/*
Most files in FFmpeg are under the GNU Lesser General Public License version 2.1
or later (LGPL v2.1+). Read the file COPYING.LGPLv2.1 for details. Some other
files have MIT/X11/BSD-style licenses. In combination the LGPL v2.1+ applies to
FFmpeg.

The source code used to build this file can be obtained at https://github.com/bgrins/videoconverter.js,
and in zip form at https://github.com/bgrins/videoconverter.js/archive/master.zip
*/

function ffmpeg_run(opts) {
  var isNode = typeof(exports) !== 'undefined';
  if (!isNode) {
    var Module = {
      'outputDirectory': 'output'
    };
    for (var i in opts) {
      Module[i] = opts[i];
    }
    var outputFilePath = Module['arguments'][Module['arguments'].length - 1];
    if (Module['arguments'].length > 2 && outputFilePath && outputFilePath.indexOf(".") > -1) {
      Module['arguments'][Module['arguments'].length - 1] = "output/" + outputFilePath;
    }
    Module['preRun'] = function() {
      FS.createFolder('/', Module['outputDirectory'], true, true);
      /* fileData / fileName is deprecated - please use file.name and file.data instead */
      if (Module['fileData']) {
        FS.createDataFile('/', Module['fileName'], Module['fileData'], true, true);
      }
      if (Module['files']) {
        Module['files'].forEach(function(file) {
          FS.createDataFile('/', file.name, file.data, true, true);
        });
      }
    };
    Module['postRun'] = function() {
      var handle = FS.analyzePath(Module['outputDirectory']);
      Module['return'] = getAllBuffers(handle);
    };
    function getAllBuffers(result) {
      var buffers = [];
      if (result && result.object && result.object.contents) {
        for (var i in result.object.contents) {
          if (result.object.contents.hasOwnProperty(i)) {
            buffers.push({
              name: i,
              data: new Uint8Array(result.object.contents[i].contents).buffer
            });
          }
        }
      }
      return buffers;
    }
  }
// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  if (!Module['printErr']) Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };

  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  Module['arguments'] = process['argv'].slice(2);

  module['exports'] = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    return read(f, 'binary');
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  this['Module'] = Module;

  eval("if (typeof gc === 'function' && gc.toString().indexOf('[native code]') > 0) var gc = undefined"); // wipe out the SpiderMonkey shell 'gc' function, which can confuse closure (uses it as a minified name, and it is then initted to a non-falsey value unexpectedly)
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WEB) {
    this['Module'] = Module;
  } else {
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}



// === Auto-generated preamble library stuff ===

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      return '(((' +target + ')+' + (quantum-1) + ')&' + -quantum + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?\{ ?[^}]* ?\}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (vararg) return 8;
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          if (Types.types[field]) {
            alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
          } else {
            alignSize = type.alignSize || QUANTUM_SIZE;
          }
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else if (field[0] === '<') {
        // vector type
        size = alignSize = Types.types[field].flatSize; // fully aligned
      } else if (field[0] === 'i') {
        // illegal integer field, that could not be legalized because it is an internal structure field
        // it is ok to have such fields, if we just use them as markers of field size and nothing more complex
        size = alignSize = parseInt(field.substr(1))/8;
        assert(size % 1 === 0, 'cannot handle non-byte-size field ' + field);
      } else {
        assert(false, 'invalid type for calculateStructAlignment');
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    if (type.name_ && type.name_[0] === '[') {
      // arrays have 2 elements, so we get the proper difference. then we scale here. that way we avoid
      // allocating a potentially huge array for [999999 x i8] etc.
      type.flatSize = parseInt(type.name_.substr(1))*type.flatSize/2;
    }
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  getAsmConst: function (code, numArgs) {
    // code is a constant string on the heap, so we can cache these
    if (!Runtime.asmConstCache) Runtime.asmConstCache = {};
    var func = Runtime.asmConstCache[code];
    if (func) return func;
    var args = [];
    for (var i = 0; i < numArgs; i++) {
      args.push(String.fromCharCode(36) + i); // $0, $1 etc
    }
    code = Pointer_stringify(code);
    if (code[0] === '"') {
      // tolerate EM_ASM("..code..") even though EM_ASM(..code..) is correct
      if (code.indexOf('"', 1) === code.length-1) {
        code = code.substr(1, code.length-2);
      } else {
        // something invalid happened, e.g. EM_ASM("..code($0)..", input)
        abort('invalid EM_ASM input |' + code + '|. Please use EM_ASM(..code..) (no quotes) or EM_ASM({ ..code($0).. }, input) (to input values)');
      }
    }
    return Runtime.asmConstCache[code] = eval('(function(' + args.join(',') + '){ ' + code + ' })'); // new Function does not allow upvars in node
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;

      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }

      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }

      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function processJSString(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+7)&-8); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = (((STATICTOP)+7)&-8); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = (((DYNAMICTOP)+7)&-8); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*(+4294967296))) : ((+((low>>>0)))+((+((high|0)))*(+4294967296)))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}


Module['Runtime'] = Runtime;









//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      value = intArrayFromString(value);
      type = 'array';
    }
    if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}

// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;

// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;

// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }

  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.
function UTF16ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16LE form. The copy will require at most (str.length*2+1)*2 bytes of space in the HEAP.
function stringToUTF16(str, outPtr) {
  for(var i = 0; i < str.length; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[(((outPtr)+(i*2))>>1)]=codeUnit;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[(((outPtr)+(str.length*2))>>1)]=0;
}
Module['stringToUTF16'] = stringToUTF16;

// Given a pointer 'ptr' to a null-terminated UTF32LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.
function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32LE form. The copy will require at most (str.length+1)*4 bytes of space in the HEAP,
// but can use less, since str.length does not return the number of characters in the string, but the number of UTF-16 code units in the string.
function stringToUTF32(str, outPtr) {
  var iChar = 0;
  for(var iCodeUnit = 0; iCodeUnit < str.length; ++iCodeUnit) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    var codeUnit = str.charCodeAt(iCodeUnit); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++iCodeUnit);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[(((outPtr)+(iChar*4))>>2)]=codeUnit;
    ++iChar;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[(((outPtr)+(iChar*4))>>2)]=0;
}
Module['stringToUTF32'] = stringToUTF32;

function demangle(func) {
  var i = 3;
  // params, etc.
  var basicTypes = {
    'v': 'void',
    'b': 'bool',
    'c': 'char',
    's': 'short',
    'i': 'int',
    'l': 'long',
    'f': 'float',
    'd': 'double',
    'w': 'wchar_t',
    'a': 'signed char',
    'h': 'unsigned char',
    't': 'unsigned short',
    'j': 'unsigned int',
    'm': 'unsigned long',
    'x': 'long long',
    'y': 'unsigned long long',
    'z': '...'
  };
  var subs = [];
  var first = true;
  function dump(x) {
    //return;
    if (x) Module.print(x);
    Module.print(func);
    var pre = '';
    for (var a = 0; a < i; a++) pre += ' ';
    Module.print (pre + '^');
  }
  function parseNested() {
    i++;
    if (func[i] === 'K') i++; // ignore const
    var parts = [];
    while (func[i] !== 'E') {
      if (func[i] === 'S') { // substitution
        i++;
        var next = func.indexOf('_', i);
        var num = func.substring(i, next) || 0;
        parts.push(subs[num] || '?');
        i = next+1;
        continue;
      }
      if (func[i] === 'C') { // constructor
        parts.push(parts[parts.length-1]);
        i += 2;
        continue;
      }
      var size = parseInt(func.substr(i));
      var pre = size.toString().length;
      if (!size || !pre) { i--; break; } // counter i++ below us
      var curr = func.substr(i + pre, size);
      parts.push(curr);
      subs.push(curr);
      i += pre + size;
    }
    i++; // skip E
    return parts;
  }
  function parse(rawList, limit, allowVoid) { // main parser
    limit = limit || Infinity;
    var ret = '', list = [];
    function flushList() {
      return '(' + list.join(', ') + ')';
    }
    var name;
    if (func[i] === 'N') {
      // namespaced N-E
      name = parseNested().join('::');
      limit--;
      if (limit === 0) return rawList ? [name] : name;
    } else {
      // not namespaced
      if (func[i] === 'K' || (first && func[i] === 'L')) i++; // ignore const and first 'L'
      var size = parseInt(func.substr(i));
      if (size) {
        var pre = size.toString().length;
        name = func.substr(i + pre, size);
        i += pre + size;
      }
    }
    first = false;
    if (func[i] === 'I') {
      i++;
      var iList = parse(true);
      var iRet = parse(true, 1, true);
      ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
    } else {
      ret = name;
    }
    paramLoop: while (i < func.length && limit-- > 0) {
      //dump('paramLoop');
      var c = func[i++];
      if (c in basicTypes) {
        list.push(basicTypes[c]);
      } else {
        switch (c) {
          case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
          case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
          case 'L': { // literal
            i++; // skip basic type
            var end = func.indexOf('E', i);
            var size = end - i;
            list.push(func.substr(i, size));
            i += size + 2; // size + 'EE'
            break;
          }
          case 'A': { // array
            var size = parseInt(func.substr(i));
            i += size.toString().length;
            if (func[i] !== '_') throw '?';
            i++; // skip _
            list.push(parse(true, 1, true)[0] + ' [' + size + ']');
            break;
          }
          case 'E': break paramLoop;
          default: ret += '?' + c; break paramLoop;
        }
      }
    }
    if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
    return rawList ? list : ret + flushList();
  }
  try {
    // Special-case the entry point, since its name differs from other name mangling.
    if (func == 'Object._main' || func == '_main') {
      return 'main()';
    }
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    switch (func[3]) {
      case 'n': return 'operator new()';
      case 'd': return 'operator delete()';
    }
    return parse();
  } catch(e) {
    return func;
  }
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function stackTrace() {
  var stack = new Error().stack;
  return stack ? demangleAll(stack) : '(no stack trace available)'; // Stack trace is not available at least on IE10 and Safari 6.
}

// Memory management

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return (x+4095)&-4096;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk

function enlargeMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.');
}

var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 33554432;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;

var totalMemory = 4096;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be more reasonable');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');

var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;

function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;

// Tools

// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr;
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=str.charCodeAt(i);
  }
  if (!dontAddNull) HEAP8[(((buffer)+(str.length))|0)]=0;
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data


var memoryInitializer = null;

// === Body ===



STATIC_BASE = 8;

STATICTOP = STATIC_BASE + 10245416;


/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } });



































































































































































































































































































































































































































































































































































































































































































































































































































































var _vp8_mode_contexts;


























































































































































































































































































































































































































































































































































































































































































































































































































































































































































var _stdout;
var _stdout=_stdout=allocate(1, "i32*", ALLOC_STATIC);


var _stderr;
var _stderr=_stderr=allocate(1, "i32*", ALLOC_STATIC);


















































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































/* memory initializer */ allocate([0,9,17,18,12,40,27,7,35,57,29,30,58,38,53,47,1,2,24,11,19,48,20,14,42,50,22,37,59,31,60,55,8,3,32,4,26,41,13,21,49,43,15,44,52,39,61,62,16,10,25,5,33,34,6,28,56,36,23,51,45,46,54,63,0,0,0,0,0,0,0,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,0,0,0,0,0,0,0,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,0,0,0,0,0,0,0,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,10,0,0,0,1,0,0,0,2,0,0,0,128,2,128,2,157,2,224,1,196,2,98,1,236,2,1,1,24,3,198,0,248,2,143,0,40,3,101,0,4,3,72,0,224,1,157,2,25,2,25,2,86,2,160,1,149,2,60,1,207,2,250,0,195,2,185,0,0,3,134,0,233,2,97,0,98,1,196,2,160,1,86,2,232,1,232,1,52,2,132,1,122,2,61,1,130,2,241,0,204,2,179,0,194,2,132,0,1,1,236,2,60,1,149,2,132,1,52,2,213,1,213,1,31,2,139,1,59,2,55,1,143,2,238,0,148,2,180,0,198,0,24,3,250,0,207,2,61,1,122,2,139,1,31,2,213,1,213,1,251,1,124,1,85,2,43,1,104,2,231,0,161,0,87,3,206,0,20,3,10,1,198,2,84,1,111,2,155,1,36,2,199,1,199,1,36,2,110,1,64,2,32,1,122,0,204,3,159,0,146,3,211,0,74,3,20,1,246,2,85,1,170,2,133,1,72,2,227,1,227,1,8,2,134,1,110,0,148,4,144,0,83,4,193,0,4,4,254,0,164,3,61,1,78,3,110,1,219,2,202,1,99,2,243,1,243,1,32,108,34,0,16,174,38,0,152,26,156,0,184,159,35,0,152,193,34,0,224,0,34,0,16,110,33,0,168,246,32,0,40,147,32,0,152,26,156,0,64,1,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,35,0,0,0,0,0,0,0,4,0,0,0,44,1,0,0,33,0,0,0,5,0,0,0,43,1,0,0,70,0,0,0,80,0,0,0,76,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,14,0,0,0,13,0,0,0,12,0,0,0,34,0,0,0,255,255,255,255,165,44,67,28,235,226,230,63,93,109,197,254,178,123,178,63,188,150,144,15,122,54,203,63,164,112,61,10,215,163,216,191,0,0,0,0,0,0,224,63,113,61,10,215,163,112,189,191,117,147,24,4,86,14,221,191,90,100,59,223,79,141,167,191,0,0,0,0,0,0,224,63,225,122,20,174,71,225,226,63,41,92,143,194,245,40,188,63,51,51,51,51,51,51,211,63,201,118,190,159,26,47,213,191,0,0,0,0,0,0,224,63,111,18,131,192,202,161,197,191,139,108,231,251,169,241,218,191,211,77,98,16,88,57,180,191,0,0,0,0,0,0,224,63,98,16,88,57,180,200,226,63,201,118,190,159,26,47,189,63,137,65,96,229,208,34,211,63,21,140,74,234,4,52,213,191,0,0,0,0,0,0,224,63,213,231,106,43,246,151,197,191,235,115,181,21,251,203,218,191,85,48,42,169,19,208,180,191,0,0,0,0,0,0,224,63,59,223,79,141,151,110,230,63,18,131,192,202,161,69,182,63,137,65,96,229,208,34,203,63,250,126,106,188,116,147,216,191,0,0,0,0,0,0,224,63,25,4,86,14,45,178,189,191,123,20,174,71,225,122,220,191,41,92,143,194,245,40,172,191,0,0,0,0,0,0,224,63,219,16,138,255,0,0,0,0,24,5,0,0,8,5,0,0,248,4,0,0,232,4,0,0,0,0,0,0,0,0,0,0,0,0,252,255,4,0,240,255,16,0,220,255,36,0,176,255,4,0,250,255,20,0,236,255,46,0,210,255,94,0,162,255,0,0,254,255,4,0,250,255,8,0,244,255,12,0,244,255,0,0,254,255,2,0,250,255,6,0,244,255,12,0,244,255,232,225,36,0,56,171,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,232,225,36,0,160,201,34,0,192,9,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,232,225,36,0,168,115,33,0,248,250,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,232,225,36,0,112,151,32,0,24,60,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,232,225,36,0,144,34,40,0,240,193,39,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,232,225,36,0,240,93,39,0,32,16,39,0,8,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,240,93,39,0,32,205,38,0,248,136,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,240,93,39,0,176,77,38,0,152,22,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,240,93,39,0,32,236,37,0,40,191,37,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,240,93,39,0,216,157,37,0,184,109,37,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,216,157,37,0,160,45,37,0,160,6,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,157,37,0,8,223,36,0,200,188,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,157,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,218,34,0,112,0,0,0,40,5,0,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,12,0,0,0,15,0,0,0,20,0,0,0,25,0,0,0,34,0,0,0,46,0,0,0,64,0,0,0,82,0,0,0,94,0,0,0,103,0,0,0,108,0,0,0,113,0,0,0,116,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,32,17,17,9,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,8,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,7,0,0,0,6,0,0,0,3,0,0,0,5,0,0,0,2,0,0,0,14,0,0,0,13,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,13,0,0,0,24,0,0,0,4,0,0,0,11,0,0,0,4,0,0,0,28,0,0,0,25,0,0,0,4,0,0,0,6,0,0,0,6,0,0,0,26,0,0,0,48,0,0,0,5,0,0,0,22,0,0,0,8,0,0,0,56,0,0,0,50,0,0,0,5,0,0,0,12,0,0,0,12,0,0,0,52,0,0,0,96,0,0,0,6,0,0,0,44,0,0,0,16,0,0,0,112,0,0,0,100,0,0,0,6,0,0,0,24,0,0,0,24,0,0,0,104,0,0,0,192,0,0,0,7,0,0,0,88,0,0,0,32,0,0,0,224,0,0,0,200,0,0,0,7,0,0,0,48,0,0,0,48,0,0,0,208,0,0,0,128,1,0,0,8,0,0,0,176,0,0,0,64,0,0,0,192,1,0,0,144,1,0,0,8,0,0,0,96,0,0,0,96,0,0,0,160,1,0,0,0,3,0,0,9,0,0,0,96,1,0,0,128,0,0,0,128,3,0,0,32,3,0,0,9,0,0,0,192,0,0,0,192,0,0,0,64,3,0,0,0,6,0,0,10,0,0,0,192,2,0,0,0,1,0,0,0,7,0,0,64,6,0,0,10,0,0,0,128,1,0,0,128,1,0,0,128,6,0,0,0,12,0,0,11,0,0,0,128,5,0,0,0,2,0,0,0,14,0,0,128,12,0,0,11,0,0,0,0,3,0,0,0,3,0,0,0,13,0,0,0,24,0,0,12,0,0,0,0,11,0,0,0,4,0,0,0,28,0,0,0,25,0,0,12,0,0,0,0,6,0,0,0,6,0,0,0,26,0,0,0,48,0,0,13,0,0,0,0,22,0,0,0,8,0,0,0,56,0,0,0,50,0,0,13,0,0,0,0,12,0,0,0,12,0,0,0,52,0,0,0,96,0,0,14,0,0,0,0,44,0,0,0,16,0,0,0,112,0,0,0,100,0,0,14,0,0,0,0,24,0,0,0,24,0,0,0,104,0,0,0,192,0,0,15,0,0,0,0,88,0,0,0,32,0,0,0,224,0,0,0,200,0,0,15,0,0,0,0,48,0,0,0,48,0,0,0,208,0,0,0,128,1,0,16,0,0,0,0,176,0,0,0,64,0,0,0,192,1,0,0,144,1,0,16,0,0,0,0,96,0,0,0,96,0,0,0,160,1,0,0,0,3,0,17,0,0,0,0,96,1,0,0,128,0,0,0,128,3,0,0,32,3,0,17,0,0,0,0,192,0,0,0,192,0,0,0,64,3,0,0,0,6,0,18,0,0,0,0,192,2,0,0,0,1,0,0,0,7,0,0,64,6,0,18,0,0,0,0,128,1,0,0,128,1,0,0,128,6,0,0,0,12,0,19,0,0,0,0,128,5,0,0,0,2,0,0,0,14,0,0,128,12,0,19,0,0,0,0,0,3,0,0,0,3,0,0,0,13,0,0,0,24,0,20,0,0,0,0,0,11,0,0,0,4,0,0,0,28,0,0,0,25,0,20,0,0,0,0,0,6,0,0,0,6,0,0,0,26,0,0,0,48,0,21,0,0,0,0,0,22,0,0,0,8,0,0,0,56,0,0,0,50,0,21,0,0,0,0,0,12,0,0,0,12,0,0,0,52,0,0,0,96,0,22,0,0,0,0,0,44,0,0,0,16,0,0,0,112,0,0,0,100,0,22,0,0,0,0,0,24,0,0,0,24,0,0,0,104,0,0,0,192,0,23,0,0,0,0,0,88,0,0,0,32,0,0,0,224,0,0,0,200,0,23,0,0,0,0,0,48,0,0,0,48,0,0,0,208,0,0,0,128,1,24,0,0,0,0,0,176,0,0,0,64,0,0,0,192,1,0,0,144,1,24,0,0,0,0,0,96,0,0,0,96,0,0,0,160,1,0,0,0,3,25,0,0,0,0,0,96,1,0,0,128,0,0,0,128,3,0,0,32,3,25,0,0,0,0,0,192,0,0,0,192,0,0,0,64,3,0,0,0,6,26,0,0,0,0,0,192,2,0,0,0,1,0,0,0,7,0,0,64,6,26,0,0,0,0,0,128,1,0,0,128,1,0,0,128,6,0,0,0,12,0,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,115,0,0,0,204,255,255,255,98,0,0,0,201,255,255,255,122,0,0,0,196,255,255,255,51,51,243,64,102,102,102,64,205,204,140,64,205,204,108,64,51,51,195,64,51,51,163,64,51,51,19,64,205,204,204,63,102,102,198,64,0,0,192,63,102,102,230,63,154,153,153,63,0,0,0,0,0,0,0,0,64,2,36,2,70,2,106,2,34,2,104,2,48,2,130,2,72,2,70,2,192,2,152,2,0,2,32,2,144,2,128,2,0,2,136,2,70,2,54,2,20,2,102,2,84,2,136,2,74,2,40,2,72,2,78,2,32,2,66,2,72,2,112,2,16,2,16,2,14,2,16,2,24,2,16,2,14,2,32,2,32,2,0,2,0,2,16,2,16,2,32,2,0,2,32,2,128,0,128,0,128,0,128,0,128,0,128,0,0,0,0,0,0,8,4,10,11,2,6,9,1,3,5,7,4,0,8,11,10,3,5,2,6,9,1,7,8,0,4,10,11,1,7,2,6,9,3,5,0,0,0,0,0,0,1,0,4,0,3,0,5,0,3,0,12,0,4,0,13,0,4,0,56,0,6,0,29,0,5,0,57,0,6,0,60,0,6,0,61,0,6,0,62,0,6,0,63,0,6,0,0,0,5,0,1,0,5,0,2,0,5,0,1,0,2,0,2,0,2,0,2,0,4,0,3,0,5,0,6,0,3,0,3,0,4,0,14,0,4,0,30,0,5,0,31,0,5,0,0,0,2,0,1,0,2,0,4,0,3,0,5,0,3,0,6,0,3,0,56,0,6,0,57,0,6,0,29,0,5,0,60,0,6,0,61,0,6,0,62,0,6,0,63,0,6,0,0,0,3,0,2,0,4,0,3,0,4,0,1,0,2,0,2,0,2,0,24,0,5,0,25,0,5,0,13,0,4,0,28,0,5,0,29,0,5,0,30,0,5,0,31,0,5,0,0,0,2,0,1,0,2,0,4,0,3,0,5,0,3,0,6,0,3,0,56,0,6,0,29,0,5,0,57,0,6,0,60,0,6,0,61,0,6,0,62,0,6,0,63,0,6,0,0,0,1,0,2,0,2,0,6,0,3,0,28,0,5,0,29,0,5,0,120,0,7,0,61,0,6,0,121,0,7,0,124,0,7,0,125,0,7,0,126,0,7,0,127,0,7,0,34,50,51,83,35,66,67,99,36,82,52,115,37,98,68,131,38,114,53,84,39,130,69,100,40,146,54,116,41,162,70,132,0,0,5,0,1,0,4,0,1,0,5,0,4,0,5,0,5,0,5,0,6,0,5,0,14,0,6,0,15,0,6,0,64,0,8,0,65,0,8,0,64,8,13,0,65,8,13,0,66,8,13,0,67,8,13,0,68,8,13,0,69,8,13,0,70,8,13,0,2,0,2,0,3,0,2,0,3,0,3,0,5,0,4,0,9,0,5,0,17,0,6,0,67,0,8,0,133,0,9,0,71,8,13,0,72,8,13,0,73,8,13,0,74,8,13,0,75,8,13,0,76,8,13,0,77,8,13,0,78,8,13,0,79,8,13,0,0,0,4,0,1,0,3,0,2,0,3,0,1,0,4,0,6,0,4,0,4,0,3,0,7,0,4,0,5,0,3,0,12,0,4,0,13,0,4,0,28,0,5,0,58,0,6,0,216,1,9,0,217,1,9,0,160,29,13,0,161,29,13,0,162,29,13,0,60,0,6,0,61,0,6,0,62,0,6,0,119,0,7,0,219,1,9,0,126,0,7,0,254,0,8,0,254,1,9,0,163,29,13,0,164,29,13,0,165,29,13,0,211,14,12,0,212,14,12,0,255,1,9,0,213,14,12,0,214,14,12,0,215,14,12,0,0,0,4,0,1,0,3,0,2,0,3,0,1,0,4,0,6,0,4,0,7,0,4,0,8,0,4,0,9,0,4,0,40,0,6,0,41,0,6,0,84,0,7,0,85,0,7,0,192,10,12,0,193,10,12,0,194,10,12,0,195,10,12,0,196,10,12,0,11,0,4,0,6,0,3,0,14,0,4,0,30,0,5,0,62,0,6,0,63,0,6,0,87,0,7,0,173,0,8,0,197,10,12,0,198,10,12,0,199,10,12,0,200,10,12,0,201,10,12,0,202,10,12,0,203,10,12,0,102,5,11,0,103,5,11,0,0,0,4,0,1,0,2,0,1,0,3,0,4,0,3,0,5,0,3,0,6,0,3,0,1,0,4,0,14,0,4,0,60,0,6,0,61,0,6,0,124,0,7,0,250,0,8,0,192,62,14,0,193,62,14,0,194,62,14,0,195,62,14,0,98,31,13,0,247,1,9,0,126,0,7,0,254,0,8,0,255,0,8,0,99,31,13,0,100,31,13,0,101,31,13,0,102,31,13,0,103,31,13,0,104,31,13,0,105,31,13,0,106,31,13,0,107,31,13,0,108,31,13,0,109,31,13,0,110,31,13,0,111,31,13,0,0,0,7,0,1,0,7,0,2,0,7,0,3,0,7,0,4,0,7,0,5,0,7,0,6,0,7,0,7,0,7,0,8,0,7,0,9,0,7,0,10,0,7,0,11,0,7,0,12,0,7,0,13,0,7,0,14,0,7,0,15,0,7,0,16,0,7,0,1,0,1,0,1,0,2,0,17,0,7,0,18,0,7,0,19,0,7,0,20,0,7,0,21,0,7,0,22,0,7,0,23,0,7,0,24,0,7,0,25,0,7,0,26,0,7,0,27,0,7,0,28,0,7,0,29,0,7,0,30,0,7,0,31,0,7,0,0,0,5,0,1,0,4,0,1,0,5,0,8,0,6,0,9,0,6,0,10,0,6,0,22,0,7,0,12,0,6,0,23,0,7,0,13,0,6,0,56,0,8,0,29,0,7,0,57,0,8,0,128,7,13,0,129,7,13,0,130,7,13,0,131,7,13,0,2,0,3,0,1,0,1,0,3,0,3,0,31,0,7,0,61,0,8,0,121,0,9,0,132,7,13,0,133,7,13,0,134,7,13,0,135,7,13,0,136,7,13,0,137,7,13,0,138,7,13,0,139,7,13,0,140,7,13,0,141,7,13,0,199,3,12,0,0,0,4,0,1,0,2,0,1,0,3,0,4,0,3,0,1,0,4,0,10,0,4,0,22,0,5,0,46,0,6,0,94,0,7,0,95,0,7,0,192,0,8,0,64,48,14,0,65,48,14,0,5,3,10,0,131,1,9,0,66,48,14,0,67,48,14,0,13,0,4,0,7,0,3,0,25,0,5,0,49,0,6,0,194,0,8,0,195,0,8,0,68,48,14,0,69,48,14,0,70,48,14,0,71,48,14,0,72,48,14,0,73,48,14,0,74,48,14,0,75,48,14,0,76,48,14,0,77,48,14,0,39,24,13,0,0,0,6,0,1,0,6,0,2,0,6,0,6,0,7,0,7,0,7,0,4,0,6,0,5,0,6,0,6,0,6,0,14,0,7,0,30,0,8,0,31,0,8,0,64,0,9,0,130,0,10,0,48,8,14,0,49,8,14,0,50,8,14,0,51,8,14,0,1,0,1,0,1,0,2,0,3,0,4,0,5,0,5,0,9,0,6,0,17,0,7,0,33,0,8,0,52,8,14,0,53,8,14,0,54,8,14,0,55,8,14,0,56,8,14,0,57,8,14,0,58,8,14,0,59,8,14,0,30,4,13,0,31,4,13,0,0,0,5,0,1,0,4,0,2,0,4,0,1,0,5,0,6,0,5,0,4,0,4,0,7,0,5,0,10,0,5,0,44,0,7,0,45,0,7,0,192,5,12,0,193,5,12,0,194,5,12,0,195,5,12,0,196,5,12,0,197,5,12,0,198,5,12,0,3,0,3,0,2,0,2,0,6,0,3,0,14,0,4,0,30,0,5,0,31,0,5,0,47,0,7,0,93,0,8,0,199,5,12,0,200,5,12,0,201,5,12,0,202,5,12,0,203,5,12,0,204,5,12,0,205,5,12,0,206,5,12,0,207,5,12,0,0,0,3,0,1,0,3,0,2,0,3,0,6,0,4,0,7,0,4,0,4,0,3,0,10,0,4,0,11,0,4,0,48,0,6,0,98,0,7,0,99,0,7,0,64,6,11,0,65,6,11,0,66,6,11,0,67,6,11,0,68,6,11,0,69,6,11,0,51,0,6,0,13,0,4,0,28,0,5,0,29,0,5,0,60,0,6,0,31,0,5,0,101,0,7,0,122,0,7,0,70,6,11,0,123,0,7,0,71,6,11,0,72,6,11,0,73,6,11,0,74,6,11,0,75,6,11,0,38,3,10,0,39,3,10,0,0,0,7,0,1,0,7,0,1,0,6,0,4,0,7,0,3,0,6,0,5,0,7,0,16,0,8,0,17,0,8,0,64,2,13,0,65,2,13,0,66,2,13,0,67,2,13,0,68,2,13,0,69,2,13,0,70,2,13,0,71,2,13,0,36,1,12,0,1,0,1,0,1,0,2,0,1,0,3,0,3,0,5,0,5,0,6,0,19,0,8,0,37,1,12,0,38,1,12,0,39,1,12,0,40,1,12,0,41,1,12,0,42,1,12,0,43,1,12,0,44,1,12,0,45,1,12,0,46,1,12,0,47,1,12,0,0,0,4,0,1,0,3,0,2,0,3,0,1,0,4,0,6,0,4,0,4,0,3,0,5,0,3,0,6,0,3,0,14,0,5,0,15,0,5,0,112,0,7,0,16,7,11,0,17,7,11,0,18,7,11,0,19,7,11,0,20,7,11,0,21,7,11,0,29,0,5,0,114,0,7,0,60,0,6,0,61,0,6,0,115,0,7,0,124,0,7,0,125,0,7,0,126,0,7,0,22,7,11,0,23,7,11,0,24,7,11,0,127,0,7,0,25,7,11,0,26,7,11,0,27,7,11,0,142,3,10,0,143,3,10,0,0,0,8,0,1,0,7,0,2,0,7,0,3,0,7,0,2,0,9,0,8,0,8,0,3,0,9,0,64,2,14,0,65,2,14,0,66,2,14,0,67,2,14,0,68,2,14,0,69,2,14,0,70,2,14,0,71,2,14,0,36,1,13,0,37,1,13,0,1,0,2,0,1,0,1,0,1,0,3,0,1,0,4,0,3,0,6,0,5,0,7,0,19,0,9,0,38,1,13,0,39,1,13,0,40,1,13,0,41,1,13,0,42,1,13,0,43,1,13,0,44,1,13,0,45,1,13,0,46,1,13,0,47,1,13,0,0,0,7,0,1,0,7,0,1,0,6,0,2,0,6,0,3,0,6,0,4,0,6,0,5,0,6,0,6,0,6,0,7,0,6,0,8,0,6,0,9,0,6,0,10,0,6,0,11,0,6,0,12,0,6,0,13,0,6,0,14,0,6,0,15,0,6,0,16,0,6,0,17,0,6,0,18,0,6,0,19,0,6,0,20,0,6,0,21,0,6,0,22,0,6,0,23,0,6,0,24,0,6,0,25,0,6,0,1,0,1,0,26,0,6,0,27,0,6,0,28,0,6,0,29,0,6,0,30,0,6,0,31,0,6,0,0,0,5,0,1,0,4,0,1,0,5,0,4,0,5,0,10,0,6,0,6,0,5,0,11,0,6,0,14,0,6,0,60,0,8,0,61,0,8,0,192,7,13,0,193,7,13,0,194,7,13,0,195,7,13,0,196,7,13,0,197,7,13,0,198,7,13,0,1,0,2,0,2,0,2,0,6,0,3,0,14,0,4,0,30,0,5,0,31,0,5,0,63,0,8,0,125,0,9,0,199,7,13,0,200,7,13,0,201,7,13,0,202,7,13,0,203,7,13,0,204,7,13,0,205,7,13,0,206,7,13,0,207,7,13,0,0,0,7,0,1,0,7,0,2,0,7,0,3,0,7,0,4,0,7,0,5,0,7,0,6,0,7,0,7,0,7,0,8,0,7,0,9,0,7,0,10,0,7,0,11,0,7,0,12,0,7,0,13,0,7,0,14,0,7,0,15,0,7,0,16,0,7,0,1,0,1,0,1,0,2,0,17,0,7,0,18,0,7,0,19,0,7,0,20,0,7,0,21,0,7,0,22,0,7,0,23,0,7,0,24,0,7,0,25,0,7,0,26,0,7,0,27,0,7,0,28,0,7,0,29,0,7,0,30,0,7,0,31,0,7,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,18,0,6,0,38,0,7,0,20,0,6,0,78,0,8,0,79,0,8,0,168,0,9,0,82,1,10,0,170,0,9,0,171,0,9,0,172,0,9,0,96,42,15,0,167,2,11,0,6,0,4,0,11,0,5,0,28,0,6,0,58,0,7,0,15,0,5,0,59,0,7,0,16,0,5,0,5,0,3,0,9,0,4,0,17,0,5,0,24,0,5,0,25,0,5,0,26,0,5,0,54,0,6,0,55,0,6,0,112,0,7,0,87,0,8,0,226,0,8,0,227,0,8,0,228,0,8,0,229,0,8,0,173,0,9,0,152,3,10,0,58,0,6,0,118,0,7,0,231,0,8,0,238,0,8,0,239,0,8,0,50,7,11,0,154,3,10,0,51,7,11,0,97,42,15,0,120,0,7,0,49,21,14,0,50,21,14,0,51,21,14,0,61,0,6,0,155,3,10,0,52,21,14,0,53,21,14,0,54,21,14,0,121,0,7,0,55,21,14,0,248,0,8,0,242,1,9,0,204,7,11,0,231,3,10,0,205,7,11,0,128,62,14,0,251,0,8,0,233,3,10,0,129,62,14,0,130,62,14,0,131,62,14,0,132,62,14,0,133,62,14,0,134,62,14,0,63,0,6,0,245,1,9,0,209,7,11,0,135,62,14,0,0,0,2,0,2,0,3,0,6,0,4,0,14,0,5,0,30,0,6,0,31,0,6,0,64,0,7,0,130,0,8,0,131,0,8,0,132,0,8,0,10,1,9,0,11,1,9,0,48,4,11,0,49,4,11,0,50,4,11,0,51,4,11,0,5,0,3,0,17,0,5,0,36,0,6,0,74,0,7,0,12,0,4,0,38,0,6,0,13,0,4,0,135,0,8,0,13,1,9,0,88,2,10,0,45,1,9,0,89,2,10,0,92,2,10,0,116,9,12,0,94,2,10,0,95,2,10,0,112,2,10,0,113,2,10,0,187,4,11,0,117,9,12,0,114,2,10,0,204,9,12,0,205,9,12,0,112,78,15,0,113,78,15,0,114,78,15,0,115,78,15,0,58,39,14,0,59,39,14,0,60,39,14,0,232,4,11,0,233,4,11,0,158,0,8,0,117,2,10,0,216,9,12,0,61,39,14,0,14,0,4,0,60,0,6,0,122,0,7,0,159,0,8,0,119,2,10,0,62,0,6,0,246,0,8,0,237,4,11,0,220,3,10,0,62,39,14,0,186,7,11,0,217,9,12,0,63,39,14,0,216,61,14,0,217,61,14,0,218,61,14,0,219,61,14,0,220,61,14,0,221,61,14,0,222,61,14,0,223,61,14,0,63,0,6,0,188,7,11,0,189,7,11,0,223,3,10,0,0,0,3,0,2,0,4,0,6,0,5,0,14,0,6,0,30,0,7,0,62,0,8,0,63,0,8,0,64,0,8,0,4,1,10,0,131,0,9,0,5,1,10,0,8,1,10,0,64,66,16,0,10,1,10,0,11,1,10,0,65,66,16,0,3,0,3,0,9,0,5,0,17,0,6,0,67,0,8,0,4,0,3,0,10,0,5,0,10,0,4,0,44,0,7,0,180,0,9,0,181,0,9,0,182,0,9,0,183,0,9,0,184,0,9,0,114,1,10,0,115,1,10,0,116,1,10,0,117,1,10,0,118,1,10,0,119,1,10,0,188,0,9,0,122,1,10,0,19,2,11,0,66,66,16,0,123,1,10,0,248,2,11,0,125,1,10,0,249,2,11,0,126,1,10,0,67,66,16,0,254,2,11,0,34,33,15,0,35,33,15,0,88,0,7,0,100,1,9,0,36,33,15,0,37,33,15,0,6,0,3,0,14,0,4,0,45,0,6,0,46,0,6,0,179,0,8,0,30,0,5,0,94,0,7,0,38,33,15,0,39,33,15,0,40,33,15,0,41,33,15,0,255,2,11,0,42,33,15,0,148,5,11,0,149,5,11,0,150,5,11,0,43,33,15,0,44,33,15,0,45,33,15,0,46,33,15,0,47,33,15,0,31,0,5,0,151,5,11,0,190,0,8,0,191,0,8,0,0,0,2,0,2,0,3,0,6,0,4,0,7,0,4,0,16,0,5,0,17,0,5,0,36,0,6,0,37,0,6,0,38,0,6,0,39,0,6,0,80,0,7,0,81,0,7,0,164,0,8,0,165,0,8,0,166,0,8,0,78,1,9,0,11,0,4,0,42,0,6,0,86,0,7,0,79,1,9,0,48,0,6,0,174,0,8,0,98,0,7,0,50,0,6,0,51,0,6,0,52,0,6,0,53,0,6,0,54,0,6,0,99,0,7,0,110,0,7,0,111,0,7,0,112,0,7,0,113,0,7,0,114,0,7,0,115,0,7,0,116,0,7,0,175,0,8,0,234,0,8,0,214,1,9,0,92,7,11,0,175,3,10,0,208,117,15,0,209,117,15,0,210,117,15,0,211,117,15,0,212,117,15,0,118,0,7,0,238,0,8,0,239,0,8,0,187,14,12,0,224,1,9,0,213,117,15,0,121,0,7,0,225,1,9,0,214,117,15,0,215,117,15,0,128,120,15,0,244,0,8,0,137,7,11,0,62,0,6,0,123,0,7,0,245,0,8,0,252,0,8,0,127,0,7,0,227,1,9,0,138,7,11,0,139,7,11,0,129,120,15,0,130,120,15,0,131,120,15,0,66,60,14,0,67,60,14,0,68,60,14,0,253,0,8,0,69,60,14,0,70,60,14,0,71,60,14,0,0,0,2,0,4,0,4,0,10,0,5,0,22,0,6,0,23,0,6,0,48,0,7,0,49,0,7,0,100,0,8,0,101,0,8,0,102,0,8,0,206,0,9,0,207,0,9,0,160,1,10,0,161,1,10,0,32,26,14,0,137,6,12,0,4,0,3,0,14,0,5,0,27,0,6,0,53,0,7,0,10,0,4,0,30,0,6,0,22,0,5,0,23,0,5,0,31,0,6,0,48,0,6,0,49,0,6,0,100,0,7,0,101,0,7,0,105,0,8,0,102,0,7,0,206,0,8,0,207,0,8,0,208,0,8,0,209,0,8,0,210,0,8,0,166,1,9,0,163,1,10,0,78,3,10,0,106,0,7,0,214,0,8,0,174,1,9,0,175,1,9,0,79,3,10,0,69,3,11,0,176,1,9,0,177,1,9,0,100,3,10,0,109,0,7,0,220,0,8,0,148,13,12,0,149,13,12,0,14,0,4,0,60,0,6,0,221,0,8,0,222,0,8,0,179,1,9,0,61,0,6,0,223,0,8,0,240,1,9,0,226,3,10,0,227,3,10,0,203,6,11,0,228,3,10,0,202,7,11,0,243,1,9,0,244,1,9,0,203,7,11,0,212,7,11,0,33,26,14,0,34,26,14,0,213,7,11,0,35,26,14,0,63,0,6,0,246,1,9,0,247,1,9,0,235,3,10,0,0,0,2,0,2,0,3,0,6,0,4,0,14,0,5,0,15,0,5,0,32,0,6,0,33,0,6,0,68,0,7,0,69,0,7,0,70,0,7,0,142,0,8,0,143,0,8,0,144,0,8,0,34,1,9,0,70,2,10,0,36,1,9,0,5,0,3,0,19,0,5,0,74,0,7,0,147,0,8,0,24,0,5,0,75,0,7,0,50,0,6,0,26,0,5,0,51,0,6,0,108,0,7,0,109,0,7,0,110,0,7,0,222,0,8,0,223,0,8,0,112,0,7,0,226,0,8,0,227,0,8,0,228,0,8,0,229,0,8,0,230,0,8,0,231,0,8,0,37,1,9,0,208,1,9,0,142,4,11,0,30,9,12,0,31,9,12,0,64,116,15,0,17,29,13,0,65,116,15,0,66,116,15,0,233,0,8,0,212,1,9,0,235,0,8,0,163,3,10,0,213,1,9,0,18,29,13,0,30,0,5,0,118,0,7,0,220,1,9,0,221,1,9,0,67,116,15,0,124,0,7,0,69,7,11,0,239,0,8,0,250,0,8,0,251,0,8,0,248,1,9,0,253,0,8,0,228,7,11,0,202,15,12,0,19,29,13,0,88,126,15,0,89,126,15,0,90,126,15,0,91,126,15,0,92,126,15,0,93,126,15,0,127,0,7,0,47,63,14,0,230,7,11,0,231,7,11,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,9,0,5,0,20,0,6,0,21,0,6,0,44,0,7,0,90,0,8,0,91,0,8,0,92,0,8,0,186,0,9,0,187,0,9,0,188,0,9,0,244,2,11,0,234,5,12,0,3,0,3,0,16,0,5,0,34,0,6,0,70,0,7,0,9,0,4,0,40,0,6,0,21,0,5,0,11,0,4,0,24,0,5,0,41,0,6,0,50,0,6,0,71,0,7,0,102,0,7,0,103,0,7,0,104,0,7,0,105,0,7,0,106,0,7,0,95,0,8,0,214,0,8,0,215,0,8,0,176,1,9,0,217,0,8,0,123,1,10,0,109,0,7,0,220,0,8,0,177,1,9,0,232,6,11,0,187,1,9,0,117,3,10,0,235,5,12,0,188,1,9,0,144,110,15,0,56,0,6,0,114,0,7,0,145,110,15,0,146,110,15,0,29,0,5,0,115,0,7,0,189,1,9,0,248,6,11,0,147,110,15,0,60,0,6,0,191,1,9,0,244,0,8,0,234,1,9,0,125,3,10,0,214,3,10,0,249,6,11,0,148,110,15,0,246,0,8,0,238,1,9,0,149,110,15,0,150,110,15,0,151,110,15,0,76,55,14,0,77,55,14,0,78,55,14,0,31,0,5,0,215,3,10,0,239,1,9,0,79,55,14,0,0,0,2,0,4,0,4,0,10,0,5,0,22,0,6,0,46,0,7,0,47,0,7,0,96,0,8,0,97,0,8,0,196,0,9,0,197,0,9,0,198,0,9,0,142,1,10,0,224,49,15,0,225,49,15,0,226,49,15,0,227,49,15,0,4,0,3,0,13,0,5,0,25,0,6,0,56,0,7,0,10,0,4,0,29,0,6,0,11,0,4,0,114,0,8,0,115,0,8,0,240,0,9,0,226,1,10,0,242,0,9,0,227,1,10,0,243,0,9,0,232,1,10,0,233,1,10,0,228,49,15,0,234,1,10,0,31,3,11,0,214,3,11,0,229,49,15,0,236,1,10,0,230,49,15,0,247,0,9,0,215,3,11,0,231,49,15,0,232,49,15,0,218,3,11,0,219,3,11,0,233,49,15,0,224,3,11,0,234,49,15,0,63,0,7,0,241,1,10,0,235,49,15,0,236,49,15,0,6,0,3,0,28,0,5,0,116,0,7,0,117,0,7,0,249,0,9,0,30,0,5,0,118,0,7,0,250,0,9,0,225,3,11,0,237,49,15,0,247,24,14,0,96,31,14,0,97,31,14,0,220,1,9,0,221,1,9,0,98,31,14,0,99,31,14,0,100,31,14,0,101,31,14,0,102,31,14,0,103,31,14,0,31,0,5,0,237,3,11,0,239,0,8,0,247,1,10,0,0,0,3,0,2,0,4,0,6,0,5,0,7,0,5,0,8,0,5,0,9,0,5,0,20,0,6,0,42,0,7,0,22,0,6,0,43,0,7,0,92,0,8,0,47,0,7,0,48,0,7,0,93,0,8,0,98,0,8,0,198,0,9,0,7,0,4,0,25,0,6,0,26,0,6,0,54,0,7,0,16,0,5,0,110,0,8,0,34,0,6,0,9,0,4,0,10,0,4,0,22,0,5,0,35,0,6,0,46,0,6,0,47,0,6,0,48,0,6,0,98,0,7,0,99,0,7,0,100,0,7,0,101,0,7,0,102,0,7,0,103,0,7,0,104,0,7,0,105,0,7,0,106,0,7,0,107,0,7,0,108,0,7,0,199,0,9,0,222,0,9,0,223,0,9,0,208,6,11,0,181,1,9,0,55,0,6,0,219,0,8,0,28,0,5,0,116,0,7,0,212,1,9,0,213,1,9,0,118,0,7,0,105,3,10,0,136,54,14,0,137,54,14,0,138,54,14,0,119,0,7,0,172,3,10,0,120,0,7,0,242,0,8,0,215,1,9,0,243,0,8,0,122,0,7,0,139,54,14,0,123,0,7,0,124,0,7,0,173,3,10,0,232,3,10,0,140,54,14,0,141,54,14,0,233,3,10,0,142,54,14,0,63,0,6,0,245,1,9,0,251,0,8,0,143,54,14,0,0,0,2,0,4,0,4,0,10,0,5,0,11,0,5,0,24,0,6,0,50,0,7,0,51,0,7,0,52,0,7,0,106,0,8,0,214,0,9,0,215,0,9,0,216,0,9,0,217,0,9,0,128,54,15,0,181,1,10,0,105,3,11,0,4,0,3,0,14,0,5,0,30,0,6,0,55,0,7,0,10,0,4,0,22,0,5,0,12,0,4,0,31,0,6,0,92,0,7,0,93,0,7,0,188,0,8,0,189,0,8,0,95,0,7,0,208,0,8,0,219,0,9,0,209,0,8,0,164,1,9,0,165,1,9,0,166,1,9,0,167,1,9,0,80,3,10,0,162,6,11,0,163,6,11,0,169,1,9,0,170,1,9,0,172,6,11,0,129,54,15,0,87,3,10,0,130,54,15,0,131,54,15,0,132,54,15,0,133,54,15,0,54,0,6,0,214,0,8,0,134,54,15,0,135,54,15,0,14,0,4,0,110,0,7,0,215,0,8,0,173,6,11,0,136,54,15,0,30,0,5,0,222,0,8,0,248,6,11,0,125,3,10,0,137,54,15,0,138,54,15,0,139,54,15,0,140,54,15,0,191,1,9,0,141,54,15,0,71,27,14,0,200,55,14,0,201,55,14,0,202,55,14,0,203,55,14,0,204,55,14,0,31,0,5,0,205,55,14,0,206,55,14,0,207,55,14,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,18,0,6,0,38,0,7,0,20,0,6,0,39,0,7,0,168,0,9,0,169,0,9,0,85,0,8,0,0,43,15,0,173,0,9,0,1,43,15,0,2,43,15,0,3,43,15,0,3,0,3,0,11,0,5,0,64,0,7,0,65,0,7,0,9,0,4,0,33,0,6,0,17,0,5,0,10,0,4,0,11,0,4,0,24,0,5,0,50,0,6,0,51,0,6,0,52,0,6,0,53,0,6,0,108,0,7,0,87,0,8,0,109,0,7,0,220,0,8,0,89,1,10,0,221,0,8,0,188,1,9,0,122,3,10,0,123,3,10,0,56,0,6,0,114,0,7,0,190,1,9,0,191,1,9,0,230,0,8,0,156,3,10,0,207,1,9,0,4,43,15,0,5,43,15,0,116,0,7,0,212,1,9,0,6,43,15,0,7,43,15,0,30,0,5,0,235,0,8,0,132,21,14,0,133,21,14,0,134,21,14,0,59,0,6,0,213,1,9,0,240,1,9,0,157,3,10,0,226,3,10,0,135,21,14,0,136,21,14,0,137,21,14,0,249,0,8,0,138,21,14,0,139,21,14,0,227,3,10,0,140,21,14,0,141,21,14,0,244,1,9,0,142,21,14,0,63,0,6,0,251,0,8,0,245,1,9,0,143,21,14,0,0,0,3,0,2,0,4,0,6,0,5,0,7,0,5,0,16,0,6,0,17,0,6,0,36,0,7,0,37,0,7,0,19,0,6,0,20,0,6,0,42,0,7,0,43,0,7,0,176,0,9,0,177,0,9,0,45,0,7,0,89,0,8,0,12,0,5,0,23,0,6,0,208,0,9,0,53,0,7,0,27,0,6,0,56,0,7,0,57,0,7,0,4,0,3,0,5,0,3,0,15,0,5,0,24,0,5,0,29,0,6,0,50,0,6,0,51,0,6,0,104,0,7,0,105,0,7,0,105,0,8,0,212,0,8,0,213,0,8,0,214,0,8,0,108,0,7,0,55,0,6,0,109,0,7,0,112,0,7,0,57,0,6,0,215,0,8,0,209,0,9,0,128,56,14,0,129,56,14,0,130,56,14,0,116,0,7,0,197,1,9,0,117,0,7,0,227,0,8,0,131,56,14,0,132,56,14,0,236,0,8,0,133,56,14,0,67,28,13,0,68,28,13,0,69,28,13,0,237,0,8,0,70,28,13,0,60,0,6,0,119,0,7,0,232,1,9,0,62,0,6,0,123,0,7,0,71,28,13,0,126,0,7,0,127,0,7,0,72,28,13,0,73,28,13,0,74,28,13,0,75,28,13,0,76,28,13,0,77,28,13,0,245,0,8,0,78,28,13,0,233,1,9,0,79,28,13,0,0,0,2,0,4,0,4,0,10,0,5,0,11,0,5,0,24,0,6,0,25,0,6,0,52,0,7,0,53,0,7,0,54,0,7,0,110,0,8,0,222,0,9,0,223,0,9,0,192,1,10,0,193,1,10,0,194,1,10,0,96,56,15,0,4,0,3,0,15,0,5,0,29,0,6,0,57,0,7,0,10,0,4,0,44,0,6,0,45,0,6,0,12,0,4,0,23,0,5,0,52,0,6,0,53,0,6,0,54,0,6,0,110,0,7,0,111,0,7,0,112,0,7,0,113,0,7,0,113,0,8,0,228,0,8,0,229,0,8,0,230,0,8,0,231,0,8,0,232,0,8,0,164,3,10,0,117,0,7,0,236,0,8,0,211,1,9,0,218,1,9,0,165,3,10,0,182,3,10,0,13,7,12,0,183,3,10,0,14,7,12,0,60,0,6,0,238,0,8,0,97,56,15,0,98,56,15,0,61,0,6,0,222,1,9,0,99,56,15,0,100,56,15,0,101,56,15,0,124,0,7,0,15,7,12,0,190,3,10,0,191,3,10,0,102,56,15,0,160,15,12,0,209,7,11,0,103,56,15,0,251,0,8,0,245,1,9,0,8,125,15,0,164,15,12,0,9,125,15,0,10,125,15,0,11,125,15,0,134,62,14,0,63,0,6,0,165,15,12,0,211,7,11,0,135,62,14,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,9,0,5,0,20,0,6,0,42,0,7,0,86,0,8,0,184,2,11,0,175,0,9,0,185,2,11,0,93,1,10,0,192,2,11,0,16,44,15,0,17,44,15,0,18,44,15,0,6,0,4,0,14,0,5,0,23,0,6,0,45,0,7,0,15,0,5,0,64,0,7,0,33,0,6,0,5,0,3,0,9,0,4,0,17,0,5,0,24,0,5,0,25,0,5,0,26,0,5,0,54,0,6,0,55,0,6,0,65,0,7,0,89,0,8,0,224,0,8,0,225,0,8,0,113,0,7,0,228,0,8,0,177,0,9,0,194,2,11,0,29,0,5,0,115,0,7,0,229,0,8,0,240,0,8,0,121,0,7,0,196,3,10,0,227,1,9,0,232,1,9,0,19,44,15,0,123,0,7,0,20,44,15,0,21,44,15,0,22,44,15,0,124,0,7,0,195,2,11,0,23,44,15,0,12,22,14,0,13,22,14,0,125,0,7,0,14,22,14,0,233,1,9,0,197,3,10,0,212,3,10,0,235,1,9,0,15,22,14,0,80,61,14,0,252,0,8,0,171,7,11,0,81,61,14,0,82,61,14,0,83,61,14,0,84,61,14,0,250,1,9,0,85,61,14,0,127,0,7,0,251,1,9,0,86,61,14,0,87,61,14,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
/* memory initializer */ allocate([9,0,5,0,10,0,5,0,11,0,5,0,24,0,6,0,50,0,7,0,13,0,5,0,51,0,7,0,0,14,13,0,57,0,7,0,1,14,13,0,58,0,7,0,2,14,13,0,8,0,4,0,30,0,6,0,59,0,7,0,62,0,7,0,18,0,5,0,63,0,7,0,19,0,5,0,40,0,6,0,41,0,6,0,84,0,7,0,43,0,6,0,85,0,7,0,88,0,7,0,3,14,13,0,89,0,7,0,90,0,7,0,4,14,13,0,5,14,13,0,3,7,12,0,91,0,7,0,92,0,7,0,4,7,12,0,5,7,12,0,93,0,7,0,6,7,12,0,7,7,12,0,8,7,12,0,9,7,12,0,10,7,12,0,11,7,12,0,24,0,5,0,47,0,6,0,13,0,4,0,25,0,5,0,12,7,12,0,112,0,7,0,29,0,5,0,13,7,12,0,14,7,12,0,15,7,12,0,16,7,12,0,57,0,6,0,17,7,12,0,60,0,6,0,18,7,12,0,19,7,12,0,20,7,12,0,21,7,12,0,22,7,12,0,61,0,6,0,23,7,12,0,24,7,12,0,25,7,12,0,26,7,12,0,27,7,12,0,28,7,12,0,29,7,12,0,31,0,5,0,30,7,12,0,113,0,7,0,31,7,12,0,0,0,3,0,2,0,4,0,6,0,5,0,14,0,6,0,15,0,6,0,64,0,8,0,65,0,8,0,66,0,8,0,24,2,11,0,144,33,15,0,145,33,15,0,146,33,15,0,147,33,15,0,148,33,15,0,149,33,15,0,150,33,15,0,5,0,4,0,17,0,6,0,36,0,7,0,135,0,9,0,12,0,5,0,74,0,8,0,75,0,8,0,2,0,2,0,6,0,3,0,13,0,5,0,14,0,5,0,15,0,5,0,19,0,6,0,56,0,6,0,228,0,8,0,229,0,8,0,204,1,9,0,231,0,8,0,116,0,7,0,234,0,8,0,205,1,9,0,26,2,11,0,151,33,15,0,30,0,5,0,118,0,7,0,235,0,8,0,220,1,9,0,239,0,8,0,221,1,9,0,240,1,9,0,152,33,15,0,153,33,15,0,249,0,8,0,226,3,10,0,154,33,15,0,155,33,15,0,250,0,8,0,156,33,15,0,157,33,15,0,158,33,15,0,159,33,15,0,246,1,9,0,176,33,15,0,252,0,8,0,247,1,9,0,177,33,15,0,178,33,15,0,179,33,15,0,180,33,15,0,250,1,9,0,181,33,15,0,182,33,15,0,183,33,15,0,184,33,15,0,185,33,15,0,227,3,10,0,221,16,14,0,127,0,7,0,251,1,9,0,222,16,14,0,223,16,14,0,0,0,2,0,2,0,3,0,6,0,4,0,14,0,5,0,30,0,6,0,62,0,7,0,63,0,7,0,64,0,7,0,4,1,9,0,131,0,8,0,132,0,8,0,133,0,8,0,10,2,10,0,11,2,10,0,24,2,10,0,25,2,10,0,9,0,4,0,68,0,7,0,13,1,9,0,28,2,10,0,35,0,6,0,69,0,7,0,80,0,7,0,11,0,4,0,12,0,4,0,21,0,5,0,26,0,5,0,27,0,5,0,41,0,6,0,56,0,6,0,57,0,6,0,58,0,6,0,81,0,7,0,118,0,7,0,119,0,7,0,120,0,7,0,121,0,7,0,122,0,7,0,123,0,7,0,248,0,8,0,15,1,9,0,29,2,10,0,64,62,14,0,65,62,14,0,66,62,14,0,67,62,14,0,229,3,10,0,68,62,14,0,243,1,9,0,69,62,14,0,70,62,14,0,71,62,14,0,250,0,8,0,72,62,14,0,73,62,14,0,74,62,14,0,75,62,14,0,236,3,10,0,76,62,14,0,126,0,7,0,254,0,8,0,255,0,8,0,247,1,9,0,77,62,14,0,78,62,14,0,79,62,14,0,208,62,14,0,209,62,14,0,210,62,14,0,211,62,14,0,212,62,14,0,213,62,14,0,107,31,13,0,108,31,13,0,109,31,13,0,110,31,13,0,111,31,13,0,0,0,3,0,4,0,5,0,20,0,7,0,11,0,6,0,12,0,6,0,42,0,8,0,43,0,8,0,52,0,8,0,64,13,14,0,65,13,14,0,27,0,7,0,66,13,14,0,67,13,14,0,68,13,14,0,69,13,14,0,70,13,14,0,14,0,6,0,60,0,8,0,71,13,14,0,61,0,8,0,72,13,14,0,73,13,14,0,74,13,14,0,1,0,2,0,4,0,3,0,20,0,5,0,11,0,4,0,12,0,4,0,13,0,4,0,42,0,6,0,31,0,7,0,86,0,7,0,87,0,7,0,112,0,7,0,226,0,8,0,114,0,7,0,58,0,6,0,59,0,6,0,60,0,6,0,61,0,6,0,227,0,8,0,75,13,14,0,230,0,8,0,231,0,8,0,248,0,8,0,76,13,14,0,77,13,14,0,78,13,14,0,249,0,8,0,79,13,14,0,80,13,14,0,81,13,14,0,169,6,13,0,170,6,13,0,171,6,13,0,172,6,13,0,173,6,13,0,174,6,13,0,175,6,13,0,63,0,6,0,176,6,13,0,177,6,13,0,178,6,13,0,179,6,13,0,180,6,13,0,125,0,7,0,181,6,13,0,182,6,13,0,183,6,13,0,184,6,13,0,185,6,13,0,186,6,13,0,187,6,13,0,188,6,13,0,189,6,13,0,190,6,13,0,191,6,13,0,0,0,2,0,2,0,3,0,3,0,3,0,8,0,4,0,18,0,5,0,19,0,5,0,40,0,6,0,41,0,6,0,84,0,7,0,85,0,7,0,86,0,7,0,174,0,8,0,175,0,8,0,176,0,8,0,98,1,9,0,198,2,10,0,12,0,4,0,45,0,6,0,178,0,8,0,102,1,9,0,46,0,6,0,103,1,9,0,188,0,8,0,26,0,5,0,54,0,6,0,55,0,6,0,56,0,6,0,95,0,7,0,114,0,7,0,115,0,7,0,116,0,7,0,117,0,7,0,118,0,7,0,119,0,7,0,120,0,7,0,121,0,7,0,122,0,7,0,123,0,7,0,189,0,8,0,192,177,16,0,193,177,16,0,225,88,15,0,29,11,12,0,226,88,15,0,227,88,15,0,228,88,15,0,248,0,8,0,228,3,10,0,243,1,9,0,30,11,12,0,229,88,15,0,230,88,15,0,250,0,8,0,231,88,15,0,248,88,15,0,249,88,15,0,250,88,15,0,246,1,9,0,251,88,15,0,126,0,7,0,254,0,8,0,255,0,8,0,202,7,11,0,150,15,12,0,252,88,15,0,253,88,15,0,254,88,15,0,255,88,15,0,184,124,15,0,185,124,15,0,186,124,15,0,187,124,15,0,188,124,15,0,247,1,9,0,189,124,15,0,190,124,15,0,191,124,15,0,0,0,2,0,2,0,3,0,6,0,4,0,14,0,5,0,15,0,5,0,32,0,6,0,33,0,6,0,68,0,7,0,69,0,7,0,140,0,8,0,141,0,8,0,28,1,9,0,29,1,9,0,30,1,9,0,62,2,10,0,63,2,10,0,5,0,3,0,18,0,5,0,76,0,7,0,77,0,7,0,12,0,4,0,78,0,7,0,26,0,5,0,54,0,6,0,79,0,7,0,110,0,7,0,111,0,7,0,224,0,8,0,225,0,8,0,226,0,8,0,227,0,8,0,228,0,8,0,229,0,8,0,204,1,9,0,231,0,8,0,232,0,8,0,233,0,8,0,205,1,9,0,80,7,11,0,169,3,10,0,81,7,11,0,64,117,15,0,171,3,10,0,65,117,15,0,66,117,15,0,67,117,15,0,214,1,9,0,85,7,11,0,118,0,7,0,169,14,12,0,68,117,15,0,69,117,15,0,30,0,5,0,119,0,7,0,248,0,8,0,174,3,10,0,94,7,11,0,125,0,7,0,228,3,10,0,252,0,8,0,253,0,8,0,229,3,10,0,230,3,10,0,190,14,12,0,70,117,15,0,206,7,11,0,71,117,15,0,248,117,15,0,249,117,15,0,250,117,15,0,251,117,15,0,252,117,15,0,253,117,15,0,127,0,7,0,255,58,14,0,158,15,12,0,159,15,12,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,18,0,6,0,19,0,6,0,20,0,6,0,42,0,7,0,22,0,6,0,43,0,7,0,92,0,8,0,93,0,8,0,94,0,8,0,190,0,9,0,191,0,9,0,96,0,8,0,7,0,4,0,13,0,5,0,25,0,6,0,32,0,6,0,9,0,4,0,33,0,6,0,17,0,5,0,20,0,5,0,42,0,6,0,43,0,6,0,44,0,6,0,45,0,6,0,46,0,6,0,47,0,6,0,48,0,6,0,49,0,7,0,98,0,7,0,99,0,7,0,100,0,7,0,101,0,7,0,102,0,7,0,97,0,8,0,112,6,11,0,104,0,7,0,105,0,7,0,207,0,8,0,157,1,9,0,168,1,9,0,169,1,9,0,57,3,10,0,170,1,9,0,86,3,10,0,54,0,6,0,214,0,8,0,16,103,15,0,17,103,15,0,14,0,4,0,110,0,7,0,174,1,9,0,18,103,15,0,19,103,15,0,60,0,6,0,87,3,10,0,111,0,7,0,244,0,8,0,245,0,8,0,94,3,10,0,236,1,9,0,20,103,15,0,237,1,9,0,95,3,10,0,220,3,10,0,221,3,10,0,21,103,15,0,139,51,14,0,140,51,14,0,141,51,14,0,31,0,5,0,239,1,9,0,142,51,14,0,143,51,14,0,0,0,2,0,4,0,4,0,10,0,5,0,11,0,5,0,24,0,6,0,25,0,6,0,52,0,7,0,106,0,8,0,107,0,8,0,108,0,8,0,218,0,9,0,108,3,11,0,110,0,8,0,183,1,10,0,109,3,11,0,128,55,15,0,4,0,3,0,14,0,5,0,30,0,6,0,62,0,7,0,10,0,4,0,44,0,6,0,23,0,5,0,45,0,6,0,63,0,7,0,192,0,8,0,97,0,7,0,193,0,8,0,98,0,7,0,198,0,8,0,100,0,7,0,199,0,8,0,202,0,8,0,223,0,9,0,150,1,9,0,151,1,9,0,152,1,9,0,153,1,9,0,121,3,11,0,154,1,9,0,189,1,10,0,108,6,11,0,129,55,15,0,55,3,10,0,109,6,11,0,112,6,11,0,57,3,10,0,113,6,11,0,52,0,6,0,207,0,8,0,130,55,15,0,131,55,15,0,14,0,4,0,27,0,5,0,106,0,7,0,107,0,7,0,157,1,9,0,60,0,6,0,244,0,8,0,245,0,8,0,216,3,10,0,178,7,11,0,132,55,15,0,218,3,10,0,133,55,15,0,219,3,10,0,220,3,10,0,134,55,15,0,135,55,15,0,196,27,14,0,197,27,14,0,198,27,14,0,199,27,14,0,31,0,5,0,221,3,10,0,179,7,11,0,239,1,9,0,0,0,2,0,4,0,4,0,10,0,5,0,22,0,6,0,23,0,6,0,96,0,8,0,194,0,9,0,134,1,10,0,135,1,10,0,196,0,9,0,64,49,15,0,65,49,15,0,139,1,10,0,66,49,15,0,140,1,10,0,67,49,15,0,7,0,4,0,13,0,5,0,100,0,8,0,101,0,8,0,16,0,5,0,199,0,9,0,102,0,8,0,5,0,3,0,6,0,3,0,9,0,4,0,17,0,5,0,56,0,6,0,57,0,6,0,116,0,7,0,117,0,7,0,118,0,7,0,103,0,8,0,238,0,8,0,222,1,9,0,240,0,8,0,141,1,10,0,68,49,15,0,223,1,9,0,61,0,6,0,62,0,6,0,226,1,9,0,198,3,10,0,242,0,8,0,243,0,8,0,199,3,10,0,69,49,15,0,70,49,15,0,248,1,9,0,71,49,15,0,72,49,15,0,73,49,15,0,253,0,8,0,74,49,15,0,75,49,15,0,76,49,15,0,77,49,15,0,249,1,9,0,78,49,15,0,252,1,9,0,79,49,15,0,80,49,15,0,81,49,15,0,82,49,15,0,83,49,15,0,250,3,10,0,251,3,10,0,84,49,15,0,85,49,15,0,86,49,15,0,87,49,15,0,88,49,15,0,89,49,15,0,255,0,8,0,173,24,14,0,174,24,14,0,175,24,14,0,0,0,4,0,128,0,11,0,129,0,11,0,130,0,11,0,131,0,11,0,132,0,11,0,133,0,11,0,134,0,11,0,135,0,11,0,136,0,11,0,137,0,11,0,138,0,11,0,139,0,11,0,140,0,11,0,141,0,11,0,142,0,11,0,143,0,11,0,72,0,10,0,73,0,10,0,74,0,10,0,75,0,10,0,76,0,10,0,77,0,10,0,1,0,1,0,1,0,2,0,78,0,10,0,2,0,4,0,3,0,4,0,79,0,10,0,80,0,10,0,81,0,10,0,82,0,10,0,83,0,10,0,84,0,10,0,85,0,10,0,86,0,10,0,87,0,10,0,88,0,10,0,89,0,10,0,90,0,10,0,91,0,10,0,92,0,10,0,93,0,10,0,94,0,10,0,95,0,10,0,96,0,10,0,97,0,10,0,98,0,10,0,99,0,10,0,100,0,10,0,101,0,10,0,102,0,10,0,103,0,10,0,104,0,10,0,105,0,10,0,106,0,10,0,107,0,10,0,108,0,10,0,109,0,10,0,110,0,10,0,111,0,10,0,112,0,10,0,113,0,10,0,114,0,10,0,115,0,10,0,116,0,10,0,117,0,10,0,118,0,10,0,119,0,10,0,120,0,10,0,121,0,10,0,122,0,10,0,123,0,10,0,124,0,10,0,125,0,10,0,126,0,10,0,127,0,10,0,0,0,3,0,2,0,4,0,12,0,6,0,13,0,6,0,28,0,7,0,15,0,6,0,0,29,15,0,59,0,8,0,1,29,15,0,117,0,9,0,2,29,15,0,128,0,9,0,3,29,15,0,4,29,15,0,5,29,15,0,131,14,14,0,9,0,5,0,17,0,6,0,129,0,9,0,130,0,9,0,33,0,7,0,40,0,7,0,131,0,9,0,2,0,2,0,3,0,3,0,12,0,4,0,13,0,4,0,11,0,5,0,21,0,6,0,82,0,8,0,112,0,7,0,57,0,6,0,113,0,7,0,83,0,8,0,132,14,14,0,116,0,7,0,117,0,7,0,118,0,7,0,220,1,9,0,30,0,5,0,62,0,6,0,221,1,9,0,239,0,8,0,248,1,9,0,249,1,9,0,133,14,14,0,134,14,14,0,135,14,14,0,253,0,8,0,136,14,14,0,137,14,14,0,138,14,14,0,139,14,14,0,140,14,14,0,141,14,14,0,142,14,14,0,143,14,14,0,144,14,14,0,145,14,14,0,252,1,9,0,146,14,14,0,147,14,14,0,148,14,14,0,149,14,14,0,150,14,14,0,151,14,14,0,253,1,9,0,152,14,14,0,254,1,9,0,153,14,14,0,154,14,14,0,155,14,14,0,156,14,14,0,255,1,9,0,157,14,14,0,158,14,14,0,159,14,14,0,0,0,3,0,2,0,4,0,3,0,4,0,8,0,5,0,18,0,6,0,19,0,6,0,20,0,6,0,21,0,6,0,44,0,7,0,90,0,8,0,91,0,8,0,92,0,8,0,93,0,8,0,128,23,14,0,121,1,10,0,122,1,10,0,6,0,4,0,14,0,5,0,30,0,6,0,62,0,7,0,16,0,5,0,34,0,6,0,18,0,5,0,10,0,4,0,19,0,5,0,22,0,5,0,35,0,6,0,46,0,6,0,47,0,6,0,48,0,6,0,49,0,6,0,63,0,7,0,95,0,8,0,200,0,8,0,101,0,7,0,102,0,7,0,103,0,7,0,104,0,7,0,201,0,8,0,105,0,7,0,106,0,7,0,214,0,8,0,215,0,8,0,216,0,8,0,129,23,14,0,123,1,10,0,178,1,9,0,130,23,14,0,28,0,5,0,179,1,9,0,131,23,14,0,132,23,14,0,29,0,5,0,218,0,8,0,133,23,14,0,134,23,14,0,135,23,14,0,55,0,6,0,219,0,8,0,120,0,7,0,242,0,8,0,230,1,9,0,244,0,8,0,136,23,14,0,137,23,14,0,245,0,8,0,231,1,9,0,138,23,14,0,139,23,14,0,140,23,14,0,141,23,14,0,236,1,9,0,142,23,14,0,31,0,5,0,247,0,8,0,237,1,9,0,143,23,14,0,0,0,4,0,2,0,5,0,128,1,12,0,129,1,12,0,130,1,12,0,131,1,12,0,132,1,12,0,133,1,12,0,134,1,12,0,135,1,12,0,136,1,12,0,137,1,12,0,197,0,11,0,198,0,11,0,199,0,11,0,200,0,11,0,201,0,11,0,202,0,11,0,203,0,11,0,204,0,11,0,205,0,11,0,206,0,11,0,207,0,11,0,1,0,1,0,1,0,2,0,4,0,5,0,5,0,5,0,6,0,5,0,208,0,11,0,209,0,11,0,210,0,11,0,211,0,11,0,212,0,11,0,213,0,11,0,214,0,11,0,215,0,11,0,216,0,11,0,217,0,11,0,218,0,11,0,7,0,5,0,219,0,11,0,220,0,11,0,221,0,11,0,222,0,11,0,223,0,11,0,224,0,11,0,225,0,11,0,226,0,11,0,227,0,11,0,228,0,11,0,229,0,11,0,230,0,11,0,231,0,11,0,232,0,11,0,233,0,11,0,234,0,11,0,235,0,11,0,236,0,11,0,237,0,11,0,238,0,11,0,239,0,11,0,240,0,11,0,241,0,11,0,242,0,11,0,243,0,11,0,244,0,11,0,245,0,11,0,246,0,11,0,247,0,11,0,248,0,11,0,249,0,11,0,250,0,11,0,251,0,11,0,252,0,11,0,253,0,11,0,254,0,11,0,255,0,11,0,0,0,8,0,1,0,8,0,2,0,8,0,3,0,8,0,4,0,8,0,5,0,8,0,6,0,8,0,7,0,8,0,8,0,8,0,9,0,8,0,10,0,8,0,11,0,8,0,12,0,8,0,13,0,8,0,14,0,8,0,15,0,8,0,16,0,8,0,17,0,8,0,18,0,8,0,19,0,8,0,20,0,8,0,21,0,8,0,22,0,8,0,1,0,1,0,23,0,8,0,12,0,7,0,13,0,7,0,14,0,7,0,15,0,7,0,16,0,7,0,17,0,7,0,18,0,7,0,19,0,7,0,20,0,7,0,21,0,7,0,22,0,7,0,23,0,7,0,24,0,7,0,25,0,7,0,26,0,7,0,27,0,7,0,28,0,7,0,29,0,7,0,30,0,7,0,31,0,7,0,32,0,7,0,33,0,7,0,34,0,7,0,35,0,7,0,36,0,7,0,37,0,7,0,38,0,7,0,39,0,7,0,40,0,7,0,41,0,7,0,42,0,7,0,43,0,7,0,44,0,7,0,45,0,7,0,46,0,7,0,47,0,7,0,48,0,7,0,49,0,7,0,50,0,7,0,51,0,7,0,52,0,7,0,53,0,7,0,54,0,7,0,55,0,7,0,56,0,7,0,57,0,7,0,58,0,7,0,59,0,7,0,60,0,7,0,61,0,7,0,62,0,7,0,63,0,7,0,0,0,9,0,1,0,9,0,2,0,9,0,3,0,9,0,4,0,9,0,5,0,9,0,6,0,9,0,7,0,9,0,8,0,9,0,9,0,9,0,10,0,9,0,11,0,9,0,12,0,9,0,13,0,9,0,14,0,9,0,15,0,9,0,16,0,9,0,17,0,9,0,18,0,9,0,19,0,9,0,20,0,9,0,21,0,9,0,11,0,8,0,1,0,2,0,1,0,1,0,12,0,8,0,13,0,8,0,14,0,8,0,15,0,8,0,16,0,8,0,17,0,8,0,18,0,8,0,19,0,8,0,20,0,8,0,21,0,8,0,22,0,8,0,23,0,8,0,24,0,8,0,25,0,8,0,26,0,8,0,27,0,8,0,28,0,8,0,29,0,8,0,30,0,8,0,31,0,8,0,32,0,8,0,33,0,8,0,34,0,8,0,35,0,8,0,36,0,8,0,37,0,8,0,38,0,8,0,39,0,8,0,40,0,8,0,41,0,8,0,42,0,8,0,43,0,8,0,44,0,8,0,45,0,8,0,46,0,8,0,47,0,8,0,48,0,8,0,49,0,8,0,50,0,8,0,51,0,8,0,52,0,8,0,53,0,8,0,54,0,8,0,55,0,8,0,56,0,8,0,57,0,8,0,58,0,8,0,59,0,8,0,60,0,8,0,61,0,8,0,62,0,8,0,63,0,8,0,0,0,10,0,1,0,10,0,2,0,10,0,3,0,10,0,4,0,10,0,5,0,10,0,6,0,10,0,7,0,10,0,8,0,10,0,9,0,10,0,10,0,10,0,11,0,10,0,12,0,10,0,13,0,10,0,14,0,10,0,15,0,10,0,16,0,10,0,17,0,10,0,18,0,10,0,19,0,10,0,10,0,9,0,11,0,9,0,12,0,9,0,1,0,1,0,1,0,3,0,13,0,9,0,14,0,9,0,1,0,2,0,15,0,9,0,16,0,9,0,17,0,9,0,18,0,9,0,19,0,9,0,20,0,9,0,21,0,9,0,22,0,9,0,23,0,9,0,24,0,9,0,25,0,9,0,26,0,9,0,27,0,9,0,28,0,9,0,29,0,9,0,30,0,9,0,31,0,9,0,32,0,9,0,33,0,9,0,34,0,9,0,35,0,9,0,36,0,9,0,37,0,9,0,38,0,9,0,39,0,9,0,40,0,9,0,41,0,9,0,42,0,9,0,43,0,9,0,44,0,9,0,45,0,9,0,46,0,9,0,47,0,9,0,48,0,9,0,49,0,9,0,50,0,9,0,51,0,9,0,52,0,9,0,53,0,9,0,54,0,9,0,55,0,9,0,56,0,9,0,57,0,9,0,58,0,9,0,59,0,9,0,60,0,9,0,61,0,9,0,62,0,9,0,63,0,9,0,0,0,2,0,4,0,4,0,10,0,5,0,11,0,5,0,24,0,6,0,25,0,6,0,52,0,7,0,106,0,8,0,107,0,8,0,108,0,8,0,218,0,9,0,219,0,9,0,184,1,10,0,221,0,9,0,185,1,10,0,128,55,15,0,4,0,3,0,14,0,5,0,30,0,6,0,31,0,6,0,10,0,4,0,88,0,7,0,23,0,5,0,24,0,5,0,89,0,7,0,90,0,7,0,91,0,7,0,200,0,8,0,101,0,7,0,102,0,7,0,201,0,8,0,206,0,8,0,207,0,8,0,208,0,8,0,209,0,8,0,210,0,8,0,211,0,8,0,223,0,9,0,212,0,8,0,213,0,8,0,214,0,8,0,174,1,9,0,129,55,15,0,189,1,10,0,94,3,10,0,95,3,10,0,130,55,15,0,96,3,10,0,55,0,6,0,177,1,9,0,131,55,15,0,132,55,15,0,14,0,4,0,60,0,6,0,97,3,10,0,133,55,15,0,195,27,14,0,61,0,6,0,217,0,8,0,196,27,14,0,104,3,10,0,197,27,14,0,198,27,14,0,199,27,14,0,200,27,14,0,219,0,8,0,105,3,10,0,106,3,10,0,201,27,14,0,202,27,14,0,203,27,14,0,204,27,14,0,205,27,14,0,31,0,5,0,107,3,10,0,206,27,14,0,207,27,14,0,0,0,3,0,2,0,4,0,6,0,5,0,7,0,5,0,16,0,6,0,68,0,8,0,35,0,7,0,18,0,6,0,38,0,7,0,160,8,13,0,78,0,8,0,79,0,8,0,161,8,13,0,162,8,13,0,163,8,13,0,80,0,8,0,6,0,4,0,11,0,5,0,41,0,7,0,21,0,6,0,28,0,6,0,58,0,7,0,30,0,6,0,4,0,3,0,20,0,5,0,21,0,5,0,11,0,4,0,31,0,6,0,48,0,6,0,49,0,6,0,25,0,5,0,81,0,8,0,52,0,6,0,53,0,6,0,54,0,6,0,55,0,6,0,118,0,8,0,119,0,8,0,112,0,7,0,29,0,5,0,113,0,7,0,114,0,7,0,164,8,13,0,115,0,7,0,240,0,8,0,165,8,13,0,166,8,13,0,167,8,13,0,121,0,7,0,122,0,7,0,168,8,13,0,169,8,13,0,241,0,8,0,170,8,13,0,171,8,13,0,172,8,13,0,173,8,13,0,246,0,8,0,174,8,13,0,124,0,7,0,247,0,8,0,175,8,13,0,176,8,13,0,177,8,13,0,178,8,13,0,250,0,8,0,179,8,13,0,180,8,13,0,181,8,13,0,182,8,13,0,183,8,13,0,251,0,8,0,92,4,12,0,63,0,6,0,93,4,12,0,94,4,12,0,95,4,12,0,0,8,1,2,9,16,24,17,10,3,4,11,18,25,32,40,33,26,19,12,5,6,13,20,27,34,41,48,56,49,42,35,28,21,14,7,15,22,29,36,43,50,57,58,51,44,37,30,23,31,38,45,52,59,60,53,46,39,47,54,61,62,55,63,0,1,2,8,9,3,4,10,16,11,5,6,7,12,17,24,18,13,14,15,19,25,32,26,20,21,22,23,27,33,40,34,28,29,30,31,35,41,48,42,36,37,38,39,43,49,50,44,45,46,47,51,56,57,52,53,54,55,58,59,60,61,62,63,0,8,1,2,9,16,24,17,10,3,4,11,18,25,32,40,33,26,19,12,5,6,13,20,27,34,41,48,56,49,42,35,28,21,14,7,15,22,29,36,43,50,57,58,51,44,37,30,23,31,38,45,52,59,60,53,46,39,47,54,61,62,55,63,0,1,2,8,9,3,4,10,16,11,5,6,7,12,17,24,18,13,14,15,19,25,32,26,20,21,22,23,27,33,40,34,28,29,30,31,35,41,48,42,36,37,38,39,43,49,50,44,45,46,47,51,56,57,52,53,54,55,58,59,60,61,62,63,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,0,1,4,2,3,5,6,7,8,9,10,11,12,13,14,15,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,0,1,4,2,3,5,6,7,8,9,10,11,12,13,14,15,0,2,1,4,6,3,5,7,0,1,2,3,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,1,1,1,2,1,2,1,4,2,216,111,36,0,32,108,36,0,112,106,36,0,120,104,36,0,160,102,36,0,176,177,36,0,0,0,0,0,0,0,0,0,6,6,6,6,3,3,3,3,4,4,4,4,6,6,6,6,12,12,12,12,3,2,1,1,2,1,1,1,4,3,2,1,6,4,3,2,12,9,6,4,1,1,3,3,5,5,5,5,7,7,7,7,7,7,7,7,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,1,1,3,3,5,5,5,5,7,7,7,7,7,7,7,7,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,1,1,3,3,5,5,5,5,7,7,7,7,7,7,7,7,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,1,1,3,3,5,5,5,5,7,7,7,7,7,7,7,7,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,46,0,0,0,58,0,0,0,73,0,0,0,92,0,0,0,117,0,0,0,147,0,0,0,185,0,0,0,233,0,0,0,38,1,0,0,114,1,0,0,210,1,0,0,75,2,0,0,228,2,0,0,164,3,0,0,150,4,0,0,200,5,0,0,72,7,0,0,45,9,0,0,143,11,0,0,144,14,0,0,89,18,0,0,30,23,0,0,33,29,0,0,179,36,0,0,61,46,0,0,66,58,0,0,102,73,0,0,122,92,0,0,132,116,0,0,205,146,0,0,245,184,0,0,8,233,0,0,155,37,1,0,235,113,1,0,17,210,1,0,54,75,2,0,215,227,2,0,35,164,3,0,108,150,4,0,174,199,5,0,71,72,7,0,216,44,9,0,92,143,11,0,143,144,14,0,176,89,18,0,184,30,23,0,30,33,29,0,97,179,36,0,112,61,46,0,61,66,58,0,195,102,73,0,225,122,92,0,123,132,116,0,136,205,146,0,195,245,184,0,246,8,233,0,15,155,37,1,133,235,113,1,235,17,210,1,30,54,75,2,10,215,227,2,214,35,164,3,60,108,150,4,20,174,199,5,173,71,72,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,0,0,34,0,0,0,43,0,0,0,54,0,0,0,68,0,0,0,86,0,0,0,108,0,0,0,136,0,0,0,172,0,0,0,216,0,0,0,17,1,0,0,87,1,0,0,177,1,0,0,33,2,0,0,175,2,0,0,97,3,0,0,66,4,0,0,94,5,0,0,195,6,0,0,132,8,0,0,187,10,0,0,133,13,0,0,9,17,0,0,118,21,0,0,10,27,0,0,17,34,0,0,236,42,0,0,20,54,0,0,34,68,0,0,216,85,0,0,40,108,0,0,69,136,0,0,177,171,0,0,81,216,0,0,139,16,1,0,98,87,1,0,163,176,1,0,23,33,2,0,197,174,2,0,71,97,3,0,47,66,4,0,139,93,5,0,143,194,6,0,94,132,8,0,23,187,10,0,30,133,13,0,188,8,17,0,47,118,21,0,61,10,27,0,121,17,34,0,94,236,42,0,122,20,54,0,244,34,68,0,190,216,85,0,246,40,108,0,231,69,136,0,124,177,171,0,236,81,216,0,207,139,16,1,248,98,87,1,215,163,176,1,157,23,33,2,240,197,174,2,174,71,97,3,58,47,66,4,224,139,93,5,92,143,194,6,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,0,0,0,0,1,2,0,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,1,2,0,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,1,2,0,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,128,26,156,0,80,179,36,0,176,177,36,0,128,26,156,0,168,150,36,0,32,162,36,0,248,159,36,0,240,157,36,0,176,149,36,0,24,147,36,0,232,139,36,0,248,134,36,0,192,132,36,0,88,130,36,0,88,128,36,0,200,126,36,0,0,0,0,0,0,0,0,0,1,1,2,3,3,3,2,4,3,4,1,4,1,5,0,5,0,3,1,2,1,3,4,3,5,3,6,3,7,3,0,0,0,3,1,3,1,2,2,2,6,3,7,3,0,0,0,0,6,3,0,2,1,2,2,2,7,3,0,0,0,0,0,0,0,2,1,2,2,2,3,2,0,0,0,0,0,0,0,0,0,2,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,3,0,3,1,1,1,2,0,2,0,0,1,1,0,1,0,0,0,0,1,1,3,3,2,3,3,4,2,4,3,5,2,5,3,6,2,6,3,7,2,7,3,8,2,8,3,9,2,9,1,9,7,3,6,3,5,3,4,3,3,3,5,4,4,4,3,4,2,4,3,5,2,5,3,6,2,6,1,6,0,6,0,0,5,4,7,3,6,3,5,3,4,4,3,4,4,3,3,3,2,4,3,5,2,5,1,6,1,5,0,6,0,0,0,0,3,5,7,3,5,4,4,4,6,3,5,3,4,3,3,4,3,3,2,4,2,5,1,5,0,5,0,0,0,0,0,0,5,4,4,4,3,4,7,3,6,3,5,3,4,3,3,3,2,4,1,5,1,4,0,5,0,0,0,0,0,0,0,0,1,6,1,5,7,3,6,3,5,3,4,3,3,3,2,3,1,4,1,3,0,6,0,0,0,0,0,0,0,0,0,0,1,6,1,5,5,3,4,3,3,3,3,2,2,3,1,4,1,3,0,6,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,4,1,5,3,3,3,2,2,2,2,3,1,3,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,0,6,1,4,3,2,2,2,1,3,1,2,1,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,0,5,1,3,3,2,2,2,1,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,4,1,3,2,3,1,1,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,4,1,2,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,3,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,12,11,2,10,11,3,16,11,4,40,33,5,24,11,6,20,11,7,32,11,8,80,33,9,18,11,10,15,11,11,64,33,12,160,99,13,4,3,14,3,2,15,2,1,16,0,0,255,0,0,0,0,0,0,0,0,0,0,0,6,4,0,0,0,5,3,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,5,4,4,3,3,4,4,4,5,5,4,4,4,4,3,3,6,7,7,7,8,9,10,9,8,7,7,6,11,12,13,11,6,7,8,9,14,10,9,8,6,11,12,13,11,6,9,14,10,9,11,12,13,11,14,10,12,0,0,1,1,2,2,3,3,4,5,6,7,7,7,8,4,5,6,9,10,10,8,11,12,11,9,9,10,10,8,11,12,11,9,9,10,10,8,11,12,11,9,9,10,10,8,13,13,9,9,10,10,8,13,13,9,9,10,10,14,14,14,14,14,0,105,0,120,0,134,0,149,0,152,0,146,1,228,1,243,1,1,2,148,2,16,2,31,2,45,2,206,2,0,0,0,0,21,1,36,1,50,1,65,1,68,1,180,1,8,3,23,3,37,3,163,2,52,3,67,3,81,3,221,2,0,0,0,0,220,69,233,189,230,217,72,183,150,44,216,32,217,35,238,239,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,105,110,102,105,110,105,116,101,32,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,1,0,0,0,0,24,52,36,0,8,51,36,0,232,49,36,0,56,48,36,0,240,45,36,0,16,41,36,0,168,31,36,0,232,24,36,0,216,17,36,0,40,12,36,0,0,0,0,0,0,0,0,0,2,1,3,6,11,11,11,6,1,1,2,0,0,0,0,0,2,1,3,6,11,11,11,6,1,1,2,0,0,0,0,0,16,16,16,8,8,16,8,8,8,4,4,8,4,4,4,16,4,2,2,8,2,4,2,2,16,16,16,8,8,16,8,8,8,4,4,8,4,4,4,16,4,2,2,8,2,4,2,2,176,177,36,0,24,101,36,0,32,99,36,0,0,0,0,0,99,56,101,102,51,100,49,48,100,101,100,99,100,50,53,55,57,98,55,97,101,56,99,57,102,48,100,49,56,48,50,56,0,0,0,0,0,0,0,0,35,112,114,97,103,109,97,32,79,80,69,78,67,76,32,69,88,84,69,78,83,73,79,78,32,99,108,95,107,104,114,95,108,111,99,97,108,95,105,110,116,51,50,95,101,120,116,101,110,100,101,100,95,97,116,111,109,105,99,115,32,58,32,101,110,97,98,108,101,10,99,111,110,115,116,97,110,116,32,115,97,109,112,108,101,114,95,116,32,115,97,109,112,108,101,114,32,61,32,67,76,75,95,78,79,82,77,65,76,73,90,69,68,95,67,79,79,82,68,83,95,70,65,76,83,69,32,124,32,67,76,75,95,65,68,68,82,69,83,83,95,67,76,65,77,80,95,84,79,95,69,68,71,69,32,124,32,67,76,75,95,70,73,76,84,69,82,95,78,69,65,82,69,83,84,59,10,47,42,32,55,46,49,56,46,49,46,49,32,32,69,120,97,99,116,45,119,105,100,116,104,32,105,110,116,101,103,101,114,32,116,121,112,101,115,32,42,47,10,116,121,112,101,100,101,102,32,115,105,103,110,101,100,32,99,104,97,114,32,105,110,116,56,95,116,59,10,116,121,112,101,100,101,102,32,117,110,115,105,103,110,101,100,32,99,104,97,114,32,32,32,117,105,110,116,56,95,116,59,10,116,121,112,101,100,101,102,32,115,104,111,114,116,32,32,105,110,116,49,54,95,116,59,10,116,121,112,101,100,101,102,32,117,110,115,105,103,110,101,100,32,115,104,111,114,116,32,32,117,105,110,116,49,54,95,116,59,10,116,121,112,101,100,101,102,32,105,110,116,32,32,105,110,116,51,50,95,116,59,10,116,121,112,101,100,101,102,32,117,110,115,105,103,110,101,100,32,32,32,117,105,110,116,51,50,95,116,59,10,116,121,112,101,100,101,102,32,117,105,110,116,56,95,116,32,32,112,105,120,101,108,59,10,116,121,112,101,100,101,102,32,117,105,110,116,49,54,95,116,32,115,117,109,95,116,59,10,116,121,112,101,100,101,102,32,117,105,110,116,51,50,95,116,32,115,117,109,50,95,116,59,10,35,100,101,102,105,110,101,32,76,79,87,82,69,83,95,67,79,83,84,95,77,65,83,75,32,40,40,49,60,60,49,52,41,45,49,41,10,35,100,101,102,105,110,101,32,76,79,87,82,69,83,95,67,79,83,84,95,83,72,73,70,84,32,49,52,10,35,100,101,102,105,110,101,32,67,79,83,84,95,77,65,88,32,40,49,60,60,50,56,41,10,35,100,101,102,105,110,101,32,80,73,88,69,76,95,77,65,88,32,50,53,53,10,35,100,101,102,105,110,101,32,66,73,84,83,95,80,69,82,95,83,85,77,32,40,56,32,42,32,115,105,122,101,111,102,40,115,117,109,95,116,41,41,10,47,42,32,67,111,110,115,116,97,110,116,115,32,102,111,114,32,111,102,102,115,101,116,115,32,105,110,116,111,32,102,114,97,109,101,32,115,116,97,116,105,115,116,105,99,115,32,98,117,102,102,101,114,32,42,47,10,35,100,101,102,105,110,101,32,67,79,83,84,95,69,83,84,32,32,32,32,48,10,35,100,101,102,105,110,101,32,67,79,83,84,95,69,83,84,95,65,81,32,49,10,35,100,101,102,105,110,101,32,73,78,84,82,65,95,77,66,83,32,32,32,50,10,35,100,101,102,105,110,101,32,67,79,80,89,50,95,73,70,95,76,84,40,32,120,44,32,121,44,32,97,44,32,98,32,41,92,10,105,102,40,40,121,41,60,40,120,41,41,92,10,123,92,10,40,120,41,32,61,32,40,121,41,59,92,10,40,97,41,32,61,32,40,98,41,59,92,10,125,10,99,111,110,115,116,97,110,116,32,105,110,116,50,32,100,105,97,95,111,102,102,115,91,52,93,32,61,10,123,10,123,48,44,32,45,49,125,44,32,123,45,49,44,32,48,125,44,32,123,49,44,32,48,125,44,32,123,48,44,32,49,125,44,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+10240);
/* memory initializer */ allocate([125,59,10,105,110,108,105,110,101,32,112,105,120,101,108,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,105,110,116,32,120,32,41,10,123,10,114,101,116,117,114,110,32,40,112,105,120,101,108,41,32,99,108,97,109,112,40,32,120,44,32,40,105,110,116,41,32,48,44,32,40,105,110,116,41,32,80,73,88,69,76,95,77,65,88,32,41,59,10,125,10,105,110,108,105,110,101,32,105,110,116,50,32,120,50,54,52,95,109,101,100,105,97,110,95,109,118,40,32,115,104,111,114,116,50,32,97,44,32,115,104,111,114,116,50,32,98,44,32,115,104,111,114,116,50,32,99,32,41,10,123,10,115,104,111,114,116,50,32,116,49,32,61,32,109,105,110,40,97,44,32,98,41,59,10,115,104,111,114,116,50,32,116,50,32,61,32,109,105,110,40,109,97,120,40,97,44,32,98,41,44,32,99,41,59,10,114,101,116,117,114,110,32,99,111,110,118,101,114,116,95,105,110,116,50,40,109,97,120,40,116,49,44,32,116,50,41,41,59,10,125,10,105,110,108,105,110,101,32,115,117,109,50,95,116,32,97,98,115,50,40,32,115,117,109,50,95,116,32,97,32,41,10,123,10,115,117,109,50,95,116,32,115,32,61,32,40,40,97,32,62,62,32,40,66,73,84,83,95,80,69,82,95,83,85,77,32,45,32,49,41,41,32,38,32,40,40,40,115,117,109,50,95,116,41,49,32,60,60,32,66,73,84,83,95,80,69,82,95,83,85,77,41,32,43,32,49,41,41,32,42,32,40,40,115,117,109,95,116,41,45,49,41,59,10,114,101,116,117,114,110,32,40,97,32,43,32,115,41,32,94,32,115,59,10,125,10,35,100,101,102,105,110,101,32,72,65,68,65,77,65,82,68,52,40,32,100,48,44,32,100,49,44,32,100,50,44,32,100,51,44,32,115,48,44,32,115,49,44,32,115,50,44,32,115,51,32,41,32,123,92,10,115,117,109,50,95,116,32,116,48,32,61,32,115,48,32,43,32,115,49,59,92,10,115,117,109,50,95,116,32,116,49,32,61,32,115,48,32,45,32,115,49,59,92,10,115,117,109,50,95,116,32,116,50,32,61,32,115,50,32,43,32,115,51,59,92,10,115,117,109,50,95,116,32,116,51,32,61,32,115,50,32,45,32,115,51,59,92,10,100,48,32,61,32,116,48,32,43,32,116,50,59,92,10,100,50,32,61,32,116,48,32,45,32,116,50,59,92,10,100,49,32,61,32,116,49,32,43,32,116,51,59,92,10,100,51,32,61,32,116,49,32,45,32,116,51,59,92,10,125,10,35,100,101,102,105,110,101,32,72,65,68,65,77,65,82,68,52,86,40,32,100,48,44,32,100,49,44,32,100,50,44,32,100,51,44,32,115,48,44,32,115,49,44,32,115,50,44,32,115,51,32,41,32,123,92,10,105,110,116,50,32,116,48,32,61,32,115,48,32,43,32,115,49,59,92,10,105,110,116,50,32,116,49,32,61,32,115,48,32,45,32,115,49,59,92,10,105,110,116,50,32,116,50,32,61,32,115,50,32,43,32,115,51,59,92,10,105,110,116,50,32,116,51,32,61,32,115,50,32,45,32,115,51,59,92,10,100,48,32,61,32,116,48,32,43,32,116,50,59,92,10,100,50,32,61,32,116,48,32,45,32,116,50,59,92,10,100,49,32,61,32,116,49,32,43,32,116,51,59,92,10,100,51,32,61,32,116,49,32,45,32,116,51,59,92,10,125,10,35,100,101,102,105,110,101,32,83,65,84,68,95,67,95,56,120,52,95,81,40,32,110,97,109,101,44,32,113,49,44,32,113,50,32,41,92,10,105,110,116,32,110,97,109,101,40,32,113,49,32,112,105,120,101,108,32,42,112,105,120,49,44,32,105,110,116,32,105,95,112,105,120,49,44,32,113,50,32,112,105,120,101,108,32,42,112,105,120,50,44,32,105,110,116,32,105,95,112,105,120,50,32,41,92,10,123,92,10,115,117,109,50,95,116,32,116,109,112,91,52,93,91,52,93,59,92,10,115,117,109,50,95,116,32,97,48,44,32,97,49,44,32,97,50,44,32,97,51,59,92,10,115,117,109,50,95,116,32,115,117,109,32,61,32,48,59,92,10,102,111,114,40,32,105,110,116,32,105,32,61,32,48,59,32,105,32,60,32,52,59,32,105,43,43,44,32,112,105,120,49,32,43,61,32,105,95,112,105,120,49,44,32,112,105,120,50,32,43,61,32,105,95,112,105,120,50,32,41,92,10,123,92,10,97,48,32,61,32,40,112,105,120,49,91,48,93,32,45,32,112,105,120,50,91,48,93,41,32,43,32,40,40,115,117,109,50,95,116,41,40,112,105,120,49,91,52,93,32,45,32,112,105,120,50,91,52,93,41,32,60,60,32,66,73,84,83,95,80,69,82,95,83,85,77,41,59,92,10,97,49,32,61,32,40,112,105,120,49,91,49,93,32,45,32,112,105,120,50,91,49,93,41,32,43,32,40,40,115,117,109,50,95,116,41,40,112,105,120,49,91,53,93,32,45,32,112,105,120,50,91,53,93,41,32,60,60,32,66,73,84,83,95,80,69,82,95,83,85,77,41,59,92,10,97,50,32,61,32,40,112,105,120,49,91,50,93,32,45,32,112,105,120,50,91,50,93,41,32,43,32,40,40,115,117,109,50,95,116,41,40,112,105,120,49,91,54,93,32,45,32,112,105,120,50,91,54,93,41,32,60,60,32,66,73,84,83,95,80,69,82,95,83,85,77,41,59,92,10,97,51,32,61,32,40,112,105,120,49,91,51,93,32,45,32,112,105,120,50,91,51,93,41,32,43,32,40,40,115,117,109,50,95,116,41,40,112,105,120,49,91,55,93,32,45,32,112,105,120,50,91,55,93,41,32,60,60,32,66,73,84,83,95,80,69,82,95,83,85,77,41,59,92,10,72,65,68,65,77,65,82,68,52,40,32,116,109,112,91,105,93,91,48,93,44,32,116,109,112,91,105,93,91,49,93,44,32,116,109,112,91,105,93,91,50,93,44,32,116,109,112,91,105,93,91,51,93,44,32,97,48,44,32,97,49,44,32,97,50,44,32,97,51,32,41,59,92,10,125,92,10,102,111,114,40,32,105,110,116,32,105,32,61,32,48,59,32,105,32,60,32,52,59,32,105,43,43,32,41,92,10,123,92,10,72,65,68,65,77,65,82,68,52,40,32,97,48,44,32,97,49,44,32,97,50,44,32,97,51,44,32,116,109,112,91,48,93,91,105,93,44,32,116,109,112,91,49,93,91,105,93,44,32,116,109,112,91,50,93,91,105,93,44,32,116,109,112,91,51,93,91,105,93,32,41,59,92,10,115,117,109,32,43,61,32,97,98,115,50,40,32,97,48,32,41,32,43,32,97,98,115,50,40,32,97,49,32,41,32,43,32,97,98,115,50,40,32,97,50,32,41,32,43,32,97,98,115,50,40,32,97,51,32,41,59,92,10,125,92,10,114,101,116,117,114,110,32,40,40,40,115,117,109,95,116,41,115,117,109,41,32,43,32,40,115,117,109,62,62,66,73,84,83,95,80,69,82,95,83,85,77,41,41,32,62,62,32,49,59,92,10,125,10,47,42,10,42,32,85,116,105,108,105,116,121,32,102,117,110,99,116,105,111,110,32,116,111,32,112,101,114,102,111,114,109,32,97,32,112,97,114,97,108,108,101,108,32,115,117,109,32,114,101,100,117,99,116,105,111,110,32,111,102,32,97,110,32,97,114,114,97,121,32,111,102,32,105,110,116,101,103,101,114,115,10,42,47,10,105,110,116,32,112,97,114,97,108,108,101,108,95,115,117,109,40,32,105,110,116,32,118,97,108,117,101,44,32,105,110,116,32,120,44,32,118,111,108,97,116,105,108,101,32,108,111,99,97,108,32,105,110,116,32,42,97,114,114,97,121,32,41,10,123,10,97,114,114,97,121,91,120,93,32,61,32,118,97,108,117,101,59,10,98,97,114,114,105,101,114,40,32,67,76,75,95,76,79,67,65,76,95,77,69,77,95,70,69,78,67,69,32,41,59,10,105,110,116,32,100,105,109,32,61,32,103,101,116,95,108,111,99,97,108,95,115,105,122,101,40,32,48,32,41,59,10,119,104,105,108,101,40,32,100,105,109,32,62,32,49,32,41,10,123,10,100,105,109,32,62,62,61,32,49,59,10,105,102,40,32,120,32,60,32,100,105,109,32,41,10,97,114,114,97,121,91,120,93,32,43,61,32,97,114,114,97,121,91,120,32,43,32,100,105,109,93,59,10,105,102,40,32,100,105,109,32,62,32,51,50,32,41,10,98,97,114,114,105,101,114,40,32,67,76,75,95,76,79,67,65,76,95,77,69,77,95,70,69,78,67,69,32,41,59,10,125,10,114,101,116,117,114,110,32,97,114,114,97,121,91,48,93,59,10,125,10,105,110,116,32,109,118,95,99,111,115,116,40,32,117,105,110,116,50,32,109,118,100,32,41,10,123,10,102,108,111,97,116,50,32,109,118,100,102,32,61,32,40,102,108,111,97,116,50,41,40,109,118,100,46,120,44,32,109,118,100,46,121,41,32,43,32,49,46,48,102,59,10,102,108,111,97,116,50,32,99,111,115,116,32,61,32,114,111,117,110,100,40,32,108,111,103,50,40,109,118,100,102,41,32,42,32,50,46,48,102,32,43,32,48,46,55,49,56,102,32,43,32,40,102,108,111,97,116,50,41,40,33,33,109,118,100,46,120,44,32,33,33,109,118,100,46,121,41,32,41,59,10,114,101,116,117,114,110,32,40,105,110,116,41,32,40,99,111,115,116,46,120,32,43,32,99,111,115,116,46,121,41,59,10,125,10,47,42,32,77,111,100,101,32,115,101,108,101,99,116,105,111,110,32,114,111,117,116,105,110,101,115,44,32,115,101,108,101,99,116,32,116,104,101,32,108,101,97,115,116,32,83,65,84,68,32,99,111,115,116,32,109,111,100,101,32,102,111,114,32,101,97,99,104,32,108,111,119,114,101,115,10,42,32,109,97,99,114,111,98,108,111,99,107,46,32,32,87,104,101,110,32,109,101,97,115,117,114,105,110,103,32,66,32,115,108,105,99,101,115,44,32,116,104,105,115,32,105,110,99,108,117,100,101,115,32,109,101,97,115,117,114,105,110,103,32,116,104,101,32,99,111,115,116,32,111,102,10,42,32,116,104,114,101,101,32,98,105,100,105,114,32,109,111,100,101,115,46,32,32,42,47,10,47,42,32,70,111,117,114,32,116,104,114,101,97,100,115,32,99,111,111,112,101,114,97,116,105,118,101,108,121,32,109,101,97,115,117,114,101,32,56,120,56,32,66,73,68,73,82,32,99,111,115,116,32,119,105,116,104,32,83,65,84,68,32,42,47,10,105,110,116,32,98,105,100,105,114,95,115,97,116,100,95,56,120,56,95,105,105,95,99,111,111,112,52,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,101,110,99,95,108,111,119,114,101,115,44,10,105,110,116,50,32,102,101,110,99,112,111,115,44,10,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,114,101,102,48,95,112,108,97,110,101,115,44,10,105,110,116,50,32,113,112,111,115,48,44,10,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,114,101,102,49,95,112,108,97,110,101,115,44,10,105,110,116,50,32,113,112,111,115,49,44,10,105,110,116,32,119,101,105,103,104,116,44,10,108,111,99,97,108,32,115,117,109,50,95,116,32,42,116,109,112,112,44,10,105,110,116,32,105,100,120,32,41,10,123,10,118,111,108,97,116,105,108,101,32,108,111,99,97,108,32,115,117,109,50,95,116,40,32,42,116,109,112,32,41,91,52,93,32,61,32,40,118,111,108,97,116,105,108,101,32,108,111,99,97,108,32,115,117,109,50,95,116,40,32,42,32,41,91,52,93,41,116,109,112,112,59,10,115,117,109,50,95,116,32,98,48,44,32,98,49,44,32,98,50,44,32,98,51,59,10,115,117,109,50,95,116,32,115,117,109,32,61,32,48,59,10,105,110,116,50,32,102,114,101,102,48,65,112,111,115,32,61,32,40,105,110,116,50,41,40,113,112,111,115,48,46,120,62,62,50,44,32,113,112,111,115,48,46,121,62,62,50,41,59,10,105,110,116,32,104,112,101,108,48,65,32,61,32,40,40,113,112,111,115,48,46,120,38,50,41,62,62,49,41,32,43,32,40,113,112,111,115,48,46,121,38,50,41,59,10,105,110,116,50,32,113,112,111,115,48,66,32,61,32,40,105,110,116,50,41,113,112,111,115,48,32,43,32,40,105,110,116,50,41,40,40,40,113,112,111,115,48,46,120,38,49,41,60,60,49,41,44,32,40,40,113,112,111,115,48,46,121,38,49,41,60,60,49,41,41,59,10,105,110,116,50,32,102,114,101,102,48,66,112,111,115,32,61,32,40,105,110,116,50,41,40,113,112,111,115,48,66,46,120,62,62,50,44,32,113,112,111,115,48,66,46,121,62,62,50,41,59,10,105,110,116,32,104,112,101,108,48,66,32,61,32,40,40,113,112,111,115,48,66,46,120,38,50,41,62,62,49,41,32,43,32,40,113,112,111,115,48,66,46,121,38,50,41,59,10,105,110,116,50,32,102,114,101,102,49,65,112,111,115,32,61,32,40,105,110,116,50,41,40,113,112,111,115,49,46,120,62,62,50,44,32,113,112,111,115,49,46,121,62,62,50,41,59,10,105,110,116,32,104,112,101,108,49,65,32,61,32,40,40,113,112,111,115,49,46,120,38,50,41,62,62,49,41,32,43,32,40,113,112,111,115,49,46,121,38,50,41,59,10,105,110,116,50,32,113,112,111,115,49,66,32,61,32,40,105,110,116,50,41,113,112,111,115,49,32,43,32,40,105,110,116,50,41,40,40,40,113,112,111,115,49,46,120,38,49,41,60,60,49,41,44,32,40,40,113,112,111,115,49,46,121,38,49,41,60,60,49,41,41,59,10,105,110,116,50,32,102,114,101,102,49,66,112,111,115,32,61,32,40,105,110,116,50,41,40,113,112,111,115,49,66,46,120,62,62,50,44,32,113,112,111,115,49,66,46,121,62,62,50,41,59,10,105,110,116,32,104,112,101,108,49,66,32,61,32,40,40,113,112,111,115,49,66,46,120,38,50,41,62,62,49,41,32,43,32,40,113,112,111,115,49,66,46,121,38,50,41,59,10,117,105,110,116,32,109,97,115,107,95,115,104,105,102,116,48,65,32,61,32,56,32,42,32,104,112,101,108,48,65,44,32,109,97,115,107,95,115,104,105,102,116,48,66,32,61,32,56,32,42,32,104,112,101,108,48,66,59,10,117,105,110,116,32,109,97,115,107,95,115,104,105,102,116,49,65,32,61,32,56,32,42,32,104,112,101,108,49,65,44,32,109,97,115,107,95,115,104,105,102,116,49,66,32,61,32,56,32,42,32,104,112,101,108,49,66,59,10,117,105,110,116,32,118,65,44,32,118,66,59,10,117,105,110,116,32,101,110,99,44,32,114,101,102,48,44,32,114,101,102,49,59,10,117,105,110,116,32,97,48,44,32,97,49,59,10,99,111,110,115,116,32,105,110,116,32,119,101,105,103,104,116,50,32,61,32,54,52,32,45,32,119,101,105,103,104,116,59,10,35,100,101,102,105,110,101,32,82,69,65,68,95,66,73,68,73,82,95,68,73,70,70,40,32,79,85,84,44,32,88,32,41,92,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,95,108,111,119,114,101,115,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,88,44,32,105,100,120,41,32,41,46,115,48,59,92,10,118,65,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,48,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,48,65,112,111,115,32,43,32,40,105,110,116,50,41,40,88,44,32,105,100,120,41,32,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,48,65,41,32,38,32,48,120,70,70,59,92,10,118,66,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,48,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,48,66,112,111,115,32,43,32,40,105,110,116,50,41,40,88,44,32,105,100,120,41,32,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,48,66,41,32,38,32,48,120,70,70,59,92,10,114,101,102,48,32,61,32,114,104,97,100,100,40,32,118,65,44,32,118,66,32,41,59,92,10,118,65,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,49,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,49,65,112,111,115,32,43,32,40,105,110,116,50,41,40,88,44,32,105,100,120,41,32,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,49,65,41,32,38,32,48,120,70,70,59,92,10,118,66,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,49,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,49,66,112,111,115,32,43,32,40,105,110,116,50,41,40,88,44,32,105,100,120,41,32,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,49,66,41,32,38,32,48,120,70,70,59,92,10,114,101,102,49,32,61,32,114,104,97,100,100,40,32,118,65,44,32,118,66,32,41,59,92,10,79,85,84,32,61,32,101,110,99,32,45,32,40,40,114,101,102,48,32,42,32,119,101,105,103,104,116,32,43,32,114,101,102,49,32,42,32,119,101,105,103,104,116,50,32,43,32,40,49,32,60,60,32,53,41,41,32,62,62,32,54,41,59,10,35,100,101,102,105,110,101,32,82,69,65,68,95,68,73,70,70,95,69,88,40,32,79,85,84,44,32,97,44,32,98,32,41,92,10,82,69,65,68,95,66,73,68,73,82,95,68,73,70,70,40,32,97,48,44,32,97,32,41,59,92,10,82,69,65,68,95,66,73,68,73,82,95,68,73,70,70,40,32,97,49,44,32,98,32,41,59,92,10,79,85,84,32,61,32,97,48,32,43,32,40,97,49,60,60,66,73,84,83,95,80,69,82,95,83,85,77,41,59,10,35,100,101,102,105,110,101,32,82,79,87,95,56,120,52,95,83,65,84,68,40,32,97,44,32,98,44,32,99,32,41,92,10,102,101,110,99,112,111,115,46,121,32,43,61,32,97,59,92,10,102,114,101,102,48,65,112,111,115,46,121,32,43,61,32,98,59,92,10,102,114,101,102,48,66,112,111,115,46,121,32,43,61,32,98,59,92,10,102,114,101,102,49,65,112,111,115,46,121,32,43,61,32,99,59,92,10,102,114,101,102,49,66,112,111,115,46,121,32,43,61,32,99,59,92,10,82,69,65,68,95,68,73,70,70,95,69,88,40,32,98,48,44,32,48,44,32,52,32,41,59,92,10,82,69,65,68,95,68,73,70,70,95,69,88,40,32,98,49,44,32,49,44,32,53,32,41,59,92,10,82,69,65,68,95,68,73,70,70,95,69,88,40,32,98,50,44,32,50,44,32,54,32,41,59,92,10,82,69,65,68,95,68,73,70,70,95,69,88,40,32,98,51,44,32,51,44,32,55,32,41,59,92,10,72,65,68,65,77,65,82,68,52,40,32,116,109,112,91,105,100,120,93,91,48,93,44,32,116,109,112,91,105,100,120,93,91,49,93,44,32,116,109,112,91,105,100,120,93,91,50,93,44,32,116,109,112,91,105,100,120,93,91,51,93,44,32,98,48,44,32,98,49,44,32,98,50,44,32,98,51,32,41,59,92,10,72,65,68,65,77,65,82,68,52,40,32,98,48,44,32,98,49,44,32,98,50,44,32,98,51,44,32,116,109,112,91,48,93,91,105,100,120,93,44,32,116,109,112,91,49,93,91,105,100,120,93,44,32,116,109,112,91,50,93,91,105,100,120,93,44,32,116,109,112,91,51,93,91,105,100,120,93,32,41,59,92,10,115,117,109,32,43,61,32,97,98,115,50,40,32,98,48,32,41,32,43,32,97,98,115,50,40,32,98,49,32,41,32,43,32,97,98,115,50,40,32,98,50,32,41,32,43,32,97,98,115,50,40,32,98,51,32,41,59,10,82,79,87,95,56,120,52,95,83,65,84,68,40,32,48,44,32,48,44,32,48,32,41,59,10,82,79,87,95,56,120,52,95,83,65,84,68,40,32,52,44,32,52,44,32,52,32,41,59,10,35,117,110,100,101,102,32,82,69,65,68,95,66,73,68,73,82,95,68,73,70,70,10,35,117,110,100,101,102,32,82,69,65,68,95,68,73,70,70,95,69,88,10,35,117,110,100,101,102,32,82,79,87,95,56,120,52,95,83,65,84,68,10,114,101,116,117,114,110,32,40,40,40,115,117,109,95,116,41,115,117,109,41,32,43,32,40,115,117,109,62,62,66,73,84,83,95,80,69,82,95,83,85,77,41,41,32,62,62,32,49,59,10,125,10,47,42,10,42,32,109,111,100,101,32,115,101,108,101,99,116,105,111,110,32,45,32,112,105,99,107,32,116,104,101,32,108,101,97,115,116,32,99,111,115,116,32,112,97,114,116,105,116,105,111,110,32,116,121,112,101,32,102,111,114,32,101,97,99,104,32,56,120,56,32,109,97,99,114,111,98,108,111,99,107,46,10,42,32,73,110,116,114,97,44,32,108,105,115,116,48,32,111,114,32,108,105,115,116,49,46,32,32,87,104,101,110,32,109,101,97,115,117,114,105,110,103,32,97,32,66,32,115,108,105,99,101,44,32,97,108,115,111,32,116,101,115,116,32,116,104,114,101,101,32,98,105,100,105,114,10,42,32,112,111,115,115,105,98,105,108,105,116,105,101,115,46,10,42,10,42,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,115,91,48,124,49,93,32,97,110,100,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,91,48,124,49,93,32,97,114,101,32,108,97,114,103,101,32,98,117,102,102,101,114,115,32,116,104,97,116,10,42,32,104,111,108,100,32,109,97,110,121,32,102,114,97,109,101,115,32,119,111,114,116,104,32,111,102,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,46,32,32,87,101,32,109,117,115,116,32,111,102,102,115,101,116,32,105,110,116,111,32,116,104,101,32,99,111,114,114,101,99,116,10,42,32,108,111,99,97,116,105,111,110,32,102,111,114,32,116,104,105,115,32,102,114,97,109,101,39,115,32,118,101,99,116,111,114,115,58,10,42,10,42,32,32,32,67,80,85,32,101,113,117,105,118,97,108,101,110,116,58,32,102,101,110,99,45,62,108,111,119,114,101,115,95,109,118,115,91,48,93,91,98,32,45,32,112,48,32,45,32,49,93,10,42,32,32,32,71,80,85,32,101,113,117,105,118,97,108,101,110,116,58,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,115,48,91,40,98,32,45,32,112,48,32,45,32,49,41,32,42,32,109,98,95,99,111,117,110,116,93,10,42,10,42,32,103,108,111,98,97,108,32,108,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,32,102,111,114,32,80,32,115,108,105,99,101,32,101,115,116,105,109,97,116,101,58,32,32,91,109,98,95,119,105,100,116,104,44,32,109,98,95,104,101,105,103,104,116,93,10,42,32,103,108,111,98,97,108,32,108,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,32,102,111,114,32,66,32,115,108,105,99,101,32,101,115,116,105,109,97,116,101,58,32,32,91,109,98,95,119,105,100,116,104,32,42,32,52,44,32,109,98,95,104,101,105,103,104,116,93,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,109,111,100,101,95,115,101,108,101,99,116,105,111,110,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,32,32,102,101,110,99,95,108,111,119,114,101,115,44,10,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,32,32,102,114,101,102,48,95,112,108,97,110,101,115,44,10,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,32,32,102,114,101,102,49,95,112,108,97,110,101,115,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,115,104,111,114,116,50,32,32,42,102,101,110,99,95,108,111,119,114,101,115,95,109,118,115,48,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,115,104,111,114,116,50,32,32,42,102,101,110,99,95,108,111,119,114,101,115,95,109,118,115,49,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,115,104,111,114,116,50,32,32,42,102,114,101,102,49,95,108,111,119,114,101,115,95,109,118,115,48,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,105,110,116,49,54,95,116,32,42,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,48,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,105,110,116,49,54,95,116,32,42,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,49,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,117,105,110,116,49,54,95,116,32,42,102,101,110,99,95,105,110,116,114,97,95,99,111,115,116,44,10,103,108,111,98,97,108,32,117,105,110,116,49,54,95,116,32,32,32,32,32,32,42,108,111,119,114,101,115,95,99,111,115,116,115,44,10,103,108,111,98,97,108,32,105,110,116,32,32,32,32,32,32,32,32,32,32,32,42,102,114,97,109,101,95,115,116,97,116,115,44,10,108,111,99,97,108,32,105,110,116,49,54,95,116,32,32,32,32,32,32,32,32,42,99,111,115,116,95,108,111,99,97,108,44,10,108,111,99,97,108,32,115,117,109,50,95,116,32,32,32,32,32,32,32,32,32,42,115,97,116,100,95,108,111,99,97,108,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,98,95,119,105,100,116,104,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,105,112,114,101,100,95,119,101,105,103,104,116,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,100,105,115,116,95,115,99,97,108,101,95,102,97,99,116,111,114,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,112,48,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,112,49,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,108,97,109,98,100,97,32,41,10,123,10,105,110,116,32,109,98,95,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,105,110,116,32,98,95,98,105,100,105,114,32,61,32,98,32,60,32,112,49,59,10,105,102,40,32,98,95,98,105,100,105,114,32,41,10,123,10,47,42,32,119,104,101,110,32,109,111,100,101,95,115,101,108,101,99,116,105,111,110,32,105,115,32,114,117,110,32,102,111,114,32,66,32,102,114,97,109,101,115,44,32,105,116,32,109,117,115,116,32,112,101,114,102,111,114,109,32,66,73,68,73,82,32,83,65,84,68,10,42,32,109,101,97,115,117,114,101,109,101,110,116,115,44,32,115,111,32,105,116,32,105,115,32,108,97,117,110,99,104,101,100,32,119,105,116,104,32,102,111,117,114,32,116,105,109,101,115,32,97,115,32,109,97,110,121,32,116,104,114,101,97,100,115,32,105,110,10,42,32,111,114,100,101,114,32,116,111,32,115,112,114,101,97,100,32,116,104,101,32,119,111,114,107,32,97,114,111,117,110,100,32,109,111,114,101,32,111,102,32,116,104,101,32,71,80,85,46,32,32,65,110,100,32,105,116,32,99,97,110,32,97,100,100,10,42,32,112,97,100,100,105,110,103,32,116,104,114,101,97,100,115,32,105,110,32,116,104,101,32,88,32,100,105,114,101,99,116,105,111,110,46,32,42,47,10,109,98,95,120,32,62,62,61,32,50,59,10,105,102,40,32,109,98,95,120,32,62,61,32,109,98,95,119,105,100,116,104,32,41,10,114,101,116,117,114,110,59,10,125,10,105,110,116,32,109,98,95,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,32,109,98,95,104,101,105,103,104,116,32,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,49,32,41,59,10,105,110,116,32,109,98,95,99,111,117,110,116,32,61,32,109,98,95,119,105,100,116,104,32,42,32,109,98,95,104,101,105,103,104,116,59,10,105,110,116,32,109,98,95,120,121,32,61,32,109,98,95,120,32,43,32,109,98,95,121,32,42,32,109,98,95,119,105,100,116,104,59,10,47,42,32,73,110,105,116,105,97,108,105,122,101,32,105,110,116,32,102,114,97,109,101,95,115,116,97,116,115,91,52,93,32,102,111,114,32,110,101,120,116,32,107,101,114,110,101,108,32,40,115,117,109,95,105,110,116,101,114,95,99,111,115,116,41,32,42,47,10,105,102,40,32,109,98,95,120,32,60,32,52,32,38,38,32,109,98,95,121,32,61,61,32,48,32,41,10,102,114,97,109,101,95,115,116,97,116,115,91,109,98,95,120,93,32,61,32,48,59,10,105,110,116,32,98,99,111,115,116,32,61,32,67,79,83,84,95,77,65,88,59,10,105,110,116,32,108,105,115,116,95,117,115,101,100,32,61,32,48,59,10,105,102,40,32,33,98,95,98,105,100,105,114,32,41,10,123,10,105,110,116,32,105,99,111,115,116,32,61,32,102,101,110,99,95,105,110,116,114,97,95,99,111,115,116,91,109,98,95,120,121,93,59,10,67,79,80,89,50,95,73,70,95,76,84,40,32,98,99,111,115,116,44,32,105,99,111,115,116,44,32,108,105,115,116,95,117,115,101,100,44,32,48,32,41,59,10,125,10,105,102,40,32,98,32,33,61,32,112,48,32,41,10,123,10,105,110,116,32,109,118,95,99,111,115,116,48,32,61,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,48,91,40,98,32,45,32,112,48,32,45,32,49,41,32,42,32,109,98,95,99,111,117,110,116,32,43,32,109,98,95,120,121,93,59,10,67,79,80,89,50,95,73,70,95,76,84,40,32,98,99,111,115,116,44,32,109,118,95,99,111,115,116,48,44,32,108,105,115,116,95,117,115,101,100,44,32,49,32,41,59,10,125,10,105,102,40,32,98,32,33,61,32,112,49,32,41,10,123,10,105,110,116,32,109,118,95,99,111,115,116,49,32,61,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,49,91,40,112,49,32,45,32,98,32,45,32,49,41,32,42,32,109,98,95,99,111,117,110,116,32,43,32,109,98,95,120,121,93,59,10,67,79,80,89,50,95,73,70,95,76,84,40,32,98,99,111,115,116,44,32,109,118,95,99,111,115,116,49,44,32,108,105,115,116,95,117,115,101,100,44,32,50,32,41,59,10,125,10,105,102,40,32,98,95,98,105,100,105,114,32,41,10,123,10,105,110,116,50,32,99,111,111,114,100,32,61,32,40,105,110,116,50,41,40,109,98,95,120,44,32,109,98,95,121,41,32,60,60,32,51,59,10,105,110,116,32,109,98,95,105,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,32,38,32,51,59,10,105,110,116,32,109,98,95,105,110,95,103,114,111,117,112,32,61,32,103,101,116,95,108,111,99,97,108,95,105,100,40,32,49,32,41,32,42,32,40,103,101,116,95,108,111,99,97,108,95,115,105,122,101,40,32,48,32,41,32,62,62,32,50,41,32,43,32,40,103,101,116,95,108,111,99,97,108,95,105,100,40,32,48,32,41,32,62,62,32,50,41,59,10,99,111,115,116,95,108,111,99,97,108,32,43,61,32,109,98,95,105,110,95,103,114,111,117,112,32,42,32,52,59,10,115,97,116,100,95,108,111,99,97,108,32,43,61,32,109,98,95,105,110,95,103,114,111,117,112,32,42,32,49,54,59,10,35,100,101,102,105,110,101,32,84,82,89,95,66,73,68,73,82,40,32,109,118,48,44,32,109,118,49,44,32,112,101,110,97,108,116,121,32,41,92,10,123,92,10,105,110,116,50,32,113,112,111,115,48,32,61,32,40,105,110,116,50,41,40,40,99,111,111,114,100,46,120,60,60,50,41,32,43,32,109,118,48,46,120,44,32,40,99,111,111,114,100,46,121,60,60,50,41,32,43,32,109,118,48,46,121,41,59,92,10,105,110,116,50,32,113,112,111,115,49,32,61,32,40,105,110,116,50,41,40,40,99,111,111,114,100,46,120,60,60,50,41,32,43,32,109,118,49,46,120,44,32,40,99,111,111,114,100,46,121,60,60,50,41,32,43,32,109,118,49,46,121,41,59,92,10,99,111,115,116,95,108,111,99,97,108,91,109,98,95,105,93,32,61,32,98,105,100,105,114,95,115,97,116,100,95,56,120,56,95,105,105,95,99,111,111,112,52,40,32,102,101,110,99,95,108,111,119,114,101,115,44,32,99,111,111,114,100,44,32,102,114,101,102,48,95,112,108,97,110,101,115,44,32,113,112,111,115,48,44,32,102,114,101,102,49,95,112,108,97,110,101,115,44,32,113,112,111,115,49,44,32,98,105,112,114,101,100,95,119,101,105,103,104,116,44,32,115,97,116,100,95,108,111,99,97,108,44,32,109,98,95,105,32,41,59,92,10,105,110,116,32,99,111,115,116,32,61,32,99,111,115,116,95,108,111,99,97,108,91,48,93,32,43,32,99,111,115,116,95,108,111,99,97,108,91,49,93,32,43,32,99,111,115,116,95,108,111,99,97,108,91,50,93,32,43,32,99,111,115,116,95,108,111,99,97,108,91,51,93,59,92,10,67,79,80,89,50,95,73,70,95,76,84,40,32,98,99,111,115,116,44,32,112,101,110,97,108,116,121,32,42,32,108,97,109,98,100,97,32,43,32,99,111,115,116,44,32,108,105,115,116,95,117,115,101,100,44,32,51,32,41,59,92,10,125,10,47,42,32,116,101,109,112,111,114,97,108,32,112,114,101,100,105,99,116,105,111,110,32,42,47,10,115,104,111,114,116,50,32,100,109,118,48,44,32,100,109,118,49,59,10,115,104,111,114,116,50,32,109,118,114,32,61,32,102,114,101,102,49,95,108,111,119,114,101,115,95,109,118,115,48,91,109,98,95,120,121,93,59,10,100,109,118,48,32,61,32,40,109,118,114,32,42,32,40,115,104,111,114,116,41,32,100,105,115,116,95,115,99,97,108,101,95,102,97,99,116,111,114,32,43,32,40,115,104,111,114,116,41,32,49,50,56,41,32,62,62,32,40,115,104,111,114,116,41,32,56,59,10,100,109,118,49,32,61,32,100,109,118,48,32,45,32,109,118,114,59,10,84,82,89,95,66,73,68,73,82,40,32,100,109,118,48,44,32,100,109,118,49,44,32,48,32,41,10,105,102,40,32,97,115,95,117,105,110,116,40,32,100,109,118,48,32,41,32,124,124,32,97,115,95,117,105,110,116,40,32,100,109,118,49,32,41,32,41,10,123,10,47,42,32,66,45,100,105,114,101,99,116,32,112,114,101,100,105,99,116,105,111,110,32,42,47,10,100,109,118,48,32,61,32,48,59,32,100,109,118,49,32,61,32,48,59,10,84,82,89,95,66,73,68,73,82,40,32,100,109,118,48,44,32,100,109,118,49,44,32,48,32,41,59,10,125,10,47,42,32,76,48,43,76,49,32,112,114,101,100,105,99,116,105,111,110,32,42,47,10,100,109,118,48,32,61,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,115,48,91,40,98,32,45,32,112,48,32,45,32,49,41,32,42,32,109,98,95,99,111,117,110,116,32,43,32,109,98,95,120,121,93,59,10,100,109,118,49,32,61,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,115,49,91,40,112,49,32,45,32,98,32,45,32,49,41,32,42,32,109,98,95,99,111,117,110,116,32,43,32,109,98,95,120,121,93,59,10,84,82,89,95,66,73,68,73,82,40,32,100,109,118,48,44,32,100,109,118,49,44,32,53,32,41,59,10,35,117,110,100,101,102,32,84,82,89,95,66,73,68,73,82,10,125,10,108,111,119,114,101,115,95,99,111,115,116,115,91,109,98,95,120,121,93,32,61,32,109,105,110,40,32,98,99,111,115,116,44,32,76,79,87,82,69,83,95,67,79,83,84,95,77,65,83,75,32,41,32,43,32,40,108,105,115,116,95,117,115,101,100,32,60,60,32,76,79,87,82,69,83,95,67,79,83,84,95,83,72,73,70,84,41,59,10,125,10,47,42,10,42,32,112,97,114,97,108,108,101,108,32,115,117,109,32,105,110,116,101,114,32,99,111,115,116,115,10,42,10,42,32,103,108,111,98,97,108,32,108,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,58,32,91,50,53,54,44,32,109,98,95,104,101,105,103,104,116,93,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,115,117,109,95,105,110,116,101,114,95,99,111,115,116,40,32,99,111,110,115,116,32,103,108,111,98,97,108,32,117,105,110,116,49,54,95,116,32,42,102,101,110,99,95,108,111,119,114,101,115,95,99,111,115,116,115,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,117,105,110,116,49,54,95,116,32,42,105,110,118,95,113,115,99,97,108,101,95,102,97,99,116,111,114,44,10,103,108,111,98,97,108,32,105,110,116,32,32,32,32,32,32,32,32,32,32,32,42,102,101,110,99,95,114,111,119,95,115,97,116,100,115,44,10,103,108,111,98,97,108,32,105,110,116,32,32,32,32,32,32,32,32,32,32,32,42,102,114,97,109,101,95,115,116,97,116,115,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,98,95,119,105,100,116,104,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,102,114,97,109,101,95,98,105,97,115,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,112,48,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,112,49,32,41,10,123,10,105,110,116,32,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,32,109,98,95,104,101,105,103,104,116,32,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,49,32,41,59,10,105,110,116,32,114,111,119,95,115,97,116,100,115,32,61,32,48,59,10,105,110,116,32,99,111,115,116,95,101,115,116,32,61,32,48,59,10,105,110,116,32,99,111,115,116,95,101,115,116,95,97,113,32,61,32,48,59,10,105,110,116,32,105,110,116,114,97,95,109,98,115,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,32,120,32,60,32,109,98,95,119,105,100,116,104,59,32,120,32,43,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,48,32,41,41,10,123,10,105,110,116,32,109,98,95,120,121,32,61,32,120,32,43,32,121,32,42,32,109,98,95,119,105,100,116,104,59,10,105,110,116,32,99,111,115,116,32,61,32,102,101,110,99,95,108,111,119,114,101,115,95,99,111,115,116,115,91,109,98,95,120,121,93,32,38,32,76,79,87,82,69,83,95,67,79,83,84,95,77,65,83,75,59,10,105,110,116,32,108,105,115,116,32,61,32,102,101,110,99,95,108,111,119,114,101,115,95,99,111,115,116,115,91,109,98,95,120,121,93,32,62,62,32,76,79,87,82,69,83,95,67,79,83,84,95,83,72,73,70,84,59,10,105,110,116,32,98,95,102,114,97,109,101,95,115,99,111,114,101,95,109,98,32,61,32,40,120,32,62,32,48,32,38,38,32,120,32,60,32,109,98,95,119,105,100,116,104,32,45,32,49,32,38,38,32,121,32,62,32,48,32,38,38,32,121,32,60,32,109,98,95,104,101,105,103,104,116,32,45,32,49,41,32,124,124,32,109,98,95,119,105,100,116,104,32,60,61,32,50,32,124,124,32,109,98,95,104,101,105,103,104,116,32,60,61,32,50,59,10,105,102,40,32,108,105,115,116,32,61,61,32,48,32,38,38,32,98,95,102,114,97,109,101,95,115,99,111,114,101,95,109,98,32,41,10,105,110,116,114,97,95,109,98,115,43,43,59,10,105,110,116,32,99,111,115,116,95,97,113,32,61,32,40,99,111,115,116,32,42,32,105,110,118,95,113,115,99,97,108,101,95,102,97,99,116,111,114,91,109,98,95,120,121,93,32,43,32,49,50,56,41,32,62,62,32,56,59,10,114,111,119,95,115,97,116,100,115,32,43,61,32,99,111,115,116,95,97,113,59,10,105,102,40,32,98,95,102,114,97,109,101,95,115,99,111,114,101,95,109,98,32,41,10,123,10,99,111,115,116,95,101,115,116,32,43,61,32,99,111,115,116,59,10,99,111,115,116,95,101,115,116,95,97,113,32,43,61,32,99,111,115,116,95,97,113,59,10,125,10,125,10,108,111,99,97,108,32,105,110,116,32,98,117,102,102,101,114,91,50,53,54,93,59,10,105,110,116,32,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,114,111,119,95,115,97,116,100,115,32,32,32,61,32,112,97,114,97,108,108,101,108,95,115,117,109,40,32,114,111,119,95,115,97,116,100,115,44,32,120,44,32,98,117,102,102,101,114,32,41,59,10,99,111,115,116,95,101,115,116,32,32,32,32,61,32,112,97,114,97,108,108,101,108,95,115,117,109,40,32,99,111,115,116,95,101,115,116,44,32,120,44,32,98,117,102,102,101,114,32,41,59,10,99,111,115,116,95,101,115,116,95,97,113,32,61,32,112,97,114,97,108,108,101,108,95,115,117,109,40,32,99,111,115,116,95,101,115,116,95,97,113,44,32,120,44,32,98,117,102,102,101,114,32,41,59,10,105,110,116,114,97,95,109,98,115,32,32,32,61,32,112,97,114,97,108,108,101,108,95,115,117,109,40,32,105,110,116,114,97,95,109,98,115,44,32,120,44,32,98,117,102,102,101,114,32,41,59,10,105,102,40,32,98,32,33,61,32,112,49,32,41,10,99,111,115,116,95,101,115,116,32,61,32,40,105,110,116,41,40,40,102,108,111,97,116,41,99,111,115,116,95,101,115,116,32,42,32,49,48,48,46,48,102,32,47,32,40,49,50,48,46,48,102,32,43,32,40,102,108,111,97,116,41,98,102,114,97,109,101,95,98,105,97,115,41,41,59,10,105,102,40,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,32,61,61,32,48,32,41,10,123,10,102,101,110,99,95,114,111,119,95,115,97,116,100,115,91,121,93,32,61,32,114,111,119,95,115,97,116,100,115,59,10,97,116,111,109,105,99,95,97,100,100,40,32,102,114,97,109,101,95,115,116,97,116,115,32,43,32,67,79,83,84,95,69,83,84,44,32,99,111,115,116,95,101,115,116,32,41,59,10,97,116,111,109,105,99,95,97,100,100,40,32,102,114,97,109,101,95,115,116,97,116,115,32,43,32,67,79,83,84,95,69,83,84,95,65,81,44,32,99,111,115,116,95,101,115,116,95,97,113,32,41,59,10,97,116,111,109,105,99,95,97,100,100,40,32,102,114,97,109,101,95,115,116,97,116,115,32,43,32,73,78,84,82,65,95,77,66,83,44,32,105,110,116,114,97,95,109,98,115,32,41,59,10,125,10,125,10,47,42,10,42,32,100,111,119,110,115,99,97,108,101,32,108,111,119,114,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+20480);
/* memory initializer */ allocate([115,32,108,117,109,97,58,32,102,117,108,108,45,114,101,115,32,98,117,102,102,101,114,32,116,111,32,100,111,119,110,32,115,99,97,108,101,32,105,109,97,103,101,44,32,97,110,100,32,116,111,32,112,97,99,107,101,100,32,104,112,101,108,32,105,109,97,103,101,10,42,10,42,32,45,45,10,42,10,42,32,102,101,110,99,95,105,109,103,32,105,115,32,97,110,32,111,117,116,112,117,116,32,105,109,97,103,101,32,40,97,114,101,97,32,111,102,32,109,101,109,111,114,121,32,114,101,102,101,114,101,110,99,101,100,32,116,104,114,111,117,103,104,32,97,32,116,101,120,116,117,114,101,10,42,32,99,97,99,104,101,41,46,32,65,32,114,101,97,100,32,111,102,32,97,110,121,32,112,105,120,101,108,32,108,111,99,97,116,105,111,110,32,40,120,44,121,41,32,114,101,116,117,114,110,115,32,102,111,117,114,32,112,105,120,101,108,32,118,97,108,117,101,115,58,10,42,10,42,32,118,97,108,46,115,48,32,61,32,80,40,120,44,121,41,10,42,32,118,97,108,46,115,49,32,61,32,80,40,120,43,49,44,121,41,10,42,32,118,97,108,46,115,50,32,61,32,80,40,120,43,50,44,121,41,10,42,32,118,97,108,46,115,51,32,61,32,80,40,120,43,51,44,121,41,10,42,10,42,32,84,104,105,115,32,105,115,32,97,32,52,120,32,114,101,112,108,105,99,97,116,105,111,110,32,111,102,32,116,104,101,32,108,111,119,114,101,115,32,112,105,120,101,108,115,44,32,97,32,116,114,97,100,101,45,111,102,102,32,98,101,116,119,101,101,110,32,109,101,109,111,114,121,10,42,32,115,105,122,101,32,97,110,100,32,114,101,97,100,32,108,97,116,101,110,99,121,46,10,42,10,42,32,45,45,10,42,10,42,32,104,112,101,108,95,112,108,97,110,101,115,32,105,115,32,97,110,32,111,117,116,112,117,116,32,105,109,97,103,101,32,116,104,97,116,32,99,111,110,116,97,105,110,115,32,116,104,101,32,102,111,117,114,32,72,80,69,76,32,112,108,97,110,101,115,32,117,115,101,100,32,102,111,114,10,42,32,115,117,98,112,101,108,32,114,101,102,105,110,101,109,101,110,116,46,32,65,32,114,101,97,100,32,111,102,32,97,110,121,32,112,105,120,101,108,32,108,111,99,97,116,105,111,110,32,40,120,44,121,41,32,114,101,116,117,114,110,115,32,97,32,85,73,110,116,51,50,32,119,105,116,104,10,42,32,116,104,101,32,102,111,117,114,32,112,108,97,110,97,114,32,118,97,108,117,101,115,32,67,32,124,32,86,32,124,32,72,32,124,32,70,10,42,10,42,32,108,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,58,32,32,91,108,111,119,114,101,115,45,119,105,100,116,104,44,32,108,111,119,114,101,115,45,104,101,105,103,104,116,93,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,100,111,119,110,115,99,97,108,101,95,104,112,101,108,40,32,99,111,110,115,116,32,103,108,111,98,97,108,32,112,105,120,101,108,32,42,102,101,110,99,44,10,119,114,105,116,101,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,101,110,99,95,105,109,103,44,10,119,114,105,116,101,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,104,112,101,108,95,112,108,97,110,101,115,44,10,105,110,116,32,115,116,114,105,100,101,32,41,10,123,10,105,110,116,32,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,105,110,116,32,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,117,105,110,116,52,32,118,97,108,117,101,115,59,10,102,101,110,99,32,43,61,32,121,32,42,32,115,116,114,105,100,101,32,42,32,50,59,10,99,111,110,115,116,32,103,108,111,98,97,108,32,112,105,120,101,108,32,42,115,114,99,49,32,61,32,102,101,110,99,32,43,32,115,116,114,105,100,101,59,10,99,111,110,115,116,32,103,108,111,98,97,108,32,112,105,120,101,108,32,42,115,114,99,50,32,61,32,40,121,32,61,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,49,32,41,45,49,41,32,63,32,115,114,99,49,32,58,32,115,114,99,49,32,43,32,115,116,114,105,100,101,59,10,105,110,116,50,32,112,111,115,32,61,32,40,105,110,116,50,41,40,120,44,32,121,41,59,10,112,105,120,101,108,32,114,105,103,104,116,44,32,108,101,102,116,59,10,114,105,103,104,116,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,120,42,50,93,44,32,115,114,99,49,91,120,42,50,93,32,41,59,10,108,101,102,116,32,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,120,42,50,43,49,93,44,32,115,114,99,49,91,120,42,50,43,49,93,32,41,59,10,118,97,108,117,101,115,46,115,48,32,61,32,114,104,97,100,100,40,32,114,105,103,104,116,44,32,108,101,102,116,32,41,59,32,32,32,32,32,32,32,32,32,32,32,47,47,32,70,10,114,105,103,104,116,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,50,42,120,43,49,93,44,32,115,114,99,49,91,50,42,120,43,49,93,32,41,59,10,108,101,102,116,32,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,50,42,120,43,50,93,44,32,115,114,99,49,91,50,42,120,43,50,93,32,41,59,10,118,97,108,117,101,115,46,115,49,32,61,32,114,104,97,100,100,40,32,114,105,103,104,116,44,32,108,101,102,116,32,41,59,32,32,32,32,32,32,32,32,32,32,32,47,47,32,72,10,114,105,103,104,116,32,61,32,114,104,97,100,100,40,32,115,114,99,49,91,50,42,120,93,44,32,115,114,99,50,91,50,42,120,93,32,41,59,10,108,101,102,116,32,32,61,32,114,104,97,100,100,40,32,115,114,99,49,91,50,42,120,43,49,93,44,32,115,114,99,50,91,50,42,120,43,49,93,32,41,59,10,118,97,108,117,101,115,46,115,50,32,61,32,114,104,97,100,100,40,32,114,105,103,104,116,44,32,108,101,102,116,32,41,59,32,32,32,32,32,32,32,32,32,32,32,47,47,32,86,10,114,105,103,104,116,32,61,32,114,104,97,100,100,40,32,115,114,99,49,91,50,42,120,43,49,93,44,32,115,114,99,50,91,50,42,120,43,49,93,32,41,59,10,108,101,102,116,32,32,61,32,114,104,97,100,100,40,32,115,114,99,49,91,50,42,120,43,50,93,44,32,115,114,99,50,91,50,42,120,43,50,93,32,41,59,10,118,97,108,117,101,115,46,115,51,32,61,32,114,104,97,100,100,40,32,114,105,103,104,116,44,32,108,101,102,116,32,41,59,32,32,32,32,32,32,32,32,32,32,32,47,47,32,67,10,117,105,110,116,52,32,118,97,108,32,61,32,40,117,105,110,116,52,41,32,40,40,118,97,108,117,101,115,46,115,51,32,38,32,48,120,102,102,41,32,60,60,32,50,52,41,32,124,32,40,40,118,97,108,117,101,115,46,115,50,32,38,32,48,120,102,102,41,32,60,60,32,49,54,41,32,124,32,40,40,118,97,108,117,101,115,46,115,49,32,38,32,48,120,102,102,41,32,60,60,32,56,41,32,124,32,40,118,97,108,117,101,115,46,115,48,32,38,32,48,120,102,102,41,59,10,119,114,105,116,101,95,105,109,97,103,101,117,105,40,32,104,112,101,108,95,112,108,97,110,101,115,44,32,112,111,115,44,32,118,97,108,32,41,59,10,120,32,61,32,115,101,108,101,99,116,40,32,120,44,32,120,43,49,44,32,120,43,49,32,60,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,48,32,41,32,41,59,10,114,105,103,104,116,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,120,42,50,93,44,32,115,114,99,49,91,120,42,50,93,32,41,59,10,108,101,102,116,32,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,120,42,50,43,49,93,44,32,115,114,99,49,91,120,42,50,43,49,93,32,41,59,10,118,97,108,117,101,115,46,115,49,32,61,32,114,104,97,100,100,40,32,114,105,103,104,116,44,32,108,101,102,116,32,41,59,10,120,32,61,32,115,101,108,101,99,116,40,32,120,44,32,120,43,49,44,32,120,43,49,32,60,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,48,32,41,32,41,59,10,114,105,103,104,116,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,120,42,50,93,44,32,115,114,99,49,91,120,42,50,93,32,41,59,10,108,101,102,116,32,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,120,42,50,43,49,93,44,32,115,114,99,49,91,120,42,50,43,49,93,32,41,59,10,118,97,108,117,101,115,46,115,50,32,61,32,114,104,97,100,100,40,32,114,105,103,104,116,44,32,108,101,102,116,32,41,59,10,120,32,61,32,115,101,108,101,99,116,40,32,120,44,32,120,43,49,44,32,120,43,49,32,60,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,48,32,41,32,41,59,10,114,105,103,104,116,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,120,42,50,93,44,32,115,114,99,49,91,120,42,50,93,32,41,59,10,108,101,102,116,32,32,61,32,114,104,97,100,100,40,32,102,101,110,99,91,120,42,50,43,49,93,44,32,115,114,99,49,91,120,42,50,43,49,93,32,41,59,10,118,97,108,117,101,115,46,115,51,32,61,32,114,104,97,100,100,40,32,114,105,103,104,116,44,32,108,101,102,116,32,41,59,10,119,114,105,116,101,95,105,109,97,103,101,117,105,40,32,102,101,110,99,95,105,109,103,44,32,112,111,115,44,32,118,97,108,117,101,115,32,41,59,10,125,10,47,42,10,42,32,100,111,119,110,115,99,97,108,101,32,108,111,119,114,101,115,32,104,105,101,114,97,114,99,104,105,99,97,108,32,109,111,116,105,111,110,32,115,101,97,114,99,104,32,105,109,97,103,101,44,32,99,111,112,121,32,102,114,111,109,32,111,110,101,32,105,109,97,103,101,32,116,111,10,42,32,97,110,111,116,104,101,114,32,100,101,99,105,109,97,116,101,100,32,105,109,97,103,101,46,32,32,84,104,105,115,32,107,101,114,110,101,108,32,105,115,32,99,97,108,108,101,100,32,105,116,101,114,97,116,105,118,101,108,121,32,116,111,32,103,101,110,101,114,97,116,101,32,97,108,108,10,42,32,111,102,32,116,104,101,32,100,111,119,110,115,99,97,108,101,115,46,10,42,10,42,32,108,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,58,32,32,91,108,111,119,101,114,95,114,101,115,32,119,105,100,116,104,44,32,108,111,119,101,114,95,114,101,115,32,104,101,105,103,104,116,93,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,100,111,119,110,115,99,97,108,101,49,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,104,105,103,104,101,114,95,114,101,115,44,32,119,114,105,116,101,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,108,111,119,101,114,95,114,101,115,32,41,10,123,10,105,110,116,32,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,105,110,116,32,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,50,32,112,111,115,32,61,32,40,105,110,116,50,41,40,120,44,32,121,41,59,10,105,110,116,32,103,115,32,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,48,32,41,59,10,117,105,110,116,52,32,116,111,112,44,32,98,111,116,44,32,118,97,108,117,101,115,59,10,116,111,112,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,104,105,103,104,101,114,95,114,101,115,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,42,50,44,32,50,42,121,41,32,41,59,10,98,111,116,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,104,105,103,104,101,114,95,114,101,115,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,42,50,44,32,50,42,121,43,49,41,32,41,59,10,118,97,108,117,101,115,46,115,48,32,61,32,114,104,97,100,100,40,32,114,104,97,100,100,40,32,116,111,112,46,115,48,44,32,98,111,116,46,115,48,32,41,44,32,114,104,97,100,100,40,32,116,111,112,46,115,49,44,32,98,111,116,46,115,49,32,41,32,41,59,10,47,42,32,116,104,101,115,101,32,115,101,108,101,99,116,32,115,116,97,116,101,109,101,110,116,115,32,97,112,112,101,97,114,32,114,101,100,117,110,100,97,110,116,44,32,97,110,100,32,116,104,101,121,32,115,104,111,117,108,100,32,98,101,44,32,98,117,116,32,116,101,115,116,115,32,98,114,101,97,107,32,119,104,101,110,10,42,32,116,104,101,121,32,97,114,101,32,110,111,116,32,104,101,114,101,46,32,32,73,32,98,101,108,105,101,118,101,32,116,104,105,115,32,119,97,115,32,99,97,117,115,101,100,32,98,121,32,97,32,100,114,105,118,101,114,32,98,117,103,10,42,47,10,118,97,108,117,101,115,46,115,49,32,61,32,115,101,108,101,99,116,40,32,118,97,108,117,101,115,46,115,48,44,32,114,104,97,100,100,40,32,114,104,97,100,100,40,32,116,111,112,46,115,50,44,32,98,111,116,46,115,50,32,41,44,32,114,104,97,100,100,40,32,116,111,112,46,115,51,44,32,98,111,116,46,115,51,32,41,32,41,44,32,40,32,120,32,43,32,49,32,60,32,103,115,41,32,41,59,10,116,111,112,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,104,105,103,104,101,114,95,114,101,115,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,42,50,43,52,44,32,50,42,121,41,32,41,59,10,98,111,116,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,104,105,103,104,101,114,95,114,101,115,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,42,50,43,52,44,32,50,42,121,43,49,41,32,41,59,10,118,97,108,117,101,115,46,115,50,32,61,32,115,101,108,101,99,116,40,32,118,97,108,117,101,115,46,115,49,44,32,114,104,97,100,100,40,32,114,104,97,100,100,40,32,116,111,112,46,115,48,44,32,98,111,116,46,115,48,32,41,44,32,114,104,97,100,100,40,32,116,111,112,46,115,49,44,32,98,111,116,46,115,49,32,41,32,41,44,32,40,32,120,32,43,32,50,32,60,32,103,115,32,41,32,41,59,10,118,97,108,117,101,115,46,115,51,32,61,32,115,101,108,101,99,116,40,32,118,97,108,117,101,115,46,115,50,44,32,114,104,97,100,100,40,32,114,104,97,100,100,40,32,116,111,112,46,115,50,44,32,98,111,116,46,115,50,32,41,44,32,114,104,97,100,100,40,32,116,111,112,46,115,51,44,32,98,111,116,46,115,51,32,41,32,41,44,32,40,32,120,32,43,32,51,32,60,32,103,115,32,41,32,41,59,10,119,114,105,116,101,95,105,109,97,103,101,117,105,40,32,108,111,119,101,114,95,114,101,115,44,32,112,111,115,44,32,40,117,105,110,116,52,41,40,118,97,108,117,101,115,41,32,41,59,10,125,10,47,42,10,42,32,83,101,99,111,110,100,32,99,111,112,121,32,111,102,32,100,111,119,110,115,99,97,108,101,32,107,101,114,110,101,108,44,32,110,111,32,100,105,102,102,101,114,101,110,99,101,115,46,32,84,104,105,115,32,105,115,32,97,32,40,110,111,32,112,101,114,102,32,108,111,115,115,41,10,42,32,119,111,114,107,97,114,111,117,110,100,32,102,111,114,32,97,32,115,99,104,101,100,117,108,105,110,103,32,98,117,103,32,105,110,32,99,117,114,114,101,110,116,32,84,97,104,105,116,105,32,100,114,105,118,101,114,115,46,32,32,84,104,105,115,32,98,117,103,32,104,97,115,10,42,32,116,104,101,111,114,101,116,105,99,97,108,108,121,32,98,101,101,110,32,102,105,120,101,100,32,105,110,32,116,104,101,32,74,117,108,121,32,50,48,49,50,32,100,114,105,118,101,114,32,114,101,108,101,97,115,101,32,102,114,111,109,32,65,77,68,46,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,100,111,119,110,115,99,97,108,101,50,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,104,105,103,104,101,114,95,114,101,115,44,32,119,114,105,116,101,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,108,111,119,101,114,95,114,101,115,32,41,10,123,10,105,110,116,32,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,105,110,116,32,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,50,32,112,111,115,32,61,32,40,105,110,116,50,41,40,120,44,32,121,41,59,10,105,110,116,32,103,115,32,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,48,32,41,59,10,117,105,110,116,52,32,116,111,112,44,32,98,111,116,44,32,118,97,108,117,101,115,59,10,116,111,112,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,104,105,103,104,101,114,95,114,101,115,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,42,50,44,32,50,42,121,41,32,41,59,10,98,111,116,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,104,105,103,104,101,114,95,114,101,115,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,42,50,44,32,50,42,121,43,49,41,32,41,59,10,118,97,108,117,101,115,46,115,48,32,61,32,114,104,97,100,100,40,32,114,104,97,100,100,40,32,116,111,112,46,115,48,44,32,98,111,116,46,115,48,32,41,44,32,114,104,97,100,100,40,32,116,111,112,46,115,49,44,32,98,111,116,46,115,49,32,41,32,41,59,10,118,97,108,117,101,115,46,115,49,32,61,32,115,101,108,101,99,116,40,32,118,97,108,117,101,115,46,115,48,44,32,114,104,97,100,100,40,32,114,104,97,100,100,40,32,116,111,112,46,115,50,44,32,98,111,116,46,115,50,32,41,44,32,114,104,97,100,100,40,32,116,111,112,46,115,51,44,32,98,111,116,46,115,51,32,41,32,41,44,32,40,32,120,32,43,32,49,32,60,32,103,115,41,32,41,59,10,116,111,112,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,104,105,103,104,101,114,95,114,101,115,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,42,50,43,52,44,32,50,42,121,41,32,41,59,10,98,111,116,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,104,105,103,104,101,114,95,114,101,115,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,42,50,43,52,44,32,50,42,121,43,49,41,32,41,59,10,118,97,108,117,101,115,46,115,50,32,61,32,115,101,108,101,99,116,40,32,118,97,108,117,101,115,46,115,49,44,32,114,104,97,100,100,40,32,114,104,97,100,100,40,32,116,111,112,46,115,48,44,32,98,111,116,46,115,48,32,41,44,32,114,104,97,100,100,40,32,116,111,112,46,115,49,44,32,98,111,116,46,115,49,32,41,32,41,44,32,40,32,120,32,43,32,50,32,60,32,103,115,32,41,32,41,59,10,118,97,108,117,101,115,46,115,51,32,61,32,115,101,108,101,99,116,40,32,118,97,108,117,101,115,46,115,50,44,32,114,104,97,100,100,40,32,114,104,97,100,100,40,32,116,111,112,46,115,50,44,32,98,111,116,46,115,50,32,41,44,32,114,104,97,100,100,40,32,116,111,112,46,115,51,44,32,98,111,116,46,115,51,32,41,32,41,44,32,40,32,120,32,43,32,51,32,60,32,103,115,32,41,32,41,59,10,119,114,105,116,101,95,105,109,97,103,101,117,105,40,32,108,111,119,101,114,95,114,101,115,44,32,112,111,115,44,32,40,117,105,110,116,52,41,40,118,97,108,117,101,115,41,32,41,59,10,125,10,47,42,32,79,112,101,110,67,76,32,49,46,50,32,102,105,110,97,108,108,121,32,97,100,100,101,100,32,97,32,109,101,109,115,101,116,32,99,111,109,109,97,110,100,44,32,98,117,116,32,119,101,39,114,101,32,110,111,116,32,116,97,114,103,101,116,105,110,103,32,49,46,50,32,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,109,101,109,115,101,116,95,105,110,116,49,54,40,32,103,108,111,98,97,108,32,105,110,116,49,54,95,116,32,42,98,117,102,44,32,105,110,116,49,54,95,116,32,118,97,108,117,101,32,41,10,123,10,98,117,102,91,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,93,32,61,32,118,97,108,117,101,59,10,125,10,47,42,32,76,111,111,107,97,104,101,97,100,32,108,111,119,114,101,115,32,105,110,116,114,97,32,97,110,97,108,121,115,105,115,10,42,10,42,32,69,97,99,104,32,105,110,116,114,97,32,97,110,97,108,121,115,105,115,32,102,117,110,99,116,105,111,110,32,104,97,115,32,98,101,101,110,32,105,109,112,108,101,109,101,110,116,101,100,32,116,119,105,99,101,44,32,111,110,99,101,32,102,111,114,32,115,99,97,108,97,114,32,71,80,85,115,10,42,32,40,78,86,41,32,97,110,100,32,111,110,99,101,32,102,111,114,32,118,101,99,116,111,114,105,122,101,100,32,71,80,85,115,32,40,65,77,68,32,112,114,101,45,83,111,117,116,104,101,114,110,32,73,115,108,97,110,100,115,41,46,32,32,120,50,54,52,32,100,101,116,101,99,116,115,10,42,32,116,104,101,32,71,80,85,32,116,121,112,101,32,97,110,100,32,115,101,116,115,32,116,104,101,32,45,68,86,69,67,84,79,82,73,90,69,32,99,111,109,112,105,108,101,32,102,108,97,103,32,97,99,99,111,114,100,105,110,103,108,121,46,10,42,10,42,32,65,108,108,32,116,104,101,32,105,110,116,114,97,32,97,110,97,108,121,115,105,115,32,102,117,110,99,116,105,111,110,115,32,119,101,114,101,32,98,97,115,101,100,32,111,110,32,116,104,101,105,114,32,67,32,118,101,114,115,105,111,110,115,32,105,110,32,112,105,120,101,108,46,99,10,42,32,97,110,100,32,112,114,111,100,117,99,101,32,116,104,101,32,101,120,97,99,116,32,115,97,109,101,32,114,101,115,117,108,116,115,46,10,42,47,10,47,42,32,102,111,114,99,101,32,97,108,108,32,99,108,97,109,112,32,97,114,103,117,109,101,110,116,115,32,97,110,100,32,114,101,116,117,114,110,32,118,97,108,117,101,32,116,111,32,105,110,116,44,32,112,114,101,118,101,110,116,32,97,109,98,105,103,117,111,117,115,32,116,121,112,101,115,32,42,47,10,35,100,101,102,105,110,101,32,99,108,97,109,112,95,105,110,116,40,32,88,44,32,77,73,78,44,32,77,65,88,32,41,32,40,105,110,116,41,32,99,108,97,109,112,40,32,40,105,110,116,41,40,88,41,44,32,40,105,110,116,41,40,77,73,78,41,44,32,40,105,110,116,41,40,77,65,88,41,32,41,10,35,105,102,32,86,69,67,84,79,82,73,90,69,10,105,110,116,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,100,97,116,97,44,32,105,110,116,32,100,97,116,97,95,115,116,114,105,100,101,44,32,105,110,116,56,32,112,114,48,44,32,105,110,116,56,32,112,114,49,44,32,105,110,116,56,32,112,114,50,44,32,105,110,116,56,32,112,114,51,32,41,10,123,10,105,110,116,56,32,97,95,118,44,32,100,95,118,59,10,105,110,116,50,32,116,109,112,48,48,44,32,116,109,112,48,49,44,32,116,109,112,48,50,44,32,116,109,112,48,51,44,32,116,109,112,49,48,44,32,116,109,112,49,49,44,32,116,109,112,49,50,44,32,116,109,112,49,51,59,10,105,110,116,50,32,116,109,112,50,48,44,32,116,109,112,50,49,44,32,116,109,112,50,50,44,32,116,109,112,50,51,44,32,116,109,112,51,48,44,32,116,109,112,51,49,44,32,116,109,112,51,50,44,32,116,109,112,51,51,59,10,100,95,118,32,61,32,99,111,110,118,101,114,116,95,105,110,116,56,40,32,118,108,111,97,100,56,40,32,48,44,32,100,97,116,97,32,41,32,41,59,10,97,95,118,46,115,48,49,50,51,52,53,54,55,32,61,32,40,100,95,118,32,45,32,112,114,48,41,46,115,48,52,49,53,50,54,51,55,59,10,72,65,68,65,77,65,82,68,52,86,40,32,116,109,112,48,48,44,32,116,109,112,48,49,44,32,116,109,112,48,50,44,32,116,109,112,48,51,44,32,97,95,118,46,108,111,46,108,111,44,32,97,95,118,46,108,111,46,104,105,44,32,97,95,118,46,104,105,46,108,111,44,32,97,95,118,46,104,105,46,104,105,32,41,59,10,100,97,116,97,32,43,61,32,100,97,116,97,95,115,116,114,105,100,101,59,10,100,95,118,32,61,32,99,111,110,118,101,114,116,95,105,110,116,56,40,32,118,108,111,97,100,56,40,32,48,44,32,100,97,116,97,32,41,32,41,59,10,97,95,118,46,115,48,49,50,51,52,53,54,55,32,61,32,40,100,95,118,32,45,32,112,114,49,41,46,115,48,52,49,53,50,54,51,55,59,10,72,65,68,65,77,65,82,68,52,86,40,32,116,109,112,49,48,44,32,116,109,112,49,49,44,32,116,109,112,49,50,44,32,116,109,112,49,51,44,32,97,95,118,46,108,111,46,108,111,44,32,97,95,118,46,108,111,46,104,105,44,32,97,95,118,46,104,105,46,108,111,44,32,97,95,118,46,104,105,46,104,105,32,41,59,10,100,97,116,97,32,43,61,32,100,97,116,97,95,115,116,114,105,100,101,59,10,100,95,118,32,61,32,99,111,110,118,101,114,116,95,105,110,116,56,40,32,118,108,111,97,100,56,40,32,48,44,32,100,97,116,97,32,41,32,41,59,10,97,95,118,46,115,48,49,50,51,52,53,54,55,32,61,32,40,100,95,118,32,45,32,112,114,50,41,46,115,48,52,49,53,50,54,51,55,59,10,72,65,68,65,77,65,82,68,52,86,40,32,116,109,112,50,48,44,32,116,109,112,50,49,44,32,116,109,112,50,50,44,32,116,109,112,50,51,44,32,97,95,118,46,108,111,46,108,111,44,32,97,95,118,46,108,111,46,104,105,44,32,97,95,118,46,104,105,46,108,111,44,32,97,95,118,46,104,105,46,104,105,32,41,59,10,100,97,116,97,32,43,61,32,100,97,116,97,95,115,116,114,105,100,101,59,10,100,95,118,32,61,32,99,111,110,118,101,114,116,95,105,110,116,56,40,32,118,108,111,97,100,56,40,32,48,44,32,100,97,116,97,32,41,32,41,59,10,97,95,118,46,115,48,49,50,51,52,53,54,55,32,61,32,40,100,95,118,32,45,32,112,114,51,41,46,115,48,52,49,53,50,54,51,55,59,10,72,65,68,65,77,65,82,68,52,86,40,32,116,109,112,51,48,44,32,116,109,112,51,49,44,32,116,109,112,51,50,44,32,116,109,112,51,51,44,32,97,95,118,46,108,111,46,108,111,44,32,97,95,118,46,108,111,46,104,105,44,32,97,95,118,46,104,105,46,108,111,44,32,97,95,118,46,104,105,46,104,105,32,41,59,10,117,105,110,116,56,32,115,117,109,95,118,59,10,72,65,68,65,77,65,82,68,52,86,40,32,97,95,118,46,108,111,46,108,111,44,32,97,95,118,46,108,111,46,104,105,44,32,97,95,118,46,104,105,46,108,111,44,32,97,95,118,46,104,105,46,104,105,44,32,116,109,112,48,48,44,32,116,109,112,49,48,44,32,116,109,112,50,48,44,32,116,109,112,51,48,32,41,59,10,115,117,109,95,118,32,61,32,97,98,115,40,32,97,95,118,32,41,59,10,72,65,68,65,77,65,82,68,52,86,40,32,97,95,118,46,108,111,46,108,111,44,32,97,95,118,46,108,111,46,104,105,44,32,97,95,118,46,104,105,46,108,111,44,32,97,95,118,46,104,105,46,104,105,44,32,116,109,112,48,49,44,32,116,109,112,49,49,44,32,116,109,112,50,49,44,32,116,109,112,51,49,32,41,59,10,115,117,109,95,118,32,43,61,32,97,98,115,40,32,97,95,118,32,41,59,10,72,65,68,65,77,65,82,68,52,86,40,32,97,95,118,46,108,111,46,108,111,44,32,97,95,118,46,108,111,46,104,105,44,32,97,95,118,46,104,105,46,108,111,44,32,97,95,118,46,104,105,46,104,105,44,32,116,109,112,48,50,44,32,116,109,112,49,50,44,32,116,109,112,50,50,44,32,116,109,112,51,50,32,41,59,10,115,117,109,95,118,32,43,61,32,97,98,115,40,32,97,95,118,32,41,59,10,72,65,68,65,77,65,82,68,52,86,40,32,97,95,118,46,108,111,46,108,111,44,32,97,95,118,46,108,111,46,104,105,44,32,97,95,118,46,104,105,46,108,111,44,32,97,95,118,46,104,105,46,104,105,44,32,116,109,112,48,51,44,32,116,109,112,49,51,44,32,116,109,112,50,51,44,32,116,109,112,51,51,32,41,59,10,115,117,109,95,118,32,43,61,32,97,98,115,40,32,97,95,118,32,41,59,10,117,105,110,116,52,32,115,117,109,50,32,61,32,115,117,109,95,118,46,104,105,32,43,32,115,117,109,95,118,46,108,111,59,10,117,105,110,116,50,32,115,117,109,51,32,61,32,115,117,109,50,46,104,105,32,43,32,115,117,109,50,46,108,111,59,10,114,101,116,117,114,110,32,40,32,115,117,109,51,46,104,105,32,43,32,115,117,109,51,46,108,111,32,41,32,62,62,32,49,59,10,125,10,35,101,108,115,101,10,83,65,84,68,95,67,95,56,120,52,95,81,40,32,115,97,116,100,95,56,120,52,95,108,112,44,32,99,111,110,115,116,32,108,111,99,97,108,44,32,112,114,105,118,97,116,101,32,41,10,35,101,110,100,105,102,10,47,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,10,42,32,56,120,56,32,112,114,101,100,105,99,116,105,111,110,32,102,111,114,32,105,110,116,114,97,32,108,117,109,97,32,98,108,111,99,107,10,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,42,47,10,35,100,101,102,105,110,101,32,70,49,32,32,32,32,32,32,32,32,32,32,32,32,114,104,97,100,100,10,35,100,101,102,105,110,101,32,70,50,40,32,97,44,32,98,44,32,99,32,41,32,40,32,97,43,50,42,98,43,99,43,50,32,41,62,62,50,10,35,105,102,32,86,69,67,84,79,82,73,90,69,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,100,100,108,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,32,41,10,123,10,105,110,116,56,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,59,10,112,114,48,46,115,48,32,61,32,40,32,50,32,43,32,116,111,112,91,48,93,32,43,32,50,42,116,111,112,91,49,93,32,43,32,116,111,112,91,50,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,49,32,61,32,40,32,50,32,43,32,116,111,112,91,49,93,32,43,32,50,42,116,111,112,91,50,93,32,43,32,116,111,112,91,51,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,50,32,61,32,40,32,50,32,43,32,116,111,112,91,50,93,32,43,32,50,42,116,111,112,91,51,93,32,43,32,116,111,112,91,52,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,51,32,61,32,40,32,50,32,43,32,116,111,112,91,51,93,32,43,32,50,42,116,111,112,91,52,93,32,43,32,116,111,112,91,53,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,52,32,61,32,40,32,50,32,43,32,116,111,112,91,52,93,32,43,32,50,42,116,111,112,91,53,93,32,43,32,116,111,112,91,54,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,53,32,61,32,40,32,50,32,43,32,116,111,112,91,53,93,32,43,32,50,42,116,111,112,91,54,93,32,43,32,116,111,112,91,55,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,54,32,61,32,40,32,50,32,43,32,116,111,112,91,54,93,32,43,32,50,42,116,111,112,91,55,93,32,43,32,116,111,112,91,56,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,55,32,61,32,40,32,50,32,43,32,116,111,112,91,55,93,32,43,32,50,42,116,111,112,91,56,93,32,43,32,116,111,112,91,57,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,48,32,61,32,40,32,50,32,43,32,116,111,112,91,49,93,32,43,32,50,42,116,111,112,91,50,93,32,43,32,116,111,112,91,51,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,49,32,61,32,40,32,50,32,43,32,116,111,112,91,50,93,32,43,32,50,42,116,111,112,91,51,93,32,43,32,116,111,112,91,52,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,50,32,61,32,40,32,50,32,43,32,116,111,112,91,51,93,32,43,32,50,42,116,111,112,91,52,93,32,43,32,116,111,112,91,53,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,51,32,61,32,40,32,50,32,43,32,116,111,112,91,52,93,32,43,32,50,42,116,111,112,91,53,93,32,43,32,116,111,112,91,54,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,52,32,61,32,40,32,50,32,43,32,116,111,112,91,53,93,32,43,32,50,42,116,111,112,91,54,93,32,43,32,116,111,112,91,55,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,53,32,61,32,40,32,50,32,43,32,116,111,112,91,54,93,32,43,32,50,42,116,111,112,91,55,93,32,43,32,116,111,112,91,56,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,54,32,61,32,40,32,50,32,43,32,116,111,112,91,55,93,32,43,32,50,42,116,111,112,91,56,93,32,43,32,116,111,112,91,57,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,55,32,61,32,40,32,50,32,43,32,116,111,112,91,56,93,32,43,32,50,42,116,111,112,91,57,93,32,43,32,116,111,112,91,49,48,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,48,32,61,32,40,32,50,32,43,32,116,111,112,91,50,93,32,43,32,50,42,116,111,112,91,51,93,32,43,32,116,111,112,91,52,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,49,32,61,32,40,32,50,32,43,32,116,111,112,91,51,93,32,43,32,50,42,116,111,112,91,52,93,32,43,32,116,111,112,91,53,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,50,32,61,32,40,32,50,32,43,32,116,111,112,91,52,93,32,43,32,50,42,116,111,112,91,53,93,32,43,32,116,111,112,91,54,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,51,32,61,32,40,32,50,32,43,32,116,111,112,91,53,93,32,43,32,50,42,116,111,112,91,54,93,32,43,32,116,111,112,91,55,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,52,32,61,32,40,32,50,32,43,32,116,111,112,91,54,93,32,43,32,50,42,116,111,112,91,55,93,32,43,32,116,111,112,91,56,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,53,32,61,32,40,32,50,32,43,32,116,111,112,91,55,93,32,43,32,50,42,116,111,112,91,56,93,32,43,32,116,111,112,91,57,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,54,32,61,32,40,32,50,32,43,32,116,111,112,91,56,93,32,43,32,50,42,116,111,112,91,57,93,32,43,32,116,111,112,91,49,48,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,55,32,61,32,40,32,50,32,43,32,116,111,112,91,57,93,32,43,32,50,42,116,111,112,91,49,48,93,32,43,32,116,111,112,91,49,49,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,48,32,61,32,40,32,50,32,43,32,116,111,112,91,51,93,32,43,32,50,42,116,111,112,91,52,93,32,43,32,116,111,112,91,53,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,49,32,61,32,40,32,50,32,43,32,116,111,112,91,52,93,32,43,32,50,42,116,111,112,91,53,93,32,43,32,116,111,112,91,54,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,50,32,61,32,40,32,50,32,43,32,116,111,112,91,53,93,32,43,32,50,42,116,111,112,91,54,93,32,43,32,116,111,112,91,55,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,51,32,61,32,40,32,50,32,43,32,116,111,112,91,54,93,32,43,32,50,42,116,111,112,91,55,93,32,43,32,116,111,112,91,56,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,52,32,61,32,40,32,50,32,43,32,116,111,112,91,55,93,32,43,32,50,42,116,111,112,91,56,93,32,43,32,116,111,112,91,57,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,53,32,61,32,40,32,50,32,43,32,116,111,112,91,56,93,32,43,32,50,42,116,111,112,91,57,93,32,43,32,116,111,112,91,49,48,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,54,32,61,32,40,32,50,32,43,32,116,111,112,91,57,93,32,43,32,50,42,116,111,112,91,49,48,93,32,43,32,116,111,112,91,49,49,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,55,32,61,32,40,32,50,32,43,32,116,111,112,91,49,48,93,32,43,32,50,42,116,111,112,91,49,49,93,32,43,32,116,111,112,91,49,50,93,32,41,32,62,62,32,50,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,112,114,48,46,115,48,32,61,32,40,32,50,32,43,32,116,111,112,91,52,93,32,43,32,50,42,116,111,112,91,53,93,32,43,32,116,111,112,91,54,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,49,32,61,32,40,32,50,32,43,32,116,111,112,91,53,93,32,43,32,50,42,116,111,112,91,54,93,32,43,32,116,111,112,91,55,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,50,32,61,32,40,32,50,32,43,32,116,111,112,91,54,93,32,43,32,50,42,116,111,112,91,55,93,32,43,32,116,111,112,91,56,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,51,32,61,32,40,32,50,32,43,32,116,111,112,91,55,93,32,43,32,50,42,116,111,112,91,56,93,32,43,32,116,111,112,91,57,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,52,32,61,32,40,32,50,32,43,32,116,111,112,91,56,93,32,43,32,50,42,116,111,112,91,57,93,32,43,32,116,111,112,91,49,48,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,53,32,61,32,40,32,50,32,43,32,116,111,112,91,57,93,32,43,32,50,42,116,111,112,91,49,48,93,32,43,32,116,111,112,91,49,49,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,54,32,61,32,40,32,50,32,43,32,116,111,112,91,49,48,93,32,43,32,50,42,116,111,112,91,49,49,93,32,43,32,116,111,112,91,49,50,93,32,41,32,62,62,32,50,59,10,112,114,48,46,115,55,32,61,32,40,32,50,32,43,32,116,111,112,91,49,49,93,32,43,32,50,42,116,111,112,91,49,50,93,32,43,32,116,111,112,91,49,51,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,48,32,61,32,40,32,50,32,43,32,116,111,112,91,53,93,32,43,32,50,42,116,111,112,91,54,93,32,43,32,116,111,112,91,55,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,49,32,61,32,40,32,50,32,43,32,116,111,112,91,54,93,32,43,32,50,42,116,111,112,91,55,93,32,43,32,116,111,112,91,56,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,50,32,61,32,40,32,50,32,43,32,116,111,112,91,55,93,32,43,32,50,42,116,111,112,91,56,93,32,43,32,116,111,112,91,57,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,51,32,61,32,40,32,50,32,43,32,116,111,112,91,56,93,32,43,32,50,42,116,111,112,91,57,93,32,43,32,116,111,112,91,49,48,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,52,32,61,32,40,32,50,32,43,32,116,111,112,91,57,93,32,43,32,50,42,116,111,112,91,49,48,93,32,43,32,116,111,112,91,49,49,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,53,32,61,32,40,32,50,32,43,32,116,111,112,91,49,48,93,32,43,32,50,42,116,111,112,91,49,49,93,32,43,32,116,111,112,91,49,50,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,54,32,61,32,40,32,50,32,43,32,116,111,112,91,49,49,93,32,43,32,50,42,116,111,112,91,49,50,93,32,43,32,116,111,112,91,49,51,93,32,41,32,62,62,32,50,59,10,112,114,49,46,115,55,32,61,32,40,32,50,32,43,32,116,111,112,91,49,50,93,32,43,32,50,42,116,111,112,91,49,51,93,32,43,32,116,111,112,91,49,52,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,48,32,61,32,40,32,50,32,43,32,116,111,112,91,54,93,32,43,32,50,42,116,111,112,91,55,93,32,43,32,116,111,112,91,56,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,49,32,61,32,40,32,50,32,43,32,116,111,112,91,55,93,32,43,32,50,42,116,111,112,91,56,93,32,43,32,116,111,112,91,57,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,50,32,61,32,40,32,50,32,43,32,116,111,112,91,56,93,32,43,32,50,42,116,111,112,91,57,93,32,43,32,116,111,112,91,49,48,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,51,32,61,32,40,32,50,32,43,32,116,111,112,91,57,93,32,43,32,50,42,116,111,112,91,49,48,93,32,43,32,116,111,112,91,49,49,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,52,32,61,32,40,32,50,32,43,32,116,111,112,91,49,48,93,32,43,32,50,42,116,111,112,91,49,49,93,32,43,32,116,111,112,91,49,50,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,53,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+30720);
/* memory initializer */ allocate([61,32,40,32,50,32,43,32,116,111,112,91,49,49,93,32,43,32,50,42,116,111,112,91,49,50,93,32,43,32,116,111,112,91,49,51,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,54,32,61,32,40,32,50,32,43,32,116,111,112,91,49,50,93,32,43,32,50,42,116,111,112,91,49,51,93,32,43,32,116,111,112,91,49,52,93,32,41,32,62,62,32,50,59,10,112,114,50,46,115,55,32,61,32,40,32,50,32,43,32,116,111,112,91,49,51,93,32,43,32,50,42,116,111,112,91,49,52,93,32,43,32,116,111,112,91,49,53,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,48,32,61,32,40,32,50,32,43,32,116,111,112,91,55,93,32,43,32,50,42,116,111,112,91,56,93,32,43,32,116,111,112,91,57,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,49,32,61,32,40,32,50,32,43,32,116,111,112,91,56,93,32,43,32,50,42,116,111,112,91,57,93,32,43,32,116,111,112,91,49,48,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,50,32,61,32,40,32,50,32,43,32,116,111,112,91,57,93,32,43,32,50,42,116,111,112,91,49,48,93,32,43,32,116,111,112,91,49,49,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,51,32,61,32,40,32,50,32,43,32,116,111,112,91,49,48,93,32,43,32,50,42,116,111,112,91,49,49,93,32,43,32,116,111,112,91,49,50,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,52,32,61,32,40,32,50,32,43,32,116,111,112,91,49,49,93,32,43,32,50,42,116,111,112,91,49,50,93,32,43,32,116,111,112,91,49,51,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,53,32,61,32,40,32,50,32,43,32,116,111,112,91,49,50,93,32,43,32,50,42,116,111,112,91,49,51,93,32,43,32,116,111,112,91,49,52,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,54,32,61,32,40,32,50,32,43,32,116,111,112,91,49,51,93,32,43,32,50,42,116,111,112,91,49,52,93,32,43,32,116,111,112,91,49,53,93,32,41,32,62,62,32,50,59,10,112,114,51,46,115,55,32,61,32,40,32,50,32,43,32,116,111,112,91,49,52,93,32,43,32,51,42,116,111,112,91,49,53,93,32,41,32,62,62,32,50,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,100,100,114,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,108,101,102,116,44,32,112,105,120,101,108,32,108,101,102,116,95,116,111,112,32,41,10,123,10,105,110,116,56,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,59,10,112,114,51,46,115,48,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,10,112,114,50,46,115,48,32,61,32,112,114,51,46,115,49,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,10,112,114,49,46,115,48,32,61,32,112,114,50,46,115,49,32,61,32,112,114,51,46,115,50,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,10,112,114,48,46,115,48,32,61,32,112,114,49,46,115,49,32,61,32,112,114,50,46,115,50,32,61,32,112,114,51,46,115,51,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,112,114,48,46,115,49,32,61,32,112,114,49,46,115,50,32,61,32,112,114,50,46,115,51,32,61,32,112,114,51,46,115,52,32,61,32,70,50,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,112,114,48,46,115,50,32,61,32,112,114,49,46,115,51,32,61,32,112,114,50,46,115,52,32,61,32,112,114,51,46,115,53,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,48,46,115,51,32,61,32,112,114,49,46,115,52,32,61,32,112,114,50,46,115,53,32,61,32,112,114,51,46,115,54,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,112,114,48,46,115,52,32,61,32,112,114,49,46,115,53,32,61,32,112,114,50,46,115,54,32,61,32,112,114,51,46,115,55,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,48,46,115,53,32,61,32,112,114,49,46,115,54,32,61,32,112,114,50,46,115,55,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,112,114,48,46,115,54,32,61,32,112,114,49,46,115,55,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,112,114,48,46,115,55,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,112,114,51,46,115,48,32,61,32,70,50,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,59,10,112,114,50,46,115,48,32,61,32,112,114,51,46,115,49,32,61,32,70,50,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,59,10,112,114,49,46,115,48,32,61,32,112,114,50,46,115,49,32,61,32,112,114,51,46,115,50,32,61,32,70,50,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,10,112,114,48,46,115,48,32,61,32,112,114,49,46,115,49,32,61,32,112,114,50,46,115,50,32,61,32,112,114,51,46,115,51,32,61,32,70,50,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,10,112,114,48,46,115,49,32,61,32,112,114,49,46,115,50,32,61,32,112,114,50,46,115,51,32,61,32,112,114,51,46,115,52,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,10,112,114,48,46,115,50,32,61,32,112,114,49,46,115,51,32,61,32,112,114,50,46,115,52,32,61,32,112,114,51,46,115,53,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,10,112,114,48,46,115,51,32,61,32,112,114,49,46,115,52,32,61,32,112,114,50,46,115,53,32,61,32,112,114,51,46,115,54,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,10,112,114,48,46,115,52,32,61,32,112,114,49,46,115,53,32,61,32,112,114,50,46,115,54,32,61,32,112,114,51,46,115,55,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,112,114,48,46,115,53,32,61,32,112,114,49,46,115,54,32,61,32,112,114,50,46,115,55,32,61,32,70,50,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,112,114,48,46,115,54,32,61,32,112,114,49,46,115,55,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,48,46,115,55,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,118,114,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,108,101,102,116,44,32,112,105,120,101,108,32,108,101,102,116,95,116,111,112,32,41,10,123,10,105,110,116,56,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,59,10,112,114,50,46,115,48,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,10,112,114,51,46,115,48,32,61,32,70,50,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,32,41,59,10,112,114,49,46,115,48,32,61,32,112,114,51,46,115,49,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,112,114,48,46,115,48,32,61,32,112,114,50,46,115,49,32,61,32,70,49,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,112,114,49,46,115,49,32,61,32,112,114,51,46,115,50,32,61,32,70,50,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,112,114,48,46,115,49,32,61,32,112,114,50,46,115,50,32,61,32,70,49,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,112,114,49,46,115,50,32,61,32,112,114,51,46,115,51,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,48,46,115,50,32,61,32,112,114,50,46,115,51,32,61,32,70,49,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,49,46,115,51,32,61,32,112,114,51,46,115,52,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,112,114,48,46,115,51,32,61,32,112,114,50,46,115,52,32,61,32,70,49,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,112,114,49,46,115,52,32,61,32,112,114,51,46,115,53,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,48,46,115,52,32,61,32,112,114,50,46,115,53,32,61,32,70,49,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,49,46,115,53,32,61,32,112,114,51,46,115,54,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,112,114,48,46,115,53,32,61,32,112,114,50,46,115,54,32,61,32,70,49,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,112,114,49,46,115,54,32,61,32,112,114,51,46,115,55,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,112,114,48,46,115,54,32,61,32,112,114,50,46,115,55,32,61,32,70,49,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,112,114,49,46,115,55,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,112,114,48,46,115,55,32,61,32,70,49,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,112,114,50,46,115,48,32,61,32,70,50,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,51,93,32,41,59,10,112,114,51,46,115,48,32,61,32,70,50,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,52,93,32,41,59,10,112,114,48,46,115,48,32,61,32,112,114,50,46,115,49,32,61,32,70,50,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,49,93,32,41,59,10,112,114,49,46,115,48,32,61,32,112,114,51,46,115,49,32,61,32,70,50,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,50,93,32,41,59,10,112,114,48,46,115,49,32,61,32,112,114,50,46,115,50,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,10,112,114,49,46,115,49,32,61,32,112,114,51,46,115,50,32,61,32,70,50,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,32,41,59,10,112,114,49,46,115,50,32,61,32,112,114,51,46,115,51,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,112,114,48,46,115,50,32,61,32,112,114,50,46,115,51,32,61,32,70,49,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,112,114,49,46,115,51,32,61,32,112,114,51,46,115,52,32,61,32,70,50,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,112,114,48,46,115,51,32,61,32,112,114,50,46,115,52,32,61,32,70,49,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,112,114,49,46,115,52,32,61,32,112,114,51,46,115,53,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,48,46,115,52,32,61,32,112,114,50,46,115,53,32,61,32,70,49,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,49,46,115,53,32,61,32,112,114,51,46,115,54,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,112,114,48,46,115,53,32,61,32,112,114,50,46,115,54,32,61,32,70,49,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,112,114,49,46,115,54,32,61,32,112,114,51,46,115,55,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,48,46,115,54,32,61,32,112,114,50,46,115,55,32,61,32,70,49,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,49,46,115,55,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,112,114,48,46,115,55,32,61,32,70,49,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,35,117,110,100,101,102,32,80,82,69,68,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,104,100,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,108,101,102,116,44,32,112,105,120,101,108,32,108,101,102,116,95,116,111,112,32,41,10,123,10,105,110,116,56,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,59,10,112,114,48,46,115,48,32,61,32,70,49,40,32,108,101,102,116,95,116,111,112,44,32,108,101,102,116,91,48,93,32,41,59,32,112,114,48,46,115,49,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,95,116,111,112,32,43,32,116,111,112,91,48,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,50,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,32,112,114,48,46,115,51,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,48,93,32,41,59,10,112,114,48,46,115,52,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,49,93,32,41,59,32,112,114,48,46,115,53,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,48,46,115,54,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,51,93,32,41,59,32,112,114,48,46,115,55,32,61,32,70,50,40,32,116,111,112,91,54,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,49,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,32,41,59,32,112,114,49,46,115,49,32,61,32,40,108,101,102,116,95,116,111,112,32,43,32,50,32,42,32,108,101,102,116,91,48,93,32,43,32,108,101,102,116,91,49,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,50,32,61,32,70,49,40,32,108,101,102,116,95,116,111,112,44,32,108,101,102,116,91,48,93,32,41,59,32,112,114,49,46,115,51,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,95,116,111,112,32,43,32,116,111,112,91,48,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,52,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,32,112,114,49,46,115,53,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,48,93,32,41,59,10,112,114,49,46,115,54,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,49,93,32,41,59,32,112,114,49,46,115,55,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,50,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,32,112,114,50,46,115,49,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,91,49,93,32,43,32,108,101,102,116,91,50,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,32,41,59,32,112,114,50,46,115,51,32,61,32,40,108,101,102,116,95,116,111,112,32,43,32,50,32,42,32,108,101,102,116,91,48,93,32,43,32,108,101,102,116,91,49,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,52,32,61,32,70,49,40,32,108,101,102,116,95,116,111,112,44,32,108,101,102,116,91,48,93,32,41,59,32,112,114,50,46,115,53,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,95,116,111,112,32,43,32,116,111,112,91,48,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,54,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,32,112,114,50,46,115,55,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,48,93,32,41,59,10,112,114,51,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,32,112,114,51,46,115,49,32,61,32,40,108,101,102,116,91,49,93,32,43,32,50,32,42,32,108,101,102,116,91,50,93,32,43,32,108,101,102,116,91,51,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,32,112,114,51,46,115,51,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,91,49,93,32,43,32,108,101,102,116,91,50,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,32,41,59,32,112,114,51,46,115,53,32,61,32,40,108,101,102,116,95,116,111,112,32,43,32,50,32,42,32,108,101,102,116,91,48,93,32,43,32,108,101,102,116,91,49,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,54,32,61,32,70,49,40,32,108,101,102,116,95,116,111,112,44,32,108,101,102,116,91,48,93,32,41,59,32,112,114,51,46,115,55,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,95,116,111,112,32,43,32,116,111,112,91,48,93,32,43,32,50,41,32,62,62,32,50,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,112,114,48,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,32,112,114,48,46,115,49,32,61,32,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,32,112,114,48,46,115,51,32,61,32,40,108,101,102,116,91,49,93,32,43,32,50,32,42,32,108,101,102,116,91,50,93,32,43,32,108,101,102,116,91,51,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,32,112,114,48,46,115,53,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,91,49,93,32,43,32,108,101,102,116,91,50,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,54,32,61,32,70,49,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,32,41,59,32,112,114,48,46,115,55,32,61,32,40,108,101,102,116,95,116,111,112,32,43,32,50,32,42,32,108,101,102,116,91,48,93,32,43,32,108,101,102,116,91,49,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,32,112,114,49,46,115,49,32,61,32,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,32,112,114,49,46,115,51,32,61,32,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,32,112,114,49,46,115,53,32,61,32,40,108,101,102,116,91,49,93,32,43,32,50,32,42,32,108,101,102,116,91,50,93,32,43,32,108,101,102,116,91,51,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,54,32,61,32,70,49,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,32,112,114,49,46,115,55,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,91,49,93,32,43,32,108,101,102,116,91,50,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,59,32,112,114,50,46,115,49,32,61,32,40,108,101,102,116,91,52,93,32,43,32,50,32,42,32,108,101,102,116,91,53,93,32,43,32,108,101,102,116,91,54,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,32,112,114,50,46,115,51,32,61,32,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,32,112,114,50,46,115,53,32,61,32,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,54,32,61,32,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,32,112,114,50,46,115,55,32,61,32,40,108,101,102,116,91,49,93,32,43,32,50,32,42,32,108,101,102,116,91,50,93,32,43,32,108,101,102,116,91,51,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,59,32,112,114,51,46,115,49,32,61,32,40,108,101,102,116,91,53,93,32,43,32,50,32,42,32,108,101,102,116,91,54,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,59,32,112,114,51,46,115,51,32,61,32,40,108,101,102,116,91,52,93,32,43,32,50,32,42,32,108,101,102,116,91,53,93,32,43,32,108,101,102,116,91,54,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,32,112,114,51,46,115,53,32,61,32,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,54,32,61,32,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,32,112,114,51,46,115,55,32,61,32,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,118,108,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,32,41,10,123,10,105,110,116,56,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,59,10,112,114,48,46,115,48,32,61,32,70,49,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,112,114,49,46,115,48,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,50,46,115,48,32,61,32,112,114,48,46,115,49,32,61,32,70,49,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,112,114,51,46,115,48,32,61,32,112,114,49,46,115,49,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,112,114,50,46,115,49,32,61,32,112,114,48,46,115,50,32,61,32,70,49,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,112,114,51,46,115,49,32,61,32,112,114,49,46,115,50,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,50,46,115,50,32,61,32,112,114,48,46,115,51,32,61,32,70,49,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,51,46,115,50,32,61,32,112,114,49,46,115,51,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,112,114,50,46,115,51,32,61,32,112,114,48,46,115,52,32,61,32,70,49,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,112,114,51,46,115,51,32,61,32,112,114,49,46,115,52,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,112,114,50,46,115,52,32,61,32,112,114,48,46,115,53,32,61,32,70,49,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,112,114,51,46,115,52,32,61,32,112,114,49,46,115,53,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,112,114,50,46,115,53,32,61,32,112,114,48,46,115,54,32,61,32,70,49,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,112,114,51,46,115,53,32,61,32,112,114,49,46,115,54,32,61,32,70,50,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,32,41,59,10,112,114,50,46,115,54,32,61,32,112,114,48,46,115,55,32,61,32,70,49,40,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,32,41,59,10,112,114,51,46,115,54,32,61,32,112,114,49,46,115,55,32,61,32,70,50,40,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,32,41,59,10,112,114,50,46,115,55,32,61,32,70,49,40,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,32,41,59,10,112,114,51,46,115,55,32,61,32,70,50,40,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,44,32,116,111,112,91,49,48,93,32,41,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,112,114,48,46,115,48,32,61,32,70,49,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,112,114,49,46,115,48,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,50,46,115,48,32,61,32,112,114,48,46,115,49,32,61,32,70,49,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,112,114,51,46,115,48,32,61,32,112,114,49,46,115,49,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,112,114,50,46,115,49,32,61,32,112,114,48,46,115,50,32,61,32,70,49,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,112,114,51,46,115,49,32,61,32,112,114,49,46,115,50,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,112,114,50,46,115,50,32,61,32,112,114,48,46,115,51,32,61,32,70,49,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,112,114,51,46,115,50,32,61,32,112,114,49,46,115,51,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,112,114,50,46,115,51,32,61,32,112,114,48,46,115,52,32,61,32,70,49,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,112,114,51,46,115,51,32,61,32,112,114,49,46,115,52,32,61,32,70,50,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,32,41,59,10,112,114,50,46,115,52,32,61,32,112,114,48,46,115,53,32,61,32,70,49,40,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,32,41,59,10,112,114,51,46,115,52,32,61,32,112,114,49,46,115,53,32,61,32,70,50,40,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,32,41,59,10,112,114,50,46,115,53,32,61,32,112,114,48,46,115,54,32,61,32,70,49,40,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,32,41,59,10,112,114,51,46,115,53,32,61,32,112,114,49,46,115,54,32,61,32,70,50,40,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,44,32,116,111,112,91,49,48,93,32,41,59,10,112,114,50,46,115,54,32,61,32,112,114,48,46,115,55,32,61,32,70,49,40,32,116,111,112,91,57,93,44,32,116,111,112,91,49,48,93,32,41,59,10,112,114,51,46,115,54,32,61,32,112,114,49,46,115,55,32,61,32,70,50,40,32,116,111,112,91,57,93,44,32,116,111,112,91,49,48,93,44,32,116,111,112,91,49,49,93,32,41,59,10,112,114,50,46,115,55,32,61,32,70,49,40,32,116,111,112,91,49,48,93,44,32,116,111,112,91,49,49,93,32,41,59,10,112,114,51,46,115,55,32,61,32,70,50,40,32,116,111,112,91,49,48,93,44,32,116,111,112,91,49,49,93,44,32,116,111,112,91,49,50,93,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,104,117,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,108,101,102,116,32,41,10,123,10,105,110,116,56,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,59,10,112,114,48,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,32,41,59,32,112,114,48,46,115,49,32,61,32,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,91,49,93,32,43,32,108,101,102,116,91,50,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,32,112,114,48,46,115,51,32,61,32,40,108,101,102,116,91,49,93,32,43,32,50,32,42,32,108,101,102,116,91,50,93,32,43,32,108,101,102,116,91,51,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,32,112,114,48,46,115,53,32,61,32,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,54,32,61,32,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,32,112,114,48,46,115,55,32,61,32,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,32,112,114,49,46,115,49,32,61,32,40,108,101,102,116,91,49,93,32,43,32,50,32,42,32,108,101,102,116,91,50,93,32,43,32,108,101,102,116,91,51,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,32,112,114,49,46,115,51,32,61,32,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,32,112,114,49,46,115,53,32,61,32,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,54,32,61,32,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,32,112,114,49,46,115,55,32,61,32,40,108,101,102,116,91,52,93,32,43,32,50,32,42,32,108,101,102,116,91,53,93,32,43,32,108,101,102,116,91,54,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,32,112,114,50,46,115,49,32,61,32,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,32,112,114,50,46,115,51,32,61,32,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,32,112,114,50,46,115,53,32,61,32,40,108,101,102,116,91,52,93,32,43,32,50,32,42,32,108,101,102,116,91,53,93,32,43,32,108,101,102,116,91,54,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,54,32,61,32,70,49,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,59,32,112,114,50,46,115,55,32,61,32,40,108,101,102,116,91,53,93,32,43,32,50,32,42,32,108,101,102,116,91,54,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,32,112,114,51,46,115,49,32,61,32,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+40960);
/* memory initializer */ allocate([32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,32,112,114,51,46,115,51,32,61,32,40,108,101,102,116,91,52,93,32,43,32,50,32,42,32,108,101,102,116,91,53,93,32,43,32,108,101,102,116,91,54,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,59,32,112,114,51,46,115,53,32,61,32,40,108,101,102,116,91,53,93,32,43,32,50,32,42,32,108,101,102,116,91,54,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,51,46,115,54,32,61,32,70,49,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,59,32,112,114,51,46,115,55,32,61,32,40,108,101,102,116,91,54,93,32,43,32,50,32,42,32,108,101,102,116,91,55,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,112,114,48,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,32,112,114,48,46,115,49,32,61,32,40,108,101,102,116,91,52,93,32,43,32,50,32,42,32,108,101,102,116,91,53,93,32,43,32,108,101,102,116,91,54,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,59,32,112,114,48,46,115,51,32,61,32,40,108,101,102,116,91,53,93,32,43,32,50,32,42,32,108,101,102,116,91,54,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,52,32,61,32,70,49,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,59,32,112,114,48,46,115,53,32,61,32,40,108,101,102,116,91,54,93,32,43,32,50,32,42,32,108,101,102,116,91,55,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,48,46,115,54,32,61,32,108,101,102,116,91,55,93,59,32,112,114,48,46,115,55,32,61,32,108,101,102,116,91,55,93,59,10,112,114,49,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,59,32,112,114,49,46,115,49,32,61,32,40,108,101,102,116,91,53,93,32,43,32,50,32,42,32,108,101,102,116,91,54,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,50,32,61,32,70,49,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,59,32,112,114,49,46,115,51,32,61,32,40,108,101,102,116,91,54,93,32,43,32,50,32,42,32,108,101,102,116,91,55,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,49,46,115,52,32,61,32,108,101,102,116,91,55,93,59,32,112,114,49,46,115,53,32,61,32,108,101,102,116,91,55,93,59,10,112,114,49,46,115,54,32,61,32,108,101,102,116,91,55,93,59,32,112,114,49,46,115,55,32,61,32,108,101,102,116,91,55,93,59,10,112,114,50,46,115,48,32,61,32,70,49,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,59,32,112,114,50,46,115,49,32,61,32,40,108,101,102,116,91,54,93,32,43,32,50,32,42,32,108,101,102,116,91,55,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,59,10,112,114,50,46,115,50,32,61,32,108,101,102,116,91,55,93,59,32,112,114,50,46,115,51,32,61,32,108,101,102,116,91,55,93,59,10,112,114,50,46,115,52,32,61,32,108,101,102,116,91,55,93,59,32,112,114,50,46,115,53,32,61,32,108,101,102,116,91,55,93,59,10,112,114,50,46,115,54,32,61,32,108,101,102,116,91,55,93,59,32,112,114,50,46,115,55,32,61,32,108,101,102,116,91,55,93,59,10,112,114,51,32,61,32,40,105,110,116,56,41,108,101,102,116,91,55,93,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,104,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,32,41,10,123,10,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,95,108,32,61,32,115,114,99,59,10,105,110,116,56,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,59,10,112,114,48,32,61,32,40,105,110,116,56,41,115,114,99,91,45,49,93,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,112,114,49,32,61,32,40,105,110,116,56,41,115,114,99,91,45,49,93,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,112,114,50,32,61,32,40,105,110,116,56,41,115,114,99,91,45,49,93,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,112,114,51,32,61,32,40,105,110,116,56,41,115,114,99,91,45,49,93,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,95,108,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,112,114,48,32,61,32,40,105,110,116,56,41,115,114,99,91,45,49,93,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,112,114,49,32,61,32,40,105,110,116,56,41,115,114,99,91,45,49,93,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,112,114,50,32,61,32,40,105,110,116,56,41,115,114,99,91,45,49,93,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,112,114,51,32,61,32,40,105,110,116,56,41,115,114,99,91,45,49,93,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,95,108,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,118,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,32,41,10,123,10,105,110,116,56,32,112,114,101,100,32,61,32,99,111,110,118,101,114,116,95,105,110,116,56,40,32,118,108,111,97,100,56,40,32,48,44,32,38,115,114,99,91,45,115,114,99,95,115,116,114,105,100,101,93,32,41,41,59,10,114,101,116,117,114,110,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,112,114,101,100,44,32,112,114,101,100,44,32,112,114,101,100,32,41,32,43,10,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,112,114,101,100,44,32,112,114,101,100,44,32,112,114,101,100,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,112,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,32,41,10,123,10,105,110,116,32,72,32,61,32,48,44,32,86,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,105,32,61,32,48,59,32,105,32,60,32,52,59,32,105,43,43,32,41,10,123,10,72,32,43,61,32,40,105,32,43,32,49,41,32,42,32,40,115,114,99,91,52,32,43,32,105,32,45,32,115,114,99,95,115,116,114,105,100,101,93,32,45,32,115,114,99,91,50,32,45,32,105,32,45,32,115,114,99,95,115,116,114,105,100,101,93,41,59,10,86,32,43,61,32,40,105,32,43,32,49,41,32,42,32,40,115,114,99,91,45,49,32,43,32,40,105,32,43,32,52,41,32,42,32,115,114,99,95,115,116,114,105,100,101,93,32,45,32,115,114,99,91,45,49,32,43,32,40,50,32,45,32,105,41,32,42,32,115,114,99,95,115,116,114,105,100,101,93,41,59,10,125,10,105,110,116,32,97,32,61,32,49,54,32,42,32,40,115,114,99,91,45,49,32,43,32,55,32,42,32,115,114,99,95,115,116,114,105,100,101,93,32,43,32,115,114,99,91,55,32,45,32,115,114,99,95,115,116,114,105,100,101,93,41,59,10,105,110,116,32,98,32,61,32,40,49,55,32,42,32,72,32,43,32,49,54,41,32,62,62,32,53,59,10,105,110,116,32,99,32,61,32,40,49,55,32,42,32,86,32,43,32,49,54,41,32,62,62,32,53,59,10,105,110,116,32,105,48,48,32,61,32,97,32,45,32,51,32,42,32,98,32,45,32,51,32,42,32,99,32,43,32,49,54,59,10,105,110,116,32,112,105,120,32,61,32,105,48,48,59,10,105,110,116,56,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,59,10,112,114,48,46,115,48,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,49,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,50,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,51,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,52,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,53,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,54,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,55,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,105,48,48,32,43,61,32,99,59,10,112,105,120,32,61,32,105,48,48,59,10,112,114,49,46,115,48,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,49,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,50,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,51,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,52,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,53,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,54,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,55,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,105,48,48,32,43,61,32,99,59,10,112,105,120,32,61,32,105,48,48,59,10,112,114,50,46,115,48,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,49,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,50,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,51,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,52,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,53,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,54,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,55,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,105,48,48,32,43,61,32,99,59,10,112,105,120,32,61,32,105,48,48,59,10,112,114,51,46,115,48,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,49,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,50,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,51,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,52,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,53,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,54,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,55,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,105,48,48,32,43,61,32,99,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,112,105,120,32,61,32,105,48,48,59,10,112,114,48,46,115,48,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,49,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,50,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,51,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,52,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,53,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,54,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,48,46,115,55,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,105,48,48,32,43,61,32,99,59,10,112,105,120,32,61,32,105,48,48,59,10,112,114,49,46,115,48,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,49,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,50,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,51,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,52,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,53,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,54,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,49,46,115,55,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,105,48,48,32,43,61,32,99,59,10,112,105,120,32,61,32,105,48,48,59,10,112,114,50,46,115,48,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,49,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,50,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,51,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,52,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,53,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,54,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,50,46,115,55,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,105,48,48,32,43,61,32,99,59,10,112,105,120,32,61,32,105,48,48,59,10,112,114,51,46,115,48,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,49,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,50,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,51,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,52,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,53,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,54,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,112,105,120,32,43,61,32,98,59,10,112,114,51,46,115,55,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,32,105,48,48,32,43,61,32,99,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,48,44,32,112,114,49,44,32,112,114,50,44,32,112,114,51,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,100,99,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,32,41,10,123,10,105,110,116,32,115,48,32,61,32,48,44,32,115,49,32,61,32,48,44,32,115,50,32,61,32,48,44,32,115,51,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,105,32,61,32,48,59,32,105,32,60,32,52,59,32,105,43,43,32,41,10,123,10,115,48,32,43,61,32,115,114,99,91,105,32,45,32,115,114,99,95,115,116,114,105,100,101,93,59,10,115,49,32,43,61,32,115,114,99,91,105,32,43,32,52,32,45,32,115,114,99,95,115,116,114,105,100,101,93,59,10,115,50,32,43,61,32,115,114,99,91,45,49,32,43,32,105,32,42,32,115,114,99,95,115,116,114,105,100,101,93,59,10,115,51,32,43,61,32,115,114,99,91,45,49,32,43,32,40,105,43,52,41,42,115,114,99,95,115,116,114,105,100,101,93,59,10,125,10,105,110,116,56,32,100,99,48,59,10,100,99,48,46,108,111,32,61,32,40,105,110,116,52,41,40,32,40,115,48,32,43,32,115,50,32,43,32,52,41,32,62,62,32,51,32,41,59,10,100,99,48,46,104,105,32,61,32,40,105,110,116,52,41,40,32,40,115,49,32,43,32,50,41,32,62,62,32,50,32,41,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,100,99,48,44,32,100,99,48,44,32,100,99,48,44,32,100,99,48,32,41,59,10,100,99,48,46,108,111,32,61,32,40,105,110,116,52,41,40,32,40,115,51,32,43,32,50,41,32,62,62,32,50,32,41,59,10,100,99,48,46,104,105,32,61,32,40,105,110,116,52,41,40,32,40,115,49,32,43,32,115,51,32,43,32,52,41,32,62,62,32,51,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,105,110,116,114,97,95,108,114,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,100,99,48,44,32,100,99,48,44,32,100,99,48,44,32,100,99,48,32,41,59,10,125,10,35,101,108,115,101,32,32,47,42,32,110,111,116,32,118,101,99,116,111,114,105,122,101,100,58,32,112,114,105,118,97,116,101,32,105,115,32,99,104,101,97,112,32,114,101,103,105,115,116,101,114,115,32,97,114,101,32,115,99,97,114,99,101,32,42,47,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,100,100,108,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,52,59,32,121,43,43,32,41,10,123,10,102,111,114,40,32,105,110,116,32,120,32,61,32,48,59,32,120,32,60,32,56,59,32,120,43,43,32,41,10,123,10,112,105,120,101,108,32,120,95,112,108,117,115,95,121,32,61,32,40,112,105,120,101,108,41,32,99,108,97,109,112,95,105,110,116,40,32,120,32,43,32,121,44,32,48,44,32,49,51,32,41,59,10,112,114,101,100,91,120,32,43,32,121,42,56,93,32,61,32,40,32,50,32,43,32,116,111,112,91,120,95,112,108,117,115,95,121,93,32,43,32,50,42,116,111,112,91,120,95,112,108,117,115,95,121,32,43,32,49,93,32,43,32,116,111,112,91,120,95,112,108,117,115,95,121,32,43,32,50,93,32,41,32,62,62,32,50,59,10,125,10,125,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,102,111,114,40,32,105,110,116,32,121,32,61,32,52,59,32,121,32,60,32,56,59,32,121,43,43,32,41,10,123,10,102,111,114,40,32,105,110,116,32,120,32,61,32,48,59,32,120,32,60,32,56,59,32,120,43,43,32,41,10,123,10,112,105,120,101,108,32,120,95,112,108,117,115,95,121,32,61,32,40,112,105,120,101,108,41,32,99,108,97,109,112,95,105,110,116,40,32,120,32,43,32,121,44,32,48,44,32,49,51,32,41,59,10,112,114,101,100,91,120,32,43,32,40,32,121,32,45,32,52,32,41,42,56,93,32,61,32,40,32,50,32,43,32,116,111,112,91,120,95,112,108,117,115,95,121,93,32,43,32,50,42,116,111,112,91,120,95,112,108,117,115,95,121,32,43,32,49,93,32,43,32,116,111,112,91,120,95,112,108,117,115,95,121,32,43,32,50,93,32,41,32,62,62,32,50,59,10,125,10,125,10,112,114,101,100,91,51,49,93,32,61,32,40,32,50,32,43,32,116,111,112,91,49,52,93,32,43,32,51,42,116,111,112,91,49,53,93,32,41,32,62,62,32,50,59,10,115,97,116,100,32,43,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,100,100,114,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,108,101,102,116,44,32,112,105,120,101,108,32,108,101,102,116,95,116,111,112,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,35,100,101,102,105,110,101,32,80,82,69,68,40,32,120,44,32,121,32,41,32,112,114,101,100,91,40,120,41,32,43,32,40,121,41,42,56,93,10,80,82,69,68,40,32,48,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,10,80,82,69,68,40,32,48,44,32,50,32,41,32,61,32,80,82,69,68,40,32,49,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,10,80,82,69,68,40,32,48,44,32,49,32,41,32,61,32,80,82,69,68,40,32,49,44,32,50,32,41,32,61,32,80,82,69,68,40,32,50,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,10,80,82,69,68,40,32,48,44,32,48,32,41,32,61,32,80,82,69,68,40,32,49,44,32,49,32,41,32,61,32,80,82,69,68,40,32,50,44,32,50,32,41,32,61,32,80,82,69,68,40,32,51,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,80,82,69,68,40,32,49,44,32,48,32,41,32,61,32,80,82,69,68,40,32,50,44,32,49,32,41,32,61,32,80,82,69,68,40,32,51,44,32,50,32,41,32,61,32,80,82,69,68,40,32,52,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,80,82,69,68,40,32,50,44,32,48,32,41,32,61,32,80,82,69,68,40,32,51,44,32,49,32,41,32,61,32,80,82,69,68,40,32,52,44,32,50,32,41,32,61,32,80,82,69,68,40,32,53,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,80,82,69,68,40,32,51,44,32,48,32,41,32,61,32,80,82,69,68,40,32,52,44,32,49,32,41,32,61,32,80,82,69,68,40,32,53,44,32,50,32,41,32,61,32,80,82,69,68,40,32,54,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,80,82,69,68,40,32,52,44,32,48,32,41,32,61,32,80,82,69,68,40,32,53,44,32,49,32,41,32,61,32,80,82,69,68,40,32,54,44,32,50,32,41,32,61,32,80,82,69,68,40,32,55,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,53,44,32,48,32,41,32,61,32,80,82,69,68,40,32,54,44,32,49,32,41,32,61,32,80,82,69,68,40,32,55,44,32,50,32,41,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,80,82,69,68,40,32,54,44,32,48,32,41,32,61,32,80,82,69,68,40,32,55,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,80,82,69,68,40,32,55,44,32,48,32,41,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,80,82,69,68,40,32,48,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,59,10,80,82,69,68,40,32,48,44,32,50,32,41,32,61,32,80,82,69,68,40,32,49,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,59,10,80,82,69,68,40,32,48,44,32,49,32,41,32,61,32,80,82,69,68,40,32,49,44,32,50,32,41,32,61,32,80,82,69,68,40,32,50,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,59,10,80,82,69,68,40,32,48,44,32,48,32,41,32,61,32,80,82,69,68,40,32,49,44,32,49,32,41,32,61,32,80,82,69,68,40,32,50,44,32,50,32,41,32,61,32,80,82,69,68,40,32,51,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,59,10,80,82,69,68,40,32,49,44,32,48,32,41,32,61,32,80,82,69,68,40,32,50,44,32,49,32,41,32,61,32,80,82,69,68,40,32,51,44,32,50,32,41,32,61,32,80,82,69,68,40,32,52,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,59,10,80,82,69,68,40,32,50,44,32,48,32,41,32,61,32,80,82,69,68,40,32,51,44,32,49,32,41,32,61,32,80,82,69,68,40,32,52,44,32,50,32,41,32,61,32,80,82,69,68,40,32,53,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,59,10,80,82,69,68,40,32,51,44,32,48,32,41,32,61,32,80,82,69,68,40,32,52,44,32,49,32,41,32,61,32,80,82,69,68,40,32,53,44,32,50,32,41,32,61,32,80,82,69,68,40,32,54,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,10,80,82,69,68,40,32,52,44,32,48,32,41,32,61,32,80,82,69,68,40,32,53,44,32,49,32,41,32,61,32,80,82,69,68,40,32,54,44,32,50,32,41,32,61,32,80,82,69,68,40,32,55,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,80,82,69,68,40,32,53,44,32,48,32,41,32,61,32,80,82,69,68,40,32,54,44,32,49,32,41,32,61,32,80,82,69,68,40,32,55,44,32,50,32,41,32,61,32,70,50,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,80,82,69,68,40,32,54,44,32,48,32,41,32,61,32,80,82,69,68,40,32,55,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,80,82,69,68,40,32,55,44,32,48,32,41,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,115,97,116,100,32,43,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,59,10,35,117,110,100,101,102,32,80,82,69,68,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,118,114,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,108,101,102,116,44,32,112,105,120,101,108,32,108,101,102,116,95,116,111,112,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,35,100,101,102,105,110,101,32,80,82,69,68,40,32,120,44,32,121,32,41,32,112,114,101,100,91,40,120,41,32,43,32,40,121,41,42,56,93,10,80,82,69,68,40,32,48,44,32,50,32,41,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,10,80,82,69,68,40,32,48,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,32,41,59,10,80,82,69,68,40,32,48,44,32,49,32,41,32,61,32,80,82,69,68,40,32,49,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,80,82,69,68,40,32,48,44,32,48,32,41,32,61,32,80,82,69,68,40,32,49,44,32,50,32,41,32,61,32,70,49,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,80,82,69,68,40,32,49,44,32,49,32,41,32,61,32,80,82,69,68,40,32,50,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,80,82,69,68,40,32,49,44,32,48,32,41,32,61,32,80,82,69,68,40,32,50,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,80,82,69,68,40,32,50,44,32,49,32,41,32,61,32,80,82,69,68,40,32,51,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,80,82,69,68,40,32,50,44,32,48,32,41,32,61,32,80,82,69,68,40,32,51,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,80,82,69,68,40,32,51,44,32,49,32,41,32,61,32,80,82,69,68,40,32,52,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,80,82,69,68,40,32,51,44,32,48,32,41,32,61,32,80,82,69,68,40,32,52,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,80,82,69,68,40,32,52,44,32,49,32,41,32,61,32,80,82,69,68,40,32,53,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,52,44,32,48,32,41,32,61,32,80,82,69,68,40,32,53,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,53,44,32,49,32,41,32,61,32,80,82,69,68,40,32,54,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,80,82,69,68,40,32,53,44,32,48,32,41,32,61,32,80,82,69,68,40,32,54,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,80,82,69,68,40,32,54,44,32,49,32,41,32,61,32,80,82,69,68,40,32,55,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,44,32,116,111,112], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+51200);
/* memory initializer */ allocate([91,54,93,32,41,59,10,80,82,69,68,40,32,54,44,32,48,32,41,32,61,32,80,82,69,68,40,32,55,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,80,82,69,68,40,32,55,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,80,82,69,68,40,32,55,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,80,82,69,68,40,32,48,44,32,50,32,41,32,61,32,70,50,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,51,93,32,41,59,10,80,82,69,68,40,32,48,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,52,93,32,41,59,10,80,82,69,68,40,32,48,44,32,48,32,41,32,61,32,80,82,69,68,40,32,49,44,32,50,32,41,32,61,32,70,50,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,49,93,32,41,59,10,80,82,69,68,40,32,48,44,32,49,32,41,32,61,32,80,82,69,68,40,32,49,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,50,93,32,41,59,10,80,82,69,68,40,32,49,44,32,48,32,41,32,61,32,80,82,69,68,40,32,50,44,32,50,32,41,32,61,32,70,50,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,59,10,80,82,69,68,40,32,49,44,32,49,32,41,32,61,32,80,82,69,68,40,32,50,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,48,93,32,41,59,10,80,82,69,68,40,32,50,44,32,49,32,41,32,61,32,80,82,69,68,40,32,51,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,80,82,69,68,40,32,50,44,32,48,32,41,32,61,32,80,82,69,68,40,32,51,44,32,50,32,41,32,61,32,70,49,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,32,41,59,10,80,82,69,68,40,32,51,44,32,49,32,41,32,61,32,80,82,69,68,40,32,52,44,32,51,32,41,32,61,32,70,50,40,32,108,101,102,116,95,116,111,112,44,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,80,82,69,68,40,32,51,44,32,48,32,41,32,61,32,80,82,69,68,40,32,52,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,80,82,69,68,40,32,52,44,32,49,32,41,32,61,32,80,82,69,68,40,32,53,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,80,82,69,68,40,32,52,44,32,48,32,41,32,61,32,80,82,69,68,40,32,53,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,80,82,69,68,40,32,53,44,32,49,32,41,32,61,32,80,82,69,68,40,32,54,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,80,82,69,68,40,32,53,44,32,48,32,41,32,61,32,80,82,69,68,40,32,54,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,80,82,69,68,40,32,54,44,32,49,32,41,32,61,32,80,82,69,68,40,32,55,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,54,44,32,48,32,41,32,61,32,80,82,69,68,40,32,55,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,55,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,80,82,69,68,40,32,55,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,115,97,116,100,32,43,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,59,10,35,117,110,100,101,102,32,80,82,69,68,10,125,10,105,110,108,105,110,101,32,117,105,110,116,51,50,95,116,32,112,97,99,107,49,54,116,111,51,50,40,32,117,105,110,116,51,50,95,116,32,97,44,32,117,105,110,116,51,50,95,116,32,98,32,41,10,123,10,114,101,116,117,114,110,32,97,32,43,32,40,98,32,60,60,32,49,54,41,59,10,125,10,105,110,108,105,110,101,32,117,105,110,116,51,50,95,116,32,112,97,99,107,56,116,111,49,54,40,32,117,105,110,116,51,50,95,116,32,97,44,32,117,105,110,116,51,50,95,116,32,98,32,41,10,123,10,114,101,116,117,114,110,32,97,32,43,32,40,98,32,60,60,32,56,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,104,100,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,108,101,102,116,44,32,112,105,120,101,108,32,108,101,102,116,95,116,111,112,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,105,110,116,32,115,97,116,100,59,10,105,110,116,32,112,49,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,41,44,32,40,40,108,101,102,116,91,53,93,32,43,32,50,32,42,32,108,101,102,116,91,54,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,50,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,41,44,32,40,40,108,101,102,116,91,52,93,32,43,32,50,32,42,32,108,101,102,116,91,53,93,32,43,32,108,101,102,116,91,54,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,51,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,41,44,32,40,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,52,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,41,44,32,40,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,53,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,41,44,32,40,40,108,101,102,116,91,49,93,32,43,32,50,32,42,32,108,101,102,116,91,50,93,32,43,32,108,101,102,116,91,51,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,54,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,41,44,32,40,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,91,49,93,32,43,32,108,101,102,116,91,50,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,55,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,32,41,41,44,32,40,40,108,101,102,116,95,116,111,112,32,43,32,50,32,42,32,108,101,102,116,91,48,93,32,43,32,108,101,102,116,91,49,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,56,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,95,116,111,112,44,32,108,101,102,116,91,48,93,32,41,41,44,32,40,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,95,116,111,112,32,43,32,116,111,112,91,48,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,57,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,48,93,44,32,108,101,102,116,95,116,111,112,32,41,41,44,32,40,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,48,93,32,41,41,32,41,59,10,105,110,116,32,112,49,48,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,49,93,32,41,41,44,32,40,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,50,93,32,41,41,32,41,59,10,105,110,116,32,112,49,49,32,61,32,32,112,97,99,107,56,116,111,49,54,40,32,40,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,51,93,32,41,41,44,32,40,70,50,40,32,116,111,112,91,54,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,52,93,32,41,41,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,56,44,32,112,57,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,48,32,43,32,48,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,49,48,44,32,112,49,49,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,52,32,43,32,48,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,55,44,32,112,56,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,48,32,43,32,49,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,57,44,32,112,49,48,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,52,32,43,32,49,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,54,44,32,112,55,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,48,32,43,32,50,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,56,44,32,112,57,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,52,32,43,32,50,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,53,44,32,112,54,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,48,32,43,32,51,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,55,44,32,112,56,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,52,32,43,32,51,32,42,32,56,93,32,41,59,10,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,52,44,32,112,53,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,48,32,43,32,48,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,54,44,32,112,55,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,52,32,43,32,48,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,51,44,32,112,52,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,48,32,43,32,49,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,53,44,32,112,54,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,52,32,43,32,49,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,50,44,32,112,51,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,48,32,43,32,50,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,52,44,32,112,53,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,52,32,43,32,50,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,49,44,32,112,50,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,48,32,43,32,51,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,51,44,32,112,52,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,52,32,43,32,51,32,42,32,56,93,32,41,59,10,115,97,116,100,32,43,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,118,108,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,116,111,112,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,105,110,116,32,115,97,116,100,59,10,35,100,101,102,105,110,101,32,80,82,69,68,40,32,120,44,32,121,32,41,32,112,114,101,100,91,40,120,41,32,43,32,40,121,41,42,56,93,10,80,82,69,68,40,32,48,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,32,41,59,10,80,82,69,68,40,32,48,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,48,93,44,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,80,82,69,68,40,32,48,44,32,50,32,41,32,61,32,80,82,69,68,40,32,49,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,32,41,59,10,80,82,69,68,40,32,48,44,32,51,32,41,32,61,32,80,82,69,68,40,32,49,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,49,93,44,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,80,82,69,68,40,32,49,44,32,50,32,41,32,61,32,80,82,69,68,40,32,50,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,80,82,69,68,40,32,49,44,32,51,32,41,32,61,32,80,82,69,68,40,32,50,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,50,44,32,50,32,41,32,61,32,80,82,69,68,40,32,51,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,50,44,32,51,32,41,32,61,32,80,82,69,68,40,32,51,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,80,82,69,68,40,32,51,44,32,50,32,41,32,61,32,80,82,69,68,40,32,52,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,80,82,69,68,40,32,51,44,32,51,32,41,32,61,32,80,82,69,68,40,32,52,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,80,82,69,68,40,32,52,44,32,50,32,41,32,61,32,80,82,69,68,40,32,53,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,80,82,69,68,40,32,52,44,32,51,32,41,32,61,32,80,82,69,68,40,32,53,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,80,82,69,68,40,32,53,44,32,50,32,41,32,61,32,80,82,69,68,40,32,54,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,80,82,69,68,40,32,53,44,32,51,32,41,32,61,32,80,82,69,68,40,32,54,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,32,41,59,10,80,82,69,68,40,32,54,44,32,50,32,41,32,61,32,80,82,69,68,40,32,55,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,32,41,59,10,80,82,69,68,40,32,54,44,32,51,32,41,32,61,32,80,82,69,68,40,32,55,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,32,41,59,10,80,82,69,68,40,32,55,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,32,41,59,10,80,82,69,68,40,32,55,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,44,32,116,111,112,91,49,48,93,32,41,59,10,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,80,82,69,68,40,32,48,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,32,41,59,10,80,82,69,68,40,32,48,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,50,93,44,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,48,44,32,50,32,41,32,61,32,80,82,69,68,40,32,49,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,32,41,59,10,80,82,69,68,40,32,48,44,32,51,32,41,32,61,32,80,82,69,68,40,32,49,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,51,93,44,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,80,82,69,68,40,32,49,44,32,50,32,41,32,61,32,80,82,69,68,40,32,50,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,32,41,59,10,80,82,69,68,40,32,49,44,32,51,32,41,32,61,32,80,82,69,68,40,32,50,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,52,93,44,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,80,82,69,68,40,32,50,44,32,50,32,41,32,61,32,80,82,69,68,40,32,51,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,32,41,59,10,80,82,69,68,40,32,50,44,32,51,32,41,32,61,32,80,82,69,68,40,32,51,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,53,93,44,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,80,82,69,68,40,32,51,44,32,50,32,41,32,61,32,80,82,69,68,40,32,52,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,32,41,59,10,80,82,69,68,40,32,51,44,32,51,32,41,32,61,32,80,82,69,68,40,32,52,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,54,93,44,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,32,41,59,10,80,82,69,68,40,32,52,44,32,50,32,41,32,61,32,80,82,69,68,40,32,53,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,32,41,59,10,80,82,69,68,40,32,52,44,32,51,32,41,32,61,32,80,82,69,68,40,32,53,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,55,93,44,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,32,41,59,10,80,82,69,68,40,32,53,44,32,50,32,41,32,61,32,80,82,69,68,40,32,54,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,32,41,59,10,80,82,69,68,40,32,53,44,32,51,32,41,32,61,32,80,82,69,68,40,32,54,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,56,93,44,32,116,111,112,91,57,93,44,32,116,111,112,91,49,48,93,32,41,59,10,80,82,69,68,40,32,54,44,32,50,32,41,32,61,32,80,82,69,68,40,32,55,44,32,48,32,41,32,61,32,70,49,40,32,116,111,112,91,57,93,44,32,116,111,112,91,49,48,93,32,41,59,10,80,82,69,68,40,32,54,44,32,51,32,41,32,61,32,80,82,69,68,40,32,55,44,32,49,32,41,32,61,32,70,50,40,32,116,111,112,91,57,93,44,32,116,111,112,91,49,48,93,44,32,116,111,112,91,49,49,93,32,41,59,10,80,82,69,68,40,32,55,44,32,50,32,41,32,61,32,70,49,40,32,116,111,112,91,49,48,93,44,32,116,111,112,91,49,49,93,32,41,59,10,80,82,69,68,40,32,55,44,32,51,32,41,32,61,32,70,50,40,32,116,111,112,91,49,48,93,44,32,116,111,112,91,49,49,93,44,32,116,111,112,91,49,50,93,32,41,59,10,115,97,116,100,32,43,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,59,10,35,117,110,100,101,102,32,80,82,69,68,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,104,117,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,44,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,108,101,102,116,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,105,110,116,32,115,97,116,100,59,10,105,110,116,32,112,49,32,61,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,48,93,44,32,108,101,102,116,91,49,93,32,41,41,44,32,40,40,108,101,102,116,91,48,93,32,43,32,50,32,42,32,108,101,102,116,91,49,93,32,43,32,108,101,102,116,91,50,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,50,32,61,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,49,93,44,32,108,101,102,116,91,50,93,32,41,41,44,32,40,40,108,101,102,116,91,49,93,32,43,32,50,32,42,32,108,101,102,116,91,50,93,32,43,32,108,101,102,116,91,51,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,51,32,61,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,50,93,44,32,108,101,102,116,91,51,93,32,41,41,44,32,40,40,108,101,102,116,91,50,93,32,43,32,50,32,42,32,108,101,102,116,91,51,93,32,43,32,108,101,102,116,91,52,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,52,32,61,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,51,93,44,32,108,101,102,116,91,52,93,32,41,41,44,32,40,40,108,101,102,116,91,51,93,32,43,32,50,32,42,32,108,101,102,116,91,52,93,32,43,32,108,101,102,116,91,53,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,53,32,61,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,52,93,44,32,108,101,102,116,91,53,93,32,41,41,44,32,40,40,108,101,102,116,91,52,93,32,43,32,50,32,42,32,108,101,102,116,91,53,93,32,43,32,108,101,102,116,91,54,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,54,32,61,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,53,93,44,32,108,101,102,116,91,54,93,32,41,41,44,32,40,40,108,101,102,116,91,53,93,32,43,32,50,32,42,32,108,101,102,116,91,54,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,55,32,61,32,112,97,99,107,56,116,111,49,54,40,32,40,70,49,40,32,108,101,102,116,91,54,93,44,32,108,101,102,116,91,55,93,32,41,41,44,32,40,40,108,101,102,116,91,54,93,32,43,32,50,32,42,32,108,101,102,116,91,55,93,32,43,32,108,101,102,116,91,55,93,32,43,32,50,41,32,62,62,32,50,41,32,41,59,10,105,110,116,32,112,56,32,61,32,112,97,99,107,56,116,111,49,54,40,32,108,101,102,116,91,55,93,44,32,108,101,102,116,91,55,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,49,44,32,112,50,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,48,32,41,32,43,32,40,32,48,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,51,44,32,112,52,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,52,32,41,32,43,32,40,32,48,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,50,44,32,112,51,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,48,32,41,32,43,32,40,32,49,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,52,44,32,112,53,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,52,32,41,32,43,32,40,32,49,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,51,44,32,112,52,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,48,32,41,32,43,32,40,32,50,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,53,44,32,112,54,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,52,32,41,32,43,32,40,32,50,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,52,44,32,112,53,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,48,32,41,32,43,32,40,32,51,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,54,44,32,112,55,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,52,32,41,32,43,32,40,32,51,32,41,32,42,32,56,93,32,41,59,10,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,53,44,32,112,54,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,48,32,41,32,43,32,40,32,48,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,55,44,32,112,56,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,52,32,41,32,43,32,40,32,48,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,54,44,32,112,55,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,48,32,41,32,43,32,40,32,49,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,56,44,32,112,56,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,52,32,41,32,43,32,40,32,49,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,55,44,32,112,56,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,48,32,41,32,43,32,40,32,50,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,56,44,32,112,56,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,52,32,41,32,43,32,40,32,50,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,56,44,32,112,56,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,48,32,41,32,43,32,40,32,51,32,41,32,42,32,56,93,32,41,59,10,118,115,116,111,114,101,52,40,32,97,115,95,117,99,104,97,114,52,40,32,112,97,99,107,49,54,116,111,51,50,40,32,112,56,44,32,112,56,32,41,32,41,44,32,48,44,32,38,112,114,101,100,91,40,32,52,32,41,32,43,32,40,32,51,32,41,32,42,32,56,93,32,41,59,10,115,97,116,100,32,43,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,104,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,95,108,32,61,32,115,114,99,59,10,118,115,116,111,114,101,56,40,32,40,117,99,104,97,114,56,41,40,115,114,99,91,45,49,93,41,44,32,48,44,32,112,114,101,100,32,41,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,118,115,116,111,114,101,56,40,32,40,117,99,104,97,114,56,41,40,115,114,99,91,45,49,93,41,44,32,49,44,32,112,114,101,100,32,41,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,118,115,116,111,114,101,56,40,32,40,117,99,104,97,114,56,41,40,115,114,99,91,45,49,93,41,44,32,50,44,32,112,114,101,100,32,41,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,118,115,116,111,114,101,56,40,32,40,117,99,104,97,114,56,41,40,115,114,99,91,45,49,93,41,44,32,51,44,32,112,114,101,100,32,41,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,95,108,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,118,115,116,111,114,101,56,40,32,40,117,99,104,97,114,56,41,40,115,114,99,91,45,49,93,41,44,32,48,44,32,112,114,101,100,32,41,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,118,115,116,111,114,101,56,40,32,40,117,99,104,97,114,56,41,40,115,114,99,91,45,49,93,41,44,32,49,44,32,112,114,101,100,32,41,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,118,115,116,111,114,101,56,40,32,40,117,99,104,97,114,56,41,40,115,114,99,91,45,49,93,41,44,32,50,44,32,112,114,101,100,32,41,59,32,115,114,99,32,43,61,32,115,114,99,95,115,116,114,105,100,101,59,10,118,115,116,111,114,101,56,40,32,40,117,99,104,97,114,56,41,40,115,114,99,91,45,49,93,41,44,32,51,44,32,112,114,101,100,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,95,108,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,118,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,117,99,104,97,114,49,54,32,118,49,54,59,10,118,49,54,46,108,111,32,61,32,118,108,111,97,100,56,40,32,48,44,32,38,115,114,99,91,45,115,114,99,95,115,116,114,105,100,101,93,32,41,59,10,118,49,54,46,104,105,32,61,32,118,108,111,97,100,56,40,32,48,44,32,38,115,114,99,91,45,115,114,99,95,115,116,114,105,100,101,93,32,41,59,10,118,115,116,111,114,101,49,54,40,32,118,49,54,44,32,48,44,32,112,114,101,100,32,41,59,10,118,115,116,111,114,101,49,54,40,32,118,49,54,44,32,49,44,32,112,114,101,100,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,32,43,10,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,112,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,32,41,10,123,10,105,110,116,32,72,32,61,32,48,44,32,86,32,61,32,48,59,10,112,114,105,118,97,116,101,32,112,105,120,101,108,32,112,114,101,100,91,51,50,93,59,10,105,110,116,32,115,97,116,100,59,10,102,111,114,40,32,105,110,116,32,105,32,61,32,48,59,32,105,32,60,32,52,59,32,105,43,43,32,41,10,123,10,72,32,43,61,32,40,105,32,43,32,49,41,32,42,32,40,115,114,99,91,52,32,43,32,105,32,45,32,115,114,99,95,115,116,114,105,100,101,93,32,45,32,115,114,99,91,50,32,45,32,105,32,45,32,115,114,99,95,115,116,114,105,100,101,93,41,59,10,86,32,43,61,32,40,105,32,43,32,49,41,32,42,32,40,115,114,99,91,45,49,32,43,32,40,105,32,43,32,52,41,32,42,32,115,114,99,95,115,116,114,105,100,101,93,32,45,32,115,114,99,91,45,49,32,43,32,40,50,32,45,32,105,41,32,42,32,115,114,99,95,115,116,114,105,100,101,93,41,59,10,125,10,105,110,116,32,97,32,61,32,49,54,32,42,32,40,115,114,99,91,45,49,32,43,32,55,32,42,32,115,114,99,95,115,116,114,105,100,101,93,32,43,32,115,114,99,91,55,32,45,32,115,114,99,95,115,116,114,105,100,101,93,41,59,10,105,110,116,32,98,32,61,32,40,49,55,32,42,32,72,32,43,32,49,54,41,32,62,62,32,53,59,10,105,110,116,32,99,32,61,32,40,49,55,32,42,32,86,32,43,32,49,54,41,32,62,62,32,53,59,10,105,110,116,32,105,48,48,32,61,32,97,32,45,32,51,32,42,32,98,32,45,32,51,32,42,32,99,32,43,32,49,54,59,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,52,59,32,121,43,43,32,41,10,123,10,105,110,116,32,112,105,120,32,61,32,105,48,48,59,10,102,111,114,40,32,105,110,116,32,120,32,61,32,48,59,32,120,32,60,32,56,59,32,120,43,43,32,41,10,123,10,112,114,101,100,91,120,32,43,32,121,42,56,93,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,10,112,105,120,32,43,61,32,98,59,10,125,10,105,48,48,32,43,61,32,99,59,10,125,10,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,52,59,32,121,43,43,32,41,10,123,10,105,110,116,32,112,105,120,32,61,32,105,48,48,59,10,102,111,114,40,32,105,110,116,32,120,32,61,32,48,59,32,120,32,60,32,56,59,32,120,43,43,32,41,10,123,10,112,114,101,100,91,120,32,43,32,121,42,56,93,32,61,32,120,50,54,52,95,99,108,105,112,95,112,105,120,101,108,40,32,112,105,120,32,62,62,32,53,32,41,59,10,112,105,120,32,43,61,32,98,59,10,125,10,105,48,48,32,43,61,32,99,59,10,125,10,115,97,116,100,32,43,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,59,10,125,10,105,110,116,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,100,99,40,32,99,111,110,115,116,32,108,111,99,97,108,32,112,105,120,101,108,32,42,115,114,99,44,32,105,110,116,32,115,114,99,95,115,116,114,105,100,101,32,41,10,123,10,112,114,105,118,97,116,101,32,112,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+61440);
/* memory initializer */ allocate([120,101,108,32,112,114,101,100,91,51,50,93,59,10,105,110,116,32,115,48,32,61,32,48,44,32,115,49,32,61,32,48,44,32,115,50,32,61,32,48,44,32,115,51,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,105,32,61,32,48,59,32,105,32,60,32,52,59,32,105,43,43,32,41,10,123,10,115,48,32,43,61,32,115,114,99,91,105,32,45,32,115,114,99,95,115,116,114,105,100,101,93,59,10,115,49,32,43,61,32,115,114,99,91,105,32,43,32,52,32,45,32,115,114,99,95,115,116,114,105,100,101,93,59,10,115,50,32,43,61,32,115,114,99,91,45,49,32,43,32,105,32,42,32,115,114,99,95,115,116,114,105,100,101,93,59,10,115,51,32,43,61,32,115,114,99,91,45,49,32,43,32,40,105,43,52,41,42,115,114,99,95,115,116,114,105,100,101,93,59,10,125,10,117,99,104,97,114,56,32,100,99,48,59,10,100,99,48,46,108,111,32,61,32,40,117,99,104,97,114,52,41,40,32,40,115,48,32,43,32,115,50,32,43,32,52,41,32,62,62,32,51,32,41,59,10,100,99,48,46,104,105,32,61,32,40,117,99,104,97,114,52,41,40,32,40,115,49,32,43,32,50,41,32,62,62,32,50,32,41,59,10,118,115,116,111,114,101,56,40,32,100,99,48,44,32,48,44,32,112,114,101,100,32,41,59,10,118,115,116,111,114,101,56,40,32,100,99,48,44,32,49,44,32,112,114,101,100,32,41,59,10,118,115,116,111,114,101,56,40,32,100,99,48,44,32,50,44,32,112,114,101,100,32,41,59,10,118,115,116,111,114,101,56,40,32,100,99,48,44,32,51,44,32,112,114,101,100,32,41,59,10,105,110,116,32,115,97,116,100,32,61,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,100,99,48,46,108,111,32,61,32,40,117,99,104,97,114,52,41,40,32,40,115,51,32,43,32,50,41,32,62,62,32,50,32,41,59,10,100,99,48,46,104,105,32,61,32,40,117,99,104,97,114,52,41,40,32,40,115,49,32,43,32,115,51,32,43,32,52,41,32,62,62,32,51,32,41,59,10,118,115,116,111,114,101,56,40,32,100,99,48,44,32,48,44,32,112,114,101,100,32,41,59,10,118,115,116,111,114,101,56,40,32,100,99,48,44,32,49,44,32,112,114,101,100,32,41,59,10,118,115,116,111,114,101,56,40,32,100,99,48,44,32,50,44,32,112,114,101,100,32,41,59,10,118,115,116,111,114,101,56,40,32,100,99,48,44,32,51,44,32,112,114,101,100,32,41,59,10,114,101,116,117,114,110,32,115,97,116,100,32,43,32,115,97,116,100,95,56,120,52,95,108,112,40,32,115,114,99,32,43,32,40,32,115,114,99,95,115,116,114,105,100,101,32,60,60,32,50,32,41,44,32,115,114,99,95,115,116,114,105,100,101,44,32,112,114,101,100,44,32,56,32,41,59,10,125,10,35,101,110,100,105,102,10,47,42,32,70,105,110,100,32,116,104,101,32,108,101,97,115,116,32,99,111,115,116,32,105,110,116,114,97,32,109,111,100,101,32,102,111,114,32,51,50,32,56,120,56,32,109,97,99,114,111,98,108,111,99,107,115,32,112,101,114,32,119,111,114,107,103,114,111,117,112,10,42,10,42,32,76,111,97,100,115,32,51,51,32,109,97,99,114,111,98,108,111,99,107,115,32,112,108,117,115,32,116,104,101,32,112,105,120,101,108,115,32,100,105,114,101,99,116,108,121,32,97,98,111,118,101,32,116,104,101,109,32,105,110,116,111,32,108,111,99,97,108,32,109,101,109,111,114,121,44,10,42,32,112,97,100,100,105,110,103,32,119,104,101,114,101,32,110,101,99,101,115,115,97,114,121,32,119,105,116,104,32,101,100,103,101,32,112,105,120,101,108,115,46,32,32,73,116,32,116,104,101,110,32,99,111,111,112,101,114,97,116,105,118,101,108,121,32,99,97,108,99,117,108,97,116,101,115,10,42,32,115,109,111,111,116,104,101,100,32,116,111,112,32,97,110,100,32,108,101,102,116,32,112,105,120,101,108,115,32,102,111,114,32,117,115,101,32,105,110,32,115,111,109,101,32,111,102,32,116,104,101,32,97,110,97,108,121,115,105,115,46,10,42,10,42,32,84,104,101,110,32,103,114,111,117,112,115,32,111,102,32,51,50,32,116,104,114,101,97,100,115,32,101,97,99,104,32,99,97,108,99,117,108,97,116,101,32,97,32,115,105,110,103,108,101,32,105,110,116,114,97,32,109,111,100,101,32,102,111,114,32,101,97,99,104,32,56,120,56,10,42,32,98,108,111,99,107,46,32,32,83,105,110,99,101,32,99,111,110,115,101,99,117,116,105,118,101,32,116,104,114,101,97,100,115,32,97,114,101,32,99,97,108,99,117,108,97,116,105,110,103,32,116,104,101,32,115,97,109,101,32,105,110,116,114,97,32,109,111,100,101,32,116,104,101,114,101,10,42,32,105,115,32,110,111,32,99,111,100,101,45,112,97,116,104,32,100,105,118,101,114,103,101,110,99,101,46,32,32,56,32,105,110,116,114,97,32,99,111,115,116,115,32,97,114,101,32,99,97,108,99,117,108,97,116,101,100,32,115,105,109,117,108,116,97,110,101,111,117,115,108,121,46,32,32,73,102,10,42,32,116,104,101,32,34,115,108,111,119,34,32,97,114,103,117,109,101,110,116,32,105,115,32,110,111,116,32,122,101,114,111,44,32,116,104,101,32,102,105,110,97,108,32,116,119,111,32,40,108,101,97,115,116,32,108,105,107,101,108,121,41,32,105,110,116,114,97,32,109,111,100,101,115,32,97,114,101,10,42,32,116,101,115,116,101,100,32,105,110,32,97,32,115,101,99,111,110,100,32,112,97,115,115,46,32,32,84,104,101,32,115,108,111,119,32,109,111,100,101,32,105,115,32,111,110,108,121,32,101,110,97,98,108,101,100,32,102,111,114,32,112,114,101,115,101,116,115,32,115,108,111,119,44,10,42,32,115,108,111,119,101,114,44,32,97,110,100,32,112,108,97,99,101,98,111,46,10,42,10,42,32,84,104,105,115,32,97,108,108,111,119,115,32,97,108,108,32,111,102,32,116,104,101,32,112,105,120,101,108,115,32,102,117,110,99,116,105,111,110,115,32,116,111,32,114,101,97,100,32,112,105,120,101,108,115,32,102,114,111,109,32,108,111,99,97,108,32,109,101,109,111,114,121,44,32,97,110,100,10,42,32,97,118,111,105,100,115,32,114,101,45,102,101,116,99,104,105,110,103,32,101,100,103,101,32,112,105,120,101,108,115,32,102,114,111,109,32,103,108,111,98,97,108,32,109,101,109,111,114,121,46,32,32,65,110,100,32,105,116,32,97,108,108,111,119,115,32,117,115,32,116,111,10,42,32,99,97,108,99,117,108,97,116,101,32,97,108,108,32,111,102,32,116,104,101,32,105,110,116,114,97,32,109,111,100,101,32,99,111,115,116,115,32,115,105,109,117,108,116,97,110,101,111,117,115,108,121,32,119,105,116,104,111,117,116,32,98,114,97,110,99,104,32,100,105,118,101,114,103,101,110,99,101,46,10,42,10,42,32,76,111,99,97,108,32,100,105,109,101,110,115,105,111,110,58,32,32,32,32,91,32,51,50,44,32,56,32,93,10,42,32,71,108,111,98,97,108,32,100,105,109,101,110,115,105,111,110,115,58,32,32,91,32,112,97,100,100,101,100,87,105,100,116,104,44,32,104,101,105,103,104,116,32,93,32,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,109,98,95,105,110,116,114,97,95,99,111,115,116,95,115,97,116,100,95,56,120,56,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,32,102,101,110,99,44,10,103,108,111,98,97,108,32,117,105,110,116,49,54,95,116,32,32,32,32,32,42,102,101,110,99,95,105,110,116,114,97,95,99,111,115,116,44,10,103,108,111,98,97,108,32,105,110,116,32,32,32,32,32,32,32,32,32,32,42,102,114,97,109,101,95,115,116,97,116,115,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,108,97,109,98,100,97,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,98,95,119,105,100,116,104,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,115,108,111,119,32,41,10,123,10,35,100,101,102,105,110,101,32,67,65,67,72,69,95,83,84,82,73,68,69,32,50,54,53,10,35,100,101,102,105,110,101,32,66,76,79,67,75,95,79,70,70,83,69,84,32,50,54,54,10,108,111,99,97,108,32,112,105,120,101,108,32,99,97,99,104,101,91,50,51,56,53,93,59,10,108,111,99,97,108,32,105,110,116,32,99,111,115,116,95,98,117,102,91,51,50,93,59,10,108,111,99,97,108,32,112,105,120,101,108,32,116,111,112,91,51,50,32,42,32,49,54,93,59,10,108,111,99,97,108,32,112,105,120,101,108,32,108,101,102,116,91,51,50,32,42,32,56,93,59,10,108,111,99,97,108,32,112,105,120,101,108,32,108,101,102,116,95,116,111,112,91,51,50,93,59,10,105,110,116,32,108,120,32,61,32,103,101,116,95,108,111,99,97,108,95,105,100,40,32,48,32,41,59,10,105,110,116,32,108,121,32,61,32,103,101,116,95,108,111,99,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,32,103,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,105,110,116,32,103,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,32,103,105,100,120,32,61,32,103,101,116,95,103,114,111,117,112,95,105,100,40,32,48,32,41,59,10,105,110,116,32,103,105,100,121,32,61,32,103,101,116,95,103,114,111,117,112,95,105,100,40,32,49,32,41,59,10,105,110,116,32,108,105,110,101,97,114,95,105,100,32,61,32,108,121,32,42,32,103,101,116,95,108,111,99,97,108,95,115,105,122,101,40,32,48,32,41,32,43,32,108,120,59,10,105,110,116,32,115,97,116,100,32,61,32,67,79,83,84,95,77,65,88,59,10,105,110,116,32,98,97,115,101,120,32,61,32,103,105,100,120,32,60,60,32,56,59,10,105,110,116,32,98,97,115,101,121,32,61,32,40,103,105,100,121,32,60,60,32,51,41,32,45,32,49,59,10,47,42,32,76,111,97,100,32,51,51,32,56,120,56,32,109,97,99,114,111,98,108,111,99,107,115,32,97,110,100,32,116,104,101,32,112,105,120,101,108,115,32,97,98,111,118,101,32,116,104,101,109,32,105,110,116,111,32,108,111,99,97,108,32,99,97,99,104,101,32,42,47,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,57,32,38,38,32,108,105,110,101,97,114,95,105,100,32,60,32,40,51,51,60,60,51,41,62,62,50,59,32,121,43,43,32,41,10,123,10,105,110,116,32,120,32,61,32,108,105,110,101,97,114,95,105,100,32,60,60,32,50,59,10,117,105,110,116,52,32,100,97,116,97,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,120,32,43,32,98,97,115,101,120,44,32,121,32,43,32,98,97,115,101,121,41,32,41,59,10,99,97,99,104,101,91,121,32,42,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,49,32,43,32,120,93,32,61,32,100,97,116,97,46,115,48,59,10,99,97,99,104,101,91,121,32,42,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,49,32,43,32,120,32,43,32,49,93,32,61,32,100,97,116,97,46,115,49,59,10,99,97,99,104,101,91,121,32,42,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,49,32,43,32,120,32,43,32,50,93,32,61,32,100,97,116,97,46,115,50,59,10,99,97,99,104,101,91,121,32,42,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,49,32,43,32,120,32,43,32,51,93,32,61,32,100,97,116,97,46,115,51,59,10,125,10,47,42,32,108,111,97,100,32,112,105,120,101,108,115,32,111,110,32,108,101,102,116,32,101,100,103,101,32,42,47,10,105,102,40,32,108,105,110,101,97,114,95,105,100,32,60,32,57,32,41,10,99,97,99,104,101,91,108,105,110,101,97,114,95,105,100,32,42,32,67,65,67,72,69,95,83,84,82,73,68,69,93,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,32,98,97,115,101,120,32,45,32,49,44,32,108,105,110,101,97,114,95,105,100,32,43,32,98,97,115,101,121,41,32,41,46,115,48,59,10,98,97,114,114,105,101,114,40,32,67,76,75,95,76,79,67,65,76,95,77,69,77,95,70,69,78,67,69,32,41,59,10,105,110,116,32,106,32,61,32,108,121,59,10,116,111,112,91,108,120,42,49,54,32,43,32,106,93,32,61,32,40,32,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,99,108,97,109,112,95,105,110,116,40,32,106,32,45,32,49,44,32,45,49,44,32,49,53,32,41,93,32,43,10,50,42,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,99,108,97,109,112,95,105,110,116,40,32,106,44,32,48,44,32,49,53,32,41,93,32,43,10,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,99,108,97,109,112,95,105,110,116,40,32,106,32,43,32,49,44,32,48,44,32,49,53,32,41,93,32,43,32,50,32,41,32,62,62,32,50,59,10,106,32,43,61,32,56,59,10,116,111,112,91,108,120,42,49,54,32,43,32,106,93,32,61,32,40,32,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,99,108,97,109,112,95,105,110,116,40,32,106,32,45,32,49,44,32,45,49,44,32,49,53,32,41,93,32,43,10,50,42,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,99,108,97,109,112,95,105,110,116,40,32,106,44,32,48,44,32,49,53,32,41,93,32,43,10,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,67,65,67,72,69,95,83,84,82,73,68,69,32,43,32,99,108,97,109,112,95,105,110,116,40,32,106,32,43,32,49,44,32,48,44,32,49,53,32,41,93,32,43,32,50,32,41,32,62,62,32,50,59,10,108,101,102,116,91,108,120,42,56,32,43,32,108,121,93,32,61,32,40,32,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,49,32,43,32,67,65,67,72,69,95,83,84,82,73,68,69,42,40,108,121,32,45,32,49,41,93,32,43,10,50,42,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,49,32,43,32,67,65,67,72,69,95,83,84,82,73,68,69,42,108,121,93,32,43,10,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,49,32,43,32,67,65,67,72,69,95,83,84,82,73,68,69,42,99,108,97,109,112,40,40,108,121,32,43,32,49,41,44,32,48,44,32,55,32,41,93,32,43,32,50,32,41,32,62,62,32,50,59,10,105,102,40,32,48,32,61,61,32,108,121,32,41,10,123,10,108,101,102,116,95,116,111,112,91,108,120,93,32,61,32,40,32,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,49,93,32,43,32,50,42,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,49,32,45,32,67,65,67,72,69,95,83,84,82,73,68,69,93,32,43,10,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,32,45,32,67,65,67,72,69,95,83,84,82,73,68,69,93,32,43,32,50,32,41,32,62,62,32,50,59,10,99,111,115,116,95,98,117,102,91,108,120,93,32,61,32,67,79,83,84,95,77,65,88,59,10,125,10,98,97,114,114,105,101,114,40,32,67,76,75,95,76,79,67,65,76,95,77,69,77,95,70,69,78,67,69,32,41,59,10,115,119,105,116,99,104,40,32,108,121,32,41,10,123,10,99,97,115,101,32,48,58,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,104,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,32,41,59,10,98,114,101,97,107,59,10,99,97,115,101,32,49,58,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,118,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,32,41,59,10,98,114,101,97,107,59,10,99,97,115,101,32,50,58,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,100,99,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,32,41,59,10,98,114,101,97,107,59,10,99,97,115,101,32,51,58,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,99,95,112,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,32,41,59,10,98,114,101,97,107,59,10,99,97,115,101,32,52,58,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,100,100,114,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,44,32,38,116,111,112,91,49,54,42,108,120,93,44,32,38,108,101,102,116,91,56,42,108,120,93,44,32,108,101,102,116,95,116,111,112,91,108,120,93,32,41,59,10,98,114,101,97,107,59,10,99,97,115,101,32,53,58,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,118,114,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,44,32,38,116,111,112,91,49,54,42,108,120,93,44,32,38,108,101,102,116,91,56,42,108,120,93,44,32,108,101,102,116,95,116,111,112,91,108,120,93,32,41,59,10,98,114,101,97,107,59,10,99,97,115,101,32,54,58,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,104,100,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,44,32,38,116,111,112,91,49,54,42,108,120,93,44,32,38,108,101,102,116,91,56,42,108,120,93,44,32,108,101,102,116,95,116,111,112,91,108,120,93,32,41,59,10,98,114,101,97,107,59,10,99,97,115,101,32,55,58,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,104,117,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,44,32,38,108,101,102,116,91,56,42,108,120,93,32,41,59,10,98,114,101,97,107,59,10,100,101,102,97,117,108,116,58,10,98,114,101,97,107,59,10,125,10,97,116,111,109,95,109,105,110,40,32,38,99,111,115,116,95,98,117,102,91,108,120,93,44,32,115,97,116,100,32,41,59,10,105,102,40,32,115,108,111,119,32,41,10,123,10,115,119,105,116,99,104,40,32,108,121,32,41,10,123,10,99,97,115,101,32,48,58,32,47,47,32,68,68,76,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,100,100,108,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,44,32,38,116,111,112,91,49,54,42,108,120,93,32,41,59,10,97,116,111,109,95,109,105,110,40,32,38,99,111,115,116,95,98,117,102,91,108,120,93,44,32,115,97,116,100,32,41,59,10,98,114,101,97,107,59,10,99,97,115,101,32,49,58,32,47,47,32,86,76,10,115,97,116,100,32,61,32,120,50,54,52,95,112,114,101,100,105,99,116,95,56,120,56,95,118,108,40,32,38,99,97,99,104,101,91,66,76,79,67,75,95,79,70,70,83,69,84,32,43,32,56,42,108,120,93,44,32,67,65,67,72,69,95,83,84,82,73,68,69,44,32,38,116,111,112,91,49,54,42,108,120,93,32,41,59,10,97,116,111,109,95,109,105,110,40,32,38,99,111,115,116,95,98,117,102,91,108,120,93,44,32,115,97,116,100,32,41,59,10,98,114,101,97,107,59,10,100,101,102,97,117,108,116,58,10,98,114,101,97,107,59,10,125,10,125,10,98,97,114,114,105,101,114,40,32,67,76,75,95,76,79,67,65,76,95,77,69,77,95,70,69,78,67,69,32,41,59,10,105,102,40,32,40,48,32,61,61,32,108,121,41,32,38,38,32,40,103,120,32,60,32,109,98,95,119,105,100,116,104,41,32,41,10,102,101,110,99,95,105,110,116,114,97,95,99,111,115,116,91,103,105,100,121,32,42,32,109,98,95,119,105,100,116,104,32,43,32,103,120,93,32,61,32,99,111,115,116,95,98,117,102,91,108,120,93,43,32,53,42,108,97,109,98,100,97,59,10,105,102,40,32,103,120,32,60,32,50,32,38,38,32,103,121,32,61,61,32,48,32,41,10,102,114,97,109,101,95,115,116,97,116,115,91,103,120,93,32,61,32,48,59,10,35,117,110,100,101,102,32,67,65,67,72,69,95,83,84,82,73,68,69,10,35,117,110,100,101,102,32,66,76,79,67,75,95,79,70,70,83,69,84,10,125,10,47,42,10,42,32,112,97,114,97,108,108,101,108,32,115,117,109,32,105,110,116,114,97,32,99,111,115,116,115,10,42,10,42,32,103,108,111,98,97,108,32,108,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,58,32,91,50,53,54,44,32,109,98,95,104,101,105,103,104,116,93,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,115,117,109,95,105,110,116,114,97,95,99,111,115,116,40,32,99,111,110,115,116,32,103,108,111,98,97,108,32,117,105,110,116,49,54,95,116,32,42,102,101,110,99,95,105,110,116,114,97,95,99,111,115,116,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,117,105,110,116,49,54,95,116,32,42,105,110,118,95,113,115,99,97,108,101,95,102,97,99,116,111,114,44,10,103,108,111,98,97,108,32,105,110,116,32,32,32,32,32,32,32,32,32,32,32,42,102,101,110,99,95,114,111,119,95,115,97,116,100,115,44,10,103,108,111,98,97,108,32,105,110,116,32,32,32,32,32,32,32,32,32,32,32,42,102,114,97,109,101,95,115,116,97,116,115,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,98,95,119,105,100,116,104,32,41,10,123,10,105,110,116,32,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,32,109,98,95,104,101,105,103,104,116,32,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,49,32,41,59,10,105,110,116,32,114,111,119,95,115,97,116,100,115,32,61,32,48,59,10,105,110,116,32,99,111,115,116,95,101,115,116,32,61,32,48,59,10,105,110,116,32,99,111,115,116,95,101,115,116,95,97,113,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,32,120,32,60,32,109,98,95,119,105,100,116,104,59,32,120,32,43,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,48,32,41,41,10,123,10,105,110,116,32,109,98,95,120,121,32,61,32,120,32,43,32,121,32,42,32,109,98,95,119,105,100,116,104,59,10,105,110,116,32,99,111,115,116,32,61,32,102,101,110,99,95,105,110,116,114,97,95,99,111,115,116,91,109,98,95,120,121,93,59,10,105,110,116,32,99,111,115,116,95,97,113,32,61,32,40,99,111,115,116,32,42,32,105,110,118,95,113,115,99,97,108,101,95,102,97,99,116,111,114,91,109,98,95,120,121,93,32,43,32,49,50,56,41,32,62,62,32,56,59,10,105,110,116,32,98,95,102,114,97,109,101,95,115,99,111,114,101,95,109,98,32,61,32,40,120,32,62,32,48,32,38,38,32,120,32,60,32,109,98,95,119,105,100,116,104,32,45,32,49,32,38,38,32,121,32,62,32,48,32,38,38,32,121,32,60,32,109,98,95,104,101,105,103,104,116,32,45,32,49,41,32,124,124,32,109,98,95,119,105,100,116,104,32,60,61,32,50,32,124,124,32,109,98,95,104,101,105,103,104,116,32,60,61,32,50,59,10,114,111,119,95,115,97,116,100,115,32,43,61,32,99,111,115,116,95,97,113,59,10,105,102,40,32,98,95,102,114,97,109,101,95,115,99,111,114,101,95,109,98,32,41,10,123,10,99,111,115,116,95,101,115,116,32,43,61,32,99,111,115,116,59,10,99,111,115,116,95,101,115,116,95,97,113,32,43,61,32,99,111,115,116,95,97,113,59,10,125,10,125,10,108,111,99,97,108,32,105,110,116,32,98,117,102,102,101,114,91,50,53,54,93,59,10,105,110,116,32,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,114,111,119,95,115,97,116,100,115,32,32,32,61,32,112,97,114,97,108,108,101,108,95,115,117,109,40,32,114,111,119,95,115,97,116,100,115,44,32,120,44,32,98,117,102,102,101,114,32,41,59,10,99,111,115,116,95,101,115,116,32,32,32,32,61,32,112,97,114,97,108,108,101,108,95,115,117,109,40,32,99,111,115,116,95,101,115,116,44,32,120,44,32,98,117,102,102,101,114,32,41,59,10,99,111,115,116,95,101,115,116,95,97,113,32,61,32,112,97,114,97,108,108,101,108,95,115,117,109,40,32,99,111,115,116,95,101,115,116,95,97,113,44,32,120,44,32,98,117,102,102,101,114,32,41,59,10,105,102,40,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,32,61,61,32,48,32,41,10,123,10,102,101,110,99,95,114,111,119,95,115,97,116,100,115,91,121,93,32,61,32,114,111,119,95,115,97,116,100,115,59,10,97,116,111,109,105,99,95,97,100,100,40,32,102,114,97,109,101,95,115,116,97,116,115,32,43,32,67,79,83,84,95,69,83,84,44,32,32,32,32,99,111,115,116,95,101,115,116,32,41,59,10,97,116,111,109,105,99,95,97,100,100,40,32,102,114,97,109,101,95,115,116,97,116,115,32,43,32,67,79,83,84,95,69,83,84,95,65,81,44,32,99,111,115,116,95,101,115,116,95,97,113,32,41,59,10,125,10,125,10,47,42,32,72,105,101,114,97,114,99,104,105,99,97,108,32,40,105,116,101,114,97,116,105,118,101,41,32,79,112,101,110,67,76,32,108,111,119,114,101,115,32,109,111,116,105,111,110,32,115,101,97,114,99,104,32,42,47,10,105,110,108,105,110,101,32,105,110,116,32,102,105,110,100,95,100,111,119,110,115,99,97,108,101,95,109,98,95,120,121,40,32,105,110,116,32,120,44,32,105,110,116,32,121,44,32,105,110,116,32,109,98,95,119,105,100,116,104,44,32,105,110,116,32,109,98,95,104,101,105,103,104,116,32,41,10,123,10,47,42,32,101,100,103,101,32,109,97,99,114,111,98,108,111,99,107,115,32,109,105,103,104,116,32,110,111,116,32,104,97,118,101,32,97,32,100,105,114,101,99,116,32,100,101,115,99,101,110,100,97,110,116,44,32,117,115,101,32,110,101,97,114,101,115,116,32,42,47,10,120,32,61,32,115,101,108,101,99,116,40,32,120,32,62,62,32,49,44,32,40,120,32,45,32,40,109,98,95,119,105,100,116,104,38,49,41,41,32,62,62,32,49,44,32,120,32,61,61,32,109,98,95,119,105,100,116,104,45,49,32,41,59,10,121,32,61,32,115,101,108,101,99,116,40,32,121,32,62,62,32,49,44,32,40,121,32,45,32,40,109,98,95,104,101,105,103,104,116,38,49,41,41,32,62,62,32,49,44,32,121,32,61,61,32,109,98,95,104,101,105,103,104,116,45,49,32,41,59,10,114,101,116,117,114,110,32,40,109,98,95,119,105,100,116,104,62,62,49,41,32,42,32,121,32,43,32,120,59,10,125,10,47,42,32,70,111,117,114,32,116,104,114,101,97,100,115,32,99,97,108,99,117,108,97,116,101,32,97,110,32,56,120,56,32,83,65,68,46,32,32,69,97,99,104,32,100,111,101,115,32,116,119,111,32,114,111,119,115,32,42,47,10,105,110,116,32,115,97,100,95,56,120,56,95,105,105,95,99,111,111,112,52,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,101,110,99,44,32,105,110,116,50,32,102,101,110,99,112,111,115,44,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,114,101,102,44,32,105,110,116,50,32,102,114,101,102,112,111,115,44,32,105,110,116,32,105,100,120,44,32,108,111,99,97,108,32,105,110,116,49,54,95,116,32,42,99,111,115,116,115,32,41,10,123,10,102,114,101,102,112,111,115,46,121,32,43,61,32,105,100,120,32,60,60,32,49,59,10,102,101,110,99,112,111,115,46,121,32,43,61,32,105,100,120,32,60,60,32,49,59,10,105,110,116,32,99,111,115,116,32,61,32,48,59,10,105,102,40,32,102,114,101,102,112,111,115,46,120,32,60,32,48,32,41,10,123,10,47,42,32,115,108,111,119,32,112,97,116,104,32,119,104,101,110,32,77,86,32,103,111,101,115,32,112,97,115,116,32,108,101,102,116,32,101,100,103,101,46,32,32,84,104,101,32,71,80,85,32,99,108,97,109,112,115,32,114,101,97,100,115,32,102,114,111,109,10,42,32,40,45,49,44,32,48,41,32,116,111,32,40,48,44,48,41,44,32,115,111,32,121,111,117,32,103,101,116,32,112,105,120,101,108,115,32,91,48,44,32,49,44,32,50,44,32,51,93,32,119,104,101,110,32,119,104,97,116,32,121,111,117,32,114,101,97,108,108,121,10,42,32,119,97,110,116,32,97,114,101,32,91,48,44,32,48,44,32,49,44,32,50,93,10,42,47,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,50,59,32,121,43,43,32,41,10,123,10,102,111,114,40,32,105,110,116,32,120,32,61,32,48,59,32,120,32,60,32,56,59,32,120,43,43,32,41,10,123,10,112,105,120,101,108,32,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,32,41,46,115,48,59,10,112,105,120,101,108,32,114,101,102,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,32,41,46,115,48,59,10,99,111,115,116,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,114,101,102,32,41,59,10,125,10,125,10,125,10,101,108,115,101,10,123,10,117,105,110,116,52,32,101,110,99,44,32,114,101,102,44,32,99,111,115,116,115,32,61,32,48,59,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,41,59,10,114,101,102,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,41,59,10,99,111,115,116,115,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,114,101,102,32,41,59,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,52,44,32,48,41,32,41,59,10,114,101,102,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,52,44,32,48,41,32,41,59,10,99,111,115,116,115,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,114,101,102,32,41,59,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,48,44,32,49,41,32,41,59,10,114,101,102,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,48,44,32,49,41,32,41,59,10,99,111,115,116,115,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,114,101,102,32,41,59,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,52,44,32,49,41,32,41,59,10,114,101,102,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,52,44,32,49,41,32,41,59,10,99,111,115,116,115,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,114,101,102,32,41,59,10,99,111,115,116,32,61,32,99,111,115,116,115,46,115,48,32,43,32,99,111,115,116,115,46,115,49,32,43,32,99,111,115,116,115,46,115,50,32,43,32,99,111,115,116,115,46,115,51,59,10,125,10,99,111,115,116,115,91,105,100,120,93,32,61,32,99,111,115,116,59,10,114,101,116,117,114,110,32,99,111,115,116,115,91,48,93,32,43,32,99,111,115,116,115,91,49,93,32,43,32,99,111,115,116,115,91,50,93,32,43,32,99,111,115,116,115,91,51,93,59,10,125,10,47,42,32,79,110,101,32,116,104,114,101,97,100,32,112,101,114,102,111,114,109,115,32,56,120,56,32,83,65,68,32,42,47,10,105,110,116,32,115,97,100,95,56,120,56,95,105,105,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,101,110,99,44,32,105,110,116,50,32,102,101,110,99,112,111,115,44,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,114,101,102,44,32,105,110,116,50,32,102,114,101,102,112,111,115,32,41,10,123,10,105,102,40,32,102,114,101,102,112,111,115,46,120,32,60,32,48,32,41,10,123,10,47,42,32,115,108,111,119,32,112,97,116,104,32,119,104,101,110,32,77,86,32,103,111,101,115,32,112,97,115,116,32,108,101,102,116,32,101,100,103,101,32,42,47,10,105,110,116,32,99,111,115,116,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,56,59,32,121,43,43,32,41,10,123,10,102,111,114,40,32,105,110,116,32,120,32,61,32,48,59,32,120,32,60,32,56,59,32,120,43,43,32,41,10,123,10,117,105,110,116,32,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,32,41,46,115,48,59,10,117,105,110,116,32,114,101,102,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,32,41,46,115,48,59,10,99,111,115,116,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,114,101,102,32,41,59,10,125,10,125,10,114,101,116,117,114,110,32,99,111,115,116,59,10,125,10,101,108,115,101,10,123,10,117,105,110,116,52,32,101,110,99,44,32,114,101,102,44,32,99,111,115,116,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,56,59,32,121,43,43,32,41,10,123,10,102,111,114,40,32,105,110,116,32,120,32,61,32,48,59,32,120,32,60,32,56,59,32,120,32,43,61,32,52,32,41,10,123,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,32,41,59,10,114,101,102,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,32,41,59,10,99,111,115,116,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,114,101,102,32,41,59,10,125,10,125,10,114,101,116,117,114,110,32,99,111,115,116,46,115,48,32,43,32,99,111,115,116,46,115,49,32,43,32,99,111,115,116,46,115,50,32,43,32,99,111,115,116,46,115,51,59,10,125,10,125,10,47,42,10,42,32,104,105,101,114,97,114,99,104,105,99,97,108,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,10,42,10,42,32,69,97,99,104,32,107,101,114,110,101,108,32,108,97,117,110,99,104,32,105,115,32,97,32,115,105,110,103,108,101,32,105,116,101,114,97,116,105,111,110,10,42,10,42,32,77,66,32,112,101,114,32,119,111,114,107,32,103,114,111,117,112,32,105,115,32,100,101,116,101,114,109,105,110,101,100,32,98,121,32,108,99,108,120,32,47,32,52,32,42,32,108,99,108,121,10,42,10,42,32,103,108,111,98,97,108,32,108,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,58,32,32,91,109,98,95,119,105,100,116,104,32,42,32,52,44,32,109,98,95,104,101,105,103,104,116,93,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,104,105,101,114,97,114,99,104,105,99,97,108,95,109,111,116,105,111,110,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,32,102,101,110,99,44,10,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,32,102,114,101,102,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,115,104,111,114,116,50,32,42,105,110,95,109,118,115,44,10,103,108,111,98,97,108,32,115,104,111,114,116,50,32,32,32,32,32,32,32,42,111,117,116,95,109,118,115,44,10,103,108,111,98,97,108,32,105,110,116,49,54,95,116,32,32,32,32,32,32,42,111,117,116,95,109,118,95,99,111,115,116,115,44,10,103,108,111,98,97,108,32,115,104,111,114,116,50,32,32,32,32,32,32,32,42,109,118,112,95,98,117,102,102,101,114,44,10,108,111,99,97,108,32,105,110,116,49,54,95,116,32,32,32,32,32,32,32,42,99,111,115,116,95,108,111,99,97,108,44,10,108,111,99,97,108,32,115,104,111,114,116,50,32,32,32,32,32,32,32,32,42,109,118,99,95,108,111,99,97,108,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,98,95,119,105,100,116,104,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,108,97,109,98,100,97,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,101,95,114,97,110,103,101,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,115,99,97,108,101,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,95,115,104,105,102,116,95,105,110,100,101,120,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,95,102,105,114,115,116,95,105,116,101,114,97,116,105,111,110,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,95,114,101,118,101,114,115,101,95,114,101,102,101,114,101,110,99,101,115,32,41,10,123,10,105,110,116,32,109,98,95,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,32,62,62,32,50,59,10,105,102,40,32,109,98,95,120,32,62,61,32,109,98,95,119,105,100,116,104,32,41,10,114,101,116,117,114,110,59,10,105,110,116,32,109,98,95,104,101,105,103,104,116,32,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,49,32,41,59,10,105,110,116,32,109,98,95,105,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,32,38,32,51,59,10,105,110,116,32,109,98,95,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,32,109,98,95,120,121,32,61,32,109,98,95,121,32,42,32,109,98,95,119,105,100,116,104,32,43,32,109,98,95,120,59,10,99,111,110,115,116,32,105,110,116,32,109,98,95,115,105,122,101,32,61,32,56,59,10,105,110,116,50,32,99,111,111,114,100,32,61,32,40,105,110,116,50,41,40,109,98,95,120,44,32,109,98,95,121,41,32,42,32,109,98,95,115,105,122,101,59,10,99,111,110,115,116,32,105,110,116,32,109,98,95,105,110,95,103,114,111,117,112,32,61,32,103,101,116,95,108,111,99,97,108,95,105,100], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+71680);
/* memory initializer */ allocate([40,32,49,32,41,32,42,32,40,103,101,116,95,108,111,99,97,108,95,115,105,122,101,40,32,48,32,41,32,62,62,32,50,41,32,43,32,40,103,101,116,95,108,111,99,97,108,95,105,100,40,32,48,32,41,32,62,62,32,50,41,59,10,99,111,115,116,95,108,111,99,97,108,32,43,61,32,52,32,42,32,109,98,95,105,110,95,103,114,111,117,112,59,10,105,110,116,32,105,95,109,118,99,32,61,32,48,59,10,109,118,99,95,108,111,99,97,108,32,43,61,32,52,32,42,32,109,98,95,105,110,95,103,114,111,117,112,59,10,109,118,99,95,108,111,99,97,108,91,109,98,95,105,93,32,61,32,48,59,10,105,110,116,50,32,109,118,112,32,61,48,59,10,105,102,40,32,33,98,95,102,105,114,115,116,95,105,116,101,114,97,116,105,111,110,32,41,10,123,10,35,100,101,102,105,110,101,32,77,86,67,40,32,68,88,44,32,68,89,32,41,92,10,123,92,10,105,110,116,32,112,120,32,61,32,109,98,95,120,32,43,32,68,88,59,92,10,105,110,116,32,112,121,32,61,32,109,98,95,121,32,43,32,68,89,59,92,10,109,118,99,95,108,111,99,97,108,91,105,95,109,118,99,93,32,61,32,98,95,115,104,105,102,116,95,105,110,100,101,120,32,63,32,105,110,95,109,118,115,91,102,105,110,100,95,100,111,119,110,115,99,97,108,101,95,109,98,95,120,121,40,32,112,120,44,32,112,121,44,32,109,98,95,119,105,100,116,104,44,32,109,98,95,104,101,105,103,104,116,32,41,93,32,58,32,92,10,105,110,95,109,118,115,91,109,98,95,119,105,100,116,104,32,42,32,112,121,32,43,32,112,120,93,59,92,10,109,118,99,95,108,111,99,97,108,91,105,95,109,118,99,93,32,62,62,61,32,40,115,104,111,114,116,41,32,115,99,97,108,101,59,92,10,105,95,109,118,99,43,43,59,92,10,125,10,47,42,32,70,105,110,100,32,77,86,80,32,102,114,111,109,32,109,101,100,105,97,110,32,111,102,32,77,86,67,115,32,42,47,10,105,102,40,32,98,95,114,101,118,101,114,115,101,95,114,101,102,101,114,101,110,99,101,115,32,41,10,123,10,47,42,32,111,100,100,32,105,116,101,114,97,116,105,111,110,115,58,32,100,101,114,105,118,101,32,77,86,80,32,102,114,111,109,32,100,111,119,110,32,97,110,100,32,114,105,103,104,116,32,42,47,10,105,102,40,32,109,98,95,120,32,60,32,109,98,95,119,105,100,116,104,32,45,32,49,32,41,10,77,86,67,40,32,49,44,32,48,32,41,59,10,105,102,40,32,109,98,95,121,32,60,32,109,98,95,104,101,105,103,104,116,32,45,32,49,32,41,10,123,10,77,86,67,40,32,48,44,32,49,32,41,59,10,105,102,40,32,109,98,95,120,32,62,32,98,95,115,104,105,102,116,95,105,110,100,101,120,32,41,10,77,86,67,40,32,45,49,44,32,49,32,41,59,10,105,102,40,32,109,98,95,120,32,60,32,109,98,95,119,105,100,116,104,32,45,32,49,32,41,10,77,86,67,40,32,49,44,32,49,32,41,59,10,125,10,125,10,101,108,115,101,10,123,10,47,42,32,101,118,101,110,32,105,116,101,114,97,116,105,111,110,115,58,32,100,101,114,105,118,101,32,77,86,80,32,102,114,111,109,32,117,112,32,97,110,100,32,108,101,102,116,32,42,47,10,105,102,40,32,109,98,95,120,32,62,32,48,32,41,10,77,86,67,40,32,45,49,44,32,48,32,41,59,10,105,102,40,32,109,98,95,121,32,62,32,48,32,41,10,123,10,77,86,67,40,32,48,44,32,45,49,32,41,59,10,105,102,40,32,109,98,95,120,32,60,32,109,98,95,119,105,100,116,104,32,45,32,49,32,41,10,77,86,67,40,32,49,44,32,45,49,32,41,59,10,105,102,40,32,109,98,95,120,32,62,32,98,95,115,104,105,102,116,95,105,110,100,101,120,32,41,10,77,86,67,40,32,45,49,44,32,45,49,32,41,59,10,125,10,125,10,35,117,110,100,101,102,32,77,86,67,10,109,118,112,32,61,32,40,105,95,109,118,99,32,60,61,32,49,41,32,63,32,99,111,110,118,101,114,116,95,105,110,116,50,95,115,97,116,40,109,118,99,95,108,111,99,97,108,91,48,93,41,32,58,32,120,50,54,52,95,109,101,100,105,97,110,95,109,118,40,32,109,118,99,95,108,111,99,97,108,91,48,93,44,32,109,118,99,95,108,111,99,97,108,91,49,93,44,32,109,118,99,95,108,111,99,97,108,91,50,93,32,41,59,10,125,10,47,42,32,99,117,114,114,101,110,116,32,109,118,112,32,109,97,116,99,104,101,115,32,116,104,101,32,112,114,101,118,105,111,117,115,32,109,118,112,32,97,110,100,32,119,101,32,104,97,118,101,32,110,111,116,32,99,104,97,110,103,101,100,32,115,99,97,108,101,46,32,32,87,101,32,107,110,111,119,10,42,32,119,101,39,114,101,32,103,111,105,110,103,32,116,111,32,97,114,114,105,118,101,32,97,116,32,116,104,101,32,115,97,109,101,32,77,86,32,97,103,97,105,110,44,32,115,111,32,106,117,115,116,32,99,111,112,121,32,116,104,101,32,112,114,101,118,105,111,117,115,10,42,32,114,101,115,117,108,116,32,116,111,32,111,117,114,32,111,117,116,112,117,116,46,32,42,47,10,105,102,40,32,33,98,95,115,104,105,102,116,95,105,110,100,101,120,32,38,38,32,109,118,112,46,120,32,61,61,32,109,118,112,95,98,117,102,102,101,114,91,109,98,95,120,121,93,46,120,32,38,38,32,109,118,112,46,121,32,61,61,32,109,118,112,95,98,117,102,102,101,114,91,109,98,95,120,121,93,46,121,32,41,10,123,10,111,117,116,95,109,118,115,91,109,98,95,120,121,93,32,61,32,105,110,95,109,118,115,91,109,98,95,120,121,93,59,10,114,101,116,117,114,110,59,10,125,10,109,118,112,95,98,117,102,102,101,114,91,109,98,95,120,121,93,32,61,32,99,111,110,118,101,114,116,95,115,104,111,114,116,50,95,115,97,116,40,109,118,112,41,59,10,105,110,116,50,32,109,118,95,109,105,110,32,61,32,45,109,98,95,115,105,122,101,32,42,32,40,105,110,116,50,41,40,109,98,95,120,44,32,109,98,95,121,41,32,45,32,52,59,10,105,110,116,50,32,109,118,95,109,97,120,32,61,32,109,98,95,115,105,122,101,32,42,32,40,40,105,110,116,50,41,40,109,98,95,119,105,100,116,104,44,32,109,98,95,104,101,105,103,104,116,41,32,45,32,40,105,110,116,50,41,40,109,98,95,120,44,32,109,98,95,121,41,32,45,32,49,41,32,43,32,52,59,10,105,110,116,50,32,98,101,115,116,109,118,32,61,32,99,108,97,109,112,40,109,118,112,44,32,109,118,95,109,105,110,44,32,109,118,95,109,97,120,41,59,10,105,110,116,50,32,114,101,102,99,114,100,32,61,32,99,111,111,114,100,32,43,32,98,101,115,116,109,118,59,10,47,42,32,109,101,97,115,117,114,101,32,99,111,115,116,32,97,116,32,98,101,115,116,109,118,32,42,47,10,105,110,116,32,98,99,111,115,116,32,61,32,115,97,100,95,56,120,56,95,105,105,95,99,111,111,112,52,40,32,102,101,110,99,44,32,99,111,111,114,100,44,32,102,114,101,102,44,32,114,101,102,99,114,100,44,32,109,98,95,105,44,32,99,111,115,116,95,108,111,99,97,108,32,41,32,43,10,108,97,109,98,100,97,32,42,32,109,118,95,99,111,115,116,40,32,97,98,115,95,100,105,102,102,40,32,98,101,115,116,109,118,44,32,109,118,112,32,41,32,60,60,32,40,50,32,43,32,115,99,97,108,101,41,32,41,59,10,100,111,10,123,10,47,42,32,109,101,97,115,117,114,101,32,99,111,115,116,115,32,97,116,32,111,102,102,115,101,116,115,32,102,114,111,109,32,98,101,115,116,109,118,32,42,47,10,114,101,102,99,114,100,32,61,32,99,111,111,114,100,32,43,32,98,101,115,116,109,118,32,43,32,100,105,97,95,111,102,102,115,91,109,98,95,105,93,59,10,105,110,116,50,32,116,114,121,109,118,32,61,32,98,101,115,116,109,118,32,43,32,100,105,97,95,111,102,102,115,91,109,98,95,105,93,59,10,105,110,116,32,99,111,115,116,32,61,32,115,97,100,95,56,120,56,95,105,105,40,32,102,101,110,99,44,32,99,111,111,114,100,44,32,102,114,101,102,44,32,114,101,102,99,114,100,32,41,32,43,10,108,97,109,98,100,97,32,42,32,109,118,95,99,111,115,116,40,32,97,98,115,95,100,105,102,102,40,32,116,114,121,109,118,44,32,109,118,112,32,41,32,60,60,32,40,50,32,43,32,115,99,97,108,101,41,32,41,59,10,99,111,115,116,95,108,111,99,97,108,91,109,98,95,105,93,32,61,32,40,99,111,115,116,60,60,50,41,32,124,32,109,98,95,105,59,10,99,111,115,116,32,61,32,109,105,110,40,32,99,111,115,116,95,108,111,99,97,108,91,48,93,44,32,109,105,110,40,32,99,111,115,116,95,108,111,99,97,108,91,49,93,44,32,109,105,110,40,32,99,111,115,116,95,108,111,99,97,108,91,50,93,44,32,99,111,115,116,95,108,111,99,97,108,91,51,93,32,41,32,41,32,41,59,10,105,102,40,32,40,99,111,115,116,32,62,62,32,50,41,32,62,61,32,98,99,111,115,116,32,41,10,98,114,101,97,107,59,10,98,101,115,116,109,118,32,43,61,32,100,105,97,95,111,102,102,115,91,99,111,115,116,38,51,93,59,10,98,99,111,115,116,32,61,32,99,111,115,116,62,62,50,59,10,105,102,40,32,98,101,115,116,109,118,46,120,32,62,61,32,109,118,95,109,97,120,46,120,32,124,124,32,98,101,115,116,109,118,46,120,32,60,61,32,109,118,95,109,105,110,46,120,32,124,124,32,98,101,115,116,109,118,46,121,32,62,61,32,109,118,95,109,97,120,46,121,32,124,124,32,98,101,115,116,109,118,46,121,32,60,61,32,109,118,95,109,105,110,46,121,32,41,10,98,114,101,97,107,59,10,125,10,119,104,105,108,101,40,32,45,45,109,101,95,114,97,110,103,101,32,62,32,48,32,41,59,10,105,110,116,50,32,116,114,121,109,118,32,61,32,48,44,32,100,105,102,102,32,61,32,48,59,10,35,100,101,102,105,110,101,32,67,79,83,84,95,77,86,95,78,79,95,80,65,68,40,32,76,32,41,92,10,116,114,121,109,118,32,61,32,99,108,97,109,112,40,32,116,114,121,109,118,44,32,109,118,95,109,105,110,44,32,109,118,95,109,97,120,32,41,59,92,10,100,105,102,102,32,61,32,99,111,110,118,101,114,116,95,105,110,116,50,95,115,97,116,40,97,98,115,95,100,105,102,102,40,32,109,118,112,44,32,116,114,121,109,118,32,41,41,59,92,10,105,102,40,32,100,105,102,102,46,120,32,62,32,49,32,124,124,32,100,105,102,102,46,121,32,62,32,49,32,41,32,123,92,10,105,110,116,50,32,114,101,102,99,114,100,32,61,32,99,111,111,114,100,32,43,32,116,114,121,109,118,59,92,10,105,110,116,32,99,111,115,116,32,61,32,115,97,100,95,56,120,56,95,105,105,95,99,111,111,112,52,40,32,102,101,110,99,44,32,99,111,111,114,100,44,32,102,114,101,102,44,32,114,101,102,99,114,100,44,32,109,98,95,105,44,32,99,111,115,116,95,108,111,99,97,108,32,41,32,43,92,10,76,32,42,32,109,118,95,99,111,115,116,40,32,97,98,115,95,100,105,102,102,40,32,116,114,121,109,118,44,32,109,118,112,32,41,32,60,60,32,40,50,32,43,32,115,99,97,108,101,41,32,41,59,92,10,105,102,40,32,99,111,115,116,32,60,32,98,99,111,115,116,32,41,32,123,32,98,99,111,115,116,32,61,32,99,111,115,116,59,32,98,101,115,116,109,118,32,61,32,116,114,121,109,118,59,32,125,32,125,10,67,79,83,84,95,77,86,95,78,79,95,80,65,68,40,32,48,32,41,59,10,105,102,40,32,33,98,95,102,105,114,115,116,95,105,116,101,114,97,116,105,111,110,32,41,10,123,10,47,42,32,116,114,121,32,99,111,115,116,32,97,116,32,112,114,101,118,105,111,117,115,32,105,116,101,114,97,116,105,111,110,39,115,32,77,86,44,32,105,102,32,77,86,80,32,119,97,115,32,116,111,111,32,102,97,114,32,97,119,97,121,32,42,47,10,105,110,116,50,32,112,114,101,118,109,118,32,61,32,98,95,115,104,105,102,116,95,105,110,100,101,120,32,63,32,99,111,110,118,101,114,116,95,105,110,116,50,95,115,97,116,40,105,110,95,109,118,115,91,102,105,110,100,95,100,111,119,110,115,99,97,108,101,95,109,98,95,120,121,40,32,109,98,95,120,44,32,109,98,95,121,44,32,109,98,95,119,105,100,116,104,44,32,109,98,95,104,101,105,103,104,116,32,41,93,41,32,58,32,99,111,110,118,101,114,116,95,105,110,116,50,95,115,97,116,40,105,110,95,109,118,115,91,109,98,95,120,121,93,41,59,10,112,114,101,118,109,118,32,62,62,61,32,115,99,97,108,101,59,10,116,114,121,109,118,32,61,32,112,114,101,118,109,118,59,10,67,79,83,84,95,77,86,95,78,79,95,80,65,68,40,32,108,97,109,98,100,97,32,41,59,10,125,10,102,111,114,40,32,105,110,116,32,105,32,61,32,48,59,32,105,32,60,32,105,95,109,118,99,59,32,105,43,43,32,41,10,123,10,47,42,32,116,114,121,32,99,111,115,116,32,97,116,32,101,97,99,104,32,99,97,110,100,105,100,97,116,101,32,77,86,44,32,105,102,32,77,86,80,32,119,97,115,32,116,111,111,32,102,97,114,32,97,119,97,121,32,42,47,10,116,114,121,109,118,32,61,32,99,111,110,118,101,114,116,95,105,110,116,50,95,115,97,116,40,32,109,118,99,95,108,111,99,97,108,91,105,93,32,41,59,10,67,79,83,84,95,77,86,95,78,79,95,80,65,68,40,32,108,97,109,98,100,97,32,41,59,10,125,10,105,102,40,32,109,98,95,105,32,61,61,32,48,32,41,10,123,10,98,101,115,116,109,118,32,60,60,61,32,115,99,97,108,101,59,10,111,117,116,95,109,118,115,91,109,98,95,120,121,93,32,61,32,99,111,110,118,101,114,116,95,115,104,111,114,116,50,95,115,97,116,40,98,101,115,116,109,118,41,59,10,111,117,116,95,109,118,95,99,111,115,116,115,91,109,98,95,120,121,93,32,61,32,109,105,110,40,32,98,99,111,115,116,44,32,76,79,87,82,69,83,95,67,79,83,84,95,77,65,83,75,32,41,59,10,125,10,125,10,47,42,32,79,112,101,110,67,76,32,108,111,119,114,101,115,32,115,117,98,112,101,108,32,82,101,102,105,110,101,32,42,47,10,47,42,32,69,97,99,104,32,116,104,114,101,97,100,32,112,101,114,102,111,114,109,115,32,56,120,56,32,83,65,68,46,32,32,52,32,116,104,114,101,97,100,115,32,112,101,114,32,77,66,44,32,115,111,32,116,104,101,32,52,32,68,73,65,32,72,80,69,76,32,111,102,102,115,101,116,115,32,97,114,101,10,42,32,99,97,108,99,117,108,97,116,101,100,32,115,105,109,117,108,116,97,110,101,111,117,115,108,121,32,42,47,10,105,110,116,32,115,97,100,95,56,120,56,95,105,105,95,104,112,101,108,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,101,110,99,44,32,105,110,116,50,32,102,101,110,99,112,111,115,44,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,114,101,102,95,112,108,97,110,101,115,44,32,105,110,116,50,32,113,112,111,115,32,41,10,123,10,105,110,116,50,32,102,114,101,102,112,111,115,32,61,32,113,112,111,115,32,62,62,32,50,59,10,105,110,116,32,104,112,101,108,95,105,100,120,32,61,32,40,40,113,112,111,115,46,120,32,38,32,50,41,32,62,62,32,49,41,32,43,32,40,113,112,111,115,46,121,32,38,32,50,41,59,10,117,105,110,116,32,109,97,115,107,95,115,104,105,102,116,32,61,32,56,32,42,32,104,112,101,108,95,105,100,120,59,10,117,105,110,116,52,32,99,111,115,116,52,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,56,59,32,121,43,43,32,41,10,123,10,117,105,110,116,52,32,101,110,99,44,32,118,97,108,52,59,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,48,44,32,121,41,41,59,10,118,97,108,52,46,115,48,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,48,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,41,32,38,32,48,120,70,70,59,10,118,97,108,52,46,115,49,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,49,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,41,32,38,32,48,120,70,70,59,10,118,97,108,52,46,115,50,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,50,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,41,32,38,32,48,120,70,70,59,10,118,97,108,52,46,115,51,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,51,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,41,32,38,32,48,120,70,70,59,10,99,111,115,116,52,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,118,97,108,52,32,41,59,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,52,44,32,121,41,41,59,10,118,97,108,52,46,115,48,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,52,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,41,32,38,32,48,120,70,70,59,10,118,97,108,52,46,115,49,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,53,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,41,32,38,32,48,120,70,70,59,10,118,97,108,52,46,115,50,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,54,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,41,32,38,32,48,120,70,70,59,10,118,97,108,52,46,115,51,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,112,111,115,32,43,32,40,105,110,116,50,41,40,55,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,41,32,38,32,48,120,70,70,59,10,99,111,115,116,52,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,118,97,108,52,32,41,59,10,125,10,114,101,116,117,114,110,32,99,111,115,116,52,46,115,48,32,43,32,99,111,115,116,52,46,115,49,32,43,32,99,111,115,116,52,46,115,50,32,43,32,99,111,115,116,52,46,115,51,59,10,125,10,47,42,32,79,110,101,32,116,104,114,101,97,100,32,109,101,97,115,117,114,101,115,32,56,120,56,32,83,65,68,32,99,111,115,116,32,97,116,32,97,32,81,80,69,76,32,111,102,102,115,101,116,32,105,110,116,111,32,97,110,32,72,80,69,76,32,112,108,97,110,101,32,42,47,10,105,110,116,32,115,97,100,95,56,120,56,95,105,105,95,113,112,101,108,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,101,110,99,44,32,105,110,116,50,32,102,101,110,99,112,111,115,44,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,114,101,102,95,112,108,97,110,101,115,44,32,105,110,116,50,32,113,112,111,115,32,41,10,123,10,105,110,116,50,32,102,114,101,102,65,112,111,115,32,61,32,113,112,111,115,32,62,62,32,50,59,10,105,110,116,32,104,112,101,108,65,32,61,32,40,40,113,112,111,115,46,120,32,38,32,50,41,32,62,62,32,49,41,32,43,32,40,113,112,111,115,46,121,32,38,32,50,41,59,10,105,110,116,50,32,113,112,111,115,66,32,61,32,113,112,111,115,32,43,32,40,40,113,112,111,115,32,38,32,49,41,32,60,60,32,49,41,59,10,105,110,116,50,32,102,114,101,102,66,112,111,115,32,61,32,113,112,111,115,66,32,62,62,32,50,59,10,105,110,116,32,104,112,101,108,66,32,61,32,40,40,113,112,111,115,66,46,120,32,38,32,50,41,32,62,62,32,49,41,32,43,32,40,113,112,111,115,66,46,121,32,38,32,50,41,59,10,117,105,110,116,32,109,97,115,107,95,115,104,105,102,116,48,32,61,32,56,32,42,32,104,112,101,108,65,44,32,109,97,115,107,95,115,104,105,102,116,49,32,61,32,56,32,42,32,104,112,101,108,66,59,10,105,110,116,32,99,111,115,116,32,61,32,48,59,10,102,111,114,40,32,105,110,116,32,121,32,61,32,48,59,32,121,32,60,32,56,59,32,121,43,43,32,41,10,123,10,102,111,114,40,32,105,110,116,32,120,32,61,32,48,59,32,120,32,60,32,56,59,32,120,43,43,32,41,10,123,10,117,105,110,116,32,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,41,46,115,48,59,10,117,105,110,116,32,118,65,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,65,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,48,41,32,38,32,48,120,70,70,59,10,117,105,110,116,32,118,66,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,66,112,111,115,32,43,32,40,105,110,116,50,41,40,120,44,32,121,41,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,49,41,32,38,32,48,120,70,70,59,10,99,111,115,116,32,43,61,32,97,98,115,95,100,105,102,102,40,32,101,110,99,44,32,114,104,97,100,100,40,32,118,65,44,32,118,66,32,41,32,41,59,10,125,10,125,10,114,101,116,117,114,110,32,99,111,115,116,59,10,125,10,47,42,32,70,111,117,114,32,116,104,114,101,97,100,115,32,109,101,97,115,117,114,101,32,56,120,56,32,83,65,84,68,32,99,111,115,116,32,97,116,32,97,32,81,80,69,76,32,111,102,102,115,101,116,32,105,110,116,111,32,97,110,32,72,80,69,76,32,112,108,97,110,101,10,42,10,42,32,69,97,99,104,32,116,104,114,101,97,100,32,99,111,108,108,101,99,116,115,32,49,47,52,32,111,102,32,116,104,101,32,114,111,119,115,32,111,102,32,100,105,102,102,115,32,97,110,100,32,112,114,111,99,101,115,115,101,115,32,111,110,101,32,113,117,97,114,116,101,114,32,111,102,10,42,32,116,104,101,32,116,114,97,110,115,102,111,114,109,115,10,42,47,10,105,110,116,32,115,97,116,100,95,56,120,56,95,105,105,95,113,112,101,108,95,99,111,111,112,52,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,101,110,99,44,10,105,110,116,50,32,102,101,110,99,112,111,115,44,10,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,102,114,101,102,95,112,108,97,110,101,115,44,10,105,110,116,50,32,113,112,111,115,44,10,108,111,99,97,108,32,115,117,109,50,95,116,32,42,116,109,112,112,44,10,105,110,116,32,105,100,120,32,41,10,123,10,118,111,108,97,116,105,108,101,32,108,111,99,97,108,32,115,117,109,50,95,116,40,32,42,116,109,112,32,41,91,52,93,32,61,32,40,118,111,108,97,116,105,108,101,32,108,111,99,97,108,32,115,117,109,50,95,116,40,32,42,32,41,91,52,93,41,116,109,112,112,59,10,115,117,109,50,95,116,32,98,48,44,32,98,49,44,32,98,50,44,32,98,51,59,10,105,110,116,50,32,102,114,101,102,65,112,111,115,32,61,32,113,112,111,115,32,62,62,32,50,59,10,105,110,116,32,104,112,101,108,65,32,61,32,40,40,113,112,111,115,46,120,38,50,41,62,62,49,41,32,43,32,40,113,112,111,115,46,121,38,50,41,59,10,105,110,116,50,32,113,112,111,115,66,32,61,32,113,112,111,115,32,43,32,40,105,110,116,50,41,40,40,40,113,112,111,115,46,120,38,49,41,60,60,49,41,44,32,40,40,113,112,111,115,46,121,38,49,41,60,60,49,41,41,59,10,105,110,116,50,32,102,114,101,102,66,112,111,115,32,61,32,113,112,111,115,66,32,62,62,32,50,59,10,105,110,116,32,104,112,101,108,66,32,61,32,40,40,113,112,111,115,66,46,120,38,50,41,62,62,49,41,32,43,32,40,113,112,111,115,66,46,121,38,50,41,59,10,117,105,110,116,32,109,97,115,107,95,115,104,105,102,116,48,32,61,32,56,32,42,32,104,112,101,108,65,44,32,109,97,115,107,95,115,104,105,102,116,49,32,61,32,56,32,42,32,104,112,101,108,66,59,10,117,105,110,116,32,118,65,44,32,118,66,59,10,117,105,110,116,32,97,48,44,32,97,49,59,10,117,105,110,116,32,101,110,99,59,10,115,117,109,50,95,116,32,115,117,109,32,61,32,48,59,10,35,100,101,102,105,110,101,32,82,69,65,68,95,68,73,70,70,40,32,79,85,84,44,32,88,32,41,92,10,101,110,99,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,101,110,99,44,32,115,97,109,112,108,101,114,44,32,102,101,110,99,112,111,115,32,43,32,40,105,110,116,50,41,40,88,44,32,105,100,120,41,32,41,46,115,48,59,92,10,118,65,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,65,112,111,115,32,43,32,40,105,110,116,50,41,40,88,44,32,105,100,120,41,32,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,48,41,32,38,32,48,120,70,70,59,92,10,118,66,32,61,32,40,114,101,97,100,95,105,109,97,103,101,117,105,40,32,102,114,101,102,95,112,108,97,110,101,115,44,32,115,97,109,112,108,101,114,44,32,102,114,101,102,66,112,111,115,32,43,32,40,105,110,116,50,41,40,88,44,32,105,100,120,41,32,41,46,115,48,32,62,62,32,109,97,115,107,95,115,104,105,102,116,49,41,32,38,32,48,120,70,70,59,92,10,79,85,84,32,61,32,101,110,99,32,45,32,114,104,97,100,100,40,32,118,65,44,32,118,66,32,41,59,10,35,100,101,102,105,110,101,32,82,69,65,68,95,68,73,70,70,95,69,88,40,32,79,85,84,44,32,97,44,32,98,32,41,92,10,123,92,10,82,69,65,68,95,68,73,70,70,40,32,97,48,44,32,97,32,41,59,92,10,82,69,65,68,95,68,73,70,70,40,32,97,49,44,32,98,32,41,59,92,10,79,85,84,32,61,32,97,48,32,43,32,40,97,49,60,60,66,73,84,83,95,80,69,82,95,83,85,77,41,59,92,10,125,10,35,100,101,102,105,110,101,32,82,79,87,95,56,120,52,95,83,65,84,68,40,32,97,44,32,98,32,41,92,10,123,92,10,102,101,110,99,112,111,115,46,121,32,43,61,32,97,59,92,10,102,114,101,102,65,112,111,115,46,121,32,43,61,32,98,59,92,10,102,114,101,102,66,112,111,115,46,121,32,43,61,32,98,59,92,10,82,69,65,68,95,68,73,70,70,95,69,88,40,32,98,48,44,32,48,44,32,52,32,41,59,92,10,82,69,65,68,95,68,73,70,70,95,69,88,40,32,98,49,44,32,49,44,32,53,32,41,59,92,10,82,69,65,68,95,68,73,70,70,95,69,88,40,32,98,50,44,32,50,44,32,54,32,41,59,92,10,82,69,65,68,95,68,73,70,70,95,69,88,40,32,98,51,44,32,51,44,32,55,32,41,59,92,10,72,65,68,65,77,65,82,68,52,40,32,116,109,112,91,105,100,120,93,91,48,93,44,32,116,109,112,91,105,100,120,93,91,49,93,44,32,116,109,112,91,105,100,120,93,91,50,93,44,32,116,109,112,91,105,100,120,93,91,51,93,44,32,98,48,44,32,98,49,44,32,98,50,44,32,98,51,32,41,59,92,10,72,65,68,65,77,65,82,68,52,40,32,98,48,44,32,98,49,44,32,98,50,44,32,98,51,44,32,116,109,112,91,48,93,91,105,100,120,93,44,32,116,109,112,91,49,93,91,105,100,120,93,44,32,116,109,112,91,50,93,91,105,100,120,93,44,32,116,109,112,91,51,93,91,105,100,120,93,32,41,59,92,10,115,117,109,32,43,61,32,97,98,115,50,40,32,98,48,32,41,32,43,32,97,98,115,50,40,32,98,49,32,41,32,43,32,97,98,115,50,40,32,98,50,32,41,32,43,32,97,98,115,50,40,32,98,51,32,41,59,92,10,125,10,82,79,87,95,56,120,52,95,83,65,84,68,40,32,48,44,32,48,32,41,59,10,82,79,87,95,56,120,52,95,83,65,84,68,40,32,52,44,32,52,32,41,59,10,35,117,110,100,101,102,32,82,69,65,68,95,68,73,70,70,10,35,117,110,100,101,102,32,82,69,65,68,95,68,73,70,70,95,69,88,10,35,117,110,100,101,102,32,82,79,87,95,56,120,52,95,83,65,84,68,10,114,101,116,117,114,110,32,40,40,40,115,117,109,95,116,41,115,117,109,41,32,43,32,40,115,117,109,62,62,66,73,84,83,95,80,69,82,95,83,85,77,41,41,32,62,62,32,49,59,10,125,10,99,111,110,115,116,97,110,116,32,105,110,116,50,32,104,112,111,102,102,115,91,52,93,32,61,10,123,10,123,48,44,32,45,50,125,44,32,123,45,50,44,32,48,125,44,32,123,50,44,32,48,125,44,32,123,48,44,32,50,125,10,125,59,10,47,42,32,115,117,98,32,112,105,120,101,108,32,114,101,102,105,110,101,109,101,110,116,32,111,102,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,44,32,111,117,116,112,117,116,32,77,86,115,32,97,110,100,32,99,111,115,116,115,32,97,114,101,32,109,111,118,101,100,32,102,114,111,109,10,42,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,115,32,105,110,116,111,32,102,105,110,97,108,32,112,101,114,45,102,114,97,109,101,32,98,117,102,102,101,114,10,42,10,42,32,103,108,111,98,97,108,32,108,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,58,32,32,91,109,98,95,119,105,100,116,104,32,42,32,52,44,32,109,98,95,104,101,105,103,104,116,93,10,42,10,42,32,87,105,116,104,32,88,32,98,101,105,110,103,32,116,104,101,32,115,111,117,114,99,101,32,49,54,120,49,54,32,112,105,120,101,108,115,44,32,70,32,105,115,32,116,104,101,32,108,111,119,114,101,115,32,112,105,120,101,108,32,117,115,101,100,32,98,121,32,116,104,101,10,42,32,109,111,116,105,111,110,32,115,101,97,114,99,104,46,32,32,87,101,32,119,105,108,108,32,110,111,119,32,117,116,105,108,105,122,101,32,116,104,101,32,72,32,86,32,97,110,100,32,67,32,112,105,120,101,108,115,32,40,115,116,111,114,101,100,32,105,110,32,115,101,112,97,114,97,116,101,10,42,32,112,108,97,110,101,115,41,32,116,111,32,115,101,97,114,99,104,32,97,116,32,104,97,108,102,45,112,101,108,32,105,110,99,114,101,109,101,110,116,115,46,10,42,10,42,32,88,32,88,32,88,32,88,32,88,32,88,10,42,32,32,70,32,72,32,70,32,72,32,70,10,42,32,88,32,88,32,88,32,88,32,88,32,88,10,42,32,32,86,32,67,32,86,32,67,32,86,10,42,32,88,32,88,32,88,32,88,32,88,32,88,10,42,32,32,70,32,72,32,70,32,72,32,70,10,42,32,88,32,88,32,88,32,88,32,88,32,88,10,42,10,42,32,84,104,101,32,89,88,32,72,80,69,76,32,98,105,116,115,32,111,102,32,116,104,101,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,115,101,108,101,99,116,115,32,116,104,101,32,112,108,97,110,101,32,119,101,32,115,101,97,114,99,104,32,105,110,46,32,32,84,104,101,10,42,32,102,111,117,114,32,112,108,97,110,101,115,32,97,114,101,32,112,97,99,107,101,100,32,105,110,32,116,104,101,32,102,114,101,102,95,112,108,97,110,101,115,32,50,68,32,105,109,97,103,101,32,98,117,102,102,101,114,46,32,32,69,97,99,104,32,115,97,109,112,108,101,10,42,32,114,101,116,117,114,110,115,58,32,32,115,48,32,61,32,70,44,32,115,49,32,61,32,72,44,32,115,50,32,61,32,86,44,32,115,51,32,61,32,67,32,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,115,117,98,112,101,108,95,114,101,102,105,110,101,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,32,32,102,101,110,99,44,10,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,32,32,102,114,101,102,95,112,108,97,110,101,115,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,115,104,111,114,116,50,32,32,42,105,110,95,109,118,115,44,10,99,111,110,115,116,32,103,108,111,98,97,108,32,105,110,116,49,54,95,116,32,42,105,110,95,115,97,100,95,109,118,95,99,111,115,116,115,44,10,108,111,99,97,108,32,105,110,116,49,54,95,116,32,32,32,32,32,32,32,32,42,99,111,115,116,95,108,111,99,97,108,44,10,108,111,99,97,108,32,115,117,109,50,95,116,32,32,32,32,32,32,32,32,32,42,115,97,116,100,95,108,111,99,97,108,44,10,108,111,99,97,108,32,115,104,111,114,116,50,32,32,32,32,32,32,32,32,32,42,109,118,99,95,108,111,99,97,108,44,10,103,108,111,98,97,108,32,115,104,111,114,116,50,32,32,32,32,32,32,32,32,42,102,101,110,99,95,108,111,119,114,101,115,95,109,118,44,10,103,108,111,98,97,108,32,105,110,116,49,54,95,116,32,32,32,32,32,32,32,42,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,98,95,119,105,100,116,104,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,108,97,109,98,100,97,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,114,101,102,44,10,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,98,95,105,115,108,105,115,116,49,32,41,10,123,10,105,110,116,32,109,98,95,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,32,62,62,32,50,59,10,105,102,40,32,109,98,95,120,32,62,61,32,109,98,95,119,105,100,116,104,32,41,10,114,101,116,117,114,110,59,10,105,110,116,32,109,98,95,104,101,105,103,104,116,32,61,32,103,101,116,95,103,108,111,98,97,108,95,115,105,122,101,40,32,49,32,41,59,10,105,110,116,32,109,98,95,105,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,32,38,32,51,59,10,105,110,116,32,109,98,95,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,105,110,116,32,109,98,95,120,121,32,61,32,109,98,95,121,32,42,32,109,98,95,119,105,100,116,104,32,43,32,109,98,95,120,59,10,47,42,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,32,97,110,100,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,32,97,114,101,32,108,97,114,103,101,32,98,117,102,102,101,114,115,32,116,104,97,116,10,42,32,104,111,108,100,32,109,97,110,121,32,102,114,97,109,101,115,32,119,111,114,116,104,32,111,102,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,46,32,32,87,101,32,109,117,115,116,32,111,102,102,115,101,116,32,105,110,116,111,32,116,104,101,32,99,111,114,114,101,99,116,10,42,32,108,111,99,97,116,105,111,110,32,102,111,114,32,116,104,105,115,32,102,114,97,109,101,39,115,32,118,101,99,116,111,114,115,46,32,32,84,104,101,32,107,101,114,110,101,108,32,119,105,108,108,32,98,101,32,112,97,115,115,101,100,32,116,104,101,32,99,111,114,114,101,99,116,10,42,32,100,105,114,101,99,116,105,111,110,97,108,32,98,117,102,102,101,114,32,102,111,114,32,116,104,101,32,100,105,114,101,99,116,105,111,110,32,111,102,32,116,104,101,32,115,101,97,114,99,104,58,32,108,105,115,116,49,32,111,114,32,108,105,115,116,48,10,42,10,42,32,32,32,67,80,85,32,101,113,117,105,118,97,108,101,110,116,58,32,102,101,110,99,45,62,108,111,119,114,101,115,95,109,118,115,91,48,93,91,98,32,45,32,112,48,32,45,32,49,93,10,42,32,32,32,71,80,85,32,101,113,117,105,118,97,108,101,110,116,58,32,102,101,110,99,95,108,111,119,114,101,115,95,109,118,115,91,40,98,32,45,32,112,48,32,45,32,49,41,32,42,32,109,98,95,99,111,117,110,116,93,32,42,47,10,102,101,110,99,95,108,111,119,114,101,115,95,109,118,32,43,61,32,32,32,32,32,32,32,40,98,95,105,115,108,105,115,116,49,32,63,32,40,114,101,102,45,98,45,49,41,32,58,32,40,98,45,114,101,102,45,49,41,41,32,42,32,109,98,95,119,105,100,116,104,32,42,32,109,98,95,104,101,105,103,104,116,59,10,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,32,43,61,32,40,98,95,105,115,108,105,115,116,49,32,63,32,40,114,101,102,45,98,45,49,41,32,58,32,40,98,45,114,101,102,45,49,41,41,32,42,32,109,98,95,119,105,100,116,104,32,42,32,109,98,95,104,101,105,103,104,116,59,10,47,42,32,65,100,106,117,115,116,32,112,111,105,110,116,101,114,115,32,105,110,116,111,32,108,111,99,97,108,32,109,101,109,111,114,121,32,98,117,102,102,101,114,115,32,102,111,114,32,116,104,105,115,32,116,104,114,101,97,100,39,115,32,100,97,116,97,32,42,47,10,105,110,116,32,109,98,95,105,110,95,103,114,111,117,112,32,61,32,103,101,116,95,108,111,99,97,108,95,105,100,40,32,49,32,41,32,42,32,40,103,101,116,95,108,111,99,97,108,95,115,105,122,101,40,32,48,32,41,32,62,62,32,50,41,32,43,32,40,103,101,116,95,108,111,99,97,108,95,105,100,40,32,48,32,41,32,62,62,32,50,41,59,10,99,111,115,116,95,108,111,99,97,108,32,43,61,32,109,98,95,105,110,95,103,114,111,117,112,32,42,32,52,59,10,115,97,116,100,95,108,111,99,97,108,32,43,61,32,109,98,95,105,110,95,103,114,111,117,112,32,42,32,49,54,59,10,109,118,99,95,108,111,99,97,108,32,43,61,32,109,98,95,105,110,95,103,114,111,117,112,32,42,32,52,59,10,105,110,116,32,105,95,109,118,99,32,61,32,48,59,10,109,118,99,95,108,111,99,97,108,91,48,93,32,61,32,109,118,99,95,108,111,99,97,108,91,49,93,32,61,32,109,118,99,95,108,111,99,97,108,91,50,93,32,61,32,109,118,99,95,108,111,99,97,108,91,51,93,32,61,32,48,59,10,35,100,101,102,105,110,101,32,77,86,67,40,32,68,88,44,32,68,89,32,41,32,109,118,99,95,108,111,99,97,108,91,105,95,109,118,99,43,43,93,32,61,32,105,110,95,109,118,115,91,109,98,95,119,105,100,116,104,32,42,32,40,109,98,95,121,32,43,32,68,89,41,32,43,32,40,109,98,95,120,32,43,32,68,88,41,93,59,10,105,102,40,32,109,98,95,120,32,62,32,48,32,41,10,77,86,67,40,32,45,49,44,32,48,32,41,59,10,105,102,40,32,109,98,95,121,32,62,32,48,32,41,10,123,10,77,86,67,40,32,48,44,32,45,49,32,41,59,10,105,102,40,32,109,98,95,120,32,60,32,109,98,95,119,105,100,116,104,32,45,32,49,32,41,10,77,86,67,40,32,49,44,32,45,49,32,41,59,10,105,102,40,32,109,98,95,120,32,62,32,48,32,41,10,77,86,67,40,32,45,49,44,32,45,49,32,41,59,10,125,10,35,117,110,100,101,102,32,77,86,67,10,105,110,116,50,32,109,118,112,32,61,32,40,105,95,109,118,99,32,60,61,32,49,41,32,63,32,99,111,110,118,101,114,116,95,105,110,116,50,95,115,97,116,40,109,118,99,95,108,111,99,97,108,91,48,93,41,32,58,32,120,50,54,52,95,109,101,100,105,97,110,95,109,118,40,32,109,118,99,95,108,111,99,97,108,91,48,93,44,32,109,118,99,95,108,111,99,97,108,91,49,93,44,32,109,118,99,95,108,111,99,97,108,91,50,93,32,41,59,10,105,110,116,32,98,99,111,115,116,32,61,32,32,105,110,95,115,97,100,95,109,118,95,99,111,115,116,115,91,109,98,95,120,121,93,59,10,105,110,116,50,32,99,111,111,114,100,32,61,32,40,105,110,116,50,41,40,109,98,95,120,44,32,109,98,95,121,41,32,60,60,32,51,59,10,105,110,116,50,32,98,109,118,32,61,32,99,111,110,118,101,114,116,95,105,110,116,50,95,115,97,116,40,32,105,110,95,109,118,115,91,109,98,95,120,121,93,32,41,59,10,47,42,32,77,97,107,101,32,109,118,112,32,97,110,100,32,98,109,118,32,81,80,69,76,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+81920);
/* memory initializer */ allocate([77,86,32,42,47,10,109,118,112,32,60,60,61,32,50,59,32,98,109,118,32,60,60,61,32,50,59,10,35,100,101,102,105,110,101,32,72,80,69,76,95,81,80,69,76,40,32,65,82,82,44,32,70,85,78,67,32,41,92,10,123,92,10,105,110,116,50,32,116,114,121,109,118,32,61,32,98,109,118,32,43,32,65,82,82,91,109,98,95,105,93,59,92,10,105,110,116,50,32,113,112,111,115,32,61,32,40,99,111,111,114,100,32,60,60,32,50,41,32,43,32,116,114,121,109,118,59,92,10,105,110,116,32,99,111,115,116,32,61,32,70,85,78,67,40,32,102,101,110,99,44,32,99,111,111,114,100,44,32,102,114,101,102,95,112,108,97,110,101,115,44,32,113,112,111,115,32,41,32,43,32,108,97,109,98,100,97,32,42,32,109,118,95,99,111,115,116,40,32,97,98,115,95,100,105,102,102,40,32,116,114,121,109,118,44,32,109,118,112,32,41,32,41,59,92,10,99,111,115,116,95,108,111,99,97,108,91,109,98,95,105,93,32,61,32,40,99,111,115,116,60,60,50,41,32,43,32,109,98,95,105,59,92,10,99,111,115,116,32,61,32,109,105,110,40,32,99,111,115,116,95,108,111,99,97,108,91,48,93,44,32,109,105,110,40,32,99,111,115,116,95,108,111,99,97,108,91,49,93,44,32,109,105,110,40,32,99,111,115,116,95,108,111,99,97,108,91,50,93,44,32,99,111,115,116,95,108,111,99,97,108,91,51,93,32,41,32,41,32,41,59,92,10,105,102,40,32,40,99,111,115,116,62,62,50,41,32,60,32,98,99,111,115,116,32,41,92,10,123,92,10,98,109,118,32,43,61,32,65,82,82,91,99,111,115,116,38,51,93,59,92,10,98,99,111,115,116,32,61,32,99,111,115,116,62,62,50,59,92,10,125,92,10,125,10,72,80,69,76,95,81,80,69,76,40,32,104,112,111,102,102,115,44,32,115,97,100,95,56,120,56,95,105,105,95,104,112,101,108,32,41,59,10,72,80,69,76,95,81,80,69,76,40,32,100,105,97,95,111,102,102,115,44,32,115,97,100,95,56,120,56,95,105,105,95,113,112,101,108,32,41,59,10,102,101,110,99,95,108,111,119,114,101,115,95,109,118,91,109,98,95,120,121,93,32,61,32,99,111,110,118,101,114,116,95,115,104,111,114,116,50,95,115,97,116,40,32,98,109,118,32,41,59,10,47,42,32,114,101,109,101,97,115,117,114,101,32,99,111,115,116,32,111,102,32,98,109,118,32,117,115,105,110,103,32,83,65,84,68,32,42,47,10,105,110,116,50,32,113,112,111,115,32,61,32,40,99,111,111,114,100,32,60,60,32,50,41,32,43,32,98,109,118,59,10,99,111,115,116,95,108,111,99,97,108,91,109,98,95,105,93,32,61,32,115,97,116,100,95,56,120,56,95,105,105,95,113,112,101,108,95,99,111,111,112,52,40,32,102,101,110,99,44,32,99,111,111,114,100,44,32,102,114,101,102,95,112,108,97,110,101,115,44,32,113,112,111,115,44,32,115,97,116,100,95,108,111,99,97,108,44,32,109,98,95,105,32,41,59,10,98,99,111,115,116,32,61,32,99,111,115,116,95,108,111,99,97,108,91,48,93,32,43,32,99,111,115,116,95,108,111,99,97,108,91,49,93,32,43,32,99,111,115,116,95,108,111,99,97,108,91,50,93,32,43,32,99,111,115,116,95,108,111,99,97,108,91,51,93,59,10,98,99,111,115,116,32,43,61,32,108,97,109,98,100,97,32,42,32,109,118,95,99,111,115,116,40,32,97,98,115,95,100,105,102,102,40,32,98,109,118,44,32,109,118,112,32,41,32,41,59,10,102,101,110,99,95,108,111,119,114,101,115,95,109,118,95,99,111,115,116,115,91,109,98,95,120,121,93,32,61,32,109,105,110,40,32,98,99,111,115,116,44,32,76,79,87,82,69,83,95,67,79,83,84,95,77,65,83,75,32,41,59,10,125,10,47,42,32,87,101,105,103,104,116,112,32,102,105,108,116,101,114,32,97,32,100,111,119,110,115,99,97,108,101,100,32,105,109,97,103,101,32,105,110,116,111,32,97,32,116,101,109,112,111,114,97,114,121,32,111,117,116,112,117,116,32,98,117,102,102,101,114,46,10,42,32,84,104,105,115,32,107,101,114,110,101,108,32,105,115,32,108,97,117,110,99,104,101,100,32,111,110,99,101,32,102,111,114,32,101,97,99,104,32,115,99,97,108,101,46,10,42,10,42,32,76,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,58,32,119,105,100,116,104,32,120,32,104,101,105,103,104,116,32,40,105,110,32,112,105,120,101,108,115,41,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,119,101,105,103,104,116,112,95,115,99,97,108,101,100,95,105,109,97,103,101,115,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,105,110,95,112,108,97,110,101,44,10,119,114,105,116,101,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,111,117,116,95,112,108,97,110,101,44,10,117,105,110,116,32,111,102,102,115,101,116,44,10,117,105,110,116,32,115,99,97,108,101,44,10,117,105,110,116,32,100,101,110,111,109,32,41,10,123,10,105,110,116,32,103,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,105,110,116,32,103,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,117,105,110,116,52,32,105,110,112,117,116,95,118,97,108,59,10,117,105,110,116,52,32,111,117,116,112,117,116,95,118,97,108,59,10,105,110,112,117,116,95,118,97,108,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,105,110,95,112,108,97,110,101,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,103,120,44,32,103,121,41,41,59,10,111,117,116,112,117,116,95,118,97,108,32,61,32,40,117,105,110,116,52,41,40,111,102,102,115,101,116,41,32,43,32,40,32,40,32,40,40,117,105,110,116,52,41,40,115,99,97,108,101,41,41,32,42,32,105,110,112,117,116,95,118,97,108,32,41,32,62,62,32,40,40,117,105,110,116,52,41,40,100,101,110,111,109,41,41,32,41,59,10,119,114,105,116,101,95,105,109,97,103,101,117,105,40,32,111,117,116,95,112,108,97,110,101,44,32,40,105,110,116,50,41,40,103,120,44,32,103,121,41,44,32,111,117,116,112,117,116,95,118,97,108,32,41,59,10,125,10,47,42,32,87,101,105,103,104,116,112,32,102,105,108,116,101,114,32,102,111,114,32,116,104,101,32,104,97,108,102,45,112,101,108,32,105,110,116,101,114,112,111,108,97,116,101,100,32,105,109,97,103,101,10,42,10,42,32,76,97,117,110,99,104,32,100,105,109,101,110,115,105,111,110,115,58,32,119,105,100,116,104,32,120,32,104,101,105,103,104,116,32,40,105,110,32,112,105,120,101,108,115,41,10,42,47,10,107,101,114,110,101,108,32,118,111,105,100,32,119,101,105,103,104,116,112,95,104,112,101,108,40,32,114,101,97,100,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,105,110,95,112,108,97,110,101,44,10,119,114,105,116,101,95,111,110,108,121,32,105,109,97,103,101,50,100,95,116,32,111,117,116,95,112,108,97,110,101,44,10,117,105,110,116,32,111,102,102,115,101,116,44,10,117,105,110,116,32,115,99,97,108,101,44,10,117,105,110,116,32,100,101,110,111,109,32,41,10,123,10,105,110,116,32,103,120,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,48,32,41,59,10,105,110,116,32,103,121,32,61,32,103,101,116,95,103,108,111,98,97,108,95,105,100,40,32,49,32,41,59,10,117,105,110,116,32,105,110,112,117,116,95,118,97,108,59,10,117,105,110,116,32,111,117,116,112,117,116,95,118,97,108,59,10,105,110,112,117,116,95,118,97,108,32,61,32,114,101,97,100,95,105,109,97,103,101,117,105,40,32,105,110,95,112,108,97,110,101,44,32,115,97,109,112,108,101,114,44,32,40,105,110,116,50,41,40,103,120,44,32,103,121,41,41,46,115,48,59,10,117,105,110,116,52,32,116,101,109,112,59,10,116,101,109,112,46,115,48,32,61,32,105,110,112,117,116,95,118,97,108,32,38,32,48,120,48,48,102,102,59,32,116,101,109,112,46,115,49,32,61,32,40,105,110,112,117,116,95,118,97,108,32,62,62,32,56,41,32,38,32,48,120,48,48,102,102,59,10,116,101,109,112,46,115,50,32,61,32,40,105,110,112,117,116,95,118,97,108,32,62,62,32,49,54,41,32,38,32,48,120,48,48,102,102,59,32,116,101,109,112,46,115,51,32,61,32,40,105,110,112,117,116,95,118,97,108,32,62,62,32,50,52,41,32,38,32,48,120,48,48,102,102,59,10,116,101,109,112,32,61,32,40,117,105,110,116,52,41,40,111,102,102,115,101,116,41,32,43,32,40,32,40,32,40,40,117,105,110,116,52,41,40,115,99,97,108,101,41,41,32,42,32,116,101,109,112,32,41,32,62,62,32,40,40,117,105,110,116,52,41,40,100,101,110,111,109,41,41,32,41,59,10,111,117,116,112,117,116,95,118,97,108,32,61,32,116,101,109,112,46,115,48,32,124,32,40,116,101,109,112,46,115,49,32,60,60,32,56,41,32,124,32,40,116,101,109,112,46,115,50,32,60,60,32,49,54,41,32,124,32,40,116,101,109,112,46,115,51,32,60,60,32,50,52,41,59,10,119,114,105,116,101,95,105,109,97,103,101,117,105,40,32,111,117,116,95,112,108,97,110,101,44,32,40,105,110,116,50,41,40,103,120,44,32,103,121,41,44,32,111,117,116,112,117,116,95,118,97,108,32,41,59,10,125,10,0,1,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,152,172,35,0,224,150,35,0,48,129,35,0,136,106,35,0,48,87,35,0,224,69,35,0,192,51,35,0,64,28,35,0,152,240,34,0,160,217,34,0,224,202,34,0,160,186,34,0,40,132,32,0,136,211,36,0,184,51,37,0,0,0,0,0,104,209,36,0,64,207,36,0,208,204,36,0,80,196,36,0,88,191,36,0,0,0,0,0,0,1,1,2,3,3,4,0,3,3,4,4,3,4,4,4,4,4,4,5,4,4,5,6,0,252,0,4,254,253,2,253,252,254,4,254,252,255,4,255,252,0,4,0,252,1,4,1,252,2,4,2,254,3,2,3,0,0,0,0,0,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,0,0,0,1,1,0,0,255,255,0,1,1,0,0,255,255,0,1,1,0,0,255,255,0,0,1,0,0,1,255,0,0,255,0,1,0,1,0,255,0,255,1,0,1,0,255,0,255,0,0,0,255,1,0,0,1,255,0,255,1,0,0,1,255,0,255,1,0,0,1,255,0,0,1,0,0,255,255,0,0,1,0,255,0,1,0,1,0,255,255,0,1,0,1,0,255,0,0,0,0,0,176,0,0,0,204,0,0,0,206,0,0,0,136,0,0,0,134,0,0,0,68,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,1,0,0,1,1,1,0,1,0,1,1,0,0,0,1,1,0,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,1,0,0,1,1,1,0,1,0,1,1,0,0,0,1,1,0,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,1,0,0,1,1,1,0,1,0,1,1,0,0,0,1,1,0,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,1,0,0,1,1,1,0,1,0,1,1,0,0,0,1,1,0,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,0,0,0,0,0,255,0,1,2,3,4,5,6,7,8,2,2,2,0,0,0,255,0,1,2,3,4,5,6,7,8,2,2,2,0,0,0,255,0,1,2,3,4,5,6,7,8,2,2,2,0,0,0,255,0,1,2,3,4,5,6,7,8,2,2,2,0,0,0,0,1,2,3,2,2,2,0,0,1,2,3,2,2,2,0,0,1,2,3,2,2,2,0,6,4,5,3,6,4,5,3,6,4,5,3,3,3,1,2,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,2,1,5,3,6,4,7,0,1,2,3,0,0,0,0,0,1,2,3,0,0,0,0,0,1,2,3,0,0,0,0,0,1,2,3,0,0,0,0,8,255,255,255,255,3,7,255,255,255,4,6,8,255,255,3,4,5,7,255,8,255,255,255,255,255,255,255,255,255,4,6,8,255,255,4,5,255,255,255,4,4,4,5,5,5,6,6,6,6,6,0,0,0,0,0,2,2,2,3,3,4,4,4,4,4,4,0,0,0,0,0,0,4,0,2,85,1,0,0,5,23,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,0,1,2,3,0,1,2,3,0,1,2,3,0,1,2,3,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,4,5,6,8,10,11,2,3,7,5,6,9,10,0,1,2,3,4,5,6,0,0,0,0,0,0,248,65,0,0,240,65,0,0,232,65,0,0,224,65,0,0,216,65,0,0,208,65,0,0,200,65,0,0,192,65,0,0,184,65,0,0,176,65,0,0,168,65,0,0,160,65,0,0,152,65,0,0,144,65,0,0,136,65,0,0,128,65,0,0,112,65,0,0,96,65,0,0,80,65,0,0,64,65,0,0,48,65,0,0,32,65,0,0,16,65,0,0,0,65,0,0,224,64,0,0,192,64,0,0,160,64,0,0,128,64,0,0,64,64,0,0,0,64,0,0,128,63,0,0,0,0,0,0,0,0,9,254,55,60,74,65,183,60,105,227,8,61,74,210,53,61,72,109,98,61,50,90,135,61,206,83,157,61,58,30,179,61,244,195,200,61,188,63,222,61,209,150,243,61,250,97,4,62,50,230,14,62,16,88,25,62,246,180,35,62,33,2,46,62,84,58,56,62,45,96,66,62,75,118,76,62,16,122,86,62,26,110,96,62,202,79,106,62,33,31,116,62,93,225,125,62,159,200,131,62,179,152,136,62,154,95,141,62,243,31,146,62,111,216,150,62,13,137,155,62,207,49,160,62,2,212,164,62,89,110,169,62,210,0,174,62,189,140,178,62,203,16,183,62,76,142,187,62,62,5,192,62,84,116,196,62,43,222,200,62,37,64,205,62,145,155,209,62,111,240,213,62,192,62,218,62,211,135,222,62,8,201,226,62,255,4,231,62,105,58,235,62,148,106,239,62,226,146,243,62,65,183,247,62,195,211,251,62,87,236,255,62,135,254,1,63,234,4,4,63,7,8,6,63,133,8,8,63,100,6,10,63,252,0,12,63,156,249,13,63,246,238,15,63,88,226,17,63,116,210,19,63,240,191,21,63,117,171,23,63,180,147,25,63,251,121,27,63,162,93,29,63,171,62,31,63,189,29,33,63,135,249,34,63,2,212,36,63,54,171,38,63,115,128,40,63,185,83,42,63,95,36,44,63,103,242,45,63,119,190,47,63,144,136,49,63,9,80,51,63,140,21,53,63,23,217,54,63,2,154,56,63,247,88,58,63,244,21,60,63,250,208,61,63,97,137,63,63,121,64,65,63,241,244,66,63,114,167,68,63,163,88,70,63,53,7,72,63,208,179,73,63,28,95,75,63,200,7,77,63,125,174,78,63,227,83,80,63,81,247,81,63,200,152,83,63,71,56,85,63,208,213,86,63,8,114,88,63,74,12,90,63,148,164,91,63,142,59,93,63,234,207,94,63,157,99,96,63,178,244,97,63,119,132,99,63,236,18,101,63,107,159,102,63,241,41,104,63,41,179,105,63,105,58,107,63,89,192,108,63,250,68,110,63,164,199,111,63,86,72,113,63,96,200,114,63,116,70,116,63,143,194,117,63,92,61,119,63,216,182,120,63,6,47,122,63,60,165,123,63,34,26,125,63,185,141,126,63,10,0,0,0,205,5,0,0,99,0,0,0,140,1,0,0,64,0,0,0,175,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,9,0,0,0,205,5,0,0,99,0,0,0,140,1,0,0,128,0,0,0,94,1,0,0,64,0,0,0,64,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,11,0,0,0,184,11,0,0,140,1,0,0,132,3,0,0,192,0,0,0,244,1,0,0,128,0,0,0,64,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,12,0,0,0,112,23,0,0,140,1,0,0,72,9,0,0,128,1,0,0,232,3,0,0,128,0,0,0,64,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,13,0,0,0,104,46,0,0,140,1,0,0,72,9,0,0,0,3,0,0,208,7,0,0,128,0,0,0,64,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,20,0,0,0,104,46,0,0,140,1,0,0,72,9,0,0,208,7,0,0,208,7,0,0,128,0,0,0,64,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,21,0,0,0,88,77,0,0,24,3,0,0,144,18,0,0,160,15,0,0,160,15,0,0,0,1,0,0,64,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,26,79,0,0,84,6,0,0,164,31,0,0,160,15,0,0,160,15,0,0,0,1,0,0,64,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,52,158,0,0,84,6,0,0,164,31,0,0,16,39,0,0,16,39,0,0,0,1,0,0,32,0,0,0,22,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,31,0,0,0,224,165,1,0,16,14,0,0,80,70,0,0,176,54,0,0,176,54,0,0,0,2,0,0,16,0,0,0,60,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,32,0,0,0,192,75,3,0,0,20,0,0,0,80,0,0,32,78,0,0,32,78,0,0,0,2,0,0,16,0,0,0,60,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,40,0,0,0,0,192,3,0,0,32,0,0,0,128,0,0,32,78,0,0,168,97,0,0,0,2,0,0,16,0,0,0,60,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,41,0,0,0,0,192,3,0,0,32,0,0,0,128,0,0,80,195,0,0,36,244,0,0,0,2,0,0,16,0,0,0,24,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,42,0,0,0,0,248,7,0,0,34,0,0,0,136,0,0,80,195,0,0,36,244,0,0,0,2,0,0,16,0,0,0,24,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,50,0,0,0,0,0,9,0,64,86,0,0,64,175,1,0,88,15,2,0,88,15,2,0,0,2,0,0,16,0,0,0,24,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,51,0,0,0,0,0,15,0,0,144,0,0,0,208,2,0,128,169,3,0,128,169,3,0,0,2,0,0,16,0,0,0,24,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,52,0,0,0,0,164,31,0,0,144,0,0,0,208,2,0,128,169,3,0,128,169,3,0,0,2,0,0,16,0,0,0,24,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,0,166,0,181,0,195,0,210,0,213,0,161,1,60,2,75,2,89,2,178,2,104,2,119,2,133,2,236,2,0,0,0,0,82,1,97,1,111,1,126,1,129,1,195,1,96,3,111,3,125,3,187,2,140,3,155,3,169,3,245,2,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,2,0,2,0,2,0,3,0,3,0,3,0,4,0,4,0,4,0,5,0,6,0,6,0,7,0,8,0,9,0,10,0,11,0,13,0,14,0,16,0,18,0,20,0,23,0,25,0,29,0,32,0,36,0,40,0,45,0,51,0,57,0,64,0,72,0,81,0,91,0,102,0,114,0,128,0,144,0,161,0,181,0,203,0,228,0,0,1,31,1,67,1,106,1,150,1,200,1,0,2,63,2,133,2,212,2,45,3,144,3,0,4,125,4,10,5,168,5,89,6,33,7,0,8,251,8,0,8,251,8,0,0,0,0,14,0,0,0,18,0,0,0,22,0,0,0,28,0,0,0,36,0,0,0,45,0,0,0,57,0,0,0,72,0,0,0,91,0,0,0,115,0,0,0,145,0,0,0,182,0,0,0,230,0,0,0,34,1,0,0,109,1,0,0,204,1,0,0,68,2,0,0,219,2,0,0,153,3,0,0,137,4,0,0,182,5,0,0,51,7,0,0,18,9,0,0,109,11,0,0,102,14,0,0,36,18,0,0,219,22,0,0,204,28,0,0,73,36,0,0,183,45,0,0,153,57,0,0,146,72,0,0,111,91,0,0,51,115,0,0,36,145,0,0,222,182,0,0,102,230,0,0,73,34,1,0,188,109,1,0,204,204,1,0,146,68,2,0,121,219,2,0,153,153,3,0,36,137,4,0,242,182,5,0,51,51,7,0,73,18,9,0,229,109,11,0,102,102,14,0,146,36,18,0,203,219,22,0,204,204,28,0,37,73,36,0,151,183,45,0,153,153,57,0,74,146,72,0,46,111,91,0,51,51,115,0,149,36,145,0,92,222,182,0,102,102,230,0,42,73,34,1,185,188,109,1,204,204,204,1,85,146,68,2,114,121,219,2,153,153,153,3,171,36,137,4,229,242,182,5,51,51,51,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,255,255,255,7,104,121,36,0,192,119,36,0,0,0,0,0,0,0,0,0,0,3,6,8,11,14,17,20,23,26,29,32,36,39,42,45,48,52,55,58,62,65,69,72,76,80,83,87,91,94,98,102,106,110,114,118,122,126,130,135,139,143,147,152,156,161,165,170,175,179,184,189,194,198,203,208,214,219,224,229,234,240,245,250,160,231,35,0,248,198,35,0,112,175,35,0,112,153,35,0,2,0,1,0,0,0,0,0,40,132,32,0,16,189,36,0,240,186,36,0,240,42,39,0,0,0,0,0,0,0,0,0,248,23,39,0,64,18,39,0,80,11,39,0,24,7,39,0,0,2,39,0,64,18,39,0,192,253,38,0,24,7,39,0,168,248,38,0,24,7,39,0,48,245,38,0,24,7,39,0,24,239,38,0,24,7,39,0,112,221,38,0,24,7,39,0,160,211,38,0,24,7,39,0,8,206,38,0,24,7,39,0,160,199,38,0,24,7,39,0,248,194,38,0,24,7,39,0,184,189,38,0,24,7,39,0,80,184,38,0,24,7,39,0,24,179,38,0,24,7,39,0,56,174,38,0,24,7,39,0,16,168,38,0,24,7,39,0,152,152,38,0,24,7,39,0,208,142,38,0,24,7,39,0,48,138,38,0,24,7,39,0,0,133,38,0,24,7,39,0,80,129,38,0,64,18,39,0,128,125,38,0,64,18,39,0,144,121,38,0,216,116,38,0,56,113,38,0,24,7,39,0,0,0,0,0,0,0,0,0,3,3,3,3,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,241,0,0,0,68,1,0,0,241,0,0,0,0,1,0,0,241,0,0,0,68,1,0,0,241,0,0,0,241,0,0,0,227,0,0,0,49,1,0,0,227,0,0,0,241,0,0,0,227,0,0,0,49,1,0,0,227,0,0,0,68,1,0,0,49,1,0,0,154,1,0,0,49,1,0,0,68,1,0,0,49,1,0,0,154,1,0,0,49,1,0,0,241,0,0,0,227,0,0,0,49,1,0,0,227,0,0,0,241,0,0,0,227,0,0,0,49,1,0,0,227,0,0,0,0,1,0,0,241,0,0,0,68,1,0,0,241,0,0,0,0,1,0,0,241,0,0,0,68,1,0,0,241,0,0,0,241,0,0,0,227,0,0,0,49,1,0,0,227,0,0,0,241,0,0,0,227,0,0,0,49,1,0,0,227,0,0,0,68,1,0,0,49,1,0,0,154,1,0,0,49,1,0,0,68,1,0,0,49,1,0,0,154,1,0,0,49,1,0,0,241,0,0,0,227,0,0,0,49,1,0,0,227,0,0,0,241,0,0,0,227,0,0,0,49,1,0,0,227,0,0,0,0,1,0,0,227,0,0,0,154,1,0,0,227,0,0,0,0,1,0,0,227,0,0,0,154,1,0,0,227,0,0,0,227,0,0,0,201,0,0,0,107,1,0,0,201,0,0,0,227,0,0,0,201,0,0,0,107,1,0,0,201,0,0,0,154,1,0,0,107,1,0,0,144,2,0,0,107,1,0,0,154,1,0,0,107,1,0,0,144,2,0,0,107,1,0,0,227,0,0,0,201,0,0,0,107,1,0,0,201,0,0,0,227,0,0,0,201,0,0,0,107,1,0,0,201,0,0,0,0,1,0,0,227,0,0,0,154,1,0,0,227,0,0,0,0,1,0,0,227,0,0,0,154,1,0,0,227,0,0,0,227,0,0,0,201,0,0,0,107,1,0,0,201,0,0,0,227,0,0,0,201,0,0,0,107,1,0,0,201,0,0,0,154,1,0,0,107,1,0,0,144,2,0,0,107,1,0,0,154,1,0,0,107,1,0,0,144,2,0,0,107,1,0,0,227,0,0,0,201,0,0,0,107,1,0,0,201,0,0,0,227,0,0,0,201,0,0,0,107,1,0,0,201,0,0,0,197,1,0,0,30,1,0,0,197,1,0,0,30,1,0,0,30,1,0,0,181,0,0,0,30,1,0,0,181,0,0,0,197,1,0,0,30,1,0,0,197,1,0,0,30,1,0,0,30,1,0,0,181,0,0,0,30,1,0,0,181,0,0,0,32,3,0,0,64,1,0,0,32,3,0,0,64,1,0,0,64,1,0,0,128,0,0,0,64,1,0,0,128,0,0,0,32,3,0,0,64,1,0,0,32,3,0,0,64,1,0,0,64,1,0,0,128,0,0,0,64,1,0,0,128,0,0,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,9,13,15,17,19,21,22,24,13,13,17,19,21,22,24,25,15,17,19,21,22,24,25,27,17,19,21,22,24,25,27,28,19,21,22,24,25,27,28,30,21,22,24,25,27,28,30,32,22,24,25,27,28,30,32,33,24,25,27,28,30,32,33,35,9,13,15,17,19,21,22,24,13,13,17,19,21,22,24,25,15,17,19,21,22,24,25,27,17,19,21,22,24,25,27,28,19,21,22,24,25,27,28,30,21,22,24,25,27,28,30,32,22,24,25,27,28,30,32,33,24,25,27,28,30,32,33,35,6,10,13,16,18,23,25,27,10,11,16,18,23,25,27,29,13,16,18,23,25,27,29,31,16,18,23,25,27,29,31,33,18,23,25,27,29,31,33,36,23,25,27,29,31,33,36,38,25,27,29,31,33,36,38,40,27,29,31,33,36,38,40,42,6,10,13,16,18,23,25,27,10,11,16,18,23,25,27,29,13,16,18,23,25,27,29,31,16,18,23,25,27,29,31,33,18,23,25,27,29,31,33,36,23,25,27,29,31,33,36,38,25,27,29,31,33,36,38,40,27,29,31,33,36,38,40,42,10,14,20,24,14,20,24,27,20,24,27,30,24,27,30,34,10,14,20,24,14,20,24,27,20,24,27,30,24,27,30,34,6,13,20,28,13,20,28,32,20,28,32,37,28,32,37,42,6,13,20,28,13,20,28,32,20,28,32,37,28,32,37,42,104,131,1,0,72,131,1,0,104,131,1,0,72,131,1,0,248,130,1,0,120,130,1,0,248,130,1,0,120,130,1,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,14,15,3,14,63,15,14,15,63,15,14,15,63,0,0,128,26,156,0,80,179,36,0,176,177,36,0,128,26,156,0,168,150,36,0,32,162,36,0,248,159,36,0,240,157,36,0,32,125,36,0,192,122,36,0,0,0,0,0,0,0,0,0,184,181,36,0,80,179,36,0,176,177,36,0,128,26,156,0,24,166,36,0,32,162,36,0,248,159,36,0,240,157,36,0,64,156,36,0,248,153,36,0,128,152,36,0,0,0,0,0,5,6,1,2,0,0,0,0,7,8,4,6,1,3,0,0,7,9,6,8,5,7,3,5,7,10,6,9,5,8,3,6,7,11,6,10,5,9,4,7,15,13,6,11,5,10,4,8,11,13,14,13,5,11,4,9,8,13,10,13,13,13,4,10,15,14,14,14,9,13,4,11,11,14,10,14,13,14,12,13,15,15,14,15,9,14,12,14,11,15,10,15,13,15,8,14,15,16,1,15,9,15,12,15,11,16,14,16,13,16,8,15,7,16,10,16,9,16,12,16,4,16,6,16,5,16,8,16,11,6,2,2,0,0,0,0,7,6,7,5,3,3,0,0,7,7,10,6,9,6,5,4,7,8,6,6,5,6,4,4,4,8,6,7,5,7,6,5,7,9,6,8,5,8,8,6,15,11,6,9,5,9,4,6,11,11,14,11,13,11,4,7,15,12,10,11,9,11,4,9,11,12,14,12,13,12,12,11,8,12,10,12,9,12,8,11,15,13,14,13,13,13,12,12,11,13,10,13,9,13,12,13,7,13,11,14,6,13,8,13,9,14,8,14,10,14,1,13,7,14,6,14,5,14,4,14,15,6,14,4,0,0,0,0,11,6,15,5,13,4,0,0,8,6,12,5,14,5,12,4,15,7,10,5,11,5,11,4,11,7,8,5,9,5,10,4,9,7,14,6,13,6,9,4,8,7,10,6,9,6,8,4,15,8,14,7,13,7,13,5,11,8,14,8,10,7,12,6,15,9,10,8,13,8,12,7,11,9,14,9,9,8,12,8,8,9,10,9,13,9,8,8,13,10,7,9,9,9,12,9,9,10,12,10,11,10,10,10,5,10,8,10,7,10,6,10,1,10,4,10,3,10,2,10,0,6,1,6,0,0,0,0,4,6,5,6,6,6,0,0,8,6,9,6,10,6,11,6,12,6,13,6,14,6,15,6,16,6,17,6,18,6,19,6,20,6,21,6,22,6,23,6,24,6,25,6,26,6,27,6,28,6,29,6,30,6,31,6,32,6,33,6,34,6,35,6,36,6,37,6,38,6,39,6,40,6,41,6,42,6,43,6,44,6,45,6,46,6,47,6,48,6,49,6,50,6,51,6,52,6,53,6,54,6,55,6,56,6,57,6,58,6,59,6,60,6,61,6,62,6,63,6,7,6,1,1,0,0,0,0,4,6,6,6,1,3,0,0,3,6,3,7,2,7,5,6,2,6,3,8,2,8,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,7,1,2,0,0,0,0,14,7,13,7,1,3,0,0,7,9,12,7,11,7,1,5,6,9,5,9,10,7,1,6,7,10,6,10,4,9,9,7,7,11,6,11,5,10,8,7,7,12,6,12,5,11,4,10,7,13,5,12,4,12,4,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,2,0,227,0,237,0,247,0,1,1,10,1,170,1,184,3,194,3,204,3,196,2,214,3,224,3,234,3,254,2,0,0,0,0,1,1,3,2,15,4,3,6,1,2,1,1,0,0,0,0,128,119,38,0,112,0,0,0,208,168,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,0,25,0,32,0,40,0,50,0,64,0,80,0,101,0,128,0,161,0,203,0,0,1,66,1,150,1,0,2,133,2,44,3,0,4,10,5,89,6,0,8,20,10,178,12,0,16,40,20,101,25,0,32,81,40,203,50,0,64,162,80,151,101,0,128,69,161,47,203,255,255,0,0,0,0,0,0,3,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,16,15,16,0,15,64,16,15,16,64,16,15,16,64,0,0,16,15,16,0,15,64,16,15,16,64,16,15,16,64,0,0,0,0,3,0,6,0,12,0,24,0,48,0,255,255,0,0,0,0,3,0,6,0,12,0,24,0,48,0,255,255,0,0,234,0,0,0,72,2,0,0,232,0,0,0,74,2,0,0,0,0,0,0,156,0,0,0,0,0,0,0,76,2,0,0,0,0,0,0,158,0,0,0,112,1,0,0,186,1,0,0,110,1,0,0,188,1,0,0,0,0,0,0,104,2,0,0,0,0,0,0,184,1,0,0,0,0,0,0,102,2,0,0,228,0,0,0,154,1,0,0,230,0,0,0,152,1,0,0,0,0,0,0,234,1,0,0,0,0,0,0,156,1,0,0,0,0,0,0,236,1,0,0,0,0,1,1,2,50,51,3,2,50,51,3,4,52,53,5,6,52,53,7,8,52,53,9,10,54,55,11,12,54,55,13,14,54,55,15,16,56,57,17,18,56,57,19,20,56,57,21,22,58,59,23,24,58,59,25,26,60,61,27,28,60,61,29,30,60,61,31,32,62,63,33,34,62,63,35,36,64,65,37,38,66,67,39,40,66,67,41,42,66,67,43,44,68,69,45,46,68,69,47,48,70,71,49,50,72,73,51,52,72,73,53,54,74,75,55,56,74,75,57,58,76,77,59,60,78,79,61,62,78,79,63,64,80,81,65,66,82,83,67,68,82,83,69,70,84,85,71,72,84,85,73,74,88,89,75,76,88,89,77,78,90,91,79,80,90,91,81,82,94,95,83,84,94,95,85,86,96,97,87,88,96,97,89,90,100,101,91,92,100,101,93,94,102,103,95,96,104,105,97,98,104,105,99,100,108,109,101,102,108,109,103,104,110,111,105,106,112,113,107,108,114,115,109,110,116,117,111,112,118,119,113,114,118,119,115,116,122,123,117,118,122,123,119,120,124,125,121,122,126,127,123,124,127,126,125,6,5,4,4,3,3,3,3,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,6,7,8,9,6,7,9,10,6,8,9,11,7,8,10,11,7,9,10,12,7,9,11,12,8,9,11,13,8,10,12,14,9,11,12,14,9,11,13,15,10,12,14,16,10,12,15,17,11,13,15,18,11,14,16,19,12,14,17,20,12,15,18,21,13,16,19,22,14,17,20,23,14,18,21,24,15,19,22,25,16,20,23,27,17,21,25,28,18,22,26,30,19,23,27,31,20,24,29,33,21,26,30,35,22,27,32,37,23,28,33,39,24,30,35,41,26,31,37,43,27,33,39,45,29,35,41,48,30,37,43,50,32,39,46,53,33,41,48,56,35,43,51,59,37,45,54,62,39,48,56,65,41,50,59,69,43,53,63,72,46,56,66,76,48,59,69,80,51,62,73,85,53,65,77,89,56,69,81,94,59,72,86,99,62,76,90,104,66,80,95,110,69,85,100,116,73,89,105,122,77,94,111,128,81,99,117,135,85,104,123,142,90,110,130,150,95,116,137,158,100,122,144,166,105,128,152,175,111,135,160,185,116,142,169,195,123,150,178,205,128,158,187,216,128,167,197,227,128,176,208,240,3,4,5,6,6,6,6,6,49,41,4,53,45,0,67,99,0,61,47,0,57,37,6,83,115,0,75,107,0,91,123,0,71,103,33,0,0,0,0,0,49,41,4,53,45,0,67,99,0,61,47,0,57,37,6,83,115,0,75,107,0,91,123,0,71,103,33,0,0,0,0,0,7,0,189,5,7,0,169,5,8,0,150,5,8,0,131,5,9,0,112,5,9,0,92,5,10,0,73,5,10,0,54,5,11,0,35,5,11,0,15,5,12,0,252,4,12,0,233,4,13,0,214,4,14,0,194,4,15,0,175,4,15,0,156,4,16,0,137,4,17,0,117,4,18,0,98,4,19,0,79,4,20,0,60,4,21,0,40,4,22,0,21,4,24,0,2,4,25,0,239,3,26,0,219,3,28,0,200,3,29,0,181,3,31,0,162,3,33,0,142,3,35,0,123,3,37,0,104,3,39,0,85,3,41,0,65,3,43,0,46,3,46,0,27,3,48,0,8,3,51,0,244,2,54,0,225,2,57,0,206,2,60,0,187,2,64,0,167,2,68,0,148,2,72,0,129,2,76,0,110,2,80,0,90,2,85,0,71,2,90,0,52,2,96,0,33,2,102,0,13,2,108,0,250,1,115,0,231,1,122,0,212,1,130,0,192,1,139,0,173,1,148,0,154,1,157,0,135,1,168,0,115,1,180,0,96,1,192,0,77,1,206,0,58,1,221,0,39,1,238,0,19,1,0,1,0,1,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,23,33,23,2,21,0,1,9,0,49,219,118,5,57,243,78,245,65,1,62,12,49,252,73,17,50,18,64,9,43,29,0,26,67,16,90,9,104,210,127,236,104,1,67,243,78,245,65,1,62,250,86,239,95,250,61,9,45,253,69,250,81,245,96,6,55,7,67,251,86,2,88,0,58,253,76,246,94,5,54,4,69,253,81,0,88,249,67,251,74,252,74,251,80,249,72,1,58,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,0,45,252,78,253,96,229,126,228,98,231,101,233,67,228,82,236,94,240,83,234,110,235,91,238,102,243,93,227,127,249,92,251,89,249,96,243,108,253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,5,54,6,60,6,59,6,69,255,48,0,68,252,69,248,88,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,3,64,1,61,9,63,7,50,16,39,5,44,4,52,11,48,251,60,255,59,0,59,22,33,5,44,14,43,255,78,0,60,9,69,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,1,67,5,59,9,67,16,30,18,32,18,35,22,29,24,31,23,38,18,43,20,41,11,63,9,59,9,64,255,94,254,89,247,108,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,0,70,252,29,5,31,7,42,1,59,254,58,253,72,253,81,245,97,0,58,8,5,10,14,14,18,13,27,2,40,0,58,253,70,250,79,248,85,0,0,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,254,69,254,59,6,70,10,44,9,31,12,43,3,53,14,34,10,38,253,52,13,40,17,32,7,44,7,38,13,50,10,57,26,43,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,8,60,6,63,17,65,21,24,23,20,26,23,27,32,28,23,28,24,23,40,24,32,28,29,23,42,19,57,22,53,22,61,11,86,12,40,11,51,14,59,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,249,92,251,89,249,96,243,108,253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,249,92,251,89,249,96,243,108], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+92160);
/* memory initializer */ allocate([253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,253,74,247,92,248,87,233,126,253,74,247,92,248,87,233,126,253,74,247,92,248,87,233,126,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,22,25,34,0,16,0,254,9,4,41,227,118,2,65,250,71,243,79,5,52,9,50,253,70,10,54,26,34,19,22,40,0,57,2,41,36,26,69,211,127,241,101,252,76,250,71,243,79,5,52,6,69,243,90,0,52,8,43,254,69,251,82,246,96,2,59,2,75,253,87,253,100,1,56,253,74,250,85,0,59,253,81,249,86,251,95,255,66,255,77,1,70,254,86,251,72,0,61,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,13,15,7,51,2,80,217,127,238,91,239,96,230,81,221,98,232,102,233,97,229,119,232,99,235,110,238,102,220,127,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,3,55,7,56,7,55,8,61,253,53,0,68,249,74,247,88,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,252,71,0,58,7,61,9,41,18,25,9,32,5,43,9,47,0,44,0,51,2,46,19,38,252,66,15,38,12,42,9,34,0,89,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,0,75,2,72,8,77,14,35,18,31,17,35,21,30,17,45,20,42,18,45,27,26,16,54,7,66,16,56,11,73,10,67,246,116,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,2,66,247,34,1,32,11,31,5,52,254,55,254,67,0,73,248,89,3,52,7,4,10,8,17,8,16,19,3,37,255,61,251,73,255,70,252,78,0,0,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,255,70,247,72,14,60,16,37,0,47,18,35,11,37,12,41,10,41,2,48,12,41,13,41,0,59,3,50,19,40,3,66,18,50,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,12,48,11,49,26,45,22,22,23,22,27,21,33,20,26,28,30,24,27,34,18,42,25,39,18,50,12,70,21,54,14,71,11,83,25,32,21,49,21,54,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,254,73,244,104,247,91,225,127,254,73,244,104,247,91,225,127,254,73,244,104,247,91,225,127,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,29,16,25,0,14,0,246,51,253,62,229,99,26,16,252,85,232,102,5,57,6,57,239,73,14,57,20,40,20,10,29,0,54,0,37,42,12,97,224,127,234,117,254,74,252,85,232,102,5,57,250,93,242,88,250,44,4,55,245,89,241,103,235,116,19,57,20,58,4,84,6,96,1,63,251,85,243,106,5,63,6,75,253,90,255,101,3,55,252,79,254,75,244,97,249,50,1,60,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,7,34,247,88,236,127,220,127,239,91,242,95,231,84,231,86,244,89,239,91,225,127,242,76,238,103,243,90,219,127,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,0,65,254,79,0,72,252,92,250,56,3,68,248,71,243,98,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,3,65,249,69,8,77,246,66,3,62,253,68,236,81,0,30,1,7,253,23,235,74,16,66,233,124,17,37,44,238,50,222,234,127,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,20,34,19,31,27,44,19,16,15,36,15,36,21,28,25,21,30,20,31,12,27,16,24,42,0,93,14,56,15,57,26,38,232,127,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,252,79,234,69,240,75,254,58,1,58,243,78,247,83,252,81,243,99,243,81,250,38,243,62,250,58,254,59,240,73,246,76,243,86,247,83,246,87,0,0,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,254,76,238,86,12,70,5,64,244,70,11,55,5,56,0,69,2,65,250,74,5,54,7,54,250,76,245,82,254,77,254,77,25,42,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,18,31,19,26,36,24,24,23,27,16,24,30,31,29,22,41,22,42,16,60,15,52,14,60,3,78,240,123,21,53,22,56,25,61,21,33,19,50,17,61,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,251,79,245,104,245,91,226,127,251,79,245,104,245,91,226,127,251,79,245,104,245,91,226,127,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,0,11,1,55,0,69,239,127,243,102,0,82,249,74,235,107,229,127,225,127,232,127,238,95,229,127,235,114,226,127,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,255,74,250,97,249,91,236,127,252,56,251,82,249,76,234,125,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,248,102,241,100,0,95,252,75,2,72,245,75,253,71,15,46,243,69,0,62,0,65,21,37,241,72,9,57,16,54,0,62,12,72,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38,1,41,17,30,250,27,3,26,22,37,240,35,252,38,248,38,253,37,3,38,5,42,0,35,16,39,22,14,48,27,37,21,60,12,68,2,97,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,245,97,236,84,245,79,250,73,252,74,243,86,243,96,245,97,237,117,248,78,251,33,252,48,254,53,253,62,243,71,246,79,244,86,243,90,242,97,0,0,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,249,99,242,95,2,95,0,76,251,74,0,70,245,75,1,68,0,65,242,73,3,62,4,62,255,68,243,75,11,55,5,64,12,70,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,29,253,26,0,22,30,31,249,35,241,34,253,34,3,36,255,34,5,32,11,35,5,34,12,39,11,30,29,34,26,29,39,19,66,31,21,31,31,25,50,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246,73,246,70,246,69,251,66,247,64,251,58,2,59,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38,1,41,17,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38,1,41,17,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246,73,246,70,246,69,251,66,247,64,251,58,2,59,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246,73,246,70,246,69,251,66,247,64,251,58,2,59,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,253,70,248,93,246,90,226,127,253,70,248,93,246,90,226,127,253,70,248,93,246,90,226,127,85,0,89,0,93,0,97,0,101,0,244,3,204,1,208,1,212,1,248,3,216,1,220,1,224,1,252,3,0,0,0,0,85,0,89,0,93,0,97,0,101,0,244,3,204,1,208,1,212,1,248,3,216,1,220,1,224,1,252,3,0,0,0,0,8,0,0,0,0,0,0,0,88,210,39,0,96,106,39,0,152,26,39,0,0,0,0,0,40,132,32,0,72,185,36,0,0,184,36,0,0,0,0,0,112,23,0,0,64,31,0,0,128,37,0,0,17,43,0,0,224,46,0,0,128,62,0,0,34,86,0,0,192,93,0,0,0,125,0,0,68,172,0,0,128,187,0,0,0,250,0,0,136,88,1,0,0,119,1,0,0,238,2,0,0,0,0,0,112,23,0,0,64,31,0,0,128,37,0,0,17,43,0,0,224,46,0,0,128,62,0,0,34,86,0,0,192,93,0,0,0,125,0,0,68,172,0,0,128,187,0,0,0,250,0,0,136,88,1,0,0,119,1,0,0,238,2,0,0,0,0,0,112,23,0,0,64,31,0,0,128,37,0,0,17,43,0,0,224,46,0,0,128,62,0,0,34,86,0,0,192,93,0,0,0,125,0,0,68,172,0,0,128,187,0,0,0,250,0,0,136,88,1,0,0,119,1,0,0,238,2,0,255,255,255,255,0,0,2,2,2,1,0,1,1,0,0,0,0,0,0,0,80,181,4,0,60,0,0,0,92,5,0,0,24,130,19,0,62,0,0,0,0,0,0,0,88,130,19,0,16,0,0,0,0,0,0,0,80,229,4,0,56,0,0,0,116,5,0,0,232,189,19,0,58,0,0,0,0,0,0,0,232,228,4,0,64,0,0,0,0,0,0,0,40,229,4,0,38,0,0,0,18,2,0,0,192,189,19,0,40,0,0,0,0,0,0,0,247,248,250,251,252,253,254,255,0,1,2,3,4,5,6,8,1,2,3,5,4,10,9,8,11,15,17,16,23,22,21,20,19,18,25,24,27,26,11,7,6,1,2,13,2,2,2,2,6,12,3,9,1,3,4,3,7,4,1,1,5,5,14,6,1,7,1,8,1,1,1,1,10,1,1,5,9,17,25,24,29,33,32,41,2,23,28,31,3,22,30,4,27,40,8,26,6,39,7,38,16,37,15,10,11,12,13,14,1,21,20,18,19,2,1,34,35,36,0,0,1,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,232,3,0,0,0,1,3,4,6,7,9,10,11,13,14,16,17,18,20,21,22,24,25,26,28,29,30,32,33,34,36,37,38,40,41,42,44,45,46,47,49,50,51,52,54,55,56,57,59,60,61,62,63,65,66,67,68,69,71,72,73,74,75,77,78,79,80,81,82,84,85,86,87,88,89,90,92,93,94,95,96,97,98,99,100,102,103,104,105,106,107,108,109,110,111,112,113,114,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,169,170,171,172,173,174,175,176,177,178,178,179,180,181,182,183,184,185,185,186,187,188,189,190,191,192,192,193,194,195,196,197,198,198,199,200,201,202,203,203,204,205,206,207,208,208,209,210,211,212,212,213,214,215,216,216,217,218,219,220,220,221,222,223,224,224,225,226,227,228,228,229,230,231,231,232,233,234,234,235,236,237,238,238,239,240,241,241,242,243,244,244,245,246,247,247,248,249,249,250,251,252,252,253,254,255,255,0,1,3,4,6,7,9,10,11,13,14,16,17,18,20,21,22,24,25,26,28,29,30,32,33,34,36,37,38,40,41,42,44,45,46,47,49,50,51,52,54,55,56,57,59,60,61,62,63,65,66,67,68,69,71,72,73,74,75,77,78,79,80,81,82,84,85,86,87,88,89,90,92,93,94,95,96,97,98,99,100,102,103,104,105,106,107,108,109,110,111,112,113,114,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,169,170,171,172,173,174,175,176,177,178,178,179,180,181,182,183,184,185,185,186,187,188,189,190,191,192,192,193,194,195,196,197,198,198,199,200,201,202,203,203,204,205,206,207,208,208,209,210,211,212,212,213,214,215,216,216,217,218,219,220,220,221,222,223,224,224,225,226,227,228,228,229,230,231,231,232,233,234,234,235,236,237,238,238,239,240,241,241,242,243,244,244,245,246,247,247,248,249,249,250,251,252,252,253,254,255,255,0,1,1,2,3,3,4,5,6,6,7,8,8,9,10,11,11,12,13,14,14,15,16,16,17,18,19,19,20,21,22,22,23,24,25,25,26,27,28,29,29,30,31,32,32,33,34,35,36,36,37,38,39,40,40,41,42,43,44,44,45,46,47,48,48,49,50,51,52,53,53,54,55,56,57,58,58,59,60,61,62,63,64,65,65,66,67,68,69,70,71,72,72,73,74,75,76,77,78,79,80,81,81,82,83,84,85,86,87,88,89,90,91,92,93,94,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,135,136,137,138,139,140,141,142,143,144,145,146,147,149,150,151,152,153,154,155,156,157,159,160,161,162,163,164,165,166,168,169,170,171,172,173,175,176,177,178,179,180,182,183,184,185,186,188,189,190,191,192,194,195,196,197,198,200,201,202,203,205,206,207,208,210,211,212,214,215,216,217,219,220,221,222,224,225,226,228,229,230,232,233,234,236,237,238,240,241,242,244,245,246,248,249,250,252,253,255,0,1,1,2,3,3,4,5,6,6,7,8,8,9,10,11,11,12,13,14,14,15,16,16,17,18,19,19,20,21,22,22,23,24,25,25,26,27,28,29,29,30,31,32,32,33,34,35,36,36,37,38,39,40,40,41,42,43,44,44,45,46,47,48,48,49,50,51,52,53,53,54,55,56,57,58,58,59,60,61,62,63,64,65,65,66,67,68,69,70,71,72,72,73,74,75,76,77,78,79,80,81,81,82,83,84,85,86,87,88,89,90,91,92,93,94,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,135,136,137,138,139,140,141,142,143,144,145,146,147,149,150,151,152,153,154,155,156,157,159,160,161,162,163,164,165,166,168,169,170,171,172,173,175,176,177,178,179,180,182,183,184,185,186,188,189,190,191,192,194,195,196,197,198,200,201,202,203,205,206,207,208,210,211,212,214,215,216,217,219,220,221,222,224,225,226,228,229,230,232,233,234,236,237,238,240,241,242,244,245,246,248,249,250,252,253,255,32,240,118,255,19,128,128,255,54,184,198,255,19,128,128,255,188,154,16,255,19,128,128,255,191,128,128,255,0,0,0,0,160,145,32,0,112,0,0,0,160,122,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,116,61,190,197,3,26,190,115,15,53,191,142,117,145,190,154,5,98,63,118,227,73,191,97,224,121,61,108,181,191,62,122,138,92,61,91,234,104,191,128,41,11,63,255,150,96,62,2,71,146,62,9,108,30,62,106,246,232,190,217,64,218,62,22,109,94,191,129,203,115,191,222,204,12,191,29,86,80,63,43,164,180,190,212,238,119,62,246,11,82,63,176,31,66,190,216,41,230,190,59,142,255,62,212,186,125,190,243,32,25,63,249,102,59,63,233,124,16,191,220,188,33,191,20,236,231,190,75,4,146,62,158,152,173,190,94,158,134,62,0,31,44,62,18,191,2,190,186,18,45,191,243,58,234,190,227,24,109,63,21,253,21,191,10,244,105,191,139,250,20,62,91,38,51,63,225,155,118,62,110,195,48,63,97,27,1,62,197,115,190,62,236,247,60,63,251,121,19,63,255,63,62,62,41,90,29,191,132,41,58,190,103,242,205,59,104,119,72,62,102,193,188,62,252,57,253,190,37,175,114,63,168,229,7,189,5,54,67,191,196,205,29,191,148,137,171,62,58,176,92,190,114,52,43,63,123,248,126,63,207,220,115,191,57,15,39,190,106,221,6,190,137,239,32,191,79,61,194,62,221,121,82,190,188,178,91,190,59,85,238,62,44,160,112,63,67,198,3,191,179,92,150,190,153,99,33,63,132,128,28,63,119,244,107,191,11,183,188,62,251,233,63,62,17,55,135,62,92,1,65,63,210,143,126,191,147,200,58,191,145,11,78,189,161,161,191,62,255,149,101,190,160,140,209,189,121,173,40,191,235,30,89,60,80,1,144,62,80,23,45,63,109,56,76,63,100,174,76,189,187,15,44,63,159,91,88,63,76,113,73,63,30,79,235,190,234,147,72,191,205,63,42,62,243,115,171,62,209,205,254,58,223,138,188,190,74,180,140,62,71,114,249,62,110,24,173,62,14,18,194,189,62,205,201,61,127,47,213,62,172,230,57,191,218,203,54,191,112,153,163,190,79,229,120,191,171,91,53,191,168,84,73,189,18,193,184,188,37,117,42,63,54,5,58,63,83,8,96,63,84,56,126,191,157,44,133,190,234,35,32,62,252,222,46,63,195,187,236,190,236,193,100,191,110,221,181,62,67,2,30,191,96,175,100,63,40,71,101,63,90,44,205,190,35,244,115,61,134,4,108,62,58,233,25,63,228,249,48,63,115,73,253,190,236,18,181,61,76,195,240,60,43,50,210,62,251,35,80,191,38,226,13,191,89,50,47,63,212,239,6,191,137,68,1,62,10,77,54,63,65,46,113,190,40,68,108,191,254,241,158,190,107,214,17,191,13,193,77,63,88,225,222,190,191,14,16,191,164,170,233,190,95,152,56,63,194,47,97,191,102,102,166,61,115,214,83,63,233,125,243,62,54,149,237,62,211,133,56,63,57,12,190,62,146,203,111,191,171,235,96,190,132,241,203,190,168,29,42,63,7,65,7,191,35,20,219,61,235,255,124,190,2,69,0,63,238,8,247,190,87,63,118,189,220,98,114,63,13,82,76,191,109,88,211,62,111,159,149,61,253,250,105,63,90,159,82,191,22,191,25,62,227,251,202,190,104,235,200,190,208,242,60,189,137,69,44,62,212,184,55,61,2,183,254,62,247,177,226,189,43,47,41,62,66,175,215,190,151,255,144,190,163,234,183,190,23,13,117,191,9,250,15,191,53,239,124,191,169,216,100,191,48,44,95,62,238,207,197,190,15,69,69,63,5,138,48,63,141,122,56,63,216,245,243,190,29,60,67,62,234,9,67,191,28,66,237,62,143,199,12,62,247,91,15,191,221,149,253,189,30,26,74,191,250,96,37,191,169,222,90,61,80,171,184,62,187,238,45,189,55,56,41,63,133,121,47,191,138,205,95,191,154,152,150,190,252,225,79,63,183,9,119,60,126,255,94,63,182,245,27,191,91,92,59,63,167,235,249,190,188,2,17,191,157,157,84,191,239,201,243,190,204,182,235,190,222,90,198,62,3,204,12,62,87,150,48,191,157,187,157,61,199,73,17,190,78,69,42,190,116,121,59,191,38,29,197,61,53,240,51,191,223,112,207,62,174,71,9,63,63,116,49,62,65,158,29,63,180,230,99,63,6,245,69,191,237,130,193,188,34,225,27,190,49,67,99,63,199,244,148,62,65,186,216,188,56,18,208,190,252,226,210,61,85,22,125,63,158,9,9,191,83,205,252,62,176,114,56,63,20,236,191,188,237,99,109,63,19,213,99,63,151,27,0,63,121,119,8,191,3,5,142,62,174,98,185,190,63,55,100,190,250,69,37,191,77,248,253,62,221,96,28,63,254,126,193,190,106,192,208,190,168,112,104,63,16,7,121,191,135,24,95,191,189,109,166,61,66,151,36,63,228,49,123,191,100,177,157,62,171,233,194,190,177,168,8,190,139,111,72,62,142,5,105,63,2,16,87,63,199,18,74,63,87,123,88,60,87,38,84,63,215,246,62,191,210,110,252,190,7,153,12,63,32,39,108,62,124,211,16,191,51,220,224,62,66,181,137,190,168,87,202,189,201,30,145,190,16,232,188,62,59,167,45,63,13,85,145,61,70,63,10,190,48,16,148,62,35,107,49,63,243,31,234,62,0,227,73,62,19,100,56,63,115,247,21,63,136,185,56,191,169,246,185,62,143,197,26,63,42,31,22,63,127,134,123,63,140,100,7,191,207,19,95,190,13,140,100,63,155,84,48,191,90,100,219,190,46,144,192,189,69,46,92,191,18,164,50,190,34,109,211,62,194,106,48,63,60,159,113,191,21,227,88,63,111,99,3,62,117,231,89,190,192,207,128,190,119,73,88,63,213,5,88,191,165,192,18,191,192,95,172,189,39,75,173,60,132,71,55,63,171,65,200,190,157,133,5,191,223,253,177,189,178,188,43,191,42,142,111,191,239,26,68,62,146,62,49,63,101,55,43,63,106,104,99,190,17,197,44,63,40,45,92,191,242,96,15,63,30,81,17,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+102400);
/* memory initializer */ allocate([195,129,12,191,59,81,94,191,249,192,6,191,15,96,209,190,253,163,47,189,153,245,98,63,70,69,56,191,241,160,89,60,174,216,59,63,45,39,209,62,183,236,76,63,50,143,4,191,250,185,129,62,226,230,116,63,183,126,186,189,234,174,84,191,149,216,181,188,165,16,192,190,255,62,99,190,62,151,233,62,241,183,9,63,115,156,219,61,117,61,5,63,199,130,138,190,59,55,77,190,170,211,65,62,130,228,1,63,190,136,6,191,134,143,168,62,157,43,138,61,176,55,117,191,0,198,71,63,225,208,75,62,48,241,247,190,247,233,32,191,24,6,88,191,16,3,25,191,120,94,178,190,241,129,45,62,99,42,93,191,166,155,112,191,167,91,246,188,42,115,195,190,174,130,160,62,217,95,150,189,148,246,6,63,217,36,247,62,64,133,103,63,190,17,89,191,83,61,61,191,190,161,184,62,34,166,48,63,118,108,188,62,218,140,243,189,48,155,20,191,148,23,85,191,194,252,109,191,82,73,109,63,163,64,183,190,3,150,204,62,107,157,184,187,3,176,161,190,7,68,56,62,19,125,78,191,123,102,201,62,94,161,59,63,16,232,212,190,137,122,57,191,177,20,117,63,62,148,100,191,44,99,243,62,190,191,49,62,182,76,214,190,0,230,154,190,183,151,32,63,39,49,72,63,211,189,254,62,131,107,14,62,203,242,17,63,238,124,59,63,248,198,232,190,81,188,154,62,243,200,159,188,52,188,97,63,69,244,107,189,8,204,139,62,23,14,212,62,113,229,0,191,96,6,163,189,66,233,171,189,110,53,235,59,27,13,48,190,81,193,1,63,45,93,5,63,11,182,33,63,142,91,204,189,55,253,129,62,253,189,72,191,87,232,51,62,240,76,88,62,59,82,45,191,168,168,178,190,212,124,29,191,55,197,195,189,88,113,178,62,29,229,124,191,222,142,160,190,236,161,29,190,203,214,26,62,164,84,62,191,249,214,215,190,55,82,50,63,133,9,15,63,60,22,15,63,124,14,20,63,127,107,255,190,2,15,44,190,187,68,245,187,115,48,27,187,116,155,64,63,95,152,104,63,198,196,126,191,167,207,214,190,62,179,212,62,103,152,6,63,200,177,73,191,194,49,47,191,56,164,97,190,198,111,18,191,134,144,251,62,63,170,125,63,3,8,127,190,17,140,91,191,149,210,31,191,88,197,39,63,54,89,251,62,179,183,28,191,23,130,40,191,224,187,41,191,0,254,9,63,117,173,205,190,231,58,173,189,221,64,113,62,54,205,87,191,50,145,6,191,52,133,62,190,201,5,175,190,27,214,156,62,42,116,78,63,235,225,39,63,18,104,112,61,137,12,55,63,38,29,41,63,174,158,35,63,158,152,5,62,241,213,62,62,229,236,89,63,203,104,228,62,127,76,119,63,207,130,56,191,189,26,128,189,190,246,116,63,254,101,247,60,186,132,163,61,232,219,42,191,239,254,160,190,189,197,219,190,53,39,143,190,49,206,223,60,245,245,188,189,154,149,61,191,183,39,32,63,229,185,82,63,58,117,253,62,146,90,72,63,77,215,51,191,176,230,48,191,82,40,15,191,209,147,26,63,134,114,98,191,120,70,103,191,92,203,172,190,2,154,84,63,174,214,65,63,0,199,50,191,97,253,31,189,92,61,103,189,27,218,88,191,113,203,23,191,180,58,185,189,234,92,17,191,111,98,176,62,97,194,8,190,106,188,236,62,49,94,19,191,255,205,75,62,66,33,90,191,202,135,160,187,229,95,107,63,0,117,51,62,50,32,103,63,181,53,82,191,37,236,75,190,22,218,57,63,232,132,44,63,238,64,213,190,38,253,121,191,56,158,123,63,193,228,198,60,154,150,32,63,78,212,102,191,249,133,247,61,20,207,53,191,181,197,109,63,30,197,249,189,40,44,209,190,133,208,225,189,151,83,82,63,93,224,130,190,220,244,151,62,126,167,137,190,92,203,52,62,181,168,183,190,152,251,24,63,198,221,184,190,165,107,134,61,95,67,80,190,150,64,90,190,155,115,112,191,7,98,145,190,10,77,118,63,151,172,118,63,194,53,215,189,254,183,114,190,190,134,48,63,160,195,220,190,19,99,177,62,152,137,54,63,47,135,229,190,80,23,33,191,100,64,174,62,169,47,179,190,221,178,251,62,30,81,33,63,64,164,215,190,53,95,33,191,246,68,71,191,159,231,239,62,158,11,79,191,68,82,11,189,11,71,112,190,232,250,158,189,77,130,91,191,198,51,208,62,138,199,245,190,193,196,95,190,168,24,7,191,198,22,162,62,153,126,17,63,135,24,239,190,160,165,119,191,180,203,7,63,173,223,0,191,195,98,148,189,76,226,52,191,239,88,80,191,175,35,254,62,62,207,35,63,152,48,102,63,192,177,115,191,19,72,125,191,40,67,117,62,41,147,154,190,92,145,0,63,28,120,5,190,151,200,141,62,56,50,95,63,146,231,186,61,202,79,130,190,102,217,111,191,50,88,113,191,88,198,2,63,252,52,110,188,127,218,76,191,38,254,168,189,103,99,1,63,243,117,153,188,4,143,199,62,216,68,54,190,44,154,230,190,63,59,108,63,89,219,20,190,98,129,107,191,110,164,20,191,209,60,72,63,174,99,32,191,185,250,201,190,115,157,142,62,112,148,124,191,137,153,253,190,243,57,167,62,131,220,121,191,22,132,62,63,155,172,121,191,217,180,6,63,3,180,197,190,97,111,154,62,33,206,203,62,2,131,52,63,53,240,115,191,84,27,236,62,208,42,67,63,19,214,14,63,42,171,13,191,80,80,118,63,178,73,6,191,61,184,115,63,242,181,103,189,225,125,93,63,229,99,103,190,21,111,252,62,31,185,73,63,48,240,32,63,57,182,18,63,79,235,74,191,37,90,210,62,122,82,114,63,173,162,63,190,137,8,159,190,10,190,117,63,33,149,162,62,75,231,123,191,151,225,123,63,108,234,124,61,213,147,117,191,112,150,2,63,165,244,44,63,182,71,175,62,253,19,188,189,44,239,194,62,77,103,199,62,214,116,33,191,152,137,18,62,107,100,87,189,65,128,60,190,179,149,215,61,15,128,216,62,10,159,109,190,152,136,115,191,208,123,147,62,68,191,10,63,243,174,10,63,61,184,155,61,211,189,46,62,95,41,235,61,114,23,145,62,241,70,214,190,95,122,123,61,3,93,103,191,167,176,138,62,246,181,174,60,60,219,211,62,17,226,146,62,135,163,171,59,204,67,6,191,103,186,167,62,146,36,248,190,39,79,89,191,4,254,168,190,111,214,216,62,128,40,8,63,92,203,112,191,98,246,74,63,51,106,166,190,207,46,223,59,93,83,200,190,157,189,71,63,155,1,18,191,30,221,192,62,5,53,84,63,77,188,55,63,234,145,166,189,239,199,189,62,173,50,83,190,184,34,105,191,237,182,3,191,3,65,108,191,97,140,168,190,185,0,12,63,245,157,83,191,35,18,113,63,14,19,221,190,152,79,22,63,174,12,106,62,192,205,18,63,52,244,111,191,100,63,227,190,137,68,105,191,91,67,73,191,47,133,103,62,175,38,3,63,38,229,62,63,224,43,146,62,33,58,156,62,244,79,20,191,178,43,53,191,98,243,105,63,88,146,76,191,155,90,142,190,194,195,148,62,83,93,120,191,0,113,15,191,76,112,74,191,74,13,205,62,83,9,111,62,3,147,51,191,183,207,98,63,163,2,159,62,124,38,251,188,224,160,221,62,185,198,247,62,13,57,182,189,23,185,127,191,162,151,145,61,246,67,92,191,169,20,19,63,1,251,8,62,80,199,155,190,32,208,41,63,203,246,177,62,164,253,107,63,60,219,51,62,87,4,191,61,81,78,84,62,32,236,4,191,151,144,3,63,230,207,255,62,190,248,26,191,63,254,54,63,90,69,71,191,35,105,47,63,236,160,62,63,181,108,173,190,215,248,100,63,69,158,20,62,250,11,101,63,61,154,78,191,20,233,254,60,47,53,82,62,60,50,38,62,71,56,9,191,176,30,159,190,147,58,109,191,78,241,8,191,140,163,66,63,153,126,73,191,165,220,117,191,162,237,216,189,10,18,187,189,124,243,51,63,79,34,66,191,117,146,45,190,172,173,248,189,154,124,171,62,248,80,118,191,84,252,183,62,114,196,26,190,251,150,9,63,108,5,65,63,186,101,223,190,160,81,66,63,30,221,224,62,241,17,49,191,187,100,20,191,171,206,170,62,31,43,232,62,193,88,47,191,24,205,6,63,40,243,3,191,139,52,5,63,178,76,159,190,229,181,82,189,205,90,74,191,174,131,115,190,168,198,211,62,207,72,120,63,153,240,203,188,61,13,232,62,147,83,11,190,58,62,98,63,104,232,31,62,99,70,216,61,165,76,146,190,139,27,119,191,231,56,15,191,43,221,125,190,63,197,201,62,250,43,148,62,97,224,53,191,48,160,23,62,15,99,90,63,193,142,115,191,235,82,211,190,226,174,86,191,124,243,7,191,224,189,107,63,174,102,29,63,240,48,93,190,18,22,229,62,105,140,102,191,160,23,50,191,80,27,93,191,136,131,68,61,218,228,248,190,218,225,207,189,132,212,9,191,174,41,4,191,64,164,95,63,43,50,106,63,218,2,178,62,122,226,65,63,40,98,145,61,182,245,11,191,233,67,7,191,211,133,216,61,230,116,217,189,48,19,101,62,183,12,0,191,160,24,81,191,107,100,3,63,85,219,37,63,145,181,118,191,170,213,15,63,33,206,67,191,115,100,77,191,210,29,120,191,48,16,88,191,58,2,80,63,55,168,61,190,200,122,26,63,209,117,105,63,10,242,243,61,120,95,61,63,100,31,36,189,212,11,34,63,134,57,185,190,11,211,215,62,218,29,98,191,40,241,249,190,97,55,172,62,71,199,237,62,26,22,59,191,11,184,23,191,238,237,106,63,7,180,132,190,159,88,3,63,188,2,65,190,200,234,118,63,7,180,124,191,247,175,172,187,103,158,244,62,78,39,41,63,242,35,254,60,211,77,34,61,46,89,101,63,177,50,106,62,214,55,144,61,2,183,114,191,108,238,40,61,237,156,98,63,198,195,39,63,129,180,63,189,45,151,141,59,124,70,202,62,194,194,105,63,251,177,185,190,133,121,119,191,176,88,171,62,94,219,123,190,17,228,232,190,17,112,168,190,52,19,72,191,138,32,62,190,103,127,160,61,70,37,93,191,218,29,14,63,199,46,209,190,95,96,86,189,162,8,5,63,246,150,202,190,171,64,113,63,143,25,40,187,45,36,60,191,201,200,217,188,77,131,118,191,255,202,86,191,154,65,76,191,243,29,220,61,2,130,73,191,51,53,121,62,71,170,239,187,196,65,94,63,235,173,77,191,218,59,127,63,37,202,134,62,41,235,99,191,71,58,187,190,27,215,151,62,94,130,227,62,10,216,198,62,133,121,87,63,217,118,98,191,209,88,27,63,59,29,176,190,145,100,70,62,139,51,62,63,195,240,73,191,176,1,73,63,245,100,158,190,223,23,59,63,186,73,28,191,159,227,187,190,117,32,139,190,207,219,176,190,234,63,27,63,30,78,112,190,155,227,60,190,80,254,78,63,55,112,95,63,236,162,232,60,216,186,84,61,119,188,9,190,159,200,211,189,201,118,126,62,16,205,12,190,18,20,87,191,52,101,183,62,15,95,254,62,247,174,233,62,31,49,74,190,154,35,235,189,1,162,152,62,131,24,168,189,162,11,2,191,99,66,116,63,253,105,99,191,23,216,67,191,96,174,85,191,196,151,101,63,139,84,152,189,127,105,101,63,7,178,54,191,159,3,15,63,119,77,192,190,235,254,113,189,36,14,41,62,122,139,199,62,59,167,65,63,227,196,215,188,232,107,134,62,181,78,92,190,122,114,121,191,42,57,95,191,63,115,46,63,5,136,9,193,102,148,185,63,200,195,97,186,39,7,206,63,194,244,136,148,16,147,221,63,9,31,89,223,17,172,229,63,35,236,118,30,94,181,234,63,52,149,153,96,165,27,240,63,115,135,245,208,195,131,242,63,52,207,26,143,156,68,245,63,27,177,129,58,6,232,247,63,148,120,131,99,171,143,250,63,136,50,67,7,190,137,253,63,226,26,175,98,112,108,0,64,254,160,248,241,19,39,2,64,141,110,168,11,189,245,3,64,211,145,165,212,250,188,5,64,122,36,89,156,245,84,7,64,67,182,116,16,41,130,183,63,130,138,43,41,30,176,207,63,212,50,67,123,93,156,222,63,97,71,83,165,124,28,228,63,232,51,133,174,130,40,233,63,38,250,33,219,158,197,237,63,233,8,131,99,52,129,241,63,98,54,249,20,157,8,244,63,238,227,75,93,119,24,247,63,242,72,255,52,117,123,250,63,188,214,116,49,204,68,254,63,175,142,205,89,25,198,0,64,166,189,28,209,152,98,2,64,176,140,43,124,102,220,3,64,12,99,14,103,94,118,5,64,176,170,127,140,144,12,7,64,110,108,91,116,240,156,204,63,252,13,0,188,81,57,218,63,131,13,156,171,30,123,230,63,66,116,29,110,52,185,241,63,71,79,75,220,124,77,246,63,61,211,148,171,59,201,250,63,47,161,41,84,227,72,255,63,138,153,44,142,132,194,1,64,33,105,159,38,45,21,4,64,190,192,211,60,108,67,6,64,111,248,44,114,128,30,195,63,182,57,17,102,154,197,215,63,2,254,38,157,19,166,232,63,125,67,139,106,157,249,240,63,3,24,221,93,138,59,245,63,228,244,200,178,38,74,249,63,143,67,177,87,7,112,253,63,42,161,226,89,181,228,0,64,131,2,194,209,13,15,3,64,228,154,45,98,25,126,5,64,176,13,11,63,136,62,248,189,216,24,125,190,0,4,140,61,172,65,17,62,170,248,128,62,154,218,189,62,68,11,212,62,142,60,18,63,253,211,21,63,30,43,17,63,177,223,35,63,228,15,37,63,22,49,44,63,220,186,255,62,54,182,14,63,56,248,80,62,48,40,2,190,32,14,104,190,224,112,38,189,192,169,109,188,0,240,231,60,88,77,174,61,64,3,187,61,144,225,5,62,20,70,69,62,148,148,108,62,96,206,144,62,66,103,162,62,46,139,226,62,180,150,151,62,158,194,179,62,30,177,78,63,32,26,37,61,87,13,10,63,66,95,49,63,69,98,38,63,108,153,59,63,40,140,70,63,132,208,70,63,59,204,97,63,40,163,87,63,88,208,99,63,103,78,89,63,81,141,93,63,194,62,44,63,178,238,29,63,233,243,44,63,170,19,187,62,56,67,173,189,224,197,183,188,16,134,229,61,16,4,209,61,60,94,50,62,28,26,90,62,20,51,93,62,126,80,185,62,82,80,214,62,127,167,11,63,90,81,9,63,153,252,10,63,66,126,179,62,54,194,168,62,0,101,185,62,64,200,60,62,192,87,147,60,174,228,159,62,144,83,184,62,36,154,124,62,52,123,94,62,60,75,74,62,136,42,241,61,64,30,245,61,80,251,173,61,232,40,197,61,188,252,34,62,208,144,107,62,80,214,157,62,204,60,207,62,90,246,200,62,0,18,226,188,136,203,162,189,88,62,239,61,16,239,34,62,248,139,187,61,112,208,60,61,208,65,102,61,64,80,10,60,128,124,28,188,80,130,39,189,0,13,26,189,160,198,136,188,200,90,134,61,128,25,251,61,104,209,106,62,60,98,91,62,204,213,244,62,25,187,159,191,122,24,250,62,189,136,70,63,81,179,45,63,255,180,40,63,247,33,30,63,2,142,36,63,221,74,10,63,121,31,13,63,21,118,36,63,180,135,216,62,224,184,2,63,179,123,3,63,130,232,229,62,210,93,243,62,212,8,146,62,132,213,176,191,48,250,66,62,152,150,249,62,48,43,235,62,78,39,214,62,196,192,213,62,148,193,235,62,172,95,209,62,218,64,199,62,100,171,240,62,164,14,116,62,190,113,143,62,14,254,173,62,188,167,141,62,154,195,172,62,22,175,23,63,48,146,197,62,7,167,137,63,82,64,19,63,102,55,13,63,40,133,248,62,124,161,241,62,61,119,0,63,150,131,155,62,84,243,3,63,223,135,97,63,40,140,70,63,11,25,24,63,238,120,203,62,129,178,23,63,4,23,28,63,198,4,154,62,32,183,144,61,15,51,89,63,70,205,131,62,80,42,144,62,116,179,69,62,48,54,129,62,92,207,137,62,224,63,2,62,128,213,135,62,95,183,37,63,183,15,7,63,94,31,201,62,220,76,118,62,26,60,205,62,214,69,233,62,51,225,59,63,88,174,219,62,22,156,47,63,229,137,34,63,90,173,77,63,31,215,89,63,190,239,91,63,6,112,141,63,232,71,178,63,157,209,171,63,17,222,138,63,74,246,100,63,140,164,91,63,253,43,49,63,36,179,15,63,104,82,220,62,144,45,232,62,176,169,184,61,14,105,177,62,106,173,177,62,231,144,5,63,139,99,22,63,143,247,25,63,0,139,106,63,72,36,164,63,211,19,156,63,175,6,99,63,100,197,38,63,165,249,31,63,254,9,228,62,14,170,187,62,144,149,101,62,134,208,219,62,234,33,169,62,186,64,30,63,227,8,125,63,247,213,125,63,179,66,75,63,84,148,154,62,232,50,122,62,240,154,232,62,124,206,15,63,50,161,250,62,240,245,40,63,170,7,33,63,58,223,14,63,215,194,11,63,32,242,237,62,148,75,16,62,128,74,164,187,126,160,130,62,4,46,45,63,205,21,54,63,162,6,238,62,32,228,246,60,32,44,193,188,176,150,208,61,8,16,120,62,52,104,118,62,186,206,204,62,246,30,190,62,178,227,166,62,42,159,195,62,88,231,147,62,47,249,69,63,60,5,85,63,160,170,167,63,11,61,132,63,102,223,132,63,246,175,114,63,135,89,121,63,73,189,113,63,127,133,100,63,37,53,95,63,115,52,93,63,177,36,87,63,191,254,85,63,53,129,68,63,130,132,48,63,175,2,58,63,44,40,187,62,112,187,237,62,13,204,155,63,137,138,85,63,188,186,86,63,163,219,43,63,36,118,46,63,2,35,33,63,138,103,4,63,181,69,5,63,76,119,10,63,27,166,7,63,37,3,20,63,114,6,0,63,6,8,242,62,48,127,221,62,69,232,99,63,140,111,235,62,1,169,35,63,206,136,229,62,19,65,31,63,255,222,33,63,131,212,52,63,124,92,190,62,209,253,43,63,32,165,73,63,240,188,143,62,40,167,159,62,29,158,43,63,87,40,68,63,190,86,54,63,16,1,73,63,220,82,33,63,104,35,250,61,186,225,180,62,72,171,16,62,236,193,177,62,104,227,175,62,228,180,228,62,100,95,14,62,134,143,209,62,160,105,10,63,120,103,141,61,232,208,169,61,218,217,236,62,92,241,17,63,183,229,13,63,13,143,39,63,248,98,225,189,148,189,194,62,202,190,78,63,50,187,48,63,204,29,77,63,176,147,72,63,236,208,81,63,77,142,86,63,132,166,77,63,140,76,64,63,108,172,35,63,46,16,28,63,70,136,49,63,63,69,43,63,28,227,35,63,177,93,15,63,232,245,53,190,96,43,240,188,92,185,27,62,156,203,50,62,8,142,99,62,212,73,156,62,74,120,152,62,98,114,194,62,224,219,173,62,158,106,152,62,82,221,128,62,216,35,118,62,188,171,182,62,20,27,169,62,146,113,172,62,200,122,169,62,62,8,15,63,26,106,239,62,192,163,14,62,200,244,202,189,160,44,167,189,56,201,234,189,64,133,63,188,224,206,85,61,192,144,38,62,90,177,149,62,96,84,206,62,94,226,231,62,50,96,240,62,108,126,1,63,136,115,9,63,10,178,2,63,20,158,96,62,224,27,248,61,192,87,147,60,92,29,79,190,232,92,16,190,88,53,89,190,88,17,236,189,16,143,115,189,192,16,72,188,160,172,224,60,248,225,16,62,236,87,81,62,40,0,94,62,38,240,133,62,206,109,171,62,196,211,189,62,229,72,24,63,196,222,52,63,183,4,113,63,93,31,111,63,90,47,98,63,1,28,121,63,134,177,89,63,69,232,99,63,76,234,95,63,12,235,48,63,51,244,35,63,75,150,50,63,251,116,23,63,212,42,26,63,66,225,69,63,153,19,28,63,28,60,1,62,212,47,5,62,87,208,40,63,135,81,39,63,10,94,16,63,79,191,50,63,8,61,247,62,77,199,14,63,216,15,235,62,142,198,151,62,54,255,137,62,48,58,170,62,52,118,146,62,234,159,148,62,172,183,236,62,20,134,172,62,17,211,97,63,93,157,90,63,58,105,148,62,204,113,63,63,98,205,2,63,117,147,91,63,122,24,250,62,226,222,72,63,229,183,68,63,111,7,52,63,21,76,43,63,106,253,91,63,163,55,112,63,221,21,123,63,51,53,46,63,200,240,35,63,192,28,15,63,198,138,215,62,192,72,212,60,124,31,221,62,48,124,87,62,62,157,11,63,252,163,54,62,186,187,228,62,210,219,222,62,172,95,209,62,136,131,204,62,188,52,25,63,137,241,47,63,253,108,59,63,68,183,225,62,68,141,232,62,115,25,35,63,98,144,33,63,252,28,55,63,24,102,49,63,16,182,106,62,146,155,165,62,159,228,118,63,97,244,124,63,18,77,95,63,62,196,223,62,124,115,207,62,198,35,253,62,87,13,10,63,157,209,24,63,60,143,218,62,44,132,255,62,58,197,216,62,204,186,186,62,30,124,222,62,32,5,214,62,0,228,37,186,112,21,112,61,124,19,67,63,208,177,80,63,117,185,43,63,196,147,86,62,152,17,95,62,158,41,142,62,156,225,160,62,240,1,195,62,244,15,137,62,194,154,143,62,154,222,230,62,82,244,114,63,254,20,91,63,28,189,83,63,207,9,49,63,104,112,59,63,192,51,32,63,181,157,32,63,159,25,6,63,238,253,4,63,250,201,210,62,250,48,173,62,214,65,192,62,186,61,249,62,168,145,17,63,75,188,2,63,112,155,202,61,77,222,31,63,100,171,240,62,150,242,199,62,184,168,134,62,72,25,154,62,252,60,92,62,40,191,83,62,40,15,29,62,164,243,57,62,32,168,209,61,160,35,25,61,240,206,183,61,164,94,61,62,170,15,146,62,8,114,134,62,229,210,126,63,80,149,116,63,92,226,82,63,33,100,122,63,87,231,57,63,101,216,73,63,68,22,75,63,171,68,61,63,142,217,96,63,100,61,133,63,49,202,130,63,233,121,106,63,109,172,94,63,234,174,52,63,194,43,68,63,158,228,59,63,98,148,74,63,137,134,44,63,238,146,1,63,192,181,52,63,34,54,178,62,106,28,222,62,222,193,226,62,218,106,192,62,195,161,24,63,255,226,74,63,176,254,75,63,195,184,41,63,171,236,33,63,140,111,235,62,184,244,7,63,125,72,13,63,234,125,237,62,48,198,119,61,116,72,66,62,106,66,174,62,238,17,241,62,33,46,6,63,45,43,27,63,14,9,37,63,184,57,59,63,74,135,56,63,135,123,32,63,15,173,27,63,116,144,251,62,182,184,180,62,126,172,253,62,113,163,19,63,92,162,10,62,224,201,224,188,1,16,133,57,32,247,222,60,224,122,99,61,184,182,133,61,136,252,206,61,200,205,219,61,44,163,32,62,56,15,98,62,212,219,18,62,196,170,103,62,48,15,241,61,96,62,133,60,98,129,129,62,42,75,209,62,88,82,120,63,56,224,125,63,233,121,106,63,73,82,110,63,83,45,102,63,12,113,110,63,20,237,103,63,135,131,114,63,219,224,117,63,10,18,112,63,215,118,107,63,240,16,99,63,8,198,89,63,171,7,92,63,209,1,85,63,221,189,95,63,50,23,148,62,96,197,97,61,216,216,182,61,40,82,237,61,112,132,185,61,112,86,151,61,208,229,33,61,64,231,196,60,192,111,67,61,176,230,153,61,104,226,239,61,180,63,31,62,0,201,13,62,0,56,58,62,220,137,87,62,180,231,3,62,188,3,210,62,178,78,170,62,14,239,238,62,120,249,1,63,193,215,22,63,236,197,218,62,32,34,119,61,132,234,93,191,129,32,142,191,248,94,184,189,192,144,38,62,8,92,24,62,224,116,211,62,83,14,3,63,19,0,21,63,40,113,12,63,0,252,28,61,212,47,5,62,24,8,107,62,196,142,138,62,44,147,190,62,204,225,45,62,168,107,191,189,159,36,94,191,19,70,137,191,28,164,93,190,0,130,186,187,96,1,247,188,208,6,5,62,120,24,132,62,164,74,178,62,128,222,124,62,90,104,26,63,144,48,13,63,218,194,219,62,195,180,0,63,90,24,81,63,73,217,139,63,181,230,124,63,252,177,51,63,158,125,128,62,228,116,125,62,45,234,16,63,164,188,3,63,130,255,246,62,8,213,24,63,89,131,25,63,167,214,9,63,72,71,188,62,82,179,135,62,88,102,34,62,156,165,98,62,134,127,14,63,63,180,87,63,242,172,66,63,2,158,231,62,72,123,139,61,104,4,151,61,234,75,162,62,190,220,146,62,182,73,136,62,146,29,186,62,58,48,220,62,156,164,191,62,210,115,0,63,241,218,41,63,156,217,47,63,154,229,52,63,72,36,17,63,128,101,126,61,176,249,129,61,176,179,109,62,125,15,85,63,230,76,124,63,151,100,84,63,74,47,29,63,89,215,11,63,110,76,44,63,41,132,47,63,54,247,24,63,206,63,137,62,90,51,170,62,172,221,188,62,126,252,198,62,112,7,142,62,108,147,45,190,88,152,10,190,192,64,130,60,67,236,22,63,188,56,66,63,117,97,16,63,0,208,188,62,18,39,174,62,156,61,229,62,120,227,244,62,230,145,206,62,220,67,98,63,233,14,103,63,43,143,59,63,169,252,79,63,82,72,101,63,227,227,140,63,128,247,162,63,53,251,153,63,152,189,138,63,129,102,119,63,105,85,60,63,32,184,49,63,123,23,49,63,123,107,35,63,50,122,38,63,127,83,25,63,226,195,14,63,10,91,235,62,174,18,194,62,186,41,13,63,5,191,59,63,32,20,118,63,228,76,153,63,255,2,142,63,175,6,99,63,169,206,45,63,112,187,237,62,138,77,206,62,208,124,224,62,22,61,198,62,48,127,221,62,176,6,189,62,81,34,90,63,55,98,87,63,136,77,57,63,155,15,105,63,158,14,53,63,248,220,37,63,88,90,233,62,144,103,67,62,96,23,105,189,144,140,207,189,40,228,128,62,212,146,248,62,126,3,21,63,189,174,22,63,98,37,30,63,172,102,31,63,2,184,29,63,132,29,235,62,38,80,243,62,124,38,43,63,48,127,221,62,114,194,208,62,72,244,108,62,64,55,142,60,140,32,98,190,162,88,154,190,48,144,3,61,8,7,131,62,148,124,184,62,186,118,177,62,22,126,208,62,154,138,244,62,101,86,53,63,175,113,102,63,66,244,45,63,25,29,163,63,130,2,175,63,127,207,160,63,147,17,91,63,124,42,84,63,202,83,75,63,51,248,76,63,134,24,52,63,185,68,12,63,43,162,35,63,58,246,31,63,25,178,12,63,124,161,241,62,186,206,204,62,172,60,38,63,78,169,234,62,156,255,146,63,199,70,160,63,43,198,143,63,166,115,29,63,101,231,8,63,48,1,242,62,179,230,6,63,72,10,219,62,76,150,140,62,18,20,198,62,250,52,214,62,26,228,177,62,38,72,161,62,112,49,104,63,14,204,67,63,34,58,219,62,97,41,12,63,102,178,211,62,108,253,240,62,248,236,232,62,204,255,237,62,150,32,234,62,214,241,246,62,56,232,238,62,238,231,247,62,210,196,205,62,12,14,220,62,74,235,237,62,0,238,27,63,174,45,252,62,204,122,83,62,160,70,194,61,252,205,47,62,128,63,203,61,124,127,8,62,12,152,0,62,16,193,0,62,24,170,195,61,176,24,229,61,224,128,12,62,20,66,28,62,96,224,184,61,188,252,34,62,128,50,111,62,16,223,192,62,254,24,163,62,32,39,94,63,224,20,71,63,128,232,80,63,19,199,92,63,190,67,78,63,37,160,98,63,156,221,88,63,160,29,106,63,246,3,101,63,199,38,93,63,173,102,90,63,42,21,62,63,229,30,31,63,241,111,38,63,11,90,34,63,240,173,76,189,192,222,140,61,40,60,156,62,146,113,172,62,110,8,253,62,88,193,195,62,38,125,17,63,35,34,1,63,13,185,32,63,98,228,19,63,227,19,19,63,29,219,12,63,242,77,217,62,226,249,161,62,6,130,180,62,250,113,183,62,60,223,163,62,34,8,113,63,49,84,27,63,104,185,182,62,40,229,35,62,152,119,150,62,48,166,80,62,210,127,154,62,238,177,131,62,94,142,245,62,51,160,49,63,121,77,47,63,132,36,57,63,77,115,28,63,130,21,4,63,86,167,248,62,240,95,139,61,124,229,32,63,36,187,128,62,32,206,161,61,16,230,140,189,224,206,85,61,0,23,183,187,208,0,92,61,192,45,154,60,80,215,64,62,176,10,230,62,58,48,220,62,206,52,243,62,90,74,187,62,170,187,159,62,126,76,144,62,68,190,47,63,177,112,138,63,134,223,123,63,75,112,98,63,241,161,113,63,145,136,99,63,33,96,81,63,56,178,91,63,87,124,54,63,18,73,54,63,55,10,60,63,76,104,75,63,146,21,73,63,150,127,83,63,74,177,49,63,35,38,42,63,78,203,145,62,68,26,116,63,128,79,43,63,237,173,0,63,99,52,24,63,48,62,211,62,126,252,198,62,68,137,191,62,88,68,123,62,182,245,149,62,42,220,164,62,14,44,208,62,150,135,196,62,172,160,219,62,242,54,200,62,214,172,195,62,214,22,145,63,40,254,132,63,103,181,51,63,221,204,30,63,166,245,49,63,10,7,249,62,94,252,29,63,100,239,31,63,224,58,23,63,247,205,43,63,62,119,59,63,96,72,52,63,29,70,16,63,224,16,30,63,236,55,44,63,132,162,36,63,16,224,129,63,151,184,70,63,208,79,97,62,188,218,123,62,150,108,138,62,64,238,12,62,174,33,129,62,4,73,134,62,8,165,116,62,4,96,151,62,186,141,194,62,170,19,187,62,96,34,131,62,242,134,145,62,230,145,206,62,230,122,189,62,225,96,34,63,63,119,118,63,208,127,5,63,192,232,185,188,166,199,15,63,174,29,57,63,80,229,61,63,212,199,104,63,28,86,121,63,114,205,71,63,8,87,45,63,103,158,34,63,6,157,238,62,200,68,22,63,235,82,43,63,253,62,25,63,86,56,204,62,110,34,51,63,164,56,109,62,144,104,131,190,84,125,137,62,122,150,229,62,130,232,229,62,210,77,48,63,241,50,69,63,207,177,21,63,236,113,232,62,226,211,209,62,120,24,132,62,242,222,172,62,84,114,243,62,25,113,2,63,70,129,227,62,41,230,1,64,71,44,40,63,159,220,36,63,178,196,36,63,75,253,12,63,88,9,28,63,91,77,27,63,101,231,8,63,98,129,129,62,28,136,227,62,240,54,51,63,234,113,83,63,45,192,23,63,78,0,2,63,38,57,226,62,200,234,120,62,72,233,244,63,174,167,190,62,226,188,192,62,26,102,198,62,160,117,164,62,142,53,196,62,152,20,229,62,116,159,186,62,240,183,166,61,42,239,140,62,32,242,237,62,210,119,41,63,20,96,220,62,30,246,160,62,238,135,138,62,242,92,121,63,32,90,137,63,9,110,121,63,109,237,104,63,165,1,114,63,106,85,119,63,91,85,109,63,52,225,118,63,81,187,127,63,212,115,118,63,162,82,111,63,215,141,124,63,152,161,112,63,36,168,121,63,243,19,88,63,101,197,97,63,83,3,109,63,126,146,132,63,87,170,88,63,31,150,79,63,169,210,86,63,174,75,91,63,29,162,84,63,183,88,99,63,226,12,107,63,219,243,93,63,29,162,84,63,22,76,102,63,132,124,84,63,224,1,95,63,66,53,56,63,242,88,80,63,32,162,8,63,192,78,246,62,192,216,192,190,128,188,246,189,0,0,184,189,0,80,232,187,0,101,232,61,192,251,8,62,224,113,191,62,96,18,197,62,192,18,216,62,144,93,10,63,192,193,5,63,224,223,12,63,64,6,8,63,160,149,225,62,0,202,53,62,128,246,43,62,0,98,138,190,0,51,11,190,64,187,20,190,0,252,181,189,0,66,210,188,0,144,27,187,0,247,219,61,128,153,18,62,192,255,10,62,64,118,81,62,64,140,137,62,224,79,174,62,96,81,164,62,128,251,24,62,96,128,61,63,128,172,171,61,128,12,38,63,128,80,29,63,192,172,59,63,144,226,55,63,32,98,62,63,128,70,67,63,208,239,67,63,176,145,71,63,176,5,87,63,96,221,86,63,144,108,82,63,176,86,63,63,16,9,43,63,16,42,38,63,64,242,145,62,0,224,94,189,0,222,245,188,0,172,167,60,0,187,6,61,0,100,113,61,128,27,163,61,128,58,243,61,64,56,7,62,0,154,29,62,64,62,96,62,192,179,146,62,32,68,152,62,64,218,133,62,0,119,119,62,128,185,120,62,16,237,28,63,224,229,58,63,0,92,84,62,160,38,0,63,64,69,18,63,96,153,9,63,176,26,33,63,32,92,16,63,16,131,61,63,16,195,50,63,160,5,239,62,160,124,43,63,240,55,96,63,224,43,94,63,224,43,94,63,32,245,71,63,96,229,152,62,128,103,167,62,0,248,29,60,128,100,56,62,0,88,125,62,0,161,97,62,64,2,154,62,0,235,136,62,224,140,226,62,192,43,207,62,0,90,83,62,192,147,216,62,192,73,31,63,80,78,40,63,64,123,45,63,128,18,41,63,96,206,57,63,192,228,1,63,32,27,202,190,240,133,6,63,24,47,135,63,192,122,120,63,208,3,121,63,80,40,107,63,32,136,81,63,80,206,104,63,48,82,93,63,208,122,73,63,32,128,34,63,160,44,3,63,32,183,145,62,32,139,166,62,128,123,220,62,128,135,95,62,128,1,251,190,0,161,54,62,16,65,71,63,0,25,55,63,208,141,61,63,112,236,25,63,16,201,10,63,240,117,41,63,144,182,33,63,80,71,15,63,224,92,202,62,192,165,182,62,192,29,26,62,192,28,4,62,160,142,157,62,96,56,130,62,160,32,145,62,0,58,7,63,32,248,8,63,160,33,253,62,192,134,231,62,224,4,158,62,192,248,114,62,128,207,167,61,0,227,13,190,0,193,173,189,0,6,28,189,0,39,244,61,160,72,165,62,192,66,154,62,0,82,104,61,0,74,161,60,128,194,139,61,128,76,87,62,64,30,123,62,0,4,83,62,128,234,37,62,128,150,160,61,0,89,43,61,0,24,80,189,64,167,96,190,0,109,40,190,128,115,11,190,0,234,251,188,0,58,24,62,192,74,113,62,32,169,224,62,112,136,18,63,160,96,29,63,0,83,127,63,248,15,149,63,104,78,152,63,120,46,132,63,128,163,49,63,16,63,27,63,32,242,239,62,192,232,237,62,96,167,250,62,144,191,16,63,96,185,25,63,144,47,30,63,112,215,36,63,0,153,7,62,64,110,120,62,224,94,160,62,224,104,60,63,240,148,121,63,192,28,116,63,192,126,79,63,32,227,210,62,32,72,154,62,64,110,77,62,0,187,110,62,224,204,129,62,224,204,172,62,224,22,210,62,128,17,210,62,128,231,231,62,80,202,59,63,224,155,107,63,160,109,248,62,240,92,93,63,16,254,58,63,48,24,64,63,48,5,33,63,224,166,48,63,48,97,36,63,176,183,4,63,64,148,227,62,64,52,136,62,192,116,91,62,64,106,118,62,192,166,247,62,0,74,15,63,224,236,188,62,0,84,254,62,0,246,240,61,208,68,3,63,0,164,165,62,192,108,175,62,128,140,119,62,0,129,169,62,128,166,134,62,64,50,90,62,0,26,8,62,0,2,64,61,0,76,6,188,0,240,111,60,128,230,121,62,160,133,174,62,208,73,113,63,64,181,117,63,160,182,29,63,48,129,52,63,80,111,78,63,192,4,104,63,112,49,125,63,40,127,128,63,24,84,132,63,64,3,114,63,192,161,118,63,224,140,78,63,32,154,47,63,64,18,100,63,48,193,127,63,160,146,129,63,80,137,48,63,192,42,37,63,96,77,162,62,0,141,218,62,128,13,17,63,80,179,69,63,96,116,98,63,0,250,103,63,128,125,116,63,112,215,79,63,240,47,92,63,16,237,28,63,224,201,1,63,64,223,52,63,112,74,73,63,224,210,70,63,64,108,16,63,0,231,192,189,0,42,41,61,128,102,57,62,32,32,177,62,96,183,215,62,32,85,225,62,128,42,10,63,224,143,15,63,48,136,34,63,64,170,47,63,48,98,58,63,128,9,58,63,48,13,37,63,128,70,24,63,32,41,12,63,192,68,67,62,0,161,84,189,0,20,121,189,0,160,246,186,0,231,28,61,0,129,20,61,0,9,89,61,0,220,141,61,128,48,195,61,192,249,7,62,128,102,14,62,64,4,67,62,0,236,113,62,0,90,83,62,0,183,108,62,64,168,106,62,0,122,125,63,128,127,117,63,128,183,102,63,80,66,77,63,160,152,100,63,192,232,89,63,224,6,97,63,96,30,98,63,80,28,101,63,160,121,106,63,112,232,109,63,160,78,106,63,112,187,108,63,176,23,96,63,128,126,95,63,32,130,78,63,32,153,216,62,0,74,62,189,0,136,149,60,128,132,237,61,0,148,112,62,192,81,140,62,32,240,152,62,128,96,185,62,64,223,200,62,160,93,240,62,240,45,5,63,112,32,9,63,80,112,14,63,192,72,9,63,128,87,245,62,96,51,1,63,112,129,122,63,192,205,97,63,128,3,203,62,0,66,245,62,0,19,200,62,64,208,214,62,128,112,150,62,0,123,209,62,192,89,187,62,128,95,206,62,128,109,213,62,144,202,0,63,128,151,0,63,80,24,13,63,80,16,9,63,240,106,14,63,64,199,40,63,96,53,150,62,0,121,102,61,192,198,3,62,0,76,155,61,128,60,244,61,0,120,80,61,128,181,240,61,128,24,140,61,0,127,202,61,0,58,189,61,0,83,58,62,64,59,73,62,0,44,103,62,128,38,156,62,192,64,153,62,96,71,54,63,0,231,72,63,208,73,27,63,64,61,57,63,192,142,44,63,80,76,39,63,96,49,191,62,128,44,245,62,32,214,225,62,64,88,49,63,112,181,137,63,176,180,142,63,216,18,137,63,240,190,99,63,224,226,35,63,144,118,1,63,192,145,215,62,64,223,243,62,96,83,165,62,192,217,208,62,128,212,200,62,224,177,180,62,192,235,0,62,0,26,94,62,128,12,98,62,64,207,235,62,80,61,96,63,240,222,115,63,240,102,98,63,0,60,51,63,224,148,230,62,160,98,178,62,64,131,6,63,192,242,8,63,112,32,52,63,0,192,31,63,16,126,37,63,64,247,64,63,144,198,84,63,64,194,59,63,96,109,178,62,128,24,61,62,128,24,183,61,32,170,203,62,192,104,68,63,160,39,108,63,80,192,97,63,160,205,62,63,224,124,132,62,32,65,129,62,128,191,211,62,64,57,160,62,32,69,174,62,32,7,229,62,112,116,8,63,128,115,216,62,128,57,221,61,0,80,146,187,0,229,148,189,192,45,34,62,176,189,7,63,224,59,59,63,128,110,44,63,96,38,16,63,128,43,75,63,16,232,90,63,240,191,121,63,128,52,101,63,112,64,111,63,224,96,56,63,32,189,86,63,112,78,75,63,64,77,65,63,16,28,74,63,16,234,91,63,240,7,72,63,160,44,89,63,224,127,93,63,224,209,91,63,64,95,117,63,32,209,244,62,192,70,242,62,112,53,84,63,176,20,30,63,160,238,57,63,160,71,186,62,80,239,13,63,32,207,243,62,224,179,224,62,192,140,0,63,176,35,16,63,128,149,233,62,0,224,4,63,160,0,24,63,80,183,28,63,64,133,50,63,232,69,137,63,152,193,133,63,240,4,92,63,160,170,66,63,128,166,72,63,0,75,80,63,64,38,67,63,208,32,28,63,112,172,36,63,224,183,35,63,128,116,47,63,0,123,61,63,144,109,61,63,192,231,67,63,144,123,68,63,240,71,61,63,160,47,112,63,16,140,87,63,0,21,158,62,32,91,185,62,192,163,181,62,224,36,217,62,0,83,146,62,128,123,89,62,0,64,113,62,224,17,143,62,32,221,164,62,96,151,199,62,96,155,201,62,160,199,207,62,64,126,216,62,32,20,214,62,128,134,131,63,16,10,140,63,88,26,130,63,128,230,104,63,144,168,112,63,0,203,101,63,32,229,106,63,128,220,99,63,96,89,106,63,144,2,115,63,32,37,128,63,176,160,132,63,248,153,132,63,208,153,110,63,144,189,101,63,80,149,97,63,88,151,128,63,176,2,139,63,96,189,113,63,80,81,63,63,112,160,73,63,32,182,61,63,96,1,62,63,96,57,47,63,160,195,57,63,224,117,88,63,80,157,101,63,240,171,111,63,144,195,104,63,240,156,82,63,16,135,63,63,112,120,53,63,0,204,97,62,0,60,84,188,0,35,199,61,128,130,236,61,0,240,194,61,0,238,28,62,0,231,3,62,128,47,51,62,64,239,34,62,192,157,90,62,0,174,125,62,0,231,134,62,32,74,155,62,32,141,167,62,32,88,162,62,64,104,162,62,0,80,87,59,0,187,54,189,0,46,233,60,0,184,126,60,0,200,206,187,0,36,185,60,0,132,14,60,0,180,214,60,0,122,142,60,0,170,19,61,0,47,22,61,0,104,176,60,0,212,40,61,128,129,214,61,64,214,0,62,0,202,121,61,128,38,25,62,32,184,167,62,32,29,92,63,48,76,47,63,64,77,65,63,80,245,16,63,16,107,49,63,0,172,64,63,48,227,58,63,16,125,58,63,16,48,41,63,96,188,5,63,224,210,218,62,32,98,19,63,160,214,236,62,240,41,3,63,0,68,16,189,0,173,47,189,96,71,159,62,64,56,138,62,96,91,169,62,192,227,82,62,128,208,110,62,224,16,164,62,128,188,145,62,128,197,171,62,128,189,122,62,64,10,27,62,0,157,217,61,32,202,133,62,192,112,89,62,128,161,153,62,64,52,31,63,128,117,26,63,192,9,233,62,224,225,161,62,96,174,146,62,96,152,30,63,240,251,65,63,192,203,128,63,96,55,89,63,80,131,45,63,16,219,62,63,128,225,185,62,64,90,110,62,240,106,14,63,160,196,227,62,192,232,194,62,0,102,134,62,224,48,137,62,192,97,60,62,0,150,9,61,0,232,240,60,224,156,148,62,128,232,253,62,160,100,74,63,176,41,19,63,96,51,192,62,160,152,248,62,0,40,223,61,0,172,20,61,96,252,185,62,96,70,137,62,64,17,140,62,224,217,52,63,64,232,226,62,48,73,67,63,16,39,58,63,48,253,71,63,64,218,71,63,160,23,100,63,112,87,101,63,80,165,105,63,208,96,103,63,96,179,108,63,240,99,118,63,192,38,121,63,240,243,61,63,192,142,1,63,240,215,4,63,224,255,176,62,0,124,116,188,128,136,162,62,32,87,183,62,128,74,217,62,96,232,218,62,16,182,22,63,112,217,37,63,192,206,33,63,0,169,41,63,240,215,47,63,192,90,61,63,240,79,65,63,80,12,7,63,192,115,157,62,192,232,194,62,0,24,224,62,160,29,251,62,208,83,32,63,112,17,23,63,0,217,213,62,0,114,181,60,128,38,37,190,128,250,100,190,0,205,222,189,0,128,19,187,0,110,215,61,96,91,169,62,192,98,213,62,192,225,255,62,0,222,237,62,240,217,5,63,0,139,251,61,128,31,43,62,32,21,150,62,96,142,130,62,0,5,19,62,0,92,230,189,128,111,95,190,192,110,139,190,128,30,33,190,0,146,171,189,0,89,5,189,128,205,209,61,128,128,70,62,96,170,144,62,64,31,102,62,224,111,147,62,64,46,28,63,0,63,74,63,16,71,117,63,48,100,102,63,160,127,109,63,128,219,120,63,160,34,127,63,144,137,118,63,64,9,117,63,208,51,102,63,224,70,86,63,128,230,61,63,32,170,55,63,96,191,28,63,16,183,44,63,208,250,51,63,0,245,175,61,0,54,187,61,16,149,27,63,240,16,12,63,240,40,24,63,96,55,46,63,176,3,43,63,128,117,26,63,48,91,33,63,224,143,249,62,224,189,186,62,192,212,141,62,32,67,130,62,160,137,133,62,32,147,170,62,0,125,253,62,64,108,207,62,120,21,141,63,16,132,83,63,64,70,40,63,48,73,24,63,80,233,10,63,192,96,255,62,0,194,223,62,128,92,226,62,128,118,196,62,32,230,190,62,64,201,189,62,160,125,213,62,0,69,182,62,128,75,153,62,128,124,199,62,128,208,146,61,112,230,108,63,128,96,142,62,128,234,123,62,0,139,43,62,0,109,28,62,0,229,2,62,0,53,251,61,0,156,238,61,0,39,201,61,128,5,195,61,0,7,228,61,128,124,25,62,0,150,192,61,128,115,164,61,192,211,31,62,48,213,51,63,192,131,60,63,48,132,118,63,208,169,118,63,168,125,138,63,8,149,147,63,80,51,166,63,64,121,162,63,136,118,164,63,152,212,164,63,176,77,155,63,136,234,136,63,120,17,139,63,208,52,124,63,240,203,84,63,128,6,78,63,64,172,153,62,128,196,104,62,0,194,32,63,176,144,49,63,0,73,79,63,64,173,113,63,248,42,141,63,96,156,150,63,80,91,143,63,176,149,148,63,192,133,136,63,16,35,99,63,192,133,104,63,224,159,66,63,0,122,39,63,16,84,59,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+112640);
/* memory initializer */ allocate([0,200,131,61,240,78,46,191,64,246,147,62,176,61,29,63,64,187,34,63,192,189,46,63,80,62,32,63,32,55,253,62,176,47,22,63,160,192,34,63,240,88,5,63,128,113,215,62,96,55,3,63,32,105,192,62,224,219,10,63,144,4,30,63,0,107,130,189,16,49,66,191,128,49,174,61,32,113,153,62,128,96,185,62,128,137,227,62,192,99,235,62,96,200,159,62,192,168,205,62,176,175,0,63,192,135,210,62,192,254,162,62,128,186,187,62,192,95,59,62,32,98,167,62,32,182,209,62,160,127,109,63,160,18,119,63,32,208,117,63,48,202,110,63,32,188,107,63,48,8,99,63,32,178,102,63,0,97,91,63,80,202,102,63,0,160,101,63,48,204,111,63,208,202,113,63,192,152,92,63,176,81,82,63,176,87,85,63,80,62,75,63,64,9,48,62,128,253,233,61,0,18,255,61,192,143,40,62,128,63,16,62,128,132,194,61,0,196,222,60,0,186,217,60,0,208,210,187,0,164,50,188,0,88,121,60,0,250,206,60,0,196,136,60,0,195,150,61,128,236,246,61,192,23,66,62,80,175,24,63,112,68,27,63,48,10,57,63,160,29,60,63,0,17,147,61,128,173,114,62,192,137,123,62,96,3,254,62,80,27,36,63,96,53,45,63,80,88,45,63,32,133,58,63,96,178,43,63,176,179,2,63,208,193,1,63,48,4,11,63,0,118,142,62,128,37,134,62,128,135,226,62,96,46,211,62,128,84,237,189,0,142,152,60,0,88,196,59,64,207,61,62,224,181,182,62,224,33,194,62,160,246,209,62,64,84,238,62,128,69,236,62,192,86,164,62,0,203,163,62,32,113,196,62,176,30,78,63,32,195,89,63,224,87,116,63,176,246,14,63,16,96,22,63,240,157,18,63,128,39,30,63,112,21,68,63,240,222,115,63,72,110,133,63,24,8,137,63,152,140,128,63,16,188,25,63,224,0,199,62,224,172,242,62,176,124,39,63,128,128,244,62,48,223,13,63,112,122,54,63,128,213,91,62,64,36,128,62,0,219,126,62,96,18,154,62,64,0,239,62,96,104,49,63,224,39,92,63,240,227,96,63,128,19,63,63,224,188,164,62,0,143,2,62,32,175,141,62,16,15,3,63,176,10,25,63,96,96,2,63,152,115,137,63,64,212,68,63,80,76,82,63,64,169,68,63,0,127,254,62,192,128,142,62,128,211,135,62,160,155,185,62,64,239,17,63,144,32,1,63,96,247,204,62,64,41,4,63,160,160,18,63,176,201,13,63,64,232,140,62,192,249,50,62,96,16,91,63,64,46,219,62,160,173,3,63,64,245,211,62,64,113,57,62,0,120,51,60,0,220,1,61,128,131,172,61,64,57,160,62,160,223,133,62,192,41,32,62,0,234,112,62,128,101,166,62,128,127,179,62,176,152,53,63,32,63,66,63,136,6,237,63,48,47,129,63,16,208,78,63,176,25,97,63,112,49,82,63,64,45,92,63,224,252,48,63,80,199,36,63,208,38,31,63,192,196,28,63,112,19,24,63,240,81,23,63,128,141,38,63,176,129,20,63,32,151,172,62,0,183,239,62,200,56,246,63,32,44,78,63,80,57,8,63,48,93,34,63,112,102,1,63,96,46,20,63,192,79,225,62,224,63,209,62,0,234,200,62,192,18,216,62,160,91,196,62,32,153,216,62,176,226,4,63,192,80,204,62,224,177,32,63,88,93,142,63,112,83,131,63,64,218,114,63,64,32,107,63,64,239,103,63,240,114,104,63,16,5,84,63,112,18,88,63,96,238,73,63,96,46,63,63,16,183,44,63,176,198,33,63,0,235,31,63,0,244,57,63,0,35,60,63,64,153,120,62,120,230,138,63,160,55,30,63,48,110,21,63,96,109,221,62,160,220,239,62,128,194,191,62,224,254,154,62,128,184,186,62,128,181,118,62,128,2,93,62,192,55,82,62,128,33,87,62,128,26,105,62,96,144,174,62,96,38,207,62,160,210,86,63,80,16,95,63,224,124,145,63,112,113,146,63,216,122,146,63,32,59,139,63,72,155,134,63,8,70,129,63,48,239,107,63,16,41,102,63,240,110,102,63,48,57,102,63,224,54,78,63,16,169,80,63,32,47,58,63,144,56,56,63,224,76,237,62,0,170,20,63,56,124,144,63,240,167,141,63,240,202,137,63,208,194,109,63,80,71,101,63,16,120,77,63,0,46,44,63,48,239,21,63,32,129,13,63,0,181,4,63,128,231,231,62,112,231,1,63,0,50,237,62,48,53,14,63,226,232,249,62,106,157,76,190,169,69,198,190,96,71,51,60,40,176,38,61,210,34,55,62,96,100,43,62,175,148,174,62,253,238,207,62,130,169,5,63,154,205,24,62,208,134,12,190,175,103,137,190,72,192,126,189,40,211,127,189,128,103,223,187,128,44,249,187,240,79,139,61,220,55,216,61,236,190,245,61,123,30,75,63,0,239,162,58,109,15,217,62,148,88,13,63,184,83,38,63,176,114,36,63,155,142,55,63,79,138,55,63,75,32,71,63,178,246,86,63,58,187,141,62,64,85,73,189,104,107,5,189,48,49,214,60,40,117,64,61,12,1,133,61,164,29,160,61,144,64,211,61,12,172,244,61,170,12,123,62,122,161,56,63,62,217,41,62,224,100,38,60,49,72,16,63,162,166,168,63,46,120,152,63,21,55,144,63,202,179,82,63,228,67,92,63,189,58,79,63,211,84,187,62,176,58,167,61,74,71,86,190,32,79,71,62,197,246,138,63,55,251,114,63,153,155,88,63,31,245,4,63,246,248,24,63,242,129,7,63,76,98,115,63,106,105,104,63,251,151,96,63,236,36,94,63,227,106,77,63,124,17,80,63,221,26,83,63,163,190,96,63,104,6,114,63,187,130,124,63,185,57,48,63,24,165,48,63,195,184,52,63,201,192,39,63,99,149,21,63,8,43,14,63,113,185,22,63,138,66,38,63,178,200,69,63,199,126,71,63,120,191,117,62,248,128,70,62,176,109,227,62,197,35,229,62,148,109,156,62,246,180,50,62,232,130,240,61,148,45,139,61,0,64,160,61,78,155,45,62,96,145,139,60,240,191,207,60,160,49,84,62,134,89,67,62,36,138,224,61,120,240,5,61,32,38,92,188,48,252,60,189,40,191,24,189,176,49,199,188,173,179,11,63,58,69,193,62,254,7,6,63,185,78,153,62,8,54,117,62,244,182,18,63,26,67,127,63,155,20,149,63,181,30,103,63,255,27,71,63,236,86,106,62,220,252,241,61,42,101,84,62,96,123,17,61,0,88,35,187,176,240,132,62,190,91,63,63,159,12,105,63,110,191,23,63,143,95,244,62,198,119,39,63,173,41,36,63,72,51,67,63,210,89,72,63,34,195,247,62,53,140,169,62,201,95,234,62,189,117,91,63,25,185,113,63,97,11,84,63,186,6,146,62,52,225,133,62,128,39,216,62,66,235,220,62,202,229,18,62,200,127,50,61,140,18,15,62,165,118,13,63,113,218,44,63,63,121,12,63,5,154,44,63,121,209,135,63,179,104,134,63,155,254,116,63,154,188,110,63,113,159,108,63,249,52,106,63,3,239,84,63,109,7,69,63,49,177,45,63,170,222,105,62,178,82,121,63,106,157,8,63,59,181,254,62,93,182,204,62,251,34,188,62,148,63,139,62,229,147,133,62,240,205,85,62,234,151,43,62,109,74,191,62,59,220,197,191,165,243,107,63,176,193,75,63,63,95,60,63,234,42,57,63,5,36,58,63,145,107,47,63,67,109,48,63,77,177,40,63,112,70,255,61,244,190,219,191,188,38,52,63,177,234,245,62,94,97,240,62,99,85,238,62,155,83,5,63,141,211,7,63,151,95,7,63,42,31,7,63,35,124,129,63,73,255,124,63,57,225,86,63,123,148,99,63,136,184,100,63,218,255,99,63,1,22,108,63,239,181,101,63,238,253,108,63,13,64,110,63,16,130,2,63,96,13,47,188,168,90,17,62,66,156,143,62,174,115,190,62,68,45,189,62,105,152,237,62,116,225,0,63,111,40,15,63,158,77,42,63,66,201,120,63,219,242,66,63,30,118,94,62,70,236,251,62,184,183,220,62,57,251,0,63,47,1,239,62,151,174,8,63,78,8,228,62,246,92,207,62,168,132,39,63,204,209,246,61,64,108,165,187,174,203,33,62,74,3,6,62,190,36,46,62,180,60,50,62,24,51,95,62,224,116,73,62,164,122,46,62,99,44,68,63,140,22,206,62,172,201,176,63,185,7,149,63,189,21,137,63,186,51,123,63,213,46,129,63,35,174,104,63,104,19,71,63,128,169,81,63,33,188,177,62,88,174,118,61,16,205,178,63,97,197,138,63,48,223,100,63,49,59,59,63,89,9,60,63,246,202,7,63,142,180,208,62,9,58,232,62,34,53,5,62,62,125,7,62,218,163,65,63,236,200,59,63,15,222,74,63,145,153,26,63,159,143,48,63,68,45,189,62,34,175,144,62,15,197,162,62,128,189,170,188,96,112,89,189,19,152,176,62,86,141,195,62,26,180,228,62,158,190,143,62,146,194,196,62,188,120,234,61,224,218,124,61,188,41,157,61,202,133,65,63,48,164,88,63,170,47,37,63,132,192,144,63,150,196,135,63,118,42,115,63,84,21,62,63,218,71,31,63,133,78,40,63,78,151,50,63,182,38,175,62,33,175,220,62,184,104,143,62,197,132,110,63,241,50,82,63,13,77,29,63,181,64,165,62,66,100,124,62,104,204,141,62,140,81,180,62,127,208,66,63,144,192,49,63,131,21,147,63,179,195,222,62,226,53,28,63,196,230,31,63,142,172,60,63,237,246,38,63,226,86,50,63,113,172,65,63,71,177,201,62,19,152,176,62,191,203,124,63,112,142,186,61,171,147,143,62,194,231,147,62,102,230,207,62,6,44,168,62,86,95,178,62,112,193,246,62,0,107,72,63,125,118,151,63,69,237,254,63,128,228,93,63,135,0,108,63,112,185,98,63,34,246,111,63,232,212,61,63,137,184,62,63,140,27,53,63,133,224,239,62,128,237,149,63,29,31,254,63,18,229,30,63,236,154,42,63,53,119,26,63,71,228,27,63,19,198,193,62,62,175,215,62,150,57,176,62,34,44,239,62,100,223,213,62,220,173,164,61,54,27,60,190,176,140,56,190,152,234,158,189,128,25,205,188,180,13,181,61,60,197,90,62,184,196,177,62,24,50,243,61,132,232,229,61,128,60,28,189,240,240,105,190,202,192,107,190,66,10,50,190,180,62,10,190,16,107,96,189,250,15,133,56,136,152,95,61,126,247,13,63,170,88,245,62,73,12,82,63,48,164,88,63,149,213,107,63,215,5,101,63,3,75,119,63,246,235,105,63,123,43,108,63,56,179,107,63,88,12,241,61,248,212,47,189,112,76,7,189,136,47,104,61,248,81,201,61,116,52,35,62,94,93,49,62,186,160,109,62,70,65,140,62,195,41,192,62,0,61,55,63,83,1,35,63,124,18,154,191,75,242,53,63,80,66,48,63,191,183,59,63,88,94,62,63,242,24,54,63,248,242,23,63,201,54,26,63,139,153,187,62,124,248,167,62,175,115,167,191,188,46,200,62,125,117,186,62,18,14,201,62,181,156,199,62,254,61,209,62,13,39,160,62,183,58,202,62,52,108,131,63,251,245,135,63,135,81,133,63,26,67,127,63,51,250,121,63,5,141,125,63,12,136,117,63,128,18,111,63,211,17,103,63,90,75,104,63,50,79,124,63,119,5,135,63,58,140,122,63,8,122,91,63,122,10,86,63,250,190,81,63,238,23,61,63,83,47,52,63,72,38,34,63,104,183,36,63,192,157,31,63,0,120,67,63,189,58,79,63,67,4,57,63,16,48,122,189,220,12,11,190,108,151,113,190,180,223,163,61,92,103,203,62,130,5,2,63,178,188,152,62,125,45,255,62,20,67,212,62,6,44,168,62,110,3,164,190,233,241,178,190,78,101,242,190,78,39,57,190,8,7,248,61,56,242,76,62,179,128,100,63,35,102,97,63,226,132,29,63,71,18,45,63,63,233,73,63,201,214,128,63,148,156,138,63,49,114,132,63,32,226,122,63,166,158,105,63,29,120,24,63,14,156,30,63,156,183,149,62,115,246,181,62,176,173,10,63,37,17,95,63,13,110,127,63,10,188,97,63,108,184,67,63,22,20,41,63,220,61,148,63,217,152,132,63,15,235,69,63,171,21,47,63,247,25,47,63,236,154,42,63,208,233,48,63,149,108,40,63,212,142,45,63,150,213,31,63,126,79,147,63,44,12,87,63,38,133,113,62,82,48,130,62,166,103,126,62,131,46,134,62,166,8,137,62,69,242,138,62,247,33,157,62,148,4,165,62,204,236,12,62,248,238,160,63,44,255,91,63,96,50,31,63,161,71,3,63,18,19,10,63,97,32,227,62,244,236,221,62,224,28,230,62,231,233,204,62,48,145,237,189,143,37,159,63,118,4,246,62,33,201,134,62,156,48,53,62,190,82,63,62,218,62,31,62,6,178,28,62,16,154,24,62,238,165,31,62,186,22,58,62,128,158,11,188,164,134,151,61,54,38,57,62,150,221,141,62,74,66,171,62,52,199,219,62,202,87,10,63,19,249,19,63,87,28,18,63,0,16,104,187,240,24,154,188,128,11,189,187,0,220,88,60,16,197,101,61,80,8,91,61,100,54,205,61,206,230,49,62,92,191,46,62,126,179,39,62,180,253,118,63,248,100,128,63,239,63,115,63,234,147,86,63,76,39,65,63,206,29,67,63,200,80,54,63,249,157,59,63,148,226,64,63,156,208,61,63,210,185,63,62,32,64,6,188,244,244,135,61,48,75,197,61,72,144,80,61,24,166,103,61,80,67,65,61,188,192,165,61,68,224,214,61,148,79,51,62,187,228,45,63,200,192,115,63,108,151,7,63,165,67,187,62,50,251,199,62,39,209,159,62,17,158,139,62,106,152,161,62,55,101,146,62,15,197,162,62,34,73,108,62,71,26,193,62,204,84,152,61,80,30,213,60,200,173,67,61,160,131,32,61,224,207,186,60,0,154,106,61,248,59,10,61,152,149,73,61,62,108,93,63,181,89,115,63,185,171,133,63,149,209,149,63,164,173,162,63,81,95,169,63,151,183,159,63,172,96,147,63,230,109,132,63,240,50,120,63,183,150,236,62,155,142,17,63,210,194,101,63,62,25,134,63,195,42,157,63,106,81,157,63,137,29,153,63,138,167,128,63,230,225,94,63,236,108,63,63,107,113,214,62,46,229,25,63,174,253,241,62,90,147,35,63,9,227,44,63,50,197,72,63,135,98,29,63,251,190,43,63,186,254,35,63,110,53,10,63,36,92,207,61,100,193,108,62,176,151,53,62,33,96,143,62,61,109,171,62,159,92,222,62,47,132,144,62,177,155,168,62,219,217,154,62,2,243,117,62,60,68,1,63,156,90,75,63,70,31,116,63,119,213,112,63,190,124,123,63,60,134,121,63,198,220,129,63,114,133,118,63,217,222,115,63,186,169,109,63,208,234,103,61,148,78,199,61,134,203,20,63,50,151,17,63,79,243,46,63,101,97,41,63,97,221,66,63,197,27,43,63,98,116,37,63,65,161,28,63,42,156,101,63,240,155,111,63,80,40,96,63,186,136,87,63,240,214,85,63,55,67,46,63,22,238,171,62,115,95,173,62,232,115,180,62,119,37,230,62,79,164,7,63,189,217,235,62,169,160,252,62,24,22,226,62,179,149,205,62,60,46,82,62,184,7,7,189,64,111,125,188,96,64,43,61,178,7,39,62,151,115,34,63,40,87,33,64,23,200,132,63,240,168,106,63,145,245,98,63,113,8,100,63,7,43,90,63,222,164,58,63,162,19,61,63,76,111,34,63,99,65,135,62,240,116,36,64,253,158,90,63,165,59,39,63,100,215,27,63,56,205,21,63,71,18,7,63,106,185,221,62,46,86,203,62,189,79,184,62,230,199,2,63,40,213,68,61,229,68,193,191,46,119,44,63,138,239,64,63,180,224,67,63,65,223,89,63,120,177,42,63,40,242,65,63,46,138,53,63,6,100,10,62,36,65,73,190,240,207,208,191,46,203,164,62,38,149,211,62,19,197,238,62,197,160,20,63,228,220,202,62,179,181,246,62,51,63,251,62,180,10,91,63,79,8,71,63,112,251,143,188,84,191,64,190,244,193,65,62,29,87,248,62,43,133,32,63,54,249,33,63,178,189,38,63,180,133,27,63,13,244,223,62,251,128,179,62,80,22,156,189,88,239,144,190,32,76,128,189,240,161,25,62,32,63,133,62,89,109,142,62,176,43,162,62,180,37,184,62,150,137,66,62,156,75,133,61,138,250,45,62,15,138,105,63,185,230,104,63,131,75,62,63,6,104,33,63,104,55,4,63,173,190,213,62,157,130,5,63,196,90,144,61,240,115,138,60,48,85,154,60,148,11,15,63,128,250,4,63,139,52,181,62,140,124,120,62,74,63,48,62,84,114,12,62,79,219,132,62,107,201,98,63,223,248,104,63,76,102,100,63,205,232,110,63,214,226,130,63,171,26,135,63,232,150,140,63,224,131,144,63,71,166,132,63,95,130,109,63,226,81,246,62,11,11,20,63,253,255,46,63,42,220,67,63,244,220,102,63,228,231,127,63,176,208,130,63,132,19,134,63,219,51,105,63,79,8,71,63,126,53,223,62,48,8,105,62,144,122,203,61,88,146,52,62,72,61,216,61,64,149,208,61,68,162,239,61,60,32,250,61,124,205,59,62,138,6,153,62,172,37,33,62,12,67,213,61,184,155,79,61,184,23,160,61,128,28,193,59,0,97,48,187,0,154,75,187,64,173,231,59,96,179,62,60,200,254,103,61,56,85,90,63,109,137,77,63,219,158,239,62,246,209,103,63,24,231,175,63,155,255,141,63,28,22,211,62,88,253,204,62,254,210,34,63,246,61,36,63,16,192,217,62,12,198,195,62,202,181,43,62,6,47,6,63,136,139,153,63,52,167,104,63,108,177,250,61,192,153,149,61,114,71,157,62,142,38,193,62,89,6,13,63,120,223,144,62,128,158,16,187,164,139,213,61,211,18,132,63,96,181,169,63,181,114,173,63,240,65,126,63,191,50,56,63,247,69,46,63,93,46,137,62,80,172,196,61,208,2,11,190,182,70,4,190,90,37,37,63,104,50,127,63,215,118,115,63,71,43,41,63,115,136,194,62,159,69,191,62,85,41,127,63,98,68,131,63,228,227,122,63,36,64,75,63,216,46,84,63,204,201,86,63,69,179,93,63,70,191,108,63,209,169,105,63,18,82,94,63,45,202,74,63,85,18,113,63,185,207,90,63,189,233,8,63,23,135,31,63,221,152,43,63,157,225,50,63,207,149,80,63,145,154,61,63,68,76,38,63,224,100,19,62,60,130,163,190,232,89,79,190,100,233,61,190,176,168,179,61,6,157,37,62,20,15,158,62,19,102,193,62,83,52,200,62,121,165,245,62,96,171,128,188,16,29,54,190,30,55,31,190,14,51,52,190,56,240,120,189,128,18,132,188,88,26,33,61,236,105,155,61,152,91,238,61,212,109,71,62,173,19,141,63,89,238,126,63,142,133,238,62,77,42,158,62,36,133,191,62,184,173,151,62,15,89,162,62,54,217,119,62,44,168,135,62,249,93,150,62,21,175,240,62,36,64,57,62,144,72,255,60,192,175,45,60,144,72,255,60,96,107,218,60,48,142,181,60,144,62,128,60,184,193,97,61,176,225,206,61,182,195,149,62,142,0,175,62,119,226,59,63,147,117,59,63,66,151,58,63,220,224,74,63,25,189,69,63,175,42,72,63,216,35,85,63,245,163,75,63,216,40,101,61,48,214,58,189,136,99,61,189,132,218,205,189,176,133,81,189,152,141,58,189,64,231,144,187,56,236,56,61,252,100,252,61,94,137,85,62,138,108,100,62,172,190,103,191,123,64,159,63,172,145,138,63,189,171,104,63,158,53,97,63,35,102,93,63,196,33,79,63,188,106,67,63,231,50,63,63,24,235,79,190,107,87,181,191,123,87,173,63,175,65,86,63,163,102,29,63,162,90,14,63,59,137,11,63,216,229,254,62,108,14,215,62,231,26,251,62,233,219,27,63,215,184,24,63,3,156,39,63,161,1,91,63,87,13,153,190,204,55,118,62,65,250,182,62,137,250,63,63,219,231,68,63,101,183,46,63,249,55,132,62,228,87,139,62,78,69,177,62,236,208,246,62,88,192,244,190,60,5,146,189,96,249,163,60,101,110,217,62,180,151,238,62,116,163,213,62,50,102,150,63,67,229,137,63,60,65,135,63,248,47,131,63,194,165,126,63,19,113,118,63,31,203,116,63,99,67,104,63,218,242,67,63,190,23,37,63,79,108,148,63,182,26,111,63,152,184,202,62,24,28,189,62,235,124,200,62,239,241,158,62,61,38,179,62,224,15,101,62,122,189,39,62,188,136,57,62,46,15,117,63,98,97,112,63,223,115,41,63,49,86,47,63,32,74,58,63,204,178,72,63,51,121,76,63,230,91,70,63,179,201,53,63,169,78,58,63,253,187,20,63,115,190,14,63,35,125,181,62,2,52,186,62,178,78,191,62,19,178,229,62,96,222,239,62,142,114,229,62,182,252,176,62,66,78,229,62,72,246,0,62,136,162,167,63,151,43,138,63,12,31,128,63,65,246,103,63,27,243,107,63,139,59,101,63,16,127,106,63,53,133,91,63,246,118,63,63,96,227,188,190,237,194,195,63,29,122,59,63,245,14,210,62,69,225,195,62,82,205,144,62,148,95,135,62,162,100,123,62,108,40,126,62,244,32,111,62,252,190,9,63,118,233,35,62,124,173,134,189,72,200,116,190,116,244,198,190,206,126,212,190,173,176,153,190,0,167,20,190,144,89,6,62,33,71,143,62,36,121,84,62,112,113,101,61,188,237,195,189,6,32,148,190,230,42,199,190,241,158,200,190,117,195,181,190,230,165,135,190,128,26,99,189,20,17,239,61,34,247,27,63,253,149,2,63,60,106,205,62,96,166,10,63,241,82,18,63,58,205,37,63,39,230,50,63,175,8,59,63,200,207,64,63,88,74,39,63,6,252,82,62,126,88,16,62,236,219,209,61,124,205,59,62,174,91,71,62,67,114,130,62,51,129,160,62,21,23,168,62,136,123,196,62,137,74,179,62,68,56,231,62,108,0,9,63,10,140,78,63,244,121,52,63,167,111,55,63,254,191,25,63,68,94,249,62,36,0,128,62,231,92,160,62,141,125,228,62,24,172,215,61,110,27,10,62,8,62,228,62,80,47,179,62,101,34,181,62,242,151,134,62,68,129,42,62,144,138,164,60,184,3,7,61,72,47,28,62,102,176,52,63,37,4,59,63,243,144,149,63,144,234,185,63,98,29,169,63,21,115,161,63,177,235,149,63,61,199,142,63,90,60,134,63,58,86,106,63,106,24,106,62,216,1,146,62,151,207,153,63,242,250,193,63,219,228,162,63,103,173,146,63,109,232,122,63,224,252,109,63,173,91,89,63,147,94,45,63,249,43,43,63,38,169,18,63,184,107,242,62,48,112,50,63,193,208,21,63,156,58,156,189,74,102,82,190,182,89,13,190,84,95,3,62,211,132,177,62,182,195,149,62,8,31,112,62,240,199,43,62,182,176,140,62,228,189,86,62,143,32,143,190,24,147,192,190,50,3,163,190,124,249,170,189,20,202,23,62,174,237,39,63,78,19,70,63,253,155,124,63,230,194,125,63,196,109,115,63,157,83,105,63,112,108,85,63,210,97,74,63,90,109,68,63,82,212,64,63,144,203,60,62,30,85,131,62,239,214,65,63,134,42,65,63,57,235,45,63,50,33,25,63,68,0,2,63,46,61,219,62,104,39,202,62,200,130,230,62,35,220,226,62,48,59,28,63,98,55,89,63,34,124,91,63,175,103,104,63,0,123,127,63,207,66,133,63,218,182,134,63,193,124,130,63,65,1,103,63,128,104,229,59,32,134,10,60,72,66,37,62,174,103,178,62,80,142,224,62,14,234,22,63,230,4,35,63,46,119,44,63,177,223,51,63,157,168,23,63,19,210,134,63,114,144,141,63,238,199,144,63,145,2,144,63,115,114,133,63,190,213,127,63,15,161,119,63,178,74,112,63,178,51,98,63,112,108,85,63,232,168,122,63,255,245,146,63,60,84,144,63,63,13,129,63,73,135,97,63,147,155,77,63,47,142,58,63,206,80,38,63,100,103,5,63,165,98,242,62,224,204,205,188,128,187,53,189,46,77,3,62,241,39,197,62,16,192,217,62,174,217,232,62,248,38,240,62,144,130,249,62,59,160,25,63,99,152,22,63,160,129,102,189,144,212,201,188,128,104,229,59,16,241,198,61,252,100,252,61,112,242,2,62,124,91,5,62,198,187,21,62,216,84,84,62,180,120,122,62,237,99,150,63,198,203,142,63,37,114,108,63,34,251,32,63,78,203,38,63,147,7,10,63,105,48,10,63,217,218,255,62,25,55,208,62,211,189,204,62,151,183,112,63,214,15,60,63,30,149,60,62,50,33,7,62,96,219,14,62,96,176,175,61,12,29,195,61,144,65,176,61,52,224,169,61,240,213,231,61,131,155,103,63,11,235,123,63,4,75,126,63,73,158,111,63,210,158,106,63,108,220,107,63,127,195,94,63,30,176,97,63,153,104,87,63,246,156,81,63,156,208,196,61,128,117,113,188,240,172,165,60,108,82,205,61,12,34,16,62,58,40,60,62,174,72,62,62,234,104,83,62,24,54,100,62,169,101,146,62,156,140,206,62,152,115,68,62,73,138,12,64,195,223,243,62,28,95,40,63,191,35,52,63,199,165,41,63,161,215,67,63,114,48,69,63,83,133,39,63,0,180,192,61,188,95,250,189,113,88,22,64,76,221,13,62,94,73,156,62,32,177,187,62,91,144,171,62,98,200,241,62,152,222,220,62,127,241,196,62,232,77,82,63,72,131,92,63,131,30,133,63,245,64,180,63,253,163,208,62,197,125,209,62,110,230,5,63,29,50,28,63,33,67,64,63,130,71,57,63,226,81,246,62,127,39,17,63,31,184,107,63,41,128,166,63,0,198,57,61,172,212,175,61,244,174,56,62,61,218,142,62,58,128,203,62,81,150,234,62,129,204,203,63,245,213,191,63,246,233,144,63,124,209,82,63,207,88,48,63,124,129,41,63,121,132,30,63,69,65,39,63,210,59,56,63,160,169,39,63,122,170,203,63,24,9,189,63,54,149,111,63,67,86,239,62,195,90,180,62,61,0,161,62,43,217,152,62,178,59,182,62,148,247,207,62,133,175,202,62,17,44,76,63,23,12,95,63,30,191,101,63,158,4,154,62,181,99,14,63,86,100,42,63,194,97,100,63,169,193,139,63,178,89,116,63,161,1,91,63,66,2,193,62,185,115,252,62,223,115,41,63,64,199,28,189,22,237,52,62,111,104,154,62,163,98,24,63,85,240,99,63,249,81,61,63,55,223,30,63,88,241,97,62,198,151,28,64,82,98,165,63,53,16,131,63,69,198,102,63,123,239,90,63,171,109,82,63,73,139,102,63,60,240,66,63,183,191,70,63,177,94,139,190,147,100,57,64,131,232,166,63,138,254,68,63,73,254,28,63,170,243,17,63,34,228,18,63,69,65,39,63,191,211,10,63,170,220,3,63,0,0,128,63,125,57,91,63,194,191,22,63,145,152,135,62,0,0,0,0,112,80,11,190,231,230,18,190,134,87,155,189,0,0,0,0,214,25,40,61,69,244,40,61,150,228,163,60,0,0,0,0,3,90,5,188,208,141,223,187,248,27,64,187,0,0,0,0,34,130,41,59,25,224,173,59,39,123,182,59,0,0,0,0,154,178,43,188,65,152,153,188,171,142,131,188,0,0,0,0,170,251,173,60,17,154,7,61,37,100,206,60,0,0,0,0,69,111,224,188,139,204,32,189,215,75,226,188,0,0,0,0,59,125,33,63,227,228,66,63,117,254,92,63,90,146,109,63,27,51,115,63,216,99,109,63,121,165,92,63,11,105,66,63,132,103,55,190,155,96,10,190,199,165,113,189,77,177,65,61,103,183,54,62,205,6,167,62,227,218,245,62,244,232,32,63,0,0,0,0,215,190,68,190,226,240,54,190,97,99,9,190,39,157,107,189,131,143,73,61,147,7,57,62,70,71,168,62,7,28,247,62,96,94,165,61,83,101,79,61,219,66,3,60,237,133,47,189,200,80,196,189,197,15,19,190,110,125,54,190,46,186,68,190,0,0,0,0,235,189,196,61,202,156,164,61,110,248,76,61,55,133,237,59,194,0,51,189,253,1,198,189,145,193,19,190,97,231,54,190,13,137,32,189,185,86,155,188,89,33,230,59,25,15,18,61,159,13,129,61,137,170,173,61,209,134,198,61,122,1,197,61,0,0,0,0,10,57,83,189,155,113,31,189,92,63,152,188,57,198,244,59,104,240,19,61,94,225,129,61,114,61,174,61,109,185,198,61,143,123,146,60,182,155,159,59,231,3,49,188,4,36,222,188,220,156,42,189,154,184,84,189,15,124,100,189,142,197,83,189,0,0,0,0,18,205,218,60,96,4,145,60,139,236,151,59,7,79,53,188,46,55,224,188,48,115,43,189,149,51,85,189,252,123,100,189,65,252,226,187,240,105,87,58,221,103,31,60,128,42,152,60,12,158,212,60,113,172,249,60,245,233,253,60,15,172,219,60,0,0,0,0,245,174,77,188,6,100,223,187,95,35,123,58,155,202,33,60,94,66,153,60,83,108,213,60,78,5,250,60,127,173,253,60,76,255,250,58,116,122,19,187,136,195,224,187,158,67,56,188,195,46,112,188,110,23,134,188,50,97,129,188,209,220,78,188,0,0,0,0,213,9,167,59,0,24,243,58,158,47,24,187,81,47,227,187,100,81,57,188,82,225,112,188,114,44,134,188,122,34,129,188,193,215,243,184,100,37,253,58,135,197,133,59,23,61,197,59,33,20,242,59,141,151,0,60,85,249,233,59,181,109,168,59,0,0,0,0,148,227,234,186,68,194,179,184,72,211,0,59,89,223,134,59,77,34,198,59,236,148,242,59,229,144,0,60,247,66,233,59,144,247,214,185,104,99,201,186,62,13,39,187,66,129,89,187,12,197,115,187,16,170,110,187,90,100,69,187,180,248,237,186,0,0,0,0,168,19,53,58,174,139,224,185,112,172,203,186,194,1,40,187,2,35,90,187,160,243,115,187,12,76,110,187,22,109,68,187,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,12,0,13,0,14,0,60,0,61,0,62,0,252,0,253,0,254,0,252,3,253,3,254,3,252,15,253,15,254,15,252,63,253,63,254,63,255,63,0,0,0,0,2,2,2,4,4,4,6,6,6,8,8,8,10,10,10,12,12,12,14,14,14,14,0,0,0,0,0,0,0,0,0,0,73,255,207,53,73,255,207,53,209,255,31,55,10,0,138,55,13,0,31,56,12,128,79,56,251,191,167,56,249,255,221,56,255,127,13,57,1,160,42,57,2,224,78,57,254,223,115,57,255,15,140,57,0,224,162,57,1,48,188,57,1,96,216,57,0,64,240,57,0,240,4,58,0,248,22,58,255,183,44,58,1,8,70,58,255,127,97,58,0,24,128,58,0,20,145,58,0,52,165,58,0,12,182,58,0,88,202,58,0,212,221,58,0,200,248,58,0,92,11,59,0,224,26,59,0,98,40,59,0,236,58,59,0,10,81,59,0,28,99,59,0,74,120,59,0,151,136,59,0,0,151,59,0,187,165,59,0,76,182,59,0,145,202,59,0,82,223,59,0,85,242,59,0,13,6,60,128,102,21,60,0,105,40,60,0,122,68,60,0,205,91,60,0,172,125,60,64,96,142,60,128,154,163,60,0,252,187,60,128,178,219,60,96,219,2,61,64,0,33,61,128,118,60,61,192,105,86,61,176,164,130,61,16,39,173,61,224,101,226,61,64,135,25,62,48,62,99,62,18,0,158,55,233,255,208,55,3,0,247,55,13,128,25,56,1,128,49,56,250,255,66,56,5,0,81,56,1,128,92,56,2,0,103,56,6,0,113,56,244,255,121,56,1,0,129,56,250,255,132,56,5,64,136,56,2,128,139,56,1,128,142,56,0,64,145,56,1,192,147,56,2,64,150,56,3,192,152,56,7,192,154,56,253,191,156,56,1,128,158,56,250,255,159,56,0,128,161,56,5,64,163,56,253,191,164,56,3,64,166,56,251,191,167,56,2,64,169,56,250,191,170,56,255,127,172,56,5,0,174,56,252,191,175,56,2,64,177,56,5,64,179,56,250,127,181,56,252,191,183,56,252,127,186,56,7,192,189,56,0,192,193,56,255,63,199,56,0,64,207,56,250,127,216,56,3,64,228,56,250,191,240,56,253,127,0,57,1,96,10,57,3,32,22,57,254,127,36,57,1,224,54,57,255,191,76,57,0,96,103,57,1,240,132,57,0,128,155,57,0,160,181,57,255,111,215,57,0,56,0,58,255,231,26,58,0,88,62,58,0,120,104,58,0,136,140,58,0,108,166,58,0,168,197,58,0,224,228,58,0,240,2,59,0,134,16,59,0,48,27,59,0,250,36,59,0,10,46,59,0,6,55,59,0,202,63,59,0,138,71,59,0,116,80,59,0,170,88,59,0,224,96,59,0,90,104,59,0,218,111,59,0,252,118,59,0,212,125,59,0,81,130,59,0,96,133,59,0,132,136,59,0,120,139,59,0,55,142,59,0,255,144,59,0,186,147,59,0,104,150,59,0,1,153,59,0,108,155,59,0,217,157,59,0,45,160,59,0,127,162,59,0,171,164,59,0,186,166,59,0,191,168,59,0,170,170,59,0,152,172,59,0,122,174,59,0,75,176,59,0,23,178,59,0,197,179,59,0,110,181,59,0,13,183,59,0,170,184,59,0,36,186,59,0,155,187,59,0,23,189,59,0,107,190,59,0,210,191,59,0,57,193,59,0,136,194,59,0,180,195,59,0,232,196,59,0,11,198,59,0,54,199,59,0,104,200,59,0,122,201,59,0,150,202,59,0,170,203,59,0,203,204,59,0,218,205,59,0,22,207,59,0,62,208,59,0,122,209,59,0,209,210,59,0,61,212,59,0,161,213,59,0,248,214,59,0,74,216,59,0,157,217,59,0,250,218,59,0,80,220,59,0,177,221,59,0,5,223,59,0,90,224,59,0,169,225,59,0,220,226,59,0,25,228,59,0,82,229,59,0,148,230,59,0,214,231,59,0,14,233,59,0,104,234,59,0,216,235,59,0,70,237,59,0,180,238,59,0,85,240,59,0,239,241,59,0,170,243,59,0,93,245,59,0,40,247,59,0,16,249,59,0,224,250,59,0,193,252,59,0,142,254,59,0,59,0,60,128,50,1,60,0,60,2,60,0,90,3,60,128,109,4,60,128,147,5,60,128,178,6,60,128,201,7,60,0,211,8,60,128,214,9,60,128,229,10,60,128,2,12,60,128,21,13,60,0,47,14,60,128,93,15,60,128,147,16,60,128,210,17,60,128,5,19,60,128,38,20,60,0,80,21,60,128,110,22,60,0,130,23,60,0,164,24,60,128,221,25,60,0,31,27,60,0,89,28,60,0,147,29,60,0,208,30,60,128,4,32,60,0,55,33,60,128,121,34,60,128,192,35,60,128,17,37,60,128,123,38,60,128,251,39,60,128,144,41,60,0,27,43,60,128,196,44,60,128,160,46,60,128,132,48,60,0,142,50,60,0,117,52,60,128,98,54,60,128,70,56,60,128,21,58,60,0,17,60,60,0,26,62,60,128,60,64,60,128,112,66,60,0,207,68,60,128,50,71,60,128,138,73,60,0,51,76,60,0,25,79,60,128,24,82,60,0,57,85,60,128,114,88,60,0,5,92,60,0,217,95,60,0,152,99,60,128,156,103,60,128,240,107,60,0,55,112,60,0,172,116,60,0,66,121,60,0,9,126,60,0,190,129,60,0,196,132,60,64,247,135,60,64,52,139,60,128,205,142,60,0,220,146,60,192,25,151,60,0,66,156,60,0,150,161,60,128,72,167,60,64,12,174,60,192,120,181,60,64,178,189,60,128,23,199,60,128,10,210,60,128,193,222,60,0,62,237,60,0,3,254,60,64,175,8,61,192,3,21,61,64,107,36,61,160,220,53,61,160,13,76,61,224,110,102,61,240,21,131,61,144,18,150,61,48,86,171,61,208,54,197,61,32,227,229,61,160,202,8,62,120,194,36,62,88,201,75,62,220,246,133,62,68,3,201,62,108,14,88,191,32,69,29,191,170,211,28,190,155,110,204,189,29,137,164,62,157,104,193,62,89,68,55,63,183,144,162,63,181,252,215,191,160,211,155,191,95,145,250,190,113,190,212,190,237,196,0,62,254,106,71,62,150,157,22,63,241,112,153,63,51,233,173,191,135,234,127,191,28,246,192,190,40,187,159,190,60,167,64,62,75,47,129,62,137,201,32,63,209,48,156,63,10,247,60,191,121,241,7,191,154,43,202,189,182,123,73,189,215,13,182,62,95,251,209,62,24,52,61,63,97,62,164,63,244,188,127,190,72,169,238,189,60,167,64,62,35,244,102,62,224,5,12,63,208,155,23,63,11,150,95,63,3,128,174,63,110,245,177,191,120,197,130,191,23,185,199,190,134,91,165,190,59,253,56,62,2,252,123,62,9,142,31,63,90,227,155,63,75,114,26,191,59,76,214,190,75,103,207,188,40,69,178,60,33,59,206,62,123,58,233,62,198,128,69,63,8,180,166,63,131,133,141,191,145,2,81,191,144,47,141,190,0,217,92,190,227,200,124,62,250,206,157,62,247,145,42,63,211,244,158,63,34,33,10,191,106,6,187,190,111,61,51,60,129,15,99,61,235,103,218,62,176,119,244,62,140,186,73,63,97,234,167,63,87,5,117,191,193,4,52,191,200,64,85,190,80,162,27,190,75,42,147,62,76,94,177,62,24,114,49,63,172,230,160,63,155,225,119,190,158,230,224,189,31,187,69,62,141,168,108,62,10,233,12,63,15,153,24,63,5,58,96,63,163,186,174,63,72,15,40,63,191,99,54,63,19,98,91,63,151,112,96,63,133,67,135,63,65,198,138,63,233,243,161,63,118,130,207,63,6,89,197,191,241,220,143,191,200,230,226,190,209,139,169,192,127,160,26,62,108,146,95,62,116,180,26,63,69,142,154,63,201,50,3,191,228,90,175,190,46,64,218,60,235,52,146,61,183,185,223,62,185,214,249,62,169,149,75,63,17,128,168,63,221,0,99,191,184,238,37,191,178,137,50,190,136,147,245,189,63,47,158,62,108,104,187,62,139,33,53,63,170,234,161,63,245,37,193,189,37,64,170,60,4,21,149,62,127,99,166,62,219,186,30,63,33,132,41,63,22,56,109,63,37,184,178,63,205,204,76,61,41,92,15,62,10,215,35,62,205,204,76,61,123,20,46,62,0,0,128,62,41,92,143,61,61,10,87,62,143,194,245,61,174,71,97,62,31,133,107,62,184,30,5,62,143,194,117,62,10,215,163,62,41,92,15,62,225,122,148,62,82,184,158,62,133,235,209,62,246,40,220,62,10,215,163,62,246,40,220,62,92,143,2,63,123,20,174,62,143,194,245,62,92,143,194,62,215,163,240,62,72,225,250,62,92,143,194,62,72,225,250,62,133,235,17,63,205,204,204,62,113,61,10,63,72,225,250,62,61,10,23,63,246,40,28,63,0,0,0,63,246,40,28,63,215,163,48,63,184,30,5,63,195,245,40,63,41,92,15,63,102,102,38,63,31,133,43,63,41,92,15,63,31,133,43,63,0,0,64,63,225,122,20,63,236,81,56,63,102,102,38,63,164,112,61,63,92,143,66,63,102,102,38,63,92,143,66,63,61,10,87,63,31,133,43,63,41,92,79,63,143,194,53,63,205,204,76,63,133,235,81,63,143,194,53,63,133,235,81,63,102,102,102,63,72,225,58,63,82,184,94,63,41,92,79,63,102,102,102,63,31,133,107,63,41,92,79,63,123,20,110,63,174,71,129,63,225,122,84,63,236,81,120,63,82,184,94,63,143,194,117,63,72,225,122,63,82,184,94,63,72,225,122,63,20,174,135,63,10,215,99,63,10,215,131,63,31,133,107,63,92,143,130,63,184,30,133,63,123,20,110,63,184,30,133,63,41,92,143,63,51,51,115,63,31,133,139,63,123,20,110,63,92,143,130,63,184,30,133,63,123,20,110,63,184,30,133,63,41,92,143,63,51,51,115,63,31,133,139,63,215,163,112,63,184,30,133,63,102,102,134,63,205,204,204,61,20,174,135,63,133,235,145,63,143,194,117,63,123,20,142,63,72,225,122,63,113,61,138,63,205,204,140,63,164,112,125,63,205,204,140,63,61,10,151,63,174,71,129,63,51,51,147,63,20,174,135,63,51,51,147,63,143,194,149,63,20,174,135,63,143,194,149,63,0,0,160,63,113,61,138,63,246,40,156,63,225,122,148,63,0,0,160,63,92,143,162,63,225,122,148,63,10,215,163,63,123,20,174,63,61,10,151,63,195,245,168,63,217,63,139,60,39,222,143,60,172,163,148,60,181,145,153,60,153,169,158,60,187,236,163,60,140,92,169,60,134,250,174,60,49,200,180,60,35,199,186,60,252,248,192,60,111,95,199,60,57,252,205,60,40,209,212,60,24,224,219,60,246,42,227,60,191,179,234,60,129,124,242,60,90,135,250,60,62,107,1,61,21,182,5,61,94,37,10,61,78,186,14,61,37,118,19,61,46,90,24,61,189,103,29,61,50,160,34,61,252,4,40,61,145,151,45,61,118,89,51,61,61,76,57,61,134,113,63,61,253,202,69,61,93,90,76,61,112,33,83,61,15,34,90,61,34,94,97,61,162,215,104,61,153,144,112,61,34,139,120,61,180,100,128,61,214,166,132,61,32,13,137,61,197,152,141,61,2,75,146,61,30,37,151,61,109,40,156,61,76,86,161,61,36,176,166,61,107,55,172,61,163,237,177,61,89,212,183,61,42,237,189,61,192,57,196,61,209,187,202,61,36,117,209,61,143,103,216,61,244,148,223,61,75,255,230,61,152,168,238,61,241,146,246,61,127,192,254,61,190,153,3,62,27,247,7,62,135,121,12,62,61,34,17,62,130,242,21,62,166,235,26,62,3,15,32,62,0,94,37,62,16,218,42,62,177,132,48,62,111,95,54,62,226,107,60,62,176,171,66,62,142,32,73,62,61,204,79,62,144,176,86,62,102,207,93,62,178,42,101,62,116,196,108,62,190,158,116,62,181,187,124,62,199,142,130,62,74,227,134,62,144,92,139,62,211,251,143,62,84,194,148,62,97,177,153,62,81,202,158,62,138,14,164,62,122,127,169,62,156,30,175,62,122,237,180,62,168,237,186,62,200,32,193,62,141,136,199,62,180,38,206,62,12,253,212,62,112,13,220,62,208,89,227,62,38,228,234,62,131,174,242,62,4,187,250,62,238,133,1,63,168,209,5,63,219,65,10,63,190,215,14,63,143,148,19,63,153,121,24,63,51,136,29,63,188,193,34,63,162,39,40,63,93,187,45,63,115,126,51,63,116,114,57,63,2,153,63,63,200,243,69,63,130,132,76,63,251,76,83,63,11,79,90,63,156,140,97,63,167,7,105,63,54,194,112,63,100,190,120,63,47,127,128,63,50,194,132,63,100,41,137,63,84,82,95,94,125,131,98,102,94,93,104,104,127,113,87,77,125,114,109,94,94,91,106,105,168,125,163,120,128,100,119,99,108,97,108,106,86,85,128,125,79,73,103,102,123,123,116,117,84,76,135,131,133,133,129,130,125,123,115,114,94,97,79,81,115,115,94,93,128,127,126,125,124,111,105,114,104,117,109,110,124,125,118,117,107,110,106,110,93,93,149,148,118,119,111,110,147,157,143,156,134,136,118,121,106,107,105,105,114,83,114,46,106,53,110,83,107,94,105,103,92,90,109,106,172,160,114,110,109,110,110,109,90,98,98,109,102,98,97,92,100,100,101,102,123,117,124,98,82,80,117,115,112,110,109,108,107,111,100,115,105,120,104,105,83,82,95,96,109,120,72,71,97,104,69,74,99,102,118,117,137,133,142,135,105,110,121,121,125,122,114,112,151,186,115,132,103,111,100,104,99,101,104,105,18,38,56,65,76,83,85,91,101,103,108,110,144,135,126,121,115,113,79,80,118,117,117,117,117,124,115,115,126,113,130,116,112,106,108,105,77,76,76,80,109,109,125,129,130,133,116,118,96,86,109,99,102,69,84,69,107,103,114,113,78,118,82,114,84,129,69,112,78,98,96,103,89,137,96,111,105,97,93,93,101,105,105,105,141,123,102,93,91,79,87,81,102,99,109,108,94,92,124,123,130,134,100,107,71,75,92,91,94,104,107,83,106,101,113,114,122,122,114,114,118,124,103,106,95,116,90,93,107,104,109,107,116,118,76,72,88,88,132,132,140,141,116,116,90,81,111,95,139,97,123,96,112,100,110,108,112,116,133,140,112,120,80,85,55,55,85,84,125,94,111,104,116,103,112,86,93,84,99,98,180,179,197,197,169,163,149,146,130,124,116,115,76,47,36,11,43,28,66,53,82,80,102,99,119,123,176,201,113,120,112,111,103,105,106,110,145,114,112,89,120,93,123,104,131,123,113,111,97,109,82,106,75,104,103,115,120,124,111,114,114,111,113,105,34,33,63,63,105,106,122,122,51,41,96,92,125,125,118,118], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+122880);
/* memory initializer */ allocate([118,119,113,113,111,180,108,178,107,171,110,160,105,136,102,117,76,79,90,92,80,88,88,93,123,124,122,122,131,128,123,122,151,158,108,107,129,128,119,119,97,99,114,120,121,125,151,157,82,89,95,96,128,94,130,95,149,113,149,120,127,115,113,109,167,171,83,80,84,79,106,106,112,110,107,108,130,139,81,88,107,106,112,112,119,118,114,112,108,105,100,98,120,116,122,117,38,37,72,73,118,125,110,120,114,126,135,142,139,142,118,119,119,119,156,145,78,75,94,94,112,110,113,113,101,108,98,104,103,109,117,118,167,167,132,132,116,108,118,111,149,136,85,74,95,92,113,112,74,69,104,107,96,100,117,121,103,105,103,103,110,106,111,101,82,72,96,92,132,130,120,121,116,113,138,139,104,103,131,131,68,69,92,92,97,97,146,151,122,132,97,95,117,116,115,116,139,134,110,110,124,129,100,110,86,91,100,102,116,136,88,90,137,139,103,114,114,117,111,110,82,83,104,102,97,99,97,97,58,56,84,84,83,122,76,105,112,126,120,134,112,120,108,110,114,128,73,90,72,76,98,100,95,96,101,102,101,108,118,126,94,102,81,83,138,140,131,130,88,100,112,124,105,106,122,123,121,121,114,114,76,108,73,83,93,95,110,111,98,99,103,103,105,112,98,108,114,95,117,98,120,116,116,115,231,238,150,146,124,126,115,122,117,121,112,112,74,73,72,74,60,61,62,61,85,85,101,101,67,69,50,51,83,83,110,110,118,113,112,111,199,124,184,115,176,117,165,120,138,115,116,114,52,116,36,107,49,99,72,106,91,107,104,105,140,138,141,135,154,147,166,159,139,136,116,115,130,119,180,157,183,149,136,121,119,114,111,110,104,129,113,154,111,148,108,132,105,117,106,111,114,35,99,65,113,94,110,98,111,107,107,106,106,110,128,135,162,175,143,155,115,116,109,109,168,155,112,109,125,125,126,122,126,124,111,112,128,96,160,77,151,77,121,80,114,94,107,103,97,104,101,116,56,79,74,83,92,95,104,106,63,68,76,77,110,107,96,90,85,83,97,96,116,110,46,42,103,100,122,120,102,101,104,104,106,101,109,98,96,61,67,35,72,61,96,93,88,80,81,76,113,110,144,143,88,89,93,94,95,96,100,101,136,132,166,160,148,147,115,116,80,78,130,129,120,108,91,85,95,91,104,102,151,147,106,109,110,110,64,69,68,67,96,96,90,166,97,128,99,120,104,121,109,118,105,109,122,138,110,143,75,97,83,94,89,94,102,103,136,142,103,110,83,89,99,101,138,138,120,122,168,88,105,90,109,107,110,111,106,105,103,102,68,72,102,104,92,102,65,75,89,94,106,106,83,74,93,85,73,66,106,102,100,92,99,97,93,99,101,96,116,112,125,120,88,88,96,96,44,98,93,115,104,116,103,107,112,113,107,107,93,83,105,99,93,84,127,125,141,143,117,118,106,103,126,121,137,123,123,114,147,142,127,123,103,110,89,91,121,124,66,71,68,69,96,97,114,105,68,65,69,67,96,94,131,130,123,121,111,104,130,121,95,95,72,74,88,88,105,104,135,124,110,98,114,111,159,158,111,113,104,106,103,108,94,107,55,57,115,118,121,122,111,111,97,99,106,111,119,126,59,62,111,112,124,125,86,93,100,110,118,145,113,132,120,125,112,112,101,115,78,149,81,114,111,121,108,112,107,108,104,104,94,96,84,83,135,132,71,69,88,86,100,98,62,60,81,80,90,89,63,66,89,90,123,116,108,99,90,86,91,92,65,65,88,88,84,79,115,109,123,111,99,99,134,136,121,123,127,137,84,88,104,107,128,130,74,69,89,89,118,112,143,132,141,131,113,113,99,102,104,105,117,115,100,99,131,126,90,88,145,144,128,127,112,114,131,133,85,84,118,119,151,152,117,117,110,105,162,140,116,107,140,134,124,122,113,113,107,110,124,133,98,103,99,107,109,113,112,112,115,105,82,77,125,122,133,132,118,120,113,113,101,88,84,80,97,99,91,91,94,94,101,100,121,86,139,108,106,93,103,99,112,108,108,107,113,83,105,102,125,125,114,115,110,112,108,109,93,112,113,121,125,131,101,101,107,109,111,111,98,102,117,126,80,84,107,109,83,84,96,97,132,136,112,118,94,93,121,118,99,98,102,103,122,127,128,133,118,104,102,88,100,94,104,102,115,116,102,105,140,142,135,130,90,88,100,101,94,86,112,112,89,121,92,101,109,108,110,112,99,93,129,114,109,99,131,119,102,97,103,103,103,116,124,101,115,95,105,101,94,91,100,100,113,90,94,86,92,92,117,111,106,103,106,105,115,99,110,91,107,104,81,90,108,113,112,113,113,114,93,101,101,102,101,126,93,103,104,105,117,106,124,107,104,119,108,133,104,111,104,106,98,98,119,121,109,112,128,135,115,121,159,113,113,106,127,114,101,102,105,111,161,162,137,138,161,159,152,150,150,148,128,79,131,102,142,120,133,119,130,117,121,115,142,133,186,155,179,144,169,135,107,103,106,106,122,122,111,112,112,115,127,123,118,115,128,125,123,119,115,109,124,130,117,126,121,133,84,144,99,114,122,125,123,131,124,135,176,200,158,176,68,74,86,87,117,115,119,116,135,128,115,116,102,104,119,123,133,148,102,109,71,121,106,117,107,127,106,122,100,110,117,115,129,128,87,84,116,116,151,157,116,128,110,117,119,134,100,114,120,129,142,141,146,151,94,91,114,114,118,118,114,112,112,109,115,112,123,123,147,148,110,164,106,152,110,158,106,151,105,135,85,51,71,27,71,34,74,45,85,53,145,134,140,130,136,134,118,122,118,126,117,84,121,81,106,80,109,106,121,127,95,94,112,110,90,94,109,107,114,109,117,118,118,123,107,107,86,93,29,31,125,112,104,60,121,111,127,116,133,130,118,117,148,145,122,126,124,127,90,91,113,110,119,118,152,147,115,112,132,131,129,140,98,112,73,85,109,115,122,126,123,122,122,122,126,125,137,140,203,210,164,176,114,114,125,122,119,112,125,120,124,122,118,115,95,96,141,144,132,131,127,130,132,134,116,114,122,123,137,134,111,111,112,116,106,118,77,101,104,115,111,111,125,126,118,121,113,115,113,113,171,170,202,199,221,206,199,184,177,167,73,90,61,93,43,74,51,71,51,72,130,130,140,137,134,132,164,160,118,111,123,136,133,154,130,158,106,110,110,114,97,97,91,94,70,69,125,123,141,140,119,100,116,77,111,67,105,52,95,34,100,122,90,124,68,120,43,117,50,112,130,129,192,188,123,118,124,117,121,115,122,111,129,111,157,85,125,109,125,119,143,152,119,128,114,116,129,136,148,157,119,117,115,115,150,148,163,154,109,102,120,126,73,119,106,121,102,122,96,113,84,83,117,115,122,117,154,143,159,142,118,122,114,117,115,122,114,130,99,156,123,120,122,116,100,81,99,91,121,112,139,131,164,142,132,119,145,133,157,141,112,109,118,116,142,134,108,110,96,99,111,110,113,112,111,104,98,94,131,131,115,114,121,118,120,115,173,148,123,117,121,124,122,124,140,146,78,82,96,93,86,90,124,125,121,123,105,106,134,135,107,109,132,141,100,95,113,114,102,105,113,130,98,145,116,115,124,117,115,105,120,123,89,87,109,108,102,101,117,117,113,122,132,138,77,116,86,99,118,126,123,120,117,111,124,119,129,118,63,58,141,135,108,106,109,111,108,110,135,138,117,114,134,127,139,129,138,130,126,122,121,118,124,121,133,130,98,85,130,123,147,129,118,112,148,130,136,123,148,131,113,112,123,118,123,115,147,95,117,110,118,119,112,113,112,113,119,119,120,120,158,133,198,145,188,129,197,137,195,133,132,140,140,139,158,156,223,217,233,233,48,56,34,37,82,84,102,102,108,110,120,142,136,169,146,195,136,186,140,182,196,186,158,155,142,134,132,125,120,119,97,105,72,75,82,85,81,84,107,109,67,121,43,119,69,124,87,129,88,128,53,57,93,98,91,94,93,98,104,104,124,123,133,133,182,181,119,121,114,116,128,105,134,112,131,72,119,59,111,84,132,142,145,180,124,132,131,143,122,134,88,85,103,103,136,140,131,143,114,132,116,57,113,57,121,76,126,80,118,86,127,112,127,97,131,100,149,91,163,86,122,119,128,121,128,116,142,127,173,139,162,116,166,107,149,103,152,107,141,108,114,113,118,116,56,43,90,90,105,105,132,134,110,107,106,105,82,84,84,84,102,106,79,89,99,99,127,129,114,118,139,157,116,123,116,123,87,89,110,113,119,126,97,97,155,163,142,153,143,146,117,114,66,67,125,126,127,128,114,113,111,114,127,133,123,132,143,162,133,148,105,108,114,114,110,109,57,48,109,106,113,130,104,131,88,139,102,169,100,172,129,114,150,97,114,112,117,119,109,116,92,107,96,116,90,125,101,122,125,140,125,133,122,129,136,153,125,135,131,139,84,71,129,123,135,120,114,103,112,101,108,121,115,156,106,123,116,131,127,139,137,147,109,117,119,126,135,144,117,119,120,127,76,105,111,116,120,125,141,138,107,104,162,155,135,130,127,123,127,121,102,104,84,87,112,115,97,102,78,82,119,118,120,123,91,105,114,119,119,126,130,126,134,126,158,134,133,99,116,100,125,122,145,143,126,117,98,96,121,120,152,148,131,126,130,129,126,119,87,87,131,131,139,137,101,102,104,105,86,83,92,89,111,105,121,115,137,124,96,84,100,96,122,119,107,108,93,96,79,82,128,123,108,106,123,120,150,150,143,140,121,120,97,99,79,80,116,116,88,90,128,131,101,97,140,140,117,116,116,118,137,135,100,91,115,112,134,121,107,99,120,122,122,125,124,126,136,141,89,95,103,119,103,116,122,139,125,137,152,170,121,122,124,124,98,97,137,140,96,92,115,113,136,136,128,132,122,124,151,158,100,107,121,131,131,158,119,130,113,114,114,109,148,130,103,95,127,116,137,120,103,108,97,97,133,128,113,109,136,128,125,124,118,118,122,121,101,99,157,152,138,134,124,115,113,101,123,112,124,110,116,113,128,121,119,110,124,113,128,67,114,118,114,123,109,121,102,123,56,116,117,111,112,99,124,114,112,79,114,88,112,113,115,117,126,127,130,132,123,122,111,104,111,102,112,102,129,118,129,115,123,124,130,133,114,117,125,127,112,117,124,125,119,120,117,116,105,104,110,110,125,124,118,116,124,123,124,121,133,132,111,111,124,124,120,119,116,116,134,130,114,116,112,113,109,111,116,118,95,98,147,145,193,168,188,156,141,145,141,139,148,149,148,149,153,157,144,144,152,152,141,145,153,143,243,134,151,133,166,135,150,149,135,132,32,39,110,111,109,114,126,127,147,146,177,169,162,156,210,187,141,147,95,150,127,155,108,133,139,148,138,138,140,140,147,146,134,130,136,134,147,146,142,150,62,174,126,151,122,156,154,156,179,184,115,107,105,99,127,124,146,131,140,44,132,125,156,146,153,153,136,137,145,144,141,139,158,152,138,132,145,145,147,145,146,141,144,140,110,97,140,141,143,142,130,123,127,117,126,120,147,146,161,155,169,135,122,117,166,155,144,144,142,142,125,122,137,128,194,172,127,85,148,143,153,141,147,147,140,143,118,140,0,69,51,60,111,123,137,135,146,146,164,165,207,214,145,143,149,147,178,168,197,170,134,154,148,159,115,140,103,118,13,38,139,138,135,138,140,141,144,144,140,140,150,150,156,157,164,171,143,143,140,142,118,120,172,172,160,163,146,147,150,151,176,176,230,237,153,153,168,156,173,149,164,148,162,146,178,158,147,145,143,145,111,126,111,130,89,118,153,158,122,120,142,125,124,105,148,138,145,144,156,151,193,154,146,147,119,135,142,141,145,145,152,147,142,141,146,146,139,138,154,154,148,150,147,149,144,145,134,134,141,140,135,134,145,147,160,163,144,145,149,146,115,67,127,119,141,135,145,141,130,124,143,144,151,165,141,144,154,152,160,136,115,82,64,71,64,65,143,143,151,149,240,251,165,173,173,179,148,134,156,55,160,105,133,91,129,96,149,149,145,144,160,154,171,159,140,142,154,163,178,244,147,140,153,150,137,121,145,144,145,146,138,139,149,152,189,198,148,148,156,158,168,182,165,182,172,201,143,142,99,92,152,152,143,143,127,127,165,148,173,124,113,122,134,142,127,142,124,126,137,137,131,132,144,142,141,138,172,176,138,111,152,136,167,154,156,137,140,150,78,145,158,157,161,154,155,147,153,164,156,191,129,109,153,146,153,141,138,137,141,138,115,94,144,141,155,147,144,142,144,137,168,113,141,134,145,137,146,144,150,148,140,155,103,178,137,149,145,147,148,153,175,201,138,146,110,108,143,146,124,134,124,127,164,158,127,135,145,146,150,150,145,147,95,80,150,151,149,149,162,162,144,152,170,169,145,154,145,149,143,146,142,145,152,146,160,98,141,141,153,153,140,137,131,131,145,146,133,132,127,124,158,150,173,164,178,167,146,146,154,155,117,127,143,147,147,156,142,143,144,145,146,152,170,199,151,165,146,147,139,140,147,149,132,134,147,149,138,139,142,143,162,188,145,149,160,164,150,150,139,139,143,142,146,146,137,138,142,142,141,140,152,153,164,171,110,112,139,139,143,143,138,138,142,142,143,143,137,140,142,142,145,141,149,141,182,135,146,146,150,150,144,145,150,151,135,137,137,145,51,62,68,54,69,57,62,41,137,139,139,144,135,150,225,232,208,197,136,135,141,143,145,150,160,169,213,247,142,137,72,54,110,107,105,107,127,130,145,143,169,155,219,174,195,164,183,157,155,157,239,232,169,164,170,172,156,159,142,143,136,144,59,100,139,142,130,138,147,146,150,161,128,235,143,155,146,167,154,149,128,151,42,149,55,136,59,127,128,126,74,92,143,153,140,150,166,176,146,152,150,145,140,100,140,105,124,59,195,191,146,148,144,136,136,133,129,122,133,148,40,147,102,140,123,148,118,136,143,143,150,148,184,153,160,147,166,149,58,68,127,135,141,145,143,147,150,151,140,143,137,137,120,114,71,65,125,123,153,148,215,159,136,135,150,146,150,150,148,138,166,94,150,145,145,139,147,145,146,147,150,139,171,63,158,142,153,133,147,148,143,143,76,72,155,159,164,176,149,149,173,195,145,165,138,144,150,167,180,169,146,151,146,166,147,166,149,171,157,156,168,166,147,149,121,122,116,124,145,145,147,148,172,189,168,180,144,146,139,145,141,150,115,172,141,146,143,148,145,145,142,143,145,147,138,143,58,73,141,142,146,145,163,149,218,161,147,132,152,147,146,147,140,150,141,152,89,150,78,134,135,137,139,142,140,137,137,130,144,144,152,151,145,140,181,170,191,168,164,166,136,148,112,124,139,144,146,149,142,151,113,182,137,150,143,156,138,147,154,156,108,102,118,119,133,139,113,111,145,144,150,147,175,151,104,106,116,114,143,144,151,157,151,191,135,113,138,123,146,146,155,157,106,145,132,127,140,125,161,165,146,150,151,154,139,140,142,143,144,148,145,149,147,138,168,104,146,136,138,140,91,108,111,110,145,140,158,154,130,112,122,118,136,135,119,118,141,140,147,146,146,145,138,138,182,188,132,132,144,144,156,155,168,172,123,128,144,151,142,140,145,145,137,144,141,152,128,188,149,149,160,161,160,160,166,163,130,107,143,143,142,142,149,149,132,132,170,174,148,148,154,153,118,111,157,155,114,109,140,139,138,137,205,187,137,133,147,144,144,145,147,149,105,125,108,117,155,162,146,146,162,157,144,122,154,143,161,139,141,142,130,131,144,144,142,141,144,142,132,132,141,141,150,151,139,141,151,153,142,142,154,154,150,150,148,148,166,165,143,142,144,144,132,132,142,144,130,128,142,142,143,143,153,153,147,142,129,125,142,141,143,142,143,147,105,122,135,140,141,140,140,140,151,151,156,155,146,146,133,134,140,142,142,145,141,146,112,133,142,142,145,145,137,138,155,157,149,150,144,144,139,138,130,128,132,131,147,147,139,140,142,143,115,121,141,143,137,141,146,146,150,150,145,144,133,133,133,135,143,144,144,144,166,167,139,142,139,140,150,149,138,138,142,140,148,147,160,155,146,146,147,147,138,137,143,142,151,150,70,100,121,129,132,132,201,188,165,145,144,136,112,127,116,125,130,129,124,135,135,146,129,128,162,158,144,151,135,129,103,86,111,113,112,122,90,139,129,117,126,129,142,145,167,147,124,124,230,209,189,175,156,141,64,80,86,108,121,129,44,79,115,113,115,128,133,106,79,109,125,127,171,156,132,109,103,115,106,70,93,145,141,128,148,125,122,107,110,117,146,145,128,110,98,111,237,212,185,156,139,133,84,55,26,77,114,127,172,170,171,168,162,143,82,82,76,70,104,126,17,95,109,111,120,132,81,74,57,126,141,131,110,127,162,148,129,123,177,172,155,151,145,134,144,123,90,66,109,130,82,127,103,123,132,131,127,97,97,142,140,128,159,134,136,123,113,117,131,140,154,169,158,134,96,109,150,122,105,120,120,150,152,122,119,125,123,126,124,107,100,113,248,233,216,189,160,142,58,24,13,77,111,127,183,189,182,157,140,131,96,83,59,43,73,119,222,196,171,146,129,128,32,13,53,101,114,127,119,101,70,70,110,127,77,86,161,148,130,118,199,183,170,167,156,141,30,115,142,133,131,130,101,103,181,176,152,126,66,44,73,94,111,128,150,122,100,101,104,118,61,110,87,76,93,125,190,170,150,134,135,129,112,89,63,123,141,132,175,154,136,142,140,132,117,143,129,128,136,132,168,142,112,113,128,128,155,169,159,144,139,131,61,136,144,124,112,123,86,81,104,121,129,130,160,127,118,150,151,134,126,115,121,132,134,131,137,148,144,139,140,134,106,102,105,90,87,113,134,129,128,121,121,123,153,151,129,139,142,134,150,142,141,148,149,141,100,121,133,147,150,134,163,158,147,132,141,132,142,127,141,136,136,132,232,218,205,189,169,146,243,224,201,171,147,138,224,196,169,162,154,140,51,20,59,111,121,128,203,197,193,177,162,145,75,40,47,122,130,129,102,77,47,83,121,129,111,108,84,56,63,114,211,181,154,137,126,125,213,198,186,162,144,138,41,45,90,110,118,130,83,63,130,164,153,128,195,167,142,123,113,119,19,42,105,113,120,132,50,63,49,64,112,128,114,90,132,171,162,134,129,128,107,83,74,110,50,116,109,120,128,132,94,59,73,111,117,126,197,170,166,153,138,132,65,48,109,133,131,128,170,163,172,158,138,130,66,126,147,160,151,132,42,129,117,95,91,120,97,165,164,142,133,125,163,142,114,88,97,122,104,77,142,143,128,120,136,160,188,169,149,130,113,83,85,102,114,125,164,169,142,120,122,124,98,152,132,105,92,117,42,71,125,155,151,137,94,105,81,107,118,126,84,56,123,117,108,122,174,179,166,137,118,121,130,103,147,152,134,124,148,127,94,117,144,134,129,106,102,95,106,118,147,157,153,125,103,117,155,128,113,132,120,122,181,151,136,126,122,122,110,111,109,108,120,124,97,130,103,89,107,124,179,158,158,142,131,128,142,111,115,122,126,125,145,145,134,115,129,128,130,139,112,99,121,125,79,104,119,102,105,123,116,121,136,125,126,127,124,100,122,119,111,119,159,140,139,128,138,131,105,100,116,128,135,132,159,142,156,147,140,134,130,150,129,126,114,120,138,124,146,131,109,119,93,115,125,131,125,129,125,121,101,119,114,120,163,154,151,153,153,139,166,153,150,133,119,121,159,151,128,130,122,123,147,154,144,133,128,127,129,131,134,140,148,138,138,136,120,131,135,131,150,140,137,144,129,129,23,12,107,119,110,205,214,212,208,201,102,95,69,117,107,118,123,118,123,121,82,58,83,95,84,139,145,153,161,169,102,100,138,121,101,129,130,138,150,139,76,104,86,112,133,113,91,63,73,129,199,193,182,181,172,119,101,83,94,76,161,157,152,157,158,110,90,121,96,79,124,107,114,88,73,152,137,121,107,99,57,50,100,81,74,115,96,72,49,69,83,68,40,53,103,36,131,107,84,64,236,245,242,231,213,95,109,88,69,110,228,221,204,182,170,129,110,97,118,104,98,76,98,75,61,93,77,113,91,72,116,94,106,134,118,177,188,169,162,153,163,149,131,131,132,177,163,173,168,158,113,131,107,113,100,132,143,131,134,142,45,36,121,113,102,43,95,84,67,56,76,82,68,48,33,55,58,59,43,65,66,85,66,81,94,102,82,54,33,94,113,111,89,60,34,138,120,101,101,86,88,73,55,114,115,92,74,93,77,123,90,117,99,79,59,97,75,97,122,104,233,237,227,208,190,209,230,233,240,241,195,197,188,167,147,204,185,168,162,157,142,124,119,123,106,117,110,81,121,123,74,116,124,119,120,178,168,146,132,125,102,104,105,110,114,104,82,78,100,86,120,102,105,93,143,127,108,128,106,88,177,189,203,207,215,101,131,119,95,73,149,139,135,147,153,160,167,165,174,177,120,109,134,140,145,131,130,142,139,161,143,158,148,145,145,123,142,132,116,102,40,23,79,82,84,26,83,141,130,122,65,46,43,89,86,28,75,80,79,98,84,65,47,26,44,49,112,101,100,94,88,76,75,48,82,104,100,75,45,15,99,83,63,34,30,66,55,94,118,113,122,106,91,68,60,135,122,104,77,59,82,102,84,62,46,92,74,55,82,71,145,134,118,93,75,79,62,83,65,55,91,94,64,70,98,89,117,110,87,97,210,223,225,223,213,83,103,86,101,85,126,106,81,79,105,216,219,217,199,179,86,78,115,138,135,102,84,87,59,46,219,206,184,167,158,201,188,165,145,135,87,113,142,152,155,190,170,153,149,146,205,208,201,185,167,84,73,124,104,96,76,88,99,74,80,110,125,122,99,112,108,84,70,130,137,161,152,136,119,105,110,91,101,74,96,111,101,93,153,149,133,124,102,97,120,101,93,75,81,64,111,94,107,79,58,188,206,215,221,232,163,175,165,150,136,103,106,123,133,132,168,184,191,183,170,110,117,90,98,93,104,87,122,98,127,129,110,127,113,125,134,118,102,140,132,186,199,202,198,188,149,147,175,185,186,117,93,99,112,93,107,138,138,129,128,96,129,104,118,134,145,136,115,121,129,138,155,148,134,120,170,151,150,145,138,168,173,185,194,200,144,159,172,168,156,121,121,138,173,168,126,111,140,139,117,149,133,142,137,130,143,139,158,158,146,119,128,121,132,145,122,136,159,153,141,133,133,130,129,126,120,76,50,149,109,92,155,118,90,66,132,117,87,156,117,119,102,44,83,91,109,73,106,84,29,55,130,112,81,241,75,40,91,89,67,112,90,149,81,72,128,90,71,28,160,73,157,123,143,108,63,88,70,81,97,75,111,149,113,96,78,104,83,179,95,105,106,65,130,66,51,118,92,53,68,105,75,176,151,115,94,75,68,95,220,103,125,105,43,95,39,114,65,145,135,33,142,138,103,52,82,85,117,110,67,102,74,42,62,118,144,121,82,57,102,67,75,44,129,96,75,63,88,48,116,135,94,85,102,66,122,77,105,122,152,120,56,90,83,100,90,128,63,80,103,126,117,103,80,193,42,73,117,93,91,95,128,100,128,162,70,120,126,73,123,99,99,91,75,135,81,125,111,77,13,94,78,85,187,157,11,143,109,99,119,53,141,82,122,68,132,89,136,119,88,75,49,174,119,70,138,121,108,78,52,104,90,96,93,93,114,90,78,46,58,62,114,69,44,162,103,58,98,141,83,137,95,119,73,111,81,46,126,111,123,107,117,122,121,54,106,104,59,110,148,97,155,97,83,133,97,71,57,91,58,52,79,127,152,109,96,92,145,107,149,102,61,125,61,170,56,89,77,106,38,147,96,77,105,123,85,83,117,63,69,126,133,93,107,92,77,115,95,111,103,61,87,103,98,155,94,111,80,78,54,117,128,130,99,109,106,99,113,133,115,89,65,74,112,127,142,121,141,112,99,119,92,122,183,155,122,98,75,78,85,101,108,134,128,123,115,90,79,58,73,127,106,60,97,107,141,163,130,123,136,156,201,189,204,206,140,116,69,60,117,123,106,124,91,63,150,144,110,80,63,112,80,70,76,63,114,86,147,165,137,125,120,140,115,101,101,99,166,158,158,104,126,131,134,143,121,102,73,36,83,132,113,76,38,20,132,111,78,73,51,131,108,131,105,80,148,138,101,65,47,115,86,50,124,129,116,89,85,87,64,111,74,39,115,113,112,83,75,122,127,114,91,106,125,130,131,108,79,136,112,110,147,164,144,124,121,236,218,190,168,106,101,160,172,191,113,138,102,91,109,100,71,85,112,119,121,96,51,64,126,135,114,76,34,104,145,127,90,56,131,142,131,92,123,102,128,105,63,24,95,115,87,49,156,174,123,105,88,58,55,141,119,99,75,81,137,117,114,80,56,119,91,106,166,135,114,84,38,93,116,129,103,97,87,97,115,184,193,173,157,117,88,114,151,121,126,111,75,129,133,130,107,71,115,92,128,108,120,100,97,111,80,119,122,91,114,94,149,129,136,114,88,132,110,85,116,99,101,71,71,110,140,142,131,110,122,98,83,127,100,106,130,123,114,103,113,87,140,116,113,140,161,171,145,129,115,178,158,161,160,118,195,209,221,228,99,83,140,134,140,127,186,168,187,187,107,114,100,111,111,104,130,131,116,128,128,104,64,18,49,126,107,69,56,153,154,142,110,113,89,120,93,73,190,172,119,96,57,21,60,126,122,81,99,117,159,141,108,88,120,144,125,89,44,94,147,131,93,81,61,133,113,85,47,62,123,121,87,53,90,120,94,76,70,48,125,103,93,64,35,140,129,88,47,30,127,104,58,51,103,124,100,102,76,47,115,87,54,46,77,182,218,174,163,145,140,126,89,105,82,125,119,101,69,58,125,107,172,145,128,138,113,109,92,90,117,93,83,93,132,125,102,67,148,161,131,110,96,99,74,119,92,54,84,81,110,152,120,106,131,108,74,68,99,107,121,97,120,101,78,132,110,127,164,134,111,159,204,189,178,158,183,146,144,137,123,106,136,108,135,117,91,163,135,113,119,177,134,122,121,132,109,157,131,113,115,87,87,100,92,120,95,59,146,139,129,101,135,122,101,119,100,112,88,99,118,90,123,125,107,121,98,73,104,80,112,79,86,122,96,104,81,107,90,93,112,150,140,109,115,113,86,73,76,112,130,111,101,112,84,123,97,63,134,115,109,77,128,141,119,125,101,108,147,119,134,149,150,127,115,136,244,220,210,189,105,138,171,156,174,117,162,133,146,141,115,93,119,98,122,114,106,154,145,162,107,131,189,165,152,101,107,129,114,139,116,186,186,161,180,100,89,137,116,116,106,130,194,196,207,110,156,157,138,149,102,93,159,138,120,109,132,105,122,135,148,128,85,76,102,168,154,141,117,100,125,106,62,101,146,124,102,65,25,15,120,94,46,21,94,149,128,115,85,92,119,93,70,52,30,162,151,123,91,80,126,112,84,47,33,138,114,73,60,87,126,211,174,158,143,129,106,65,31,133,119,95,52,99,173,123,96,119,206,178,127,104,60,61,67,152,136,104,63,83,133,130,92,64,45,120,96,53,30,130,128,103,74,59,35,135,114,77,30,57,108,130,123,90,87,143,125,93,54,60,133,118,79,87,95,115,89,111,88,65,124,102,70,40,47,148,131,123,130,104,127,109,87,56,121,147,123,121,107,85,178,237,200,193,170,139,118,100,75,110,133,121,81,73,68,120,195,157,141,131,127,102,107,88,60,136,113,100,69,45,128,105,93,77,67,131,116,149,184,156,115,85,35,45,112,128,108,68,73,111,118,93,187,162,139,136,115,84,57,37,131,133,125,98,85,138,115,92,86,61,116,96,70,52,110,115,109,135,104,88,136,159,122,109,115,122,110,98,70,95,112,81,68,85,90,124,101,87,56,89,109,82,98,100,115,124,102,76,88,63,111,78,42,78,102,110,71,64,131,111,125,104,107,87,123,129,131,99,85,68,147,137,102,99,75,120,155,142,109,91,132,109,131,141,113,136,119,94,152,128,127,102,79,159,134,111,78,98,109,80,115,86,51,63,103,116,86,170,149,123,135,178,159,125,114,113,189,226,203,202,140,117,116,94,70,128,103,94,174,149,118,98,83,84,106,115,157,120,94,95,131,112,75,96,74,121,97,144,117,95,120,90,140,138,110,119,93,55,92,114,114,87,151,125,100,111,82,83,160,139,114,86,56,90,138,104,109,101,77,118,140,142,143,148,126,121,102,129,107,111,113,79,58,111,91,120,94,63,115,98,121,94,99,97,78,120,92,68,173,148,122,114,109,87,82,132,229,192,176,155,137,116,123,97,115,132,115,86,120,95,135,116,101,136,108,109,74,100,125,115,112,158,144,124,134,114,83,73,147,120,120,104,150,122,116,110,104,192,183,174,134,112,116,120,93,121,101,93,110,90,121,93,147,152,122,115,153,171,161,142,123,95,116,114,93,113,89,96,77,93,113,174,180,143,138,116,86,100,135,106,103,121,149,115,103,121,95,82,149,121,117,92,93,111,114,123,209,196,193,183,125,102,107,130,104,115,91,113,103,99,114,86,68,108,110,111,159,162,125,113,125,235,234,225,214,99,74,118,121,127,104,123,158,128,127,113,96,116,136,158,100,80,138,155,166,118,143,115,125,114,119,137,133,136,139,151,188,172,174,173,138,161,158,158,155,121,198,194,211,202,100,90,112,110,122,100,91,122,128,135,101,109,127,101,114,105,126,160,147,143,109,138,142,158,163,113,174,185,188,206,112,154,166,176,183,101,108,140,140,143,106,135,130,137,126,103,114,115,128,126,107,86,21,115,75,117,139,97,65,105,64,191,101,106,139,107,98,218,132,104,73,136,165,84,118,150,111,58,130,107,99,136,132,56,52,102,136,69,78,163,85,173,148,138,85,69,106,128,133,155,104,91,149,56,104,103,101,172,96,57,104,97,125,197,166,107,169,47,120,103,150,89,99,139,162,101,69,137,158,126,191,173,127,79,155,51,131,112,86,74,135,61,114,81,125,117,112,72,175,72,127,123,142,132,78,116,158,111,121,143,108,102,89,20,194,81,99,107,65,150,103,78,91,69,96,104,116,116,103,105,107,117,110,130,28,88,103,62,72,85,125,126,141,126,178,121,102,57,46,124,97,91,89,138,95,98,143,99,169,123,140,119,113,82,140,118,112,91,92,241,134,89,95,112,78,167,140,145,121,100,109,205,144,91,100,113,103,142,175,95,117,121,35,121,127,159,129,85,64,75,116,98,103,127,129,66,68,110,96,86,79,100,156,133,92,135,96,164,132,121,93,163,134,91,208,104,77,126,116,58,136,118,132,81,61,73,115,66,129,123,111,85,42,178,134,108,132,159,45,157,105,164,100,94,60,96,57,154,105,102,103,114,96,12,91,119,115,67,92,64,94,61,106,106,165,105,94,98,68,30,146,130,107,173,140,102,90,163,106,184,100,53,68,131,92,105,111,68,153,186,101,82,48,99,147,122,136,176,96,96,104,132,167,149,136,138,144,97,120,92,128,128,129,129,130,130,131,130,129,129,134,133,127,125,136,135,135,134,173,172,133,139,136,165,133,176,137,159,135,152,147,161,147,152,149,156,146,146,140,136,134,135,136,140,139,155,123,133,132,142,132,148,143,177,124,143,123,136,126,134,126,125,125,124,129,128,123,123,133,133,116,116,121,121,121,120,129,128,131,131,132,133,132,129,138,124,138,124,132,100,135,94,149,111,152,115,150,128,141,133,129,129,130,129,147,145,136,137,120,122,120,122,127,129,104,108,113,115,124,124,140,139,147,145,132,130,184,177,201,196,170,171,160,161,145,147,137,145,131,131,130,130,130,130,130,130,132,134,131,132,131,133,141,144,142,149,84,93,103,104,139,139,142,140,147,147,172,165,122,121,98,100,101,106,112,117,122,124,124,124,134,133,133,133,146,142,147,145,156,156,143,146,119,124,129,132,151,149,136,135,147,148,181,180,199,188,190,173,166,161,147,142,153,149,154,146,150,146,138,134,131,135,96,136,48,138,56,131,63,124,85,128,103,132,117,134,120,132,125,129,131,130,129,128,129,128,163,168,117,120,121,121,136,138,131,132,135,136,131,133,133,133,133,134,117,118,105,109,142,151,144,159,131,138,121,126,123,123,121,124,131,131,129,129,141,140,142,134,87,90,109,109,130,127,139,143,133,131,127,126,134,135,134,136,97,98,130,132,134,137,115,119,125,130,107,109,119,118,126,127,134,135,127,132,172,203,160,196,152,179,152,172,148,168,153,172,145,156,137,140,102,116,42,56,74,61,82,70,86,78,101,97,104,100,115,108,116,108,123,118,149,143,166,129,168,96,142,95,135,98,117,86,116,93,121,108,119,107,121,117,135,135,127,138,72,132,99,136,112,147,120,152,136,155,138,146,140,142,134,139,163,145,192,130,147,124,147,125,133,125,127,124,128,123,129,122,130,122,130,125,130,137,135,180,124,133,130,129,132,133,124,124,131,130,132,136,126,124,127,125,132,132,133,133,144,140,143,142,137,135,143,138,152,149,221,219,158,161,143,141,130,129,140,135,170,145,193,156,186,152,167,139,151,131,142,127,134,120,131,125,135,133,141,125,199,109,137,126,134,123,130,129,132,123,128,125,122,126,125,125,130,128,91,89,138,135,139,134,133,129,132,130,125,128,136,135,129,127,126,126,132,131,133,131,128,120,132,126,126,119,134,130,131,123,104,95,140,141,136,137,133,133,133,134,117,98,74,49,112,111,123,122,126,127,131,131,127,126,128,129,130,131,124,127,101,107,108,109,115,115,100,99,130,128,134,136,125,127,128,130,136,137,145,150,149,164,136,151,114,111,124,125,143,150,162,174,158,169,136,137,131,131,131,131,132,133,111,110,122,121,136,136,134,133,131,132,127,127,125,125,128,129,129,130,125,127,140,140,148,149,133,136,146,153,110,118,127,129,128,129,131,133,127,131,140,161,167,224,131,139,136,143,135,139,138,143,149,155,141,143,134,132,120,111,83,83,121,126,102,107,112,115,97,104,120,115,129,123,122,122,134,135,122,131,102,124,114,119,93,103,78,79,67,72,66,73,78,82,103,102,144,135,165,139,165,129,160,126,153,127,161,134,160,142,160,143,148,140,138,135,138,95,147,54,143,78,140,112,142,113,140,121,135,117,135,122,136,131,131,132,147,159,140,156,127,81,142,128,146,127,144,125,146,128,149,130,144,135,133,128,130,131,131,131,134,139,126,134,141,154,168,205,153,176,148,163,147,158,141,143,131,135,126,146,108,157,107,156,119,146,100,138,104,125,119,134,101,122,113,122,95,133,52,140,83,136,110,133,114,131,123,131,133,131,138,135,132,132,127,127,129,128,124,122,128,126,145,170,143,172,141,163,143,176,138,164,139,155,135,145,135,136,136,127,132,76,128,76,127,63,125,66,123,67,120,71,124,92,122,111,133,133,135,136,139,140,147,147,150,144,156,147,150,145,154,146,120,123,123,124,137,133,170,141,124,124,135,134,134,135,132,132,129,129,130,130,136,136,130,132,147,159,135,158,115,146,120,148,117,136,115,137,113,132,133,142,140,144,132,134,134,135,134,137,137,147,162,178,136,147,134,144,123,132,111,113,113,113,124,124,132,131,126,126,117,114,100,95,130,125,157,145,164,156,163,158,145,145,133,134,134,134,127,126,113,102,136,130,124,122,143,145,127,131,135,143,133,137,132,132,92,94,122,125,128,129,131,130,134,135,132,128,129,127,132,132,131,129,127,127,129,129,132,131,139,131,137,132,216,178,146,134,147,137,151,142,148,139,144,138,128,127,129,129,123,131,71,91,126,128,130,134,117,123,125,125,135,140,129,132,132,132,133,134,124,130,127,133,133,138,142,149,135,141,145,149,154,164,135,138,135,135,141,142,138,137,116,96,105,86,127,118,128,120,124,117,125,117,125,121,131,131,132,134,144,145,112,112,121,123,113,116,121,123,139,138,128,128,131,131,134,132,132,132,125,128,127,130,125,131,120,128,90,119,68,98,99,112,115,124,135,135,134,134,128,129,137,137,137,138,110,114,129,130,144,145,123,125,129,129,132,133,129,130,168,187,140,149,137,144,129,130,129,134,133,138,118,118,122,120,131,130,129,128,133,133,125,125,124,123,181,179,129,129,131,127,139,136,130,128,133,133,132,132,121,120,122,119,132,129,129,125,107,96,136,137,150,146,135,134,131,131,130,130,126,123,126,123,128,125,130,123,134,127,183,159,143,135,137,134,129,129,128,128,134,133,139,138,133,132,129,127,154,151,150,144,146,146,141,142,132,132,131,131,130,130,132,133,114,115,132,132,122,122,132,131,115,117,120,120,129,129,130,130,130,129,130,131,129,131,130,130,129,129,133,132,143,144,91,91,137,136,118,107,60,45,56,49,57,52,60,56,71,75,77,80,92,97,106,106,112,131,58,121,19,65,84,101,108,122,121,127,112,117,106,112,117,124,126,127,130,129,138,133,166,155,192,179,192,177,208,191,204,192,186,179,163,163,138,142,134,134,144,142,243,236,148,146,141,137,145,141,151,144,147,143,135,139,134,133,134,128,138,88,142,10,127,76,130,96,129,102,128,108,123,111,127,119,127,124,136,136,139,139,142,140,246,241,158,167,143,145,146,149,143,145,148,152,133,134,139,135,135,136,99,137,95,133,75,138,67,135,73,128,83,132,96,126,115,127,130,132,137,136,140,135,134,130,137,131,159,151,215,197,181,170,160,149,150,143,145,148,186,207,141,147,135,137,122,122,126,125,128,126,127,127,134,126,131,123,133,133,126,122,128,122,99,93,59,60,82,82,106,107,119,123,124,128,128,129,134,137,133,139,133,136,141,132,139,122,142,97,130,81,128,89,129,101,125,112,137,140,129,148,101,159,118,180,122,178,120,178,116,168,118,153,127,151,126,136,132,134,125,126,118,105,156,124,180,132,163,124,148,121,131,112,127,115,125,122,129,131,128,129,136,134,142,141,165,158,203,182,141,136,132,130,135,135,130,130,133,133,132,132,127,126,106,105,112,110,106,105,80,84,100,101,122,125,126,128,101,109,46,59,114,112,119,119,126,121,129,124,128,125,125,122,123,120,125,122,135,134,121,134,56,139,131,145,135,138,136,139,126,130,122,132,126,129,124,129,153,169,146,179,138,139,151,143,148,138,153,137,142,129,144,126,140,128,133,126,136,134,154,149,173,157,152,144,149,141,137,136,127,121,123,121,121,126,120,123,157,143,166,135,120,122,112,118,102,118,111,124,134,131,141,138,135,134,126,129,140,123,152,76,131,116,138,136,126,134,130,142,126,136,120,132,126,128,124,127,131,138,80,147,126,138,130,140,129,134,133,135,131,132,126,127,127,125,125,123,132,132,130,132,123,130,102,102,107,110,116,127,132,152,142,160,143,151,142,146,132,132,132,132,125,126,132,140,158,199,135,149,134,140,135,131,129,120,127,121,129,130,122,123,125,124,138,138,138,135,140,141,101,94,105,98,121,122,127,128,126,127,119,121,133,156,132,159,130,148,137,164,127,138,130,137,135,140,126,126,128,129,129,129,126,124,130,128,143,138,149,143,185,170,129,127,138,133,138,135,132,134,137,144,139,183,131,145,127,128,128,127,128,122,129,125,145,139,135,131,132,133,132,130,152,96,159,85,150,105,154,115,143,120,138,126,134,124,130,126,128,127,121,123,122,123,116,125,84,87,133,135,129,131,123,126,133,135,131,130,136,134,129,119,79,63,116,116,136,133,133,130,140,143,127,127,124,125,127,128,128,126,124,120,139,128,153,134,151,134,174,145,159,136,165,144,171,149,143,135,134,134,133,133,121,119,177,162,166,154,127,130,132,132,136,137,142,143,138,137,167,151,162,142,128,136,142,148,128,143,145,153,140,149,132,141,128,139,127,133,156,169,131,129,126,120,127,125,129,120,131,126,126,123,124,121,122,121,123,123,138,140,149,156,145,152,105,102,131,126,151,146,147,139,144,137,143,133,135,130,132,130,131,129,126,130,126,129,110,135,115,139,108,146,105,147,121,134,124,133,137,137,135,134,143,142,146,146,120,121,139,137,133,129,149,145,139,133,130,127,134,134,134,134,125,124,117,119,120,113,84,80,122,125,108,112,97,102,118,120,124,123,115,116,110,111,98,97,127,124,129,127,120,117,114,109,106,104,116,116,138,138,139,141,142,146,127,125,133,130,134,128,134,127,116,91,105,84,114,106,128,128,126,126,131,137,126,129,133,139,134,145,132,143,150,192,131,142,138,141,132,130,132,130,149,138,196,152,137,125,134,125,139,128,133,125,141,134,134,135,134,135,134,135,131,130,136,133,110,106,142,144,153,162,131,129,134,132,131,130,126,125,132,130,168,153,126,124,130,126,140,135,140,134,138,133,145,137,135,134,130,130,132,131,133,132,129,129,125,128,128,130,133,139,143,152,193,215,152,160,130,131,129,131,130,131,135,136,136,141,83,81,121,120,136,130,150,145,147,145,134,133,135,133,146,142,135,131,127,128,134,135,93,102,126,132,131,133,127,129,124,125,120,122,103,106,128,129,139,138,127,128,134,134,143,138,139,134,135,133,131,130,133,131,139,134,138,136,166,156,119,116,121,122,126,124,116,117,123,124,131,131,129,129,130,128,141,138,135,132,154,145,137,129,131,125,146,137,138,135,131,131,131,132,129,130,134,138,111,116,113,118,123,125,122,124,143,147,138,140,116,113,114,112,130,126,117,115,127,126,139,137,141,139,131,132,143,144,139,140,130,130,129,128,136,134,119,117,152,143,155,143,120,119,142,139,124,130,126,128,112,110,112,109,136,132,125,118,121,115,103,101,109,100,125,120,121,117,122,121,128,128,127,127,124,124,128,127,131,129,142,138,147,141,115,108,113,109,122,119,136,133,150,139,142,131,119,111,151,137,121,116,146,134,137,129,121,123,127,129,130,130,130,130,136,137,126,126,136,136,133,133,139,139,142,143,119,120,134,134,132,132,133,133,135,138,129,131,133,134,135,138,126,130,117,118,131,132,135,135,129,129,128,128,126,129,127,129,123,125,115,117,156,157,127,131,129,129,128,129,129,130,131,131,126,127,135,134,136,135,140,136,117,113,132,128,104,97,109,106,131,131,131,131,121,123,124,125,126,127,127,127,135,135,128,128,130,130,141,140,129,129,129,129,129,127,127,125,149,146,125,123,134,133,134,132,152,150,138,138,128,128,126,125,132,133,141,143,136,136,126,127,126,127,129,131,128,129,135,134,176,139,192,135,145,122,149,117,155,134,169,133,157,139,142,136,151,152,142,147,166,174,103,107,141,134,140,136,144,135,147,135,156,131,153,127,133,126,130,124,127,130,123,124,114,105,195,193,156,157,165,158,126,122,149,141,174,173,152,147,136,139,131,138,163,169,103,124,80,102,153,186,121,151,134,161,156,190,141,151,121,123,124,127,119,127,133,134,157,156,81,69,136,134,160,169,118,114,135,128,114,116,97,97,117,122,152,161,115,121,106,122,135,137,111,113,125,135,141,145,143,146,143,150,132,136,142,150,151,167,101,107,155,173,112,124,105,100,128,126,127,130,133,134,142,121,131,116,176,145,161,120,209,150,196,133,147,115,149,130,144,145,144,145,120,119,163,160,117,118,123,117,154,119,193,98,149,101,137,116,133,135,140,143,144,156,131,146,186,201,140,139,123,125,158,169,157,166,142,143,130,131,132,132,128,128,141,142,147,149,145,148,137,139,129,129,107,108,157,157,120,121,119,119,140,132,137,131,118,113,143,136,134,135,164,158,133,125,127,124,148,122,197,130,173,145,110,139,123,165,83,158,90,167,93,142,136,169,134,152,130,126,154,138,227,150,156,114,147,114,142,109,135,110,166,135,176,150,152,142,132,132,136,136,130,135,143,152,136,144,152,160,177,185,112,112,165,166,160,161,145,145,138,139,116,118,127,131,66,80,132,142,119,127,101,108,120,130,126,130,135,135,142,139,153,137,55,30,142,139,139,143,135,133,129,133,109,108,129,129,136,135,134,131,129,132,132,134,135,149,79,206,123,137,135,143,130,140,131,134,100,99,165,164,142,123,148,133,133,122,142,133,138,125,119,111,129,123,137,130,131,132,123,129,174,185,196,181,127,111,156,141,132,114,129,106,132,107,126,117,134,140,131,136,119,146,92,246,128,132,125,129,132,140,128,141,126,145,137,142,130,130,110,115,124,139,127,151,118,152,98,146,36,108,126,158,112,146,112,130,138,136,145,138,153,145,116,125,90,103,137,138,189,185,141,151,86,93,111,111,133,171,125,209,140,132,130,134,129,101,142,120,142,132,135,126,141,140,140,134,128,123,131,123,138,118,163,133,240,197,176,151,126,123,81,94,109,118,124,133,135,133,137,134,154,135,140,155,69,190,119,149,141,151,142,123,135,125,129,130,127,125,132,127,107,80,123,103,145,131,133,107,140,103,135,106,170,145,159,143,136,137,127,130,105,119,129,134,141,151,116,127,119,140,75,119,152,162,149,152,72,138,9,143,118,160,126,134,141,147,135,131,129,129,135,129,136,126,133,125,137,135,146,141,145,139,141,140,133,130,213,208,139,130,139,136,117,117,126,125,133,130,138,131,141,100,145,93,159,121,144,132,117,160,102,187,99,162,117,144,132,132,134,134,140,141,127,126,128,131,116,116,121,127,119,126,114,114,99,100,141,144,148,159,179,224,95,131,100,125,87,110,112,132,134,147,111,125,122,122,137,140,141,129,169,12,144,132,133,144,141,146,137,147,136,122,133,130,131,128,141,142,128,139,15,69,160,159,142,130,137,126,159,141,145,143,128,125,134,128,131,130,127,127,114,104,119,98,83,68,139,120,173,142,199,154,191,153,158,145], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+133120);
/* memory initializer */ allocate([128,130,127,127,148,150,110,99,119,109,120,113,163,154,110,90,138,129,149,144,131,134,124,142,76,217,130,129,140,138,133,135,145,150,136,138,127,130,130,134,144,119,178,70,143,130,115,136,139,138,129,109,136,116,147,122,126,112,126,123,132,139,128,144,107,156,75,163,120,164,151,136,151,99,160,112,159,126,143,126,140,138,137,135,152,108,251,85,138,116,137,118,141,119,136,121,150,134,138,131,137,137,143,144,150,153,148,154,152,151,117,104,124,96,93,67,146,138,149,148,149,153,172,193,108,114,125,128,145,165,149,160,121,130,115,120,110,112,121,118,145,146,141,142,127,127,103,95,138,143,114,126,109,115,143,136,153,149,144,142,140,138,150,144,128,116,142,136,135,122,93,88,164,163,141,142,171,182,154,160,124,125,122,123,158,155,111,97,138,130,157,134,101,65,129,118,121,114,124,119,131,133,125,129,136,147,135,152,131,133,110,115,118,114,161,159,233,218,172,166,140,107,125,0,140,103,140,115,125,113,132,135,128,133,138,146,131,145,127,133,131,131,122,122,135,132,126,124,132,133,164,167,121,127,117,120,167,162,145,143,135,134,136,134,156,146,195,177,127,139,108,140,141,173,141,178,131,155,129,141,134,134,119,114,184,184,127,126,147,151,130,140,146,159,134,145,131,136,137,142,135,137,128,136,83,108,97,98,152,119,207,144,142,121,144,129,131,127,130,132,124,125,108,107,94,116,81,114,139,173,131,158,145,177,141,163,136,140,143,144,135,141,132,136,134,142,142,136,173,50,143,106,142,127,134,139,127,133,125,125,129,130,131,133,132,148,110,138,113,135,138,175,108,151,55,119,51,100,93,116,121,121,146,151,99,120,127,137,107,122,125,139,110,132,135,156,141,156,148,157,137,137,141,140,139,137,130,128,138,136,132,134,115,110,177,179,81,86,100,98,84,83,121,121,148,157,127,133,146,156,127,136,143,151,135,139,138,142,136,136,201,164,151,129,123,136,147,148,127,142,128,143,101,126,119,133,114,131,116,126,132,133,140,140,126,125,156,153,142,129,140,130,77,69,134,132,146,148,135,136,133,132,123,116,116,103,150,135,144,127,130,117,136,122,122,106,48,38,81,78,145,146,135,136,123,122,126,133,133,138,145,145,144,150,160,181,142,139,150,150,136,136,139,139,133,133,139,135,134,129,140,137,153,145,132,131,151,144,68,66,137,137,139,139,146,146,142,139,129,128,131,129,133,132,135,134,135,134,201,200,137,136,146,143,155,153,157,158,131,138,140,139,143,144,128,123,216,192,159,150,137,138,136,142,145,148,126,162,140,170,186,95,131,140,143,148,133,128,130,133,141,139,153,150,122,122,134,144,124,130,159,166,133,139,151,150,138,139,131,134,121,121,131,129,148,180,121,135,118,131,124,148,119,119,129,126,150,156,155,160,40,154,115,157,133,129,140,133,143,133,143,132,144,130,141,131,134,130,137,133,134,136,141,140,145,137,152,124,183,91,118,154,123,158,136,134,140,142,138,142,138,135,131,131,138,129,121,128,146,219,124,123,125,135,120,126,127,141,133,136,127,124,120,107,152,125,149,108,158,144,196,185,174,164,151,149,138,131,140,137,149,148,144,145,143,145,140,143,141,147,112,125,113,113,149,155,143,149,146,151,138,138,141,138,144,129,134,125,143,140,153,154,142,123,162,42,154,106,153,130,153,153,137,137,144,144,142,140,165,151,161,140,144,134,156,124,167,143,166,155,132,132,137,138,137,132,124,127,140,144,134,140,162,180,127,131,152,169,145,156,133,134,131,133,130,132,147,149,125,117,127,118,159,155,147,142,122,117,145,144,138,137,130,133,113,149,168,224,166,201,129,151,147,154,136,135,140,136,152,141,120,112,140,127,161,100,132,115,118,125,115,133,115,157,144,146,114,135,127,139,138,141,135,135,137,136,147,142,143,144,139,152,142,136,147,143,177,39,125,71,147,143,66,88,132,158,123,126,116,135,119,124,128,135,133,140,137,126,137,130,155,38,149,103,130,135,139,143,127,137,135,141,138,148,131,148,136,147,132,139,136,140,115,129,115,151,136,160,87,131,157,176,150,164,140,141,135,119,137,133,141,140,140,139,134,134,142,144,131,132,131,134,131,132,116,114,129,133,205,207,130,133,160,170,137,127,124,112,158,146,155,137,134,136,137,142,177,184,149,152,135,134,133,132,135,129,144,136,139,134,161,155,126,109,215,186,177,153,160,149,139,139,136,140,140,142,186,71,129,144,131,165,142,152,140,151,141,143,137,139,144,138,150,135,133,126,136,143,99,152,139,131,190,118,122,147,134,155,136,143,138,135,137,132,147,144,150,144,138,134,129,133,130,138,56,175,129,166,147,165,140,138,144,137,141,133,150,139,129,135,40,83,126,130,110,120,100,110,126,128,141,142,217,175,172,151,146,153,125,132,128,137,141,141,145,145,140,133,132,131,129,144,128,177,133,195,147,120,138,131,161,114,166,134,162,118,161,115,155,129,137,136,141,129,141,132,55,168,121,126,136,139,120,133,149,147,132,141,131,136,147,150,151,132,101,31,117,101,129,132,122,138,128,137,140,170,131,143,131,134,149,192,122,158,136,146,133,166,143,141,141,136,141,129,125,155,140,138,137,131,111,112,131,132,120,127,149,148,151,141,156,148,133,129,127,124,144,137,142,139,134,133,141,138,133,135,124,96,226,152,116,108,128,105,155,130,153,138,144,139,142,141,137,135,142,143,156,162,136,89,188,145,181,152,138,146,146,154,145,149,152,133,158,133,42,153,117,144,149,139,125,139,134,128,150,128,143,125,135,132,143,141,143,141,164,173,141,142,156,155,154,154,169,170,77,80,112,105,135,134,126,143,120,172,111,144,120,154,107,153,95,134,104,134,128,116,163,131,151,136,135,133,142,143,152,204,149,112,156,128,150,126,127,129,139,175,143,141,138,135,168,148,152,105,164,121,134,122,119,109,122,148,136,143,153,132,158,148,149,150,133,131,142,141,150,149,156,173,138,155,129,144,111,107,130,129,96,89,106,104,135,135,144,146,131,153,134,154,146,166,117,138,163,187,190,216,149,156,149,152,142,142,153,154,109,145,40,102,116,126,137,139,149,157,108,124,139,146,142,147,130,126,120,111,172,146,169,136,150,135,126,96,159,143,150,122,162,129,156,142,135,142,144,138,222,109,137,145,144,142,141,143,138,136,124,150,133,144,137,145,141,144,139,144,134,154,114,136,145,173,151,215,110,115,127,134,145,150,145,144,144,142,139,131,147,132,141,119,143,106,165,41,147,129,129,144,138,135,138,140,128,150,89,163,154,115,141,127,132,145,135,157,143,145,140,141,127,135,127,129,142,147,116,147,104,162,153,143,146,130,144,110,133,123,130,137,118,198,126,152,154,146,139,127,147,112,207,151,156,136,162,137,108,121,130,135,125,131,131,134,134,134,141,144,107,143,137,144,124,136,115,147,130,157,119,167,71,144,97,128,134,138,132,133,138,138,146,146,147,131,141,138,185,65,145,123,139,130,142,128,139,136,157,147,124,119,164,148,170,154,133,130,157,148,140,141,130,135,134,137,136,137,143,144,144,144,178,186,71,73,120,118,127,124,152,151,155,146,141,138,142,143,139,143,133,134,139,140,138,135,146,141,78,198,129,139,141,141,134,141,137,136,120,120,124,118,143,148,148,152,131,143,129,137,152,158,157,160,175,178,137,139,131,133,146,152,121,147,142,143,129,136,149,145,197,114,103,141,124,140,141,140,129,129,127,130,131,124,123,117,150,139,120,109,119,120,163,163,117,121,139,139,136,136,94,74,150,145,126,127,147,150,158,162,84,74,136,129,140,132,136,135,146,145,124,116,129,120,130,129,130,109,122,111,160,141,135,113,131,121,136,135,135,135,147,147,140,140,144,145,139,142,131,137,145,145,143,153,48,49,145,143,151,147,158,146,135,124,124,116,159,140,131,126,123,120,103,117,113,119,148,146,128,124,123,126,123,120,158,141,148,137,146,143,125,143,89,107,116,123,149,147,141,139,149,153,118,121,139,138,105,119,168,147,139,141,143,138,133,130,126,126,143,142,146,144,124,123,143,145,149,148,147,141,151,143,118,113,175,171,125,109,84,55,34,51,109,112,118,132,122,102,78,80,132,119,132,132,125,131,109,91,131,131,136,136,137,137,140,145,140,143,117,136,122,106,109,91,115,119,133,117,103,80,55,117,123,102,93,80,139,116,70,39,95,89,103,113,112,122,135,244,229,215,199,181,163,150,146,144,143,173,171,154,155,154,151,148,145,143,132,138,116,85,117,94,108,117,107,116,132,118,123,119,88,67,49,95,84,95,121,103,74,70,179,164,141,126,107,112,119,95,103,149,139,148,144,147,148,141,151,133,142,129,111,131,108,128,122,108,121,96,115,138,116,93,105,115,115,123,129,106,136,180,147,130,108,141,131,118,136,155,176,156,135,129,140,146,142,134,141,130,109,80,52,38,18,47,118,134,155,141,100,78,72,89,79,96,92,98,133,111,83,91,72,58,105,115,112,120,145,127,135,113,113,105,105,85,69,61,115,96,116,145,159,170,175,175,168,155,140,120,84,52,80,145,125,127,116,126,128,108,101,198,227,200,178,159,147,148,121,88,46,109,124,126,126,137,147,147,129,107,164,148,127,117,134,120,111,116,120,103,98,73,66,61,70,115,116,125,126,100,77,188,162,140,114,128,139,123,145,165,164,134,109,100,108,118,127,130,156,182,190,173,167,165,162,157,152,147,150,164,179,183,173,155,140,136,134,135,122,92,69,140,132,118,108,128,138,132,123,127,148,137,150,149,139,127,124,130,136,138,112,70,41,37,132,140,129,125,130,111,78,33,51,161,141,136,120,122,126,110,87,106,85,68,48,81,112,113,135,125,98,85,102,80,100,87,86,116,142,133,110,66,48,152,139,135,136,123,128,116,89,102,128,99,83,61,105,124,120,94,73,83,78,100,122,124,128,132,144,137,116,102,75,144,136,127,140,127,154,144,118,99,90,90,89,75,68,83,123,103,89,198,180,154,138,122,136,120,138,118,121,136,110,105,85,111,101,104,121,126,139,115,99,101,107,110,123,126,127,115,88,109,164,134,138,138,120,121,130,202,195,202,199,201,181,164,159,148,120,116,194,199,186,171,154,142,137,133,137,129,112,149,134,112,149,138,120,134,119,102,107,83,79,114,119,127,128,128,144,148,165,155,161,150,135,122,116,115,120,99,80,120,123,124,111,89,70,108,118,95,66,53,105,126,125,105,83,111,129,197,191,197,206,213,216,208,196,169,133,109,127,164,134,121,99,92,82,71,131,121,93,91,136,105,115,140,120,110,150,164,139,108,87,81,93,92,104,116,133,114,125,126,111,136,110,156,147,133,113,94,118,120,115,125,124,126,127,134,116,131,161,158,166,157,150,150,144,141,125,185,169,142,140,143,139,131,134,138,179,188,170,150,134,140,144,133,127,127,150,177,204,184,192,194,190,193,177,158,114,113,138,116,137,135,132,131,127,134,120,147,163,135,133,137,136,136,133,135,137,120,95,73,46,48,111,97,97,123,139,130,109,76,52,72,61,61,125,127,132,119,119,90,66,41,64,156,143,129,131,106,58,25,99,115,122,136,129,132,134,123,97,53,27,114,125,114,120,123,122,107,93,57,47,133,128,138,141,131,145,132,122,110,79,57,30,73,153,144,150,132,85,59,133,125,130,115,100,96,148,127,111,86,61,38,110,121,108,99,157,143,105,77,116,118,115,131,122,122,133,119,134,108,86,61,129,165,143,127,125,105,89,111,97,85,113,99,98,117,149,131,101,106,88,95,79,119,123,120,125,109,81,100,201,183,156,138,115,116,141,119,129,105,76,60,110,99,92,82,150,156,129,95,69,115,115,113,134,125,118,97,67,96,203,197,171,151,133,125,143,131,120,134,105,80,51,60,139,134,129,160,223,219,219,212,197,173,157,146,132,112,164,144,119,102,92,76,73,94,132,112,124,114,93,92,83,73,69,99,129,103,188,163,142,132,127,101,82,59,140,141,111,74,46,105,113,99,127,122,125,94,63,112,116,101,81,120,136,134,133,190,224,193,179,158,146,143,140,136,152,161,132,120,112,94,114,102,92,116,129,194,196,202,211,212,210,190,169,152,166,166,145,111,91,132,133,128,136,130,118,94,72,74,92,86,89,92,106,123,126,100,86,137,117,92,76,104,106,114,133,109,204,192,166,148,138,128,111,81,118,99,79,146,169,141,123,102,131,120,127,105,136,204,170,154,131,145,135,119,117,95,64,83,141,136,118,96,99,126,115,93,98,102,95,105,106,114,119,128,131,121,98,139,149,119,109,86,105,129,134,119,104,169,185,155,141,122,107,127,136,115,85,108,87,126,102,128,136,129,125,99,126,158,133,139,132,113,91,107,141,122,128,161,130,127,105,120,118,106,122,140,161,168,187,184,176,158,144,140,127,111,89,130,132,105,134,121,100,122,129,110,128,115,129,116,132,118,114,119,138,133,132,188,183,159,161,147,134,140,132,113,84,167,147,132,124,109,133,121,132,128,116,121,98,101,145,129,128,129,124,112,152,158,136,161,139,165,158,142,139,138,110,127,148,117,126,118,101,116,155,168,154,128,120,152,150,141,140,135,127,111,109,134,104,133,110,112,132,114,111,87,68,89,107,121,121,126,126,129,120,148,169,163,173,178,185,188,178,163,122,97,86,117,101,138,118,142,155,139,125,114,131,138,153,149,163,150,143,141,157,161,138,152,134,121,122,109,110,124,151,171,196,168,145,139,147,151,146,139,134,169,179,170,175,178,177,173,165,154,120,151,118,107,125,129,133,133,136,139,119,141,159,151,160,165,168,169,162,152,115,111,119,94,117,121,127,127,132,136,134,153,147,142,142,147,159,159,154,147,110,106,139,135,143,142,147,146,147,147,115,133,151,133,141,142,151,152,147,144,115,132,144,131,125,126,128,130,131,136,138,118,96,71,48,26,43,130,125,125,134,122,98,54,28,84,77,73,109,125,133,112,67,48,141,129,126,113,112,118,143,123,89,54,71,73,75,131,123,123,126,109,81,31,15,94,110,109,119,128,132,122,97,92,73,50,27,22,104,133,133,119,94,48,34,168,160,154,151,130,147,133,90,54,71,123,106,105,93,117,143,132,107,69,45,78,178,169,150,139,138,123,116,96,69,49,32,113,103,112,154,151,125,79,60,152,160,154,155,137,142,151,124,88,66,59,94,87,95,119,166,154,122,92,138,132,124,114,97,97,122,99,98,219,191,176,165,159,153,131,130,119,91,51,24,41,144,156,147,139,139,122,81,65,124,111,104,90,94,98,138,120,112,91,63,65,89,75,78,106,126,107,91,85,69,95,90,84,108,120,155,139,100,78,120,110,109,91,77,73,144,130,135,112,88,65,62,142,129,126,170,154,150,131,121,116,100,92,83,86,131,122,98,107,102,75,54,38,117,130,146,139,117,107,86,66,44,30,97,128,129,116,100,59,108,127,119,139,129,129,124,106,79,49,154,190,166,152,133,123,141,149,123,89,61,70,143,132,125,126,136,113,177,166,141,123,109,108,105,93,137,117,147,123,99,85,109,98,91,75,129,121,102,78,53,90,149,136,134,135,144,136,126,90,114,152,137,152,138,128,133,115,107,129,99,78,60,129,125,118,147,141,119,124,110,91,79,64,106,117,134,111,164,143,123,113,116,95,76,56,147,159,140,109,83,84,140,135,127,129,123,104,116,99,91,87,80,110,113,121,124,106,174,174,152,141,132,134,126,124,140,190,240,215,212,189,173,158,144,137,123,97,79,102,110,111,90,75,126,124,134,121,104,145,127,100,77,65,120,118,123,106,87,41,68,119,106,115,109,119,137,232,241,225,217,202,183,169,156,145,161,146,127,110,97,107,88,114,108,106,141,244,216,192,172,163,148,143,144,144,128,127,109,89,77,68,124,120,121,125,125,94,48,71,116,113,104,120,142,137,133,129,115,82,68,120,99,133,134,124,130,106,108,160,130,111,89,129,124,119,134,120,149,143,116,95,87,142,132,122,126,114,108,107,80,141,133,123,137,124,117,95,69,43,62,98,114,116,112,120,122,99,87,164,145,123,99,95,118,105,126,101,102,120,113,110,92,139,134,126,148,194,241,219,221,215,200,193,174,151,127,104,122,136,113,106,110,95,78,106,131,163,217,199,194,175,164,155,142,138,139,124,88,57,161,161,145,139,124,116,127,110,91,98,126,104,113,98,94,94,145,138,114,90,75,130,117,107,99,90,119,98,86,101,148,133,103,83,124,131,143,168,169,133,110,117,139,149,147,137,124,106,80,138,194,163,142,119,106,130,136,125,105,114,87,113,101,89,108,102,114,90,53,46,105,116,126,122,118,122,124,102,92,195,167,160,144,154,154,132,118,97,88,72,98,120,112,98,79,117,114,107,185,191,191,188,175,165,153,143,119,97,90,89,120,151,136,113,99,112,141,121,144,122,125,113,133,111,92,69,120,98,78,109,151,145,157,157,151,143,130,110,120,188,159,141,119,112,109,98,126,112,83,110,169,139,127,105,93,123,141,145,117,106,91,78,123,107,101,125,117,95,71,147,176,153,148,133,135,127,124,106,79,64,115,96,108,115,106,105,127,115,90,98,105,81,144,135,117,125,126,104,98,165,138,136,112,149,148,131,119,144,186,185,204,202,209,200,182,161,123,153,190,189,199,194,191,176,157,147,121,103,119,98,100,120,106,97,95,126,137,130,102,117,117,92,126,114,101,118,131,219,190,167,153,151,144,140,142,143,114,102,151,152,132,120,112,120,127,131,138,122,91,143,118,120,114,104,124,117,148,142,117,126,97,125,108,116,142,125,126,106,91,169,208,178,158,138,127,135,133,126,101,83,147,130,125,117,114,117,120,103,94,149,136,129,139,118,133,133,147,152,126,132,119,97,132,129,114,126,112,107,148,125,112,114,124,125,129,135,139,121,157,151,131,140,118,147,136,121,115,105,159,167,185,191,196,190,176,160,124,106,104,122,130,114,152,144,134,136,136,152,159,153,131,114,116,126,129,129,124,109,87,131,107,115,130,107,144,131,126,162,176,175,180,176,160,141,134,134,136,127,108,161,162,133,141,124,112,128,130,115,110,140,107,155,134,131,156,137,122,106,116,127,118,161,150,170,167,152,139,177,203,176,155,139,130,128,129,132,137,119,125,103,110,123,107,120,108,101,113,107,160,154,160,166,169,176,168,156,115,90,65,115,115,104,120,112,109,124,131,123,100,109,185,158,141,132,116,119,139,130,119,156,124,138,127,116,141,128,133,118,115,180,149,151,135,130,147,129,117,90,80,119,124,128,132,130,128,135,112,97,142,161,167,165,154,142,136,135,118,141,193,172,157,152,148,145,146,141,125,147,165,166,149,133,123,122,128,131,128,193,177,174,182,186,197,193,191,173,124,144,162,133,113,113,123,128,129,130,117,98,121,122,137,132,110,97,111,130,128,176,151,125,126,134,130,121,127,130,122,151,142,111,106,121,126,126,130,134,148,167,186,153,129,122,124,128,130,128,148,172,206,178,171,182,169,180,172,156,133,164,174,160,155,163,163,172,169,158,132,150,147,142,152,140,140,140,134,135,137,158,167,172,163,153,169,158,146,147,150,161,162,172,153,133,140,144,136,135,109,84,101,120,129,134,133,136,137,143,112,114,157,147,141,136,135,133,135,138,121,154,161,150,149,154,151,144,146,144,111,117,125,125,130,131,135,137,143,148,121,141,146,131,138,126,118,111,119,130,120,135,145,121,140,134,138,137,131,134,115,137,132,137,139,138,138,139,145,149,131,149,147,133,132,126,131,134,130,133,110,98,84,141,107,169,169,123,125,126,118,210,98,126,132,138,128,139,156,157,140,142,129,95,192,178,182,186,183,159,135,134,144,124,100,228,203,161,122,104,139,159,134,161,121,126,192,152,218,180,132,132,119,99,96,97,80,53,134,143,102,114,133,114,127,83,77,126,85,107,110,114,194,186,139,116,147,104,129,138,126,133,109,144,115,45,130,97,159,155,157,162,189,185,168,163,151,151,142,135,144,147,120,74,192,186,149,118,71,84,143,156,133,178,168,107,119,149,105,112,182,184,158,118,118,148,128,177,171,152,139,135,126,209,171,150,123,100,190,158,166,97,136,123,136,139,128,138,126,121,132,131,128,95,60,168,127,140,208,161,109,102,119,162,150,137,107,200,156,136,136,128,103,95,74,91,220,173,152,138,139,129,140,136,122,82,180,115,53,90,121,107,99,148,116,139,100,63,191,155,130,129,163,155,98,175,95,151,127,107,124,124,116,88,71,164,148,96,57,89,125,117,77,63,162,144,113,109,137,134,134,130,149,174,158,158,130,81,28,67,142,139,129,100,194,134,68,175,131,103,136,132,122,96,119,82,115,249,215,168,125,139,199,96,146,123,136,179,142,137,181,166,106,86,122,106,123,131,106,119,129,189,188,147,126,110,101,114,147,136,132,106,72,175,148,99,130,153,125,136,123,119,147,170,157,126,209,188,158,152,101,89,142,131,161,150,148,124,89,119,141,137,131,103,81,85,64,175,129,121,137,144,142,145,119,205,148,80,165,138,143,137,167,165,148,149,110,234,217,170,167,152,75,140,155,155,175,129,136,134,136,152,161,131,140,121,91,79,255,209,132,147,120,114,177,128,110,61,89,131,125,127,93,87,167,115,186,162,107,106,134,162,151,100,79,67,151,116,130,142,162,153,155,143,122,85,202,187,135,125,158,155,103,129,74,149,130,98,129,126,148,152,153,133,118,94,80,70,47,90,124,118,143,184,158,126,70,82,111,113,126,135,175,141,203,166,123,123,134,133,113,111,128,76,128,177,151,178,134,125,120,120,193,106,98,134,101,86,101,114,136,127,134,196,86,105,145,128,119,137,138,126,230,161,141,128,129,136,88,83,103,118,178,123,89,101,161,173,165,147,130,123,171,158,131,81,50,177,162,136,125,115,82,173,195,168,130,112,112,121,152,148,167,87,82,161,142,147,98,89,168,138,97,157,132,114,74,126,161,141,135,123,68,137,124,118,112,92,65,96,191,181,161,151,141,145,129,102,97,111,144,128,55,128,115,155,129,184,167,147,131,141,125,33,127,111,127,131,125,130,137,130,121,195,172,177,176,149,98,97,126,106,168,159,144,185,156,151,182,158,123,93,110,116,98,99,125,136,139,148,79,112,149,128,147,136,118,105,166,152,117,115,92,128,148,132,170,143,226,190,122,192,165,121,143,144,174,124,113,124,122,135,34,93,118,111,111,136,123,116,99,195,139,99,114,102,96,108,111,112,113,129,172,137,105,139,154,86,113,108,132,79,63,120,93,162,90,103,94,95,117,127,104,100,142,129,93,27,196,153,113,91,101,90,84,68,138,38,118,148,87,103,125,109,96,152,100,56,31,62,176,129,124,115,103,92,100,121,130,125,128,71,82,71,152,85,107,116,138,133,103,116,139,144,72,37,118,141,109,95,86,92,121,167,156,104,92,91,122,114,89,61,172,128,95,103,84,101,88,84,116,125,108,62,74,108,160,143,189,164,91,115,144,43,116,79,106,108,74,83,87,90,61,71,76,76,95,130,89,94,114,107,101,145,161,147,143,163,147,129,101,73,111,108,93,104,186,141,99,89,112,126,111,113,152,41,159,115,131,124,117,101,115,130,124,87,59,177,63,85,109,116,103,68,145,132,29,119,96,89,117,90,181,103,101,111,97,96,199,171,113,120,93,119,101,64,56,55,63,90,105,101,86,45,136,179,142,102,115,114,113,108,121,84,23,125,76,102,119,107,120,104,73,177,83,114,128,85,152,126,137,115,149,109,163,133,110,98,54,61,95,111,135,103,88,164,115,187,122,98,129,132,95,86,71,119,146,111,38,67,102,100,66,148,137,103,145,95,35,85,44,136,102,111,108,115,136,105,120,110,108,147,112,169,116,146,81,120,94,84,93,97,90,119,102,91,48,147,204,151,148,160,144,131,144,175,158,133,212,163,172,152,151,112,148,151,145,179,160,124,164,164,167,161,141,120,131,141,198,177,169,156,146,156,124,185,164,195,181,193,201,147,148,168,165,159,162,148,150,148,146,157,158,149,164,129,160,214,174,166,154,176,146,141,155,140,140,169,106,155,166,162,134,193,157,155,146,196,171,107,177,174,163,155,147,203,162,146,150,83,157,170,180,178,159,157,151,117,115,183,170,180,174,150,177,173,136,181,196,184,164,168,165,148,175,168,209,189,159,114,157,158,141,168,170,139,175,128,151,39,128,154,159,161,148,180,131,165,159,131,163,150,174,178,178,198,172,138,184,191,143,164,161,163,210,171,155,168,150,116,182,170,145,152,141,139,191,149,160,202,145,169,145,181,148,183,197,165,146,171,161,153,157,170,164,149,183,167,246,235,162,144,170,152,173,150,113,135,156,154,158,148,178,159,161,114,180,156,116,163,164,161,122,164,164,183,135,135,144,182,160,147,163,152,169,185,159,177,99,211,168,167,215,170,150,157,154,176,154,143,163,117,178,160,163,165,164,166,174,136,159,169,152,123,199,149,169,140,159,208,155,161,186,122,134,167,171,145,148,176,148,137,114,160,166,153,162,156,164,172,155,148,155,182,114,150,157,154,140,159,166,160,169,206,182,145,157,165,147,202,131,154,193,162,162,149,167,157,191,188,149,205,147,166,150,150,159,153,171,160,111,34,114,63,134,244,114,63,33,174,115,63,106,84,116,63,18,235,116,63,206,116,117,63,177,243,117,63,83,105,118,63,251,214,118,63,175,61,119,63,69,158,119,63,112,249,119,63,197,79,120,63,194,161,120,63,211,239,120,63,84,58,121,63,151,129,121,63,224,197,121,63,111,7,122,63,121,70,122,63,46,131,122,63,186,189,122,63,68,246,122,63,236,44,123,63,212,97,123,63,23,149,123,63,207,198,123,63,19,247,123,63,249,37,124,63,148,83,124,63,246,127,124,63,48,171,124,63,81,213,124,63,102,254,124,63,126,38,125,63,164,77,125,63,227,115,125,63,71,153,125,63,216,189,125,63,160,225,125,63,167,4,126,63,246,38,126,63,148,72,126,63,136,105,126,63,216,137,126,63,140,169,126,63,169,200,126,63,52,231,126,63,51,5,127,63,171,34,127,63,161,63,127,63,24,92,127,63,22,120,127,63,158,147,127,63,180,174,127,63,92,201,127,63,154,227,127,63,112,253,127,63,113,11,128,63,250,23,128,63,83,36,128,63,126,48,128,63,126,60,128,63,82,72,128,63,31,5,101,63,55,147,102,63,8,244,103,63,7,49,105,63,242,80,106,63,200,88,107,63,88,76,108,63,151,46,109,63,222,1,110,63,22,200,110,63,203,130,111,63,73,51,112,63,167,218,112,63,206,121,113,63,137,17,114,63,133,162,114,63,89,45,115,63,136,178,115,63,133,50,116,63,184,173,116,63,122,36,117,63,29,151,117,63,233,5,118,63,32,113,118,63,252,216,118,63,179,61,119,63,117,159,119,63,110,254,119,63,200,90,120,63,167,180,120,63,45,12,121,63,121,97,121,63,168,180,121,63,214,5,122,63,27,85,122,63,141,162,122,63,68,238,122,63,81,56,123,63,201,128,123,63,188,199,123,63,59,13,124,63,86,81,124,63,26,148,124,63,149,213,124,63,212,21,125,63,227,84,125,63,204,146,125,63,156,207,125,63,92,11,126,63,22,70,126,63,210,127,126,63,153,184,126,63,116,240,126,63,106,39,127,63,130,93,127,63,196,146,127,63,55,199,127,63,224,250,127,63,227,22,128,63,248,47,128,63,176,72,128,63,15,97,128,63,24,121,128,63,204,144,128,63,166,157,88,63,103,211,90,63,105,202,92,63,159,143,94,63,79,44,96,63,90,167,97,63,0,6,99,63,90,76,100,63,171,125,101,63,149,156,102,63,69,171,103,63,135,171,104,63,222,158,105,63,149,134,106,63,195,99,107,63,92,55,108,63,52,2,109,63,4,197,109,63,109,128,110,63,0,53,111,63,61,227,111,63,149,139,112,63,112,46,113,63,41,204,113,63,20,101,114,63,123,249,114,63,165,137,115,63,208,21,116,63,52,158,116,63,7,35,117,63,121,164,117,63,182,34,118,63,232,157,118,63,52,22,119,63,191,139,119,63,169,254,119,63,17,111,120,63,18,221,120,63,200,72,121,63,76,178,121,63,181,25,122,63,25,127,122,63,141,226,122,63,35,68,123,63,239,163,123,63,1,2,124,63,105,94,124,63,55,185,124,63,122,18,125,63,63,106,125,63,147,192,125,63,131,21,126,63,26,105,126,63,99,187,126,63,106,12,127,63,56,92,127,63,215,170,127,63,80,248,127,63,86,34,128,63,250,71,128,63,24,109,128,63,178,145,128,63,207,181,128,63,112,217,128,63,42,226,76,63,219,172,79,63,80,42,82,63,71,106,84,63,19,120,86,63,31,92,88,63,217,28,90,63,76,191,91,63,122,71,93,63,165,184,94,63,122,21,96,63,52,96,97,63,179,154,98,63,144,198,99,63,41,229,100,63,171,247,101,63,31,255,102,63,106,252,103,63,88,240,104,63,156,219,105,63,214,190,106,63,150,154,107,63,92,111,108,63,155,61,109,63,188,5,110,63,29,200,110,63,23,133,111,63,246,60,112,63,4,240,112,63,131,158,113,63,175,72,114,63,194,238,114,63,239,144,115,63,102,47,116,63,85,202,116,63,228,97,117,63,58,246,117,63,124,135,118,63,203,21,119,63,71,161,119,63,14,42,120,63,59,176,120,63,232,51,121,63,47,181,121,63,38,52,122,63,228,176,122,63,124,43,123,63,3,164,123,63,139,26,124,63,38,143,124,63,228,1,125,63,213,114,125,63,8,226,125,63,139,79,126,63,108,187,126,63,184,37,127,63,123,142,127,63,193,245,127,63,202,45,128,63,1,96,128,63,137,145,128,63,104,194,128,63,162,242,128,63,60,34,129,63,91,201,65,63,197,23,69,63,29,13,72,63,87,187,74,63,97,47,77,63,226,114,79,63,60,141,81,63,59,132,83,63,129,92,85,63,209,25,87,63,66,191,88,63,108,79,90,63,122,204,91,63,72,56,93,63,110,148,94,63,75,226,95,63,19,35,97,63,212,87,98,63,121,129,99,63,215,160,100,63,167,182,101,63,147,195,102,63,49,200,103,63,8,197,104,63,148,186,105,63,69,169,106,63,128,145,107,63,162,115,108,63,1,80,109,63,235,38,110,63,168,248,110,63,122,197,111,63,160,141,112,63,81,81,113,63,196,16,114,63,41,204,114,63,175,131,115,63,128,55,116,63,197,231,116,63,162,148,117,63,60,62,118,63,179,228,118,63,39,136,119,63,180,40,120,63,120,198,120,63,138,97,121,63,5,250,121,63,0,144,122,63,144,35,123,63,203,180,123,63,196,67,124,63,143,208,124,63,61,91,125,63,224,227,125,63,135,106,126,63,67,239,126,63,33,114,127,63,49,243,127,63,64,57,128,63,13,120,128,63,6,182,128,63,48,243,128,63,146,47,129,63,50,107,129,63,105,74,55,63,186,12,59,63,133,108,62,63,105,125,65,63,146,77,68,63,153,231,70,63,164,83,73,63,23,152,75,63,17,186,77,63,188,189,79,63,137,166,81,63,88,119,83,63,148,50,85,63,78,218,86,63,78,112,88,63,30,246,89,63,21,109,91,63,97,214,92,63,12,51,94,63,2,132,95,63,22,202,96,63,4,6,98,63,119,56,99,63,8,98,100,63,65,131,101,63,161,156,102,63,154,174,103,63,150,185,104,63,245,189,105,63,16,188,106,63,56,180,107,63,186,166,108,63,219,147,109,63,219,123,110,63,247,94,111,63,104,61,112,63,96,23,113,63,18,237,113,63,171,190,114,63,85,140,115,63,57,86,116,63,125,28,117,63,68,223,117,63,175,158,118,63,223,90,119,63,241,19,120,63,1,202,120,63,43,125,121,63,134,45,122,63,44,219,122,63,51,134,123,63,177,46,124,63,186,212,124,63,98,120,125,63,188,25,126,63,217,184,126,63,203,85,127,63,161,240,127,63,182,68,128,63,29,144,128,63,140,218,128,63,11,36,129,63,160,108,129,63,80,180,129,63,254,92,45,63,177,132,49,63,136,66,53,63,85,171,56,63,48,206,59,63,103,182,62,63,177,108,65,63,233,247,67,63,143,93,70,63,30,162,72,63,76,201,74,63,49,214,76,63,110,203,78,63,62,171,80,63,143,119,82,63,13,50,84,63,45,220,85,63,55,119,87,63,77,4,89,63,113,132,90,63,137,248,91,63,99,97,93,63,185,191,94,63,50,20,96,63,102,95,97,63,224,161,98,63,29,220,99,63,146,14,101,63,169,57,102,63,194,93,103,63,57,123,104,63,95,146,105,63,130,163,106,63,234,174,107,63,216,180,108,63,140,181,109,63,62,177,110,63,36,168,111,63,114,154,112,63,86,136,113,63,253,113,114,63,145,87,115,63,58,57,116,63,28,23,117,63,90,241,117,63,22,200,118,63,111,155,119,63,131,107,120,63,110,56,121,63,74,2,122,63,49,201,122,63,59,141,123,63,127,78,124,63,18,13,125,63,11,201,125,63,123,130,126,63,120,57,127,63,18,238,127,63,45,80,128,63,49,168,128,63,29,255,128,63,248,84,129,63,201,169,129,63,153,253,129,63,58,249,35,63,255,120,40,63,114,137,44,63,50,64,48,63,249,172,51,63,149,219,54,63,38,213,57,63,219,160,60,63,124,68,63,63,195,196,65,63,151,37,68,63,64,106,70,63,130,149,72,63,190,169,74,63,254,168,76,63,8,149,78,63,105,111,80,63,128,57,82,63,128,244,83,63,126,161,85,63,110,65,87,63,45,213,88,63,129,93,90,63,31,219,91,63,169,78,93,63,179,184,94,63,197,25,96,63,92,114,97,63,233,194,98,63,212,11,100,63,128,77,101,63,70,136,102,63,120,188,103,63,100,234,104,63,81,18,106,63,131,52,107,63,55,81,108,63,169,104,109,63,15,123,110,63,156,136,111,63,129,145,112,63,235,149,113,63,4,150,114,63,246,145,115,63,230,137,116,63,247,125,117,63,77,110,118,63,8,91,119,63,69,68,120,63,35,42,121,63,188,12,122,63,44,236,122,63,138,200,123,63,240,161,124,63,115,120,125,63,41,76,126,63,40,29,127,63,130,235,127,63,165,91,128,63,74,192,128,63,184,35,129,63,248,133,129,63,16,231,129,63,10,71,130,63,168,23,27,63,77,227,31,63,210,59,36,63,78,55,40,63,217,229,43,63,149,83,47,63,227,137,50,63,45,144,53,63,110,108,56,63,136,35,59,63,137,185,61,63,216,49,64,63,87,143,66,63,126,212,68,63,112,3,71,63,6,30,73,63,224,37,75,63,108,28,77,63,237,2,79,63,132,218,80,63,51,164,82,63,225,96,84,63,96,17,86,63,108,182,87,63,178,80,89,63,205,224,90,63,78,103,92,63,182,228,93,63,128,89,95,63,25,198,96,63,232,42,98,63,77,136,99,63,159,222,100,63,48,46,102,63,76,119,103,63,59,186,104,63,62,247,105,63,148,46,107,63,120,96,108,63,31,141,109,63,189,180,110,63,131,215,111,63,159,245,112,63,58,15,114,63,126,36,115,63,146,53,116,63,153,66,117,63,183,75,118,63,12,81,119,63,183,82,120,63,214,80,121,63,132,75,122,63,221,66,123,63,251,54,124,63,245,39,125,63,227,21,126,63,219,0,127,63,242,232,127,63,31,103,128,63,104,216,128,63,94,72,129,63,10,183,129,63,116,36,130,63,165,144,130,63,57,177,18,63,151,189,23,63,126,84,28,63,46,140,32,63,235,116,36,63,253,26,40,63,234,135,43,63,62,195,46,63,17,211,49,63,95,188,52,63,79,131,55,63,92,43,58,63,124,183,60,63,57,42,63,63,197,133,65,63,7,204,67,63,173,254,69,63,48,31,72,63,222,46,74,63,227,46,76,63,74,32,78,63,2,4,80,63,229,218,81,63,183,165,83,63,42,101,85,63,226,25,87,63,116,196,88,63,103,101,90,63,59,253,91,63,99,140,93,63,73,19,95,63,82,146,96,63,218,9,98,63,53,122,99,63,180,227,100,63,161,70,102,63,66,163,103,63,216,249,104,63,161,74,106,63,213,149,107,63,170,219,108,63,85,28,110,63,3,88,111,63,228,142,112,63,33,193,113,63,228,238,114,63,82,24,116,63,144,61,117,63,193,94,118,63,5,124,119,63,124,149,120,63,67,171,121,63,119,189,122,63,51,204,123,63,144,215,124,63,168,223,125,63,145,228,126,63,99,230,127,63,153,114,128,63,138,240,128,63,14,109,129,63,47,232,129,63,245,97,130,63,106,218,130,63,67,191,10,63,41,2,16,63,137,206,20,63,141,58,25,63,115,86,29,63,136,46,33,63,91,204,36,63,133,55,40,63,39,118,43,63,76,141,46,63,38,129,49,63,59,85,52,63,142,12,55,63,178,169,57,63,226,46,60,63,16,158,62,63,240,248,64,63,5,65,67,63,164,119,69,63,255,157,71,63,40,181,73,63,20,190,75,63,163,185,77,63,158,168,79,63,189,139,81,63,166,99,83,63,245,48,85,63,53,244,86,63,232,173,88,63,134,94,90,63,125,6,92,63,53,166,93,63,12,62,95,63,90,206,96,63,115,87,98,63,164,217,99,63,52,85,101,63,104,202,102,63,127,57,104,63,181,162,105,63,65,6,107,63,89,100,108,63,46,189,109,63,240,16,111,63,204,95,112,63,235,169,113,63,118,239,114,63,146,48,116,63,99,109,117,63,13,166,118,63,175,218,119,63,105,11,121,63,88,56,122,63,152,97,123,63,69,135,124,63,120,169,125,63,74,200,126,63,211,227,127,63,20,126,128,63,176,8,129,63,200,145,129,63,102,25,130,63,147,159,130,63,88,36,131,63,119,59,3,63,152,171,8,63,68,165,13,63,85,62,18,63,222,134,22,63,19,139,26,63,115,84,30,63,143,234,33,63,134,83,37,63,99,148,40,63,89,177,43,63,242,173,46,63,52,141,49,63,181,81,52,63,182,253,54,63,44,147,57,63,209,19,60,63,42,129,62,63,146,220,64,63,63,39,67,63,69,98,69,63,160,142,71,63,48,173,73,63,196,190,75,63,22,196,77,63,208,189,79,63,144,172,81,63,230,144,83,63,84,107,85,63,87,60,87,63,94,4,89,63,212,195,90,63,24,123,92,63,135,42,94,63,117,210,95,63,49,115,97,63,5,13,99,63,56,160,100,63,9,45,102,63,182,179,103,63,122,52,105,63,138,175,106,63,26,37,108,63,91,149,109,63,123,0,111,63,165,102,112,63,2,200,113,63,186,36,115,63,242,124,116,63,206,208,117,63,111,32,119,63,245,107,120,63,127,179,121,63,43,247,122,63,20,55,124,63,85,115,125,63,7,172,126,63,67,225,127,63,145,137,128,63,220,32,129,63,141,182,129,63,176,74,130,63,78,221,130,63,112,110,131,63,182,108,216,178,102,198,150,54,54,0,0,0,0,0,0,0,255,127,127,255,0,0,0,0,255,255,255,255,0,0,0,0,235,128,128,255,0,0,0,0,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,0,0,0,0,0,0,160,63,0,0,0,0,0,0,176,63,0,0,0,0,0,0,184,63,0,0,0,0,0,0,192,63,0,0,0,0,0,0,196,63,0,0,0,0,0,0,200,63,0,0,0,0,0,0,204,63,0,0,0,0,0,0,208,63,0,0,0,0,0,0,210,63,0,0,0,0,0,0,212,63,0,0,0,0,0,0,214,63,0,0,0,0,0,0,216,63,0,0,0,0,0,0,218,63,0,0,0,0,0,0,220,63,0,0,0,0,0,0,222,63,0,0,0,0,0,0,224,63,0,0,0,0,0,0,225,63,0,0,0,0,0,0,226,63,0,0,0,0,0,0,227,63,0,0,0,0,0,0,228,63,0,0,0,0,0,0,229,63,0,0,0,0,0,0,230,63,0,0,0,0,0,0,231,63,0,0,0,0,0,0,232,63,0,0,0,0,0,0,233,63,0,0,0,0,0,0,234,63,0,0,0,0,0,0,235,63,0,0,0,0,0,0,236,63,0,0,0,0,0,0,237,63,0,0,0,0,0,0,238,63,0,0,0,0,0,0,239,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+143360);
/* memory initializer */ allocate([0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,123,20,174,71,225,122,148,63,0,0,0,0,0,0,160,63,0,0,0,0,0,0,176,63,0,0,0,0,0,0,184,63,0,0,0,0,0,0,192,63,0,0,0,0,0,0,196,63,0,0,0,0,0,0,200,63,0,0,0,0,0,0,204,63,0,0,0,0,0,0,208,63,0,0,0,0,0,0,210,63,0,0,0,0,0,0,212,63,0,0,0,0,0,0,214,63,0,0,0,0,0,0,216,63,0,0,0,0,0,0,218,63,0,0,0,0,0,0,220,63,0,0,0,0,0,0,222,63,0,0,0,0,0,0,224,63,0,0,0,0,0,0,225,63,0,0,0,0,0,0,226,63,0,0,0,0,0,0,227,63,0,0,0,0,0,0,228,63,0,0,0,0,0,0,229,63,0,0,0,0,0,0,230,63,0,0,0,0,0,0,231,63,0,0,0,0,0,0,232,63,0,0,0,0,0,0,233,63,0,0,0,0,0,0,234,63,0,0,0,0,0,0,235,63,0,0,0,0,0,0,236,63,0,0,0,0,0,0,237,63,0,0,0,0,0,0,238,63,0,0,0,0,0,0,239,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,72,48,34,0,16,144,33,0,160,20,33,0,64,172,32,0,128,80,32,0,48,56,40,0,0,220,39,0,0,116,39,0,160,34,39,0,248,219,38,0,0,151,38,0,192,91,38,0,80,38,38,0,240,244,37,0,48,201,37,0,24,165,37,0,112,249,39,0,112,0,0,0,208,192,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,227,37,0,112,0,0,0,240,124,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,144,33,0,112,0,0,0,64,156,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,0,0,0,61,1,0,0,4,0,0,0,0,0,0,0,5,0,0,0,33,0,0,0,7,0,0,0,6,0,0,0,34,0,0,0,64,1,0,0,12,0,0,0,13,0,0,0,14,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,8,0,0,0,255,255,255,255,192,120,36,0,112,0,0,0,240,193,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,56,33,0,88,202,32,0,200,108,32,0,200,84,40,0,200,249,39,0,96,143,39,0,160,54,39,0,160,240,38,0,0,0,0,0,0,0,0,0,216,76,35,0,112,0,0,0,80,176,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,1,0,0,239,0,0,0,239,0,0,0,213,0,0,0,0,0,0,0,224,0,0,0,224,0,0,0,152,0,0,0,0,0,0,0,135,0,0,0,135,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,0,0,54,1,0,0,54,1,0,0,24,1,0,0,0,0,0,0,64,1,0,0,64,1,0,0,228,0,0,0,0,0,0,0,175,0,0,0,175,0,0,0,136,0,0,0,0,0,0,0,129,0,0,0,129,0,0,0,102,0,0,0,19,1,0,0,245,0,0,0,245,0,0,0,218,0,0,0,0,0,0,0,230,0,0,0,230,0,0,0,156,0,0,0,0,0,0,0,138,0,0,0,138,0,0,0,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,1,0,0,61,1,0,0,61,1,0,0,30,1,0,0,0,0,0,0,72,1,0,0,72,1,0,0,233,0,0,0,0,0,0,0,180,0,0,0,180,0,0,0,140,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,105,0,0,0,32,94,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,8,0,0,8,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,226,36,0,168,171,35,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,176,226,36,0,48,202,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,176,226,36,0,48,10,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,176,226,36,0,208,115,33,0,24,251,32,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,208,115,33,0,136,151,32,0,96,60,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,115,33,0,168,34,40,0,56,194,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,115,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,94,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,122,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,225,34,0,112,0,0,0,128,101,2,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,63,120,51,98,136,11,53,151,200,193,53,80,233,61,54,183,247,156,54,46,124,234,54,153,192,35,55,244,2,90,55,56,3,140,55,227,228,174,55,177,166,213,55,108,36,0,56,146,101,23,56,201,150,48,56,18,184,75,56,81,201,104,56,94,229,131,56,29,94,148,56,229,206,165,56,167,55,184,56,128,152,203,56,85,241,223,56,36,66,245,56,126,197,5,57,238,101,17,57,99,130,29,57,207,26,42,57,63,47,55,57,179,191,68,57,30,204,82,57,141,84,97,57,243,88,112,57,94,217,127,57,227,234,135,57,18,39,144,57,64,161,152,57,105,89,161,57,146,79,170,57,181,131,179,57,215,245,188,57,245,165,198,57,14,148,208,57,34,192,218,57,46,42,229,57,57,210,239,57,60,184,250,57,27,238,2,58,22,159,8,58,13,111,14,58,0,94,20,58,239,107,26,58,218,152,32,58,192,228,38,58,161,79,45,58,124,217,51,58,83,130,58,58,37,74,65,58,240,48,72,58,182,54,79,58,116,91,86,58,45,159,93,58,222,1,101,58,136,131,108,58,42,36,116,58,196,227,123,58,44,225,129,58,241,223,133,58,49,238,137,58,238,11,142,58,37,57,146,58,215,117,150,58,5,194,154,58,174,29,159,58,209,136,163,58,110,3,168,58,134,141,172,58,24,39,177,58,36,208,181,58,169,136,186,58,169,80,191,58,33,40,196,58,19,15,201,58,126,5,206,58,98,11,211,58,191,32,216,58,148,69,221,58,225,121,226,58,166,189,231,58,227,16,237,58,152,115,242,58,196,229,247,58,103,103,253,58,65,124,1,59,137,76,4,59,141,36,7,59,76,4,10,59,198,235,12,59,251,218,15,59,235,209,18,59,149,208,21,59,251,214,24,59,26,229,27,59,244,250,30,59,136,24,34,59,215,61,37,59,223,106,40,59,161,159,43,59,29,220,46,59,83,32,50,59,66,108,53,59,234,191,56,59,76,27,60,59,103,126,63,59,59,233,66,59,199,91,70,59,12,214,73,59,10,88,77,59,193,225,80,59,48,115,84,59,86,12,88,59,53,173,91,59,204,85,95,59,26,6,99,59,32,190,102,59,222,125,106,59,82,69,110,59,127,20,114,59,97,235,117,59,251,201,121,59,76,176,125,59,41,207,128,59,8,202,130,59,194,200,132,59,87,203,134,59,198,209,136,59,17,220,138,59,55,234,140,59,55,252,142,59,18,18,145,59,199,43,147,59,87,73,149,59,194,106,151,59,6,144,153,59,37,185,155,59,30,230,157,59,241,22,160,59,158,75,162,59,37,132,164,59,134,192,166,59,192,0,169,59,212,68,171,59,193,140,173,59,137,216,175,59,41,40,178,59,163,123,180,59,245,210,182,59,33,46,185,59,38,141,187,59,4,240,189,59,186,86,192,59,73,193,194,59,177,47,197,59,242,161,199,59,10,24,202,59,251,145,204,59,196,15,207,59,102,145,209,59,223,22,212,59,49,160,214,59,90,45,217,59,91,190,219,59,51,83,222,59,227,235,224,59,107,136,227,59,201,40,230,59,255,204,232,59,12,117,235,59,240,32,238,59,171,208,240,59,61,132,243,59,165,59,246,59,228,246,248,59,250,181,251,59,229,120,254,59,212,159,0,60,32,5,2,60,87,108,3,60,121,213,4,60,134,64,6,60,126,173,7,60,96,28,9,60,45,141,10,60,229,255,11,60,136,116,13,60,21,235,14,60,141,99,16,60,239,221,17,60,59,90,19,60,114,216,20,60,147,88,22,60,158,218,23,60,147,94,25,60,115,228,26,60,60,108,28,60,240,245,29,60,141,129,31,60,20,15,33,60,133,158,34,60,224,47,36,60,36,195,37,60,82,88,39,60,105,239,40,60,106,136,42,60,84,35,44,60,40,192,45,60,229,94,47,60,139,255,48,60,26,162,50,60,146,70,52,60,243,236,53,60,61,149,55,60,112,63,57,60,140,235,58,60,145,153,60,60,126,73,62,60,84,251,63,60,18,175,65,60,185,100,67,60,72,28,69,60,192,213,70,60,31,145,72,60,103,78,74,60,151,13,76,60,175,206,77,60,176,145,79,60,152,86,81,60,103,29,83,60,31,230,84,60,190,176,86,60,69,125,88,60,179,75,90,60,9,28,92,60,71,238,93,60,107,194,95,60,119,152,97,60,106,112,99,60,68,74,101,60,5,38,103,60,173,3,105,60,60,227,106,60,178,196,108,60,14,168,110,60,81,141,112,60,123,116,114,60,139,93,116,60,130,72,118,60,95,53,120,60,34,36,122,60,203,20,124,60,90,7,126,60,208,251,127,60,22,249,128,60,54,245,129,60,74,242,130,60,80,240,131,60,73,239,132,60,53,239,133,60,19,240,134,60,229,241,135,60,169,244,136,60,95,248,137,60,8,253,138,60,164,2,140,60,50,9,141,60,178,16,142,60,37,25,143,60,139,34,144,60,226,44,145,60,44,56,146,60,104,68,147,60,150,81,148,60,182,95,149,60,201,110,150,60,205,126,151,60,196,143,152,60,172,161,153,60,135,180,154,60,83,200,155,60,17,221,156,60,193,242,157,60,98,9,159,60,245,32,160,60,122,57,161,60,241,82,162,60,89,109,163,60,178,136,164,60,253,164,165,60,57,194,166,60,103,224,167,60,134,255,168,60,151,31,170,60,152,64,171,60,139,98,172,60,111,133,173,60,68,169,174,60,10,206,175,60,193,243,176,60,105,26,178,60,2,66,179,60,139,106,180,60,6,148,181,60,113,190,182,60,205,233,183,60,26,22,185,60,87,67,186,60,133,113,187,60,163,160,188,60,177,208,189,60,177,1,191,60,160,51,192,60,128,102,193,60,80,154,194,60,16,207,195,60,193,4,197,60,97,59,198,60,242,114,199,60,114,171,200,60,227,228,201,60,67,31,203,60,147,90,204,60,211,150,205,60,3,212,206,60,34,18,208,60,49,81,209,60,48,145,210,60,30,210,211,60,252,19,213,60,201,86,214,60,133,154,215,60,49,223,216,60,204,36,218,60,86,107,219,60,208,178,220,60,56,251,221,60,144,68,223,60,214,142,224,60,12,218,225,60,48,38,227,60,67,115,228,60,69,193,229,60,54,16,231,60,21,96,232,60,227,176,233,60,160,2,235,60,75,85,236,60,228,168,237,60,108,253,238,60,226,82,240,60,70,169,241,60,153,0,243,60,218,88,244,60,8,178,245,60,37,12,247,60,48,103,248,60,41,195,249,60,15,32,251,60,228,125,252,60,166,220,253,60,85,60,255,60,121,78,0,61,63,255,0,61,123,176,1,61,46,98,2,61,88,20,3,61,248,198,3,61,15,122,4,61,156,45,5,61,161,225,5,61,27,150,6,61,12,75,7,61,116,0,8,61,82,182,8,61,167,108,9,61,113,35,10,61,179,218,10,61,106,146,11,61,152,74,12,61,60,3,13,61,87,188,13,61,231,117,14,61,238,47,15,61,107,234,15,61,94,165,16,61,199,96,17,61,166,28,18,61,251,216,18,61,198,149,19,61,7,83,20,61,190,16,21,61,234,206,21,61,141,141,22,61,165,76,23,61,52,12,24,61,56,204,24,61,177,140,25,61,161,77,26,61,6,15,27,61,224,208,27,61,48,147,28,61,246,85,29,61,49,25,30,61,226,220,30,61,8,161,31,61,164,101,32,61,181,42,33,61,59,240,33,61,55,182,34,61,168,124,35,61,142,67,36,61,233,10,37,61,186,210,37,61,255,154,38,61,186,99,39,61,234,44,40,61,143,246,40,61,168,192,41,61,55,139,42,61,59,86,43,61,180,33,44,61,161,237,44,61,4,186,45,61,219,134,46,61,38,84,47,61,231,33,48,61,28,240,48,61,198,190,49,61,229,141,50,61,120,93,51,61,127,45,52,61,251,253,52,61,236,206,53,61,81,160,54,61,42,114,55,61,120,68,56,61,58,23,57,61,112,234,57,61,27,190,58,61,58,146,59,61,204,102,60,61,211,59,61,61,79,17,62,61,62,231,62,61,161,189,63,61,120,148,64,61,195,107,65,61,130,67,66,61,181,27,67,61,92,244,67,61,118,205,68,61,4,167,69,61,6,129,70,61,124,91,71,61,101,54,72,61,194,17,73,61,146,237,73,61,214,201,74,61,141,166,75,61,184,131,76,61,86,97,77,61,104,63,78,61,236,29,79,61,229,252,79,61,80,220,80,61,46,188,81,61,128,156,82,61,69,125,83,61,125,94,84,61,40,64,85,61,69,34,86,61,214,4,87,61,218,231,87,61,81,203,88,61,58,175,89,61,150,147,90,61,101,120,91,61,167,93,92,61,91,67,93,61,130,41,94,61,28,16,95,61,40,247,95,61,167,222,96,61,152,198,97,61,251,174,98,61,209,151,99,61,25,129,100,61,212,106,101,61,0,85,102,61,159,63,103,61,176,42,104,61,51,22,105,61,41,2,106,61,144,238,106,61,105,219,107,61,180,200,108,61,113,182,109,61,160,164,110,61,65,147,111,61,84,130,112,61,216,113,113,61,206,97,114,61,54,82,115,61,15,67,116,61,89,52,117,61,22,38,118,61,67,24,119,61,226,10,120,61,243,253,120,61,117,241,121,61,104,229,122,61,204,217,123,61,162,206,124,61,232,195,125,61,160,185,126,61,201,175,127,61,49,83,128,61,183,206,128,61,117,74,129,61,107,198,129,61,154,66,130,61,1,191,130,61,160,59,131,61,120,184,131,61,136,53,132,61,209,178,132,61,81,48,133,61,10,174,133,61,251,43,134,61,37,170,134,61,134,40,135,61,32,167,135,61,242,37,136,61,252,164,136,61,62,36,137,61,184,163,137,61,106,35,138,61,84,163,138,61,118,35,139,61,209,163,139,61,99,36,140,61,45,165,140,61,46,38,141,61,104,167,141,61,218,40,142,61,131,170,142,61,100,44,143,61,125,174,143,61,206,48,144,61,86,179,144,61,23,54,145,61,14,185,145,61,62,60,146,61,165,191,146,61,67,67,147,61,26,199,147,61,39,75,148,61,109,207,148,61,234,83,149,61,158,216,149,61,138,93,150,61,173,226,150,61,7,104,151,61,153,237,151,61,98,115,152,61,99,249,152,61,155,127,153,61,10,6,154,61,176,140,154,61,142,19,155,61,163,154,155,61,239,33,156,61,114,169,156,61,44,49,157,61,29,185,157,61,69,65,158,61,165,201,158,61,59,82,159,61,8,219,159,61,13,100,160,61,72,237,160,61,186,118,161,61,99,0,162,61,67,138,162,61,90,20,163,61,167,158,163,61,43,41,164,61,230,179,164,61,216,62,165,61,0,202,165,61,95,85,166,61,245,224,166,61,193,108,167,61,196,248,167,61,254,132,168,61,110,17,169,61,20,158,169,61,241,42,170,61,4,184,170,61,78,69,171,61,206,210,171,61,133,96,172,61,113,238,172,61,149,124,173,61,238,10,174,61,126,153,174,61,67,40,175,61,63,183,175,61,114,70,176,61,218,213,176,61,120,101,177,61,77,245,177,61,88,133,178,61,152,21,179,61,15,166,179,61,187,54,180,61,158,199,180,61,182,88,181,61,4,234,181,61,137,123,182,61,67,13,183,61,50,159,183,61,88,49,184,61,179,195,184,61,68,86,185,61,11,233,185,61,7,124,186,61,57,15,187,61,160,162,187,61,61,54,188,61,16,202,188,61,24,94,189,61,85,242,189,61,200,134,190,61,112,27,191,61,78,176,191,61,97,69,192,61,170,218,192,61,39,112,193,61,218,5,194,61,194,155,194,61,224,49,195,61,50,200,195,61,186,94,196,61,119,245,196,61,104,140,197,61,143,35,198,61,235,186,198,61,124,82,199,61,66,234,199,61,61,130,200,61,108,26,201,61,209,178,201,61,106,75,202,61,57,228,202,61,59,125,203,61,115,22,204,61,224,175,204,61,129,73,205,61,86,227,205,61,97,125,206,61,159,23,207,61,19,178,207,61,187,76,208,61,151,231,208,61,168,130,209,61,237,29,210,61,103,185,210,61,21,85,211,61,248,240,211,61,14,141,212,61,89,41,213,61,216,197,213,61,140,98,214,61,115,255,214,61,143,156,215,61,223,57,216,61,99,215,216,61,27,117,217,61,7,19,218,61,38,177,218,61,122,79,219,61,2,238,219,61,189,140,220,61,173,43,221,61,208,202,221,61,39,106,222,61,178,9,223,61,112,169,223,61,98,73,224,61,136,233,224,61,226,137,225,61,111,42,226,61,47,203,226,61,35,108,227,61,74,13,228,61,165,174,228,61,52,80,229,61,245,241,229,61,234,147,230,61,19,54,231,61,110,216,231,61,253,122,232,61,191,29,233,61,180,192,233,61,221,99,234,61,56,7,235,61,199,170,235,61,136,78,236,61,125,242,236,61,164,150,237,61,255,58,238,61,140,223,238,61,76,132,239,61,63,41,240,61,101,206,240,61,189,115,241,61,73,25,242,61,7,191,242,61,247,100,243,61,26,11,244,61,112,177,244,61,248,87,245,61,179,254,245,61,160,165,246,61,192,76,247,61,18,244,247,61,151,155,248,61,77,67,249,61,55,235,249,61,82,147,250,61,159,59,251,61,31,228,251,61,209,140,252,61,181,53,253,61,203,222,253,61,19,136,254,61,141,49,255,61,57,219,255,61,140,66,0,62,148,151,0,62,181,236,0,62,238,65,1,62,65,151,1,62,173,236,1,62,49,66,2,62,206,151,2,62,132,237,2,62,83,67,3,62,59,153,3,62,59,239,3,62,84,69,4,62,134,155,4,62,209,241,4,62,52,72,5,62,176,158,5,62,68,245,5,62,242,75,6,62,183,162,6,62,150,249,6,62,141,80,7,62,156,167,7,62,196,254,7,62,5,86,8,62,94,173,8,62,207,4,9,62,89,92,9,62,252,179,9,62,183,11,10,62,138,99,10,62,118,187,10,62,122,19,11,62,150,107,11,62,203,195,11,62,24,28,12,62,125,116,12,62,250,204,12,62,144,37,13,62,62,126,13,62,4,215,13,62,227,47,14,62,217,136,14,62,232,225,14,62,15,59,15,62,78,148,15,62,165,237,15,62,20,71,16,62,155,160,16,62,58,250,16,62,241,83,17,62,193,173,17,62,168,7,18,62,167,97,18,62,190,187,18,62,237,21,19,62,51,112,19,62,146,202,19,62,9,37,20,62,151,127,20,62,61,218,20,62,251,52,21,62,209,143,21,62,190,234,21,62,195,69,22,62,224,160,22,62,21,252,22,62,97,87,23,62,197,178,23,62,64,14,24,62,211,105,24,62,126,197,24,62,64,33,25,62,26,125,25,62,11,217,25,62,20,53,26,62,52,145,26,62,108,237,26,62,187,73,27,62,34,166,27,62,160,2,28,62,53,95,28,62,226,187,28,62,166,24,29,62,129,117,29,62,116,210,29,62,126,47,30,62,159,140,30,62,215,233,30,62,39,71,31,62,141,164,31,62,11,2,32,62,160,95,32,62,76,189,32,62,16,27,33,62,234,120,33,62,219,214,33,62,228,52,34,62,3,147,34,62,58,241,34,62,135,79,35,62,235,173,35,62,103,12,36,62,249,106,36,62,162,201,36,62,98,40,37,62,56,135,37,62,38,230,37,62,42,69,38,62,69,164,38,62,119,3,39,62,192,98,39,62,31,194,39,62,149,33,40,62,33,129,40,62,197,224,40,62,126,64,41,62,79,160,41,62,54,0,42,62,51,96,42,62,72,192,42,62,114,32,43,62,179,128,43,62,11,225,43,62,121,65,44,62,253,161,44,62,152,2,45,62,73,99,45,62,16,196,45,62,238,36,46,62,226,133,46,62,237,230,46,62,13,72,47,62,68,169,47,62,145,10,48,62,245,107,48,62,110,205,48,62,254,46,49,62,163,144,49,62,95,242,49,62,49,84,50,62,25,182,50,62,23,24,51,62,43,122,51,62,85,220,51,62,148,62,52,62,234,160,52,62,86,3,53,62,216,101,53,62,111,200,53,62,28,43,54,62,223,141,54,62,184,240,54,62,167,83,55,62,171,182,55,62,197,25,56,62,245,124,56,62,59,224,56,62,150,67,57,62,7,167,57,62,141,10,58,62,41,110,58,62,219,209,58,62,162,53,59,62,126,153,59,62,112,253,59,62,120,97,60,62,149,197,60,62,199,41,61,62,15,142,61,62,108,242,61,62,222,86,62,62,102,187,62,62,3,32,63,62,181,132,63,62,125,233,63,62,90,78,64,62,75,179,64,62,83,24,65,62,111,125,65,62,160,226,65,62,231,71,66,62,66,173,66,62,179,18,67,62,57,120,67,62,211,221,67,62,131,67,68,62,71,169,68,62,33,15,69,62,15,117,69,62,18,219,69,62,42,65,70,62,87,167,70,62,153,13,71,62,240,115,71,62,91,218,71,62,219,64,72,62,111,167,72,62,25,14,73,62,215,116,73,62,169,219,73,62,144,66,74,62,140,169,74,62,157,16,75,62,193,119,75,62,251,222,75,62,73,70,76,62,171,173,76,62,34,21,77,62,173,124,77,62,76,228,77,62,0,76,78,62,200,179,78,62,164,27,79,62,149,131,79,62,154,235,79,62,179,83,80,62,225,187,80,62,34,36,81,62,120,140,81,62,225,244,81,62,95,93,82,62,241,197,82,62,151,46,83,62,81,151,83,62,31,0,84,62,1,105,84,62,247,209,84,62,0,59,85,62,30,164,85,62,79,13,86,62,149,118,86,62,238,223,86,62,91,73,87,62,219,178,87,62,112,28,88,62,24,134,88,62,211,239,88,62,163,89,89,62,134,195,89,62,124,45,90,62,134,151,90,62,164,1,91,62,213,107,91,62,26,214,91,62,114,64,92,62,221,170,92,62,92,21,93,62,239,127,93,62,148,234,93,62,77,85,94,62,26,192,94,62,249,42,95,62,236,149,95,62,242,0,96,62,11,108,96,62,55,215,96,62,119,66,97,62,202,173,97,62,47,25,98,62,168,132,98,62,52,240,98,62,210,91,99,62,132,199,99,62,73,51,100,62,32,159,100,62,11,11,101,62,8,119,101,62,24,227,101,62,59,79,102,62,113,187,102,62,186,39,103,62,21,148,103,62,131,0,104,62,3,109,104,62,151,217,104,62,60,70,105,62,245,178,105,62,192,31,106,62,157,140,106,62,141,249,106,62,144,102,107,62,165,211,107,62,204,64,108,62,6,174,108,62,82,27,109,62,176,136,109,62,33,246,109,62,164,99,110,62,57,209,110,62,225,62,111,62,154,172,111,62,102,26,112,62,68,136,112,62,52,246,112,62,55,100,113,62,75,210,113,62,113,64,114,62,169,174,114,62,243,28,115,62,80,139,115,62,190,249,115,62,61,104,116,62,207,214,116,62,115,69,117,62,40,180,117,62,239,34,118,62,200,145,118,62,179,0,119,62,175,111,119,62,189,222,119,62,221,77,120,62,14,189,120,62,80,44,121,62,165,155,121,62,10,11,122,62,130,122,122,62,10,234,122,62,164,89,123,62,80,201,123,62,13,57,124,62,219,168,124,62,186,24,125,62,171,136,125,62,173,248,125,62,192,104,126,62,228,216,126,62,26,73,127,62,96,185,127,62,220,20,128,62,16,77,128,62,77,133,128,62,147,189,128,62,225,245,128,62,55,46,129,62,150,102,129,62,253,158,129,62,109,215,129,62,229,15,130,62,102,72,130,62,238,128,130,62,128,185,130,62,25,242,130,62,187,42,131,62,102,99,131,62,24,156,131,62,211,212,131,62,150,13,132,62,98,70,132,62,53,127,132,62,17,184,132,62,245,240,132,62,226,41,133,62,214,98,133,62,211,155,133,62,216,212,133,62,229,13,134,62,250,70,134,62,23,128,134,62,61,185,134,62,106,242,134,62,160,43,135,62,221,100,135,62,35,158,135,62,112,215,135,62,198,16,136,62,35,74,136,62,137,131,136,62,247,188,136,62,108,246,136,62,233,47,137,62,111,105,137,62,252,162,137,62,145,220,137,62,46,22,138,62,211,79,138,62,127,137,138,62,52,195,138,62,240,252,138,62,180,54,139,62,128,112,139,62,84,170,139,62,47,228,139,62,18,30,140,62,253,87,140,62,239,145,140,62,233,203,140,62,235,5,141,62,245,63,141,62,6,122,141,62,31,180,141,62,63,238,141,62,103,40,142,62,150,98,142,62,205,156,142,62,12,215,142,62,82,17,143,62,159,75,143,62,245,133,143,62,81,192,143,62,181,250,143,62,33,53,144,62,147,111,144,62,14,170,144,62,143,228,144,62,25,31,145,62,169,89,145,62,65,148,145,62,224,206,145,62,134,9,146,62,52,68,146,62,233,126,146,62,165,185,146,62,105,244,146,62,52,47,147,62,6,106,147,62,223,164,147,62,191,223,147,62,167,26,148,62,150,85,148,62,139,144,148,62,136,203,148,62,140,6,149,62,152,65,149,62,170,124,149,62,195,183,149,62,227,242,149,62,11,46,150,62,57,105,150,62,111,164,150,62,171,223,150,62,238,26,151,62,56,86,151,62,138,145,151,62,226,204,151,62,65,8,152,62,167,67,152,62,19,127,152,62,135,186,152,62,1,246,152,62,130,49,153,62,10,109,153,62,153,168,153,62,47,228,153,62,203,31,154,62,110,91,154,62,24,151,154,62,200,210,154,62,127,14,155,62,61,74,155,62,2,134,155,62,205,193,155,62,158,253,155,62,119,57,156,62,85,117,156,62,59,177,156,62,39,237,156,62,25,41,157,62,18,101,157,62,18,161,157,62,24,221,157,62,36,25,158,62,55,85,158,62,80,145,158,62,112,205,158,62,150,9,159,62,195,69,159,62,246,129,159,62,47,190,159,62,111,250,159,62,180,54,160,62,1,115,160,62,83,175,160,62,172,235,160,62,11,40,161,62,112,100,161,62,219,160,161,62,77,221,161,62,196,25,162,62,66,86,162,62,198,146,162,62,81,207,162,62,225,11,163,62,119,72,163,62,20,133,163,62,182,193,163,62,95,254,163,62,13,59,164,62,194,119,164,62,125,180,164,62,61,241,164,62,4,46,165,62,208,106,165,62,162,167,165,62,123,228,165,62,89,33,166,62,61,94,166,62,39,155,166,62,23,216,166,62,12,21,167,62,7,82,167,62,8,143,167,62,15,204,167,62,28,9,168,62,46,70,168,62,70,131,168,62,100,192,168,62,136,253,168,62,177,58,169,62,223,119,169,62,20,181,169,62,78,242,169,62,141,47,170,62,211,108,170,62,29,170,170,62,109,231,170,62,195,36,171,62,31,98,171,62,127,159,171,62,230,220,171,62,81,26,172,62,194,87,172,62,57,149,172,62,181,210,172,62,54,16,173,62,189,77,173,62,73,139,173,62,218,200,173,62,113,6,174,62,13,68,174,62,174,129,174,62,85,191,174,62,0,253,174,62,177,58,175,62,103,120,175,62,35,182,175,62,227,243,175,62,169,49,176,62,116,111,176,62,68,173,176,62,25,235,176,62,243,40,177,62,210,102,177,62,182,164,177,62,160,226,177,62,142,32,178,62,129,94,178,62,121,156,178,62,119,218,178,62,121,24,179,62,128,86,179,62,140,148,179,62,157,210,179,62,178,16,180,62,205,78,180,62,236,140,180,62,16,203,180,62,57,9,181,62,103,71,181,62,154,133,181,62,209,195,181,62,13,2,182,62,78,64,182,62,147,126,182,62,221,188,182,62,44,251,182,62,127,57,183,62,215,119,183,62,52,182,183,62,149,244,183,62,251,50,184,62,101,113,184,62,212,175,184,62,71,238,184,62,191,44,185,62,59,107,185,62,188,169,185,62,65,232,185,62,202,38,186,62,88,101,186,62,235,163,186,62,129,226,186,62,28,33,187,62,188,95,187,62,95,158,187,62,7,221,187,62,180,27,188,62,100,90,188,62,25,153,188,62,210,215,188,62,143,22,189,62,80,85,189,62,22,148,189,62,223,210,189,62,173,17,190,62,127,80,190,62,85,143,190,62,47,206,190,62,13,13,191,62,239,75,191,62,213,138,191,62,191,201,191,62,173,8,192,62,159,71,192,62,149,134,192,62,143,197,192,62,141,4,193,62,143,67,193,62,148,130,193,62,158,193,193,62,171,0,194,62,188,63,194,62,209,126,194,62,234,189,194,62,6,253,194,62,38,60,195,62,74,123,195,62,113,186,195,62,157,249,195,62,204,56,196,62,254,119,196,62,52,183,196,62,110,246,196,62,171,53,197,62,236,116,197,62,49,180,197,62,121,243,197,62,196,50,198,62,19,114,198,62,102,177,198,62,188,240,198,62,21,48,199,62,114,111,199,62,210,174,199,62,54,238,199,62,157,45,200,62,7,109,200,62,117,172,200,62,230,235,200,62,90,43,201,62,209,106,201,62,76,170,201,62,202,233,201,62,75,41,202,62,208,104,202,62,88,168,202,62,226,231,202,62,112,39,203,62,1,103,203,62,149,166,203,62,45,230,203,62,199,37,204,62,100,101,204,62,4,165,204,62,168,228,204,62,78,36,205,62,248,99,205,62,164,163,205,62,83,227,205,62,5,35,206,62,186,98,206,62,114,162,206,62,45,226,206,62,234,33,207,62,171,97,207,62,110,161,207,62,52,225,207,62,253,32,208,62,200,96,208,62,150,160,208,62,103,224,208,62,59,32,209,62,17,96,209,62,234,159,209,62,198,223,209,62,164,31,210,62,133,95,210,62,104,159,210,62,78,223,210,62,55,31,211,62,33,95,211,62,15,159,211,62,255,222,211,62,241,30,212,62,230,94,212,62,221,158,212,62,215,222,212,62,211,30,213,62,209,94,213,62,210,158,213,62,213,222,213,62,219,30,214,62,226,94,214,62,236,158,214,62,248,222,214,62,7,31,215,62,24,95,215,62,42,159,215,62,63,223,215,62,87,31,216,62,112,95,216,62,139,159,216,62,169,223,216,62,200,31,217,62,234,95,217,62,14,160,217,62,51,224,217,62,91,32,218,62,133,96,218,62,176,160,218,62,222,224,218,62,13,33,219,62,63,97,219,62,114,161,219,62,167,225,219,62,222,33,220,62,23,98,220,62,82,162,220,62,142,226,220,62,204,34,221,62,12,99,221,62,78,163,221,62,146,227,221,62,215,35,222,62,29,100,222,62,102,164,222,62,176,228,222,62,252,36,223,62,73,101,223,62,152,165,223,62,232,229,223,62,58,38,224,62,142,102,224,62,227,166,224,62,57,231,224,62,145,39,225,62,234,103,225,62,69,168,225,62,161,232,225,62,255,40,226,62,94,105,226,62,190,169,226,62,32,234,226,62,131,42,227,62,231,106,227,62,76,171,227,62,179,235,227,62,27,44,228,62,132,108,228,62,238,172,228,62,90,237,228,62,199,45,229,62,52,110,229,62,163,174,229,62,19,239,229,62,133,47,230,62,247,111,230,62,106,176,230,62,222,240,230,62,83,49,231,62,202,113,231,62,65,178,231,62,185,242,231,62,50,51,232,62,172,115,232,62,38,180,232,62,162,244,232,62,31,53,233,62,156,117,233,62,26,182,233,62,153,246,233,62,25,55,234,62,153,119,234,62,26,184,234,62,156,248,234,62,31,57,235,62,162,121,235,62,38,186,235,62,170,250,235,62,47,59,236,62,181,123,236,62,59,188,236,62,194,252,236,62,73,61,237,62,209,125,237,62,89,190,237,62,226,254,237,62,107,63,238,62,245,127,238,62,127,192,238,62,10,1,239,62,149,65,239,62,32,130,239,62,171,194,239,62,55,3,240,62,196,67,240,62,80,132,240,62,221,196,240,62,106,5,241,62,247,69,241,62,132,134,241,62,18,199,241,62,160,7,242,62,45,72,242,62,187,136,242,62,74,201,242,62,216,9,243,62,102,74,243,62,244,138,243,62,131,203,243,62,17,12,244,62,159,76,244,62,46,141,244,62,188,205,244,62,74,14,245,62,216,78,245,62,102,143,245,62,244,207,245,62,129,16,246,62,15,81,246,62,156,145,246,62,41,210,246,62,182,18,247,62,67,83,247,62,207,147,247,62], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+153600);
/* memory initializer */ allocate([91,212,247,62,231,20,248,62,115,85,248,62,254,149,248,62,136,214,248,62,19,23,249,62,157,87,249,62,38,152,249,62,175,216,249,62,56,25,250,62,192,89,250,62,72,154,250,62,207,218,250,62,86,27,251,62,220,91,251,62,97,156,251,62,230,220,251,62,106,29,252,62,238,93,252,62,113,158,252,62,243,222,252,62,117,31,253,62,245,95,253,62,118,160,253,62,245,224,253,62,116,33,254,62,241,97,254,62,110,162,254,62,235,226,254,62,102,35,255,62,224,99,255,62,90,164,255,62,211,228,255,62,165,18,0,63,225,50,0,63,27,83,0,63,86,115,0,63,144,147,0,63,201,179,0,63,2,212,0,63,58,244,0,63,114,20,1,63,169,52,1,63,224,84,1,63,22,117,1,63,76,149,1,63,129,181,1,63,181,213,1,63,233,245,1,63,28,22,2,63,78,54,2,63,128,86,2,63,178,118,2,63,226,150,2,63,18,183,2,63,65,215,2,63,112,247,2,63,157,23,3,63,203,55,3,63,247,87,3,63,35,120,3,63,78,152,3,63,120,184,3,63,161,216,3,63,202,248,3,63,242,24,4,63,25,57,4,63,63,89,4,63,101,121,4,63,137,153,4,63,173,185,4,63,208,217,4,63,243,249,4,63,20,26,5,63,52,58,5,63,84,90,5,63,115,122,5,63,145,154,5,63,173,186,5,63,202,218,5,63,229,250,5,63,255,26,6,63,24,59,6,63,48,91,6,63,72,123,6,63,94,155,6,63,116,187,6,63,136,219,6,63,155,251,6,63,174,27,7,63,191,59,7,63,208,91,7,63,223,123,7,63,237,155,7,63,250,187,7,63,7,220,7,63,18,252,7,63,28,28,8,63,37,60,8,63,44,92,8,63,51,124,8,63,57,156,8,63,61,188,8,63,64,220,8,63,67,252,8,63,68,28,9,63,68,60,9,63,66,92,9,63,64,124,9,63,60,156,9,63,55,188,9,63,49,220,9,63,41,252,9,63,33,28,10,63,23,60,10,63,12,92,10,63,255,123,10,63,242,155,10,63,227,187,10,63,211,219,10,63,193,251,10,63,174,27,11,63,154,59,11,63,133,91,11,63,110,123,11,63,86,155,11,63,60,187,11,63,33,219,11,63,5,251,11,63,231,26,12,63,200,58,12,63,168,90,12,63,134,122,12,63,98,154,12,63,62,186,12,63,23,218,12,63,240,249,12,63,199,25,13,63,156,57,13,63,112,89,13,63,66,121,13,63,19,153,13,63,227,184,13,63,176,216,13,63,125,248,13,63,72,24,14,63,17,56,14,63,216,87,14,63,159,119,14,63,99,151,14,63,38,183,14,63,232,214,14,63,167,246,14,63,101,22,15,63,34,54,15,63,221,85,15,63,150,117,15,63,78,149,15,63,4,181,15,63,184,212,15,63,106,244,15,63,27,20,16,63,202,51,16,63,120,83,16,63,36,115,16,63,206,146,16,63,118,178,16,63,28,210,16,63,193,241,16,63,100,17,17,63,6,49,17,63,165,80,17,63,67,112,17,63,223,143,17,63,121,175,17,63,17,207,17,63,167,238,17,63,60,14,18,63,206,45,18,63,95,77,18,63,238,108,18,63,123,140,18,63,7,172,18,63,144,203,18,63,23,235,18,63,157,10,19,63,32,42,19,63,162,73,19,63,34,105,19,63,159,136,19,63,27,168,19,63,149,199,19,63,13,231,19,63,131,6,20,63,247,37,20,63,104,69,20,63,216,100,20,63,70,132,20,63,178,163,20,63,27,195,20,63,131,226,20,63,233,1,21,63,76,33,21,63,174,64,21,63,13,96,21,63,106,127,21,63,197,158,21,63,31,190,21,63,117,221,21,63,202,252,21,63,29,28,22,63,109,59,22,63,188,90,22,63,8,122,22,63,82,153,22,63,153,184,22,63,223,215,22,63,34,247,22,63,100,22,23,63,162,53,23,63,223,84,23,63,26,116,23,63,82,147,23,63,136,178,23,63,187,209,23,63,237,240,23,63,28,16,24,63,73,47,24,63,115,78,24,63,155,109,24,63,193,140,24,63,228,171,24,63,6,203,24,63,36,234,24,63,65,9,25,63,91,40,25,63,115,71,25,63,136,102,25,63,155,133,25,63,171,164,25,63,185,195,25,63,197,226,25,63,206,1,26,63,213,32,26,63,217,63,26,63,219,94,26,63,218,125,26,63,215,156,26,63,210,187,26,63,202,218,26,63,191,249,26,63,178,24,27,63,162,55,27,63,144,86,27,63,123,117,27,63,100,148,27,63,74,179,27,63,46,210,27,63,15,241,27,63,237,15,28,63,201,46,28,63,162,77,28,63,121,108,28,63,77,139,28,63,31,170,28,63,237,200,28,63,185,231,28,63,131,6,29,63,74,37,29,63,14,68,29,63,207,98,29,63,142,129,29,63,74,160,29,63,3,191,29,63,186,221,29,63,110,252,29,63,31,27,30,63,205,57,30,63,121,88,30,63,34,119,30,63,200,149,30,63,107,180,30,63,12,211,30,63,170,241,30,63,69,16,31,63,221,46,31,63,114,77,31,63,5,108,31,63,148,138,31,63,33,169,31,63,171,199,31,63,50,230,31,63,182,4,32,63,56,35,32,63,182,65,32,63,50,96,32,63,170,126,32,63,32,157,32,63,147,187,32,63,3,218,32,63,112,248,32,63,218,22,33,63,65,53,33,63,165,83,33,63,6,114,33,63,100,144,33,63,191,174,33,63,23,205,33,63,108,235,33,63,190,9,34,63,13,40,34,63,89,70,34,63,162,100,34,63,232,130,34,63,43,161,34,63,107,191,34,63,167,221,34,63,225,251,34,63,24,26,35,63,75,56,35,63,123,86,35,63,168,116,35,63,211,146,35,63,249,176,35,63,29,207,35,63,62,237,35,63,91,11,36,63,118,41,36,63,141,71,36,63,161,101,36,63,177,131,36,63,191,161,36,63,201,191,36,63,208,221,36,63,212,251,36,63,213,25,37,63,210,55,37,63,204,85,37,63,195,115,37,63,183,145,37,63,167,175,37,63,148,205,37,63,126,235,37,63,101,9,38,63,72,39,38,63,40,69,38,63,4,99,38,63,221,128,38,63,179,158,38,63,134,188,38,63,85,218,38,63,33,248,38,63,233,21,39,63,174,51,39,63,112,81,39,63,46,111,39,63,233,140,39,63,160,170,39,63,84,200,39,63,4,230,39,63,178,3,40,63,91,33,40,63,1,63,40,63,164,92,40,63,67,122,40,63,223,151,40,63,120,181,40,63,12,211,40,63,158,240,40,63,43,14,41,63,182,43,41,63,60,73,41,63,192,102,41,63,63,132,41,63,187,161,41,63,52,191,41,63,169,220,41,63,26,250,41,63,136,23,42,63,242,52,42,63,89,82,42,63,188,111,42,63,28,141,42,63,119,170,42,63,208,199,42,63,36,229,42,63,117,2,43,63,194,31,43,63,12,61,43,63,82,90,43,63,148,119,43,63,211,148,43,63,14,178,43,63,69,207,43,63,120,236,43,63,168,9,44,63,212,38,44,63,252,67,44,63,33,97,44,63,66,126,44,63,95,155,44,63,120,184,44,63,142,213,44,63,159,242,44,63,173,15,45,63,184,44,45,63,190,73,45,63,193,102,45,63,191,131,45,63,186,160,45,63,177,189,45,63,165,218,45,63,148,247,45,63,128,20,46,63,103,49,46,63,75,78,46,63,43,107,46,63,7,136,46,63,224,164,46,63,180,193,46,63,132,222,46,63,81,251,46,63,26,24,47,63,222,52,47,63,159,81,47,63,92,110,47,63,21,139,47,63,202,167,47,63,123,196,47,63,40,225,47,63,209,253,47,63,118,26,48,63,23,55,48,63,180,83,48,63,77,112,48,63,226,140,48,63,115,169,48,63,0,198,48,63,137,226,48,63,14,255,48,63,142,27,49,63,11,56,49,63,132,84,49,63,248,112,49,63,105,141,49,63,214,169,49,63,62,198,49,63,162,226,49,63,2,255,49,63,95,27,50,63,182,55,50,63,10,84,50,63,90,112,50,63,166,140,50,63,237,168,50,63,48,197,50,63,111,225,50,63,170,253,50,63,225,25,51,63,19,54,51,63,66,82,51,63,108,110,51,63,146,138,51,63,180,166,51,63,209,194,51,63,234,222,51,63,0,251,51,63,16,23,52,63,29,51,52,63,37,79,52,63,41,107,52,63,41,135,52,63,37,163,52,63,28,191,52,63,15,219,52,63,253,246,52,63,232,18,53,63,206,46,53,63,176,74,53,63,141,102,53,63,102,130,53,63,59,158,53,63,11,186,53,63,215,213,53,63,159,241,53,63,98,13,54,63,33,41,54,63,220,68,54,63,146,96,54,63,68,124,54,63,241,151,54,63,154,179,54,63,63,207,54,63,223,234,54,63,123,6,55,63,18,34,55,63,165,61,55,63,52,89,55,63,190,116,55,63,67,144,55,63,196,171,55,63,65,199,55,63,185,226,55,63,45,254,55,63,156,25,56,63,7,53,56,63,109,80,56,63,207,107,56,63,44,135,56,63,133,162,56,63,217,189,56,63,40,217,56,63,115,244,56,63,186,15,57,63,252,42,57,63,57,70,57,63,114,97,57,63,166,124,57,63,214,151,57,63,1,179,57,63,40,206,57,63,74,233,57,63,103,4,58,63,128,31,58,63,148,58,58,63,163,85,58,63,174,112,58,63,180,139,58,63,182,166,58,63,179,193,58,63,171,220,58,63,159,247,58,63,142,18,59,63,120,45,59,63,94,72,59,63,63,99,59,63,27,126,59,63,243,152,59,63,197,179,59,63,148,206,59,63,93,233,59,63,34,4,60,63,226,30,60,63,157,57,60,63,84,84,60,63,5,111,60,63,178,137,60,63,91,164,60,63,254,190,60,63,157,217,60,63,55,244,60,63,204,14,61,63,93,41,61,63,232,67,61,63,111,94,61,63,241,120,61,63,110,147,61,63,231,173,61,63,91,200,61,63,201,226,61,63,51,253,61,63,152,23,62,63,249,49,62,63,84,76,62,63,171,102,62,63,252,128,62,63,73,155,62,63,145,181,62,63,212,207,62,63,19,234,62,63,76,4,63,63,128,30,63,63,176,56,63,63,219,82,63,63,0,109,63,63,33,135,63,63,61,161,63,63,84,187,63,63,102,213,63,63,115,239,63,63,123,9,64,63,127,35,64,63,125,61,64,63,118,87,64,63,106,113,64,63,90,139,64,63,68,165,64,63,42,191,64,63,10,217,64,63,229,242,64,63,188,12,65,63,141,38,65,63,90,64,65,63,33,90,65,63,228,115,65,63,161,141,65,63,89,167,65,63,13,193,65,63,187,218,65,63,100,244,65,63,8,14,66,63,167,39,66,63,65,65,66,63,214,90,66,63,102,116,66,63,241,141,66,63,119,167,66,63,248,192,66,63,115,218,66,63,234,243,66,63,91,13,67,63,199,38,67,63,47,64,67,63,145,89,67,63,238,114,67,63,69,140,67,63,152,165,67,63,230,190,67,63,46,216,67,63,113,241,67,63,175,10,68,63,232,35,68,63,28,61,68,63,75,86,68,63,116,111,68,63,153,136,68,63,184,161,68,63,210,186,68,63,230,211,68,63,246,236,68,63,0,6,69,63,5,31,69,63,5,56,69,63,0,81,69,63,245,105,69,63,230,130,69,63,209,155,69,63,182,180,69,63,151,205,69,63,114,230,69,63,72,255,69,63,25,24,70,63,229,48,70,63,171,73,70,63,108,98,70,63,40,123,70,63,222,147,70,63,143,172,70,63,59,197,70,63,226,221,70,63,131,246,70,63,31,15,71,63,182,39,71,63,71,64,71,63,211,88,71,63,90,113,71,63,220,137,71,63,88,162,71,63,207,186,71,63,64,211,71,63,172,235,71,63,19,4,72,63,116,28,72,63,209,52,72,63,39,77,72,63,121,101,72,63,197,125,72,63,11,150,72,63,77,174,72,63,137,198,72,63,191,222,72,63,240,246,72,63,28,15,73,63,66,39,73,63,99,63,73,63,127,87,73,63,149,111,73,63,166,135,73,63,177,159,73,63,183,183,73,63,183,207,73,63,178,231,73,63,168,255,73,63,152,23,74,63,131,47,74,63,104,71,74,63,72,95,74,63,34,119,74,63,247,142,74,63,199,166,74,63,145,190,74,63,85,214,74,63,20,238,74,63,206,5,75,63,130,29,75,63,49,53,75,63,218,76,75,63,126,100,75,63,28,124,75,63,181,147,75,63,72,171,75,63,213,194,75,63,93,218,75,63,224,241,75,63,93,9,76,63,213,32,76,63,71,56,76,63,179,79,76,63,26,103,76,63,124,126,76,63,216,149,76,63,46,173,76,63,127,196,76,63,202,219,76,63,16,243,76,63,80,10,77,63,139,33,77,63,192,56,77,63,240,79,77,63,26,103,77,63,62,126,77,63,93,149,77,63,118,172,77,63,137,195,77,63,151,218,77,63,160,241,77,63,163,8,78,63,160,31,78,63,151,54,78,63,137,77,78,63,118,100,78,63,93,123,78,63,62,146,78,63,25,169,78,63,239,191,78,63,192,214,78,63,138,237,78,63,79,4,79,63,15,27,79,63,201,49,79,63,125,72,79,63,43,95,79,63,212,117,79,63,119,140,79,63,21,163,79,63,172,185,79,63,63,208,79,63,203,230,79,63,82,253,79,63,211,19,80,63,79,42,80,63,197,64,80,63,53,87,80,63,159,109,80,63,4,132,80,63,99,154,80,63,189,176,80,63,16,199,80,63,94,221,80,63,167,243,80,63,233,9,81,63,38,32,81,63,93,54,81,63,143,76,81,63,187,98,81,63,225,120,81,63,1,143,81,63,28,165,81,63,48,187,81,63,64,209,81,63,73,231,81,63,77,253,81,63,75,19,82,63,67,41,82,63,53,63,82,63,34,85,82,63,9,107,82,63,234,128,82,63,198,150,82,63,155,172,82,63,107,194,82,63,53,216,82,63,250,237,82,63,185,3,83,63,113,25,83,63,37,47,83,63,210,68,83,63,121,90,83,63,27,112,83,63,183,133,83,63,77,155,83,63,222,176,83,63,104,198,83,63,237,219,83,63,108,241,83,63,230,6,84,63,89,28,84,63,199,49,84,63,46,71,84,63,145,92,84,63,237,113,84,63,67,135,84,63,148,156,84,63,223,177,84,63,35,199,84,63,99,220,84,63,156,241,84,63,207,6,85,63,253,27,85,63,37,49,85,63,71,70,85,63,99,91,85,63,121,112,85,63,138,133,85,63,149,154,85,63,153,175,85,63,152,196,85,63,146,217,85,63,133,238,85,63,114,3,86,63,90,24,86,63,60,45,86,63,24,66,86,63,238,86,86,63,190,107,86,63,136,128,86,63,76,149,86,63,11,170,86,63,196,190,86,63,118,211,86,63,35,232,86,63,203,252,86,63,108,17,87,63,7,38,87,63,156,58,87,63,44,79,87,63,182,99,87,63,58,120,87,63,183,140,87,63,47,161,87,63,162,181,87,63,14,202,87,63,116,222,87,63,213,242,87,63,47,7,88,63,132,27,88,63,211,47,88,63,28,68,88,63,95,88,88,63,156,108,88,63,211,128,88,63,4,149,88,63,47,169,88,63,85,189,88,63,116,209,88,63,142,229,88,63,162,249,88,63,175,13,89,63,183,33,89,63,185,53,89,63,181,73,89,63,171,93,89,63,155,113,89,63,134,133,89,63,106,153,89,63,72,173,89,63,33,193,89,63,243,212,89,63,192,232,89,63,135,252,89,63,71,16,90,63,2,36,90,63,183,55,90,63,102,75,90,63,15,95,90,63,178,114,90,63,79,134,90,63,230,153,90,63,119,173,90,63,3,193,90,63,136,212,90,63,7,232,90,63,129,251,90,63,244,14,91,63,98,34,91,63,201,53,91,63,43,73,91,63,135,92,91,63,220,111,91,63,44,131,91,63,118,150,91,63,186,169,91,63,248,188,91,63,47,208,91,63,97,227,91,63,141,246,91,63,179,9,92,63,212,28,92,63,238,47,92,63,2,67,92,63,16,86,92,63,24,105,92,63,26,124,92,63,23,143,92,63,13,162,92,63,253,180,92,63,232,199,92,63,204,218,92,63,171,237,92,63,131,0,93,63,86,19,93,63,34,38,93,63,233,56,93,63,169,75,93,63,100,94,93,63,24,113,93,63,199,131,93,63,112,150,93,63,18,169,93,63,175,187,93,63,70,206,93,63,215,224,93,63,97,243,93,63,230,5,94,63,101,24,94,63,222,42,94,63,81,61,94,63,190,79,94,63,36,98,94,63,133,116,94,63,224,134,94,63,53,153,94,63,132,171,94,63,205,189,94,63,16,208,94,63,77,226,94,63,132,244,94,63,181,6,95,63,224,24,95,63,5,43,95,63,36,61,95,63,61,79,95,63,80,97,95,63,93,115,95,63,101,133,95,63,102,151,95,63,97,169,95,63,86,187,95,63,69,205,95,63,46,223,95,63,18,241,95,63,239,2,96,63,198,20,96,63,151,38,96,63,98,56,96,63,40,74,96,63,231,91,96,63,160,109,96,63,84,127,96,63,1,145,96,63,168,162,96,63,73,180,96,63,229,197,96,63,122,215,96,63,10,233,96,63,147,250,96,63,22,12,97,63,148,29,97,63,11,47,97,63,125,64,97,63,232,81,97,63,77,99,97,63,173,116,97,63,6,134,97,63,90,151,97,63,167,168,97,63,239,185,97,63,48,203,97,63,108,220,97,63,162,237,97,63,209,254,97,63,251,15,98,63,30,33,98,63,60,50,98,63,84,67,98,63,101,84,98,63,113,101,98,63,119,118,98,63,119,135,98,63,112,152,98,63,100,169,98,63,82,186,98,63,58,203,98,63,28,220,98,63,247,236,98,63,205,253,98,63,157,14,99,63,103,31,99,63,43,48,99,63,233,64,99,63,161,81,99,63,83,98,99,63,255,114,99,63,165,131,99,63,69,148,99,63,224,164,99,63,116,181,99,63,2,198,99,63,138,214,99,63,13,231,99,63,137,247,99,63,255,7,100,63,112,24,100,63,218,40,100,63,62,57,100,63,157,73,100,63,246,89,100,63,72,106,100,63,149,122,100,63,219,138,100,63,28,155,100,63,87,171,100,63,140,187,100,63,186,203,100,63,227,219,100,63,6,236,100,63,35,252,100,63,58,12,101,63,75,28,101,63,86,44,101,63,91,60,101,63,91,76,101,63,84,92,101,63,71,108,101,63,53,124,101,63,28,140,101,63,254,155,101,63,217,171,101,63,175,187,101,63,126,203,101,63,72,219,101,63,12,235,101,63,202,250,101,63,130,10,102,63,52,26,102,63,224,41,102,63,134,57,102,63,38,73,102,63,193,88,102,63,85,104,102,63,227,119,102,63,108,135,102,63,238,150,102,63,107,166,102,63,226,181,102,63,83,197,102,63,190,212,102,63,35,228,102,63,130,243,102,63,219,2,103,63,46,18,103,63,124,33,103,63,195,48,103,63,5,64,103,63,64,79,103,63,118,94,103,63,166,109,103,63,208,124,103,63,244,139,103,63,18,155,103,63,42,170,103,63,61,185,103,63,73,200,103,63,80,215,103,63,80,230,103,63,75,245,103,63,64,4,104,63,47,19,104,63,24,34,104,63,251,48,104,63,217,63,104,63,176,78,104,63,130,93,104,63,78,108,104,63,20,123,104,63,212,137,104,63,142,152,104,63,66,167,104,63,240,181,104,63,153,196,104,63,60,211,104,63,217,225,104,63,112,240,104,63,1,255,104,63,140,13,105,63,17,28,105,63,145,42,105,63,11,57,105,63,127,71,105,63,237,85,105,63,85,100,105,63,183,114,105,63,20,129,105,63,106,143,105,63,187,157,105,63,6,172,105,63,75,186,105,63,139,200,105,63,196,214,105,63,248,228,105,63,38,243,105,63,78,1,106,63,112,15,106,63,141,29,106,63,163,43,106,63,180,57,106,63,191,71,106,63,196,85,106,63,196,99,106,63,189,113,106,63,177,127,106,63,159,141,106,63,135,155,106,63,106,169,106,63,70,183,106,63,29,197,106,63,238,210,106,63,186,224,106,63,127,238,106,63,63,252,106,63,249,9,107,63,173,23,107,63,91,37,107,63,4,51,107,63,167,64,107,63,68,78,107,63,219,91,107,63,109,105,107,63,249,118,107,63,127,132,107,63,255,145,107,63,122,159,107,63,238,172,107,63,94,186,107,63,199,199,107,63,42,213,107,63,136,226,107,63,224,239,107,63,51,253,107,63,128,10,108,63,198,23,108,63,8,37,108,63,67,50,108,63,121,63,108,63,169,76,108,63,211,89,108,63,248,102,108,63,23,116,108,63,48,129,108,63,68,142,108,63,82,155,108,63,90,168,108,63,92,181,108,63,89,194,108,63,80,207,108,63,65,220,108,63,45,233,108,63,19,246,108,63,243,2,109,63,206,15,109,63,163,28,109,63,114,41,109,63,60,54,109,63,0,67,109,63,190,79,109,63,119,92,109,63,42,105,109,63,215,117,109,63,127,130,109,63,33,143,109,63,189,155,109,63,84,168,109,63,229,180,109,63,113,193,109,63,247,205,109,63,119,218,109,63,242,230,109,63,103,243,109,63,214,255,109,63,64,12,110,63,164,24,110,63,3,37,110,63,91,49,110,63,175,61,110,63,253,73,110,63,69,86,110,63,135,98,110,63,196,110,110,63,252,122,110,63,45,135,110,63,90,147,110,63,128,159,110,63,161,171,110,63,189,183,110,63,211,195,110,63,227,207,110,63,238,219,110,63,243,231,110,63,243,243,110,63,237,255,110,63,226,11,111,63,209,23,111,63,186,35,111,63,158,47,111,63,125,59,111,63,85,71,111,63,41,83,111,63,247,94,111,63,191,106,111,63,130,118,111,63,63,130,111,63,247,141,111,63,169,153,111,63,86,165,111,63,253,176,111,63,159,188,111,63,59,200,111,63,210,211,111,63,99,223,111,63,239,234,111,63,117,246,111,63,246,1,112,63,114,13,112,63,231,24,112,63,88,36,112,63,195,47,112,63,40,59,112,63,137,70,112,63,227,81,112,63,56,93,112,63,136,104,112,63,210,115,112,63,23,127,112,63,87,138,112,63,145,149,112,63,197,160,112,63,244,171,112,63,30,183,112,63,66,194,112,63,97,205,112,63,123,216,112,63,143,227,112,63,157,238,112,63,167,249,112,63,171,4,113,63,169,15,113,63,162,26,113,63,150,37,113,63,132,48,113,63,109,59,113,63,81,70,113,63,47,81,113,63,8,92,113,63,219,102,113,63,170,113,113,63,114,124,113,63,54,135,113,63,244,145,113,63,173,156,113,63,96,167,113,63,14,178,113,63,183,188,113,63,91,199,113,63,249,209,113,63,146,220,113,63,37,231,113,63,179,241,113,63,60,252,113,63,192,6,114,63,62,17,114,63,183,27,114,63,43,38,114,63,154,48,114,63,3,59,114,63,103,69,114,63,197,79,114,63,31,90,114,63,115,100,114,63,194,110,114,63,11,121,114,63,79,131,114,63,143,141,114,63,200,151,114,63,253,161,114,63,44,172,114,63,87,182,114,63,123,192,114,63,155,202,114,63,182,212,114,63,203,222,114,63,219,232,114,63,230,242,114,63,235,252,114,63,236,6,115,63,231,16,115,63,221,26,115,63,206,36,115,63,186,46,115,63,160,56,115,63,130,66,115,63,94,76,115,63,53,86,115,63,7,96,115,63,212,105,115,63,155,115,115,63,94,125,115,63,27,135,115,63,211,144,115,63,134,154,115,63,52,164,115,63,221,173,115,63,128,183,115,63,31,193,115,63,184,202,115,63,77,212,115,63,220,221,115,63,102,231,115,63,235,240,115,63,107,250,115,63,230,3,116,63,92,13,116,63,204,22,116,63,56,32,116,63,159,41,116,63,0,51,116,63,93,60,116,63,180,69,116,63,6,79,116,63,84,88,116,63,156,97,116,63,223,106,116,63,29,116,116,63,87,125,116,63,139,134,116,63,186,143,116,63,228,152,116,63,9,162,116,63,41,171,116,63,68,180,116,63,91,189,116,63,108,198,116,63,120,207,116,63,127,216,116,63,129,225,116,63,127,234,116,63,119,243,116,63,106,252,116,63,89,5,117,63,66,14,117,63,38,23,117,63,6,32,117,63,225,40,117,63,182,49,117,63,135,58,117,63,83,67,117,63,26,76,117,63,220,84,117,63,153,93,117,63,81,102,117,63,4,111,117,63,179,119,117,63,92,128,117,63,1,137,117,63,160,145,117,63,59,154,117,63,209,162,117,63,98,171,117,63,239,179,117,63,118,188,117,63,249,196,117,63,118,205,117,63,239,213,117,63,99,222,117,63,210,230,117,63,61,239,117,63,162,247,117,63,3,0,118,63,95,8,118,63,182,16,118,63,8,25,118,63,86,33,118,63,159,41,118,63,227,49,118,63,34,58,118,63,92,66,118,63,146,74,118,63,195,82,118,63,239,90,118,63,22,99,118,63,57,107,118,63,86,115,118,63,112,123,118,63,132,131,118,63,148,139,118,63,158,147,118,63,165,155,118,63,166,163,118,63,163,171,118,63,155,179,118,63,142,187,118,63,125,195,118,63,103,203,118,63,76,211,118,63,45,219,118,63,9,227,118,63,224,234,118,63,178,242,118,63,128,250,118,63,74,2,119,63,14,10,119,63,206,17,119,63,137,25,119,63,64,33,119,63,242,40,119,63,160,48,119,63,72,56,119,63,237,63,119,63,140,71,119,63,39,79,119,63,190,86,119,63,79,94,119,63,220,101,119,63,101,109,119,63,233,116,119,63,105,124,119,63,228,131,119,63,90,139,119,63,204,146,119,63,57,154,119,63,162,161,119,63,6,169,119,63,101,176,119,63,192,183,119,63,23,191,119,63,105,198,119,63,182,205,119,63,255,212,119,63,68,220,119,63,132,227,119,63,191,234,119,63,246,241,119,63,41,249,119,63,87,0,120,63,129,7,120,63,166,14,120,63,198,21,120,63,227,28,120,63,250,35,120,63,14,43,120,63,28,50,120,63,39,57,120,63,45,64,120,63,46,71,120,63,44,78,120,63,36,85,120,63,25,92,120,63,9,99,120,63,244,105,120,63,219,112,120,63,190,119,120,63,156,126,120,63,118,133,120,63,76,140,120,63,29,147,120,63,234,153,120,63,179,160,120,63,119,167,120,63,55,174,120,63,242,180,120,63,169,187,120,63,92,194,120,63,11,201,120,63,181,207,120,63,91,214,120,63,252,220,120,63,154,227,120,63,51,234,120,63,199,240,120,63,88,247,120,63,228,253,120,63,108,4,121,63,240,10,121,63,111,17,121,63,234,23,121,63,97,30,121,63,211,36,121,63,66,43,121,63,172,49,121,63,18,56,121,63,116,62,121,63,209,68,121,63,42,75,121,63,127,81,121,63,208,87,121,63,29,94,121,63,101,100,121,63,170,106,121,63,234,112,121,63,38,119,121,63,93,125,121,63,145,131,121,63,193,137,121,63,236,143,121,63,19,150,121,63,54,156,121,63,85,162,121,63,112,168,121,63,134,174,121,63,153,180,121,63,167,186,121,63,178,192,121,63,184,198,121,63,186,204,121,63,184,210,121,63,178,216,121,63,168,222,121,63,154,228,121,63,135,234,121,63,113,240,121,63,87,246,121,63,56,252,121,63,22,2,122,63,239,7,122,63,197,13,122,63,150,19,122,63,100,25,122,63,45,31,122,63,243,36,122,63,180,42,122,63,113,48,122,63,43,54,122,63,224,59,122,63,146,65,122,63,63,71,122,63,233,76,122,63,142,82,122,63,48,88,122,63,206,93,122,63,103,99,122,63,253,104,122,63,143,110,122,63,29,116,122,63,167,121,122,63,45,127,122,63,175,132,122,63,45,138,122,63,168,143,122,63,30,149,122,63,145,154,122,63,255,159,122,63,106,165,122,63,209,170,122,63,52,176,122,63,147,181,122,63,239,186,122,63,70,192,122,63,154,197,122,63,234,202,122,63,54,208,122,63,126,213,122,63,194,218,122,63,3,224,122,63,64,229,122,63,121,234,122,63,174,239,122,63,223,244,122,63,13,250,122,63,55,255,122,63,93,4,123,63,127,9,123,63,157,14,123,63,184,19,123,63,207,24,123,63,227,29,123,63,242,34,123,63,254,39,123,63,6,45,123,63,10,50,123,63,11,55,123,63,8,60,123,63,1,65,123,63,247,69,123,63,233,74,123,63,215,79,123,63,193,84,123,63,168,89,123,63,139,94,123,63,107,99,123,63,71,104,123,63,31,109,123,63,243,113,123,63,196,118,123,63,146,123,123,63,91,128,123,63,33,133,123,63,228,137,123,63,163,142,123,63,94,147,123,63,22,152,123,63,202,156,123,63,122,161,123,63,39,166,123,63,208,170,123,63,118,175,123,63,24,180,123,63,183,184,123,63,82,189,123,63,233,193,123,63,125,198,123,63,14,203,123,63,155,207,123,63,36,212,123,63,170,216,123,63,45,221,123,63,172,225,123,63,39,230,123,63,159,234,123,63,19,239,123,63,132,243,123,63,242,247,123,63,92,252,123,63,195,0,124,63,38,5,124,63,133,9,124,63,226,13,124,63,58,18,124,63,144,22,124,63,226,26,124,63,48,31,124,63,123,35,124,63,195,39,124,63,7,44,124,63,72,48,124,63,134,52,124,63,192,56,124,63,247,60,124,63,42,65,124,63,90,69,124,63,135,73,124,63,176,77,124,63,214,81,124,63,249,85,124,63,24,90,124,63,52,94,124,63,77,98,124,63,98,102,124,63,116,106,124,63,131,110,124,63,142,114,124,63,150,118,124,63,155,122,124,63,157,126,124,63,155,130,124,63,150,134,124,63,142,138,124,63,130,142,124,63,116,146,124,63,98,150,124,63,77,154,124,63,52,158,124,63,24,162,124,63,249,165,124,63,215,169,124,63,178,173,124,63,137,177,124,63,94,181,124,63,47,185,124,63,253,188,124,63,199,192,124,63,143,196,124,63,83,200,124,63,20,204,124,63,211,207,124,63,141,211,124,63,69,215,124,63,250,218,124,63,171,222,124,63,90,226,124,63,5,230,124,63,173,233,124,63,82,237,124,63,244,240,124,63,147,244,124,63,46,248,124,63,199,251,124,63,93,255,124,63,239,2,125,63,127,6,125,63,11,10,125,63,148,13,125,63,27,17,125,63,158,20,125,63,30,24,125,63,155,27,125,63,21,31,125,63,140,34,125,63,0,38,125,63,114,41,125,63,224,44,125,63,75,48,125,63,179,51,125,63,24,55,125,63,122,58,125,63,217,61,125,63,54,65,125,63,143,68,125,63,229,71,125,63,56,75,125,63,137,78,125,63,214,81,125,63,33,85,125,63,104,88,125,63,173,91,125,63,239,94,125,63,46,98,125,63,106,101,125,63,163,104,125,63,217,107,125,63,12,111,125,63,61,114,125,63,106,117,125,63,149,120,125,63,189,123,125,63,226,126,125,63,4,130,125,63,36,133,125,63,64,136,125,63,90,139,125,63,112,142,125,63,133,145,125,63,150,148,125,63,164,151,125,63,176,154,125,63,185,157,125,63,191,160,125,63,194,163,125,63,194,166,125,63,192,169,125,63,187,172,125,63,179,175,125,63,168,178,125,63,155,181,125,63,139,184,125,63,120,187,125,63,99,190,125,63,74,193,125,63,48,196,125,63,18,199,125,63,241,201,125,63,206,204,125,63,169,207,125,63,128,210,125,63,85,213,125,63,39,216,125,63,247,218,125,63,196,221,125,63,142,224,125,63,85,227,125,63,26,230,125,63,220,232,125,63,156,235,125,63,89,238,125,63,19,241,125,63,203,243,125,63,128,246,125,63,51,249,125,63,227,251,125,63,144,254,125,63,59,1,126,63,227,3,126,63,137,6,126,63,44,9,126,63,204,11,126,63,106,14,126,63,6,17,126,63,158,19,126,63,53,22,126,63,200,24,126,63,90,27,126,63,232,29,126,63,116,32,126,63,254,34,126,63,133,37,126,63,10,40,126,63,140,42,126,63,12,45,126,63,137,47,126,63,4,50,126,63,124,52,126,63,242,54,126,63,101,57,126,63,214,59,126,63,68,62,126,63,176,64,126,63,26,67,126,63,129,69,126,63,230,71,126,63,72,74,126,63,168,76,126,63,5,79,126,63,96,81,126,63,185,83,126,63,15,86,126,63,99,88,126,63,181,90,126,63,4,93,126,63,81,95,126,63,155,97,126,63,227,99,126,63,41,102,126,63,108,104,126,63,173,106,126,63,236,108,126,63,40,111,126,63,98,113,126,63,154,115,126,63,208,117,126,63,3,120,126,63,51,122,126,63,98,124,126,63,142,126,126,63,184,128,126,63,224,130,126,63,5,133,126,63,40,135,126,63,73,137,126,63,104,139,126,63,132,141,126,63,159,143,126,63,183,145,126,63,204,147,126,63,224,149,126,63,241,151,126,63,0,154,126,63,13,156,126,63,24,158,126,63,32,160,126,63,38,162,126,63,42,164,126,63,44,166,126,63,44,168,126,63,41,170,126,63,37,172,126,63,30,174,126,63,21,176,126,63,10,178,126,63,253,179,126,63,238,181,126,63,220,183,126,63,201,185,126,63,179,187,126,63,155,189,126,63,129,191,126,63,101,193,126,63,71,195,126,63,39,197,126,63,5,199,126,63,224,200,126,63,186,202,126,63,145,204,126,63,103,206,126,63,58,208,126,63,12,210,126,63,219,211,126,63,168,213,126,63,115,215,126,63,61,217,126,63,4,219,126,63,201,220,126,63,140,222,126,63,77,224,126,63,12,226,126,63,202,227,126,63,133,229,126,63,62,231,126,63,245,232,126,63,170,234,126,63,94,236,126,63,15,238,126,63,190,239,126,63,108,241,126,63,23,243,126,63,193,244,126,63,104,246,126,63,14,248,126,63,178,249,126,63,84,251,126,63,243,252,126,63,145,254,126,63,46,0,127,63,200,1,127,63,96,3,127,63,247,4,127,63,139,6,127,63,30,8,127,63,175,9,127,63,62,11,127,63,203,12,127,63,86,14,127,63,223,15,127,63,103,17,127,63,237,18,127,63,112,20,127,63,242,21,127,63,115,23,127,63,241,24,127,63,110,26,127,63,233,27,127,63,98,29,127,63,217,30,127,63,78,32,127,63,194,33,127,63,52,35,127,63,164,36,127,63,18,38,127,63,127,39,127,63,234,40,127,63,83,42,127,63,186,43,127,63,32,45,127,63,131,46,127,63,230,47,127,63,70,49,127,63,165,50,127,63,2,52,127,63,93,53,127,63,182,54,127,63,14,56,127,63,100,57,127,63,185,58,127,63,12,60,127,63,93,61,127,63,172,62,127,63,250,63,127,63,70,65,127,63,145,66,127,63,217,67,127,63,33,69,127,63,102,70,127,63,170,71,127,63,236,72,127,63,45,74,127,63,108,75,127,63,169,76,127,63,229,77,127,63,31,79,127,63,88,80,127,63,143,81,127,63,196,82,127,63,248,83,127,63,42,85,127,63,91,86,127,63,138,87,127,63,184,88,127,63,228,89,127,63,14,91,127,63,55,92,127,63,94,93,127,63,132,94,127,63,169,95,127,63,203,96,127,63,237,97,127,63,12,99,127,63,42,100,127,63,71,101,127,63,98,102,127,63,124,103,127,63,148,104,127,63,171,105,127,63,192,106,127,63,212,107,127,63,230,108,127,63,247,109,127,63,6,111,127,63,20,112,127,63,33,113,127,63,44,114,127,63,53,115,127,63,61,116,127,63,68,117,127,63,73,118,127,63,77,119,127,63,79,120,127,63,80,121,127,63,80,122,127,63,78,123,127,63,75,124,127,63,70,125,127,63,64,126,127,63,57,127,127,63,48,128,127,63,38,129,127,63,27,130,127,63,14,131,127,63,0,132,127,63,240,132,127,63,223,133,127,63,205,134,127,63,185,135,127,63,164,136,127,63,142,137,127,63,118,138,127,63,93,139,127,63,67,140,127,63,40,141,127,63,11,142,127,63,237,142,127,63,205,143,127,63,173,144,127,63,139,145,127,63,103,146,127,63,67,147,127,63,29,148,127,63,246,148,127,63,205,149,127,63,164,150,127,63,121,151,127,63,77,152,127,63,31,153,127,63,241,153,127,63,193,154,127,63,144,155,127,63,93,156,127,63,42,157,127,63,245,157,127,63,191,158,127,63,136,159,127,63,79,160,127,63,22,161,127,63,219,161,127,63,159,162,127,63,98,163,127,63,36,164,127,63,228,164,127,63,163,165,127,63,98,166,127,63,31,167,127,63,219,167,127,63,149,168,127,63,79,169,127,63,7,170,127,63,190,170,127,63,117,171,127,63,42,172,127,63,221,172,127,63,144,173,127,63,66,174,127,63,242,174,127,63,162,175,127,63,80,176,127,63,253,176,127,63,169,177,127,63,85,178,127,63,254,178,127,63,167,179,127,63,79,180,127,63,246,180,127,63,156,181,127,63,64,182,127,63,228,182,127,63,134,183,127,63,40,184,127,63,200,184,127,63,103,185,127,63,6,186,127,63,163,186,127,63,63,187,127,63,219,187,127,63,117,188,127,63,14,189,127,63,166,189,127,63,61,190,127,63,212,190,127,63,105,191,127,63,253,191,127,63,144,192,127,63,34,193,127,63,180,193,127,63,68,194,127,63,211,194,127,63,98,195,127,63,239,195,127,63,123,196,127,63,7,197,127,63,145,197,127,63,27,198,127,63,163,198,127,63,43,199,127,63,178,199,127,63,56,200,127,63,189,200,127,63,65,201,127,63,196,201,127,63,70,202,127,63,199,202,127,63,71,203,127,63,199,203,127,63,69,204,127,63,195,204,127,63,64,205,127,63,187,205,127,63,54,206,127,63,177,206,127,63,42,207,127,63,162,207,127,63,26,208,127,63,144,208,127,63,6,209,127,63,123,209,127,63,239,209,127,63,98,210,127,63,213,210,127,63,70,211,127,63,183,211,127,63,39,212,127,63,150,212,127,63,4,213,127,63,114,213,127,63,222,213,127,63,74,214,127,63,181,214,127,63,32,215,127,63,137,215,127,63,242,215,127,63,89,216,127,63,192,216,127,63,39,217,127,63,140,217,127,63,241,217,127,63,85,218,127,63,184,218,127,63,27,219,127,63,124,219,127,63,221,219,127,63,61,220,127,63,157,220,127,63,251,220,127,63,89,221,127,63,183,221,127,63,19,222,127,63,111,222,127,63,202,222,127,63,36,223,127,63,126,223,127,63,215,223,127,63,47,224,127,63,134,224,127,63,221,224,127,63,51,225,127,63,137,225,127,63,221,225,127,63,49,226,127,63,133,226,127,63,215,226,127,63,41,227,127,63,122,227,127,63,203,227,127,63,27,228,127,63,106,228,127,63,185,228,127,63,7,229,127,63,84,229,127,63,161,229,127,63,237,229,127,63,56,230,127,63,131,230,127,63,205,230,127,63,23,231,127,63,96,231,127,63,168,231,127,63,239,231,127,63,54,232,127,63,125,232,127,63,195,232,127,63,8,233,127,63,76,233,127,63,144,233,127,63,212,233,127,63,23,234,127,63,89,234,127,63,154,234,127,63,219,234,127,63,28,235,127,63,92,235,127,63,155,235,127,63,218,235,127,63,24,236,127,63,86,236,127,63,147,236,127,63,207,236,127,63,11,237,127,63,71,237,127,63,130,237,127,63,188,237,127,63,246,237,127,63,47,238,127,63,104,238,127,63,160,238,127,63,216,238,127,63,15,239,127,63,69,239,127,63,123,239,127,63,177,239,127,63,230,239,127,63,27,240,127,63,79,240,127,63,130,240,127,63,182,240,127,63,232,240,127,63,26,241,127,63,76,241,127,63,125,241,127,63,174,241,127,63,222,241,127,63,14,242,127,63,61,242,127,63,108,242,127,63,154,242,127,63,200,242,127,63,245,242,127,63,34,243,127,63,79,243,127,63,123,243,127,63,166,243,127,63,209,243,127,63,252,243,127,63,38,244,127,63,80,244,127,63,121,244,127,63,162,244,127,63,203,244,127,63,243,244,127,63,27,245,127,63,66,245,127,63,105,245,127,63,143,245,127,63,181,245,127,63,219,245,127,63,0,246,127,63,37,246,127,63,73,246,127,63,109,246,127,63,145,246,127,63,180,246,127,63,215,246,127,63,250,246,127,63,28,247,127,63,62,247,127,63,95,247,127,63,128,247,127,63,160,247,127,63,193,247,127,63,225,247,127,63,0,248,127,63,31,248,127,63,62,248,127,63,93,248,127,63,123,248,127,63,152,248,127,63,182,248,127,63,211,248,127,63,240,248,127,63,12,249,127,63,40,249,127,63,68,249,127,63,95,249,127,63,122,249,127,63,149,249,127,63,175,249,127,63,202,249,127,63,227,249,127,63,253,249,127,63,22,250,127,63,47,250,127,63,71,250,127,63,96,250,127,63,120,250,127,63,143,250,127,63,166,250,127,63,190,250,127,63,212,250,127,63,235,250,127,63,1,251,127,63,23,251,127,63,44,251,127,63,66,251,127,63,87,251,127,63,108,251,127,63,128,251,127,63,148,251,127,63,168,251,127,63,188,251,127,63,208,251,127,63,227,251,127,63,246,251,127,63,8,252,127,63,27,252,127,63,45,252,127,63,63,252,127,63,81,252,127,63,98,252,127,63,115,252,127,63,132,252,127,63,149,252,127,63,165,252,127,63,182,252,127,63,198,252,127,63,213,252,127,63,229,252,127,63,244,252,127,63,3,253,127,63,18,253,127,63,33,253,127,63,47,253,127,63,62,253,127,63,76,253,127,63,89,253,127,63,103,253,127,63,116,253,127,63,130,253,127,63,143,253,127,63,155,253,127,63,168,253,127,63,181,253,127,63,193,253,127,63,205,253,127,63,217,253,127,63,228,253,127,63,240,253,127,63,251,253,127,63,6,254,127,63,17,254,127,63,28,254,127,63,38,254,127,63,49,254,127,63,59,254,127,63,69,254,127,63,79,254,127,63,89,254,127,63,98,254,127,63,108,254,127,63,117,254,127,63,126,254,127,63,135,254,127,63,144,254,127,63,152,254,127,63,161,254,127,63,169,254,127,63,177,254,127,63,185,254,127,63,193,254,127,63,201,254,127,63,208,254,127,63,216,254,127,63,223,254,127,63,230,254,127,63,237,254,127,63,244,254,127,63,251,254,127,63,2,255,127,63,8,255,127,63,14,255,127,63,21,255,127,63,27,255,127,63,33,255,127,63,39,255,127,63,45,255,127,63,50,255,127,63,56,255,127,63,61,255,127,63,67,255,127,63,72,255,127,63,77,255,127,63,82,255,127,63,87,255,127,63,92,255,127,63,96,255,127,63,101,255,127,63,105,255,127,63,110,255,127,63,114,255,127,63,118,255,127,63,122,255,127,63,126,255,127,63,130,255,127,63,134,255,127,63,138,255,127,63,142,255,127,63,145,255,127,63,149,255,127,63,152,255,127,63,155,255,127,63,159,255,127,63,162,255,127,63,165,255,127,63,168,255,127,63,171,255,127,63,174,255,127,63,176,255,127,63,179,255,127,63,182,255,127,63,184,255,127,63,187,255,127,63,189,255,127,63,192,255,127,63,194,255,127,63,196,255,127,63,198,255,127,63,201,255,127,63,203,255,127,63,205,255,127,63,207,255,127,63,209,255,127,63,210,255,127,63,212,255,127,63,214,255,127,63,216,255,127,63,217,255,127,63,219,255,127,63,220,255,127,63,222,255,127,63,223,255,127,63,225,255,127,63,226,255,127,63,227,255,127,63,229,255,127,63,230,255,127,63,231,255,127,63,232,255,127,63,233,255,127,63,234,255,127,63,235,255,127,63,236,255,127,63,237,255,127,63,238,255,127,63,239,255,127,63,240,255,127,63,241,255,127,63,241,255,127,63,242,255,127,63,243,255,127,63,244,255,127,63,244,255,127,63,245,255,127,63,246,255,127,63,246,255,127,63,247,255,127,63,247,255,127,63,248,255,127,63,248,255,127,63,249,255,127,63,249,255,127,63,250,255,127,63,250,255,127,63,250,255,127,63,251,255,127,63,251,255,127,63,251,255,127,63,252,255,127,63,252,255,127,63,252,255,127,63,253,255,127,63,253,255,127,63,253,255,127,63,253,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,24,0,120,58,76,70,11,60,242,204,192,60,116,252,59,61,86,73,154,61,241,93,228,61,248,163,29,62,180,231,78,62,54,157,130,62,78,220,159,62,193,174,190,62,65,132,222,62,173,194,254,62,186,101,15,63,248,0,31,63,29,233,45,63,249,219,59,63,45,162,72,63,160,17,84,63,38,15,94,63,46,143,102,63,112,149,109,63,174,51,115,63,159,135,119,63,66,184,122,63,196,242,124,63,75,103,126,63,196,69,127,63,241,186,127,63,217,237,127,63,162,253,127,63,248,255,127,63,169,12,120,55,54,134,11,57,38,198,193,57,94,226,61,58], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+163840);
/* memory initializer */ allocate([234,237,156,58,85,101,234,58,56,170,35,59,207,219,89,59,169,226,139,59,42,178,174,59,13,91,213,59,204,219,255,59,91,25,23,60,250,46,48,60,194,45,75,60,156,20,104,60,46,113,131,60,225,202,147,60,185,22,165,60,1,84,183,60,245,129,202,60,198,159,222,60,155,172,243,60,199,211,4,61,213,71,16,61,250,49,28,61,174,145,40,61,101,102,53,61,141,175,66,61,140,108,80,61,193,156,94,61,133,63,109,61,41,84,124,61,252,236,133,61,26,232,141,61,13,27,150,61,110,133,158,61,212,38,167,61,210,254,175,61,245,12,185,61,200,80,194,61,209,201,203,61,146,119,213,61,139,89,223,61,51,111,233,61,2,184,243,61,105,51,254,61,106,112,4,62,214,223,9,62,171,103,15,62,153,7,21,62,77,191,26,62,116,142,32,62,181,116,38,62,184,113,44,62,34,133,50,62,149,174,56,62,178,237,62,62,21,66,69,62,92,171,75,62,30,41,82,62,243,186,88,62,112,96,95,62,40,25,102,62,170,228,108,62,132,194,115,62,68,178,122,62,185,217,128,62,203,98,132,62,26,244,135,62,105,141,139,62,120,46,143,62,6,215,146,62,211,134,150,62,156,61,154,62,29,251,157,62,19,191,161,62,57,137,165,62,71,89,169,62,249,46,173,62,5,10,177,62,36,234,180,62,13,207,184,62,117,184,188,62,18,166,192,62,153,151,196,62,190,140,200,62,52,133,204,62,175,128,208,62,225,126,212,62,125,127,216,62,52,130,220,62,184,134,224,62,185,140,228,62,233,147,232,62,248,155,236,62,150,164,240,62,117,173,244,62,67,182,248,62,178,190,252,62,57,99,0,63,153,102,2,63,82,105,4,63,60,107,6,63,48,108,8,63,6,108,10,63,151,106,12,63,188,103,14,63,78,99,16,63,39,93,18,63,33,85,20,63,21,75,22,63,222,62,24,63,87,48,26,63,92,31,28,63,199,11,30,63,117,245,31,63,66,220,33,63,12,192,35,63,176,160,37,63,12,126,39,63,254,87,41,63,104,46,43,63,39,1,45,63,29,208,46,63,43,155,48,63,51,98,50,63,23,37,52,63,188,227,53,63,4,158,55,63,214,83,57,63,23,5,59,63,173,177,60,63,128,89,62,63,120,252,63,63,126,154,65,63,124,51,67,63,93,199,68,63,12,86,70,63,119,223,71,63,138,99,73,63,54,226,74,63,104,91,76,63,17,207,77,63,35,61,79,63,145,165,80,63,76,8,82,63,75,101,83,63,130,188,84,63,231,13,86,63,114,89,87,63,26,159,88,63,218,222,89,63,172,24,91,63,138,76,92,63,113,122,93,63,93,162,94,63,78,196,95,63,67,224,96,63,58,246,97,63,54,6,99,63,56,16,100,63,67,20,101,63,92,18,102,63,133,10,103,63,198,252,103,63,37,233,104,63,168,207,105,63,89,176,106,63,64,139,107,63,102,96,108,63,216,47,109,63,159,249,109,63,201,189,110,63,97,124,111,63,118,53,112,63,23,233,112,63,81,151,113,63,53,64,114,63,212,227,114,63,61,130,115,63,131,27,116,63,184,175,116,63,238,62,117,63,56,201,117,63,171,78,118,63,90,207,118,63,90,75,119,63,192,194,119,63,162,53,120,63,21,164,120,63,48,14,121,63,8,116,121,63,182,213,121,63,79,51,122,63,235,140,122,63,162,226,122,63,139,52,123,63,191,130,123,63,85,205,123,63,102,20,124,63,9,88,124,63,88,152,124,63,106,213,124,63,88,15,125,63,58,70,125,63,41,122,125,63,62,171,125,63,143,217,125,63,54,5,126,63,75,46,126,63,228,84,126,63,27,121,126,63,7,155,126,63,190,186,126,63,88,216,126,63,236,243,126,63,144,13,127,63,91,37,127,63,99,59,127,63,188,79,127,63,125,98,127,63,185,115,127,63,135,131,127,63,249,145,127,63,36,159,127,63,26,171,127,63,238,181,127,63,179,191,127,63,122,200,127,63,85,208,127,63,84,215,127,63,136,221,127,63,0,227,127,63,204,231,127,63,249,235,127,63,150,239,127,63,177,242,127,63,85,245,127,63,144,247,127,63,109,249,127,63,246,250,127,63,54,252,127,63,55,253,127,63,1,254,127,63,156,254,127,63,18,255,127,63,103,255,127,63,163,255,127,63,204,255,127,63,229,255,127,63,244,255,127,63,252,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,204,8,120,52,171,134,11,54,79,202,193,54,190,233,61,55,238,247,156,55,192,123,234,55,43,192,35,56,161,2,90,56,189,2,140,56,76,228,174,56,227,165,213,56,199,35,0,57,168,100,23,57,134,149,48,57,104,182,75,57,64,199,104,57,7,228,131,57,105,92,148,57,191,204,165,57,6,53,184,57,65,149,203,57,105,237,223,57,120,61,245,57,184,194,5,58,166,98,17,58,134,126,29,58,81,22,42,58,9,42,55,58,172,185,68,58,54,197,82,58,165,76,97,58,250,79,112,58,47,207,127,58,34,229,135,58,154,32,144,58,255,153,152,58,80,81,161,58,139,70,170,58,174,121,179,58,186,234,188,58,171,153,198,58,129,134,208,58,58,177,218,58,212,25,229,58,79,192,239,58,167,164,250,58,109,227,2,59,117,147,8,59,105,98,14,59,73,80,20,59,19,93,26,59,199,136,32,59,100,211,38,59,232,60,45,59,83,197,51,59,164,108,58,59,218,50,65,59,243,23,72,59,239,27,79,59,204,62,86,59,138,128,93,59,38,225,100,59,161,96,108,59,249,254,115,59,45,188,123,59,29,204,129,59,145,201,133,59,113,214,137,59,188,242,141,59,113,30,146,59,145,89,150,59,26,164,154,59,12,254,158,59,102,103,163,59,40,224,167,59,80,104,172,59,222,255,176,59,209,166,181,59,40,93,186,59,228,34,191,59,2,248,195,59,131,220,200,59,101,208,205,59,168,211,210,59,74,230,215,59,76,8,221,59,172,57,226,59,105,122,231,59,131,202,236,59,249,41,242,59,202,152,247,59,245,22,253,59,60,82,1,60,170,32,4,60,196,246,6,60,137,212,9,60,249,185,12,60,19,167,15,60,216,155,18,60,69,152,21,60,92,156,24,60,26,168,27,60,129,187,30,60,143,214,33,60,69,249,36,60,160,35,40,60,162,85,43,60,73,143,46,60,149,208,49,60,133,25,53,60,26,106,56,60,81,194,59,60,44,34,63,60,168,137,66,60,199,248,69,60,134,111,73,60,230,237,76,60,231,115,80,60,134,1,84,60,197,150,87,60,162,51,91,60,28,216,94,60,52,132,98,60,232,55,102,60,56,243,105,60,35,182,109,60,170,128,113,60,202,82,117,60,131,44,121,60,214,13,125,60,96,123,128,60,161,115,130,60,174,111,132,60,134,111,134,60,40,115,136,60,149,122,138,60,205,133,140,60,206,148,142,60,152,167,144,60,44,190,146,60,136,216,148,60,173,246,150,60,154,24,153,60,78,62,155,60,202,103,157,60,13,149,159,60,23,198,161,60,231,250,163,60,125,51,166,60,217,111,168,60,249,175,170,60,223,243,172,60,137,59,175,60,247,134,177,60,40,214,179,60,29,41,182,60,213,127,184,60,80,218,186,60,140,56,189,60,138,154,191,60,74,0,194,60,202,105,196,60,11,215,198,60,12,72,201,60,205,188,203,60,77,53,206,60,140,177,208,60,137,49,211,60,69,181,213,60,189,60,216,60,243,199,218,60,230,86,221,60,149,233,223,60,0,128,226,60,39,26,229,60,8,184,231,60,164,89,234,60,250,254,236,60,9,168,239,60,210,84,242,60,83,5,245,60,141,185,247,60,126,113,250,60,39,45,253,60,134,236,255,60,206,87,1,61,52,187,2,61,117,32,4,61,144,135,5,61,133,240,6,61,84,91,8,61,253,199,9,61,128,54,11,61,219,166,12,61,16,25,14,61,29,141,15,61,3,3,17,61,193,122,18,61,87,244,19,61,197,111,21,61,10,237,22,61,39,108,24,61,26,237,25,61,228,111,27,61,132,244,28,61,251,122,30,61,71,3,32,61,105,141,33,61,96,25,35,61,45,167,36,61,206,54,38,61,67,200,39,61,141,91,41,61,171,240,42,61,156,135,44,61,96,32,46,61,248,186,47,61,99,87,49,61,160,245,50,61,175,149,52,61,144,55,54,61,67,219,55,61,199,128,57,61,28,40,59,61,65,209,60,61,56,124,62,61,254,40,64,61,148,215,65,61,250,135,67,61,47,58,69,61,51,238,70,61,5,164,72,61,166,91,74,61,20,21,76,61,80,208,77,61,90,141,79,61,49,76,81,61,212,12,83,61,68,207,84,61,128,147,86,61,135,89,88,61,90,33,90,61,248,234,91,61,97,182,93,61,148,131,95,61,145,82,97,61,88,35,99,61,232,245,100,61,65,202,102,61,100,160,104,61,78,120,106,61,1,82,108,61,123,45,110,61,188,10,112,61,197,233,113,61,148,202,115,61,41,173,117,61,133,145,119,61,166,119,121,61,140,95,123,61,55,73,125,61,166,52,127,61,237,144,128,61,105,136,129,61,198,128,130,61,5,122,131,61,37,116,132,61,39,111,133,61,9,107,134,61,204,103,135,61,112,101,136,61,244,99,137,61,88,99,138,61,157,99,139,61,193,100,140,61,196,102,141,61,167,105,142,61,106,109,143,61,11,114,144,61,139,119,145,61,234,125,146,61,40,133,147,61,67,141,148,61,61,150,149,61,20,160,150,61,201,170,151,61,92,182,152,61,203,194,153,61,24,208,154,61,66,222,155,61,72,237,156,61,42,253,157,61,233,13,159,61,132,31,160,61,250,49,161,61,76,69,162,61,122,89,163,61,130,110,164,61,101,132,165,61,35,155,166,61,188,178,167,61,47,203,168,61,124,228,169,61,162,254,170,61,163,25,172,61,124,53,173,61,47,82,174,61,187,111,175,61,31,142,176,61,92,173,177,61,113,205,178,61,94,238,179,61,35,16,181,61,192,50,182,61,52,86,183,61,127,122,184,61,160,159,185,61,153,197,186,61,104,236,187,61,13,20,189,61,136,60,190,61,217,101,191,61,255,143,192,61,250,186,193,61,202,230,194,61,111,19,196,61,233,64,197,61,55,111,198,61,89,158,199,61,78,206,200,61,23,255,201,61,179,48,203,61,35,99,204,61,101,150,205,61,121,202,206,61,96,255,207,61,25,53,209,61,164,107,210,61,0,163,211,61,45,219,212,61,44,20,214,61,251,77,215,61,154,136,216,61,10,196,217,61,74,0,219,61,89,61,220,61,56,123,221,61,230,185,222,61,99,249,223,61,174,57,225,61,200,122,226,61,176,188,227,61,102,255,228,61,233,66,230,61,58,135,231,61,88,204,232,61,66,18,234,61,249,88,235,61,124,160,236,61,203,232,237,61,230,49,239,61,204,123,240,61,125,198,241,61,249,17,243,61,63,94,244,61,79,171,245,61,42,249,246,61,206,71,248,61,60,151,249,61,114,231,250,61,114,56,252,61,58,138,253,61,202,220,254,61,17,24,0,62,33,194,0,62,149,108,1,62,108,23,2,62,166,194,2,62,68,110,3,62,69,26,4,62,168,198,4,62,111,115,5,62,152,32,6,62,35,206,6,62,17,124,7,62,98,42,8,62,20,217,8,62,40,136,9,62,157,55,10,62,117,231,10,62,173,151,11,62,71,72,12,62,66,249,12,62,158,170,13,62,91,92,14,62,120,14,15,62,246,192,15,62,213,115,16,62,19,39,17,62,177,218,17,62,175,142,18,62,13,67,19,62,202,247,19,62,231,172,20,62,99,98,21,62,62,24,22,62,120,206,22,62,16,133,23,62,7,60,24,62,92,243,24,62,16,171,25,62,33,99,26,62,145,27,27,62,94,212,27,62,137,141,28,62,17,71,29,62,246,0,30,62,56,187,30,62,215,117,31,62,211,48,32,62,43,236,32,62,224,167,33,62,241,99,34,62,93,32,35,62,38,221,35,62,74,154,36,62,202,87,37,62,165,21,38,62,219,211,38,62,108,146,39,62,88,81,40,62,159,16,41,62,64,208,41,62,59,144,42,62,144,80,43,62,63,17,44,62,72,210,44,62,170,147,45,62,102,85,46,62,122,23,47,62,232,217,47,62,175,156,48,62,206,95,49,62,69,35,50,62,21,231,50,62,61,171,51,62,189,111,52,62,148,52,53,62,195,249,53,62,73,191,54,62,38,133,55,62,91,75,56,62,230,17,57,62,199,216,57,62,255,159,58,62,141,103,59,62,113,47,60,62,171,247,60,62,59,192,61,62,31,137,62,62,89,82,63,62,232,27,64,62,204,229,64,62,5,176,65,62,146,122,66,62,115,69,67,62,168,16,68,62,49,220,68,62,14,168,69,62,62,116,70,62,194,64,71,62,152,13,72,62,193,218,72,62,61,168,73,62,12,118,74,62,44,68,75,62,159,18,76,62,100,225,76,62,122,176,77,62,225,127,78,62,154,79,79,62,164,31,80,62,255,239,80,62,170,192,81,62,166,145,82,62,242,98,83,62,141,52,84,62,121,6,85,62,180,216,85,62,63,171,86,62,25,126,87,62,65,81,88,62,185,36,89,62,126,248,89,62,147,204,90,62,245,160,91,62,165,117,92,62,163,74,93,62,238,31,94,62,135,245,94,62,109,203,95,62,159,161,96,62,30,120,97,62,233,78,98,62,1,38,99,62,100,253,99,62,19,213,100,62,14,173,101,62,84,133,102,62,229,93,103,62,193,54,104,62,231,15,105,62,88,233,105,62,19,195,106,62,24,157,107,62,103,119,108,62,255,81,109,62,224,44,110,62,11,8,111,62,126,227,111,62,58,191,112,62,62,155,113,62,139,119,114,62,31,84,115,62,251,48,116,62,31,14,117,62,138,235,117,62,59,201,118,62,52,167,119,62,115,133,120,62,248,99,121,62,196,66,122,62,213,33,123,62,44,1,124,62,200,224,124,62,170,192,125,62,208,160,126,62,59,129,127,62,245,48,128,62,111,161,128,62,11,18,129,62,201,130,129,62,168,243,129,62,169,100,130,62,204,213,130,62,15,71,131,62,117,184,131,62,251,41,132,62,162,155,132,62,107,13,133,62,84,127,133,62,93,241,133,62,136,99,134,62,210,213,134,62,61,72,135,62,200,186,135,62,116,45,136,62,63,160,136,62,42,19,137,62,52,134,137,62,94,249,137,62,168,108,138,62,17,224,138,62,153,83,139,62,64,199,139,62,6,59,140,62,235,174,140,62,239,34,141,62,17,151,141,62,82,11,142,62,177,127,142,62,46,244,142,62,201,104,143,62,130,221,143,62,89,82,144,62,78,199,144,62,96,60,145,62,143,177,145,62,220,38,146,62,70,156,146,62,205,17,147,62,113,135,147,62,50,253,147,62,16,115,148,62,9,233,148,62,32,95,149,62,82,213,149,62,161,75,150,62,12,194,150,62,146,56,151,62,53,175,151,62,243,37,152,62,204,156,152,62,193,19,153,62,209,138,153,62,252,1,154,62,66,121,154,62,163,240,154,62,31,104,155,62,181,223,155,62,101,87,156,62,48,207,156,62,21,71,157,62,20,191,157,62,45,55,158,62,96,175,158,62,172,39,159,62,18,160,159,62,145,24,160,62,41,145,160,62,218,9,161,62,165,130,161,62,136,251,161,62,132,116,162,62,152,237,162,62,197,102,163,62,10,224,163,62,103,89,164,62,220,210,164,62,105,76,165,62,14,198,165,62,202,63,166,62,158,185,166,62,137,51,167,62,139,173,167,62,164,39,168,62,213,161,168,62,27,28,169,62,121,150,169,62,237,16,170,62,119,139,170,62,24,6,171,62,206,128,171,62,155,251,171,62,125,118,172,62,117,241,172,62,130,108,173,62,165,231,173,62,221,98,174,62,42,222,174,62,140,89,175,62,2,213,175,62,142,80,176,62,46,204,176,62,226,71,177,62,170,195,177,62,135,63,178,62,119,187,178,62,124,55,179,62,148,179,179,62,191,47,180,62,254,171,180,62,80,40,181,62,181,164,181,62,45,33,182,62,184,157,182,62,85,26,183,62,5,151,183,62,199,19,184,62,156,144,184,62,130,13,185,62,123,138,185,62,133,7,186,62,161,132,186,62,206,1,187,62,13,127,187,62,93,252,187,62,190,121,188,62,48,247,188,62,178,116,189,62,70,242,189,62,233,111,190,62,157,237,190,62,98,107,191,62,54,233,191,62,26,103,192,62,14,229,192,62,17,99,193,62,36,225,193,62,70,95,194,62,119,221,194,62,184,91,195,62,7,218,195,62,100,88,196,62,209,214,196,62,75,85,197,62,212,211,197,62,107,82,198,62,16,209,198,62,195,79,199,62,132,206,199,62,82,77,200,62,45,204,200,62,21,75,201,62,11,202,201,62,13,73,202,62,29,200,202,62,56,71,203,62,97,198,203,62,149,69,204,62,214,196,204,62,34,68,205,62,123,195,205,62,223,66,206,62,79,194,206,62,202,65,207,62,81,193,207,62,226,64,208,62,127,192,208,62,38,64,209,62,216,191,209,62,148,63,210,62,91,191,210,62,44,63,211,62,7,191,211,62,235,62,212,62,218,190,212,62,210,62,213,62,211,190,213,62,222,62,214,62,242,190,214,62,15,63,215,62,53,191,215,62,99,63,216,62,154,191,216,62,217,63,217,62,32,192,217,62,112,64,218,62,199,192,218,62,38,65,219,62,140,193,219,62,250,65,220,62,112,194,220,62,236,66,221,62,112,195,221,62,250,67,222,62,139,196,222,62,34,69,223,62,192,197,223,62,100,70,224,62,14,199,224,62,189,71,225,62,115,200,225,62,46,73,226,62,239,201,226,62,181,74,227,62,127,203,227,62,79,76,228,62,36,205,228,62,253,77,229,62,219,206,229,62,190,79,230,62,164,208,230,62,142,81,231,62,125,210,231,62,111,83,232,62,100,212,232,62,93,85,233,62,89,214,233,62,89,87,234,62,91,216,234,62,96,89,235,62,104,218,235,62,114,91,236,62,126,220,236,62,141,93,237,62,158,222,237,62,176,95,238,62,196,224,238,62,218,97,239,62,241,226,239,62,10,100,240,62,35,229,240,62,62,102,241,62,89,231,241,62,116,104,242,62,145,233,242,62,173,106,243,62,202,235,243,62,230,108,244,62,3,238,244,62,31,111,245,62,59,240,245,62,86,113,246,62,112,242,246,62,137,115,247,62,161,244,247,62,184,117,248,62,206,246,248,62,226,119,249,62,244,248,249,62,4,122,250,62,18,251,250,62,30,124,251,62,40,253,251,62,47,126,252,62,52,255,252,62,54,128,253,62,52,1,254,62,48,130,254,62,40,3,255,62,29,132,255,62,135,2,0,63,254,66,0,63,115,131,0,63,230,195,0,63,86,4,1,63,197,68,1,63,49,133,1,63,155,197,1,63,3,6,2,63,103,70,2,63,202,134,2,63,42,199,2,63,135,7,3,63,225,71,3,63,56,136,3,63,141,200,3,63,222,8,4,63,44,73,4,63,119,137,4,63,191,201,4,63,3,10,5,63,68,74,5,63,130,138,5,63,188,202,5,63,242,10,6,63,36,75,6,63,83,139,6,63,126,203,6,63,165,11,7,63,199,75,7,63,230,139,7,63,1,204,7,63,23,12,8,63,41,76,8,63,54,140,8,63,63,204,8,63,67,12,9,63,67,76,9,63,62,140,9,63,52,204,9,63,37,12,10,63,18,76,10,63,249,139,10,63,219,203,10,63,184,11,11,63,144,75,11,63,98,139,11,63,47,203,11,63,246,10,12,63,184,74,12,63,116,138,12,63,43,202,12,63,219,9,13,63,134,73,13,63,43,137,13,63,202,200,13,63,98,8,14,63,245,71,14,63,129,135,14,63,7,199,14,63,135,6,15,63,0,70,15,63,114,133,15,63,222,196,15,63,67,4,16,63,161,67,16,63,249,130,16,63,73,194,16,63,147,1,17,63,213,64,17,63,17,128,17,63,69,191,17,63,114,254,17,63,151,61,18,63,181,124,18,63,203,187,18,63,218,250,18,63,225,57,19,63,225,120,19,63,216,183,19,63,200,246,19,63,176,53,20,63,143,116,20,63,103,179,20,63,54,242,20,63,253,48,21,63,188,111,21,63,114,174,21,63,32,237,21,63,197,43,22,63,98,106,22,63,246,168,22,63,129,231,22,63,3,38,23,63,125,100,23,63,237,162,23,63,84,225,23,63,178,31,24,63,7,94,24,63,83,156,24,63,149,218,24,63,206,24,25,63,253,86,25,63,35,149,25,63,63,211,25,63,82,17,26,63,90,79,26,63,89,141,26,63,78,203,26,63,57,9,27,63,25,71,27,63,240,132,27,63,188,194,27,63,126,0,28,63,54,62,28,63,227,123,28,63,134,185,28,63,30,247,28,63,172,52,29,63,47,114,29,63,167,175,29,63,20,237,29,63,118,42,30,63,206,103,30,63,26,165,30,63,91,226,30,63,145,31,31,63,188,92,31,63,219,153,31,63,239,214,31,63,247,19,32,63,244,80,32,63,230,141,32,63,203,202,32,63,165,7,33,63,115,68,33,63,53,129,33,63,235,189,33,63,150,250,33,63,52,55,34,63,198,115,34,63,75,176,34,63,197,236,34,63,50,41,35,63,146,101,35,63,230,161,35,63,46,222,35,63,105,26,36,63,151,86,36,63,185,146,36,63,205,206,36,63,213,10,37,63,208,70,37,63,190,130,37,63,158,190,37,63,114,250,37,63,56,54,38,63,241,113,38,63,157,173,38,63,59,233,38,63,204,36,39,63,79,96,39,63,197,155,39,63,45,215,39,63,135,18,40,63,211,77,40,63,18,137,40,63,66,196,40,63,101,255,40,63,121,58,41,63,128,117,41,63,120,176,41,63,98,235,41,63,62,38,42,63,11,97,42,63,202,155,42,63,122,214,42,63,28,17,43,63,175,75,43,63,52,134,43,63,170,192,43,63,16,251,43,63,105,53,44,63,178,111,44,63,236,169,44,63,23,228,44,63,51,30,45,63,64,88,45,63,61,146,45,63,43,204,45,63,10,6,46,63,218,63,46,63,154,121,46,63,74,179,46,63,235,236,46,63,124,38,47,63,254,95,47,63,112,153,47,63,210,210,47,63,36,12,48,63,102,69,48,63,152,126,48,63,186,183,48,63,204,240,48,63,205,41,49,63,191,98,49,63,160,155,49,63,113,212,49,63,49,13,50,63,225,69,50,63,128,126,50,63,15,183,50,63,141,239,50,63,251,39,51,63,87,96,51,63,163,152,51,63,222,208,51,63,8,9,52,63,34,65,52,63,42,121,52,63,33,177,52,63,7,233,52,63,219,32,53,63,159,88,53,63,81,144,53,63,242,199,53,63,129,255,53,63,255,54,54,63,108,110,54,63,198,165,54,63,16,221,54,63,71,20,55,63,109,75,55,63,129,130,55,63,131,185,55,63,116,240,55,63,82,39,56,63,30,94,56,63,217,148,56,63,129,203,56,63,23,2,57,63,155,56,57,63,13,111,57,63,108,165,57,63,185,219,57,63,244,17,58,63,28,72,58,63,50,126,58,63,53,180,58,63,38,234,58,63,4,32,59,63,207,85,59,63,135,139,59,63,45,193,59,63,192,246,59,63,64,44,60,63,173,97,60,63,7,151,60,63,78,204,60,63,130,1,61,63,163,54,61,63,177,107,61,63,171,160,61,63,146,213,61,63,102,10,62,63,39,63,62,63,212,115,62,63,110,168,62,63,244,220,62,63,103,17,63,63,198,69,63,63,17,122,63,63,73,174,63,63,109,226,63,63,126,22,64,63,122,74,64,63,99,126,64,63,56,178,64,63,248,229,64,63,165,25,65,63,62,77,65,63,195,128,65,63,52,180,65,63,144,231,65,63,216,26,66,63,13,78,66,63,44,129,66,63,56,180,66,63,47,231,66,63,18,26,67,63,224,76,67,63,154,127,67,63,64,178,67,63,208,228,67,63,77,23,68,63,180,73,68,63,7,124,68,63,69,174,68,63,111,224,68,63,131,18,69,63,131,68,69,63,110,118,69,63,68,168,69,63,5,218,69,63,177,11,70,63,72,61,70,63,202,110,70,63,55,160,70,63,143,209,70,63,210,2,71,63,255,51,71,63,23,101,71,63,26,150,71,63,8,199,71,63,224,247,71,63,163,40,72,63,81,89,72,63,233,137,72,63,107,186,72,63,216,234,72,63,48,27,73,63,114,75,73,63,158,123,73,63,181,171,73,63,181,219,73,63,161,11,74,63,118,59,74,63,54,107,74,63,224,154,74,63,116,202,74,63,242,249,74,63,90,41,75,63,173,88,75,63,233,135,75,63,15,183,75,63,32,230,75,63,26,21,76,63,254,67,76,63,204,114,76,63,132,161,76,63,38,208,76,63,177,254,76,63,38,45,77,63,133,91,77,63,206,137,77,63,0,184,77,63,28,230,77,63,34,20,78,63,17,66,78,63,234,111,78,63,172,157,78,63,88,203,78,63,238,248,78,63,108,38,79,63,213,83,79,63,38,129,79,63,97,174,79,63,134,219,79,63,147,8,80,63,138,53,80,63,107,98,80,63,52,143,80,63,231,187,80,63,131,232,80,63,8,21,81,63,119,65,81,63,206,109,81,63,15,154,81,63,57,198,81,63,76,242,81,63,71,30,82,63,44,74,82,63,250,117,82,63,177,161,82,63,81,205,82,63,218,248,82,63,76,36,83,63,166,79,83,63,234,122,83,63,22,166,83,63,44,209,83,63,42,252,83,63,17,39,84,63,224,81,84,63,153,124,84,63,58,167,84,63,196,209,84,63,54,252,84,63,146,38,85,63,214,80,85,63,2,123,85,63,24,165,85,63,22,207,85,63,252,248,85,63,204,34,86,63,131,76,86,63,36,118,86,63,172,159,86,63,30,201,86,63,120,242,86,63,186,27,87,63,229,68,87,63,248,109,87,63,244,150,87,63,216,191,87,63,165,232,87,63,90,17,88,63,248,57,88,63,126,98,88,63,236,138,88,63,67,179,88,63,130,219,88,63,169,3,89,63,185,43,89,63,177,83,89,63,145,123,89,63,90,163,89,63,11,203,89,63,164,242,89,63,37,26,90,63,143,65,90,63,225,104,90,63,27,144,90,63,62,183,90,63,72,222,90,63,59,5,91,63,22,44,91,63,217,82,91,63,133,121,91,63,24,160,91,63,148,198,91,63,248,236,91,63,68,19,92,63,120,57,92,63,149,95,92,63,153,133,92,63,134,171,92,63,91,209,92,63,24,247,92,63,189,28,93,63,74,66,93,63,191,103,93,63,28,141,93,63,98,178,93,63,143,215,93,63,165,252,93,63,162,33,94,63,136,70,94,63,86,107,94,63,11,144,94,63,169,180,94,63,47,217,94,63,157,253,94,63,243,33,95,63,49,70,95,63,88,106,95,63,102,142,95,63,92,178,95,63,59,214,95,63,1,250,95,63,175,29,96,63,70,65,96,63,196,100,96,63,43,136,96,63,122,171,96,63,176,206,96,63,207,241,96,63,214,20,97,63,197,55,97,63,155,90,97,63,90,125,97,63,1,160,97,63,144,194,97,63,8,229,97,63,103,7,98,63,174,41,98,63,221,75,98,63,245,109,98,63,244,143,98,63,220,177,98,63,171,211,98,63,99,245,98,63,3,23,99,63,139,56,99,63,251,89,99,63,83,123,99,63,147,156,99,63,188,189,99,63,204,222,99,63,197,255,99,63,166,32,100,63,110,65,100,63,32,98,100,63,185,130,100,63,58,163,100,63,164,195,100,63,245,227,100,63,47,4,101,63,82,36,101,63,92,68,101,63,78,100,101,63,41,132,101,63,236,163,101,63,151,195,101,63,43,227,101,63,167,2,102,63,11,34,102,63,87,65,102,63,139,96,102,63,168,127,102,63,174,158,102,63,155,189,102,63,113,220,102,63,47,251,102,63,214,25,103,63,101,56,103,63,220,86,103,63,59,117,103,63,132,147,103,63,180,177,103,63,205,207,103,63,206,237,103,63,184,11,104,63,138,41,104,63,69,71,104,63,233,100,104,63,116,130,104,63,233,159,104,63,69,189,104,63,139,218,104,63,185,247,104,63,207,20,105,63,207,49,105,63,182,78,105,63,135,107,105,63,64,136,105,63,225,164,105,63,108,193,105,63,223,221,105,63,59,250,105,63,127,22,106,63,172,50,106,63,195,78,106,63,193,106,106,63,169,134,106,63,121,162,106,63,51,190,106,63,213,217,106,63,96,245,106,63,212,16,107,63,48,44,107,63,118,71,107,63,165,98,107,63,188,125,107,63,189,152,107,63,167,179,107,63,121,206,107,63,53,233,107,63,218,3,108,63,104,30,108,63,223,56,108,63,63,83,108,63,136,109,108,63,187,135,108,63,214,161,108,63,219,187,108,63,201,213,108,63,161,239,108,63,97,9,109,63,11,35,109,63,159,60,109,63,27,86,109,63,129,111,109,63,209,136,109,63,9,162,109,63,44,187,109,63,56,212,109,63,45,237,109,63,12,6,110,63,212,30,110,63,134,55,110,63,33,80,110,63,166,104,110,63,21,129,110,63,110,153,110,63,176,177,110,63,220,201,110,63,241,225,110,63,241,249,110,63,218,17,111,63,173,41,111,63,106,65,111,63,16,89,111,63,161,112,111,63,28,136,111,63,128,159,111,63,207,182,111,63,7,206,111,63,42,229,111,63,54,252,111,63,45,19,112,63,14,42,112,63,217,64,112,63,142,87,112,63,46,110,112,63,184,132,112,63,43,155,112,63,138,177,112,63,210,199,112,63,5,222,112,63,35,244,112,63,42,10,113,63,29,32,113,63,249,53,113,63,193,75,113,63,114,97,113,63,15,119,113,63,150,140,113,63,7,162,113,63,99,183,113,63,170,204,113,63,220,225,113,63,249,246,113,63,0,12,114,63,242,32,114,63,207,53,114,63,151,74,114,63,73,95,114,63,231,115,114,63,112,136,114,63,227,156,114,63,66,177,114,63,140,197,114,63,193,217,114,63,225,237,114,63,236,1,115,63,227,21,115,63,197,41,115,63,146,61,115,63,74,81,115,63,238,100,115,63,125,120,115,63,248,139,115,63,94,159,115,63,175,178,115,63,236,197,115,63,21,217,115,63,41,236,115,63,41,255,115,63,21,18,116,63,236,36,116,63,175,55,116,63,94,74,116,63,248,92,116,63,127,111,116,63,241,129,116,63,80,148,116,63,154,166,116,63,208,184,116,63,242,202,116,63,1,221,116,63,251,238,116,63,226,0,117,63,181,18,117,63,116,36,117,63,31,54,117,63,183,71,117,63,59,89,117,63,171,106,117,63,8,124,117,63,81,141,117,63,135,158,117,63,169,175,117,63,184,192,117,63,179,209,117,63,155,226,117,63,112,243,117,63,50,4,118,63,224,20,118,63,123,37,118,63,3,54,118,63,120,70,118,63,217,86,118,63,40,103,118,63,100,119,118,63,140,135,118,63,162,151,118,63,165,167,118,63,149,183,118,63,114,199,118,63,61,215,118,63,245,230,118,63,154,246,118,63,44,6,119,63,172,21,119,63,26,37,119,63,117,52,119,63,189,67,119,63,243,82,119,63,22,98,119,63,40,113,119,63,39,128,119,63,19,143,119,63,238,157,119,63,182,172,119,63,108,187,119,63,16,202,119,63,162,216,119,63,34,231,119,63,144,245,119,63,236,3,120,63,55,18,120,63,111,32,120,63,150,46,120,63,170,60,120,63,174,74,120,63,159,88,120,63,127,102,120,63,77,116,120,63,10,130,120,63,181,143,120,63,79,157,120,63,215,170,120,63,78,184,120,63,180,197,120,63,8,211,120,63,76,224,120,63,126,237,120,63,158,250,120,63,174,7,121,63,173,20,121,63,155,33,121,63,119,46,121,63,67,59,121,63,254,71,121,63,168,84,121,63,66,97,121,63,202,109,121,63,66,122,121,63,169,134,121,63,0,147,121,63,70,159,121,63,124,171,121,63,161,183,121,63,181,195,121,63,186,207,121,63,173,219,121,63,145,231,121,63,100,243,121,63,40,255,121,63,219,10,122,63,126,22,122,63,16,34,122,63,147,45,122,63,6,57,122,63,105,68,122,63,188,79,122,63,255,90,122,63,51,102,122,63,86,113,122,63,106,124,122,63,111,135,122,63,99,146,122,63,72,157,122,63,30,168,122,63,228,178,122,63,155,189,122,63,66,200,122,63,218,210,122,63,99,221,122,63,221,231,122,63,71,242,122,63,162,252,122,63,238,6,123,63,43,17,123,63,89,27,123,63,120,37,123,63,137,47,123,63,138,57,123,63,124,67,123,63,96,77,123,63,53,87,123,63,252,96,123,63,179,106,123,63,92,116,123,63,247,125,123,63,131,135,123,63,1,145,123,63,112,154,123,63,209,163,123,63,36,173,123,63,104,182,123,63,158,191,123,63,198,200,123,63,224,209,123,63,236,218,123,63,234,227,123,63,218,236,123,63,188,245,123,63,144,254,123,63,86,7,124,63,14,16,124,63,185,24,124,63,86,33,124,63,230,41,124,63,104,50,124,63,220,58,124,63,67,67,124,63,156,75,124,63,232,83,124,63,39,92,124,63,88,100,124,63,124,108,124,63,147,116,124,63,157,124,124,63,153,132,124,63,137,140,124,63,107,148,124,63,65,156,124,63,9,164,124,63,197,171,124,63,116,179,124,63,22,187,124,63,172,194,124,63,52,202,124,63,176,209,124,63,32,217,124,63,131,224,124,63,217,231,124,63,35,239,124,63,97,246,124,63,146,253,124,63,183,4,125,63,208,11,125,63,221,18,125,63,221,25,125,63,209,32,125,63,185,39,125,63,150,46,125,63,102,53,125,63,42,60,125,63,227,66,125,63,143,73,125,63,48,80,125,63,197,86,125,63,78,93,125,63,204,99,125,63,62,106,125,63,165,112,125,63,0,119,125,63,80,125,125,63,148,131,125,63,205,137,125,63,251,143,125,63,29,150,125,63,52,156,125,63,64,162,125,63,65,168,125,63,55,174,125,63,34,180,125,63,2,186,125,63,215,191,125,63,161,197,125,63,96,203,125,63,21,209,125,63,190,214,125,63,93,220,125,63,242,225,125,63,124,231,125,63,251,236,125,63,112,242,125,63,218,247,125,63,58,253,125,63,143,2,126,63,219,7,126,63,28,13,126,63,82,18,126,63,127,23,126,63,161,28,126,63,186,33,126,63,200,38,126,63,204,43,126,63,199,48,126,63,183,53,126,63,158,58,126,63,123,63,126,63,78,68,126,63,23,73,126,63,215,77,126,63,141,82,126,63,58,87,126,63,221,91,126,63,118,96,126,63,6,101,126,63,141,105,126,63,10,110,126,63,126,114,126,63,233,118,126,63,75,123,126,63,164,127,126,63,243,131,126,63,57,136,126,63,119,140,126,63,171,144,126,63,214,148,126,63,249,152,126,63,18,157,126,63,35,161,126,63,44,165,126,63,43,169,126,63,34,173,126,63,16,177,126,63,246,180,126,63,211,184,126,63,167,188,126,63,115,192,126,63,55,196,126,63,243,199,126,63,166,203,126,63,81,207,126,63,243,210,126,63,142,214,126,63,32,218,126,63,171,221,126,63,45,225,126,63,167,228,126,63,26,232,126,63,132,235,126,63,231,238,126,63,66,242,126,63,149,245,126,63,224,248,126,63,36,252,126,63,96,255,126,63,148,2,127,63,193,5,127,63,230,8,127,63,4,12,127,63,27,15,127,63,42,18,127,63,50,21,127,63,50,24,127,63,43,27,127,63,29,30,127,63,8,33,127,63,236,35,127,63,201,38,127,63,158,41,127,63,109,44,127,63,53,47,127,63,246,49,127,63,175,52,127,63,99,55,127,63,15,58,127,63,181,60,127,63,83,63,127,63,236,65,127,63,125,68,127,63,8,71,127,63,141,73,127,63,11,76,127,63,131,78,127,63,244,80,127,63,95,83,127,63,195,85,127,63,33,88,127,63,121,90,127,63,203,92,127,63,23,95,127,63,92,97,127,63,155,99,127,63,213,101,127,63,8,104,127,63,54,106,127,63,93,108,127,63,127,110,127,63,155,112,127,63,177,114,127,63,193,116,127,63,203,118,127,63,208,120,127,63,207,122,127,63,201,124,127,63,189,126,127,63,171,128,127,63,148,130,127,63,120,132,127,63,86,134,127,63,47,136,127,63,2,138,127,63,209,139,127,63,153,141,127,63,93,143,127,63,28,145,127,63,213,146,127,63,137,148,127,63,57,150,127,63,227,151,127,63,136,153,127,63,40,155,127,63,196,156,127,63,90,158,127,63,236,159,127,63,121,161,127,63,1,163,127,63,132,164,127,63,3,166,127,63,125,167,127,63,242,168,127,63,99,170,127,63,207,171,127,63,55,173,127,63,154,174,127,63,249,175,127,63,84,177,127,63,170,178,127,63,251,179,127,63,73,181,127,63,146,182,127,63,215,183,127,63,24,185,127,63,85,186,127,63,141,187,127,63,193,188,127,63,242,189,127,63,30,191,127,63,71,192,127,63,107,193,127,63,140,194,127,63,168,195,127,63,193,196,127,63,214,197,127,63,231,198,127,63,245,199,127,63,255,200,127,63,5,202,127,63,7,203,127,63,6,204,127,63,1,205,127,63,249,205,127,63,237,206,127,63,222,207,127,63,203,208,127,63,181,209,127,63,156,210,127,63,127,211,127,63,95,212,127,63,59,213,127,63,20,214,127,63,234,214,127,63,189,215,127,63,141,216,127,63,90,217,127,63,35,218,127,63,233,218,127,63,173,219,127,63,109,220,127,63,43,221,127,63,229,221,127,63,156,222,127,63,81,223,127,63,3,224,127,63,178,224,127,63,94,225,127,63,7,226,127,63,174,226,127,63,82,227,127,63,243,227,127,63,146,228,127,63,46,229,127,63,199,229,127,63,94,230,127,63,242,230,127,63,132,231,127,63,19,232,127,63,160,232,127,63,42,233,127,63,178,233,127,63,56,234,127,63,187,234,127,63,60,235,127,63,187,235,127,63,55,236,127,63,177,236,127,63,41,237,127,63,159,237,127,63,18,238,127,63,132,238,127,63,243,238,127,63,96,239,127,63,204,239,127,63,53,240,127,63,156,240,127,63,1,241,127,63,101,241,127,63,198,241,127,63,37,242,127,63,131,242,127,63,222,242,127,63,56,243,127,63,144,243,127,63,231,243,127,63,59,244,127,63,142,244,127,63,223,244,127,63,46,245,127,63,124,245,127,63,200,245,127,63,19,246,127,63,91,246,127,63,163,246,127,63,233,246,127,63,45,247,127,63,111,247,127,63,177,247,127,63,240,247,127,63,47,248,127,63,108,248,127,63,167,248,127,63,225,248,127,63,26,249,127,63,82,249,127,63,136,249,127,63,188,249,127,63,240,249,127,63,34,250,127,63,83,250,127,63,131,250,127,63,178,250,127,63,224,250,127,63,12,251,127,63,55,251,127,63,97,251,127,63,138,251,127,63,178,251,127,63,217,251,127,63,255,251,127,63,36,252,127,63,72,252,127,63,107,252,127,63,141,252,127,63,173,252,127,63,205,252,127,63,237,252,127,63,11,253,127,63,40,253,127,63,69,253,127,63,96,253,127,63,123,253,127,63,149,253,127,63,174,253,127,63,199,253,127,63,222,253,127,63,245,253,127,63,12,254,127,63,33,254,127,63,54,254,127,63,74,254,127,63,93,254,127,63,112,254,127,63,130,254,127,63,148,254,127,63,165,254,127,63,181,254,127,63,197,254,127,63,212,254,127,63,227,254,127,63,241,254,127,63,254,254,127,63,11,255,127,63,24,255,127,63,36,255,127,63,47,255,127,63,59,255,127,63,69,255,127,63,79,255,127,63,89,255,127,63,99,255,127,63,108,255,127,63,116,255,127,63,124,255,127,63,132,255,127,63,140,255,127,63,147,255,127,63,154,255,127,63,160,255,127,63,166,255,127,63,172,255,127,63,178,255,127,63,183,255,127,63,188,255,127,63,193,255,127,63,197,255,127,63,202,255,127,63,206,255,127,63,209,255,127,63,213,255,127,63,216,255,127,63,220,255,127,63,223,255,127,63,225,255,127,63,228,255,127,63,230,255,127,63,233,255,127,63,235,255,127,63,237,255,127,63,239,255,127,63,240,255,127,63,242,255,127,63,243,255,127,63,245,255,127,63,246,255,127,63,247,255,127,63,248,255,127,63,249,255,127,63,250,255,127,63,251,255,127,63,251,255,127,63,252,255,127,63,252,255,127,63,253,255,127,63,253,255,127,63,254,255,127,63,254,255,127,63,254,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,5,12,120,56,50,131,11,58,118,186,193,58,226,203,61,59,38,207,156,59,139,32,234,59,245,102,35,60,63,100,89,60,184,127,139,60,59,23,174,60,239,114,212,60,96,140,254,60,45,46,22,61,114,237,46,61,155,127,73,61,220,223,101,61,123,4,130,61,159,250,145,61,71,207,162,61,38,127,180,61,173,6,199,61,16,98,218,61,63,141,238,61,244,193,1,62,185,160,12,62,128,224,23,62,182,126,35,62,166,120,47,62,116,203,59,62,34,116,72,62,141,111,85,62,107,186,98,62,83,81,112,62,180,48,126,62,110,42,134,62,252,92,141,62,9,174,148,62,138,27,156,62,100,163,163,62,112,67,171,62,119,249,178,62,54,195,186,62,93,158,194,62,147,136,202,62,118,127,210,62,154,128,218,62,142,137,226,62,217,151,234,62,2,169,242,62,139,186,250,62,251,100,1,63,99,106,5,63,65,108,9,63,89,105,13,63,116,96,17,63,94,80,21,63,231,55,25,63,231,21,29,63,58,233,32,63,197,176,36,63,116,107,40,63,62,24,44,63,35,182,47,63,43,68,51,63,109,193,54,63,10,45,58,63,48,134,61,63,26,204,64,63,17,254,67,63,107,27,71,63,142,35,74,63,238,21,77,63,15,242,79,63,132,183,82,63,239,101,85,63,3,253,87,63,129,124,90,63,60,228,92,63,21,52,95,63,254,107,97,63,246,139,99,63,14,148,101,63,98,132,103,63,33,93,105,63,133,30,107,63,213,200,108,63,103,92,110,63,155,217,111,63,224,64,113,63,172,146,114,63,131,207,115,63,241,247,116,63,139,12,118,63,239,13,119,63,193,252,119,63,172,217,120,63,99,165,121,63,155,96,122,63,15,12,123,63,124,168,123,63,163,54,124,63,71,183,124,63,41,43,125,63,13,147,125,63,183,239,125,63,229,65,126,63,89,138,126,63,205,201,126,63,251,0,127,63,150,48,127,63,78,89,127,63,205,123,127,63,182,152,127,63,167,176,127,63,53,196,127,63,239,211,127,63,91,224,127,63,245,233,127,63,51,241,127,63,127,246,127,63,59,250,127,63,190,252,127,63,84,254,127,63,64,255,127,63,186,255,127,63,238,255,127,63,254,255,127,63,0,0,128,63,171,15,120,53,24,135,11,55,225,201,193,55,107,233,61,56,128,247,156,56,187,122,234,56,24,191,35,57,213,0,90,57,56,1,140,57,229,225,174,57,88,162,213,57,60,33,0,58,24,97,23,58,175,144,48,58,243,175,75,58,212,190,104,58,159,222,131,58,143,85,148,58,48,196,165,58,119,42,184,58,90,136,203,58,204,221,223,58,191,42,245,58,148,183,5,59,124,85,17,59,16,111,29,59,73,4,42,59,31,21,55,59,138,161,68,59,129,169,82,59,252,44,97,59,241,43,112,59,88,166,127,59,19,206,135,59,169,6,144,59,233,124,152,59,204,48,161,59,79,34,170,59,106,81,179,59,26,190,188,59,86,104,198,59,26,80,208,59,95,117,218,59,31,216,228,59,83,120,239,59,244,85,250,59,126,184,2,60,177,100,8,60,145,47,14,60,25,25,20,60,70,33,26,60,19,72,32,60,126,141,38,60,129,241,44,60,25,116,51,60,65,21,58,60,246,212,64,60,50,179,71,60,243,175,78,60,50,203,85,60,235,4,93,60,26,93,100,60,186,211,107,60,198,104,115,60,58,28,123,60,7,119,129,60,33,111,133,60,102,118,137,60,212,140,141,60,105,178,145,60,33,231,149,60,251,42,154,60,243,125,158,60,6,224,162,60,50,81,167,60,115,209,171,60,199,96,176,60,43,255,180,60,154,172,185,60,19,105,190,60,146,52,195,60,20,15,200,60,149,248,204,60,19,241,209,60,137,248,214,60,245,14,220,60,83,52,225,60,160,104,230,60,215,171,235,60,246,253,240,60,249,94,246,60,220,206,251,60,205,166,0,61,153,109,3,61,207,59,6,61,109,17,9,61,114,238,11,61,220,210,14,61,167,190,17,61,211,177,20,61,94,172,23,61,68,174,26,61,133,183,29,61,30,200,32,61,12,224,35,61,78,255,38,61,225,37,42,61,196,83,45,61,243,136,48,61,109,197,51,61,47,9,55,61,55,84,58,61,130,166,61,61,15,0,65,61,218,96,68,61,226,200,71,61,35,56,75,61,156,174,78,61,73,44,82,61,40,177,85,61,55,61,89,61,115,208,92,61,217,106,96,61,103,12,100,61,25,181,103,61,238,100,107,61,227,27,111,61,244,217,114,61,30,159,118,61,96,107,122,61,182,62,126,61,143,12,129,61], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+174080);
/* memory initializer */ allocate([73,253,130,61,138,241,132,61,79,233,134,61,150,228,136,61,94,227,138,61,167,229,140,61,109,235,142,61,175,244,144,61,109,1,147,61,164,17,149,61,83,37,151,61,120,60,153,61,17,87,155,61,30,117,157,61,155,150,159,61,136,187,161,61,226,227,163,61,169,15,166,61,218,62,168,61,116,113,170,61,116,167,172,61,218,224,174,61,162,29,177,61,205,93,179,61,87,161,181,61,62,232,183,61,130,50,186,61,32,128,188,61,22,209,190,61,98,37,193,61,2,125,195,61,245,215,197,61,57,54,200,61,203,151,202,61,169,252,204,61,211,100,207,61,68,208,209,61,252,62,212,61,249,176,214,61,56,38,217,61,184,158,219,61,117,26,222,61,111,153,224,61,163,27,227,61,14,161,229,61,175,41,232,61,132,181,234,61,138,68,237,61,191,214,239,61,33,108,242,61,174,4,245,61,99,160,247,61,62,63,250,61,61,225,252,61,93,134,255,61,78,23,1,62,252,108,2,62,56,196,3,62,255,28,5,62,81,119,6,62,45,211,7,62,145,48,9,62,125,143,10,62,238,239,11,62,228,81,13,62,94,181,14,62,89,26,16,62,214,128,17,62,210,232,18,62,77,82,20,62,69,189,21,62,184,41,23,62,166,151,24,62,13,7,26,62,236,119,27,62,65,234,28,62,11,94,30,62,73,211,31,62,250,73,33,62,28,194,34,62,173,59,36,62,172,182,37,62,24,51,39,62,240,176,40,62,50,48,42,62,220,176,43,62,238,50,45,62,101,182,46,62,64,59,48,62,126,193,49,62,30,73,51,62,29,210,52,62,123,92,54,62,54,232,55,62,76,117,57,62,187,3,59,62,131,147,60,62,162,36,62,62,22,183,63,62,222,74,65,62,248,223,66,62,98,118,68,62,28,14,70,62,35,167,71,62,117,65,73,62,18,221,74,62,247,121,76,62,35,24,78,62,149,183,79,62,74,88,81,62,66,250,82,62,121,157,84,62,240,65,86,62,163,231,87,62,146,142,89,62,186,54,91,62,26,224,92,62,177,138,94,62,124,54,96,62,122,227,97,62,169,145,99,62,7,65,101,62,147,241,102,62,75,163,104,62,44,86,106,62,54,10,108,62,102,191,109,62,187,117,111,62,51,45,113,62,204,229,114,62,132,159,116,62,90,90,118,62,75,22,120,62,85,211,121,62,120,145,123,62,176,80,125,62,253,16,127,62,46,105,128,62,101,74,129,62,36,44,130,62,105,14,131,62,52,241,131,62,130,212,132,62,84,184,133,62,169,156,134,62,127,129,135,62,213,102,136,62,171,76,137,62,255,50,138,62,209,25,139,62,32,1,140,62,233,232,140,62,46,209,141,62,236,185,142,62,34,163,143,62,208,140,144,62,244,118,145,62,142,97,146,62,156,76,147,62,29,56,148,62,17,36,149,62,118,16,150,62,76,253,150,62,144,234,151,62,67,216,152,62,99,198,153,62,239,180,154,62,230,163,155,62,71,147,156,62,17,131,157,62,67,115,158,62,219,99,159,62,218,84,160,62,60,70,161,62,3,56,162,62,43,42,163,62,181,28,164,62,160,15,165,62,233,2,166,62,145,246,166,62,149,234,167,62,245,222,168,62,176,211,169,62,197,200,170,62,50,190,171,62,246,179,172,62,17,170,173,62,129,160,174,62,69,151,175,62,91,142,176,62,196,133,177,62,125,125,178,62,133,117,179,62,220,109,180,62,128,102,181,62,112,95,182,62,171,88,183,62,47,82,184,62,252,75,185,62,17,70,186,62,108,64,187,62,11,59,188,62,239,53,189,62,22,49,190,62,126,44,191,62,38,40,192,62,13,36,193,62,51,32,194,62,150,28,195,62,52,25,196,62,12,22,197,62,30,19,198,62,104,16,199,62,233,13,200,62,159,11,201,62,138,9,202,62,169,7,203,62,249,5,204,62,123,4,205,62,44,3,206,62,11,2,207,62,24,1,208,62,81,0,209,62,181,255,209,62,66,255,210,62,248,254,211,62,213,254,212,62,216,254,213,62,255,254,214,62,75,255,215,62,184,255,216,62,71,0,218,62,245,0,219,62,195,1,220,62,173,2,221,62,180,3,222,62,214,4,223,62,17,6,224,62,101,7,225,62,208,8,226,62,81,10,227,62,231,11,228,62,144,13,229,62,76,15,230,62,25,17,231,62,245,18,232,62,224,20,233,62,217,22,234,62,221,24,235,62,236,26,236,62,5,29,237,62,39,31,238,62,79,33,239,62,125,35,240,62,176,37,241,62,230,39,242,62,31,42,243,62,88,44,244,62,145,46,245,62,200,48,246,62,253,50,247,62,45,53,248,62,88,55,249,62,124,57,250,62,153,59,251,62,172,61,252,62,181,63,253,62,179,65,254,62,163,67,255,62,195,34,0,63,173,163,0,63,142,36,1,63,102,165,1,63,53,38,2,63,250,166,2,63,180,39,3,63,99,168,3,63,5,41,4,63,155,169,4,63,36,42,5,63,159,170,5,63,12,43,6,63,105,171,6,63,183,43,7,63,244,171,7,63,32,44,8,63,59,172,8,63,68,44,9,63,58,172,9,63,28,44,10,63,235,171,10,63,164,43,11,63,73,171,11,63,216,42,12,63,80,170,12,63,177,41,13,63,251,168,13,63,44,40,14,63,69,167,14,63,68,38,15,63,41,165,15,63,243,35,16,63,162,162,16,63,53,33,17,63,172,159,17,63,5,30,18,63,65,156,18,63,95,26,19,63,94,152,19,63,61,22,20,63,252,147,20,63,155,17,21,63,24,143,21,63,116,12,22,63,173,137,22,63,195,6,23,63,182,131,23,63,133,0,24,63,46,125,24,63,179,249,24,63,18,118,25,63,74,242,25,63,91,110,26,63,69,234,26,63,6,102,27,63,159,225,27,63,14,93,28,63,84,216,28,63,111,83,29,63,95,206,29,63,36,73,30,63,188,195,30,63,40,62,31,63,102,184,31,63,119,50,32,63,90,172,32,63,14,38,33,63,146,159,33,63,230,24,34,63,10,146,34,63,253,10,35,63,190,131,35,63,77,252,35,63,169,116,36,63,211,236,36,63,200,100,37,63,138,220,37,63,22,84,38,63,110,203,38,63,143,66,39,63,122,185,39,63,47,48,40,63,172,166,40,63,241,28,41,63,254,146,41,63,210,8,42,63,108,126,42,63,205,243,42,63,243,104,43,63,223,221,43,63,143,82,44,63,3,199,44,63,59,59,45,63,54,175,45,63,244,34,46,63,116,150,46,63,182,9,47,63,185,124,47,63,125,239,47,63,1,98,48,63,69,212,48,63,72,70,49,63,10,184,49,63,139,41,50,63,202,154,50,63,198,11,51,63,127,124,51,63,246,236,51,63,40,93,52,63,22,205,52,63,191,60,53,63,36,172,53,63,66,27,54,63,27,138,54,63,174,248,54,63,249,102,55,63,254,212,55,63,187,66,56,63,47,176,56,63,91,29,57,63,63,138,57,63,217,246,57,63,41,99,58,63,48,207,58,63,236,58,59,63,93,166,59,63,130,17,60,63,93,124,60,63,235,230,60,63,44,81,61,63,33,187,61,63,201,36,62,63,35,142,62,63,48,247,62,63,238,95,63,63,94,200,63,63,126,48,64,63,80,152,64,63,209,255,64,63,3,103,65,63,228,205,65,63,117,52,66,63,181,154,66,63,163,0,67,63,64,102,67,63,139,203,67,63,131,48,68,63,41,149,68,63,124,249,68,63,123,93,69,63,39,193,69,63,127,36,70,63,132,135,70,63,51,234,70,63,142,76,71,63,148,174,71,63,68,16,72,63,159,113,72,63,164,210,72,63,83,51,73,63,172,147,73,63,174,243,73,63,89,83,74,63,173,178,74,63,169,17,75,63,77,112,75,63,154,206,75,63,143,44,76,63,43,138,76,63,110,231,76,63,89,68,77,63,234,160,77,63,34,253,77,63,0,89,78,63,133,180,78,63,176,15,79,63,128,106,79,63,246,196,79,63,18,31,80,63,210,120,80,63,56,210,80,63,66,43,81,63,242,131,81,63,69,220,81,63,61,52,82,63,217,139,82,63,24,227,82,63,252,57,83,63,131,144,83,63,174,230,83,63,123,60,84,63,236,145,84,63,0,231,84,63,183,59,85,63,16,144,85,63,12,228,85,63,170,55,86,63,235,138,86,63,206,221,86,63,83,48,87,63,121,130,87,63,66,212,87,63,172,37,88,63,184,118,88,63,101,199,88,63,180,23,89,63,164,103,89,63,53,183,89,63,104,6,90,63,59,85,90,63,175,163,90,63,197,241,90,63,123,63,91,63,210,140,91,63,201,217,91,63,97,38,92,63,154,114,92,63,115,190,92,63,237,9,93,63,7,85,93,63,194,159,93,63,29,234,93,63,24,52,94,63,179,125,94,63,239,198,94,63,203,15,95,63,72,88,95,63,100,160,95,63,33,232,95,63,126,47,96,63,123,118,96,63,24,189,96,63,85,3,97,63,51,73,97,63,177,142,97,63,207,211,97,63,141,24,98,63,236,92,98,63,235,160,98,63,138,228,98,63,202,39,99,63,170,106,99,63,42,173,99,63,75,239,99,63,13,49,100,63,111,114,100,63,114,179,100,63,21,244,100,63,90,52,101,63,63,116,101,63,197,179,101,63,236,242,101,63,180,49,102,63,29,112,102,63,39,174,102,63,211,235,102,63,32,41,103,63,15,102,103,63,159,162,103,63,209,222,103,63,164,26,104,63,26,86,104,63,49,145,104,63,235,203,104,63,71,6,105,63,69,64,105,63,230,121,105,63,42,179,105,63,16,236,105,63,153,36,106,63,197,92,106,63,148,148,106,63,7,204,106,63,29,3,107,63,214,57,107,63,52,112,107,63,53,166,107,63,218,219,107,63,36,17,108,63,18,70,108,63,164,122,108,63,220,174,108,63,184,226,108,63,57,22,109,63,96,73,109,63,44,124,109,63,157,174,109,63,181,224,109,63,115,18,110,63,214,67,110,63,225,116,110,63,146,165,110,63,233,213,110,63,232,5,111,63,142,53,111,63,219,100,111,63,209,147,111,63,110,194,111,63,179,240,111,63,160,30,112,63,54,76,112,63,117,121,112,63,93,166,112,63,239,210,112,63,41,255,112,63,14,43,113,63,156,86,113,63,213,129,113,63,184,172,113,63,70,215,113,63,127,1,114,63,99,43,114,63,243,84,114,63,46,126,114,63,21,167,114,63,169,207,114,63,233,247,114,63,214,31,115,63,113,71,115,63,184,110,115,63,173,149,115,63,80,188,115,63,162,226,115,63,161,8,116,63,80,46,116,63,174,83,116,63,187,120,116,63,119,157,116,63,228,193,116,63,1,230,116,63,206,9,117,63,76,45,117,63,123,80,117,63,92,115,117,63,238,149,117,63,51,184,117,63,42,218,117,63,211,251,117,63,48,29,118,63,64,62,118,63,3,95,118,63,122,127,118,63,166,159,118,63,134,191,118,63,27,223,118,63,101,254,118,63,101,29,119,63,27,60,119,63,135,90,119,63,169,120,119,63,131,150,119,63,19,180,119,63,91,209,119,63,91,238,119,63,20,11,120,63,132,39,120,63,174,67,120,63,145,95,120,63,46,123,120,63,132,150,120,63,149,177,120,63,96,204,120,63,231,230,120,63,41,1,121,63,38,27,121,63,223,52,121,63,85,78,121,63,136,103,121,63,120,128,121,63,37,153,121,63,144,177,121,63,185,201,121,63,161,225,121,63,72,249,121,63,174,16,122,63,212,39,122,63,185,62,122,63,96,85,122,63,198,107,122,63,238,129,122,63,216,151,122,63,131,173,122,63,241,194,122,63,33,216,122,63,20,237,122,63,202,1,123,63,68,22,123,63,130,42,123,63,133,62,123,63,77,82,123,63,217,101,123,63,43,121,123,63,68,140,123,63,34,159,123,63,200,177,123,63,52,196,123,63,104,214,123,63,99,232,123,63,39,250,123,63,180,11,124,63,9,29,124,63,40,46,124,63,17,63,124,63,196,79,124,63,65,96,124,63,137,112,124,63,156,128,124,63,124,144,124,63,39,160,124,63,158,175,124,63,226,190,124,63,244,205,124,63,211,220,124,63,128,235,124,63,251,249,124,63,69,8,125,63,94,22,125,63,71,36,125,63,255,49,125,63,136,63,125,63,225,76,125,63,11,90,125,63,7,103,125,63,212,115,125,63,115,128,125,63,229,140,125,63,42,153,125,63,66,165,125,63,46,177,125,63,238,188,125,63,130,200,125,63,235,211,125,63,41,223,125,63,61,234,125,63,38,245,125,63,230,255,125,63,124,10,126,63,234,20,126,63,47,31,126,63,75,41,126,63,64,51,126,63,13,61,126,63,180,70,126,63,51,80,126,63,140,89,126,63,191,98,126,63,205,107,126,63,181,116,126,63,120,125,126,63,23,134,126,63,146,142,126,63,233,150,126,63,28,159,126,63,44,167,126,63,26,175,126,63,229,182,126,63,142,190,126,63,22,198,126,63,124,205,126,63,194,212,126,63,231,219,126,63,235,226,126,63,208,233,126,63,149,240,126,63,59,247,126,63,195,253,126,63,44,4,127,63,118,10,127,63,163,16,127,63,179,22,127,63,165,28,127,63,123,34,127,63,52,40,127,63,210,45,127,63,83,51,127,63,186,56,127,63,5,62,127,63,53,67,127,63,75,72,127,63,72,77,127,63,42,82,127,63,243,86,127,63,163,91,127,63,58,96,127,63,185,100,127,63,32,105,127,63,111,109,127,63,166,113,127,63,199,117,127,63,208,121,127,63,196,125,127,63,161,129,127,63,104,133,127,63,25,137,127,63,182,140,127,63,61,144,127,63,176,147,127,63,14,151,127,63,89,154,127,63,143,157,127,63,179,160,127,63,195,163,127,63,192,166,127,63,171,169,127,63,132,172,127,63,74,175,127,63,255,177,127,63,163,180,127,63,53,183,127,63,183,185,127,63,40,188,127,63,137,190,127,63,217,192,127,63,26,195,127,63,76,197,127,63,111,199,127,63,130,201,127,63,135,203,127,63,126,205,127,63,102,207,127,63,65,209,127,63,14,211,127,63,205,212,127,63,128,214,127,63,38,216,127,63,191,217,127,63,76,219,127,63,204,220,127,63,65,222,127,63,170,223,127,63,8,225,127,63,91,226,127,63,163,227,127,63,224,228,127,63,19,230,127,63,59,231,127,63,90,232,127,63,110,233,127,63,122,234,127,63,124,235,127,63,116,236,127,63,100,237,127,63,75,238,127,63,42,239,127,63,1,240,127,63,207,240,127,63,149,241,127,63,84,242,127,63,12,243,127,63,188,243,127,63,101,244,127,63,7,245,127,63,162,245,127,63,55,246,127,63,198,246,127,63,78,247,127,63,209,247,127,63,77,248,127,63,196,248,127,63,54,249,127,63,162,249,127,63,9,250,127,63,108,250,127,63,201,250,127,63,34,251,127,63,118,251,127,63,198,251,127,63,18,252,127,63,89,252,127,63,157,252,127,63,221,252,127,63,26,253,127,63,83,253,127,63,136,253,127,63,187,253,127,63,234,253,127,63,22,254,127,63,64,254,127,63,103,254,127,63,139,254,127,63,173,254,127,63,204,254,127,63,234,254,127,63,5,255,127,63,30,255,127,63,53,255,127,63,74,255,127,63,94,255,127,63,112,255,127,63,128,255,127,63,143,255,127,63,157,255,127,63,169,255,127,63,180,255,127,63,191,255,127,63,200,255,127,63,208,255,127,63,215,255,127,63,221,255,127,63,227,255,127,63,232,255,127,63,236,255,127,63,239,255,127,63,243,255,127,63,245,255,127,63,248,255,127,63,249,255,127,63,251,255,127,63,252,255,127,63,253,255,127,63,254,255,127,63,255,255,127,63,255,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,168,9,120,57,17,119,11,59,135,139,193,59,74,113,61,60,148,82,156,60,94,8,233,60,42,83,34,61,74,118,87,61,138,227,137,61,7,140,171,61,34,154,208,61,108,239,248,61,164,52,18,62,100,112,41,62,65,21,66,62,67,11,92,62,47,56,119,62,197,191,137,62,92,97,152,62,135,112,167,62,4,220,182,62,188,145,198,62,231,126,214,62,48,144,230,62,227,177,246,62,13,104,3,63,121,107,11,63,98,89,19,63,42,40,27,63,137,206,34,63,166,67,42,63,49,127,49,63,126,121,56,63,153,43,63,63,92,143,69,63,127,159,75,63,165,87,81,63,104,180,86,63,89,179,91,63,8,83,96,63,252,146,100,63,177,115,104,63,138,246,107,63,198,29,111,63,109,236,113,63,62,102,116,63,154,143,118,63,104,109,120,63,3,5,122,63,26,92,123,63,153,120,124,63,143,96,125,63,17,26,126,63,39,171,126,63,176,25,127,63,74,107,127,63,68,165,127,63,132,204,127,63,123,229,127,63,17,244,127,63,158,251,127,63,219,254,127,63,218,255,127,63,0,0,128,63,60,12,120,54,253,134,11,56,19,201,193,56,248,231,61,57,148,245,156,57,115,118,234,57,238,186,35,58,113,249,89,58,32,251,139,58,96,216,174,58,34,148,213,58,3,23,0,59,209,82,23,59,65,125,48,59,21,150,75,59,8,157,104,59,233,200,131,59,20,58,148,59,218,161,165,59,16,0,184,59,136,84,203,59,16,159,223,59,118,223,244,59,194,138,5,60,128,32,17,60,217,48,29,60,172,187,41,60,219,192,54,60,67,64,68,60,194,57,82,60,52,173,96,60,115,154,111,60,88,1,127,60,222,112,135,60,186,157,143,60,42,7,152,60,25,173,160,60,112,143,169,60,23,174,178,60,246,8,188,60,243,159,197,60,245,114,207,60,225,129,217,60,156,204,227,60,10,83,238,60,14,21,249,60,70,9,2,61,177,165,7,61,187,95,13,61,81,55,19,61,102,44,25,61,230,62,31,61,195,110,37,61,233,187,43,61,71,38,50,61,202,173,56,61,97,82,63,61,247,19,70,61,121,242,76,61,210,237,83,61,240,5,91,61,187,58,98,61,32,140,105,61,8,250,112,61,93,132,120,61,132,21,128,61,249,246,131,61,130,230,135,61,19,228,139,61,159,239,143,61,26,9,148,61,119,48,152,61,169,101,156,61,163,168,160,61,88,249,164,61,186,87,169,61,186,195,173,61,76,61,178,61,95,196,182,61,230,88,187,61,209,250,191,61,18,170,196,61,152,102,201,61,85,48,206,61,56,7,211,61,48,235,215,61,47,220,220,61,34,218,225,61,248,228,230,61,161,252,235,61,11,33,241,61,35,82,246,61,217,143,251,61,13,109,0,62,105,24,3,62,247,201,5,62,174,129,8,62,133,63,11,62,113,3,14,62,104,205,16,62,96,157,19,62,79,115,22,62,42,79,25,62,232,48,28,62,124,24,31,62,221,5,34,62,255,248,36,62,215,241,39,62,90,240,42,62,125,244,45,62,51,254,48,62,114,13,52,62,45,34,55,62,88,60,58,62,232,91,61,62,208,128,64,62,3,171,67,62,118,218,70,62,26,15,74,62,229,72,77,62,199,135,80,62,181,203,83,62,162,20,87,62,127,98,90,62,63,181,93,62,213,12,97,62,50,105,100,62,73,202,103,62,12,48,107,62,108,154,110,62,92,9,114,62,203,124,117,62,173,244,120,62,241,112,124,62,138,241,127,62,52,187,129,62,190,127,131,62,91,70,133,62,4,15,135,62,176,217,136,62,89,166,138,62,245,116,140,62,126,69,142,62,234,23,144,62,50,236,145,62,78,194,147,62,54,154,149,62,224,115,151,62,70,79,153,62,93,44,155,62,31,11,157,62,130,235,158,62,127,205,160,62,11,177,162,62,31,150,164,62,177,124,166,62,186,100,168,62,47,78,170,62,9,57,172,62,62,37,174,62,198,18,176,62,150,1,178,62,167,241,179,62,238,226,181,62,100,213,183,62,254,200,185,62,179,189,187,62,122,179,189,62,74,170,191,62,25,162,193,62,221,154,195,62,142,148,197,62,34,143,199,62,142,138,201,62,203,134,203,62,205,131,205,62,140,129,207,62,253,127,209,62,24,127,211,62,210,126,213,62,33,127,215,62,252,127,217,62,88,129,219,62,45,131,221,62,112,133,223,62,23,136,225,62,25,139,227,62,108,142,229,62,5,146,231,62,219,149,233,62,228,153,235,62,21,158,237,62,102,162,239,62,203,166,241,62,59,171,243,62,173,175,245,62,21,180,247,62,107,184,249,62,164,188,251,62,181,192,253,62,150,196,255,62,30,228,0,63,207,229,1,63,88,231,2,63,182,232,3,63,226,233,4,63,215,234,5,63,146,235,6,63,12,236,7,63,66,236,8,63,45,236,9,63,202,235,10,63,19,235,11,63,4,234,12,63,151,232,13,63,200,230,14,63,145,228,15,63,239,225,16,63,220,222,17,63,84,219,18,63,81,215,19,63,208,210,20,63,202,205,21,63,61,200,22,63,34,194,23,63,117,187,24,63,50,180,25,63,85,172,26,63,215,163,27,63,182,154,28,63,236,144,29,63,117,134,30,63,77,123,31,63,110,111,32,63,214,98,33,63,126,85,34,63,100,71,35,63,130,56,36,63,212,40,37,63,87,24,38,63,5,7,39,63,219,244,39,63,213,225,40,63,239,205,41,63,36,185,42,63,113,163,43,63,209,140,44,63,64,117,45,63,188,92,46,63,63,67,47,63,199,40,48,63,78,13,49,63,211,240,49,63,80,211,50,63,195,180,51,63,39,149,52,63,122,116,53,63,184,82,54,63,220,47,55,63,229,11,56,63,206,230,56,63,149,192,57,63,54,153,58,63,174,112,59,63,249,70,60,63,21,28,61,63,255,239,61,63,179,194,62,63,48,148,63,63,113,100,64,63,116,51,65,63,55,1,66,63,182,205,66,63,239,152,67,63,224,98,68,63,134,43,69,63,222,242,69,63,230,184,70,63,156,125,71,63,253,64,72,63,7,3,73,63,184,195,73,63,14,131,74,63,6,65,75,63,159,253,75,63,215,184,76,63,172,114,77,63,28,43,78,63,38,226,78,63,199,151,79,63,253,75,80,63,201,254,80,63,39,176,81,63,22,96,82,63,150,14,83,63,164,187,83,63,63,103,84,63,103,17,85,63,26,186,85,63,86,97,86,63,28,7,87,63,105,171,87,63,62,78,88,63,152,239,88,63,120,143,89,63,221,45,90,63,198,202,90,63,50,102,91,63,33,0,92,63,147,152,92,63,134,47,93,63,251,196,93,63,242,88,94,63,105,235,94,63,98,124,95,63,219,11,96,63,213,153,96,63,80,38,97,63,76,177,97,63,201,58,98,63,199,194,98,63,70,73,99,63,71,206,99,63,202,81,100,63,208,211,100,63,88,84,101,63,100,211,101,63,244,80,102,63,9,205,102,63,163,71,103,63,195,192,103,63,107,56,104,63,154,174,104,63,82,35,105,63,147,150,105,63,96,8,106,63,184,120,106,63,157,231,106,63,16,85,107,63,19,193,107,63,166,43,108,63,203,148,108,63,132,252,108,63,209,98,109,63,180,199,109,63,48,43,110,63,68,141,110,63,244,237,110,63,64,77,111,63,42,171,111,63,181,7,112,63,225,98,112,63,177,188,112,63,38,21,113,63,67,108,113,63,10,194,113,63,123,22,114,63,155,105,114,63,106,187,114,63,234,11,115,63,31,91,115,63,9,169,115,63,172,245,115,63,9,65,116,63,35,139,116,63,252,211,116,63,151,27,117,63,245,97,117,63,26,167,117,63,8,235,117,63,193,45,118,63,72,111,118,63,159,175,118,63,202,238,118,63,201,44,119,63,161,105,119,63,84,165,119,63,228,223,119,63,85,25,120,63,168,81,120,63,226,136,120,63,3,191,120,63,16,244,120,63,11,40,121,63,247,90,121,63,215,140,121,63,173,189,121,63,125,237,121,63,73,28,122,63,20,74,122,63,226,118,122,63,181,162,122,63,144,205,122,63,118,247,122,63,107,32,123,63,112,72,123,63,138,111,123,63,186,149,123,63,5,187,123,63,109,223,123,63,245,2,124,63,160,37,124,63,113,71,124,63,108,104,124,63,147,136,124,63,233,167,124,63,114,198,124,63,48,228,124,63,38,1,125,63,89,29,125,63,201,56,125,63,124,83,125,63,115,109,125,63,178,134,125,63,60,159,125,63,19,183,125,63,60,206,125,63,184,228,125,63,139,250,125,63,184,15,126,63,66,36,126,63,44,56,126,63,120,75,126,63,43,94,126,63,70,112,126,63,204,129,126,63,194,146,126,63,41,163,126,63,4,179,126,63,86,194,126,63,35,209,126,63,109,223,126,63,55,237,126,63,131,250,126,63,85,7,127,63,175,19,127,63,148,31,127,63,7,43,127,63,10,54,127,63,160,64,127,63,205,74,127,63,146,84,127,63,242,93,127,63,239,102,127,63,141,111,127,63,206,119,127,63,181,127,127,63,67,135,127,63,124,142,127,63,98,149,127,63,247,155,127,63,61,162,127,63,56,168,127,63,233,173,127,63,83,179,127,63,120,184,127,63,90,189,127,63,252,193,127,63,95,198,127,63,134,202,127,63,116,206,127,63,41,210,127,63,168,213,127,63,244,216,127,63,13,220,127,63,247,222,127,63,179,225,127,63,67,228,127,63,168,230,127,63,229,232,127,63,252,234,127,63,237,236,127,63,188,238,127,63,105,240,127,63,246,241,127,63,101,243,127,63,183,244,127,63,238,245,127,63,11,247,127,63,16,248,127,63,254,248,127,63,214,249,127,63,155,250,127,63,76,251,127,63,236,251,127,63,124,252,127,63,252,252,127,63,110,253,127,63,211,253,127,63,44,254,127,63,121,254,127,63,189,254,127,63,247,254,127,63,42,255,127,63,84,255,127,63,120,255,127,63,150,255,127,63,175,255,127,63,195,255,127,63,211,255,127,63,224,255,127,63,234,255,127,63,241,255,127,63,246,255,127,63,250,255,127,63,253,255,127,63,254,255,127,63,255,255,127,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,24,0,0,0,11,0,0,0,20,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,80,0,0,0,33,0,0,0,18,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,64,0,0,0,33,0,0,0,160,0,0,0,99,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,224,249,39,0,104,143,39,0,184,54,39,0,176,240,38,0,248,169,38,0,88,109,38,0,72,54,38,0,104,1,38,0,0,215,37,0,120,176,37,0,120,141,37,0,64,77,37,0,248,25,37,0,128,245,36,0,48,206,36,0,40,177,36,0,48,148,36,0,240,120,36,0,32,94,36,0,104,67,36,0,168,42,36,0,240,241,35,0,72,205,35,0,152,181,35,0,216,158,35,0,232,138,35,0,152,115,35,0,40,96,35,0,232,76,35,0,240,58,35,0,120,39,35,0,24,253,34,0,176,224,34,0,152,208,34,0,224,192,34,0,72,176,34,0,0,0,0,0,0,0,0,0,56,231,23,0,40,228,23,0,195,7,0,0,232,226,23,0,104,224,23,0,159,9,0,0,88,223,23,0,64,221,23,0,133,10,0,0,88,220,23,0,136,218,23,0,115,11,0,0,184,217,23,0,32,216,23,0,101,12,0,0,96,215,23,0,232,213,23,0,93,12,0,0,56,213,23,0,216,211,23,0,87,12,0,0,56,211,23,0,0,210,23,0,77,13,0,0,120,208,23,0,104,205,23,0,195,7,0,0,40,204,23,0,168,201,23,0,159,9,0,0,152,200,23,0,128,198,23,0,133,10,0,0,152,197,23,0,200,195,23,0,115,11,0,0,248,194,23,0,96,193,23,0,101,12,0,0,160,192,23,0,40,191,23,0,93,12,0,0,120,190,23,0,24,189,23,0,87,12,0,0,120,188,23,0,64,187,23,0,77,13,0,0,64,186,23,0,64,184,23,0,128,11,0,0,160,183,23,0,96,182,23,0,79,13,0,0,192,181,23,0,128,180,23,0,79,13,0,0,224,179,23,0,160,178,23,0,79,13,0,0,0,178,23,0,192,176,23,0,79,13,0,0,0,178,23,0,192,176,23,0,79,13,0,0,0,178,23,0,192,176,23,0,79,13,0,0,0,178,23,0,192,176,23,0,79,13,0,0,75,173,133,85,150,40,78,53,222,41,39,220,9,168,255,223,152,71,27,230,174,99,160,213,144,26,66,202,34,204,146,87,75,57,54,174,43,9,20,41,101,4,129,242,193,21,0,106,39,230,75,46,52,160,153,89,138,79,125,232,248,170,185,41,97,179,83,197,226,222,223,247,71,245,236,33,225,236,91,108,130,29,71,209,4,252,156,9,70,252,146,18,141,253,16,192,10,179,57,90,75,0,140,202,172,245,60,8,209,15,200,244,219,22,149,238,134,86,16,49,200,172,23,189,38,253,251,28,118,210,229,214,68,44,0,7,42,104,222,91,151,179,21,254,93,186,119,190,218,202,203,199,243,169,96,246,67,4,177,232,217,224,175,189,48,176,85,170,212,71,177,251,141,7,30,52,201,187,194,70,118,88,193,67,18,217,255,69,98,71,186,2,204,5,73,79,134,233,109,152,77,19,9,169,213,245,235,17,46,233,32,72,63,34,248,245,19,245,190,249,209,84,27,12,173,155,152,12,173,181,85,18,113,236,172,23,180,7,9,197,115,247,44,37,238,253,189,80,202,237,147,223,203,168,73,221,225,9,168,211,100,21,230,3,84,86,68,236,115,6,159,245,7,18,15,9,119,81,250,243,254,242,9,16,158,52,253,11,85,0,137,67,24,40,96,198,214,0,90,0,3,153,95,182,104,180,44,75,22,216,181,38,245,217,17,80,77,230,185,228,75,11,30,253,95,80,12,194,127,166,214,26,76,0,71,1,40,34,179,205,95,166,188,246,32,180,213,217,170,205,55,63,92,82,237,14,237,2,32,202,133,193,223,71,87,9,3,187,28,76,126,232,143,5,214,45,211,15,90,75,201,26,31,179,176,235,38,38,70,71,159,9,76,73,12,237,171,253,42,76,43,5,120,220,204,254,176,251,229,243,125,155,207,194,244,98,26,18,75,10,167,76,176,246,23,225,20,46,139,219,252,200,82,10,85,103,157,173,142,215,99,249,81,249,15,86,121,84,60,45,125,166,211,239,129,0,22,232,214,13,147,3,251,254,239,255,129,254,160,6,48,26,111,250,102,81,89,3,192,238,143,5,80,196,154,222,61,218,90,20,55,22,88,238,155,253,93,210,242,21,134,16,107,2,169,3,157,236,234,200,48,189,6,229,192,232,36,197,31,254,187,227,210,197,188,73,169,84,198,155,94,11,119,4,185,254,54,254,29,252,72,218,205,252,188,158,244,10,1,79,59,4,169,251,158,241,4,249,220,179,198,3,53,3,125,28,1,171,38,42,109,228,3,165,69,249,230,254,171,212,170,0,42,174,2,143,71,49,18,70,129,14,229,249,117,3,5,0,52,2,228,23,168,88,194,8,217,228,247,38,12,232,242,16,184,104,135,241,184,7,201,251,246,245,107,253,35,225,148,245,166,196,58,69,23,17,178,239,211,212,205,2,22,168,26,6,220,47,251,230,158,71,215,23,71,27,68,23,19,71,123,38,250,20,52,92,51,229,87,230,194,255,204,85,47,52,85,253,201,14,120,8,209,0,15,242,153,251,244,178,248,249,28,5,221,252,245,243,177,62,33,202,251,243,198,16,161,92,241,216,215,38,0,194,134,50,177,163,195,84,250,37,53,89,160,47,243,58,157,21,229,18,195,8,51,8,219,4,249,15,140,18,156,50,167,15,92,246,25,13,236,243,139,34,128,66,234,16,239,23,173,21,33,36,218,43,176,111,142,218,135,221,236,0,241,3,199,1,60,252,173,26,90,75,6,252,200,0,29,7,66,2,76,20,189,3,132,40,2,13,0,206,129,255,50,244,255,223,35,199,45,86,32,23,29,4,230,42,86,101,30,160,18,165,127,209,123,229,139,88,254,212,104,22,7,10,153,92,243,215,241,242,119,239,174,234,187,80,165,213,235,241,221,239,228,241,223,17,195,252,162,254,177,252,25,243,123,13,26,227,172,210,207,11,199,1,128,12,181,218,130,12,147,166,176,43,158,152,243,200,235,239,22,60,215,55,93,213,103,176,223,14,248,212,36,86,34,56,32,196,203,225,109,231,201,186,232,249,16,47,163,178,69,254,253,231,118,239,96,255,171,32,110,88,135,46,253,74,151,4,254,28,109,217,216,239,96,18,184,255,28,226,144,255,77,209,98,243,39,106,202,12,75,23,77,29,133,189,98,3,148,156,225,2,69,7,41,7,230,7,80,9,147,18,159,235,88,29,251,12,155,10,249,11,186,249,151,16,53,2,253,21,193,9,99,70,200,236,239,244,0,186,130,224,122,61,6,252,88,8,234,11,229,179,34,66,139,116,18,216,49,59,174,211,118,0,60,155,63,202,216,59,44,254,40,237,96,19,89,239,39,6,159,214,105,76,245,223,127,250,5,253,141,251,161,253,128,5,101,247,105,211,229,7,12,231,216,245,199,2,99,254,49,246,40,255,65,242,149,145,183,6,146,199,154,66,93,54,187,52,94,155,7,193,28,75,173,28,243,207,170,2,49,241,57,255,159,239,10,81,221,194,85,44,228,22,200,252,14,172,38,242,253,255,87,249,137,240,253,35,85,60,172,248,220,7,85,179,100,63,19,237,205,244,107,241,70,227,81,255,105,177,166,43,13,242,245,159,244,76,254,25,211,3,114,253,60,85,250,226,17,230,241,213,86,223,183,60,235,57,57,70,220,227,175,242,114,7,120,188,197,13,149,240,121,250,18,245,240,68,34,8,76,230,105,196,7,186,57,5,234,59,166,82,66,24,226,37,51,59,166,159,21,168,97,240,52,249,175,253,71,4,157,225,226,97,225,21,167,83,80,254,134,249,14,229,98,250,138,199,225,228,188,2,149,208,23,253,133,161,194,87,143,24,211,12,254,42,4,15,240,74,189,57,26,168,170,59,67,21,8,245,54,252,241,242,185,12,132,241,136,18,147,223,30,89,32,216,26,95,22,174,134,77,219,3,74,209,123,231,66,15,11,179,4,51,183,249,209,72,42,29,215,152,235,167,177,63,222,7,223,42,112,70,129,228,47,18,30,198,51,73,173,61,16,5,94,36,111,249,75,57,2,243,167,103,179,209,96,22,29,23,88,52,36,39,68,247,128,159,205,6,185,229,151,49,7,170,240,15,74,21,195,245,177,36,151,82,174,154,166,243,31,246,192,80,206,73,141,201,78,27,188,223,195,61,246,162,175,43,185,202,92,46,173,62,70,10,185,71,20,216,61,3,88,3,14,252,157,0,64,56,186,237,33,20,22,204,214,148,236,212,109,84,248,43,45,68,180,29,74,51,28,254,7,0,212,4,61,2,118,16,200,21,247,243,148,3,124,220,5,5,2,221,161,4,229,143,83,84,143,92,172,74,187,244,54,200,10,223,118,91,239,231,178,50,245,11,121,219,188,8,2,244,80,227,84,177,156,22,70,2,217,253,103,240,59,1,163,225,32,32,78,146,79,207,198,53,3,196,5,75,112,175,243,50,209,180,193,14,79,255,93,31,23,252,148,69,42,20,116,227,25,239,80,185,148,253,186,250,84,58,164,57,59,251,237,205,182,197,221,253,245,105,186,8,172,6,204,10,40,21,50,31,181,157,57,11,52,14,152,15,224,20,158,39,11,83,134,4,3,21,252,1,238,214,34,1,177,249,90,4,213,96,191,64,176,157,214,254,240,244,173,251,0,232,130,248,145,225,101,244,20,165,176,15,41,42,165,67,10,239,10,174,201,242,114,238,49,255,33,217,9,242,11,31,130,4,104,226,181,31,33,201,86,66,167,152,108,148,196,196,224,62,52,190,74,221,88,163,34,62,90,97,48,22,174,248,164,1,132,0,117,0,6,254,146,180,58,255,156,1,201,254,240,2,142,248,141,15,248,225,182,64,165,180,126,198,113,254,39,253,33,241,156,239,149,207,215,29,40,13,26,9,132,35,134,92,206,215,87,249,180,243,36,10,206,224,10,57,57,237,243,64,121,31,201,5,49,0,53,67,37,97,50,29,152,180,255,253,129,46,42,9,212,21,37,13,57,236,204,170,106,44,144,42,17,19,5,1,186,18,97,80,245,19,119,232,143,224,15,250,189,31,92,198,159,80,186,197,133,93,190,241,163,48,101,5,29,14,239,33,62,162,240,18,70,26,147,41,102,39,129,98,185,157,215,251,161,25,153,54,95,11,233,84,81,64,62,154,16,249,15,10,106,179,96,190,216,11,23,26,164,58,10,186,10,223,206,171,25,150,32,46,120,13,100,252,215,193,145,251,6,20,123,175,40,30,178,8,55,68,58,21,14,113,144,68,222,4,254,60,33,210,42,96,125,187,200,12,143,12,30,70,223,10,46,253,112,167,91,23,210,233,144,243,25,154,178,101,183,25,230,12,86,79,29,242,101,245,68,254,49,250,246,5,96,175,46,170,81,208,63,155,159,34,244,251,224,69,58,2,26,193,137,32,7,246,171,59,139,245,222,38,169,248,93,64,38,206,177,142,136,255,83,247,219,0,97,0,109,1,35,0,246,4,50,253,200,5,127,245,138,7,153,226,104,7,46,34,114,7,59,71,108,206,226,231,107,241,145,53,102,217,168,193,160,250,22,228,152,214,48,33,95,62,168,221,108,29,215,79,225,11,111,203,8,4,184,150,155,22,152,97,18,238,228,223,150,219,32,232,165,188,145,100,112,186,58,27,168,14,114,2,142,255,130,8,97,17,2,237,142,27,228,234,130,18,245,244,58,19,117,253,251,73,118,217,80,3,94,7,176,254,222,234,66,28,220,79,145,218,168,253,13,3,238,179,152,206,234,25,134,5,194,1,185,242,126,190,99,43,144,51,134,234,159,84,63,243,251,18,183,232,106,29,171,213,182,109,110,40,155,205,99,100,40,100,129,253,95,1,139,4,75,73,166,234,17,197,111,255,159,250,115,199,93,106,105,133,115,128,191,83,178,244,60,60,135,73,112,86,198,75,55,88,19,53,78,214,214,41,225,19,108,237,141,3,232,174,108,205,76,175,242,28,162,10,99,13,65,45,175,251,198,71,19,77,78,218,170,87,178,76,216,254,114,229,171,198,99,84,84,77,151,83,106,180,179,226,102,99,88,51,140,33,46,157,20,12,134,214,160,81,33,36,2,243,4,7,213,252,169,5,34,12,140,18,41,47,74,200,16,175,195,55,20,239,18,155,107,233,99,173,244,235,58,41,60,201,122,169,24,11,214,253,189,99,240,68,38,58,174,173,155,9,54,98,102,219,4,249,194,205,18,233,45,155,241,212,42,26,51,3,73,40,166,0,189,107,11,2,101,0,68,180,85,13,166,37,64,0,38,3,74,245,245,185,240,245,34,89,105,33,102,4,156,11,99,59,0,7,90,99,160,233,143,188,117,250,68,6,46,17,188,44,195,6,235,92,240,235,17,18,99,214,77,109,169,38,50,246,224,214,127,146,183,11,6,250,192,252,194,252,131,212,33,207,190,86,181,227,230,163,62,171,39,66,124,170,69,7,122,218,216,36,82,74,37,40,44,37,191,104,218,7,177,236,136,220,171,21,94,247,190,55,60,196,140,180,30,7,14,237,241,252,1,221,252,243,168,177,131,243,40,32,22,245,168,186,252,51,157,12,33,252,51,208,75,230,75,40,176,218,212,8,88,175,168,228,153,21,127,226,190,226,154,215,230,215,57,14,23,76,172,232,103,181,118,183,5,50,3,5,188,239,102,16,199,144,62,246,74,7,175,62,202,104,3,205,84,231,217,3,195,249,109,254,112,53,57,25,238,97,244,105,26,175,106,185,2,249,102,158,65,23,70,252,232,103,96,161,233,195,212,96,161,7,144,251,187,0,15,247,217,48,254,174,120,252,148,71,10,83,98,10,4,232,51,63,4,87,212,253,106,8,57,232,126,54,174,155,191,147,209,15,69,237,52,172,105,103,235,75,92,220,127,3,47,1,72,169,191,153,118,232,153,96,114,166,186,220,60,200,146,193,180,92,189,166,52,36,255,240,42,115,163,85,187,231,143,6,245,247,160,251,77,254,74,38,205,240,71,48,64,239,229,181,56,77,170,255,163,9,198,7,3,252,22,235,250,81,177,221,47,235,246,163,134,237,113,10,25,236,229,21,235,237,206,74,181,101,29,208,204,3,202,26,199,17,45,109,71,240,32,247,187,23,68,243,131,236,139,254,221,249,110,241,168,227,64,205,140,221,11,236,14,90,190,19,152,3,55,10,232,30,71,227,215,236,218,78,6,255,78,21,68,12,16,27,221,182,253,247,197,215,236,238,152,76,15,19,107,253,163,248,224,57,101,222,153,178,247,23,38,173,28,55,87,209,81,247,154,19,116,46,213,88,150,1,128,204,203,245,56,204,95,168,62,207,68,223,170,66,179,98,31,247,192,19,170,254,145,0,209,32,237,186,168,74,119,41,3,180,187,66,85,81,188,233,10,48,2,156,151,40,12,30,198,17,163,61,186,67,77,180,96,237,182,4,213,225,84,42,228,149,81,211,179,26,16,249,238,9,127,12,90,17,105,68,129,241,110,252,224,81,122,190,74,233,79,43,186,255,177,89,233,12,103,11,112,24,64,237,26,174,98,243,36,23,93,191,135,8,173,10,118,13,246,164,83,232,62,255,228,201,37,213,32,76,5,4,115,17,180,232,196,181,239,5,153,254,87,3,211,249,73,226,54,86,196,210,208,216,206,66,132,207,249,9,228,16,228,87,119,22,138,47,217,157,76,70,16,231,156,4,158,4,150,37,166,91,233,222,216,238,147,245,214,29,61,190,121,234,185,244,251,213,109,174,78,28,29,4,143,10,134,175,126,226,92,29,196,225,236,22,190,80,141,85,201,1,121,58,7,187,111,209,19,14,197,249,127,247,99,255,213,255,93,2,209,9,250,34,31,41,31,88,28,193,87,193,114,23,87,19,139,26,2,237,128,168,161,73,166,29,99,249,144,159,180,242,89,55,190,4,210,238,249,229,42,229,157,216,236,159,37,36,228,40,87,69,188,225,147,0,86,231,67,17,59,63,83,191,233,239,206,16,201,29,33,21,231,12,175,10,34,29,66,178,50,247,138,241,227,247,105,84,22,58,1,49,63,232,28,249,70,18,220,45,43,11,41,27,127,7,225,240,194,13,163,170,91,246,43,215,205,73,10,214,175,14,49,216,254,236,157,245,89,186,38,251,143,58,135,36,94,46,219,249,16,237,21,88,37,37,240,149,238,41,115,81,183,153,42,186,254,227,144,250,217,179,202,49,6,32,60,248,91,7,254,109,178,252,189,227,249,0,233,0,224,227,157,2,141,254,124,244,194,90,253,233,69,12,32,1,151,12,22,251,158,255,41,148,221,67,61,165,246,19,65,212,242,245,33,211,192,236,238,5,176,234,158,2,154,184,159,7,94,40,103,178,215,237,105,1,96,255,101,252,44,73,184,55,173,243,195,226,0,243,71,23,226,241,85,82,108,28,208,13,185,31,8,250,26,223,244,1,18,181,241,73,24,103,241,251,23,61,68,100,183,32,111,7,153,7,53,209,100,245,61,13,226,104,21,238,11,7,22,0,153,4,113,253,209,4,176,247,164,30,231,6,7,253,17,32,166,180,15,238,131,7,169,254,79,253,54,242,61,243,36,241,63,245,134,72,194,247,170,7,183,250,3,65,205,10,194,165,79,254,41,19,46,1,216,50,61,62,239,232,131,12,30,16,173,43,136,234,31,246,120,251,189,251,187,230,121,250,50,22,244,254,71,2,67,219,140,179,72,24,122,6,225,3,181,255,97,249,104,238,15,247,8,240,100,230,63,191,152,18,132,252,106,213,116,25,135,94,133,232,3,255,232,3,63,0,175,255,141,255,130,254,203,250,160,94,70,253,197,237,15,245,56,181,148,252,62,143,143,170,133,49,56,231,163,12,207,65,153,82,196,153,145,243,116,254,230,0,120,71,146,225,199,205,89,253,63,250,5,0,8,215,165,44,205,100,158,251,121,5,74,254,198,14,251,226,96,104,159,68,57,75,254,48,188,24,22,253,245,49,100,36,242,167,22,235,90,13,56,167,98,105,127,71,52,4,188,3,77,149,84,244,152,3,235,0,185,8,81,0,55,24,176,20,221,62,176,57,19,223,168,251,224,230,44,75,193,38,75,243,254,4,70,252,149,94,1,8,109,166,25,10,150,246,136,239,70,36,202,55,233,178,111,240,216,246,4,4,96,177,73,70,14,219,228,89,169,189,177,33,16,229,6,175,178,14,7,68,69,87,80,74,74,3,117,94,230,97,49,233,178,255,169,3,147,253,10,77,116,161,86,248,250,197,200,255,238,88,1,236,213,67,60,93,232,179,98,230,146,247,82,68,69,172,12,13,237,205,185,176,107,218,173,67,203,2,217,8,229,239,20,254,196,35,147,50,167,106,73,173,72,232,15,219,148,204,27,165,74,201,168,239,66,27,2,0,170,3,187,203], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+184320);
/* memory initializer */ allocate([192,13,23,161,118,89,133,76,209,236,194,178,52,77,162,219,150,206,235,14,170,234,103,239,181,228,140,231,137,201,194,157,125,36,129,40,218,201,208,229,28,88,249,253,251,25,80,73,9,237,26,49,138,57,31,216,201,252,199,70,142,1,210,249,140,255,149,254,233,228,106,206,24,145,104,33,49,27,17,255,214,245,160,237,3,252,223,7,9,20,118,92,241,206,2,224,60,158,112,72,99,55,127,6,229,14,44,82,108,218,69,236,248,248,193,251,215,169,35,65,112,58,243,36,226,10,95,66,72,154,138,180,242,230,80,4,166,22,137,185,55,249,249,96,177,40,177,212,128,3,103,235,193,248,141,45,13,245,233,96,69,172,176,178,79,164,167,190,106,233,11,22,76,10,76,19,68,249,36,17,207,151,129,202,74,41,217,154,254,59,216,179,130,102,195,183,200,6,118,31,52,22,154,81,251,15,100,181,4,199,28,215,108,67,93,192,11,58,209,186,26,181,147,48,207,149,227,206,87,26,206,253,208,3,255,254,107,48,86,222,24,169,125,178,5,43,82,30,215,14,77,46,26,148,231,222,65,4,41,250,45,16,122,247,160,151,33,253,250,252,189,5,53,12,194,53,254,17,73,114,83,73,26,217,199,187,27,219,102,187,30,246,221,230,114,241,50,249,255,16,71,229,195,178,155,37,98,214,83,28,197,13,83,42,225,21,110,98,204,164,196,215,90,186,119,2,120,45,252,7,114,174,151,252,202,222,217,251,198,194,59,214,86,58,171,193,233,109,148,20,221,1,227,251,134,4,41,250,146,221,124,233,123,158,132,101,227,30,242,251,142,255,252,246,217,250,176,230,192,5,31,19,23,186,6,155,181,20,68,255,45,6,128,12,73,67,250,16,85,86,145,183,12,86,246,215,33,2,76,213,228,8,90,146,182,31,239,59,25,9,100,36,57,80,60,58,29,82,185,24,242,23,68,160,69,3,67,222,44,233,218,28,11,254,7,41,163,78,171,44,109,237,71,245,110,94,198,219,169,59,59,223,53,233,176,11,208,244,160,23,207,226,167,45,228,177,141,252,78,209,8,217,187,170,172,238,214,149,130,13,170,76,0,5,37,10,137,77,135,20,61,235,189,74,74,199,14,221,181,53,184,250,210,72,247,68,249,42,161,26,14,184,192,24,95,249,196,8,224,237,108,15,166,205,103,235,204,79,46,41,74,16,12,252,239,75,187,84,129,244,233,178,144,239,40,5,141,3,63,221,135,36,126,224,198,245,123,205,214,103,179,13,233,37,156,167,119,32,231,31,19,204,232,21,150,12,165,14,28,250,165,0,204,255,60,255,102,0,40,167,128,221,135,3,99,211,186,198,136,255,110,23,53,77,89,52,44,14,77,20,80,33,195,22,214,251,6,3,217,255,90,255,195,36,252,218,109,37,52,205,136,95,68,97,214,69,187,8,121,171,254,79,108,18,234,227,78,246,39,37,75,6,73,170,150,55,247,250,72,36,13,247,175,90,132,242,166,213,11,0,24,37,225,11,10,20,206,240,29,173,195,167,182,55,146,217,227,78,195,54,91,0,208,188,97,183,212,3,17,0,53,3,120,0,194,253,253,47,187,180,174,53,245,63,95,255,137,23,220,242,250,5,91,240,150,9,136,213,225,162,105,0,221,19,252,254,158,22,180,253,226,74,25,16,73,16,127,52,52,57,163,81,10,29,81,255,45,51,136,241,193,90,67,15,122,39,43,232,171,91,84,20,195,250,63,6,118,51,111,243,90,242,13,59,61,223,14,210,114,237,122,4,67,18,78,180,69,58,29,236,249,0,254,171,152,39,167,191,7,204,206,71,103,222,116,2,143,9,16,13,58,12,5,236,119,0,236,69,106,168,31,187,207,85,91,192,4,226,223,65,150,94,236,21,238,240,215,252,238,14,13,247,107,39,200,246,235,157,54,251,56,1,141,11,248,43,121,104,46,204,129,242,152,251,206,178,108,245,252,17,211,24,102,6,157,99,119,179,183,225,87,12,171,255,23,254,193,248,46,3,222,48,133,74,183,237,206,245,62,250,144,164,173,181,201,31,166,77,232,30,230,254,71,3,60,179,151,46,142,106,117,243,218,8,180,15,170,251,34,32,6,251,186,81,228,97,208,103,69,1,11,222,24,255,86,247,69,253,227,211,152,239,13,7,239,229,100,166,197,250,43,248,242,193,233,251,217,147,77,204,34,56,199,169,157,7,119,51,216,194,202,248,119,31,223,11,249,46,220,27,200,159,157,1,213,246,16,162,50,255,171,48,2,230,95,254,149,216,3,71,120,163,221,175,244,191,62,28,251,2,27,22,35,236,54,54,79,163,187,212,125,179,76,44,245,1,208,97,192,29,54,179,69,6,230,151,174,34,48,41,161,1,19,5,5,1,124,56,105,44,65,243,6,39,2,32,191,70,75,5,154,174,20,220,68,193,145,222,38,253,130,248,55,174,139,184,99,246,165,245,220,16,6,245,201,95,12,213,135,155,52,1,46,251,141,220,128,188,215,248,98,141,107,161,9,191,229,244,181,39,37,235,184,244,98,85,164,172,40,194,1,58,28,163,64,20,129,39,97,175,177,179,159,211,221,32,206,5,150,163,129,233,168,226,3,4,198,174,164,53,180,77,82,170,156,208,146,228,25,181,120,221,109,86,150,191,145,7,90,20,82,231,20,163,85,51,74,43,51,255,148,23,132,254,210,33,23,255,116,109,109,234,53,29,211,29,43,92,35,38,226,245,154,84,103,145,242,243,212,254,248,251,208,6,176,168,6,65,208,0,9,26,8,188,44,244,50,72,120,36,79,245,84,180,151,1,219,238,207,236,38,188,131,73,10,187,104,52,128,59,69,30,224,24,95,90,2,185,160,29,104,239,47,250,133,230,74,2,83,216,116,58,224,99,4,15,244,231,33,19,11,205,2,168,15,22,213,222,199,247,58,159,137,3,146,219,176,5,32,244,60,250,142,4,180,238,228,43,244,35,69,13,85,250,30,53,31,194,220,95,187,22,35,33,79,244,43,84,236,189,61,30,210,93,172,197,50,163,44,235,248,229,111,238,211,51,179,75,116,50,162,247,31,253,108,82,171,169,65,13,235,237,103,22,31,182,199,228,127,10,124,4,237,192,71,172,65,146,138,253,143,199,132,28,160,2,98,72,212,187,91,216,95,1,92,44,34,213,60,67,16,18,145,0,127,69,57,253,105,242,66,247,15,62,235,7,0,0,112,146,2,7,175,253,58,245,164,170,15,45,29,179,73,19,244,85,19,84,180,243,254,6,45,3,39,32,73,10,205,46,29,244,185,86,248,34,72,159,78,253,25,58,194,246,4,235,214,32,193,234,238,254,126,253,111,255,10,3,51,230,90,28,44,81,45,164,63,183,254,88,144,166,112,156,36,39,178,249,228,5,143,250,183,29,151,1,154,159,255,191,244,248,165,237,160,214,61,181,222,40,93,241,17,34,249,228,210,50,172,20,170,231,236,236,88,174,251,248,251,65,54,202,47,254,143,75,11,214,97,205,105,98,49,198,207,233,247,253,191,254,69,251,5,27,235,243,215,78,233,150,6,209,15,5,49,1,200,7,1,76,39,252,25,0,247,253,51,26,142,241,173,32,17,222,161,85,226,149,60,18,109,23,205,27,176,45,81,95,214,213,232,2,56,219,181,77,171,7,242,30,160,217,102,13,34,83,56,249,92,42,117,34,135,105,147,221,241,5,26,162,115,6,158,30,72,251,71,15,43,212,201,12,3,207,0,28,226,71,138,84,157,35,240,210,120,235,165,27,78,9,100,0,233,14,199,229,220,4,238,5,191,254,10,31,18,183,171,41,254,236,215,2,8,3,245,193,42,224,217,247,211,88,31,6,102,242,28,17,81,245,21,33,143,228,96,211,37,5,90,105,41,17,241,29,153,68,54,253,138,2,193,192,189,252,173,32,3,7,22,200,169,63,152,17,192,216,238,29,190,151,236,187,20,10,48,0,112,240,52,2,17,233,98,10,30,183,35,49,96,154,230,194,112,10,189,250,137,252,170,236,112,16,101,229,9,10,115,175,46,222,212,248,30,198,61,234,230,164,48,198,11,101,58,21,21,146,203,246,189,244,198,253,127,9,40,51,45,245,162,97,48,207,109,159,255,251,212,233,13,239,116,7,196,72,181,172,214,67,12,108,7,147,207,195,156,5,56,228,63,247,83,31,7,15,248,95,43,254,202,37,187,41,121,252,91,216,9,7,244,172,187,18,209,221,98,4,146,218,65,10,7,89,188,3,114,3,196,30,131,74,84,217,54,161,72,29,61,36,212,3,116,151,246,234,20,21,62,4,112,6,166,112,10,251,65,254,5,0,83,254,236,255,77,196,244,23,28,89,228,4,21,217,255,1,83,3,245,30,55,254,78,208,165,16,155,29,78,238,4,33,34,251,165,56,137,158,128,233,106,186,25,214,159,38,135,162,136,203,86,7,55,197,181,39,107,64,245,198,64,210,92,173,11,243,72,3,205,233,141,87,202,7,74,2,118,90,100,233,61,197,124,215,201,219,45,203,251,252,219,218,103,240,56,161,15,33,172,22,159,222,65,253,104,207,111,240,222,157,13,146,237,190,129,62,186,10,75,6,233,19,237,251,41,0,243,227,191,77,67,123,19,130,103,54,230,233,77,3,26,206,73,22,55,65,170,255,162,20,27,58,146,105,132,82,160,61,19,215,120,57,192,76,33,211,207,203,28,177,131,196,149,33,78,220,142,253,139,42,129,232,202,24,48,250,8,251,57,250,233,250,136,241,147,234,214,242,207,69,52,230,98,97,30,101,201,243,224,32,135,108,151,250,230,20,92,239,25,78,56,22,106,1,94,67,225,14,82,243,64,4,151,255,89,140,187,10,119,59,89,255,138,14,174,13,133,243,154,33,92,30,226,249,109,252,21,254,185,12,137,246,146,21,126,80,156,255,132,201,152,211,241,195,150,170,184,222,189,47,152,253,120,9,25,248,46,17,35,241,172,31,220,227,51,82,219,82,77,219,65,180,128,3,151,233,200,196,206,172,170,66,18,252,146,254,117,24,168,12,95,209,171,192,52,194,181,25,173,243,220,96,173,10,23,251,149,252,195,249,11,176,86,43,7,94,229,220,56,55,172,8,230,200,183,46,33,168,39,16,225,251,212,234,33,3,161,245,60,0,52,235,234,252,49,23,52,227,28,249,95,168,52,154,203,84,82,16,173,233,8,230,196,197,45,5,20,162,213,5,120,232,56,207,122,93,134,11,65,6,149,4,123,74,222,68,9,70,98,214,176,42,162,236,159,12,44,243,200,106,78,16,109,249,241,1,170,39,197,28,221,65,249,72,147,166,204,241,197,245,52,241,103,234,184,235,207,220,182,176,49,234,240,166,49,83,100,27,233,2,208,2,172,1,77,250,109,0,246,243,105,1,45,223,225,31,129,87,241,0,219,6,150,252,248,244,116,4,99,49,2,9,247,86,198,157,107,187,207,245,51,13,97,40,238,178,148,195,120,162,56,240,4,206,84,155,40,51,65,15,35,5,16,18,9,163,40,53,229,98,105,251,125,8,159,255,179,53,254,235,215,90,118,16,127,169,222,26,190,254,88,71,170,252,116,209,35,253,128,67,131,206,35,218,11,92,144,192,227,250,170,22,152,236,70,76,54,173,210,159,73,255,219,22,247,192,125,59,232,218,254,249,121,1,16,55,225,97,107,52,98,32,24,91,178,65,163,227,118,0,5,194,153,74,53,38,235,254,64,239,85,84,24,204,125,192,249,64,2,237,45,19,239,180,115,91,113,57,46,253,125,0,6,76,132,237,120,248,249,210,34,81,49,21,86,148,191,244,21,239,128,1,201,247,87,5,246,254,41,220,65,21,221,102,124,248,125,16,102,244,54,177,200,170,74,21,254,226,224,20,35,255,216,229,91,2,76,220,28,5,142,148,149,37,68,223,81,248,187,36,141,249,33,89,142,29,126,235,187,239,105,5,34,252,48,2,18,251,162,96,143,181,245,41,161,29,70,228,195,1,162,78,35,217,129,232,116,247,78,250,233,86,164,36,136,35,207,42,195,246,116,241,236,72,118,253,46,251,84,43,254,29,81,23,7,75,51,250,204,251,37,253,84,253,43,0,147,236,118,52,171,78,60,0,220,1,89,252,195,177,6,34,195,9,248,3,122,251,79,1,211,152,166,72,103,247,99,253,81,13,25,3,138,237,171,34,225,159,82,218,59,14,229,254,247,51,100,172,149,241,96,251,78,248,76,6,173,0,60,0,151,3,205,4,30,27,103,253,249,63,95,66,221,20,65,201,0,247,90,176,246,98,143,214,171,46,27,226,37,231,234,54,121,93,53,204,198,227,87,252,234,0,69,255,167,24,171,248,218,48,169,248,63,73,211,164,109,2,45,25,26,13,46,161,214,32,195,20,31,243,86,236,160,237,40,236,126,155,227,20,5,251,17,204,59,252,234,164,190,4,147,102,148,231,51,39,119,177,197,59,55,193,16,20,90,37,185,240,202,179,137,18,254,86,181,239,42,31,112,179,200,54,143,233,137,174,235,34,7,0,57,240,223,3,79,232,52,0,33,180,157,13,153,11,52,30,106,30,224,98,62,24,65,252,244,205,208,248,41,167,156,28,78,42,178,237,142,6,68,216,171,235,198,16,9,251,49,15,22,5,26,29,126,2,150,79,195,243,48,207,93,220,31,72,201,207,186,227,120,72,215,231,201,33,9,229,129,252,213,66,220,64,88,217,163,111,29,11,104,6,109,11,214,254,120,58,124,154,30,58,52,162,23,7,182,230,251,101,46,20,233,82,1,62,113,84,233,57,76,171,54,64,24,80,246,199,54,228,190,239,231,111,90,0,220,249,21,3,122,252,181,255,57,250,167,9,35,240,28,14,64,247,162,42,168,33,83,68,103,67,208,187,126,66,27,192,14,175,91,183,186,98,56,69,11,242,159,6,27,252,241,23,97,231,242,43,161,211,229,178,182,255,95,240,208,249,72,52,162,0,112,255,239,253,76,82,243,30,124,211,166,1,230,255,190,27,37,203,169,177,69,10,78,255,83,254,241,35,88,5,34,169,63,10,237,175,57,97,80,254,19,26,246,254,19,34,80,0,120,109,37,76,220,243,211,219,118,7,239,170,225,20,255,54,31,211,60,49,191,23,165,77,35,5,195,42,109,38,76,183,126,61,184,18,93,2,15,249,174,14,9,240,192,84,136,23,192,253,239,13,6,242,251,63,120,10,40,249,204,2,71,236,137,250,58,238,116,253,199,186,218,242,205,241,236,238,134,230,120,169,214,28,178,5,210,47,246,74,14,22,121,225,191,176,96,83,172,226,240,77,246,91,231,217,37,22,58,248,29,247,78,60,155,42,41,186,97,25,14,53,234,193,226,194,148,237,131,23,186,94,221,231,255,247,56,229,72,251,150,3,71,69,187,255,119,241,139,35,63,193,187,163,93,23,216,246,182,30,42,221,225,93,164,99,231,212,27,253,212,206,12,76,57,57,91,60,22,173,147,4,54,8,123,4,229,10,0,16,131,8,46,34,218,184,162,186,130,215,173,235,214,251,43,242,253,244,10,178,111,209,144,23,123,32,134,40,138,220,204,247,231,75,239,255,220,2,79,253,80,199,232,180,73,228,39,73,78,7,122,89,72,15,147,2,253,99,90,240,147,37,109,3,56,10,167,88,118,233,0,70,228,14,252,78,1,10,223,104,131,235,100,213,208,8,251,253,146,236,198,0,33,170,232,241,158,86,20,182,60,83,69,251,200,74,51,65,204,249,126,44,2,249,119,15,96,242,91,27,61,228,141,81,36,232,221,185,222,182,187,96,124,64,139,12,238,79,101,158,119,176,132,17,9,236,34,254,22,231,50,248,11,216,207,253,233,169,189,168,231,11,94,182,162,29,151,57,106,178,207,24,73,236,125,5,56,218,31,4,135,170,162,43,153,13,29,218,126,25,241,190,29,89,147,85,118,183,93,68,72,57,11,5,162,19,220,76,6,63,158,178,196,189,237,185,219,189,168,22,224,223,44,19,231,34,224,8,140,251,79,165,36,6,193,10,194,249,95,8,238,242,90,170,152,217,220,251,86,147,190,4,121,28,150,0,98,0,2,6,23,2,21,68,98,165,123,252,92,83,78,177,225,12,48,249,241,223,42,172,186,239,231,237,18,186,102,21,5,5,136,0,25,73,11,82,242,96,157,44,2,5,246,237,49,242,212,29,247,254,93,8,195,252,13,248,144,243,1,77,215,10,254,255,66,4,104,0,141,229,39,177,122,11,179,247,220,255,244,4,88,37,214,36,114,37,84,86,3,54,152,24,233,253,206,177,180,16,180,248,64,254,225,188,224,160,164,55,177,202,208,173,223,8,35,45,170,245,77,60,19,238,206,72,53,239,146,253,160,177,73,16,195,70,132,250,154,53,223,248,25,192,120,35,232,2,5,86,125,0,42,42,172,37,241,198,209,183,134,198,166,43,238,174,186,254,46,163,0,24,229,30,90,2,4,6,6,230,234,25,117,206,148,83,49,81,73,229,156,16,205,173,252,21,255,72,52,93,136,32,66,70,72,22,131,235,83,185,213,253,147,12,203,23,152,55,3,236,208,187,4,180,127,210,174,171,38,44,74,60,246,99,121,26,197,151,107,83,204,223,245,22,44,242,191,23,249,245,43,10,105,246,45,21,2,208,100,181,198,21,71,249,231,152,144,163,120,89,163,254,203,14,141,8,77,251,220,20,177,12,167,167,104,0,128,249,244,212,215,244,13,175,15,162,188,77,89,89,79,227,207,183,232,198,48,223,91,205,193,14,118,15,47,32,14,80,177,228,79,251,96,255,179,249,231,252,23,222,61,2,8,3,201,16,54,241,149,79,194,23,55,235,32,184,57,73,159,9,2,49,187,225,202,225,121,247,66,43,144,237,103,86,33,7,225,160,240,15,223,5,22,181,223,249,13,0,199,254,119,1,62,1,193,253,240,9,178,0,102,0,40,0,132,193,239,150,144,19,248,12,174,2,135,4,155,100,6,105,62,2,214,232,180,240,127,5,68,220,15,226,197,244,64,223,25,183,32,103,235,226,136,185,36,184,98,34,52,247,130,170,171,30,253,45,93,107,209,205,126,250,134,76,192,8,59,23,239,43,108,62,157,230,216,94,169,84,173,183,43,38,150,25,86,245,78,1,203,239,40,6,254,212,89,0,147,160,178,233,40,30,198,5,164,83,63,158,63,223,9,0,112,246,234,39,44,206,49,193,137,4,220,172,203,221,163,199,122,166,36,198,69,10,20,54,172,227,27,11,89,218,66,11,223,198,177,95,94,253,126,230,158,1,219,164,161,172,198,1,56,8,88,231,135,42,167,70,81,251,175,0,19,254,206,253,77,245,118,0,206,251,93,0,229,216,21,240,89,146,164,86,229,58,132,253,227,237,232,191,213,220,62,176,168,210,60,174,207,18,20,62,174,94,190,202,254,243,221,251,188,229,2,18,172,182,77,196,211,190,180,93,245,59,94,253,158,241,175,84,123,17,200,208,148,18,33,10,234,20,113,23,215,58,122,103,249,162,157,188,32,27,122,1,182,2,158,2,96,91,121,221,135,198,120,29,148,252,80,43,56,14,8,13,65,88,89,242,232,246,143,255,28,1,2,27,25,12,187,39,238,25,67,183,168,9,88,23,46,43,96,209,165,253,105,253,47,63,57,64,108,51,53,240,59,18,7,29,138,75,174,60,123,230,145,6,7,237,152,66,131,66,20,2,136,181,95,250,246,235,61,4,183,206,55,187,14,8,12,157,65,74,7,193,72,39,248,173,190,202,123,244,7,60,222,77,120,253,187,249,62,39,200,249,240,51,96,77,226,251,248,41,26,2,106,97,158,37,164,220,141,216,226,11,12,158,12,162,147,54,100,0,147,25,251,26,119,27,108,40,223,92,34,186,247,166,64,248,143,250,254,242,51,36,237,55,246,199,129,240,226,11,126,63,105,188,174,37,111,172,76,92,133,65,204,2,103,10,114,0,184,181,34,244,38,6,11,255,183,5,231,252,138,87,145,91,211,198,238,253,158,67,49,53,194,210,255,30,126,201,169,91,204,159,182,103,235,251,95,14,86,247,76,41,7,82,138,241,103,195,197,0,78,65,229,159,81,19,5,0,29,42,239,16,166,104,157,220,232,192,232,244,203,62,220,161,163,240,79,229,101,49,139,228,48,8,28,156,78,223,158,26,11,0,154,4,184,209,185,253,71,221,193,175,25,215,132,254,73,246,201,96,121,171,115,180,124,6,36,253,9,9,111,53,245,15,229,95,115,96,69,173,194,246,8,254,222,239,182,214,116,92,169,7,155,79,145,69,222,218,149,14,246,181,108,231,240,240,162,65,95,252,170,176,181,186,141,26,143,48,190,23,248,211,142,199,1,27,180,91,212,29,137,249,233,89,223,41,156,223,70,3,145,222,45,251,80,185,57,15,221,62,210,5,254,241,84,32,61,59,49,241,99,173,205,6,111,238,235,84,62,9,234,254,72,237,189,60,174,165,116,202,244,29,104,63,56,94,177,58,181,177,21,50,64,177,51,65,121,210,47,193,199,206,15,79,168,13,11,246,167,229,182,209,89,17,132,30,47,81,184,66,3,45,85,218,190,96,46,33,254,164,66,243,93,43,48,228,133,216,57,226,120,169,129,184,21,104,78,37,51,156,221,1,194,30,254,249,99,4,88,255,214,1,106,38,165,254,137,93,115,215,5,219,0,240,26,218,56,229,216,171,109,81,6,28,250,20,20,38,43,163,90,251,0,2,254,249,18,252,194,216,151,206,34,75,2,249,134,252,4,59,68,92,226,194,38,246,77,251,211,250,18,227,211,245,71,4,9,255,39,254,177,0,153,31,4,0,136,48,244,168,165,40,208,225,180,86,23,42,77,236,178,2,22,2,44,255,175,243,118,250,61,190,250,71,205,61,172,89,49,22,75,247,124,12,170,242,199,170,41,198,19,0,19,3,8,4,170,0,153,223,123,253,142,252,241,246,31,150,176,1,216,238,219,5,182,250,213,209,180,255,100,176,203,215,64,44,211,0,111,237,189,237,235,228,30,203,143,56,155,23,140,20,53,254,50,254,143,0,191,255,244,245,88,28,11,243,252,35,112,165,250,216,206,158,196,218,186,73,213,23,125,9,110,199,122,32,229,8,112,55,184,13,25,101,240,85,208,0,250,78,231,254,54,159,193,255,97,251,71,4,110,232,146,10,81,170,161,245,51,2,23,0,214,232,243,0,227,220,225,20,78,80,150,195,155,49,64,16,79,43,141,80,80,215,3,82,171,255,236,222,194,0,235,3,213,218,75,179,249,242,255,200,246,13,171,164,101,253,228,247,161,13,136,243,89,180,27,2,6,250,184,28,147,196,68,88,169,75,19,4,243,64,176,248,99,254,211,4,100,235,34,242,143,85,251,30,40,248,72,66,113,229,209,114,85,246,235,202,197,32,172,163,181,169,158,200,39,200,201,210,134,177,184,62,200,248,105,61,148,17,9,15,59,191,193,78,93,173,98,30,88,46,109,230,7,251,107,182,46,212,116,45,20,4,224,9,221,229,3,186,158,211,226,236,16,252,217,4,164,16,15,9,223,23,157,13,241,78,198,11,24,244,196,20,69,238,95,81,254,33,2,249,165,198,22,1,132,54,175,216,205,214,52,167,235,224,126,251,253,53,52,250,33,251,107,227,153,253,38,51,239,73,169,38,172,5,248,9,222,246,96,13,234,237,116,43,128,179,139,212,183,175,153,213,225,213,225,174,177,26,216,3,9,197,143,22,37,98,1,21,169,178,5,2,216,51,222,226,81,249,132,80,131,232,87,172,195,51,197,174,137,52,129,67,48,51,61,194,136,192,53,90,59,240,253,223,103,3,70,2,27,49,119,173,82,198,29,220,53,22,222,16,16,249,161,44,157,186,63,217,65,2,125,23,190,65,247,68,90,155,208,238,34,242,80,202,99,191,52,14,254,242,157,173,242,193,165,25,117,212,201,33,198,204,49,91,3,203,18,246,170,220,122,226,56,114,117,14,129,254,140,214,163,97,101,7,238,223,184,81,174,192,156,20,86,65,163,41,228,77,65,237,132,180,236,253,172,219,208,108,101,19,15,255,24,2,3,253,30,175,172,242,182,73,205,10,140,5,13,244,148,10,178,181,181,254,209,13,116,0,190,242,238,178,147,11,118,37,52,18,217,76,207,194,251,230,7,69,20,15,216,223,27,180,115,17,156,1,47,186,155,224,179,2,101,188,252,13,59,9,230,26,179,14,235,24,214,175,178,188,203,200,140,250,125,162,181,32,7,207,119,224,35,172,234,194,142,12,169,31,179,232,247,16,49,20,123,10,74,190,230,235,82,191,204,24,84,214,195,50,100,156,182,169,251,15,192,244,82,223,176,232,250,188,178,245,92,90,25,236,55,200,157,168,237,84,105,14,145,11,117,246,181,186,67,98,147,10,58,6,7,0,53,184,50,35,174,16,219,2,86,254,128,253,113,163,156,96,10,22,100,2,204,254,60,252,1,253,244,4,225,0,99,6,173,0,148,3,79,21,93,25,38,19,64,41,1,90,12,189,67,67,194,173,228,182,72,19,164,242,29,13,146,250,128,60,70,170,237,198,59,5,30,2,46,229,50,247,218,208,253,243,243,177,114,175,245,248,255,45,63,5,213,34,181,2,177,95,150,171,246,36,73,18,38,36,121,225,32,62,73,234,54,244,47,220,189,250,237,167,68,50,146,254,212,19,65,249,203,79,229,254,149,244,162,248,87,231,85,252,223,247,137,250,185,13,167,243,231,253,45,236,4,44,196,75,221,3,41,9,57,16,137,22,79,239,233,0,113,254,122,170,142,251,166,191,14,23,112,21,117,243,23,39,14,207,141,73,196,81,122,251,254,6,115,251,150,19,81,251,15,25,30,223,210,173,100,7,50,242,231,14,42,233,43,64,64,79,152,245,149,210,205,239,121,184,74,167,0,58,104,67,179,40,84,30,8,47,12,74,221,9,85,172,3,183,111,213,16,17,117,228,187,17,218,249,2,8,128,22,180,96,111,62,14,69,230,253,173,166,59,43,61,40,129,1,16,2,239,222,47,244,27,192,59,165,107,64,70,14,208,22,63,2,114,46,155,7,69,98,253,25,225,25,68,242,84,248,10,15,122,254,140,255,85,70,164,81,243,55,59,226,86,213,26,46,7,237,140,244,234,203,121,225,118,84,219,8,189,253,41,219,20,253,183,172,79,48,73,32,131,223,95,5,73,186,105,11,102,35,30,86,222,71,187,33,33,250,142,246,137,184,114,198,85,244,25,59,253,242,28,87,54,54,185,202,242,22,174,181,227,60,86,44,254,174,179,7,45,6,213,228,64,172,151,9,65,0,158,1,3,2,140,238,103,253,192,237,125,0,234,180,247,83,179,176,176,248,122,248,45,255,2,252,69,20,38,208,17,249,2,164,62,238,181,22,65,1,69,231,54,57,63,27,19,249,99,3,10,202,108,12,247,30,188,1,96,76,74,12,252,229,220,47,76,248,0,68,40,161,100,205,23,253,20,56,173,251,190,92,97,218,88,184,108,71,27,225,149,226,174,74,41,30,141,206,134,7,253,58,208,205,105,8,127,84,72,7,174,247,120,91,160,66,19,195,248,249,87,0,122,32,208,209,245,56,145,175,211,30,205,247,144,76,30,89,104,188,8,248,29,1,233,240,234,223,110,184,228,41,80,202,99,203,126,249,15,56,16,19,190,177,196,3,131,239,76,255,234,159,5,191,12,77,37,23,169,18,62,17,65,246,197,91,243,192,102,11,242,251,38,248,30,74,20,246,31,52,125,5,206,231,144,251,185,9,102,53,110,88,113,227,127,255,24,245,118,201,135,65,228,89,216,2,69,13,162,0,222,11,225,3,70,34,47,170,47,230,142,3,100,207,142,168,190,245,81,235,64,76,144,38,137,248,158,184,182,183,142,197,152,18,207,27,106,32,94,244,30,101,236,29,39,225,252,3,244,23,23,59,69,73,206,160,127,230,29,230,244,30,93,47,13,219,102,162,126,21,169,3,96,189,3,235,218,9,71,1,105,4,122,254,158,61,243,77,116,215,164,43,221,243,5,58,128,209,101,224,248,185,241,168,171,188,109,229,194,205,132,247,147,230,39,23,170,48,173,168,15,254,66,1,14,4,13,230,228,234,87,79,59,4,56,166,210,222,98,47,6,253,63,10,203,19,0,77,147,248,226,255,187,254,85,0,219,3,58,233,116,16,186,220,161,35,50,158,68,225,116,28,252,207,114,50,168,171,205,81,162,249,242,225,117,247,179,222,28,234,148,157,244,229,132,1,249,167,246,5,122,35,193,0,69,225,220,168,43,20,106,1,176,3,253,254,240,14,182,209,167,29,120,165,254,98,219,92,248,214,27,16,137,173,181,82,167,87,186,252,141,237,35,85,40,24,134,255,106,6,51,253,184,95,175,77,5,248,218,3,7,0,201,255,79,149,121,255,133,9,3,1,89,0,51,1,126,95,223,240,241,234,204,252,173,246,105,1,153,21,152,22,250,72,242,0,120,170,93,240,32,87,131,17,210,2,46,208,146,29,88,60,225,33,193,11,213,79,116,82,148,173,248,243,148,251,145,10,223,248,44,21,239,252,100,72,36,66,51,203,131,191,246,197,153,176,115,200,171,8,100,5,226,83,152,251,71,1,83,0,127,247,13,84,240,240,156,200,52,255,113,247,185,3,46,219,2,62,42,214,97,243,38,82,91,254,159,250,128,2,209,223,16,174,126,8,213,16,82,72,116,220,113,184,98,195,120,14,201,232,193,1,61,223,51,4,62,169,128,236,137,11,244,49,109,71,150,5,89,58,227,84,159,244,145,1,125,237,119,177,163,6,133,251,121,13,121,20,149,34,118,86,133,226,171,5,150,247,136,33,200,70,2,195,119,75,153,232,173,13,25,11,9,23,253,24,182,33,234,89,163,9,140,11,123,1,71,22,225,169,115,247,189,189,174,253,134,73,81,235,104,6,6,3,80,11,112,250,2,14,12,247,198,77,226,248,113,183,227,82,79,201,227,206,82,64,123,2,50,248,142,180,113,191,176,47,64,191,82,225,54,218,244,3,115,171,67,11,88,206,17,9,19,252,215,1,211,241,109,31,177,212,189,99,45,16,32,172,143,245,244,2,105,253,245,253,90,25,83,33,89,75,5,74,204,23,125,219,69,66,23,96,200,54,88,39,232,253,58,215,45,224,97,8,12,166,79,189,75,21,207,238,231,197,40,80,129,184,11,218,147,209,89,186,14,247,216,200,22,8,195,87,135,6,213,2,166,222,37,57,193,13,159,175,17,26,8,32,24,79,58,17,170,250,183,253,205,4,111,246,43,29,20,228,99,53,202,223,120,87,88,188,116,248,35,15,152,220,28,241,190,3,9,1,209,238,143,11,217,193,142,76,90,19,175,251,89,70,61,217,39,185,234,240,170,43,189,22,252,198,53,251,188,37,115,84,220,43,55,210,47,253,92,249,109,0,162,247,61,0,140,229,213,159,8,168,232,21,91,248,31,249,12,252,80,163,157,238,128,245,169,198,86,239,191,38,47,33,130,252,214,79,4,202,141,188,139,0,236,25,15,238,93,55,111,188,117,191,96,3,74,14,12,88,104,0,29,249,172,255,6,0,76,84,105,186,142,227,217,249,226,247,192,254,71,247,33,39,88,245,90,58,184,202,5,187,228,249,182,186,39,181,167,53,197,10,135,11,168,17,134,21,225,28,47,42,31,75,54,202,143,1,160,11,181,251,149,19,121,251,79,86,40,14,201,246,72,18,66,247,174,88,181,14,151,239,163,223,102,229,154,207,18,184,22,60,178,235,43,229,193,216,84,223,106,193,174,175,114,255,113,167,144,254,39,17,48,254,243,255,46,3,162,251,191,251,253,169,74,0,17,6,174,249,22,75,22,187,78,203,74,3,251,246,81,18,106,64,77,81,229,195,188,239,128,240,20,243,206,43,26,203,31,53,239,179,202,53,25,7,86,3,233,82,58,252,149,249,244,254,229,245,149,255,70,177,120,1,150,4,208,254,153,244,197,1,242,234,238,2,238,169,46,252,188,181,199,65,16,39,4,242,163,8,179,5,83,5,158,245,223,255,29,240,141,4,31,170,112,222,56,245,144,187,143,193,49,58,43,5,140,2,141,219,181,12,226,198,149,47,236,76,39,231,141,22,221,195,139,67,206,64,150,244,107,253,167,253,73,6,82,88,224,3,235,251,97,19,147,35,217,43,149,30,192,63,195,72,144,170,103,250,138,0,190,5,157,248,60,255,213,179,229,184,48,43,252,253,239,9,55,247,84,251,90,187,182,78,198,44,111,254,59,10,30,18,38,224,115,46,113,194,207,68,149,197,173,255,22,1,67,1,55,0,102,255,232,0,108,30,182,5,219,71,192,59,109,194,149,251,0,0,0,0,0,0,0,0,0,0,0,0,212,216,43,81,230,42,48,238,30,3,188,255,42,43,10,80,39,230,34,235,251,248,161,249,137,15,226,253,206,27,114,251,156,73,86,57,32,239,160,255,129,227,20,254,222,169,75,239,132,10,224,22,154,21,102,85,212,227,51,235,121,255,161,164,194,3,179,31,124,253,126,1,229,249,72,13,29,243,85,18,20,229,126,87,207,13,214,11,128,28,70,24,252,79,189,208,57,0,89,229,56,7,179,168,225,232,167,26,203,252,185,241,125,254,147,231,57,249,155,168,98,232,50,6,54,182,200,199,254,35,193,2,172,233,8,1,212,185,26,57,241,30,175,254,146,255,108,0,8,0,74,0,167,255,206,255,212,25,19,250,183,84,134,249,243,224,10,255,163,84,65,231,158,223,155,255,187,250,234,255,13,170,180,230,38,31,136,2,6,8,181,254,215,208,96,2,149,228,78,2,160,15,101,3,36,26,73,61,222,231,233,219,182,255,133,0,63,7,35,252,116,80,152,244,133,238,225,0,86,251,195,240,203,252,90,230,149,252,182,176,54,245,147,243,2,240,9,234,207,189,37,38,11,6,183,26,188,7,9,79,209,251,134,236,77,24,5,186,116,234,122,24,102,1,138,4,169,14,214,251,187,16,101,243,56,62,202,39,255,27,131,18,82,4,173,16,172,40,212,18,186,233,141,243,109,199,144,250,21,248,81,3,121,2,55,24,97,27,21,206,254,246,180,245,68,250,137,228,168,29,121,41,198,232,10,244,160,49,36,0,5,0,0,0,1,0,64,0,50,0,0,0,60,0,0,0,176,45,24,0,0,0,0,0,0,0,0,0,114,1,0,0,98,3,0,0,230,0,0,0,250,3,0,0,254,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,68,36,0,5,0,0,0,2,0,1,0,114,3,0,0,224,3,0,0,152,19,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,17,23,0,134,0,0,0,122,3,0,0,172,0,0,0,0,0,0,0,130,10,0,0,0,0,0,0,248,69,36,0,5,0,0,0,1,0,16,0,66,2,0,0,186,10,0,0,88,190,3,0,0,0,0,0,0,0,0,0,152,1,0,0,52,0,0,0,130,0,0,0,134,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,78,36,0,5,0,0,0,2,0,3,0,36,2,0,0,4,8,0,0,96,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,149,3,0,116,0,0,0,18,3,0,0,52,1,0,0,0,0,0,0,110,2,0,0,174,1,0,0,10,0,0,0,10,0,0,0,10,0,0,0,5,0,0,0,5,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,216,39,39,0,112,0,0,0,112,159,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,255,254,0,0,0,0,253,255,32,64,38,1,253,0,254,254,29,63,41,2,253,0,254,254,26,63,43,4,252,0,254,253,24,62,46,5,252,0,254,253,21,60,49,7,252,0,255,252,18,59,51,9,252,0,255,252,16,57,53,12,252,255,255,252,14,55,55,14,252,255,255,252,12,53,57,16,252,255,0,252,9,51,59,18,252,255,0,252,7,49,60,21,253,254,0,252,5,46,62,24,253,254,0,252,4,43,63,26,254,254,0,253,2,41,63,29,254,254,0,253,1,38,64,32,255,253,0,1,251,126,8,253,1,0,255,3,246,122,18,250,2,0,255,4,243,118,27,247,3,255,255,4,240,112,37,245,4,255,255,5,238,105,48,242,4,255,255,5,237,97,58,240,5,255,255,6,237,88,68,238,5,255,255,6,237,78,78,237,6,255,255,5,238,68,88,237,6,255,255,5,240,58,97,237,5,255,255,4,242,48,105,238,5,255,255,4,245,37,112,240,4,255,255,3,247,27,118,243,4,255,0,2,250,18,122,246,3,255,0,1,253,8,126,251,1,0,255,3,249,127,8,253,1,0,254,5,243,125,17,250,3,255,253,7,239,121,27,246,5,254,252,9,236,115,37,243,6,254,252,10,233,108,48,240,8,253,252,10,232,100,59,237,9,253,252,11,232,90,70,235,10,252,252,11,233,80,80,233,11,252,252,10,235,70,90,232,11,252,253,9,237,59,100,232,10,252,253,8,240,48,108,233,10,252,254,6,243,37,115,236,9,252,254,5,246,27,121,239,7,253,255,3,250,17,125,243,5,254,0,1,253,8,127,249,3,255,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,255,255,3,0,249,255,127,0,8,0,253,255,1,0,0,0,254,255,5,0,243,255,125,0,17,0,250,255,3,0,255,255,253,255,7,0,239,255,121,0,27,0,246,255,5,0,254,255,252,255,9,0,236,255,115,0,37,0,243,255,6,0,254,255,252,255,10,0,233,255,108,0,48,0,240,255,8,0,253,255,252,255,10,0,232,255,100,0,59,0,237,255,9,0,253,255,252,255,11,0,232,255,90,0,70,0,235,255,10,0,252,255,252,255,11,0,233,255,80,0,80,0,233,255,11,0,252,255,252,255,10,0,235,255,70,0,90,0,232,255,11,0,252,255,253,255,9,0,237,255,59,0,100,0,232,255,10,0,252,255,253,255,8,0,240,255,48,0,108,0,233,255,10,0,252,255,254,255,6,0,243,255,37,0,115,0,236,255,9,0,252,255,254,255,5,0,246,255,27,0,121,0,239,255,7,0,253,255,255,255,3,0,250,255,17,0,125,0,243,255,5,0,254,255,0,0,1,0,253,255,8,0,127,0,249,255,3,0,255,255,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,253,255,255,255,32,0,64,0,38,0,1,0,253,255,0,0,254,255,254,255,29,0,63,0,41,0,2,0,253,255,0,0,254,255,254,255,26,0,63,0,43,0,4,0,252,255,0,0,254,255,253,255,24,0,62,0,46,0,5,0,252,255,0,0,254,255,253,255,21,0,60,0,49,0,7,0,252,255,0,0,255,255,252,255,18,0,59,0,51,0,9,0,252,255,0,0,255,255,252,255,16,0,57,0,53,0,12,0,252,255,255,255,255,255,252,255,14,0,55,0,55,0,14,0,252,255,255,255,255,255,252,255,12,0,53,0,57,0,16,0,252,255,255,255,0,0,252,255,9,0,51,0,59,0,18,0,252,255,255,255,0,0,252,255,7,0,49,0,60,0,21,0,253,255,254,255,0,0,252,255,5,0,46,0,62,0,24,0,253,255,254,255,0,0,252,255,4,0,43,0,63,0,26,0,254,255,254,255,0,0,253,255,2,0,41,0,63,0,29,0,254,255,254,255,0,0,253,255,1,0,38,0,64,0,32,0,255,255,253,255,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,1,0,251,255,126,0,8,0,253,255,1,0,0,0,255,255,3,0,246,255,122,0,18,0,250,255,2,0,0,0,255,255,4,0,243,255,118,0,27,0,247,255,3,0,255,255,255,255,4,0,240,255,112,0,37,0,245,255,4,0,255,255,255,255,5,0,238,255,105,0,48,0,242,255,4,0,255,255,255,255,5,0,237,255,97,0,58,0,240,255,5,0,255,255,255,255,6,0,237,255,88,0,68,0,238,255,5,0,255,255,255,255,6,0,237,255,78,0,78,0,237,255,6,0,255,255,255,255,5,0,238,255,68,0,88,0,237,255,6,0,255,255,255,255,5,0,240,255,58,0,97,0,237,255,5,0,255,255,255,255,4,0,242,255,48,0,105,0,238,255,5,0,255,255,255,255,4,0,245,255,37,0,112,0,240,255,4,0,255,255,255,255,3,0,247,255,27,0,118,0,243,255,4,0,255,255,0,0,2,0,250,255,18,0,122,0,246,255,3,0,255,255,0,0,1,0,253,255,8,0,126,0,251,255,1,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,255,255,255,255,0,0,255,255,1,0,255,255,1,0,0,0,1,0,1,0,0,0,1,0,255,255,1,0,255,255,0,0,254,255,254,255,0,0,254,255,2,0,254,255,2,0,0,0,2,0,2,0,0,0,2,0,254,255,2,0,254,255,0,0,252,255,252,255,0,0,252,255,4,0,252,255,4,0,0,0,4,0,4,0,0,0,4,0,252,255,4,0,252,255,0,0,248,255,248,255,0,0,248,255,8,0,248,255,8,0,0,0,8,0,8,0,0,0,8,0,248,255,8,0,248,255,0,0,240,255,240,255,0,0,240,255,16,0,240,255,16,0,0,0,16,0,16,0,0,0,16,0,240,255,16,0,240,255,0,0,224,255,224,255,0,0,224,255,32,0,224,255,32,0,0,0,32,0,32,0,0,0,32,0,224,255,32,0,224,255,0,0,192,255,192,255,0,0,192,255,64,0,192,255,64,0,0,0,64,0,64,0,0,0,64,0,192,255,64,0,192,255,0,0,128,255,128,255,0,0,128,255,128,0,128,255,128,0,0,0,128,0,128,0,0,0,128,0,128,255,128,0,128,255,0,0,0,255,0,255,0,0,0,255,0,1,0,255,0,1,0,0,0,1,0,1,0,0,0,1,0,255,0,1,0,255,0,0,0,254,0,254,0,0,0,254,0,2,0,254,0,2,0,0,0,2,0,2,0,0,0,2,0,254,0,2,0,254,0,0,0,252,0,252,0,0,0,252,0,4,0,252,0,4,0,0,0,4,0,4,0,0,0,4,0,252,0,4,0,252,0,0,0,0,0,0,1,0,0,0,8,0,0,0,9,0,0,0,0,0,0,0,4,0,0,0,32,0,0,0,36,0,0,0,0,0,0,0,2,0,0,0,8,0,0,0,10,0,0,0,0,0,0,0,2,0,0,0,16,0,0,0,18,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,1,2,3,4,5,6,0,255,254,253,252,251,250,249,0,0,2,4,6,8,10,12,0,255,254,253,252,251,250,249,0,0,32,88,3,0,16,134,3,0,8,33,3,0,32,88,3,0,160,86,3,0,144,132,3,0,136,31,3,0,160,86,3,0,128,112,3,0,112,134,3,0,104,33,3,0,128,112,3,0,128,88,3,0,128,88,3,0,128,88,3,0,128,88,3,0,32,88,3,0,32,88,3,0,32,88,3,0,32,88,3,0,96,88,3,0,80,134,3,0,72,33,3,0,96,88,3,0,160,87,3,0,144,133,3,0,136,32,3,0,160,87,3,0,128,116,3,0,112,138,3,0,104,37,3,0,128,116,3,0,128,104,3,0,128,104,3,0,128,104,3,0,128,104,3,0,96,88,3,0,96,88,3,0,96,88,3,0,96,88,3,0,240,1,24,0,80,12,51,0,8,151,142,0,0,88,10,0,112,9,51,0,64,192,81,0,128,24,25,0,0,23,51,0,144,111,149,0,240,1,24,0,80,12,51,0,8,151,142,0,112,1,24,0,208,11,51,0,0,150,142,0,128,87,10,0,240,8,51,0,56,191,81,0,0,24,25,0,128,22,51,0,136,110,149,0,112,1,24,0,208,11,51,0,0,150,142,0,16,10,24,0,112,20,51,0,88,167,142,0,32,88,10,0,144,9,51,0,136,192,81,0,160,24,25,0,32,23,51,0,216,111,149,0,16,10,24,0,112,20,51,0,88,167,142,0,16,2,24,0,112,12,51,0,80,151,142,0,16,2,24,0,112,12,51,0,80,151,142,0,16,2,24,0,112,12,51,0,80,151,142,0,16,2,24,0,112,12,51,0,80,151,142,0,0,0,0,0,8,0,8,0,0,0,0,0,1,0,1,0,16,0,16,0,1,0,1,0,9,0,9,0,24,0,24,0,2,0,2,0,17,0,17,0,2,0,2,0,32,0,32,0,10,0,10,0,3,0,3,0,25,0,25,0,18,0,18,0,11,0,11,0,3,0,3,0,40,0,40,0,33,0,33,0,26,0,26,0,4,0,4,0,19,0,19,0,48,0,48,0,12,0,12,0,4,0,4,0,34,0,34,0,27,0,27,0,5,0,5,0,41,0,41,0,20,0,20,0,5,0,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+194560);
/* memory initializer */ allocate([13,0,13,0,35,0,35,0,28,0,28,0,6,0,6,0,42,0,42,0,21,0,21,0,49,0,49,0,6,0,6,0,36,0,36,0,14,0,14,0,29,0,29,0,43,0,43,0,7,0,7,0,50,0,50,0,22,0,22,0,15,0,15,0,37,0,37,0,44,0,44,0,30,0,30,0,51,0,51,0,23,0,23,0,38,0,38,0,45,0,45,0,31,0,31,0,52,0,52,0,39,0,39,0,53,0,53,0,46,0,46,0,54,0,54,0,47,0,47,0,55,0,55,0,0,0,0,0,0,0,8,0,16,0,1,0,9,0,24,0,2,0,17,0,32,0,10,0,25,0,3,0,40,0,18,0,11,0,33,0,26,0,19,0,4,0,48,0,41,0,34,0,12,0,27,0,56,0,20,0,5,0,42,0,35,0,13,0,49,0,28,0,6,0,21,0,43,0,36,0,14,0,50,0,29,0,57,0,7,0,44,0,22,0,37,0,51,0,15,0,58,0,30,0,23,0,45,0,52,0,38,0,59,0,31,0,46,0,53,0,39,0,60,0,47,0,61,0,54,0,62,0,55,0,63,0,0,0,0,0,0,0,0,0,4,0,4,0,1,0,1,0,8,0,8,0,5,0,5,0,1,0,1,0,2,0,2,0,9,0,9,0,2,0,2,0,6,0,6,0,3,0,3,0,10,0,10,0,7,0,7,0,11,0,11,0,0,0,0,0,0,0,4,0,1,0,8,0,5,0,12,0,9,0,2,0,6,0,13,0,3,0,10,0,7,0,14,0,11,0,15,0,0,0,0,0,16,0,16,0,0,0,0,0,32,0,32,0,1,0,1,0,48,0,48,0,17,0,17,0,1,0,1,0,64,0,64,0,2,0,2,0,33,0,33,0,80,0,80,0,18,0,18,0,2,0,2,0,49,0,49,0,3,0,3,0,96,0,96,0,34,0,34,0,65,0,65,0,19,0,19,0,3,0,3,0,112,0,112,0,50,0,50,0,4,0,4,0,81,0,81,0,35,0,35,0,66,0,66,0,4,0,4,0,128,0,128,0,20,0,20,0,51,0,51,0,97,0,97,0,82,0,82,0,5,0,5,0,36,0,36,0,144,0,144,0,67,0,67,0,113,0,113,0,21,0,21,0,52,0,52,0,5,0,5,0,98,0,98,0,160,0,160,0,83,0,83,0,37,0,37,0,6,0,6,0,68,0,68,0,129,0,129,0,22,0,22,0,53,0,53,0,114,0,114,0,6,0,6,0,99,0,99,0,176,0,176,0,84,0,84,0,38,0,38,0,7,0,7,0,69,0,69,0,145,0,145,0,130,0,130,0,115,0,115,0,23,0,23,0,54,0,54,0,192,0,192,0,100,0,100,0,7,0,7,0,85,0,85,0,161,0,161,0,39,0,39,0,70,0,70,0,8,0,8,0,146,0,146,0,131,0,131,0,116,0,116,0,55,0,55,0,208,0,208,0,101,0,101,0,24,0,24,0,86,0,86,0,8,0,8,0,132,0,132,0,40,0,40,0,71,0,71,0,177,0,177,0,147,0,147,0,224,0,224,0,117,0,117,0,162,0,162,0,9,0,9,0,102,0,102,0,56,0,56,0,25,0,25,0,87,0,87,0,148,0,148,0,9,0,9,0,133,0,133,0,72,0,72,0,118,0,118,0,193,0,193,0,163,0,163,0,41,0,41,0,103,0,103,0,178,0,178,0,10,0,10,0,57,0,57,0,149,0,149,0,134,0,134,0,88,0,88,0,26,0,26,0,119,0,119,0,10,0,10,0,164,0,164,0,104,0,104,0,73,0,73,0,209,0,209,0,179,0,179,0,42,0,42,0,11,0,11,0,194,0,194,0,135,0,135,0,165,0,165,0,150,0,150,0,58,0,58,0,27,0,27,0,89,0,89,0,11,0,11,0,120,0,120,0,74,0,74,0,43,0,43,0,225,0,225,0,105,0,105,0,12,0,12,0,180,0,180,0,151,0,151,0,195,0,195,0,136,0,136,0,28,0,28,0,166,0,166,0,121,0,121,0,59,0,59,0,12,0,12,0,210,0,210,0,90,0,90,0,106,0,106,0,44,0,44,0,181,0,181,0,75,0,75,0,152,0,152,0,13,0,13,0,167,0,167,0,137,0,137,0,13,0,13,0,60,0,60,0,196,0,196,0,122,0,122,0,29,0,29,0,91,0,91,0,14,0,14,0,182,0,182,0,76,0,76,0,211,0,211,0,153,0,153,0,14,0,14,0,107,0,107,0,138,0,138,0,45,0,45,0,226,0,226,0,168,0,168,0,197,0,197,0,123,0,123,0,30,0,30,0,61,0,61,0,15,0,15,0,92,0,92,0,154,0,154,0,183,0,183,0,169,0,169,0,108,0,108,0,212,0,212,0,77,0,77,0,139,0,139,0,198,0,198,0,46,0,46,0,124,0,124,0,227,0,227,0,62,0,62,0,31,0,31,0,184,0,184,0,93,0,93,0,170,0,170,0,155,0,155,0,185,0,185,0,78,0,78,0,47,0,47,0,199,0,199,0,213,0,213,0,140,0,140,0,63,0,63,0,109,0,109,0,125,0,125,0,94,0,94,0,200,0,200,0,171,0,171,0,156,0,156,0,228,0,228,0,186,0,186,0,214,0,214,0,201,0,201,0,79,0,79,0,141,0,141,0,110,0,110,0,229,0,229,0,95,0,95,0,126,0,126,0,215,0,215,0,172,0,172,0,111,0,111,0,142,0,142,0,202,0,202,0,157,0,157,0,216,0,216,0,230,0,230,0,217,0,217,0,187,0,187,0,127,0,127,0,231,0,231,0,158,0,158,0,173,0,173,0,143,0,143,0,203,0,203,0,188,0,188,0,232,0,232,0,218,0,218,0,233,0,233,0,159,0,159,0,174,0,174,0,204,0,204,0,189,0,189,0,234,0,234,0,219,0,219,0,175,0,175,0,205,0,205,0,235,0,235,0,220,0,220,0,190,0,190,0,236,0,236,0,206,0,206,0,191,0,191,0,221,0,221,0,207,0,207,0,237,0,237,0,222,0,222,0,238,0,238,0,223,0,223,0,239,0,239,0,0,0,0,0,0,0,16,0,32,0,1,0,48,0,17,0,64,0,33,0,2,0,80,0,18,0,49,0,96,0,34,0,3,0,65,0,19,0,112,0,50,0,81,0,35,0,4,0,128,0,66,0,20,0,97,0,51,0,82,0,5,0,144,0,36,0,67,0,113,0,98,0,21,0,52,0,160,0,83,0,129,0,37,0,68,0,6,0,114,0,176,0,99,0,53,0,22,0,84,0,145,0,38,0,69,0,130,0,7,0,115,0,192,0,100,0,54,0,23,0,85,0,161,0,146,0,131,0,39,0,70,0,208,0,116,0,8,0,101,0,177,0,55,0,86,0,24,0,162,0,147,0,132,0,71,0,224,0,117,0,40,0,102,0,9,0,148,0,56,0,87,0,193,0,163,0,240,0,133,0,178,0,25,0,118,0,72,0,41,0,103,0,164,0,10,0,149,0,88,0,134,0,209,0,179,0,57,0,119,0,194,0,26,0,73,0,165,0,150,0,104,0,42,0,135,0,11,0,180,0,120,0,89,0,225,0,195,0,58,0,27,0,210,0,151,0,181,0,166,0,74,0,43,0,105,0,12,0,136,0,90,0,59,0,241,0,121,0,28,0,196,0,167,0,211,0,152,0,44,0,182,0,137,0,75,0,13,0,226,0,106,0,122,0,60,0,197,0,91,0,168,0,29,0,183,0,153,0,14,0,76,0,212,0,138,0,45,0,107,0,15,0,198,0,92,0,227,0,169,0,30,0,123,0,154,0,61,0,242,0,184,0,213,0,139,0,46,0,77,0,31,0,108,0,170,0,199,0,185,0,124,0,228,0,93,0,155,0,214,0,62,0,140,0,243,0,78,0,47,0,200,0,109,0,186,0,171,0,201,0,94,0,63,0,215,0,229,0,156,0,79,0,125,0,141,0,110,0,216,0,187,0,172,0,244,0,202,0,230,0,217,0,95,0,157,0,126,0,245,0,111,0,142,0,231,0,188,0,127,0,158,0,218,0,173,0,232,0,246,0,233,0,203,0,143,0,247,0,174,0,189,0,159,0,219,0,204,0,248,0,234,0,249,0,175,0,190,0,220,0,205,0,250,0,235,0,191,0,221,0,251,0,236,0,206,0,252,0,222,0,207,0,237,0,223,0,253,0,238,0,254,0,239,0,255,0,255,255,0,0,0,0,255,255,0,0,1,0,1,0,0,0,255,255,0,0,0,0,255,255,0,0,1,0,1,0,0,0,255,255,255,255,1,0,255,255,255,255,1,0,1,0,1,0,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,1,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,129,18,18,0,4,196,36,0,2,1,8,0,0,0,0,0,145,50,18,0,68,196,37,0,34,183,57,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,0,1,2,3,3,4,4,5,5,5,5,5,0,0,0,0,255,7,0,0,255,7,0,0,255,6,0,0,105,6,0,0,255,5,0,0,172,5,0,0,105,5,0,0,48,5,0,0,255,4,0,0,211,4,0,0,172,4,0,0,137,4,0,0,105,4,0,0,75,4,0,0,48,4,0,0,22,4,0,0,255,3,0,0,232,3,0,0,211,3,0,0,191,3,0,0,172,3,0,0,154,3,0,0,137,3,0,0,121,3,0,0,105,3,0,0,90,3,0,0,75,3,0,0,61,3,0,0,48,3,0,0,35,3,0,0,22,3,0,0,10,3,0,0,255,2,0,0,243,2,0,0,232,2,0,0,221,2,0,0,211,2,0,0,201,2,0,0,191,2,0,0,181,2,0,0,172,2,0,0,163,2,0,0,154,2,0,0,145,2,0,0,137,2,0,0,129,2,0,0,121,2,0,0,113,2,0,0,105,2,0,0,97,2,0,0,90,2,0,0,82,2,0,0,75,2,0,0,68,2,0,0,61,2,0,0,55,2,0,0,48,2,0,0,41,2,0,0,35,2,0,0,29,2,0,0,22,2,0,0,16,2,0,0,10,2,0,0,4,2,0,0,255,1,0,0,249,1,0,0,243,1,0,0,238,1,0,0,232,1,0,0,227,1,0,0,221,1,0,0,216,1,0,0,211,1,0,0,206,1,0,0,201,1,0,0,196,1,0,0,191,1,0,0,186,1,0,0,181,1,0,0,177,1,0,0,172,1,0,0,168,1,0,0,163,1,0,0,159,1,0,0,154,1,0,0,150,1,0,0,145,1,0,0,141,1,0,0,137,1,0,0,133,1,0,0,129,1,0,0,125,1,0,0,121,1,0,0,117,1,0,0,113,1,0,0,109,1,0,0,105,1,0,0,101,1,0,0,97,1,0,0,93,1,0,0,90,1,0,0,86,1,0,0,82,1,0,0,79,1,0,0,75,1,0,0,72,1,0,0,68,1,0,0,65,1,0,0,61,1,0,0,58,1,0,0,55,1,0,0,51,1,0,0,48,1,0,0,45,1,0,0,41,1,0,0,38,1,0,0,35,1,0,0,32,1,0,0,29,1,0,0,25,1,0,0,22,1,0,0,19,1,0,0,16,1,0,0,13,1,0,0,10,1,0,0,7,1,0,0,4,1,0,0,1,1,0,0,255,0,0,0,252,0,0,0,249,0,0,0,246,0,0,0,243,0,0,0,240,0,0,0,238,0,0,0,235,0,0,0,232,0,0,0,229,0,0,0,227,0,0,0,224,0,0,0,221,0,0,0,219,0,0,0,216,0,0,0,214,0,0,0,211,0,0,0,208,0,0,0,206,0,0,0,203,0,0,0,201,0,0,0,198,0,0,0,196,0,0,0,194,0,0,0,191,0,0,0,189,0,0,0,186,0,0,0,184,0,0,0,181,0,0,0,179,0,0,0,177,0,0,0,174,0,0,0,172,0,0,0,170,0,0,0,168,0,0,0,165,0,0,0,163,0,0,0,161,0,0,0,159,0,0,0,156,0,0,0,154,0,0,0,152,0,0,0,150,0,0,0,148,0,0,0,145,0,0,0,143,0,0,0,141,0,0,0,139,0,0,0,137,0,0,0,135,0,0,0,133,0,0,0,131,0,0,0,129,0,0,0,127,0,0,0,125,0,0,0,123,0,0,0,121,0,0,0,119,0,0,0,117,0,0,0,115,0,0,0,113,0,0,0,111,0,0,0,109,0,0,0,107,0,0,0,105,0,0,0,103,0,0,0,101,0,0,0,99,0,0,0,97,0,0,0,95,0,0,0,93,0,0,0,92,0,0,0,90,0,0,0,88,0,0,0,86,0,0,0,84,0,0,0,82,0,0,0,81,0,0,0,79,0,0,0,77,0,0,0,75,0,0,0,73,0,0,0,72,0,0,0,70,0,0,0,68,0,0,0,66,0,0,0,65,0,0,0,63,0,0,0,61,0,0,0,60,0,0,0,58,0,0,0,56,0,0,0,55,0,0,0,53,0,0,0,51,0,0,0,50,0,0,0,48,0,0,0,46,0,0,0,45,0,0,0,43,0,0,0,41,0,0,0,40,0,0,0,38,0,0,0,37,0,0,0,35,0,0,0,33,0,0,0,32,0,0,0,30,0,0,0,29,0,0,0,27,0,0,0,25,0,0,0,24,0,0,0,22,0,0,0,21,0,0,0,19,0,0,0,18,0,0,0,16,0,0,0,15,0,0,0,13,0,0,0,12,0,0,0,10,0,0,0,9,0,0,0,7,0,0,0,6,0,0,0,4,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,1,0,0,0,0,0,1,0,0,1,255,2,254,253,0,0,0,2,255,4,254,253,0,0,3,86,128,6,86,23,88,29,6,86,128,11,87,42,91,52,9,86,129,17,88,61,94,76,12,86,129,22,88,77,97,93,15,87,129,28,89,93,100,110,17,87,129,33,90,105,103,123,20,88,130,38,91,118,106,136,23,88,130,43,91,128,108,146,26,89,131,48,92,139,111,156,28,89,131,53,93,147,114,163,31,90,131,58,94,156,117,171,34,90,131,62,94,163,119,177,37,90,132,66,95,171,122,184,39,90,132,70,96,177,124,189,42,91,132,75,97,183,127,194,44,91,132,79,97,188,129,198,47,92,133,83,98,193,132,202,49,92,133,86,99,197,134,205,52,93,133,90,100,201,137,208,54,93,133,94,100,204,139,211,57,94,134,98,101,208,142,214,59,94,134,101,102,211,144,216,62,94,135,105,103,214,146,218,64,94,135,108,103,216,148,220,66,95,135,111,104,219,151,222,68,95,135,114,105,221,153,223,71,96,136,117,106,224,155,225,73,96,136,120,106,225,157,226,76,97,136,123,107,227,159,228,78,97,136,126,108,229,160,229,80,98,137,129,109,231,162,231,82,98,137,131,109,232,164,232,84,98,138,134,110,234,166,233,86,98,138,137,111,235,168,234,89,99,138,140,112,236,170,235,91,99,138,142,112,237,171,235,93,100,139,145,113,238,173,236,95,100,139,147,114,239,174,237,97,101,140,149,115,240,176,238,99,101,140,151,115,241,177,238,101,102,140,154,116,242,179,239,103,102,140,156,117,242,180,239,105,103,141,158,118,243,182,240,107,103,141,160,118,243,183,240,109,104,141,162,119,244,185,241,111,104,141,164,119,244,186,241,113,104,142,166,120,245,187,242,114,104,142,168,121,245,188,242,116,105,143,170,122,246,190,243,118,105,143,171,122,246,191,243,120,106,143,173,123,247,192,244,121,106,143,175,124,247,193,244,123,107,144,177,125,248,195,244,125,107,144,178,125,248,196,244,127,108,145,180,126,249,197,245,128,108,145,181,127,249,198,245,130,109,145,183,128,249,199,245,132,109,145,184,128,249,200,245,134,110,146,186,129,250,201,246,135,110,146,187,130,250,202,246,137,111,147,189,131,251,203,246,138,111,147,190,131,251,204,246,140,112,147,192,132,251,205,247,141,112,147,193,132,251,206,247,143,113,148,194,133,251,207,247,144,113,148,195,134,251,207,247,146,114,149,197,135,252,208,248,147,114,149,198,135,252,209,248,149,115,149,199,136,252,210,248,150,115,149,200,137,252,210,248,152,115,150,201,138,252,211,248,153,115,150,202,138,252,212,248,155,116,151,204,139,253,213,249,156,116,151,205,139,253,213,249,158,117,151,206,140,253,214,249,159,117,151,207,141,253,215,249,161,118,152,208,142,253,216,249,162,118,152,209,142,253,216,249,163,119,153,210,143,253,217,249,164,119,153,211,143,253,217,249,166,120,153,212,144,254,218,250,167,120,153,212,145,254,219,250,168,121,154,213,146,254,220,250,169,121,154,214,146,254,220,250,171,122,155,215,147,254,221,250,172,122,155,216,147,254,221,250,173,123,155,217,148,254,222,250,174,123,155,217,149,254,222,250,176,124,156,218,150,254,223,250,177,124,156,219,150,254,223,250,178,125,157,220,151,254,224,251,179,125,157,220,151,254,224,251,180,126,157,221,152,254,225,251,181,126,157,221,152,254,225,251,183,127,158,222,153,254,226,251,184,127,158,223,154,254,226,251,185,128,159,224,155,255,227,251,186,128,159,224,155,255,227,251,187,129,160,225,156,255,228,251,188,130,160,225,156,255,228,251,189,131,160,226,157,255,228,251,190,131,160,226,158,255,228,251,191,132,161,227,159,255,229,251,192,132,161,227,159,255,229,251,193,133,162,228,160,255,230,252,194,133,162,229,160,255,230,252,195,134,163,230,161,255,231,252,196,134,163,230,161,255,231,252,197,135,163,231,162,255,231,252,198,135,163,231,162,255,231,252,199,136,164,232,163,255,232,252,200,136,164,232,164,255,232,252,201,137,165,233,165,255,233,252,201,137,165,233,165,255,233,252,202,138,166,233,166,255,233,252,203,138,166,233,166,255,233,252,204,139,166,234,167,255,234,252,205,139,166,234,167,255,234,252,206,140,167,235,168,255,235,252,206,140,167,235,168,255,235,252,207,141,168,236,169,255,235,252,208,141,168,236,170,255,235,252,209,142,169,237,171,255,236,252,209,143,169,237,171,255,236,252,210,144,169,237,172,255,236,252,211,144,169,237,172,255,236,252,212,145,170,238,173,255,237,252,213,145,170,238,173,255,237,252,214,146,171,239,174,255,237,253,214,146,171,239,174,255,237,253,215,147,172,240,175,255,238,253,215,147,172,240,175,255,238,253,216,148,173,240,176,255,238,253,217,148,173,240,176,255,238,253,218,149,173,241,177,255,239,253,218,149,173,241,178,255,239,253,219,150,174,241,179,255,239,253,219,151,174,241,179,255,239,253,220,152,175,242,180,255,240,253,221,152,175,242,180,255,240,253,222,153,176,242,181,255,240,253,222,153,176,242,181,255,240,253,223,154,177,243,182,255,240,253,223,154,177,243,182,255,240,253,224,155,178,244,183,255,241,253,224,155,178,244,183,255,241,253,225,156,178,244,184,255,241,253,225,157,178,244,184,255,241,253,226,158,179,244,185,255,242,253,227,158,179,244,185,255,242,253,228,159,180,245,186,255,242,253,228,159,180,245,186,255,242,253,229,160,181,245,187,255,242,253,229,160,181,245,187,255,242,253,230,161,182,246,188,255,243,253,230,162,182,246,188,255,243,253,231,163,183,246,189,255,243,253,231,163,183,246,189,255,243,253,232,164,184,247,190,255,243,253,232,164,184,247,190,255,243,253,233,165,185,247,191,255,244,253,233,165,185,247,191,255,244,253,234,166,185,247,192,255,244,253,234,167,185,247,192,255,244,253,235,168,186,248,193,255,244,253,235,168,186,248,193,255,244,253,236,169,187,248,194,255,244,253,236,169,187,248,194,255,244,253,236,170,188,248,195,255,245,253,236,170,188,248,195,255,245,253,237,171,189,249,196,255,245,254,237,172,189,249,196,255,245,254,238,173,190,249,197,255,245,254,238,173,190,249,197,255,245,254,239,174,191,249,198,255,245,254,239,174,191,249,198,255,245,254,240,175,192,249,199,255,246,254,240,176,192,249,199,255,246,254,240,177,193,250,200,255,246,254,240,177,193,250,200,255,246,254,241,178,194,250,201,255,246,254,241,178,194,250,201,255,246,254,242,179,195,250,202,255,246,254,242,180,195,250,202,255,246,254,242,181,196,250,203,255,247,254,242,181,196,250,203,255,247,254,243,182,197,251,204,255,247,254,243,183,197,251,204,255,247,254,244,184,198,251,205,255,247,254,244,184,198,251,205,255,247,254,244,185,199,251,206,255,247,254,244,185,199,251,206,255,247,254,245,186,200,251,207,255,247,254,245,187,200,251,207,255,247,254,246,188,201,252,207,255,248,254,246,188,201,252,207,255,248,254,246,189,202,252,208,255,248,254,246,190,202,252,208,255,248,254,247,191,203,252,209,255,248,254,247,191,203,252,209,255,248,254,247,192,204,252,210,255,248,254,247,193,204,252,210,255,248,254,248,194,205,252,211,255,248,254,248,194,205,252,211,255,248,254,248,195,206,252,212,255,249,254,248,196,206,252,212,255,249,254,249,197,207,253,213,255,249,254,249,197,207,253,213,255,249,254,249,198,208,253,214,255,249,254,249,199,209,253,214,255,249,254,250,200,210,253,215,255,249,254,250,200,210,253,215,255,249,254,250,201,211,253,215,255,249,254,250,202,211,253,215,255,249,254,250,203,212,253,216,255,249,254,250,203,212,253,216,255,249,254,251,204,213,253,217,255,250,254,251,205,213,253,217,255,250,254,251,206,214,254,218,255,250,254,251,206,215,254,218,255,250,254,252,207,216,254,219,255,250,254,252,208,216,254,219,255,250,254,252,209,217,254,220,255,250,254,252,210,217,254,220,255,250,254,252,211,218,254,221,255,250,254,252,212,218,254,221,255,250,254,253,213,219,254,222,255,250,254,253,213,220,254,222,255,250,254,253,214,221,254,223,255,250,254,253,215,221,254,223,255,250,254,253,216,222,254,224,255,251,254,253,217,223,254,224,255,251,254,253,218,224,254,225,255,251,254,253,219,224,254,225,255,251,254,254,220,225,254,225,255,251,254,254,221,226,254,225,255,251,254,254,222,227,255,226,255,251,254,254,223,227,255,226,255,251,254,254,224,228,255,227,255,251,254,254,225,229,255,227,255,251,254,254,226,230,255,228,255,251,254,254,227,230,255,229,255,251,254,255,228,231,255,230,255,251,254,255,229,232,255,230,255,251,254,255,230,233,255,231,255,252,254,255,231,234,255,231,255,252,254,255,232,235,255,232,255,252,254,255,233,236,255,232,255,252,254,255,235,237,255,233,255,252,254,255,236,238,255,234,255,252,254,255,238,240,255,235,255,252,255,255,239,241,255,235,255,252,254,255,241,243,255,236,255,252,254,255,243,245,255,237,255,252,254,255,246,247,255,239,255,253,255,255,246,247,255,239,255,253,255,96,153,32,0,24,146,32,0,44,1,0,0,1,0,0,0,0,0,0,128,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,138,32,0,200,132,32,0,52,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,32,127,32,0,16,121,32,0,68,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,64,116,32,0,160,106,32,0,56,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,96,82,32,0,184,68,32,0,60,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,96,62,32,0,0,55,32,0,64,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,96,48,32,0,88,42,32,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,96,48,32,0,16,37,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,96,48,32,0,216,31,32,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,96,48,32,0,144,89,40,0,144,82,40,0,240,0,0,0,1,0,0,0,64,66,15,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,160,57,40,0,184,44,40,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,57,40,0,64,36,40,0,0,0,0,0,0,0,0,0,128,0,0,0,64,66,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,57,40,0,32,29,40,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,57,40,0,32,23,40,0,216,17,40,0,72,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,16,13,40,0,56,7,40,0,96,1,40,0,80,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,104,247,39,0,24,222,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,16,13,40,0,160,207,39,0,240,195,39,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,16,13,40,0,160,187,39,0,160,179,39,0,76,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,79,64,17,0,0,0,0,0,0,0,176,172,39,0,120,166,39,0,84,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,208,156,39,0,64,149,39,0,88,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,24,64,17,0,0,0,0,0,0,0,232,140,39,0,208,117,39,0,92,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,17,0,0,0,0,0,0,0,64,103,39,0,120,95,39,0,96,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,248,86,39,0,136,27,156,0,44,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,48,192,0,0,0,0,0,0,48,64,17,0,0,0,0,0,0,0,160,57,40,0,136,27,156,0,240,0,0,0,1,0,0,0,64,66,15,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,160,57,40,0,208,75,39,0,136,27,156,0,48,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,17,0,0,0,216,70,39,0,216,64,39,0,88,59,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,216,70,39,0,176,53,39,0,48,36,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,216,70,39,0,16,24,39,0,160,106,32,0,56,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,64,17,0,0,0,0,0,0,0,72,18,39,0,184,68,32,0,60,1,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,17,0,0,0,0,0,0,0,96,48,32,0,0,55,32,0,64,1,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,8,64,17,0,0,0,0,0,0,0,88,11,39,0,16,121,32,0,68,1,0,0,1,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,2,254,253,0,0,0,2,255,4,254,253,0,0,0,1,255,2,254,253,0,0,0,2,255,4,254,253,0,0,0,1,255,2,3,4,254,253,5,6,252,251,250,7,8,9,249,248,247,246,0,0,0,0,0,2,255,4,6,8,254,253,10,12,252,251,250,14,16,18,249,248,247,246,0,0,0,0,0,255,0,0,0,0,0,0,6,86,128,11,87,42,91,52,3,86,128,6,86,23,88,29,6,86,128,11,87,42,91,52,9,86,129,17,88,61,94,76,12,86,129,22,88,77,97,93,15,87,129,28,89,93,100,110,17,87,129,33,90,105,103,123,20,88,130,38,91,118,106,136,23,88,130,43,91,128,108,146,26,89,131,48,92,139,111,156,28,89,131,53,93,147,114,163,31,90,131,58,94,156,117,171,34,90,131,62,94,163,119,177,37,90,132,66,95,171,122,184,39,90,132,70,96,177,124,189,42,91,132,75,97,183,127,194,44,91,132,79,97,188,129,198,47,92,133,83,98,193,132,202,49,92,133,86,99,197,134,205,52,93,133,90,100,201,137,208,54,93,133,94,100,204,139,211,57,94,134,98,101,208,142,214,59,94,134,101,102,211,144,216,62,94,135,105,103,214,146,218,64,94,135,108,103,216,148,220,66,95,135,111,104,219,151,222,68,95,135,114,105,221,153,223,71,96,136,117,106,224,155,225,73,96,136,120,106,225,157,226,76,97,136,123,107,227,159,228,78,97,136,126,108,229,160,229,80,98,137,129,109,231,162,231,82,98,137,131,109,232,164,232,84,98,138,134,110,234,166,233,86,98,138,137,111,235,168,234,89,99,138,140,112,236,170,235,91,99,138,142,112,237,171,235,93,100,139,145,113,238,173,236,95,100,139,147,114,239,174,237,97,101,140,149,115,240,176,238,99,101,140,151,115,241,177,238,101,102,140,154,116,242,179,239,103,102,140,156,117,242,180,239,105,103,141,158,118,243,182,240,107,103,141,160,118,243,183,240,109,104,141,162,119,244,185,241,111,104,141,164,119,244,186,241,113,104,142,166,120,245,187,242,114,104,142,168,121,245,188,242,116,105,143,170,122,246,190,243,118,105,143,171,122,246,191,243,120,106,143,173,123,247,192,244,121,106,143,175,124,247,193,244,123,107,144,177,125,248,195,244,125,107,144,178,125,248,196,244,127,108,145,180,126,249,197,245,128,108,145,181,127,249,198,245,130,109,145,183,128,249,199,245,132,109,145,184,128,249,200,245,134,110,146,186,129,250,201,246,135,110,146,187,130,250,202,246,137,111,147,189,131,251,203,246,138,111,147,190,131,251,204,246,140,112,147,192,132,251,205,247,141,112,147,193,132,251,206,247,143,113,148,194,133,251,207,247,144,113,148,195,134,251,207,247,146,114,149,197,135,252,208,248,147,114,149,198,135,252,209,248,149,115,149,199,136,252,210,248,150,115,149,200,137,252,210,248,152,115,150,201,138,252,211,248,153,115,150,202,138,252,212,248,155,116,151,204,139,253,213,249,156,116,151,205,139,253,213,249,158,117,151,206,140,253,214,249,159,117,151,207,141,253,215,249,161,118,152,208,142,253,216,249,162,118,152,209,142,253,216,249,163,119,153,210,143,253,217,249,164,119,153,211,143,253,217,249,166,120,153,212,144,254,218,250,167,120,153,212,145,254,219,250,168,121,154,213,146,254,220,250,169,121,154,214,146,254,220,250,171,122,155,215,147,254,221,250,172,122,155,216,147,254,221,250,173,123,155,217,148,254,222,250,174,123,155,217,149,254,222,250,176,124,156,218,150,254,223,250,177,124,156,219,150,254,223,250,178,125,157,220,151,254,224,251,179,125,157,220,151,254,224,251,180,126,157,221,152,254,225,251,181,126,157,221,152,254,225,251,183,127,158,222,153,254,226,251,184,127,158,223,154,254,226,251,185,128,159,224,155,255,227,251,186,128,159,224,155,255,227,251,187,129,160,225,156,255,228,251,188,130,160,225,156,255,228,251,189,131,160,226,157,255,228,251,190,131,160,226,158,255,228,251,191,132,161,227,159,255,229,251,192,132,161,227,159,255,229,251,193,133,162,228,160,255,230,252,194,133,162,229,160,255,230,252,195,134,163,230,161,255,231,252,196,134,163,230,161,255,231,252,197,135,163,231,162,255,231,252,198,135,163,231,162,255,231,252,199,136,164,232,163,255,232,252,200,136,164,232,164,255,232,252,201,137,165,233,165,255,233,252,201,137,165,233,165,255,233,252,202,138,166,233,166,255,233,252,203,138,166,233,166,255,233,252,204,139,166,234,167,255,234,252,205,139,166,234,167,255,234,252,206,140,167,235,168,255,235,252,206,140,167,235,168,255,235,252,207,141,168,236,169,255,235,252,208,141,168,236,170,255,235,252,209,142,169,237,171,255,236,252,209,143,169,237,171,255,236,252,210,144,169,237,172,255,236,252,211,144,169,237,172,255,236,252,212,145,170,238,173,255,237,252,213,145,170,238,173,255,237,252,214,146,171,239,174,255,237,253,214,146,171,239,174,255,237,253,215,147,172,240,175,255,238,253,215,147,172,240,175,255,238,253,216,148,173,240,176,255,238,253,217,148,173,240,176,255,238,253,218,149,173,241,177,255,239,253,218,149,173,241,178,255,239,253,219,150,174,241,179,255,239,253,219,151,174,241,179,255,239,253,220,152,175,242,180,255,240,253,221,152,175,242,180,255,240,253,222,153,176,242,181,255,240,253,222,153,176,242,181,255,240,253,223,154,177,243,182,255,240,253,223,154,177,243,182,255,240,253,224,155,178,244,183,255,241,253,224,155,178,244,183,255,241,253,225,156,178,244,184,255,241,253,225,157,178,244,184,255,241,253,226,158,179,244,185,255,242,253,227,158,179,244,185,255,242,253,228,159,180,245,186,255,242,253,228,159,180,245,186,255,242,253,229,160,181,245,187,255,242,253,229,160,181,245,187,255,242,253,230,161,182,246,188,255,243,253,230,162,182,246,188,255,243,253,231,163,183,246,189,255,243,253,231,163,183,246,189,255,243,253,232,164,184,247,190,255,243,253,232,164,184,247,190,255,243,253,233,165,185,247,191,255,244,253,233,165,185,247,191,255,244,253,234,166,185,247,192,255,244,253,234,167,185,247,192,255,244,253,235,168,186,248,193,255,244,253,235,168,186,248,193,255,244,253,236,169,187,248,194,255,244,253,236,169,187,248,194,255,244,253,236,170,188,248,195,255,245,253,236,170,188,248,195,255,245,253,237,171,189,249,196,255,245,254,237,172,189,249,196,255,245,254,238,173,190,249,197,255,245,254,238,173,190,249,197,255,245,254,239,174,191,249,198,255,245,254,239,174,191,249,198,255,245,254,240,175,192,249,199,255,246,254,240,176,192,249,199,255,246,254,240,177,193,250,200,255,246,254,240,177,193,250,200,255,246,254,241,178,194,250,201,255,246,254,241,178,194,250,201,255,246,254,242,179,195,250,202,255,246,254,242,180,195,250,202,255,246,254,242,181,196,250,203,255,247,254,242,181,196,250,203,255,247,254,243,182,197,251,204,255,247,254,243,183,197,251,204,255,247,254,244,184,198,251,205,255,247,254,244,184,198,251,205,255,247,254,244,185,199,251,206,255,247,254,244,185,199,251,206,255,247,254,245,186,200,251,207,255,247,254,245,187,200,251,207,255,247,254,246,188,201,252,207,255,248,254,246,188,201,252,207,255,248,254,246,189,202,252,208,255,248,254,246,190,202,252,208,255,248,254,247,191,203,252,209,255,248,254,247,191,203,252,209,255,248,254,247,192,204,252,210,255,248,254,247,193,204,252,210,255,248,254,248,194,205,252,211,255,248,254,248,194,205,252,211,255,248,254,248,195,206,252,212,255,249,254,248,196,206,252,212,255,249,254,249,197,207,253,213,255,249,254,249,197,207,253,213,255,249,254,249,198,208,253,214,255,249,254,249,199,209,253,214,255,249,254,250,200,210,253,215,255,249,254,250,200,210,253,215,255,249,254,250,201,211,253,215,255,249,254,250,202,211,253,215,255,249,254,250,203,212,253,216,255,249,254,250,203,212,253,216,255,249,254,251,204,213,253,217,255,250,254,251,205,213,253,217,255,250,254,251,206,214,254,218,255,250,254,251,206,215,254,218,255,250,254,252,207,216,254,219,255,250,254,252,208,216,254,219,255,250,254,252,209,217,254,220,255,250,254,252,210,217,254,220,255,250,254,252,211,218,254,221,255,250,254,252,212,218,254,221,255,250,254,253,213,219,254,222,255,250,254,253,213,220,254,222,255,250,254,253,214,221,254,223,255,250,254,253,215,221,254,223,255,250,254,253,216,222,254,224,255,251,254,253,217,223,254,224,255,251,254,253,218,224,254,225,255,251,254,253,219,224,254,225,255,251,254,254,220,225,254,225,255,251,254,254,221,226,254,225,255,251,254,254,222,227,255,226,255,251,254,254,223,227,255,226,255,251,254,254,224,228,255,227,255,251,254,254,225,229,255,227,255,251,254,254,226,230,255,228,255,251,254,254,227,230,255,229,255,251,254,255,228,231,255,230,255,251,254,255,229,232,255,230,255,251,254,255,230,233,255,231,255,252,254,255,231,234,255,231,255,252,254,255,232,235,255,232,255,252,254,255,233,236,255,232,255,252,254,255,235,237,255,233,255,252,254,255,236,238,255,234,255,252,254,255,238,240,255,235,255,252,255,255,239,241,255,235,255,252,254,255,241,243,255,236,255,252,254,255,243,245,255,237,255,252,254,255,246,247,255,239,255,253,255,10,0,0,0,1,0,0,0,255,255,255,255,10,0,0,0,3,0,0,0,255,255,255,255,10,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,13,0,0,0,1,0,0,0,255,255,255,255,13,0,0,0,3,0,0,0,255,255,255,255,13,0,0,0,2,0,0,0,255,255,255,255,11,0,0,0,1,0,0,0,255,255,255,255,11,0,0,0,3,0,0,0,255,255,255,255,10,0,0,0,1,0,0,0,3,0,0,0,10,0,0,0,2,0,0,0,3,0,0,0,9,0,0,0,0,0,0,0,255,255,255,255,11,0,0,0,1,0,0,0,3,0,0,0,13,0,0,0,1,0,0,0,3,0,0,0,11,0,0,0,2,0,0,0,255,255,255,255,11,0,0,0,2,0,0,0,3,0,0,0,13,0,0,0,2,0,0,0,3,0,0,0,12,0,0,0,1,0,0,0,255,255,255,255,12,0,0,0,2,0,0,0,255,255,255,255,12,0,0,0,3,0,0,0,255,255,255,255,12,0,0,0,1,0,0,0,3,0,0,0,12,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,0,0,0,0,255,255,255,255,4,0,0,0,0,0,0,0,255,255,255,255,7,0,0,0,0,0,0,0,255,255,255,255,6,0,0,0,0,0,0,0,255,255,255,255,8,0,0,0,0,0,0,0,255,255,255,255,5,0,0,0,0,0,0,0,255,255,255,255,3,0,0,0,0,0,0,0,255,255,255,255,137,30,42,148,151,207,70,52,91,92,45,102,136,116,180,74,90,100,73,32,19,187,222,215,46,34,100,91,30,32,116,121,186,93,86,94,72,35,36,149,68,206,68,63,105,73,31,28,138,57,124,55,122,151,67,23,21,140,126,197,40,37,171,86,27,28,128,154,212,45,43,53,74,32,27,107,86,160,63,134,102,59,67,44,140,161,202,78,67,119,63,36,126,146,123,158,60,90,96,43,46,168,134,107,128,69,142,92,44,29,68,159,201,177,50,57,77,58,38,76,114,97,172,78,133,92,46,41,76,140,63,184,69,112,57,38,32,85,140,46,112,54,151,133,39,27,61,131,110,175,44,75,136,52,30,74,113,130,175,51,64,58,47,35,80,100,74,143,64,163,74,36,61,116,114,128,162,80,125,82,82,26,26,171,208,204,44,32,105,55,44,68,166,179,192,57,57,108,42,26,11,199,241,228,23,15,85,68,42,19,131,160,199,55,52,83,58,50,25,139,115,232,39,52,118,50,35,33,153,104,162,64,59,131,44,24,16,150,177,202,33,19,156,55,27,12,153,203,218,26,27,49,53,49,21,110,116,168,59,80,76,38,72,19,168,203,212,50,50,107,103,26,36,129,132,201,83,80,93,59,38,83,112,103,162,98,136,90,62,30,23,158,200,207,59,57,50,67,30,29,84,86,191,102,91,59,60,32,33,112,71,220,64,89,104,53,26,34,130,56,149,84,120,103,53,21,23,133,109,210,56,77,172,77,19,29,112,142,228,55,66,36,61,29,29,93,97,165,83,175,162,47,47,43,114,137,181,100,99,95,69,23,29,128,83,199,46,44,101,53,40,55,139,69,183,61,80,110,40,29,19,161,180,207,43,24,91,60,34,19,105,61,198,53,64,89,52,31,22,158,40,209,58,62,89,44,31,29,147,46,158,56,102,198,35,19,12,135,87,209,41,45,167,55,25,21,118,95,215,38,39,66,51,38,25,113,58,164,70,93,97,47,54,34,146,108,203,72,103,151,64,19,37,156,66,138,49,95,133,46,27,80,150,55,124,55,121,135,36,23,27,165,149,166,54,64,118,53,21,36,131,63,163,60,109,81,40,26,35,154,40,185,51,97,123,35,19,34,179,19,97,48,129,124,36,20,26,136,62,164,33,77,154,45,18,32,130,90,157,40,79,91,45,26,28,129,45,129,49,147,123,38,44,51,136,74,162,57,97,121,75,17,22,136,138,185,32,34,166,56,39,58,133,117,173,48,53,187,35,21,12,161,212,207,20,23,145,56,29,19,117,109,181,55,68,112,47,29,17,153,64,220,59,51,114,46,16,24,136,76,147,41,64,172,34,17,11,108,152,187,13,15,209,51,24,14,115,133,209,32,26,104,55,30,18,122,79,179,44,88,116,37,49,25,129,168,164,41,54,148,82,22,32,127,143,213,39,41,70,62,44,61,123,105,189,48,57,64,47,25,17,175,222,220,24,30,86,68,36,17,106,102,206,59,74,74,57,39,23,151,68,216,55,63,58,49,30,35,141,70,168,82,40,115,51,25,15,136,129,202,38,35,139,68,26,16,111,141,215,29,28,28,59,39,19,114,75,180,77,104,42,40,61,26,126,152,206,61,59,93], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+204800);
/* memory initializer */ allocate([78,23,39,111,117,170,74,124,94,48,34,86,101,92,146,78,179,134,47,22,24,138,187,178,68,69,59,56,25,33,105,112,187,95,177,129,48,31,27,114,63,183,82,116,56,43,28,37,121,63,123,61,192,169,42,17,24,109,97,177,56,76,122,58,18,28,105,139,182,70,92,63,46,23,32,74,86,150,67,183,88,36,38,48,92,122,165,88,137,91,65,70,60,155,159,199,61,60,81,44,78,115,132,119,173,71,112,93,39,38,21,184,227,206,42,32,64,58,47,36,124,137,193,80,82,78,49,50,35,144,95,205,63,78,59,41,53,52,148,71,142,65,128,51,40,36,28,143,143,202,40,55,137,52,34,29,129,183,227,42,35,43,42,44,44,104,105,164,64,130,80,43,81,53,140,169,204,68,84,72,0,0,0,0,144,11,54,157,195,130,46,58,108,118,15,123,148,131,101,44,93,131,113,12,23,188,226,142,26,32,125,120,11,50,123,163,135,64,77,103,113,9,36,155,111,157,32,44,161,116,9,55,176,76,96,37,61,149,115,9,28,141,161,167,21,25,193,120,12,32,145,195,142,32,38,86,116,12,64,120,140,125,49,115,121,102,19,66,162,182,122,35,59,128,0,0,0,0,0,0,158,97,94,93,24,99,85,119,44,62,59,67,149,53,53,94,20,48,83,53,24,52,18,18,150,40,39,78,12,26,67,33,11,24,7,5,174,35,49,68,11,27,57,15,9,12,3,3,254,1,247,2,0,3,4,6,255,5,252,251,253,7,249,8,250,248,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,247,4,255,6,8,12,254,10,252,251,253,14,248,16,250,249,0,0,0,0,0,0,244,1,246,2,245,243,0,0,254,2,0,4,255,253,0,0,122,1,0,0,122,1,0,0,210,0,0,0,122,1,0,0,122,1,0,0,210,0,0,0,210,0,0,0,210,0,0,0,8,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,0,0,0,0,255,255,255,255,0,0,255,255,1,0,255,255,1,0,0,0,1,0,1,0,0,0,1,0,255,255,1,0,255,255,0,0,255,255,254,255,1,0,254,255,2,0,0,0,1,0,2,0,255,255,2,0,254,255,0,0,0,0,0,0,0,0,0,0,254,255,252,255,2,0,252,255,4,0,0,0,2,0,4,0,254,255,4,0,252,255,0,0,0,0,0,0,0,0,0,0,252,255,248,255,4,0,248,255,8,0,0,0,4,0,8,0,252,255,8,0,248,255,0,0,0,0,0,0,0,0,0,0,248,255,240,255,8,0,240,255,16,0,0,0,8,0,16,0,248,255,16,0,240,255,0,0,0,0,0,0,0,0,0,0,240,255,224,255,16,0,224,255,32,0,0,0,16,0,32,0,240,255,32,0,224,255,0,0,0,0,0,0,0,0,0,0,224,255,192,255,32,0,192,255,64,0,0,0,32,0,64,0,224,255,64,0,192,255,0,0,0,0,0,0,0,0,0,0,192,255,128,255,64,0,128,255,128,0,0,0,64,0,128,0,192,255,128,0,128,255,0,0,0,0,0,0,0,0,0,0,128,255,0,255,128,0,0,255,0,1,0,0,128,0,0,1,128,255,0,1,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,254,0,1,0,254,0,2,0,0,0,1,0,2,0,255,0,2,0,254,0,0,0,0,0,0,0,0,0,0,0,254,0,252,0,2,0,252,0,4,0,0,0,2,0,4,0,254,0,4,0,252,0,0,0,0,0,0,0,0,0,0,3,0,248,255,13,0,112,0,13,0,248,255,3,0,0,0,3,0,249,255,10,0,112,0,17,0,247,255,3,0,255,255,2,0,250,255,7,0,111,0,21,0,247,255,3,0,255,255,2,0,251,255,4,0,111,0,24,0,246,255,3,0,255,255,2,0,252,255,1,0,110,0,28,0,245,255,3,0,255,255,1,0,253,255,255,255,108,0,32,0,244,255,4,0,255,255,1,0,254,255,253,255,106,0,36,0,243,255,4,0,255,255,1,0,255,255,250,255,105,0,40,0,242,255,4,0,255,255,1,0,255,255,249,255,102,0,44,0,242,255,4,0,255,255,1,0,0,0,247,255,100,0,48,0,241,255,4,0,255,255,1,0,1,0,245,255,97,0,53,0,240,255,4,0,255,255,0,0,1,0,244,255,95,0,57,0,240,255,4,0,255,255,0,0,2,0,243,255,91,0,61,0,240,255,4,0,255,255,0,0,2,0,242,255,88,0,65,0,240,255,4,0,255,255,0,0,3,0,241,255,84,0,69,0,239,255,4,0,0,0,0,0,3,0,240,255,81,0,73,0,240,255,3,0,0,0,0,0,3,0,240,255,77,0,77,0,240,255,3,0,0,0,0,0,3,0,240,255,73,0,81,0,240,255,3,0,0,0,0,0,4,0,239,255,69,0,84,0,241,255,3,0,0,0,255,255,4,0,240,255,65,0,88,0,242,255,2,0,0,0,255,255,4,0,240,255,61,0,91,0,243,255,2,0,0,0,255,255,4,0,240,255,57,0,95,0,244,255,1,0,0,0,255,255,4,0,240,255,53,0,97,0,245,255,1,0,1,0,255,255,4,0,241,255,48,0,100,0,247,255,0,0,1,0,255,255,4,0,242,255,44,0,102,0,249,255,255,255,1,0,255,255,4,0,242,255,40,0,105,0,250,255,255,255,1,0,255,255,4,0,243,255,36,0,106,0,253,255,254,255,1,0,255,255,4,0,244,255,32,0,108,0,255,255,253,255,1,0,255,255,3,0,245,255,28,0,110,0,1,0,252,255,2,0,255,255,3,0,246,255,24,0,111,0,4,0,251,255,2,0,255,255,3,0,247,255,21,0,111,0,7,0,250,255,2,0,255,255,3,0,247,255,17,0,112,0,10,0,249,255,3,0,2,0,245,255,25,0,96,0,25,0,245,255,2,0,0,0,2,0,245,255,22,0,96,0,28,0,245,255,2,0,0,0,2,0,246,255,19,0,95,0,31,0,245,255,2,0,0,0,2,0,246,255,17,0,95,0,34,0,244,255,2,0,0,0,2,0,247,255,14,0,94,0,37,0,244,255,2,0,0,0,2,0,248,255,12,0,93,0,40,0,244,255,1,0,0,0,2,0,248,255,9,0,92,0,43,0,244,255,1,0,1,0,2,0,249,255,7,0,91,0,46,0,244,255,1,0,0,0,2,0,249,255,5,0,90,0,49,0,244,255,1,0,0,0,2,0,250,255,3,0,88,0,52,0,244,255,0,0,1,0,2,0,251,255,1,0,86,0,55,0,244,255,0,0,1,0,2,0,251,255,255,255,84,0,58,0,245,255,0,0,1,0,2,0,252,255,254,255,82,0,61,0,245,255,255,255,1,0,2,0,252,255,252,255,80,0,64,0,246,255,255,255,1,0,1,0,253,255,251,255,77,0,67,0,247,255,255,255,1,0,1,0,253,255,250,255,75,0,70,0,248,255,254,255,1,0,1,0,254,255,249,255,72,0,72,0,249,255,254,255,1,0,1,0,254,255,248,255,70,0,75,0,250,255,253,255,1,0,1,0,255,255,247,255,67,0,77,0,251,255,253,255,1,0,1,0,255,255,246,255,64,0,80,0,252,255,252,255,2,0,1,0,255,255,245,255,61,0,82,0,254,255,252,255,2,0,1,0,0,0,245,255,58,0,84,0,255,255,251,255,2,0,1,0,0,0,244,255,55,0,86,0,1,0,251,255,2,0,1,0,0,0,244,255,52,0,88,0,3,0,250,255,2,0,0,0,1,0,244,255,49,0,90,0,5,0,249,255,2,0,0,0,1,0,244,255,46,0,91,0,7,0,249,255,2,0,1,0,1,0,244,255,43,0,92,0,9,0,248,255,2,0,0,0,1,0,244,255,40,0,93,0,12,0,248,255,2,0,0,0,2,0,244,255,37,0,94,0,14,0,247,255,2,0,0,0,2,0,244,255,34,0,95,0,17,0,246,255,2,0,0,0,2,0,245,255,31,0,95,0,19,0,246,255,2,0,0,0,2,0,245,255,28,0,96,0,22,0,245,255,2,0,255,255,248,255,33,0,80,0,33,0,248,255,255,255,0,0,255,255,248,255,30,0,80,0,35,0,248,255,255,255,1,0,255,255,248,255,28,0,80,0,37,0,249,255,254,255,1,0,0,0,248,255,26,0,79,0,39,0,249,255,254,255,1,0,0,0,248,255,24,0,79,0,41,0,249,255,254,255,1,0,0,0,248,255,22,0,78,0,43,0,250,255,254,255,1,0,0,0,248,255,20,0,78,0,45,0,251,255,253,255,1,0,0,0,248,255,18,0,77,0,48,0,251,255,253,255,1,0,0,0,248,255,16,0,76,0,50,0,252,255,253,255,1,0,0,0,248,255,15,0,75,0,52,0,253,255,252,255,1,0,0,0,249,255,13,0,74,0,54,0,253,255,252,255,1,0,0,0,249,255,11,0,73,0,56,0,254,255,252,255,1,0,0,0,249,255,10,0,71,0,58,0,255,255,252,255,1,0,1,0,249,255,8,0,70,0,60,0,0,0,251,255,1,0,1,0,250,255,6,0,68,0,62,0,1,0,251,255,1,0,1,0,250,255,5,0,67,0,63,0,2,0,251,255,1,0,1,0,250,255,4,0,65,0,65,0,4,0,250,255,1,0,1,0,251,255,2,0,63,0,67,0,5,0,250,255,1,0,1,0,251,255,1,0,62,0,68,0,6,0,250,255,1,0,1,0,251,255,0,0,60,0,70,0,8,0,249,255,1,0,1,0,252,255,255,255,58,0,71,0,10,0,249,255,0,0,1,0,252,255,254,255,56,0,73,0,11,0,249,255,0,0,1,0,252,255,253,255,54,0,74,0,13,0,249,255,0,0,1,0,252,255,253,255,52,0,75,0,15,0,248,255,0,0,1,0,253,255,252,255,50,0,76,0,16,0,248,255,0,0,1,0,253,255,251,255,48,0,77,0,18,0,248,255,0,0,1,0,253,255,251,255,45,0,78,0,20,0,248,255,0,0,1,0,254,255,250,255,43,0,78,0,22,0,248,255,0,0,1,0,254,255,249,255,41,0,79,0,24,0,248,255,0,0,1,0,254,255,249,255,39,0,79,0,26,0,248,255,0,0,1,0,254,255,249,255,37,0,80,0,28,0,248,255,255,255,1,0,255,255,248,255,35,0,80,0,30,0,248,255,255,255,253,255,0,0,35,0,64,0,35,0,0,0,253,255,0,0,253,255,255,255,34,0,64,0,36,0,1,0,253,255,0,0,253,255,255,255,32,0,64,0,38,0,1,0,253,255,0,0,254,255,254,255,31,0,63,0,39,0,2,0,253,255,0,0,254,255,254,255,29,0,63,0,41,0,2,0,253,255,0,0,254,255,254,255,28,0,63,0,42,0,3,0,252,255,0,0,254,255,253,255,27,0,63,0,43,0,4,0,252,255,0,0,254,255,253,255,25,0,62,0,45,0,5,0,252,255,0,0,254,255,253,255,24,0,62,0,46,0,5,0,252,255,0,0,254,255,253,255,23,0,61,0,47,0,6,0,252,255,0,0,254,255,253,255,21,0,60,0,49,0,7,0,252,255,0,0,255,255,252,255,20,0,60,0,50,0,8,0,252,255,255,255,255,255,252,255,19,0,59,0,51,0,9,0,252,255,255,255,255,255,252,255,17,0,58,0,52,0,10,0,252,255,0,0,255,255,252,255,16,0,57,0,53,0,12,0,252,255,255,255,255,255,252,255,15,0,56,0,54,0,13,0,252,255,255,255,255,255,252,255,14,0,55,0,55,0,14,0,252,255,255,255,255,255,252,255,13,0,54,0,56,0,15,0,252,255,255,255,255,255,252,255,12,0,53,0,57,0,16,0,252,255,255,255,0,0,252,255,10,0,52,0,58,0,17,0,252,255,255,255,255,255,252,255,9,0,51,0,59,0,19,0,252,255,255,255,255,255,252,255,8,0,50,0,60,0,20,0,252,255,255,255,0,0,252,255,7,0,49,0,60,0,21,0,253,255,254,255,0,0,252,255,6,0,47,0,61,0,23,0,253,255,254,255,0,0,252,255,5,0,46,0,62,0,24,0,253,255,254,255,0,0,252,255,5,0,45,0,62,0,25,0,253,255,254,255,0,0,252,255,4,0,43,0,63,0,27,0,253,255,254,255,0,0,252,255,3,0,42,0,63,0,28,0,254,255,254,255,0,0,253,255,2,0,41,0,63,0,29,0,254,255,254,255,0,0,253,255,2,0,39,0,63,0,31,0,254,255,254,255,0,0,253,255,1,0,38,0,64,0,32,0,255,255,253,255,0,0,253,255,1,0,36,0,64,0,34,0,255,255,253,255,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,1,0,253,255,128,0,3,0,255,255,0,0,0,0,255,255,2,0,250,255,127,0,7,0,254,255,1,0,0,0,255,255,3,0,247,255,126,0,12,0,252,255,1,0,0,0,255,255,4,0,244,255,125,0,16,0,251,255,1,0,0,0,255,255,4,0,242,255,123,0,20,0,250,255,2,0,0,0,255,255,5,0,241,255,120,0,25,0,248,255,2,0,0,0,255,255,5,0,239,255,118,0,30,0,247,255,3,0,255,255,255,255,6,0,238,255,114,0,35,0,246,255,3,0,255,255,255,255,6,0,237,255,111,0,41,0,244,255,3,0,255,255,255,255,6,0,236,255,107,0,46,0,243,255,4,0,255,255,255,255,6,0,235,255,103,0,52,0,242,255,4,0,255,255,255,255,6,0,235,255,99,0,57,0,240,255,5,0,255,255,255,255,6,0,235,255,94,0,63,0,239,255,5,0,255,255,255,255,6,0,236,255,89,0,68,0,238,255,5,0,255,255,255,255,6,0,236,255,84,0,73,0,237,255,6,0,255,255,255,255,6,0,236,255,79,0,79,0,236,255,6,0,255,255,255,255,6,0,237,255,73,0,84,0,236,255,6,0,255,255,255,255,5,0,238,255,68,0,89,0,236,255,6,0,255,255,255,255,5,0,239,255,63,0,94,0,235,255,6,0,255,255,255,255,5,0,240,255,57,0,99,0,235,255,6,0,255,255,255,255,4,0,242,255,52,0,103,0,235,255,6,0,255,255,255,255,4,0,243,255,46,0,107,0,236,255,6,0,255,255,255,255,3,0,244,255,41,0,111,0,237,255,6,0,255,255,255,255,3,0,246,255,35,0,114,0,238,255,6,0,255,255,255,255,3,0,247,255,30,0,118,0,239,255,5,0,255,255,0,0,2,0,248,255,25,0,120,0,241,255,5,0,255,255,0,0,2,0,250,255,20,0,123,0,242,255,4,0,255,255,0,0,1,0,251,255,16,0,125,0,244,255,4,0,255,255,0,0,1,0,252,255,12,0,126,0,247,255,3,0,255,255,0,0,1,0,254,255,7,0,127,0,250,255,2,0,255,255,0,0,0,0,255,255,3,0,128,0,253,255,1,0,0,0,0,1,255,254,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,40,27,3,0,40,26,3,0,40,25,3,0,176,144,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,232,197,150,0,208,137,40,0,1,0,0,0,5,0,0,0,216,197,150,0,192,137,40,0,2,0,0,0,7,0,0,0,208,197,150,0,176,137,40,0,3,0,0,0,11,0,0,0,200,197,150,0,160,137,40,0,4,0,0,0,19,0,0,0,184,197,150,0,144,137,40,0,5,0,0,0,35,0,0,0,152,197,150,0,120,137,40,0,14,0,0,0,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,35,0,0,0,253,255,56,0,12,0,253,255,255,255,240,1,24,0,80,12,51,0,8,151,142,0,112,1,24,0,208,11,51,0,0,150,142,0,16,10,24,0,112,20,51,0,88,167,142,0,16,2,24,0,112,12,51,0,80,151,142,0,0,0,0,0,0,0,0,0,1,0,1,0,8,0,1,0,8,0,8,0,9,0,2,0,2,0,2,0,16,0,9,0,16,0,16,0,17,0,10,0,10,0,3,0,3,0,3,0,24,0,17,0,24,0,24,0,18,0,11,0,11,0,4,0,25,0,18,0,4,0,4,0,32,0,25,0,19,0,12,0,26,0,19,0,32,0,32,0,12,0,5,0,33,0,26,0,5,0,5,0,40,0,33,0,27,0,20,0,20,0,13,0,34,0,27,0,41,0,34,0,40,0,40,0,13,0,6,0,6,0,6,0,35,0,28,0,28,0,21,0,42,0,35,0,48,0,48,0,48,0,41,0,21,0,14,0,14,0,7,0,36,0,29,0,49,0,42,0,43,0,36,0,56,0,49,0,29,0,22,0,22,0,15,0,50,0,43,0,44,0,37,0,57,0,50,0,37,0,30,0,30,0,23,0,51,0,44,0,58,0,51,0,38,0,31,0,45,0,38,0,52,0,45,0,59,0,52,0,46,0,39,0,53,0,46,0,60,0,53,0,54,0,47,0,61,0,54,0,62,0,55,0,0,0,0,0,0,0,1,0,8,0,2,0,9,0,16,0,10,0,3,0,17,0,24,0,18,0,11,0,4,0,25,0,32,0,19,0,12,0,26,0,5,0,33,0,20,0,27,0,40,0,13,0,34,0,6,0,41,0,28,0,21,0,35,0,42,0,48,0,14,0,7,0,36,0,29,0,43,0,56,0,49,0,22,0,15,0,37,0,50,0,44,0,57,0,30,0,23,0,51,0,45,0,58,0,38,0,31,0,52,0,59,0,39,0,46,0,53,0,60,0,47,0,54,0,61,0,55,0,62,0,63,0,0,0,0,0,0,0,0,0,4,0,1,0,1,0,1,0,4,0,4,0,2,0,2,0,5,0,2,0,8,0,8,0,8,0,5,0,6,0,3,0,9,0,6,0,12,0,9,0,10,0,7,0,13,0,10,0,14,0,11,0,0,0,0,0,0,0,1,0,4,0,5,0,2,0,8,0,3,0,6,0,12,0,9,0,7,0,10,0,13,0,11,0,14,0,15,0,0,0,0,0,0,0,0,0,1,0,1,0,32,0,1,0,32,0,32,0,2,0,2,0,33,0,2,0,64,0,33,0,3,0,3,0,64,0,64,0,34,0,3,0,65,0,34,0,4,0,4,0,35,0,4,0,96,0,65,0,66,0,35,0,96,0,96,0,97,0,66,0,67,0,36,0,36,0,5,0,5,0,5,0,128,0,97,0,98,0,67,0,6,0,6,0,128,0,128,0,68,0,37,0,37,0,6,0,129,0,98,0,99,0,68,0,160,0,129,0,130,0,99,0,38,0,7,0,69,0,38,0,7,0,7,0,100,0,69,0,161,0,130,0,131,0,100,0,160,0,160,0,70,0,39,0,39,0,8,0,8,0,8,0,101,0,70,0,162,0,131,0,132,0,101,0,192,0,161,0,71,0,40,0,192,0,192,0,102,0,71,0,40,0,9,0,163,0,132,0,9,0,9,0,193,0,162,0,133,0,102,0,164,0,133,0,72,0,41,0,103,0,72,0,134,0,103,0,224,0,193,0,41,0,10,0,194,0,163,0,10,0,10,0,224,0,224,0,165,0,134,0,225,0,194,0,195,0,164,0,73,0,42,0,104,0,73,0,135,0,104,0,42,0,11,0,11,0,11,0,166,0,135,0,196,0,165,0,226,0,195,0,0,1,225,0,74,0,43,0,105,0,74,0,136,0,105,0,227,0,196,0,43,0,12,0,197,0,166,0,167,0,136,0,1,1,226,0,0,1,0,1,12,0,12,0,228,0,197,0,75,0,44,0,106,0,75,0,198,0,167,0,137,0,106,0,2,1,227,0,168,0,137,0,32,1,1,1,44,0,13,0,229,0,198,0,3,1,228,0,199,0,168,0,107,0,76,0,13,0,13,0,169,0,138,0,138,0,107,0,32,1,32,1,33,1,2,1,76,0,45,0,230,0,199,0,4,1,229,0,45,0,14,0,200,0,169,0,139,0,108,0,34,1,3,1,108,0,77,0,231,0,200,0,64,1,33,1,5,1,230,0,170,0,139,0,77,0,46,0,35,1,4,1,14,0,14,0,65,1,34,1,201,0,170,0,6,1,231,0,64,1,64,1,171,0,140,0,36,1,5,1,232,0,201,0,140,0,109,0,66,1,35,1,109,0,78,0,46,0,15,0,202,0,171,0,7,1,232,0,233,0,202,0,37,1,6,1,96,1,65,1,67,1,36,1,15,0,15,0,78,0,47,0,203,0,172,0,8,1,233,0,38,1,7,1,68,1,37,1,172,0,141,0,97,1,66,1,141,0,110,0,234,0,203,0,96,1,96,1,47,0,16,0,39,1,8,1,110,0,79,0,9,1,234,0,98,1,67,1,69,1,38,1,79,0,48,0,16,0,16,0,204,0,173,0,235,0,204,0,173,0,142,0,99,1,68,1,128,1,97,1,70,1,39,1,142,0,111,0,40,1,9,1,10,1,235,0,100,1,69,1,129,1,98,1,111,0,80,0,48,0,17,0,71,1,40,1,41,1,10,1,205,0,174,0,128,1,128,1,236,0,205,0,101,1,70,1,130,1,99,1,80,0,49,0,174,0,143,0,17,0,17,0,72,1,41,1,102,1,71,1,131,1,100,1,42,1,11,1,73,1,42,1,132,1,101,1,112,0,81,0,160,1,129,1,237,0,206,0,103,1,72,1,49,0,18,0,206,0,175,0,161,1,130,1,133,1,102,1,74,1,43,1,18,0,18,0,160,1,160,1,104,1,73,1,81,0,50,0,162,1,131,1,134,1,103,1,238,0,207,0,50,0,19,0,105,1,74,1,163,1,132,1,113,0,82,0,192,1,161,1,192,1,192,1,164,1,133,1,82,0,51,0,106,1,75,1,193,1,162,1,165,1,134,1,224,1,224,1,194,1,163,1,166,1,135,1,114,0,83,0,195,1,164,1,224,1,193,1,196,1,165,1,225,1,194,1,197,1,166,1,0,2,0,2,226,1,195,1,198,1,167,1,0,2,225,1,227,1,196,1,1,2,226,1,228,1,197,1,2,2,227,1,229,1,198,1,32,2,1,2,32,2,32,2,230,1,199,1,33,2,2,2,34,2,3,2,64,2,64,2,64,2,33,2,65,2,34,2,66,2,35,2,96,2,65,2,97,2,66,2,98,2,67,2,19,0,19,0,143,0,112,0,11,1,236,0,135,1,104,1,3,2,228,1,96,2,96,2,20,0,20,0,51,0,20,0,144,0,113,0,175,0,144,0,12,1,237,0,43,1,12,1,136,1,105,1,167,1,136,1,4,2,229,1,35,2,4,2,128,2,97,2,128,2,128,2,21,0,21,0,52,0,21,0,83,0,52,0,145,0,114,0,176,0,145,0,207,0,176,0,13,1,238,0,44,1,13,1,75,1,44,1,137,1,106,1,168,1,137,1,199,1,168,1,5,2,230,1,36,2,5,2,67,2,36,2,129,2,98,2,160,2,129,2,160,2,160,2,22,0,22,0,53,0,22,0,84,0,53,0,115,0,84,0,146,0,115,0,177,0,146,0,208,0,177,0,239,0,208,0,14,1,239,0,45,1,14,1,76,1,45,1,107,1,76,1,138,1,107,1,169,1,138,1,200,1,169,1,231,1,200,1,6,2,231,1,37,2,6,2,68,2,37,2,99,2,68,2,130,2,99,2,161,2,130,2,192,2,161,2,192,2,192,2,54,0,23,0,85,0,54,0,116,0,85,0,178,0,147,0,209,0,178,0,240,0,209,0,46,1,15,1,77,1,46,1,108,1,77,1,170,1,139,1,201,1,170,1,232,1,201,1,38,2,7,2,69,2,38,2,100,2,69,2,162,2,131,2,193,2,162,2,224,2,193,2,86,0,55,0,117,0,86,0,210,0,179,0,241,0,210,0,78,1,47,1,109,1,78,1,202,1,171,1,233,1,202,1,70,2,39,2,101,2,70,2,194,2,163,2,225,2,194,2,118,0,87,0,242,0,211,0,110,1,79,1,234,1,203,1,102,2,71,2,226,2,195,2,23,0,23,0,147,0,116,0,15,1,240,0,139,1,108,1,7,2,232,1,131,2,100,2,224,2,224,2,24,0,24,0,55,0,24,0,148,0,117,0,179,0,148,0,16,1,241,0,47,1,16,1,140,1,109,1,171,1,140,1,8,2,233,1,39,2,8,2,132,2,101,2,163,2,132,2,0,3,225,2,0,3,0,3,25,0,25,0,56,0,25,0,87,0,56,0,149,0,118,0,180,0,149,0,211,0,180,0,17,1,242,0,48,1,17,1,79,1,48,1,141,1,110,1,172,1,141,1,203,1,172,1,9,2,234,1,40,2,9,2,71,2,40,2,133,2,102,2,164,2,133,2,195,2,164,2,1,3,226,2,32,3,1,3,32,3,32,3,26,0,26,0,57,0,26,0,88,0,57,0,119,0,88,0,150,0,119,0,181,0,150,0,212,0,181,0,243,0,212,0,18,1,243,0,49,1,18,1,80,1,49,1,111,1,80,1,142,1,111,1,173,1,142,1,204,1,173,1,235,1,204,1,10,2,235,1,41,2,10,2,72,2,41,2,103,2,72,2,134,2,103,2,165,2,134,2,196,2,165,2,227,2,196,2,2,3,227,2,33,3,2,3,64,3,33,3,64,3,64,3,58,0,27,0,89,0,58,0,120,0,89,0,182,0,151,0,213,0,182,0,244,0,213,0,50,1,19,1,81,1,50,1,112,1,81,1,174,1,143,1,205,1,174,1,236,1,205,1,42,2,11,2,73,2,42,2,104,2,73,2,166,2,135,2,197,2,166,2,228,2,197,2,34,3,3,3,65,3,34,3,96,3,65,3,90,0,59,0,121,0,90,0,214,0,183,0,245,0,214,0,82,1,51,1,113,1,82,1,206,1,175,1,237,1,206,1,74,2,43,2,105,2,74,2,198,2,167,2,229,2,198,2,66,3,35,3,97,3,66,3,122,0,91,0,246,0,215,0,114,1,83,1,238,1,207,1,106,2,75,2,230,2,199,2,98,3,67,3,27,0,27,0,151,0,120,0,19,1,244,0,143,1,112,1,11,2,236,1,135,2,104,2,3,3,228,2,96,3,96,3,28,0,28,0,59,0,28,0,152,0,121,0,183,0,152,0,20,1,245,0,51,1,20,1,144,1,113,1,175,1,144,1,12,2,237,1,43,2,12,2,136,2,105,2,167,2,136,2,4,3,229,2,35,3,4,3,128,3,97,3,128,3,128,3,29,0,29,0,60,0,29,0,91,0,60,0,153,0,122,0,184,0,153,0,215,0,184,0,21,1,246,0,52,1,21,1,83,1,52,1,145,1,114,1,176,1,145,1,207,1,176,1,13,2,238,1,44,2,13,2,75,2,44,2,137,2,106,2,168,2,137,2,199,2,168,2,5,3,230,2,36,3,5,3,67,3,36,3,129,3,98,3,160,3,129,3,160,3,160,3,30,0,30,0,61,0,30,0,92,0,61,0,123,0,92,0,154,0,123,0,185,0,154,0,216,0,185,0,247,0,216,0,22,1,247,0,53,1,22,1,84,1,53,1,115,1,84,1,146,1,115,1,177,1,146,1,208,1,177,1,239,1,208,1,14,2,239,1,45,2,14,2,76,2,45,2,107,2,76,2,138,2,107,2,169,2,138,2,200,2,169,2,231,2,200,2,6,3,231,2,37,3,6,3,68,3,37,3,99,3,68,3,130,3,99,3,161,3,130,3,192,3,161,3,192,3,192,3,62,0,31,0,93,0,62,0,124,0,93,0,186,0,155,0,217,0,186,0,248,0,217,0,54,1,23,1,85,1,54,1,116,1,85,1,178,1,147,1,209,1,178,1,240,1,209,1,46,2,15,2,77,2,46,2,108,2,77,2,170,2,139,2,201,2,170,2,232,2,201,2,38,3,7,3,69,3,38,3,100,3,69,3,162,3,131,3,193,3,162,3,224,3,193,3,94,0,63,0,125,0,94,0,218,0,187,0,249,0,218,0,86,1,55,1,117,1,86,1,210,1,179,1,241,1,210,1,78,2,47,2,109,2,78,2,202,2,171,2,233,2,202,2,70,3,39,3,101,3,70,3,194,3,163,3,225,3,194,3,126,0,95,0,250,0,219,0,118,1,87,1,242,1,211,1,110,2,79,2,234,2,203,2,102,3,71,3,226,3,195,3,155,0,124,0,23,1,248,0,147,1,116,1,15,2,240,1,139,2,108,2,7,3,232,2,131,3,100,3,156,0,125,0,187,0,156,0,24,1,249,0,55,1,24,1,148,1,117,1,179,1,148,1,16,2,241,1,47,2,16,2,140,2,109,2,171,2,140,2,8,3,233,2,39,3,8,3,132,3,101,3,163,3,132,3,157,0,126,0,188,0,157,0,219,0,188,0,25,1,250,0,56,1,25,1,87,1,56,1,149,1,118,1,180,1,149,1,211,1,180,1,17,2,242,1,48,2,17,2,79,2,48,2,141,2,110,2,172,2,141,2,203,2,172,2,9,3,234,2,40,3,9,3,71,3,40,3,133,3,102,3,164,3,133,3,195,3,164,3,158,0,127,0,189,0,158,0,220,0,189,0,251,0,220,0,26,1,251,0,57,1,26,1,88,1,57,1,119,1,88,1,150,1,119,1,181,1,150,1,212,1,181,1,243,1,212,1,18,2,243,1,49,2,18,2,80,2,49,2,111,2,80,2,142,2,111,2,173,2,142,2,204,2,173,2,235,2,204,2,10,3,235,2,41,3,10,3,72,3,41,3,103,3,72,3,134,3,103,3,165,3,134,3,196,3,165,3,227,3,196,3,190,0,159,0,221,0,190,0,252,0,221,0,58,1,27,1,89,1,58,1,120,1,89,1,182,1,151,1,213,1,182,1,244,1,213,1,50,2,19,2,81,2,50,2,112,2,81,2,174,2,143,2,205,2,174,2,236,2,205,2,42,3,11,3,73,3,42,3,104,3,73,3,166,3,135,3,197,3,166,3,228,3,197,3,222,0,191,0,253,0,222,0,90,1,59,1,121,1,90,1,214,1,183,1,245,1,214,1,82,2,51,2,113,2,82,2,206,2,175,2,237,2,206,2,74,3,43,3,105,3,74,3,198,3,167,3,229,3,198,3,254,0,223,0,122,1,91,1,246,1,215,1,114,2,83,2,238,2,207,2,106,3,75,3,230,3,199,3,27,1,252,0,151,1,120,1,19,2,244,1,143,2,112,2,11,3,236,2,135,3,104,3,28,1,253,0,59,1,28,1,152,1,121,1,183,1,152,1,20,2,245,1,51,2,20,2,144,2,113,2,175,2,144,2,12,3,237,2,43,3,12,3,136,3,105,3,167,3,136,3,29,1,254,0,60,1,29,1,91,1,60,1,153,1,122,1,184,1,153,1,215,1,184,1,21,2,246,1,52,2,21,2,83,2,52,2,145,2,114,2,176,2,145,2,207,2,176,2,13,3,238,2,44,3,13,3,75,3,44,3,137,3,106,3,168,3,137,3,199,3,168,3,30,1,255,0,61,1,30,1,92,1,61,1,123,1,92,1,154,1,123,1,185,1,154,1,216,1,185,1,247,1,216,1,22,2,247,1,53,2,22,2,84,2,53,2,115,2,84,2,146,2,115,2,177,2,146,2,208,2,177,2,239,2,208,2,14,3,239,2,45,3,14,3,76,3,45,3,107,3,76,3,138,3,107,3,169,3,138,3,200,3,169,3,231,3,200,3,62,1,31,1,93,1,62,1,124,1,93,1,186,1,155,1,217,1,186,1,248,1,217,1,54,2,23,2,85,2,54,2,116,2,85,2,178,2,147,2,209,2,178,2,240,2,209,2,46,3,15,3,77,3,46,3,108,3,77,3,170,3,139,3,201,3,170,3,232,3,201,3,94,1,63,1,125,1,94,1,218,1,187,1,249,1,218,1,86,2,55,2,117,2,86,2,210,2,179,2,241,2,210,2,78,3,47,3,109,3,78,3,202,3,171,3,233,3,202,3,126,1,95,1,250,1,219,1,118,2,87,2,242,2,211,2,110,3,79,3,234,3,203,3,155,1,124,1,23,2,248,1,147,2,116,2,15,3,240,2,139,3,108,3,156,1,125,1,187,1,156,1,24,2,249,1,55,2,24,2,148,2,117,2,179,2,148,2,16,3,241,2,47,3,16,3,140,3,109,3,171,3,140,3,157,1,126,1,188,1,157,1,219,1,188,1,25,2,250,1,56,2,25,2,87,2,56,2,149,2,118,2,180,2,149,2,211,2,180,2,17,3,242,2,48,3,17,3,79,3,48,3,141,3,110,3,172,3,141,3,203,3,172,3,158,1,127,1,189,1,158,1,220,1,189,1,251,1,220,1,26,2,251,1,57,2,26,2,88,2,57,2,119,2,88,2,150,2,119,2,181,2,150,2,212,2,181,2,243,2,212,2,18,3,243,2,49,3,18,3,80,3,49,3,111,3,80,3,142,3,111,3,173,3,142,3,204,3,173,3,235,3,204,3,190,1,159,1,221,1,190,1,252,1,221,1,58,2,27,2,89,2,58,2,120,2,89,2,182,2,151,2,213,2,182,2,244,2,213,2,50,3,19,3,81,3,50,3,112,3,81,3,174,3,143,3,205,3,174,3,236,3,205,3,222,1,191,1,253,1,222,1,90,2,59,2,121,2,90,2,214,2,183,2,245,2,214,2,82,3,51,3,113,3,82,3,206,3,175,3,237,3,206,3,254,1,223,1,122,2,91,2,246,2,215,2,114,3,83,3,238,3,207,3,27,2,252,1,151,2,120,2,19,3,244,2,143,3,112,3,28,2,253,1,59,2,28,2,152,2,121,2,183,2,152,2,20,3,245,2,51,3,20,3,144,3,113,3,175,3,144,3,29,2,254,1,60,2,29,2,91,2,60,2,153,2,122,2,184,2,153,2,215,2,184,2,21,3,246,2,52,3,21,3,83,3,52,3,145,3,114,3,176,3,145,3,207,3,176,3,30,2,255,1,61,2,30,2,92,2,61,2,123,2,92,2,154,2,123,2,185,2,154,2,216,2,185,2,247,2,216,2,22,3,247,2,53,3,22,3,84,3,53,3,115,3,84,3,146,3,115,3,177,3,146,3,208,3,177,3,239,3,208,3,62,2,31,2,93,2,62,2,124,2,93,2,186,2,155,2,217,2,186,2,248,2,217,2,54,3,23,3,85,3,54,3,116,3,85,3,178,3,147,3,209,3,178,3,240,3,209,3,94,2,63,2,125,2,94,2,218,2,187,2,249,2,218,2,86,3,55,3,117,3,86,3,210,3,179,3,241,3,210,3,126,2,95,2,250,2,219,2,118,3,87,3,242,3,211,3,155,2,124,2,23,3,248,2,147,3,116,3,156,2,125,2,187,2,156,2,24,3,249,2,55,3,24,3,148,3,117,3,179,3,148,3,157,2,126,2,188,2,157,2,219,2,188,2,25,3,250,2,56,3,25,3,87,3,56,3,149,3,118,3,180,3,149,3,211,3,180,3,158,2,127,2,189,2,158,2,220,2,189,2,251,2,220,2,26,3,251,2,57,3,26,3,88,3,57,3,119,3,88,3,150,3,119,3,181,3,150,3,212,3,181,3,243,3,212,3,190,2,159,2,221,2,190,2,252,2,221,2,58,3,27,3,89,3,58,3,120,3,89,3,182,3,151,3,213,3,182,3,244,3,213,3,222,2,191,2,253,2,222,2,90,3,59,3,121,3,90,3,214,3,183,3,245,3,214,3,254,2,223,2,122,3,91,3,246,3,215,3,27,3,252,2,151,3,120,3,28,3,253,2,59,3,28,3,152,3,121,3,183,3,152,3,29,3,254,2,60,3,29,3,91,3,60,3,153,3,122,3,184,3,153,3,215,3,184,3,30,3,255,2,61,3,30,3,92,3,61,3,123,3,92,3,154,3,123,3,185,3,154,3,216,3,185,3,247,3,216,3,62,3,31,3,93,3,62,3,124,3,93,3,186,3,155,3,217,3,186,3,248,3,217,3,94,3,63,3,125,3,94,3,218,3,187,3,249,3,218,3,126,3,95,3,250,3,219,3,155,3,124,3,156,3,125,3,187,3,156,3,157,3,126,3,188,3,157,3,219,3,188,3,158,3,127,3,189,3,158,3,220,3,189,3,251,3,220,3,190,3,159,3,221,3,190,3,252,3,221,3,222,3,191,3,253,3,222,3,254,3,223,3,0,0,0,0,0,0,1,0,32,0,2,0,33,0,64,0,3,0,34,0,65,0,4,0,96,0,35,0,66,0,5,0,36,0,97,0,67,0,128,0,98,0,68,0,37,0,6,0,129,0,99,0,7,0,160,0,69,0,38,0,130,0,100,0,161,0,131,0,39,0,70,0,8,0,101,0,162,0,132,0,192,0,71,0,40,0,9,0,102,0,163,0,133,0,193,0,72,0,224,0,103,0,41,0,164,0,10,0,194,0,134,0,165,0,73,0,104,0,135,0,225,0,42,0,195,0,11,0,0,1,166,0,226,0,196,0,74,0,105,0,136,0,43,0,12,0,167,0,197,0,227,0,1,1,75,0,106,0,137,0,228,0,44,0,198,0,168,0,2,1,32,1,13,0,229,0,76,0,107,0,199,0,138,0,3,1,169,0,33,1,45,0,230,0,4,1,200,0,108,0,14,0,170,0,139,0,64,1,34,1,77,0,231,0,5,1,46,0,201,0,140,0,35,1,109,0,232,0,65,1,6,1,171,0,78,0,36,1,15,0,66,1,202,0,7,1,96,1,172,0,37,1,233,0,141,0,67,1,110,0,47,0,203,0,8,1,234,0,38,1,97,1,68,1,16,0,79,0,204,0,9,1,39,1,69,1,173,0,98,1,142,0,235,0,128,1,48,0,40,1,111,0,10,1,99,1,70,1,80,0,17,0,205,0,236,0,174,0,100,1,129,1,71,1,143,0,41,1,11,1,101,1,130,1,112,0,49,0,72,1,42,1,206,0,160,1,237,0,102,1,131,1,81,0,175,0,18,0,73,1,103,1,132,1,43,1,74,1,133,1,113,0,161,1,238,0,104,1,50,0,207,0,162,1,134,1,75,1,19,0,192,1,105,1,82,0,163,1,135,1,239,0,51,0,106,1,164,1,114,0,193,1,224,1,165,1,83,0,107,1,194,1,166,1,0,2,195,1,167,1,115,0,196,1,225,1,197,1,226,1,198,1,32,2,227,1,199,1,1,2,228,1,2,2,229,1,3,2,230,1,33,2,64,2,231,1,34,2,35,2,96,2,65,2,66,2,67,2,97,2,98,2,99,2,20,0,144,0,12,1,136,1,4,2,128,2,21,0,52,0,145,0,176,0,13,1,44,1,137,1,168,1,5,2,36,2,129,2,160,2,22,0,53,0,84,0,146,0,177,0,208,0,14,1,45,1,76,1,138,1,169,1,200,1,6,2,37,2,68,2,130,2,161,2,192,2,23,0,54,0,85,0,116,0,147,0,178,0,209,0,240,0,15,1,46,1,77,1,108,1,139,1,170,1,201,1,232,1,7,2,38,2,69,2,100,2,131,2,162,2,193,2,224,2,55,0,86,0,117,0,179,0,210,0,241,0,47,1,78,1,109,1,171,1,202,1,233,1,39,2,70,2,101,2,163,2,194,2,225,2,87,0,118,0,211,0,242,0,79,1,110,1,203,1,234,1,71,2,102,2,195,2,226,2,119,0,243,0,111,1,235,1,103,2,227,2,24,0,148,0,16,1,140,1,8,2,132,2,0,3,25,0,56,0,149,0,180,0,17,1,48,1,141,1,172,1,9,2,40,2,133,2,164,2,1,3,32,3,26,0,57,0,88,0,150,0,181,0,212,0,18,1,49,1,80,1,142,1,173,1,204,1,10,2,41,2,72,2,134,2,165,2,196,2,2,3,33,3,64,3,27,0,58,0,89,0,120,0,151,0,182,0,213,0,244,0,19,1,50,1,81,1,112,1,143,1,174,1,205,1,236,1,11,2,42,2,73,2,104,2,135,2,166,2,197,2,228,2,3,3,34,3,65,3,96,3,59,0,90,0,121,0,183,0,214,0,245,0,51,1,82,1,113,1,175,1,206,1,237,1,43,2,74,2,105,2,167,2,198,2,229,2,35,3,66,3,97,3,91,0,122,0,215,0,246,0,83,1,114,1,207,1,238,1,75,2,106,2,199,2,230,2,67,3,98,3,123,0,247,0,115,1,239,1,107,2,231,2,99,3,28,0,152,0,20,1,144,1,12,2,136,2,4,3,128,3,29,0,60,0,153,0,184,0,21,1,52,1,145,1,176,1,13,2,44,2,137,2,168,2,5,3,36,3,129,3,160,3,30,0,61,0,92,0,154,0,185,0,216,0,22,1,53,1,84,1,146,1,177,1,208,1,14,2,45,2,76,2,138,2,169,2,200,2,6,3,37,3,68,3,130,3,161,3,192,3,31,0,62,0,93,0,124,0,155,0,186,0,217,0,248,0,23,1,54,1,85,1,116,1,147,1,178,1,209,1,240,1,15,2,46,2,77,2,108,2,139,2,170,2,201,2,232,2,7,3,38,3,69,3,100,3,131,3,162,3,193,3,224,3,63,0,94,0,125,0,187,0,218,0,249,0,55,1,86,1,117,1,179,1,210,1,241,1,47,2,78,2,109,2,171,2,202,2,233,2,39,3,70,3,101,3,163,3,194,3,225,3,95,0,126,0,219,0,250,0,87,1,118,1,211,1,242,1,79,2,110,2,203,2,234,2,71,3,102,3,195,3,226,3,127,0,251,0,119,1,243,1,111,2,235,2,103,3,227,3,156,0,24,1,148,1,16,2,140,2,8,3,132,3,157,0,188,0,25,1,56,1,149,1,180,1,17,2,48,2,141,2,172,2,9,3,40,3,133,3,164,3,158,0,189,0,220,0,26,1,57,1,88,1,150,1,181,1,212,1,18,2,49,2,80,2,142,2,173,2,204,2,10,3,41,3,72,3,134,3,165,3,196,3,159,0,190,0,221,0,252,0,27,1,58,1,89,1,120,1,151,1,182,1,213,1,244,1,19,2,50,2,81,2,112,2,143,2,174,2,205,2,236,2,11,3,42,3,73,3,104,3,135,3,166,3,197,3,228,3,191,0,222,0,253,0,59,1,90,1,121,1,183,1,214,1,245,1,51,2,82,2,113,2,175,2,206,2,237,2,43,3,74,3,105,3,167,3,198,3,229,3,223,0,254,0,91,1,122,1,215,1,246,1,83,2,114,2,207,2,238,2,75,3,106,3,199,3,230,3,255,0,123,1,247,1,115,2,239,2,107,3,231,3,28,1,152,1,20,2,144,2,12,3,136,3,29,1,60,1,153,1,184,1,21,2,52,2,145,2,176,2,13,3,44,3,137,3,168,3,30,1,61,1,92,1,154,1,185,1,216,1,22,2,53,2,84,2,146,2,177,2,208,2,14,3,45,3,76,3,138,3,169,3,200,3,31,1,62,1,93,1,124,1,155,1,186,1,217,1,248,1,23,2,54,2,85,2,116,2,147,2,178,2,209,2,240,2,15,3,46,3,77,3,108,3,139,3,170,3,201,3,232,3,63,1,94,1,125,1,187,1,218,1,249,1,55,2,86,2,117,2,179,2,210,2,241,2,47,3,78,3,109,3,171,3,202,3,233,3,95,1,126,1,219,1,250,1,87,2,118,2,211,2,242,2,79,3,110,3,203,3,234,3,127,1,251,1,119,2,243,2,111,3,235,3,156,1,24,2,148,2,16,3,140,3,157,1,188,1,25,2,56,2,149,2,180,2,17,3,48,3,141,3,172,3,158,1,189,1,220,1,26,2,57,2,88,2,150,2,181,2,212,2,18,3,49,3,80,3,142,3,173,3,204,3,159,1,190,1,221,1,252,1,27,2,58,2,89,2,120,2,151,2,182,2,213,2,244,2,19,3,50,3,81,3,112,3,143,3,174,3,205,3,236,3,191,1,222,1,253,1,59,2,90,2,121,2,183,2,214,2,245,2,51,3,82,3,113,3,175,3,206,3,237,3,223,1,254,1,91,2,122,2,215,2,246,2,83,3,114,3,207,3,238,3,255,1,123,2,247,2,115,3,239,3,28,2,152,2,20,3,144,3,29,2,60,2,153,2,184,2,21,3,52,3,145,3,176,3,30,2,61,2,92,2,154,2,185,2,216,2,22,3,53,3,84,3,146,3,177,3,208,3,31,2,62,2,93,2,124,2,155,2,186,2,217,2,248,2,23,3,54,3,85,3,116,3,147,3,178,3,209,3,240,3,63,2,94,2,125,2,187,2,218,2,249,2,55,3,86,3,117,3,179,3,210,3,241,3,95,2,126,2,219,2,250,2,87,3,118,3,211,3,242,3,127,2,251,2,119,3,243,3,156,2,24,3,148,3,157,2,188,2,25,3,56,3,149,3,180,3,158,2,189,2,220,2,26,3,57,3,88,3,150,3,181,3,212,3,159,2,190,2,221,2,252,2,27,3,58,3,89,3,120,3,151,3,182,3,213,3,244,3,191,2,222,2,253,2,59,3,90,3,121,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+215040);
/* memory initializer */ allocate([183,3,214,3,245,3,223,2,254,2,91,3,122,3,215,3,246,3,255,2,123,3,247,3,28,3,152,3,29,3,60,3,153,3,184,3,30,3,61,3,92,3,154,3,185,3,216,3,31,3,62,3,93,3,124,3,155,3,186,3,217,3,248,3,63,3,94,3,125,3,187,3,218,3,249,3,95,3,126,3,219,3,250,3,127,3,251,3,156,3,157,3,188,3,158,3,189,3,220,3,159,3,190,3,221,3,252,3,191,3,222,3,253,3,223,3,254,3,255,3,0,0,0,0,0,0,0,0,1,0,1,0,16,0,1,0,16,0,16,0,2,0,2,0,17,0,2,0,32,0,17,0,32,0,32,0,3,0,3,0,33,0,18,0,18,0,3,0,48,0,33,0,19,0,4,0,4,0,4,0,34,0,19,0,48,0,48,0,49,0,34,0,35,0,20,0,64,0,49,0,20,0,5,0,5,0,5,0,50,0,35,0,64,0,64,0,65,0,50,0,36,0,21,0,21,0,6,0,51,0,36,0,6,0,6,0,80,0,65,0,66,0,51,0,37,0,22,0,81,0,66,0,52,0,37,0,22,0,7,0,80,0,80,0,67,0,52,0,7,0,7,0,82,0,67,0,96,0,81,0,53,0,38,0,38,0,23,0,68,0,53,0,96,0,96,0,23,0,8,0,97,0,82,0,83,0,68,0,69,0,54,0,54,0,39,0,8,0,8,0,39,0,24,0,84,0,69,0,98,0,83,0,112,0,97,0,112,0,112,0,24,0,9,0,113,0,98,0,99,0,84,0,70,0,55,0,85,0,70,0,55,0,40,0,9,0,9,0,40,0,25,0,114,0,99,0,100,0,85,0,128,0,113,0,115,0,100,0,71,0,56,0,86,0,71,0,25,0,10,0,129,0,114,0,128,0,128,0,101,0,86,0,56,0,41,0,10,0,10,0,41,0,26,0,116,0,101,0,130,0,115,0,144,0,129,0,87,0,72,0,102,0,87,0,26,0,11,0,72,0,57,0,131,0,116,0,117,0,102,0,145,0,130,0,57,0,42,0,144,0,144,0,11,0,11,0,42,0,27,0,132,0,117,0,146,0,131,0,103,0,88,0,88,0,73,0,118,0,103,0,160,0,145,0,73,0,58,0,147,0,132,0,133,0,118,0,27,0,12,0,161,0,146,0,58,0,43,0,12,0,12,0,160,0,160,0,119,0,104,0,148,0,133,0,89,0,74,0,134,0,119,0,104,0,89,0,162,0,147,0,43,0,28,0,74,0,59,0,176,0,161,0,163,0,148,0,28,0,13,0,149,0,134,0,120,0,105,0,135,0,120,0,177,0,162,0,164,0,149,0,13,0,13,0,105,0,90,0,59,0,44,0,90,0,75,0,150,0,135,0,44,0,29,0,178,0,163,0,176,0,176,0,136,0,121,0,165,0,150,0,121,0,106,0,75,0,60,0,179,0,164,0,151,0,136,0,29,0,14,0,60,0,45,0,14,0,14,0,106,0,91,0,166,0,151,0,180,0,165,0,192,0,177,0,91,0,76,0,192,0,192,0,45,0,30,0,137,0,122,0,122,0,107,0,152,0,137,0,193,0,178,0,76,0,61,0,167,0,152,0,181,0,166,0,30,0,15,0,194,0,179,0,208,0,193,0,182,0,167,0,107,0,92,0,138,0,123,0,61,0,46,0,153,0,138,0,46,0,31,0,195,0,180,0,92,0,77,0,168,0,153,0,209,0,194,0,196,0,181,0,208,0,208,0,123,0,108,0,183,0,168,0,210,0,195,0,77,0,62,0,108,0,93,0,169,0,154,0,154,0,139,0,62,0,47,0,197,0,182,0,211,0,196,0,184,0,169,0,224,0,209,0,224,0,224,0,139,0,124,0,93,0,78,0,198,0,183,0,124,0,109,0,78,0,63,0,212,0,197,0,225,0,210,0,170,0,155,0,185,0,170,0,155,0,140,0,213,0,198,0,199,0,184,0,109,0,94,0,226,0,211,0,140,0,125,0,94,0,79,0,240,0,225,0,214,0,199,0,227,0,212,0,200,0,185,0,125,0,110,0,241,0,226,0,186,0,171,0,171,0,156,0,156,0,141,0,228,0,213,0,110,0,95,0,215,0,200,0,242,0,227,0,141,0,126,0,201,0,186,0,229,0,214,0,126,0,111,0,216,0,201,0,243,0,228,0,172,0,157,0,187,0,172,0,230,0,215,0,157,0,142,0,202,0,187,0,142,0,127,0,244,0,229,0,217,0,202,0,231,0,216,0,188,0,173,0,245,0,230,0,158,0,143,0,173,0,158,0,232,0,217,0,246,0,231,0,218,0,203,0,203,0,188,0,174,0,159,0,189,0,174,0,247,0,232,0,233,0,218,0,204,0,189,0,219,0,204,0,248,0,233,0,190,0,175,0,234,0,219,0,220,0,205,0,249,0,234,0,205,0,190,0,221,0,206,0,250,0,235,0,235,0,220,0,206,0,191,0,236,0,221,0,222,0,207,0,251,0,236,0,237,0,222,0,252,0,237,0,238,0,223,0,253,0,238,0,254,0,239,0,0,0,0,0,0,0,1,0,16,0,2,0,17,0,32,0,3,0,18,0,33,0,48,0,4,0,34,0,19,0,49,0,20,0,5,0,35,0,64,0,50,0,36,0,65,0,21,0,6,0,51,0,80,0,66,0,37,0,22,0,52,0,7,0,81,0,67,0,38,0,82,0,53,0,23,0,96,0,68,0,8,0,83,0,97,0,54,0,39,0,69,0,112,0,24,0,98,0,84,0,70,0,55,0,9,0,40,0,85,0,99,0,113,0,128,0,25,0,114,0,100,0,71,0,86,0,56,0,10,0,41,0,115,0,101,0,129,0,116,0,72,0,87,0,26,0,130,0,144,0,102,0,57,0,11,0,42,0,117,0,131,0,145,0,88,0,103,0,27,0,73,0,132,0,118,0,146,0,58,0,160,0,12,0,43,0,133,0,147,0,104,0,89,0,119,0,161,0,74,0,148,0,134,0,28,0,162,0,59,0,13,0,176,0,120,0,149,0,90,0,135,0,105,0,163,0,44,0,75,0,177,0,164,0,29,0,150,0,121,0,136,0,178,0,165,0,14,0,106,0,60,0,91,0,151,0,45,0,179,0,192,0,137,0,166,0,122,0,76,0,180,0,152,0,30,0,61,0,15,0,107,0,167,0,181,0,193,0,92,0,208,0,46,0,138,0,123,0,153,0,194,0,77,0,168,0,182,0,31,0,195,0,209,0,183,0,108,0,139,0,62,0,154,0,47,0,196,0,93,0,169,0,210,0,197,0,224,0,124,0,184,0,211,0,78,0,109,0,170,0,155,0,63,0,198,0,212,0,185,0,225,0,240,0,140,0,94,0,199,0,125,0,79,0,213,0,226,0,171,0,186,0,156,0,214,0,200,0,110,0,227,0,141,0,95,0,241,0,215,0,228,0,201,0,126,0,242,0,187,0,172,0,157,0,229,0,111,0,216,0,243,0,142,0,202,0,230,0,127,0,217,0,244,0,173,0,188,0,231,0,158,0,203,0,143,0,245,0,218,0,232,0,189,0,246,0,159,0,174,0,233,0,247,0,219,0,204,0,175,0,190,0,248,0,234,0,205,0,220,0,249,0,191,0,235,0,221,0,250,0,206,0,222,0,251,0,236,0,207,0,237,0,223,0,252,0,238,0,253,0,239,0,254,0,255,0,65,32,18,144,162,194,41,51,98,132,68,18,165,217,196,45,40,78,173,80,19,176,240,193,64,35,46,221,135,38,194,248,121,96,85,29,48,12,154,155,139,90,34,117,119,67,6,25,204,243,158,13,21,96,120,7,76,176,208,126,28,54,103,97,5,44,131,176,139,48,68,97,83,5,42,156,111,152,26,49,152,80,5,58,178,74,83,33,62,145,86,5,32,154,192,168,14,22,163,77,7,64,116,132,122,37,126,120,85,5,32,156,216,148,19,29,73,101,21,107,181,192,103,19,67,125,235,162,36,255,34,3,149,144,2,173,34,7,145,85,7,166,63,7,94,66,8,64,46,17,81,31,25,29,30,9,102,187,225,239,183,119,96,41,33,16,77,74,142,142,172,170,238,247,50,126,123,221,226,3,136,37,5,52,13,20,152,15,101,100,66,192,128,64,32,64,96,128,224,144,192,168,192,176,192,198,198,245,216,136,140,148,160,176,192,224,234,234,240,128,128,64,96,112,64,64,96,64,160,128,128,216,128,176,160,176,176,192,198,198,208,208,136,140,148,160,176,192,224,234,234,240,128,128,64,96,112,64,64,96,64,160,128,222,34,30,72,16,44,58,32,12,10,7,6,177,58,59,68,26,63,52,79,25,17,14,12,174,73,87,92,41,83,82,99,50,53,39,39,199,122,141,147,63,159,148,133,118,121,104,114,0,43,46,168,134,107,128,69,142,92,44,29,68,159,201,177,50,57,77,63,36,126,146,123,158,60,90,96,58,38,76,114,97,172,78,133,92,46,41,76,140,63,184,69,112,57,38,32,85,140,46,112,54,151,133,39,27,61,131,110,175,44,75,136,47,35,80,100,74,143,64,163,74,52,30,74,113,130,175,51,64,58,36,61,116,114,128,162,80,125,82,55,44,68,166,179,192,57,57,108,42,26,11,199,241,228,23,15,85,82,26,26,171,208,204,44,32,105,68,42,19,131,160,199,55,52,83,58,50,25,139,115,232,39,52,118,50,35,33,153,104,162,64,59,131,44,24,16,150,177,202,33,19,156,53,49,21,110,116,168,59,80,76,55,27,12,153,203,218,26,27,49,38,72,19,168,203,212,50,50,107,92,45,102,136,116,180,74,90,100,73,32,19,187,222,215,46,34,100,137,30,42,148,151,207,70,52,91,91,30,32,116,121,186,93,86,94,72,35,36,149,68,206,68,63,105,73,31,28,138,57,124,55,122,151,67,23,21,140,126,197,40,37,171,74,32,27,107,86,160,63,134,102,86,27,28,128,154,212,45,43,53,59,67,44,140,161,202,78,67,119,59,38,83,112,103,162,98,136,90,62,30,23,158,200,207,59,57,50,103,26,36,129,132,201,83,80,93,67,30,29,84,86,191,102,91,59,60,32,33,112,71,220,64,89,104,53,26,34,130,56,149,84,120,103,53,21,23,133,109,210,56,77,172,61,29,29,93,97,165,83,175,162,77,19,29,112,142,228,55,66,36,47,47,43,114,137,181,100,99,95,53,40,55,139,69,183,61,80,110,40,29,19,161,180,207,43,24,91,69,23,29,128,83,199,46,44,101,60,34,19,105,61,198,53,64,89,52,31,22,158,40,209,58,62,89,44,31,29,147,46,158,56,102,198,35,19,12,135,87,209,41,45,167,51,38,25,113,58,164,70,93,97,55,25,21,118,95,215,38,39,66,47,54,34,146,108,203,72,103,151,46,27,80,150,55,124,55,121,135,36,23,27,165,149,166,54,64,118,64,19,37,156,66,138,49,95,133,53,21,36,131,63,163,60,109,81,40,26,35,154,40,185,51,97,123,35,19,34,179,19,97,48,129,124,36,20,26,136,62,164,33,77,154,45,26,28,129,45,129,49,147,123,45,18,32,130,90,157,40,79,91,38,44,51,136,74,162,57,97,121,56,39,58,133,117,173,48,53,187,35,21,12,161,212,207,20,23,145,75,17,22,136,138,185,32,34,166,56,29,19,117,109,181,55,68,112,47,29,17,153,64,220,59,51,114,46,16,24,136,76,147,41,64,172,34,17,11,108,152,187,13,15,209,55,30,18,122,79,179,44,88,116,51,24,14,115,133,209,32,26,104,37,49,25,129,168,164,41,54,148,48,34,86,101,92,146,78,179,134,47,22,24,138,187,178,68,69,59,78,23,39,111,117,170,74,124,94,56,25,33,105,112,187,95,177,129,48,31,27,114,63,183,82,116,56,43,28,37,121,63,123,61,192,169,42,17,24,109,97,177,56,76,122,46,23,32,74,86,150,67,183,88,58,18,28,105,139,182,70,92,63,36,38,48,92,122,165,88,137,91,62,44,61,123,105,189,48,57,64,47,25,17,175,222,220,24,30,86,82,22,32,127,143,213,39,41,70,68,36,17,106,102,206,59,74,74,57,39,23,151,68,216,55,63,58,49,30,35,141,70,168,82,40,115,51,25,15,136,129,202,38,35,139,59,39,19,114,75,180,77,104,42,68,26,16,111,141,215,29,28,28,40,61,26,126,152,206,61,59,93,44,78,115,132,119,173,71,112,93,39,38,21,184,227,206,42,32,64,65,70,60,155,159,199,61,60,81,58,47,36,124,137,193,80,82,78,49,50,35,144,95,205,63,78,59,41,53,52,148,71,142,65,128,51,40,36,28,143,143,202,40,55,137,42,44,44,104,105,164,64,130,80,52,34,29,129,183,227,42,35,43,43,81,53,140,169,204,68,84,72,0,0,0,0,118,15,123,148,131,101,44,93,131,113,12,23,188,226,142,26,32,125,144,11,54,157,195,130,46,58,108,120,11,50,123,163,135,64,77,103,113,9,36,155,111,157,32,44,161,116,9,55,176,76,96,37,61,149,115,9,28,141,161,167,21,25,193,116,12,64,120,140,125,49,115,121,120,12,32,145,195,142,32,38,86,102,19,66,162,182,122,35,59,128,0,0,0,0,0,0,174,35,49,68,11,27,57,15,9,12,3,3,150,40,39,78,12,26,67,33,11,24,7,5,149,53,53,94,20,48,83,53,24,52,18,18,158,97,94,93,24,99,85,119,44,62,59,67,195,29,183,84,49,136,8,42,71,0,0,0,0,0,0,0,0,0,31,107,169,35,99,159,17,82,140,8,66,114,2,44,76,1,19,32,40,132,201,29,114,187,13,91,157,7,75,127,3,58,95,1,28,47,69,142,221,42,122,201,15,91,159,6,67,121,1,42,77,1,17,31,102,148,228,67,117,204,17,82,154,6,59,114,2,39,75,1,15,29,156,57,233,119,57,212,58,48,163,29,40,124,12,30,81,3,12,31,191,107,226,124,117,204,25,99,155,0,0,0,0,0,0,0,0,0,29,148,210,37,126,194,8,93,157,2,68,118,1,39,69,1,17,33,41,151,213,27,123,193,3,82,144,1,58,105,1,32,60,1,13,26,59,159,220,23,126,198,4,88,151,1,66,114,1,38,71,1,18,34,114,136,232,51,114,207,11,83,155,3,56,105,1,33,65,1,17,34,149,65,234,121,57,215,61,49,166,28,36,114,12,25,76,3,16,42,214,49,220,132,63,188,42,65,137,0,0,0,0,0,0,0,0,0,85,137,221,104,131,216,49,111,192,21,87,155,2,49,87,1,16,28,89,163,230,90,137,220,29,100,183,10,70,135,2,42,81,1,17,33,108,167,237,55,133,222,15,97,179,4,72,135,1,45,85,1,19,38,124,146,240,66,124,224,17,88,175,4,58,122,1,36,75,1,18,37,141,79,241,126,70,227,66,58,182,30,44,136,12,34,96,2,20,47,229,99,249,143,111,235,46,109,192,0,0,0,0,0,0,0,0,0,82,158,236,94,146,224,25,117,191,9,87,149,3,56,99,1,33,57,83,167,237,68,145,222,10,103,177,2,72,131,1,41,79,1,20,39,99,167,239,47,141,224,10,104,178,2,73,133,1,44,85,1,22,47,127,145,243,71,129,228,17,93,177,3,61,124,1,41,84,1,21,52,157,78,244,140,72,231,69,58,184,31,44,137,14,38,105,8,23,61,125,34,187,52,41,133,6,31,56,0,0,0,0,0,0,0,0,0,37,109,153,51,102,147,23,87,128,8,67,101,1,41,63,1,19,29,31,154,185,17,127,175,6,96,145,2,73,114,1,51,82,1,28,45,23,163,200,10,131,185,2,93,148,1,67,111,1,41,69,1,14,24,29,176,217,12,145,201,3,101,156,1,69,111,1,39,63,1,14,23,57,192,233,25,154,215,6,109,167,3,78,118,1,48,69,1,21,29,202,105,245,108,106,216,18,90,144,0,0,0,0,0,0,0,0,0,33,172,219,64,149,206,14,117,177,5,90,141,2,61,95,1,37,57,33,179,220,11,140,198,1,89,148,1,60,104,1,33,57,1,12,21,30,181,221,8,141,198,1,87,145,1,58,100,1,31,55,1,12,20,32,186,224,7,142,198,1,86,143,1,58,100,1,31,55,1,12,22,57,192,227,20,143,204,3,96,154,1,68,112,1,42,69,1,19,32,212,35,215,113,47,169,29,48,105,0,0,0,0,0,0,0,0,0,74,129,203,106,120,203,49,107,178,19,84,144,4,50,84,1,15,25,71,172,217,44,141,209,15,102,173,6,76,133,2,51,89,1,24,42,64,185,231,31,148,216,8,103,175,3,74,131,1,46,81,1,18,30,65,196,235,25,157,221,5,105,174,1,67,120,1,38,69,1,15,30,65,204,238,30,156,224,7,107,177,2,70,124,1,42,73,1,18,34,225,86,251,144,104,235,42,99,181,0,0,0,0,0,0,0,0,0,85,175,239,112,165,229,29,136,200,12,103,162,6,77,123,2,53,84,75,183,239,30,155,221,3,106,171,1,74,128,1,44,76,1,17,28,73,185,240,27,159,222,2,107,172,1,75,127,1,42,73,1,17,29,62,190,238,21,159,222,2,107,172,1,72,122,1,40,71,1,18,32,61,199,240,27,161,226,4,113,180,1,76,129,1,46,80,1,23,41,7,27,153,5,30,95,1,16,30,0,0,0,0,0,0,0,0,0,50,75,127,57,75,124,27,67,108,10,54,86,1,33,52,1,12,18,43,125,151,26,108,148,7,83,122,2,59,89,1,38,60,1,17,27,23,144,163,13,112,154,2,75,117,1,50,81,1,31,51,1,14,23,18,162,185,6,123,171,1,78,125,1,51,86,1,31,54,1,14,23,15,199,227,3,150,204,1,91,146,1,55,95,1,30,53,1,11,20,19,55,240,19,59,196,3,52,105,0,0,0,0,0,0,0,0,0,41,166,207,104,153,199,31,123,181,14,101,152,5,72,106,1,36,52,35,176,211,12,131,190,2,88,144,1,60,101,1,36,60,1,16,28,28,183,213,8,134,191,1,86,142,1,56,96,1,30,53,1,12,20,20,190,215,4,135,192,1,84,139,1,53,91,1,28,49,1,11,20,13,196,216,2,137,192,1,86,143,1,57,99,1,32,56,1,13,24,211,29,217,96,47,156,22,43,87,0,0,0,0,0,0,0,0,0,78,120,193,111,116,186,46,102,164,15,80,128,2,49,76,1,18,28,71,161,203,42,132,192,10,98,150,3,69,109,1,44,70,1,18,29,57,186,211,30,140,196,4,93,146,1,62,102,1,38,65,1,16,27,47,199,217,14,145,196,1,88,142,1,57,98,1,36,62,1,15,26,26,219,229,5,155,207,1,94,151,1,60,104,1,36,62,1,16,28,233,29,248,146,47,220,43,52,140,0,0,0,0,0,0,0,0,0,100,163,232,179,161,222,63,142,204,37,113,174,26,89,137,18,68,97,85,181,230,32,146,209,7,100,164,3,71,121,1,45,77,1,18,30,65,187,230,20,148,207,2,97,159,1,68,116,1,40,70,1,14,29,40,194,227,8,147,204,1,94,155,1,65,112,1,39,66,1,14,26,16,208,228,3,151,207,1,98,160,1,67,117,1,41,74,1,17,31,17,38,140,7,34,80,1,17,29,0,0,0,0,0,0,0,0,0,37,75,128,41,76,128,26,66,116,12,52,94,2,32,55,1,10,16,50,127,154,37,109,152,16,82,121,5,59,85,1,35,54,1,13,20,40,142,167,17,110,157,2,71,112,1,44,72,1,27,45,1,11,17,30,175,188,9,124,169,1,74,116,1,48,78,1,30,49,1,11,18,10,222,223,2,150,194,1,83,128,1,48,79,1,27,45,1,11,17,36,41,235,29,36,193,10,27,111,0,0,0,0,0,0,0,0,0,85,165,222,177,162,215,110,135,195,57,113,168,23,83,120,10,49,61,85,190,223,36,139,200,5,90,146,1,60,103,1,38,65,1,18,30,72,202,223,23,141,199,2,86,140,1,56,97,1,36,61,1,16,27,55,218,225,13,145,200,1,86,141,1,57,99,1,35,61,1,13,22,15,235,212,1,132,184,1,84,139,1,57,97,1,34,56,1,14,23,181,21,201,61,37,123,10,38,71,0,0,0,0,0,0,0,0,0,47,106,172,95,104,173,42,93,159,18,77,131,4,50,81,1,17,23,62,147,199,44,130,189,28,102,154,18,75,115,2,44,65,1,12,19,55,153,210,24,130,194,3,93,146,1,61,97,1,31,50,1,10,16,49,186,223,17,148,204,1,96,142,1,53,83,1,26,44,1,11,17,13,217,212,2,136,180,1,78,124,1,50,83,1,29,49,1,14,23,197,13,247,82,17,222,25,17,162,0,0,0,0,0,0,0,0,0,126,186,247,234,191,243,176,177,234,104,158,220,66,128,186,55,90,137,111,197,242,46,158,219,9,104,171,2,65,125,1,44,80,1,17,91,104,208,245,39,168,224,3,109,162,1,79,124,1,50,102,1,43,102,84,220,246,31,177,231,2,115,180,1,79,134,1,55,77,1,60,79,43,243,240,8,180,217,1,115,166,1,84,121,1,51,67,1,16,6,4,0,8,0,8,0,9,0,10,0,11,0,12,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,38,0,39,0,40,0,41,0,42,0,43,0,43,0,44,0,45,0,46,0,47,0,48,0,48,0,49,0,50,0,51,0,52,0,53,0,53,0,54,0,55,0,56,0,57,0,57,0,58,0,59,0,60,0,61,0,62,0,62,0,63,0,64,0,65,0,66,0,66,0,67,0,68,0,69,0,70,0,70,0,71,0,72,0,73,0,74,0,74,0,75,0,76,0,77,0,78,0,78,0,79,0,80,0,81,0,81,0,82,0,83,0,84,0,85,0,85,0,87,0,88,0,90,0,92,0,93,0,95,0,96,0,98,0,99,0,101,0,102,0,104,0,105,0,107,0,108,0,110,0,111,0,113,0,114,0,116,0,117,0,118,0,120,0,121,0,123,0,125,0,127,0,129,0,131,0,134,0,136,0,138,0,140,0,142,0,144,0,146,0,148,0,150,0,152,0,154,0,156,0,158,0,161,0,164,0,166,0,169,0,172,0,174,0,177,0,180,0,182,0,185,0,187,0,190,0,192,0,195,0,199,0,202,0,205,0,208,0,211,0,214,0,217,0,220,0,223,0,226,0,230,0,233,0,237,0,240,0,243,0,247,0,250,0,253,0,1,1,5,1,9,1,13,1,16,1,20,1,24,1,28,1,32,1,36,1,40,1,44,1,48,1,53,1,57,1,61,1,66,1,70,1,74,1,79,1,84,1,88,1,93,1,98,1,103,1,108,1,113,1,118,1,123,1,128,1,133,1,139,1,144,1,150,1,155,1,161,1,167,1,173,1,179,1,185,1,191,1,198,1,205,1,211,1,219,1,226,1,233,1,241,1,249,1,1,2,10,2,18,2,27,2,37,2,47,2,57,2,67,2,78,2,90,2,102,2,114,2,128,2,142,2,156,2,172,2,188,2,205,2,224,2,243,2,7,3,28,3,51,3,75,3,101,3,128,3,157,3,187,3,220,3,254,3,34,4,74,4,115,4,160,4,208,4,2,5,56,5,0,0,0,0,1,0,1,0,0,0,0,0,2,0,2,0,8,0,8,0,3,0,3,0,9,0,9,0,8,0,8,0,4,0,4,0,10,0,10,0,16,0,16,0,11,0,11,0,17,0,17,0,5,0,5,0,16,0,16,0,18,0,18,0,12,0,12,0,24,0,24,0,6,0,6,0,25,0,25,0,19,0,19,0,24,0,24,0,13,0,13,0,26,0,26,0,20,0,20,0,32,0,32,0,27,0,27,0,33,0,33,0,14,0,14,0,21,0,21,0,34,0,34,0,32,0,32,0,28,0,28,0,40,0,40,0,35,0,35,0,22,0,22,0,29,0,29,0,41,0,41,0,36,0,36,0,40,0,40,0,42,0,42,0,30,0,30,0,43,0,43,0,48,0,48,0,37,0,37,0,49,0,49,0,48,0,48,0,44,0,44,0,38,0,38,0,50,0,50,0,56,0,56,0,51,0,51,0,45,0,45,0,57,0,57,0,52,0,52,0,58,0,58,0,46,0,46,0,59,0,59,0,53,0,53,0,60,0,60,0,54,0,54,0,61,0,61,0,62,0,62,0,0,0,0,0,0,0,1,0,2,0,8,0,3,0,9,0,4,0,10,0,16,0,5,0,11,0,17,0,12,0,18,0,6,0,24,0,19,0,13,0,25,0,7,0,26,0,20,0,32,0,14,0,27,0,21,0,33,0,28,0,34,0,15,0,22,0,35,0,40,0,29,0,41,0,36,0,23,0,30,0,42,0,37,0,48,0,43,0,31,0,44,0,49,0,38,0,50,0,56,0,45,0,39,0,51,0,57,0,52,0,46,0,58,0,53,0,59,0,47,0,60,0,54,0,61,0,55,0,62,0,63,0,0,0,0,0,1,0,1,0,0,0,0,0,2,0,2,0,4,0,4,0,5,0,5,0,4,0,4,0,6,0,6,0,8,0,8,0,9,0,9,0,8,0,8,0,12,0,12,0,10,0,10,0,13,0,13,0,14,0,14,0,0,0,0,0,0,0,1,0,2,0,4,0,3,0,5,0,6,0,8,0,7,0,9,0,10,0,12,0,13,0,11,0,14,0,15,0,0,0,0,0,1,0,1,0,2,0,2,0,0,0,0,0,3,0,3,0,16,0,16,0,4,0,4,0,17,0,17,0,5,0,5,0,18,0,18,0,16,0,16,0,19,0,19,0,6,0,6,0,32,0,32,0,20,0,20,0,33,0,33,0,7,0,7,0,34,0,34,0,21,0,21,0,32,0,32,0,35,0,35,0,8,0,8,0,48,0,48,0,22,0,22,0,49,0,49,0,36,0,36,0,9,0,9,0,37,0,37,0,50,0,50,0,23,0,23,0,48,0,48,0,51,0,51,0,10,0,10,0,64,0,64,0,38,0,38,0,24,0,24,0,52,0,52,0,65,0,65,0,53,0,53,0,39,0,39,0,66,0,66,0,11,0,11,0,64,0,64,0,25,0,25,0,67,0,67,0,54,0,54,0,80,0,80,0,40,0,40,0,68,0,68,0,12,0,12,0,26,0,26,0,81,0,81,0,55,0,55,0,69,0,69,0,82,0,82,0,41,0,41,0,13,0,13,0,83,0,83,0,80,0,80,0,70,0,70,0,27,0,27,0,56,0,56,0,84,0,84,0,96,0,96,0,14,0,14,0,71,0,71,0,97,0,97,0,42,0,42,0,85,0,85,0,57,0,57,0,98,0,98,0,28,0,28,0,86,0,86,0,99,0,99,0,96,0,96,0,72,0,72,0,43,0,43,0,100,0,100,0,58,0,58,0,29,0,29,0,112,0,112,0,87,0,87,0,113,0,113,0,73,0,73,0,112,0,112,0,101,0,101,0,44,0,44,0,30,0,30,0,114,0,114,0,59,0,59,0,102,0,102,0,88,0,88,0,115,0,115,0,74,0,74,0,128,0,128,0,116,0,116,0,45,0,45,0,103,0,103,0,89,0,89,0,60,0,60,0,129,0,129,0,117,0,117,0,130,0,130,0,131,0,131,0,104,0,104,0,75,0,75,0,46,0,46,0,118,0,118,0,128,0,128,0,90,0,90,0,61,0,61,0,132,0,132,0,105,0,105,0,144,0,144,0,119,0,119,0,145,0,145,0,133,0,133,0,76,0,76,0,146,0,146,0,120,0,120,0,91,0,91,0,134,0,134,0,147,0,147,0,62,0,62,0,106,0,106,0,135,0,135,0,121,0,121,0,92,0,92,0,148,0,148,0,144,0,144,0,77,0,77,0,149,0,149,0,136,0,136,0,107,0,107,0,160,0,160,0,161,0,161,0,150,0,150,0,122,0,122,0,78,0,78,0,137,0,137,0,162,0,162,0,151,0,151,0,93,0,93,0,163,0,163,0,108,0,108,0,164,0,164,0,152,0,152,0,123,0,123,0,138,0,138,0,160,0,160,0,165,0,165,0,94,0,94,0,176,0,176,0,166,0,166,0,109,0,109,0,153,0,153,0,177,0,177,0,124,0,124,0,178,0,178,0,139,0,139,0,167,0,167,0,154,0,154,0,110,0,110,0,179,0,179,0,176,0,176,0,180,0,180,0,168,0,168,0,140,0,140,0,125,0,125,0,181,0,181,0,192,0,192,0,193,0,193,0,155,0,155,0,182,0,182,0,169,0,169,0,194,0,194,0,126,0,126,0,141,0,141,0,195,0,195,0,183,0,183,0,192,0,192,0,196,0,196,0,156,0,156,0,170,0,170,0,142,0,142,0,184,0,184,0,197,0,197,0,208,0,208,0,198,0,198,0,209,0,209,0,171,0,171,0,157,0,157,0,185,0,185,0,210,0,210,0,208,0,208,0,211,0,211,0,199,0,199,0,224,0,224,0,158,0,158,0,212,0,212,0,224,0,224,0,186,0,186,0,200,0,200,0,172,0,172,0,225,0,225,0,213,0,213,0,214,0,214,0,226,0,226,0,201,0,201,0,227,0,227,0,187,0,187,0,240,0,240,0,215,0,215,0,173,0,173,0,228,0,228,0,241,0,241,0,202,0,202,0,242,0,242,0,216,0,216,0,229,0,229,0,174,0,174,0,188,0,188,0,243,0,243,0,230,0,230,0,203,0,203,0,217,0,217,0,231,0,231,0,244,0,244,0,218,0,218,0,245,0,245,0,189,0,189,0,232,0,232,0,204,0,204,0,190,0,190,0,246,0,246,0,233,0,233,0,247,0,247,0,219,0,219,0,205,0,205,0,248,0,248,0,234,0,234,0,220,0,220,0,206,0,206,0,249,0,249,0,235,0,235,0,221,0,221,0,250,0,250,0,222,0,222,0,236,0,236,0,237,0,237,0,251,0,251,0,238,0,238,0,252,0,252,0,253,0,253,0,254,0,254,0,0,0,0,0,0,0,1,0,2,0,3,0,16,0,4,0,17,0,5,0,18,0,6,0,19,0,32,0,20,0,7,0,33,0,21,0,34,0,8,0,35,0,22,0,48,0,36,0,9,0,49,0,23,0,50,0,37,0,10,0,38,0,51,0,24,0,64,0,52,0,11,0,65,0,39,0,25,0,53,0,66,0,54,0,40,0,67,0,12,0,80,0,26,0,68,0,55,0,81,0,41,0,69,0,13,0,27,0,82,0,56,0,70,0,83,0,42,0,14,0,84,0,96,0,71,0,28,0,57,0,85,0,97,0,15,0,72,0,98,0,43,0,86,0,58,0,99,0,29,0,87,0,100,0,112,0,73,0,44,0,101,0,59,0,30,0,113,0,88,0,114,0,74,0,128,0,102,0,45,0,31,0,115,0,60,0,103,0,89,0,116,0,75,0,129,0,117,0,46,0,104,0,90,0,61,0,130,0,118,0,131,0,132,0,105,0,76,0,47,0,119,0,144,0,91,0,62,0,133,0,106,0,145,0,120,0,146,0,134,0,77,0,147,0,121,0,92,0,135,0,148,0,63,0,107,0,136,0,122,0,93,0,149,0,160,0,78,0,150,0,137,0,108,0,161,0,162,0,151,0,123,0,79,0,138,0,163,0,152,0,94,0,164,0,109,0,165,0,153,0,124,0,139,0,176,0,166,0,95,0,177,0,167,0,110,0,154,0,178,0,125,0,179,0,140,0,168,0,155,0,111,0,180,0,192,0,181,0,169,0,141,0,126,0,182,0,193,0,194,0,156,0,183,0,170,0,195,0,127,0,142,0,196,0,184,0,208,0,197,0,157,0,171,0,143,0,185,0,198,0,209,0,199,0,210,0,172,0,158,0,186,0,211,0,224,0,212,0,200,0,240,0,159,0,213,0,225,0,187,0,201,0,173,0,226,0,214,0,215,0,227,0,202,0,228,0,188,0,241,0,216,0,174,0,229,0,242,0,203,0,243,0,217,0,230,0,175,0,189,0,244,0,231,0,204,0,218,0,232,0,245,0,219,0,246,0,190,0,233,0,205,0,191,0,247,0,234,0,248,0,220,0,206,0,249,0,235,0,221,0,207,0,250,0,236,0,222,0,251,0,223,0,237,0,238,0,252,0,239,0,253,0,254,0,255,0,0,1,1,2,2,2,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,0,1,1,2,2,2,3,3,3,3,4,4,4,5,5,5,245,2,0,4,255,6,8,12,254,10,253,252,14,16,251,250,18,20,249,248,247,246,0,0,2,6,254,4,253,252,8,10,251,250,12,14,249,248,247,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,112,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,0,0,0,0,0,0,0,4,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,255,255,1,0,0,0,0,0,1,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,254,255,1,0,255,255,2,0,0,0,1,0,1,0,0,0,2,0,255,255,1,0,254,255,0,0,254,255,254,255,0,0,252,255,2,0,254,255,4,0,0,0,2,0,2,0,0,0,4,0,254,255,2,0,252,255,0,0,252,255,252,255,0,0,248,255,4,0,252,255,8,0,0,0,4,0,4,0,0,0,8,0,252,255,4,0,248,255,0,0,248,255,248,255,0,0,240,255,8,0,248,255,16,0,0,0,8,0,8,0,0,0,16,0,248,255,8,0,240,255,0,0,240,255,240,255,0,0,224,255,16,0,240,255,32,0,0,0,16,0,16,0,0,0,32,0,240,255,16,0,224,255,0,0,224,255,224,255,0,0,192,255,32,0,224,255,64,0,0,0,32,0,32,0,0,0,64,0,224,255,32,0,192,255,0,0,192,255,192,255,0,0,128,255,64,0,192,255,128,0,0,0,64,0,64,0,0,0,128,0,192,255,64,0,128,255,0,0,128,255,128,255,0,0,0,255,128,0,128,255,0,1,0,0,128,0,128,0,0,0,0,1,128,255,128,0,0,255,0,0,0,255,0,255,0,0,0,254,0,1,0,255,0,2,0,0,0,1,0,1,0,0,0,2,0,255,0,1,0,254,0,0,0,254,0,254,0,0,0,252,0,2,0,254,0,4,0,0,0,2,0,2,0,0,0,4,0,254,0,2,0,252,0,0,4,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,104,0,106,0,108,0,110,0,112,0,114,0,116,0,118,0,120,0,122,0,124,0,126,0,128,0,130,0,132,0,134,0,136,0,138,0,140,0,142,0,144,0,146,0,148,0,150,0,152,0,155,0,158,0,161,0,164,0,167,0,170,0,173,0,176,0,179,0,182,0,185,0,188,0,191,0,194,0,197,0,200,0,203,0,207,0,211,0,215,0,219,0,223,0,227,0,231,0,235,0,239,0,243,0,247,0,251,0,255,0,4,1,9,1,14,1,19,1,24,1,29,1,34,1,39,1,44,1,49,1,55,1,61,1,67,1,73,1,79,1,85,1,91,1,97,1,103,1,110,1,117,1,124,1,131,1,138,1,145,1,152,1,160,1,168,1,176,1,184,1,192,1,200,1,209,1,218,1,227,1,236,1,245,1,254,1,8,2,18,2,28,2,38,2,48,2,59,2,70,2,81,2,92,2,103,2,115,2,127,2,139,2,151,2,164,2,177,2,190,2,203,2,217,2,231,2,245,2,3,3,18,3,33,3,48,3,64,3,80,3,96,3,113,3,130,3,147,3,165,3,183,3,201,3,220,3,239,3,2,4,22,4,42,4,63,4,84,4,105,4,127,4,149,4,172,4,195,4,219,4,243,4,12,5,37,5,63,5,89,5,116,5,143,5,171,5,199,5,228,5,1,6,31,6,61,6,92,6,124,6,156,6,189,6,223,6,1,7,36,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,1,0,0,240,0,0,0,1,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,60,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,4,0,0,0,63,0,0,0,100,0,0,0,100,0,0,0,112,23,0,0,160,15,0,0,136,19,0,0,50,0,0,0,0,0,0,0,144,1,0,0,1,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,204,1,0,0,2,0,0,0,88,0,0,0,3,0,0,0,174,0,0,0,5,0,0,0,8,1,0,0,6,0,0,0,92,0,0,0,7,0,0,0,136,1,0,0,8,0,0,0,134,1,0,0,9,0,0,0,196,0,0,0,11,0,0,0,168,0,0,0,13,0,0,0,202,0,0,0,15,0,0,0,202,0,0,0,14,0,0,0,202,0,0,0,16,0,0,0,202,0,0,0,17,0,0,0,202,0,0,0,18,0,0,0,202,0,0,0,19,0,0,0,48,0,0,0,20,0,0,0,48,0,0,0,21,0,0,0,202,0,0,0,22,0,0,0,202,0,0,0,23,0,0,0,202,0,0,0,24,0,0,0,202], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+225280);
/* memory initializer */ allocate([25,0,0,0,202,0,0,0,26,0,0,0,202,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,36,0,0,0,40,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,251,0,0,0,248,0,0,0,244,0,0,0,240,0,0,0,236,0,0,0,232,0,0,0,229,0,0,0,225,0,0,0,221,0,0,0,217,0,0,0,213,0,0,0,208,0,0,0,204,0,0,0,199,0,0,0,194,0,0,0,190,0,0,0,187,0,0,0,183,0,0,0,179,0,0,0,175,0,0,0,172,0,0,0,168,0,0,0,164,0,0,0,160,0,0,0,157,0,0,0,153,0,0,0,149,0,0,0,145,0,0,0,142,0,0,0,138,0,0,0,134,0,0,0,130,0,0,0,127,0,0,0,124,0,0,0,120,0,0,0,117,0,0,0,114,0,0,0,110,0,0,0,107,0,0,0,104,0,0,0,101,0,0,0,98,0,0,0,95,0,0,0,92,0,0,0,89,0,0,0,86,0,0,0,83,0,0,0,80,0,0,0,77,0,0,0,74,0,0,0,71,0,0,0,68,0,0,0,65,0,0,0,62,0,0,0,59,0,0,0,56,0,0,0,53,0,0,0,50,0,0,0,47,0,0,0,44,0,0,0,41,0,0,0,38,0,0,0,35,0,0,0,32,0,0,0,30,0,0,0,28,0,0,0,26,0,0,0,24,0,0,0,22,0,0,0,20,0,0,0,18,0,0,0,16,0,0,0,0,2,4,6,255,254,253,252,112,86,140,37,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,0,2,255,4,254,253,0,0,162,101,204,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,176,246,255,255,255,255,255,255,255,255,255,223,241,252,255,255,255,255,255,255,255,255,249,253,253,255,255,255,255,255,255,255,255,255,244,252,255,255,255,255,255,255,255,255,234,254,254,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,246,254,255,255,255,255,255,255,255,255,239,253,254,255,255,255,255,255,255,255,255,254,255,254,255,255,255,255,255,255,255,255,255,248,254,255,255,255,255,255,255,255,255,251,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,251,254,254,255,255,255,255,255,255,255,255,254,255,254,255,255,255,255,255,255,255,255,255,254,253,255,254,255,255,255,255,255,255,250,255,254,255,254,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,217,255,255,255,255,255,255,255,255,255,255,225,252,241,253,255,255,254,255,255,255,255,234,250,241,250,253,255,253,254,255,255,255,255,254,255,255,255,255,255,255,255,255,255,223,254,254,255,255,255,255,255,255,255,255,238,253,254,254,255,255,255,255,255,255,255,255,248,254,255,255,255,255,255,255,255,255,249,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,247,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,253,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,186,251,250,255,255,255,255,255,255,255,255,234,251,244,254,255,255,255,255,255,255,255,251,251,243,253,254,255,254,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,236,253,254,255,255,255,255,255,255,255,255,251,253,253,254,254,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,250,254,252,254,255,255,255,255,255,255,255,248,254,249,253,255,255,255,255,255,255,255,255,253,253,255,255,255,255,255,255,255,255,246,253,253,255,255,255,255,255,255,255,255,252,254,251,254,254,255,255,255,255,255,255,255,254,252,255,255,255,255,255,255,255,255,248,254,253,255,255,255,255,255,255,255,255,253,255,254,254,255,255,255,255,255,255,255,255,251,254,255,255,255,255,255,255,255,255,245,251,254,255,255,255,255,255,255,255,255,253,253,254,255,255,255,255,255,255,255,255,255,251,253,255,255,255,255,255,255,255,255,252,253,254,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,249,255,254,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,253,136,254,255,228,219,128,128,128,128,128,189,129,242,255,227,213,255,219,128,128,128,106,126,227,252,214,209,255,255,128,128,128,1,98,248,255,236,226,255,255,128,128,128,181,133,238,254,221,234,255,154,128,128,128,78,134,202,247,198,180,255,219,128,128,128,1,185,249,255,243,255,128,128,128,128,128,184,150,247,255,236,224,128,128,128,128,128,77,110,216,255,236,230,128,128,128,128,128,1,101,251,255,241,255,128,128,128,128,128,170,139,241,252,236,209,255,255,128,128,128,37,116,196,243,228,255,255,255,128,128,128,1,204,254,255,245,255,128,128,128,128,128,207,160,250,255,238,128,128,128,128,128,128,102,103,231,255,211,171,128,128,128,128,128,1,152,252,255,240,255,128,128,128,128,128,177,135,243,255,234,225,128,128,128,128,128,80,129,211,255,194,224,128,128,128,128,128,1,1,255,128,128,128,128,128,128,128,128,246,1,255,128,128,128,128,128,128,128,128,255,128,128,128,128,128,128,128,128,128,128,198,35,237,223,193,187,162,160,145,155,62,131,45,198,221,172,176,220,157,252,221,1,68,47,146,208,149,167,221,162,255,223,128,1,149,241,255,221,224,255,255,128,128,128,184,141,234,253,222,220,255,199,128,128,128,81,99,181,242,176,190,249,202,255,255,128,1,129,232,253,214,197,242,196,255,255,128,99,121,210,250,201,198,255,202,128,128,128,23,91,163,242,170,187,247,210,255,255,128,1,200,246,255,234,255,128,128,128,128,128,109,178,241,255,231,245,255,255,128,128,128,44,130,201,253,205,192,255,255,128,128,128,1,132,239,251,219,209,255,165,128,128,128,94,136,225,251,218,190,255,255,128,128,128,22,100,174,245,186,161,255,199,128,128,128,1,182,249,255,232,235,128,128,128,128,128,124,143,241,255,227,234,128,128,128,128,128,35,77,181,251,193,211,255,205,128,128,128,1,157,247,255,236,231,255,255,128,128,128,121,141,235,255,225,227,255,255,128,128,128,45,99,188,251,195,217,255,224,128,128,128,1,1,251,255,213,255,128,128,128,128,128,203,1,248,255,255,128,128,128,128,128,128,137,1,177,255,224,255,128,128,128,128,128,253,9,248,251,207,208,255,192,128,128,128,175,13,224,243,193,185,249,198,255,255,128,73,17,171,221,161,179,236,167,255,234,128,1,95,247,253,212,183,255,255,128,128,128,239,90,244,250,211,209,255,255,128,128,128,155,77,195,248,188,195,255,255,128,128,128,1,24,239,251,218,219,255,205,128,128,128,201,51,219,255,196,186,128,128,128,128,128,69,46,190,239,201,218,255,228,128,128,128,1,191,251,255,255,128,128,128,128,128,128,223,165,249,255,213,255,128,128,128,128,128,141,124,248,255,255,128,128,128,128,128,128,1,16,248,255,255,128,128,128,128,128,128,190,36,230,255,236,255,128,128,128,128,128,149,1,255,128,128,128,128,128,128,128,128,1,226,255,128,128,128,128,128,128,128,128,247,192,255,128,128,128,128,128,128,128,128,240,128,255,128,128,128,128,128,128,128,128,1,134,252,255,255,128,128,128,128,128,128,213,62,250,255,255,128,128,128,128,128,128,55,93,255,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,202,24,213,235,186,191,220,160,240,175,255,126,38,182,232,169,184,228,174,255,187,128,61,46,138,219,151,178,240,170,255,216,128,1,112,230,250,199,191,247,159,255,255,128,166,109,228,252,211,215,255,174,128,128,128,39,77,162,232,172,180,245,178,255,255,128,1,52,220,246,198,199,249,220,255,255,128,124,74,191,243,183,193,250,221,255,255,128,24,71,130,219,154,170,243,182,255,255,128,1,182,225,249,219,240,255,224,128,128,128,149,150,226,252,216,205,255,171,128,128,128,28,108,170,242,183,194,254,223,255,255,128,1,81,230,252,204,203,255,192,128,128,128,123,102,209,247,188,196,255,233,128,128,128,20,95,153,243,164,173,255,203,128,128,128,1,222,248,255,216,213,128,128,128,128,128,168,175,246,252,235,205,255,255,128,128,128,47,116,215,255,211,212,255,255,128,128,128,1,121,236,253,212,214,255,255,128,128,128,141,84,213,252,201,202,255,219,128,128,128,42,80,160,240,162,185,255,205,128,128,128,1,1,255,128,128,128,128,128,128,128,128,244,1,255,128,128,128,128,128,128,128,128,238,1,255,128,128,128,128,128,128,128,128,147,136,18,106,145,1,179,121,1,223,1,34,208,1,1,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,250,255,123,0,12,0,255,255,0,0,2,0,245,255,108,0,36,0,248,255,1,0,0,0,247,255,93,0,50,0,250,255,0,0,3,0,240,255,77,0,77,0,240,255,3,0,0,0,250,255,50,0,93,0,247,255,0,0,1,0,248,255,36,0,108,0,245,255,2,0,0,0,255,255,12,0,123,0,250,255,0,0,246,2,245,4,244,243,0,0,147,136,18,223,1,34,106,145,1,208,1,1,179,121,1,223,1,34,179,121,1,208,1,1,147,136,18,106,145,1,179,121,1,223,1,34,208,1,1,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,2,8,4,6,0,255,254,253,10,12,252,251,250,249,0,0,0,0,0,0,3,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,3,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,255,255,0,0,0,0,255,255,0,0,1,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,255,7,0,0,255,7,0,0,255,6,0,0,105,6,0,0,255,5,0,0,172,5,0,0,105,5,0,0,48,5,0,0,255,4,0,0,211,4,0,0,172,4,0,0,137,4,0,0,105,4,0,0,75,4,0,0,48,4,0,0,22,4,0,0,255,3,0,0,232,3,0,0,211,3,0,0,191,3,0,0,172,3,0,0,154,3,0,0,137,3,0,0,121,3,0,0,105,3,0,0,90,3,0,0,75,3,0,0,61,3,0,0,48,3,0,0,35,3,0,0,22,3,0,0,10,3,0,0,255,2,0,0,243,2,0,0,232,2,0,0,221,2,0,0,211,2,0,0,201,2,0,0,191,2,0,0,181,2,0,0,172,2,0,0,163,2,0,0,154,2,0,0,145,2,0,0,137,2,0,0,129,2,0,0,121,2,0,0,113,2,0,0,105,2,0,0,97,2,0,0,90,2,0,0,82,2,0,0,75,2,0,0,68,2,0,0,61,2,0,0,55,2,0,0,48,2,0,0,41,2,0,0,35,2,0,0,29,2,0,0,22,2,0,0,16,2,0,0,10,2,0,0,4,2,0,0,255,1,0,0,249,1,0,0,243,1,0,0,238,1,0,0,232,1,0,0,227,1,0,0,221,1,0,0,216,1,0,0,211,1,0,0,206,1,0,0,201,1,0,0,196,1,0,0,191,1,0,0,186,1,0,0,181,1,0,0,177,1,0,0,172,1,0,0,168,1,0,0,163,1,0,0,159,1,0,0,154,1,0,0,150,1,0,0,145,1,0,0,141,1,0,0,137,1,0,0,133,1,0,0,129,1,0,0,125,1,0,0,121,1,0,0,117,1,0,0,113,1,0,0,109,1,0,0,105,1,0,0,101,1,0,0,97,1,0,0,93,1,0,0,90,1,0,0,86,1,0,0,82,1,0,0,79,1,0,0,75,1,0,0,72,1,0,0,68,1,0,0,65,1,0,0,61,1,0,0,58,1,0,0,55,1,0,0,51,1,0,0,48,1,0,0,45,1,0,0,41,1,0,0,38,1,0,0,35,1,0,0,32,1,0,0,29,1,0,0,25,1,0,0,22,1,0,0,19,1,0,0,16,1,0,0,13,1,0,0,10,1,0,0,7,1,0,0,4,1,0,0,1,1,0,0,255,0,0,0,252,0,0,0,249,0,0,0,246,0,0,0,243,0,0,0,240,0,0,0,238,0,0,0,235,0,0,0,232,0,0,0,229,0,0,0,227,0,0,0,224,0,0,0,221,0,0,0,219,0,0,0,216,0,0,0,214,0,0,0,211,0,0,0,208,0,0,0,206,0,0,0,203,0,0,0,201,0,0,0,198,0,0,0,196,0,0,0,194,0,0,0,191,0,0,0,189,0,0,0,186,0,0,0,184,0,0,0,181,0,0,0,179,0,0,0,177,0,0,0,174,0,0,0,172,0,0,0,170,0,0,0,168,0,0,0,165,0,0,0,163,0,0,0,161,0,0,0,159,0,0,0,156,0,0,0,154,0,0,0,152,0,0,0,150,0,0,0,148,0,0,0,145,0,0,0,143,0,0,0,141,0,0,0,139,0,0,0,137,0,0,0,135,0,0,0,133,0,0,0,131,0,0,0,129,0,0,0,127,0,0,0,125,0,0,0,123,0,0,0,121,0,0,0,119,0,0,0,117,0,0,0,115,0,0,0,113,0,0,0,111,0,0,0,109,0,0,0,107,0,0,0,105,0,0,0,103,0,0,0,101,0,0,0,99,0,0,0,97,0,0,0,95,0,0,0,93,0,0,0,92,0,0,0,90,0,0,0,88,0,0,0,86,0,0,0,84,0,0,0,82,0,0,0,81,0,0,0,79,0,0,0,77,0,0,0,75,0,0,0,73,0,0,0,72,0,0,0,70,0,0,0,68,0,0,0,66,0,0,0,65,0,0,0,63,0,0,0,61,0,0,0,60,0,0,0,58,0,0,0,56,0,0,0,55,0,0,0,53,0,0,0,51,0,0,0,50,0,0,0,48,0,0,0,46,0,0,0,45,0,0,0,43,0,0,0,41,0,0,0,40,0,0,0,38,0,0,0,37,0,0,0,35,0,0,0,33,0,0,0,32,0,0,0,30,0,0,0,29,0,0,0,27,0,0,0,25,0,0,0,24,0,0,0,22,0,0,0,21,0,0,0,19,0,0,0,18,0,0,0,16,0,0,0,15,0,0,0,13,0,0,0,12,0,0,0,10,0,0,0,9,0,0,0,7,0,0,0,6,0,0,0,4,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,0,1,2,2,2,2,2,2,2,2,2,0,0,0,0,0,0,1,254,2,255,253,0,0,142,114,183,0,0,0,0,0,162,101,204,0,0,0,0,0,254,1,247,2,0,3,4,6,255,5,252,251,253,7,249,8,250,248,0,0,0,0,0,0,39,53,200,87,26,21,43,232,171,56,34,51,104,114,102,29,93,77,88,88,147,150,42,46,45,196,205,107,54,32,26,51,1,81,43,31,39,28,85,171,58,165,90,98,64,34,22,116,206,23,34,43,166,73,34,19,21,102,132,188,16,76,124,68,25,106,22,64,171,36,225,114,62,18,78,95,85,57,50,48,51,43,97,183,117,85,38,35,179,61,112,113,77,85,179,255,38,120,114,40,42,1,196,245,209,10,25,109,193,101,35,159,215,111,89,46,111,100,80,8,43,154,1,51,26,71,88,43,29,140,166,213,37,43,154,61,63,30,155,67,45,68,1,209,41,40,5,102,211,183,4,1,221,142,78,78,16,255,128,34,197,171,51,50,17,168,209,192,23,25,82,60,148,31,172,219,228,21,18,111,175,69,143,80,85,82,72,155,103,56,58,10,171,218,189,17,13,152,231,120,48,89,115,113,120,152,112,144,71,10,38,171,213,144,34,26,114,26,17,163,44,195,21,10,173,121,24,80,195,26,62,44,64,85,63,20,8,114,114,208,12,9,226,170,46,55,19,136,160,33,206,71,81,40,11,96,182,84,29,16,36,152,179,64,126,170,118,46,70,95,75,79,123,47,51,128,81,171,1,57,17,5,71,102,57,53,41,49,125,98,42,88,104,85,117,175,82,115,21,2,10,102,255,166,23,6,38,33,13,121,57,73,26,1,85,41,10,67,138,77,110,90,47,114,57,18,10,102,102,213,34,20,43,101,29,16,10,85,128,101,196,26,117,20,15,36,163,128,68,1,26,95,84,53,89,128,100,113,101,45,63,59,90,180,59,166,93,73,154,40,40,21,116,143,209,34,39,175,138,31,36,171,27,166,38,44,229,57,46,22,24,128,1,54,17,37,47,15,16,183,34,223,49,45,183,46,17,33,183,6,98,15,32,183,40,3,9,115,51,192,18,6,223,65,32,73,115,28,128,23,128,205,87,37,9,115,59,77,64,21,47,67,87,58,169,82,115,26,59,179,54,57,112,184,5,41,38,166,213,30,34,26,133,152,116,10,32,134,104,55,44,218,9,54,53,130,226,75,32,12,51,192,255,160,43,51,39,19,53,221,26,114,32,73,255,31,9,65,234,2,15,1,118,73,56,21,23,111,59,205,45,37,192,88,31,35,67,102,85,55,186,85,55,38,70,124,73,102,1,34,98,64,90,70,205,40,41,23,26,57,86,40,64,135,148,224,45,183,128,22,26,17,131,240,154,14,1,209,164,50,31,137,154,133,25,35,218,83,12,13,54,192,255,68,47,28,45,16,21,91,64,222,7,1,197,56,21,39,155,60,138,23,102,213,18,11,7,63,144,171,4,4,246,85,26,85,85,128,128,32,146,171,35,27,10,146,174,171,12,26,128,51,103,44,131,131,123,31,6,158,68,45,128,34,1,47,11,245,171,62,17,19,70,146,85,55,62,70,102,61,71,37,34,53,31,243,192,75,15,9,9,64,255,184,119,16,37,43,37,154,100,163,85,160,1,63,9,92,136,28,64,32,201,85,56,8,17,132,137,255,55,116,128,86,6,28,5,64,255,25,248,1,58,15,20,82,135,57,26,121,40,69,60,71,38,73,119,28,222,37,101,75,128,139,118,146,116,128,85,56,41,15,176,236,85,37,9,62,190,80,35,99,180,80,126,54,45,146,36,19,30,171,255,97,27,20,71,30,17,119,118,255,17,18,138,101,38,60,138,55,70,43,26,142,32,41,20,117,151,142,20,21,163,138,45,61,62,219,1,81,188,64,112,19,12,61,195,128,48,4,24,85,126,47,87,176,51,41,20,32,66,102,167,99,74,62,40,234,128,41,53,9,178,241,141,26,8,107,134,183,89,137,98,101,106,165,148,104,79,12,27,217,255,87,17,7,74,43,26,146,73,166,49,23,157,65,38,105,160,51,52,31,115,128,47,41,14,110,182,183,21,17,194,87,68,71,44,114,51,15,186,23,66,45,25,102,197,189,23,18,22,72,187,100,130,157,111,32,75,80,0,0,0,0,120,90,79,133,87,85,80,111,151,0,0,0,0,0,0,0,2,1,0,9,0,0,0,0,252,1,2,3,0,254,255,253,0,1,2,3,254,255,253,252,145,156,163,128,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,96,153,32,0,24,146,32,0,44,1,0,0,1,0,0,0,0,0,0,128,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,138,32,0,200,132,32,0,52,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,32,127,32,0,16,121,32,0,68,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,64,116,32,0,160,106,32,0,56,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,96,82,32,0,184,68,32,0,60,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,96,62,32,0,0,55,32,0,64,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,96,48,32,0,88,42,32,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,96,48,32,0,16,37,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,96,48,32,0,216,31,32,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,96,48,32,0,144,89,40,0,144,82,40,0,240,0,0,0,1,0,0,0,64,66,15,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,160,57,40,0,184,44,40,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,57,40,0,64,36,40,0,0,0,0,0,0,0,0,0,128,0,0,0,64,66,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,57,40,0,32,29,40,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,57,40,0,32,23,40,0,216,17,40,0,72,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,16,13,40,0,56,7,40,0,96,1,40,0,80,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,104,247,39,0,24,222,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,16,13,40,0,160,207,39,0,240,195,39,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,16,13,40,0,160,187,39,0,160,179,39,0,76,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,79,64,17,0,0,0,0,0,0,0,248,86,39,0,136,27,156,0,44,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,48,192,0,0,0,0,0,0,48,64,17,0,0,0,0,0,0,0,160,57,40,0,136,27,156,0,240,0,0,0,1,0,0,0,64,66,15,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,160,57,40,0,208,75,39,0,136,27,156,0,48,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,17,0,0,0,216,70,39,0,216,64,39,0,88,59,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,216,70,39,0,176,53,39,0,48,36,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,216,70,39,0,16,24,39,0,160,106,32,0,56,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,64,17,0,0,0,0,0,0,0,72,18,39,0,184,68,32,0,60,1,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,17,0,0,0,0,0,0,0,96,48,32,0,0,55,32,0,64,1,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,8,64,17,0,0,0,0,0,0,0,88,11,39,0,16,121,32,0,68,1,0,0,1,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,237,246,253,253,254,254,254,254,254,254,254,254,254,254,250,250,252,254,254,231,243,245,253,254,254,254,254,254,254,254,254,254,254,251,251,254,254,254,0,0,237,246,253,253,254,254,254,254,254,254,254,254,254,254,250,250,252,254,254,231,243,245,253,254,254,254,254,254,254,254,254,254,254,251,251,254,254,254,0,0,249,2,251,4,250,6,248,247,2,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,14,0,0,0,4,0,0,0,15,0,0,0,4,0,0,0,162,128,225,146,172,147,214,39,156,128,129,132,75,145,178,206,239,254,254,164,128,204,170,119,235,140,230,228,128,130,130,74,148,180,203,236,254,254,0,0,7,0,0,0,0,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,5,0,0,0,7,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,4,0,0,0,7,0,0,0,1,0,0,0,1,0,0,0,143,0,0,0,14,0,0,0,18,0,0,0,14,0,0,0,107,0,0,0,135,0,0,0,64,0,0,0,57,0,0,0,68,0,0,0,60,0,0,0,56,0,0,0,128,0,0,0,65,0,0,0,159,0,0,0,134,0,0,0,128,0,0,0,34,0,0,0,234,0,0,0,188,0,0,0,128,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,2,2,3,3,2,2,3,3,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,253,2,254,4,0,255,0,0,110,111,150,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,10,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,6,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,2,2,4,16,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,16,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,10,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,7,0,0,0,6,0,0,0,252,2,4,6,0,255,254,253,145,156,163,128,0,0,0,0,4,0,0,0,3,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,142,114,183,0,0,0,0,0,231,120,48,89,115,113,120,152,112,152,179,64,126,170,118,46,70,95,175,69,143,80,85,82,72,155,103,56,58,10,171,218,189,17,13,152,144,71,10,38,171,213,144,34,26,114,26,17,163,44,195,21,10,173,121,24,80,195,26,62,44,64,85,170,46,55,19,136,160,33,206,71,63,20,8,114,114,208,12,9,226,81,40,11,96,182,84,29,16,36,134,183,89,137,98,101,106,165,148,72,187,100,130,157,111,32,75,80,66,102,167,99,74,62,40,234,128,41,53,9,178,241,141,26,8,107,104,79,12,27,217,255,87,17,7,74,43,26,146,73,166,49,23,157,65,38,105,160,51,52,31,115,128,87,68,71,44,114,51,15,186,23,47,41,14,110,182,183,21,17,194,66,45,25,102,197,189,23,18,22,88,88,147,150,42,46,45,196,205,43,97,183,117,85,38,35,179,61,39,53,200,87,26,21,43,232,171,56,34,51,104,114,102,29,93,77,107,54,32,26,51,1,81,43,31,39,28,85,171,58,165,90,98,64,34,22,116,206,23,34,43,166,73,68,25,106,22,64,171,36,225,114,34,19,21,102,132,188,16,76,124,62,18,78,95,85,57,50,48,51,193,101,35,159,215,111,89,46,111,60,148,31,172,219,228,21,18,111,112,113,77,85,179,255,38,120,114,40,42,1,196,245,209,10,25,109,100,80,8,43,154,1,51,26,71,88,43,29,140,166,213,37,43,154,61,63,30,155,67,45,68,1,209,142,78,78,16,255,128,34,197,171,41,40,5,102,211,183,4,1,221,51,50,17,168,209,192,23,25,82,125,98,42,88,104,85,117,175,82,95,84,53,89,128,100,113,101,45,75,79,123,47,51,128,81,171,1,57,17,5,71,102,57,53,41,49,115,21,2,10,102,255,166,23,6,38,33,13,121,57,73,26,1,85,41,10,67,138,77,110,90,47,114,101,29,16,10,85,128,101,196,26,57,18,10,102,102,213,34,20,43,117,20,15,36,163,128,68,1,26,138,31,36,171,27,166,38,44,229,67,87,58,169,82,115,26,59,179,63,59,90,180,59,166,93,73,154,40,40,21,116,143,209,34,39,175,57,46,22,24,128,1,54,17,37,47,15,16,183,34,223,49,45,183,46,17,33,183,6,98,15,32,183,65,32,73,115,28,128,23,128,205,40,3,9,115,51,192,18,6,223,87,37,9,115,59,77,64,21,47,104,55,44,218,9,54,53,130,226,64,90,70,205,40,41,23,26,57,54,57,112,184,5,41,38,166,213,30,34,26,133,152,116,10,32,134,75,32,12,51,192,255,160,43,51,39,19,53,221,26,114,32,73,255,31,9,65,234,2,15,1,118,73,88,31,35,67,102,85,55,186,85,56,21,23,111,59,205,45,37,192,55,38,70,124,73,102,1,34,98,102,61,71,37,34,53,31,243,192,69,60,71,38,73,119,28,222,37,68,45,128,34,1,47,11,245,171,62,17,19,70,146,85,55,62,70,75,15,9,9,64,255,184,119,16,37,43,37,154,100,163,85,160,1,63,9,92,136,28,64,32,201,85,86,6,28,5,64,255,25,248,1,56,8,17,132,137,255,55,116,128,58,15,20,82,135,57,26,121,40,164,50,31,137,154,133,25,35,218,51,103,44,131,131,123,31,6,158,86,40,64,135,148,224,45,183,128,22,26,17,131,240,154,14,1,209,83,12,13,54,192,255,68,47,28,45,16,21,91,64,222,7,1,197,56,21,39,155,60,138,23,102,213,85,26,85,85,128,128,32,146,171,18,11,7,63,144,171,4,4,246,35,27,10,146,174,171,12,26,128,190,80,35,99,180,80,126,54,45,85,126,47,87,176,51,41,20,32,101,75,128,139,118,146,116,128,85,56,41,15,176,236,85,37,9,62,146,36,19,30,171,255,97,27,20,71,30,17,119,118,255,17,18,138,101,38,60,138,55,70,43,26,142,138,45,61,62,219,1,81,188,64,32,41,20,117,151,142,20,21,163,112,19,12,61,195,128,48,4,24,0,0,0,0,0,0,255,255,255,255,0,0,1,0,0,0,0,0,1,0,255,255,254,255,1,0,254,255,2,0,0,0,1,0,2,0,255,255,2,0,254,255,0,0,80,0,0,0,82,0,0,0,84,0,0,0,86,0,0,0,88,0,0,0,90,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,97,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,164,0,0,0,165,0,0,0,166,0,0,0,167,0,0,0,168,0,0,0,169,0,0,0,170,0,0,0,171,0,0,0,172,0,0,0,173,0,0,0,174,0,0,0,175,0,0,0,176,0,0,0,177,0,0,0,178,0,0,0,179,0,0,0,180,0,0,0,181,0,0,0,182,0,0,0,183,0,0,0,184,0,0,0,184,0,0,0,185,0,0,0,185,0,0,0,186,0,0,0,186,0,0,0,187,0,0,0,187,0,0,0,188,0,0,0,188,0,0,0,189,0,0,0,189,0,0,0,190,0,0,0,190,0,0,0,191,0,0,0,191,0,0,0,192,0,0,0,192,0,0,0,193,0,0,0,193,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,195,0,0,0,195,0,0,0,196,0,0,0,196,0,0,0,197,0,0,0,197,0,0,0,198,0,0,0,198,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,224,197,150,0,200,137,40,0,1,0,0,0,5,0,0,0,136,210,28,0,184,137,40,0,2,0,0,0,7,0,0,0,128,210,28,0,168,137,40,0,3,0,0,0,11,0,0,0,120,210,28,0,152,137,40,0,4,0,0,0,19,0,0,0,104,210,28,0,136,137,40,0,5,0,0,0,35,0,0,0,80,210,28,0,104,137,40,0,11,0,0,0,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,8,0,0,0,5,0,0,0,2,0,0,0,3,0,0,0,6,0,0,0,9,0,0,0,12,0,0,0,13,0,0,0,10,0,0,0,7,0,0,0,11,0,0,0,14,0,0,0,15,0,0,0,162,128,225,146,172,147,214,39,156,128,129,132,75,145,178,206,239,254,254,164,128,204,170,119,235,140,230,228,128,130,130,74,148,180,203,236,254,254,0,0,8,87,24,0,0,0,0,0,8,135,24,0,0,0,0,0,254,254,243,230,196,177,153,140,133,130,129,0,0,0,0,0,180,157,141,134,130,0,0,0,176,155,140,135,0,0,0,0,173,148,140,0,0,0,0,0,4,5,6,7,8,9,10,10,11,12,13,14,15,16,17,17,18,19,20,20,21,21,22,22,23,23,24,25,25,26,27,28,29,30,31,32,33,34,35,36,37,37,38,39,40,41,42,43,44,45,46,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,76,77,78,79,80,81,82,83,84,85,86,87,88,89,91,93,95,96,98,100,101,102,104,106,108,110,112,114,116,118,122,124,126,128,130,132,134,136,138,140,143,145,148,151,154,157,1,0,0,0,40,1,0,0,2,0,0,0,128,0,0,0,3,0,0,0,116,0,0,0,4,0,0,0,114,0,0,0,5,0,0,0,114,0,0,0,6,0,0,0,114,0,0,0,7,0,0,0,114,0,0,0,0,1,0,0,12,1,0,0,1,1,0,0,228,0,0,0,2,1,0,0,158,0,0,0,3,1,0,0,230,0,0,0,255,255,255,255,0,0,0,0,0,255,0,0,0,0,0,0,0,0,1,255,0,0,0,0,0,0,0,0,2,255,0,0,0,0,0,0,0,0,3,255,0,0,0,0,0,0,0,0,5,255,0,0,0,0,0,0,0,0,6,255,0,0,0,0,0,0,0,0,4,7,8,9,10,11,12,13,14,255,15,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,176,246,255,255,255,255,255,255,255,255,255,223,241,252,255,255,255,255,255,255,255,255,249,253,253,255,255,255,255,255,255,255,255,255,244,252,255,255,255,255,255,255,255,255,234,254,254,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,246,254,255,255,255,255,255,255,255,255,239,253,254,255,255,255,255,255,255,255,255,254,255,254,255,255,255,255,255,255,255,255,255,248,254,255,255,255,255,255,255,255,255,251,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,251,254,254,255,255,255,255,255,255,255,255,254,255,254,255,255,255,255,255,255,255,255,255,254,253,255,254,255,255,255,255,255,255,250,255,254,255,254,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+235520);
/* memory initializer */ allocate([255,255,255,255,255,255,255,255,217,255,255,255,255,255,255,255,255,255,255,225,252,241,253,255,255,254,255,255,255,255,234,250,241,250,253,255,253,254,255,255,255,255,254,255,255,255,255,255,255,255,255,255,223,254,254,255,255,255,255,255,255,255,255,238,253,254,254,255,255,255,255,255,255,255,255,248,254,255,255,255,255,255,255,255,255,249,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,247,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,253,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,186,251,250,255,255,255,255,255,255,255,255,234,251,244,254,255,255,255,255,255,255,255,251,251,243,253,254,255,254,255,255,255,255,255,253,254,255,255,255,255,255,255,255,255,236,253,254,255,255,255,255,255,255,255,255,251,253,253,254,254,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,250,254,252,254,255,255,255,255,255,255,255,248,254,249,253,255,255,255,255,255,255,255,255,253,253,255,255,255,255,255,255,255,255,246,253,253,255,255,255,255,255,255,255,255,252,254,251,254,254,255,255,255,255,255,255,255,254,252,255,255,255,255,255,255,255,255,248,254,253,255,255,255,255,255,255,255,255,253,255,254,254,255,255,255,255,255,255,255,255,251,254,255,255,255,255,255,255,255,255,245,251,254,255,255,255,255,255,255,255,255,253,253,254,255,255,255,255,255,255,255,255,255,251,253,255,255,255,255,255,255,255,255,252,253,254,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,249,255,254,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,245,2,0,4,255,6,8,12,254,10,253,252,14,16,251,250,18,20,249,248,247,246,0,0,2,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,28,0,0,0,5,0,0,0,58,0,0,0,6,0,0,0,59,0,0,0,6,0,0,0,60,0,0,0,6,0,0,0,61,0,0,0,6,0,0,0,124,0,0,0,7,0,0,0,125,0,0,0,7,0,0,0,126,0,0,0,7,0,0,0,127,0,0,0,7,0,0,0,0,0,0,0,1,0,0,0,0,1,2,3,6,4,5,6,6,6,6,6,6,6,6,7,0,2,255,4,254,6,8,12,253,10,251,250,252,14,249,16,248,247,0,0,0,0,0,0,120,90,79,133,87,85,80,111,151,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,28,0,0,0,5,0,0,0,30,0,0,0,5,0,0,0,58,0,0,0,6,0,0,0,59,0,0,0,6,0,0,0,62,0,0,0,6,0,0,0,126,0,0,0,7,0,0,0,127,0,0,0,7,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,5,5,6,6,7,7,8,0,0,0,0,0,0,0,0,1,2,3,0,1,2,3,0,1,2,3,0,1,2,3,4,5,4,5,6,7,6,7,8,0,0,0,0,0,0,0,136,42,17,0,160,187,13,0,176,113,11,0,41,207,9,0,68,149,8,0,32,161,7,0,208,221,6,0,208,221,6,0,2,62,6,0,216,184,5,0,41,72,5,0,148,231,4,0,224,147,4,0,162,74,4,0,1,10,4,0,1,10,4,0,144,208,3,0,42,157,3,0,232,110,3,0,232,110,3,0,13,69,3,0,13,69,3,0,1,31,3,0,1,31,3,0,68,252,2,0,68,252,2,0,108,220,2,0,32,191,2,0,32,191,2,0,20,164,2,0,10,139,2,0,202,115,2,0,36,94,2,0,240,73,2,0,9,55,2,0,81,37,2,0,171,20,2,0,0,5,2,0,59,246,1,0,72,232,1,0,21,219,1,0,21,219,1,0,149,206,1,0,184,194,1,0,116,183,1,0,188,172,1,0,134,162,1,0,203,152,1,0,128,143,1,0,160,134,1,0,34,126,1,0,34,126,1,0,0,118,1,0,54,110,1,0,188,102,1,0,144,95,1,0,171,88,1,0,10,82,1,0,169,75,1,0,133,69,1,0,154,63,1,0,229,57,1,0,99,52,1,0,18,47,1,0,239,41,1,0,248,36,1,0,42,32,1,0,132,27,1,0,4,23,1,0,168,18,1,0,110,14,1,0,85,10,1,0,92,6,1,0,128,2,1,0,193,254,0,0,29,251,0,0,148,247,0,0,36,244,0,0,203,240,0,0,138,237,0,0,96,234,0,0,74,231,0,0,74,231,0,0,73,228,0,0,92,225,0,0,130,222,0,0,186,219,0,0,3,217,0,0,94,214,0,0,200,211,0,0,67,209,0,0,205,206,0,0,101,204,0,0,12,202,0,0,192,199,0,0,129,197,0,0,42,193,0,0,3,189,0,0,8,185,0,0,27,183,0,0,94,179,0,0,200,175,0,0,10,174,0,0,85,172,0,0,5,169,0,0,212,165,0,0,194,162,0,0,205,159,0,0,242,156,0,0,49,154,0,0,137,151,0,0,247,148,0,0,21,144,0,0,194,141,0,0,130,139,0,0,84,137,0,0,55,135,0,0,42,133,0,0,46,131,0,0,64,129,0,0,96,127,0,0,142,125,0,0,236,122,0,0,58,121,0,0,197,118,0,0,105,116,0,0,36,114,0,0,246,111,0,0,52,223,10,0,144,178,8,0,120,63,7,0,102,54,6,0,154,111,5,0,250,212,4,0,72,89,4,0,18,244,3,0,188,159,3,0,94,88,3,0,51,27,3,0,48,230,2,0,205,183,2,0,223,142,2,0,125,106,2,0,240,73,2,0,164,44,2,0,34,18,2,0,9,250,1,0,9,228,1,0,222,207,1,0,80,189,1,0,47,172,1,0,83,156,1,0,153,141,1,0,227,127,1,0,24,115,1,0,31,103,1,0,230,91,1,0,91,81,1,0,111,71,1,0,20,62,1,0,62,53,1,0,227,44,1,0,248,36,1,0,116,29,1,0,82,22,1,0,136,15,1,0,17,9,1,0,231,2,1,0,4,253,0,0,101,247,0,0,4,242,0,0,222,236,0,0,239,231,0,0,51,227,0,0,168,222,0,0,74,218,0,0,23,214,0,0,13,210,0,0,41,206,0,0,106,202,0,0,204,198,0,0,80,195,0,0,241,191,0,0,140,185,0,0,143,179,0,0,243,173,0,0,173,168,0,0,183,163,0,0,10,159,0,0,159,154,0,0,113,150,0,0,124,146,0,0,186,142,0,0,41,139,0,0,196,135,0,0,136,132,0,0,115,129,0,0,130,126,0,0,178,123,0,0,2,121,0,0,111,118,0,0,247,115,0,0,153,113,0,0,84,111,0,0,37,109,0,0,11,107,0,0,6,105,0,0,20,103,0,0,53,101,0,0,102,99,0,0,168,97,0,0,248,95,0,0,141,93,0,0,64,91,0,0,16,89,0,0,249,86,0,0,251,84,0,0,20,83,0,0,66,81,0,0,133,79,0,0,218,77,0,0,64,76,0,0,183,74,0,0,62,73,0,0,211,71,0,0,117,70,0,0,37,69,0,0,226,67,0,0,169,66,0,0,124,65,0,0,89,64,0,0,229,62,0,0,129,61,0,0,45,60,0,0,231,58,0,0,174,57,0,0,131,56,0,0,99,55,0,0,78,54,0,0,68,53,0,0,68,52,0,0,77,51,0,0,95,50,0,0,122,49,0,0,157,48,0,0,147,47,0,0,148,46,0,0,112,45,0,0,181,44,0,0,212,43,0,0,251,42,0,0,43,42,0,0,98,41,0,0,161,40,0,0,231,39,0,0,51,39,0,0,128,0,0,0,112,0,16,0,96,0,32,0,80,0,48,0,64,0,64,0,48,0,80,0,32,0,96,0,16,0,112,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,60,0,62,0,64,0,66,0,68,0,70,0,72,0,74,0,76,0,78,0,80,0,82,0,84,0,86,0,88,0,90,0,92,0,94,0,96,0,98,0,100,0,102,0,104,0,106,0,108,0,110,0,112,0,114,0,116,0,119,0,122,0,125,0,128,0,131,0,134,0,137,0,140,0,143,0,146,0,149,0,152,0,155,0,158,0,161,0,164,0,167,0,170,0,173,0,177,0,181,0,185,0,189,0,193,0,197,0,201,0,205,0,209,0,213,0,217,0,221,0,225,0,229,0,234,0,239,0,245,0,249,0,254,0,3,1,8,1,13,1,18,1,23,1,28,1,237,246,231,243,0,0,0,0,219,246,238,249,232,239,249,255,248,253,239,244,241,248,198,232,251,253,219,241,253,255,248,249,244,238,251,255,0,0,0,0,227,246,230,247,244,255,255,255,255,255,255,255,255,209,231,231,249,249,253,255,255,255,255,255,225,242,241,251,253,255,255,255,255,255,255,241,253,252,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,255,248,255,255,255,255,255,255,255,255,255,255,240,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,206,203,227,239,247,255,253,255,255,255,255,207,199,220,236,243,252,252,255,255,255,255,212,219,230,243,244,253,252,255,255,255,255,236,237,247,252,253,255,255,255,255,255,255,240,240,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,230,233,249,255,255,255,255,255,255,255,255,238,238,250,255,255,255,255,255,255,255,255,248,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,225,239,227,231,244,253,243,255,255,253,255,232,234,224,228,242,249,242,252,251,251,255,235,249,238,240,251,255,249,255,253,253,255,249,253,251,250,255,255,255,255,255,255,255,251,250,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,243,244,250,250,255,255,255,255,255,255,255,249,248,250,253,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,253,253,254,254,254,254,254,245,253,254,254,254,254,254,0,0,8,0,4,1,2,2,255,0,254,0,2,3,253,0,252,0,8,4,4,5,2,6,251,0,250,0,2,7,249,0,248,0,0,0,0,0,0,0,0,0,0,1,2,7,6,5,4,0,10,13,11,12,0,1,2,3,14,8,15,16,4,5,6,7,13,14,11,0,1,15,16,18,2,17,3,4,19,20,5,6,21,22,7,8,9,10,0,0,254,254,254,254,254,250,250,252,254,254,254,254,254,251,251,254,198,197,196,146,198,204,169,142,130,136,149,149,191,249,135,201,181,154,98,117,132,126,146,169,184,240,246,254,0,0,0,0,225,146,172,147,214,39,156,204,170,119,235,140,230,228,0,0,247,210,135,68,138,220,239,246,244,184,201,44,173,221,239,253,0,0,1,1,1,2,2,2,2,2,2,3,3,4,4,4,5,5,5,5,6,6,7,7,7,7,7,8,8,9,9,9,9,9,9,10,10,11,11,11,11,11,11,12,12,12,12,12,12,13,13,13,13,13,14,14,14,14,15,15,15,15,15,15,146,255,181,207,232,243,238,251,244,250,249,179,255,214,240,250,255,244,255,255,255,255,0,0,122,0,0,0,133,0,0,0,0,0,0,0,1,0,0,0,78,0,0,0,171,0,0,0,139,0,0,0,117,0,0,0,168,0,0,0,79,0,0,0,133,0,0,0,51,0,0,0,0,0,0,0,1,0,0,0,169,0,0,0,71,0,0,0,214,0,0,0,44,0,0,0,210,0,0,0,38,0,0,0,142,0,0,0,240,255,255,255,0,0,0,0,1,0,0,0,221,0,0,0,226,255,255,255,246,0,0,0,253,255,255,255,203,0,0,0,17,0,0,0,4,4,4,4,8,8,0,0,255,132,132,159,153,151,161,170,164,162,136,110,103,114,129,118,124,125,132,136,114,110,142,135,134,123,143,126,153,183,166,161,171,180,179,164,203,218,225,217,215,206,203,217,229,241,248,243,253,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,1,1,1,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,0,0,128,0,0,0,0,0,253,255,122,0,9,0,0,0,252,255,109,0,24,0,255,255,251,255,91,0,45,0,253,255,252,255,68,0,68,0,252,255,253,255,45,0,91,0,251,255,255,255,24,0,109,0,252,255,0,0,9,0,122,0,253,255,0,0,128,0,0,0,0,0,252,255,124,0,9,0,255,255,251,255,110,0,25,0,254,255,250,255,91,0,46,0,253,255,251,255,69,0,69,0,251,255,253,255,46,0,91,0,250,255,254,255,25,0,110,0,251,255,255,255,9,0,124,0,252,255,0,0,128,0,0,0,0,0,252,255,123,0,10,0,255,255,250,255,110,0,26,0,254,255,249,255,92,0,47,0,252,255,250,255,70,0,70,0,250,255,252,255,47,0,92,0,249,255,254,255,26,0,110,0,250,255,255,255,10,0,123,0,252,255,0,0,128,0,0,0,0,0,251,255,124,0,10,0,255,255,249,255,110,0,27,0,254,255,249,255,91,0,48,0,252,255,250,255,70,0,70,0,250,255,252,255,48,0,92,0,248,255,254,255,27,0,110,0,249,255,255,255,10,0,124,0,251,255,0,0,128,0,0,0,0,0,250,255,124,0,11,0,255,255,248,255,111,0,28,0,253,255,248,255,92,0,49,0,251,255,249,255,71,0,71,0,249,255,251,255,49,0,92,0,248,255,253,255,28,0,111,0,248,255,255,255,11,0,124,0,250,255,0,0,128,0,0,0,0,0,250,255,123,0,12,0,255,255,247,255,111,0,29,0,253,255,247,255,93,0,50,0,250,255,248,255,72,0,72,0,248,255,250,255,50,0,93,0,247,255,253,255,29,0,111,0,247,255,255,255,12,0,123,0,250,255,0,0,128,0,0,0,0,0,249,255,124,0,12,0,255,255,246,255,111,0,30,0,253,255,246,255,93,0,51,0,250,255,247,255,73,0,73,0,247,255,250,255,51,0,93,0,246,255,253,255,30,0,111,0,246,255,255,255,12,0,124,0,249,255,0,0,128,0,0,0,0,0,249,255,123,0,13,0,255,255,245,255,112,0,31,0,252,255,245,255,94,0,52,0,249,255,246,255,74,0,74,0,246,255,249,255,52,0,94,0,245,255,252,255,31,0,112,0,245,255,255,255,13,0,123,0,249,255,0,0,128,0,0,0,0,0,248,255,124,0,13,0,255,255,244,255,112,0,32,0,252,255,244,255,94,0,53,0,249,255,246,255,74,0,74,0,246,255,249,255,53,0,94,0,244,255,252,255,32,0,112,0,244,255,255,255,13,0,124,0,248,255,0,0,128,0,0,0,0,0,247,255,124,0,14,0,255,255,243,255,112,0,33,0,252,255,243,255,95,0,54,0,248,255,245,255,75,0,75,0,245,255,248,255,54,0,95,0,243,255,252,255,33,0,112,0,243,255,255,255,14,0,124,0,247,255,0,0,128,0,0,0,0,0,247,255,123,0,15,0,255,255,242,255,113,0,34,0,251,255,242,255,95,0,55,0,248,255,244,255,76,0,76,0,244,255,248,255,55,0,95,0,242,255,251,255,34,0,112,0,243,255,255,255,15,0,123,0,247,255,0,0,128,0,0,0,0,0,246,255,124,0,15,0,255,255,242,255,113,0,34,0,251,255,241,255,96,0,56,0,247,255,243,255,77,0,77,0,243,255,247,255,56,0,96,0,241,255,251,255,34,0,113,0,242,255,255,255,15,0,124,0,246,255,0,0,128,0,0,0,0,0,246,255,123,0,16,0,255,255,241,255,113,0,35,0,251,255,240,255,98,0,56,0,246,255,242,255,78,0,78,0,242,255,246,255,56,0,98,0,240,255,251,255,35,0,113,0,241,255,255,255,16,0,123,0,246,255,0,0,128,0,0,0,0,0,245,255,124,0,17,0,254,255,240,255,113,0,36,0,251,255,239,255,98,0,57,0,246,255,242,255,78,0,78,0,242,255,246,255,57,0,98,0,239,255,251,255,36,0,113,0,240,255,254,255,17,0,124,0,245,255,0,0,128,0,0,0,0,0,244,255,125,0,17,0,254,255,239,255,114,0,37,0,250,255,238,255,99,0,58,0,245,255,241,255,79,0,79,0,241,255,245,255,58,0,99,0,238,255,250,255,37,0,114,0,239,255,254,255,17,0,125,0,244,255,0,0,128,0,0,0,0,0,244,255,124,0,18,0,254,255,238,255,114,0,38,0,250,255,237,255,99,0,59,0,245,255,240,255,80,0,80,0,240,255,245,255,59,0,99,0,237,255,250,255,38,0,114,0,238,255,254,255,18,0,124,0,244,255,0,0,128,0,0,0,0,0,252,255,118,0,16,0,254,255,249,255,106,0,34,0,251,255,248,255,90,0,53,0,249,255,248,255,72,0,72,0,248,255,249,255,53,0,90,0,248,255,251,255,34,0,106,0,249,255,254,255,16,0,118,0,252,255,243,220,251,253,237,232,241,245,247,251,253,235,211,246,249,234,231,248,249,252,252,254,0,0,227,246,230,247,244,254,254,254,254,254,254,202,254,209,231,231,249,249,253,254,254,254,206,254,225,242,241,251,253,254,254,254,254,235,254,241,253,252,254,254,254,254,254,254,234,254,248,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,240,254,248,254,254,254,254,254,254,254,254,238,254,240,253,254,254,254,254,254,254,254,244,254,251,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,206,203,227,239,247,254,253,254,254,254,254,207,199,220,236,243,252,252,254,254,254,254,212,219,230,243,244,253,252,254,254,254,254,236,237,247,252,253,254,254,254,254,254,254,240,240,248,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,230,233,249,254,254,254,254,254,254,254,254,238,238,250,254,254,254,254,254,254,254,254,248,251,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,225,239,227,231,244,253,243,254,254,253,254,232,234,224,228,242,249,242,252,251,251,254,235,249,238,240,251,254,249,254,253,253,254,249,253,251,250,254,254,254,254,254,254,254,251,250,249,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,243,244,250,250,254,254,254,254,254,254,254,249,248,250,253,254,254,254,254,254,254,254,253,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,0,0,0,0,20,1,0,0,238,0,0,0,195,0,0,0,156,0,0,0,113,0,0,0,18,1,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,192,0,59,0,182,0,50,0,141,0,48,0,110,0,40,0,92,0,19,0,125,0,128,0,169,0,87,0,169,0,83,0,184,0,62,0,220,0,16,0,184,0,0,0,8,1,0,0,212,0,40,0,212,0,36,0,169,0,49,0,174,0,27,0,8,0,120,0,182,0,71,0,3,1,10,0,197,0,19,0,143,0,22,0,123,0,16,0,110,0,8,0,133,0,88,0,0,0,1,0,0,1,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,207,0,46,0,187,0,50,0,97,0,83,0,23,0,100,0,41,0,56,0,56,0,188,0,166,0,90,0,146,0,108,0,161,0,88,0,136,0,95,0,174,0,0,0,10,1,0,0,8,1,7,0,243,0,18,0,184,0,43,0,242,255,154,0,20,0,112,0,20,0,199,0,230,0,26,0,197,0,22,0,159,0,20,0,146,0,12,0,136,0,4,0,54,0,162,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,192,0,59,0,156,0,72,0,84,0,101,0,49,0,101,0,79,0,47,0,79,0,167,0,138,0,115,0,136,0,116,0,166,0,80,0,238,0,0,0,195,0,0,0,5,1,0,0,225,0,33,0,205,0,42,0,159,0,61,0,79,0,96,0,92,0,66,0,28,0,195,0,200,0,37,0,197,0,18,0,159,0,13,0,143,0,7,0,102,0,5,0,123,0,126,0,197,0,3,0,220,0,247,255,210,0,244,255,187,0,250,255,151,0,254,255,174,0,80,0,200,0,53,0,187,0,47,0,159,0,40,0,118,0,38,0,100,0,18,0,141,0,111,0,179,0,78,0,166,0,86,0,197,0,50,0,207,0,27,0,187,0,0,0,115,0,139,0,218,0,34,0,220,0,29,0,174,0,46,0,128,0,61,0,54,0,89,0,187,0,65,0,238,0,14,0,197,0,18,0,125,0,26,0,90,0,25,0,82,0,13,0,161,0,86,0,189,0,1,0,205,0,254,255,156,0,252,255,143,0,252,255,146,0,252,255,172,0,72,0,230,0,31,0,192,0,45,0,102,0,76,0,38,0,85,0,56,0,41,0,64,0,173,0,166,0,91,0,141,0,111,0,128,0,116,0,118,0,109,0,177,0,0,0,23,0,222,0,253,0,14,0,236,0,21,0,174,0,49,0,33,0,118,0,44,0,93,0,23,0,187,0,218,0,28,0,179,0,28,0,118,0,35,0,95,0,30,0,72,0,24,0,128,0,108,0,187,0,1,0,174,0,255,255,125,0,255,255,110,0,255,255,108,0,255,255,202,0,52,0,197,0,53,0,146,0,75,0,46,0,118,0,33,0,103,0,64,0,50,0,118,0,126,0,138,0,114,0,128,0,122,0,161,0,86,0,243,0,250,255,195,0,0,0,38,0,210,0,215,0,39,0,179,0,58,0,97,0,101,0,95,0,85,0,87,0,70,0,69,0,152,0,236,0,24,0,205,0,18,0,172,0,12,0,154,0,6,0,125,0,1,0,169,0,75,0,187,0,4,0,230,0,254,255,228,0,252,255,236,0,252,255,241,0,254,255,192,0,66,0,200,0,46,0,187,0,42,0,159,0,34,0,136,0,25,0,105,0,10,0,179,0,62,0,207,0,55,0,192,0,63,0,192,0,54,0,195,0,36,0,177,0,1,0,143,0,98,0,225,0,27,0,207,0,34,0,200,0,30,0,131,0,57,0,97,0,60,0,197,0,45,0,15,1,8,0,218,0,13,0,133,0,19,0,90,0,19,0,72,0,7,0,182,0,51,0,179,0,1,0,225,0,255,255,154,0,254,255,110,0,255,255,92,0,0,0,195,0,41,0,241,0,26,0,189,0,40,0,82,0,64,0,33,0,60,0,67,0,17,0,120,0,94,0,192,0,68,0,151,0,94,0,146,0,90,0,143,0,72,0,161,0,0,0,113,0,128,0,0,1,12,0,218,0,29,0,166,0,48,0,44,0,99,0,31,0,87,0,148,0,78,0,238,0,20,0,184,0,22,0,113,0,27,0,90,0,22,0,74,0,9,0,192,0,37,0,184,0,0,0,215,0,255,255,141,0,255,255,97,0,0,0,49,0,0,0,8,1,13,0,182,0,51,0,138,0,61,0,95,0,63,0,54,0,59,0,64,0,25,0,200,0,45,0,179,0,75,0,156,0,87,0,174,0,65,0,177,0,44,0,174,0,0,0,164,0,85,0,195,0,45,0,148,0,65,0,105,0,79,0,95,0,72,0,87,0,60,0,169,0,63,0,146,197,181,207,232,243,238,251,244,250,249,179,219,214,240,250,254,244,254,254,254,254,0,0,154,0,61,0,141,0,54,0,90,0,45,0,54,0,34,0,54,0,13,0,128,0,109,0,136,0,54,0,148,0,45,0,92,0,41,0,54,0,33,0,51,0,15,0,87,0,113,0,87,0,44,0,97,0,40,0,67,0,36,0,46,0,29,0,41,0,15,0,64,0,80,0,59,0,33,0,61,0,31,0,51,0,28,0,44,0,22,0,33,0,12,0,49,0,63,0,69,0,12,0,59,0,16,0,46,0,14,0,31,0,13,0,26,0,6,0,92,0,26,0,128,0,108,0,77,0,119,0,54,0,84,0,26,0,71,0,87,0,19,0,95,0,155,0,154,0,4,0,182,0,0,0,159,0,248,255,128,0,251,255,143,0,251,255,187,0,55,0,182,0,0,0,228,0,253,255,187,0,249,255,174,0,247,255,189,0,245,255,169,0,79,0,161,0,247,255,192,0,248,255,187,0,247,255,169,0,246,255,136,0,247,255,184,0,40,0,164,0,245,255,179,0,246,255,174,0,246,255,161,0,246,255,115,0,249,255,197,0,20,0,195,0,245,255,195,0,245,255,146,0,246,255,110,0,250,255,95,0,252,255,195,0,39,0,182,0,55,0,172,0,77,0,177,0,37,0,169,0,29,0,172,0,52,0,92,0,162,0,174,0,80,0,164,0,80,0,95,0,80,0,46,0,66,0,56,0,24,0,36,0,193,0,164,0,80,0,166,0,77,0,105,0,76,0,49,0,68,0,46,0,31,0,49,0,186,0,97,0,78,0,110,0,74,0,72,0,72,0,44,0,60,0,33,0,30,0,69,0,131,0,61,0,61,0,69,0,63,0,51,0,57,0,31,0,48,0,26,0,27,0,64,0,89,0,67,0,23,0,51,0,32,0,36,0,33,0,26,0,28,0,20,0,12,0,44,0,68,0,26,0,197,0,41,0,189,0,61,0,129,0,28,0,103,0,49,0,52,0,244,255,245,0,102,0,141,0,79,0,166,0,72,0,162,0,97,0,125,0,179,0,4,0,51,1,0,0,72,0,168,0,69,0,175,0,84,0,160,0,105,0,127,0,148,0,34,0,54,1,0,0,84,0,151,0,82,0,161,0,87,0,153,0,87,0,135,0,115,0,51,0,61,1,0,0,97,0,125,0,102,0,131,0,105,0,125,0,87,0,122,0,84,0,64,0,54,0,184,0,166,0,18,0,146,0,43,0,125,0,51,0,90,0,64,0,95,0,7,0,38,0,154,0,38,1,0,0,13,0,225,0,10,0,225,0,67,0,168,0,0,0,167,0,161,0,94,0,172,0,76,0,172,0,75,0,136,0,80,0,64,0,98,0,74,0,67,0,59,1,0,0,169,0,76,0,207,0,56,0,164,0,66,0,97,0,80,0,67,0,72,0,72,1,0,0,136,0,80,0,187,0,53,0,154,0,62,0,72,0,85,0,254,255,105,0,49,1,0,0,74,0,91,0,128,0,64,0,113,0,64,0,61,0,77,0,41,0,75,0,3,1,0,0,46,0,84,0,51,0,81,0,28,0,89,0,31,0,78,0,23,0,77,0,202,0,0,0,67,1,0,0,67,1,0,0,44,1,0,0,236,0,0,0,195,0,0,0,72,1,0,0,2,2,2,2,4,4,0,0,255,0,1,1,2,1,1,2,2,1,1,2,2,2,1,2,2,2,2,2,1,1,2,2,3,3,4,3,4,4,4,3,3,3,3,3,4,3,3,3,4,4,4,4,4,3,3,4,4,4,3,4,4,4,4,4,4,4,5,5,5,5,5,5,16,0,11,0,10,0,16,0,24,0,40,0,51,0,61,0,12,0,12,0,14,0,19,0,26,0,58,0,60,0,55,0,14,0,13,0,16,0,24,0,40,0,57,0,69,0,56,0,14,0,17,0,22,0,29,0,51,0,87,0,80,0,62,0,18,0,22,0,37,0,58,0,68,0,109,0,103,0,77,0,24,0,35,0,55,0,64,0,81,0,104,0,113,0,92,0,49,0,64,0,78,0,87,0,103,0,121,0,120,0,101,0,72,0,92,0,95,0,98,0,112,0,100,0,103,0,99,0,17,0,18,0,24,0,47,0,99,0,99,0,99,0,99,0,18,0,21,0,26,0,66,0,99,0,99,0,99,0,99,0,24,0,26,0,56,0,99,0,99,0,99,0,99,0,99,0,47,0,66,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,99,0,16,0,16,0,16,0,20,0,24,0,28,0,32,0,40,0,16,0,16,0,20,0,24,0,28,0,32,0,40,0,48,0,16,0,20,0,24,0,28,0,32,0,40,0,48,0,64,0,20,0,24,0,28,0,32,0,40,0,48,0,64,0,64,0,24,0,28,0,32,0,40,0,48,0,64,0,64,0,64,0,28,0,32,0,40,0,48,0,64,0,64,0,64,0,96,0,32,0,40,0,48,0,64,0,64,0,64,0,96,0,128,0,40,0,48,0,64,0,64,0,64,0,96,0,128,0,128,0,30,25,20,20,15,15,14,14,13,13,12,12,11,11,10,10,9,9,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,200,0,190,0,180,0,170,0,170,0,160,0,160,0,150,0,150,0,140,0,140,0,130,0,130,0,120,0,120,0,110,0,110,0,100,0,100,0,90,0,90,0,90,0,80,0,80,0,80,0,70,0,70,0,70,0,60,0,60,0,60,0,60,0,50,0,50,0,50,0,50,0,40,0,40,0,40,0,40,0,40,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,20,0,20,0,20,0,20,0,20,0,20,0,20,0,20,0,10,0,10,0,10,0,10,0,10,0,10,0,10,0,244,1,0,0,194,1,0,0,144,1,0,0,114,1,0,0,84,1,0,0,54,1,0,0,29,1,0,0,9,1,0,0,245,0,0,0,225,0,0,0,210,0,0,0,195,0,0,0,185,0,0,0,180,0,0,0,170,0,0,0,160,0,0,0,150,0,0,0,145,0,0,0,135,0,0,0,130,0,0,0,125,0,0,0,115,0,0,0,110,0,0,0,107,0,0,0,100,0,0,0,96,0,0,0,93,0,0,0,89,0,0,0,85,0,0,0,82,0,0,0,75,0,0,0,74,0,0,0,70,0,0,0,68,0,0,0,64,0,0,0,60,0,0,0,57,0,0,0,56,0,0,0,52,0,0,0,50,0,0,0,49,0,0,0,45,0,0,0,44,0,0,0,43,0,0,0,40,0,0,0,38,0,0,0,37,0,0,0,35,0,0,0,33,0,0,0,32,0,0,0,30,0,0,0,29,0,0,0,28,0,0,0,25,0,0,0,24,0,0,0,22,0,0,0,21,0,0,0,19,0,0,0,18,0,0,0,17,0,0,0,15,0,0,0,13,0,0,0,12,0,0,0,10,0,0,0,0,1,128,0,86,0,64,0,248,51,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,51,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,22,34,0,144,41,37,0,48,0,0,0,5,0,0,0,144,3,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,88,217,36,0,112,186,36,0,40,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,8,0,1,0,88,217,36,0,248,242,32,0,248,156,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,88,217,36,0,16,144,32,0,224,129,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,88,217,36,0,56,52,32,0,8,104,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,88,217,36,0,96,76,36,0,0,53,36,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,96,76,36,0,144,11,36,0,128,215,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,96,76,36,0,240,190,35,0,32,168,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,96,76,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,22,34,0,112,0,0,0,216,222,3,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,38,0,112,0,0,0,160,117,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,0,32,0,48,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,176,0,192,0,208,0,224,0,240,0,0,1,16,1,32,1,48,1,64,1,80,1,96,1,112,1,128,1,144,1,160,1,176,1,192,1,208,1,224,1,240,1,0,2,8,2,16,2,24,2,32,2,40,2,48,2,56,2,64,2,72,2,80,2,88,2,96,2,104,2,112,2,120,2,128,2,136,2,144,2,152,2,160,2,168,2,176,2,184,2,192,2,200,2,208,2,216,2,224,2,232,2,240,2,248,2,0,3,8,3,16,3,24,3,32,3,40,3,48,3,56,3,64,3,72,3,80,3,88,3,96,3,104,3,112,3,120,3,128,3,136,3,144,3,152,3,160,3,168,3,176,3,184,3,192,3,200,3,208,3,216,3,224,3,232,3,240,3,248,3,0,4,64,4,128,4,192,4,0,5,64,5,128,5,192,5,0,6,64,6,128,6,192,6,0,7,64,7,128,7,192,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,20,0,24,0,28,0,32,0,48,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,253,3,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,7,250,6,251,5,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,241,15,242,14,243,13,244,12,245,11,246,10,247,9,248,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,225,31,226,30,227,29,228,28,229,27,230,26,231,25,232,24,233,23,234,22,235,21,236,20,237,19,238,18,239,17,240,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,193,63,194,62,195,61,196,60,197,59,198,58,199,57,200,56,201,55,202,54,203,53,204,52,205,51,206,50,207,49,208,48,209,47,210,46,211,45,212,44,213,43,214,42,215,41,216,40,217,39,218,38,219,37,220,36,221,35,222,34,223,33,224,32,129,127,130,126,131,125,132,124,133,123,134,122,135,121,136,120,137,119,138,118,139,117,140,116,141,115,142,114,143,113,144,112,145,111,146,110,147,109,148,108,149,107,150,106,151,105,152,104,153,103,154,102,155,101,156,100,157,99,158,98,159,97,160,96,161,95,162,94,163,93,164,92,165,91,166,90,167,89,168,88,169,87,170,86,171,85,172,84,173,83,174,82,175,81,176,80,177,79,178,78,179,77,180,76,181,75,182,74,183,73,184,72,185,71,186,70,187,69,188,68,189,67,190,66,191,65,192,64,24,0,1,4,5,7,3,2,6,8,0,0,0,0,0,0,5,4,3,3,3,3,3,3,3,5,0,0,0,0,0,0,60,6,0,1,3,2,4,12,28,0,0,0,0,0,0,0,6,3,3,2,2,3,4,5,6,0,0,0,0,0,0,0,234,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,3,234,0,42,0,26,0,6,0,1,0,0,0,2,0,10,0,106,0,234,1,234,7,12,0,0,0,0,0,0,0,0,0,0,0,11,9,7,5,3,1,2,4,6,8,10,12,100,6,0,0,0,0,0,0,0,0,0,0,100,0,228,0,164,0,104,0,4,0,8,0,20,0,24,0,0,0,1,0,2,0,3,0,12,0,40,0,36,0,100,1,0,0,100,2,11,0,0,0,0,0,10,8,8,7,6,6,5,5,4,2,2,2,4,7,8,9,0,11,20,87,12,0,2,0,1,0,0,0,4,0,52,0,84,0,148,0,20,0,20,1,20,2,20,3,20,6,20,14,20,15,20,39,20,7,20,23,20,55,15,4,2,1,3,5,6,7,8,10,10,11,11,12,12,12,14,14,15,14,0,0,0,0,31,0,1,3,7,15,0,0,5,1,2,3,4,5,0,0,124,3,4,0,60,0,76,0,58,0,44,0,28,0,26,0,36,0,20,0,1,0,2,0,0,0,3,0,7,0,5,0,6,0,8,0,9,0,10,0,12,0,252,0,124,0,124,1,10,6,7,7,6,6,6,6,6,5,4,4,4,3,3,3,3,4,4,5,7,8,9,10,130,82,22,0,0,0,54,1,4,0,0,0,7,0,10,0,14,0,3,0,1,0,13,0,6,0,9,0,18,0,5,0,37,0,34,0,21,0,2,0,118,0,53,0,66,0,194,0,130,1,182,0,54,0,194,3,130,4,194,1,130,6,130,8,130,10,130,0,130,2,130,18,130,50,130,34,0,0,0,0,15,6,0,9,3,3,3,4,4,3,4,4,5,4,5,6,6,6,6,8,7,6,8,9,9,8,9,10,11,10,11,12,12,12,14,15,14,14,0,0,234,51,5,0,0,0,12,0,0,0,6,0,3,0,8,0,2,0,1,0,4,0,7,0,26,0,15,0,28,0,44,0,10,0,29,0,45,0,42,0,13,0,76,0,140,0,106,0,205,0,77,0,234,0,12,2,12,3,12,1,234,1,234,7,234,11,234,3,234,19,0,0,14,4,0,10,4,3,3,4,4,3,4,4,5,4,5,6,6,5,6,7,7,7,8,8,8,8,9,10,10,10,10,11,12,13,14,0,0,0,0,0,96,23,1,0,0,0,130,0,12,0,6,0,3,0,7,0,8,0,4,0,16,0,18,0,34,0,26,0,0,0,32,0,10,0,64,0,74,0,106,0,42,0,66,0,2,0,96,0,170,0,224,0,194,0,194,1,96,1,96,3,96,7,96,15,13,2,0,8,4,3,3,3,4,4,5,5,6,5,7,7,7,7,7,7,8,8,8,9,8,8,9,9,10,11,13,12,164,7,1,0,32,0,18,0,28,0,8,0,6,0,16,0,0,0,20,0,4,0,50,0,112,0,12,0,2,0,58,0,26,0,44,0,42,0,34,0,36,0,10,0,100,0,48,0,98,0,164,0,164,1,164,3,11,1,6,6,5,4,3,6,6,5,6,6,7,6,6,6,6,6,6,7,8,6,7,7,7,9,10,11,0,0,0,0,142,3,1,0,0,0,34,0,10,0,6,0,18,0,2,0,30,0,62,0,86,0,22,0,14,0,50,0,114,0,66,0,142,0,78,0,242,0,46,0,54,0,194,0,142,1,0,0,10,1,2,6,4,5,6,7,6,6,7,7,8,7,8,8,9,7,8,6,6,8,10,0,87,28,4,0,0,0,1,0,3,0,2,0,15,0,14,0,7,0,22,0,55,0,39,0,38,0,102,0,6,0,151,0,70,0,198,1,23,0,134,7,134,0,87,2,215,0,87,3,198,0,134,3,134,1,0,0,87,1,87,12,87,0,0,0,134,11,0,0,87,20,0,0,87,4,0,0,0,0,0,0,13,3,3,2,3,3,4,4,6,5,6,6,7,7,8,8,8,9,8,11,9,10,8,10,9,12,10,0,10,13,11,0,12,0,13,0,13,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+245760);
/* memory initializer */ allocate([8,0,0,0,10,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,36,0,0,0,44,0,0,0,52,0,0,0,60,0,0,0,76,0,0,0,92,0,0,0,108,0,0,0,124,0,0,0,156,0,0,0,188,0,0,0,220,0,0,0,252,0,0,0,60,1,0,0,124,1,0,0,188,1,0,0,252,1,0,0,124,2,0,0,252,2,0,0,124,3,0,0,252,3,0,0,252,4,0,0,252,5,0,0,252,6,0,0,252,7,0,0,252,9,0,0,252,11,0,0,252,13,0,0,252,15,0,0,252,19,0,0,252,23,0,0,252,27,0,0,252,31,0,0,252,39,0,0,252,47,0,0,252,55,0,0,252,63,0,0,252,79,0,0,252,95,0,0,252,111,0,0,252,127,0,0,252,159,0,0,252,191,0,0,252,223,0,0,252,255,0,0,252,63,1,0,252,127,1,0,252,191,1,0,0,0,128,2,160,4,212,6,250,8,122,9,250,9,250,11,250,13,10,16,10,18,76,20,76,22,0,0,0,0,0,0,0,0,0,0,128,2,0,0,132,4,0,0,196,6,0,0,4,9,0,0,36,11,0,0,68,13,0,0,84,15,0,0,100,17,0,0,100,20,0,0,228,22,0,0,228,25,0,0,100,28,0,0,228,30,0,0,232,32,0,0,232,34,0,0,40,37,0,0,0,0,0,0,0,0,8,2,40,2,104,2,104,4,136,4,200,4,204,6,236,6,44,7,108,7,132,9,170,11,234,11,26,14,58,16,122,16,138,18,206,20,14,21,14,23,154,25,234,29,150,32,88,36,4,39,134,41,226,43,142,47,206,50,248,52,152,55,194,57,72,60,222,63,114,68,148,79,58,85,58,87,122,87,126,90,126,92,190,92,244,96,244,98,52,99,92,103,100,105,168,105,200,107,208,107,216,107,224,107,232,107,64,110,98,110,130,110,130,112,162,112,194,112,194,114,228,114,4,115,8,117,42,117,74,117,74,119,108,119,140,119,144,121,178,121,210,121,226,123,2,124,34,124,50,126,84,126,116,126,0,0,0,0,184,125,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,94,39,0,176,16,39,0,20,0,0,0,5,0,0,0,88,205,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,137,38,0,176,16,39,0,20,0,0,0,5,0,0,0,88,205,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,32,78,38,0,232,22,38,0,36,0,0,0,5,0,0,0,56,236,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,72,191,37,0,224,157,37,0,52,0,0,0,5,0,0,0,224,109,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,8,46,37,0,184,6,37,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,8,46,37,0,32,223,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,8,46,37,0,248,188,36,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,8,46,37,0,224,159,36,0,144,132,36,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,224,159,36,0,96,106,36,0,248,77,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,159,36,0,152,54,36,0,16,17,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,159,36,0,112,219,35,0,176,192,35,0,148,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,184,169,35,0,168,147,35,0,152,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,125,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,90,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,34,0,112,0,0,0,96,234,3,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,48,132,38,0,208,2,0,0,224,1,0,0,96,128,38,0,208,2,0,0,64,2,0,0,208,124,38,0,96,1,0,0,240,0,0,0,160,120,38,0,96,1,0,0,32,1,0,0,240,115,38,0,128,2,0,0,224,1,0,0,144,112,38,0,0,3,0,0,64,2,0,0,8,106,38,0,96,1,0,0,240,0,0,0,152,90,38,0,96,1,0,0,240,0,0,0,176,82,38,0,128,0,0,0,96,0,0,0,40,78,38,0,176,0,0,0,144,0,0,0,96,73,38,0,96,1,0,0,32,1,0,0,224,70,38,0,192,2,0,0,64,2,0,0,16,67,38,0,128,5,0,0,128,4,0,0,240,63,38,0,160,0,0,0,120,0,0,0,224,59,38,0,64,1,0,0,240,0,0,0,152,56,38,0,128,2,0,0,224,1,0,0,128,51,38,0,32,3,0,0,88,2,0,0,120,37,38,0,0,4,0,0,0,3,0,0,96,27,38,0,64,6,0,0,176,4,0,0,40,23,38,0,0,8,0,0,0,6,0,0,216,18,38,0,0,5,0,0,0,4,0,0,120,14,38,0,0,10,0,0,0,8,0,0,224,10,38,0,0,20,0,0,0,16,0,0,160,7,38,0,84,3,0,0,224,1,0,0,88,5,38,0,86,5,0,0,0,3,0,0,112,3,38,0,64,6,0,0,0,4,0,0,144,255,37,0,128,7,0,0,176,4,0,0,240,243,37,0,0,10,0,0,64,6,0,0,144,239,37,0,128,12,0,0,0,8,0,0,64,236,37,0,0,15,0,0,96,9,0,0,88,233,37,0,0,25,0,0,0,16,0,0,136,230,37,0,0,30,0,0,192,18,0,0,224,227,37,0,64,1,0,0,200,0,0,0,120,225,37,0,128,2,0,0,94,1,0,0,16,219,37,0,84,3,0,0,224,1,0,0,208,216,37,0,0,5,0,0,208,2,0,0,48,213,37,0,128,7,0,0,56,4,0,0,128,199,37,0,0,8,0,0,56,4,0,0,192,193,37,0,206,7,0,0,56,4,0,0,80,191,37,0,0,8,0,0,90,3,0,0,0,189,37,0,0,16,0,0,112,8,0,0,200,186,37,0,156,15,0,0,112,8,0,0,224,183,37,0,0,16,0,0,180,6,0,0,96,181,37,0,128,2,0,0,104,1,0,0,16,179,37,0,240,0,0,0,160,0,0,0,88,177,37,0,144,1,0,0,240,0,0,0,216,174,37,0,176,1,0,0,240,0,0,0,176,163,37,0,224,1,0,0,64,1,0,0,232,159,37,0,192,3,0,0,28,2,0,0,0,0,0,0,48,132,38,0,48,117,0,0,233,3,0,0,96,128,38,0,25,0,0,0,1,0,0,0,208,124,38,0,48,117,0,0,233,3,0,0,160,120,38,0,25,0,0,0,1,0,0,0,240,115,38,0,48,117,0,0,233,3,0,0,144,112,38,0,25,0,0,0,1,0,0,0,8,106,38,0,24,0,0,0,1,0,0,0,152,90,38,0,192,93,0,0,233,3,0,0,8,0,0,0,7,0,0,0,7,0,0,0,10,0,0,0,9,0,0,0,9,0,0,0,6,0,0,0,0,0,0,0,191,0,0,0,97,0,0,0,48,0,0,0,95,2,0,0,246,0,0,0,230,0,0,0,32,0,0,0,0,0,0,0,1,2,18,18,2,3,254,18,2,4,7,5,3,6,8,255,18,2,0,0,1,18,18,255,18,2,3,4,6,5,7,18,253,8,2,255,3,0,1,2,1,18,254,4,18,2,3,6,255,7,5,254,18,8,2,4,0,0,1,17,17,2,3,4,18,255,5,6,7,18,2,8,17,3,254,0,1,1,18,18,2,18,3,2,18,4,255,3,18,2,6,8,17,5,0,0,2,18,17,2,3,254,5,18,253,2,4,7,3,6,8,5,17,0,1,1,18,254,2,253,18,5,254,18,2,3,6,2,17,4,7,255,0,1,1,17,8,18,3,254,2,5,4,18,6,3,8,7,2,5,4,0,0,2,18,17,254,2,18,3,2,5,253,4,7,18,3,8,6,2,0,1,1,3,6,5,5,1,3,7,4,2,6,4,18,3,7,5,6,0,1,2,1,18,3,2,254,1,5,4,6,2,7,1,8,3,255,1,0,0,1,18,18,2,3,6,3,5,254,2,4,18,3,254,255,6,7,0,0,1,254,18,2,18,7,2,6,254,3,4,18,18,2,253,8,5,0,0,2,18,18,18,2,4,3,18,5,3,6,254,2,4,18,8,7,0,0,1,254,1,18,2,254,18,255,5,7,2,3,4,18,2,6,2,0,1,1,17,18,3,2,1,7,255,2,4,3,5,6,254,18,7,8,0,1,1,18,18,2,18,3,4,6,254,18,5,8,2,3,7,4,255,0,0,1,18,18,18,255,2,3,4,6,8,18,3,5,2,6,7,4,0,1,1,17,254,18,18,2,5,3,8,2,255,6,1,3,4,7,5,0,0,1,17,17,18,2,3,6,254,8,1,7,5,2,3,1,4,8,0,1,1,17,17,3,2,7,1,4,3,6,2,5,254,8,7,18,6,0,0,1,18,17,254,2,18,3,253,7,6,5,2,4,255,8,3,17,0,1,1,2,18,18,254,2,4,255,5,18,3,8,6,2,7,17,4,0,0,1,17,3,6,8,5,4,3,8,1,18,7,2,4,5,6,3,0,1,2,17,18,4,8,3,2,5,7,6,8,2,7,254,18,3,4,0,1,1,6,5,5,3,4,7,3,2,4,6,3,7,1,5,2,4,0,1,1,1,18,255,2,1,3,8,254,2,5,6,3,8,7,18,4,0,0,1,1,17,255,18,3,2,5,4,6,7,8,3,4,2,1,254,0,0,1,18,2,18,18,2,18,6,254,18,7,5,4,3,2,18,254,0,0,3,1,4,18,3,2,4,1,5,2,3,6,18,8,7,2,4,0,0,1,17,254,1,253,2,18,3,254,4,18,3,6,7,253,2,8,0,1,1,17,18,18,4,2,3,7,6,18,8,5,255,4,2,3,17,0,1,2,18,255,17,18,2,3,254,18,5,8,2,4,3,7,6,255,0,1,1,18,18,18,254,4,2,3,18,5,8,2,4,6,7,254,3,0,1,2,18,18,254,18,255,3,2,5,18,254,7,2,3,4,6,8,0,0,1,17,18,255,2,4,18,8,3,6,5,7,253,2,4,3,17,0,1,1,18,18,17,2,255,18,3,2,18,6,5,4,18,7,2,255,0,0,2,1,18,255,18,3,2,4,6,253,7,255,5,1,2,3,8,0,1,1,1,17,254,2,253,6,3,5,1,2,7,6,8,254,4,1,0,0,1,17,255,5,1,4,3,6,2,254,18,3,2,4,5,8,255,0,0,2,18,18,17,2,3,254,5,18,2,4,7,8,6,17,3,5,0,1,1,1,5,1,3,4,3,7,5,1,3,6,1,2,4,3,8,0,1,2,1,255,3,2,18,7,254,5,2,6,4,3,255,18,8,7,0,0,2,18,17,3,18,2,5,4,3,6,2,7,8,18,3,4,5,0,1,1,3,6,17,8,7,5,18,255,1,2,3,4,2,6,8,1,0,0,2,18,18,3,253,18,2,6,5,3,7,18,4,254,8,2,3,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,1,7,2,3,18,254,3,6,4,2,7,8,5,3,17,0,1,1,3,6,5,5,1,3,7,4,2,6,4,18,3,7,5,6,0,0,1,18,18,18,2,4,255,18,8,255,2,3,4,6,254,1,7,0,1,1,18,254,17,18,2,6,3,254,5,4,7,1,253,8,2,6,0,0,1,17,18,18,4,2,7,3,6,254,18,8,4,5,2,7,17,0,1,1,18,18,5,4,6,4,1,5,4,3,2,5,6,1,4,5,0,0,1,18,18,254,18,2,253,3,8,5,18,6,4,3,255,7,2,0,1,1,18,2,254,253,18,5,2,3,254,4,6,1,253,2,7,8,0,0,1,18,3,5,8,2,6,7,3,1,5,2,255,8,6,7,4,0,1,1,4,3,8,1,5,6,2,5,8,254,2,7,3,18,5,4,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,3,18,18,7,2,4,18,6,2,3,255,8,5,18,253,0,0,1,3,17,18,2,18,6,7,253,18,2,5,6,3,8,7,255,0,1,1,18,18,2,18,18,2,255,7,3,18,5,2,6,4,255,18,0,0,3,18,3,4,1,5,2,18,4,2,3,18,7,6,1,2,4,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,1,18,2,3,6,4,5,7,18,3,8,2,4,254,17,0,1,2,18,17,2,3,5,18,6,254,7,3,2,4,18,8,255,5,0,0,2,1,18,255,18,3,2,4,6,253,7,255,5,1,2,3,8,0,1,1,1,18,255,8,2,6,3,254,1,2,5,4,253,8,6,3,0,0,1,18,18,2,18,2,18,7,6,18,2,254,3,5,4,18,8,0,1,2,18,17,2,3,18,255,2,3,6,18,5,4,3,7,2,8,0,1,2,18,18,3,254,4,18,5,7,6,2,4,253,8,5,18,3,0,1,1,17,254,18,18,2,5,3,8,2,255,6,1,3,4,7,5,0,1,1,3,17,18,5,7,2,4,6,1,8,255,3,7,4,1,2,0,0,2,1,254,2,18,3,5,2,4,7,255,2,3,5,18,254,4,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,1,2,254,6,18,253,2,7,3,254,5,6,1,8,2,4,0,0,1,18,18,18,3,254,6,18,2,4,3,5,8,7,6,2,254,0,1,1,1,5,1,3,4,3,7,5,1,3,6,1,2,4,3,8,0,0,1,3,17,18,2,5,18,6,7,5,254,2,4,18,3,6,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,17,255,18,2,4,255,8,3,18,7,253,4,5,1,2,254,0,0,1,255,18,18,2,18,3,5,18,2,18,8,6,4,5,7,255,0,1,1,18,18,3,6,4,8,254,2,5,3,7,18,6,8,4,2,0,1,1,17,18,18,254,5,2,3,1,4,255,8,6,5,3,2,18,0,1,1,17,17,1,2,4,5,2,6,255,3,1,1,254,4,2,7,0,1,1,17,1,7,2,3,18,254,3,6,4,2,7,8,5,3,17,0,0,1,18,17,254,253,1,2,3,2,5,4,7,253,6,254,2,1,0,1,1,1,3,5,18,1,2,7,3,6,2,5,8,255,1,4,7,0,1,1,17,3,6,8,1,4,5,3,254,7,2,8,5,6,18,3,0,1,1,17,18,2,4,8,254,3,1,5,6,7,1,2,3,4,7,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,3,1,8,18,5,2,3,18,6,7,254,4,3,2,8,18,0,0,1,18,17,2,18,3,4,255,18,7,6,2,8,4,18,18,5,0,0,1,18,18,2,18,18,2,7,254,6,5,4,3,18,3,2,17,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,8,18,3,2,1,5,4,6,255,3,253,8,18,7,2,0,1,2,18,17,18,2,3,5,254,18,6,255,2,3,7,4,8,17,0,0,1,255,18,18,2,18,3,5,18,2,18,8,6,4,5,7,255,0,1,2,18,18,254,17,2,18,3,4,18,8,7,255,2,4,5,17,0,0,2,17,253,17,3,2,254,18,8,4,253,2,18,5,3,254,6,0,0,1,18,18,2,18,18,2,7,254,6,5,4,3,18,3,2,17,0,0,2,1,18,255,3,5,2,253,18,7,3,255,6,4,2,17,5,0,1,1,17,254,17,2,253,1,5,255,4,6,3,2,8,7,254,5,0,1,1,1,18,1,3,5,8,6,2,3,255,7,1,4,8,5,253,0,0,2,3,18,18,2,18,254,6,5,7,2,4,18,3,6,253,5,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,3,6,17,8,7,5,18,255,1,2,3,4,2,6,8,1,0,0,4,18,2,17,3,18,254,2,6,18,2,7,3,5,4,8,18,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,18,18,2,3,6,3,5,254,2,4,18,3,254,255,6,7,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,1,2,5,3,254,1,4,3,7,6,253,2,1,1,2,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,18,18,254,18,254,2,3,6,18,4,255,2,3,8,1,4,0,1,1,17,254,17,2,253,1,5,255,4,6,3,2,8,7,254,5,0,0,1,17,17,18,3,2,18,18,6,8,2,254,3,5,4,17,18,0,1,1,1,5,1,3,4,3,7,5,1,3,6,1,2,4,3,8,0,1,1,1,3,253,18,18,6,5,18,2,255,3,8,7,253,4,17,0,1,1,18,1,2,1,3,8,7,4,1,5,2,255,253,18,6,2,0,0,1,18,3,5,2,6,8,18,5,7,2,3,255,6,7,8,5,0,0,2,18,3,254,7,8,2,5,4,253,8,3,2,18,5,4,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,3,1,1,2,5,2,7,4,3,255,18,254,8,2,1,6,7,0,0,1,3,17,18,5,2,6,7,18,4,5,3,6,18,2,7,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,1,18,1,2,3,5,1,2,6,7,4,3,8,1,17,5,0,1,2,17,255,18,254,2,3,5,18,2,4,6,7,3,255,5,8,0,1,1,18,18,253,18,254,2,3,254,18,6,4,5,8,3,17,253,0,1,1,18,7,6,5,5,3,1,4,2,7,3,4,253,6,18,8,0,0,2,18,18,2,3,5,18,2,4,3,6,18,7,8,255,5,2,0,0,1,18,17,255,2,18,3,2,18,4,3,18,2,6,5,8,17,0,0,2,18,17,2,3,18,5,255,6,7,8,2,3,4,5,18,6,0,1,2,18,253,18,2,3,254,253,5,18,7,6,2,4,3,8,254,0,1,1,17,18,18,254,2,3,5,4,8,18,255,5,3,6,254,7,0,1,2,18,17,2,254,18,3,255,4,18,2,7,5,3,8,6,4,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,1,5,1,3,4,3,7,5,1,3,6,1,2,4,3,8,0,0,2,18,18,3,3,254,2,5,18,6,3,255,4,7,255,1,2,0,0,1,254,1,18,2,254,5,7,18,3,2,6,2,255,4,254,17,0,0,2,18,18,18,2,3,254,18,5,4,2,6,8,3,254,4,18,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,18,255,3,2,5,1,3,2,8,4,7,6,2,255,5,0,1,1,17,18,18,4,2,3,7,6,18,8,5,255,4,2,3,17,0,0,1,18,18,254,18,2,3,4,5,6,18,8,2,3,7,254,4,0,0,1,18,254,18,18,253,254,2,3,5,8,1,2,6,4,7,255,0,0,1,18,17,2,18,3,254,2,7,6,4,18,3,8,7,4,2,0,1,1,17,18,18,4,2,3,7,6,18,8,5,255,4,2,3,17,0,1,1,18,17,18,2,5,3,254,18,6,2,3,4,8,7,5,255,0,0,1,2,255,18,255,2,4,253,18,5,3,6,18,2,4,7,8,0,1,1,17,18,8,3,6,4,255,5,2,7,3,8,6,5,18,4,0,0,2,18,3,254,7,8,2,5,4,253,8,3,2,18,5,4,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,1,18,255,8,2,6,3,254,1,2,5,4,253,8,6,3,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,17,18,18,4,2,7,3,6,254,18,8,4,5,2,7,17,0,1,2,18,255,18,3,254,18,2,5,3,6,7,2,255,18,8,4,0,1,2,1,18,254,4,18,2,3,6,255,7,5,254,18,8,2,4,0,1,2,1,18,253,2,3,18,255,5,6,2,8,3,4,1,254,7,0,0,1,1,17,255,18,3,2,5,4,6,7,8,3,4,2,1,254,0,1,1,18,17,18,4,3,5,1,2,6,3,4,7,1,8,5,2,0,0,1,18,254,7,1,3,2,253,4,6,254,7,8,1,5,4,3,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,18,18,18,254,2,5,3,7,18,2,4,253,5,6,3,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,3,3,18,255,5,2,7,18,6,5,2,4,3,255,7,18,6,0,0,2,18,18,18,4,3,2,6,4,8,18,5,3,2,7,254,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,18,18,18,2,3,254,18,5,4,2,6,8,3,254,4,18,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,8,18,3,2,1,5,4,6,255,3,253,8,18,7,2,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,18,2,4,6,254,2,8,3,4,18,7,255,6,0,0,1,18,1,254,2,4,1,3,255,2,5,7,1,6,8,254,17,0,0,1,17,17,18,2,5,4,18,3,8,7,4,6,8,1,5,2,0,1,2,18,18,5,4,6,3,4,18,8,4,255,7,5,3,6,2,0,0,1,18,18,253,18,3,6,2,5,7,18,3,8,255,4,5,2,0,1,1,18,2,254,253,18,5,2,254,4,3,6,18,8,255,2,7,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,1,7,2,3,18,254,3,6,4,2,7,8,5,3,17,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,17,18,3,18,2,5,4,7,253,6,3,2,18,4,7,3,0,1,1,1,7,4,5,3,4,5,1,3,6,3,2,4,8,254,7,0,0,1,1,18,255,254,18,3,2,255,6,7,4,5,3,18,2,253,0,1,1,18,18,255,3,6,18,5,4,8,2,3,6,18,7,4,254,0,0,2,18,18,2,6,18,2,18,5,3,18,2,4,7,8,3,18,0,1,1,3,18,18,5,18,6,2,4,7,254,18,5,8,6,3,2,0,0,1,18,254,7,1,3,2,253,4,6,254,7,8,1,5,4,3,0,1,1,18,254,18,2,5,18,3,254,4,7,2,255,8,6,5,1,0,1,1,17,17,5,18,4,1,2,8,6,4,254,3,5,255,1,8,0,0,2,1,2,17,3,7,18,2,255,4,5,18,2,7,3,6,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,3,6,17,8,7,5,18,255,1,2,3,4,2,6,8,1,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,18,18,18,2,254,3,6,4,8,18,2,5,7,4,3,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,18,1,8,3,5,6,4,255,8,3,7,18,2,5,8,4,0,1,1,17,18,5,2,4,3,1,6,254,1,3,2,4,5,255,17,0,1,1,18,17,2,18,3,253,7,2,6,4,3,5,18,8,2,254,0,1,1,18,17,18,4,3,5,255,18,2,7,8,4,6,3,18,5,0,0,1,18,17,18,254,2,253,3,4,8,5,2,18,6,3,7,254,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,17,18,8,3,4,6,18,5,254,3,8,5,2,4,7,6,0,0,1,18,254,3,5,1,7,3,2,6,253,4,1,5,8,3,254,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,3,17,18,5,255,18,2,6,7,18,5,3,253,255,6,2,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,3,18,17,254,3,255,18,2,5,3,7,6,2,4,8,18,5,0,0,1,18,255,18,2,18,3,5,18,2,8,18,5,4,255,6,2,0,1,2,18,254,18,18,2,3,4,253,2,5,18,7,4,3,8,6,0,0,2,17,255,18,2,255,1,7,3,8,5,254,4,1,2,253,6,0,0,1,18,17,2,18,2,18,6,7,4,3,18,5,2,254,17,8,0,0,3,18,17,2,3,253,255,18,2,4,5,18,7,3,2,253,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,2,3,18,18,18,2,6,5,18,7,2,4,6,18,5,3,8,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,18,18,3,6,3,254,2,18,5,255,7,3,4,254,2,6,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,1,1,18,17,18,18,254,2,3,253,18,6,4,2,254,8,3,7,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,18,18,18,4,2,7,8,18,3,2,254,4,7,6,17,5,0,1,1,18,18,255,254,8,3,18,6,3,5,8,2,4,7,1,6,0,1,1,1,253,3,18,18,2,255,3,6,5,18,4,7,254,8,3,0,1,1,1,18,4,2,5,18,1,3,255,6,1,4,8,2,5,1,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,1,255,18,18,2,18,3,5,18,2,18,6,8,4,5,7,255,0,0,10,10,10,10,16,16,16,28,16,16,29,42,49,20,49,59,25,26,26,27,31,33,33,33,34,34,37,67,38,39,39,40,40,41,79,43,44,45,45,48,48,64,50,51,52,88,52,53,74,55,57,58,58,74,60,101,61,62,84,66,66,68,69,87,82,71,97,73,73,82,75,111,77,94,78,87,81,83,97,85,83,94,86,99,89,90,99,111,92,93,134,95,98,105,98,105,110,102,108,102,118,103,106,106,113,109,112,114,112,116,125,115,116,117,117,126,119,125,121,121,123,145,124,126,131,127,129,165,130,132,138,133,135,145,136,137,139,146,141,143,142,144,148,147,155,151,149,151,150,152,157,153,154,156,168,158,162,161,160,172,163,169,164,166,184,167,170,177,174,171,173,182,176,180,178,175,189,179,181,186,183,192,185,200,187,191,188,190,197,193,196,197,194,195,196,198,202,199,201,210,203,207,204,205,206,208,214,209,211,221,212,213,215,224,216,217,218,219,220,222,228,223,225,226,224,227,229,240,230,231,232,233,234,235,236,238,239,237,242,241,243,242,244,245,246,247,248,249,250,251,252,252,253,254,255,4,2,3,1,4,1,2,3,25,0,39,0,242,0,186,3,48,9,103,18,49,0,48,0,151,0,33,2,139,5,36,1,235,0,212,1,216,3,132,5,100,3,95,4,102,15,49,9,205,36,47,0,57,0,232,0,195,2,138,7,55,0,41,0,132,0,177,1,237,0,134,0,249,0,171,3,235,1,188,8,30,1,243,0,32,2,138,5,236,0,142,0,43,1,234,1,25,1,176,4,177,4,184,3,145,6,101,3,237,1,154,4,169,14,168,14,189,8,204,36,38,0,53,0,219,0,196,2,178,7,56,0,43,0,127,0,179,1,244,0,145,0,22,1,187,3,21,2,50,9,45,0,42,0,138,0,222,1,40,0,32,0,92,0,144,0,104,0,238,1,233,0,141,0,42,1,135,0,93,0,24,1,73,3,239,1,227,1,185,8,240,0,211,0,20,2,155,4,218,0,137,0,37,1,23,2,45,1,144,6,148,0,125,0,31,1,126,0,89,0,39,1,165,1,17,1,248,0,93,4,185,3,89,2,128,5,193,2,223,1,133,5,22,2,99,1,176,1,196,3,184,8,139,7,85,7,129,5,103,15,0,0,0,0,5,6,8,10,12,13,6,6,8,10,11,9,8,9,10,11,10,11,12,12,14,6,6,8,10,11,6,6,8,9,8,8,8,10,9,12,9,8,10,11,8,8,9,9,9,11,11,10,11,10,9,11,12,12,12,14,6,6,8,10,11,6,6,7,9,8,8,9,10,10,12,6,6,8,9,6,6,7,8,7,9,8,8,9,8,7,9,10,9,9,12,8,8,10,11,8,8,9,10,9,11,8,7,9,7,7,9,9,9,8,11,10,10,11,10,9,11,10,9,9,10,12,11,11,11,12,1,0,85,0,28,0,26,0,43,0,40,0,103,0,139,0,57,0,112,1,13,1,165,2,71,0,100,4,151,6,35,5,203,8,27,0,14,0,0,0,16,0,18,0,54,0,72,0,76,0,194,0,155,0,113,1,59,0,36,2,74,3,214,2,25,0,15,0,2,0,20,0,23,0,6,0,93,0,84,0,199,0,180,0,146,1,14,1,51,2,67,0,44,0,15,0,19,0,6,0,47,0,44,0,104,0,119,0,223,0,17,1,164,1,106,1,164,2,39,0,17,0,24,0,45,0,15,0,74,0,64,0,151,0,31,0,27,1,34,0,109,1,102,0,53,0,5,0,43,0,73,0,9,0,117,0,203,0,170,0,135,1,6,1,138,0,71,0,96,0,110,0,29,0,116,0,196,0,30,0,24,1,167,1,56,0,66,0,83,0,118,0,168,0,202,0,130,0,16,1,141,1,45,1,185,0,200,0,222,0,28,0,171,0,19,1,140,1,15,1,154,0,165,0,183,0,26,1,134,1,166,1,89,2,83,1,138,1,147,1,32,0,12,1,70,0,58,0,7,1,73,1,108,1,215,2,37,2,88,2,22,3,150,6,23,3,66,0,34,5,144,2,202,8,1,0,0,0,0,0,0,0,7,6,6,6,7,7,8,9,9,10,10,11,11,11,12,12,6,4,5,5,6,6,7,8,8,9,9,10,10,10,11,6,4,5,5,6,7,7,8,8,9,9,10,10,11,6,5,5,6,6,7,7,8,8,9,9,10,10,7,6,6,6,7,7,8,8,9,9,10,10,7,6,7,7,7,8,8,8,9,9,10,8,7,7,7,8,8,8,9,9,9,9,8,8,8,8,8,9,9,9,9,8,8,8,9,9,9,9,10,9,9,9,9,9,9,10,9,9,9,10,10,11,10,10,10,10,11,10,10,10,11,10,11,12,11,12,3,0,0,0,0,0,0,0,26,0,3,0,23,0,16,0,12,0,9,0,5,0,0,0,13,0,10,0,9,0,12,0,15,0,2,0,4,0,7,0,11,0,15,0,28,0,6,0,16,0,21,0,28,0,34,0,59,0,14,0,25,0,35,0,52,0,54,0,58,0,71,0,8,0,10,0,30,0,49,0,55,0,80,0,83,0,107,0,111,0,140,0,232,0,234,0,235,0,22,0,62,0,63,0,108,0,137,0,138,0,163,0,164,0,212,0,221,0,236,0,238,0,26,1,210,1,36,0,37,0,46,0,39,0,194,0,192,0,218,0,219,0,17,1,68,1,22,1,74,1,69,1,184,1,171,1,218,1,222,1,219,1,223,1,54,2,55,2,166,3,167,3,77,0,76,0,94,0,95,0,131,1,130,1,134,1,33,2,135,1,32,2,46,2,47,2,150,2,84,3,151,2,85,3,114,3,115,3,22,0,0,0,0,0,0,0,7,6,5,5,5,5,5,5,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,5,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,232,225,37,0,112,0,0,0,160,117,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,12,0,0,0,255,37,15,4,3,1,0,0,0,0,255,36,14,6,3,1,0,0,0,0,255,26,13,3,1,0,0,0,0,0,255,43,15,3,1,0,0,0,0,0,255,20,6,1,0,0,0,0,0,0,255,40,1,0,0,0,0,0,0,0,255,16,14,2,0,0,0,0,0,0,255,30,28,3,0,0,0,0,0,0,6,5,4,4,3,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,9,5,4,4,3,3,3,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,4,4,3,3,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,4,3,3,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,8,3,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,4,3,3,2,2,2,2,2,2,2,2,2,2,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,119,0,0,0,99,0,0,0,85,0,0,0,81,0,0,0,67,0,0,0,58,0,0,0,126,0,0,0,109,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,2,9,2,10,2,11,2,12,3,1,3,2,3,3,3,4,3,5,3,6,3,7,3,8,3,9,3,10,3,11,4,1,4,2,4,3,4,4,4,5,4,6,5,1,5,2,5,3,5,4,5,5,6,1,6,2,6,3,6,4,7,1,7,2,7,3,7,4,8,1,8,2,8,3,8,4,9,1,9,2,9,3,9,4,10,1,10,2,10,3,11,1,11,2,11,3,12,1,12,2,12,3,13,1,13,2,13,3,14,1,14,2,14,3,15,1,15,2,15,3,16,1,16,2,17,1,17,2,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,0,1,0,2,0,3,0,4,0,5,0,6,1,1,1,2,1,3,1,4,1,5,2,1,2,2,2,3,2,4,3,1,3,2,3,3,3,4,4,1,4,2,4,3,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,3,1,3,2,3,3,3,4,3,5,3,6,3,7,4,1,4,2,4,3,4,4,4,5,5,1,5,2,5,3,5,4,5,5,6,1,6,2,6,3,6,4,7,1,7,2,7,3,7,4,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,10,3,11,1,11,2,11,3,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,16,2,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,1,1,1,2,1,3,1,4,1,5,2,1,2,2,2,3,2,4,3,1,3,2,3,3,3,4,4,1,4,2,4,3,5,1,5,2,5,3,6,1,6,2,6,3,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,3,1,3,2,3,3,3,4,3,5,3,6,3,7,4,1,4,2,4,3,4,4,4,5,5,1,5,2,5,3,5,4,6,1,6,2,6,3,6,4,7,1,7,2,7,3,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,10,3,11,1,11,2,11,3,12,1,12,2,12,3,13,1,13,2,13,3,14,1,14,2,15,1,15,2,16,1,17,1,18,1,19,1,20,1,0,1,0,2,0,3,0,4,1,1,1,2,1,3,1,4,2,1,2,2,2,3,3,1,3,2,3,3,4,1,4,2,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,2,1,2,2,2,3,2,4,2,5,3,1,3,2,3,3,3,4,4,1,4,2,4,3,4,4,5,1,5,2,5,3,5,4,6,1,6,2,6,3,7,1,7,2,7,3,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,10,3,11,1,11,2,11,3,12,1,12,2,12,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+256000);
/* memory initializer */ allocate([13,1,13,2,14,1,14,2,15,1,15,2,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,0,1,0,2,0,3,0,4,0,5,1,1,1,2,1,3,1,4,2,1,2,2,2,3,3,1,3,2,3,3,4,1,4,2,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,2,1,2,2,2,3,2,4,2,5,3,1,3,2,3,3,3,4,4,1,4,2,4,3,5,1,5,2,5,3,6,1,6,2,6,3,7,1,7,2,7,3,8,1,8,2,9,1,9,2,10,1,11,1,12,1,13,1,14,1,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,1,1,1,2,1,3,2,1,2,2,3,1,3,2,4,1,4,2,5,1,5,2,6,1,6,2,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,1,1,1,2,1,3,1,4,1,5,1,6,2,1,2,2,2,3,2,4,3,1,3,2,3,3,4,1,4,2,4,3,5,1,5,2,5,3,6,1,6,2,6,3,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,0,1,0,2,0,3,1,1,1,2,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,2,9,2,10,3,1,3,2,3,3,3,4,3,5,3,6,3,7,4,1,4,2,4,3,4,4,4,5,4,6,5,1,5,2,5,3,5,4,5,5,6,1,6,2,6,3,6,4,7,1,7,2,7,3,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,0,1,0,2,0,3,0,4,1,1,1,2,1,3,2,1,2,2,2,3,3,1,3,2,4,1,4,2,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,3,1,3,2,3,3,3,4,3,5,3,6,4,1,4,2,4,3,4,4,4,5,5,1,5,2,5,3,5,4,6,1,6,2,6,3,6,4,7,1,7,2,7,3,8,1,8,2,8,3,9,1,9,2,9,3,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,16,2,17,1,17,2,18,1,18,2,19,1,19,2,20,1,20,2,21,1,21,2,22,1,22,2,23,1,24,1,0,1,0,2,0,3,0,4,1,1,1,2,1,3,2,1,2,2,2,3,3,1,3,2,3,3,4,1,4,2,5,1,5,2,6,1,6,2,7,1,7,2,8,1,8,2,9,1,9,2,10,1,10,2,11,1,11,2,12,1,12,2,13,1,13,2,14,1,14,2,15,1,15,2,16,1,16,2,17,1,17,2,18,1,18,2,19,1,19,2,20,1,20,2,21,1,21,2,22,1,22,2,23,1,23,2,24,1,24,2,25,1,25,2,26,1,26,2,27,1,27,2,28,1,28,2,29,1,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,4,0,2,85,1,0,1,205,0,171,0,146,0,128,0,114,0,102,0,93,0,85,0,79,0,73,0,68,0,64,0,60,0,57,0,54,0,51,0,49,0,47,0,45,0,43,0,41,0,39,0,38,0,37,0,35,0,34,0,33,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,179,37,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,30,17,15,9,5,4,3,3,3,3,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,26,16,11,7,5,3,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,20,15,13,6,4,3,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,29,15,12,5,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,14,9,7,3,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,26,10,6,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,14,13,9,6,5,4,3,2,2,2,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,24,22,9,6,4,3,2,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,15,12,11,6,5,4,4,4,4,3,3,3,3,3,3,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,23,11,8,7,5,5,4,4,3,3,3,3,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,0,0,0,0,16,11,8,7,5,4,4,3,3,3,3,3,3,3,2,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,14,9,5,4,4,4,3,3,3,3,3,3,3,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,27,10,5,4,3,3,3,3,2,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,6,4,3,3,3,3,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,56,20,10,7,6,5,4,3,3,3,2,2,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,13,8,6,5,4,4,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,5,0,0,0,3,0,0,0,13,0,0,0,4,0,0,0,18,0,0,0,5,0,0,0,14,0,0,0,6,0,0,0,21,0,0,0,7,0,0,0,19,0,0,0,8,0,0,0,63,0,0,0,8,0,0,0,75,0,0,0,9,0,0,0,31,1,0,0,9,0,0,0,184,0,0,0,10,0,0,0,227,3,0,0,10,0,0,0,114,1,0,0,11,0,0,0,77,2,0,0,12,0,0,0,218,3,0,0,12,0,0,0,221,2,0,0,13,0,0,0,85,31,0,0,13,0,0,0,185,5,0,0,14,0,0,0,174,62,0,0,14,0,0,0,0,0,0,0,4,0,0,0,16,0,0,0,5,0,0,0,8,0,0,0,7,0,0,0,32,0,0,0,8,0,0,0,41,0,0,0,9,0,0,0,244,1,0,0,9,0,0,0,51,2,0,0,10,0,0,0,224,1,0,0,11,0,0,0,42,1,0,0,12,0,0,0,221,3,0,0,12,0,0,0,10,5,0,0,13,0,0,0,41,31,0,0,13,0,0,0,66,10,0,0,14,0,0,0,114,18,0,0,15,0,0,0,55,23,0,0,15,0,0,0,3,0,0,0,5,0,0,0,17,0,0,0,7,0,0,0,196,0,0,0,8,0,0,0,75,0,0,0,10,0,0,0,180,0,0,0,11,0,0,0,212,7,0,0,11,0,0,0,69,3,0,0,12,0,0,0,215,2,0,0,13,0,0,0,191,7,0,0,13,0,0,0,56,9,0,0,14,0,0,0,187,11,0,0,14,0,0,0,94,9,0,0,15,0,0,0,19,0,0,0,5,0,0,0,120,0,0,0,7,0,0,0,105,0,0,0,9,0,0,0,50,2,0,0,10,0,0,0,97,4,0,0,11,0,0,0,236,3,0,0,12,0,0,0,32,5,0,0,13,0,0,0,42,31,0,0,13,0,0,0,80,62,0,0,14,0,0,0,81,62,0,0,14,0,0,0,134,20,0,0,15,0,0,0,12,0,0,0,6,0,0,0,36,0,0,0,9,0,0,0,148,0,0,0,11,0,0,0,192,8,0,0,12,0,0,0,9,15,0,0,14,0,0,0,240,30,0,0,15,0,0,0,61,0,0,0,6,0,0,0,83,0,0,0,9,0,0,0,160,1,0,0,11,0,0,0,214,2,0,0,13,0,0,0,8,15,0,0,14,0,0,0,19,0,0,0,7,0,0,0,124,0,0,0,9,0,0,0,193,7,0,0,11,0,0,0,172,4,0,0,14,0,0,0,27,0,0,0,7,0,0,0,160,0,0,0,10,0,0,0,68,3,0,0,12,0,0,0,121,15,0,0,14,0,0,0,121,0,0,0,7,0,0,0,225,3,0,0,10,0,0,0,212,2,0,0,13,0,0,0,6,35,0,0,14,0,0,0,33,0,0,0,8,0,0,0,60,2,0,0,10,0,0,0,174,15,0,0,12,0,0,0,222,35,0,0,14,0,0,0,53,0,0,0,8,0,0,0,117,1,0,0,11,0,0,0,179,7,0,0,13,0,0,0,197,0,0,0,8,0,0,0,116,1,0,0,11,0,0,0,133,7,0,0,13,0,0,0,72,0,0,0,9,0,0,0,163,1,0,0,11,0,0,0,158,4,0,0,13,0,0,0,44,0,0,0,9,0,0,0,250,0,0,0,10,0,0,0,214,7,0,0,11,0,0,0,146,0,0,0,10,0,0,0,204,5,0,0,13,0,0,0,241,30,0,0,15,0,0,0,163,0,0,0,10,0,0,0,237,3,0,0,12,0,0,0,62,9,0,0,14,0,0,0,226,1,0,0,11,0,0,0,115,18,0,0,15,0,0,0,196,7,0,0,11,0,0,0,135,20,0,0,15,0,0,0,145,2,0,0,12,0,0,0,147,2,0,0,12,0,0,0,138,15,0,0,12,0,0,0,9,5,0,0,13,0,0,0,8,5,0,0,13,0,0,0,141,7,0,0,13,0,0,0,190,7,0,0,13,0,0,0,140,7,0,0,13,0,0,0,174,4,0,0,14,0,0,0,186,11,0,0,14,0,0,0,7,35,0,0,14,0,0,0,154,11,0,0,14,0,0,0,54,23,0,0,15,0,0,0,14,0,0,0,4,0,0,0,69,0,0,0,7,0,0,0,243,1,0,0,9,0,0,0,122,4,0,0,11,0,0,0,220,5,0,0,13,0,0,0,223,35,0,0,14,0,0,0,25,0,0,0,5,0,0,0,40,0,0,0,9,0,0,0,118,1,0,0,11,0,0,0,157,4,0,0,13,0,0,0,221,35,0,0,14,0,0,0,48,0,0,0,6,0,0,0,162,0,0,0,10,0,0,0,239,2,0,0,12,0,0,0,184,5,0,0,14,0,0,0,63,0,0,0,6,0,0,0,165,0,0,0,10,0,0,0,219,3,0,0,12,0,0,0,63,9,0,0,14,0,0,0,68,0,0,0,7,0,0,0,203,7,0,0,11,0,0,0,95,9,0,0,15,0,0,0,99,0,0,0,7,0,0,0,195,3,0,0,12,0,0,0,21,0,0,0,8,0,0,0,246,8,0,0,12,0,0,0,23,0,0,0,8,0,0,0,152,4,0,0,13,0,0,0,44,0,0,0,8,0,0,0,178,7,0,0,13,0,0,0,47,0,0,0,8,0,0,0,84,31,0,0,13,0,0,0,141,0,0,0,8,0,0,0,189,7,0,0,13,0,0,0,142,0,0,0,8,0,0,0,130,17,0,0,13,0,0,0,251,0,0,0,8,0,0,0,11,5,0,0,13,0,0,0,45,0,0,0,8,0,0,0,192,7,0,0,11,0,0,0,121,0,0,0,9,0,0,0,95,31,0,0,13,0,0,0,122,0,0,0,9,0,0,0,86,31,0,0,13,0,0,0,49,2,0,0,10,0,0,0,228,3,0,0,10,0,0,0,161,1,0,0,11,0,0,0,67,1,0,0,11,0,0,0,247,1,0,0,11,0,0,0,111,1,0,0,12,0,0,0,146,2,0,0,12,0,0,0,231,2,0,0,12,0,0,0,108,1,0,0,12,0,0,0,109,1,0,0,12,0,0,0,220,3,0,0,12,0,0,0,139,15,0,0,12,0,0,0,153,4,0,0,13,0,0,0,216,3,0,0,12,0,0,0,142,7,0,0,13,0,0,0,213,2,0,0,13,0,0,0,94,31,0,0,13,0,0,0,43,31,0,0,13,0,0,0,143,7,0,0,13,0,0,0,173,4,0,0,14,0,0,0,175,62,0,0,14,0,0,0,220,35,0,0,14,0,0,0,74,0,0,0,9,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,11,0,0,0,5,0,0,0,20,0,0,0,6,0,0,0,63,0,0,0,6,0,0,0,93,0,0,0,7,0,0,0,162,0,0,0,8,0,0,0,172,0,0,0,9,0,0,0,110,1,0,0,9,0,0,0,10,2,0,0,10,0,0,0,226,2,0,0,10,0,0,0,50,4,0,0,11,0,0,0,201,5,0,0,11,0,0,0,39,8,0,0,12,0,0,0,84,11,0,0,12,0,0,0,230,4,0,0,13,0,0,0,95,16,0,0,13,0,0,0,42,23,0,0,13,0,0,0,178,32,0,0,14,0,0,0,78,45,0,0,14,0,0,0,240,57,0,0,14,0,0,0,117,65,0,0,15,0,0,0,158,90,0,0,15,0,0,0,4,0,0,0,4,0,0,0,30,0,0,0,5,0,0,0,66,0,0,0,7,0,0,0,182,0,0,0,8,0,0,0,115,1,0,0,9,0,0,0,149,3,0,0,10,0,0,0,46,7,0,0,11,0,0,0,148,11,0,0,12,0,0,0,164,22,0,0,13,0,0,0,179,32,0,0,14,0,0,0,69,46,0,0,14,0,0,0,5,0,0,0,5,0,0,0,64,0,0,0,7,0,0,0,73,0,0,0,9,0,0,0,143,2,0,0,10,0,0,0,203,5,0,0,11,0,0,0,138,4,0,0,13,0,0,0,221,9,0,0,14,0,0,0,226,115,0,0,15,0,0,0,24,0,0,0,5,0,0,0,37,0,0,0,8,0,0,0,138,0,0,0,10,0,0,0,27,5,0,0,11,0,0,0,95,14,0,0,12,0,0,0,201,9,0,0,14,0,0,0,156,19,0,0,15,0,0,0,41,0,0,0,6,0,0,0,79,0,0,0,9,0,0,0,18,4,0,0,11,0,0,0,141,4,0,0,13,0,0,0,65,46,0,0,14,0,0,0,56,0,0,0,6,0,0,0,14,1,0,0,9,0,0,0,168,5,0,0,11,0,0,0,92,16,0,0,13,0,0,0,242,57,0,0,14,0,0,0,88,0,0,0,7,0,0,0,31,2,0,0,10,0,0,0,126,14,0,0,12,0,0,0,255,57,0,0,14,0,0,0,35,0,0,0,8,0,0,0,227,2,0,0,10,0,0,0,229,4,0,0,13,0,0,0,64,46,0,0,14,0,0,0,161,0,0,0,8,0,0,0,190,5,0,0,11,0,0,0,200,9,0,0,14,0,0,0,131,0,0,0,8,0,0,0,58,1,0,0,11,0,0,0,33,23,0,0,13,0,0,0,68,0,0,0,9,0,0,0,118,2,0,0,12,0,0,0,246,57,0,0,14,0,0,0,139,0,0,0,10,0,0,0,239,4,0,0,13,0,0,0,155,90,0,0,15,0,0,0,8,2,0,0,10,0,0,0,254,28,0,0,13,0,0,0,153,3,0,0,10,0,0,0,180,28,0,0,13,0,0,0,158,3,0,0,10,0,0,0,243,57,0,0,14,0,0,0,171,5,0,0,11,0,0,0,227,115,0,0,15,0,0,0,55,7,0,0,11,0,0,0,159,90,0,0,15,0,0,0,45,8,0,0,12,0,0,0,105,14,0,0,12,0,0,0,104,14,0,0,12,0,0,0,51,4,0,0,11,0,0,0,123,11,0,0,12,0,0,0,248,45,0,0,14,0,0,0,86,46,0,0,14,0,0,0,87,46,0,0,14,0,0,0,247,57,0,0,14,0,0,0,165,81,0,0,15,0,0,0,3,0,0,0,3,0,0,0,42,0,0,0,6,0,0,0,228,0,0,0,8,0,0,0,142,2,0,0,10,0,0,0,53,7,0,0,11,0,0,0,88,16,0,0,13,0,0,0,250,28,0,0,13,0,0,0,249,45,0,0,14,0,0,0,116,65,0,0,15,0,0,0,9,0,0,0,4,0,0,0,84,0,0,0,8,0,0,0,152,3,0,0,10,0,0,0,139,4,0,0,13,0,0,0,157,19,0,0,15,0,0,0,13,0,0,0,4,0,0,0,173,0,0,0,9,0,0,0,38,8,0,0,12,0,0,0,76,45,0,0,14,0,0,0,17,0,0,0,5,0,0,0,107,1,0,0,9,0,0,0,127,11,0,0,12,0,0,0,164,81,0,0,15,0,0,0,25,0,0,0,5,0,0,0,27,2,0,0,10,0,0,0,253,22,0,0,13,0,0,0,29,0,0,0,5,0,0,0,148,3,0,0,10,0,0,0,211,40,0,0,14,0,0,0,43,0,0,0,6,0,0,0,188,5,0,0,11,0,0,0,154,90,0,0,15,0,0,0,47,0,0,0,6,0,0,0,71,2,0,0,12,0,0,0,16,0,0,0,7,0,0,0,53,10,0,0,12,0,0,0,62,0,0,0,6,0,0,0,122,11,0,0,12,0,0,0,89,0,0,0,7,0,0,0,94,16,0,0,13,0,0,0,38,0,0,0,8,0,0,0,207,9,0,0,14,0,0,0,85,0,0,0,8,0,0,0,181,28,0,0,13,0,0,0,87,0,0,0,8,0,0,0,91,14,0,0,12,0,0,0,160,0,0,0,8,0,0,0,104,20,0,0,13,0,0,0,112,1,0,0,9,0,0,0,144,0,0,0,10,0,0,0,206,1,0,0,9,0,0,0,26,2,0,0,10,0,0,0,24,2,0,0,10,0,0,0,104,1,0,0,9,0,0,0,30,2,0,0,10,0,0,0,68,2,0,0,12,0,0,0,54,7,0,0,11,0,0,0,56,1,0,0,11,0,0,0,25,5,0,0,11,0,0,0,94,14,0,0,12,0,0,0,44,7,0,0,11,0,0,0,85,11,0,0,12,0,0,0,220,9,0,0,14,0,0,0,187,32,0,0,14,0,0,0,140,4,0,0,13,0,0,0,35,23,0,0,13,0,0,0,68,46,0,0,14,0,0,0,165,22,0,0,13,0,0,0,24,5,0,0,11,0,0,0,254,57,0,0,14,0,0,0,105,1,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,15,0,0,0,4,0,0,0,22,0,0,0,5,0,0,0,32,0,0,0,6,0,0,0,24,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,154,0,0,0,8,0,0,0,86,0,0,0,9,0,0,0,62,1,0,0,9,0,0,0,240,0,0,0,10,0,0,0,165,3,0,0,10,0,0,0,119,0,0,0,11,0,0,0,239,1,0,0,11,0,0,0,154,0,0,0,12,0,0,0,93,0,0,0,13,0,0,0,1,0,0,0,4,0,0,0,17,0,0,0,5,0,0,0,2,0,0,0,7,0,0,0,11,0,0,0,8,0,0,0,18,0,0,0,9,0,0,0,214,1,0,0,9,0,0,0,126,2,0,0,10,0,0,0,145,1,0,0,11,0,0,0,234,0,0,0,12,0,0,0,220,3,0,0,12,0,0,0,59,1,0,0,13,0,0,0,4,0,0,0,5,0,0,0,20,0,0,0,7,0,0,0,158,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,172,1,0,0,11,0,0,0,226,1,0,0,11,0,0,0,202,3,0,0,12,0,0,0,95,0,0,0,13,0,0,0,23,0,0,0,5,0,0,0,78,0,0,0,7,0,0,0,94,0,0,0,9,0,0,0,243,0,0,0,10,0,0,0,173,1,0,0,11,0,0,0,236,0,0,0,12,0,0,0,240,5,0,0,13,0,0,0,14,0,0,0,6,0,0,0,225,0,0,0,8,0,0,0,164,3,0,0,10,0,0,0,156,0,0,0,12,0,0,0,61,1,0,0,13,0,0,0,59,0,0,0,6,0,0,0,28,0,0,0,9,0,0,0,20,0,0,0,11,0,0,0,190,9,0,0,12,0,0,0,6,0,0,0,7,0,0,0,122,0,0,0,9,0,0,0,144,1,0,0,11,0,0,0,55,1,0,0,13,0,0,0,27,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,92,7,0,0,11,0,0,0,113,0,0,0,7,0,0,0,215,0,0,0,10,0,0,0,191,9,0,0,12,0,0,0,7,0,0,0,8,0,0,0,175,0,0,0,10,0,0,0,204,4,0,0,11,0,0,0,52,0,0,0,8,0,0,0,101,2,0,0,10,0,0,0,159,0,0,0,12,0,0,0,224,0,0,0,8,0,0,0,22,0,0,0,11,0,0,0,39,3,0,0,12,0,0,0,21,0,0,0,9,0,0,0,125,1,0,0,11,0,0,0,187,14,0,0,12,0,0,0,20,0,0,0,9,0,0,0,246,0,0,0,10,0,0,0,228,1,0,0,11,0,0,0,203,0,0,0,10,0,0,0,157,9,0,0,12,0,0,0,202,0,0,0,10,0,0,0,252,2,0,0,12,0,0,0,127,1,0,0,11,0,0,0,205,4,0,0,11,0,0,0,253,2,0,0,12,0,0,0,254,4,0,0,11,0,0,0,58,1,0,0,13,0,0,0,10,0,0,0,4,0,0,0,66,0,0,0,7,0,0,0,211,1,0,0,9,0,0,0,221,4,0,0,11,0,0,0,18,0,0,0,5,0,0,0,232,0,0,0,8,0,0,0,76,0,0,0,11,0,0,0,54,1,0,0,13,0,0,0,57,0,0,0,6,0,0,0,100,2,0,0,10,0,0,0,186,14,0,0,12,0,0,0,0,0,0,0,7,0,0,0,174,0,0,0,10,0,0,0,156,9,0,0,12,0,0,0,31,0,0,0,7,0,0,0,222,4,0,0,11,0,0,0,67,0,0,0,7,0,0,0,220,4,0,0,11,0,0,0,3,0,0,0,8,0,0,0,203,3,0,0,12,0,0,0,6,0,0,0,8,0,0,0,158,9,0,0,12,0,0,0,42,0,0,0,8,0,0,0,241,5,0,0,13,0,0,0,15,0,0,0,8,0,0,0,254,9,0,0,12,0,0,0,51,0,0,0,8,0,0,0,255,9,0,0,12,0,0,0,152,0,0,0,8,0,0,0,159,9,0,0,12,0,0,0,234,0,0,0,8,0,0,0,60,1,0,0,13,0,0,0,46,0,0,0,8,0,0,0,146,1,0,0,11,0,0,0,54,1,0,0,9,0,0,0,106,0,0,0,9,0,0,0,21,0,0,0,11,0,0,0,175,3,0,0,10,0,0,0,227,1,0,0,11,0,0,0,116,0,0,0,11,0,0,0,235,0,0,0,12,0,0,0,249,2,0,0,12,0,0,0,92,0,0,0,13,0,0,0,237,0,0,0,12,0,0,0,221,3,0,0,12,0,0,0,38,3,0,0,12,0,0,0,94,0,0,0,13,0,0,0,22,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,20,0,0,0,5,0,0,0,23,0,0,0,7,0,0,0,127,0,0,0,8,0,0,0,84,1,0,0,9,0,0,0,242,1,0,0,10,0,0,0,191,0,0,0,11,0,0,0,101,0,0,0,12,0,0,0,170,10,0,0,12,0,0,0,48,6,0,0,13,0,0,0,151,21,0,0,13,0,0,0,183,3,0,0,14,0,0,0,34,43,0,0,14,0,0,0,230,11,0,0,15,0,0,0,11,0,0,0,4,0,0,0,55,0,0,0,7,0,0,0,98,0,0,0,9,0,0,0,7,0,0,0,11,0,0,0,102,1,0,0,12,0,0,0,206,0,0,0,13,0,0,0,144,21,0,0,13,0,0,0,246,5,0,0,14,0,0,0,231,11,0,0,15,0,0,0,7,0,0,0,5,0,0,0,109,0,0,0,8,0,0,0,3,0,0,0,11,0,0,0,31,3,0,0,12,0,0,0,242,5,0,0,14,0,0,0,2,0,0,0,6,0,0,0,97,0,0,0,9,0,0,0,85,0,0,0,12,0,0,0,223,1,0,0,14,0,0,0,26,0,0,0,6,0,0,0,30,0,0,0,10,0,0,0,201,10,0,0,12,0,0,0,35,43,0,0,14,0,0,0,30,0,0,0,6,0,0,0,31,0,0,0,10,0,0,0,195,10,0,0,12,0,0,0,43,43,0,0,14,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,11,0,0,0,248,2,0,0,13,0,0,0,25,0,0,0,7,0,0,0,6,0,0,0,11,0,0,0,61,6,0,0,13,0,0,0,87,0,0,0,7,0,0,0,130,1,0,0,11,0,0,0,162,42,0,0,14,0,0,0,4,0,0,0,8,0,0,0,128,1,0,0,11,0,0,0,156,5,0,0,14,0,0,0,125,0,0,0,8,0,0,0,100,1,0,0,12,0,0,0,109,7,0,0,15,0,0,0,2,0,0,0,9,0,0,0,141,1,0,0,11,0,0,0,129,21,0,0,13,0,0,0,173,0,0,0,8,0,0,0,96,0,0,0,12,0,0,0,103,12,0,0,14,0,0,0,28,0,0,0,9,0,0,0,238,0,0,0,13,0,0,0,3,0,0,0,9,0,0,0,207,2,0,0,13,0,0,0,217,0,0,0,9,0,0,0,128,21,0,0,13,0,0,0,2,0,0,0,11,0,0,0,131,1,0,0,11,0,0,0,87,0,0,0,12,0,0,0,97,0,0,0,12,0,0,0,49,0,0,0,11,0,0,0,102,0,0,0,12,0,0,0,49,6,0,0,13,0,0,0,50,6,0,0,13,0,0,0,172,0,0,0,13,0,0,0,29,3,0,0,12,0,0,0,118,0,0,0,12,0,0,0,58,0,0,0,11,0,0,0,101,1,0,0,12,0,0,0,102,12,0,0,14,0,0,0,3,0,0,0,2,0,0,0,84,0,0,0,7,0,0,0,171,2,0,0,10,0,0,0,22,0,0,0,13,0,0,0,247,5,0,0,14,0,0,0,5,0,0,0,4,0,0,0,248,0,0,0,9,0,0,0,169,10,0,0,12,0,0,0,95,0,0,0,15,0,0,0,4,0,0,0,4,0,0,0,28,0,0,0,10,0,0,0,80,21,0,0,13,0,0,0,4,0,0,0,5,0,0,0,119,0,0,0,11,0,0,0,108,7,0,0,15,0,0,0,14,0,0,0,5,0,0,0,10,0,0,0,12,0,0,0,12,0,0,0,5,0,0,0,98,5,0,0,11,0,0,0,4,0,0,0,6,0,0,0,28,3,0,0,12,0,0,0,6,0,0,0,6,0,0,0,200,0,0,0,13,0,0,0,13,0,0,0,6,0,0,0,218,1,0,0,13,0,0,0,7,0,0,0,6,0,0,0,201,0,0,0,13,0,0,0,1,0,0,0,7,0,0,0,46,0,0,0,14,0,0,0,20,0,0,0,7,0,0,0,150,21,0,0,13,0,0,0,10,0,0,0,7,0,0,0,194,10,0,0,12,0,0,0,22,0,0,0,7,0,0,0,91,1,0,0,14,0,0,0,21,0,0,0,7,0,0,0,90,1,0,0,14,0,0,0,15,0,0,0,8,0,0,0,94,0,0,0,15,0,0,0,126,0,0,0,8,0,0,0,171,0,0,0,8,0,0,0,45,0,0,0,9,0,0,0,216,0,0,0,9,0,0,0,11,0,0,0,9,0,0,0,20,0,0,0,10,0,0,0,179,2,0,0,10,0,0,0,243,1,0,0,10,0,0,0,58,0,0,0,10,0,0,0,0,0,0,0,10,0,0,0,88,0,0,0,10,0,0,0,46,0,0,0,9,0,0,0,94,0,0,0,10,0,0,0,99,5,0,0,11,0,0,0,236,0,0,0,12,0,0,0,84,0,0,0,12,0,0,0,193,10,0,0,12,0,0,0,86,21,0,0,13,0,0,0,250,2,0,0,13,0,0,0,129,1,0,0,11,0,0,0,87,21,0,0,13,0,0,0,157,5,0,0,14,0,0,0,163,42,0,0,14,0,0,0,42,43,0,0,14,0,0,0,222,1,0,0,14,0,0,0,60,6,0,0,13,0,0,0,207,0,0,0,13,0,0,0,148,21,0,0,13,0,0,0,13,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,15,0,0,0,4,0,0,0,13,0,0,0,5,0,0,0,12,0,0,0,5,0,0,0,21,0,0,0,6,0,0,0,19,0,0,0,6,0,0,0,18,0,0,0,6,0,0,0,23,0,0,0,7,0,0,0,31,0,0,0,8,0,0,0,30,0,0,0,8,0,0,0,29,0,0,0,8,0,0,0,37,0,0,0,9,0,0,0,36,0,0,0,9,0,0,0,35,0,0,0,9,0,0,0,33,0,0,0,9,0,0,0,33,0,0,0,10,0,0,0,32,0,0,0,10,0,0,0,15,0,0,0,10,0,0,0,14,0,0,0,10,0,0,0,7,0,0,0,11,0,0,0,6,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,33,0,0,0,11,0,0,0,80,0,0,0,12,0,0,0,81,0,0,0,12,0,0,0,82,0,0,0,12,0,0,0,14,0,0,0,4,0,0,0,20,0,0,0,6,0,0,0,22,0,0,0,7,0,0,0,28,0,0,0,8,0,0,0,32,0,0,0,9,0,0,0,31,0,0,0,9,0,0,0,13,0,0,0,10,0,0,0,34,0,0,0,11,0,0,0,83,0,0,0,12,0,0,0,85,0,0,0,12,0,0,0,11,0,0,0,5,0,0,0,21,0,0,0,7,0,0,0,30,0,0,0,9,0,0,0,12,0,0,0,10,0,0,0,86,0,0,0,12,0,0,0,17,0,0,0,6,0,0,0,27,0,0,0,8,0,0,0,29,0,0,0,9,0,0,0,11,0,0,0,10,0,0,0,16,0,0,0,6,0,0,0,34,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,13,0,0,0,6,0,0,0,28,0,0,0,9,0,0,0,8,0,0,0,10,0,0,0,18,0,0,0,7,0,0,0,27,0,0,0,9,0,0,0,84,0,0,0,12,0,0,0,20,0,0,0,7,0,0,0,26,0,0,0,9,0,0,0,87,0,0,0,12,0,0,0,25,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,24,0,0,0,8,0,0,0,35,0,0,0,11,0,0,0,23,0,0,0,8,0,0,0,25,0,0,0,9,0,0,0,24,0,0,0,9,0,0,0,7,0,0,0,10,0,0,0,88,0,0,0,12,0,0,0,7,0,0,0,4,0,0,0,12,0,0,0,6,0,0,0,22,0,0,0,8,0,0,0,23,0,0,0,9,0,0,0,6,0,0,0,10,0,0,0,5,0,0,0,11,0,0,0,4,0,0,0,11,0,0,0,89,0,0,0,12,0,0,0,15,0,0,0,6,0,0,0,22,0,0,0,9,0,0,0,5,0,0,0,10,0,0,0,14,0,0,0,6,0,0,0,4,0,0,0,10,0,0,0,17,0,0,0,7,0,0,0,36,0,0,0,11,0,0,0,16,0,0,0,7,0,0,0,37,0,0,0,11,0,0,0,19,0,0,0,7,0,0,0,90,0,0,0,12,0,0,0,21,0,0,0,8,0,0,0,91,0,0,0,12,0,0,0,20,0,0,0,8,0,0,0,19,0,0,0,8,0,0,0,26,0,0,0,8,0,0,0,21,0,0,0,9,0,0,0,20,0,0,0,9,0,0,0,19,0,0,0,9,0,0,0,18,0,0,0,9,0,0,0,17,0,0,0,9,0,0,0,38,0,0,0,11,0,0,0,39,0,0,0,11,0,0,0,92,0,0,0,12,0,0,0,93,0,0,0,12,0,0,0,94,0,0,0,12,0,0,0,95,0,0,0,12,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,15,0,0,0,4,0,0,0,21,0,0,0,6,0,0,0,23,0,0,0,7,0,0,0,31,0,0,0,8,0,0,0,37,0,0,0,9,0,0,0,36,0,0,0,9,0,0,0,33,0,0,0,10,0,0,0,32,0,0,0,10,0,0,0,7,0,0,0,11,0,0,0,6,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,6,0,0,0,3,0,0,0,20,0,0,0,6,0,0,0,30,0,0,0,8,0,0,0,15,0,0,0,10,0,0,0,33,0,0,0,11,0,0,0,80,0,0,0,12,0,0,0,14,0,0,0,4,0,0,0,29,0,0,0,8,0,0,0,14,0,0,0,10,0,0,0,81,0,0,0,12,0,0,0,13,0,0,0,5,0,0,0,35,0,0,0,9,0,0,0,13,0,0,0,10,0,0,0,12,0,0,0,5,0,0,0,34,0,0,0,9,0,0,0,82,0,0,0,12,0,0,0,11,0,0,0,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+266240);
/* memory initializer */ allocate([12,0,0,0,10,0,0,0,83,0,0,0,12,0,0,0,19,0,0,0,6,0,0,0,11,0,0,0,10,0,0,0,84,0,0,0,12,0,0,0,18,0,0,0,6,0,0,0,10,0,0,0,10,0,0,0,17,0,0,0,6,0,0,0,9,0,0,0,10,0,0,0,16,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,22,0,0,0,7,0,0,0,85,0,0,0,12,0,0,0,21,0,0,0,7,0,0,0,20,0,0,0,7,0,0,0,28,0,0,0,8,0,0,0,27,0,0,0,8,0,0,0,33,0,0,0,9,0,0,0,32,0,0,0,9,0,0,0,31,0,0,0,9,0,0,0,30,0,0,0,9,0,0,0,29,0,0,0,9,0,0,0,28,0,0,0,9,0,0,0,27,0,0,0,9,0,0,0,26,0,0,0,9,0,0,0,34,0,0,0,11,0,0,0,35,0,0,0,11,0,0,0,86,0,0,0,12,0,0,0,87,0,0,0,12,0,0,0,7,0,0,0,4,0,0,0,25,0,0,0,9,0,0,0,5,0,0,0,11,0,0,0,15,0,0,0,6,0,0,0,4,0,0,0,11,0,0,0,14,0,0,0,6,0,0,0,13,0,0,0,6,0,0,0,12,0,0,0,6,0,0,0,19,0,0,0,7,0,0,0,18,0,0,0,7,0,0,0,17,0,0,0,7,0,0,0,16,0,0,0,7,0,0,0,26,0,0,0,8,0,0,0,25,0,0,0,8,0,0,0,24,0,0,0,8,0,0,0,23,0,0,0,8,0,0,0,22,0,0,0,8,0,0,0,21,0,0,0,8,0,0,0,20,0,0,0,8,0,0,0,19,0,0,0,8,0,0,0,24,0,0,0,9,0,0,0,23,0,0,0,9,0,0,0,22,0,0,0,9,0,0,0,21,0,0,0,9,0,0,0,20,0,0,0,9,0,0,0,19,0,0,0,9,0,0,0,18,0,0,0,9,0,0,0,17,0,0,0,9,0,0,0,7,0,0,0,10,0,0,0,6,0,0,0,10,0,0,0,5,0,0,0,10,0,0,0,4,0,0,0,10,0,0,0,36,0,0,0,11,0,0,0,37,0,0,0,11,0,0,0,38,0,0,0,11,0,0,0,39,0,0,0,11,0,0,0,88,0,0,0,12,0,0,0,89,0,0,0,12,0,0,0,90,0,0,0,12,0,0,0,91,0,0,0,12,0,0,0,92,0,0,0,12,0,0,0,93,0,0,0,12,0,0,0,94,0,0,0,12,0,0,0,95,0,0,0,12,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,13,0,0,0,4,0,0,0,5,0,0,0,4,0,0,0,28,0,0,0,5,0,0,0,22,0,0,0,5,0,0,0,63,0,0,0,6,0,0,0,58,0,0,0,6,0,0,0,46,0,0,0,6,0,0,0,34,0,0,0,6,0,0,0,123,0,0,0,7,0,0,0,103,0,0,0,7,0,0,0,95,0,0,0,7,0,0,0,71,0,0,0,7,0,0,0,38,0,0,0,7,0,0,0,239,0,0,0,8,0,0,0,205,0,0,0,8,0,0,0,193,0,0,0,8,0,0,0,169,0,0,0,8,0,0,0,79,0,0,0,8,0,0,0,242,1,0,0,9,0,0,0,221,1,0,0,9,0,0,0,153,1,0,0,9,0,0,0,133,1,0,0,9,0,0,0,93,1,0,0,9,0,0,0,27,1,0,0,9,0,0,0,239,3,0,0,10,0,0,0,225,3,0,0,10,0,0,0,200,3,0,0,10,0,0,0,49,3,0,0,10,0,0,0,3,3,0,0,10,0,0,0,241,2,0,0,10,0,0,0,160,2,0,0,10,0,0,0,51,2,0,0,10,0,0,0,38,1,0,0,10,0,0,0,192,7,0,0,11,0,0,0,111,7,0,0,11,0,0,0,108,7,0,0,11,0,0,0,97,6,0,0,11,0,0,0,4,6,0,0,11,0,0,0,114,5,0,0,11,0,0,0,81,5,0,0,11,0,0,0,106,4,0,0,11,0,0,0,116,2,0,0,11,0,0,0,39,15,0,0,12,0,0,0,36,15,0,0,12,0,0,0,219,14,0,0,12,0,0,0,142,12,0,0,12,0,0,0,11,12,0,0,12,0,0,0,10,12,0,0,12,0,0,0,227,10,0,0,12,0,0,0,214,8,0,0,12,0,0,0,144,4,0,0,12,0,0,0,149,4,0,0,12,0,0,0,25,31,0,0,13,0,0,0,181,29,0,0,13,0,0,0,9,0,0,0,4,0,0,0,16,0,0,0,5,0,0,0,41,0,0,0,6,0,0,0,98,0,0,0,7,0,0,0,243,0,0,0,8,0,0,0,173,0,0,0,8,0,0,0,229,1,0,0,9,0,0,0,121,1,0,0,9,0,0,0,156,0,0,0,9,0,0,0,177,3,0,0,10,0,0,0,174,2,0,0,10,0,0,0,39,1,0,0,10,0,0,0,110,7,0,0,11,0,0,0,112,5,0,0,11,0,0,0,117,2,0,0,11,0,0,0,37,15,0,0,12,0,0,0,192,14,0,0,12,0,0,0,160,10,0,0,12,0,0,0,215,8,0,0,12,0,0,0,76,30,0,0,13,0,0,0,8,0,0,0,5,0,0,0,99,0,0,0,7,0,0,0,175,0,0,0,8,0,0,0,123,1,0,0,9,0,0,0,179,3,0,0,10,0,0,0,221,7,0,0,11,0,0,0,64,6,0,0,11,0,0,0,141,15,0,0,12,0,0,0,193,11,0,0,12,0,0,0,145,4,0,0,12,0,0,0,40,0,0,0,6,0,0,0,195,0,0,0,8,0,0,0,81,1,0,0,9,0,0,0,161,2,0,0,10,0,0,0,115,5,0,0,11,0,0,0,195,14,0,0,12,0,0,0,53,31,0,0,13,0,0,0,101,0,0,0,7,0,0,0,218,1,0,0,9,0,0,0,175,2,0,0,10,0,0,0,119,2,0,0,11,0,0,0,201,8,0,0,12,0,0,0,129,23,0,0,13,0,0,0,37,0,0,0,7,0,0,0,24,1,0,0,9,0,0,0,70,6,0,0,11,0,0,0,166,10,0,0,12,0,0,0,128,23,0,0,13,0,0,0,201,0,0,0,8,0,0,0,33,3,0,0,10,0,0,0,155,15,0,0,12,0,0,0,30,25,0,0,13,0,0,0,72,0,0,0,8,0,0,0,204,7,0,0,11,0,0,0,161,10,0,0,12,0,0,0,128,1,0,0,9,0,0,0,101,4,0,0,11,0,0,0,5,25,0,0,13,0,0,0,226,3,0,0,10,0,0,0,193,14,0,0,12,0,0,0,155,60,0,0,14,0,0,0,244,2,0,0,10,0,0,0,200,8,0,0,12,0,0,0,193,7,0,0,11,0,0,0,40,9,0,0,13,0,0,0,225,5,0,0,11,0,0,0,13,50,0,0,14,0,0,0,194,14,0,0,12,0,0,0,24,100,0,0,15,0,0,0,52,31,0,0,13,0,0,0,120,0,0,0,7,0,0,0,85,1,0,0,9,0,0,0,82,5,0,0,11,0,0,0,31,25,0,0,13,0,0,0,250,0,0,0,8,0,0,0,220,7,0,0,11,0,0,0,7,25,0,0,13,0,0,0,172,0,0,0,8,0,0,0,73,2,0,0,11,0,0,0,177,19,0,0,14,0,0,0,246,1,0,0,9,0,0,0,226,10,0,0,12,0,0,0,220,1,0,0,9,0,0,0,237,4,0,0,12,0,0,0,132,1,0,0,9,0,0,0,4,25,0,0,13,0,0,0,86,1,0,0,9,0,0,0,217,9,0,0,13,0,0,0,231,3,0,0,10,0,0,0,41,9,0,0,13,0,0,0,178,3,0,0,10,0,0,0,104,59,0,0,14,0,0,0,245,2,0,0,10,0,0,0,176,19,0,0,14,0,0,0,34,3,0,0,10,0,0,0,105,59,0,0,14,0,0,0,52,2,0,0,10,0,0,0,53,121,0,0,15,0,0,0,199,7,0,0,11,0,0,0,51,200,0,0,16,0,0,0,96,6,0,0,11,0,0,0,52,121,0,0,15,0,0,0,75,2,0,0,11,0,0,0,50,200,0,0,16,0,0,0,167,10,0,0,12,0,0,0,24,31,0,0,13,0,0,0,122,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,30,0,0,0,5,0,0,0,4,0,0,0,5,0,0,0,18,0,0,0,6,0,0,0,112,0,0,0,7,0,0,0,26,0,0,0,7,0,0,0,95,0,0,0,8,0,0,0,71,0,0,0,8,0,0,0,211,1,0,0,9,0,0,0,181,0,0,0,9,0,0,0,87,0,0,0,9,0,0,0,181,3,0,0,10,0,0,0,109,1,0,0,10,0,0,0,98,1,0,0,10,0,0,0,206,7,0,0,11,0,0,0,25,7,0,0,11,0,0,0,145,6,0,0,11,0,0,0,198,2,0,0,11,0,0,0,86,1,0,0,11,0,0,0,146,15,0,0,12,0,0,0,46,13,0,0,12,0,0,0,32,13,0,0,12,0,0,0,158,5,0,0,12,0,0,0,104,4,0,0,12,0,0,0,166,2,0,0,12,0,0,0,162,29,0,0,13,0,0,0,96,28,0,0,13,0,0,0,67,26,0,0,13,0,0,0,29,11,0,0,13,0,0,0,192,8,0,0,13,0,0,0,93,5,0,0,13,0,0,0,3,0,0,0,3,0,0,0,10,0,0,0,5,0,0,0,119,0,0,0,7,0,0,0,229,0,0,0,8,0,0,0,217,1,0,0,9,0,0,0,229,3,0,0,10,0,0,0,102,1,0,0,10,0,0,0,148,6,0,0,11,0,0,0,82,1,0,0,11,0,0,0,159,5,0,0,12,0,0,0,60,31,0,0,13,0,0,0,75,26,0,0,13,0,0,0,94,5,0,0,13,0,0,0,12,0,0,0,4,0,0,0,125,0,0,0,7,0,0,0,68,0,0,0,8,0,0,0,224,3,0,0,10,0,0,0,105,7,0,0,11,0,0,0,49,14,0,0,12,0,0,0,38,31,0,0,13,0,0,0,92,5,0,0,13,0,0,0,27,0,0,0,5,0,0,0,226,0,0,0,8,0,0,0,165,3,0,0,10,0,0,0,201,2,0,0,11,0,0,0,35,31,0,0,13,0,0,0,71,59,0,0,14,0,0,0,7,0,0,0,5,0,0,0,216,1,0,0,9,0,0,0,216,2,0,0,11,0,0,0,39,31,0,0,13,0,0,0,148,52,0,0,14,0,0,0,53,0,0,0,6,0,0,0,225,3,0,0,10,0,0,0,156,5,0,0,12,0,0,0,195,56,0,0,14,0,0,0,12,0,0,0,6,0,0,0,101,1,0,0,10,0,0,0,35,29,0,0,13,0,0,0,56,22,0,0,14,0,0,0,104,0,0,0,7,0,0,0,147,6,0,0,11,0,0,0,69,58,0,0,14,0,0,0,32,0,0,0,7,0,0,0,144,15,0,0,12,0,0,0,246,124,0,0,15,0,0,0,232,0,0,0,8,0,0,0,143,5,0,0,12,0,0,0,239,44,0,0,15,0,0,0,69,0,0,0,8,0,0,0,58,11,0,0,13,0,0,0,241,1,0,0,9,0,0,0,70,59,0,0,14,0,0,0,167,1,0,0,9,0,0,0,118,22,0,0,14,0,0,0,86,0,0,0,9,0,0,0,42,105,0,0,15,0,0,0,141,3,0,0,10,0,0,0,9,227,0,0,16,0,0,0,170,0,0,0,10,0,0,0,17,198,1,0,17,0,0,0,223,2,0,0,11,0,0,0,185,179,0,0,17,0,0,0,200,2,0,0,11,0,0,0,32,140,3,0,18,0,0,0,176,1,0,0,11,0,0,0,144,99,1,0,18,0,0,0,159,15,0,0,12,0,0,0,113,103,1,0,18,0,0,0,208,14,0,0,12,0,0,0,67,24,7,0,19,0,0,0,42,13,0,0,12,0,0,0,140,158,15,0,20,0,0,0,97,4,0,0,12,0,0,0,142,158,15,0,20,0,0,0,103,11,0,0,13,0,0,0,95,5,0,0,13,0,0,0,63,0,0,0,6,0,0,0,109,0,0,0,9,0,0,0,144,14,0,0,12,0,0,0,78,5,0,0,13,0,0,0,19,0,0,0,6,0,0,0,25,1,0,0,10,0,0,0,102,11,0,0,13,0,0,0,11,0,0,0,6,0,0,0,53,2,0,0,11,0,0,0,245,124,0,0,15,0,0,0,117,0,0,0,7,0,0,0,36,13,0,0,12,0,0,0,233,249,0,0,16,0,0,0,46,0,0,0,7,0,0,0,34,31,0,0,13,0,0,0,33,0,0,0,7,0,0,0,79,5,0,0,13,0,0,0,20,0,0,0,7,0,0,0,68,58,0,0,14,0,0,0,228,0,0,0,8,0,0,0,247,124,0,0,15,0,0,0,94,0,0,0,8,0,0,0,133,113,0,0,15,0,0,0,55,0,0,0,8,0,0,0,115,44,0,0,15,0,0,0,219,1,0,0,9,0,0,0,221,89,0,0,16,0,0,0,199,1,0,0,9,0,0,0,43,105,0,0,15,0,0,0,166,1,0,0,9,0,0,0,229,88,0,0,16,0,0,0,180,0,0,0,9,0,0,0,208,243,1,0,17,0,0,0,176,0,0,0,9,0,0,0,201,177,0,0,17,0,0,0,230,3,0,0,10,0,0,0,112,103,1,0,18,0,0,0,110,1,0,0,10,0,0,0,162,231,3,0,18,0,0,0,27,1,0,0,10,0,0,0,141,158,15,0,20,0,0,0,217,0,0,0,10,0,0,0,143,158,15,0,20,0,0,0,168,0,0,0,10,0,0,0,35,199,2,0,19,0,0,0,73,7,0,0,11,0,0,0,132,48,14,0,20,0,0,0,150,6,0,0,11,0,0,0,69,142,5,0,20,0,0,0,222,2,0,0,11,0,0,0,136,28,11,0,21,0,0,0,49,2,0,0,11,0,0,0,10,97,28,0,21,0,0,0,177,1,0,0,11,0,0,0,45,132,113,0,23,0,0,0,43,13,0,0,12,0,0,0,23,194,56,0,22,0,0,0,47,13,0,0,12,0,0,0,19,57,22,0,22,0,0,0,178,5,0,0,12,0,0,0,18,57,22,0,22,0,0,0,105,4,0,0,12,0,0,0,44,132,113,0,23,0,0,0,66,26,0,0,13,0,0,0,193,8,0,0,13,0,0,0,115,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,96,6,0,255,204,204,0,240,136,136,15,0,17,17,200,254,239,140,127,19,49,247,0,200,140,0,19,0,0,49,0,204,204,0,51,0,0,51,240,15,102,102,240,0,0,15,34,34,68,68,0,246,200,140,111,0,49,19,140,49,19,200,204,51,0,102,192,12,102,0,48,3,0,249,140,200,159,0,19,49,0,96,128,8,6,0,16,1,136,204,0,252,207,0,204,136,63,0,51,17,17,51,0,243,246,111,3,6,198,8,99,140,49,198,16,99,96,192,54,1,108,19,200,54,128,108,76,50,48,185,39,0,8,85,39,0,16,10,39,0,120,198,38,0,208,131,38,0,232,72,38,0,56,18,38,0,248,232,37,0,208,188,37,0,56,156,37,0,56,104,37,0,56,22,34,0,0,0,0,0,0,0,0,0,160,159,35,0,120,193,34,0,216,0,34,0,8,110,33,0,160,246,32,0,32,147,32,0,0,0,0,0,0,0,0,0,128,14,39,0,96,203,38,0,64,135,38,0,232,75,38,0,80,21,38,0,64,235,37,0,0,0,0,0,0,0,0,0,144,10,34,0,248,115,33,0,168,251,32,0,176,151,32,0,144,60,32,0,208,34,40,0,224,194,39,0,0,0,0,0,112,85,33,0,96,0,33,0,232,76,33,0,200,155,32,0,96,68,33,0,200,60,33,0,104,44,33,0,136,13,33,0,240,2,33,0,192,250,32,0,240,242,32,0,16,235,32,0,240,228,32,0,160,221,32,0,120,215,32,0,0,0,0,0,232,19,34,0,144,122,33,0,0,1,33,0,24,156,32,0,224,64,32,0,0,41,40,0,224,200,39,0,80,98,39,0,160,20,39,0,160,208,38,0,48,140,38,0,128,80,38,0,0,0,0,0,0,0,0,0,56,66,32,0,112,81,38,0,0,0,0,0,0,0,0,0,16,9,37,0,184,214,34,0,8,225,36,0,96,157,32,0,56,190,36,0,88,161,36,0,16,134,36,0,120,107,36,0,248,41,40,0,104,21,39,0,32,80,36,0,240,55,36,0,136,22,36,0,112,221,35,0,8,194,35,0,0,0,0,0,0,124,33,0,192,2,33,0,136,157,32,0,112,66,32,0,16,42,40,0,208,203,39,0,104,100,39,0,136,21,39,0,160,209,38,0,8,141,38,0,200,7,37,0,0,193,35,0,192,81,38,0,168,26,38,0,0,239,37,0,0,0,0,0,240,50,35,0,168,26,35,0,200,69,32,0,240,238,34,0,16,217,34,0,112,45,40,0,0,202,34,0,0,0,0,0,120,7,33,0,24,162,32,0,0,71,32,0,112,46,40,0,216,209,39,0,0,0,0,0,96,85,38,0,224,32,38,0,24,241,37,0,128,195,37,0,136,161,37,0,224,120,37,0,120,53,37,0,128,11,37,0,0,0,0,0,0,0,0,0,88,137,36,0,216,109,36,0,88,83,36,0,72,58,36,0,224,28,36,0,184,226,35,0,176,196,35,0,16,173,35,0,64,234,34,0,56,13,33,0,120,216,38,0,72,213,39,0,104,55,37,0,0,0,0,0,112,53,37,0,0,0,0,0,16,17,37,0,232,250,34,0,32,232,36,0,192,174,32,0,240,72,37,0,240,196,36,0,168,147,33,0,160,166,36,0,72,140,36,0,88,112,36,0,48,85,36,0,56,60,36,0,72,32,36,0,16,58,40,0,248,36,39,0,104,231,35,0,192,198,35,0,96,175,35,0,0,0,0,0,0,0,0,0,16,61,36,0,32,34,36,0,104,232,35,0,216,199,35,0,0,176,35,0,240,153,35,0,0,0,0,0,0,0,0,0,224,87,37,0,184,250,35,0,200,3,35,0,64,60,34,0,64,154,33,0,8,30,33,0,160,179,32,0,192,87,32,0,192,63,40,0,24,229,39,0,232,123,39,0,0,41,39,0,0,0,0,0,0,0,0,0,224,97,38,0,152,43,38,0,96,249,37,0,144,206,37,0,152,7,35,0,136,169,37,0,48,132,37,0,0,0,0,0,32,100,38,0,160,45,38,0,200,250,37,0,240,207,37,0,152,170,37,0,64,134,37,0,112,68,37,0,120,21,37,0,24,237,36,0,16,201,36,0,80,162,33,0,200,170,36,0,200,143,36,0,144,116,36,0,168,89,36,0,176,63,36,0,152,37,36,0,40,235,35,0,168,201,35,0,120,177,35,0,0,0,0,0,0,0,0,0,72,130,39,0,80,165,33,0,48,46,39,0,0,0,0,0,112,191,32,0,152,98,32,0,240,72,40,0,232,239,39,0,160,133,39,0,208,48,39,0,120,234,38,0,88,163,38,0,168,103,38,0,248,48,38,0,192,253,37,0,96,211,37,0,64,173,37,0,56,137,37,0,40,72,37,0,152,23,37,0,144,239,36,0,64,203,36,0,104,173,36,0,240,145,36,0,208,118,36,0,184,91,36,0,176,65,36,0,152,39,36,0,8,238,35,0,88,203,35,0,208,179,35,0,88,157,35,0,200,136,35,0,224,113,35,0,64,94,35,0,200,75,35,0,152,57,35,0,184,37,35,0,192,250,34,0,96,223,34,0,16,169,33,0,0,0,0,0,136,238,33,0,168,223,33,0,40,212,33,0,0,0,0,0,152,148,33,0,40,24,33,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,53,34,0,112,0,0,0,40,78,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,10,0,0,228,9,0,0,6,10,0,0,4,10,0,0,10,10,0,0,164,0,0,0,12,10,0,0,228,9,0,0,14,10,0,0,0,0,0,0,173,171,68,36,47,37,77,199,146,255,41,189,0,0,0,0,255,255,255,255,0,0,0,0,1,0,128,184,0,0,64,58,255,255,3,187,1,0,136,59,1,0,238,187,251,255,62,60,0,128,145,188,2,0,215,60,0,128,30,189,1,192,112,61,0,0,202,189,255,255,108,62,0,84,111,63,3,0,28,190,0,0,161,61,0,64,74,189,255,127,7,61,255,127,184,188,252,255,118,60,0,0,32,188,0,0,192,59,255,255,79,187,3,0,184,58,255,255,191,185,254,255,127,185,2,0,192,58,1,0,120,187,255,255,247,59,2,0,85,188,254,255,168,60,0,0,255,188,1,0,60,61,0,224,138,189,250,127,213,61,3,224,57,190,255,107,0,63,0,64,65,63,3,128,86,190,252,31,235,61,0,128,150,189,1,0,75,61,1,0,10,189,1,0,184,60,254,255,106,188,0,0,11,60,255,255,145,187,3,0,240,58,0,0,224,185,0,0,224,185,3,0,240,58,255,255,145,187,0,0,11,60,254,255,106,188,1,0,184,60,1,0,10,189,1,0,75,61,0,128,150,189,252,31,235,61,3,128,86,190,0,64,65,63,255,107,0,63,3,224,57,190,250,127,213,61,0,224,138,189,1,0,60,61,0,0,255,188,254,255,168,60,2,0,85,188,255,255,247,59,1,0,120,187,2,0,192,58,254,255,127,185,255,255,191,185,3,0,184,58,255,255,79,187,0,0,192,59,0,0,32,188,252,255,118,60,255,127,184,188,255,127,7,61,0,64,74,189,0,0,161,61,3,0,28,190,0,84,111,63,255,255,108,62,0,0,202,189,1,192,112,61,0,128,30,189,2,0,215,60,0,128,145,188,251,255,62,60,1,0,238,187,1,0,136,59,255,255,3,187,0,0,64,58,1,0,128,184,7,0,0,0,20,0,0,0,33,0,0,0,46,0,0,0,59,0,0,0,72,0,0,0,85,0,0,0,98,0,0,0,111,0,0,0,124,0,0,0,137,0,0,0,150,0,0,0,163,0,0,0,176,0,0,0,189,0,0,0,202,0,0,0,215,0,0,0,228,0,0,0,241,0,0,0,254,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,164,0,0,0,165,0,0,0,166,0,0,0,167,0,0,0,168,0,0,0,169,0,0,0,170,0,0,0,171,0,0,0,172,0,0,0,173,0,0,0,174,0,0,0,175,0,0,0,177,0,0,0,178,0,0,0,179,0,0,0,180,0,0,0,181,0,0,0,182,0,0,0,183,0,0,0,184,0,0,0,185,0,0,0,186,0,0,0,187,0,0,0,188,0,0,0,190,0,0,0,191,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,196,0,0,0,197,0,0,0,198,0,0,0,199,0,0,0,200,0,0,0,201,0,0,0,203,0,0,0,204,0,0,0,205,0,0,0,206,0,0,0,207,0,0,0,208,0,0,0,209,0,0,0,210,0,0,0,211,0,0,0,212,0,0,0,213,0,0,0,214,0,0,0,216,0,0,0,217,0,0,0,218,0,0,0,219,0,0,0,220,0,0,0,221,0,0,0,222,0,0,0,223,0,0,0,224,0,0,0,225,0,0,0,226,0,0,0,227,0,0,0,229,0,0,0,230,0,0,0,231,0,0,0,232,0,0,0,233,0,0,0,234,0,0,0,235,0,0,0,236,0,0,0,237,0,0,0,238,0,0,0,239,0,0,0,240,0,0,0,242,0,0,0,243,0,0,0,244,0,0,0,245,0,0,0,246,0,0,0,247,0,0,0,248,0,0,0,249,0,0,0,250,0,0,0,251,0,0,0,252,0,0,0,253,0,0,0,144,175,35,0,32,205,34,0,4,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,8,12,34,0,32,205,34,0,4,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,80,117,33,0,16,252,32,0,8,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,224,152,32,0,16,252,32,0,8,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,24,61,32,0,88,35,40,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,80,195,39,0,88,35,40,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,0,95,39,0,56,17,39,0,12,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,136,205,38,0,56,17,39,0,12,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,168,137,38,0,80,78,38,0,16,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,48,23,38,0,80,78,38,0,16,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,72,236,37,0,88,191,37,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,8,158,37,0,88,191,37,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,96,110,37,0,32,46,37,0,76,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,254,34,0,112,0,0,0,112,84,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,8,0,0,0,10,0,0,0,0,0,0,0,1,0,255,255,6,10,43,52,1,1,1,5,1,1,13,0,19,0,0,0,252,255,255,255,254,255,255,255,252,255,255,255,255,255,255,255,252,255,255,255,0,0,0,0,252,255,255,255,1,0,0,0,252,255,255,255,2,0,0,0,4,0,0,0,254,255,255,255,4,0,0,0,255,255,255,255,4,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,254,255,255,255,3,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,3,0,0,0,254,255,255,255,253,255,255,255,0,0,0,0,252,255,255,255,2,0,0,0,253,255,255,255,16,19,23,26,30,33,37,40,44,47,51,54,58,61,65,68,72,75,79,82,86,89,92,96,99,103,106,110,113,117,120,124,127,131,134,138,141,145,148,152,155,159,162,165,169,172,176,179,183,186,190,193,197,200,204,207,211,214,218,221,225,228,232,235,0,1,1,2,0,1,2,3,0,2,3,4,0,1,3,4,0,1,2,4,0,2,3,5,0,2,4,5,0,1,4,5,0,1,3,5,0,2,4,6,0,3,5,6,0,1,5,6,0,1,3,6,0,6,6,6,0,0,6,6,0,0,0,6,0,3,4,7,0,3,6,7,0,1,6,7,0,1,4,7,0,3,5,8,0,4,6,8,0,2,6,8,0,2,4,8,0,8,8,8,0,0,8,8,0,0,0,8,0,4,7,11,0,5,9,11,0,2,9,11,0,2,6,11,0,11,11,11,0,0,11,11,0,0,0,11,0,5,9,14,0,7,11,14,0,3,11,14,0,3,7,14,0,14,14,14,0,0,14,14,0,0,0,14,0,6,11,17,0,8,13,17,0,4,13,17,0,4,9,17,0,17,17,17,0,0,17,17,0,0,0,17,0,7,13,20,0,10,15,20,0,5,15,20,0,5,10,20,0,20,20,20,0,0,20,20,0,0,0,20,0,11,18,23,0,5,18,23,0,5,12,23,0,23,23,23,0,0,23,23,0,0,0,23,0,13,20,26,0,6,20,26,0,6,13,26,0,26,26,26,0,0,26,26,0,0,0,26,0,14,22,29,0,7,22,29,0,7,15,29,0,29,29,29,0,0,29,29,0,0,0,29,0,16,24,32,0,8,24,32,0,8,16,32,0,32,32,32,0,0,32,32,0,0,0,32,0,35,35,35,0,0,35,35,0,0,0,35,0,18,27,36,0,9,27,36,0,9,18,36,0,40,40,40,0,0,40,40,0,0,0,40,0,46,46,46,0,0,46,46,0,0,0,46,1,2,2,3,1,2,3,4,1,3,4,5,1,2,4,5,1,2,3,5,1,3,4,6,1,3,5,6,1,2,5,6,1,2,4,6,1,3,5,7,1,4,6,7,1,2,6,7,1,2,4,7,1,7,7,7,1,1,7,7,1,1,1,7,1,4,5,8,1,4,7,8,1,2,7,8,1,2,5,8,1,4,6,9,1,5,7,9,1,3,7,9,1,3,5,9,1,9,9,9,1,1,9,9,1,1,1,9,1,5,8,12,1,6,10,12,1,3,10,12,1,3,7,12,1,12,12,12,1,1,12,12,1,1,1,12,1,6,10,15,1,8,12,15,1,4,12,15,1,4,8,15,1,15,15,15,1,1,15,15,1,1,1,15,1,7,12,18,1,9,14,18,1,5,14,18,1,5,10,18,1,18,18,18,1,1,18,18,1,1,1,18,1,8,14,21,1,11,16,21,1,6,16,21,1,6,11,21,1,21,21,21,1,1,21,21,1,1,1,21,1,12,19,24,1,6,19,24,1,6,13,24,1,24,24,24,1,1,24,24,1,1,1,24,1,14,21,27,1,7,21,27,1,7,14,27,1,27,27,27,1,1,27,27,1,1,1,27,1,15,23,30,1,8,23,30,1,8,16,30,1,30,30,30,1,1,30,30,1,1,1,30,1,17,25,33,1,9,25,33,1,9,17,33,1,33,33,33,1,1,33,33,1,1,1,33,1,36,36,36,1,1,36,36,1,1,1,36,1,19,28,37,1,10,28,37,1,10,19,37,1,41,41,41,1,1,41,41,1,1,1,41,1,47,47,47,1,1,47,47,1,1,1,47,2,3,3,4,2,3,4,5,2,4,5,6,2,3,5,6,2,3,4,6,2,4,5,7,2,4,6,7,2,3,6,7,2,3,5,7,2,4,6,8,2,5,7,8,2,3,7,8,2,3,5,8,2,8,8,8,2,2,8,8,2,2,2,8,2,5,6,9,2,5,8,9,2,3,8,9,2,3,6,9,2,5,7,10,2,6,8,10,2,4,8,10,2,4,6,10,2,10,10,10,2,2,10,10,2,2,2,10,2,6,9,13,2,7,11,13,2,4,11,13,2,4,8,13,2,13,13,13,2,2,13,13,2,2,2,13,2,7,11,16,2,9,13,16,2,5,13,16,2,5,9,16,2,16,16,16,2,2,16,16,2,2,2,16,2,8,13,19,2,10,15,19,2,6,15,19,2,6,11,19,2,19,19,19,2,2,19,19,2,2,2,19,2,9,15,22,2,12,17,22,2,7,17,22,2,7,12,22,2,22,22,22,2,2,22,22,2,2,2,22,2,13,20,25,2,7,20,25,2,7,14,25,2,25,25,25,2,2,25,25,2,2,2,25,2,15,22,28,2,8,22,28,2,8,15,28,2,28,28,28,2,2,28,28,2,2,2,28,2,16,24,31,2,9,24,31,2,9,17,31,2,31,31,31,2,2,31,31,2,2,2,31,2,18,26,34,2,10,26,34,2,10,18,34,2,34,34,34,2,2,34,34,2,2,2,34,2,37,37,37,2,2,37,37,2,2,2,37,2,20,29,38,2,11,29,38,2,11,20,38,2,42,42,42,2,2,42,42,2,2,2,42,2,48,48,48,2,2,48,48,2,2,2,48,3,4,4,5,3,4,5,6,3,5,6,7,3,4,6,7,3,4,5,7,3,5,6,8,3,5,7,8,3,4,7,8,3,4,6,8,3,5,7,9,3,6,8,9,3,4,8,9,3,4,6,9,3,9,9,9,3,3,9,9,3,3,3,9,3,6,7,10,3,6,9,10,3,4,9,10,3,4,7,10,3,6,8,11,3,7,9,11,3,5,9,11,3,5,7,11,3,11,11,11,3,3,11,11,3,3,3,11,3,7,10,14,3,8,12,14,3,5,12,14,3,5,9,14,3,14,14,14,3,3,14,14,3,3,3,14,3,8,12,17,3,10,14,17,3,6,14,17,3,6,10,17,3,17,17,17,3,3,17,17,3,3,3,17,3,9,14,20,3,11,16,20,3,7,16,20,3,7,12,20,3,20,20,20,3,3,20,20,3,3,3,20,3,10,16,23,3,13,18,23,3,8,18,23,3,8,13,23,3,23,23,23,3,3,23,23,3,3,3,23,3,14,21,26,3,8,21,26,3,8,15,26,3,26,26,26,3,3,26,26,3,3,3,26,3,16,23,29,3,9,23,29,3,9,16,29,3,29,29,29,3,3,29,29,3,3,3,29,3,17,25,32,3,10,25,32,3,10,18,32,3,32,32,32,3,3,32,32,3,3,3,32,3,19,27,35,3,11,27,35,3,11,19,35,3,35,35,35,3,3,35,35,3,3,3,35,3,38,38,38,3,3,38,38,3,3,3,38,3,21,30,39,3,12,30,39,3,12,21,39,3,43,43,43,3,3,43,43,3,3,3,43,3,49,49,49,3,3,49,49,3,3,3,49,4,5,5,6,4,5,6,7,4,6,7,8,4,5,7,8,4,5,6,8,4,6,7,9,4,6,8,9,4,5,8,9,4,5,7,9,4,6,8,10,4,7,9,10,4,5,9,10,4,5,7,10,4,10,10,10,4,4,10,10,4,4,4,10,4,7,8,11,4,7,10,11,4,5,10,11,4,5,8,11,4,7,9,12,4,8,10,12,4,6,10,12,4,6,8,12,4,12,12,12,4,4,12,12,4,4,4,12,4,8,11,15,4,9,13,15,4,6,13,15,4,6,10,15,4,15,15,15,4,4,15,15,4,4,4,15,4,9,13,18,4,11,15,18,4,7,15,18,4,7,11,18,4,18,18,18,4,4,18,18,4,4,4,18,4,10,15,21,4,12,17,21,4,8,17,21,4,8,13,21,4,21,21,21,4,4,21,21,4,4,4,21,4,11,17,24,4,14,19,24,4,9,19,24,4,9,14,24,4,24,24,24,4,4,24,24,4,4,4,24,4,15,22,27,4,9,22,27,4,9,16,27,4,27,27,27,4,4,27,27,4,4,4,27,4,17,24,30,4,10,24,30,4,10,17,30,4,30,30,30,4,4,30,30,4,4,4,30,4,18,26,33,4,11,26,33,4,11,19,33,4,33,33,33,4,4,33,33,4,4,4,33,4,20,28,36,4,12,28,36,4,12,20,36,4,36,36,36,4,4,36,36,4,4,4,36,4,39,39,39,4,4,39,39,4,4,4,39,4,22,31,40,4,13,31,40,4,13,22,40,4,44,44,44,4,4,44,44,4,4,4,44,4,50,50,50,4,4,50,50,4,4,4,50,5,6,6,7,5,6,7,8,5,7,8,9,5,6,8,9,5,6,7,9,5,7,8,10,5,7,9,10,5,6,9,10,5,6,8,10,5,7,9,11,5,8,10,11,5,6,10,11,5,6,8,11,5,11,11,11,5,5,11,11,5,5,5,11,5,8,9,12,5,8,11,12,5,6,11,12,5,6,9,12,5,8,10,13,5,9,11,13,5,7,11,13,5,7,9,13,5,13,13,13,5,5,13,13,5,5,5,13,5,9,12,16,5,10,14,16,5,7,14,16,5,7,11,16,5,16,16,16,5,5,16,16,5,5,5,16,5,10,14,19,5,12,16,19,5,8,16,19,5,8,12,19,5,19,19,19,5,5,19,19,5,5,5,19,5,11,16,22,5,13,18,22,5,9,18,22,5,9,14,22,5,22,22,22,5,5,22,22,5,5,5,22,5,12,18,25], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+276480);
/* memory initializer */ allocate([5,15,20,25,5,10,20,25,5,10,15,25,5,25,25,25,5,5,25,25,5,5,5,25,5,16,23,28,5,10,23,28,5,10,17,28,5,28,28,28,5,5,28,28,5,5,5,28,5,18,25,31,5,11,25,31,5,11,18,31,5,31,31,31,5,5,31,31,5,5,5,31,5,19,27,34,5,12,27,34,5,12,20,34,5,34,34,34,5,5,34,34,5,5,5,34,5,21,29,37,5,13,29,37,5,13,21,37,5,37,37,37,5,5,37,37,5,5,5,37,5,40,40,40,5,5,40,40,5,5,5,40,5,23,32,41,5,14,32,41,5,14,23,41,5,45,45,45,5,5,45,45,5,5,5,45,5,51,51,51,5,5,51,51,5,5,5,51,6,7,7,8,6,7,8,9,6,8,9,10,6,7,9,10,6,7,8,10,6,8,9,11,6,8,10,11,6,7,10,11,6,7,9,11,6,8,10,12,6,9,11,12,6,7,11,12,6,7,9,12,6,12,12,12,6,6,12,12,6,6,6,12,6,9,10,13,6,9,12,13,6,7,12,13,6,7,10,13,6,9,11,14,6,10,12,14,6,8,12,14,6,8,10,14,6,14,14,14,6,6,14,14,6,6,6,14,6,10,13,17,6,11,15,17,6,8,15,17,6,8,12,17,6,17,17,17,6,6,17,17,6,6,6,17,6,11,15,20,6,13,17,20,6,9,17,20,6,9,13,20,6,20,20,20,6,6,20,20,6,6,6,20,6,12,17,23,6,14,19,23,6,10,19,23,6,10,15,23,6,23,23,23,6,6,23,23,6,6,6,23,6,13,19,26,6,16,21,26,6,11,21,26,6,11,16,26,6,26,26,26,6,6,26,26,6,6,6,26,6,17,24,29,6,11,24,29,6,11,18,29,6,29,29,29,6,6,29,29,6,6,6,29,6,19,26,32,6,12,26,32,6,12,19,32,6,32,32,32,6,6,32,32,6,6,6,32,6,20,28,35,6,13,28,35,6,13,21,35,6,35,35,35,6,6,35,35,6,6,6,35,6,22,30,38,6,14,30,38,6,14,22,38,6,38,38,38,6,6,38,38,6,6,6,38,6,41,41,41,6,6,41,41,6,6,6,41,6,24,33,42,6,15,33,42,6,15,24,42,6,46,46,46,6,6,46,46,6,6,6,46,6,52,52,52,6,6,52,52,6,6,6,52,7,8,8,9,7,8,9,10,7,9,10,11,7,8,10,11,7,8,9,11,7,9,10,12,7,9,11,12,7,8,11,12,7,8,10,12,7,9,11,13,7,10,12,13,7,8,12,13,7,8,10,13,7,13,13,13,7,7,13,13,7,7,7,13,7,10,11,14,7,10,13,14,7,8,13,14,7,8,11,14,7,10,12,15,7,11,13,15,7,9,13,15,7,9,11,15,7,15,15,15,7,7,15,15,7,7,7,15,7,11,14,18,7,12,16,18,7,9,16,18,7,9,13,18,7,18,18,18,7,7,18,18,7,7,7,18,7,12,16,21,7,14,18,21,7,10,18,21,7,10,14,21,7,21,21,21,7,7,21,21,7,7,7,21,7,13,18,24,7,15,20,24,7,11,20,24,7,11,16,24,7,24,24,24,7,7,24,24,7,7,7,24,7,14,20,27,7,17,22,27,7,12,22,27,7,12,17,27,7,27,27,27,7,7,27,27,7,7,7,27,7,18,25,30,7,12,25,30,7,12,19,30,7,30,30,30,7,7,30,30,7,7,7,30,7,20,27,33,7,13,27,33,7,13,20,33,7,33,33,33,7,7,33,33,7,7,7,33,7,21,29,36,7,14,29,36,7,14,22,36,7,36,36,36,7,7,36,36,7,7,7,36,7,23,31,39,7,15,31,39,7,15,23,39,7,39,39,39,7,7,39,39,7,7,7,39,7,42,42,42,7,7,42,42,7,7,7,42,7,25,34,43,7,16,34,43,7,16,25,43,7,47,47,47,7,7,47,47,7,7,7,47,7,53,53,53,7,7,53,53,7,7,7,53,8,9,9,10,8,9,10,11,8,10,11,12,8,9,11,12,8,9,10,12,8,10,11,13,8,10,12,13,8,9,12,13,8,9,11,13,8,10,12,14,8,11,13,14,8,9,13,14,8,9,11,14,8,14,14,14,8,8,14,14,8,8,8,14,8,11,12,15,8,11,14,15,8,9,14,15,8,9,12,15,8,11,13,16,8,12,14,16,8,10,14,16,8,10,12,16,8,16,16,16,8,8,16,16,8,8,8,16,8,12,15,19,8,13,17,19,8,10,17,19,8,10,14,19,8,19,19,19,8,8,19,19,8,8,8,19,8,13,17,22,8,15,19,22,8,11,19,22,8,11,15,22,8,22,22,22,8,8,22,22,8,8,8,22,8,14,19,25,8,16,21,25,8,12,21,25,8,12,17,25,8,25,25,25,8,8,25,25,8,8,8,25,8,15,21,28,8,18,23,28,8,13,23,28,8,13,18,28,8,28,28,28,8,8,28,28,8,8,8,28,8,19,26,31,8,13,26,31,8,13,20,31,8,31,31,31,8,8,31,31,8,8,8,31,8,21,28,34,8,14,28,34,8,14,21,34,8,34,34,34,8,8,34,34,8,8,8,34,8,22,30,37,8,15,30,37,8,15,23,37,8,37,37,37,8,8,37,37,8,8,8,37,8,24,32,40,8,16,32,40,8,16,24,40,8,40,40,40,8,8,40,40,8,8,8,40,8,43,43,43,8,8,43,43,8,8,8,43,8,26,35,44,8,17,35,44,8,17,26,44,8,48,48,48,8,8,48,48,8,8,8,48,8,54,54,54,8,8,54,54,8,8,8,54,9,10,10,11,9,10,11,12,9,11,12,13,9,10,12,13,9,10,11,13,9,11,12,14,9,11,13,14,9,10,13,14,9,10,12,14,9,11,13,15,9,12,14,15,9,10,14,15,9,10,12,15,9,15,15,15,9,9,15,15,9,9,9,15,9,12,13,16,9,12,15,16,9,10,15,16,9,10,13,16,9,12,14,17,9,13,15,17,9,11,15,17,9,11,13,17,9,17,17,17,9,9,17,17,9,9,9,17,9,13,16,20,9,14,18,20,9,11,18,20,9,11,15,20,9,20,20,20,9,9,20,20,9,9,9,20,9,14,18,23,9,16,20,23,9,12,20,23,9,12,16,23,9,23,23,23,9,9,23,23,9,9,9,23,9,15,20,26,9,17,22,26,9,13,22,26,9,13,18,26,9,26,26,26,9,9,26,26,9,9,9,26,9,16,22,29,9,19,24,29,9,14,24,29,9,14,19,29,9,29,29,29,9,9,29,29,9,9,9,29,9,20,27,32,9,14,27,32,9,14,21,32,9,32,32,32,9,9,32,32,9,9,9,32,9,22,29,35,9,15,29,35,9,15,22,35,9,35,35,35,9,9,35,35,9,9,9,35,9,23,31,38,9,16,31,38,9,16,24,38,9,38,38,38,9,9,38,38,9,9,9,38,9,25,33,41,9,17,33,41,9,17,25,41,9,41,41,41,9,9,41,41,9,9,9,41,9,44,44,44,9,9,44,44,9,9,9,44,9,27,36,45,9,18,36,45,9,18,27,45,9,49,49,49,9,9,49,49,9,9,9,49,9,55,55,55,9,9,55,55,9,9,9,55,10,11,11,12,10,11,12,13,10,12,13,14,10,11,13,14,10,11,12,14,10,12,13,15,10,12,14,15,10,11,14,15,10,11,13,15,10,12,14,16,10,13,15,16,10,11,15,16,10,11,13,16,10,16,16,16,10,10,16,16,10,10,10,16,10,13,14,17,10,13,16,17,10,11,16,17,10,11,14,17,10,13,15,18,10,14,16,18,10,12,16,18,10,12,14,18,10,18,18,18,10,10,18,18,10,10,10,18,10,14,17,21,10,15,19,21,10,12,19,21,10,12,16,21,10,21,21,21,10,10,21,21,10,10,10,21,10,15,19,24,10,17,21,24,10,13,21,24,10,13,17,24,10,24,24,24,10,10,24,24,10,10,10,24,10,16,21,27,10,18,23,27,10,14,23,27,10,14,19,27,10,27,27,27,10,10,27,27,10,10,10,27,10,17,23,30,10,20,25,30,10,15,25,30,10,15,20,30,10,30,30,30,10,10,30,30,10,10,10,30,10,21,28,33,10,15,28,33,10,15,22,33,10,33,33,33,10,10,33,33,10,10,10,33,10,23,30,36,10,16,30,36,10,16,23,36,10,36,36,36,10,10,36,36,10,10,10,36,10,24,32,39,10,17,32,39,10,17,25,39,10,39,39,39,10,10,39,39,10,10,10,39,10,26,34,42,10,18,34,42,10,18,26,42,10,42,42,42,10,10,42,42,10,10,10,42,10,45,45,45,10,10,45,45,10,10,10,45,10,28,37,46,10,19,37,46,10,19,28,46,10,50,50,50,10,10,50,50,10,10,10,50,10,56,56,56,10,10,56,56,10,10,10,56,11,12,12,13,11,12,13,14,11,13,14,15,11,12,14,15,11,12,13,15,11,13,14,16,11,13,15,16,11,12,15,16,11,12,14,16,11,13,15,17,11,14,16,17,11,12,16,17,11,12,14,17,11,17,17,17,11,11,17,17,11,11,11,17,11,14,15,18,11,14,17,18,11,12,17,18,11,12,15,18,11,14,16,19,11,15,17,19,11,13,17,19,11,13,15,19,11,19,19,19,11,11,19,19,11,11,11,19,11,15,18,22,11,16,20,22,11,13,20,22,11,13,17,22,11,22,22,22,11,11,22,22,11,11,11,22,11,16,20,25,11,18,22,25,11,14,22,25,11,14,18,25,11,25,25,25,11,11,25,25,11,11,11,25,11,17,22,28,11,19,24,28,11,15,24,28,11,15,20,28,11,28,28,28,11,11,28,28,11,11,11,28,11,18,24,31,11,21,26,31,11,16,26,31,11,16,21,31,11,31,31,31,11,11,31,31,11,11,11,31,11,22,29,34,11,16,29,34,11,16,23,34,11,34,34,34,11,11,34,34,11,11,11,34,11,24,31,37,11,17,31,37,11,17,24,37,11,37,37,37,11,11,37,37,11,11,11,37,11,25,33,40,11,18,33,40,11,18,26,40,11,40,40,40,11,11,40,40,11,11,11,40,11,27,35,43,11,19,35,43,11,19,27,43,11,43,43,43,11,11,43,43,11,11,11,43,11,46,46,46,11,11,46,46,11,11,11,46,11,29,38,47,11,20,38,47,11,20,29,47,11,51,51,51,11,11,51,51,11,11,11,51,11,57,57,57,11,11,57,57,11,11,11,57,12,13,13,14,12,13,14,15,12,14,15,16,12,13,15,16,12,13,14,16,12,14,15,17,12,14,16,17,12,13,16,17,12,13,15,17,12,14,16,18,12,15,17,18,12,13,17,18,12,13,15,18,12,18,18,18,12,12,18,18,12,12,12,18,12,15,16,19,12,15,18,19,12,13,18,19,12,13,16,19,12,15,17,20,12,16,18,20,12,14,18,20,12,14,16,20,12,20,20,20,12,12,20,20,12,12,12,20,12,16,19,23,12,17,21,23,12,14,21,23,12,14,18,23,12,23,23,23,12,12,23,23,12,12,12,23,12,17,21,26,12,19,23,26,12,15,23,26,12,15,19,26,12,26,26,26,12,12,26,26,12,12,12,26,12,18,23,29,12,20,25,29,12,16,25,29,12,16,21,29,12,29,29,29,12,12,29,29,12,12,12,29,12,19,25,32,12,22,27,32,12,17,27,32,12,17,22,32,12,32,32,32,12,12,32,32,12,12,12,32,12,23,30,35,12,17,30,35,12,17,24,35,12,35,35,35,12,12,35,35,12,12,12,35,12,25,32,38,12,18,32,38,12,18,25,38,12,38,38,38,12,12,38,38,12,12,12,38,12,26,34,41,12,19,34,41,12,19,27,41,12,41,41,41,12,12,41,41,12,12,12,41,12,28,36,44,12,20,36,44,12,20,28,44,12,44,44,44,12,12,44,44,12,12,12,44,12,47,47,47,12,12,47,47,12,12,12,47,12,30,39,48,12,21,39,48,12,21,30,48,12,52,52,52,12,12,52,52,12,12,12,52,12,58,58,58,12,12,58,58,12,12,12,58,13,14,14,15,13,14,15,16,13,15,16,17,13,14,16,17,13,14,15,17,13,15,16,18,13,15,17,18,13,14,17,18,13,14,16,18,13,15,17,19,13,16,18,19,13,14,18,19,13,14,16,19,13,19,19,19,13,13,19,19,13,13,13,19,13,16,17,20,13,16,19,20,13,14,19,20,13,14,17,20,13,16,18,21,13,17,19,21,13,15,19,21,13,15,17,21,13,21,21,21,13,13,21,21,13,13,13,21,13,17,20,24,13,18,22,24,13,15,22,24,13,15,19,24,13,24,24,24,13,13,24,24,13,13,13,24,13,18,22,27,13,20,24,27,13,16,24,27,13,16,20,27,13,27,27,27,13,13,27,27,13,13,13,27,13,19,24,30,13,21,26,30,13,17,26,30,13,17,22,30,13,30,30,30,13,13,30,30,13,13,13,30,13,20,26,33,13,23,28,33,13,18,28,33,13,18,23,33,13,33,33,33,13,13,33,33,13,13,13,33,13,24,31,36,13,18,31,36,13,18,25,36,13,36,36,36,13,13,36,36,13,13,13,36,13,26,33,39,13,19,33,39,13,19,26,39,13,39,39,39,13,13,39,39,13,13,13,39,13,27,35,42,13,20,35,42,13,20,28,42,13,42,42,42,13,13,42,42,13,13,13,42,13,29,37,45,13,21,37,45,13,21,29,45,13,45,45,45,13,13,45,45,13,13,13,45,13,48,48,48,13,13,48,48,13,13,13,48,13,31,40,49,13,22,40,49,13,22,31,49,13,53,53,53,13,13,53,53,13,13,13,53,13,59,59,59,13,13,59,59,13,13,13,59,14,15,15,16,14,15,16,17,14,16,17,18,14,15,17,18,14,15,16,18,14,16,17,19,14,16,18,19,14,15,18,19,14,15,17,19,14,16,18,20,14,17,19,20,14,15,19,20,14,15,17,20,14,20,20,20,14,14,20,20,14,14,14,20,14,17,18,21,14,17,20,21,14,15,20,21,14,15,18,21,14,17,19,22,14,18,20,22,14,16,20,22,14,16,18,22,14,22,22,22,14,14,22,22,14,14,14,22,14,18,21,25,14,19,23,25,14,16,23,25,14,16,20,25,14,25,25,25,14,14,25,25,14,14,14,25,14,19,23,28,14,21,25,28,14,17,25,28,14,17,21,28,14,28,28,28,14,14,28,28,14,14,14,28,14,20,25,31,14,22,27,31,14,18,27,31,14,18,23,31,14,31,31,31,14,14,31,31,14,14,14,31,14,21,27,34,14,24,29,34,14,19,29,34,14,19,24,34,14,34,34,34,14,14,34,34,14,14,14,34,14,25,32,37,14,19,32,37,14,19,26,37,14,37,37,37,14,14,37,37,14,14,14,37,14,27,34,40,14,20,34,40,14,20,27,40,14,40,40,40,14,14,40,40,14,14,14,40,14,28,36,43,14,21,36,43,14,21,29,43,14,43,43,43,14,14,43,43,14,14,14,43,14,30,38,46,14,22,38,46,14,22,30,46,14,46,46,46,14,14,46,46,14,14,14,46,14,49,49,49,14,14,49,49,14,14,14,49,14,32,41,50,14,23,41,50,14,23,32,50,14,54,54,54,14,14,54,54,14,14,14,54,14,60,60,60,14,14,60,60,14,14,14,60,15,16,16,17,15,16,17,18,15,17,18,19,15,16,18,19,15,16,17,19,15,17,18,20,15,17,19,20,15,16,19,20,15,16,18,20,15,17,19,21,15,18,20,21,15,16,20,21,15,16,18,21,15,21,21,21,15,15,21,21,15,15,15,21,15,18,19,22,15,18,21,22,15,16,21,22,15,16,19,22,15,18,20,23,15,19,21,23,15,17,21,23,15,17,19,23,15,23,23,23,15,15,23,23,15,15,15,23,15,19,22,26,15,20,24,26,15,17,24,26,15,17,21,26,15,26,26,26,15,15,26,26,15,15,15,26,15,20,24,29,15,22,26,29,15,18,26,29,15,18,22,29,15,29,29,29,15,15,29,29,15,15,15,29,15,21,26,32,15,23,28,32,15,19,28,32,15,19,24,32,15,32,32,32,15,15,32,32,15,15,15,32,15,22,28,35,15,25,30,35,15,20,30,35,15,20,25,35,15,35,35,35,15,15,35,35,15,15,15,35,15,26,33,38,15,20,33,38,15,20,27,38,15,38,38,38,15,15,38,38,15,15,15,38,15,28,35,41,15,21,35,41,15,21,28,41,15,41,41,41,15,15,41,41,15,15,15,41,15,29,37,44,15,22,37,44,15,22,30,44,15,44,44,44,15,15,44,44,15,15,15,44,15,31,39,47,15,23,39,47,15,23,31,47,15,47,47,47,15,15,47,47,15,15,15,47,15,50,50,50,15,15,50,50,15,15,15,50,15,33,42,51,15,24,42,51,15,24,33,51,15,55,55,55,15,15,55,55,15,15,15,55,15,61,61,61,15,15,61,61,15,15,15,61,16,17,17,18,16,17,18,19,16,18,19,20,16,17,19,20,16,17,18,20,16,18,19,21,16,18,20,21,16,17,20,21,16,17,19,21,16,18,20,22,16,19,21,22,16,17,21,22,16,17,19,22,16,22,22,22,16,16,22,22,16,16,16,22,16,19,20,23,16,19,22,23,16,17,22,23,16,17,20,23,16,19,21,24,16,20,22,24,16,18,22,24,16,18,20,24,16,24,24,24,16,16,24,24,16,16,16,24,16,20,23,27,16,21,25,27,16,18,25,27,16,18,22,27,16,27,27,27,16,16,27,27,16,16,16,27,16,21,25,30,16,23,27,30,16,19,27,30,16,19,23,30,16,30,30,30,16,16,30,30,16,16,16,30,16,22,27,33,16,24,29,33,16,20,29,33,16,20,25,33,16,33,33,33,16,16,33,33,16,16,16,33,16,23,29,36,16,26,31,36,16,21,31,36,16,21,26,36,16,36,36,36,16,16,36,36,16,16,16,36,16,27,34,39,16,21,34,39,16,21,28,39,16,39,39,39,16,16,39,39,16,16,16,39,16,29,36,42,16,22,36,42,16,22,29,42,16,42,42,42,16,16,42,42,16,16,16,42,16,30,38,45,16,23,38,45,16,23,31,45,16,45,45,45,16,16,45,45,16,16,16,45,16,32,40,48,16,24,40,48,16,24,32,48,16,48,48,48,16,16,48,48,16,16,16,48,16,51,51,51,16,16,51,51,16,16,16,51,16,34,43,52,16,25,43,52,16,25,34,52,16,56,56,56,16,16,56,56,16,16,16,56,16,62,62,62,16,16,62,62,16,16,16,62,17,18,18,19,17,18,19,20,17,19,20,21,17,18,20,21,17,18,19,21,17,19,20,22,17,19,21,22,17,18,21,22,17,18,20,22,17,19,21,23,17,20,22,23,17,18,22,23,17,18,20,23,17,23,23,23,17,17,23,23,17,17,17,23,17,20,21,24,17,20,23,24,17,18,23,24,17,18,21,24,17,20,22,25,17,21,23,25,17,19,23,25,17,19,21,25,17,25,25,25,17,17,25,25,17,17,17,25,17,21,24,28,17,22,26,28,17,19,26,28,17,19,23,28,17,28,28,28,17,17,28,28,17,17,17,28,17,22,26,31,17,24,28,31,17,20,28,31,17,20,24,31,17,31,31,31,17,17,31,31,17,17,17,31,17,23,28,34,17,25,30,34,17,21,30,34,17,21,26,34,17,34,34,34,17,17,34,34,17,17,17,34,17,24,30,37,17,27,32,37,17,22,32,37,17,22,27,37,17,37,37,37,17,17,37,37,17,17,17,37,17,28,35,40,17,22,35,40,17,22,29,40,17,40,40,40,17,17,40,40,17,17,17,40,17,30,37,43,17,23,37,43,17,23,30,43,17,43,43,43,17,17,43,43,17,17,17,43,17,31,39,46,17,24,39,46,17,24,32,46,17,46,46,46,17,17,46,46,17,17,17,46,17,33,41,49,17,25,41,49,17,25,33,49,17,49,49,49,17,17,49,49,17,17,17,49,17,52,52,52,17,17,52,52,17,17,17,52,17,35,44,53,17,26,44,53,17,26,35,53,17,57,57,57,17,17,57,57,17,17,17,57,17,63,63,63,17,17,63,63,17,17,17,63,18,19,19,20,18,19,20,21,18,20,21,22,18,19,21,22,18,19,20,22,18,20,21,23,18,20,22,23,18,19,22,23,18,19,21,23,18,20,22,24,18,21,23,24,18,19,23,24,18,19,21,24,18,24,24,24,18,18,24,24,18,18,18,24,18,21,22,25,18,21,24,25,18,19,24,25,18,19,22,25,18,21,23,26,18,22,24,26,18,20,24,26,18,20,22,26,18,26,26,26,18,18,26,26,18,18,18,26,18,22,25,29,18,23,27,29,18,20,27,29,18,20,24,29,18,29,29,29,18,18,29,29,18,18,18,29,18,23,27,32,18,25,29,32,18,21,29,32,18,21,25,32,18,32,32,32,18,18,32,32,18,18,18,32,18,24,29,35,18,26,31,35,18,22,31,35,18,22,27,35,18,35,35,35,18,18,35,35,18,18,18,35,18,25,31,38,18,28,33,38,18,23,33,38,18,23,28,38,18,38,38,38,18,18,38,38,18,18,18,38,18,29,36,41,18,23,36,41,18,23,30,41,18,41,41,41,18,18,41,41,18,18,18,41,18,31,38,44,18,24,38,44,18,24,31,44,18,44,44,44,18,18,44,44,18,18,18,44,18,32,40,47,18,25,40,47,18,25,33,47,18,47,47,47,18,18,47,47,18,18,18,47,18,34,42,50,18,26,42,50,18,26,34,50,18,50,50,50,18,18,50,50,18,18,18,50,18,53,53,53,18,18,53,53,18,18,18,53,18,36,45,54,18,27,45,54,18,27,36,54,18,58,58,58,18,18,58,58,18,18,18,58,19,20,20,21,19,20,21,22,19,21,22,23,19,20,22,23,19,20,21,23,19,21,22,24,19,21,23,24,19,20,23,24,19,20,22,24,19,21,23,25,19,22,24,25,19,20,24,25,19,20,22,25,19,25,25,25,19,19,25,25,19,19,19,25,19,22,23,26,19,22,25,26,19,20,25,26,19,20,23,26,19,22,24,27,19,23,25,27,19,21,25,27,19,21,23,27,19,27,27,27,19,19,27,27,19,19,19,27,19,23,26,30,19,24,28,30,19,21,28,30,19,21,25,30,19,30,30,30,19,19,30,30,19,19,19,30,19,24,28,33,19,26,30,33,19,22,30,33,19,22,26,33,19,33,33,33,19,19,33,33,19,19,19,33,19,25,30,36,19,27,32,36,19,23,32,36,19,23,28,36,19,36,36,36,19,19,36,36,19,19,19,36,19,26,32,39,19,29,34,39,19,24,34,39,19,24,29,39,19,39,39,39,19,19,39,39,19,19,19,39,19,30,37,42,19,24,37,42,19,24,31,42,19,42,42,42,19,19,42,42,19,19,19,42,19,32,39,45,19,25,39,45,19,25,32,45,19,45,45,45,19,19,45,45,19,19,19,45,19,33,41,48,19,26,41,48,19,26,34,48,19,48,48,48,19,19,48,48,19,19,19,48,19,35,43,51,19,27,43,51,19,27,35,51,19,51,51,51,19,19,51,51,19,19,19,51,19,54,54,54,19,19,54,54,19,19,19,54,19,37,46,55,19,28,46,55,19,28,37,55,19,59,59,59,19,19,59,59,19,19,19,59,20,21,21,22,20,21,22,23,20,22,23,24,20,21,23,24,20,21,22,24,20,22,23,25,20,22,24,25,20,21,24,25,20,21,23,25,20,22,24,26,20,23,25,26,20,21,25,26,20,21,23,26,20,26,26,26,20,20,26,26,20,20,20,26,20,23,24,27,20,23,26,27,20,21,26,27,20,21,24,27,20,23,25,28,20,24,26,28,20,22,26,28,20,22,24,28,20,28,28,28,20,20,28,28,20,20,20,28,20,24,27,31,20,25,29,31,20,22,29,31,20,22,26,31,20,31,31,31,20,20,31,31,20,20,20,31,20,25,29,34,20,27,31,34,20,23,31,34,20,23,27,34,20,34,34,34,20,20,34,34,20,20,20,34,20,26,31,37,20,28,33,37,20,24,33,37,20,24,29,37,20,37,37,37,20,20,37,37,20,20,20,37,20,27,33,40,20,30,35,40,20,25,35,40,20,25,30,40,20,40,40,40,20,20,40,40,20,20,20,40,20,31,38,43,20,25,38,43,20,25,32,43,20,43,43,43,20,20,43,43,20,20,20,43,20,33,40,46,20,26,40,46,20,26,33,46,20,46,46,46,20,20,46,46,20,20,20,46,20,34,42,49,20,27,42,49,20,27,35,49,20,49,49,49,20,20,49,49,20,20,20,49,20,36,44,52,20,28,44,52,20,28,36,52,20,52,52,52,20,20,52,52,20,20,20,52,20,55,55,55,20,20,55,55,20,20,20,55,20,38,47,56,20,29,47,56,20,29,38,56,20,60,60,60,20,20,60,60,20,20,20,60,21,22,22,23,21,22,23,24,21,23,24,25,21,22,24,25,21,22,23,25,21,23,24,26,21,23,25,26,21,22,25,26,21,22,24,26,21,23,25,27,21,24,26,27,21,22,26,27,21,22,24,27,21,27,27,27,21,21,27,27,21,21,21,27,21,24,25,28,21,24,27,28,21,22,27,28,21,22,25,28,21,24,26,29,21,25,27,29,21,23,27,29,21,23,25,29,21,29,29,29,21,21,29,29,21,21,21,29,21,25,28,32,21,26,30,32,21,23,30,32,21,23,27,32,21,32,32,32,21,21,32,32,21,21,21,32,21,26,30,35,21,28,32,35,21,24,32,35,21,24,28,35,21,35,35,35,21,21,35,35,21,21,21,35,21,27,32,38,21,29,34,38,21,25,34,38,21,25,30,38,21,38,38,38,21,21,38,38,21,21,21,38,21,28,34,41,21,31,36,41,21,26,36,41,21,26,31,41,21,41,41,41,21,21,41,41,21,21,21,41,21,32,39,44,21,26,39,44,21,26,33,44,21,44,44,44,21,21,44,44,21,21,21,44,21,34,41,47,21,27,41,47,21,27,34,47,21,47,47,47,21,21,47,47,21,21,21,47,21,35,43,50,21,28,43,50,21,28,36,50,21,50,50,50,21,21,50,50,21,21,21,50,21,37,45,53,21,29,45,53,21,29,37,53,21,53,53,53,21,21,53,53,21,21,21,53,21,56,56,56,21,21,56,56,21,21,21,56,21,39,48,57,21,30,48,57,21,30,39,57,21,61,61,61,21,21,61,61,21,21,21,61,22,23,23,24,22,23,24,25,22,24,25,26,22,23,25,26,22,23,24,26,22,24,25,27,22,24,26,27,22,23,26,27,22,23,25,27,22,24,26,28,22,25,27,28,22,23,27,28,22,23,25,28,22,28,28,28,22,22,28,28,22,22,22,28,22,25,26,29,22,25,28,29,22,23,28,29,22,23,26,29,22,25,27,30,22,26,28,30,22,24,28,30,22,24,26,30,22,30,30,30,22,22,30,30,22,22,22,30,22,26,29,33,22,27,31,33,22,24,31,33,22,24,28,33,22,33,33,33,22,22,33,33,22,22,22,33,22,27,31,36,22,29,33,36,22,25,33,36,22,25,29,36,22,36,36,36,22,22,36,36,22,22,22,36,22,28,33,39,22,30,35,39,22,26,35,39,22,26,31,39,22,39,39,39,22,22,39,39,22,22,22,39,22,29,35,42,22,32,37,42,22,27,37,42,22,27,32,42,22,42,42,42,22,22,42,42,22,22,22,42,22,33,40,45,22,27,40,45,22,27,34,45,22,45,45,45,22,22,45,45,22,22,22,45,22,35,42,48,22,28,42,48,22,28,35,48,22,48,48,48,22,22,48,48,22,22,22,48,22,36,44,51,22,29,44,51,22,29,37,51,22,51,51,51,22,22,51,51,22,22,22,51,22,38,46,54,22,30,46,54,22,30,38,54,22,54,54,54,22,22,54,54,22,22,22,54,22,57,57,57,22,22,57,57,22,22,22,57,22,40,49,58,22,31,49,58,22,31,40,58,22,62,62,62,22,22,62,62,22,22,22,62,23,24,24,25,23,24,25,26,23,25,26,27,23,24,26,27,23,24,25,27,23,25,26,28,23,25,27,28,23,24,27,28,23,24,26,28,23,25,27,29,23,26,28,29,23,24,28,29,23,24,26,29,23,29,29,29,23,23,29,29,23,23,23,29,23,26,27,30,23,26,29,30,23,24,29,30,23,24,27,30,23,26,28,31,23,27,29,31,23,25,29,31,23,25,27,31,23,31,31,31,23,23,31,31,23,23,23,31,23,27,30,34,23,28,32,34,23,25,32,34,23,25,29,34,23,34,34,34,23,23,34,34,23,23,23,34,23,28,32,37,23,30,34,37,23,26,34,37,23,26,30,37,23,37,37,37,23,23,37,37,23,23,23,37,23,29,34,40,23,31,36,40,23,27,36,40,23,27,32,40,23,40,40,40,23,23,40,40,23,23,23,40,23,30,36,43,23,33,38,43,23,28,38,43,23,28,33,43,23,43,43,43,23,23,43,43,23,23,23,43,23,34,41,46,23,28,41,46,23,28,35,46,23,46,46,46,23,23,46,46,23,23,23,46,23,36,43,49,23,29,43,49,23,29,36,49,23,49,49,49,23,23,49,49,23,23,23,49,23,37,45,52,23,30,45,52,23,30,38,52,23,52,52,52,23,23,52,52,23,23,23,52,23,39,47,55,23,31,47,55,23,31,39,55,23,55,55,55,23,23,55,55,23,23,23,55,23,58,58,58,23,23,58,58,23,23,23,58,23,41,50,59,23,32,50,59,23,32,41,59,23,63,63,63,23,23,63,63,23,23,23,63,24,25,25,26,24,25,26,27,24,26,27,28,24,25,27,28,24,25,26,28,24,26,27,29,24,26,28,29,24,25,28,29,24,25,27,29,24,26,28,30,24,27,29,30,24,25,29,30,24,25,27,30,24,30,30,30,24,24,30,30,24,24,24,30,24,27,28,31,24,27,30,31,24,25,30,31,24,25,28,31,24,27,29,32,24,28,30,32,24,26,30,32,24,26,28,32,24,32,32,32,24,24,32,32,24,24,24,32,24,28,31,35,24,29,33,35,24,26,33,35,24,26,30,35,24,35,35,35,24,24,35,35,24,24,24,35,24,29,33,38,24,31,35,38,24,27,35,38,24,27,31,38,24,38,38,38,24,24,38,38,24,24,24,38,24,30,35,41,24,32,37,41,24,28,37,41,24,28,33,41,24,41,41,41,24,24,41,41,24,24,24,41,24,31,37,44,24,34,39,44,24,29,39,44,24,29,34,44,24,44,44,44,24,24,44,44,24,24,24,44,24,35,42,47,24,29,42,47,24,29,36,47,24,47,47,47,24,24,47,47,24,24,24,47,24,37,44,50,24,30,44,50,24,30,37,50,24,50,50,50,24,24,50,50,24,24,24,50,24,38,46,53,24,31,46,53,24,31,39,53,24,53,53,53,24,24,53,53,24,24,24,53,24,40,48,56,24,32,48,56,24,32,40,56,24,56,56,56,24,24,56,56,24,24,24,56,24,59,59,59,24,24,59,59,24,24,24,59,24,42,51,60,24,33,51,60,24,33,42,60,25,26,26,27,25,26,27,28,25,27,28,29,25,26,28,29,25,26,27,29,25,27,28,30,25,27,29,30,25,26,29,30,25,26,28,30,25,27,29,31,25,28,30,31,25,26,30,31,25,26,28,31,25,31,31,31,25,25,31,31,25,25,25,31,25,28,29,32,25,28,31,32,25,26,31,32,25,26,29,32,25,28,30,33,25,29,31,33,25,27,31,33,25,27,29,33,25,33,33,33,25,25,33,33,25,25,25,33,25,29,32,36,25,30,34,36,25,27,34,36,25,27,31,36,25,36,36,36,25,25,36,36,25,25,25,36,25,30,34,39,25,32,36,39,25,28,36,39,25,28,32,39,25,39,39,39,25,25,39,39,25,25,25,39,25,31,36,42,25,33,38,42,25,29,38,42,25,29,34,42,25,42,42,42,25,25,42,42,25,25,25,42,25,32,38,45,25,35,40,45,25,30,40,45,25,30,35,45,25,45,45,45,25,25,45,45,25,25,25,45,25,36,43,48,25,30,43,48,25,30,37,48,25,48,48,48,25,25,48,48,25,25,25,48,25,38,45,51,25,31,45,51,25,31,38,51,25,51,51,51,25,25,51,51,25,25,25,51,25,39,47,54,25,32,47,54,25,32,40,54,25,54,54,54,25,25,54,54,25,25,25,54,25,41,49,57,25,33,49,57,25,33,41,57,25,57,57,57,25,25,57,57,25,25,25,57,25,60,60,60,25,25,60,60,25,25,25,60,25,43,52,61,25,34,52,61,25,34,43,61,26,27,27,28,26,27,28,29,26,28,29,30,26,27,29,30,26,27,28,30,26,28,29,31,26,28,30,31,26,27,30,31,26,27,29,31,26,28,30,32,26,29,31,32,26,27,31,32,26,27,29,32,26,32,32,32,26,26,32,32,26,26,26,32,26,29,30,33,26,29,32,33,26,27,32,33,26,27,30,33,26,29,31,34,26,30,32,34,26,28,32,34,26,28,30,34,26,34,34,34,26,26,34,34,26,26,26,34,26,30,33,37,26,31,35,37,26,28,35,37,26,28,32,37,26,37,37,37,26,26,37,37,26,26,26,37,26,31,35,40,26,33,37,40,26,29,37,40,26,29,33,40,26,40,40,40,26,26,40,40,26,26,26,40,26,32,37,43,26,34,39,43,26,30,39,43,26,30,35,43,26,43,43,43,26,26,43,43,26,26,26,43,26,33,39,46,26,36,41,46,26,31,41,46,26,31,36,46,26,46,46,46,26,26,46,46,26,26,26,46,26,37,44,49,26,31,44,49,26,31,38,49,26,49,49,49,26,26,49,49,26,26,26,49,26,39,46,52,26,32,46,52,26,32,39,52,26,52,52,52,26,26,52,52,26,26,26,52,26,40,48,55,26,33,48,55,26,33,41,55,26,55,55,55,26,26,55,55,26,26,26,55,26,42,50,58,26,34,50,58,26,34,42,58,26,58,58,58,26,26,58,58,26,26,26,58,26,61,61,61,26,26,61,61,26,26,26,61,26,44,53,62,26,35,53,62,26,35,44,62,27,28,28,29,27,28,29,30,27,29,30,31,27,28,30,31,27,28,29,31,27,29,30,32,27,29,31,32,27,28,31,32,27,28,30,32,27,29,31,33,27,30,32,33,27,28,32,33,27,28,30,33,27,33,33,33,27,27,33,33,27,27,27,33,27,30,31,34,27,30,33,34,27,28,33,34,27,28,31,34,27,30,32,35,27,31,33,35,27,29,33,35,27,29,31,35,27,35,35,35,27,27,35,35,27,27,27,35,27,31,34,38,27,32,36,38,27,29,36,38,27,29,33,38,27,38,38,38,27,27,38,38,27,27,27,38,27,32,36,41,27,34,38,41,27,30,38,41,27,30,34,41,27,41,41,41,27,27,41,41,27,27,27,41,27,33,38,44,27,35,40,44,27,31,40,44,27,31,36,44,27,44,44,44,27,27,44,44,27,27,27,44,27,34,40,47,27,37,42,47,27,32,42,47,27,32,37,47,27,47,47,47,27,27,47,47,27,27,27,47,27,38,45,50,27,32,45,50,27,32,39,50,27,50,50,50,27,27,50,50,27,27,27,50,27,40,47,53,27,33,47,53,27,33,40,53,27,53,53,53,27,27,53,53,27,27,27,53,27,41,49,56,27,34,49,56,27,34,42,56,27,56,56,56,27,27,56,56,27,27,27,56,27,43,51,59,27,35,51,59,27,35,43,59,27,59,59,59,27,27,59,59,27,27,27,59,27,62,62,62,27,27,62,62,27,27,27,62,27,45,54,63,27,36,54,63,27,36,45,63,28,29,29,30,28,29,30,31,28,30,31,32,28,29,31,32,28,29,30,32,28,30,31,33,28,30,32,33,28,29,32,33,28,29,31,33,28,30,32,34,28,31,33,34,28,29,33,34,28,29,31,34,28,34,34,34,28,28,34,34,28,28,28,34,28,31,32,35,28,31,34,35,28,29,34,35,28,29,32,35,28,31,33,36,28,32,34,36,28,30,34,36,28,30,32,36,28,36,36,36,28,28,36,36,28,28,28,36,28,32,35,39,28,33,37,39,28,30,37,39,28,30,34,39,28,39,39,39,28,28,39,39,28,28,28,39,28,33,37,42,28,35,39,42,28,31,39,42,28,31,35,42,28,42,42,42,28,28,42,42,28,28,28,42,28,34,39,45,28,36,41,45,28,32,41,45,28,32,37,45,28,45,45,45,28,28,45,45,28,28,28,45,28,35,41,48,28,38,43,48,28,33,43,48,28,33,38,48,28,48,48,48,28,28,48,48,28,28,28,48,28,39,46,51,28,33,46,51,28,33,40,51,28,51,51,51,28,28,51,51,28,28,28,51,28,41,48,54,28,34,48,54,28,34,41,54,28,54,54,54,28,28,54,54,28,28,28,54,28,42,50,57,28,35,50,57,28,35,43,57,28,57,57,57,28,28,57,57,28,28,28,57,28,44,52,60,28,36,52,60,28,36,44,60,28,60,60,60,28,28,60,60,28,28,28,60,28,63,63,63,28,28,63,63,28,28,28,63,29,30,30,31,29,30,31,32,29,31,32,33,29,30,32,33,29,30,31,33,29,31,32,34,29,31,33,34,29,30,33,34,29,30,32,34,29,31,33,35,29,32,34,35,29,30,34,35,29,30,32,35,29,35,35,35,29,29,35,35,29,29,29,35,29,32,33,36,29,32,35,36,29,30,35,36,29,30,33,36,29,32,34,37,29,33,35,37,29,31,35,37,29,31,33,37,29,37,37,37,29,29,37,37,29,29,29,37,29,33,36,40,29,34,38,40,29,31,38,40,29,31,35,40,29,40,40,40,29,29,40,40,29,29,29,40,29,34,38,43,29,36,40,43,29,32,40,43,29,32,36,43,29,43,43,43,29,29,43,43,29,29,29,43,29,35,40,46,29,37,42,46,29,33,42,46,29,33,38,46,29,46,46,46,29,29,46,46,29,29,29,46,29,36,42,49,29,39,44,49,29,34,44,49,29,34,39,49,29,49,49,49,29,29,49,49,29,29,29,49,29,40,47,52,29,34,47,52,29,34,41,52,29,52,52,52,29,29,52,52,29,29,29,52,29,42,49,55,29,35,49,55,29,35,42,55,29,55,55,55,29,29,55,55,29,29,29,55,29,43,51,58,29,36,51,58,29,36,44,58,29,58,58,58,29,29,58,58,29,29,29,58,29,45,53,61,29,37,53,61,29,37,45,61,29,61,61,61,29,29,61,61,29,29,29,61,30,31,31,32,30,31,32,33,30,32,33,34,30,31,33,34,30,31,32,34,30,32,33,35,30,32,34,35,30,31,34,35,30,31,33,35,30,32,34,36,30,33,35,36,30,31,35,36,30,31,33,36,30,36,36,36,30,30,36,36,30,30,30,36,30,33,34,37,30,33,36,37,30,31,36,37,30,31,34,37,30,33,35,38,30,34,36,38,30,32,36,38,30,32,34,38,30,38,38,38,30,30,38,38,30,30,30,38,30,34,37,41,30,35,39,41,30,32,39,41,30,32,36,41,30,41,41,41,30,30,41,41,30,30,30,41,30,35,39,44,30,37,41,44,30,33,41,44,30,33,37,44,30,44,44,44,30,30,44,44,30,30,30,44,30,36,41,47,30,38,43,47,30,34,43,47,30,34,39,47,30,47,47,47,30,30,47,47,30,30,30,47,30,37,43,50,30,40,45,50,30,35,45,50,30,35,40,50,30,50,50,50,30,30,50,50,30,30,30,50,30,41,48,53,30,35,48,53,30,35,42,53,30,53,53,53,30,30,53,53,30,30,30,53,30,43,50,56,30,36,50,56,30,36,43,56,30,56,56,56,30,30,56,56,30,30,30,56,30,44,52,59,30,37,52,59,30,37,45,59,30,59,59,59,30,30,59,59,30,30,30,59,30,46,54,62,30,38,54,62,30,38,46,62,30,62,62,62,30,30,62,62,30,30,30,62,31,32,32,33,31,32,33,34,31,33,34,35,31,32,34,35,31,32,33,35,31,33,34,36,31,33,35,36,31,32,35,36,31,32,34,36,31,33,35,37,31,34,36,37,31,32,36,37,31,32,34,37,31,37,37,37,31,31,37,37,31,31,31,37,31,34,35,38,31,34,37,38,31,32,37,38,31,32,35,38,31,34,36,39,31,35,37,39,31,33,37,39,31,33,35,39,31,39,39,39,31,31,39,39,31,31,31,39,31,35,38,42,31,36,40,42,31,33,40,42,31,33,37,42,31,42,42,42,31,31,42,42,31,31,31,42,31,36,40,45,31,38,42,45,31,34,42,45,31,34,38,45,31,45,45,45,31,31,45,45,31,31,31,45,31,37,42,48,31,39,44,48,31,35,44,48,31,35,40,48,31,48,48,48,31,31,48,48,31,31,31,48,31,38,44,51,31,41,46,51,31,36,46,51,31,36,41,51,31,51,51,51,31,31,51,51,31,31,31,51,31,42,49,54,31,36,49,54,31,36,43,54,31,54,54,54,31,31,54,54,31,31,31,54,31,44,51,57,31,37,51,57,31,37,44,57,31,57,57,57,31,31,57,57,31,31,31,57,31,45,53,60,31,38,53,60,31,38,46,60,31,60,60,60,31,31,60,60,31,31,31,60,31,47,55,63,31,39,55,63,31,39,47,63,31,63,63,63,31,31,63,63,31,31,31,63,32,33,33,34,32,33,34,35,32,34,35,36,32,33,35,36,32,33,34,36,32,34,35,37,32,34,36,37,32,33,36,37,32,33,35,37,32,34,36,38,32,35,37,38,32,33,37,38,32,33,35,38,32,38,38,38,32,32,38,38,32,32,32,38,32,35,36,39,32,35,38,39,32,33,38,39,32,33,36,39,32,35,37,40,32,36,38,40,32,34,38,40,32,34,36,40,32,40,40,40,32,32,40,40,32,32,32,40,32,36,39,43,32,37,41,43,32,34,41,43,32,34,38,43,32,43,43,43,32,32,43,43,32,32,32,43,32,37,41,46,32,39,43,46,32,35,43,46,32,35,39,46,32,46,46,46,32,32,46,46,32,32,32,46,32,38,43,49,32,40,45,49,32,36,45,49,32,36,41,49,32,49,49,49,32,32,49,49,32,32,32,49,32,39,45,52,32,42,47,52,32,37,47,52,32,37,42,52,32,52,52,52,32,32,52,52,32,32,32,52,32,43,50,55,32,37,50,55,32,37,44,55,32,55,55,55,32,32,55,55,32,32,32,55,32,45,52,58,32,38,52,58,32,38,45,58,32,58,58,58,32,32,58,58,32,32,32,58,32,46,54,61,32,39,54,61,32,39,47,61,32,61,61,61,32,32,61,61,32,32,32,61,33,34,34,35,33,34,35,36,33,35,36,37,33,34,36,37,33,34,35,37,33,35,36,38,33,35,37,38,33,34,37,38,33,34,36,38,33,35,37,39,33,36,38,39,33,34,38,39,33,34,36,39,33,39,39,39,33,33,39,39,33,33,33,39,33,36,37,40,33,36,39,40,33,34,39,40,33,34,37,40,33,36,38,41,33,37,39,41,33,35,39,41,33,35,37,41,33,41,41,41,33,33,41,41,33,33,33,41,33,37,40,44,33,38,42,44,33,35,42,44,33,35,39,44,33,44,44,44,33,33,44,44,33,33,33,44,33,38,42,47,33,40,44,47,33,36,44,47,33,36,40,47,33,47,47,47,33,33,47,47,33,33,33,47,33,39,44,50,33,41,46,50,33,37,46,50,33,37,42,50,33,50,50,50,33,33,50,50,33,33,33,50,33,40,46,53,33,43,48,53,33,38,48,53,33,38,43,53,33,53,53,53,33,33,53,53,33,33,33,53,33,44,51,56,33,38,51,56,33,38,45,56,33,56,56,56,33,33,56,56,33,33,33,56,33,46,53,59,33,39,53,59,33,39,46,59,33,59,59,59,33,33,59,59,33,33,33,59,33,47,55,62,33,40,55,62,33,40,48,62,33,62,62,62,33,33,62,62,33,33,33,62,34,35,35,36,34,35,36,37,34,36,37,38,34,35,37,38,34,35,36,38,34,36,37,39,34,36,38,39,34,35,38,39,34,35,37,39,34,36,38,40,34,37,39,40,34,35,39,40,34,35,37,40,34,40,40,40,34,34,40,40,34,34,34,40,34,37,38,41,34,37,40,41,34,35,40,41,34,35,38,41,34,37,39,42,34,38,40,42,34,36,40,42,34,36,38,42,34,42,42,42,34,34,42,42,34,34,34,42,34,38,41,45,34,39,43,45,34,36,43,45,34,36,40,45,34,45,45,45,34,34,45,45,34,34,34,45,34,39,43,48,34,41,45,48,34,37,45,48,34,37,41,48,34,48,48,48,34,34,48,48,34,34,34,48,34,40,45,51,34,42,47,51,34,38,47,51,34,38,43,51,34,51,51,51,34,34,51,51,34,34,34,51,34,41,47,54,34,44,49,54,34,39,49,54,34,39,44,54,34,54,54,54,34,34,54,54,34,34,34,54,34,45,52,57,34,39,52,57,34,39,46,57,34,57,57,57,34,34,57,57,34,34,34,57,34,47,54,60,34,40,54,60,34,40,47,60,34,60,60,60,34,34,60,60,34,34,34,60,34,48,56,63,34,41,56,63,34,41,49,63,34,63,63,63,34,34,63,63,34,34,34,63,35,36,36,37,35,36,37,38,35,37,38,39,35,36,38,39,35,36,37,39,35,37,38,40,35,37,39,40,35,36,39,40,35,36,38,40,35,37,39,41,35,38,40,41,35,36,40,41,35,36,38,41,35,41,41,41,35,35,41,41,35,35,35,41,35,38,39,42,35,38,41,42,35,36,41,42,35,36,39,42], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+286720);
/* memory initializer */ allocate([35,38,40,43,35,39,41,43,35,37,41,43,35,37,39,43,35,43,43,43,35,35,43,43,35,35,35,43,35,39,42,46,35,40,44,46,35,37,44,46,35,37,41,46,35,46,46,46,35,35,46,46,35,35,35,46,35,40,44,49,35,42,46,49,35,38,46,49,35,38,42,49,35,49,49,49,35,35,49,49,35,35,35,49,35,41,46,52,35,43,48,52,35,39,48,52,35,39,44,52,35,52,52,52,35,35,52,52,35,35,35,52,35,42,48,55,35,45,50,55,35,40,50,55,35,40,45,55,35,55,55,55,35,35,55,55,35,35,35,55,35,46,53,58,35,40,53,58,35,40,47,58,35,58,58,58,35,35,58,58,35,35,35,58,35,48,55,61,35,41,55,61,35,41,48,61,35,61,61,61,35,35,61,61,35,35,35,61,36,37,37,38,36,37,38,39,36,38,39,40,36,37,39,40,36,37,38,40,36,38,39,41,36,38,40,41,36,37,40,41,36,37,39,41,36,38,40,42,36,39,41,42,36,37,41,42,36,37,39,42,36,42,42,42,36,36,42,42,36,36,36,42,36,39,40,43,36,39,42,43,36,37,42,43,36,37,40,43,36,39,41,44,36,40,42,44,36,38,42,44,36,38,40,44,36,44,44,44,36,36,44,44,36,36,36,44,36,40,43,47,36,41,45,47,36,38,45,47,36,38,42,47,36,47,47,47,36,36,47,47,36,36,36,47,36,41,45,50,36,43,47,50,36,39,47,50,36,39,43,50,36,50,50,50,36,36,50,50,36,36,36,50,36,42,47,53,36,44,49,53,36,40,49,53,36,40,45,53,36,53,53,53,36,36,53,53,36,36,36,53,36,43,49,56,36,46,51,56,36,41,51,56,36,41,46,56,36,56,56,56,36,36,56,56,36,36,36,56,36,47,54,59,36,41,54,59,36,41,48,59,36,59,59,59,36,36,59,59,36,36,36,59,36,49,56,62,36,42,56,62,36,42,49,62,36,62,62,62,36,36,62,62,36,36,36,62,37,38,38,39,37,38,39,40,37,39,40,41,37,38,40,41,37,38,39,41,37,39,40,42,37,39,41,42,37,38,41,42,37,38,40,42,37,39,41,43,37,40,42,43,37,38,42,43,37,38,40,43,37,43,43,43,37,37,43,43,37,37,37,43,37,40,41,44,37,40,43,44,37,38,43,44,37,38,41,44,37,40,42,45,37,41,43,45,37,39,43,45,37,39,41,45,37,45,45,45,37,37,45,45,37,37,37,45,37,41,44,48,37,42,46,48,37,39,46,48,37,39,43,48,37,48,48,48,37,37,48,48,37,37,37,48,37,42,46,51,37,44,48,51,37,40,48,51,37,40,44,51,37,51,51,51,37,37,51,51,37,37,37,51,37,43,48,54,37,45,50,54,37,41,50,54,37,41,46,54,37,54,54,54,37,37,54,54,37,37,37,54,37,44,50,57,37,47,52,57,37,42,52,57,37,42,47,57,37,57,57,57,37,37,57,57,37,37,37,57,37,48,55,60,37,42,55,60,37,42,49,60,37,60,60,60,37,37,60,60,37,37,37,60,37,50,57,63,37,43,57,63,37,43,50,63,37,63,63,63,37,37,63,63,37,37,37,63,38,39,39,40,38,39,40,41,38,40,41,42,38,39,41,42,38,39,40,42,38,40,41,43,38,40,42,43,38,39,42,43,38,39,41,43,38,40,42,44,38,41,43,44,38,39,43,44,38,39,41,44,38,44,44,44,38,38,44,44,38,38,38,44,38,41,42,45,38,41,44,45,38,39,44,45,38,39,42,45,38,41,43,46,38,42,44,46,38,40,44,46,38,40,42,46,38,46,46,46,38,38,46,46,38,38,38,46,38,42,45,49,38,43,47,49,38,40,47,49,38,40,44,49,38,49,49,49,38,38,49,49,38,38,38,49,38,43,47,52,38,45,49,52,38,41,49,52,38,41,45,52,38,52,52,52,38,38,52,52,38,38,38,52,38,44,49,55,38,46,51,55,38,42,51,55,38,42,47,55,38,55,55,55,38,38,55,55,38,38,38,55,38,45,51,58,38,48,53,58,38,43,53,58,38,43,48,58,38,58,58,58,38,38,58,58,38,38,38,58,38,49,56,61,38,43,56,61,38,43,50,61,38,61,61,61,38,38,61,61,38,38,38,61,39,40,40,41,39,40,41,42,39,41,42,43,39,40,42,43,39,40,41,43,39,41,42,44,39,41,43,44,39,40,43,44,39,40,42,44,39,41,43,45,39,42,44,45,39,40,44,45,39,40,42,45,39,45,45,45,39,39,45,45,39,39,39,45,39,42,43,46,39,42,45,46,39,40,45,46,39,40,43,46,39,42,44,47,39,43,45,47,39,41,45,47,39,41,43,47,39,47,47,47,39,39,47,47,39,39,39,47,39,43,46,50,39,44,48,50,39,41,48,50,39,41,45,50,39,50,50,50,39,39,50,50,39,39,39,50,39,44,48,53,39,46,50,53,39,42,50,53,39,42,46,53,39,53,53,53,39,39,53,53,39,39,39,53,39,45,50,56,39,47,52,56,39,43,52,56,39,43,48,56,39,56,56,56,39,39,56,56,39,39,39,56,39,46,52,59,39,49,54,59,39,44,54,59,39,44,49,59,39,59,59,59,39,39,59,59,39,39,39,59,39,50,57,62,39,44,57,62,39,44,51,62,39,62,62,62,39,39,62,62,39,39,39,62,40,41,41,42,40,41,42,43,40,42,43,44,40,41,43,44,40,41,42,44,40,42,43,45,40,42,44,45,40,41,44,45,40,41,43,45,40,42,44,46,40,43,45,46,40,41,45,46,40,41,43,46,40,46,46,46,40,40,46,46,40,40,40,46,40,43,44,47,40,43,46,47,40,41,46,47,40,41,44,47,40,43,45,48,40,44,46,48,40,42,46,48,40,42,44,48,40,48,48,48,40,40,48,48,40,40,40,48,40,44,47,51,40,45,49,51,40,42,49,51,40,42,46,51,40,51,51,51,40,40,51,51,40,40,40,51,40,45,49,54,40,47,51,54,40,43,51,54,40,43,47,54,40,54,54,54,40,40,54,54,40,40,40,54,40,46,51,57,40,48,53,57,40,44,53,57,40,44,49,57,40,57,57,57,40,40,57,57,40,40,40,57,40,47,53,60,40,50,55,60,40,45,55,60,40,45,50,60,40,60,60,60,40,40,60,60,40,40,40,60,40,51,58,63,40,45,58,63,40,45,52,63,40,63,63,63,40,40,63,63,40,40,40,63,41,42,42,43,41,42,43,44,41,43,44,45,41,42,44,45,41,42,43,45,41,43,44,46,41,43,45,46,41,42,45,46,41,42,44,46,41,43,45,47,41,44,46,47,41,42,46,47,41,42,44,47,41,47,47,47,41,41,47,47,41,41,41,47,41,44,45,48,41,44,47,48,41,42,47,48,41,42,45,48,41,44,46,49,41,45,47,49,41,43,47,49,41,43,45,49,41,49,49,49,41,41,49,49,41,41,41,49,41,45,48,52,41,46,50,52,41,43,50,52,41,43,47,52,41,52,52,52,41,41,52,52,41,41,41,52,41,46,50,55,41,48,52,55,41,44,52,55,41,44,48,55,41,55,55,55,41,41,55,55,41,41,41,55,41,47,52,58,41,49,54,58,41,45,54,58,41,45,50,58,41,58,58,58,41,41,58,58,41,41,41,58,41,48,54,61,41,51,56,61,41,46,56,61,41,46,51,61,41,61,61,61,41,41,61,61,41,41,41,61,42,43,43,44,42,43,44,45,42,44,45,46,42,43,45,46,42,43,44,46,42,44,45,47,42,44,46,47,42,43,46,47,42,43,45,47,42,44,46,48,42,45,47,48,42,43,47,48,42,43,45,48,42,48,48,48,42,42,48,48,42,42,42,48,42,45,46,49,42,45,48,49,42,43,48,49,42,43,46,49,42,45,47,50,42,46,48,50,42,44,48,50,42,44,46,50,42,50,50,50,42,42,50,50,42,42,42,50,42,46,49,53,42,47,51,53,42,44,51,53,42,44,48,53,42,53,53,53,42,42,53,53,42,42,42,53,42,47,51,56,42,49,53,56,42,45,53,56,42,45,49,56,42,56,56,56,42,42,56,56,42,42,42,56,42,48,53,59,42,50,55,59,42,46,55,59,42,46,51,59,42,59,59,59,42,42,59,59,42,42,42,59,42,49,55,62,42,52,57,62,42,47,57,62,42,47,52,62,42,62,62,62,42,42,62,62,42,42,42,62,43,44,44,45,43,44,45,46,43,45,46,47,43,44,46,47,43,44,45,47,43,45,46,48,43,45,47,48,43,44,47,48,43,44,46,48,43,45,47,49,43,46,48,49,43,44,48,49,43,44,46,49,43,49,49,49,43,43,49,49,43,43,43,49,43,46,47,50,43,46,49,50,43,44,49,50,43,44,47,50,43,46,48,51,43,47,49,51,43,45,49,51,43,45,47,51,43,51,51,51,43,43,51,51,43,43,43,51,43,47,50,54,43,48,52,54,43,45,52,54,43,45,49,54,43,54,54,54,43,43,54,54,43,43,43,54,43,48,52,57,43,50,54,57,43,46,54,57,43,46,50,57,43,57,57,57,43,43,57,57,43,43,43,57,43,49,54,60,43,51,56,60,43,47,56,60,43,47,52,60,43,60,60,60,43,43,60,60,43,43,43,60,43,50,56,63,43,53,58,63,43,48,58,63,43,48,53,63,43,63,63,63,43,43,63,63,43,43,43,63,44,45,45,46,44,45,46,47,44,46,47,48,44,45,47,48,44,45,46,48,44,46,47,49,44,46,48,49,44,45,48,49,44,45,47,49,44,46,48,50,44,47,49,50,44,45,49,50,44,45,47,50,44,50,50,50,44,44,50,50,44,44,44,50,44,47,48,51,44,47,50,51,44,45,50,51,44,45,48,51,44,47,49,52,44,48,50,52,44,46,50,52,44,46,48,52,44,52,52,52,44,44,52,52,44,44,44,52,44,48,51,55,44,49,53,55,44,46,53,55,44,46,50,55,44,55,55,55,44,44,55,55,44,44,44,55,44,49,53,58,44,51,55,58,44,47,55,58,44,47,51,58,44,58,58,58,44,44,58,58,44,44,44,58,44,50,55,61,44,52,57,61,44,48,57,61,44,48,53,61,44,61,61,61,44,44,61,61,44,44,44,61,45,46,46,47,45,46,47,48,45,47,48,49,45,46,48,49,45,46,47,49,45,47,48,50,45,47,49,50,45,46,49,50,45,46,48,50,45,47,49,51,45,48,50,51,45,46,50,51,45,46,48,51,45,51,51,51,45,45,51,51,45,45,45,51,45,48,49,52,45,48,51,52,45,46,51,52,45,46,49,52,45,48,50,53,45,49,51,53,45,47,51,53,45,47,49,53,45,53,53,53,45,45,53,53,45,45,45,53,45,49,52,56,45,50,54,56,45,47,54,56,45,47,51,56,45,56,56,56,45,45,56,56,45,45,45,56,45,50,54,59,45,52,56,59,45,48,56,59,45,48,52,59,45,59,59,59,45,45,59,59,45,45,45,59,45,51,56,62,45,53,58,62,45,49,58,62,45,49,54,62,45,62,62,62,45,45,62,62,45,45,45,62,46,47,47,48,46,47,48,49,46,48,49,50,46,47,49,50,46,47,48,50,46,48,49,51,46,48,50,51,46,47,50,51,46,47,49,51,46,48,50,52,46,49,51,52,46,47,51,52,46,47,49,52,46,52,52,52,46,46,52,52,46,46,46,52,46,49,50,53,46,49,52,53,46,47,52,53,46,47,50,53,46,49,51,54,46,50,52,54,46,48,52,54,46,48,50,54,46,54,54,54,46,46,54,54,46,46,46,54,46,50,53,57,46,51,55,57,46,48,55,57,46,48,52,57,46,57,57,57,46,46,57,57,46,46,46,57,46,51,55,60,46,53,57,60,46,49,57,60,46,49,53,60,46,60,60,60,46,46,60,60,46,46,46,60,46,52,57,63,46,54,59,63,46,50,59,63,46,50,55,63,46,63,63,63,46,46,63,63,46,46,46,63,47,48,48,49,47,48,49,50,47,49,50,51,47,48,50,51,47,48,49,51,47,49,50,52,47,49,51,52,47,48,51,52,47,48,50,52,47,49,51,53,47,50,52,53,47,48,52,53,47,48,50,53,47,53,53,53,47,47,53,53,47,47,47,53,47,50,51,54,47,50,53,54,47,48,53,54,47,48,51,54,47,50,52,55,47,51,53,55,47,49,53,55,47,49,51,55,47,55,55,55,47,47,55,55,47,47,47,55,47,51,54,58,47,52,56,58,47,49,56,58,47,49,53,58,47,58,58,58,47,47,58,58,47,47,47,58,47,52,56,61,47,54,58,61,47,50,58,61,47,50,54,61,47,61,61,61,47,47,61,61,47,47,47,61,48,49,49,50,48,49,50,51,48,50,51,52,48,49,51,52,48,49,50,52,48,50,51,53,48,50,52,53,48,49,52,53,48,49,51,53,48,50,52,54,48,51,53,54,48,49,53,54,48,49,51,54,48,54,54,54,48,48,54,54,48,48,48,54,48,51,52,55,48,51,54,55,48,49,54,55,48,49,52,55,48,51,53,56,48,52,54,56,48,50,54,56,48,50,52,56,48,56,56,56,48,48,56,56,48,48,48,56,48,52,55,59,48,53,57,59,48,50,57,59,48,50,54,59,48,59,59,59,48,48,59,59,48,48,48,59,48,53,57,62,48,55,59,62,48,51,59,62,48,51,55,62,48,62,62,62,48,48,62,62,48,48,48,62,49,50,50,51,49,50,51,52,49,51,52,53,49,50,52,53,49,50,51,53,49,51,52,54,49,51,53,54,49,50,53,54,49,50,52,54,49,51,53,55,49,52,54,55,49,50,54,55,49,50,52,55,49,55,55,55,49,49,55,55,49,49,49,55,49,52,53,56,49,52,55,56,49,50,55,56,49,50,53,56,49,52,54,57,49,53,55,57,49,51,55,57,49,51,53,57,49,57,57,57,49,49,57,57,49,49,49,57,49,53,56,60,49,54,58,60,49,51,58,60,49,51,55,60,49,60,60,60,49,49,60,60,49,49,49,60,49,54,58,63,49,56,60,63,49,52,60,63,49,52,56,63,49,63,63,63,49,49,63,63,49,49,49,63,50,51,51,52,50,51,52,53,50,52,53,54,50,51,53,54,50,51,52,54,50,52,53,55,50,52,54,55,50,51,54,55,50,51,53,55,50,52,54,56,50,53,55,56,50,51,55,56,50,51,53,56,50,56,56,56,50,50,56,56,50,50,50,56,50,53,54,57,50,53,56,57,50,51,56,57,50,51,54,57,50,53,55,58,50,54,56,58,50,52,56,58,50,52,54,58,50,58,58,58,50,50,58,58,50,50,50,58,50,54,57,61,50,55,59,61,50,52,59,61,50,52,56,61,50,61,61,61,50,50,61,61,50,50,50,61,51,52,52,53,51,52,53,54,51,53,54,55,51,52,54,55,51,52,53,55,51,53,54,56,51,53,55,56,51,52,55,56,51,52,54,56,51,53,55,57,51,54,56,57,51,52,56,57,51,52,54,57,51,57,57,57,51,51,57,57,51,51,51,57,51,54,55,58,51,54,57,58,51,52,57,58,51,52,55,58,51,54,56,59,51,55,57,59,51,53,57,59,51,53,55,59,51,59,59,59,51,51,59,59,51,51,51,59,51,55,58,62,51,56,60,62,51,53,60,62,51,53,57,62,51,62,62,62,51,51,62,62,51,51,51,62,52,53,53,54,52,53,54,55,52,54,55,56,52,53,55,56,52,53,54,56,52,54,55,57,52,54,56,57,52,53,56,57,52,53,55,57,52,54,56,58,52,55,57,58,52,53,57,58,52,53,55,58,52,58,58,58,52,52,58,58,52,52,52,58,52,55,56,59,52,55,58,59,52,53,58,59,52,53,56,59,52,55,57,60,52,56,58,60,52,54,58,60,52,54,56,60,52,60,60,60,52,52,60,60,52,52,52,60,52,56,59,63,52,57,61,63,52,54,61,63,52,54,58,63,52,63,63,63,52,52,63,63,52,52,52,63,53,54,54,55,53,54,55,56,53,55,56,57,53,54,56,57,53,54,55,57,53,55,56,58,53,55,57,58,53,54,57,58,53,54,56,58,53,55,57,59,53,56,58,59,53,54,58,59,53,54,56,59,53,59,59,59,53,53,59,59,53,53,53,59,53,56,57,60,53,56,59,60,53,54,59,60,53,54,57,60,53,56,58,61,53,57,59,61,53,55,59,61,53,55,57,61,53,61,61,61,53,53,61,61,53,53,53,61,54,55,55,56,54,55,56,57,54,56,57,58,54,55,57,58,54,55,56,58,54,56,57,59,54,56,58,59,54,55,58,59,54,55,57,59,54,56,58,60,54,57,59,60,54,55,59,60,54,55,57,60,54,60,60,60,54,54,60,60,54,54,54,60,54,57,58,61,54,57,60,61,54,55,60,61,54,55,58,61,54,57,59,62,54,58,60,62,54,56,60,62,54,56,58,62,54,62,62,62,54,54,62,62,54,54,54,62,55,56,56,57,55,56,57,58,55,57,58,59,55,56,58,59,55,56,57,59,55,57,58,60,55,57,59,60,55,56,59,60,55,56,58,60,55,57,59,61,55,58,60,61,55,56,60,61,55,56,58,61,55,61,61,61,55,55,61,61,55,55,55,61,55,58,59,62,55,58,61,62,55,56,61,62,55,56,59,62,55,58,60,63,55,59,61,63,55,57,61,63,55,57,59,63,55,63,63,63,55,55,63,63,55,55,55,63,56,57,57,58,56,57,58,59,56,58,59,60,56,57,59,60,56,57,58,60,56,58,59,61,56,58,60,61,56,57,60,61,56,57,59,61,56,58,60,62,56,59,61,62,56,57,61,62,56,57,59,62,56,62,62,62,56,56,62,62,56,56,56,62,56,59,60,63,56,59,62,63,56,57,62,63,56,57,60,63,57,58,58,59,57,58,59,60,57,59,60,61,57,58,60,61,57,58,59,61,57,59,60,62,57,59,61,62,57,58,61,62,57,58,60,62,57,59,61,63,57,60,62,63,57,58,62,63,57,58,60,63,57,63,63,63,57,57,63,63,57,57,57,63,58,59,59,60,58,59,60,61,58,60,61,62,58,59,61,62,58,59,60,62,58,60,61,63,58,60,62,63,58,59,62,63,58,59,61,63,59,60,60,61,59,60,61,62,59,61,62,63,59,60,62,63,59,60,61,63,60,61,61,62,60,61,62,63,61,62,62,63,96,103,109,115,122,128,134,141,147,153,160,166,172,179,185,192,160,59,34,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,226,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,213,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,2,34,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,243,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,32,34,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,17,34,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,100,2,4,8,1,1,2,4,8,4,8,4,0,0,0,1,1,2,4,8,1,1,2,4,8,4,8,4,0,0,0,1,100,2,4,8,1,1,2,4,8,4,8,4,0,0,0,1,100,2,4,8,1,1,2,4,8,4,8,4,0,0,0,0,128,191,154,6,28,191,171,170,170,190,137,98,13,190,0,0,0,0,137,98,13,62,171,170,170,62,154,6,28,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,32,191,85,85,149,190,0,0,0,0,0,0,128,62,0,0,0,63,0,0,64,63,0,0,128,63,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,232,95,34,0,112,0,0,0,16,195,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,224,38,0,112,0,0,0,192,157,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,1,0,0,0,0,0,0,207,6,0,0,0,0,0,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,143,2,93,3,106,4,215,3,11,5,159,6,31,5,185,6,212,8,102,6,103,8,9,11,174,7,22,10,62,13,246,8,196,11,115,15,61,10,114,13,168,17,133,11,32,15,221,19,205,12,207,16,18,22,20,14,125,18,71,24,92,15,43,20,124,26,164,16,217,21,177,28,236,17,136,23,230,30,0,0,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,35,0,3,0,49,0,33,0,17,0,83,0,19,0,1,0,9,0,41,0,51,0,25,0,11,0,5,0,7,0,0,0,48,0,34,0,40,0,32,0,8,0,0,0,50,0,114,0,16,0,2,0,18,0,24,0,10,0,4,0,6,0,1,0,50,0,56,0,32,0,8,0,2,0,24,0,114,0,0,0,40,0,34,0,18,0,16,0,10,0,4,0,6,0,1,0,50,0,16,0,114,0,48,0,34,0,56,0,8,0,40,0,24,0,2,0,18,0,0,0,10,0,4,0,6,0,1,0,18,0,82,0,0,0,32,0,24,0,34,0,8,0,40,0,56,0,2,0,50,0,16,0,10,0,4,0,6,0,1,0,22,0,150,0,6,0,70,0,86,0,2,0,54,0,118,0,18,0,34,0,50,0,38,0,10,0,14,0,0,0,1,0,26,0,154,0,50,0,114,0,90,0,122,0,58,0,2,0,18,0,34,0,10,0,42,0,6,0,14,0,0,0,1,0,42,0,170,0,2,0,66,0,106,0,58,0,122,0,34,0,50,0,18,0,10,0,26,0,6,0,14,0,0,0,1,0,66,0,194,0,2,0,10,0,74,0,58,0,122,0,34,0,18,0,50,0,42,0,26,0,6,0,14,0,0,0,1,0,186,0,186,1,58,0,18,0,82,0,122,0,2,0,34,0,50,0,10,0,42,0,26,0,0,0,4,0,6,0,1,0,170,0,170,1,42,0,34,0,98,0,106,0,2,0,18,0,50,0,10,0,26,0,58,0,0,0,4,0,6,0,1,0,170,0,170,1,42,0,34,0,98,0,106,0,2,0,18,0,50,0,10,0,58,0,26,0,0,0,4,0,6,0,1,0,138,0,138,1,10,0,34,0,98,0,74,0,2,0,18,0,50,0,42,0,26,0,58,0,0,0,4,0,6,0,1,0,6,6,6,6,6,7,7,6,6,6,6,5,4,3,3,1,6,6,6,6,6,6,7,7,6,6,6,5,4,3,3,1,7,6,6,6,6,6,7,6,6,6,6,5,4,3,3,1,7,6,7,6,6,6,6,6,6,6,6,5,4,3,3,1,7,7,6,6,6,6,6,6,6,6,6,5,4,3,3,1,8,8,7,7,7,6,7,7,6,6,6,6,4,4,2,1,8,8,7,7,7,7,7,6,6,6,6,6,4,4,2,1,8,8,7,7,7,7,7,6,6,6,6,6,4,4,2,1,8,8,7,7,7,7,7,6,6,6,6,6,4,4,2,1,9,9,8,7,7,7,6,6,6,6,6,6,3,3,3,1,9,9,8,7,7,7,6,6,6,6,6,6,3,3,3,1,9,9,8,7,7,7,6,6,6,6,6,6,3,3,3,1,9,9,8,7,7,7,6,6,6,6,6,6,3,3,3,1,0,1,255,0,254,0,253,0,252,0,251,0,250,0,249,0,248,0,247,0,246,0,245,0,244,0,243,0,242,0,241,0,240,0,239,0,238,0,237,0,236,0,235,0,234,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,0,10,0,0,0,6,0,46,0,2,0,14,0,26,0,126,0,78,0,90,0,226,0,190,1,186,1,186,0,114,0,34,0,190,2,190,0,58,3,242,3,242,1,162,3,34,1,34,3,162,1,114,1,114,3,58,1,206,0,206,2,254,2,254,0,162,0,242,0,58,0,206,1,254,1,98,0,218,0,62,0,50,0,122,0,18,0,30,0,22,0,4,0,1,0,0,0,5,3,5,6,6,7,7,8,8,8,8,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,9,9,9,9,9,8,8,8,7,7,6,6,5,3,1,0,112,209,31,0,16,206,31,0,200,202,31,0,144,199,31,0,248,196,31,0,96,194,31,0,200,191,31,0,72,189,31,0,216,186,31,0,144,184,31,0,96,182,31,0,88,180,31,0,120,178,31,0,0,0,0,0,172,0,0,0,169,0,0,0,165,0,0,0,162,0,0,0,131,0,0,0,132,0,0,0,130,0,0,0,125,0,0,0,121,0,0,0,114,0,0,0,110,0,0,0,101,0,0,0,96,0,0,0,0,0,0,0,200,210,31,0,104,207,31,0,24,204,31,0,216,200,31,0,0,198,31,0,104,195,31,0,208,192,31,0,72,190,31,0,208,187,31,0,120,185,31,0,64,183,31,0,40,181,31,0,56,179,31,0,0,0,0,0,32,212,31,0,192,208,31,0,104,205,31,0,32,202,31,0,8,199,31,0,112,196,31,0,216,193,31,0,72,191,31,0,200,188,31,0,96,186,31,0,32,184,31,0,248,181,31,0,248,179,31,0,0,0,0,0,70,14,204,12,109,11,40,10,252,8,232,7,235,6,4,6,50,5,116,4,201,3,48,3,168,2,48,2,199,1,108,1,30,1,220,0,165,0,120,0,84,0,56,0,35,0,20,0,10,0,4,0,1,0,0,0,0,0,0,0,150,1,122,1,95,1,69,1,44,1,20,1,253,0,231,0,210,0,190,0,171,0,153,0,136,0,120,0,105,0,91,0,78,0,66,0,55,0,45,0,36,0,28,0,21,0,15,0,10,0,6,0,3,0,1,0,0,0,0,0,29,0,28,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,6,0,254,255,250,255,4,0,12,0,252,255,244,255,6,0,18,0,250,255,238,255,10,0,30,0,246,255,226,255,16,0,48,0,240,255,208,255,25,0,75,0,231,255,181,255,40,0,120,0,216,255,136,255,64,0,192,0,192,255,64,255,101,0,47,1,155,255,209,254,161,0,227,1,95,255,29,254,0,1,0,3,0,255,0,253,150,1,194,4,106,254,62,251,133,2,143,7,123,253,113,248,0,4,0,12,0,252,0,244,89,6,11,19,167,249,245,236,20,10,60,30,236,245,196,225,47,237,57,82,241,84,169,228,32,38,62,238,214,9,64,44,181,239,224,43,225,63,57,51,47,68,254,230,88,68,223,249,49,242,219,67,176,61,5,247,123,79,251,254,173,38,220,12,194,51,57,7,190,18,162,67,223,27,62,31,17,2,150,7,235,42,63,22,13,5,56,58,30,13,120,13,15,21,70,51,164,56,125,11,93,45,223,31,183,25,34,40,153,13,18,31,76,25,230,12,0,0,0,0,240,206,249,228,187,246,70,6,245,20,255,35,111,53,141,74,80,181,37,200,128,217,151,233,131,248,82,7,17,24,24,46,27,213,46,241,46,4,199,19,96,34,27,49,222,64,133,83,231,171,168,187,28,200,38,211,14,221,212,229,34,238,24,246,40,254,79,6,183,14,184,23,170,33,139,45,162,59,249,77,84,198,242,222,170,239,148,253,106,9,63,20,123,30,44,40,118,49,137,58,159,67,162,76,127,85,80,94,24,103,141,111,248,150,180,163,69,175,83,186,177,196,204,206,111,216,30,226,243,235,64,246,247,0,32,12,129,24,154,38,107,55,96,77,101,159,107,181,131,197,113,211,24,224,180,235,28,246,89,255,91,8,6,17,82,25,74,33,201,40,248,47,230,54,146,61,223,67,187,73,70,79,103,84,48,89,163,93,236,97,249,101,212,105,90,109,158,112,173,115,107,118,240,120,90,123,165,125,64,130,100,131,206,132,93,134,5,136,222,137,215,139,244,141,81,144,226,146,222,149,15,153,129,156,121,160,76,165,210,170,138,177,10,185,36,193,204,201,57,211,211,221,214,233,147,248,111,9,202,26,236,41,31,56,249,69,106,84,195,99,181,115,168,66,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,3,36,0,248,8,35,0,16,0,0,0,32,82,85,68,255,255,255,255,255,255,255,127,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,168,65,34,0,80,159,33,0,24,0,0,0,32,82,85,68,255,255,255,255,255,255,255,127,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,32,35,33,0,96,183,32,0,72,0,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,112,91,32,0,80,159,33,0,80,0,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,232,65,40,0,24,232,39,0,8,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,16,170,36,0,224,142,36,0,32,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,120,114,36,0,72,88,36,0,40,0,0,0,2,0,0,0,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,56,98,38,0,24,44,38,0,56,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,176,249,37,0,184,206,37,0,64,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,160,169,37,0,136,132,37,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,66,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,1,0,0,0,0,0,0,0,0,0,0,212,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,22,38,0,112,0,0,0,208,162,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,187,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,130,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,104,36,0,184,76,36,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,152,104,36,0,184,53,36,0,0,13,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,80,216,35,0,56,191,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,112,168,35,0,160,146,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,16,124,35,0,232,101,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,160,83,35,0,160,117,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,0,49,35,0,160,117,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,224,101,34,0,88,73,34,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,48,37,34,0,88,73,34,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,193,34,0,112,0,0,0,136,165,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,235,36,0,224,176,35,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,64,16,0,1,0,120,235,36,0,208,205,34,0,240,12,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,235,36,0,8,118,33,0,136,252,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,235,36,0,48,153,32,0,152,61,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,235,36,0,208,35,40,0,144,195,39,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,235,36,0,64,95,39,0,152,17,39,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,64,95,39,0,200,205,38,0,240,137,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,64,95,39,0,176,78,38,0,136,23,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,64,95,39,0,120,236,37,0,152,191,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,64,95,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,9,35,0,112,0,0,0,248,167,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,2,0,0,250,0,0,0,1,0,0,0,120,2,0,0,250,0,0,0,0,0,0,0,178,0,0,0,250,0,0,0,0,0,0,0,164,0,0,0,94,3,0,0,1,0,0,0,186,0,0,0,6,0,0,0,1,0,0,0,4,2,0,0,2,1,0,0,1,0,0,0,180,3,0,0,40,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,250,0,0,0,1,0,0,0,96,3,0,0,6,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,2,0,0,250,0,0,0,0,0,0,0,176,0,0,0,250,0,0,0,0,0,0,0,8,2,0,0,2,1,0,0,0,0,0,0,182,3,0,0,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,90,90,88,85,82,78,73,67,61,54,46,38,31,22,13,4,252,243,234,225,218,210,202,195,189,183,178,174,171,168,166,166,90,87,80,70,57,43,25,9,247,231,213,199,186,176,169,166,166,169,176,186,199,213,231,247,9,25,43,57,70,80,87,90,90,82,67,46,22,252,225,202,183,171,166,168,178,195,218,243,13,38,61,78,88,90,85,73,54,31,4,234,210,189,174,166,89,75,50,18,238,206,181,167,167,181,206,238,18,50,75,89,89,75,50,18,238,206,181,167,167,181,206,238,18,50,75,89,88,67,31,243,202,174,166,178,210,252,38,73,90,85,61,22,234,195,171,166,183,218,4,46,78,90,82,54,13,225,189,168,87,57,9,213,176,166,186,231,25,70,90,80,43,247,199,169,169,199,247,43,80,90,70,25,231,186,166,176,213,9,57,87,85,46,243,189,166,183,234,38,82,88,54,252,195,166,178,225,31,78,90,61,4,202,168,174,218,22,73,90,67,13,210,171,83,36,220,173,173,220,36,83,83,36,220,173,173,220,36,83,83,36,220,173,173,220,36,83,83,36,220,173,173,220,36,83,82,22,202,166,195,13,78,85,31,210,166,189,4,73,88,38,218,168,183,252,67,90,46,225,171,178,243,61,90,54,234,174,80,9,186,169,231,57,90,43,213,166,199,25,87,70,247,176,176,247,70,87,25,199,166,213,43,90,57,231,169,186,9,80,78,252,174,183,13,85,67,234,168,195,31,90,54,218,166,210,46,90,38,202,166,225,61,88,22,189,171,243,73,82,4,178,75,238,167,206,50,89,18,181,181,18,89,50,206,167,238,75,75,238,167,206,50,89,18,181,181,18,89,50,206,167,238,75,73,225,166,234,78,67,218,166,243,82,61,210,168,252,85,54,202,171,4,88,46,195,174,13,90,38,189,178,22,90,31,183,70,213,169,9,90,25,176,199,57,80,231,166,247,87,43,186,186,43,87,247,166,231,80,57,199,176,25,90,9,169,213,70,67,202,178,38,85,234,166,4,90,13,168,225,82,46,183,195,61,73,210,174,31,88,243,166,252,90,22,171,218,78,54,189,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,64,192,192,64,61,183,210,82,31,168,243,90,252,166,22,85,218,178,54,67,189,202,78,38,171,234,90,4,166,13,88,225,174,46,73,195,57,176,231,90,247,169,43,70,186,213,87,9,166,25,80,199,199,80,25,166,9,87,213,186,70,43,169,247,90,231,176,57,54,171,252,88,210,195,82,13,166,38,67,178,234,90,225,183,73,31,166,22,78,189,218,90,243,174,61,46,168,4,85,202,50,167,18,75,181,238,89,206,206,89,238,181,75,18,167,50,50,167,18,75,181,238,89,206,206,89,238,181,75,18,167,50,46,166,38,54,166,31,61,168,22,67,171,13,73,174,4,78,178,252,82,183,243,85,189,234,88,195,225,90,202,218,90,210,43,166,57,25,169,70,9,176,80,247,186,87,231,199,90,213,213,90,199,231,87,186,247,80,176,9,70,169,25,57,166,43,38,168,73,252,189,90,210,225,85,178,13,61,166,54,22,174,82,234,202,90,195,243,78,171,31,46,166,67,4,183,88,218,36,173,83,220,220,83,173,36,36,173,83,220,220,83,173,36,36,173,83,220,220,83,173,36,36,173,83,220,220,83,173,36,31,178,90,195,4,54,168,82,218,234,73,166,67,243,210,85,171,46,13,189,90,183,22,38,174,88,202,252,61,166,78,225,25,186,90,176,43,9,199,87,169,57,247,213,80,166,70,231,231,70,166,80,213,247,57,169,87,199,9,43,176,90,186,25,22,195,85,166,73,218,252,46,178,90,174,54,243,225,67,168,88,189,31,13,202,82,166,78,210,4,38,183,90,171,61,234,18,206,75,167,89,181,50,238,238,50,181,89,167,75,206,18,18,206,75,167,89,181,50,238,238,50,181,89,167,75,206,18,13,218,61,178,88,166,85,183,54,225,4,22,210,67,174,90,166,82,189,46,234,252,31,202,73,171,90,168,78,195,38,243,9,231,43,199,70,176,87,166,90,169,80,186,57,213,25,247,247,25,213,57,186,80,169,90,166,87,176,70,199,43,231,9,4,243,22,225,38,210,54,195,67,183,78,174,85,168,90,166,90,166,88,171,82,178,73,189,61,202,46,218,31,234,13,252,0,2,0,3,0,2,0,3,1,3,2,4,1,4,1,4,1,3,3,4,4,5,5,6,6,7,7,8,8,9,9,9,3,3,3,3,3,4,4,4,4,5,5,6,6,6,6,0,4,3,3,3,4,4,3,3,4,5,5,6,5,6,0,0,5,3,4,4,3,3,3,4,3,4,5,5,5,0,0,0,4,4,4,3,3,3,3,3,4,5,4,5,0,0,0,0,6,5,3,3,3,3,3,3,4,3,6,0,0,0,0,0,6,5,3,3,3,2,3,4,3,6,0,0,0,0,0,0,6,4,5,3,2,2,3,3,6,0,0,0,0,0,0,0,6,6,4,2,2,3,2,5,0,0,0,0,0,0,0,0,5,5,3,2,2,2,4,0,0,0,0,0,0,0,0,0,4,4,3,3,1,3,0,0,0,0,0,0,0,0,0,0,4,4,2,1,3,0,0,0,0,0,0,0,0,0,0,0,3,3,1,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,2,3,2,3,2,3,2,3,2,3,2,3,2,1,7,6,5,4,3,5,4,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+296960);
/* memory initializer */ allocate([2,3,2,3,2,1,0,0,5,7,6,5,4,3,4,3,2,3,2,1,1,0,0,0,3,7,5,4,6,5,4,3,3,2,2,1,0,0,0,0,5,4,3,7,6,5,4,3,2,1,1,0,0,0,0,0,1,1,7,6,5,4,3,2,1,1,0,0,0,0,0,0,1,1,5,4,3,3,2,1,1,0,0,0,0,0,0,0,1,1,1,3,3,2,2,1,0,0,0,0,0,0,0,0,1,0,1,3,2,1,1,1,0,0,0,0,0,0,0,0,1,0,1,3,2,1,1,0,0,0,0,0,0,0,0,0,0,1,1,2,1,3,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,1,5,255,255,5,7,7,4,1,255,255,4,6,6,0,0,0,0,0,206,230,84,190,201,63,208,190,24,121,22,191,81,119,44,63,66,196,6,63,171,244,184,62,213,40,60,62,0,0,0,0,2,38,222,190,186,141,36,63,68,29,175,62,0,0,0,0,206,230,84,190,201,63,208,190,24,121,22,191,189,62,62,191,215,179,93,191,113,120,115,191,253,152,126,191,111,232,126,63,52,58,118,63,108,41,101,63,219,74,76,63,81,119,44,63,66,196,6,63,171,244,184,62,213,40,60,62,0,0,0,0,2,38,222,190,28,38,72,191,224,148,121,191,92,28,124,63,215,179,93,63,186,141,36,63,68,29,175,62,112,177,4,0,48,177,4,0,32,177,4,0,0,177,4,0,0,0,2,0,6,0,7,0,2,0,6,0,7,0,0,0,6,0,7,0,0,0,2,0,0,0,1,0,2,0,3,0,1,2,3,3,2,3,3,1,3,3,1,2,2,2,2,2,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,0,0,0,0,136,7,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,239,36,0,248,179,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,16,0,1,0,176,239,36,0,208,207,34,0,160,14,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,176,239,36,0,240,118,33,0,160,253,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,176,239,36,0,112,153,32,0,112,62,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,176,239,36,0,72,36,40,0,0,197,39,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,176,239,36,0,168,95,39,0,88,18,39,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,176,239,36,0,48,206,38,0,56,138,38,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,176,239,36,0,0,79,38,0,16,24,38,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,176,239,36,0,200,236,37,0,232,191,37,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,200,236,37,0,136,158,37,0,80,111,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,200,236,37,0,216,46,37,0,80,111,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,200,236,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,7,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,23,35,0,112,0,0,0,104,178,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,0,105,0,109,0,101,0,108,0,105,0,110,0,101,0,46,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,104,0,101,0,97,0,100,0,101,0,114,0,46,0,69,0,118,0,101,0,110,0,116,0,115,0,0,0,0,0,16,79,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,122,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,208,34,0,8,15,34,0,4,0,0,0,69,90,73,83,120,119,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,8,254,32,0,240,153,32,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,168,62,32,0,120,36,40,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,64,16,0,1,0,0,0,0,0,48,197,39,0,192,95,39,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,64,16,0,1,0,0,0,0,0,168,18,39,0,176,206,38,0,96,0,0,0,82,76,79,67,112,138,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,79,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,41,35,0,112,0,0,0,8,182,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,39,0,112,0,0,0,32,158,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,119,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,209,34,0,192,15,34,0,8,0,0,0,1,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,119,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,3,0,0,0,0,0,0,0,0,0,0,30,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,45,35,0,112,0,0,0,120,184,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,220,5,0,0,4,0,0,0,208,7,0,0,7,0,0,0,232,3,0,0,9,0,0,0,208,7,0,0,255,255,255,127,232,3,0,0,3,0,0,0,220,5,0,0,4,0,0,0,208,7,0,0,7,0,0,0,232,3,0,0,8,0,0,0,208,7,0,0,14,0,0,0,255,255,255,127,255,255,255,127,232,3,0,0,3,0,0,0,220,5,0,0,4,0,0,0,208,7,0,0,7,0,0,0,0,0,0,0,8,0,0,0,232,3,0,0,9,0,0,0,208,7,0,0,14,0,0,0,255,255,255,127,255,255,255,127,136,19,0,0,1,0,0,0,148,17,0,0,3,0,0,0,32,78,0,0,4,0,0,0,80,195,0,0,5,0,0,0,255,255,255,127,7,0,0,0,16,39,0,0,8,0,0,0,32,78,0,0,9,0,0,0,80,195,0,0,10,0,0,0,255,255,255,127,255,255,255,127,196,9,0,0,1,0,0,0,164,6,0,0,3,0,0,0,16,39,0,0,4,0,0,0,168,97,0,0,5,0,0,0,255,255,255,127,7,0,0,0,136,19,0,0,8,0,0,0,16,39,0,0,9,0,0,0,168,97,0,0,10,0,0,0,255,255,255,127,255,255,255,127,232,3,0,0,3,0,0,0,208,7,0,0,4,0,0,0,196,9,0,0,6,0,0,0,160,15,0,0,7,0,0,0,208,7,0,0,9,0,0,0,196,9,0,0,12,0,0,0,160,15,0,0,255,255,255,127,232,3,0,0,3,0,0,0,208,7,0,0,7,0,0,0,208,7,0,0,255,255,255,127,208,7,0,0,1,0,0,0,196,9,0,0,3,0,0,0,136,19,0,0,4,0,0,0,76,29,0,0,7,0,0,0,196,9,0,0,8,0,0,0,136,19,0,0,13,0,0,0,255,255,255,127,255,255,255,127,0,0,0,0,255,255,255,255,4,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,64,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,1,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,8,0,0,0,160,90,32,0,112,0,0,0,80,119,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,123,32,0,112,0,0,0,80,119,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,225,38,0,112,0,0,0,112,159,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,190,37,0,136,157,37,0,4,0,0,0,69,90,73,83,136,108,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,44,37,0,136,157,37,0,4,0,0,0,69,90,73,83,136,108,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,240,5,37,0,112,219,36,0,24,0,0,0,84,65,82,86,24,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,224,158,36,0,112,219,36,0,24,0,0,0,84,65,82,86,24,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,128,131,36,0,8,105,36,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,72,77,36,0,8,105,36,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,32,54,36,0,144,15,36,0,48,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,192,35,0,8,169,35,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,64,16,0,1,0,0,0,0,0,232,146,35,0,8,169,35,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,113,33,0,112,0,0,0,104,188,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,120,24,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,16,34,0,216,119,33,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,200,254,32,0,184,154,32,0,240,62,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,254,32,0,232,36,40,0,240,62,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,254,32,0,184,197,39,0,80,96,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,254,32,0,16,19,39,0,80,96,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,254,32,0,8,207,38,0,200,138,38,0,8,0,0,0,5,0,0,0,56,79,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,24,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,0,0,0,0,0,0,0,0,0,0,0,152,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,48,35,0,112,0,0,0,248,190,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,242,35,0,112,0,0,0,0,0,0,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,54,38,0,72,2,38,0,8,0,0,0,2,0,0,0,152,58,0,0,0,0,0,0,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,109,38,0,112,0,0,0,32,193,4,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,6,6,7,8,9,10,11,13,14,16,18,20,22,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,7,8,8,8,9,9,9,0,1,3,4,6,7,9,10,11,0,0,0,0,0,0,0,10,6,10,6,10,10,10,10,1,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,1,255,0,0,1,255,0,0,1,255,0,0,1,255,0,1,1,255,0,1,1,255,1,1,1,255,1,1,1,255,1,1,1,255,1,1,1,255,1,1,2,255,1,1,2,255,1,1,2,255,1,1,2,255,1,2,3,255,1,2,3,255,2,2,3,255,2,2,4,255,2,3,4,255,2,3,4,255,3,3,5,255,3,4,6,255,3,4,6,255,4,5,7,255,4,5,8,255,4,6,9,255,5,7,10,255,6,8,11,255,6,8,13,255,7,10,14,255,8,11,16,255,9,12,18,255,10,13,20,255,11,15,23,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,74,44,25,13,7,3,68,42,24,13,7,3,58,39,23,13,7,3,126,70,37,19,10,5,132,70,37,20,10,5,124,70,38,20,10,5,120,69,37,20,11,5,116,67,37,20,11,5,108,66,36,20,10,5,102,62,36,20,10,5,88,58,34,19,10,5,162,89,49,25,13,7,156,87,49,26,14,7,150,86,47,26,14,7,142,84,47,26,14,7,131,79,46,26,14,7,0,1,1,2,3,3,4,5,0,0,0,0,0,0,0,0,71,80,83,86,101,114,115,105,111,110,73,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,80,83,76,97,116,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,80,83,76,97,116,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,80,83,76,111,110,103,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,71,80,83,76,111,110,103,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,71,80,83,65,108,116,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,71,80,83,65,108,116,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,71,80,83,84,105,109,101,83,116,97,109,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,71,80,83,83,97,116,101,108,108,105,116,101,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,80,83,83,116,97,116,117,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,71,80,83,77,101,97,115,117,114,101,77,111,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,71,80,83,68,79,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,71,80,83,83,112,101,101,100,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,71,80,83,83,112,101,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,71,80,83,84,114,97,99,107,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,71,80,83,84,114,97,99,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,71,80,83,73,109,103,68,105,114,101,99,116,105,111,110,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,71,80,83,73,109,103,68,105,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,71,80,83,77,97,112,68,97,116,117,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,71,80,83,68,101,115,116,76,97,116,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,71,80,83,68,101,115,116,76,97,116,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,71,80,83,68,101,115,116,76,111,110,103,105,116,117,100,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,71,80,83,68,101,115,116,76,111,110,103,105,116,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,71,80,83,68,101,115,116,66,101,97,114,105,110,103,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,71,80,83,68,101,115,116,66,101,97,114,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,71,80,83,68,101,115,116,68,105,115,116,97,110,99,101,82,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,71,80,83,68,101,115,116,68,105,115,116,97,110,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,71,80,83,80,114,111,99,101,115,115,105,110,103,77,101,116,104,111,100,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,71,80,83,65,114,101,97,73,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,71,80,83,68,97,116,101,83,116,97,109,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,0,71,80,83,68,105,102,102,101,114,101,110,116,105,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,73,109,97,103,101,87,105,100,116,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,73,109,97,103,101,76,101,110,103,116,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,66,105,116,115,80,101,114,83,97,109,112,108,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,67,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,80,104,111,116,111,109,101,116,114,105,99,73,110,116,101,114,112,114,101,116,97,116,105,111,110,0,0,0,0,0,0,0,6,1,79,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,1,83,97,109,112,108,101,115,80,101,114,80,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,1,80,108,97,110,97,114,67,111,110,102,105,103,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,28,1,89,67,98,67,114,83,117,98,83,97,109,112,108,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,2,89,67,98,67,114,80,111,115,105,116,105,111,110,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,2,88,82,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,1,89,82,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,1,82,101,115,111,108,117,116,105,111,110,85,110,105,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,83,116,114,105,112,79,102,102,115,101,116,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,82,111,119,115,80,101,114,83,116,114,105,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,83,116,114,105,112,66,121,116,101,67,111,117,110,116,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,74,80,69,71,73,110,116,101,114,99,104,97,110,103,101,70,111,114,109,97,116,0,0,0,0,0,0,0,0,0,0,0,1,2,74,80,69,71,73,110,116,101,114,99,104,97,110,103,101,70,111,114,109,97,116,76,101,110,103,116,104,0,0,0,0,0,2,2,84,114,97,110,115,102,101,114,70,117,110,99,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,1,87,104,105,116,101,80,111,105,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,1,80,114,105,109,97,114,121,67,104,114,111,109,97,116,105,99,105,116,105,101,115,0,0,0,0,0,0,0,0,0,0,0,63,1,89,67,98,67,114,67,111,101,102,102,105,99,105,101,110,116,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,2,82,101,102,101,114,101,110,99,101,66,108,97,99,107,87,104,105,116,101,0,0,0,0,0,0,0,0,0,0,0,0,0,20,2,68,97,116,101,84,105,109,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,1,73,109,97,103,101,68,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,1,77,97,107,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,1,77,111,100,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,83,111,102,116,119,97,114,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,1,65,114,116,105,115,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,1,67,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,130,69,120,105,102,86,101,114,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,70,108,97,115,104,112,105,120,86,101,114,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,67,111,108,111,114,83,112,97,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,160,67,111,109,112,111,110,101,110,116,115,67,111,110,102,105,103,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,0,1,145,67,111,109,112,114,101,115,115,101,100,66,105,116,115,80,101,114,80,105,120,101,108,0,0,0,0,0,0,0,0,0,0,2,145,80,105,120,101,108,88,68,105,109,101,110,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,160,80,105,120,101,108,89,68,105,109,101,110,115,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,160,77,97,107,101,114,78,111,116,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,146,85,115,101,114,67,111,109,109,101,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,146,82,101,108,97,116,101,100,83,111,117,110,100,70,105,108,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,160,68,97,116,101,84,105,109,101,79,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,144,68,97,116,101,84,105,109,101,68,105,103,105,116,105,122,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,144,83,117,98,83,101,99,84,105,109,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,146,83,117,98,83,101,99,84,105,109,101,79,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,146,83,117,98,83,101,99,84,105,109,101,68,105,103,105,116,105,122,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,146,146,73,109,97,103,101,85,110,105,113,117,101,73,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,164,69,120,112,111,115,117,114,101,84,105,109,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,130,70,78,117,109,98,101,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,157,130,69,120,112,111,115,117,114,101,80,114,111,103,114,97,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,136,83,112,101,99,116,114,97,108,83,101,110,115,105,116,105,118,105,116,121,0,0,0,0,0,0,0,0,0,0,0,0,0,36,136,73,83,79,83,112,101,101,100,82,97,116,105,110,103,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,136,79,69,67,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,136,83,104,117,116,116,101,114,83,112,101,101,100,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,146,65,112,101,114,116,117,114,101,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,146,66,114,105,103,104,116,110,101,115,115,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,146,69,120,112,111,115,117,114,101,66,105,97,115,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,146,77,97,120,65,112,101,114,116,117,114,101,86,97,108,117,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,146,83,117,98,106,101,99,116,68,105,115,116,97,110,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,146,77,101,116,101,114,105,110,103,77,111,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,146,76,105,103,104,116,83,111,117,114,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,146,70,108,97,115,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,146,70,111,99,97,108,76,101,110,103,116,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,146,83,117,98,106,101,99,116,65,114,101,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,146,70,108,97,115,104,69,110,101,114,103,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,162,83,112,97,116,105,97,108,70,114,101,113,117,101,110,99,121,82,101,115,112,111,110,115,101,0,0,0,0,0,0,0,0,12,162,70,111,99,97,108,80,108,97,110,101,88,82,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,14,162,70,111,99,97,108,80,108,97,110,101,89,82,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,15,162,70,111,99,97,108,80,108,97,110,101,82,101,115,111,108,117,116,105,111,110,85,110,105,116,0,0,0,0,0,0,0,0,16,162,83,117,98,106,101,99,116,76,111,99,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,162,69,120,112,111,115,117,114,101,73,110,100,101,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,162,83,101,110,115,105,110,103,77,101,116,104,111,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,162,70,105,108,101,83,111,117,114,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,83,99,101,110,101,84,121,112,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,163,67,70,65,80,97,116,116,101,114,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,163,67,117,115,116,111,109,82,101,110,100,101,114,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,164,69,120,112,111,115,117,114,101,77,111,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,164,87,104,105,116,101,66,97,108,97,110,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,164,68,105,103,105,116,97,108,90,111,111,109,82,97,116,105,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,164,70,111,99,97,108,76,101,110,103,116,104,73,110,51,53,109,109,70,105,108,109,0,0,0,0,0,0,0,0,0,0,0,5,164,83,99,101,110,101,67,97,112,116,117,114,101,84,121,112,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,164,71,97,105,110,67,111,110,116,114,111,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,164,67,111,110,116,114,97,115,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,164,83,97,116,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,164,83,104,97,114,112,110,101,115,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,164,68,101,118,105,99,101,83,101,116,116,105,110,103,68,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,0,0,0,11,164,83,117,98,106,101,99,116,68,105,115,116,97,110,99,101,82,97,110,103,101,0,0,0,0,0,0,0,0,0,0,0,0,12,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,120,34,5,0,5,0,0,0,120,34,5,0,15,0,0,0,72,36,5,0,5,0,0,0,120,34,5,0,25,0,0,0,224,38,5,0,15,0,0,0,72,36,5,0,35,0,0,0,192,34,5,0,5,0,0,0,120,34,5,0,45,0,0,0,176,32,5,0,25,0,0,0,224,38,5,0,55,0,0,0,240,36,5,0,15,0,0,0,72,36,5,0,120,145,40,0,120,141,40,0,4,0,0,0,112,141,40,0,112,139,40,0,2,0,0,0,120,145,40,0,120,141,40,0,4,0,0,0,0,0,0,0,184,51,11,0,184,48,11,0,160,45,11,0,0,0,0,0,0,0,0,0,26,7,0,0,38,14,0,0,48,16,0,0,90,18,0,0,114,20,0,0,172,22,0,0,236,22,0,0,12,23,0,0,44,23,0,0,108,23,0,0,108,24,0,0,172,24,0,0,204,24,0,0,236,24,0,0,250,29,0,0,240,34,0,0,34,40,0,0,148,45,0,0,218,47,0,0,236,54,0,0,230,61,0,0,244,63,0,0,66,66,0,0,104,68,0,0,228,70,0,0,4,71,0,0,36,71,0,0,68,71,0,0,132,71,0,0,132,72,0,0,196,72,0,0,228,72,0,0,4,73,0,0,68,78,0,0,66,83,0,0,120,88,0,0,160,93,0,0,38,96,0,0,16,103,0,0,30,110,0,0,64,112,0,0,182,114,0,0,242,116,0,0,144,119,0,0,176,119,0,0,208,119,0,0,240,119,0,0,48,120,0,0,48,121,0,0,112,121,0,0,144,121,0,0,208,121,0,0,58,127,0,0,106,132,0,0,164,137,0,0,36,143,0,0,166,145,0,0,108,152,0,0,98,159,0,0,152,161,0,0,68,164,0,0,196,166,0,0,84,169,0,0,116,169,0,0,148,169,0,0,180,169,0,0,212,169,0,0,84,170,0,0,148,170,0,0,180,170,0,0,212,170,0,0,44,176,0,0,94,181,0,0,162,186,0,0,8,192,0,0,138,194,0,0,94,201,0,0,92,208,0,0,212,210,0,0,120,213,0,0,52,216,0,0,186,218,0,0,58,219,0,0,90,219,0,0,122,219,0,0,154,219,0,0,26,220,0,0,90,220,0,0,122,220,0,0,154,220,0,0,22,226,0,0,154,231,0,0,220,236,0,0,84,242,0,0,218,244,0,0,204,251,0,0,12,252,0,0,76,252,0,0,204,252,0,0,76,253,0,0,28,2,1,0,138,7,1,0,138,9,1,0,190,11,1,0,200,13,1,0,16,16,1,0,152,18,1,0,74,25,1,0,138,25,1,0,202,25,1,0,10,26,1,0,138,26,1,0,100,31,1,0,184,36,1,0,190,38,1,0,254,40,1,0,22,43,1,0,120,45,1,0,254,47,1,0,222,54,1,0,30,55,1,0,62,55,1,0,126,55,1,0,254,55,1,0,28,61,1,0,104,66,1,0,120,68,1,0,216,70,1,0,18,73,1,0,198,75,1,0,72,78,1,0,88,85,1,0,152,85,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+307200);
/* memory initializer */ allocate([184,85,1,0,248,85,1,0,120,86,1,0,150,91,1,0,228,96,1,0,22,99,1,0,206,101,1,0,22,104,1,0,174,106,1,0,48,109,1,0,14,116,1,0,46,116,1,0,78,116,1,0,142,116,1,0,14,117,1,0,110,122,1,0,218,127,1,0,32,130,1,0,214,132,1,0,138,135,1,0,20,138,1,0,148,140,1,0,152,147,1,0,184,147,1,0,216,147,1,0,248,147,1,0,56,148,1,0,170,153,1,0,238,158,1,0,158,161,1,0,64,164,1,0,226,166,1,0,102,169,1,0,232,171,1,0,6,179,1,0,38,179,1,0,70,179,1,0,102,179,1,0,134,179,1,0,238,184,1,0,144,190,1,0,44,193,1,0,204,195,1,0,86,198,1,0,214,200,1,0,88,203,1,0,3,5,1,2,1,3,1,1,1,6,1,5,2,5,0,0,212,0,0,0,8,0,0,0,197,33,0,0,14,0,0,0,138,241,0,0,16,0,0,0,188,213,0,0,16,0,0,0,121,8,0,0,12,0,0,0,77,53,0,0,14,0,0,0,63,14,1,0,17,0,0,0,84,15,1,0,17,0,0,0,102,8,0,0,12,0,0,0,110,53,0,0,14,0,0,0,85,15,1,0,17,0,0,0,62,14,1,0,17,0,0,0,206,16,0,0,13,0,0,0,132,60,0,0,14,0,0,0,189,213,0,0,16,0,0,0,139,241,0,0,16,0,0,0,104,8,0,0,12,0,0,0,140,67,0,0,15,0,0,0,171,135,0,0,16,0,0,0,11,121,0,0,15,0,0,0,16,15,0,0,12,0,0,0,61,67,0,0,15,0,0,0,211,106,0,0,15,0,0,0,10,121,0,0,15,0,0,0,167,26,0,0,13,0,0,0,212,67,0,0,15,0,0,0,30,135,0,0,16,0,0,0,223,106,0,0,15,0,0,0,124,13,0,0,12,0,0,0,148,60,0,0,14,0,0,0,141,67,0,0,15,0,0,0,210,106,0,0,15,0,0,0,188,6,0,0,11,0,0,0,233,33,0,0,14,0,0,0,218,106,0,0,15,0,0,0,153,106,0,0,15,0,0,0,247,16,0,0,13,0,0,0,137,67,0,0,15,0,0,0,219,106,0,0,15,0,0,0,196,120,0,0,15,0,0,0,86,13,0,0,12,0,0,0,247,53,0,0,14,0,0,0,142,67,0,0,15,0,0,0,152,106,0,0,15,0,0,0,82,13,0,0,12,0,0,0,149,60,0,0,14,0,0,0,136,67,0,0,15,0,0,0,60,67,0,0,15,0,0,0,84,13,0,0,12,0,0,0,75,30,0,0,13,0,0,0,99,60,0,0,14,0,0,0,131,60,0,0,14,0,0,0,97,8,0,0,12,0,0,0,235,33,0,0,14,0,0,0,108,53,0,0,14,0,0,0,246,53,0,0,14,0,0,0,99,8,0,0,12,0,0,0,159,33,0,0,14,0,0,0,104,53,0,0,14,0,0,0,130,60,0,0,14,0,0,0,174,1,0,0,9,0,0,0,192,16,0,0,13,0,0,0,17,15,0,0,12,0,0,0,250,26,0,0,13,0,0,0,0,0,0,0,1,0,0,0,240,0,0,0,8,0,0,0,173,1,0,0,9,0,0,0,193,16,0,0,13,0,0,0,10,0,0,0,4,0,0,0,197,3,0,0,10,0,0,0,137,7,0,0,11,0,0,0,181,26,0,0,13,0,0,0,9,0,0,0,4,0,0,0,53,4,0,0,11,0,0,0,147,7,0,0,11,0,0,0,64,30,0,0,13,0,0,0,29,0,0,0,5,0,0,0,203,3,0,0,10,0,0,0,120,8,0,0,12,0,0,0,175,26,0,0,13,0,0,0,11,0,0,0,4,0,0,0,199,3,0,0,10,0,0,0,145,7,0,0,11,0,0,0,171,26,0,0,13,0,0,0,31,0,0,0,5,0,0,0,54,4,0,0,11,0,0,0,191,6,0,0,11,0,0,0,25,15,0,0,12,0,0,0,61,0,0,0,6,0,0,0,81,13,0,0,12,0,0,0,196,16,0,0,13,0,0,0,232,33,0,0,14,0,0,0,54,0,0,0,6,0,0,0,55,4,0,0,11,0,0,0,175,6,0,0,11,0,0,0,197,16,0,0,13,0,0,0,12,0,0,0,4,0,0,0,50,4,0,0,11,0,0,0,148,7,0,0,11,0,0,0,48,30,0,0,13,0,0,0,66,0,0,0,7,0,0,0,112,8,0,0,12,0,0,0,36,15,0,0,12,0,0,0,67,30,0,0,13,0,0,0,32,0,0,0,6,0,0,0,62,4,0,0,11,0,0,0,149,7,0,0,11,0,0,0,170,26,0,0,13,0,0,0,55,0,0,0,6,0,0,0,172,6,0,0,11,0,0,0,174,6,0,0,11,0,0,0,246,16,0,0,13,0,0,0,52,0,0,0,6,0,0,0,58,4,0,0,11,0,0,0,80,13,0,0,12,0,0,0,174,26,0,0,13,0,0,0,57,0,0,0,6,0,0,0,63,4,0,0,11,0,0,0,141,7,0,0,11,0,0,0,210,16,0,0,13,0,0,0,56,0,0,0,6,0,0,0,59,4,0,0,11,0,0,0,189,6,0,0,11,0,0,0,211,16,0,0,13,0,0,0,17,0,0,0,5,0,0,0,172,1,0,0,9,0,0,0,243,0,0,0,8,0,0,0,57,4,0,0,11,0,0,0,161,2,0,0,10,0,0,0,64,87,0,0,15,0,0,0,191,160,1,0,18,0,0,0,25,93,1,0,17,0,0,0,20,21,0,0,13,0,0,0,30,70,0,0,15,0,0,0,118,81,1,0,17,0,0,0,119,81,1,0,17,0,0,0,173,17,0,0,13,0,0,0,46,104,0,0,16,0,0,0,249,130,6,0,20,0,0,0,125,65,3,0,19,0,0,0,54,26,0,0,14,0,0,0,45,42,0,0,14,0,0,0,94,208,0,0,17,0,0,0,36,104,0,0,16,0,0,0,21,21,0,0,13,0,0,0,92,84,0,0,15,0,0,0,233,48,2,0,18,0,0,0,250,26,1,0,17,0,0,0,215,21,0,0,13,0,0,0,71,87,0,0,15,0,0,0,121,141,0,0,16,0,0,0,37,104,0,0,16,0,0,0,162,43,0,0,14,0,0,0,186,168,0,0,16,0,0,0,246,53,2,0,18,0,0,0,24,93,1,0,17,0,0,0,174,17,0,0,13,0,0,0,111,52,0,0,15,0,0,0,59,140,0,0,16,0,0,0,110,52,0,0,15,0,0,0,26,13,0,0,13,0,0,0,31,70,0,0,15,0,0,0,248,130,6,0,20,0,0,0,117,24,1,0,17,0,0,0,161,43,0,0,14,0,0,0,97,141,0,0,16,0,0,0,247,53,2,0,18,0,0,0,232,48,2,0,18,0,0,0,19,21,0,0,13,0,0,0,123,141,0,0,16,0,0,0,244,26,1,0,17,0,0,0,245,26,1,0,17,0,0,0,133,17,0,0,13,0,0,0,191,70,0,0,15,0,0,0,96,141,0,0,16,0,0,0,124,141,0,0,16,0,0,0,18,21,0,0,13,0,0,0,28,70,0,0,15,0,0,0,141,174,0,0,16,0,0,0,120,141,0,0,16,0,0,0,14,13,0,0,13,0,0,0,19,52,0,0,15,0,0,0,177,70,0,0,15,0,0,0,22,52,0,0,15,0,0,0,234,10,0,0,12,0,0,0,44,42,0,0,14,0,0,0,65,87,0,0,15,0,0,0,47,42,0,0,14,0,0,0,88,1,0,0,9,0,0,0,210,8,0,0,12,0,0,0,76,5,0,0,11,0,0,0,134,6,0,0,12,0,0,0,0,0,0,0,2,0,0,0,105,0,0,0,8,0,0,0,107,0,0,0,8,0,0,0,140,6,0,0,12,0,0,0,7,0,0,0,3,0,0,0,94,1,0,0,9,0,0,0,163,2,0,0,10,0,0,0,233,10,0,0,12,0,0,0,6,0,0,0,3,0,0,0,49,2,0,0,10,0,0,0,184,2,0,0,10,0,0,0,8,26,0,0,14,0,0,0,16,0,0,0,5,0,0,0,169,1,0,0,10,0,0,0,66,3,0,0,11,0,0,0,136,10,0,0,12,0,0,0,4,0,0,0,4,0,0,0,162,1,0,0,10,0,0,0,164,2,0,0,10,0,0,0,132,17,0,0,13,0,0,0,18,0,0,0,5,0,0,0,50,2,0,0,10,0,0,0,178,2,0,0,10,0,0,0,128,6,0,0,12,0,0,0,27,0,0,0,6,0,0,0,106,4,0,0,11,0,0,0,142,6,0,0,12,0,0,0,89,35,0,0,14,0,0,0,22,0,0,0,5,0,0,0,95,1,0,0,9,0,0,0,160,2,0,0,10,0,0,0,77,5,0,0,11,0,0,0,5,0,0,0,4,0,0,0,51,2,0,0,10,0,0,0,185,2,0,0,10,0,0,0,214,21,0,0,13,0,0,0,34,0,0,0,6,0,0,0,104,4,0,0,11,0,0,0,131,6,0,0,12,0,0,0,10,26,0,0,14,0,0,0,19,0,0,0,5,0,0,0,54,2,0,0,10,0,0,0,187,2,0,0,10,0,0,0,134,17,0,0,13,0,0,0,23,0,0,0,5,0,0,0,171,1,0,0,10,0,0,0,167,2,0,0,10,0,0,0,211,8,0,0,12,0,0,0,20,0,0,0,5,0,0,0,55,2,0,0,10,0,0,0,96,4,0,0,11,0,0,0,15,13,0,0,13,0,0,0,25,0,0,0,6,0,0,0,170,1,0,0,10,0,0,0,179,2,0,0,10,0,0,0,129,6,0,0,12,0,0,0,24,0,0,0,6,0,0,0,168,1,0,0,10,0,0,0,165,2,0,0,10,0,0,0,143,6,0,0,12,0,0,0,7,0,0,0,4,0,0,0,85,0,0,0,7,0,0,0,71,0,0,0,7,0,0,0,173,0,0,0,8,0,0,0,167,0,0,0,14,0,0,0,184,178,1,0,18,0,0,0,142,178,1,0,18,0,0,0,117,101,3,0,19,0,0,0,172,108,0,0,16,0,0,0,105,10,0,0,18,0,0,0,52,41,0,0,20,0,0,0,107,82,0,0,21,0,0,0,161,108,0,0,16,0,0,0,185,178,1,0,18,0,0,0,173,41,0,0,20,0,0,0,83,147,2,0,24,0,0,0,167,108,0,0,16,0,0,0,171,108,0,0,16,0,0,0,187,178,1,0,18,0,0,0,155,2,0,0,16,0,0,0,68,217,0,0,17,0,0,0,106,10,0,0,18,0,0,0,168,73,1,0,23,0,0,0,31,101,3,0,19,0,0,0,175,108,0,0,16,0,0,0,76,10,0,0,18,0,0,0,30,101,3,0,19,0,0,0,72,10,0,0,18,0,0,0,156,41,0,0,20,0,0,0,159,41,0,0,20,0,0,0,82,147,2,0,24,0,0,0,172,41,0,0,20,0,0,0,150,2,0,0,16,0,0,0,70,217,0,0,17,0,0,0,104,10,0,0,18,0,0,0,152,2,0,0,16,0,0,0,39,5,0,0,17,0,0,0,77,217,0,0,17,0,0,0,215,20,0,0,19,0,0,0,116,101,3,0,19,0,0,0,92,10,0,0,18,0,0,0,153,178,1,0,18,0,0,0,157,41,0,0,20,0,0,0,158,41,0,0,20,0,0,0,37,5,0,0,17,0,0,0,102,10,0,0,18,0,0,0,213,164,0,0,22,0,0,0,155,20,0,0,19,0,0,0,149,2,0,0,16,0,0,0,173,108,0,0,16,0,0,0,73,10,0,0,18,0,0,0,33,5,0,0,17,0,0,0,170,108,0,0,16,0,0,0,69,217,0,0,17,0,0,0,152,178,1,0,18,0,0,0,47,5,0,0,17,0,0,0,84,54,0,0,15,0,0,0,160,108,0,0,16,0,0,0,50,5,0,0,17,0,0,0,145,2,0,0,16,0,0,0,82,54,0,0,15,0,0,0,32,5,0,0,17,0,0,0,93,10,0,0,18,0,0,0,148,2,0,0,16,0,0,0,155,0,0,0,11,0,0,0,226,6,0,0,12,0,0,0,40,0,0,0,12,0,0,0,176,1,0,0,10,0,0,0,1,0,0,0,3,0,0,0,16,0,0,0,8,0,0,0,47,0,0,0,6,0,0,0,76,0,0,0,10,0,0,0,13,0,0,0,4,0,0,0,0,0,0,0,10,0,0,0,6,0,0,0,9,0,0,0,52,1,0,0,12,0,0,0,12,0,0,0,4,0,0,0,7,0,0,0,10,0,0,0,7,0,0,0,9,0,0,0,225,6,0,0,12,0,0,0,14,0,0,0,5,0,0,0,218,0,0,0,9,0,0,0,34,0,0,0,9,0,0,0,100,3,0,0,11,0,0,0,15,0,0,0,4,0,0,0,6,0,0,0,10,0,0,0,15,0,0,0,9,0,0,0,53,1,0,0,12,0,0,0,20,0,0,0,5,0,0,0,221,0,0,0,9,0,0,0,4,0,0,0,9,0,0,0,21,0,0,0,11,0,0,0,26,0,0,0,6,0,0,0,179,1,0,0,10,0,0,0,5,0,0,0,10,0,0,0,227,6,0,0,12,0,0,0,12,0,0,0,5,0,0,0,185,0,0,0,8,0,0,0,4,0,0,0,8,0,0,0,219,0,0,0,9,0,0,0,14,0,0,0,4,0,0,0,11,0,0,0,10,0,0,0,35,0,0,0,9,0,0,0,203,6,0,0,12,0,0,0,5,0,0,0,6,0,0,0,177,1,0,0,10,0,0,0,1,0,0,0,10,0,0,0,224,6,0,0,12,0,0,0,17,0,0,0,5,0,0,0,223,0,0,0,9,0,0,0,14,0,0,0,9,0,0,0,115,3,0,0,11,0,0,0,3,0,0,0,5,0,0,0,184,0,0,0,8,0,0,0,6,0,0,0,8,0,0,0,117,1,0,0,9,0,0,0,21,0,0,0,5,0,0,0,116,1,0,0,9,0,0,0,39,0,0,0,9,0,0,0,114,3,0,0,11,0,0,0,16,0,0,0,5,0,0,0,187,0,0,0,8,0,0,0,5,0,0,0,8,0,0,0,222,0,0,0,9,0,0,0,15,0,0,0,5,0,0,0,1,0,0,0,9,0,0,0,18,0,0,0,8,0,0,0,4,0,0,0,10,0,0,0,2,0,0,0,3,0,0,0,22,0,0,0,5,0,0,0,9,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,3,5,2,3,3,3,2,4,3,4,2,2,3,2,1,6,2,6,3,6,2,5,0,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,114,0,101,0,100,0,105,0,114,0,101,0,99,0,116,0,111,0,114,0,46,0,108,0,101,0,103,0,97,0,99,0,121,0,95,0,97,0,116,0,116,0,114,0,105,0,98,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,104,0,101,0,97,0,100,0,101,0,114,0,46,0,116,0,105,0,109,0,101,0,0,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,104,0,101,0,97,0,100,0,101,0,114,0,46,0,108,0,101,0,103,0,97,0,99,0,121,0,95,0,97,0,116,0,116,0,114,0,105,0,98,0,0,0,3,0,3,0,4,0,11,0,5,0,20,0,6,0,63,0,6,0,93,0,7,0,162,0,8,0,172,0,9,0,110,1,9,0,10,2,10,0,226,2,10,0,50,4,11,0,201,5,11,0,39,8,12,0,84,11,12,0,230,4,13,0,95,16,13,0,42,23,13,0,178,32,14,0,78,45,14,0,240,57,14,0,117,65,15,0,158,90,15,0,4,0,4,0,30,0,5,0,66,0,7,0,182,0,8,0,115,1,9,0,149,3,10,0,46,7,11,0,148,11,12,0,164,22,13,0,179,32,14,0,69,46,14,0,5,0,5,0,64,0,7,0,73,0,9,0,143,2,10,0,203,5,11,0,138,4,13,0,221,9,14,0,226,115,15,0,24,0,5,0,37,0,8,0,138,0,10,0,27,5,11,0,95,14,12,0,201,9,14,0,156,19,15,0,41,0,6,0,79,0,9,0,18,4,11,0,141,4,13,0,65,46,14,0,56,0,6,0,14,1,9,0,168,5,11,0,92,16,13,0,242,57,14,0,88,0,7,0,31,2,10,0,126,14,12,0,255,57,14,0,35,0,8,0,227,2,10,0,229,4,13,0,64,46,14,0,161,0,8,0,190,5,11,0,200,9,14,0,131,0,8,0,58,1,11,0,33,23,13,0,68,0,9,0,118,2,12,0,246,57,14,0,139,0,10,0,239,4,13,0,155,90,15,0,8,2,10,0,254,28,13,0,153,3,10,0,180,28,13,0,158,3,10,0,243,57,14,0,171,5,11,0,227,115,15,0,55,7,11,0,159,90,15,0,45,8,12,0,105,14,12,0,104,14,12,0,51,4,11,0,123,11,12,0,248,45,14,0,86,46,14,0,87,46,14,0,247,57,14,0,165,81,15,0,3,0,3,0,42,0,6,0,228,0,8,0,142,2,10,0,53,7,11,0,88,16,13,0,250,28,13,0,249,45,14,0,116,65,15,0,9,0,4,0,84,0,8,0,152,3,10,0,139,4,13,0,157,19,15,0,13,0,4,0,173,0,9,0,38,8,12,0,76,45,14,0,17,0,5,0,107,1,9,0,127,11,12,0,164,81,15,0,25,0,5,0,27,2,10,0,253,22,13,0,29,0,5,0,148,3,10,0,211,40,14,0,43,0,6,0,188,5,11,0,154,90,15,0,47,0,6,0,71,2,12,0,16,0,7,0,53,10,12,0,62,0,6,0,122,11,12,0,89,0,7,0,94,16,13,0,38,0,8,0,207,9,14,0,85,0,8,0,181,28,13,0,87,0,8,0,91,14,12,0,160,0,8,0,104,20,13,0,112,1,9,0,144,0,10,0,206,1,9,0,26,2,10,0,24,2,10,0,104,1,9,0,30,2,10,0,68,2,12,0,54,7,11,0,56,1,11,0,25,5,11,0,94,14,12,0,44,7,11,0,85,11,12,0,220,9,14,0,187,32,14,0,140,4,13,0,35,23,13,0,68,46,14,0,165,22,13,0,24,5,11,0,254,57,14,0,105,1,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,5,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,13,13,14,14,15,15,16,16,17,18,19,20,21,22,23,24,25,26,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,1,2,3,4,5,6,7,8,9,10,11,1,2,3,4,5,6,7,8,1,2,3,4,5,6,7,1,2,3,4,5,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,6,7,8,9,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,2,0,5,0,3,0,13,0,4,0,18,0,5,0,14,0,6,0,21,0,7,0,19,0,8,0,63,0,8,0,75,0,9,0,31,1,9,0,184,0,10,0,227,3,10,0,114,1,11,0,77,2,12,0,218,3,12,0,221,2,13,0,85,31,13,0,185,5,14,0,174,62,14,0,0,0,4,0,16,0,5,0,8,0,7,0,32,0,8,0,41,0,9,0,244,1,9,0,51,2,10,0,224,1,11,0,42,1,12,0,221,3,12,0,10,5,13,0,41,31,13,0,66,10,14,0,114,18,15,0,55,23,15,0,3,0,5,0,17,0,7,0,196,0,8,0,75,0,10,0,180,0,11,0,212,7,11,0,69,3,12,0,215,2,13,0,191,7,13,0,56,9,14,0,187,11,14,0,94,9,15,0,19,0,5,0,120,0,7,0,105,0,9,0,50,2,10,0,97,4,11,0,236,3,12,0,32,5,13,0,42,31,13,0,80,62,14,0,81,62,14,0,134,20,15,0,12,0,6,0,36,0,9,0,148,0,11,0,192,8,12,0,9,15,14,0,240,30,15,0,61,0,6,0,83,0,9,0,160,1,11,0,214,2,13,0,8,15,14,0,19,0,7,0,124,0,9,0,193,7,11,0,172,4,14,0,27,0,7,0,160,0,10,0,68,3,12,0,121,15,14,0,121,0,7,0,225,3,10,0,212,2,13,0,6,35,14,0,33,0,8,0,60,2,10,0,174,15,12,0,222,35,14,0,53,0,8,0,117,1,11,0,179,7,13,0,197,0,8,0,116,1,11,0,133,7,13,0,72,0,9,0,163,1,11,0,158,4,13,0,44,0,9,0,250,0,10,0,214,7,11,0,146,0,10,0,204,5,13,0,241,30,15,0,163,0,10,0,237,3,12,0,62,9,14,0,226,1,11,0,115,18,15,0,196,7,11,0,135,20,15,0,145,2,12,0,147,2,12,0,138,15,12,0,9,5,13,0,8,5,13,0,141,7,13,0,190,7,13,0,140,7,13,0,174,4,14,0,186,11,14,0,7,35,14,0,154,11,14,0,54,23,15,0,14,0,4,0,69,0,7,0,243,1,9,0,122,4,11,0,220,5,13,0,223,35,14,0,25,0,5,0,40,0,9,0,118,1,11,0,157,4,13,0,221,35,14,0,48,0,6,0,162,0,10,0,239,2,12,0,184,5,14,0,63,0,6,0,165,0,10,0,219,3,12,0,63,9,14,0,68,0,7,0,203,7,11,0,95,9,15,0,99,0,7,0,195,3,12,0,21,0,8,0,246,8,12,0,23,0,8,0,152,4,13,0,44,0,8,0,178,7,13,0,47,0,8,0,84,31,13,0,141,0,8,0,189,7,13,0,142,0,8,0,130,17,13,0,251,0,8,0,11,5,13,0,45,0,8,0,192,7,11,0,121,0,9,0,95,31,13,0,122,0,9,0,86,31,13,0,49,2,10,0,228,3,10,0,161,1,11,0,67,1,11,0,247,1,11,0,111,1,12,0,146,2,12,0,231,2,12,0,108,1,12,0,109,1,12,0,220,3,12,0,139,15,12,0,153,4,13,0,216,3,12,0,142,7,13,0,213,2,13,0,94,31,13,0,43,31,13,0,143,7,13,0,173,4,14,0,175,62,14,0,220,35,14,0,74,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,5,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,11,11,11,12,12,12,13,13,13,14,14,14,15,15,15,16,16,17,17,18,19,20,21,22,23,24,25,26,27,28,29,30,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,1,2,3,4,5,6,7,8,9,10,11,12,1,2,3,4,5,6,7,8,9,10,11,1,2,3,4,5,6,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,6,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,4,0,3,0,20,0,5,0,23,0,7,0,127,0,8,0,84,1,9,0,242,1,10,0,191,0,11,0,101,0,12,0,170,10,12,0,48,6,13,0,151,21,13,0,183,3,14,0,34,43,14,0,230,11,15,0,11,0,4,0,55,0,7,0,98,0,9,0,7,0,11,0,102,1,12,0,206,0,13,0,144,21,13,0,246,5,14,0,231,11,15,0,7,0,5,0,109,0,8,0,3,0,11,0,31,3,12,0,242,5,14,0,2,0,6,0,97,0,9,0,85,0,12,0,223,1,14,0,26,0,6,0,30,0,10,0,201,10,12,0,35,43,14,0,30,0,6,0,31,0,10,0,195,10,12,0,43,43,14,0,6,0,7,0,4,0,11,0,248,2,13,0,25,0,7,0,6,0,11,0,61,6,13,0,87,0,7,0,130,1,11,0,162,42,14,0,4,0,8,0,128,1,11,0,156,5,14,0,125,0,8,0,100,1,12,0,109,7,15,0,2,0,9,0,141,1,11,0,129,21,13,0,173,0,8,0,96,0,12,0,103,12,14,0,28,0,9,0,238,0,13,0,3,0,9,0,207,2,13,0,217,0,9,0,128,21,13,0,2,0,11,0,131,1,11,0,87,0,12,0,97,0,12,0,49,0,11,0,102,0,12,0,49,6,13,0,50,6,13,0,172,0,13,0,29,3,12,0,118,0,12,0,58,0,11,0,101,1,12,0,102,12,14,0,3,0,2,0,84,0,7,0,171,2,10,0,22,0,13,0,247,5,14,0,5,0,4,0,248,0,9,0,169,10,12,0,95,0,15,0,4,0,4,0,28,0,10,0,80,21,13,0,4,0,5,0,119,0,11,0,108,7,15,0,14,0,5,0,10,0,12,0,12,0,5,0,98,5,11,0,4,0,6,0,28,3,12,0,6,0,6,0,200,0,13,0,13,0,6,0,218,1,13,0,7,0,6,0,201,0,13,0,1,0,7,0,46,0,14,0,20,0,7,0,150,21,13,0,10,0,7,0,194,10,12,0,22,0,7,0,91,1,14,0,21,0,7,0,90,1,14,0,15,0,8,0,94,0,15,0,126,0,8,0,171,0,8,0,45,0,9,0,216,0,9,0,11,0,9,0,20,0,10,0,179,2,10,0,243,1,10,0,58,0,10,0,0,0,10,0,88,0,10,0,46,0,9,0,94,0,10,0,99,5,11,0,236,0,12,0,84,0,12,0,193,10,12,0,86,21,13,0,250,2,13,0,129,1,11,0,87,21,13,0,157,5,14,0,163,42,14,0,42,43,14,0,222,1,14,0,60,6,13,0,207,0,13,0,148,21,13,0,13,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,12,13,13,14,14,15,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,0,0,0,0,0,1,1,1,1,2,2,2,3,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,0,0,0,0,32,32,31,31,32,33,31,33,33,32,32,30,34,31,32,29,33,30,32,33,31,35,34,30,34,31,33,29,29,31,33,35,30,30,35,32,32,34,34,28,25,32,36,27,32,32,32,37,39,3,32,30,31,26,31,32,32,38,29,29,32,34,31,31,34,35,33,33,28,33,1,33,27,29,30,31,28,29,37,35,31,33,35,27,36,37,25,25,61,35,4,5,32,33,36,30,23,30,28,34,31,32,32,39,32,34,21,39,32,59,32,28,32,36,60,33,24,36,32,32,41,2,32,38,26,22,33,30,31,32,32,30,31,32,29,3,40,38,32,32,33,26,31,34,28,38,34,31,3,31,35,38,27,35,33,28,29,27,29,27,43,29,37,63,31,33,34,30,31,30,37,30,35,35,26,41,37,31,33,28,26,30,42,24,7,27,33,29,36,28,34,57,23,41,36,23,35,34,25,30,25,33,25,25,29,24,33,39,33,33,0,37,31,36,21,32,61,24,35,61,31,5,31,59,39,21,32,30,34,22,40,32,29,16,31,5,62,2,20,39,39,32,33,1,31,24,36,32,36,32,28,26,6,31,38,34,58,35,32,33,33,17,43,26,31,40,31,34,32,32,31,19,30,32,29,33,38,38,32,59,40,18,38,32,35,34,32,17,1,15,30,28,31,28,34,29,32,27,35,27,49,22,37,34,37,26,32,32,22,28,45,29,30,31,43,46,41,30,26,13,34,32,27,38,42,42,33,47,33,60,27,42,25,32,22,32,48,32,45,33,33,41,27,25,19,31,35,19,36,42,27,17,31,44,28,33,33,31,23,31,40,33,31,34,30,32,33,36,35,47,37,41,31,23,41,29,30,35,32,25,32,28,58,2,37,33,14,33,49,20,39,36,21,9,23,33,35,24,39,37,11,33,30,31,31,28,51,40,35,29,25,33,46,35,37,30,30,8,63,28,15,40,33,45,49,25,32,4,47,51,36,39,53,10,24,29,30,31,25,40,38,38,33,56,23,27,32,37,26,29,43,36,33,24,55,43,9,29,34,34,24,33,18,33,33,30,31,50,24,60,30,39,34,30,39,28,22,38,2,26,63,32,57,21,39,33,28,18,30,34,22,33,29,41,30,34,35,21,13,34,35,39,30,46,32,42,32,31,33,26,11,33,22,31,25,31,53,27,43,25,40,50,21,36,38,30,12,31,34,20,15,29,32,62,30,13,17,32,19,31,20,31,30,7,1,17,34,37,31,31,44,34,26,40,16,37,52,48,30,20,18,33,38,29,7,25,30,54,45,47,46,41,29,29,16,30,14,26,38,34,34,29,34,30,29,30,57,30,4,46,33,29,39,44,30,31,50,33,31,32,19,32,40,31,37,47,1,35,16,31,0,35,33,1,17,34,9,34,33,31,49,43,42,51,34,29,23,29,14,30,45,49,11,24,31,28,35,41,30,44,18,29,34,35,36,25,26,21,31,30,34,19,34,44,36,38,25,31,28,23,37,3,55,41,30,22,41,24,33,26,35,35,30,55,51,47,48,38,24,15,21,50,25,46,30,29,10,34,42,45,29,42,22,3,33,27,34,1,34,28,34,36,35,23,23,13,58,3,26,63,25,31,34,61,38,39,25,61,29,37,30,41,26,48,28,33,50,35,30,37,29,29,40,6,39,28,28,19,8,22,45,34,35,10,58,17,37,39,30,18,54,14,29,16,59,30,35,23,35,30,47,36,29,55,20,12,31,35,14,29,18,34,34,24,29,26,22,2,27,23,8,30,55,38,60,31,4,34,49,34,27,34,33,30,31,54,42,35,38,46,44,26,27,9,39,25,21,29,28,42,13,0,5,34,37,28,24,29,63,26,22,27,29,25,33,25,61,0,35,25,36,15,27,40,53,33,3,10,16,37,38,18,30,46,27,9,6,29,62,8,42,28,29,3,25,16,26,29,35,28,27,51,61,48,37,9,34,7,49,45,20,29,21,5,5,29,28,34,29,24,10,24,35,36,38,55,11,36,38,53,54,26,30,49,20,27,30,39,33,41,49,22,38,38,4,30,8,9,3,24,22,50,37,36,31,27,2,9,42,63,25,19,44,1,28,28,48,30,34,41,41,38,12,27,15,0,16,34,35,38,28,29,40,42,51,52,45,54,59,59,42,44,37,26,46,24,15,39,22,46,19,35,38,17,37,23,52,55,50,37,26,11,37,12,24,30,16,13,22,13,36,35,40,41,34,41,26,53,51,5,21,30,2,63,41,20,1,56,21,24,25,5,28,35,26,28,30,18,29,23,40,34,20,42,39,34,28,61,38,27,62,9,36,17,9,49,24,25,54,34,39,37,3,1,25,38,38,44,35,36,12,60,36,38,40,25,43,39,53,28,39,57,46,10,52,27,35,42,45,59,15,60,38,24,23,39,12,29,24,0,20,16,28,43,35,28,1,49,4,21,42,39,29,3,44,21,53,55,11,5,3,39,53,28,25,19,34,28,21,0,0,0,0,0,32,31,32,31,33,32,33,33,31,34,30,32,32,34,35,32,34,33,29,30,30,32,31,31,33,35,35,33,31,29,29,33,34,30,31,28,36,30,34,32,32,37,32,32,25,27,39,32,32,32,38,35,36,32,37,61,26,32,34,35,3,35,27,28,29,34,28,37,31,36,32,27,31,30,29,39,33,29,33,35,25,25,29,33,31,31,31,33,32,30,32,32,41,39,33,36,32,28,34,36,38,24,60,31,23,28,32,33,59,32,40,30,5,34,32,38,32,30,43,4,32,32,42,31,31,32,26,38,26,22,21,37,61,63,37,31,32,33,2,1,23,33,41,27,35,30,38,23,33,3,28,34,34,27,41,29,39,35,36,29,32,27,30,32,24,61,37,26,59,25,35,27,36,37,30,31,34,40,3,28,34,39,32,31,32,30,24,28,35,36,26,32,31,33,29,33,39,25,30,24,35,59,29,34,25,30,21,35,43,40,32,29,5,28,31,62,33,33,25,31,21,31,43,31,34,33,20,40,39,31,31,57,38,32,42,33,32,31,32,29,30,44,5,31,22,34,36,17,38,58,38,35,32,60,35,24,32,38,16,45,42,32,31,29,4,30,17,40,46,48,63,32,42,19,41,22,28,36,45,33,33,32,29,7,41,42,18,33,33,32,22,37,1,26,22,23,49,28,26,27,32,33,27,23,28,36,15,6,34,27,31,26,23,2,33,32,34,41,28,32,41,0,36,38,34,31,47,32,17,31,39,33,37,51,30,47,32,50,32,19,63,30,25,27,33,62,24,31,27,30,37,31,45,32,39,20,46,47,35,19,34,1,49,21,21,14,51,26,23,31,36,35,58,29,29,21,20,42,13,28,12,40,31,33,39,60,32,44,33,31,28,37,29,32,30,49,43,28,39,25,32,48,2,15,20,25,31,28,21,24,25,15,31,17,37,43,18,32,33,24,33,36,13,33,31,39,11,31,33,32,39,37,32,32,29,17,44,46,36,35,26,37,58,32,34,38,8,38,38,22,29,25,16,35,32,35,33,43,18,46,38,50,33,18,53,60,13,32,36,33,51,36,43,45,27,42,29,24,30,25,31,52,31,35,38,9,22,34,4,17,28,55,42,25,17,20,47,34,33,16,40,25,16,30,53,29,10,11,14,26,33,4,35,44,26,16,31,26,34,38,29,31,30,24,22,61,32,9,45,34,31,19,9,31,46,31,35,54,29,57,30,50,3,31,63,34,47,41,51,18,31,14,37,38,31,24,32,31,50,33,31,54,27,9,33,23,19,32,29,29,33,28,47,49,30,47,33,27,25,54,44,45,50,58,51,48,33,59,33,34,57,13,26,33,13,48,30,11,7,56,34,55,26,0,26,35,1,51,33,53,31,45,12,29,29,51,31,48,2,6,34,30,28,33,60,40,27,46,31,9,35,29,31,39,55,46,19,37,62,34,30,16,19,49,41,41,39,37,14,5,13,35,55,30,40,40,42,8,20,25,45,35,33,36,54,38,27,37,62,40,15,59,49,31,29,34,34,39,24,29,25,29,21,29,10,61,33,49,35,34,3,38,39,29,7,41,1,35,4,23,15,23,11,37,28,35,30,30,24,1,43,56,8,34,42,24,45,30,20,23,8,38,22,33,17,52,34,22,53,43,44,1,27,31,41,43,41,30,31,36,30,5,55,31,33,30,40,23,15,29,34,34,59,34,30,11,13,38,5,0,30,42,5,30,29,34,10,44,30,63,35,12,3,26,15,17,25,34,43,39,34,56,29,23,30,12,30,10,35,9,24,58,10,12,54,33,37,20,41,35,29,18,61,30,40,24,39,53,62,26,29,33,34,53,49,21,27,11,63,20,26,23,7,13,6,47,29,30,9,51,22,34,21,25,33,56,57,30,38,51,51,38,63,28,40,35,33,18,33,33,24,58,58,34,49,29,43,4,1,4,42,35,35,30,17,5,56,61,25,37,36,55,28,35,29,50,48,52,2,42,34,40,46,46,43,35,29,48,20,29,31,41,7,30,35,19,14,21,8,39,39,40,46,55,34,6,30,34,37,25,37,33,22,44,52,17,35,29,36,35,40,37,28,30,50,14,28,55,6,23,19,14,30,3,30,28,28,61,61,47,45,48,40,40,34,34,25,30,29,35,4,26,53,50,26,41,27,59,27,38,39,3,50,43,47,23,33,55,35,21,23,35,61,33,46,52,35,34,24,30,43,16,37,21,2,24,45,34,30,55,55,1,29,29,26,28,25,31,36,22,17,30,52,2,44,44,57,26,62,41,39,57,26,46,49,11,16,19,5,59,38,39,58,38,25,49,50,22,28,59,9,59,7,28,55,17,4,35,50,21,29,44,47,18,24,19,25,42,35,3,51,35,16,35,30,63,57,39,39,25,35,38,9,16,36,45,31,60,14,34,42,24,0,37,18,61,57,37,28,53,20,46,14,47,38,38,38,9,34,39,43,17,39,59,5,27,0,12,27,0,0,0,0,0,0,0,7,0,9,0,15,0,10,0,17,0,26,0,28,0,17,0,49,0,37,0,45,0,47,0,111,0,117,0,65,0,76,0,78,0,92,0,96,0,98,0,102,0,104,0,105,0,107,0,166,0,193,0,203,0,204,0,206,0,218,0,232,0,238,0,135,0,144,0,158,0,159,0,186,0,202,0,216,0,219,0,223,0,4,1,9,1,12,1,67,1,69,1,74,1,86,1,92,1,179,1,211,1,218,1,3,1,9,1,11,1,34,1,39,1,52,1,97,1,100,1,118,1,132,1,141,1,142,1,143,1,144,1,147,1,150,1,157,1,158,1,159,1,169,1,178,1,180,1,186,1,187,1,188,1,1,2,2,2,5,2,7,2,13,2,16,2,17,2,21,2,27,2,31,2,129,2,133,2,144,2,156,2,157,2,162,2,167,2,168,2,170,2,176,2,177,2,180,2,188,2,191,2,32,3,38,3,39,3,41,3,42,3,54,3,96,3,98,3,99,3,114,3,178,3,188,3,189,3,3,2,5,2,26,2,73,2,74,2,76,2,199,2,202,2,206,2,239,2,13,3,34,3,37,3,56,3,115,3,122,3,9,4,21,4,22,4,24,4,40,4,45,4,47,4,52,4,8,5,9,5,16,5,17,5,28,5,30,5,36,5,65,5,67,5,70,5,71,5,77,5,87,5,95,5,106,5,108,5,109,5,111,5,118,5,119,5,122,5,123,5,124,5,125,5,0,6,1,6,3,6,20,6,22,6,23,6,28,6,31,6,66,6,72,6,73,6,74,6,75,6,87,6,104,6,105,6,107,6,110,6,127,6,194,6,200,6,203,6,222,6,223,6,226,6,227,6,239,6,72,7,75,7,110,7,111,7,124,7,9,4,35,4,40,4,41,4,42,4,43,4,50,4,51,4,150,4,154,4,213,4,219,4,129,5,130,5,139,5,140,5,141,5,152,5,153,5,154,5,158,5,221,5,25,6,50,6,51,6,72,6,114,6,161,6,162,6,163,6,175,6,226,6,227,6,228,6,0,8,1,8,2,8,3,8,26,8,27,8,41,8,47,8,50,8,62,8,63,8,82,8,83,8,88,8,107,8,119,8,120,8,121,8,122,8,123,8,0,10,1,10,13,10,14,10,15,10,36,10,55,10,58,10,59,10,62,10,70,10,71,10,74,10,75,10,95,10,121,10,122,10,123,10,128,10,129,10,132,10,133,10,153,10,165,10,166,10,184,10,186,10,187,10,188,10,189,10,200,10,206,10,207,10,215,10,220,10,235,10,4,12,37,12,38,12,39,12,42,12,43,12,58,12,59,12,60,12,61,12,160,12,173,12,212,12,213,12,252,12,253,12,134,13,146,13,147,13,148,13,149,13,176,13,184,13,185,13,186,13,187,13,192,13,194,13,195,13,218,13,219,13,220,13,221,13,146,14,147,14,148,14,149,14,199,14,204,14,206,14,207,14,216,14,217,14,218,14,219,14,8,8,9,8,10,8,16,8,17,8,68,8,69,8,97,8,98,8,99,8,108,8,34,9,35,9,46,9,47,9,54,9,55,9,177,9,178,9,179,9,180,9,181,9,184,9,185,9,186,9,187,9,188,9,189,9,190,9,191,9,0,11,21,11,44,11,45,11,46,11,47,11,54,11,185,11,40,12,42,12,43,12,44,12,45,12,46,12,47,12,48,12,49,12,56,12,96,12,97,12,98,12,99,12,141,12,142,12,143,12,146,12,190,12,191,12,230,12,231,12,64,13,65,13,87,13,88,13,89,13,90,13,91,13,92,13,93,13,152,13,153,13,154,13,155,13,156,13,157,13,173,13,174,13,175,13,192,13,193,13,194,13,195,13,202,13,203,13,236,13,237,13,238,13,239,13,24,16,34,16,35,16,48,16,49,16,50,16,51,16,80,16,81,16,92,16,116,16,117,16,118,16,119,16,120,16,121,16,122,16,123,16,178,16,179,16,184,16,185,16,186,16,187,16,212,16,234,16,235,16,236,16,237,16,4,20,5,20,6,20,7,20,16,20,17,20,18,20,19,20,20,20,21,20,22,20,23,20,24,20,25,20,102,20,103,20,104,20,105,20,106,20,107,20,108,20,109,20,126,20,127,20,136,20,137,20,138,20,139,20,182,20,183,20,184,20,185,20,186,20,187,20,188,20,189,20,240,20,241,20,248,20,249,20,250,20,251,20,252,20,253,20,254,20,255,20,42,21,43,21,44,21,45,21,46,21,47,21,48,21,49,21,72,21,73,21,78,21,79,21,88,21,89,21,90,21,91,21,114,21,154,21,155,21,172,21,186,21,187,21,208,21,209,21,210,21,211,21,212,21,213,21,29,24,30,24,31,24,64,24,65,24,66,24,67,24,68,24,69,24,70,24,71,24,72,24,73,24,97,24,98,24,99,24,100,24,101,24,102,24,103,24,104,24,105,24,106,24,107,24,108,24,109,24,110,24,27,25,28,25,29,25,30,25,31,25,66,25,67,25,68,25,69,25,70,25,71,25,88,25,89,25,237,25,238,25,239,25,240,25,241,25,242,25,243,25,244,25,245,25,246,25,247,25,14,27,15,27,98,27,99,27,100,27,101,27,102,27,103,27,104,27,105,27,106,27,107,27,108,27,109,27,110,27,111,27,130,27,168,27,169,27,170,27,171,27,172,27,173,27,174,27,175,27,176,27,177,27,178,27,179,27,128,29,129,29,130,29,131,29,132,29,133,29,134,29,135,29,136,29,137,29,138,29,139,29,140,29,141,29,7,16,8,16,9,16,10,16,11,16,12,16,13,16,14,16,15,16,22,16,128,16,129,16,130,16,131,16,132,16,133,16,134,16,135,16,192,16,58,18,59,18,60,18,61,18,62,18,63,18,64,18,65,18,66,18,67,18,80,19,82,19,83,19,88,19,89,19,90,19,91,19,92,19,93,19,94,19,95,19,96,19,97,19,2,22,3,22,12,22,13,22,14,22,15,22,32,22,33,22,34,22,35,22,36,22,37,22,38,22,39,22,40,22,41,22,110,22,111,22,124,22,125,22,126,22,127,22,112,23,113,23,82,24,83,24,114,24,115,24,116,24,117,24,118,24,119,24,120,24,121,24,122,24,123,24,124,24,125,24,126,24,127,24,24,25,25,25,38,25,39,25,112,25,113,25,114,25,115,25,116,25,117,25,118,25,119,25,120,25,121,25,122,25,123,25,160,26,161,26,162,26,163,26,164,26,165,26,166,26,167,26,168,26,169,26,170,26,171,26,172,26,173,26,60,27,61,27,62,27,63,27,80,27,81,27,82,27,83,27,84,27,85,27,86,27,87,27,88,27,89,27,50,32,51,32,52,32,53,32,54,32,55,32,56,32,57,32,58,32,59,32,60,32,61,32,62,32,63,32,64,32,65,32,66,32,67,32,186,32,187,32,204,32,205,32,206,32,207,32,224,32,225,32,226,32,227,32,228,32,229,32,230,32,231,32,170,33,171,33,192,33,193,33,194,33,195,33,196,33,197,33,198,33,199,33,200,33,201,33,202,33,203,33,204,33,205,33,206,33,207,33,208,33,209,33,210,33,211,33,148,40,149,40,150,40,151,40,152,40,153,40,154,40,155,40,156,40,157,40,158,40,159,40,192,40,193,40,194,40,195,40,196,40,197,40,198,40,199,40,200,40,201,40,202,40,203,40,48,41,49,41,50,41,51,41,52,41,53,41,54,41,55,41,56,41,57,41,58,41,59,41,60,41,61,41,62,41,63,41,96,41,97,41,98,41,99,41,100,41], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+317440);
/* memory initializer */ allocate([101,41,102,41,103,41,104,41,105,41,106,41,107,41,64,42,65,42,66,42,67,42,68,42,69,42,70,42,71,42,72,42,73,42,74,42,75,42,76,42,77,42,78,42,79,42,80,42,81,42,82,42,83,42,230,42,231,42,36,43,37,43,38,43,39,43,40,43,41,43,42,43,43,43,44,43,45,43,46,43,47,43,48,43,49,43,50,43,51,43,90,43,91,43,20,48,21,48,22,48,23,48,32,48,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,42,48,43,48,44,48,45,48,46,48,47,48,48,48,49,48,50,48,51,48,52,48,53,48,54,48,55,48,56,48,57,48,192,48,193,48,222,48,223,48,24,50,25,50,26,50,27,50,28,50,29,50,30,50,31,50,32,50,33,50,34,50,35,50,36,50,37,50,38,50,39,50,40,50,41,50,42,50,43,50,44,50,45,50,46,50,47,50,48,50,49,50,50,50,51,50,52,50,53,50,120,51,121,51,122,51,123,51,124,51,125,51,126,51,127,51,192,51,193,51,194,51,195,51,196,51,197,51,198,51,199,51,200,51,201,51,202,51,203,51,204,51,205,51,206,51,207,51,208,51,209,51,210,51,211,51,212,51,213,51,214,51,215,51,216,51,217,51,6,55,7,55,48,55,49,55,50,55,51,55,52,55,53,55,54,55,55,55,56,55,57,55,58,55,59,55,60,55,61,55,62,55,63,55,64,55,65,55,66,55,67,55,68,55,69,55,70,55,71,55,72,55,73,55,74,55,75,55,76,55,77,55,78,55,79,55,52,59,53,59,54,59,55,59,232,59,233,59,234,59,235,59,236,59,237,59,238,59,239,59,240,59,241,59,242,59,243,59,244,59,245,59,246,59,247,59,248,59,249,59,250,59,251,59,252,59,253,59,254,59,255,59,0,32,1,32,2,32,3,32,4,32,5,32,6,32,7,32,8,32,9,32,10,32,11,32,12,32,13,32,46,32,47,32,130,33,131,33,180,33,181,33,182,33,183,33,184,33,185,33,186,33,187,33,188,33,189,33,190,33,191,33,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,106,36,107,36,108,36,109,36,110,36,111,36,112,36,113,36,114,36,115,36,162,38,163,38,11,0,2,4,4,4,5,5,5,5,6,6,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,4,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,1,2,3,4,5,6,7,8,9,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,1,0,2,0,6,0,3,0,15,0,4,0,22,0,5,0,32,0,6,0,24,0,7,0,8,0,8,0,154,0,8,0,86,0,9,0,62,1,9,0,240,0,10,0,165,3,10,0,119,0,11,0,239,1,11,0,154,0,12,0,93,0,13,0,1,0,4,0,17,0,5,0,2,0,7,0,11,0,8,0,18,0,9,0,214,1,9,0,126,2,10,0,145,1,11,0,234,0,12,0,220,3,12,0,59,1,13,0,4,0,5,0,20,0,7,0,158,0,8,0,9,0,10,0,172,1,11,0,226,1,11,0,202,3,12,0,95,0,13,0,23,0,5,0,78,0,7,0,94,0,9,0,243,0,10,0,173,1,11,0,236,0,12,0,240,5,13,0,14,0,6,0,225,0,8,0,164,3,10,0,156,0,12,0,61,1,13,0,59,0,6,0,28,0,9,0,20,0,11,0,190,9,12,0,6,0,7,0,122,0,9,0,144,1,11,0,55,1,13,0,27,0,7,0,8,0,10,0,92,7,11,0,113,0,7,0,215,0,10,0,191,9,12,0,7,0,8,0,175,0,10,0,204,4,11,0,52,0,8,0,101,2,10,0,159,0,12,0,224,0,8,0,22,0,11,0,39,3,12,0,21,0,9,0,125,1,11,0,187,14,12,0,20,0,9,0,246,0,10,0,228,1,11,0,203,0,10,0,157,9,12,0,202,0,10,0,252,2,12,0,127,1,11,0,205,4,11,0,253,2,12,0,254,4,11,0,58,1,13,0,10,0,4,0,66,0,7,0,211,1,9,0,221,4,11,0,18,0,5,0,232,0,8,0,76,0,11,0,54,1,13,0,57,0,6,0,100,2,10,0,186,14,12,0,0,0,7,0,174,0,10,0,156,9,12,0,31,0,7,0,222,4,11,0,67,0,7,0,220,4,11,0,3,0,8,0,203,3,12,0,6,0,8,0,158,9,12,0,42,0,8,0,241,5,13,0,15,0,8,0,254,9,12,0,51,0,8,0,255,9,12,0,152,0,8,0,159,9,12,0,234,0,8,0,60,1,13,0,46,0,8,0,146,1,11,0,54,1,9,0,106,0,9,0,21,0,11,0,175,3,10,0,227,1,11,0,116,0,11,0,235,0,12,0,249,2,12,0,92,0,13,0,237,0,12,0,221,3,12,0,38,3,12,0,94,0,13,0,22,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,12,13,13,13,14,14,15,15,16,17,18,19,20,0,0,0,0,1,1,1,1,2,2,2,3,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,15,16,17,18,19,20,21,22,23,24,25,26,0,0,0,0,32,31,32,33,32,31,31,33,33,34,32,30,32,35,34,31,32,29,33,30,32,34,33,31,30,35,31,31,29,33,35,30,29,33,34,34,30,32,32,36,29,32,35,32,28,32,32,27,35,37,34,29,30,36,35,34,25,30,29,35,33,31,31,32,31,28,39,28,29,37,31,33,27,36,28,36,37,33,33,31,27,32,31,38,26,25,25,33,39,31,34,30,32,32,32,34,36,32,28,33,30,38,37,27,33,28,32,37,35,38,29,34,27,29,29,32,32,34,35,3,26,36,31,38,30,26,35,34,37,26,25,32,32,39,23,37,32,32,29,32,29,36,29,30,41,31,30,21,39,25,34,38,32,35,39,32,33,33,32,27,29,25,28,27,26,31,30,35,24,24,31,34,32,30,35,40,28,38,5,35,29,36,36,32,38,30,33,31,35,26,23,38,32,41,28,25,37,40,37,39,32,36,33,39,25,26,28,31,28,42,23,31,33,31,39,1,59,22,27,4,33,34,33,24,41,3,35,41,41,28,36,36,28,33,35,21,23,21,22,37,27,27,43,29,60,39,27,25,59,34,27,27,26,40,37,27,61,26,39,33,31,22,37,25,30,25,24,61,31,34,25,38,32,32,30,3,61,43,29,23,28,32,28,32,31,34,5,33,32,33,33,42,37,23,38,31,40,26,32,26,37,38,36,24,29,30,20,22,29,24,32,41,2,34,25,33,29,31,39,35,36,24,32,30,33,27,44,60,30,36,19,34,31,24,16,35,32,38,21,33,31,31,21,35,5,17,29,38,38,18,58,19,43,41,30,41,43,39,29,7,29,17,28,19,28,31,25,19,40,26,21,33,39,23,40,30,39,34,35,32,32,24,33,30,40,47,39,37,32,33,24,23,45,47,27,23,42,32,32,33,36,37,37,17,18,22,40,38,32,31,35,24,17,25,17,23,33,34,51,42,31,36,36,29,21,22,37,44,43,25,47,33,45,27,31,58,31,32,31,38,43,20,47,45,54,1,26,34,38,14,22,24,33,34,32,32,37,21,23,49,35,23,28,39,39,23,55,33,30,30,63,16,42,28,13,33,33,35,19,46,43,17,19,36,39,24,31,32,33,26,28,62,33,63,33,39,19,49,17,31,43,13,15,29,25,35,33,23,49,41,28,29,34,38,7,61,11,50,13,41,19,47,25,26,15,42,41,29,45,27,17,35,32,29,32,24,13,26,26,31,24,33,28,30,31,11,45,46,33,33,35,57,32,32,35,45,34,11,37,42,39,37,31,49,21,27,29,47,53,40,51,16,26,1,40,30,41,44,34,25,27,31,35,35,31,15,49,1,35,40,5,58,21,29,22,59,45,31,9,26,9,29,11,32,30,3,13,20,18,20,11,3,29,40,31,53,30,17,20,37,31,42,47,47,54,38,9,34,13,37,21,25,27,43,42,45,40,25,27,46,22,25,53,20,2,14,39,15,22,44,34,21,38,33,27,48,34,52,35,47,49,54,2,13,23,52,29,45,22,49,54,21,40,42,31,30,29,34,0,25,23,51,24,59,28,38,29,31,2,13,31,8,31,33,12,45,41,7,14,30,25,18,43,20,43,35,44,1,49,42,42,18,41,38,41,44,53,11,20,25,45,46,47,48,39,52,46,49,63,55,44,38,13,13,57,22,51,16,12,28,35,57,25,20,26,28,28,29,32,31,62,34,35,35,19,49,48,39,40,18,43,46,11,6,48,19,49,41,10,23,58,17,21,23,34,30,60,0,44,34,26,37,46,43,49,59,4,34,59,37,22,25,28,46,6,40,59,42,36,61,28,30,31,43,10,22,23,47,20,52,55,36,25,16,1,11,27,29,5,63,18,41,31,34,38,1,5,13,28,31,17,38,39,41,36,37,22,39,33,43,43,15,17,49,30,21,22,20,10,17,25,54,57,3,34,8,36,25,31,14,15,19,29,25,18,39,53,22,27,20,29,33,41,42,35,62,50,29,53,50,35,55,42,61,63,4,7,42,21,46,47,49,27,46,17,55,41,50,63,4,56,18,8,10,18,51,63,36,55,18,5,55,9,29,17,21,30,27,1,59,7,11,12,15,5,42,24,41,43,7,27,22,25,31,30,37,22,39,53,29,36,37,48,0,5,13,17,31,32,26,46,28,44,45,46,53,49,51,3,41,3,22,42,33,5,45,7,22,40,53,24,14,25,27,10,12,34,16,17,53,20,26,39,45,18,45,35,33,31,49,4,39,42,11,51,5,13,26,27,17,52,30,0,22,12,34,62,36,38,41,47,30,63,38,41,43,59,33,45,37,38,40,47,24,48,49,30,1,10,22,49,15,39,59,31,32,33,18,13,15,31,21,27,44,42,39,46,17,26,32,30,31,0,30,34,9,12,13,25,31,32,55,43,35,61,33,35,46,25,47,48,62,63,38,61,1,2,5,7,9,46,10,34,35,36,55,51,7,40,23,34,37,5,13,42,18,25,27,28,0,0,0,0,0,32,32,31,32,33,31,33,31,33,32,34,32,30,32,31,34,35,32,34,33,29,33,30,30,31,31,35,29,33,35,33,34,31,29,30,34,30,36,28,32,34,37,30,27,32,25,39,32,34,32,35,35,35,31,35,29,32,29,30,29,37,27,36,38,37,33,32,31,29,31,28,36,33,30,34,33,33,28,27,25,31,26,39,32,32,31,33,39,31,38,28,36,21,23,43,36,34,41,30,25,28,31,30,34,38,35,61,34,28,30,37,37,35,27,36,3,59,38,37,32,31,29,26,33,37,33,27,27,35,34,34,40,42,33,32,29,4,5,28,24,25,35,39,38,32,23,27,32,30,35,26,34,60,36,29,22,26,41,7,30,38,30,36,29,30,41,26,25,32,34,24,39,1,25,39,32,28,29,32,38,26,36,28,63,28,39,23,21,26,35,31,35,57,31,29,29,28,30,27,35,2,38,40,34,37,29,38,43,26,32,33,42,24,40,28,32,32,32,36,32,43,25,21,31,30,31,41,29,33,37,26,37,27,59,23,33,35,31,31,37,38,39,32,23,32,27,37,36,31,40,25,27,38,31,36,28,31,36,25,45,3,34,38,39,40,38,30,32,19,24,25,26,45,20,24,33,33,31,41,34,39,47,40,58,59,41,33,3,17,61,42,30,26,29,36,61,33,37,62,28,25,38,25,38,17,23,34,33,21,33,49,27,32,23,27,22,24,22,39,43,27,37,6,42,47,26,30,31,41,39,33,22,45,36,32,45,19,22,30,5,5,17,29,22,31,31,43,37,27,32,32,32,33,34,43,35,29,26,22,32,19,32,25,31,41,49,28,34,28,39,34,19,37,38,29,21,36,42,24,48,16,28,49,22,34,31,38,39,44,11,35,30,33,33,23,28,33,46,15,13,24,41,24,34,34,30,26,24,14,60,21,29,39,23,35,37,63,45,33,34,47,41,22,42,35,35,23,32,35,43,32,7,31,41,20,31,16,13,63,25,30,32,35,30,30,31,42,47,39,38,40,40,51,55,56,18,21,39,39,33,17,41,23,24,43,25,31,20,19,45,1,34,31,22,35,15,46,46,35,31,28,29,29,23,41,27,14,53,53,27,24,32,57,32,17,42,37,29,33,1,25,32,32,63,26,40,44,36,31,39,20,20,44,23,33,34,35,33,33,28,41,23,41,41,29,25,26,49,29,24,37,49,50,51,51,26,39,25,26,15,39,18,42,17,4,31,32,32,60,1,42,32,0,12,19,35,21,41,17,26,20,45,46,32,37,22,47,29,31,27,29,30,21,33,35,18,25,33,50,51,42,2,15,51,53,33,25,29,55,37,38,33,38,59,38,33,39,13,32,40,61,61,32,9,44,3,31,29,25,31,27,23,9,25,9,29,20,30,30,42,18,28,25,28,28,21,29,43,29,43,26,44,44,21,38,21,24,45,45,35,39,22,35,36,34,34,45,34,29,31,46,25,46,16,17,31,20,32,47,47,47,32,49,49,49,31,1,27,28,39,39,21,36,23,51,2,40,51,32,53,24,30,24,30,21,40,57,57,31,41,58,32,12,4,32,34,59,31,32,13,9,35,26,35,37,61,37,63,26,29,41,38,23,20,41,26,41,42,42,42,26,26,26,26,1,26,37,37,37,23,34,42,27,43,34,27,31,24,33,16,3,31,24,33,24,4,44,44,11,44,31,13,13,44,45,13,25,22,38,26,38,38,39,32,30,39,30,22,32,26,30,47,47,47,19,47,30,31,35,8,23,47,47,27,35,47,31,48,35,19,36,49,49,33,31,39,27,39,49,49,50,50,50,39,31,51,51,39,28,33,33,21,40,31,52,53,40,53,9,33,31,53,54,54,54,55,55,34,15,56,25,56,21,21,40,40,25,40,58,36,5,41,41,12,60,41,41,37,22,61,18,29,29,30,61,30,61,62,62,30,30,63,18,13,30,23,19,20,20,41,13,2,5,5,1,5,32,6,32,35,20,35,27,35,35,36,36,13,36,41,41,41,3,30,42,27,20,30,27,28,30,21,33,33,14,24,30,42,24,33,25,42,43,14,43,43,14,43,7,36,37,37,37,37,7,14,25,43,43,44,15,37,7,7,3,1,8,15,15,8,44,44,44,45,45,45,45,8,8,45,21,45,28,28,28,21,28,28,22,37,46,46,37,8,29,37,29,22,46,37,22,29,47,47,38,38,16,38,38,33,38,22,47,47,29,25,16,0,48,1,34,48,48,34,25,26,26,49,49,26,1,49,4,26,4,49,1,9,49,49,49,10,49,17,38,17,17,50,38,50,50,22,38,51,38,38,51,39,39,18,22,39,51,22,52,52,52,39,53,53,10,23,18,29,10,53,29,54,11,54,11,11,55,1,18,55,55,55,55,55,55,29,34,18,29,56,56,34,57,34,34,29,29,57,57,35,35,35,35,35,39,35,59,59,18,59,39,30,18,40,60,60,61,30,18,61,61,19,19,0,0,0,0,0,1,0,3,0,5,0,7,0,3,0,8,0,12,0,1,0,2,0,27,0,6,0,11,0,21,0,2,0,14,0,15,0,20,0,32,0,34,0,37,0,39,0,41,0,45,0,75,0,77,0,3,0,34,0,35,0,37,0,39,0,66,0,72,0,73,0,80,0,92,0,145,0,159,0,14,0,67,0,76,0,84,0,86,0,140,0,152,0,154,0,155,0,177,0,178,0,32,1,33,1,38,1,51,1,57,1,161,1,164,1,165,1,166,1,167,1,174,1,175,1,11,0,25,0,133,0,144,0,155,0,170,0,175,0,12,1,14,1,28,1,30,1,51,1,68,1,96,1,116,1,117,1,119,1,120,1,73,2,75,2,82,2,97,2,101,2,112,2,82,3,83,3,85,3,89,3,16,0,17,0,19,0,52,0,53,0,54,0,55,0,61,0,62,0,9,1,38,1,86,1,26,2,30,2,58,2,62,2,142,2,143,2,207,2,145,4,148,4,159,4,160,4,163,4,166,4,167,4,173,4,174,4,192,4,196,4,198,4,200,4,201,4,245,4,246,4,247,4,128,6,130,6,131,6,136,6,137,6,141,6,142,6,143,6,162,6,163,6,169,6,176,6,177,6,180,6,181,6,36,0,96,0,99,0,120,0,121,0,17,2,68,2,69,2,71,2,72,2,73,2,74,2,75,2,107,2,175,2,184,2,187,2,54,4,118,4,119,4,126,4,200,4,201,4,202,4,20,5,134,5,135,5,152,5,157,5,217,5,218,5,32,9,33,9,59,9,60,9,61,9,66,9,67,9,68,9,69,9,89,9,94,9,95,9,130,9,131,9,142,9,143,9,196,9,231,9,232,9,233,9,2,13,23,13,24,13,25,13,65,13,66,13,67,13,80,13,95,13,109,13,110,13,111,13,82,0,83,0,84,0,85,0,86,0,87,0,194,0,195,0,196,0,197,0,30,4,31,4,32,4,33,4,140,4,141,4,211,4,212,4,213,4,92,5,93,5,114,5,115,5,116,5,117,5,222,8,223,8,254,8,255,8,150,9,54,10,55,10,8,11,9,11,10,11,11,11,50,11,51,11,52,11,53,11,54,11,55,11,56,11,57,11,176,11,247,11,248,11,249,11,250,11,251,11,252,11,253,11,254,11,255,11,84,18,85,18,86,18,87,18,112,18,113,18,114,18,115,18,116,18,117,18,171,18,172,18,173,18,174,18,175,18,176,18,177,18,21,19,22,19,23,19,191,19,192,19,193,19,194,19,195,19,196,19,197,19,198,19,199,19,200,19,201,19,202,19,203,19,204,19,205,19,6,26,7,26,40,26,41,26,42,26,43,26,44,26,45,26,128,26,187,26,188,26,189,26,216,26,217,26,148,0,149,0,150,0,151,0,160,0,161,0,162,0,163,0,49,8,50,8,51,8,52,8,53,8,54,8,55,8,56,8,57,8,58,8,59,8,57,9,58,9,59,9,60,9,61,9,62,9,63,9,160,9,161,9,162,9,163,9,164,9,165,9,172,17,173,17,174,17,175,17,176,17,177,17,178,17,179,17,180,17,181,17,182,17,183,17,184,17,185,17,186,17,187,17,47,19,84,20,85,20,86,20,87,20,88,20,89,20,90,20,91,20,92,20,93,20,94,20,95,20,96,20,97,20,98,20,99,20,100,20,101,20,102,20,103,20,104,20,105,20,106,20,107,20,222,23,223,23,224,23,225,23,226,23,227,23,228,23,229,23,230,23,231,23,232,23,233,23,234,23,235,23,236,23,237,23,64,37,65,37,66,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,75,37,76,37,77,37,78,37,79,37,80,37,81,37,82,37,83,37,84,37,85,37,40,38,102,39,103,39,104,39,105,39,106,39,107,39,108,39,109,39,110,39,111,39,112,39,113,39,114,39,115,39,116,39,117,39,118,39,119,39,120,39,121,39,122,39,123,39,124,39,125,39,3,53,68,53,69,53,70,53,71,53,96,53,97,53,98,53,99,53,100,53,101,53,102,53,103,53,104,53,105,53,106,53,107,53,108,53,109,53,110,53,111,53,112,53,113,53,114,53,115,53,116,53,117,53,240,3,61,16,62,16,63,16,64,16,65,16,66,16,67,16,68,16,69,16,70,16,71,16,72,16,73,16,74,16,75,16,76,16,77,16,78,16,79,16,80,16,81,16,82,16,83,16,84,16,85,16,86,16,87,16,88,16,89,16,90,16,91,16,92,16,93,16,94,16,95,16,96,16,97,16,112,18,113,18,184,33,185,33,186,33,187,33,188,33,189,33,190,33,191,33,240,33,241,33,242,33,243,33,244,33,245,33,246,33,247,33,248,33,249,33,250,33,251,33,252,33,253,33,254,33,255,33,64,35,65,35,66,35,67,35,68,35,69,35,70,35,71,35,72,35,73,35,74,35,75,35,76,35,77,35,78,35,79,35,80,35,81,35,82,35,83,35,84,35,85,35,86,35,87,35,92,38,136,47,137,47,138,47,139,47,140,47,141,47,142,47,143,47,144,47,145,47,146,47,147,47,148,47,149,47,150,47,151,47,152,47,153,47,154,47,155,47,156,47,157,47,158,47,159,47,160,47,161,47,162,47,163,47,164,47,165,47,166,47,167,47,168,47,169,47,170,47,171,47,172,47,173,47,174,47,175,47,176,47,177,47,178,47,179,47,180,47,181,47,182,47,183,47,184,47,185,47,186,47,187,47,82,76,83,76,40,78,41,78,42,78,43,78,44,78,45,78,46,78,47,78,48,78,49,78,50,78,51,78,52,78,53,78,54,78,55,78,56,78,57,78,58,78,59,78,60,78,61,78,62,78,63,78,128,78,129,78,130,78,131,78,132,78,133,78,134,78,135,78,136,78,137,78,138,78,139,78,140,78,141,78,142,78,143,78,144,78,145,78,146,78,147,78,148,78,149,78,150,78,151,78,152,78,153,78,154,78,155,78,156,78,157,78,158,78,159,78,160,78,161,78,162,78,163,78,164,78,165,78,166,78,167,78,168,78,169,78,170,78,171,78,172,78,173,78,174,78,175,78,176,78,177,78,178,78,179,78,180,78,181,78,182,78,183,78,184,78,185,78,186,78,187,78,188,78,189,78,190,78,191,78,192,78,193,78,194,78,195,78,196,78,197,78,198,78,199,78,200,78,201,78,202,78,203,78,4,106,5,106,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,234,7,235,7,236,7,237,7,238,7,239,7,240,7,241,7,242,7,243,7,244,7,245,7,246,7,247,7,248,7,249,7,250,7,251,7,252,7,253,7,254,7,255,7,0,32,1,32,2,32,3,32,4,32,5,32,6,32,7,32,8,32,9,32,10,32,11,32,12,32,13,32,14,32,15,32,16,32,17,32,18,32,19,32,20,32,21,32,22,32,23,32,24,32,25,32,26,32,27,32,28,32,29,32,30,32,31,32,32,32,33,32,34,32,35,32,36,32,37,32,38,32,39,32,40,32,41,32,42,32,43,32,44,32,45,32,46,32,47,32,48,32,49,32,50,32,51,32,52,32,53,32,54,32,55,32,56,32,57,32,58,32,59,32,60,32,61,32,62,32,63,32,64,32,65,32,66,32,67,32,68,32,69,32,70,32,71,32,72,32,73,32,74,32,75,32,76,32,77,32,78,32,79,32,80,32,81,32,82,32,83,32,84,32,85,32,86,32,87,32,88,32,89,32,90,32,91,32,92,32,93,32,94,32,95,32,96,32,97,32,98,32,99,32,100,32,101,32,102,32,103,32,104,32,105,32,106,32,107,32,108,32,109,32,110,32,111,32,112,32,113,32,114,32,115,32,116,32,117,32,118,32,119,32,120,32,121,32,186,76,187,76,136,93,137,93,138,93,139,93,140,93,141,93,142,93,143,93,176,93,177,93,178,93,179,93,180,93,181,93,182,93,183,93,184,93,185,93,186,93,187,93,188,93,189,93,190,93,191,93,64,94,65,94,66,94,67,94,68,94,69,94,70,94,71,94,72,94,73,94,74,94,75,94,76,94,77,94,78,94,79,94,80,94,81,94,82,94,83,94,84,94,85,94,86,94,87,94,88,94,89,94,90,94,91,94,92,94,93,94,94,94,95,94,96,94,97,94,98,94,99,94,100,94,101,94,102,94,103,94,104,94,105,94,106,94,107,94,108,94,109,94,110,94,111,94,112,94,113,94,114,94,115,94,116,94,117,94,118,94,119,94,120,94,121,94,122,94,123,94,124,94,125,94,126,94,127,94,128,94,129,94,130,94,131,94,132,94,133,94,134,94,135,94,136,94,137,94,138,94,139,94,140,94,141,94,142,94,143,94,144,94,145,94,146,94,147,94,148,94,149,94,150,94,151,94,152,94,153,94,154,94,155,94,156,94,157,94,158,94,159,94,160,94,161,94,162,94,163,94,164,94,165,94,166,94,167,94,168,94,169,94,170,94,171,94,172,94,173,94,174,94,175,94,176,94,177,94,178,94,179,94,180,94,181,94,182,94,183,94,184,94,185,94,186,94,187,94,188,94,189,94,190,94,191,94,192,94,193,94,194,94,195,94,196,94,197,94,198,94,199,94,200,94,201,94,202,94,203,94,204,94,205,94,206,94,207,94,208,94,209,94,210,94,211,94,212,94,213,94,214,94,215,94,216,94,217,94,218,94,219,94,220,94,221,94,222,94,223,94,224,94,225,94,226,94,227,94,228,94,229,94,230,94,231,94,232,94,233,94,234,94,235,94,236,94,237,94,238,94,239,94,240,94,241,94,242,94,243,94,244,94,245,94,246,94,247,94,248,94,249,94,250,94,251,94,252,94,253,94,254,94,255,94,0,95,1,95,2,95,3,95,4,95,5,95,6,95,7,95,8,95,9,95,10,95,11,95,12,95,13,95,14,95,15,95,0,0,1,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,8,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,1,2,3,4,5,6,7,8,9,10,11,1,2,3,4,5,6,7,8,1,2,3,4,5,6,7,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,1,1,1,1,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,1,163,100,0,0,0,0,0,2,163,100,1,0,0,0,0,3,163,100,0,0,0,0,0,4,163,100,1,0,0,0,100,163,1,0,1,0,0,0,100,163,2,0,0,0,0,0,100,163,3,0,1,0,0,0,4,0,179,5,54,11,144,16,196,21,211,26,191,31,139,36,56,41,199,45,58,50,147,54,209,58,248,62,6,67,255,70,226,74,177,78,108,82,20,86,170,89,46,93,162,96,5,100,89,103,158,106,212,109,252,112,23,116,36,119,37,122,25,125,1,128,0,0,0,0,0,0,255,127,226,127,105,127,165,126,145,125,49,124,132,122,140,120,72,118,189,115,233,112,209,109,116,106,214,102,248,98,221,94,136,90,251,85,57,81,69,76,34,71,211,65,91,60,190,54,255,48,35,43,43,37,29,31,251,24,202,18,142,12,73,6,1,0,185,249,117,243,56,237,7,231,230,224,215,218,224,212,3,207,68,201,167,195,48,190,225,184,189,179,201,174,7,170,122,165,37,161,10,157,44,153,142,149,49,146,24,143,69,140,185,137,118,135,125,133,208,131,112,130,93,129,152,128,32,128,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,0,1,1,1,0,0,0,1,0,0,1,0,0,0,0,1,1,0,1,0,0,1,1,1,0,0,0,1,0,0,1,0,0,0,0,1,1,0,1,0,0,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,0,1,1,0,0,1,1,0,0,0,1,0,0,1,0,1,1,0,1,1,0,1,1,0,1,1,0,1,1,0,1,1,0,0,1,0,0,1,0,0,1,0,0,1,0,0,1,1,1,0,0,0,1,1,1,0,0,0,0,1,1,1,0,0,0,1,1,1,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,0,1,0,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,0,1,1,0,0,1,1,0,0,1,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,0,0,1,1,1,1,0,0,0,0,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,0,0,1,0,1,0,0,0,0,0,0,0,168,87,138,62,37,117,2,63,134,201,36,63,56,103,68,63,39,194,118,63,167,232,136,63,154,153,161,63,101,25,202,63,23,217,246,63,79,64,15,64,91,211,32,64,63,53,54,64,14,45,50,62,45,67,188,62,255,178,27,63,11,181,86,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+327680);
/* memory initializer */ allocate([13,224,141,63,249,160,175,63,0,111,209,63,75,200,239,63,147,24,4,64,95,7,22,64,241,244,38,64,11,181,54,64,82,73,29,62,130,226,167,62,42,169,3,63,36,151,47,63,204,238,121,63,138,31,163,63,119,190,199,63,18,165,237,63,222,113,6,64,123,20,22,64,72,225,38,64,215,163,56,64,225,122,84,62,240,22,232,62,180,89,69,63,91,211,132,63,100,204,165,63,138,176,193,63,61,44,228,63,20,63,2,64,117,147,16,64,114,249,31,64,238,124,43,64,185,252,55,64,169,164,14,62,236,47,123,62,110,52,192,62,200,152,11,63,188,150,80,63,204,127,144,63,224,45,184,63,119,45,225,63,91,66,2,64,117,147,20,64,68,250,37,64,148,246,54,64,0,0,0,62,208,179,185,62,143,228,66,63,252,169,145,63,82,73,181,63,100,59,199,63,117,147,216,63,98,16,232,63,18,20,239,63,153,187,2,64,156,162,27,64,125,174,54,64,176,3,103,62,181,55,216,62,212,43,37,63,104,34,92,63,73,157,136,63,16,233,167,63,134,56,198,63,181,21,235,63,140,219,4,64,204,93,19,64,78,209,33,64,90,100,51,64,250,237,107,62,28,124,225,62,220,104,48,63,120,122,101,63,248,83,147,63,29,201,181,63,127,251,210,63,242,210,237,63,243,142,7,64,36,151,23,64,50,230,38,64,81,107,58,64,29,90,100,62,19,97,195,62,223,79,13,63,236,47,27,63,108,120,74,63,122,165,140,63,139,108,183,63,198,109,228,63,46,144,4,64,243,31,22,64,11,181,38,64,48,187,55,64,163,146,122,62,225,122,20,63,165,44,83,63,104,145,125,63,95,7,150,63,111,18,179,63,230,174,213,63,234,4,244,63,100,93,8,64,100,59,27,64,178,157,43,64,75,89,58,64,58,35,74,62,165,44,195,62,253,135,20,63,98,161,70,63,104,145,109,63,54,205,147,63,66,96,181,63,240,133,209,63,193,202,241,63,138,142,16,64,163,1,36,64,199,186,52,64,107,154,247,61,18,131,128,62,245,219,247,62,95,7,78,63,84,82,143,63,61,155,173,63,2,188,205,63,184,64,242,63,215,163,8,64,74,123,23,64,45,67,40,64,6,129,57,64,69,216,112,62,0,145,222,62,204,127,40,63,87,91,81,63,198,109,116,63,212,43,149,63,242,65,191,63,41,203,240,63,50,230,10,64,131,47,24,64,108,9,41,64,63,198,56,64,79,30,86,62,206,25,209,62,186,73,44,63,254,67,106,63,126,29,144,63,236,192,169,63,93,254,203,63,27,13,232,63,77,132,1,64,147,58,21,64,173,250,36,64,2,43,55,64,105,0,239,61,217,95,118,62,139,108,231,62,44,212,58,63,218,27,124,63,155,85,159,63,236,192,193,63,134,201,228,63,193,202,1,64,248,83,19,64,127,217,37,64,23,72,56,64,236,192,153,62,91,66,254,62,121,233,38,63,94,186,89,63,225,122,148,63,241,244,178,63,211,77,202,63,44,212,234,63,69,216,4,64,81,218,19,64,47,221,36,64,195,100,54,64,127,251,122,62,70,37,213,62,117,147,24,63,217,206,71,63,19,97,115,63,215,52,159,63,123,131,199,63,57,214,237,63,57,180,4,64,154,119,20,64,111,129,36,64,166,155,52,64,155,85,159,62,54,60,13,63,234,4,52,63,26,81,90,63,40,15,147,63,86,125,182,63,135,167,215,63,153,42,248,63,194,23,10,64,199,75,27,64,60,189,42,64,41,237,57,64,48,76,102,62,194,134,199,62,118,79,14,63,14,79,63,63,188,5,130,63,57,214,173,63,204,127,216,63,160,26,255,63,146,203,11,64,27,158,22,64,220,70,35,64,178,157,51,64,184,30,133,62,85,48,234,62,104,34,60,63,240,22,120,63,116,181,149,63,32,65,177,63,135,22,209,63,3,120,243,63,123,131,7,64,69,71,22,64,214,197,37,64,45,178,53,64,139,253,101,62,122,165,172,62,213,120,233,62,217,95,6,63,52,162,52,63,145,126,131,63,156,196,176,63,35,74,219,63,230,174,253,63,62,121,16,64,190,159,34,64,168,87,54,64,60,78,17,62,52,128,247,62,14,45,98,63,49,153,146,63,214,86,164,63,52,17,182,63,36,151,199,63,91,211,228,63,88,57,8,64,74,12,26,64,218,172,38,64,108,120,54,64,92,32,65,62,45,67,188,62,146,203,15,63,155,85,79,63,121,88,144,63,48,42,177,63,140,74,202,63,11,36,232,63,253,246,1,64,182,243,17,64,185,141,34,64,196,66,53,64,14,190,112,62,253,135,212,62,72,225,42,63,132,13,95,63,111,240,133,63,58,35,170,63,1,77,212,63,251,203,246,63,8,172,8,64,53,94,22,64,32,210,39,64,110,52,56,64,113,61,138,62,57,214,229,62,164,223,30,63,48,76,54,63,52,17,70,63,218,27,124,63,137,210,174,63,116,36,223,63,189,227,0,64,238,90,14,64,39,194,30,64,236,81,52,64,127,217,125,62,92,143,226,62,221,36,38,63,59,223,95,63,93,220,142,63,103,68,177,63,196,177,214,63,222,113,250,63,219,138,9,64,144,49,23,64,78,98,36,64,250,237,51,64,78,98,80,62,191,125,189,62,228,131,14,63,200,152,75,63,179,12,129,63,106,77,163,63,63,198,196,63,33,31,228,63,184,30,1,64,122,165,16,64,37,117,30,64,2,188,49,64,237,13,62,62,5,52,177,62,126,140,25,63,25,115,103,63,157,128,158,63,154,8,187,63,109,86,213,63,160,26,247,63,75,89,10,64,233,72,26,64,235,115,41,64,254,101,55,64,190,193,87,62,63,53,190,62,254,101,7,63,254,67,42,63,80,141,87,63,77,243,142,63,50,85,184,63,68,139,220,63,153,187,254,63,97,50,17,64,143,228,34,64,90,100,55,64,71,114,249,61,126,140,153,62,65,130,34,63,60,189,114,63,209,34,163,63,122,54,203,63,232,217,244,63,247,6,15,64,94,186,25,64,52,128,31,64,122,165,40,64,28,124,53,64,175,148,37,62,97,84,178,62,20,63,22,63,9,249,80,63,79,175,132,63,210,0,158,63,197,254,186,63,161,248,217,63,245,74,249,63,241,244,14,64,181,166,33,64,95,7,54,64,137,65,128,62,163,146,250,62,137,65,64,63,140,74,106,63,229,208,138,63,66,207,174,63,243,142,211,63,44,212,234,63,37,6,1,64,139,253,17,64,199,41,34,64,6,18,52,64,19,242,193,61,141,40,237,61,177,191,108,61,3,9,10,189,208,68,216,187,195,100,42,60,89,23,55,189,23,217,78,189,155,85,159,189,142,6,240,188,132,158,205,60,140,74,106,188,77,243,14,61,90,245,185,188,199,41,186,189,134,56,86,61,184,30,5,61,158,239,39,189,25,4,214,189,126,29,184,189,250,237,107,186,143,194,245,59,31,133,107,189,160,26,175,189,134,90,83,188,31,133,107,61,253,135,116,61,82,39,32,61,43,246,23,61,153,187,150,188,185,252,7,188,67,28,235,60,140,74,106,60,112,206,136,60,166,155,68,60,39,160,137,188,163,35,57,61,125,174,182,60,224,45,16,189,56,248,66,60,95,41,75,189,203,161,197,189,112,95,135,189,250,237,235,187,64,19,225,61,122,165,172,61,114,138,14,188,239,201,67,189,23,183,81,188,166,155,68,188,23,183,209,185,116,181,149,61,244,108,214,61,37,6,129,61,46,144,160,60,85,193,40,188,47,110,35,189,204,238,201,189,17,199,186,189,119,190,31,189,168,87,202,188,150,33,142,189,44,101,153,189,208,68,216,187,125,174,182,60,220,215,129,61,40,126,12,61,172,139,91,188,189,227,148,61,93,109,197,60,208,68,216,59,197,254,50,61,35,219,121,61,43,24,21,61,95,41,203,60,5,163,18,189,40,126,140,189,195,100,42,188,86,125,46,61,224,45,16,60,247,117,96,188,2,43,135,188,186,107,137,61,121,233,166,61,14,190,176,189,38,228,131,189,224,45,16,188,153,187,22,59,93,109,69,61,105,111,240,61,74,12,2,62,106,77,115,61,2,43,135,60,238,90,194,61,211,222,224,61,247,117,96,60,191,125,253,62,229,242,255,62,127,217,253,62,8,61,251,62,73,46,255,62,63,53,254,62,127,217,253,62,146,203,255,62,155,85,255,62,127,217,253,62,128,72,255,62,137,210,254,62,142,117,145,62,174,216,95,62,7,240,22,62,177,191,44,62,83,5,99,62,39,194,134,62,21,140,138,62,75,89,134,62,136,99,93,62,236,47,123,62,109,231,123,62,83,150,129,62,21,246,53,243,117,245,239,242,229,244,125,21,170,1,215,27,107,255,39,12,81,244,7,247,215,246,142,10,55,252,78,252,21,11,90,4,8,7,247,4,217,47,22,247,251,246,30,6,183,244,52,244,221,247,2,14,215,34,91,10,15,16,206,248,204,249,108,250,179,12,154,255,156,0,192,254,210,2,175,6,85,80,4,244,93,247,164,243,174,242,188,242,190,244,46,248,194,6,237,15,120,245,98,249,233,244,132,11,77,245,180,246,52,247,225,250,243,254,108,7,20,245,68,254,76,244,35,246,74,20,179,5,178,19,191,251,146,3,20,16,220,29,191,243,172,243,188,15,149,242,88,243,231,245,166,21,255,19,157,38,77,244,175,243,135,242,227,243,33,242,115,242,108,247,9,251,29,15,37,21,16,245,58,248,43,13,18,247,2,252,118,12,218,253,187,6,200,3,124,7,67,245,6,250,93,247,85,244,227,242,66,243,238,251,37,40,107,0,102,10,91,38,63,245,173,16,51,243,53,12,197,243,98,244,77,243,66,25,12,37,14,248,109,245,136,246,158,243,197,245,26,247,113,255,151,249,80,46,87,23,254,250,187,245,164,246,196,246,36,248,195,251,240,245,138,246,98,247,163,53,43,247,191,10,24,249,178,9,215,251,165,254,119,255,31,0,107,2,129,1,47,247,89,247,94,249,130,245,116,17,253,245,209,251,177,250,77,30,148,14,216,244,58,35,2,248,42,250,70,247,95,247,189,255,60,5,129,9,149,11,94,245,153,247,106,244,36,245,84,245,27,250,219,247,4,250,22,27,32,251,112,248,101,247,237,252,11,249,129,252,58,248,85,18,230,248,223,249,162,7,21,247,157,246,18,41,223,243,206,251,234,244,255,255,168,4,89,4,237,12,55,247,109,246,132,249,231,9,97,250,254,13,187,251,174,253,164,7,246,2,229,20,36,246,240,246,145,248,249,247,211,19,83,252,47,253,232,253,149,8,251,246,45,244,76,250,161,244,80,44,86,246,191,249,43,249,188,12,243,9,235,14,33,251,87,250,19,11,162,251,116,253,252,253,133,254,19,2,184,1,199,253,210,245,15,246,113,246,107,249,230,33,180,248,45,248,32,252,0,23,143,33,200,248,38,248,108,247,255,247,110,253,145,13,214,0,137,3,61,1,254,247,197,251,223,245,50,34,70,247,111,246,104,249,146,8,196,8,198,9,133,249,68,245,232,17,61,244,118,14,253,246,161,248,88,248,212,251,73,11,50,244,83,244,9,247,22,245,255,11,204,249,213,255,67,10,254,4,239,7,159,247,9,246,227,246,123,243,91,243,56,245,122,35,58,254,243,16,240,6,78,245,177,18,128,247,152,248,100,8,70,5,0,3,249,0,233,3,219,5,29,3,122,247,93,250,27,255,224,255,59,3,145,1,14,1,69,2,124,1,190,246,184,246,137,245,229,243,50,249,131,251,58,18,75,253,85,4,123,29,64,246,9,244,254,244,195,245,32,248,90,22,68,19,193,4,113,8,145,9,97,247,118,244,185,14,248,244,239,248,126,244,99,249,135,254,29,6,4,16,125,244,247,11,10,244,153,244,235,243,40,246,80,249,79,9,25,5,75,7,161,39,160,244,21,243,95,29,82,242,217,251,34,245,147,33,18,253,33,250,187,243,74,246,107,11,242,245,222,248,36,251,209,13,190,9,23,10,24,6,94,245,212,12,197,8,22,251,110,253,118,254,227,1,207,2,97,4,49,4,123,244,11,252,24,244,85,2,225,243,50,246,78,248,39,28,187,33,125,7,20,249,29,254,242,246,188,248,60,246,165,11,141,249,38,2,184,2,103,2,183,247,249,247,173,249,178,247,36,12,89,13,27,254,209,255,80,3,72,6,180,245,85,249,70,12,214,14,223,1,168,251,85,2,189,254,19,6,251,5,142,244,58,8,162,246,246,246,213,248,0,0,104,11,128,3,52,9,235,4,161,244,144,243,81,2,14,242,195,242,65,243,172,28,216,29,218,26,149,25,136,248,202,250,43,249,200,253,74,249,107,254,161,250,128,13,0,252,145,248,168,36,95,245,75,246,183,246,46,244,125,252,195,243,40,244,108,246,35,30,188,9,110,246,71,249,166,247,39,250,201,255,248,2,78,9,159,4,81,4,34,245,133,1,8,250,97,252,152,2,237,253,125,5,107,1,70,2,220,254,114,249,98,245,53,245,188,243,17,245,126,247,101,245,224,245,52,252,54,251,206,12,107,251,100,11,244,249,66,254,39,251,47,255,123,1,177,2,26,2,38,12,41,11,57,249,36,251,179,253,99,254,65,0,215,1,10,2,67,1,5,248,44,255,29,5,41,254,204,253,240,255,122,1,192,254,75,254,228,0,110,247,179,245,47,246,146,245,185,248,70,252,222,247,162,246,34,247,187,21,113,244,116,246,22,245,56,249,161,249,212,250,202,5,31,254,13,9,190,5,201,244,41,248,190,2,68,248,21,254,110,255,73,253,111,255,1,11,244,4,189,242,128,242,3,244,151,242,198,244,51,255,38,3,222,11,222,14,63,10,118,244,187,248,56,253,249,3,186,254,44,0,163,255,142,3,7,3,90,1,191,245,246,245,98,244,216,246,104,245,118,248,91,247,193,13,195,250,231,16,115,255,67,3,161,251,200,250,188,251,157,248,164,252,41,253,59,1,2,10,23,16,178,245,232,245,97,248,106,245,61,246,231,249,72,252,5,11,201,9,172,246,193,248,146,244,206,6,253,245,161,245,246,248,10,12,247,11,152,9,24,243,146,245,157,247,32,250,203,254,141,5,125,6,10,6,48,2,103,2,226,245,199,249,13,250,233,7,95,12,183,252,156,254,120,253,53,1,141,4,110,244,164,247,138,247,82,250,154,249,180,251,189,252,174,2,210,3,38,2,162,249,3,252,112,250,181,248,162,251,38,254,66,0,216,23,136,3,91,2,195,252,37,254,168,250,81,251,87,28,134,252,47,254,114,0,118,0,224,0,107,246,1,251,0,32,247,250,60,254,209,255,180,0,68,1,115,2,209,0,46,245,206,43,167,252,72,249,129,252,237,253,221,254,248,254,232,0,110,254,117,245,255,245,127,246,211,247,221,250,86,0,106,10,127,6,71,5,45,9,28,245,224,17,96,14,171,250,29,252,255,253,46,0,44,0,10,2,142,0,77,245,138,249,98,248,221,17,109,253,232,253,29,1,72,0,107,3,115,2,70,12,105,0,83,252,221,4,23,254,17,254,27,255,44,0,20,255,197,251,224,246,87,251,172,249,189,248,197,250,113,253,205,0,8,4,205,21,171,4,181,245,52,249,96,10,184,7,204,255,16,3,160,255,91,255,163,1,26,254,146,34,144,253,232,252,5,250,3,253,94,253,38,253,195,252,106,255,229,255,207,8,103,251,167,10,106,250,225,2,122,252,244,252,39,253,169,0,22,1,145,14,179,14,224,255,211,249,205,253,195,253,77,0,140,254,192,255,35,254,60,246,14,2,110,249,184,5,194,252,132,255,220,253,49,2,202,0,91,4,110,249,240,249,34,248,177,247,162,250,19,253,48,253,64,0,49,8,32,27,45,245,65,19,112,249,92,247,106,250,223,252,114,0,123,3,152,4,87,3,243,13,117,247,226,249,98,249,84,0,210,255,164,3,18,3,253,2,88,3,242,251,14,254,139,255,210,249,157,250,118,251,149,24,145,254,82,2,132,0,73,246,71,8,151,247,43,249,65,3,65,4,251,1,133,0,81,1,167,1,39,245,203,9,21,1,81,250,5,252,19,7,127,2,173,253,136,0,230,251,131,244,122,17,80,255,71,4,89,4,33,254,182,0,217,254,27,255,163,253,13,248,143,249,109,251,51,0,0,0,125,0,28,11,202,254,174,255,128,253,53,247,166,247,34,247,225,249,212,8,92,0,112,1,95,0,153,5,66,5,52,3,221,246,226,248,129,252,187,255,158,0,190,0,143,3,240,3,252,2,172,2,36,249,11,252,167,249,182,249,174,23,13,254,244,251,117,255,105,4,232,1,12,2,103,253,154,252,165,254,180,255,123,0,91,0,244,255,14,0,205,244,29,248,42,11,145,248,115,251,53,1,31,1,226,4,255,2,8,3,32,245,114,246,123,251,204,1,29,10,181,1,227,254,199,2,213,254,146,1,133,245,33,247,78,249,1,250,221,253,22,16,254,1,134,4,188,2,119,2,220,247,44,251,253,1,15,252,2,254,63,255,205,251,231,252,215,2,102,8,94,245,200,3,53,4,213,249,126,250,130,252,145,1,19,4,171,1,182,0,192,246,220,246,57,249,151,248,43,250,216,3,246,11,10,11,25,4,164,0,157,4,58,248,215,248,72,249,176,250,24,0,205,5,131,7,204,1,255,1,69,0,78,0,159,254,253,255,177,14,32,254,254,249,217,251,28,2,192,255,246,249,36,252,234,5,113,251,182,250,205,253,155,5,112,3,99,4,182,0,61,247,195,247,182,246,103,247,45,250,188,252,132,255,93,2,15,24,52,14,46,245,113,244,116,244,53,244,150,247,120,253,13,7,90,18,113,11,30,8,49,252,152,254,129,252,145,253,175,253,145,252,167,254,237,16,236,1,200,255,202,247,243,252,36,254,244,4,94,2,98,253,150,6,151,255,114,1,205,1,35,255,156,252,155,250,41,1,128,0,190,253,215,252,86,252,56,15,234,1,192,15,115,10,84,253,172,251,45,251,109,252,150,252,105,252,222,252,240,251,212,250,240,255,108,8,151,7,116,253,102,253,209,255,37,250,168,0,46,255,117,16,153,248,58,249,25,249,124,250,157,252,185,255,73,1,87,3,14,5,199,248,41,17,224,250,195,249,204,253,178,1,58,254,13,1,124,3,225,255,110,251,67,0,114,1,136,251,192,254,122,14,213,252,66,255,133,255,90,255,109,253,247,251,235,252,122,252,165,254,232,254,148,255,199,254,196,1,117,14,31,250,206,245,58,245,10,246,14,248,175,250,92,253,201,2,215,8,94,32,63,247,52,246,20,246,71,249,182,0,155,7,50,1,237,6,196,4,93,11,196,255,73,0,21,255,161,249,234,250,76,253,75,16,194,252,49,0,68,255,41,254,96,247,39,247,18,250,60,255,179,11,11,10,189,253,188,255,37,3,242,250,250,4,198,16,180,250,66,253,236,253,47,254,133,255,112,254,49,253,80,1,21,12,98,6,118,252,185,255,10,254,86,252,42,252,26,253,93,251,35,249,74,11,201,249,23,5,216,0,201,254,108,254,227,255,245,1,225,253,70,250,51,6,53,1,190,253,83,255,34,0,92,4,6,5,96,251,106,251,81,255,36,253,149,253,180,13,176,255,191,0,221,251,82,255,83,254,42,254,16,39,91,252,25,250,191,249,221,249,91,250,215,251,129,250,227,251,92,252,159,4,195,30,52,254,183,249,174,249,138,250,126,251,53,251,12,252,86,250,20,0,28,0,21,255,146,255,203,0,105,0,252,0,102,255,205,255,198,255,124,11,22,254,17,0,205,255,131,0,150,255,242,253,202,253,202,252,103,251,201,250,189,10,96,2,217,249,214,250,185,250,111,0,129,2,161,5,247,255,221,2,49,255,239,254,103,253,138,253,180,253,178,255,254,0,48,1,250,2,155,245,139,245,42,251,174,255,9,10,185,11,164,3,248,251,211,0,188,254,40,0,115,5,188,252,161,251,133,253,111,250,22,250,145,251,229,5,147,11,159,20,77,4,174,50,248,21,237,7,13,15,30,23,236,5,167,244,32,255,164,255,205,252,35,3,67,4,19,12,229,242,152,0,66,251,107,227,30,253,243,220,34,2,3,47,87,252,168,8,65,8,190,4,79,230,214,7,131,249,95,253,8,233,240,1,198,1,72,13,164,2,190,254,124,44,122,2,111,251,12,49,84,233,212,225,76,2,111,229,56,4,98,1,111,249,82,252,134,7,25,254,188,253,156,0,79,0,149,59,155,2,131,4,143,2,49,253,207,7,239,252,214,0,6,11,252,3,81,248,73,0,125,254,119,255,135,196,240,249,155,254,14,11,92,8,254,11,8,246,106,9,206,4,35,16,231,3,248,0,19,2,115,252,108,15,58,50,136,224,157,8,235,244,85,255,159,249,127,255,163,255,60,7,128,248,157,0,175,37,172,255,106,255,171,250,14,250,115,204,24,24,133,243,2,23,68,249,249,230,196,250,245,226,147,253,156,233,177,244,145,0,134,15,216,2,112,38,18,254,189,28,118,254,210,202,0,255,118,248,212,1,246,254,65,31,103,255,147,254,228,29,135,0,120,5,227,240,67,4,185,236,188,244,235,4,163,26,1,4,245,229,55,4,190,217,171,26,186,239,84,4,125,4,173,73,81,2,79,255,213,251,124,253,140,247,119,18,85,0,155,255,203,213,9,255,214,34,213,8,99,21,244,2,202,11,121,230,149,7,103,1,123,239,182,4,190,3,146,252,42,2,164,182,241,8,42,19,12,227,251,225,252,30,197,3,156,9,71,17,205,253,172,241,102,242,235,12,55,249,203,3,200,226,246,41,186,7,61,9,20,0,215,241,210,1,8,8,54,230,180,36,73,12,90,12,65,7,138,253,7,229,124,6,48,244,145,247,85,4,2,5,207,10,210,0,101,247,27,12,47,225,13,7,197,204,220,3,165,231,30,6,137,250,116,218,29,7,249,253,199,255,100,13,56,201,117,4,18,246,76,219,239,255,184,1,113,222,223,8,125,225,99,7,89,252,22,239,233,250,106,1,170,1,63,1,152,4,104,12,154,8,28,200,149,253,130,244,33,247,237,253,116,253,89,1,17,69,173,5,231,249,85,1,227,247,165,3,177,1,249,5,207,1,185,251,48,19,184,252,138,63,205,3,196,6,50,253,46,26,181,241,197,15,64,253,109,245,143,5,11,5,252,8,149,0,91,252,198,250,227,7,29,24,225,1,89,58,148,254,56,15,69,254,224,3,128,252,122,1,30,255,31,250,12,1,84,254,194,245,223,254,235,247,232,40,216,240,46,235,129,1,237,11,222,237,245,5,235,249,204,2,200,9,80,3,62,254,30,248,54,254,63,253,48,228,225,253,166,247,244,9,161,254,225,2,106,50,12,252,63,0,253,59,76,1,187,252,31,255,237,250,27,11,54,5,99,253,35,8,61,253,147,4,27,32,142,8,71,41,90,5,160,250,153,244,60,8,114,39,124,254,90,17,164,0,234,1,156,29,26,0,200,248,153,244,128,2,150,18,148,255,2,32,211,250,246,246,191,1,58,20,185,251,174,38,75,253,216,241,33,255,178,2,255,40,8,3,105,252,171,249,254,7,213,1,174,5,97,14,190,251,16,249,177,5,212,0,6,8,30,252,186,2,16,254,75,87,145,253,254,0,192,3,23,240,19,2,244,245,199,199,2,252,2,1,173,241,226,3,138,59,214,19,222,241,133,7,51,251,38,249,179,6,6,17,6,5,200,246,18,238,32,7,184,30,143,5,158,247,53,245,117,214,218,1,195,252,135,4,99,255,202,255,98,255,227,255,202,0,129,254,29,1,254,255,94,3,148,254,159,1,133,255,111,255,251,217,143,4,215,39,128,250,80,244,83,8,100,254,135,18,176,11,227,13,151,253,134,37,241,244,53,9,180,20,113,2,90,253,12,254,128,255,200,255,73,231,158,251,249,245,112,7,244,248,197,2,122,12,108,255,165,250,122,230,44,249,46,250,79,55,186,5,115,5,77,4,91,245,247,1,68,0,50,250,0,0,211,0,62,251,253,255,184,81,173,6,48,255,185,252,222,17,60,232,99,230,153,255,40,252,137,254,217,32,179,6,134,247,117,236,32,243,170,52,187,4,193,239,168,13,16,4,13,27,213,0,138,250,185,1,49,251,210,252,74,3,38,6,121,4,79,5,181,1,15,249,86,80,3,1,35,238,124,250,98,255,160,39,245,4,125,5,169,206,176,251,153,253,236,193,99,1,45,241,122,251,169,12,252,0,232,0,77,255,151,253,10,248,29,1,10,252,32,251,43,7,234,249,242,4,33,216,117,2,200,254,112,44,154,0,224,254,27,23,159,254,60,0,135,10,171,252,153,255,43,61,99,9,96,251,3,0,20,36,55,213,82,17,61,3,3,10,92,255,176,252,122,253,79,28,127,3,190,6,16,253,45,252,29,4,53,252,62,1,132,8,159,3,36,3,250,254,190,1,189,12,194,236,85,238,223,4,247,7,226,49,89,251,226,250,58,234,155,18,145,2,213,239,69,42,219,252,171,251,139,243,71,249,167,0,218,216,171,248,75,8,72,1,120,228,174,247,127,9,242,5,137,12,0,223,18,7,220,234,87,38,163,241,175,25,163,231,95,252,78,254,185,246,238,202,169,13,140,251,203,4,46,231,5,254,73,1,102,249,55,4,144,252,97,241,75,240,219,237,91,232,190,3,242,17,158,251,148,210,1,6,166,242,38,251,133,0,137,219,75,6,80,254,237,41,139,252,44,254,102,203,178,2,214,0,8,35,113,13,75,21,37,255,116,21,135,254,153,1,228,14,146,9,252,1,142,25,240,14,135,241,254,253,186,223,1,6,33,31,178,3,203,244,58,34,161,1,230,19,56,8,38,26,170,254,235,4,85,237,91,250,17,250,77,1,33,17,140,2,126,254,188,253,156,248,151,252,70,7,144,10,13,54,217,234,73,248,249,22,238,27,80,32,244,230,192,2,62,7,1,1,94,241,195,217,94,218,100,252,113,5,91,243,3,1,200,255,38,17,38,19,148,4,250,19,200,245,199,238,100,251,83,18,232,28,143,253,169,34,190,26,56,251,43,255,80,235,80,242,109,255,164,69,189,250,179,12,166,6,160,5,196,246,21,254,29,255,229,6,66,254,238,217,29,248,23,44,61,255,169,218,200,254,120,3,157,22,39,249,195,212,233,9,247,254,30,249,245,252,203,222,204,254,167,255,181,7,56,14,192,67,46,5,79,253,114,254,20,241,119,8,229,0,132,253,94,8,69,230,17,253,187,51,209,1,198,232,54,255,56,252,220,251,16,255,126,214,77,13,22,5,17,251,204,3,87,44,100,0,218,8,94,252,196,247,230,20,142,243,122,43,25,8,16,234,138,2,208,7,24,4,252,21,237,253,162,2,5,33,6,4,128,4,63,47,96,1,153,1,251,251,44,251,66,255,164,233,179,253,222,13,166,7,255,200,173,254,136,6,133,249,166,17,181,255,130,253,125,21,21,1,190,253,119,247,157,0,18,8,186,33,157,246,81,6,57,207,167,248,81,32,179,0,152,247,242,250,0,254,97,254,200,1,115,255,131,255,107,254,132,0,49,0,70,248,115,181,61,254,56,250,68,1,235,234,235,0,63,251,90,1,22,251,212,13,91,39,51,40,196,19,247,247,12,24,32,252,128,36,122,241,200,16,127,3,240,222,85,1,146,5,136,2,214,5,79,11,80,241,155,39,171,60,40,252,242,249,217,250,250,249,137,255,251,253,71,255,216,242,193,219,129,242,95,239,68,4,120,216,208,19,27,12,218,3,254,245,220,208,140,7,89,25,182,3,143,246,82,5,201,253,79,2,53,253,253,253,178,13,42,253,175,24,214,0,148,254,27,14,103,7,43,248,239,254,233,5,75,9,219,1,9,237,241,253,27,211,27,0,247,16,166,246,129,253,24,253,215,245,165,42,118,7,145,9,214,4,129,247,202,20,42,240,216,255,178,16,172,2,216,31,198,3,130,42,243,255,157,16,225,254,136,243,36,2,228,7,189,0,18,229,29,3,112,8,67,2,244,15,231,6,85,240,128,253,17,30,23,3,177,3,206,4,91,25,228,5,78,241,79,254,76,44,127,255,149,251,255,235,76,12,8,6,32,226,74,7,188,37,61,9,194,247,14,3,174,255,82,14,67,253,47,1,42,1,114,248,131,255,109,250,75,187,92,251,175,0,122,228,24,254,97,4,62,230,233,1,241,249,13,56,219,5,224,253,236,66,198,0,212,9,175,9,46,252,42,255,185,242,57,251,46,8,130,0,4,252,25,4,58,253,1,50,14,254,41,1,171,250,69,255,159,243,133,255,59,35,190,3,221,0,154,55,178,253,193,3,20,12,8,0,255,0,22,238,253,6,218,9,223,206,165,255,202,252,219,252,54,253,178,20,19,5,234,12,248,250,120,51,235,0,218,6,189,255,120,7,164,253,168,12,0,248,56,255,4,3,83,255,28,252,88,5,76,9,38,1,251,2,209,76,60,255,16,2,182,0,166,246,155,3,237,2,246,202,87,3,77,2,175,218,0,0,105,22,159,40,187,35,137,249,105,241,222,4,131,246,133,251,105,247,119,244,102,2,132,250,63,254,180,222,33,247,137,19,211,218,124,11,52,255,41,14,254,254,32,0,241,5,213,254,6,249,236,244,243,5,123,9,189,252,67,12,59,255,23,13,233,254,82,198,13,251,49,20,241,251,41,213,58,0,129,2,1,253,87,251,177,253,52,253,190,252,173,31,109,252,57,253,69,215,112,249,130,253,83,10,174,252,254,254,212,40,106,1,238,234,163,254,121,198,113,253,16,4,186,6,231,215,39,2,229,254,160,38,152,1,112,254,92,23,86,7,13,3,101,252,101,253,235,252,164,254,112,2,252,254,179,56,220,252,185,6,254,255,236,20,10,7,194,4,242,1,79,7,36,252,167,63,67,16,218,246,62,239,49,12,197,12,112,0,92,242,100,4,40,250,71,7,110,250,190,251,62,6,59,255,136,4,132,249,186,251,221,1,248,239,116,254,69,6,22,102,234,2,180,205,16,9,102,249,178,33,39,0,61,5,26,251,158,248,251,9,84,201,62,251,243,14,192,4,115,252,76,255,184,6,169,255,113,255,221,3,84,1,110,250,67,240,69,12,48,219,210,1,221,223,166,1,45,227,246,7,145,1,98,0,18,14,57,251,78,252,165,9,135,4,215,2,244,254,211,1,203,0,185,212,10,15,115,242,83,248,191,248,121,250,83,246,101,12,184,28,11,37,91,234,68,24,94,7,228,240,168,10,65,2,63,236,65,1,204,3,179,255,47,0,227,0,218,255,243,251,34,255,165,254,171,254,155,4,76,252,80,2,195,226,170,8,189,232,138,10,22,46,197,0,116,24,175,6,230,3,8,0,177,231,96,251,121,4,11,249,96,5,114,5,132,1,79,253,231,8,111,25,238,9,217,236,77,15,234,252,23,2,145,248,160,238,120,16,234,255,197,229,84,20,199,18,121,12,216,251,27,21,151,17,126,246,56,239,103,5,22,250,249,239,235,2,88,15,171,11,41,37,188,9,13,222,31,252,149,245,216,255,86,255,212,243,99,2,63,9,169,63,24,251,132,250,122,242,210,1,244,253,88,21,235,1,194,2,189,226,235,7,117,1,10,240,84,6,147,225,192,2,138,19,170,6,133,32,173,252,101,217,0,244,123,17,136,10,155,222,96,0,208,206,101,207,169,1,182,0,56,254,171,254,181,252,103,2,177,2,214,3,190,5,250,253,231,0,230,253,26,1,153,1,168,253,209,254,227,255,51,0,252,255,141,255,79,0,229,255,194,1,87,252,51,254,214,253,97,255,170,1,198,2,78,142,156,247,99,0,98,13,46,7,139,48,73,2,224,247,36,246,38,254,36,6,206,2,66,2,168,254,188,0,72,1,93,47,112,0,142,2,48,251,148,249,32,1,41,2,233,5,198,3,244,3,49,0,119,2,145,255,18,255,140,255,74,255,235,255,210,255,78,1,5,43,58,254,251,254,12,0,21,0,52,0,40,176,217,254,10,254,252,253,183,254,26,255,209,1,59,0,14,1,203,3,129,255,249,1,62,255,43,0,226,255,44,1,38,0,153,2,155,253,33,0,84,255,103,255,67,1,90,255,54,0,143,1,109,0,186,0,27,249,34,255,138,0,16,0,204,0,159,117,208,0,204,253,156,253,156,0,110,255,167,254,65,1,118,255,202,0,72,255,93,0,198,2,183,193,167,203,234,0,167,251,146,0,247,255,56,0,140,253,190,252,12,251,104,3,61,0,96,251,130,255,51,255,145,0,147,255,200,223,113,0,110,255,8,5,182,35,89,3,242,252,82,253,0,255,118,253,37,4,54,255,12,0,59,253,168,255,17,1,241,1,150,0,197,255,153,221,240,0,20,2,16,0,202,5,4,43,68,254,126,7,6,249,142,7,172,0,86,2,212,250,6,22,162,243,236,1,223,253,254,252,43,4,0,0,156,254,91,254,148,6,17,1,10,254,60,1,92,4,39,3,239,253,193,252,189,203,92,254,236,0,214,1,226,245,63,255,209,255,68,2,179,249,30,3,27,0,240,255,32,206,131,252,0,1,0,0,123,6,183,5,32,2,196,0,20,137,58,1,91,254,252,1,236,254,83,255,158,1,132,254,141,254,216,255,135,255,119,1,176,1,74,254,1,0,162,254,232,254,174,4,139,254,196,1,100,0,188,255,93,35,165,0,2,3,73,0,35,1,205,2,3,2,84,2,189,254,252,255,254,255,35,3,226,2,45,10,30,0,73,0,199,1,16,44,254,5,229,254,222,5,90,220,104,237,198,253,227,1,77,255,76,222,153,249,66,1,200,255,5,24,254,242,114,0,246,17,72,248,222,255,200,255,72,3,241,2,4,48,68,228,20,254,64,1,100,254,140,3,162,4,188,1,146,25,236,252,18,21,185,2,49,51,194,0,118,254,38,1,79,10,12,0,15,252,110,250,220,255,58,8,4,255,21,131,190,255,85,1,228,3,42,1,105,0,6,0,10,0,106,0,14,254,12,255,151,255,194,253,16,0,50,255,24,0,237,247,131,254,25,40,153,255,6,253,239,252,12,248,105,209,16,0,58,253,221,255,242,254,157,255,4,0,4,3,240,254,70,255,184,254,168,197,199,255,179,250,81,255,162,253,220,0,150,3,245,255,142,1,67,255,234,254,138,0,173,1,253,1,67,253,213,255,214,255,138,253,208,253,216,45,240,253,46,40,135,253,154,252,167,1,38,2,136,252,41,1,86,255,2,1,186,8,230,1,36,1,66,254,174,209,24,39,52,0,179,4,92,255,42,3,9,250,164,253,141,252,180,253,160,255,76,1,148,0,76,255,223,0,100,1,29,1,178,1,199,255,84,255,248,253,80,254,184,255,38,1,163,255,122,255,60,1,183,119,161,254,22,1,84,0,73,254,77,2,105,0,233,3,41,1,148,2,196,0,171,0,178,0,166,255,201,255,148,4,108,82,227,0,224,254,116,1,162,0,202,1,213,253,207,250,124,1,110,1,152,255,105,0,162,2,134,254,48,5,27,1,120,248,37,2,250,2,198,1,55,0,94,2,211,48,24,0,179,1,23,0,29,0,26,24,105,4,161,255,97,0,57,2,132,0,235,1,164,0,224,254,13,252,122,255,210,4,85,254,2,255,244,253,226,0,222,200,72,1,186,255,130,6,67,255,208,246,73,4,107,2,120,2,43,252,233,2,75,2,229,255,56,255,153,252,50,0,214,1,10,255,50,10,69,2,254,0,165,38,182,253,112,3,138,209,130,1,111,4,117,0,48,4,116,0,194,252,96,255,22,252,69,253,190,255,26,255,252,254,112,0,106,0,221,0,41,1,209,255,218,29,170,0,182,254,169,253,205,255,36,254,33,0,219,1,112,2,55,24,162,254,106,254,184,0,138,3,240,253,126,1,145,1,92,1,26,0,70,255,33,0,126,255,194,255,206,255,244,4,124,255,147,255,140,4,158,254,163,2,3,0,110,254,12,255,132,2,136,2,124,255,252,255,45,0,162,79,120,255,56,2,126,0,120,1,140,56,136,254,11,1,206,52,252,254,111,0,246,3,246,2,183,1,39,2,92,255,207,0,128,0,96,254,104,2,178,2,12,219,192,248,99,4,58,3,247,254,6,253,60,6,136,253,52,0,146,253,130,252,111,1,79,254,156,255,81,7,244,2,228,187,168,0,227,253,38,2,145,0,20,234,223,251,192,250,112,253,62,255,216,0,12,254,11,255,246,0,64,0,176,2,215,2,250,48,140,234,252,0,116,252,88,254,236,253,109,253,235,254,26,255,32,253,73,255,35,0,28,255,200,0,244,255,8,255,196,255,19,254,177,1,190,1,110,1,124,253,92,0,188,254,29,0,65,3,218,171,47,252,94,0,123,1,49,0,222,251,248,0,78,255,85,0,63,252,82,251,208,255,211,1,14,255,38,216,20,6,255,43,52,253,46,3,106,249,10,14,229,255,182,2,222,252,134,1,48,16,105,253,44,0,222,253,56,1,228,255,28,254,213,3,205,254,240,1,152,1,203,0,255,48,40,1,40,251,159,0,78,3,67,252,43,250,150,253,57,6,92,46,56,10,162,7,156,1,102,252,216,250,253,12,2,255,156,248,95,2,81,247,215,221,50,250,17,0,87,1,206,255,206,253,251,85,162,254,21,254,186,255,196,255,105,2,0,3,166,254,131,1,148,2,129,5,222,0,104,2,173,0,213,250,177,15,49,255,243,253,69,204,11,0,184,1,154,253,232,254,37,2,98,253,177,255,203,1,48,2,154,255,42,255,202,255,79,251,230,0,242,253,89,3,20,4,143,254,166,9,254,212,214,206,243,0,51,255,70,3,104,252,92,1,30,253,39,5,86,0,178,255,84,254,139,248,101,255,2,0,252,1,199,2,220,254,163,6,225,0,155,255,93,255,28,2,220,37,235,0,73,255,218,255,198,0,46,254,52,255,3,221,110,252,213,254,193,0,10,0,211,2,131,2,235,253,118,250,67,1,20,0,78,1,138,252,181,254,112,1,130,0,231,137,104,255,242,255,125,2,132,0,24,255,107,255,82,254,64,0,13,255,136,254,114,1,132,1,196,0,182,251,117,0,230,252,240,255,238,254,92,1,208,1,4,146,184,0,66,1,155,255,2,0,229,255,73,255,98,2,0,1,96,255,195,253,30,255,76,2,77,6,4,4,46,37,153,247,190,249,240,253,156,254,140,255,9,211,36,7,98,247,209,255,11,253,57,250,107,250,131,198,150,6,253,0,34,3,206,1,219,255,108,252,223,254,111,254,71,52,97,1,182,255,114,0,67,255,124,2,178,1,129,253,245,3,234,0,232,45,219,0,184,5,124,255,218,205,125,0,176,253,216,255,94,255,20,249,250,1,223,1,166,1,36,0,15,0,64,252,31,3,5,2,31,5,103,254,236,2,217,2,190,1,21,43,17,205,233,4,117,253,243,255,26,253,136,5,124,254,238,254,229,252,163,0,196,253,74,0,174,1,166,255,130,255,182,255,170,253,140,0,125,0,236,255,148,176,208,0,37,0,19,0,82,255,47,255,49,1,28,0,110,254,28,0,197,254,255,255,122,255,184,1,192,252,79,0,133,253,208,254,8,0,0,128,113,2,214,1,56,251,161,254,34,2,109,251,62,253,140,2,31,0,60,29,64,254,148,3,220,4,133,254,212,254,68,0,100,3,95,2,247,0,70,0,40,252,234,55,21,0,162,254,174,255,112,1,200,1,26,253,216,1,34,0,14,3,14,254,145,252,188,2,161,1,216,0,159,1,95,255,75,255,160,253,34,6,94,3,160,255,142,255,159,31,230,255,168,0,149,254,220,252,220,255,254,252,139,0,85,255,245,25,111,250,218,18,88,235,78,5,29,210,192,255,138,2,122,243,100,249,21,3,1,248,233,254,148,3,144,249,140,4,252,7,112,255,51,253,120,254,40,255,116,1,92,1,28,4,81,255,156,2,52,1,241,255,184,113,106,254,250,252,109,1,18,252,242,253,52,4,59,0,96,253,169,255,150,255,174,0,96,0,103,2,206,1,213,255,16,254,112,0,149,0,200,255,74,255,244,254,0,128,51,255,92,253,165,0,70,251,187,254,28,31,212,255,34,2,69,253,29,1,94,254,99,1,238,0,38,2,67,0,169,1,128,1,74,252,182,254,48,255,60,254,212,0,90,45,66,255,37,0,117,252,127,212,42,252,73,2,241,252,160,252,164,0,232,255,254,253,45,255,2,0,2,254,188,253,83,2,128,0,100,0,27,255,201,255,34,1,229,253,40,0,150,225,242,254,39,1,4,254,50,2,84,251,218,0,33,0,204,14,6,221,198,251,41,1,118,252,190,254,123,0,138,4,169,254,121,210,88,0,228,255,149,4,9,0,157,255,36,0,45,209,100,1,86,49,255,2,73,255,41,252,209,253,186,0,124,4,18,2,72,254,206,4,56,254,123,255,88,254,35,0,155,254,162,1,177,5,81,253,228,2,14,255,191,69,144,254,223,251,250,254,122,253,150,1,56,253,222,251,172,255,198,1,214,3,230,255,47,253,103,1,253,1,234,51,87,9,215,2,69,1,72,1,13,1,100,255,90,1,14,255,225,255,156,254,229,2,140,1,158,255,108,0,35,0,19,255,12,140,196,0,187,255,206,1,173,254,24,0,59,251,96,1,110,253,140,1,243,0,134,249,54,254,127,251,5,0,106,253,209,255,18,0,196,253,201,253,220,247,44,252,46,255,150,0,116,254,244,57,46,255,0,0,94,255,229,253,76,2,156,252,248,0,128,222,252,3,14,2,32,4,6,1,107,255,50,3,183,250,160,251,255,2,30,253,134,253,106,198,151,255,43,3,182,6,140,255,192,255,51,1,152,3,36,251,84,9,229,39,103,238,6,255,105,2,67,249,123,253,234,4,122,4,178,253,195,2,244,255,116,1,2,7,244,3,107,255,148,1,46,252,206,254,168,0,0,250,89,0,142,0,170,3,77,178,205,3,31,254,93,254,120,252,57,254,227,248,175,249,142,2,26,248,114,7,15,254,174,211,182,254,97,210,242,255,1,0,23,2,135,254,33,4,42,255,43,255,174,1,243,255,205,242,14,212,143,3,52,253,16,255,246,255,4,1,132,0,157,253,192,255,174,253,164,222,69,3,123,241,126,251,138,3,127,41,10,254,89,255,67,0,119,0,189,52,67,250,213,0,232,251,133,250,176,1,201,251,45,0,26,255,38,253,53,255,173,253,130,251,52,254,159,255,139,1,208,254,168,108,212,254,240,255,153,0,97,253,39,2,180,1,68,252,74,255,194,0,113,0,128,234,194,0,7,1,180,254,251,253,12,255,116,254,28,2,56,0,141,254,190,1,147,0,190,255,7,0,206,254,160,5,204,254,71,1,133,2,85,2,14,230,72,0,136,1,118,255,206,255,112,255,250,254,248,1,26,255,114,0,28,8,239,31,164,4,34,1,152,252,202,0,69,0,82,0,231,254,130,255,221,254,98,255,104,255,211,255,239,0,153,0,252,253,90,254,77,253,33,3,28,0,240,1,214,254,146,212,190,40,29,255,173,252,214,0,223,252,26,2,66,3,119,255,174,3,61,2,149,1,28,5,186,8,44,1,245,4,73,48,16,253,129,8,25,253,60,0,208,1,178,3,46,1,90,254,116,0,80,251,146,255,181,252,28,1,190,253,220,2,204,254,153,0,192,255,156,0,225,0,208,141,60,254,46,254,126,255,120,3,240,0,49,1,173,255,236,0,208,0,161,1,250,5,38,1,82,2,95,1,252,1,137,0,150,227,72,255,201,0,44,0,133,253,133,252,116,253,172,253,124,1,116,253,34,222,180,255,94,241,36,253,6,1,188,248,250,251,86,5,233,254,188,1,143,3,209,0,74,1,251,0,48,255,21,253,65,0,86,216,52,255,160,50,187,254,91,1,47,254,38,253,41,253,129,1,167,255,5,253,85,254,100,3,217,255,165,252,34,0,227,255,124,254,212,250,38,255,3,8,199,249,135,21,11,41,188,222,206,8,215,22,62,250,202,7,96,18,172,248,112,3,30,241,23,254,78,252,55,251,176,251,125,0,139,0,100,253,184,8,231,253,179,0,41,255,63,0,144,0,72,0,174,4,22,38,248,0,59,253,52,1,56,41,78,254,50,254,1,53,72,4,21,254,250,254,36,3,193,249,167,2,57,2,92,2,46,5,213,0,22,248,68,1,204,245,139,254,238,205,236,255,38,0,85,255,60,1,156,60,50,1,251,2,97,0,91,0,192,252,23,0,75,254,122,254,249,1,54,251,214,9,106,0,239,247,59,1,86,0,11,2,172,0,12,252,229,201,30,13,50,10,131,254,62,255,176,4,246,239,238,250,203,241,2,250,12,3,87,5,224,253,254,252,154,6,23,4,202,255,88,8,214,48,32,0,33,26,194,2,108,251,78,3,11,237,98,8,244,9,217,255,47,254,172,253,177,0,213,0,165,1,28,0,124,254,11,0,69,0,31,0,173,255,228,255,90,255,106,255,132,178,189,254,3,0,147,2,15,3,134,1,139,0,118,255,31,0,145,255,197,1,176,255,176,1,249,253,253,254,174,2,167,44,163,0,133,204,42,2,40,0,133,254,136,255,76,253,84,1,169,0,120,0,36,254,131,2,10,3,245,1,128,255,31,2,251,4,122,255,88,80,201,0,145,1,0,2,150,254,46,255,243,254,212,252,112,0,75,0,149,0,221,253,18,254,94,254,156,255,203,202,22,252,152,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+337920);
/* memory initializer */ allocate([98,6,117,254,63,239,5,250,209,255,82,3,178,251,246,52,109,254,171,2,92,255,89,247,100,251,42,249,88,1,118,2,56,252,157,2,28,2,26,0,174,253,192,0,239,255,176,254,189,76,109,4,18,0,200,255,162,1,86,254,1,250,153,1,220,2,186,0,12,1,58,176,234,255,62,0,147,253,210,2,184,1,96,0,205,254,128,255,224,1,5,0,87,0,156,2,151,254,169,253,234,255,140,2,80,255,142,255,214,0,55,208,70,253,232,0,96,2,130,255,54,253,24,254,28,255,161,3,210,249,123,178,245,0,52,254,124,0,57,0,72,1,76,254,98,255,236,0,60,255,234,253,209,0,69,0,229,0,210,0,5,255,76,4,71,2,159,1,210,0,189,0,37,255,218,4,26,76,151,255,190,0,138,254,213,255,24,255,253,0,49,2,215,254,136,254,203,251,204,254,174,52,82,207,64,0,66,255,214,254,125,253,204,1,232,0,37,252,34,254,60,6,168,0,46,253,104,2,151,252,158,255,76,252,231,0,178,251,139,46,234,2,17,254,224,4,179,4,59,43,224,255,160,0,162,255,232,255,103,255,47,255,83,250,221,251,199,254,102,252,119,4,230,253,188,250,189,254,167,2,202,255,24,255,42,254,27,8,65,181,116,2,250,252,35,0,247,0,170,255,209,2,0,2,25,5,82,3,32,38,248,0,156,246,36,255,6,0,183,255,166,250,55,2,152,5,31,246,28,250,22,56,32,252,169,251,84,252,145,255,200,3,238,253,64,2,102,0,235,251,197,1,180,0,162,255,0,225,202,254,0,2,228,3,224,255,218,251,106,255,230,255,225,229,75,255,176,254,26,250,104,2,70,0,180,254,81,255,112,2,222,253,171,0,108,1,243,3,68,0,228,254,144,254,199,2,46,0,73,0,222,255,93,254,148,1,110,110,27,1,188,254,79,1,125,255,60,1,212,0,229,255,170,254,218,251,214,1,245,4,198,1,30,1,120,248,118,249,29,253,123,254,49,4,228,231,195,254,182,253,62,255,74,255,22,205,176,252,244,17,109,253,197,2,138,253,202,254,144,1,88,1,236,254,174,1,108,3,1,248,12,252,120,249,76,255,64,0,245,85,32,253,61,3,10,1,182,0,180,1,144,255,220,255,131,0,252,0,193,255,154,0,112,1,107,0,93,0,214,255,0,128,0,0,200,0,26,255,15,1,16,249,233,16,218,3,215,253,225,1,96,7,46,245,80,3,95,231,8,1,212,47,74,6,128,253,68,5,74,245,226,247,139,3,165,251,114,1,101,191,221,249,80,255,24,0,253,253,234,0,186,3,93,2,101,2,102,255,207,1,23,2,96,255,172,2,214,1,59,3,218,40,150,0,99,253,228,229,83,1,226,253,38,253,161,254,216,3,212,0,116,0,249,255,62,0,158,3,127,8,71,255,216,253,233,1,47,255,127,20,38,0,110,1,53,0,16,0,7,1,114,255,233,253,32,255,82,1,82,255,131,255,113,0,50,206,144,1,102,254,25,1,244,255,232,2,83,255,230,1,129,208,149,255,73,255,28,254,2,0,150,0,1,0,17,255,7,0,113,254,160,253,151,252,186,2,169,249,189,2,251,252,16,1,192,252,162,255,103,252,117,3,20,53,178,0,192,0,148,0,66,5,44,0,59,0,237,254,242,255,184,254,212,0,133,0,33,255,44,1,118,254,237,254,213,255,180,255,209,255,66,1,48,255,209,84,228,1,73,1,68,7,40,0,108,252,246,1,130,0,221,1,218,6,247,1,48,31,174,254,189,254,26,255,98,1,160,3,174,1,167,255,162,255,108,0,225,253,109,1,126,255,70,0,134,3,125,255,58,0,213,1,68,2,27,135,36,0,232,0,102,254,61,254,104,0,6,222,113,0,110,249,214,255,233,254,164,255,232,254,35,254,126,254,237,253,64,3,80,0,102,197,200,255,93,0,164,0,47,253,196,32,100,254,164,246,72,2,236,3,202,254,75,247,208,254,129,254,19,1,38,4,242,4,41,1,186,255,115,252,123,3,131,0,234,251,27,2,246,126,232,3,235,255,27,255,138,0,248,5,81,255,34,2,70,1,168,0,192,254,204,2,221,254,214,254,29,255,70,4,197,255,239,206,143,50,18,3,88,2,50,255,121,3,7,253,54,0,76,1,27,251,171,253,101,1,156,251,206,255,88,255,148,4,218,8,75,0,82,255,71,2,152,1,99,255,74,57,122,1,46,1,251,255,48,0,109,0,28,0,235,255,20,4,17,2,165,252,98,251,54,255,192,7,52,1,146,1,66,0,141,251,35,10,132,254,95,4,53,1,226,1,47,214,100,0,17,238,126,45,172,250,147,254,49,37,194,254,233,255,52,4,121,255,74,245,191,252,78,0,142,3,96,0,236,255,169,253,46,0,87,3,15,251,140,18,90,9,6,255,120,220,62,252,191,0,166,254,92,1,86,1,117,7,226,59,10,1,28,2,15,1,170,11,76,5,6,6,5,252,129,252,225,2,25,1,172,2,230,253,174,40,102,252,31,1,167,2,204,0,122,212,239,246,166,254,220,249,6,255,197,254,164,253,56,5,55,1,37,5,169,251,153,1,152,255,35,255,211,200,25,250,34,252,193,2,216,252,75,2,164,2,92,1,192,226,209,250,132,235,255,247,104,241,211,255,190,1,22,6,13,253,92,232,146,23,26,239,228,2,164,254,81,48,67,8,106,253,83,253,64,230,192,39,127,33,245,251,64,245,155,238,229,254,11,6,168,18,140,244,188,2,97,13,191,240,49,4,52,9,74,228,87,249,77,254,232,18,104,248,164,4,12,3,133,240,230,231,66,249,151,18,252,238,180,247,106,249,65,1,123,252,134,5,101,252,138,245,82,251,71,198,10,248,56,242,123,0,208,43,112,7,134,248,164,29,184,10,87,239,234,236,54,242,41,250,83,249,31,233,245,14,148,8,22,237,207,252,150,252,239,233,123,247,225,240,190,14,168,250,66,1,154,251,28,252,223,240,130,53,103,219,176,252,213,14,101,253,197,251,125,9,233,242,120,249,22,242,202,249,77,242,40,2,210,25,215,239,179,216,180,234,2,232,82,250,190,6,238,250,129,238,238,23,90,6,25,245,48,6,20,5,94,22,24,10,101,43,184,2,240,242,142,246,69,35,250,16,30,242,113,5,144,0,3,8,212,34,30,24,50,20,120,1,50,38,6,247,233,239,149,14,221,255,143,245,174,8,103,5,254,7,43,11,253,192,101,6,85,251,106,253,240,10,63,247,217,14,58,236,46,252,38,22,183,234,177,255,151,13,94,2,182,14,211,250,247,254,139,3,23,253,237,3,64,199,125,239,141,240,230,227,106,14,118,8,40,246,35,45,1,254,12,23,124,254,242,240,144,242,88,8,156,252,86,244,210,2,6,5,69,240,142,40,146,249,73,20,235,9,215,4,139,30,189,255,54,13,31,243,210,255,32,241,62,3,33,5,116,247,6,239,34,23,223,251,106,231,237,55,209,7,200,3,54,16,231,239,132,5,210,254,47,223,148,250,153,41,215,218,18,4,72,3,2,238,50,8,142,4,192,5,222,252,6,245,164,1,207,253,187,254,92,10,206,244,54,5,14,19,190,3,83,0,200,1,179,4,86,226,254,56,70,251,154,8,94,248,110,248,171,242,184,251,148,23,117,249,216,250,123,238,87,214,42,39,76,246,55,243,145,18,237,254,42,242,156,3,238,4,180,28,113,244,19,253,104,254,242,17,12,19,21,254,81,13,8,18,110,0,45,2,158,250,176,249,76,238,163,6,132,5,67,2,18,254,204,2,197,0,206,164,20,247,156,0,72,4,105,255,221,248,176,2,190,254,67,9,27,225,212,250,109,249,181,30,162,27,61,254,2,1,128,35,108,7,212,33,72,3,163,13,53,243,213,11,37,254,182,247,163,233,36,222,75,232,126,242,144,16,65,244,169,234,179,36,130,245,110,18,51,253,42,0,246,248,50,12,131,243,164,235,220,249,13,255,61,254,21,32,105,247,212,242,14,16,16,224,227,214,81,234,216,16,170,2,21,8,193,7,127,241,132,229,169,4,15,11,76,247,230,1,173,241,235,252,101,249,215,17,208,1,190,247,220,246,167,248,129,7,66,6,242,71,255,5,201,253,228,0,113,219,117,232,245,254,44,14,255,127,143,5,182,255,255,244,64,8,128,255,20,250,114,246,137,6,252,10,210,249,77,8,106,2,9,10,154,10,82,249,84,1,183,12,80,3,51,13,243,246,199,246,225,248,156,1,64,246,12,185,56,251,248,9,32,244,144,0,171,253,36,30,52,19,205,244,132,247,72,8,40,245,163,2,47,209,156,6,152,250,252,241,214,16,252,3,137,239,5,255,78,228,132,248,122,7,12,245,45,24,180,229,166,250,136,241,194,1,164,245,153,25,218,255,108,40,220,4,58,247,111,241,146,247,196,250,53,9,46,12,162,36,65,249,78,12,229,240,253,4,241,255,1,3,208,246,101,254,148,5,48,201,251,251,12,11,154,248,196,23,220,255,6,2,103,51,71,4,95,251,121,243,213,253,72,243,180,255,44,15,66,13,242,3,154,7,160,0,1,237,106,18,81,228,111,240,226,21,22,13,142,30,159,233,235,225,80,36,251,11,254,13,136,20,61,53,84,240,98,247,229,240,104,253,152,255,45,17,74,225,36,0,187,3,218,255,51,252,130,13,140,19,108,1,100,220,52,245,136,247,156,248,48,226,30,237,100,233,19,242,35,251,64,238,152,25,249,17,38,9,225,25,16,4,106,8,183,228,206,22,136,248,145,242,165,4,138,246,213,253,214,12,232,197,248,252,204,4,130,9,120,0,105,53,136,3,182,250,133,2,242,249,159,250,160,248,136,5,89,253,107,249,195,6,100,9,102,233,213,12,63,255,133,255,181,7,79,14,148,250,143,197,243,241,179,21,116,250,28,1,247,5,241,245,149,7,103,3,60,15,136,247,37,206,154,11,104,254,197,243,230,230,100,7,14,3,112,26,228,254,10,4,57,38,141,23,223,240,250,239,3,239,244,9,154,241,10,234,161,18,161,254,242,31,171,227,103,14,112,2,222,238,188,15,36,245,110,248,35,240,176,248,16,251,132,28,248,2,82,33,203,252,150,252,111,200,137,251,232,234,174,252,23,246,222,1,132,6,36,251,150,254,109,3,153,13,198,250,158,235,43,8,156,15,191,253,134,1,178,33,52,3,181,0,36,252,228,21,222,37,88,4,8,244,246,254,210,4,26,254,240,4,131,247,153,202,145,14,116,243,244,9,209,6,109,219,129,31,129,14,241,242,17,237,248,10,148,237,129,247,25,0,170,233,216,15,63,7,55,18,20,9,114,251,31,2,2,0,91,15,132,243,211,10,104,252,165,244,22,253,39,251,206,254,233,10,234,255,174,245,232,11,184,12,12,7,226,250,212,69,232,248,56,0,98,249,47,254,234,253,30,247,251,23,57,247,45,246,203,251,233,12,239,5,17,1,104,4,155,249,1,10,2,250,106,3,232,166,161,251,9,246,152,215,75,247,74,242,194,0,34,10,201,6,105,18,199,53,204,13,201,254,161,31,12,252,183,252,248,238,25,3,245,254,50,255,105,50,133,245,232,230,196,0,186,27,102,249,78,253,212,4,190,244,148,245,28,248,99,32,102,245,1,238,101,252,227,247,194,244,151,6,39,215,217,249,124,8,122,240,163,22,212,6,196,248,233,235,155,18,23,236,232,244,197,248,74,10,82,23,180,0,2,243,137,249,202,4,119,1,17,20,138,245,130,235,231,16,170,241,228,38,72,248,141,8,136,11,127,229,71,253,105,4,120,233,69,233,132,25,66,14,81,249,17,15,47,0,110,218,107,248,220,9,36,251,74,28,126,45,192,255,0,9,201,0,133,241,68,253,149,0,132,10,219,252,138,15,178,10,47,252,20,252,112,233,235,49,30,29,159,254,133,237,230,240,164,27,146,0,26,243,249,11,163,7,169,254,77,250,86,254,238,232,218,250,244,1,10,252,22,252,214,247,148,244,215,175,50,10,45,6,141,1,204,242,187,244,254,1,133,251,70,13,122,7,99,0,137,255,144,0,200,243,141,9,255,6,141,1,150,14,176,255,174,242,42,241,138,251,21,250,201,245,252,249,73,20,139,8,172,3,105,19,226,246,51,191,69,1,118,247,41,238,1,20,130,252,64,229,142,232,40,7,200,253,67,32,65,3,92,13,149,238,20,253,114,13,6,17,31,244,37,216,87,36,25,250,43,237,158,7,58,252,245,13,197,1,193,2,110,63,123,252,93,255,206,244,152,255,25,249,13,249,31,251,179,12,183,7,230,4,186,252,122,254,178,243,252,3,222,9,23,248,150,2,255,244,198,250,169,252,142,242,125,173,241,0,122,255,72,252,180,253,12,10,32,8,217,31,114,0,4,38,138,229,110,235,98,246,238,8,169,253,86,254,116,5,117,228,52,251,56,1,113,238,35,246,41,18,231,250,174,251,194,246,184,8,225,15,14,183,241,250,69,243,20,252,240,235,206,0,153,4,246,235,90,9,214,9,155,250,4,10,118,255,245,16,92,66,242,9,126,26,151,242,82,3,54,252,1,255,28,5,180,8,168,6,253,250,172,5,208,245,207,5,34,12,37,247,74,244,98,229,118,6,203,82,19,6,200,3,154,0,124,0,22,251,202,2,105,254,44,0,247,0,224,3,180,8,8,11,155,5,171,254,188,4,180,249,238,23,100,6,80,223,66,2,214,234,217,0,65,255,204,0,21,228,246,19,182,14,191,19,165,232,27,26,112,1,243,241,13,238,206,29,229,241,176,246,89,5,83,27,29,243,203,255,244,7,210,237,163,16,146,37,12,252,108,244,45,17,192,247,109,46,144,249,82,252,110,242,224,253,126,250,90,248,1,250,165,11,201,249,109,190,79,1,1,18,58,248,237,14,123,253,50,7,192,255,99,242,130,12,138,254,198,255,126,250,136,28,90,248,162,247,108,211,27,246,1,2,251,231,233,229,104,8,81,12,238,19,168,8,175,250,212,8,255,18,137,228,2,6,126,235,49,246,96,0,11,13,137,242,132,241,0,28,184,239,70,3,194,243,156,12,5,250,34,234,45,55,208,0,154,247,51,3,195,251,250,47,58,26,38,245,220,219,3,236,33,230,81,249,99,239,94,231,244,250,166,250,253,251,116,252,209,244,216,248,37,18,46,253,228,254,95,255,14,236,198,27,50,207,22,250,179,234,20,243,192,13,77,4,184,251,235,246,22,253,223,255,85,10,150,238,227,252,84,253,234,5,180,6,196,231,180,25,157,242,118,253,3,215,4,19,201,22,175,246,238,254,250,5,52,15,108,248,121,250,171,246,21,211,240,247,169,3,179,254,81,5,209,249,82,21,8,247,65,243,104,223,116,239,43,231,188,246,213,243,56,5,120,247,194,0,90,239,98,225,34,27,183,17,237,2,164,28,67,0,185,254,17,1,139,12,223,248,155,254,127,27,18,13,138,24,232,1,156,240,212,39,63,25,71,1,55,17,141,3,121,3,177,236,146,253,47,240,228,9,78,7,140,2,242,6,151,2,247,11,12,252,146,250,66,16,6,80,170,255,94,12,69,1,136,248,255,1,134,253,238,4,145,237,46,250,111,26,14,243,131,255,138,17,162,215,10,21,204,38,13,3,34,1,150,8,159,6,206,14,170,248,80,30,212,254,229,7,132,21,152,8,232,0,226,27,90,5,60,243,168,13,110,54,50,251,1,247,190,3,141,0,20,13,205,244,37,252,97,36,222,2,210,25,211,241,12,209,197,20,12,255,190,248,2,0,236,248,170,230,124,3,158,3,20,255,248,3,31,251,43,254,18,255,140,248,158,214,160,237,117,252,190,225,7,15,52,2,188,232,67,13,115,1,240,235,161,15,156,4,1,3,213,253,176,248,129,244,48,249,172,33,205,5,173,38,144,250,97,13,252,224,151,0,120,1,192,7,215,11,231,14,50,252,25,2,130,228,172,7,7,234,105,17,26,216,5,249,48,245,190,222,176,0,148,241,41,25,76,12,90,2,48,248,201,53,24,245,80,4,237,247,181,231,235,5,224,254,168,12,142,234,69,45,158,14,217,246,40,249,117,14,101,29,116,249,77,3,239,26,68,11,212,13,150,9,242,3,150,9,127,233,243,7,41,13,100,218,162,252,108,228,10,7,44,22,92,9,197,10,3,23,67,253,136,209,35,240,252,30,240,254,2,10,83,0,48,2,196,235,81,247,156,254,241,242,58,11,166,250,68,226,237,6,214,7,94,239,192,20,86,1,4,32,75,19,7,2,240,13,68,17,208,10,160,209,51,244,101,7,154,6,149,234,63,224,116,29,140,255,240,247,135,238,117,4,138,7,144,2,208,225,74,245,52,243,222,10,44,11,62,232,78,20,113,237,26,254,235,252,220,189,202,253,252,19,172,4,64,3,186,16,78,0,16,12,208,10,77,8,3,4,176,6,54,1,40,3,197,249,150,255,102,12,246,17,127,244,15,6,248,225,108,2,152,249,83,1,186,17,11,13,20,2,161,254,4,1,249,0,169,247,225,253,70,184,120,253,225,240,138,21,10,249,219,211,138,254,226,247,74,6,50,0,169,238,14,246,14,244,71,3,251,219,58,10,254,6,103,0,219,251,149,254,29,1,42,242,247,1,75,254,30,0,102,5,75,0,220,244,252,251,23,12,222,16,244,246,227,2,33,3,19,167,114,8,145,3,162,6,149,0,1,8,199,254,221,252,65,13,60,250,44,17,93,240,86,3,192,250,38,4,25,39,188,24,182,222,200,245,80,217,122,254,182,243,121,244,126,16,162,21,239,1,192,14,140,202,79,18,117,247,119,252,133,19,65,24,167,18,46,251,164,7,1,238,190,11,142,254,98,253,96,207,86,233,215,31,140,0,205,5,60,231,91,8,207,4,22,0,44,255,42,8,92,253,62,9,67,253,239,239,109,1,154,11,191,253,150,3,156,28,59,253,243,7,42,20,64,28,25,204,69,243,116,252,148,248,97,239,226,245,62,1,27,19,184,2,216,255,145,249,36,6,59,251,32,19,121,20,49,0,221,247,52,236,221,29,18,35,92,6,79,11,190,236,124,224,218,8,233,7,180,248,178,12,82,10,239,252,21,199,251,38,153,13,58,247,130,4,86,10,56,10,15,248,136,244,236,250,186,9,111,3,43,251,52,251,44,253,12,249,12,2,37,230,245,242,34,246,205,13,76,3,130,11,160,8,62,242,133,207,10,244,76,9,192,1,92,2,156,237,99,9,122,7,198,255,149,0,136,241,29,248,150,16,148,228,131,243,56,253,85,247,52,39,40,245,162,243,88,10,131,11,58,13,45,25,51,6,244,254,232,253,103,7,211,220,39,42,42,252,23,32,14,25,46,20,143,18,160,0,234,11,159,252,72,24,93,251,91,228,104,6,214,19,2,17,226,6,227,240,150,4,107,255,54,4,92,7,29,20,243,58,80,254,119,246,178,251,86,251,54,4,1,250,97,32,114,245,167,15,182,2,72,0,173,2,0,11,188,51,90,254,74,228,176,1,252,7,28,209,236,254,126,8,116,252,80,237,93,22,6,255,22,0,252,19,254,255,126,10,187,3,195,222,239,225,105,241,160,2,78,251,203,16,188,16,64,48,198,246,125,22,37,5,197,16,252,1,234,11,244,253,73,4,18,13,231,253,120,246,196,249,229,233,92,16,143,253,123,6,245,11,231,10,176,6,81,244,198,3,249,189,98,2,14,243,64,16,90,241,68,2,177,242,172,254,203,209,248,253,167,249,89,11,162,2,109,255,92,235,74,239,99,236,27,18,155,24,159,8,35,10,125,225,188,255,11,16,218,16,252,249,220,212,90,247,221,252,232,0,78,226,161,255,106,4,127,19,151,254,139,6,135,17,23,14,208,231,126,255,137,0,96,250,10,11,178,0,246,201,40,252,125,4,206,4,51,6,35,6,214,12,173,20,45,247,229,7,189,231,72,226,106,245,198,9,219,16,229,253,174,222,22,253,114,253,93,240,227,232,112,241,170,17,146,215,14,251,210,0,214,19,84,244,230,240,79,15,201,3,217,251,100,231,24,238,140,246,210,247,140,252,34,9,178,243,85,21,135,251,34,253,108,6,135,8,170,74,136,251,247,246,108,254,212,4,255,13,134,0,10,7,8,240,21,245,169,2,154,14,39,7,187,64,149,3,14,247,192,241,204,249,98,255,240,253,232,252,138,1,248,226,142,9,146,1,121,254,183,255,138,250,6,5,153,230,96,20,70,4,85,252,137,6,10,248,226,61,77,248,64,16,128,249,63,28,130,2,138,22,113,16,209,248,220,0,246,254,165,0,7,8,102,20,240,242,112,230,36,21,234,5,74,2,55,6,104,196,101,245,173,3,28,5,46,220,209,244,71,19,159,244,245,250,231,10,31,31,14,0,179,251,190,14,252,13,80,3,57,5,114,4,233,244,20,242,76,235,141,48,14,0,186,5,54,228,174,4,110,242,19,255,239,245,231,250,189,1,45,4,82,255,148,6,62,15,229,0,210,22,78,253,210,3,14,253,158,4,165,252,86,82,71,255,198,2,29,3,149,247,111,1,136,247,234,3,221,14,100,252,212,1,238,246,250,241,72,6,59,13,18,0,0,6,166,252,130,2,228,224,25,69,115,38,242,236,69,244,205,28,46,23,190,16,244,40,193,255,235,237,206,3,77,247,42,10,226,14,113,7,124,249,174,247,228,7,200,246,37,11,100,2,206,19,32,251,156,252,15,254,150,13,111,248,66,244,123,253,5,14,203,11,35,243,85,64,133,235,154,244,252,6,247,245,133,14,98,218,184,250,226,240,96,254,162,239,97,221,24,229,14,254,210,252,241,252,239,237,209,22,26,6,131,247,225,1,24,1,48,3,134,18,22,217,23,46,19,248,100,246,108,19,168,253,84,250,147,248,182,247,58,12,126,10,205,252,194,246,98,3,211,247,28,4,198,255,28,1,246,14,126,237,238,239,215,250,27,5,252,244,51,19,75,210,10,2,66,248,112,27,211,32,226,6,210,255,20,2,233,19,149,19,153,253,14,12,41,8,243,26,173,251,49,240,169,244,236,20,62,237,59,252,50,26,55,15,62,35,108,5,219,42,39,23,118,244,59,252,111,242,199,235,162,245,90,13,61,235,201,190,69,230,96,254,148,1,206,4,230,245,36,243,110,5,14,0,31,254,162,238,55,5,109,0,36,4,118,15,251,4,233,233,229,4,149,246,207,0,250,206,64,24,113,246,169,242,199,9,80,3,22,12,120,36,87,10,151,9,190,8,52,9,172,247,227,20,147,3,179,8,153,255,200,22,56,246,138,29,96,37,44,232,251,15,108,10,70,249,31,1,107,26,218,15,125,254,244,247,146,21,112,12,158,18,98,255,138,2,236,211,65,46,86,24,120,239,188,20,102,12,62,19,102,244,103,237,44,252,117,0,152,7,74,248,148,234,134,25,246,254,202,227,156,3,162,245,180,253,137,37,223,246,100,7,194,247,224,19,64,7,28,31,67,240,84,252,149,5,37,3,159,237,174,250,124,3,67,255,94,223,187,12,194,0,255,2,195,244,187,239,34,252,153,47,96,255,46,248,152,250,244,234,188,249,226,0,47,231,195,239,237,6,56,9,252,238,38,253,170,234,42,240,203,194,8,250,118,254,5,16,53,255,232,10,237,252,63,13,213,254,240,24,162,249,238,227,35,206,10,18,166,3,111,254,230,10,236,8,188,236,20,251,135,232,226,245,19,247,247,250,38,13,160,239,146,238,255,127,193,243,160,248,67,0,198,244,150,0,152,18,221,249,72,2,117,247,102,1,59,249,250,250,35,238,45,248,80,7,172,3,106,248,1,255,104,221,216,250,236,242,246,18,3,254,20,11,242,255,186,9,255,249,114,3,164,4,196,243,151,196,159,249,212,255,245,244,112,1,181,251,207,251,45,254,174,24,231,22,24,11,176,235,57,2,88,244,187,25,124,37,196,236,201,1,15,19,159,238,200,13,76,7,202,240,191,240,60,60,226,245,169,253,145,236,52,15,82,250,152,253,98,7,116,245,60,243,150,250,215,251,250,243,106,246,146,248,118,18,222,255,134,239,83,6,254,243,164,21,8,231,14,242,127,10,218,221,77,1,150,255,22,9,55,249,65,241,141,1,31,242,24,230,78,232,95,37,88,11,135,252,112,4,15,5,190,75,244,254,201,243,76,255,160,6,210,252,249,252,206,236,56,254,10,253,158,252,78,4,100,241,138,254,213,1,10,229,160,5,253,215,179,231,67,237,254,243,138,251,41,1,205,19,245,249,98,21,204,2,58,254,222,14,4,16,85,11,135,247,24,253,168,19,46,234,86,244,238,8,110,9,180,30,144,245,210,255,194,216,228,20,6,252,248,3,182,35,191,17,211,21,180,8,132,245,14,238,103,246,198,248,189,241,242,248,218,18,90,210,148,7,55,242,54,4,142,235,140,246,173,255,238,246,242,235,249,252,165,2,215,219,160,252,109,252,142,17,155,1,44,237,111,23,120,17,191,22,11,238,49,12,180,248,253,249,34,9,103,239,130,4,146,203,23,3,45,251,40,251,108,1,177,0,28,250,33,246,123,244,242,247,118,0,213,243,37,1,121,248,212,72,180,251,152,0,32,246,122,7,156,250,168,249,46,1,193,252,104,252,64,1,145,252,28,251,45,3,245,255,48,27,246,253,20,12,137,255,206,5,252,11,34,26,249,243,249,51,198,24,169,3,96,6,254,251,104,7,225,246,135,240,134,21,222,10,187,0,112,246,29,251,244,2,16,194,107,12,125,251,40,3,44,249,63,230,214,5,206,243,158,255,32,241,235,1,216,6,116,12,110,8,124,248,251,2,141,4,148,0,167,243,252,250,162,70,61,255,155,251,77,3,32,183,51,254,236,0,158,251,228,252,155,255,83,3,92,241,94,5,155,222,218,242,54,250,2,4,254,7,42,17,247,253,232,0,26,254,136,249,255,127,162,7,97,251,126,255,136,1,194,0,156,252,67,11,88,255,118,249,114,252,222,255,51,3,175,251,92,6,249,236,183,253,110,251,196,253,195,1,71,15,18,42,221,255,226,239,212,27,198,27,164,252,182,240,34,243,16,1,121,253,220,0,189,46,206,242,166,10,198,7,88,6,151,241,156,38,90,9,24,12,250,253,49,20,78,240,36,12,168,0,232,4,102,254,245,240,88,212,17,215,250,7,141,5,208,5,32,252,230,249,115,253,89,251,198,8,211,1,124,18,154,0,217,2,76,28,238,255,33,5,205,255,224,248,194,4,193,5,149,229,250,211,57,239,22,16,19,4,106,233,90,5,46,0,237,212,246,15,35,250,245,255,147,253,208,1,13,3,112,53,1,1,42,2,47,12,238,2,191,248,22,4,28,251,0,254,227,2,219,57,98,49,1,15,8,11,163,0,84,6,39,0,158,18,131,5,107,247,13,2,146,2,163,1,5,0,92,0,8,6,34,1,10,248,107,41,124,233,249,242,27,230,237,245,180,15,221,243,219,10,81,3,46,22,4,1,244,10,99,0,59,5,32,2,158,5,62,254,170,253,252,2,32,6,246,251,48,238,44,10,227,184,108,6,235,3,93,253,145,12,178,254,192,252,84,250,66,1,96,2,44,1,88,237,212,252,220,255,115,2,118,6,8,255,186,252,67,84,167,255,166,249,18,2,129,251,224,36,10,2,6,232,165,8,145,216,206,253,232,3,173,19,134,255,253,255,152,27,141,1,186,247,106,1,175,61,233,251,94,197,9,250,180,250,11,245,208,253,180,243,10,1,211,255,44,5,16,243,20,249,78,9,189,0,137,25,124,0,8,251,156,0,76,2,138,245,222,243,12,11,156,241,177,2,44,15,42,18,192,0,189,254,206,234,46,253,222,44,161,253,7,14,203,16,69,8,106,1,102,220,180,45,193,242,53,9,215,29,149,8,254,16,154,11,35,246,169,0,32,232,91,0,240,5,237,255,22,6,20,238,187,252,29,224,129,3,200,224,32,8,226,243,6,3,160,214,198,254,119,255,244,253,87,0,225,252,145,255,74,0,32,5,94,3,10,1,243,0,199,0,224,254,181,4,195,252,114,6,64,11,56,159,27,15,211,204,85,2,206,217,220,247,239,243,168,251,36,2,130,253,143,14,66,254,13,19,51,8,68,0,80,245,206,236,65,228,7,1,244,219,242,252,195,247,64,4,167,248,112,250,226,255,183,250,74,2,245,15,11,242,111,209,62,9,4,2,252,251,66,3,22,255,102,8,235,193,1,9,221,241,249,245,82,223,98,2,130,11,177,246,245,8,178,3,34,242,142,229,55,250,10,253,160,252,24,255,39,11,40,0,230,246,21,8,167,254,9,7,179,253,39,251,135,2,76,27,191,245,228,55,241,10,247,2,76,245,88,253,196,3,109,1,6,254,252,86,230,6,54,255,65,245,219,254,170,14,0,5,247,253,229,242,7,18,82,2,9,249,217,255,210,255,48,0,178,245,217,253,244,9,168,248,146,14,66,249,171,3,167,254,249,255,162,249,147,164,22,252,23,22,52,8,184,1,146,6,252,3,174,253,88,1,231,5,250,250,142,21,217,1,122,211,56,238,208,2,93,18,46,30,126,0,95,248,28,254,144,249,26,249,53,6,228,3,80,253,131,254,142,6,218,5,240,253,164,252,101,253,201,252,255,127,49,254,13,255,38,251,50,4,156,9,125,250,53,254,3,250,182,5,213,245,240,252,121,254,82,1,116,13,122,8,100,252,181,3,180,7,240,5,10,244,97,253,108,50,76,10,245,10,210,2,16,209,230,255,104,2,168,4,169,4,252,251,128,255,190,166,191,0,152,1,223,243,176,253,72,254,240,4,236,245,79,3,82,3,252,8,234,254,126,0,166,8,123,245,235,255,62,255,174,253,235,253,45,0,58,2,38,0,124,2,252,4,171,0,150,116,136,2,143,3,154,254,44,1,90,2,157,1,73,216,202,255,183,250,42,0,22,249,235,1,134,208,240,248,26,0,169,1,217,7,142,3,58,224,106,1,209,7,142,255,230,245,231,251,7,255,200,254,160,0,141,6,163,105,212,255,160,0,66,3,243,0,162,253,240,254,45,252,187,249,105,0,21,254,242,2,26,255,138,9,24,0,237,235,117,254,22,242,100,56,72,251,96,243,251,9,76,205,118,252,173,1,217,0,80,254,17,251,12,255,31,255,144,3,192,255,12,3,77,4,86,3,16,255,52,1,42,144,6,2,32,0,208,3,62,222,31,244,9,7,26,253,23,250,128,0,139,243,89,3,59,200,246,248,205,4,188,255,203,253,65,0,254,15,78,6,194,223,127,251,128,253,97,63,180,13,153,250,214,240,165,254,66,5,5,15,105,10,36,9,186,248,58,235,122,5,184,250,78,171,74,253,98,251,30,1,218,252,85,8,56,7,236,253,90,241,140,29,30,4,28,1,98,241,255,9,188,10,80,13,248,249,170,254,206,167,201,4,190,3,255,9,11,1,122,1,232,241,132,250,123,249,243,255,111,4,153,0,143,253,156,5,211,0,44,2,227,2,70,4,212,40,82,3,8,20,205,44,121,0,73,19,197,241,91,5,139,254,226,229,229,0,72,243,181,255,24,5,1,252,60,254,32,1,165,49,4,53,11,254,48,7,236,251,34,248,19,240,90,245,14,252,14,241,139,253,46,254,101,252,177,252,152,22,130,3,252,208,229,4,51,249,10,6,130,241,222,10,154,242,238,248,7,1,194,223,54,12,55,0,136,254,202,0,200,3,106,249,176,3,60,196,152,245,113,5,15,3,184,212,178,6,126,249,216,251,5,237,216,246,78,1,33,5,71,251,109,3,220,248,174,247,15,244,84,1,94,31,106,243,102,45,12,234,189,5,12,13,46,11,151,240,156,252,95,1,222,250,229,8,214,246,96,48,228,3,100,246,18,7,191,2,146,247,96,12,97,217,50,34,175,13,122,250,189,1,82,3,226,255,85,9,151,253,199,12,186,249,255,233,177,11,25,39,72,22,187,210,182,16,24,5,142,246,223,1,44,191,195,207,99,11,71,1,127,3,254,4,132,5,202,254,115,253,249,250,112,3,58,239,38,0,131,8,230,247,238,248,198,0,248,249,184,224,152,9,251,244,105,243,127,241,243,45,223,247,115,255,225,18,116,6,14,14,39,2,137,249,126,251,196,255,210,254,227,2,42,250,35,10,18,252,105,10,82,42,250,211,76,244,132,253,66,254,24,7,253,249,53,16,72,255,156,255,201,255,9,1,159,8,127,2,94,255,94,247,142,253,93,2,99,173,115,8,54,252,182,254,209,237,68,13,236,243,224,253,118,253,208,254,93,0,52,250,136,252,234,220,79,7,165,6,113,250,135,6,245,255,249,250,44,200,80,2,16,4,146,253,146,51,108,253,55,206,236,244,216,248,153,13,10,6,235,0,122,253,84,8,166,253,87,9,254,5,15,14,188,236,216,254,193,248,229,247,170,245,37,255,248,215,137,4,67,23,42,27,149,35,170,13,212,232,5,249,117,1,210,4,220,4,211,252,180,255,123,35,0,236,13,254,18,249,154,247,105,41,86,255,136,4,214,3,171,253,95,0,151,0,234,253,154,25,72,3,66,252,48,253,18,8,206,255,195,244,182,255,236,247,72,159,43,253,155,254,249,4,149,7,221,9,46,0,205,252,26,255,6,4,243,8,225,254,68,4,245,246,171,1,237,255,192,1,162,6,69,38,210,42,218,11,62,10,164,245,152,251,62,255,76,255,104,251,254,248,24,169,244,0,253,255,192,248,226,251,65,245,53,254,194,255,79,254,30,247,2,249,64,255,48,253,91,254,55,0,47,253,168,7,70,4,196,9,207,246,32,254,240,252,59,251,7,254,202,6,24,217,236,213,167,202,122,0,131,1,101,253,58,254,220,3,60,120,11,253,241,246,110,3,194,3,241,2,26,5,204,2,253,252,27,2,63,253,252,1,123,7,66,8,169,3,191,1,167,3,104,250,137,251,83,17,239,45,118,246,203,255,151,214,187,7,43,21,8,247,84,255,157,232,112,251,36,248,209,8,85,250,97,0,27,251,172,21,116,3,144,199,62,12,245,9,172,0,28,21,101,3,173,255,85,2,128,207,250,2,245,251,219,252,167,250,220,252,152,2,172,37,23,239,106,4,10,250,172,244,116,2,108,2,220,230,190,246,59,8,196,209,37,0,96,3,57,8,58,1,216,0,239,253,42,3,69,12,132,14,107,27,163,245,186,5,164,197,72,51,194,4,239,8,111,255,69,254,101,252,220,1,107,9,52,21,157,253,164,8,170,5,30,244,114,237,234,13,75,2,238,195,209,196,88,2,5,4,207,246,90,252,194,7,164,5,133,247,252,3,68,253,28,250,195,0,94,246,226,252,76,64,140,247,8,2,151,10,248,201,24,248,153,252,108,235,228,13,117,0,96,254,248,255,80,8,222,249,4,8,159,243,108,64,217,254,252,9,23,5,72,254,160,29,233,12,162,242,84,251,239,248,94,8,244,250,24,4,58,1,153,7,66,2,56,4,1,255,85,4,105,2,61,6,198,0,103,142,13,255,54,0,223,255,76,0,94,254,52,5,219,1,215,5,18,6,242,252,52,1,250,250,20,4,44,1,8,6,134,2,225,36,17,10,124,212,141,5,83,4,29,254,178,253,113,2,96,33,190,1,234,248,178,6,173,2,148,37,139,236,228,243,44,253,247,32,227,246,250,1,229,13,120,251,105,247,109,253,11,16,172,33,130,250,95,241,193,6,4,42,100,3,174,255,24,10,188,243,48,14,57,10,40,15,105,251,93,255,72,7,44,252,39,2,201,0,79,254,72,250,196,2,134,7,233,222,30,15,184,246,207,60,64,8,241,2,110,246,72,0,107,4,116,11,117,255,248,24,11,6,3,0,113,2,201,252,42,249,43,3,47,252,147,250,20,5,160,4,143,1,76,18,196,0,95,14,120,249,38,255,241,212,98,0,236,1,232,15,189,4,44,248,18,14,5,249,8,5,30,219,61,16,85,239,181,13,197,20,194,253,170,212,54,4,96,24,57,6,27,206,152,1,120,15,92,4,237,5,208,252,191,253,72,253,42,2,109,6,88,252,83,0,225,176,14,253,180,5,86,4,132,5,11,253,121,1,69,9,184,249,122,250,252,251,176,243,254,5,207,239,226,8,226,254,110,228,238,8,173,15,211,9,121,10,30,234,0,0,52,249,1,1,244,2,232,44,186,3,161,17,128,15,243,18,22,1,1,254,61,3,37,11,241,217,117,241,242,249,68,254,160,16,89,253,109,211,62,239,66,250,161,239,72,252,17,255,58,255,81,5,55,37,201,5,43,252,123,5,223,3,1,255,110,36,40,7,112,248,121,255,99,4,196,10,140,7,239,9,27,3,68,49,125,9,14,254,127,204,228,14,164,249,196,0,30,7,237,16,200,10,92,253,170,244,220,4,74,248,122,228,72,208,223,5,128,247,124,7,109,1,124,2,172,211,90,236,9,243,46,241,8,252,133,4,194,239,96,13,88,1,142,17,44,3,254,243,4,17,37,1,121,242,208,4,210,6,136,10,179,223,63,252,36,239,130,0,74,239,73,201,209,11,113,245,179,0,64,216,231,5,76,250,180,251,109,251,217,249,220,245,22,248,120,211,129,10,200,5,231,2,123,249,168,10,230,2,196,255,188,44,84,0,106,253,144,5,1,197,102,254,93,8,128,249,158,250,134,255,97,0,154,254,204,252,126,1,231,240,118,1,162,6,235,255,16,253,83,2,189,221,37,253,152,36,162,6,230,245,122,229,53,246,16,249,129,19,229,240,9,245,66,255,129,56,142,201,23,12,82,251,118,1,146,6,96,7,30,1,192,253,210,247,198,1,78,253,116,5,141,251,90,254,149,1,238,0,182,6,0,8,136,52,105,255,9,255,202,0,124,252,2,234,49,12,20,213,177,249,163,7,195,240,32,13,149,5,88,15,159,7,181,251,77,254,36,6,220,5,232,74,219,2,73,254,102,14,33,244,244,0,82,239,222,255,9,5,40,1,106,254,168,8,136,250,102,248,8,1,0,6,176,11,54,0,124,3,75,255,247,249,22,1,91,97,221,3,21,5,1,251,68,255,58,255,107,253,100,2,16,250,51,9,84,205,74,253,208,253,84,5,84,244,164,231,251,9,26,230,143,5,184,1,170,253,188,251,48,1,31,246,94,249,115,252,0,10,76,3,0,3,84,244,107,253,0,72,134,4,129,253,206,19,7,43,242,255,9,9,244,2,107,248,22,213,22,254,141,235,86,10,102,9,170,0,222,253,81,1,99,25,158,238,222,21,43,1,8,254,242,55,52,252,140,36,248,247,108,34,193,249,117,248,36,8,119,0,41,252,207,254,157,5,147,1,91,10,97,255,229,0,209,0,158,5,3,249,121,251,249,3,160,1,152,1,198,1,90,3,116,253,238,249,174,4,102,71,122,0,177,1,91,255,162,0,220,214,43,45,146,18,26,248,150,16,140,250,143,246,252,248,40,250,1,251,37,15,63,251,254,252,215,3,159,253,230,6,72,255,224,233,34,2,12,31,186,7,6,255,254,16,170,13,237,10,34,3,78,3,172,206,188,251,16,255,13,3,12,212,69,252,216,38,34,255,153,4,238,4,234,253,254,6,28,227,172,5,155,16,47,1,126,241,9,247,222,254,29,255,160,2,162,88,146,253,46,254,63,6,16,254,70,1,103,3,100,248,148,0,193,1,214,0,129,247,201,2,138,1,129,7,212,143,238,252,59,4,127,253,208,4,10,255,36,6,39,6,145,252,110,244,199,255,113,1,97,6,79,250,170,4,58,251,48,1,69,252,104,0,31,251,89,252,135,0,10,253,155,13,90,251,177,5,106,4,252,250,131,241,122,70,6,0,25,0,209,4,184,254,91,1,0,254,23,8,72,1,139,185,230,17,1,15,78,254,23,253,76,1,192,253,190,11,80,1,15,211,122,253,181,13,28,252,246,4,249,7,73,5,169,4,160,11,49,45,163,243,170,5,255,16,218,9,218,216,250,255,58,49,106,3,6,2,219,1,227,4,38,243,142,245,194,18,238,209,78,252,86,254,226,244,83,6,81,4,2,252,255,255,223,6,134,2,107,40,135,244,193,52,80,4,102,2,125,4,224,252,73,9,141,255,24,3,76,252,129,246,13,249,138,251,41,3,198,243,191,1,100,195,57,1,227,43,190,250,134,246,79,245,54,249,188,8,70,4,34,3,43,5,28,14,43,255,103,5,240,10,154,40,186,4,200,246,37,216,57,248,154,255,147,245,255,8,120,247,38,7,122,251,255,233,13,240,4,255,55,1,100,2,181,254,30,245,123,207,10,39,138,232,124,236,70,252,246,3,133,251,92,3,228,4,90,4,235,247,10,1,26,255,177,253,166,238,230,0,123,80,106,5,106,4,68,250,240,241,120,8,68,3,38,249,1,254,226,253,216,0,26,0,148,13,141,4,59,239,26,12,11,255,189,253,38,7,200,8,206,20,75,184,141,1,90,21,222,2,80,15,162,241,63,1,218,251,158,253,171,226,216,251,176,5,159,233,64,4,139,35,218,8,241,0,201,0,223,216,247,249,17,245,211,5,218,105,196,255,56,249,107,5,91,3,62,250,177,255,158,251,53,252,234,250,138,3,147,251,157,245,216,254,64,5,118,245,64,254,60,250,44,255,207,249,30,5,17,56,139,247,75,247,112,253,99,20,62,243,198,248,6,31,133,19,9,247,7,2,96,2,230,218,92,249,234,6,52,196,6,5,158,244,204,8,51,253,88,8,174,9,93,241,58,9,251,255,19,255,30,9,189,2,250,252,96,253,236,255,169,253,111,2,68,253,55,253,45,252,26,139,190,251,80,3,115,255,249,4,57,253,246,6,35,255,153,255,170,0,71,255,221,251,250,11,41,5,158,4,57,14,39,255,167,7,30,46,86,9,184,215,241,245,76,6,84,2,160,254,149,8,7,248,81,9,126,252,109,219,136,251,112,213,20,0,94,225,233,251,103,14,99,8,24,10,7,255,184,255,255,127,144,7,190,1,135,252,179,252,128,252,245,4,192,1,71,1,173,242,4,0,190,2,148,248,122,253,31,3,254,252,150,2,113,252,168,252,31,1,131,6,148,255,192,255,16,0,42,6,245,247,65,149,112,0,68,255,200,9,76,253,250,0,104,1,52,2,100,3,51,16,60,5,160,70,0,242,189,1,108,1,193,245,100,254,154,244,140,255,51,10,164,246,212,255,182,42,24,250,114,251,239,0,145,3,190,0,167,198,1,253,50,10,115,11,171,246,6,14,112,249,143,24,237,253,152,253,37,5,246,251,124,252,103,3,183,254,211,1,176,4,134,248,84,4,78,12,34,229,32,2,181,199,247,10,51,21,49,52,168,5,39,249,12,2,37,233,187,5,182,248,232,26,218,221,92,5,21,250,19,19,56,247,238,251,20,18,16,42,149,0,154,254,249,250,247,250,255,127,143,251,173,3,192,247,195,1,100,250,174,0,38,1,219,1,173,241,74,6,105,6,169,253,114,2,10,8,159,2,90,6,39,252,133,255,248,7,165,1,5,7,16,72,234,9,153,254,78,236,24,12,144,251,192,254,31,7,30,0,30,209,239,250,174,252,94,254,39,250,31,249,209,19,192,42,212,0,151,237,178,249,40,249,169,247,227,1,19,4,59,248,219,254,39,0,231,251,67,0,198,226,200,2,18,235,128,3,172,48,48,249,255,248,2,6,249,13,250,255,162,1,184,255,48,4,87,5,56,4,236,13,188,5,226,1,238,250,214,230,213,254,122,205,11,253,153,239,2,15,189,211,64,251,50,255,62,6,145,251,88,243,222,12,226,254,228,253,9,3,164,4,91,251,164,17,78,10,23,8,230,37,124,252,234,3,19,73,63,253,192,248,161,4,32,237,98,249,82,242,236,246,246,244,8,238,204,7,218,243,110,0,117,0,149,1,42,190,2,254,123,198,163,6,130,7,187,247,98,245,45,0,40,4,251,1,11,249,58,8,250,246,215,4,228,22,50,9,80,31,240,48,77,252,164,254,224,6,6,8,136,240,179,247,6,242,92,15,111,6,12,243,165,23,136,1,200,243,137,12,115,246,207,1,237,244,237,249,235,4,40,1,71,250,47,7,53,237,164,1,41,255,213,1,11,252,240,254,185,0,75,150,126,251,8,0,42,1,3,1,71,252,213,253,216,1,105,2,153,251,95,253,214,3,114,254,111,249,72,1,114,3,102,2,32,3,175,1,84,0,112,3,16,255,142,61,12,200,21,5,42,6,164,3,74,253,80,250,131,9,141,249,184,5,227,0,247,5,15,2,128,255,186,2,101,9,42,253,209,5,248,3,146,7,151,248,58,250,18,255,164,3,203,9,249,253,133,251,45,2,30,9,188,2,142,205,13,58,158,0,255,0,171,4,141,252,31,13,235,251,47,8,8,2,249,0,158,3,21,3,112,5,71,255,138,249,134,3,9,0,138,247,132,248,31,2,178,247,26,11,180,254,76,5,168,254,180,1,108,254,82,255,23,254,90,3,2,1,229,0,211,255,71,1,196,254,104,251,58,254,115,0,36,255,54,254,62,255,15,1,238,253,36,6,194,253,20,158,167,0,89,2,253,251,87,249,184,243,121,239,156,249,12,252,22,252,249,253,199,252,54,254,177,3,34,2,193,0,11,186,100,255,213,251,58,3,82,1,128,4,50,2,6,254,80,3,239,0,188,0,144,2,97,0,82,255,197,255,242,0,154,7,189,255,233,2,251,7,168,1,64,255,62,2,244,253,17,6,54,2,200,5,21,253,231,1,113,175], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+348160);
/* memory initializer */ allocate([104,3,191,251,10,4,77,5,151,3,153,0,154,0,242,1,54,0,43,2,35,252,195,2,171,255,235,255,188,2,112,250,90,0,143,2,113,254,123,0,59,253,117,0,182,1,74,1,48,253,190,0,44,3,118,255,204,1,0,128,94,255,102,254,185,254,134,255,72,251,214,253,10,254,78,255,203,254,117,1,199,16,79,252,130,234,64,245,41,230,39,251,254,4,221,250,253,225,38,252,93,254,206,255,80,9,224,237,154,231,228,209,204,254,66,254,158,13,40,237,200,6,178,253,192,3,195,0,81,2,164,0,27,13,119,6,209,4,66,0,237,252,165,254,73,202,74,0,71,251,212,252,254,239,154,255,142,3,133,249,12,248,181,243,229,247,211,245,40,251,147,17,191,6,244,218,37,2,216,2,83,13,166,7,169,238,216,251,58,22,192,249,64,248,159,6,180,253,207,18,118,255,204,242,0,254,17,6,186,7,214,16,38,253,110,254,60,3,76,8,136,55,34,255,197,10,18,222,11,2,212,9,249,3,22,3,120,255,42,254,4,255,51,253,40,3,167,251,198,53,142,255,98,251,237,11,138,235,73,247,184,6,1,254,37,252,56,6,23,251,238,245,241,6,51,4,63,9,29,255,26,9,96,253,196,245,87,250,74,8,106,1,225,4,58,5,185,254,129,171,252,249,24,0,204,246,112,253,189,7,164,255,49,255,116,247,34,0,55,254,245,250,207,4,52,254,128,255,116,254,81,2,97,253,23,250,136,0,177,254,48,2,159,251,234,1,240,3,180,3,181,33,240,242,211,1,113,3,157,233,96,4,212,254,104,250,203,4,22,6,222,3,202,251,214,0,102,252,175,255,96,4,30,195,104,251,179,4,137,248,151,0,204,5,19,6,91,254,92,254,84,254,6,253,36,1,197,255,51,4,119,253,183,252,238,1,194,0,27,0,0,253,156,254,54,0,163,0,183,255,37,1,75,249,120,254,238,2,234,0,239,2,145,255,234,104,143,3,123,254,195,1,186,1,4,1,139,255,14,1,19,0,131,246,106,2,62,252,122,1,10,0,94,248,200,250,13,2,254,254,75,253,197,239,25,40,108,11,175,250,125,12,215,39,214,26,208,245,96,233,107,2,54,248,13,248,67,253,38,10,209,1,193,253,55,1,175,0,162,0,89,251,162,0,99,255,109,255,69,1,39,2,24,2,68,255,222,254,91,255,87,1,14,0,244,254,23,150,22,1,127,0,23,255,188,255,94,2,125,0,153,2,182,1,70,254,206,9,32,3,57,248,127,253,126,254,218,249,78,0,178,3,189,0,106,0,55,247,244,254,84,249,88,251,218,3,4,12,15,7,21,0,4,233,60,252,0,1,212,193,216,250,205,244,22,242,235,1,174,13,175,254,250,249,240,1,146,243,140,6,189,246,88,239,251,247,6,56,214,233,208,6,21,7,109,241,79,241,70,5,247,6,74,254,104,252,62,9,158,5,81,253,0,2,114,248,67,1,170,243,239,6,172,7,170,229,178,39,83,30,189,5,175,7,83,3,182,10,245,28,246,242,230,2,62,7,54,1,64,255,88,252,22,249,249,252,48,252,4,250,100,250,98,253,64,240,170,4,200,250,239,238,76,1,92,2,194,3,85,148,52,252,74,3,25,253,19,1,201,2,5,255,225,252,90,251,116,1,43,255,89,254,202,0,165,4,225,255,60,4,50,252,244,2,108,255,123,249,128,2,219,253,173,254,30,250,144,255,170,253,154,252,154,1,5,204,85,51,137,248,4,9,164,255,248,252,221,0,223,5,42,6,35,3,204,254,120,249,108,254,173,255,67,242,209,250,162,253,134,246,195,255,255,253,62,1,243,248,1,8,95,7,247,252,244,4,226,253,140,255,222,13,104,182,86,244,45,252,93,10,197,244,102,252,232,214,36,3,107,0,162,12,10,251,160,253,18,4,15,14,197,3,170,254,208,247,245,254,168,6,157,240,23,3,132,8,39,252,48,3,52,253,155,245,99,0,243,5,126,46,10,249,7,3,27,207,172,12,78,241,254,7,234,254,3,6,79,11,135,246,246,255,222,3,204,5,159,250,185,242,40,252,99,12,233,5,184,2,239,252,155,0,208,251,158,1,224,7,116,248,204,243,154,251,68,0,15,15,80,5,234,15,188,68,178,6,172,253,160,15,120,6,230,0,254,254,218,8,75,3,72,249,16,18,54,253,86,3,184,2,124,2,179,250,94,1,24,251,245,253,168,0,51,217,2,253,198,0,120,10,124,31,120,8,27,245,81,200,164,5,248,253,169,0,8,4,198,5,38,1,124,253,192,254,88,3,2,5,40,255,24,252,99,252,2,0,134,252,167,2,139,253,128,4,207,250,139,201,255,191,230,251,2,252,106,0,129,251,215,255,59,253,235,6,142,252,39,253,116,250,8,6,136,255,130,1,186,252,72,245,23,6,136,3,17,1,131,239,215,251,200,254,234,251,234,0,62,3,131,1,172,0,68,252,180,254,104,1,152,1,125,0,90,0,92,1,147,3,248,254,143,3,7,1,124,0,148,253,156,253,220,0,164,0,202,0,124,0,212,137,97,255,238,3,192,254,27,1,151,249,224,250,159,220,149,21,96,29,188,244,94,208,211,10,116,251,50,7,237,4,186,253,254,2,194,9,137,1,185,3,151,253,12,253,189,254,186,248,171,4,210,250,76,254,59,252,110,1,185,229,54,251,54,35,144,1,22,251,212,252,233,254,108,254,85,6,86,0,86,6,240,255,96,0,253,253,255,254,217,255,122,255,51,7,218,254,21,254,116,252,136,255,48,253,118,251,237,249,149,1,122,255,16,2,44,92,179,255,183,0,68,254,29,8,187,3,137,2,198,8,164,12,223,2,78,251,18,31,224,36,246,23,157,227,28,0,186,242,244,1,101,19,50,251,50,1,101,1,126,11,118,252,131,237,135,3,151,240,95,17,22,4,155,251,209,1,159,4,90,206,6,252,218,211,57,20,37,255,168,231,16,6,13,8,164,250,246,250,202,252,39,1,46,3,69,244,241,253,154,253,168,252,34,3,167,0,154,4,18,254,167,249,242,2,242,249,170,2,250,250,32,254,74,253,86,0,189,255,107,250,45,251,209,253,201,254,66,1,204,254,200,255,40,1,98,255,232,255,20,253,59,255,74,105,30,4,209,0,30,255,165,0,169,2,125,255,85,1,85,1,230,5,103,2,139,3,248,254,75,5,132,1,198,0,251,255,162,1,241,252,123,111,82,0,209,253,53,254,168,254,23,1,142,255,198,3,239,253,89,254,30,1,94,254,2,253,42,0,186,0,205,1,162,1,80,253,121,11,233,10,146,0,173,6,103,253,230,7,37,1,14,250,76,245,202,193,168,253,33,250,60,249,245,244,253,251,166,6,252,0,125,253,214,1,209,252,90,3,94,248,166,4,55,7,240,255,10,1,29,0,230,1,129,101,139,0,220,0,177,1,182,254,168,0,150,254,206,253,180,0,138,3,130,1,179,252,152,2,40,4,152,253,38,250,177,254,92,255,94,252,170,252,155,252,155,255,52,255,67,3,117,0,94,193,130,238,74,10,93,6,175,248,124,251,139,254,242,253,233,9,199,3,127,246,167,252,240,4,122,249,113,0,77,3,230,29,193,250,125,20,187,249,188,8,90,251,208,255,12,13,67,248,186,249,167,250,29,255,41,253,198,253,112,4,76,7,155,2,92,0,112,255,19,2,181,3,194,251,18,2,228,6,46,1,190,0,124,146,182,0,57,3,229,0,112,253,73,2,188,1,200,0,85,251,193,248,125,254,243,252,132,4,180,2,116,251,251,253,48,254,237,254,184,254,218,0,54,252,174,0,128,254,207,253,218,255,48,253,116,255,253,3,241,254,199,255,207,1,31,157,170,254,216,255,26,0,159,0,170,252,148,3,4,250,247,251,9,1,105,0,49,253,180,253,96,0,77,254,216,254,30,255,224,0,101,1,30,0,64,2,190,255,171,138,184,255,118,1,32,0,0,1,48,1,172,252,62,253,248,0,27,253,133,254,212,3,117,2,64,5,18,15,93,247,103,255,182,240,65,241,34,6,206,2,238,251,198,250,199,238,58,5,254,19,66,20,35,14,94,8,121,35,32,245,73,16,14,14,221,25,210,17,86,255,154,253,172,4,106,251,160,19,209,2,185,255,11,1,4,0,254,99,143,254,100,1,75,1,75,4,121,1,156,254,86,252,137,4,161,252,83,4,124,255,222,0,148,0,130,5,140,3,60,0,121,1,0,5,212,1,178,2,198,1,247,0,56,238,234,23,245,254,157,11,212,232,232,230,137,236,159,239,198,242,155,6,69,5,139,5,110,241,44,1,118,47,145,244,52,6,222,255,125,246,241,254,63,252,48,249,89,7,183,255,59,254,236,252,226,252,206,35,184,10,90,3,86,1,223,3,225,254,54,3,219,255,132,4,43,250,211,2,209,200,37,249,237,7,91,252,4,251,120,2,127,235,208,1,240,254,125,4,222,254,85,18,40,253,61,250,73,3,10,0,229,254,92,0,244,254,217,254,102,1,160,0,149,1,2,0,131,254,167,2,204,2,66,255,128,0,19,1,255,0,123,0,100,254,59,254,239,254,26,0,82,255,172,254,132,2,136,254,192,107,231,255,66,0,35,12,85,249,143,3,244,1,251,251,5,4,235,249,60,35,114,254,48,246,186,253,107,4,200,190,83,254,252,250,253,255,16,9,236,253,210,254,82,255,110,255,99,254,104,8,241,3,42,0,146,1,65,250,157,0,110,22,242,252,27,255,75,9,134,2,26,11,16,249,49,254,67,245,223,241,82,249,7,208,202,253,7,1,154,243,223,246,118,37,130,251,161,9,225,17,16,8,120,253,129,247,171,248,94,253,134,253,174,254,87,1,44,250,110,3,238,253,48,4,102,53,66,238,234,2,232,37,164,239,92,228,155,4,28,253,179,253,148,252,12,1,200,251,38,252,24,238,132,10,216,11,237,247,230,0,51,242,176,3,170,236,140,248,172,5,1,255,70,253,180,5,162,253,6,255,102,255,225,168,79,252,90,6,180,253,30,254,243,249,127,255,210,3,137,253,46,253,70,4,235,6,201,254,20,2,4,254,184,2,152,251,246,4,86,3,172,255,194,16,158,1,23,13,37,4,163,3,136,244,122,218,221,255,210,9,185,251,55,2,60,254,184,222,197,15,81,254,184,10,28,247,87,10,92,251,58,254,112,254,142,241,197,254,38,45,101,253,0,2,162,0,117,254,41,205,245,255,104,248,134,252,234,199,246,240,56,239,30,5,188,253,8,255,25,5,146,1,231,251,115,0,37,8,251,248,108,251,191,254,105,252,199,254,0,254,125,255,83,6,64,2,243,1,24,248,130,0,14,0,180,255,76,231,239,1,141,9,139,190,212,246,110,245,142,248,73,9,52,247,149,253,237,245,131,2,107,253,4,251,167,3,125,3,224,3,100,247,109,246,117,254,4,254,139,4,40,255,22,205,50,253,6,252,117,249,70,253,198,2,255,254,98,10,154,4,254,7,34,247,228,245,150,199,138,251,254,251,199,8,232,253,58,1,123,0,105,251,95,253,40,6,216,245,5,0,196,3,107,2,78,249,37,198,34,250,146,249,129,251,163,255,124,210,34,255,87,1,101,247,161,254,96,252,223,254,119,10,53,8,230,2,235,2,59,247,146,0,220,248,88,245,34,4,24,4,230,11,242,0,80,17,246,0,94,1,149,203,0,3,219,252,27,7,252,55,36,5,142,254,135,1,115,250,110,250,157,254,212,252,192,255,196,0,155,244,73,4,242,249,34,251,180,1,194,255,211,252,70,5,43,2,68,247,203,249,212,3,53,250,138,39,126,246,68,28,135,196,233,5,42,8,56,251,173,255,251,244,152,2,146,2,86,243,249,251,229,5,107,10,96,255,221,250,36,4,123,3,176,1,225,250,57,246,24,5,15,5,209,6,46,253,64,246,199,238,224,242,40,245,23,245,199,236,72,49,249,251,69,254,215,5,144,246,224,237,156,17,128,244,48,10,43,5,118,254,97,254,193,247,239,247,6,4,204,241,198,250,100,11,65,244,160,241,176,243,141,255,65,2,182,10,17,3,179,238,103,248,208,254,237,236,123,255,192,243,121,248,192,253,106,2,244,6,8,10,202,247,98,255,110,240,93,251,24,1,143,2,162,0,184,250,158,233,12,60,222,250,17,6,18,1,199,244,125,16,2,18,209,239,125,202,200,10,25,251,18,255,207,5,47,6,142,5,32,247,126,18,32,231,27,3,106,254,218,5,52,6,12,254,72,245,149,252,32,8,109,7,192,3,88,1,211,3,254,254,184,3,222,9,247,209,125,3,157,2,81,5,6,2,168,250,14,15,235,9,111,2,213,248,175,239,126,10,116,244,12,245,97,4,70,221,97,5,101,4,106,240,140,0,10,14,221,6,223,8,110,1,187,6,102,8,245,52,24,249,103,250,24,230,190,253,194,12,205,9,230,27,168,2,252,5,38,5,157,251,36,22,3,5,100,254,228,234,77,11,169,245,121,245,124,250,84,1,118,253,95,3,103,7,51,11,128,1,114,2,88,3,252,1,85,5,217,254,192,3,32,154,234,0,252,255,239,0,100,254,250,255,3,253,224,2,226,255,136,0,144,3,26,2,232,252,157,1,103,3,75,254,49,1,30,0,62,255,81,4,167,251,222,13,10,237,193,1,219,253,54,226,122,14,142,241,242,6,161,5,192,8,73,0,1,2,201,242,214,246,164,250,115,15,157,11,151,4,57,232,207,19,169,247,104,33,97,19,79,251,78,250,189,245,38,253,3,2,12,253,220,1,176,251,67,8,4,251,242,1,80,1,61,254,41,3,250,251,44,2,45,255,186,255,163,255,89,0,13,253,40,1,104,3,230,254,124,1,214,254,214,10,148,2,59,5,223,253,173,1,254,202,240,219,95,253,11,1,205,252,97,6,223,255,111,2,174,252,232,238,145,251,231,3,250,254,136,7,183,2,41,249,23,245,4,3,200,19,122,251,24,1,160,247,33,5,120,3,78,246,213,1,180,11,130,250,237,48,80,251,78,251,171,3,253,255,79,3,50,3,100,252,135,0,228,250,32,209,224,253,176,253,182,240,185,1,44,13,116,12,34,5,212,248,62,253,180,252,217,250,5,4,38,249,172,0,164,9,121,252,135,252,246,198,250,247,174,45,68,248,38,253,131,249,214,0,219,4,175,254,122,253,161,255,152,5,170,252,20,255,88,0,254,255,2,2,149,249,172,255,233,13,46,1,2,3,32,251,224,1,152,2,226,2,192,6,9,249,77,247,66,253,2,242,255,190,177,6,226,5,148,2,89,246,13,8,208,255,167,243,161,6,132,3,59,250,46,2,31,1,117,234,255,3,76,248,231,3,192,248,50,244,28,255,199,2,246,4,84,10,120,253,40,4,59,15,75,251,14,253,56,4,238,4,18,0,92,3,226,8,143,2,238,1,35,255,225,194,54,5,39,254,144,249,171,254,213,13,37,12,121,249,127,2,69,246,185,0,221,1,124,254,78,20,208,233,44,3,188,2,132,8,232,253,244,179,52,246,32,10,85,11,32,0,115,251,220,5,90,254,234,252,134,248,203,3,111,0,202,4,234,250,29,2,234,240,192,252,130,2,49,1,226,240,217,34,58,2,180,0,198,6,220,249,133,252,8,69,12,253,190,2,180,10,121,253,74,8,102,0,165,250,205,1,198,1,204,0,205,254,32,251,230,246,73,5,9,249,109,248,167,253,0,2,70,8,126,247,254,0,166,4,28,251,155,3,142,4,104,1,64,1,64,1,186,4,114,255,96,254,236,4,51,255,123,5,255,251,52,75,72,1,58,0,21,0,236,251,250,6,105,8,185,2,76,254,175,249,155,252,19,254,141,246,226,243,203,7,239,5,249,248,103,255,129,10,103,253,165,250,109,252,54,72,173,3,204,245,223,251,52,4,233,242,208,255,58,250,63,2,216,2,130,0,88,255,40,0,130,3,93,8,238,5,59,252,138,248,128,3,70,3,196,4,160,1,42,250,124,5,130,255,224,83,92,2,204,6,102,0,212,252,228,252,34,253,58,4,5,254,44,254,60,249,147,4,252,0,103,1,180,1,3,253,23,3,214,2,214,252,46,7,250,248,30,22,198,246,251,4,243,244,55,240,118,5,121,10,224,1,172,53,16,253,204,8,26,5,254,251,42,7,54,0,9,39,47,2,90,5,199,2,126,7,35,249,134,2,16,0,66,243,116,10,215,6,221,245,174,18,230,251,97,9,229,196,76,4,130,1,196,2,153,254,199,1,231,255,74,252,241,0,30,254,12,1,23,9,50,245,114,255,56,248,202,253,220,255,222,3,98,231,173,12,142,250,213,249,248,2,11,253,189,247,162,222,127,244,224,252,69,240,226,243,217,250,59,248,5,249,86,254,78,2,7,4,211,1,31,0,114,10,150,6,240,199,150,4,90,250,211,252,13,251,103,11,4,8,218,249,15,253,41,13,190,251,246,14,250,7,112,44,116,4,127,3,106,4,48,253,252,250,27,247,49,0,44,253,141,1,145,51,39,252,63,6,147,254,237,5,16,254,210,3,104,8,111,5,241,6,216,11,88,252,24,1,183,6,57,238,10,19,83,252,96,255,188,3,92,253,27,255,220,253,183,0,34,191,169,252,151,242,224,4,190,253,206,8,236,253,9,12,130,250,189,248,163,253,17,7,23,252,142,255,58,251,50,15,159,253,42,12,130,246,162,247,184,1,244,6,70,6,141,239,23,4,56,254,88,32,9,0,234,22,74,249,92,252,7,205,206,253,25,12,185,253,235,255,76,248,230,4,84,255,15,2,234,8,200,19,241,234,50,4,101,1,53,7,24,0,28,252,100,0,206,255,74,4,89,11,95,254,87,252,73,254,247,0,70,72,180,246,216,247,110,254,188,253,83,0,230,254,186,255,201,3,28,2,37,255,148,251,91,249,61,255,42,244,68,245,74,248,232,250,139,248,56,4,18,4,100,4,128,255,184,22,255,8,24,11,140,246,35,0,166,64,209,2,225,247,47,250,255,3,114,253,233,7,199,5,71,255,111,246,244,1,218,11,103,10,71,15,179,4,230,3,82,2,235,253,93,255,250,254,227,2,13,0,86,254,182,0,138,1,94,1,153,138,141,254,150,0,82,254,147,0,158,251,43,0,122,254,42,1,63,3,62,255,158,0,142,255,255,254,190,250,183,253,206,0,56,254,222,1,10,254,82,249,73,249,187,253,232,253,45,0,163,252,57,3,69,4,1,255,83,253,38,0,236,255,163,1,174,253,10,0,128,250,242,253,9,181,196,0,40,250,255,0,52,7,201,221,19,242,15,252,98,252,206,252,85,251,236,0,82,11,74,255,8,56,152,250,40,4,157,4,202,248,31,2,185,253,170,0,23,243,93,251,154,246,216,255,229,251,209,251,228,255,202,5,220,251,223,251,212,11,25,248,145,3,28,4,212,3,218,235,34,18,13,201,80,15,170,5,111,238,201,249,74,3,82,247,120,254,214,255,38,242,254,254,18,242,35,10,225,0,120,245,16,18,235,8,203,5,30,250,116,8,151,0,124,1,121,243,194,251,158,214,213,7,75,9,249,245,99,252,149,254,19,251,118,51,183,255,144,4,167,8,71,249,214,2,13,2,24,4,66,1,197,252,69,8,50,15,66,5,72,242,195,8,126,2,211,8,165,250,44,247,94,41,83,3,33,251,130,252,79,7,142,252,93,248,238,14,186,241,62,249,138,3,26,8,220,253,117,3,59,246,220,250,53,243,58,214,239,7,53,4,197,11,175,251,135,11,115,7,194,4,194,0,68,7,130,249,178,0,147,3,68,4,41,3,61,254,158,253,40,253,31,3,127,255,155,255,119,252,254,255,166,9,12,5,119,255,32,2,149,182,199,251,212,254,197,255,26,1,183,254,224,253,212,250,107,8,110,36,206,1,124,254,209,254,132,244,160,253,172,202,20,2,186,250,254,251,50,5,183,21,179,254,97,19,195,2,216,248,46,4,179,9,32,248,197,254,149,8,81,3,164,254,123,1,125,247,181,194,135,3,120,12,48,15,140,1,2,18,189,12,227,245,217,236,125,253,20,14,156,250,244,5,149,247,213,1,56,242,234,252,173,1,234,240,5,7,152,255,60,9,118,251,233,249,243,3,57,7,21,255,96,248,216,247,156,5,198,9,234,240,88,249,245,197,209,244,198,2,112,2,21,17,98,231,152,253,217,252,215,249,68,246,148,253,107,252,180,3,93,19,176,252,161,252,2,2,94,247,114,8,15,253,192,196,236,247,184,48,205,245,45,253,237,10,131,222,34,247,210,3,219,245,167,8,84,253,231,9,42,12,251,254,78,255,81,9,251,236,137,4,224,255,67,250,26,8,129,250,154,12,32,252,194,17,170,243,20,4,207,1,91,235,4,0,140,250,141,250,234,6,25,249,164,252,250,255,62,247,244,249,101,253,75,2,42,252,58,247,224,250,14,6,226,253,182,20,52,253,135,0,233,193,54,13,34,254,255,4,103,2,37,13,84,6,187,206,26,255,29,12,158,12,229,250,44,11,116,2,135,2,245,241,42,255,161,249,223,10,236,2,64,4,199,255,130,232,192,9,103,1,207,2,196,5,18,253,148,249,179,247,73,15,52,241,53,2,162,251,125,250,97,5,4,252,10,255,163,73,98,250,130,251,44,250,87,253,226,252,248,252,192,3,143,3,87,250,80,1,166,251,193,247,147,252,236,253,156,2,250,3,74,4,152,1,240,7,161,253,112,253,147,232,17,12,158,9,64,184,253,251,78,0,30,240,183,1,179,252,196,5,34,1,234,1,60,254,102,6,203,242,80,0,163,6,202,1,4,1,191,4,252,253,91,7,194,255,35,0,20,246,89,249,238,251,215,6,90,254,198,4,207,0,152,255,88,4,151,0,39,254,246,253,58,103,50,2,116,3,103,247,231,254,238,0,185,252,13,4,180,253,81,0,147,255,254,255,224,255,75,0,142,2,233,1,12,2,124,254,128,250,118,252,87,251,88,252,239,254,216,255,156,255,106,253,246,253,111,255,119,0,102,2,102,252,15,157,76,255,100,253,194,253,161,0,64,254,173,0,238,2,159,253,212,252,131,255,46,3,60,2,42,10,148,79,244,0,28,7,212,2,3,2,164,3,246,250,56,253,34,252,207,254,243,255,5,253,123,251,225,1,4,253,64,1,112,2,148,253,130,2,42,250,200,253,167,253,113,253,234,252,188,250,78,1,234,250,126,1,14,3,158,251,127,253,3,164,180,0,207,1,134,253,102,253,87,2,156,254,209,251,48,3,192,253,184,4,144,3,135,254,112,2,25,4,42,0,161,255,114,1,140,7,89,255,237,254,142,0,97,255,102,254,83,2,206,253,136,253,236,2,168,4,102,2,215,255,238,255,100,255,195,255,0,5,82,253,107,1,247,2,244,2,94,180,154,253,103,8,95,251,169,0,71,1,214,5,14,3,223,250,122,255,73,3,218,0,180,255,92,244,202,0,80,0,25,1,89,0,195,255,114,249,59,0,131,255,195,0,64,1,226,250,200,255,38,3,47,0,191,255,249,0,0,72,102,253,6,254,52,255,62,255,208,253,96,254,199,241,74,1,244,254,74,3,104,41,80,255,168,1,48,249,231,241,110,249,180,252,203,254,230,253,179,1,171,55,255,250,117,1,188,10,66,253,178,250,2,253,152,13,89,253,199,15,17,2,190,233,218,255,211,252,179,4,126,18,62,1,236,251,11,236,139,8,110,242,159,1,132,9,51,244,164,249,56,254,85,250,78,13,250,248,233,3,56,222,212,1,164,4,241,1,20,18,76,252,23,240,138,209,66,245,30,253,240,5,26,240,214,252,133,233,166,250,162,11,108,17,149,3,197,4,188,254,114,251,35,9,59,251,0,248,202,2,228,26,24,12,86,27,13,0,237,254,217,240,22,3,104,0,103,5,8,8,165,7,0,220,82,254,57,255,5,1,252,2,147,255,46,255,27,3,116,3,178,254,10,6,240,254,221,255,226,2,244,254,243,255,64,254,133,2,97,0,76,0,4,5,169,254,114,253,112,0,131,2,62,89,122,2,171,253,147,253,240,252,132,254,183,3,60,254,83,253,140,0,176,2,254,252,247,0,89,253,28,255,24,151,55,1,222,253,68,254,94,2,69,0,61,255,18,0,36,255,178,254,214,255,31,2,228,255,236,1,254,2,208,0,74,251,214,253,213,0,168,251,117,249,160,253,126,1,219,7,213,19,222,187,87,5,66,253,168,252,96,254,64,249,61,248,150,11,96,248,38,0,152,0,200,2,210,0,179,253,213,11,91,251,32,248,121,224,250,41,161,247,212,253,84,248,162,0,8,254,227,3,214,3,251,245,134,253,39,252,124,249,188,1,206,247,101,254,232,1,117,5,146,251,96,7,104,252,233,254,209,58,11,253,22,251,32,244,134,252,151,255,98,253,22,254,18,255,141,246,234,250,147,3,240,252,95,252,117,6,167,255,52,4,189,1,234,9,112,250,231,74,165,255,181,1,240,2,254,0,167,3,86,3,126,249,170,255,225,253,29,4,152,2,101,255,27,254,102,240,206,255,50,0,198,255,190,245,9,7,198,254,76,193,217,248,241,3,40,9,42,244,86,252,225,6,253,250,106,255,87,254,252,229,124,252,94,5,35,3,37,2,133,245,69,3,227,1,113,253,2,18,235,4,211,255,66,3,79,4,78,243,236,241,190,244,97,246,45,235,48,44,139,249,79,242,193,248,158,236,131,33,66,9,86,246,245,1,254,250,217,3,100,252,124,13,200,1,14,255,38,15,209,247,178,11,164,27,53,254,14,10,244,62,85,32,168,255,60,2,218,255,0,0,128,6,215,253,28,7,208,247,52,4,159,1,92,254,108,7,96,249,126,255,42,1,237,249,201,0,108,254,217,248,92,252,76,3,134,37,15,254,80,192,206,12,150,3,245,253,219,249,184,9,211,252,147,0,4,6,211,14,110,5,37,4,178,255,246,255,62,2,60,10,137,251,0,254,186,253,40,250,224,2,29,239,18,3,199,244,194,250,92,15,172,56,91,49,125,252,194,6,95,253,130,1,92,253,227,10,36,245,112,244,119,1,219,1,116,247,202,8,83,3,20,3,12,1,240,4,157,11,162,255,38,4,238,3,71,253,157,2,133,253,38,252,16,237,50,250,250,255,182,240,123,24,232,249,8,0,9,254,153,20,39,242,69,0,42,59,215,8,46,250,220,253,204,6,100,6,132,252,129,252,1,3,41,254,226,0,97,25,94,246,11,248,212,251,51,4,122,252,100,53,67,251,136,48,61,242,132,255,190,251,204,3,146,251,18,254,248,245,113,3,247,243,113,1,2,255,150,253,110,252,187,1,26,251,146,2,42,5,34,2,242,255,10,3,140,255,134,254,222,252,244,254,48,0,116,4,86,101,247,1,131,253,153,252,26,4,42,1,69,255,131,1,106,254,87,1,212,0,110,0,211,2,183,2,209,255,206,255,200,253,190,255,91,1,204,249,20,0,189,2,27,254,158,255,237,252,150,17,22,4,164,249,34,246,185,0,248,3,0,255,68,253,109,254,102,255,103,0,16,253,79,253,36,8,73,250,246,8,104,1,182,68,70,253,18,251,20,3,116,0,243,2,239,2,72,254,158,253,43,254,211,4,246,246,216,4,204,254,41,2,41,4,122,95,35,253,155,2,4,0,28,254,93,0,249,254,151,254,234,254,12,250,176,0,31,5,25,6,179,1,76,254,201,251,4,1,146,254,216,1,231,251,135,2,158,0,46,1,93,252,220,255,34,252,224,2,68,254,53,4,232,249,5,255,148,0,232,3,72,4,212,254,32,255,205,254,18,187,39,0,206,0,74,0,249,1,21,244,251,250,231,252,44,253,206,2,68,1,35,3,106,3,174,23,69,247,7,243,218,253,48,36,155,13,180,239,72,240,41,254,90,3,122,10,202,251,126,248,40,8,111,4,146,252,33,2,157,8,68,3,192,251,35,2,173,48,174,8,196,252,255,240,189,18,200,246,50,246,67,240,91,247,168,53,8,4,66,252,103,7,8,1,37,250,238,247,15,255,44,5,32,255,232,252,8,3,82,8,40,10,28,247,113,239,188,12,74,6,172,249,60,251,64,245,211,3,20,248,170,76,158,247,172,2,39,253,21,255,223,254,76,2,168,253,245,0,145,252,208,252,157,1,169,255,122,251,10,255,69,0,202,3,145,255,244,1,73,4,63,4,118,255,180,250,30,0,78,254,60,254,238,166,177,0,236,1,206,0,255,254,170,252,165,5,37,0,104,5,97,0,254,254,43,3,34,255,53,0,36,2,208,6,124,0,249,251,52,4,186,0,197,1,83,255,156,4,69,247,71,2,120,254,250,249,42,253,121,11,205,241,168,252,166,5,116,30,37,245,62,252,27,247,115,6,168,7,76,250,3,251,190,217,224,254,155,9,46,9,39,246,84,0,66,2,238,8,224,1,84,6,21,25,56,255,170,0,233,5,198,0,23,252,21,254,24,252,161,0,30,254,95,2,214,0,231,2,220,254,118,254,64,255,92,0,73,0,97,254,196,254,81,2,214,255,166,254,200,1,44,0,182,3,129,0,67,255,38,3,35,255,143,246,15,18,100,11,95,239,120,0,173,215,174,4,244,215,139,255,63,34,88,12,19,9,138,4,118,253,189,8,181,239,82,9,176,1,91,6,169,227,38,0,124,0,182,241,234,249,65,210,10,0,210,31,164,6,73,248,165,190,93,9,32,4,58,246,156,245,85,245,83,246,208,5,196,4,16,19,124,251,13,7,253,255,63,244,167,231,88,247,112,13,246,243,76,8,70,0,99,246,101,4,127,7,173,46,54,246,146,253,161,8,66,253,125,10,223,35,2,254,10,245,151,251,225,248,46,249,240,241,250,8,224,242,41,42,78,249,126,6,194,255,139,1,62,55,251,254,112,255,88,217,217,44,140,252,107,247,96,1,186,254,59,254,64,248,235,7,70,250,218,12,94,0,153,13,229,9,49,17,116,21,219,14,247,0,128,252,104,249,162,243,106,4,155,251,75,248,66,1,99,3,112,248,202,2,144,252,8,0,9,9,122,91,110,249,91,253,128,1,164,247,126,254,152,3,37,246,17,254,42,250,211,11,61,253,148,4,133,250,129,8,167,247,139,252,245,251,155,249,119,1,148,9,131,241,109,251,21,8,71,4,111,248,82,253,68,252,242,7,82,13,253,243,153,254,170,253,220,247,118,72,245,6,211,255,120,5,212,249,132,204,159,253,160,250,183,243,8,255,29,22,230,26,181,240,62,255,148,38,41,4,39,15,66,249,187,252,108,253,213,226,17,244,188,13,27,1,188,249,143,253,141,4,207,11,5,250,223,248,150,5,207,253,143,252,66,5,127,255,231,248,83,3,0,128,218,254,68,255,140,255,122,253,152,4,118,2,135,3,161,1,73,246,96,1,235,252,59,2,129,255,250,247,192,247,162,1,95,6,10,1,242,254,106,1,51,245,82,251,74,255,2,14,8,251,190,5,190,255,48,184,50,251,55,3,147,4,70,5,77,4,130,5,110,241,255,5,155,255,94,243,11,9,222,255,54,254,81,5,143,191,34,252,158,5,238,9,87,251,74,2,84,249,129,10,181,10,122,23,113,16,170,232,140,253,20,6,190,8,246,23,32,244,135,244,140,8,132,249,113,4,36,5,166,245,137,3,10,254,163,255,103,251,36,131,110,251,224,5,252,250,152,255,168,0,55,0,150,13,95,255,2,11,28,254,224,255,0,250,194,4,170,252,161,254,113,17,26,66,169,2,102,16,163,1,98,254,168,26,190,240,78,45,75,0,40,19,94,5,64,0,124,245,81,241,249,11,139,250,54,255,165,254,94,246,96,0,11,4,3,253,254,254,127,14,157,5,182,184,54,2,208,3,179,9,4,0,184,251,114,7,161,14,195,245,60,245,72,7,208,253,98,0,53,3,2,240,229,20,89,5,131,235,134,247,116,11,228,251,92,15,99,254,112,254,230,121,101,4,95,6,43,0,4,253,130,6,12,3,244,7,204,253,64,0,31,5,54,255,75,3,18,248,88,3,230,6,165,243,122,251,142,253,60,1,127,0,247,6,126,7,56,13,185,244,3,233,227,6,46,19,8,255,204,66,50,244,168,248,145,244,249,250,20,243,25,249,194,245,76,250,6,255,13,14,82,238,178,3,3,250,35,4,248,255,217,252,253,250,156,5,80,212,131,2,142,1,227,249,191,7,196,255,122,217,195,4,66,1,60,12,5,248,114,4,114,24,44,242,22,3,101,252,172,237,135,250,173,10,42,221,41,19,37,24,192,0,82,0,186,251,4,0,134,253,213,250,207,244,12,4,204,5,99,246,87,252,158,1,221,0,131,8,74,254,249,4,126,245,10,72,221,10,252,6,216,8,50,251,188,16,156,237,166,4,54,237,49,252,230,0,112,241,200,9,18,14,160,13,88,0,42,5,231,1,149,11,109,241,219,246,49,23,97,33,180,6,140,28,57,35,26,25,215,2,152,15,24,238,132,1,130,14,140,4,18,0,189,1,229,4,142,1,59,248,200,252,82,254,233,2,185,234,128,8,62,248,133,240,45,11,194,0,75,69,99,7,8,235,76,16,125,0,18,2,50,245,155,4,145,1,223,6,183,249,2,122,142,3,76,4,12,4,76,252,179,251,154,253,232,6,168,254,72,3,72,253,182,252,64,1,92,250,0,246,129,243,58,0,132,247,95,5,70,244,203,252,161,252,192,208,76,246,91,253,174,247,98,17,240,13,136,243,166,251,110,243,49,12,9,254,194,21,207,253,56,15,70,41,7,244,48,245,118,5,183,6,108,245,160,7,114,255,169,18,46,252,190,8,108,233,82,254,204,4,238,250,149,244,1,17,171,249,192,246,164,244,180,224,46,17,10,254,6,2,204,228,110,2,135,254,174,14,198,25,86,17,193,26,240,225,214,1,1,14,210,1,184,198,110,13,114,57,104,248,16,246,239,252,69,14,250,4,187,1,74,253,176,7,85,242,39,11,166,240,70,251,240,253,139,7,9,15,252,252,157,245,147,17,216,241,228,253,147,249,75,252,130,254,211,3,83,2,165,0,173,1,176,255,12,176,16,4,32,2,241,9,110,236,182,247,232,244,177,254,107,254,148,1,206,255,76,244,202,4,7,2,234,251,161,14,243,246,67,24,92,199,26,38,86,233,110,20,216,243,226,5,157,14,152,2,122,252,197,0,172,9,222,241,248,7,214,251,34,9,255,254,236,245,219,254,180,10,192,253,2,8,159,252,174,241,214,247,217,248,200,130,146,2,13,6,66,6,192,6,234,253,134,1,19,250,141,253,71,240,227,252,209,246,199,10,154,255,14,10,200,255,28,3,24,255,138,252,103,6,43,245,239,3,62,3,248,22,84,247,250,2,6,241,207,244,97,254,72,2,86,242,62,238,20,193,88,1,24,240,39,2,197,234,215,7,118,250,254,14,130,249,189,7,217,13,144,5,1,3,87,8,169,6,28,197,132,253,27,1,58,13,97,0,232,251,163,240,204,0,88,222,212,253,136,244,145,16,236,19,241,6,98,0,207,2,58,24,40,250,196,2,112,8,164,246,220,15,233,5,205,8,210,255,225,248,124,255,197,2,12,253,80,252,63,2,46,4,209,249,75,2,1,160,59,248,106,3,200,253,16,4,92,4,94,240,124,12,10,11,117,0,54,6,152,9,170,3,112,0,86,252,12,251,192,19,221,244,179,11,255,9,191,204,74,223,9,14,228,229,79,14,254,2,235,2,248,3,103,252,193,8,106,248,173,16,16,243,12,252,36,9,221,10,215,240,228,9,72,248,100,250,109,243,164,1,72,86,26,253,128,253,198,12,166,5,143,7,255,4,121,7,97,5,31,243,17,253,113,16,228,251,77,9,122,11,206,250,106,8,224,10,140,246,246,4,30,9,242,253,200,5,77,254,158,8,252,0,2,254,6,252,67,250,242,250,74,252,168,1,34,4,243,246,178,252,255,174,171,248,88,0,81,254,12,251,116,0,134,254,234,246,43,12,10,255,30,0,139,237,136,2,36,8,206,55,207,252,192,9,101,248,251,236,25,218,225,5,84,246,196,247,235,2,63,254,186,11,168,234,254,253,13,7,255,9,190,9,238,49,48,251,59,47,70,8,156,15,32,10,34,4,254,1,152,250,22,244,229,9,104,254,99,20,228,11,170,12,71,255,94,10,117,241,16,0,69,249,31,7,0,24,58,237,182,0,236,6,233,18,6,64,160,255,201,9,223,225,132,235,12,243,136,229,168,5,66,250,142,16,38,1,121,3,188,246,119,231,137,246,47,21,71,8,81,11,98,5,49,3,31,252,193,249,186,198,198,11,187,242,218,231,11,255,33,19,252,19,237,8,209,244,150,4,159,1,135,229,23,15,135,232,142,237,137,255,94,2,57,247,95,17,40,4,113,248,145,10,187,245,136,251,52,209,221,14,114,3,98,6,70,21,52,239,131,2,108,13,208,29,80,2,230,3,162,2,169,245,36,18,58,229,88,5,110,255,189,242,103,41,89,5,12,15,153,6,133,9,159,240,77,13,213,9,103,7,244,200,138,251,10,10,179,39,72,6,115,246,82,3,114,249,40,12,119,242,66,12,61,17,75,248,201,239,139,4,30,7,21,241,224,249,105,254,174,245,168,1,109,1,241,241,164,0,88,250,38,4,0,6,54,6,66,248,200,0,140,72,26,255,130,253,27,251,114,6,232,8,81,19,175,17,207,246,136,239,168,14,33,241,102,14,48,237,78,9,15,198,26,5,94,67,29,253,220,7,193,13,193,5,100,250,234,5,114,255,51,254,14,4,158,9,203,3,74,5,248,4,251,6,116,9,102,252,36,13,202,8,241,1,69,5,235,10,0,128,169,1,82,7,184,255,157,9,133,1,206,254,100,251,122,253,251,0,43,1,81,245,65,2,31,4,34,7,84,6,66,251,142,5,123,252,7,251,193,246,39,251,110,1,9,2,79,254,55,0,160,15,219,11,146,250,201,9,250,6,219,195,157,1,228,232,22,255,231,13,136,229,52,236,203,8,36,0,76,255,84,2,112,22,110,246,4,251,78,237,176,248,24,0,252,0,208,1,17,11,120,255,0,156,223,255,105,3,86,10,191,5,200,250,206,250,236,254,242,6,14,255,73,252,44,6,177,255,166,252,97,252,42,239,164,253,144,29,79,249,76,252,192,0,252,254,202,250,164,251,63,253,126,2,132,0,162,4,72,252,133,4,172,1,247,7,32,6,242,6,181,87,114,247,128,8,138,6,100,240,14,5,138,4,18,1,159,1,195,244,208,1,249,1,206,248,214,251,63,247,7,253,221,254,8,0,37,252,152,255,28,3,0,128,22,5,215,252,59,2,190,4,199,1,174,2,144,2,40,249,118,3,234,252,132,2,166,251,54,9,188,44,210,238,54,5,39,51,158,12,230,248,213,15,58,248,187,251,110,3,212,14,152,10,13,250,51,251,53,4,192,3,226,4,181,255,95,243,202,225,223,10,238,32,185,254,108,250,105,249,4,240,13,1,89,12,199,253,13,251,238,6,212,10,15,248,171,0,248,253,15,6,135,14,220,242,36,255,112,7,254,250,40,248,206,252,165,16,138,252,255,180,130,242,34,254,171,245,215,245,180,247,119,240,144,11,27,6,80,254,35,252,122,10,198,6,131,220,6,18,154,238,231,9,223,227,36,255,218,216,81,254,29,225,121,3,70,218,253,25,250,2,221,248,254,22,94,3,212,248,82,254,21,192,77,22,83,3,22,7,48,1,181,19,149,6,20,252,244,19,208,232,185,243,172,3,40,7,242,254,94,253,161,5,15,255,150,12,217,253,78,254,187,255,0,242,93,1,182,250,208,208,55,14,99,20,159,29,1,252,30,8,191,12,81,233,151,252,245,15,223,235,217,241,76,254,147,237,245,248,126,231,255,247,9,255,212,9,130,7,220,39,146,8,218,249,233,253,144,2,102,6,237,243,132,4,97,5,60,251,92,19,35,255,120,19,126,251,251,17,174,249,233,233,233,245,182,52,118,246,128,240,14,12,74,4,167,249,43,202,230,205,99,10,20,14,66,253,148,248,76,242,117,231,16,9,187,7,249,244,230,236,64,249,2,0,206,238,75,254,140,7,56,243,37,11,54,244,72,3,136,253,221,229,28,254,107,37,240,3,157,45,2,245,19,248,112,31,110,251,58,227,152,245,21,13,39,5,120,251,184,248,94,2,32,6,52,21,101,237,90,246,97,8,6,7,10,254,254,249,104,241,160,250,50,5,17,242,178,255,222,1,25,253,122,3,224,252,212,255,216,248,31,249,2,252,28,252,178,252,164,4,238,251,126,243,121,246,66,6,17,14,52,2,162,71,239,255,47,5,125,254,50,248,20,251,24,13,81,3,84,237,140,7,200,255,65,10,1,42,116,249,216,214,164,11,6,6,153,4,215,243,165,252,10,2,20,12,116,37,66,11,68,238,130,250,193,235,50,0,107,239,65,14,92,254,228,241,86,235,129,248,223,56,211,245,145,4,39,248,8,42,188,246,83,1,22,246,124,17,185,11,38,238,170,243,119,242,57,11,138,2,205,247,76,0,142,4,67,250,47,245,121,254,119,16,138,253,88,250,252,248,219,249,26,23,39,3,212,249,24,8,99,0,68,2,73,244,55,4,54,255,20,70,47,251,211,236,55,4,134,1,133,252,42,7,149,247,174,245,89,249,64,7,211,200,33,8,106,12,80,246,10,239,41,209,254,247,22,4,108,9,180,1,22,4,13,247,74,249,241,243,174,6,61,252,134,248,161,242,46,24,42,251,19,239,115,0,202,214,74,245,105,252,15,237,222,5,18,244,24,243,252,8,198,248,33,9,13,230,203,7,1,251,18,255,226,2,132,255,25,53,252,0,112,250,91,255,226,10,75,249,186,252,20,212,37,213,122,252,254,242,236,245,81,245,85,255,201,15,155,247,198,9,70,26,30,253,117,239,112,1,0,24,74,249,84,222,160,248,112,0,230,254,237,255,30,16,45,42,98,2,231,243,103,30,98,244,246,247,26,242,214,1,230,232,82,40,236,255,85,0,140,249,223,23,138,250,53,10,149,14,124,241,138,7,27,239,81,251,103,252,66,254,71,4,238,3,142,3,237,246,161,254,40,3,0,128,18,1,66,5,105,0,56,9,96,251,201,8,54,252,153,0,108,12,27,5,159,8,62,252,161,8,103,252,224,5,139,255,193,247,106,241,106,22,78,31,76,0,30,6,197,11,50,254,240,241,99,15,254,18,14,4,216,16,234,252,86,254,136,249,20,0,184,214,11,231,59,230,134,16,94,11,200,9,110,244,0,1,46,3,24,254,56,3,157,254,246,13,158,248,159,245,1,253,170,10,193,251,22,246,62,242,29,240,105,24,230,242,99,54,230,15,4,213,95,18,141,3,176,232,149,234,110,239,244,252,71,246,240,2,254,239,46,30,80,2,241,218,212,7,62,1,30,239,77,27,234,242,34,254,44,239,231,7,241,2,87,228,162,240,158,252,123,24,178,233,52,8,237,222,100,0,210,237,139,229,175,16,232,41,98,45,104,4,189,49,191,5,114,234,118,251,145,247,110,254,136,253,144,237,228,255,124,250,243,251,129,3,38,251,57,249,184,245,124,242,61,13,186,253,206,0,69,1,13,246,46,0,60,5,184,238,160,203,202,236,240,244,174,5,79,8,252,4,244,8,123,240,98,243,126,225,30,2,131,16,113,10,214,222,122,252,81,5,138,250,62,248,33,252,88,253,90,2,185,244,211,253,96,10,142,12,2,7,9,122,182,5,79,250,90,241,125,248,179,246,33,5,128,255,84,255,121,253,194,253,21,4,134,9,126,6,247,1,32,1,255,5,8,252,183,9,204,252,84,18,239,10,51,131,166,0,137,249,112,247,132,253,77,5,199,246,53,254,40,249,222,10,219,254,112,255,108,7,173,2,230,6,108,7,165,254,120,238,78,2,147,3,30,3,109,4,114,238,148,250,75,0,116,3,32,51,168,246,167,2,197,254,160,226,62,4,33,15,225,12,212,252,142,253,29,219,244,9,239,230,83,6,28,28,199,255,5,0,10,14,126,248,184,0,224,10,251,254,18,243,219,10,174,0,254,10,59,252,160,244,213,248,169,1,67,239,128,3,209,7,133,14,7,3,88,251,93,87,81,255,242,5,57,253,145,251,3,20,251,253,102,3,227,16,73,2,75,254,4,1,55,249,64,248,218,9,21,246,51,252,148,221,211,192,70,18,245,239,130,0,104,225,116,4,232,10,66,13,76,253,247,239,213,254,208,5,222,4,92,2,236,10,73,241,67,2,188,0,248,249,86,0,168,1,180,4,89,17,24,252,123,59,131,13,140,242,161,249,127,247,169,13,148,6,157,3,56,11,191,240,97,22,135,2,145,3,10,253,221,253,54,2,251,6,24,3,27,250,151,249,98,252,21,250,140,255,242,4,225,1,152,240,110,111,25,247,201,21,2,4,242,15,163,253,184,2,70,4,34,254,100,22,79,28,181,5,241,5,22,255,214,255,146,252,14,1,214,253,118,14,185,255,82,5,39,30,49,1,170,202,135,236,208,251,4,248,195,26,182,1,13,223,155,3,231,253,231,5,21,252,8,8,5,247,38,195,247,1,152,7,116,12,14,9,225,6,10,5,238,246,200,253,201,249,70,245,82,248,200,217,234,5,36,234,230,15,75,255,66,244,145,248,16,255,137,251,137,1,6,250,202,252,8,2,221,3,192,249,210,242,178,3,166,2,86,0,91,248,155,7,164,4,100,1,207,2,198,244,59,247], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+358400);
/* memory initializer */ allocate([190,181,35,2,107,35,183,1,176,246,79,3,21,243,140,255,166,251,67,254,79,242,57,252,28,251,16,19,113,2,198,5,102,244,29,247,57,5,166,1,30,15,142,248,247,251,188,6,236,253,198,6,243,3,168,170,35,254,5,255,153,253,2,3,96,29,6,4,236,238,66,254,172,243,246,246,172,0,133,3,70,0,45,7,181,4,192,250,117,11,56,4,246,250,73,5,221,39,134,4,127,43,48,2,104,242,184,246,115,29,214,234,244,200,90,8,3,255,128,219,141,248,129,8,175,2,212,10,86,245,222,253,172,239,229,7,191,253,226,9,18,241,88,228,203,3,35,8,60,251,203,0,115,12,121,14,16,253,225,245,64,253,195,187,112,251,42,255,214,9,52,1,183,253,93,4,155,248,184,9,64,7,233,255,114,9,150,244,168,7,235,0,163,249,171,223,64,4,240,7,106,3,203,10,181,248,60,0,148,6,66,3,140,245,38,6,230,243,178,12,117,241,130,255,59,0,237,252,150,10,162,3,104,5,219,1,181,240,118,251,104,6,78,190,52,9,186,255,249,2,55,16,246,252,11,2,73,255,174,75,129,239,157,250,125,249,102,249,0,254,38,34,222,255,232,14,90,253,189,10,114,9,171,254,64,251,184,16,96,247,248,254,188,244,71,18,203,252,32,7,188,229,8,250,246,208,76,217,167,3,242,16,140,255,100,2,6,0,95,255,143,7,64,6,70,254,219,15,206,9,138,8,2,226,16,14,100,246,208,251,134,255,231,248,10,255,226,10,119,35,13,2,30,255,68,10,11,246,179,5,181,17,87,4,254,187,177,17,15,246,56,243,147,1,58,245,172,248,174,10,88,8,229,231,249,247,139,4,252,244,176,11,162,11,178,5,36,6,204,9,8,53,247,249,13,58,228,252,212,230,182,15,250,238,239,253,111,13,186,245,103,246,214,11,100,244,114,254,215,1,243,9,103,4,64,5,202,0,164,1,190,248,179,253,82,2,198,5,214,21,146,6,232,249,134,254,106,247,144,1,183,8,54,2,176,255,6,248,51,238,251,246,39,34,94,239,11,5,250,45,206,2,38,9,96,11,50,20,166,9,176,26,65,3,126,19,217,7,22,251,126,252,122,250,190,4,158,2,200,247,52,236,20,3,203,181,25,253,160,252,156,254,56,6,102,233,140,2,88,19,241,246,183,251,129,8,138,249,63,11,147,249,84,255,211,249,10,244,219,252,215,251,82,247,121,81,134,251,96,3,154,6,254,248,87,3,51,1,16,9,34,14,40,24,223,239,187,0,137,246,82,19,0,244,43,255,195,245,22,248,95,233,38,252,195,249,77,8,194,5,230,6,104,1,212,237,250,251,10,6,195,251,3,255,248,3,160,255,184,249,151,228,9,237,15,5,241,254,167,14,85,1,92,77,42,248,18,9,6,247,97,1,227,247,4,253,212,0,150,0,140,251,52,2,154,253,12,1,25,248,180,254,69,253,87,252,148,6,175,249,177,166,178,4,112,255,62,0,117,1,170,253,184,0,219,3,137,14,157,253,86,0,92,14,106,1,116,253,42,255,201,254,74,253,75,248,47,9,35,253,191,249,91,251,67,110,102,255,10,0,165,254,72,13,53,5,97,249,251,252,82,5,65,254,73,244,142,253,16,249,170,9,147,8,239,251,227,252,36,7,62,0,69,13,13,249,148,244,204,6,98,249,243,15,252,58,31,15,115,225,148,255,36,1,230,3,69,12,181,22,106,252,246,250,122,252,127,3,200,250,206,255,222,7,238,247,79,9,68,0,25,124,178,254,219,4,189,7,53,253,125,0,132,254,8,251,44,4,155,254,58,249,142,251,138,253,18,4,176,2,74,254,210,253,100,246,178,244,100,16,20,252,127,247,13,247,163,237,90,201,235,2,74,234,62,245,158,7,36,245,222,32,250,250,78,252,220,0,53,246,64,255,142,14,175,250,16,5,89,247,104,3,78,32,19,245,180,229,232,4,91,248,156,244,107,0,1,198,76,7,30,18,12,5,18,252,165,20,131,11,92,236,174,3,153,0,164,1,128,251,121,254,28,14,13,18,172,0,250,2,148,252,23,242,186,199,216,253,246,245,160,238,168,194,218,252,96,252,52,13,82,253,212,245,201,240,54,253,142,253,29,249,120,4,229,1,34,0,126,248,248,5,43,255,186,19,220,252,185,0,96,0,248,12,147,253,183,254,92,250,96,3,108,249,199,64,80,7,255,12,98,8,108,4,232,223,73,0,124,25,87,6,205,239,135,236,170,5,122,253,235,227,172,17,196,249,72,8,73,15,168,2,46,8,124,6,240,2,59,251,110,9,146,15,182,215,48,8,129,0,174,234,122,2,206,234,174,253,253,217,35,8,20,247,35,236,87,237,213,250,52,249,13,24,183,252,130,255,247,0,117,251,163,228,23,15,4,253,240,249,76,5,36,42,23,253,63,207,183,255,114,20,108,243,163,11,123,2,44,13,228,253,220,255,71,11,101,20,163,3,68,249,40,237,12,3,207,255,120,0,29,253,122,3,202,2,98,250,54,254,187,248,164,190,190,248,30,204,134,8,116,229,21,243,44,2,104,244,30,2,202,246,183,5,48,242,74,7,17,11,167,250,216,249,247,244,233,13,167,249,66,7,228,251,201,251,22,5,255,247,108,74,92,251,215,239,56,6,159,237,58,4,112,251,51,9,137,2,148,248,234,245,232,3,7,244,161,246,41,14,38,4,92,3,26,10,171,245,163,57,75,12,138,19,192,229,192,6,190,247,226,19,234,244,204,11,72,236,86,16,189,8,194,2,175,236,170,255,140,248,73,251,135,0,163,2,56,255,138,169,212,5,186,9,212,250,145,251,182,252,177,5,185,0,62,5,188,13,142,252,45,4,135,4,204,255,52,7,94,251,42,2,20,15,32,7,168,247,143,252,255,250,53,204,63,253,166,255,102,8,61,2,227,10,44,4,80,248,121,0,37,3,30,17,247,251,252,219,24,253,90,250,12,28,1,1,161,232,149,249,202,231,62,7,60,242,36,4,138,255,56,0,181,252,16,11,158,255,91,242,112,1,6,0,171,248,225,241,94,248,51,70,194,3,252,5,38,249,192,14,149,2,23,248,196,255,11,252,58,251,10,244,187,255,187,236,248,11,104,251,213,0,221,1,57,4,143,6,232,246,192,7,1,171,143,252,202,255,179,251,188,251,86,2,112,6,200,242,43,255,123,1,218,250,76,248,118,2,232,253,78,248,51,254,156,254,112,168,193,248,143,255,108,3,7,245,181,253,237,246,200,255,129,8,227,252,113,6,27,240,70,5,229,247,101,0,152,250,167,6,61,4,215,1,157,31,252,3,240,239,202,3,98,3,80,250,171,254,138,5,118,205,123,1,59,38,22,7,33,9,87,249,185,38,2,4,170,7,24,253,172,244,102,249,254,5,65,252,139,253,26,9,151,14,134,18,189,243,169,247,250,8,51,245,147,250,206,241,3,106,159,2,160,8,238,1,247,3,83,251,17,255,191,254,135,251,89,253,131,253,212,243,32,2,72,252,114,3,140,1,63,4,165,243,132,245,247,2,43,253,118,247,226,253,241,9,85,14,24,0,153,6,233,40,44,7,93,254,66,1,171,9,116,7,190,250,50,0,255,230,196,241,40,2,44,9,47,5,77,46,163,9,117,21,8,6,208,1,4,7,15,245,25,32,246,3,201,247,180,14,155,31,170,0,122,207,172,6,122,246,175,248,178,7,112,8,93,236,121,253,138,255,14,11,75,9,189,251,165,233,124,0,201,11,161,1,55,0,96,5,201,251,210,27,14,12,183,69,164,9,201,12,169,253,230,12,102,252,231,247,96,249,37,3,230,7,149,248,116,12,145,5,244,238,116,255,80,241,181,1,113,5,238,250,14,67,253,250,168,244,76,253,6,2,108,254,176,3,58,248,56,252,43,5,72,9,68,210,139,8,92,12,209,253,164,8,62,6,51,249,104,1,121,2,3,12,108,253,12,252,10,3,53,2,28,248,133,255,5,0,87,247,105,244,118,1,16,1,80,1,67,249,104,254,34,247,171,245,236,251,251,253,119,7,126,254,169,238,77,226,24,252,236,29,77,2,83,58,85,11,222,46,210,204,129,248,64,15,86,0,81,6,156,28,6,12,178,6,28,18,56,246,62,255,54,243,58,253,33,0,83,248,6,247,209,9,214,2,75,0,67,0,116,3,56,8,14,16,144,7,147,40,162,10,78,248,48,207,191,18,14,12,134,244,183,6,166,247,174,254,156,251,203,3,152,239,224,1,223,242,76,24,66,23,38,7,233,3,180,11,70,16,218,244,75,254,106,250,48,4,200,254,107,205,41,12,81,246,14,248,44,27,245,10,80,8,88,3,157,221,155,237,6,251,136,255,228,4,58,15,126,25,182,240,28,247,194,10,212,245,34,244,40,16,38,10,132,247,253,18,103,246,2,0,123,245,216,252,199,13,96,251,136,1,102,247,102,9,192,3,216,251,227,245,137,4,114,9,216,2,46,254,255,236,211,0,128,57,211,247,71,248,85,0,182,206,231,247,44,244,213,251,198,6,69,246,34,37,90,254,98,245,106,244,43,15,220,244,80,1,26,5,7,247,217,7,29,10,255,11,192,0,41,251,199,214,2,0,106,251,36,244,211,38,229,255,2,251,168,5,223,72,249,2,163,3,189,1,162,255,206,0,192,1,183,248,232,0,255,238,244,17,252,254,48,252,82,2,136,2,28,3,160,250,94,251,240,11,99,12,213,233,35,24,249,250,38,66,58,250,66,4,65,2,139,31,95,4,127,11,120,243,60,7,194,7,115,23,133,3,62,252,132,243,141,248,136,1,211,245,236,10,242,15,56,254,219,243,61,251,123,0,166,9,174,0,26,251,186,250,201,236,247,4,14,48,126,251,83,231,238,242,221,250,112,255,190,4,207,255,163,13,251,251,5,248,75,223,101,16,107,19,80,38,4,38,188,2,199,8,61,245,14,248,188,12,71,3,198,214,125,6,220,44,148,243,139,248,65,4,211,252,44,12,201,247,114,241,94,238,151,2,128,4,62,15,254,18,179,10,12,241,195,2,152,10,183,224,192,252,148,191,64,250,138,246,39,234,66,1,154,248,250,10,109,0,4,249,2,8,211,13,216,243,222,231,183,9,54,8,121,255,91,12,48,8,27,16,202,254,190,251,254,255,154,245,65,189,93,5,168,5,162,0,15,2,143,2,56,247,54,242,194,0,25,5,166,29,117,234,201,4,71,6,24,241,137,8,137,245,122,238,186,253,117,19,117,249,147,0,198,57,119,0,251,45,52,251,244,3,11,232,57,247,183,240,68,5,202,248,255,253,14,231,19,253,70,26,233,2,215,252,225,252,152,12,43,0,74,247,38,10,178,11,202,249,66,212,116,199,0,255,183,2,109,3,160,241,82,245,88,250,56,5,159,249,255,12,169,13,140,11,242,252,142,11,182,248,60,11,211,7,168,252,2,5,204,19,135,1,213,214,167,6,0,128,196,252,97,37,75,1,26,27,50,12,16,252,31,11,134,2,198,233,176,6,229,252,202,238,88,5,51,1,242,253,98,247,26,0,46,255,78,5,234,2,128,7,155,2,26,15,99,254,48,253,24,239,85,246,91,251,161,252,31,241,68,236,137,222,43,11,123,7,31,19,152,48,54,205,197,10,175,232,214,15,76,4,42,219,66,19,26,40,14,250,180,27,182,221,80,248,229,16,248,32,48,15,82,248,80,253,105,246,150,11,180,246,146,6,92,19,250,246,134,241,148,1,118,26,154,68,107,207,149,245,0,19,61,219,220,230,156,219,121,252,106,234,135,13,102,249,126,235,232,206,34,9,226,250,53,244,8,3,127,253,155,13,54,0,20,214,218,240,77,253,49,187,178,17,27,40,150,30,40,33,176,206,94,238,225,188,158,27,43,12,80,16,127,1,50,238,154,1,235,24,98,24,94,18,245,18,39,255,190,1,29,241,164,246,244,0,184,247,203,12,2,20,180,0,171,17,232,33,180,248,236,231,76,10,64,236,57,240,158,210,174,15,85,44,200,245,48,32,1,236,196,7,8,246,172,23,134,12,106,253,126,10,92,4,49,215,68,244,138,2,131,30,140,208,185,254,88,3,108,252,115,254,168,253,13,18,195,11,163,21,41,21,186,246,195,37,150,237,141,30,253,244,61,2,140,17,90,7,110,151,206,5,205,228,79,4,211,9,4,32,57,7,188,226,133,235,58,8,86,235,8,213,126,250,136,242,156,222,72,238,206,225,11,12,221,23,134,199,80,222,131,254,160,30,86,18,190,240,31,32,243,12,217,22,56,51,180,204,193,23,25,46,56,226,136,254,28,231,95,229,178,26,224,6,101,250,48,4,177,13,42,250,59,253,154,22,198,1,15,7,90,10,48,30,77,5,22,252,10,235,192,246,4,8,77,1,168,24,176,254,82,32,139,249,43,239,26,230,25,11,144,9,206,32,0,21,176,227,62,250,206,248,233,239,70,3,245,1,146,239,212,15,30,251,49,174,246,242,176,253,99,244,145,27,128,255,93,243,39,239,50,246,207,211,195,236,31,12,168,5,190,235,214,250,81,190,164,7,242,224,81,10,182,244,44,17,18,9,155,250,137,248,192,1,239,9,207,13,14,3,135,14,144,253,74,6,229,244,159,29,2,7,188,2,35,12,176,17,85,21,236,9,206,251,88,23,229,2,64,2,74,17,48,17,200,236,92,22,106,241,94,251,149,41,76,4,41,41,12,11,150,45,57,223,196,128,67,219,105,229,149,252,229,8,224,2,62,238,251,182,180,4,197,251,94,13,0,243,125,23,80,244,180,22,184,10,108,210,41,246,176,246,205,241,132,25,218,26,252,244,154,235,27,208,70,200,249,229,130,251,16,248,51,8,34,18,102,6,190,239,124,253,249,0,195,243,54,46,40,214,82,48,210,18,124,248,249,233,208,230,151,9,222,236,155,253,224,6,89,9,134,5,127,27,150,228,13,23,172,244,202,14,98,243,122,241,186,13,56,240,188,237,223,24,87,250,58,245,184,244,226,15,28,228,152,1,24,226,84,12,207,77,190,248,15,26,96,1,229,242,2,12,148,21,107,250,162,7,248,229,158,216,53,17,194,249,218,252,243,6,255,228,150,27,200,19,118,25,238,251,72,13,102,234,88,251,78,2,30,243,252,252,59,2,161,231,82,38,164,207,22,5,64,5,154,242,246,14,10,16,160,22,204,231,224,0,212,245,114,15,249,206,93,234,142,223,9,7,87,238,250,13,3,239,172,233,96,19,36,14,236,5,147,22,174,21,130,241,1,13,46,41,102,16,28,20,37,243,196,0,88,24,31,27,233,250,190,215,70,7,147,25,248,249,76,244,52,11,219,238,18,229,141,111,182,204,117,5,229,246,20,240,54,11,8,14,213,25,9,1,74,237,70,242,176,243,6,34,230,0,70,12,16,251,30,7,255,252,24,24,0,249,141,8,100,10,152,245,74,13,235,253,228,243,36,254,116,251,204,23,142,244,44,13,249,232,59,33,106,252,148,237,210,249,151,93,226,5,56,9,139,255,237,7,60,254,81,230,196,3,180,204,234,244,216,14,229,242,96,12,110,20,108,43,58,3,81,249,38,242,230,28,4,240,188,244,231,2,8,249,16,241,147,242,26,4,22,243,160,3,11,236,193,224,45,6,161,33,202,237,246,241,174,249,201,38,114,240,41,234,171,221,92,250,21,209,24,5,124,49,238,235,85,42,241,224,7,240,81,15,1,235,74,246,226,245,134,44,176,255,54,30,61,238,234,211,70,228,178,225,183,20,212,28,254,211,126,212,28,222,30,0,184,24,85,2,172,30,72,12,163,240,38,59,114,15,165,47,5,254,125,249,141,21,165,239,197,2,206,250,46,8,131,18,61,5,84,32,96,33,133,216,89,216,57,14,3,3,190,18,231,18,74,243,226,219,120,227,2,58,21,185,252,11,129,19,190,236,233,42,126,24,80,33,16,23,46,205,112,225,20,5,62,253,100,255,124,239,46,1,234,38,241,243,120,17,189,17,123,51,80,230,19,246,92,32,205,255,246,20,239,238,33,1,50,15,169,241,102,7,60,85,41,244,216,20,36,223,183,9,69,251,153,229,12,5,165,14,56,221,126,2,207,26,154,0,121,4,84,253,248,25,222,240,213,7,62,18,56,17,95,16,144,15,120,2,141,11,4,250,122,240,240,245,156,249,126,241,120,255,174,236,60,15,111,1,192,105,72,7,146,5,7,243,92,3,24,249,39,248,148,242,106,10,85,217,208,250,230,246,250,243,70,243,8,238,228,21,128,235,167,6,51,17,83,237,173,223,61,26,236,240,228,42,118,214,88,223,13,247,87,79,178,29,68,240,227,1,234,236,117,10,199,236,177,23,17,21,159,247,57,24,40,254,4,7,53,11,6,242,237,11,218,246,135,243,227,245,113,243,42,5,24,2,92,255,198,254,192,18,145,248,198,250,199,209,153,164,186,21,88,17,184,248,216,9,101,239,72,250,189,19,151,222,244,240,212,232,175,252,55,228,91,242,38,235,121,249,216,5,152,17,218,248,84,22,46,255,117,5,244,247,194,8,185,253,44,10,235,20,114,54,94,51,66,5,89,10,9,250,40,238,187,34,231,28,164,230,125,215,235,236,0,51,186,223,13,251,113,244,156,252,53,23,43,1,167,253,130,34,156,5,28,21,122,7,65,241,212,3,144,34,34,247,96,248,246,26,194,33,131,155,84,37,204,56,206,7,155,204,52,1,236,201,114,216,157,247,104,32,236,6,70,4,16,218,144,222,128,226,151,21,90,250,183,251,90,233,138,188,44,11,46,255,88,8,175,0,217,2,255,45,222,235,150,239,30,52,137,15,158,56,229,233,145,35,197,212,146,241,186,18,175,253,161,26,83,7,145,236,79,14,45,16,131,223,28,221,79,8,176,239,112,4,108,255,216,29,191,31,24,253,50,9,133,1,64,6,181,230,50,238,239,41,143,44,56,15,42,51,22,7,71,20,246,240,69,10,254,71,151,32,22,18,240,237,66,253,6,241,28,247,178,244,236,249,157,5,168,1,20,22,140,231,83,9,43,233,72,29,161,41,62,245,198,18,145,4,28,5,238,239,29,235,228,58,54,22,119,28,188,11,146,231,66,20,240,200,83,40,74,248,117,219,88,234,38,252,146,232,5,1,142,17,163,9,137,248,165,253,60,238,192,250,203,7,189,249,224,40,102,20,130,14,34,235,153,224,242,48,159,152,235,248,204,15,234,2,187,31,210,208,161,237,155,11,121,238,252,9,64,15,42,246,224,5,142,22,55,21,96,4,90,252,174,235,86,229,186,221,244,27,168,246,147,41,154,244,54,239,33,13,82,241,130,252,196,22,53,255,215,236,80,25,251,45,138,178,119,187,200,236,145,188,82,39,141,39,236,220,249,178,2,92,3,109,47,10,154,228,240,23,49,163,62,237,69,228,106,3,47,51,163,84,229,222,118,205,190,204,146,241,84,182,66,242,254,241,114,49,231,252,165,41,13,27,38,253,147,211,91,225,94,0,189,245,100,232,91,247,227,238,42,216,72,233,200,255,3,239,138,14,71,15,73,249,47,246,22,204,146,12,105,0,84,7,180,255,173,251,3,10,168,17,48,40,230,22,198,225,36,24,135,38,100,5,100,26,72,10,146,182,98,36,22,28,226,226,176,1,219,196,14,33,80,8,174,246,106,245,36,1,17,253,203,243,3,24,77,19,74,12,230,11,120,0,65,1,4,233,241,19,52,239,120,24,195,254,131,6,74,253,14,31,7,22,44,243,65,4,200,230,154,198,57,242,176,251,217,16,134,174,240,30,226,213,32,203,165,3,171,17,80,10,70,8,97,0,154,253,106,38,213,218,232,0,222,19,192,229,7,250,56,2,67,12,175,241,137,222,53,202,130,24,238,238,235,233,40,221,13,226,81,219,3,230,201,48,174,241,17,236,220,207,188,18,228,253,156,40,84,14,117,242,212,27,210,238,87,0,149,208,52,255,189,4,114,247,172,46,175,245,126,246,241,233,3,11,76,12,230,13,201,230,121,14,108,6,238,243,127,239,146,232,112,0,125,69,204,227,118,8,57,16,164,17,180,251,125,249,134,250,123,221,200,24,206,249,133,242,53,9,104,2,120,254,29,224,197,210,16,24,33,245,215,30,57,44,185,209,134,31,111,20,160,230,156,243,114,242,112,244,83,211,209,1,42,254,248,245,189,43,55,219,235,239,118,251,155,248,199,246,39,2,142,56,182,13,164,250,45,12,212,223,168,244,220,56,119,12,200,0,118,8,106,201,158,10,106,15,140,9,190,7,200,20,39,8,82,247,37,6,230,2,132,221,179,240,184,212,15,255,232,222,231,23,34,1,196,246,165,243,131,7,84,248,186,253,4,10,66,234,245,230,21,8,224,28,155,35,228,98,224,5,236,9,210,252,46,249,54,2,212,249,14,247,170,0,186,2,105,0,95,37,198,229,184,253,186,236,133,254,21,254,46,252,228,17,156,4,229,242,90,7,9,239,209,18,223,5,240,38,82,221,212,236,91,13,46,237,50,247,38,26,240,238,159,213,27,236,158,17,199,243,152,0,134,7,118,238,230,5,156,186,213,229,194,3,146,13,117,19,25,0,40,228,152,5,10,21,36,12,63,238,68,4,127,6,173,250,4,12,44,221,14,24,244,0,99,251,199,252,91,252,62,234,69,67,233,253,180,244,89,236,239,250,62,244,208,22,166,2,236,2,104,15,94,6,192,241,175,234,198,245,108,3,255,25,238,244,37,10,245,229,50,5,216,255,185,238,113,24,231,2,195,23,184,253,98,241,135,250,243,6,210,235,207,17,182,21,140,33,180,230,97,29,231,249,86,19,246,252,236,13,139,44,14,252,177,243,185,200,4,252,35,10,50,243,235,95,5,237,115,252,10,9,21,5,50,8,224,233,98,15,46,240,53,255,40,13,236,245,245,11,206,219,137,231,164,229,50,15,158,7,183,254,26,4,174,251,76,2,153,92,107,253,1,27,210,2,68,233,99,8,205,14,103,249,149,2,13,21,185,222,128,4,216,14,248,27,114,20,63,5,146,12,172,244,121,254,94,239,220,19,81,237,94,28,227,216,213,252,124,235,74,25,70,188,172,246,220,245,245,221,204,22,51,37,127,2,44,18,255,11,42,12,144,249,27,6,93,252,97,216,42,17,234,244,132,209,12,252,73,3,76,233,24,244,101,245,60,255,94,233,202,177,157,7,136,13,254,252,152,8,20,242,183,7,158,231,111,248,114,15,46,22,72,245,96,7,15,241,138,22,29,15,123,32,38,227,38,5,22,5,98,234,54,238,156,3,36,241,60,239,27,167,220,224,211,226,41,242,178,30,115,216,179,245,99,237,108,214,200,232,135,4,35,243,11,17,61,251,40,208,196,19,192,227,35,27,183,249,35,244,36,236,180,25,1,62,216,20,127,28,82,9,145,11,47,18,242,37,216,19,115,45,254,6,81,11,175,2,110,252,76,253,3,230,142,222,124,250,244,0,126,17,114,6,7,28,22,4,223,229,109,14,64,242,158,23,200,250,184,7,182,65,104,251,24,3,59,249,94,32,65,227,158,246,168,222,112,5,57,243,180,25,181,236,26,6,83,2,115,239,8,19,170,16,250,248,67,230,33,29,111,16,250,38,100,240,68,247,250,243,69,7,117,39,166,246,78,243,61,226,86,228,31,200,32,22,199,250,245,212,1,241,206,39,81,28,14,12,10,249,24,0,18,242,17,42,250,239,248,230,80,253,229,220,202,11,202,232,54,29,144,254,5,225,54,244,110,26,178,255,73,22,64,243,180,251,242,18,166,17,228,255,124,231,41,19,182,27,214,238,226,244,168,255,178,1,247,7,96,1,99,38,84,48,183,4,143,222,132,238,216,5,193,236,39,8,182,229,110,4,175,255,57,0,3,222,154,244,113,15,228,244,206,248,196,18,61,235,111,254,148,27,243,191,62,237,135,217,134,68,61,210,112,207,236,229,107,36,123,204,127,233,118,31,148,253,249,226,142,14,126,69,200,30,251,0,167,11,152,14,206,27,45,67,165,33,165,5,70,196,200,192,76,43,149,236,222,232,155,248,107,35,105,36,53,224,202,2,182,0,190,243,90,28,174,248,35,245,48,42,99,11,196,20,170,235,235,245,235,39,28,254,94,3,119,0,228,25,234,5,43,15,144,252,162,29,243,245,207,12,217,14,140,17,246,240,200,36,218,255,94,29,194,253,212,15,144,251,100,253,200,37,192,218,247,9,129,239,206,251,224,241,254,32,158,0,190,12,29,31,31,5,70,222,126,229,188,2,109,19,149,3,14,253,124,251,166,23,19,8,5,42,165,1,6,4,87,44,101,8,66,239,43,47,241,17,169,4,86,235,138,222,107,244,168,26,162,231,88,9,189,242,230,20,27,245,105,29,175,248,216,11,42,250,113,245,153,183,47,6,67,37,252,9,186,238,65,232,117,245,76,225,35,238,212,223,185,16,201,251,86,187,232,244,44,29,67,18,118,236,12,251,7,250,226,223,93,32,2,253,38,239,160,23,243,44,182,19,116,246,114,12,196,6,192,30,198,25,12,11,152,244,86,32,207,51,36,216,54,5,80,234,36,41,36,21,250,9,164,216,104,4,137,240,118,243,251,15,32,7,120,19,182,21,100,247,32,8,38,241,214,25,44,227,28,14,240,237,222,24,253,248,198,15,83,24,40,239,210,236,177,247,229,58,48,16,11,190,173,14,255,8,98,253,249,21,226,245,222,245,187,9,154,243,103,16,128,4,4,250,116,227,126,222,31,25,159,11,144,23,221,11,229,226,173,245,127,21,80,225,109,246,189,20,162,241,209,31,72,7,107,223,41,195,36,30,159,215,231,34,62,48,78,215,4,240,222,2,160,40,182,42,92,22,242,6,204,22,125,243,52,214,206,10,82,16,41,185,51,191,167,234,115,236,71,28,136,99,142,28,248,230,254,23,188,225,113,250,34,239,191,254,173,244,144,14,144,243,6,242,178,210,57,251,150,222,144,2,151,240,12,240,44,253,45,1,67,37,223,37,249,248,214,245,157,250,94,235,155,237,82,46,90,37,172,226,22,19,128,3,148,22,96,255,76,206,130,218,196,4,221,234,48,236,180,230,13,210,152,255,95,36,110,20,79,2,246,16,7,1,142,51,119,186,156,248,59,10,18,71,224,247,152,64,65,72,186,154,197,99,66,0,8,230,91,6,234,10,50,241,208,36,107,5,222,80,140,20,91,20,166,6,251,3,121,212,155,230,233,182,117,42,148,239,130,19,186,6,121,33,86,14,34,17,22,190,172,34,7,247,73,245,46,238,9,220,97,31,166,254,254,241,21,219,170,12,16,6,182,16,125,229,206,27,46,14,250,17,53,227,11,206,72,215,182,197,62,244,93,7,48,16,118,238,234,15,116,30,79,251,180,227,115,10,197,4,108,228,228,205,64,242,191,7,249,237,15,32,70,6,5,2,62,14,172,227,48,3,150,241,94,253,44,51,130,192,119,18,8,224,56,252,10,235,16,247,220,176,150,4,72,180,153,239,84,235,70,2,194,204,44,7,162,6,14,248,247,198,242,25,222,214,226,1,173,252,240,38,138,27,202,203,94,223,132,18,174,177,63,255,167,248,75,251,54,240,155,27,72,50,214,22,72,237,215,248,200,9,106,243,185,249,74,10,235,17,105,26,13,6,100,4,211,36,138,15,143,223,100,29,203,9,144,233,166,12,118,20,176,241,182,2,176,144,118,249,29,213,250,33,138,253,52,18,244,11,132,227,156,39,166,46,168,5,68,233,184,243,28,12,79,41,232,26,177,13,12,39,227,10,28,254,121,31,223,5,185,24,2,12,114,15,203,36,32,253,29,9,190,248,192,12,70,240,2,63,91,199,92,235,40,254,82,3,166,227,6,6,193,5,212,246,113,228,154,218,29,247,225,238,118,29,152,254,127,244,218,240,28,0,41,3,88,2,198,8,75,2,13,249,128,242,31,253,170,12,37,246,186,248,239,23,131,3,46,4,2,195,238,42,244,243,74,37,171,28,195,34,46,250,117,215,23,220,239,240,97,32,93,28,201,48,134,30,198,230,199,4,126,60,48,213,168,248,58,19,117,225,241,253,190,246,103,14,78,5,127,40,70,200,40,250,36,4,147,219,50,234,149,240,128,187,190,5,14,19,41,42,88,11,250,245,125,236,149,25,253,23,40,43,105,12,18,254,127,35,29,3,241,245,16,234,173,4,150,11,233,211,50,18,8,254,219,17,22,7,142,73,142,102,95,9,46,34,96,10,14,32,69,205,97,220,253,251,55,254,204,4,249,23,18,9,196,6,194,233,132,252,7,255,78,255,159,228,240,238,146,1,68,234,193,235,166,9,119,237,228,10,73,243,195,235,62,253,40,0,205,236,222,34,207,241,105,246,206,58,0,21,157,252,154,227,45,252,141,27,247,226,181,53,175,19,70,247,26,33,119,27,179,240,7,20,78,226,68,2,35,47,204,8,149,0,86,0,186,253,159,233,145,8,82,16,21,220,208,209,57,15,18,5,236,251,50,25,93,7,150,179,61,24,254,237,16,246,72,20,235,236,157,19,187,246,154,255,190,28,126,246,72,242,48,240,254,11,45,0,192,250,202,0,115,247,192,1,148,4,123,11,221,253,235,3,30,231,59,14,123,251,92,15,100,232,174,205,167,7,218,249,14,10,6,58,67,192,29,230,249,1,78,4,111,219,105,224,101,29,70,250,28,1,172,14,129,254,27,20,196,19,38,254,19,2,0,232,176,248,74,251,15,2,3,237,134,207,84,29,198,227,182,19,55,208,199,239,20,18,190,199,111,235,22,2,248,5,160,203,194,255,187,182,0,251,171,219,242,215,226,220,65,231,212,225,190,242,159,7,41,204,147,250,102,235,248,237,85,218,201,215,52,5,14,234,15,214,144,226,158,219,162,228,8,253,14,30,139,11,108,254,16,245,146,59,12,241,106,23,32,21,219,32,184,64,144,227,11,229,34,255,238,249,162,252,177,248,171,3,162,241,4,239,128,243,148,12,78,6,150,33,226,31,213,6,46,227,134,249,163,3,30,15,223,35,229,5,52,236,239,255,101,22,71,224,209,10,133,243,32,243,236,34,12,11,90,246,112,246,245,28,221,244,222,251,103,238,75,218,46,236,73,0,42,243,82,240,32,249,2,10,122,53,120,242,62,21,190,242,101,66,128,244,35,1,128,16,151,4,67,247,18,229,153,234,245,250,62,13,79,21,130,3,133,13,22,225,79,237,87,7,35,4,119,241,92,233,190,19,165,240,171,24,100,246,117,7,61,2,211,242,236,11,78,255,218,3,60,2,168,232,149,22,192,236,213,214,68,2,217,182,245,2,223,6,47,240,184,8,98,7,19,16,187,2,138,244,62,19,87,9,96,42,239,19,244,16,18,250,240,8,235,8,182,34,245,235,179,238,224,238,63,243,157,46,153,15,210,44,137,14,252,5,208,3,224,23,162,7,200,246,9,249,32,8,44,231,178,9,218,237,56,248,54,6,254,6,218,12,248,246,204,253,252,1,104,249,158,226,209,219,243,11,91,7,67,244,233,250,70,220,42,40,53,5,84,18,221,247,80,194,160,8,104,4,202,210,19,228,154,251,125,236,19,74,138,231,181,19,131,8,202,252,31,251,108,39,174,254,112,22,99,6,231,9,226,23,197,250,111,223,238,238,192,16,164,9,235,11,203,48,174,218,62,240,10,2,195,251,220,22,57,245,54,19,35,214,62,255,144,211,243,11,43,47,13,4,140,20,48,3,30,23,61,248,244,30,122,232,122,215,87,45,203,97,178,210,254,65,154,9,171,234,9,248,129,1,114,23,150,29,205,4,190,252,248,251,227,226,134,10,89,250,48,14,119,16,213,13,120,11,34,243,233,3,205,230,13,238,94,210,200,30,213,8,202,14,223,244,228,8,198,252,158,14,162,29,178,254,21,11,229,246,207,205,146,4,130,251,123,235,27,252,220,220,188,31,186,8,136,3,10,247,72,12,184,28,180,234,0,6,160,221,94,7,150,184,197,217,126,224,222,208,0,6,108,17,191,250,138,5,47,29,139,52,125,227,131,21,139,26,72,255,201,34,8,248,187,236,134,19,149,28,245,229,242,235,134,35,143,222,26,246,94,13,230,8,46,12,205,0,179,22,199,8,58,23,54,4,199,247,222,228,170,0,167,249,130,237,89,250,23,239,55,238,74,247,222,221,71,196,143,28,9,26,183,19,192,7,120,46,98,54,6,215,159,219,144,5,81,244,128,5,79,1,210,34,189,14,110,34,237,30,48,238,142,255,144,253,24,35,194,249,188,253,161,12,78,2,132,247,166,243,111,240,18,21,18,54,151,210,73,0,26,50,76,251,255,19,64,40,234,216,121,245,38,5,156,0,84,0,8,253,226,237,36,241,225,11,242,252,78,244,215,243,125,2,72,243,57,233,196,1,76,251,78,6,150,210,95,237,116,41,250,221,205,177,46,41,73,239,0,27,107,250,228,14,28,11,63,15,154,210,6,221,180,0,58,15,18,15,119,0,105,5,198,15,245,232,55,252,178,234,249,51,164,229,46,23,91,31,76,227,43,241,171,139,164,236,245,7,229,246,36,243,62,32,197,25,94,17,88,225,106,24,120,5,98,251,154,236,94,242,126,250,18,247,6,13,94,1,55,36,171,11,90,252,186,233,215,240,159,255,97,253,244,19,123,255,22,5,110,45,102,221,45,244,214,255,98,14,29,250,152,15,9,22,218,10,6,222,51,246,176,250,77,0,68,8,98,0,37,11,66,231,27,23,66,251,95,245,217,34,100,5,194,239,37,239,124,237,199,173,132,27,98,3,46,8,30,219,43,35,229,235,223,236,79,13,218,210,184,16,156,17,41,26,76,6,228,5,99,33,79,200,105,255,198,218,174,227,57,44,162,199,176,236,72,246,69,5,8,255,46,250,213,6,130,15,58,233,31,81,34,18,164,12,36,0,73,189,165,212,108,23,249,213,217,255,142,30,153,226,105,250,179,0,255,240,250,8,127,5,15,255,1,247,28,36,214,241,209,25,167,7,250,253,112,1,142,6,42,235,39,233,134,236,197,246,95,2,249,10,18,252,241,225,38,39,168,8,224,220,186,16,39,3,115,57,56,37,199,212,198,11,85,12,221,21,115,4,238,250,198,241,159,30,92,3,16,239,64,10,181,239,255,6,247,244,242,20,239,253,214,5,81,1,121,238,97,253,240,20,211,12,69,19,156,198,193,15,243,238,153,10,9,229,8,249,146,213,29,24,158,20,11,58,172,252,36,39,16,48,194,34,239,243,223,35,49,7,84,32,65,19,251,254,16,251,103,2,31,14,199,56,157,25,7,2,132,16,214,28,243,248,79,238,128,19,181,16,170,254,118,218,183,235,146,228,32,165,98,9,28,253,59,11,68,236,191,7,123,19,8,13,34,241,55,5,204,244,78,3,228,29,168,3,182,13,38,238,62,244,155,221,33,24,195,238,247,22,156,196,160,249,104,52,65,238,254,14,179,219,208,6,152,3,184,60,236,14,36,233,95,15,53,9,170,230,140,7,12,47,26,231,15,246,171,246,195,10,119,224,245,223,51,18,190,16,0,63,37,252,178,1,113,238,180,238,48,237,167,215,79,238,160,203,29,204,144,251,162,15,9,251,219,13,102,235,55,234,189,2,147,254,52,245,114,1,143,254,51,10,192,252,22,15,252,17,150,225,162,43,83,250,224,249,6,42,168,0,146,1,63,248,156,5,102,221,96,39,145,222,158,15,42,239,90,203,224,243,62,211,250,1,238,184,116,241,144,229,24,31,139,239,97,4,134,249,139,251,174,248,129,254,30,236,236,2,248,251,73,251,22,4,183,248,173,246,78,8,168,241,77,26,22,245,213,14,202,60,43,209,170,0,241,23,146,2,161,3,192,18,56,239,69,252,115,247,68,255,108,12,138,255,2,253,122,247,240,228,50,247,215,25,186,238,180,24,225,255,158,14,56,233,98,236,63,18,38,6,91,231,32,1,48,245,68,246,46,237,184,235,8,255,92,243,83,254,120,0,158,4,10,215,108,244,127,241,166,232,41,46,172,177,131,230,6,8,145,252,166,253,229,244,76,28,164,250,161,1,84,255,250,12,100,230,147,228,210,22,189,28,17,245,76,14,155,29,74,18,62,247,73,0,225,219,69,82,244,247,226,241,182,9,185,18,113,244,2,254,182,255,162,232,226,8,205,239,188,12,202,7,114,249,186,226,200,202,0,10,49,227,128,252,175,236,234,244,168,212,79,248,247,22,188,1,108,243,38,57,51,19,184,246,229,222,126,38,116,44,52,43,254,5,179,199,14,17,184,218,106,214,26,226,4,186,153,13,88,243,240,6,124,246,45,223,95,14,134,248,249,48,92,234,82,235,107,23,80,23,207,245,14,190,21,3,222,218,165,216,146,208,100,226,78,228,2,248,57,43,193,29,81,242,35,248,188,13,203,24,61,255,209,243,140,9,14,0,122,236,255,2,112,19,122,240,78,35,67,2,12,7,242,223,255,127,255,233,250,3,76,52,228,3,63,206,149,243,246,247,95,53,250,4,133,238,218,28,94,249,7,70,26,232,70,62,150,244,150,242,15,23,189,24,67,220,60,55,48,250,183,11,127,4,57,9,113,248,253,215,210,210,57,235,197,3,26,20,68,14,71,254,131,247,100,242,101,14,229,202,89,249,178,255,128,250,85,72,52,241,62,243,90,12,228,3,238,77,144,222,125,19,193,25,47,235,134,11,184,201,60,242,214,21,215,15,196,23,189,9,115,49,102,233,250,18,84,28,57,228,106,227,35,21,225,28,246,221,130,242,230,249,127,7,207,255,88,253,117,28,114,254,116,244,188,27,187,21,230,253,183,6,240,255,16,241,181,1,70,229,224,5,62,22,190,4,137,12,54,195,243,238,113,36,23,156,145,5,218,245,59,223,21,229,53,243,232,12,103,240,9,231,90,252,182,30,236,18,122,255,162,38,218,237,164,9,83,217,241,239,248,243,64,236,220,1,213,204,167,5,205,0,136,246,186,27,213,208,218,237,99,202,175,32,162,244,243,222,107,5,225,13,12,216,45,245,90,18,173,230,202,47,106,224,1,13,70,9,196,1,243,248,219,19,222,7,164,0,231,27,81,0,174,23,22,11,198,20,138,236,160,5,222,7,55,243,254,229,226,252,124,243,118,5,169,253,54,233,22,8,36,18,170,188,134,1,108,249,188,236,1,35,71,208,249,243,174,25,107,5,153,232,133,225,5,5,15,29,117,254,24,244,246,7,177,252,78,253,249,235,180,8,172,239,85,242,18,2,184,253,156,38,189,254,190,1,228,194,54,220,109,249,59,14,6,242,74,10,240,1,161,31,109,0,32,4,142,5,76,21,117,25,63,254,171,246,46,1,171,26,227,5,222,243,236,227,211,236,71,254,155,50,163,240,54,235,35,20,125,165,36,245,161,245,48,240,44,50,131,241,155,25,188,233,196,14,90,230,193,238,83,43,27,44,43,25,186,35,228,252,116,250,224,21,66,47,98,233,219,25,22,215,111,208,254,232,196,84,140,43,99,13,58,12,161,233,54,57,129,54,95,245,124,5,226,243,171,237,154,18,221,6,229,9,158,15,238,253,10,253,181,20,110,250,244,34,48,253,221,26,233,240,92,9,146,20,83,253,122,3,236,227,182,10,242,254,189,31,220,252,36,126,52,27,151,33,118,242,200,251,25,223,22,8,217,254,99,255,200,234,152,0,174,9,102,241,80,4,220,5,86,235,97,246,14,231,23,246,229,246,38,243,162,246,159,0,188,25,13,246,136,246,120,247,124,32,38,22,24,234,216,245,99,10,166,0,236,57,62,10,6,215,6,192,64,0,178,1,224,17,62,244,175,9,114,229,103,13,104,1,213,251,93,13,152,2,189,15,46,240,16,255,35,15,160,2,3,14,245,1,190,9,208,255,13,39,187,12,103,33,56,226,190,67,13,42,232,16,119,241,193,6,228,244,70,231,250,19,229,60,251,254,126,226,148,10,92,28,220,22,224,221,180,1,240,231,180,253,225,232,120,22,55,12,50,238,28,2,74,0,48,240,151,14,193,30,203,244,224,253,145,255,62,20,8,4,11,9,97,255,241,19,10,16,18,254,166,2,108,237,231,240,35,227,68,246,25,28,26,20,10,225,11,47,129,43,183,6,3,9,156,234,135,49,60,31,214,2,165,3,150,12,91,29,166,2,30,233,100,245,223,5,58,244,179,247,118,19,136,236,211,1,218,3,74,21,64,250,194,20,251,250,218,0,173,242,159,17,111,31,172,16,141,223,165,214,48,67,231,12,129,29,241,20,84,4,210,224,48,32,32,233,208,242,144,240,188,244,49,17,172,227,238,15,114,29,92,13,246,201,141,251,246,41,24,246,124,2,78,30,186,16,79,242,166,4,42,227,28,224,186,20,104,254,115,236,216,10,126,30,173,18,33,225,190,246,60,54,30,2,11,22,36,27,71,25,139,10,47,3,102,17,90,7,242,8,240,240,242,243,23,32,162,12,92,17,212,249,19,11,245,243,50,26,241,28,18,18,98,10,4,9,29,31,246,251,232,245,88,1,192,2,248,47,104,40,160,224,198,238,232,231,204,26,41,31,2,234,232,229,119,236,201,231,118,215,28,249,6,243,68,239,232,251,161,10,38,210,232,209,217,224,194,10,96,13,39,226,59,247,175,236,62,255,100,248,222,244,15,16,170,170,210,221,210,16,174,95,188,40,118,105,112,19,115,245,45,243,45,253,253,249,102,26,254,217,67,242,1,25,62,238,102,254,84,217,173,236,84,27,231,42,246,19,236,77,178,255,254,248,43,43,242,255,60,1,47,25,50,176,147,36,102,35,170,247,143,53,48,25,255,25,144,235,2,18,144,215,30,244,247,221,145,22,122,246,214,245,131,227,13,253,80,26,144,11,164,241,190,244,178,217,62,5,218,4,74,8,189,10,119,2,102,25,218,8,60,205,52,53,50,77,160,31,190,2,214,238,36,222,76,250,100,243,83,255,161,231,35,18,132,248,2,16,70,247,178,4,227,6,26,24,80,231,184,50,208,232,109,32,133,23,143,8,210,1,52,240,135,248,126,242,5,32,79,243,209,232,79,9,111,239,113,19,193,238,192,2,160,13,92,223,245,39,50,2,14,0,36,237,206,240,81,226,144,239,162,243,108,4,56,191,6,254,117,5,122,24,235,12,150,22,45,9,185,12,55,244,134,30,192,4,16,29,144,216,154,49,176,3,197,4,109,249,152,0,132,23,26,225,57,15,214,228,33,219,146,217,236,240,249,234,124,239,68,248,51,240,18,29,128,234,97,8,124,2,41,11,70,238,204,252,179,16,200,247,212,19,71,20,149,254,42,165,170,7,190,255,126,29,88,0,17,34,175,250,53,30,155,245,162,20,8,236,232,255,49,252,128,243,69,247,24,20,213,0,60,231,122,240,242,4,177,246,128,9,132,255,23,255,80,242,108,41,38,3,106,252,81,45,132,75,206,0,32,29,75,221,36,218,15,12,101,14,121,247,142,226,194,46,22,236,60,227,107,251,229,243,132,25,62,229,14,18,196,252,134,1,211,1,12,235,90,17,170,248,245,34,12,239,251,254,96,245,3,26,56,63,104,230,104,241,200,195,158,61,206,254,112,239,241,248,192,215,65,43,183,10,134,15,75,234,85,242,195,20,10,214,134,254,91,238,195,232,16,226,242,244,146,230,48,232,4,8,97,13,179,7,0,243,206,20,174,250,14,7,50,200,26,206,170,23,219,242,33,253,230,245,30,183,8,26,30,37,202,249,67,1,45,25,154,186,102,57,198,217,112,14,61,238,65,6,61,14,184,253,142,3,212,9,5,32,58,15,210,16,119,2,28,248,213,16,3,253,65,230,35,8,9,35,62,250,229,255,170,35,80,233,44,33,121,255,182,8,248,8,99,238,248,17,87,19,138,7,252,245,255,232,198,250,39,210,243,24,191,241,185,234,98,246,113,237,12,252,195,13,80,242,218,218,68,244,145,244,144,245,204,246,33,253,179,0,182,3,198,6,77,4,105,6,182,249,119,251,186,249,77,255,158,249,55,13,158,253,240,0,73,0,104,4,50,3,228,251,151,249,212,2,110,248,51,249,69,251,127,15,196,7,165,5,194,11,155,8,107,249,94,249,210,248,9,253,112,255,3,2,231,3,191,4,167,12,136,248,0,248,53,249,48,250,108,255,54,6,90,5,42,4,246,4,95,245,155,249,99,0,84,248,224,0,78,252,99,250,70,252,243,2,140,5,16,245,93,247,0,247,0,248,245,18,54,253,129,254,111,8,31,7,24,9,173,249,208,249,209,248,86,21,89,249,222,252,29,255,229,1,249,3,159,6,101,246,95,9,228,248,206,8,163,250,1,253,53,0,193,2,50,4,13,5,210,249,74,246,96,247,219,246,40,247,172,247,214,249,237,251,66,1,5,30,106,247,24,249,198,247,16,0,97,247,41,250,174,251,63,252,30,254,106,6,129,26,252,249,252,249,87,250,103,251,170,252,205,254,85,3,255,4,169,5,181,12,109,250,10,9,63,250,39,252,255,251,191,254,155,3,116,4,142,4,112,245,104,10,116,246,99,245,225,1,11,12,87,250,201,4,96,12,85,9,180,247,67,248,194,250,109,248,144,248,128,18,139,252,198,252,26,15,254,7,222,254,201,253,62,248,168,248,174,7,47,254,102,6,171,2,237,3,75,4,230,244,23,246,1,246,133,246,37,251,199,15,91,5,57,15,225,9,96,9,230,245,208,250,17,3,95,249,197,6,78,9], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+368640);
/* memory initializer */ allocate([70,254,190,0,133,3,1,5,147,245,150,8,34,250,132,250,33,10,74,253,70,255,210,1,41,4,175,4,143,248,147,250,27,24,231,248,255,253,35,252,156,254,246,0,83,6,91,7,36,0,126,247,190,249,96,2,13,250,23,0,241,4,66,2,185,3,14,4,29,254,26,247,166,247,52,249,72,2,244,0,202,255,64,255,147,3,73,4,43,255,223,249,69,7,135,250,102,14,167,249,46,251,154,253,92,3,31,5,139,250,11,9,104,7,184,249,210,250,49,250,157,255,193,8,185,2,132,4,175,6,205,247,29,250,121,255,142,5,73,253,199,255,110,5,55,3,169,3,134,255,223,1,47,0,160,247,22,250,187,3,219,250,42,253,224,1,129,4,113,244,2,246,243,245,181,250,169,248,90,250,35,25,165,2,52,12,62,12,58,7,42,7,140,250,119,250,10,5,128,252,207,253,148,5,239,3,81,4,203,247,4,248,243,6,135,248,180,248,130,5,148,3,208,4,88,4,55,5,153,245,152,255,255,253,160,255,42,254,224,1,236,5,106,255,42,1,202,2,2,246,4,12,212,1,23,253,79,252,69,254,175,252,35,252,85,1,78,4,177,1,76,2,20,249,206,1,241,253,158,2,128,255,148,255,71,2,189,2,23,247,155,247,162,246,67,245,3,246,101,249,185,251,56,5,128,35,4,15,249,248,187,248,140,248,62,247,120,247,9,9,195,14,215,252,7,2,181,8,134,248,119,249,228,6,134,253,93,248,71,249,149,1,13,254,243,0,96,6,183,246,121,28,133,249,40,249,195,250,76,252,189,254,73,3,167,6,238,6,19,248,80,9,171,248,130,248,63,249,203,5,227,1,124,7,64,2,234,4,250,246,252,248,160,8,213,249,57,0,57,249,119,251,57,20,138,6,164,9,141,248,37,250,76,7,227,8,148,253,156,254,28,255,233,1,40,4,81,3,85,253,76,251,31,249,93,247,162,253,4,253,224,251,48,15,253,0,238,5,5,246,229,247,119,0,225,249,203,3,102,251,123,10,196,5,210,3,139,5,125,244,142,246,140,247,154,4,46,6,190,5,128,3,133,2,135,6,182,5,70,247,173,250,96,251,128,5,18,4,189,251,48,255,207,255,15,2,149,3,242,4,92,250,130,247,113,246,4,247,60,249,4,12,255,21,248,0,147,8,83,246,68,249,126,246,83,246,36,246,220,248,27,9,77,3,143,5,231,6,167,246,102,248,167,252,50,254,88,1,17,0,128,252,87,9,124,3,114,3,196,252,232,254,16,253,144,251,229,249,240,251,198,4,107,251,227,6,155,4,88,250,154,7,233,248,204,249,154,249,254,250,230,12,132,0,253,1,128,5,56,245,222,246,113,248,73,5,5,250,206,251,132,4,14,12,94,5,131,6,254,8,169,249,151,248,57,248,18,254,43,10,14,253,12,2,241,4,24,5,246,11,177,250,171,250,195,7,202,250,108,252,110,255,216,255,123,2,9,4,188,6,223,251,49,0,121,251,250,252,106,0,29,4,103,255,134,0,179,2,137,255,54,251,76,1,149,254,59,255,187,255,123,255,61,2,190,0,216,0,68,247,218,254,8,5,194,247,255,249,19,252,105,251,56,0,131,16,87,6,120,246,154,248,169,249,183,246,239,8,60,251,30,250,177,0,57,22,33,11,215,244,138,247,14,246,126,8,146,246,217,246,47,2,4,252,42,18,186,13,197,244,29,5,3,246,26,246,69,247,147,248,23,6,60,17,253,8,156,8,103,244,30,248,161,246,238,244,129,246,36,5,62,250,245,4,229,9,157,13,180,244,173,246,100,245,243,246,17,248,56,248,225,250,135,31,93,15,223,14,165,247,117,7,104,247,216,246,244,247,154,249,126,251,46,255,221,10,91,8,95,4,220,248,235,247,254,246,73,248,115,251,68,254,21,3,105,9,15,6,143,244,153,255,128,248,38,248,120,252,182,2,68,255,4,0,27,4,166,4,167,245,106,246,99,247,141,249,192,248,240,249,115,251,96,1,23,13,242,4,73,249,57,0,220,248,92,254,86,252,29,251,51,254,14,5,134,4,125,3,112,245,101,246,211,246,1,250,247,10,109,1,40,4,124,3,62,3,198,4,114,247,250,249,19,247,43,25,185,249,174,250,163,253,125,2,115,3,109,3,182,246,244,8,34,12,223,251,240,6,186,251,165,252,249,0,199,0,0,1,255,249,50,8,154,251,195,8,94,251,63,255,45,255,211,0,246,1,52,1,41,13,125,12,9,251,166,250,157,254,89,254,231,253,212,1,19,255,157,255,97,250,44,249,119,247,76,248,179,250,210,252,42,254,47,3,26,5,246,24,191,7,111,251,43,249,227,255,168,250,41,23,253,249,124,252,64,2,189,2,172,6,184,249,132,251,194,13,202,252,136,255,51,254,98,255,213,255,39,0,17,246,168,34,189,250,212,249,222,0,24,254,94,255,39,1,126,1,35,1,135,43,57,251,10,251,137,250,120,254,205,253,12,254,164,253,224,253,121,255,5,249,223,250,46,250,141,250,180,251,2,251,206,252,28,24,0,3,61,6,145,253,87,253,152,251,217,249,89,28,103,253,3,252,73,254,164,3,191,2,40,250,136,247,103,248,82,250,216,252,19,251,158,254,107,3,50,26,164,7,19,249,33,250,0,250,118,251,150,250,163,248,185,249,194,254,184,255,249,255,116,248,187,250,6,24,196,248,167,254,238,255,175,255,223,0,83,1,169,1,106,1,169,249,104,250,75,248,238,251,163,250,150,30,38,0,140,255,232,3,165,1,185,246,240,248,216,248,234,251,29,8,187,3,40,6,69,2,56,3,27,248,210,249,134,250,116,250,69,0,221,13,255,253,192,0,6,1,227,1,57,246,77,16,245,255,4,250,131,252,26,1,187,0,64,1,176,0,3,1,252,246,38,9,175,246,157,247,240,252,137,254,157,1,65,3,121,3,17,5,135,5,195,251,15,252,35,250,34,251,238,250,17,6,104,5,76,1,150,2,178,8,161,246,40,249,167,252,107,7,131,0,245,1,209,0,217,0,90,1,198,16,237,248,98,249,200,251,16,253,249,254,28,255,249,0,116,2,203,3,204,9,249,251,55,11,226,251,42,0,54,255,30,253,86,255,17,255,222,254,65,245,181,246,181,246,49,248,88,250,132,254,58,6,255,4,119,5,97,6,184,246,209,248,87,5,149,6,100,1,130,255,206,255,143,0,31,0,33,0,58,1,160,0,105,253,81,253,25,0,132,1,245,254,68,255,68,255,127,255,202,245,39,4,213,248,227,254,245,9,205,0,226,255,114,1,63,1,41,1,169,255,96,247,116,251,185,252,126,3,246,254,102,254,119,1,239,4,156,3,210,245,235,246,194,248,0,7,151,1,72,1,146,255,63,2,66,4,203,3,43,246,209,249,75,5,156,248,22,254,53,255,78,3,212,2,85,2,11,3,142,249,255,250,242,250,37,2,110,255,220,253,131,11,228,255,9,1,83,1,0,250,200,246,182,246,166,247,156,250,166,254,39,6,219,10,175,12,153,6,172,254,4,249,209,248,103,0,31,0,85,3,115,253,87,12,109,1,154,0,148,1,189,252,52,253,221,255,213,16,101,255,66,251,100,251,18,253,246,253,15,253,94,1,132,249,189,249,121,251,186,253,23,254,43,4,55,10,211,6,37,249,209,246,246,246,83,250,154,3,130,13,99,3,183,1,237,1,188,4,208,249,137,249,20,5,247,6,105,6,162,5,48,3,253,250,80,250,119,250,134,19,131,7,56,255,194,251,220,251,8,252,206,251,63,251,251,250,35,251,121,2,134,1,93,250,181,251,5,254,225,11,87,1,93,255,23,253,101,253,29,9,160,247,100,246,57,247,241,247,56,249,26,253,162,1,52,12,176,13,227,0,33,253,31,3,210,250,236,255,225,253,108,7,237,0,97,253,223,253,65,249,121,0,42,249,116,14,27,254,215,253,179,255,44,255,174,3,62,0,111,6,80,253,30,250,107,250,149,253,185,252,172,0,137,12,12,254,141,254,112,249,128,250,158,251,205,253,43,14,141,255,254,1,22,2,191,255,199,0,32,3,176,19,119,2,24,253,156,253,1,252,181,251,217,250,16,250,76,250,160,251,238,254,60,251,93,1,56,7,148,253,125,250,152,253,235,6,0,4,57,251,109,247,215,246,160,247,19,250,225,251,127,254,45,2,202,5,141,26,30,247,50,3,52,254,61,253,238,254,134,2,142,2,219,2,12,1,91,1,231,17,247,250,84,250,87,251,208,251,87,253,78,255,125,255,148,255,35,2,15,250,243,252,238,250,239,0,26,254,67,254,125,13,30,255,90,0,141,2,43,251,112,2,84,18,30,254,226,252,225,252,2,253,123,253,134,252,109,252,164,14,115,252,12,252,85,0,195,3,119,1,156,255,14,252,11,251,28,250,58,8,86,251,72,10,83,2,198,252,35,255,101,254,176,251,171,250,230,251,192,247,161,252,151,7,41,253,201,251,35,253,78,0,198,7,107,1,185,3,45,5,203,1,133,252,36,13,102,254,150,254,221,253,30,252,165,250,22,251,238,47,213,255,124,249,180,248,44,248,171,247,185,248,99,248,243,248,248,250,152,249,199,14,122,250,190,253,7,254,48,254,98,255,252,0,71,0,76,0,22,0,236,255,184,255,243,255,237,255,161,255,242,255,2,0,23,0,251,255,9,5,118,2,35,1,61,253,230,252,167,252,53,253,134,255,39,2,219,0,202,246,143,248,139,250,21,1,60,2,87,1,21,3,14,2,93,6,223,3,44,252,222,0,228,2,175,4,19,0,176,4,160,252,45,254,112,253,118,255,52,3,43,248,100,252,154,0,195,0,137,1,11,1,73,255,0,4,100,0,219,4,152,252,63,253,243,252,90,254,135,254,114,252,131,253,89,0,33,11,44,0,160,214,192,252,99,254,100,2,18,2,123,1,241,2,162,5,66,244,166,252,203,251,14,209,60,255,253,252,138,251,140,253,134,244,73,254,5,243,20,0,225,48,98,246,10,251,199,255,31,223,78,253,22,3,20,1,45,9,171,254,148,249,230,0,128,247,54,255,123,198,170,0,189,6,214,11,171,2,25,255,129,2,14,255,76,243,110,0,96,250,70,11,69,250,125,251,59,56,41,1,52,0,240,0,98,15,152,38,125,226,66,251,23,13,129,0,11,251,88,255,157,2,197,53,247,250,47,254,33,39,136,253,184,254,236,254,223,255,31,0,195,73,108,255,125,255,13,2,133,6,240,8,53,255,100,3,108,253,248,0,103,254,165,255,39,1,42,220,52,250,161,3,8,11,73,4,123,243,143,255,152,10,248,249,15,2,139,5,61,252,124,254,179,2,105,190,172,255,72,0,38,241,155,254,97,6,178,196,62,0,120,232,26,253,236,234,118,17,58,255,1,0,148,5,101,249,27,73,122,5,21,246,137,254,249,222,123,252,109,255,54,243,143,36,235,254,19,221,202,2,18,11,108,11,74,231,139,3,133,255,247,40,28,254,92,237,109,3,112,38,7,254,118,226,45,1,159,2,116,0,141,254,156,14,103,1,129,1,231,235,116,252,156,0,167,37,198,14,40,218,138,239,79,252,251,225,78,1,137,8,194,250,132,1,51,249,22,1,25,255,112,252,137,3,241,251,86,2,1,8,150,2,58,255,106,87,166,0,116,0,93,249,79,1,68,223,255,4,0,6,107,58,230,4,190,0,41,246,160,253,108,1,207,253,116,22,102,251,101,252,111,12,197,255,56,54,30,246,241,0,204,253,193,254,170,226,247,255,132,255,134,176,49,1,231,255,112,254,222,0,209,189,24,254,34,3,107,249,251,12,202,231,232,3,121,252,178,252,125,254,206,1,79,3,14,2,40,39,228,7,42,8,165,218,136,5,169,0,106,208,84,254,148,40,101,3,44,4,153,8,239,251,148,243,152,0,122,253,4,0,177,15,211,251,51,1,163,20,205,11,162,202,19,254,9,0,30,2,152,0,199,245,226,240,254,253,185,52,156,4,165,253,231,4,92,9,250,28,198,34,99,212,190,245,169,233,228,6,90,3,81,4,196,5,28,249,177,7,209,3,54,249,96,252,140,201,164,5,195,239,68,3,45,208,143,254,0,255,191,194,200,20,206,235,3,254,97,1,211,249,81,250,197,3,204,2,209,0,141,252,195,254,87,248,168,35,251,223,125,8,126,246,154,251,226,15,1,4,233,190,155,228,109,255,81,6,23,253,123,243,216,5,30,7,81,251,73,244,117,0,107,2,222,177,24,255,142,0,135,12,49,2,220,254,157,249,11,4,37,0,152,10,13,255,179,223,49,1,215,245,239,1,180,56,63,3,4,1,202,255,121,16,163,2,160,249,98,19,25,3,42,4,133,0,168,254,116,207,95,0,20,24,238,250,188,248,38,14,45,254,157,252,102,251,45,43,118,0,220,255,171,228,5,253,147,62,16,0,155,9,50,1,204,252,145,251,79,3,59,253,160,3,92,255,219,254,152,233,31,2,228,210,13,21,36,248,44,1,28,255,237,251,243,19,210,253,163,4,116,255,22,205,221,249,228,2,153,236,80,254,111,231,14,249,121,13,175,254,193,206,88,1,50,241,194,249,238,254,166,254,42,250,148,255,69,1,65,251,51,3,148,1,200,253,226,254,140,172,135,60,7,247,94,2,117,0,10,0,63,255,52,252,220,254,195,253,125,251,247,250,255,251,216,1,130,4,75,3,187,0,74,2,89,80,251,255,20,255,99,251,188,251,188,2,123,3,165,253,167,253,144,84,63,254,63,255,177,251,214,254,36,8,5,255,193,1,122,250,16,67,121,254,104,0,167,234,145,1,135,34,13,3,205,6,201,0,143,254,210,1,70,48,132,253,79,252,88,15,163,253,219,187,156,19,247,250,209,3,198,231,247,6,5,254,180,255,11,1,225,255,85,245,232,249,55,251,68,5,168,43,133,6,242,2,135,6,58,240,151,0,141,254,115,28,243,0,107,5,126,0,239,3,12,5,241,255,184,2,26,1,193,245,41,4,254,251,191,0,136,253,124,255,99,205,224,255,95,249,90,254,16,255,72,5,12,40,43,4,104,32,36,251,247,255,211,254,58,244,7,255,140,254,235,41,23,2,99,8,1,221,90,1,104,254,119,223,143,248,208,255,16,224,222,10,156,1,145,5,78,252,20,253,71,4,166,250,126,35,157,255,113,255,68,0,224,253,8,1,238,1,135,254,13,0,150,253,237,0,193,0,221,13,61,1,88,255,20,228,47,9,12,255,72,204,229,242,238,246,235,253,82,37,250,26,124,0,74,253,123,252,54,245,207,0,109,252,40,246,113,255,96,33,90,253,28,245,126,50,23,3,16,5,253,18,66,250,121,3,91,14,38,3,34,1,118,212,166,1,1,36,225,255,72,6,140,0,99,15,9,229,236,254,64,253,49,9,168,254,242,251,26,255,79,255,158,2,151,253,127,255,167,252,217,223,126,2,101,254,4,255,163,194,62,251,210,0,32,1,30,2,21,2,129,220,3,215,144,253,151,4,99,2,26,255,234,2,175,5,178,253,62,3,220,6,72,194,55,3,203,251,20,3,47,4,212,1,138,249,148,2,215,3,31,218,236,250,150,2,5,8,231,254,149,50,133,1,109,252,197,0,50,249,21,238,210,6,195,2,89,6,61,35,156,8,247,2,23,5,84,254,36,255,41,0,133,234,48,193,63,255,187,1,187,1,178,255,121,3,207,253,253,21,207,251,107,27,222,0,125,6,166,4,84,4,94,0,248,21,44,241,151,1,62,253,134,255,232,2,107,1,112,6,112,213,83,2,185,3,85,0,245,254,195,0,83,3,21,67,132,253,243,0,139,3,237,7,68,253,95,1,215,5,99,255,193,253,112,210,228,4,149,32,152,253,124,14,61,22,250,255,39,249,48,4,95,3,201,252,74,239,245,208,238,2,85,2,73,12,38,0,52,224,64,12,34,1,7,0,76,43,148,252,50,7,175,0,130,13,204,1,79,6,178,45,197,252,16,0,62,207,172,1,155,1,65,10,184,250,142,0,17,2,229,0,208,255,59,252,111,255,176,253,143,2,243,1,79,86,125,86,37,0,173,248,189,2,45,0,212,2,87,4,95,6,6,1,4,255,124,220,205,20,152,1,131,253,156,253,135,2,244,4,66,3,2,254,91,2,199,0,48,3,80,217,61,37,212,249,109,10,32,7,212,247,67,253,241,254,65,29,46,0,33,243,180,252,208,254,30,255,252,254,76,253,251,255,241,253,37,0,207,255,250,249,187,255,193,251,39,80,111,1,1,0,159,13,231,9,10,236,130,2,199,4,174,247,178,244,216,6,174,249,4,38,159,249,248,26,137,0,142,2,154,254,99,1,235,255,235,254,188,255,68,255,132,0,18,2,116,1,197,254,22,211,221,0,47,3,176,9,138,250,133,255,97,1,42,12,7,209,68,251,169,251,148,3,52,25,168,248,75,7,51,1,190,255,65,7,138,0,44,252,240,243,82,255,215,255,119,254,112,253,79,3,208,61,133,254,102,1,160,2,123,254,152,3,103,173,119,254,94,1,194,253,237,3,221,247,26,0,79,0,53,255,225,224,26,243,83,233,4,3,210,254,56,8,40,251,142,53,160,26,234,8,131,241,24,250,175,255,88,247,67,244,188,1,229,252,239,2,115,8,15,81,12,3,30,2,32,254,112,2,87,254,1,3,170,9,241,232,143,1,68,41,144,255,69,0,127,250,93,7,35,9,67,0,148,253,196,0,128,246,158,23,119,249,112,25,41,3,224,30,252,253,182,16,223,0,103,1,128,64,200,4,32,254,7,254,33,253,10,254,175,253,43,238,122,7,122,0,237,253,162,5,208,1,69,0,36,1,154,1,187,253,120,178,35,4,132,0,112,5,29,23,193,2,230,225,192,9,49,250,233,252,163,46,185,0,247,254,148,246,118,2,164,224,154,5,75,40,251,249,84,241,157,246,130,248,26,4,121,31,234,0,234,52,164,255,132,247,97,253,111,45,103,0,116,0,85,255,4,238,245,254,166,253,15,0,198,1,203,26,153,247,253,221,128,249,61,0,214,9,55,252,135,3,185,4,101,250,219,52,78,2,236,0,203,252,86,2,162,4,246,225,134,0,19,252,255,184,108,255,7,2,132,3,183,3,150,1,0,242,47,0,223,36,138,5,227,252,231,242,65,253,250,248,36,251,35,1,32,245,20,57,237,7,95,255,16,4,222,239,248,11,185,6,174,244,13,1,39,13,99,5,23,56,78,253,113,253,218,7,185,236,87,253,210,245,131,45,236,2,101,0,25,53,117,2,28,0,228,253,170,252,125,5,46,2,175,221,8,252,13,205,121,0,212,253,95,19,158,6,48,253,118,255,199,240,182,0,146,7,76,3,151,3,85,253,10,47,179,251,101,255,161,250,27,250,11,0,220,0,53,3,217,84,145,254,134,253,68,250,82,255,234,3,77,251,62,1,152,45,190,247,168,9,91,249,44,23,107,253,70,4,196,9,23,234,254,0,181,1,113,252,181,249,187,224,217,0,141,251,41,5,39,214,121,247,139,4,134,252,146,253,20,50,253,3,246,202,16,4,144,12,80,2,174,2,225,2,191,244,99,249,155,15,57,254,58,18,228,239,156,219,13,8,149,41,15,1,8,1,83,229,129,2,13,8,229,229,0,254,21,253,85,220,141,9,87,1,40,217,184,244,95,2,153,213,103,3,162,1,248,1,168,3,55,4,17,1,144,1,168,186,121,254,249,249,207,231,202,5,225,2,48,8,42,252,167,0,204,3,80,1,39,4,8,251,190,249,141,248,9,0,65,255,153,196,137,255,207,15,199,5,131,250,14,2,226,183,141,253,52,248,2,252,248,249,56,1,36,31,29,255,29,3,172,235,144,247,135,1,89,254,1,1,252,14,186,1,117,248,22,0,143,0,53,255,106,1,183,255,63,61,223,254,91,250,65,2,90,3,144,44,78,248,2,252,14,6,114,3,141,241,119,245,138,15,88,2,86,0,18,15,235,33,255,225,8,237,211,15,215,250,181,253,46,0,13,254,158,254,113,253,155,194,67,0,234,1,146,245,218,1,162,250,225,21,60,0,49,187,216,252,87,0,111,1,67,2,33,4,252,3,118,254,157,4,67,255,162,213,251,2,75,10,26,1,49,243,158,252,103,196,63,254,112,0,39,195,227,0,13,1,140,54,7,251,233,5,49,250,195,0,63,1,223,9,226,254,5,233,16,235,65,252,231,10,249,242,79,252,63,248,121,252,102,211,77,33,157,2,218,23,153,0,111,251,82,251,215,253,125,27,16,2,115,239,205,2,42,255,32,7,124,39,193,3,117,35,107,7,167,40,49,255,227,255,99,1,118,229,111,0,197,202,81,5,7,242,35,1,182,17,161,8,213,249,109,0,11,2,200,1,238,42,31,0,64,254,129,1,201,5,2,0,162,59,30,3,127,22,92,3,216,191,221,250,95,6,56,254,47,252,76,255,223,245,167,4,71,23,224,255,176,31,6,254,170,225,177,248,50,196,150,2,196,0,79,176,157,3,190,1,13,248,148,253,82,253,7,255,43,246,167,1,191,2,121,2,60,3,74,255,219,255,106,254,107,255,53,3,17,169,140,2,10,2,247,228,225,61,2,188,197,62,91,177,47,63,66,62,88,63,72,80,108,63,63,87,131,63,114,249,143,63,250,237,179,63,177,191,212,63,43,135,230,63,242,65,239,63,111,129,4,64,4,86,22,64,180,200,38,64,230,63,48,64,235,115,57,64,238,90,2,62,16,122,118,62,165,44,195,62,208,179,25,63,208,213,70,63,110,52,112,63,5,52,145,63,143,228,170,63,127,251,194,63,31,244,220,63,48,42,249,63,45,33,11,64,53,94,22,64,108,9,33,64,127,217,45,64,143,228,58,64,242,210,77,62,250,126,170,62,29,201,229,62,6,129,37,63,68,250,77,63,141,40,125,63,99,238,146,63,111,240,165,63,86,14,189,63,138,142,212,63,204,127,240,63,90,100,7,64,108,9,21,64,11,70,33,64,71,114,45,64,146,92,58,64,215,52,239,61,9,249,96,62,130,226,167,62,224,45,240,62,247,117,32,63,193,57,83,63,137,210,134,63,60,189,162,63,72,80,188,63,185,141,214,63,108,9,241,63,45,33,7,64,8,172,20,64,155,230,33,64,209,34,47,64,248,83,59,64,59,223,15,62,73,46,159,62,128,72,255,62,220,104,48,63,200,7,93,63,96,118,135,63,5,52,161,63,206,170,183,63,5,197,207,63,130,226,231,63,180,200,254,63,78,98,12,64,72,80,24,64,202,50,36,64,200,7,49,64,221,181,60,64,32,99,46,62,182,132,156,62,0,111,225,62,143,194,5,63,112,206,24,63,178,157,79,63,202,84,137,63,233,38,169,63,168,53,197,63,16,122,222,63,60,78,249,63,131,192,10,64,77,243,22,64,179,234,35,64,254,212,48,64,88,57,60,64,176,3,231,61,185,141,134,62,222,147,231,62,162,69,38,63,60,78,81,63,35,74,123,63,75,89,150,63,238,124,175,63,57,69,199,63,251,58,224,63,197,143,249,63,245,74,9,64,22,106,21,64,86,125,34,64,231,29,47,64,35,74,59,64,217,61,57,62,94,75,168,62,125,63,5,63,90,245,57,63,95,7,110,63,222,147,143,63,25,4,166,63,169,164,190,63,185,252,215,63,221,181,236,63,184,175,3,64,171,62,15,64,134,56,26,64,147,169,38,64,247,228,49,64,240,22,60,64,55,26,128,62,206,25,241,62,105,111,48,63,88,168,85,63,26,192,107,63,242,210,133,63,11,181,158,63,181,21,187,63,245,185,210,63,150,67,235,63,61,10,3,64,63,87,15,64,35,219,29,64,133,235,41,64,82,73,49,64,145,237,56,64,244,253,212,61,178,157,111,62,241,244,202,62,170,241,18,63,39,194,70,63,86,125,126,63,154,153,153,63,19,97,179,63,113,27,205,63,52,17,230,63,29,56,255,63,160,137,12,64,17,54,24,64,66,62,36,64,36,185,48,64,150,178,60,64,239,201,67,62,187,184,173,62,115,215,242,62,224,156,33,63,141,40,77,63,4,231,124,63,119,190,151,63,156,51,178,63,172,173,200,63,152,76,221,63,54,171,246,63,188,116,7,64,5,197,19,64,76,166,34,64,206,170,47,64,84,82,59,64,203,161,197,61,41,92,79,62,68,250,173,62,238,124,255,62,170,130,49,63,23,72,112,63,221,36,150,63,110,52,176,63,188,5,202,63,86,159,227,63,223,79,253,63,233,183,11,64,238,124,23,64,255,178,35,64,4,231,48,64,4,231,60,64,208,179,89,62,127,251,186,62,182,243,13,63,80,141,55,63,237,13,94,63,39,49,136,63,14,190,160,63,22,251,179,63,58,146,203,63,178,157,231,63,145,237,252,63,203,161,9,64,174,182,22,64,20,174,35,64,124,242,44,64,20,208,56,64,181,21,59,62,68,105,175,62,163,146,250,62,194,23,38,63,168,198,75,63,147,24,116,63,222,147,143,63,125,208,163,63,222,113,186,63,49,153,210,63,148,246,230,63,208,68,0,64,193,57,15,64,170,130,29,64,93,220,42,64,229,97,57,64,23,72,80,62,184,175,195,62,226,233,5,63,14,45,50,63,31,133,107,63,15,11,133,63,79,175,148,63,23,72,176,63,118,79,198,63,242,210,221,63,3,120,251,63,38,228,7,64,109,86,21,64,118,79,34,64,87,91,45,64,166,155,60,64,61,10,215,61,170,241,82,62,45,178,189,62,126,140,25,63,93,109,85,63,183,98,135,63,85,193,160,63,183,98,183,63,64,19,209,63,18,131,232,63,79,30,254,63,212,43,13,64,210,0,26,64,54,60,37,64,205,204,48,64,253,135,60,64,60,78,17,62,123,131,207,62,250,126,42,63,33,31,100,63,27,47,133,63,54,205,147,63,169,19,160,63,184,64,178,63,46,144,200,63,121,88,224,63,77,21,252,63,70,37,13,64,189,227,24,64,85,193,36,64,231,140,48,64,174,182,58,64,154,8,27,62,215,163,144,62,237,158,220,62,97,195,19,63,100,59,63,63,149,101,120,63,174,182,146,63,222,113,170,63,218,27,196,63,75,234,220,63,66,207,246,63,55,26,8,64,223,224,19,64,220,104,32,64,147,58,45,64,156,51,58,64,251,92,45,62,83,150,161,62,236,192,249,62,35,219,41,63,215,18,82,63,102,247,116,63,109,197,142,63,29,56,167,63,44,101,193,63,136,244,219,63,191,125,245,63,98,161,6,64,230,174,17,64,23,217,30,64,62,121,44,64,162,69,58,64,5,163,18,62,95,41,139,62,163,35,217,62,59,112,14,63,110,163,49,63,125,174,102,63,230,63,148,63,206,136,178,63,231,29,207,63,11,181,230,63,132,158,253,63,209,34,11,64,58,35,22,64,28,235,34,64,65,241,47,64,151,144,59,64,213,231,106,62,120,122,197,62,160,26,15,63,118,79,62,63,8,61,107,63,120,11,140,63,111,18,163,63,108,9,185,63,18,20,207,63,189,82,230,63,234,4,252,63,136,133,10,64,92,143,22,64,201,118,34,64,146,203,47,64,39,49,60,64,104,179,42,62,73,46,159,62,104,34,236,62,81,107,26,63,205,204,60,63,56,248,98,63,131,192,138,63,18,20,167,63,5,197,191,63,199,41,218,63,157,17,245,63,24,38,7,64,44,212,18,64,38,228,31,64,109,86,45,64,222,113,58,64,16,88,57,62,147,24,164,62,105,111,240,62,123,131,31,63,15,156,67,63,77,243,126,63,203,16,159,63,32,210,183,63,19,97,203,63,46,144,224,63,45,67,244,63,242,176,4,64,140,185,15,64,231,140,28,64,167,121,43,64,42,58,58,64,32,99,238,61,82,39,192,62,63,87,27,63,169,19,64,63,174,71,129,63,220,70,155,63,231,140,176,63,152,221,195,63,215,163,208,63,143,194,229,63,250,237,243,63,49,153,6,64,18,131,24,64,156,196,36,64,62,121,44,64,131,47,56,64,211,222,32,62,82,39,224,62,127,106,44,63,134,201,84,63,102,247,100,63,63,87,123,63,248,194,148,63,56,103,180,63,227,54,210,63,171,62,231,63,157,128,246,63,97,195,11,64,87,236,27,64,131,47,40,64,89,23,47,64,137,65,56,64,187,39,15,62,240,133,137,62,99,127,217,62,246,151,29,63,213,120,73,63,176,114,128,63,236,192,153,63,29,56,175,63,122,165,196,63,196,177,222,63,99,238,250,63,146,92,10,64,115,104,21,64,237,158,32,64,206,136,46,64,136,244,59,64,38,228,67,62,213,231,170,62,155,85,255,62,129,4,37,63,222,2,73,63,30,22,130,63,11,36,152,63,63,53,174,63,232,217,196,63,68,139,220,63,252,169,241,63,77,132,5,64,170,241,18,64,9,138,31,64,175,148,45,64,0,145,58,64,90,245,185,61,161,103,51,62,198,109,148,62,16,88,9,63,125,174,70,63,174,71,129,63,236,47,155,63,207,247,179,63,15,11,205,63,43,135,230,63,113,27,253,63,39,49,12,64,38,228,23,64,185,252,35,64,37,6,49,64,76,55,61,64,34,142,53,62,202,195,162,62,246,40,252,62,233,183,47,63,7,95,88,63,251,92,125,63,217,206,151,63,64,164,175,63,141,151,198,63,188,5,226,63,50,119,253,63,64,164,11,64,2,43,23,64,44,212,34,64,102,102,46,64,12,2,59,64,184,175,3,62,233,183,111,62,118,224,188,62,131,81,9,63,162,180,55,63,41,92,111,63,198,220,141,63,159,171,165,63,206,170,191,63,238,90,218,63,54,205,243,63,248,83,7,64,177,191,20,64,118,79,34,64,255,178,47,64,162,180,59,64,85,193,104,62,1,77,196,62,201,118,14,63,126,29,56,63,103,213,87,63,247,6,127,63,0,145,150,63,116,181,173,63,62,232,201,63,148,246,222,63,29,201,245,63,8,61,7,64,125,174,18,64,226,88,31,64,197,32,44,64,131,192,58,64,143,194,53,62,209,145,156,62,44,212,218,62,85,48,26,63,101,170,80,63,44,101,137,63,206,25,169,63,69,71,194,63,57,214,213,63,7,95,232,63,22,251,251,63,57,214,9,64,129,38,22,64,51,196,33,64,90,245,45,64,217,95,58,64,103,68,41,62,100,93,220,62,115,215,34,63,94,75,72,63,181,21,107,63,29,201,133,63,65,130,154,63,131,47,180,63,210,111,207,63,42,58,234,63,209,145,0,64,154,119,12,64,195,245,24,64,233,72,38,64,156,51,50,64,128,183,60,64,227,199,24,62,175,148,133,62,129,149,195,62,127,106,12,63,186,107,57,63,0,145,110,63,184,175,147,63,171,207,173,63,161,103,195,63,39,160,217,63,12,147,241,63,157,128,6,64,236,81,20,64,22,106,33,64,168,87,46,64,187,39,59,64,170,96,84,62,83,150,193,62,180,89,5,63,174,216,47,63,58,146,91,63,205,204,124,63,206,170,151,63,159,171,173,63,66,207,190,63,84,227,221,63,19,242,241,63,103,213,7,64,103,213,19,64,167,121,31,64,124,242,44,64,147,24,56,64,95,41,11,62,66,207,102,62,66,62,168,62,28,235,226,62,2,154,40,63,120,122,101,63,102,102,142,63,43,24,173,63,71,3,200,63,222,2,225,63,95,7,254,63,39,49,12,64,11,181,22,64,3,120,35,64,15,11,49,64,125,208,59,64,152,110,18,62,245,219,151,62,59,223,239,62,134,56,38,63,47,221,84,63,38,228,131,63,127,106,156,63,230,63,180,63,106,188,204,63,102,247,228,63,113,27,253,63,231,29,11,64,181,21,23,64,91,177,35,64,7,95,48,64,39,49,60,64,171,62,23,62,204,238,137,62,206,170,207,62,142,6,16,63,111,129,52,63,251,92,93,63,233,72,134,63,174,216,159,63,132,158,189,63,136,133,218,63,184,30,245,63,63,87,7,64,118,113,19,64,238,235,32,64,68,250,45,64,143,228,58,64,86,14,45,62,35,74,155,62,250,126,234,62,95,41,43,63,136,133,90,63,26,192,131,63,236,47,155,63,165,44,179,63,190,48,201,63,158,94,225,63,190,159,250,63,207,247,7,64,176,3,19,64,16,122,30,64,104,34,44,64,153,187,58,64,64,164,223,61,233,72,142,62,62,121,248,62,197,32,48,63,125,174,102,63,202,50,140,63,193,57,163,63,67,28,187,63,63,198,212,63,95,152,236,63,138,176,1,64,214,197,13,64,116,181,25,64,16,88,37,64,43,24,49,64,241,99,60,64,245,74,25,62,227,54,186,62,90,245,25,63,132,158,77,63,132,13,127,63,238,124,151,63,130,226,175,63,53,239,200,63,86,125,222,63,56,103,244,63,68,139,4,64,14,79,15,64,243,31,26,64,41,237,37,64,67,173,49,64,200,7,61,64,115,215,18,62,73,46,127,62,40,15,203,62,16,233,23,63,18,165,77,63,220,104,136,63,239,201,163,63,153,187,182,63,55,137,201,63,45,67,228,63,235,226,246,63,22,251,7,64,218,172,22,64,5,163,34,64,21,29,45,64,227,199,56,64,157,17,37,62,171,207,149,62,85,48,234,62,216,129,35,63,129,149,83,63,211,77,130,63,116,36,151,63,255,33,173,63,29,56,199,63,247,117,224,63,246,151,245,63,249,160,7,64,82,39,20,64,213,9,32,64,71,114,45,64,34,253,58,64,12,147,169,61,109,197,62,62,203,161,165,62,174,71,1,63,154,153,57,63,95,152,124,63,88,202,154,63,222,113,178,63,68,139,204,63,148,135,229,63,34,142,253,63,33,31,12,64,64,19,25,64,124,242,36,64,137,65,48,64,162,180,59,64,4,231,76,62,209,34,187,62,139,108,7,63,228,20,45,63,191,125,77,63,128,72,127,63,131,192,154,63,201,118,182,63,84,227,205,63,246,40,228,63,191,125,253,63,39,194,10,64,243,31,22,64,123,20,34,64,115,215,46,64,186,218,58,64,172,28,26,62,159,171,141,62,7,206,217,62,127,251,26,63,181,55,72,63,75,234,116,63,46,144,144,63,139,108,167,63,146,203,191,63,222,2,217,63,192,236,238,63,221,181,4,64,102,102,18,64,54,205,31,64,196,66,45,64,169,164,58,64,174,182,34,62,253,135,212,62,165,44,19,63,254,67,42,63,146,92,78,63,25,4,134,63,28,124,161,63,100,59,175,63,217,206,191,63,65,241,227,63,143,194,253,63,208,213,6,64,61,155,17,64,1,222,34,64,181,166,45,64,15,156,55,64,200,152,187,61,200,7,61,62,19,242,193,62,188,5,34,63,73,157,96,63,41,203,136,63,90,245,161,63,124,97,186,63,104,34,212,63,175,37,236,63,163,146,2,64,244,108,14,64,44,101,25,64,170,130,37,64,106,222,49,64,232,217,60,64,67,173,105,62,216,240,212,62,180,89,21,63,73,157,48,63,151,144,79,63,218,27,132,63,168,198,163,63,134,90,195,63,227,199,216,63,56,103,236,63,155,230,5,64,79,175,16,64,186,73,24,64,41,237,33,64,57,69,47,64,244,253,60,64,249,15,41,62,7,206,153,62,76,55,233,62,178,46,30,63,117,2,74,63,180,89,117,63,197,143,145,63,25,115,175,63,61,44,204,63,47,221,228,63,85,193,248,63,66,96,9,64,190,48,21,64,182,132,32,64,30,167,44,64,115,104,57,64,56,248,2,62,93,254,195,62,74,12,34,63,157,17,85,63,89,23,119,63,61,10,143,63,230,174,157,63,216,240,172,63,213,120,193,63,78,209,209,63,186,73,228,63,168,87,250,63,232,217,12,64,252,169,29,64,88,57,44,64,161,248,57,64,143,83,244,61,119,190,95,62,116,70,180,62,43,246,7,63,118,224,60,63,182,132,108,63,221,36,142,63,119,45,169,63,52,162,196,63,27,13,224,63,145,15,250,63,173,105,10,64,180,200,22,64,8,61,35,64,165,78,48,64,204,127,60,64,53,239,56,62,233,183,175,62,247,6,255,62,106,222,49,63,138,142,100,63,224,190,134,63,222,147,159,63,244,253,180,63,9,249,208,63,143,194,229,63,2,43,255,63,2,154,12,64,16,122,22,64,100,93,36,64,227,165,47,64,112,95,59,64,200,7,61,62,155,85,159,62,177,225,233,62,66,207,22,63,177,80,59,63,186,107,89,63,120,156,130,63,177,225,153,63,215,52,175,63,86,14,205,63,223,224,235,63,68,139,4,64,164,112,17,64,193,57,31,64,48,42,45,64,190,159,58,64,88,57,180,61,128,183,128,62,204,127,8,63,199,41,58,63,93,254,99,63,202,84,145,63,124,242,168,63,171,62,191,63,145,237,204,63,102,136,219,63,123,131,239,63,126,29,4,64,203,161,17,64,102,102,34,64,70,37,45,64,4,231,56,64,77,132,13,62,179,12,145,62,86,125,238,62,46,144,48,63,181,55,104,63,48,42,137,63,107,154,159,63,200,7,181,63,227,165,203,63,187,184,229,63,6,129,253,63,79,30,10,64,251,92,21,64,66,96,33,64,54,171,46,64,77,243,58,64,245,74,217,61,143,228,178,62,161,248,33,63,90,100,91,63,126,140,121,63,2,43,135,63,58,146,147,63,154,153,169,63,168,53,205,63,131,192,234,63,1,77,252,63,161,103,7,64,57,69,19,64,56,248,34,64,255,178,51,64,60,189,62,64,175,37,36,62,87,91,145,62,182,132,220,62,135,22,25,63,186,73,76,63,113,27,133,63,147,58,153,63,113,27,173,63,233,38,201,63,143,83,228,63,190,48,249,63,83,150,9,64,122,54,23,64,35,74,35,64,143,228,46,64,21,140,58,64,141,40,45,62,36,151,159,62,34,142,245,62,18,131,48,63,9,138,95,63,101,25,130,63,89,134,152,63,25,115,175,63,75,234,196,63,131,47,220,63,158,94,241,63,1,77,4,64,179,234,15,64,44,101,29,64,25,115,43,64,76,55,57,64,203,161,197,61,233,72,46,62,19,97,163,62,37,117,18,63,41,92,79,63,181,21,131,63,228,20,157,63,116,181,181,63,139,253,205,63,45,33,231,63,228,131,254,63,108,9,13,64,184,30,25,64,233,38,37,64,204,127,48,64,65,241,59,64,20,174,71,62,61,44,180,62,148,246,6,63,65,130,50,63,9,138,95,63,149,101,136,63,154,8,155,63,218,172,178,63,233,72,206,63,218,27,228,63,96,229,248,63,85,48,10,64,93,109,21,64,167,232,32,64,178,157,47,64,52,128,59,64,150,33,14,62,28,235,130,62,170,241,210,62,120,156,18,63,45,67,60,63,232,106,107,63,166,155,140,63,109,231,163,63,47,110,187,63,227,165,211,63,131,192,234,63,145,126,3,64,181,166,17,64,70,148,30,64,94,75,44,64,124,97,58,64,218,172,58,62,159,205,170,62,100,204,253,62,109,86,45,63,122,54,91,63,236,192,129,63,93,109,157,63,103,68,177,63,190,48,201,63,58,35,226,63,159,171,245,63,133,124,8,64,98,16,20,64,23,183,33,64,181,166,45,64,83,150,57,64,193,202,161,61,147,169,66,62,179,12,209,62,11,70,37,63,30,167,88,63,227,165,131,63,207,102,157,63,77,132,181,63,208,213,206,63,231,29,231,63,249,160,255,63,159,60,12,64,34,108,24,64,63,198,36,64,147,58,49,64,227,199,60,64,46,144,160,59,237,13,62,60,188,116,147,59,36,151,127,59,111,18,131,186,130,226,71,188,158,239,167,188,137,210,94,187,66,96,101,188,75,89,134,187,154,119,156,60,38,228,3,189,23,183,81,57,95,41,75,188,100,93,220,188,202,84,193,59,142,6,112,61,186,218,10,61,155,85,31,189,147,169,2,189,0,111,1,188,158,239,167,188,79,175,20,189,232,217,172,188,93,109,197,60,70,182,115,61,55,26,64,61,103,213,231,60,224,45,144,60,226,233,149,188,187,184,141,188,23,183,209,185,82,73,29,59,104,145,109,60,245,185,90,61,229,97,161,60,244,253,212,187,172,139,219,187,62,232,89,60,5,163,18,61,195,100,42,188,9,27,30,189,234,149,50,188,36,151,255,187,174,71,225,60,139,108,103,61,132,158,205,60,124,242,48,187,159,171,173,187,77,21,140,60,224,45,16,60,131,192,74,61,176,3,103,60,36,151,127,59,162,69,54,189,86,125,46,189,153,187,150,188,66,96,229,188,125,174,182,188,36,151,127,59,77,21,140,188,181,55,120,189,9,249,160,189,197,32,48,189,137,210,94,61,70,182,115,61,111,18,3,61,82,73,157,186,124,242,48,60,80,141,151,60,208,68,216,59,231,29,39,61,101,25,98,61,215,52,239,187,168,87,202,188,166,155,68,189,250,237,235,188,7,95,152,60,159,171,173,60,195,100,170,186,157,17,37,61,216,240,116,61,223,79,141,61,134,90,83,61,33,31,244,188,151,255,144,188,211,188,227,60,39,160,137,60,159,171,45,188,132,158,205,60,9,27,30,61,222,147,7,61,195,100,170,187,62,232,89,60,32,99,238,60,0,111,129,188,39,194,6,189,189,82,22,189,67,28,235,60,54,60,61,61,224,45,144,188,46,144,160,59,20,63,198,60,137,210,94,187,27,47,93,60,4,231,12,60,33,31,116,188,93,109,197,60,59,112,78,61,240,133,201,60,64,164,223,188,116,36,23,189,124,242,48,188,16,233,55,189,0,0,128,189,12,147,41,189,215,52,239,188,177,225,105,189,88,57,52,189,224,45,16,188,46,144,32,60,250,237,107,58,23,183,209,185,52,128,55,58,73,157,0,189,195,100,170,188,101,25,98,188,28,235,226,188,224,45,144,187,171,207,85,61,37,6,1,61,27,47,221,188,28,235,226,188,23,183,209,188,85,193,40,188,193,168,164,188,67,28,235,188,138,142,228,188,43,24,149,188,202,84,65,61,181,21,123,61,236,81,56,61,48,42,41,61,149,101,8,61,198,220,53,61,125,174,182,60,130,226,199,59,0,111,1,61,74,123,3,61,168,53,77,61,127,106,60,61,205,204,204,60,90,245,185,60,18,131,192,60,156,51,34,60,80,141,151,60,150,33,14,189,77,21,140,189,44,212,154,188,20,63,198,60,227,165,155,188,64,164,223,188,82,73,157,186,242,65,207,188,142,6,240,60,54,60,189,188,161,103,179,188,111,18,131,186,218,172,122,60,23,183,81,60,185,252,135,188,14,45,50,189,159,205,42,189,20,63,70,188,5,197,15,189,119,190,31,189,72,80,252,59,211,188,227,188,115,104,17,189,153,187,22,60,59,112,206,187,111,18,3,58,124,242,176,60,91,211,60,61,100,93,92,61,199,186,56,61,33,31,244,60,244,253,84,188,237,13,190,59,85,193,168,60,238,235,64,61,241,99,76,61,66,96,229,60,4,231,12,60,52,128,55,186,220,215,1,189,61,44,212,60,224,45,144,60,4,231,140,59,159,171,173,60,101,25,98,60,159,171,45,60,88,57,180,60,10,215,35,187,10,215,163,59,130,226,71,60,231,29,167,187,4,231,12,188,202,84,65,189,111,18,3,186,9,27,158,60,23,183,81,59,240,133,201,60,198,220,181,60,188,116,19,60,111,18,3,189,188,5,146,189,25,115,87,189,254,101,119,188,88,57,52,189,221,181,132,189,164,223,62,189,153,187,22,188,127,106,60,60,134,90,83,188,159,171,173,59,4,231,12,189,45,178,29,189,46,144,32,61,180,89,117,61,12,147,41,61,2,43,135,60,46,144,32,188,111,18,3,189,171,207,213,188,88,57,180,187,211,188,99,188,88,57,52,188,39,160,9,60,4,231,140,60,240,133,73,189,136,244,91,189,111,18,3,189,250,237,107,187,135,22,217,60,45,178,29,61,23,183,209,59,66,96,229,188,127,106,188,188,172,139,91,60,93,109,197,60,159,171,45,60,228,131,30,61,49,8,44,60,137,210,222,59,244,253,212,60,145,237,252,62,118,113,251,62,208,68,248,62,180,200,246,62,135,167,247,62,190,193,247,62,34,253,246,62,116,181,245,62,217,95,246,62,161,214,244,62,70,37,245,62,5,52,241,62,124,242,240,62,187,39,239,62,58,146,235,62,195,100,234,62,171,62,151,62,190,48,89,62,146,92,62,62,204,127,72,62,7,240,22,62,173,105,222,61,168,87,10,62,3,120,11,62,153,42,24,62,186,107,9,62,254,212,248,61,23,183,17,62,84,82,39,62,120,156,34,62,246,151,29,62,36,40,62,62,160,197,154,197,183,255,139,251,252,5,193,253,148,253,208,252,161,4,195,249,165,245,146,5,78,250,37,5,216,250,237,255,47,255,160,254,93,255,144,3,171,255,76,255,222,253,159,251,77,254,167,254,229,0,108,1,174,252,120,2,86,254,153,254,0,128,22,1,3,252,54,1,225,255,157,254,70,254,22,255,159,1,54,255,103,215,109,6,134,254,34,247,69,3,191,248,44,2,89,252,192,250,200,11,124,13,61,6,98,5,210,1,84,202,146,252,195,5,237,0,235,250,28,38,176,253,23,0,64,255,79,1,198,255,29,1,120,1,40,0,24,0,36,1,170,1,86,248,226,252,233,2,99,5,222,255,141,1,100,198,115,231,175,28,26,231,90,17,48,198,86,7,232,255,70,6,40,253,36,254,218,6,228,251,143,3,67,12,92,250,34,255,80,248,66,7,50,5,244,0,213,0,167,3,164,255,164,254,155,0,162,1,200,113,236,0,66,255,30,255,203,254,78,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+378880);
/* memory initializer */ allocate([78,253,46,0,204,2,234,253,147,0,138,253,181,255,198,252,37,0,137,18,224,251,96,9,118,5,214,5,204,1,35,255,92,11,112,253,5,195,132,244,38,9,158,255,69,2,184,243,41,254,188,14,9,8,47,6,170,53,117,255,74,1,151,4,173,1,63,0,48,199,138,254,159,5,54,251,90,254,78,253,48,3,255,4,176,253,106,6,188,2,58,5,0,0,54,253,46,0,121,1,68,255,146,254,59,255,131,253,146,253,250,254,187,255,131,253,14,251,1,1,108,2,240,251,68,1,136,181,166,253,49,254,207,250,1,2,139,10,91,254,130,248,202,8,108,254,147,1,22,250,134,0,147,0,3,0,170,1,93,2,20,1,49,2,230,255,218,254,118,2,12,254,32,254,123,255,56,253,136,251,238,0,135,253,173,0,20,142,98,251,238,254,118,255,241,254,24,255,30,0,194,2,88,255,176,252,192,2,172,247,8,255,148,255,157,2,141,4,234,0,219,4,87,208,160,8,77,248,195,252,65,40,132,240,34,250,103,254,178,240,168,17,45,247,227,252,187,8,72,234,82,249,88,246,24,1,45,249,44,252,79,238,168,235,235,248,74,1,122,3,180,231,58,253,49,234,160,237,111,252,104,11,60,207,12,239,78,1,233,250,27,1,28,253,19,251,228,13,138,12,136,210,154,199,3,246,229,252,235,2,34,2,72,246,99,7,229,1,213,2,82,1,43,6,44,8,50,9,28,1,252,10,234,1,162,5,187,0,117,245,172,4,9,249,204,4,60,9,52,52,2,1,54,8,237,231,56,255,157,234,244,10,192,253,222,26,220,244,198,8,162,4,72,2,120,255,138,20,241,14,229,11,131,249,130,235,244,9,66,236,225,238,250,249,112,50,212,249,244,4,121,250,36,248,253,3,198,247,211,3,86,9,83,13,204,251,73,254,40,21,53,5,184,1,94,13,184,203,236,9,240,9,172,241,252,246,18,4,77,2,70,16,226,19,3,6,137,242,91,27,212,238,63,1,178,253,225,1,41,254,244,86,112,248,215,254,22,5,139,4,169,3,92,255,79,3,0,3,59,3,82,254,24,3,216,1,235,249,200,2,166,253,17,252,234,254,50,252,130,243,64,41,180,247,79,1,74,251,117,2,112,202,12,0,119,249,77,253,102,253,182,244,58,3,0,7,245,249,32,248,39,3,18,7,73,3,210,252,190,4,248,2,224,251,148,1,162,255,144,0,41,1,184,253,106,0,116,0,124,255,236,0,5,254,86,0,85,3,98,253,157,1,255,127,218,2,83,42,10,254,17,5,239,240,245,251,190,249,92,255,71,249,188,5,251,1,40,4,198,5,227,16,8,253,142,252,21,239,4,10,75,213,184,11,53,8,68,246,184,255,92,49,183,10,167,251,114,223,64,26,44,9,235,1,233,255,215,251,226,5,42,8,61,249,51,248,163,2,169,1,229,31,183,2,237,8,79,254,3,2,47,254,165,254,18,252,101,1,201,255,57,0,225,1,250,132,208,252,60,0,76,0,73,254,184,254,39,255,9,1,123,0,71,3,218,0,75,5,243,0,146,252,237,205,48,20,62,1,96,5,141,244,145,49,173,255,36,255,32,11,254,252,150,0,95,6,163,7,16,6,165,250,19,244,216,6,174,227,232,255,254,253,64,234,7,250,144,255,163,1,144,251,96,253,201,248,144,251,90,0,197,1,202,18,212,50,205,246,83,246,113,5,195,1,62,13,12,0,76,247,48,7,17,246,156,246,103,244,186,0,68,254,204,0,247,254,53,211,156,8,29,7,7,14,67,0,117,34,175,15,73,255,242,232,68,250,130,44,246,11,128,255,36,254,191,9,184,244,170,52,174,2,216,250,115,1,140,252,37,7,238,248,81,1,156,251,94,250,176,1,158,7,77,251,151,2,51,215,6,9,254,2,137,0,66,17,5,11,135,0,116,0,124,208,248,241,174,2,6,9,205,4,138,7,36,249,227,250,159,5,99,241,207,254,11,6,44,217,126,12,53,5,99,9,225,244,204,240,253,254,26,249,113,3,230,55,81,249,184,252,211,8,211,11,9,250,132,4,88,11,181,255,40,253,0,6,129,255,152,0,88,243,42,253,118,209,13,4,173,252,155,248,20,253,34,243,166,251,184,23,103,0,253,249,221,17,155,249,122,20,145,10,94,217,254,0,227,249,105,254,26,7,36,166,86,4,119,0,0,1,61,253,61,254,89,253,118,1,89,252,99,253,147,1,246,255,174,253,243,253,123,5,8,252,215,253,83,2,87,255,219,9,174,255,179,3,52,45,114,251,148,45,158,236,74,3,164,252,89,0,20,243,128,253,46,2,173,252,110,2,22,252,187,236,202,10,199,7,135,255,121,5,145,255,207,255,100,3,135,0,144,250,233,254,208,253,156,1,15,255,134,5,222,252,24,251,214,254,191,1,74,69,192,254,130,251,114,6,114,254,250,21,188,23,41,221,199,1,172,49,210,247,157,0,81,5,21,250,214,5,190,231,215,253,7,249,88,254,23,244,30,240,92,251,36,253,200,7,122,248,215,5,61,4,94,168,163,4,135,1,24,250,235,2,199,254,10,254,51,5,200,1,189,254,246,0,187,253,56,0,168,5,23,8,23,2,14,3,8,2,120,255,222,254,194,207,174,209,56,254,36,9,202,254,22,0,162,8,29,246,120,254,126,252,79,15,74,5,180,254,97,239,169,0,169,1,36,254,17,10,108,251,192,7,10,1,2,2,252,253,177,9,81,0,55,8,58,253,17,1,125,5,37,198,226,22,37,14,42,252,89,1,252,7,158,0,254,247,166,253,186,3,86,1,239,0,157,0,195,254,221,255,252,254,51,1,28,131,228,0,179,255,225,0,102,255,131,2,141,252,250,253,32,0,116,1,208,0,40,168,54,254,18,2,104,0,254,0,249,252,16,251,197,253,132,3,249,254,189,254,216,254,194,3,8,2,36,2,108,247,42,0,128,5,45,255,11,193,4,8,112,49,202,252,251,1,65,1,252,252,238,252,112,255,45,242,124,3,154,242,19,0,217,248,137,4,44,7,220,3,146,251,64,253,78,244,180,2,253,2,201,1,88,6,246,1,13,0,108,1,81,1,108,125,237,5,31,255,189,0,141,0,217,3,196,253,6,1,110,255,31,0,236,0,13,1,234,254,106,249,112,201,223,4,15,252,22,4,155,52,252,4,244,254,51,1,153,250,8,6,136,0,181,3,70,0,190,1,111,5,116,247,233,2,138,254,105,200,56,253,158,196,235,253,148,255,60,247,48,251,194,1,129,252,62,4,242,252,198,251,50,253,108,253,28,3,209,247,162,10,44,254,75,249,147,0,242,163,121,1,36,255,61,249,120,250,230,1,15,255,10,1,222,252,190,254,42,4,224,253,89,255,8,2,239,250,156,255,110,2,158,2,68,255,199,2,32,0,131,4,116,2,94,1,144,255,102,255,232,251,212,255,36,0,58,254,48,1,255,127,100,1,206,1,86,251,37,2,138,0,0,0,20,4,137,255,195,0,74,4,9,2,222,12,64,241,32,255,201,16,24,251,209,254,59,8,44,1,29,204,117,11,134,243,128,250,200,239,99,16,31,1,92,252,223,4,141,52,21,1,162,1,170,253,87,0,108,4,176,255,107,254,168,203,144,2,226,250,89,250,122,240,183,6,57,1,244,1,54,4,142,255,169,5,219,254,136,255,110,237,207,21,235,0,236,235,159,252,28,254,212,60,80,1,194,248,102,255,58,254,61,250,42,253,122,241,48,240,39,6,224,1,70,4,95,247,126,243,164,1,204,253,208,255,196,3,149,245,124,8,126,249,112,0,38,253,203,0,34,14,15,194,11,237,48,0,196,251,232,5,87,252,25,13,59,254,223,0,219,8,139,0,190,0,167,7,48,253,37,17,169,2,143,40,144,255,102,48,142,252,159,6,211,13,87,255,59,12,134,255,43,14,252,0,185,0,245,253,112,0,37,255,214,0,74,255,154,255,118,0,230,0,196,255,223,252,231,255,42,0,233,254,6,1,154,129,88,1,226,253,126,1,33,255,108,254,177,4,170,245,93,255,221,252,225,11,15,252,234,14,244,2,202,22,169,55,220,248,139,0,38,255,110,253,222,250,140,236,6,243,75,250,194,249,165,255,160,9,70,252,173,235,233,252,59,5,226,202,82,2,190,2,124,254,165,251,183,246,142,254,182,241,6,243,79,7,209,9,94,11,255,15,109,247,195,16,118,3,201,253,158,4,210,254,96,253,235,255,244,254,196,141,57,255,0,252,252,250,229,1,152,5,194,251,119,0,6,4,162,1,125,253,115,251,55,7,226,255,180,252,115,252,96,254,164,253,159,253,223,254,121,254,18,255,162,255,121,254,214,252,157,1,100,1,186,3,113,248,20,121,185,1,138,0,101,5,106,4,247,246,46,2,53,255,8,255,73,252,152,1,23,7,0,1,83,254,132,252,73,253,114,4,183,1,8,253,193,255,98,25,58,2,148,59,187,242,170,0,167,3,82,1,1,0,240,253,12,2,227,253,231,254,253,255,243,1,179,254,173,2,180,1,176,125,133,1,103,255,60,2,0,1,53,0,16,0,122,252,212,2,33,11,199,9,80,0,155,2,181,248,230,2,101,59,245,221,228,245,36,254,62,254,35,253,133,252,154,4,41,249,162,249,142,255,144,0,118,255,161,39,68,255,184,249,125,255,9,255,224,253,46,38,158,253,204,244,112,242,89,1,178,219,140,14,74,10,252,235,120,254,247,9,119,253,14,3,238,255,96,255,161,254,42,47,41,54,242,250,238,4,193,243,211,244,18,0,241,2,167,0,108,2,128,246,206,7,228,2,110,7,144,1,50,255,190,13,21,242,136,253,72,0,238,248,240,5,197,252,196,253,68,6,155,253,120,14,32,253,92,43,158,49,139,243,232,252,32,242,85,6,49,7,212,4,191,4,55,254,70,37,62,36,73,10,159,221,94,3,205,6,24,237,196,245,104,2,68,1,104,8,48,14,112,3,40,254,135,7,128,242,199,247,59,252,98,13,155,248,23,12,128,251,42,242,182,0,230,3,126,254,178,4,225,1,97,248,2,254,93,252,152,6,151,0,160,202,202,240,51,252,118,252,244,5,104,37,47,10,209,48,205,252,162,235,48,23,134,253,158,253,204,239,91,254,26,254,184,248,206,254,117,9,212,2,37,255,232,250,198,247,8,254,106,26,146,20,100,244,79,251,148,250,30,249,84,1,135,82,25,252,126,0,111,0,56,251,54,249,55,1,56,253,62,254,142,255,120,253,16,253,84,255,67,0,119,1,57,252,248,251,245,213,163,248,81,247,70,243,224,1,28,255,113,255,237,250,72,51,10,244,138,5,6,0,119,253,232,248,224,254,255,2,89,1,108,3,21,254,180,3,28,2,89,255,177,7,165,248,57,254,104,80,112,253,114,0,52,1,23,1,81,4,174,253,52,5,255,0,156,254,70,255,228,253,106,7,151,252,35,254,124,5,11,119,114,1,190,254,175,254,50,255,72,254,130,252,202,255,46,254,128,253,104,254,0,255,208,253,33,250,114,2,195,253,108,249,163,1,151,1,28,8,158,19,71,12,145,251,170,208,206,208,74,250,244,247,200,234,188,251,39,6,166,7,56,252,122,0,190,3,64,235,165,2,96,248,12,208,198,249,187,4,186,251,200,7,232,212,79,244,190,252,239,250,141,251,56,1,246,249,99,239,167,4,21,0,211,10,127,2,46,246,223,25,234,2,38,7,151,11,152,6,211,197,52,31,3,16,159,255,141,4,210,246,65,0,228,250,42,7,220,247,147,6,254,19,159,249,246,255,94,235,147,1,47,250,248,254,142,1,140,246,54,50,38,250,174,245,50,250,58,3,187,2,91,247,8,247,73,46,222,1,102,247,207,253,6,255,199,0,127,246,76,252,110,254,177,1,147,1,231,50,132,255,76,255,219,5,125,253,15,2,104,44,201,22,170,3,130,12,60,254,59,11,117,251,139,255,1,248,212,251,211,0,50,12,20,255,236,52,66,253,96,1,200,254,147,248,159,247,30,9,188,208,180,255,93,254,106,1,173,13,36,255,242,243,60,2,1,6,168,12,47,250,12,252,128,2,255,253,162,3,134,1,43,121,212,2,178,255,62,253,183,0,99,255,134,255,177,252,124,251,45,1,252,1,56,254,65,1,61,1,20,5,0,254,49,249,206,39,218,254,140,255,87,16,94,5,48,52,197,250,40,7,243,9,66,253,34,245,72,250,152,4,249,250,208,8,121,8,68,3,48,8,8,255,241,6,42,44,45,255,9,1,6,241,80,1,144,7,182,253,121,2,13,4,133,248,62,50,162,3,239,254,29,9,89,243,173,1,118,1,214,9,97,253,58,2,96,247,129,1,228,254,3,195,40,249,61,5,237,253,24,253,169,251,34,1,2,247,12,252,139,244,146,254,226,255,13,238,120,5,48,2,48,0,123,61,79,252,155,1,84,7,137,9,160,247,58,251,160,48,54,0,42,253,73,245,244,9,52,8,27,5,152,1,58,255,246,248,193,255,129,248,165,3,183,254,240,253,210,193,168,6,212,11,217,0,94,2,12,245,4,8,104,36,80,2,201,3,180,26,135,2,97,253,72,2,255,255,236,13,241,245,180,1,109,247,158,1,55,255,75,4,252,252,36,255,190,253,45,254,125,0,90,252,15,1,28,172,32,1,215,0,216,0,220,1,208,253,0,3,118,4,87,255,168,251,240,200,156,199,209,10,72,250,195,255,93,5,45,242,213,251,151,4,243,249,163,252,180,254,172,248,87,12,84,1,175,6,107,246,201,1,232,9,90,4,26,247,160,9,75,243,46,254,3,48,196,48,204,244,224,252,118,4,108,239,78,255,197,14,6,6,105,253,184,7,33,12,145,0,156,255,18,249,241,251,91,6,180,60,98,16,16,21,229,2,24,7,224,253,116,220,159,16,197,251,14,251,20,10,152,239,142,7,185,6,129,0,228,8,112,245,195,250,226,250,106,209,58,250,199,0,243,2,107,2,135,16,34,254,165,249,38,251,50,7,114,51,144,246,10,3,192,0,17,1,14,3,6,3,140,8,186,252,67,12,4,250,153,249,207,251,172,253,2,3,159,254,203,255,82,0,190,254,152,175,168,254,69,254,158,0,112,255,214,253,50,0,186,3,111,255,176,254,254,247,84,2,74,252,126,245,84,54,41,202,184,18,111,3,72,2,85,244,199,3,192,0,183,253,241,252,195,250,220,243,170,249,174,9,174,250,66,250,236,249,82,254,146,255,32,253,95,224,25,8,196,3,95,254,133,6,207,234,90,225,24,2,83,50,102,249,119,4,14,255,74,254,30,247,57,0,46,1,194,253,125,2,0,11,150,249,118,8,84,255,125,3,165,1,154,253,203,253,174,254,242,253,195,251,85,252,142,251,33,252,127,7,184,6,99,182,98,248,170,254,138,7,65,1,184,0,68,252,138,254,50,254,40,255,250,255,26,0,130,1,206,255,91,2,48,253,122,2,4,255,5,1,164,252,218,0,62,89,24,45,53,254,78,252,196,1,154,255,77,251,246,248,175,251,202,254,19,3,36,255,167,251,5,248,138,2,199,53,202,241,216,254,122,252,99,254,252,0,208,252,84,255,7,254,201,250,122,3,0,3,245,253,40,3,181,254,32,78,248,254,227,6,133,0,255,255,48,254,181,3,70,252,109,255,244,6,66,255,30,0,2,227,249,237,18,252,42,254,26,253,244,1,85,29,220,5,14,6,226,241,42,3,35,10,226,5,130,205,4,14,146,1,13,246,225,5,65,0,4,0,54,13,103,247,119,246,15,250,182,234,20,241,26,1,92,20,162,4,224,251,226,246,220,3,187,50,134,1,45,16,136,245,127,6,158,224,0,249,31,255,94,253,21,228,198,51,95,6,179,39,252,242,249,255,93,253,33,253,4,3,5,247,186,254,105,6,106,251,137,248,82,0,8,3,123,3,67,254,158,72,238,0,137,5,188,246,10,218,134,245,88,2,135,250,92,2,1,249,234,255,10,6,28,249,13,2,181,250,92,1,188,12,91,4,204,0,12,2,225,0,24,206,89,253,21,195,92,251,54,4,82,0,165,252,28,0,51,3,60,251,51,2,5,9,75,1,122,251,38,248,248,254,129,254,196,6,88,254,74,245,249,252,183,254,132,0,135,1,237,4,9,4,172,217,203,209,129,9,130,10,94,2,92,245,48,28,216,254,214,248,98,249,200,1,132,237,112,254,136,243,148,5,196,254,150,202,114,245,16,9,108,230,23,248,198,4,213,6,165,15,108,11,45,242,16,236,227,246,98,250,38,10,62,0,11,253,248,2,87,1,154,0,53,131,234,253,16,5,185,2,88,0,89,1,191,253,12,254,82,255,186,254,58,255,16,1,157,0,209,252,132,253,117,251,157,252,239,254,30,4,6,3,88,6,221,3,107,0,192,251,95,253,95,8,78,166,202,253,151,0,72,0,229,255,10,4,68,254,245,1,113,7,81,250,21,0,33,1,82,214,235,252,139,246,130,245,185,254,36,3,63,244,139,3,192,3,99,5,213,255,216,253,155,8,130,250,113,252,170,212,239,253,106,17,200,239,186,255,90,12,254,206,70,1,106,3,146,5,203,11,11,9,104,0,28,207,201,249,195,244,4,3,190,7,136,4,117,238,89,13,12,250,165,247,130,0,162,3,143,36,124,184,136,254,250,15,44,254,156,0,40,255,60,0,125,253,144,242,0,1,189,252,171,246,124,6,226,253,164,249,174,16,246,13,192,243,177,1,45,4,72,117,49,2,12,1,22,3,38,1,207,0,240,249,32,253,159,255,41,255,158,255,178,2,174,2,54,255,32,253,59,254,143,2,255,1,100,255,238,3,105,1,144,5,26,251,151,254,27,251,117,250,222,254,78,0,43,2,53,2,24,254,101,252,239,184,138,253,116,252,188,0,157,3,108,249,241,0,193,254,114,199,111,66,121,250,18,1,80,2,64,5,248,6,37,253,88,1,224,3,141,0,34,1,225,1,116,2,111,2,114,251,212,247,140,0,224,251,168,53,242,2,188,7,18,255,84,8,164,250,88,247,231,208,130,249,66,0,206,6,161,8,62,252,218,249,28,244,173,0,6,244,183,0,132,238,8,252,16,24,12,3,87,251,250,242,179,0,141,254,244,0,160,0,82,253,157,2,74,1,170,1,65,0,159,0,104,253,70,255,223,1,26,253,54,0,93,2,91,127,83,252,114,1,165,255,88,3,57,3,18,4,118,1,139,2,57,1,222,2,16,255,207,255,83,253,54,248,164,253,149,252,44,0,140,252,118,3,212,50,30,250,35,239,122,248,234,11,253,251,30,254,216,255,137,0,0,246,86,5,220,209,64,8,218,8,126,245,197,250,68,253,13,255,18,9,238,251,27,18,118,243,185,16,47,0,158,2,2,36,141,4,46,3,194,255,28,247,187,50,54,253,177,9,75,5,128,3,24,11,128,249,0,8,167,254,237,8,218,6,99,253,236,8,224,254,193,253,176,3,8,250,44,0,47,4,62,253,225,253,189,250,112,3,1,1,84,5,164,5,24,186,99,0,3,6,21,7,157,253,99,1,14,247,212,3,237,252,132,0,44,1,49,9,204,0,226,252,216,254,174,253,127,3,74,3,67,73,105,4,79,0,67,255,3,2,114,3,226,254,109,0,49,1,118,1,43,5,93,3,238,255,178,255,38,1,192,254,162,2,248,1,97,255,219,253,161,255,109,129,166,255,146,2,58,4,75,6,119,255,182,255,136,4,230,252,201,255,54,3,67,10,179,4,44,242,101,38,76,225,153,220,81,240,130,252,86,247,217,2,145,252,179,248,114,246,210,15,24,254,155,51,222,254,204,252,115,1,116,55,98,3,133,252,218,0,210,248,114,8,120,4,70,255,0,2,136,5,34,2,226,12,27,251,128,0,178,4,45,2,81,248,168,2,33,2,117,255,64,244,21,72,6,243,119,255,163,0,97,5,92,4,12,10,215,249,202,248,139,2,217,250,28,3,162,252,75,1,31,17,149,9,154,248,192,12,57,55,74,3,241,243,156,14,180,251,160,246,172,250,102,9,161,1,167,246,156,252,170,243,16,218,152,13,133,250,104,7,201,0,5,5,175,253,58,210,99,0,229,253,70,255,45,0,38,247,60,208,158,245,242,10,82,251,254,3,0,241,121,5,130,248,119,6,189,6,96,0,51,255,111,252,93,6,56,2,251,250,240,4,120,251,82,2,223,0,176,254,100,250,40,254,176,178,41,2,214,5,61,255,58,2,26,1,115,253,202,255,165,251,153,0,28,254,141,0,68,255,234,254,83,255,208,1,13,0,134,253,214,255,134,1,48,254,10,255,110,2,205,4,76,253,247,113,194,253,126,4,121,255,125,10,148,9,63,0,62,252,106,252,135,249,70,248,84,255,91,253,170,242,65,5,132,240,59,11,124,250,114,253,72,244,243,41,84,44,72,247,4,2,111,32,67,255,4,10,106,255,139,254,135,3,237,254,90,9,145,251,252,1,168,1,88,249,82,247,51,241,146,7,216,0,98,206,184,9,172,250,129,247,90,4,205,252,60,245,28,6,184,3,36,0,97,2,91,252,224,249,110,0,143,0,217,249,116,239,16,2,194,58,128,248,92,1,193,245,97,20,119,7,192,251,3,1,178,253,108,1,33,8,255,241,150,2,249,0,137,255,145,255,10,3,119,8,11,0,196,9,14,28,116,56,36,17,25,16,39,14,62,6,20,2,5,254,109,3,246,14,116,1,120,247,6,245,228,45,209,247,201,251,2,244,0,253,85,11,253,241,244,245,24,39,51,2,20,238,2,4,93,4,87,7,28,209,96,254,61,1,240,7,8,7,34,4,172,255,216,254,44,249,28,10,245,212,165,249,64,243,176,9,96,0,98,8,144,245,114,9,82,14,202,251,81,255,90,5,187,9,190,216,83,253,63,226,162,15,96,43,135,3,60,23,5,11,234,11,95,246,127,4,176,252,165,247,33,48,128,250,67,250,254,7,123,245,175,9,86,242,5,12,18,241,49,7,156,246,92,212,105,254,10,244,67,249,157,234,85,2,132,7,59,255,178,1,144,249,118,10,98,246,124,4,87,2,4,5,141,204,75,252,148,230,242,2,42,29,36,23,131,5,232,253,73,42,76,2,41,1,202,254,175,253,128,252,16,3,14,255,204,2,245,1,204,255,203,15,13,253,78,253,70,10,98,69,145,247,78,8,186,3,220,250,121,43,34,6,131,1,177,245,129,54,201,254,111,20,7,247,228,241,90,253,163,251,178,2,233,254,99,9,251,249,237,1,100,249,0,248,253,252,91,252,167,1,188,2,72,3,227,2,164,7,80,252,100,2,138,245,101,0,245,0,238,252,82,3,13,1,75,5,13,85,207,1,227,245,84,2,249,253,20,3,213,255,196,4,178,41,239,18,168,4,79,1,107,3,150,255,148,41,40,10,15,21,250,254,248,8,216,232,208,251,134,255,200,9,33,5,93,4,43,252,94,1,119,1,214,252,8,0,182,5,28,248,192,246,8,0,135,88,1,6,87,0,140,3,64,3,236,236,56,1,108,2,18,4,164,238,148,2,46,6,106,245,118,244,28,39,148,218,166,31,64,22,165,250,37,244,237,242,146,1,218,0,72,4,124,248,88,0,34,247,79,16,197,251,15,254,123,246,252,242,200,252,212,0,198,246,248,17,136,225,19,211,115,30,236,0,200,250,136,205,193,2,180,17,48,250,226,45,115,243,166,245,220,9,178,245,128,255,184,254,74,13,197,1,14,255,60,246,176,8,196,2,194,1,58,244,124,255,227,4,125,255,193,252,58,253,31,170,222,0,172,247,67,243,234,1,52,244,164,252,246,9,124,3,145,253,174,241,104,253,125,255,226,7,1,11,27,209,240,1,158,253,186,227,187,240,205,244,216,26,111,7,80,3,244,25,228,14,202,233,41,240,135,254,208,247,249,215,212,251,206,5,159,1,3,255,118,247,26,4,3,3,56,229,20,4,42,29,137,11,166,226,65,6,103,27,14,249,170,249,220,242,37,249,19,11,176,0,140,10,223,3,0,10,214,253,3,19,35,6,22,234,50,10,150,48,89,241,20,217,63,245,248,18,221,245,209,234,41,39,44,3,175,2,155,10,173,15,14,12,249,208,72,1,104,240,204,15,176,240,145,255,215,253,72,249,150,9,170,6,171,250,36,3,183,129,41,254,129,3,194,237,12,3,160,241,127,250,186,245,20,0,184,0,99,255,222,254,234,10,222,253,96,255,28,6,122,4,116,2,77,237,17,255,225,43,20,254,163,7,96,2,57,36,108,243,246,14,134,1,162,232,242,242,200,242,52,9,28,7,111,242,211,3,216,255,34,177,47,0,56,255,242,19,131,254,32,7,59,255,232,8,130,9,183,245,127,250,171,251,208,251,89,3,18,6,35,29,6,0,98,47,202,251,14,4,212,254,76,202,129,12,6,253,110,10,229,251,67,254,146,3,84,255,210,253,74,10,122,251,57,12,182,255,169,242,62,4,68,221,118,0,121,253,29,1,186,0,206,11,43,236,62,5,125,13,201,224,191,255,82,18,176,3,133,14,139,248,201,217,145,254,93,249,252,252,0,128,6,5,104,254,84,1,172,254,174,1,250,4,84,2,147,255,41,253,20,1,78,252,139,0,12,7,230,251,22,242,144,250,101,251,1,1,103,6,108,100,230,8,111,9,126,8,153,0,126,0,196,255,80,2,226,3,178,254,244,254,34,7,206,254,63,247,214,10,140,243,246,2,62,254,87,31,30,2,163,26,80,249,115,55,106,247,25,1,244,255,178,253,127,251,216,17,164,241,181,7,155,235,209,248,165,253,252,12,188,9,2,244,178,252,123,0,96,251,155,2,122,213,191,255,201,245,203,3,235,39,35,251,210,28,182,247,254,246,59,2,6,247,166,7,252,238,6,220,225,16,245,10,96,7,121,43,2,5,69,233,32,246,151,252,99,4,176,232,172,245,117,234,153,247,80,252,224,225,41,248,44,247,128,248,52,8,187,254,153,0,26,4,10,0,182,5,138,2,241,206,202,13,242,2,141,17,248,5,177,228,22,237,203,5,152,246,225,10,141,249,194,252,153,5,96,246,211,73,157,248,191,243,228,3,181,9,240,11,219,251,81,240,22,247,76,5,244,245,22,254,185,4,113,4,4,0,132,253,254,250,233,3,90,251,84,255,31,201,96,239,76,248,177,8,126,237,226,251,134,20,177,31,198,16,36,0,245,45,103,240,196,251,24,15,56,244,140,215,97,1,147,11,52,251,24,2,97,2,169,254,222,4,33,14,173,241,186,18,120,176,217,1,213,2,34,251,143,249,108,7,227,245,203,244,10,246,138,252,116,251,172,248,51,1,200,14,82,237,36,254,68,253,70,8,188,248,253,5,107,236,52,9,233,12,10,13,24,200,2,251,190,254,158,7,70,252,58,248,158,5,30,13,55,29,230,11,235,229,250,243,181,6,41,12,60,207,234,250,35,255,2,254,183,40,87,242,74,16,234,241,71,27,170,244,202,1,155,2,54,2,111,9,109,254,174,244,212,255,216,248,146,255,7,7,148,4,7,0,2,250,90,0,174,2,234,150,65,6,202,252,146,2,182,0,105,255,89,1,208,5,136,5,240,254,24,6,46,38,36,8,16,0,248,199,148,5,2,2,98,10,224,250,47,8,198,1,9,249,248,247,177,17,130,4,65,247,188,3,156,2,140,250,174,244,149,1,141,206,244,206,118,253,181,253,133,13,90,246,0,0,172,243,114,12,248,239,193,6,158,5,206,248,90,254,124,17,153,7,92,252,97,250,66,253,138,250,21,13,84,7,25,252,218,247,41,186,80,254,196,15,5,247,109,4,88,0,83,247,86,245,86,252,26,252,124,255,86,254,36,8,12,8,146,251,199,254,146,1,230,253,223,245,230,7,213,2,30,6,234,247,118,84,231,6,88,254,96,128,205,0,41,251,75,243,198,0,23,251,38,9,130,248,225,5,196,1,68,5,164,253,210,3,55,4,252,255,172,9,33,251,110,255,163,252,120,248,66,208,14,205,152,250,77,248,108,250,200,4,129,253,173,255,10,4,160,13,250,246,203,253,74,0,177,254,214,10,90,2,104,3,172,247,109,255,112,8,244,0,162,0,56,49,116,2,46,216,240,250,44,4,224,248,175,236,122,12,18,8,129,252,240,252,43,9,66,248,73,0,6,4,45,49,194,255,32,247,243,14,16,249,242,9,119,250,238,12,118,18,250,243,220,253,182,222,96,6,245,229,240,3,104,4,37,3,186,3,104,2,243,1,218,132,209,250,22,3,66,255,34,4,123,251,152,5,240,255,155,1,148,243,59,3,71,1,146,3,180,6,162,5,28,4,157,249,243,248,207,239,146,202,13,14,31,247,224,232,8,14,112,4,45,255,205,2,61,15,244,235,220,11,167,253,176,50,97,6,76,40,118,249,44,254,137,3,27,9,73,3,9,255,91,232,175,253,47,243,195,16,39,20,227,251,234,248,53,10,173,8,122,4,103,3,91,254,226,253,155,3,17,242,142,251,67,39,108,42,23,232,107,253,211,233,134,252,246,254,52,8,79,24,186,255,158,245,178,255,96,13,202,2,90,8,181,250,43,252,198,7,4,3,170,3,31,5,85,248,156,3,12,168,4,1,171,254,227,4,214,249,23,0,95,5,44,4,128,10,131,240,201,2,34,235,255,254,37,0,110,232,236,254,228,0,40,251,253,227,182,242,171,198,172,6,195,254,192,244,106,3,186,5,12,2,43,8,53,2,132,239,247,254,52,0,211,242,36,255,153,243,86,10,192,1,164,249,62,248,152,8,138,14,120,194,208,27,12,248,134,247,141,253,201,251,36,240,209,8,99,252,166,242,80,203,228,250,148,13,241,252,172,240,204,252,164,252,114,9,166,11,207,221,41,35,38,1,117,209,55,252,1,13,7,253,179,5,68,235,19,7,123,1,50,1,120,2,84,245,208,9,164,4,114,242,137,247,196,253,30,247,135,249,10,94,97,255,118,255,222,248,33,246,211,243,118,252,22,249,98,251,216,4,8,244,9,9,234,252,80,1,253,240,184,203,89,254,10,51,242,255,140,248,224,255,47,10,231,1,134,246,195,0,135,0,182,10,4,6,246,251,88,3,16,247,225,254,250,252,241,1,224,6,191,0,178,0,42,1,38,0,78,135,33,3,80,250,7,9,248,4,203,248,78,1,91,252,183,0,178,249,227,2,89,7,20,203,235,202,216,5,229,247,255,250,26,250,108,0,99,14,160,251,240,2,44,252,235,254,247,250,224,7,222,254,46,7,191,254,117,255,143,252,153,207,135,198,114,7,222,3,126,243,16,9,237,2,80,7,15,246,79,250,65,249,222,2,185,254,196,254,38,4,179,243,113,244,162,8,144,3,184,3,134,7,42,221,74,4,82,2,97,250,134,250,89,43,154,13,40,254,219,0,251,240,106,253,243,37,88,15,230,4,39,248,87,48,68,249,114,54,100,7,146,250,174,2,126,8,242,3,239,250,57,255,63,7,207,1,41,10,56,17,186,7,143,6,178,249,253,255,67,209,92,63,60,3,217,5,21,253,28,254,7,2,244,248,26,241,215,12,56,8,125,4,222,1,178,240,224,5,72,9,196,254,248,253,87,250,178,240,152,2,212,10,206,191,78,1,228,253,246,252,4,245,118,232,216,238,114,246,151,13,158,14,144,253,55,15,121,4,168,254,77,1,122,46,91,245,73,50,135,251,241,248,233,254,60,254,211,249,36,2,196,235,36,248,83,13,164,4,129,250,80,240,44,254,112,7,68,249,130,211,226,255,66,56,74,6,166,247,225,4,90,1,209,23,103,250,113,253,82,255,68,14,170,15,186,3,78,250,158,254,176,248,127,245,112,3,178,252,232,250,67,249,214,6,94,251,240,5,243,1,185,253,25,71,197,251,5,243,0,12,192,234,74,255,41,4,168,251,40,252,197,9,239,253,101,2,6,8,204,1,131,235,11,11,91,250,157,246,158,205,224,5,20,223,245,251,244,237,168,6,230,245,162,5,137,48,232,247,229,2,216,241,179,50,239,7,148,254,166,14,38,236,80,248,146,0,158,2,108,240,193,252,122,15,141,1,69,24,102,251,48,3,168,255,80,254,108,218,52,45,194,0,33,1,90,248,189,247,153,252,252,20,183,243,28,14,108,6,58,3,13,2,15,246,254,253,231,253,181,9,10,252,252,4,29,2,88,252,210,254,108,251,183,0,59,3,131,93,96,4,166,254,199,254,199,10,94,15,246,243,44,247,118,252,57,252,216,5,102,0,34,245,67,1,171,251,219,255,250,9,152,244,230,3,94,252,96,248,142,251,50,7,199,249,193,67,66,251,215,251,134,8,111,251,225,45,22,1,118,32,211,5,204,253,145,4,214,32,79,5,31,251,210,247,171,250,229,15,36,7,129,3,234,4,59,4,223,16,98,2,254,2,225,8,217,15,109,2,82,1,37,5,51,174,36,2,36,248,51,2,78,4,229,255,191,11,105,4,212,251,2,5,133,244,167,11,166,7,8,7,120,7,192,6,162,253,12,7,96,237,204,19,171,250,191,17,143,1,184,200,194,231,43,24,99,247,150,4,156,248,44,243,50,255,56,11,194,245,213,255,4,44,152,255,36,1,212,248,124,231,213,2,18,8,164,253,118,44,64,254,230,2,38,11,114,252,186,252,246,248,94,14,115,254,238,253,105,214,52,9,129,47,226,5,89,10,249,242,56,12,121,8,54,23,104,8,44,55,172,1,187,0,248,0,56,6,212,255,197,255,138,244,91,7,101,252,113,10,177,252,150,0,162,247,60,226,70,43,173,253,90,25,151,202,180,3,219,0,222,250,248,243,59,5,12,43,82,5,247,0,185,248,45,4,54,241,170,6,40,4,64,1,183,17,136,0,211,14,185,5,180,250,63,254,13,0,91,254,233,6,246,79,133,8,141,254,140,9,24,253,215,8,101,255,80,253,20,255,127,238,15,6,252,10,172,9,100,250,42,254,240,254,228,8,82,2,166,252,46,252,98,4,164,9,122,219,159,254,4,252,238,1,111,51,234,6,198,6,186,255,234,237,70,48,206,252,45,252,165,240,232,3,9,239,10,10,191,21,250,12,114,11,20,255,68,237,75,27,134,249,195,16,94,4,174,6,254,247,2,203,254,255,233,255,56,8,77,4,196,254,114,7,107,6,84,1,52,23,108,12,187,252,186,7,238,214,186,5,232,228,16,14,181,4,189,3,45,255,176,223,75,6,210,20,159,235,40,247,207,233,243,243,15,220,194,255,38,13,90,5,234,218,244,0,116,234,186,4,114,11,80,254,15,251,120,1,138,248,8,252,179,252,156,12,70,4,160,243,122,2,247,254,158,242,15,17,92,240,235,254,23,197,158,15,199,37,90,13,179,2,164,35,93,245,147,7,7,9,69,2,140,236,53,13,34,250,110,3,243,251,216,5,186,11,136,3,244,234,28,243,7,1,253,4,74,253,254,2,245,6,110,4,250,0,166,128,227,254,210,0,246,9,129,254,140,3,46,1,36,1,160,254,55,10,159,255,185,248,116,7,125,10,10,254,73,241,160,1,222,3,166,253,3,250,43,0,8,5,46,5,254,64,177,1,76,251,58,7,183,249,127,5,228,227,15,9,138,22,48,6,126,4,134,253,106,249,79,5,140,250,182,1,246,0,186,0,2,212,86,251,50,241,61,243,132,10,243,2,142,0,148,63,222,246,195,250,193,40,38,0,26,250,40,246,123,243,145,3,199,14,170,249,120,237,99,7,198,9,248,255,110,244,43,8,138,58,246,4,115,11,170,2,49,4,25,216,70,6,14,252,202,252,144,4,133,250,254,0,132,4,134,12,118,15,203,6,110,254,114,253,2,237,179,248,83,10,214,244,146,2,114,252,12,246,52,21,56,248,48,255,158,7,90,195,8,2,140,239,110,12,64,16,244,5,156,244,74,2,141,12,163,2,185,0,139,253,157,2,186,252,246,1,31,240,97,1,24,240,216,248,196,247,170,19,180,9,26,60,202,247,124,19,70,0,243,3,8,10,80,5,251,244,24,13,190,212,130,245,99,2,204,1,19,7,21,12,34,0,76,220,117,251,26,0,149,252,206,9,110,4,214,250,226,8,64,252,201,252,2,254,68,4,210,5,186,5,70,248,255,127,181,246,5,252,135,253,230,250,14,255,2,8,56,5,148,245,109,247,70,254,8,0,244,8,248,16,121,246,64,250,11,4,149,199,228,248,165,24,208,247,45,0,33,14,25,6,228,4,12,11,186,41,130,252,89,42,69,9,155,255,145,3,112,8,93,10,144,11,175,238,169,4,28,19,181,247,25,225,223,3,173,245,172,250,199,241,248,217,188,1,101,3,174,11,158,3,60,251,116,249,68,29,24,17,98,241,204,228,179,17,98,29,130,245,164,0,46,4,119,227,71,7,30,2,146,0,224,252,60,72,15,237,220,240,114,8,247,19,46,10,147,16,37,244,82,244,82,249,86,254,61,235,228,246,4,252,244,254,38,251,217,255,108,249,0,128,8,5,42,253,24,249,48,1,190,2,103,244,68,253,74,2,5,6,181,251,164,254,0,245,123,247,20,251,134,249,230,8,67,1,244,249,209,9,40,46,144,246,51,233,138,255,114,26,32,13,255,239,248,254,10,251,40,4,122,217,171,241,200,255,91,2,61,250,184,5,175,218,6,0,237,243,211,20,116,254,124,3,42,245,190,237,83,14,2,217,216,235,134,251,70,240,16,248,120,11,13,7,254,251,41,4,92,254,196,253,220,6,33,254,185,253,40,120,36,253,238,2,14,1,251,249,28,0,166,251,160,255,248,254,143,4,36,2,58,2,84,0,67,248,194,247,144,251,102,1,63,231,255,254,190,198,120,4,184,220,66,1,110,241,242,243,185,250,8,243,236,239,116,254,127,255,126,243,123,5,165,254,96,9,141,254,20,2,19,6,56,245,54,4,36,3,222,250,196,85,183,8,8,245,101,248,70,3,140,48,78,199,128,254,238,249,93,253,139,252,78,5,76,6,62,243,158,255,84,7,65,254,193,8,47,13,27,249,232,10,162,2,23,250,148,251,144,241,104,44,132,248,38,245,46,254,135,254,42,8,57,15,46,21,10,246,56,9,207,12,209,33,222,3,176,247,32,10,54,252,163,246,243,254,214,88,182,2,54,1,127,246,152,3,78,253,198,5,90,5,62,254,189,1,157,250,36,251,70,9,120,5,240,251,196,233,92,249,162,249,28,240,87,251,49,253,119,244,22,242,8,1,65,204,235,237,5,0,173,12,164,233,145,9,118,12,1,235,24,242,6,241,247,4,32,6,6,253,122,11,14,3,146,250,243,0,46,254,96,5,206,3,146,249,8,249,249,0,254,253,25,203,112,7,26,42,252,252,101,255,158,30,226,255,50,14,39,254,116,220,144,255,106,240,184,252,215,5,214,246,186,254,71,14,12,5,220,254,36,213,103,13,250,254,171,0,209,217,39,252,66,2,56,1,7,246,47,13,132,223,130,5,210,250,155,9,212,243,55,4,26,28,160,10,206,7,182,10,64,18,203,249,28,221,132,255,116,253,184,255,105,9,98,252,179,241,78,241,240,57,186,250,70,247,234,4,188,249,169,0,103,0,239,4,112,254,3,253,144,0,56,3,87,3,224,203,163,249,185,7,179,11,84,248,118,253,37,255,169,210,82,232,232,252,37,251,98,250,221,6,156,5,101,241,44,3,168,252,125,218,132,246,148,211,201,12,242,246,185,223,15,6,250,247,194,241,77,12,207,8,82,2,100,254,42,244,22,6,182,2,69,251,106,2,184,12,126,25,220,249,162,220,255,25,120,243,32,14,114,8,65,12,158,16,2,18,200,216,164,4,79,1,153,253,128,2,58,248,198,254,126,23,168,246,130,247,87,1,74,26,216,250,183,0,159,255,18,242,172,11,225,203,219,249,146,220,172,1,23,11,72,26,171,251,167,251,178,251,148,19,28,5,153,240,135,12,252,2,144,244,120,4,28,244,193,15,54,7,60,25,187,239,61,33,96,38,92,61,126,253,236,2,124,0,106,254,233,50,39,3,213,254,39,5,219,5,74,251,178,251,199,243,211,14,47,0,77,246,90,246,239,8,188,15,120,6,148,254,80,249,224,249,156,240,46,245,136,202,28,3,52,13,107,1,137,6,136,4,162,240,68,11,60,236,64,3,191,18,108,1,42,244,156,214,243,248,72,243,68,246,217,248,64,4,100,43,164,12,8,20,236,11,134,17,84,0,30,8,200,0,25,240,177,6,3,6,21,96,5,252,32,0,208,255,82,0,81,0,147,4,19,251,9,249,99,249,146,8,178,6,31,255,59,248,146,1,51,10,60,253,227,193,222,0,5,254,55,50,138,4,0,250,188,244,119,7,24,251,98,252,173,248,88,250,86,245,243,11,49,251,144,6,32,7,8,5,41,255,247,255,40,0,67,252,14,108,204,248,121,248,178,252,136,251,73,254,77,242,228,244,168,248,125,2,18,4,237,0,239,3,125,254,119,209,232,245,114,255,112,2,18,254,159,5,177,8,39,205,147,248,27,251,209,251,85,228,150,247,46,3,27,15,106,4,205,245,44,247,12,6,155,207,6,252,102,0,154,4,34,4,241,197,228,7,254,15,21,251,163,252,138,252,209,243,78,10,189,6,172,250,218,247,183,0,251,1,46,252,242,243,138,197,247,2,195,250,186,255,90,33,158,11,116,255,205,9,148,238,164,10,164,250,235,1,6,232,167,254,134,247,93,251,182,254,174,212,41,61,212,254,57,8,240,1,211,247,65,254,208,7,123,13,202,5,246,2,46,16,50,2,54,240,211,5,111,12,149,6,87,245,75,6,178,45,70,58,25,0,74,3,50,245,101,253,228,249,197,245,134,2,111,5,94,3,115,252,163,247,179,253,188,5,13,253,44,5,3,253,122,2,195,0,90,179,18,252,119,251,130,9,240,248,72,16,12,16,236,245,133,253,27,246,134,247,139,241,233,251,149,254,1,3,200,19,248,255,114,253,42,9,240,2,168,53,40,240,7,0,116,21,158,28,226,236,236,240,253,12,149,240,113,18,181,21,141,241,194,0,99,205,28,4,219,250,174,245,141,244,26,4,145,240,88,9,45,218,215,9,64,11,140,241,228,248,63,3,18,17,103,251,22,128,104,1,42,245,96,253,240,248,242,255,243,251,209,250,129,5,89,247,172,0,21,6,177,3,239,7,66,253,52,7,174,251,216,1,43,10,46,252,222,10,197,233,193,5,220,233,217,27,200,25,144,247,108,0,204,248,14,8,165,246,28,253,154,6,211,255,43,253,77,0,68,28,153,205,228,242,4,253,78,7,208,2,103,247,22,3,222,38,146,241,36,235,65,240,19,16,207,26,48,9,204,5,22,14,9,237,202,2,8,16,96,24,93,28,57,229,55,19,225,244,45,26,45,29,152,253,78,211,113,248,197,35,24,240,133,0,168,232,151,9,112,219,174,244,255,238,215,225,230,243,79,242,8,10,200,234,192,253,168,216,250,0,125,8,156,239,30,239,128,10,100,20,118,232,166,254,158,45,23,8,80,227,122,247,238,253,76,255,248,245,244,5,175,249,135,221,19,237,234,10,3,245,147,245,137,246,107,245,231,220,57,8,235,237,196,2,248,7,208,233,90,246,147,227,185,26,123,25,100,16,124,229,66,248,4,15,120,236,156,0,138,7,244,6,16,241,226,254,68,15,167,6,136,28,121,4,144,0,156,4,233,27,103,12,1,202,180,25,6,244,79,231,245,217,80,17,135,251,107,11,180,245,254,14,131,228,183,240,238,4,138,250,107,1,115,255,138,252,221,233,44,255,186,247,99,245,164,10,142,182,206,247,101,255,137,250,14,3,29,3,254,2,53,10,254,20,73,241,81,249,112,2,181,2,240,9,247,231,11,28,179,26,6,253,197,19,143,2,40,10,248,35,138,228,135,27,118,6,180,242,176,0,146,234,94,5,238,195,25,254,32,29,94,248,100,9,78,244,184,249,58,9,14,254,240,224,1,232,100,240,60,6,59,244,157,4,2,250,111,235,220,0,139,245,23,4,235,237,38,197,126,15,66,254,63,210,194,233,119,254,6,255,200,250,30,227,228,5,95,24,204,14,129,24,71,24,54,3,97,10,121,31,199,32,110,253,255,245,189,210,227,245,210,229,245,219,8,252,84,247,26,218,100,23,67,7,44,232,14,238,221,0,225,9,169,8,81,32,12,7,16,232,213,244,189,223,157,237,66,246,121,7,160,254,47,238,223,254,247,248,30,252,163,238,23,252,46,21,116,42,58,227,143,6,181,235,53,229,166,11,106,254,96,9,168,17,229,241,156,248,36,19,80,242,3,3,214,10,252,252,119,248,70,227,119,1,116,2,170,17,45,4,55,252,147,31,101,255,106,12,142,251,216,6,120,188,38,17,77,246,233,247,183,250,125,251,56,254,133,245,142,26,140,248,5,7,255,229,46,245,234,21,74,199,34,23,132,240,86,252,171,252,136,5,203,251,46,238,96,255,188,22,41,244,227,19,195,7,70,245,61,241,238,0,248,254,254,243,58,210,154,36,78,38,98,231,139,15,134,244,194,15,137,1,137,250,142,238,133,8,244,2,138,1,216,8,176,241,78,0,214,1,100,243,102,15,78,249,196,2,124,19,146,7,94,245,203,17,66,236,254,251,112,75,98,1,107,0,19,235,244,238,85,2,250,245,4,245,26,247,66,254,104,5,141,254,250,245,124,254,132,240,227,220,176,35,61,13,248,32,62,234,18,251,14,233,8,8,171,232,71,255,188,17], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+389120);
/* memory initializer */ allocate([196,236,154,0,187,241,167,251,24,244,187,27,82,245,124,11,208,229,7,6,72,224,150,39,243,218,11,230,208,18,70,254,224,255,130,246,68,19,15,232,70,236,232,23,157,247,2,229,194,250,51,4,102,246,50,0,117,237,248,243,94,7,210,5,28,74,48,0,19,3,137,9,107,254,132,6,137,250,154,8,127,8,248,241,12,6,88,245,0,237,248,1,127,1,120,1,207,251,94,8,248,1,214,243,234,24,116,234,150,52,196,0,48,7,175,27,24,3,1,242,46,1,244,3,128,234,14,1,26,13,122,238,248,246,38,246,200,244,197,240,43,247,91,20,137,5,253,243,105,255,39,252,252,252,162,249,164,0,147,2,216,5,163,254,147,253,224,255,90,244,72,249,109,242,54,227,251,249,98,4,250,79,190,6,122,17,100,243,112,27,193,12,10,2,111,247,191,247,12,21,120,7,41,23,248,45,118,251,40,10,208,15,140,2,32,13,113,243,120,1,44,39,166,23,26,241,125,251,93,0,160,17,3,242,59,240,60,29,55,250,237,10,75,10,13,208,36,245,165,231,107,22,127,10,120,1,96,23,13,246,126,221,236,16,192,10,150,7,234,3,16,243,131,20,170,255,142,225,150,3,147,246,59,12,12,243,47,8,39,238,234,195,98,234,10,5,59,20,112,11,218,11,61,9,14,1,204,226,48,244,254,26,75,5,138,231,8,248,250,40,152,5,252,47,101,4,168,243,166,17,205,3,209,246,66,249,175,7,208,5,126,1,231,13,98,241,164,244,80,252,130,249,170,2,134,3,248,238,162,19,100,239,68,251,59,243,120,232,52,241,168,35,178,245,167,249,59,1,15,12,63,243,55,215,217,227,18,240,62,243,137,226,153,235,84,21,192,9,214,219,29,255,208,15,92,3,248,253,48,53,126,242,253,14,41,3,152,255,34,240,18,237,120,255,161,249,153,54,144,251,52,13,75,4,74,240,39,7,32,13,182,220,204,255,252,253,160,39,210,19,2,19,90,32,52,252,192,9,32,9,62,34,65,11,113,9,44,234,248,11,94,15,150,239,115,2,38,252,214,6,190,3,212,246,142,19,219,245,166,255,133,0,231,90,127,9,112,240,102,7,210,247,232,248,143,19,164,243,222,9,186,248,91,10,17,7,5,28,82,13,154,0,82,58,216,11,62,235,44,0,164,34,225,253,146,247,221,20,2,1,4,224,188,14,244,10,120,29,147,32,24,242,193,255,33,253,20,5,44,239,195,251,134,236,28,6,168,229,211,245,202,254,251,4,142,4,128,253,206,18,21,17,31,12,38,251,161,23,78,237,85,2,182,0,67,9,38,27,39,247,133,1,179,198,106,248,83,245,27,254,159,252,171,253,160,250,90,6,140,240,36,251,252,5,78,15,17,243,38,6,168,255,163,175,161,234,185,255,61,249,156,5,124,9,142,15,32,238,110,252,84,21,147,236,114,6,196,246,74,246,140,12,48,21,59,246,243,17,87,252,216,2,236,235,36,217,157,5,64,41,184,233,248,254,64,245,181,3,109,20,91,250,174,1,59,3,7,16,49,248,239,237,181,239,191,221,33,221,249,27,187,17,56,27,87,23,238,237,23,245,96,39,110,215,81,246,188,6,176,11,98,1,66,14,0,13,138,17,117,248,180,28,115,28,24,243,94,17,94,249,56,251,70,244,244,16,17,4,95,2,58,254,91,239,105,185,81,251,194,240,58,2,176,22,206,21,54,26,235,0,51,255,64,239,144,13,82,253,153,255,182,241,76,254,48,218,66,255,19,1,105,252,218,9,217,247,136,35,196,19,206,230,42,40,16,13,25,224,248,225,105,46,29,12,0,251,42,217,35,210,165,8,200,2,136,15,134,239,91,235,237,10,180,11,166,15,5,8,40,9,56,24,141,0,56,10,115,240,58,27,158,239,171,249,100,202,92,30,240,10,172,8,189,1,246,254,190,15,188,1,28,255,82,10,81,6,49,246,163,6,36,34,110,13,241,247,211,247,14,7,182,3,56,228,23,250,186,244,171,221,102,3,128,13,226,239,254,242,29,2,67,216,3,249,84,12,114,17,179,232,223,1,57,20,10,245,202,9,146,249,231,241,81,6,51,227,182,243,171,246,17,14,170,30,89,0,211,242,62,18,172,239,142,243,240,11,101,249,34,5,18,36,137,225,43,5,248,238,118,217,118,248,155,31,116,203,55,33,188,7,239,43,8,30,191,232,187,239,136,243,28,2,95,6,131,0,202,8,210,20,110,255,236,221,180,243,18,11,124,4,210,240,118,1,212,248,198,240,177,37,95,4,237,39,128,0,164,34,123,227,41,10,228,4,36,9,51,241,74,18,181,0,82,17,52,249,16,17,111,3,148,253,254,7,50,7,76,3,99,252,54,246,240,242,140,221,46,253,61,254,9,2,135,3,250,250,13,244,68,235,105,237,110,245,107,250,202,10,159,3,77,250,150,227,4,209,134,34,147,15,102,9,178,33,200,243,105,25,30,239,59,255,96,246,178,10,210,255,161,0,95,54,204,8,11,8,213,3,204,0,137,4,46,19,171,2,41,239,33,8,116,248,95,4,77,232,51,235,80,33,160,237,110,234,217,231,112,22,177,242,27,248,128,10,98,243,186,9,48,252,12,254,102,225,16,8,119,12,132,18,102,14,226,6,44,10,118,246,168,233,130,226,201,1,106,242,95,224,146,230,111,220,95,31,225,236,244,1,124,246,203,5,193,238,25,248,72,241,63,246,137,248,21,3,54,2,55,252,148,239,240,23,44,236,104,10,130,239,99,26,238,6,225,26,64,0,181,4,229,219,174,18,80,17,73,20,46,247,77,237,247,226,219,6,230,252,17,5,145,226,229,49,164,35,38,3,44,9,80,224,194,30,4,239,126,250,162,254,32,246,64,2,149,2,16,1,246,17,179,2,121,7,235,242,167,248,194,248,245,252,203,252,252,32,60,0,10,10,235,248,182,250,96,238,161,234,120,18,217,12,57,10,146,219,242,229,165,252,103,245,145,217,68,18,159,245,34,12,143,250,38,40,3,244,51,247,247,3,198,8,77,247,16,0,124,254,26,31,213,5,206,243,109,245,46,31,38,232,74,250,127,249,234,250,43,9,56,14,238,196,93,247,161,1,163,26,191,3,196,244,44,229,52,43,231,246,210,254,59,6,254,237,42,37,133,49,250,237,173,244,115,255,7,237,167,5,0,25,178,244,160,6,184,244,97,7,161,13,215,10,8,254,59,230,118,235,168,227,133,254,31,251,120,255,46,12,47,242,223,12,126,242,55,8,113,254,177,59,34,255,239,248,172,0,209,8,155,7,195,2,234,13,197,233,247,13,94,247,118,22,47,3,219,15,240,255,26,5,4,204,59,249,198,250,107,242,127,20,98,248,228,235,90,253,138,31,204,6,34,1,241,7,31,18,112,239,232,253,162,235,170,250,187,9,245,1,197,255,128,238,174,1,227,254,197,232,13,253,33,199,64,22,48,27,110,17,13,9,14,25,138,204,98,19,125,252,36,23,92,43,183,20,54,252,32,246,161,231,205,8,188,8,41,2,202,1,75,247,80,31,86,228,53,11,143,239,148,238,120,230,229,13,26,249,135,30,113,253,115,232,126,235,165,249,86,10,118,242,0,242,133,3,65,40,129,252,85,254,181,3,40,245,108,13,1,3,221,239,59,35,222,236,22,242,214,224,153,254,78,5,8,250,233,243,208,22,186,231,31,10,218,247,8,37,128,2,42,11,216,0,215,241,108,22,160,228,183,251,213,247,113,255,224,18,66,24,178,250,158,15,54,253,67,3,92,240,80,14,188,7,216,4,86,11,254,1,227,249,171,1,252,247,144,239,31,250,163,4,51,251,148,14,92,252,10,252,176,18,42,72,9,236,231,11,202,255,245,249,204,240,164,33,18,1,166,5,36,242,247,225,89,254,168,4,100,238,93,215,225,221,66,254,188,1,47,231,168,15,74,250,54,221,119,251,165,246,138,9,156,8,160,234,32,188,167,9,79,253,114,5,183,241,185,247,255,252,56,11,113,5,115,245,48,242,66,14,134,254,91,3,246,242,132,5,194,11,85,243,177,254,221,241,1,254,117,248,42,228,102,236,140,219,168,238,114,7,39,247,106,5,136,31,80,230,236,250,82,21,226,236,118,2,22,228,215,8,42,3,152,11,100,4,85,247,244,8,182,240,212,248,229,229,231,5,61,245,116,5,121,9,222,162,201,8,203,255,133,252,114,249,26,249,4,249,246,1,142,239,211,0,136,40,125,234,69,3,204,231,84,8,40,254,87,216,66,28,80,250,108,255,22,19,123,9,67,9,210,4,62,252,154,24,248,3,199,6,202,253,146,252,121,224,221,9,132,47,253,18,33,37,53,227,98,254,186,11,64,2,165,254,26,252,45,11,220,252,218,11,42,3,236,252,229,253,212,247,106,19,36,7,203,244,14,245,249,25,89,14,63,255,62,240,210,2,106,6,208,14,66,34,188,40,25,243,247,240,88,238,22,255,162,239,61,251,236,250,224,239,192,32,130,251,42,6,226,231,208,251,249,236,12,224,214,229,222,14,38,227,15,246,28,4,218,253,132,251,228,250,126,221,162,245,190,7,12,34,179,25,80,5,156,246,101,7,120,10,217,14,89,43,175,5,149,9,95,226,177,226,90,206,92,254,231,7,112,253,100,4,56,11,204,37,43,239,54,255,178,5,130,230,234,253,1,250,156,3,252,11,138,251,209,19,4,5,0,234,101,3,155,249,174,244,36,19,38,216,8,215,183,251,98,7,254,42,212,255,88,5,69,248,107,25,60,1,193,3,8,0,11,240,1,10,14,248,203,251,34,10,47,254,242,235,156,252,54,0,218,229,136,37,68,242,253,27,3,43,70,37,172,18,16,245,150,251,78,249,132,245,143,254,138,18,128,245,50,16,28,226,216,3,65,243,236,254,82,220,224,244,113,240,10,39,24,14,162,12,172,253,7,1,30,12,78,255,40,247,236,14,59,239,136,233,7,242,182,240,71,4,230,249,94,86,2,18,69,0,73,244,254,0,130,8,171,244,77,251,244,250,82,10,74,243,147,250,139,11,60,5,30,2,42,3,89,5,136,12,229,252,56,243,99,245,151,251,77,34,58,229,44,244,152,253,217,2,17,2,222,228,85,6,102,37,195,197,22,21,86,3,250,252,6,217,215,234,44,246,181,237,83,22,190,255,8,13,80,236,128,2,114,226,166,13,104,27,35,247,96,5,86,201,48,25,148,240,95,249,108,240,97,230,72,9,135,16,197,243,253,7,143,246,225,232,152,228,97,249,86,35,226,224,67,20,7,246,122,5,209,246,36,255,43,23,225,248,34,247,72,2,56,241,108,11,22,24,37,244,66,9,59,19,200,251,170,2,37,225,181,213,224,248,116,252,32,6,19,242,193,15,86,239,100,248,155,3,112,21,53,255,164,246,117,252,223,10,50,243,135,5,30,30,66,255,168,235,25,247,242,4,148,251,192,242,11,40,216,251,19,44,114,8,165,8,32,236,127,17,206,237,245,248,254,5,119,239,23,240,26,27,126,15,242,236,180,254,73,23,1,36,232,1,120,25,78,17,52,31,167,36,230,245,182,4,185,228,151,252,227,4,57,7,57,23,160,247,16,248,196,248,160,1,136,14,115,9,14,33,101,12,4,45,178,244,115,234,45,255,166,69,98,12,74,4,47,253,238,247,92,248,231,243,219,251,255,10,191,1,189,2,193,1,27,254,49,10,215,4,209,8,32,249,19,12,114,29,126,14,127,245,236,243,247,26,103,246,199,12,211,24,50,250,196,252,202,7,9,242,109,15,113,12,46,10,208,236,89,193,127,221,39,7,20,10,201,7,163,251,176,242,90,226,146,227,115,255,136,10,37,3,104,7,52,1,122,1,92,36,78,11,28,239,18,4,69,3,108,18,162,237,189,9,203,235,168,33,44,254,19,198,175,14,179,12,115,239,196,250,104,20,51,8,4,253,185,223,93,249,76,0,72,250,67,8,186,253,214,12,187,241,249,3,160,6,122,250,100,253,236,217,158,233,109,9,10,251,74,232,106,66,116,8,192,234,9,7,181,247,32,3,87,8,193,18,137,252,163,247,121,253,18,237,49,254,191,253,202,248,213,253,119,248,254,7,80,32,49,223,46,15,194,232,150,239,200,206,11,245,221,1,65,0,252,23,65,4,127,237,7,35,160,7,80,248,180,241,241,25,82,3,24,243,17,249,170,15,67,42,29,56,72,253,205,250,68,249,19,255,229,241,244,0,189,11,253,16,74,255,228,239,162,9,186,10,195,255,63,13,144,250,204,14,46,6,139,14,228,27,97,247,162,241,141,245,4,255,204,226,210,36,204,231,154,12,226,13,74,231,68,239,202,24,176,238,79,20,183,245,61,246,176,4,140,251,186,240,224,25,92,65,58,23,2,253,70,10,80,251,196,7,134,21,81,251,30,16,7,5,198,1,253,248,104,10,137,19,34,4,244,1,75,254,176,11,36,248,96,255,28,3,18,237,84,230,152,216,91,2,227,1,98,238,1,206,174,13,8,249,182,13,140,240,150,23,84,35,115,232,2,28,184,249,120,0,146,3,56,255,99,15,126,231,204,11,91,24,62,245,248,20,99,249,116,232,130,1,42,248,106,7,72,210,11,217,243,253,192,245,7,7,44,16,176,12,199,255,109,241,180,14,206,21,10,241,76,246,238,247,237,5,124,252,198,223,1,224,116,10,123,4,96,26,252,26,172,4,182,245,80,13,164,11,238,251,131,15,120,2,174,236,198,233,133,0,141,9,66,254,242,250,247,252,28,13,4,234,124,232,150,224,205,19,115,250,115,245,243,196,2,12,112,252,242,245,83,10,132,20,186,247,9,15,47,241,174,252,74,16,96,24,71,253,64,27,88,241,131,4,89,30,48,221,208,225,128,16,198,246,80,241,104,14,98,9,173,242,163,243,10,246,248,255,47,255,178,254,187,252,56,22,97,13,44,238,15,39,84,237,21,12,250,16,76,234,100,6,219,6,152,198,18,7,147,25,196,255,214,15,43,41,230,23,194,238,224,6,253,13,183,252,119,17,233,255,180,0,3,1,169,238,82,204,210,250,121,7,147,253,151,249,190,244,186,236,4,2,210,240,140,238,146,255,82,238,219,235,126,29,159,238,45,3,244,238,232,6,131,221,211,7,164,250,81,7,47,255,3,6,52,4,136,207,72,250,170,248,27,6,228,7,192,2,145,5,237,254,122,241,10,18,160,251,63,236,250,241,182,15,71,248,108,2,143,0,53,246,113,14,65,243,104,2,70,244,237,242,59,82,210,238,108,1,124,248,28,1,92,245,7,247,52,19,142,10,2,19,197,16,35,245,70,4,11,250,206,253,111,21,206,247,50,18,82,5,171,253,158,242,101,12,202,235,82,15,252,240,202,5,103,18,221,22,210,5,123,21,127,187,188,3,32,2,12,1,82,237,8,254,93,240,113,252,87,2,210,6,102,227,115,7,198,7,89,66,99,12,171,245,16,4,185,227,242,21,48,1,22,14,207,242,46,14,151,28,108,0,16,254,2,4,246,11,120,254,62,9,156,7,238,253,38,3,140,10,140,245,99,245,118,20,120,193,201,252,248,254,232,249,10,252,8,253,156,241,182,254,12,22,124,249,1,216,233,245,243,28,175,253,145,8,57,250,180,244,250,14,215,241,54,208,177,251,76,7,255,235,39,15,188,10,144,7,234,7,220,17,107,232,238,12,26,222,204,45,170,20,244,246,35,16,66,3,181,240,101,3,58,249,136,233,231,4,62,37,215,241,141,255,232,232,131,255,250,8,42,250,22,23,16,254,97,245,40,5,103,12,60,244,190,240,250,17,104,237,226,232,248,245,232,25,158,221,12,233,214,24,45,9,207,0,71,20,177,32,212,232,150,10,14,31,89,14,224,245,31,5,192,32,248,238,166,33,226,233,156,4,99,8,20,4,55,6,77,234,195,249,66,17,38,0,213,249,67,18,67,249,99,249,186,230,250,11,79,226,234,205,12,2,86,244,178,242,156,34,14,251,94,252,220,16,147,4,164,244,199,0,7,249,221,244,252,241,0,12,255,241,148,245,157,251,228,5,204,1,124,26,232,179,38,11,218,249,236,3,210,19,115,7,60,248,153,4,74,0,100,250,176,8,208,4,64,244,130,242,162,252,92,2,115,253,218,10,45,9,170,12,234,32,82,254,100,14,206,18,162,248,254,19,207,5,186,1,238,246,124,252,218,244,22,255,146,215,14,225,23,253,46,250,250,233,130,232,17,240,93,244,161,254,21,37,30,247,158,211,26,224,60,227,69,32,18,6,70,249,43,18,193,252,228,8,222,5,40,10,242,4,104,17,207,239,3,241,0,242,146,16,218,15,165,246,197,228,134,17,161,12,82,24,26,5,14,211,177,231,244,235,1,6,201,238,230,5,100,22,248,10,185,22,148,236,172,244,129,3,119,246,229,248,19,22,180,228,177,216,16,247,68,233,30,251,157,3,48,12,237,23,83,217,119,255,100,14,55,230,53,4,200,12,21,0,13,13,186,252,197,241,65,249,191,238,148,2,105,230,72,255,67,224,12,249,112,20,189,23,224,224,23,25,239,14,210,11,203,17,208,1,246,12,128,234,69,3,13,242,13,15,27,247,184,248,26,253,252,234,208,23,200,26,52,4,109,3,126,253,134,7,152,237,110,199,5,243,144,245,61,29,188,247,164,240,185,8,58,243,70,1,173,8,132,0,155,248,20,253,197,1,13,14,252,246,237,238,0,22,25,14,247,251,68,254,225,245,207,67,208,243,212,245,85,12,142,254,26,36,186,249,115,10,171,252,195,5,96,254,48,243,121,251,191,0,170,241,26,1,186,16,67,252,94,244,236,13,91,0,216,175,26,244,224,4,253,4,40,13,94,4,55,1,170,253,126,5,183,246,92,250,137,5,214,241,167,0,216,230,13,13,117,2,37,246,46,17,93,251,226,16,129,254,142,7,30,243,174,222,147,8,100,20,254,1,24,251,236,228,219,251,21,20,142,192,146,250,222,253,80,241,19,248,95,252,100,232,81,242,56,1,30,33,189,2,161,34,107,18,195,7,62,5,120,5,185,255,147,235,245,249,133,221,45,9,36,50,57,250,13,18,115,23,163,229,144,243,221,233,142,244,206,251,132,12,74,1,84,18,56,11,200,213,75,0,20,251,83,70,4,16,74,250,111,5,125,249,9,248,81,253,58,237,25,23,122,10,50,30,122,27,143,10,130,6,120,0,65,6,75,8,122,5,162,237,35,212,195,30,41,234,26,18,30,247,199,11,171,253,160,226,185,251,50,237,83,255,186,21,253,5,247,10,18,33,75,20,126,30,25,10,195,244,26,27,154,240,146,1,15,241,66,16,189,35,233,230,143,9,129,27,116,11,171,217,76,8,198,255,253,255,200,205,219,224,204,5,139,3,180,0,106,31,180,247,4,17,235,239,102,4,22,218,203,247,117,15,171,248,115,4,236,27,123,14,195,250,157,17,60,251,218,17,142,249,152,230,124,27,228,215,184,254,70,18,83,208,198,19,201,23,16,254,196,225,159,8,137,17,51,255,106,5,121,245,94,250,122,18,124,3,29,47,234,14,23,243,79,17,84,36,142,13,0,18,219,16,124,3,98,3,78,249,249,5,9,10,122,211,4,244,230,254,90,6,75,2,224,249,162,249,36,255,15,248,229,27,84,245,43,242,76,13,154,60,91,7,119,245,98,252,84,23,85,25,118,229,63,8,186,9,177,4,91,21,208,246,192,12,159,255,96,9,40,253,220,242,89,13,201,5,46,11,206,1,39,11,143,235,108,22,40,28,244,214,74,243,170,5,10,251,219,254,72,13,190,228,51,39,67,251,212,16,81,10,131,33,70,33,153,244,161,254,53,254,235,247,151,253,126,2,189,250,107,0,121,23,243,7,232,254,217,7,208,12,44,251,144,197,199,235,120,246,197,3,170,245,209,247,154,20,33,7,121,14,247,14,66,254,78,240,10,28,145,246,248,16,58,7,3,254,12,254,32,4,234,238,77,22,56,5,24,13,235,30,2,247,177,47,230,199,29,25,143,5,96,11,74,25,193,249,92,4,232,8,54,249,36,12,96,233,30,242,111,2,170,251,30,232,136,17,237,34,152,243,102,53,8,243,185,254,159,245,75,227,198,14,55,250,105,22,56,255,152,11,254,218,120,22,192,19,80,18,24,235,80,254,118,252,8,241,185,222,249,255,83,14,255,13,106,24,20,34,241,41,155,36,182,3,162,249,12,214,156,22,15,16,162,244,181,1,78,246,118,7,185,0,136,247,173,243,69,242,38,249,114,19,202,16,247,228,220,1,38,245,34,2,140,245,58,247,209,243,168,244,109,245,102,248,38,30,244,8,147,9,110,16,66,251,150,254,92,4,164,252,30,0,31,252,136,252,234,251,108,241,36,247,19,246,172,23,84,247,195,249,142,249,216,250,88,0,205,4,70,8,44,9,150,5,183,248,114,247,182,247,204,248,235,247,46,249,15,0,46,249,41,5,145,245,79,244,81,243,5,245,163,247,176,250,94,7,14,1,131,254,44,22,234,247,68,254,94,253,198,251,136,251,166,254,201,252,22,18,32,255,148,7,119,246,232,247,110,247,217,254,127,8,185,4,34,253,168,0,155,3,79,5,149,245,133,1,231,245,25,247,109,247,139,251,8,252,38,255,109,0,134,7,64,20,78,247,160,248,7,251,236,251,25,0,205,1,118,3,101,4,225,4,89,247,179,246,37,12,85,248,199,11,21,248,234,252,168,4,110,6,140,8,166,244,218,245,228,1,188,246,164,250,198,251,182,6,152,2,111,5,92,9,42,246,145,7,198,246,50,246,32,250,131,11,190,1,172,2,155,7,11,8,65,243,71,244,88,243,38,244,218,245,39,13,55,17,23,9,146,9,178,11,181,246,173,248,186,248,243,24,92,248,119,250,243,253,74,4,44,7,116,11,128,5,150,251,119,250,157,6,250,254,123,253,253,253,187,1,223,2,107,2,238,244,58,247,170,245,39,246,213,252,208,25,91,254,36,6,223,7,162,12,218,247,101,250,89,0,112,6,70,3,38,252,121,251,72,251,224,255,74,5,169,247,145,247,116,30,136,246,75,252,8,248,101,251,228,0,163,4,192,11,109,244,60,246,230,247,23,248,97,250,156,6,134,254,172,253,194,255,115,9,62,242,196,243,173,244,38,243,143,244,28,11,49,0,211,16,194,10,57,15,112,244,25,5,190,248,193,252,157,250,251,252,185,12,211,3,207,3,233,5,223,244,182,249,179,9,200,1,141,250,134,253,79,3,40,5,92,4,151,4,193,9,238,249,128,8,95,249,27,252,225,252,136,255,83,1,228,3,99,5,95,44,235,249,85,247,67,247,0,249,220,247,15,252,13,3,13,13,171,3,162,7,188,248,213,246,187,247,48,248,142,250,241,14,106,0,35,10,114,8,134,244,72,246,192,247,4,3,221,251,30,7,159,0,249,3,148,9,226,5,33,5,201,245,81,246,131,244,84,247,50,246,42,253,95,18,242,6,47,13,195,243,152,245,251,244,45,245,23,6,24,252,78,254,82,7,34,16,171,11,74,244,124,245,234,246,44,6,73,247,189,250,70,16,229,7,153,4,227,9,192,244,223,246,227,245,225,5,229,244,92,246,173,254,221,251,140,12,168,16,216,243,187,244,183,244,207,3,38,246,26,247,209,2,193,19,149,15,45,13,230,243,125,244,152,251,53,247,143,7,165,11,191,11,207,3,191,7,0,8,211,244,2,247,129,246,76,250,44,250,12,250,80,252,20,6,242,6,13,6,158,245,45,247,208,10,100,246,89,250,141,11,247,2,68,1,229,9,173,9,137,244,105,249,6,246,169,245,105,250,118,0,147,254,40,40,246,5,119,13,246,245,220,8,209,246,189,247,28,10,247,255,190,252,91,4,86,7,61,9,79,0,108,4,173,249,130,250,224,249,26,249,32,255,57,3,65,8,102,5,220,253,147,245,251,248,125,245,165,247,65,246,46,255,252,4,55,53,11,9,173,7,79,249,182,249,117,247,230,9,41,250,235,250,110,2,51,2,106,8,183,10,158,12,8,249,18,249,232,252,19,254,125,255,156,0,176,3,187,4,162,248,101,1,6,252,225,0,227,254,1,4,122,255,218,0,34,1,153,0,237,22,153,246,216,244,21,244,20,246,90,243,44,247,142,254,61,254,170,24,12,254,6,246,194,247,145,252,189,254,231,253,58,2,204,4,20,6,62,5,74,246,38,13,46,7,87,252,65,252,85,253,63,0,169,3,140,2,188,4,140,247,88,250,166,0,225,252,218,253,219,250,225,1,43,1,118,21,80,5,181,243,242,245,35,252,14,6,160,7,34,250,160,255,189,13,24,5,7,9,141,244,158,247,130,247,252,247,67,2,168,2,128,3,137,10,191,2,85,5,34,16,193,246,189,245,203,243,90,252,235,243,149,247,69,252,137,23,160,19,207,243,8,244,189,244,102,246,187,6,182,252,216,11,39,17,23,9,21,11,24,246,96,247,182,249,115,247,109,25,112,250,164,251,147,5,14,11,42,13,60,4,230,249,137,249,164,249,21,254,212,8,191,254,165,1,6,3,213,4,61,243,209,3,158,243,184,243,118,245,212,250,144,5,218,11,251,12,19,13,51,244,11,244,235,7,215,246,84,3,240,244,78,249,38,23,165,17,255,14,46,250,144,246,66,249,12,251,78,250,167,247,77,249,188,253,123,5,96,52,67,244,110,245,9,244,71,245,39,245,168,247,226,10,202,0,21,20,79,13,224,243,71,244,152,243,196,242,77,242,209,244,207,247,21,9,58,10,2,24,51,248,176,243,244,251,122,245,229,245,86,244,66,245,85,247,185,249,56,23,179,244,183,245,75,247,5,245,78,246,189,247,85,247,100,251,126,20,180,12,217,243,252,247,123,245,138,244,243,248,23,10,97,1,238,4,140,33,60,15,92,246,90,245,187,248,208,246,67,247,66,245,215,246,112,248,65,38,200,32,94,242,204,243,244,241,210,241,174,243,170,246,231,2,252,25,222,24,255,23,220,244,37,242,204,243,98,245,186,251,18,254,49,0,227,251,67,244,255,127,71,249,51,251,77,249,202,249,51,6,47,251,56,13,4,255,56,1,96,4,41,243,146,244,24,244,244,244,58,246,95,251,236,7,194,14,231,1,35,8,104,2,215,251,170,249,99,248,253,250,161,252,163,26,5,2,111,4,2,5,71,10,89,250,59,250,20,252,30,1,78,5,121,255,172,254,147,0,126,255,59,21,183,249,132,248,34,249,214,251,154,251,222,1,227,3,74,4,157,5,55,249,197,250,184,248,39,248,242,251,20,252,195,253,42,3,86,23,24,11,93,1,233,249,40,250,129,251,205,254,174,255,169,2,59,3,38,2,8,3,138,7,166,0,180,251,47,250,95,251,98,251,70,251,186,254,90,3,152,6,255,245,186,13,32,253,19,6,197,255,118,252,133,255,87,0,102,0,18,1,110,7,53,254,192,11,40,252,61,253,178,254,197,253,195,254,66,255,141,254,210,244,95,2,66,5,19,250,60,251,151,253,190,9,185,2,190,0,64,0,192,12,86,15,31,251,250,249,91,252,210,254,10,255,8,255,69,0,229,254,26,249,18,253,150,248,21,251,185,26,246,249,239,252,192,255,184,4,14,5,14,250,50,249,175,248,150,248,81,250,216,27,16,253,182,6,118,5,99,4,74,245,125,18,240,249,77,246,94,247,17,254,99,1,96,3,62,3,247,2,95,245,189,247,157,248,96,249,143,251,233,249,15,251,110,253,177,253,82,3,69,253,238,4,217,253,225,251,109,3,96,0,124,254,64,255,33,254,189,251,53,245,157,250,218,12,27,9,150,252,205,254,126,254,103,2,110,1,133,0,145,245,61,20,243,16,130,252,153,252,134,253,91,255,153,1,91,0,221,254,167,245,101,254,103,31,101,248,124,251,57,0,95,1,246,3,216,1,58,255,232,248,178,253,71,11,90,249,167,251,86,13,212,253,117,0,227,1,135,254,85,249,134,251,125,251,214,9,222,7,130,254,3,0,250,255,206,0,158,255,18,42,18,1,121,250,122,249,4,252,244,251,238,252,242,252,49,254,216,253,60,246,220,40,168,249,5,249,61,253,209,250,197,255,119,1,91,0,22,0,40,245,217,246,200,247,57,3,9,253,201,252,226,1,125,4,241,4,58,2,116,249,222,248,200,248,237,23,145,250,204,252,63,254,76,3,74,2,23,2,199,244,85,246,209,245,205,245,218,248,25,254,107,6,144,6,40,8,10,10,203,246,31,252,117,12,63,250,178,13,77,251,231,252,150,2,208,1,98,0,53,246,81,6,255,248,113,248,229,250,87,255,9,0,117,3,216,2,154,4,38,248,190,250,161,250,69,255,220,253,193,10,48,254,151,255,31,3,255,1,134,247,132,246,127,247,39,250,24,8,60,3,185,1,252,3,105,3,232,3,239,250,5,250,185,248,81,248,20,250,192,251,10,253,26,255,25,6,255,25,131,247,5,249,244,249,29,249,170,250,232,255,123,253,180,26,200,5,131,7,88,245,189,248,6,7,38,248,207,249,91,253,141,254,125,5,230,4,254,4,54,247,45,245,193,244,41,245,64,247,173,250,240,254,209,4,28,24,210,19,190,244,141,246,250,247,140,246,28,251,91,1,45,5,7,7,187,6,9,17,6,3,18,8,82,7,24,1,61,253,163,253,187,253,106,253,176,251,10,248,199,27,119,255,141,252,201,251,23,252,202,255,177,252,11,252,235,251,192,252,88,18,197,14,144,253,51,250,176,250,177,250,229,250,61,251,158,252,79,252,43,21,24,250,253,246,170,247,248,247,68,249,139,249,138,253,157,0,71,13,41,253,164,252,155,250,132,254,52,253,201,250,235,14,78,0,254,255,21,1,143,243,210,243,101,245,218,243,36,250,90,6,24,13,3,12,164,7,229,253,0,65,76,251,23,247,253,246,32,247,211,246,39,248,120,247,39,245,185,246,9,252,64,24,110,254,205,250,98,251,5,253,38,253,175,255,177,253,96,251,121,248,31,2,112,17,185,251,125,255,226,253,127,255,230,1,146,254,183,251,198,249,214,253,241,255,175,254,80,12,45,253,71,0,216,255,129,1,203,254,255,252,34,1,171,252,222,251,84,251,235,249,173,253,111,14,105,4,182,1,193,6,227,250,53,252,153,252,90,0,138,5,237,4,233,255,154,250,33,255,241,249,55,253,236,251,143,17,96,255,157,252,38,251,164,4,159,0,120,0,135,249,73,252,0,6,97,255,226,250,77,4,108,254,155,0,181,6,232,255,185,249,43,9,8,8,105,248,223,250,239,250,175,255,34,0,161,5,98,1,194,247,175,248,252,253,78,4,126,8,83,8,0,0,78,252,39,253,61,0,107,0,242,255,148,255,206,255,42,0,92,255,79,255,164,255,227,255,162,0,69,5,180,246,205,247,100,249,44,252,207,255,162,255,75,1,37,5,235,14,30,254,242,252,249,252,115,252,128,253,181,251,153,253,31,255,20,6,157,11,138,253,70,0,70,255,193,249,204,251,88,17,134,252,78,0,180,255,251,253,169,252,162,248,15,250,74,251,128,251,124,252,241,2,58,5,222,6,127,9,127,246,223,249,242,250,185,253,40,2,248,7,102,255,250,0,1,2,29,9,204,252,61,248,13,247,66,247,168,248,141,249,160,251,250,254,221,7,28,38,13,245,242,245,182,245,27,245,100,1,210,248,69,1,232,17,0,14,182,9,12,250,82,7,175,254,248,248,133,249,150,1,146,9,228,4,11,255,250,251,193,7,115,254,227,249,205,255,148,0,247,7,68,251,39,253,68,253,245,255,136,3,137,2,19,2,17,247,152,249,254,2,43,253,171,0,196,249,107,5,117,12,96,253,53,254,230,252,90,254,54,253,61,255,25,255,185,0,99,0,72,252,56,247,134,247,90,251,55,254,178,5,34,0,155,4,123,9,147,6,134,249,165,14,232,248,48,248,7,11,37,251,121,250,201,2,107,3,75,0,238,252,193,0,175,195,200,0,26,4,95,191,215,255,73,1,155,252,86,255,166,252,165,10,217,0,191,1,59,8,233,255,125,254,216,215,129,254,192,254,131,1,140,62,177,255,57,252,200,13,181,247,231,253,132,253,31,249,181,3,100,0,239,255,66,254,5,1,255,87,75,1,26,0,169,255,50,255,12,247,102,251,92,255,86,2,147,0,121,3,105,199,249,244,0,251,156,248,33,0,29,249,225,3,199,18,71,252,133,8,180,253,59,0,216,254,218,0,35,1,152,255,239,1,188,251,184,8,200,197,41,252,153,244,27,3,201,188,3,248,172,11,85,2,184,215,50,253,108,247,66,233,79,3,24,5,11,253,150,237,108,255,63,3,34,253,38,3,252,16,204,254,244,0,54,2,146,10,92,2,20,253,160,252,200,253,37,255,128,255,80,253,38,255,110,0,151,141,226,1,76,0,89,250,114,255,95,254,3,255,188,31,193,178,222,3,194,17,12,252,110,224,133,0,180,249,61,247,52,241,32,6,180,244,84,3,150,249,105,242,233,255,20,5,204,253,243,251,249,0,59,199,213,255,65,1,88,253,10,0,95,254,130,91,141,1,148,255,51,7,180,0,200,46,115,218,97,1,184,14,130,0,245,251,244,16,218,0,84,2,32,255,245,252,112,249,46,5,152,0,53,252,3,218,157,254,208,20,53,254,114,63,74,254,158,3,66,24,120,7,1,3,61,10,108,255,16,252,5,2,85,1,246,241,59,252,119,44,150,252,203,189,143,4,213,242,137,249,74,2,124,255,150,15,254,252,211,0,246,0,2,2,90,255,34,253,200,118,254,254,247,253,236,255,83,1,243,1,244,245,62,8,16,1,77,5,123,0,25,11,192,254,225,255,68,254,11,254,215,0,214,255,83,2,108,0,228,1,33,255,169,3,219,1,184,255,193,254,75,0,51,255,46,252,61,220,145,0,228,7,253,255,134,9,206,15,255,250,149,252,252,5,170,253,0,48,113,1,2,248,87,1,246,252,233,6,227,245,127,253,29,68,1,7,176,253,94,248,185,249,40,24,112,13,0,254,106,245,206,250,129,255,61,34,83,0,13,255,197,254,197,2,0,1,152,4,82,251,49,254,202,3,210,254,200,253,27,252,2,252,159,0,0,43,27,0,18,51,243,5,89,243,26,9,56,237,227,23,51,217,169,5,105,8,217,243,244,6,37,253,121,0,143,252,47,200,247,254,54,2,157,253,3,255,107,244,250,0,151,255,190,255,10,10,126,248,152,10,115,7,23,248,58,254,173,0,183,5,227,255,45,131,143,255,41,249,231,242,254,0,233,3,125,26,227,255,129,253,247,250,32,1,242,1,255,171,48,0,109,0,153,247,33,255,80,5,154,242,146,2,167,239,86,249,220,4,107,7,124,0,12,0,221,255,33,1,126,1,177,1,5,1,125,255,54,0,122,253,232,254,86,0,180,0,153,0,87,255,238,176,161,255,222,2,244,253,77,0,102,0,20,33,91,254,29,0,253,255,51,0,246,5,168,253,248,254,99,1,157,7,39,252,221,254,170,255,228,39,235,252,119,254,74,255,205,255,178,3,180,190,70,252,155,4,71,245,3,254,90,237,181,253,160,253,233,29,3,254,124,254,219,3,109,0,38,255,85,187,244,253,45,254,149,249,68,254,150,5,237,9,132,255,249,6,27,0,225,30,183,255,193,243,39,251,2,255,190,247,151,4,12,3,206,255,215,15,23,2,182,1,32,0,143,255,252,254,81,0,78,4,197,255,4,114,208,255,212,0,227,255,168,254,47,2,88,3,29,254,96,2,216,255,38,250,112,0,134,40,174,4,78,254,213,15,6,5,236,0,31,7,174,62,80,2,47,6,78,0,133,235,31,5,200,1,194,250,222,253,159,254,233,51,179,254,239,253,133,174,183,0,89,255,168,250,174,254,78,253,152,16,51,255,102,253,134,253,139,249,150,4,234,0,66,183,123,3,28,1,184,245,20,250,33,1,234,43,215,2,133,0,28,1,189,254,166,250,140,3,143,204,100,254,131,4,154,1,98,2,0,244,228,223,131,253,242,0,121,253,232,247,169,62,244,8,183,224,95,1,191,243,253,243,229,251,217,17,125,0,23,0,1,5,183,9,8,2,47,255,80,253,205,0,32,251,246,0,167,253,21,2,79,208,6,247,58,3,54,245,45,0,19,59,209,2,104,4,30,3,92,253,93,1,103,255,7,1,89,0,170,252,232,255,162,254,29,255,157,0,75,2,16,255,71,255,151,2,184,129,108,255,52,255,164,246,171,253,168,254,168,31,232,254,137,254,8,1,136,2,229,2,222,254,191,254,7,1,199,253,131,254,167,0,221,6,60,140,30,0,137,1,142,1,78,2,14,255,81,0,65,6,99,14,19,3,176,254,163,2,200,251,55,253,5,1,244,71,224,6,97,2,254,237,217,253,230,10,95,77,67,5,131,255,60,219,251,254,36,2,32,4,179,0,107,252,75,255,93,49,245,254,109,2,124,209,86,5,76,0,243,22,26,253,138,1,155,0,142,254,177,9,46,0,224,195,168,254,234,217,183,250,62,247,107,249,250,250,16,9,128,247,63,249,193,2,210,249,54,6,67,6,137,82,29,242,144,8,141,252,110,13,233,0,173,7,231,253,143,1,46,237,11,240,47,2,220,254,10,5,116,245,10,0,211,254,183,248,226,0,52,0,190,250,50,1,60,1,7,208,243,253,29,1,159,37,254,255,175,252,84,6,128,0,176,0,3,252,39,254,249,30,123,255,155,9,223,255,19,250,225,169,4,247,98,0,71,242,78,1,9,18,63,255,227,250,1,251,226,2,69,254,95,0,150,1,148,2,63,253,202,255,217,255,28,103,2,253,249,0,137,246,79,30,79,253,187,240,4,188,65,0,57,7,177,3,35,62,106,5,79,254,193,252,51,231,177,240,78,7,160,31,55,1,195,58,173,6,197,254,8,5,98,29,41,255,48,236,222,4,50,250,178,14,174,17,237,5,112,248,225,253,249,254,3,3,25,216,87,254,22,236,59,0,246,254,12,252,132,254,173,247,118,2,149,1,153,2,58,238,123,5,8,0,210,255,145,252,142,1,236,253,71,255,226,254,153,3,191,255,122,1,157,2,174,0,80,196,91,0,248,252,32,33,159,9,184,0,17,8,102,253,207,253,26,16,82,2,220,2,167,15,172,252,185,255,194,0,130,255,229,6,222,249,200,3,255,254,224,254,182,3,90,107,179,254,114,1,107,250,29,1,46,2,237,43,121,255,53,2,16,5,251,254,194,255,88,2,175,5,177,5,52,3,101,1,77,251,169,0,227,64,131,252,103,1,231,0,162,1,221,253,161,255,26,15,1,254,56,231,51,255,155,3,17,255,179,192,173,249,217,0,222,242,58,231,241,249,137,2,20,254,8,1,201,255,170,0,96,66,165,255,50,1,43,0,46,245,70,2,52,249,77,0,142,252,12,1,253,253,211,255,51,232,24,0,36,234,74,35,28,1,139,12,78,3,134,4,162,251,164,253,254,253,122,5,19,254,86,252,204,240,242,0,131,2,141,5,78,254,106,254,154,255,168,255,43,210,161,0,6,2,210,3,228,5,248,0,244,251,127,5,116,254,37,1,130,4,101,250,239,1,51,32,20,0,179,252,3,235,147,2,62,9,220,113,145,0,91,2,248,15,5,255,231,244,34,246,202,80,179,250,106,246,148,2,131,255,91,1,252,45,143,255,155,254,123,247,46,251,116,7,80,254,171,64,8,255,54,3,156,60,98,255,115,253,37,6,93,0,86,245,169,251,190,3,242,249,127,251,17,0,98,2,13,3,140,254,152,249,144,0,121,255,109,251,124,86,85,254,230,255,178,2,224,252,39,250,212,254,62,21,134,1,40,44,37,36,74,4,188,21,247,255,16,15,197,3,224,7,3,206,151,6,147,3,103,14,27,2,192,9,190,2,212,250,185,255,101,205,32,29,18,18,176,252,233,248,63,3,103,8,241,30,72,244,123,0,165,4,47,250,222,0,109,19,144,7,54,0,225,214,42,251,123,251,116,2,32,55,140,247,198,5,39,252,250,239,123,2,225,0,201,254,159,253,9,252,45,1,251,1,171,255,187,1,186,0,216,253,57,253,164,189,209,250,220,0,53,2,119,249,225,253,201,72,75,1,127,0,170,254,22,0,179,255,152,254,73,254,11,254,200,248,133,251,29,254,109,4,161,254,41,0,140,3,246,1,110,253,218,1,82,254,172,211,255,255,237,253,195,1,197,2,227,0,46,252,92,1,247,254,13,1,136,254,207,9,68,255,145,255,125,254,41,3,241,3,34,6,13,253,57,211,155,2,129,252,190,1,20,1,145,0,255,253,139,255,50,254,172,254,177,5,61,252,191,0,236,252,106,255,45,252,5,254,108,148,122,0,112,1,183,255,67,39,47,254,130,2,251,1,84,229,241,0,95,236,62,6,106,251,69,9,32,247,138,248,148,255,15,0,166,0,2,0,22,41,165,3,84,206,254,1,10,3,88,254,158,1,35,19,247,2,94,3,74,254,138,252,201,1,48,1,87,92,136,0,53,255,222,1,203,253,244,0,227,253,115,9,251,252,83,4,39,255,43,6,243,251,220,1,159,255,227,3,53,70,161,0,82,64,78,255,50,253,186,249,179,3,199,7,218,8,225,4,148,10,157,253,144,5,114,255,203,255,36,0,253,1,47,102,112,255,101,1,219,255,22,255,75,2,55,1,3,254,153,249,180,254,174,249,130,254,46,1,47,222,188,255,226,255,33,2,222,205,158,0,158,0,135,0,109,2,158,254,153,252,195,1,196,4,225,255,2,0,154,203,60,0,3,0,132,254,29,2,212,255,40,2,146,254,155,0,50,254,61,0,24,255,190,195,61,1,176,2,97,4,117,11,239,27,88,255,49,220,39,246,233,2,232,10,48,215,57,2,17,241,118,2,238,237,161,255,96,254,60,3,3,1,72,0,171,0,123,2,6,255,128,255,86,254,103,255,4,1,253,252,58,1,235,0,26,0,25,126,169,254,239,2,93,250,68,1,84,253,108,7,202,250,230,7,30,0,49,4,154,246,32,8,27,254,192,254,224,59,164,252,239,253,196,191,37,255,200,6,107,255,96,255,196,252,65,4,157,1,241,0,136,14,166,255,146,0,85,4,243,0,191,254,0,255,188,255,88,0,206,255,59,2,155,4,58,158,104,0,161,3,35,0,17,2,117,0,100,202,222,2,192,250,200,1,210,21,30,6,227,206,184,252,175,249,66,246,255,6,109,7,250,11,145,247,98,254,240,240,90,217,184,249,111,253,251,59,251,252,255,219,110,253,52,252,122,18,86,244,106,242,11,253,120,250,138,241,169,70,117,2,149,27,124,0,211,22,158,0,73,74,100,247,192,228,93,6,231,233,77,4,189,248,111,250,220,253,148,251,77,236,50,4,176,253,60,255,110,7,177,88,52,251,214,0,83,253,12,248,192,246,197,254,110,252,21,2,218,0,67,4,141,253,239,7,98,54,104,0,62,254,142,17,14,254,151,254,158,96,111,2,5,4,133,9,157,251,28,236,105,230,182,1,178,64,119,1,210,204,63,255,44,248,228,13,179,0,40,7,38,8,30,3,234,253,61,255,63,228,28,3,129,15,19,208,34,6,177,16,124,245,216,4,171,244,3,248,107,246,116,1,101,2,220,253,11,255,175,2,2,1,252,220,36,250,17,250,31,252,163,68,155,254,148,3,78,251,216,6,33,8,232,253,143,243,218,251,135,75,209,2,26,217,28,4,152,252,248,0,195,243,200,1,105,6,149,0,245,255,139,11,54,1,150,243,121,182,241,1,53,252,69,230,156,250,95,1,106,0,213,255,95,2,110,237,213,0,6,4,1,21,220,252,3,246,82,3,57,4,62,253,45,5,182,197,230,252,20,201,95,248,123,3,32,243,73,1,2,254,154,251,89,4,217,6,101,254,233,6,173,1,71,255,4,252,194,0,150,255,206,44,177,253,240,254,166,1,81,1,12,2,106,255,54,3,51,0,136,255,25,28,34,3,128,2,116,255,214,255,221,109,4,252,29,1,47,254,123,12,69,0,226,1,71,252,6,1,8,226,139,254,38,20,249,21,69,244,38,2,251,20,243,21,104,247,16,21,220,252,135,0,20,5,230,241,233,255,79,254,191,52,224,0,143,3,171,199,10,254,153,247,125,249,115,248,72,11,235,254,35,2,35,252,43,12,224,255,88,253,92,255,36,3,156,1,62,0,102,255,66,255,156,0,70,213,152,254,168,255,75,3,72,1,251,252,245,254,132,206,88,3,216,5,13,255,182,253,224,2,129,247,91,253,3,244,56,29,28,249,72,240,247,245,13,7,194,0,98,229,145,251,19,255,122,10,100,255,134,252,5,5,112,1,10,7,85,253,93,255,167,4,249,204,16,254,177,254,74,68,234,2,50,3,48,0,171,83,170,253,39,249,111,251,169,247,40,0,102,220,80,2,184,240,188,7,248,254,208,254,202,31,71,255,30,1,48,244,48,0,162,249,141,3,149,2,106,253,165,70,240,0,55,255,69,0,192,0,49,1,105,169,180,2,145,251,28,252,142,1,182,255,121,72,66,252,199,4,54,234,252,1,160,254,210,4,62,254,241,1,12,3,79,0,51,0,35,255,255,0,230,255,40,52,86,255,231,0,78,2,169,0,35,253,212,252,191,255,37,255,53,174,200,0,35,0,79,255,58,254,120,2,245,254,105,254,136,255,111,2,80,255,104,253,203,2,233,255,62,1,148,0,101,4,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+399360);
/* memory initializer */ allocate([197,2,73,171,26,255,99,254,118,5,45,251,229,254,79,6,175,0,213,254,93,1,144,1,144,255,2,85,103,253,108,1,65,4,23,5,202,255,11,2,131,254,224,250,48,0,138,252,20,251,152,1,159,1,99,223,203,27,180,0,250,252,180,13,53,252,1,255,61,255,81,0,142,245,47,252,157,254,36,250,178,0,223,247,176,238,10,252,84,1,186,22,138,0,150,255,21,66,179,4,93,1,199,12,193,3,107,1,120,23,101,232,152,14,38,253,151,239,254,253,13,232,188,255,169,197,11,249,198,240,216,255,0,182,51,254,98,249,11,251,13,253,175,255,65,9,228,1,19,2,34,55,85,0,32,0,98,216,114,255,88,2,186,246,119,1,163,2,153,245,155,0,77,252,27,25,212,44,229,4,185,19,39,4,211,7,184,249,159,9,136,247,152,251,55,4,127,1,28,252,112,1,184,4,30,242,65,252,244,17,71,251,198,239,246,4,149,36,41,245,41,249,230,3,201,177,165,254,225,5,218,0,114,255,86,1,128,255,245,253,97,255,75,0,45,254,1,1,123,255,114,255,200,2,147,253,172,1,112,140,13,0,146,1,57,254,119,0,29,254,97,4,51,254,192,3,39,3,210,255,41,1,8,58,221,0,156,254,221,0,189,58,120,237,5,246,191,1,118,250,184,5,111,5,132,250,76,233,0,2,239,246,154,38,242,0,6,247,119,255,175,252,146,243,178,36,132,5,28,4,89,5,120,252,18,254,25,255,89,4,63,4,251,203,0,3,102,251,61,244,24,0,229,0,164,0,70,216,72,1,52,1,177,253,213,0,225,253,174,255,234,252,149,252,26,3,210,253,29,226,195,253,242,4,220,247,227,8,69,255,97,0,128,1,202,209,71,255,40,254,85,5,116,45,131,250,104,1,25,254,72,254,228,248,163,254,219,254,29,1,25,0,117,255,97,254,228,253,148,255,112,4,95,253,230,0,2,75,223,253,226,253,151,3,197,4,250,253,196,0,116,170,27,3,115,0,240,255,203,1,11,13,165,254,166,254,70,255,73,253,245,254,54,253,185,0,10,1,62,251,120,0,7,255,233,0,146,255,52,137,29,1,219,0,208,8,24,2,70,254,161,2,49,250,35,254,196,255,242,248,183,0,229,227,191,253,182,8,86,226,98,243,65,0,179,89,111,0,134,1,222,27,124,241,253,235,37,254,224,255,158,255,46,254,138,255,213,255,74,0,209,251,122,252,178,6,164,15,26,0,97,0,144,6,167,1,252,0,195,37,38,2,98,1,34,255,19,0,32,255,217,252,109,1,81,2,107,1,173,252,228,255,41,2,238,0,31,254,1,3,23,1,191,71,50,254,30,1,217,18,115,255,244,1,159,79,82,6,225,255,254,253,76,246,185,254,198,222,63,253,152,252,18,2,243,216,220,255,81,254,8,11,113,12,176,6,194,254,41,37,175,216,102,2,9,254,133,1,30,50,143,255,241,255,17,252,245,253,243,250,202,247,225,253,123,251,185,253,204,4,6,1,94,253,201,248,14,255,43,1,7,209,35,2,177,253,43,220,19,1,156,1,189,9,229,3,205,4,190,7,162,107,245,0,106,0,216,250,103,255,89,254,69,252,63,254,136,1,56,3,28,3,99,251,104,6,140,252,186,255,85,34,37,39,242,248,251,3,90,0,214,5,23,8,113,252,121,251,212,0,159,8,30,252,60,246,15,254,92,0,232,210,114,254,250,252,194,5,32,0,97,253,85,255,30,251,7,255,137,4,114,253,51,255,220,255,197,6,251,2,181,166,57,62,66,62,200,62,60,78,33,63,113,27,77,63,199,186,128,63,243,31,154,63,54,171,182,63,211,222,216,63,121,88,248,63,89,23,11,64,206,136,22,64,250,237,31,64,158,94,37,64,125,208,43,64,140,219,48,64,174,71,57,64,20,63,6,62,56,248,162,62,114,138,238,62,183,98,15,63,222,113,42,63,149,101,72,63,254,212,128,63,17,199,162,63,53,94,194,63,111,240,221,63,231,251,249,63,117,2,14,64,250,237,23,64,65,241,31,64,150,178,44,64,8,61,59,64,212,154,38,62,112,95,231,62,106,222,33,63,216,129,51,63,167,232,72,63,213,231,122,63,2,43,151,63,217,61,169,63,82,73,197,63,27,13,232,63,194,134,247,63,119,45,5,64,29,90,20,64,168,53,33,64,239,56,45,64,189,227,60,64,61,10,23,62,163,146,122,62,135,22,217,62,92,32,17,63,240,133,73,63,81,218,123,63,155,85,151,63,183,209,176,63,24,149,196,63,199,75,215,63,46,144,240,63,228,20,9,64,222,113,26,64,231,29,39,64,98,161,50,64,211,222,60,64,218,172,250,61,79,64,147,62,50,85,0,63,229,208,50,63,38,228,99,63,102,136,139,63,186,73,164,63,200,7,189,63,198,109,212,63,82,73,237,63,34,253,2,64,224,190,14,64,195,100,26,64,95,7,38,64,50,119,49,64,151,255,60,64,69,71,50,62,63,87,155,62,96,118,239,62,157,128,22,63,7,206,57,63,34,253,118,63,58,35,146,63,76,55,169,63,108,9,193,63,102,136,219,63,226,233,245,63,251,58,8,64,253,135,20,64,107,154,31,64,199,75,43,64,4,231,56,64,67,173,41,62,65,130,162,62,8,61,251,62,16,233,39,63,29,90,84,63,79,64,131,63,65,130,154,63,252,169,177,63,0,111,201,63,127,106,228,63,172,139,243,63,35,74,7,64,103,68,21,64,59,1,33,64,1,222,46,64,45,178,57,64,83,5,35,62,168,53,141,62,129,38,226,62,252,169,33,63,19,97,83,63,177,191,124,63,121,88,144,63,88,57,164,63,123,131,183,63,254,212,208,63,62,232,241,63,172,173,8,64,93,220,22,64,120,11,36,64,146,203,47,64,186,73,60,64,191,14,28,62,164,112,221,62,103,213,23,63,33,31,52,63,129,4,69,63,198,109,100,63,91,66,150,63,43,24,189,63,95,152,212,63,196,66,229,63,140,185,251,63,237,158,12,64,142,6,24,64,186,73,32,64,189,82,42,64,69,216,56,64,172,28,90,62,254,67,154,62,228,131,190,62,90,245,217,62,188,5,2,63,129,149,51,63,150,67,123,63,242,176,160,63,145,126,187,63,48,42,217,63,102,247,244,63,72,225,6,64,54,60,21,64,106,222,33,64,255,178,47,64,32,210,59,64,177,225,233,61,201,229,191,62,23,217,30,63,156,162,67,63,201,229,79,63,148,246,102,63,22,251,123,63,65,241,147,63,119,45,185,63,105,0,223,63,21,140,250,63,50,85,8,64,149,101,24,64,72,191,37,64,115,104,49,64,202,84,61,64,18,131,0,62,123,131,111,62,180,200,182,62,208,68,8,63,192,236,62,63,213,9,128,63,150,33,150,63,88,168,173,63,17,199,194,63,60,78,217,63,42,58,242,63,95,7,6,64,197,32,20,64,120,156,34,64,214,86,48,64,190,193,59,64,39,194,6,62,195,100,106,62,219,138,221,62,163,146,42,63,149,212,89,63,174,216,127,63,187,184,149,63,242,176,176,63,146,203,199,63,192,91,216,63,187,184,237,63,136,133,6,64,200,152,23,64,179,12,37,64,66,96,49,64,237,158,60,64,7,206,25,62,238,90,130,62,66,207,198,62,89,134,8,63,234,149,50,63,163,146,106,63,116,181,141,63,40,15,171,63,66,96,197,63,236,81,224,63,206,136,242,63,158,94,5,64,166,10,18,64,51,196,29,64,0,0,44,64,77,132,57,64,138,31,35,62,26,81,154,62,58,35,234,62,147,169,34,63,183,209,80,63,12,2,123,63,137,210,150,63,43,246,175,63,172,173,200,63,214,197,221,63,93,220,246,63,117,147,8,64,183,209,20,64,193,202,33,64,182,243,45,64,216,129,59,64,71,114,57,62,129,38,162,62,4,86,238,62,70,148,38,63,106,222,81,63,195,245,128,63,181,55,152,63,16,233,175,63,213,231,194,63,131,192,218,63,103,68,241,63,85,193,4,64,154,153,17,64,121,233,30,64,104,34,44,64,152,76,57,64,200,7,61,62,116,36,183,62,98,16,8,63,190,159,58,63,213,231,106,63,59,1,141,63,161,248,161,63,133,235,185,63,254,212,208,63,149,212,233,63,240,133,1,64,170,96,12,64,85,193,24,64,183,209,36,64,48,42,49,64,2,154,60,64,161,103,179,61,134,90,19,62,23,183,81,62,181,21,187,62,41,203,32,63,5,163,98,63,15,156,139,63,48,76,166,63,213,231,194,63,217,95,222,63,137,65,248,63,228,20,9,64,189,82,22,64,67,28,35,64,75,200,47,64,195,211,59,64,59,112,14,62,6,129,213,62,43,246,39,63,200,152,75,63,36,151,95,63,64,164,127,63,158,239,151,63,35,219,185,63,109,86,205,63,125,63,229,63,47,221,0,64,207,247,11,64,191,125,21,64,34,108,32,64,232,106,47,64,70,182,63,64,193,168,164,61,131,192,10,62,157,17,133,62,201,229,255,62,18,165,61,63,206,136,114,63,50,85,144,63,223,224,171,63,231,29,199,63,174,182,226,63,175,37,252,63,242,210,9,64,111,18,23,64,216,129,35,64,250,237,47,64,20,174,59,64,148,135,5,62,237,13,158,62,192,236,254,62,231,140,40,63,254,101,87,63,17,54,132,63,36,185,156,63,132,158,181,63,118,79,206,63,195,245,232,63,217,206,255,63,126,29,12,64,86,14,25,64,228,20,37,64,216,240,48,64,54,205,59,64,74,12,66,62,106,222,145,62,45,178,189,62,79,64,211,62,78,98,32,63,255,178,107,63,11,181,150,63,82,39,176,63,138,176,201,63,28,235,226,63,108,120,250,63,5,163,10,64,209,34,23,64,20,174,35,64,241,99,48,64,45,67,60,64,236,81,56,62,246,151,157,62,25,4,246,62,68,250,45,63,67,173,89,63,188,150,128,63,100,204,149,63,220,215,169,63,205,59,190,63,193,57,211,63,17,54,236,63,83,150,5,64,236,81,20,64,69,71,34,64,55,26,48,64,2,154,60,64,20,174,71,62,148,135,165,62,177,225,233,62,98,16,24,63,69,71,66,63,210,111,127,63,214,197,149,63,106,77,171,63,181,55,192,63,49,8,212,63,170,130,233,63,59,223,3,64,159,205,18,64,216,240,32,64,74,123,47,64,104,34,60,64,83,150,129,62,183,209,224,62,88,57,20,63,80,141,55,63,75,89,102,63,211,77,146,63,29,201,173,63,61,44,196,63,151,255,208,63,39,160,225,63,40,126,252,63,220,70,11,64,159,205,22,64,40,15,35,64,150,67,47,64,95,7,58,64,254,212,56,62,224,190,142,62,245,219,183,62,11,181,198,62,35,74,11,63,63,53,78,63,7,206,137,63,18,131,168,63,120,11,196,63,55,26,224,63,60,78,249,63,41,203,8,64,210,0,22,64,252,24,35,64,163,1,48,64,88,57,60,64,60,78,81,62,136,244,187,62,58,35,10,63,116,70,52,63,255,178,91,63,113,172,123,63,11,36,144,63,25,226,168,63,15,11,189,63,202,84,217,63,222,147,239,63,148,246,2,64,156,196,16,64,97,84,30,64,70,37,45,64,99,238,58,64,98,161,214,61,82,184,94,62,226,88,215,62,249,160,23,63,151,144,63,63,215,163,112,63,87,91,145,63,144,160,176,63,45,67,204,63,45,178,221,63,197,254,242,63,94,75,8,64,105,0,23,64,24,38,35,64,220,70,47,64,80,141,59,64,13,113,172,61,179,12,49,62,140,74,202,62,15,11,37,63,173,105,94,63,119,190,135,63,64,164,159,63,139,108,183,63,5,197,207,63,66,62,232,63,229,97,1,64,137,65,12,64,183,209,24,64,25,226,36,64,27,47,49,64,209,145,60,64,61,155,21,62,248,194,132,62,14,45,210,62,202,84,17,63,200,152,59,63,143,83,100,63,249,49,134,63,50,119,157,63,11,36,184,63,145,237,212,63,12,147,241,63,185,141,6,64,65,241,19,64,23,183,33,64,21,140,46,64,84,82,59,64,62,232,25,62,45,33,159,62,216,129,243,62,72,80,44,63,246,40,92,63,127,251,130,63,111,18,155,63,44,212,178,63,70,182,203,63,129,4,229,63,78,209,249,63,91,66,10,64,26,81,22,64,170,241,34,64,109,197,46,64,83,150,57,64,191,125,93,62,81,218,187,62,51,51,3,63,26,192,43,63,247,117,80,63,63,53,126,63,229,208,154,63,242,210,181,63,132,13,207,63,154,8,219,63,145,126,235,63,2,188,5,64,179,123,22,64,35,219,33,64,54,171,42,64,16,88,57,64,81,107,90,62,192,91,224,62,124,242,32,63,109,197,94,63,41,237,141,63,185,252,175,63,246,151,205,63,14,79,223,63,147,169,234,63,248,194,244,63,40,15,251,63,23,72,4,64,25,115,11,64,215,18,22,64,169,164,38,64,52,162,56,64,156,162,35,62,122,54,139,62,157,128,198,62,43,135,246,62,162,180,23,63,80,141,71,63,72,191,133,63,219,249,166,63,33,176,194,63,212,154,222,63,21,29,249,63,216,240,8,64,60,189,22,64,99,238,34,64,137,65,48,64,218,27,60,64,207,102,149,62,9,138,15,63,9,27,46,63,219,138,61,63,147,24,84,63,0,111,113,63,17,54,148,63,88,57,180,63,179,12,209,63,13,113,236,63,122,165,252,63,53,239,4,64,250,126,18,64,163,35,33,64,227,165,47,64,121,233,62,64,195,100,42,62,170,130,145,62,12,2,203,62,81,218,11,63,124,242,80,63,198,109,132,63,206,170,151,63,218,27,172,63,197,143,193,63,112,206,224,63,238,124,255,63,20,208,12,64,94,75,24,64,220,104,36,64,87,91,49,64,184,30,61,64,163,146,186,61,235,115,117,62,202,84,1,63,186,107,73,63,195,211,131,63,227,199,144,63,36,185,156,63,147,169,170,63,137,65,184,63,121,233,214,63,87,236,247,63,34,253,10,64,15,156,23,64,118,113,35,64,219,249,46,64,184,175,59,64,30,167,40,62,52,17,150,62,56,103,196,62,164,223,254,62,197,32,32,63,237,158,108,63,163,35,145,63,173,105,166,63,118,113,195,63,43,135,230,63,29,90,252,63,228,20,9,64,181,55,24,64,29,56,35,64,105,0,43,64,207,247,55,64,35,219,121,62,147,169,194,62,216,129,243,62,245,74,41,63,232,217,92,63,211,188,131,63,38,83,157,63,207,247,179,63,206,136,194,63,150,33,222,63,97,195,243,63,201,118,6,64,11,36,20,64,114,249,31,64,247,228,45,64,198,220,57,64,229,208,34,62,79,64,147,62,30,22,234,62,99,127,25,63,235,115,69,63,170,241,114,63,139,108,143,63,49,8,164,63,7,206,185,63,94,186,209,63,242,176,232,63,192,236,2,64,88,168,17,64,190,159,30,64,16,233,43,64,172,28,58,64,122,54,107,62,237,158,220,62,42,58,18,63,136,244,43,63,50,85,80,63,41,237,133,63,201,229,159,63,53,94,186,63,34,253,214,63,45,67,236,63,232,106,251,63,245,74,9,64,57,69,23,64,43,135,34,64,233,183,47,64,156,196,60,64,236,81,152,62,123,131,239,62,146,203,255,62,221,181,20,63,14,190,32,63,251,58,48,63,72,80,92,63,165,189,145,63,62,121,184,63,71,3,216,63,197,32,240,63,253,246,5,64,214,86,20,64,249,15,33,64,12,2,47,64,90,100,59,64,1,222,2,62,155,85,191,62,208,179,25,63,102,247,52,63,46,144,80,63,211,77,130,63,108,9,161,63,41,203,176,63,221,36,190,63,200,7,221,63,178,157,255,63,27,13,8,64,88,202,18,64,40,126,36,64,56,103,48,64,191,125,57,64,185,141,6,62,220,104,128,62,177,191,204,62,115,104,17,63,237,13,62,63,146,203,111,63,247,117,144,63,215,163,168,63,1,77,196,63,109,197,222,63,242,65,247,63,80,252,8,64,86,125,22,64,200,152,35,64,98,16,48,64,61,44,60,64,61,155,213,61,124,97,114,62,54,205,219,62,193,57,35,63,96,229,80,63,54,205,123,63,109,197,150,63,174,71,177,63,33,176,202,63,205,204,228,63,244,253,252,63,249,49,10,64,183,98,23,64,91,177,35,64,168,198,47,64,175,37,60,64,209,145,28,62,156,196,128,62,69,216,176,62,229,242,223,62,74,123,51,63,180,200,102,63,240,133,137,63,168,53,173,63,124,242,200,63,117,147,224,63,104,34,0,64,191,14,8,64,70,148,14,64,43,24,29,64,86,125,46,64,236,81,60,64,97,84,18,62,5,197,143,62,37,6,225,62,129,38,34,63,0,145,78,63,176,114,120,63,188,116,147,63,154,153,169,63,44,101,193,63,125,63,221,63,190,193,247,63,207,102,9,64,254,67,22,64,172,139,35,64,169,19,48,64,195,211,59,64,102,102,38,62,245,185,154,62,216,129,243,62,252,169,33,63,132,158,77,63,237,13,126,63,198,109,148,63,222,2,169,63,87,236,191,63,242,176,216,63,190,159,242,63,219,249,6,64,41,92,19,64,126,29,32,64,17,54,44,64,213,120,57,64,196,66,45,62,96,118,175,62,57,214,5,63,185,141,70,63,71,3,120,63,246,40,140,63,231,29,167,63,217,206,183,63,215,163,200,63,247,6,231,63,71,3,248,63,204,93,7,64,7,206,21,64,169,19,32,64,95,7,46,64,79,64,59,64,129,38,66,61,55,26,0,62,185,141,70,62,193,168,196,62,244,108,38,63,72,80,108,63,39,194,142,63,213,120,169,63,79,30,198,63,103,68,225,63,102,136,251,63,252,169,9,64,248,83,23,64,102,136,35,64,208,68,48,64,126,29,60,64,211,222,96,62,32,99,238,62,146,203,63,63,210,0,126,63,120,122,149,63,245,219,159,63,103,213,167,63,66,207,174,63,237,13,182,63,152,221,195,63,72,80,220,63,229,242,255,63,175,37,16,64,105,0,31,64,200,7,45,64,43,135,58,64,176,3,231,61,179,123,114,62,18,165,189,62,131,47,12,63,116,181,69,63,73,46,127,63,57,180,152,63,252,24,179,63,102,247,204,63,127,217,229,63,0,145,254,63,130,226,11,64,225,122,24,64,18,131,36,64,14,190,48,64,170,96,60,64,131,81,9,62,187,184,141,62,121,233,230,62,88,202,34,63,152,76,85,63,186,73,132,63,181,166,153,63,234,149,178,63,236,192,201,63,26,81,226,63,203,161,253,63,160,26,11,64,161,103,23,64,102,136,35,64,240,22,48,64,134,201,60,64,183,98,255,61,83,5,131,62,234,4,180,62,161,248,241,62,64,164,47,63,202,195,114,63,162,180,151,63,229,97,177,63,143,228,202,63,49,8,228,63,141,40,253,63,231,29,11,64,152,221,23,64,230,63,36,64,156,196,48,64,121,88,60,64,58,146,75,62,231,251,169,62,24,149,244,62,154,119,44,63,20,174,87,63,90,100,131,63,230,174,149,63,180,200,174,63,41,237,197,63,248,83,219,63,197,32,248,63,92,143,10,64,234,149,22,64,75,89,34,64,186,73,48,64,16,88,61,64,4,231,12,62,221,36,134,62,17,199,218,62,41,237,29,63,43,135,70,63,138,176,113,63,148,246,142,63,220,104,168,63,140,74,194,63,35,219,217,63,26,81,242,63,17,199,6,64,179,234,19,64,211,222,32,64,177,225,45,64,1,222,58,64,208,68,88,62,18,131,224,62,250,237,27,63,83,5,67,63,138,142,116,63,26,192,147,63,147,24,172,63,157,17,197,63,243,142,219,63,88,168,245,63,77,21,8,64,197,254,22,64,150,33,38,64,94,75,52,64,33,31,60,64,27,158,66,64,204,238,9,62,7,240,86,62,167,121,135,62,41,203,176,62,66,207,6,63,71,114,73,63,0,145,134,63,168,198,163,63,201,118,190,63,179,234,219,63,148,246,246,63,89,134,8,64,77,132,21,64,44,212,34,64,58,146,47,64,179,234,59,64,183,209,160,62,158,239,23,63,105,111,64,63,20,208,84,63,63,87,91,63,244,253,116,63,51,51,131,63,236,81,144,63,54,205,171,63,172,173,208,63,29,201,237,63,18,131,4,64,192,236,18,64,166,155,32,64,146,92,46,64,220,70,59,64,129,4,197,61,172,173,88,62,159,205,202,62,220,104,16,63,189,82,54,63,161,103,99,63,43,24,141,63,138,142,172,63,114,249,199,63,242,176,224,63,67,28,251,63,82,184,10,64,233,183,23,64,243,142,35,64,80,141,47,64,190,193,59,64,16,233,183,61,190,159,26,62,8,172,156,62,244,253,20,63,37,117,82,63,102,247,132,63,216,240,156,63,50,230,182,63,191,125,205,63,233,183,231,63,171,62,255,63,54,205,11,64,229,242,23,64,231,140,36,64,69,216,48,64,52,162,60,64,75,200,7,62,141,40,109,62,46,144,192,62,253,135,4,63,132,158,45,63,23,72,96,63,131,47,140,63,215,163,168,63,151,255,192,63,3,9,218,63,81,218,243,63,207,247,7,64,226,233,21,64,252,24,35,64,64,164,47,64,240,22,60,64,14,45,50,62,2,154,168,62,84,116,4,63,196,177,46,63,235,226,86,63,248,194,132,63,85,48,154,63,135,167,175,63,149,101,200,63,128,72,223,63,140,219,248,63,211,222,8,64,240,22,20,64,119,190,31,64,32,65,45,64,52,128,59,64,250,237,107,62,174,71,193,62,135,22,249,62,91,66,30,63,85,193,72,63,140,185,107,63,153,187,142,63,241,99,164,63,161,103,187,63,71,114,217,63,13,224,245,63,98,16,8,64,103,213,19,64,50,119,33,64,25,115,47,64,204,93,59,64,117,2,26,60,171,207,213,60,179,123,114,187,75,89,134,59,153,187,22,188,224,45,144,187,237,13,190,188,215,52,239,187,117,2,154,187,39,160,9,187,205,204,204,60,104,145,109,189,66,96,101,188,77,21,12,189,142,6,112,189,111,18,3,59,16,233,55,61,182,243,125,60,134,56,86,189,138,142,228,188,216,240,244,60,226,233,149,188,153,187,150,189,1,222,130,189,137,210,222,186,39,160,9,61,122,54,171,60,153,187,150,59,72,80,252,59,179,123,114,188,17,199,58,188,166,155,68,188,127,106,60,60,10,215,163,187,162,69,54,61,82,73,157,59,117,2,154,60,247,117,96,188,111,18,3,188,239,201,195,60,153,187,150,188,98,161,86,189,119,190,159,188,59,112,78,188,30,167,232,60,0,111,129,61,176,3,103,60,7,95,24,188,82,73,29,188,46,144,160,60,127,106,188,60,8,61,27,61,72,80,252,60,129,38,194,60,52,128,183,188,143,194,117,189,190,159,154,189,136,244,219,189,168,87,202,189,181,55,120,189,24,149,212,189,192,236,30,190,80,141,23,190,39,160,137,189,59,112,78,61,222,113,138,61,39,160,9,61,39,160,137,187,152,76,149,61,96,118,207,61,51,196,177,61,196,66,173,61,19,97,195,61,170,241,82,61,208,68,216,187,233,72,174,189,240,167,70,189,69,216,240,60,193,202,33,61,114,138,14,60,36,151,255,59,125,174,54,61,198,109,180,61,39,160,137,61,82,73,29,189,10,215,35,187,231,251,41,61,188,150,16,61,111,18,3,60,195,100,170,59,227,165,155,60,43,24,149,60,101,25,226,59,39,160,137,60,190,48,25,61,179,123,114,59,215,52,239,188,233,183,47,189,254,101,247,60,3,120,139,61,164,223,190,188,56,248,194,188,82,73,157,185,4,231,140,187,124,242,176,59,237,13,62,187,33,31,116,188,74,123,131,61,109,197,126,61,113,172,11,61,237,13,190,188,91,211,60,189,75,89,6,188,55,26,64,189,255,33,125,189,148,135,5,189,163,35,57,189,75,234,132,189,253,135,116,189,83,5,35,189,184,64,2,189,237,13,62,188,224,45,144,58,250,237,107,58,82,73,29,189,82,73,29,189,36,151,127,188,244,253,212,188,52,128,55,186,165,189,65,61,198,220,53,60,5,163,18,189,20,63,70,189,231,29,167,188,237,13,62,187,188,116,19,188,213,120,233,188,131,192,74,189,117,2,26,189,54,205,187,61,33,31,244,61,243,31,210,61,117,147,152,61,120,156,34,61,18,165,61,61,242,65,207,60,10,215,35,59,201,118,62,61,10,215,35,60,130,226,71,61,195,100,42,61,125,174,182,60,25,115,215,60,250,237,235,59,159,171,173,187,70,182,115,61,166,155,196,59,61,44,84,189,0,111,1,189,4,231,140,187,62,232,89,188,164,223,190,188,143,194,245,187,132,158,205,188,28,235,226,60,172,139,219,187,137,210,94,188,23,183,209,185,18,131,192,60,52,128,55,60,43,24,149,188,221,181,4,189,49,8,172,188,66,96,101,187,193,202,33,189,82,73,29,189,111,18,3,58,143,194,117,188,78,209,17,189,169,19,80,60,208,68,88,187,137,210,94,187,158,239,167,60,80,252,152,61,249,15,233,61,59,223,207,61,168,198,203,61,38,228,131,188,188,116,147,187,134,90,83,60,202,84,65,61,31,133,107,61,198,220,181,60,43,24,21,60,179,123,114,59,238,235,64,189,43,246,23,61,208,68,88,60,195,100,170,60,168,87,202,60,91,177,63,60,75,89,134,60,236,81,184,60,95,41,75,60,153,187,22,187,224,45,16,60,153,187,150,187,117,2,154,59,9,249,32,189,250,237,235,58,179,123,114,60,111,18,3,59,224,45,144,59,2,43,135,60,200,152,187,60,195,100,170,188,19,97,67,189,182,243,253,188,75,89,134,188,119,190,31,189,154,119,156,189,61,10,87,189,117,2,26,188,143,194,245,59,231,29,39,188,188,116,147,187,59,112,78,189,5,52,145,189,121,88,168,61,115,104,145,61,86,125,46,61,52,128,183,58,43,246,23,189,10,215,35,189,73,157,128,188,182,243,125,188,187,184,141,188,101,25,98,188,166,155,196,186,172,139,91,60,122,54,43,189,113,172,139,189,23,183,209,188,10,215,163,59,188,116,19,61,151,255,16,61,179,123,242,59,156,51,34,189,18,131,192,188,30,167,232,60,168,87,74,61,218,172,122,60,52,128,55,61,10,215,35,59,130,226,199,187,59,112,206,60,205,204,204,61,139,108,103,62,173,250,92,62,172,173,88,62,64,19,97,62,152,110,82,62,98,16,88,62,146,203,63,62,220,70,67,62,6,18,84,62,246,151,93,62,187,184,77,62,115,215,82,62,99,127,89,62,8,61,91,62,189,82,86,62,51,51,179,61,167,232,200,61,179,12,241,61,63,87,219,61,243,142,211,61,36,151,255,61,98,161,214,61,219,138,253,61,251,203,238,61,59,112,206,61,99,127,217,61,95,41,203,61,58,146,203,61,136,133,218,61,95,152,204,61,252,24,243,61,154,153,153,61,120,156,162,61,12,147,169,61,50,230,174,61,87,236,175,61,120,11,164,61,16,122,182,61,18,20,191,61,130,115,198,61,127,106,188,61,90,100,187,61,160,137,176,61,51,196,177,61,16,122,182,61,13,113,172,61,85,193,168,61,0,0,128,61,201,118,190,61,121,233,166,61,196,177,174,61,16,233,183,61,12,147,169,61,121,88,168,61,53,94,186,61,88,202,178,61,126,140,185,61,14,79,175,61,49,8,172,61,228,131,158,61,156,196,160,61,77,21,140,61,224,156,145,61,204,238,169,62,71,3,216,62,213,231,234,62,115,104,209,62,170,130,209,62,77,132,205,62,88,168,181,62,113,172,171,62,127,217,189,62,86,159,171,62,201,118,190,62,70,37,181,62,206,25,209,62,200,152,219,62,59,223,207,62,80,141,215,62,69,216,112,61,122,54,171,60,75,89,6,188,127,106,60,188,40,126,12,189,146,92,126,189,246,151,93,189,187,184,13,189,187,184,13,189,226,233,21,189,88,57,180,188,135,22,217,188,231,29,39,188,190,48,25,61,218,172,250,60,120,122,37,61,218,172,250,60,188,116,19,60,124,242,176,187,149,101,8,61,117,2,154,59,56,248,194,60,176,3,103,60,2,43,135,60,218,172,250,60,49,8,44,61,184,64,130,60,95,41,75,60,12,147,41,61,0,111,129,60,129,38,194,188,176,3,103,60,8,172,156,61,17,199,186,59,244,253,212,188,86,125,46,189,193,202,33,189,59,112,78,188,141,40,109,189,159,205,42,189,71,255,190,176,220,1,240,254,31,0,130,253,38,3,195,255,220,0,176,0,178,0,236,252,71,254,179,254,152,254,249,254,140,255,0,254,66,38,41,253,200,34,168,4,235,254,244,2,98,253,27,3,201,254,240,0,151,253,93,253,54,252,244,2,89,3,17,2,90,255,162,2,122,3,246,253,69,3,79,0,150,253,228,250,248,201,232,2,46,21,128,10,19,2,142,1,220,5,83,248,47,255,166,254,101,2,99,8,69,39,138,250,189,0,148,255,215,1,78,251,231,3,178,0,250,2,167,253,92,4,252,36,231,254,251,2,76,251,202,252,236,255,96,255,218,252,128,57,243,254,143,0,174,250,236,253,236,252,4,250,107,254,85,0,241,254,161,236,20,1,222,255,228,255,190,255,112,0,68,255,186,253,90,253,128,0,168,2,214,3,84,2,122,47,28,215,89,255,132,254,222,2,216,254,26,1,33,255,170,255,170,254,212,252,2,2,131,1,94,254,148,254,64,251,14,0,117,1,101,1,145,42,227,43,54,253,206,0,150,253,161,253,84,2,190,0,214,2,240,1,212,254,95,0,254,3,103,255,212,0,228,253,252,0,25,1,238,0,22,255,28,0,24,0,184,0,255,127,141,253,57,2,67,1,230,1,32,2,164,254,179,253,228,254,238,0,228,0,219,1,83,0,183,225,182,0,233,2,144,1,135,253,49,255,137,0,126,1,90,0,78,0,203,2,192,1,207,1,169,3,219,39,241,208,101,253,142,254,20,250,152,254,94,0,64,3,3,4,245,3,92,0,186,234,66,3,46,1,252,2,162,255,50,254,159,31,33,4,52,1,133,253,52,1,147,252,78,252,152,253,51,0,66,4,217,203,234,1,205,252,78,59,128,254,155,1,222,253,14,255,204,1,189,254,76,0,21,1,46,6,132,3,161,251,89,1,36,5,114,4,228,7,76,6,108,255,44,3,217,4,146,215,233,218,59,252,187,255,175,7,88,255,128,255,18,4,191,1,235,1,123,255,37,236,62,254,92,255,50,0,70,1,13,1,229,254,226,0,216,255,178,254,146,255,60,0,209,255,169,0,206,35,164,4,82,252,242,255,64,8,26,255,122,2,27,253,42,255,176,254,162,253,30,12,59,0,216,0,13,7,104,251,211,0,248,255,52,2,156,0,251,254,44,1,85,2,174,170,66,0,24,255,6,254,154,251,33,4,91,2,168,5,121,254,249,0,27,219,0,216,182,2,167,0,122,251,123,253,127,254,47,255,74,1,7,2,167,254,168,253,192,0,78,0,27,255,208,0,163,220,129,254,150,41,248,254,84,0,39,1,108,255,87,0,12,5,1,1,56,4,204,253,165,246,80,251,28,254,208,255,255,253,129,254,245,255,252,253,52,188,108,251,38,255,124,0,185,254,31,0,72,1,176,255,231,0,58,0,73,252,48,2,11,254,120,254,64,119,200,255,126,1,253,253,206,255,101,255,82,1,0,0,98,254,125,252,95,0,11,0,122,1,162,254,203,1,161,2,76,0,86,0,123,1,222,125,143,0,208,255,169,1,118,254,196,255,164,254,194,1,23,254,220,0,56,0,105,4,131,255,66,1,168,0,240,255,66,1,219,254,38,1,218,255,72,1,141,0,180,2,174,255,96,255,0,128,116,255,249,249,55,4,28,4,100,252,199,253,168,0,10,249,47,3,194,2,218,250,148,242,44,11,170,42,236,0,71,40,114,3,137,248,11,0,102,6,67,255,245,0,166,252,52,43,198,252,184,2,224,0,171,6,230,6,216,1,80,42,247,254,95,255,163,0,222,1,254,254,228,254,170,255,240,1,169,1,185,255,152,215,115,255,169,1,79,250,121,4,193,255,55,253,185,253,185,254,116,2,112,1,238,255,46,249,243,253,174,254,146,255,153,254,92,0,23,255,176,172,204,1,237,254,158,255,198,255,51,0,208,0,56,0,135,251,205,255,14,255,65,0,76,0,214,0,141,0,28,0,170,255,26,0,157,3,193,0,252,38,186,254,78,44,176,0,234,253,209,254,130,0,217,249,189,0,16,254,69,253,125,1,155,1,132,2,229,0,109,255,182,2,50,248,11,2,216,249,92,31,111,215,124,248,150,4,96,2,98,9,63,2,39,249,181,1,208,252,243,4,147,0,168,5,154,253,97,3,52,4,100,255,136,19,228,7,229,7,43,40,52,254,179,246,102,243,105,240,40,19,228,254,105,0,244,254,25,4,203,0,122,253,220,2,90,25,128,255,164,3,10,0,158,252,74,0,192,255,66,3,204,0,159,0,94,255,86,255,146,255,20,143,52,0,0,254,184,255,71,1,103,2,22,2,28,254,131,0,250,254,31,0,105,254,28,1,33,0,110,43,86,255,62,1,48,50,154,251,109,253,244,1,54,1,109,254,22,255,237,0,224,253,208,4,13,255,102,251,59,252,139,255,108,0,232,250,208,45,50,247,207,4,203,251,120,255,136,253,153,255,0,255,148,249,212,254,144,6,105,251,68,252,213,255,182,6,175,0,144,0,19,1,222,252,33,255,92,4,65,1,153,252,106,251,105,251,240,3,255,0,196,121,28,0,147,253,34,255,71,207,13,213,56,253,247,0,226,6,162,1,75,255,90,0,92,0,106,254,77,254,151,255,172,253,214,8,140,255,218,249,182,242,140,26,8,31,205,3,155,245,212,8,109,2,184,228,126,1,161,250,212,245,14,6,83,250,109,4,198,3,147,1,28,1,184,255,220,255,174,0,201,1,166,255,38,0,75,254,36,254,142,254,213,1,255,127,245,254,94,1,182,2,87,255,242,252,62,8,148,253,242,252,99,253,178,230,54,41,34,243,229,1,177,0,41,2,96,243,92,6,31,9,154,252,152,254,168,251,149,8,38,254,7,236,18,13,110,3,54,2,17,241,105,251,101,1,13,41,53,4,254,253,244,3,38,0,59,0,157,2,142,2,93,1,234,251,99,1,192,0,57,0,95,0,93,46,66,253,217,39,204,0,45,0,160,253,68,254,153,3,210,251,196,254,6,5,250,245,234,7,129,255,177,255,70,252,93,0,248,250,216,216,181,2,116,34,146,254,172,255,22,231,146,6,141,253,130,1,254,0,247,1,104,255,176,254,38,0,171,254,117,1,171,255,64,4,85,249,119,0,14,255,242,0,186,254,94,255,109,0,70,0,142,255,193,252,233,254,0,128,62,0,58,0,214,0,136,0,194,0,153,255,193,216,158,253,91,0,202,254,27,47,90,1,112,253,218,3,222,1,108,1,241,6,83,255,105,253,153,255,243,3,139,254,200,0,96,6,214,204,67,14,162,1,222,1,68,0,39,255,169,0,78,0,104,251,89,251,128,249,184,254,152,0,227,251,35,2,15,2,61,215,80,255,123,43,119,255,220,255,38,4,33,0,71,0,38,253,32,8,13,8,140,254,131,253,172,255,232,2,109,0,155,254,38,2,53,1,17,255,122,255,135,0,19,176,79,255,78,253,24,254,220,255,97,254,19,1,64,0,122,1,242,43,222,252,199,253,56,255,219,5,47,51,190,251,81,255,189,0,94,255,17,253,28,4,75,252,158,255,225,4,223,1,232,250,221,12,3,3,106,6,131,254,143,5,210,8,160,4,198,18,58,213,223,240,92,1,209,252,61,235,22,243,21,243,33,9,8,3,131,255,208,255,77,254,101,255,226,255,38,1,116,0,96,0,209,255,254,3,121,254,73,255,252,0,58,3,224,255,37,1,167,250,134,71,110,255,239,0,246,254,34,0,102,255,64,253,14,254,121,255,228,0,205,253,46,255,98,255,254,253,55,255,197,253,171,254,84,254,74,0,104,255,41,1,94,255,124,253,40,255,4,255,14,202,193,2,208,1,105,82,74,0,87,255,24,3,12,0,131,0,64,1,114,254,66,254,44,0,150,254,132,1,234,255,243,255,47,255,181,4,125,36,78,2,85,253,161,254,177,0,174,249,239,1,14,0,193,254,243,2,88,44,249,0,35,252,38,6,102,252,148,254,110,1,148,215,81,1,210,253,132,255,24,47,102,0,34,3,220,253,2,255,252,5,7,0,230,254,53,254,185,252,171,0,163,238,182,249,21,250,219,255,202,3,50,1,143,252,18,255,102,255,198,255,27,0,179,1,166,0,59,2,225,0,180,252,17,217,64,255,150,252,53,254,253,250,105,250,16,6,218,255,82,253,49,255,197,2,206,46,129,254,130,7,164,255,196,255,196,2,124,252,99,3,39,0,190,5,5,2,74,255,56,254,90,0,2,4,64,255,4,39,174,3,48,0,21,3,213,3,74,0,76,253,253,250,215,4,89,6,159,251,226,254,165,251,38,1,172,51,212,3,56,1,23,253,191,45,31,4,28,4,117,252,201,0,176,2,108,1,147,4,96,0,177,253,43,252,10,255,107,3,160,254,165,2,113,3,115,254,90,50,10,0,0,0,156,1,76,0,208,1,19,1,47,253,228,255,59,255,104,0,18,255,140,254,240,254,234,1,146,5,195,3,80,204,90,251,22,3,161,0,191,254,114,4,134,2,103,1,73,255,109,253,127,255,92,1,81,167,248,3,109,255,26,0,176,255,36,1,54,1,1,255,49,1,69,0,169,97,240,255,100,253,210,0,17,0,244,255,45,0,10,253,180,255,224,253,142,252,61,0,26,0,110,249,140,221,154,0,1,210,64,0,216,1,48,254,245,0,222,1,232,249,101,3,144,8,98,0,133,2,161,255,103,219,174,253,133,253,132,212,132,3,70,6,120,252,73,3,10,10,72,250,193,3,32,4,157,2,205,1,235,12,99,255,124,253,121,0,74,253,170,0,116,0,137,1,227,5,23,255,114,253,94,255,108,0,98,0,63,68,91,1,176,211,67,253,228,254,10,255,175,254,145,248,14,0,137,38,197,1,202,211,178,241,69,9,82,4,112,250,83,249,73,245,164,252,0,43,43,6,218,255,155,250,211,1,25,254,230,250,113,1,170,1,88,254,128,0,54,4,61,4,171,2,8,49,24,3,72,255,234,254,186,0,214,7,107,1,54,1,181,255,94,3,121,1,234,1,0,255,224,249,132,255,223,213,80,250,244,253,21,251,5,2,204,248,146,3,1,3,177,3,227,2,227,251,77,253,177,0,96,0,210,251,94,255,61,253,174,253,99,217,103,0,196,1,34,253,138,229,15,253,192,0,88,0,220,254,201,0,236,253,231,0,231,254,77,253,48,251,24,249,15,253,113,1,20,6,117,255,156,2,173,3,8,1,132,40,12,38,208,3,215,9,168,255,173,3,190,1,126,255,83,8,137,253,69,1,29,1,176,0,20,255,134,253,165,255,112,0,255,127,23,255,42,253,156,0,113,3,39,255,15,254,20,255,174,251,27,1,164,0,184,254,139,253,206,148,239,255,176,0,174,254,64,255,26,2,251,252,122,2,76,255,104,3,66,255,238,253,74,2,82,27,244,11,176,254,224,2,12,251,138,251,187,255,177,250,233,251,49,252,170,255,201,48,138,4,3,254,34,254,205,2,254,253,10,254,37,249,56,43,244,29,84,1,230,0,129,255,210,5,193,255,168,2,215,254,125,0,164,6,201,9,3,0,5,248,255,0,11,6,57,2,77,246,221,2,128,252,113,3,172,18,8,6,126,203,48,5,145,7,160,238,128,254,237,2,173,0,182,28,156,0,112,255,52,0,241,253,222,255,253,255,83,255,118,0,240,253,181,255,39,0,42,0,150,252,212,198,218,1,99,254,150,255,141,255,81,254,54,0,210,2,156,0,44,254,113,1,149,0,188,255,233,252,38,5,102,8,69,0,198,1,88,74,3,0,111,0,216,255,93,1,88,0,129,1,202,255,117,254,32,255,249,253,0,0,37,255,179,0,3,255,141,211,253,42,65,7,130,255,8,255,48,1,152,253,95,1,68,1,244,1,214,5,146,250,45,9,23,251,166,251,43,255,220,31,238,247,18,38,251,2,176,252,93,1,249,255,211,2,58,252,213,1,91,0,4,255,56,5,67,2,24,7,92,5,83,252,108,1,20,1,223,255,7,0,87,254,79,254,235,255,34,2,97,253,217,133,98,252,101,0,147,0,46,1,216,253,224,0,56,2,174,246,7,2,54,254,115,51,72,250,137,4,127,2,246,255,147,252,75,1,44,13,184,255,38,20,62,253,138,3,108,10,240,3,84,245,192,12,105,0,118,2,161,2,100,248,60,255,182,204,190,6,225,2,221,18,93,0,142,2,127,8,18,15,251,255,245,0,41,254,113,1,59,21,100,1,122,205,61,0,192,7,207,3,194,2,106,246,126,253,163,255,244,252,69,254,49,250,52,254,88,4,129,1,53,1,228,215,197,0,100,249,178,248,50,0,114,248,4,21,87,251,7,3,19,254,32,252,211,253,136,11,152,1,8,18,195,250,22,42,185,20,86,3,215,11,67,0,105,2,132,9,232,247,67,250,36,3,190,253,243,0,8,1,190,35,200,0,1,42,162,254,182,0,204,255,106,254,252,1,7,253,95,255,138,251,25,0,228,1,127,0,126,0,221,1,171,254,110,0,115,1,255,127,66,4,166,2,175,0,146,0,252,3,127,252,110,3,119,255,5,254,234,253,146,2,166,2,249,1,15,253,49,255,135,1,60,0,17,165,252,252,213,250,214,249,253,255,196,0,19,253,220,0,30,254,239,252,200,1,38,0,10,4,189,253,198,255,253,249,165,1,22,253,238,0,251,5,42,83,74,2,71,254,236,254,232,5,41,2,129,250,236,254,60,0,212,251,43,1,138,2,231,255,46,49,10,8,157,3,217,254,48,249,32,20,71,19,93,254,16,1,129,254,103,253,62,255,1,255,62,2,245,254,29,2,7,4,230,254,120,253,110,2,72,250,228,255,243,254,235,253,176,255,36,254,26,1,176,254,125,0,104,0,208,1,12,221,81,3,171,0,238,5,216,254,51,0,229,255,25,12,17,236,100,254,18,254,62,255,55,253,3,251,102,0,204,6,67,254,104,13,156,4,4,25,100,213,54,252,31,0,142,0,14,255,177,255,178,255,180,255,124,0,7,4,83,0,201,255,242,5,155,253,0,128,118,254,26,5,31,1,189,2,139,237,195,251,159,1,134,255,230,253,93,253,82,0,116,0,40,253,157,255,244,1,147,2,183,254,36,1,150,255,27,36,172,254,99,209,14,254,85,1,199,252,111,254,110,254,142,0,243,255,203,254,46,253,141,0,0,0,87,253,238,1,159,2,70,251,186,5,201,250,223,45,232,254,80,6,39,211,52,0,61,1,134,3,115,253,57,252,18,254,94,255,83,253,74,254,244,2,81,0,49,255,65,2,204,226,159,254,150,3,225,255,149,255,181,0,11,2,210,255,16,253,117,1,116,252,240,248,108,252,120,2,228,5,221,255,225,228,64,0,16,51,113,253,163,0,197,4,137,249,248,245,66,254,111,254,214,1,146,253,80,252,160,14,54,254,203,0,125,0,238,0,76,20,21,0,161,47,71,4,67,4,237,252,123,251,44,252,126,251,27,30,227,255,106,0,202,4,184,2,50,252,133,254,231,253,56,0,95,0,35,254,240,253,19,212,10,252,140,0,124,1,89,0,28,2,84,0,149,253,190,254,196,253,16,255,230,255,215,2,54,1,43,0,234,252,225,255,2,161,110,0,106,2,44,0,148,255,89,0,65,255,223,255,55,255,22,254,43,0,120,255,86,5,254,255,162,0,192,252,213,1,116,255,234,254,88,2,97,194,93,249,184,0,33,7,216,2,245,248,148,252,152,0,60,0,211,252,247,11,95,252,204,3,230,254,206,2,234,32,136,252,103,5,104,253,59,2,190,3,214,3,236,0,220,253,66,0,106,7,238,254,219,41,99,249,79,0,26,251,40,1,97,2,170,2,206,251,16,1,157,0,228,181,121,1,244,255,182,1,24,2,96,253,36,1,207,2,48,254,82,4,216,254,212,252,6,0,178,254,67,0,166,2,126,1,166,2,45,1,107,169,184,0,80,0,97,253,170,255,139,0,214,254,160,1,158,253,33,4,15,0,26,255,120,1,0,253,131,2,58,0,27,0,178,0,26,253,60,0,12,254,229,1,45,178,8,252,205,2,102,4,31,1,123,8,124,254,173,5,235,255,244,254,237,249,249,254,201,2,173,6,177,251,53,214,252,6,248,255,11,254,132,252,212,44,42,248,210,1,134,31,226,254,163,0,35,0,238,1,76,0,148,5,55,247,100,0,250,249,63,1,42,255,67,253,146,39,218,254,70,209,112,253,227,0,0,254,10,252,213,0,168,253,48,253,63,0,76,255,6,5,39,4,57,218,224,251,245,4,204,5,20,0,22,3,29,0,78,217,139,254,96,2,105,1,109,253,43,0,246,251,160,255,37,255,191,255,136,1,97,179,48,254,212,0,52,3,74,255,29,255,207,1,45,1,130,2,37,255,130,1,110,251,108,0,49,234,166,1,5,254,18,2,222,251,125,255,20,0,105,199,101,0,242,255,97,254,32,0,147,251,107,252,176,3,192,252,68,2,205,9,65,252,214,1,160,4,176,1,42,251,193,0,186,203,25,9,201,7,11,4,80,0,67,12,215,253,147,6], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+409600);
/* memory initializer */ allocate([134,1,200,5,130,2,52,2,91,212,166,1,40,252,209,253,82,253,168,0,247,252,214,252,2,251,85,254,160,255,155,6,244,113,77,254,206,255,56,252,221,0,173,2,52,0,139,254,13,2,205,253,94,1,16,2,49,1,193,2,57,1,100,2,2,255,36,255,154,249,100,255,24,0,109,0,131,252,71,253,245,0,19,10,155,2,114,255,27,48,74,253,215,14,5,0,74,254,39,254,86,254,59,0,251,234,200,255,200,0,232,254,236,254,96,0,179,1,217,2,80,1,123,0,54,253,140,254,191,206,235,208,18,255,223,0,14,255,230,0,151,2,123,253,98,0,3,2,3,0,212,2,254,1,208,255,66,4,83,255,96,236,24,2,123,2,113,255,190,2,172,0,60,255,164,0,190,0,104,255,76,255,238,0,114,255,183,254,191,0,216,254,96,254,255,45,16,254,161,255,136,1,226,3,184,253,99,252,61,252,30,1,54,254,32,12,58,248,200,3,106,250,230,3,105,254,69,111,180,1,42,0,122,1,46,255,148,0,107,255,236,253,94,0,140,253,186,0,70,255,238,254,250,0,196,254,164,191,78,211,207,254,60,255,1,253,137,247,255,255,122,1,104,247,22,0,101,9,176,3,6,249,218,252,157,2,184,3,195,40,64,245,167,249,36,4,230,207,3,5,234,0,155,246,115,2,30,3,222,251,55,1,22,245,101,245,73,0,42,255,45,3,67,245,236,41,67,254,141,208,53,246,76,248,116,6,128,248,215,0,42,1,82,4,58,3,235,226,69,0,113,249,93,253,225,4,164,5,171,251,208,255,84,250,192,246,218,11,20,254,12,51,55,1,138,242,70,1,110,250,80,9,158,247,100,11,253,34,60,255,164,8,191,1,239,6,47,10,70,209,234,254,239,16,49,249,135,0,212,0,215,255,164,255,164,0,245,255,8,254,60,3,249,253,190,252,251,0,127,7,250,2,85,97,76,255,124,255,182,254,138,0,225,0,14,4,3,0,138,125,124,254,208,0,130,253,198,250,91,255,200,0,26,255,225,0,247,252,34,247,6,32,71,2,106,15,2,250,130,6,248,251,120,44,202,0,30,0,198,10,7,254,1,245,241,4,64,0,239,255,152,254,124,2,134,0,246,1,3,1,104,3,12,146,234,251,164,254,170,255,29,253,55,0,192,1,168,0,112,253,70,4,206,251,200,17,190,252,248,8,52,9,196,253,131,248,227,42,55,12,204,255,15,217,241,253,202,7,166,249,17,4,238,12,241,246,184,8,76,211,160,246,4,249,26,251,145,20,126,12,176,27,170,17,12,5,65,255,242,193,227,10,22,0,182,249,184,0,124,1,9,2,80,1,98,255,109,3,212,1,115,25,12,253,148,234,100,0,48,254,28,36,90,245,148,249,75,245,14,235,157,249,126,3,199,248,134,39,64,243,136,238,231,4,13,242,75,254,230,251,225,5,86,212,63,255,7,211,232,255,207,2,212,0,49,248,43,253,246,1,116,251,220,251,150,253,165,255,30,253,228,2,50,247,229,237,140,10,95,0,171,252,69,4,156,210,56,252,20,37,231,255,104,253,111,1,81,4,125,21,144,255,92,29,46,40,53,3,28,254,204,0,145,5,93,242,46,251,112,239,223,14,61,11,32,7,167,1,210,1,84,254,179,252,170,255,220,51,244,32,78,253,80,253,62,2,198,244,216,253,188,17,158,3,189,234,117,2,117,254,42,8,196,187,79,1,115,9,251,4,90,241,203,249,214,1,57,249,74,1,228,9,70,4,182,231,140,252,20,255,50,218,39,217,65,254,30,2,40,253,126,248,108,0,111,247,78,252,198,12,73,8,64,10,242,3,10,214,154,255,253,10,242,204,243,5,4,250,245,250,164,1,49,248,6,1,86,251,126,239,86,250,237,254,83,0,144,4,54,6,19,250,86,254,112,250,152,0,164,2,199,44,56,3,212,247,174,251,18,211,233,246,234,254,37,10,245,255,25,3,138,255,137,1,68,2,13,254,25,253,179,255,85,254,104,254,76,253,245,141,9,255,34,248,102,252,97,0,69,2,93,21,117,250,70,253,210,5,26,241,254,244,8,202,168,2,11,14,8,6,62,9,54,244,175,9,67,1,90,1,252,254,81,1,170,10,182,47,162,251,219,211,44,244,212,0,215,255,228,6,188,253,41,2,78,21,248,255,146,254,78,251,133,3,228,252,98,223,28,17,84,250,212,254,128,4,242,11,108,242,229,255,246,50,34,0,82,211,215,250,8,250,181,51,114,0,210,9,208,3,197,253,88,251,254,247,157,249,60,252,160,1,233,255,197,251,247,255,255,127,220,253,44,2,63,251,200,255,69,1,24,4,111,255,202,0,240,5,44,0,146,1,144,1,157,253,219,33,197,251,44,4,200,4,1,209,14,9,171,251,242,4,26,5,65,18,29,1,29,234,19,6,156,255,221,251,147,1,43,255,88,253,120,252,179,44,69,2,128,47,130,253,53,1,191,255,165,3,24,247,166,7,82,10,16,7,9,31,216,247,82,3,84,254,17,3,35,252,210,4,123,250,233,2,252,213,151,7,72,255,180,12,160,255,164,3,104,253,166,51,62,44,162,250,185,254,109,7,45,4,252,249,104,0,117,255,120,252,106,0,128,6,157,3,46,0,97,1,189,252,214,253,82,6,68,252,75,254,41,253,181,242,14,4,200,3,180,1,46,0,223,238,84,1,249,189,14,254,47,0,214,253,113,254,142,246,165,254,102,1,240,90,234,0,84,255,174,254,34,4,132,247,255,255,174,6,192,255,185,253,80,247,244,252,131,253,172,13,108,0,21,4,60,3,40,253,250,36,73,246,27,206,132,7,122,251,208,0,49,0,136,0,23,47,42,0,155,250,137,254,242,210,7,255,66,6,228,3,204,0,58,253,153,18,1,254,111,194,166,0,96,251,64,255,50,0,151,255,122,3,162,218,14,8,0,250,133,0,71,255,125,253,84,255,130,252,157,254,240,255,141,250,30,2,112,8,31,254,176,251,231,252,5,2,26,176,186,2,75,255,121,255,78,254,141,6,75,255,97,254,30,253,218,249,128,6,22,201,85,2,190,207,52,254,199,254,188,6,82,253,85,0,118,251,120,253,97,3,165,0,31,255,101,248,2,11,246,252,86,240,146,1,174,2,162,43,180,254,96,40,11,253,186,18,156,8,35,254,220,254,146,254,220,32,84,246,238,1,254,1,18,41,1,3,130,2,71,254,55,4,42,27,150,16,32,247,222,254,32,255,32,5,142,1,0,6,76,253,74,1,157,0,78,252,156,255,218,248,214,0,204,155,102,5,212,248,72,254,110,0,6,254,74,254,190,246,126,0,50,2,69,242,246,3,78,33,151,249,67,246,59,17,6,220,62,8,113,2,114,0,67,1,146,9,103,9,170,2,207,7,48,219,176,9,69,0,213,247,187,209,156,241,83,254,170,249,105,252,250,253,70,0,170,5,61,242,6,20,74,22,85,250,73,10,52,3,52,255,74,44,178,224,241,2,153,255,34,1,101,252,128,5,42,1,86,248,137,252,219,37,170,250,216,212,201,255,33,255,240,251,93,255,132,0,164,2,8,253,126,19,202,254,186,219,133,246,106,56,94,254,222,252,153,254,189,254,61,11,46,255,100,250,38,6,74,251,9,1,101,255,31,255,0,128,91,1,222,0,115,251,200,0,156,3,111,4,181,252,190,255,169,254,178,254,143,255,209,0,14,0,53,255,190,4,128,252,142,3,40,250,39,7,103,225,183,252,43,215,69,6,190,222,35,254,208,255,15,255,198,255,0,128,213,0,108,0,194,1,131,4,226,255,89,0,240,0,0,253,52,5,34,1,159,250,183,3,74,2,21,221,18,5,240,1,193,2,131,249,6,7,142,248,71,247,76,249,38,252,100,247,131,251,126,10,130,33,255,127,133,2,107,253,121,255,2,3,80,254,218,253,127,254,240,254,113,2,210,4,39,253,19,0,217,6,228,254,150,255,113,253,238,2,70,254,103,90,184,254,248,253,6,254,22,3,232,251,38,253,41,254,74,254,227,1,138,254,171,3,30,255,115,254,175,252,234,208,252,252,216,255,0,210,232,0,228,253,63,246,89,253,81,1,77,5,202,1,171,254,138,226,233,3,236,1,96,254,40,250,250,220,86,38,40,249,94,253,222,9,224,253,172,244,218,250,214,249,18,255,75,0,173,43,214,6,146,243,52,2,198,253,16,2,236,3,146,0,120,4,6,29,158,0,52,37,220,255,172,254,71,254,84,2,133,249,140,5,82,253,220,255,172,253,167,8,241,250,246,178,155,247,234,251,221,246,114,251,241,11,142,254,212,253,223,255,190,254,4,1,233,255,150,255,189,254,147,0,199,255,179,0,202,1,172,2,253,250,227,4,207,4,140,183,255,253,32,254,73,253,81,2,0,12,168,7,66,1,66,253,237,251,224,253,117,23,98,5,100,0,31,255,176,252,242,250,238,242,60,3,206,245,62,244,151,37,207,250,164,7,182,251,110,241,113,4,125,48,20,251,153,9,164,213,168,26,63,239,115,253,210,254,193,238,138,2,108,249,241,23,142,254,116,253,83,243,39,254,106,255,54,244,72,7,22,251,160,3,181,246,115,56,137,255,234,8,8,255,67,12,102,25,222,16,166,8,165,249,126,0,90,254,70,1,146,253,210,254,252,125,244,254,200,1,252,254,252,254,56,252,135,1,15,254,152,0,228,6,172,214,143,254,21,1,70,0,175,204,166,251,169,251,208,1,218,8,104,244,216,2,64,251,190,6,20,4,88,1,204,191,22,6,106,12,217,253,92,2,186,1,133,252,98,37,60,6,227,253,122,247,218,2,118,252,242,0,167,3,140,255,203,255,220,158,224,253,241,252,97,0,112,252,78,251,146,253,109,255,41,255,150,254,240,255,246,253,98,249,154,254,44,253,68,10,183,1,70,185,226,249,232,11,37,16,42,251,95,243,150,251,188,244,54,245,7,4,243,251,63,0,85,247,205,41,18,250,174,215,145,5,24,3,228,248,124,1,247,252,55,244,251,5,228,251,93,242,61,4,84,254,3,253,143,255,42,0,247,254,109,1,99,0,165,252,35,0,98,2,44,0,17,254,6,1,153,6,34,8,101,84,156,1,51,253,117,251,43,243,58,236,209,249,87,2,235,254,194,255,103,2,126,23,11,249,209,1,224,253,222,200,13,44,236,255,184,2,151,2,132,4,16,255,119,2,14,245,77,1,16,246,164,249,7,3,64,252,215,253,240,1,134,254,14,2,91,254,86,254,34,1,43,2,147,1,134,1,30,132,25,0,193,1,142,2,178,254,219,250,165,0,240,1,18,6,168,255,247,252,114,2,25,250,196,220,67,249,161,49,226,252,40,251,195,0,140,7,191,252,85,252,43,0,182,0,243,9,15,19,18,36,114,1,10,8,179,225,32,2,82,4,108,253,34,2,255,38,225,0,124,0,184,3,151,247,60,249,200,10,10,251,80,255,6,13,177,229,242,253,235,40,141,253,155,30,41,247,219,1,219,2,140,3,72,32,69,6,64,255,162,19,110,9,103,20,83,2,69,4,41,9,228,252,215,33,4,4,252,31,71,255,30,250,28,244,156,255,230,248,31,231,86,255,192,6,223,219,118,3,193,247,163,254,134,251,79,8,102,45,149,224,64,11,167,8,157,6,1,247,162,6,97,4,9,242,97,252,52,253,148,7,210,9,104,210,83,6,148,3,249,255,183,253,252,1,220,250,52,252,10,3,46,38,178,247,64,9,200,255,60,26,145,4,184,241,206,250,58,37,130,208,164,4,94,211,159,254,177,3,107,248,214,6,194,3,147,251,1,7,14,9,175,245,85,4,165,3,36,3,249,1,60,0,150,249,66,247,232,246,234,249,224,249,229,255,184,3,4,0,96,5,162,252,28,184,220,248,11,16,58,254,52,0,78,251,126,4,174,2,98,248,15,254,125,213,144,1,90,254,198,6,202,255,157,43,19,243,2,25,147,252,1,178,112,254,106,6,25,5,128,246,213,243,119,1,58,15,20,7,71,235,78,252,181,6,11,253,250,12,126,0,235,2,44,7,229,38,112,7,146,2,243,50,13,249,163,2,204,2,59,254,158,2,220,249,210,0,3,250,123,255,38,1,34,2,236,161,244,251,27,254,139,255,72,255,144,253,17,1,123,252,98,3,97,2,161,251,28,0,250,0,13,0,70,0,154,4,114,3,136,253,136,171,197,250,158,3,234,248,1,251,76,7,75,255,127,1,89,253,210,251,227,19,124,4,10,4,96,8,37,245,30,241,184,17,177,6,235,3,10,52,50,11,111,243,204,9,43,17,224,1,14,0,167,0,251,2,222,255,10,4,194,250,187,250,156,255,31,255,208,1,110,252,133,250,197,248,215,92,2,3,55,254,255,254,208,251,177,4,71,2,197,255,67,10,189,5,249,255,134,210,24,13,21,252,250,255,68,45,201,254,125,246,124,247,208,246,160,7,156,21,153,7,113,28,248,1,106,46,165,253,45,0,42,0,140,250,165,251,239,251,219,251,54,2,83,245,3,253,175,2,118,0,106,251,68,176,12,255,38,252,105,255,72,11,78,4,233,250,121,255,17,2,162,4,164,51,73,255,138,3,143,239,153,238,199,8,246,0,182,230,234,10,170,5,161,230,229,248,86,2,74,254,244,0,216,251,95,253,96,253,229,249,31,2,26,247,241,243,213,252,74,7,80,0,213,181,86,253,57,2,217,253,2,2,220,26,158,29,71,3,65,240,55,3,38,9,236,250,156,4,190,2,72,216,91,248,229,1,138,254,105,255,198,212,51,254,232,205,59,251,1,5,50,253,220,7,74,1,223,254,25,254,49,255,46,253,138,1,156,0,25,248,2,213,139,254,252,255,18,255,85,41,223,3,44,251,210,252,41,2,15,5,35,247,223,10,75,248,169,2,31,38,90,14,112,249,170,208,196,250,188,246,224,254,95,8,184,254,41,3,56,1,246,7,224,2,246,255,140,3,201,211,74,0,218,24,158,251,10,6,72,255,94,6,197,248,161,247,24,4,154,34,50,254,198,230,252,249,43,3,130,0,42,242,72,215,137,36,132,1,144,4,251,248,4,7,201,239,231,246,1,0,240,254,78,3,126,253,248,0,136,251,121,217,108,249,66,255,187,29,205,239,76,253,234,20,197,246,97,2,194,236,94,12,46,8,89,3,143,254,118,0,213,2,125,252,167,253,250,255,44,2,228,128,182,3,34,254,245,2,136,0,208,253,14,253,50,2,64,254,223,0,64,253,104,2,109,1,82,88,167,4,16,251,162,255,159,3,218,254,10,251,240,255,40,246,22,248,164,1,35,230,8,254,194,37,196,1,133,254,160,248,24,2,137,4,51,244,97,2,230,236,25,255,86,15,81,252,255,127,153,253,44,1,102,3,26,253,173,1,214,255,155,0,36,4,124,252,165,254,34,0,235,1,215,241,7,250,191,39,178,0,254,224,106,254,92,6,150,254,84,227,79,254,233,1,56,2,162,2,24,2,186,244,26,232,240,255,237,253,182,0,218,5,158,239,206,254,63,0,107,250,85,4,119,2,110,215,240,255,206,232,204,255,142,41,231,252,35,0,150,252,97,6,4,255,197,2,226,254,244,252,20,67,224,255,144,3,137,0,108,249,221,10,251,233,82,1,209,42,121,5,176,0,98,7,51,2,141,254,66,2,21,255,142,252,152,253,177,253,96,253,203,252,162,47,149,3,10,3,85,254,102,1,125,250,240,7,164,250,99,7,8,249,38,7,240,248,48,254,149,54,224,7,158,33,110,252,95,227,195,248,189,245,171,8,68,10,113,8,137,8,110,9,153,34,239,254,248,3,205,8,46,4,139,3,111,1,82,254,62,2,15,4,93,0,170,0,255,0,245,254,38,2,100,253,31,1,35,7,121,77,244,0,109,241,4,0,117,83,129,255,100,1,131,2,224,7,218,12,218,4,46,0,34,253,6,247,196,254,38,230,216,254,71,250,145,2,85,250,213,1,212,0,7,11,13,245,170,209,163,3,44,0,148,2,40,6,56,7,223,214,253,10,117,251,252,254,61,255,192,63,137,242,250,254,180,255,73,254,97,242,12,5,2,13,152,253,197,5,108,7,139,34,81,0,178,252,189,26,161,255,144,255,25,255,129,0,70,27,165,0,213,243,152,9,240,7,169,47,187,10,155,6,40,253,113,248,17,255,200,3,218,60,44,247,235,248,184,1,140,8,251,240,254,4,120,255,148,250,86,225,50,254,105,11,52,249,120,255,164,0,103,0,50,255,255,127,53,254,225,4,224,2,178,253,227,252,116,2,100,2,71,1,140,1,40,2,128,255,180,255,254,254,211,253,173,1,170,0,20,2,165,254,169,0,175,253,159,110,135,253,197,250,27,252,254,254,68,1,116,2,182,12,162,251,198,34,193,255,154,18,252,244,125,9,52,3,210,255,10,235,111,247,211,220,232,250,171,253,97,216,43,2,72,244,38,1,215,249,153,252,116,255,214,2,116,14,78,247,135,3,3,255,90,40,126,244,144,2,213,2,100,253,104,252,117,6,32,5,87,6,130,251,62,209,109,8,180,17,172,254,56,222,152,253,107,250,44,252,226,255,135,2,38,254,186,1,234,19,188,0,22,251,20,224,81,213,145,239,144,255,197,9,87,243,99,248,159,0,243,253,66,4,164,1,178,40,135,209,48,4,178,255,252,251,39,13,169,245,93,13,229,7,54,9,51,252,16,1,7,109,216,1,110,254,117,5,97,252,248,251,6,251,80,3,221,0,71,245,58,253,76,253,103,254,130,7,142,0,82,2,29,4,170,211,233,252,183,14,33,6,29,2,145,46,134,0,112,1,76,252,127,245,128,3,87,251,166,4,66,33,156,5,249,3,87,2,226,242,162,15,136,50,93,253,20,4,70,251,40,1,171,251,200,7,2,5,6,3,210,204,160,253,119,212,134,0,22,1,176,3,136,252,94,1,218,249,189,0,18,246,148,13,54,244,40,13,168,219,209,248,21,2,254,255,33,4,174,2,213,209,134,251,51,252,58,6,198,13,182,244,8,250,161,13,37,254,253,254,118,218,37,254,40,252,25,242,26,253,152,1,126,255,13,247,131,3,145,47,114,248,94,255,90,243,74,6,228,21,211,5,240,247,41,5,226,244,65,244,149,248,128,252,44,2,177,7,79,247,83,72,60,16,53,5,161,13,136,247,105,7,96,250,22,250,243,201,249,3,189,18,197,1,203,247,90,229,155,3,185,0,242,2,55,255,201,239,126,0,231,252,75,254,170,9,190,16,251,230,167,15,148,249,11,253,206,204,156,9,174,248,181,248,181,251,230,235,129,11,114,8,181,238,156,6,251,2,220,6,203,252,66,0,164,254,209,7,190,2,22,4,171,250,198,253,49,4,143,127,247,255,194,1,7,253,140,3,56,255,196,253,230,250,29,10,102,9,134,7,236,6,34,43,59,248,74,15,88,251,25,7,66,210,169,11,130,244,68,61,127,7,101,253,13,251,92,20,188,1,96,3,252,240,182,1,178,246,206,3,215,3,137,252,202,252,185,0,245,0,136,243,6,4,161,5,8,146,200,245,132,254,44,1,198,7,162,255,25,252,29,1,41,2,59,8,192,3,165,252,233,3,160,249,160,8,234,250,51,5,140,240,97,41,117,248,122,238,160,36,69,230,49,254,235,241,156,9,26,5,2,0,195,7,107,6,216,253,47,5,100,4,187,253,67,5,138,2,182,140,22,1,38,4,179,5,183,3,112,9,140,1,174,253,162,3,178,1,236,12,0,245,90,21,223,18,203,244,188,255,130,252,58,0,20,205,210,0,108,248,36,246,115,4,252,7,224,255,201,3,139,8,4,2,69,2,249,31,32,8,176,0,60,253,249,5,108,4,93,253,152,250,59,213,150,4,131,235,68,2,66,29,186,12,218,16,146,10,148,202,57,249,145,7,65,2,148,255,116,10,100,2,58,252,58,252,183,12,121,5,163,5,198,248,4,255,54,36,173,19,44,250,91,248,170,247,174,4,142,13,242,40,44,254,97,253,137,249,69,252,176,12,32,13,192,1,194,248,199,157,45,245,10,243,49,2,96,253,255,6,146,8,170,253,137,6,92,254,35,2,122,0,96,255,84,255,150,6,115,254,163,4,11,0,145,252,198,255,67,1,180,0,228,245,165,247,254,248,148,244,231,3,167,150,0,251,135,250,254,252,15,24,159,238,178,239,150,20,51,237,43,16,25,248,134,10,68,11,90,13,196,232,46,12,104,251,83,18,118,33,0,128,87,253,215,253,40,255,40,255,93,252,5,254,67,2,92,252,28,253,93,1,81,0,72,8,58,251,52,2,216,249,217,4,159,0,19,10,164,12,5,75,24,253,65,249,245,248,223,4,193,253,251,254,5,1,28,2,1,255,196,255,108,250,152,200,182,235,95,3,229,3,19,4,196,252,210,1,247,206,58,8,56,0,202,253,118,4,145,1,80,5,18,9,117,2,169,3,138,11,154,216,244,255,250,9,128,233,11,2,176,196,124,2,156,0,165,0,178,245,110,4,146,2,46,17,151,250,124,248,155,4,150,12,116,252,127,251,162,70,243,3,156,7,17,252,96,1,84,255,210,230,234,255,28,255,248,254,73,0,76,0,181,8,187,250,215,23,188,210,64,2,46,13,176,249,224,30,74,12,216,3,32,4,166,249,41,12,166,241,203,0,60,254,86,252,26,8,105,9,52,251,6,224,50,245,90,43,62,6,46,222,33,253,44,2,74,6,5,227,109,235,134,4,25,11,145,17,127,29,238,247,81,4,249,2,245,9,28,249,54,11,49,15,58,250,120,7,200,9,119,250,195,3,246,198,67,2,28,0,119,244,53,6,122,15,164,250,24,243,54,2,127,10,228,37,96,246,202,204,189,11,252,252,65,241,118,255,108,239,167,19,219,9,189,244,70,2,66,254,238,254,239,12,99,255,240,252,76,252,220,254,13,12,243,252,186,3,171,247,219,229,85,54,68,247,160,1,227,245,134,243,156,2,60,248,70,247,61,9,10,4,177,4,156,255,152,6,116,1,156,0,2,255,163,3,64,2,184,237,54,2,225,248,38,1,109,6,30,108,183,250,50,251,208,6,58,2,143,6,96,2,221,255,18,228,225,238,40,209,162,244,208,247,0,2,46,7,57,12,102,254,254,246,217,253,192,240,44,16,18,206,49,249,150,255,162,239,78,234,175,50,195,253,52,242,46,240,15,0,27,5,62,0,107,6,60,248,142,22,16,8,126,18,241,3,246,7,22,245,112,245,227,8,233,254,204,249,114,252,83,122,225,4,150,249,78,0,164,0,252,254,146,252,186,2,165,4,159,0,7,232,54,248,7,3,156,13,99,6,97,4,39,17,5,233,220,211,138,14,90,254,124,247,122,243,147,243,46,250,35,1,46,5,143,1,160,7,43,223,192,8,175,0,213,13,162,16,238,5,243,252,81,4,242,1,164,254,3,3,46,62,120,0,123,1,12,248,117,241,196,42,221,248,148,12,40,0,210,0,218,254,211,252,211,246,61,253,199,3,185,3,65,10,210,202,17,250,238,36,86,45,121,252,49,3,93,24,82,221,96,255,24,249,188,1,4,245,95,249,14,252,60,252,54,7,181,11,73,10,124,248,245,1,72,250,98,9,38,252,137,251,15,2,163,4,95,252,187,81,205,253,17,3,26,254,84,252,89,6,228,252,71,253,92,1,84,254,171,5,63,4,52,247,79,246,171,3,122,3,52,246,179,250,180,248,115,5,14,231,30,170,14,10,128,254,188,254,72,30,180,11,127,253,33,225,143,233,126,239,174,239,214,238,91,36,66,15,29,255,16,254,204,17,75,4,186,252,14,246,166,4,209,38,49,43,6,15,100,255,177,1,199,244,23,249,36,0,116,12,138,17,17,17,106,18,183,237,12,245,11,250,77,252,56,236,172,239,188,250,132,250,183,251,174,240,192,251,68,254,188,202,245,249,149,6,167,249,210,222,188,9,184,255,165,38,166,9,193,2,105,0,233,21,229,234,78,3,90,0,80,253,160,4,142,24,3,255,182,249,20,13,222,247,134,34,107,246,221,250,45,251,49,253,1,238,166,247,110,234,30,215,108,7,5,6,128,245,217,2,112,1,115,221,2,5,182,1,28,246,232,246,225,18,255,231,197,15,0,14,29,31,41,250,87,27,83,236,172,250,183,27,157,16,151,10,112,223,106,15,189,250,192,0,204,252,184,254,128,251,18,6,101,3,189,19,235,37,0,233,58,239,238,240,240,242,152,32,124,253,214,6,252,248,107,255,134,241,25,198,144,2,49,250,94,246,128,2,18,247,170,244,90,11,44,0,211,0,176,254,24,117,214,254,44,8,80,253,65,7,15,7,87,249,139,12,169,1,234,251,128,0,167,4,82,248,42,253,32,244,208,241,188,4,170,11,146,20,62,4,40,14,252,11,166,1,221,3,159,95,207,14,75,247,127,241,181,246,166,250,249,248,182,10,69,243,147,236,142,253,239,8,23,22,151,2,106,252,210,51,82,30,149,251,186,9,205,243,53,11,178,252,244,244,119,0,204,56,236,17,32,245,127,241,13,246,114,14,117,12,44,13,196,234,88,3,30,17,28,16,78,13,176,254,113,252,119,255,172,16,172,238,30,6,145,4,52,244,156,54,94,255,198,227,10,246,78,252,152,246,224,251,181,253,239,254,92,252,37,255,171,224,194,251,229,245,12,15,211,4,234,255,222,0,180,251,198,249,137,0,63,248,241,39,134,19,164,254,62,254,251,25,87,247,231,225,204,9,77,39,96,238,42,247,12,24,146,11,150,0,104,246,65,4,97,252,159,253,198,243,110,249,65,251,221,219,126,255,64,241,203,254,208,201,236,254,246,228,174,255,100,10,25,251,94,230,80,10,86,10,166,1,172,255,124,232,225,210,82,249,122,242,150,245,222,48,73,12,38,255,140,11,191,1,30,0,220,8,150,246,136,250,148,2,175,1,252,11,2,1,210,244,79,15,133,10,24,253,254,11,125,247,88,251,92,252,209,247,233,254,253,7,243,223,159,59,193,238,68,8,207,15,68,40,38,12,88,5,245,249,167,42,220,3,175,255,117,252,64,249,228,251,45,242,95,237,240,245,242,251,39,36,152,0,175,1,151,9,248,249,88,7,200,254,164,10,232,203,155,239,81,251,197,2,73,253,105,249,186,1,252,245,166,249,160,248,78,7,211,13,150,244,78,242,46,225,146,234,152,249,130,8,125,8,128,243,238,237,92,4,105,51,155,235,172,252,233,251,0,243,121,240,167,238,54,11,78,250,32,22,228,255,13,15,17,7,161,10,146,2,98,196,27,14,151,12,83,2,44,0,49,235,74,246,242,248,94,2,86,246,44,251,215,3,205,6,58,223,156,7,83,7,242,248,106,231,210,252,21,253,161,8,204,250,10,8,210,250,176,22,89,4,243,213,184,253,198,15,132,5,228,242,24,0,230,205,30,239,17,247,215,213,192,11,9,229,7,251,54,6,160,253,254,253,203,254,112,255,24,248,30,7,23,17,98,4,137,253,180,255,173,253,192,0,197,211,232,31,196,39,122,253,174,9,164,17,71,4,94,0,6,0,227,4,110,253,60,10,114,2,6,12,215,2,89,30,198,3,247,241,178,228,202,246,254,3,8,5,173,10,253,254,221,254,178,9,41,1,12,251,98,40,227,2,186,248,183,205,131,246,3,26,49,17,54,247,148,6,228,5,244,6,199,251,246,255,132,232,127,3,187,246,17,251,125,0,168,5,136,18,20,6,157,227,50,9,152,211,131,4,237,225,112,250,110,252,177,253,168,9,26,2,151,5,185,3,5,0,6,244,217,251,3,0,150,1,211,3,154,3,100,253,97,6,2,0,137,2,117,255,196,3,92,3,137,182,152,7,135,8,178,250,115,5,113,251,249,20,59,242,223,2,118,245,60,41,143,251,117,240,103,5,51,248,107,23,65,25,6,9,245,6,201,254,48,13,31,28,71,245,136,249,186,233,108,12,201,11,215,233,56,253,58,221,10,8,198,253,170,0,228,8,29,15,140,219,227,224,106,4,63,8,6,22,29,250,128,11,38,6,105,252,77,250,54,252,85,43,32,2,120,244,110,255,180,237,209,254,240,253,81,251,134,252,96,245,127,249,56,213,117,1,121,6,168,7,150,250,43,1,252,238,81,238,244,34,210,28,44,6,21,5,87,232,226,29,25,227,38,18,24,249,196,10,249,254,226,254,178,254,89,5,238,252,80,241,56,3,44,203,21,236,99,249,165,254,227,248,200,7,134,13,141,5,36,19,50,254,237,203,175,249,210,246,243,15,239,221,8,233,36,19,96,11,235,0,129,40,196,250,8,3,218,245,8,56,35,241,200,253,52,241,7,14,118,254,203,251,68,15,192,23,161,7,82,250,11,252,251,1,113,39,68,13,202,237,5,253,202,9,206,5,16,12,68,2,170,255,93,4,70,6,130,242,226,213,6,19,26,24,180,15,213,233,192,26,183,1,195,221,37,15,106,24,222,2,173,12,150,252,40,239,145,252,240,238,249,250,140,12,174,247,101,250,83,6,232,254,246,243,210,251,23,182,172,3,132,246,244,249,138,251,241,254,193,0,16,255,134,252,150,3,2,239,78,236,222,220,196,19,161,230,127,13,253,254,124,3,246,250,68,5,231,251,119,206,207,255,110,71,75,0,23,3,38,7,236,239,0,40,244,255,53,254,173,9,234,245,240,242,194,249,214,3,188,254,208,255,123,239,228,222,112,43,100,0,162,231,140,4,65,9,252,247,247,0,114,2,165,8,231,8,189,245,33,1,41,254,144,251,230,248,53,60,67,2,10,4,77,229,59,222,133,206,246,2,92,252,210,238,53,2,202,1,24,248,46,240,228,243,105,7,44,5,119,12,84,7,236,29,129,1,214,251,253,249,219,250,184,245,254,2,63,0,133,1,67,255,112,4,115,253,34,3,243,2,70,0,140,139,128,2,79,209,149,42,30,8,239,253,133,40,205,9,40,245,152,255,72,247,174,0,187,252,158,0,227,5,171,7,239,254,254,5,60,4,21,33,8,10,118,49,28,247,248,10,4,8,250,226,178,1,193,14,223,3,152,2,164,10,95,6,208,241,51,8,186,253,44,16,245,2,240,43,28,2,111,250,36,216,68,6,88,2,14,248,220,251,209,3,51,7,247,14,91,252,208,252,159,11,243,230,53,6,109,252,72,253,107,8,212,253,27,186,20,13,41,251,246,3,21,246,52,6,192,254,98,9,51,250,130,224,234,251,78,250,200,0,43,5,101,1,88,241,20,11,142,22,138,210,111,252,120,253,140,6,246,0,3,251,215,251,30,9,63,58,228,0,112,3,132,247,0,12,40,246,165,5,162,5,8,10,26,251,218,2,98,248,64,255,227,46,205,249,254,9,202,2,33,0,228,16,222,237,25,255,233,254,1,255,160,69,12,5,202,13,2,253,192,255,245,0,141,6,180,6,203,9,246,241,52,242,184,11,204,7,34,235,180,248,246,233,235,255,108,4,78,251,80,4,113,230,218,4,201,1,81,249,0,128,49,0,54,254,39,1,90,3,251,7,244,4,23,251,166,254,25,3,42,2,236,4,198,251,217,3,83,250,168,6,127,9,214,244,186,5,208,234,90,221,106,18,253,249,135,22,110,0,248,245,54,250,164,254,196,210,234,244,189,4,169,253,201,249,112,242,5,229,47,24,88,15,100,18,46,5,26,250,178,24,9,15,240,239,9,30,88,23,30,243,116,1,182,234,96,247,164,25,253,228,143,3,120,16,146,6,29,253,158,247,203,0,94,1,208,252,95,1,198,242,56,244,59,197,184,213,215,253,151,236,138,0,0,1,136,6,208,248,35,11,222,61,118,11,79,7,168,253,35,243,179,252,120,245,183,5,205,251,208,2,103,251,254,249,111,9,147,28,28,254,58,4,194,3,254,2,179,252,65,214,212,232,198,238,0,15,106,1,194,0,32,238,225,39,36,242,129,255,78,251,246,0,34,253,2,3,55,1,202,243,4,3,138,246,139,251,214,207,192,3,31,6,0,11,80,0,194,238,246,252,153,2,4,9,92,254,76,255,38,251,89,254,106,47,113,0,59,250,83,11,214,0,92,1,97,252,4,253,26,0,153,251,16,247,0,128,22,5,138,1,134,2,59,254,78,252,186,252,113,6,12,247,158,4,234,249,243,230,247,254,106,248,117,242,71,7,58,242,118,13,161,252,118,3,202,0,54,255,90,61,178,8,227,6,126,3,168,3,63,63,75,253,146,6,22,26,206,6,85,5,188,2,27,249,221,252,43,1,110,247,235,4,177,2,134,6,133,253,28,0,114,46,242,255,146,252,193,234,103,0,116,43,16,2,155,4,194,255,100,3,104,253,237,2,152,251,149,5,27,254,128,7,158,252,152,4,27,4,123,1,226,140,50,9,4,255,144,249,100,254,220,252,59,5,129,254,212,252,191,3,125,3,51,249,182,5,180,248,214,1,64,8,159,248,68,247,124,249,13,253,254,245,74,5,39,24,44,213,19,22,218,251,246,9,175,231,62,255,151,6,242,252,32,6,171,255,10,0,248,255,104,4,247,253,190,251,115,248,143,242,118,245,233,11,66,233,111,81,198,2,21,3,176,248,58,4,38,251,56,16,88,6,43,42,155,247,122,255,63,4,132,3,249,224,58,20,155,242,154,210,223,241,236,226,200,252,134,13,189,253,194,252,242,3,27,243,170,47,186,234,29,249,84,1,24,253,3,254,42,2,116,4,234,47,208,250,44,18,224,3,117,248,60,253,50,4,202,10,115,11,98,254,39,255,182,39,185,239,121,252,148,2,232,3,27,0,243,251,4,250,28,5,207,33,127,35,74,244,200,38,118,241,212,253,204,18,246,11,88,2,1,5,39,15,114,0,228,234,77,7,126,8,35,8,145,210,211,254,231,241,139,9,252,8,255,18,186,252,227,255,118,8,39,5,62,8,107,5,27,253,55,251,63,249,32,203,48,227,16,250,107,2,201,236,213,9,14,239,142,249,219,1,200,1,20,17,24,3,152,12,171,7,221,253,233,247,94,8,2,255,13,6,66,229,126,9,160,255,132,77,83,2,173,4,169,250,227,7,222,7,245,249,65,241,94,251,38,218,118,254,246,239,64,249,244,251,129,11,253,1,162,55,155,248,66,246,68,244,202,1,39,249,68,10,62,38,122,13,140,249,190,254,71,32,112,15,148,247,194,247,70,254,232,4,25,6,207,236,132,242,74,0,235,11,203,34,208,242,160,255,14,65,45,2,8,2,66,254,40,246,80,249,103,8,137,246,177,14,77,242,231,1,55,8,9,3,96,254,253,1,212,1,45,14,173,243,196,44,58,8,113,247,10,252,130,4,101,36,192,2,230,254,26,12,162,10,84,0,150,0,222,232,247,11,181,32,136,209,123,251,18,247,11,249,163,28,51,5,178,254,50,252,139,249,240,2,78,248,167,255,114,242,114,9,202,250,31,14,226,49,140,255,173,7,149,249,200,5,79,247,66,214,106,251,18,2,52,252,91,252,207,2,210,2,250,5,195,254,105,0,181,200,9,10,154,17,202,222,87,253,248,249,226,253,2,245,119,251,139,253,16,249,44,242,170,250,159,241,46,7,162,249,65,253,69,49,209,207,28,248,125,8,27,0,59,1,158,18,238,17,189,249,188,255,130,4,132,244,174,4,204,30,198,9,182,253,184,1,252,235,106,246,219,245,198,252,233,28,243,10,200,17,116,243,150,11,65,234,76,2,168,8,20,29,183,245,222,232,178,1,95,13,244,15,248,8,202,51,22,8,240,237,54,251,166,0,145,254,241,253,86,4,129,250,106,255,140,0,72,2,139,254,167,245,94,3,244,1,220,12,78,242,89,253,115,177,239,6,42,253,50,13,242,2,86,248,124,233,198,250,212,241,77,253,202,17,158,248,123,232,90,230,30,10,6,1,205,9,1,1,222,238,80,246,208,24,22,248,210,4,113,254,24,89,83,247,142,253,54,253,173,254,84,251,57,254,176,255,201,2,126,6,218,1,236,246,241,253,5,16,226,214,247,237,252,40,137,251,37,3,80,5,212,14,174,3,172,2,36,10,33,5,53,6,198,253,100,21,229,255,4,36,43,250,71,10,186,229,96,244,41,200,137,0,34,253,33,248,146,2,67,1,83,0,235,9,50,251,178,6,224,247,146,2,141,182,162,11,228,3,210,242,228,255,201,250,150,0,106,8,45,4,172,252,37,1,23,2,20,252,31,252,148,241,16,207,94,1,246,6,38,254,159,5,67,200,248,255,10,249,15,253,72,249,167,0,72,254,110,245,222,0,163,249,224,254,159,2,145,255,30,40,110,3,152,0,74,1,24,252,127,2,0,251,87,4,232,247,159,5,36,254,41,2,98,244,154,253,130,6,46,254,35,46,143,250,154,0,112,2,71,253,176,0,84,4,248,1,250,0,60,2,250,255,192,2,16,0,135,2,137,251,129,250,101,254,193,92,63,1,67,255,108,254,127,253,170,255,61,253,254,252,210,254,13,0,114,254,76,0,87,253,243,253,98,1,55,251,11,253,126,165,28,254,59,252,82,254,165,52,130,3,249,1,239,255,244,53,134,252,101,1,150,2,232,3,89,252,196,255,176,3,144,1,80,254,35,255,23,4,51,1,76,255,140,20,125,64,138,2,243,254,27,6,142,232,246,243,186,0,250,242,118,233,242,3,118,254,128,0,69,253,25,2,229,255,246,3,237,253,206,255,93,255,128,249,254,251,220,2,240,250,96,85,62,2,160,1,23,253,69,254,154,250,16,1,23,3,28,5,204,254,156,249,168,0,86,213,119,0,90,251,99,4,212,5,170,6,52,4,32,248,198,12,30,252,108,3,244,246,80,244,81,49,100,254,97,255,129,20,144,5,208,254,45,2,81,254,152,254,172,254,207,253,220,254,212,6,32,255,253,6,160,254,130,1,136,0,76,0,29,5,242,254,116,161,253,253,118,4,71,8,120,4,83,255,240,3,75,253,82,254,228,251,98,7,61,207,104,211,102,11,55,6,78,251,10,249,201,250,74,5,167,6,2,254,191,16,170,252,129,4,226,7,250,253,64,252,49,46,15,5,205,253,244,43,190,0,238,15,222,0,213,243,234,12,235,2,78,10,247,3,118,249,96,31,174,246,61,2,163,254,192,252,96,0,92,37,188,45,29,254,46,5,12,7,169,244,24,248,22,255,241,3,157,12,24,255,35,3,19,1,188,1,139,253,64,255,125,1,247,250,147,255,165,142,14,1,92,254,104,254,46,254,113,0,231,253,246,254,40,1,180,0,250,1,247,3,203,253,251,253,214,5,211,212,128,15,57,249,146,13,57,248,122,223,139,31,204,6,101,240,249,250,2,246,6,4,158,14,150,253,216,245,9,249,136,10,200,5,30,4,85,1,178,14,129,16,50,249,194,210,252,16,204,221,237,1,108,254,0,15,231,251,85,253,62,252,163,0,245,42,159,255,176,252,232,237,234,10,124,10,236,9,227,2,86,33,104,14,146,252,66,12,16,10,44,25,90,14,189,246,38,255,48,11,238,47,50,11,189,0,197,17,30,19,22,231,230,251,162,243,247,232,197,8,243,10,186,255,139,248,223,10,111,15,153,0,213,43,110,253,236,49,18,255,90,13,69,247,242,2,55,1,29,253,146,246,190,2,52,4,47,1,192,254,47,0,40,243,22,255,160,250,206,11,153,255,12,249,204,2,110,46,190,42,230,234,201,234,172,4,144,253,139,252,116,253,80,243,74,0,77,254,82,253,154,0,227,33,253,12,13,249,171,254,52,2,123,252,55,5,129,253,166,13,228,248,34,1,164,255,240,243,167,18,164,247,30,9,198,2,40,41,62,197,231,57,198,251,235,251,240,3,222,2,241,0,232,251,91,252,245,0,145,3,114,0,66,1,250,248,246,0,43,4,92,1,152,1,73,255,40,253,141,205,173,2,245,5,158,6,183,0,88,255,159,49,12,251,77,6,232,247,10,6,231,2,52,9,87,8,218,253,103,255,47,5,2,0,199,48,217,243,43,9,70,249,212,254,63,255,174,8,120,248,110,253,128,254,150,233,139,251,50,14,72,40,187,255,243,249,127,42,3,7,151,254,210,248,143,0,178,4,71,1,67,195,12,251,62,255,212,12,244,255,168,254,6,248,127,6,78,1,226,252,151,252,200,6,188,254,195,0,95,254,130,254,104,166,44,3,34,254,62,252,61,254,218,2,126,1,121,255,31,5,222,254,122,0,148,0,249,252,207,254,38,130,172,255,98,0,118,1,113,1,212,255,155,3,80,254,156,0,65,250,236,0,217,255,143,0,110,255,67,3,135,0,229,0,215,254,154,6,130,26,119,208,47,3,80,255,76,7,247,255,20,244,108,0,114,0,4,1,73,44,127,245,124,255,253,2,17,255,54,0,179,2,247,217,141,253,38,254,180,47,174,8,85,226,17,255,1,7,67,8,51,2,170,246,57,248,90,11,163,2,155,3,146,0,235,241,213,3,67,249,92,0,206,253,56,173,48,1,62,254,189,254,135,252,42,253,176,2,94,251,30,10,210,1,70,1,34,253,52,1,242,252,109,243,195,3,198,1,68,5,255,253,185,3,122,250,192,254,244,3,132,251,161,4,52,188,241,255,10,6,66,5,134,8,103,246,146,5,102,249,155,0,89,34,114,5,254,1,48,10,53,255,137,10,96,2,52,10,26,203,177,0,34,18,200,252,85,7,184,248,145,6,247,251,207,5,19,253,100,1,245,255,255,255,146,254,41,255,251,5,218,255,102,252,134,254,216,254,221,4,255,77,171,246,53,254,111,241,93,255,178,25,98,1,65,250,195,0,97,1,39,7,163,253,13,247,153,254,179,3,217,32,126,13,128,48,130,9,157,13,40,0,94,1,104,6,226,2,157,217,167,3,85,255,80,252,127,5,113,254,59,2,245,10,204,204,16,3,166,2,101,9,72,1,95,254,164,4,196,249,119,253,178,250,150,251,85,1,202,0,101,246,43,44,54,247,66,242,236,248,10,13,100,252,43,39,188,11,191,2,72,255,102,253,223,0,148,249,203,227,179,13,124,39,44,5,100,254,141,254,164,255,192,9,110,12,10,0,29,40,26,252,14,252,98,2,224,12,206,248,151,1,150,1,183,249,75,255,154,8,106,253,86,250,80,5,208,5,44,255,221,5,42,255,213,253,168,0,19,1,45,1,74,252,200,12,189,254,152,80,235,255,63,249,5,43,101,8,194,219,79,26,175,253,50,227,82,254,40,245,39,9,162,250,7,2,244,236,59,3,83,246,77,248,225,4,172,164,238,248,199,0,7,253,134,8,118,6,191,1,24,254,61,251,108,1,203,255,130,254,35,252,154,0,223,253,152,252,8,3,45,255,26,30,1,253,70,31,118,255,197,7,76,255,50,1,230,1,88,4,120,253,244,255,2,6,212,254,154,9,55,233,99,251,0,226,212,229,147,253,204,254,213,138,90,2,232,255,94,0,240,2,5,2,86,0,7,255,34,4,192,2,108,254,125,254,106,0,136,253,97,255,251,4,59,255,17,251,70,251,103,249,8,215,158,7,11,248,86,23,136,240,38,0,4,5,35,11,3,245,179,249,146,249,180,39,138,0,116,244,196,0,138,255,28,254,92,3,124,0,250,254,30,0,88,250,128,0,31,1,71,1,78,2,136,106,135,1,30,253,161,249,31,254,25,250,82,0,194,253,31,253,154,253,65,254,176,255,36,1,237,255,252,0,254,255,43,146,76,1,141,0,205,5,102,255,102,5,37,249,90,254,100,249,160,247,142,3,236,3,102,7,255,249,129,3,54,254,27,76,215,250,232,8,110,2,32,1,51,247,23,252,48,252,104,254,118,254,132,0,6,255,84,254,234,255,140,0,31,1,115,255,5,121,219,254,119,2,217,2,254,255,25,255,129,255,121,1,145,252,218,254,149,255,253,0,60,252,234,4,58,2,71,0,205,36,166,32,79,36,162,32,222,253,129,4,241,248,41,6,95,11,240,248,16,7,161,249,188,250,191,228,130,254,89,6,23,245,137,41,185,7,255,248,64,207,1,0,218,7,23,0,167,1,78,4,128,248,34,254,53,7,248,3,209,1,246,2,32,3,252,249,72,21,24,215,67,245,35,252,38,231,67,36,117,1,0,246,154,234,174,249,20,0,204,253,206,251,235,15,41,254,253,253,153,1,235,247,103,1,236,252,158,210,220,9,149,3,197,10,243,0,67,243,10,27,124,24,180,243,12,245,172,242,90,239,145,248,19,4,33,208,94,255,62,6,240,1,198,1,121,5,157,249,89,206,95,253,64,13,231,4,66,6,74,251,215,254,238,247,193,11,125,4,5,5,229,250,156,1,67,109,183,0,57,2,24,5,62,253,56,3,133,253,154,254,172,254,228,255,192,250,187,3,14,0,164,2,13,255,236,255,85,209,70,5,186,31,196,0,79,216,61,19,76,241,125,6,111,254,145,0,253,0,168,2,206,2,154,253,155,253,242,1,219,254,95,239,84,253,251,197,230,214,186,2,1,6,32,248,138,4,132,245,214,249,8,0,18,255,114,243,67,245,215,249,93,251,113,0,79,250,44,4,78,2,25,0,124,253,232,3,126,9,180,249,190,51,132,245,150,249,216,237,48,3,177,251,124,226,121,22,98,240,198,250,248,252,90,248,76,218,248,250,222,254,112,239,28,245,1,224,89,6,254,9,214,4,224,248,217,255,199,243,44,221,26,243,0,234,24,249,98,3,196,2,172,2,202,13,188,221,205,5,165,2,98,215,174,2,172,252,194,228,166,20,158,245,100,2,156,4,217,242,189,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+419840);
/* memory initializer */ allocate([76,22,136,5,166,0,227,10,143,241,151,5,112,6,6,31,224,253,216,251,254,253,184,252,154,252,222,4,2,242,162,219,38,241,185,15,197,223,90,23,132,0,149,253,232,10,58,38,220,4,242,0,100,248,163,237,240,232,183,3,62,29,90,242,48,0,140,238,157,246,202,23,217,246,177,239,56,5,14,246,231,254,32,253,34,249,72,249,58,43,106,252,182,250,45,15,223,255,236,239,222,4,38,255,110,224,2,253,116,30,225,5,23,6,60,252,205,6,58,254,164,249,6,253,218,11,220,252,136,252,46,218,131,37,4,246,58,11,176,234,250,11,189,225,188,3,108,253,254,249,131,254,8,253,211,6,35,2,251,253,71,253,125,250,154,1,254,253,108,240,37,255,46,52,167,246,232,254,222,43,80,10,27,3,230,9,98,224,210,248,71,0,16,0,53,255,128,16,160,255,243,244,218,7,169,7,224,250,14,251,112,15,238,26,84,27,130,224,100,18,169,4,145,242,13,6,167,3,170,0,102,2,156,252,43,0,10,255,68,255,84,252,130,0,126,0,32,253,185,2,2,254,200,255,60,6,242,202,25,4,236,60,155,255,195,2,117,10,30,2,246,253,132,253,194,0,199,246,28,251,12,2,224,255,227,0,93,254,116,253,167,253,84,0,68,215,119,250,61,51,195,253,190,14,208,241,233,7,43,251,76,253,50,250,192,0,197,4,196,1,180,1,4,253,180,245,103,255,83,253,118,0,88,254,133,253,54,254,209,0,191,253,246,208,144,16,147,213,49,0,2,250,33,252,144,246,232,254,47,8,207,248,254,4,162,255,89,254,196,253,75,252,222,2,193,251,161,48,114,25,26,238,91,225,118,241,166,5,227,9,42,251,234,247,235,5,205,250,78,9,42,4,238,250,91,251,155,26,180,248,198,251,60,249,100,1,194,245,237,1,239,242,87,5,201,6,145,17,114,198,186,250,158,254,196,250,30,33,128,251,40,7,1,7,62,3,206,3,162,201,10,2,64,250,58,246,191,245,99,255,152,254,239,255,194,252,161,2,36,0,197,250,244,197,10,2,191,203,83,3,169,3,177,251,212,255,152,1,148,254,71,252,120,254,45,7,38,9,212,4,111,0,38,255,105,252,217,3,93,39,215,251,48,7,132,255,196,14,249,212,204,0,181,1,194,252,56,26,72,249,32,1,33,252,70,4,15,22,240,250,20,247,106,6,232,3,221,255,141,255,208,0,12,255,181,251,192,252,212,247,34,3,93,255,15,13,60,252,58,1,126,0,76,251,242,2,82,186,198,252,62,17,139,32,254,252,222,4,84,242,144,6,65,3,148,255,238,1,114,252,86,231,240,244,249,9,170,231,141,4,47,14,75,249,100,9,0,128,8,2,218,255,204,4,60,253,58,0,4,1,3,3,76,2,64,254,133,1,156,0,94,2,194,252,144,1,24,254,68,255,24,2,108,250,206,46,100,255,129,250,4,7,12,4,137,3,91,5,64,250,69,1,26,12,100,250,49,25,57,8,81,212,96,6,200,248,251,3,223,4,28,5,185,250,201,252,143,6,117,253,210,3,40,1,64,4,125,15,122,250,194,209,139,0,216,33,132,242,244,248,16,12,4,248,35,255,189,250,208,4,115,252,213,250,127,250,119,5,253,9,216,56,255,5,32,236,163,6,244,3,5,13,100,15,246,8,165,4,48,247,28,254,21,243,203,250,208,1,207,254,24,253,232,255,16,176,76,1,152,11,52,1,119,253,36,1,110,254,202,4,241,245,31,250,156,255,133,5,221,2,0,252,104,2,135,255,190,254,67,0,95,255,60,253,251,0,206,1,183,151,168,251,155,250,188,254,226,254,67,4,150,2,214,61,68,51,231,251,232,248,157,254,56,7,223,252,82,249,209,9,202,1,226,252,130,1,42,253,156,254,40,251,147,251,124,254,119,2,91,0,75,7,207,9,206,254,25,12,63,56,197,253,143,8,156,244,34,11,249,2,118,246,186,2,111,247,77,245,134,248,19,240,233,237,158,49,77,1,138,4,152,231,78,207,202,254,149,255,95,246,93,255,178,7,26,252,27,251,215,7,79,0,86,254,236,254,109,1,56,2,248,253,90,92,20,1,35,4,184,0,57,4,138,2,238,8,65,255,115,3,102,248,246,0,64,0,31,255,32,3,142,3,120,255,163,4,187,3,12,195,47,50,21,253,106,3,250,1,122,253,128,7,63,254,191,254,128,4,61,5,117,6,85,1,224,255,139,3,161,2,21,4,221,4,13,254,165,215,75,18,159,251,164,243,54,13,253,24,195,250,255,252,162,4,229,0,182,250,54,227,155,0,66,7,241,21,97,242,9,255,241,252,212,2,252,1,205,54,240,253,61,7,36,6,68,2,60,253,16,2,142,250,218,34,236,8,38,2,12,12,66,249,93,243,68,253,220,27,44,242,56,255,216,12,209,252,115,247,208,4,108,9,40,8,179,251,48,49,38,3,228,5,205,6,13,0,100,4,213,240,81,253,12,224,234,243,238,242,245,6,60,46,111,253,115,242,149,5,226,248,151,242,87,0,31,15,139,2,59,252,35,249,122,26,109,0,112,0,125,255,198,2,167,46,181,208,124,242,42,253,234,3,37,241,68,2,196,10,243,250,116,0,201,1,69,2,250,14,114,249,47,252,218,4,8,248,232,0,206,216,108,6,14,247,88,5,172,0,60,244,143,5,196,245,24,14,177,213,209,254,182,249,174,12,50,2,92,20,192,1,147,252,186,3,176,2,235,220,67,2,205,2,35,5,72,252,161,26,150,2,146,12,45,28,188,247,206,40,244,3,222,8,166,252,10,0,214,251,122,41,220,23,221,253,149,12,131,252,48,15,192,251,155,216,9,255,40,4,84,242,51,12,80,246,176,247,228,10,51,247,228,217,40,254,90,255,88,253,215,2,74,0,185,200,67,255,58,249,98,2,111,251,77,3,94,0,238,252,138,1,187,253,244,1,189,7,68,213,98,1,244,1,143,1,96,248,139,254,149,8,152,237,234,245,191,10,142,2,101,2,26,251,126,5,8,8,26,207,47,6,186,253,226,18,251,249,252,1,156,175,14,1,190,4,3,2,198,251,5,0,7,0,235,253,228,255,246,4,229,250,241,1,199,255,181,254,165,3,92,0,168,252,38,215,32,238,249,216,122,9,152,25,50,244,23,1,206,253,64,255,86,7,67,247,114,19,39,249,76,1,74,250,171,252,238,0,222,1,18,38,39,227,206,215,170,223,201,1,49,12,73,3,48,0,95,241,238,250,131,253,228,248,44,254,8,255,120,5,138,1,131,255,74,252,4,45,188,248,170,1,251,252,125,49,172,249,98,255,89,6,21,4,0,3,190,255,244,255,89,6,254,252,47,2,54,0,81,2,132,56,146,58,234,1,31,2,213,252,188,2,235,254,132,3,78,255,48,248,219,1,241,0,182,3,106,0,20,251,106,3,162,252,219,73,101,248,180,252,205,0,229,4,173,255,174,7,252,8,122,245,84,3,146,9,149,2,178,254,250,253,144,251,183,246,69,1,128,4,255,1,113,3,67,169,130,3,62,2,186,253,247,254,174,250,3,255,216,255,244,252,81,248,213,1,204,5,206,252,98,252,190,3,97,254,2,225,182,254,74,1,159,5,107,6,77,0,10,4,100,255,194,208,198,14,163,233,248,253,170,253,41,9,178,13,213,20,190,254,99,0,208,255,210,5,20,0,129,44,140,13,136,251,101,27,112,241,233,27,152,5,18,7,26,0,112,252,126,230,201,251,235,6,95,0,167,15,174,211,213,255,249,0,232,198,7,255,1,0,43,253,244,0,29,4,23,7,142,253,152,1,168,254,180,7,174,8,240,8,236,246,101,254,103,240,238,1,62,253,42,236,81,210,195,241,214,247,161,9,5,23,24,236,159,26,231,253,139,19,234,4,185,0,237,249,149,252,1,248,86,255,79,254,62,255,4,252,93,1,44,253,189,131,197,0,251,0,94,254,34,255,150,253,22,1,42,2,107,1,183,0,126,252,14,0,94,1,233,2,250,247,169,249,38,3,254,252,34,251,58,6,202,255,187,183,236,5,72,3,170,255,228,1,2,2,185,4,210,3,52,2,231,253,34,0,81,254,128,0,170,3,241,248,64,3,166,255,187,140,126,253,117,5,204,255,11,2,119,254,216,0,140,3,9,0,193,255,198,2,75,252,3,0,72,255,175,0,101,2,81,253,104,254,27,0,169,252,82,71,2,5,76,252,37,255,70,9,132,6,41,238,39,4,3,248,250,46,205,1,2,12,26,4,4,249,169,0,126,203,100,2,19,0,29,248,173,2,196,1,104,255,43,1,54,1,233,246,92,1,41,255,98,6,55,255,114,8,196,215,164,48,107,241,92,254,84,9,6,2,252,246,96,255,16,6,19,13,114,6,221,12,172,251,17,8,182,206,20,0,214,255,125,253,202,0,238,250,251,0,185,9,42,5,58,9,114,14,66,255,80,2,60,207,87,252,24,8,251,5,46,1,103,254,125,252,8,252,124,254,79,4,54,117,21,3,183,249,220,253,22,252,31,4,93,2,69,252,21,6,196,1,145,253,42,3,85,2,72,253,132,41,106,251,94,2,68,10,215,253,7,247,12,26,216,245,19,3,176,13,234,241,247,15,28,4,132,24,61,226,81,1,5,10,243,255,181,4,132,255,198,4,78,146,177,255,215,253,116,2,30,2,35,5,159,253,66,1,129,252,135,254,74,253,98,2,239,0,104,255,171,244,162,38,204,2,6,4,22,243,220,3,30,253,50,2,95,247,116,249,155,17,141,4,132,205,98,3,102,255,80,14,145,254,236,245,138,227,196,253,119,8,118,0,252,1,179,238,32,254,74,3,185,9,156,249,6,248,101,4,55,7,26,10,249,233,33,13,8,253,181,43,111,2,230,254,73,5,233,254,3,2,208,252,201,2,66,1,161,1,252,244,166,251,229,249,145,1,156,171,236,250,52,252,6,247,29,254,128,8,194,252,87,8,12,240,71,4,158,7,111,248,27,2,138,254,125,12,170,2,216,1,168,250,97,224,6,209,225,18,210,21,211,1,96,9,148,0,125,1,118,255,186,3,53,254,44,253,202,3,156,0,93,248,173,250,48,2,7,253,84,249,193,249,0,188,216,251,164,250,12,254,136,4,223,2,185,1,251,252,28,255,164,1,152,251,4,1,162,3,79,50,98,252,25,255,75,5,174,252,47,2,113,44,63,249,174,9,193,3,80,1,32,4,217,19,60,38,213,253,227,15,216,33,96,245,74,250,196,11,144,227,197,3,182,5,161,237,65,14,36,8,69,253,250,254,152,1,68,255,145,8,88,247,99,238,32,253,241,251,16,237,205,223,234,224,84,255,218,250,94,37,57,18,35,13,168,241,45,6,217,253,24,248,94,6,7,6,90,0,64,249,232,252,249,248,11,10,80,0,100,254,211,254,202,244,4,7,49,235,111,0,190,67,80,2,196,247,221,1,5,6,242,4,218,251,41,255,94,247,223,0,191,4,59,255,87,0,92,184,189,255,36,3,114,254,138,255,127,242,27,253,113,248,64,253,238,254,54,2,152,252,227,248,74,50,193,19,21,8,206,6,195,231,29,232,178,249,218,254,187,0,166,235,198,6,70,250,142,247,38,247,126,253,108,255,184,1,2,0,233,0,193,254,131,253,34,253,26,255,45,1,252,1,79,254,55,1,199,254,74,251,194,152,235,253,63,6,208,0,219,254,255,8,192,2,50,6,216,251,162,249,178,2,161,6,111,2,250,6,76,1,170,2,199,0,151,49,219,1,8,5,89,246,227,252,188,255,187,37,208,252,95,246,34,2,115,250,60,6,98,252,119,17,56,9,175,21,124,252,41,1,96,0,144,1,168,3,12,6,214,251,167,249,140,2,136,5,138,255,243,253,171,2,9,6,60,5,204,80,168,3,247,251,251,252,224,32,186,3,42,237,127,16,193,213,200,254,128,252,19,2,68,12,143,249,252,1,54,40,197,254,226,247,72,2,243,5,118,0,229,3,195,209,163,253,250,254,60,249,155,253,188,47,150,245,246,248,5,254,198,238,156,255,79,8,142,255,138,252,10,245,244,1,10,4,5,245,98,49,247,3,23,220,151,239,238,0,72,4,121,251,83,6,230,9,108,6,119,242,189,18,127,2,23,10,220,250,100,217,180,3,199,5,162,4,32,249,169,254,250,250,139,249,166,2,241,226,190,17,105,231,192,249,190,228,48,0,192,1,113,1,61,6,144,241,183,247,234,3,124,9,152,211,9,21,59,3,78,214,52,247,192,8,206,4,254,243,154,248,40,1,88,247,59,2,114,0,15,254,117,249,31,5,7,247,51,7,162,254,168,252,19,8,174,4,180,253,14,1,42,254,80,10,18,1,130,76,6,253,49,211,145,253,6,254,140,16,27,213,42,255,192,248,153,1,4,251,89,252,111,249,252,19,6,3,192,11,36,17,144,255,235,218,172,251,174,5,105,5,41,4,7,2,26,254,52,1,139,251,33,1,144,5,168,241,139,193,102,241,200,249,254,254,232,12,62,0,161,5,45,0,82,253,210,251,176,249,67,253,9,9,126,7,235,18,142,2,250,189,7,1,45,7,34,240,167,10,59,253,244,5,164,249,233,7,231,254,8,1,214,4,1,252,51,209,82,244,243,250,33,3,122,218,164,253,46,255,224,4,174,15,68,14,234,211,210,247,42,254,206,250,187,56,172,246,133,5,128,240,129,2,120,11,161,0,105,249,20,251,186,6,80,248,108,1,170,252,206,199,162,39,24,3,133,0,210,6,5,1,17,13,104,254,244,7,16,1,132,5,208,2,26,243,41,250,18,239,162,8,31,3,138,68,40,10,34,5,252,2,47,5,105,13,135,254,200,16,98,9,206,251,214,1,52,28,4,246,254,12,14,239,218,247,103,248,89,46,197,13,233,5,240,5,234,248,36,205,95,252,47,248,40,250,68,2,35,243,182,243,119,247,162,5,134,1,22,248,163,247,64,255,244,182,9,248,22,239,155,6,6,255,171,5,159,244,16,11,44,243,83,11,249,5,136,252,230,1,179,246,77,250,153,245,18,2,51,253,8,255,78,249,118,49,28,7,32,211,236,251,219,11,32,15,130,246,167,2,51,4,219,1,175,253,162,3,41,249,149,1,252,246,100,8,254,1,18,245,189,1,16,255,47,229,58,8,197,211,158,2,246,16,154,0,188,225,243,248,5,21,182,252,71,253,59,253,176,2,14,254,149,21,108,59,42,248,206,239,108,246,88,9,62,242,25,248,26,5,146,21,148,3,224,241,225,254,115,253,77,1,182,254,4,0,202,158,123,2,119,0,99,248,131,3,220,255,219,255,98,10,123,255,16,8,234,253,219,253,47,249,186,255,255,127,65,4,155,252,150,0,169,253,134,251,194,253,88,254,121,1,120,253,209,254,78,2,197,1,118,7,161,254,41,2,48,1,16,253,16,253,10,254,214,255,21,134,134,253,193,1,126,2,62,4,130,250,196,4,34,3,100,252,174,248,44,255,86,0,56,255,140,251,106,2,147,253,163,253,32,213,163,6,165,253,8,8,160,238,17,250,4,10,25,253,16,48,202,5,35,2,203,249,207,252,39,255,159,249,191,251,34,247,181,0,134,253,50,15,222,2,217,250,13,248,232,12,88,51,140,220,29,240,70,0,29,5,43,4,158,254,249,5,99,5,22,252,4,243,243,253,207,252,98,250,82,42,12,4,153,48,218,4,157,9,42,11,209,8,174,1,103,251,118,4,154,252,76,3,78,4,184,4,54,250,62,3,214,68,63,245,6,0,174,0,33,17,173,254,109,8,101,255,188,255,66,255,99,251,29,0,2,248,164,247,27,0,181,3,97,7,190,1,202,255,56,65,207,255,24,243,119,248,41,7,151,14,17,254,55,251,33,210,45,247,123,3,94,248,32,11,8,254,140,4,71,246,93,3,67,2,229,210,208,3,214,255,197,5,132,246,231,249,112,0,74,0,95,245,14,47,120,2,3,5,148,248,198,7,87,251,70,6,166,250,4,245,227,250,117,250,18,207,63,13,139,239,106,245,13,1,90,0,239,56,167,254,52,3,230,23,124,3,158,24,247,244,76,1,1,244,231,8,172,14,185,0,43,244,98,9,245,0,242,3,239,254,17,128,116,255,168,253,226,1,236,5,50,254,139,7,149,7,16,1,202,254,32,2,90,254,209,252,164,251,35,3,151,253,152,249,16,239,41,210,72,14,104,251,146,4,191,231,91,8,221,249,19,8,243,3,114,38,22,3,166,6,65,255,143,3,211,10,3,255,26,3,234,240,163,248,18,254,22,8,134,245,4,3,251,2,208,16,215,194,110,247,50,248,61,252,154,235,81,255,238,0,32,0,83,39,76,253,8,11,38,254,200,11,38,209,205,255,201,2,119,9,48,11,174,254,230,18,185,251,215,0,97,203,254,255,192,2,240,2,194,198,116,5,228,1,52,2,138,252,249,252,181,251,7,3,245,251,125,6,11,252,162,251,193,1,54,3,173,55,74,204,196,251,173,251,120,249,228,3,216,1,189,8,72,254,162,4,176,4,192,247,148,250,187,251,146,248,43,2,184,254,43,250,14,248,170,1,160,247,124,254,196,177,5,5,98,4,218,2,125,6,216,249,220,247,114,11,81,1,190,255,55,6,237,33,57,9,146,0,90,5,22,0,91,5,151,255,162,239,115,1,60,204,72,1,21,5,29,252,105,14,22,25,177,255,129,250,128,254,60,3,72,3,86,3,10,1,198,4,28,3,218,253,39,253,67,251,169,255,12,2,46,4,62,87,227,246,62,2,168,2,144,253,207,1,207,15,20,255,114,0,252,3,76,253,39,6,192,254,99,243,222,0,8,2,228,3,56,8,228,234,235,184,175,251,72,255,223,251,216,41,51,246,28,228,253,246,53,5,225,11,183,0,217,4,75,225,12,244,152,5,9,0,105,250,211,245,103,10,17,1,250,0,2,3,28,253,43,26,79,213,197,227,105,0,89,244,77,251,101,6,72,232,26,230,165,3,10,250,146,2,52,10,1,21,165,255,190,255,80,19,209,11,163,10,155,252,142,0,36,41,130,38,49,255,0,12,206,245,0,0,81,0,54,4,88,8,246,254,223,0,163,3,127,254,215,3,5,4,108,0,242,8,21,254,61,104,53,2,116,255,106,253,168,2,98,247,221,252,247,252,6,255,45,254,98,0,128,11,248,207,162,239,50,247,20,253,228,247,172,18,2,254,35,255,148,5,238,231,133,10,94,24,66,240,10,1,140,25,198,9,27,20,215,237,12,7,238,214,171,242,199,9,95,8,124,248,29,241,90,14,245,16,226,251,198,243,20,251,192,253,119,3,52,101,251,252,162,4,36,2,162,253,24,253,29,252,40,5,5,254,23,1,11,7,109,246,112,3,225,255,251,255,79,6,2,3,214,209,38,4,154,251,216,1,215,254,162,208,83,251,120,7,62,252,217,4,44,9,28,9,25,244,25,6,4,15,208,2,125,254,115,1,126,11,150,4,213,246,220,4,164,39,172,249,244,209,35,5,225,255,181,248,122,13,203,249,60,20,112,12,202,245,243,255,130,0,107,0,41,1,113,0,129,250,6,114,224,253,83,255,222,3,145,3,200,248,34,252,206,4,8,1,104,7,194,228,154,255,72,247,242,14,35,247,93,236,94,0,188,206,180,1,165,232,221,6,221,6,44,253,74,9,24,10,216,2,2,252,150,227,156,2,232,2,252,253,164,1,166,209,246,0,179,250,102,9,90,14,222,245,102,6,35,244,158,246,245,5,120,227,202,251,236,6,48,36,78,48,202,0,2,0,40,253,172,2,75,254,166,5,38,242,60,3,198,247,80,245,196,3,76,255,124,25,202,8,2,2,242,252,163,2,138,5,39,212,200,10,126,240,223,253,168,35,55,230,212,253,82,248,239,237,107,255,58,255,254,242,217,249,202,231,144,2,162,2,111,1,17,7,155,0,250,235,221,23,196,253,63,19,168,5,193,248,100,6,200,33,218,7,13,35,15,12,188,39,34,0,97,251,244,255,223,251,192,0,117,244,10,4,138,254,196,9,102,36,6,240,156,235,108,254,2,252,78,250,169,250,253,2,87,251,6,6,46,1,199,250,222,255,169,5,154,5,162,8,148,1,51,243,168,224,83,5,89,226,136,35,37,220,152,4,113,227,32,2,18,221,55,253,200,255,63,10,221,255,87,6,164,8,197,6,56,253,209,250,192,254,82,248,88,44,4,251,36,241,218,253,8,2,16,237,38,2,208,5,176,3,4,42,242,252,11,22,169,245,143,230,84,242,195,244,88,7,22,230,45,9,0,1,184,1,188,0,20,223,28,238,175,9,155,18,241,248,255,253,60,239,63,249,34,229,192,1,206,229,118,251,74,19,47,253,89,21,129,5,201,221,126,252,98,239,146,235,210,240,223,224,194,6,72,14,174,4,209,13,33,0,251,15,216,247,34,226,136,4,106,11,87,3,26,251,200,245,254,252,83,253,156,255,191,253,193,236,232,252,197,247,141,37,3,10,232,19,255,23,180,242,74,222,68,16,12,127,188,254,155,1,222,255,71,253,50,3,185,255,22,9,114,255,35,252,24,250,102,1,252,254,207,14,193,253,93,0,224,0,208,0,179,251,255,127,123,4,53,255,223,7,205,1,156,2,216,254,244,242,218,255,208,2,31,252,229,6,192,250,43,5,136,2,27,252,217,2,69,2,93,1,93,3,13,248,255,6,162,247,202,252,111,250,52,3,101,230,213,252,164,194,112,252,227,18,220,5,164,253,15,2,87,252,128,253,40,251,84,18,235,4,174,0,248,208,194,1,4,32,236,10,253,235,59,6,26,2,155,255,38,255,205,21,111,1,116,245,21,1,63,8,158,10,178,5,155,0,156,255,212,12,14,254,233,38,31,250,160,215,110,251,217,20,8,4,157,197,130,4,190,253,3,210,79,252,108,253,157,2,36,9,242,251,240,5,201,2,103,10,166,1,38,251,126,7,22,255,255,248,212,249,241,254,4,234,38,248,79,208,8,249,191,238,12,245,205,243,36,239,126,0,209,24,169,246,216,247,68,3,10,246,9,2,22,251,150,3,119,17,240,253,147,16,153,253,125,13,229,229,248,6,22,3,144,51,188,2,66,1,209,252,161,23,222,254,160,3,159,251,5,250,146,252,130,251,124,5,69,1,238,253,77,254,2,255,220,252,24,246,77,2,247,32,193,251,136,192,131,253,8,250,49,1,215,249,130,2,85,167,117,255,39,5,76,2,249,243,32,3,171,253,128,250,130,251,73,12,156,252,172,12,20,252,236,3,77,250,158,210,51,238,197,241,110,252,142,16,142,253,185,15,155,12,25,2,67,239,218,7,235,2,59,6,63,6,106,23,227,252,113,252,38,11,158,242,216,222,149,248,211,254,158,247,145,255,246,253,196,248,3,12,232,240,5,250,142,2,193,0,0,212,185,21,48,1,13,2,90,1,55,245,156,251,110,4,162,32,84,207,1,252,46,226,66,245,18,250,137,19,200,5,241,251,10,254,175,5,74,2,244,3,10,251,147,48,127,3,145,4,210,1,56,214,235,240,29,17,254,6,255,2,240,248,231,253,223,251,186,246,246,247,8,39,166,252,224,249,90,253,28,241,16,250,241,5,230,0,76,249,106,52,118,248,45,252,200,12,92,4,53,238,209,253,192,254,48,47,128,53,226,254,140,2,116,9,189,6,235,254,213,0,234,251,106,6,192,253,22,250,51,252,35,250,77,0,25,2,162,253,120,4,88,253,200,253,80,4,128,8,55,252,121,6,240,252,83,4,224,251,197,255,25,234,64,0,137,46,78,255,255,33,160,14,20,1,206,255,249,205,98,4,6,232,109,7,73,254,221,2,173,26,185,11,195,255,19,252,232,14,147,15,252,241,246,252,209,8,69,47,196,0,228,53,99,1,127,5,221,3,101,0,17,4,220,3,250,4,58,250,153,251,40,5,70,254,124,13,75,249,220,4,46,254,156,252,189,254,246,1,219,4,186,255,129,3,190,3,221,10,68,246,20,3,232,2,220,207,87,4,72,210,60,254,34,253,118,76,211,255,184,253,173,246,194,252,91,2,124,1,19,3,110,244,254,7,220,9,157,246,187,2,208,239,51,6,61,2,76,2,238,0,168,255,31,0,234,254,0,128,107,251,23,253,155,2,68,255,197,4,143,254,251,254,66,1,250,247,139,2,100,0,212,247,59,1,22,6,84,2,105,254,110,255,46,251,6,135,185,255,121,2,24,2,191,250,27,7,143,2,168,2,83,250,236,1,15,251,244,250,244,6,188,255,240,3,215,0,244,177,247,253,180,243,0,255,193,0,148,3,197,1,86,0,116,0,108,0,238,5,116,250,35,250,176,2,157,2,172,4,213,249,82,252,100,3,36,3,110,0,102,4,202,0,62,4,220,91,46,4,169,249,235,2,218,255,140,255,152,4,42,2,199,246,240,3,61,4,180,7,254,248,160,255,208,1,82,174,72,251,239,240,46,254,131,247,157,9,60,9,93,252,84,253,240,11,49,253,88,252,119,3,179,243,236,3,173,27,87,244,79,219,22,20,107,218,150,0,174,0,60,2,72,247,122,254,76,5,160,0,212,213,208,8,190,8,242,0,127,6,229,1,90,48,212,4,176,2,164,244,60,4,23,4,242,18,184,255,126,253,68,6,152,0,174,252,158,2,200,3,121,243,154,6,105,0,44,246,19,45,134,1,163,251,180,253,237,213,63,11,134,18,97,223,35,6,174,252,163,253,89,248,139,1,36,48,214,6,242,8,164,255,6,3,175,244,1,4,207,248,34,2,64,15,68,15,230,44,9,0,60,5,56,209,243,253,242,5,213,255,213,255,188,248,240,231,57,255,175,9,241,17,196,244,87,244,20,4,194,255,212,252,184,40,71,246,182,251,28,3,244,250,234,247,72,4,104,248,159,247,234,238,17,4,10,252,76,35,162,247,72,1,216,223,152,0,232,203,79,247,148,53,145,254,210,253,106,248,161,0,40,254,176,8,20,253,222,13,215,252,19,254,73,8,210,4,4,3,26,20,181,9,22,247,122,29,95,250,59,6,216,35,64,24,12,5,168,6,128,15,36,250,74,248,65,242,246,244,149,0,121,252,248,1,69,255,84,252,121,0,41,255,153,253,255,254,94,248,190,3,9,8,65,255,10,83,42,253,33,8,254,4,134,6,170,252,170,10,60,224,238,253,236,3,14,10,150,5,24,246,157,213,109,5,155,0,116,255,110,8,202,10,223,14,10,15,112,241,70,252,154,211,197,2,135,57,2,2,182,2,169,255,89,3,7,255,93,254,105,2,94,254,136,251,224,255,122,247,185,252,169,5,208,251,239,252,10,255,66,53,200,48,102,1,65,254,42,247,158,3,255,3,123,252,167,254,212,8,6,250,70,250,99,244,134,247,42,8,44,0,76,164,91,2,52,249,167,254,74,254,68,244,42,5,240,243,250,4,85,1,164,254,234,253,31,4,210,11,92,252,2,2,254,34,127,195,138,254,53,4,142,4,48,0,248,3,106,252,229,255,102,254,246,254,135,250,208,240,154,244,158,247,255,10,42,7,149,252,162,0,90,253,84,7,15,248,207,7,202,205,229,249,192,0,158,1,14,3,219,243,152,5,155,239,54,9,69,33,16,3,232,4,174,250,122,11,165,211,192,235,182,215,217,255,122,247,106,249,241,0,61,255,24,255,231,231,206,0,181,0,42,254,240,3,169,253,228,254,221,2,188,252,136,2,118,255,30,8,57,1,112,95,36,2,71,254,166,5,164,249,62,251,192,255,52,253,104,246,195,7,160,254,255,251,97,248,40,5,94,1,232,2,38,10,40,252,104,184,110,2,252,255,220,249,125,3,29,244,243,238,127,0,255,255,30,255,96,249,52,5,176,250,100,26,36,10,27,47,114,1,150,241,241,1,73,2,83,6,246,252,214,35,2,248,166,8,212,7,109,4,45,4,132,0,6,255,237,249,118,252,49,2,152,205,241,251,186,224,84,7,252,8,164,251,103,7,246,6,150,14,172,251,58,5,127,250,8,255,245,62,78,250,156,0,190,245,64,0,81,251,40,242,187,16,194,242,108,254,146,5,117,252,48,245,244,252,222,255,32,183,211,7,3,2,99,12,115,253,250,2,232,242,102,255,109,251,60,254,202,249,208,232,7,2,186,4,246,1,103,254,214,8,183,2,4,4,204,33,228,9,180,245,144,13,94,251,70,5,117,253,129,253,190,32,94,243,118,2,173,215,19,247,132,248,58,3,87,250,30,253,168,254,254,3,80,243,71,174,56,255,56,2,172,255,9,3,222,249,60,245,18,11,26,0,38,15,83,249,101,0,153,5,66,247,49,1,61,0,239,251,95,9,116,2,27,250,124,254,178,3,221,2,254,249,118,253,223,77,222,1,56,214,82,3,86,253,191,1,7,9,35,0,22,251,28,9,103,211,207,6,190,252,148,2,98,12,74,9,82,245,6,253,129,251,246,248,148,219,17,18,0,9,94,251,156,4,30,19,150,2,101,228,101,3,101,2,10,7,231,18,84,13,172,234,162,252,150,239,196,30,223,251,56,11,200,250,195,6,220,213,64,4,105,13,42,0,85,252,175,9,25,25,223,3,171,249,150,12,96,246,172,11,227,255,225,1,86,45,16,245,133,223,236,29,199,242,193,4,40,253,170,241,172,2,9,247,44,253,201,253,154,247,150,255,128,248,161,247,137,13,176,7,191,251,79,209,112,245,233,11,185,250,57,28,95,22,243,253,79,10,163,7,211,8,89,25,181,248,8,6,129,243,128,236,116,9,23,16,212,244,223,218,152,247,220,39,147,251,79,251,68,250,83,244,50,18,66,2,91,4,112,1,34,6,248,252,9,254,18,6,49,5,72,253,8,253,63,2,9,250,231,240,180,32,206,242,55,224,56,223,113,242,194,248,12,237,150,20,134,253,96,2,9,5,20,226,119,19,14,251,234,247,118,252,219,12,155,9,199,18,111,239,141,22,46,247,108,238,74,10,136,204,12,25,26,1,39,233,38,1,142,253,120,3,192,251,144,2,192,0,138,253,179,242,75,207,66,11,136,8,80,15,155,10,60,229,169,251,101,3,95,255,85,1,64,7,22,219,159,10,189,253,0,241,197,221,129,4,52,242,197,253,2,253,109,32,120,11,251,214,207,251,84,39,142,244,164,24,69,245,21,12,82,249,231,240,72,250,161,238,190,1,130,3,10,21,206,251,213,237,61,24,199,1,19,249,10,251,74,27,67,246,236,15,109,41,38,246,209,3,2,16,129,4,78,254,231,15,182,244,104,11,215,35,228,8,91,18,130,2,213,251,56,252,252,1,40,249,216,2,188,12,12,254,134,5,178,21,201,10,181,7,160,237,79,8,117,5,210,251,56,199,241,196,84,29,57,5,86,16,158,244,107,241,126,10,42,254,201,8,195,240,164,5,221,14,99,0,21,249,158,254,121,252,61,245,59,253,140,236,214,0,66,245,116,253,238,251,154,5,190,251,156,253,242,245,250,4,30,5,8,253,140,5,144,255,216,10,21,237,212,58,191,236,154,240,167,233,164,249,138,251,207,11,101,250,122,5,242,3,111,2,57,242,64,10,184,0,220,3,98,0,84,1,36,65,18,251,118,251,111,12,48,237,176,253,251,3,130,250,82,246,67,9,20,252,104,15,35,3,33,22,43,247,43,64,93,1,41,12,108,252,186,1,38,249,33,242,185,250,27,6,220,250,20,2,87,1,120,254,229,5,51,253,134,255,158,9,95,252,71,255,85,253,164,182,122,10,133,255,6,2,133,254,216,235,245,0,148,7,140,54,233,207,78,2,226,255,159,0,234,249,108,248,36,0,8,250,253,253,102,251,88,3,117,254,29,0,34,233,113,205,230,51,244,245,25,4,0,3,220,12,175,240,204,255,50,254,176,7,69,19,118,2,162,3,2,4,46,10,63,1,235,254,189,24,185,247,164,237,116,8,47,6,154,0,59,8,69,250,83,1,122,2,168,188,173,253,59,242,126,245,4,249,36,254,215,255,165,0,8,252,80,250,164,254,25,44,152,244,36,241,53,9,236,46,8,15,4,7,116,8,77,234,175,17,55,255,197,3,227,236,91,13,41,25,155,6,179,255,92,1,255,252,183,106,167,254,176,254,227,253,192,254,204,3,158,3,254,251,28,4,190,2,224,0,76,0,230,2,220,0,148,24,177,33,98,241,43,16,155,232,17,234,127,253,25,255,187,252,12,24,45,16,208,14,138,18,244,38,8,7,115,254,67,247,86,247,85,226,55,245,16,254,85,250,154,4,54,252,54,251,223,9,199,247,242,6,166,5,194,7,242,38,205,204,39,252,138,251,169,250,183,254,110,238,78,2,36,0,25,8,211,251,94,3,133,0,212,9,229,255,142,17,174,210,154,249,220,9,169,5,52,22,157,253,20,219,198,245,142,19,153,13,129,253,123,1,227,246,14,254,55,253,126,1,16,3,13,1,196,233,162,254,12,2,239,182,238,251,187,250,186,4,234,6,124,15,44,19,149,251,127,68,236,252,152,248,30,0,134,245,20,4,68,6,100,241,18,0,235,6,75,1,183,16,74,10,144,254,65,254,173,228,56,251,80,253,8,235,20,255,88,221,145,9,99,208,113,17,103,7,180,9,35,5,186,234,55,254,193,253,101,0,52,9,207,249,132,12,152,255,180,227,114,249,223,252,196,245,5,238,156,209,5,249,146,11,252,248,199,242,101,254,164,22,84,11,206,253,67,3,37,1,215,27,75,19,209,2,100,244,30,254,121,0,122,245,27,247,156,1,226,49,170,254,206,2,234,12,246,1,143,227,205,254,40,2,246,27,217,12,69,236,110,20,95,251,208,11,82,252,189,250,229,254,143,201,48,255,16,10,118,252,56,7,60,22,126,246,175,0,157,30,80,7,72,238,243,242,67,252,195,57,194,249,98,35,192,14,151,1,58,249,235,4,61,244,125,255,251,241,154,253,16,1,104,244,181,249,61,14,66,224,72,8,4,19,170,234,77,204,132,242,67,232,200,19,199,249,141,250,133,246,141,251,66,252,49,6,206,250,130,8,246,252,217,13,20,11,32,30,105,23,80,254,247,13,161,3,241,224,115,0,132,8,64,15,63,255,20,6,4,255,111,252,14,10,172,46,83,238,111,5,191,222,188,17,241,205,205,242,188,237,46,7,212,233,41,5,232,231,117,5,252,3,182,1,115,255,96,13,136,1,0,254,178,249,140,250,194,254,109,246,9,6,36,228,29,249,88,254,247,13,196,252,16,75,186,7,88,6,79,248,125,249,252,252,17,248,243,252,196,6,244,0,44,255,160,1,132,3,0,221,234,3,203,251,59,18,57,242,50,6,203,204,118,246,245,14,6,17,32,4,144,11,193,251,106,253,167,18,84,231,13,24,104,241,8,248,69,255,136,3,230,4,132,253,240,7,34,253,9,251,125,245,48,13,52,2,167,225,150,234,72,3,91,55,60,233,58,252,149,6,48,216,124,254,78,254,122,14,82,2,140,8,109,1,209,0,42,1,33,7,20,255,218,49,108,6,127,12,44,254,76,50,130,0,135,247,178,242,13,242,209,237,35,9,5,42,12,5,104,11,33,1,198,254,177,253,161,249,14,249,240,250,2,255,213,1,64,219,130,4,78,1,252,255,126,248,227,10,61,1,160,1,89,249,251,54,65,6,126,2,44,247,51,252,200,252,0,11,118,244,210,12,124,241,142,252,137,242,242,11,211,229,209,4,177,0,251,13,180,13,45,242,241,214,83,29,184,29,120,248,178,9,49,253,230,8,47,20,100,38,76,41,205,241,66,245,79,13,140,255,15,13,152,242,209,242,214,3,135,3,89,243,68,254,218,249,179,254,141,37,134,248,236,253,87,7,178,255,232,185,139,228,50,6,206,243,104,1,111,254,195,4,218,247,250,11,110,3,148,22,76,252,102,0,160,7,162,1,96,254,234,3,100,5,17,5,164,255,128,253,213,253,121,251,155,144,35,249,72,253,124,0,150,253,54,6,44,1,170,253,156,3,66,255,58,249,156,239,31,235,12,201,83,23,101,32,218,240,88,250,15,249,82,255,153,3,237,249,158,252,48,2,232,0,134,248,94,240,252,252,168,7,175,236,96,13,92,25,91,14,224,252,226,20,52,17,129,253,201,41,95,6,90,250,139,238,132,225,137,14,216,18,148,253,75,4,116,244,55,20,107,246,226,236,2,10,206,248,76,19,111,5,2,11,71,4,67,239,69,25,82,248,28,199,72,247,80,2,194,21,134,245,91,10,70,18,236,226,173,246,156,26,43,206,224,233,214,255,134,0,211,244,12,249,98,255,130,5,130,236,161,2,35,8,177,245,203,11,254,255,113,32,67,248,190,247,202,255,76,11,123,6,191,197,182,255,188,251,93,251,161,9,86,247,23,3,160,253,5,12,26,0,184,251,100,249,162,12,52,228,213,248,132,235,142,1,153,39,186,2,250,8,242,1,148,27,30,25,113,5,236,9,231,1,2,250,122,248,237,235,97,13,181,17,203,19,233,253,100,252,170,3,249,248,248,62,245,7,113,241,203,252,170,11,10,9,33,255,78,5,9,0,137,10,242,248,84,252,210,241,205,248,40,245,58,247,68,2,114,249,123,9,78,8,113,248,140,11,81,3,58,71,126,2,86,1,12,4,249,0,232,255,153,10,75,248,122,255,139,238,34,248,238,231,192,178,191,2,206,255,247,8,10,247,179,7,155,4,246,3,70,9,56,250,233,5,118,2,6,6,140,96,206,13,110,11,150,2,186,244,247,253,164,254,146,1,88,4,141,254,51,6,30,7,88,7,4,5,46,1,81,7,4,5,100,252,20,25,42,18,50,31,171,1,105,1,172,223,48,1,121,209,231,250,30,248,189,0,2,1,71,3,82,252,223,1,166,243,85,251,142,251,24,6,198,248,72,235,108,216,219,214,235,250,181,243,88,253,56,0,164,16,45,229,186,250,186,251,151,250,39,7,254,255,83,252,156,14,21,30,169,252,232,12,116,13,141,238,13,1,4,240,76,2,133,54,226,249,23,242,144,7,0,11,166,11,12,7,150,10,163,1,173,2,116,17,232,1,208,218,78,245,134,15,6,217,111,249,142,246,36,9,51,253,125,252,217,244,26,215,6,4,214,246,77,234,255,9,132,8,52,235,40,7,54,40,86,1,54,44,184,246,192,240,12,250,34,241,54,4,152,248,31,28,62,242,84,5,243,8,113,252,100,255,25,239,246,252,13,137,191,253,98,255,48,2,189,10,31,3,129,10,81,1,211,254,62,251,219,4,175,2,144,252,93,254,40,0,232,254,4,0,42,7,180,38,161,7,152,1,56,4,73,34,21,15,40,2,6,229,38,242,246,229,35,0,145,248,180,18,216,19,49,11,23,255,7,4,89,238,72,202,143,246,50,249,35,227,119,12,142,253,101,254,73,227,247,11,247,248,231,238,98,244,132,255,218,10,173,10,93,1,89,251,128,230,93,249,251,26,239,0,51,245,182,233,43,14,48,8,236,255,237,8,252,27,195,13,194,210,32,14,154,253,122,24,227,254,59,14,226,5,81,14,237,4,222,246,162,1,58,236,29,19,129,11,131,7,82,244,77,238,102,221,209,10,91,236,154,8,9,13,207,41,204,2,238,21,122,197,194,246,217,234,25,0,127,249,1,17,244,11,145,247,237,3,205,249,144,254,75,252,28,245,39,4,27,5,197,255,210,255,63,231,244,1,86,251,98,11,68,9,143,250,134,248,236,14,120,251,121,255,193,14,185,200,88,20,14,247,106,22,250,3,129,1,91,7,190,245,183,219,58,4,22,6,36,249,160,10,249,253,6,205,168,241,223,6,243,255,143,13,231,15,167,232,167,0,142,239,171,8,64,5,148,246,145,17,222,228,148,2,70,34,187,243,192,23,130,238,216,9,159,253,248,243,27,253,184,30,4,29,179,254,130,4,199,248,198,5,204,1,174,254,5,230,80,246,156,6,56,8,106,6,160,10,249,3,199,10,226,248,148,245,39,247,5,252,34,221,207,5,221,2,232,196,167,21,138,239,124,228,154,2,196,27,174,8,106,246,131,19,244,19,201,5,194,8,111,22,25,254,197,37,39,1,211,13,228,18,231,1,251,249,56,3,198,232,36,26,144,254,146,250,41,232,193,17,111,10,16,208,88,12,248,2,224,247,195,13,64,245,132,244,50,253,154,8,109,234,42,9,52,234,113,236,68,24,226,234,172,211,248,4,13,21,27,9,107,14,96,251,255,241,108,238,165,253,218,255,91,235,237,253,236,18,246,240,104,15,131,230,165,233,247,246,39,252,111,3,66,2,111,243,240,241,2,245,152,5,48,45,75,250,31,249,242,239,248,239,153,255,245,248,75,20,59,250,68,5,107,0,62,15,191,4,194,13,180,242,138,35,19,255,68,0,34,0,36,246,248,208,217,231,74,8,214,1,23,251,90,1,24,255,67,249,25,23,11,250,15,233,54,7,152,211,19,4,253,251,105,16,232,240,58,239,76,30,55,7,152,241,255,127,48,247,16,0,108,8,11,1,104,4,114,5,112,248,24,254,107,254,167,254,44,4,66,2,224,5,88,251,107,254,36,1,125,4,147,16,152,0,12,4,246,6,95,10,203,164,180,251,115,248,98,1,198,3,238,249,149,4,94,251,239,1,106,2,241,3,101,245,205,1,86,23,171,3,224,13,45,5,57,13,68,252,129,8,53,8,111,255,24,252,22,9,162,9,6,11,206,61,187,253,55,253,46,17,60,3,79,243,154,240,198,7,162,252,224,8,92,1,100,244,241,0,138,245,167,248,221,168,161,1,181,253,56,1,24,1,36,246,76,9,43,1,91,15,178,0,94,11,16,246,156,254,238,252,34,2,183,255,162,252,240,0,139,249,6,5,221,240,232,247,59,250,160,65,132,251,51,8,144,12,54,20,129,8,226,11,228,252,158,1,6,254,115,3,45,7,171,5,48,11,82,3,91,9,98,254,182,12,111,248,5,192,120,240,130,8,63,250,151,18,192,252,186,34,252,12,19,244,105,254,6,250,81,254,60,251,128,0,112,242,212,3,52,0,132,198,196,6,139,7,138,230,8,249,151,212,114,17,232,255,145,222,105,0,102,21,236,239,91,247,66,244,202,6,163,239,238,12,15,253,77,7,68,2,139,252,17,12,210,31,130,236,223,248,244,253,36,14,248,228,109,2,216,251,25,18,27,250,80,0,59,213,64,245,220,1,156,241,219,13,81,248,36,13,71,11,39,253,241,30,136,239,159,241,175,199,118,240,5,1,134,251,156,251,123,252,9,3,15,3,254,255,35,252,210,249,148,15,105,30,29,231,46,247,16,13,98,1,233,51,11,13,60,1,142,243,216,247,97,248,54,1,223,253,64,253,216,255,64,17,120,254,247,251,18,22,99,0,64,244,124,241,144,9,82,241,247,36,255,248,126,255,169,6,101,25,90,247,154,11,20,215,52,2,192,232,227,253,29,8,166,255,188,25,214,244,59,249,225,219,167,254,158,243,122,19,25,13,252,236,169,34,113,0,153,235,26,6,93,255,114,246,149,238,140,224,82,4,125,213,161,4,36,249,104,255,37,12,181,0,109,250,99,32,155,44,135,231,68,8,43,254,30,20,75,5,182,0,28,253,11,3,182,225,76,7,144,0,96,15,196,255,240,252,25,255,111,3,136,66,31,247,94,7,230,253,247,3,6,7,135,253,66,4,118,7,128,0,50,232,102,248,222,249,41,253,231,183,242,1,16,3,189,238,120,6,235,255,154,0,126,9,231,14,215,255,108,245,198,249,228,0,240,252,116,28,60,254,46,226,188,205,236,13,97,21,36,251,183,8,28,0,225,16,72,250,122,5,178,250,193,8,144,2,152,251,136,4,208,246,57,14,88,253,24,7,208,26,214,255,245,4,232,254,15,251,0,248,238,0,115,253,3,53,34,15,243,254,41,31,190,8,34,251,238,247,133,18,170,6,170,13,83,2,255,9,55,0,81,2,145,6,76,6,43,0,60,245,142,10,135,9,89,246,215,252,98,7,136,66,237,252,72,239,143,4,122,248,147,236,99,251,52,245,201,239,146,11,116,13,76,3,142,9,189,54,254,12,85,251,219,248,52,6,229,6,188,243,114,33,167,199,200,15,211,7,30,253,248,251,14,243,68,247,36,2,0,3,212,246,180,1,219,6,31,0,248,237,235,4,13,1,7,6,143,250,218,20,177,191,84,11,80,246,123,6,217,0,24,233,38,15,148,20,220,4,248,253,78,251,214,4,182,0,231,251,73,253,192,254,80,229,240,232,98,11,200,245,26,10,50,213,70,243,202,248,231,237,67,9,179,12,1,242,71,10,190,239,219,11,158,10,104,2,74,11,206,0,0,63,211,3,223,13,48,229,107,243,249,22,108,14,182,6,234,0,228,244,132,6,102,0,127,10,186,252,220,3,92,4,21,2,186,15,189,227,84,23,43,202,190,242,66,242,218,254,17,231,139,6,155,17,68,21,129,1,117,248,162,3,187,2,103,6,159,1,64,26,174,30,234,5,120,12,51,247,62,198,229,250,103,3,49,5,89,7,228,25,35,11,171,255,20,247,70,238,187,252,72,247,13,1,77,247,106,54,241,247,140,226,18,35,171,4,157,10,254,250,52,252,25,5,24,15,108,9,4,9,40,237,46,243,160,252,23,254,78,250,144,8,31,62,156,9,232,10,215,239,10,4,153,254,5,0,249,8,250,255,237,240,222,1,1,250,32,8,27,253,238,7,165,253,176,245,146,248,240,223,234,14,7,251,54,224,223,7,209,35,144,242,13,249], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+430080);
/* memory initializer */ allocate([236,15,192,253,163,255,74,249,232,2,3,10,88,26,255,240,75,5,54,6,156,239,156,201,100,1,69,52,248,9,210,244,230,10,190,253,234,13,151,10,82,253,57,241,23,254,206,4,128,3,184,4,179,251,102,242,82,246,4,3,230,4,64,1,223,248,185,254,46,4,80,249,39,1,35,185,198,245,1,6,165,253,198,14,8,251,147,248,158,1,169,0,82,230,202,228,151,10,36,243,148,51,212,250,36,14,98,19,19,11,81,16,253,18,182,246,98,234,117,14,128,239,137,253,129,243,115,253,177,18,235,251,207,247,68,2,142,8,116,255,48,0,3,12,190,250,214,252,224,7,54,2,17,246,235,0,214,232,164,7,225,1,59,74,158,240,89,25,137,10,188,18,107,13,190,27,246,11,180,5,74,233,163,10,85,16,141,236,26,246,246,247,120,255,226,13,132,245,148,59,16,16,182,243,252,10,14,28,174,245,67,21,237,251,221,252,226,10,170,249,196,7,244,252,202,5,41,205,30,249,159,250,91,240,161,0,160,218,230,31,40,7,74,1,172,230,177,3,220,238,66,4,244,253,20,6,186,253,64,1,2,3,86,252,203,221,209,3,60,4,106,228,224,13,7,3,156,237,23,247,216,253,213,216,167,16,173,4,96,253,163,255,84,22,15,241,82,238,245,6,71,38,98,17,189,7,179,243,64,218,47,12,210,14,165,255,54,26,72,3,182,251,46,44,139,244,17,3,243,245,236,2,11,7,135,250,245,249,234,239,81,3,188,253,132,250,0,6,90,219,182,249,31,9,147,1,133,244,57,244,87,241,87,226,104,6,18,13,222,245,164,224,109,21,141,8,215,242,58,8,249,20,243,245,253,253,179,5,84,27,64,5,123,254,159,228,92,40,184,252,227,240,133,3,207,230,212,246,99,246,249,239,214,252,244,247,16,4,117,0,241,125,25,255,177,3,231,3,97,251,180,0,163,5,188,0,87,3,158,249,6,3,54,255,99,0,178,6,30,1,175,252,176,7,241,217,158,195,165,252,114,241,209,8,99,1,89,255,118,249,16,7,24,254,94,4,120,250,107,249,112,11,191,5,135,251,232,253,3,9,52,252,89,251,89,6,100,250,122,1,210,78,130,253,34,7,216,1,212,254,179,252,235,251,50,4,239,251,2,254,217,255,4,2,196,17,181,10,43,216,224,246,244,14,45,8,204,239,78,220,143,16,216,9,48,242,33,241,182,11,78,247,14,229,230,18,248,9,24,248,53,234,90,5,186,45,54,226,30,6,221,3,186,236,191,250,182,232,163,16,134,4,128,241,106,245,243,251,105,0,83,245,44,4,98,14,64,15,252,7,184,0,25,2,146,242,160,250,76,1,148,69,158,243,82,9,214,247,153,13,184,250,175,1,8,252,218,251,204,253,40,249,214,245,19,5,64,26,21,3,251,4,183,217,200,20,23,9,48,240,91,17,116,225,88,4,208,4,141,251,104,252,24,253,179,252,86,241,70,23,244,234,8,13,6,242,69,240,176,2,125,228,120,255,93,255,141,250,88,52,193,6,186,248,52,10,65,1,222,240,179,3,34,252,164,243,223,44,46,0,70,248,165,247,198,4,57,15,64,218,108,14,55,21,220,242,134,241,180,0,87,240,3,10,199,254,156,12,161,249,221,217,32,220,86,232,14,238,16,4,5,243,65,1,95,243,171,19,129,248,107,234,107,7,172,4,214,248,121,254,37,2,190,247,100,250,192,245,137,9,106,2,42,148,183,252,88,252,43,4,133,4,230,0,16,3,13,253,6,7,37,255,254,251,161,251,64,1,205,245,154,250,72,34,127,4,155,14,161,253,181,11,232,225,18,233,8,7,77,5,109,19,54,218,194,235,206,255,138,252,8,8,222,252,139,248,62,2,76,249,12,231,190,244,58,242,140,243,225,253,244,0,176,37,9,20,51,236,86,2,167,220,42,7,209,242,89,5,181,5,241,250,132,254,238,254,90,28,119,219,159,246,139,46,33,236,225,5,115,16,49,253,122,252,226,6,88,255,130,2,187,2,237,247,91,252,68,4,66,252,203,2,70,248,80,248,179,249,17,251,247,252,146,4,76,218,158,218,100,2,161,240,237,0,130,1,141,16,68,250,68,216,156,236,103,11,228,230,240,227,119,0,26,14,59,0,96,12,158,234,171,252,153,233,27,249,247,11,184,250,176,3,114,248,84,242,66,36,32,23,16,3,90,0,19,1,139,12,114,9,134,222,254,214,22,248,4,252,83,244,231,5,215,255,58,211,68,248,176,20,54,10,235,255,2,3,100,255,255,244,116,237,32,222,119,13,193,227,246,17,189,250,79,253,130,243,178,1,56,0,239,247,6,7,193,53,235,253,0,251,228,252,177,9,56,0,97,5,159,234,156,35,95,251,166,253,243,9,147,241,80,221,162,11,133,35,37,7,236,18,119,253,60,1,94,255,240,5,74,233,252,18,199,0,206,250,194,235,131,231,82,10,196,4,0,11,254,239,115,240,48,204,114,254,105,1,208,10,78,237,255,3,159,255,143,2,115,254,99,9,216,249,126,254,168,251,24,3,85,251,9,253,230,2,217,2,156,244,4,252,102,83,230,255,7,242,147,2,17,251,98,5,13,239,88,7,234,18,99,253,77,251,48,23,48,3,92,223,76,14,137,6,91,253,190,246,116,6,6,34,26,251,27,24,44,229,133,252,160,229,87,255,210,233,92,226,81,243,166,11,161,20,179,236,153,254,230,242,83,3,183,249,70,212,98,2,5,1,112,248,155,10,44,242,72,246,38,8,222,23,146,3,104,243,241,6,234,249,169,3,152,14,219,243,111,7,154,16,130,238,76,10,244,8,85,250,247,39,176,29,150,8,89,247,53,247,82,248,252,249,45,254,147,1,111,6,205,244,227,245,222,255,246,246,166,253,67,9,54,10,170,8,66,246,75,14,148,10,204,251,110,252,233,0,125,4,145,5,63,1,45,252,255,3,86,253,110,0,239,0,171,1,191,2,93,244,47,246,167,245,39,247,252,28,14,2,126,8,116,11,204,244,248,247,72,247,115,6,211,250,168,252,38,255,43,8,202,1,228,5,72,251,179,252,244,0,71,254,46,2,240,2,68,253,166,250,117,254,212,3,191,254,24,255,15,255,37,1,151,40,0,249,100,248,18,250,231,251,43,0,244,5,241,7,126,246,47,1,194,6,75,251,104,250,97,251,74,253,161,4,29,246,160,245,65,245,36,249,215,250,180,251,31,1,157,33,204,244,6,246,209,2,239,247,121,249,253,252,163,2,175,8,126,245,59,246,247,246,37,7,117,12,45,0,33,7,232,7,175,243,248,244,87,245,252,246,150,6,142,254,226,1,46,10,100,244,236,246,188,9,30,249,130,249,28,0,112,19,142,12,47,245,196,254,134,251,94,248,86,0,196,255,142,254,120,4,143,21,7,249,254,249,236,251,188,253,167,255,192,2,127,4,230,245,186,251,49,29,60,251,204,251,206,255,5,4,58,7,218,13,207,12,242,248,89,251,240,253,170,2,136,4,61,5,220,244,5,6,202,246,207,248,243,246,185,250,225,3,113,9,141,245,178,9,243,247,215,247,97,14,114,2,83,6,26,7,156,244,5,11,78,246,138,247,196,251,113,4,161,21,48,11,61,246,10,249,108,8,254,9,163,251,127,0,123,4,20,6,244,245,25,15,40,248,243,248,89,253,119,0,35,0,39,5,112,245,176,248,36,249,187,26,113,252,66,1,105,6,157,9,164,245,91,248,180,7,210,249,10,12,84,0,62,4,207,5,89,244,235,246,36,245,28,246,190,248,233,254,108,39,167,17,196,246,158,10,141,248,118,10,19,252,246,0,219,5,143,6,246,245,75,34,44,248,165,249,180,252,89,0,176,6,97,8,244,12,29,249,150,249,3,11,169,253,9,0,138,3,121,5,15,247,80,247,158,9,212,249,181,252,197,9,232,255,30,5,19,12,47,249,94,9,16,251,37,253,113,0,63,3,48,5,13,245,180,246,8,245,181,246,14,247,160,250,22,255,194,8,209,13,167,247,254,247,20,251,65,11,177,0,134,4,144,5,25,243,205,243,198,243,211,244,229,247,224,9,213,255,50,15,222,243,144,245,6,246,41,7,198,252,55,0,46,19,252,12,153,15,128,247,114,246,200,248,238,252,18,13,54,6,242,7,91,245,247,254,47,1,52,4,63,248,77,14,20,6,191,7,146,243,104,245,84,244,231,244,204,250,208,18,22,25,88,16,74,247,32,251,128,247,242,248,175,249,146,252,180,14,29,5,24,247,253,1,45,255,170,1,5,3,99,0,1,2,116,2,167,0,196,0,48,247,246,248,123,251,212,2,125,5,103,5,80,9,103,254,96,253,59,254,51,255,167,255,244,255,240,0,114,0,84,247,217,252,234,250,180,249,107,254,110,4,101,5,187,2,232,248,153,247,165,248,159,11,160,3,247,5,29,6,7,3,163,247,67,248,4,250,177,253,10,13,171,2,227,6,210,1,20,248,218,247,168,5,146,253,77,2,14,5,126,4,145,0,178,246,187,251,145,254,218,3,67,1,148,1,163,3,141,254,204,244,79,245,201,247,129,0,3,3,218,5,182,7,55,250,220,251,162,246,155,251,29,1,217,10,159,11,151,5,96,245,212,6,185,246,201,248,112,252,245,14,40,3,242,7,68,246,113,246,32,251,33,252,169,5,24,5,99,3,147,4,73,244,4,246,53,245,6,247,31,13,181,16,199,7,34,11,124,245,176,245,223,245,21,7,54,254,252,11,244,3,1,8,70,243,252,244,227,244,165,246,227,10,211,255,81,21,240,13,69,246,190,247,164,248,6,0,180,254,24,255,144,6,115,4,240,7,177,246,121,247,67,249,110,252,192,0,79,16,11,8,150,244,100,244,152,244,94,247,137,251,58,7,164,9,79,7,190,243,157,255,165,245,50,246,127,255,119,2,141,6,133,7,26,243,204,243,114,243,185,243,200,245,7,253,138,15,138,16,94,249,200,252,73,248,26,253,145,9,158,253,21,0,230,3,25,244,119,245,69,245,129,248,247,249,110,29,219,4,220,13,185,248,23,251,83,1,253,251,122,0,155,253,197,7,185,3,72,247,33,249,41,249,55,252,201,249,125,7,187,254,121,3,219,52,2,251,87,247,92,248,176,250,132,252,118,253,158,252,1,255,192,0,141,251,38,251,203,247,110,249,191,249,134,11,36,9,121,0,150,2,190,1,180,245,175,6,103,2,184,248,239,250,182,251,216,254,46,4,4,5,123,3,164,28,12,247,226,246,159,248,110,251,92,7,198,253,52,0,122,4,176,3,221,247,112,247,140,246,139,247,250,249,62,250,234,254,51,16,226,5,130,6,246,3,135,249,79,247,43,247,120,33,91,250,245,253,141,255,231,3,90,2,54,245,43,247,15,1,251,248,159,249,234,252,135,1,139,3,22,5,52,4,141,248,85,247,117,246,85,248,41,250,242,250,114,18,167,3,155,6,90,5,205,246,207,249,50,246,7,247,130,10,45,250,121,253,104,1,180,5,199,5,7,248,112,1,214,40,3,251,52,253,84,255,230,253,225,254,169,0,24,255,192,3,193,251,101,246,108,247,91,251,81,248,206,249,241,252,155,20,251,10,13,250,59,249,187,246,102,248,206,249,0,251,70,254,51,255,26,9,175,24,77,246,189,247,171,245,32,248,72,250,89,0,17,2,58,5,171,20,114,12,138,22,249,246,120,245,140,246,149,253,238,246,242,32,127,255,125,6,208,4,159,250,3,251,87,251,150,1,204,250,34,251,25,252,15,254,0,4,220,5,25,245,119,250,131,247,115,9,44,250,34,253,235,10,47,2,238,2,7,2,102,245,3,254,14,18,95,14,218,254,73,0,219,252,90,2,157,255,94,0,158,245,64,248,251,26,12,249,36,251,16,1,106,3,140,0,46,5,181,2,137,245,30,247,9,246,39,52,197,245,218,17,53,249,5,9,0,5,211,4,13,252,220,247,80,248,132,250,8,10,75,12,176,254,14,1,243,1,250,1,225,249,64,247,131,245,97,248,50,247,223,10,125,250,174,34,17,9,155,6,249,245,110,246,244,245,18,247,10,248,245,248,220,250,197,254,208,1,199,4,60,248,97,252,13,248,117,8,79,14,105,252,184,254,229,0,254,255,217,0,43,245,144,247,179,245,121,247,217,19,102,250,246,5,14,11,162,6,129,4,6,245,148,251,32,21,56,248,171,16,179,250,41,3,51,2,9,0,192,255,123,244,149,27,252,17,112,250,209,248,158,253,5,255,114,1,133,3,147,0,40,247,63,12,169,12,178,251,115,254,244,250,39,0,17,0,124,1,127,1,53,250,78,250,52,3,87,8,122,253,33,254,173,0,23,0,238,254,70,254,46,252,64,251,120,248,92,28,31,251,68,252,232,255,250,0,182,1,128,0,240,15,152,0,117,10,181,253,101,253,96,253,106,253,20,254,46,253,80,253,141,248,237,252,29,12,132,250,46,251,4,254,233,14,168,1,145,2,170,255,125,247,169,253,93,8,90,250,201,248,245,16,223,252,230,255,199,255,216,0,167,249,222,252,216,6,235,250,57,10,247,249,255,253,111,254,234,0,146,2,19,5,1,251,106,3,128,250,145,251,216,255,89,254,138,1,148,2,172,2,13,13,87,252,206,248,103,251,153,7,147,253,19,0,163,255,141,0,197,255,190,245,40,13,204,249,89,248,30,250,145,14,165,254,218,0,241,1,73,2,65,246,108,246,186,247,66,2,31,255,122,1,40,0,56,4,140,3,249,2,234,247,185,249,230,9,1,250,213,5,104,10,215,0,122,2,61,1,23,255,92,16,90,250,175,247,236,248,108,250,213,249,242,251,97,0,221,3,246,7,87,14,109,245,208,245,106,247,161,251,65,6,18,4,45,5,206,4,125,4,250,245,226,251,75,14,131,247,20,249,55,253,200,251,155,255,219,3,37,3,237,249,19,253,26,250,115,13,134,250,76,16,72,253,181,1,20,1,219,0,81,245,107,246,222,247,58,15,157,252,186,253,42,253,110,4,203,4,97,4,29,9,61,252,62,250,82,9,65,252,185,254,118,255,4,0,12,1,223,1,183,244,176,244,115,245,73,248,175,253,188,4,231,5,63,4,202,5,76,6,89,249,10,19,46,0,172,250,194,250,224,253,145,252,57,254,24,254,116,254,200,245,81,3,136,246,72,248,45,250,29,253,69,1,4,5,39,7,199,4,208,255,79,250,181,247,218,250,81,6,216,251,180,9,45,254,21,2,195,2,95,1,166,1,243,253,111,253,202,0,36,254,133,0,89,253,79,252,192,252,114,7,91,244,211,245,137,248,19,246,33,45,207,249,19,6,148,8,80,6,147,245,215,246,137,246,200,248,36,249,54,19,57,253,162,4,81,7,119,5,96,253,135,250,12,250,142,251,94,253,5,5,195,0,116,3,135,254,213,251,179,247,121,1,45,249,188,249,69,3,178,254,141,255,197,255,160,0,227,1,84,247,61,50,159,249,176,249,98,252,77,251,143,255,166,255,122,1,148,0,108,22,88,0,58,247,194,249,246,249,98,249,230,10,184,255,78,2,28,0,208,245,216,16,212,251,19,12,136,253,117,253,110,1,63,0,232,2,119,1,210,6,193,10,229,247,171,249,247,251,41,254,204,3,199,0,63,2,143,2,156,247,103,9,124,247,28,249,250,251,191,251,243,15,176,255,161,1,128,1,172,4,20,247,11,246,21,249,251,252,213,0,164,4,20,3,63,5,78,5,232,245,43,30,133,247,3,247,39,250,74,254,233,3,110,0,159,2,171,3,35,25,145,22,27,249,249,250,99,251,10,252,87,0,105,252,90,254,68,254,118,248,42,19,132,249,234,249,33,14,103,251,5,1,9,0,5,1,209,255,21,246,189,10,84,246,6,247,233,251,217,250,171,254,164,253,63,8,219,10,137,244,147,19,188,248,197,246,106,249,247,251,32,3,238,6,164,6,198,5,3,45,228,252,48,250,151,248,160,248,101,249,25,249,254,248,170,249,70,251,20,247,39,245,178,246,165,250,18,255,181,11,110,12,76,2,105,4,192,2,248,0,167,6,248,254,230,250,133,251,208,253,23,250,68,252,131,6,60,5,100,20,28,247,89,247,255,247,57,250,242,250,250,252,66,0,246,4,27,8,101,250,67,248,238,246,152,248,215,250,50,254,138,0,158,19,245,9,147,6,156,255,48,249,8,250,89,254,205,23,195,255,224,254,145,253,118,253,196,252,15,250,134,0,216,4,137,250,86,250,100,2,55,252,25,10,177,3,200,254,142,251,72,246,47,246,60,248,185,249,251,252,56,13,168,4,91,10,20,10,40,252,33,248,71,250,216,249,225,8,59,251,91,0,55,10,72,3,19,5,211,251,153,247,149,248,33,253,184,1,120,3,15,255,246,1,185,3,29,14,14,7,193,248,1,247,34,249,218,250,52,250,246,255,85,2,139,14,200,7,24,254,241,247,20,247,132,247,143,248,245,249,87,252,238,255,204,12,16,28,106,248,2,247,161,246,76,248,158,250,133,253,46,1,57,4,78,21,30,13,65,254,217,252,205,0,243,248,246,249,66,254,220,24,108,252,151,0,135,254,186,253,168,252,52,255,37,253,140,252,94,253,255,254,189,255,28,6,182,9,235,3,28,250,100,249,235,5,135,252,146,253,62,9,9,0,239,255,11,255,149,14,223,251,228,254,125,12,225,255,72,254,165,251,183,249,214,248,118,248,230,0,6,1,176,28,217,255,46,249,206,253,238,249,210,248,144,249,226,250,109,8,80,0,154,255,238,0,201,252,146,253,48,253,141,255,238,254,16,0,230,249,7,249,1,250,178,254,44,10,60,13,102,254,153,255,164,254,114,255,140,6,71,254,37,247,60,248,115,250,88,253,22,5,122,10,127,1,246,255,207,5,194,251,5,255,146,251,141,0,172,255,21,252,126,252,95,0,0,9,34,3,243,249,230,249,90,10,132,8,64,0,0,254,192,252,63,253,83,254,34,7,21,247,72,248,3,251,139,10,248,1,249,0,247,255,178,0,223,255,179,250,142,251,189,11,37,1,229,0,97,6,59,255,228,253,35,251,175,249,11,251,239,25,133,9,121,253,35,250,183,251,229,251,130,251,97,251,75,250,71,0,249,5,31,11,125,4,63,253,191,250,187,249,139,253,151,253,196,255,223,247,101,250,170,3,76,3,225,251,183,252,155,4,136,1,88,4,178,3,28,251,64,249,246,254,151,27,201,250,104,252,232,251,206,0,48,0,149,253,156,18,18,1,90,9,225,252,226,252,21,252,2,251,248,248,166,249,121,250,14,254,159,5,107,6,70,248,22,251,144,251,5,5,247,255,84,2,141,0,93,247,140,3,34,3,42,254,155,251,144,12,22,255,100,254,3,0,44,252,15,0,233,251,250,5,148,2,194,7,32,254,13,254,218,253,35,253,237,253,46,5,185,249,19,3,144,251,22,252,191,255,102,1,231,2,253,0,218,254,170,13,247,251,10,251,234,252,25,2,252,6,53,1,184,255,39,251,49,248,97,2,165,11,255,251,150,249,66,252,5,15,59,251,62,252,59,252,180,249,55,248,223,255,144,251,62,4,210,255,154,4,27,255,139,0,132,2,206,2,96,249,107,9,251,3,224,251,52,0,224,0,25,254,117,254,216,255,125,0,185,11,93,248,98,248,240,252,169,251,129,3,254,253,159,0,17,3,71,4,128,11,6,246,153,246,73,248,136,253,6,4,176,6,110,1,207,1,125,0,206,246,228,252,31,22,225,251,129,251,154,252,92,1,92,253,167,5,215,0,19,252,5,250,114,252,201,8,74,254,73,11,107,0,108,254,241,254,234,253,2,252,187,247,54,249,213,8,255,254,236,252,32,0,211,6,172,4,142,3,33,0,1,0,233,255,28,0,231,255,19,0,13,0,227,255,233,255,208,255,117,252,191,247,70,248,110,250,233,253,53,6,116,7,164,10,110,6,127,252,246,2,22,9,162,2,87,250,111,0,220,0,219,1,94,255,71,250,12,248,240,253,28,5,217,247,17,248,228,250,183,0,35,0,73,4,240,3,72,7,188,247,1,247,120,248,251,254,38,9,220,254,200,5,12,1,46,6,55,4,97,251,126,251,247,252,53,1,194,4,171,2,34,5,141,6,10,253,47,249,142,5,205,250,154,249,180,251,209,254,139,19,199,255,133,254,1,254,12,253,41,253,245,246,188,248,17,249,92,253,14,15,189,255,204,255,226,7,252,5,96,255,59,255,181,255,114,248,146,251,233,7,18,7,21,254,83,0,134,2,134,1,215,254,71,254,170,254,33,254,26,254,216,254,226,255,187,1,127,4,180,13,231,23,19,254,109,250,143,250,7,251,0,251,105,249,109,249,25,250,245,19,16,252,143,251,130,253,119,253,170,254,178,253,34,254,191,253,163,254,189,253,244,9,49,254,59,8,200,253,90,253,236,252,58,254,160,253,60,254,142,7,205,5,46,249,17,252,106,251,195,253,239,0,137,255,167,2,180,255,105,249,164,7,126,252,35,254,200,1,100,255,180,5,13,0,92,0,37,252,42,2,44,245,238,245,98,249,21,255,241,2,247,5,82,4,3,6,62,5,231,250,160,25,10,250,27,249,231,252,168,253,248,0,226,253,193,255,91,254,220,18,8,5,212,249,222,248,117,251,10,252,35,255,206,252,147,255,195,255,241,4,147,7,15,251,98,254,120,7,66,255,123,251,93,253,12,253,89,252,225,9,136,0,83,249,65,249,229,248,32,250,48,251,65,252,104,4,46,16,103,248,142,11,124,252,104,250,72,249,156,250,125,1,193,5,211,4,38,4,219,3,250,255,147,253,36,255,122,246,125,254,233,253,233,255,90,252,188,255,135,236,63,2,227,1,75,28,205,251,149,3,203,6,216,248,188,253,28,6,131,0,76,255,9,251,88,14,161,0,16,4,201,6,159,10,77,4,71,255,126,250,221,0,90,254,29,222,15,253,111,254,244,234,13,0,250,2,98,5,89,4,232,6,79,255,69,13,114,8,11,1,213,8,100,255,172,6,176,252,177,255,229,248,169,243,84,234,23,253,40,28,241,251,131,29,122,255,101,10,192,247,222,8,57,248,185,1,152,231,246,0,166,0,44,8,134,250,14,255,224,202,229,253,135,1,91,9,249,42,43,252,154,42,109,254,55,3,111,6,218,254,93,0,248,1,184,234,189,4,199,248,251,243,22,3,183,252,12,50,254,211,166,248,219,252,238,254,176,7,207,255,165,4,176,255,231,254,216,255,153,1,119,9,69,2,174,250,207,0,155,252,179,253,222,12,194,254,16,238,36,254,246,3,121,255,177,185,62,255,39,3,126,244,34,255,44,0,254,253,201,238,79,251,131,4,21,255,98,0,80,17,170,254,82,9,122,5,68,252,29,13,167,7,182,18,117,255,90,242,72,239,179,253,26,223,107,1,22,253,128,2,152,254,17,252,180,251,203,224,170,206,238,3,184,249,160,252,30,255,109,252,16,248,250,4,84,2,72,7,43,4,61,6,204,1,45,248,72,234,172,224,50,9,123,1,177,243,44,0,112,27,70,253,171,244,112,19,159,3,199,4,163,255,172,0,189,0,239,25,62,232,42,253,244,253,4,244,38,241,16,0,241,251,151,255,29,9,162,254,206,254,133,254,192,252,2,5,56,0,201,13,50,2,165,253,66,23,38,1,15,251,109,31,106,240,87,255,133,255,61,243,60,2,145,252,26,6,95,251,31,3,139,218,151,1,178,253,65,0,224,244,177,1,85,234,237,255,12,28,32,225,120,254,67,1,64,254,127,238,67,241,90,235,165,7,226,0,8,248,220,12,171,11,88,249,19,11,107,255,155,5,55,3,239,6,47,245,146,0,234,0,125,255,241,255,12,1,37,0,139,0,22,0,60,255,91,0,81,242,211,234,24,0,232,254,58,0,114,1,143,2,132,5,113,0,50,1,20,64,22,255,59,1,67,252,72,0,151,251,201,7,225,182,121,250,69,5,36,9,29,2,57,1,176,250,31,0,161,5,178,255,79,217,119,254,111,1,56,253,39,248,116,1,215,254,133,255,47,1,54,254,189,254,46,0,253,33,235,250,192,221,213,255,26,7,212,0,225,253,43,236,155,224,24,246,190,2,24,3,131,254,240,254,149,7,176,24,177,248,142,201,250,254,241,247,108,0,163,252,229,1,72,254,0,3,33,22,210,254,49,1,40,202,73,11,129,255,162,255,145,0,28,5,231,30,72,223,125,253,172,253,77,5,81,252,49,5,172,255,194,255,115,6,135,1,9,247,176,234,155,254,253,237,81,5,121,15,217,254,130,2,70,253,166,33,77,6,242,253,136,255,51,255,17,0,53,177,228,4,251,254,23,2,36,251,92,0,197,254,110,3,124,1,157,0,145,12,19,254,251,252,1,2,2,254,40,44,125,252,229,255,142,1,14,231,147,2,23,252,79,245,17,204,195,4,10,252,63,255,189,1,167,246,88,1,231,255,169,253,224,244,116,3,94,0,245,255,204,253,220,255,211,38,54,242,206,1,82,252,105,39,56,3,178,11,219,254,71,0,183,39,55,254,199,2,60,252,176,247,226,9,160,0,2,246,147,9,118,6,12,241,24,6,111,3,1,252,94,223,83,3,179,255,144,255,116,76,218,7,203,251,207,250,254,250,253,4,252,0,10,234,9,18,58,0,245,246,53,254,31,251,92,0,196,2,31,253,5,243,182,0,21,6,111,253,34,2,65,254,173,74,109,6,176,254,230,255,7,248,38,23,138,18,182,248,82,15,238,10,200,20,7,0,214,1,74,3,229,0,201,253,230,2,22,243,147,2,153,252,30,255,223,245,21,252,163,250,83,2,0,253,178,80,176,3,204,4,23,1,5,250,150,253,105,1,77,240,169,254,161,254,231,27,37,1,92,0,103,245,243,254,226,255,180,254,253,15,216,0,239,0,205,253,151,7,80,252,36,247,70,0,47,255,184,1,213,5,66,254,235,1,150,254,25,0,181,254,177,1,207,249,173,0,102,4,226,241,22,255,167,245,157,4,127,253,96,255,143,14,183,252,170,247,140,250,130,233,242,255,108,1,213,237,127,4,194,0,142,235,246,22,188,250,148,250,23,255,226,14,164,252,7,37,232,255,40,230,107,5,57,254,191,1,32,255,75,244,12,0,174,13,183,255,214,1,46,220,141,6,28,253,176,253,154,249,163,2,163,255,78,186,214,6,177,252,225,3,167,246,207,255,19,248,148,7,76,2,219,1,117,242,55,0,223,19,173,11,124,1,147,3,34,245,114,9,39,44,74,4,241,3,92,5,108,233,209,254,171,5,204,3,247,226,197,253,125,6,64,0,25,40,5,6,206,255,60,252,30,253,3,255,223,243,73,253,222,253,249,252,229,181,234,243,181,246,226,2,89,6,111,2,49,4,14,3,211,2,167,242,190,253,67,255,12,16,91,4,58,251,114,220,128,237,91,1,178,3,66,1,141,241,193,0,221,196,111,1,201,3,236,252,74,253,148,253,230,255,240,255,4,0,34,254,56,81,105,251,25,255,6,10,10,251,162,0,181,0,85,250,6,235,131,246,50,221,46,241,81,233,137,249,248,0,80,17,113,5,109,246,110,245,24,253,175,2,74,3,255,250,144,11,212,246,153,0,121,249,103,250,30,251,184,251,197,9,239,234,170,16,182,251,112,3,65,251,49,3,69,254,69,39,193,2,79,253,137,245,75,251,26,243,215,252,106,252,19,252,124,0,183,254,108,0,204,255,71,235,93,254,128,0,55,224,147,5,131,1,21,255,234,245,190,0,83,255,249,251,112,10,39,252,237,12,217,232,159,28,241,222,254,255,147,23,231,2,40,2,242,255,188,253,188,255,146,209,220,1,61,0,148,4,239,253,36,252,103,3,248,252,180,254,134,81,128,1,115,30,178,213,211,2,154,6,249,253,194,3,151,2,20,5,47,254,47,0,6,242,56,0,61,224,249,7,180,222,233,250,205,24,111,7,186,229,132,4,32,255,6,5,205,246,169,242,217,3,10,254,86,246,49,0,27,245,224,241,85,249,35,13,116,255,166,6,129,248,2,211,108,254,62,0,235,228,93,251,78,42,132,0,28,1,129,253,69,5,63,9,201,254,142,253,233,2,28,22,104,255,135,255,140,235,31,254,1,23,17,251,5,223,223,255,168,3,167,1,139,255,111,0,225,251,153,255,191,254,6,5,157,253,9,3,59,3,166,1,94,255,145,229,15,255,33,1,71,254,192,250,146,10,20,251,215,237,177,252,21,193,249,254,222,248,247,253,8,253,174,3,53,1,124,245,29,237,171,252,218,252,236,254,190,254,15,22,195,4,79,254,166,254,109,251,252,251,191,0,106,254,188,1,33,0,16,1,174,13,219,1,126,247,123,7,222,254,243,251,65,3,73,253,135,255,159,1,44,2,1,4,36,247,78,1,31,11,24,249,123,254,46,201,218,240,68,3,253,17,63,248,153,254,198,5,107,255,55,3,98,252,196,252,135,0,213,1,123,253,184,254,162,255,78,255,4,11,13,3,199,246,110,233,32,5,78,15,255,255,186,241,82,252,65,246,103,2,210,0,146,189,116,254,67,254,126,1,51,2,54,249,95,0,109,220,5,19,92,1,15,2,56,22,111,255,85,251,193,246,19,253,69,255,41,26,27,0,91,1,27,49,192,255,85,254,181,14,56,3,64,251,154,251,109,23,74,2,110,0,218,254,16,255,110,6,70,255,80,5,157,1,197,230,1,250,120,243,248,253,147,253,165,33,74,4,237,255,57,255,74,211,111,253,159,254,138,3,166,2,81,180,130,255,152,6,132,2,207,4,153,247,26,253,64,1,188,255,118,207,66,245,203,5,189,249,177,245,212,11,102,10,116,255,29,21,107,252,105,254,207,0,176,36,199,253,163,3,132,255,174,255,226,24,221,1,24,208,69,4,99,13,36,253,206,255,232,0,189,255,97,2,79,6,49,254,71,2,16,7,219,5,3,254,145,160,231,0,184,255,64,255,179,254,126,226,170,254,180,220,208,254,136,0,166,195,53,5,133,251,48,250,96,250,75,0,63,0,235,2,41,1,5,255,30,0,211,254,238,248,170,255,32,2,50,215,20,5,228,40,218,0,89,246,190,7,167,1,230,11,168,251,111,253,152,255,175,41,210,255,55,213,195,231,5,251,180,7,169,3,181,255,182,254,239,253,235,245,230,5,167,248,164,250,67,249,205,56,208,253,140,252,178,3,205,254,89,236,118,30,66,255,208,2,245,5,29,0,100,3,214,4,116,1,50,254,163,9,155,245,161,10,22,250,211,2,34,245,18,254,240,0,21,228,75,2,239,2,77,6,46,43,50,4,19,1,204,3,54,252,27,0,181,255,24,0,247,255,163,0,88,0,21,0,87,0,178,255,25,253,128,255,224,246,21,255,25,253,178,240,179,254,64,4,61,255,90,255,14,3,137,255,65,243,92,2,107,8,254,254,254,250,127,255,43,0,252,235,40,254,173,2,93,200,242,250,157,255,126,248,228,254,90,254,168,251,134,243,71,248,168,5,93,254,252,227,20,0,186,255,54,8,0,0,22,1,90,7,235,216,76,6,132,23,71,0,115,255,3,4,213,255,160,252,64,254,247,172,176,254,214,247,87,20,162,2,210,2,6,4,87,5,171,7,169,23,216,3,193,251,150,241,47,0,195,255,104,0,175,255,127,3,22,0,216,2,65,255,147,12,108,20,229,255,222,252,158,5,190,220,184,250,187,253,144,3,104,253,233,255,246,253,112,252,178,0,165,253,59,2,62,2,150,1,52,2,175,0,107,254,107,244,208,251,213,6,67,252,110,254,215,36,113,6,103,254,35,1,133,22,40,3,98,26,215,2,219,255,2,255,250,5,213,0,181,12,101,1,115,1,45,0,4,251,112,207,239,10,124,248,80,255,173,251,73,255,198,0,78,14,20,0,114,251,203,9,100,242,185,252,135,61,0,0,64,62,246,40,220,62,186,73,44,63,206,25,97,63,39,49,136,63,112,206,160,63,14,190,184,63,220,215,209,63,30,167,232,63,131,47,0,64,94,75,12,64,94,75,24,64,94,75,36,64,166,155,48,64,200,7,61,64,62,232,89,62,96,118,207,62,43,246,7,63,65,241,35,63,154,153,73,63,215,163,96,63,154,119,140,63,165,189,169,63,215,52,199,63,121,233,214,63,60,189,234,63,227,165,7,64,122,165,20,64,99,127,29,64,76,55,41,64,196,66,57,64,242,65,79,62,104,34,172,62,52,128,247,62,159,171,45,63,30,167,104,63,72,225,138,63,163,1,156,63,38,228,179,63,9,27,206,63,232,106,227,63,38,228,251,63,190,48,9,64,74,12,22,64,34,253,34,64,172,139,47,64,227,165,59,64,106,222,241,61,158,94,105,62,19,242,225,62,182,132,28,63,66,96,69,63,202,84,113,63,27,158,142,63,76,166,162,63,27,158,190,63,192,236,222,63,204,238,249,63,229,97,9,64,193,57,23,64,23,217,34,64,218,172,46,64,121,233,58,64,68,139,236,61,150,67,139,62,199,41,250,62,32,99,46,63,163,1,92,63,207,102,133,63,203,161,157,63,79,175,180,63,185,141,206,63,240,167,230,63,4,231,252,63,187,39,11,64,132,13,23,64,156,162,35,64,32,210,47,64,93,254,59,64,248,83,227,61,12,147,169,62,152,110,242,62,206,170,15,63,157,128,54,63,160,137,80,63,127,251,130,63,78,98,168,63,193,202,201,63,24,38,227,63,21,140,250,63,249,15,9,64,166,155,20,64,37,117,34,64,7,240,46,64,156,162,59,64,12,147,41,62,31,133,171,62,217,206,215,62,36,151,15,63,200,7,45,63,67,173,89,63,231,251,145,63,56,103,180,63,148,135,205,63,217,206,215,63,122,199,225,63,202,50,0,64,233,38,17,64,133,124,32,64,179,123,46,64,136,244,59,64,79,30,22,62,254,67,186,62,186,218,234,62,32,65,17,63,31,244,60,63,41,237,93,63,20,63,118,63,239,56,149,63,211,188,187,63,100,59,223,63,238,124,247,63,228,131,6,64,63,87,19,64,100,204,33,64,252,24,47,64,57,69,59,64,245,74,217,61,19,97,131,62,5,163,242,62,91,211,44,63,105,0,95,63,222,2,137,63,229,208,162,63,129,149,187,63,68,139,212,63,36,185,236,63,35,219,1,64,145,15,14,64,181,166,25,64,57,214,37,64,165,189,49,64,25,226,60,64,138,142,228,61,215,18,114,62,177,80,203,62,138,176,33,63,140,185,91,63,186,73,132,63,175,148,149,63,254,67,170,63,103,213,199,63,91,211,228,63,171,207,253,63,255,33,13,64,176,3,23,64,170,241,34,64,127,251,46,64,188,116,59,64,66,62,136,62,189,82,214,62,193,57,3,63,171,207,37,63,165,189,97,63,66,96,141,63,111,129,164,63,161,214,180,63,143,228,202,63,190,48,225,63,165,78,248,63,171,62,11,64,222,147,23,64,211,222,32,64,50,85,44,64,117,2,58,64,135,22,25,62,177,191,140,62,183,209,224,62,229,97,33,63,28,235,82,63,26,81,130,63,55,137,153,63,126,29,176,63,46,144,200,63,115,215,226,63,239,201,251,63,201,118,10,64,77,243,22,64,19,97,35,64,227,165,47,64,36,151,59,64,17,199,186,61,33,31,52,62,173,250,156,62,96,229,16,63,145,237,76,63,216,240,116,63,25,115,151,63,181,166,185,63,126,29,208,63,2,188,229,63,36,185,0,64,20,208,12,64,183,98,23,64,48,187,35,64,224,190,50,64,211,77,62,64,21,140,10,62,122,165,140,62,41,203,208,62,222,2,25,63,120,11,68,63,12,147,105,63,57,214,141,63,201,118,174,63,51,51,203,63,13,113,228,63,155,85,247,63,243,142,7,64,32,65,21,64,94,75,32,64,161,248,45,64,61,10,59,64,130,115,70,62,142,6,208,62,18,20,255,62,181,166,25,63,212,43,69,63,181,55,104,63,118,224,148,63,94,186,177,63,180,89,205,63,16,233,231,63,231,29,247,63,23,183,5,64,0,111,17,64,99,127,29,64,17,54,40,64,50,85,56,64,36,40,62,62,58,146,171,62,165,78,224,62,131,47,28,63,197,143,65,63,12,2,91,63,75,234,132,63,188,150,168,63,160,137,200,63,7,95,216,63,101,170,224,63,234,4,252,63,237,158,16,64,252,169,33,64,114,138,46,64,190,193,59,64,170,96,212,61,228,20,93,62,244,108,214,62,237,13,30,63,45,178,77,63,227,165,131,63,118,224,156,63,221,36,182,63,133,235,209,63,136,133,234,63,238,235,0,64,36,185,12,64,78,98,24,64,100,93,36,64,36,185,48,64,56,103,60,64,102,102,38,62,150,33,142,62,236,81,216,62,39,160,25,63,208,179,73,63,144,160,104,63,184,64,138,63,177,80,163,63,11,181,190,63,155,85,223,63,93,220,254,63,248,83,11,64,195,211,23,64,9,249,36,64,176,3,51,64,13,113,60,64,153,42,88,62,53,94,186,62,120,122,21,63,190,159,58,63,9,27,78,63,94,75,128,63,203,161,157,63,200,7,181,63,8,61,203,63,150,67,227,63,191,125,253,63,83,150,9,64,97,50,21,64,113,61,34,64,36,185,48,64,237,158,60,64,23,183,17,62,167,121,135,62,97,195,211,62,92,143,34,63,141,151,78,63,243,142,115,63,77,243,142,63,92,32,169,63,204,238,201,63,44,212,226,63,7,95,248,63,84,227,9,64,252,169,21,64,118,224,32,64,155,85,47,64,163,35,61,64,103,213,231,61,143,83,116,62,215,18,210,62,103,213,23,63,130,226,71,63,31,244,124,63,80,141,151,63,115,104,177,63,157,17,205,63,162,69,230,63,105,0,255,63,98,16,12,64,30,167,24,64,188,150,36,64,96,229,48,64,47,221,60,64,165,189,1,62,239,56,133,62,121,88,200,62,153,42,24,63,65,130,66,63,3,120,107,63,46,255,137,63,131,192,162,63,195,211,195,63,53,239,224,63,116,36,247,63,73,157,8,64,167,232,20,64,125,174,34,64,75,200,47,64,227,165,59,64,187,39,79,62,77,243,174,62,211,222,224,62,168,53,29,63,59,112,62,63,22,251,91,63,95,7,142,63,180,89,173,63,53,94,194,63,223,224,211,63,52,162,228,63,178,46,2,64,44,101,17,64,7,240,30,64,142,117,45,64,24,149,60,64,65,241,227,61,145,237,124,62,45,67,188,62,197,143,17,63,184,30,69,63,123,131,111,63,26,81,138,63,183,98,159,63,242,210,189,63,210,0,222,63,98,161,246,63,80,252,8,64,12,147,21,64,228,20,33,64,213,231,46,64,67,173,57,64,195,100,42,62,253,246,181,62,54,171,14,63,242,65,63,63,8,172,108,63,63,198,140,63,113,172,163,63,129,149,187,63,212,43,213,63,44,212,234,63,70,37,1,64,78,209,13,64,227,54,26,64,237,13,38,64,35,219,49,64,244,253,60,64,130,115,6,62,102,102,134,62,42,58,242,62,102,247,36,63,178,157,79,63,118,224,124,63,67,28,147,63,21,29,169,63,5,52,201,63,153,42,232,63,134,56,254,63,105,111,12,64,5,197,23,64,255,178,35,64,176,3,47,64,145,126,59,64,143,228,242,61,90,100,155,62,32,65,1,63,178,157,47,63,182,243,93,63,41,92,127,63,142,117,145,63,198,109,172,63,96,229,200,63,164,223,222,63,249,160,247,63,110,163,9,64,220,215,21,64,254,101,35,64,177,225,49,64,224,156,61,64,28,235,226,61,30,22,138,62,43,24,245,62,10,104,34,63,108,120,74,63,207,102,117,63,152,110,146,63,216,240,172,63,227,199,200,63,245,74,225,63,75,89,246,63,65,241,7,64,64,19,21,64,250,126,34,64,229,208,46,64,48,187,59,64,94,186,201,61,140,185,107,62,235,115,181,62,47,110,19,63,111,18,67,63,203,16,119,63,95,41,147,63,139,108,167,63,102,102,198,63,127,106,228,63,149,212,249,63,252,24,11,64,229,208,22,64,137,65,36,64,8,172,48,64,184,64,58,64,254,101,247,61,86,159,139,62,165,78,224,62,115,215,18,63,173,250,60,63,180,200,86,63,60,78,129,63,247,228,161,63,174,71,193,63,100,59,223,63,138,31,251,63,233,38,9,64,48,42,21,64,129,4,33,64,86,125,46,64,77,243,58,64,46,255,33,62,178,46,142,62,184,30,229,62,162,180,39,63,250,237,91,63,64,19,129,63,101,25,146,63,243,31,170,63,172,139,203,63,61,44,228,63,129,38,250,63,27,158,10,64,242,176,20,64,23,72,32,64,78,98,44,64,164,223,58,64,150,67,11,62,252,24,147,62,131,192,234,62,233,38,33,63,238,90,66,63,172,173,104,63,48,76,134,63,127,251,162,63,59,1,197,63,47,110,227,63,43,246,247,63,111,129,8,64,116,70,20,64,147,24,32,64,130,226,43,64,138,142,56,64,235,115,181,61,35,74,59,62,54,60,189,62,91,211,28,63,180,89,85,63,94,186,129,63,120,122,157,63,195,211,187,63,118,79,214,63,132,158,237,63,90,100,3,64,2,43,15,64,16,88,25,64,108,9,37,64,110,163,49,64,71,3,60,64,223,79,77,62,43,24,181,62,215,163,240,62,114,249,31,63,86,14,61,63,25,226,104,63,228,131,150,63,227,199,176,63,234,4,196,63,242,210,213,63,136,99,237,63,152,221,7,64,157,17,21,64,61,155,33,64,235,226,50,64,2,188,61,64,150,178,76,62,155,85,159,62,51,196,241,62,7,240,54,63,120,11,100,63,192,91,128,63,210,111,151,63,90,245,177,63,102,102,206,63,224,45,224,63,45,67,244,63,185,252,7,64,53,239,20,64,107,43,34,64,176,114,44,64,64,19,57,64,0,145,254,61,93,109,133,62,192,91,224,62,143,194,21,63,125,63,69,63,222,2,121,63,9,138,143,63,187,39,167,63,88,202,194,63,251,203,222,63,31,244,244,63,193,168,8,64,50,119,21,64,226,233,33,64,5,163,46,64,3,9,58,64,134,201,212,61,34,108,120,62,53,94,218,62,211,222,32,63,242,176,80,63,86,125,126,63,181,166,153,63,184,175,179,63,113,172,203,63,204,93,227,63,31,133,251,63,42,58,10,64,205,59,22,64,138,31,35,64,74,123,47,64,42,169,59,64,113,172,11,62,217,206,119,62,148,246,198,62,79,30,22,63,61,44,68,63,10,104,98,63,12,2,139,63,99,127,169,63,98,161,198,63,200,7,229,63,142,6,0,64,46,255,9,64,95,41,23,64,106,77,35,64,97,50,49,64,39,194,58,64,245,219,23,62,161,248,145,62,38,83,229,62,83,150,33,63,186,218,74,63,232,106,123,63,242,210,149,63,63,87,171,63,205,204,196,63,40,126,220,63,223,224,243,63,168,87,6,64,21,140,18,64,255,178,31,64,205,204,44,64,206,136,58,64,251,203,110,62,240,133,233,62,81,107,10,63,247,6,31,63,73,157,64,63,211,77,82,63,97,195,115,63,104,145,149,63,202,195,194,63,35,74,219,63,243,31,234,63,11,36,4,64,139,253,17,64,181,21,31,64,32,65,45,64,254,101,59,64,3,9,10,62,27,13,160,62,24,149,4,63,126,29,56,63,17,54,108,63,71,114,145,63,32,65,169,63,118,224,188,63,177,80,211,63,69,216,232,63,130,226,255,63,122,165,12,64,20,208,24,64,75,234,36,64,117,147,48,64,6,18,60,64,174,216,223,61,10,104,98,62,152,221,243,62,200,152,43,63,234,4,84,63,33,31,116,63,183,98,143,63,188,150,176,63,180,89,205,63,251,203,230,63,127,217,253,63,254,67,10,64,50,230,22,64,120,122,37,64,195,245,48,64,96,118,59,64,219,249,62,62,127,251,154,62,250,126,234,62,163,1,44,63,61,10,87,63,179,12,129,63,50,85,152,63,220,104,176,63,2,188,197,63,197,32,216,63,60,78,249,63,161,214,8,64,155,230,17,64,36,185,32,64,168,198,47,64,230,63,60,64,174,71,33,62,229,242,159,62,95,7,238,62,165,78,32,63,100,59,79,63,100,93,124,63,235,115,149,63,9,27,174,63,208,68,200,63,179,12,225,63,113,61,250,63,196,177,10,64,29,56,23,64,150,178,36,64,135,22,49,64,238,235,60,64,105,111,240,61,178,46,142,62,224,190,238,62,243,31,34,63,92,32,81,63,147,58,129,63,197,32,152,63,217,61,177,63,69,71,202,63,167,232,224,63,98,16,248,63,124,242,8,64,127,217,21,64,212,154,34,64,160,26,47,64,0,0,60,64,26,192,219,61,103,213,103,62,179,12,209,62,167,232,24,63,155,85,63,63,243,142,115,63,103,68,145,63,174,182,170,63,219,138,197,63,237,13,222,63,98,16,248,63,190,48,9,64,188,5,22,64,159,205,34,64,140,185,47,64,27,13,60,64,153,187,22,62,188,116,147,62,207,102,245,62,247,117,32,63,27,47,77,63,112,206,128,63,182,243,149,63,169,164,174,63,82,184,198,63,23,217,222,63,157,128,246,63,81,218,7,64,209,145,20,64,31,244,32,64,72,191,45,64,186,218,58,64,41,203,16,62,248,83,131,62,54,171,222,62,13,113,28,63,244,253,68,63,252,24,115,63,123,131,143,63,193,202,169,63,88,202,194,63,116,70,220,63,90,100,243,63,67,173,5,64,17,54,20,64,40,126,32,64,140,74,46,64,94,75,60,64], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+440320);
/* memory initializer */ allocate([110,52,0,62,231,140,136,62,120,11,228,62,52,162,36,63,48,76,86,63,83,150,129,63,12,2,155,63,125,63,181,63,59,223,207,63,99,127,233,63,1,77,0,64,52,162,12,64,9,249,24,64,173,250,36,64,118,224,48,64,172,173,60,64,57,69,7,62,248,83,131,62,75,234,196,62,230,174,21,63,46,255,65,63,200,7,109,63,82,39,136,63,193,168,156,63,49,8,188,63,95,7,222,63,205,204,252,63,120,11,12,64,190,193,23,64,242,65,35,64,141,151,46,64,47,221,56,64,24,38,19,62,25,4,150,62,174,182,226,62,246,151,29,63,182,243,77,63,153,187,118,63,92,143,146,63,153,42,168,63,220,215,193,63,221,36,222,63,5,52,249,63,78,209,9,64,127,217,21,64,143,228,34,64,40,15,47,64,211,188,59,64,196,66,45,62,242,210,141,62,175,37,196,62,246,40,28,63,236,81,72,63,150,33,110,63,254,212,136,63,190,193,159,63,111,18,187,63,247,6,215,63,223,79,245,63,45,33,11,64,231,251,21,64,205,59,34,64,197,32,48,64,169,164,58,64,145,237,252,61,164,223,126,62,192,236,222,62,124,97,34,63,115,215,82,63,69,216,128,63,34,108,152,63,154,119,172,63,149,101,200,63,133,235,233,63,207,247,3,64,165,78,16,64,201,118,26,64,220,215,37,64,189,227,48,64,211,188,59,64,100,59,223,61,112,206,72,62,38,83,197,62,19,242,17,63,125,208,51,63,124,97,98,63,149,212,145,63,176,114,176,63,49,8,204,63,54,205,227,63,140,219,248,63,209,34,11,64,193,168,24,64,124,242,36,64,235,115,49,64,202,50,60,64,119,190,31,62,188,5,178,62,23,72,0,63,124,242,32,63,1,222,66,63,109,86,125,63,248,83,147,63,168,198,171,63,104,145,197,63,171,62,215,63,190,193,239,63,153,42,4,64,36,185,16,64,93,254,31,64,9,249,44,64,22,106,57,64,207,102,21,62,254,101,119,62,230,63,196,62,31,133,11,63,76,166,74,63,218,27,108,63,62,121,136,63,151,255,152,63,58,146,179,63,79,175,212,63,199,75,247,63,109,86,9,64,159,171,21,64,182,132,32,64,123,131,43,64,23,217,58,64,118,79,30,62,38,83,197,62,118,79,30,63,117,147,88,63,206,170,135,63,18,20,159,63,46,255,177,63,61,10,199,63,0,145,222,63,250,126,242,63,69,216,4,64,57,69,15,64,138,176,25,64,18,131,36,64,62,121,48,64,246,40,60,64,27,47,221,61,159,60,108,62,206,136,210,62,177,80,27,63,143,194,69,63,238,90,114,63,176,114,144,63,37,6,169,63,84,116,196,63,44,101,225,63,144,49,255,63,234,4,12,64,99,238,22,64,199,75,35,64,215,18,46,64,226,233,57,64,190,193,23,62,174,182,162,62,45,33,255,62,238,90,34,63,171,62,71,63,145,237,124,63,220,215,153,63,58,146,171,63,186,218,194,63,136,99,221,63,155,230,245,63,3,9,6,64,60,189,18,64,27,13,32,64,159,171,45,64,154,8,59,64,250,126,234,61,244,253,148,62,81,107,250,62,249,49,38,63,142,6,80,63,207,247,115,63,160,26,143,63,78,98,168,63,242,176,192,63,251,58,216,63,62,232,241,63,107,154,7,64,138,176,21,64,220,70,35,64,159,205,46,64,154,8,59,64,165,78,192,61,31,244,44,62,102,102,166,62,116,70,20,63,157,17,69,63,8,172,108,63,175,37,148,63,213,120,177,63,116,70,204,63,9,27,230,63,116,181,253,63,122,199,9,64,82,73,21,64,188,116,35,64,214,86,48,64,224,190,58,64,0,145,254,61,109,86,125,62,140,219,200,62,196,177,30,63,222,113,74,63,55,26,112,63,95,41,147,63,146,203,175,63,25,115,199,63,219,249,222,63,101,25,250,63,47,221,8,64,106,188,20,64,214,197,33,64,88,202,46,64,60,189,58,64,112,206,72,62,201,229,191,62,111,129,4,63,216,129,35,63,92,32,81,63,9,27,134,63,236,47,155,63,240,133,177,63,48,187,199,63,225,122,220,63,137,65,240,63,87,91,5,64,170,241,18,64,193,168,32,64,176,114,44,64,128,183,56,64,166,155,4,62,52,17,118,62,198,109,212,62,59,112,30,63,163,146,74,63,94,186,105,63,76,166,138,63,113,172,163,63,63,53,190,63,154,8,219,63,39,160,249,63,144,160,8,64,51,196,17,64,130,226,31,64,243,142,47,64,216,240,60,64,111,18,131,60,116,70,20,61,192,236,30,60,17,199,186,59,52,128,183,186,215,52,239,187,153,187,150,187,23,183,209,187,20,63,70,188,108,9,249,58,33,31,116,60,88,57,52,189,202,50,68,189,154,119,28,189,166,155,68,189,43,24,149,188,150,67,139,60,17,199,58,60,33,31,244,188,41,92,143,188,208,68,88,187,151,255,16,189,96,229,80,189,10,215,35,187,145,126,251,60,5,197,15,61,222,113,10,61,49,8,44,61,101,25,98,60,41,92,143,188,231,29,39,188,159,171,173,59,39,160,9,60,82,73,157,185,85,193,40,61,124,242,48,187,104,145,109,60,36,151,127,187,185,252,7,60,10,215,35,61,23,183,209,56,98,161,214,188,88,57,180,59,75,89,6,188,114,138,14,61,87,91,49,61,247,117,96,60,82,73,29,187,88,57,180,187,98,161,214,60,207,102,85,61,77,243,14,61,80,141,151,60,108,9,249,59,147,169,2,189,29,201,101,189,127,106,60,189,242,65,207,188,192,236,30,188,148,135,133,60,153,187,150,60,179,123,114,187,166,155,68,189,43,246,23,189,73,157,128,61,39,49,136,61,179,123,242,60,17,199,186,187,242,65,207,60,90,245,185,60,41,92,15,61,187,184,141,61,100,59,95,61,234,149,178,60,117,2,26,60,16,233,55,189,7,95,24,189,111,18,3,58,134,90,211,60,202,84,65,60,213,120,233,60,227,165,155,61,121,88,168,61,245,219,87,61,216,240,244,188,46,144,160,187,150,67,139,60,119,190,159,60,137,210,94,60,140,74,234,60,177,191,236,60,211,188,99,60,124,242,176,59,108,9,121,60,130,226,199,60,52,128,55,59,52,128,183,187,244,253,212,188,145,126,251,60,140,74,106,61,114,138,14,188,224,45,16,60,95,41,203,59,0,0,0,0,205,204,76,60,0,0,0,0,215,52,239,188,158,239,167,61,234,149,178,61,1,77,132,61,187,184,13,61,108,9,249,59,224,45,16,187,242,65,207,188,66,62,104,189,117,2,154,188,39,160,9,189,149,212,137,189,211,222,96,189,185,252,135,188,61,44,212,188,66,96,101,188,111,18,131,59,237,13,62,187,197,32,48,189,99,127,89,189,242,65,207,188,108,9,249,186,30,167,232,187,9,249,32,61,250,237,235,59,111,240,5,189,202,84,193,188,18,131,192,188,151,255,144,188,7,95,152,188,66,96,229,188,193,168,164,188,72,80,252,187,118,224,28,61,122,54,43,61,74,123,3,61,69,216,240,60,222,113,138,60,91,177,63,61,70,148,246,60,62,232,89,60,79,175,20,61,134,90,83,61,201,229,191,61,182,243,253,61,5,197,15,62,20,174,7,62,32,65,241,61,95,152,204,61,132,158,205,60,179,123,114,187,131,192,74,189,114,249,143,189,161,103,179,188,171,207,213,188,108,9,249,188,231,29,167,188,7,95,24,189,115,104,17,61,98,161,86,60,7,95,24,188,156,51,34,188,101,25,226,187,137,210,94,187,244,253,212,187,195,100,170,188,54,60,189,188,91,177,63,188,232,217,172,188,203,16,199,188,153,187,150,59,14,79,47,188,66,96,229,187,240,133,73,60,127,106,188,60,108,9,121,60,75,89,134,60,85,193,40,61,219,138,125,61,233,183,175,61,160,137,176,61,52,128,183,187,205,204,76,60,43,24,149,60,150,33,14,61,192,236,30,61,17,199,58,61,11,181,38,61,22,251,203,188,127,106,60,189,85,193,168,60,216,240,244,60,242,65,207,60,12,147,169,60,151,255,144,60,56,248,194,60,242,65,207,60,166,155,68,59,39,160,137,59,111,18,3,59,221,181,4,188,137,210,94,188,104,145,237,188,39,160,137,187,130,226,71,60,231,29,167,59,14,79,47,60,17,199,186,60,232,217,172,60,137,210,222,187,234,149,50,189,216,240,244,188,36,151,255,187,9,138,159,189,31,244,236,189,40,15,139,189,4,231,140,60,143,194,117,60,231,29,167,187,221,181,4,60,23,183,81,189,72,80,124,189,250,237,107,61,156,162,163,61,84,116,164,61,39,160,9,61,23,183,209,56,33,31,244,188,80,252,152,189,127,106,60,188,120,122,37,188,150,67,139,188,10,215,163,187,114,138,142,60,104,145,237,188,107,43,118,189,143,194,117,188,20,63,70,60,2,43,135,60,127,106,188,60,52,128,55,59,220,215,1,189,2,43,135,188,78,209,17,61,199,186,56,61,166,155,68,60,74,123,3,61,39,160,9,60,237,13,190,187,130,226,71,60,221,36,70,62,89,134,56,62,156,196,96,62,180,200,118,62,229,97,97,62,147,24,68,62,127,106,60,62,221,36,70,62,120,156,98,62,189,227,84,62,91,66,62,62,58,35,74,62,11,70,101,62,228,131,94,62,127,106,60,62,135,22,89,62,145,126,251,62,24,149,244,62,223,224,235,62,37,6,225,62,120,156,226,62,101,170,224,62,101,25,226,62,201,118,222,62,108,9,217,62,72,191,221,62,194,134,231,62,37,117,226,62,184,30,229,62,73,157,224,62,20,174,231,62,156,162,227,62,93,207,133,1,149,3,214,4,142,253,120,252,171,248,24,9,248,205,191,250,150,1,80,0,127,1,255,240,164,4,117,252,65,9,159,203,183,43,13,246,236,253,250,2,165,249,168,2,255,246,213,252,162,251,160,12,85,13,38,248,59,254,96,229,252,239,107,6,201,43,165,3,32,247,160,5,95,246,50,229,186,0,27,6,236,222,216,248,114,251,172,253,186,254,105,0,141,255,160,254,144,253,133,123,129,0,211,254,153,253,199,254,80,255,108,2,251,255,182,250,21,242,166,2,211,254,109,2,136,3,255,252,222,250,68,252,10,247,150,254,125,1,162,246,189,66,100,0,122,15,194,252,17,73,237,0,240,250,206,13,172,5,3,1,154,6,222,243,216,241,196,254,240,255,12,23,147,8,16,252,255,55,93,55,155,249,106,4,86,4,243,1,20,250,244,1,48,253,18,254,14,252,16,251,251,252,109,5,212,0,100,31,12,3,96,2,97,254,163,3,211,254,118,247,208,8,62,253,172,50,123,242,145,241,25,8,48,245,11,250,141,226,71,254,15,253,206,17,21,224,41,249,27,229,237,15,58,26,53,0,66,4,66,244,104,14,118,251,197,255,46,1,160,3,62,254,238,0,57,42,97,1,186,2,36,254,172,0,106,247,231,238,162,226,69,6,204,24,27,20,91,255,165,0,49,254,163,255,227,4,159,2,75,2,110,254,29,255,50,254,200,146,215,0,200,255,66,252,111,253,252,1,98,0,5,245,93,250,4,12,74,24,224,217,31,215,254,252,89,1,4,12,140,255,188,244,167,8,164,245,26,5,78,10,132,255,195,254,110,1,181,5,217,254,209,19,204,1,128,7,184,47,136,228,160,26,221,11,186,245,193,251,221,250,123,0,186,253,167,247,197,19,35,1,204,6,42,255,128,7,114,242,143,42,19,37,230,13,24,251,64,254,192,215,169,246,98,7,228,1,49,43,236,25,166,1,12,9,129,249,164,254,121,2,176,4,252,6,156,251,141,160,140,0,101,3,226,2,223,0,107,250,90,2,177,1,60,255,153,251,111,248,145,252,202,254,204,253,254,3,228,238,79,28,158,240,109,17,171,8,239,222,50,36,44,238,159,243,121,242,35,254,237,2,156,9,248,252,38,1,85,255,48,4,212,6,232,3,48,255,116,7,26,252,150,248,11,215,56,9,82,209,148,246,207,245,45,15,78,245,68,5,209,253,194,250,150,36,24,6,208,252,154,4,86,1,81,255,6,5,198,11,145,41,246,0,56,12,218,25,207,254,154,42,215,24,213,238,135,5,196,0,128,43,236,6,25,244,241,12,49,251,74,248,51,244,56,250,191,250,194,252,15,6,217,9,6,254,141,30,35,30,214,19,23,32,54,8,16,6,199,8,182,14,170,243,237,248,119,2,140,15,115,254,70,35,13,251,74,248,3,6,152,254,197,254,28,3,115,237,28,8,7,252,205,2,242,8,204,43,149,36,90,6,123,1,12,8,49,5,4,0,231,255,188,250,54,2,14,251,134,6,118,8,67,51,42,0,112,9,134,247,20,231,172,0,60,1,40,0,44,1,25,254,146,1,36,255,78,3,130,252,123,250,77,247,170,7,22,76,92,198,41,56,186,253,254,252,70,255,16,252,16,250,46,253,139,252,62,10,55,1,15,253,224,1,27,2,13,252,44,249,192,252,165,253,33,248,101,3,244,197,168,253,62,8,228,1,14,233,252,5,218,12,34,255,194,237,223,255,230,252,243,247,95,251,160,255,81,1,3,2,161,248,26,0,59,79,57,254,225,252,194,255,197,251,236,0,71,249,199,253,21,251,105,1,66,4,30,255,200,5,55,52,130,253,172,3,152,14,19,25,149,232,62,3,57,230,197,17,47,6,215,220,80,4,255,250,10,251,162,255,80,4,228,247,140,2,215,8,185,5,231,255,86,35,53,224,170,245,112,204,234,253,116,196,88,250,146,250,196,1,72,2,198,254,88,251,183,3,117,3,140,1,8,3,23,5,18,5,64,254,127,128,22,255,194,255,31,0,92,255,238,251,174,255,230,255,240,254,209,253,92,255,157,2,12,254,4,2,67,5,143,37,99,4,190,250,150,248,149,32,169,214,238,8,143,235,223,5,198,1,24,248,152,16,6,247,187,247,78,52,175,252,30,8,72,4,117,253,56,208,138,254,212,252,111,241,195,252,112,255,189,4,43,254,88,4,122,4,48,3,50,3,112,252,57,252,139,3,12,0,139,9,9,253,215,248,82,255,186,252,232,1,232,249,190,184,210,253,134,21,220,250,222,6,117,15,38,228,142,250,98,19,30,15,141,248,225,219,169,8,216,240,195,238,101,7,243,243,54,255,87,2,27,5,38,6,210,251,223,245,94,245,34,37,70,216,81,4,15,19,160,8,38,0,220,21,154,232,123,243,35,0,189,36,37,255,106,2,28,5,97,1,129,13,176,6,205,2,119,205,25,0,128,8,226,245,57,251,16,2,38,5,236,17,254,29,111,22,18,223,121,238,84,5,146,31,65,249,125,254,213,1,100,12,145,1,45,245,182,2,218,56,26,247,56,14,180,212,156,3,175,253,255,240,14,239,227,0,238,2,158,11,238,244,27,249,85,8,99,251,29,20,238,45,173,46,210,13,138,9,241,10,177,5,202,252,165,242,92,246,191,0,122,253,49,252,9,251,64,3,16,12,17,254,218,216,25,7,39,5,144,252,62,5,88,250,243,241,18,243,49,34,95,255,106,230,142,5,128,253,4,254,22,45,235,254,91,255,69,3,221,28,82,252,1,43,159,255,12,6,138,5,67,254,57,8,78,252,28,222,154,20,138,34,64,2,144,250,55,249,4,251,115,21,56,1,40,14,246,10,109,8,231,253,120,6,190,7,236,250,110,255,207,1,240,1,152,65,116,255,37,249,192,252,181,247,113,254,179,22,66,253,75,11,210,241,205,248,90,1,252,1,148,254,14,254,210,253,48,125,24,253,90,0,140,254,174,1,192,2,103,3,139,0,4,3,184,2,148,255,238,255,54,1,101,254,226,252,209,1,91,255,191,254,233,2,43,147,16,253,243,1,41,255,172,0,35,0,60,255,254,252,18,1,222,253,160,255,42,254,240,220,196,35,69,2,136,3,220,237,135,225,197,13,161,253,44,25,218,15,72,253,173,251,136,253,195,5,196,0,91,252,115,3,77,4,22,1,177,1,32,2,15,254,4,0,166,248,224,5,82,2,78,137,218,0,211,0,82,3,35,252,63,1,157,252,214,255,242,2,242,1,186,255,206,253,148,2,215,210,54,0,35,3,169,1,198,3,7,252,56,251,170,206,42,7,215,255,98,0,197,251,180,13,214,6,41,249,72,0,9,254,218,255,195,86,252,0,88,0,221,0,178,2,82,0,196,250,252,1,126,2,64,3,226,1,51,0,18,31,142,10,104,251,126,34,201,254,232,9,72,232,205,239,114,20,238,1,99,255,247,250,210,233,175,249,228,5,116,255,201,255,201,2,184,1,185,128,105,0,118,254,155,253,52,252,66,2,98,4,224,255,114,0,28,255,86,1,43,251,99,4,102,4,68,255,150,255,44,44,53,241,51,2,95,13,58,217,87,6,9,246,88,250,227,239,150,3,170,250,36,254,190,255,4,0,249,2,164,0,195,255,221,79,238,0,40,1,236,1,154,251,158,255,79,251,14,0,208,248,159,252,154,4,155,252,105,0,139,3,248,0,2,6,174,11,171,45,103,30,30,6,208,229,93,9,82,2,223,248,129,254,168,16,119,7,212,1,250,3,92,253,140,245,180,225,193,245,209,41,150,10,114,224,120,235,163,6,204,247,157,254,218,247,76,42,99,2,18,0,194,252,210,3,171,239,44,5,114,235,185,254,4,7,207,217,26,5,114,248,30,221,48,37,196,246,99,240,31,216,74,231,114,5,34,249,100,3,168,4,156,244,233,255,206,249,216,254,182,1,233,254,165,200,238,249,50,255,79,9,250,1,157,4,106,32,21,254,45,245,66,239,52,228,112,249,250,1,193,6,91,205,99,252,39,252,164,1,46,249,245,254,34,254,13,210,250,251,187,0,218,240,236,5,168,9,141,254,29,0,41,3,92,249,104,255,48,2,41,7,61,56,200,3,160,255,86,243,63,246,180,255,48,8,121,37,80,251,190,1,225,5,122,31,186,6,245,1,155,3,109,251,212,218,24,246,200,28,254,255,72,235,120,246,160,254,254,1,64,1,45,1,120,0,175,2,82,252,137,0,56,3,196,254,32,5,254,1,147,251,200,148,108,254,17,4,16,1,8,198,175,250,189,49,30,3,16,254,155,6,124,249,62,249,160,3,95,243,82,1,190,253,156,0,16,3,237,252,14,255,150,253,171,252,254,250,10,210,130,15,146,47,14,248,244,0,173,242,44,1,159,0,166,13,12,244,77,250,76,246,72,214,240,2,227,0,180,249,102,252,219,253,158,0,212,8,40,226,129,238,21,240,148,246,229,225,88,2,186,207,93,0,126,249,229,252,252,204,61,0,255,1,202,247,182,247,108,1,99,255,6,9,240,249,236,4,158,0,31,37,138,27,7,0,242,232,70,228,188,1,152,14,212,248,37,12,232,246,201,1,153,252,185,254,244,252,149,2,236,33,226,9,244,254,186,3,100,5,251,251,162,1,120,255,69,242,161,7,104,249,81,222,36,243,78,30,236,10,123,45,93,252,11,254,151,252,68,254,194,250,180,201,10,255,229,254,13,249,230,3,218,250,152,1,225,5,50,254,171,41,235,248,78,0,126,191,104,1,19,248,174,3,138,6,171,0,61,1,244,0,159,4,212,2,248,2,98,6,95,3,25,3,126,0,186,254,212,3,139,253,203,86,119,253,250,4,205,2,75,5,195,248,0,249,7,252,200,247,0,253,84,249,254,8,49,9,159,43,238,41,172,242,38,247,75,0,152,255,169,1,144,252,24,8,118,11,94,252,14,1,146,246,99,252,255,3,22,253,20,255,172,249,57,3,44,5,155,255,108,180,245,250,73,2,117,8,75,11,78,14,191,253,8,7,152,1,50,250,107,0,95,1,193,254,80,4,188,3,147,1,116,2,235,254,199,255,170,3,0,128,185,255,71,254,48,255,224,255,191,0,58,1,85,255,101,2,237,2,76,3,40,254,68,254,184,3,42,0,166,224,160,10,119,7,36,245,23,48,134,255,241,13,165,255,160,23,248,252,158,6,193,255,8,251,253,13,86,6,234,9,190,0,204,204,204,252,16,244,165,4,108,250,12,255,16,253,213,231,111,242,71,253,88,5,19,4,22,30,96,1,116,255,57,205,176,255,128,49,63,250,41,12,225,5,155,2,88,9,231,6,25,2,157,7,145,2,126,255,212,3,207,6,77,32,76,9,249,246,197,0,117,253,227,9,41,2,163,251,116,254,216,1,213,17,128,206,18,9,152,254,34,206,157,8,165,245,62,214,38,255,74,2,109,20,34,0,59,0,194,6,202,4,58,8,168,15,170,248,208,218,170,250,106,251,222,254,243,251,106,6,210,4,49,1,1,251,126,253,102,4,113,204,227,255,130,2,112,11,144,7,252,254,76,2,170,45,66,36,222,242,52,30,49,4,178,10,80,18,29,250,75,250,33,247,149,251,177,7,152,247,101,6,250,252,66,0,90,251,50,255,21,254,200,251,132,2,134,254,111,1,60,70,209,249,114,8,150,3,135,255,80,254,115,0,5,0,23,3,176,7,17,247,218,249,183,218,138,43,212,13,164,237,253,253,60,238,113,3,79,2,20,4,253,254,46,252,2,0,232,0,10,3,58,255,119,251,134,254,173,255,165,1,26,1,196,103,223,252,164,249,65,248,211,254,163,3,118,3,148,8,173,5,240,2,140,11,106,242,234,1,116,250,247,51,13,5,6,219,206,1,227,205,122,43,125,31,81,2,113,14,157,253,234,253,70,253,132,251,62,6,37,1,42,253,70,253,33,1,180,0,108,3,143,254,213,255,234,0,131,171,88,250,15,253,32,254,188,3,226,3,19,2,108,252,118,2,208,2,4,247,184,218,118,250,225,3,82,8,201,246,156,9,173,254,235,254,41,6,174,47,77,242,0,251,146,7,103,3,198,248,215,252,220,242,6,27,110,4,146,19,68,34,55,8,209,217,132,250,28,20,42,250,13,6,225,6,212,252,142,2,157,253,54,3,27,255,128,254,226,40,175,254,159,8,131,0,2,11,147,244,210,242,174,221,152,222,22,247,88,0,222,251,123,33,84,11,239,253,223,249,90,7,43,252,204,0,139,11,125,239,100,16,31,244,52,42,30,7,82,0,144,7,76,9,192,50,229,233,135,242,49,5,124,249,11,5,66,249,136,32,58,1,177,10,91,253,80,9,114,252,146,252,175,2,128,2,47,253,112,252,28,206,225,247,114,254,4,249,44,246,249,221,242,251,39,252,17,228,159,220,122,3,203,1,214,254,150,3,179,216,80,3,52,253,30,7,68,3,212,218,39,252,157,250,103,254,67,247,12,4,198,251,88,249,53,5,104,250,199,44,205,246,169,232,118,249,128,253,214,253,160,32,172,10,125,235,147,16,158,254,78,14,176,253,155,219,75,251,196,251,29,252,24,44,206,247,172,249,63,9,250,250,64,235,192,255,28,2,233,246,113,245,35,248,55,222,230,250,76,252,163,5,152,2,96,9,98,18,221,15,131,1,236,255,67,7,67,36,1,185,38,3,135,250,229,4,84,2,128,8,110,249,161,8,221,2,124,5,4,230,194,10,182,3,42,9,45,14,37,229,205,19,170,219,192,5,174,3,160,4,64,215,192,3,147,15,193,7,165,1,44,1,52,253,170,3,244,1,96,255,226,0,169,255,144,249,191,248,71,248,189,254,1,9,237,201,204,239,94,244,54,21,162,242,142,251,158,247,12,6,106,250,222,2,173,254,150,33,40,238,16,254,221,1,105,19,33,10,26,11,197,33,195,246,225,226,129,245,249,0,92,29,203,255,219,0,115,4,100,253,54,2,246,253,9,5,33,0,115,255,104,252,222,9,19,245,72,64,48,248,10,253,62,255,232,42,187,0,150,6,65,237,199,37,46,7,56,251,45,5,144,2,198,234,135,12,21,7,41,7,39,56,227,47,161,255,232,253,46,249,16,242,70,254,196,3,64,250,65,5,132,10,179,253,8,2,104,2,101,1,70,1,173,250,187,111,188,2,217,1,116,252,151,251,22,4,82,4,41,254,40,254,44,252,29,0,62,2,162,254,223,253,183,253,112,248,23,1,114,3,144,252,204,255,168,136,115,1,102,255,5,251,134,248,104,0,146,255,98,4,49,253,217,2,25,253,104,1,254,2,198,0,102,210,100,2,150,214,133,4,186,0,196,243,254,11,255,5,155,0,6,3,40,219,102,19,195,229,64,1,47,20,112,0,167,10,220,43,88,5,72,7,173,4,17,250,224,5,199,69,49,0,164,8,99,2,4,249,116,11,139,1,32,0,202,253,121,9,15,219,161,2,158,2,9,255,81,6,222,206,128,5,206,1,169,197,158,5,216,252,198,248,240,252,64,7,144,249,255,2,84,250,140,249,171,249,248,3,148,5,61,212,121,16,246,230,10,10,8,252,72,249,180,220,122,254,62,0,35,251,211,11,1,255,110,6,78,5,117,252,160,252,138,255,106,3,12,1,252,0,104,0,98,252,216,253,74,251,197,3,48,255,104,160,122,3,20,250,138,253,139,252,220,252,138,254,8,168,137,251,247,252,20,2,185,0,91,2,239,6,161,248,157,1,54,254,244,251,45,255,133,10,64,27,230,218,157,5,179,39,146,9,218,249,77,19,116,3,42,254,218,242,56,18,164,1,200,253,71,22,10,0,100,249,143,0,56,6,42,213,75,11,111,244,98,15,198,7,190,6,129,235,254,12,81,230,72,2,235,254,71,254,143,6,248,253,59,5,53,4,58,211,245,254,161,254,201,0,187,42,54,16,50,15,204,5,55,10,92,253,64,254,12,9,2,251,6,38,33,244,25,11,196,3,123,226,156,0,196,227,136,255,157,21,30,239,4,7,251,9,72,217,34,244,188,8,166,4,222,0,108,249,201,12,24,249,89,24,214,230,97,33,207,255,211,255,62,9,37,1,52,1,79,253,52,1,112,1,60,254,101,4,22,9,225,246,127,186,235,7,245,252,222,2,16,248,222,4,174,244,78,16,182,255,216,255,223,243,169,247,228,3,86,206,30,14,72,19,120,248,248,5,194,239,1,249,242,246,139,3,186,254,241,87,108,253,254,3,178,1,204,253,28,0,144,255,252,0,116,1,182,252,254,255,136,2,19,9,154,253,81,91,249,254,230,1,104,254,150,254,203,252,44,253,204,3,224,4,188,1,51,249,92,254,165,250,64,4,203,253,22,0,118,254,192,255,220,254,153,255,11,254,210,136,218,254,246,254,177,1,68,253,230,2,12,253,105,254,63,252,108,255,120,250,239,251,31,254,121,0,90,1,0,40,85,49,196,5,169,245,70,5,36,248,250,254,11,234,202,2,46,17,84,245,23,215,106,38,211,235,33,252,211,253,83,245,124,242,147,22,147,2,192,5,237,7,221,246,70,188,105,22,112,252,18,23,61,235,152,3,183,10,72,247,151,7,15,253,160,6,230,248,32,247,204,253,230,250,241,253,100,255,224,38,36,0,220,9,5,8,49,7,122,249,126,41,228,9,16,234,188,254,148,251,132,251,128,7,248,39,181,255,138,253,212,213,82,6,80,4,3,246,165,253,67,8,198,3,77,241,145,243,173,252,150,17,227,249,78,39,57,1,59,253,211,41,99,3,236,14,69,245,142,13,106,248,26,254,252,15,111,231,197,246,44,2,118,12,182,19,179,248,70,11,76,41,76,252,161,239,8,6,65,249,209,2,175,243,56,253,166,3,74,6,46,4,224,4,149,41,36,9,162,212,72,245,159,254,191,255,147,236,10,249,243,251,186,4,168,4,114,4,82,4,206,36,140,2,133,218,129,249,204,1,147,35,245,244,7,3,107,4,124,18,93,0,220,1,131,1,255,127,95,255,10,1,106,254,92,2,163,2,83,0,179,253,129,253,220,0,194,252,152,8,114,255,48,248,128,255,134,3,55,3,31,1,205,2,65,7,166,249,208,0,224,10,184,255,146,180,46,24,241,247,115,220,91,13,185,6,212,247,76,1,123,230,86,226,114,4,39,3,234,245,100,253,154,1,15,254,246,5,96,0,176,3,247,12,14,5,177,254,172,7,132,254,150,253,253,11,101,0,20,74,6,247,192,215,90,251,26,252,152,250,54,211,0,255,133,238,187,15,52,242,36,7,225,250,167,242,171,240,35,255,40,108,229,8,53,251,19,4,113,254,1,243,3,2,129,6,152,253,164,10,222,253,0,18,192,253,153,255,152,220,255,250,205,253,252,241,126,8,200,252,51,13,200,246,98,1,76,3,124,228,9,247,203,245,112,212,238,3,216,251,145,189,156,4,131,1,0,223,68,3,190,253,61,10,156,254,60,250,58,9,54,3,195,17,118,0,148,210,96,1,111,1,66,252,121,207,191,255,201,249,0,247,192,244,148,6,172,6,99,249,243,252,185,255,28,39,234,253,168,241,161,1,0,248,93,248,251,40,23,251,93,3,98,254,38,240,226,11,249,5,65,233,221,26,178,240,225,3,221,0,16,10,156,225,170,0,120,253,117,255,174,242,38,31,12,253,97,10,172,253,239,48,57,255,184,53,150,8,86,252,39,247,200,6,1,1,237,5,92,253,115,251,198,244,127,246,123,0,195,252,45,10,226,215,170,243,40,14,24,8,48,27,210,5,26,18,199,1,17,224,115,4,63,238,45,250,143,14,222,221,97,248,81,2,14,0,81,11,186,9,31,247,100,250,16,213,189,11,216,238,150,242,47,238,10,252,222,218,183,249,32,251,199,249,66,255,24,215,192,12,30,247,233,19,135,253,217,1,171,1,213,2,41,6,24,43,62,1,60,208,78,0,164,251,185,1,138,7,201,15,120,253,28,239,32,255,178,10,122,34,216,255,71,1,225,6,67,9,171,0,199,15,173,242,65,246,126,4,107,208,88,249,35,0,16,2,161,1,114,2,74,7,40,254,210,1,137,3,170,252,149,252,170,4,51,95,232,1,26,0,183,2,241,6,30,3,87,255,240,255,28,251,139,1,103,3,146,4,133,253,155,249,46,8,205,234,247,191,128,254,32,15,33,0,81,253,15,249,192,239,204,11,142,248,28,15,187,2,112,254,99,26,75,243,155,49,194,5,144,28,223,3,122,253,146,104,220,9,96,8,12,254,72,4,179,248,12,4,85,249,9,2,213,247,165,5,31,9,107,0,238,0,29,255,136,255,0,128,79,2,255,254,99,3,49,251,138,2,47,254,100,1,175,1,250,2,252,253,174,253,0,2,242,0,250,8,244,3,254,249,28,210,223,13,24,234,130,247,132,246,61,41,113,2,234,3,217,108,179,253,9,250,240,249,156,0,113,7,17,4,162,239,252,8,67,6,44,252,28,249,228,1,19,6,152,245,125,1,156,45,112,221,12,244,163,2,122,253,224,2,1,251,19,251,60,248,31,2,168,248,125,7,139,247,30,11,87,46,28,8,141,40,205,254,2,17,73,0,28,245,96,246,196,3,38,255,16,6,54,7,190,5,65,2,174,253,213,2,78,120,43,0,13,0,62,250,4,1,194,4,153,5,142,255,252,3,120,253,90,253,169,248,191,255,23,3,110,1,99,33,163,3,67,4,250,3,184,63,164,251,247,252,182,251,148,1,180,0,125,252,207,244,151,216,17,253,40,0,202,246,92,244,246,13,225,30,66,255,247,35,238,255,178,182,242,254,76,235,25,248,118,9,91,251,243,4,195,251,64,253,167,26,116,8,2,0,125,0,241,246,155,1,79,2,24,254,202,253,190,242,48,1,169,207,244,254,90,43,106,255,168,246,25,251,100,12,162,0,15,5,9,23,8,31,131,23,1,13,34,248,141,11,187,236,197,18,220,10,179,234,120,10,148,12,224,10,219,253,60,178,58,251,38,2,44,242,30,7,242,15,95,9,68,229,97,8,170,3,171,253,122,0,236,255,118,197,172,249,39,6,49,2,152,1,95,231,248,2,98,6,92,10,147,223,84,244,72,7,220,9,156,12,42,29,196,245,154,1,84,5,204,6,156,8,207,7,168,6,215,245,161,254,152,255,192,41,2,228,134,0,166,254,76,46,246,203,157,243,50,251,85,4,224,246,62,252,205,253,6,4,16,11,55,252,51,248,161,12,98,254,202,223,230,247,177,10,229,13,89,6,12,4,77,3,56,7,174,6,108,215,22,238,3,27,174,10,11,222,101,253,32,6,222,6,92,9,66,243,63,246,64,250,184,209,79,253,51,13,156,6,169,5,28,11,76,33,18,195,81,1,78,2,231,12,198,249,12,246,177,17,177,1,127,248,152,3,37,4,99,249,191,0,44,0,189,3,163,246,154,251,41,0,116,8,205,249,56,2,118,188,79,18,252,251,109,254,145,4,254,250,190,249,242,0,46,251,78,7,43,4,140,9,216,6,8,246,71,34,104,5,51,22,94,237,108,207,88,253,224,203,60,255,236,254,213,254,222,2,90,48,60,9,71,1,42,250,48,2,166,255,66,13,240,1,53,9,117,2,239,255,16,4,62,253,77,2,38,1,145,251,180,97,188,1,182,4,214,254,144,5,244,5,116,247,192,255,179,251,50,248,118,1,97,5,154,250,171,211,176,5,85,255,191,246,54,27,8,245,229,220,62,13,213,252,159,2,216,11,188,242,169,217,198,8,66,17,90,253,59,7,200,249,226,212,86,251,228,241,29,10,6,255,17,254,179,4,68,5,219,252,61,7,167,254,213,253,205,221,33,218,72,241,30,250,20,224,190,254,5,228,81,231,4,8,116,0,149,238,232,246,249,18,247,245,139,5,191,3,114,4,122,27,228,18,121,13,170,26,99,52,131,252,213,3,244,247,130,241,105,12,7,253,152,251,34,17,129,255,42,26,98,13,150,244,195,255,152,1,146,5,42,251,108,60,94,0,117,1,13,14,128,246,59,248,165,252,240,220,122,11,247,252,153,1,50,255,178,225,56,13,39,1,46,254,29,0,245,30,0,8,162,3,248,8,210,216,74,1,184,30,20,252,127,254,82,8,132,1,3,14,128,238,24,6,32,206,210,245,242,31,3,3,65,242,202,249,176,253,144,8,154,251,179,255,149,240,76,7,232,250,99,43,13,3,96,24,38,16,14,243,151,1,19,232,48,20,9,254,107,8,34,252,143,0,219,0,34,217,94,251,90,250,138,7,253,220,12,240,3,232,48,252,153,0,159,202,52,2,63,53,138,0,243,254,123,1,53,5,82,249,84,252,1,254,190,4,114,247,67,5,139,250,215,250,94,0,246,248,227,25,26,5,197,207,220,10,189,251,246,238,183,19,66,254,112,242,176,23,51,4,222,1,1,3,58,0,34,3,50,2,211,249,164,111,194,0,58,5,61,2,213,253,105,2,103,254,31,251,248,255,109,4,184,3,136,255,198,9,193,20,201,3,128,249,233,6,89,208,175,21,110,254,254,18,198,12,255,127,202,255,105,5,50,255,19,0,10,2,104,251,101,253,252,254,148,250,41,249,70,247,228,0,169,254,131,252,126,252,20,252,213,9,24,255,4,82,251,1,191,248,14,10,72,3,153,253,126,248,148,2,76,3,52,0,248,4,97,2,76,253,45,85,170,3,166,2,113,254,234,255,209,248,28,252,24,6,218,0,133,15,109,230,129,251,182,240,235,252,170,3,11,211,22,247,162,253,185,254,16,12,29,3,252,249,82,226,98,5,156,255,60,8,141,248,105,210,2,6,128,43,54,1,208,247,35,244,109,12,195,6,251,7,96,13,182,251,254,7,33,2,14,249,93,2,164,3,64,3,204,246,38,250,105,4,22,45,119,0,14,213,120,241,220,16,90,1,75,220,81,15,106,252,156,234,116,1,194,254,38,36,87,253,32,19,51,6,84,6,58,7,217,15,29,250,150,254,206,251,184,254,34,250,236,243,175,10,134,254,204,210,244,250,241,245,187,242,114,226,239,220,134,6,211,33,113,253,116,3,23,7,124,219,58,2,138,1,134,6,150,7,61,255,130,1,41,2,181,34,10,220,144,253,248,246,236,61,14,3,50,2,39,250,208,2,12,7,135,5,31,241,199,14,130,248,88,242,131,253,69,2,137,4,193,3,64,252,94,252,119,249,136,3,246,44,18,247,20,217,148,11,136,233,181,8,18,3,57,250,62,182,237,5,128,0,210,12,157,0,126,247,204,253,115,232,254,2,9,238,36,14,228,238,110,177,91,253,86,8,163,255,206,5,136,2,74,237,70,7,60,250,200,255,141,242,194,245,10,245,95,251,122,0,9,7,245,249,209,47,31,245,82,9,56,0,21,240,44,213,192,252,120,237,186,250,33,11,1,255,161,250,163,0,26,5,37,0,0,9,140,250,30,212,240,37,196,6,42,247,48,14,81,254,189,253,51,240,38,3,120,208,227,250,72,3,62,250,150,3,40,251,191,249,48,0,215,239,22,27,128,15,202,28,248,15,200,33,47,9,186,5,103,2,230,207,213,246,30,17,94,3,64,239,190,243,94,7,251,238,119,1,157,7,73,0,31,1,135,0,196,255,38,250,133,246,239,4,250,12,186,253,100,68,78,251,22,6,23,13,228,1,73,254,197,253,142,254,176,46,136,45,129,250,126,250,96,244,53,254,141,1,188,7,162,250,213,4,180,19,230,247,149,1,102,214,82,255,244,206,86,248,217,17,243,250,56,255,34,12,87,1,236,2,126,7,60,4,98,253,3,0,210,251,115,254,125,15,238,38,159,253,219,37,124,252,137,0,1,9,200,232,80,252,36,250,126,2,65,253,186,253,114,39,245,253,8,3,242,4,252,18,69,24,157,4,254,233,6,2,156,35,124,237,187,41,221,253,241,250,165,255,104,0,213,243,68,249,239,255,161,7,23,253,182,2,38,254,216,47,172,253,94,253,253,2,162,2,142,17,181,4,251,22,154,249,100,240,104,253,246,33,12,234,128,15,51,253,71,215,227,254,195,206,112,1,192,240,75,48,248,250,218,4,39,250,211,243,92,9,36,255,164,6,28,245,250,0,107,0,106,255,89,1,169,2,212,255,94,246,123,254,50,8,56,1,54,0,174,10,47,169,48,251,14,249,39,4,206,249,254,229,88,1,183,244,4,239,155,241,204,247,12,0,37,249,255,230,107,255,214,31,63,214,20,253,163,5,0,128,162,6,181,5,216,0,93,5,2,245,246,3,111,4,29,255,227,250,152,253,30,6,139,1,44,253,84,3,43,6,81,218,66,251,216,2,73,1,28,36,179,0,36,28,188,252,142,240,168,0,166,233,152,0,186,244,216,1,117,253,250,19,30,34,185,255,142,44,74,4,84,250,166,4,86,2,144,252,19,57,252,48,13,250,60,5,247,3,230,5,48,255,206,0,34,5,4,250,10,255,118,243,155,249,59,255,197,0,0,128,168,5,65,255,72,249,39,255,253,3,205,3,205,247,56,0,94,2,39,0,223,249,75,251,185,246,148,247,190,18,200,9,118,209,165,3,129,232,97,10,161,244,203,235,84,248,40,6,148,20,166,4,163,2,88,3,74,249,20,239,166,0,20,6,61,74,248,7,174,4,134,247,32,7,175,242,121,0,62,3,4,255,243,253,33,1,91,249,36,1,86,3,130,251,172,251,171,0,255,1,98,86,150,2,17,251,228,253,254,246,228,246,101,3,185,235,186,0,24,2,154,1,104,226,78,2,57,53,191,13,18,15,29,245,136,254,150,230,123,3,161,19,250,247,124,32,189,247,244,29,80,233,96,246,138,246,5,6,245,240,42,6,164,1,151,253,149,230,166,252,160,0,36,15,242,244,174,232,33,243,101,38,75,4,81,6,174,13,204,243,236,239,138,0,31,1,146,3,220,253,32,4,246,249,194,4,29,255,112,45,194,253,28,252,90,217,40,3,20,233,79,250,182,32,218,247,232,254,14,4,16,2,70,7,28,1,86,15,112,255,0,28,200,4,108,45,35,255,250,3,147,6,154,3,49,2,254,26,103,7,228,11,69,49,182,255,112,250,118,6,168,34,207,8,34,252,9,248,13,1,86,37,138,39,190,3,210,1,100,248,38,251,18,4,118,3,137,251,140,242,240,221,126,7,212,254,130,74,163,249,223,3,140,3,128,252,183,4,18,14,62,237,160,244,4,16,120,11,192,250,203,1,8,229,54,253,12,2,171,0,106,250,174,5,91,245,106,4,11,253,45,11,90,212,48,245,90,21,78,14,110,0,49,248,88,48,131,247,52,246,234,244,23,248,230,238,134,0,128,217,202,6,3,4,148,5,38,0,232,249,24,50,108,54,37,2,74,2,208,2,155,3,240,251,245,244,56,243,110,7,191,247,64,10,224,12,222,255,3,48,169,5,150,208,228,252,186,0,217,10,17,252,204,12,181,253,131,248,126,255,72,8,204,253,148,254,237,3,153,253,224,5,148,246,3,36,108,211,70,246,238,4,96,245,72,6,52,243,14,5,90,7,68,255,178,27,141,23,145,239,77,245,72,0,205,216,120,249,229,5,132,255,143,249,164,1,217,241,211,251,39,212,14,253,124,254,22,3,119,243,182,254,184,245,112,209,106,12,4,249,25,10,50,16,152,7,59,245,136,214,220,0,200,200,110,8,238,254,218,7,150,254,83,4,164,254,58,248,96,0,39,252,63,6,30,6,113,5,48,1,156,250,100,252,227,254,108,2,226,255,122,252,98,102,205,5,18,4,120,251,96,1,79,255,221,4,87,7,238,255,215,2,91,254,223,0,238,250,42,4,194,3,26,5,26,15,102,3,164,182,223,240,107,0,128,250,19,251,40,3,206,252,202,6,159,5,148,247,37,250,196,247,238,237,199,15,60,252,42,65,111,251,10,1,157,36,214,4,88,245,77,9,127,47,107,8,40,254,11,247,255,253,224,14,78,253,114,247,141,251,250,255,99,5,237,166,100,5,156,253,52,1,114,5,122,252,82,250,196,245,200,251,208,244,27,243,108,0,218,0,14,34,151,253,182,251,156,5,43,248,130,240,158,245,8,24,150,252,228,237,1,34,202,242,216,208,162,1,211,248,218,206,14,1,236,252,106,251,108,8,205,1,215,254,222,1,136,253,156,254,164,22,8,209,160,1,42,10,216,13,40,251,54,252,10,19,53,28,192,2,236,34,12,9,150,4,233,9,4,21,251,255,230,248,204,11,232,239,130,27,110,218,170,249,248,13,151,9,214,254,195,1,78,235,203,28,222,249,100,205,30,38,40,255,121,3,19,21,37,245,60,240,200,6,177,248,12,248,161,251,55,7,144,3,244,8,82,3,220,0,20,5,180,8,143,1,187,244,120,245,95,9,107,12,122,24,93,6,35,51,24,255,54,235,117,5,44,253,130,6,36,248,59,14,120,5,92,245,169,185,6,254,153,255,38,5,169,9,197,3,181,253,111,4,120,252,2,254,241,213,145,7,183,253,183,255,130,249,205,11,84,1,69,207,174,249,255,255,134,248,126,148,68,10,74,246,21,1,106,3,209,246,165,10,147,3,226,3,71,251,73,254,120,11,46,0,246,3,232,248,23,242,206,199,41,12,96,215,255,251,66,8,48,5,234,254,158,4,228,248,88,15,218,251,230,254,209,250,68,250,87,23,38,9,138,253,135,239,132,39,26,251,170,245,166,235,42,217,112,7,21,0,248,1,21,9,163,5,70,25,38,10,194,31,42,3,48,1,221,251,123,253,42,57,130,243,181,16,99,253,254,227,18,6,239,246,82,9,208,251,179,9,211,239,25,11,86,13,78,31,187,243,105,42,234,25,66,12,127,12,192,254,36,0,170,250,223,239,85,12,42,10,177,16,125,246,85,10,170,11,128,241,101,240,156,234,171,237,128,249,240,24,63,212,40,5,136,8,18,236,88,244,223,249,188,247,23,250,204,55,82,212,147,244,37,253,215,250,37,231,203,5,135,13,12,5,239,247,155,254,148,35,227,24,0,15,7,229,42,221,90,11,134,249,245,2,206,7,188,253,60,253,150,8,75,7,192,3,170,17,104,7,118,249,177,236,135,10,95,246,226,247,27,38,11,237,214,245,138,13,57,15,207,241,54,19,255,247,146,14,66,248,155,216,126,242,182,248,32,0,86,249,64,14,204,254,82,252,162,249,194,6,0,2,20,57,87,13,206,3,7,12,253,2,129,3,242,254,235,248,3,250,94,4,11,245,52,245,106,4,250,248,242,17,194,243,196,3,142,177,14,10,194,126,157,250,52,0,102,1,30,255,110,7,1,1,209,251,118,253,113,254,131,254,25,8,6,9,116,8,29,32,153,5,139,253,160,5,96,4,222,242,222,237,208,7,122,1,184,4,168,245,182,17,235,12,144,51,220,10,28,12,134,243,146,214,213,210,117,238,170,8,108,238,110,2,33,5,122,10,187,11,149,250,210,240,225,249,0,237,147,42,130,175,186,249,196,255,90,2,125,0,38,253,168,251,211,3,69,1,243,255,71,255,217,4,224,254,216,253,154,23,119,228,65,227,80,250,237,1,196,43,191,255,134,247,128,235,200,8,234,251,79,2,37,8,228,244,244,0,130,242,69,2,35,5,227,11,48,1,148,253,149,1,24,178,1,3,52,4,80,250,74,253,0,10,234,251,210,9,216,56,50,6,141,228,154,237,86,5,16,6,2,17,224,12,206,1,88,2,244,1,153,12,219,19,232,252,127,12,70,253,251,241,220,245,234,242,198,10,53,244,32,22,85,219,108,18,203,243,234,12,124,24,176,253,146,253,208,239,110,231,126,19,20,253,62,7,238,251,76,244,73,239,82,1,184,248,65,222,56,212,164,3,46,253,252,6,121,248,194,1,143,8,52,46,0,231,244,20,68,247,140,12,148,32,99,243,226,244,188,237,223,248,68,10,209,254,179,253,48,30,136,239,230,240,208,238,62,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+450560);
/* memory initializer */ allocate([204,211,14,22,132,14,219,18,232,0,185,253,52,1,215,248,105,8,52,246,210,255,89,3,141,218,208,10,16,20,182,5,22,20,54,31,160,242,43,4,38,29,80,19,98,0,246,3,114,237,0,54,106,4,30,9,177,36,112,9,89,238,27,0,208,7,161,3,52,255,225,1,36,245,120,241,243,4,13,1,249,234,49,248,225,4,114,239,121,219,240,226,180,232,10,24,85,229,40,12,203,245,92,255,68,6,221,4,206,255,171,33,52,240,44,18,30,11,167,32,225,20,170,244,247,8,193,18,104,236,130,231,77,11,172,10,74,242,203,245,196,17,24,231,158,17,70,41,67,7,14,4,67,223,222,10,170,249,159,0,245,251,96,243,74,241,44,6,48,253,132,238,233,240,104,252,169,247,54,254,96,1,171,245,213,11,45,1,135,251,34,254,112,14,76,210,202,38,249,25,122,28,58,9,74,67,166,12,250,6,150,2,203,3,32,253,121,253,209,6,6,254,247,252,178,5,102,9,119,250,3,225,178,252,162,245,80,4,106,2,33,245,72,216,6,243,26,37,85,252,218,246,172,248,134,248,84,0,140,13,123,230,116,30,43,241,218,250,121,247,30,5,129,252,79,19,38,4,140,238,142,0,12,255,116,3,101,2,117,201,35,233,77,252,15,73,60,252,66,4,46,4,108,5,220,249,170,251,159,2,170,6,108,2,250,254,139,246,27,247,223,233,164,235,130,19,75,9,175,253,0,8,153,56,141,4,17,249,211,247,162,9,163,1,148,1,53,21,17,12,186,250,183,7,233,8,60,0,87,2,192,249,238,8,54,9,42,26,217,191,176,14,154,2,227,250,190,250,226,10,60,9,168,5,90,4,36,70,75,235,126,9,154,4,92,255,147,8,87,15,134,255,31,253,188,5,51,1,185,248,56,6,222,225,132,246,190,3,220,0,59,0,28,16,103,248,143,43,156,33,227,247,77,237,30,238,72,4,125,10,78,25,122,32,179,231,254,240,125,8,213,255,104,0,50,246,37,12,236,246,114,239,155,237,95,243,156,12,190,44,124,9,66,2,12,3,184,251,72,0,160,167,115,250,248,239,226,0,208,1,66,249,77,248,20,8,118,4,132,5,132,5,30,3,211,245,133,242,176,251,80,247,54,247,114,242,196,253,116,250,244,250,198,255,39,255,87,172,84,255,32,231,30,0,134,247,95,0,122,1,146,244,124,247,4,11,85,253,226,7,39,239,99,203,20,21,16,7,176,253,124,18,54,230,30,234,41,252,222,239,35,254,44,251,41,247,152,15,94,205,14,249,185,245,139,246,22,253,172,7,218,6,8,253,193,10,140,255,236,240,6,40,64,254,218,250,156,255,124,215,140,5,46,255,208,10,48,0,187,246,41,30,111,243,184,254,7,6,33,246,125,14,184,15,108,252,20,238,42,253,50,239,42,252,134,198,31,14,90,251,91,35,199,0,204,8,68,5,148,239,181,2,217,4,176,200,100,246,31,248,181,11,254,2,152,254,62,254,153,244,216,224,138,12,77,255,231,34,158,2,131,4,232,26,55,247,169,10,18,7,139,24,172,2,11,218,29,249,103,252,30,238,101,15,248,230,151,5,74,245,165,255,210,247,186,247,232,217,241,10,63,246,147,0,243,232,106,235,114,51,250,10,40,6,137,243,13,40,130,16,196,250,152,9,55,4,253,48,252,235,92,223,24,252,210,253,180,0,234,247,168,248,170,233,81,253,53,41,42,4,220,0,205,239,73,253,64,14,124,242,185,243,169,249,102,8,42,212,250,245,5,231,224,13,176,239,70,253,224,4,112,0,236,237,64,252,44,253,167,4,36,8,103,59,166,254,115,1,190,0,225,20,69,239,198,226,74,5,184,238,65,241,209,239,164,5,228,197,179,253,194,9,25,5,26,254,92,6,157,252,48,6,70,4,246,255,20,251,234,251,224,9,80,107,142,3,211,251,61,3,139,255,183,251,2,3,252,0,124,250,49,9,152,8,245,255,112,2,11,33,176,24,7,219,201,4,228,9,39,21,36,36,95,250,158,250,57,4,51,248,192,240,108,198,156,235,43,14,93,22,36,24,40,235,72,0,30,18,147,3,16,254,116,2,88,7,92,254,240,10,25,228,102,226,108,12,142,239,169,251,163,11,70,254,74,255,218,10,94,9,202,201,161,8,230,254,136,252,180,0,0,14,19,252,2,0,231,3,254,243,181,4,3,238,130,20,103,67,23,11,158,10,90,253,165,245,160,0,60,6,77,18,20,9,28,12,160,14,94,248,102,210,109,2,90,253,158,231,135,242,158,248,62,12,223,254,6,228,220,8,11,223,144,253,135,19,198,232,213,50,244,0,56,255,42,250,172,251,184,14,189,1,125,9,16,251,18,3,79,244,154,13,144,9,56,252,96,251,213,0,252,252,67,19,42,0,246,240,228,7,206,185,84,0,200,11,166,253,13,7,219,2,194,13,210,245,131,253,191,99,168,2,59,4,42,16,66,6,190,0,194,248,62,252,133,254,61,246,149,9,150,254,56,238,81,18,120,8,214,232,200,214,47,234,170,237,143,9,255,7,44,21,68,15,87,250,166,255,188,255,240,1,87,206,177,247,126,5,242,213,134,9,230,8,146,11,245,230,234,255,82,248,254,10,46,249,129,254,179,246,163,232,168,42,190,207,112,253,212,8,80,20,140,248,29,247,180,16,150,4,92,252,236,253,16,11,89,2,15,6,14,223,182,239,245,230,139,35,26,229,195,8,49,2,234,7,242,241,155,251,134,2,188,235,129,23,136,253,4,3,153,244,64,241,46,217,157,9,134,255,128,0,120,250,3,250,87,1,38,5,86,202,8,250,238,230,84,251,64,3,255,127,19,253,163,248,218,252,227,2,190,248,62,15,5,4,76,1,182,247,216,4,145,10,82,5,190,0,34,4,132,250,200,4,98,4,184,4,190,0,192,7,181,250,158,6,248,173,12,252,114,9,11,251,126,251,89,4,243,8,243,246,59,1,72,50,8,247,26,250,80,4,60,44,134,251,6,252,46,5,122,252,168,0,135,2,220,248,2,241,206,233,172,10,18,255,122,255,138,52,34,6,120,9,228,3,90,242,120,241,33,19,243,22,149,0,33,231,3,26,231,246,4,27,110,4,169,1,186,181,33,254,148,248,142,13,15,249,213,252,187,6,210,255,201,247,238,250,113,11,73,239,129,253,117,246,63,28,93,251,159,247,247,252,41,243,31,19,174,34,154,219,33,1,175,15,180,243,170,253,178,8,180,45,114,0,165,12,114,37,38,238,32,10,30,14,32,247,243,244,228,242,185,251,86,235,101,18,181,248,118,248,14,175,169,3,124,3,135,5,8,6,134,11,226,19,169,3,125,250,123,0,225,255,224,249,82,1,86,252,89,21,164,22,224,1,34,245,23,13,71,246,129,254,249,5,202,233,142,9,75,253,4,206,169,253,102,7,216,249,60,247,178,237,181,39,195,251,66,39,121,10,114,4,240,9,239,248,218,252,158,20,230,221,100,241,217,246,203,3,74,243,91,255,44,255,188,239,82,3,233,0,130,202,186,1,49,4,14,15,130,205,47,248,140,13,3,253,61,3,126,8,251,5,108,232,160,213,255,212,35,3,177,6,68,11,200,7,75,0,83,244,12,1,90,1,206,7,190,18,16,35,232,237,71,7,225,239,156,253,182,18,194,42,240,250,73,31,185,250,100,1,81,249,57,1,253,8,38,5,114,31,188,2,194,4,222,8,148,247,67,0,1,6,149,7,114,13,9,52,179,2,40,9,34,10,15,6,13,15,111,28,55,215,238,3,170,209,156,21,157,253,186,253,209,8,199,244,153,15,243,235,40,247,82,246,40,6,42,7,189,236,24,40,107,250,92,215,137,1,125,241,66,250,45,248,128,1,5,19,132,229,239,250,36,6,19,4,68,27,226,238,67,244,114,14,80,16,188,250,148,236,38,6,87,38,149,232,45,252,25,14,118,14,201,222,156,2,26,13,248,9,223,35,105,251,200,4,213,244,168,43,200,23,181,250,84,0,247,4,132,254,216,20,43,1,78,253,147,254,145,224,161,241,124,243,54,5,117,203,144,250,152,8,194,241,234,251,60,239,229,2,91,249,186,6,13,8,178,250,98,28,44,231,195,3,142,8,187,250,166,248,208,200,202,237,224,13,53,2,171,251,37,21,215,4,198,245,26,3,240,247,29,46,44,35,170,247,244,10,178,3,80,0,173,246,75,251,11,0,106,6,223,248,236,246,102,236,112,16,165,20,149,2,142,48,115,7,16,3,112,42,84,1,18,0,118,255,69,11,57,247,17,0,78,1,156,243,161,11,202,3,24,2,252,249,252,253,24,254,0,254,202,250,118,248,142,246,54,4,5,97,12,0,12,8,4,255,24,246,98,247,149,243,127,229,118,221,32,34,113,5,119,0,116,6,142,39,88,3,87,3,26,253,223,254,96,247,247,14,253,26,100,230,168,9,11,255,63,249,180,5,58,244,59,0,198,255,132,0,63,15,78,241,117,250,217,51,148,10,184,225,84,0,197,13,231,250,178,254,147,203,43,23,19,237,119,245,154,2,46,2,178,251,120,2,126,244,57,16,78,240,164,17,11,19,108,17,225,249,185,8,130,1,14,253,232,4,97,8,100,249,10,205,45,6,250,253,45,17,191,4,45,253,85,13,128,253,32,236,175,6,54,253,232,9,129,9,77,253,6,42,196,221,165,21,233,247,130,249,155,50,198,50,228,4,162,255,34,3,13,10,3,246,190,255,192,252,106,0,40,253,26,4,213,252,132,245,117,2,116,191,251,5,175,249,68,5,204,0,186,6,112,1,42,2,40,249,114,0,69,5,160,7,17,252,66,10,243,7,212,31,21,246,56,239,148,238,162,222,239,243,249,249,167,252,199,245,27,249,242,25,119,8,5,250,31,229,86,0,98,254,248,232,224,235,37,68,105,4,114,236,120,11,152,242,78,247,152,4,204,3,146,4,18,2,62,13,4,1,163,244,34,242,121,235,235,6,130,254,102,249,174,66,128,10,54,2,126,9,24,249,45,13,180,5,120,242,139,253,47,12,174,1,30,242,165,32,163,27,37,1,139,11,195,255,249,228,181,236,94,14,60,229,140,2,158,8,30,23,48,245,50,244,89,22,254,252,178,251,223,251,56,245,14,12,235,21,96,255,154,10,238,251,9,10,88,200,6,15,20,32,16,21,144,0,136,209,106,2,188,4,211,12,63,241,53,253,226,240,224,9,172,244,109,6,6,249,196,248,216,10,188,250,182,253,234,0,252,255,126,249,46,0,47,8,61,248,216,182,92,244,197,9,202,15,79,0,199,248,35,248,111,31,150,248,148,255,84,1,104,237,86,8,40,35,91,1,125,40,171,18,4,26,158,6,75,243,22,247,48,250,166,40,138,224,170,242,138,244,181,249,100,12,109,247,109,19,225,4,72,11,42,240,150,233,77,244,22,247,185,7,159,254,252,253,202,20,153,12,213,236,23,5,208,237,219,38,20,255,166,36,28,9,28,8,190,5,101,12,104,18,85,10,47,2,40,19,231,5,77,249,8,237,118,22,4,251,206,254,164,232,57,56,163,5,85,0,156,0,38,30,25,3,103,16,74,8,74,4,128,0,52,248,139,250,236,255,234,253,16,204,18,250,102,244,23,252,182,230,254,231,145,32,100,21,242,11,242,253,241,250,87,6,169,221,233,4,214,7,163,233,219,11,155,244,0,5,225,222,46,23,142,38,181,204,14,0,64,4,247,255,177,7,110,1,114,243,192,0,204,10,219,5,90,1,17,248,172,244,31,246,48,4,197,45,86,20,212,255,46,246,60,221,76,11,84,8,51,14,151,14,166,10,118,5,147,23,242,244,40,238,168,1,8,222,88,5,236,240,31,7,196,245,194,17,94,247,124,6,120,249,228,214,28,254,182,3,11,0,114,238,180,231,235,233,236,203,52,11,204,1,232,239,66,240,51,243,10,2,181,242,102,4,86,255,156,248,242,238,24,5,149,13,29,250,87,4,174,253,134,6,32,223,102,249,188,9,59,228,227,9,35,16,69,224,236,236,121,64,16,255,193,255,99,125,206,3,176,250,165,246,43,248,124,251,147,252,96,254,102,252,65,7,254,2,71,0,100,5,253,254,240,254,124,248,194,9,38,243,83,193,240,247,150,11,120,11,15,251,73,8,232,1,197,14,204,5,87,251,168,18,23,252,99,253,33,6,133,254,164,253,251,255,105,248,245,2,103,1,208,253,118,0,21,70,19,9,215,0,197,29,2,242,62,224,70,253,165,38,64,245,95,254,18,251,32,250,247,12,162,4,112,247,198,11,13,3,238,241,210,231,211,225,97,12,246,7,151,4,100,2,173,9,216,239,136,208,186,17,55,2,140,255,106,243,42,254,138,255,215,219,133,253,6,12,180,210,93,0,174,239,54,16,97,23,62,17,194,247,30,2,155,251,38,251,22,255,39,3,151,250,112,246,56,3,109,0,222,248,216,11,13,1,108,55,140,13,140,3,244,255,242,8,126,22,149,6,168,2,75,23,53,245,83,255,222,255,63,12,206,4,178,8,167,9,182,218,218,8,209,249,217,2,178,13,88,214,116,253,164,8,148,253,202,10,17,253,63,231,13,239,35,16,46,251,47,21,25,247,188,244,95,252,218,206,160,1,254,7,242,240,122,43,78,245,98,253,54,255,72,24,158,227,254,37,28,5,31,249,88,18,219,251,112,255,226,1,206,249,25,17,104,236,202,240,248,8,244,16,213,253,69,244,187,247,62,252,100,0,196,17,178,248,195,201,71,5,102,243,78,224,121,1,121,254,192,250,156,247,148,18,66,242,163,199,98,253,18,255,144,1,210,4,37,17,157,4,22,4,169,1,224,255,72,3,106,139,44,6,32,252,52,7,169,7,231,250,31,4,162,1,52,0,127,253,126,9,19,249,53,235,13,13,9,235,203,54,235,11,24,15,148,1,90,16,173,248,66,233,31,239,112,0,139,1,79,255,56,4,64,244,8,2,8,0,226,0,150,5,157,249,8,0,184,245,79,243,245,241,110,2,52,2,212,32,127,56,160,0,108,225,239,239,93,191,80,3,176,24,7,9,234,15,254,247,156,2,183,5,238,246,254,6,96,3,61,1,174,253,137,9,218,247,175,247,158,247,209,248,245,251,39,1,161,9,31,245,219,245,175,255,142,247,33,252,244,11,240,11,169,11,145,246,169,15,242,11,115,251,255,250,190,254,117,2,184,8,225,1,49,247,141,4,81,250,147,253,227,255,155,3,91,5,250,244,139,246,220,245,140,248,194,24,23,1,53,7,204,13,117,244,245,245,6,246,232,2,7,249,115,252,7,3,84,12,226,2,224,6,54,254,178,253,183,255,22,0,165,255,70,1,182,251,25,250,24,252,205,6,0,252,206,253,113,254,224,2,197,37,195,247,176,248,253,249,72,251,247,254,226,3,60,9,183,247,158,255,243,5,109,250,86,250,123,251,218,254,95,5,65,244,147,245,225,244,15,249,84,251,23,251,41,4,168,35,124,244,51,246,214,1,39,246,101,248,40,253,247,1,226,14,22,246,91,246,87,247,165,7,20,10,27,255,188,4,215,8,154,243,156,245,24,245,124,245,202,4,0,254,43,2,120,15,93,244,134,246,186,7,122,247,180,248,57,254,73,18,228,17,46,246,150,249,251,251,80,249,160,1,186,252,150,254,184,4,91,20,176,247,181,248,199,250,219,253,186,255,60,3,228,5,32,247,181,249,139,28,180,249,36,251,51,254,237,2,206,9,85,14,164,12,203,248,203,250,158,252,12,1,82,3,150,6,11,245,55,4,46,247,229,247,31,248,165,251,214,0,175,10,97,245,116,10,150,247,72,248,68,11,137,1,223,4,78,9,29,244,140,8,113,245,207,246,187,248,48,255,67,17,159,17,117,247,162,249,198,8,27,9,175,251,58,255,50,3,185,6,124,247,243,13,207,248,54,249,4,252,14,0,151,1,4,4,24,246,133,247,189,247,230,25,56,252,206,254,158,5,246,13,149,246,191,248,119,7,246,249,149,10,57,0,142,3,191,6,169,243,251,245,141,245,70,245,31,248,234,253,13,33,215,23,5,247,96,11,197,248,100,10,57,250,159,255,124,4,156,8,50,246,77,34,110,247,2,249,166,251,146,255,116,4,69,11,189,12,127,248,159,249,206,10,236,252,109,254,98,2,115,6,45,246,27,248,111,9,186,249,131,251,175,9,41,1,157,6,239,14,254,249,210,9,19,251,120,252,20,255,38,2,45,6,169,244,120,246,150,244,67,245,80,246,199,248,89,254,29,14,92,13,172,248,119,248,255,249,139,11,58,0,246,3,158,7,33,243,63,244,167,243,146,244,207,246,51,9,95,1,126,21,188,243,71,245,35,245,223,4,243,251,26,2,75,19,30,17,0,14,20,247,239,246,204,248,25,253,84,12,10,6,54,9,206,253,155,255,15,254,84,251,1,252,180,7,231,4,94,5,182,243,248,244,15,244,59,245,56,249,162,14,233,21,254,19,149,247,127,249,91,249,12,249,73,248,153,251,113,12,244,7,20,246,68,1,31,254,55,1,112,2,207,2,31,2,6,4,38,2,1,2,130,246,231,248,151,251,62,0,246,5,17,7,124,8,222,250,245,251,182,253,220,254,233,0,209,0,31,2,4,255,188,246,87,248,163,249,230,250,104,254,195,1,59,5,24,3,197,245,244,246,168,249,149,7,166,2,209,3,174,6,172,1,61,246,191,246,203,247,88,250,172,11,106,3,193,9,195,1,41,247,100,247,123,5,137,253,182,2,144,5,122,6,13,255,200,247,134,254,99,1,166,5,117,1,121,1,205,3,12,253,14,245,52,246,223,247,177,0,96,1,124,9,55,9,3,250,106,245,16,246,178,251,163,1,60,12,198,4,150,7,60,245,52,7,131,246,194,248,253,250,120,15,97,6,101,11,214,244,32,245,198,247,255,251,52,6,137,3,68,4,121,6,44,244,101,245,34,245,86,247,36,11,166,15,230,9,142,14,33,245,205,246,158,247,65,8,79,251,33,13,154,4,110,10,129,243,20,245,134,245,71,246,113,7,41,254,233,19,84,17,107,247,202,251,233,246,164,1,131,253,10,0,111,6,82,5,23,7,41,246,197,246,130,247,82,250,225,255,29,16,118,13,18,244,119,244,78,245,232,246,156,249,62,4,190,8,84,8,239,243,80,254,142,245,45,246,88,255,233,2,188,8,1,9,114,243,119,244,169,243,242,243,68,245,80,251,18,13,7,20,130,251,11,254,195,247,130,249,253,8,111,254,139,2,40,5,0,244,208,245,239,244,55,247,149,250,24,30,19,7,96,19,86,246,227,245,83,0,13,254,239,252,194,0,32,5,162,5,100,245,129,249,216,247,236,248,140,250,70,7,143,254,117,5,105,34,13,247,108,246,66,248,180,250,89,254,163,1,76,2,129,3,62,4,79,0,149,247,91,248,111,1,56,4,233,0,206,2,185,1,3,2,130,2,218,2,150,9,6,3,5,247,10,250,240,252,153,254,96,0,129,1,226,1,41,19,59,246,129,246,1,248,141,251,131,0,231,2,231,3,219,4,14,5,150,247,79,254,99,246,103,247,240,249,93,255,56,255,169,15,195,6,116,6,179,246,175,20,79,250,129,252,152,13,50,251,162,255,215,1,42,2,157,2,102,246,9,251,22,1,66,247,196,248,211,252,120,3,8,4,33,3,240,3,254,254,230,253,48,249,217,247,141,249,41,251,174,8,252,255,15,3,114,3,222,1,14,3,201,250,83,250,192,6,141,253,125,254,51,255,221,0,193,0,22,247,250,253,40,29,240,248,146,251,57,255,84,1,65,1,154,1,105,2,230,8,76,254,222,247,90,248,43,250,139,252,116,2,26,3,87,3,221,3,232,0,165,251,199,245,152,247,246,250,237,250,54,254,222,0,96,15,21,13,64,247,29,245,127,245,49,247,39,251,48,3,3,9,30,6,149,6,187,6,144,11,170,247,28,246,250,248,152,251,207,251,4,21,245,3,245,5,135,5,72,248,200,1,230,253,103,250,189,250,22,0,16,254,28,1,131,1,209,1,90,247,185,248,43,247,25,4,49,250,58,251,74,6,109,2,232,3,92,4,167,246,37,253,235,15,71,9,102,251,116,252,129,254,71,1,31,2,60,2,233,247,9,248,238,12,145,248,34,250,184,255,123,0,181,2,209,2,150,3,182,248,29,251,215,251,254,21,218,249,227,253,1,0,246,3,45,3,119,3,159,247,139,246,128,247,36,249,64,7,152,1,255,255,247,2,85,4,252,4,237,11,111,245,93,246,236,247,120,251,125,5,203,1,143,4,195,4,38,5,106,247,11,248,43,248,100,247,9,248,63,250,7,250,8,1,53,5,30,7,183,247,102,250,40,254,109,7,144,9,179,253,88,254,248,0,120,1,90,2,221,249,248,251,37,251,173,249,50,22,118,251,106,1,58,2,97,3,84,3,173,248,219,252,162,16,223,249,176,11,105,251,51,0,164,0,58,1,136,2,221,247,198,21,249,9,182,248,124,251,126,253,58,255,74,1,190,1,90,2,195,246,65,6,57,11,5,248,26,250,138,251,236,255,76,2,23,2,164,2,97,247,155,249,114,2,233,2,244,249,178,253,233,2,28,2,249,1,106,2,237,2,147,250,89,3,107,5,114,254,162,253,181,255,170,255,11,0,78,0,250,12,189,250,186,7,105,250,23,253,232,254,214,255,135,0,94,1,120,1,4,254,187,250,145,11,96,251,121,253,23,251,193,11,138,254,11,2,104,2,200,248,215,255,92,10,183,249,189,249,212,12,232,255,246,1,122,0,192,1,223,246,251,251,222,2,3,250,243,5,224,250,14,253,79,1,254,1,6,3,1,3,139,255,139,0,26,251,68,250,59,252,137,254,2,0,227,0,6,2,115,12,12,250,248,252,27,251,161,11,238,253,63,1,195,255,244,0,157,1,14,247,13,12,29,249,56,250,162,250,200,12,169,255,67,1,165,1,140,2,243,246,122,247,188,249,255,255,223,252,40,5,100,255,139,3,31,3,150,3,42,250,99,247,113,4,69,0,225,4,109,13,157,3,29,0,163,1,192,1,246,13,228,249,79,249,70,9,83,252,4,255,123,0,7,1,110,1,27,2,35,4,192,248,39,249,254,2,88,249,106,0,6,1,84,2,172,2,52,3,57,246,170,248,43,7,174,253,0,252,199,247,225,249,232,1,26,3,115,3,166,249,155,253,126,250,30,11,123,250,229,13,164,254,204,1,76,1,65,2,117,252,188,2,112,249,106,4,155,249,231,252,96,255,218,255,217,1,118,2,207,5,80,7,10,250,99,5,218,252,121,0,129,254,149,0,3,1,157,1,247,2,255,244,58,245,14,247,188,250,204,1,246,6,0,6,233,5,223,5,39,247,121,12,117,0,88,249,169,250,25,254,125,0,109,1,82,2,139,2,17,247,248,4,23,246,10,248,21,250,190,253,178,11,70,2,173,3,34,4,236,249,209,249,48,253,208,249,188,3,248,251,69,7,146,0,146,1,173,1,120,247,131,6,217,4,33,1,52,0,24,255,247,254,210,0,248,0,75,1,109,4,235,248,179,248,107,250,52,250,244,21,112,254,36,5,122,4,126,4,73,248,206,252,127,248,250,247,24,249,137,11,224,253,170,1,88,3,83,4,237,1,29,248,176,0,133,248,240,251,205,2,165,255,216,2,135,2,8,3,200,246,227,2,168,247,30,0,124,2,65,254,140,255,242,1,19,2,7,3,54,247,159,33,229,247,120,248,208,251,62,254,38,0,183,1,46,2,10,3,132,17,32,4,218,248,76,249,36,252,100,254,4,1,56,0,169,1,67,2,61,247,254,15,13,251,124,8,34,252,206,253,97,0,48,1,21,2,97,2,22,3,12,3,19,248,101,248,209,250,200,4,255,0,88,1,4,2,148,2,177,253,166,6,138,255,134,250,140,1,149,250,220,8,9,255,177,0,99,1,113,5,242,246,73,248,229,249,95,3,85,252,147,254,155,1,32,3,251,3,190,246,48,18,3,247,193,247,113,249,70,253,202,1,20,3,236,3,114,4,237,8,60,19,108,248,93,248,121,251,76,254,237,0,5,0,44,1,108,1,68,246,117,8,27,248,232,247,224,5,156,253,163,255,249,0,164,2,31,3,149,246,160,7,40,249,142,246,19,247,213,250,147,253,69,3,19,4,242,4,76,0,88,12,128,247,128,247,75,249,175,251,21,4,154,1,216,2,172,3,34,27,198,248,62,248,202,249,4,251,217,251,254,251,7,252,219,252,166,254,9,0,161,244,229,244,149,248,58,255,145,8,253,12,35,5,37,0,240,253,141,254,87,2,17,253,147,247,136,248,169,252,220,3,198,4,61,4,185,3,140,12,23,245,252,245,85,249,111,253,171,2,85,4,171,2,135,2,190,1,142,248,245,246,247,245,132,246,94,249,168,253,76,4,206,14,40,13,124,8,225,7,129,252,182,250,34,253,248,9,109,254,188,255,110,254,16,253,92,252,75,251,111,248,60,2,102,250,12,254,189,253,35,1,187,6,32,5,159,6,18,255,77,249,19,248,11,250,208,252,149,254,0,11,167,0,148,8,1,7,129,3,199,251,250,254,198,250,28,4,49,251,162,255,16,5,247,1,184,0,76,2,247,247,113,252,115,248,23,249,167,0,245,3,238,6,134,5,9,5,102,9,142,248,249,247,96,248,66,249,174,249,61,254,63,2,205,11,9,10,248,252,143,249,193,247,118,248,37,250,187,250,173,253,73,1,18,12,82,21,94,248,227,250,238,249,121,251,148,251,73,1,202,2,248,2,225,9,113,9,22,4,255,251,166,251,211,250,102,255,35,250,64,16,72,253,230,0,142,1,38,248,129,1,192,250,36,0,11,251,37,252,241,3,173,5,139,4,55,6,148,3,2,250,4,254,221,0,196,249,150,251,114,5,27,2,164,2,164,2,239,4,237,7,28,1,56,6,161,0,132,255,196,253,174,250,102,248,156,247,48,250,34,255,103,19,78,251,85,252,137,254,176,255,175,253,67,254,94,254,243,252,232,249,31,0,149,18,119,250,70,252,110,254,193,0,196,254,234,254,98,252,129,252,0,252,76,254,113,10,199,7,254,0,28,0,163,252,245,250,195,5,108,245,127,245,186,247,65,253,34,1,49,7,0,8,189,4,82,2,132,0,218,245,133,246,36,252,169,251,98,255,222,1,70,8,11,10,62,3,106,250,90,253,251,252,60,5,169,9,226,252,17,253,215,0,18,1,191,255,79,1,101,248,252,248,100,250,22,15,157,253,105,0,225,255,7,3,157,2,159,5,14,251,134,6,29,253,21,251,196,253,239,255,149,255,176,0,130,0,59,15,150,13,220,253,107,250,104,251,176,251,133,251,33,250,3,251,212,251,254,254,85,10,217,6,179,254,197,252,230,250,197,252,10,254,206,254,137,255,190,249,148,249,130,7,103,4,140,253,207,251,92,1,195,0,104,2,173,2,214,6,126,252,196,248,21,7,68,253,254,0,86,2,22,255,79,254,245,251,198,9,94,0,211,1,120,249,119,252,8,3,167,2,245,255,209,251,203,248,197,251,192,254,178,2,110,0,60,253,203,251,210,9,70,0,100,254,212,254,141,254,51,253,164,6,167,249,190,250,162,7,14,0,192,255,135,255,181,0,95,253,115,252,226,8,147,250,10,8,33,250,50,1,69,255,47,255,187,255,243,5,136,253,73,253,253,250,36,252,199,253,226,252,247,253,142,1,18,11,161,7,89,247,166,249,106,0,6,0,14,254,199,255,173,0,219,2,234,3,86,249,165,6,184,254,47,249,138,250,128,8,237,255,55,1,236,1,155,2,207,251,245,248,108,249,191,2,220,250,11,7,147,2,145,3,138,3,9,4,66,248,154,255,177,3,172,249,206,2,43,2,101,2,38,0,138,1,165,1,178,10,121,251,56,247,196,248,224,249,33,0,107,1,210,5,167,3,49,2,184,5,94,246,71,251,76,251,76,253,217,7,129,0,98,1,116,1,124,1,251,247,98,4,224,8,200,252,181,250,98,252,134,255,55,2,14,2,155,3,216,250,59,0,30,255,138,6,24,250,218,5,137,253,221,0,26,0,9,255,216,255,177,249,195,249,63,8,34,0,211,252,200,0,219,0,246,2,232,3,50,1,138,1,82,254,139,255,103,254,175,255,49,255,16,0,36,0,176,0,55,249,174,244,67,244,90,247,200,253,92,8,36,16,32,10,248,1,247,253,27,250,26,14,46,4,158,248,217,250,245,255,174,0,108,255,44,255,165,254,48,254,212,251,248,245,28,246,75,248,249,253,56,8,129,14,90,7,111,255,217,250,185,246,186,248,181,252,13,8,246,254,185,5,98,3,144,3,159,4,8,249,24,8,205,0,137,254,88,4,138,254,234,253,82,254,94,255,52,255,119,1,82,0,201,252,132,251,16,253,73,18,173,254,9,255,234,252,192,251,18,254,2,247,250,246,189,249,46,0,39,13,206,255,137,1,103,5,177,5,159,250,43,248,131,2,70,1,56,1,165,4,31,255,51,2,5,1,186,255,101,253,89,251,49,247,42,254,232,3,142,0,243,253,237,8,244,2,13,8,71,252,0,23,197,250,2,250,28,251,240,255,140,255,207,254,137,254,172,253,27,14,135,252,1,254,43,0,215,252,109,253,31,253,2,254,254,254,148,255,21,250,246,10,237,249,1,4,92,252,167,253,146,0,164,0,207,0,71,0,70,6,93,0,140,246,249,246,151,249,12,255,249,6,36,3,16,4,171,1,26,250,38,0,70,246,61,248,44,0,187,2,127,5,220,3,37,4,155,1,138,4,154,250,147,245,157,249,119,252,223,5,162,2,77,5,101,3,244,0,155,1,52,10,0,249,157,247,99,249,154,5,25,1,38,0,228,0,168,1,243,8,74,5,176,247,159,250,10,252,159,253,131,0,105,255,162,1,90,2,111,0,152,8,245,249,127,251,155,5,254,250,6,0,145,255,255,255,92,0,238,0,101,2,33,247,99,251,81,250,105,252,74,255,42,4,140,7,143,6,77,249,9,11,28,249,33,249,27,253,195,252,245,1,234,2,32,4,136,5,152,6,205,254,178,253,203,3,224,241,160,249,38,255,69,7,57,250,145,254,72,230,231,1,73,252,56,42,24,255,188,1,89,0,64,251,215,249,3,5,249,0,253,255,194,241,157,8,164,251,70,10,62,8,121,12,14,1,67,255,78,0,198,252,242,3,232,214,142,254,210,4,28,234,250,254,253,4,160,5,177,8,162,9,49,1,165,9,28,253,120,0,112,12,77,8,161,4,98,243,61,6,122,249,165,223,127,217,127,255,228,34,181,250,51,34,195,2,0,255,121,255,167,1,7,6,246,6,245,236,147,1,117,1,34,6,73,255,14,3,111,218,21,246,66,4,11,2,17,27,54,251,89,40,234,254,25,252,252,254,238,248,154,2,49,254,44,232,248,7,0,1,20,2,61,250,127,1,81,51,55,213,78,247,37,251,48,6,212,246,215,252,18,14,208,252,194,0,224,1,84,0,249,8,88,1,195,235,157,231,200,245,45,8,200,27,187,246,190,250,35,1,140,254,161,252,241,189,170,248,122,1,198,252,67,2,225,2,44,254,16,247,8,1,122,2,108,0,2,255,109,18,250,250,69,11,218,3,176,236,158,255,215,7,223,3,52,247,185,244,3,232,163,253,22,215,128,3,6,0,235,0,105,254,186,255,222,1,56,223,138,213,63,2,96,253,103,0,64,1,77,255,27,255,189,1,132,254,100,4,199,12,209,250,237,254,17,255,115,215,114,220,81,5,96,0,25,251,235,254,100,36,97,254,46,247,32,35,139,255,89,6,64,253,44,252,240,2,173,35,168,221,89,254,240,254,159,252,19,247,187,1,34,248,224,245,108,12,174,4,10,10,32,13,78,228,239,12,185,2,181,8,46,0,40,254,72,27,116,255,244,252,151,40,202,251,48,0,204,253,47,236,40,6,198,252,29,254,184,3,75,4,240,210,116,253,119,1,184,1,105,227,86,10,215,247,244,10,211,14,208,229,251,0,43,3,56,251,72,248,177,236,241,229,12,3,216,244,29,225,143,9,171,14,121,255,103,4,72,1,41,2,122,13,95,1,66,236,251,255,53,4,109,0,2,255,121,254,1,254,148,1,195,255,254,1,139,1,100,232,226,226,108,1,193,253,65,0,102,254,127,248,8,255,128,0,55,1,235,66,169,247,205,253,140,252,52,9,145,240,104,251,201,190,2,250,185,7,114,2,174,9,18,6,210,251,38,0,217,253,114,1,211,212,181,254,38,4,151,250,111,249,4,4,22,13,239,0,180,255,100,255,49,0,141,1,148,27,238,244,129,230,22,0,128,7,73,252,100,1,6,226,57,221,136,255,61,1,209,254,160,0,18,2,3,18,59,4,2,2,81,208,229,254,133,5,176,252,123,253,80,254,0,0,64,255,172,18,99,242,88,251,178,214,250,4,15,244,219,1,68,255,183,0,185,30,50,212,244,254,235,1,142,5,228,255,149,0,3,2,141,249,158,2,62,254,66,252,64,239,55,2,74,255,156,2,229,15,43,255,104,251,148,0,150,34,105,255,218,1,87,2,17,5,237,0,14,181,177,11,30,254,177,253,214,250,25,0,140,253,196,252,53,255,36,250,143,21,172,255,211,2,143,251,193,4,245,50,61,253,140,254,56,255,210,239,234,252,188,0,152,229,160,223,254,2,110,1,188,1,251,253,137,245,66,250,195,255,161,0,106,241,237,11,220,7,183,1,115,2,12,2,162,21,37,2,39,254,60,247,207,32,5,231,179,22,83,3,58,0,112,44,250,255,175,254,79,253,26,250,78,253,124,254,253,241,105,10,43,13,198,248,71,252,255,253,69,2,200,215,36,2,68,4,53,2,125,70,215,0,50,250,10,251,194,1,144,252,151,1,109,230,201,32,206,0,253,253,227,249,37,255,176,248,199,5,126,1,199,253,118,236,33,251,211,255,28,253,1,249,25,67,70,251,249,2,132,0,165,249,106,19,187,21,210,2,238,21,174,1,27,22,139,0,169,4,233,5,120,4,217,250,49,2,231,235,242,3,199,0,144,2,138,240,216,13,34,249,42,3,214,249,104,62,117,255,245,251,96,254,225,253,94,254,8,11,115,230,94,0,95,253,221,45,170,1,241,255,96,235,12,3,3,7,248,237,0,32,215,254,50,255,115,3,65,9,117,254,86,239,208,243,57,255,217,3,216,4,96,1,232,0,86,255,176,0,157,1,17,254,137,250,242,2,106,2,41,232,77,255,14,246,197,3,174,250,218,252,70,3,184,240,190,250,193,243,87,252,219,0,51,1,75,242,186,4,77,9,13,225,214,24,139,252,86,11,28,1,0,10,253,6,222,26,6,0,190,238,98,247,189,251,48,7,138,255,157,245,240,3,144,8,115,6,83,5,164,225,228,4,80,251,133,0,11,253,245,1,158,255,211,188,98,0,225,253,207,6,109,2,215,252,98,248,231,252,144,4,25,253,44,228,166,0,195,30,142,238,100,1,106,250,45,254,141,33,203,38,8,2,158,252,153,7,169,253,78,254,113,0,77,2,128,242,85,2,188,23,90,4,188,37,252,5,25,8,118,255,47,253,250,251,227,250,113,2,56,240,187,4,108,182,133,240,140,238,197,0,88,2,20,252,208,252,208,253,36,254,144,247,254,255,26,0,226,31,33,4,78,255,37,210,166,248,232,3,29,255,109,0,196,248,117,251,9,189,140,0,50,253,130,251,33,0,117,5,211,255,51,255,153,0,42,250,29,80,205,255,120,252,169,253,123,7,116,3,248,1,229,248,121,238,228,4,21,251,104,247,31,234,64,254,82,253,146,22,105,3,70,239,235,253,39,1,62,254,142,5,89,9,195,12,185,240,249,0,235,241,138,243,184,251,138,246,18,1,130,248,230,15,50,255,80,254,127,7,123,253,237,254,154,50,55,1,199,5,152,245,172,252,55,237,78,4,137,254,20,0,123,6,101,251,175,4,44,0,42,234,168,251,202,253,151,211,131,255,153,252,158,0,184,4,9,1,249,253,107,254,135,9,151,251,35,7,11,219,100,33,186,249,124,1,60,19,150,2,34,5,121,254,24,248,59,3,187,203,58,255,114,255,64,6,1,13,125,0,96,253,36,255,45,2,210,72,60,0,128,28,24,215,56,253,164,4,40,3,64,0,223,1,43,2,8,1,138,1,157,253,214,252,249,224,21,255,23,229,217,249,40,5,131,254,10,227,204,6,24,253,113,1,142,253,13,229,160,247,175,253,156,2,161,254,84,241,233,235,234,248,38,3,37,254,76,2,5,254,128,220,139,253,154,0,223,228,175,251,162,41,77,254,128,1,11,253,159,4,222,14,21,253,134,254,23,2,240,39,114,2,158,252,117,248,52,250,186,22,18,253,100,218,6,255,77,2,115,253,58,255,104,0,90,252,183,4,46,0,192,3,248,251,140,16,119,17,176,244,15,6,222,225,127,248,234,2,97,253,250,19,106,21,246,253,240,242,143,248,252,219,105,253,181,250,157,253,65,0,88,5,116,2,4,251,132,229,193,245,107,253,139,255,75,254,131,21,133,12,160,3,25,2,241,218,80,0,154,255,230,253,235,254,95,3,115,250,166,23,203,4,184,2,254,13,4,254,35,249,145,0,87,249,79,251,61,16,14,243,243,8,190,252,53,3,40,2,44,253,1,2,254,217,16,221,121,7,245,1,40,255,204,2,206,10,201,252,231,9,58,1,238,6,212,242,235,0,244,0,64,251,58,253,177,2,80,26,204,255,218,0,66,223,68,254,152,3,57,2,230,236,254,247,156,253,172,6,31,254,116,195,194,244,77,253,26,2,131,255,175,255,162,252,146,216,18,47,144,250,186,254,133,0,61,0,206,255,203,2,250,229,95,253,249,41,172,253,44,0,66,15,247,0,23,253,86,19,46,255,241,1,173,248,5,32,93,8,174,5,233,255,56,250,136,8,220,252,139,21,225,250,67,221,192,244,234,241,230,254,140,255,148,31,106,2,109,254,82,4,187,199,135,4,229,0,230,2,72,255,11,180,183,254,21,253,40,251,207,5,122,249,185,252,179,255,142,252,22,213,221,244,232,255,21,253,225,241,147,7,109,5,132,0,247,20,75,5,152,1,8,251,124,44,153,0,148,10,33,250,169,0,189,28,51,0,238,202,108,254,208,254,114,2,163,0,234,248,253,253,189,1,77,2,86,251,2,3,43,2,246,0,91,255,56,173,184,0,247,254,164,251,27,254,85,224,56,248,203,213,144,252,81,250,206,196,8,9,80,249,245,255,149,248,112,254,254,255,58,1,194,254,232,254,110,253,214,251,232,245,3,4,33,3,72,209,239,5,169,34,209,1,99,243,9,7,164,254,237,2,7,0,55,4,253,247,1,45,193,252,143,203,85,231,145,251,64,4,32,4,210,255,18,252,118,1,55,236,139,4,110,254,206,255,77,250,114,37,2,2,97,250,130,253,101,255,87,235,107,31,156,253,227,2,60,4,196,255,123,3,18,3,250,255,202,251,49,8,43,235,169,13,23,0,111,252,23,5,189,3,221,255,238,230,110,255,53,252,178,10,223,37,70,249,46,248,137,3,43,249,107,252,122,0,123,1,187,254,57,254,230,0,57,3,119,255,177,254,160,255,96,255,134,1,219,2,195,245,255,232,147,240,18,20,71,3,90,251,190,255,193,3,8,238,41,9,71,6,112,246,3,230,176,253,150,255,61,226,230,252,94,251,213,206,245,255,80,247,31,255,169,244,22,2,75,5,166,228,58,1,238,1,158,7,159,222,29,246,122,246,179,255,118,3,197,248,176,3,84,216,187,11,54,7,127,7,227,7,215,1,195,1,76,254,12,252,103,177,19,1,98,0,240,6,66,2,96,0,240,255,132,4,105,14,7,0,49,255,152,3,105,0,198,255,81,255,163,0,185,2,105,254,195,255,237,4,17,5,197,19,206,20,154,251,4,2,184,4,156,212,185,1,7,0,125,252,237,255,144,254,182,1,137,248,90,2,204,2,57,1,85,3,168,5,207,252,83,250,104,5,237,238,19,4,92,7,83,6,148,8,91,39,244,249,79,251,228,252,108,20,97,10,52,32,163,253,166,1,75,253,99,12,145,2,62,21,85,255,121,2,43,6,74,249,23,208,59,4,48,252,219,254,38,241,206,254,100,253,138,30,196,250,110,254,183,8,136,238,78,209,145,61,90,100,59,62,180,89,213,62,245,185,42,63,91,177,95,63,167,232,136,63,57,180,160,63,30,167,184,63,254,67,210,63,153,42,232,63,151,144,255,63,236,81,12,64,227,199,24,64,134,201,36,64,251,92,49,64,186,107,61,64,19,242,65,62,149,212,201,62,104,179,10,63,36,185,44,63,105,111,64,63,50,85,96,63,29,56,143,63,84,82,167,63,11,36,192,63,121,233,214,63,17,199,234,63,151,255,4,64,224,190,18,64,239,56,29,64,189,82,42,64,213,231,58,64,216,240,52,62,205,59,174,62,198,109,4,63,166,155,52,63,125,208,99,63,167,232,136,63,50,119,157,63,237,158,180,63,193,168,204,63,122,54,227,63,67,28,251,63,177,225,9,64,9,27,22,64,69,71,34,64,231,29,47,64,178,157,59,64,182,243,253,61,51,196,113,62,37,117,226,62,19,242,33,63,198,220,69,63,165,78,112,63,27,158,142,63,13,113,164,63,177,191,188,63,122,54,219,63,158,94,249,63,65,130,10,64,98,161,22,64,8,61,35,64,95,152,48,64,93,220,58,64,34,108,248,61,59,112,142,62,23,72,0,63,96,229,48,63,8,61,91,63,226,233,133,63,203,161,157,63,107,43,182,63,18,20,207,63,39,194,230,63,61,155,253,63,106,77,11,64,238,124,23,64,75,200,35,64,10,215,47,64,224,45,60,64,77,132,13,62,16,88,153,62,23,72,240,62,217,95,22,63,229,97,49,63,68,105,79,63,5,52,129,63,84,227,165,63,114,138,198,63,158,94,225,63,175,37,252,63,131,192,10,64,126,140,21,64,7,240,34,64,2,43,47,64,162,69,58,64,42,58,18,62,94,186,137,62,9,27,190,62,243,142,243,62,49,153,42,63,235,226,102,63,50,85,144,63,247,6,175,63,95,7,198,63,45,178,213,63,165,189,233,63,42,169,3,64,132,158,17,64,97,195,31,64,46,255,45,64,97,84,58,64,213,231,42,62,182,243,157,62,57,214,229,62,206,136,18,63,170,130,49,63,57,180,88,63,217,206,119,63,59,1,149,63,199,75,183,63,151,144,215,63,213,231,242,63,88,202,6,64,136,244,19,64,9,249,32,64,213,231,46,64,134,90,59,64,176,3,231,61,104,179,138,62,226,233,245,62,169,19,48,63,95,7,94,63,211,222,136,63,236,47,163,63,15,156,187,63,184,30,213,63,136,244,235,63,107,43,2,64,82,184,14,64,132,158,25,64,30,22,38,64,67,173,49,64,117,147,60,64,253,246,245,61,197,32,112,62,13,224,205,62,106,77,35,63,50,119,93,63,220,70,131,63,47,221,148,63,154,153,169,63,86,14,197,63,65,241,227,63,6,18,0,64,227,199,12,64,187,39,23,64,100,59,35,64,241,99,48,64,174,216,59,64,10,215,131,62,70,37,213,62,215,18,2,63,139,253,37,63,90,100,91,63,76,166,138,63,56,248,162,63,168,87,178,63,146,92,198,63,72,225,226,63,199,75,255,63,93,109,13,64,86,125,22,64,229,97,33,64,2,188,45,64,207,102,57,64,22,251,11,62,185,252,135,62,47,221,228,62,239,201,35,63,160,137,80,63,154,153,129,63,232,106,155,63,33,176,178,63,116,36,199,63,41,237,221,63,233,38,249,63,84,82,11,64,100,204,25,64,63,198,36,64,170,241,46,64,247,228,57,64,51,196,177,61,105,111,48,62,141,151,142,62,78,209,1,63,111,240,69,63,165,78,128,63,144,160,152,63,25,4,182,63,11,181,206,63,29,56,231,63,112,95,255,63,78,98,12,64,61,44,24,64,134,201,36,64,200,7,49,64,36,185,60,64,42,58,18,62,221,181,132,62,102,102,198,62,106,188,20,63,50,85,64,63,77,243,110,63,95,7,142,63,203,161,173,63,138,31,203,63,184,175,227,63,42,169,243,63,23,183,5,64,38,83,21,64,127,217,33,64,9,27,46,64,111,240,57,64,232,217,108,62,224,45,208,62,182,243,253,62,57,214,21,63,135,167,71,63,172,139,107,63,213,120,145,63,134,201,172,63,240,133,193,63,7,206,225,63,127,106,244,63,149,212,5,64,173,250,16,64,87,91,29,64,47,221,44,64,195,245,56,64,38,83,69,62,14,79,175,62,233,183,239,62,250,126,26,63,227,165,59,63,44,101,89,63,9,27,134,63,96,118,167,63,162,180,199,63,96,229,216,63,179,234,227,63,34,108,0,64,34,108,16,64,45,33,31,64,53,239,44,64,131,192,58,64,129,4,197,61,111,240,69,62,95,41,203,62,58,146,27,63,192,236,78,63,1,222,130,63,148,135,157,63,107,154,183,63,174,71,209,63,73,157,232,63,82,39,0,64,33,31,12,64,149,101,24,64,175,37,36,64,88,57,48,64,242,176,60,64,244,108,22,62,48,42,137,62,245,185,218,62,227,165,27,63,145,126,75,63,36,185,108,63,28,124,137,63,115,215,162,63,220,215,193,63,140,74,226,63,39,49,0,64,13,113,12,64,96,229,24,64,111,240,37,64,65,241,51,64,233,38,61,64], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+460800);
/* memory initializer */ allocate([230,174,37,62,231,140,200,62,13,113,28,63,23,72,64,63,184,30,85,63,197,32,128,63,125,174,158,63,228,20,181,63,122,199,201,63,249,49,222,63,61,10,247,63,225,122,8,64,125,208,19,64,111,18,35,64,164,112,49,64,145,15,62,64,174,216,31,62,93,220,134,62,114,249,207,62,141,40,29,63,118,79,78,63,134,56,118,63,104,34,140,63,242,176,168,63,44,212,202,63,197,143,225,63,165,78,248,63,71,114,9,64,223,79,21,64,28,124,33,64,210,111,47,64,70,37,61,64,100,93,220,61,104,145,109,62,86,159,203,62,198,109,20,63,152,76,69,63,41,92,127,63,126,29,152,63,231,140,176,63,34,142,205,63,235,226,230,63,18,20,255,63,198,109,12,64,161,214,24,64,177,191,36,64,136,99,49,64,206,25,61,64,150,67,11,62,128,72,127,62,65,241,195,62,133,124,16,63,200,7,61,63,144,160,104,63,111,18,139,63,70,37,165,63,53,94,194,63,177,191,220,63,66,96,245,63,31,133,7,64,11,70,21,64,44,212,34,64,86,159,47,64,149,101,60,64,13,113,44,62,135,22,153,62,83,150,225,62,180,89,21,63,12,2,59,63,231,29,103,63,184,64,138,63,220,70,163,63,3,120,187,63,19,97,211,63,44,212,234,63,187,39,3,64,2,154,16,64,250,126,30,64,57,180,44,64,107,43,58,64,250,126,234,61,12,2,107,62,187,39,175,62,183,209,0,63,19,97,51,63,245,219,103,63,190,159,138,63,127,251,162,63,43,135,190,63,23,72,216,63,168,87,242,63,29,56,7,64,56,103,20,64,2,188,33,64,27,158,46,64,106,77,59,64,141,151,46,62,248,83,195,62,8,172,28,63,223,224,75,63,187,39,111,63,81,218,139,63,181,21,163,63,188,116,187,63,152,221,211,63,121,233,230,63,141,40,253,63,192,91,12,64,231,140,24,64,245,74,37,64,141,151,50,64,248,194,60,64,74,123,3,62,20,63,134,62,87,91,241,62,16,233,39,63,4,231,76,63,98,16,128,63,243,31,146,63,133,124,168,63,247,228,201,63,66,62,232,63,84,82,255,63,112,206,12,64,231,140,24,64,68,139,36,64,42,169,47,64,220,70,59,64,32,99,238,61,243,142,147,62,53,239,8,63,209,34,59,63,48,42,89,63,249,15,121,63,108,9,145,63,72,225,170,63,250,237,195,63,77,132,221,63,105,111,248,63,246,40,8,64,101,170,20,64,140,74,34,64,70,182,47,64,247,117,60,64,251,92,237,61,167,121,135,62,96,118,239,62,51,51,35,63,7,240,70,63,193,168,116,63,247,228,145,63,173,250,172,63,119,45,201,63,82,39,224,63,123,131,247,63,154,119,8,64,216,240,20,64,27,158,34,64,122,54,47,64,241,244,58,64,27,47,221,61,118,113,91,62,133,235,177,62,245,219,7,63,100,93,60,63,103,213,119,63,40,15,147,63,101,25,170,63,18,20,199,63,101,25,226,63,218,27,252,63,90,100,11,64,194,134,23,64,156,162,35,64,136,244,47,64,32,210,59,64,94,75,8,62,254,212,120,62,212,154,198,62,238,90,2,63,247,228,33,63,174,216,79,63,131,47,132,63,117,2,162,63,185,252,191,63,56,248,218,63,120,122,245,63,11,36,8,64,43,24,21,64,14,45,34,64,73,46,47,64,245,219,59,64,210,111,31,62,252,24,147,62,158,94,233,62,249,160,39,63,25,226,88,63,87,91,129,63,170,241,146,63,46,255,169,63,241,244,202,63,111,18,227,63,81,107,250,63,0,145,10,64,135,22,21,64,38,83,33,64,254,212,44,64,0,145,58,64,132,13,15,62,251,92,141,62,240,22,232,62,165,44,35,63,137,65,64,63,105,111,96,63,239,56,133,63,54,60,165,63,221,181,196,63,156,196,224,63,144,160,248,63,89,134,8,64,68,139,20,64,14,190,32,64,72,80,44,64,211,222,56,64,55,137,193,61,103,68,41,62,7,95,184,62,4,231,28,63,16,122,86,63,45,67,132,63,7,240,158,63,101,25,186,63,35,74,211,63,140,74,234,63,149,212,1,64,7,206,13,64,164,112,25,64,55,137,37,64,22,106,49,64,143,83,60,64,165,189,65,62,29,201,197,62,218,172,250,62,57,69,23,63,245,185,58,63,202,195,114,63,246,40,148,63,109,86,173,63,136,99,189,63,227,165,211,63,147,24,244,63,27,47,9,64,151,255,20,64,239,201,31,64,179,12,45,64,83,5,59,64,11,70,37,62,110,52,160,62,156,51,2,63,198,109,52,63,238,124,95,63,40,15,131,63,78,98,152,63,144,160,176,63,238,235,200,63,213,9,224,63,182,132,244,63,209,34,7,64,57,180,20,64,99,127,33,64,144,160,44,64,38,83,57,64,34,142,245,61,166,155,132,62,17,199,218,62,158,239,23,63,64,19,65,63,102,102,118,63,20,174,143,63,217,95,166,63,237,158,196,63,213,231,218,63,13,113,244,63,33,31,8,64,110,52,20,64,19,242,33,64,36,40,46,64,82,184,58,64,27,158,222,61,197,254,114,62,199,41,218,62,242,176,32,63,187,39,79,63,200,7,125,63,222,2,153,63,131,47,180,63,22,106,205,63,195,211,227,63,6,18,252,63,5,163,10,64,41,237,21,64,215,52,35,64,211,188,47,64,171,62,59,64,147,58,1,62,28,235,98,62,120,122,197,62,84,116,20,63,34,253,54,63,127,106,92,63,39,160,137,63,26,81,170,63,247,6,199,63,16,88,225,63,111,129,252,63,172,28,10,64,231,29,23,64,81,218,35,64,121,88,48,64,22,251,59,64,207,247,19,62,151,255,144,62,20,208,228,62,69,216,32,63,209,145,76,63,17,199,122,63,79,64,147,63,206,136,170,63,163,1,196,63,90,100,219,63,88,202,242,63,4,86,6,64,30,22,18,64,19,97,31,64,183,209,44,64,100,204,57,64,30,167,40,62,23,72,208,62,241,244,10,63,254,101,39,63,193,168,68,63,249,15,89,63,87,236,111,63,18,165,149,63,255,33,189,63,132,158,221,63,218,27,244,63,13,224,5,64,236,192,17,64,131,47,32,64,214,197,45,64,176,3,59,64,37,117,2,62,45,67,156,62,194,23,6,63,53,94,58,63,45,67,108,63,52,128,143,63,14,79,167,63,54,60,189,63,234,4,212,63,115,104,233,63,224,45,0,64,41,203,12,64,77,21,24,64,38,228,35,64,98,16,48,64,223,224,59,64,100,93,220,61,156,196,96,62,43,135,246,62,229,242,47,63,56,248,82,63,165,189,113,63,18,165,141,63,144,49,175,63,226,233,205,63,119,190,231,63,107,43,254,63,170,130,9,64,152,110,22,64,50,119,37,64,242,210,49,64,163,1,60,64,70,182,51,62,36,40,158,62,78,98,240,62,85,48,42,63,47,221,84,63,234,149,130,63,11,181,150,63,191,125,173,63,200,7,197,63,161,103,219,63,146,92,246,63,181,55,8,64,89,23,19,64,10,215,31,64,196,177,46,64,153,42,60,64,194,134,39,62,101,25,162,62,122,54,235,62,196,177,30,63,238,235,80,63,4,231,124,63,20,63,150,63,27,158,174,63,57,180,200,63,208,179,225,63,186,218,250,63,23,217,10,64,249,160,23,64,22,106,37,64,68,250,49,64,5,52,61,64,181,166,249,61,94,75,136,62,68,139,236,62,107,43,38,63,57,214,85,63,133,235,129,63,152,110,154,63,179,123,178,63,74,12,202,63,67,173,225,63,224,45,248,63,119,45,9,64,143,194,21,64,188,5,34,64,252,24,47,64,25,226,60,64,172,139,219,61,29,56,103,62,95,41,203,62,105,111,16,63,25,226,56,63,146,203,111,63,147,169,146,63,115,215,170,63,93,109,197,63,217,95,222,63,18,20,247,63,48,42,9,64,30,22,22,64,240,167,34,64,64,164,47,64,33,31,60,64,169,164,14,62,61,10,151,62,106,222,241,62,234,4,36,63,159,171,77,63,149,101,128,63,226,233,149,63,50,119,173,63,169,164,198,63,93,220,222,63,2,188,245,63,139,108,7,64,36,185,20,64,248,194,32,64,88,168,45,64,121,233,58,64,40,15,11,62,29,201,133,62,108,9,217,62,158,94,25,63,42,169,67,63,55,26,112,63,194,134,143,63,59,223,167,63,140,219,192,63,46,255,217,63,251,58,240,63,180,89,5,64,239,201,19,64,140,219,32,64,26,81,46,64,47,110,59,64,165,189,1,62,231,251,137,62,249,160,231,62,199,186,40,63,7,240,86,63,227,54,130,63,65,241,155,63,242,210,181,63,128,183,208,63,62,121,232,63,172,173,0,64,38,83,13,64,175,37,24,64,108,9,37,64,143,83,48,64,169,19,60,64,185,141,6,62,28,124,129,62,84,116,196,62,122,165,12,63,27,158,62,63,25,226,104,63,91,66,134,63,43,135,158,63,120,11,188,63,168,198,219,63,72,225,250,63,248,83,11,64,105,0,23,64,69,71,34,64,14,45,46,64,199,41,58,64,191,125,29,62,52,17,150,62,239,201,227,62,76,166,26,63,26,192,75,63,25,115,119,63,16,88,145,63,163,35,169,63,133,235,193,63,68,139,220,63,14,190,248,63,222,2,9,64,58,35,22,64,225,11,35,64,21,140,46,64,70,182,59,64,180,89,53,62,206,25,145,62,97,195,211,62,226,233,21,63,220,104,64,63,91,177,111,63,249,160,135,63,123,131,159,63,52,162,188,63,91,211,212,63,156,196,240,63,41,92,7,64,40,126,20,64,236,192,33,64,19,97,47,64,106,188,60,64,36,151,255,61,183,98,127,62,92,32,225,62,120,156,34,63,234,149,82,63,39,49,128,63,247,6,151,63,45,67,172,63,7,95,200,63,131,81,233,63,104,34,4,64,236,81,16,64,98,161,26,64,107,43,38,64,184,30,49,64,27,13,60,64,18,20,191,61,77,21,76,62,219,249,158,62,146,203,223,62,116,70,36,63,106,188,100,63,87,236,143,63,4,231,172,63,165,78,200,63,76,55,225,63,5,163,250,63,21,140,10,64,35,74,23,64,64,164,35,64,154,119,48,64,95,152,60,64,162,180,55,62,38,83,165,62,15,156,243,62,91,177,31,63,181,55,72,63,180,200,118,63,139,108,143,63,130,226,167,63,242,176,192,63,18,20,215,63,137,210,238,63,153,42,4,64,13,224,17,64,18,20,31,64,229,242,43,64,162,69,58,64,110,52,0,62,235,115,117,62,20,208,196,62,85,48,10,63,143,83,52,63,32,65,97,63,153,187,134,63,86,14,157,63,169,164,182,63,215,18,210,63,168,53,237,63,129,4,5,64,192,236,18,64,143,83,32,64,138,176,45,64,170,241,58,64,59,112,14,62,143,228,178,62,143,228,18,63,22,106,77,63,32,65,129,63,159,205,154,63,37,6,177,63,228,131,198,63,13,113,220,63,220,104,240,63,152,221,3,64,152,221,15,64,234,149,26,64,249,49,38,64,116,181,49,64,225,122,60,64,29,201,229,61,100,59,95,62,143,194,213,62,145,126,27,63,170,130,65,63,211,77,114,63,204,93,147,63,131,192,170,63,131,192,194,63,130,226,223,63,93,220,254,63,33,31,12,64,161,248,21,64,173,105,34,64,100,59,47,64,109,197,58,64,248,83,35,62,181,21,155,62,16,233,247,62,247,228,33,63,12,147,73,63,8,61,123,63,99,127,153,63,191,125,173,63,181,55,192,63,113,27,221,63,180,89,245,63,142,117,5,64,56,248,18,64,133,235,33,64,46,255,45,64,198,220,57,64,113,61,10,62,122,165,140,62,152,76,245,62,204,238,41,63,123,20,78,63,235,226,118,63,174,216,143,63,205,59,166,63,210,0,190,63,130,115,214,63,192,91,240,63,26,81,6,64,80,252,20,64,174,182,34,64,139,108,47,64,223,224,59,64,236,47,187,61,69,216,48,62,238,235,160,62,165,44,3,63,75,89,54,63,54,171,110,63,57,214,149,63,167,232,176,63,40,15,203,63,202,50,228,63,61,44,252,63,231,251,9,64,74,12,22,64,67,28,35,64,58,146,47,64,22,251,59,64,254,67,250,61,197,143,113,62,103,68,201,62,226,88,23,63,203,16,71,63,248,83,115,63,63,198,148,63,135,167,175,63,249,49,198,63,18,165,221,63,14,79,247,63,17,54,8,64,175,37,20,64,187,184,33,64,174,182,46,64,148,246,58,64,226,233,85,62,20,63,198,62,211,77,2,63,61,44,36,63,136,244,75,63,143,228,130,63,23,72,152,63,188,5,178,63,17,54,204,63,131,47,220,63,91,66,238,63,141,151,6,64,247,6,19,64,111,129,32,64,65,241,47,64,217,61,57,64,38,228,3,62,126,29,120,62,97,84,210,62,236,47,27,63,20,208,68,63,122,54,107,63,122,54,139,63,79,175,164,63,125,174,190,63,176,114,216,63,210,0,246,63,235,226,6,64,182,243,17,64,175,37,32,64,193,202,45,64,50,230,58,64,82,73,157,60,54,60,61,61,23,183,81,60,124,242,176,59,36,151,127,188,202,84,65,188,27,47,93,188,166,155,68,59,166,155,68,188,95,41,75,59,166,155,196,60,199,186,56,189,125,208,51,189,124,242,48,189,245,219,87,189,12,147,169,188,242,65,207,60,39,160,9,60,35,219,249,188,250,237,107,188,153,187,150,59,44,212,26,189,128,72,63,189,231,29,39,188,66,96,229,60,27,47,93,61,254,101,119,60,197,254,50,61,176,3,103,60,206,136,210,188,237,13,190,187,215,52,239,59,14,79,47,60,124,242,176,59,43,246,23,61,49,8,44,188,2,43,135,60,140,74,106,188,179,123,114,60,154,119,28,61,124,242,176,187,30,167,232,188,23,183,209,56,234,149,178,188,134,90,211,60,97,195,83,61,73,157,128,60,23,183,81,187,227,165,155,188,40,126,12,61,250,237,107,61,187,184,13,61,46,144,32,61,0,111,129,188,1,77,4,189,177,191,108,189,36,185,124,189,20,63,198,188,250,237,107,188,117,2,154,60,22,251,203,60,39,160,9,59,232,217,44,189,49,8,44,189,154,153,153,61,191,14,156,61,184,30,5,61,208,68,216,187,185,252,7,61,117,2,26,61,192,236,30,61,37,6,129,61,61,10,87,61,46,144,160,60,231,29,167,59,20,63,70,189,38,228,3,189,202,84,193,59,208,68,88,60,0,111,1,60,129,38,194,60,228,131,158,61,224,190,142,61,153,187,150,60,74,123,3,189,111,240,5,189,247,117,224,60,30,167,232,60,17,199,186,59,177,191,236,60,239,201,67,61,30,167,104,60,159,171,173,187,17,199,58,60,215,52,239,60,23,183,81,187,198,220,53,188,155,85,31,189,176,3,231,60,181,21,123,61,10,215,163,60,82,73,29,186,198,220,53,60,82,73,157,59,64,164,223,60,137,210,222,58,116,36,23,189,221,36,134,61,8,61,155,61,248,83,99,61,56,248,194,60,82,73,29,187,10,215,35,188,86,159,43,189,114,138,142,189,0,111,129,188,202,50,68,189,7,95,152,189,78,209,17,189,57,180,200,188,10,215,35,189,52,128,55,188,172,139,91,60,23,183,209,56,232,217,44,189,206,136,82,189,221,181,4,188,185,252,7,60,254,101,119,188,1,77,4,61,23,183,209,184,198,220,53,189,48,76,38,189,14,79,175,188,10,215,163,187,18,131,192,188,158,239,167,188,208,68,216,188,221,181,4,189,112,206,8,61,46,144,32,61,135,22,217,60,177,191,236,60,188,116,147,60,204,238,73,61,90,245,185,60,192,236,158,60,6,129,21,61,137,210,94,61,3,9,138,61,102,247,100,61,226,233,149,61,163,146,186,61,238,235,192,61,43,135,150,61,114,138,142,60,163,35,57,188,65,130,98,189,39,49,136,189,90,245,185,188,61,44,212,188,62,232,217,188,239,201,195,188,8,61,27,189,39,194,6,61,187,184,141,60,49,8,172,188,17,199,58,188,59,112,206,187,166,155,196,59,78,209,17,188,156,51,162,188,176,3,231,188,111,18,3,188,5,163,146,188,104,145,237,188,153,187,150,59,59,112,78,188,208,68,216,187,41,92,15,61,62,232,89,61,18,131,192,60,156,51,162,60,159,171,173,60,16,233,55,61,3,120,139,61,76,166,138,61,46,144,160,187,4,231,12,60,166,155,68,60,78,209,17,61,90,245,57,61,179,123,114,61,16,233,55,61,210,0,222,188,96,229,80,189,88,57,52,188,91,177,191,60,48,76,166,60,203,16,199,60,20,63,198,60,62,232,89,60,46,144,32,60,111,18,131,59,82,73,29,59,111,18,3,186,143,194,245,187,59,112,78,188,9,249,32,189,195,100,170,187,2,43,135,60,23,183,209,58,9,27,158,188,239,201,195,60,39,160,9,61,237,13,62,59,142,6,112,189,63,198,92,189,117,2,26,188,185,252,135,189,16,233,183,189,27,47,93,189,208,68,216,187,172,139,91,60,179,123,242,187,172,139,219,59,207,102,85,189,160,137,48,189,195,100,42,60,223,79,141,61,75,200,135,61,229,97,161,60,137,210,222,186,61,44,84,189,253,135,116,189,77,21,140,188,124,242,176,187,66,96,101,188,111,18,3,188,4,231,140,60,116,70,20,189,188,5,146,189,182,243,253,188,82,73,29,60,203,16,199,60,191,14,28,61,95,41,203,187,46,144,32,189,249,49,230,188,9,27,30,61,91,211,60,61,101,25,226,59,82,73,29,61,111,18,3,60,176,3,103,188,77,21,140,60,13,113,172,62,82,39,160,62,48,42,169,62,159,171,173,62,111,18,163,62,145,126,155,62,251,203,142,62,149,212,137,62,233,72,142,62,187,39,143,62,234,4,148,62,84,82,135,62,194,134,135,62,248,194,132,62,198,220,149,62,240,22,168,62,164,223,254,62,183,98,255,62,173,105,254,62,174,216,255,62,100,204,253,62,100,59,255,62,201,118,254,62,164,223,254,62,91,211,252,62,191,125,253,62,91,177,255,62,228,131,254,62,247,6,255,62,45,33,255,62,118,79,254,62,97,50,245,62,37,217,95,253,10,2,220,255,140,1,79,254,181,3,70,254,49,207,118,247,184,16,27,252,77,249,39,227,133,254,170,13,196,253,87,217,30,26,128,237,65,2,74,7,147,2,133,255,110,249,164,1,158,252,106,17,189,22,83,12,249,30,70,234,250,248,14,12,108,33,191,255,17,221,50,9,165,239,42,241,115,2,189,248,224,217,237,248,68,249,211,255,210,248,102,6,243,1,148,0,177,254,180,81,248,254,212,253,243,254,10,252,5,250,199,2,249,253,206,1,3,236,104,15,74,252,85,32,110,3,61,237,117,236,206,238,142,237,172,11,112,255,25,229,165,41,115,252,188,2,17,247,94,47,155,255,7,253,44,7,59,3,159,253,26,2,186,1,104,238,20,7,234,14,191,28,96,0,213,253,62,6,56,39,214,253,156,3,98,13,6,249,60,10,172,247,99,3,249,253,5,247,96,253,4,254,201,0,103,246,120,42,117,236,46,21,70,221,152,255,19,10,172,3,145,1,103,3,159,43,192,4,30,4,196,244,13,250,146,240,51,251,174,242,84,254,64,14,83,219,47,244,40,249,159,29,113,15,146,7,59,15,155,5,234,31,251,3,240,246,19,5,128,251,226,0,138,1,64,44,65,250,92,2,72,255,55,2,136,241,165,233,206,232,167,1,146,36,194,17,10,243,189,242,220,19,11,239,11,249,197,245,54,4,147,254,151,0,99,254,169,171,56,252,54,255,73,255,81,3,31,254,151,1,245,255,108,245,168,9,129,10,240,219,246,218,16,249,133,2,26,250,126,250,29,232,142,255,10,246,130,7,132,6,32,1,234,250,180,3,175,7,52,0,89,9,73,248,118,1,206,67,204,250,183,20,123,12,142,245,176,18,118,250,177,250,199,255,178,247,10,18,186,34,55,25,157,4,76,0,118,1,113,37,58,34,160,2,126,253,154,2,171,230,215,6,183,12,90,252,52,24,124,3,171,0,154,255,212,255,186,254,50,5,192,254,32,254,182,252,152,168,207,253,115,255,123,2,128,230,79,22,96,9,70,3,30,11,116,243,35,235,153,234,97,19,62,8,200,226,137,239,28,31,228,250,195,4,5,6,190,238,149,24,86,238,233,236,128,233,230,10,161,5,247,23,147,251,165,249,211,4,146,3,60,2,237,251,63,250,249,253,246,237,52,251,76,208,77,4,214,213,60,239,253,238,31,25,180,253,32,252,100,2,21,249,95,26,7,19,69,2,108,2,160,254,21,1,215,2,178,8,104,33,213,255,247,8,193,36,98,4,194,29,93,7,168,4,104,250,177,251,218,33,226,247,109,254,5,249,36,6,104,247,231,225,169,229,3,251,52,251,187,3,189,29,0,250,82,33,71,22,70,21,155,16,171,252,46,19,42,6,16,11,250,4,206,245,243,0,4,11,183,3,24,36,81,6,93,2,157,229,88,245,230,233,26,15,99,255,191,4,234,222,10,248,67,255,171,40,20,29,136,254,151,1,152,251,2,3,102,254,247,1,171,6,18,3,239,253,82,0,229,255,8,84,230,254,81,0,151,251,82,253,213,253,114,10,157,255,4,5,168,8,214,4,148,1,186,242,242,3,126,15,146,251,134,245,142,55,211,249,51,38,166,251,80,3,113,7,81,8,159,240,122,237,205,4,115,31,8,239,74,15,177,16,109,253,159,0,92,251,204,248,144,3,24,251,34,254,226,192,203,244,191,3,208,247,138,247,56,9,181,30,98,245,42,231,229,29,239,25,89,243,102,249,38,251,111,13,230,4,70,252,92,2,104,68,224,254,108,9,211,0,214,254,96,10,159,235,22,249,124,3,187,7,54,250,170,13,216,255,184,40,242,251,186,248,177,38,42,1,77,0,131,8,164,238,20,10,235,247,183,230,61,0,84,0,11,4,123,253,106,253,200,252,25,253,152,255,86,248,132,255,112,19,254,234,26,251,113,228,110,242,57,214,26,251,243,9,74,253,122,12,174,255,182,245,230,0,102,1,244,255,58,6,166,255,86,2,180,255,112,173,2,251,78,3,172,255,3,1,24,246,166,238,33,9,186,249,64,243,202,243,177,253,241,250,120,246,224,245,136,42,189,22,162,252,50,236,162,40,119,214,159,0,156,245,126,3,192,247,18,249,148,14,4,252,166,1,15,37,72,6,32,252,254,7,19,1,76,214,46,10,25,252,221,1,180,248,102,249,156,18,237,230,130,226,223,31,17,2,4,9,118,254,166,246,10,11,24,26,240,1,44,14,122,253,114,12,111,253,44,247,120,250,14,220,240,1,224,25,137,9,18,6,109,247,246,222,125,242,210,1,50,26,32,4,183,221,60,21,96,240,198,243,186,18,17,232,216,7,66,6,195,0,46,2,174,250,144,252,154,245,254,37,191,217,173,11,146,243,182,246,198,250,62,4,182,237,116,1,113,254,121,43,167,253,102,253,86,20,174,251,106,1,83,12,72,1,122,217,207,2,66,6,230,3,218,246,89,3,230,5,220,1,88,28,44,18,138,233,129,236,3,18,14,34,174,238,233,239,161,254,186,249,247,251,123,241,1,14,165,36,198,249,188,19,10,227,51,255,52,9,195,232,222,221,246,5,210,248,152,18,188,234,111,2,112,0,209,244,78,22,56,19,25,37,175,14,252,41,55,255,204,2,235,2,1,246,19,240,63,254,27,253,120,255,233,250,196,253,94,7,38,252,223,214,205,255,80,5,114,9,116,0,46,250,136,7,7,217,112,18,227,0,52,212,146,14,76,244,20,5,207,38,100,1,246,237,128,254,204,3,102,12,148,14,221,252,106,10,22,3,19,8,39,9,71,251,93,216,21,0,106,35,44,238,204,9,80,255,8,1,106,38,32,13,110,28,170,36,6,251,10,2,206,255,54,16,140,252,80,2,80,253,53,1,14,81,160,2,210,250,166,254,110,1,10,8,161,253,121,2,108,2,91,253,74,1,69,0,176,1,63,1,180,1,212,254,85,85,194,254,92,253,64,1,126,254,121,3,44,253,142,250,152,245,81,254,254,7,120,255,144,21,44,26,168,4,147,22,170,36,43,242,250,233,3,193,253,254,33,2,245,254,180,7,194,246,213,255,103,2,251,0,235,3,44,252,214,8,233,214,134,47,215,7,140,252,232,249,30,251,21,254,74,254,52,3,188,4,184,13,98,1,214,251,210,255,98,0,59,1,84,33,176,3,239,250,75,31,5,4,129,254,186,249,67,223,142,249,36,11,66,252,221,6,82,239,112,8,189,219,102,11,122,241,32,255,10,24,217,233,180,14,214,253,94,20,34,246,225,255,35,2,6,0,97,6,46,238,144,5,153,4,158,252,112,6,141,2,168,23,203,248,9,251,162,254,84,2,18,247,165,38,62,230,75,4,118,2,231,253,230,0,204,3,122,255,21,254,79,0,50,1,182,255,253,0,208,0,244,248,73,0,123,211,122,1,45,50,235,248,86,1,73,1,141,4,38,2,44,2,141,255,243,2,117,0,207,9,4,1,91,251,130,250,8,250,74,7,228,12,50,218,1,4,173,40,199,0,62,11,12,242,253,33,153,248,91,251,192,253,200,242,94,255,142,213,181,12,13,251,91,0,229,8,170,255,190,242,176,25,85,246,144,251,57,239,182,249,128,224,41,1,52,221,175,238,118,244,174,255,94,211,254,237,15,8,242,5,220,224,17,254,7,7,106,11,197,235,159,252,131,18,64,43,87,15,29,254,153,212,185,246,104,250,186,4,194,250,114,9,152,6,84,3,192,255,133,0,26,238,32,228,62,41,167,242,166,243,241,7,77,12,22,244,228,9,56,2,116,246,242,15,213,244,146,215,137,236,233,25,230,0,66,23,140,251,111,253,26,252,132,4,224,2,66,221,64,0,171,3,252,254,88,249,242,253,206,250,155,252,133,246,89,48,16,5,136,255,192,214,2,7,126,220,207,5,250,27,7,2,130,254,94,243,190,255,14,5,59,9,202,5,242,1,43,240,16,253,102,255,181,253,219,254,149,64,65,0,69,251,130,6,35,1,4,11,174,8,2,0,97,3,88,1,74,251,66,251,142,247,138,34,55,43,211,247,104,7,167,252,112,255,65,1,180,218,112,17,174,19,230,254,136,4,62,255,55,3,151,13,214,223,202,22,192,254,202,27,72,255,153,245,106,210,216,1,35,248,254,250,38,17,101,17,178,247,77,246,124,252,138,231,67,247,229,253,146,251,164,0,170,1,247,220,46,249,88,248,236,31,177,247,20,178,145,2,56,253,88,1,69,254,202,1,204,253,56,0,244,2,99,255,18,1,212,250,212,242,165,11,123,2,18,219,204,236,68,11,12,9,8,32,84,250,87,8,249,6,226,251,82,0,143,19,188,239,130,2,25,36,227,19,234,3,163,9,39,223,170,252,163,252,243,246,149,1,238,248,231,252,29,225,240,1,19,252,45,13,8,252,55,37,226,253,136,6,111,220,24,1,162,43,17,1,140,3,89,0,23,255,98,42,102,3,180,1,94,6,0,13,13,254,227,19,200,4,175,35,32,254,146,251,124,9,168,244,213,19,222,7,43,11,181,16,83,30,15,34,46,211,83,6,143,4,140,243,217,251,79,254,61,239,86,10,0,4,216,7,61,1,234,2,71,1,168,26,150,4,18,35,134,20,12,221,120,255,214,245,94,250,70,253,74,252,8,7,40,1,8,252,117,6,187,14,146,219,184,17,121,27,121,18,230,25,18,4,167,0,221,44,50,48,109,255,18,11,99,2,52,7,199,254,230,1,108,252,137,252,113,250,130,2,242,0,75,0,173,248,123,253,41,251,186,247,178,5,240,254,89,249,181,3,10,3,66,85,214,0,216,250,54,1,120,10,250,249,102,247,48,4,124,255,237,247,247,241,155,223,165,215,70,35,146,1,114,245,168,11,220,208,98,12,182,251,105,251,92,251,182,11,135,4,80,249,120,252,236,0,42,0,55,3,36,2,222,253,94,248,117,62,92,247,94,7,252,8,245,8,46,10,89,11,61,9,66,251,56,6,82,5,94,247,138,6,156,248,201,58,12,252,248,244,232,252,73,211,136,43,245,18,155,254,50,251,236,2,188,4,218,254,88,254,96,245,78,0,155,247,198,3,114,30,109,6,138,0,59,253,208,1,30,14,188,215,54,1,138,237,146,241,64,4,192,253,178,2,68,0,111,255,46,243,192,219,191,218,6,251,130,12,76,2,254,6,157,5,40,15,245,248,126,251,234,58,172,246,46,249,139,252,219,8,21,7,152,6,241,251,47,38,94,1,146,12,54,41,24,4,109,241,92,241,189,13,114,252,105,253,99,254,235,251,44,251,8,255,124,255,84,251,12,0,199,61,141,2,149,5,141,254,254,15,22,244,55,2,108,234,136,212,91,239,137,7,73,249,44,32,174,2,29,5,223,251,53,253,230,245,47,5,218,255,220,231,171,13,224,247,20,35,158,248,62,0,20,252,236,12,177,22,110,233,231,240,158,253,180,0,249,253,57,12,40,35,71,6,36,33,40,240,133,18,117,238,157,254,212,250,179,4,184,248,213,252,133,193,135,255,45,5,207,252,134,247,135,233,219,2,173,248,18,247,23,220,205,254,247,0,165,9,54,249,254,207,31,0,4,4,158,2,190,255,192,248,58,2,42,242,183,242,144,0,192,254,244,253,184,0,96,252,186,249,226,42,214,243,99,221,187,5,132,4,104,3,84,32,23,22,73,253,228,10,149,14,107,8,4,248,236,215,147,6,67,7,249,254,46,70,237,255,85,6,50,0,251,254,209,239,221,4,234,255,228,249,41,3,158,9,187,224,223,4,65,250,5,253,106,249,70,253,52,11,28,3,196,15,168,241,201,43,78,4,103,219,16,252,249,4,118,252,150,238,106,6,74,243,235,13,162,255,133,231,164,253,239,33,84,9,166,8,223,6,148,225,200,16,213,226,219,13,176,12,77,3,152,225,109,247,214,255,207,20,22,252,181,240,27,238,65,251,105,252,140,242,22,20,174,248,52,244,189,245,105,4,152,238,48,7,48,211,110,252,34,231,167,13,41,245,228,1,29,233,212,3,81,248,70,5,161,3,200,26,144,240,219,242,234,5,255,28,93,253,44,247,139,23,0,244,12,231,124,241,162,246,188,21,167,5,170,255,156,4,41,251,164,250,77,254,222,250,70,248,174,3,30,248,3,4,192,2,193,79,162,255,41,251,252,0,85,255,180,251,148,6,121,5,111,2,158,254,142,245,78,236,34,253,25,230,163,29,37,19,196,249,150,26,134,16,165,252,157,252,242,4,227,240,124,240,12,6,231,236,251,10,215,8,164,9,98,1,203,231,2,251,155,7,43,22,116,41,62,249,8,8,186,255,218,11,185,253,111,3,121,241,81,222,39,251,54,3,200,22,163,0,205,251,240,252,142,1,146,4,51,253,138,254,88,3,158,171,89,0,255,253,4,1,86,3,128,4,250,2,167,253,11,2,149,255,9,4,85,7,80,250,226,0,234,174,109,1,17,221,25,5,193,0,180,3,39,1,136,10,163,243,66,248,121,246,43,4,22,208,6,252,72,13,78,255,203,7,225,45,41,7,57,38,147,4,70,2,204,248,157,0,38,251,16,240,96,3,21,249,95,239,209,2,86,240,54,31,142,0,218,2,184,7,33,230,29,18,30,227,137,251,189,252,13,13,196,6,158,227,64,254,3,21,34,1,63,7,65,27,237,25,95,230,166,250,25,249,47,245,91,251,32,15,225,236,185,237,66,15,128,249,234,5,228,30,232,224,205,239,45,251,86,249,242,12,144,0,132,6,223,218,220,8,51,16,211,9,85,250,75,25,139,6,106,0,213,3,201,0,53,1,60,0,123,255,40,254,49,2,132,254,106,4,91,0,174,203,46,56,24,254,192,251,207,252,100,0,49,1,219,8,223,9,208,249,227,3,107,233,255,241,222,248,35,3,244,239,191,243,79,47,45,255,70,3,15,19,84,248,64,249,6,54,36,8,241,210,152,2,61,246,163,242,65,253,176,17,200,3,240,3,22,209,216,3,98,10,166,1,132,5,20,42,168,8,61,239,49,5,236,246,88,9,19,248,34,48,29,4,169,0,91,49,122,252,194,255,98,253,65,244,6,243,124,244,25,7,64,214,16,251,157,7,174,10,48,4,107,250,37,8,72,40,107,249,175,238,249,250,108,218,148,251,20,0,102,2,166,9,5,11,46,23,198,13,28,44,50,0,86,205,84,209,90,4,188,7,79,252,55,253,19,235,182,14,65,254,201,3,199,8,78,46,100,8,151,207,238,5,98,2,175,17,140,4,67,5,114,250,137,2,141,2,87,3,232,255,200,117,20,0,204,253,247,244,245,255,128,250,176,255,239,0,49,1,165,243,170,252,56,2,238,255,140,239,109,254,32,1,63,244,229,0,128,251,6,64,147,252,54,254,60,1,128,255,123,208,64,4,196,252,122,213,243,254,235,2,254,251,180,6,88,213,12,220,205,243,190,3,16,232,252,254,173,252,12,250,174,246,184,230,228,0,107,10,86,12,116,255,183,6,26,9,86,245,8,12,44,0,127,61,137,247,139,210,161,253,220,1,152,1,39,207,186,248,156,248,72,254,55,241,212,246,205,4,174,254,74,254,227,252,237,116,53,253,110,1,59,255,64,2,68,255,228,1,240,0,20,237,144,4,226,251,95,3,107,3,217,254,37,193,76,248,136,15,249,14,240,11,254,252,243,3,230,243,165,0,133,15,105,219,238,255,213,254,10,212,237,3,196,33,60,198,36,247,84,10,38,223,66,2,121,8,2,253,204,10,74,9,210,12,106,245,188,29,226,253,226,208,123,246,98,254,6,254,164,215,172,10,71,3,223,245,155,3,135,4,223,251,91,227,170,255,16,11,64,44,176,249,210,254,47,17,221,253,219,23,255,38,11,229,171,255,224,253,204,236,110,1,14,19,42,222,145,28,16,244,253,251,77,9,202,34,154,227,253,1,156,251,48,246,156,249,198,22,20,233,65,9,92,243,13,49,103,245,249,49,115,244,152,6,172,252,115,18,134,255,224,246,166,237,230,250,25,227,214,247,95,248,31,250,7,13,102,213,218,245,42,5,252,9,42,28,239,249,238,4,86,7,33,214,210,6,80,245,168,5,30,34,126,218,60,3,216,6,160,249,101,31,168,10,50,2,169,248,180,214,224,253,50,247,51,248,16,231,169,255,10,233,39,254,242,1,112,244,190,233,20,211,23,7,2,8,220,28,110,20,222,10,226,21,2,2,206,254,222,50,11,2,232,213,178,252,204,2,14,1,22,13,123,232,140,5,225,231,70,248,127,15,92,45,248,12,252,239,92,246,243,17,38,235,65,0,150,13,19,0,173,13,232,193,201,250,187,248,104,248,95,15,46,14,19,18,252,232,54,254,127,1,45,255,174,253,91,255,33,97,112,253,252,8,108,254,1,1,214,0,125,253,250,8,76,255,35,0,110,19,66,3,26,252,54,249,73,21,250,219,150,213,92,16,187,35,249,233,101,249,222,3,103,248,93,13,57,242,45,35,10,248,191,246,234,19,199,3,224,61,196,0,124,243,201,251,248,252,30,46,184,250,251,247,219,7,53,1,130,2,5,6,70,250,143,238,23,26,124,22,50,29,198,255,184,248,20,23,216,249,90,137,120,252,197,253,144,251,169,1,234,255,154,2,126,4,34,253,82,0,230,4,30,255,75,254,134,252,184,5,216,242,219,3,147,209,103,4,200,227,80,7,250,223,71,34,121,245,177,5,254,58,125,252,152,250,73,248,99,7,56,12,185,5,143,249,173,250,203,5,47,1,234,253,249,255,82,249,159,250,1,3,154,49,229,220,222,252,28,18,60,2,212,7,71,242,186,1,121,217,143,12,58,238,90,8,6,239,50,22,45,43,52,28,114,38,29,3,137,250,137,245,31,233,161,247,169,12,26,9,248,0,138,253,20,4,127,2,152,242,125,0,67,86,184,7,21,252,45,3,40,2,197,253,6,17,200,231,51,14,63,21,132,253,233,0,8,237,65,242,52,254,44,27,137,239,1,6,215,30,86,54,43,226,112,5,36,6,136,2,106,14,60,248,97,246,26,243,165,2,100,252,233,253,119,232,30,16,10,28,207,239,96,19,188,248,82,213,66,250,222,218,30,255,254,254,32,0,33,254,174,8,94,0,94,44,144,15,84,245,63,8,178,253,116,246,168,254,87,254,86,2,154,250,67,251,32,187,30,6,107,5,63,242,199,255,219,248,180,18,62,2,50,255,26,31,197,35,59,25,198,249,181,250,10,19,42,4,214,7,1,7,111,226,65,9,84,4,25,5,26,244,28,201,56,249,51,240,24,239,73,29,232,12,238,5,222,233,239,253,160,16,59,18,164,3,41,250,82,215,98,254,194,247,178,243,30,251,161,221,93,254,42,20,49,33,240,221,22,253,57,244,3,25,15,15,182,28,165,0,197,255,66,252,148,22,156,23,200,6,200,11,31,0,244,3,94,13,174,29,75,229,212,247,214,8,27,24,134,215,196,247,184,250,6,7,248,236,31,231,203,9,80,10,186,23,43,7,132,11,132,1,142,1,177,219,248,234,216,247,48,8,230,2,214,12,185,1,223,27,192,247,26,217,20,234,175,9,51,21,126,216,94,253,52,1,243,251,2,3,2,2,76,7,4,255,131,209,40,252,158,2,202,9,20,21,233,251,153,35,143,213,8,19,184,6,178,8,179,3,224,246,89,10,173,0,72,250,198,244,111,17,10,251,101,13,98,24,252,234,164,225,58,238,253,222,253,7,217,244,216,20,38,197,94,254,234,236,120,253,152,14,177,3,68,252,39,237,140,255,130,0,97,7,170,37,206,14,237,238,12,28,236,249,162,25,97,247,26,225,250,1,166,171,150,2,174,254,81,252,2,252,53,25,45,1,48,254,55,254,72,3,241,12,194,42,218,254,220,31,138,0,111,250,93,9,232,252,68,25,7,18,1,254,66,62,238,1,18,1,168,232,108,253,54,15,164,247,144,5,211,7,5,16,7,11,232,79,96,248,211,249,101,3,116,2,76,0,124,5,220,15,252,1,151,243,78,252,80,244,118,9,115,4,117,248,16,255,243,3,109,1,174,251,237,81,98,250,116,1,137,0,222,251,147,4,28,251,234,10,154,5,22,7,226,1,108,15,112,245,198,79,15,255,185,1,159,251,243,1,12,4,106,252,236,37,162,243,24,254,117,215,127,243,122,235,177,248,33,22,178,206,89,226,127,0,189,5,37,247,21,7,155,239,17,8,166,253,117,254,116,253,77,1,86,181,188,251,214,16,54,6,152,6,83,250,177,0,50,17,144,4,84,23,241,250,70,243,6,6,32,237,49,13,87,234,218,241,176,236,16,8,226,244,182,31,179,252,134,229,200,241,97,22,117,252,1,213,251,255,74,10,146,212,60,8,144,0,243,51,251,0,80,1,51,2,181,255,188,11,169,0,204,240,197,5,42,4,221,249,167,251,192,251,5,2,209,1,175,170,251,249,186,251,49,7,3,220,186,187,126,6,8,0,168,4,150,4,246,3,229,233,73,253,60,1,215,235,11,7,224,251,191,246,153,244,125,11,16,218,183,7,170,1,206,43,240,8,42,24,76,227,10,244,13,13,180,12,250,239,166,254,148,252,80,228,254,242,155,17,54,1,160,249,43,1,180,245,76,245,16,253,175,39,223,227,160,218,62,12,94,240,215,255,175,9,232,248,237,200,247,13,137,4,27,25,94,246,134,1,165,248,135,231,14,251,249,254,194,5,176,253,14,173,94,0,91,16,1,0,155,12,55,243,158,7,150,1,31,2,125,6,168,245,220,219,0,248,157,232,46,253,68,19,198,238,216,48,220,249,196,8,234,21,51,1,18,218,198,241,220,230,16,17,140,11,35,247,204,231,229,15,2,253,145,241,88,13,102,233,60,218,157,45,184,4,59,252,236,5,108,4,250,3,232,231,178,7,139,215,99,5,43,253,171,221,146,14,191,255,106,237,230,248,230,251,169,37,167,17,70,11,107,10,204,24,132,9,74,254,186,7,98,219,250,250,53,15,231,247,65,212,223,247,17,13,140,242,248,218,106,9,194,7,179,248,180,12,61,23,185,247,111,254,42,255,88,13,213,251,78,72,86,244,182,13,252,1,155,254,187,252,75,251,68,11,67,45,45,45,213,253,152,245,151,252,58,14,236,247,198,6,200,238,74,1,75,255,178,250,127,5,245,217,41,3,37,216,238,247,112,13,241,247,166,12,150,14,135,6,238,2,234,26,228,15,214,4,237,1,206,250,76,0,214,34,103,42,85,0,204,47,242,13,206,251,192,11,48,219,142,243,247,4,132,254,99,255,146,236,79,41,158,250,37,255,74,5,203,249,184,42,220,8,53,241,240,251,143,29,156,3,250,40,218,252,218,250,216,249,47,255,93,0,95,241,20,241,183,1,156,217,135,231,160,252,110,122,35,0,52,5,187,1,178,253,78,3,104,0,100,3,161,252,246,5,192,251,230,44,113,228,236,13,109,0,0,244,70,247,78,238,74,7,159,242,212,38,86,12,227,248,88,253,156,251,68,11,167,4,195,255,30,218,172,29,210,253,197,220,99,251,208,0,194,250,188,255,200,254,38,1,68,250,130,5,39,0,167,173,212,2,167,247,167,3,248,255,199,215,181,13,146,230,98,230,6,229,143,248,123,7,32,23,233,220,88,13,132,28,164,250,114,250,30,7,63,215,30,246,133,6,42,2,64,244,233,242,102,252,87,32,192,235,144,21,177,18,171,2,6,254,50,238,146,7,250,32,161,206,202,255,165,244,204,252,20,39,244,6,229,1,121,5,54,241,18,3,207,232,72,10,252,249,204,3,242,242,246,8,140,31,18,252,211,45,223,248,220,11,61,4,136,4,48,218,103,43,158,30,56,246,192,247,72,9,230,9,40,14,43,2,26,14,248,253,193,252,241,255,14,254,167,0,199,2,99,167,25,252,70,250,149,249,118,254,28,21,105,239,253,246,212,15,124,251,40,251,22,254,194,249,243,238,66,223,253,40,208,1,48,191,139,14,227,225,203,252,134,239,102,252,142,1,3,22,136,8,226,19,24,228,116,9,24,3,188,254,2,251,100,12,45,51,72,6,100,240,85,247,179,11,244,228,48,3,78,246,106,254,130,13,247,1,38,224,132,13,238,9,137,241,76,33,195,255,82,254,172,90,179,4,31,9,180,21,36,254,155,3,203,253,81,2,181,249,22,7,178,249,101,228,91,248,182,39,46,239,91,254,70,240,62,7,103,217,155,2,40,30,166,244,91,27,225,248,200,24,90,222,107,244,96,245,194,255,222,252,153,7,222,17,4,238,107,223,6,2,41,242,95,0,90,239,156,235,123,255,30,40,207,7,162,12,196,34,254,236,132,241,143,238,190,17,241,9,234,6,83,27,231,13,109,4,128,251,88,57,234,3,122,2,143,205,150,6,147,249,252,248,206,255,112,0,172,251,46,4,174,2,44,4,19,6,128,3,170,13,218,40,224,255,241,46,31,253,138,2,80,254,148,1,170,0,121,42,72,7,74,249,53,43,236,249,74,241,225,0,87,27,194,6,249,228,153,248,153,244,58,32,66,39,233,237,48,250,63,237,32,250,80,245,146,255,210,241,64,245,102,212,104,4,236,245,172,45,90,253,58,5,127,8,114,232,104,2,115,6,134,228,15,244,116,9,206,7,31,17,71,249,246,213,84,254,86,11,118,252,54,239,93,8,38,251,88,21,161,253,13,21,14,221,206,240,132,42,8,6,116,2,79,248,78,54,222,249,200,251,79,253,188,237,198,241,241,2,169,211,146,255,24,253,190,16,139,4,33,12,24,38,135,43,200,16,94,249,244,3,236,8,35,252,66,252,247,218,226,2,24,0,170,1,102,6,58,15,181,34,122,11,134,221,166,11,113,249,18,33,117,253,24,20,176,10,239,2,172,255,30,30,5,12,69,11,146,0,178,251,247,245,9,248,51,43,34,217,232,251,249,251,223,255,2,236,184,251,62,248,2,9,96,9,104,36,44,24,244,1,42,8,61,0,163,211,118,0,225,5,8,4,128,248,92,255,240,217,194,237,235,212,154,255,64,252,1,252,246,245,6,16,107,240,42,211,4,3,21,250,178,251,110,247,186,6,85,251,48,224,234,2,194,218,178,12,150,153,70,6,122,254,72,253,10,1,77,252,49,2,10,250,248,255,56,4,69,255,39,22,201,8,226,255,223,239,0,253,100,213,242,14,74,215,112,255,21,251,164,250,31,242,7,5,225,235,42,25,19,236,106,5,23,3,199,249,142,50,4,253,168,1,188,231,5,38,190,2,7,218,12,2,46,237,48,251,6,0,28,254,206,252,187,3,25,25,10,14,36,20,226,254,234,5,114,17,36,249,57,44,89,253,55,250,35,254,177,224,13,244,124,17,167,2,137,251,61,11,21,10,158,12,239,0,242,46,195,249,119,52,76,46,4,1,234,12,54,253,19,5,233,238,246,252,170,0,203,253,74,242,24,230,26,13,13,23,210,251,232,232,154,242,150,236,152,237,88,10,103,220,25,6,234,3,229,233,151,243,126,2,241,8,230,251,22,48,132,215,14,11,63,252,62,255,214,230,158,8,126,13,217,247,231,16,56,4,17,40,171,31,40,19,187,243,221,246,144,29,149,254,181,14,24,31,155,27,216,5,254,240,13,7,111,9,145,3,151,249,221,234,97,226,245,17,212,250,66,11,46,44,246,245], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+471040);
/* memory initializer */ allocate([195,244,216,13,34,18,55,247,198,27,205,254,171,242,201,244,242,220,42,231,185,233,206,15,83,0,95,7,108,242,6,239,77,244,166,254,210,255,127,86,192,253,37,10,184,2,240,5,140,0,121,11,228,242,36,252,250,15,34,251,237,242,107,5,216,8,2,5,128,27,218,252,246,205,175,251,255,127,86,239,108,0,50,248,88,253,1,251,45,254,146,255,206,1,0,3,142,6,128,5,160,248,165,251,214,36,220,22,6,242,247,20,184,251,42,239,140,218,254,16,160,23,212,9,142,12,116,17,236,254,71,59,176,252,197,244,198,254,142,232,33,210,192,1,22,36,46,244,162,240,24,11,234,247,58,7,188,1,255,1,226,253,42,227,114,23,145,199,38,250,176,0,44,3,184,245,13,247,16,243,113,15,114,1,150,247,142,6,94,251,18,231,8,6,206,13,73,241,221,226,97,28,56,243,173,41,115,249,122,228,113,249,124,255,60,8,100,248,134,244,239,234,178,231,227,211,18,8,213,3,37,253,77,7,93,247,230,13,247,171,90,253,19,254,217,247,245,0,123,2,37,248,12,243,133,52,41,8,54,216,90,4,39,251,73,8,255,246,244,12,254,250,173,10,62,1,206,13,236,18,97,250,228,34,31,226,212,253,161,226,142,242,204,19,38,242,138,33,23,223,234,27,85,253,153,2,236,11,235,245,248,0,128,223,222,8,133,27,224,252,2,23,139,8,5,255,8,246,229,240,81,14,149,249,19,210,90,234,14,7,85,14,4,254,148,242,88,2,172,40,206,234,144,6,63,238,16,45,189,248,186,234,14,238,52,239,107,251,26,1,52,8,4,246,14,37,99,227,172,227,173,243,249,252,150,202,176,16,250,11,136,36,111,6,112,4,26,3,248,253,114,253,3,6,60,247,83,12,249,208,219,2,51,13,144,248,210,26,197,37,176,246,51,8,134,246,97,6,226,242,226,233,116,8,183,41,46,235,154,27,194,22,69,255,24,237,106,251,146,241,208,3,12,246,244,8,67,242,17,252,55,240,172,2,118,197,75,237,217,239,232,238,74,214,54,250,30,215,247,13,88,248,113,12,174,4,60,255,132,252,208,234,194,18,40,53,164,225,112,15,52,17,204,255,73,4,110,12,117,245,132,3,22,251,137,224,226,243,16,3,242,245,20,6,36,4,215,234,25,2,215,46,118,253,25,254,246,215,110,26,124,241,38,4,221,9,15,4,70,244,110,22,10,254,25,238,112,255,112,255,248,232,46,252,250,6,116,250,152,7,126,255,174,235,214,249,141,30,101,210,252,38,201,19,54,23,150,254,216,63,223,252,140,7,218,4,246,255,23,3,86,255,92,246,33,254,225,12,232,16,209,44,243,249,228,207,209,0,203,6,83,7,25,5,42,239,7,205,207,236,248,35,58,252,10,10,118,255,122,3,93,5,212,250,59,252,115,33,120,226,234,1,144,250,63,22,232,233,55,21,134,15,149,251,34,251,202,250,237,240,178,243,80,205,239,228,153,2,177,36,234,1,164,8,18,0,30,2,229,0,171,240,44,7,127,16,148,20,176,4,215,1,20,0,70,217,114,233,170,32,41,23,81,228,213,7,8,61,90,6,43,21,44,250,0,250,95,254,165,7,25,10,108,254,155,251,248,8,84,2,68,3,156,254,233,2,6,245,63,11,206,246,78,171,148,255,214,2,162,252,81,2,214,255,10,1,180,250,185,247,157,76,46,3,158,9,132,244,222,0,11,14,2,22,217,252,195,4,142,9,34,22,209,248,180,27,171,214,240,235,152,246,94,22,164,251,212,246,82,231,31,35,94,26,55,235,80,227,110,247,88,234,169,6,212,48,109,35,82,248,206,236,177,8,209,13,51,250,235,235,178,1,172,249,249,234,58,253,189,234,90,15,170,27,155,2,39,243,126,243,207,247,178,7,129,210,145,244,206,247,191,250,121,13,229,247,6,1,12,253,37,7,241,254,244,250,55,4,142,233,168,254,76,14,152,238,9,14,28,226,169,250,196,252,14,247,39,4,138,16,68,187,113,252,76,232,16,4,116,244,144,10,227,6,206,3,60,12,185,2,243,4,240,0,112,234,176,207,78,42,135,253,205,232,3,9,76,7,88,247,19,251,85,2,98,231,231,235,222,13,95,29,205,228,168,14,108,3,136,248,30,0,24,220,51,4,232,237,148,35,115,4,143,3,74,36,244,4,18,252,74,249,244,229,222,12,26,250,127,25,200,1,136,250,160,44,184,239,156,240,130,18,1,237,174,11,130,12,71,254,120,237,15,18,1,239,157,15,248,212,31,253,136,0,42,31,39,241,74,16,18,14,87,247,81,3,8,246,40,169,67,1,193,0,252,255,250,251,78,2,89,6,136,12,157,214,64,10,27,253,65,51,236,251,65,6,55,20,151,8,7,241,12,7,246,246,25,3,34,211,113,253,8,243,97,244,225,15,204,243,62,253,160,227,242,251,246,243,129,234,21,228,175,32,181,4,188,251,98,249,202,251,64,45,8,0,43,251,227,247,4,38,99,19,220,10,162,2,69,2,34,32,49,251,220,219,132,2,44,243,24,253,255,127,211,255,166,1,141,251,228,251,219,247,73,253,156,253,171,5,224,254,58,0,146,252,53,0,96,11,157,248,20,228,101,7,212,11,165,0,195,3,212,8,32,225,225,22,120,182,199,245,250,251,152,252,220,5,94,4,23,253,143,0,76,254,215,4,0,241,249,6,54,246,13,79,254,251,236,249,165,250,108,253,95,251,171,3,35,5,182,241,204,234,75,2,247,239,60,6,68,49,149,22,148,4,94,242,98,251,179,254,114,24,222,245,96,8,34,237,66,255,180,7,127,10,47,5,37,252,58,197,51,18,185,255,234,26,52,6,77,237,222,16,136,241,240,1,31,234,162,7,30,251,195,242,220,235,22,36,250,8,175,236,183,0,12,248,114,0,218,47,230,246,71,0,189,242,134,250,84,14,19,2,163,42,138,4,58,30,129,35,30,251,220,5,213,24,131,4,26,236,175,245,121,6,214,1,230,7,23,2,206,254,145,185,121,252,97,11,146,234,233,6,117,250,122,35,101,8,188,13,48,27,65,3,99,4,242,4,136,6,78,253,162,37,86,244,189,237,238,3,99,247,153,244,123,243,57,245,107,0,93,252,34,218,36,9,162,252,34,245,204,241,58,219,92,37,33,4,216,33,46,5,88,15,172,5,172,237,147,242,162,33,30,215,18,230,193,244,80,13,93,3,15,244,201,252,164,0,81,12,142,241,179,194,138,252,176,5,206,12,240,231,199,255,86,4,22,0,87,244,131,28,198,251,15,225,76,208,224,1,35,226,45,255,50,6,34,15,170,12,141,252,74,26,195,249,6,254,160,14,128,29,73,226,191,255,94,250,10,1,28,39,58,6,188,245,76,27,231,251,252,253,77,253,160,2,49,19,252,6,125,58,86,1,194,3,44,28,100,4,244,1,111,4,201,254,46,15,4,49,56,21,75,24,13,13,134,255,4,22,215,26,177,213,170,15,156,216,176,5,96,20,11,252,78,4,68,16,46,250,190,235,14,255,110,238,250,12,0,14,128,247,72,22,3,2,220,210,166,5,207,16,168,240,125,239,156,227,181,23,190,211,54,3,250,247,37,244,44,246,232,248,44,241,216,32,145,34,42,244,247,223,125,4,220,28,12,4,26,10,242,21,30,247,83,236,39,250,128,1,174,5,218,31,136,6,151,246,19,13,202,51,45,252,1,2,146,30,102,10,26,7,161,21,176,251,85,10,120,214,193,221,221,233,251,251,38,3,176,220,180,237,24,3,112,236,81,233,172,240,196,3,57,1,39,246,82,4,160,233,222,52,114,224,120,16,148,250,228,245,218,3,56,199,126,250,133,13,80,5,188,250,152,255,213,5,214,244,212,244,253,7,154,71,206,18,212,241,63,253,100,243,108,253,152,245,56,10,196,17,169,14,38,6,217,250,170,251,44,2,232,12,13,245,252,50,240,17,106,11,99,53,238,246,16,244,99,245,174,0,130,239,56,239,241,225,86,5,250,6,17,4,146,255,51,248,6,16,193,248,124,252,203,0,31,5,84,13,11,16,81,88,240,239,171,1,72,246,1,1,13,251,3,251,226,230,231,227,171,41,143,17,35,239,190,26,157,51,167,28,52,252,191,243,79,1,159,253,59,12,102,9,78,241,103,8,188,235,5,226,20,8,21,248,138,14,251,252,52,243,3,6,50,225,237,3,125,53,249,17,62,223,4,254,30,22,231,236,93,0,149,214,211,15,254,255,70,4,223,236,30,247,183,246,180,8,125,234,48,254,129,242,29,255,217,36,157,31,59,247,117,14,233,251,85,229,245,7,134,7,230,241,196,195,187,253,17,232,229,247,197,9,88,247,9,21,7,247,156,245,27,6,172,12,138,5,36,248,148,11,203,47,109,222,168,10,43,242,145,230,30,43,62,44,73,255,178,251,14,4,200,4,20,0,161,5,163,254,216,4,199,225,94,252,131,5,33,27,34,16,24,203,191,245,222,13,77,12,38,253,234,29,26,12,161,2,45,247,252,9,7,6,198,5,73,252,64,224,87,19,143,46,236,17,0,223,16,3,22,211,140,248,18,10,120,11,184,226,54,233,195,7,79,13,219,239,196,236,188,250,236,250,148,3,131,3,33,79,235,7,170,5,36,17,92,241,6,15,139,8,122,251,112,18,227,241,192,20,215,15,192,1,17,231,166,221,72,247,128,7,66,3,207,105,14,253,90,0,130,5,39,252,155,250,195,255,138,2,56,4,123,27,44,245,47,251,98,52,142,17,40,254,176,244,37,236,87,247,110,233,181,1,59,229,132,19,114,13,204,23,159,230,225,240,184,15,126,252,183,255,5,244,23,245,8,22,188,23,106,246,14,14,235,254,136,6,54,229,115,9,25,38,148,24,131,34,75,217,140,237,150,253,98,28,96,254,173,7,152,236,117,9,131,4,231,14,140,255,115,241,192,30,219,236,79,9,76,6,118,247,2,247,231,10,78,247,120,4,189,203,54,230,218,252,187,27,206,247,98,16,176,247,215,33,77,239,196,1,121,255,91,232,0,5,15,50,206,12,4,33,127,17,144,249,173,5,127,5,58,252,8,252,101,12,91,227,56,238,136,204,48,249,65,2,220,249,99,2,178,4,110,255,115,233,196,11,56,244,211,249,90,12,234,14,78,248,51,24,154,7,72,218,45,11,61,225,61,12,96,225,199,42,108,249,206,254,29,255,48,38,174,255,200,6,156,4,129,13,198,244,245,20,252,226,180,29,63,10,74,244,34,247,170,40,228,4,91,245,175,238,222,6,151,235,122,25,42,26,200,2,86,18,168,246,240,0,167,1,42,244,92,206,192,243,200,235,224,1,168,249,156,205,113,29,19,17,162,4,220,248,11,253,198,248,50,252,85,241,135,5,98,231,82,10,17,241,222,249,102,224,59,32,153,7,3,220,123,4,32,16,51,239,38,3,47,249,192,2,64,246,95,5,222,252,9,0,216,252,4,255,179,234,17,15,113,40,232,253,83,7,176,244,216,213,30,13,39,4,134,252,32,28,76,14,150,1,24,11,195,228,139,238,30,18,101,224,212,10,157,224,192,6,61,235,66,28,98,245,123,14,54,251,174,209,163,246,4,3,213,12,7,240,136,250,89,4,216,190,93,7,77,254,65,252,242,0,207,252,3,1,38,248,191,248,211,253,110,252,95,199,66,248,119,2,40,252,189,247,76,243,195,10,225,7,194,247,96,221,232,252,245,250,55,245,195,246,186,2,23,4,204,3,145,198,94,41,151,240,151,2,204,3,180,4,15,245,15,5,240,250,50,0,168,5,120,3,169,248,122,0,78,0,73,255,180,253,74,63,124,254,64,247,112,4,242,4,211,230,59,10,128,249,71,231,116,245,21,6,15,254,86,2,146,255,18,5,178,254,191,0,201,116,131,1,163,1,76,0,152,0,21,2,78,0,112,0,101,0,158,0,136,0,20,255,88,0,43,0,107,0,84,0,21,0,15,231,81,249,221,6,131,5,192,35,184,255,148,5,182,251,88,40,6,254,152,254,29,1,220,255,0,245,51,3,88,0,176,0,31,254,84,255,19,8,196,12,103,21,157,33,8,44,168,248,105,1,46,6,147,236,157,250,251,14,74,0,253,255,237,1,81,254,110,5,101,0,218,253,59,0,220,1,43,254,185,253,56,2,220,2,9,252,176,251,70,253,114,93,106,4,12,251,24,1,204,0,197,255,195,217,195,254,167,3,128,11,94,215,252,245,216,237,226,5,250,14,22,252,245,10,98,255,103,254,46,3,106,255,159,255,11,242,242,249,76,5,230,20,147,254,194,245,130,242,54,1,170,4,143,3,80,213,169,3,44,31,90,235,214,253,207,7,17,251,206,253,10,0,191,254,232,2,44,0,64,0,238,254,72,138,84,1,229,251,244,2,226,255,250,255,243,254,239,254,12,0,95,0,29,6,118,204,222,209,27,254,218,249,158,1,16,255,60,254,52,2,228,2,36,254,191,3,55,4,224,249,90,254,37,0,102,255,133,39,188,255,132,5,86,46,164,242,73,16,58,20,15,2,253,251,250,251,63,248,192,1,52,253,160,6,150,7,2,255,52,1,76,4,234,252,166,31,230,25,69,14,6,252,181,253,178,228,237,255,135,6,145,5,153,31,124,14,98,251,6,3,147,2,113,0,181,1,50,0,67,3,236,253,55,212,146,6,190,226,224,245,210,4,175,237,123,227,113,255,33,13,97,4,177,0,39,254,1,2,136,0,197,3,76,240,31,18,68,251,247,4,89,11,47,229,3,41,40,241,230,242,91,236,234,241,74,252,138,17,14,2,238,3,2,0,224,6,187,22,201,255,182,251,205,248,92,1,242,247,20,220,128,14,54,211,110,243,166,252,160,10,77,2,64,1,93,3,59,0,237,20,52,2,132,254,26,2,114,255,234,1,212,0,180,6,158,2,112,7,75,255,163,11,175,3,20,66,247,4,220,3,222,252,46,250,194,35,131,2,189,6,67,5,245,244,0,240,229,1,77,228,148,243,117,237,188,249,40,6,164,233,216,23,117,255,190,6,195,45,104,1,95,29,209,9,72,20,96,247,55,248,61,3,125,254,164,233,66,17,116,0,117,244,30,255,249,0,121,1,101,8,143,244,157,19,8,244,32,3,77,250,120,44,108,33,204,6,112,1,233,244,255,247,158,5,179,250,244,15,104,7,240,253,85,6,32,249,173,53,46,1,6,252,210,217,63,242,22,5,94,5,115,4,150,3,68,249,4,253,90,3,36,3,20,249,116,1,190,254,242,253,148,46,88,209,172,15,213,6,201,6,247,249,68,0,121,3,24,1,178,2,104,247,44,4,28,254,85,255,199,1,212,255,150,243,195,8,178,253,237,2,232,252,92,178,198,0,236,0,135,10,171,242,140,2,28,1,204,252,146,251,57,255,144,255,238,233,94,254,23,4,66,4,212,8,31,243,140,247,212,52,184,6,186,254,142,3,86,249,72,15,105,251,151,6,152,247,50,0,35,0,182,6,209,2,100,36,48,247,22,239,49,27,80,17,149,224,45,0,90,5,144,13,76,11,104,243,88,5,75,5,206,253,74,253,234,2,198,0,164,4,3,11,59,12,189,246,38,25,79,3,63,8,53,216,133,242,158,217,82,242,143,2,137,2,180,5,14,1,118,0,45,0,192,0,188,0,141,251,254,254,151,2,172,255,129,148,3,253,119,252,101,1,252,255,89,0,140,254,232,255,178,0,103,4,209,0,153,4,54,245,181,253,208,5,29,35,145,12,10,246,215,0,68,37,228,227,235,4,124,241,207,10,251,254,40,255,104,3,64,244,228,247,234,33,197,2,45,14,87,0,214,243,128,214,246,0,122,249,54,249,205,4,200,29,160,251,16,3,49,1,233,0,71,255,24,1,70,250,244,254,198,0,243,1,52,1,117,247,131,251,124,254,218,255,174,254,196,251,32,180,40,0,166,7,64,247,170,255,8,1,108,217,249,250,246,15,158,14,198,9,162,216,222,17,43,250,54,4,146,12,106,9,148,254,25,4,78,10,35,0,241,250,200,0,225,244,66,42,224,208,71,9,92,1,159,254,228,10,203,252,132,243,1,254,146,0,223,7,235,0,186,251,62,10,128,10,177,255,56,20,140,252,218,209,26,3,136,10,208,229,124,13,15,5,32,15,108,11,146,17,90,255,170,253,67,251,123,3,102,21,246,254,247,252,251,255,248,252,235,3,211,248,100,255,246,69,197,1,215,254,247,249,89,3,224,254,204,254,27,231,253,7,202,248,191,11,68,247,144,248,47,3,183,244,104,16,128,32,144,38,154,253,190,252,16,15,158,1,22,255,23,6,229,226,57,14,50,251,69,3,129,255,92,10,155,1,236,253,252,206,100,249,10,4,142,246,56,252,46,2,228,249,96,248,51,1,216,251,136,229,52,6,180,245,181,3,80,32,244,255,116,242,153,13,188,25,20,10,225,28,16,1,248,5,26,7,98,247,163,254,116,254,72,210,207,5,25,38,199,237,232,255,36,8,244,252,172,19,121,253,84,14,49,2,75,4,186,251,22,2,246,4,157,255,238,3,36,254,240,253,193,48,53,6,57,6,110,249,110,27,104,10,254,33,205,253,58,4,50,255,87,0,70,248,112,255,228,0,208,4,121,3,4,56,65,0,219,251,14,41,161,255,137,2,53,0,62,252,129,254,175,9,42,5,250,248,24,11,20,254,93,254,90,0,88,253,79,0,2,4,80,174,57,6,26,253,62,4,4,2,187,2,89,9,192,255,38,248,46,0,165,252,111,0,72,254,201,55,16,1,29,3,99,216,106,241,54,12,22,244,20,5,73,0,38,249,2,251,98,7,106,245,192,2,136,4,1,0,13,1,232,255,146,253,124,0,138,0,246,253,2,254,95,0,110,254,86,149,42,254,42,255,97,255,140,1,55,255,140,254,122,0,136,0,19,252,232,2,157,7,214,252,168,245,42,253,128,254,187,3,208,4,74,5,167,254,227,179,32,4,63,255,233,4,249,254,142,1,16,253,90,2,98,0,25,3,17,0,218,78,67,255,201,245,82,255,166,0,180,1,155,1,234,251,118,1,41,254,3,255,233,0,160,32,62,5,1,251,89,36,142,8,89,243,114,235,130,242,52,7,172,2,47,1,174,238,103,232,89,242,78,246,133,1,97,1,159,0,242,255,5,142,1,254,98,255,92,0,111,254,220,255,215,254,191,1,163,253,13,1,85,0,212,0,8,0,138,255,126,255,207,0,94,51,248,221,200,9,75,5,60,243,116,5,116,237,104,247,232,249,228,0,94,255,155,4,208,11,230,2,164,252,69,0,10,0,54,117,230,253,23,254,131,255,42,255,108,1,86,253,229,254,20,2,122,255,227,0,64,254,236,255,246,254,70,0,2,0,94,36,10,58,88,3,19,254,227,242,36,0,8,255,214,0,25,1,183,255,196,12,233,2,11,255,17,252,146,0,136,1,36,0,106,31,137,11,53,230,239,225,73,17,62,246,59,2,110,247,60,13,230,252,207,253,53,245,120,7,42,244,225,0,214,0,229,255,66,3,91,214,181,1,6,254,233,253,205,32,52,5,154,246,92,221,100,244,105,5,40,1,97,3,14,9,122,3,244,0,135,255,226,0,119,1,128,3,115,215,38,247,180,242,215,3,231,4,3,1,163,44,199,1,31,244,51,1,114,246,220,1,211,2,18,0,16,216,254,1,40,2,114,253,148,252,47,254,116,2,228,206,18,3,119,254,190,239,170,3,209,250,97,249,160,253,184,250,125,255,144,252,62,3,248,3,115,85,104,254,232,249,12,254,110,249,197,1,94,252,36,5,120,255,178,1,85,253,156,1,202,0,233,0,126,1,46,248,205,219,246,251,6,34,178,1,71,224,219,11,207,243,0,7,152,10,255,249,198,251,86,3,57,5,196,251,91,0,123,238,241,9,196,238,118,248,54,208,62,237,33,18,181,1,96,252,115,8,174,243,9,2,103,253,80,251,94,10,163,3,124,254,138,255,136,251,133,0,225,19,86,251,8,250,57,252,229,252,188,0,126,7,129,3,122,228,63,226,206,27,123,22,92,245,42,225,40,254,152,254,177,253,222,3,40,244,62,30,214,2,114,21,167,36,223,1,40,244,144,248,246,27,98,18,138,9,216,249,198,255,100,255,119,240,120,245,99,16,90,255,14,13,226,249,183,14,193,239,138,233,129,21,17,226,164,17,23,240,204,245,16,20,222,254,102,253,2,5,8,3,202,253,166,253,202,254,235,3,120,253,112,11,169,243,171,1,112,251,114,245,162,189,51,255,169,254,84,251,68,248,117,6,0,254,228,248,94,254,216,242,194,13,82,248,100,19,160,233,191,235,46,255,71,249,147,39,108,228,23,13,78,1,160,255,135,243,79,249,154,253,183,245,147,0,240,249,197,246,116,241,61,249,74,227,77,21,84,245,205,244,170,48,160,1,0,0,62,17,65,3,78,2,81,6,149,1,73,0,100,3,232,0,195,0,15,0,60,255,242,252,237,2,69,252,172,255,152,4,215,253,61,208,171,242,48,50,200,250,20,0,126,3,254,0,23,252,155,250,106,254,123,251,54,254,44,1,117,254,57,3,222,255,74,0,126,1,6,252,230,215,58,5,83,43,32,2,29,3,48,239,109,5,21,253,132,7,255,254,55,10,219,255,233,238,14,3,158,0,134,254,19,0,140,2,229,253,244,3,141,239,239,4,99,252,96,0,246,219,33,23,239,223,185,255,210,248,103,247,239,226,196,255,137,1,6,234,248,254,22,252,85,0,197,7,176,249,40,255,110,252,179,38,108,31,190,253,106,225,87,249,216,241,126,9,59,0,181,22,102,3,195,254,15,246,76,240,206,250,191,4,136,36,49,21,68,1,61,237,87,253,6,254,154,237,82,230,168,239,65,0,217,2,226,250,149,250,105,5,60,9,136,6,189,9,74,254,169,250,117,252,38,0,4,177,148,249,0,2,99,254,92,1,144,255,236,253,17,3,52,5,228,27,132,248,26,249,206,210,19,7,49,220,180,255,5,250,81,255,53,249,253,252,222,7,7,2,15,0,64,2,32,34,45,252,228,255,38,7,73,1,210,254,174,47,35,250,75,20,207,254,176,5,187,253,208,5,142,0,235,0,99,255,192,0,4,6,102,252,48,43,47,46,108,244,48,250,176,6,30,248,144,252,46,243,66,255,58,255,132,9,8,255,222,0,22,0,95,3,224,5,30,8,1,248,216,0,10,251,36,253,180,184,162,4,106,12,38,253,176,1,166,3,81,6,105,3,21,254,186,255,0,253,167,2,118,5,25,2,148,254,172,0,227,253,162,255,232,255,127,255,155,151,201,0,214,253,155,254,185,255,60,0,96,0,127,249,145,5,220,4,76,1,212,251,70,1,66,3,148,253,63,250,49,6,152,5,160,3,94,73,148,250,81,11,192,1,40,0,43,5,153,5,19,3,215,0,225,12,26,10,168,252,195,1,220,186,223,2,213,255,149,1,28,251,232,2,244,3,165,2,56,1,206,0,233,254,80,254,21,26,169,255,184,255,96,215,150,255,216,43,128,4,90,254,232,7,192,2,158,9,83,251,232,0,137,255,4,0,145,252,64,6,60,253,168,13,23,1,113,255,184,251,213,253,242,17,206,5,161,0,174,3,226,7,170,9,118,193,132,254,63,255,105,211,201,1,236,254,44,212,188,249,218,255,45,3,52,240,96,7,87,239,111,6,142,252,213,3,34,253,146,255,140,0,22,244,224,4,219,253,113,251,57,252,2,14,176,2,156,250,168,1,217,185,230,7,226,8,212,255,130,250,80,254,55,5,109,253,83,37,3,242,37,43,78,7,38,3,87,2,239,247,156,0,188,238,16,0,45,9,159,253,14,244,30,253,196,255,220,253,137,255,207,255,26,0,248,5,206,248,162,24,254,54,76,253,104,21,65,1,204,7,96,5,242,243,234,1,202,255,127,4,164,3,189,1,97,217,192,61,13,12,98,3,28,248,7,249,78,8,104,252,158,1,222,254,138,0,244,0,226,3,66,253,130,5,74,1,202,0,163,2,123,254,15,255,74,122,124,1,44,1,203,255,36,3,147,255,157,1,212,255,6,0,14,0,230,1,219,254,144,255,26,0,112,45,188,252,148,240,250,253,172,250,96,44,230,13,180,253,220,247,234,1,125,1,69,252,159,8,119,244,91,4,247,254,2,0,65,0,208,1,76,255,145,255,82,255,104,255,212,136,121,0,49,255,189,252,102,4,71,255,91,0,160,255,222,0,157,255,163,255,102,216,82,254,72,255,140,254,62,255,185,3,156,255,126,1,114,250,107,54,213,248,135,249,53,3,152,1,40,3,167,253,49,254,230,27,220,21,99,12,126,8,180,10,170,211,251,3,169,5,126,254,106,6,119,14,175,16,128,6,184,8,94,253,215,3,39,2,95,33,154,0,129,254,141,246,93,4,248,253,42,213,202,238,98,241,177,255,115,252,21,7,179,19,156,1,75,4,154,5,173,0,20,3,164,255,20,252,8,5,169,255,163,3,1,40,169,252,6,0,107,254,20,10,191,44,126,4,132,248,30,14,250,254,36,1,129,3,201,37,131,254,175,6,103,245,169,251,26,1,124,247,22,247,38,247,44,253,175,252,245,209,120,3,48,12,77,250,239,1,196,213,232,252,238,254,40,252,65,208,31,253,166,246,213,254,190,253,58,245,241,5,6,3,146,7,89,3,113,248,217,0,142,2,172,5,145,241,78,26,36,3,134,0,178,3,148,247,23,37,168,253,86,248,124,235,10,255,245,4,44,33,237,4,99,247,150,255,222,250,60,3,245,3,229,208,151,2,180,1,168,245,135,38,138,253,111,244,188,11,247,3,175,243,61,250,231,255,143,1,178,252,174,1,43,251,100,255,69,255,91,4,10,254,149,254,130,1,252,244,174,3,98,252,215,2,106,4,92,176,238,254,116,4,198,0,199,0,244,9,186,1,157,0,246,249,109,14,124,3,204,1,152,25,250,18,0,246,31,222,138,7,47,221,99,13,174,2,61,0,130,221,154,254,58,5,182,255,156,4,55,11,18,241,104,0,110,9,50,249,161,44,86,238,137,1,56,244,204,3,34,0,117,0,15,193,12,229,204,228,190,6,181,252,14,255,163,247,35,3,187,251,186,1,240,6,125,9,24,252,233,1,137,1,123,2,133,1,102,4,253,47,144,249,124,211,187,244,200,255,0,15,82,255,105,12,84,249,165,4,122,7,234,5,67,255,168,255,20,1,16,255,136,255,143,244,95,38,166,2,56,2,26,0,96,39,241,245,218,252,192,255,6,25,174,255,109,251,121,8,244,248,101,253,219,255,54,0,112,16,77,42,144,46,44,254,124,7,215,252,142,254,144,0,32,14,249,254,0,239,132,255,44,1,10,255,72,254,141,255,191,1,105,254,133,81,172,254,54,0,4,253,217,252,69,253,229,254,215,2,102,252,74,4,65,2,250,255,215,252,206,255,141,255,181,255,24,1,156,0,182,0,225,0,32,137,44,255,95,254,11,255,177,0,94,0,4,0,141,253,167,0,47,0,152,0,148,0,45,5,124,246,177,216,72,253,18,217,8,4,0,252,138,241,93,15,144,1,77,1,180,2,238,240,39,10,65,251,123,254,137,1,102,253,87,8,40,40,117,246,180,7,154,1,120,254,78,2,34,48,245,253,117,4,52,0,68,250,51,3,43,255,162,0,116,0,154,253,122,214,52,255,33,251,23,2,199,0,86,232,234,9,108,6,237,210,230,249,182,5,43,250,38,255,216,254,163,253,65,1,95,2,146,254,255,254,187,252,184,17,93,210,242,4,35,241,144,17,38,11,8,0,112,221,124,0,144,2,239,251,155,1,144,0,148,3,189,1,165,255,252,254,107,255,142,252,79,254,135,255,89,1,68,0,93,1,53,3,140,2,251,0,243,165,247,3,200,2,183,255,126,27,16,250,178,22,196,206,25,11,169,1,9,1,10,6,170,3,59,7,100,251,191,10,14,254,9,5,250,252,71,1,207,15,60,224,194,245,73,21,149,12,82,244,123,39,88,7,173,0,90,240,143,1,180,254,130,2,41,1,95,238,50,251,182,254,236,252,135,170,135,3,228,250,35,2,246,253,93,7,62,249,193,255,205,3,129,3,158,2,111,253,24,255,242,1,92,0,248,255,254,212,48,4,144,254,184,248,241,44,169,13,218,2,110,8,163,249,185,250,209,249,199,8,30,250,96,8,122,252,127,2,175,0,138,232,38,252,106,239,26,250,249,6,192,217,17,254,203,7,27,220,122,250,10,246,42,6,86,9,83,244,137,6,68,248,21,0,42,240,104,33,131,4,211,254,180,4,192,14,6,1,220,248,211,248,10,252,247,255,151,10,187,5,207,1,171,210,207,6,68,252,67,251,204,240,254,5,198,215,22,0,122,252,110,253,33,249,203,9,16,6,246,207,230,251,111,2,107,243,242,5,220,255,66,254,219,232,96,8,228,244,232,58,64,248,47,14,139,7,102,7,169,4,98,249,156,243,211,252,200,250,22,2,147,254,65,3,219,254,255,84,14,251,64,251,228,3,254,255,119,254,166,252,247,2,201,3,26,255,105,255,209,3,150,252,119,0,128,252,6,1,138,255,89,0,95,0,94,0,75,254,89,137,50,254,104,1,180,253,178,254,86,0,253,251,48,255,24,2,60,255,111,1,45,254,119,0,224,255,16,246,60,24,126,34,248,254,89,225,80,3,219,8,37,15,22,231,55,247,140,5,180,248,141,242,163,14,178,253,58,0,238,254,79,232,232,222,18,23,37,12,202,22,65,15,38,8,20,5,244,14,250,253,240,253,168,241,2,7,1,17,152,1,54,2,239,245,143,251,189,10,154,245,240,253,201,226,174,21,116,11,176,254,97,14,14,248,212,0,227,221,249,3,210,8,33,32,131,1,227,0,109,3,192,10,161,250,76,10,195,31,10,15,42,229,122,251,104,241,226,222,228,0,79,233,97,0,5,246,116,244,96,252,166,2,112,0,154,5,30,251,216,4,100,254,85,239,29,241,226,16,154,242,25,30,80,21,36,229,132,242,161,28,70,12,220,0,150,2,251,5,140,234,148,250,186,26,209,241,106,1,165,19,116,31,193,246,30,235,92,22,154,254,165,9,148,8,110,250,240,254,22,2,64,255,237,253,63,253,186,255,253,254,93,0,79,1,162,255,111,255,239,255,152,3,162,4,206,252,169,253,87,1,109,178,152,11,161,0,128,0,70,239,86,2,152,0,186,4,219,250,247,249,27,255,181,0,168,230,67,22,102,28,127,24,105,34,27,0,94,237,220,252,88,255,9,255,88,253,127,255,42,254,104,255,147,3,176,0,120,252,110,2,24,1,170,11,10,4,234,251,30,254,63,155,18,255,169,4,181,245,18,255,35,5,27,247,52,6,128,252,0,2,160,252,99,2,114,254,253,4,44,255,154,254,202,0,194,51,16,0,164,252,82,6,0,252,54,1,40,45,22,253,220,240,12,3,9,240,37,254,89,3,249,3,97,250,134,252,155,0,108,33,106,1,122,251,68,8,221,254,190,255,8,251,254,1,142,250,211,8,103,237,40,3,28,253,87,252,169,54,191,0,17,1,10,226,120,26,78,3,141,248,187,3,106,204,92,248,161,6,134,6,183,254,12,255,91,9,231,23,222,252,17,252,137,2,50,252,170,0,168,247,228,213,252,3,246,4,162,7,94,4,36,52,215,3,142,250,174,253,254,253,182,253,2,4,227,248,36,2,214,254,14,13,69,3,141,250,153,54,253,3,144,225,142,244,186,5,118,21,181,252,128,9,98,5,188,255,174,0,151,1,76,0,147,252,179,2,27,219,10,2,136,242,245,9,100,254,202,246,107,3,76,236,72,252,127,216,174,25,53,231,56,245,106,253,29,0,29,255,20,19,24,5,155,1,8,243,130,9,17,3,26,198,60,17,224,8,249,230,124,8,155,253,127,249,40,1,230,2,112,2,135,0,196,20,137,243,169,252,243,247,229,1,140,243,182,11,102,5,212,9,122,246,78,242,18,255,225,2,139,253,233,3,5,3,132,68,198,5,44,253,4,253,49,251,26,251,210,249,76,253,161,254,241,249,85,255,183,0,38,0,100,253,244,2,254,252,24,95,119,252,242,227,246,1,74,241,102,249,52,6,242,5,52,7,252,4,178,5,247,252,195,6,248,18,244,197,183,251,36,0,226,250,78,3,36,250,9,2,171,241,4,255,128,17,214,245,179,252,85,2,96,238,38,4,220,254,170,183,180,7,178,254,176,255,24,251,146,254,56,14,76,254,244,255,122,249,77,254,216,5,149,5,172,212,244,3,88,252,56,251,48,208,24,244,210,0,113,7,83,251,155,254,225,217,184,245,180,254,167,242,230,58,216,5,158,8,8,7,205,0,104,5,218,13,195,248,243,2,248,3,214,2,58,0,106,255,3,205,135,40,227,245,182,254,80,6,9,12,203,10,199,245,76,251,68,1,203,255,152,11,205,5,214,0,124,0,178,254,19,255,144,65,52,10,255,3,54,239,148,247,240,16,45,239,88,19,12,4,81,0,6,253,88,13,202,2,69,255,252,239,11,253,100,4,240,39,147,27,168,1,196,254,1,5,26,208,144,3,49,248,2,0,37,253,72,255,111,3,90,252,54,255,121,254,234,251,174,254,155,255,153,187,80,249,52,234,233,246,82,246,234,6,63,233,219,5,66,2,126,255,144,5,230,248,110,0,30,2,22,0,220,3,125,239,20,11,89,250,146,4,47,48,131,8,48,212,60,246,64,0,112,252,70,252,142,2,222,252,57,254,171,253,234,0,216,254,43,3,59,4,56,7,52,16,125,2,48,230,198,246,202,242,104,253,224,204,23,11,18,12,222,12,54,238,214,9,201,255,69,3,112,5,17,23,7,5,52,250,197,3,149,64,77,242,145,248,230,249,104,9,173,19,48,237,129,5,105,1,158,248,170,0,158,253,37,249,244,253,157,252,162,231,107,177,23,253,68,252,80,255,182,11,130,0,100,253,181,252,245,254,148,254,195,253,239,1,127,0,190,255,255,127,15,1,104,254,142,2,133,255,39,7,151,0,228,3,82,0,116,2,5,255,144,0,198,0,168,255,101,1,37,0,100,2,184,0,238,0,184,253,204,255,183,138,97,254,148,1,202,253,100,0,147,2,176,254,109,3,211,0,38,253,135,254,184,0,120,235,52,250,89,251,196,247,24,0,115,225,209,0,216,244,204,248,185,2,166,22,89,251,171,1,82,46,232,3,251,254,184,0,82,253,158,4,186,243,190,243,139,0,144,0,117,0,74,14,18,242,230,249,160,2,244,7,203,58,51,236,217,253,17,2,160,6,42,255,138,245,178,232,133,241,31,11,6,246,32,249,84,251,40,8,228,24,242,6,135,50,141,8,200,7,225,6,66,2,226,253,15,253,98,251,225,16,79,7,53,1,192,2,21,251,116,3,192,74,151,245,72,4,232,11,89,255,104,3,168,254,188,251,208,1,183,12,170,255,72,6,218,251,223,249,93,249,152,17,238,254,56,2,148,5,91,80,172,5,130,252,233,252,203,1,142,252,232,251,128,244,169,212,241,252,192,252,110,246,138,2,224,10,84,12,17,2,201,1,227,1,247,206,143,2,174,2,11,253,161,3,212,0,218,4,55,255,165,249,218,18,153,248,229,3,103,243,84,0,80,0,31,1,168,247,149,1,68,255,134,252,160,184,1,254,138,255,198,241,6,252,164,1,106,49,38,254,228,253,66,27,65,27,66,17,138,4,204,250,168,251,27,249,80,10,50,2,116,251,232,4,83,2,55,2,29,254,233,132,64,252,208,252,244,2,225,5,12,0,250,253,234,0,184,0,167,2,72,1,168,253,119,255,11,1,72,254,236,9,81,2,255,3,20,210,114,2,14,248,124,22,102,217,103,12,90,251,92,6,80,15,147,12,114,5,66,3,116,255,196,15,114,18,57,254,33,12,181,250,222,243,232,3,126,30,77,247,175,2,212,249,108,12,242,207,142,250,87,254,232,1,69,255,220,255,219,0,158,0,230,46,147,6,103,8,254,255,170,251,38,208,197,255,160,2,52,7,36,8,203,247,116,6,241,252,122,2,55,204,173,254,92,15,212,8,92,207,152,0,60,1,80,253,79,0,112,252,223,247,104,5,188,0,150,7,62,253,204,0,188,2,240,6,77,54,158,202,188,254,216,1,31,4,122,253,82,0,255,252,147,252,69,254,29,255,124,252,124,2,154,252,214,1,144,255,170,253,206,238,90,245,239,6,40,255,213,255,13,183,161,252,4,238,105,13,162,2,101,255,208,0,10,6,38,1,99,255,152,253,62,43,205,4,240,253,76,8,187,2,40,14,54,0,252,253,194,0,12,203,110,7,6,254,219,250,124,7,215,1,170,254,68,3,18,0,138,3,102,2,248,255,73,252,28,4,159,255,164,8,100,252,54,1,6,0,35,253,122,0,179,92,212,1,89,1,9,6,154,5,99,2,147,1,192,243,90,247,202,255,255,3,146,250,133,235,96,241,254,254,215,26,14,249,161,2,198,246,49,205,248,252,50,252,203,251,194,32,118,240,27,239,212,4,171,15,137,4,249,254,200,4,99,205,156,255,241,10,178,5,247,243,66,2,17,0,13,4,26,253,84,23,136,253,88,11,79,206,179,229,34,254,182,0,75,248,204,252,1,229,216,236,82,252,164,254,159,254,162,254,184,30,34,0,56,2,193,7,188,3,238,12,118,0,237,247,56,49,103,35,73,6,19,251,40,1,32,251,136,249,191,255,40,7,245,5,223,5,29,20,18,17,154,249,228,240,64,1,247,5,88,254,12,69,244,6,148,4,148,251,104,4,14,5,190,254,155,255,206,1,244,229,48,244,149,29,176,212,45,6,13,0,138,250,38,2,24,17,87,6,191,6,89,3,66,235,224,9,239,253,111,254,27,2,108,25,150,16,9,16,13,235,96,0,161,203,74,253,197,19,117,13,45,243,164,254,66,250,90,4,90,2,108,254,127,255,130,2,11,6,70,90,49,247,177,7,77,1,17,5,116,0,101,249,108,1,240,253,246,2,41,251,222,248,7,255,117,254,172,2,168,252,130,253,240,216,43,245,249,231,36,251,190,243,40,218,54,248,212,27,88,5,178,248,200,254,71,7,18,252,195,3,21,3,231,2,194,239,8,253,104,5,155,226,65,252,250,254,120,22,165,15,251,208,46,255,118,3,87,248,31,19,5,255,98,255,212,0,165,2,6,2,86,1,30,255,152,254,210,1,17,0,232,110,236,255,246,0,82,253,254,254,128,2,134,254,136,255,69,254,54,4,204,245,36,8,86,249,238,16,189,237,230,237,32,9,242,216,247,38,251,250,218,10,220,12,75,249,138,0,66,8,160,251,76,255,134,251,212,46,61,3,30,246,133,221,177,26,89,251,139,249,131,10,29,240,142,4,179,7,47,1,224,253,77,250,251,254,41,4,82,13,2,8,91,12,253,253,80,21,91,239,107,21,251,5,206,247,228,7,189,14,76,2,147,3,158,0,156,209,26,1,100,251,9,1,28,43,190,255,51,249,154,248,118,239,232,11,218,0,250,251,192,8,134,206,14,247,119,249,137,248,200,5,31,1,175,255,158,4,216,0,18,214,153,8,198,255,149,253,137,33,194,253,32,238,60,7,44,254,153,229,13,226,167,0,227,3,166,251,4,251,251,247,130,8,59,224,10,251,114,225,170,214,4,21,221,11,47,4,59,3,108,19,0,4,127,255,76,255,70,244,178,252,32,253,115,37,98,7,47,40,94,248,18,4,22,6,74,252,102,9,196,248,227,8,38,26,65,253,114,252,14,15,44,3,9,2,205,251,7,253,237,20,185,240,52,15,8,31,228,17,167,19,64,4,204,27,46,249,153,235,47,10,155,12,248,8,227,21,211,0,37,253,50,25,16,243,166,207,186,254,149,16,72,16,225,252,21,242,7,254,213,2,79,235,148,8,173,8,240,255,112,242,59,1,114,2,13,232,71,0,152,3,225,238,196,250,141,245,104,253,244,28,40,251,175,250,229,3,23,241,183,246,59,210,125,6,22,0,28,2,115,235,74,252,48,29,76,12,223,29,208,238,206,17,196,238,155,252,8,250,198,245,119,32,62,8,22,2,52,254,33,255,94,255,196,252,18,1,52,7,69,7,209,249,243,26,102,20,20,249,192,244,0,231,95,18,46,10,106,240,56,251,192,239,72,35,213,254,255,127,127,1,89,3,213,249,89,254,140,4,186,249,194,4,102,254,9,3,220,254,122,0,26,1,182,255,142,250,3,1,34,253,102,0,174,255,104,127,171,1,223,253,110,255,115,255,84,1,250,1,216,252,171,0,246,252,132,3,52,255,235,254,28,255,86,254,54,2,31,254,142,251,117,252,112,0,162,10,103,3,115,0,222,227,161,7,198,252,236,248,116,254,126,198,184,252,155,0,90,4,248,21,88,4,109,255,17,231,158,3,225,5,104,1,169,3,177,203,201,3,150,27,170,8,53,242,215,1,202,1,191,0,47,254,216,33,112,251,34,2,61,8,80,252,182,255,108,6,175,255,8,253,128,248,99,10,18,52,231,5,132,251,66,5,28,3,236,255,0,195,222,4,90,251,126,213,250,252,186,255,59,14,128,252,38,7,64,255,250,3,61,4,161,255,203,254,147,2,91,0,215,2,122,238,230,1,226,247,211,4,177,199,43,240,173,249,227,245,186,253,214,237,236,15,6,253,169,251,21,1,168,5,26,253,198,254,45,252,97,7,119,10,76,248,176,9,46,1,53,11,33,220,67,254,231,248,94,50,106,0,187,0,130,250,153,253,106,251,234,2,141,254,126,1,94,1,237,248,241,253,36,0,244,1,189,252,150,255,110,4,97,247,253,3,92,1,140,3,236,170,192,1,176,2,196,255,2,249,109,7,50,166,187,5,84,2,112,252,138,243,204,5,13,1,103,254,38,254,122,249,48,5,152,0,110,254,103,1,34,253,104,204,62,0,155,239,158,231,75,20,231,244,166,19,234,10,240,4,150,251,237,14,193,3,217,2,51,4,49,0,108,255,99,28,36,10,27,236,164,223,37,229,13,244,69,15,229,237,122,5,66,231,170,254,245,243,163,252,234,1,233,4,138,253,128,0,192,8,64,3,36,4,246,248,140,249,128,0,136,30,201,199,190,229,0,243,230,245,228,11,64,4,41,6,84,3,114,255,80,255,91,5,212,4,208,3,133,47,196,249,57,255,8,254,244,212,186,253,204,3,68,250,158,246,102,253,1,243,156,247,54,4,62,255,203,37,202,247,44,251,186,255,82,252,35,1,84,5,123,5,222,242,163,50,137,254,64,249,79,6,206,246,121,2,6,254,62,255,237,50,92,55,22,2,254,251,87,254,184,9,76,255,90,253,76,254,16,1,227,5,178,254,72,3,24,252,212,251,5,4,206,254,24,0,173,238,150,232,229,250,155,16,128,15,223,9,43,252,190,245,208,238,14,255,225,248,89,253,31,50,234,255,51,0,131,254,118,9,184,246,36,224,59,250,194,228,78,4,139,254,211,1,50,44,214,253,80,254,56,3,109,28,137,1,78,255,179,0,115,253,72,46,199,249,63,55,37,253,244,251,238,246,5,1,56,248,128,251,106,250,182,250,205,255,227,254,155,249,144,0,197,255,122,247,99,22,26,2,144,252,141,1,194,11,195,2,226,248,18,252,78,18,24,236,150,16,232,243,99,240,2,255,239,212,138,1,167,254,92,73,82,253,251,253,162,242,104,0,131,247,135,9,232,234,246,255,60,4,29,7,166,253,151,5,149,1,95,8,243,1,149,1,95,1,194,255,209,255,162,7,37,139,184,1,30,4,47,2,70,251,186,1,160,3,255,255,59,0,23,1,144,255,146,255,72,254,116,254,37,3,55,1,90,3,81,254,210,251,16,138,135,0,222,4,167,254,22,3,242,1,63,1,210,254,43,254,246,255,0,2,195,252,242,253,252,247,152,9,134,0,81,180,70,251,244,250,128,2,160,12,20,10,205,3,148,246,15,1,230,254,120,2,245,253,177,252,118,255,34,252,197,9,24,2,90,255,52,8,155,254,122,0,210,1,252,255,242,7,115,78,42,6,188,1,168,254,79,253,101,22,56,254,9,254,176,253,186,250,242,251,164,3,132,248,74,4,34,252,97,167,8,6,70,254,116,254,198,253,85,253,152,253,105,250,118,0,17,16,200,254,252,8,45,8,216,246,117,244,199,24,210,16,162,216,142,24,94,233,218,252,152,2,39,255,36,2,208,19,18,18,149,249,157,210,11,3,164,7,112,244,102,2,39,8,144,35,142,246,7,3,161,238,0,3,63,6,196,251,231,3,116,6,66,4,118,2,83,251,89,242,112,252,167,217,136,2,206,12,36,7,37,53,197,10,193,252,89,251,202,248,95,250,234,254,174,222,57,254,17,254,67,1,113,252,196,9,20,55,51,14,248,3,88,252,145,20,236,243,77,8,135,255,192,255,112,253,175,254,222,36,80,226,123,5,115,209,132,8,52,10,128,6,67,4,194,254,28,243,85,254,26,1,187,7,126,3,65,253,2,2,160,0,161,6,108,25,60,3,187,0,222,255,186,251,211,244,240,0,107,236,116,23,68,237,33,252,158,0,173,44,62,249,98,1,171,4,206,14,64,215,0,242,48,54,80,1,251,7,221,0,92,2,114,11,56,4,119,250,86,7,146,252,53,254,93,254,108,1,243,251,84,30,28,12,48,0,49,43,144,7,181,8,190,35,40,254,154,4,127,255,60,11,7,255,254,254,99,251,183,254], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+481280);
/* memory initializer */ allocate([187,253,140,251,81,248,91,1,229,253,118,254,7,3,129,251,225,255,28,4,148,248,43,255,240,249,212,87,164,0,143,255,135,0,242,250,38,2,58,30,201,227,29,253,82,5,142,21,193,0,134,247,171,209,179,250,95,1,167,8,165,0,16,0,162,253,215,2,98,255,252,252,148,203,32,251,134,48,212,252,232,6,70,254,245,4,204,251,131,3,124,0,7,255,170,251,141,2,8,244,160,249,71,3,26,255,0,2,130,2,174,51,229,51,216,253,167,251,173,253,96,3,25,2,12,252,229,253,153,253,21,254,246,3,32,3,246,255,22,2,53,251,77,158,215,4,230,255,250,14,104,0,250,2,235,4,64,8,212,254,104,252,212,252,100,2,219,251,134,254,10,255,249,255,34,43,196,183,125,250,179,255,151,1,212,253,218,0,215,6,45,4,218,254,253,6,136,3,29,1,180,255,44,1,96,255,128,255,186,242,47,248,153,6,82,19,66,245,147,5,168,206,175,248,246,248,165,251,39,245,172,238,121,11,248,230,45,254,231,1,19,4,74,15,175,255,4,6,58,210,88,5,144,206,185,253,241,3,96,254,249,0,82,7,133,4,226,3,166,252,102,255,38,1,77,1,230,255,73,0,216,249,236,255,208,253,212,251,45,5,180,253,49,102,44,6,101,254,181,253,197,251,177,255,250,2,36,1,146,253,20,3,28,1,222,7,78,0,42,2,252,253,60,5,67,3,44,1,5,159,46,2,63,253,234,255,139,0,97,255,10,255,183,253,222,16,234,0,28,5,58,255,214,242,92,22,77,9,19,54,4,0,57,2,66,31,164,4,193,255,94,249,16,18,107,254,38,255,142,16,136,252,100,251,166,14,16,237,231,218,37,1,193,251,38,204,223,255,202,244,201,1,150,253,82,1,222,255,30,1,89,1,55,235,136,3,232,233,222,247,100,49,1,227,20,2,190,3,51,248,53,250,90,244,43,12,197,248,23,248,61,7,106,252,121,252,18,6,28,2,91,191,161,5,123,11,8,251,34,12,70,9,66,15,71,253,120,4,238,2,133,254,154,230,212,3,130,1,36,0,85,4,171,4,128,24,168,16,221,5,249,20,232,249,207,13,60,4,227,2,249,251,208,238,4,33,82,254,5,249,11,226,25,255,141,255,228,16,228,248,206,247,238,252,54,29,107,245,81,200,139,22,115,0,92,249,145,255,54,250,167,250,144,255,122,0,40,254,233,0,123,9,24,7,180,0,31,254,160,3,82,0,84,0,68,253,64,254,78,252,176,7,108,6,168,0,89,255,36,63,155,0,180,215,173,3,184,253,232,1,96,0,85,20,235,1,204,248,1,205,242,4,160,254,188,252,46,2,10,6,72,249,57,1,241,7,85,2,241,199,74,17,209,12,209,253,54,10,176,12,39,247,184,215,178,249,224,254,224,1,139,5,222,253,27,254,67,3,192,3,206,1,155,3,118,25,66,3,57,253,161,206,107,34,49,255,14,7,81,1,40,251,68,237,79,9,21,1,117,4,201,3,59,0,197,0,85,5,154,253,72,220,216,18,76,254,95,16,228,245,157,17,135,1,65,236,97,243,66,27,12,231,51,0,105,0,161,252,26,4,47,51,225,49,92,254,230,249,133,255,142,10,36,1,37,4,123,0,149,1,125,7,237,254,237,1,161,255,61,255,130,0,203,245,50,35,196,0,154,250,15,23,113,28,49,6,253,9,148,252,94,12,254,26,78,2,12,244,209,253,114,18,137,1,101,2,120,254,50,244,164,38,16,7,155,3,187,31,145,38,127,249,45,9,78,11,79,2,208,7,106,241,107,252,220,0,152,1,40,1,112,253,48,10,92,249,144,1,18,214,58,21,104,25,137,250,127,8,77,251,42,231,59,251,58,236,45,0,202,3,12,254,214,250,152,4,250,22,89,210,180,24,121,247,23,9,154,3,4,234,77,242,102,9,106,3,119,5,166,17,169,254,89,3,32,255,34,3,43,253,143,222,80,17,182,7,33,7,136,247,61,254,176,242,187,25,165,29,33,13,153,237,62,250,79,12,158,7,254,3,186,5,232,35,58,18,202,252,0,4,38,9,84,247,145,4,220,40,177,11,36,252,201,238,185,229,134,3,123,6,80,0,106,0,144,1,34,0,210,6,186,228,244,40,189,24,179,252,251,242,228,6,217,0,134,237,22,243,176,241,242,244,206,8,97,252,201,255,75,2,20,7,25,1,23,17,226,241,187,250,10,7,216,231,168,245,163,239,91,219,85,243,205,239,128,1,193,8,148,21,34,254,2,250,203,208,0,32,246,248,235,17,59,23,145,243,187,245,45,7,130,9,252,0,156,253,167,237,192,253,150,0,64,253,128,253,174,0,130,255,187,215,94,1,141,243,106,18,243,244,74,49,132,247,174,13,209,1,97,255,167,253,26,5,150,4,64,254,220,254,120,255,242,0,31,0,211,220,197,231,213,216,25,0,47,255,236,255,244,250,28,251,208,16,97,14,110,17,207,238,60,17,216,4,192,253,34,14,83,2,19,255,240,9,112,232,25,250,243,5,172,241,112,242,176,21,219,236,240,254,75,23,180,10,146,252,210,50,191,0,31,248,0,3,199,1,211,255,39,229,176,241,79,10,63,252,252,11,110,239,47,5,58,9,139,248,166,251,100,0,204,232,220,0,97,3,104,205,180,255,1,251,177,253,68,4,82,242,88,0,186,247,253,50,99,216,48,244,235,253,125,248,255,239,135,0,136,6,131,249,110,6,142,254,151,254,132,2,59,255,116,229,60,213,172,45,50,252,232,1,93,1,96,15,30,250,107,255,1,2,121,5,16,249,121,254,46,255,57,0,200,255,168,254,250,3,53,31,163,236,167,0,219,3,196,255,62,0,86,6,183,4,187,255,82,1,251,192,210,255,250,3,76,250,203,252,122,253,36,5,126,0,233,237,182,252,31,250,217,61,252,230,94,238,130,11,107,11,174,4,187,243,219,243,179,249,61,7,118,252,76,254,170,251,230,254,42,255,160,242,187,243,108,240,28,1,246,86,245,4,251,6,164,251,107,250,249,3,115,1,69,255,199,252,22,2,94,1,64,4,26,0,176,0,210,34,6,26,167,3,26,8,206,224,84,237,146,8,4,7,185,2,56,240,182,9,164,6,190,35,219,255,232,249,145,9,94,255,128,0,211,226,126,245,231,254,166,237,168,1,23,2,136,5,243,0,193,253,120,251,70,1,143,246,40,3,56,194,226,3,210,254,26,0,126,3,48,227,139,1,182,253,55,3,195,250,204,3,100,0,241,0,231,2,214,1,11,1,218,253,218,1,182,0,76,71,178,0,74,255,249,255,168,13,84,8,95,3,105,255,229,2,146,247,5,253,116,253,9,254,78,254,32,253,2,3,100,255,129,181,187,1,158,254,13,255,66,0,162,16,58,26,249,13,186,67,44,2,14,242,245,4,130,250,132,6,163,254,166,255,13,3,82,0,46,2,168,3,236,252,208,251,235,255,184,230,50,244,37,254,171,228,0,245,66,241,147,6,130,201,154,13,176,248,64,10,40,4,194,254,20,5,66,251,179,0,245,255,132,255,208,17,245,244,86,231,152,233,135,4,29,5,170,234,124,210,96,16,151,0,225,253,100,242,16,247,137,255,233,2,93,5,135,255,139,253,84,20,226,29,242,247,214,242,178,244,174,254,175,250,56,4,166,241,52,50,25,232,214,249,32,253,15,255,228,249,147,255,71,254,79,1,160,1,142,6,194,18,89,243,38,24,154,0,184,241,199,250,125,189,171,6,131,254,88,249,135,254,254,3,176,253,215,3,191,254,37,0,202,248,108,238,15,10,82,55,208,253,169,36,83,16,196,250,118,242,163,12,191,6,9,6,233,255,124,2,24,1,217,255,103,3,173,0,45,221,133,246,98,8,142,241,135,208,67,241,223,240,178,19,112,0,20,3,141,251,245,0,34,2,22,1,248,255,19,252,187,1,180,255,24,251,63,32,1,15,228,23,130,16,121,14,2,251,186,230,100,20,4,23,116,242,176,10,51,21,248,242,248,254,114,7,38,1,196,255,90,228,19,30,192,217,60,228,18,248,31,4,206,228,190,2,230,247,24,255,127,0,82,254,146,2,240,254,245,2,138,0,159,0,172,254,2,238,253,3,146,0,246,225,113,23,28,22,35,13,145,254,166,51,71,254,13,0,150,252,156,2,245,8,107,3,214,4,110,0,10,3,154,5,48,252,103,8,23,224,141,5,62,10,206,0,229,252,208,252,149,199,209,249,28,13,155,11,60,252,191,254,183,252,108,254,111,0,37,234,152,16,21,241,214,0,40,246,56,253,31,250,81,3,179,3,148,252,188,0,149,12,95,3,105,0,72,188,26,7,14,0,17,0,51,231,123,1,138,18,139,207,208,253,136,242,80,14,59,32,77,3,127,1,68,5,29,253,244,252,159,6,220,18,133,255,121,253,55,3,212,38,73,255,244,248,56,228,95,255,66,2,149,253,14,45,142,12,50,6,176,18,20,246,164,4,208,254,27,254,120,253,200,252,173,253,143,221,42,16,159,3,69,243,58,255,182,15,165,8,165,249,133,2,10,57,222,251,201,5,122,249,143,255,52,2,58,253,61,254,152,254,19,251,200,9,247,0,190,21,162,227,64,5,14,236,184,249,154,7,112,239,31,227,200,40,234,12,148,7,25,252,155,0,64,3,55,0,234,39,211,44,76,243,153,223,67,5,101,9,93,13,197,245,214,8,243,244,242,2,205,254,36,2,8,248,150,251,61,1,170,0,36,1,248,0,41,10,14,182,106,248,137,5,142,6,238,12,238,245,79,248,14,6,194,11,70,0,8,0,248,11,176,252,248,1,84,255,180,0,251,6,147,251,123,9,234,3,104,253,216,255,192,0,152,164,20,252,1,2,206,252,130,254,104,1,104,1,12,1,98,0,54,255,64,255,100,253,132,205,74,210,157,28,29,3,145,7,162,2,102,246,227,253,39,250,119,249,69,252,156,254,26,254,182,0,43,1,210,255,65,0,120,239,138,5,132,25,52,9,226,236,6,19,41,13,23,238,39,34,217,5,85,250,94,3,92,222,74,249,180,6,171,246,115,1,80,2,229,28,140,243,119,253,126,0,236,250,94,5,244,250,133,2,42,250,176,10,68,250,240,248,185,188,160,254,111,0,34,255,20,255,171,0,58,255,198,224,18,241,204,20,40,190,251,253,119,0,58,1,152,254,253,253,179,1,8,2,130,253,99,6,164,1,167,4,62,3,198,2,241,26,109,11,19,12,254,1,196,12,90,249,198,192,206,2,201,243,49,254,251,2,245,251,213,2,134,255,134,2,172,0,92,255,235,254,221,22,94,228,246,255,22,249,16,246,90,23,150,252,18,254,24,255,129,56,23,7,146,248,219,3,3,250,192,4,229,2,108,2,161,0,62,17,88,16,224,255,128,244,245,237,50,254,85,61,254,251,116,255,164,246,45,249,230,253,0,252,219,0,86,3,161,254,92,3,30,255,218,238,220,2,45,248,130,246,228,253,80,2,86,6,156,4,129,1,252,247,210,15,249,67,118,253,13,255,173,6,237,4,95,0,205,254,10,236,102,253,74,228,235,253,243,250,51,188,113,11,85,9,137,255,99,254,61,1,62,252,197,2,240,249,26,0,175,0,188,2,198,253,152,78,83,4,232,0,169,0,135,252,235,253,4,251,22,0,191,3,98,3,70,252,232,252,105,3,84,255,221,6,195,0,148,0,167,1,138,17,78,34,119,2,170,2,40,7,112,241,50,249,134,212,79,251,240,6,52,36,182,253,178,250,122,253,114,2,158,252,5,0,7,1,110,15,8,253,158,244,49,206,131,206,233,5,252,255,119,2,43,7,56,1,89,255,10,6,236,253,107,2,152,4,156,5,140,255,56,1,142,27,48,12,235,15,216,250,203,2,50,255,220,249,70,5,24,69,98,251,224,249,168,2,6,0,207,0,242,3,88,2,2,253,42,2,53,250,132,2,150,221,112,2,148,0,81,240,0,250,185,248,92,0,218,2,42,198,130,1,202,235,116,250,181,254,2,255,152,255,19,1,156,227,3,10,207,46,191,255,107,31,169,249,227,245,206,245,48,5,82,12,143,7,88,14,31,249,120,19,149,2,209,0,242,251,122,0,5,252,236,142,55,0,102,1,229,253,232,1,55,0,106,2,20,0,198,254,190,1,8,252,106,2,163,255,162,255,181,254,220,255,194,0,86,249,228,25,140,1,110,255,3,253,4,41,59,10,174,255,114,213,188,240,136,252,64,255,108,2,163,0,78,0,6,3,219,254,152,255,38,237,14,201,165,248,70,243,31,238,52,250,36,21,78,239,169,236,244,12,117,252,156,7,93,251,108,254,70,14,144,1,186,255,203,1,104,243,134,243,34,9,38,17,251,255,161,243,201,12,116,0,254,251,124,249,183,14,16,1,234,190,137,0,158,249,17,252,220,0,202,254,214,3,28,32,240,255,29,251,172,245,240,242,188,8,219,249,238,31,100,2,118,4,209,213,137,1,61,253,196,18,141,1,208,4,220,254,130,22,8,195,105,11,216,230,216,13,165,246,8,254,98,7,172,0,14,252,178,0,124,1,117,251,148,1,50,251,10,4,172,253,105,0,10,248,199,7,237,21,200,254,196,239,35,216,20,12,160,237,43,232,172,249,243,251,150,251,54,6,129,32,227,252,247,0,186,3,153,255,254,14,26,9,80,39,125,12,196,222,20,5,12,252,49,230,235,240,19,22,31,0,37,254,46,6,166,250,83,4,116,8,231,2,201,253,234,18,142,244,119,12,66,255,74,247,209,255,254,0,99,8,79,2,0,254,32,5,135,4,43,3,164,5,224,250,255,254,144,62,21,3,254,245,143,15,139,254,217,219,46,1,185,241,118,22,240,240,227,228,94,15,246,246,180,21,253,239,247,254,33,254,21,237,126,255,20,0,5,237,11,12,82,25,102,241,160,240,78,2,32,231,8,249,75,0,193,240,78,229,156,238,153,252,252,2,162,251,27,34,38,0,108,255,216,242,70,231,142,254,186,8,139,3,7,245,78,250,254,246,110,254,119,10,58,251,114,4,192,0,219,250,244,3,154,60,112,2,23,1,64,240,5,10,18,24,86,252,128,22,149,6,254,16,123,11,199,252,181,254,48,7,212,253,171,1,222,237,233,255,154,32,153,29,45,254,8,15,198,1,134,240,117,1,140,255,10,9,4,19,48,255,169,250,245,248,121,10,38,3,73,239,20,13,240,253,203,54,18,255,55,254,52,245,64,3,184,237,2,17,195,4,223,252,110,9,172,235,72,241,132,230,43,20,99,213,120,6,65,1,188,12,19,249,214,0,121,255,45,238,86,20,70,237,206,5,150,1,254,251,25,1,7,7,38,255,64,1,116,252,104,3,32,4,139,11,48,255,225,252,132,60,78,1,106,107,98,254,246,254,134,2,229,0,94,0,241,255,46,1,23,254,111,254,125,0,240,2,36,254,56,255,48,252,195,0,4,0,110,254,172,8,244,3,195,6,226,9,116,253,124,172,89,253,157,252,61,255,142,255,46,5,227,9,164,254,71,255,142,255,178,0,74,253,214,254,48,34,199,6,80,10,186,246,47,24,236,5,139,22,49,26,3,255,202,222,218,3,86,8,194,248,162,13,90,253,208,255,133,0,76,3,157,249,94,6,168,23,12,253,171,251,27,6,91,250,117,255,68,2,88,250,13,183,78,3,122,254,253,254,12,6,188,254,25,1,142,0,0,7,187,4,48,5,44,239,248,251,220,234,134,18,55,255,209,255,215,254,45,223,243,37,100,28,84,241,37,6,165,2,168,255,111,255,13,19,146,50,192,12,17,7,62,28,233,245,91,6,6,249,55,228,56,250,193,247,4,254,159,1,128,6,29,254,230,253,7,255,80,0,93,27,254,245,137,252,217,14,11,25,174,8,36,0,107,3,31,236,145,42,174,15,84,19,212,249,145,5,234,248,121,254,160,255,66,1,172,230,104,7,146,225,74,252,117,239,86,223,46,12,235,18,170,14,46,4,144,249,12,30,117,249,77,13,150,3,222,8,61,2,193,0,136,23,208,34,215,236,238,248,217,3,85,7,110,8,154,247,126,254,68,15,238,7,163,1,201,206,198,253,106,255,44,6,36,0,104,255,2,0,230,253,227,249,153,26,53,253,134,231,75,206,194,229,42,3,165,253,11,6,233,3,202,8,42,3,237,6,96,253,71,1,246,0,14,25,169,226,148,3,185,254,62,3,86,46,21,17,235,3,226,24,62,249,177,247,101,2,91,6,114,2,251,2,160,252,207,0,23,255,154,14,60,222,158,249,254,247,66,15,61,254,186,50,36,237,99,244,150,237,33,2,54,3,223,2,45,242,0,255,65,0,163,255,162,255,107,11,163,27,77,241,28,24,184,218,141,245,7,241,162,3,162,1,112,238,206,14,130,1,139,225,234,0,159,253,253,254,198,1,74,1,10,6,46,226,82,248,3,2,64,246,118,1,73,10,58,244,30,16,192,38,65,228,161,5,106,255,15,30,158,2,208,255,215,255,0,254,63,229,7,249,171,14,68,7,114,9,214,246,86,251,218,249,150,60,188,1,21,250,73,2,230,2,57,255,165,251,134,255,245,255,140,0,173,225,158,5,195,254,68,254,3,189,232,255,125,10,168,252,162,243,85,4,52,1,233,0,30,0,63,0,18,2,133,2,84,0,133,0,251,23,97,251,79,214,10,206,144,255,248,249,15,18,64,2,220,252,255,3,146,249,168,4,13,1,121,10,44,0,115,252,242,255,98,254,48,0,94,240,160,18,112,13,180,12,161,5,101,0,116,1,94,12,138,250,69,1,56,63,57,253,230,1,48,5,114,0,62,254,225,255,128,4,106,8,187,255,4,255,32,0,154,3,219,0,249,247,165,1,159,250,238,3,154,253,234,0,216,255,172,255,204,0,35,106,182,0,10,4,0,6,66,3,154,224,219,4,254,243,107,225,157,43,194,248,107,251,153,252,9,16,4,14,137,243,188,0,202,247,124,0,90,255,134,31,198,212,232,25,179,10,149,225,184,0,16,233,80,5,191,251,249,4,84,0,109,249,208,249,207,3,50,255,136,4,180,0,12,0,23,232,60,21,122,198,61,23,156,229,66,3,214,6,186,243,146,252,7,0,36,255,115,248,115,255,160,0,26,0,244,2,224,252,6,0,88,224,179,228,25,13,66,242,158,17,114,207,224,2,131,245,238,251,32,0,160,4,249,253,200,254,207,251,110,254,71,0,90,254,221,255,255,6,191,49,23,247,63,10,34,250,218,240,71,26,45,41,170,251,4,9,102,3,100,4,106,3,130,250,123,0,254,0,149,1,72,1,244,14,139,226,24,12,191,200,96,253,67,249,89,254,130,248,68,16,101,254,22,12,200,253,247,13,177,244,134,254,7,244,24,255,193,1,174,31,216,8,153,250,211,253,69,214,52,226,59,16,242,2,122,255,103,26,27,4,250,247,124,252,76,252,67,2,3,251,151,0,206,1,42,45,202,254,188,223,254,39,227,250,20,244,89,1,79,253,147,251,180,253,36,2,212,3,204,250,113,3,112,1,8,3,64,253,166,1,145,48,34,5,49,250,111,237,119,10,20,12,85,252,136,0,182,253,176,13,246,251,82,231,178,13,164,1,22,9,10,4,4,255,114,254,168,231,136,17,234,231,38,249,140,3,20,19,188,235,87,244,41,42,140,255,66,18,140,15,247,255,37,3,32,6,172,249,168,255,110,255,211,11,230,192,83,11,159,30,24,23,85,254,14,1,69,250,125,254,161,254,103,2,190,254,254,255,219,251,114,253,56,0,74,254,132,0,84,9,204,1,124,8,82,7,44,244,230,12,243,7,64,253,58,251,133,178,40,254,190,248,106,249,226,254,5,0,20,253,235,1,162,254,8,239,103,0,193,5,136,9,7,53,186,250,176,5,137,40,170,7,220,11,42,251,44,6,95,2,72,5,229,3,188,4,23,254,251,0,235,15,127,242,42,24,18,3,44,1,28,246,139,254,38,246,36,12,218,254,74,19,92,244,229,5,162,48,73,253,152,251,160,255,98,1,162,241,46,33,176,9,216,8,42,20,131,46,113,18,87,4,240,2,183,11,84,15,107,250,65,1,20,1,53,1,165,253,89,2,194,255,9,13,14,242,201,12,218,25,47,248,182,3,20,2,204,3,83,6,188,3,65,0,159,253,231,254,79,198,74,254,68,2,230,0,28,255,132,216,1,48,200,34,104,3,32,243,255,5,128,254,221,1,111,252,247,252,34,2,189,1,20,252,77,254,52,253,118,255,60,2,179,1,18,18,160,252,172,233,6,245,11,5,68,237,15,255,223,9,218,246,176,250,65,16,94,7,128,255,15,250,158,53,26,7,214,253,99,255,63,218,47,10,11,252,67,2,98,4,35,6,132,245,100,44,192,230,72,255,250,249,218,233,189,251,98,253,249,4,229,251,249,255,234,254,9,246,220,253,79,214,102,250,169,254,61,1,220,243,177,249,65,247,204,200,234,1,58,254,163,9,198,7,214,1,208,251,184,1,34,1,190,11,188,238,221,247,234,11,219,10,211,246,178,253,179,236,40,29,216,220,130,245,3,248,248,221,47,243,84,246,136,2,108,255,152,1,169,250,167,251,211,106,167,251,227,2,39,0,163,5,48,255,82,253,218,3,223,2,66,253,76,0,153,2,62,255,91,255,110,1,162,253,212,236,164,240,187,193,6,245,220,17,48,3,212,247,117,16,68,246,166,15,158,3,210,0,170,251,157,249,242,254,30,255,150,254,69,255,254,6,200,11,168,8,50,15,226,7,211,250,72,77,253,252,100,1,70,8,158,255,80,253,248,3,210,3,47,2,217,255,160,0,202,254,222,25,38,249,160,212,204,0,92,247,66,9,166,210,95,4,144,12,30,12,12,2,22,1,195,252,12,2,28,0,70,3,118,1,180,255,15,238,139,244,201,41,146,230,150,236,23,248,89,219,156,242,240,239,105,10,179,5,125,250,165,1,225,1,74,3,171,254,147,0,98,255,12,16,45,0,71,19,235,255,31,225,10,8,134,4,156,59,201,253,16,253,32,252,186,251,221,251,66,9,52,3,143,2,251,254,24,1,127,240,198,24,73,33,42,12,113,1,19,208,148,6,4,0,78,18,193,7,172,241,32,244,165,2,2,255,57,0,95,255,35,252,133,254,163,27,188,253,30,11,151,243,19,247,190,3,72,228,102,255,253,253,239,242,175,52,220,13,244,248,34,1,82,254,214,2,143,1,54,0,2,245,251,39,166,7,228,242,206,250,24,2,146,12,142,200,200,0,228,252,162,252,56,250,19,7,166,254,92,2,121,254,25,255,1,2,1,215,115,232,164,230,214,221,155,254,35,255,158,248,147,245,8,0,36,249,76,233,232,251,210,8,223,0,38,254,130,4,30,255,92,1,202,249,99,11,158,0,5,162,107,3,178,252,126,4,24,252,180,252,140,255,10,255,37,255,30,254,145,254,120,0,5,2,23,254,186,1,212,31,176,19,186,14,18,252,205,255,153,243,218,215,140,238,164,4,217,5,141,230,251,255,164,249,173,246,239,250,51,253,94,6,232,0,232,241,224,229,140,9,232,252,10,255,155,1,184,5,77,14,172,12,159,251,190,249,218,195,69,254,114,3,132,5,158,3,16,0,183,255,133,10,0,28,73,219,16,2,236,30,202,219,123,249,60,245,24,5,2,12,26,250,215,247,211,5,236,249,90,254,98,254,132,0,64,255,100,23,148,17,148,29,30,213,245,236,101,14,96,7,108,253,42,249,253,253,88,245,195,243,74,245,154,2,211,244,114,2,0,1,243,0,235,17,17,242,224,254,10,9,157,18,228,212,154,28,157,29,91,10,192,12,118,254,10,255,133,252,72,250,75,249,123,0,251,253,26,254,5,252,47,28,42,2,210,2,99,239,89,9,237,11,65,11,2,6,200,247,61,2,65,1,161,2,62,15,217,244,176,3,240,205,114,1,168,13,184,3,101,250,235,24,254,2,225,8,39,253,80,0,128,246,130,251,104,9,129,252,137,60,49,251,230,254,22,243,77,254,89,255,56,242,205,233,243,230,197,9,39,237,124,0,56,12,87,254,16,245,38,252,21,247,17,254,192,242,232,249,211,247,163,210,219,255,157,0,74,254,230,252,196,7,211,255,228,5,20,0,98,0,54,254,11,255,106,4,110,0,243,253,253,252,96,4,198,2,2,171,174,0,46,255,25,237,92,246,120,253,220,238,245,255,174,11,75,255,74,237,120,239,50,14,27,25,212,10,166,0,76,244,27,209,94,6,7,255,179,0,88,3,30,251,136,239,201,7,44,20,149,18,49,236,235,16,43,244,4,251,80,212,208,244,214,4,188,24,129,246,252,4,174,254,36,254,229,233,150,246,206,9,61,7,11,237,153,243,152,248,232,41,140,14,192,3,235,38,49,1,86,252,122,253,56,245,156,5,113,0,182,255,230,243,6,240,134,11,141,10,224,3,206,0,143,250,125,247,146,213,164,246,16,252,79,10,245,249,96,254,48,36,32,7,152,254,145,1,4,19,197,248,17,248,29,248,41,249,216,253,244,2,161,3,109,5,54,6,214,247,78,251,219,250,4,2,250,248,4,252,74,253,226,16,108,5,112,7,211,245,41,251,237,3,11,253,32,251,154,254,187,2,55,255,153,1,69,4,171,244,50,247,211,245,221,245,200,247,111,249,198,26,132,10,83,12,118,13,25,246,115,250,47,249,130,3,2,248,79,250,236,251,243,254,212,6,81,7,36,247,182,251,151,1,183,248,201,247,230,5,63,251,113,254,182,6,225,7,54,14,107,249,245,249,56,250,101,6,24,253,68,2,74,2,33,5,129,5,105,2,28,248,129,248,125,247,164,3,87,252,47,2,3,7,248,5,60,6,205,244,7,246,53,246,163,245,195,246,63,248,86,255,231,33,175,16,177,16,215,8,213,248,114,248,73,249,14,249,53,9,125,0,39,5,7,6,229,6,105,14,65,251,65,9,3,250,181,249,253,252,133,255,237,3,17,5,185,5,69,246,71,10,156,249,137,249,220,4,102,251,130,1,193,3,20,5,17,6,203,246,156,246,255,246,127,247,78,249,129,254,158,255,2,1,62,15,171,9,149,244,236,245,131,245,13,245,138,245,132,246,33,251,194,1,238,31,171,19,2,247,163,249,41,250,40,7,80,6,191,253,127,2,104,3,98,4,157,5,17,3,101,248,72,248,55,3,139,248,19,252,174,1,220,4,177,6,128,6,23,246,89,31,87,249,43,248,18,248,125,251,64,0,82,4,183,7,229,8,150,246,177,245,12,247,190,248,162,0,232,2,43,2,23,6,183,6,14,7,22,247,66,248,134,248,135,5,7,249,149,8,254,0,251,2,58,5,205,6,51,246,57,248,232,246,195,248,5,247,25,20,222,255,215,5,97,11,202,11,39,248,56,249,107,9,197,249,85,7,220,250,181,2,18,4,29,6,208,6,159,245,143,247,82,247,169,247,102,17,8,249,51,5,136,12,36,11,139,11,154,14,198,250,111,250,42,8,191,249,233,254,254,255,200,2,196,4,156,5,175,246,15,251,181,27,231,249,50,249,21,252,27,1,241,3,51,7,7,8,53,247,129,247,6,9,215,250,72,248,82,7,164,0,221,10,161,10,183,9,215,9,179,251,253,249,217,249,49,250,44,253,231,255,99,1,131,2,243,3,8,247,249,248,153,248,92,249,183,10,100,252,2,255,32,0,224,5,118,7,5,245,130,3,197,246,42,246,152,246,55,249,88,252,221,0,28,10,223,9,25,246,200,246,83,246,187,248,166,248,41,7,3,14,27,5,93,8,226,8,79,254,54,248,100,249,218,250,138,250,162,254,238,5,131,7,67,3,238,4,58,247,55,13,154,9,72,250,174,248,41,252,99,255,19,2,210,5,193,6,71,37,79,249,37,248,33,248,178,248,55,252,222,255,136,4,188,6,127,7,30,246,140,0,125,248,62,249,72,249,163,253,117,2,41,6,206,3,93,5,36,247,210,249,91,252,100,4,168,249,254,253,60,16,138,255,235,5,115,7,37,247,194,253,225,250,70,252,209,255,21,251,15,0,108,1,86,3,241,3,83,247,117,2,226,3,146,249,212,250,27,250,55,9,125,13,113,5,120,7,2,14,18,247,23,246,0,246,145,246,44,249,144,254,21,12,65,11,51,10,4,246,232,10,234,249,93,4,111,249,191,255,220,255,4,2,209,4,234,5,19,2,234,248,230,3,253,248,99,249,153,252,213,2,100,3,224,5,185,5,139,3,44,1,244,247,194,246,168,246,167,248,172,253,218,6,121,8,56,8,61,245,149,10,6,247,189,245,137,246,173,248,35,253,46,15,88,10,5,11,111,2,227,253,93,255,193,254,85,0,84,0,15,0,204,2,255,1,60,2,108,15,213,10,32,250,46,249,216,248,90,252,178,255,220,3,253,4,238,5,138,245,168,8,142,247,229,246,228,247,56,252,117,13,46,4,29,8,158,8,180,244,135,246,142,245,167,244,228,244,232,245,155,250,197,12,136,10,209,12,214,247,143,254,21,250,169,250,56,255,41,8,227,2,188,2,98,3,145,4,28,247,223,251,35,11,29,10,106,249,253,253,191,255,67,2,254,4,57,6,235,244,102,246,251,245,33,245,229,244,92,246,88,249,5,250,195,5,57,16,95,247,191,248,175,248,127,247,246,2,5,250,135,12,139,4,226,5,59,7,177,246,109,249,209,248,140,22,233,248,47,254,105,1,62,4,120,7,92,8,187,245,104,249,72,6,114,247,141,246,240,247,27,251,117,5,51,8,2,9,1,2,128,6,109,249,163,249,110,249,147,255,13,1,183,2,48,4,37,5,208,0,190,249,130,248,242,251,211,252,56,1,24,0,26,0,249,2,222,3,16,247,79,247,100,248,116,248,216,248,75,252,62,254,152,3,37,3,188,5,175,244,183,245,3,246,208,1,130,247,123,251,146,4,182,8,246,9,218,9,173,245,120,248,49,247,238,245,82,0,98,247,193,255,103,10,215,7,244,8,226,0,19,246,129,245,63,245,75,247,236,249,17,3,253,14,27,9,188,9,64,246,52,249,95,246,9,247,153,247,118,4,107,1,127,15,151,7,128,9,197,245,160,246,8,2,30,247,148,248,50,250,87,8,127,5,252,8,240,8,5,245,6,244,200,243,230,243,31,246,61,250,124,8,85,13,29,14,243,13,52,2,213,246,47,247,183,246,104,248,21,249,186,253,253,1,147,6,183,7,227,254,168,247,31,246,96,246,187,247,22,1,70,4,18,4,144,8,184,7,245,6,174,248,6,248,201,247,48,249,236,251,45,13,228,4,69,7,81,7,128,245,199,248,98,246,66,246,199,247,145,248,173,8,250,0,117,6,185,8,95,51,29,249,233,245,42,246,123,247,244,251,231,253,144,255,214,0,78,2,160,253,34,247,76,247,235,250,6,252,103,14,41,254,230,254,141,3,129,6,134,246,177,6,216,252,40,251,170,250,48,252,116,255,194,6,171,2,191,0,85,28,228,247,83,245,118,245,51,247,164,251,120,1,175,2,34,5,252,5,204,252,65,250,212,247,1,248,252,248,189,250,36,253,204,24,225,9,161,5,76,250,203,248,234,251,149,249,150,31,96,252,90,0,148,2,172,1,68,255,92,2,26,248,44,2,112,249,151,249,122,252,66,3,173,3,200,5,114,7,121,246,243,245,237,243,219,244,141,246,186,249,8,9,64,10,99,10,99,10,250,250,31,247,160,246,222,248,139,9,145,250,173,2,30,7,18,7,89,6,55,248,37,253,9,38,60,250,97,251,36,251,34,0,171,255,0,0,201,0,75,16,130,246,203,244,206,244,72,246,126,251,27,251,26,1,155,10,59,14,174,247,38,246,69,243,21,244,95,244,100,247,16,251,79,4,201,27,12,31,9,251,98,249,37,248,242,250,185,249,247,0,209,254,203,2,180,16,116,7,223,246,193,247,72,247,181,247,144,249,234,250,6,30,189,4,214,3,216,3,222,245,177,247,67,248,200,247,155,246,82,248,88,252,161,255,70,1,160,2,41,247,131,252,169,250,8,5,215,250,185,250,199,9,235,2,134,1,9,255,84,247,164,252,57,14,182,14,68,249,49,250,237,253,239,0,134,0,174,255,253,245,255,249,43,15,137,248,195,247,79,249,32,4,214,2,209,3,67,4,174,248,170,250,164,249,61,43,139,249,72,253,118,0,178,255,81,1,29,0,145,9,98,250,167,253,3,250,208,252,238,4,28,2,79,0,52,254,133,250,132,12,130,248,156,248,137,248,68,250,48,252,214,255,225,10,64,4,52,2,20,255,37,247,236,246,174,247,168,248,85,254,254,254,225,253,135,3,22,20,1,249,181,249,207,251,95,11,177,11,241,250,112,254,229,0,192,0,171,255,109,17,81,249,105,250,152,249,197,13,138,250,155,255,37,255,71,1,159,1,99,253,16,250,195,25,245,250,3,20,155,0,32,254,250,253,216,253,134,252,207,245,162,27,148,12,226,251,196,248,115,251,231,255,89,0,151,254,116,255,182,249,166,8,87,11,55,249,88,249,102,251,60,253,85,255,177,0,162,2,205,251,134,252,82,0,207,1,104,250,232,251,65,253,9,253,9,255,88,1,144,9,112,253,145,251,14,17,185,253,63,253,40,0,198,254,92,253,9,251,37,17,72,252,177,12,186,249,12,250,108,251,22,254,97,0,128,0,165,255,190,255,243,250,160,6,166,251,81,250,249,253,60,10,223,1,255,254,24,250,11,248,255,250,216,6,251,250,236,248,229,10,204,255,164,2,153,1,40,1,71,248,237,251,14,1,177,249,83,8,229,251,95,255,14,254,255,2,137,6,20,4,27,0,173,251,62,249,192,248,16,251,237,254,89,255,125,3,187,1,10,15,97,0,36,251,101,249,226,249,192,251,218,251,187,252,97,255,38,7,112,250,190,9,170,248,4,250,57,248,103,11,62,0,143,1,12,2,125,1,196,250,145,246,20,248,218,0,194,250,154,1,47,3,21,2,180,3,206,7,67,251,201,248,107,14,181,247,30,7,244,249,25,2,219,3,100,1,123,0,36,15,84,246,27,248,109,247,230,249,31,253,202,8,197,2,29,3,78,4,17,8,46,247,166,246,232,248,0,250,35,4,45,18,177,5,200,1,229,255,78,247,32,253,253,2,169,248,116,247,255,248,96,252,124,3,1,7,209,8,98,251,146,249,3,249,217,23,112,248,220,16,205,254,113,255,223,0,236,0,91,247,186,248,225,248,254,12,238,248,152,250,59,254,239,3,51,5,125,5,39,16,6,247,135,249,189,7,90,249,171,252,194,254,42,1,248,2,1,4,23,246,34,245,87,244,129,245,233,244,141,17,64,254,153,16,232,11,118,10,21,4,155,12,78,253,146,250,48,252,116,253,75,2,194,0,19,253,178,250,38,253,250,0,156,246,12,246,147,247,253,251,32,0,43,8,35,4,80,5,6,1,169,247,243,247,15,249,178,249,10,255,212,7,45,10,236,5,76,252,220,251,204,251,149,249,20,253,144,0,59,6,194,6,19,2,194,251,122,247,29,254,113,247,149,246,65,248,215,246,67,39,183,252,176,5,156,3,207,0,44,18,217,248,22,248,82,249,69,247,196,15,13,253,186,255,21,2,119,3,149,248,234,246,175,247,189,247,186,249,163,5,253,9,173,3,106,2,15,2,181,3,245,249,237,247,7,249,199,1,196,255,79,0,202,0,144,3,186,3,33,246,215,56,155,248,245,246,207,245,204,248,241,1,31,1,59,255,114,2,183,26,220,252,237,250,21,251,171,251,159,255,208,3,144,0,169,254,161,250,226,246,156,14,231,251,164,11,53,249,38,254,223,0,137,0,155,0,85,255,146,11,22,7,182,246,173,245,55,247,171,251,90,3,131,2,94,6,119,5,206,247,206,3,74,249,111,247,158,247,48,250,25,13,109,255,163,4,242,4,23,6,28,246,131,244,57,245,203,247,182,251,26,6,25,4,253,7,111,8,6,247,15,29,175,247,199,246,242,246,240,249,90,254,226,1,217,3,87,4,162,23,25,22,94,249,37,247,177,247,145,251,116,255,226,254,160,254,132,255,50,251,164,13,166,250,59,251,142,11,41,251,40,254,46,253,87,255,167,255,250,246,172,11,193,246,139,246,227,245,14,248,106,253,165,1,71,7,176,10,204,245,53,21,200,247,47,247,120,246,231,248,211,18,115,3,110,2,124,2,231,43,184,254,37,248,79,249,130,249,246,250,55,251,16,250,251,249,112,252,144,1,177,251,118,245,94,255,7,1,60,252,156,2,149,1,220,2,189,9,69,246,232,3,162,244,231,252,185,250,253,253,27,4,210,7,221,6,102,8,38,248,27,248,50,247,152,248,95,248,152,2,155,27,72,10,19,2,169,250,76,247,65,8,29,248,5,9,78,250,86,254,218,4,82,1,205,0,34,255,219,250,242,248,83,246,133,246,83,246,196,248,64,250,113,252,213,8,40,40,191,246,126,1,108,12,70,251,191,249,20,253,36,253,248,1,160,5,118,4,243,255,98,2,103,246,29,253,218,250,11,252,204,255,42,254,115,2,126,18,224,4,131,11,137,253,24,6,48,8,191,252,107,251,61,250,244,247,115,247,199,3,85,250,248,249,10,253,230,253,225,255,115,5,222,13,253,255,49,248,73,248,58,249,136,245,48,246,11,248,230,250,4,255,8,5,124,23,226,18,193,251,187,12,43,12,167,250,144,251,76,252,248,254,186,253,91,253,125,253,60,246,4,5,195,254,176,248,130,251,130,251,54,1,64,3,61,6,26,11,151,24,222,14,97,253,0,250,76,250,24,251,57,251,32,250,120,249,65,250,78,5,236,3,155,248,90,4,149,249,153,255,255,253,189,0,47,1,140,0,174,249,120,253,48,253,106,28,61,2,76,255,37,253,54,251,228,249,50,249,151,0,55,8,230,249,50,252,94,0,34,2,208,13,51,255,135,249,26,246,117,247,24,11,32,251,195,1,55,10,171,0,223,1,207,254,237,250,84,249,160,247,199,249,247,250,206,10,239,8,112,254,188,0,205,255,141,0,105,0,176,247,112,19,102,249,64,251,105,251,41,1,174,5,193,1,34,254,54,252,134,248,77,250,220,11,108,10,74,252,134,253,5,254,138,254,4,0,34,0,128,249,85,11,79,3,1,11,126,251,141,249,18,251,120,251,144,253,117,2,42,6,253,2,46,248,183,247,9,250,146,7,240,254,113,0,31,1,187,3,63,250,60,0,111,31,137,0,234,253,183,252,203,251,32,250,4,249,34,249,177,248,119,0,163,3,239,6,64,253,232,10,98,1,11,254,166,250,10,248,249,251,161,249,134,248,145,252,121,1,165,29,173,0,60,255,21,254,134,249,206,14,251,252,61,249,212,11,49,0,11,252,205,253,48,251,71,252,38,253,248,245,122,248,89,253,245,254,188,254,62,252,51,0,205,1,168,10,47,14,205,13,102,249,226,244,190,246,103,248,107,252,217,253,20,1,74,10,230,13,224,245,42,249,138,246,206,249,76,251,23,252,251,17,10,7,113,10,149,6,150,10,171,252,239,246,129,248,189,249,156,252,122,14,34,1,58,2,82,1,59,247,88,249,133,248,33,2,237,252,99,6,189,6,14,2,154,2,68,6,130,2,126,251,159,12,48,251,20,249,145,253,217,0,27,0,3,0,129,2,149,246,132,7,57,252,209,249,37,250,12,9,74,5,141,255,77,1,47,2,71,249,171,9,106,248,190,247,84,251,197,253,233,6,46,9,35,5,161,253,158,17,122,250,76,247,224,250,159,5,213,1,8,255,113,254,242,254,47,253,19,250,33,251,253,252,220,255,88,25,174,3,233,254,196,253,239,251,140,248,172,246,23,247,221,245,29,247,7,250,51,0,215,1,83,17,186,11,178,10,209,15,26,6,110,245,120,249,143,249,76,251,250,253,232,254,6,3,64,5,6,0,98,248,15,250,24,249,52,252,140,5,195,11,65,255,132,2,198,5,148,12,199,254,214,11,103,255,183,252,29,253,134,254,11,252,126,250,233,248,200,247,247,251,207,247,56,248,81,252,87,9,168,1,113,1,65,6,3,13,214,5,244,247,21,248,43,6,129,250,96,4,232,254,59,255,249,2,24,4,58,253,254,15,3,250,64,248,172,249,148,251,253,253,27,254,203,3,84,10,139,15,107,253,157,248,160,251,127,252,180,9,87,6,21,0,2,250,122,246,129,12,26,250,90,3,77,250,57,253,204,250,191,252,16,255,251,2,72,4,101,250,227,255,102,12,19,249,237,255,196,2,144,6,147,1,114,252,80,247,146,245,149,253,40,5,17,253,213,250,2,252,59,11,56,4,217,3,1,0,191,0,143,30,37,254,164,253,154,251,57,252,141,251,192,249,25,249,119,251,194,250,88,248,192,247,255,248,196,249,31,12,23,2,209,7,163,12,151,0,38,247,217,252,71,248,131,249,25,251,24,9,72,10,117,12,109,2,150,251,121,247,153,251,87,9,140,252,125,8,78,253,158,254,252,253,96,1,186,3,55,7,182,255,20,251,209,248,253,9,59,251,228,0,138,253,94,255,130,1,182,5,159,248,220,245,88,247,179,248,250,253,1,5,25,9,93,10,93,4,1,250,242,251,40,249,186,248,157,249,213,251,226,3,92,20,159,10,248,254,27,248,32,7,194,247,149,253,2,6,115,254,180,254,103,255,92,3,1,5,168,25,2,249,101,246,85,249,84,249,225,252,38,1,89,0,219,1,224,3,124,249,229,248,38,248,169,249,31,8,183,12,124,254,79,2,197,5,69,2,248,249,220,1,223,248,65,252,240,250,243,251,59,254,122,4,85,18,71,3,235,7,205,11,61,249,46,249,84,248,165,251,173,4,102,0,164,0,94,255,3,247,255,250,26,248,143,15,158,251,231,254,85,0,96,1,18,4,63,6,63,25,163,255,38,248,60,248,22,247,115,247,133,248,71,249,17,0,86,18,168,1,26,252,145,255,53,248,34,251,104,251,78,0,140,255,159,7,243,11,74,248,9,249,61,247,42,251,95,15,96,252,241,255,241,4,0,6,115,7,216,255,230,254,86,5,107,251,100,242,99,1,202,251,216,14,34,17,221,255,160,239,11,2,11,5,166,2,156,0,224,8,237,251,51,4,199,248,198,254,246,253,136,1,50,8,177,255,217,1,237,254,2,0,254,24,195,1,94,0,173,0,81,254,91,4,220,213,35,0,31,7,204,242,159,255,158,255,162,254,233,255,16,251,204,254,244,34,73,253,177,255,192,13,52,1,84,1,150,254,221,253,183,4,98,251,104,215,108,255,252,13,225,1,87,254,94,3,30,19,224,2,104,255,142,253,23,0,35,233,39,0,113,255,162,1,153,255,79,250,230,205,134,255,27,1,31,255,65,41,103,255,168,34,218,252,205,255,93,0,164,1,47,255,89,1,19,226,36,253,208,255,223,1,31,255,20,1,73,52,222,206,96,250,247,254,238,254,81,4,208,242,77,253,189,253,52,252,44,1,93,1,106,1,210,2,40,254,185,0,46,3,14,0,138,18,249,2,176,254,155,6,120,3,123,249,227,182,59,3,211,245,153,3,155,0,68,0,112,0,40,244,225,254,158,1,170,255,194,255,43,255,150,255,39,3,149,253,86,2,78,255,32,12,31,254,239,249,226,4,85,223,82,253,120,218,116,0,209,255,65,1,167,255,171,3,221,255,197,224,81,216,242,253,145,0,107,1,122,8,53,4,57,251,30,253,120,0,104,254,122,254,176,255,108,254,185,249,53,216,224,230,193,3,94,0,77,250,233,1,241,25,116,1,239,3,70,23,190,252,222,0,51,0,26,1,19,252,121,17,119,221,183,255,35,254,211,253,121,0,91,255,85,251,182,1,139,0,66,255,147,239,74,239,247,237,88,226,40,0,90,254,53,254,82,2,163,28,164,0,41,1,71,10,141,220,178,255,116,1,187,231,227,251,182,0,185,255,126,254,164,253,56,210,40,2,151,253,157,1,12,5,4,0,27,254,138,4,163,23,208,235,75,255,0,4,138,253,237,254,29,240,77,222,106,5,202,3,89,254,157,11,56,9,107,1,238,254,154,1,48,0,0,3,142,11,85,254,86,0,64,0,128,255,239,254,74,255,220,254,100,3,207,1,73,0,140,255,147,230,81,235,219,255,179,2,88,1,136,255,168,0,163,1,238,1,105,251,208,73,121,255,136,254,38,255,59,254,108,252,240,251,93,169,178,252,19,252,8,1,159,0,85,2,72,252,199,252,137,1,184,254,154,198,115,1,249,254,228,2,38,0,23,252,9,5,100,253,187,0,101,255,143,0,171,2,221,27,205,253,65,223,221,254,176,0,75,0,101,2,203,228,40,211,68,1,22,254,74,2,160,1,250,2,145,22,64,0,209,255,228,239,84,251,143,255,189,2,45,255,31,9,130,0,172,2,110,28,98,255,43,255,41,1,93,42,97,250,47,254,17,0,232,252,99,25,53,216,68,254,120,250,226,1,124,2,192,5,240,2,157,0,178,254,98,243,237,255,165,229,148,2,246,243,217,15,145,26,237,255,123,2,19,0,79,38,14,2,126,0,188,1,66,255,94,254,126,151,54,255,243,0,85,2,10,0,89,1,46,3,182,254,160,0,88,1,146,15,214,1,203,1,83,9,219,253,113,46,211,248,226,255,48,10,103,2,253,8,253,252,203,249,233,228,41,5,191,16,39,1,210,253,33,250,157,253,56,8,155,1,38,255,121,4,86,254,58,0,154,255,13,0,75,29,220,1,64,240], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+491520);
/* memory initializer */ allocate([67,247,158,245,105,248,148,20,15,4,133,1,179,27,234,255,156,0,70,255,128,9,146,252,49,1,66,249,137,12,105,1,250,251,249,1,106,2,250,254,171,248,12,1,245,2,24,0,242,94,102,0,205,3,142,0,71,252,81,251,116,0,1,255,250,20,165,254,147,254,169,3,229,228,91,251,8,253,19,2,33,249,63,253,211,253,148,253,127,4,250,0,125,84,4,250,128,255,141,5,45,255,80,2,6,20,197,0,52,253,89,4,212,22,246,254,244,255,211,252,85,0,226,3,198,247,181,240,122,5,21,2,9,2,141,252,87,0,126,254,254,255,2,239,78,77,76,255,149,254,60,0,101,0,75,249,119,0,131,254,100,0,203,253,192,12,236,11,200,0,105,227,26,0,91,1,30,254,113,41,2,253,14,2,145,253,167,13,83,1,202,238,197,255,43,255,174,2,165,253,133,0,99,0,48,0,180,6,66,251,117,5,164,246,128,254,123,252,90,241,108,253,38,239,57,1,192,0,36,1,3,1,124,253,176,0,51,8,25,31,227,255,130,2,102,244,0,7,195,255,4,239,66,2,75,7,180,248,32,0,142,20,137,0,221,23,187,1,80,255,95,1,144,1,82,7,81,255,31,240,185,2,36,1,24,253,121,0,242,235,84,27,58,255,116,2,49,4,169,253,140,255,20,186,135,2,231,251,105,253,147,5,162,255,209,2,55,1,81,1,96,5,32,245,107,15,62,5,41,6,106,254,252,254,12,216,109,0,54,9,133,9,90,1,237,4,204,254,210,247,146,6,144,0,93,253,183,0,172,1,74,252,225,4,246,249,33,0,2,255,169,2,16,251,60,252,202,254,70,3,100,0,64,170,52,250,228,249,83,1,42,1,67,0,174,254,89,0,197,2,53,0,2,1,153,254,243,10,17,6,200,254,199,224,165,249,165,4,220,1,133,255,80,1,1,253,166,183,77,2,174,3,123,253,131,254,135,248,186,253,55,0,148,252,3,254,55,98,178,2,237,252,144,251,114,0,162,0,86,1,25,255,218,221,99,0,122,253,38,254,152,250,146,255,158,255,186,33,242,255,52,218,200,254,102,1,240,1,92,253,159,255,112,7,180,247,190,255,180,248,246,1,255,253,84,243,31,8,60,250,64,21,216,255,131,254,244,1,18,255,41,254,128,47,248,0,19,252,186,244,173,0,215,242,157,254,0,255,139,255,38,254,254,250,157,254,130,0,31,237,31,0,24,255,125,205,198,252,66,1,71,3,1,6,73,0,226,0,160,248,29,254,224,244,66,255,247,4,13,14,94,238,218,255,205,23,91,1,188,255,97,254,151,255,128,249,59,211,146,255,113,254,133,1,1,254,167,3,88,254,84,249,254,251,199,90,42,1,195,28,10,220,202,253,3,1,100,254,67,251,79,1,102,2,160,3,204,3,129,248,105,254,253,1,47,1,62,202,244,253,120,40,38,5,58,245,46,9,150,255,137,255,188,255,245,231,1,255,64,254,222,255,192,255,226,238,47,0,123,2,173,254,150,1,65,254,67,254,160,214,233,0,160,0,117,234,203,250,99,26,72,252,172,0,20,251,218,254,152,13,160,254,25,255,159,1,226,1,14,254,65,255,14,248,254,30,61,31,80,253,225,218,120,1,28,255,12,254,222,0,3,252,105,254,5,1,179,0,110,2,193,4,69,254,5,253,4,254,49,253,99,238,91,0,193,1,229,254,91,0,217,255,193,3,92,216,60,6,55,220,185,254,221,0,42,254,164,2,12,0,136,5,216,3,20,213,132,234,67,255,41,253,226,0,83,18,176,2,247,2,162,3,212,230,142,255,229,253,242,253,235,255,62,251,138,2,200,23,163,1,41,24,80,251,84,0,48,251,222,255,149,255,60,0,200,8,194,1,163,4,240,4,75,255,89,3,187,8,213,244,85,203,64,255,182,253,49,255,63,234,247,1,48,13,219,4,68,253,71,8,118,247,216,254,128,3,43,1,177,0,184,0,95,5,194,9,161,0,67,2,157,241,187,1,235,255,70,255,110,242,238,0,18,1,21,1,187,254,123,223,33,255,125,0,191,0,77,1,167,254,145,250,52,227,125,44,225,251,226,15,182,251,87,0,53,255,187,1,107,1,65,252,35,60,176,15,2,255,75,6,88,255,210,251,149,10,0,253,250,1,35,251,189,22,195,9,28,6,27,0,85,0,197,7,188,251,150,0,52,252,148,2,223,255,175,2,33,2,228,249,208,2,60,255,204,255,41,249,220,156,34,251,153,253,135,1,0,254,7,165,204,1,104,1,171,255,45,253,6,255,93,255,208,255,103,252,108,240,169,1,12,251,97,249,161,12,187,251,114,251,198,0,178,29,21,0,98,1,221,2,181,47,165,254,20,2,85,254,22,0,170,8,190,253,202,242,38,254,143,253,78,0,62,238,95,3,203,255,155,254,7,250,246,3,198,2,76,5,82,254,159,249,9,159,95,0,26,0,78,2,177,253,103,225,181,250,213,217,10,254,117,252,183,195,189,3,207,1,35,0,16,254,38,1,81,8,250,4,96,255,173,255,19,2,1,253,29,1,232,0,95,23,22,232,84,6,16,16,17,255,59,249,210,255,215,250,211,1,101,2,93,241,20,247,167,54,117,1,51,188,37,255,176,255,46,255,182,5,37,0,100,249,36,2,43,233,164,1,54,0,162,254,227,254,189,7,6,1,150,252,28,11,77,254,95,231,49,25,72,0,119,2,162,255,96,0,70,254,113,4,89,0,108,1,64,13,72,242,125,254,31,4,62,1,169,251,197,228,88,1,111,220,160,255,110,219,190,0,31,255,114,1,161,0,183,255,218,248,174,0,48,0,250,253,98,242,137,0,21,255,42,3,23,0,80,0,126,253,221,255,196,254,243,254,139,254,147,246,91,252,221,9,11,1,4,254,56,255,166,1,114,242,7,251,128,2,92,248,139,0,138,1,237,251,0,213,98,255,191,251,25,248,202,0,45,252,24,253,97,255,120,254,219,255,113,249,135,8,85,5,189,244,112,237,49,247,109,0,124,6,155,253,1,254,4,5,93,227,179,3,97,27,232,247,191,254,88,252,217,253,149,252,160,0,109,150,142,2,9,1,164,0,120,1,214,2,107,255,253,10,162,255,96,22,190,2,162,251,5,246,217,0,70,255,149,255,146,0,173,255,194,255,60,255,196,2,146,0,145,14,96,254,212,0,93,255,75,225,91,1,83,0,201,251,30,252,15,1,226,251,145,249,139,0,236,255,98,1,18,5,164,242,106,4,161,0,219,1,183,240,212,1,23,0,29,1,93,249,42,32,77,252,222,0,4,1,180,16,171,254,243,24,21,0,234,1,140,248,138,249,196,255,167,9,221,2,121,255,109,0,144,251,92,198,58,19,141,4,149,0,120,240,190,255,174,253,37,24,146,255,36,1,105,4,177,253,127,217,189,61,49,153,106,62,32,210,207,62,65,241,19,63,163,146,58,63,78,209,97,63,91,211,132,63,18,131,152,63,65,241,171,63,231,29,191,63,72,225,210,63,91,66,230,63,169,19,248,63,191,125,5,64,186,218,14,64,147,24,24,64,97,50,33,64,193,202,41,64,43,135,50,64,152,221,59,64,202,84,193,61,58,35,74,62,136,244,155,62,87,91,241,62,209,145,28,63,34,108,72,63,89,23,103,63,205,204,132,63,87,236,151,63,122,165,172,63,247,117,192,63,251,203,214,63,204,238,233,63,75,200,255,63,11,70,9,64,5,197,19,64,129,4,29,64,138,31,39,64,214,86,48,64,46,255,57,64,215,52,239,61,197,143,145,62,8,61,251,62,113,172,43,63,41,92,79,63,64,19,113,63,110,163,137,63,122,199,153,63,50,85,168,63,126,140,185,63,76,166,202,63,130,115,222,63,27,158,238,63,213,120,1,64,39,194,10,64,205,204,20,64,41,237,29,64,229,242,39,64,30,167,48,64,188,5,58,64,21,140,10,62,160,26,111,62,68,139,172,62,137,65,224,62,102,247,20,63,159,60,60,63,68,250,93,63,74,12,130,63,53,94,146,63,9,27,166,63,63,53,190,63,91,66,214,63,113,172,235,63,224,45,0,64,57,214,9,64,93,254,19,64,168,87,30,64,11,36,40,64,26,81,50,64,200,7,61,64,22,106,205,61,65,241,99,62,52,128,183,62,228,131,254,62,179,12,33,63,66,96,69,63,81,107,106,63,46,144,136,63,47,110,155,63,32,99,174,63,202,84,193,63,77,132,213,63,204,127,232,63,2,188,253,63,238,235,8,64,140,185,19,64,204,238,29,64,192,91,40,64,27,158,50,64,120,11,60,64,208,68,216,61,151,144,79,62,226,88,151,62,86,14,205,62,6,129,5,63,140,185,43,63,131,192,90,63,45,33,135,63,210,0,158,63,145,126,179,63,30,167,200,63,141,40,221,63,14,190,240,63,59,112,2,64,125,208,11,64,61,155,21,64,220,70,31,64,20,208,40,64,81,107,50,64,91,211,60,64,59,223,207,61,218,27,124,62,225,11,211,62,120,11,20,63,48,42,57,63,243,31,98,63,91,211,132,63,192,91,152,63,202,195,170,63,111,129,188,63,0,145,206,63,179,12,225,63,215,18,242,63,53,94,2,64,235,226,10,64,0,0,20,64,205,204,28,64,59,112,38,64,120,11,48,64,147,169,58,64,34,253,54,62,107,154,119,62,2,43,167,62,208,179,9,63,231,140,40,63,52,162,68,63,29,90,116,63,164,112,141,63,51,51,155,63,141,40,173,63,102,247,188,63,242,210,213,63,11,36,232,63,159,205,250,63,139,253,5,64,0,111,17,64,33,31,28,64,177,225,37,64,108,9,45,64,22,251,55,64,87,236,175,61,10,215,35,62,117,147,152,62,209,145,252,62,232,106,43,63,147,24,84,63,192,236,126,63,168,198,147,63,5,197,167,63,202,195,186,63,244,108,206,63,19,242,225,63,200,7,245,63,29,90,4,64,247,228,13,64,177,80,23,64,4,231,32,64,118,79,42,64,126,29,52,64,188,5,62,64,53,94,186,61,98,16,88,62,159,60,172,62,197,143,241,62,226,233,21,63,44,212,58,63,147,24,100,63,70,148,134,63,71,114,153,63,187,184,173,63,69,71,194,63,32,210,215,63,216,129,235,63,52,162,0,64,86,125,10,64,215,163,20,64,185,141,30,64,84,116,40,64,189,82,50,64,159,60,60,64,56,248,66,62,24,38,147,62,154,119,188,62,247,6,255,62,229,242,31,63,94,186,73,63,99,127,105,63,154,153,137,63,207,247,155,63,85,193,176,63,239,201,195,63,138,176,217,63,68,250,237,63,12,2,3,64,66,62,12,64,205,204,20,64,238,235,28,64,48,76,38,64,68,105,47,64,72,191,57,64,54,205,187,61,42,169,83,62,249,49,166,62,210,0,254,62,55,137,33,63,22,106,77,63,224,156,113,63,4,231,140,63,205,59,158,63,78,209,177,63,168,53,197,63,188,5,218,63,152,221,235,63,241,99,0,64,83,150,9,64,229,242,19,64,184,30,29,64,60,189,38,64,190,193,47,64,29,201,57,64,21,140,202,61,46,144,96,62,165,78,192,62,250,126,10,63,229,97,49,63,134,56,86,63,213,231,122,63,0,0,144,63,254,67,162,63,34,142,181,63,101,170,200,63,109,86,221,63,137,65,240,63,139,253,1,64,9,138,11,64,141,40,21,64,77,243,30,64,209,145,40,64,208,213,50,64,21,29,61,64,50,85,176,61,148,246,70,62,182,132,156,62,190,48,249,62,0,145,30,63,238,90,66,63,67,28,107,63,50,119,141,63,32,210,159,63,234,4,180,63,146,203,199,63,43,24,221,63,254,101,239,63,198,220,1,64,88,202,10,64,215,163,20,64,132,158,29,64,209,34,39,64,125,208,47,64,203,161,57,64,164,223,190,61,98,16,88,62,155,85,191,62,45,67,12,63,162,69,54,63,90,100,91,63,41,92,127,63,142,117,145,63,74,123,163,63,25,4,182,63,103,213,199,63,60,189,218,63,227,165,235,63,29,201,253,63,77,21,8,64,48,76,18,64,160,137,28,64,52,128,39,64,220,215,49,64,197,32,60,64,143,83,244,61,233,183,111,62,170,96,180,62,14,190,0,63,134,201,36,63,190,193,71,63,146,203,111,63,189,227,140,63,27,158,158,63,240,133,177,63,164,112,197,63,26,192,219,63,167,121,239,63,83,150,1,64,58,35,10,64,164,223,18,64,58,146,27,64,103,68,37,64,211,77,46,64,78,209,57,64,159,205,170,61,58,146,75,62,79,30,182,62,125,174,6,63,54,60,45,63,48,187,87,63,7,95,128,63,219,138,149,63,153,42,168,63,19,242,185,63,136,99,205,63,249,15,225,63,63,87,243,63,14,79,3,64,214,86,12,64,165,189,21,64,56,248,30,64,45,67,40,64,2,188,49,64,162,180,59,64,55,26,192,61,186,107,73,62,111,129,164,62,41,92,239,62,63,87,27,63,202,50,68,63,206,25,113,63,4,86,142,63,176,114,160,63,97,84,178,63,67,28,195,63,132,13,215,63,44,212,234,63,231,29,255,63,112,206,8,64,139,108,19,64,159,171,29,64,43,246,39,64,9,27,50,64,114,249,59,64,23,72,208,61,147,169,130,62,219,138,221,62,3,9,26,63,187,39,63,63,5,52,97,63,217,61,129,63,37,117,146,63,110,163,161,63,195,211,179,63,192,236,198,63,131,192,218,63,1,77,236,63,5,197,255,63,170,130,9,64,183,98,19,64,25,226,28,64,72,225,38,64,2,154,48,64,7,240,58,64,24,38,211,61,12,2,107,62,174,216,191,62,138,31,3,63,140,219,40,63,209,34,75,63,100,59,111,63,164,112,141,63,228,131,158,63,180,89,173,63,193,168,188,63,114,138,206,63,84,82,223,63,101,25,242,63,17,199,2,64,45,67,12,64,202,195,22,64,206,136,34,64,74,123,47,64,153,42,60,64,205,59,206,61,252,24,115,62,63,53,190,62,198,109,4,63,6,129,37,63,0,145,78,63,138,142,116,63,240,167,142,63,5,52,161,63,200,7,181,63,201,229,199,63,140,185,219,63,230,63,236,63,169,19,0,64,87,91,9,64,97,84,18,64,79,64,27,64,242,210,37,64,73,46,47,64,23,183,57,64,120,122,165,61,14,190,48,62,106,222,145,62,67,28,235,62,237,158,28,63,108,9,73,63,235,115,117,63,169,19,144,63,122,54,163,63,181,55,184,63,145,126,203,63,224,45,224,63,213,231,242,63,172,139,3,64,149,101,12,64,182,243,21,64,28,235,30,64,93,254,39,64,122,165,48,64,141,151,58,64,213,231,42,62,239,201,131,62,255,33,189,62,0,145,14,63,136,99,45,63,146,92,78,63,74,12,130,63,109,86,149,63,140,185,163,63,140,185,179,63,29,201,197,63,230,63,220,63,113,27,237,63,66,62,0,64,179,12,9,64,251,92,21,64,124,97,30,64,161,103,39,64,60,189,46,64,144,160,56,64,156,162,35,62,64,19,129,62,50,230,174,62,125,208,3,63,200,152,43,63,35,74,75,63,69,216,112,63,50,230,142,63,78,209,153,63,129,38,170,63,137,210,190,63,137,210,214,63,163,1,236,63,203,16,255,63,134,90,7,64,103,68,17,64,186,73,28,64,156,162,39,64,253,135,48,64,91,66,58,64,199,186,184,61,21,140,74,62,2,43,167,62,195,100,234,62,16,122,22,63,59,112,62,63,76,55,105,63,200,152,139,63,128,183,160,63,205,204,180,63,112,206,200,63,66,96,221,63,222,2,241,63,83,5,3,64,212,43,13,64,5,163,22,64,225,122,32,64,62,232,41,64,58,146,51,64,15,11,61,64,194,134,167,61,104,145,45,62,132,13,143,62,47,221,228,62,204,93,27,63,15,156,67,63,173,105,110,63,218,27,140,63,93,220,158,63,33,31,180,63,39,49,200,63,22,251,219,63,153,187,238,63,39,160,1,64,225,11,11,64,200,7,21,64,27,158,30,64,159,60,40,64,154,153,49,64,5,197,59,64,131,192,74,62,247,117,160,62,106,222,209,62,82,184,254,62,107,43,38,63,244,108,86,63,138,176,113,63,125,208,131,63,219,249,150,63,28,124,177,63,3,9,202,63,116,70,220,63,82,39,232,63,54,171,246,63,240,133,5,64,131,192,18,64,237,13,30,64,222,147,39,64,138,142,48,64,215,52,59,64,222,2,9,62,233,183,111,62,70,148,182,62,61,155,245,62,4,231,28,63,74,12,66,63,227,199,104,63,233,72,134,63,247,117,152,63,10,104,170,63,253,246,189,63,8,61,211,63,23,217,230,63,207,247,251,63,29,56,7,64,217,61,17,64,249,49,26,64,193,168,36,64,79,30,46,64,197,143,57,64,201,229,191,61,23,72,80,62,133,124,176,62,183,209,0,63,111,18,35,63,237,158,76,63,135,167,119,63,53,239,144,63,88,57,164,63,72,191,181,63,48,76,198,63,94,186,217,63,102,247,236,63,138,142,0,64,133,235,9,64,158,239,19,64,23,183,29,64,179,234,39,64,46,255,49,64,218,27,60,64,63,53,222,61,100,93,92,62,27,13,160,62,204,238,233,62,124,97,18,63,30,167,56,63,42,58,98,63,48,187,135,63,69,71,154,63,98,16,176,63,228,20,197,63,224,156,217,63,156,162,235,63,230,63,0,64,83,150,9,64,70,182,19,64,37,6,29,64,159,205,38,64,49,8,48,64,211,77,58,64,249,49,102,61,243,142,83,62,114,138,206,62,68,139,12,63,40,15,43,63,186,218,74,63,111,18,115,63,113,61,138,63,87,236,151,63,149,101,168,63,13,224,189,63,36,185,212,63,58,146,235,63,11,70,1,64,88,168,9,64,203,161,17,64,145,15,26,64,70,182,35,64,85,193,44,64,15,11,57,64,165,78,192,61,195,211,107,62,36,151,191,62,240,167,6,63,21,140,42,63,143,83,84,63,30,22,122,63,254,212,144,63,211,188,163,63,141,40,181,63,175,148,197,63,214,197,213,63,233,38,233,63,219,249,254,63,78,98,8,64,100,59,19,64,129,4,29,64,200,7,37,64,9,27,46,64,3,9,58,64,242,210,205,61,145,15,122,62,222,147,199,62,85,48,10,63,243,31,50,63,53,239,88,63,55,26,128,63,179,234,147,63,240,167,166,63,108,9,185,63,17,54,204,63,178,157,223,63,156,51,242,63,51,51,3,64,238,235,12,64,75,89,22,64,97,195,31,64,108,9,41,64,250,126,50,64,165,78,60,64,60,78,209,61,114,249,79,62,111,129,164,62,229,97,225,62,165,78,16,63,249,49,54,63,95,7,94,63,252,24,131,63,9,27,150,63,108,9,169,63,95,7,190,63,131,192,210,63,141,151,230,63,129,149,251,63,38,228,7,64,32,99,18,64,209,145,28,64,164,223,38,64,27,47,49,64,181,55,60,64,150,67,75,62,225,11,179,62,122,165,236,62,163,35,25,63,233,183,63,63,27,13,96,63,123,20,126,63,191,125,149,63,30,22,170,63,241,244,186,63,250,126,202,63,201,229,223,63,156,51,242,63,57,69,3,64,90,100,11,64,83,150,21,64,201,118,30,64,38,228,39,64,75,200,47,64,142,117,57,64,74,123,3,62,163,35,121,62,35,219,185,62,34,108,248,62,95,152,28,63,219,249,62,63,65,241,99,63,166,155,132,63,20,63,150,63,181,55,168,63,218,27,188,63,2,43,207,63,159,205,226,63,57,69,247,63,129,38,6,64,196,66,17,64,17,54,28,64,196,177,38,64,141,40,49,64,133,124,60,64,207,102,213,61,30,22,106,62,181,55,184,62,110,163,1,63,20,208,36,63,227,54,74,63,41,92,111,63,161,103,139,63,2,188,157,63,199,186,176,63,72,225,194,63,146,92,214,63,192,91,232,63,97,195,251,63,248,83,7,64,243,31,18,64,29,90,28,64,170,241,38,64,83,150,49,64,125,208,59,64,119,190,159,61,160,137,48,62,35,219,121,62,5,163,178,62,2,43,7,63,9,27,62,63,251,92,109,63,255,178,139,63,41,203,160,63,61,155,181,63,140,74,202,63,173,105,222,63,3,9,242,63,247,6,3,64,84,116,12,64,243,31,22,64,20,174,31,64,21,29,41,64,245,185,50,64,21,29,61,64,247,228,225,61,148,135,133,62,32,65,209,62,214,197,13,63,147,58,49,63,52,128,87,63,201,118,126,63,35,74,147,63,251,92,165,63,149,101,184,63,254,67,202,63,31,244,220,63,0,145,238,63,68,139,0,64,145,15,10,64,61,10,19,64,162,180,27,64,219,138,37,64,100,59,47,64,233,72,58,64,20,208,4,62,110,163,129,62,31,244,204,62,34,108,8,63,100,93,44,63,31,133,75,63,193,168,116,63,197,254,138,63,166,155,156,63,82,73,173,63,62,121,192,63,122,199,209,63,111,240,229,63,23,217,246,63,72,191,5,64,45,67,16,64,18,20,27,64,231,140,36,64,0,0,44,64,196,66,57,64,124,97,178,61,240,133,73,62,41,92,175,62,136,99,253,62,84,116,36,63,26,192,75,63,6,18,116,63,86,125,142,63,46,255,161,63,150,33,182,63,74,12,202,63,157,17,221,63,48,187,239,63,162,69,2,64,134,201,12,64,251,203,22,64,102,247,32,64,169,164,42,64,197,32,52,64,129,4,61,64,24,149,212,61,138,176,97,62,48,76,166,62,122,199,233,62,66,62,24,63,114,138,62,63,197,143,97,63,232,217,132,63,46,255,153,63,23,72,176,63,6,129,197,63,17,199,218,63,102,102,238,63,145,15,2,64,131,47,12,64,106,222,21,64,119,190,31,64,202,84,41,64,203,16,51,64,57,180,60,64,240,22,8,62,50,119,141,62,177,225,201,62,97,195,3,63,11,181,38,63,27,158,78,63,96,229,112,63,79,64,139,63,22,106,157,63,174,71,177,63,15,156,195,63,93,109,213,63,82,39,232,63,16,233,255,63,2,154,8,64,246,151,17,64,171,62,27,64,240,133,37,64,139,108,47,64,17,199,58,64,25,115,215,61,63,87,91,62,52,128,183,62,69,216,0,63,216,129,35,63,75,200,71,63,141,151,110,63,231,251,137,63,54,205,155,63,224,45,176,63,136,99,197,63,82,39,216,63,126,140,233,63,198,220,253,63,207,247,7,64,155,230,17,64,231,29,27,64,80,252,36,64,222,113,46,64,134,56,58,64,64,164,223,61,222,2,137,62,105,111,208,62,135,22,9,63,136,133,42,63,105,111,80,63,48,76,118,63,176,3,143,63,110,163,161,63,104,145,181,63,167,232,200,63,127,106,220,63,25,4,238,63,163,35,1,64,12,2,11,64,73,157,20,64,249,49,30,64,191,14,40,64,143,194,49,64,211,188,59,64,91,66,190,61,114,138,78,62,109,86,157,62,231,251,233,62,10,215,19,63,188,116,67,63,237,13,110,63,76,166,138,63,13,224,157,63,53,94,178,63,66,96,197,63,154,8,219,63,194,23,238,63,68,250,1,64,160,26,11,64,8,172,20,64,64,19,29,64,27,158,38,64,167,121,47,64,240,133,57,64,82,184,158,61,223,79,77,62,33,176,178,62,184,30,5,63,36,185,44,63,212,154,86,63,86,14,125,63,20,63,150,63,110,52,168,63,134,56,182,63,232,106,203,63,224,190,222,63,154,119,236,63,16,88,1,64,249,49,10,64,213,120,17,64,160,26,27,64,152,221,35,64,132,158,45,64,203,161,57,64,101,25,226,61,104,179,106,62,113,172,171,62,69,71,242,62,191,125,29,63,225,122,68,63,49,153,106,63,15,156,139,63,5,52,161,63,234,4,180,63,88,202,194,63,184,64,210,63,98,161,230,63,144,49,255,63,128,183,8,64,77,243,18,64,124,242,28,64,99,238,38,64,36,185,48,64,143,228,58,64,48,42,169,61,205,204,76,62,196,66,173,62,184,175,3,63,204,93,43,63,130,115,86,63,8,172,124,63,104,179,146,63,143,194,165,63,55,137,185,63,95,41,203,63,185,141,222,63,231,140,240,63,9,27,2,64,247,6,11,64,250,237,19,64,137,65,28,64,171,207,37,64,203,16,47,64,122,199,57,64,208,179,217,61,66,62,104,62,251,58,176,62,152,110,242,62,209,145,28,63,224,45,64,63,231,29,103,63,149,212,137,63,132,13,159,63,152,221,179,63,171,62,199,63,193,202,217,63,170,130,233,63,150,178,252,63,153,42,8,64,215,18,18,64,220,70,27,64,101,25,38,64,20,208,48,64,188,116,59,64,31,133,235,61,169,19,144,62,2,154,232,62,49,8,28,63,177,191,60,63,136,244,91,63,18,165,125,63,178,46,142,63,111,240,157,63,182,243,173,63,91,66,190,63,77,243,206,63,27,158,222,63,142,6,240,63,87,91,1,64,159,205,10,64,234,4,20,64,95,41,31,64,238,235,44,64,45,33,59,64,129,38,194,61,170,96,84,62,5,197,175,62,228,20,253,62,37,117,34,63,70,182,67,63,170,130,97,63,217,206,135,63,148,135,157,63,52,162,172,63,129,149,187,63,73,46,207,63,105,111,224,63,44,101,241,63,67,28,3,64,123,20,14,64,68,139,24,64,233,183,35,64,127,106,48,64,20,208,60,64,99,127,217,61,11,70,101,62,209,145,188,62,15,11,5,63,86,159,43,63,170,130,81,63,208,213,118,63,244,108,142,63,128,183,160,63,143,228,178,63,27,47,197,63,254,212,216,63,51,51,235,63,0,145,254,63,20,208,8,64,111,18,19,64,233,38,29,64,222,147,39,64,205,59,50,64,40,126,60,64,198,220,181,61,223,79,77,62,51,196,145,62,82,73,221,62,102,136,19,63,161,248,65,63,113,27,109,63,25,4,142,63,159,205,162,63,210,111,183,63,88,202,202,63,183,98,223,63,76,55,241,63,201,118,2,64,80,141,11,64,115,104,21,64,102,102,30,64,239,201,39,64,29,90,48,64,230,174,57,64,68,105,47,62,139,253,133,62,166,10,198,62,139,253,21,63,157,17,53,63,250,126,90,63,36,151,135,63,39,194,150,63,146,203,167,63,208,179,185,63,227,165,203,63,194,134,223,63,145,15,242,63,153,42,4,64,37,6,13,64,213,120,21,64,42,169,31,64,76,55,41,64,123,131,47,64,54,60,57,64,149,212,9,62,65,130,130,62,87,91,209,62,40,126,12,63,247,228,49,63,235,226,86,63,209,34,123,63,240,167,142,63,192,91,160,63,97,195,179,63,22,106,197,63,43,246,215,63,62,232,233,63,40,126,252,63,173,250,8,64,68,250,17,64,81,107,26,64,15,156,35,64,169,19,44,64,145,237,56,64,192,236,158,61,139,253,37,62,174,182,130,62,70,148,214,62,245,74,25,63,17,199,74,63,203,16,119,63,174,71,145,63,6,129,165,63,174,71,185,63,216,240,204,63,135,22,225,63,6,18,244,63,77,21,4,64,235,115,13,64,105,0,23,64,73,157,32,64,79,30,42,64,103,213,51,64,29,201,61,64,124,242,176,61,52,17,54,62,243,31,146,62,254,212,216,62,114,138,14,63,254,212,56,63,235,115,101,63,146,203,135,63,170,96,156,63,37,6,177,63,207,102,197,63,149,212,217,63,235,115,237,63,131,81,1,64,68,105,11,64,152,76,21,64,95,41,31,64,14,190,40,64,11,181,50,64,179,12,61,64,140,74,234,61,38,228,131,62,189,82,214,62,215,52,15,63,0,0,48,63,37,117,82,63,116,181,117,63,77,21,140,63,43,24,157,63,194,134,175,63,19,242,193,63,161,214,212,63,199,75,231,63,133,235,249,63,14,45,6,64,88,57,16,64,222,113,26,64,215,163,36,64,102,102,46,64,92,143,58,64,173,250,220,61,47,110,99,62,104,179,170,62,98,16,248,62,140,185,27,63,220,104,64,63,93,220,102,63,107,154,135,63,53,94,154,63,176,3,175,63,174,182,194,63,98,16,216,63,249,15,233,63,57,214,253,63,33,31,8,64,27,158,18,64,65,241,27,64,163,146,38,64,56,248,46,64,21,29,57,64,58,146,203,61,193,168,100,62,145,15,186,62,70,182,3,63,11,36,40,63,82,39,80,63,99,127,121,63,188,150,144,63,243,31,162,63,79,175,180,63,12,147,201,63,173,250,220,63,11,181,238,63,136,99,1,64,127,251,10,64,64,19,21,64,41,92,31,64,223,79,41,64,3,9,50,64,179,234,59,64,66,96,229,61,189,227,84,62,82,39,160,62,24,38,211,62,25,115,7,63,86,125,46,63,108,9,89,63,133,235,129,63,125,174,150,63,159,60,172,63,147,169,194,63,240,22,216,63,45,67,236,63,204,127,0,64,173,105,10,64,154,119,20,64,140,74,30,64,163,1,40,64,247,228,49,64,199,186,60,64,196,177,174,61,59,223,79,62,81,218,187,62,121,88,8,63,241,244,42,63,105,0,79,63,152,221,115,63,27,158,142,63,30,167,160,63,239,56,181,63,25,226,200,63,206,136,218,63,179,234,235,63,22,251,251,63,19,97,7,64,215,52,15,64,36,151,23,64,75,200,35,64,23,217,46,64,254,67,58,64,16,88,185,61,100,204,93,62,97,50,181,62,70,37,5,63,31,133,43,63,88,168,85,63,59,1,125,63,76,166,146,63,60,189,162,63,76,55,177,63,156,51,194,63,61,155,213,63,157,128,230,63,74,12,250,63,136,133,6,64,202,84,17,64,201,118,26,64,205,59,38,64,16,233,47,64,171,207,57,64,39,160,9,60,190,48,25,61,75,89,134,60,218,172,122,188,250,237,235,60,14,79,47,60,96,229,208,188,20,63,198,188,0,0,0,0,88,57,180,187,221,181,4,188,143,194,245,187,224,45,16,187,195,100,170,187,101,25,226,187,137,210,222,186,82,73,157,57,43,24,21,60,52,128,55,59,124,242,48,187,150,67,11,60,4,231,140,59,18,131,192,188,121,88,40,189,120,122,165,60,225,11,19,61,117,2,26,61,74,123,3,61,218,172,250,60,5,163,18,189,101,25,226,188,188,116,19,188,23,183,81,59,82,73,157,59,255,33,253,60,185,252,7,61,30,167,232,60,129,38,194,60,231,29,167,59,120,122,37,188,164,223,190,188,14,79,47,189,178,157,111,189,228,131,30,189,36,151,127,59,221,181,4,60,237,13,62,59,137,210,222,186,82,73,29,186,137,210,222,187,224,45,144,59,43,24,149,60,117,2,26,61,228,131,30,61,112,206,8,189,100,93,220,188,43,24,149,188,101,25,226,187,195,100,42,187,66,96,101,59,46,144,160,187,159,171,173,188,231,29,39,189,57,180,200,188,7,95,152,60,44,212,154,60,218,172,122,60,166,155,68,60,73,157,128,60,88,57,180,59,153,187,150,187,5,163,146,60,30,167,232,60,23,183,81,187,171,207,213,188,158,239,167,188,36,151,127,187,114,138,142,60,216,240,244,60,12,147,169,60,82,73,157,58,52,128,183,187,111,18,131,58,176,3,103,60,56,248,66,188,227,165,155,60,37,6,1,61,208,68,88,59,23,183,81,188,143,194,245,60,75,89,6,61,72,80,252,60,188,150,16,61,62,232,217,60,208,68,216,59,75,89,6,189,64,164,223,188,124,242,176,59,104,145,109,60,41,92,143,60,166,155,196,58,77,21,140,188,95,41,203,59,75,89,134,188,188,116,147,59,30,167,232,187,10,215,35,59,211,188,227,60,103,213,231,60,91,177,63,60,195,100,42,187,213,120,233,188,231,29,39,189,226,233,21,189,202,84,193,187,195,100,170,188,151,255,16,189,112,206,8,189,25,115,215,188,23,183,209,187,250,237,235,59,82,73,29,186,18,131,192,188,179,123,114,187,145,126,251,188,69,216,240,188,148,135,133,188,229,97,161,188,18,131,192,188,82,73,157,60,195,100,170,58,161,103,179,188,240,133,73,188,23,183,209,185,221,181,4,188,82,73,29,188,240,133,73,188,120,122,37,188,39,160,9,59,254,101,119,60,159,171,45,60,254,101,119,60,215,52,239,60,208,68,88,59,103,213,231,60,95,41,75,60,237,13,190,59,137,210,222,186,108,9,121,187,108,9,121,60,176,3,103,60,208,68,88,60,78,209,145,60,73,157,128,60,215,52,239,59,224,45,144,60,176,3,103,60,192,236,30,60,153,187,22,188,148,135,133,188,127,106,188,188,172,139,91,188,156,51,34,188,69,216,112,188,111,18,131,59,226,233,149,188,41,92,143,188,111,18,3,188,185,252,7,188,104,145,237,188,159,205,42,189,83,5,35,189,100,93,220,188,83,5,163,188,140,74,106,188,159,171,173,187,156,51,34,188,124,242,176,187,83,5,163,188,161,103,179,188,150,67,139,188,14,79,47,60,192,236,158,60,66,96,101,59,197,254,50,61,48,76,38,61,197,32,176,60,166,155,68,60,159,171,173,59,52,128,55,187,56,248,194,60,3,9,10,61,51,196,177,60,224,45,144,58,90,245,185,60,130,226,199,60,111,240,5,61,44,212,26,61,197,254,50,61,78,209,17,61,208,68,88,187,163,35,57,60,11,181,38,61,112,206,8,61,205,204,76,188,82,73,157,185,176,3,103,188,64,164,223,188,247,117,96,188,0,111,1,188,104,145,109,188,30,167,232,187,17,199,58,60,116,70,148,60,143,194,117,60,150,67,11,60,72,80,252,187,108,9,121,187,161,103,179,188,25,115,215,188,190,48,153,188,164,223,190,188,62,232,89,60,135,22,217,60,36,151,127,188,43,24,21,188,88,57,52,188,23,183,209,186,140,74,106,60,151,255,144,60,166,155,196,60,75,89,6,60,140,74,106,188,206,136,210,188,52,128,183,186,23,183,81,57,75,89,6,60,188,116,147,60,184,30,5,61,150,67,11,61,218,172,122,188,155,85,31,189,166,155,196,188,75,89,6,60,66,96,101,60,153,187,150,59,101,25,98,188,44,212,26,189,226,233,21,189,106,77,243,60,59,112,206,60,36,151,255,59,59,112,206,59,82,73,29,58,224,45,144,59,179,123,242,59,117,2,26,60,163,35,57,60,49,8,44,60,247,117,96,60,161,103,51,61,98,161,214,60,36,151,255,187,80,141,151,188,197,32,176,188,11,181,38,189,14,45,50,189,195,100,170,188,23,183,209,185,250,237,107,188,158,239,167,188,95,41,203,188,184,64,130,188,101,25,226,187,218,172,122,188,208,68,88,60,115,104,17,61,33,31,244,60,166,155,68,60,250,237,235,59,202,84,193,60,25,115,87,61,202,50,68,61,164,223,190,60,62,232,89,188,103,213,231,188,91,177,63,189,211,222,96,189,80,141,23,189,23,183,81,59,52,128,183,59,153,187,22,59,10,215,163,59,82,73,29,59,138,142,228,60,237,13,62,60,188,116,147,187,82,73,157,186,14,79,47,60,227,165,155,60,242,65,207,60,154,119,156,60,4,231,140,59,9,27,158,60,114,138,14,189,240,133,201,188,240,133,73,60,49,8,172,60,27,47,93,60,82,73,29,188,234,149,50,188,108,9,249,187,36,151,127,188,104,145,237,188,111,18,131,60,192,236,158,60,161,103,179,60,61,44,212,60,205,204,204,60,119,190,159,60,109,86,253,62,210,0,254,62,145,237,252,62,236,192,249,62,208,68,248,62,188,5,242,62,3,9,234,62,222,2,233,62,11,36,232,62,248,194,228,62,247,228,225,62,192,236,222,62,191,14,220,62,245,185,218,62,48,76,230,62,11,181,230,62,213,120,233,62,67,28,235,62,15,156,243,62,173,250,252,62,219,138,125,62,180,89,53,62,58,35,74,62,73,157,64,62,104,179,42,62,127,251,58,62,42,169,83,62,114,249,79,62,197,143,49,62,228,20,29,62,96,229,16,62,143,83,52,62,184,64,66,62,235,115,53,62,249,15,41,62,183,98,255,61,97,50,213,61,218,27,252,61,217,61,57,62,248,194,100,62,214,195,220,235,250,248,112,255,153,237,164,237,3,11,123,254,148,0,216,245,170,6,142,248,190,253,239,1,24,0,61,3,129,254,219,206,147,45,241,251,115,5,110,10,224,254,23,0,116,2,8,255,0,254,79,0,186,254,204,234,242,244,84,246,27,251,109,252,10,47,94,253,146,255,134,11,45,15,89,233,215,3,104,2,116,253,196,255,140,254,22,0,115,255,89,255,98,0,125,0,156,255,75,106,133,0,129,255,241,254,240,254,80,255,244,4,173,0,90,254,127,9,98,240,19,245,24,9,182,0,126,25,246,12,118,231,172,214,126,15,56,33,15,2,35,37,59,24,222,3,35,252,142,23,120,255,135,2,180,251,188,254,198,245,61,246,244,1,124,255,182,252,213,4,15,14,237,8,90,11,14,42,20,44,22,245,242,0,184,0,114,248,55,0,185,252,99,251,150,1,87,3,134,3,250,40,185,254,231,249,110,22,172,1,170,8,243,5,109,20,170,35,8,253,108,0,116,255,213,86,108,4,155,1,208,2,158,1,156,254,23,253,4,251,125,252,206,253,113,1,5,0,166,225,5,16,42,14,126,0,243,255,252,238,216,2,131,243,138,7,66,250,232,228,102,254,64,26,105,7,238,253,85,239,123,247,148,252,40,254,20,246,6,216,168,15,233,39,255,245,27,248,204,2,158,250,187,254,171,1,11,255,58,1,208,255,138,255,106,255,169,137,144,254,0,1,113,1,112,253,178,255,10,255,116,255,30,251,133,253,52,5,220,202,113,215,161,250,97,1,113,9,92,8,163,254,180,5,205,255,203,254,11,2,253,1,48,9,184,4,135,254,25,248,236,37,141,1,192,4,114,41,192,238,144,21,62,15,185,247,32,254,92,254,146,4,36,0,24,243,14,6,246,254,146,6,216,252,116,9,140,10,111,63,70,15,60,2,137,254,85,0,209,217,136,255,166,8,219,10,246,44,68,10,96,254,52,249,231,250,202,4,78,0,78,0,123,2,166,1,188,201,22,5,235,239,62,251,121,10,12,223,69,249,242,8,255,10,148,4,75,255,93,253,37,254,5,253,90,9,201,241,223,30,109,253,19,9,229,18,154,229,244,36,56,250,157,246,33,245,216,5,38,3,54,254,10,255,12,0,2,255,121,0,197,5,135,253,255,253,23,3,208,0,122,254,79,255,244,250,9,176,207,238,138,245,66,35,128,0,247,254,54,3,4,1,194,43,60,12,169,248,205,240,92,7,182,252,149,255,92,29,184,4,240,249,29,252,179,4,102,8,36,43,5,5,234,8,80,0,68,5,222,20,41,8,156,3,192,5,82,250,189,223,30,255,237,215,225,246,118,246,224,0,185,12,8,250,29,26,94,6,177,7,48,0,194,18,163,23,219,3,214,33,192,246,136,236,74,248,47,240,56,235,139,19,43,1,112,254,215,2,208,0,69,255,22,11,61,238,210,37,66,247,41,4,122,243,107,39,51,19,129,11,157,249,58,255,50,4,70,253,52,253,160,255,110,5,172,245,238,3,198,239,91,41,108,4,96,11,25,227,98,223,17,3,156,0,222,254,114,255,138,254,143,247,42,4,78,5,250,248,234,11,237,255,196,1,230,40,60,213,94,16,40,252,215,247,40,253,223,5,177,16,44,3,86,19,90,241,76,3,49,251,210,249,43,246,81,9,215,214,175,22,243,237,76,1,155,254,60,207,140,6,160,0,10,42,55,251,162,250,14,0,147,250,172,244,45,254,20,251,203,1,163,252,102,0,179,6,199,16,100,227,24,227,195,40,31,1,74,7,253,2,194,6,102,13,24,253,254,255,19,249,160,255,209,7,117,8,118,0,80,36,224,237,252,237,222,27,8,20,225,224,148,1,79,254,79,254,174,8,142,224,231,7,206,10,252,254,120,246,71,6,138,9,83,30,26,254,182,14,51,9,91,29,230,0,224,4,87,221,224,223,81,220,134,250,236,248,199,4,152,0,244,246,29,253,107,254,240,252,170,253,113,2,247,1,81,255,195,253,51,132,246,1,34,254,214,253,90,252,131,1,176,255,28,254,67,253,222,255,205,255,18,254,75,250,237,3,104,11,12,45,107,10,118,249,192,252,232,33,121,233,18,3,234,249,242,247,241,3,120,254,51,8,147,227,229,245,158,24,254,11,144,17,79,249,54,240,83,224,106,6,154,248,122,13,72,3,48,14,160,0,66,2,149,0,255,2,242,2,208,0,154,252,96,253,252,0,226,255,43,255,30,254,50,0,190,253,254,255,108,255,246,0,82,131,200,253,130,0,216,1,249,2,229,255,205,255,198,1,144,0,124,0,212,22,94,223,90,37,85,241,250,254,214,12,96,4,215,3,140,253,34,253,60,249,112,250,97,1,109,254,5,62,16,203,177,254,81,1,7,2,140,0,41,1,150,0,213,2,244,252,108,3,140,255,165,255,128,255,19,1,195,9,97,36,0,253,27,215,124,4,124,8,239,230,220,12,117,247,172,251,239,11,81,4,113,2,26,3,68,0,81,1,104,5,150,255,252,253,62,2,100,3,81,3,27,252,81,0,196,100,28,0,206,0,28,242,161,254,34,4,102,4,110,225,190,20,250,239,232,20,77,229,64,240,207,5,230,0,241,21,169,3,244,40,185,255,93,10,179,4,255,255,155,2,47,250,104,216,102,30,5,253,24,3,154,5,86,255,111,1,96,0,24,170,4,255,244,2,145,0,60,250,128,5,243,5,205,252,192,253,36,254,212,251,15,255,217,255,11,6,81,37,146,253,249,248,69,7,227,23,160,252,194,41,182,253,214,1,200,0,138,4,74,2,44,0,126,210,125,13,30,34,62,245,78,255,236,0,166,245,94,10,139,10,156,4,205,20,54,254,216,255,38,255,250,255,126,0,138,26,250,1,92,3,87,46,140,2,129,6,139,239,255,18,144,5,80,22,105,253,80,253,246,255,115,250,92,253,211,250,134,254,201,254,22,254,45,76,218,4,12,1,229,17,51,6,127,251,80,3,158,250,121,251,249,1,63,0,192,2,150,7,156,8,198,247,44,0,223,1,182,251,77,1,165,171,151,253,212,230,219,13,2,5,8,249,56,18,206,250,47,10,217,4,5,242,247,0,149,252,95,44,59,244,120,255,243,205,192,199,65,7,26,252,62,5,163,4,174,254,239,4,63,2,202,4,29,252,84,2,190,1,37,1,255,2,156,254,70,0,18,3,210,1,202,0,149,0,81,3,193,142,140,2,124,0,47,255,132,255,106,254,169,234,123,250,236,250,37,235,31,249,162,18,120,10,210,214,158,13,225,21,116,11,45,6,233,1,9,2,57,191,1,0,7,250,54,23,210,4,106,18,145,249,126,4,242,10,130,2,74,2,252,14,240,0,51,1,22,254,67,0,3,3,48,3,118,252,18,6,66,4,207,246,139,253,27,44,125,11,90,244,1,37,154,5,1,239,175,224,203,235,135,31,139,7,1,5,41,240,104,243,130,248,241,254,52,255,158,2,163,13,107,0,120,132,227,0,75,0,165,255,108,0,171,0,203,255,55,255,117,1,63,0,118,0,126,0,152,255,127,0,168,255,18,7,168,45,0,216,38,2,108,14,142,236,173,249,40,0,143,3,200,251,68,2,1,253,77,1,192,0,147,1,52,1,120,252,142,0,193,121,247,1,179,251,110,255,112,255,35,0,181,0,157,254,54,0,78,2,243,1,95,0,25,249,188,1,207,255,112,8,8,28,0,47,78,25,27,253,56,234,124,253,155,255,29,251,12,251,61,9,45,39,25,2,60,250,51,1,60,8,82,246,80,252,229,41,93,1,110,239,121,255,153,29,116,238,212,5,48,246,56,30,2,236,156,229,124,246,158,248,170,246,84,6,146,3,122,6,47,0,84,210,122,255,52,249,60,255,49,37,120,255,160,250,22,222,144,251,72,4,135,3,132,251,178,254,28,255,252,255,93,253,57,255,122,7,11,11,166,212,175,247,1,246,46,252,175,0,40,7,91,39,202,246,160,248,6,211,214,244,104,48,207,254,50,255,161,3,217,1,208,243,50,245,212,251,43,251,164,1,50,253,235,255,176,254,211,255,34,254,19,250,38,7,156,206,3,1,202,46,1,1,214,5,33,249,247,0,35,253,112,0,62,247,34,1,234,0,236,215,245,6,242,248,248,239,211,6,38,0,76,253,107,19,103,220,123,248,212,249,153,253,120,218,195,14,106,212,213,1,128,237,43,1,1,245,60,8,118,7,204,246,66,0,11,2,72,254,250,8,133,239,48,246,170,251,184,43,44,23,187,245,207,224,32,252,7,3,146,251,215,12,132,3,87,253,217,255,74,251,84,249,112,229,151,254,16,43,48,33,58,255,241,240,206,5,13,246,237,6,50,0,236,254,226,254,17,3,52,225,182,1,238,17,234,10,213,20,100,21,60,8,148,2,26,14,4,9,166,222,224,0,124,255,134,0,219,2,220,3,168,250,54,15,222,16,183,38,152,255,64,1,222,218,185,6,198,233,176,6,213,221,172,248,254,235,232,250,94,255,240,2,62,14,85,6,81,43,93,4,77,248,34,4,254,11,180,0,72,90,175,0,227,1,252,251,230,253,241,1,29,4,61,0,20,3,57,254,22,0,201,255,224,255,186,254,84,62,3,248,20,3,56,38,110,251,205,252,163,241,135,2,28,254,66,2,96,255,30,1,91,254,33,1,204,31,254,14,190,253,182,248,230,247,155,2,81,209,148,6,111,13,0,5,158,0,8,249,252,4,126,2,50,2,253,7,36,255,84,3,174,253,195,247,151,245,188,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+501760);
/* memory initializer */ allocate([38,0,91,0,97,5,144,253,102,183,14,254,142,252,36,0,24,2,157,255,62,0,101,235,235,11,231,0,57,231,41,249,182,4,146,249,189,250,234,202,151,5,241,254,70,254,174,85,113,255,224,248,134,254,49,254,48,3,123,1,80,1,221,254,116,253,19,1,10,253,1,1,238,197,232,250,92,28,211,242,225,4,56,248,174,10,251,245,8,244,96,254,120,9,23,1,22,41,206,0,87,253,254,199,154,2,51,7,120,253,14,2,190,7,110,1,172,2,251,3,192,0,8,0,30,254,79,237,86,8,70,249,178,41,179,249,33,0,124,4,226,249,242,39,69,13,155,2,180,251,30,253,116,9,54,200,195,1,90,0,150,215,113,10,151,4,201,241,10,1,202,253,0,0,136,6,58,4,42,1,103,1,15,254,248,6,198,253,22,246,218,9,15,241,121,24,99,0,9,225,88,12,71,43,131,0,224,247,92,0,1,139,12,1,219,254,240,0,254,0,74,255,111,255,47,1,12,0,86,0,84,2,246,0,136,0,252,3,15,250,146,251,115,216,197,233,140,23,137,241,57,239,122,241,169,233,204,253,148,2,191,254,207,251,83,0,4,244,23,24,244,49,6,253,121,31,65,251,75,9,94,8,215,241,9,254,118,250,208,254,119,253,11,254,242,206,243,49,153,14,185,5,148,241,215,250,82,4,144,251,117,253,206,255,72,6,59,0,185,253,82,0,75,1,187,1,14,3,93,0,29,1,54,1,221,113,70,253,204,255,115,252,18,255,34,255,142,255,4,0,138,2,56,255,235,0,237,9,86,2,122,1,248,42,29,12,220,223,154,6,39,239,84,27,245,255,196,245,78,250,108,250,67,2,208,254,20,0,140,254,129,3,90,2,176,1,118,255,178,2,81,2,51,250,136,0,191,0,109,130,4,1,199,0,156,1,88,255,215,255,128,254,150,254,242,255,242,0,110,1,194,254,208,254,8,6,202,1,146,225,4,13,3,236,111,248,100,3,78,49,138,3,149,7,155,18,162,6,95,1,22,255,51,252,206,35,70,26,126,10,248,0,13,14,172,217,112,254,59,16,36,11,97,254,170,8,108,3,143,5,12,15,149,11,102,254,28,7,76,32,240,250,174,2,114,0,15,12,191,11,70,219,137,233,125,242,238,229,162,1,41,16,170,18,56,0,137,250,94,249,226,245,151,32,174,247,231,9,4,24,122,255,167,246,31,45,174,254,223,2,118,2,110,253,46,52,181,3,144,251,39,255,39,252,182,0,10,252,179,5,221,0,33,30,150,250,109,250,46,5,43,2,66,0,134,10,1,250,244,254,228,202,146,2,49,1,90,3,36,2,52,206,186,253,225,251,109,253,133,208,172,3,140,247,42,246,130,255,124,255,182,252,129,2,29,254,66,254,192,235,70,255,1,254,145,4,52,232,17,24,10,12,104,253,11,248,79,3,24,43,230,250,119,249,61,251,220,255,70,7,69,39,12,3,230,254,187,252,249,254,253,1,180,253,154,206,255,252,140,247,85,247,12,2,151,242,219,230,50,15,145,253,171,226,241,0,202,15,8,1,142,250,62,14,243,228,192,235,194,4,60,250,64,247,90,7,182,0,134,242,15,254,108,255,160,0,213,249,167,179,176,255,118,3,145,3,196,2,216,2,137,1,165,253,246,252,86,13,246,252,41,250,181,4,38,9,232,0,206,241,180,255,104,190,84,253,42,5,192,0,64,204,110,253,226,29,123,18,87,255,28,20,123,250,210,11,176,9,114,247,236,3,222,247,237,0,171,0,51,253,2,253,243,253,230,209,64,241,70,217,94,5,78,243,159,1,29,245,81,255,199,251,24,3,212,3,200,44,66,3,202,2,31,252,150,0,77,0,2,9,241,43,14,244,166,242,34,249,17,255,137,255,128,250,195,23,76,239,35,7,124,6,239,8,75,244,192,253,144,1,14,8,154,243,185,231,42,39,198,251,41,0,249,0,42,39,201,231,211,254,24,1,136,39,201,8,15,2,204,253,234,3,110,2,13,13,152,1,54,11,102,50,251,51,177,2,80,1,205,252,213,255,64,3,38,251,145,2,150,255,42,0,99,4,149,0,232,247,78,0,209,254,73,1,241,84,132,247,76,251,192,1,157,5,208,253,136,254,55,1,183,255,153,0,239,252,144,254,54,0,67,254,164,255,120,0,197,255,135,254,146,1,55,2,36,155,4,5,8,5,200,0,159,252,250,250,215,255,186,248,146,1,179,0,222,246,220,240,128,19,224,248,148,216,177,242,188,222,28,242,130,0,193,233,214,22,29,9,179,11,62,8,222,228,185,19,183,246,119,6,165,252,127,237,112,6,119,27,80,227,128,19,224,6,57,253,62,12,27,56,117,252,171,0,77,248,10,244,201,251,88,2,91,2,32,255,72,254,192,211,221,254,105,253,86,7,53,253,92,245,28,1,56,254,38,213,103,243,64,247,252,0,47,252,152,254,217,2,196,253,141,15,79,6,204,255,4,235,207,23,96,217,217,26,10,241,52,19,42,7,211,249,252,211,244,246,114,254,81,5,7,24,176,10,80,248,16,18,76,255,252,254,59,251,255,233,236,250,199,251,103,250,3,254,110,1,124,254,124,6,84,1,203,181,182,2,96,251,211,252,44,5,237,4,223,2,70,255,138,20,185,253,35,255,171,6,149,0,254,3,189,252,65,4,123,11,233,7,165,1,155,1,25,14,27,202,208,1,254,35,158,9,143,231,144,23,119,7,2,5,55,218,206,3,65,253,128,255,182,3,113,1,136,4,94,253,200,254,222,201,54,4,74,226,8,0,226,10,111,1,215,230,200,252,61,255,202,2,228,1,108,0,219,1,33,1,12,252,201,249,128,213,188,254,121,253,105,247,138,40,149,22,227,3,96,254,103,3,40,251,132,254,70,0,155,248,208,29,191,6,116,252,96,253,107,213,62,252,102,227,26,3,212,6,64,234,191,4,213,22,153,218,147,246,145,247,5,12,79,5,96,254,133,24,171,255,72,5,86,242,242,23,101,4,20,255,158,7,33,33,204,2,208,253,225,250,28,255,250,0,72,254,56,235,107,248,18,218,29,18,140,5,154,255,226,223,104,2,50,247,240,253,196,0,221,250,19,253,159,255,227,254,248,193,81,4,118,2,112,1,215,252,29,0,104,249,246,246,233,2,165,249,128,77,180,246,12,16,134,6,203,10,19,1,18,2,236,1,179,253,25,176,151,2,188,243,236,9,194,247,106,254,54,4,176,7,27,253,102,246,234,1,16,254,82,1,69,2,55,4,152,253,154,0,113,39,231,0,28,255,221,1,20,0,92,5,228,44,168,251,180,243,35,2,248,0,92,253,5,32,14,23,237,250,7,2,8,245,9,45,180,255,215,4,248,251,226,253,97,1,209,251,22,1,18,1,221,10,195,225,188,12,151,10,175,0,52,48,86,4,212,246,73,235,160,5,69,2,186,255,6,1,82,217,185,246,18,2,153,5,88,6,61,250,77,252,138,52,38,5,96,249,207,0,198,0,138,4,80,252,143,219,234,251,195,0,150,255,170,2,32,57,170,252,150,246,30,4,242,0,164,254,69,2,207,1,204,2,248,2,154,10,76,5,177,250,33,51,5,10,229,214,142,7,125,2,194,4,136,4,62,3,137,3,16,1,152,1,187,253,110,250,101,2,26,10,6,224,164,14,249,229,20,17,142,255,220,237,182,11,32,219,173,2,219,221,35,13,9,234,123,239,110,228,79,251,202,252,14,7,223,33,168,252,156,253,141,4,86,254,61,1,211,26,176,255,84,228,119,4,186,248,182,10,157,2,38,2,22,0,173,0,205,16,90,215,18,4,166,254,202,250,175,244,135,2,232,2,14,0,198,250,144,249,45,251,222,13,57,254,77,8,164,4,240,66,164,4,130,229,175,252,42,1,226,251,218,219,153,1,56,249,130,5,170,227,159,248,201,1,28,253,22,0,6,1,242,125,121,6,252,246,128,10,161,253,97,2,4,0,150,0,248,254,192,0,116,255,246,0,119,254,180,255,54,197,134,1,201,3,201,1,156,5,119,253,204,1,138,208,79,5,246,3,201,247,192,253,55,0,178,253,113,0,126,250,121,164,182,0,174,246,224,249,136,3,38,255,231,254,68,255,78,255,63,0,211,0,37,2,175,2,219,208,168,255,114,253,210,251,157,204,132,255,71,253,182,1,102,12,164,6,14,1,234,0,223,254,143,253,133,61,220,246,18,33,141,1,148,238,250,251,134,12,57,4,219,250,250,251,184,255,231,1,59,250,178,221,72,27,59,251,91,9,126,12,179,11,230,22,85,251,69,232,4,252,90,252,100,3,42,254,0,252,178,4,26,252,230,250,102,86,88,1,28,2,191,243,221,253,136,9,228,255,222,0,116,1,88,254,57,255,44,4,107,252,151,255,74,239,52,0,213,254,21,27,195,45,248,253,219,244,58,0,129,222,160,1,8,251,104,4,224,255,140,251,175,248,17,254,235,0,31,8,198,254,208,250,201,245,30,177,80,3,239,249,131,1,53,232,138,3,60,216,186,33,6,254,238,15,62,1,159,245,76,6,130,255,112,250,252,255,47,249,169,254,46,1,135,9,158,47,173,3,10,207,108,237,80,255,166,255,241,250,17,4,83,7,62,254,89,0,212,0,50,8,172,6,84,7,225,15,146,6,180,7,204,236,73,252,69,214,163,5,30,213,4,3,11,252,21,255,59,0,213,0,26,255,142,0,192,253,250,1,101,0,44,0,119,255,126,102,209,255,190,254,223,254,25,1,54,10,70,238,122,2,92,4,167,4,169,11,9,253,105,234,38,2,59,8,126,232,251,212,87,254,35,255,133,3,217,0,34,2,213,0,234,7,183,2,50,4,172,247,83,255,128,249,241,252,233,97,186,254,86,0,136,253,118,5,100,18,161,244,72,9,135,0,65,250,120,252,222,246,219,3,144,12,44,238,58,1,76,61,42,255,214,4,230,0,75,255,183,136,218,254,155,0,161,253,218,0,203,254,76,255,10,255,154,255,36,252,124,253,111,0,235,214,188,249,100,251,68,245,167,4,97,205,254,255,20,252,28,0,60,255,182,7,234,252,41,3,98,34,76,251,76,1,180,0,239,240,1,4,146,232,150,218,94,0,211,251,162,246,185,0,131,2,57,250,66,1,240,9,40,49,140,223,240,240,6,5,64,6,21,246,64,245,40,246,145,254,82,252,161,1,203,254,142,247,252,7,134,42,228,6,20,43,226,14,139,11,252,251,7,252,40,249,25,254,163,253,48,0,8,9,144,254,34,249,4,255,115,1,170,77,54,248,139,6,118,21,108,253,123,249,0,1,202,255,83,252,222,16,206,254,95,8,17,1,217,242,240,243,109,25,164,248,232,234,192,253,130,44,107,3,199,1,15,1,38,255,121,5,212,255,40,235,118,208,56,18,179,253,22,242,114,248,210,22,77,5,160,12,169,5,110,254,36,212,160,255,27,250,25,8,41,249,8,3,73,254,7,3,26,243,209,52,187,254,138,255,84,255,155,1,116,254,10,24,105,246,204,255,248,237,15,3,56,207,219,247,185,22,2,251,123,2,79,249,72,11,194,252,137,2,58,29,150,39,187,35,200,14,22,4,114,248,236,245,102,0,89,253,132,255,68,0,145,2,161,1,81,255,0,128,176,255,119,1,83,252,224,0,15,1,24,255,239,5,157,255,88,253,67,0,66,0,150,253,252,0,115,7,1,20,152,9,187,247,84,219,95,250,124,2,188,30,108,223,147,7,60,5,231,5,199,2,130,25,44,249,73,255,90,0,1,10,228,22,148,254,253,19,251,239,68,240,80,252,30,41,252,251,23,4,195,2,84,47,204,206,90,240,154,3,233,251,92,1,53,252,240,254,172,246,179,1,246,0,225,251,148,0,196,248,126,207,29,246,196,13,7,16,168,254,131,6,2,11,32,238,239,254,111,223,183,0,241,1,112,255,139,217,220,254,9,254,68,251,220,16,102,250,206,212,29,244,71,233,43,252,45,3,0,0,50,253,45,254,45,40,195,181,174,255,8,3,168,4,6,4,24,6,56,4,112,255,217,2,94,2,31,255,123,254,69,255,40,2,94,252,68,254,185,232,88,248,221,250,90,10,254,250,154,182,236,6,7,1,130,5,44,3,54,254,36,254,232,2,35,10,86,254,237,255,159,35,177,17,34,250,65,18,91,14,6,29,60,4,202,228,250,253,16,203,30,4,170,9,229,218,17,4,250,19,186,1,111,11,255,1,44,250,217,0,42,253,142,1,246,253,35,0,119,0,180,254,106,0,48,3,181,1,57,251,220,107,9,2,227,255,50,254,111,1,58,252,220,1,1,246,99,242,96,255,207,5,240,254,182,253,130,232,24,255,95,14,184,248,220,4,63,2,1,199,29,254,108,250,20,0,194,30,124,244,179,232,79,9,198,12,234,1,190,10,221,253,70,218,63,250,175,3,29,1,172,246,252,252,210,249,109,12,91,13,68,10,59,255,48,13,30,204,252,225,55,13,70,0,106,251,186,255,209,229,119,227,215,253,4,14,198,252,244,255,182,28,236,241,89,1,74,4,16,15,150,3,246,7,217,255,250,44,182,61,47,5,134,4,180,1,106,252,71,0,185,3,207,3,123,4,174,0,155,1,187,5,83,0,72,238,25,250,230,20,14,243,175,54,18,0,11,16,109,7,66,3,54,10,52,9,143,254,175,3,171,254,52,254,28,17,226,216,236,12,43,242,103,243,147,253,1,33,153,250,129,17,137,250,194,241,88,252,155,3,221,0,90,1,148,30,102,9,205,11,127,236,196,11,105,213,123,248,217,31,126,1,83,250,214,4,89,2,171,4,59,247,24,245,234,239,217,1,34,19,161,50,50,232,17,23,88,5,62,245,209,254,0,3,225,255,5,251,120,5,84,2,210,250,107,2,48,249,121,4,119,240,127,2,223,213,99,249,72,212,227,253,78,254,136,211,7,252,25,56,118,5,9,2,89,243,59,7,21,254,237,0,0,252,234,3,70,244,209,254,223,255,124,230,89,2,114,241,152,30,202,23,133,216,189,3,131,251,177,2,47,5,205,255,153,7,222,3,150,255,83,2,234,0,6,2,36,4,77,0,69,3,208,112,165,255,117,254,237,254,247,254,233,254,39,255,212,254,240,0,225,251,106,254,218,16,165,247,205,24,77,247,148,232,195,3,110,215,21,18,208,253,56,4,134,0,89,123,214,250,253,5,80,247,253,0,51,250,164,255,38,1,183,0,188,253,164,1,172,0,230,252,50,255,170,254,174,254,53,0,171,255,104,252,77,115,49,4,52,252,209,248,236,3,34,1,46,0,204,1,185,255,36,252,195,6,150,254,234,247,8,15,254,255,254,240,222,2,59,251,180,224,80,4,126,26,201,37,58,4,143,222,164,252,169,247,235,249,179,249,81,201,128,6,220,8,222,249,36,253,242,3,110,254,141,251,84,254,144,1,99,4,196,247,0,210,167,254,112,41,221,4,186,243,84,243,148,251,164,6,204,254,37,6,31,2,166,2,40,20,10,244,177,1,143,10,172,252,217,236,168,248,170,6,171,54,161,9,20,237,120,252,108,255,94,1,96,212,126,5,56,1,132,209,141,1,1,3,182,21,182,250,187,0,226,255,231,0,4,252,202,0,116,3,58,255,177,243,194,252,214,222,98,253,49,245,237,5,99,205,235,240,22,245,194,248,76,255,135,0,228,27,7,16,181,238,194,1,238,1,247,251,170,251,215,244,48,43,57,253,224,252,44,14,76,255,172,252,196,215,184,247,62,254,128,56,1,254,47,1,72,250,226,253,167,255,52,255,244,1,112,254,194,254,57,2,216,0,172,1,94,1,181,7,119,255,139,252,254,248,50,252,137,15,54,13,64,183,92,254,101,248,165,0,63,254,115,5,95,188,226,254,6,8,65,254,76,245,167,248,218,253,138,247,80,5,123,232,162,255,148,0,164,2,173,249,55,249,55,209,87,255,128,249,227,225,58,24,190,232,145,6,203,2,249,254,56,0,113,1,77,2,52,2,197,7,81,6,144,249,245,35,63,5,12,211,45,227,49,241,192,243,25,4,180,252,24,0,198,229,56,249,154,233,165,244,152,19,119,8,166,233,70,251,88,24,172,1,163,9,250,242,59,250,57,253,72,26,222,215,190,236,176,231,163,254,58,253,62,6,55,253,84,249,15,254,2,255,55,2,140,252,131,0,0,45,116,252,111,250,186,248,119,203,202,249,99,253,145,2,249,1,236,0,252,255,21,0,78,3,100,0,56,32,201,248,125,255,70,255,181,0,218,252,221,12,208,251,72,251,156,56,19,6,247,5,32,2,136,255,254,254,6,0,159,246,167,48,128,42,67,4,210,246,85,252,28,251,204,253,150,0,142,255,139,5,225,2,60,249,72,254,1,247,30,255,24,2,68,246,195,251,123,216,251,212,202,14,155,20,246,255,175,9,143,0,145,249,247,224,116,3,174,249,8,8,90,50,88,254,98,23,65,250,102,253,198,253,70,250,13,254,64,0,54,2,54,249,129,253,116,44,156,253,87,7,14,6,181,48,213,254,35,250,74,10,12,4,204,11,243,255,126,58,238,247,102,233,149,245,111,21,144,229,212,1,127,254,10,3,219,252,232,253,208,254,206,2,130,1,29,1,122,29,131,2,182,5,145,3,99,18,173,3,246,242,62,255,13,26,115,238,165,34,187,252,144,1,147,252,151,212,70,1,242,246,115,53,232,250,82,248,91,252,56,1,128,0,214,1,216,254,190,254,84,1,154,251,19,7,207,7,69,11,129,12,75,1,66,246,159,15,148,2,176,255,241,247,125,190,199,250,170,1,20,19,118,232,216,255,45,8,86,1,80,255,83,0,134,0,28,3,87,254,26,221,52,8,102,33,160,0,35,255,4,255,54,128,26,5,52,5,159,253,147,255,35,2,80,3,6,2,216,255,47,1,10,255,61,254,127,247,52,253,18,253,1,0,16,173,7,5,233,250,3,8,123,6,221,5,143,254,121,250,18,1,52,1,4,1,115,1,127,250,106,253,77,227,249,27,72,14,176,251,158,34,217,233,90,5,98,4,16,0,108,4,185,68,122,26,31,252,101,2,103,253,188,11,216,12,167,249,225,248,21,252,228,2,22,252,136,252,91,253,215,251,50,157,229,3,96,255,76,255,213,252,188,0,179,254,77,246,72,253,29,5,120,0,200,1,140,255,28,248,128,252,48,28,184,24,46,220,215,32,86,244,108,249,168,2,216,6,84,253,101,2,81,1,139,253,26,210,19,254,188,254,117,252,121,254,29,4,45,55,142,0,164,1,131,248,134,254,108,250,166,255,15,254,92,4,48,254,122,8,37,3,220,249,120,252,196,220,234,253,50,25,22,254,254,41,23,1,253,2,193,3,111,240,114,245,119,9,139,236,58,251,118,6,191,251,147,247,148,7,251,55,129,252,190,6,19,6,122,0,32,242,250,4,170,253,114,252,240,11,88,249,30,25,126,214,246,3,187,221,241,3,144,7,152,254,44,254,251,251,119,221,143,253,164,8,186,8,160,10,166,4,192,255,226,247,80,18,242,33,30,20,62,254,232,2,228,252,227,233,180,254,254,224,110,10,42,240,97,5,198,249,34,45,162,237,209,241,233,2,230,2,166,255,225,250,240,48,200,237,66,3,171,252,6,6,112,33,161,8,251,15,60,11,69,8,90,253,148,6,17,3,48,1,44,31,78,8,210,254,47,32,199,247,48,6,118,46,225,251,145,250,84,2,39,9,86,0,132,1,188,250,17,252,148,5,157,1,241,219,184,215,78,227,172,251,105,5,25,251,142,240,226,2,22,251,154,1,226,0,11,59,221,251,235,239,206,255,8,254,66,249,145,5,10,217,166,254,176,2,208,1,244,0,182,253,80,221,77,3,109,253,164,3,227,250,34,1,227,255,95,254,120,247,243,3,106,218,163,5,49,35,153,7,138,10,60,253,76,41,106,9,176,4,140,17,247,245,164,5,175,10,100,222,226,8,39,240,222,1,57,255,5,5,151,49,33,48,139,244,84,249,174,4,163,2,20,254,208,253,204,255,19,251,85,0,32,254,160,255,184,2,4,253,134,250,120,133,188,253,93,253,114,249,198,255,88,2,246,253,220,254,135,2,220,255,154,0,132,251,181,1,25,6,76,2,91,2,205,29,179,189,29,0,196,252,179,253,105,252,164,250,42,254,67,254,172,1,16,2,196,22,159,254,224,255,11,249,66,253,78,253,228,227,75,243,150,7,248,17,186,208,94,253,16,215,224,246,199,2,130,247,206,226,100,250,61,254,35,228,88,3,164,245,100,7,136,13,222,253,164,2,16,204,252,253,206,202,27,252,170,3,150,6,238,3,78,5,165,250,154,3,22,2,86,255,126,0,255,0,189,252,50,0,177,3,214,251,116,249,3,0,14,4,75,254,174,101,162,1,27,0,188,251,19,254,84,254,162,253,183,251,140,253,42,1,39,1,218,252,183,0,146,0,72,5,172,255,46,253,65,3,189,155,104,12,233,3,190,254,221,246,15,0,37,254,23,251,68,8,108,3,125,2,239,253,172,251,46,1,108,246,22,77,58,0,83,3,117,38,118,4,120,8,194,2,62,43,20,6,32,2,186,11,190,8,122,240,178,10,208,255,124,223,118,247,157,254,171,197,144,8,79,246,140,10,217,1,26,254,249,2,48,255,76,0,178,255,102,0,224,236,98,5,89,48,179,223,28,0,68,4,49,236,36,250,90,251,220,252,61,4,2,253,237,1,22,0,239,251,176,35,46,251,41,208,199,3,112,10,141,252,230,17,7,19,99,7,236,253,73,1,226,0,190,1,202,229,56,1,110,252,136,5,196,248,236,11,112,25,11,35,168,21,119,25,189,253,253,3,15,255,143,3,14,3,128,242,174,39,183,248,101,15,244,207,8,0,216,1,114,3,212,249,249,248,255,251,137,253,129,255,44,196,111,31,56,255,188,248,70,2,245,238,6,251,61,4,208,255,79,9,126,2,224,1,113,1,186,252,195,250,158,1,142,255,197,10,198,4,110,247,190,242,69,25,114,9,226,2,136,249,234,60,190,251,202,0,215,2,255,252,228,1,158,9,11,19,120,6,5,241,19,190,156,20,239,0,214,3,176,248,126,255,133,3,72,5,101,255,75,19,131,223,40,35,199,9,229,1,160,4,220,253,180,250,198,226,68,255,205,249,240,1,32,214,13,39,223,250,145,34,32,20,30,255,164,244,47,1,182,252,154,252,165,0,164,250,151,255,102,255,170,0,120,9,84,246,178,247,119,223,93,1,99,238,8,20,164,255,126,35,161,227,160,1,132,255,85,1,168,255,239,0,52,20,41,2,246,5,192,6,163,7,47,250,61,230,27,212,16,216,118,254,97,252,92,252,162,2,231,2,61,1,20,18,5,33,72,241,241,9,178,13,154,246,148,35,11,22,52,18,20,16,108,246,145,250,102,255,182,255,180,0,150,20,14,225,46,0,38,43,188,23,223,2,242,30,60,255,200,251,165,5,81,253,157,246,240,252,230,2,243,254,14,254,122,23,51,240,29,4,123,3,254,249,101,2,172,255,98,239,67,252,74,18,76,201,2,8,121,253,50,253,45,2,96,245,133,9,5,226,98,46,188,219,34,253,7,3,73,247,105,0,110,1,80,5,158,255,130,255,252,1,87,10,217,2,250,2,154,221,83,215,48,35,211,247,83,4,201,0,141,5,157,4,253,254,140,5,60,3,71,1,92,248,195,253,150,252,98,1,102,10,99,250,112,42,232,219,32,226,134,6,62,6,173,0,182,1,139,254,202,253,246,0,33,209,25,7,157,253,1,0,140,249,84,7,74,5,246,4,235,252,44,1,191,254,57,45,252,253,73,1,91,22,124,18,181,6,176,231,20,235,108,231,142,254,196,241,102,252,206,255,242,255,187,253,238,249,117,249,236,255,59,252,63,111,146,2,14,254,24,254,248,1,167,253,181,1,183,253,11,255,60,255,186,0,25,1,82,255,159,0,45,29,2,23,8,236,54,19,193,220,152,254,40,0,97,244,176,18,75,254,73,6,8,4,199,10,215,254,106,0,56,20,37,239,56,2,192,218,239,250,129,229,43,213,5,5,8,1,74,1,4,254,246,253,112,2,150,2,27,2,80,28,44,202,40,0,92,8,116,247,133,7,244,220,123,4,196,250,102,3,11,3,252,255,155,255,138,254,13,3,101,22,176,233,111,233,32,8,107,3,138,52,241,249,99,243,230,248,142,255,241,4,245,1,124,2,192,253,145,253,11,251,190,11,255,3,94,3,79,5,158,7,76,2,136,167,218,0,74,254,11,6,104,254,180,252,249,254,150,255,162,57,79,253,6,219,46,252,235,255,132,5,43,0,220,7,96,1,140,3,21,1,64,252,21,253,26,255,235,249,36,228,181,233,79,0,86,246,129,8,27,235,206,9,80,206,17,11,152,247,99,249,202,1,197,0,125,253,223,2,88,245,131,252,198,10,76,20,18,242,58,239,206,236,58,251,188,0,76,221,166,231,87,9,18,250,151,2,60,2,71,250,123,4,38,33,245,7,212,9,173,3,204,23,82,45,1,246,90,249,200,248,100,252,46,255,148,255,228,251,168,32,113,226,20,238,87,255,136,13,10,220,50,7,23,239,61,246,171,254,80,2,150,3,154,255,84,1,214,0,13,4,188,254,95,192,68,40,209,255,227,255,60,5,165,253,53,245,220,253,136,1,209,5,107,255,255,252,189,255,214,51,71,247,65,32,46,6,10,4,82,239,148,3,134,17,167,4,154,255,159,0,109,0,232,253,104,253,37,252,151,224,33,249,168,16,32,234,9,202,122,251,176,6,212,9,134,253,248,1,3,2,220,2,210,255,83,253,31,254,149,6,10,249,6,1,240,241,129,57,190,24,5,31,101,0,146,3,163,247,254,255,182,0,61,3,41,255,134,255,181,24,88,241,4,245,82,6,184,13,201,249,76,239,82,27,147,215,213,233,35,250,26,249,99,248,180,1,82,0,36,234,32,10,194,251,12,245,236,9,202,1,218,253,214,248,159,246,117,226,36,9,142,6,14,226,186,17,27,0,193,24,58,14,172,66,190,20,91,4,43,6,114,255,115,254,98,253,218,7,95,3,8,254,77,3,80,3,2,3,139,221,171,7,222,10,162,0,106,4,37,10,125,202,100,240,32,3,195,9,235,251,24,250,70,255,197,255,137,255,72,236,144,26,194,221,16,3,77,228,22,252,79,1,201,7,235,251,89,2,12,7,166,0,63,5,110,0,32,255,199,8,168,254,251,255,60,239,214,22,143,33,186,209,233,250,253,251,223,6,88,255,62,255,255,250,233,1,122,1,51,236,7,243,230,43,137,254,218,252,122,15,188,37,112,244,104,253,213,251,141,253,15,1,181,4,136,4,5,1,141,14,197,30,89,253,22,0,86,2,194,251,92,254,120,8,210,255,64,195,164,1,196,4,52,5,198,255,100,255,97,30,207,237,96,1,212,59,104,237,164,247,239,245,215,250,245,7,141,254,26,251,112,252,103,251,169,250,153,255,220,17,246,218,193,249,38,1,147,1,240,254,229,246,243,238,155,52,233,17,6,246,49,249,33,2,162,0,143,254,186,23,9,44,104,221,17,224,239,9,249,255,58,1,15,248,144,10,37,249,105,250,233,252,236,254,61,4,236,0,153,25,80,7,131,1,32,4,225,255,126,175,159,253,96,2,239,3,68,6,35,250,188,255,241,253,204,0,252,0,229,9,47,253,188,5,188,1,184,255,61,0,47,255,0,2,40,255,42,0,129,1,22,254,152,255,154,142,90,255,237,236,62,245,20,3,82,254,157,252,53,2,125,251,50,2,52,4,221,6,82,244,133,197,200,32,134,3,38,2,102,0,77,230,229,228,193,254,172,0,161,252,211,3,130,8,118,2,160,0,184,3,178,3,141,240,235,5,96,1,253,9,37,235,22,24,236,17,8,248,191,15,233,253,56,246,222,10,152,208,58,5,58,245,202,1,97,253,155,0,86,27,218,245,93,252,116,254,102,252,12,8,191,1,214,255,119,253,236,253,216,253,103,248,92,191,47,3,104,254,141,13,234,239,107,3,7,252,114,212,1,254,6,15,171,211,120,248,243,252,205,10,87,253,55,253,143,2,38,255,160,224,47,254,39,1,55,6,129,254,159,248,91,6,108,0,125,4,209,9,132,1,186,233,179,194,24,0,214,1,30,239,137,14,48,6,16,7,94,1,27,249,148,253,119,244,2,17,64,33,11,207,170,255,70,246,64,255,5,254,232,7,102,15,223,252,132,52,226,2,218,247,162,0,221,7,69,3,56,0,128,254,92,12,188,19,134,4,109,254,255,228,62,239,236,247,238,64,78,245,88,3,188,244,128,246,102,254,101,251,56,254,248,1,177,250,180,1,96,1,49,231,71,1,108,247,34,250,46,1,82,1,185,252,235,0,248,253,3,5,150,10,126,73,208,8,254,255,144,1,20,5,95,251,0,4,96,241,42,242,2,239,5,253,110,7,111,198,61,21,48,0,203,249,232,254,189,255,232,0,228,8,133,5,212,12,204,254,245,3,98,2,3,89,83,253,212,2,12,0,153,254,141,249,220,251,57,2,248,0,252,14,93,2,99,254,52,13,176,250,160,251,139,244,192,246,47,252,151,39,68,48,155,14,221,249,94,254,68,2,154,245,60,211,16,232,51,11,204,44,57,3,127,243,11,254,118,255,13,253,214,253,168,0,245,2,204,253,172,1,170,208,181,196,70,248,176,1,171,253,248,5,222,11,200,253,69,5,207,242,146,3,242,1,160,3,165,255,251,255,232,35,184,11,238,9,125,250,114,2,145,10,5,253,175,12,168,53,218,11,122,8,189,255,172,252,134,254,240,4,45,245,145,246,116,239,126,0,64,248,232,203,192,251,96,254,69,248,248,253,202,9,31,250,38,1,162,246,218,0,220,221,223,240,21,8,162,250,86,0,26,252,245,240,46,4,45,52,187,3,13,12,232,253,166,0,158,3,43,1,132,25,44,5,10,254,134,249,37,7,17,251,189,1,146,248,172,5,69,245,218,191,83,7,237,6,196,1,32,1,104,23,90,6,75,14,107,252,207,8,28,250,100,1,35,2,158,0,9,0,139,255,127,249,173,253,56,56,11,252,49,0,36,240,32,47,82,14,169,244,71,220,116,254,11,239,71,252,198,10,78,255,52,255,50,254,98,0,222,0,218,241,88,208,124,238,162,255,62,222,194,233,194,15,48,253,97,249,239,2,124,249,246,254,169,254,40,1,144,255,124,252,90,241,152,254,234,3,22,227,78,30,202,28,4,13,163,226,255,252,8,251,156,1,85,250,167,255,29,255,188,211,40,254,172,251,118,254,173,254,67,248,90,242,78,47,204,253,186,232,78,253,214,251,126,255,250,2,206,255,80,250,15,250,20,223,226,3,157,252,90,10,225,246,98,1,51,247,4,18,180,207,190,245,61,7,65,2,153,255,45,101,17,255,136,2,167,0,228,254,198,0,172,254,168,251,201,255,14,255,42,255,16,2,112,0,253,254,228,254,6,255,23,0,219,1,12,3,210,253,111,0,148,0,149,246,142,178,122,251,239,10,60,252,44,0,76,251,163,4,60,240,80,7,213,13,0,3,159,0,187,7,54,13,143,255,36,3,3,252,124,14,239,245,225,37,7,45,186,254,110,228,210,16,236,4,198,14,42,13,59,6,193,2,220,8,134,8,229,5,107,4,149,38,164,227,254,254,49,0,150,6,64,250,4,246,75,248,103,168,82,1,230,1,195,3,45,4,222,255,253,251,166,255,143,252,39,254,42,2,74,231,151,252,240,217,173,39,201,251,72,2,233,251,94,248,60,24,112,9,125,252,172,5,170,3,73,254,104,253,135,16,154,36,120,30,170,0,232,36,108,237,175,7,174,2,94,251,124,2,73,249,36,251,228,253,40,253,50,1,14,249,212,224,166,242,126,32,220,248,20,6,159,13,211,39,157,14,2,254,29,8,40,250,217,4,128,1,221,1,229,251,242,30,19,240,47,246,81,3,75,253,46,220,168,16,252,224,89,249,204,1,86,244,74,2,13,0,121,1,13,3,121,228,196,26,186,250,113,29,19,254,129,248,123,1,36,12,197,16,19,33,221,240,63,0,44,0,237,1,216,5,215,249,212,233,246,12,228,25,57,20,182,212,122,4,179,12,121,251,51,254,186,1,226,4,212,0,176,0,2,14,137,0,63,220,52,202,237,223,137,1,146,4,181,6,97,253,42,1,23,255,115,3,3,250,145,1,254,0,20,30,37,237,26,3,121,1,136,254,208,47,130,28,141,9,144,4,206,253,248,5,51,2,165,1,162,253,0,0,160,22,211,251,56,3,144,14,87,245,237,3,38,253,222,16,132,2,184,67,204,249,52,8,147,254,253,1,97,254,100,14,88,220,184,251,74,239,13,6,33,251,143,21,67,43,88,247,116,23,157,241,153,1,38,253,98,254,249,254,33,230,2,32,233,1,131,220,78,1,176,251,210,252,132,5,242,5,135,249,139,228,210,239,6,251,248,253,216,255,138,2,162,248,229,37,192,44,113,226,152,4,196,12,200,11,85,4,139,255,166,252,101,255,31,251,26,255,40,255,105,15,182,35,7,247,134,0,253,245,27,59,89,3,195,249,150,253,150,0,178,253,90,255,155,254,132,1,187,255,193,221,98,11,63,4,65,18,219,199,88,2,126,1,155,248,76,3,14,255,32,2,150,255,56,2,139,251,115,1,103,10,188,248,43,253,130,31,183,250,217,221,63,215,252,248,171,1,183,255,178,0,96,0,212,3,34,254,210,3,231,6,146,23,121,2,198,3,165,2,191,255,140,252,161,1,205,1,62,0,156,252,93,0,156,255,7,2,176,63,86,10,20,251,239,47,116,255,142,0,130,43,132,252,190,247,139,253,172,0,232,2,248,247,64,252,61,0,44,252,34,8,73,254,202,243,252,245,150,4,178,255,254,0,78,255,63,6,76,254,79,74,215,20,106,249,242,252,8,2,233,221,0,1,252,241,194,233,35,48,213,247,231,5,112,253,32,15,66,9,254,252,26,1,199,1,195,253,217,255,165,30,234,206,146,49,100,255,70,254,29,255,63,2,238,254,75,249,120,0,216,255,74,7,123,2,161,0,14,1,15,4,184,12,95,253,241,242,196,16,89,200,230,27,43,237,177,253,94,254,120,1,21,0,60,2,39,2,70,0,96,234,79,0,236,9,7,254,229,254,162,254,1,251,162,249,186,8,164,253,126,20,84,187,50,244,228,251,205,254,226,25,234,10,166,6,83,7,172,248,243,3,192,254,244,4,230,254,48,4,34,56,242,223,194,4,118,2,173,0,62,29,72,59,254,231,39,19,132,253,195,250,80,5,251,249,12,252,246,252,84,0,170,1,132,255,22,253,4,255,179,212,247,6,239,244,41,3,24,253,146,8,0,13,117,27,23,236,70,19,47,244,127,253,47,1,184,254,2,1,226,33,53,0,189,242,207,3,40,217,154,222,48,13,54,253,54,4,162,4,86,2,40,3,90,255,16,253,228,1,32,236,204,5,2,251,130,44,172,248,212,223,39,20,218,248,16,250,201,10,80,2,52,255,176,250,198,1,230,0,82,236,210,249,15,234,66,5,3,248,2,9,100,69,238,1,60,2,118,248,83,1,38,2,16,3,151,0,15,253,100,18,14,244,181,223,209,12,226,251,102,3,79,251,43,248,104,252,125,216,19,21,233,230,226,252,111,1,35,255,80,235,8,245,121,32,43,236,119,6,56,255,114,0,46,0,94,1,186,246,100,3,185,254,121,1,158,218,207,4,42,36,48,34,2,12,197,238,204,254,11,9,168,26,25,243,128,252,94,251,67,2,255,245,232,8,74,2,226,252,139,18,97,242,26,5,39,251,25,254,166,255,204,255,159,12,213,253,218,186,135,245,113,6,239,255,234,254,121,253,127,239,180,10,32,251,14,241,76,5,244,13,14,252,32,63,90,254,48,1,130,15,100,4,195,254,214,253,161,2,89,251,108,12,179,238,45,6,7,6,207,247,112,16,109,219,162,39,104,7,88,11,240,239,108,250,49,255,203,1,221,255,19,21,0,221,69,12,252,42,52,1,103,14,4,6,148,247,176,253,104,6,235,3,232,254,29,3,204,0,254,26,200,252,116,18,121,18,177,21,163,243,227,1,244,255,33,0,180,253,133,254,146,1,215,13,82,218,74,0,131,37,47,254,56,11,193,246,139,252,78,11,123,255,198,10,47,253,145,13,246,203,226,5,192,250,0,2,42,4,148,223,127,44,200,46,79,251,13,0,156,253,165,0,225,248,154,0,133,255,210,4,89,254,145,254,198,255,128,1,127,10,232,9,58,3,79,24,214,6,115,222,102,4,44,38,10,230,251,7,34,7,243,251,30,248,180,2,206,252,153,242,45,254,254,42,79,13,112,3,1,248,193,215,24,24,148,5,205,254,238,255,149,2,4,255,242,2,183,4,19,245,15,244,165,231,99,0,93,252,82,6,180,2,230,10,218,254,80,251,120,233,85,210,71,235,156,255,134,1,241,252,116,210,189,237,254,202,204,10,134,5,238,252,129,1,163,0,206,2,26,3,94,4,59,3,134,253,181,255,80,24,125,15,212,247,160,251,5,231,98,21,70,205,111,240,123,2,224,253,171,248,65,255,0,0,121,0,123,1,13,244,132,0,208,102,47,253,238,4,62,253,165,1,171,255,218,255,153,2,78,2,48,255,60,255,168,0,10,0,247,4,38,255,147,254,45,233,247,232,198,207,46,244,28,23,141,255,145,245,2,252,53,255,194,3,227,3,174,252,15,2,252,253,151,249,196,1,68,0,180,4,228,2,129,1,38,0,240,2,150,0,240,243,128,80,202,255,217,255,221,23,152,12,164,255,197,254,55,17,206,254,37,5,117,254,175,249,144,35,91,242,28,214,13,244,27,1,81,0,193,217,118,243,139,28,107,17,129,253,195,255,128,4,72,255,242,8,142,1,170,244,40,245,168,249,129,4,242,0,95,221,223,241,53,1,99,209,249,240,138,233,163,12,103,255,197,254,126,1,209,0,101,252,24,8,202,1,164,0,47,14,49,12,148,12,196,252,60,222,167,8,33,15,157,48,21,2,137,253,203,255,120,255,40,253,16,255,164,1,54,11,139,236,138,3,56,243,127,18,29,14,108,9,145,240,165,214,221,28,52,2,194,12,188,250,12,2,34,6,211,25,26,13,238,251,70,7,68,7,93,251,129,22,70,249,39,32,252,226,226,233,215,4,185,244,38,255,42,3,217,251,230,58,174,2,186,246,219,254,17,248,11,255,89,17,181,19,76,4,66,26,251,6,181,253,132,254,132,0,4,20,66,207,95,0,50,251,184,5,177,248,161,3,150,5,106,10,72,241,224,10,143,241,210,223,9,255,91,2,42,223,50,5,9,4,25,253,14,246,179,10,88,3,102,206,150,236,242,8,176,251,34,0,232,251,176,255,122,2,73,253,172,255,70,9,39,159,216,251,200,251,2,255,212,252,252,0,210,249,111,254,253,2,79,3,84,1,223,1,165,243,150,0,69,255,240,32,47,10,27,8,104,5,167,1,63,227,234,215,50,247,54,0,41,4,40,0,89,3,222,7,44,236,198,0,145,2,226,1,90,254,119,247,174,252,194,254,164,0,84,253,138,10,16,252,85,68,192,255,124,229,178,232,240,199,211,246,188,9,10,1,53,4,143,7,157,255,174,16,15,9,169,246,11,3,187,0,186,255,236,237,238,239,240,241,242,243,244,245,28,2,0,6,58,246,247,248,249,250,251,252,253,254,255,0,0,0,0,0,0,0,8,8,8,8,8,8,8,8,8,8,5,2,1,3,6,8,8,8,8,8,8,8,8,8,8,0,0,0,0,0,0,0,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,222,31,223,31,224,31,225,31,226,31,227,31,228,31,229,31,230,31,231,31,242,7,253,0,62,0,14,0,6,0,0,0,2,0,30,0,252,0,248,3,204,31,232,31,233,31,234,31,235,31,236,31,205,31,237,31,238,31,239,31,240,31,241,31,242,31,243,31,244,31,245,31,246,31,247,31,248,31,249,31,250,31,251,31,252,31,253,31,254,31,254,63,255,63,0,0,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,11,8,6,4,3,1,2,5,8,10,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,0,242,31,243,31,244,31,245,31,246,31,247,31,248,31,248,15,254,0,126,0,14,0,6,0,0,0,2,0,30,0,62,0,254,1,249,31,250,31,251,31,252,31,253,31,254,31,254,63,255,63,0,0,0,0,0,0,13,13,13,13,13,13,13,12,8,7,4,3,1,2,5,6,9,13,13,13,13,13,13,14,14,0,0,0,0,0,0,0,228,255,0,0,229,255,0,0,230,255,0,0,231,255,0,0,232,255,0,0,233,255,0,0,234,255,0,0,235,255,0,0,236,255,0,0,237,255,0,0,238,255,0,0,239,255,0,0,240,255,0,0,241,255,0,0,242,255,0,0,243,255,0,0,244,255,0,0,226,255,0,0,252,15,0,0,252,7,0,0,254,1,0,0,126,0,0,0,30,0,0,0,6,0,0,0,0,0,0,0,2,0,0,0,14,0,0,0,62,0,0,0,254,0,0,0,253,7,0,0,253,15,0,0,240,127,0,0,227,255,0,0,245,255,0,0,246,255,0,0,247,255,0,0,248,255,0,0,249,255,0,0,250,255,0,0,246,255,1,0,247,255,1,0,248,255,1,0,249,255,1,0,250,255,1,0,251,255,1,0,252,255,1,0,253,255,1,0,254,255,1,0,255,255,1,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,11,9,7,5,3,1,2,4,6,8,11,12,15,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,17,17,0,0,0,0,0,0,0,237,255,3,0,238,255,3,0,222,255,7,0,223,255,7,0,224,255,7,0,225,255,7,0,226,255,7,0,227,255,7,0,228,255,7,0,229,255,7,0,230,255,7,0,231,255,7,0,232,255,7,0,233,255,7,0,234,255,7,0,235,255,7,0,236,255,7,0,244,255,1,0,247,255,0,0,249,255,0,0,248,255,0,0,251,63,0,0,250,63,0,0,248,63,0,0,250,31,0,0,252,15,0,0,252,7,0,0,254,0,0,0,62,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,30,0,0,0,126,0,0,0,254,1,0,0,253,7,0,0,251,31,0,0,249,63,0,0,252,63,0,0,250,127,0,0,246,255,0,0,245,255,1,0,236,255,3,0,237,255,7,0,238,255,7,0,239,255,7,0,240,255,7,0,241,255,7,0,242,255,7,0,243,255,7,0,244,255,7,0,245,255,7,0,246,255,7,0,247,255,7,0,248,255,7,0,249,255,7,0,250,255,7,0,251,255,7,0,252,255,7,0,253,255,7,0,254,255,7,0,255,255,7,0,0,0,0,0,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,17,16,16,16,14,14,14,13,12,11,8,6,4,2,1,3,5,7,9,11,13,14,14,15,16,17,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,214,255,3,0,215,255,3,0,216,255,3,0,217,255,3,0,218,255,3,0,219,255,3,0,184,255,7,0,185,255,7,0,186,255,7,0,187,255,7,0,188,255,7,0,189,255,7,0,190,255,7,0,191,255,7,0,192,255,7,0,193,255,7,0,194,255,7,0,195,255,7,0,196,255,7,0,197,255,7,0,198,255,7,0,199,255,7,0,200,255,7,0,201,255,7,0,202,255,7,0,203,255,7,0,204,255,7,0,205,255,7,0,206,255,7,0,207,255,7,0,208,255,7,0,209,255,7,0,210,255,7,0,211,255,7,0,230,255,1,0,212,255,3,0,240,255,0,0,233,255,1,0,213,255,3,0,231,255,1,0,241,255,0,0,236,255,0,0,237,255,0,0,238,255,0,0,244,127,0,0,249,63,0,0,247,63,0,0,250,31,0,0,249,31,0,0,251,15,0,0,252,7,0,0,252,3,0,0,253,1,0,0,253,0,0,0,125,0,0,0,61,0,0,0,29,0,0,0,13,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,12,0,0,0,28,0,0,0,60,0,0,0,124,0,0,0,252,0,0,0,252,1,0,0,253,3,0,0,250,15,0,0,248,31,0,0,246,63,0,0,248,63,0,0,245,127,0,0,239,255,0,0,232,255,1,0,242,255,0,0,212,255,7,0,213,255,7,0,214,255,7,0,215,255,7,0,216,255,7,0,217,255,7,0,218,255,7,0,219,255,7,0,220,255,7,0,221,255,7,0,222,255,7,0,223,255,7,0,224,255,7,0,225,255,7,0,226,255,7,0,227,255,7,0,228,255,7,0,229,255,7,0,230,255,7,0,231,255,7,0,232,255,7,0,233,255,7,0,234,255,7,0,235,255,7,0,236,255,7,0,237,255,7,0,238,255,7,0,239,255,7,0,240,255,7,0,241,255,7,0,242,255,7,0,243,255,7,0,244,255,7,0,245,255,7,0,246,255,7,0,247,255,7,0,248,255,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+512000);
/* memory initializer */ allocate([249,255,7,0,250,255,7,0,251,255,7,0,252,255,7,0,253,255,7,0,254,255,7,0,255,255,7,0,0,0,0,0,18,18,18,18,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,17,18,16,17,18,17,16,16,16,16,15,14,14,13,13,12,11,10,9,8,7,6,5,4,3,2,2,3,4,5,6,7,8,9,10,12,13,14,14,15,16,17,16,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,0,0,0,0,0,0,6,14,43,52,2,67,1,1,13,1,3,1,4,1,2,1,6,14,43,52,2,5,1,1,13,1,3,1,4,1,1,0,92,32,81,63,166,10,134,189,14,190,48,62,80,141,151,60,225,11,19,189,200,152,59,61,0,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,5,162,19,63,205,177,20,63,122,195,21,63,31,215,22,63,187,236,23,63,96,4,25,63,0,30,26,63,0,60,27,63,0,90,28,63,0,122,29,63,0,158,30,63,0,196,31,63,0,234,32,63,0,20,34,63,0,64,35,63,0,108,36,63,0,156,37,63,0,206,38,63,0,2,40,63,0,58,41,63,0,114,42,63,0,172,43,63,0,234,44,63,0,42,46,63,0,108,47,63,0,176,48,63,0,246,49,63,0,62,51,63,0,138,52,63,0,216,53,63,0,40,55,63,0,122,56,63,0,208,57,63,0,38,59,63,0,128,60,63,0,220,61,63,0,60,63,63,0,156,64,63,0,0,66,63,0,104,67,63,0,208,68,63,0,60,70,63,0,170,71,63,0,28,73,63,0,142,74,63,0,4,76,63,0,126,77,63,0,250,78,63,0,120,80,63,0,250,81,63,0,126,83,63,0,4,85,63,0,142,86,63,0,26,88,63,0,170,89,63,0,60,91,63,0,208,92,63,0,104,94,63,0,4,96,63,0,162,97,63,0,66,99,63,0,230,100,63,0,142,102,63,0,56,104,63,0,228,105,63,0,148,107,63,0,72,109,63,0,254,110,63,0,184,112,63,0,116,114,63,0,52,116,63,0,248,117,63,0,190,119,63,0,136,121,63,0,86,123,63,0,38,125,63,0,174,126,63,0,162,127,63,0,254,127,63,0,198,127,63,0,250,126,63,0,152,125,63,0,160,123,63,0,24,121,63,0,252,117,63,0,80,114,63,0,24,110,63,0,84,105,63,0,8,100,63,0,56,94,63,0,228,87,63,0,18,81,63,0,200,73,63,0,6,66,63,0,212,57,63,0,52,49,63,0,44,40,63,0,196,30,63,0,254,20,63,0,224,10,63,0,114,0,63,0,112,235,62,0,116,213,62,0,252,190,62,0,20,168,62,0,200,144,62,0,88,114,62,0,136,66,62,0,72,18,62,0,112,195,61,0,160,67,61,0,0,0,0,0,0,125,63,0,9,122,63,229,26,119,63,148,53,116,63,243,88,113,63,232,132,110,63,89,185,107,63,45,246,104,63,74,59,102,63,152,136,99,63,254,221,96,63,100,59,94,63,178,160,91,63,208,13,89,63,167,130,86,63,31,255,83,63,34,131,81,63,153,14,79,63,109,161,76,63,137,59,74,63,214,220,71,63,63,133,69,63,175,52,67,63,17,235,64,63,80,168,62,63,87,108,60,63,18,55,58,63,109,8,56,63,84,224,53,63,179,190,51,63,119,163,49,63,141,142,47,63,225,127,45,63,97,119,43,63,251,116,41,63,156,120,39,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,16,0,17,0,18,0,19,0,20,0,32,0,33,0,34,0,35,0,48,0,49,0,50,0,64,0,65,0,80,0,0,1,1,1,2,1,3,1,4,1,16,1,17,1,18,1,19,1,32,1,33,1,34,1,48,1,49,1,64,1,0,2,1,2,2,2,3,2,16,2,17,2,18,2,32,2,33,2,48,2,0,3,1,3,2,3,16,3,17,3,32,3,0,4,1,4,16,4,0,5,0,16,1,16,2,16,3,16,4,16,16,16,17,16,18,16,19,16,32,16,33,16,34,16,48,16,49,16,64,16,0,17,1,17,2,17,3,17,16,17,17,17,18,17,32,17,33,17,48,17,0,18,1,18,2,18,16,18,17,18,32,18,0,19,1,19,16,19,0,20,0,32,1,32,2,32,3,32,16,32,17,32,18,32,32,32,33,32,48,32,0,33,1,33,2,33,16,33,17,33,32,33,0,34,1,34,16,34,0,35,0,48,1,48,2,48,16,48,17,48,32,48,0,49,1,49,16,49,0,50,0,64,1,64,16,64,0,65,0,80,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,32,33,34,35,36,37,38,39,40,41,42,43,44,45,48,49,50,51,52,53,54,55,56,57,58,59,60,64,65,66,67,68,69,70,71,72,73,74,75,80,81,82,83,84,85,86,87,88,89,90,96,97,98,99,100,101,102,103,104,105,112,113,114,115,116,117,118,119,120,128,129,130,131,132,133,134,135,144,145,146,147,148,149,150,160,161,162,163,164,165,176,177,178,179,180,192,193,194,195,208,209,210,224,225,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,93,39,0,144,45,37,0,236,8,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,17,0,0,0,208,93,39,0,56,219,35,0,200,233,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,120,38,34,0,120,38,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,24,136,33,0,24,136,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,40,13,33,0,40,13,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,128,166,32,0,24,75,32,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,8,50,40,0,80,213,39,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,232,109,39,0,56,29,39,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,128,216,38,0,248,146,38,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,160,88,38,0,160,88,38,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,48,35,38,0,48,35,38,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,120,242,37,0,248,196,37,0,0,0,0,0,128,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,144,162,37,0,224,122,37,0,0,0,0,0,128,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,128,55,37,0,8,14,37,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,72,229,36,0,176,193,36,0,0,0,0,0,128,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,128,164,36,0,152,137,36,0,0,0,0,0,128,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,24,110,36,0,96,26,156,0,0,0,0,0,128,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,80,58,36,0,232,28,36,0,0,0,0,0,128,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,208,93,39,0,208,226,35,0,192,196,35,0,8,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,80,173,35,0,128,151,35,0,12,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,16,130,35,0,96,107,35,0,152,76,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,184,87,35,0,168,70,35,0,16,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,56,52,35,0,168,28,35,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,116,64,17,0,0,0,0,0,0,0,32,241,34,0,16,218,34,0,52,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,116,64,17,0,0,0,0,0,0,0,160,203,34,0,24,187,34,0,252,43,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,216,168,34,0,240,150,34,0,0,44,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,24,137,34,0,8,122,34,0,104,0,0,0,3,0,0,0,0,0,0,0,0,36,254,64,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,24,105,34,0,104,84,34,0,112,0,0,0,3,0,0,0,0,0,0,0,0,36,254,64,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,136,44,34,0,184,24,34,0,28,44,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,17,0,0,0,0,0,0,0,216,10,34,0,216,251,33,0,20,44,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,17,0,0,0,0,0,0,0,80,233,33,0,32,219,33,0,32,44,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,17,0,0,0,0,0,0,0,176,207,33,0,128,197,33,0,24,44,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,17,0,0,0,0,0,0,0,200,188,33,0,128,174,33,0,164,93,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,17,0,0,0,200,188,33,0,176,140,33,0,160,125,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,200,188,33,0,48,116,33,0,152,106,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,200,188,33,0,160,96,33,0,160,86,33,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,200,188,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,36,254,64,0,0,0,0,0,36,254,64,16,225,36,0,86,2,0,0,8,253,7,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,12,1,0,0,34,0,0,0,144,0,0,0,6,1,0,0,34,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,2,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,3,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,255,255,255,255,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,13,0,0,0,16,0,0,0,0,0,1,0,0,0,0,0,13,16,1,0,1,0,0,0,1,80,1,0,2,0,0,0,0,0,1,0,3,0,0,0,0,0,0,0,0,0,0,0,4,4,4,4,4,4,8,8,8,16,28,36,0,0,0,0,4,4,4,4,4,4,4,8,8,8,8,12,16,20,20,0,4,4,4,4,4,8,8,8,12,12,12,16,16,16,0,0,4,4,4,4,4,4,4,8,8,8,12,12,16,16,20,0,4,4,4,4,4,4,4,4,8,8,12,12,16,20,20,0,224,5,8,0,224,5,8,0,224,5,8,0,0,6,8,0,0,6,8,0,0,6,8,0,16,6,8,0,16,6,8,0,32,6,8,0,32,6,8,0,32,6,8,0,240,5,8,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,12,12,12,12,12,16,16,24,28,36,44,64,64,64,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,12,12,12,12,12,12,12,12,12,12,12,12,12,16,16,16,16,16,16,16,20,20,20,20,24,24,24,28,28,32,36,36,40,44,48,52,56,60,64,80,4,4,4,4,4,4,4,4,4,4,4,4,4,4,8,8,8,8,12,12,12,16,16,16,20,24,24,28,36,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,0,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,12,12,12,12,16,16,20,20,24,24,28,28,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,96,0,0,0,0,0,0,0,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,12,12,12,12,16,16,20,20,24,24,28,28,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,4,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,8,8,8,12,12,12,12,16,16,16,20,20,24,24,28,28,32,36,36,40,44,48,52,52,64,64,64,64,64,0,8,8,8,8,8,8,8,8,8,8,8,12,12,12,12,12,12,12,12,12,16,16,16,16,20,20,20,24,24,28,28,32,36,40,40,44,48,52,56,60,64,64,64,0,0,0,0,0,96,6,8,0,96,6,8,0,184,6,8,0,232,6,8,0,232,6,8,0,32,7,8,0,88,7,8,0,88,7,8,0,136,7,8,0,136,7,8,0,136,7,8,0,144,6,8,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,48,0,52,0,56,0,60,0,68,0,76,0,84,0,92,0,100,0,112,0,124,0,136,0,148,0,164,0,184,0,208,0,236,0,12,1,44,1,76,1,108,1,140,1,172,1,204,1,0,2,0,0,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,48,0,52,0,56,0,64,0,72,0,80,0,88,0,96,0,108,0,120,0,132,0,144,0,160,0,176,0,192,0,212,0,236,0,4,1,32,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,52,0,60,0,68,0,80,0,92,0,104,0,120,0,140,0,164,0,192,0,224,0,0,1,32,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,0,0,4,0,8,0,12,0,16,0,20,0,24,0,32,0,40,0,48,0,64,0,92,0,128,0,0,0,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,36,0,44,0,52,0,60,0,72,0,88,0,108,0,128,0,0,0,4,0,8,0,12,0,16,0,20,0,28,0,36,0,44,0,56,0,68,0,80,0,96,0,112,0,128,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,36,0,44,0,52,0,64,0,76,0,92,0,108,0,128,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,40,0,48,0,60,0,72,0,88,0,108,0,128,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,48,0,52,0,56,0,64,0,72,0,80,0,88,0,96,0,108,0,120,0,132,0,144,0,156,0,172,0,188,0,212,0,240,0,20,1,64,1,128,1,192,1,0,2,64,2,128,2,192,2,0,3,64,3,128,3,192,3,0,4,0,0,0,0,0,0,12,0,24,0,36,0,48,0,60,0,72,0,84,0,96,0,108,0,120,0,132,0,144,0,156,0,172,0,188,0,204,0,220,0,236,0,252,0,12,1,32,1,52,1,72,1,92,1,116,1,140,1,164,1,192,1,220,1,252,1,32,2,68,2,108,2,152,2,200,2,252,2,52,3,112,3,176,3,0,4,0,0,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,48,0,52,0,56,0,64,0,72,0,80,0,88,0,100,0,112,0,124,0,140,0,156,0,172,0,192,0,216,0,240,0,12,1,48,1,88,1,128,1,168,1,208,1,248,1,32,2,72,2,112,2,152,2,192,2,232,2,16,3,56,3,96,3,136,3,176,3,216,3,0,4,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,48,0,56,0,64,0,72,0,80,0,88,0,96,0,108,0,120,0,132,0,144,0,160,0,176,0,196,0,216,0,240,0,8,1,36,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,32,2,64,2,96,2,128,2,160,2,192,2,224,2,0,3,32,3,64,3,96,3,128,3,160,3,0,4,0,0,0,0,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,48,0,56,0,64,0,72,0,80,0,88,0,96,0,108,0,120,0,132,0,144,0,160,0,176,0,196,0,216,0,240,0,8,1,36,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,32,2,64,2,96,2,128,2,160,2,192,2,224,2,0,3,32,3,64,3,96,3,128,3,160,3,192,3,224,3,0,4,0,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,32,0,36,0,40,0,44,0,52,0,60,0,68,0,76,0,84,0,92,0,100,0,108,0,116,0,124,0,136,0,148,0,160,0,172,0,188,0,204,0,220,0,240,0,4,1,28,1,52,1,80,1,108,1,140,1,176,1,212,1,252,1,40,2,88,2,140,2,192,2,0,3,64,3,128,3,192,3,0,4,0,0,8,0,16,0,24,0,32,0,40,0,48,0,56,0,64,0,72,0,80,0,88,0,100,0,112,0,124,0,136,0,148,0,160,0,172,0,184,0,196,0,212,0,228,0,244,0,4,1,24,1,44,1,64,1,88,1,112,1,140,1,168,1,200,1,236,1,20,2,60,2,104,2,152,2,204,2,4,3,64,3,128,3,192,3,0,4,216,246,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,246,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,6,10,3,7,11,4,8,5,9,12,13,14,15,2,255,255,255,255,2,1,255,255,255,1,2,255,255,255,2,1,255,255,255,1,2,255,255,255,1,2,255,255,255,0,2,255,255,255,0,2,1,4,3,0,1,2,4,3,0,2,1,4,3,2,0,1,3,4,0,4,2,1,3,2,0,255,255,255,2,1,0,4,3,1,2,4,0,3,2,1,0,4,3,2,1,4,3,0,1,2,4,0,3,2,0,255,255,255,2,0,1,4,3,1,2,0,4,3,2,1,0,4,3,2,1,3,4,0,2,4,1,0,3,0,2,255,255,255,0,2,1,3,4,1,2,3,0,4,2,0,1,3,4,2,1,3,0,4,2,0,4,3,1,0,2,255,255,255,0,2,4,1,3,1,4,2,0,3,4,2,0,1,3,2,0,1,4,3,4,2,1,0,3,0,0,0,0,0,0,1,0,0,1,0,2,1,1,2,0,3,0,2,1,1,2,0,3,0,4,1,3,2,2,3,1,4,0,4,1,3,2,2,3,1,4,2,4,3,3,4,2,4,3,3,4,4,4,0,0,0,0,0,0,41,15,0,0,255,16,0,0,26,19,0,0,105,21,0,0,10,24,0,0,2,27,0,0,81,30,0,0,14,34,0,0,53,38,0,0,235,42,0,0,51,48,0,0,4,54,0,0,163,60,0,0,27,68,0,0,105,76,0,0,113,85,0,0,232,95,0,0,8,108,0,0,127,120,0,0,54,136,0,0,151,151,0,0,227,170,0,0,207,191,0,0,155,213,0,0,254,240,0,0,137,12,1,0,47,47,1,0,25,92,1,0,157,135,1,0,54,171,1,0,171,238,1,0,221,40,2,0,120,216,12,0,96,0,0,0,240,12,8,0,104,9,26,0,0,0,0,1,1,1,2,1,0,2,3,1,4,1,5,1,0,3,1,2,2,2,6,1,7,1,8,1,9,1,0,4,0,0,0,1,1,1,0,2,2,1,0,3,0,4,0,5,3,1,4,1,1,2,1,3,0,6,0,7,0,8,0,9,0,0,0,255,255,255,255,254,0,255,255,0,255,0,1,0,1,0,255,1,0,0,255,1,255,0,0,0,255,1,0,0,255,0,0,1,255,1,0,255,255,0,1,1,0,0,255,1,0,1,0,0,1,255,0,0,0,255,1,0,1,0,254,1,0,255,1,0,0,0,1,0,255,0,0,0,255,0,0,0,0,1,1,0,0,255,0,1,0,0,0,0,255,1,1,255,255,254,0,255,1,0,255,0,255,252,255,254,255,254,1,254,0,0,4,254,255,1,1,0,2,1,1,0,2,0,0,0,1,1,0,255,255,255,1,0,255,253,253,1,255,1,254,255,1,255,0,1,2,1,255,255,1,1,1,2,1,0,1,254,254,0,255,254,254,0,255,255,255,0,1,0,255,255,0,255,0,2,1,2,2,1,255,1,0,2,0,255,1,0,0,0,254,0,255,255,1,1,254,0,254,0,1,254,254,1,255,255,3,254,0,253,252,253,2,1,0,3,254,2,3,2,2,255,253,1,0,1,0,0,0,1,254,1,254,254,255,254,254,2,0,252,0,2,255,0,2,2,2,1,0,255,255,1,253,2,2,1,0,3,1,255,1,3,1,0,1,1,2,255,1,255,254,255,0,255,1,255,1,254,254,255,255,253,1,252,253,1,254,0,254,3,255,255,0,2,2,255,253,2,1,0,254,255,253,254,254,1,2,253,0,1,251,254,253,0,254,255,2,0,255,255,0,254,1,3,249,254,254,255,2,255,0,3,1,3,1,0,0,1,2,3,1,2,0,254,254,1,1,2,2,3,4,1,255,2,254,4,0,0,0,4,2,0,254,254,2,252,255,5,254,254,253,2,253,255,3,253,0,4,3,0,1,254,4,4,3,2,2,1,0,255,4,3,3,2,1,0,255,255,3,3,2,2,1,0,255,254,3,2,2,1,0,255,254,253,2,2,1,0,255,255,254,253,2,1,0,0,255,254,253,252,1,0,0,255,254,253,252,252,0,0,255,254,254,253,252,252,2,3,3,3,3,3,3,3,2,2,2,2,2,2,3,3,1,2,2,2,2,2,2,2,0,1,1,1,1,1,1,1,255,0,0,0,0,0,1,1,254,254,255,255,255,255,255,255,253,253,253,253,253,253,254,254,251,252,252,252,252,252,252,253,252,254,255,0,1,2,2,3,252,254,255,0,1,2,3,3,252,253,255,0,1,2,3,3,252,253,255,0,1,2,3,3,251,253,255,0,1,2,3,3,251,253,255,0,1,2,3,3,251,253,255,0,1,1,2,3,251,253,254,255,0,1,2,3,4,4,5,5,6,6,7,7,2,2,2,3,3,4,4,4,0,0,0,0,1,1,1,2,254,254,254,254,255,255,255,0,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,254,254,254,254,254,254,254,255,255,255,255,254,254,254,254,5,3,1,255,254,253,253,253,5,3,1,255,254,253,253,253,5,3,1,255,254,253,253,253,5,3,1,255,254,253,253,253,5,4,1,0,254,253,253,253,6,4,2,0,254,254,253,253,6,4,2,0,255,254,254,253,6,4,2,1,255,254,254,254,255,1,3,3,2,0,253,250,255,1,3,4,3,0,253,250,255,1,4,4,3,1,253,250,255,1,3,4,3,1,253,250,254,1,3,4,3,1,253,250,254,1,3,4,3,1,253,249,254,1,3,3,2,0,253,249,254,0,2,3,2,0,253,250,10,9,8,6,6,5,4,4,6,5,4,3,2,2,2,1,2,1,0,255,254,254,254,255,255,254,253,252,252,252,252,253,254,253,252,252,251,252,252,253,254,254,253,253,253,253,254,254,255,255,255,255,255,255,255,0,1,1,1,1,1,1,1,2,254,255,1,2,4,5,7,8,253,254,0,1,3,5,7,8,252,253,255,0,2,4,6,7,251,252,254,255,1,3,5,7,250,251,253,254,0,2,4,6,250,251,252,254,255,1,3,5,249,250,251,253,254,0,2,3,248,249,251,252,253,255,1,2,11,9,7,5,3,1,255,255,10,8,6,3,1,0,254,254,9,7,5,2,0,254,253,252,8,6,3,1,255,253,252,252,6,4,2,255,253,252,251,251,5,3,0,254,252,251,250,250,3,1,255,253,251,250,249,249,2,0,254,252,250,250,249,249,5,6,7,7,7,8,8,8,3,4,5,5,6,6,6,6,0,2,2,3,4,4,4,5,254,255,0,1,2,2,3,3,252,253,254,255,0,1,1,2,250,251,252,253,254,254,255,0,248,249,250,250,251,252,253,253,246,247,248,248,249,250,250,251,6,5,3,1,255,253,250,248,6,5,4,2,255,253,250,248,6,5,4,2,0,253,250,248,6,5,4,2,0,253,250,248,6,6,4,2,0,253,250,248,6,5,4,2,0,253,250,248,6,5,4,2,0,253,250,248,6,5,4,2,255,253,251,248,11,10,9,8,7,6,5,4,8,8,7,6,5,4,3,2,6,5,4,4,2,2,1,0,3,3,2,1,0,0,255,254,1,1,0,255,254,254,253,253,255,255,254,253,252,252,251,251,253,252,252,251,250,250,249,249,251,251,250,249,248,248,248,248,242,243,244,245,247,249,250,252,244,245,246,247,249,251,253,255,246,247,249,250,253,254,0,2,248,250,252,254,0,2,4,5,251,253,0,2,4,5,7,8,254,0,2,4,6,8,9,10,0,3,5,7,8,10,11,12,3,5,7,8,10,11,12,12,237,237,238,238,239,240,241,242,241,241,242,243,244,245,246,247,245,246,247,248,250,251,252,253,250,251,253,254,255,0,1,2,255,0,2,3,4,5,6,6,4,6,7,8,9,10,10,10,9,10,11,12,13,14,14,14,12,14,14,15,16,16,16,16,22,21,19,17,14,11,9,5,20,19,17,14,11,8,4,1,17,15,13,10,6,3,0,252,13,11,8,5,1,254,251,247,9,6,3,255,252,249,245,243,4,0,253,250,247,244,241,239,254,251,248,245,242,240,238,236,248,246,243,240,239,237,235,234,17,18,18,18,17,16,16,14,16,16,15,15,14,13,12,11,12,12,11,10,9,8,7,5,7,6,6,4,3,2,1,255,1,0,255,254,253,252,251,250,251,250,249,248,247,246,245,244,245,244,243,242,241,240,240,239,240,239,239,238,237,236,236,236,0,0,0,0,255,255,254,253,1,0,0,0,0,255,254,253,1,1,0,0,255,255,254,254,1,1,1,0,0,255,255,254,2,1,1,1,0,255,255,254,2,2,1,1,0,0,255,254,2,2,1,1,1,0,255,255,2,2,1,1,1,0,0,254,0,255,255,0,0,1,2,3,0,255,255,0,1,1,2,2,255,255,255,255,0,1,2,2,255,255,254,255,0,1,1,2,255,254,254,255,0,0,1,2,255,254,254,254,255,0,1,2,255,255,254,255,0,0,1,2,255,255,255,255,0,1,1,2,3,2,2,2,1,1,0,0,3,2,2,2,2,1,0,0,2,2,2,1,1,1,0,0,2,2,1,1,1,0,0,255,1,1,1,0,0,0,255,255,0,0,255,255,255,255,255,255,254,254,254,254,254,254,254,254,254,253,253,253,254,254,254,254,5,2,0,0,255,0,0,0,4,2,0,255,255,255,0,255,4,1,255,255,254,255,255,255,4,1,255,255,254,255,255,255,4,1,255,254,254,255,255,255,4,1,255,254,254,255,255,255,4,1,255,255,255,255,255,255,4,2,0,255,0,0,0,255,254,255,0,1,1,1,1,1,253,255,0,1,1,1,1,1,253,255,0,1,1,1,1,1,253,255,0,1,1,1,1,1,253,254,0,1,2,2,1,1,252,254,0,1,2,2,2,2,251,253,255,1,1,2,1,2,251,253,254,0,1,1,1,1,3,3,1,0,254,252,252,251,3,3,2,0,255,254,253,252,2,2,1,1,0,255,254,254,1,1,1,1,1,0,0,0,0,0,0,1,1,1,1,1,254,255,255,0,0,1,2,2,253,254,254,255,0,1,2,3,253,253,254,255,0,1,2,3,253,253,253,253,253,254,254,254,253,253,254,254,254,255,255,255,254,254,254,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,1,1,2,2,2,2,1,1,1,2,2,3,3,3,2,2,2,2,3,3,3,3,248,249,251,253,254,255,0,255,252,253,255,0,1,2,1,1,255,1,2,3,3,2,2,1,1,2,3,3,2,2,1,0,2,3,3,2,1,0,0,255,1,2,1,0,255,255,255,255,1,1,0,255,255,254,254,255,1,1,0,0,255,255,0,255,252,253,254,0,1,2,3,3,252,253,254,0,1,2,2,2,253,253,254,255,0,1,1,1,254,254,254,255,255,0,0,0,0,255,255,255,255,255,255,255,2,1,1,0,0,255,255,254,3,3,3,1,0,255,254,254,5,4,4,2,1,0,255,254,0,0,0,0,1,2,3,3,0,255,0,0,1,2,3,3,0,255,0,0,1,2,3,2,0,0,0,1,1,2,2,2,2,1,1,1,1,1,1,0,2,2,2,1,0,0,255,254,2,1,0,0,254,253,251,250,0,255,255,253,251,250,248,247,254,0,1,2,2,1,255,252,254,0,2,2,2,1,255,252,254,0,2,2,2,1,255,253,254,0,2,2,2,1,255,253,254,255,2,2,2,1,255,253,254,255,1,2,2,1,255,253,253,255,1,2,2,1,255,253,254,255,1,2,2,1,255,253,255,1,1,255,253,253,0,4,255,1,1,255,253,253,0,4,255,1,1,0,253,253,0,4,255,1,2,0,253,253,0,5,0,1,2,0,253,252,0,4,0,1,2,0,253,252,0,5,0,1,2,0,253,253,0,4,0,1,2,255,254,254,0,4,6,6,5,6,5,5,5,5,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,255,255,255,255,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,2,2,2,2,2,2,2,2,0,1,1,0,0,0,0,0,255,254,254,254,254,254,254,255,253,253,253,253,253,253,253,254,253,252,252,253,253,253,254,254,254,254,254,254,255,255,0,0,0,1,1,1,2,2,3,3,3,4,4,5,5,6,6,6,4,1,254,253,253,255,1,3,4,1,254,252,253,255,1,3,5,1,254,252,253,255,1,4,5,1,254,253,253,255,2,4,5,1,254,253,253,255,2,4,4,0,253,252,253,255,2,4,4,0,253,253,253,255,1,3,3,0,254,253,254,255,1,3,253,252,252,252,252,252,252,252,255,255,255,255,255,255,254,254,2,1,1,2,2,1,1,1,3,3,3,4,4,3,3,3,3,3,3,4,4,4,3,3,1,2,1,2,2,2,2,2,254,254,254,255,255,255,0,0,252,252,252,252,253,253,253,253,255,254,253,253,254,254,255,0,0,255,254,254,254,255,0,1,2,1,255,255,255,255,0,1,3,1,0,255,255,0,0,1,3,2,0,255,0,0,0,1,3,1,0,255,0,0,0,1,3,1,0,255,0,0,0,1,2,1,0,0,0,0,0,1,0,0,0,1,1,2,3,4,0,0,255,0,0,0,2,3,0,255,255,255,255,255,0,1,0,255,255,255,255,255,255,0,0,0,255,255,255,254,254,255,1,0,0,255,255,254,254,255,2,2,1,0,255,255,255,255,3,3,2,1,0,255,255,0,1,0,1,0,0,255,254,255,0,0,0,0,255,255,254,255,0,255,0,0,255,255,255,255,255,255,255,0,0,0,0,0,255,255,255,0,0,0,1,1,255,255,255,0,1,1,2,3,254,254,255,0,1,2,3,4,254,254,255,0,1,2,4,5,253,255,1,0,0,255,0,1,253,0,1,0,255,255,0,2,253,0,1,0,255,255,0,2,254,1,2,0,255,255,0,2,254,1,2,0,255,255,0,2,254,1,2,0,255,255,0,2,255,2,2,0,255,255,0,2,255,1,1,0,255,255,255,1,254,254,255,1,3,4,3,1,254,254,255,0,2,3,2,0,254,254,255,0,1,2,1,255,255,255,255,0,1,2,1,255,255,255,255,0,1,1,0,254,0,255,255,0,1,1,0,255,0,255,255,0,1,1,1,255,0,255,255,0,0,1,0,255,254,255,0,1,1,1,1,1,254,255,0,0,0,0,0,0,254,255,255,0,255,255,254,254,254,255,255,255,255,254,254,253,255,0,1,1,0,255,254,254,1,2,3,3,2,1,0,0,1,2,3,3,3,2,1,0,0,0,1,1,1,1,0,0,0,255,255,255,0,0,0,0,1,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,1,1,1,1,1,255,0,0,1,1,0,0,0,253,254,255,255,255,255,0,255,251,251,252,253,254,254,254,255,1,1,1,1,2,1,0,255,1,1,1,2,1,1,0,255,1,1,1,1,1,1,0,254,2,1,1,1,1,1,0,254,1,1,0,0,0,0,255,253,1,1,0,0,0,255,254,253,1,1,0,0,255,255,254,252,1,0,0,255,254,254,253,252,8,7,5,3,2,1,1,1,2,1,0,0,255,255,254,255,255,255,255,254,254,254,254,255,255,255,255,255,0,255,255,0,0,0,0,1,1,0,0,0,0,0,1,1,1,0,0,0,255,0,0,0,0,0,255,255,254,254,255,255,255,254,254,255,9,4,0,254,254,254,255,255,7,2,255,254,254,255,0,0,4,0,254,254,255,0,1,1,1,254,254,254,255,0,1,1,255,254,254,255,0,1,1,1,255,254,255,0,1,1,1,0,255,255,0,1,1,1,0,255,0,255,0,1,0,0,255,255,0,1,1,1,1,1,0,0,1,2,2,2,1,0,0,0,2,2,2,2,1,0,255,255,1,1,1,0,255,254,254,254,0,0,0,255,254,253,254,254,255,255,255,254,254,254,255,0,255,255,255,255,0,0,1,2,255,255,255,0,1,2,3,4,255,255,0,0,255,254,253,253,255,255,0,0,0,255,255,255,254,254,255,0,1,1,1,1,254,254,254,0,1,2,3,3,255,255,255,0,1,3,3,3,1,0,0,0,1,1,2,2,2,2,1,0,0,255,255,255,3,2,1,0,255,254,253,253,255,255,255,254,254,253,252,251,0,0,0,255,255,253,253,252,1,1,1,0,0,255,254,253,2,2,2,1,1,0,255,255,2,2,2,2,1,1,0,255,2,2,2,2,2,1,0,0,1,1,2,1,1,1,0,0,0,0,1,1,0,0,0,255,254,2,3,1,255,1,1,255,253,2,3,0,255,1,1,255,253,2,3,0,255,1,1,255,252,2,3,0,255,1,1,254,252,1,3,0,255,1,1,254,252,1,3,255,254,1,1,254,253,1,2,0,255,1,1,254,253,1,2,0,255,1,1,255,255,255,255,254,254,254,254,254,1,1,1,1,0,0,0,0,1,2,2,2,2,2,2,2,0,0,1,1,1,2,2,2,254,254,255,255,255,0,0,0,253,253,253,253,253,253,253,254,255,255,255,255,254,254,254,254,4,4,4,4,4,3,3,2,253,253,254,255,0,1,2,5,253,253,253,254,255,1,3,6,253,253,254,254,0,2,3,5,253,254,254,254,0,1,3,5,254,254,254,255,255,1,3,5,254,254,255,255,0,1,2,4,255,255,255,255,0,1,1,4,255,255,255,255,0,1,2,3,0,255,0,1,1,0,255,255,0,0,0,1,2,0,255,255,1,0,255,0,1,0,0,0,1,255,254,255,0,0,0,0,1,254,253,255,0,0,0,1,1,255,253,254,0,1,1,2,1,255,254,255,0,1,1,2,2,0,255,0,1,1,2,2,1,1,1,1,0,0,1,2,255,0,0,255,0,0,0,1,253,254,255,255,255,0,1,1,252,254,255,0,0,1,1,1,253,254,0,0,1,1,1,1,253,255,0,1,1,1,0,0,255,0,1,1,1,0,0,255,0,1,2,2,1,0,0,255,252,252,252,253,254,255,255,255,254,254,254,255,0,0,0,0,255,0,0,0,1,1,1,1,0,0,1,1,1,1,1,1,0,0,1,1,2,2,1,0,0,0,1,1,1,1,1,0,0,0,0,1,1,1,1,0,255,0,0,1,1,1,0,0,1,2,2,2,1,255,254,252,1,1,2,2,1,0,254,252,0,1,1,1,1,0,255,253,255,0,1,1,0,0,255,254,255,0,1,1,1,0,0,255,254,255,0,0,0,0,0,255,255,255,0,1,1,0,0,0,255,0,1,1,1,1,1,0,2,2,0,255,254,255,255,254,1,1,255,254,254,255,255,254,1,1,255,254,254,0,0,255,1,1,0,254,255,1,1,0,1,1,0,255,255,1,2,1,1,1,0,255,255,1,2,1,1,1,0,255,255,1,1,1,1,1,0,255,0,1,1,1,0,0,255,254,252,252,252,252,3,3,3,2,1,0,0,0,3,3,3,3,2,2,2,2,0,0,0,0,0,0,0,1,255,255,255,255,255,255,255,0,0,255,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,255,255,0,255,255,1,2,255,1,1,0,0,0,2,3,255,1,1,0,255,255,1,3,255,1,1,0,254,254,0,1,254,1,0,0,254,254,0,1,253,0,0,0,0,255,1,1,253,0,1,1,0,1,2,1,253,255,0,1,1,1,2,1,252,252,253,0,1,1,1,0,0,252,254,0,1,1,1,0,255,253,255,1,1,1,0,255,255,255,1,1,1,1,0,255,0,1,2,2,1,0,255,0,0,2,2,1,0,255,255,0,1,2,1,0,255,254,255,0,1,2,2,0,255,254,255,1,1,1,1,0,0,255,255,255,255,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,255,255,255,255,255,255,1,0,0,255,255,255,255,255,2,1,0,0,255,255,255,255,5,3,2,1,0,0,0,0,6,5,3,2,1,0,0,0,4,4,3,1,0,0,0,1,3,3,2,1,0,0,0,1,2,2,1,0,255,255,0,1,0,0,0,255,255,255,0,1,0,0,255,255,254,255,0,2,0,255,255,254,254,254,0,1,0,255,255,254,254,254,255,0,0,0,255,254,254,254,255,0,0,0,255,255,255,0,2,3,0,255,254,254,255,255,1,2,1,0,255,255,255,0,0,0,1,1,1,0,0,0,255,255,1,2,1,0,0,255,255,255,255,0,0,0,255,255,255,255,253,254,255,255,0,1,1,2,252,253,255,1,2,3,5,5,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,255,0,0,0,1,255,255,254,254,254,255,255,0,0,0,0,0,0,1,1,1,2,2,2,2,2,3,3,3,1,1,1,1,2,2,1,1,252,253,252,252,252,252,253,253,255,0,1,2,2,3,3,3,255,255,255,255,0,0,0,0,0,0,255,254,254,253,253,254,3,2,1,0,255,254,254,254,4,3,2,1,1,0,0,0,2,2,1,1,0,1,1,1,0,255,255,255,255,0,0,1,254,254,254,254,254,255,0,0,1,255,0,2,1,254,255,1,1,255,0,2,1,254,254,1,1,255,0,3,2,254,255,1,0,254,0,3,2,254,254,1,0,254,0,3,2,254,254,1,0,254,0,3,1,254,255,1,0,254,0,2,1,254,254,1,0,255,0,2,1,254,255,1,0,1,2,2,3,3,2,2,0,1,1,2,3,3,2,1,0,0,1,2,2,2,2,1,255,0,0,1,1,1,1,1,255,255,0,0,0,0,0,0,255,255,255,255,255,255,255,255,254,254,254,254,254,254,254,255,254,254,254,254,254,254,254,255,0,0,255,254,255,0,3,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+522240);
/* memory initializer */ allocate([0,0,255,255,255,0,2,4,1,1,0,0,255,255,1,2,1,2,1,1,0,255,255,0,0,1,2,1,0,255,254,254,255,0,1,2,1,0,253,253,254,255,1,2,2,0,254,252,254,255,0,2,2,1,255,253,0,0,0,0,0,0,255,255,0,0,255,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,255,255,255,0,255,255,255,255,255,255,255,0,255,0,0,0,0,255,255,0,0,0,1,1,0,0,0,1,3,3,3,4,3,3,3,3,5,1,254,254,0,0,0,255,4,255,253,255,0,0,0,255,3,255,255,0,1,1,0,255,2,0,0,1,1,1,0,254,1,0,0,1,1,1,0,254,0,255,255,255,0,0,0,255,0,255,255,255,255,0,0,255,2,1,0,0,0,1,0,0,1,0,1,1,1,1,0,0,1,0,0,1,1,0,0,0,1,255,255,0,0,0,0,0,2,0,255,255,255,255,255,0,3,1,255,255,254,254,254,255,4,2,1,0,255,254,254,255,2,1,0,0,255,255,0,0,0,255,255,255,255,0,1,1,0,1,2,2,2,1,255,253,0,0,1,1,1,0,255,254,0,0,0,0,0,0,255,255,0,0,255,0,0,1,1,0,0,0,255,0,1,1,1,1,0,0,0,0,1,1,1,0,0,0,1,1,2,1,255,253,0,0,0,1,1,255,252,251,254,254,254,255,0,2,2,2,0,0,0,0,1,1,1,0,1,1,1,1,1,0,254,253,0,0,1,1,0,255,253,252,255,255,0,1,0,0,254,253,255,255,0,1,1,1,0,255,0,0,0,1,1,1,1,0,1,1,1,1,0,0,0,0,0,1,0,0,1,1,1,2,1,2,0,0,0,0,255,1,0,2,0,255,1,0,255,0,0,1,0,0,2,1,0,1,0,1,255,0,2,2,0,1,255,0,255,255,2,1,1,2,254,254,253,254,0,1,1,1,254,254,253,253,255,255,255,0,253,255,0,1,2,1,1,0,253,255,0,1,2,1,1,1,254,0,0,1,1,1,1,1,255,0,0,0,0,0,0,0,254,0,0,0,0,255,255,0,254,0,0,0,0,0,255,255,253,0,1,1,1,1,0,1,251,254,0,1,2,2,1,2,254,255,255,0,0,1,2,3,0,0,1,1,0,0,1,2,0,0,1,0,255,255,0,1,255,255,255,255,254,254,255,0,254,254,254,254,254,255,0,1,0,0,0,255,0,1,2,2,2,1,0,0,0,1,2,2,2,1,0,255,255,255,0,0,0,1,1,1,1,1,255,252,255,255,0,1,1,1,0,253,254,255,0,0,1,2,2,254,255,0,0,0,0,2,3,255,255,0,0,0,0,1,2,0,0,0,255,254,255,1,1,0,0,0,255,254,254,0,2,1,0,0,255,254,255,1,2,2,1,0,0,0,254,253,254,253,0,0,1,0,254,254,255,255,0,255,1,1,255,255,0,0,0,255,1,1,255,255,0,0,0,1,2,1,255,255,0,1,1,2,3,2,0,0,1,2,255,0,2,1,0,0,2,3,254,255,0,0,255,0,1,2,1,1,0,255,254,254,255,1,1,1,1,255,254,254,0,2,1,1,1,255,255,255,0,2,0,0,0,0,0,0,1,2,255,255,255,0,0,0,1,2,255,254,255,1,1,1,0,0,255,254,255,1,2,2,0,255,255,254,255,2,2,2,0,255,255,255,255,254,255,255,0,1,0,0,255,255,255,0,1,2,1,0,0,0,0,1,1,2,1,1,0,0,1,1,1,1,1,1,0,1,1,0,1,1,1,1,1,1,0,255,255,255,1,2,1,0,255,254,254,253,2,2,1,0,254,253,252,252,252,254,1,1,1,1,0,0,254,0,1,0,0,0,0,0,0,1,1,254,254,255,0,1,2,2,1,254,254,255,1,2,1,2,1,254,254,255,1,2,255,1,1,255,255,255,0,1,254,0,1,1,0,255,255,0,254,0,2,2,1,255,255,0,1,1,0,0,0,1,0,0,254,253,253,254,254,255,0,0,253,252,253,254,255,0,0,0,255,255,0,1,2,3,2,1,0,1,2,3,3,3,2,1,1,1,1,2,1,0,0,255,0,0,0,0,255,255,255,255,0,255,255,0,0,0,0,0,1,1,0,0,255,255,0,2,0,0,1,0,255,255,1,1,254,255,0,1,1,1,1,1,253,253,0,2,2,1,1,0,254,254,0,1,1,1,0,0,1,0,0,0,0,0,255,255,3,1,255,253,254,255,0,1,4,2,255,253,253,255,1,2,0,0,0,255,255,255,255,255,1,2,1,0,0,0,255,255,2,3,3,2,1,0,255,255,3,4,4,2,1,0,255,254,3,3,2,1,0,255,254,254,1,1,0,255,255,254,254,253,0,0,0,255,255,254,254,254,255,255,255,255,255,254,254,255,1,2,2,2,2,1,2,2,0,1,1,1,1,0,0,0,0,0,0,1,1,0,255,254,0,0,0,0,1,0,255,252,1,0,0,0,0,0,254,251,1,0,0,0,0,0,255,252,1,0,255,0,0,0,255,253,0,255,255,0,1,1,1,255,254,255,0,0,255,255,255,254,255,0,0,0,255,255,254,254,0,1,1,0,255,255,255,254,0,1,1,0,0,0,255,255,0,1,0,0,1,1,1,0,1,1,0,0,1,2,2,1,1,1,0,0,1,2,2,1,1,1,0,255,0,1,1,0,4,2,1,0,0,1,1,1,4,2,1,0,0,0,0,1,3,1,0,0,255,255,255,0,1,0,0,255,255,254,255,0,0,0,0,0,255,255,255,0,255,255,0,0,255,255,0,1,254,255,0,255,255,0,0,1,254,254,255,254,255,0,0,1,0,1,1,1,2,1,0,255,255,255,255,0,0,255,254,254,255,0,255,0,0,255,254,255,0,0,0,0,0,0,1,2,0,0,0,0,0,0,2,3,255,0,255,255,255,255,0,3,255,0,0,255,255,254,0,3,0,0,0,0,255,255,1,4,2,2,0,0,0,0,0,1,1,1,255,254,255,254,255,1,255,255,254,254,254,253,254,0,255,0,255,255,255,254,255,1,1,1,0,0,1,0,0,1,2,2,0,0,1,0,0,1,2,2,0,0,0,0,255,255,2,2,0,0,1,0,255,255,255,0,1,1,0,255,255,255,1,2,3,2,1,0,0,0,0,1,1,1,0,255,0,0,254,254,255,0,1,0,0,0,254,254,255,2,2,2,1,0,254,255,0,1,1,0,0,255,255,255,0,0,255,254,255,254,0,1,1,1,0,0,1,1,253,253,253,254,255,255,254,254,255,255,0,1,2,1,0,0,1,1,1,2,2,1,0,0,1,1,1,1,1,0,255,1,1,0,255,255,0,0,255,1,0,255,255,255,0,255,255,1,1,0,255,0,0,255,0,2,2,0,255,0,0,0,0,2,1,0,254,255,0,1,1,0,2,0,255,255,0,1,1,0,1,0,254,255,0,1,0,255,1,0,255,255,0,1,0,255,0,1,1,0,1,1,0,0,254,1,2,1,0,0,0,1,251,0,2,1,0,255,0,1,250,255,2,1,0,255,0,0,5,3,0,255,254,255,255,255,1,1,0,255,255,0,255,255,255,0,1,1,2,2,1,0,254,255,0,1,2,1,1,1,254,255,255,255,0,255,0,1,0,1,0,0,255,255,0,0,0,1,1,1,1,0,0,0,253,254,0,1,1,0,0,255,255,0,1,0,255,0,2,3,255,0,0,254,252,254,255,0,0,1,1,0,254,255,0,255,1,2,3,1,0,1,1,0,255,0,1,1,1,1,1,0,254,253,254,0,0,0,1,0,255,254,254,0,1,0,0,255,3,1,0,0,1,0,255,255,254,255,0,0,255,255,0,0,255,0,0,0,0,1,1,1,255,255,255,0,1,1,1,1,0,254,253,255,1,0,0,0,1,255,253,255,1,1,0,255,3,1,255,1,2,2,0,255,3,1,0,1,2,1,1,0,0,254,254,255,255,0,0,0,1,0,255,255,1,2,1,0,0,255,254,255,1,2,2,1,255,255,255,0,0,1,2,0,254,0,0,0,0,0,1,255,255,0,1,0,255,255,255,255,0,1,1,2,0,254,255,0,1,2,2,2,1,255,255,0,0,1,1,1,0,254,254,255,0,0,255,255,255,255,254,254,0,0,255,0,1,2,2,1,0,0,255,255,0,1,2,2,1,1,255,254,255,255,255,255,2,2,1,0,0,255,254,254,1,2,2,1,0,0,254,254,0,0,0,0,1,1,0,255,0,255,255,255,2,3,2,1,0,254,1,2,255,0,0,1,255,254,2,3,255,0,0,0,0,254,2,3,255,255,0,0,0,255,3,2,254,0,1,0,0,255,3,1,254,0,1,0,0,255,2,1,255,1,0,255,0,0,1,255,254,0,0,255,1,0,0,254,254,255,255,255,1,1,1,1,1,255,255,254,0,0,0,1,1,1,1,1,0,0,0,1,1,1,2,3,1,0,0,255,0,0,1,2,0,255,255,254,255,0,1,2,254,254,254,254,255,0,1,1,255,255,255,255,0,0,0,255,2,2,2,0,255,255,254,252,255,254,255,255,0,1,2,3,255,255,255,255,0,1,2,3,1,0,255,0,255,0,1,2,1,0,0,0,255,0,2,2,1,0,255,255,254,0,1,2,0,254,254,254,253,255,0,1,0,254,254,254,254,255,1,1,0,0,0,0,0,1,2,2,5,6,6,6,7,7,8,8,0,0,0,0,0,1,2,3,253,252,252,251,251,252,253,254,252,252,252,251,252,252,253,253,1,2,2,2,2,3,3,3,2,3,3,4,4,5,5,5,255,0,1,1,2,3,4,4,247,246,247,247,248,249,250,251,252,252,251,250,250,249,249,249,0,255,254,254,253,253,252,252,4,4,3,3,2,1,1,0,7,7,7,6,6,5,4,4,2,4,5,6,4,1,253,250,3,4,5,5,4,0,251,248,2,3,4,4,2,254,249,246,2,2,2,1,0,252,247,244,247,249,253,1,4,4,3,3,246,249,254,3,5,5,3,3,247,250,254,3,6,5,4,3,248,250,255,3,4,4,3,2,251,251,251,251,253,1,4,7,251,251,251,252,254,1,6,8,252,251,252,253,255,3,8,10,253,252,253,254,1,5,9,11,254,254,254,254,254,254,254,254,252,251,251,251,251,251,251,252,253,252,252,252,252,252,252,253,9,10,10,11,11,11,10,10,7,4,1,254,252,250,247,246,9,7,3,0,254,252,248,247,11,8,4,2,0,253,250,248,11,9,5,3,1,254,251,249,243,243,243,244,245,246,248,248,0,1,2,3,4,4,4,3,3,4,5,6,6,6,5,4,3,4,4,4,3,3,3,2,10,10,11,10,9,9,8,7,6,6,6,6,5,4,3,2,0,0,0,255,254,253,252,252,246,246,245,244,243,242,242,242,16,16,17,16,15,13,12,11,255,254,253,252,252,252,252,253,252,251,250,250,250,250,250,250,251,250,250,250,250,250,251,251,243,243,243,244,245,246,248,250,247,248,249,250,252,254,0,1,254,255,1,3,5,7,8,9,5,7,9,11,13,14,15,15,16,14,11,7,2,253,249,247,14,12,8,3,255,250,247,245,11,9,4,0,252,248,245,243,8,5,1,253,250,246,244,242,238,241,247,253,1,6,9,11,239,243,249,255,3,7,11,12,241,245,251,1,5,9,12,13,243,247,253,2,5,9,11,13,22,21,19,15,10,3,252,247,20,18,15,9,2,251,244,239,16,13,8,1,249,242,236,232,10,6,255,248,241,235,231,229,231,233,236,242,249,1,9,14,233,235,240,247,0,9,16,21,236,240,246,255,8,16,22,25,241,245,253,6,14,20,25,27,252,254,0,1,2,2,2,2,251,254,0,2,3,3,3,3,250,252,255,1,2,3,3,3,249,251,254,0,1,1,2,2,2,1,1,1,1,0,254,253,3,3,2,1,0,255,253,252,4,3,2,1,0,254,252,250,5,4,3,1,255,253,251,250,5,6,6,4,2,0,254,253,3,4,4,4,3,1,0,255,254,254,255,255,255,255,254,254,251,252,253,254,254,254,253,253,255,255,255,255,255,255,255,255,253,252,252,252,253,253,253,253,255,255,255,255,255,255,255,254,5,6,6,6,6,5,4,3,4,4,4,4,4,5,6,7,0,255,255,255,255,0,1,2,254,253,253,253,253,254,255,0,253,253,252,252,252,253,254,255,0,254,252,252,254,0,2,3,0,254,253,253,255,2,4,5,255,254,252,253,0,3,5,6,254,253,252,253,255,2,4,5,9,4,0,253,253,255,0,1,8,4,255,252,253,255,1,2,6,2,253,251,252,254,0,1,5,1,253,252,252,254,0,1,5,3,1,255,252,248,246,246,3,3,2,1,0,254,253,252,1,1,1,2,3,2,1,0,255,0,1,2,3,4,3,2,0,1,2,2,1,255,253,253,0,1,1,1,255,254,252,253,253,253,253,253,253,253,255,2,252,252,253,0,3,7,12,14,251,251,250,250,250,250,250,251,2,2,2,1,0,0,0,0,4,4,3,2,1,0,0,0,6,6,5,4,2,2,1,1,249,249,250,253,0,4,7,8,255,254,253,253,254,255,1,2,3,3,1,255,254,254,254,255,6,6,4,2,0,254,254,254,250,251,254,2,5,9,11,12,252,252,254,0,2,4,5,6,253,254,254,254,254,255,0,1,254,254,254,253,253,253,253,254,249,253,1,3,3,0,253,251,250,254,3,5,4,1,253,251,251,255,4,6,5,2,253,252,252,0,5,7,6,3,255,253,0,0,0,0,0,0,0,0,254,254,253,253,253,253,254,255,6,7,8,9,9,8,7,6,252,252,251,251,250,250,251,252,247,248,250,252,0,3,6,6,251,252,255,3,5,6,5,3,1,3,6,6,4,1,254,251,6,7,5,1,253,249,246,245,10,9,5,1,253,250,250,252,5,3,255,251,250,251,254,2,254,252,250,250,252,1,6,10,250,249,249,252,1,7,11,12,6,5,3,2,0,0,0,0,2,1,255,254,253,254,255,255,0,255,254,252,252,254,255,1,0,0,255,254,255,0,2,3,0,255,254,254,254,254,255,255,5,4,2,1,0,0,0,0,6,5,3,1,0,0,0,0,2,0,254,252,252,253,254,254,249,252,0,2,2,2,2,1,249,253,0,0,0,0,0,0,252,255,1,1,0,0,0,1,255,1,2,2,2,2,3,3,254,0,2,2,1,1,1,1,255,1,2,2,1,0,0,255,0,2,4,2,0,255,254,253,1,2,3,1,254,252,250,250,1,2,2,4,5,6,4,1,0,255,255,255,0,0,254,252,0,0,255,254,254,254,252,250,2,1,0,0,1,1,255,253,1,1,1,1,1,2,3,3,0,0,1,0,1,2,4,4,255,255,255,255,0,1,2,3,252,252,251,251,251,253,255,0,250,251,251,252,253,254,255,255,255,0,0,1,1,2,3,3,0,1,1,1,2,2,3,4,0,0,255,255,0,1,2,3,0,1,1,1,0,0,255,255,1,3,3,2,1,255,254,254,254,0,2,2,2,2,1,1,247,248,252,254,1,3,3,3,255,255,255,254,253,253,253,252,0,0,0,255,254,254,253,253,2,2,2,0,255,255,255,255,5,5,4,3,2,2,2,2,6,3,255,252,253,255,1,1,2,255,253,252,255,2,2,0,255,254,254,1,4,4,1,253,254,255,1,4,6,3,253,248,3,3,2,1,255,254,254,254,252,252,254,255,1,3,4,4,252,251,251,252,254,0,2,2,7,7,4,1,255,254,253,254,255,1,3,0,252,250,0,6,254,1,4,1,252,250,255,7,253,1,4,2,253,250,255,6,254,0,3,2,254,251,255,4,1,255,254,1,4,4,255,249,1,255,252,255,5,6,0,250,3,0,252,253,3,6,2,252,3,0,251,252,1,4,1,253,2,2,3,3,3,3,2,2,252,251,250,249,249,249,249,250,1,2,3,3,3,3,2,2,0,0,1,1,1,2,2,1,3,253,253,3,4,254,254,2,3,252,252,4,4,252,252,2,4,252,252,4,4,252,253,3,3,253,252,3,3,253,253,3,254,254,254,254,254,254,255,255,6,7,8,8,8,7,6,5,251,250,249,249,248,249,250,251,1,1,2,2,2,2,1,1,0,0,0,0,0,255,0,0,255,0,0,0,0,255,0,0,254,253,254,254,254,253,253,253,2,3,5,6,4,2,1,0,8,6,2,0,0,0,0,0,4,1,0,0,0,255,255,255,1,255,0,0,0,255,254,253,254,254,255,0,0,254,252,251,3,1,255,254,253,252,251,251,2,1,0,0,1,1,0,0,0,255,255,0,2,2,2,2,255,254,255,1,2,2,2,2,0,255,254,255,255,255,255,0,255,254,254,255,255,0,0,1,2,1,1,2,2,1,1,0,6,5,3,1,0,254,252,252,253,254,255,0,1,1,0,255,0,1,3,4,5,5,3,1,255,255,255,0,1,0,255,254,254,254,254,255,0,255,254,253,0,255,254,254,255,255,0,2,1,255,254,255,255,255,0,2,1,0,254,254,254,254,1,5,1,255,254,254,254,0,5,10,0,0,0,0,0,255,255,255,255,255,255,0,0,0,1,2,1,2,2,3,4,4,6,5,253,253,253,254,254,253,253,253,1,255,254,254,0,3,5,7,2,0,254,253,254,0,2,3,3,1,254,253,253,254,255,255,3,1,0,255,255,255,255,255,1,3,5,4,2,255,253,252,253,254,1,2,1,0,255,254,251,253,0,2,2,1,0,0,253,255,1,2,2,1,0,0,0,255,255,255,1,2,3,4,253,252,252,253,255,0,0,1,254,253,254,255,1,1,1,1,254,254,0,3,4,4,3,2,252,252,253,254,255,1,2,3,0,1,1,1,255,254,253,253,3,4,5,4,2,255,253,253,254,254,0,2,2,2,1,0,252,0,5,7,4,255,252,252,255,2,4,3,0,253,253,254,2,1,0,255,254,254,0,1,0,0,255,254,254,255,1,2,252,253,254,255,0,1,2,2,10,9,5,0,253,252,253,254,1,255,254,254,255,0,0,0,254,254,255,1,1,1,0,255,251,253,0,3,4,2,0,254,254,255,0,1,1,0,255,255,3,2,255,254,254,255,1,1,7,5,255,251,250,254,2,4,254,3,3,253,252,1,2,254,253,3,4,253,252,2,3,254,253,3,4,253,252,2,3,254,252,2,4,254,253,1,2,255,4,3,255,253,253,255,1,2,252,250,252,0,4,5,4,1,0,2,5,6,2,253,251,252,1,1,255,253,251,254,2,4,255,0,1,2,2,3,3,4,255,0,1,1,0,255,255,255,255,0,1,2,2,1,255,254,253,254,255,0,0,255,254,253,1,1,1,1,0,0,1,2,1,0,255,0,0,1,1,0,1,254,252,255,1,2,1,0,1,252,249,253,1,3,2,1,1,1,1,1,1,1,0,255,1,1,1,0,1,2,2,0,1,1,0,0,0,2,0,253,3,2,0,255,255,254,250,247,0,0,0,1,0,0,1,2,1,0,0,0,255,255,0,2,0,1,1,1,255,253,254,0,249,251,1,6,6,2,255,255,3,1,255,253,252,254,1,4,2,0,254,253,252,253,255,2,2,2,1,1,1,0,0,1,1,1,0,0,0,0,0,1,255,1,1,254,251,250,252,255,255,1,4,3,2,0,1,2,255,0,2,3,1,0,0,1,255,0,1,0,0,255,255,0,0,1,2,2,0,254,255,1,254,255,255,254,255,2,6,8,255,255,254,253,254,0,1,2,255,0,0,255,255,0,255,255,2,1,1,1,1,0,0,0,0,0,1,1,1,255,255,1,255,0,2,2,255,253,254,3,0,2,3,0,251,249,254,4,255,0,0,0,255,254,253,253,255,0,255,254,254,254,254,254,1,1,0,0,1,2,0,255,1,2,1,2,5,6,2,0,254,252,253,0,2,2,0,253,3,1,0,1,2,1,254,253,3,1,0,0,0,0,0,255,1,255,254,254,255,1,3,3,3,2,1,2,4,3,1,254,254,252,252,253,255,0,254,253,1,0,255,255,0,1,0,255,3,2,0,0,0,1,1,0,1,1,0,0,0,0,0,0,2,3,3,2,2,2,1,1,0,255,254,253,251,251,251,252,1,1,0,255,0,1,3,3,247,250,254,0,1,1,2,2,250,254,1,2,1,1,0,1,254,1,2,2,1,1,1,1,0,2,2,1,0,1,1,1,1,0,0,0,0,0,255,0,0,0,0,0,255,253,254,0,253,253,253,254,255,3,7,9,1,2,2,2,0,254,252,253,2,0,254,255,3,4,255,250,1,0,254,253,255,3,3,0,0,3,3,0,254,255,1,1,250,255,3,2,255,254,0,1,5,3,0,254,253,0,2,1,1,1,2,2,0,254,252,249,253,254,1,2,2,1,255,252,2,2,0,254,254,0,2,2,0,0,254,253,254,255,0,0,0,0,0,0,0,0,2,2,254,255,0,1,0,1,2,3,252,254,0,0,255,0,2,3,254,254,254,255,255,0,2,4,0,0,0,0,255,255,0,1,0,255,255,255,255,255,0,0,6,4,2,0,255,254,255,255,0,1,1,1,1,255,251,246,1,1,1,1,1,1,0,252,1,0,1,1,1,1,1,255,2,1,1,1,0,0,0,0,253,1,4,3,3,1,255,0,252,0,1,0,255,0,0,0,251,0,2,1,1,1,0,255,255,2,1,254,254,255,0,255,2,4,5,3,0,255,1,2,0,0,1,0,254,254,255,255,254,254,254,254,253,254,255,0,0,0,1,0,0,0,1,2,0,254,254,253,255,2,2,255,1,0,0,0,1,5,3,254,255,255,0,255,0,2,0,251,255,0,1,0,0,2,2,254,3,1,255,255,0,1,1,2,1,0,0,1,1,1,1,1,246,248,254,1,2,1,1,1,255,1,2,1,0,0,0,0,255,255,0,1,2,2,2,1,255,255,255,0,255,253,251,252,1,1,2,1,1,0,0,2,255,254,255,255,255,0,2,4,253,249,251,0,2,0,0,0,3,255,254,1,2,1,1,2,1,254,255,1,2,1,0,1,0,255,0,3,2,255,255,255,2,1,1,0,0,0,0,0,247,249,254,3,3,2,1,1,3,2,0,254,254,255,1,1,0,255,0,0,1,1,0,0,254,255,1,1,1,0,0,0,1,2,1,254,252,253,1,2,1,2,1,254,253,0,3,1,255,255,0,0,1,3,0,252,2,0,255,1,2,254,254,3,2,0,255,2,3,254,252,1,0,1,1,1,2,254,250,254,255,0,0,0,2,0,254,255,255,255,1,2,1,254,253,254,3,255,254,255,255,0,1,2,10,4,0,0,255,254,254,255,3,255,254,255,0,255,255,0,251,2,7,1,252,254,1,0,254,2,3,255,253,0,2,0,2,1,0,0,1,1,255,254,1,254,254,255,255,254,0,0,0,3,254,249,255,3,0,0,1,3,253,251,2,3,255,0,0,2,254,254,4,2,254,0,255,1,255,0,2,255,254,1,4,0,253,252,254,1,2,1,0,0,3,5,3,1,255,254,1,1,1,255,253,255,1,1,1,255,254,254,0,0,255,254,245,253,3,6,246,255,5,7,247,255,6,7,247,255,4,6,5,7,0,242,6,9,2,241,6,9,2,241,4,6,0,242,16,3,251,250,16,1,248,248,14,255,247,247,12,0,248,248,8,12,16,17,254,2,6,9,246,248,252,0,241,242,245,249,249,246,254,16,249,245,253,18,249,245,255,20,250,248,1,19,247,243,240,239,2,254,249,247,11,8,4,255,16,15,11,7,234,254,13,15,232,254,14,16,231,252,13,15,231,250,10,13,26,26,22,16,17,15,9,3,254,250,245,242,236,231,228,228,229,229,231,235,240,241,245,249,3,8,12,13,23,28,31,30,20,16,249,223,22,19,250,221,22,19,250,222,20,17,250,224,236,236,2,38,235,234,2,40,235,234,2,40,236,236,3,38,209,252,24,26,206,253,26,27,206,253,26,27,209,252,24,26,45,6,233,229,48,5,231,228,48,5,230,228,44,6,232,229,226,220,246,76,225,219,245,78,225,219,245,78,225,220,246,77,203,224,35,52,202,222,36,52,202,222,36,52,203,223,34,51,163,222,62,65,163,222,62,66,163,222,62,65,163,222,60,64,249,0,2,2,248,255,3,3,248,0,4,5,250,1,5,5,3,7,11,11,2,2,3,3,1,254,250,249,1,251,245,243,3,254,252,253,7,0,251,251,12,4,251,249,14,6,252,249,18,14,3,254,6,4,0,253,248,251,254,0,240,245,254,2,248,250,7,18,249,248,2,13,252,250,254,6,0,252,253,1,1,253,243,238,0,255,251,249,255,1,6,7,254,4,15,17,241,242,249,254,250,251,255,0,6,6,3,1,15,13,6,1,2,254,245,10,2,255,244,11,3,255,244,11,2,254,245,11,247,14,255,251,247,15,254,251,248,16,254,251,249,15,255,252,2,6,8,8,254,3,9,12,245,251,4,10,237,240,248,0,14,8,249,241,12,7,249,242,8,5,252,247,5,3,255,252,12,242,254,2,13,241,255,3,14,241,255,3,13,242,255,3,0,6,10,243,0,6,10,241,0,7,9,239,1,6,8,240,248,251,15,254,248,250,17,254,248,250,16,253,248,251,15,254,247,245,245,246,9,10,9,8,8,10,10,9,248,247,248,249,9,10,9,7,248,246,246,246,249,246,245,245,11,12,11,8,0,10,7,0,0,7,0,250,0,2,251,250,254,255,252,255,5,0,250,247,2,2,2,1,254,0,5,7,250,251,1,4,3,248,2,255,4,247,3,0,5,249,3,0,7,251,3,0,251,253,2,9,250,253,1,8,250,253,1,7,251,254,0,4,13,8,3,1,253,251,252,255,248,249,253,0,255,1,3,2,3,2,251,244,4,3,254,247,3,4,1,252,3,5,4,255,247,248,252,0,8,6,2,0,10,8,3,0,250,251,253,255,253,247,244,251,0,253,251,0,2,3,2,4,5,8,7,6,255,254,5,12,255,255,5,9,2,1,255,254,2,255,245,239,249,3,3,255,247,3,4,255,246,4,6,255,247,5,7,0,238,249,2,2,248,1,5,3,3,4,1,0,9,5,254,253,254,0,6,8,252,251,251,253,1,254,250,248,10,9,3,255,0,254,254,0,0,252,251,0,254,248,252,8,251,249,6,24,9,1,249,1,9,1,248,1,8,0,246,1,8,255,245,255,8,8,6,3,5,4,3,2,254,253,255,0,246,243,248,252,0,4,2,253,0,6,3,251,3,10,2,244,5,10,252,234,0,252,255,3,1,252,255,5,1,251,0,8,255,250,254,7,255,255,254,252,255,254,252,250,255,255,255,254,1,5,10,9,10,3,0,254,6,255,254,251,3,255,254,250,2,0,0,251,6,3,0,0,6,3,1,1,4,254,254,1,0,247,247,254,245,253,1,2,250,2,4,5,253,2,3,4,254,1,1,2,250,252,255,254,2,255,255,254,10,2,254,254,11,2,252,255,6,0,254,2,3,3,0,0,250,3,3,0,239,255,5,0,255,4,10,11,253,254,0,1,253,252,251,253,255,254,254,255,2,253,247,244,3,3,3,2,2,2,4,4,2,1,255,254,254,9,5,246,253,5,5,251,254,1,2,0,255,254,254,1,254,253,7,254,255,253,7,253,255,254,8,252,254,254,7,253,1,248,253,12,2,254,254,4,1,3,0,251,255,5,2,249,255,3,1,251,249,254,3,1,254,249,254,2,20,3,251,255,5,0,253,254,249,249,0,6,250,0,7,6,2,6,0,249,254,6,249,1,254,7,248,3,254,7,249,3,255,7,250,2,251,254,5,7,4,1,252,248,6,3,254,251,249,251,3,7,255,255,6,5,0,255,1,252,2,1,0,249,1,0,0,252,248,0,3,1,254,1,255,255,1,255,253,1,1,254,1,9,5,2,253,252,255,0,255,253,253,1,3,1,252,0,4,2,2,254,254,12,0,254,251,3,255,0,253,1,253,255,254,1,1,5,3,0,250,252,254,1,0,254,254,2,6,1,252,255,253,251,251,255,3,5,5,4,0,3,1,255,254,1,254,253,2,252,251,253,4,254,253,254,6,0,255,255,7,1,0,0,253,254,254,0,254,253,251,255,254,2,0,255,255,11,9,255,0,1,255,246,255,1,0,250,1,0,1,4,2,251,255,13,254,4,5,0,251,1,6,3,250,254,3,2,251,254,0,254,255,1,1,254,255,254,0,2,5,5,5,7,0,252,248,249,0,2,255,251,255,2,2,253,0,5,3,251,3,8,2,244,8,4,0,254,10,255,252,255,3,250,253,0,252,251,0,0,0,246,252,2,255,250,3,5,255,253,6,4,0,254,4,2,0,8,1,255,0,11,1,253,255,6,254,252,253,254,249,252,0,255,255,255,4,5,6,5,251,247,248,251,2,2,3,2,0,2,6,1,2,0,3,0,1,254,255,254,0,255,253,250,0,0,2,0,4,0,2,1,5,254,0,0,254,247,255,2,0,1,0,246,255,1,8,0,255,254,4,0,1,255,2,255,253,254,2,255,253,255,2,253,0,255,1,0,8,1,255,3,0,1,1,2,0,252,254,0,255,251,1,255,254,255,11,2,1,5,254,254,0,2,252,0,254,1,251,1,0,5,0,1,251,253,0,6,252,2,0,0,253,5,1,0,253,3,0,0,3,254,253,1,1,252,0,8,254,253,254,3,1,2,255,255,1,1,0,2,2,0,1,6,1,255,2,1,0,3,0,237,1,253,254,2,6,5,254,249,253,1,3,1,255,255,0,2,248,255,255,252,1,1,255,2,4,3,2,3,251,1,3,0,0,2,255,1,253,0,0,5,251,254,0,8,252,252,252,6,1,2,1,2,2,2,253,2,4,0,247,0,7,0,245,1,0,0,0,254,3,3,255,250,4,3,253,246,255,2,6,2,7,254,253,5,252,0,3,255,252,2,1,249,2,255,255,3,3,2,2,2,251,249,249,251,5,6,4,2,254,255,0,1,12,13,13,11,249,246,241,239,240,241,244,246,11,15,15,12,2,17,20,15,211,232,2,13,21,20,250,220,12,16,255,229,238,235,10,45,245,236,249,21,43,248,228,0,33,240,228,3,244,238,238,250,236,246,28,55,251,238,235,238,56,30,250,236,222,27,29,234,226,29,26,231,30,34,33,26,231,225,221,223,225,221,220,224,29,36,37,31,185,244,38,34,193,255,42,33,58,37,225,196,55,34,223,195,199,199,22,93,199,198,21,93,59,69,70,62,193,188,188,196,192,185,185,192,63,73,72,62,254,0,7,15,245,246,253,5,251,248,246,246,1,9,14,9,15,8,252,245,12,2,245,244,248,0,19,28,4,255,241,230,241,27,2,242,242,22,1,247,252,250,243,246,250,242,6,47,221,236,6,23,6,9,6,4,250,2,23,234,249,4,28,235,20,234,254,6,22,228,251,8,246,238,240,244,36,19,2,255,253,0,4,8,211,246,23,23,40,15,236,221,252,255,4,1,9,251,223,24,8,3,230,19,255,4,6,253,32,25,243,207,24,24,15,7,239,229,237,249,209,0,39,24,235,250,7,4,255,0,246,243,1,1,5,16,20,5,253,247,255,252,254,250,239,249,1,4,12,7,0,0,3,0,12,11,253,1,0,233,4,17,250,0,6,3,231,0,239,10,8,5,242,4,1,4,13,10,4,2,233,247,1,2,3,253,1,7,1,233,249,20,249,238,2,12,251,252,10,9,4,10,7,232,6,3,4,246,22,242,234,6,0,5,5,255,252,3,245,252,249,31,7,242,251,240,255,42,252,254,247,251,5,248,250,253,42,252,235,251,238,12,20,244,13,243,246,7,248,247,254,238,240,6,40,8,10,255,0,4,253,4,255,243,254,6,1,241,5,3,1,2,252,254,1,3,15,0,247,252,253,252,252,252,253,5,16,253,2,13,3,4,253,248,246,0,250,254,252,255,254,253,250,23,6,250,7,1,4,238,5,1,255,1,241,14,251,6,252,4,2,2,2,6,232,2,7,3,230,0,3,3,5,7,1,6,14,254,238,253,7,5,252,2,250,3,32,1,250,250,250,244,5,220,7,6,9,255,11,0,4,4,5,3,4,15,3,218,10,23,251,214,0,4,4,4,23,17,250,243,243,219,1,29,5,242,255,1,5,0,3,1,0,4,251,2,8,0,0,246,4,7,254,253,246,3,1,1,244,255,13,3,0,255,1,253,0,255,3,1,250,247,3,9,250,1,252,250,8,255,0,8,253,253,0,18,251,255,252,255,248,254,3,252,0,17,255,251,5,254,9,246,1,251,6,251,4,2,2,3,10,242,248,1,255,254,238,255,255,20,1,2,255,1,247,1,255,247,22,252,6,252,8,253,255,7,237,5,249,31,252,252,250,0,251,251,249,248,237,252,1,1,4,32,38,255,248,4,249,248,250,244,255,0,249,1,255,9,255,0,9,255,255,0,2,250,1,253,244,0,2,1,1,1,8,0,9,1,0,2,254,1,245,0,0,8,2,246,255,2,255,0,254,252,0,251,254,255,255,14,253,7,255,5,0,246,1,1,255,251,14,255,254,1,253,254,250,0,0,6,2,3,247,4,4,251,255,255,249,3,8,255,2,252,255,245,11,2,1,0,255,2,3,9,0,2,0,241,3,5,236,3,3,255,3,3,1,255,16,1,2,227,9,2,243,250,255,253,36,255,248,253,2,5,4,2,219,9,11,3,255,1,254,0,1,255,255,255,254,255,1,255,255,0,255,255,0,255,255,255,255,0,255,0,0,0,253,1,255,0,1,255,1,255,2,2,1,1,2,0,0,0,255,1,1,0,0,0,1,255,0,1,255,1,1,0,1,0,255,1,1,0,0,0,254,0,0,254,0,0,254,0,254,255,254,255,0,0,255,0,1,0,1,255,2,2,1,2,2,1,0,1,1,0,1,1,254,1,255,255,1,0,1,255,255,255,1,255,0,255,0,255,0,0,0,254,0,1,0,255,255,0,2,253,1,254,3,255,2,0,2,1,1,255,1,1,0,0,1,1,2,254,1,0,254,255,2,254,254,0,253,0,255,0,255,0,255,0,254,253,1,254,254,255,1,255,255,1,255,1,1,0,254,0,1,1,1,1,2,1,0,0,255,0,0,1,0,1,255,1,0,2,0,0,0,253,1,1,1,253,0,255,0,253,1,253,0,254,1,2,255,253,0,253,1,255,0,255,0,0,1,2,1,1,255,2,253,3,1,0,251,1,0,255,253,1,0,2,0,253,4,2,0,254,1,254,3,254,1,1,0,255,2,5,3,1,255,0,2,253,254,0,0,254,2,253,255,255,2,1,0,254,3,255,1,255,2,4,0,1,0,1,0,255,253,254,255,0,0,2,255,255,2,252,254,3,0,255,251,1,0,1,0,6,254,2,0,1,1,255,255,254,1,254,255,0,2,254,254,255,252,2,255,253,255,254,2,255,2,255,2,0,3,253,253,0,253,0,0,254,4,252,0,255,4,0,254,254,3,254,0,4,5,0,1,0,253,3,3,2,0,0,1,2,251,254,253,0,253,2,254,2,254,4,7,253,4,2,3,2,255,0,253,1,252,253,4,5,2,1,1,0,251,253,5,5,2,1,0,0,250,252,5,5,2,1,0,0,249,252,4,5,2,1,0,0,248,251,3,4,2,1,0,0,248,250,3,4,1,1,1,0,248,250,2,4,2,1,1,0,248,250,2,4,1,1,1,1,255,255,255,255,255,255,255,255,255,254,254,254,254,254,254,254,254,253,253,253,253,253,253,253,254,253,253,253,253,253,252,253,254,254,254,254,254,253,253,254,1,1,1,1,1,0,255,255,4,5,5,5,4,3,3,2,7,7,8,8,8,7,6,5,2,1,2,4,4,0,252,250,1,1,2,5,5,1,251,249,1,2,1,4,5,1,251,248,1,1,1,5,5,0,250,248,0,1,1,5,6,1,250,247,0,0,1,4,5,0,251,248,0,0,1,4,5,0,251,249,0,0,1,4,4,1,252,249,1,2,3,0,253,252,253,255,1,3,4,0,253,252,253,255,2,4,5,1,253,252,253,254,2,5,6,1,253,251,252,254,3,6,6,1,253,251,252,254,3,6,6,1,253,251,252,254,3,6,6,1,253,251,252,254,3,5,5,1,253,252,252,254,2,2,2,2,1,0,0,255,4,4,4,3,2,1,1,0,4,5,4,4,3,3,2,1,4,4,4,4,4,3,2,2,2,3,3,3,3,3,2,1,255,255,255,255,0,0,0,0,251,250,250,251,251,252,253,253,249,247,247,248,249,250,250,251,6,6,6,6,6,5,5,4,4,4,4,3,3,3,3,2,0,255,255,255,254,254,255,255,253,251,250,250,250,250,251,252,253,251,250,249,250,250,251,252,255,254,254,254,254,254,255,255,0,1,1,1,1,1,1,1,3,3,3,3,3,3,3,3,2,1,254,251,252,0,2,5,2,1,254,250,251,0,3,5,2,1,254,250,250,255,3,6,3,2,254,249,250,0,4,7,2,1,254,249,251,0,5,7,2,1,254,250,251,0,4,7,2,1,254,250,252,0,4,6,1,1,254,251,252,0,3,6,246,247,250,252,255,2,3,2,246,247,251,253,0,4,4,3,247,249,253,255,2,5,5,3,249,251,254,0,3,5,5,3,250,253,0,1,4,6,5,3,252,254,1,2,3,5,4,2,254,0,1,2,2,4,3,1,255,1,2,2,2,3,3,1,252,251,251,250,250,250,250,251,253,253,252,252,252,252,252,252,0,0,0,0,255,255,255,255,5,5,6,5,5,4,3,2,5,6,7,7,7,6,5,4,3,3,4,4,4,4,3,2,0,255,0,0,255,255,0,255,253,253,252,252,252,252,253,253,1,254,251,1,5,4,2,0,1,253,250,1,6,5,2,0,0,252,249,0,6,6,2,1,255,251,247,255,6,6,3,1,255,250,246,254,6,6,3,1,255,250,247,254,5,6,3,1,254,250,247,254,5,5,3,1,254,250,249,254,4,4,2,1,251,249,248,247,247,248,249,250,251,250,250,249,249,250,250,251,253,253,253,252,251,251,252,252,255,0,0,255,255,255,255,255,0,1,2,2,2,2,2,1,2,3,4,5,5,5,5,4,3,4,5,6,8,8,8,7,3,4,5,6,7,7,7,6,5,6,7,8,9,10,10,9,3,4,6,7,8,9,9,8,0,1,2,3,4,5,5,5,255,254,255,255,0,1,2,2,254,253,253,253,253,254,255,0,253,252,251,251,251,251,251,252,252,251,251,250,249,249,250,251,253,252,251,250,249,249,250,250,13,7,0,253,253,252,252,251,14,7,0,253,253,252,252,252,15,8,255,252,252,252,251,252,15,8,255,252,252,251,252,253,15,7,255,252,251,251,251,252,14,7,255,252,252,252,252,253,12,6,255,252,252,252,252,253,11,5,255,252,252,252,252,253,239,252,5,4,4,4,3,3,238,251,5,4,4,4,3,3,237,251,6,4,4,4,3,2,236,251,6,4,4,4,3,3,236,252,6,4,4,5,3,3,237,251,6,4,4,5,3,3,238,252,5,4,4,4,3,2,239,251,4,3,4,4,3,3,250,250,250,252,254,1,6,11,250,249,249,252,254,2,8,13,248,248,249,252,254,3,9,14,248,248,249,251,255,4,10,16,248,248,249,251,255,4,10,17,248,248,249,252,0,5,10,16,248,248,250,253,0,4,9,15,249,249,251,253,0,4,8,12,8,7,7,5,2,254,248,242,8,8,7,5,2,254,248,241,8,8,7,5,1,253,247,240,8,8,7,5,1,253,246,239,8,9,8,5,1,253,246,239,8,8,7,4,1,252,246,240,7,7,7,4,1,253,247,242,6,7,6,3,0,253,247,243,5,1,252,252,253,255,0,0,7,2,253,253,254,255,1,0,7,1,253,253,255,0,1,1,6,1,253,254,255,1,1,0,6,0,252,254,255,0,1,0,5,0,252,253,255,0,0,255,5,0,253,255,0,0,0,254,4,1,254,255,0,1,0,255,2,2,1,1,254,250,248,248,1,1,1,1,254,251,248,248,1,1,1,0,255,253,251,251,0,0,0,0,255,255,255,254,0,255,0,0,0,0,1,0,1,0,0,0,1,2,3,2,2,1,1,1,2,3,4,3,3,3,3,3,4,4,5,4,252,252,253,254,0,0,1,1,252,252,253,254,255,0,0,1,254,254,254,255,255,255,0,0,0,1,0,0,0,0,0,255,2,2,2,2,2,2,1,1,3,4,4,4,4,4,4,3,1,1,1,3,3,4,3,3,251,250,251,252,253,253,254,254,252,254,255,255,255,255,0,1,252,254,255,255,255,255,0,1,253,254,255,255,255,0,1,2,252,253,254,255,255,1,3,3,252,253,253,255,255,1,4,5,252,253,254,254,255,1,4,7,254,254,255,255,0,2,6,8,255,0,0,1,1,4,7,8,253,253,253,254,254,255,255,0,255,255,0,1,2,2,3,3,0,1,2,4,5,6,6,5,255,0,2,3,5,6,5,3,255,255,0,2,3,3,2,1,254,254,255,0,255,253,252,252,0,0,255,255,254,252,248,249,1,2,1,0,255,252,250,249,254,4,1,250,0,3,0,0,254,5,1,249,0,3,0,0,253,5,1,248,0,3,255,255,254,6,1,247,0,3,0,255,254,6,2,248,0,4,0,255,253,5,1,249,1,4,0,0,254,4,1,249,0,4,1,0,255,4,1,250,0,3,1,0,0,0,0,3,4,5,4,1,1,1,1,2,3,3,2,0,2,2,1,2,2,1,255,254,4,3,1,1,0,255,253,251,5,3,1,255,254,253,252,250,5,3,0,254,253,251,250,249,4,3,0,254,253,252,251,251,4,3,0,255,254,254,253,253,0,0,0,0,255,251,254,6,0,0,0,1,255,250,254,8,0,0,0,2,0,250,253,9,0,255,0,2,0,249,254,10,0,255,0,2,255,248,253,10,0,255,255,2,255,249,253,9,0,255,0,1,255,250,253,8,0,0,0,1,0,251,254,7,2,3,3,2,1,0,255,255,3,4,3,2,1,0,255,254,3,4,4,2,1,255,254,253,2,3,3,2,0,255,254,253,255,0,1,1,0,255,254,254,251,252,253,255,0,1,1,1,248,248,251,255,1,3,4,3,246,247,251,0,3,5,6,5,251,255,4,5,3,1,0,0,250,255,4,5,2,0,255,254,250,255,5,4,2,255,254,254,249,255,4,4,1,254,253,253,250,255,5,4,1,254,253,253,251,0,4,4,1,255,254,254,252,0,5,4,1,255,255,254,253,1,4,3,1,255,255,254,254,253,254,1,4,6,5,3,253,252,252,0,3,5,4,2,253,251,251,255,2,4,3,1,252,250,252,255,2,4,2,255,254,252,253,1,2,4,2,255,254,252,254,1,3,3,1,254,254,253,254,1,3,3,1,254,254,254,255,1,3,3,0,254,252,252,253,254,255,2,5,7,252,252,253,253,254,1,5,7,254,253,254,253,253,255,3,5,255,255,0,254,253,254,2,4,1,1,1,255,252,253,1,3,4,3,2,255,252,253,255,1,6,4,3,0,253,253,254,0,6,5,3,1,254,253,254,255,12,11,8,4,0,254,254,255,10,9,6,2,255,254,255,0,4,3,2,0,255,255,0,1,255,255,255,255,254,0,1,2,253,251,252,254,254,0,2,3,251,251,252,254,255,0,1,2,251,251,252,254,255,0,1,1,252,252,253,254,254,255,0,0,3,3,2,255,253,252,253,254,3,2,0,254,252,252,253,254,2,2,1,255,253,251,252,253,3,3,3,1,254,253,253,253,4,4,4,3,0,254,254,254,5,5,5,3,0,255,254,254,5,5,4,2,255,254,253,254,3,3,3,0,254,252,252,252,255,255,4,254,254,6,2,251,255,0,4,254,253,6,2,250,255,0,4,254,253,7,3,249,255,255,4,253,252,8,3,249,0,255,4,253,252,7,3,250,255,255,4,253,252,7,3,250,255,255,3,253,252,6,3,250,255,0,3,254,253,6,3,251,1,254,249,2,5,254,255,1,1,254,248,3,6,253,255,2,2,254,247,4,7,252,254,2,3,255,247,5,7,252,255,3,3,255,247,4,7,252,254,2,3,255,249,4,6,252,254,1,2,0,250,4,6,252,255,1,2,0,251,3,4,253,255,1,254,2,2,0,0,255,253,252,254,2,2,1,1,0,254,252,254,2,2,2,2,1,255,254,253,2,3,3,4,2,0,254,253,2,3,2,4,2,0,253,252,1,2,1,2,1,255,253,251,0,1,0,1,1,254,253,252,0,0,0,1,0,254,253,0,0,255,254,254,2,7,8,0,0,255,253,254,1,6,7,0,1,255,253,253,0,4,5,0,1,0,255,255,0,1,3,0,2,1,1,0,255,0,1,254,0,1,2,1,0,255,255,251,254,0,1,1,0,253,253,250,252,255,1,1,255,253,252,252,254,2,5,6,4,3,2,251,253,1,4,4,2,0,0,252,254,0,2,1,255,254,254,254,255,0,1,0,254,253,254,254,0,0,0,255,255,254,255,254,255,255,0,0,0,1,2,254,254,255,255,0,1,3,4,254,253,254,255,0,2,4,5,2,1,254,254,255,0,1,0,1,0,253,253,255,0,1,0,0,255,253,253,255,1,1,1,0,0,253,255,1,2,3,3,0,255,253,255,1,3,3,3,254,254,252,254,1,3,4,4,253,253,252,254,1,3,3,4,254,253,251,254,1,2,3,3,4,5,3,4,4,4,4,5,3,3,1,0,0,0,0,1,1,1,255,254,253,252,253,254,2,2,0,254,254,252,253,254,2,3,1,255,255,253,253,254,1,2,0,0,255,254,254,255,0,1,0,255,255,253,254,255,1,1,0,255,255,254,254,254,254,255,255,0,1,2,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+532480);
/* memory initializer */ allocate([1,2,3,5,6,5,5,3,1,2,3,4,5,5,4,3,254,254,253,253,254,255,0,0,253,253,252,251,252,253,254,255,255,255,254,254,254,255,0,0,0,1,0,255,255,0,0,1,255,0,255,254,253,254,254,255,7,7,6,5,4,2,255,254,3,3,2,2,1,0,254,253,0,255,255,255,0,255,254,254,255,253,254,255,0,0,0,1,0,254,254,255,255,1,2,2,3,1,255,255,255,1,2,2,3,1,254,253,254,255,1,2,1,254,251,250,251,253,254,0,0,255,254,253,255,0,254,254,0,0,255,255,0,1,255,254,0,0,254,255,0,0,0,254,255,254,253,253,254,255,253,253,255,254,253,253,254,254,253,252,2,2,0,0,0,0,255,254,5,5,3,2,2,2,0,255,8,8,6,5,4,4,2,1,249,248,250,253,255,255,254,255,251,251,253,0,2,1,0,0,255,255,0,3,4,3,1,1,2,1,1,3,4,3,2,2,3,2,0,2,3,2,1,2,4,2,255,255,0,1,1,1,3,2,254,253,254,255,0,1,3,1,253,252,253,254,0,1,252,254,255,2,3,3,1,0,249,251,252,254,0,0,255,254,250,251,251,252,254,254,254,253,255,0,255,255,0,0,0,255,2,3,2,2,2,2,1,0,3,5,4,3,1,0,1,0,3,4,3,2,0,255,255,255,5,5,3,1,0,255,255,255,1,1,0,255,253,251,250,252,1,1,0,0,0,253,253,255,0,255,255,0,1,0,1,3,254,254,253,255,2,2,4,7,254,254,254,0,2,2,3,6,255,0,0,1,1,0,0,3,0,3,3,3,1,254,253,255,1,3,4,3,0,253,251,252,0,2,0,255,253,252,254,254,1,4,2,0,254,253,254,255,3,6,3,1,254,254,0,255,4,7,4,1,254,253,255,0,3,6,3,0,253,253,255,0,1,3,0,255,253,254,1,1,0,1,255,254,253,255,2,2,254,255,253,253,253,255,1,2,3,1,255,0,1,0,0,0,2,255,254,255,1,0,255,255,1,255,254,0,1,0,254,253,0,254,255,1,3,1,253,251,0,254,255,2,5,2,253,251,0,254,255,4,6,3,254,251,0,254,0,4,7,4,254,252,0,254,0,4,6,4,254,252,254,254,253,252,253,254,255,0,1,1,0,255,255,255,0,1,3,3,2,2,1,1,1,1,2,2,2,2,1,0,0,1,0,0,0,0,255,255,255,255,252,252,252,252,252,252,252,253,253,253,254,253,254,255,255,0,3,4,4,5,5,6,6,7,255,254,7,254,252,255,255,0,255,254,9,255,252,255,255,0,255,253,10,255,252,255,255,1,255,253,10,254,253,255,255,2,255,254,10,254,252,255,255,2,255,254,9,254,252,255,255,2,255,254,8,254,252,0,255,1,0,254,7,254,253,255,0,2,3,252,1,3,253,254,1,0,3,251,1,4,253,254,1,0,3,250,2,5,253,255,3,0,3,250,2,5,253,255,2,0,3,250,1,5,252,254,3,0,3,250,1,5,253,254,2,0,2,250,1,4,253,255,1,0,2,250,1,4,254,255,1,0,0,0,1,1,1,0,0,2,0,255,1,1,1,0,0,2,0,255,0,0,0,0,0,2,0,255,0,0,0,0,255,0,1,0,1,0,0,255,254,255,3,1,1,0,0,254,252,253,5,3,2,1,0,253,251,252,5,4,2,0,255,252,251,251,1,0,255,254,254,253,250,247,2,0,255,255,0,0,253,250,1,0,0,255,0,0,254,251,2,1,1,1,1,2,255,253,1,1,2,1,2,2,1,255,1,1,2,1,1,1,1,1,0,0,2,1,0,0,2,2,0,1,2,2,0,0,2,2,252,253,0,1,4,6,4,3,253,254,0,0,2,4,1,0,255,255,0,0,1,1,254,253,1,1,1,0,1,1,253,251,1,1,1,0,1,1,253,251,255,0,0,255,1,1,254,252,255,0,0,255,1,2,0,254,255,0,0,0,2,3,1,0,255,0,3,4,0,252,251,251,0,0,4,5,2,254,253,254,0,255,2,4,2,255,255,0,0,254,255,1,0,254,0,1,1,254,254,0,0,255,255,1,1,254,253,0,1,0,255,0,1,254,254,1,3,1,0,0,1,254,255,2,4,2,0,0,1,2,3,2,0,2,2,1,255,0,1,0,253,1,1,1,255,0,0,254,252,0,2,1,255,2,2,255,251,0,2,1,255,3,4,255,251,0,2,1,254,2,4,0,252,255,0,0,252,0,2,0,252,254,0,0,251,255,2,1,254,1,3,2,1,0,1,0,1,2,255,254,2,0,255,254,1,3,0,255,3,0,254,252,0,3,1,0,5,1,253,251,254,2,1,1,6,1,254,251,254,1,0,1,5,1,255,251,254,0,255,0,3,0,254,252,254,0,255,0,1,255,0,254,0,1,0,1,1,1,2,3,2,1,1,2,255,255,0,1,1,0,1,1,252,253,0,0,1,1,1,2,252,253,0,2,2,2,3,2,251,252,0,1,1,1,1,2,251,252,255,255,254,254,255,0,253,254,0,0,254,253,254,255,2,3,4,4,2,0,0,0,252,254,0,1,0,0,0,0,253,255,1,1,0,0,0,0,254,0,2,2,0,0,0,2,255,1,2,1,255,0,3,5,0,2,1,255,254,0,5,6,0,1,0,253,253,0,4,6,1,1,254,252,252,253,1,2,1,0,254,252,251,252,254,0,255,253,253,253,253,254,255,255,3,2,1,0,0,1,1,1,5,4,3,2,1,1,2,2,2,1,0,254,254,254,255,255,0,0,0,255,254,254,254,254,0,1,3,3,2,1,255,255,0,1,3,4,3,2,1,255,252,253,255,1,0,254,253,253,253,252,249,248,249,252,255,2,0,255,253,252,252,254,0,2,1,0,0,255,253,254,0,2,2,1,1,0,255,255,0,2,1,1,1,1,0,0,0,1,1,1,1,1,1,1,1,1,0,0,1,2,3,3,2,2,0,0,1,3,4,4,3,2,3,3,3,0,255,0,1,2,1,1,1,255,254,255,255,1,254,254,255,253,253,254,254,0,252,252,254,254,254,254,253,0,252,252,255,1,1,0,255,2,253,255,2,3,4,3,3,5,254,0,2,3,3,3,3,3,254,254,0,0,0,0,0,1,0,2,1,255,253,255,3,254,255,0,255,255,253,0,4,254,254,254,254,254,254,1,5,254,253,254,253,255,254,1,4,253,254,0,255,0,255,0,3,251,1,2,1,2,0,0,2,251,2,4,2,3,1,1,3,253,1,2,1,1,0,1,4,254,4,253,252,255,3,3,1,3,4,252,252,255,3,2,0,2,4,253,252,0,2,2,255,1,4,253,254,1,2,1,254,0,2,252,254,1,2,0,253,0,2,253,254,0,1,0,254,2,3,255,255,0,0,0,0,3,2,254,254,254,255,255,255,2,2,2,3,4,3,1,0,255,1,0,1,2,1,255,254,254,2,1,2,1,1,0,255,255,4,3,4,3,2,1,1,1,3,2,2,2,1,1,1,1,255,254,255,0,255,255,255,255,253,253,254,255,254,254,254,254,252,252,253,253,252,252,253,253,2,1,255,253,252,254,3,4,2,2,1,255,253,254,1,2,1,2,3,3,0,254,255,254,255,0,2,4,2,0,255,253,254,254,0,3,3,2,0,253,0,254,253,255,1,2,2,255,3,255,252,251,253,0,2,0,6,3,254,250,251,0,3,1,254,3,254,0,3,254,254,1,253,4,253,0,3,254,255,2,253,5,253,0,4,254,255,2,254,4,252,255,3,253,254,2,253,4,253,0,3,253,255,2,254,5,254,0,3,253,255,2,254,4,253,1,3,254,255,2,254,3,254,1,3,254,0,2,1,0,0,255,1,2,252,255,2,0,0,255,1,2,252,254,1,1,1,255,2,4,254,0,0,255,1,255,2,5,255,1,0,255,0,254,1,5,255,1,0,255,255,254,0,3,253,255,1,1,0,254,0,3,253,255,1,1,0,253,0,3,254,0,1,0,255,1,1,2,4,5,1,0,255,1,1,1,5,7,0,0,254,255,255,0,3,5,0,255,254,255,255,255,2,3,0,255,253,255,255,255,1,2,255,254,252,254,254,254,0,0,255,254,254,255,254,254,0,0,0,255,255,0,255,255,0,0,3,3,0,255,255,1,4,4,2,3,0,254,254,0,1,1,2,3,1,255,255,0,1,0,1,2,0,255,255,255,0,254,0,1,0,255,254,255,0,254,0,1,0,255,254,255,1,0,1,1,255,253,252,253,1,3,1,2,255,253,251,252,1,3,253,254,0,1,1,1,0,254,0,1,1,1,0,0,255,253,1,2,1,1,0,255,255,254,0,255,253,255,255,255,0,255,0,253,250,253,254,255,1,1,2,255,252,253,254,0,2,2,5,4,1,1,0,1,3,2,5,4,2,1,0,255,0,1,254,0,254,251,250,253,0,0,254,0,1,0,255,1,2,2,254,0,1,3,2,2,2,1,254,0,2,4,3,2,1,1,254,0,2,3,2,0,255,0,253,255,1,1,0,255,255,1,252,255,1,0,255,254,0,2,252,255,0,255,255,254,1,4,253,0,0,255,1,1,1,0,253,1,0,255,0,0,255,255,255,3,3,0,1,0,0,1,253,2,2,254,255,0,0,1,251,0,0,254,255,1,0,2,249,254,1,0,1,2,2,2,251,0,3,2,3,3,2,2,253,2,4,1,0,0,254,253,5,2,254,254,0,255,255,255,2,255,252,253,255,254,255,255,0,254,254,1,2,255,0,1,255,254,255,3,3,255,0,2,1,0,0,3,3,254,255,2,2,1,1,3,2,254,254,0,1,0,255,1,1,253,253,254,1,0,1,2,3,0,0,0,252,251,253,0,1,255,254,255,254,253,255,1,2,0,0,0,1,1,2,1,2,1,1,1,3,4,3,1,0,254,255,255,3,3,2,0,254,253,253,254,1,1,0,255,254,252,254,254,2,1,0,0,0,255,0,1,2,1,1,1,1,1,1,3,0,0,0,255,254,255,1,0,254,255,255,254,253,254,0,0,255,0,0,255,254,0,1,1,1,1,0,255,255,1,3,1,2,2,0,254,255,2,3,0,3,1,255,255,1,4,2,254,2,0,253,255,3,5,0,251,1,255,254,0,3,3,255,250,255,0,3,4,2,0,1,2,254,255,0,1,255,254,0,1,254,253,254,253,250,249,250,253,2,2,3,1,255,254,253,254,2,2,3,1,0,0,0,0,2,1,1,0,1,1,0,1,1,0,0,0,0,1,1,2,1,0,255,0,0,2,2,1,1,1,3,1,255,255,255,1,254,255,0,0,254,254,255,2,254,254,1,1,1,0,1,3,254,254,0,255,0,255,0,2,0,0,1,0,255,255,254,1,3,2,2,1,0,254,254,1,5,3,3,2,1,1,1,4,0,253,252,251,252,253,255,1,250,252,255,2,2,0,0,255,252,254,1,3,3,2,2,0,253,254,255,2,3,3,2,0,253,254,254,1,2,1,1,255,254,254,254,0,2,2,1,255,255,255,255,1,2,3,2,0,255,255,254,1,2,2,2,255,0,255,254,0,2,1,0,255,6,4,2,1,0,0,0,1,4,2,255,254,254,254,255,255,2,1,255,254,254,254,254,255,2,2,0,254,254,254,255,0,0,0,255,254,254,255,0,1,253,253,254,255,255,254,255,0,253,254,2,3,2,0,255,254,254,0,4,5,5,2,0,255,5,4,2,0,255,254,255,255,4,3,2,1,0,255,0,255,1,1,0,1,1,0,1,255,254,255,255,0,0,254,254,253,255,0,0,0,255,253,253,251,0,1,1,255,255,254,254,253,255,255,255,254,255,1,3,1,255,254,254,255,2,5,6,5,253,253,254,1,1,254,255,255,1,2,3,4,1,253,255,253,3,2,0,1,255,253,255,253,1,0,255,0,255,255,1,0,1,1,0,1,2,2,5,3,1,1,1,2,2,2,3,0,253,255,254,254,253,253,255,253,255,1,1,0,255,255,0,254,2,0,254,254,2,4,1,254,1,0,254,255,3,5,2,255,255,254,253,254,1,3,1,254,255,254,255,255,0,2,1,255,0,0,1,1,1,2,2,0,0,1,4,4,2,2,3,1,254,255,2,1,254,253,254,253,255,0,1,0,253,252,252,251,4,0,253,252,252,252,254,255,5,0,255,0,255,253,254,255,4,0,0,1,1,0,0,0,0,253,254,255,0,0,1,0,0,254,0,0,1,1,2,1,2,0,0,0,1,1,1,0,2,0,255,255,1,1,1,0,1,255,254,254,0,2,2,2,253,251,254,0,255,253,253,0,0,254,0,2,2,0,0,3,2,255,254,0,0,255,255,2,5,2,255,255,255,255,255,2,5,2,0,255,255,0,255,2,2,1,0,0,0,1,0,2,255,255,1,1,2,2,1,2,253,254,0,0,0,0,254,255,0,3,2,0,254,253,253,253,0,3,3,1,0,0,1,2,255,0,255,254,255,255,1,3,255,0,255,254,255,255,0,2,255,0,255,254,0,0,255,2,255,0,255,254,255,255,254,1,0,1,0,253,255,255,255,2,5,5,2,255,255,255,1,3,0,0,1,255,253,254,0,2,1,1,3,0,254,254,0,1,1,1,3,1,0,0,255,255,0,255,2,1,1,0,255,253,255,254,1,1,1,0,254,252,255,0,2,1,1,0,255,253,1,1,3,2,1,0,254,253,2,2,4,2,1,255,254,252,1,2,2,2,0,254,0,2,255,255,254,253,252,251,253,1,0,1,1,0,255,255,255,1,0,1,1,1,0,0,0,2,0,1,1,2,1,1,1,2,255,255,0,2,2,2,2,3,254,252,252,255,254,254,254,0,1,0,0,1,0,0,0,1,0,255,253,254,0,2,2,1,0,255,254,253,0,1,1,2,1,0,254,253,255,0,0,1,255,0,255,254,0,0,255,0,255,1,1,0,2,2,0,0,0,2,3,1,3,5,3,2,255,1,1,254,0,3,1,1,255,0,0,252,252,255,255,255,255,1,1,0,1,2,1,2,253,0,1,0,1,1,0,2,251,253,255,255,0,1,0,1,252,253,254,253,254,255,255,0,0,0,255,254,254,254,254,0,3,4,2,0,0,0,0,1,2,1,0,0,0,0,255,0,0,1,2,3,4,4,3,2,255,4,7,4,0,0,0,0,255,4,6,3,0,1,1,1,0,3,4,0,255,0,0,1,0,1,1,254,255,0,255,255,255,0,255,255,255,0,0,0,255,255,255,0,0,0,0,0,255,253,253,0,1,255,254,255,253,252,252,254,255,254,254,255,2,2,1,0,1,1,0,253,254,255,0,0,1,1,0,253,254,255,0,1,2,1,1,254,1,2,2,2,3,3,2,255,1,2,1,0,1,1,2,255,0,1,254,252,254,0,1,255,1,1,255,253,254,0,255,253,1,2,0,255,0,1,255,252,255,255,254,254,0,3,4,3,1,1,255,253,254,0,0,0,2,2,2,2,2,1,255,255,1,1,1,3,3,0,254,254,0,255,255,255,0,254,255,255,255,253,252,253,254,254,0,2,255,255,0,1,2,2,3,5,254,255,255,0,0,0,0,1,254,253,2,0,0,1,1,255,255,252,1,254,255,2,2,0,1,252,0,254,254,1,1,255,2,253,1,255,255,1,1,255,3,254,3,1,0,1,1,255,1,253,2,1,0,1,0,255,255,251,1,0,255,0,1,1,0,253,3,3,1,2,3,3,0,255,254,1,5,5,2,255,1,255,254,255,1,1,254,251,1,1,255,254,255,255,255,253,1,1,255,255,255,2,4,3,255,255,255,255,255,0,4,3,255,255,0,1,255,253,255,255,0,0,0,2,2,0,0,255,0,254,253,0,1,1,3,2,2,3,2,1,0,0,254,254,2,3,0,1,1,3,3,2,0,0,253,255,255,2,2,3,254,254,253,1,1,2,1,1,254,255,254,2,1,1,255,254,0,1,0,2,0,0,254,254,0,1,0,2,0,0,254,254,253,254,254,0,255,254,254,253,0,1,255,3,255,1,3,255,0,1,255,3,255,255,2,253,1,1,254,3,255,253,0,253,2,2,254,3,0,254,1,254,1,1,253,3,255,254,1,253,1,1,253,3,0,255,1,254,1,2,255,4,0,255,1,254,0,1,255,3,255,253,0,253,253,253,255,1,2,1,255,254,254,254,0,2,1,0,254,254,253,254,1,2,1,255,254,255,253,254,2,4,0,254,254,1,253,255,2,4,0,254,254,2,255,1,4,3,255,253,254,2,0,2,4,2,255,254,255,2,0,1,2,0,255,0,1,3,3,0,251,1,4,0,0,1,1,254,251,2,5,255,254,1,255,0,0,3,3,1,0,255,254,3,4,254,253,255,0,254,253,3,5,253,253,0,0,254,255,3,2,254,254,2,2,255,2,0,0,255,0,0,0,0,0,253,254,1,3,0,254,254,9,8,4,0,253,252,252,253,9,8,4,255,252,251,251,253,8,7,3,254,251,251,251,252,6,4,1,254,252,251,252,253,244,242,245,252,1,5,6,6,248,246,249,251,254,1,1,1,5,4,3,1,0,0,255,255,13,13,9,6,3,0,255,254,252,252,253,255,1,4,8,11,251,250,252,254,0,3,8,12,249,249,250,252,254,2,7,10,249,249,251,252,254,1,5,8,253,254,255,1,3,6,7,6,2,3,5,7,8,8,6,4,4,5,4,3,1,254,250,249,1,0,254,249,246,242,239,240,251,252,1,8,9,3,253,249,249,250,1,11,12,5,253,248,248,249,0,9,11,5,253,249,248,250,255,5,8,4,254,250,252,251,249,248,247,247,248,250,252,251,250,249,249,250,252,254,0,1,2,3,5,8,10,9,1,2,3,6,9,12,14,13,5,6,6,5,4,3,2,1,5,6,7,7,6,6,6,4,255,0,1,1,3,5,5,5,243,240,239,239,242,246,250,252,9,11,13,16,15,13,12,10,252,251,250,249,249,249,250,251,250,250,249,249,249,249,250,251,254,255,0,0,0,0,0,255,245,243,241,240,240,242,244,246,2,3,4,5,4,3,3,3,6,7,8,8,8,7,6,5,3,4,3,3,3,3,3,3,3,4,4,1,254,249,243,239,5,7,7,5,1,251,243,237,6,8,9,8,5,255,247,240,6,8,10,10,7,2,252,245,18,9,255,246,243,247,252,0,22,12,255,244,241,246,252,2,23,13,0,246,243,247,253,2,20,12,2,250,247,250,254,2,250,250,250,249,249,249,249,250,250,249,248,248,247,247,247,248,253,253,253,253,253,253,253,253,12,15,18,21,21,19,17,14,14,16,18,18,18,16,15,13,5,6,6,5,5,4,4,3,250,249,247,246,246,246,247,249,246,245,243,242,242,243,244,246,229,239,252,5,9,10,10,7,224,237,253,7,11,12,11,8,226,240,254,8,12,12,10,7,233,244,0,7,10,11,9,6,16,17,16,12,6,255,248,244,17,18,15,10,1,248,241,238,15,14,10,4,251,242,236,233,10,8,4,255,247,240,235,234,246,244,244,245,251,4,14,20,245,243,241,244,252,7,19,27,245,243,242,245,253,8,21,28,246,245,244,247,254,8,18,25,255,255,255,1,4,6,6,5,0,0,0,2,4,3,1,254,0,0,2,4,4,255,249,246,0,0,3,5,3,253,245,241,242,243,248,255,3,3,255,252,251,252,255,4,8,8,3,0,3,2,2,3,4,5,3,1,5,3,0,254,254,255,255,255,9,1,250,250,251,253,254,255,12,1,250,250,252,254,255,0,14,4,252,252,254,254,255,255,14,6,255,255,255,255,255,255,4,6,8,10,11,9,7,5,255,255,255,0,0,255,255,254,254,252,252,251,251,251,251,252,254,253,253,252,252,253,254,255,2,3,4,4,3,1,0,0,255,1,4,5,6,5,4,3,248,250,254,2,3,4,4,3,242,243,247,251,254,255,0,0,253,252,251,252,0,7,12,13,253,252,251,251,254,4,9,10,254,253,252,251,252,255,3,4,255,255,254,253,253,254,0,1,9,5,254,248,245,246,249,252,12,10,6,2,0,255,0,0,2,2,3,4,3,1,1,1,247,248,252,0,1,2,1,0,6,8,8,5,1,251,245,243,0,1,2,2,255,252,248,245,253,254,1,3,3,1,255,252,254,255,2,5,6,6,4,1,3,4,5,5,4,1,253,250,5,6,4,2,2,2,0,253,6,5,0,251,251,254,255,254,7,4,253,245,244,249,253,254,1,0,255,255,255,0,0,0,2,3,4,4,5,5,4,3,249,247,247,246,246,247,249,250,3,4,5,6,5,5,5,5,249,249,249,249,250,250,251,252,251,252,253,255,255,255,0,0,253,254,1,4,5,5,5,5,254,255,3,6,9,10,10,9,242,1,10,3,254,0,1,1,240,2,13,3,253,255,1,0,241,2,12,3,252,254,1,1,246,3,10,2,253,255,1,1,0,1,4,2,251,246,253,11,255,1,4,2,250,243,254,15,255,0,3,1,250,244,255,15,255,1,2,1,252,248,0,11,10,5,254,254,2,5,1,252,7,0,248,250,1,5,2,252,2,251,244,249,2,7,4,255,255,249,246,252,4,9,7,2,251,251,252,250,250,251,251,253,255,254,254,252,251,250,251,252,6,7,7,4,0,254,253,253,13,14,13,10,5,1,255,254,1,1,2,2,2,2,2,2,251,250,248,247,247,248,249,250,7,9,10,11,11,9,7,5,255,254,253,253,252,252,252,253,255,255,0,0,0,0,255,255,253,253,252,251,252,253,253,254,2,1,255,253,253,254,255,0,12,12,8,3,1,0,0,1,250,248,248,250,254,2,6,8,1,1,255,254,0,3,5,7,3,3,1,255,255,0,0,2,0,1,0,255,255,255,254,255,1,0,0,0,0,0,2,4,2,1,3,4,3,1,0,2,2,1,0,0,255,255,0,3,5,1,250,244,243,248,255,4,254,0,255,254,255,0,2,3,250,253,254,0,1,1,1,1,247,251,0,4,5,3,1,0,248,253,3,7,8,4,1,0,1,2,2,3,3,1,255,253,4,5,5,6,6,5,2,0,0,0,0,0,1,0,254,252,253,253,252,253,253,252,249,248,14,12,6,255,253,253,0,0,7,5,1,253,251,252,254,255,254,254,254,254,254,254,255,255,250,252,255,1,1,1,0,255,2,2,1,253,250,249,250,253,1,0,255,253,254,1,4,6,0,0,1,2,4,7,8,7,0,0,0,0,255,252,249,248,0,2,1,254,253,253,254,255,255,1,0,253,251,254,0,2,254,255,254,251,252,1,6,9,253,254,253,252,254,5,11,13,252,254,2,6,4,253,246,242,254,255,1,4,4,1,255,254,0,0,255,254,254,0,4,6,2,2,0,253,253,0,5,9,252,252,254,1,6,9,3,249,254,254,254,255,4,8,0,245,1,1,0,0,2,6,255,246,2,2,1,0,2,4,0,249,255,254,253,250,249,248,248,248,2,3,3,1,255,254,253,252,5,5,5,4,3,2,0,255,3,3,3,3,2,2,1,1,3,3,2,254,253,0,7,10,1,2,2,254,251,252,0,3,0,3,4,2,253,251,250,252,0,2,4,4,1,252,249,249,2,4,5,5,5,5,6,6,252,252,253,251,251,253,253,254,253,252,252,251,252,254,254,254,1,1,0,0,2,4,5,4,254,0,3,4,4,3,2,2,247,249,252,0,3,6,6,6,251,251,253,254,0,1,3,4,5,5,2,254,252,250,251,253,1,250,252,7,5,254,254,1,5,251,252,6,4,251,252,1,5,251,252,6,4,251,253,1,1,249,253,8,7,255,253,1,248,249,252,0,2,4,5,5,5,6,5,2,255,251,249,249,5,6,4,1,253,251,250,251,249,249,251,254,1,6,9,10,6,3,0,1,3,0,248,242,3,0,255,1,4,3,0,252,1,0,0,1,2,1,1,1,255,255,1,2,1,255,255,0,1,1,1,1,0,254,253,0,1,2,1,0,254,248,247,252,1,3,3,2,1,253,253,1,0,1,1,1,1,1,4,8,2,5,9,7,2,255,255,1,252,255,1,0,253,252,255,2,253,0,3,3,0,255,0,2,252,255,1,1,254,252,251,252,1,255,254,254,255,2,4,5,2,1,1,0,255,255,0,0,2,3,4,5,4,2,1,0,247,247,250,253,255,255,255,255,250,250,4,7,0,254,255,254,255,254,5,6,255,254,0,255,4,255,1,0,252,254,0,254,7,1,255,254,253,1,3,1,4,2,1,3,3,1,1,2,2,254,252,0,3,1,0,0,1,252,248,252,1,2,1,0,2,253,247,250,0,3,3,2,255,255,0,255,255,0,1,2,3,1,252,248,249,253,1,2,2,255,253,254,255,0,1,0,255,0,5,11,9,3,255,253,255,254,254,255,1,1,1,1,0,255,0,3,6,6,5,5,2,1,255,255,254,251,250,252,2,2,2,1,255,252,251,251,255,253,250,249,250,252,255,1,5,5,3,4,4,3,4,5,255,254,253,254,254,254,0,1,0,0,0,0,0,1,2,3,250,250,252,255,2,2,2,2,250,249,251,254,0,255,255,0,2,2,2,4,4,3,3,4,2,1,0,255,0,0,2,4,12,5,251,248,251,0,2,2,2,253,250,253,0,0,255,254,254,253,255,3,4,1,254,253,2,2,3,4,3,1,255,255,3,2,1,0,1,4,3,0,4,3,0,251,250,0,3,3,2,3,1,249,244,250,1,3,1,3,4,255,250,252,0,1,247,252,2,6,7,4,1,0,249,255,4,6,4,0,253,253,250,0,4,4,1,254,253,254,252,1,3,2,0,254,255,0,0,5,2,251,253,3,1,252,254,4,2,250,253,6,4,253,255,5,3,251,255,7,3,252,255,2,0,250,253,5,3,253,248,253,3,5,3,1,254,254,2,4,4,254,252,253,1,3,2,1,253,251,253,3,4,3,251,250,251,3,10,8,255,251,0,3,2,252,247,249,0,6,251,255,5,7,4,255,253,253,251,251,254,3,6,5,255,252,9,6,0,252,254,1,1,255,255,255,255,1,1,0,255,0,255,0,0,0,0,255,255,0,2,1,254,255,1,1,0,0,12,8,2,255,255,252,249,249,2,1,3,6,7,4,2,0,1,0,255,0,255,252,249,248,0,0,255,0,0,0,255,253,0,0,0,0,1,1,0,254,255,0,1,1,0,0,255,254,0,0,255,253,252,253,255,1,255,0,0,0,1,4,10,12,255,0,254,254,253,253,255,1,253,255,254,252,2,9,9,7,253,0,255,253,0,2,255,1,255,1,254,253,0,255,253,0,0,0,253,254,0,255,255,1,255,254,255,255,254,255,255,254,2,255,254,255,0,1,0,254,3,255,254,2,5,3,255,253,1,251,251,1,6,6,2,0,1,2,0,255,0,1,0,254,251,253,255,0,1,2,1,254,249,251,254,254,254,254,0,1,255,0,1,1,0,3,9,12,0,6,5,1,254,253,0,3,0,6,5,1,1,1,2,3,251,254,254,253,0,0,0,0,250,253,253,254,0,0,255,254,4,4,2,1,0,255,255,0,254,254,0,1,2,1,1,0,2,2,1,255,253,251,247,246,2,1,255,255,1,4,4,1,4,0,254,254,254,254,255,0,7,1,252,253,254,0,1,1,10,5,255,254,0,1,1,0,5,1,253,252,253,255,255,254,2,1,255,253,253,1,1,255,254,255,3,0,255,1,1,0,253,1,7,2,253,254,255,0,254,4,8,255,248,251,0,2,252,255,1,2,1,253,252,254,251,253,254,1,4,4,4,6,253,254,252,253,0,1,1,2,2,2,2,1,2,1,255,255,252,255,0,255,253,253,255,255,1,4,4,2,0,255,254,253,4,6,5,3,2,1,254,252,0,1,1,1,1,255,252,250,1,2,2,255,250,251,255,2,253,254,1,1,252,253,2,5,254,255,2,2,253,252,0,3,254,254,2,6,5,2,1,2,2,253,253,0,0,2,3,1,3,255,1,3,1,2,255,251,251,249,252,254,1,8,8,1,255,0,2,0,253,0,1,253,254,251,251,254,253,255,0,254,255,252,0,4,0,2,4,0,0,0,8,10,2,1,3,255,252,253,2,3,253,253,1,255,1,254,252,2,7,3,254,255,6,4,254,255,2,0,255,3,1,1,254,254,254,251,253,4,250,254,1,1,255,252,254,4,254,255,254,254,0,1,0,254,255,1,0,255,0,0,255,253,0,1,254,252,253,255,0,0,6,8,5,0,0,1,2,3,254,254,2,5,2,0,0,1,2,254,254,255,255,1,2,4,2,255,0,1,0,0,0,1,248,249,255,1,255,255,1,3,0,3,6,2,254,1,2,0,246,249,255,0,253,255,2,1,0,0,2,2,1,1,1,255,3,0,254,254,0,2,1,0,8,1,0,0,254,253,255,0,2,254,2,5,1,254,255,1,253,250,253,255,253,253,255,2,2,0,1,2,2,1,0,0,1,255,255,254,255,0,1,0,15,9,2,255,254,253,253,253,0,253,254,0,0,255,255,255,1,0,1,0,0,255,255,255,0,2,2,254,253,253,249,248,0,2,2,0,1,2,1,1,1,2,2,2,3,1,0,3,1,0,255,254,255,254,0,5,245,250,255,1,2,3,1,253,1,4,3,255,254,1,2,255,2,2,1,255,254,0,1,255,0,0,255,255,0,2,3,2,1,1,2,1,255,1,0,252,0,0,0,254,254,2,4,254,254,253,0,0,255,2,1,250,0,2,5,5,3,2,255,249,4,2,0,0,3,3,1,255,0,255,255,3,6,4,1,255,254,254,0,2,2,0,254,254,255,0,255,251,249,251,255,1,5,255,254,0,2,4,2,251,0,251,254,2,1,2,0,250,6,1,0,1,254,255,4,2,2,253,253,0,255,254,0,0,1,255,0,2,0,0,6,11,2,255,255,0,253,254,3,5,0,254,255,0,255,0,0,253,1,255,255,255,254,255,253,249,1,1,254,254,1,3,1,254,255,2,0,255,255,1,0,0,252,2,3,255,254,254,0,1,245,254,4,5,6,2,255,254,250,254,1,255,253,252,1,9,253,0,3,3,2,253,253,3,1,1,0,0,1,255,254,3,2,0,253,253,0,255,255,3,1,255,253,1,2,250,252,6,0,254,251,254,0,253,254,3,2,2,1,254,254,1,2,255,255,1,1,254,255,6,7,255,1,0,252,254,1,254,253,1,252,0,253,254,2,0,253,0,253,4,3,1,8,7,0,255,253,4,1,252,2,3,254,253,253,6,1,252,1,1,255,255,254,4,253,253,3,0,255,255,1,2,252,2,4,253,255,2,3,255,252,5,4,250,253,2,4,0,250,249,252,248,243,247,248,248,255,6,254,5,22,27,240,249,11,10,238,249,13,10,241,252,12,8,247,255,9,5,254,2,15,240,253,2,19,237,253,2,19,237,254,3,15,242,17,22,22,16,250,249,251,254,244,240,240,244,1,1,255,253,11,239,0,8,14,235,255,9,14,235,254,8,11,240,254,6,7,254,240,11,9,254,235,14,10,255,234,14,8,255,238,10,246,16,3,247,243,20,4,245,242,21,4,246,245,16,3,248,11,4,247,247,15,6,244,242,17,8,244,242,16,10,249,245,4,10,14,13,255,7,15,16,244,249,3,8,236,233,238,246,246,238,230,231,4,1,250,245,13,15,11,3,12,15,13,8,240,237,240,245,7,12,15,11,11,16,16,11,250,247,245,246,18,19,12,5,18,16,5,252,6,0,246,241,247,239,233,234,246,242,255,21,245,239,0,29,245,240,1,30,246,242,0,23,240,239,244,250,237,237,242,249,253,255,1,2,27,35,29,19,219,248,23,23,214,247,28,29,213,246,26,28,218,245,19,22,32,16,240,223,39,20,238,219,38,19,237,218,32,15,239,222,24,9,250,252,255,246,250,3,248,247,255,3,3,7,2,250,255,253,255,0,255,4,2,249,253,11,3,240,1,20,9,238,253,248,6,12,251,246,7,13,250,247,5,7,251,251,2,255,248,12,253,255,246,15,253,1,245,13,252,1,245,8,253,2,9,6,251,244,3,0,248,243,252,252,255,255,252,1,15,18,9,13,14,12,4,3,255,254,254,251,248,251,249,245,247,252,7,251,249,252,14,254,249,252,17,0,248,251,15,1,249,251,246,255,6,4,241,247,2,4,2,255,253,0,25,13,248,246,7,11,253,240,7,11,253,241,6,7,254,247,4,2,253,251,249,255,255,0,247,254,2,6,244,252,6,14,243,250,8,19,238,238,245,251,253,0,3,4,6,8,6,6,6,6,6,6,251,3,13,246,250,1,15,247,250,253,15,250,250,250,10,253,9,1,247,247,11,9,6,5,0,3,8,7,241,242,250,251,245,250,11,19,254,251,247,248,6,2,247,246,6,5,4,5,249,253,8,15,255,3,10,15,5,5,255,254,4,254,235,231,6,250,250,5,8,247,249,9,8,244,249,13,4,242,249,14,252,253,1,1,253,251,254,253,7,0,254,252,20,7,252,252,253,236,250,10,6,0,0,1,5,8,5,255,253,0,0,254,13,6,255,2,5,3,2,3,253,0,3,0,240,248,254,251,254,249,250,0,253,250,253,1,251,255,2,255,255,12,16,5,249,1,9,8,246,254,5,3,250,2,7,3,252,0,255,249,3,4,247,232,0,2,6,3,255,255,4,7,5,3,255,254,3,6,247,2,1,6,243,1,1,8,246,2,1,8,249,1,253,253,2,22,254,253,251,12,254,253,246,2,253,255,252,2,11,12,8,2,251,251,251,248,250,252,0,253,254,255,3,3,12,250,254,255,12,248,254,254,9,249,0,253,4,250,2,254,237,1,12,253,252,4,5,252,6,1,254,255,4,252,254,7,253,252,249,248,252,252,254,0,255,2,14,16,252,254,4,4,255,7,2,251,254,0,255,1,4,253,255,13,6,244,242,8,255,5,4,251,254,5,3,247,254,7,4,244,255,7,4,247,250,253,1,1,11,11,0,250,6,4,254,249,244,246,3,10,254,253,253,254,6,11,14,10,247,245,246,246,2,2,3,2,249,251,249,255,255,2,0,7,255,1,0,9,3,4,251,255,10,255,241,255,4,1,251,2,253,1,255,1,253,1,4,4,2,255,4,10,6,2,255,0,2,2,249,244,252,2,0,253,255,252,255,248,3,255,2,247,4,0,5,251,2,0,8,3,3,2,1,1,4,254,0,3,2,255,4,1,0,6,255,231,255,254,254,252,253,0,255,252,255,255,252,2,0,250,2,25,245,255,5,0,7,0,254,2,10,255,253,4,251,251,254,255,0,6,3,255,254,255,255,1,255,249,244,251,8,6,2,4,2,6,255,250,9,10,255,252,1,0,252,0,3,254,247,251,252,3,4,0,252,3,3,0,245,0,3,2,245,3,7,2,2,252,7,3,1,248,7,1,255,244,4,1,3,247,2,2,2,254,254,9,239,253,3,1,252,7,1,250,5,4,255,3,255,2,0,252,249,8,12,255,254,5,4,251,3,251,248,254,0,0,251,254,254,248,3,27,255,252,253,6,253,1,254,249,4,4,1,255,249,246,249,253,10,10,5,3,254,254,252,253,0,1,5,7,4,254,240,236,0,4,7,8,2,0,254,255,254,1,3,17,253,1,254,255,255,254,255,254,255,251,255,0,5,253,1,0,6,254,0,0,255,254,0,253,245,1,8,255,3,0,0,0,0,2,4,1,2,0,6,1,254,238,253,2,242,0,6,1,251,254,255,1,255,1,0,1,1,7,4,0,255,0,1,252,1,8,3,252,253,4,1,3,250,1,252,1,1,244,3,3,255,246,0,255,2,0,2,1,3,2,2,4,3,0,0,3,2,0,254,1,5,2,251,0,6,255,242,255,254,250,253,253,2,255,4,5,6,255,254,0,4,4,255,251,252,1,245,0,255,2,252,1,2,253,3,255,1,254,15,0,1,255,0,254,1,252,249,1,254,250,255,21,254,2,255,1,21,255,254,0,255,253,1,254,247,254,2,255,2,1,252,255,1,8,2,250,246,255,4,0,252,253,3,3,5,0,255,255,3,2,1,254,254,254,4,3,5,2,252,239,0,254,4,3,249,252,0,3,9,9,2,255,245,250,0,255,5,1,0,1,0,17,5,245,3,254,250,0,2,254,252,1,252,1,2,255,251,255,251,253,253,5,253,254,4,16,2,251,254,5,255,255,0,0,252,1,255,2,5,11,255,255,254,1,252,254,253,255,251,255,10,0,6,1,0,253,0,252,1,0,254,252,3,255,6,9,3,0,254,1,254,0,254,253,254,254,1,0,1,250,1,0,2,1,255,3,254,1,0,255,241,0,255,5,2,6,2,0,2,2,0,244,252,6,0,1,4,255,1,2,1,252,1,254,249,0,0,0,0,255,251,2,11,3,1,3,0,250,0,253,247,252,1,3,255,0,4,1,254,0,7,253,255,6,1,254,6,2,0,255,3,254,254,4,0,2,255,2,242,2,2,2,0,255,254,3,253,242,0,2,3,253,5,1,3,2,1,253,4,242,1,254,11,255,0,255,3,0,255,1,0,2,254,3,253,2,252,255,252,3,255,2,1,3,250,254,2,7,254,1,2,0,254,0,0,255,12,5,255,2,248,255,1,249,2,254,252,2,11,0,245,254,3,1,253,255,0,3,1,255,0,3,0,254,0,250,255,253,12,249,254,0,7,254,1,1,1,2,2,2,255,2,0,2,233,0,4,0,3,2,1,3,252,251,255,5,253,5,10,255,0,0,3,252,1,255,2,251,7,2,250,249,7,3,253,252,249,254,7,8,248,252,3,4,19,17,9,3,242,240,244,248,238,240,248,253,11,14,12,8,7,240,246,20,7,239,246,20,250,18,8,235,249,18,9,236,25,3,236,242,29,7,238,243,227,252,21,14,225,250,20,14,237,230,228,232,31,32,22,10,15,24,31,28,224,224,234,243,2,248,233,230,247,3,27,35,3,11,21,21,8,252,229,222,226,225,12,47,227,226,13,47,38,30,239,210,34,26,237,210,214,206,205,213,34,48,55,48,48,54,51,42,212,204,203,209,4,5,0,250,254,254,0,1,245,250,255,254,1,8,9,1,0,1,250,5,8,1,244,2,7,242,249,8,5,248,0,8,1,4,11,8,244,248,0,251,255,1,0,4,241,248,3,16,17,8,252,250,9,252,243,248,2,6,1,238,255,11,11,244,6,0,2,0,14,6,249,235,1,255,243,236,1,1,10,21,234,251,7,13,245,255,4,12,249,0,14,19,252,3,251,237,230,242,10,15,18,4,250,254,25,19,251,238,236,249,4,2,243,250,255,252,25,37,254,221,5,4,1,1,235,220,2,43,2,254,255,3,8,254,250,255,254,253,2,12,251,254,254,255,253,255,255,251,255,7,8,254,2,7,5,253,1,1,253,248,253,255,253,254,254,253,2,13,15,0,245,250,3,0,0,0,250,247,251,252,18,4,1,3,12,3,0,4,240,253,3,253,239,3,18,2,255,253,255,255,250,16,248,0,247,14,249,0,3,243,14,251,3,243,14,252,249,20,14,233,8,249,248,4,8,241,237,16,246,13,11,253,9,255,1,26,5,241,229,2,236,7,16,252,216,9,31,1,26,244,226,249,40,254,237,4,6,0,0,0,250,254,1,2,0,255,0,250,9,0,254,255,249,8,2,253,255,2,253,2,7,252,254,4,2,0,0,250,253,254,9,2,254,255,0,252,253,253,0,253,250,2,10,4,3,0,246,8,0,0,252,4,255,1,4,2,3,249,247,7,2,1,247,252,255,12,0,0,3,255,7,252,3,242,4,2,244,247,1,11,2,5,1,0,3,1,0,2,0,8,6,237,250,246,249,252,9,7,5,7,6,21,3,253,245,247,251,254,252,247,240,255,254,251,1,36,8,11,19,0,2,5,252,215,255,255,254,255,254,254,1,6,0,4,1,248,1,1,1,0,254,253,4,0,2,255,3,253,1,3,252,1,255,3,0,251,3,4,2,3,254,253,250,255,254,253,254,2,252,8,1,0,249,4,2,6,249,255,1,0,254,2,252,1,8,250,2,255,250,2,0,2,5,4,248,255,255,245,0,9,0,254,2,2,17,251,252,255,255,252,254,254,0,243,9,253,255,12,249,2,0,254,251,2,249,251,20,253,7,7,255,226,3,5,8,1,250,3,255,252,2,254,245,18,0,249,3,14,20,253,238,247,7,254,0,255,254,0,0,255,252,255,1,0,254,2,0,4,1,253,2,1,3,1,251,1,253,0,255,254,7,1,0,253,2,5,0,254,2,251,255,1,255,254,4,255,0,253,5,0,0,3,255,254,252,1,5,255,255,0,255,9,255,254,255,255,254,5,5,255,254,2,253,254,1,2,245,1,2,1,3,2,2,246,255,254,4,2,4,1,4,5,251,1,0,6,245,1,1,0,6,6,0,2,1,241,7,3,5,9,226,2,2,2,222,1,9,2,5,8,8,2,7,2,6,6,2,229,1,4,14,10,14,18,16,18,10,10,14,14,14,16,0,0,0,0,16,14,0,128,129,0,128,129,255,255,255,255,255,255,0,0,72,64,38,0,112,0,0,0,160,117,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,6,7,6,0,0,0,0,243,4,53,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,1,0,4,0,3,0,5,0,3,0,12,0,4,0,13,0,4,0,56,0,6,0,57,0,6,0,58,0,6,0,59,0,6,0,240,0,8,0,241,0,8,0,242,0,8,0,243,0,8,0,244,0,8,0,245,0,8,0,246,0,8,0,247,0,8,0,224,3,10,0,225,3,10,0,226,3,10,0,227,3,10,0,228,3,10,0,229,3,10,0,230,3,10,0,231,3,10,0,232,3,10,0,233,3,10,0,234,3,10,0,235,3,10,0,236,3,10,0,237,3,10,0,238,3,10,0,239,3,10,0,63,0,6,0,248,246,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,246,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,184,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,33,0,144,27,33,0,0,0,0,0,0,0,0,0,184,177,32,0,112,0,0,0,112,159,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,2,0,0,0,13,0,0,0,13,0,0,0,5,0,0,0,13,0,0,0,13,0,0,0,8,0,0,0,13,0,0,0,13,0,0,0,11,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,1,0,0,0,13,0,0,0,13,0,0,0,4,0,0,0,13,0,0,0,13,0,0,0,7,0,0,0,13,0,0,0,13,0,0,0,10,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,13,0,0,0,13,0,0,0,3,0,0,0,13,0,0,0,13,0,0,0,6,0,0,0,13,0,0,0,13,0,0,0,9,0,0,0,0,0,0,0,1,1,0,0,0,1,1,0,0,2,1,0,0,2,1,1,0,2,1,2,0,0,2,2,0,0,2,2,0,0,4,10,0,0,4,10,0,0,4,10,0,0,4,10,0,1,2,1,2,1,2,1,0,3,5,3,5,3,5,3,0,2,3,2,3,2,3,2,0,6,123,12,1,0,2,11,108,36,8,1,0,9,93,50,6,0,3,16,77,77,16,3,0,6,50,93,9,0,1,8,36,108,11,2,0,1,12,123,6,0,0,0,0,0,0,0,3,1,2,0,0,0,0,0,3,1,2,0,0,0,0,0,10,4,5,1,11,6,7,2,12,8,9,3,0,0,0,0,10,4,5,1,11,6,7,2,12,8,9,3,0,0,0,0,53,53,54,0,0,0,0,0,0,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,18,0,0,0,20,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,8,0,16,0,24,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,176], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+542720);
/* memory initializer */ allocate([192,0,224,0,0,1,32,1,64,1,96,1,128,1,160,1,192,1,224,1,0,2,64,2,128,2,192,2,0,3,128,3,0,4,0,0,0,0,0,0,140,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,180,162,25,0,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,255,255,255,255,0,0,0,0,0,213,127,170,254,43,129,84,41,252,86,131,215,2,168,125,82,135,45,248,172,121,211,6,123,174,4,209,133,80,250,47,164,113,219,14,90,143,37,240,141,88,242,39,115,166,12,217,246,35,137,92,8,221,119,162,223,10,160,117,33,244,94,139,157,72,226,55,99,182,28,201,180,97,203,30,74,159,53,224,207,26,176,101,49,228,78,155,230,51,153,76,24,205,103,178,57,236,70,147,199,18,184,109,16,197,111,186,238,59,145,68,107,190,20,193,149,64,234,63,66,151,61,232,188,105,195,22,239,58,144,69,17,196,110,187,198,19,185,108,56,237,71,146,189,104,194,23,67,150,60,233,148,65,235,62,106,191,21,192,75,158,52,225,181,96,202,31,98,183,29,200,156,73,227,54,25,204,102,179,231,50,152,77,48,229,79,154,206,27,177,100,114,167,13,216,140,89,243,38,91,142,36,241,165,112,218,15,32,245,95,138,222,11,161,116,9,220,118,163,247,34,136,93,214,3,169,124,40,253,87,130,255,42,128,85,1,212,126,171,132,81,251,46,122,175,5,208,173,120,210,7,83,134,44,249,10,83,116,97,110,100,97,114,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,58,10,78,65,77,69,32,32,32,32,32,32,32,32,68,69,67,79,77,80,79,83,73,84,73,79,78,0,0,0,0,73,110,100,105,118,105,100,117,97,108,32,99,104,97,110,110,101,108,115,58,10,78,65,77,69,32,32,32,32,32,32,32,32,68,69,83,67,82,73,80,84,73,79,78,0,0,0,0,80,105,120,101,108,32,102,111,114,109,97,116,115,58,10,73,46,46,46,46,32,61,32,83,117,112,112,111,114,116,101,100,32,73,110,112,117,116,32,32,102,111,114,109,97,116,32,102,111,114,32,99,111,110,118,101,114,115,105,111,110,10,46,79,46,46,46,32,61,32,83,117,112,112,111,114,116,101,100,32,79,117,116,112,117,116,32,102,111,114,109,97,116,32,102,111,114,32,99,111,110,118,101,114,115,105,111,110,10,46,46,72,46,46,32,61,32,72,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,101,100,32,102,111,114,109,97,116,10,46,46,46,80,46,32,61,32,80,97,108,101,116,116,101,100,32,102,111,114,109,97,116,10,46,46,46,46,66,32,61,32,66,105,116,115,116,114,101,97,109,32,102,111,114,109,97,116,10,70,76,65,71,83,32,78,65,77,69,32,32,32,32,32,32,32,32,32,32,32,32,78,66,95,67,79,77,80,79,78,69,78,84,83,32,66,73,84,83,95,80,69,82,95,80,73,88,69,76,10,45,45,45,45,45,0,0,0,0,0,0,70,105,108,116,101,114,115,58,10,32,32,84,46,46,32,61,32,84,105,109,101,108,105,110,101,32,115,117,112,112,111,114,116,10,32,32,46,83,46,32,61,32,83,108,105,99,101,32,116,104,114,101,97,100,105,110,103,10,32,32,46,46,67,32,61,32,67,111,109,109,109,97,110,100,32,115,117,112,112,111,114,116,10,32,32,65,32,61,32,65,117,100,105,111,32,105,110,112,117,116,47,111,117,116,112,117,116,10,32,32,86,32,61,32,86,105,100,101,111,32,105,110,112,117,116,47,111,117,116,112,117,116,10,32,32,78,32,61,32,68,121,110,97,109,105,99,32,110,117,109,98,101,114,32,97,110,100,47,111,114,32,116,121,112,101,32,111,102,32,105,110,112,117,116,47,111,117,116,112,117,116,10,32,32,124,32,61,32,83,111,117,114,99,101,32,111,114,32,115,105,110,107,32,102,105,108,116,101,114,0,0,0,0,0,0,0,79,117,116,112,117,116,58,0,83,117,112,112,111,114,116,101,100,32,102,105,108,101,32,112,114,111,116,111,99,111,108,115,58,10,73,110,112,117,116,58,0,0,0,0,0,0,0,0,66,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,115,58,0,0,0,0,0,0,67,111,100,101,99,115,58,10,32,68,46,46,46,46,46,32,61,32,68,101,99,111,100,105,110,103,32,115,117,112,112,111,114,116,101,100,10,32,46,69,46,46,46,46,32,61,32,69,110,99,111,100,105,110,103,32,115,117,112,112,111,114,116,101,100,10,32,46,46,86,46,46,46,32,61,32,86,105,100,101,111,32,99,111,100,101,99,10,32,46,46,65,46,46,46,32,61,32,65,117,100,105,111,32,99,111,100,101,99,10,32,46,46,83,46,46,46,32,61,32,83,117,98,116,105,116,108,101,32,99,111,100,101,99,10,32,46,46,46,73,46,46,32,61,32,73,110,116,114,97,32,102,114,97,109,101,45,111,110,108,121,32,99,111,100,101,99,10,32,46,46,46,46,76,46,32,61,32,76,111,115,115,121,32,99,111,109,112,114,101,115,115,105,111,110,10,32,46,46,46,46,46,83,32,61,32,76,111,115,115,108,101,115,115,32,99,111,109,112,114,101,115,115,105,111,110,10,32,45,45,45,45,45,45,45,0,0,0,0,0,84,104,105,115,32,102,105,108,116,101,114,32,104,97,115,32,115,117,112,112,111,114,116,32,102,111,114,32,116,105,109,101,108,105,110,101,32,116,104,114,111,117,103,104,32,116,104,101,32,39,101,110,97,98,108,101,39,32,111,112,116,105,111,110,46,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,110,111,110,101,32,40,115,105,110,107,32,102,105,108,116,101,114,41,0,0,0,0,0,0,32,32,32,32,32,32,32,32,100,121,110,97,109,105,99,32,40,100,101,112,101,110,100,105,110,103,32,111,110,32,116,104,101,32,111,112,116,105,111,110,115,41,0,0,0,0,0,0,32,32,32,32,79,117,116,112,117,116,115,58,0,0,0,0,32,32,32,32,32,32,32,32,110,111,110,101,32,40,115,111,117,114,99,101,32,102,105,108,116,101,114,41,0,0,0,0,32,32,32,32,73,110,112,117,116,115,58,0,0,0,0,0,32,32,32,32,115,108,105,99,101,32,116,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,101,100,0,0,0,70,105,108,101,32,102,111,114,109,97,116,115,58,10,32,68,46,32,61,32,68,101,109,117,120,105,110,103,32,115,117,112,112,111,114,116,101,100,10,32,46,69,32,61,32,77,117,120,105,110,103,32,115,117,112,112,111,114,116,101,100,10,32,45,45,0,0,0,0,0,0,0,184,136,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,250,36,0,104,183,35,0,4,0,0,0,1,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,50,64,0,0,0,0,0,0,59,64,16,0,1,0,200,250,36,0,104,210,34,0,48,17,34,0,0,0,0,0,128,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,200,120,33,0,64,255,32,0,0,0,0,0,128,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,16,155,32,0,128,63,32,0,0,0,0,0,128,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,104,37,40,0,136,198,39,0,0,0,0,0,128,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,248,96,39,0,112,19,39,0,0,0,0,0,128,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,136,207,38,0,56,139,38,0,0,0,0,0,128,0,0,0,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,96,79,38,0,192,24,38,0,0,0,0,0,128,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,128,237,37,0,64,192,37,0,0,0,0,0,128,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,192,158,37,0,232,112,37,0,0,0,0,0,128,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,160,47,37,0,216,7,37,0,0,0,0,0,128,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,250,36,0,72,224,36,0,176,189,36,0,40,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,64,16,0,1,0,72,224,36,0,104,210,34,0,48,17,34,0,0,0,0,0,128,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,200,120,33,0,64,255,32,0,0,0,0,0,128,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,16,155,32,0,128,63,32,0,0,0,0,0,128,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,104,37,40,0,136,198,39,0,0,0,0,0,128,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,88,160,36,0,24,133,36,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,216,106,36,0,24,79,36,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,80,55,36,0,200,19,36,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,128,220,35,0,8,193,35,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,248,96,39,0,112,19,39,0,0,0,0,0,128,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,136,207,38,0,56,139,38,0,0,0,0,0,128,0,0,0,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,96,170,35,0,64,148,35,0,0,0,0,0,128,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,0,126,35,0,24,103,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,16,85,35,0,168,67,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,16,50,35,0,0,21,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,80,235,34,0,152,215,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,192,200,34,0,120,184,34,0,0,0,0,0,128,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,240,165,34,0,32,148,34,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,176,134,34,0,136,119,34,0,0,0,0,0,128,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,200,102,34,0,16,78,34,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,192,39,34,0,200,22,34,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,120,8,34,0,216,249,33,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,216,230,33,0,240,216,33,0,0,0,0,0,128,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,0,206,33,0,16,196,33,0,0,0,0,0,128,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,40,188,33,0,128,169,33,0,0,0,0,0,128,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,96,79,38,0,192,24,38,0,0,0,0,0,128,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,128,237,37,0,64,192,37,0,0,0,0,0,128,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,192,158,37,0,232,112,37,0,0,0,0,0,128,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,160,47,37,0,216,7,37,0,0,0,0,0,128,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,72,224,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,136,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,35,0,112,0,0,0,152,118,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,0,80,21,0,0,0,255,255,255,127,21,0,0,0,80,0,0,80,20,0,0,0,221,126,121,108,20,0,0,0,255,255,255,127,20,0,0,0,35,194,48,76,19,0,0,0,172,31,30,94,19,0,0,0,99,227,53,84,18,0,0,0,23,51,186,72,17,0,0,0,213,174,170,66,16,0,0,0,52,18,73,114,16,0,0,0,236,74,67,105,15,0,0,0,154,230,232,90,14,0,0,0,84,74,236,76,13,0,0,0,120,105,0,125,13,0,0,0,0,106,255,99,12,0,0,0,20,62,73,89,11,0,0,0,91,164,34,78,10,0,0,0,152,228,117,69,9,0,0,0,228,214,48,104,9,0,0,0,12,117,234,91,8,0,0,0,97,24,134,97,7,0,0,0,97,24,134,97,6,0,0,0,97,24,134,97,5,0,0,0,97,24,134,97,4,0,0,0,97,24,134,97,3,0,0,0,248,92,16,0,240,92,16,0,224,92,16,0,192,92,16,0,128,92,16,0,0,92,16,0,1,0,0,0,0,0,0,0,12,0,8,0,140,0,8,0,76,0,8,0,204,0,8,0,44,0,8,0,172,0,8,0,108,0,8,0,236,0,8,0,28,0,8,0,156,0,8,0,92,0,8,0,220,0,8,0,60,0,8,0,188,0,8,0,124,0,8,0,252,0,8,0,2,0,8,0,130,0,8,0,66,0,8,0,194,0,8,0,34,0,8,0,162,0,8,0,98,0,8,0,226,0,8,0,18,0,8,0,146,0,8,0,82,0,8,0,210,0,8,0,50,0,8,0,178,0,8,0,114,0,8,0,242,0,8,0,10,0,8,0,138,0,8,0,74,0,8,0,202,0,8,0,42,0,8,0,170,0,8,0,106,0,8,0,234,0,8,0,26,0,8,0,154,0,8,0,90,0,8,0,218,0,8,0,58,0,8,0,186,0,8,0,122,0,8,0,250,0,8,0,6,0,8,0,134,0,8,0,70,0,8,0,198,0,8,0,38,0,8,0,166,0,8,0,102,0,8,0,230,0,8,0,22,0,8,0,150,0,8,0,86,0,8,0,214,0,8,0,54,0,8,0,182,0,8,0,118,0,8,0,246,0,8,0,14,0,8,0,142,0,8,0,78,0,8,0,206,0,8,0,46,0,8,0,174,0,8,0,110,0,8,0,238,0,8,0,30,0,8,0,158,0,8,0,94,0,8,0,222,0,8,0,62,0,8,0,190,0,8,0,126,0,8,0,254,0,8,0,1,0,8,0,129,0,8,0,65,0,8,0,193,0,8,0,33,0,8,0,161,0,8,0,97,0,8,0,225,0,8,0,17,0,8,0,145,0,8,0,81,0,8,0,209,0,8,0,49,0,8,0,177,0,8,0,113,0,8,0,241,0,8,0,9,0,8,0,137,0,8,0,73,0,8,0,201,0,8,0,41,0,8,0,169,0,8,0,105,0,8,0,233,0,8,0,25,0,8,0,153,0,8,0,89,0,8,0,217,0,8,0,57,0,8,0,185,0,8,0,121,0,8,0,249,0,8,0,5,0,8,0,133,0,8,0,69,0,8,0,197,0,8,0,37,0,8,0,165,0,8,0,101,0,8,0,229,0,8,0,21,0,8,0,149,0,8,0,85,0,8,0,213,0,8,0,53,0,8,0,181,0,8,0,117,0,8,0,245,0,8,0,13,0,8,0,141,0,8,0,77,0,8,0,205,0,8,0,45,0,8,0,173,0,8,0,109,0,8,0,237,0,8,0,29,0,8,0,157,0,8,0,93,0,8,0,221,0,8,0,61,0,8,0,189,0,8,0,125,0,8,0,253,0,8,0,19,0,9,0,19,1,9,0,147,0,9,0,147,1,9,0,83,0,9,0,83,1,9,0,211,0,9,0,211,1,9,0,51,0,9,0,51,1,9,0,179,0,9,0,179,1,9,0,115,0,9,0,115,1,9,0,243,0,9,0,243,1,9,0,11,0,9,0,11,1,9,0,139,0,9,0,139,1,9,0,75,0,9,0,75,1,9,0,203,0,9,0,203,1,9,0,43,0,9,0,43,1,9,0,171,0,9,0,171,1,9,0,107,0,9,0,107,1,9,0,235,0,9,0,235,1,9,0,27,0,9,0,27,1,9,0,155,0,9,0,155,1,9,0,91,0,9,0,91,1,9,0,219,0,9,0,219,1,9,0,59,0,9,0,59,1,9,0,187,0,9,0,187,1,9,0,123,0,9,0,123,1,9,0,251,0,9,0,251,1,9,0,7,0,9,0,7,1,9,0,135,0,9,0,135,1,9,0,71,0,9,0,71,1,9,0,199,0,9,0,199,1,9,0,39,0,9,0,39,1,9,0,167,0,9,0,167,1,9,0,103,0,9,0,103,1,9,0,231,0,9,0,231,1,9,0,23,0,9,0,23,1,9,0,151,0,9,0,151,1,9,0,87,0,9,0,87,1,9,0,215,0,9,0,215,1,9,0,55,0,9,0,55,1,9,0,183,0,9,0,183,1,9,0,119,0,9,0,119,1,9,0,247,0,9,0,247,1,9,0,15,0,9,0,15,1,9,0,143,0,9,0,143,1,9,0,79,0,9,0,79,1,9,0,207,0,9,0,207,1,9,0,47,0,9,0,47,1,9,0,175,0,9,0,175,1,9,0,111,0,9,0,111,1,9,0,239,0,9,0,239,1,9,0,31,0,9,0,31,1,9,0,159,0,9,0,159,1,9,0,95,0,9,0,95,1,9,0,223,0,9,0,223,1,9,0,63,0,9,0,63,1,9,0,191,0,9,0,191,1,9,0,127,0,9,0,127,1,9,0,255,0,9,0,255,1,9,0,0,0,7,0,64,0,7,0,32,0,7,0,96,0,7,0,16,0,7,0,80,0,7,0,48,0,7,0,112,0,7,0,8,0,7,0,72,0,7,0,40,0,7,0,104,0,7,0,24,0,7,0,88,0,7,0,56,0,7,0,120,0,7,0,4,0,7,0,68,0,7,0,36,0,7,0,100,0,7,0,20,0,7,0,84,0,7,0,52,0,7,0,116,0,7,0,3,0,8,0,131,0,8,0,67,0,8,0,195,0,8,0,35,0,8,0,163,0,8,0,99,0,8,0,227,0,8,0,232,127,8,0,104,185,22,0,1,1,0,0,30,1,0,0,15,0,0,0,0,0,0,0,0,0,5,0,16,0,5,0,8,0,5,0,24,0,5,0,4,0,5,0,20,0,5,0,12,0,5,0,28,0,5,0,2,0,5,0,18,0,5,0,10,0,5,0,26,0,5,0,6,0,5,0,22,0,5,0,14,0,5,0,30,0,5,0,1,0,5,0,17,0,5,0,9,0,5,0,25,0,5,0,5,0,5,0,21,0,5,0,13,0,5,0,29,0,5,0,3,0,5,0,19,0,5,0,11,0,5,0,27,0,5,0,7,0,5,0,23,0,5,0,128,132,8,0,224,185,22,0,0,0,0,0,30,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,88,186,22,0,0,0,0,0,19,0,0,0,7,0,0,0,0,0,0,0,176,61,35,0,112,0,0,0,32,107,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,1,0,0,0,0,0,0,0,13,0,0,0,13,0,0,0,2,0,0,0,13,0,0,0,0,0,0,0,13,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,13,0,0,0,1,0,0,0,5,0,0,0,13,0,0,0,3,0,0,0,2,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,7,0,0,0,6,0,0,0,13,0,0,0,4,0,0,0,8,0,0,0,13,0,0,0,6,0,0,0,5,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,10,0,0,0,9,0,0,0,13,0,0,0,7,0,0,0,11,0,0,0,13,0,0,0,9,0,0,0,8,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,114,3,0,0,82,1,0,0,48,6,0,0,74,6,0,0,0,0,0,0,140,1,0,0,108,0,0,0,198,1,0,0,170,0,0,0,28,0,0,0,0,0,0,0,144,0,0,0,0,0,0,255,0,1,255,0,1,0,255,255,255,1,1,255,1,1,0,0,0,0,0,0,104,79,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,210,34,0,88,17,34,0,4,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,16,0,1,0,0,0,0,0,208,120,33,0,104,255,32,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,79,64,16,0,1,0,0,0,0,0,24,155,32,0,152,63,32,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,24,155,32,0,112,37,40,0,248,198,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,24,155,32,0,32,97,39,0,200,19,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,24,155,32,0,168,207,38,0,88,139,38,0,8,5,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,79,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,2,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,68,35,0,112,0,0,0,232,134,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,63,38,0,112,0,0,0,112,165,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,6,38,0,112,0,0,0,16,114,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,4,4,4,4,8,8,8,8,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,9,9,9,9,10,10,10,10,12,12,12,12,12,12,12,12,20,20,20,20,20,20,20,20,0,0,0,0,0,12,0,36,0,18,0,6,0,18,0,18,0,0,0,0,7,158,0,3,132,1,1,1,128,0,86,165,59,244,129,131,73,128,119,224,0,0,0,0,195,193,66,73,59,250,130,131,73,128,119,224,0,0,0,0,195,194,192,196,0,0,0,0,0,0,0,0,0,0,151,17,6,3,2,1,0,0,0,0,1,0,0,0,0,0,0,0,254,254,0,0,0,0,0,0,24,78,40,0,112,0,0,0,208,195,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,11,12,14,12,10,16,14,13,14,18,17,16,19,24,40,26,24,22,22,24,49,35,37,29,40,58,51,61,60,57,51,56,55,64,72,92,78,64,68,87,69,55,56,80,109,81,87,95,98,103,104,103,62,77,113,121,112,100,120,92,101,103,99,17,18,18,24,21,24,47,26,26,47,99,66,56,66,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,10,7,7,8,7,6,10,8,8,8,11,10,10,11,14,24,16,14,13,13,14,29,21,22,17,24,35,31,37,36,34,31,34,33,38,43,55,47,38,41,52,41,33,34,48,65,49,52,57,59,62,62,62,37,46,68,73,67,60,72,55,61,62,59,10,11,11,14,13,14,28,16,16,28,59,40,34,40,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,6,4,5,6,5,4,6,6,5,6,7,7,6,8,10,16,10,10,9,9,10,20,14,15,12,16,23,20,24,24,23,20,22,22,26,29,37,31,26,27,35,28,22,22,32,44,32,35,38,39,41,42,41,25,31,45,48,45,40,48,37,40,41,40,7,7,7,10,8,10,19,10,10,19,40,26,22,26,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,5,3,4,4,4,3,5,4,4,4,5,5,5,6,7,12,8,7,7,7,7,15,11,11,9,12,17,15,18,18,17,15,17,17,19,22,28,23,19,20,26,21,17,17,24,33,24,26,29,29,31,31,31,19,23,34,36,34,30,36,28,30,31,30,5,5,5,7,6,7,14,8,8,14,30,20,17,20,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,3,2,2,3,2,2,3,3,3,3,4,3,3,4,5,8,5,5,4,4,5,10,7,7,6,8,12,10,12,12,11,10,11,11,13,14,18,16,13,14,17,14,11,11,16,22,16,17,19,20,21,21,21,12,15,23,24,22,20,24,18,20,21,20,3,4,4,5,4,5,9,5,5,9,20,13,11,13,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,13,9,10,11,10,8,13,11,10,11,14,14,13,15,19,32,21,19,18,18,19,39,28,30,23,32,46,41,49,48,46,41,45,44,51,58,74,62,51,54,70,55,44,45,64,87,65,70,76,78,82,83,82,50,62,90,97,90,80,96,74,81,82,79,14,14,14,19,17,19,38,21,21,38,79,53,45,53,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,32,22,24,28,24,20,32,28,26,28,36,34,32,38,48,80,52,48,44,44,48,98,70,74,58,80,116,102,122,120,114,102,112,110,128,144,184,156,128,136,174,138,110,112,160,218,162,174,190,196,206,208,206,124,154,226,242,224,200,240,184,202,206,198,34,36,36,48,42,48,94,52,52,94,198,132,112,132,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,2,1,1,1,1,1,2,1,1,1,2,2,2,2,2,4,3,2,2,2,2,5,4,4,3,4,6,5,6,6,6,5,6,6,6,7,9,8,6,7,9,7,6,6,8,11,8,9,10,10,10,10,10,6,8,11,12,11,10,12,9,10,10,10,2,2,2,2,2,2,5,3,3,5,10,7,6,7,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,2,2,2,2,2,1,2,2,2,2,3,2,2,3,3,6,4,3,3,3,3,7,5,5,4,6,8,7,9,8,8,7,8,8,9,10,13,11,9,10,12,10,8,8,11,15,11,12,13,14,14,15,14,9,11,16,17,16,14,17,13,14,14,14,2,3,3,3,3,3,7,4,4,7,14,9,8,9,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,20,14,15,18,15,13,20,18,16,18,23,21,20,24,30,50,33,30,28,28,30,61,44,46,36,50,73,64,76,75,71,64,70,69,80,90,115,98,80,85,109,86,69,70,100,136,101,109,119,123,129,130,129,78,96,141,151,140,125,150,115,126,129,124,21,23,23,30,26,30,59,33,33,59,124,83,70,83,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,16,11,12,14,12,10,16,14,13,14,18,17,16,19,24,40,26,24,22,22,24,49,35,37,29,40,58,51,61,60,57,51,56,55,64,72,92,78,64,68,87,69,55,56,80,109,81,87,95,98,103,104,103,62,77,113,121,112,100,120,92,101,103,99,17,18,18,24,21,24,47,26,26,47,99,66,56,66,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,10,7,7,8,7,6,10,8,8,8,11,10,10,11,14,24,16,14,13,13,14,29,21,22,17,24,35,31,37,36,34,31,34,33,38,43,55,47,38,41,52,41,33,34,48,65,49,52,57,59,62,62,62,37,46,68,73,67,60,72,55,61,62,59,10,11,11,14,13,14,28,16,16,28,59,40,34,40,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,59,6,4,5,6,5,4,6,6,5,6,7,7,6,8,10,16,10,10,9,9,10,20,14,15,12,16,23,20,24,24,23,20,22,22,26,29,37,31,26,27,35,28,22,22,32,44,32,35,38,39,41,42,41,25,31,45,48,45,40,48,37,40,41,40,7,7,7,10,8,10,19,10,10,19,40,26,22,26,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,5,3,4,4,4,3,5,4,4,4,5,5,5,6,7,12,8,7,7,7,7,15,11,11,9,12,17,15,18,18,17,15,17,17,19,22,28,23,19,20,26,21,17,17,24,33,24,26,29,29,31,31,31,19,23,34,36,34,30,36,28,30,31,30,5,5,5,7,6,7,14,8,8,14,30,20,17,20,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,3,2,2,3,2,2,3,3,3,3,4,3,3,4,5,8,5,5,4,4,5,10,7,7,6,8,12,10,12,12,11,10,11,11,13,14,18,16,13,14,17,14,11,11,16,22,16,17,19,20,21,21,21,12,15,23,24,22,20,24,18,20,21,20,3,4,4,5,4,5,9,5,5,9,20,13,11,13,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,13,9,10,11,10,8,13,11,10,11,14,14,13,15,19,32,21,19,18,18,19,39,28,30,23,32,46,41,49,48,46,41,45,44,51,58,74,62,51,54,70,55,44,45,64,87,65,70,76,78,82,83,82,50,62,90,97,90,80,96,74,81,82,79,14,14,14,19,17,19,38,21,21,38,79,53,45,53,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,79,32,22,24,28,24,20,32,28,26,28,36,34,32,38,48,80,52,48,44,44,48,98,70,74,58,80,116,102,122,120,114,102,112,110,128,144,184,156,128,136,174,138,110,112,160,218,162,174,190,196,206,208,206,124,154,226,242,224,200,240,184,202,206,198,34,36,36,48,42,48,94,52,52,94,198,132,112,132,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,198,2,1,1,1,1,1,2,1,1,1,2,2,2,2,2,4,3,2,2,2,2,5,4,4,3,4,6,5,6,6,6,5,6,6,6,7,9,8,6,7,9,7,6,6,8,11,8,9,10,10,10,10,10,6,8,11,12,11,10,12,9,10,10,10,2,2,2,2,2,2,5,3,3,5,10,7,6,7,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,2,2,2,2,2,1,2,2,2,2,3,2,2,3,3,6,4,3,3,3,3,7,5,5,4,6,8,7,9,8,8,7,8,8,9,10,13,11,9,10,12,10,8,8,11,15,11,12,13,14,14,15,14,9,11,16,17,16,14,17,13,14,14,14,2,3,3,3,3,3,7,4,4,7,14,9,8,9,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,20,14,15,18,15,13,20,18,16,18,23,21,20,24,30,50,33,30,28,28,30,61,44,46,36,50,73,64,76,75,71,64,70,69,80,90,115,98,80,85,109,86,69,70,100,136,101,109,119,123,129,130,129,78,96,141,151,140,125,150,115,126,129,124,21,23,23,30,26,30,59,33,33,59,124,83,70,83,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,124,255,218,0,12,3,1,0,2,17,3,17,0,63,0,0,0,255,192,0,17,8,0,240,1,64,3,1,34,0,2,17,1,3,17,1,0,0,0,0,0,255,219,0,132,0,5,3,4,4,4,3,5,4,4,4,6,5,5,6,8,13,8,8,7,7,8,16,12,12,10,13,20,17,21,20,19,17,19,19,22,24,31,26,22,23,30,23,19,19,27,37,28,30,32,33,35,35,35,21,26,39,41,38,34,41,31,34,35,34,1,5,6,6,8,7,8,16,8,8,16,34,22,19,22,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,0,0,255,196,1,162,0,0,1,5,1,1,1,1,1,1,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,1,0,3,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,16,0,2,1,3,3,2,4,3,5,5,4,4,0,0,1,125,1,2,3,0,4,17,5,18,33,49,65,6,19,81,97,7,34,113,20,50,129,145,161,8,35,66,177,193,21,82,209,240,36,51,98,114,130,9,10,22,23,24,25,26,37,38,39,40,41,42,52,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,225,226,227,228,229,230,231,232,233,234,241,242,243,244,245,246,247,248,249,250,17,0,2,1,2,4,4,3,4,7,5,4,4,0,1,2,119,0,1,2,3,17,4,5,33,49,6,18,65,81,7,97,113,19,34,50,129,8,20,66,145,161,177,193,9,35,51,82,240,21,98,114,209,10,22,36,52,225,37,241,23,24,25,26,38,39,40,41,42,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,130,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,226,227,228,229,230,231,232,233,234,242,243,244,245,246,247,248,249,250,0,0,0,0,0,1,2,3,6,10,15,21,235,241,246,250,253,254,255,0,0,1,2,3,6,10,15,21,0,255,254,253,250,246,241,235,0,0,8,0,16,0,32,0,48,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,176,0,192,0,208,0,224,0,240,0,0,1,16,1,32,1,48,1,64,1,80,1,96,1,112,1,128,1,144,1,160,1,176,1,192,1,208,1,224,1,240,1,0,2,8,2,16,2,24,2,32,2,40,2,48,2,56,2,64,2,72,2,80,2,88,2,96,2,104,2,112,2,120,2,128,2,136,2,144,2,152,2,160,2,168,2,176,2,184,2,192,2,200,2,208,2,216,2,224,2,232,2,240,2,248,2,0,3,8,3,16,3,24,3,32,3,40,3,48,3,56,3,64,3,72,3,80,3,88,3,96,3,104,3,112,3,120,3,128,3,136,3,144,3,152,3,160,3,168,3,176,3,184,3,192,3,200,3,208,3,216,3,224,3,232,3,240,3,248,3,0,4,64,4,128,4,192,4,0,5,64,5,128,5,192,5,0,6,64,6,128,6,192,6,0,7,64,7,128,7,192,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,20,0,24,0,28,0,32,0,48,0,64,152,155,38,0,112,0,0,0,208,159,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,178,32,0,112,0,0,0,0,0,0,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,92,39,0,112,0,0,0,64,135,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+552960);
/* memory initializer */ allocate([4,0,0,0,33,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,0,218,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,7,0,0,78,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,33,40,0,112,0,0,0,64,135,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,1,3,2,1,1,0,0,0,0,4,8,12,16,20,24,28,32,36,40,44,48,52,56,60,65,69,73,77,81,85,89,93,97,101,105,109,113,117,121,125,130,134,138,142,146,150,154,158,162,166,170,174,178,182,186,190,195,199,203,207,211,215,219,223,227,231,235,239,243,247,251,255,104,113,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,183,35,0,168,210,34,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,176,17,34,0,168,210,34,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,248,120,33,0,144,255,32,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,40,155,32,0,144,255,32,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,192,63,32,0,96,40,40,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,192,0,0,0,0,0,0,62,64,16,0,1,0,0,0,0,0,40,199,39,0,96,40,40,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,192,0,0,0,0,0,0,62,64,16,0,1,0,0,0,0,0,40,97,39,0,224,19,39,0,24,0,0,0,4,0,0,0,205,204,204,204,204,204,236,191,205,204,204,204,204,204,236,191,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,184,207,38,0,224,19,39,0,24,0,0,0,4,0,0,0,205,204,204,204,204,204,236,191,205,204,204,204,204,204,236,191,0,0,0,0,0,0,20,64,16,0,1,0,0,0,0,0,136,139,38,0,144,79,38,0,28,0,0,0,4,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,192,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,64,25,38,0,144,79,38,0,28,0,0,0,4,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,192,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,200,237,37,0,128,192,37,0,32,0,0,0,1,0,0,0,225,255,255,255,255,255,255,255,0,0,0,0,0,0,63,192,0,0,0,0,0,0,62,64,16,0,1,0,0,0,0,0,200,158,37,0,128,192,37,0,32,0,0,0,1,0,0,0,225,255,255,255,255,255,255,255,0,0,0,0,0,0,63,192,0,0,0,0,0,0,62,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,113,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,224,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,77,35,0,112,0,0,0,160,153,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,66,73,0,0,0,0,0,80,66,73,0,0,0,0,0,0,0,0,0,3,1,1,1,2,2,2,3,3,3,4,4,0,1,2,3,0,1,2,3,1,2,3,1,2,3,2,3,0,0,0,0,3,1,1,1,2,2,2,3,3,3,4,4,0,1,2,3,0,1,2,3,1,2,3,1,2,3,2,3,128,2,0,0,224,1,0,0,208,2,0,0,224,1,0,0,208,2,0,0,64,2,0,0,96,1,0,0,32,1,0,0,96,1,0,0,240,0,0,0,160,0,0,0,128,0,0,0,0,2,0,0,128,1,0,0,128,2,0,0,96,1,0,0,128,2,0,0,240,0,0,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,8,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,17,0,3,0,51,0,51,51,255,0,255,255,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,3,0,0,0,0,0,0,3,3,3,3,0,0,0,0,15,15,0,0,0,0,0,0,15,15,15,15,0,0,0,0,15,15,15,15,15,15,15,15,255,255,255,255,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,255,3,1,1,3,0,0,0,2,0,0,0,2,0,0,0,0,63,1,22,2,44,3,90,5,81,7,31,8,86,9,58,10,36,12,68,13,39,14,73,15,53,16,69,17,57,19,88,20,34,21,71,24,46,25,94,26,54,28,75,29,50,32,70,33,92,35,74,38,85,40,56,42,87,43,65,45,59,48,79,49,93,51,89,55,95,61,76,67,83,77,80,0,0,0,0,232,62,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,6,0,0,252,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,106,36,0,248,84,35,0,8,0,0,0,3,0,0,0,0,0,0,0,0,128,123,64,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,104,134,34,0,248,84,35,0,8,0,0,0,3,0,0,0,0,0,0,0,0,128,123,64,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,192,205,33,0,96,76,33,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,80,221,32,0,96,76,33,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,224,124,32,0,168,34,32,0,28,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,64,10,40,0,168,34,32,0,28,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,128,163,39,0,0,68,39,0,32,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,8,252,38,0,0,68,39,0,32,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,88,182,38,0,64,119,38,0,24,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,156,32,0,112,0,0,0,96,159,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,221,95,63,77,78,65,63,218,115,233,62,22,81,243,61,192,237,233,189,75,5,53,190,1,189,208,189,3,210,126,60,191,67,177,61,167,35,160,61,219,220,152,60,59,167,25,189,143,254,87,189,178,241,224,188,161,76,35,60,145,9,248,60,129,4,197,60,101,54,72,59,113,29,99,188,44,102,132,188,100,93,220,187,209,4,138,59,159,117,13,60,58,119,187,59,0,0,0,128,121,35,115,187,237,211,113,187,216,244,160,186,50,174,184,58,137,12,43,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,4,9,1,12,5,13,16,24,20,25,17,28,21,29,32,40,36,41,33,44,37,45,18,26,22,27,19,30,23,31,2,10,6,11,3,14,7,15,48,56,52,57,49,60,53,61,34,42,38,43,35,46,39,47,50,58,54,59,51,62,55,63,32,144,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,190,36,0,80,149,35,0,8,0,0,0,3,0,0,0,252,169,241,210,77,98,80,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,48,185,34,0,80,149,35,0,8,0,0,0,3,0,0,0,252,169,241,210,77,98,80,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,104,250,33,0,56,105,33,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,24,245,64,8,0,1,0,0,0,0,0,0,243,32,0,56,105,33,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,24,245,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,144,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,24,34,0,112,0,0,0,200,162,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,5,2,3,4,5,6,6,8,8,7,7,8,8,73,110,116,101,114,112,108,97,121,32,77,86,69,32,70,105,108,101,26,0,26,0,0,0,0,0,0,0,255,1,0,0,1,255,0,0,255,0,1,0,255,1,1,0,0,255,1,0,1,255,1,0,255,255,1,0,1,0,255,0,0,1,255,0,1,1,255,0,255,1,255,0,1,255,255,0,255,0,0,1,255,1,0,1,0,255,0,1,0,0,0,0,1,255,0,1,255,255,0,1,255,0,1,1,255,1,1,1,0,255,1,1,1,255,1,1,255,255,1,1,0,0,255,1,1,0,255,1,255,0,255,1,0,1,255,1,1,1,255,1,255,1,255,1,0,255,255,1,1,255,255,1,0,0,0,0,255,255,255,1,1,0,0,255,0,1,0,255,1,1,0,255,255,1,0,255,1,255,0,255,0,0,1,255,1,0,1,255,255,0,1,255,0,1,1,255,1,1,1,255,255,1,1,255,0,255,1,255,1,255,1,255,255,255,1,255,0,0,0,0,1,0,255,255,0,1,255,255,1,1,255,255,255,1,255,255,1,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,1,0,0,0,0,0,0,18,0,9,0,0,0,3,0,6,0,0,15,0,0,0,12,0,0,0,0,24,21,0,0,0,0,0,0,238,0,254,255,0,241,0,2,0,0,3,0,253,247,0,244,0,0,0,0,250,0,0,0,232,235,0,0,176,2,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,1,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,70,36,0,128,61,35,0,4,0,0,0,69,90,73,83,224,111,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,216,192,33,0,128,61,35,0,4,0,0,0,69,90,73,83,224,111,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,152,64,33,0,160,212,32,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,152,64,33,0,224,116,32,0,240,26,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,152,64,33,0,24,3,40,0,32,150,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,152,64,33,0,72,60,39,0,32,56,39,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,56,242,38,0,136,171,38,0,12,0,0,0,84,65,82,86,184,110,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,48,55,38,0,136,171,38,0,12,0,0,0,84,65,82,86,184,110,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,2,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,35,32,0,112,0,0,0,64,166,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,45,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,5,0,0,150,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,80,36,0,16,68,35,0,4,0,0,0,69,90,73,83,232,119,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,196,33,0,16,68,35,0,4,0,0,0,69,90,73,83,232,119,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,68,33,0,64,215,32,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,8,119,32,0,224,28,32,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,8,119,32,0,248,4,40,0,40,154,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,119,32,0,88,63,39,0,128,247,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,119,32,0,200,177,38,0,144,115,38,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,200,177,38,0,120,59,38,0,32,5,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,177,38,0,224,218,37,0,200,178,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,200,177,38,0,192,148,37,0,152,83,37,0,40,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,192,148,37,0,0,29,37,0,24,251,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,192,148,37,0,0,209,36,0,16,179,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,192,148,37,0,120,150,36,0,128,122,36,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,192,148,37,0,248,95,36,0,112,69,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,192,148,37,0,24,48,36,0,232,245,35,0,44,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,36,192,0,0,0,0,0,0,36,64,16,0,1,0,0,0,0,0,160,208,35,0,128,183,35,0,76,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,160,208,35,0,104,161,35,0,224,140,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,160,208,35,0,144,117,35,0,248,97,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,160,208,35,0,32,78,35,0,240,60,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,160,208,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,45,35,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,71,32,0,112,0,0,0,16,169,8,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,223,255,255,255,255,255,255,255,255,253,207,255,255,255,255,221,252,205,255,255,255,204,203,188,223,255,253,219,201,105,188,255,252,255,185,66,90,205,255,253,220,98,3,155,207,255,253,201,83,74,204,255,255,255,186,154,188,255,255,252,220,188,188,255,255,255,254,204,205,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,240,0,0,0,255,255,223,253,255,255,255,255,255,253,205,255,255,255,252,252,204,207,223,255,255,219,169,155,207,223,255,203,151,103,155,255,255,220,167,66,71,173,255,255,201,99,3,105,191,255,252,167,83,71,172,223,253,220,151,119,140,189,255,255,204,170,171,207,255,255,255,204,204,207,255,255,255,254,255,239,255,255,255,253,255,220,255,223,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,185,175,255,255,255,255,150,86,159,255,255,255,166,67,71,239,255,255,249,83,3,106,255,255,255,166,67,70,175,255,255,255,150,86,159,255,255,255,255,201,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,239,255,255,255,255,255,255,255,255,253,221,255,255,253,255,253,253,255,255,255,255,221,219,188,223,255,255,255,250,67,107,255,223,255,253,163,2,173,255,255,253,251,82,58,223,255,255,255,203,170,206,255,223,255,254,221,223,255,255,255,255,237,253,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,240,0,0,0,255,207,204,255,255,255,255,255,191,255,204,202,255,207,251,170,170,207,203,252,255,170,169,153,172,191,252,169,152,136,153,170,207,202,168,83,88,159,204,204,185,115,2,104,172,207,202,152,83,55,155,172,251,170,151,120,138,251,255,250,187,153,154,171,255,255,235,186,170,172,203,255,191,188,188,207,255,255,207,252,252,255,255,207,160,0,0,0,175,255,255,255,255,255,255,255,254,253,252,255,255,255,252,171,186,252,255,255,255,169,119,120,175,255,255,168,101,69,104,255,252,251,116,51,53,123,255,255,183,67,35,70,175,255,203,117,51,53,122,204,255,248,101,69,104,172,207,204,168,119,120,191,255,255,255,185,153,252,255,255,255,255,254,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,218,252,255,255,252,251,154,153,186,255,255,251,151,119,119,156,207,252,152,101,69,104,175,255,201,117,51,53,121,255,251,134,67,35,71,159,255,201,117,51,53,123,191,255,168,101,69,104,175,255,250,168,119,120,155,255,255,255,251,153,187,255,255,255,254,206,255,207,255,255,255,255,255,255,255,240,0,0,0,255,255,253,222,255,255,255,255,220,187,188,239,255,255,219,153,137,172,223,255,219,151,102,103,156,255,236,151,101,69,103,172,255,185,101,51,53,105,191,251,134,67,51,70,155,238,185,101,51,53,105,190,253,167,101,69,103,172,223,219,151,102,103,155,223,255,220,169,137,155,207,255,255,220,187,188,222,255,255,255,255,239,239,255,240,0,0,0,255,255,255,255,252,255,255,255,255,251,187,255,255,255,255,170,153,171,255,255,250,152,118,103,172,207,250,167,100,69,103,155,255,248,116,51,52,104,175,251,150,67,51,70,139,255,249,117,67,53,105,191,204,152,101,69,103,154,191,255,152,102,104,143,255,255,255,152,136,175,255,255,255,255,186,186,190,255,255,255,223,255,255,255,192,0,0,0,255,255,255,255,255,255,255,255,255,255,250,255,255,170,255,249,175,255,255,255,255,250,136,127,175,250,255,248,117,85,121,255,255,249,117,50,52,138,255,255,184,67,34,88,255,255,207,149,51,70,122,255,250,255,117,70,121,250,255,175,249,137,138,254,255,255,255,255,175,170,255,255,255,255,250,255,255,255,175,255,255,250,255,250,144,0,0,0,188,186,170,153,170,189,187,186,153,136,137,155,204,186,152,119,119,120,154,186,152,118,101,102,120,171,168,118,85,69,86,121,169,135,85,68,68,103,138,152,117,68,68,69,104,154,135,101,68,69,103,138,169,118,85,69,86,121,171,152,118,85,86,120,154,186,152,119,119,120,154,205,203,169,136,137,170,187,221,202,169,154,171,204,176,0,0,0,189,202,170,170,171,206,220,203,169,136,137,155,205,187,152,135,119,120,171,218,168,118,101,102,120,172,169,118,85,68,86,121,170,151,101,68,68,103,154,168,117,68,52,69,121,154,135,101,68,69,103,154,185,118,85,69,86,121,171,168,118,101,102,120,187,203,168,119,119,120,171,189,203,169,152,153,170,205,253,251,170,171,171,204,192,0,0,0,205,203,170,170,171,206,237,203,169,136,137,171,206,203,152,119,119,120,155,203,168,118,101,86,120,171,169,118,85,69,86,121,186,135,85,68,69,87,138,168,117,68,52,69,120,170,135,101,68,69,103,138,169,118,85,69,86,121,171,168,118,101,102,120,171,203,152,119,119,120,155,205,203,169,136,137,171,205,237,203,170,170,171,205,192,0,0,0,205,203,185,170,187,255,221,203,169,137,137,155,239,187,168,119,119,120,155,252,168,118,85,86,120,171,185,118,85,69,86,121,187,151,101,68,68,87,138,168,117,68,68,69,104,170,135,101,68,69,87,154,185,118,85,69,86,121,187,152,118,85,102,120,171,251,168,119,119,120,171,189,251,169,136,137,172,204,188,203,186,170,170,187,160,0,0,0,172,171,169,170,171,204,220,186,152,136,136,154,189,186,152,119,119,120,155,202,168,118,101,86,120,171,169,118,85,69,86,121,186,135,85,68,69,87,137,152,117,68,68,69,104,154,135,85,68,69,87,137,168,118,85,85,86,121,171,168,118,85,86,120,154,203,168,119,119,120,155,220,203,169,136,137,154,189,203,203,169,169,170,187,176,0,0,0,175,255,191,255,255,255,255,191,255,255,255,255,255,251,191,255,255,255,255,255,255,255,169,175,255,255,255,251,150,86,159,255,255,255,166,50,54,175,255,255,249,99,18,106,255,255,255,150,51,54,191,255,255,255,150,86,154,255,255,255,255,218,154,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,247,86,252,207,255,255,246,50,57,255,255,255,248,98,18,111,255,255,255,246,67,55,255,255,255,255,166,88,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,234,255,255,255,255,255,150,86,159,255,255,255,182,67,54,255,255,255,251,98,18,91,255,255,255,214,66,54,255,255,255,255,150,86,159,255,255,255,255,250,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,143,255,255,255,255,249,67,95,255,255,255,255,163,17,223,255,255,255,255,97,62,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,138,255,255,255,255,248,83,94,255,255,255,255,147,17,143,255,255,255,254,81,57,255,255,255,255,255,136,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,172,187,170,170,172,222,203,186,169,152,153,171,222,186,152,119,119,120,171,234,168,118,101,102,121,172,169,134,84,68,86,121,170,135,101,68,69,87,154,169,117,68,52,69,120,154,135,101,68,69,103,154,185,134,85,69,86,137,172,168,118,101,102,120,154,204,168,135,119,137,155,191,219,169,152,153,155,188,223,203,170,185,171,187,160,0,0,0,188,203,170,154,171,206,205,203,153,136,137,155,205,202,152,119,103,120,155,203,168,118,101,86,120,171,169,118,85,69,86,121,170,135,101,68,69,87,138,152,101,68,68,69,120,170,135,85,68,69,87,138,169,118,85,69,86,121,171,168,118,85,102,120,155,203,168,119,103,120,155,205,219,169,136,137,155,205,220,219,170,169,171,190,176,0,0,0,188,187,170,170,171,205,220,203,153,136,137,171,205,187,152,119,119,120,155,203,168,118,85,86,120,171,169,118,85,68,86,121,170,135,101,68,69,87,138,168,117,68,68,69,104,170,135,85,68,69,103,137,169,118,85,69,86,121,171,168,118,101,102,120,170,203,152,119,119,120,154,189,203,169,136,137,171,187,221,203,170,154,170,187,176,0,0,0,223,236,186,170,189,239,221,203,169,153,154,189,207,219,152,119,119,136,172,222,169,118,85,102,121,159,185,134,85,69,86,137,187,151,101,68,69,103,155,184,117,68,52,69,121,170,151,100,68,69,87,155,201,134,85,68,86,121,188,168,118,85,102,121,191,252,168,135,119,120,170,255,252,170,153,153,172,207,255,203,186,171,188,190,176,0,0,0,188,187,187,155,187,254,205,204,169,153,153,172,237,204,168,135,119,136,171,203,168,118,86,102,121,188,169,134,85,68,86,121,202,151,101,68,68,103,138,169,117,68,52,69,121,187,151,100,68,69,103,154,185,134,84,69,86,137,188,169,118,102,102,121,172,252,168,135,119,121,155,222,220,169,153,154,171,189,189,219,186,170,187,205,176,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,247,127,252,175,255,255,246,50,111,255,255,255,255,98,3,255,255,255,255,255,99,95,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,191,191,255,255,255,255,255,191,255,255,255,255,255,255,204,207,191,255,255,255,255,186,153,187,255,255,252,187,134,86,155,255,255,251,167,66,54,175,255,255,249,98,19,89,255,255,255,166,50,71,175,239,255,255,150,87,154,204,255,255,251,170,170,239,255,255,255,255,251,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,153,155,255,255,255,250,134,86,139,255,255,255,166,66,54,175,255,255,249,82,19,88,255,255,255,165,51,54,159,255,255,254,134,86,139,255,255,255,254,168,154,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,119,127,255,255,255,255,117,69,104,207,255,255,181,67,53,143,255,255,248,67,35,87,207,255,255,165,50,52,143,255,255,255,100,68,111,255,255,255,255,135,152,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,237,175,255,255,255,243,63,255,255,255,255,244,2,255,255,255,255,255,82,55,255,255,255,255,249,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,143,255,255,240,0,0,0,143,248,255,255,255,255,254,239,255,255,255,255,255,136,238,239,255,255,255,255,143,248,103,135,255,255,255,248,118,84,119,239,255,255,132,51,53,127,255,248,134,83,35,87,255,255,255,101,51,53,120,255,255,248,85,68,88,238,238,254,254,103,136,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,252,204,252,255,255,255,188,169,169,207,255,252,186,152,119,137,191,255,185,135,102,103,138,207,186,135,101,68,103,159,251,168,101,67,69,105,207,234,118,67,51,70,143,252,168,101,67,52,104,175,249,151,100,68,87,175,255,250,151,102,103,156,255,255,251,169,153,155,255,255,255,255,203,204,239,255,255,255,255,255,255,255,240,0,0,0,255,253,223,255,255,255,255,237,220,205,207,255,255,204,203,169,154,188,255,253,219,168,118,120,173,255,220,168,101,69,104,191,254,202,117,51,53,122,207,252,166,67,35,71,156,255,201,117,51,53,121,206,253,184,101,69,104,172,223,252,168,118,120,171,223,255,253,186,153,171,207,255,255,253,221,205,223,223,255,255,255,253,255,255,208,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,157,255,175,255,255,255,175,119,138,255,255,255,249,117,69,104,255,255,255,132,51,53,154,255,255,246,67,35,71,255,255,255,117,51,53,122,255,255,248,100,69,105,255,255,255,151,134,120,159,255,255,175,255,175,255,255,255,255,255,223,255,252,255,255,255,255,255,255,175,240,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,238,221,221,221,93,221,77,221,221,214,221,213,221,221,93,221,109,221,221,213,221,221,214,221,221,109,221,221,221,221,221,221,214,221,221,214,213,221,93,109,85,221,13,85,101,221,93,221,102,221,221,221,221,213,213,93,93,214,221,221,221,221,214,213,109,109,109,212,109,221,221,221,221,221,221,221,221,221,221,221,85,214,221,222,224,0,0,0,155,155,169,155,172,204,250,186,187,169,170,191,255,170,170,152,136,136,173,249,153,136,118,102,121,170,153,152,117,84,86,143,250,169,117,67,52,104,171,186,134,83,51,86,138,188,184,100,51,69,121,172,203,134,84,85,103,138,172,202,118,103,120,137,187,255,185,120,136,154,187,159,253,249,171,154,171,170,255,252,250,171,153,170,128,0,0,0,204,188,187,188,187,187,187,188,203,187,187,187,187,187,187,188,203,187,187,187,187,187,180,187,187,187,187,180,68,180,43,188,204,203,187,51,75,187,187,187,180,187,68,59,187,187,187,187,179,180,187,187,187,187,180,68,59,187,187,187,180,179,187,188,204,204,204,203,180,187,187,187,187,187,187,204,204,204,204,204,204,203,204,204,192,0,0,0,119,103,118,103,119,102,102,103,119,119,102,102,102,102,102,103,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,118,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,102,103,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,112,0,0,0,0,0,0,160,255,35,3,64,0,0,0,224,240,122,11,192,0,0,0,192,163,123,9,64,0,0,0,160,213,252,252,191,0,0,0,32,124,194,201,191,0,0,0,128,168,157,247,63,0,0,0,32,150,137,251,191,0,0,0,224,104,71,239,63,0,0,0,160,192,166,193,191,0,0,0,224,96,112,216,191,0,0,0,64,178,140,209,63,0,0,0,192,169,11,177,63,0,0,0,96,252,138,214,191,0,0,0,160,60,28,216,63,0,0,0,64,157,172,206,191,0,0,0,96,172,148,177,63,0,0,0,64,201,170,0,64,0,0,0,224,178,85,8,192,0,0,0,224,104,163,9,64,0,0,0,0,187,14,6,192,0,0,0,64,63,247,247,63,0,0,0,96,197,239,213,191,0,0,0,192,109,244,230,191,0,0,0,32,230,45,241,63,0,0,0,128,126,92,240,191,0,0,0,128,196,32,226,63,0,0,0,96,5,215,202,191,0,0,0,192,165,188,176,191,0,0,0,192,233,108,186,63,0,0,0,96,225,67,177,191,0,0,0,64,133,72,116,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,4,0,0,0,0,0,0,96,1,250,6,64,0,0,0,160,80,42,20,192,0,0,0,160,41,250,24,64,0,0,0,160,194,100,23,192,0,0,0,192,110,167,13,64,0,0,0,0,205,202,240,191,0,0,0,64,170,237,242,191,0,0,0,96,196,230,0,64,0,0,0,192,30,141,254,191,0,0,0,64,225,248,239,63,0,0,0,192,80,224,197,191,0,0,0,128,189,223,212,191,0,0,0,96,172,10,217,63,0,0,0,128,112,51,209,191,0,0,0,32,77,1,185,63,0,0,0,32,135,9,152,191,0,0,0,160,38,107,5,64,0,0,0,128,213,82,19,192,0,0,0,0,203,71,26,64,0,0,0,160,44,212,29,192,0,0,0,96,194,231,26,64,0,0,0,96,133,100,19,192,0,0,0,96,101,84,0,64,0,0,0,0,156,107,230,63,0,0,0,32,75,161,7,192,0,0,0,160,245,81,16,64,0,0,0,64,243,188,16,192,0,0,0,96,66,166,10,64,0,0,0,32,166,241,0,192,0,0,0,0,64,35,236,63,0,0,0,32,188,66,160,191,0,0,0,0,255,31,219,191,0,0,0,0,1,165,222,63,0,0,0,160,208,182,214,191,0,0,0,64,93,101,198,63,0,0,0,0,91,47,175,191,0,0,0,0,57,35,250,63,0,0,0,32,167,23,2,192,0,0,0,192,249,66,3,64,0,0,0,160,200,18,5,192,0,0,0,128,252,38,1,64,0,0,0,32,147,11,253,191,0,0,0,96,83,78,241,63,0,0,0,128,49,127,230,191,0,0,0,160,65,120,196,63,0,0,0,128,250,69,165,63,0,0,0,160,156,211,210,191,0,0,0,160,2,30,208,63,0,0,0,128,66,197,209,191,0,0,0,160,143,52,196,63,0,0,0,0,82,6,186,191,0,0,0,96,231,60,145,63,0,0,0,224,38,71,234,63,0,0,0,160,22,26,240,191,0,0,0,192,13,243,227,63,0,0,0,0,43,183,240,191,0,0,0,224,128,166,228,63,0,0,0,128,110,9,236,191,0,0,0,160,215,181,224,63,0,0,0,0,55,148,229,191,0,0,0,192,80,197,220,63,0,0,0,160,130,209,224,191,0,0,0,160], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+563212);
/* memory initializer */ allocate([129,31,214,63,0,0,0,224,11,91,217,191,0,0,0,224,143,37,209,63,0,0,0,224,227,132,210,191,0,0,0,224,184,28,200,63,0,0,0,96,206,113,200,191,0,0,0,192,75,180,186,63,0,0,0,32,255,56,187,191,0,0,0,128,100,250,167,63,0,0,0,96,112,77,164,191,0,0,0,32,49,248,172,63,0,0,0,224,232,57,226,191,0,0,0,0,213,16,218,191,0,0,0,224,78,173,213,191,0,0,0,64,41,20,211,191,0,0,0,160,192,94,200,191,0,0,0,0,1,34,197,191,0,0,0,32,63,61,193,191,0,0,0,160,253,188,184,191,0,0,0,192,162,191,180,191,0,0,0,128,195,160,176,191,0,0,0,224,15,226,171,191,0,0,0,224,187,53,166,191,0,0,0,0,65,189,162,191,0,0,0,32,27,227,154,191,0,0,0,0,177,60,147,191,0,0,0,32,6,107,139,191,0,0,0,64,36,162,130,191,0,0,0,32,120,199,101,191,0,0,0,0,104,148,59,191,0,0,0,192,57,215,215,191,0,0,0,32,56,14,234,191,0,0,0,96,127,154,225,191,0,0,0,0,246,86,222,191,0,0,0,96,59,225,212,191,0,0,0,0,61,60,212,191,0,0,0,224,247,67,205,191,0,0,0,96,80,85,205,191,0,0,0,224,66,11,201,191,0,0,0,0,180,62,199,191,0,0,0,192,219,189,195,191,0,0,0,160,193,13,194,191,0,0,0,224,67,82,190,191,0,0,0,160,52,251,184,191,0,0,0,160,21,149,179,191,0,0,0,128,116,111,177,191,0,0,0,32,131,113,165,191,0,0,0,0,127,231,162,191,0,0,0,192,42,212,147,191,0,0,0,0,94,181,142,191,0,0,0,128,65,165,237,191,0,0,0,224,44,149,239,191,0,0,0,192,110,50,228,191,0,0,0,160,33,161,224,191,0,0,0,32,209,110,217,191,0,0,0,96,178,213,214,191,0,0,0,160,113,5,211,191,0,0,0,96,181,214,208,191,0,0,0,160,255,204,203,191,0,0,0,224,85,194,199,191,0,0,0,64,220,183,195,191,0,0,0,64,110,61,192,191,0,0,0,128,65,120,186,191,0,0,0,64,158,108,181,191,0,0,0,224,95,21,174,191,0,0,0,128,114,2,168,191,0,0,0,160,43,159,156,191,0,0,0,192,6,61,149,191,0,0,0,0,184,46,131,191,0,0,0,96,188,174,120,191,0,0,0,160,237,62,243,191,0,0,0,0,237,28,238,191,0,0,0,128,156,184,229,191,0,0,0,128,176,114,226,191,0,0,0,224,93,0,224,191,0,0,0,96,50,98,220,191,0,0,0,64,175,54,216,191,0,0,0,32,68,199,213,191,0,0,0,96,10,211,210,191,0,0,0,0,89,254,207,191,0,0,0,160,196,203,203,191,0,0,0,160,204,13,200,191,0,0,0,224,30,139,195,191,0,0,0,64,38,17,191,191,0,0,0,0,21,128,185,191,0,0,0,160,33,69,179,191,0,0,0,192,172,250,168,191,0,0,0,192,223,205,165,191,0,0,0,160,228,175,157,191,0,0,0,0,215,78,136,191,0,0,0,0,21,53,8,64,0,0,0,64,132,27,24,192,0,0,0,128,215,99,34,64,0,0,0,32,93,166,39,192,0,0,0,224,198,136,41,64,0,0,0,32,253,213,39,192,0,0,0,160,11,89,34,64,0,0,0,64,36,124,21,192,0,0,0,32,212,58,242,63,0,0,0,160,123,150,3,64,0,0,0,192,79,227,19,192,0,0,0,32,36,40,24,64,0,0,0,64,106,190,23,192,0,0,0,0,245,156,19,64,0,0,0,64,5,108,12,192,0,0,0,32,27,135,1,64,0,0,0,192,2,173,242,191,0,0,0,192,146,98,223,63,0,0,0,128,52,37,197,191,0,0,0,32,108,198,151,63,79,10,38,2,87,25,252,10,246,3,134,7,143,11,245,2,84,250,145,255,211,255,103,254,145,1,33,2,9,6,115,249,75,0,161,253,182,241,144,254,122,238,16,1,129,23,44,254,84,4,32,4,94,2,40,243,235,3,194,252,176,254,132,244,247,0,227,0,164,6,82,1,95,255,62,22,61,1,184,253,134,24,170,244,234,240,37,1,184,242,28,2,177,0,184,252,41,254,195,3,13,255,223,254,77,0,39,0,202,29,77,1,65,2,71,1,153,254,231,3,120,254,107,0,130,5,253,1,41,252,36,0,63,255,188,255,68,226,249,252,78,255,135,5,45,4,254,5,4,251,180,4,103,2,17,8,243,1,124,0,9,1,58,254,182,7,28,25,68,240,78,4,118,250,171,255,208,252,192,255,210,255,158,3,64,252,78,0,215,18,215,255,182,255,86,253,7,253,58,230,12,12,195,249,129,11,163,252,125,243,99,253,123,241,202,254,207,244,89,250,72,0,195,7,108,1,55,19,9,255,94,14,60,255,105,229,129,255,59,252,233,0,123,255,160,15,180,255,74,255,241,14,67,0,188,2,114,248,33,2,93,246,95,250,117,2,81,13,0,2,251,242,27,2,224,236,85,13,221,247,42,2,62,2,214,36,40,1,168,255,235,253,191,254,198,251,59,9,42,0,206,255,230,234,133,255,106,17,106,4,177,10,122,1,229,5,61,243,202,3,179,0,190,247,90,2,223,1,74,254,21,1,83,219,120,4,149,9,135,241,254,240,125,15,226,1,206,4,163,8,231,254,215,248,51,249,117,6,156,252,229,1,100,241,251,20,221,3,158,4,10,0,236,248,233,0,4,4,28,243,90,18,36,6,44,6,160,3,198,254,132,242,62,3,25,250,201,251,42,2,129,2,103,5,105,0,179,251,13,6,152,240,134,3,99,230,237,1,211,243,14,3,69,253,58,237,142,3,253,254,228,255,177,6,156,228,58,2,10,251,166,237,248,255,220,0,57,239,111,4,191,240,177,3,45,254,140,247,117,253,181,0,212,0,159,0,75,2,51,6,77,4,15,228,203,254,66,250,145,251,247,254,186,254,172,0,136,34,214,2,244,252,170,0,242,251,210,1,216,0,252,2,231,0,221,253,152,9,92,254,196,31,230,1,98,3,153,254,23,13,219,248,226,7,160,254,183,250,199,2,133,2,125,4,74,0,46,254,99,253,241,3,14,12,240,0,44,29,74,255,155,7,35,255,240,1,64,254,189,0,143,255,16,253,133,0,42,255,226,250,112,255,246,251,115,20,109,248,152,245,192,0,246,5,240,246,250,2,246,252,101,1,227,4,168,1,31,255,16,252,27,255,160,254,25,242,241,254,211,251,250,4,81,255,112,1,53,25,7,254,31,0,254,29,165,0,94,254,144,255,119,253,141,5,155,2,178,254,17,4,159,254,73,2,13,16,71,4,163,20,173,2,81,253,77,250,30,4,184,19,62,255,172,8,81,0,244,0,205,14,12,0,101,252,77,250,63,1,74,9,203,255,1,16,106,253,124,251,223,0,29,10,221,253,87,19,166,254,236,248,145,255,88,1,127,20,131,1,53,254,214,252,254,3,234,0,214,2,48,7,223,253,136,252,216,2,106,0,3,4,15,254,93,1,8,255,165,43,201,254,126,0,223,1,12,248,9,1,250,250,228,227,1,254,128,0,215,248,240,1,196,29,235,9,239,248,194,3,154,253,148,252,89,3,130,8,130,2,100,251,10,247,143,3,92,15,199,2,207,251,155,250,59,235,237,0,98,254,67,2,178,255,229,255,178,255,242,255,100,0,65,255,142,0,255,255,174,1,74,255,207,0,195,255,184,255,254,236,71,2,235,19,64,253,40,250,41,4,50,255,67,9,216,5,241,6,204,254,194,18,121,250,154,4,90,10,56,1,174,254,6,255,192,255,229,255,165,243,207,253,253,250,184,3,122,252,98,1,61,6,182,255,83,253,62,243,151,252,24,253,167,27,220,2,185,2,38,2,174,250,251,0,34,0,26,253,0,0,105,0,160,253,255,255,219,40,86,3,153,255,93,254,238,8,31,244,50,243,205,255,21,254,69,255,108,16,89,3,195,251,59,246,145,249,84,26,93,2,225,247,212,6,7,2,134,13,106,0,69,253,220,0,153,253,106,254,164,1,18,3,60,2,167,2,218,0,136,252,43,40,129,0,18,247,63,253,178,255,208,19,122,2,190,2,85,231,217,253,205,254,246,224,177,0,151,248,189,253,84,6,125,0,116,0,167,255,204,254,6,252,142,0,6,254,144,253,149,3,245,252,120,2,17,236,58,1,101,255,55,22,77,0,112,255,141,11,80,255,30,0,67,5,86,254,205,255,149,30,177,4,176,253,1,0,9,18,156,234,168,8,158,1,1,5,175,255,89,254,190,254,39,14,191,1,95,3,137,254,23,254,14,2,27,254,159,0,66,4,207,1,145,1,125,255,223,0,94,6,98,246,43,247,111,2,251,3,241,24,173,253,114,253,29,245,77,9,72,1,235,247,34,21,110,254,214,253,198,249,164,252,83,0,109,236,86,252,37,4,163,0,61,242,216,251,191,4,249,2,68,6,128,239,136,3,110,245,43,19,210,248,215,12,210,243,48,254,39,255,93,251,120,229,212,6,199,253,101,2,151,243,3,255,164,0,179,252,27,2,72,254,177,248,38,248,238,246,46,244,222,1,249,8,208,253,75,233,0,3,83,249,148,253,66,0,197,237,37,3,41,255,246,20,70,254,23,255,180,229,89,1,106,0,131,17,184,6,165,10,147,255,186,10,68,255,204,0,113,7,201,4,253,0,198,12,120,7,196,248,0,255,221,239,0,3,144,15,217,1,102,250,28,17,208,0,243,9,27,4,19,13,85,255,117,2,171,246,46,253,9,253,166,0,144,8,69,1,63,255,223,254,79,252,76,254,163,3,72,5,6,27,109,245,37,252,124,11,246,13,39,16,123,243,95,1,159,3,128,0,175,248,226,236,48,237,51,254,184,2,174,249,129,0,228,255,147,8,146,9,73,2,253,9,228,250,100,247,178,253,41,9,115,14,200,254,84,17,94,13,157,253,150,255,169,245,40,249,183,255,210,34,95,253,89,6,82,3,208,2,98,251,11,255,143,255,114,3,33,255,247,236,15,252,11,22,159,255,85,237,101,255,188,1,78,11,148,252,98,234,244,4,124,255,143,252,123,254,102,239,103,255,212,255,218,3,28,7,223,33,150,2,168,254,58,255,139,248,59,4,114,0,194,254,46,4,35,243,137,254,221,25,232,0,99,244,156,255,29,254,239,253,136,255,64,235,166,6,139,2,137,253,229,1,43,22,50,0,108,4,47,254,227,251,115,10,200,249,189,21,12,4,8,245,69,1,231,3,12,2,253,10,247,254,81,1,130,16,2,2,64,2,159,23,175,0,204,0,254,253,151,253,162,255,210,244,218,254,238,6,210,3,128,228,87,255,67,3,195,252,210,8,219,255,193,254,190,10,138,0,223,254,188,251,78,0,8,4,220,16,79,251,40,3,157,231,84,252,40,16,89,0,204,251,121,253,1,255,49,255,227,0,186,255,194,255,54,255,66,0,24,0,36,252,186,218,31,255,29,253,161,0,118,245,117,0,160,253,173,0,139,253,234,6,173,19,25,20,226,9,252,251,5,12,16,254,63,18,189,248,100,8,191,1,121,239,170,0,201,2,67,1,234,2,167,5,168,248,205,19,85,30,20,254,249,252,109,253,254,252,197,255,254,254,164,255,109,249,225,237,65,249,176,247,33,2,60,236,232,9,13,6,236,1,0,251,110,232,197,3,172,12,219,1,72,251,168,2,229,254,39,1,155,254,255,254,217,6,150,254,87,12,106,0,75,255,13,7,179,3,22,252,120,255,244,2,165,4,237,0,133,246,249,254,142,233,13,0,123,8,83,251,193,254,140,254,236,250,82,21,187,3,200,4,106,2,193,251,101,10,22,248,236,255,89,8,86,1,236,15,226,1,65,21,250,255,78,8,113,255,196,249,18,1,241,3,94,0,138,242,142,1,55,4,33,1,250,7,115,3,43,248,192,254,8,15,139,1,216,1,103,2,173,12,241,2,167,248,40,255,38,22,192,255,203,253,0,246,38,6,4,3,16,241,164,3,222,18,158,4,226,251,134,1,216,255,41,7,162,254,151,0,149,0,58,252,194,255,55,253,166,221,175,253,87,0,61,242,13,255,48,2,32,243,244,0,249,252,6,28,237,2,241,254,118,33,99,0,234,4,215,4,23,254,149,255,93,249,157,253,22,4,65,0,3,254,12,2,158,254,0,25,8,255,148,0,86,253,163,255,208,249,195,255,157,17,223,1,110,0,204,27,217,254,224,1,9,6,3,0,127,0,12,247,126,3,237,4,112,231,211,255,102,254,110,254,156,254,89,10,137,2,116,6,125,253,187,25,117,0,108,3,223,255,188,3,210,254,83,6,1,252,157,255,130,1,170,255,14,254,172,2,165,4,146,0,125,1,104,38,159,255,8,1,91,0,83,251,205,1,118,1,124,229,171,1,38,1,88,237,0,0,52,11,79,20,221,17,197,252,181,248,111,2,66,251,195,253,181,251,60,250,50,1,67,253,32,255,91,239,145,251,196,9,106,237,189,5,155,255,20,7,127,255,15,0,248,2,107,255,132,252,119,250,249,2,189,4,95,254,33,6,158,255,139,6,117,255,42,227,135,253,24,10,249,253,149,234,29,0,64,1,129,254,172,253,217,254,155,254,96,254,214,15,55,254,157,254,163,235,184,252,193,254,41,5,88,254,127,255,105,20,181,0,120,245,82,255,61,227,185,254,7,2,92,3,244,235,19,1,115,255,79,19,204,0,56,255,173,11,171,3,134,1,51,254,179,254,118,254,82,255,56,1,127,255,89,28,110,254,92,3,255,255,117,10,133,3,97,2,248,0,167,3,19,254,211,31,33,8,109,251,159,247,24,6,98,6,55,0,46,249,49,2,21,253,163,3,56,253,224,253,30,3,158,255,68,2,195,252,222,253,238,0,252,247,59,255,34,3,11,51,117,1,218,230,135,4,179,252,217,16,19,0,158,2,141,253,80,252,253,4,171,228,159,253,121,7,95,2,58,254,167,255,91,3,213,255,185,255,238,1,169,0,55,253,34,248,34,6,152,237,233,0,239,239,210,0,151,241,251,3,200,0,49,0,8,7,157,253,40,254,210,4,67,2,107,1,122,255,233,0,101,0,93,234,132,7,58,249,42,252,96,252,61,253,42,251,50,6,92,14,133,18,46,245,33,12,174,3,115,248,83,5,32,1,32,246,160,0,229,1,218,255,23,0,113,0,237,255,250,253,146,255,83,255,86,255,77,2,39,254,40,1,98,241,85,4,95,244,69,5,11,23,98,0,58,12,87,3,243,1,3,0,217,243,176,253,60,2,134,252,175,2,185,2,194,0,168,254,115,4,183,12,246,4,109,246,166,7,117,254,11,1,73,252,80,247,60,8,245,255,227,242,42,10,99,9,60,6,236,253,141,10,203,8,63,251,156,247,179,2,11,253,253,247,117,1,172,7,213,5,148,18,222,4,7,239,16,254,203,250,236,255,172,255,234,249,49,1,159,4,212,31,140,253,66,253,62,249,232,0,251,254,172,10,245,0,97,1,95,241,245,3,186,0,6,248,42,3,202,240,95,1,197,9,84,3,66,16,87,254,179,236,0,250,189,8,68,5,78,239,205,10,238,4,224,25,99,3,176,2,92,7,173,12,224,4,144,247,81,2,182,0,20,252,213,251,175,2,253,3,104,252,116,5,14,255,255,244,210,248,233,242,232,3,107,23,155,9,229,254,117,7,172,5,39,238,44,2,44,248,214,255,191,242,206,255,127,254,85,2,215,3,164,1,167,24,220,249,127,249,240,23,104,249,185,235,175,254,153,239,115,1,8,4,172,255,121,8,163,3,120,254,6,255,137,0,63,3,2,32,23,254,164,255,209,0,115,0,173,5,246,0,121,253,168,3,73,4,112,254,85,2,136,1,93,0,227,225,57,253,44,253,3,8,241,1,127,7,148,252,255,252,84,255,156,11,184,3,43,2,151,0,151,253,5,3,232,18,169,241,73,3,244,0,107,253,160,242,190,3,81,0,20,2,197,254,28,3,115,21,252,253,255,255,165,250,237,253,94,234,57,1,43,249,109,9,189,252,185,243,12,255,114,242,174,252,111,239,165,252,182,255,93,8,19,252,35,18,173,254,249,15,163,252,44,230,227,1,184,244,188,253,211,255,78,14,150,3,195,254,12,14,27,253,129,3,238,245,114,253,164,249,183,248,117,2,147,12,214,0,150,248,149,4,99,238,146,6,143,247,185,2,109,255,111,38,239,2,186,251,171,254,99,253,214,250,137,2,192,252,130,254,165,234,212,255,182,13,32,5,32,12,54,255,78,7,101,255,89,2,207,2,234,255,162,254,138,1,81,0,141,1,31,220,82,255,95,1,147,237,158,238,88,14,139,4,47,9,184,6,24,4,59,251,232,254,238,255,241,255,166,2,165,240,99,18,157,255,31,7,233,253,212,248,138,0,142,4,41,244,139,21,82,5,211,4,199,1,83,2,169,241,78,4,93,255,62,0,80,4,45,3,102,3,217,254,192,251,213,254,120,240,37,3,212,226,100,254,195,247,236,0,46,0,124,233,103,2,61,250,85,3,22,3,203,231,56,1,125,2,173,240,90,254,194,251,241,233,110,3,126,250,37,8,205,255,131,244,255,252,193,255,70,3,55,3,229,2,225,10,194,1,165,228,135,255,109,252,60,0,215,255,0,0,217,255,70,34,135,2,247,253,123,1,170,254,168,254,50,3,36,5,32,4,182,0,205,10,45,254,206,30,45,0,23,3,97,254,24,15,132,246,207,8,107,253,192,255,157,6,144,0,248,6,86,251,210,255,192,248,184,4,35,16,146,3,92,31,239,255,147,7,121,250,21,2,35,1,46,254,186,0,63,253,156,2,154,253,3,255,114,247,31,1,89,15,192,5,231,249,5,0,121,3,28,248,158,0,242,255,117,250,58,5,159,254,110,2,202,255,87,0,176,251,161,244,1,2,136,253,253,5,245,254,22,0,167,25,39,1,69,1,227,26,195,3,139,254,163,254,183,0,128,3,53,7,123,251,95,1,145,254,147,4,10,17,252,1,0,22,192,2,116,250,162,248,174,2,110,20,247,255,118,9,230,0,8,1,154,14,242,254,168,254,240,253,88,252,238,8,228,253,178,16,81,1,103,253,225,2,103,6,229,250,195,22,80,2,164,250,100,254,139,5,227,17,79,1,223,0,213,251,144,255,66,254,149,0,95,5,101,255,120,254,68,248,49,2,189,255,85,1,45,27,219,1,185,44,39,0,81,0,254,2,168,248,46,2,122,255,252,224,23,254,249,0,138,252,154,254,194,26,234,10,87,247,87,4,58,251,150,251,206,252,52,4,225,248,97,3,84,247,155,4,140,17,224,0,231,247,174,254,25,235,122,254,133,0,240,1,214,255,240,255,46,0,181,1,66,1,237,254,184,255,48,0,187,254,57,1,84,4,236,251,173,252,90,236,11,4,220,16,255,250,111,252,117,250,83,252,122,7,192,3,218,4,202,0,245,19,219,1,230,4,189,6,32,250,252,255,243,254,91,254,106,255,199,238,158,253,244,249,108,249,207,252,46,255,72,0,89,253,150,255,31,241,143,251,4,0,52,28,161,255,42,3,128,9,181,254,236,1,175,255,138,0,194,255,155,253,132,253,106,0,156,42,144,3,144,0,192,0,227,4,126,240,70,252,121,4,151,4,71,249,206,20,71,249,199,253,179,241,114,251,205,25,24,253,42,250,85,3,134,0,187,12,8,254,52,249,180,0,49,255,109,253,196,0,179,0,150,255,118,0,21,3,190,252,99,40,92,254,70,244,56,254,113,0,35,25,181,3,209,2,107,245,193,249,84,253,124,224,174,0,120,250,198,255,206,3,52,1,42,253,213,4,198,249,7,2,125,255,58,255,141,250,156,4,83,255,82,1,48,234,233,254,20,255,161,26,89,0,36,255,127,15,149,255,65,0,175,9,234,255,130,2,11,28,155,4,27,255,54,255,84,19,167,234,96,6,251,250,140,8,11,248,227,6,124,2,151,16,227,3,152,4,2,0,162,246,212,4,107,253,126,1,205,251,130,0,103,0,69,255,92,2,206,254,181,245,119,247,157,0,7,3,229,24,100,252,222,6,29,244,171,6,36,11,156,247,123,26,120,1,6,252,186,246,35,252,249,0,239,234,224,255,26,2,96,254,12,236,110,253,47,7,163,1,129,4,140,240,151,253,123,248,58,21,114,2,208,5,16,241,140,0,114,1,74,247,137,228,197,7,187,253,127,2,103,239,40,255,201,4,248,252,51,252,226,253,150,244,9,249,130,246,77,243,190,3,241,12,124,2,123,231,119,0,158,252,106,254,100,255,25,237,198,3,43,254,183,21,193,0,120,1,54,237,154,252,163,0,34,16,36,10,155,8,142,255,119,9,146,253,88,254,119,11,237,2,196,9,134,16,94,255,47,250,121,8,220,235,239,2,188,10,192,8,243,249,213,18,175,0,226,8,86,3,177,11,70,3,66,1,153,245,230,252,229,254,158,255,113,5,59,253,106,1,29,1,195,251,51,4,118,1,38,4,112,25,209,242,190,243,99,15,44,14,86,15,118,246,197,7,185,253,254,250,166,248,176,240,15,238,28,2,107,10,101,255,156,0,132,246,205,4,76,254,218,6,255,10,158,249,5,247,131,4,222,3,105,14,38,251,73,12,111,15,45,0,186,0,170,251,1,1,177,254,225,34,21,2,83,255,45,3,21,0,48,6,29,2,212,255,69,5,108,0,213,235,84,253,146,21,156,252,93,233,1,3,71,2,11,11,206,252,81,234,205,5,37,0,137,253,250,254,0,239,236,253,61,0,178,1,239,6,14,35,144,255,172,252,53,251,147,249,4,1,42,1,82,254,95,3,236,240,159,255,67,25,184,254,142,246,195,255,27,251,39,6,30,0,205,233,65,8,205,3,141,254,205,255,235,20,215,1,184,253,20,254,117,247,239,10,6,254,83,17,158,7,169,242,149,254,108,254,173,3,68,10,110,255,178,1,37,11,121,3,122,2,117,22,202,255,126,0,189,0,152,250,133,254,123,243,228,253,184,6,174,3,100,231,226,254,198,255,197,251,198,14,251,0,178,254,76,16,119,2,17,0,83,0,195,2,42,5,201,12,195,253,0,4,32,232,228,253,52,19,155,0,71,251,52,1,30,253,154,247,18,3,88,255,68,0,55,255,192,255,16,253,197,249,28,220,64,1,86,254,111,0,121,247,118,3,31,253,193,0,187,252,147,12,48,23,182,15,252,2,174,255,16,13,169,252,121,14,164,245,253,5,50,255,167,241,211,4,139,4,63,251,111,12,33,5,23,253,154,25,107,27,22,5,81,8,12,1,186,255,110,0,156,1,101,255,89,249,175,236,105,0,87,249,156,1,68,230,89,11,255,4,73,0,114,246,253,233,144,4,158,11,148,1,118,253,9,1,19,249,191,248,148,255,117,253,145,2,200,252,24,13,177,0,155,0,251,4,220,7,31,0,249,255,215,251,14,8,155,1,235,246,48,255,94,231,171,2,13,4,220,251,191,0,69,255,183,253,215,23,53,254,59,2,104,6,75,253,154,3,13,247,25,2,142,7,7,1,7,15,54,255,148,27,136,0,16,17,147,11,248,251,18,0,44,7,112,255,243,240,218,1,213,7,18,5,92,9,57,3,30,247,12,0,175,14,118,254,139,3,234,1,181,11,132,8,222,249,24,252,94,23,127,255,204,252,71,244,124,10,148,251,164,244,77,4,180,19,137,1,155,249,137,1,63,5,49,251,148,1,25,7,183,5,69,254,29,4,184,253,180,225,45,0,243,1,243,239,214,0,23,2,236,242,54,0,198,249,1,27,0,0,162,255,68,34,244,1,13,0,222,2,5,0,30,3,15,250,85,3,174,255,249,254,149,253,22,6,200,1,23,23,160,250,30,4,53,252,5,251,109,255,145,255,100,19,65,1,67,0,112,27,243,253,108,2,115,3,222,251,148,251,15,243,118,2,226,0,199,231,13,252,87,4,204,252,217,254,68,2,124,2,148,9,130,253,184,26,227,254,143,2,222,5,231,251,201,253,73,1,223,255,7,255,58,2,186,0,167,0,12,3,80,4,42,0,197,0,50,39,241,250,48,255,32,0,63,250,204,2,159,0,240,229,211,255,7,2,52,239,10,255,108,14,198,19,209,16,20,253,220,253,181,0,130,254,143,252,80,248,68,2,196,3,92,254,185,254,187,242,208,249,210,10,83,242,123,6,28,251,48,9,6,0,30,0,0,0,239,254,27,0,52,255,27,254,80,254,250,255,176,0,84,254,26,6,104,0,145,230,196,251,157,8,245,255,122,235,124,255,4,254,187,255,117,1,33,250,208,0,198,255,191,20,92,0,58,252,93,230,32,254,232,255,144,5,38,250,91,255,242,17,121,252,5,249,159,254,140,227,142,0,240,3,107,3,35,232,240,255,162,0,31,19,30,0,68,255,51,8,45,6,44,1,253,254,103,252,126,254,24,254,140,0,30,254,223,27,179,255,238,1,60,255,135,12,6,255,154,255,62,1,210,3,161,0,124,28,55,0,189,250,211,245,130,3,41,7,90,2,60,248,118,2,111,255,154,255,98,254,123,255,161,1,165,253,156,0,129,251,117,254,113,2,116,249,86,0,168,2,9,52,66,1,72,233,220,254,33,255,109,16,151,254,135,3,32,255,209,6,95,0,58,230,79,0,19,9,232,255,7,1,10,3,146,0,85,252,22,7,153,7,208,2,111,1,85,244,131,3,199,238,136,0,143,243,170,254,24,243,248,3,28,1,167,254,9,9,109,254,133,1,133,250,43,7,151,0,124,255,90,249,173,254,209,233,234,7,82,244,47,0,204,253,143,1,137,247,112,5,104,5,230,19,118,244,115,17,234,255,233,255,152,1,84,6,101,5,76,9,37,3,124,1,220,255,221,252,253,2,246,252,137,3,56,255,99,253,102,15,33,1,176,0,97,237,223,7,30,242,182,4,183,23,180,0,9,8,208,255,109,1,208,255,137,246,73,2,147,255,238,250,215,9,243,253,179,253,118,1,208,3,83,14,43,8,182,244,91,5,42,253,40,255,253,251,140,255,74,8,149,253,14,241,41,18,143,4,0,0,213,4,2,6,201,9,220,253,235,243,64,5,210,253,121,248,199,0,158,9,47,5,245,17,65,3,180,241,171,254,14,252,172,1,148,0,110,249,130,0,33,6,81,34,16,253,248,251,153,246,97,1,133,254,239,12,124,3,125,3,220,245,39,255,189,252,13,247,113,4,13,239,198,255,199,10,223,3,199,13,231,254,94,232,29,251,10,7,8,0,180,240,236,255,116,255,171,2,182,253,50,249,177,0,230,253,108,7,145,8,239,255,208,247,5,1,133,2,83,1,77,0,112,4,247,253,25,2,100,252,100,255,251,254,195,0,25,4,217,255,236,0,119,255,0,0,127,12,225,0,46,0,86,0,41,255,45,2,238,234,17,0,143,3,102,249,208,255,208,255,81,255,245,255,137,253,103,255,122,17,165,254,217,255,223,6,154,0,170,0,76,255,239,254,91,2,178,253,181,235,182,255,253,6,240,0,44,255,175,1,143,9,112,1,180,255,199,254,11,0,146,244,19,0,185,255,208,0,205,255,40,253,244,230,195,255,141,0,144,255,160,20,180,255,83,17,110,254,231,255,46,0,210,0,152,255,172,0,10,241,146,254,233,255,239,0,144,255,137,0,36,26,112,231,48,253,124,255,120,255,40,2,104,249,167,254,223,254,27,254,149,0,174,0,180,0,105,1,20,255,92,0,151,1,6,0,69,9,124,1,89,255,77,3,188,1,190,252,114,219,157,1,234,250,204,1,77,0,34,0,56,0,20,250,113,255,207,0,213,255,225,255,150,255,204,255,147,1,203,254,42,1,168,255,16,6,16,255,248,252,112,2,171,239,170,254,60,237,57,0,233,255,160,0,212,255,213,1,239,255,99,240,41,236,249,254,72,0,181,0,61,4,26,2,157,253,144,254,59,0,52,255,61,255,216,255,55,255,221,252,27,236,112,243,224,1,46,0,39,253,244,0,248,12,185,0,247,1,163,11,96,254,110,0,25,0,140,0,10,254,188,8,188,238,220,255,18,255,234,254,60,0,174,255,171,253,218,0,69,0,161,255,202,247,166,247,252,246,44,241,20,0,45,255,27,255,41,1,81,14,81,0,148,0,35,5,71,238,218,255,186,0,222,243,242,253,90,0,221,255,63,255,210,254,28,233,20,1,204,254,206,0,133,2,1,0,14,255,68,2,209,11,233,245,166,255,255,1,197,254,119,255,15,248,39,239,181,2,229,1,45,255,206,5,156,4,181,0,120,255,204,0,23,0,127,1,199,5,43,255,42,0,32,0,192,255,120,255,165,255,110,255,178,1,231,0,36,0,198,255,74,243,169,245,238,255,89,1,171,0,196,255,84,0,209,0,246,0,181,253,231,36,189,255,69,255,148,255,30,255,54,254,249,253,175,212,90,254,10,254,132,0,79,0,42,1,37,254,100,254,196,0,92,255,77,227,185,0,125,255,113,1,18,0,12,254,132,2,178,254,93,0,179,255,71,0,85,1,238,13,231,254,161,239,111,255,87,0,37,0,50,1,102,242,149,233,161,0,11,255,37,1,208,0,124,1,72,11,31,0,233,255,243,247,171,253,200,255,94,1,151,255,143,4,64,0,86,1,54,14,177,255,150,255,148,0,46,21,49,253,24,255,8,0,117,254,177,12,27,236,34,255,61,253,241,0,62,1,223,2,120,1,78,0,90,255,178,249,247,255,211,242,74,1,252,249,236,7,72,13,247,255,61,1,9,0,39,19,6,1,62,0,222,0,161,255,48,255,192,203,155,255,121,0,42,1,5,0,172,0,150,1,92,255,79,0,172,0,201,7,235,0,229,0,169,4,238,254,56,23,106,252,241,255,24,5,51,1,126,4,127,254,230,252,117,242,148,2,95,8,147,0,233,254,17,253,207,254,28,4,205,0,148,255,60,2,44,255,29,0,206,255,6,0,165,14,238,0,32,248,162,251,207,250,53,252,73,10,7,2,194,0,217,13,245,255,77,0,164,255,191,4,73,254,152,0,161,252,68,6,180,0,254,253,252,0,52,1,125,255,86,252,133,0,122,1,11,0,121,47,51,0,230,1,71,0,36,254,169,253,57,0,129,255,125,10,83,255,74,255,212,1,115,242,174,253,132,254,9,1,145,252,160,254,234,254,203,254,63,2,124,0,62,42,3,253,192,255,198,2,151,255,40,1,2,10,98,0,154,254,44,2,105,11,123,255,251,255,106,254,42,0,240,1,227,251,91,248,189,2,10,1,4,1,71,254,43,0,64,255,255,255,130,247,166,38,166,255,75,255,29,0,50,0,166,252,59,0,66,255,49,0,230,254,96,6,245,5,100,0,181,241,13,0,173,0,16,255,184,20,129,254,7,1,201,254,211,6,169,0,101,247,227,255,150,255,86,1,211,254,66,0,49,0,23,0,89,3,161,253,186,2,82,251,65,255,62,254,173,248,183,254,148,247,156,0,95,0,145,0,129,0,191,254,88,0,25,4,140,15,242,255,65,1,52,250,127,3,226,255,130,247,33,1,165,3,91,252,15,0,71,10,68,0,238,11,221,0,169,255,175,0,200,0,169,3,169,255,16,248,92,1,146,0,140,254,60,0,250,245,169,13,158,255,57,1,24,2,213,254,198,255,11,221,67,1,244,253,181,254,201,2,209,255,104,1,155,0,168,0,175,2,145,250,181,7,158,2,20,3,54,255,127,255,7,236,54,0,154,4,194,4,172,0,118,2,102,255,233,251,72,3,71,0,175,254,91,0,214,0,38,254,112,2,251,252,16,0,130,255,84,1,137,253,30,254,101,255,163,1,50,0,32,213,26,253,243,252,169,0,149,0,33,0,87,255,44,0,98,1,26,0,129,0,77,255,121,5,8,3,101,255,100,240,211,252,82,2,238,0,195,255,168,0,129,254,211,219,38,1,214,1,190,254,66,255,68,252,222,254,27,0,74,254,2,255,27,49,88,1,119,254,200,253,56,0,81,0,171,0,141,255,238,238,49,0,190,254,19,255,76,253,201,255,207,255,221,16,250,255,27,237,100,255,179,0,247,0,174,254,208,255,184,3,219,251,223,255,90,252,250,0,0,255,170,249,15,4,30,253,159,10,236,255,66,255,249,0,137,255,21,255,192,23,123,0,10,254,93,250,86,0,108,249,79,255,128,255,198,255,19,255,127,253,79,255,64,0,144,246,15,0,140,255,191,230,100,254,161,0,163,1,0,3,36,0,113,0,80,252,15,255,112,250,161,255,123,2,6,7,47,247,238,255,230,11,173,0,223,255,49,255,204,255,193,252,158,233,202,255,57,255,194,0,1,255,211,1,45,255,171,252,0,254,99,45,148,0,97,14,5,238,230,254,129,0,51,255,162,253,167,0,50,1,208,1,229,1,65,252,53,255,254,0,151,0,32,229,250,254,60,20,146,2,158,250,150,4,203,255,197,255,223,255,251,243,129,255,33,255,239,255,225,255,114,247,23,0,61,1,87,255,203,0,33,255,34,255,81,235,116,0,80,0,59,245,102,253,49,13,36,254,85,0,138,253,109,255,204,6,81,255,141,255,207,0,240,0,8,255,161,255,8,252,126,15,158,15,169,254,113,237,187,0,143,255,6,255,111,0,2,254,53,255,130,0,89,0,55,1,96,2,35,255,131,254,3,255,153,254,50,247,45,0,224,0,115,255,45,0,237,255,224,1,46,236,29,3,28,238,93,255,110,0,22,255,81,1,6,0,195,2,236,1,139,234,66,245,162,255,149,254,113,0,41,9,88,1,123,1,208,1,106,243,200,255,243,254,250,254,246,255,159,253,68,1,227,11,209,0,20,12,168,253,42,0,153,253,239,255,203,255,30,0,99,4,224,0,81,2,120,2,166,255,172,1,93,4,107,250,171,229,161,255,219,254,153,255,32,245,251,0,152,6,109,2,163,254,35,4,187,251,108,255,191,1,149,0,88,0,92,0,175,2,225,4,80,0,33,1,207,248,221,0,246,255,164,255,56,249,118,0,136,0,138,0,94,255,190,239,145,255,62,0,95,0,166,0,84,255,73,253,155,241,62,22,241,253,240,7,219,253,43,0,155,255,221,0,181,0,33,254,17,30,215,7,129,255,37,3,173,255,233,253,74,5,129,254,253,0,146,253,94,11,225,4,14,3,13,0,42,0,226,3,223,253,75,0,27,254,74,1,240,255,87,1,16,1,243,252,104,1,159,255,231,255,149,252,111,206,145,253,205,254,195,0,0,255,132,210,229,0,180,0,214,255,151,254,132,255,175,255,233,255,52,254,55,248,212,0,134,253,177,252,80,6,222,253,185,253,99,0,216,14,10,0,177,0,110,1,218,23,83,255,9,1,43,255,10,0,84,4,224,254,102,249,19,255,200,254,38,0,32,247,175,1,230,255,78,255,4,253,251,1,99,1,165,2,42,255,208,252,133,207,47,0,12,0,38,1,217,254,180,240,91,253,235,236,6,255,59,254,220,225,222,1,231,0,17,0,8,255,147,0,40,4,125,2,176,255,215,255,9,1,129,254,142,0,116,0,175,11,12,244,41,3,8,8,137,255,158,252,234,255,108,253,233,0,50,1,175,248,139,251,83,27,186,0,26,222,147,255,217,255,151,255,218,2,18,0,178,252,17,1,150,244,210,0,26,0,82,255,114,255,222,3,131,0,76,254,142,5,39,255,176,243,152,12,35,0,59,1,209,255,48,0,35,255,56,2,44,0,182,0,160,6,37,249,63,255,15,2,158,0,213,253,99,242,171,0,56,238,209,255,184,237,95,0,144,255,184,0,80,0,220,255,109,252,87,0,24,0,253,254,49,249,68,0,139,255,149,1,11,0,40,0,192,254,239,255,98,255,122,255,70,255,74,251,46,254,238,4,133,0,2,255,156,255,210,0,57,249,132,253,63,1,46,252,69,0,197,0,247,253,129,234,178,255,224,253,13,252,101,0,23,254,141,254,177,255,60,255,238,255,185,252,67,4,170,2,95,250,185,246,153,251,54,0,61,3,206,254,1,255,129,2,175,241,217,1,176,13,245,251,96,255,45,254,237,254,75,254,79,0,55,203,70,1,132,0,82,0,188,0,106,1,182,255,126,5,210,255,48,11,95,1,210,253,3,251,108,0,164,255,203,255,72,0,215,255,225,255,159,255,97,1,73,0,72,7,49,255,106,0,175,255,166,240,173,0,41,0,229,253,15,254,135,0,242,253,201,252,69,0,246,255,176,0,136,2,82,249,52,2,80,0,237,0,92,248,234,0,11,0,142,0,175,252,20,16,39,254,110,0,129,0,89,8,86,255,121,12,10,0,245,0,71,252,197,252,226,255,211,4,110,1,189,255,54,0,201,253,47,227,157,9,70,2,74,0,60,248,223,255,216,254,18,12,202,255,145,0,52,2,217,254,237,1,254,255,202,254,147,255,62,251,63,255,245,254,245,255,46,254,222,255,68,246,31,1,241,0,37,14,231,253,202,1,101,3,109,252,222,254,14,3,65,0,166,255,133,253,44,7,80,0,7,2,100,3,79,5,38,2,164,255,64,253,110,0,46,255,15,239,136,254,56,255,123,245,6,0,125,1,176,2,44,2,115,3,168,255,162,6,57,4,133,0,106,4,178,255,85,3,88,254,217,255,115,252,213,249,42,245,140,254,20,14,249,253,193,14,190,255,50,5,225,251,111,4,29,252,220,0,204,243,122,0,83,0,21,4,67,253,136,255,112,229,243,254,195,0,173,4,124,21,22,254,77,21,55,255,155,1,55,3,110,255,46,0,252,0,92,245,94,2,100,252,254,249,138,1,92,254,5,25,0,234,83,252,110,254,119,255,216,3,232,255,82,2,216,255,116,255,236,255,204,0,187,4,34,1,88,253,103,0,78,254,218,254,110,6,97,255,8,247,19,255,251,1,189,255,217,220,159,255,147,1,63,250,145,255,22,0,255,254,101,247,168,253,65,2,139,255,48,0,168,8,86,255,168,4,188,2,35,254,142,6,211,3,91,9,187,255,46,249,165,247,218,254,142,239,181,0,140,254,64,1,76,255,9,254,218,253,102,240,85,231,246,1,220,252,80,254,144,255,55,254,8,252,125,2,41,1,164,3,21,2,30,3,229,0,23,252,36,245,87,240,152,4,189,0,217,249,21,0,184,13,164,254,86,250,184,9,207,1,99,2,210,255,85,0,94,0,247,12,31,244,150,254,251,254,2,250,148,248,7,0,249,253,204,255,142,4,82,255,104,255,67,255,97,254,129,2,27,0,228,6,24,1,211,254,160,11,146,0,136,253,182,15,54,248,172,255,195,255,159,249,29,1,73,254,13,3,176,253,143,1,70,237,203,0,217,254,32,0,113,250,216,0,43,245,247,255,5,14,144,240,61,255,161,0,33,255,64,247,162,248,173,245,210,3,113,0,5,252,109,6,213,5,173,252,137,5,182,255,205,2,155,1,119,3,152,250,73,0,117,0,191,255,249,255,133,0,18,0,69,0,11,0,158,255,45,0,41,249,106,245,11,0,116,255,29,0,185,0,71,1,193,2,56,0,152,0,10,32,139,255,157,0,34,254,36,0,204,253,228,3,113,219,61,253,162,2,145,4,14,1,156,0,89,253,15,0,208,2,218,255,168,236,60,255,183,0,156,254,20,252,185,0,108,255,195,255,151,0,27,255,95,255,23,0,254,16,118,253,224,238,235,255,141,3,105,0,241,254,22,246,78,240,12,251,95,1,140,1,66,255,121,255,202,3,87,12,89,252,200,228,125,255,249,251,53,0,82,254,242,0,37,255,128,1,16,11,105,255,152,0,21,229,164,5,193,255,210,255,72,0,141,2,115,15,165,239,191,254,214,254,166,2,41,254,152,2,214,255,226,255,57,3,195,0,133,251,88,245,78,255,255,246,168,2,188,7,109,255,64,1,164,254,211,16,38,3,249,254,196,255,154,255,8,0,155,216,114,2,126,255,11,1,147,253,45,0,99,255,182,1,190,0,78,0,72,6,10,255,126,254,0,1,1,255,19,22,63,254,243,255,198,0,135,243,73,1,12,254,168,250,9,230,97,2,5,254,160,255,222,0,84,251,171,0,244,255,213,254,113,250,186,1,47,0,251,255,230,254,238,255,105,19,28,249,231,0,41,254,180,19,156,1,216,5,110,255,35,0,219,19,28,255,99,1,30,254,217,251,241,4,80,0,2,251,201,4,58,3,134,248,11,3,183,1,1,254,175,239,169,1,218,255,201,255,58,38,237,3,230,253,104,253,127,253,126,2,125,0,5,245,4,9,28,0,123,251,27,255,144,253,45,0,98,1,144,254,131,249,90,0,10,3,184,254,16,1,33,255,86,37,54,3,89,255,244,255,4,252,146,11,68,9,92,252,169,7,118,5,100,10,3,0,235,0,165,1,114,0,229,254,115,1,140,249,73,1,77,254,143,255,240,250,11,254,82,253,41,1,128,254,88,40,216,1,102,2,139,0,3,253,203,254,180,0,39,248,85,255,81,255,243,13,146,0,46,0,180,250,122,255,241,255,90,255,254,7,108,0,119,0,231,254,203,3,41,254,146,251,34,0,152,255,219,0,234,2,33,255,245,0,75,255,12,0,91,255,216,0,232,252,86,0,50,2,241,248,140,255,212,250,78,2,192,254,176,255,71,7,92,254,214,251,70,253,193,244,250,255,182,0,235,246,63,2,97,0,200,245,122,11,95,253,75,253,140,255,113,7,82,254,131,18,244,255,21,243,181,2,29,255,223,0,145,255,38,250,5,0,215,6,220,255,234,0,24,238,70,3,142,254,216,254,206,252,81,1,210,255,39,221,107,3,89,254,240,1,84,251,232,255,10,252,201,3,38,1,237,0,59,249,27,0,239,9,214,5,190,0,201,1,145,250,185,4,19,22,36,2,248,1,174,2,183,244,105,255,213,2,230,1,124,241,227,254,62,3,31,0,12,20,2,3,232,255,30,254,143,254,130,255,240,249,165,254,240,254,125,254,243,218,245,249,91,251,113,1,44,3,55,1,24,2,135,1,105,1,84,249,224,254,162,255,5,8,45,2,157,253,57,238,192,246,173,0,216,1,160,0,199,248,96,0,111,226,183,0,228,1,119,254,166,254,203,254,243,255,249,255,2,0,17,255,155,40,181,253,141,255,2,5,134,253,81,0,90,0,43,253,131,245,66,251,153,238,151,248,169,244,197,252,124,0,167,8,184,2,55,251,183,250,141,254,87,1,165,1,128,253,200,5,106,251,76,0,189,252,52,253,143,253,221,253,226,4,120,245,84,8,220,253,183,1,161,253,152,1,35,255,162,19,96,1,168,254,197,250,166,253,142,249,108,254,54,254,10,254,61,0,92,255,53,0,230,255,164,245,47,255,64,0,28,240,201,2,193,0,139,255,246,250,95,0,170,255,253,253,56,5,20,254,118,6,109,244,79,14,121,239,255,255,201,11,115,1,20,1,249,255,223,254,223,255,202,232,237,0,30,0,74,2,248,254,19,254,179,1,124,254,91,255,194,40,192,0,57,15,218,234,105,1,77,3,253,254,225,1,75,1,138,2,24,255,23,0,3,249,27,0,31,240,252,3,91,239,117,253,102,12,183,3,221,242,65,2,144,255,130,2,103,251,85,249,236,1,6,255,44,251,24,0,142,250,241,248,171,252,145,6,187,255,83,3,65,252,129,233,54,255,30,0,118,242,175,253,38,21,65,0,141,0,193,254,162,2,159,4,101,255,200,254,116,1,13,11,181,255,196,255,198,245,16,255,128,11,137,253,131,239,240,255,211,1,211,0,198,255,55,0,241,253,205,255,96,255,130,2,207,254,132,1,157,1,210,0,175,255,201,242,136,255,144,0,36,255,96,253,72,5,138,253,236,246,89,254,139,224,125,255,112,252,252,254,132,254,214,1,154,0,190,250,143,246,86,254,109,254,119,255,96,255,7,11,97,2,40,255,83,255,183,253,254,253,95,0,54,255,222,0,16,0,136,0,215,6,237,0,191,251,189,3,112,255,250,253,160,1,165,254,196,255,207,0,21,1,0,2,147,251,166,0,143,5,141,252,62,255,152,228,110,248,161,1,254,8,32,252,77,255,226,2,182,255,155,1,50,254,99,254,67,0,234,0,190,254,92,255,209,255,167,255,129,5,134,1,100,251,184,244,143,2,166,7,0,0,222,248,41,254,33,251,51,1,104,0,202,222,58,255,34,255,191,0,25,1,156,252,47,0,55,238,130,9,174,0,7,1,28,11,184,255,171,253,97,251,138,254,163,255,20,13,13,0,173,0,141,24,224,255,43,255,90,7,155,1,160,253,206,253,182,11,37,1,54,0,109,255,136,255,54,3,163,255,167,2,206,0,99,243,1,253,189,249,253,254,202,254,210,16,36,2,247,255,157,255,166,233,184,254,80,255,197,1,82,1,41,218,193,255,76,3,66,1,103,2,205,251,142,254,159,0,223,255,187,231,161,250,229,2,223,252,217,250,233,5,51,5,187,255,142,10,54,254,53,255,103,0,88,18,228,254,209,1,194,255,216,255,112,12,238,0,13,232,34,2,177,6,147,254,232,255,116,0,223,255,48,1,39,3,25,255,35,1,135,3,237,2,2,255,73,208,115,0,221,255,161,255,90,255,64,241,86,255,91,238,105,255,67,0,211,225,154,2,195,253,24,253,49,253,37,0,31,0,117,1,148,0,131,255,15,0,106,255,119,252,214,255,16,1,153,235,138,2,113,20,109,0,45,251,223,3,211,0,242,5,213,253,184,254], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+573452);
/* memory initializer */ allocate([204,255,215,20,234,255,156,234,226,243,131,253,218,3,212,1,219,255,92,255,248,254,246,250,242,2,84,252,83,253,162,252,102,28,233,254,71,254,216,1,103,255,45,246,59,15,161,255,104,1,250,2,14,0,178,1,107,2,185,0,26,255,209,4,206,250,80,5,12,253,105,1,145,250,9,255,120,0,11,242,37,1,119,1,38,3,150,21,24,2,137,0,230,1,28,254,13,0,219,255,12,0,252,255,81,0,43,0,10,0,43,0,218,255,141,254,192,255,113,251,139,255,141,254,90,248,90,255,31,2,159,255,173,255,135,1,197,255,161,249,46,1,53,4,128,255,127,253,192,255,21,0,254,245,21,255,86,1,47,228,122,253,207,255,63,252,115,255,46,255,213,253,196,249,36,252,211,2,47,255,255,241,10,0,221,255,27,4,0,0,138,0,173,3,118,236,37,3,193,11,35,0,186,255,1,2,235,255,80,254,32,255,124,214,89,255,235,251,43,10,80,1,104,1,3,2,171,2,213,3,212,11,236,1,225,253,204,248,23,0,226,255,52,0,216,255,191,1,11,0,107,1,161,255,73,6,53,10,243,255,112,254,207,2,95,238,92,253,222,254,200,1,180,254,245,255,251,254,57,254,89,0,211,254,29,1,31,1,202,0,25,1,87,0,54,255,54,250,233,253,106,3,34,254,55,255,107,18,56,3,52,255,145,0,66,11,148,1,48,13,107,1,238,255,129,255,252,2,106,0,90,6,178,0,185,0,22,0,131,253,184,231,119,5,63,252,168,255,215,253,165,255,98,0,39,7,9,0,185,253,229,4,51,249,0,10,129,255,119,255,127,254,173,248,90,0,16,255,140,0,10,5,200,0,150,229,118,1,79,7,26,34,145,255,213,253,12,250,129,247,175,237,9,2,77,255,166,0,219,249,32,4,166,254,247,0,164,255,81,22,49,2,233,0,152,254,224,1,27,253,128,226,28,250,3,1,214,221,68,6,105,5,211,2,46,22,195,8,147,1,82,48,198,13,62,2,118,19,51,2,177,6,199,250,56,5,196,255,134,252,120,247,205,253,131,36,7,3,174,24,141,252,196,5,177,254,224,2,204,253,123,2,75,234,105,2,54,0,1,1,187,254,190,255,199,233,37,4,127,252,90,0,202,32,212,7,240,36,34,255,22,248,55,252,93,0,251,255,102,252,165,230,216,5,255,249,139,2,235,254,242,251,184,23,170,222,34,246,109,6,179,5,35,2,43,9,171,255,7,253,214,227,103,255,158,1,208,23,127,1,64,1,114,1,122,252,55,3,255,11,243,1,37,253,38,0,217,1,157,6,16,219,178,3,194,4,226,251,70,0,111,1,43,254,75,225,111,252,145,1,198,0,173,255,109,3,204,254,185,33,253,0,23,248,133,7,132,5,71,5,152,254,76,252,154,226,65,4,231,226,116,6,141,0,213,255,222,247,44,0,130,0,155,226,55,197,191,250,180,0,63,244,27,238,245,254,5,9,139,250,144,255,193,255,51,1,22,253,243,255,35,0,160,221,101,248,137,251,184,251,234,245,70,251,3,30,25,253,203,249,67,22,176,255,161,250,163,255,29,254,129,0,188,23,45,232,118,1,80,255,130,251,96,254,137,0,43,239,122,248,27,12,82,0,188,252,136,1,113,253,108,0,172,1,33,13,57,1,107,1,110,29,129,4,78,1,214,8,145,254,187,255,211,252,26,218,2,12,171,234,0,0,159,248,23,5,142,223,143,255,91,253,180,2,64,245,12,5,85,255,174,1,1,18,66,247,196,0,125,6,231,255,92,255,226,245,201,236,153,253,249,255,15,253,240,19,77,20,190,255,202,254,59,3,130,255,103,2,70,0,56,254,238,0,170,2,129,253,207,253,113,1,183,0,113,0,174,1,184,252,232,252,142,227,143,226,107,2,67,254,76,2,19,0,219,251,140,2,46,0,93,3,169,37,29,251,215,255,69,253,163,253,147,250,240,0,210,213,221,2,194,0,50,251,188,251,248,253,37,255,7,0,6,2,75,255,226,208,139,2,216,255,104,4,122,254,36,255,74,254,215,1,254,1,120,2,191,254,113,5,123,34,87,243,229,229,94,1,161,7,10,255,186,253,146,234,104,226,99,255,120,3,149,11,233,255,250,2,211,26,113,14,213,255,31,225,86,252,71,8,121,1,231,255,179,2,136,0,43,253,219,29,38,253,232,7,236,228,36,3,53,0,136,1,184,1,80,1,91,24,131,228,48,234,213,249,91,4,221,6,233,3,32,0,218,254,176,253,44,1,4,253,81,221,180,249,179,252,186,6,56,27,128,1,11,1,94,3,78,42,148,254,142,251,207,255,17,4,116,252,144,197,41,3,116,2,130,251,188,250,75,254,37,3,109,3,192,255,17,4,133,20,242,254,230,7,229,4,32,252,7,43,126,10,17,0,80,0,73,250,133,16,80,0,190,252,186,219,155,4,66,0,217,255,192,255,39,240,89,254,116,0,95,250,59,249,240,2,138,6,163,5,245,2,179,243,97,35,62,242,167,15,131,252,155,4,124,254,224,24,34,254,45,17,44,54,76,244,22,3,192,2,5,247,141,232,193,1,222,234,207,7,181,0,241,248,150,254,199,255,198,1,189,246,74,14,27,254,44,255,31,45,255,5,222,1,222,249,234,254,72,2,96,2,165,235,53,27,18,4,88,255,175,254,209,251,72,0,195,1,52,255,24,252,236,251,177,2,186,0,90,255,137,254,210,36,107,1,93,0,51,253,48,1,107,0,173,30,29,251,69,4,180,2,26,253,33,0,64,2,191,1,166,2,196,1,152,1,51,237,199,2,173,253,252,253,172,251,149,7,240,11,37,255,171,242,194,42,233,5,185,246,48,0,104,254,49,0,113,254,24,234,198,255,161,0,200,18,180,1,68,0,213,233,230,0,64,3,52,251,238,24,180,253,224,250,4,3,241,16,107,254,165,234,34,255,102,5,110,8,108,2,184,252,42,3,10,241,48,0,155,255,17,2,146,245,7,255,11,4,60,226,199,251,10,230,189,5,19,4,231,2,17,6,212,253,238,254,68,0,238,0,54,4,146,255,213,235,50,2,223,2,131,223,178,4,211,250,62,252,61,0,184,16,58,2,26,29,9,1,20,250,184,2,225,249,87,253,0,0,32,240,12,6,39,246,145,2,55,2,105,223,155,6,106,250,219,18,39,3,137,3,215,245,9,227,153,3,51,249,107,1,53,1,211,0,247,253,197,11,227,252,136,2,131,241,193,3,150,2,147,1,126,254,49,253,136,233,75,5,61,26,191,0,79,2,141,254,55,251,251,235,32,3,4,255,119,233,77,4,145,2,115,255,73,9,171,250,38,255,142,255,148,0,20,1,102,1,158,254,18,0,225,255,59,219,118,234,78,250,36,255,42,1,154,2,147,2,103,1,212,3,147,250,101,0,220,5,53,18,216,1,8,1,90,226,67,250,41,0,38,0,253,254,166,254,26,254,35,217,44,3,166,1,182,250,99,246,247,247,3,255,14,7,149,255,215,255,0,64,116,255,84,253,45,21,115,7,246,255,135,252,171,248,97,229,206,252,34,233,132,243,129,252,86,249,70,255,8,31,100,0,4,212,35,238,97,254,77,18,139,1,109,232,157,22,42,238,112,2,158,247,58,2,130,0,132,252,105,5,250,254,238,25,236,246,92,1,224,254,95,2,218,249,207,27,243,251,216,255,165,236,78,252,161,235,11,252,48,251,149,252,178,255,113,254,231,0,83,255,28,233,189,0,13,253,183,223,233,2,198,3,202,0,190,248,230,255,110,253,55,0,107,4,200,255,214,11,158,0,158,14,19,251,61,1,253,24,9,2,4,254,246,253,8,248,21,253,6,229,156,252,146,255,49,253,42,10,10,10,174,251,237,252,160,254,252,35,223,253,171,28,57,216,42,253,80,4,162,251,137,249,127,1,90,5,132,5,16,2,175,237,114,254,38,241,86,253,4,213,250,246,75,31,253,8,203,232,0,254,229,14,210,0,99,5,151,196,119,4,216,246,155,9,64,9,172,230,226,247,10,255,127,1,52,255,169,5,59,254,253,249,160,1,252,1,0,228,118,248,183,16,197,1,41,255,216,254,166,254,59,22,56,255,169,252,40,2,33,23,147,255,76,2,23,244,32,5,111,26,178,255,220,227,163,4,14,253,237,251,57,254,156,1,22,254,52,12,239,254,188,5,222,253,40,2,206,254,67,3,249,254,190,227,68,1,62,1,56,251,240,0,198,0,193,0,218,253,84,253,128,207,85,0,67,250,49,254,211,254,180,0,34,1,96,252,1,231,93,252,176,0,54,1,76,253,28,31,52,255,0,2,207,3,241,230,118,254,226,255,136,255,102,6,62,250,131,254,24,23,156,0,194,252,193,253,31,255,17,240,237,252,67,252,223,252,181,0,63,2,92,4,229,252,25,253,43,252,178,1,147,254,204,217,234,248,167,5,57,4,153,0,116,3,249,33,3,1,113,3,107,253,48,251,221,253,208,1,130,3,108,240,36,254,22,3,165,29,243,253,215,252,172,244,9,251,170,0,223,0,70,236,6,246,178,5,102,253,25,2,179,229,212,0,192,1,236,249,179,5,34,3,100,245,175,221,12,43,254,254,205,4,114,4,75,3,252,1,103,0,111,253,249,4,204,31,112,1,163,253,200,26,110,0,89,254,82,21,95,254,225,3,1,1,176,21,209,255,121,5,137,255,216,250,49,24,84,251,56,0,163,255,188,249,45,250,127,252,238,0,55,3,117,16,104,0,145,0,231,251,186,219,230,255,211,252,117,255,243,1,145,215,46,254,253,253,114,251,100,254,22,253,247,1,80,7,17,0,91,209,234,242,148,255,128,227,101,254,203,18,178,248,162,0,219,21,110,253,83,1,120,252,255,26,53,253,16,255,185,255,121,1,139,18,199,255,40,221,9,2,241,2,137,254,95,251,42,5,184,254,5,0,13,2,158,253,127,0,239,5,23,3,16,3,0,192,116,0,17,252,160,254,230,1,65,225,202,0,156,241,125,254,164,2,18,221,55,253,65,254,211,253,135,4,206,3,132,254,97,251,25,4,247,255,70,3,92,252,117,255,115,1,152,6,63,226,168,4,46,9,36,255,50,238,121,10,32,6,102,0,250,4,66,254,161,254,15,6,77,4,221,220,100,235,192,238,83,13,221,0,83,254,156,1,89,6,33,238,254,0,137,253,54,1,134,254,15,38,91,3,166,3,142,0,136,250,247,228,66,25,28,240,104,10,162,1,70,0,28,1,121,252,233,255,10,254,2,17,151,232,125,0,222,255,34,251,102,248,52,255,234,3,226,226,168,255,76,222,145,9,147,53,62,1,201,221,38,1,92,247,138,0,7,253,29,1,106,249,35,1,94,2,180,0,249,2,153,254,69,250,43,1,95,254,151,254,129,252,196,233,127,0,73,252,165,0,1,0,140,1,205,252,124,234,24,1,248,2,101,254,255,251,119,253,104,249,110,231,16,1,239,255,85,226,9,0,51,1,128,0,101,240,137,255,225,1,228,243,1,255,139,2,139,0,92,242,250,255,137,238,196,1,185,255,139,0,231,4,16,232,167,4,70,1,28,0,18,255,94,5,178,254,55,254,188,252,106,215,185,0,152,253,38,13,217,255,183,0,235,255,96,24,117,4,85,1,164,254,226,2,121,0,191,255,126,254,229,255,220,253,81,1,252,255,130,255,59,2,215,8,72,19,187,251,115,254,193,3,2,233,34,253,229,5,108,253,195,255,170,0,241,252,155,239,77,250,138,3,225,255,144,1,31,254,49,2,6,0,233,1,235,234,126,249,41,0,232,253,140,255,57,26,8,5,99,255,140,255,160,16,103,7,15,26,45,7,224,253,252,4,239,7,89,1,71,25,172,255,76,7,42,248,232,250,144,225,190,2,91,251,105,0,251,236,230,254,234,252,171,27,140,253,7,251,252,0,77,255,120,254,96,0,216,225,99,0,12,2,176,223,236,255,164,0,78,254,171,255,84,254,82,5,108,0,223,0,29,4,245,255,63,255,236,235,65,255,97,255,193,0,69,31,217,255,29,254,228,6,219,251,244,254,194,254,144,252,218,1,49,0,248,255,33,255,130,0,255,43,165,0,12,0,213,255,153,255,135,251,180,253,175,255,43,1,73,0,188,1,181,227,125,250,128,253,78,252,16,0,143,252,240,1,99,9,36,254,66,4,218,254,29,0,108,255,109,0,145,0,204,255,247,0,223,253,91,4,229,226,21,254,77,250,141,1,101,222,2,252,214,5,42,1,220,235,154,254,183,251,161,244,167,1,140,2,134,254,203,246,182,255,159,1,145,254,146,1,125,8,102,255,122,0,27,1,72,5,46,1,139,254,81,254,229,254,147,255,192,255,169,254,148,255,55,0,204,198,241,0,37,0,45,253,185,255,48,255,130,255,221,15,97,217,238,1,225,8,7,254,56,240,66,0,218,252,159,251,154,248,15,3,91,250,170,1,204,252,53,249,245,255,138,2,230,254,250,253,124,0,158,227,235,255,160,0,173,254,5,0,48,255,192,45,198,0,203,255,153,3,89,0,99,23,58,237,176,0,92,7,64,0,251,253,121,8,108,0,41,1,145,255,123,254,184,252,151,2,75,0,27,254,2,237,79,255,103,10,27,255,184,31,37,255,206,1,32,12,187,3,128,1,30,5,183,255,8,254,2,1,170,0,252,248,30,254,59,22,75,254,230,222,71,2,107,249,197,252,36,1,191,255,202,7,128,254,105,0,123,0,0,1,174,255,145,254,100,59,128,255,252,254,246,255,169,0,249,0,250,250,31,4,136,0,166,2,61,0,140,5,97,255,241,255,35,255,6,255,107,0,235,255,41,1,54,0,242,0,145,255,212,1,237,0,220,255,97,255,37,0,154,255,24,254,31,238,72,0,241,3,255,255,194,4,231,7,128,253,75,254,254,2,213,254,0,24,184,0,1,252,171,0,124,254,116,3,242,250,192,254,14,34,128,3,217,254,48,252,221,252,20,12,184,6,1,255,182,250,103,253,193,255,30,17,41,0,135,255,99,255,98,1,127,0,75,2,169,253,25,255,228,1,106,255,228,254,14,254,1,254,79,0,127,21,13,0,137,25,249,2,173,249,140,4,157,246,241,11,154,236,212,2,52,4,237,249,121,3,147,254,60,0,72,254,24,228,124,255,27,1,207,254,130,255,54,250,125,0,204,255,223,255,4,5,63,252,75,5,185,3,12,252,29,255,86,0,219,2,242,255,151,193,200,255,149,252,116,249,127,0,244,1,62,13,242,255,193,254,124,253,143,0,249,0,0,214,23,0,54,0,205,251,145,255,168,2,78,249,72,1,212,247,172,252,110,2,181,3,61,0,6,0,239,255,144,0,190,0,216,0,130,0,191,255,27,0,190,254,117,255,43,0,89,0,76,0,172,255,120,216,209,255,111,1,251,254,38,0,50,0,137,16,46,255,14,0,255,255,25,0,250,2,213,254,124,255,177,0,206,3,20,254,111,255,213,255,241,19,118,254,60,255,165,255,231,255,217,1,90,223,36,254,77,2,164,250,2,255,173,246,219,254,208,254,244,14,2,255,63,255,237,1,54,0,148,255,171,221,250,254,23,255,203,252,34,255,202,2,246,4,195,255,124,3,13,0,112,15,220,255,225,249,148,253,130,255,224,251,75,2,134,1,232,255,235,7,11,1,218,0,15,0,200,255,126,255,40,0,39,2,227,255,2,57,233,255,106,0,242,255,84,255,23,1,171,1,15,255,47,1,236,255,20,253,55,0,67,20,86,2,39,255,234,7,131,2,118,0,143,3,87,31,40,1,23,3,39,0,195,245,143,2,228,0,97,253,240,254,80,255,244,25,90,255,248,254,67,215,91,0,173,255,84,253,87,255,168,254,75,8,154,255,179,254,195,254,198,252,74,2,116,0,161,219,189,1,141,0,221,250,10,253,144,0,244,21,107,1,66,0,142,0,95,255,84,253,198,1,72,230,51,255,65,2,205,0,49,1,0,250,243,239,194,254,121,0,189,254,244,251,84,31,122,4,92,240,175,0,224,249,255,249,243,253,236,8,62,0,11,0,128,2,219,4,4,1,152,255,168,254,102,0,144,253,122,0,212,254,10,1,40,232,131,251,156,1,156,250,22,0,137,29,104,1,52,2,142,1,174,254,174,0,180,255,131,0,44,0,86,254,244,255,81,255,143,255,78,0,37,1,136,255,164,255,75,1,221,192,182,255,155,255,82,251,214,254,85,255,212,15,117,255,69,255,131,0,67,1,114,1,112,255,96,255,131,0,228,254,66,255,83,0,110,3,31,198,14,0,196,0,198,0,38,1,136,255,40,0,32,3,49,7,137,1,88,255,81,1,228,253,156,254,130,0,250,35,112,3,48,1,0,247,237,254,114,5,175,38,161,2,194,255,158,237,126,255,18,1,16,2,89,0,54,254,166,255,174,24,123,255,54,1,191,232,170,2,37,0,121,11,141,254,197,0,77,0,72,255,216,4,22,0,241,225,85,255,246,236,92,253,159,251,182,252,126,253,136,4,192,251,160,252,96,1,234,252,26,3,33,3,68,41,15,249,71,4,71,254,182,6,116,0,214,3,244,254,199,0,152,246,6,248,23,1,110,255,133,2,186,250,5,0,106,255,92,252,113,0,25,0,96,253,153,0,158,0,4,232,250,254,142,0,207,18,255,255,88,254,42,3,63,0,88,0,2,254,20,255,124,15,190,255,205,4,240,255,10,253,241,212,131,251,48,0,36,249,167,0,4,9,160,255,114,253,129,253,113,1,35,255,47,0,202,0,73,1,160,254,230,255,237,255,142,51,129,254,124,0,69,251,39,15,168,254,94,248,2,222,32,0,156,3,216,1,17,31,180,2,40,255,97,254,154,243,89,248,167,3,208,15,155,0,97,29,86,3,99,255,131,2,176,14,149,255,24,246,110,2,26,253,89,7,214,8,246,2,56,252,241,254,125,255,129,1,13,236,44,255,12,246,29,0,124,255,6,254,66,255,215,251,58,1,202,0,76,1,30,247,189,2,4,0,234,255,73,254,198,0,247,254,164,255,113,255,204,1,224,255,189,0,78,1,87,0,41,226,45,0,125,254,144,16,207,4,92,0,8,4,179,254,232,254,13,8,40,1,109,1,211,7,86,254,221,255,96,0,194,255,114,3,240,252,227,1,128,255,113,255,218,1,172,53,90,255,184,0,54,253,142,0,22,1,246,21,189,255,26,1,135,2,126,255,225,255,44,1,215,2,216,2,153,1,178,0,167,253,84,0,113,32,66,254,179,0,115,0,209,0,239,254,209,255,140,7,1,255,157,243,154,255,205,1,137,255,90,224,215,252,108,0,112,249,157,243,249,252,68,1,10,255,132,0,229,255,84,0,47,33,211,255,153,0,21,0,152,250,34,1,155,252,38,0,72,254,133,0,255,254,234,255,26,244,12,0,19,245,165,17,142,0,69,6,167,1,67,2,210,253,211,254,255,254,189,2,10,255,44,254,102,248,120,0,65,1,198,2,39,255,53,255,206,255,212,255,22,233,80,0,3,1,232,1,242,2,124,0,251,253,191,2,59,255,146,0,64,2,51,253,247,0,25,16,10,0,90,254,130,245,73,1,159,4,237,56,72,0,45,1,251,7,131,255,116,250,17,251,100,40,90,253,54,251,74,1,194,255,173,0,253,22,200,255,78,255,190,251,152,253,185,3,40,255,85,32,132,255,155,1,78,30,178,255,186,254,18,3,46,0,171,250,213,253,223,1,250,252,192,253,8,0,48,1,134,1,70,255,204,252,72,0,189,255,183,253,62,43,43,255,244,255,88,1,113,254,20,253,106,255,159,10,195,0,20,22,18,18,37,2,222,10,252,255,136,7,226,1,240,3,2,231,75,3,201,1,51,7,13,1,223,4,94,1,107,253,221,255,179,230,143,14,9,9,88,254,117,252,159,1,51,4,120,15,37,250,61,0,82,2,24,253,110,0,182,9,199,3,27,0,113,235,150,253,190,253,57,1,143,27,199,251,227,2,20,254,253,247,61,1,112,0,101,255,208,254,5,254,150,0,253,0,214,255,221,0,92,0,237,254,157,254,210,222,105,253,109,0,26,1,188,252,241,254,100,36,165,0,63,0,85,255,10,0,218,255,76,255,37,255,6,255,100,252,195,253,15,255,54,2,81,255,20,0,198,1,251,0,184,254,236,0,41,255,215,233,0,0,247,254,225,0,98,1,113,0,24,254,174,0,124,255,134,0,68,255,231,4,162,255,201,255,63,255,148,1,248,1,16,3,135,254,157,233,77,1,65,254,222,0,138,0,72,0,0,255,198,255,26,255,87,255,216,2,31,254,95,0,118,254,182,255,23,254,3,255,54,202,61,0,184,0,220,255,161,19,24,255,65,1,253,0,170,242,120,0,48,246,31,3,182,253,162,4,145,251,69,252,202,255,7,0,83,0,0,0,139,20,210,1,42,231,254,0,132,1,45,255,207,0,145,9,123,1,174,1,37,255,70,254,228,0,151,0,43,46,67,0,155,255,239,0,230,254,121,0,242,254,185,4,126,254,41,2,148,255,21,3,250,253,237,0,208,255,241,1,26,35,80,0,40,32,167,255,153,254,221,252,217,1,227,3,108,4,112,2,73,5,207,254,199,2,185,255,230,255,18,0,254,0,23,51,184,255,178,0,238,255,140,255,37,1,155,0,2,255,205,252,90,255,216,252,66,255,150,0,24,239,223,255,242,255,16,1,239,230,78,0,78,0,67,0,54,1,79,255,77,254,225,0,98,2,241,255,1,0,206,229,30,0,1,0,67,255,14,1,235,255,20,1,74,255,77,0,25,255,30,0,140,255,223,225,158,0,88,1,48,2,186,5,247,13,172,255,25,238,20,251,116,1,115,5,153,235,28,1,137,248,59,1,248,246,209,255,49,255,158,1,129,0,36,0,85,0,61,1,131,255,193,255,44,255,180,255,130,0,127,254,157,0,117,0,12,0,12,63,85,255,119,1,47,253,161,0,170,254,182,3,101,253,243,3,15,0,24,2,77,251,15,4,14,255,97,255,240,29,83,254,248,254,227,223,147,255,99,3,182,255,177,255,98,254,32,2,206,0,120,0,67,7,212,255,73,0,42,2,121,0,96,255,129,255,223,255,44,0,232,255,29,1,77,2,30,207,51,0,208,1,17,0,8,1,58,0,51,229,111,1,96,253,227,0,233,10,14,3,114,231,92,254,216,252,33,251,127,3,182,3,253,5,201,251,49,255,121,248,173,236,221,252,184,254,253,29,126,254,0,238,183,254,27,254,61,9,44,250,54,249,134,254,61,253,198,248,84,35,58,1,202,13,61,0,105,11,79,0,36,37,178,251,97,242,46,3,244,244,38,2,95,252,56,253,238,254,202,253,39,246,24,2,216,254,159,255,183,3,88,44,154,253,106,0,170,254,7,252,97,251,99,255,55,254,10,1,109,0,33,2,199,254,247,3,49,27,52,0,32,255,199,8,8,255,76,255,79,48,55,1,2,2,194,4,207,253,14,246,53,243,218,0,89,32,187,0,106,230,160,255,23,252,241,6,89,0,148,3,18,4,143,1,245,254,159,255,32,242,141,1,192,7,10,232,16,3,88,8,190,250,107,2,86,250,2,252,54,251,185,0,50,1,238,254,134,255,87,1,129,0,127,238,19,253,9,253,16,254,81,34,78,255,201,1,167,253,107,3,16,4,244,254,200,249,237,253,195,37,104,1,142,236,13,2,76,254,123,0,226,249,227,0,52,3,74,0,251,255,197,5,154,0,203,249,61,219,248,0,27,254,35,243,78,253,175,0,53,0,235,255,47,1,184,246,106,0,3,2,128,10,111,254,2,251,169,1,28,2,159,254,150,2,219,226,115,254,139,228,48,252,189,1,144,249,164,0,2,255,205,253,44,2,108,3,51,255,116,3,214,0,164,255,3,254,96,0,203,255,102,22,217,254,120,255,211,0,168,0,5,1,182,255,155,1,25,0,197,255,12,14,144,1,64,1,187,255,235,255,238,54,2,254,142,0,24,255,61,6,34,0,240,0,36,254,131,0,4,241,70,255,19,10,252,10,35,250,18,1,125,10,249,10,180,251,136,10,110,254,67,0,138,2,244,248,245,255,40,255,95,26,112,0,199,1,214,227,5,255,205,251,191,252,58,252,163,5,118,255,17,1,18,254,21,6,241,255,173,254,174,255,146,1,206,0,31,0,179,255,162,255,78,0,164,234,77,255,212,255,165,1,163,0,126,254,123,255,66,231,171,1,235,2,135,255,220,254,112,1,193,251,174,254,2,250,156,14,143,252,36,248,252,250,134,3,97,0,177,242,201,253,138,255,60,5,179,255,67,254,130,2,184,0,133,3,171,254,175,255,83,2,125,230,8,255,89,255,36,34,117,1,152,1,23,0,213,41,213,254,148,252,184,253,213,251,20,0,52,238,39,1,92,248,222,3,124,255,104,255,228,15,164,255,142,0,24,250,23,0,209,252,198,1,74,1,181,254,82,35,120,0,156,255,34,0,96,0,152,0,181,212,89,1,201,253,14,254,198,0,219,255,60,36,33,254,99,2,28,245,253,0,80,255,105,2,32,255,248,0,134,1,39,0,25,0,146,255,127,0,243,255,19,26,172,255,115,0,38,1,84,0,146,254,107,254,224,255,147,255,27,215,99,0,17,0,168,255,30,255,60,1,123,255,53,255,196,255,55,1,169,255,181,254,101,1,245,255,158,0,74,0,50,2,8,0,98,1,165,213,142,255,50,255,187,2,151,253,115,255,39,3,87,0,107,255,174,0,199,0,201,255,128,42,180,254,182,0,32,2,139,2,229,255,5,1,66,255,113,253,24,0,69,254,138,253,204,0,207,0,178,239,229,13,89,0,126,254,218,6,27,254,129,255,159,255,40,0,200,250,24,254,79,255,18,253,88,0,240,251,89,247,5,254,169,0,92,11,69,0,204,255,10,33,89,2,174,0,99,6,224,1,181,0,188,11,51,244,76,7,148,254,204,247,0,255,7,244,223,255,213,226,134,252,99,248,236,255,0,219,26,255,177,252,134,253,135,254,216,255,160,4,242,0,9,1,144,27,42,0,16,0,50,236,185,255,44,1,94,251,187,0,81,1,205,250,77,0,39,254,141,12,106,22,114,2,220,9,19,2,233,3,221,252,207,4,197,251,204,253,27,2,191,0,14,254,184,0,91,2,15,249,33,254,250,8,164,253,227,247,122,2,74,18,149,250,149,252,242,1,229,216,83,255,240,2,109,0,186,255,171,0,192,255,251,254,177,255,37,0,23,255,128,0,190,255,186,255,100,1,202,254,214,0,56,198,6,0,200,0,29,255,59,0,15,255,48,2,26,255,223,1,147,1,234,255,148,0,4,29,110,0,79,255,110,0,94,29,188,246,3,251,223,0,60,253,219,2,183,2,66,253,166,244,0,1,120,251,77,19,121,0,132,251,188,255,88,254,202,249,89,18,193,2,13,2,172,2,61,254,10,255,141,255,44,2,31,2,254,229,128,1,179,253,31,250,12,0,114,0,82,0,36,236,164,0,154,0,217,254,106,0,241,254,216,255,118,254,75,254,141,1,233,254,15,241,226,254,120,2,239,251,113,4,163,255,48,0,192,0,230,232,164,255,21,255,170,2,185,22,66,253,180,0,13,255,37,255,114,252,82,255,110,255,142,0,12,0,187,255,49,255,243,254,203,255,55,2,176,254,114,0,129,37,240,254,242,254,203,1,98,2,254,254,97,0,58,213,141,1,57,0,249,255,229,0,133,6,83,255,83,255,164,255,165,254,123,255,155,254,92,0,132,0,159,253,60,0,132,255,116,0,202,255,155,196,142,0,109,0,103,4,12,1,36,255,80,1,25,253,18,255,227,255,122,252,91,0,243,241,224,254,90,4,43,241,177,249,32,0,217,44,55,0,194,0,239,13,191,248,255,245,19,255,241,255,208,255,24,255,198,255,235,255,37,0,233,253,62,254,89,3,209,7,12,0,48,0,72,3,211,0,126,0,225,18,19,1,176,0,145,255,9,0,144,255,109,254,182,0,40,1,181,0,87,254,242,255,20,1,118,0,16,255,128,1,139,0,223,35,26,255,143,0,108,9,186,255,250,0,207,39,41,3,241,255,255,254,38,251,93,255,99,239,160,254,76,254,8,1,122,236,239,255,41,255,132,5,56,6,88,3,97,255,148,18,88,236,51,1,5,255,194,0,14,25,200,255,249,255,9,254,251,254,122,253,230,251,241,254,190,253,221,254,102,2,130,0,176,254,101,252,136,255,149,0,132,232,17,1,217,254,22,238,137,0,206,0,222,4,242,1,102,2,223,3,208,53,122,0,52,0,108,253,180,255,45,255,35,254,32,255,196,0,155,1,142,1,178,253,52,3,71,254,221,255,42,17,146,19,122,252,253,1,45,0,235,2,11,4,57,254,189,253,105,0,79,4,16,254,31,251,8,255,46,0,117,233,58,255,126,254,224,2,15,0,177,254,171,255,144,253,132,255,68,2,185,254,154,255,238,255,98,3,125,1,169,252,13,6,23,237,117,2,164,3,248,232,72,3,7,248,207,254,242,245,87,1,225,255,244,252,251,252,159,254,147,1,141,248,189,246,213,253,188,254,33,254,49,27,226,254,62,239,114,2,71,252,242,255,111,249,69,254,224,5,146,254,1,2,74,251,102,3,23,36,112,0,43,255,169,1,125,1,10,7,238,2,82,2,61,0,104,255,244,247,219,220,16,253,197,0,19,254,80,255,123,254,177,253,172,11,142,2,100,9,52,255,48,1,233,254,202,0,66,0,71,255,159,1,159,0,22,250,137,229,219,255,199,245,34,251,84,240,184,4,214,253,168,12,113,253,118,254,72,250,160,238,132,1,34,4,148,254,32,249,57,4,210,253,140,255,148,255,99,0,99,252,251,2,235,250,5,255,2,1,223,255,55,1,43,2,227,0,233,254,167,253,121,255,93,253,137,214,87,252,158,0,247,1,4,248,51,4,142,255,182,16,176,220,67,0,204,251,63,253,134,255,235,253,227,12,222,248,220,250,196,2,0,241,28,253,142,254,206,251,87,0,50,254,129,8,103,251,57,0,89,231,86,255,247,252,0,255,179,1,35,1,131,40,174,255,87,254,35,249,60,255,240,14,111,231,62,0,154,17,249,253,241,252,131,4,110,3,39,1,4,248,49,1,186,0,7,1,76,249,30,254,210,233,159,1,149,10,213,0,107,29,96,5,45,3,11,7,190,0,142,1,83,25,145,5,235,0,153,10,8,2,180,244,89,251,186,23,142,2,121,230,64,1,32,253,34,254,3,10,203,254,107,242,101,255,19,1,0,4,134,1,126,254,181,254,219,54,251,0,102,254,216,5,24,0,248,4,208,252,37,2,18,255,71,246,158,0,194,0,1,0,206,254,240,243,248,254,200,0,226,255,248,253,40,254,226,255,48,254,4,253,184,1,109,253,88,0,10,3,225,255,254,248,23,241,168,254,119,3,217,253,115,0,5,253,38,235,90,11,50,0,224,2,160,21,179,251,74,1,107,254,160,1,254,3,163,255,71,0,50,39,56,255,22,251,179,242,224,1,141,0,143,1,244,1,55,1,9,254,45,1,46,17,198,1,102,252,207,3,155,255,249,252,175,255,69,249,53,4,89,3,110,249,45,3,79,3,86,1,236,254,254,13,175,11,195,21,201,2,0,5,84,2,211,250,193,251,87,253,131,5,135,1,64,249,236,1,32,2,232,5,44,253,235,226,86,254,6,0,234,253,197,241,194,249,90,10,190,252,48,8,179,254,67,0,210,6,208,249,21,252,248,4,174,6,130,6,176,0,60,210,73,1,219,248,129,1,34,3,130,254,196,8,248,255,34,255,209,246,113,1,213,251,118,219,37,1,205,255,199,248,12,254,210,246,224,248,198,252,62,254,149,247,200,1,245,0,4,7,64,1,183,255,206,254,134,255,34,1,118,0,214,254,93,253,76,255,196,252,86,0,212,255,165,0,179,1,199,223,1,3,118,2,122,249,6,253,197,1,5,23,3,1,164,255,21,252,154,254,224,255,186,250,233,253,223,254,153,1,210,253,168,254,16,253,149,23,88,253,167,9,69,2,161,254,227,4,61,233,194,0,152,255,47,3,233,4,149,253,243,0,154,1,103,17,55,252,50,0,6,5,11,252,219,254,196,225,73,0,103,2,11,2,107,255,200,252,187,8,35,6,202,3,176,3,170,18,124,255,38,236,83,0,129,0,204,252,221,252,182,2,79,6,139,4,5,2,110,254,176,255,250,2,149,255,93,254,142,0,218,254,34,44,45,1,228,1,255,253,105,0,35,2,106,4,99,239,26,253,120,1,247,249,52,4,20,17,34,9,225,244,239,1,66,255,116,246,163,3,87,25,117,0,7,251,208,5,181,255,190,254,25,254,202,245,5,255,209,4,15,16,191,254,37,255,231,224,245,255,107,0,216,252,194,1,111,0,43,17,89,0,4,3,170,248,154,248,51,4,224,253,5,219,53,254,125,2,74,3,68,252,30,253,100,17,9,3,181,255,47,255,210,254,228,252,17,3,11,227,65,1,137,2,201,255,114,0,43,0,254,251,33,255,157,253,209,0,89,234,14,32,139,3,226,242,172,5,225,253,155,243,13,2,161,255,35,0,37,254,243,253,63,253,199,253,94,1,206,0,148,255,13,250,88,253,229,254,233,245,128,236,197,255,56,252,73,249,66,245,252,22,199,1,29,0,180,1,16,3,155,255,40,255,110,0,100,2,1,254,244,255,98,0,189,255,177,0,70,251,222,0,167,254,243,0,130,206,40,254,26,1,155,247,175,2,185,245,82,17,77,0,247,253,108,254,90,252,212,0,73,253,143,254,114,4,68,5,119,252,245,1,43,1,29,215,250,3,50,3,149,7,31,0,1,1,195,4,176,3,99,255,176,7,143,249,130,255,72,254,169,253,255,255,46,24,14,10,180,254,241,2,195,0,125,255,84,23,215,254,160,2,170,255,113,255,209,254,5,0,135,255,102,255,155,253,165,21,20,250,208,254,194,3,69,0,191,248,46,16,122,255,194,2,128,3,54,251,121,255,202,254,211,219,111,4,147,242,108,2,34,3,223,255,186,253,117,7,127,5,242,0,39,10,3,250,233,254,68,3,134,31,73,251,113,22,200,0,179,255,162,0,13,3,46,254,237,249,225,12,67,252,225,0,10,5,7,0,165,2,41,0,219,253,38,245,120,5,123,1,217,242,113,1,103,2,254,230,15,2,58,0,47,22,142,255,76,255,26,11,88,0,205,245,206,255,115,1,161,0,68,254,14,8,218,255,16,1,142,222,1,3,18,0,223,245,30,255,9,254,65,252,241,250,189,0,141,254,93,253,8,250,158,255,2,2,44,251,116,0,202,0,94,53,60,6,184,254,61,0,239,13,26,254,12,243,231,222,195,254,52,11,93,254,239,255,23,2,59,252,9,254,248,240,174,8,108,2,52,249,2,0,105,25,217,1,215,254,186,255,227,11,205,255,16,250,225,3,22,4,173,7,168,12,179,7,196,255,118,253,203,255,8,255,180,238,147,254,117,241,98,4,111,249,93,6,78,5,239,255,112,4,0,255,40,9,230,254,156,0,127,0,101,255,62,1,255,250,214,251,57,0,135,252,3,255,140,250,189,253,104,252,18,252,14,220,65,253,195,0,66,20,241,0,206,6,228,3,118,0,151,5,63,17,108,246,181,26,8,251,199,253,157,13,72,1,185,1,64,3,41,2,94,0,136,2,92,0,134,254,159,43,7,3,201,1,176,6,232,255,173,3,57,21,147,249,118,8,249,0,201,255,232,248,127,1,223,2,148,252,187,1,200,253,37,1,14,251,51,27,78,255,82,255,94,251,95,4,48,255,53,3,219,5,40,250,133,247,154,5,106,3,133,0,214,226,223,253,145,8,249,252,131,250,75,251,193,253,52,248,123,253,216,253,249,254,157,34,251,253,76,0,32,252,22,1,113,9,167,250,35,0,75,250,137,250,5,2,185,0,177,244,91,1,225,240,60,14,28,1,212,12,244,255,87,255,67,248,172,4,189,255,52,11,142,3,134,0,238,253,150,0,208,250,110,7,22,253,95,1,34,255,10,2,186,233,29,3,148,248,241,0,222,8,252,2,177,254,68,5,163,254,16,3,206,249,231,253,148,0,139,12,100,249,56,0,142,6,191,254,222,254,222,30,69,0,52,0,54,1,81,1,250,0,84,2,14,39,80,1,13,4,163,0,64,0,71,254,78,11,247,251,218,2,50,253,28,251,203,1,125,255,160,30,102,252,213,253,39,22,43,1,177,2,91,4,122,253,7,254,249,254,96,2,18,254,0,0,186,1,246,248,170,253,67,253,168,239,70,0,217,250,166,255,195,35,173,254,0,0,121,0,206,1,223,2,129,253,225,1,125,0,12,27,51,13,171,2,237,11,61,251,13,254,43,4,108,255,111,245,245,255,27,3,139,6,130,3,226,0,208,4,49,0,196,253,163,219,175,8,181,3,255,2,203,252,165,255,51,4,160,254,107,225,42,2,175,253,4,5,11,255,215,4,142,4,123,251,102,235,40,3,103,3,90,250,151,29,115,254,13,253,240,2,97,16,179,0,51,255,219,255,18,253,141,245,105,254,68,253,220,0,179,255,68,6,63,0,205,1,246,216,123,253,163,249,103,0,64,2,132,0,21,39,207,255,19,252,97,0,184,249,3,2,246,255,110,255,170,248,112,3,173,1,9,251,228,3,147,254,76,0,103,254,157,9,29,0,135,4,217,0,160,231,56,255,22,253,118,0,164,248,201,1,208,252,160,253,143,12,244,0,237,2,220,8,20,255,4,251,234,254,112,5,25,249,231,4,62,250,56,224,108,5,254,252,225,0,69,254,10,0,120,254,147,2,162,251,141,249,254,253,89,252,145,255,88,4,205,3,9,255,21,255,46,205,31,253,40,0,115,255,47,20,114,252,23,1,45,254,78,241,79,3,161,240,250,3,130,7,62,3,190,0,253,0,150,251,97,254,115,1,206,2,249,14,12,4,18,235,96,252,98,3,254,253,164,10,50,9,193,1,210,0,182,5,168,2,168,248,194,255,236,42,41,3,166,253,145,0,232,253,114,0,109,255,200,253,121,12,190,254,124,3,131,253,155,250,191,255,249,2,79,6,161,19,185,254,77,19,137,253,151,235,180,4,226,11,230,3,233,251,65,252,150,255,74,6,105,255,120,0,128,251,191,0,30,0,187,46,101,0,18,0,102,254,248,250,114,1,253,252,57,5,224,253,155,253,33,1,139,255,89,6,102,238,22,10,102,249,151,255,52,235,163,255,29,1,113,251,20,242,39,253,74,237,83,2,19,1,40,255,39,255,144,232,170,2,85,255,149,252,224,0,92,255,103,11,28,3,175,255,154,5,186,0,137,254,239,239,77,255,21,1,83,5,59,254,201,9,132,1,208,248,91,255,64,237,214,255,24,230,54,0,33,253,215,253,113,249,149,3,254,255,136,253,161,1,34,254,18,254,247,254,73,0,140,254,152,254,179,0,64,254,9,1,43,1,104,255,45,255,186,49,179,255,162,7,234,253,5,3,12,2,182,1,109,7,195,238,154,254,16,6,8,255,204,249,134,255,129,255,29,21,226,0,175,252,185,226,155,254,167,255,185,0,234,2,83,3,157,2,49,1,9,255,129,13,63,255,95,255,126,2,88,2,98,2,87,3,244,250,142,1,248,5,202,8,115,6,34,223,251,2,249,5,166,254,185,14,145,255,162,230,91,1,26,253,149,7,175,7,70,2,133,234,3,253,206,252,58,7,188,249,13,255,81,252,245,255,116,3,76,244,185,246,242,3,138,254,205,25,225,254,47,236,211,0,10,253,191,2,209,245,235,2,126,255,83,254,79,246,30,19,55,254,153,12,190,3,85,33,30,2,33,24,211,251,70,251,61,252,201,232,170,255,144,5,201,253,59,3,2,254,79,230,254,254,252,255,178,238,115,0,25,21,110,5,98,1,219,6,26,252,84,3,225,3,31,254,218,0,37,252,11,3,95,254,79,2,123,23,16,2,33,1,176,254,210,253,60,0,164,35,82,255,235,0,17,255,112,255,252,254,112,242,234,2,173,18,140,2,33,237,29,253,235,255,96,3,250,246,140,2,235,27,116,0,194,254,206,255,99,242,187,254,167,254,104,233,120,4,95,9,93,250,223,3,242,246,239,252,231,254,49,255,88,250,53,1,233,3,184,3,192,5,243,232,244,252,101,246,238,5,150,38,51,251,158,2,245,253,193,4,92,255,201,255,161,255,243,0,229,30,86,0,228,238,165,252,169,253,73,255,221,246,6,3,70,251,10,254,125,252,53,0,15,4,34,0,183,225,216,254,97,248,49,238,158,4,106,255,62,11,210,236,201,10,55,250,0,8,40,10,16,7,119,244,47,247,62,0,162,0,91,4,214,0,98,238,158,3,243,229,163,5,132,255,193,0,198,254,46,1,187,2,238,255,233,2,85,1,127,3,153,253,217,254,75,255,143,0,85,254,128,25,50,4,154,251,118,1,214,254,6,251,22,0,119,3,1,254,223,251,156,12,210,2,95,2,112,2,161,255,77,43,238,3,236,252,227,254,164,255,62,5,187,254,196,252,42,0,252,241,137,253,192,253,207,17,100,253,242,250,203,6,161,6,121,253,32,9,120,1,136,255,70,5,134,2,187,254,95,0,86,23,7,3,199,0,147,222,163,3,176,254,117,253,207,253,79,254,38,247,127,255,111,253,96,251,67,0,65,2,105,2,88,7,40,2,90,0,151,253,239,254,221,249,199,226,5,1,230,255,236,255,53,254,252,251,57,0,188,222,213,255,214,10,1,0,114,239,168,2,18,243,200,255,104,255,36,2,65,248,152,3,131,3,132,8,205,254,74,247,107,249,26,252,43,8,144,255,21,0,241,249,158,4,249,25,186,254,24,3,26,7,84,226,51,2,52,4,254,28,116,252,244,5,33,255,166,22,38,5,208,242,5,2,66,16,244,2,210,239,240,6,134,1,78,1,212,255,218,0,170,20,24,3,39,0,156,6,30,2,194,255,173,253,78,2,27,0,218,34,221,3,182,0,213,2,112,0,202,1,46,220,24,252,152,4,246,250,133,250,42,253,102,23,215,254,210,4,68,249,167,253,16,2,48,4,184,0,110,255,61,0,173,2,184,4,168,255,45,255,100,1,97,37,149,254,121,255,97,255,219,251,151,255,102,254,198,255,79,1,254,216,212,254,45,255,95,2,187,1,102,254,62,249,184,254,19,1,67,2,37,3,131,3,48,254,238,255,40,1,66,254,92,9,243,255,158,1,66,218,127,254,216,252,181,248,154,0,196,253,23,13,209,248,176,255,133,4,186,254,225,1,111,34,241,251,41,4,62,8,199,4,64,252,223,255,48,254,228,233,234,1,198,254,90,1,218,2,125,254,178,251,0,26,49,253,107,251,199,255,94,251,90,9,236,250,103,253,182,253,217,255,185,255,155,0,160,4,4,0,59,243,179,254,21,253,68,2,23,1,185,253,252,27,71,255,110,0,161,9,172,1,251,1,110,17,147,238,199,0,81,1,243,241,7,255,186,255,88,253,83,234,253,5,149,3,209,254,242,219,81,254,132,255,5,252,113,1,139,0,87,5,151,0,233,251,164,26,105,255,222,0,138,244,207,252,203,3,99,227,44,2,11,4,40,251,43,12,210,250,172,15,252,10,33,4,20,10,251,254,149,15,207,7,88,6,98,9,202,254,11,3,158,254,135,254,107,255,11,4,197,246,102,1,82,14,10,255,152,248,119,1,79,15,144,250,171,2,112,2,16,233,132,2,135,1,32,1,58,255,19,255,68,0,228,254,88,0,8,252,250,0,32,0,164,4,13,255,160,253,192,254,37,255,177,212,31,2,156,0,10,4,87,255,73,255,219,253,190,255,204,2,228,3,96,252,203,254,201,21,229,0,125,0,208,250,67,35,70,253,27,254,98,249,71,3,87,1,193,1,119,6,237,3,29,4,104,254,146,35,186,0,158,2,6,3,58,1,61,2,48,15,142,252,26,0,214,9,235,253,61,255,43,2,81,1,10,255,229,213,25,255,31,0,198,254,83,252,105,4,77,1,177,226,168,0,217,253,237,0,97,255,47,17,165,1,181,2,198,0,60,255,207,253,11,4,220,253,34,4,15,2,33,14,151,254,37,5,73,248,178,245,82,248,136,255,188,254,46,22,52,247,105,253,181,0,239,254,255,243,230,254,146,253,107,1,71,0,184,0,248,252,28,1,20,250,82,254,3,0,169,3,139,33,2,1,220,251,237,249,194,252,174,254,62,1,86,220,146,255,203,1,196,253,70,0,93,0,120,0,234,253,16,5,88,255,29,0,110,252,180,254,27,252,206,252,14,1,13,255,11,2,56,0,185,209,64,254,11,0,102,255,164,0,67,8,243,255,133,253,196,2,105,253,43,0,8,255,84,243,254,0,19,0,155,251,252,1,154,0,249,33,191,0,83,2,41,17,10,245,88,255,132,248,137,1,136,15,129,3,76,249,221,255,76,255,93,2,223,251,86,251,100,0,128,254,219,255,149,255,179,10,49,255,243,26,176,0,81,0,123,252,0,5,122,249,155,255,25,1,123,4,48,0,21,0,105,255,44,251,210,0,98,0,142,255,195,253,4,31,103,255,210,254,205,250,81,1,190,254,198,25,221,1,147,0,25,252,162,243,24,255,16,236,225,252,182,248,198,255,139,239,96,5,181,0,163,2,50,2,126,0,235,0,212,8,224,235,13,255,69,253,60,250,39,16,57,2,55,2,225,2,189,239,101,2,223,251,242,6,34,2,62,254,232,255,69,1,110,1,102,9,217,250,60,0,250,235], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+583692);
/* memory initializer */ allocate([49,0,145,2,207,232,62,255,114,3,195,12,178,0,214,254,81,7,134,48,203,1,16,1,195,0,221,248,212,0,222,252,218,2,215,1,20,6,166,1,128,2,236,0,71,0,85,2,151,22,2,21,119,253,244,5,61,3,181,1,161,254,134,255,136,250,71,8,128,255,75,0,115,249,135,253,190,254,18,231,195,253,50,252,136,6,134,254,14,255,124,14,79,0,211,250,141,1,106,255,185,7,186,1,235,2,129,255,22,0,80,235,97,254,50,255,50,1,9,1,189,0,120,1,209,2,33,250,83,254,230,253,136,232,159,255,127,254,198,253,199,254,67,250,37,255,131,249,10,0,112,24,50,251,133,253,228,255,144,239,168,254,138,1,138,0,150,4,86,255,202,252,114,0,193,251,155,255,62,227,84,0,94,3,234,5,85,1,141,255,64,1,136,255,167,249,55,0,49,253,163,5,35,253,191,253,29,28,148,0,26,0,120,0,177,7,76,19,63,241,161,253,139,6,64,0,134,253,172,255,78,1,226,26,124,253,24,255,144,19,196,254,92,255,118,255,240,255,15,0,225,36,182,255,191,255,6,1,66,3,119,4,155,255,178,1,183,254,123,0,52,255,211,255,147,0,22,238,26,253,208,1,132,5,36,2,190,249,200,255,76,5,253,252,7,1,197,2,31,254,63,255,89,1,53,223,215,255,36,0,148,248,78,255,48,3,90,226,31,0,61,244,141,254,118,245,186,8,157,255,0,0,202,2,179,252,141,36,189,2,11,251,69,255,125,239,62,254,183,255,155,249,71,18,118,255,138,238,100,1,136,5,182,5,166,243,197,1,195,255,123,20,15,255,175,246,182,1,55,19,4,255,59,241,150,0,79,1,58,0,71,255,78,7,179,0,192,0,244,245,58,254,77,0,211,18,99,7,21,237,198,247,40,254,254,240,167,0,68,4,97,253,194,0,154,252,139,0,141,255,57,254,196,1,249,253,43,1,0,4,74,1,157,255,181,43,82,0,57,0,175,252,167,0,162,239,127,2,0,3,53,29,114,2,94,0,21,251,209,254,181,0,232,254,57,11,179,253,51,254,55,6,227,255,28,27,16,251,120,0,230,254,97,255,85,241,252,255,195,255,68,216,152,0,244,255,56,255,111,0,233,222,13,255,144,1,182,252,125,6,229,243,244,1,61,254,89,254,63,255,230,0,167,1,7,1,147,19,242,3,20,4,83,237,195,2,84,0,53,232,43,255,73,20,178,1,22,2,76,4,248,253,202,249,75,0,190,254,2,0,216,7,234,253,153,0,81,10,230,5,82,229,10,255,4,0,15,1,75,0,228,250,114,248,255,254,92,26,77,2,211,254,115,2,173,4,124,14,98,17,50,234,224,250,213,244,113,3,173,1,40,2,226,2,142,252,216,3,232,1,156,252,48,254,199,228,209,2,226,247,161,1,23,232,72,255,128,255,96,225,99,10,232,245,2,255,176,0,234,252,41,253,226,1,101,1,104,0,71,254,98,255,44,252,211,17,254,239,62,4,63,251,206,253,241,7,0,2,117,223,78,242,183,255,40,3,140,254,190,249,236,2,143,3,169,253,37,250,58,0,53,1,240,216,141,255,70,0,67,6,24,1,110,255,207,252,5,2,18,0,75,5,135,255,218,239,152,0,236,250,247,0,90,28,159,1,130,0,229,255,60,8,81,1,208,252,176,9,140,1,21,2,66,0,85,255,187,231,47,0,9,12,120,253,94,252,18,7,23,255,79,254,180,253,150,21,58,0,238,255,86,242,131,254,73,31,7,0,205,4,152,0,102,254,201,253,167,1,158,254,207,1,174,255,110,255,204,244,15,1,115,233,134,10,18,252,150,0,143,255,247,253,249,9,234,254,81,2,187,255,139,230,239,252,113,1,77,246,40,255,184,243,135,252,188,6,88,255,97,231,171,0,153,248,226,252,119,255,84,255,22,253,202,255,162,0,161,253,153,1,201,0,228,254,113,255,71,214,67,30,132,251,47,1,58,0,4,0,160,255,27,254,110,255,226,254,191,253,124,253,0,254,236,0,64,2,165,1,93,0,37,1,44,40,254,255,139,255,178,253,222,253,94,1,189,1,211,254,212,254,71,42,32,255,160,255,217,253,108,255,18,4,131,255,224,0,62,253,135,33,61,255,52,0,84,245,200,0,67,17,134,1,102,3,100,0,72,255,233,0,35,24,195,254,40,254,172,7,210,254,238,221,205,9,124,253,232,1,227,243,123,3,3,255,218,255,133,0,241,255,171,250,245,252,156,253,161,2,211,21,66,3,121,1,67,3,30,248,75,0,71,255,57,14,121,0,181,2,63,0,247,1,134,2,249,255,92,1,141,0,225,250,20,2,255,253,95,0,197,254,191,255,178,230,240,255,176,252,46,255,136,255,164,2,5,20,21,2,51,16,146,253,252,255,106,255,29,250,132,255,71,255,245,20,11,1,49,4,129,238,173,0,52,255,188,239,72,252,233,255,8,240,111,5,205,0,200,2,39,254,139,254,35,2,83,253,190,17,207,255,185,255,33,0,241,254,132,0,246,0,68,255,6,0,203,254,118,0,96,0,238,6,158,0,173,255,11,242,151,4,134,255,37,230,115,249,119,251,246,254,168,18,125,13,62,0,166,254,62,254,156,250,103,0,55,254,20,251,185,255,175,16,174,254,142,250,62,25,139,1,135,2,126,9,33,253,188,1,45,7,147,1,144,0,59,234,211,0,0,18,241,255,36,3,70,0,177,7,133,242,118,255,160,254,152,4,85,255,250,253,142,255,168,255,79,1,204,254,192,255,84,254,237,239,62,1,51,255,130,255,82,225,159,253,105,0,144,0,14,1,10,1,65,238,130,235,201,254,75,2,49,1,141,255,116,1,215,2,218,254,158,1,109,3,37,225,155,1,230,253,138,1,23,2,233,0,198,252,73,1,235,1,16,237,118,253,75,1,2,4,116,255,74,25,194,0,55,254,98,0,153,252,11,247,105,3,97,1,44,3,158,17,78,4,123,1,139,2,42,255,146,255,20,0,67,245,152,224,160,255,221,0,221,0,217,255,188,1,232,254,254,10,232,253,181,13,111,0,62,3,82,2,41,2,47,0,252,10,150,248,203,0,159,254,196,255,115,1,181,0,56,3,184,234,41,1,220,1,42,0,123,255,97,0,169,1,138,33,195,254,121,0,197,1,246,3,162,254,175,0,235,2,178,255,225,254,56,233,113,2,74,16,204,254,61,7,30,11,253,255,148,252,23,2,175,1,101,254,165,247,123,232,118,1,42,1,36,6,19,0,27,240,31,6,144,0,3,0,165,21,74,254,152,3,87,0,192,6,230,0,39,3,216,22,99,254,7,0,159,231,214,0,205,0,32,5,93,253,70,0,8,1,114,0,232,255,30,254,184,255,216,254,71,1,249,0,39,43,62,43,18,0,87,252,94,1,22,0,106,1,43,2,47,3,130,0,131,255,63,238,102,10,203,0,194,254,207,254,67,1,121,2,160,1,2,255,45,1,99,0,151,1,169,236,158,18,234,252,54,5,144,3,234,251,162,254,121,255,160,14,22,0,145,249,90,254,105,255,143,255,126,255,167,254,254,255,249,254,18,0,232,255,253,252,222,255,225,253,19,40,183,0,0,0,207,6,243,4,6,246,64,1,99,2,216,251,90,250,107,3,216,252,1,19,208,252,124,13,68,0,70,1,78,255,177,0,246,255,118,255,223,255,163,255,65,0,8,1,185,0,99,255,139,233,110,0,151,1,216,4,70,253,195,255,176,0,21,6,132,232,162,253,213,253,202,1,154,12,85,252,165,3,153,0,224,255,160,3,69,0,22,254,249,249,169,255,236,255,60,255,185,254,167,1,231,30,67,255,178,0,79,1,62,255,203,1,180,214,60,255,174,0,226,254,246,1,239,251,12,0,39,0,155,255,113,240,142,249,170,244,130,1,105,255,27,4,149,253,198,26,80,13,116,4,194,248,13,253,216,255,172,251,34,250,221,0,115,254,119,1,57,4,135,40,133,1,14,1,17,255,55,1,44,255,128,1,213,4,121,244,199,0,161,20,200,255,34,0,64,253,174,3,145,4,33,0,202,254,97,0,64,251,207,11,188,252,184,12,148,1,111,15,255,254,91,8,111,0,179,0,63,32,99,2,16,255,4,255,145,254,5,255,216,254,22,247,189,3,61,0,247,254,208,2,232,0,34,0,146,0,204,0,222,254,61,217,17,2,65,0,184,2,142,11,96,1,244,240,224,4,25,253,117,254,81,23,92,0,124,255,74,251,58,1,83,240,205,2,37,20,254,252,170,248,79,251,66,252,13,2,188,15,116,0,116,26,211,255,194,251,177,254,183,22,51,0,57,0,171,255,3,247,123,255,212,254,7,0,227,0,101,13,205,251,255,238,192,252,30,0,235,4,28,254,195,1,92,2,51,253,109,26,38,1,118,0,102,254,43,1,80,2,251,240,66,0,10,254,128,220,182,255,3,1,194,1,219,1,202,0,0,249,23,0,111,18,197,2,114,254,116,249,161,254,126,252,146,253,145,0,144,250,137,28,246,3,176,255,7,2,239,247,251,5,92,3,88,250,134,0,147,6,177,2,11,28,167,254,185,254,236,3,93,246,172,254,234,250,193,22,117,1,50,0,140,26,58,1,13,0,242,254,86,254,190,2,23,1,216,238,4,254,135,230,60,0,234,254,175,9,79,3,152,254,188,255,100,248,91,0,201,3,165,1,203,1,171,254,132,23,218,253,179,255,81,253,14,253,5,0,109,0,154,1,108,42,73,255,195,254,34,253,169,255,245,1,167,253,158,0,204,22,223,251,212,4,174,252,149,11,182,254,35,2,225,4,12,245,127,0,218,0,57,254,219,252,94,240,108,0,199,253,148,2,20,235,189,251,69,2,67,254,201,254,9,25,254,1,123,229,7,2,71,6,40,1,86,1,112,1,96,250,178,252,205,7,29,255,28,9,242,247,207,237,6,4,202,20,135,0,131,0,170,242,64,1,6,4,243,242,0,255,139,254,43,238,198,4,171,0,148,236,92,250,47,1,205,234,179,1,208,0,251,0,211,1,27,2,136,0,199,0,84,221,61,255,253,252,232,243,228,2,112,1,23,4,22,254,83,0,229,1,168,0,19,2,133,253,223,252,71,252,4,0,161,255,77,226,197,255,231,7,227,2,66,253,7,1,242,219,199,254,27,252,2,254,252,252,156,0,146,15,143,255,142,1,214,245,201,251,195,0,45,255,128,0,125,7,221,0,59,252,11,0,71,0,155,255,180,0,220,255,159,30,112,255,46,253,32,1,173,1,72,22,40,252,2,254,7,3,184,1,199,248,188,250,197,7,44,1,43,0,136,7,245,16,0,241,133,246,233,7,108,253,219,254,23,0,7,255,79,255,185,254,78,225,33,0,245,0,202,250,237,0,81,253,240,10,30,0,153,221,108,254,43,0,183,0,33,1,16,2,254,1,59,255,78,2,162,255,209,234,125,1,37,5,141,0,153,249,80,254,52,226,32,255,56,0,148,225,113,0,134,0,69,27,132,253,244,2,25,253,97,0,159,0,239,4,113,255,131,244,136,245,33,254,115,5,125,249,40,254,32,252,61,254,180,233,166,16,78,1,237,11,76,0,184,253,169,253,236,254,190,13,8,1,186,247,102,1,150,255,143,3,189,19,224,1,186,17,181,3,83,20,153,255,242,255,177,0,187,242,55,0,99,229,168,2,4,249,145,0,219,8,80,4,235,252,54,0,5,1,228,0,118,21,15,0,32,255,192,0,228,2,0,0,208,29,142,1,63,11,174,1,236,223,111,253,47,3,28,255,24,254,166,255,240,250,83,2,163,11,241,255,215,15,4,255,213,240,89,252,26,226,74,1,97,0,40,216,206,1,223,0,7,252,203,254,170,254,132,255,22,251,211,0,95,1,60,1,158,1,165,255,238,255,54,255,182,255,154,1,137,212,70,1,5,1,91,1,241,234,106,0,156,0,74,255,220,255,177,0,145,1,188,2,12,2,193,250,110,254,186,228,63,0,194,0,242,255,82,0,220,255,91,253,119,254,187,0,196,28,5,254,107,251,9,253,81,241,40,253,154,11,54,5,32,0,214,250,107,244,156,0,185,252,126,1,18,231,107,255,106,3,72,5,221,255,13,254,99,0,87,254,210,243,224,255,196,249,232,21,202,252,215,255,158,11,176,253,103,2,241,6,60,9,69,20,181,239,187,253,168,3,241,253,62,1,186,249,217,253,230,20,64,254,216,255,52,29,189,0,63,1,146,250,10,0,103,252,32,39,61,2,215,251,61,3,90,251,234,255,89,239,87,0,50,249,187,254,57,1,68,255,28,2,90,234,68,255,255,1,88,255,250,253,17,0,152,0,174,7,248,245,164,252,175,10,70,251,148,1,112,255,39,229,127,255,178,1,94,244,13,11,208,255,20,220,219,248,3,212,212,5,182,236,10,7,93,0,128,1,60,5,236,0,82,39,219,2,93,3,61,255,109,226,179,255,31,254,68,253,86,18,34,253,83,231,25,1,237,6,175,0,97,234,20,2,31,0,100,27,131,253,254,241,72,4,12,14,59,255,99,225,157,253,33,7,230,255,253,254,3,9,12,0,217,2,90,248,156,0,6,1,118,21,26,0,96,233,182,243,194,1,205,251,41,1,253,1,154,0,156,2,191,0,244,254,207,249,113,1,34,5,75,253,165,2,202,5,198,0,122,1,80,43,173,255,17,9,63,255,198,251,19,244,20,0,241,254,175,50,16,1,90,4,220,1,226,252,203,254,97,255,30,21,147,255,93,253,109,2,252,245,182,43,194,250,168,255,172,1,47,254,231,237,9,254,106,0,24,219,58,254,228,255,110,254,247,4,220,224,242,2,49,255,69,246,6,2,139,241,226,253,12,251,151,253,79,255,211,1,126,255,222,3,247,15,89,3,244,253,66,233,145,0,217,0,233,225,237,254,247,25,175,255,38,2,119,3,79,254,222,252,20,2,131,2,188,0,173,7,104,252,228,254,127,14,172,4,64,221,155,254,142,253,140,3,228,254,62,253,210,249,182,0,25,30,118,255,188,246,98,255,136,252,151,16,29,17,190,229,173,249,238,248,120,2,104,251,194,255,165,16,167,255,9,1,125,5,87,250,123,254,100,228,2,1,12,255,240,254,43,224,37,0,55,254,121,221,171,12,61,239,116,254,161,240,139,3,198,255,84,9,116,252,71,251,133,253,25,254,75,249,77,27,30,237,88,8,202,252,69,253,139,8,160,255,209,217,120,242,27,3,122,2,201,252,99,253,146,0,181,252,15,0,29,255,159,2,61,253,236,216,198,0,81,0,181,249,222,255,177,247,175,246,79,253,110,2,42,7,193,255,195,236,41,255,99,251,254,253,21,30,95,2,238,7,248,254,175,9,145,3,178,0,41,14,62,255,101,2,109,3,128,254,204,225,240,3,69,8,16,2,211,254,28,2,176,255,47,2,28,0,118,29,16,254,122,4,83,230,79,250,109,30,29,255,121,249,180,255,141,254,159,252,115,255,42,0,96,0,21,1,102,254,26,234,72,1,6,221,34,255,0,249,213,3,136,255,118,253,221,8,124,250,14,4,70,255,174,222,248,254,236,8,41,253,231,5,253,237,139,249,193,7,206,255,231,220,11,255,13,243,151,1,109,252,233,255,186,255,30,0,99,253,209,254,134,3,84,0,177,1,217,0,145,223,167,30,183,248,88,253,254,0,218,255,108,1,16,0,50,0,90,0,234,253,215,237,224,252,201,3,199,251,198,1,147,0,194,255,93,34,84,0,112,252,250,253,161,254,76,0,208,253,98,250,117,2,0,64,144,2,151,0,112,3,140,1,166,255,240,2,118,255,163,252,133,37,2,1,72,254,215,230,178,1,133,22,26,1,214,5,252,254,76,255,255,252,187,30,170,255,24,2,250,254,26,255,4,221,225,22,177,253,253,5,162,1,7,254,100,255,141,4,159,1,88,255,32,250,176,254,101,253,15,2,93,22,42,0,173,1,155,6,1,0,85,0,60,255,97,14,36,0,213,1,148,254,47,2,142,3,200,248,3,1,249,0,104,249,5,1,220,255,176,253,100,255,187,255,206,232,76,255,218,254,22,0,121,252,109,5,245,18,121,0,65,20,202,3,186,4,49,2,158,3,216,1,73,255,223,25,101,1,178,255,11,233,91,0,68,255,166,229,110,255,86,1,240,233,113,14,56,5,216,2,187,255,142,1,107,10,201,247,109,7,217,252,2,1,72,0,119,255,85,1,71,0,87,255,152,255,173,255,206,0,92,254,163,4,232,2,120,0,225,235,194,253,72,0,151,222,200,254,140,0,187,255,179,23,109,20,202,0,70,249,92,255,73,0,159,6,216,251,234,0,24,0,17,19,175,252,52,254,193,33,184,254,63,251,130,6,229,254,180,255,212,10,145,1,75,3,108,237,41,1,145,33,111,1,36,253,31,255,58,255,160,240,248,0,76,254,217,1,237,255,71,254,164,0,220,0,246,254,3,0,106,0,12,255,74,233,85,2,102,253,11,255,174,219,157,252,32,254,24,1,216,255,117,255,22,231,148,236,138,252,246,11,235,2,57,248,124,249,89,254,22,2,98,3,183,255,155,230,61,255,68,1,205,255,133,255,42,1,244,1,193,0,22,1,201,222,215,254,10,4,240,255,47,255,27,29,9,2,207,254,215,254,255,249,47,244,177,2,248,0,63,1,17,21,217,5,180,8,251,252,115,255,136,8,0,4,73,238,56,220,168,253,92,252,159,247,229,253,204,1,105,248,169,16,48,246,64,17,208,254,208,6,233,1,150,254,130,3,188,8,80,247,49,0,64,255,76,1,110,1,113,255,73,1,189,225,252,255,51,4,116,0,39,2,19,0,249,255,178,27,87,255,69,3,185,255,141,254,195,1,225,255,218,1,99,3,91,254,64,238,78,0,136,12,219,253,192,7,106,5,96,247,134,250,80,6,189,0,219,255,215,228,155,233,53,6,222,250,16,4,56,250,24,234,67,10,189,13,250,0,250,30,94,0,79,18,242,5,167,21,126,255,50,254,189,29,114,253,135,2,213,231,139,0,86,1,205,19,39,253,128,0,17,0,207,255,176,0,122,0,58,3,247,1,76,0,60,255,223,60,84,50,234,2,154,240,46,3,48,249,238,6,174,254,17,12,98,249,47,2,21,235,18,11,88,250,108,0,183,254,57,253,94,1,171,0,41,1,133,255,160,2,113,2,4,233,166,26,74,3,20,1,242,0,50,247,145,253,178,252,137,9,119,3,238,247,5,252,49,5,107,0,173,255,58,3,189,255,160,254,37,2,137,0,1,252,72,255,245,255,222,53,48,0,115,3,210,13,235,253,79,234,93,3,226,2,76,254,117,235,190,255,107,254,193,14,194,253,226,2,253,0,107,1,180,255,32,1,68,1,175,254,157,0,137,255,159,255,171,0,2,2,116,248,205,235,67,2,249,0,48,4,52,255,62,255,201,254,143,2,184,229,186,0,78,255,99,0,117,22,183,254,163,1,156,3,149,251,86,2,241,255,153,255,27,247,186,0,52,253,226,253,153,0,30,255,57,22,219,0,52,0,122,14,107,252,140,0,176,214,105,255,36,4,133,2,148,1,30,5,75,1,216,0,123,250,114,232,51,236,104,240,86,5,164,3,23,6,169,255,119,30,14,15,178,14,237,251,218,1,160,4,102,0,41,245,81,251,201,251,102,1,193,255,56,38,141,0,107,15,194,0,124,255,180,254,0,254,44,255,49,233,29,255,79,30,39,3,171,253,10,249,108,255,160,254,55,251,76,253,147,0,78,248,180,13,77,252,135,13,59,255,129,18,70,253,66,2,84,255,249,252,231,31,30,12,115,3,110,252,16,0,59,3,114,0,132,248,115,252,162,253,87,0,12,4,77,254,102,0,96,0,142,254,52,255,80,209,21,0,221,1,5,5,137,24,87,3,219,225,131,4,11,254,171,253,55,23,145,0,138,253,178,242,13,0,141,239,167,2,170,25,25,255,102,232,9,254,62,255,157,5,8,22,58,251,245,31,130,1,38,252,9,254,197,4,71,3,251,2,235,254,5,249,45,250,5,0,50,255,42,0,240,10,180,254,231,244,113,255,56,254,134,2,100,253,139,255,115,3,86,0,199,27,242,254,112,2,147,251,204,254,33,254,67,220,112,250,242,0,240,208,8,0,3,9,126,230,239,253,206,1,190,250,103,255,219,16,74,255,93,253,178,255,32,254,207,255,142,1,104,254,96,250,4,32,180,1,207,253,72,255,175,0,7,7,102,255,73,254,47,253,122,8,66,1,155,25,229,253,120,249,139,253,87,244,239,0,219,255,120,29,232,251,39,251,73,28,132,253,252,7,18,253,182,4,83,5,238,253,184,232,86,1,240,226,104,2,116,1,220,17,138,255,87,1,62,4,58,2,92,255,41,2,79,254,50,2,33,0,33,32,21,255,22,255,206,4,234,0,138,3,51,2,183,255,224,40,159,254,124,253,83,250,95,4,237,0,158,2,144,255,171,27,61,254,82,13,151,255,172,12,205,250,102,0,226,2,238,241,76,0,157,1,194,254,10,0,161,234,0,4,177,254,246,0,116,225,92,255,211,9,125,250,161,2,134,23,50,0,197,229,12,1,104,8,73,252,196,255,234,0,219,247,86,1,186,11,87,255,169,9,101,253,66,229,102,3,91,21,150,0,190,255,58,239,213,254,156,253,237,240,177,0,97,1,138,237,35,2,84,1,242,233,26,248,117,0,171,236,209,254,24,1,246,254,151,254,161,2,117,255,251,255,45,228,248,254,243,0,131,235,95,1,144,2,141,19,170,2,149,255,42,1,177,255,127,5,63,254,227,252,99,253,216,253,14,255,179,224,56,0,252,15,47,6,115,240,207,255,220,224,134,1,110,1,225,255,102,4,16,1,0,20,246,255,123,4,158,241,101,255,252,0,163,0,199,1,102,1,22,253,97,245,81,254,188,1,79,254,176,1,155,254,250,20,72,1,253,255,212,6,2,2,30,28,241,253,172,0,145,1,197,255,254,241,163,5,22,2,5,4,27,2,139,14,16,21,37,230,1,246,40,9,26,1,44,252,97,0,195,254,238,252,219,1,58,222,51,1,191,1,221,243,211,0,200,255,16,13,243,249,249,219,198,1,96,1,229,255,205,0,247,1,4,1,140,254,137,253,115,251,113,230,188,1,255,5,148,1,40,249,213,255,91,219,242,2,162,255,34,228,16,8,170,0,30,32,232,254,30,251,165,254,152,6,77,251,239,0,232,251,38,238,144,237,78,254,16,252,201,239,93,247,122,250,6,254,221,234,3,21,216,3,235,17,193,255,143,0,200,3,53,255,195,20,79,2,12,253,204,4,140,254,191,2,173,26,180,255,23,27,211,1,47,12,254,255,15,241,175,0,96,240,60,244,191,225,192,252,234,245,173,0,200,7,184,14,19,1,39,0,91,2,232,253,219,22,218,1,254,0,184,255,6,5,188,252,200,21,77,5,196,13,150,1,2,220,214,253,134,15,160,254,227,6,30,254,146,2,92,6,45,15,146,7,28,24,157,6,193,235,150,0,183,229,214,4,38,4,205,216,84,254,48,0,165,1,71,255,147,2,86,254,135,253,131,0,27,253,206,1,49,254,121,254,63,255,242,254,86,253,169,254,158,208,170,255,108,255,0,1,1,1,1,1,1,2,2,2,2,3,3,3,4,4,5,5,5,6,7,7,8,8,9,10,11,11,12,13,13,14,15,15,16,17,17,18,19,19,20,21,22,22,23,24,25,26,27,27,28,29,30,31,32,33,34,35,36,37,37,38,39,40,41,41,42,43,44,45,45,46,47,48,49,50,51,52,52,53,54,55,55,56,57,57,58,59,59,60,60,60,61,61,61,62,0,1,1,1,1,1,1,2,2,2,2,3,3,3,4,4,4,5,5,5,6,6,7,7,8,8,9,10,10,11,11,12,13,13,14,15,16,17,17,18,19,19,20,21,21,22,22,23,23,24,24,25,25,25,26,26,26,26,27,27,27,27,27,28,28,28,28,28,28,29,29,29,29,29,29,29,29,30,0,0,240,14,35,0,88,72,34,0,4,0,0,0,5,0,0,0,80,165,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,200,39,33,0,88,72,34,0,4,0,0,0,5,0,0,0,80,165,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,159,38,0,112,0,0,0,48,37,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,7,35,0,88,64,34,0,28,0,0,0,5,0,0,0,192,157,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,232,33,33,0,88,64,34,0,28,0,0,0,5,0,0,0,192,157,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,168,182,32,0,88,64,34,0,28,0,0,0,5,0,0,0,192,157,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,80,90,32,0,0,0,0,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,64,65,40,0,128,231,39,0,20,0,0,0,1,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,93,37,0,112,0,0,0,240,37,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,80,38,0,112,0,0,0,16,168,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,97,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,252,36,0,184,184,35,0,4,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,16,0,1,0,104,252,36,0,0,211,34,0,32,18,34,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,104,252,36,0,88,121,33,0,248,255,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,104,252,36,0,112,155,32,0,32,64,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,104,252,36,0,144,40,40,0,72,199,39,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,104,252,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,97,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,81,35,0,112,0,0,0,232,39,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,206,37,0,248,234,36,0,28,0,0,0,5,0,0,0,192,157,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,232,33,33,0,248,234,36,0,28,0,0,0,5,0,0,0,192,157,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,168,182,32,0,248,234,36,0,28,0,0,0,5,0,0,0,192,157,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,199,36,0,0,0,0,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,64,65,40,0,128,231,39,0,20,0,0,0,1,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,4,38,0,112,0,0,0,176,41,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,202,32,0,2,80,1,0,1,0,0,0,232,153,38,0,3,80,1,0,1,0,0,0,24,143,38,0,4,80,1,0,1,0,0,0,168,138,38,0,41,80,1,0,1,0,0,0,72,133,38,0,28,0,0,0,0,0,0,0,160,129,38,0,53,54,50,72,0,0,0,0,208,125,38,0,50,80,1,0,1,0,0,0,200,121,38,0,13,0,0,0,0,0,0,0,144,143,39,0,1,80,1,0,1,0,0,0,48,117,38,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,252,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,7,0,0,26,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,252,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,97,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,97,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,191,38,0,112,0,0,0,32,179,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,255,0,0,0,0,160,207,34,0,144,191,34,0,4,0,0,0,5,0,0,0,80,174,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,155,34,0,144,191,34,0,4,0,0,0,5,0,0,0,80,174,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,200,140,34,0,232,125,34,0,60,6,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,200,75,35,0,232,125,34,0,60,6,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,112,37,0,112,0,0,0,192,45,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,3,3,2,3,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,63,0,0,0,3,0,0,0,0,0,0,0,208,13,40,0,112,0,0,0,32,107,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,7,0,0,0,6,0,0,0,1,0,0,0,224,243,18,0,144,35,16,0,232,219,20,0,136,201,20,0,224,243,18,0,40,220,20,0,208,35,16,0,16,25,16,0,96,35,16,0,40,220,20,0,232,219,20,0,232,219,20,0,232,219,20,0,232,219,20,0,232,219,20,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,12,13,20,21,14,15,22,23,28,29,36,37,30,31,38,39,52,53,60,61,54,55,62,63,68,69,76,77,70,71,78,79,92,93,100,101,94,95,102,103,108,109,116,117,110,111,118,119,0,40,80,0,0,0,0,0,4,5,7,8,0,0,0,0,176,58,178,58,180,58,182,58,184,58,186,58,188,58,190,58,192,58,194,58,196,58,198,58,200,58,202,58,204,58,206,58,208,58,210,58,212,58,214,58,216,58,218,58,220,58,222,58,224,58,226,58,228,58,230,58,232,58,234,58,236,58,238,58,240,58,242,58,244,58,246,58,248,58,250,58,252,58,254,58,64,5,66,5,68,5,70,5,72,5,74,5,76,5,78,5,88,5,94,5,173,2,84,1,84,7,168,3,86,0,40,0,232,0,74,0,11,0,59,0,19,0,3,0,15,0,5,0,1,0,6,0,0,0,8,0,28,0,4,0,36,0,75,0,233,0,41,0,87,0,169,3,85,7,85,1,174,2,95,5,89,5,79,5,77,5,75,5,73,5,71,5,69,5,67,5,65,5,255,58,253,58,251,58,249,58,247,58,245,58,243,58,241,58,239,58,237,58,235,58,233,58,231,58,229,58,227,58,225,58,223,58,221,58,219,58,217,58,215,58,213,58,211,58,209,58,207,58,205,58,203,58,201,58,199,58,197,58,195,58,193,58,191,58,189,58,187,58,185,58,183,58,181,58,179,58,177,58,96,15,98,15,100,15,102,15,104,15,106,15,108,15,110,15,112,15,114,15,116,15,118,15,120,15,122,15,124,15,126,15,128,15,130,15,132,15,134,15,136,15,138,15,140,15,142,15,144,15,146,15,148,15,150,15,152,15,154,15,156,15,158,15,160,15,162,15,164,15,166,15,168,15,170,15,172,15,174,15,176,15,178,15,180,15,182,15,184,15,186,15,188,15,190,15,160,7,162,7,210,3,234,1,252,0,127,0,28,0,12,0,4,0,52,0,16,0,27,0,9,0,11,0,14,0,1,0,3,0,2,0,15,0,12,0,10,0,0,0,17,0,53,0,5,0,13,0,29,0,60,0,253,0,235,1,211,3,163,7,161,7,191,15,189,15,187,15,185,15,183,15,181,15,179,15,177,15,175,15,173,15,171,15,169,15,167,15,165,15,163,15,161,15,159,15,157,15,155,15,153,15,151,15,149,15,147,15,145,15,143,15,141,15,139,15,137,15,135,15,133,15,131,15,129,15,127,15,125,15,123,15,121,15,119,15,117,15,115,15,113,15,111,15,109,15,107,15,105,15,103,15,101,15,99,15,97,15,208,81,210,81,212,81,214,81,216,81,218,81,220,81,222,81,224,81,226,81,228,81,230,81,232,81,234,81,236,81,238,81,240,81,242,81,244,81,246,81,248,81,250,81,252,81,254,81,192,112,194,112,196,112,198,112,200,112,202,112,204,112,206,112,236,112,234,16,104,56,119,56,118,8,53,28,52,4,52,10,27,14,27,2,27,5,15,7,15,1,128,3,128,0,64,1,193,1,65,0,161,0,226,0,34,0,82,0,114,0,18,0,42,0,58,0,10,0,22,0,30,0,6,0,12,0,0,0,4,0,1,0,13,0,7,0,31,0,23,0,11,0,59,0,43,0,19,0,115,0,83,0,35,0,227,0,162,0,66,0,194,1,65,1,129,0,129,3,140,2,12,1,28,5,28,2,28,14,53,10,53,4,58,28,119,8,116,8,105,56,235,16,237,112,207,112,205,112,203,112,201,112,199,112,197,112,195,112,193,112,255,81,253,81,251,81,249,81,247,81,245,81,243,81,241,81,239,81,237,81,235,81,233,81,231,81,229,81,227,81,225,81,223,81,221,81,219,81,217,81,215,81,213,81,211,81,209,81,100,111,102,111,104,111,106,111,108,111,110,111,112,111,114,111,116,111,118,111,120,111,122,111,124,111,126,111,128,111,130,111,132,111,134,111,136,111,138,111,140,111,142,111,144,111,146,111,148,111,150,111,152,111,154,111,156,111,158,111,160,111,162,111,164,111,166,111,168,111,170,111,172,111,174,111,176,111,178,111,180,111,182,111,180,23,220,55,219,11,239,27,238,5,248,13,248,2,253,6,125,1,127,3,191,0,64,0,192,0,33,0,97,0,17,0,49,0,9,0,25,0,6,0,14,0,4,0,0,0,5,0,15,0,7,0,26,0,10,0,54,0,22,0,110,0,46,0,193,0,65,0,188,1,188,0,122,3,122,1,249,2,249,13,239,5,236,5,216,27,221,55,181,23,183,111,181,111,179,111,177,111,175,111,173,111,171,111,169,111,167,111,165,111,163,111,161,111,159,111,157,111,155,111,153,111,151,111,149,111,147,111,145,111,143,111,141,111,139,111,137,111,135,111,133,111,131,111,129,111,127,111,125,111,123,111,121,111,119,111,117,111,115,111,113,111,111,111,109,111,107,111,105,111,103,111,101,111,84,223,86,223,200,223,202,223,204,223,206,223,208,223,210,223,212,223,214,223,216,223,218,223,220,223,222,223,224,223,226,223,232,15,234,47,168,111,246,111,245,7,247,7,210,55,249,55,248,3,248,11,251,11,235,27,250,1,250,5,250,9,250,13,255,13,255,0,255,2,251,6,124,0,124,1,124,2,127,2,60,0,188,0,60,1,188,1,28,0,92,0,156,0,220,0,12,0,44,0,76,0,108,0,4,0,20,0,36,0,52,0,0,0,8,0,16,0,24,0,30,0,2,0,6,0,10,0,14,0,11,0,7,0,3,0,31,0,25,0,17,0,9,0,1,0,53,0,37,0,21,0,5,0,109,0,77,0,45,0,13,0,221,0,157,0,93,0,29,0,189,1,61,1,189,0,61,0,124,3,125,2,125,1,125,0,252,6,252,4,252,2,252,0,251,13,251,9,251,5,251,1,248,27,232,27,249,11,249,3,250,55,211,55,244,23,246,7,247,111,169,111,235,47,233,15,227,223,225,223,223,223,221,223,219,223,217,223,215,223,213,223,211,223,209,223,207,223,205,223,203,223,201,223,87,223,85,223,0,0,0,0,0,0,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,13,13,13,13,13,13,13,13,13,13,12,11,11,10,9,8,8,7,6,6,5,4,4,3,2,3,3,4,5,5,6,7,8,8,9,10,11,11,12,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,14,13,12,11,10,8,7,6,6,5,5,4,4,4,3,3,3,4,4,4,4,5,6,6,7,8,9,11,12,13,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,14,14,13,13,12,12,12,11,11,11,10,10,9,9,9,8,8,8,7,7,7,6,6,6,5,5,5,4,4,3,3,3,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,12,12,12,13,13,13,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,14,13,13,12,12,11,11,10,10,9,8,8,7,7,6,6,5,5,4,4,3,2,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,12,12,12,13,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+593932);
/* memory initializer */ allocate([15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,15,15,15,14,14,14,14,13,13,13,13,12,12,12,12,12,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,5,4,4,4,4,4,4,4,5,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,255,255,255,127,1,0,0,0,255,255,255,127,1,0,0,0,255,255,255,127,2,0,0,0,255,255,255,127,2,0,0,0,255,255,255,127,2,0,0,0,255,255,255,127,2,0,0,0,85,85,85,85,2,0,0,0,85,85,85,85,2,0,0,0,85,85,85,85,2,0,0,0,255,255,255,127,3,0,0,0,255,255,255,127,3,0,0,0,102,102,102,102,3,0,0,0,85,85,85,85,3,0,0,0,73,146,36,73,3,0,0,0,73,146,36,73,3,0,0,0,255,255,255,127,4,0,0,0,102,102,102,102,4,0,0,0,209,69,23,93,4,0,0,0,85,85,85,85,4,0,0,0,73,146,36,73,4,0,0,0,255,255,255,127,5,0,0,0,113,28,199,113,5,0,0,0,102,102,102,102,5,0,0,0,100,33,11,89,5,0,0,0,78,236,196,78,5,0,0,0,68,68,68,68,5,0,0,0,120,120,120,120,6,0,0,0,242,26,202,107,6,0,0,0,209,69,23,93,6,0,0,0,30,133,235,81,6,0,0,0,73,146,36,73,6,0,0,0,255,255,255,127,7,0,0,0,113,28,199,113,7,0,0,0,62,6,231,99,7,0,0,0,129,5,22,88,7,0,0,0,236,115,72,77,7,0,0,0,68,68,68,68,7,0,0,0,120,120,120,120,8,0,0,0,155,6,180,105,8,0,0,0,209,69,23,93,8,0,0,0,30,133,235,81,8,0,0,0,4,222,126,72,8,0,0,0,128,127,128,127,9,0,0,0,14,28,56,112,9,0,0,0,1,58,255,98,9,0,0,0,174,32,38,87,9,0,0,0,181,115,189,76,9,0,0,0,175,213,179,67,9,0,0,0,114,7,40,119,10,0,0,0,105,144,6,105,10,0,0,0,253,161,144,92,10,0,0,0,31,47,131,81,10,0,0,0,247,17,220,71,10,0,0,0,182,189,163,126,11,0,0,0,161,246,140,111,11,0,0,0,84,63,65,98,11,0,0,0,209,196,146,86,11,0,0,0,237,25,75,76,11,0,0,0,169,102,55,67,11,0,0,0,61,214,116,118,12,0,0,0,229,79,91,104,12,0,0,0,235,181,242,91,12,0,0,0,15,55,2,81,12,0,0,0,211,219,94,71,12,0,0,0,216,57,194,125,13,0,0,0,12,217,203,110,13,0,0,0,133,253,161,97,13,0,0,0,201,244,4,86,13,0,0,0,147,59,201,75,13,0,0,0,217,113,197,66,13,0,0,0,174,75,165,117,14,0,0,0,42,187,167,103,14,0,0,0,117,206,82,91,14,0,0,0,146,45,118,80,14,0,0,0,45,145,228,70,14,0,0,0,193,113,235,124,15,0,0,0,29,206,14,110,15,0,0,0,204,26,248,96,15,0,0,0,61,36,111,85,15,0,0,0,252,158,69,75,15,0,0,0,158,58,81,66,15,0,0,0,213,232,219,116,16,0,0,0,23,65,245,102,16,0,0,0,139,16,182,90,16,0,0,0,49,161,235,79,16,0,0,0,243,21,106,70,16,0,0,0,36,192,19,124,17,0,0,0,8,89,81,109,17,0,0,0,77,131,80,96,17,0,0,0,69,146,219,84,17,0,0,0,25,113,195,74,17,0,0,0,255,216,222,65,17,0,0,0,195,232,17,116,18,0,0,0,34,104,67,102,18,0,0,0,247,77,25,90,18,0,0,0,190,174,97,79,18,0,0,0,235,108,240,69,18,0,0,0,20,83,61,123,19,0,0,0,64,113,148,108,19,0,0,0,56,13,170,95,19,0,0,0,11,243,72,84,19,0,0,0,34,86,66,74,19,0,0,0,212,12,109,65,19,0,0,0,208,115,73,115,20,0,0,0,72,205,146,101,20,0,0,0,235,186,125,89,20,0,0,0,83,150,216,78,20,0,0,0,211,154,119,69,20,0,0,0,157,117,104,122,21,0,0,0,79,240,216,107,21,0,0,0,247,210,4,95,21,0,0,0,248,94,183,83,21,0,0,0,69,20,194,73,21,0,0,0,129,9,252,64,21,0,0,0,170,81,130,114,22,0,0,0,175,89,227,100,22,0,0,0,193,39,227,88,22,0,0,0,173,103,80,78,22,0,0,0,154,160,255,68,22,0,0,0,166,9,149,121,23,0,0,0,164,173,30,107,23,0,0,0,48,184,96,94,23,0,0,0,68,198,38,83,23,0,0,0,76,176,66,73,23,0,0,0,198,203,139,64,23,0,0,0,198,203,139,64,23,0,0,0,198,203,139,64,23,0,0,0,198,203,139,64,23,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,1,2,3,4,5,6,7,8,9,10,0,1,0,1,0,1,0,0,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,7,7,8,8,9,9,12,1,0,0,1,0,0,0,42,254,16,0,3,0,0,0,3,0,0,0,1,0,0,0,19,0,0,0,32,0,0,0,41,0,0,0,20,0,0,0,22,0,0,0,69,0,0,0,73,0,0,0,47,0,0,0,66,0,0,0,142,0,0,0,143,0,0,0,41,1,0,0,9,0,0,0,13,0,0,0,172,4,0,0,44,0,0,0,97,5,0,0,230,2,0,0,124,8,0,0,226,2,0,0,92,9,0,0,24,0,0,0,1,0,0,0,22,0,0,0,68,0,0,0,42,0,0,0,7,0,0,0,89,1,0,0,67,1,0,0,40,1,0,0,90,1,0,0,45,1,0,0,43,0,0,0,160,0,0,0,66,1,0,0,42,1,0,0,239,2,0,0,175,4,0,0,125,8,0,0,233,74,0,0,249,67,0,0,103,0,0,0,153,1,0,0,5,43,0,0,131,21,0,0,254,33,0,0,44,254,16,0,4,0,0,0,46,0,0,0,13,1,0,0,10,0,0,0,68,2,0,0,23,0,0,0,69,2,0,0,17,0,0,0,14,1,0,0,44,1,0,0,42,0,0,0,47,0,0,0,33,1,0,0,70,0,0,0,126,8,0,0,186,0,0,0,50,0,0,0,240,135,0,0,220,86,0,0,236,2,0,0,250,67,0,0,111,43,0,0,232,74,0,0,183,2,0,0,43,254,16,0,1,0,0,0,81,0,0,0,16,0,0,0,238,2,0,0,156,11,0,0,118,37,0,0,152,1,0,0,221,86,0,0,205,0,0,0,192,10,0,0,112,1,0,0,239,74,0,0,45,0,0,0,173,4,0,0,255,33,0,0,207,5,0,0,4,43,0,0,41,254,16,0,40,254,16,0,237,2,0,0,116,46,0,0,196,31,2,0,238,74,0,0,227,15,1,0,23,127,8,0,0,0,0,0,151,0,0,0,227,2,0,0,218,10,0,0,117,37,0,0,59,23,0,0,251,67,0,0,117,46,0,0,45,254,16,0,182,21,0,0,108,5,0,0,87,0,0,0,35,1,0,0,32,1,0,0,30,2,0,0,114,1,0,0,177,2,0,0,9,2,21,2,4,5,5,6,6,7,7,7,7,6,7,8,8,9,10,10,11,12,11,12,12,12,12,11,4,5,7,8,9,9,9,9,9,9,8,8,9,9,12,11,12,15,15,13,15,14,13,14,21,5,6,9,10,10,11,10,11,9,9,6,8,9,7,12,10,12,16,15,12,15,14,15,10,21,6,7,11,12,14,14,15,15,14,12,11,15,12,11,14,13,14,21,21,12,16,18,15,17,20,7,8,12,12,14,15,15,16,21,13,11,7,9,9,10,11,10,32,19,34,0,200,97,39,0,60,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,104,20,39,0,200,97,39,0,60,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,224,121,33,0,48,208,38,0,64,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,216,139,38,0,48,208,38,0,64,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,56,80,38,0,144,25,38,0,68,0,0,0,5,0,0,0,224,237,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,192,37,0,208,158,37,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,208,113,37,0,232,47,37,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,240,64,0,0,0,0,0,0,0,0,88,8,37,0,232,47,37,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,240,64,0,0,0,0,0,0,0,0,120,224,36,0,224,189,36,0,72,0,0,0,5,0,0,0,144,160,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,133,36,0,248,106,36,0,76,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,79,36,0,88,55,36,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,208,20,36,0,200,220,35,0,112,193,35,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,208,20,36,0,144,160,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,20,36,0,136,170,35,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,20,36,0,160,148,35,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,20,36,0,64,126,35,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,20,36,0,88,103,35,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,20,36,0,80,85,35,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,208,20,36,0,248,67,35,0,32,50,35,0,100,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,48,22,35,0,184,235,34,0,96,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,224,215,34,0,16,201,34,0,92,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,192,184,34,0,72,166,34,0,88,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,176,148,34,0,208,134,34,0,104,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,216,119,34,0,240,102,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,216,119,34,0,208,78,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,216,119,34,0,64,40,34,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,216,119,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,230,194,230,193,230,192,230,63,230,62,230,61,230,60,230,59,230,58,230,56,230,55,230,54,230,53,230,52,230,50,230,51,230,32,230,123,115,16,230,17,230,18,230,19,230,20,230,21,230,22,230,23,230,24,230,25,230,26,230,27,230,28,230,29,230,30,230,31,230,195,230,33,230,34,230,35,230,36,230,37,230,38,230,39,230,40,230,41,230,42,230,43,230,44,230,45,230,46,230,47,230,48,230,49,230,223,28,96,14,153,3,231,0,29,0,0,0,1,0,1,0,1,0,2,0,6,0,2,0,7,0,6,0,15,0,56,0,114,0,154,3,196,230,197,230,198,230,199,230,200,230,201,230,202,230,203,230,204,230,205,230,206,230,207,230,208,230,209,230,210,230,211,230,212,230,213,230,214,230,215,230,216,230,217,230,218,230,219,230,220,230,221,230,222,230,223,230,224,230,225,230,226,230,227,230,228,230,229,230,230,230,231,230,232,230,233,230,234,230,235,230,236,230,237,230,238,230,239,230,240,230,241,230,242,230,243,230,244,230,245,230,0,0,0,0,0,0,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,16,15,13,11,8,5,2,1,3,5,6,6,7,7,7,9,10,13,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,18,0,0,0,20,0,0,0,23,0,0,0,26,0,0,0,30,0,0,0,34,0,0,0,38,0,0,0,44,0,0,0,50,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,82,0,0,0,93,0,0,0,106,0,0,0,120,0,0,0,136,0,0,0,155,0,0,0,176,0,0,0,200,0,0,0,226,0,0,0,1,1,0,0,36,1,0,0,75,1,0,0,120,1,0,0,171,1,0,0,228,1,0,0,38,2,0,0,112,2,0,0,196,2,0,0,36,3,0,0,144,3,0,0,11,4,0,0,151,4,0,0,54,5,0,0,234,5,0,0,182,6,0,0,158,7,0,0,165,8,0,0,208,9,0,0,35,11,0,0,164,12,0,0,89,14,0,0,73,16,0,0,124,18,0,0,250,20,0,0,207,23,0,0,6,27,0,0,172,30,0,0,209,34,0,0,132,39,0,0,218,44,0,0,232,50,0,0,199,57,0,0,148,65,0,0,111,74,0,0,123,84,0,0,227,95,0,0,213,108,0,0,135,123,0,0,52,140,0,0,34,159,0,0,158,180,0,0,1,205,0,0,174,232,0,0,24,8,1,0,192,43,1,0,56,84,1,0,39,130,1,0,74,182,1,0,118,241,1,0,160,52,2,0,219,128,2,0,97,215,2,0,149,57,3,0,11,169,3,0,142,39,4,0,38,183,4,0,32,90,5,0,27,19,6,0,16,229,6,0,93,211,7,0,215,225,8,0,213,20,10,0,70,113,11,0,194,252,12,0,163,189,14,0,30,187,16,0,99,253,18,0,186,141,21,0,173,118,24,0,53,196,27,0,228,131,31,0,37,197,35,0,117,153,40,0,176,20,46,0,94,77,52,0,19,93,59,0,216,96,67,0,160,121,76,0,209,204,86,0,222,132,98,0,245,209,111,0,198,234,126,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,10,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,26,0,0,0,34,0,0,0,44,0,0,0,56,0,0,0,72,0,0,0,93,0,0,0,120,0,0,0,155,0,0,0,200,0,0,0,1,1,0,0,75,1,0,0,171,1,0,0,38,2,0,0,196,2,0,0,144,3,0,0,151,4,0,0,234,5,0,0,158,7,0,0,208,9,0,0,164,12,0,0,73,16,0,0,250,20,0,0,6,27,0,0,209,34,0,0,218,44,0,0,199,57,0,0,111,74,0,0,227,95,0,0,135,123,0,0,34,159,0,0,1,205,0,0,24,8,1,0,56,84,1,0,74,182,1,0,160,52,2,0,97,215,2,0,11,169,3,0,38,183,4,0,27,19,6,0,93,211,7,0,213,20,10,0,194,252,12,0,30,187,16,0,186,141,21,0,53,196,27,0,37,197,35,0,176,20,46,0,19,93,59,0,160,121,76,0,222,132,98,0,198,234,126,0,0,0,0,0,171,170,170,0,78,117,135,0,101,131,107,0,102,102,102,0,98,70,81,0,10,130,64,0,142,227,56,0,26,39,45,0,119,214,35,0,0,0,0,0,171,170,170,0,78,117,135,0,101,131,107,0,102,102,102,0,98,70,81,0,10,130,64,0,142,227,56,0,26,39,45,0,119,214,35,0,0,0,0,0,208,99,35,0,112,0,0,0,248,63,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,226,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,192,226,35,0,1,0,0,0,4,0,0,0,184,196,35,0,4,0,0,0,64,0,0,0,48,173,35,0,255,255,255,255,2,0,0,0,112,151,35,0,2,0,0,0,1,0,0,0,0,130,35,0,255,255,255,255,128,0,0,0,80,107,35,0,8,0,0,0,0,2,0,0,176,87,35,0,255,255,255,255,16,0,0,0,136,70,35,0,255,255,255,255,0,1,0,0,48,52,35,0,20,0,0,0,0,4,0,0,152,28,35,0,20,0,0,0,8,0,0,0,16,241,34,0,8,0,0,0,0,0,0,0,0,0,0,0,145,215,16,186,177,67,19,186,59,178,1,186,48,154,255,185,173,73,0,186,169,35,4,186,225,2,9,186,127,77,15,186,22,215,20,186,37,231,25,186,43,196,32,186,108,122,37,186,111,115,43,186,79,172,49,186,98,248,53,186,193,162,59,186,197,47,62,186,79,15,67,186,141,92,68,186,207,92,73,186,148,128,74,186,80,95,77,186,209,241,75,186,129,145,76,186,163,130,76,186,231,94,75,186,99,9,72,186,251,100,69,186,96,223,63,186,171,37,61,186,125,89,53,186,46,86,46,186,184,61,38,186,185,223,27,186,61,223,17,186,89,227,6,186,12,129,241,185,201,179,214,185,250,143,183,185,159,226,151,185,206,6,92,185,248,169,23,185,222,118,129,184,39,104,98,55,61,130,229,56,210,57,86,57,239,163,154,57,78,27,211,57,26,227,5,58,190,143,35,58,245,129,67,58,72,170,97,58,223,147,129,58,66,117,147,58,96,220,164,58,7,57,182,58,216,106,202,58,229,23,221,58,144,126,240,58,233,7,2,59,144,166,12,59,139,216,22,59,238,98,33,59,65,183,43,59,225,166,54,59,135,33,65,59,202,251,75,59,245,143,86,59,74,145,97,59,217,251,107,59,234,112,118,59,148,121,128,59,23,194,133,59,215,125,138,59,252,75,143,59,198,36,148,59,85,184,152,59,191,16,157,59,156,3,161,59,187,32,165,59,157,115,168,59,158,231,171,59,76,55,175,59,141,151,177,59,92,209,179,59,103,200,181,59,55,76,183,59,75,57,184,59,13,254,184,59,176,198,184,59,112,95,184,59,176,58,183,59,140,140,181,59,205,106,179,59,104,107,176,59,47,189,172,59,148,94,168,59,143,80,163,59,38,165,157,59,194,220,150,59,170,135,143,59,99,44,135,59,37,7,124,59,111,1,104,59,64,81,82,59,189,109,58,59,130,158,32,59,108,222,4,59,155,228,206,58,37,230,142,58,169,227,24,58,54,144,231,55,42,62,15,186,56,160,151,186,108,114,236,186,84,180,34,187,253,71,81,187,15,28,129,187,47,189,154,187,56,84,181,187,219,8,209,187,144,242,237,187,170,4,6,188,159,160,21,188,122,185,37,188,32,97,54,188,152,163,71,188,14,114,89,60,254,197,107,60,208,157,126,60,137,18,137,60,232,253,146,60,145,46,157,60,109,141,167,60,64,38,178,60,35,249,188,60,69,4,200,60,124,64,211,60,14,181,222,60,175,89,234,60,250,43,246,60,254,7,1,61,57,17,7,61,32,40,13,61,6,85,19,61,250,133,25,61,24,196,31,61,241,7,38,61,65,76,44,61,36,160,50,61,254,237,56,61,10,56,63,61,189,126,69,61,173,186,75,61,105,241,81,61,24,30,88,61,76,48,94,61,228,55,100,61,84,34,106,61,182,253,111,61,133,177,117,61,112,69,123,61,103,97,128,61,137,3,131,61,136,148,133,61,254,15,136,61,218,117,138,61,226,180,140,61,235,223,142,61,32,236,144,61,151,215,146,61,171,158,148,61,212,62,150,61,239,193,151,61,10,20,153,61,22,62,154,61,120,61,155,61,90,14,156,61,159,171,156,61,203,25,157,61,113,82,157,61,97,85,157,61,162,31,157,61,177,174,156,61,141,1,156,61,162,24,155,61,62,236,153,61,220,129,152,61,226,208,150,61,236,215,148,61,235,153,146,61,101,21,144,61,66,62,141,61,138,36,138,61,239,177,134,61,83,245,130,61,15,202,125,61,80,2,117,61,33,149,107,61,235,119,97,61,56,171,86,61,34,39,75,61,114,255,62,61,208,20,50,61,244,111,36,61,185,21,22,61,97,255,6,61,55,62,238,60,77,13,205,60,38,100,170,60,164,26,134,60,3,183,64,60,162,47,228,59,45,137,1,59,225,72,82,187,29,110,12,188,212,124,103,188,138,226,162,188,48,138,211,188,72,225,2,189,8,201,28,189,243,107,55,189,33,221,82,189,241,21,111,189,236,5,134,189,196,224,148,189,5,31,164,189,196,184,179,189,120,177,195,189,22,9,212,189,229,185,228,189,166,198,245,189,148,149,3,190,104,114,12,190,231,122,21,190,5,174,30,190,192,8,40,190,190,138,49,190,114,52,59,190,162,3,69,190,220,249,78,190,155,15,89,190,221,74,99,190,133,163,109,190,239,29,120,190,21,91,129,190,190,181,134,190,156,29,140,190,148,146,145,190,162,19,151,190,56,160,156,190,68,55,162,190,228,214,167,190,171,128,173,190,19,50,179,190,213,233,184,62,136,168,190,62,207,107,196,62,28,51,202,62,156,253,207,62,178,203,213,62,90,154,219,62,39,105,225,62,18,56,231,62,68,5,237,62,72,208,242,62,198,150,248,62,191,88,254,62,24,11,2,63,71,229,4,63,196,188,7,63,182,143,10,63,81,93,13,63,241,37,16,63,254,231,18,63,111,164,21,63,72,89,24,63,47,7,27,63,88,172,29,63,174,73,32,63,223,221,34,63,148,104,37,63,43,233,39,63,32,95,42,63,152,202,44,63,12,42,47,63,246,125,49,63,237,197,51,63,59,0,54,63,161,45,56,63,125,77,58,63,199,94,60,63,255,97,62,63,25,86,64,63,177,58,66,63,228,15,68,63,201,212,69,63,165,136,71,63,129,44,73,63,200,190,74,63,173,63,76,63,206,174,77,63,133,11,79,63,115,86,80,63,77,142,81,63,225,178,82,63,47,197,83,63,57,195,84,63,125,174,85,63,81,133,86,63,197,72,87,63,187,247,87,63,68,146,88,63,153,24,89,63,55,139,89,63,14,232,89,63,164,48,90,63,230,100,90,63,179,131,90,63,156,142,90,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+604172);
/* memory initializer */ allocate([248,249,250,251,252,253,254,255,0,1,2,3,4,5,6,7,251,252,253,254,255,0,1,2,3,4,5,6,7,9,11,13,251,253,254,255,0,1,2,3,4,5,6,7,9,11,13,16,250,252,254,255,0,1,2,3,4,5,6,7,9,11,13,16,252,254,255,0,1,2,3,4,5,6,7,9,11,13,16,20,254,255,0,1,2,3,4,5,6,7,9,11,13,16,20,24,28,224,169,63,31,177,151,63,244,87,143,63,0,0,0,0,171,170,170,62,148,94,154,62,211,103,95,62,4,219,235,61,179,96,2,61,0,0,0,0,54,60,53,63,0,0,128,63,28,206,180,63,249,2,21,80,0,0,0,0,0,0,64,63,102,102,102,63,72,225,122,63,176,45,35,0,56,27,156,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,152,255,34,0,56,27,156,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,8,226,34,0,56,27,156,0,12,0,0,0,1,0,0,0,64,75,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,60,35,0,112,0,0,0,48,85,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,153,62,205,204,204,62,0,0,0,63,51,51,51,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,255,0,1,0,0,255,0,1,255,255,1,1,1,255,255,1,1,2,0,3,4,0,0,0,128,0,128,0,0,1,0,0,68,172,0,0,34,86,0,0,17,43,0,0,0,119,1,0,128,187,0,0,0,125,0,0,192,93,0,0,128,62,0,0,64,31,0,0,0,0,0,0,0,8,12,0,16,20,24,0,64,31,0,0,128,62,0,0,0,125,0,0,17,43,0,0,34,86,0,0,68,172,0,0,224,46,0,0,192,93,0,0,128,187,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,1,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,117,56,0,0,0,0,0,0,8,0,0,0,0,0,0,0,5,0,0,0,115,49,54,0,0,0,0,0,16,0,0,0,0,0,0,0,6,0,0,0,115,51,50,0,0,0,0,0,32,0,0,0,0,0,0,0,7,0,0,0,102,108,116,0,0,0,0,0,32,0,0,0,0,0,0,0,8,0,0,0,100,98,108,0,0,0,0,0,64,0,0,0,0,0,0,0,9,0,0,0,117,56,112,0,0,0,0,0,8,0,0,0,1,0,0,0,0,0,0,0,115,49,54,112,0,0,0,0,16,0,0,0,1,0,0,0,1,0,0,0,115,51,50,112,0,0,0,0,32,0,0,0,1,0,0,0,2,0,0,0,102,108,116,112,0,0,0,0,32,0,0,0,1,0,0,0,3,0,0,0,100,98,108,112,0,0,0,0,64,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,14,0,0,0,14,0,0,0,16,114,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,187,35,0,48,212,34,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,16,64,16,0,1,0,0,0,0,0,112,19,34,0,48,212,34,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,16,64,16,0,1,0,0,0,0,0,40,122,33,0,160,0,33,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,16,156,32,0,160,0,33,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,208,64,32,0,232,40,40,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,128,200,39,0,232,40,40,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,248,97,39,0,128,20,39,0,44,8,0,0,4,0,0,0,205,204,204,204,204,204,236,191,205,204,204,204,204,204,236,191,0,0,0,0,0,0,16,64,16,0,1,0,0,0,0,0,128,208,38,0,128,20,39,0,44,8,0,0,4,0,0,0,205,204,204,204,204,204,236,191,205,204,204,204,204,204,236,191,0,0,0,0,0,0,16,64,16,0,1,0,0,0,0,0,240,139,38,0,96,80,38,0,48,8,0,0,4,0,0,0,205,204,204,204,204,204,236,191,205,204,204,204,204,204,236,191,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,184,25,38,0,96,80,38,0,48,8,0,0,4,0,0,0,205,204,204,204,204,204,236,191,205,204,204,204,204,204,236,191,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,16,238,37,0,200,192,37,0,52,8,0,0,4,0,0,0,205,204,204,204,204,204,236,191,205,204,204,204,204,204,236,191,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,224,158,37,0,200,192,37,0,52,8,0,0,4,0,0,0,205,204,204,204,204,204,236,191,205,204,204,204,204,204,236,191,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,114,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,1,0,0,0,0,0,0,0,0,0,0,248,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,102,35,0,112,0,0,0,136,92,9,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,202,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,121,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,111,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,153,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,131,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,192,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,186,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,62,0,15,1,15,2,15,3,15,4,15,5,15,6,15,7,15,8,15,9,15,10,15,11,15,12,15,13,15,14,15,15,15,16,15,17,15,18,15,19,15,20,15,21,15,22,15,23,15,24,15,25,15,26,15,27,15,28,15,29,15,30,15,31,15,32,15,33,15,34,15,35,15,36,15,37,15,38,15,39,15,40,15,41,15,42,15,43,15,44,15,45,15,46,15,47,15,48,15,49,15,50,15,51,15,52,15,53,15,54,15,55,15,56,15,57,15,58,15,59,15,60,15,61,15,62,15,63,15,128,3,129,3,130,3,131,3,132,3,133,3,134,3,135,3,136,3,137,3,138,3,139,3,140,3,141,3,142,3,143,3,144,3,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,192,0,193,0,194,0,195,0,196,0,197,0,198,0,199,0,200,0,201,0,202,0,203,0,204,0,205,0,206,0,207,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,32,0,33,0,34,0,35,0,12,0,13,0,4,0,0,0,5,0,14,0,15,0,36,0,37,0,38,0,39,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,208,0,209,0,210,0,211,0,212,0,213,0,214,0,215,0,216,0,217,0,218,0,219,0,220,0,221,0,222,0,223,0,160,3,161,3,162,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,170,3,171,3,172,3,173,3,174,3,175,3,176,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,64,15,65,15,66,15,67,15,68,15,69,15,70,15,71,15,72,15,73,15,74,15,75,15,76,15,77,15,78,15,79,15,80,15,81,15,82,15,83,15,84,15,85,15,86,15,87,15,88,15,89,15,90,15,91,15,92,15,93,15,94,15,95,15,96,15,97,15,98,15,99,15,100,15,101,15,102,15,103,15,104,15,105,15,106,15,107,15,108,15,109,15,110,15,111,15,112,15,113,15,114,15,115,15,116,15,117,15,118,15,119,15,120,15,121,15,122,15,123,15,124,15,125,15,126,15,127,15,14,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,6,6,6,6,5,5,4,2,4,5,5,6,6,6,6,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,127,254,0,63,1,63,2,63,3,63,4,63,5,63,6,63,7,63,8,63,9,63,10,63,11,63,12,63,13,63,14,63,15,63,16,63,17,63,18,63,19,63,20,63,21,63,22,63,23,63,24,63,25,63,26,63,27,63,28,63,29,63,30,63,31,63,32,63,33,63,34,63,35,63,36,63,37,63,38,63,39,63,40,63,41,63,42,63,43,63,44,63,45,63,46,63,47,63,48,63,49,63,50,63,51,63,52,63,53,63,54,63,55,63,56,63,57,63,58,63,59,63,60,63,61,63,62,63,63,63,128,15,129,15,130,15,131,15,132,15,133,15,134,15,135,15,136,15,137,15,138,15,139,15,140,15,141,15,142,15,143,15,144,15,145,15,146,15,147,15,148,15,149,15,150,15,151,15,152,15,153,15,154,15,155,15,156,15,157,15,158,15,159,15,192,3,193,3,194,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,202,3,203,3,204,3,205,3,206,3,207,3,224,0,225,0,226,0,227,0,228,0,229,0,230,0,231,0,48,0,49,0,50,0,51,0,8,0,9,0,2,0,0,0,3,0,10,0,11,0,52,0,53,0,54,0,55,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,239,0,208,3,209,3,210,3,211,3,212,3,213,3,214,3,215,3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,160,15,161,15,162,15,163,15,164,15,165,15,166,15,167,15,168,15,169,15,170,15,171,15,172,15,173,15,174,15,175,15,176,15,177,15,178,15,179,15,180,15,181,15,182,15,183,15,184,15,185,15,186,15,187,15,188,15,189,15,190,15,191,15,64,63,65,63,66,63,67,63,68,63,69,63,70,63,71,63,72,63,73,63,74,63,75,63,76,63,77,63,78,63,79,63,80,63,81,63,82,63,83,63,84,63,85,63,86,63,87,63,88,63,89,63,90,63,91,63,92,63,93,63,94,63,95,63,96,63,97,63,98,63,99,63,100,63,101,63,102,63,103,63,104,63,105,63,106,63,107,63,108,63,109,63,110,63,111,63,112,63,113,63,114,63,115,63,116,63,117,63,118,63,119,63,120,63,121,63,122,63,123,63,124,63,125,63,126,63,127,63,16,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,8,8,8,8,8,8,8,8,6,6,6,6,4,4,3,2,3,4,4,6,6,6,6,8,8,8,8,8,8,8,8,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,160,0,0,0,172,0,0,0,240,0,0,0,64,1,0,0,96,1,0,0,128,2,0,0,192,2,0,0,0,0,0,0,120,0,0,0,132,0,0,0,144,0,0,0,240,0,0,0,32,1,0,0,224,1,0,0,248,255,255,255,246,255,255,255,180,0,0,0,104,1,0,0,64,2,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,17,18,18,18,19,19,19,20,20,20,22,22,22,22,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,20,21,21,22,23,23,23,24,24,24,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,4,5,5,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,4,4,5,5,5,7,8,9,64,48,96,32,80,48,48,64,64,64,80,48,32,96,48,64,64,80,32,96,48,80,64,48,80,64,80,48,96,32,80,64,0,0,0,0,16,0,0,0,32,0,0,0,16,0,0,0,32,0,0,0,28,0,0,0,32,0,0,0,28,0,0,0,0,0,0,0,32,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,28,0,0,0,32,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,3,3,3,4,4,4,6,6,6,7,8,8,9,9,10,10,11,11,12,13,14,15,16,17,128,128,128,128,128,128,128,128,128,128,122,96,75,59,47,37,29,23,18,15,13,11,10,9,8,7,6,5,4,3,2,1,1,5,1,0,3,61,29,2,4,60,63,28,13,62,12,1,1,4,5,5,5,7,6,5,4,7,7,6,5,7,5,3,0,0,0,1,0,2,17,0,17,1,17,2,17,5,17,6,34,0,34,1,34,2,34,7,114,2,39,2,34,8,130,2,40,2,18,1,22,1,33,2,0,5,10,3,6,10,7,8,10,4,7,10,6,7,10,8,8,10,8,9,10,9,9,10,9,9,9,2,6,10,4,7,10,7,8,9,5,7,10,6,7,10,8,8,9,8,9,10,8,8,9,9,9,8,6,8,11,6,8,10,7,8,10,6,8,11,7,8,10,8,8,9,8,9,10,9,9,10,9,9,9,7,8,10,7,8,10,7,8,8,7,8,10,7,8,9,7,8,8,8,8,9,8,8,8,7,7,7,0,4,10,3,6,10,7,8,11,3,6,10,5,7,10,9,9,11,9,10,11,9,10,11,11,11,11,2,6,10,4,6,10,7,8,10,4,7,10,6,7,10,8,9,10,8,9,11,9,9,11,10,10,11,6,8,11,6,8,11,8,9,11,7,9,11,7,8,11,9,9,11,9,10,12,10,10,12,11,11,11,8,9,11,8,9,11,9,9,11,9,10,11,9,10,11,9,10,11,10,11,12,10,10,12,10,10,10,0,5,10,3,6,10,7,8,10,4,7,10,6,7,10,8,9,10,8,9,11,8,9,10,10,10,10,2,6,10,4,6,10,7,8,10,4,7,10,5,7,10,8,8,10,8,9,10,8,9,10,9,9,9,5,7,11,6,8,11,7,8,11,6,8,11,7,8,10,8,9,10,8,9,11,9,9,10,10,9,10,7,8,10,7,8,10,8,9,10,8,9,10,8,9,10,8,8,10,9,9,10,9,9,10,9,9,9,0,5,11,3,6,11,8,9,12,4,7,12,6,7,12,9,10,13,10,11,13,10,11,14,12,13,14,1,6,11,4,7,11,8,9,12,5,7,11,6,8,12,9,10,13,10,11,14,10,11,13,12,12,14,6,8,12,7,9,13,9,10,14,7,10,13,8,10,12,11,11,13,11,13,14,11,12,14,13,13,15,9,10,12,9,11,14,10,11,14,11,11,13,10,11,13,11,12,14,12,14,15,13,13,14,13,13,14,0,5,11,3,6,11,7,9,11,4,6,11,5,7,10,9,9,11,8,9,11,9,10,11,11,11,11,2,6,10,3,6,10,7,9,11,4,7,10,5,7,10,8,9,11,8,9,11,9,9,11,11,11,11,5,8,11,6,8,11,8,10,12,6,8,11,7,8,11,9,10,11,9,10,12,9,10,11,11,11,11,8,9,11,8,10,12,9,11,12,8,10,12,9,10,12,10,11,12,10,11,12,10,10,11,11,11,11,0,5,13,2,7,16,9,11,16,4,8,16,7,9,16,12,12,16,12,16,16,12,16,16,16,16,16,1,6,13,4,8,16,9,11,16,6,9,16,7,10,16,13,13,16,13,15,16,12,16,16,16,16,16,7,9,16,8,11,15,11,13,16,10,12,16,10,12,16,16,13,16,16,16,16,14,16,16,16,16,16,12,12,16,12,16,16,16,16,16,13,14,16,12,13,16,16,16,16,16,16,16,14,16,16,16,16,16,0,6,11,3,7,11,8,10,12,4,7,11,6,8,11,10,11,12,9,10,12,10,10,12,12,12,13,1,6,11,4,7,11,8,10,12,4,7,11,6,8,11,10,10,12,9,10,12,10,10,12,13,13,13,6,8,12,7,10,12,10,12,13,7,9,12,8,10,12,11,11,13,11,12,14,11,11,13,13,13,13,9,11,13,10,12,14,12,13,15,10,12,14,11,12,14,13,13,14,12,13,15,13,13,14,14,14,14,0,5,16,2,6,16,10,14,16,4,8,16,7,9,16,11,16,16,11,16,16,16,16,16,16,16,16,1,6,12,4,8,12,12,12,16,6,8,16,8,10,16,16,16,16,16,16,16,16,16,16,12,16,16,7,10,16,8,11,14,16,16,16,10,12,16,10,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,5,11,3,6,11,10,10,12,3,7,11,6,8,11,11,11,12,10,10,12,11,11,13,14,13,14,1,6,11,4,7,11,10,11,13,5,7,11,7,8,11,11,11,13,10,11,13,11,11,12,13,13,14,7,10,12,9,11,13,12,13,14,9,10,13,9,10,13,12,11,13,12,13,16,12,13,13,14,14,14,11,14,16,12,14,15,14,13,16,13,13,15,13,14,16,14,13,16,13,13,16,13,14,15,15,14,15,0,4,16,2,7,16,10,16,16,4,10,16,7,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,6,13,4,11,16,16,16,16,6,10,16,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,16,10,16,16,16,16,16,10,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,5,10,3,6,10,7,8,9,4,6,10,6,7,9,8,8,9,8,8,9,8,9,9,9,9,8,3,6,10,4,6,10,7,7,9,5,7,10,6,7,9,7,7,8,7,8,9,8,8,9,8,8,7,6,8,10,6,8,10,7,8,9,7,8,10,7,8,10,8,8,8,8,9,9,8,8,9,9,8,7,7,8,9,7,8,9,7,7,7,8,8,9,7,8,9,7,7,7,8,8,8,7,7,7,7,6,5,0,5,11,3,6,11,8,9,11,3,6,10,6,7,11,9,9,11,7,9,11,9,9,11,10,10,11,2,6,10,4,7,10,7,9,11,4,7,11,6,7,10,9,9,11,7,9,11,8,9,10,10,10,10,5,8,11,6,8,11,8,9,11,6,8,11,7,8,11,9,9,11,8,10,11,9,9,11,10,10,10,8,9,11,8,9,11,9,9,10,8,9,11,8,9,11,9,9,10,8,9,10,9,9,10,9,9,8,0,5,10,4,6,10,7,8,10,4,6,10,6,7,9,8,8,9,8,8,9,8,9,9,9,9,9,2,6,10,4,6,10,7,7,9,5,7,10,6,7,9,7,7,9,7,8,9,8,8,9,9,8,8,6,8,10,6,8,10,7,8,9,6,8,10,7,8,10,8,8,9,8,9,10,8,8,9,9,9,8,8,8,10,7,8,9,7,8,8,7,8,10,7,8,9,7,7,8,8,8,9,8,8,8,7,7,6,0,5,12,4,7,12,8,10,13,4,7,12,6,8,12,10,10,12,8,9,12,10,10,12,12,12,12,1,6,12,4,7,12,8,9,12,4,7,12,6,8,11,9,10,12,8,9,12,9,10,11,11,11,12,6,8,12,7,9,12,9,10,13,6,9,12,8,9,12,10,10,12,9,10,12,10,10,12,12,12,12,8,10,12,9,10,12,10,10,12,8,10,12,9,10,12,10,10,11,9,10,12,10,10,11,11,10,10,0,5,10,3,6,10,7,8,11,4,6,10,6,7,10,8,9,10,8,8,10,9,9,10,10,10,10,2,6,10,4,6,10,7,8,10,4,7,10,6,7,10,8,8,10,7,8,10,8,8,9,10,9,9,5,8,11,6,8,10,7,9,10,6,8,11,7,8,10,8,8,10,8,9,11,9,9,10,10,9,9,8,9,10,8,9,10,8,9,10,8,9,10,8,8,10,8,8,9,8,9,10,8,8,9,9,8,8,0,6,13,4,7,14,9,11,14,3,7,13,7,8,13,11,11,14,8,10,13,10,11,13,13,13,14,1,6,12,4,8,13,9,10,15,4,8,13,7,8,12,11,11,14,8,10,13,10,10,13,13,13,14,5,9,13,7,9,13,10,11,14,6,10,14,8,10,14,11,11,14,9,11,14,11,11,13,13,13,14,9,10,14,9,11,13,11,12,14,9,11,13,9,11,14,11,12,13,10,12,15,11,11,13,13,12,13,0,5,11,3,6,11,7,9,12,3,6,11,6,7,11,9,9,11,8,9,11,9,9,11,11,11,12,2,6,11,4,6,11,7,9,11,4,7,11,5,7,10,9,9,11,7,8,11,9,9,10,11,11,11,5,8,11,6,8,11,8,9,12,6,8,11,7,8,11,9,9,11,8,9,12,9,9,11,11,11,11,8,10,12,8,10,11,9,10,12,8,10,12,8,9,12,10,10,12,9,10,12,9,9,11,11,10,11,0,6,13,3,8,14,10,12,16,3,8,15,7,9,15,12,13,15,9,11,15,11,12,16,14,16,16,1,7,13,4,8,14,9,11,15,4,8,14,7,9,14,12,13,15,8,10,14,11,11,14,16,14,16,6,9,14,7,10,14,11,13,15,7,10,14,9,10,13,12,12,15,10,11,14,11,11,14,14,14,16,9,11,14,10,11,14,13,14,15,9,12,14,10,12,16,13,14,16,10,13,16,12,12,14,15,14,15,0,6,12,3,7,12,9,11,13,4,7,12,6,8,12,10,11,13,8,10,13,10,11,13,13,13,14,1,6,12,4,7,12,9,10,14,4,7,12,6,7,12,10,11,13,8,9,13,10,10,12,13,13,14,6,9,13,7,9,13,10,12,14,7,9,13,8,10,13,11,11,14,9,11,13,11,11,14,13,13,14,10,12,14,10,12,14,12,13,15,10,12,14,10,12,14,12,13,15,11,13,15,12,12,15,14,14,14,0,6,16,3,8,16,10,13,16,3,8,16,7,9,16,13,16,16,8,10,16,11,13,16,16,16,16,1,7,14,4,8,16,10,12,16,4,8,13,7,9,16,13,14,16,8,10,16,11,11,14,16,16,16,6,9,14,8,10,14,12,16,16,6,10,13,9,11,16,13,14,16,9,12,16,12,11,16,16,16,16,10,12,16,11,12,16,16,14,16,9,12,16,11,12,16,16,15,16,10,13,16,12,13,16,16,16,16,0,10,5,10,7,12,9,11,8,13,9,12,10,13,11,12,16,16,14,15,15,16,13,14,5,12,6,11,9,13,10,11,9,14,9,12,11,14,11,12,16,16,14,15,15,16,13,13,10,15,9,12,12,16,11,12,12,16,10,13,13,16,11,12,16,16,13,14,15,16,13,12,6,12,8,11,8,12,10,11,9,14,10,12,10,13,11,12,15,16,14,15,14,16,13,13,8,13,9,12,10,13,10,12,10,14,9,12,11,14,10,12,15,16,13,15,14,16,13,13,11,16,10,13,13,16,11,12,12,16,11,13,13,16,11,12,16,16,13,14,15,16,12,12,10,16,12,14,10,14,11,12,12,16,13,14,11,14,12,12,16,16,15,16,14,15,13,13,11,16,12,14,11,14,11,12,12,16,12,14,11,14,11,12,16,16,14,15,13,15,13,12,14,16,13,14,13,16,12,12,14,16,13,14,13,16,12,12,16,16,14,14,14,15,12,11,2,10,6,10,7,12,9,11,8,12,9,11,10,13,10,11,15,16,14,15,14,16,13,13,5,12,6,11,9,13,10,11,9,13,9,11,10,13,10,11,15,16,13,14,14,16,13,13,9,15,8,12,12,15,11,11,11,16,10,12,13,15,11,11,15,16,13,14,15,16,12,12,6,12,8,11,8,12,9,11,9,14,9,12,10,13,10,11,15,16,14,15,14,16,13,13,7,13,8,11,9,13,10,11,9,14,9,12,10,13,10,11,14,16,13,14,13,16,12,12,11,16,10,12,12,15,11,11,11,16,10,12,12,15,11,11,15,16,12,13,14,16,12,11,9,15,11,13,9,13,11,12,11,16,12,14,10,14,11,12,16,16,14,15,13,15,12,12,11,16,11,14,10,14,11,12,11,16,12,13,11,14,11,11,15,16,14,15,13,14,12,12,13,16,12,14,13,15,11,11,13,16,12,14,13,15,11,11,16,16,13,14,13,15,11,10,5,12,7,11,8,13,10,11,9,13,9,12,10,14,11,12,16,16,14,15,14,16,13,13,7,13,7,11,9,13,10,11,9,14,9,12,11,14,11,12,16,16,14,14,14,16,13,13,9,15,8,12,12,15,11,12,11,16,10,12,13,16,11,12,16,16,13,14,15,16,12,12,7,13,8,12,9,13,10,11,10,14,10,12,10,14,11,12,16,16,14,15,14,16,13,13,8,14,9,12,10,13,10,11,9,14,9,12,10,14,10,11,15,16,13,14,14,16,12,12,11,16,10,12,12,15,11,12,11,16,10,12,12,15,11,11,15,16,12,14,14,16,12,11,10,16,11,13,9,14,11,12,12,16,12,14,11,14,11,12,16,16,14,16,14,15,13,12,11,16,11,14,10,14,11,12,11,16,12,14,11,14,11,11,15,16,14,15,13,15,12,12,13,16,12,14,13,15,11,11,13,16,12,14,12,14,11,11,15,16,12,13,13,14,11,10,6,13,8,11,9,13,10,11,10,14,10,12,10,13,10,11,15,16,13,13,13,14,12,11,7,13,8,11,9,13,9,11,10,14,9,11,10,13,10,11,15,16,13,13,13,14,11,11,9,14,8,11,10,13,9,10,11,15,9,11,11,13,9,10,15,16,12,13,13,14,10,9,7,13,8,11,9,13,9,11,10,14,10,12,10,13,10,11,15,16,13,13,13,14,11,11,8,13,8,11,9,13,9,10,9,14,9,11,10,13,9,10,14,16,12,13,13,14,11,10,9,14,8,11,10,13,9,9,10,14,8,11,10,13,9,9,14,16,11,12,12,14,10,9,9,14,9,12,8,12,9,10,11,15,10,12,10,13,9,10,15,16,13,13,12,13,11,10,9,14,9,12,9,12,9,10,10,14,10,12,9,12,9,9,14,16,12,13,11,13,10,9,10,14,9,11,10,12,8,8,10,14,9,11,10,12,8,8,12,14,9,10,10,11,8,7,0,9,6,9,6,10,8,9,7,11,8,11,9,11,9,10,14,16,13,14,13,14,12,11,5,11,7,10,8,10,8,9,8,12,8,11,9,12,9,10,14,16,12,13,13,14,11,11,10,14,9,11,11,13,10,10,11,15,9,11,12,13,10,10,15,16,12,12,13,14,11,9,6,11,7,10,7,10,8,9,8,12,9,11,9,11,9,10,14,16,13,13,13,14,11,11,7,12,8,11,8,11,9,9,9,13,9,11,9,12,9,10,14,16,12,13,12,14,11,10,11,14,10,12,11,13,10,10,12,15,10,12,12,13,10,10,15,16,12,12,13,14,10,9,10,14,11,13,9,12,10,10,11,15,12,13,10,12,10,10,14,16,13,14,12,13,11,10,11,14,11,13,10,12,10,10,12,15,11,13,10,12,10,10,15,16,13,13,12,13,11,9,13,16,12,13,12,13,10,9,14,16,12,13,12,13,10,9,16,16,12,12,13,13,10,7,4,10,6,9,7,10,8,9,8,12,9,11,9,11,9,9,14,16,13,13,13,14,11,11,6,11,7,10,8,11,8,9,9,12,9,11,9,12,9,9,14,16,12,13,13,14,11,10,10,14,9,11,11,13,9,9,11,14,9,11,11,13,10,9,14,16,11,12,13,14,10,9,6,11,8,10,7,10,8,9,9,12,9,11,9,11,9,9,14,16,13,13,12,13,11,10,8,12,8,10,8,11,9,9,9,12,9,11,9,11,9,9,14,16,12,13,12,13,11,10,11,14,10,11,11,13,9,9,11,14,10,11,11,13,9,9,14,16,11,12,13,14,10,8,10,14,11,12,9,12,10,10,11,14,11,13,10,12,10,10,14,16,13,14,12,13,11,9,11,14,11,12,10,12,10,10,11,14,11,12,10,12,10,9,14,16,13,13,11,12,10,9,13,16,12,13,12,13,10,9,13,16,11,12,11,13,10,8,15,16,12,12,12,12,9,7,8,12,8,11,9,12,9,10,10,14,10,12,11,13,10,10,16,16,14,14,14,14,12,11,8,13,8,11,9,12,10,10,11,14,10,12,11,13,10,10,16,16,13,14,14,14,12,11,11,14,9,12,11,13,10,10,12,15,10,12,12,14,10,10,15,16,12,12,14,14,11,9,9,13,9,11,9,12,10,10,11,14,10,12,10,12,10,10,15,16,14,14,13,14,12,11,9,13,9,11,10,12,10,10,10,14,10,12,10,12,10,10,15,16,13,13,13,14,11,10,11,15,10,12,11,13,10,10,11,15,10,12,12,13,10,9,15,16,11,12,13,14,10,9,11,15,11,13,10,12,10,10,12,16,12,13,11,13,10,10,16,16,14,14,12,13,11,9,11,15,11,13,10,13,10,10,12,15,12,13,10,12,10,10,14,16,13,13,12,13,10,9,13,16,12,13,12,13,10,9,13,16,11,12,11,13,10,9,14,16,11,12,12,12,9,7,10,15,10,12,11,13,10,10,12,16,12,13,12,13,11,10,16,16,14,14,14,15,12,10,10,14,10,12,10,13,10,10,12,15,11,12,11,13,10,10,16,16,14,13,14,14,11,9,11,14,10,11,11,12,9,9,12,15,10,11,11,13,9,8,16,16,12,12,13,13,10,7,10,15,10,12,10,13,10,10,12,15,11,12,11,13,10,10,16,16,14,13,14,14,11,9,10,14,10,12,10,12,10,10,12,15,11,12,11,13,10,10,16,16,13,13,13,14,11,9,11,14,10,11,10,12,9,8,11,14,9,11,11,12,9,8,14,16,10,11,12,13,9,7,11,15,11,12,10,12,10,9,13,16,11,12,11,12,10,9,16,16,13,13,12,13,10,7,11,15,10,12,10,12,9,8,12,15,11,12,10,12,9,8,14,16,12,12,11,12,9,7,11,14,10,11,10,12,8,7,11,14,9,10,10,11,8,6,12,15,9,9,9,10,7,4,0,6,3,7,3,7,6,7,5,9,6,9,7,9,8,8,16,16,16,16,16,16,16,11,3,8,5,8,6,8,7,7,7,11,7,10,8,10,8,9,16,16,16,16,16,16,14,10,8,16,7,11,10,16,9,9,11,16,9,14,16,16,10,9,16,16,16,16,16,16,16,10,3,8,5,8,5,8,7,7,7,11,8,10,8,10,8,9,16,16,16,16,16,16,16,11,6,10,7,9,7,10,8,8,8,11,8,10,8,11,8,8,16,16,16,16,16,16,11,10,10,16,9,13,11,16,10,9,11,16,9,11,16,16,10,9,16,16,11,16,16,16,11,9,9,16,10,11,8,11,9,9,11,16,12,16,10,16,10,10,16,16,16,16,16,16,16,10,10,16,11,16,10,16,10,10,11,16,11,16,10,16,10,9,16,16,16,16,16,16,11,9,16,16,16,16,16,16,11,9,16,16,16,16,16,16,11,9,16,16,11,16,16,16,9,7,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,2,8,5,9,6,9,8,8,8,12,9,11,9,11,10,10,16,16,14,16,14,16,14,12,5,10,6,9,8,10,8,9,9,12,9,11,10,12,10,10,16,16,14,15,15,16,13,12,10,13,9,12,11,12,10,10,12,15,11,12,12,13,11,10,16,16,15,14,15,16,13,12,6,10,8,10,7,10,8,9,9,13,10,11,10,12,10,10,16,16,14,16,14,16,13,12,7,11,8,11,9,11,9,9,10,13,10,11,10,12,10,9,16,16,14,14,14,15,12,11,11,14,11,12,11,13,10,10,12,15,11,13,12,13,11,10,16,16,14,16,15,15,13,11,10,13,11,12,10,12,10,10,12,15,12,13,11,13,11,11,16,16,15,16,14,15,13,11,11,14,11,13,11,12,11,10,12,16,12,13,12,13,11,10,16,16,15,16,13,15,12,11,13,15,12,13,13,14,11,11,14,16,13,13,13,14,11,11,16,16,15,14,15,15,12,10,3,8,6,9,7,9,8,8,8,12,9,11,9,11,9,9,16,16,15,15,15,16,13,12,6,10,7,9,8,10,8,8,9,12,9,11,10,12,10,9,16,16,14,14,14,15,13,11,10,13,9,11,11,12,10,10,12,14,11,12,12,13,11,10,16,16,14,14,15,15,13,11,6,10,8,10,7,10,8,9,10,12,10,11,10,11,10,9], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+611456);
/* memory initializer */ allocate([16,16,14,15,14,15,13,11,8,11,8,10,9,11,9,9,9,13,9,11,10,11,9,9,16,16,13,14,14,14,12,10,11,14,10,12,11,12,10,10,12,14,11,12,12,13,10,10,16,16,13,14,15,15,12,10,10,13,11,12,10,12,10,10,12,14,12,13,11,13,11,10,16,16,15,14,14,14,12,11,11,14,11,12,10,12,10,10,12,15,12,12,11,13,10,10,16,16,14,15,13,14,12,10,13,15,12,13,12,13,11,10,13,16,12,13,12,13,11,10,16,16,13,14,13,15,11,9,6,10,8,10,8,11,9,10,11,13,11,12,11,13,11,10,16,16,16,16,16,16,13,12,8,11,9,11,9,11,10,10,11,14,11,12,11,12,11,10,16,16,15,15,16,16,13,12,11,14,10,12,12,13,11,10,13,16,12,13,13,14,11,11,16,16,15,16,16,16,13,12,8,12,9,11,9,11,10,10,11,14,11,12,11,12,11,10,16,16,16,16,16,16,13,12,9,12,10,11,10,12,10,10,11,14,11,12,11,13,10,10,16,16,15,14,15,15,13,11,12,14,11,13,12,13,11,10,12,15,11,12,13,13,11,10,16,16,14,15,16,15,13,11,11,15,12,13,11,13,11,10,13,16,13,14,12,14,11,11,16,16,16,16,15,15,13,12,12,14,12,13,11,13,11,10,13,15,12,13,11,13,11,10,16,16,15,15,13,15,13,11,13,16,13,13,13,13,12,11,13,16,13,13,13,13,11,10,16,16,13,15,14,14,12,9,9,13,10,12,11,13,11,11,13,16,13,14,13,14,12,11,16,16,16,16,16,16,14,12,10,14,11,13,11,13,11,10,13,16,13,13,13,14,12,11,16,16,16,16,16,16,14,12,11,15,11,13,12,13,11,10,14,16,12,13,13,14,12,10,16,16,15,16,16,16,13,11,10,14,11,12,11,13,11,10,13,16,12,13,12,14,12,11,16,16,16,16,16,16,14,12,11,14,11,12,11,13,11,10,13,15,12,13,12,13,11,10,16,16,15,15,16,16,13,11,12,15,12,13,12,13,11,10,13,16,12,13,13,13,11,10,16,16,14,14,16,15,13,10,12,15,12,13,12,13,11,10,14,16,13,14,13,14,12,11,16,16,16,16,15,16,13,11,12,16,12,13,12,13,11,10,13,16,13,13,12,14,11,10,16,16,15,16,14,15,13,10,12,15,12,14,12,13,11,10,13,16,12,13,12,13,11,10,16,16,13,14,13,14,11,8,0,11,5,11,7,13,10,12,7,13,9,13,10,14,12,13,16,16,15,16,16,16,15,15,4,13,6,12,10,14,11,12,8,14,9,13,11,15,12,13,16,16,15,16,15,16,15,14,9,16,9,13,13,16,12,13,12,16,10,14,14,16,13,13,16,16,14,16,16,16,14,14,5,13,8,13,8,13,11,12,9,14,10,13,10,14,12,13,16,16,15,16,15,16,14,15,7,14,9,13,10,14,11,13,9,15,10,13,11,14,12,13,16,16,14,16,15,16,14,14,11,16,11,14,13,16,12,13,12,16,11,14,14,16,12,13,16,16,14,15,16,16,14,13,10,16,12,15,10,15,12,14,12,16,13,16,11,15,13,14,16,16,16,16,14,16,14,14,11,16,12,15,11,16,12,13,12,16,13,15,12,16,12,13,16,16,16,16,14,16,14,14,14,16,13,15,14,16,13,13,14,16,14,15,14,16,13,13,16,16,15,16,15,16,13,13,2,12,6,11,7,13,10,12,7,13,9,12,10,14,11,12,16,16,15,16,15,16,14,15,5,13,6,12,9,13,10,12,8,14,9,13,11,14,11,13,16,16,14,16,15,16,14,14,9,16,8,13,12,16,11,13,11,16,10,13,13,16,12,13,16,16,13,15,16,16,13,13,5,13,8,12,7,13,10,12,8,14,10,13,10,14,11,13,16,16,14,16,15,16,14,14,7,14,8,12,9,14,11,12,8,14,9,13,10,14,11,12,15,16,14,15,14,16,13,14,11,16,10,13,13,16,12,13,11,16,10,13,13,16,12,13,16,16,13,15,15,16,13,13,9,16,12,15,9,14,11,13,11,16,13,15,11,14,12,13,16,16,15,16,14,16,14,14,11,16,12,14,11,15,12,13,11,16,12,14,11,15,12,13,16,16,15,16,14,16,13,13,13,16,13,15,13,16,12,13,14,16,13,15,13,16,12,12,16,16,14,15,14,16,12,12,4,13,7,12,8,14,11,12,9,14,10,13,11,14,12,13,16,16,15,16,16,16,15,15,6,14,7,12,10,14,11,12,9,15,10,13,11,15,12,13,16,16,15,16,16,16,14,14,9,16,8,13,12,16,11,13,12,16,10,14,13,16,12,13,16,16,14,16,16,16,14,14,6,14,8,13,8,14,11,13,9,15,10,13,11,14,12,13,16,16,15,16,16,16,14,14,7,15,9,13,10,14,11,13,9,15,10,13,11,14,11,13,16,16,14,16,15,16,14,14,10,16,10,13,12,16,12,13,11,16,10,13,13,16,12,13,16,16,13,14,15,16,13,13,9,16,12,14,9,14,11,13,12,16,12,15,11,15,12,13,16,16,16,16,15,16,14,14,10,16,12,15,11,15,12,13,11,16,12,14,11,15,12,13,16,16,14,16,13,16,13,13,13,16,13,15,13,16,12,13,13,16,12,14,13,16,12,12,15,16,13,14,13,16,12,12,6,14,8,13,9,14,10,12,10,15,10,12,11,14,11,12,16,16,14,14,14,16,13,13,7,15,8,13,9,14,10,12,10,15,10,13,11,14,11,12,16,16,14,14,14,16,13,12,9,16,8,12,11,14,10,11,11,16,10,13,11,14,10,11,16,16,13,14,14,16,12,11,7,14,9,13,9,14,10,12,10,16,10,13,11,14,11,12,16,16,14,14,14,15,13,12,7,14,9,13,9,14,10,12,9,14,10,12,10,14,11,12,15,16,13,14,14,15,12,12,9,15,9,12,11,14,10,11,10,15,9,12,11,14,10,11,14,16,11,13,13,15,11,11,9,16,10,13,9,14,10,11,11,16,11,13,10,14,10,11,16,16,14,15,13,15,12,12,9,16,10,13,9,13,10,11,10,15,10,13,10,13,10,11,14,16,13,14,12,14,11,11,11,16,10,13,11,13,9,10,11,14,10,12,10,13,9,9,13,15,10,11,11,12,9,8,0,10,5,10,6,11,8,10,7,12,8,11,9,12,9,10,14,16,13,13,13,14,12,11,5,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,11,11,9,15,8,12,11,14,10,10,11,16,9,12,12,14,10,10,14,16,11,12,13,14,11,10,5,12,8,11,7,11,9,10,8,13,9,11,9,12,9,10,14,16,12,13,13,14,11,11,7,13,8,11,9,12,9,10,9,13,9,11,9,12,9,10,14,16,12,13,12,13,11,10,11,15,10,12,12,14,10,10,12,16,10,12,12,14,10,10,14,16,11,12,13,14,10,9,10,15,11,13,9,13,10,10,11,15,12,13,10,12,10,10,14,16,13,14,12,13,11,10,11,16,11,13,10,13,10,10,11,16,11,13,10,13,10,10,14,16,13,14,12,13,11,9,13,16,12,13,12,14,11,10,14,16,12,13,12,14,10,9,16,16,12,13,13,13,10,8,3,11,6,10,7,11,9,10,8,12,8,11,9,12,9,10,14,16,13,13,13,14,11,11,5,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,11,10,9,14,8,11,11,14,10,10,11,15,9,11,12,14,10,10,14,16,11,12,13,14,11,9,6,12,8,11,7,11,9,10,8,13,9,11,9,12,9,10,14,16,12,13,13,13,11,10,7,13,8,11,8,12,9,10,9,13,9,11,9,12,9,9,14,16,12,13,12,13,11,10,10,15,9,12,11,14,10,10,11,15,9,11,11,13,10,9,14,16,11,12,13,14,10,9,9,15,11,13,9,12,10,10,11,15,11,13,9,12,10,10,14,16,13,14,12,13,11,10,10,15,11,13,10,13,10,10,11,15,11,13,10,12,10,10,14,16,12,13,11,12,10,9,13,16,12,13,12,14,10,9,13,16,11,12,12,13,10,9,14,16,11,12,12,13,9,8,7,13,8,12,9,13,10,11,10,14,10,12,11,13,11,11,16,16,13,14,14,14,12,11,8,14,8,12,9,13,10,10,10,14,10,12,11,13,10,10,16,16,13,13,14,14,12,11,10,15,9,12,11,14,10,10,12,16,10,12,12,14,10,10,16,16,12,13,14,15,11,10,8,14,9,12,9,13,10,11,10,15,10,12,10,13,10,11,16,16,13,14,14,14,12,11,8,14,9,12,9,13,10,10,10,14,10,12,10,13,10,10,15,16,13,13,13,14,11,10,10,15,10,12,12,14,10,10,11,16,9,12,12,14,10,10,14,16,11,12,13,14,10,9,11,16,11,13,10,13,10,10,12,16,12,13,10,13,11,10,15,16,14,14,12,13,11,10,11,16,11,13,10,13,10,10,11,16,12,13,10,12,10,10,14,16,13,14,11,13,11,9,13,16,12,13,12,14,10,10,12,16,11,12,12,13,10,9,14,16,11,12,11,12,9,8,10,16,10,13,11,14,11,11,12,16,11,13,12,14,11,11,16,16,14,13,14,14,12,10,10,15,10,13,10,13,10,11,12,16,11,13,11,13,11,10,16,16,14,13,14,14,12,10,11,15,9,12,11,13,10,9,12,16,10,12,12,13,10,9,16,16,12,12,13,14,10,8,10,16,10,13,10,14,11,11,12,16,11,13,12,14,11,10,16,16,14,13,14,14,12,10,9,15,9,12,10,13,10,10,11,16,10,12,11,13,10,10,16,16,13,13,13,14,11,9,10,15,9,11,11,13,9,9,11,15,9,11,11,13,9,8,14,16,10,11,13,13,10,8,11,16,11,13,10,13,10,9,13,16,11,13,11,13,10,9,16,16,13,13,13,13,10,8,11,16,10,12,10,13,10,9,11,16,11,12,10,12,9,9,15,16,12,13,11,12,10,8,11,16,10,12,11,12,9,8,11,15,9,11,10,12,9,7,13,15,9,9,10,10,7,5,0,7,3,8,4,9,7,8,5,10,7,10,8,11,8,9,16,16,16,16,16,16,11,10,2,10,4,9,7,10,7,8,7,16,7,10,9,16,8,9,16,16,16,16,16,16,11,10,8,16,7,10,10,16,9,8,10,16,9,11,16,16,9,9,16,16,16,16,16,16,11,9,3,10,6,9,6,11,8,8,7,16,8,10,9,16,9,9,16,16,16,16,16,16,11,10,5,16,7,10,8,11,8,8,8,16,8,10,9,16,8,8,16,16,11,16,16,16,10,9,9,16,9,11,11,16,9,9,11,16,9,11,11,16,9,8,16,16,10,16,16,16,10,9,8,16,10,16,8,16,10,9,12,16,11,16,10,16,10,9,16,16,16,16,16,16,12,10,10,16,11,16,10,16,10,9,11,16,11,16,10,16,10,9,16,16,16,16,16,16,11,9,16,16,16,16,16,16,10,9,16,16,11,16,16,16,10,9,16,16,10,11,11,16,9,7,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,2,9,6,9,6,10,8,9,8,12,9,11,9,12,10,10,16,16,14,14,15,15,13,12,5,11,7,10,8,11,9,9,9,13,9,11,10,12,10,10,15,16,14,14,14,16,12,11,10,14,9,11,11,13,10,10,12,15,10,12,12,13,11,10,16,16,14,15,14,15,12,11,5,11,8,10,7,11,9,9,9,13,9,12,9,12,10,10,15,16,13,14,13,16,12,11,7,12,8,11,9,11,9,10,9,13,9,11,10,12,9,9,16,16,13,14,13,14,11,11,10,14,10,12,11,13,10,10,11,16,11,12,12,13,10,10,16,16,13,14,13,14,12,11,10,14,11,13,10,13,10,11,12,16,12,13,10,12,11,11,16,16,14,15,13,14,12,11,11,15,11,13,11,13,10,10,12,15,12,13,11,13,11,10,15,16,14,15,13,15,12,11,12,16,12,13,12,14,11,11,13,16,12,13,12,14,11,10,16,16,13,14,13,14,11,10,3,10,6,9,7,10,8,9,9,12,9,11,10,12,9,10,15,16,14,14,14,14,12,11,6,11,7,10,8,10,9,9,9,13,9,11,10,12,9,9,15,16,13,14,14,15,12,11,10,14,9,11,11,12,10,10,12,14,10,12,11,13,10,10,15,16,13,14,14,16,12,11,6,11,8,10,7,11,9,9,9,13,9,11,9,12,9,9,15,16,14,14,13,14,12,11,7,11,8,11,8,11,9,9,9,12,9,11,9,12,9,9,15,16,13,13,13,14,11,10,10,13,10,12,11,13,10,10,11,15,10,12,11,13,10,10,14,16,12,13,13,14,11,10,10,14,11,12,9,12,10,10,11,15,11,13,10,13,10,10,15,16,14,14,13,14,12,11,10,14,10,12,10,12,10,10,11,15,11,12,10,12,10,10,15,16,13,14,12,14,11,10,12,16,11,13,12,14,11,10,12,16,12,13,11,13,10,10,15,16,12,14,12,14,11,9,7,12,9,11,9,12,10,10,11,14,11,12,11,13,11,11,16,16,15,16,15,16,13,12,8,12,9,11,9,12,10,10,11,14,11,12,11,13,10,10,16,16,14,15,15,16,13,12,11,14,10,12,11,13,10,10,12,16,11,13,12,14,11,10,16,16,14,15,14,16,12,11,8,13,9,11,9,12,10,10,11,14,11,12,11,13,10,10,16,16,15,15,14,15,13,12,9,13,9,12,9,12,10,10,11,14,10,12,10,12,10,10,16,16,14,15,14,14,12,11,11,15,11,12,11,13,11,10,12,16,11,12,12,13,11,10,16,16,13,15,14,15,11,11,11,16,11,13,10,13,11,11,12,16,12,14,11,13,11,11,16,16,14,15,14,15,13,11,11,16,11,13,11,13,11,10,12,16,12,13,10,13,11,10,16,16,14,14,12,14,12,10,12,16,12,14,12,14,11,11,13,16,12,14,12,14,11,10,15,16,12,14,12,14,11,9,9,14,11,13,11,13,11,11,13,16,12,14,13,14,12,11,16,16,16,16,16,16,14,12,9,14,10,12,10,13,11,11,12,16,12,13,13,14,11,11,16,16,16,16,16,14,13,12,10,15,11,13,11,14,11,10,13,16,12,13,12,15,11,10,16,16,14,16,15,16,13,11,10,14,10,13,11,14,11,11,13,16,12,13,12,14,11,11,16,16,16,16,15,16,13,12,10,14,10,12,10,13,10,11,12,15,12,13,12,13,11,10,16,16,14,14,15,15,13,11,11,16,11,13,11,14,11,10,12,16,11,13,12,14,11,10,16,16,13,14,14,15,12,10,11,16,12,13,11,14,11,10,13,16,13,14,12,14,11,11,16,16,15,16,15,15,12,11,11,16,12,13,11,14,11,10,13,16,12,13,11,14,11,10,16,16,14,15,13,14,12,10,12,16,12,14,12,14,10,10,12,16,11,13,11,14,10,10,14,16,11,13,12,13,10,8,0,12,6,13,7,14,11,14,8,14,10,14,11,15,13,15,16,16,16,16,16,16,16,16,5,14,7,13,10,16,12,14,9,16,10,14,12,16,13,16,16,16,16,16,16,16,16,16,10,16,9,14,14,16,13,16,12,16,11,16,16,16,14,16,16,16,16,16,16,16,16,16,5,14,9,14,8,14,12,14,9,16,11,14,11,16,13,16,16,16,16,16,16,16,16,16,8,16,10,14,11,16,12,14,10,16,11,15,12,16,13,16,16,16,16,16,16,16,16,16,12,16,12,16,14,16,14,16,13,16,12,16,15,16,14,16,16,16,16,16,16,16,16,16,10,16,13,16,11,16,14,16,13,16,14,16,13,16,14,16,16,16,16,16,16,16,16,16,12,16,14,16,13,16,14,16,13,16,14,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,15,16,16,16,14,16,16,16,16,16,16,16,16,16,1,12,6,12,8,14,11,13,8,14,10,13,11,14,13,14,16,16,16,16,16,16,16,16,5,14,7,13,10,14,11,14,9,16,10,14,12,16,13,15,16,16,16,16,16,16,16,16,9,16,9,14,13,16,13,14,12,16,11,15,14,16,13,16,16,16,16,16,16,16,16,16,5,14,9,13,8,14,12,14,9,16,11,14,11,16,13,14,16,16,16,16,16,16,16,16,7,15,9,14,10,16,12,14,9,16,10,14,11,16,12,14,16,16,16,16,16,16,15,16,11,16,11,15,14,16,13,15,12,16,11,15,14,16,13,14,16,16,14,16,16,16,14,16,10,16,13,16,10,16,13,16,12,16,14,16,12,16,13,16,16,16,16,16,16,16,16,16,11,16,13,16,12,16,13,16,12,16,13,16,12,16,13,16,16,16,16,16,16,16,15,16,14,16,14,16,16,16,14,16,15,16,14,16,14,16,14,16,16,16,16,16,16,16,14,14,4,14,8,13,9,16,12,14,9,16,11,14,11,16,13,16,16,16,16,16,16,16,16,16,6,15,8,13,10,16,12,14,10,16,11,14,12,16,13,16,16,16,16,16,16,16,16,16,9,16,9,14,13,16,13,15,12,16,11,16,14,16,13,16,16,16,16,16,16,16,16,16,6,16,9,14,9,16,12,14,10,16,11,15,12,16,13,15,16,16,16,16,16,16,16,16,8,16,10,14,11,16,12,14,10,16,11,14,12,16,13,15,16,16,16,16,16,16,16,16,11,16,11,15,14,16,13,15,12,16,11,15,14,16,13,14,16,16,14,16,16,16,14,16,10,16,13,16,10,16,13,15,13,16,14,16,12,16,14,16,16,16,16,16,16,16,16,16,11,16,13,16,12,16,13,16,12,16,13,16,11,16,13,16,16,16,16,16,15,16,15,16,14,16,14,16,15,16,14,16,14,16,14,16,14,16,14,14,16,16,14,16,15,16,14,14,6,16,9,14,10,16,12,14,10,16,11,13,12,16,13,14,16,16,16,16,16,16,14,14,7,16,9,14,10,16,12,13,11,16,11,14,12,16,12,14,16,16,16,16,16,16,14,14,9,16,9,14,12,16,11,13,12,16,11,14,12,16,12,13,16,16,14,16,16,16,13,14,7,16,10,14,10,16,12,14,11,16,11,14,11,16,12,14,16,16,16,16,16,16,14,14,8,16,10,14,10,16,11,13,10,16,11,13,11,16,12,13,16,16,14,16,16,16,14,14,10,16,9,13,12,16,11,13,11,16,10,13,12,16,11,12,16,16,13,15,15,16,13,13,9,16,11,14,9,16,11,13,12,16,12,16,12,16,12,13,16,16,16,16,15,16,14,14,10,16,11,14,10,16,11,13,11,16,12,14,10,15,11,13,16,16,15,16,13,16,13,13,12,16,11,13,12,16,11,12,12,16,11,13,11,14,11,11,13,16,12,13,12,14,11,11,0,10,5,10,6,11,8,10,7,12,8,11,8,12,9,10,14,16,13,13,13,14,12,11,4,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,11,11,9,15,8,12,12,14,10,11,11,16,9,12,12,14,10,10,14,16,11,13,13,15,11,11,4,12,8,11,6,11,9,10,8,13,9,11,8,12,9,10,14,16,12,13,13,14,11,11,7,13,8,11,9,12,9,10,8,13,9,11,9,12,9,10,14,16,12,13,12,13,11,10,11,16,10,12,12,14,10,11,11,16,10,12,12,14,10,10,15,16,11,13,13,14,11,10,10,16,11,13,9,13,10,11,11,15,12,13,10,12,10,11,15,16,13,14,12,13,11,11,11,16,11,13,10,13,10,11,12,16,11,13,10,13,10,10,15,16,13,14,12,13,11,10,13,16,12,13,13,14,11,11,14,16,12,13,12,14,11,10,16,16,13,13,13,14,11,9,3,11,6,10,6,11,9,10,8,12,8,11,9,12,9,10,14,16,13,13,13,13,12,11,5,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,11,11,9,15,8,11,11,14,10,10,11,15,9,11,12,14,10,10,14,16,11,12,13,14,11,10,5,12,8,11,7,11,9,10,8,13,9,11,9,12,9,10,14,16,12,13,13,13,11,11,7,13,8,11,8,12,9,10,8,13,8,11,9,12,9,9,13,16,11,13,12,13,11,10,10,15,9,12,11,14,10,10,11,15,9,11,11,13,10,10,14,16,11,12,13,14,10,10,9,16,11,13,9,12,10,10,11,16,11,13,9,12,10,10,15,16,13,14,12,13,11,10,11,16,11,13,10,13,10,10,11,15,11,13,9,12,10,10,14,16,12,13,11,13,10,10,13,16,12,13,12,14,11,10,13,16,11,13,12,13,10,10,14,16,11,12,12,13,10,9,7,14,8,12,9,13,10,11,10,14,10,12,11,13,11,11,16,16,14,14,14,14,12,12,7,14,8,12,9,13,10,11,10,14,10,12,11,13,10,11,16,16,13,13,14,14,12,11,10,15,9,12,12,14,10,10,12,16,9,12,12,14,10,10,16,16,12,13,14,15,12,11,8,14,9,12,9,13,10,11,10,15,10,12,10,13,10,11,16,16,14,14,14,14,12,11,8,14,9,12,9,13,10,11,10,14,10,12,10,13,10,10,15,16,13,13,13,14,12,11,10,15,10,12,12,14,10,10,11,16,9,12,12,14,10,10,14,16,11,12,13,14,11,10,11,16,11,14,9,13,10,11,12,16,12,14,10,13,11,11,16,16,14,15,13,14,12,11,11,16,12,14,10,13,11,11,11,16,11,13,10,13,10,10,15,16,13,14,12,13,11,10,13,16,12,14,13,14,11,10,12,16,11,13,12,13,10,10,14,16,11,12,11,13,10,9,10,16,10,13,11,14,11,11,12,16,11,13,12,14,11,11,16,16,14,13,14,15,12,11,10,16,10,13,10,14,11,11,12,16,11,13,11,14,11,11,16,16,14,13,14,14,12,11,11,15,9,12,11,14,10,10,13,16,10,12,12,14,10,10,16,16,13,13,14,14,11,10,10,16,10,13,11,14,11,11,12,16,11,13,12,14,11,11,16,16,14,14,14,14,12,11,9,16,10,13,10,14,11,11,11,15,11,12,11,13,11,11,16,16,13,13,14,14,12,10,10,15,9,12,11,14,10,10,11,16,9,11,11,13,10,9,15,16,11,12,13,14,10,9,11,16,11,13,10,13,10,10,13,16,12,13,11,13,10,10,16,16,14,14,13,13,11,10,11,16,11,13,10,13,10,10,12,16,11,13,10,13,10,10,15,16,13,13,12,13,11,9,11,16,11,12,11,13,10,9,11,15,10,11,11,12,9,8,13,15,10,10,10,11,8,7,0,9,3,8,5,9,7,8,5,11,6,9,8,11,8,9,16,16,16,16,16,16,11,10,2,10,4,9,7,10,7,8,7,16,7,10,9,11,8,9,16,16,11,16,16,16,11,10,7,16,7,10,10,16,8,9,10,16,8,10,11,16,9,9,16,16,16,16,16,16,11,10,3,11,6,9,6,11,8,8,7,16,8,10,8,11,8,9,16,16,15,16,16,16,11,10,5,11,7,9,8,11,8,8,7,16,7,10,8,11,8,8,16,16,11,16,16,16,10,9,9,16,8,11,11,16,9,9,10,16,8,11,11,16,9,9,16,16,10,16,16,16,10,9,8,16,10,11,8,16,9,9,11,16,11,16,10,16,10,9,16,16,16,16,16,16,11,10,9,16,10,16,10,16,9,9,10,16,10,16,9,16,9,9,16,16,16,16,15,16,10,9,16,16,11,16,16,16,10,10,13,16,11,16,11,16,10,9,16,16,10,11,11,16,9,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,6,10,7,11,9,10,8,12,9,12,9,12,10,10,16,16,14,16,14,15,13,12,5,12,7,10,9,11,9,10,9,13,9,12,10,13,10,10,16,16,14,15,14,14,13,12,10,15,10,12,12,14,11,11,12,16,11,13,12,14,11,11,16,16,14,16,15,16,13,12,6,12,8,11,8,11,10,10,9,13,10,12,10,12,10,10,15,16,13,15,13,14,12,12,7,13,9,11,9,12,10,10,9,14,10,12,10,13,10,10,15,16,13,15,13,14,12,11,11,15,11,13,12,14,11,11,12,16,11,13,12,14,11,11,16,16,13,15,14,16,12,11,10,16,12,14,10,13,11,11,12,16,12,14,11,13,11,11,16,16,15,16,14,16,13,12,11,16,12,14,11,14,11,11,12,16,12,14,11,14,11,11,16,16,14,15,13,15,12,12,13,16,13,15,13,15,12,12,13,16,12,15,12,15,11,11,16,16,13,16,13,15,12,11,4,11,7,10,7,11,9,10,9,13,9,12,10,12,10,10,15,16,14,15,14,15,13,12,6,12,7,11,9,11,9,10,9,13,9,12,10,12,10,10,15,16,14,15,14,15,12,12,10,15,9,12,12,13,11,11,12,15,11,13,12,14,11,11,16,16,13,15,14,16,12,12,6,12,8,11,8,11,9,10,9,14,10,12,10,12,10,10,14,16,13,14,13,14,12,12,8,13,9,11,9,12,10,10,9,13,9,12,9,12,9,10,14,16,13,14,13,14,12,11,11,15,11,13,11,14,11,11,12,16,10,13,12,13,11,10,15,16,12,15,13,16,12,11,10,15,11,13,10,13,11,11,12,16,12,14,11,13,11,11,16,16,14,15,13,16,13,12,11,16,11,14,11,13,11,11,12,16,12,14,10,13,11,11,15,16,13,16,12,14,12,11,12,16,12,14,12,15,11,11,13,16,12,14,12,14,11,11,15,16,13,15,13,15,11,10,7,13,9,12,10,13,11,11,11,15,12,13,12,13,11,11,16,16,15,16,16,16,14,13,8,13,9,12,10,13,11,11,12,15,11,13,12,13,11,11,16,16,14,15,15,16,13,12,11,16,11,13,12,14,11,11,13,16,12,14,13,15,12,11,16,16,14,16,15,16,13,12,9,15,10,13,10,13,11,11,12,15,11,13,11,13,11,11,16,16,14,16,16,16,13,12,9,14,10,13,10,13,11,11,11,14,11,13,11,13,11,11,16,16,14,16,14,16,12,12,11,16,11,14,12,14,12,11,12,16,11,13,13,14,11,11,16,16,13,15,14,16,12,11,12,16,12,14,11,14,11,11,13,16,13,14,12,15,12,11,16,16,16,16,14,16,13,12,12,16,12,14,11,14,12,11,12,16,12,15,11,14,11,11,16,16,14,16,13,15,12,12,13,16,13,16,13,16,12,12,13,16,12,15,12,16,11,11,14,16,12,15,12,15,11,10,9,16,11,14,12,14,12,12,13,16,13,15,14,16,12,12,16,16,16,16,16,16,14,13,10,16,11,14,12,14,12,12,13,16,13,14,13,16,12,12,16,16,15,16,16,16,13,12,11,16,11,14,12,15,12,11,13,16,12,14,13,16,12,11,16,16,14,16,16,16,13,12,11,16,11,14,12,14,12,12,13,16,12,15,13,16,12,12,16,16,16,16,16,16,14,13,10,16,11,14,11,15,11,11,13,16,12,14,12,14,12,11,16,16,14,16,16,16,13,12,11,16,11,15,12,15,12,11,13,16,11,14,13,15,12,11,16,16,13,16,14,16,12,11,12,16,12,15,11,15,12,11,14,16,13,15,12,16,12,11,16,16,15,16,14,16,13,12,11,16,12,15,11,15,11,11,13,16,13,16,11,15,11,11,16,16,14,16,13,15,12,11,12,16,12,15,12,16,11,11,12,16,11,15,12,14,11,11,13,16,12,13,11,13,10,9,0,13,6,13,8,14,12,16,8,16,11,16,12,16,14,16,16,16,16,16,16,16,16,16,4,16,7,14,11,16,13,16,9,16,11,16,12,16,14,16,16,16,16,16,16,16,16,16,10,16,10,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,10,16,8,16,13,16,10,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,8,16,10,16,11,16,13,16,10,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,12,16,12,16,16,16,16,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,11,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,13,16,16,16,14,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,13,7,13,8,16,12,16,8,16,10,16,11,16,13,16,16,16,16,16,16,16,16,16,4,16,7,14,10,16,12,16,9,16,10,16,12,16,14,16,16,16,16,16,16,16,16,16,10,16,9,16,14,16,14,16,13,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,9,16,8,16,12,16,9,16,11,16,11,16,13,16,16,16,16,16,16,16,16,16,7,16,10,16,11,16,13,16,9,16,11,16,11,16,13,16,16,16,16,16,16,16,16,16,12,16,12,16,16,16,14,16,13,16,12,16,16,16,14,16,16,16,16,16,16,16,16,16,10,16,13,16,11,16,14,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,12,16,14,16,13,16,14,16,13,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,16,8,16,9,16,13,16,10,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,6,16,8,16,11,16,13,16,10,16,11,16,13,16,14,16,16,16,16,16,16,16,16,16,9,16,9,16,13,16,13,16,13,16,12,16,16,16,14,16,16,16,16,16,16,16,16,16,6,16,10,16,10,16,13,16,10,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,8,16,10,16,11,16,13,16,10,16,11,16,12,16,14,16,16,16,16,16,16,16,16,16,11,16,11,16,16,16,14,16,12,16,11,16,16,16,14,16,16,16,16,16,16,16,16,16,10,16,13,16,10,16,13,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,12,16,13,16,12,16,14,16,12,16,15,16,12,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,10,16,10,16,13,16,11,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,8,16,9,16,11,16,12,16,11,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,9,16,9,16,12,16,12,16,13,16,11,16,13,16,13,16,16,16,16,16,16,16,16,16,8,16,10,16,10,16,12,16,11,16,12,16,12,16,13,16,16,16,16,16,16,16,16,16,8,16,10,16,11,16,12,16,10,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,10,16,10,14,12,16,12,16,11,16,10,14,13,16,12,14,16,16,14,16,16,16,14,16,9,16,12,16,10,16,12,16,13,16,13,16,12,16,13,16,16,16,16,16,16,16,16,16,10,16,12,16,11,16,12,16,11,16,12,16,11,16,12,15,16,16,16,16,16,16,16,16,13,16,12,16,13,16,12,13,12,16,12,16,12,16,12,13,16,16,13,14,13,16,13,13,0,10,5,10,5,10,8,10,6,11,8,11,8,11,9,10,14,16,13,14,13,14,12,12,4,12,5,10,8,12,9,10,7,12,8,11,9,12,9,10,14,16,12,13,13,14,12,12,9,16,8,12,12,14,10,11,11,16,9,12,12,14,11,11,14,16,12,13,14,15,12,12,4,12,7,11,6,11,9,10,8,12,9,11,8,11,9,10,14,16,12,14,13,14,12,12,7,13,8,11,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,12,13,11,11,11,16,10,12,12,14,11,11,12,16,10,12,12,14,11,11,16,16,12,13,14,15,12,11,10,16,11,14,9,13,10,11,11,16,12,14,10,13,11,11,15,16,13,14,13,14,12,12,11,16,12,14,10,13,11,11,12,16,12,14,11,13,11,11,15,16,13,14,13,14,12,11,14,16,13,14,13,15,12,12,14,16,12,14,13,15,11,11,16,16,13,14,14,15,12,11,3,11,5,10,6,11,9,10,7,12,8,11,9,11,9,10,14,16,13,13,13,14,12,12,5,12,6,10,8,12,9,10,8,13,8,11,9,12,9,10,14,16,12,13,13,14,12,12,9,16,8,11,11,14,10,11,11,16,9,12,12,14,10,11,15,16,12,13,14,15,12,11,5,12,7,11,6,11,9,10,8,13,9,11,8,11,9,10,14,16,12,14,13,13,12,12,7,13,8,11,8,12,9,10,8,12,8,11,9,12,9,10,13,16,12,13,12,13,11,11,10,16,9,12,12,14,10,11,11,15,9,12,12,14,10,11,14,16,11,13,13,14,11,11,9,16,11,14,8,13,10,11,11,16,12,13,10,13,10,11,16,16,13,15,13,14,12,12,11,16,11,14,10,13,10,11,11,16,11,13,10,13,10,11,14,16,13,14,12,13,11,11,14,16,12,14,13,15,11,11,13,16,12,13,12,14,11,11,14,16,12,13,12,13,11,10,6,14,8,12,9,13,10,11,10,14,10,12,11,13,11,12,16,16,14,14,14,14,13,12,7,14,8,12,9,13,10,11,10,14,10,12,11,13,11,11,16,16,13,14,14,15,13,12,10,16,8,12,12,14,10,11,12,16,10,12,13,15,11,11,16,16,13,14,15,16,12,12,8,15,9,13,9,13,10,11,10,15,10,13,10,13,11,11,16,16,14,14,14,14,13,12,8,15,9,12,10,13,10,11,10,14,10,12,10,13,10,11,16,16,13,14,13,14,12,12,10,16,10,13,12,15,11,11,11,16,9,12,12,14,11,11,14,16,11,13,14,16,12,11,10,16,12,14,9,13,11,11,12,16,12,14,11,13,11,11,16,16,15,16,14,14,13,12,11,16,12,14,11,14,11,11,11,16,12,14,10,13,11,11,15,16,13,15,12,14,12,11,14,16,13,14,13,16,12,12,12,16,12,13,12,14,11,11,14,16,11,12,12,13,10,10,9,16,10,14,11,15,12,12,12,16,11,13,12,15,12,12,16,16,14,13,15,15,13,12,10,16,10,14,11,15,11,12,12,16,11,13,12,14,12,12,16,16,14,13,15,14,13,12,11,16,9,12,12,14,11,11,13,16,11,13,13,15,11,11,16,16,14,14,16,16,12,12,10,16,10,14,11,14,11,12,12,16,11,13,12,14,12,12,16,16,14,14,15,15,13,12,10,16,10,13,11,14,11,12,11,16,11,13,11,14,11,12,16,16,14,14,14,14,13,12,11,16,10,12,12,15,11,11,12,16,9,12,12,14,10,11,16,16,12,13,14,15,11,11,11,16,12,14,10,14,11,11,13,16,12,14,12,14,11,11,16,16,15,15,14,15,12,12,11,16,12,14,11,14,11,11,12,16,12,14,11,13,11,11,16,16,14,14,13,14,12,11,12,16,11,13,12,14,10,10,12,15,11,12,12,13,10,10,14,15,11,11,12,12,10,9,0,8,3,8,5,9,7,8,5,10,6,10,8,11,8,9,16,16,15,16,16,16,11,11,2,10,4,9,7,10,7,8,7,16,7,10,9,11,8,9,16,16,15,16,16,16,11,11,7,16,6,11,10,16,9,10,10,16,9,11,11,16,9,10,16,16,16,16,16,16,16,11,3,10,6,9,5,10,7,9,7,16,8,10,8,11,8,9,16,16,16,16,16,16,11,11,5,11,7,10,8,11,8,9,7,14,7,10,8,11,8,9,16,16,11,16,16,16,10,11,9,16,9,11,11,16,9,10,10,16,8,11,11,16,9,10,16,16,11,16,16,16,11,10,8,16,9,16,7,16,9,10,11,16,11,16,10,16,10,10,16,16,16,16,16,16,16,11,9,16,10,16,9,16,9,10,10,16,10,16,9,16,9,10,16,16,16,16,11,16,11,11,16,16,16,16,16,16,10,10,11,16,11,16,11,16,10,10,16,16,11,16,11,16,10,9,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,6,10,7,11,9,10,8,12,9,12,9,12,10,10,15,16,14,15,14,16,13,12,5,12,7,11,8,11,9,10,9,13,9,12,10,12,10,10,16,16,14,15,13,16,13,12,10,15,10,13,12,14,11,11,12,16,11,13,12,14,11,11,16,16,14,16,14,16,13,12,5,12,8,11,7,11,9,10,9,13,10,12,9,12,10,10,14,16,14,15,13,14,13,12,7,13,9,12,9,12,10,10,9,13,9,12,9,12,10,10,14,16,13,14,13,15,12,12,11,16,11,13,12,14,11,11,12,16,11,14,12,14,11,11,16,16,14,16,14,16,13,12,10,16,11,14,10,13,11,11,12,16,12,14,11,13,11,11,15,16,15,16,14,16,13,12,11,16,12,14,11,14,11,12], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+621696);
/* memory initializer */ allocate([12,16,12,14,11,14,11,11,15,16,14,16,13,16,13,12,13,16,13,16,13,16,12,12,13,16,13,16,13,16,12,12,16,16,14,15,14,16,13,12,4,11,7,10,7,11,9,10,9,13,9,11,9,12,10,10,15,16,14,15,14,15,13,12,6,12,7,11,8,11,9,10,9,13,9,12,10,12,10,10,15,16,13,14,14,15,12,12,10,14,10,12,12,13,11,11,12,16,11,13,12,14,11,11,16,16,14,15,15,16,13,12,6,12,8,11,8,11,9,10,9,13,10,12,9,12,10,10,16,16,14,15,13,14,12,12,8,13,9,11,9,12,9,10,9,13,9,12,9,12,9,10,14,16,13,14,13,14,12,11,11,15,11,13,12,14,11,11,11,16,10,13,12,14,11,11,15,16,13,15,14,16,12,11,10,16,12,13,10,13,11,11,11,16,12,14,10,13,11,11,16,16,14,16,13,16,13,12,11,16,12,14,10,14,11,11,11,16,12,14,10,13,11,11,16,16,14,16,12,15,12,11,13,16,13,15,13,15,12,12,13,16,12,15,12,15,12,11,15,16,13,16,13,16,12,11,8,14,9,12,10,13,11,11,11,16,11,13,11,13,11,11,16,16,16,16,16,16,14,13,9,14,10,12,10,13,11,11,11,16,11,13,12,13,11,11,16,16,15,16,15,16,14,12,11,16,11,13,12,14,12,11,13,16,12,14,13,14,12,11,16,16,15,16,16,16,14,13,9,14,10,13,10,13,11,11,11,16,11,13,11,13,11,11,16,16,15,16,14,15,14,13,9,14,10,13,10,13,11,11,11,15,11,13,11,13,11,11,16,16,14,16,14,16,13,12,12,16,12,14,13,14,12,11,12,16,11,14,12,15,12,11,16,16,13,16,15,16,13,11,11,16,12,14,11,14,12,11,13,16,13,15,12,14,12,12,16,16,16,16,14,16,14,13,12,16,13,15,11,14,12,12,12,16,13,14,11,15,12,11,16,16,15,16,13,15,13,12,13,16,13,15,13,16,12,12,13,16,13,15,13,15,12,12,15,16,13,16,13,15,11,10,10,16,12,14,12,15,12,12,14,16,13,15,13,16,13,12,16,16,16,16,16,16,15,13,10,16,12,14,12,15,12,12,13,16,13,15,13,15,13,12,16,16,16,16,16,16,14,13,11,16,12,15,13,16,12,12,14,16,13,16,13,16,12,12,16,16,15,16,15,16,14,12,11,16,12,14,12,16,12,12,14,16,13,15,13,15,13,12,16,16,16,16,16,16,15,13,11,16,12,14,12,15,12,12,13,16,12,14,12,15,12,12,16,16,16,16,16,16,14,12,12,16,12,15,13,16,12,12,13,16,12,15,13,15,12,11,16,16,14,16,15,16,13,12,12,16,13,16,12,16,12,12,15,16,14,16,13,16,12,12,16,16,16,16,16,16,14,13,12,16,13,15,12,16,12,12,13,16,13,15,12,15,12,12,16,16,15,16,14,16,13,12,13,16,13,16,12,16,12,12,13,16,12,16,12,15,12,12,14,16,12,14,12,14,11,10,0,16,6,16,8,16,16,16,9,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,4,16,7,16,11,16,16,16,10,16,11,16,13,16,16,16,16,16,16,16,16,16,16,16,10,16,10,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,10,16,9,16,16,16,10,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,12,16,16,16,10,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,16,7,16,8,16,13,16,9,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,4,16,7,16,11,16,13,16,9,16,11,16,13,16,16,16,16,16,16,16,16,16,16,16,9,16,9,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,4,16,10,16,8,16,16,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,7,16,10,16,11,16,16,16,9,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,12,16,12,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,11,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,13,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,16,8,16,10,16,16,16,10,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,6,16,8,16,11,16,16,16,10,16,12,16,15,16,16,16,16,16,16,16,16,16,16,16,9,16,9,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,10,16,10,16,16,16,11,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,11,16,16,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,11,16,12,16,16,16,16,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,12,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,10,16,11,16,16,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,8,16,9,16,11,16,13,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,9,16,9,16,13,16,12,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,10,16,10,16,14,16,12,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,9,16,11,16,11,16,13,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,13,16,12,16,12,16,11,16,16,16,13,16,16,16,16,16,16,16,16,16,9,16,12,16,10,16,13,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,10,16,13,16,11,16,13,16,12,16,13,16,12,16,13,16,16,16,16,16,16,16,16,16,13,16,13,16,16,16,12,16,13,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,0,10,4,10,5,11,9,11,6,11,8,11,8,12,10,12,15,16,13,15,14,15,13,14,4,12,5,11,8,12,9,11,7,13,8,12,9,13,10,12,15,16,13,15,14,16,13,14,10,16,9,13,12,16,11,13,11,16,10,14,13,16,12,13,16,16,14,16,15,16,14,15,4,12,7,12,6,12,9,11,8,13,9,12,9,12,10,12,15,16,13,15,14,15,13,14,7,13,8,12,9,13,10,12,8,13,9,12,9,13,10,12,14,16,13,15,13,15,13,14,12,16,11,14,13,16,12,13,12,16,11,14,13,16,12,13,16,16,14,16,15,16,14,15,10,16,12,16,10,14,12,13,12,16,13,16,11,14,12,13,16,16,16,16,15,16,14,15,12,16,13,16,11,15,12,13,13,16,13,16,12,15,12,14,16,16,16,16,14,16,13,14,16,16,14,16,14,16,13,15,16,16,14,16,14,16,13,15,16,16,16,16,16,16,14,16,2,11,5,11,6,11,9,11,7,12,8,11,9,12,10,12,15,16,14,14,14,14,13,14,4,13,6,11,8,12,9,11,8,13,8,12,10,13,10,12,15,16,13,15,14,15,13,14,9,16,8,13,12,15,11,12,11,16,10,14,13,16,12,13,16,16,14,16,16,16,14,15,5,13,8,12,7,12,9,11,8,13,9,12,9,12,10,12,16,16,14,15,14,15,13,13,7,13,8,12,9,13,10,12,8,13,8,12,9,13,10,12,14,16,13,14,13,15,12,13,11,16,10,14,13,16,12,13,11,16,10,13,12,15,11,13,14,16,12,14,14,16,13,14,10,16,12,15,9,14,11,13,12,16,12,16,11,14,12,13,16,16,15,16,16,16,14,15,11,16,12,15,11,15,12,13,12,16,12,15,11,14,12,13,16,16,14,16,13,15,13,14,15,16,14,16,14,16,13,14,14,16,13,16,14,16,13,14,16,16,14,16,14,16,13,14,7,15,8,13,9,14,11,13,10,14,10,13,11,14,12,13,16,16,15,16,15,16,15,14,7,16,8,13,10,14,11,13,11,15,10,13,12,14,12,13,16,16,16,16,16,16,15,15,10,16,9,13,13,16,12,13,13,16,11,14,14,16,13,14,16,16,16,16,16,16,15,16,8,16,10,14,9,14,11,13,11,16,11,14,11,14,12,13,16,16,16,16,16,16,14,15,8,16,10,14,10,14,11,13,10,15,10,14,11,14,12,13,16,16,14,16,15,16,14,14,11,16,10,14,13,16,12,13,11,16,10,13,13,16,12,13,16,16,13,16,16,16,14,14,11,16,12,16,10,15,12,13,14,16,14,16,12,16,13,14,16,16,16,16,16,16,16,16,12,16,13,16,11,16,12,14,12,16,13,16,11,14,12,13,16,16,16,16,14,16,14,14,15,16,14,16,16,16,13,14,13,16,13,15,14,16,13,14,14,16,13,14,14,15,13,14,9,16,11,16,12,16,13,14,12,16,12,15,13,16,13,14,16,16,16,15,16,16,15,15,10,16,10,16,12,16,12,14,12,16,12,14,13,16,13,14,16,16,16,16,16,16,15,15,11,16,10,14,14,16,12,13,14,16,12,16,14,16,13,14,16,16,16,16,16,16,16,15,10,16,12,16,11,16,12,14,13,16,12,15,13,16,13,14,16,16,16,16,16,16,16,15,10,16,11,16,12,16,12,14,12,16,12,15,13,16,13,14,16,16,16,16,16,16,14,14,11,16,10,14,14,16,12,13,13,16,11,14,14,16,12,13,16,16,15,16,16,16,14,14,12,16,13,16,11,16,12,14,15,16,14,16,13,16,13,14,16,16,16,16,16,16,14,16,12,16,13,16,12,16,12,14,13,16,13,16,12,16,12,13,16,16,16,16,16,16,14,15,13,16,13,16,14,16,12,13,13,16,13,14,14,16,12,13,16,16,14,14,14,15,13,13,0,9,3,9,5,9,7,9,5,10,7,11,8,11,9,10,16,16,16,16,16,16,16,16,2,11,4,10,7,11,8,10,7,16,7,11,9,16,9,11,16,16,16,16,16,16,16,16,8,16,7,16,11,16,10,11,11,16,10,16,16,16,11,16,16,16,16,16,16,16,16,16,2,11,6,10,6,10,8,10,7,16,8,16,8,11,9,11,16,16,16,16,16,16,16,16,5,13,7,11,8,11,9,11,6,12,8,12,8,12,9,11,16,16,16,16,16,16,16,16,10,16,10,16,12,16,10,13,10,16,9,16,11,16,11,12,16,16,16,16,16,16,16,16,8,16,10,16,8,16,10,12,11,16,12,16,10,16,11,16,16,16,16,16,16,16,16,16,10,16,11,16,10,16,11,16,11,16,12,16,10,16,11,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,5,10,6,10,9,10,7,12,9,12,9,12,10,10,16,16,15,16,14,16,13,13,5,12,7,11,8,11,9,10,8,13,9,12,10,12,10,11,16,16,16,16,14,16,13,12,10,16,10,13,12,14,12,12,12,16,11,14,13,15,12,12,16,16,16,15,16,16,14,13,5,12,8,11,7,11,9,10,8,13,10,12,9,12,10,10,15,16,14,15,14,14,13,13,7,13,9,12,9,12,10,10,9,13,10,13,10,13,10,10,14,16,14,15,14,16,13,12,11,16,12,14,12,15,12,12,12,16,12,15,13,16,12,12,16,16,15,16,16,16,14,13,10,16,12,14,10,14,12,12,12,16,13,14,11,14,12,12,16,16,16,16,14,16,14,13,11,16,12,14,11,14,12,12,12,16,13,16,11,15,12,12,16,16,16,16,14,16,14,13,13,16,14,16,14,16,13,13,13,16,13,16,13,16,13,12,16,16,16,16,16,16,13,13,4,11,7,10,7,11,9,10,8,12,9,12,9,12,10,11,15,16,14,15,14,16,13,13,6,12,7,11,8,11,9,10,9,13,9,12,10,12,10,10,16,16,15,16,15,16,13,12,10,16,10,13,12,14,12,11,12,16,11,14,13,14,12,12,16,16,16,14,16,16,14,13,6,12,8,11,7,11,9,10,9,14,10,12,9,12,10,10,15,16,14,16,14,16,14,13,7,13,9,12,9,12,10,10,9,13,9,12,9,12,10,10,14,16,13,14,14,16,12,11,11,16,11,14,12,14,12,12,12,16,11,14,12,14,12,11,16,16,13,16,14,16,13,12,10,16,12,14,10,14,11,11,12,16,13,14,11,14,12,12,16,16,16,16,14,16,13,13,11,16,12,16,11,14,12,12,12,16,12,14,11,14,12,11,16,16,15,16,13,15,13,12,13,16,14,16,13,16,13,12,13,16,13,16,13,16,13,12,16,16,14,16,14,16,12,11,8,13,10,12,10,13,11,11,11,14,12,14,12,14,12,12,16,16,16,16,16,16,14,13,9,14,10,13,10,13,11,11,12,16,12,13,12,13,12,11,16,16,16,16,16,16,15,14,12,16,11,14,13,15,12,12,13,16,12,15,14,15,13,12,16,16,16,16,16,16,15,13,9,14,11,13,10,13,11,11,11,16,12,14,12,14,12,12,16,16,16,16,16,16,16,13,10,15,11,13,11,14,12,11,11,16,12,14,11,14,12,11,16,16,16,16,16,16,14,12,12,16,12,14,13,15,13,12,12,16,12,14,13,15,12,12,16,16,14,16,16,16,14,12,12,16,13,16,11,14,12,12,14,16,14,16,12,16,13,12,16,16,16,16,16,16,16,13,12,16,13,16,12,16,13,12,12,16,13,16,12,16,12,12,16,16,16,16,14,16,14,12,14,16,14,16,14,16,14,13,13,16,13,16,13,16,13,12,16,16,13,16,13,16,12,11,9,16,12,15,13,16,13,12,13,16,14,16,14,16,14,13,16,16,16,16,16,16,16,14,10,16,12,15,12,15,13,12,13,16,14,16,13,16,13,12,16,16,16,16,16,16,16,13,12,16,12,16,13,16,13,12,14,16,13,16,14,16,13,12,16,16,16,16,16,16,16,13,11,16,12,15,12,16,13,12,14,16,14,16,13,16,13,13,16,16,16,16,16,16,15,13,11,16,12,16,12,16,13,12,13,16,13,15,13,16,13,12,16,16,16,16,16,16,15,13,12,16,12,16,13,16,13,12,13,16,12,16,13,16,13,12,16,16,14,16,16,16,14,12,12,16,14,16,11,16,13,12,14,16,14,16,13,16,13,12,16,16,16,16,16,16,16,13,12,16,13,16,12,16,13,12,13,16,13,16,12,16,13,12,16,16,16,16,14,16,14,12,13,16,13,16,13,16,13,13,13,16,12,16,12,16,12,12,14,16,13,15,13,16,12,11,8,10,10,10,10,10,11,10,10,11,10,10,10,10,10,6,12,12,13,12,13,12,13,11,13,13,13,12,13,12,12,8,14,13,16,13,15,13,16,12,16,16,16,14,16,13,14,10,12,13,12,12,13,13,13,12,13,13,12,12,13,12,12,8,13,14,14,12,14,14,14,12,14,15,14,12,14,13,13,8,16,16,16,12,16,16,16,13,16,16,16,13,16,14,14,9,14,16,13,13,16,16,16,14,15,16,14,13,15,15,14,10,16,16,14,13,16,16,16,13,16,16,16,13,16,15,14,10,16,16,16,11,16,16,16,12,16,16,16,12,16,16,15,9,12,13,13,13,12,12,14,12,12,14,13,12,12,12,12,8,14,14,16,14,13,12,14,12,14,15,14,13,13,12,13,8,16,16,16,15,16,13,16,13,16,16,16,15,16,13,15,10,14,16,14,14,14,14,15,13,14,16,14,13,13,13,13,9,16,16,16,14,16,14,16,12,16,16,14,13,14,13,13,8,16,16,16,14,16,14,16,13,16,16,16,14,16,14,14,9,16,16,16,16,16,16,16,16,16,16,16,14,16,16,14,10,16,16,16,14,16,16,16,13,16,16,16,14,16,15,14,9,16,16,16,13,16,16,16,12,16,16,16,13,16,15,15,8,14,16,16,16,14,14,16,14,16,16,16,15,13,13,14,10,16,16,16,16,15,13,16,13,16,16,16,16,16,13,14,10,16,16,16,16,16,11,16,12,16,16,16,16,16,12,16,9,16,16,16,16,16,16,16,15,16,16,16,16,16,14,14,10,16,16,16,16,16,15,16,13,16,16,16,15,16,13,14,9,16,16,16,16,16,13,16,12,16,16,16,16,16,13,14,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,16,16,16,16,16,16,16,14,16,16,16,16,16,16,14,9,16,16,16,14,16,15,16,11,16,16,16,14,16,14,14,8,12,13,13,13,13,13,14,12,12,13,12,12,12,12,12,8,14,14,16,14,15,14,16,13,14,15,14,13,14,13,13,9,16,16,16,15,16,16,16,14,16,16,16,14,16,14,16,10,14,15,14,14,15,14,15,13,14,14,13,12,13,13,13,9,15,16,15,14,16,16,16,13,15,16,14,12,14,13,13,8,16,16,16,14,16,16,16,13,16,16,16,13,16,14,14,9,16,16,16,16,16,16,16,15,16,16,13,13,16,16,14,10,16,16,16,14,16,16,16,14,16,16,15,13,16,14,14,9,16,16,16,12,16,16,16,13,16,16,16,12,16,16,15,8,13,14,14,14,14,14,16,13,13,14,14,13,12,12,12,8,16,16,16,14,15,14,16,13,15,16,14,13,13,12,13,8,16,16,16,16,16,14,16,14,16,16,16,14,16,13,14,9,15,16,16,15,16,15,16,13,14,16,14,13,13,13,12,8,16,16,16,14,16,14,15,12,15,15,14,12,13,12,12,7,16,16,16,14,16,14,16,12,16,16,16,13,16,13,13,7,16,16,16,16,16,16,16,14,16,16,14,14,16,14,13,9,16,16,16,14,16,16,16,13,16,16,14,12,16,13,12,7,16,16,16,12,16,16,16,11,16,16,15,12,16,13,13,6,16,16,16,16,16,16,16,15,16,16,16,15,13,13,14,10,16,16,16,16,16,14,16,14,16,16,16,16,14,13,14,9,16,16,16,16,16,13,16,13,16,16,16,16,16,12,14,8,16,16,16,16,16,16,16,14,16,16,16,14,14,13,13,9,16,16,16,16,16,14,16,13,16,16,16,13,14,12,12,7,16,16,16,16,16,13,16,12,16,16,16,13,14,12,13,6,16,16,16,16,16,16,16,16,16,16,16,16,16,15,14,9,16,16,16,16,16,16,16,13,16,16,16,13,15,13,12,7,16,16,16,13,16,14,16,11,16,16,16,12,16,12,12,5,14,16,15,16,16,16,16,15,14,15,14,14,13,14,13,10,16,16,16,16,16,16,16,16,16,16,16,14,16,14,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,16,14,16,14,14,15,14,13,10,16,16,16,16,16,16,16,15,16,16,14,13,16,14,14,9,16,16,16,16,16,16,16,16,16,16,16,14,16,16,15,9,16,16,16,16,16,16,16,16,16,16,12,13,16,16,13,10,16,16,16,16,16,16,16,16,16,16,13,13,16,16,13,9,16,16,16,14,16,16,16,14,16,16,15,12,16,16,14,8,16,16,16,16,16,16,16,16,14,16,15,14,13,13,13,9,16,16,16,16,16,16,16,14,16,16,16,14,14,13,13,9,16,16,16,16,16,16,16,16,16,16,16,16,16,14,15,9,16,16,16,16,16,16,16,15,15,16,14,14,14,13,13,9,16,16,16,16,16,16,16,13,16,16,14,12,13,12,12,7,16,16,16,16,16,16,16,13,16,16,16,13,16,13,13,7,16,16,16,16,16,16,16,16,16,16,13,13,16,14,13,9,16,16,16,15,16,16,16,13,16,16,13,12,14,13,12,6,16,16,16,13,16,16,16,12,16,16,14,10,15,12,12,5,16,16,16,16,16,16,16,16,16,16,16,16,12,13,13,9,16,16,16,16,16,16,16,14,16,16,16,15,13,12,13,8,16,16,16,16,16,14,16,14,16,16,16,16,15,12,14,8,16,16,16,16,16,16,16,16,16,16,16,14,13,13,13,8,16,16,16,16,16,16,16,13,16,16,15,13,12,11,12,6,16,16,16,15,16,14,16,12,16,16,16,12,13,10,12,5,16,16,16,16,16,16,16,16,16,16,14,14,13,14,12,8,16,16,16,16,16,16,16,13,16,16,13,12,13,12,10,5,16,16,16,13,16,13,16,10,16,16,13,10,13,10,10,1,2,7,7,8,7,8,9,8,7,9,8,8,8,8,9,7,6,9,10,10,10,10,11,10,10,11,11,11,10,11,11,9,9,11,12,12,12,13,14,13,13,14,14,13,13,13,14,11,6,10,9,10,10,11,11,11,10,11,10,11,11,11,11,9,6,9,10,10,10,11,12,11,10,12,11,11,11,11,11,8,9,11,12,12,12,13,13,13,12,14,14,13,13,13,13,10,9,13,11,13,13,14,14,13,13,14,13,13,14,14,14,12,9,12,12,12,12,14,14,13,13,14,13,13,13,14,13,11,8,12,12,11,12,14,14,12,13,14,14,13,13,13,14,11,6,10,10,11,9,10,12,11,10,12,11,11,10,11,11,9,7,10,10,11,10,11,12,11,11,12,11,11,11,11,11,9,9,12,13,13,12,12,14,13,13,14,14,13,14,13,14,11,8,11,11,12,11,12,12,12,11,13,12,12,12,12,12,10,7,10,10,11,10,11,12,11,10,12,11,11,11,11,11,8,9,11,12,12,12,12,13,12,12,13,13,12,13,12,13,10,10,13,13,14,14,14,15,14,14,15,14,15,14,14,14,12,9,12,12,13,12,13,14,13,12,13,13,12,13,13,13,10,9,12,12,12,12,13,14,12,12,14,13,12,13,13,13,10,9,12,13,13,11,13,14,13,13,14,14,14,12,13,13,11,10,12,13,13,12,12,14,13,13,14,14,14,13,13,14,11,10,13,14,14,13,12,15,13,14,14,14,14,15,13,14,11,11,14,14,14,13,14,15,14,14,15,15,14,13,14,14,12,10,13,12,13,12,12,14,13,13,14,13,13,13,13,13,10,10,12,13,13,13,12,14,12,13,14,14,13,13,13,13,10,13,15,16,16,15,15,16,16,15,16,15,16,16,16,16,14,11,14,14,14,14,14,15,14,14,15,15,14,14,14,15,11,10,13,13,13,13,13,14,12,13,14,14,13,13,13,13,10,6,10,10,11,10,11,12,11,10,12,10,11,10,11,11,9,8,11,11,12,11,12,13,12,11,12,12,12,12,12,12,10,11,13,14,14,13,14,15,14,13,15,15,14,14,14,15,12,7,11,10,12,11,12,12,12,11,12,11,12,11,12,12,10,7,10,10,11,10,11,12,11,11,12,11,11,11,11,11,9,10,12,13,13,12,13,14,13,13,14,13,13,13,13,13,10,10,13,12,14,13,14,14,14,13,14,12,14,15,14,14,11,10,12,12,12,12,13,14,13,13,14,13,12,13,13,13,10,9,12,13,13,13,14,14,13,13,14,14,13,13,13,13,10,7,10,10,11,10,11,12,11,10,12,12,11,9,11,11,9,7,10,11,11,10,11,12,11,10,12,12,11,11,11,11,9,10,12,13,13,13,13,15,13,13,14,13,13,13,13,13,10,8,11,11,11,11,11,12,11,11,12,12,11,11,12,11,9,6,9,9,10,9,10,10,10,9,11,10,10,9,10,10,7,8,10,11,11,11,11,12,11,11,12,12,11,11,11,11,8,10,13,13,13,13,14,14,13,13,14,13,13,13,13,13,11,8,11,11,11,11,12,12,11,11,12,11,11,11,11,11,8,8,11,11,11,11,12,12,10,11,12,12,11,11,11,11,8,10,13,13,13,12,13,14,13,12,14,14,14,10,13,13,11,10,12,12,13,12,13,14,12,12,13,13,13,12,12,13,10,11,13,14,14,13,13,14,13,13,15,14,13,13,13,13,10,10,12,13,13,12,13,14,13,13,14,14,13,12,13,13,11,8,11,11,11,11,11,12,11,11,12,12,11,11,11,11,8,9,11,12,12,11,11,12,11,12,12,12,11,12,11,11,8,12,15,14,14,14,15,15,14,14,15,15,14,14,14,15,12,10,12,12,12,12,12,13,12,12,13,13,12,12,12,12,9,9,11,11,11,11,11,12,10,11,12,12,11,11,11,11,7,10,13,13,13,13,14,15,14,13,14,14,14,12,14,15,12,11,14,14,14,14,15,15,14,14,15,15,15,14,15,15,12,13,16,16,16,15,16,16,16,15,16,16,16,16,16,16,14,10,13,13,14,13,15,14,14,13,15,13,14,14,14,14,12,10,13,13,13,13,13,14,13,13,14,13,13,13,13,14,11,12,14,14,14,14,15,15,14,14,15,15,14,15,14,14,12,11,14,14,15,14,15,15,14,14,15,12,14,15,16,15,12,11,13,13,14,13,14,14,14,14,14,13,13,14,14,14,11,11,14,14,14,14,15,15,14,14,16,14,13,14,14,14,11,10,13,13,13,12,14,14,14,12,15,14,14,11,13,13,12,10,12,13,14,12,13,14,13,13,14,14,13,12,13,13,11,12,14,14,15,14,15,16,15,15,15,15,15,14,14,15,12,10,13,13,13,12,13,14,13,13,14,13,13,12,13,13,11,9,11,11,12,11,12,12,11,11,12,12,11,11,11,11,9,10,12,12,12,12,12,13,12,12,13,13,12,13,12,12,9,11,13,13,15,14,14,15,14,14,15,14,14,14,14,14,11,10,12,12,12,12,12,13,12,12,13,11,11,12,12,12,8,9,12,12,11,12,12,13,11,12,12,12,11,12,11,11,8,10,13,13,14,12,14,15,14,13,15,15,14,10,13,13,11,11,13,14,13,13,14,14,13,13,14,14,14,11,13,13,11,12,14,14,14,14,14,15,14,15,16,15,14,13,13,14,11,11,14,13,14,13,14,15,14,13,15,14,14,11,13,13,11,9,12,12,12,11,12,13,11,12,13,12,11,10,11,11,8,10,12,12,12,12,12,13,11,12,12,12,11,11,11,11,8,12,15,14,15,14,15,16,15,15,15,15,14,14,14,14,12,10,12,12,12,12,12,13,11,12,13,12,11,11,11,11,8,8,10,10,10,10,10,11,9,10,11,10,9,10,9,9,5,12,12,11,9,11,10,11,9,11,11,10,9,9,8,9,5,14,13,14,11,14,11,13,10,14,13,12,10,12,10,11,6,16,13,16,12,16,12,16,11,16,14,16,12,15,12,13,8,14,14,12,11,14,12,13,10,13,13,11,10,12,11,10,6,16,15,14,11,16,13,14,10,15,14,13,10,13,11,11,7,16,16,16,11,16,14,16,11,16,16,15,12,15,13,13,8,16,16,13,12,16,16,15,12,16,16,12,11,15,13,12,8,16,16,14,11,16,16,16,11,16,16,14,11,15,14,13,8,16,16,15,10,16,16,16,10,16,16,15,11,16,14,14,8,14,14,14,12,13,11,13,10,13,13,12,11,11,10,10,6,16,15,16,13,13,11,14,11,15,14,13,11,12,10,11,7,16,15,16,14,16,11,16,11,16,16,16,13,16,12,13,8,16,16,14,13,15,13,14,11,14,15,13,11,13,11,11,7,16,16,15,13,15,13,14,11,16,15,14,11,13,11,11,7,16,16,16,13,16,13,16,11,16,16,16,12,16,12,13,8,16,16,16,14,16,16,16,13,16,16,14,13,15,14,13,9,16,16,16,13,16,16,16,12,16,16,14,12,15,13,13,8,16,16,16,12,16,16,16,11,16,16,15,12,16,13,13,7,16,16,16,16,13,12,16,12,16,16,14,13,12,11,12,8,16,16,16,15,14,11,16,11,16,16,16,13,14,11,13,8,16,16,16,16,15,10,16,11,16,16,16,14,15,11,13,8,16,16,16,16,16,14,16,13,16,16,14,14,14,12,13,9,16,16,16,15,16,13,16,12,16,16,16,13,14,12,13,8,16,16,16,14,16,12,16,11,16,16,16,13,15,12,13,7,16,16,16,16,16,16,16,14,16,16,16,15,16,14,13,9,16,16,16,16,16,16,16,12,16,16,16,14,16,13,13,8,16,16,16,14,16,14,16,10,16,16,16,13,16,13,13,7,14,14,13,12,13,12,13,11,12,13,11,10,11,10,10,6,16,16,15,13,16,13,15,11,14,14,13,11,13,11,11,7,16,16,16,14,16,14,16,12,16,16,16,13,16,13,14,9,16,16,13,13,15,14,14,11,13,14,11,11,12,11,11,7,16,16,15,12,16,14,15,11,14,14,12,11,13,11,11,7,16,16,16,13,16,14,16,12,16,16,14,12,16,13,13,8,16,16,14,14,16,16,16,13,16,16,12,11,15,13,12,8,16,16,15,13,16,16,16,12,16,16,13,11,16,13,12,8,16,16,16,11,16,16,16,11,16,16,14,11,16,14,13,7,16,16,15,13,14,13,14,11,14,14,12,11,11,10,11,7,16,16,16,13,14,12,15,11,15,14,13,11,12,11,11,7,16,16,16,14,16,13,16,12,16,16,16,13,14,12,13,8,16,16,15,13,15,14,14,12,14,14,12,11,12,11,11,7,16,16,14,12,15,13,14,11,15,14,13,11,12,11,11,6,16,16,16,13,16,13,16,11,16,15,14,11,14,11,12,6,16,16,16,14,16,16,16,13,16,16,13,12,14,13,12,8,16,16,15,13,16,14,15,11,16,16,13,11,14,12,11,6,16,16,16,12,16,14,15,11,16,16,13,10,14,12,12,6,16,16,16,16,16,14,16,13,16,16,14,13,12,11,12,8,16,16,16,16,16,13,16,12,16,16,15,13,13,11,12,8,16,16,16,15,16,12,16,12,16,16,16,14,14,11,13,7,16,16,16,16,16,15,16,13,16,16,14,13,13,12,12,8,16,16,16,14,15,13,15,11,16,15,14,12,13,11,11,6,16,16,16,14,16,12,15,11,16,16,15,12,14,11,12,6,16,16,16,16,16,16,16,13,16,16,15,13,14,13,12,8,16,16,16,14,16,14,16,12,16,16,14,12,13,12,11,6,16,16,16,13,16,13,15,10,16,16,14,11,14,11,11,5,16,16,15,14,16,16,16,13,14,14,12,12,12,12,12,8,16,16,16,15,16,16,16,14,16,16,14,13,14,13,13,9,16,16,16,16,16,16,16,14,16,16,16,14,16,13,15,9,16,16,14,15,16,16,16,14,14,16,12,12,13,13,12,8,16,16,16,14,16,16,16,13,16,15,13,12,14,12,12,8,16,16,16,16,16,16,16,13,16,16,14,12,16,13,13,8,16,16,16,15,16,16,16,14,16,16,11,11,15,14,12,8,16,16,16,14,16,16,16,13,16,16,12,11,15,13,12,8,16,16,16,13,16,16,16,12,16,16,13,10,16,13,12,7,16,16,16,16,16,15,16,13,14,16,13,13,12,12,12,8,16,16,16,15,16,14,16,13,16,16,14,13,13,12,12,8,16,16,16,16,16,15,16,13,16,16,16,13,15,12,14,8,16,16,16,15,16,16,16,13,14,16,13,12,12,12,11,8,16,16,16,14,16,14,16,12,14,14,13,11,13,11,11,6,16,16,16,14,16,14,16,12,16,15,14,11,14,11,12,6,16,16,16,15,16,16,16,14,16,16,12,12,14,13,11,8,16,16,15,14,16,16,16,12,16,15,12,11,13,12,11,6,16,16,16,13,16,14,16,11,16,14,13,10,14,11,11,5,16,16,16,16,16,16,16,14,14,16,15,13,11,11,11,8,16,16,16,16,16,15,16,13,16,16,16,13,12,11,12,7,16,16,16,16,16,13,16,12,16,16,16,13,13,11,13,7,16,16,16,16,16,16,16,13,16,16,14,13,12,12,11,7,16,16,16,15,16,14,15,12,16,14,13,12,12,11,11,6,16,16,16,14,16,13,15,11,16,14,14,11,13,10,11,5,16,16,16,16,16,16,16,13,16,16,13,12,12,12,11,7,16,16,16,14,16,14,15,12,16,15,12,11,12,11,10,5,16,16,16,13,16,13,14,10,16,14,12,9,12,10,9,3,2,6,6,7,6,7,8,7,7,8,7,8,7,8,8,5,5,8,9,9,9,9,12,10,10,11,10,10,10,11,11,8,9,10,13,12,13,12,15,13,13,14,13,14,13,13,14,11,5,10,9,10,10,10,12,10,10,12,10,11,11,11,11,8,6,9,10,9,10,11,12,10,10,12,11,11,10,11,11,8,9,11,12,11,12,13,14,12,13,14,14,12,13,13,13,11,10,13,11,12,14,14,15,13,13,15,12,13,14,14,14,12,9,12,12,12,13,13,15,13,13,14,13,13,14,13,15,11,8,11,12,10,12,13,14,12,13,14,14,13,13,13,14,11,5,9,10,10,9,10,12,11,10,12,11,11,9,11,11,9,6,10,10,11,10,10,12,11,11,12,11,11,11,11,11,9,9,11,13,13,12,11,14,12,13,15,13,13,14,13,14,11,8,11,11,12,11,12,13,12,12,13,12,13,12,12,12,10,7,10,10,11,10,11,12,11,11,12,11,11,11,11,12,9,9,12,12,12,12,12,14,12,13,14,13,13,13,13,13,11,11,14,13,15,15,16,16,15,15,16,15,15,16,16,15,13,10,12,13,13,13,14,15,13,13,14,13,13,14,14,14,11,9,12,12,12,13,13,14,12,13,14,14,13,13,13,14,11,9,13,13,13,11,12,15,13,13,15,14,14,11,13,14,11,10,13,13,13,12,12,15,13,13,15,14,14,13,13,14,11,10,12,13,13,12,11,14,12,13,15,13,13,13,13,14,11,11,14,15,15,13,14,16,14,14,16,16,14,14,15,15,13,10,13,13,13,12,13,14,13,13,14,14,14,13,13,14,11,10,12,13,13,13,12,14,13,13,14,14,13,13,13,13,11,13,15,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,15,15,15,14,15,16,14,15,16,16,15,16,15,15,13,10,12,12,12,13,13,14,12,13,14,13,13,13,13,13,11,6,10,10,11,10,11,12,11,10,12,11,11,10,11,11,9,8,11,12,12,12,12,13,12,12,13,12,13,12,13,13,10,11,13,15,14,15,14,16,14,15,16,16,14,15,15,15,13,7,11,10,12,11,11,13,11,11,13,10,11,12,12,12,10,7,11,11,11,11,11,13,11,11,13,11,12,12,12,12,9,10,12,13,13,13,13,15,13,14,15,14,14,14,14,15,11,10,13,12,14,14,14,15,13,13,15,12,13,15,15,14,12,10,13,12,12,13,13,15,14,13,15,13,13,14,14,14,11,10,13,13,12,13,14,15,13,13,15,13,13,14,14,14,11,7,10,11,11,10,11,12,11,10,12,12,12,9,11,12,9,7,11,11,11,11,11,13,11,11,13,12,12,11,12,12,9,10,12,14,13,13,13,16,13,14,16,14,14,13,13,14,11,8,11,11,12,11,12,13,12,12,13,12,12,12,12,12,10,6,9,9,10,9,10,11,10,10,11,10,10,10,10,10,8,8,11,11,11,12,11,13,11,12,13,12,12,12,12,12,10,11,14,13,14,14,14,16,14,14,16,14,14,15,15,14,12,9,12,11,12,12,12,13,12,12,13,12,12,12,12,12,10,8,11,11,11,11,11,13,11,12,12,12,12,12,12,12,9,10,13,14,13,11,13,14,14,13,15,15,14,10,13,14,11,10,13,13,13,12,13,14,13,13,14,14,14,13,13,13,11,10,13,14,13,13,12,15,13,14,15,14,14,14,13,14,12,11,14,14,14,13,13,15,14,14,15,14,15,13,14,14,12,9,11,12,12,11,11,13,12,12,13,12,12,12,12,12,10,9,11,12,12,12,11,13,11,12,13,12,12,12,12,12,10,13,15,15,16,15,16,16,15,16,16,16,15,15,15,16,14,10,13,13,13,13,13,14,13,13,14,13,13,13,13,13,11,8,11,11,11,11,11,12,11,11,12,12,11,12,11,12,9,11,14,14,15,14,15,15,14,13,15,14,15,12,14,15,13,12,15,15,15,15,15,16,15,15,16,16,16,15,16,15,13,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,14,13,15,14,14,16,14,14,16,13,14,15,14,15,12,11,14,13,14,14,14,16,15,14,16,14,14,15,15,15,12,13,15,15,15,15,16,16,15,16,16,16,15,16,16,16,13,11,14,13,14,14,14,15,14,14,16,12,14,16,16,14,12,11,14,14,14,14,15,16,15,14,16,13,14,16,15,14,12,12,14,14,14,14,14,16,14,15,16,14,14,14,15,15,12,11,14,14,14,13,14,16,15,13,16,15,15,11,14,14,12,11,14,14,15,14,14,16,14,14,15,14,14,13,15,15,12,13,15,16,15,15,15,16,15,16,16,16,16,15,15,16,13,11,14,14,14,14,14,15,14,14,16,14,14,14,15,14,12,9,12,12,12,12,12,13,12,12,13,12,13,12,12,12,10,11,13,13,13,13,13,14,13,13,14,13,14,13,13,14,11,12,15,14,15,15,15,16,15,14,16,14,14,16,16,14,13,10,12,12,12,12,12,14,12,13,13,12,12,13,13,13,10,10,12,12,12,12,12,14,12,12,13,12,12,12,12,12,10,10,14,14,14,12,14,16,14,13,16,16,16,10,13,14,12,11,14,14,14,13,14,16,14,14,16,15,14,12,13,14,12,12,14,14,14,14,14,16,14,14,16,15,15,14,14,15,12,12,14,15,15,14,15,16,14,15,15,15,15,13,15,14,12,9,12,12,12,12,13,13,12,12,13,13,12,11,12,12,10,10,12,12,12,12,12,13,12,12,13,12,12,12,12,12,10,13,15,15,15,15,16,16,16,16,16,16,16,15,16,15,13,10,12,12,13,12,13,13,12,13,14,13,13,12,13,13,10,7,10,10,10,10,10,11,10,10,11,10,10,10,10,10,7,10,10,9,8,9,8,9,7,9,9,8,7,8,7,7,4,13,11,12,9,12,9,12,9,12,11,11,9,10,9,9,6,15,12,15,11,14,10,14,10,14,13,13,11,13,11,12,7,13,12,11,9,12,11,12,9,12,12,10,9,10,10,9,6,14,13,12,10,13,12,13,9,13,12,11,10,12,11,10,6,16,14,14,10,15,13,14,10,15,15,14,11,14,12,12,8,15,14,12,11,15,14,13,11,14,14,11,10,13,12,11,8,15,16,13,11,16,14,14,11,15,15,12,10,14,13,12,8,16,15,14,10,16,14,14,10,16,15,14,10,14,13,12,7,13,12,12,11,11,9,12,9,12,12,11,10,10,9,9,6,13,13,14,12,12,10,12,10,14,13,12,11,11,10,10,7,16,14,16,13,14,11,15,10,16,15,14,12,14,11,12,8,14,14,13,12,13,12,13,10,13,13,12,11,11,10,10,7,15,14,14,12,14,12,13,10,14,13,12,11,12,11,11,7,16,15,16,13,15,13,15,10,16,15,14,12,14,12,12,7,15,16,14,13,16,14,14,12,15,15,12,12,13,12,12,8,16,16,14,13,16,14,14,11,15,15,14,11,14,12,12,8,16,16,15,12,16,14,15,10,16,16,13,12,14,13,12,7,14,14,14,13,13,11,13,11,14,14,13,12,11,10,11,8,16,15,16,13,13,11,14,11,15,14,14,13,12,11,12,8,15,15,16,14,14,10,14,10,16,15,15,13,14,10,12,8,16,16,16,14,15,13,14,12,15,15,13,13,13,12,12,8,16,16,16,14,15,13,14,11,16,16,14,13,13,12,12,8,16,16,16,14,16,12,15,11,16,15,15,13,14,12,12,8,16,16,16,16,16,15,15,13,16,16,14,13,14,13,12,9,16,16,16,14,16,15,15,11,16,16,14,13,15,13,12,8,16,16,16,14,16,14,14,10,16,16,15,13,14,12,12,7,12,12,12,11,12,11,12,10,11,11,10,9,9,9,9,6,14,13,14,12,13,12,13,10,13,13,12,10,12,10,11,7,16,14,16,13,15,13,16,12,15,14,14,12,14,12,13,8,14,14,13,11,14,12,13,11,12,12,10,10,11,10,10,7,14,14,13,12,14,12,13,11,13,13,12,10,12,11,10,7,16,15,15,12,16,14,15,11,16,14,13,11,14,12,12,8,16,16,13,13,16,15,14,12,14,14,11,11,13,12,11,8,16,16,14,12,16,14,14,12,15,14,12,11,14,12,12,8,16,15,14,11,16,15,15,11,16,15,13,11,14,13,12,8,14,13,13,12,13,11,13,10,12,13,11,10,10,10,10,7,15,14,14,13,13,12,13,11,14,13,12,11,12,10,11,7,16,15,16,14,15,12,15,11,16,14,14,12,14,11,12,8,14,15,13,12,14,13,13,11,13,13,11,11,11,10,10,7,14,14,14,12,14,13,13,10,14,13,12,10,12,10,10,6,16,15,15,13,16,13,15,11,15,14,13,11,13,11,11,7,16,16,14,13,16,15,14,12,15,15,12,11,13,12,11,8,16,16,14,13,16,14,14,11,15,14,12,11,13,12,11,7,16,16,15,12,16,14,14,11,15,15,13,11,14,12,11,6,16,15,15,14,14,12,14,12,13,14,13,12,11,11,11,8,16,16,16,14,14,12,15,12,15,14,14,12,12,11,12,8,16,16,16,15,14,12,15,12,16,15,14,13,13,11,12,8,16,16,16,15,15,14,15,12,14,14,13,12,12,11,11,8,16,16,15,14,14,12,14,11,14,14,13,12,12,11,11,7,16,16,16,14,15,12,14,11,15,15,14,12,13,11,12,7,16,16,16,16,16,15,16,13,15,15,14,12,13,12,11,8,16,16,16,14,15,14,14,12,16,15,13,12,13,12,11,7,16,16,16,13,16,13,14,10,16,15,14,11,13,11,11,6,14,15,13,13,14,13,14,12,12,13,11,11,11,11,10,8,16,16,15,13,16,14,16,13,14,14,13,12,13,12,12,8,16,16,16,14,16,14,16,13,16,14,15,13,15,13,13,9], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+631936);
/* memory initializer */ allocate([15,15,14,14,15,14,14,12,13,14,11,11,12,12,11,8,15,16,15,13,15,14,14,12,14,14,12,11,13,12,12,8,16,16,16,13,16,15,15,13,16,15,14,11,15,12,13,8,16,16,14,13,16,15,15,13,14,14,10,11,14,12,11,8,16,16,15,13,16,16,15,13,15,14,12,11,14,13,12,8,16,16,15,13,16,15,16,12,16,14,13,10,15,13,12,7,15,15,15,14,14,14,15,12,13,14,12,12,11,11,11,8,16,15,16,14,15,13,15,12,14,14,13,12,12,11,12,8,16,16,16,15,16,14,16,13,16,15,14,12,14,11,13,8,16,16,15,14,16,14,15,13,14,14,12,11,12,11,11,8,15,16,15,14,15,14,14,12,14,13,12,11,12,11,11,7,16,16,16,14,16,13,16,12,15,14,13,11,13,11,12,7,16,16,15,14,16,15,15,13,14,15,11,11,13,12,11,8,16,16,15,13,16,14,15,12,15,14,12,11,13,11,11,7,16,16,15,13,16,14,16,12,15,14,13,10,13,11,11,6,16,16,16,14,14,14,15,13,14,14,14,12,11,11,11,8,16,16,16,14,15,14,16,13,15,14,14,13,12,11,11,7,16,16,16,16,15,13,16,12,15,15,14,12,13,10,12,7,16,16,16,14,15,15,14,13,14,14,13,12,12,11,11,8,16,15,16,14,16,13,15,12,14,14,13,12,12,10,10,6,16,15,16,14,16,13,16,11,16,14,13,11,13,10,11,6,16,16,16,15,16,16,15,13,14,16,12,12,12,12,10,7,16,16,16,14,16,14,14,12,15,15,12,11,12,11,10,6,16,16,16,13,16,13,15,10,15,14,13,10,13,10,10,4,1,6,6,7,6,7,9,8,7,9,7,8,7,8,8,6,6,9,10,10,10,10,12,11,10,12,11,11,11,11,12,9,9,10,13,11,13,12,14,13,14,14,14,14,14,14,14,12,6,10,9,10,10,11,13,11,11,13,10,12,11,12,12,9,6,10,10,10,10,11,13,11,11,13,12,12,11,12,12,9,9,11,13,12,13,14,15,13,14,16,14,14,14,14,15,12,10,13,11,13,14,14,16,14,14,15,13,14,15,15,16,12,9,13,12,12,14,14,16,14,14,15,14,14,15,15,15,12,8,11,12,11,13,14,15,13,13,15,14,14,13,15,15,11,6,10,10,11,9,10,13,11,10,13,11,12,10,12,12,9,6,10,10,11,11,10,13,11,11,13,11,12,12,12,13,10,9,12,13,13,13,12,16,13,14,15,14,14,15,14,15,12,8,12,12,13,12,13,15,14,13,15,13,14,13,13,14,11,7,11,11,12,11,12,13,12,12,13,12,13,12,13,13,10,9,12,13,13,13,13,16,13,13,15,14,14,14,15,15,12,11,15,14,15,15,16,16,16,15,16,15,16,16,16,16,14,10,13,13,14,14,14,16,15,14,16,15,15,15,15,16,13,9,12,13,13,13,14,16,14,13,15,14,14,14,16,15,12,10,13,14,14,11,13,16,14,14,16,15,15,12,14,15,12,10,13,14,14,12,12,16,15,14,16,15,15,14,14,16,12,9,12,13,14,13,11,16,13,14,15,13,14,14,14,15,12,11,15,16,16,14,16,16,16,16,16,16,16,16,16,16,14,10,13,14,14,13,14,16,15,14,16,16,16,14,15,16,13,10,13,13,14,13,13,16,13,13,14,14,15,15,14,15,13,13,15,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,16,16,16,15,16,16,16,16,16,16,16,16,16,16,14,10,12,13,14,13,13,14,13,13,14,13,14,14,14,15,12,6,10,11,11,10,11,13,12,11,13,11,12,11,12,12,10,8,12,13,13,12,13,14,14,13,15,14,14,14,14,15,12,12,14,16,15,15,15,16,15,16,16,16,16,16,16,16,14,7,11,11,12,12,12,14,13,12,14,11,12,13,13,13,11,8,11,12,12,12,12,14,13,12,14,12,13,13,14,14,11,11,13,14,14,14,14,16,15,15,16,15,15,16,16,16,13,10,14,12,14,14,15,16,15,13,16,12,14,16,16,15,13,10,13,13,14,14,15,16,15,14,16,14,15,15,16,16,12,10,13,14,13,14,14,16,15,14,16,15,15,14,16,16,13,7,11,11,11,10,12,14,13,11,14,13,13,10,12,13,10,8,11,12,12,11,12,14,13,12,15,13,13,12,13,14,11,11,13,14,14,14,14,16,15,14,16,15,16,16,16,16,14,8,12,12,13,12,13,15,14,12,15,13,13,13,14,14,11,6,10,10,11,10,11,13,12,11,13,11,12,11,12,12,9,9,12,13,13,13,13,14,13,13,15,14,14,14,14,14,12,11,15,14,15,14,15,16,16,16,16,15,16,16,16,16,14,9,13,12,13,13,13,15,14,13,14,13,14,14,15,14,12,9,12,12,12,12,13,14,13,13,14,13,13,13,13,14,11,10,13,15,14,12,14,16,14,14,16,15,15,12,14,16,12,10,14,14,14,13,14,16,15,14,16,16,16,13,14,16,13,11,13,14,14,14,13,16,14,14,16,15,15,15,15,16,13,11,15,15,15,14,15,16,16,15,16,16,16,14,16,16,13,9,13,13,13,12,13,15,14,13,15,14,14,13,14,15,11,9,12,12,13,12,12,14,13,13,14,13,14,14,14,14,11,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,14,14,15,15,14,16,16,14,16,14,15,15,16,16,12,9,12,12,13,12,12,14,12,12,14,13,13,13,13,14,11,11,14,14,16,14,16,16,16,13,16,14,16,14,16,16,13,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,15,14,16,14,15,16,16,15,16,14,15,16,16,16,13,11,15,14,16,15,16,16,16,15,16,15,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,11,14,13,14,15,14,16,15,14,16,12,14,16,16,15,13,11,14,14,16,14,15,16,16,15,16,14,15,16,16,16,14,12,14,14,15,14,16,16,15,14,16,15,15,15,16,16,13,11,14,15,15,13,15,16,16,14,16,16,16,12,15,15,13,11,15,16,16,15,16,16,16,15,16,16,16,14,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,15,14,16,15,16,16,16,16,16,16,16,16,16,16,13,10,13,13,14,14,14,16,15,14,16,14,15,14,14,15,12,12,15,14,16,14,15,16,15,15,16,15,15,16,15,16,13,12,16,14,16,15,16,16,16,16,16,14,15,16,16,16,14,10,13,13,14,14,13,16,14,13,16,13,14,15,15,15,12,10,13,13,14,13,13,16,14,14,15,14,14,14,14,15,12,10,14,15,14,13,15,16,15,14,16,16,16,11,14,16,12,11,14,14,16,14,15,16,15,15,16,16,16,13,15,16,13,12,15,15,15,15,15,16,16,16,16,16,16,16,15,16,13,12,16,16,16,15,16,16,16,16,16,16,16,14,16,16,13,10,13,14,14,13,14,16,14,13,16,15,14,12,14,16,11,10,13,13,14,13,14,16,14,14,15,14,14,13,14,14,11,13,16,15,16,16,16,16,16,16,16,16,16,16,16,16,14,11,13,14,15,14,14,16,15,14,16,14,15,14,15,16,12,8,11,11,11,11,12,13,12,11,13,11,12,11,12,12,9,8,8,8,7,8,7,8,6,8,8,7,6,7,6,6,4,11,10,11,9,11,9,11,8,11,10,10,9,10,8,9,6,13,11,13,10,12,10,13,9,13,12,13,10,12,10,11,7,11,11,10,9,11,10,11,9,10,11,9,8,10,9,9,6,12,12,11,9,12,11,12,9,12,12,11,9,11,10,10,7,14,13,13,10,15,12,13,10,15,13,13,10,13,12,12,8,13,13,11,10,14,13,12,10,13,13,10,10,12,11,10,8,15,14,13,10,14,13,13,10,14,13,12,10,13,12,11,8,14,14,13,10,16,13,13,10,15,14,13,10,13,12,12,8,11,11,11,10,10,9,10,9,10,10,10,9,9,8,9,6,12,12,12,11,11,9,12,9,12,12,11,10,11,9,10,7,14,13,14,12,13,10,13,10,15,13,14,12,12,10,12,8,13,13,12,11,12,11,12,10,12,12,11,10,11,10,10,7,14,13,13,11,13,12,12,10,13,13,12,11,12,10,10,7,16,15,15,12,14,12,13,10,15,14,13,12,13,12,12,8,15,15,13,13,14,14,14,12,14,14,12,11,13,12,11,8,15,16,14,12,15,14,13,11,15,15,13,12,13,12,11,8,16,15,15,12,16,14,14,10,15,15,14,12,14,12,12,8,13,13,13,13,11,10,12,10,12,13,12,11,10,10,10,8,14,13,14,13,12,10,13,10,14,14,13,12,12,10,11,8,15,14,16,14,13,10,14,10,16,14,14,13,13,10,12,8,15,15,14,14,14,13,13,12,14,14,13,12,12,11,11,9,15,15,15,14,14,12,14,11,15,14,13,13,13,11,11,8,16,15,16,14,15,12,14,11,16,16,15,13,14,12,12,8,16,16,16,14,15,14,14,12,15,15,14,13,13,12,11,9,16,16,15,15,16,14,14,11,16,16,14,13,14,12,12,8,16,16,16,13,15,13,14,10,16,16,15,13,14,12,12,8,11,11,11,10,11,10,11,9,10,10,9,8,9,9,9,6,12,12,13,11,12,11,12,10,12,12,11,10,11,10,10,7,15,13,15,12,14,13,14,11,14,13,13,11,13,11,12,8,12,13,12,11,13,11,12,10,11,12,10,9,11,10,10,7,14,13,13,11,14,12,13,11,12,12,11,10,12,11,10,7,15,14,15,12,15,13,15,11,15,14,13,11,13,12,12,8,14,14,13,12,15,14,13,12,13,13,11,10,13,12,11,8,16,15,13,12,15,14,14,12,14,14,12,11,14,12,11,8,16,15,14,12,16,15,15,11,15,14,13,11,14,13,12,8,12,12,12,11,12,11,12,10,11,11,11,10,10,9,9,7,13,13,14,12,13,11,13,11,13,12,12,11,11,10,10,7,15,14,16,13,14,12,14,11,14,14,14,12,13,11,12,8,13,13,13,12,13,12,13,11,12,12,11,10,11,10,10,7,14,14,13,12,13,12,13,10,13,13,11,10,12,10,10,7,16,15,15,13,15,12,14,11,15,14,13,11,13,11,11,7,15,16,14,13,15,14,14,12,14,14,12,11,13,12,11,8,16,15,14,13,15,14,14,11,14,14,12,11,13,12,11,7,16,15,15,12,16,14,14,11,15,14,13,11,14,12,11,7,14,15,14,14,13,12,13,12,13,13,12,12,11,10,11,8,15,15,15,14,13,12,14,12,14,14,13,12,12,11,11,8,16,15,16,14,14,12,15,12,16,14,14,13,13,11,12,8,15,15,15,14,14,13,14,12,14,14,13,12,12,11,11,8,15,15,15,14,14,13,14,12,14,14,13,12,12,11,11,7,16,15,16,14,15,12,15,11,15,14,14,12,13,11,12,7,16,16,16,15,16,15,14,13,15,15,13,12,13,12,11,9,16,16,16,14,15,14,14,12,15,15,13,12,14,12,11,8,16,16,16,14,16,14,14,11,15,15,14,12,14,12,11,7,13,13,13,12,13,12,13,11,11,12,11,10,10,10,10,8,15,14,14,13,14,13,14,12,13,13,12,11,13,11,11,8,16,15,16,14,16,14,16,13,15,14,14,12,14,12,13,9,14,15,13,13,14,13,14,12,12,13,11,11,12,11,11,8,15,15,14,13,15,14,14,12,13,13,12,11,13,12,11,8,16,16,16,13,16,15,16,13,15,14,14,12,14,13,13,9,14,15,13,13,16,15,15,13,13,14,11,11,13,12,11,9,16,16,14,13,16,15,16,13,14,14,12,11,14,13,12,8,16,16,15,12,16,15,15,12,15,14,13,11,14,13,12,8,14,14,14,13,14,13,14,12,12,13,12,11,11,11,11,8,15,15,15,14,14,13,15,12,14,13,13,12,12,11,11,8,16,16,16,15,15,14,16,13,15,14,14,12,14,12,12,9,15,15,14,14,14,14,14,13,13,14,12,11,12,11,11,8,15,15,15,13,15,14,14,12,13,13,12,11,12,11,11,7,16,15,16,14,16,14,15,12,15,14,14,12,13,12,12,8,16,16,15,14,16,15,15,13,14,14,12,11,13,12,11,8,16,16,15,13,16,14,14,12,14,15,12,11,13,12,11,7,16,16,16,13,16,15,15,12,15,14,13,11,14,12,11,7,15,15,15,14,13,13,14,13,13,14,13,12,11,11,11,8,16,16,16,14,15,13,15,12,14,14,14,13,12,11,12,8,16,16,16,14,15,13,15,12,15,14,14,12,13,11,12,8,15,16,16,14,15,14,15,13,14,14,12,12,11,11,11,8,16,15,15,14,15,14,14,12,14,14,13,12,12,11,11,7,16,16,16,13,15,13,15,12,15,14,14,12,13,11,11,7,16,16,16,15,15,16,15,13,14,14,12,12,12,12,11,8,16,16,16,14,16,14,14,12,15,15,13,11,12,11,10,7,16,16,15,13,16,14,14,11,15,14,13,10,13,11,10,5,1,6,6,7,6,7,9,7,6,9,7,8,7,8,8,5,5,8,10,10,10,10,12,11,11,12,11,11,11,12,12,9,9,10,12,11,13,12,15,13,14,15,15,14,14,15,15,12,6,10,9,10,10,11,13,12,11,13,11,12,12,12,12,10,6,10,10,10,11,11,13,11,11,13,12,12,11,12,12,10,9,12,13,12,13,13,16,13,14,16,15,14,14,15,16,12,9,13,11,13,14,14,16,15,14,16,13,15,15,15,15,12,9,13,12,13,14,15,16,15,14,16,15,15,15,15,16,12,8,12,12,11,13,14,15,13,13,15,14,14,14,14,14,12,6,10,10,11,9,10,13,11,11,13,12,12,10,12,12,9,6,10,11,11,11,10,13,12,11,13,12,12,12,12,13,10,9,12,13,13,13,12,16,13,14,16,14,15,16,14,15,12,8,12,13,13,13,13,16,14,13,16,13,14,14,14,14,12,7,11,11,12,11,12,14,13,12,14,13,13,12,13,13,11,9,12,13,13,13,13,15,14,14,16,16,15,15,15,16,12,11,16,14,16,16,16,16,16,16,16,16,16,16,16,16,14,10,14,14,15,15,16,16,16,14,16,14,16,16,16,16,13,9,13,13,13,14,14,16,14,14,16,15,14,14,16,16,13,9,13,14,14,11,13,16,14,13,16,15,16,13,14,15,12,10,13,14,15,13,12,16,14,14,16,15,15,14,14,16,13,9,12,13,14,12,11,15,13,13,15,13,14,15,14,16,12,11,15,16,16,14,16,16,16,15,16,16,16,16,16,16,13,11,14,14,15,13,14,16,15,15,16,16,16,16,16,16,13,10,12,13,14,13,13,16,14,14,14,14,16,15,14,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,9,12,13,14,13,13,16,13,13,15,15,16,15,15,16,12,6,11,11,12,10,12,13,12,11,13,11,12,11,12,13,10,9,12,13,13,13,13,16,14,14,15,14,14,14,14,14,12,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,14,7,11,11,12,12,12,14,13,12,14,11,13,13,13,13,11,8,12,12,13,12,13,14,13,13,14,13,13,13,14,14,11,11,14,14,15,16,15,16,16,15,16,16,16,16,16,16,13,10,14,12,14,15,15,16,16,14,16,12,15,16,16,16,13,11,14,13,15,15,15,16,16,14,16,14,14,16,16,16,13,11,14,14,14,15,16,16,16,16,16,16,15,16,16,16,13,7,11,12,11,10,12,14,13,12,14,13,13,10,12,13,10,8,12,12,13,12,12,15,13,13,14,13,13,13,13,14,11,11,13,15,16,14,15,16,16,16,16,16,16,16,16,16,13,9,12,13,13,13,13,15,14,13,15,13,14,13,14,14,12,7,11,11,11,11,11,13,12,11,13,11,12,11,12,12,10,9,12,13,13,13,13,16,13,14,16,15,14,14,14,16,12,12,14,14,16,16,16,16,16,16,16,15,16,16,16,16,14,10,13,13,14,14,14,16,15,14,16,14,14,16,15,15,12,9,12,13,13,13,15,16,14,13,16,14,13,13,14,14,11,10,14,15,14,12,14,16,15,13,16,16,16,12,14,16,12,11,14,14,14,14,14,16,15,15,16,16,16,14,15,16,13,11,14,14,16,14,13,16,15,14,16,15,16,15,15,16,13,12,16,16,16,14,16,16,16,16,16,16,16,15,16,16,14,10,13,14,14,13,14,16,14,13,16,15,15,13,14,14,12,9,12,13,14,13,12,16,14,13,16,14,14,14,14,15,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,15,15,16,16,16,16,16,16,16,16,16,16,16,16,13,9,12,13,13,13,13,14,13,12,15,14,14,14,14,14,11,11,14,14,16,14,16,16,16,13,16,14,16,14,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,14,14,16,16,15,16,16,15,16,14,16,16,16,16,14,12,15,15,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,10,14,12,15,15,15,16,16,14,16,12,14,16,16,15,14,12,15,14,16,16,16,16,16,15,16,14,16,16,16,16,14,12,15,15,15,15,16,16,16,16,16,16,15,16,16,16,14,11,15,15,16,14,16,16,16,14,16,16,16,13,16,16,13,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,11,15,14,16,14,14,16,15,14,16,15,16,15,16,16,12,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,12,16,15,16,16,16,16,16,16,16,15,16,16,16,16,14,10,14,13,14,15,14,16,15,14,16,13,16,16,16,15,13,10,14,14,14,13,14,16,15,15,16,14,14,14,16,16,12,10,14,15,14,13,16,16,15,13,16,16,16,12,14,16,12,11,16,16,16,14,15,16,16,16,16,16,16,14,16,16,13,12,15,14,16,15,16,16,16,16,16,16,16,16,14,16,14,13,16,16,16,16,16,16,16,16,16,16,16,15,16,16,14,11,14,14,14,14,15,16,14,14,16,16,16,13,15,15,12,10,14,13,14,14,14,16,15,14,16,15,15,14,14,16,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,12,14,14,16,16,16,16,16,16,16,15,16,16,16,16,13,8,11,11,12,12,12,13,12,11,13,12,12,12,13,12,10,5,6,6,6,6,6,7,6,6,7,6,6,6,6,6,4,9,9,9,8,9,8,10,8,10,10,9,9,9,8,9,6,11,10,12,10,11,10,12,9,12,11,11,10,11,10,11,8,9,10,9,8,10,10,10,9,9,10,8,8,9,9,8,7,10,11,10,9,11,11,11,9,11,11,10,9,10,10,10,7,13,12,12,10,13,12,13,10,13,12,12,11,13,12,11,9,11,12,10,10,12,12,11,10,11,12,10,10,11,11,10,8,12,12,11,10,13,13,13,10,13,13,12,11,13,12,11,9,12,12,12,10,13,13,13,10,13,13,12,10,13,12,12,9,9,9,10,10,9,8,10,9,9,10,9,9,8,8,9,6,10,11,11,11,10,9,11,9,11,11,11,10,10,9,10,7,12,12,13,12,12,10,13,10,13,13,13,12,12,11,11,9,11,12,11,11,11,11,11,10,11,12,10,10,10,10,10,8,12,12,12,11,12,11,11,10,12,12,11,11,11,11,10,8,14,13,13,12,13,12,13,10,14,14,13,12,13,12,12,9,13,14,13,12,13,13,13,12,13,13,12,12,12,12,11,9,14,14,13,12,13,13,13,11,14,14,13,12,13,12,12,9,14,15,14,12,15,13,13,11,15,14,14,12,14,13,12,9,11,11,12,12,10,10,12,11,11,12,11,11,10,10,10,8,12,12,14,13,11,10,12,11,13,13,13,12,12,10,11,9,13,13,14,14,12,10,13,11,14,14,14,13,12,11,12,9,13,13,13,13,12,13,13,12,13,14,12,12,12,12,11,9,13,14,14,13,13,12,13,11,14,14,13,12,13,12,12,9,14,14,14,14,14,12,13,11,15,15,15,13,14,12,12,9,14,15,15,13,14,14,13,12,13,14,13,13,12,12,11,10,16,16,15,14,15,14,13,11,15,15,14,13,13,13,12,9,15,15,15,13,14,13,13,11,15,15,15,13,14,13,12,9,8,9,9,9,9,9,10,9,8,10,9,9,8,8,9,7,11,11,11,11,11,11,12,10,11,11,11,10,10,10,10,8,13,13,14,12,13,12,14,11,13,13,13,12,13,11,12,9,10,11,10,11,11,11,12,10,10,11,10,10,10,10,10,8,12,12,12,11,12,12,12,11,11,12,11,10,11,11,10,8,14,13,14,12,14,13,14,12,14,13,13,11,13,12,12,9,12,13,12,12,13,13,13,12,12,13,11,11,12,12,11,9,13,14,13,12,14,14,14,12,14,13,12,11,13,12,12,9,14,14,13,12,15,14,15,12,14,14,13,11,13,13,12,9,10,11,11,11,10,10,12,10,10,11,10,10,9,9,10,7,12,12,13,12,12,11,12,11,12,12,12,11,11,10,10,8,14,13,14,13,14,12,13,12,14,13,14,12,13,11,12,9,12,13,12,12,12,12,12,11,11,12,11,10,10,10,10,8,12,12,12,12,12,12,12,11,12,12,11,10,11,10,10,7,14,14,14,12,14,12,14,11,14,13,13,11,13,11,11,8,13,15,13,13,14,14,14,12,13,14,12,12,12,12,11,9,14,15,13,12,14,13,13,11,13,13,12,11,13,12,11,8,15,15,15,12,15,14,14,11,14,14,13,11,13,12,12,8,12,13,13,13,12,12,13,12,12,13,12,12,11,11,11,9,13,14,15,14,13,12,14,12,13,13,14,12,12,11,12,9,14,14,15,14,14,12,14,12,14,14,14,13,13,11,12,9,13,14,14,14,13,13,14,13,13,13,12,12,12,12,11,9,14,14,14,13,13,13,13,12,13,14,13,12,12,11,11,8,15,14,15,14,14,13,14,11,15,14,14,12,13,11,12,8,14,15,14,14,15,14,14,13,14,15,13,13,12,12,11,10,16,15,14,14,14,14,13,12,14,14,13,12,13,12,11,9,15,15,15,14,16,14,14,11,15,15,14,12,13,12,11,8,11,12,11,12,12,12,12,11,10,11,10,10,10,10,10,8,13,13,13,13,13,13,14,12,12,12,12,12,12,11,12,9,14,14,14,13,15,13,15,13,14,14,14,12,14,12,13,10,12,13,12,13,13,13,13,12,11,12,11,11,12,11,11,9,14,14,13,13,14,14,14,12,12,13,12,11,13,12,12,9,14,14,15,13,15,15,15,13,15,13,13,12,14,12,13,10,13,15,12,13,14,14,14,13,12,13,11,11,13,12,11,10,14,15,14,13,15,14,15,13,14,14,12,11,13,13,12,9,14,15,14,13,15,14,15,13,14,14,13,11,14,13,12,9,12,13,13,13,12,13,13,12,11,12,12,11,11,11,11,9,13,14,14,13,14,13,14,12,13,13,13,12,12,11,11,9,15,15,16,14,15,14,14,13,15,14,14,13,13,12,13,10,13,14,14,13,13,14,14,13,12,13,12,12,11,11,11,9,14,14,14,13,14,13,14,12,13,13,12,11,12,11,11,8,15,15,15,13,15,14,14,12,14,13,13,12,13,12,12,9,14,15,14,14,15,15,14,13,13,14,12,12,13,12,12,9,15,15,14,13,15,14,14,13,14,14,12,11,13,12,11,8,15,16,14,13,15,15,15,12,14,14,13,11,14,12,12,8,12,14,13,13,13,13,14,12,12,13,12,12,10,11,11,9,14,15,15,14,13,13,15,13,13,14,14,12,12,11,12,9,15,15,16,14,14,13,15,13,14,14,14,13,13,11,12,9,14,15,14,14,14,14,14,13,13,14,13,12,12,12,11,9,14,15,15,14,14,14,14,12,13,14,13,12,12,11,11,8,15,15,15,14,14,13,15,12,15,14,14,12,13,11,11,8,14,16,14,14,14,15,14,13,13,14,12,12,12,12,11,9,15,15,15,14,15,14,14,12,14,14,13,12,12,11,11,8,15,15,14,13,15,13,14,12,14,14,13,11,13,11,11,7,1,5,6,7,6,7,9,8,6,9,8,8,7,8,8,6,5,8,10,10,10,11,13,12,11,13,12,12,12,12,13,10,8,10,13,12,13,13,16,14,14,16,16,14,16,16,16,12,5,10,9,11,11,12,13,12,11,13,11,12,12,12,13,10,6,10,11,11,11,12,14,12,11,13,13,13,12,13,13,11,8,12,13,12,14,14,16,14,14,16,16,16,16,16,16,13,9,13,11,14,14,16,16,16,14,16,14,16,16,16,16,13,9,13,13,13,14,16,16,16,16,14,16,16,16,16,16,14,8,12,13,12,13,14,16,14,14,16,16,16,14,16,16,13,5,10,11,12,9,11,13,12,11,13,13,13,11,12,13,10,6,10,11,12,11,11,14,13,12,14,12,13,13,13,13,11,9,12,14,15,13,13,16,16,14,16,16,16,16,16,16,13,8,13,13,14,13,14,16,16,14,16,14,16,14,16,14,13,7,11,12,13,12,12,14,13,12,14,13,14,13,14,14,12,9,13,14,14,14,14,16,16,16,16,16,16,16,16,16,13,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,15,14,16,16,16,16,16,16,16,16,16,16,16,16,14,9,13,14,14,14,16,16,16,14,16,16,16,16,16,16,14,9,13,14,15,11,13,16,14,14,16,16,16,13,14,16,13,9,13,14,16,13,13,16,16,14,16,16,16,16,15,16,14,8,12,13,16,13,12,16,14,13,16,14,16,16,16,16,13,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,16,16,14,16,16,16,16,16,16,16,16,16,16,14,9,13,16,16,14,14,16,16,14,16,16,16,16,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,13,14,15,14,14,16,14,13,16,16,16,14,16,16,14,6,11,11,12,11,12,14,13,11,14,12,13,12,13,13,11,9,13,13,14,13,14,16,16,14,16,16,16,15,16,16,13,11,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,7,11,11,13,12,13,16,14,12,16,12,14,14,14,14,12,8,12,12,13,12,14,16,14,13,16,14,14,14,14,14,12,11,15,15,16,16,16,16,16,16,16,16,16,16,16,16,14,10,14,13,16,16,16,16,16,14,16,14,16,16,16,16,16,10,16,14,16,16,16,16,16,16,16,16,16,16,16,16,14,10,16,14,16,16,16,16,16,16,16,16,16,16,16,16,14,7,11,12,12,11,13,16,14,12,15,14,14,11,13,13,12,8,12,12,13,13,13,16,14,13,16,13,15,13,14,14,12,11,14,16,16,16,16,16,16,16,16,16,16,16,16,16,14,8,12,13,14,13,14,16,16,14,16,14,16,14,16,15,13,6,11,11,12,11,12,13,13,11,13,12,13,12,13,13,11,9,13,14,14,14,14,16,14,14,16,16,16,16,16,14,13,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,13,14,14,16,16,16,14,16,14,16,16,16,16,13,9,13,14,13,13,16,16,14,13,16,16,16,13,16,14,13,10,14,14,16,13,16,16,16,16,16,16,16,13,14,16,14,11,16,16,16,14,16,16,16,16,16,16,16,16,16,16,14,10,14,16,16,14,14,16,16,16,16,16,16,16,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,14,14,14,16,16,16,14,16,16,16,14,16,16,13,9,13,13,16,14,14,16,16,14,16,14,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,13,14,14,13,16,16,14,13,16,14,16,14,14,16,12,10,14,14,16,16,16,16,16,13,16,16,16,14,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,14,16,16,16,16,16,16,16,16,16,16,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,13,16,16,16,16,16,14,16,12,16,16,16,16,14,11,16,16,16,16,16,16,16,16,16,15,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,14,16,16,16,14,16,16,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,11,16,16,16,16,16,16,16,14,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,15,14,16,16,16,16,16,16,16,14,16,16,16,16,14,10,14,14,14,14,16,16,16,16,16,16,16,16,16,16,13,10,14,16,16,13,16,16,16,14,16,16,16,12,16,16,14,11,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,15,14,16,14,16,16,16,16,16,16,16,14,16,16,13,10,15,14,16,15,16,16,16,16,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,14,14,16,16,16,16,16,16,16,16,16,16,16,16,14,8,12,12,13,12,14,14,14,12,16,13,14,12,14,14,11,0,3,3,4,3,5,5,5,2,5,4,6,4,6,6,6,0,2,3,4,2,5,6,7,3,6,5,7,4,7,8,8,0,3,4,4,3,4,5,5,3,5,4,5,4,5,5,3,0,3,3,4,3,4,5,5,3,5,4,6,3,5,6,5,0,4,4,4,4,5,5,4,4,5,4,5,4,4,4,2,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,6,6,5,6,5,6,4,6,6,5,4,4,4,4,1,0,4,4,4,4,5,5,4,4,5,5,4,4,4,4,2,0,4,3,4,3,4,5,4,3,5,4,5,3,5,5,5,0,2,3,4,2,5,6,7,3,6,5,7,4,7,8,8,0,4,4,4,4,4,5,4,4,5,4,4,3,4,4,3,0,3,3,4,3,4,5,5,3,5,4,6,3,5,6,5,0,4,4,4,4,4,5,4,4,5,5,5,4,4,4,2,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,5,6,5,5,5,6,4,6,6,5,4,5,4,4,1,0,4,4,4,4,4,5,4,4,5,5,4,4,4,5,2,0,3,3,4,3,4,4,5,3,5,4,5,4,5,5,5,0,2,3,4,2,4,6,7,3,6,5,7,5,7,8,8,0,4,4,4,4,4,5,4,3,5,4,4,4,4,4,3,0,3,3,4,3,3,6,6,3,6,4,6,3,6,6,5,0,4,4,4,3,4,5,4,4,5,4,4,4,4,4,3,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,5,5,5,5,5,6,4,5,6,5,5,5,4,4,1,0,4,4,4,4,4,6,4,4,6,5,4,4,4,4,2,0,3,3,4,3,4,4,5,3,5,4,5,4,5,5,5,0,2,3,4,2,4,7,6,3,7,5,7,5,7,7,7,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,3,3,3,3,4,6,6,3,6,4,6,3,6,6,5,0,3,4,4,3,4,5,4,4,5,4,5,4,5,4,3,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,4,5,4,4,4,5,4,4,5,5,4,4,4,4,2,0,4,4,4,4,5,5,4,4,5,5,4,4,4,4,2,0,3,3,4,3,4,5,6,2,5,4,7,4,6,6,7,0,2,3,4,2,4,6,7,3,7,5,7,5,7,7,7,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,2,3,4,3,4,6,5,3,6,4,6,4,6,6,6,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,4,4,4,4,5,5,4,4,5,5,4,4,4,4,2,0,3,4,4,4,4,5,4,4,5,4,4,4,4,4,3,0,5,8,3,6,9,6,7,9,4,6,9,6,7,9,8,8,9,7,8,9,8,9,9,9,9,9,2,6,9,4,7,9,7,8,9,5,7,9,6,7,9,8,8,9,7,8,9,8,9,9,9,9,8,5,8,10,6,8,10,8,9,9,7,8,10,7,9,10,8,9,9,8,9,10,9,9,10,9,9,9,7,9,10,8,9,10,8,8,9,8,9,10,8,9,10,8,8,9,8,9,9,8,9,9,8,8,7,0,4,9,2,6,10,7,8,10,3,6,10,6,7,10,9,9,10,8,9,11,9,10,11,10,11,11,2,6,10,4,7,10,8,9,10,5,7,10,7,8,10,9,9,10,9,10,11,10,10,11,11,11,11,6,9,11,7,9,11,9,10,12,8,9,11,8,10,11,10,10,11,10,11,12,11,11,12,11,11,11,9,11,12,10,11,12,10,11,12,10,11,12,10,11,12,11,11,12,11,12,12,11,12,12,12,11,11,0,4,9,3,6,9,6,8,9,4,6,9,5,7,9,8,8,9,7,8,10,8,9,10,9,9,9,2,6,9,4,7,9,7,8,9,5,7,9,6,7,10,8,9,9,7,9,10,8,9,10,9,9,9,5,8,10,6,8,10,8,9,10,7,8,10,7,9,11,9,9,10,8,9,10,9,10,10,10,10,9,7,9,10,8,9,11,8,9,10,8,9,11,8,9,11,9,9,10,9,9,10,9,9,10,9,9,8,0,4,9,2,5,10,7,8,11,3,6,10,6,7,10,9,10,11,8,9,11,9,10,11,11,11,12,2,6,10,4,7,10,8,9,11,5,7,10,6,8,10,9,10,11,9,10,12,10,10,12,11,12,12,6,9,11,8,9,12,9,11,13,8,10,12,9,10,12,11,11,12,10,12,13,11,12,13,13,12,13,10,11,13,10,12,13,11,12,13,11,12,13,11,12,13,12,12,13,12,13,14,13,13,14,13,13,13,0,4,9,3,6,9,7,8,10,3,6,9,5,7,10,8,9,10,7,9,10,8,9,10,10,10,10,2,6,9,4,7,10,7,9,10,4,7,10,6,8,10,8,9,10,8,9,10,9,9,10,10,10,10,5,8,11,7,9,11,8,10,11,7,9,11,8,9,11,9,10,11,9,10,11,10,10,11,11,11,11,8,10,11,9,10,11,9,10,11,9,10,12,9,10,12,10,11,11,9,10,11,10,11,11,10,10,10,0,4,10,3,6,11,8,10,12,3,6,11,6,8,11,10,11,13,9,10,13,11,12,14,13,13,14,1,6,10,5,8,12,9,10,13,5,8,11,7,9,12,11,11,13,10,12,13,11,12,14,14,13,15,7,10,12,9,11,14,11,12,15,9,11,13,10,11,14,12,12,14,12,14,16,13,13,16,14,14,16,12,13,15,12,14,15,13,14,16,13,14,16,14,14,16,14,15,16,14,16,16,15,16,16,15,15,16,0,4,9,2,6,9,7,9,11,3,6,10,6,7,10,9,10,11,7,9,10,9,10,11,11,11,12,2,6,10,4,7,10,8,9,11,5,7,10,7,8,10,9,10,11,8,9,11,9,10,11,11,12,11,6,9,11,7,10,12,9,11,12,7,10,12,9,10,12,11,11,12,9,11,12,10,11,12,12,12,12,9,11,12,9,11,13,11,12,13,9,11,13,10,12,13,11,12,13,11,12,13,11,12,13,12,13,12,0,4,11,2,6,12,9,11,16,4,7,12,7,9,15,11,12,16,10,11,16,11,13,16,16,16,16,1,6,11,5,8,16,9,12,16,6,9,15,8,10,16,12,13,16,12,14,16,12,16,16,16,16,16,8,11,14,10,12,16,12,16,16,10,13,16,12,16,16,13,14,16,14,16,16,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,0,5,9,3,6,10,8,10,12,3,6,10,6,8,10,10,11,12,8,9,11,10,10,12,13,13,13,1,6,10,5,8,11,9,11,13,5,8,11,7,9,11,11,11,13,8,9,11,10,10,12,13,13,14,6,9,12,8,11,13,11,13,15,8,10,13,10,11,13,12,13,15,10,12,13,12,12,13,14,14,14,9,12,14,11,13,15,13,15,16,11,13,15,12,14,15,14,15,16,13,14,15,14,14,15,15,16,16,0,4,16,2,7,16,10,13,16,3,8,16,7,10,16,16,16,16,12,16,16,15,16,16,16,16,16,1,7,16,6,9,16,10,16,16,7,12,16,9,13,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,16,11,13,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,4,9,3,6,11,9,12,16,3,6,10,6,8,11,12,13,16,8,9,12,10,11,13,16,16,16,1,6,10,5,8,12,10,13,16,5,8,11,8,9,13,13,14,16,9,10,14,11,12,15,16,16,16,6,10,13,9,12,16,14,16,16,9,12,14,11,13,16,16,16,16,12,14,16,14,16,16,16,16,16,11,16,16,13,16,16,16,16,16,12,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,4,16,2,8,16,10,16,16,3,9,16,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,7,16,5,10,16,16,16,16,7,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,15,16,10,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,3,9,3,7,11,11,15,16,3,6,11,7,9,12,16,16,16,8,10,16,11,16,16,16,16,16,1,6,11,6,9,15,16,16,16,5,8,16,9,11,16,16,16,16,10,16,16,16,16,16,16,16,16,7,11,16,11,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,4,16,2,8,16,16,16,16,3,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,7,16,5,12,16,16,16,16,6,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,4,8,3,6,8,6,7,8,4,6,8,6,7,8,7,8,8,7,8,8,8,8,8,8,8,8,3,6,8,4,6,9,7,7,8,5,7,9,6,7,9,8,8,8,7,8,8,8,8,8,8,8,7,6,8,9,7,8,9,7,8,9,7,8,9,7,8,9,8,8,9,8,8,9,8,9,9,8,8,8,8,9,9,8,9,9,7,8,8,8,9,9,8,9,9,8,8,8,7,8,8,8,8,8,7,7,6,0,4,9,3,6,9,7,8,10,3,6,9,5,7,10,9,9,10,7,8,10,8,9,10,10,10,10,2,6,9,4,7,10,8,9,10,4,7,10,6,7,10,9,9,10,7,8,10,8,9,10,10,10,10,6,8,10,7,9,11,9,10,11,7,9,11,8,9,11,10,10,11,8,9,11,9,10,11,11,11,10,8,10,11,9,10,11,9,10,11,8,10,11,9,10,11,10,10,11,8,10,11,9,10,10,10,10,9,0,4,8,3,6,8,6,7,9,4,6,8,5,7,8,8,8,9,7,7,8,8,8,8,8,9,8,3,6,8,4,6,9,7,7,9,5,6,9,6,7,9,8,8,9,7,8,8,8,8,8,8,8,8,6,8,9,7,8,10,7,8,9,7,8,10,7,8,10,8,8,9,7,8,9,8,9,9,9,9,8,7,9,10,8,9,10,8,8,8,8,9,10,8,9,9,8,8,8,7,8,8,8,8,8,8,7,6,0,4,9,3,6,10,8,9,11,3,5,9,5,7,10,9,10,11,7,8,10,9,9,11,11,11,12,2,5,10,4,7,10,8,9,11,4,6,10,6,7,10,9,10,11,7,9,10,9,9,11,11,11,11,6,8,11,7,9,11,9,10,12,7,9,11,8,9,12,10,10,12,8,10,11,10,10,11,12,11,11,8,10,12,9,11,12,10,11,12,9,10,12,10,11,12,11,11,12,9,10,12,10,10,11,11,11,10,0,4,8,3,6,9,7,8,9,4,6,8,5,7,9,8,9,9,7,8,9,8,8,9,9,9,9,2,6,9,4,6,9,7,8,10,5,7,9,6,7,9,8,8,9,7,8,9,8,8,9,9,9,9,6,8,10,7,8,10,8,9,10,6,8,10,8,8,10,9,9,10,8,9,10,9,9,10,10,10,9,8,9,10,8,9,10,8,9,10,8,9,10,9,9,10,9,9,9,8,9,9,8,9,9,9,9,8,0,4,10,3,6,10,8,10,12,2,6,10,6,8,11,10,11,12,7,9,11,9,10,12,12,13,13,2,6,10,4,7,11,9,10,13,4,7,11,7,8,11,10,11,12,8,9,12,10,10,12,12,12,13,6,9,12,8,10,13,10,12,14,7,10,13,9,10,13,11,11,13,9,11,13,11,11,13,13,13,13,9,11,13,10,12,14,11,12,14,9,11,14,11,12,14,12,12,14,9,12,13,11,12,13,13,12,12,0,4,9,3,6,9,7,8,10,3,6,9,6,7,9,9,9,10,7,8,9,8,9,10,10,10,11,2,6,9,4,7,10,7,9,10,4,7,10,6,7,10,9,9,10,7,8,10,8,9,10,10,10,10,6,8,11,7,9,11,8,10,11,6,9,11,8,9,11,9,9,11,8,9,11,9,10,11,11,10,10,8,10,11,9,10,11,9,10,11,8,10,11,9,10,11,10,10,11,8,10,11,9,10,11,10,10,10,0,4,12,3,7,12,10,11,14,3,6,12,7,9,13,12,13,14,8,11,13,11,12,14,14,14,14,1,7,12,5,8,13,10,12,14,4,8,13,8,9,13,12,13,14,9,11,14,11,12,14,14,14,14,7,10,14,9,11,14,11,13,16,8,11,14,10,12,14,13,13,16,10,12,15,12,13,15,15,15,15,10,13,15,12,13,14,13,15,15,10,13,15,12,13,15,13,14,15,10,13,14,12,13,14,14,14,14,0,4,9,3,6,10,7,9,11,3,5,9,5,7,10,9,10,12,7,8,10,9,10,11,11,12,12,2,6,10,4,7,10,7,9,12,4,7,10,6,7,11,9,10,12,7,9,11,9,9,11,11,11,12,5,8,11,7,9,12,9,10,13,6,9,12,8,9,12,10,10,12,8,10,12,10,10,12,12,12,12,8,10,12,9,11,13,10,11,13,9,11,13,10,11,13,11,11,13,9,11,12,10,11,12,11,11,12,0,4,12,3,7,13,10,12,15,3,7,13,7,9,14,12,12,13,8,11,14,11,13,15,15,14,14,1,6,13,5,8,13,10,13,15,4,8,13,8,9,14,13,13,15,8,11,14,12,12,15,15,14,14,7,10,13,9,11,13,12,14,16,8,11,14,10,12,15,13,13,16,10,12,15,12,13,15,15,14,15,11,12,14,12,14,14,13,15,15,10,12,14,12,13,15,14,15,15,10,13,13,12,13,15,14,14,15,0,5,10,3,7,11,9,11,14,3,7,11,7,8,12,11,12,14,7,9,12,10,11,14,13,14,16,1,7,11,5,8,12,9,11,15,4,8,12,7,9,13,11,12,15,8,10,13,10,11,14,14,14,16,6,9,13,8,11,14,10,13,16,7,10,14,9,11,15,12,13,16,9,11,15,12,12,15,14,14,16,10,12,14,11,13,15,12,14,16,10,12,15,11,13,16,13,14,16,10,13,16,12,13,15,14,15,16,0,5,16,3,8,14,11,13,14,2,8,14,8,10,16,13,13,14,9,13,16,12,13,16,16,14,16,1,7,14,6,10,14,12,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+642176);
/* memory initializer */ allocate([5,9,14,9,11,16,15,16,16,10,12,16,13,13,16,16,14,16,8,11,14,11,13,14,14,14,16,8,12,14,11,13,16,16,16,16,10,12,15,13,14,16,16,16,16,11,14,14,14,15,16,16,15,16,10,13,16,13,14,14,16,16,16,10,13,16,13,14,16,16,16,16,0,5,11,3,7,13,9,12,16,3,7,12,6,9,14,11,13,16,7,10,16,11,12,16,16,16,16,1,6,12,5,9,16,9,13,16,4,8,16,7,10,16,12,15,16,7,11,16,11,12,16,16,16,16,6,10,15,8,11,16,11,14,16,7,11,16,10,12,16,13,16,16,9,13,16,13,14,16,16,16,16,10,12,16,12,16,16,16,16,16,11,13,16,13,16,16,16,16,16,12,16,16,16,16,16,16,16,16,0,5,16,3,8,16,12,12,16,2,8,16,8,10,16,13,13,16,9,13,16,12,13,16,16,16,16,1,8,16,6,10,16,12,16,16,5,9,16,9,11,16,13,16,16,9,12,14,12,12,16,16,16,16,8,11,13,11,12,16,14,16,16,8,12,16,11,13,16,16,15,16,9,13,14,12,13,16,16,16,16,10,12,13,14,13,16,16,16,16,9,13,16,13,12,16,16,16,16,10,12,16,14,15,16,16,16,16,0,7,5,7,5,7,6,6,7,10,7,9,8,9,8,7,12,14,11,12,12,12,11,9,6,9,6,8,7,9,7,7,8,11,8,9,9,10,9,8,13,15,12,12,12,13,11,9,10,13,9,10,11,12,9,8,12,14,10,11,12,13,10,9,16,16,12,12,14,13,11,9,6,9,7,9,7,9,8,7,9,11,9,10,9,10,9,8,14,16,12,12,13,13,11,9,8,11,8,10,9,10,9,8,10,13,10,11,10,11,9,8,14,16,12,12,13,13,11,9,12,14,10,11,12,13,10,9,13,16,11,12,13,13,10,9,16,16,13,12,14,14,11,9,11,13,11,12,10,11,10,9,13,14,12,12,11,12,10,9,16,16,13,13,13,13,11,9,12,15,12,12,11,12,10,9,13,16,13,13,12,12,11,9,16,16,14,13,13,13,11,9,14,16,13,13,13,14,11,9,16,16,13,13,14,14,11,9,16,16,13,13,14,13,11,8,4,9,6,8,6,9,7,7,8,11,8,9,9,10,8,8,13,15,12,12,13,13,11,9,7,10,7,9,8,10,8,8,9,12,9,10,10,11,9,8,14,16,12,12,13,13,11,9,11,13,9,10,11,12,9,8,12,14,10,11,12,13,10,9,16,16,13,12,14,14,11,9,7,10,8,9,8,10,8,8,10,12,10,11,10,11,9,8,14,16,13,13,13,13,11,9,9,12,9,10,9,11,9,8,11,13,10,11,10,11,10,9,15,16,13,13,13,13,11,9,12,14,11,11,12,13,10,9,13,16,11,12,13,13,10,9,16,16,12,12,14,13,11,8,11,14,11,12,10,11,10,9,13,15,12,13,11,12,10,9,16,16,14,13,13,13,11,9,12,15,12,13,11,12,10,9,13,16,13,13,12,12,11,9,16,16,14,13,13,13,11,9,15,16,13,13,13,13,11,9,16,16,13,13,13,13,11,9,16,16,13,12,13,13,10,7,8,11,8,10,9,11,9,9,10,13,10,11,11,12,10,9,15,16,13,13,14,14,12,10,9,12,9,11,10,11,9,9,12,14,11,11,11,12,10,9,16,16,13,13,14,14,12,10,12,14,10,11,12,13,10,9,14,16,11,12,13,14,10,9,16,16,13,13,15,14,11,9,9,12,10,11,9,11,10,9,12,14,11,12,11,12,10,9,16,16,14,13,14,14,12,10,11,14,10,12,11,12,10,9,12,15,11,12,12,13,11,10,16,16,14,13,14,14,12,10,13,16,11,12,13,14,11,9,14,16,12,12,13,14,11,9,16,16,13,13,14,14,11,9,12,15,12,13,10,12,10,9,14,16,13,13,11,12,11,10,16,16,14,14,14,13,12,9,13,16,13,13,12,13,11,10,14,16,13,13,12,13,11,10,16,16,14,14,13,13,12,9,15,16,13,13,13,14,11,9,16,16,13,13,13,14,11,9,16,16,13,12,13,13,10,8,10,13,10,11,10,12,10,9,12,14,11,12,12,13,11,10,16,16,13,13,14,14,12,9,11,14,10,11,11,12,10,9,13,16,11,12,12,13,11,10,16,16,14,13,14,14,12,9,12,15,10,11,12,13,9,8,14,16,11,11,13,14,10,8,16,16,12,12,14,14,10,8,11,14,11,12,11,12,10,9,13,16,12,13,12,13,11,10,16,16,14,13,14,14,12,9,12,15,11,12,11,13,10,10,13,16,12,13,12,13,11,10,16,16,14,13,14,14,12,9,13,16,11,11,13,13,10,8,14,16,11,12,13,14,10,8,16,16,12,12,14,14,10,8,12,15,12,13,10,11,10,9,14,16,13,13,11,12,10,9,16,16,14,13,13,13,11,8,13,16,12,13,11,12,10,9,14,16,13,13,12,12,10,9,16,16,14,13,13,12,10,8,14,16,12,12,12,13,10,8,14,16,12,12,12,13,10,7,16,16,11,11,12,11,8,5,0,7,4,8,5,8,7,8,6,10,7,10,8,10,9,9,13,16,12,13,13,14,12,12,4,10,6,9,8,11,8,9,8,12,8,11,10,12,10,10,14,16,12,13,14,15,12,12,9,14,9,11,12,14,11,11,11,15,10,12,13,14,11,11,15,16,13,14,15,16,13,12,5,10,7,10,7,10,9,9,8,12,9,11,10,11,10,10,14,16,13,14,14,14,12,12,8,12,8,11,10,12,10,10,10,14,10,12,11,13,10,11,15,16,13,14,14,15,13,12,11,16,10,12,13,15,11,11,13,16,11,13,14,15,12,12,16,16,14,14,16,16,13,12,11,15,11,13,11,13,11,11,13,16,12,14,12,13,12,12,16,16,14,15,15,15,13,12,12,16,12,14,12,14,12,12,14,16,13,14,13,14,12,12,16,16,14,16,16,16,13,12,14,16,13,14,15,16,13,12,16,16,14,15,16,16,13,12,16,16,15,16,16,16,13,12,2,9,5,8,6,9,8,9,7,11,8,10,9,11,9,10,13,16,12,13,14,14,12,12,5,11,6,10,9,11,9,9,9,13,9,11,10,12,10,10,14,16,12,14,14,15,12,12,9,14,9,11,12,14,10,11,11,16,10,12,13,14,11,11,16,16,13,14,15,16,13,12,6,11,7,10,8,11,9,9,9,13,9,11,10,12,10,10,14,16,13,14,14,14,12,12,8,13,8,11,10,12,10,10,10,13,10,12,11,13,10,11,14,16,13,14,14,15,12,12,11,15,10,12,13,15,11,11,12,16,11,13,13,15,12,11,16,16,13,14,15,16,13,12,11,15,11,13,10,13,11,11,13,16,12,14,12,13,12,11,16,16,14,15,15,15,13,12,12,16,12,13,12,14,12,12,13,16,12,14,13,14,12,12,16,16,14,15,15,15,13,12,14,16,13,14,15,16,12,12,16,16,13,14,15,16,12,12,16,16,14,15,16,16,13,12,6,12,7,10,9,12,9,10,9,13,9,12,11,13,11,11,14,16,13,14,15,15,13,12,8,13,8,11,10,13,10,10,10,14,10,12,12,14,11,11,15,16,13,14,16,16,13,12,10,15,9,12,12,15,11,11,12,16,11,13,14,16,12,12,16,16,14,14,16,16,13,12,8,13,9,11,10,12,10,11,11,14,11,12,11,13,11,11,16,16,14,15,15,16,13,12,10,14,10,12,11,13,11,11,11,15,11,13,12,14,11,11,15,16,13,14,15,16,13,12,12,16,11,13,13,16,12,12,13,16,11,13,14,16,12,12,16,16,13,14,16,16,13,12,12,16,12,14,11,13,11,11,13,16,13,14,12,14,12,12,16,16,15,16,16,16,14,13,13,16,12,14,12,14,12,12,14,16,13,14,13,14,12,12,16,16,14,16,14,16,13,12,15,16,13,15,15,16,13,12,15,16,13,15,14,16,13,12,16,16,14,15,15,16,13,11,8,13,8,11,10,13,10,11,11,15,10,12,12,14,11,11,15,16,13,14,15,15,13,12,9,14,9,12,11,14,10,11,11,16,10,12,13,14,11,11,16,16,13,14,15,16,13,12,11,15,9,12,12,14,10,10,12,16,11,12,14,15,11,11,16,16,13,14,16,16,12,11,9,14,10,12,11,13,11,11,12,16,11,13,12,14,11,11,16,16,14,14,15,15,13,12,10,15,10,12,12,14,11,11,12,16,11,13,13,14,11,11,16,16,14,14,15,16,13,12,12,16,10,12,13,15,11,11,13,16,11,13,14,15,11,11,16,16,13,13,15,16,12,11,12,16,11,13,10,13,11,11,14,16,13,14,12,14,11,11,16,16,15,16,14,15,13,11,13,16,12,14,12,14,11,11,13,16,12,14,12,14,11,11,16,16,14,15,14,14,12,11,14,16,12,13,13,15,11,11,14,16,12,13,13,14,11,11,15,16,12,13,13,13,10,9,0,7,4,7,5,7,6,6,6,10,7,8,8,9,8,7,13,14,11,12,12,12,11,9,5,9,6,8,7,9,7,7,8,11,8,9,9,10,9,8,13,16,12,12,12,13,11,9,10,13,8,10,11,12,9,9,12,14,10,11,12,13,10,9,15,16,12,12,14,14,11,9,6,10,7,9,7,9,8,7,8,11,9,10,9,10,9,8,14,16,12,12,13,12,11,9,8,11,8,10,9,10,9,8,10,13,10,11,10,11,9,9,14,16,12,12,13,13,11,9,12,15,10,11,12,13,10,9,13,16,11,12,13,13,10,9,16,16,12,13,14,14,11,9,10,14,11,12,9,11,10,9,12,15,12,13,11,12,11,9,16,16,13,13,13,13,11,9,12,15,12,13,11,12,11,9,13,16,12,13,12,13,11,10,16,16,13,13,13,13,11,9,14,16,13,13,13,14,11,10,16,16,13,13,13,14,11,10,16,16,13,13,14,14,11,9,4,9,6,8,6,9,7,7,8,11,8,9,9,10,9,8,13,15,12,12,13,13,11,9,6,10,7,9,8,10,8,8,9,12,9,10,10,11,9,8,14,16,12,12,13,13,11,10,10,13,8,10,11,12,9,9,12,15,10,11,12,13,10,9,16,16,12,12,14,14,11,9,7,11,8,9,7,10,8,8,9,12,10,11,9,11,9,9,14,16,12,13,13,13,11,10,9,12,9,10,9,11,9,9,10,13,10,11,10,11,10,9,14,16,12,13,13,13,11,9,12,15,10,11,12,13,10,9,13,16,11,12,13,13,10,9,16,16,12,12,14,14,11,9,10,14,11,12,9,11,10,9,12,16,12,13,11,12,11,9,16,16,14,14,13,13,11,9,12,16,12,13,11,12,10,10,13,16,12,13,11,12,11,10,16,16,13,13,13,13,11,9,14,16,13,13,13,14,11,9,15,16,13,13,13,14,11,9,16,16,13,13,13,13,10,8,7,11,8,10,9,11,9,9,10,13,10,11,11,12,10,10,15,16,13,13,14,14,12,10,9,13,9,11,10,12,10,9,11,14,10,12,12,13,10,10,16,16,13,13,14,14,12,10,11,15,9,11,12,13,10,9,13,16,11,12,13,14,11,10,16,16,13,13,15,15,11,10,9,13,10,11,9,11,10,9,11,14,11,12,11,12,11,10,16,16,14,14,14,14,12,10,10,14,10,12,11,12,10,10,12,15,11,12,12,13,11,10,16,16,13,13,14,14,12,10,13,16,11,12,13,14,11,10,13,16,11,12,13,14,11,10,16,16,12,13,14,14,11,9,11,15,12,13,10,12,10,10,13,16,13,14,11,13,11,10,16,16,14,14,14,14,12,10,13,16,13,13,11,13,11,10,14,16,13,14,12,13,11,10,16,16,14,14,13,13,12,10,15,16,13,14,14,14,11,10,15,16,13,13,13,14,11,10,16,16,12,13,13,13,10,8,9,13,10,11,10,12,10,10,12,15,11,12,12,13,11,10,16,16,14,13,14,14,12,10,10,14,10,12,11,13,10,10,13,16,11,12,12,14,11,10,16,16,13,13,14,14,12,10,12,16,9,11,12,14,10,9,13,16,10,12,13,14,10,9,16,16,12,12,14,14,11,9,10,14,11,12,10,12,10,10,13,16,12,13,12,13,11,10,16,16,14,14,14,14,12,10,11,16,11,12,11,13,11,10,13,16,12,13,12,14,11,10,16,16,14,14,14,14,12,10,13,16,11,12,13,14,10,9,14,16,11,12,13,14,10,9,16,16,12,12,14,14,10,8,12,16,12,13,10,12,10,9,14,16,13,13,11,12,11,9,16,16,14,14,13,13,11,9,13,16,12,13,11,12,10,9,14,16,13,13,11,13,11,9,16,16,14,14,13,13,11,9,14,16,12,13,12,13,10,8,14,16,12,12,12,13,10,8,15,16,11,11,11,12,9,6,0,7,4,7,5,8,7,8,5,10,7,10,8,10,9,10,13,16,12,14,14,14,13,12,4,10,6,9,8,11,9,9,8,12,8,11,10,12,10,10,14,16,13,14,14,15,13,12,9,14,9,12,12,14,11,11,12,16,11,13,13,15,12,12,15,16,14,15,15,16,13,13,5,10,7,10,7,10,9,9,8,12,9,11,9,11,10,10,14,16,13,14,14,15,13,12,7,12,8,11,10,12,10,10,10,13,10,12,11,13,11,11,15,16,13,15,14,16,13,13,11,16,11,13,13,16,12,12,13,16,12,14,14,16,12,12,16,16,14,16,16,16,14,13,11,15,12,14,11,13,11,12,13,16,12,14,12,14,12,12,16,16,14,16,14,16,13,13,13,16,12,14,12,14,12,12,14,16,13,15,13,15,13,13,16,16,15,16,16,16,14,13,15,16,13,16,15,16,13,13,16,16,14,16,16,16,14,13,16,16,16,16,16,16,14,13,2,9,5,8,6,9,8,9,7,11,8,10,9,11,9,10,14,16,13,14,14,15,13,12,5,11,6,10,9,11,9,10,8,13,9,11,11,12,10,11,14,16,13,14,14,16,13,13,9,15,9,12,12,14,11,11,12,16,11,13,13,15,12,12,16,16,14,15,16,16,14,13,6,11,7,10,8,11,9,10,9,13,9,12,10,12,10,11,14,16,13,14,14,15,13,13,8,12,8,11,10,12,10,11,9,13,10,12,11,13,11,11,14,16,13,14,14,16,13,13,12,16,11,13,13,15,12,12,13,16,11,13,14,16,12,12,16,16,14,15,16,16,13,13,11,15,11,14,10,13,11,12,13,16,13,15,12,14,12,12,16,16,15,16,15,16,14,13,12,16,12,14,12,14,12,12,13,16,13,15,13,14,12,13,16,16,15,16,15,16,13,13,15,16,13,16,15,16,13,13,16,16,14,16,16,16,13,13,16,16,15,16,16,16,14,13,5,12,7,10,9,12,10,10,9,13,9,12,11,13,11,11,15,16,13,14,15,15,13,13,7,13,8,11,10,13,10,11,10,14,10,12,12,14,11,12,16,16,14,15,16,16,14,13,10,16,9,12,13,15,11,12,13,16,11,13,14,16,12,12,16,16,14,16,16,16,14,13,8,13,9,12,9,12,10,11,11,15,11,13,11,13,11,12,16,16,14,16,16,16,14,13,9,14,10,12,11,13,11,12,11,15,11,13,12,14,12,12,16,16,14,16,15,16,14,13,12,16,11,14,14,16,12,12,13,16,12,14,14,16,13,13,16,16,13,15,16,16,14,13,11,16,12,14,10,13,12,12,13,16,13,15,12,14,12,13,16,16,16,16,16,16,14,14,13,16,13,15,12,15,12,13,13,16,13,15,12,15,13,13,16,16,15,16,14,16,14,13,16,16,14,16,16,16,14,13,15,16,14,16,15,16,14,13,16,16,14,16,15,16,13,12,8,14,9,12,10,14,11,12,11,16,10,13,12,14,12,12,16,16,14,15,15,16,14,13,9,15,9,12,12,14,11,12,12,16,11,13,13,15,12,12,16,16,14,15,16,16,14,13,11,16,9,12,13,15,11,11,13,16,11,13,14,16,12,12,16,16,14,14,16,16,13,12,9,15,10,13,11,14,11,12,12,16,11,14,12,14,12,12,16,16,14,16,16,16,14,13,10,16,10,13,12,15,12,12,12,16,12,14,13,15,12,12,16,16,14,16,16,16,14,13,12,16,11,13,13,16,12,12,13,16,11,13,14,16,12,12,16,16,13,14,16,16,13,12,11,16,12,14,10,13,11,12,13,16,13,15,12,14,12,12,16,16,16,16,15,16,13,12,12,16,12,15,12,14,12,12,13,16,13,15,12,14,12,12,16,16,15,16,14,15,13,12,14,16,13,14,13,16,12,12,13,16,12,14,13,15,12,12,14,16,12,13,13,14,11,10,0,7,4,7,5,7,6,6,6,10,7,8,8,9,8,8,13,14,11,12,12,12,11,10,5,9,6,8,7,9,7,7,8,11,8,9,9,10,9,8,13,16,12,12,13,13,11,10,10,14,8,10,11,13,9,9,12,15,10,11,12,13,10,10,16,16,12,13,14,14,11,10,5,10,7,9,6,9,8,8,8,11,9,10,9,10,9,8,14,16,12,12,13,13,11,10,8,12,8,10,9,10,9,9,10,13,9,11,10,11,9,9,14,16,12,13,13,13,11,10,12,16,10,12,12,13,10,10,13,16,11,12,13,14,11,10,16,16,12,13,14,14,11,10,10,14,11,13,9,11,10,10,12,16,12,13,11,12,11,10,16,16,13,14,13,13,12,10,12,16,12,13,11,13,11,10,13,16,12,13,12,13,11,10,16,16,13,14,13,14,12,10,14,16,13,14,13,14,12,11,16,16,13,14,14,15,12,11,16,16,13,14,14,14,11,10,3,9,5,8,6,9,7,7,8,11,8,10,9,10,9,8,14,15,12,12,13,13,11,10,6,11,6,9,8,10,8,8,9,12,9,10,10,11,9,9,14,16,12,13,13,13,11,10,10,14,8,11,12,13,9,9,12,16,10,11,12,13,10,10,16,16,12,13,14,14,11,10,6,11,8,10,7,10,8,8,9,12,10,11,9,11,9,9,14,16,12,13,13,13,12,10,9,12,9,11,9,11,9,9,10,13,10,11,10,12,10,9,14,16,12,13,13,13,11,10,12,16,10,12,12,14,10,10,13,16,10,12,13,14,11,10,16,16,12,13,14,14,11,10,10,15,11,13,9,11,10,10,12,16,12,13,11,12,11,10,16,16,14,14,13,14,12,10,12,16,12,13,11,13,11,10,13,16,12,13,11,13,11,10,16,16,13,14,13,13,12,10,14,16,13,14,14,14,11,11,15,16,13,14,13,14,11,10,16,16,13,13,13,14,11,9,7,12,8,11,9,11,9,10,10,14,10,12,11,12,11,10,16,16,13,13,14,14,12,11,9,13,9,11,10,12,10,10,11,15,10,12,12,13,11,10,16,16,13,14,14,14,12,11,11,16,9,11,12,14,10,10,13,16,10,12,13,14,11,10,16,16,13,14,16,16,12,11,9,13,10,12,9,12,10,10,11,15,11,13,11,13,11,11,16,16,14,14,14,14,13,11,10,14,10,12,11,13,11,10,12,16,11,13,12,13,11,11,16,16,13,14,14,14,12,11,13,16,11,13,13,14,11,11,13,16,11,13,13,14,11,11,16,16,12,13,14,15,12,10,11,16,12,14,10,12,11,10,13,16,13,14,11,13,11,11,16,16,15,16,14,14,13,11,13,16,13,14,12,13,11,11,13,16,13,14,12,13,11,11,16,16,14,14,13,14,12,11,15,16,13,14,14,16,12,11,14,16,13,14,13,14,12,11,16,16,12,13,13,14,11,9,9,14,10,12,10,13,11,11,12,16,12,13,12,14,12,11,16,16,14,14,14,14,13,11,10,16,10,13,12,14,11,11,13,16,12,13,13,14,12,11,16,16,14,14,15,15,13,11,12,16,9,12,13,14,10,10,14,16,11,12,13,15,11,10,16,16,13,13,15,16,11,10,10,16,11,13,11,13,11,11,13,16,12,14,12,14,12,11,16,16,14,14,14,14,13,11,11,16,11,13,12,14,11,11,13,16,12,14,13,14,12,11,16,16,14,14,14,15,13,11,13,16,11,13,13,14,11,10,14,16,11,13,13,14,11,10,16,16,12,13,14,15,11,9,12,16,12,14,10,13,11,10,14,16,13,14,11,13,11,10,16,16,14,15,13,14,12,10,13,16,13,14,11,13,11,10,14,16,13,14,12,13,11,10,16,16,14,14,13,13,11,10,14,16,12,13,13,14,11,9,14,16,12,13,12,13,10,9,14,16,11,11,12,12,9,7,0,7,3,8,5,8,7,9,5,10,7,10,8,11,10,10,14,16,14,15,14,16,14,14,4,10,6,10,8,11,9,10,8,12,9,11,10,12,11,11,15,16,14,16,15,16,14,14,10,16,10,13,13,16,12,13,13,16,12,14,14,16,13,13,16,16,16,16,16,16,14,15,4,10,7,10,7,10,9,10,8,12,9,12,10,12,11,12,14,16,14,16,15,16,14,14,8,12,9,12,10,13,11,12,10,14,11,13,11,14,12,13,16,16,14,16,16,16,14,15,12,16,12,14,14,16,13,14,14,16,13,16,16,16,14,14,16,16,16,16,16,16,16,16,11,16,12,16,11,14,13,13,13,16,13,16,13,15,13,14,16,16,16,16,16,16,15,16,13,16,13,16,13,16,13,14,14,16,14,16,14,16,14,15,16,16,16,16,16,16,16,16,16,16,15,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,2,9,5,9,6,10,8,10,7,11,8,11,9,12,10,11,14,16,14,16,15,16,14,14,5,11,6,10,9,12,10,11,9,13,9,12,11,13,11,12,16,16,14,16,16,16,14,14,10,16,9,13,13,16,12,13,13,16,12,14,14,16,13,13,16,16,16,16,16,16,16,14,5,11,8,11,7,11,10,11,9,13,10,13,10,13,11,12,16,16,14,16,16,16,14,14,8,13,9,12,10,13,11,12,10,14,10,13,11,14,12,12,16,16,14,16,15,16,14,14,12,16,12,14,14,16,13,14,14,16,12,16,15,16,13,14,16,16,15,16,16,16,15,15,11,16,12,16,10,14,12,13,13,16,14,16,13,16,13,14,16,16,16,16,16,16,15,16,13,16,13,16,13,16,13,14,14,16,14,16,13,16,13,14,16,16,16,16,16,16,15,16,16,16,15,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,5,13,7,12,9,13,11,12,10,14,10,13,11,13,12,13,16,16,16,16,16,16,16,15,7,14,8,12,11,14,11,12,11,16,11,13,13,16,13,13,16,16,16,16,16,16,16,16,11,16,10,14,14,16,12,13,13,16,12,15,16,16,14,14,16,16,16,16,16,16,16,16,8,14,10,13,9,13,11,12,11,16,12,14,12,14,13,13,16,16,16,16,16,16,16,16,10,16,11,14,12,14,12,13,11,16,12,14,12,15,13,13,16,16,15,16,16,16,15,16,13,16,12,16,15,16,14,14,13,16,12,16,16,16,14,14,16,16,14,16,16,16,14,16,11,16,13,16,10,14,12,13,14,16,14,16,13,16,14,14,16,16,16,16,16,16,16,16,13,16,14,16,13,16,14,15,13,16,14,16,13,16,14,15,16,16,16,16,15,16,15,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,15,16,16,16,15,16,16,16,14,14,8,16,10,14,11,16,12,13,12,16,12,14,13,16,13,14,16,16,16,16,16,16,16,14,10,16,10,14,12,16,12,13,13,16,12,15,14,16,13,14,16,16,16,16,16,16,16,15,11,16,10,13,13,16,12,13,14,16,12,14,15,16,13,13,16,16,16,16,16,16,15,14,10,16,11,14,11,16,12,13,13,16,13,16,13,16,13,14,16,16,16,16,16,16,16,15,11,16,12,14,13,16,13,14,13,16,13,16,14,16,13,14,16,16,16,16,16,16,16,15,13,16,12,14,14,16,13,13,13,16,12,15,14,16,13,13,16,16,14,16,16,16,14,13,11,16,12,16,11,15,12,13,14,16,14,16,13,16,13,14,16,16,16,16,16,16,14,14,12,16,13,16,12,16,13,14,13,16,14,16,13,16,13,14,16,16,16,16,14,16,14,14,14,16,13,16,14,16,13,13,13,16,13,16,14,16,13,13,15,16,13,14,13,15,12,12,0,7,4,6,4,7,6,7,6,9,7,8,7,9,8,8,13,14,12,12,12,13,11,11,5,9,5,8,7,9,7,8,8,11,8,10,9,10,9,9,13,15,12,13,12,13,11,11,9,14,8,11,11,13,10,10,11,15,10,12,12,13,10,11,14,16,12,13,14,14,12,11,5,9,7,9,6,9,8,8,8,11,8,10,8,10,9,9,13,16,12,13,13,13,11,11,7,11,8,10,9,11,9,9,9,13,9,11,10,11,10,10,14,16,12,13,13,13,12,11,11,16,10,12,12,14,11,11,13,16,11,13,13,14,11,11,16,16,13,14,14,15,12,11,10,15,11,13,9,12,10,10,12,16,12,13,11,12,11,11,15,16,13,14,13,14,12,11,12,16,12,14,11,13,11,11,13,16,12,14,12,13,12,11,16,16,13,14,14,14,12,11,14,16,13,14,14,15,12,12,16,16,13,14,14,16,12,12,16,16,14,14,14,15,12,11,3,9,5,8,6,9,7,8,7,11,8,10,9,10,9,9,13,14,12,13,13,13,12,11,6,11,6,9,8,10,8,9,9,12,8,10,10,11,9,10,14,16,12,13,13,14,12,11,9,14,8,11,11,13,10,10,12,16,10,12,12,14,11,11,16,16,12,13,14,15,12,11,6,11,8,10,7,10,8,9,9,12,9,11,9,11,10,10,14,16,13,13,13,14,12,11,8,12,9,11,9,11,9,10,10,13,9,11,10,12,10,10,14,16,12,13,13,14,12,11,12,16,10,12,12,14,11,11,12,16,10,12,13,14,11,11,15,16,12,13,14,14,11,11,10,15,11,13,9,12,10,10,12,16,12,14,11,13,11,11,16,16,14,14,14,14,12,11,12,16,12,14,11,13,11,11,13,16,12,14,11,13,11,11,16,16,13,14,13,14,12,11,14,16,13,14,14,15,12,11,14,16,13,14,13,15,12,11,16,16,13,14,13,14,11,10,6,13,8,11,9,12,10,10,10,14,10,12,11,13,11,11,16,16,13,14,14,14,13,12,8,14,8,12,10,13,10,11,11,15,10,12,12,13,11,11,16,16,14,14,15,16,13,12,11,16,9,12,12,14,11,11,13,16,11,13,13,16,11,11,16,16,13,14,16,16,13,12,8,14,10,12,9,12,10,11,11,15,11,13,11,13,11,11,16,16,14,15,14,15,13,12,10,15,10,13,11,13,11,11,11,15,11,13,12,13,11,11,16,16,13,15,14,15,13,12,12,16,11,13,13,15,11,11,13,16,11,13,13,15,11,11,16,16,12,14,14,16,12,11,11,16,12,14,10,13,11,11,13,16,13,15,12,14,12,12,16,16,15,16,14,15,13,12,12,16,13,14,12,14,12,12,13,16,13,14,12,14,12,12,16,16,14,15,13,14,12,12,15,16,13,15,14,16,12,12,14,16,13,14,13,15,12,12,15,16,12,13,13,14,11,10,9,15,10,13,11,14,11,12,12,16,12,14,12,14,12,12,16,16,14,14,14,15,13,12,10,16,10,13,12,14,12,12,13,16,12,14,13,15,12,12,16,16,14,14,15,16,13,12,11,16,9,12,13,15,11,11,14,16,11,13,14,16,11,11,16,16,13,14,16,16,12,11,10,16,11,14,11,14,12,12,13,16,13,14,12,14,12,12,16,16,14,15,15,15,13,12,11,16,12,14,12,15,12,12,13,16,12,14,13,15,12,12,16,16,14,15,15,16,13,12,12,16,11,13,13,15,11,11,13,16,11,13,13,15,11,11,16,16,12,13,14,16,12,10,11,16,12,14,10,13,11,11,14,16,13,14,12,14,11,11,16,16,15,16,14,14,12,11,12,16,13,14,11,14,11,11,13,16,13,14,12,14,11,11,16,16,14,15,13,14,12,11,14,16,12,14,13,14,11,10,13,16,12,13,12,14,11,10,14,16,11,12,12,12,10,8,0,8,4,9,5,9,8,10,6,11,8,11,9,12,11,12,16,16,16,16,16,16,16,16,4,11,6,11,9,12,10,12,9,13,10,13,11,16,12,13,16,16,16,16,16,16,16,16,11,16,11,16,16,16,14,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,4,11,8,12,7,12,10,12,8,13,10,13,10,13,12,14,16,16,16,16,16,16,16,16,8,13,10,14,11,16,12,14,11,16,12,16,12,16,13,16,16,16,16,16,16,16,16,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,14,16,12,16,16,16,13,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,5,10,7,11,9,11,8,12,9,12,10,13,12,13,16,16,16,16,16,16,16,16,5,12,7,12,10,13,11,12,9,16,10,13,12,16,13,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,14,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,6,12,9,13,8,12,11,13,10,16,11,16,11,16,13,16,16,16,16,16,16,16,16,16,9,16,10,14,11,16,12,16,10,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,14,16,13,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,14,16,11,16,14,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,9,13,10,16,12,14,11,16,12,16,12,16,13,16,16,16,16,16,16,16,16,16,8,16,9,14,12,16,13,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,16,16,12,16,10,16,16,16,14,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,10,16,12,16,12,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,10,16,12,16,13,16,14,16,11,16,13,16,13,16,16,16,16,16,16,16,16,16,16,16,14,16,13,16,16,16,16,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,11,16,14,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,12,16,13,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,10,16,11,16,13,16,14,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,12,16,13,16,13,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,14,16,16,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,12,16,16,16,14,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,11,16,13,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,13,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,14,16,16,16,14,15,0,7,3,7,4,7,6,7,6,9,7,9,7,9,8,9,13,14,12,13,13,13,12,12,4,9,5,9,7,9,8,9,7,11,8,10,9,11,9,10,13,16,12,14,13,14,12,12,9,14,8,12,12,14,10,11,11,16,10,13,13,14,11,12,15,16,13,14,14,16,12,12,5,10,7,9,6,9,8,9,8,11,8,11,8,10,9,10,14,16,12,14,13,14,12,12,7,12,8,11,9,11,9,10,9,13,9,12,10,12,10,11,14,16,12,14,13,14,12,12,12,16,11,13,13,15,11,12,13,16,11,14,13,15,12,12,15,16,13,15,14,16,13,13,10,15,12,14,9,13,11,12,12,16,12,14,11,13,12,12,15,16,13,15,14,15,13,13,12,16,12,14,12,14,12,12,13,16,13,14,12,14,12,12,16,16,14,15,14,16,13,13,15,16,13,15,14,16,12,13,16,16,14,16,14,16,13,13,16,16,14,16,15,16,13,13,3,9,5,9,6,9,8,9,7,11,8,10,9,11,9,10,14,15,13,14,13,14,12,12,5,11,6,10,8,11,9,10,9,12,9,11,10,12,10,11,14,16,13,14,14,15,13,13,9,15,8,12,12,14,10,11,12,16,10,13,13,15,11,12,15,16,13,14,14,16,13,13,6,11,8,11,7,10,9,10,9,13,10,12,9,12,10,11,14,16,13,14,14,14,13,13,8,13,9,12,9,12,10,11,9,13,9,12,10,12,10,11,14,16,12,14,13,14,12,12,12,16,11,13,13,15,11,12,12,16,11,13,13,15,11,12,14,16,12,14,14,15,12,12,10,15,11,14,9,13,11,12,12,16,12,14,11,14,12,12,16,16,14,16,14,15,13,13,12,16,12,14,11,14,12,12,12,16,13,14,11,14,12,12,15,16,14,15,13,15,12,13,14,16,13,15,14,16,13,13,14,16,13,15,14,16,12,13,15,16,13,15,13,15,12,12,6,13,8,12,9,12,10,11,10,14,11,13,11,13,12,12,15,16,14,15,15,15,14,13,8,14,9,12,11,13,11,12,11,15,11,13,12,14,12,12,16,16,14,15,15,16,14,14,10,16,9,13,12,15,11,12,13,16,11,14,13,16,12,12,16,16,14,15,16,16,13,13,8,14,10,13,9,13,11,12,11,15,12,14,11,14,12,12,16,16,15,16,15,16,14,14,10,15,10,13,11,14,11,12,11,15,11,14,12,14,12,12,15,16,14,15,14,16,13,13,12,16,11,14,13,16,12,12,12,16,11,14,13,15,12,12,15,16,12,14,15,16,13,13,11,16,12,14,10,14,11,12,13,16,13,16,12,14,12,13,16,16,16,16,15,16,14,13,12,16,13,15,12,14,12,13,13,16,13,15,12,14,12,13,16,16,14,16,13,15,13,13,15,16,14,16,14,16,13,13,14,16,13,15,13,16,13,13,14,16,12,14,13,14,12,12,9,16,11,14,11,15,12,13,13,16,12,14,12,15,13,13,16,16,14,15,15,15,14,13,11,16,11,14,12,16,12,13,13,16,12,14,13,16,13,13,16,16,14,15,16,16,14,13,11,16,10,13,13,16,11,12,14,16,11,14,14,16,12,12,16,16,14,14,16,16,13,12,11,16,12,14,11,15,12,13,13,16,13,15,13,16,13,13,16,16,15,16,15,16,14,13,11,16,12,15,12,16,12,13,13,16,13,15,13,16,13,13,16,16,15,16,15,16,14,13,12,16,11,14,13,16,12,12,13,16,11,14,13,16,12,12,16,16,13,14,15,16,12,12,11,16,12,14,10,14,11,12,14,16,13,15,12,15,12,12,16,16,16,16,14,15,13,12,12,16,13,15,12,14,12,12,13,16,13,15,12,14,12,12,16,16,14,16,14,15,12,12,14,16,13,15,13,16,11,12,13,16,12,14,13,15,11,11,14,16,12,13,12,13,11,10,0,8,4,9,5,10,9,11,5,11,9,12,9,13,12,16,16,16,16,16,16,16,16,16,4,11,6,12,9,13,11,13,9,16,10,16,12,16,13,16,16,16,16,16,16,16,16,16,12,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,12,8,13,7,12,11,16,8,16,11,16,11,16,15,16,16,16,16,16,16,16,16,16,8,16,10,16,11,16,13,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,10,6,11,7,12,10,13,7,12,10,13,10,16,12,16,16,16,16,16,16,16,16,16,5,13,7,12,10,16,12,16,10,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,11,16,11,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,5,13,9,16,8,16,12,16,9,16,12,16,11,16,16,16,16,16,16,16,16,16,16,16,9,16,11,16,12,16,13,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,9,16,10,16,13,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,16,16,8,16,9,16,12,16,13,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,11,16,13,16,12,16,13,16,13,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,13,16,16,16,11,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,7,16,11,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,11,16,13,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,7,4,8,4,8,7,8,6,10,7,10,8,10,9,10,13,16,13,15,13,15,13,14,4,10,5,10,7,10,9,10,7,12,8,11,9,12,10,11,13,16,13,15,13,16,13,14,9,16,9,13,12,16,11,13,11,16,11,14,13,16,12,14,15,16,14,16,15,16,14,14,4,10,7,10,6,10,9,10,8,12,9,12,9,11,10,12,13,16,13,16,14,16,13,14,7,12,8,12,9,12,10,12,9,13,10,13,10,13,11,12,14,16,13,16,14,16,13,14,12,16,11,14,13,16,12,14,13,16,12,16,14,16,13,14,16,16,14,16,15,16,14,14,10,16,12,15,10,14,12,13,12,16,13,16,12,14,13,14,15,16,14,16,14,16,14,14,12,16,13,16,12,16,13,14,13,16,13,16,13,16,13,14,16,16,14,16,15,16,14,15,15,16,14,16,15,16,13,15,16,16,14,16,15,16,14,15,16,16,16,16,16,16,15,15,2,9,5,10,6,10,8,10,7,11,8,11,9,11,10,11,14,16,13,15,14,15,14,14,5,11,6,11,8,12,9,11,8,13,9,12,10,13,11,12,14,16,13,15,14,16,14,14,9,16,8,13,12,16,11,13,12,16,11,14,13,16,12,13,16,16,14,16,15,16,14,15,5,12,8,11,7,11,9,11,9,13,10,13,10,13,11,12,14,16,14,16,14,16,14,15,8,13,9,13,10,13,11,12,9,13,10,13,10,13,11,13,13,16,13,15,13,16,13,14,12,16,11,14,13,16,12,14,12,16,11,14,13,16,12,14,14,16,13,16,14,16,13,14,10,16,12,15,9,14,11,13,12,16,13,16,12,15,12,14,16,16,15,16,15,16,14,14,12,16,13,16,12,16,12,14,12,16,13,16,12,15,13,14,15,16,14,16,14,16,14,14,15,16,14,16,14,16,14,15,14,16,13,16,14,16,13,14,16,16,14,16,14,16,13,14,6,14,9,13,9,14,11,12,10,14,11,13,11,14,12,13,16,16,15,16,15,16,14,15,8,15,9,13,11,14,11,13,11,16,11,14,12,15,12,14,16,16,15,16,16,16,15,16,10,16,9,14,12,16,12,13,13,16,11,15,14,16,13,14,16,16,15,16,16,16,15,16,8,15,10,13,10,14,11,13,11,16,12,14,12,14,12,14,16,16,16,16,16,16,15,16,10,16,11,14,11,15,12,13,11,16,11,14,12,15,12,14,16,16,14,16,15,16,14,15,12,16,11,15,13,16,13,14,12,16,11,14,13,16,13,14,15,16,13,16,16,16,14,15,10,16,12,15,10,15,12,13,13,16,13,16,12,16,13,14,16,16,16,16,16,16,15,15,12,16,13,16,12,16,13,14,12,16,13,16,12,16,13,14,16,16,15,16,14,16,14,15,15,16,14,16,15,16,14,15,14,16,13,16,14,16,13,14,14,16,13,15,14,16,13,14,9,16,11,16,11,16,12,14,13,16,12,16,13,16,13,14,16,16,15,16,16,16,15,15,11,16,11,16,12,16,13,14,13,16,12,16,13,16,13,14,16,16,15,16,16,16,15,15,11,16,10,15,13,16,12,13,14,16,12,16,14,16,13,14,16,16,15,16,16,16,14,14,11,16,12,16,11,16,13,14,13,16,13,16,13,16,13,14,16,16,16,16,16,16,15,15,11,16,12,16,12,16,13,14,13,16,13,16,13,16,13,14,16,16,15,16,16,16,15,14,12,16,12,15,13,16,12,14,13,16,12,16,14,16,13,14,16,16,14,16,16,16,14,14,11,16,12,16,11,16,12,14,14,16,14,16,12,16,13,14,16,16,16,16,16,16,15,14,12,16,13,16,12,16,12,14,13,16,13,16,12,16,13,14,16,16,16,16,15,16,14,14,14,16,13,16,14,16,12,14,13,16,13,16,13,16,12,13,15,16,13,14,14,15,13,13,0,8,4,10,5,11,10,16,5,12,9,16,10,16,16,16,16,16,16,16,16,16,16,16,4,12,7,12,9,16,12,16,9,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,12,9,16,8,16,12,16,8,16,11,16,11,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,12,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,11,6,12,7,16,11,16,7,16,10,16,11,16,16,16,16,16,16,16,16,16,16,16,5,16,7,16,10,16,12,16,9,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,10,16,8,16,12,16,9,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,9,16,11,16,12,16,16,16,10,16,12,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,9,16,10,16,16,16,11,16,12,16,16,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+652416);
/* memory initializer */ allocate([16,16,16,16,16,16,16,16,8,16,9,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,11,16,11,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,10,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,9,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,12,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,8,4,10,5,9,8,10,6,11,8,12,8,11,10,13,14,16,14,16,14,16,16,16,3,11,5,11,8,12,10,12,7,12,9,13,10,13,11,13,14,16,14,16,16,16,16,16,9,16,9,16,12,16,12,16,11,16,11,16,14,16,13,16,16,16,16,16,16,16,16,16,4,11,7,12,6,11,10,12,8,13,9,13,9,13,11,14,13,16,14,16,14,16,16,16,7,13,9,13,9,13,11,13,9,14,10,16,11,16,12,16,15,16,14,16,16,16,16,16,12,16,12,16,14,16,13,16,13,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,10,16,13,16,12,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,12,16,13,16,13,16,14,16,13,16,14,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,2,10,5,11,6,11,9,11,7,12,9,13,9,13,11,13,14,16,16,16,16,16,16,16,4,12,6,12,8,13,10,13,8,13,9,13,11,16,12,16,16,16,16,16,16,16,16,16,9,16,8,16,12,16,12,16,12,16,11,16,13,16,13,16,16,16,16,16,16,16,16,16,5,12,8,13,7,13,10,13,8,14,10,14,10,14,12,14,16,16,16,16,16,16,16,16,7,14,9,16,10,16,11,14,8,14,10,16,11,16,12,16,13,16,14,16,16,16,16,16,11,16,11,16,13,16,13,16,12,16,12,16,14,16,14,16,16,16,16,16,16,16,16,16,9,16,12,16,10,16,12,16,12,16,13,16,12,16,14,16,16,16,16,16,16,16,16,16,12,16,13,16,12,16,14,16,12,16,13,16,12,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,8,16,9,16,11,13,10,16,11,16,11,16,13,16,16,16,16,16,16,16,16,16,7,16,9,16,10,16,12,16,11,16,11,16,12,16,13,16,16,16,16,16,16,16,16,16,10,16,9,16,12,16,13,16,13,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,7,16,10,16,9,16,12,16,11,16,12,16,12,16,13,16,16,16,16,16,16,16,16,16,9,16,11,16,11,16,12,16,11,16,12,16,13,16,13,16,16,16,16,16,16,16,16,16,12,16,12,16,14,16,14,16,12,16,12,16,14,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,10,16,13,16,13,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,12,16,13,16,12,16,14,16,12,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,11,16,11,16,13,16,12,16,13,16,13,16,15,16,16,16,16,16,16,16,16,16,10,16,11,16,13,16,13,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,11,16,11,16,14,16,13,16,14,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,12,16,12,16,13,16,13,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,11,16,12,16,13,16,14,16,13,16,13,16,14,16,16,16,16,16,16,16,16,16,16,16,12,16,12,16,14,16,14,16,14,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,11,16,14,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,12,16,14,16,13,16,14,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,10,4,12,5,16,11,16,6,16,10,16,11,16,16,16,16,16,16,16,16,16,16,16,3,16,7,16,10,16,16,16,9,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,4,16,10,16,9,16,16,16,9,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,12,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,16,6,16,8,16,16,16,8,16,11,16,12,16,16,16,16,16,16,16,16,16,16,16,5,16,8,16,11,16,16,16,10,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,11,16,9,16,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,12,16,16,16,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,16,9,16,11,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,16,11,16,15,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,9,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,3,3,3,3,3,4,4,4,4,4,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,6,0,0,60,0,67,0,76,0,85,0,96,0,108,0,121,0,136,0,152,0,171,0,192,0,216,0,242,0,16,1,49,1,85,1,127,1,176,1,225,1,32,2,94,2,171,2,255,2,86,3,195,3,50,4,188,4,112,5,30,6,172,6,186,7,163,8,1,0,0,0,2,0,0,1,8,48,0,0,64,48,0,0,8,48,0,0,8,192,0,0,0,8,0,0,8,1,0,0,16,48,0,0,32,48,0,0,8,240,0,0,8,48,0,1,47,0,98,0,139,1,47,6,191,24,255,35,0,0,0,0,6,7,9,11,13,14,0,0,1,3,3,4,4,5,6,6,6,7,7,7,8,8,9,9,9,9,10,10,10,11,11,11,10,10,10,12,13,14,15,15,1,2,3,5,5,6,6,7,7,8,8,9,10,10,10,11,11,11,12,12,13,13,13,13,13,13,13,14,16,16,16,16,1,2,3,4,5,6,8,8,9,9,10,10,11,12,12,12,13,13,14,14,14,14,16,16,14,16,16,16,14,16,16,16,1,2,3,4,5,6,8,8,9,9,10,10,11,12,12,12,13,13,16,16,16,16,16,16,16,16,14,12,16,16,16,16,1,2,3,4,5,7,7,8,8,9,10,10,12,11,13,12,15,13,14,13,12,15,14,13,12,12,10,11,16,16,16,16,1,2,4,4,5,5,6,7,7,7,8,8,8,9,9,10,10,10,10,11,11,11,11,12,11,11,11,13,14,15,16,16,1,2,3,5,5,6,6,7,7,8,9,9,9,10,10,10,11,11,12,12,12,12,13,13,12,12,13,14,16,16,16,16,1,2,3,4,6,6,7,7,8,8,9,9,10,10,11,12,12,12,13,13,13,14,14,15,14,14,16,16,16,16,16,16,1,2,3,4,5,6,8,8,9,9,10,10,11,11,12,12,13,13,15,15,16,16,16,16,16,16,16,16,16,16,16,16,1,2,3,4,5,6,7,8,9,10,11,13,14,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,2,3,4,5,6,7,8,10,10,11,11,13,12,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,1,2,3,4,5,6,7,8,10,10,10,11,14,13,15,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,7,9,9,8,9,8,9,8,9,9,8,8,8,8,8,4,7,10,11,10,11,10,12,10,12,11,11,10,11,10,10,7,10,11,15,12,15,12,15,12,15,14,14,12,14,12,14,9,7,11,10,10,12,11,11,10,11,12,10,10,11,10,10,7,8,12,12,11,13,12,12,10,13,13,12,10,12,11,11,7,11,13,15,11,15,13,15,12,16,14,14,12,15,13,13,9,10,15,11,12,15,14,14,12,15,15,12,12,14,14,12,9,11,15,13,12,16,15,14,12,15,15,13,12,15,14,13,9,13,15,14,10,16,15,16,11,16,16,15,12,16,15,15,9,7,11,11,11,11,10,11,10,11,12,11,10,10,10,10,7,9,12,13,12,12,11,13,10,13,13,12,11,12,10,11,7,12,13,16,14,15,12,16,12,16,15,15,13,15,12,14,9,9,13,13,12,13,12,13,11,13,13,12,11,12,11,11,7,9,13,13,12,13,12,13,11,13,13,13,11,12,11,11,7,12,14,15,13,16,13,15,11,16,14,15,12,15,12,13,8,12,16,14,14,16,15,15,13,16,15,14,13,15,14,13,9,12,15,14,13,15,14,15,12,16,15,14,12,14,13,13,8,13,16,16,12,16,14,16,11,16,16,15,12,16,14,14,8,10,15,15,15,12,12,14,12,14,15,15,14,12,12,13,9,11,15,16,14,13,12,15,12,16,15,15,14,14,12,13,9,14,15,16,16,15,11,16,12,16,16,16,15,16,12,15,9,12,16,16,15,14,14,14,13,16,16,15,14,14,13,13,9,12,15,15,14,14,13,15,12,16,15,14,13,14,13,13,8,13,16,16,15,16,12,16,11,16,16,16,14,16,13,14,8,14,16,16,16,16,16,15,14,16,16,16,15,16,15,14,11,13,16,16,15,16,15,15,12,16,16,16,14,15,14,14,9,14,16,16,13,16,14,16,10,16,16,16,13,16,14,14,8,7,12,11,11,11,11,12,10,11,11,10,10,10,10,10,7,9,13,13,12,13,12,13,11,13,13,12,11,12,11,11,8,12,14,16,14,16,14,16,13,16,14,15,13,15,13,14,9,9,13,12,12,13,12,13,11,12,13,11,10,12,11,11,7,9,13,13,12,13,12,13,11,13,13,12,11,12,11,11,7,12,14,16,13,16,14,15,12,15,15,14,12,15,13,13,8,11,15,13,14,15,15,14,13,15,15,12,12,14,14,12,9,11,15,14,13,15,14,14,12,15,14,13,11,14,13,12,8,13,16,15,12,16,15,16,12,16,16,14,11,15,14,14,8,8,13,13,12,12,12,13,11,12,13,12,11,11,10,10,7,9,13,14,12,13,12,13,11,13,13,13,11,12,11,11,7,12,14,16,14,15,13,15,12,15,15,15,13,14,12,13,8,9,13,13,12,13,12,13,11,13,13,12,11,12,11,11,7,9,13,12,12,13,12,12,10,13,13,12,10,12,10,10,6,11,14,14,12,14,12,14,11,14,14,13,11,13,11,12,7,12,16,14,14,15,15,14,13,15,15,13,12,14,13,12,8,11,14,13,12,14,13,13,11,14,14,13,11,13,12,11,7,11,14,14,12,15,13,14,11,15,14,13,11,14,12,12,6,11,16,15,15,13,14,15,13,14,15,15,13,12,12,12,9,12,15,15,14,14,13,15,12,15,15,14,13,13,11,12,8,13,16,16,15,16,13,16,13,16,16,15,14,14,12,14,8,11,16,15,14,14,14,14,13,15,15,14,13,13,12,12,8,11,14,14,13,13,12,14,11,14,14,13,12,12,11,11,7,12,14,15,13,14,12,14,11,15,14,14,12,13,11,12,7,13,16,16,16,16,15,16,14,16,16,15,14,15,14,13,9,12,15,14,13,15,13,14,12,15,15,13,12,13,12,12,7,11,15,14,12,14,13,14,10,15,14,13,11,13,11,11,5,10,15,15,15,15,14,15,13,12,14,12,12,12,13,12,9,12,16,16,15,16,15,16,14,14,15,14,13,14,13,13,9,14,16,16,16,16,16,16,15,16,16,16,14,16,14,15,11,11,15,15,14,15,15,15,14,14,15,12,12,13,13,12,9,12,15,15,14,16,14,15,13,14,14,13,12,14,13,12,8,13,16,16,15,16,16,16,14,16,16,15,12,16,14,14,9,13,16,14,16,16,16,16,15,15,16,11,12,16,15,12,9,13,16,15,14,16,15,16,14,15,16,12,11,15,14,13,8,13,16,16,13,16,16,16,13,16,16,13,11,16,14,14,8,11,15,15,15,14,14,15,13,13,15,14,13,12,12,12,9,11,15,16,14,15,14,15,13,14,14,14,13,13,12,13,8,13,16,16,16,16,15,16,14,16,16,16,13,15,12,14,9,11,16,15,14,14,14,15,13,14,14,13,12,13,12,11,8,11,14,14,13,14,13,14,12,13,13,12,11,12,11,11,7,12,15,15,13,15,14,15,12,15,14,14,11,13,12,12,7,13,16,15,15,16,16,16,14,15,16,12,12,14,14,12,8,11,15,14,13,15,13,14,12,14,14,12,11,13,12,11,6,11,14,14,12,15,13,14,11,15,14,12,10,13,11,11,5,12,16,16,16,15,15,16,15,14,16,15,15,10,12,12,9,13,16,16,16,15,14,16,13,15,15,15,14,12,11,13,8,14,16,16,16,16,14,16,13,16,16,16,14,14,11,14,8,13,16,16,15,15,15,15,14,15,16,14,13,12,12,11,8,11,15,15,13,14,13,14,12,14,14,13,12,12,11,11,6,11,15,15,13,15,12,14,11,14,14,13,11,12,10,11,5,13,16,16,15,16,16,16,14,16,16,14,14,14,13,11,8,11,14,14,13,14,13,14,11,14,14,12,11,12,11,10,5,10,13,13,11,13,12,13,9,13,13,12,9,12,10,10,3,5,7,7,7,7,7,8,7,7,8,7,7,7,7,7,4,7,9,11,9,11,9,11,9,11,10,10,9,10,9,10,6,11,11,14,11,14,11,14,11,15,13,14,12,14,12,13,9,6,11,10,9,11,10,11,9,11,11,9,9,10,10,9,6,8,11,11,10,12,11,12,10,12,12,11,10,12,11,11,7,11,13,14,11,15,13,15,11,15,14,14,12,14,13,13,9,10,14,11,11,15,14,13,12,14,14,11,11,14,13,12,9,11,14,13,11,15,14,14,11,15,15,13,11,14,14,13,9,12,14,14,10,16,15,16,11,16,16,15,11,16,15,14,9,6,10,11,10,10,9,11,9,10,11,10,10,9,9,9,6,9,12,12,11,12,10,12,10,12,12,12,11,11,10,11,7,12,13,15,13,14,11,15,11,15,15,14,13,14,12,14,9,9,12,12,11,12,11,12,11,12,13,11,11,12,11,11,7,9,12,12,11,13,11,12,10,13,13,12,11,12,11,11,7,12,14,15,12,15,12,14,11,15,15,14,12,14,13,13,8,12,15,14,13,15,14,14,13,16,16,14,13,15,14,13,9,12,15,14,13,15,14,14,12,15,15,13,12,14,13,13,9,13,15,15,12,16,14,15,11,16,16,15,12,15,14,14,9,10,14,14,14,12,11,13,12,14,15,14,13,12,11,12,9,12,14,15,14,13,11,14,12,15,15,15,14,13,11,13,9,13,15,16,15,14,11,16,11,16,16,16,14,15,12,15,9,12,15,15,14,14,14,14,13,15,15,14,14,14,13,13,9,12,15,15,14,14,13,14,12,15,15,14,13,14,13,13,9,13,15,16,14,15,13,16,11,16,16,15,14,15,13,14,9,14,16,16,16,16,16,15,14,16,16,16,16,16,16,14,11,14,16,16,14,16,15,15,12,16,16,16,14,15,14,14,9,14,16,16,14,16,14,16,11,16,16,16,14,16,14,14,9,6,11,10,10,10,10,11,10,10,11,9,9,9,9,9,6,9,12,12,11,13,11,13,11,12,12,11,11,12,11,11,7,12,14,16,13,16,14,16,13,15,14,15,12,15,13,14,9,8,12,11,11,12,12,12,11,11,12,10,10,11,11,10,7,9,12,12,11,13,12,13,11,13,12,11,10,12,11,11,7,12,14,15,12,15,14,15,12,15,14,14,12,14,13,13,9,11,15,13,13,15,14,14,13,14,15,11,11,14,14,12,9,11,14,13,12,15,14,14,12,14,14,12,11,14,13,12,8,13,15,15,12,16,15,15,12,15,15,14,11,15,14,14,8,8,12,12,11,11,11,12,11,11,12,11,11,10,10,10,7,9,13,13,12,13,11,13,11,12,13,12,11,11,10,11,7,12,14,15,14,15,13,15,12,15,14,14,13,14,12,13,9,9,13,12,12,12,12,12,11,12,13,11,11,11,11,10,7,9,12,12,11,12,11,12,10,12,12,11,10,11,10,10,7,11,13,14,12,14,12,14,11,14,13,13,11,13,11,12,7,12,15,14,13,15,14,14,13,15,15,13,12,13,13,12,9,11,14,13,12,14,13,13,11,14,14,12,11,13,12,11,7,11,14,14,12,14,13,14,11,14,14,13,11,13,12,12,7,11,15,15,14,13,13,14,13,14,15,14,13,11,11,12,9,12,15,15,14,14,12,14,12,14,14,14,13,12,11,12,8,13,16,16,15,15,12,16,13,16,15,15,14,14,12,14,9,12,15,15,14,14,14,14,13,15,15,14,13,12,12,12,9,11,14,14,13,13,12,13,11,14,13,13,12,12,11,11,7,12,14,15,13,14,12,14,11,15,14,13,12,13,11,12,7,13,16,16,15,16,15,15,14,16,16,15,14,14,14,12,9,12,15,14,13,14,13,14,12,15,14,13,12,13,12,12,8,12,14,14,13,15,13,14,11,14,14,13,12,13,12,12,6,10,14,14,13,14,14,14,13,12,13,12,12,12,12,11,9,12,15,15,14,15,14,16,14,14,14,13,12,14,13,13,9,14,16,16,16,16,16,16,15,16,16,16,14,16,14,16,11,11,15,14,14,15,14,14,14,13,14,11,12,13,13,12,9,12,15,14,14,15,14,15,13,14,14,13,12,14,13,13,9,13,16,16,14,16,15,16,14,16,15,15,12,16,14,14,9,13,16,14,15,16,16,16,14,14,16,11,12,15,14,12,9,13,16,15,14,16,15,16,14,15,15,12,11,15,14,13,9,14,16,16,13,16,16,16,14,16,15,13,11,16,14,14,9,11,15,15,14,14,14,14,13,13,14,13,13,11,11,11,9,12,15,15,14,15,14,15,13,14,14,13,13,13,12,12,9,13,16,16,16,16,14,16,14,16,15,16,14,15,12,14,9,11,15,14,14,15,14,14,13,14,14,12,12,12,12,11,8,11,14,14,13,14,13,13,12,13,13,12,11,12,11,11,7,12,14,15,13,15,13,14,13,14,14,13,12,13,12,12,8,13,16,15,15,16,15,15,14,15,16,12,12,14,14,11,9,12,15,14,13,15,13,14,12,14,14,12,11,13,12,11,7,12,14,14,13,15,13,14,12,15,14,13,10,13,12,12,6,12,16,16,15,14,14,15,14,13,15,14,14,10,11,11,9,13,16,16,15,15,14,15,14,15,15,15,14,12,11,12,8,14,16,16,16,16,14,16,14,16,15,15,14,14,11,14,8,12,16,16,15,15,14,15,14,14,16,14,14,12,12,11,8,11,14,14,13,14,13,14,12,14,14,13,12,12,11,11,7,12,14,15,13,14,13,14,12,14,14,13,12,13,11,12,6,14,16,16,16,16,16,15,14,16,16,14,13,13,13,11,8,12,15,15,13,15,13,14,12,14,14,13,12,13,12,10,6,11,14,13,12,14,12,13,10,14,13,12,10,12,10,10,4,4,6,6,6,6,6,7,6,6,7,6,6,6,6,6,3,6,9,10,9,10,9,11,9,10,10,10,9,10,9,10,6,10,11,14,11,14,11,14,11,14,13,14,11,14,11,13,9,6,10,9,9,10,10,10,9,10,11,9,9,10,10,9,6,8,11,11,9,12,11,12,10,12,12,11,10,12,11,11,7,11,13,14,11,15,13,15,11,15,14,14,11,15,13,14,9,10,13,11,11,14,14,13,11,14,14,11,11,13,13,11,9,11,14,12,11,15,14,14,11,15,15,13,11,14,14,13,9,12,14,13,10,16,15,16,11,16,16,14,11,16,14,14,9,6,10,10,10,9,9,10,9,10,11,10,10,9,9,9,6,8,11,12,11,11,10,12,10,12,12,12,11,11,10,11,7,11,13,15,13,14,11,15,11,15,14,14,13,14,12,14,9,8,12,12,12,12,12,12,11,12,13,11,11,11,11,11,8,9,12,12,11,12,12,13,11,13,13,12,11,12,11,11,8,11,14,15,13,14,13,15,11,15,15,14,13,15,13,14,9,12,16,14,14,15,15,14,12,15,16,14,13,14,14,13,10,11,15,14,13,15,14,15,12,15,16,14,13,15,14,13,9,13,15,15,12,16,15,16,12,16,16,15,13,15,14,14,9,10,14,14,14,11,11,13,11,14,14,14,13,11,11,11,9,11,14,15,14,13,11,14,12,15,15,15,14,13,11,13,9,13,14,16,15,14,11,16,12,16,16,16,14,15,12,15,10,12,16,15,15,14,14,14,12,16,16,14,14,14,13,13,10,12,15,15,14,14,13,14,12,15,16,14,14,14,13,13,9,13,16,16,14,16,13,16,12,16,16,16,14,16,13,15,10,14,16,16,16,16,16,15,14,16,16,16,16,16,16,14,11,13,16,16,15,16,16,16,13,16,16,16,15,16,15,14,10,14,16,16,14,16,14,16,12,16,16,16,15,16,15,15,10,6,10,10,10,10,10,11,10,9,10,9,9,9,9,9,6,9,12,12,11,12,11,13,11,12,12,11,10,12,11,11,8,12,14,15,14,15,14,16,13,15,14,14,12,15,13,14,10,8,12,11,11,12,12,12,11,11,12,10,10,11,11,10,7,9,12,12,11,13,12,13,11,12,13,11,10,12,12,11,8,11,14,14,13,15,14,15,13,15,14,14,12,15,13,14,9,11,15,12,13,15,15,14,13,14,15,11,11,14,14,12,9,11,14,13,13,15,14,15,13,15,15,13,11,15,14,13,9,13,15,15,12,16,15,16,13,16,15,14,11,16,15,14,9,8,12,12,11,11,11,12,11,11,12,11,11,9,10,10,7,9,12,13,12,12,11,13,11,12,13,12,12,11,11,11,8,12,14,15,14,15,13,16,13,15,14,15,13,14,12,14,9,9,13,12,12,12,12,13,12,12,13,11,11,11,11,10,8,9,12,12,12,12,12,13,11,12,13,11,11,12,11,11,7,11,13,14,13,14,13,15,12,14,14,14,12,14,12,13,8,12,15,14,14,15,15,14,13,15,16,13,13,14,14,12,9,11,14,13,13,14,14,14,12,14,15,13,12,14,13,12,8,11,14,14,13,15,14,15,12,15,15,14,12,14,13,13,8,11,14,14,14,13,13,14,13,13,14,14,13,11,11,11,9,11,15,15,14,14,13,15,13,14,15,14,14,13,11,13,9,13,16,16,16,15,13,16,13,16,16,16,15,15,12,15,10,11,15,15,15,14,14,14,13,15,15,14,14,13,13,12,9,11,14,14,13,13,13,14,12,14,14,13,13,13,12,12,8,12,15,15,14,15,13,15,12,15,15,14,13,14,12,13,8,13,16,16,16,16,16,16,14,16,16,15,15,15,15,13,10,12,15,15,14,15,14,15,13,15,16,14,13,14,14,13,9,12,15,15,14,15,14,15,12,15,15,14,13,14,13,13,8,10,14,13,13,14,13,14,13,11,13,11,11,11,11,11,9,12,15,16,14,15,14,16,14,14,14,14,13,14,13,13,10,14,16,16,16,16,16,16,16,16,15,16,13,16,14,16,11,11,15,14,14,15,14,15,14,13,14,11,12,13,13,11,9,12,15,15,14,15,15,16,14,14,14,13,12,14,13,13,9,13,16,16,15,16,16,16,15,16,15,15,12,16,14,15,10,12,16,14,15,16,16,16,14,14,16,11,12,14,15,12,9,13,16,15,14,16,16,16,14,15,16,13,12,15,15,13,9,14,16,16,14,16,16,16,15,16,16,14,12,16,15,15,10,11,14,14,14,14,14,14,13,12,14,13,13,11,11,11,9,11,15,15,14,14,14,16,14,14,14,14,13,13,12,13,9,13,16,16,16,16,15,16,15,16,15,16,14,15,13,15,10,11,15,15,14,14,14,15,14,14,15,13,13,12,13,11,9,11,14,14,13,14,14,14,13,13,14,13,12,13,12,12,8,12,15,15,14,16,14,16,14,15,15,15,13,14,13,14,9,13,16,15,16,16,16,16,15,15,16,13,13,14,14,12,9,12,15,14,14,15,15,15,13,14,15,13,12,14,13,12,8,12,15,14,14,15,15,15,13,15,15,14,12,14,13,13,8,12,16,15,15,13,14,15,14,13,15,14,14,10,11,11,9,12,16,16,15,15,14,16,14,15,15,15,14,13,12,13,9,14,16,16,16,16,14,16,15,16,15,16,15,14,12,15,10,12,16,15,15,15,15,15,14,15,16,14,14,12,13,11,9,11,15,15,14,14,14,15,13,14,15,14,13,13,12,12,8,12,15,15,14,15,14,15,13,15,15,14,13,14,12,13,8,14,16,16,16,16,16,16,15,16,16,14,14,14,14,11,9,12,15,15,14,15,15,15,13,15,15,14,13,14,13,12,8,11,14,14,13,14,13,14,12,13,14,13,12,13,12,12,7,2,6,6,5,6,6,7,6,6,7,6,6,6,6,6,3,6,9,10,9,10,9,11,9,10,10,10,9,10,9,10,7,10,11,14,11,14,11,14,11,14,13,14,12,14,12,13,9,6,10,9,9,10,10,10,9,10,11,9,9,10,10,9,7,8,11,11,9,12,11,12,10,12,12,11,10,12,11,11,8,11,13,14,11,16,13,15,12,16,14,14,12,15,13,14,10,10,13,11,11,14,14,13,11,13,14,11,11,13,13,11,9,11,13,13,11,15,14,14,12,15,15,13,12,15,14,13,10,12,14,14,11,16,15,16,12,16,16,15,12,16,15,15,10,6,10,10,10,9,9,10,9,10,11,10,10,9,9,9,7,8,11,12,11,11,10,12,10,12,12,12,11,11,10,11,8,12,13,16,13,14,11,16,12,16,15,15,13,14,12,14,10,9,13,12,12,12,12,12,11,13,13,12,12,12,12,11,8,10,13,13,12,13,12,13,11,14,14,13,12,13,12,12,9,12,14,16,13,15,13,15,12,16,16,16,13,16,14,14,10,12,16,14,14,16,15,14,13,16,16,14,14,15,15,13,11,12,16,15,14,16,15,15,12,16,16,15,14,16,15,14,10,14,16,16,14,16,15,16,13,16,16,16,14,16,16,15,11,10,14,14,13,11,11,13,12,14,14,13,13,11,11,12,9,12,14,16,14,13,11,14,12,16,15,15,14,14,12,13,10,13,14,16,15,14,11,16,12,16,16,16,15,16,13,15,11,12,16,15,15,14,14,14,13,16,16,15,15,14,14,13,11,13,16,16,15,14,14,15,13,16,16,16,15,15,14,14,11,14,16,16,15,16,14,16,13,16,16,16,15,16,14,15,11,15,16,16,16,16,16,16,14,16,16,16,16,16,16,14,12,15,16,16,16,16,16,16,13,16,16,16,16,16,16,15,12,15,16,16,15,16,15,16,13,16,16,16,16,16,16,16,11,6,10,10,10,10,10,11,10,9,10,9,9,9,9,9,7,9,12,13,12,13,12,14,12,12,12,12,11,12,11,11,8,12,14,16,14,16,14,16,14,15,14,15,13,16,13,14,11,8,12,11,11,12,12,12,11,11,12,10,10,11,11,10,8,10,13,13,12,14,13,14,12,13,13,12,11,13,12,12,9,12,15,15,13,16,15,16,14,16,15,15,12,16,14,15,10,11,15,13,13,16,15,14,13,14,15,11,12,14,14,12,10,12,16,14,13,16,16,16,14,16,15,13,12,15,15,14,10,14,16,16,14,16,16,16,14,16,16,15,13,16,16,15,11,8,12,12,12,11,11,12,11,11,12,11,11,9,10,10,8,10,13,14,13,13,12,14,12,13,13,13,12,12,11,12,9,13,15,16,15,16,14,16,14,16,15,16,14,15,13,15,11,10,13,13,13,13,13,13,12,13,14,12,12,12,12,11,9,10,13,13,13,13,13,14,12,13,14,13,12,12,12,12,9,12,15,15,14,16,14,16,13,16,15,15,13,15,13,14,10,13,16,15,15,16,16,15,14,16,16,13,14,15,15,12,10,12,16,14,14,16,16,15,13,16,16,14,13,15,14,13,10,13,16,16,14,16,15,16,13,16,16,16,13,16,15,15,10,11,15,15,14,13,13,14,13,13,15,14,14,11,12,12,10,12,15,16,15,14,13,16,14,16,15,16,14,13,12,13,10,14,16,16,16,16,14,16,14,16,16,16,16,16,13,16,11,12,16,16,16,15,15,15,14,15,16,14,14,13,14,12,10,12,16,16,15,15,14,16,13,16,16,15,14,14,13,13,10,13,16,16,15,16,14,16,13,16,16,16,15,16,14,15,10,15,16,16,16,16,16,16,15,16,16,16,16,16,16,13,12,14,16,16,16,16,16,16,14,16,16,16,15,16,15,14,11,14,16,16,15,16,16,16,13,16,16,16,15,16,15,14,10,10,14,13,13,13,13,14,13,11,13,11,11,11,11,11,9,12,15,16,15,16,15,16,14,14,14,14,13,14,13,14,11,15,16,16,16,16,16,16,16,16,16,16,14,16,14,16,12,11,15,14,14,15,15,15,14,13,14,11,12,13,13,12,10,13,16,15,15,16,16,16,15,15,15,13,12,15,14,13,10,14,16,16,16,16,16,16,16,16,16,16,13,16,16,16,12,13,16,14,15,16,16,16,15,14,16,11,12,15,15,12,10,14,16,16,16,16,16,16,16,16,16,13,13,16,16,14,11,15,16,16,16,16,16,16,16,16,16,16,13,16,16,16,11,11,15,15,14,13,14,14,14,13,14,13,13,11,12,11,10,12,16,16,16,16,15,16,15,15,15,15,14,13,12,14,10,15,16,16,16,16,16,16,16,16,16,16,15,16,14,16,12,12,16,15,15,16,16,16,14,14,15,13,13,13,13,12,10,12,16,16,15,15,15,16,14,14,15,14,13,14,13,13,10,14,16,16,16,16,16,16,15,16,16,16,14,16,14,15,11,14,16,16,16,16,16,16,16,16,16,14,14,15,15,12,11,13,16,16,15,16,16,16,14,16,16,14,13,16,14,13,10,14,16,16,16,16,16,16,15,16,16,16,14,16,14,15,10,12,16,16,15,14,15,16,14,13,15,14,14,11,12,12,10,13,16,16,16,16,15,16,16,16,16,16,15,13,12,14,11,15,16,16,16,16,16,16,16,16,16,16,16,16,13,16,11,14,16,16,16,16,16,16,15,16,16,15,15,13,14,12,11,13,16,16,16,16,16,16,15,16,16,16,14,14,13,13,10,14,16,16,16,16,16,16,15,16,16,16,15,15,14,14,10,15,16,16,16,16,16,16,16,16,16,15,16,15,16,13,11,14,16,16,16,16,16,16,14,16,16,15,14,15,14,13,10,12,15,15,14,15,14,16,14,14,16,15,13,14,13,13,9,2,5,5,5,5,5,6,6,5,6,5,6,5,6,6,4,6,8,10,8,10,9,11,9,10,10,10,9,10,9,10,8,10,11,13,11,13,11,14,11,14,13,13,12,13,12,13,10,6,10,8,9,10,10,10,9,10,11,9,9,10,10,9,7,8,11,11,10,12,11,12,10,12,12,11,10,12,12,11,9,11,13,14,11,15,14,15,12,16,14,14,12,15,14,14,11,10,13,11,11,14,13,13,12,13,14,11,11,13,13,12,10,11,14,13,11,16,14,14,12,15,15,14,12,15,14,14,11,12,14,14,11,16,16,16,13,16,16,16,13,16,16,15,12,6,10,10,10,8,9,10,9,10,11,10,10,9,9,9,8,8,11,12,12,11,10,12,11,12,12,12,12,12,11,12,9,11,13,16,14,14,12,15,12,16,15,16,14,14,13,14,11,9,13,12,12,12,12,12,11,13,13,12,12,12,12,11,10,10,13,13,12,13,12,13,11,14,14,13,13,13,13,12,10,13,14,16,14,15,14,16,13,16,16,16,14,16,14,15,12,12,16,14,14,16,15,14,13,16,16,14,14,15,15,13,12,13,16,15,14,16,16,15,13,16,16,15,14,16,16,14,12,14,16,16,14,16,16,16,14,16,16,16,16,16,16,16,12,10,13,14,13,11,11,13,12,13,14,13,13,11,12,12,10,11,14,15,15,13,12,14,13,16,16,16,15,14,13,14,11,12,14,16,16,14,12,16,13,16,16,16,16,15,13,16,12,12,16,15,16,14,15,14,14,16,16,15,16,14,14,13,12,13,16,16,16,16,14,16,13,16,16,16,16,16,14,15,12,14,16,16,16,16,14,16,14,16,16,16,16,16,15,16,13,15,16,16,16,16,16,16,15,16,16,16,16,16,16,15,13,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,13,15,16,16,16,16,16,16,14,16,16,16,16,16,16,16,13,6,10,10,10,10,10,10,10,8,10,9,9,8,9,9,7,9,12,13,12,13,12,13,12,12,12,12,11,12,11,12,10,12,14,16,14,16,14,16,14,16,15,15,14,16,14,15,12,8,12,11,11,12,12,12,11,11,12,10,10,11,12,10,9,10,13,13,12,14,13,14,12,13,13,12,11,13,13,12,10,13,15,16,14,16,16,16,14,16,15,15,13,16,15,15,12,11,15,13,13,15,15,15,14,14,14,11,12,14,14,12,11,13,16,14,14,16,16,16,14,16,15,13,13,16,14,14,11,14,16,16,14,16,16,16,15,16,16,16,14,16,16,16,12,8,12,12,12,11,11,12,12,11,12,11,11,9,10,10,9,10,13,14,13,13,12,14,13,13,13,13,13,12,11,12,10,13,15,16,15,16,14,16,14,16,16,16,15,16,13,15,12,10,14,13,13,13,13,13,13,13,14,12,12,12,12,11,10,10,13,13,13,13,13,14,12,13,14,13,12,13,12,12,10,13,16,16,14,16,15,16,14,16,16,15,14,16,14,15,11,13,16,15,16,16,16,15,14,16,16,14,14,15,15,13,12,13,16,15,14,16,16,16,14,16,16,14,14,15,15,14,11,14,16,16,15,16,16,16,14,16,16,16,15,16,16,15,12,11,14,15,14,13,13,14,14,13,15,14,14,11,12,12,11,13,16,16,16,14,14,16,14,16,16,16,15,14,13,14,12,14,16,16,16,16,14,16,16,16,16,16,16,16,14,16,13,13,16,16,16,15,16,15,15,16,16,15,16,14,14,13,12,13,16,16,15,15,14,16,14,16,16,16,15,14,14,14,11,14,16,16,16,16,16,16,15,16,16,16,16,16,15,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,15,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,9,13,13,13,13,13,14,13,10,12,11,12,11,12,11,10,12,15,16,15,16,16,16,16,14,14,14,13,14,13,14,12,14,16,16,16,16,16,16,16,16,16,16,15,16,16,16,14,11,15,14,14,15,14,15,14,13,14,11,12,13,13,12,11,13,16,16,15,16,16,16,15,15,15,14,13,16,15,14,12,15,16,16,16,16,16,16,16,16,16,16,14,16,16,16,13,12,16,14,15,16,16,16,16,14,16,11,13,15,16,13,12,14,16,16,16,16,16,16,16,16,16,14,14,16,16,15,12,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,13,11,15,14,14,13,14,15,14,12,14,13,13,11,12,12,11,13,16,16,16,16,15,16,16,15,15,15,15,14,13,14,12,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,13,13,16,16,16,16,16,16,15,14,16,13,14,13,14,13,11,13,16,16,16,16,16,16,15,15,16,15,14,14,14,14,11,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,14,16,16,16,16,16,16,16,16,16,14,15,16,16,13,12,14,16,16,16,16,16,16,16,16,16,14,14,16,16,15,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,11,16,16,15,13,15,16,15,13,15,15,15,11,12,12,11,14,16,16,16,16,16,16,16,16,16,16,16,14,14,15,12,15,16,16,16,16,16,16,16,16,16,16,16,16,14,16,13,14,16,16,16,16,16,16,16,16,16,15,16,14,14,13,12,14,16,16,16,16,16,16,16,16,16,16,16,14,14,14,12,14,16,16,16,16,16,16,16,16,16,16,16,16,15,16,12,15,16,16,16,16,16,16,16,16,16,16,16,15,16,14,13,14,16,16,16,16,16,16,16,16,16,16,16,16,16,15,12,12,14,14,14,14,15,16,14,14,16,15,14,14,15,14,11,1,5,5,6,5,6,7,7,5,7,6,7,5,6,6,6,6,9,10,9,10,9,11,10,11,11,11,10,11,10,11,9,10,11,14,12,14,12,16,12,16,13,16,13,14,13,16,12,6,10,9,9,10,11,11,10,10,11,9,10,10,11,10,9,8,11,11,10,13,12,13,12,13,13,12,12,13,13,13,11,11,13,16,12,16,16,16,13,16,16,16,14,16,16,16,13,10,14,11,12,14,14,13,13,13,16,12,13,14,16,13,12,11,14,13,12,16,16,16,14,16,16,14,14,16,16,16,13,12,14,16,12,16,16,16,16,16,16,16,16,16,16,16,14,6,10,10,11,9,9,11,10,10,11,11,11,9,10,10,9,9,12,13,12,12,11,13,12,13,13,13,13,12,12,13,11,12,13,16,16,16,13,16,14,16,16,16,16,16,14,16,13,9,13,13,13,13,13,13,13,13,14,13,13,13,13,12,11,10,14,14,13,14,13,14,13,16,16,14,15,14,14,14,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,14,14,16,11,12,14,13,14,16,16,16,12,13,13,12,12,16,16,16,13,13,16,14,16,16,16,16,16,14,16,13,13,16,16,16,16,13,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,6,10,10,10,10,11,11,11,9,11,9,10,9,10,10,9,9,13,13,13,13,13,14,13,12,13,13,12,13,12,13,11,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,8,13,12,12,13,13,13,13,11,13,10,12,12,13,12,11,10,14,13,13,16,16,16,14,14,14,13,13,14,14,14,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,11,16,13,16,16,16,16,16,14,16,12,13,16,16,14,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,13,13,13,11,12,13,13,11,13,12,13,10,12,12,11,10,14,16,16,14,13,16,14,14,16,16,14,13,13,14,12,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,10,16,14,16,14,14,14,14,13,16,13,14,13,14,12,12,10,14,14,14,14,16,16,14,14,16,14,14,14,14,14,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,13,16,16,16,14,16,16,16,12,14,14,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,14,13,14,13,14,16,16,11,13,12,13,11,13,12,12,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,14,16,16,16,16,16,13,16,12,13,14,16,13,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,14,16,12,16,16,16,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,14,16,16,16,13,16,14,16,12,13,13,13,13,16,16,16,16,16,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+662656);
/* memory initializer */ allocate([16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,14,16,16,16,14,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,14,16,16,16,14,16,16,16,12,16,14,14,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,1,5,5,6,5,6,7,8,5,7,6,8,6,7,7,7,5,9,10,10,10,10,12,11,10,11,11,11,10,11,12,10,9,11,13,12,13,12,16,14,16,14,16,16,16,13,16,13,5,10,9,10,10,11,11,11,10,11,9,11,10,11,11,10,8,11,11,11,12,13,13,13,12,13,12,12,13,13,13,12,11,13,16,13,16,16,16,16,16,16,16,16,16,16,16,16,9,14,11,12,14,16,13,14,13,16,12,14,16,16,13,13,11,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,11,14,14,13,16,16,16,16,16,16,16,16,16,16,16,16,5,10,11,11,9,10,11,11,10,12,11,12,9,11,11,11,8,12,13,13,11,11,14,13,13,14,13,16,12,12,13,12,11,13,16,16,16,13,16,16,16,16,16,16,16,16,16,16,9,13,12,13,12,13,13,14,13,16,13,16,13,16,13,13,10,14,13,14,13,13,16,14,16,16,16,16,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,14,16,16,11,12,14,16,13,16,16,16,12,14,13,13,11,16,16,16,13,13,16,16,16,16,16,16,16,16,16,16,12,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,5,10,10,11,10,11,12,12,8,11,10,11,9,11,11,11,9,12,13,13,13,13,16,16,12,13,13,13,13,13,16,13,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,13,11,13,12,13,13,14,11,13,10,13,12,14,12,12,10,14,13,14,16,16,16,16,13,16,13,14,16,16,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,13,16,16,16,16,16,13,16,12,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,8,13,13,13,11,13,14,16,11,13,13,14,10,12,12,12,10,14,16,16,13,16,16,16,13,16,16,16,13,13,16,14,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,14,16,13,16,16,16,13,16,13,16,13,16,13,14,10,16,16,16,14,16,16,16,14,16,16,16,13,16,16,13,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,13,16,16,16,14,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,9,14,13,16,13,16,16,16,10,14,12,14,11,13,13,13,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,12,16,12,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,16,16,16,16,13,16,13,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,14,16,16,16,12,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,12,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,11,16,16,16,14,16,16,16,14,16,16,16,12,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,13,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,16,16,16,16,16,16,16,14,16,16,16,16,16,16,14,0,6,6,3,6,4,5,3,6,5,4,3,3,4,4,3,0,6,6,4,6,4,5,3,6,5,4,3,4,4,4,2,0,7,7,4,7,5,5,4,7,5,5,4,5,4,4,1,0,7,7,5,7,5,6,4,7,6,5,3,5,4,4,1,0,6,6,3,6,3,5,4,6,5,3,4,3,4,4,3,0,6,6,4,6,4,4,4,6,4,4,3,4,4,4,2,0,6,6,4,6,4,5,4,6,5,4,3,4,4,3,2,0,7,7,5,7,5,6,4,7,6,5,3,5,4,4,1,0,6,6,3,6,3,5,4,6,5,3,4,3,4,4,3,0,5,5,3,5,4,5,4,5,5,4,4,4,4,4,2,0,6,6,4,6,4,5,3,6,5,4,3,4,4,4,2,0,7,7,5,7,5,6,4,7,6,5,3,5,4,4,1,0,6,6,3,6,3,5,4,6,5,3,4,3,4,4,3,0,5,5,3,5,4,5,4,5,5,4,4,4,4,4,2,0,6,6,4,6,4,5,3,6,5,4,3,4,4,4,2,0,7,7,4,7,5,6,4,7,6,5,4,4,4,4,1,0,5,5,3,5,3,5,4,5,5,3,4,3,4,4,4,0,5,5,3,5,4,5,4,5,5,3,4,3,4,4,3,0,6,6,4,6,4,5,4,6,5,4,3,4,4,3,2,0,7,7,4,7,5,6,4,7,6,5,4,4,4,4,1,0,5,5,3,5,3,5,4,5,5,3,4,3,4,4,4,0,5,5,3,5,4,5,4,5,5,3,4,3,4,4,3,0,5,5,3,5,4,4,4,5,4,4,4,3,4,4,3,0,6,6,4,6,4,5,4,6,5,4,3,4,4,3,2,0,4,4,3,4,3,5,5,4,5,3,5,3,5,4,5,0,4,4,3,4,4,5,4,4,5,3,5,3,5,4,4,0,4,4,3,4,4,5,4,4,5,4,4,3,4,4,4,0,4,4,3,5,4,5,4,5,5,4,4,3,4,4,3,0,0,16,0,0,0,1,0,0,0,17,0,0,0,0,0,0,0,0,1,0,1,1,2,0,1,1,2,1,2,2,3,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,17,18,19,20,20,21,22,22,23,23,24,24,25,25,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,15,16,17,18,18,19,20,20,21,21,22,22,23,23,0,32,16,48,2,34,18,50,1,33,17,49,3,35,19,51,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,22,22,23,23,23,24,24,25,25,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,0,9,9,9,9,9,9,9,9,0,2,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,2,0,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,0,1,9,9,9,9,9,9,9,0,2,1,6,4,8,5,7,3,1,0,2,6,5,4,3,8,7,2,8,0,1,7,4,3,6,5,2,0,1,3,8,5,4,7,6,2,0,1,4,6,7,8,3,5,0,1,5,2,6,3,8,4,7,0,1,6,2,4,7,5,8,3,2,7,0,1,4,8,6,3,5,2,8,0,1,7,3,4,5,6,1,0,9,9,9,9,9,9,9,1,2,5,6,3,0,4,8,7,1,6,2,5,3,0,4,8,7,2,1,7,6,8,3,5,0,4,1,2,5,3,6,8,4,7,0,1,6,2,0,4,5,8,7,3,1,5,2,6,3,8,4,0,7,1,6,0,2,4,5,7,3,8,2,1,7,6,0,8,5,4,3,1,2,7,8,3,4,5,6,0,9,9,9,9,9,9,9,9,9,0,2,1,8,7,6,5,4,3,1,2,0,6,5,7,4,8,3,2,8,7,1,0,6,4,3,5,2,0,8,1,3,7,5,4,6,2,0,4,1,7,8,6,3,5,2,0,1,5,8,4,6,7,3,2,0,6,1,4,7,8,5,3,2,7,8,1,0,5,4,6,3,2,8,7,1,0,4,3,6,5,9,9,9,9,9,9,9,9,9,0,2,1,3,5,8,6,4,7,1,0,2,5,3,6,4,8,7,2,8,1,0,3,5,7,6,4,3,2,5,8,1,4,6,7,0,4,2,0,6,1,5,8,3,7,5,3,1,2,8,6,4,0,7,1,6,0,2,4,5,8,3,7,2,7,0,1,5,4,8,6,3,2,8,3,5,1,0,7,6,4,9,9,9,9,9,9,9,9,9,2,0,6,1,4,7,5,8,3,1,6,2,0,4,5,3,7,8,2,8,7,6,4,0,1,5,3,4,2,1,0,6,8,3,5,7,4,2,6,0,1,5,7,8,3,1,2,5,0,6,3,4,7,8,6,4,0,1,2,7,5,3,8,2,7,4,6,0,1,8,5,3,2,8,7,4,6,1,3,5,0,9,9,9,9,9,9,9,9,9,5,1,2,3,6,8,0,4,7,1,5,6,3,2,0,4,8,7,2,1,5,3,6,8,7,4,0,5,3,1,2,6,8,4,7,0,1,6,2,4,5,8,0,3,7,5,1,3,6,2,0,8,4,7,1,6,5,2,0,4,3,7,8,2,7,1,6,5,0,8,3,4,2,5,1,3,6,8,4,0,7,9,9,9,9,9,9,9,9,9,1,6,2,0,5,4,3,7,8,1,6,5,4,2,3,0,7,8,2,1,6,7,4,8,5,3,0,2,1,6,5,8,4,3,0,7,6,4,1,2,0,5,7,8,3,1,6,5,2,3,0,4,8,7,6,1,4,0,2,7,5,3,8,2,7,4,6,1,5,0,8,3,2,1,6,8,4,7,3,5,0,9,9,9,9,9,9,9,9,9,2,0,4,7,6,1,8,5,3,6,1,2,0,4,7,5,8,3,2,7,8,0,1,6,4,3,5,2,4,0,8,3,1,7,6,5,4,2,7,0,6,1,8,5,3,2,1,0,8,5,6,7,4,3,2,6,4,1,7,0,5,8,3,2,7,4,0,8,6,1,5,3,2,8,7,4,1,0,3,6,5,9,9,9,9,9,9,9,9,9,2,0,8,1,3,4,6,5,7,1,2,0,6,8,5,7,3,4,2,8,7,1,0,3,6,5,4,8,3,2,5,1,0,4,7,6,2,0,4,8,5,1,7,6,3,2,1,0,8,5,3,6,4,7,2,1,6,0,8,4,5,7,3,2,7,8,4,0,6,1,5,3,2,8,3,0,7,4,1,6,5,0,0,0,0,0,0,0,1,1,0,1,1,0,2,2,0,0,3,3,0,1,2,2,1,0,4,4,0,3,1,1,3,0,5,5,0,2,2,1,4,4,1,0,6,3,2,1,5,2,3,5,1,6,0,0,7,4,2,2,4,3,3,6,1,1,6,7,0,0,8,5,2,4,3,2,5,3,4,1,7,4,4,7,1,8,0,6,2,3,5,5,3,2,6,1,8,2,7,7,2,8,1,5,4,4,5,3,6,6,3,8,2,4,6,5,5,6,4,2,8,7,3,3,7,6,5,5,6,7,4,4,7,8,3,3,8,7,5,8,4,5,7,4,8,6,6,7,6,5,8,8,5,6,7,8,6,7,7,6,8,8,7,7,8,8,8,0,0,0,0,0,0,6,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,1,0,0,0,176,63,40,0,112,0,0,0,160,122,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,86,37,0,112,0,0,0,160,122,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,3,3,3,3,3,6,6,6,6,6,6,6,6,9,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,15,232,81,10,0,216,81,10,0,6,6,5,5,4,41,41,41,41,40,40,40,40,40,40,76,6,6,5,5,4,41,41,41,41,40,40,40,40,40,40,76,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,3,3,0,0,0,0,0,0,0,0,0,0,0,2,2,3,3,3,3,0,0,0,0,0,0,0,0,0,0,2,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,3,3,3,3,3,3,3,4,5,6,7,8,9,10,11,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,3,2,3,2,1,0,0,0,0,0,0,0,0,0,0,0,3,0,1,3,2,5,4,0,0,0,0,0,0,0,0,0,7,6,5,4,3,2,1,1,1,1,1,1,1,1,1,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,2,2,1,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,2,2,1,2,1,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,2,2,3,3,2,3,1,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,0,3,1,3,3,3,2,3,5,3,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,3,6,3,5,3,4,3,3,3,2,3,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,67,77,85,0,0,0,0,1,0,0,0,6,0,1,0,64,31,0,0,1,0,0,0,3,0,0,0,71,83,77,0,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,4,0,0,0,71,55,50,51,0,0,0,0,1,0,0,0,53,80,1,0,64,31,0,0,1,0,0,0,5,0,0,0,68,86,73,52,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,6,0,0,0,68,86,73,52,0,0,0,0,1,0,0,0,0,0,0,0,128,62,0,0,1,0,0,0,7,0,0,0,76,80,67,0,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,8,0,0,0,80,67,77,65,0,0,0,0,1,0,0,0,7,0,1,0,64,31,0,0,1,0,0,0,9,0,0,0,71,55,50,50,0,0,0,0,1,0,0,0,28,16,1,0,64,31,0,0,1,0,0,0,10,0,0,0,76,49,54,0,0,0,0,0,1,0,0,0,1,0,1,0,68,172,0,0,2,0,0,0,11,0,0,0,76,49,54,0,0,0,0,0,1,0,0,0,1,0,1,0,68,172,0,0,1,0,0,0,12,0,0,0,81,67,69,76,80,0,0,0,1,0,0,0,24,80,1,0,64,31,0,0,1,0,0,0,13,0,0,0,67,78,0,0,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,14,0,0,0,77,80,65,0,0,0,0,0,1,0,0,0,0,80,1,0,255,255,255,255,255,255,255,255,14,0,0,0,77,80,65,0,0,0,0,0,1,0,0,0,1,80,1,0,255,255,255,255,255,255,255,255,15,0,0,0,71,55,50,56,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,16,0,0,0,68,86,73,52,0,0,0,0,1,0,0,0,0,0,0,0,17,43,0,0,1,0,0,0,17,0,0,0,68,86,73,52,0,0,0,0,1,0,0,0,0,0,0,0,34,86,0,0,1,0,0,0,18,0,0,0,71,55,50,57,0,0,0,0,1,0,0,0,0,0,0,0,64,31,0,0,1,0,0,0,25,0,0,0,67,101,108,66,0,0,0,0,0,0,0,0,0,0,0,0,144,95,1,0,255,255,255,255,26,0,0,0,74,80,69,71,0,0,0,0,0,0,0,0,8,0,0,0,144,95,1,0,255,255,255,255,28,0,0,0,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,95,1,0,255,255,255,255,31,0,0,0,72,50,54,49,0,0,0,0,0,0,0,0,4,0,0,0,144,95,1,0,255,255,255,255,32,0,0,0,77,80,86,0,0,0,0,0,0,0,0,0,1,0,0,0,144,95,1,0,255,255,255,255,32,0,0,0,77,80,86,0,0,0,0,0,0,0,0,0,2,0,0,0,144,95,1,0,255,255,255,255,33,0,0,0,77,80,50,84,0,0,0,0,2,0,0,0,0,0,2,0,144,95,1,0,255,255,255,255,34,0,0,0,72,50,54,51,0,0,0,0,0,0,0,0,5,0,0,0,144,95,1,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,128,62,39,0,112,0,0,0,0,112,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,71,71,32,86,65,71,32,87,65,68,80,88,65,68,80,88,77,65,32,0,0,0,0,18,16,1,0,71,65,68,80,32,68,65,82,82,65,68,80,1,0,1,0,80,67,77,66,0,0,1,0,80,67,77,32,0,0,0,0,0,0,0,0,0,0,1,0,2,0,8,0,9,0,3,0,16,0,10,0,4,0,17,0,11,0,24,0,5,0,18,0,25,0,12,0,19,0,26,0,32,0,6,0,13,0,20,0,33,0,27,0,7,0,34,0,40,0,21,0,28,0,41,0,14,0,35,0,48,0,42,0,29,0,36,0,49,0,22,0,43,0,15,0,56,0,37,0,50,0,44,0,30,0,57,0,23,0,51,0,58,0,45,0,38,0,52,0,31,0,59,0,53,0,46,0,60,0,39,0,61,0,47,0,54,0,55,0,62,0,63,0,0,0,1,0,4,0,2,0,5,0,3,0,6,0,8,0,9,0,7,0,12,0,10,0,13,0,11,0,14,0,15,0,0,0,1,0,2,0,16,0,3,0,17,0,4,0,18,0,32,0,5,0,33,0,19,0,6,0,34,0,48,0,20,0,49,0,7,0,35,0,21,0,50,0,64,0,8,0,36,0,65,0,22,0,51,0,37,0,80,0,9,0,66,0,52,0,23,0,38,0,81,0,67,0,10,0,53,0,24,0,82,0,68,0,96,0,39,0,11,0,54,0,83,0,97,0,69,0,25,0,98,0,84,0,40,0,112,0,55,0,12,0,70,0,99,0,113,0,85,0,26,0,41,0,56,0,114,0,100,0,13,0,71,0,128,0,86,0,27,0,115,0,101,0,129,0,42,0,57,0,72,0,116,0,14,0,87,0,130,0,102,0,144,0,73,0,131,0,117,0,28,0,58,0,15,0,88,0,43,0,145,0,103,0,132,0,146,0,118,0,74,0,160,0,89,0,133,0,104,0,29,0,59,0,147,0,119,0,44,0,161,0,148,0,90,0,105,0,134,0,162,0,120,0,176,0,75,0,135,0,149,0,30,0,60,0,163,0,177,0,45,0,121,0,91,0,106,0,164,0,178,0,150,0,192,0,136,0,165,0,179,0,31,0,151,0,193,0,76,0,122,0,61,0,137,0,194,0,107,0,152,0,180,0,208,0,46,0,166,0,167,0,195,0,92,0,181,0,138,0,209,0,123,0,153,0,224,0,196,0,77,0,168,0,210,0,182,0,240,0,108,0,197,0,62,0,154,0,225,0,183,0,169,0,211,0,47,0,139,0,93,0,184,0,226,0,212,0,241,0,198,0,170,0,124,0,155,0,199,0,78,0,213,0,185,0,109,0,227,0,200,0,63,0,228,0,242,0,140,0,214,0,171,0,186,0,156,0,229,0,243,0,125,0,94,0,201,0,244,0,215,0,216,0,230,0,141,0,187,0,202,0,79,0,172,0,110,0,157,0,245,0,217,0,231,0,95,0,246,0,232,0,126,0,203,0,247,0,233,0,173,0,218,0,142,0,111,0,158,0,188,0,248,0,127,0,234,0,219,0,249,0,189,0,204,0,143,0,174,0,159,0,250,0,235,0,205,0,220,0,175,0,190,0,251,0,221,0,191,0,206,0,236,0,207,0,237,0,252,0,222,0,253,0,223,0,238,0,239,0,254,0,255,0,96,107,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,0,37,0,32,238,37,0,16,0,0,0,5,0,0,0,224,192,37,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,96,188,35,0,32,238,37,0,16,0,0,0,5,0,0,0,224,192,37,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,224,64,32,0,232,158,37,0,24,0,0,0,5,0,0,0,144,122,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,41,40,0,232,158,37,0,24,0,0,0,5,0,0,0,144,122,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,224,200,39,0,88,114,37,0,28,0,0,0,5,0,0,0,24,156,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,80,98,39,0,88,114,37,0,28,0,0,0,5,0,0,0,24,156,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,32,48,37,0,112,8,37,0,44,0,0,0,5,0,0,0,152,224,36,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,8,190,36,0,112,8,37,0,44,0,0,0,5,0,0,0,152,224,36,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,192,160,36,0,120,133,36,0,64,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,107,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,116,35,0,112,0,0,0,152,90,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,60,34,0,112,0,0,0,96,160,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,4,5,6,8,9,10,11,12,13,14,15,16,32,64,73,65,82,76,0,73,65,82,84,0,73,67,77,83,0,73,67,77,84,0,73,67,79,80,0,73,67,82,68,0,73,67,82,80,0,73,68,73,77,0,73,68,80,73,0,73,69,78,71,0,73,71,78,82,0,73,75,69,89,0,73,76,71,84,0,73,76,78,71,0,73,77,69,68,0,73,78,65,77,0,73,80,76,84,0,73,80,82,68,0,73,80,82,84,0,73,84,82,75,0,73,83,66,74,0,73,83,70,84,0,73,83,72,80,0,73,83,77,80,0,73,83,82,67,0,73,83,82,70,0,73,84,67,72,0,0,0,0,0,0,0,0,0,0,72,150,32,0,112,0,0,0,64,135,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,27,0,0,0,30,0,0,0,29,0,0,0,3,0,0,0,2,0,0,0,62,0,0,0,64,0,0,0,44,0,0,0,48,0,0,0,46,0,0,0,50,0,0,0,255,255,255,255,0,0,0,0,0,102,37,0,112,0,0,0,208,168,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,2,0,0,0,28,0,0,0,42,0,0,0,36,1,0,0,0,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,0,248,0,0,224,7,0,0,31,0,0,0,0,0,0,0,0,15,0,0,240,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,75,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,75,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,75,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,152,255,255,255,116,0,0,0,0,0,0,0,116,0,0,0,24,0,0,0,80,0,0,0,24,0,0,0,0,0,0,0,152,255,255,255,116,0,0,0,0,0,0,0,116,0,0,0,1,0,1,1,1,2,2,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,5,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,5,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,184,185,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,185,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,219,33,0,224,207,33,0,224,197,33,0,224,207,33,0,248,188,33,0,176,174,33,0,208,140,33,0,176,174,33,0,216,125,33,0,80,116,33,0,0,0,0,0,0,0,0,0,104,156,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,20,34,0,176,122,33,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,40,1,33,0,176,122,33,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,156,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,2,0,0,0,0,0,0,0,0,0,0,168,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,119,35,0,112,0,0,0,152,98,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,0,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,1,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,2,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,3,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,4,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,5,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,6,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,7,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,8,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,9,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,10,0,0,0,146,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,11,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,164,0,0,0,165,0,0,0,166,0,0,0,167,0,0,0,168,0,0,0,169,0,0,0,12,0,0,0,170,0,0,0,171,0,0,0,172,0,0,0,173,0,0,0,174,0,0,0,175,0,0,0,176,0,0,0,177,0,0,0,178,0,0,0,179,0,0,0,180,0,0,0,181,0,0,0,13,0,0,0,182,0,0,0,183,0,0,0,184,0,0,0,185,0,0,0,186,0,0,0,187,0,0,0,188,0,0,0,189,0,0,0,190,0,0,0,191,0,0,0,192,0,0,0,193,0,0,0,14,0,0,0,194,0,0,0,195,0,0,0,196,0,0,0,197,0,0,0,198,0,0,0,199,0,0,0,200,0,0,0,201,0,0,0,202,0,0,0,203,0,0,0,204,0,0,0,205,0,0,0,15,0,0,0,206,0,0,0,207,0,0,0,208,0,0,0,209,0,0,0,210,0,0,0,211,0,0,0,212,0,0,0,213,0,0,0,214,0,0,0,215,0,0,0,216,0,0,0,217,0,0,0,16,0,0,0,218,0,0,0,219,0,0,0,220,0,0,0,221,0,0,0,222,0,0,0,223,0,0,0,224,0,0,0,225,0,0,0,226,0,0,0,227,0,0,0,228,0,0,0,229,0,0,0,17,0,0,0,230,0,0,0,231,0,0,0,232,0,0,0,233,0,0,0,234,0,0,0,235,0,0,0,236,0,0,0,237,0,0,0,238,0,0,0,239,0,0,0,240,0,0,0,241,0,0,0,18,0,0,0,242,0,0,0,243,0,0,0,244,0,0,0,245,0,0,0,246,0,0,0,247,0,0,0,248,0,0,0,249,0,0,0,250,0,0,0,251,0,0,0,252,0,0,0,253,0,0,0,19,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,2,0,0,0,3,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,12,0,0,0,13,0,0,0,10,0,0,0,11,0,0,0,14,0,0,0,15,0,0,0,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,14,15,16,16,0,0,0,0,14,15,16,16,0,0,0,0,63,102,240,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,1,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,232,3,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,2,3,3,4,6,6,8,12,12,16,24,24,32,0,0,0,4,4,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,4,8,16,32,64,128,27,54,0,0,0,0,0,0,232,195,33,0,24,68,33,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,48,215,32,0,240,118,32,0,12,0,0,0,5,0,0,0,216,28,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,232,4,40,0,216,153,39,0,16,0,0,0,84,65,82,86,24,63,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,118,34,0,112,0,0,0,168,105,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,229,39,0,0,0,0,0,192,160,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,17,1,0,180,128,128,255,168,44,136,255,145,147,44,255,133,63,52,255,63,193,204,255,51,109,212,255,28,212,120,255,0,0,0,0,64,32,32,16,16,8,8,8,8,4,0,0,0,0,0,0,6,5,5,4,4,3,3,3,3,2,0,0,0,0,0,0,6,5,5,4,4,3,3,3,3,2,0,0,0,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+672896);
/* memory initializer */ allocate([80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,0,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,0,0,0,0,68,172,0,0,255,255,255,255,1,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,1,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,255,255,255,255,3,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,9,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,255,255,255,255,4,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,9,0,0,0,3,0,0,0,8,0,0,0,2,0,0,0,7,0,0,0,1,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,3,0,0,0,27,0,0,0,29,0,0,0,28,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,14,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,28,0,0,0,255,255,255,255,10,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,70,0,0,0,80,0,0,0,76,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,82,0,0,0,61,1,0,0,255,255,255,255,0,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,4,0,0,0,33,0,0,0,5,0,0,0,14,0,0,0,34,0,0,0,13,0,0,0,12,0,0,0,64,1,0,0,35,0,0,0,44,1,0,0,43,1,0,0,82,0,0,0,61,1,0,0,8,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,33,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,4,0,0,0,33,0,0,0,5,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,8,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,2,0,0,0,3,0,0,0,43,0,0,0,47,0,0,0,45,0,0,0,49,0,0,0,44,0,0,0,48,0,0,0,46,0,0,0,50,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,7,0,0,0,255,255,255,255,82,0,0,0,61,1,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,39,1,0,0,40,1,0,0,41,1,0,0,42,1,0,0,2,0,0,0,3,0,0,0,8,0,0,0,6,0,0,0,5,0,0,0,14,0,0,0,0,0,0,0,12,0,0,0,43,1,0,0,35,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,14,0,0,0,34,0,0,0,13,0,0,0,12,0,0,0,5,0,0,0,33,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,64,1,0,0,8,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,32,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,70,0,0,0,80,0,0,0,76,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,33,0,0,0,7,0,0,0,6,0,0,0,64,1,0,0,12,0,0,0,13,0,0,0,34,0,0,0,14,0,0,0,82,0,0,0,84,0,0,0,86,0,0,0,58,1,0,0,60,1,0,0,88,0,0,0,61,1,0,0,63,1,0,0,255,255,255,255,0,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,14,0,0,0,34,0,0,0,13,0,0,0,12,0,0,0,64,1,0,0,5,0,0,0,33,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,82,0,0,0,61,1,0,0,8,0,0,0,255,255,255,255,43,1,0,0,44,1,0,0,35,0,0,0,14,0,0,0,34,0,0,0,13,0,0,0,12,0,0,0,64,1,0,0,5,0,0,0,33,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,82,0,0,0,61,1,0,0,8,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,34,0,0,0,35,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,39,1,0,0,41,1,0,0,40,1,0,0,42,1,0,0,42,0,0,0,68,0,0,0,36,1,0,0,38,1,0,0,255,255,255,255,0,0,0,0,0,0,0,0,1,0,0,0,27,0,0,0,39,1,0,0,29,0,0,0,41,1,0,0,28,0,0,0,40,1,0,0,30,0,0,0,42,1,0,0,255,255,255,255,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,54,0,0,0,56,0,0,0,58,0,0,0,35,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,33,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,70,0,0,0,80,0,0,0,76,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,54,0,0,0,56,0,0,0,58,0,0,0,255,255,255,255,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,0,0,0,0,8,0,0,0,5,0,0,0,4,0,0,0,7,0,0,0,33,0,0,0,82,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,2,0,0,0,3,0,0,0,27,0,0,0,29,0,0,0,28,0,0,0,30,0,0,0,255,255,255,255,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,33,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,33,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,35,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,70,0,0,0,80,0,0,0,76,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,33,0,0,0,7,0,0,0,6,0,0,0,8,0,0,0,32,0,0,0,255,255,255,255,3,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,39,1,0,0,41,1,0,0,40,1,0,0,42,1,0,0,255,255,255,255,0,0,0,0,0,0,0,0,12,0,0,0,4,0,0,0,13,0,0,0,5,0,0,0,14,0,0,0,7,0,0,0,8,0,0,0,25,0,0,0,26,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,0,0,0,0,17,0,0,0,255,255,255,255,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,39,1,0,0,41,1,0,0,40,1,0,0,42,1,0,0,42,0,0,0,68,0,0,0,36,1,0,0,38,1,0,0,255,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,29,0,0,0,27,0,0,0,41,1,0,0,39,1,0,0,40,1,0,0,42,1,0,0,255,255,255,255,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,35,0,0,0,33,0,0,0,8,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,14,0,0,0,34,0,0,0,13,0,0,0,12,0,0,0,64,1,0,0,5,0,0,0,33,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,82,0,0,0,61,1,0,0,8,0,0,0,255,255,255,255,6,0,0,0,0,0,0,0,8,0,0,0,25,0,0,0,26,0,0,0,5,0,0,0,4,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,4,0,0,0,33,0,0,0,5,0,0,0,25,0,0,0,26,0,0,0,64,1,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,5,0,0,0,33,0,0,0,4,0,0,0,7,0,0,0,255,255,255,255,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,255,255,255,255,28,0,0,0,255,255,255,255,43,1,0,0,255,255,255,255,44,1,0,0,255,255,255,255,35,0,0,0,255,255,255,255,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,32,0,0,0,255,255,255,255,31,0,0,0,255,255,255,255,5,0,0,0,43,1,0,0,255,255,255,255,0,0,0,0,4,0,0,0,44,1,0,0,255,255,255,255,0,0,0,0,0,0,0,0,35,0,0,0,255,255,255,255,0,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,255,255,255,255,128,187,0,0,255,255,255,255,6,0,0,0,7,0,0,0,33,0,0,0,0,0,0,0,35,0,0,0,4,0,0,0,44,1,0,0,12,0,0,0,13,0,0,0,34,0,0,0,14,0,0,0,5,0,0,0,43,1,0,0,54,0,0,0,104,0,0,0,55,0,0,0,103,0,0,0,56,0,0,0,106,0,0,0,57,0,0,0,105,0,0,0,58,0,0,0,108,0,0,0,59,0,0,0,107,0,0,0,8,0,0,0,66,0,0,0,32,0,0,0,31,0,0,0,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,42,0,0,0,68,0,0,0,41,0,0,0,67,0,0,0,36,1,0,0,38,1,0,0,35,1,0,0,37,1,0,0,82,0,0,0,61,1,0,0,88,0,0,0,87,0,0,0,63,1,0,0,62,1,0,0,255,255,255,255,4,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,8,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,36,0,0,0,40,0,0,0,44,0,0,0,48,0,0,0,52,0,0,0,56,0,0,0,60,0,0,0,64,0,0,0,68,0,0,0,72,0,0,0,76,0,0,0,80,0,0,0,84,0,0,0,88,0,0,0,92,0,0,0,96,0,0,0,100,0,0,0,104,0,0,0,108,0,0,0,112,0,0,0,116,0,0,0,120,0,0,0,124,0,0,0,128,0,0,0,132,0,0,0,136,0,0,0,140,0,0,0,144,0,0,0,148,0,0,0,152,0,0,0,156,0,0,0,160,0,0,0,164,0,0,0,168,0,0,0,172,0,0,0,176,0,0,0,180,0,0,0,184,0,0,0,188,0,0,0,192,0,0,0,196,0,0,0,200,0,0,0,204,0,0,0,208,0,0,0,212,0,0,0,216,0,0,0,220,0,0,0,224,0,0,0,228,0,0,0,232,0,0,0,236,0,0,0,240,0,0,0,244,0,0,0,249,0,0,0,255,0,0,0,12,0,0,0,10,0,0,0,10,0,0,0,8,0,0,0,8,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,4,0,0,0,0,3,5,7,11,15,5,6,7,8,9,10,11,12,14,16,134,255,255,255,240,255,255,255,67,0,0,0,138,0,0,0,197,0,0,0,249,0,0,0,41,1,0,0,82,1,0,0,121,1,0,0,156,1,0,0,188,1,0,0,218,1,0,0,245,1,0,0,15,2,0,0,40,2,0,0,255,255,255,127,131,255,255,255,79,0,0,0,177,0,0,0,245,0,0,0,43,1,0,0,92,1,0,0,143,1,0,0,255,255,255,127,7,0,0,0,217,0,0,0,74,1,0,0,255,255,255,127,4,1,0,0,255,255,255,127,0,1,0,1,0,1,0,1,0,1,0,1,3,1,6,1,9,1,13,1,16,1,19,1,22,1,26,1,29,1,32,1,36,1,39,1,43,1,47,1,50,1,54,1,58,1,61,1,65,1,69,1,73,1,77,1,81,1,85,1,89,1,93,1,97,1,102,1,106,1,110,1,115,1,119,1,123,1,128,1,133,1,137,1,142,1,147,1,152,1,157,1,161,1,166,1,172,1,177,1,182,1,187,1,192,1,198,1,203,1,209,1,214,1,220,1,226,1,232,1,237,1,243,1,249,1,255,1,70,0,110,0,160,0,208,0,253,0,60,1,122,1,183,1,243,1,47,2,108,2,168,2,228,2,32,3,93,3,152,3,212,3,0,0,0,0,0,0,70,0,110,0,160,0,208,0,253,0,60,1,122,1,183,1,243,1,47,2,108,2,168,2,228,2,32,3,93,3,152,3,212,3,0,0,0,0,0,0,249,255,255,255,241,255,255,255,225,255,255,255,193,255,255,255,0,0,0,0,0,0,0,0,0,0,0,2,0,4,0,6,4,8,4,10,4,12,4,14,4,16,4,18,4,20,4,22,20,24,20,26,56,28,0,0,0,0,1,4,11,32,81,230,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,160,64,0,0,64,65,102,102,18,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,64,0,0,168,65,0,0,96,66,0,0,29,67,0,0,0,0,0,0,1,2,0,1,2,3,4,5,6,0,1,1,2,2,3,3,4,5,6,7,8,9,10,11,11,12,13,13,13,14,0,1,1,2,2,2,3,3,4,4,5,5,6,6,7,8,8,9,10,10,11,12,13,14,15,16,17,18,19,20,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,29,30,0,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,7,7,7,8,8,9,9,9,10,10,11,11,11,12,12,13,13,13,13,14,14,14,15,15,15,15,16,16,16,17,17,17,18,18,18,19,19,20,20,20,21,21,22,22,23,23,24,25,26,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,42,43,44,44,45,45,46,47,47,48,48,49,49,50,50,50,51,51,51,52,52,52,53,53,53,54,54,54,55,55,55,56,56,56,57,57,57,57,58,58,58,58,59,59,59,59,60,60,60,60,60,61,61,61,61,61,61,61,62,0,0,1,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,25,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,0,0,1,0,2,1,3,0,4,1,5,0,1,6,7,8,0,1,2,2,3,3,4,0,0,0,0,0,0,57,180,200,62,229,208,66,63,41,92,143,63,86,14,189,63,250,126,234,63,70,182,11,64,190,159,34,64,233,38,57,64,20,174,79,64,162,69,102,64,186,73,124,64,76,55,137,64,2,43,151,64,0,0,0,0,150,67,11,63,20,174,135,63,98,16,200,63,29,90,4,64,68,139,36,64,166,155,68,64,207,247,99,64,113,61,130,64,10,215,147,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,219,249,62,63,90,100,187,63,31,133,11,64,176,114,56,64,66,96,101,64,172,28,138,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,196,128,63,0,0,0,64,80,141,63,64,61,10,127,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,22,169,63,244,253,44,64,121,233,126,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,24,212,63,139,108,95,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,100,251,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,255,255,255,255,255,0,0,0,0,0,3,4,3,3,1,5,1,4,5,2,5,3,1,5,1,51,51,164,44,236,81,190,47,137,65,121,60,140,46,74,42,230,74,50,43,132,58,210,55,98,39,239,34,106,62,203,37,166,49,209,46,146,36,36,32,65,58,227,34,208,46,251,43,0,32,178,28,103,51,60,30,246,40,49,38,114,28,28,25,50,45,174,26,158,35,192,33,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,51,51,130,31,123,20,140,46,66,29,52,18,98,39,154,25,98,16,146,36,193,22,63,14,0,32,123,20,27,13,114,28,207,17,77,11,0,0,0,0,0,1,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,251,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,252,253,253,253,253,253,253,253,254,254,254,255,40,14,65,18,221,21,79,25,1,29,186,32,108,36,24,40,202,43,174,47,79,52,252,57,130,65,199,76,225,94,216,127,0,0,205,12,156,25,0,32,102,38,205,44,0,48,51,51,102,54,154,57,205,60,0,64,51,67,102,70,154,73,205,76,159,0,206,0,12,1,93,1,163,1,226,1,42,2,125,2,221,2,74,3,201,3,90,4,1,5,193,5,158,6,156,7,193,8,17,10,147,11,80,13,79,15,155,17,63,20,72,23,199,26,203,30,105,35,185,40,222,48,135,63,150,82,93,107,204,0,185,1,208,1,185,7,101,3,53,4,48,4,246,11,1,5,151,18,111,6,3,6,53,7,108,27,61,7,122,2,203,7,32,9,47,9,40,60,101,10,141,4,142,10,60,15,150,10,149,39,123,12,216,6,170,13,64,10,79,14,81,3,144,15,65,22,118,16,71,13,63,17,24,5,87,18,8,8,0,21,206,17,10,21,164,2,142,21,2,92,191,21,114,30,12,22,245,11,40,22,233,5,69,23,34,9,133,25,36,4,148,26,110,23,164,26,231,6,25,27,253,14,109,28,158,1,137,28,105,10,42,29,40,44,6,31,26,3,71,31,190,7,71,31,86,5,134,32,33,12,144,32,202,18,4,34,18,31,29,35,231,8,71,35,31,4,31,36,240,13,67,36,95,6,182,37,167,24,83,38,45,10,136,39,171,2,159,39,83,16,5,40,154,7,95,40,194,4,228,40,232,38,155,41,184,11,199,42,250,5,217,42,170,20,195,43,1,9,61,44,234,13,251,45,98,26,63,46,57,7,165,46,143,17,178,46,18,5,199,46,119,59,201,46,115,3,210,46,26,11,150,48,93,8,49,49,81,14,92,49,175,32,114,49,58,6,86,50,68,10,184,50,78,19,90,51,91,4,168,51,12,2,29,52,91,12,87,52,131,7,237,52,73,23,38,53,121,5,87,53,95,9,214,53,69,15,44,54,171,42,146,55,187,6,152,55,123,11,198,55,104,29,103,56,246,17,115,56,216,3,122,56,217,8,200,57,123,5,226,57,117,13,51,58,77,22,169,58,2,60,200,58,154,7,221,58,95,10,45,60,119,37,45,60,239,15,210,60,15,28,71,61,238,8,75,61,88,6,83,61,252,11,156,61,29,20,252,61,181,4,98,62,184,2,121,63,0,14,210,63,125,7,40,64,0,10,99,64,86,17,145,64,10,25,236,64,190,46,199,65,76,34,134,66,234,11,137,66,149,71,196,66,32,6,227,66,77,20,199,67,65,8,222,67,212,3,158,68,102,102,201,68,72,15,231,68,255,127,231,70,191,30,21,71,212,9,26,71,17,22,247,72,211,12,242,73,90,5,71,75,189,53,117,75,24,16,4,76,181,7,198,76,34,39,52,77,136,26,200,77,15,20,72,78,25,11,242,82,121,77,30,6,52,5,41,6,229,13,255,11,90,25,97,16,179,39,144,17,230,9,155,19,136,17,210,21,254,60,93,22,142,5,53,25,68,2,68,26,175,26,233,29,199,13,136,31,51,8,40,32,199,20,123,34,71,34,12,38,52,11,128,38,185,5,103,39,200,48,1,40,101,17,107,42,218,25,57,44,3,14,153,44,8,7,123,45,124,9,198,45,220,3,24,48,229,19,235,48,221,32,30,49,102,102,57,49,68,13,116,51,87,6,229,51,119,9,106,52,199,23,147,52,10,50,88,53,23,14,31,55,169,17,64,55,205,4,89,56,79,7,95,56,66,28,109,56,18,11,36,57,52,39,12,58,88,68,57,59,45,14,105,59,187,22,195,59,208,8,158,60,114,18,47,61,36,4,143,61,36,31,67,62,188,46,148,62,180,11,214,62,171,6,137,64,158,16,192,64,80,24,254,65,76,9,10,66,169,2,61,67,214,32,202,68,90,13,231,69,149,20,248,70,228,45,54,71,39,6,175,72,255,127,40,73,180,84,193,74,239,9,222,75,177,25,246,75,1,16,250,75,96,35,147,79,37,58,143,194,245,61,0,0,0,63,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,16,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,32,0,0,0,38,0,0,0,45,0,0,0,54,0,0,0,64,0,0,0,76,0,0,0,91,0,0,0,108,0,0,0,128,0,0,0,152,0,0,0,181,0,0,0,215,0,0,0,0,1,0,0,48,1,0,0,106,1,0,0,175,1,0,0,0,2,0,0,97,2,0,0,212,2,0,0,93,3,0,0,0,4,0,0,194,4,0,0,168,5,0,0,186,6,0,0,0,8,0,0,131,9,0,0,80,11,0,0,116,13,0,0,0,16,0,0,7,19,0,0,161,22,0,0,233,26,0,0,0,32,0,0,14,38,0,0,65,45,0,0,209,53,0,0,0,64,0,0,28,76,0,0,130,90,0,0,162,107,0,0,0,128,0,0,56,152,0,0,5,181,0,0,69,215,0,0,0,0,1,0,112,48,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,0,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,0,0,0,24,0,0,0,8,0,0,0,24,0,0,0,16,0,0,0,32,0,0,0,16,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,4,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,24,0,0,0,16,0,0,0,16,0,0,0,32,0,0,0,16,0,0,0,8,0,0,0,24,0,0,0,8,0,0,0,8,0,0,0,24,0,0,0,16,0,0,0,4,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,8,0,0,0,9,0,0,0,6,0,0,0,6,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,32,0,0,0,38,0,0,0,46,0,0,0,54,0,0,0,64,0,0,0,76,0,0,0,91,0,0,0,108,0,0,0,128,0,0,0,152,0,0,0,181,0,0,0,216,0,0,0,0,1,0,0,49,1,0,0,106,1,0,0,175,1,0,0,0,2,0,0,97,2,0,0,212,2,0,0,93,3,0,0,0,4,0,0,194,4,0,0,168,5,0,0,186,6,0,0,0,8,0,0,132,9,0,0,81,11,0,0,117,13,0,0,0,16,0,0,7,19,0,0,161,22,0,0,233,26,0,0,0,32,0,0,14,38,0,0,65,45,0,0,209,53,0,0,0,64,0,0,28,76,0,0,131,90,0,0,163,107,0,0,0,128,0,0,56,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,9,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,17,0,0,0,20,0,0,0,24,0,0,0,29,0,0,0,34,0,0,0,41,0,0,0,48,0,0,0,57,0,0,0,68,0,0,0,81,0,0,0,96,0,0,0,114,0,0,0,136,0,0,0,162,0,0,0,192,0,0,0,228,0,0,0,16,1,0,0,67,1,0,0,128,1,0,0,201,1,0,0,31,2,0,0,134,2,0,0,0,3,0,0,145,3,0,0,62,4,0,0,12,5,0,0,0,6,0,0,35,7,0,0,124,8,0,0,23,10,0,0,0,12,0,0,69,14,0,0,248,16,0,0,46,20,0,0,0,24,0,0,139,28,0,0,241,33,0,0,93,40,0,0,0,48,0,0,21,57,0,0,226,67,0,0,186,80,0,0,0,96,0,0,42,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,245,255,12,0,32,0,46,255,183,3,36,15,219,252,106,1,100,255,53,0,245,255,109,68,117,183,138,13,193,184,187,138,107,184,183,230,157,57,0,5,126,57,196,151,95,186,4,118,8,186,36,77,5,59,252,88,77,58,57,33,138,187,92,56,70,186,148,116,0,60,90,72,128,184,62,58,92,188,243,100,33,59,226,15,178,60,41,165,255,187,48,162,11,189,92,22,154,60,243,132,94,61,30,146,50,189,8,138,203,189,190,63,7,62,19,177,237,62,0,0,0,0,0,0,0,0,0,0,0,0,152,147,10,0,112,147,10,0,72,148,10,0,176,149,10,0,0,0,0,0,0,0,16,0,12,0,33,0,78,0,0,0,0,0,0,0,186,73,177,72,184,53,193,191,205,65,10,125,52,197,145,63,109,250,55,88,205,173,177,191,166,110,219,181,140,237,152,63,153,235,184,10,247,4,181,191,191,34,199,239,208,36,159,63,91,53,58,173,252,174,183,191,68,122,31,129,30,238,161,63,231,43,80,164,94,100,185,191,182,27,183,119,145,50,163,63,43,65,144,205,159,192,236,63,62,0,3,61,0,7,60,0,6,64,0,6,63,0,6,62,3,4,19,0,4,18,0,4,17,0,4,16,0,4,70,0,2,20,0,4,0,0,0,0,15,3,1,60,0,1,61,0,1,62,0,1,15,2,1,63,0,1,64,0,1,65,0,1,15,1,1,66,0,1,67,0,1,68,0,1,15,0,1,69,0,1,16,0,2,70,0,4,0,252,0,253,0,0,0,0,0,0,0,0,0,0,0,0,0,253,254,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,4,0,0,3,2,0,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,253,3,0,0,254,0,3,0,0,0,0,0,0,0,251,0,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,3,6,253,252,0,253,253,3,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,3,61,0,7,60,0,6,64,0,6,63,0,6,62,3,4,0,0,1,16,0,4,52,0,1,48,0,7,56,0,3,49,0,6,57,0,3,32,0,7,58,0,2,33,0,7,1,0,1,17,0,4,53,0,1,49,6,1,34,0,2,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+683136);
/* memory initializer */ allocate([0,1,18,0,4,54,0,1,50,0,7,58,2,1,55,0,1,51,0,7,59,0,3,34,2,5,35,0,7,3,0,1,19,0,4,0,0,0,0,0,10,0,191,255,197,255,12,0,110,0,34,0,122,255,157,0,104,0,172,255,222,255,141,255,23,0,155,255,3,0,45,0,155,255,240,255,197,255,28,0,211,255,134,0,189,255,22,0,61,0,227,255,226,0,230,255,201,255,77,255,157,0,205,255,36,255,163,255,219,255,60,0,118,0,74,0,208,255,161,255,75,255,111,0,36,0,204,255,41,255,78,0,144,255,39,0,239,255,209,255,33,255,19,0,12,0,158,255,114,255,130,0,54,0,129,255,21,0,244,255,39,0,208,255,12,0,128,0,6,0,89,255,82,0,154,255,177,255,55,0,212,255,48,0,236,255,203,255,8,0,195,255,11,0,186,255,99,255,88,255,20,0,200,255,182,255,78,0,33,0,193,255,83,255,254,255,181,255,203,255,110,255,77,0,66,0,227,255,9,0,181,255,65,0,119,0,213,255,76,0,233,0,98,0,125,0,100,255,229,255,78,0,247,255,170,0,176,0,143,0,108,255,249,255,27,0,120,255,5,0,27,0,18,0,139,0,204,0,7,0,72,255,59,255,52,0,253,255,78,0,67,255,8,0,191,255,62,0,3,61,0,7,60,0,6,64,0,6,63,0,6,62,3,4,0,0,1,16,0,4,52,0,1,48,0,7,56,0,3,33,0,4,1,0,1,17,0,4,32,0,7,19,0,1,34,0,7,2,0,1,18,0,4,33,4,3,49,0,3,57,0,3,35,0,7,3,0,1,19,1,2,36,0,6,4,0,1,20,0,4,53,0,1,49,3,4,22,0,3,37,0,7,5,0,1,21,0,4,36,6,1,39,0,3,7,0,1,23,0,3,38,0,7,6,0,1,22,3,1,24,0,1,54,0,1,50,0,7,58,0,3,39,3,4,9,0,1,25,0,4,40,0,7,8,0,1,24,1,3,42,0,4,10,0,1,26,0,4,41,0,7,59,0,2,43,0,7,11,0,1,27,0,3,42,4,3,44,0,2,12,0,1,28,0,4,55,0,1,51,0,7,59,2,1,45,0,6,13,0,1,29,0,4,44,2,5,31,0,3,46,0,7,14,0,1,30,0,4,45,6,1,70,0,2,47,0,7,15,0,1,0,0,0,0,0,0,104,1,222,0,52,3,73,4,89,2,63,1,120,6,198,0,92,2,1,2,16,6,141,0,111,5,155,0,170,9,5,1,13,1,17,3,183,5,134,2,99,4,191,0,223,7,223,0,17,3,76,3,178,4,243,3,212,3,39,3,198,11,25,3,58,2,180,0,111,4,102,5,10,3,0,1,109,7,179,0,39,3,110,2,181,5,202,1,207,4,178,0,236,7,53,3,131,1,159,3,216,5,236,3,120,3,136,1,198,8,85,1,39,1,182,5,132,4,182,2,254,3,217,1,178,8,84,5,210,0,222,1,5,4,252,3,210,2,181,0,194,6,251,0,218,2,232,1,185,5,37,1,23,5,70,1,35,10,131,1,202,1,72,2,33,6,230,2,5,4,173,0,118,7,239,1,93,2,135,4,244,4,207,2,205,3,134,2,56,11,172,1,187,1,78,1,67,3,185,5,144,3,138,0,180,6,186,1,108,2,10,3,36,5,194,1,162,4,79,1,166,5,129,6,230,1,26,4,139,6,251,3,112,3,22,1,166,8,202,0,27,2,28,6,118,4,21,2,216,3,135,1,82,8,65,4,92,1,55,1,44,3,121,4,40,2,205,1,34,7,7,1,89,2,163,2,194,6,172,0,243,5,193,0,145,9,21,1,78,1,156,2,37,3,161,5,39,5,207,0,148,6,142,3,70,2,38,5,123,5,74,4,211,3,64,3,140,10,79,5,112,2,228,0,12,5,211,3,32,3,195,0,178,8,29,1,218,2,94,3,1,6,89,2,91,4,253,1,160,10,98,1,218,0,143,4,188,4,2,6,50,4,247,0,138,6,174,6,66,1,94,8,239,4,9,3,213,3,44,2,71,8,174,6,193,0,84,2,11,4,189,3,182,2,141,1,205,7,253,0,231,2,91,2,48,6,65,1,66,5,90,1,173,8,196,2,195,1,220,2,16,4,135,5,160,4,230,0,61,7,151,3,54,1,125,6,89,6,194,2,88,3,75,3,86,11,190,2,211,1,92,1,84,4,24,4,91,3,50,1,172,7,207,1,48,2,245,3,145,5,21,2,118,4,122,2,87,9,111,3,141,1,60,4,65,5,164,6,208,3,248,0,95,7,165,4,132,2,39,8,238,4,91,2,109,3,38,2,155,8,27,5,225,0,27,1,16,5,99,1,31,2,87,1,25,8,18,1,204,0,75,4,26,6,11,2,108,5,161,0,224,10,18,1,112,0,81,3,78,7,175,0,165,4,160,0,210,5,64,4,201,3,91,4,147,2,250,12,134,4,49,4,111,12,83,5,5,2,223,0,204,6,223,0,192,2,131,1,77,10,234,0,180,2,237,3,7,5,74,6,184,3,20,2,89,9,134,2,234,1,40,2,83,6,145,2,77,3,158,2,248,6,232,8,191,0,239,6,16,1,52,11,174,3,184,3,68,10,199,5,22,1,67,2,29,6,218,0,46,3,180,0,75,9,187,0,20,1,164,5,175,4,199,4,176,4,93,1,193,11,51,1,56,1,76,3,106,7,50,1,95,3,214,1,149,6,217,4,1,2,191,6,199,2,185,8,61,4,96,3,70,13,15,2,158,1,184,1,76,5,100,2,196,3,147,0,125,8,226,2,209,1,12,5,109,3,213,6,80,4,177,2,57,8,31,5,68,2,96,3,103,7,240,2,140,2,97,2,205,5,163,6,2,2,120,5,130,1,83,8,165,3,30,3,169,9,218,3,78,1,104,1,95,5,142,1,109,2,20,1,135,8,24,1,55,1,90,4,102,5,39,3,4,5,175,0,45,10,124,2,230,0,48,3,203,6,152,1,50,4,176,0,83,6,96,4,16,3,91,5,192,1,234,11,165,4,112,3,223,11,141,4,168,1,241,0,136,6,186,0,47,3,77,1,128,9,68,1,72,2,5,4,113,4,10,6,247,3,73,2,150,8,227,3,62,2,69,2,210,6,135,2,221,2,228,2,146,7,201,6,91,1,174,6,117,1,125,9,19,3,37,4,135,9,158,5,185,0,24,2,209,5,178,0,191,2,216,0,130,8,231,1,154,0,141,5,134,5,226,3,79,4,96,1,0,12,217,1,152,1,51,3,7,8,168,0,230,3,98,1,125,7,116,4,153,2,7,7,225,3,165,8,210,4,119,2,187,11,250,2,117,1,108,2,238,5,169,1,145,3,44,1,174,7,68,3,146,1,161,4,180,3,105,5,97,4,43,2,10,7,229,5,218,1,118,3,96,7,98,2,227,2,73,2,207,4,75,9,149,2,55,5,205,0,163,8,55,3,54,3,176,9,155,4,255,0,37,1,136,3,219,0,151,0,187,4,167,5,242,1,214,1,253,0,23,6,177,0,11,6,226,3,90,9,242,0,91,0,45,3,89,3,78,2,166,3,46,5,97,7,26,1,45,3,216,1,33,4,214,5,194,1,243,12,115,8,103,7,26,2,20,2,119,5,218,0,146,0,16,6,219,6,114,2,54,3,202,0,19,5,151,2,194,2,196,6,96,10,145,1,162,1,233,2,250,2,14,4,71,2,212,6,210,6,5,5,15,2,145,4,34,5,62,3,44,2,68,8,49,4,17,9,41,1,58,2,213,3,147,1,212,1,79,4,204,6,243,0,213,2,179,0,231,4,218,1,94,5,82,5,130,7,144,3,29,1,179,3,162,3,188,2,81,2,92,5,117,7,64,2,76,2,148,3,86,4,92,4,224,0,159,10,97,6,172,8,146,1,8,2,37,4,192,1,146,1,72,5,219,5,7,3,152,2,77,2,57,4,215,2,33,3,158,8,117,8,133,4,54,2,34,3,143,3,92,4,50,1,167,6,0,7,68,3,143,2,231,3,37,4,14,4,42,1,41,8,86,4,217,6,105,1,55,1,202,3,239,0,9,1,207,4,215,5,61,2,54,2,6,1,33,6,37,1,61,5,120,4,223,8,32,2,214,0,109,3,79,3,207,2,26,3,104,5,19,8,18,1,191,2,176,2,75,4,26,5,135,1,131,11,232,7,134,6,215,1,13,2,221,4,34,1,8,1,21,6,32,6,39,3,206,2,143,1,169,4,173,2,115,3,58,6,169,10,252,2,244,1,242,2,41,3,84,4,29,2,112,6,243,5,105,5,102,2,172,4,185,4,79,3,89,1,194,8,162,5,211,6,199,0,48,2,68,4,194,0,93,1,229,4,117,6,251,1,113,2,98,1,96,5,175,1,163,4,185,5,116,8,104,3,104,1,206,3,240,3,186,2,192,2,66,5,66,8,196,1,208,2,48,3,216,4,65,4,183,1,171,9,218,5,248,7,80,1,206,2,189,4,187,0,195,1,170,5,88,5,117,3,80,2,66,2,107,4,19,2,93,3,63,7,228,6,220,5,188,1,202,3,167,3,135,3,168,1,151,6,97,6,78,4,25,3,129,3,36,4,129,3,185,0,219,7,181,4,63,7,71,1,118,0,151,3,111,0,171,1,184,1,47,5,185,0,213,1,50,0,248,4,91,0,124,3,59,0,235,6,193,0,222,0,158,0,76,4,127,0,59,3,55,0,210,3,23,3,153,2,47,0,188,2,121,5,158,2,91,3,121,7,24,4,215,1,215,0,22,4,125,0,133,2,42,1,63,6,160,0,81,2,39,0,163,4,206,1,237,2,85,1,240,5,255,1,34,1,24,3,141,3,106,1,241,2,81,0,87,4,34,4,7,2,253,0,60,3,71,3,173,2,29,2,141,5,234,4,130,1,130,0,194,3,119,0,30,2,131,1,151,5,185,0,14,2,51,0,151,4,4,1,63,3,167,0,192,6,254,1,17,1,181,1,148,4,113,0,3,3,144,0,98,4,239,2,107,2,119,0,236,1,252,4,146,2,183,2,90,7,103,2,159,1,200,0,250,3,88,0,169,2,83,1,156,5,69,1,43,2,122,0,18,4,229,1,58,3,89,1,94,5,231,2,127,1,250,3,237,3,102,1,192,2,86,0,21,5,74,2,85,2,241,0,64,3,109,2,43,2,61,2,224,5,71,3,160,156,10,0,160,154,10,0,160,152,10,0,160,151,10,0,160,150,10,0,0,0,0,0,0,0,0,57,0,0,16,57,0,0,32,57,0,0,48,57,0,0,80,57,0,0,96,57,0,0,128,57,0,0,144,57,0,0,160,57,0,0,184,57,0,0,200,57,0,0,224,57,0,0,0,58,0,0,16,58,0,0,32,58,0,0,52,58,0,0,72,58,0,0,100,58,0,0,128,58,0,0,142,58,0,0,160,58,0,0,180,58,0,0,202,58,0,0,226,58,0,0,254,58,0,0,14,59,0,0,32,59,0,0,51,59,0,0,73,59,0,0,97,59,0,0,125,59,0,0,142,59,0,0,159,59,0,128,178,59,0,128,200,59,0,0,225,59,0,128,252,59,0,128,13,60,0,192,30,60,0,64,50,60,0,0,72,60,0,128,96,60,0,192,123,60,0,64,141,60,0,128,158,60,0,224,177,60,0,128,199,60,0,224,223,60,0,64,251,60,0,240,12,61,0,32,30,61,0,112,49,61,0,16,71,61,0,80,95,61,0,144,122,61,0,152,140,61,0,192,157,61,0,0,177,61,0,152,198,61,0,208,222,61,0,0,250,61,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,12,0,0,0,13,0,0,0,15,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,33,0,0,0,35,0,0,0,37,0,0,0,39,0,0,0,41,0,0,0,43,0,0,0,45,0,0,0,47,0,0,0,49,0,0,0,51,0,0,0,53,0,0,0,55,0,0,0,57,0,0,0,59,0,0,0,61,0,0,0,64,0,0,0,67,0,0,0,70,0,0,0,73,0,0,0,76,0,0,0,79,0,0,0,82,0,0,0,85,0,0,0,88,0,0,0,91,0,0,0,94,0,0,0,97,0,0,0,100,0,0,0,103,0,0,0,106,0,0,0,109,0,0,0,112,0,0,0,115,0,0,0,118,0,0,0,121,0,0,0,124,0,0,0,127,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,35,174,152,255,0,0,0,0,208,255,255,255,192,255,255,255,0,0,126,64,0,0,74,64,0,0,32,64,0,0,0,64,0,0,204,63,0,0,160,63,0,0,128,63,0,0,72,63,0,0,32,63,0,0,0,63,0,0,208,62,0,0,160,62,0,0,128,62,0,0,64,62,0,0,32,62,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,2,2,2,2,3,3,2,2,3,3,3,3,4,4,4,4,5,5,4,4,6,6,6,6,6,6,6,6,0,0,0,0,6,5,6,5,0,0,0,0,8,159,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,1,37,0,120,189,35,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,96,213,34,0,88,20,34,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,216,122,33,0,72,1,33,0,12,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,120,156,32,0,128,65,32,0,16,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,96,41,40,0,112,201,39,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,224,98,39,0,224,20,39,0,20,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,224,98,39,0,192,208,38,0,88,140,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,98,39,0,192,80,38,0,224,25,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,98,39,0,96,238,37,0,232,192,37,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,98,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,159,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,0,0,0,0,0,0,0,0,0,0,134,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,124,35,0,112,0,0,0,96,161,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,8,9,11,255,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,0,13,5,1,4,1,0,7,12,9,17,1,0,5,3,33,32,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,0,1,2,3,6,5,4,7,7,3,1,2,7,6,5,4,7,5,4,1,4,3,3,4,5,4,5,2,2,3,2,6,6,5,6,1,4,2,3,7,7,5,6,1,4,3,2,7,7,6,3,2,7,5,4,1,7,1,0,0,0,8,48,2,32,0,48,0,0,0,48,2,0,1,0,1,0,8,48,3,32,0,48,3,0,0,0,0,0,0,0,0,0,102,102,134,64,1,0,0,0,102,102,134,64,2,0,0,0,102,102,134,64,3,0,0,0,102,102,134,64,4,0,0,0,102,102,134,64,5,0,0,0,102,102,134,64,6,0,0,0,102,102,134,64,7,0,0,0,102,102,134,64,8,0,0,0,102,102,134,64,9,0,0,0,102,102,134,64,10,0,0,0,102,102,134,64,8,0,0,0,51,51,211,64,16,0,0,0,51,51,211,64,24,0,0,0,51,51,211,64,32,0,0,0,51,51,211,64,40,0,0,0,51,51,211,64,48,0,0,0,51,51,211,64,56,0,0,0,51,51,211,64,64,0,0,0,205,204,204,64,80,0,0,0,0,0,192,64,96,0,0,0,51,51,179,64,112,0,0,0,102,102,166,64,128,0,0,0,102,102,166,64,160,0,0,0,102,102,166,64,208,117,32,0,112,0,0,0,80,119,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,238,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,2,0,0,166,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,140,38,0,200,80,38,0,228,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,8,26,38,0,200,80,38,0,228,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,193,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,159,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,3,0,0,0,0,0,0,0,0,0,0,136,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,133,35,0,112,0,0,0,232,165,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,4,53,63,0,0,128,63,243,4,53,63,0,0,0,0,243,4,53,191,0,0,128,191,243,4,53,191,0,0,128,63,243,4,53,63,0,0,0,0,243,4,53,191,0,0,128,191,243,4,53,191,0,0,0,0,243,4,53,63,195,85,102,61,249,233,0,62,155,80,76,62,155,232,161,62,182,179,228,62,108,134,33,63,24,89,75,63,0,0,128,63,120,36,161,63,200,221,202,63,53,71,15,64,194,98,74,64,66,97,160,64,94,47,254,64,42,67,142,65,55,62,79,59,156,68,184,59,10,215,35,60,57,173,145,60,226,134,1,61,195,85,102,61,173,173,162,61,21,202,229,61,6,75,34,62,187,62,101,62,155,232,161,62,180,212,203,62,206,77,0,63,108,134,33,63,24,89,75,63,0,0,128,63,120,36,161,63,200,221,202,63,193,100,255,63,191,194,32,64,194,98,74,64,82,240,142,64,7,232,201,64,163,153,14,65,150,109,73,65,42,67,142,65,114,251,252,65,192,239,96,66,0,0,200,66,244,211,49,67,39,29,158,67,0,0,128,63,59,223,111,63,147,87,87,63,229,213,25,63,79,59,188,62,0,0,0,0,180,200,22,191,0,0,128,191,2,6,10,14,18,22,26,30,34,246,250,254,51,57,15,21,27,33,39,45,54,66,78,42,102,66,78,90,102,114,126,90,253,255,1,3,5,7,10,14,18,22,0,0,0,0,0,0,0,0,0,0,188,181,182,62,253,66,18,63,210,23,109,63,175,223,152,63,219,15,201,63,233,214,12,64,219,15,73,64,72,97,38,0,112,0,0,0,32,161,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,9,11,13,14,15,63,7,7,11,12,14,15,63,63,9,11,13,14,15,63,63,63,11,11,13,14,63,63,63,63,11,13,14,63,63,63,63,63,13,14,63,63,63,63,63,63,13,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,4,5,6,7,9,11,13,15,5,5,7,8,11,13,15,17,6,7,9,11,13,15,15,17,7,7,9,11,13,15,17,19,7,9,11,13,14,16,19,23,9,11,13,14,16,19,23,29,9,11,13,15,17,21,28,35,11,13,16,17,21,28,35,41,4,4,5,5,6,7,7,9,4,4,5,6,7,7,9,9,5,5,6,7,7,9,9,10,5,5,6,7,7,9,9,10,5,6,7,7,8,9,10,12,6,7,7,8,9,10,12,15,6,7,7,9,10,11,14,17,7,7,9,10,11,14,17,21,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,4,4,4,4,4,4,5,5,4,4,4,4,4,5,5,6,4,4,4,4,5,5,6,7,4,4,4,4,5,6,7,7,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,240,229,39,0,97,112,99,111,4,0,0,0,8,0,0,0,44,1,0,0,242,0,0,0,220,0,0,0,194,0,0,0,0,0,0,0,232,124,39,0,97,112,99,115,1,0,0,0,9,0,0,0,208,2,0,0,48,2,0,0,234,1,0,0,184,1,0,0,1,0,0,0,168,41,39,0,97,112,99,110,1,0,0,0,6,0,0,0,26,4,0,0,40,3,0,0,198,2,0,0,120,2,0,0,2,0,0,0,144,226,38,0,97,112,99,104,1,0,0,0,6,0,0,0,30,6,0,0,192,4,0,0,46,4,0,0,182,3,0,0,3,0,0,0,8,157,38,0,97,112,52,104,1,0,0,0,6,0,0,0,46,9,0,0,36,7,0,0,64,6,0,0,145,5,0,0,3,0,0,0,0,0,0,0,84,6,0,0,140,10,0,0,187,23,0,0,0,36,0,0,0,1,8,9,2,3,10,11,16,17,24,25,18,19,26,27,4,5,12,20,13,6,7,14,21,28,29,22,15,23,30,31,32,33,40,48,41,34,35,42,49,56,57,50,43,36,37,44,51,58,59,52,45,38,39,46,53,60,61,54,47,55,62,63,102,102,109,112,101,103,0,0,208,7,0,0,0,0,0,0,0,0,0,0,248,244,34,0,1,0,0,0,176,219,34,0,2,0,0,0,24,205,34,0,3,0,0,0,120,188,34,0,157,255,255,255,0,0,0,0,0,0,0,0,160,64,40,0,1,0,0,0,0,230,39,0,2,0,0,0,240,124,39,0,3,0,0,0,216,41,39,0,157,255,255,255,0,0,0,0,0,0,0,0,0,57,35,0,1,0,0,0,72,37,35,0,2,0,0,0,216,249,34,0,3,0,0,0,208,222,34,0,4,0,0,0,24,207,34,0,157,255,255,255,0,0,0,0,1,0,0,0,152,207,34,0,2,0,0,0,136,191,34,0,3,0,0,0,24,174,34,0,157,255,255,255,0,0,0,0,66,0,0,0,120,173,36,0,66,2,0,0,0,146,36,0,77,0,0,0,224,118,36,0,88,0,0,0,200,91,36,0,100,0,0,0,192,65,36,0,110,0,0,0,176,39,36,0,110,8,0,0,24,238,35,0,122,0,0,0,104,203,35,0,122,8,0,0,224,179,35,0,144,0,0,0,104,157,35,0,244,0,0,0,224,136,35,0,244,8,0,0,240,113,35,0,44,0,0,0,80,94,35,0,157,255,255,255,0,0,0,0,20,0,0,0,32,208,34,0,30,0,0,0,48,192,34,0,40,0,0,0,56,175,34,0,50,0,0,0,16,156,34,0,60,0,0,0,80,141,34,0,157,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,89,85,86,0,0,0,0,0,255,255,255,255,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,5,1,0,0,0,0,62,134,138,49,62,117,61,39,62,23,131,22,62,0,0,0,62,78,35,201,61,212,139,138,61,175,66,13,61,134,138,49,62,175,65,118,62,248,247,103,62,41,196,80,62,134,138,49,62,63,126,11,62,74,43,192,61,21,239,67,61,117,61,39,62,248,247,103,62,122,130,90,62,76,167,68,62,117,61,39,62,81,102,3,62,243,4,181,61,211,144,56,61,23,131,22,62,41,196,80,62,76,167,68,62,197,251,48,62,23,131,22,62,94,131,236,61,193,233,162,61,209,26,38,61,0,0,0,62,134,138,49,62,117,61,39,62,23,131,22,62,0,0,0,62,78,35,201,61,212,139,138,61,175,66,13,61,78,35,201,61,63,126,11,62,81,102,3,62,94,131,236,61,78,35,201,61,117,8,158,61,201,181,89,61,173,249,221,60,212,139,138,61,74,43,192,61,243,4,181,61,193,233,162,61,212,139,138,61,201,181,89,61,26,246,21,61,53,230,152,60,175,66,13,61,21,239,67,61,211,144,56,61,209,26,38,61,175,66,13,61,173,249,221,60,53,230,152,60,12,229,27,60,4,0,8,0,12,0,16,0,24,0,32,0,48,0,64,0,80,0,96,0,128,0,160,0,192,0,224,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,0,1,80,149,62,7,68,168,62,240,107,196,62,12,176,207,62,246,179,224,62,246,11,182,62,252,111,165,62,250,155,152,62,15,68,134,62,2,160,74,62,0,240,255,255,154,249,255,255,114,252,255,255,138,253,255,255,30,254,255,255,122,254,255,255,197,254,255,255,0,255,255,255,197,254,255,255,122,254,255,255,30,254,255,255,138,253,255,255,114,252,255,255,154,249,255,255,0,240,255,255,0,0,0,0,32,0,0,0,26,0,0,0,21,0,0,0,17,0,0,0,13,0,0,0,9,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,254,255,255,255,251,255,255,255,247,255,255,255,243,255,255,255,239,255,255,255,235,255,255,255,230,255,255,255,224,255,255,255,230,255,255,255,235,255,255,255,239,255,255,255,243,255,255,255,247,255,255,255,251,255,255,255,254,255,255,255,0,0,0,0,2,0,0,0,5,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,21,0,0,0,26,0,0,0,32,0,0,0,0,0,0,0,205,204,76,63,154,153,25,63,205,204,76,62,12,2,171,62,37,6,1,63,96,229,48,63,248,242,32,0,16,144,32,0,56,52,32,0,0,0,0,0,0,24,0,32,0,0,0,0,0,0,0,0,12,0,0,0,4,0,0,0,13,0,0,0,7,0,0,0,5,0,0,0,14,0,0,0,255,255,255,255,16,123,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,190,35,0,208,213,34,0,4,0,0,0,5,0,0,0,224,20,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,123,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,176,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,112,111,115,116,112,114,111,99,101,115,115,105,110,103,32,102,105,108,116,101,114,115,58,10,70,105,108,116,101,114,115,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,79,112,116,105,111,110,115,10,115,104,111,114,116,32,32,108,111,110,103,32,110,97,109,101,32,32,32,32,32,32,32,115,104,111,114,116,32,32,32,108,111,110,103,32,111,112,116,105,111,110,32,32,32,32,32,68,101,115,99,114,105,112,116,105,111,110,10,42,32,32,32,32,32,32,42,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,97,32,32,32,32,32,32,32,97,117,116,111,113,32,32,32,32,32,32,32,32,32,32,32,67,80,85,32,112,111,119,101,114,32,100,101,112,101,110,100,101,110,116,32,101,110,97,98,108,101,114,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,99,32,32,32,32,32,32,32,99,104,114,111,109,32,32,32,32,32,32,32,32,32,32,32,99,104,114,111,109,105,110,97,110,99,101,32,102,105,108,116,101,114,105,110,103,32,101,110,97,98,108,101,100,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,121,32,32,32,32,32,32,32,110,111,99,104,114,111,109,32,32,32,32,32,32,32,32,32,99,104,114,111,109,105,110,97,110,99,101,32,102,105,108,116,101,114,105,110,103,32,100,105,115,97,98,108,101,100,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,110,32,32,32,32,32,32,32,110,111,108,117,109,97,32,32,32,32,32,32,32,32,32,32,108,117,109,97,32,102,105,108,116,101,114,105,110,103,32,100,105,115,97,98,108,101,100,10,104,98,32,32,32,32,32,104,100,101,98,108,111,99,107,32,32,32,32,32,32,32,32,40,50,32,116,104,114,101,115,104,111,108,100,41,32,32,32,32,32,32,32,32,32,32,32,104,111,114,105,122,111,110,116,97,108,32,100,101,98,108,111,99,107,105,110,103,32,102,105,108,116,101,114,10,32,32,32,32,32,32,32,49,46,32,100,105,102,102,101,114,101,110,99,101,32,102,97,99,116,111,114,58,32,100,101,102,97,117,108,116,61,51,50,44,32,104,105,103,104,101,114,32,45,62,32,109,111,114,101,32,100,101,98,108,111,99,107,105,110,103,10,32,32,32,32,32,32,32,50,46,32,102,108,97,116,110,101,115,115,32,116,104,114,101,115,104,111,108,100,58,32,100,101,102,97,117,108,116,61,51,57,44,32,108,111,119,101,114,32,45,62,32,109,111,114,101,32,100,101,98,108,111,99,107,105,110,103,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,116,104,101,32,104,32,38,32,118,32,100,101,98,108,111,99,107,105,110,103,32,102,105,108,116,101,114,115,32,115,104,97,114,101,32,116,104,101,115,101,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,115,111,32,121,111,117,32,99,97,110,39,116,32,115,101,116,32,100,105,102,102,101,114,101,110,116,32,116,104,114,101,115,104,111,108,100,115,32,102,111,114,32,104,32,47,32,118,10,118,98,32,32,32,32,32,118,100,101,98,108,111,99,107,32,32,32,32,32,32,32,32,40,50,32,116,104,114,101,115,104,111,108,100,41,32,32,32,32,32,32,32,32,32,32,32,118,101,114,116,105,99,97,108,32,100,101,98,108,111,99,107,105,110,103,32,102,105,108,116,101,114,10,104,97,32,32,32,32,32,104,97,100,101,98,108,111,99,107,32,32,32,32,32,32,32,40,50,32,116,104,114,101,115,104,111,108,100,41,32,32,32,32,32,32,32,32,32,32,32,104,111,114,105,122,111,110,116,97,108,32,100,101,98,108,111,99,107,105,110,103,32,102,105,108,116,101,114,10,118,97,32,32,32,32,32,118,97,100,101,98,108,111,99,107,32,32,32,32,32,32,32,40,50,32,116,104,114,101,115,104,111,108,100,41,32,32,32,32,32,32,32,32,32,32,32,118,101,114,116,105,99,97,108,32,100,101,98,108,111,99,107,105,110,103,32,102,105,108,116,101,114,10,104,49,32,32,32,32,32,120,49,104,100,101,98,108,111,99,107,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,101,120,112,101,114,105,109,101,110,116,97,108,32,104,32,100,101,98,108,111,99,107,32,102,105,108,116,101,114,32,49,10,118,49,32,32,32,32,32,120,49,118,100,101,98,108,111,99,107,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,101,120,112,101,114,105,109,101,110,116,97,108,32,118,32,100,101,98,108,111,99,107,32,102,105,108,116,101,114,32,49,10,100,114,32,32,32,32,32,100,101,114,105,110,103,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,100,101,114,105,110,103,105,110,103,32,102,105,108,116,101,114,10,97,108,32,32,32,32,32,97,117,116,111,108,101,118,101,108,115,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,97,117,116,111,109,97,116,105,99,32,98,114,105,103,104,116,110,101,115,115,32,47,32,99,111,110,116,114,97,115,116,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,102,32,32,32,32,32,32,32,32,102,117,108,108,121,114,97,110,103,101,32,32,32,32,32,115,116,114,101,116,99,104,32,108,117,109,105,110,97,110,99,101,32,116,111,32,40,48,46,46,50,53,53,41,10,108,98,32,32,32,32,32,108,105,110,98,108,101,110,100,100,101,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,108,105,110,101,97,114,32,98,108,101,110,100,32,100,101,105,110,116,101,114,108,97,99,101,114,10,108,105,32,32,32,32,32,108,105,110,105,112,111,108,100,101,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,108,105,110,101,97,114,32,105,110,116,101,114,112,111,108,97,116,105,110,103,32,100,101,105,110,116,101,114,108,97,99,101,10,99,105,32,32,32,32,32,99,117,98,105,99,105,112,111,108,100,101,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,99,117,98,105,99,32,105,110,116,101,114,112,111,108,97,116,105,110,103,32,100,101,105,110,116,101,114,108,97,99,101,114,10,109,100,32,32,32,32,32,109,101,100,105,97,110,100,101,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,109,101,100,105,97,110,32,100,101,105,110,116,101,114,108,97,99,101,114,10,102,100,32,32,32,32,32,102,102,109,112,101,103,100,101,105,110,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,102,102,109,112,101,103,32,100,101,105,110,116,101,114,108,97,99,101,114,10,108,53,32,32,32,32,32,108,111,119,112,97,115,115,53,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,70,73,82,32,108,111,119,112,97,115,115,32,100,101,105,110,116,101,114,108,97,99,101,114,10,100,101,32,32,32,32,32,100,101,102,97,117,108,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,104,98,58,97,44,118,98,58,97,44,100,114,58,97,10,102,97,32,32,32,32,32,102,97,115,116,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,104,49,58,97,44,118,49,58,97,44,100,114,58,97,10,97,99,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,104,97,58,97,58,49,50,56,58,55,44,118,97,58,97,44,100,114,58,97,10,116,110,32,32,32,32,32,116,109,112,110,111,105,115,101,32,32,32,32,32,32,32,32,40,51,32,116,104,114,101,115,104,111,108,100,41,32,32,32,32,32,32,32,32,32,32,32,116,101,109,112,111,114,97,108,32,110,111,105,115,101,32,114,101,100,117,99,101,114,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,49,46,32,60,61,32,50,46,32,60,61,32,51,46,32,32,32,32,32,32,32,32,32,32,32,32,108,97,114,103,101,114,32,45,62,32,115,116,114,111,110,103,101,114,32,102,105,108,116,101,114,105,110,103,10,102,113,32,32,32,32,32,102,111,114,99,101,81,117,97,110,116,32,32,32,32,32,32,60,113,117,97,110,116,105,122,101,114,62,32,32,32,32,32,32,32,32,32,32,32,32,32,102,111,114,99,101,32,113,117,97,110,116,105,122,101,114,10,85,115,97,103,101,58,10,60,102,105,108,116,101,114,78,97,109,101,62,91,58,60,111,112,116,105,111,110,62,91,58,60,111,112,116,105,111,110,62,46,46,46,93,93,91,91,44,124,47,93,91,45,93,60,102,105,108,116,101,114,78,97,109,101,62,91,58,60,111,112,116,105,111,110,62,46,46,46,93,93,46,46,46,10,108,111,110,103,32,102,111,114,109,32,101,120,97,109,112,108,101,58,10,118,100,101,98,108,111,99,107,58,97,117,116,111,113,47,104,100,101,98,108,111,99,107,58,97,117,116,111,113,47,108,105,110,98,108,101,110,100,100,101,105,110,116,32,32,32,32,100,101,102,97,117,108,116,44,45,118,100,101,98,108,111,99,107,10,115,104,111,114,116,32,102,111,114,109,32,101,120,97,109,112,108,101,58,10,118,98,58,97,47,104,98,58,97,47,108,98,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,100,101,44,45,118,98,10,109,111,114,101,32,101,120,97,109,112,108,101,115,58,10,116,110,58,54,52,58,49,50,56,58,50,53,54,10,10,0,0,0,0,58,124,0,0,0,0,0,0,44,47,0,0,0,0,0,0,240,139,35,0,112,0,0,0,184,175,10,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,119,58,57,229,83,87,57,20,168,120,57,114,146,143,57,95,203,165,57,215,116,191,57,38,23,221,57,173,79,255,57,22,106,19,58,67,59,42,58,140,148,68,58,226,1,99,58,111,18,131,58,14,92,151,58,142,201,174,58,92,215,201,58,40,21,233,58,111,148,6,59,13,105,27,59,15,119,51,59,55,62,79,59,13,82,111,59,119,46,138,59,204,145,159,59,156,68,184,59,20,202,212,59,176,185,245,59,45,225,13,60,10,215,35,60,17,51,61,60,241,123,90,60,51,77,124,60,57,173,145,60,139,57,168,60,80,67,194,60,210,84,224,60,226,134,1,61,72,147,21,61,21,186,44,61,63,118,71,61,195,85,102,61,77,254,132,61,14,148,153,61,120,89,177,61,205,204,204,61,213,127,236,61,119,141,8,62,64,176,29,62,135,24,54,62,237,71,82,62,36,212,114,62,4,53,140,62,155,232,161,62,26,248,186,62,155,232,215,62,207,83,249,62,154,245,15,63,224,61,38,63,17,249,63,63,215,175,93,63,0,0,128,63,229,207,147,63,213,176,170,63,80,28,197,63,169,158,227,63,244,108,3,64,150,196,23,64,68,66,47,64,194,98,74,64,33,182,105,64,97,241,134,64,97,212,155,64,0,243,179,64,88,205,207,64,85,247,239,64,230,141,10,65,0,0,32,65,223,195,56,65,10,93,85,65,100,99,118,65,42,67,142,65,49,72,164,65,188,181,189,65,214,18,219,65,114,251,252,65,213,17,18,66,185,173,40,66,121,201,66,66,192,239,96,66,87,224,129,66,149,250,149,66,96,49,173,66,0,0,200,66,214,244,230,66,38,90,5,67,30,254,25,67,244,211,49,67,62,90,77,67,43,35,109,67,197,235,136,67,39,29,158,67,74,150,182,67,39,217,210,67,216,123,243,67,216,149,12,68,109,88,34,68,59,121,59,68,183,125,88,68,0,0,122,68,6,89,144,68,176,176,166,68,166,125,192,68,241,72,222,68,103,88,0,69,251,53,20,69,183,38,43,69,113,164,69,69,220,59,100,69,184,199,131,69,103,45,152,69,78,187,175,69,136,238,202,69,137,87,234,69,147,78,7,70,0,64,28,70,72,111,52,70], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+693376);
/* memory initializer */ allocate([219,92,80,70,16,157,112,70,151,237,138,70,128,110,160,70,121,67,185,70,101,240,213,70,142,13,247,70,106,165,14,71,166,185,36,71,193,56,62,71,34,170,91,71,42,170,125,71,182,118,146,71,55,34,169,71,0,80,195,71,25,139,225,71,9,58,2,72,42,98,22,72,252,168,45,72,32,138,72,72,88,148,103,72,63,182,133,72,121,104,154,72,196,78,178,72,16,232,205,72,241,198,237,72,85,74,9,73,90,138,30,73,99,20,55,73,197,106,83,73,0,0,128,63,211,144,56,63,21,239,67,63,201,181,89,63,0,0,128,63,193,233,162,63,94,131,236,63,248,247,103,64,211,144,56,63,129,16,5,63,175,66,13,63,210,245,28,63,211,144,56,63,88,232,106,63,56,132,170,63,117,61,39,64,21,239,67,63,175,66,13,63,26,246,21,63,203,160,38,63,21,239,67,63,103,96,121,63,243,4,181,63,134,138,49,64,201,181,89,63,210,245,28,63,203,160,38,63,177,37,57,63,201,181,89,63,212,139,138,63,78,35,201,63,234,69,69,64,0,0,128,63,211,144,56,63,21,239,67,63,201,181,89,63,0,0,128,63,193,233,162,63,94,131,236,63,248,247,103,64,193,233,162,63,88,232,106,63,103,96,121,63,212,139,138,63,193,233,162,63,91,89,207,63,23,131,22,64,186,158,147,64,94,131,236,63,56,132,170,63,243,4,181,63,78,35,201,63,94,131,236,63,23,131,22,64,122,130,90,64,162,79,214,64,248,247,103,64,117,61,39,64,134,138,49,64,234,69,69,64,248,247,103,64,186,158,147,64,162,79,214,64,114,49,82,65,51,83,20,54,39,35,217,22,218,14,167,9,70,6,20,4,167,2,185,1,0,96,0,72,0,54,128,40,96,30,200,22,22,17,209,12,156,9,53,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,235,17,63,133,235,17,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,51,179,62,0,0,0,63,0,0,0,63,0,0,64,63,205,204,76,62,0,0,0,63,133,235,17,63,0,0,64,63,29,128,128,255,0,0,0,0,96,32,33,0,112,0,0,0,128,164,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,85,85,255,0,255,255,15,255,51,255,85,0,255,15,255,51,255,85,255,0,128,0,0,0,8,0,0,0,136,0,0,0,34,0,0,0,170,0,0,0,85,0,0,0,255,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,16,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,1,0,1,0,0,0,0,0,1,0,1,1,0,0,0,0,1,1,0,0,0,0,0,0,1,1,0,1,0,0,0,0,1,1,1,0,0,0,0,0,1,1,1,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,1,0,0,0,0,1,0,0,1,1,0,0,0,1,0,1,0,0,0,0,0,1,0,1,0,1,0,0,0,1,0,1,1,0,0,0,0,1,0,1,1,1,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,1,0,0,0,1,1,0,1,0,0,0,0,1,1,0,1,1,0,0,0,1,1,1,0,0,0,0,0,1,1,1,0,1,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,1,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,1,0,0,1,0,0,1,0,0,0,0,1,0,0,1,0,1,0,0,1,0,0,1,1,0,0,0,1,0,0,1,1,1,0,0,1,0,1,0,0,0,0,0,1,0,1,0,0,1,0,0,1,0,1,0,1,0,0,0,1,0,1,0,1,1,0,0,1,0,1,1,0,0,0,0,1,0,1,1,0,1,0,0,1,0,1,1,1,0,0,0,1,0,1,1,1,1,0,0,1,1,0,0,0,0,0,0,1,1,0,0,0,1,0,0,1,1,0,0,1,0,0,0,1,1,0,0,1,1,0,0,1,1,0,1,0,0,0,0,1,1,0,1,0,1,0,0,1,1,0,1,1,0,0,0,1,1,0,1,1,1,0,0,1,1,1,0,0,0,0,0,1,1,1,0,0,1,0,0,1,1,1,0,1,0,0,0,1,1,1,0,1,1,0,0,1,1,1,1,0,0,0,0,1,1,1,1,0,1,0,0,1,1,1,1,1,0,0,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,1,0,0,0,0,1,0,0,1,0,0,0,0,1,1,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,1,0,1,0,0,0,1,1,0,0,1,0,0,0,1,1,1,0,1,0,0,1,0,0,0,0,1,0,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,0,0,1,0,0,1,1,0,1,0,1,0,0,1,1,1,0,0,1,0,0,1,1,1,1,0,1,0,1,0,0,0,0,0,1,0,1,0,0,0,1,0,1,0,1,0,0,1,0,0,1,0,1,0,0,1,1,0,1,0,1,0,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,1,0,1,0,1,1,0,0,0,0,1,0,1,1,0,0,1,0,1,0,1,1,0,1,0,0,1,0,1,1,0,1,1,0,1,0,1,1,1,0,0,0,1,0,1,1,1,0,1,0,1,0,1,1,1,1,0,0,1,0,1,1,1,1,1,0,1,1,0,0,0,0,0,0,1,1,0,0,0,0,1,0,1,1,0,0,0,1,0,0,1,1,0,0,0,1,1,0,1,1,0,0,1,0,0,0,1,1,0,0,1,0,1,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,1,0,1,1,0,1,0,0,0,0,1,1,0,1,0,0,1,0,1,1,0,1,0,1,0,0,1,1,0,1,0,1,1,0,1,1,0,1,1,0,0,0,1,1,0,1,1,0,1,0,1,1,0,1,1,1,0,0,1,1,0,1,1,1,1,0,1,1,1,0,0,0,0,0,1,1,1,0,0,0,1,0,1,1,1,0,0,1,0,0,1,1,1,0,0,1,1,0,1,1,1,0,1,0,0,0,1,1,1,0,1,0,1,0,1,1,1,0,1,1,0,0,1,1,1,0,1,1,1,0,1,1,1,1,0,0,0,0,1,1,1,1,0,0,1,0,1,1,1,1,0,1,0,0,1,1,1,1,0,1,1,0,1,1,1,1,1,0,0,0,1,1,1,1,1,0,1,0,1,1,1,1,1,1,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,1,0,0,0,0,0,1,1,1,0,0,0,0,1,0,0,1,0,0,0,0,1,0,1,1,0,0,0,0,1,1,0,1,0,0,0,0,1,1,1,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,1,1,0,0,0,1,0,1,0,1,0,0,0,1,0,1,1,1,0,0,0,1,1,0,0,1,0,0,0,1,1,0,1,1,0,0,0,1,1,1,0,1,0,0,0,1,1,1,1,1,0,0,1,0,0,0,0,1,0,0,1,0,0,0,1,1,0,0,1,0,0,1,0,1,0,0,1,0,0,1,1,1,0,0,1,0,1,0,0,1,0,0,1,0,1,0,1,1,0,0,1,0,1,1,0,1,0,0,1,0,1,1,1,1,0,0,1,1,0,0,0,1,0,0,1,1,0,0,1,1,0,0,1,1,0,1,0,1,0,0,1,1,0,1,1,1,0,0,1,1,1,0,0,1,0,0,1,1,1,0,1,1,0,0,1,1,1,1,0,1,0,0,1,1,1,1,1,1,0,1,0,0,0,0,0,1,0,1,0,0,0,0,1,1,0,1,0,0,0,1,0,1,0,1,0,0,0,1,1,1,0,1,0,0,1,0,0,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,1,0,1,0,0,1,1,1,1,0,1,0,1,0,0,0,1,0,1,0,1,0,0,1,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,1,0,1,0,1,1,0,0,1,0,1,0,1,1,0,1,1,0,1,0,1,1,1,0,1,0,1,0,1,1,1,1,1,0,1,1,0,0,0,0,1,0,1,1,0,0,0,1,1,0,1,1,0,0,1,0,1,0,1,1,0,0,1,1,1,0,1,1,0,1,0,0,1,0,1,1,0,1,0,1,1,0,1,1,0,1,1,0,1,0,1,1,0,1,1,1,1,0,1,1,1,0,0,0,1,0,1,1,1,0,0,1,1,0,1,1,1,0,1,0,1,0,1,1,1,0,1,1,1,0,1,1,1,1,0,0,1,0,1,1,1,1,0,1,1,0,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,1,1,1,0,0,0,0,1,0,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,0,1,1,0,0,0,1,0,1,1,1,0,0,0,1,1,0,1,1,0,0,0,1,1,1,1,1,0,0,1,0,0,0,1,1,0,0,1,0,0,1,1,1,0,0,1,0,1,0,1,1,0,0,1,0,1,1,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,1,1,1,0,0,1,1,1,0,1,1,0,0,1,1,1,1,1,1,0,1,0,0,0,0,1,1,0,1,0,0,0,1,1,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,1,1,0,1,0,1,0,0,1,1,0,1,0,1,0,1,1,1,0,1,0,1,1,0,1,1,0,1,0,1,1,1,1,1,0,1,1,0,0,0,1,1,0,1,1,0,0,1,1,1,0,1,1,0,1,0,1,1,0,1,1,0,1,1,1,1,0,1,1,1,0,0,1,1,0,1,1,1,0,1,1,1,0,1,1,1,1,0,1,1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,1,1,1,0,0,0,1,1,1,1,1,0,0,1,0,0,1,1,1,0,0,1,0,1,1,1,1,0,0,1,1,0,1,1,1,0,0,1,1,1,1,1,1,0,1,0,0,0,1,1,1,0,1,0,0,1,1,1,1,0,1,0,1,0,1,1,1,0,1,0,1,1,1,1,1,0,1,1,0,0,1,1,1,0,1,1,0,1,1,1,1,0,1,1,1,0,1,1,1,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,0,0,0,1,1,1,1,1,0,0,1,0,1,1,1,1,0,0,1,1,1,1,1,1,0,1,0,0,1,1,1,1,0,1,0,1,1,1,1,1,0,1,1,0,1,1,1,1,0,1,1,1,1,1,1,1,1,0,0,0,1,1,1,1,1,0,0,1,1,1,1,1,1,0,1,0,1,1,1,1,1,0,1,1,1,1,1,1,1,1,0,0,1,1,1,1,1,1,0,1,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,2,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,2,0,0,0,0,0,2,2,0,0,0,0,0,0,2,2,2,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,2,0,0,0,0,2,0,2,0,0,0,0,0,2,0,2,2,0,0,0,0,2,2,0,0,0,0,0,0,2,2,0,2,0,0,0,0,2,2,2,0,0,0,0,0,2,2,2,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,2,0,0,0,0,2,0,0,2,2,0,0,0,2,0,2,0,0,0,0,0,2,0,2,0,2,0,0,0,2,0,2,2,0,0,0,0,2,0,2,2,2,0,0,0,2,2,0,0,0,0,0,0,2,2,0,0,2,0,0,0,2,2,0,2,0,0,0,0,2,2,0,2,2,0,0,0,2,2,2,0,0,0,0,0,2,2,2,0,2,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2,2,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,2,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,2,0,0,2,0,0,2,0,0,0,0,2,0,0,2,0,2,0,0,2,0,0,2,2,0,0,0,2,0,0,2,2,2,0,0,2,0,2,0,0,0,0,0,2,0,2,0,0,2,0,0,2,0,2,0,2,0,0,0,2,0,2,0,2,2,0,0,2,0,2,2,0,0,0,0,2,0,2,2,0,2,0,0,2,0,2,2,2,0,0,0,2,0,2,2,2,2,0,0,2,2,0,0,0,0,0,0,2,2,0,0,0,2,0,0,2,2,0,0,2,0,0,0,2,2,0,0,2,2,0,0,2,2,0,2,0,0,0,0,2,2,0,2,0,2,0,0,2,2,0,2,2,0,0,0,2,2,0,2,2,2,0,0,2,2,2,0,0,0,0,0,2,2,2,0,0,2,0,0,2,2,2,0,2,0,0,0,2,2,2,0,2,2,0,0,2,2,2,2,0,0,0,0,2,2,2,2,0,2,0,0,2,2,2,2,2,0,0,0,2,2,2,2,2,2,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,2,0,0,0,0,2,0,0,2,0,0,0,0,2,2,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,2,0,2,0,0,0,2,2,0,0,2,0,0,0,2,2,2,0,2,0,0,2,0,0,0,0,2,0,0,2,0,0,2,0,2,0,0,2,0,2,0,0,2,0,0,2,0,2,2,0,2,0,0,2,2,0,0,0,2,0,0,2,2,0,2,0,2,0,0,2,2,2,0,0,2,0,0,2,2,2,2,0,2,0,2,0,0,0,0,0,2,0,2,0,0,0,2,0,2,0,2,0,0,2,0,0,2,0,2,0,0,2,2,0,2,0,2,0,2,0,0,0,2,0,2,0,2,0,2,0,2,0,2,0,2,2,0,0,2,0,2,0,2,2,2,0,2,0,2,2,0,0,0,0,2,0,2,2,0,0,2,0,2,0,2,2,0,2,0,0,2,0,2,2,0,2,2,0,2,0,2,2,2,0,0,0,2,0,2,2,2,0,2,0,2,0,2,2,2,2,0,0,2,0,2,2,2,2,2,0,2,2,0,0,0,0,0,0,2,2,0,0,0,0,2,0,2,2,0,0,0,2,0,0,2,2,0,0,0,2,2,0,2,2,0,0,2,0,0,0,2,2,0,0,2,0,2,0,2,2,0,0,2,2,0,0,2,2,0,0,2,2,2,0,2,2,0,2,0,0,0,0,2,2,0,2,0,0,2,0,2,2,0,2,0,2,0,0,2,2,0,2,0,2,2,0,2,2,0,2,2,0,0,0,2,2,0,2,2,0,2,0,2,2,0,2,2,2,0,0,2,2,0,2,2,2,2,0,2,2,2,0,0,0,0,0,2,2,2,0,0,0,2,0,2,2,2,0,0,2,0,0,2,2,2,0,0,2,2,0,2,2,2,0,2,0,0,0,2,2,2,0,2,0,2,0,2,2,2,0,2,2,0,0,2,2,2,0,2,2,2,0,2,2,2,2,0,0,0,0,2,2,2,2,0,0,2,0,2,2,2,2,0,2,0,0,2,2,2,2,0,2,2,0,2,2,2,2,2,0,0,0,2,2,2,2,2,0,2,0,2,2,2,2,2,2,0,0,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,2,2,0,0,0,0,0,2,0,2,0,0,0,0,0,2,2,2,0,0,0,0,2,0,0,2,0,0,0,0,2,0,2,2,0,0,0,0,2,2,0,2,0,0,0,0,2,2,2,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,2,2,0,0,0,2,0,2,0,2,0,0,0,2,0,2,2,2,0,0,0,2,2,0,0,2,0,0,0,2,2,0,2,2,0,0,0,2,2,2,0,2,0,0,0,2,2,2,2,2,0,0,2,0,0,0,0,2,0,0,2,0,0,0,2,2,0,0,2,0,0,2,0,2,0,0,2,0,0,2,2,2,0,0,2,0,2,0,0,2,0,0,2,0,2,0,2,2,0,0,2,0,2,2,0,2,0,0,2,0,2,2,2,2,0,0,2,2,0,0,0,2,0,0,2,2,0,0,2,2,0,0,2,2,0,2,0,2,0,0,2,2,0,2,2,2,0,0,2,2,2,0,0,2,0,0,2,2,2,0,2,2,0,0,2,2,2,2,0,2,0,0,2,2,2,2,2,2,0,2,0,0,0,0,0,2,0,2,0,0,0,0,2,2,0,2,0,0,0,2,0,2,0,2,0,0,0,2,2,2,0,2,0,0,2,0,0,2,0,2,0,0,2,0,2,2,0,2,0,0,2,2,0,2,0,2,0,0,2,2,2,2,0,2,0,2,0,0,0,2,0,2,0,2,0,0,2,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,2,2,0,2,0,2,2,0,0,2,0,2,0,2,2,0,2,2,0,2,0,2,2,2,0,2,0,2,0,2,2,2,2,2,0,2,2,0,0,0,0,2,0,2,2,0,0,0,2,2,0,2,2,0,0,2,0,2,0,2,2,0,0,2,2,2,0,2,2,0,2,0,0,2,0,2,2,0,2,0,2,2,0,2,2,0,2,2,0,2,0,2,2,0,2,2,2,2,0,2,2,2,0,0,0,2,0,2,2,2,0,0,2,2,0,2,2,2,0,2,0,2,0,2,2,2,0,2,2,2,0,2,2,2,2,0,0,2,0,2,2,2,2,0,2,2,0,2,2,2,2,2,0,2,0,2,2,2,2,2,2,2,2,0,0,0,0,0,0,2,2,0,0,0,0,0,2,2,2,0,0,0,0,2,0,2,2,0,0,0,0,2,2,2,2,0,0,0,2,0,0,2,2,0,0,0,2,0,2,2,2,0,0,0,2,2,0,2,2,0,0,0,2,2,2,2,2,0,0,2,0,0,0,2,2,0,0,2,0,0,2,2,2,0,0,2,0,2,0,2,2,0,0,2,0,2,2,2,2,0,0,2,2,0,0,2,2,0,0,2,2,0,2,2,2,0,0,2,2,2,0,2,2,0,0,2,2,2,2,2,2,0,2,0,0,0,0,2,2,0,2,0,0,0,2,2,2,0,2,0,0,2,0,2,2,0,2,0,0,2,2,2,2,0,2,0,2,0,0,2,2,0,2,0,2,0,2,2,2,0,2,0,2,2,0,2,2,0,2,0,2,2,2,2,2,0,2,2,0,0,0,2,2,0,2,2,0,0,2,2,2,0,2,2,0,2,0,2,2,0,2,2,0,2,2,2,2,0,2,2,2,0,0,2,2,0,2,2,2,0,2,2,2,0,2,2,2,2,0,2,2,0,2,2,2,2,2,2,2,2,0,0,0,0,0,2,2,2,0,0,0,0,2,2,2,2,0,0,0,2,0,2,2,2,0,0,0,2,2,2,2,2,0,0,2,0,0,2,2,2,0,0,2,0,2,2,2,2,0,0,2,2,0,2,2,2,0,0,2,2,2,2,2,2,0,2,0,0,0,2,2,2,0,2,0,0,2,2,2,2,0,2,0,2,0,2,2,2,0,2,0,2,2,2,2,2,0,2,2,0,0,2,2,2,0,2,2,0,2,2,2,2,0,2,2,2,0,2,2,2,0,2,2,2,2,2,2,2,2,0,0,0,0,2,2,2,2,0,0,0,2,2,2,2,2,0,0,2,0,2,2,2,2,0,0,2,2,2,2,2,2,0,2,0,0,2,2,2,2,0,2,0,2,2,2,2,2,0,2,2,0,2,2,2,2,0,2,2,2,2,2,2,2,2,0,0,0,2,2,2,2,2,0,0,2,2,2,2,2,2,0,2,0,2,2,2,2,2,0,2,2,2,2,2,2,2,2,0,0,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,4,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,4,0,0,0,0,0,4,4,0,0,0,0,0,0,4,4,4,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,4,0,0,0,0,4,0,4,0,0,0,0,0,4,0,4,4,0,0,0,0,4,4,0,0,0,0,0,0,4,4,0,4,0,0,0,0,4,4,4,0,0,0,0,0,4,4,4,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,4,0,0,0,0,4,0,0,4,4,0,0,0,4,0,4,0,0,0,0,0,4,0,4,0,4,0,0,0,4,0,4,4,0,0,0,0,4,0,4,4,4,0,0,0,4,4,0,0,0,0,0,0,4,4,0,0,4,0,0,0,4,4,0,4,0,0,0,0,4,4,0,4,4,0,0,0,4,4,4,0,0,0,0,0,4,4,4,0,4,0,0,0,4,4,4,4,0,0,0,0,4,4,4,4,4,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,4,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,4,0,0,4,0,0,4,0,0,0,0,4,0,0,4,0,4,0,0,4,0,0,4,4,0,0,0,4,0,0,4,4,4,0,0,4,0,4,0,0,0,0,0,4,0,4,0,0,4,0,0,4,0,4,0,4,0,0,0,4,0,4,0,4,4,0,0,4,0,4,4,0,0,0,0,4,0,4,4,0,4,0,0,4,0,4,4,4,0,0,0,4,0,4,4,4,4,0,0,4,4,0,0,0,0,0,0,4,4,0,0,0,4,0,0,4,4,0,0,4,0,0,0,4,4,0,0,4,4,0,0,4,4,0,4,0,0,0,0,4,4,0,4,0,4,0,0,4,4,0,4,4,0,0,0,4,4,0,4,4,4,0,0,4,4,4,0,0,0,0,0,4,4,4,0,0,4,0,0,4,4,4,0,4,0,0,0,4,4,4,0,4,4,0,0,4,4,4,4,0,0,0,0,4,4,4,4,0,4,0,0,4,4,4,4,4,0,0,0,4,4,4,4,4,4,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,4,0,4,0,0,0,0,4,0,0,4,0,0,0,0,4,4,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,4,0,4,0,0,0,4,4,0,0,4,0,0,0,4,4,4,0,4,0,0,4,0,0,0,0,4,0,0,4,0,0,4,0,4,0,0,4,0,4,0,0,4,0,0,4,0,4,4,0,4,0,0,4,4,0,0,0,4,0,0,4,4,0,4,0,4,0,0,4,4,4,0,0,4,0,0,4,4,4,4,0,4,0,4,0,0,0,0,0,4,0,4,0,0,0,4,0,4,0,4,0,0,4,0,0,4,0,4,0,0,4,4,0,4,0,4,0,4,0,0,0,4,0,4,0,4,0,4,0,4,0,4,0,4,4,0,0,4,0,4,0,4,4,4,0,4,0,4,4,0,0,0,0,4,0,4,4,0,0,4,0,4,0,4,4,0,4,0,0,4,0,4,4,0,4,4,0,4,0,4,4,4,0,0,0,4,0,4,4,4,0,4,0,4,0,4,4,4,4,0,0,4,0,4,4,4,4,4,0,4,4,0,0,0,0,0,0,4,4,0,0,0,0,4,0,4,4,0,0,0,4,0,0,4,4,0,0,0,4,4,0,4,4,0,0,4,0,0,0,4,4,0,0,4,0,4,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,4,0,4,4,0,4,0,0,0,0,4,4,0,4,0,0,4,0,4,4,0,4,0,4,0,0,4,4,0,4,0,4,4,0,4,4,0,4,4,0,0,0,4,4,0,4,4,0,4,0,4,4,0,4,4,4,0,0,4,4,0,4,4,4,4,0,4,4,4,0,0,0,0,0,4,4,4,0,0,0,4,0,4,4,4,0,0,4,0,0,4,4,4,0,0,4,4,0,4,4,4,0,4,0,0,0,4,4,4,0,4,0,4,0,4,4,4,0,4,4,0,0,4,4,4,0,4,4,4,0,4,4,4,4,0,0,0,0,4,4,4,4,0,0,4,0,4,4,4,4,0,4,0,0,4,4,4,4,0,4,4,0,4,4,4,4,4,0,0,0,4,4,4,4,4,0,4,0,4,4,4,4,4,4,0,0,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,4,4,0,0,0,0,0,4,0,4,0,0,0,0,0,4,4,4,0,0,0,0,4,0,0,4,0,0,0,0,4,0,4,4,0,0,0,0,4,4,0,4,0,0,0,0,4,4,4,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,4,4,0,0,0,4,0,4,0,4,0,0,0,4,0,4,4,4,0,0,0,4,4,0,0,4,0,0,0,4,4,0,4,4,0,0,0,4,4,4,0,4,0,0,0,4,4,4,4,4,0,0,4,0,0,0,0,4,0,0,4,0,0,0,4,4,0,0,4,0,0,4,0,4,0,0,4,0,0,4,4,4,0,0,4,0,4,0,0,4,0,0,4,0,4,0,4,4,0,0,4,0,4,4,0,4,0,0,4,0,4,4,4,4,0,0,4,4,0,0,0,4,0,0,4,4,0,0,4,4,0,0,4,4,0,4,0,4,0,0,4,4,0,4,4,4,0,0,4,4,4,0,0,4,0,0,4,4,4,0,4,4,0,0,4,4,4,4,0,4,0,0,4,4,4,4,4,4,0,4,0,0,0,0,0,4,0,4,0,0,0,0,4,4,0,4,0,0,0,4,0,4,0,4,0,0,0,4,4,4,0,4,0,0,4,0,0,4,0,4,0,0,4,0,4,4,0,4,0,0,4,4,0,4,0,4,0,0,4,4,4,4,0,4,0,4,0,0,0,4,0,4,0,4,0,0,4,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,4,4,0,4,0,4,4,0,0,4,0,4,0,4,4,0,4,4,0,4,0,4,4,4,0,4,0,4,0,4,4,4,4,4,0,4,4,0,0,0,0,4,0,4,4,0,0,0,4,4,0,4,4,0,0,4,0,4,0,4,4,0,0,4,4,4,0,4,4,0,4,0,0,4,0,4,4,0,4,0,4,4,0,4,4,0,4,4,0,4,0,4,4,0,4,4,4,4,0,4,4,4,0,0,0,4,0,4,4,4,0,0,4,4,0,4,4,4,0,4,0,4,0,4,4,4,0,4,4,4,0,4,4,4,4,0,0,4,0,4,4,4,4,0,4,4,0,4,4,4,4,4,0,4,0,4,4,4,4,4,4,4,4,0,0,0,0,0,0,4,4,0,0,0,0,0,4,4,4,0,0,0,0,4,0,4,4,0,0,0,0,4,4,4,4,0,0,0,4,0,0,4,4,0,0,0,4,0,4,4,4,0,0,0,4,4,0,4,4,0,0,0,4,4,4,4,4,0,0,4,0,0,0,4,4,0,0,4,0,0,4,4,4,0,0,4,0,4,0,4,4,0,0,4,0,4,4,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,4,4,4,0,0,4,4,4,0,4,4,0,0,4,4,4,4,4,4,0,4,0,0,0,0,4,4,0,4,0,0,0,4,4,4,0,4,0,0,4,0,4,4,0,4,0,0,4,4,4,4,0,4,0,4,0,0,4,4,0,4,0,4,0,4,4,4,0,4,0,4,4,0,4,4,0,4,0,4,4,4,4,4,0,4,4,0,0,0,4,4,0,4,4,0,0,4,4,4,0,4,4,0,4,0,4,4,0,4,4,0,4,4,4,4,0,4,4,4,0,0,4,4,0,4,4,4,0,4,4,4,0,4,4,4,4,0,4,4,0,4,4,4,4,4,4,4,4,0,0,0,0,0,4,4,4,0,0,0,0,4,4,4,4,0,0,0,4,0,4,4,4,0,0,0,4,4,4,4,4,0,0,4,0,0,4,4,4,0,0,4,0,4,4,4,4,0,0,4,4,0,4,4,4,0,0,4,4,4,4,4,4,0,4,0,0,0,4,4,4,0,4,0,0,4,4,4,4,0,4,0,4,0,4,4,4,0,4,0,4,4,4,4,4,0,4,4,0,0,4,4,4,0,4,4,0,4,4,4,4,0,4,4,4,0,4,4,4,0,4,4,4,4,4,4,4,4,0,0,0,0,4,4,4,4,0,0,0,4,4,4,4,4,0,0,4,0,4,4,4,4,0,0,4,4,4,4,4,4,0,4,0,0,4,4,4,4,0,4,0,4,4,4,4,4,0,4,4,0,4,4,4,4,0,4,4,4,4,4,4,4,4,0,0,0,4,4,4,4,4,0,0,4,4,4,4,4,4,0,4,0,4,4,4,4,4,0,4,4,4,4,4,4,4,4,0,0,4,4,4,4,4,4,0,4,4,4,4,4,4,4,4,0,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,8,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,8,0,0,0,0,0,8,8,0,0,0,0,0,0,8,8,8,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,8,0,0,0,0,8,0,8,0,0,0,0,0,8,0,8,8,0,0,0,0,8,8,0,0,0,0,0,0,8,8,0,8,0,0,0,0,8,8,8,0,0,0,0,0,8,8,8,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,8,0,0,0,0,8,0,0,8,8,0,0,0,8,0,8,0,0,0,0,0,8,0,8,0,8,0,0,0,8,0,8,8,0,0,0,0,8,0,8,8,8,0,0,0,8,8,0,0,0,0,0,0,8,8,0,0,8,0,0,0,8,8,0,8,0,0,0,0,8,8,0,8,8,0,0,0,8,8,8,0,0,0,0,0,8,8,8,0,8,0,0,0,8,8,8,8,0,0,0,0,8,8,8,8,8,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,8,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,8,0,0,8,0,0,8,0,0,0,0,8,0,0,8,0,8,0,0,8,0,0,8,8,0,0,0,8,0,0,8,8,8,0,0,8,0,8,0,0,0,0,0,8,0,8,0,0,8,0,0,8,0,8,0,8,0,0,0,8,0,8,0,8,8,0,0,8,0,8,8,0,0,0,0,8,0,8,8,0,8,0,0,8,0,8,8,8,0,0,0,8,0,8,8,8,8,0,0,8,8,0,0,0,0,0,0,8,8,0,0,0,8,0,0,8,8,0,0,8,0,0,0,8,8,0,0,8,8,0,0,8,8,0,8,0,0,0,0,8,8,0,8,0,8,0,0,8,8,0,8,8,0,0,0,8,8,0,8,8,8,0,0,8,8,8,0,0,0,0,0,8,8,8,0,0,8,0,0,8,8,8,0,8,0,0,0,8,8,8,0,8,8,0,0,8,8,8,8,0,0,0,0,8,8,8,8,0,8,0,0,8,8,8,8,8,0,0,0,8,8,8,8,8,8,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,8,0,8,0,0,0,0,8,0,0,8,0,0,0,0,8,8,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,8,0,8,0,0,0,8,8,0,0,8,0,0,0,8,8,8,0,8,0,0,8,0,0,0,0,8,0,0,8,0,0,8,0,8,0,0,8,0,8,0,0,8,0,0,8,0,8,8,0,8,0,0,8,8,0,0,0,8,0,0,8,8,0,8,0,8,0,0,8,8,8,0,0,8,0,0,8,8,8,8,0,8,0,8,0,0,0,0,0,8,0,8,0,0,0,8,0,8,0,8,0,0,8,0,0,8,0,8,0,0,8,8,0,8,0,8,0,8,0,0,0,8,0,8,0,8,0,8,0,8,0,8,0,8,8,0,0,8,0,8,0,8,8,8,0,8,0,8,8,0,0,0,0,8,0,8,8,0,0,8,0,8,0,8,8,0,8,0,0,8,0,8,8,0,8,8,0,8,0,8,8,8,0,0,0,8,0,8,8,8,0,8,0,8,0,8,8,8,8,0,0,8,0,8,8,8,8,8,0,8,8,0,0,0,0,0,0,8,8,0,0,0,0,8,0,8,8,0,0,0,8,0,0,8,8,0,0,0,8,8,0,8,8,0,0,8,0,0,0,8,8,0,0,8,0,8,0,8,8,0,0,8,8,0,0,8,8,0,0,8,8,8,0,8,8,0,8,0,0,0,0,8,8,0,8,0,0,8,0,8,8,0,8,0,8,0,0,8,8,0,8,0,8,8,0,8,8,0,8,8,0,0,0,8,8,0,8,8,0,8,0,8,8,0,8,8,8,0,0,8,8,0,8,8,8,8,0,8,8,8,0,0,0,0,0,8,8,8,0,0,0,8,0,8,8,8,0,0,8,0,0,8,8,8,0,0,8,8,0,8,8,8,0,8,0,0,0,8,8,8,0,8,0,8,0,8,8,8,0,8,8,0,0,8,8,8,0,8,8,8,0,8,8,8,8,0,0,0,0,8,8,8,8,0,0,8,0,8,8,8,8,0,8,0,0,8,8,8,8,0,8,8,0,8,8,8,8,8,0,0,0,8,8,8,8,8,0,8,0,8,8,8,8,8,8,0,0,8,8,8,8,8,8,8,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,8,8,0,0,0,0,0,8,0,8,0,0,0,0,0,8,8,8,0,0,0,0,8,0,0,8,0,0,0,0,8,0,8,8,0,0,0,0,8,8,0,8,0,0,0,0,8,8,8,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,8,8,0,0,0,8,0,8,0,8,0,0,0,8,0,8,8,8,0,0,0,8,8,0,0,8,0,0,0,8,8,0,8,8,0,0,0,8,8,8,0,8,0,0,0,8,8,8,8,8,0,0,8,0,0,0,0,8,0,0,8,0,0,0,8,8,0,0,8,0,0,8,0,8,0,0,8,0,0,8,8,8,0,0,8,0,8,0,0,8,0,0,8,0,8,0,8,8,0,0,8,0,8,8,0,8,0,0,8,0,8,8,8,8,0,0,8,8,0,0,0,8,0,0,8,8,0,0,8,8,0,0,8,8,0,8,0,8,0,0,8,8,0,8,8,8,0,0,8,8,8,0,0,8,0,0,8,8,8,0,8,8,0,0,8,8,8,8,0,8,0,0,8,8,8,8,8,8,0,8,0,0,0,0,0,8,0,8,0,0,0,0,8,8,0,8,0,0,0,8,0,8,0,8,0,0,0,8,8,8,0,8,0,0,8,0,0,8,0,8,0,0,8,0,8,8,0,8,0,0,8,8,0,8,0,8,0,0,8,8,8,8,0,8,0,8,0,0,0,8,0,8,0,8,0,0,8,8,0,8,0,8,0,8,0,8,0,8,0,8,0,8,8,8,0,8,0,8,8,0,0,8,0,8,0,8,8,0,8,8,0,8,0,8,8,8,0,8,0,8,0,8,8,8,8,8,0,8,8,0,0,0,0,8,0,8,8,0,0,0,8,8,0,8,8,0,0,8,0,8,0,8,8,0,0,8,8,8,0,8,8,0,8,0,0,8,0,8,8,0,8,0,8,8,0,8,8,0,8,8,0,8,0,8,8,0,8,8,8,8,0,8,8,8,0,0,0,8,0,8,8,8,0,0,8,8,0,8,8,8,0,8,0,8,0,8,8,8,0,8,8,8,0,8,8,8,8,0,0,8,0,8,8,8,8,0,8,8,0,8,8,8,8,8,0,8,0,8,8,8,8,8,8,8,8,0,0,0,0,0,0,8,8,0,0,0,0,0,8,8,8,0,0,0,0,8,0,8,8,0,0,0,0,8,8,8,8,0,0,0,8,0,0,8,8,0,0,0,8,0,8,8,8,0,0,0,8,8,0,8,8,0,0,0,8,8,8,8,8,0,0,8,0,0,0,8,8,0,0,8,0,0,8,8,8,0,0,8,0,8,0,8,8,0,0,8,0,8,8,8,8,0,0,8,8,0,0,8,8,0,0,8,8,0,8,8,8,0,0,8,8,8,0,8,8,0,0,8,8,8,8,8,8,0,8,0,0,0,0,8,8,0,8,0,0,0,8,8,8,0,8,0,0,8,0,8,8,0,8,0,0,8,8,8,8,0,8,0,8,0,0,8,8,0,8,0,8,0,8,8,8,0,8,0,8,8,0,8,8,0,8,0,8,8,8,8,8,0,8,8,0,0,0,8,8,0,8,8,0,0,8,8,8,0,8,8,0,8,0,8,8,0,8,8,0,8,8,8,8,0,8,8,8,0,0,8,8,0,8,8,8,0,8,8,8,0,8,8,8,8,0,8,8,0,8,8,8,8,8,8,8,8,0,0,0,0,0,8,8,8,0,0,0,0,8,8,8,8,0,0,0,8,0,8,8,8,0,0,0,8,8,8,8,8,0,0,8,0,0,8,8,8,0,0,8,0,8,8,8,8,0,0,8,8,0,8,8,8,0,0,8,8,8,8,8,8,0,8,0,0,0,8,8,8,0,8,0,0,8,8,8,8,0,8,0,8,0,8,8,8,0,8,0,8,8,8,8,8,0,8,8,0,0,8,8,8,0,8,8,0,8,8,8,8,0,8,8,8,0,8,8,8,0,8,8,8,8,8,8,8,8,0,0,0,0,8,8,8,8,0,0,0,8,8,8,8,8,0,0,8,0,8,8,8,8,0,0,8,8,8,8,8,8,0,8,0,0,8,8,8,8,0,8,0,8,8,8,8,8,0,8,8,0,8,8,8,8,0,8,8,8,8,8,8,8,8,0,0,0,8,8,8,8,8,0,0,8,8,8,8,8,8,0,8,0,8,8,8,8,8,0,8,8,8,8,8,8,8,8,0,0,8,8,8,8,8,8,0,8,8,8,8,8,8,8,8,0,8,8,8,8,8,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,16,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,16,0,0,0,0,0,16,16,0,0,0,0,0,0,16,16,16,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,16,0,0,0,0,16,0,16,0,0,0,0,0,16,0,16,16,0,0,0,0,16,16,0,0,0,0,0,0,16,16,0,16,0,0,0,0,16,16,16,0,0,0,0,0,16,16,16,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,16,0,0,0,0,16,0,0,16,16,0,0,0,16,0,16,0,0,0,0,0,16,0,16,0,16,0,0,0,16,0,16,16,0,0,0,0,16,0,16,16,16,0,0,0,16,16,0,0,0,0,0,0,16,16,0,0,16,0,0,0,16,16,0,16,0,0,0,0,16,16,0,16,16,0,0,0,16,16,16,0,0,0,0,0,16,16,16,0,16,0,0,0,16,16,16,16,0,0,0,0,16,16,16,16,16,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,16,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,16,0,0,16,0,0,16,0,0,0,0,16,0,0,16,0,16,0,0,16,0,0,16,16,0,0,0,16,0,0,16,16,16,0,0,16,0,16,0,0,0,0,0,16,0,16,0,0,16,0,0,16,0,16,0,16,0,0,0,16,0,16,0,16,16,0,0,16,0,16,16,0,0,0,0,16,0,16,16,0,16,0,0,16,0,16,16,16,0,0,0,16,0,16,16,16,16,0,0,16,16,0,0,0,0,0,0,16,16,0,0,0,16,0,0,16,16,0,0,16,0,0,0,16,16,0,0,16,16,0,0,16,16,0,16,0,0,0,0,16,16,0,16,0,16,0,0,16,16,0,16,16,0,0,0,16,16,0,16,16,16,0,0,16,16,16,0,0,0,0,0,16,16,16,0,0,16,0,0,16,16,16,0,16,0,0,0,16,16,16,0,16,16,0,0,16,16,16,16,0,0,0,0,16,16,16,16,0,16,0,0,16,16,16,16,16,0,0,0,16,16,16,16,16,16,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,16,0,16,0,0,0,0,16,0,0,16,0,0,0,0,16,16,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,16,0,16,0,0,0,16,16,0,0,16,0,0,0,16,16,16,0,16,0,0,16,0,0,0,0,16,0,0,16,0,0,16,0,16,0,0,16,0,16,0,0,16,0,0,16,0,16,16,0,16,0,0,16,16,0,0,0,16,0,0,16,16,0,16,0,16,0,0,16,16,16,0,0,16,0,0,16,16,16,16,0,16,0,16,0,0,0,0,0,16,0,16,0,0,0,16,0,16,0,16,0,0,16,0,0,16,0,16,0,0,16,16,0,16,0,16,0,16,0,0,0,16,0,16,0,16,0,16,0,16,0,16,0,16,16,0,0,16,0,16,0,16,16,16,0,16,0,16,16,0,0,0,0,16,0,16,16,0,0,16,0,16,0,16,16,0,16,0,0,16,0,16,16,0,16,16,0,16,0,16,16,16,0,0,0,16,0,16,16,16,0,16,0,16,0,16,16,16,16,0,0,16,0,16,16,16,16,16,0,16,16,0,0,0,0,0,0,16,16,0,0,0,0,16,0,16,16,0,0,0,16,0,0,16,16,0,0,0,16,16,0,16,16,0,0,16,0,0,0,16,16,0,0,16,0,16,0,16,16,0,0,16,16,0,0,16,16,0,0,16,16,16,0,16,16,0,16,0,0,0,0,16,16,0,16,0,0,16,0,16,16,0,16,0,16,0,0,16,16,0,16,0,16,16,0,16,16,0,16,16,0,0,0,16,16,0,16,16,0,16,0,16,16,0,16,16,16,0,0,16,16,0,16,16,16,16,0,16,16,16,0,0,0,0,0,16,16,16,0,0,0,16,0,16,16,16,0,0,16,0,0,16,16,16,0,0,16,16,0,16,16,16,0,16,0,0,0,16,16,16,0,16,0,16,0,16,16,16,0,16,16,0,0,16,16,16,0,16,16,16,0,16,16,16,16,0,0,0,0,16,16,16,16,0,0,16,0,16,16,16,16,0,16,0,0,16,16,16,16,0,16,16,0,16,16,16,16,16,0,0,0,16,16,16,16,16,0,16,0,16,16,16,16,16,16,0,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,16,16,0,0,0,0,0,16,0,16,0,0,0,0,0,16,16,16,0,0,0,0,16,0,0,16,0,0,0,0,16,0,16,16,0,0,0,0,16,16,0,16,0,0,0,0,16,16,16,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,16,16,0,0,0,16,0,16,0,16,0,0,0,16,0,16,16,16,0,0,0,16,16,0,0,16,0,0,0,16,16,0,16,16,0,0,0,16,16,16,0,16,0,0,0,16,16,16,16,16,0,0,16,0,0,0,0,16,0,0,16,0,0,0,16,16,0,0,16,0,0,16,0,16,0,0,16,0,0,16,16,16,0,0,16,0,16,0,0,16,0,0,16,0,16,0,16,16,0,0,16,0,16,16,0,16,0,0,16,0,16,16,16,16,0,0,16,16,0,0,0,16,0,0,16,16,0,0,16,16,0,0,16,16,0,16,0,16,0,0,16,16,0,16,16,16,0,0,16,16,16,0,0,16,0,0,16,16,16,0,16,16,0,0,16,16,16,16,0,16,0,0,16,16,16,16,16,16,0,16,0,0,0,0,0,16,0,16,0,0,0,0,16,16,0,16,0,0,0,16,0,16,0,16,0,0,0,16,16,16,0,16,0,0,16,0,0,16,0,16,0,0,16,0,16,16,0,16,0,0,16,16,0,16,0,16,0,0,16,16,16,16,0,16,0,16,0,0,0,16,0,16,0,16,0,0,16,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,16,16,0,16,0,16,16,0,0,16,0,16,0,16,16,0,16,16,0,16,0,16,16,16,0,16,0,16,0,16,16,16,16,16,0,16,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+703616);
/* memory initializer */ allocate([16,0,16,16,0,0,0,16,16,0,16,16,0,0,16,0,16,0,16,16,0,0,16,16,16,0,16,16,0,16,0,0,16,0,16,16,0,16,0,16,16,0,16,16,0,16,16,0,16,0,16,16,0,16,16,16,16,0,16,16,16,0,0,0,16,0,16,16,16,0,0,16,16,0,16,16,16,0,16,0,16,0,16,16,16,0,16,16,16,0,16,16,16,16,0,0,16,0,16,16,16,16,0,16,16,0,16,16,16,16,16,0,16,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,16,16,0,0,0,0,0,16,16,16,0,0,0,0,16,0,16,16,0,0,0,0,16,16,16,16,0,0,0,16,0,0,16,16,0,0,0,16,0,16,16,16,0,0,0,16,16,0,16,16,0,0,0,16,16,16,16,16,0,0,16,0,0,0,16,16,0,0,16,0,0,16,16,16,0,0,16,0,16,0,16,16,0,0,16,0,16,16,16,16,0,0,16,16,0,0,16,16,0,0,16,16,0,16,16,16,0,0,16,16,16,0,16,16,0,0,16,16,16,16,16,16,0,16,0,0,0,0,16,16,0,16,0,0,0,16,16,16,0,16,0,0,16,0,16,16,0,16,0,0,16,16,16,16,0,16,0,16,0,0,16,16,0,16,0,16,0,16,16,16,0,16,0,16,16,0,16,16,0,16,0,16,16,16,16,16,0,16,16,0,0,0,16,16,0,16,16,0,0,16,16,16,0,16,16,0,16,0,16,16,0,16,16,0,16,16,16,16,0,16,16,16,0,0,16,16,0,16,16,16,0,16,16,16,0,16,16,16,16,0,16,16,0,16,16,16,16,16,16,16,16,0,0,0,0,0,16,16,16,0,0,0,0,16,16,16,16,0,0,0,16,0,16,16,16,0,0,0,16,16,16,16,16,0,0,16,0,0,16,16,16,0,0,16,0,16,16,16,16,0,0,16,16,0,16,16,16,0,0,16,16,16,16,16,16,0,16,0,0,0,16,16,16,0,16,0,0,16,16,16,16,0,16,0,16,0,16,16,16,0,16,0,16,16,16,16,16,0,16,16,0,0,16,16,16,0,16,16,0,16,16,16,16,0,16,16,16,0,16,16,16,0,16,16,16,16,16,16,16,16,0,0,0,0,16,16,16,16,0,0,0,16,16,16,16,16,0,0,16,0,16,16,16,16,0,0,16,16,16,16,16,16,0,16,0,0,16,16,16,16,0,16,0,16,16,16,16,16,0,16,16,0,16,16,16,16,0,16,16,16,16,16,16,16,16,0,0,0,16,16,16,16,16,0,0,16,16,16,16,16,16,0,16,0,16,16,16,16,16,0,16,16,16,16,16,16,16,16,0,0,16,16,16,16,16,16,0,16,16,16,16,16,16,16,16,0,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,32,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,32,0,0,0,0,0,32,32,0,0,0,0,0,0,32,32,32,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,32,0,0,0,0,32,0,32,0,0,0,0,0,32,0,32,32,0,0,0,0,32,32,0,0,0,0,0,0,32,32,0,32,0,0,0,0,32,32,32,0,0,0,0,0,32,32,32,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,32,0,0,0,0,32,0,0,32,32,0,0,0,32,0,32,0,0,0,0,0,32,0,32,0,32,0,0,0,32,0,32,32,0,0,0,0,32,0,32,32,32,0,0,0,32,32,0,0,0,0,0,0,32,32,0,0,32,0,0,0,32,32,0,32,0,0,0,0,32,32,0,32,32,0,0,0,32,32,32,0,0,0,0,0,32,32,32,0,32,0,0,0,32,32,32,32,0,0,0,0,32,32,32,32,32,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,32,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,32,0,0,32,0,0,32,0,0,0,0,32,0,0,32,0,32,0,0,32,0,0,32,32,0,0,0,32,0,0,32,32,32,0,0,32,0,32,0,0,0,0,0,32,0,32,0,0,32,0,0,32,0,32,0,32,0,0,0,32,0,32,0,32,32,0,0,32,0,32,32,0,0,0,0,32,0,32,32,0,32,0,0,32,0,32,32,32,0,0,0,32,0,32,32,32,32,0,0,32,32,0,0,0,0,0,0,32,32,0,0,0,32,0,0,32,32,0,0,32,0,0,0,32,32,0,0,32,32,0,0,32,32,0,32,0,0,0,0,32,32,0,32,0,32,0,0,32,32,0,32,32,0,0,0,32,32,0,32,32,32,0,0,32,32,32,0,0,0,0,0,32,32,32,0,0,32,0,0,32,32,32,0,32,0,0,0,32,32,32,0,32,32,0,0,32,32,32,32,0,0,0,0,32,32,32,32,0,32,0,0,32,32,32,32,32,0,0,0,32,32,32,32,32,32,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,32,0,32,0,0,0,0,32,0,0,32,0,0,0,0,32,32,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,32,0,32,0,0,0,32,32,0,0,32,0,0,0,32,32,32,0,32,0,0,32,0,0,0,0,32,0,0,32,0,0,32,0,32,0,0,32,0,32,0,0,32,0,0,32,0,32,32,0,32,0,0,32,32,0,0,0,32,0,0,32,32,0,32,0,32,0,0,32,32,32,0,0,32,0,0,32,32,32,32,0,32,0,32,0,0,0,0,0,32,0,32,0,0,0,32,0,32,0,32,0,0,32,0,0,32,0,32,0,0,32,32,0,32,0,32,0,32,0,0,0,32,0,32,0,32,0,32,0,32,0,32,0,32,32,0,0,32,0,32,0,32,32,32,0,32,0,32,32,0,0,0,0,32,0,32,32,0,0,32,0,32,0,32,32,0,32,0,0,32,0,32,32,0,32,32,0,32,0,32,32,32,0,0,0,32,0,32,32,32,0,32,0,32,0,32,32,32,32,0,0,32,0,32,32,32,32,32,0,32,32,0,0,0,0,0,0,32,32,0,0,0,0,32,0,32,32,0,0,0,32,0,0,32,32,0,0,0,32,32,0,32,32,0,0,32,0,0,0,32,32,0,0,32,0,32,0,32,32,0,0,32,32,0,0,32,32,0,0,32,32,32,0,32,32,0,32,0,0,0,0,32,32,0,32,0,0,32,0,32,32,0,32,0,32,0,0,32,32,0,32,0,32,32,0,32,32,0,32,32,0,0,0,32,32,0,32,32,0,32,0,32,32,0,32,32,32,0,0,32,32,0,32,32,32,32,0,32,32,32,0,0,0,0,0,32,32,32,0,0,0,32,0,32,32,32,0,0,32,0,0,32,32,32,0,0,32,32,0,32,32,32,0,32,0,0,0,32,32,32,0,32,0,32,0,32,32,32,0,32,32,0,0,32,32,32,0,32,32,32,0,32,32,32,32,0,0,0,0,32,32,32,32,0,0,32,0,32,32,32,32,0,32,0,0,32,32,32,32,0,32,32,0,32,32,32,32,32,0,0,0,32,32,32,32,32,0,32,0,32,32,32,32,32,32,0,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,32,32,0,0,0,0,0,32,0,32,0,0,0,0,0,32,32,32,0,0,0,0,32,0,0,32,0,0,0,0,32,0,32,32,0,0,0,0,32,32,0,32,0,0,0,0,32,32,32,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,32,32,0,0,0,32,0,32,0,32,0,0,0,32,0,32,32,32,0,0,0,32,32,0,0,32,0,0,0,32,32,0,32,32,0,0,0,32,32,32,0,32,0,0,0,32,32,32,32,32,0,0,32,0,0,0,0,32,0,0,32,0,0,0,32,32,0,0,32,0,0,32,0,32,0,0,32,0,0,32,32,32,0,0,32,0,32,0,0,32,0,0,32,0,32,0,32,32,0,0,32,0,32,32,0,32,0,0,32,0,32,32,32,32,0,0,32,32,0,0,0,32,0,0,32,32,0,0,32,32,0,0,32,32,0,32,0,32,0,0,32,32,0,32,32,32,0,0,32,32,32,0,0,32,0,0,32,32,32,0,32,32,0,0,32,32,32,32,0,32,0,0,32,32,32,32,32,32,0,32,0,0,0,0,0,32,0,32,0,0,0,0,32,32,0,32,0,0,0,32,0,32,0,32,0,0,0,32,32,32,0,32,0,0,32,0,0,32,0,32,0,0,32,0,32,32,0,32,0,0,32,32,0,32,0,32,0,0,32,32,32,32,0,32,0,32,0,0,0,32,0,32,0,32,0,0,32,32,0,32,0,32,0,32,0,32,0,32,0,32,0,32,32,32,0,32,0,32,32,0,0,32,0,32,0,32,32,0,32,32,0,32,0,32,32,32,0,32,0,32,0,32,32,32,32,32,0,32,32,0,0,0,0,32,0,32,32,0,0,0,32,32,0,32,32,0,0,32,0,32,0,32,32,0,0,32,32,32,0,32,32,0,32,0,0,32,0,32,32,0,32,0,32,32,0,32,32,0,32,32,0,32,0,32,32,0,32,32,32,32,0,32,32,32,0,0,0,32,0,32,32,32,0,0,32,32,0,32,32,32,0,32,0,32,0,32,32,32,0,32,32,32,0,32,32,32,32,0,0,32,0,32,32,32,32,0,32,32,0,32,32,32,32,32,0,32,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,32,32,0,0,0,0,0,32,32,32,0,0,0,0,32,0,32,32,0,0,0,0,32,32,32,32,0,0,0,32,0,0,32,32,0,0,0,32,0,32,32,32,0,0,0,32,32,0,32,32,0,0,0,32,32,32,32,32,0,0,32,0,0,0,32,32,0,0,32,0,0,32,32,32,0,0,32,0,32,0,32,32,0,0,32,0,32,32,32,32,0,0,32,32,0,0,32,32,0,0,32,32,0,32,32,32,0,0,32,32,32,0,32,32,0,0,32,32,32,32,32,32,0,32,0,0,0,0,32,32,0,32,0,0,0,32,32,32,0,32,0,0,32,0,32,32,0,32,0,0,32,32,32,32,0,32,0,32,0,0,32,32,0,32,0,32,0,32,32,32,0,32,0,32,32,0,32,32,0,32,0,32,32,32,32,32,0,32,32,0,0,0,32,32,0,32,32,0,0,32,32,32,0,32,32,0,32,0,32,32,0,32,32,0,32,32,32,32,0,32,32,32,0,0,32,32,0,32,32,32,0,32,32,32,0,32,32,32,32,0,32,32,0,32,32,32,32,32,32,32,32,0,0,0,0,0,32,32,32,0,0,0,0,32,32,32,32,0,0,0,32,0,32,32,32,0,0,0,32,32,32,32,32,0,0,32,0,0,32,32,32,0,0,32,0,32,32,32,32,0,0,32,32,0,32,32,32,0,0,32,32,32,32,32,32,0,32,0,0,0,32,32,32,0,32,0,0,32,32,32,32,0,32,0,32,0,32,32,32,0,32,0,32,32,32,32,32,0,32,32,0,0,32,32,32,0,32,32,0,32,32,32,32,0,32,32,32,0,32,32,32,0,32,32,32,32,32,32,32,32,0,0,0,0,32,32,32,32,0,0,0,32,32,32,32,32,0,0,32,0,32,32,32,32,0,0,32,32,32,32,32,32,0,32,0,0,32,32,32,32,0,32,0,32,32,32,32,32,0,32,32,0,32,32,32,32,0,32,32,32,32,32,32,32,32,0,0,0,32,32,32,32,32,0,0,32,32,32,32,32,32,0,32,0,32,32,32,32,32,0,32,32,32,32,32,32,32,32,0,0,32,32,32,32,32,32,0,32,32,32,32,32,32,32,32,0,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,64,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,64,0,0,0,0,0,64,64,0,0,0,0,0,0,64,64,64,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,64,0,0,0,0,64,0,64,0,0,0,0,0,64,0,64,64,0,0,0,0,64,64,0,0,0,0,0,0,64,64,0,64,0,0,0,0,64,64,64,0,0,0,0,0,64,64,64,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,64,0,0,0,0,64,0,0,64,64,0,0,0,64,0,64,0,0,0,0,0,64,0,64,0,64,0,0,0,64,0,64,64,0,0,0,0,64,0,64,64,64,0,0,0,64,64,0,0,0,0,0,0,64,64,0,0,64,0,0,0,64,64,0,64,0,0,0,0,64,64,0,64,64,0,0,0,64,64,64,0,0,0,0,0,64,64,64,0,64,0,0,0,64,64,64,64,0,0,0,0,64,64,64,64,64,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,64,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,64,0,0,64,0,0,64,0,0,0,0,64,0,0,64,0,64,0,0,64,0,0,64,64,0,0,0,64,0,0,64,64,64,0,0,64,0,64,0,0,0,0,0,64,0,64,0,0,64,0,0,64,0,64,0,64,0,0,0,64,0,64,0,64,64,0,0,64,0,64,64,0,0,0,0,64,0,64,64,0,64,0,0,64,0,64,64,64,0,0,0,64,0,64,64,64,64,0,0,64,64,0,0,0,0,0,0,64,64,0,0,0,64,0,0,64,64,0,0,64,0,0,0,64,64,0,0,64,64,0,0,64,64,0,64,0,0,0,0,64,64,0,64,0,64,0,0,64,64,0,64,64,0,0,0,64,64,0,64,64,64,0,0,64,64,64,0,0,0,0,0,64,64,64,0,0,64,0,0,64,64,64,0,64,0,0,0,64,64,64,0,64,64,0,0,64,64,64,64,0,0,0,0,64,64,64,64,0,64,0,0,64,64,64,64,64,0,0,0,64,64,64,64,64,64,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,64,0,64,0,0,0,0,64,0,0,64,0,0,0,0,64,64,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,64,0,64,0,0,0,64,64,0,0,64,0,0,0,64,64,64,0,64,0,0,64,0,0,0,0,64,0,0,64,0,0,64,0,64,0,0,64,0,64,0,0,64,0,0,64,0,64,64,0,64,0,0,64,64,0,0,0,64,0,0,64,64,0,64,0,64,0,0,64,64,64,0,0,64,0,0,64,64,64,64,0,64,0,64,0,0,0,0,0,64,0,64,0,0,0,64,0,64,0,64,0,0,64,0,0,64,0,64,0,0,64,64,0,64,0,64,0,64,0,0,0,64,0,64,0,64,0,64,0,64,0,64,0,64,64,0,0,64,0,64,0,64,64,64,0,64,0,64,64,0,0,0,0,64,0,64,64,0,0,64,0,64,0,64,64,0,64,0,0,64,0,64,64,0,64,64,0,64,0,64,64,64,0,0,0,64,0,64,64,64,0,64,0,64,0,64,64,64,64,0,0,64,0,64,64,64,64,64,0,64,64,0,0,0,0,0,0,64,64,0,0,0,0,64,0,64,64,0,0,0,64,0,0,64,64,0,0,0,64,64,0,64,64,0,0,64,0,0,0,64,64,0,0,64,0,64,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,64,0,64,64,0,64,0,0,0,0,64,64,0,64,0,0,64,0,64,64,0,64,0,64,0,0,64,64,0,64,0,64,64,0,64,64,0,64,64,0,0,0,64,64,0,64,64,0,64,0,64,64,0,64,64,64,0,0,64,64,0,64,64,64,64,0,64,64,64,0,0,0,0,0,64,64,64,0,0,0,64,0,64,64,64,0,0,64,0,0,64,64,64,0,0,64,64,0,64,64,64,0,64,0,0,0,64,64,64,0,64,0,64,0,64,64,64,0,64,64,0,0,64,64,64,0,64,64,64,0,64,64,64,64,0,0,0,0,64,64,64,64,0,0,64,0,64,64,64,64,0,64,0,0,64,64,64,64,0,64,64,0,64,64,64,64,64,0,0,0,64,64,64,64,64,0,64,0,64,64,64,64,64,64,0,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,64,64,0,0,0,0,0,64,0,64,0,0,0,0,0,64,64,64,0,0,0,0,64,0,0,64,0,0,0,0,64,0,64,64,0,0,0,0,64,64,0,64,0,0,0,0,64,64,64,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,64,64,0,0,0,64,0,64,0,64,0,0,0,64,0,64,64,64,0,0,0,64,64,0,0,64,0,0,0,64,64,0,64,64,0,0,0,64,64,64,0,64,0,0,0,64,64,64,64,64,0,0,64,0,0,0,0,64,0,0,64,0,0,0,64,64,0,0,64,0,0,64,0,64,0,0,64,0,0,64,64,64,0,0,64,0,64,0,0,64,0,0,64,0,64,0,64,64,0,0,64,0,64,64,0,64,0,0,64,0,64,64,64,64,0,0,64,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,64,64,0,64,0,64,0,0,64,64,0,64,64,64,0,0,64,64,64,0,0,64,0,0,64,64,64,0,64,64,0,0,64,64,64,64,0,64,0,0,64,64,64,64,64,64,0,64,0,0,0,0,0,64,0,64,0,0,0,0,64,64,0,64,0,0,0,64,0,64,0,64,0,0,0,64,64,64,0,64,0,0,64,0,0,64,0,64,0,0,64,0,64,64,0,64,0,0,64,64,0,64,0,64,0,0,64,64,64,64,0,64,0,64,0,0,0,64,0,64,0,64,0,0,64,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,64,64,0,64,0,64,64,0,0,64,0,64,0,64,64,0,64,64,0,64,0,64,64,64,0,64,0,64,0,64,64,64,64,64,0,64,64,0,0,0,0,64,0,64,64,0,0,0,64,64,0,64,64,0,0,64,0,64,0,64,64,0,0,64,64,64,0,64,64,0,64,0,0,64,0,64,64,0,64,0,64,64,0,64,64,0,64,64,0,64,0,64,64,0,64,64,64,64,0,64,64,64,0,0,0,64,0,64,64,64,0,0,64,64,0,64,64,64,0,64,0,64,0,64,64,64,0,64,64,64,0,64,64,64,64,0,0,64,0,64,64,64,64,0,64,64,0,64,64,64,64,64,0,64,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,64,64,0,0,0,0,0,64,64,64,0,0,0,0,64,0,64,64,0,0,0,0,64,64,64,64,0,0,0,64,0,0,64,64,0,0,0,64,0,64,64,64,0,0,0,64,64,0,64,64,0,0,0,64,64,64,64,64,0,0,64,0,0,0,64,64,0,0,64,0,0,64,64,64,0,0,64,0,64,0,64,64,0,0,64,0,64,64,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,64,64,64,0,0,64,64,64,0,64,64,0,0,64,64,64,64,64,64,0,64,0,0,0,0,64,64,0,64,0,0,0,64,64,64,0,64,0,0,64,0,64,64,0,64,0,0,64,64,64,64,0,64,0,64,0,0,64,64,0,64,0,64,0,64,64,64,0,64,0,64,64,0,64,64,0,64,0,64,64,64,64,64,0,64,64,0,0,0,64,64,0,64,64,0,0,64,64,64,0,64,64,0,64,0,64,64,0,64,64,0,64,64,64,64,0,64,64,64,0,0,64,64,0,64,64,64,0,64,64,64,0,64,64,64,64,0,64,64,0,64,64,64,64,64,64,64,64,0,0,0,0,0,64,64,64,0,0,0,0,64,64,64,64,0,0,0,64,0,64,64,64,0,0,0,64,64,64,64,64,0,0,64,0,0,64,64,64,0,0,64,0,64,64,64,64,0,0,64,64,0,64,64,64,0,0,64,64,64,64,64,64,0,64,0,0,0,64,64,64,0,64,0,0,64,64,64,64,0,64,0,64,0,64,64,64,0,64,0,64,64,64,64,64,0,64,64,0,0,64,64,64,0,64,64,0,64,64,64,64,0,64,64,64,0,64,64,64,0,64,64,64,64,64,64,64,64,0,0,0,0,64,64,64,64,0,0,0,64,64,64,64,64,0,0,64,0,64,64,64,64,0,0,64,64,64,64,64,64,0,64,0,0,64,64,64,64,0,64,0,64,64,64,64,64,0,64,64,0,64,64,64,64,0,64,64,64,64,64,64,64,64,0,0,0,64,64,64,64,64,0,0,64,64,64,64,64,64,0,64,0,64,64,64,64,64,0,64,64,64,64,64,64,64,64,0,0,64,64,64,64,64,64,0,64,64,64,64,64,64,64,64,0,64,64,64,64,64,64,64,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,128,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,128,0,0,0,0,0,128,128,0,0,0,0,0,0,128,128,128,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,128,0,0,0,0,128,0,128,0,0,0,0,0,128,0,128,128,0,0,0,0,128,128,0,0,0,0,0,0,128,128,0,128,0,0,0,0,128,128,128,0,0,0,0,0,128,128,128,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,128,0,0,0,0,128,0,0,128,128,0,0,0,128,0,128,0,0,0,0,0,128,0,128,0,128,0,0,0,128,0,128,128,0,0,0,0,128,0,128,128,128,0,0,0,128,128,0,0,0,0,0,0,128,128,0,0,128,0,0,0,128,128,0,128,0,0,0,0,128,128,0,128,128,0,0,0,128,128,128,0,0,0,0,0,128,128,128,0,128,0,0,0,128,128,128,128,0,0,0,0,128,128,128,128,128,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,128,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,128,0,0,128,0,0,128,0,0,0,0,128,0,0,128,0,128,0,0,128,0,0,128,128,0,0,0,128,0,0,128,128,128,0,0,128,0,128,0,0,0,0,0,128,0,128,0,0,128,0,0,128,0,128,0,128,0,0,0,128,0,128,0,128,128,0,0,128,0,128,128,0,0,0,0,128,0,128,128,0,128,0,0,128,0,128,128,128,0,0,0,128,0,128,128,128,128,0,0,128,128,0,0,0,0,0,0,128,128,0,0,0,128,0,0,128,128,0,0,128,0,0,0,128,128,0,0,128,128,0,0,128,128,0,128,0,0,0,0,128,128,0,128,0,128,0,0,128,128,0,128,128,0,0,0,128,128,0,128,128,128,0,0,128,128,128,0,0,0,0,0,128,128,128,0,0,128,0,0,128,128,128,0,128,0,0,0,128,128,128,0,128,128,0,0,128,128,128,128,0,0,0,0,128,128,128,128,0,128,0,0,128,128,128,128,128,0,0,0,128,128,128,128,128,128,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,128,0,128,0,0,0,0,128,0,0,128,0,0,0,0,128,128,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,128,0,128,0,0,0,128,128,0,0,128,0,0,0,128,128,128,0,128,0,0,128,0,0,0,0,128,0,0,128,0,0,128,0,128,0,0,128,0,128,0,0,128,0,0,128,0,128,128,0,128,0,0,128,128,0,0,0,128,0,0,128,128,0,128,0,128,0,0,128,128,128,0,0,128,0,0,128,128,128,128,0,128,0,128,0,0,0,0,0,128,0,128,0,0,0,128,0,128,0,128,0,0,128,0,0,128,0,128,0,0,128,128,0,128,0,128,0,128,0,0,0,128,0,128,0,128,0,128,0,128,0,128,0,128,128,0,0,128,0,128,0,128,128,128,0,128,0,128,128,0,0,0,0,128,0,128,128,0,0,128,0,128,0,128,128,0,128,0,0,128,0,128,128,0,128,128,0,128,0,128,128,128,0,0,0,128,0,128,128,128,0,128,0,128,0,128,128,128,128,0,0,128,0,128,128,128,128,128,0,128,128,0,0,0,0,0,0,128,128,0,0,0,0,128,0,128,128,0,0,0,128,0,0,128,128,0,0,0,128,128,0,128,128,0,0,128,0,0,0,128,128,0,0,128,0,128,0,128,128,0,0,128,128,0,0,128,128,0,0,128,128,128,0,128,128,0,128,0,0,0,0,128,128,0,128,0,0,128,0,128,128,0,128,0,128,0,0,128,128,0,128,0,128,128,0,128,128,0,128,128,0,0,0,128,128,0,128,128,0,128,0,128,128,0,128,128,128,0,0,128,128,0,128,128,128,128,0,128,128,128,0,0,0,0,0,128,128,128,0,0,0,128,0,128,128,128,0,0,128,0,0,128,128,128,0,0,128,128,0,128,128,128,0,128,0,0,0,128,128,128,0,128,0,128,0,128,128,128,0,128,128,0,0,128,128,128,0,128,128,128,0,128,128,128,128,0,0,0,0,128,128,128,128,0,0,128,0,128,128,128,128,0,128,0,0,128,128,128,128,0,128,128,0,128,128,128,128,128,0,0,0,128,128,128,128,128,0,128,0,128,128,128,128,128,128,0,0,128,128,128,128,128,128,128,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,128,128,0,0,0,0,0,128,0,128,0,0,0,0,0,128,128,128,0,0,0,0,128,0,0,128,0,0,0,0,128,0,128,128,0,0,0,0,128,128,0,128,0,0,0,0,128,128,128,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,128,128,0,0,0,128,0,128,0,128,0,0,0,128,0,128,128,128,0,0,0,128,128,0,0,128,0,0,0,128,128,0,128,128,0,0,0,128,128,128,0,128,0,0,0,128,128,128,128,128,0,0,128,0,0,0,0,128,0,0,128,0,0,0,128,128,0,0,128,0,0,128,0,128,0,0,128,0,0,128,128,128,0,0,128,0,128,0,0,128,0,0,128,0,128,0,128,128,0,0,128,0,128,128,0,128,0,0,128,0,128,128,128,128,0,0,128,128,0,0,0,128,0,0,128,128,0,0,128,128,0,0,128,128,0,128,0,128,0,0,128,128,0,128,128,128,0,0,128,128,128,0,0,128,0,0,128,128,128,0,128,128,0,0,128,128,128,128,0,128,0,0,128,128,128,128,128,128,0,128,0,0,0,0,0,128,0,128,0,0,0,0,128,128,0,128,0,0,0,128,0,128,0,128,0,0,0,128,128,128,0,128,0,0,128,0,0,128,0,128,0,0,128,0,128,128,0,128,0,0,128,128,0,128,0,128,0,0,128,128,128,128,0,128,0,128,0,0,0,128,0,128,0,128,0,0,128,128,0,128,0,128,0,128,0,128,0,128,0,128,0,128,128,128,0,128,0,128,128,0,0,128,0,128,0,128,128,0,128,128,0,128,0,128,128,128,0,128,0,128,0,128,128,128,128,128,0,128,128,0,0,0,0,128,0,128,128,0,0,0,128,128,0,128,128,0,0,128,0,128,0,128,128,0,0,128,128,128,0,128,128,0,128,0,0,128,0,128,128,0,128,0,128,128,0,128,128,0,128,128,0,128,0,128,128,0,128,128,128,128,0,128,128,128,0,0,0,128,0,128,128,128,0,0,128,128,0,128,128,128,0,128,0,128,0,128,128,128,0,128,128,128,0,128,128,128,128,0,0,128,0,128,128,128,128,0,128,128,0,128,128,128,128,128,0,128,0,128,128,128,128,128,128,128,128,0,0,0,0,0,0,128,128,0,0,0,0,0,128,128,128,0,0,0,0,128,0,128,128,0,0,0,0,128,128,128,128,0,0,0,128,0,0,128,128,0,0,0,128,0,128,128,128,0,0,0,128,128,0,128,128,0,0,0,128,128,128,128,128,0,0,128,0,0,0,128,128,0,0,128,0,0,128,128,128,0,0,128,0,128,0,128,128,0,0,128,0,128,128,128,128,0,0,128,128,0,0,128,128,0,0,128,128,0,128,128,128,0,0,128,128,128,0,128,128,0,0,128,128,128,128,128,128,0,128,0,0,0,0,128,128,0,128,0,0,0,128,128,128,0,128,0,0,128,0,128,128,0,128,0,0,128,128,128,128,0,128,0,128,0,0,128,128,0,128,0,128,0,128,128,128,0,128,0,128,128,0,128,128,0,128,0,128,128,128,128,128,0,128,128,0,0,0,128,128,0,128,128,0,0,128,128,128,0,128,128,0,128,0,128,128,0,128,128,0,128,128,128,128,0,128,128,128,0,0,128,128,0,128,128,128,0,128,128,128,0,128,128,128,128,0,128,128,0,128,128,128,128,128,128,128,128,0,0,0,0,0,128,128,128,0,0,0,0,128,128,128,128,0,0,0,128,0,128,128,128,0,0,0,128,128,128,128,128,0,0,128,0,0,128,128,128,0,0,128,0,128,128,128,128,0,0,128,128,0,128,128,128,0,0,128,128,128,128,128,128,0,128,0,0,0,128,128,128,0,128,0,0,128,128,128,128,0,128,0,128,0,128,128,128,0,128,0,128,128,128,128,128,0,128,128,0,0,128,128,128,0,128,128,0,128,128,128,128,0,128,128,128,0,128,128,128,0,128,128,128,128,128,128,128,128,0,0,0,0,128,128,128,128,0,0,0,128,128,128,128,128,0,0,128,0,128,128,128,128,0,0,128,128,128,128,128,128,0,128,0,0,128,128,128,128,0,128,0,128,128,128,128,128,0,128,128,0,128,128,128,128,0,128,128,128,128,128,128,128,128,0,0,0,128,128,128,128,128,0,0,128,128,128,128,128,128,0,128,0,128,128,128,128,128,0,128,128,128,128,128,128,128,128,0,0,128,128,128,128,128,128,0,128,128,128,128,128,128,128,128,0,128,128,128,128,128,128,128,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+713856);
/* memory initializer */ allocate([32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,88,227,39,0,112,0,0,0,112,159,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,2,0,0,0,8,0,0,0,1,0,0,0,10,0,0,0,1,0,0,0,12,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,24,0,0,0,11,0,0,0,20,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,80,0,0,0,33,0,0,0,18,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,64,0,0,0,33,0,0,0,160,0,0,0,99,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,70,0,0,0,76,0,0,0,255,255,255,255,0,0,0,0,3,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,12,0,0,0,4,0,0,0,13,0,0,0,5,0,0,0,14,0,0,0,25,0,0,0,112,0,0,0,255,255,255,255,0,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,113,0,0,0,255,255,255,255,0,0,0,0,9,0,0,0,1,0,0,0,11,0,0,0,2,0,0,0,11,0,0,0,4,0,0,0,11,0,0,0,8,0,0,0,45,0,0,0,16,0,0,0,2,0,0,0,24,0,0,0,27,0,0,0,32,0,0,0,9,0,0,0,33,0,0,0,255,255,255,255,0,0,0,0,9,0,0,0,1,0,0,0,11,0,0,0,2,0,0,0,11,0,0,0,4,0,0,0,11,0,0,0,8,0,0,0,62,0,0,0,12,0,0,0,46,0,0,0,15,0,0,0,46,0,0,0,16,0,0,0,3,0,0,0,24,0,0,0,30,0,0,0,32,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,154,153,153,62,205,204,12,63,51,51,51,63,205,204,76,63,102,102,102,63,0,0,128,63,154,153,153,63,60,0,0,0,0,0,185,9,60,0,0,0,0,0,97,20,1,0,27,24,0,0,113,15,0,0,124,40,1,0,141,36,255,255,139,34,1,0,180,36,0,0,162,22,255,255,64,42,2,0,86,45,254,255,40,47,0,0,168,33,1,0,138,47,0,0,104,56,0,0,107,30,255,255,153,53,0,0,29,71,0,0,135,56,0,0,191,61,1,0,171,59,0,0,168,52,255,255,199,71,255,255,0,0,1,0,186,43,255,255,210,50,1,0,148,73,254,255,130,79,1,0,105,63,255,255,0,0,60,0,0,0,0,0,98,47,0,0,73,52,1,0,170,69,1,0,139,81,0,0,236,85,1,0,0,0,1,0,101,71,255,255,73,83,1,0,170,53,255,255,150,74,255,255,163,79,255,255,0,0,0,0,16,82,60,0,0,0,254,255,23,89,0,0,28,62,1,0,0,0,0,0,69,70,255,255,243,86,1,0,75,95,1,0,98,90,0,0,140,93,1,0,213,89,2,0,76,88,255,255,86,101,0,0,134,102,1,0,233,98,0,0,55,103,0,0,253,93,0,0,111,106,60,0,0,0,255,255,228,99,1,0,110,93,1,0,74,101,2,0,40,103,255,255,105,74,1,0,221,106,255,255,218,95,60,0,0,0,255,255,5,98,0,0,133,111,1,0,0,0,0,0,9,89,255,255,59,100,0,0,193,114,0,0,68,118,0,0,86,102,1,0,249,87,255,255,247,112,0,0,248,106,1,0,210,117,255,255,0,0,0,0,173,94,255,255,110,117,0,0,3,85,1,0,197,120,60,0,0,0,0,0,52,122,0,0,249,114,1,0,197,104,1,0,239,111,0,0,95,122,2,0,79,120,1,0,157,122,0,0,66,126,1,0,16,124,254,255,86,124,0,0,56,105,255,255,204,121,1,0,155,120,0,0,225,108,255,255,221,118,1,0,74,121,0,0,0,0,0,0,168,124,1,0,123,123,0,0,77,123,0,0,213,99,0,0,125,122,60,0,0,0,1,0,96,115,1,0,57,113,255,255,104,105,255,255,99,123,2,0,116,120,254,255,157,121,0,0,35,118,255,255,22,120,255,255,90,125,60,0,0,0,2,0,182,120,60,0,0,0,0,0,75,117,0,0,114,113,60,0,0,0,0,0,12,124,0,0,233,95,0,0,36,100,254,255,37,119,60,0,0,0,255,255,177,115,0,0,185,119,60,0,0,0,0,0,90,114,2,0,207,118,0,0,88,107,0,0,237,121,255,255,243,109,0,0,136,119,1,0,164,123,2,0,140,113,60,0,0,0,1,0,155,111,1,0,58,112,1,0,190,122,0,0,97,110,0,0,221,96,60,0,0,0,0,0,0,0,60,0,0,0,0,0,89,86,0,0,204,108,60,0,0,0,60,0,0,0,255,255,150,94,0,0,66,96,0,0,9,91,60,0,0,0,60,0,0,0,1,0,99,89,0,0,97,84,60,0,0,0,2,0,50,100,60,0,0,0,254,255,21,122,254,255,56,98,0,0,78,70,232,48,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,3,37,0,152,190,35,0,4,0,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,64,16,0,1,0,40,3,37,0,48,214,34,0,48,21,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,48,123,33,0,208,1,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,192,156,32,0,224,65,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,152,41,40,0,40,202,39,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,40,99,39,0,24,21,39,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,240,208,38,0,144,140,38,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,32,81,38,0,40,26,38,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,112,238,37,0,8,193,37,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,32,159,37,0,128,115,37,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,40,3,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,48,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,3,0,0,0,0,0,0,0,0,0,0,194,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,57,254,44,244,4,54,245,216,233,90,29,220,255,8,245,31,244,215,18,136,11,23,223,201,14,175,5,131,8,66,222,115,31,200,247,81,250,9,3,84,4,174,246,206,8,148,254,93,253,200,247,158,23,206,233,48,4,51,12,61,236,192,20,230,246,111,241,12,27,206,240,163,2,16,249,29,0,161,39,66,118,247,14,59,240,156,11,231,251,21,252,173,9,28,244,255,10,72,247,217,6,180,249,178,6,16,249,7,6,15,252,173,1,86,255,216,1,15,251,128,8,109,245,219,9,170,249,88,1,58,3,6,250,188,6,134,249,165,6,240,247,84,10,11,244,81,11,69,248,45,2,12,3,166,250,74,3,143,2,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,145,35,0,112,0,0,0,32,36,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,89,32,0,112,0,0,0,16,165,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,161,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,3,37,0,248,190,35,0,4,0,0,0,5,0,0,0,72,214,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,184,21,34,0,104,123,33,0,8,0,0,0,5,0,0,0,72,214,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,16,2,33,0,40,157,32,0,12,0,0,0,5,0,0,0,56,66,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,208,41,40,0,224,202,39,0,16,0,0,0,5,0,0,0,72,214,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,184,99,39,0,72,21,39,0,20,0,0,0,5,0,0,0,72,214,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,32,209,38,0,176,140,38,0,24,0,0,0,5,0,0,0,112,81,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,26,38,0,208,238,37,0,28,0,0,0,5,0,0,0,56,66,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,24,193,37,0,64,159,37,0,32,0,0,0,5,0,0,0,112,81,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,224,115,37,0,48,49,37,0,108,16,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,224,115,37,0,8,9,37,0,160,26,156,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,115,37,0,48,190,36,0,160,26,156,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,115,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,161,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,2,0,0,0,0,0,0,0,0,0,0,36,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,150,35,0,112,0,0,0,112,40,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,254,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,254,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,114,37,0,112,0,0,0,112,186,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,72,37,0,192,23,37,0,51,115,174,103,80,93,251,83,149,75,6,68,57,61,26,55,151,49,161,44,0,64,0,32,0,16,0,8,0,4,0,2,0,1,128,0,64,0,32,0,200,143,34,0,192,25,156,0,4,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,208,111,34,0,192,25,156,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,187,0,0,0,119,1,0,68,172,0,0,0,125,0,0,0,1,0,2,3,3,4,4,5,6,7,8,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,7,0,0,0,3,1,0,0,7,1,0,0,3,6,0,0,7,6,0,0,15,6,0,0,55,6,0,0,63,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,20,24,0,0,0,0,8,0,0,0,0,8,0,0,0,0,8,32,0,0,0,8,0,0,0,1,8,16,0,0,0,8,0,0,0,2,8,1,0,0,0,8,0,0,0,16,8,2,0,0,0,6,0,0,0,6,32,0,0,6,0,0,1,6,16,0,0,6,0,0,2,6,0,16,0,6,0,32,0,6,0,2,0,6,0,1,0,6,1,0,0,6,0,0,32,6,2,0,0,6,0,0,16,6,16,0,32,6,1,0,2,6,32,0,16,6,2,0,1,6,32,16,0,6,0,18,0,6,0,2,1,6,2,1,0,6,0,33,0,6,0,1,2,6,0,32,16,6,0,0,33,6,0,0,18,6,0,1,32,6,18,0,0,6,0,16,32,6,1,32,0,6,2,16,0,6,16,32,0,6,1,2,0,6,33,0,0,6,0,2,16,6,32,1,0,6,0,34,0,6,16,2,0,6,0,16,2,6,17,0,0,6,0,17,0,6,34,0,0,6,32,0,2,6,16,0,1,6,0,32,1,6,2,32,0,6,1,16,0,6,1,0,32,6,0,32,2,6,1,32,2,6,16,1,0,6,2,0,16,6,0,16,1,6,16,1,32,6,32,2,16,6,0,0,34,6,16,0,2,6,0,2,32,6,32,2,0,6,0,0,17,6,2,16,1,6,0,1,16,6,0,2,17,4,1,2,4,2,1,4,1,0,4,16,32,4,32,16,4,32,0,4,17,0,4,2,0,4,18,0,4,0,33,4,34,0,4,0,18,4,33,0,4,2,17,4,0,1,4,16,2,4,2,32,4,32,17,4,1,16,4,33,16,4,16,0,4,16,34,4,32,32,4,0,34,4,1,34,4,32,1,4,2,2,4,0,32,4,0,16,4,0,17,4,34,1,4,17,32,4,18,1,4,18,32,4,17,2,4,16,16,4,1,1,4,2,33,4,32,18,4,1,18,4,34,17,4,33,18,4,34,16,4,33,2,4,32,2,4,16,1,4,0,2,4,16,33,4,1,32,4,17,34,4,18,33,4,34,32,4,2,16,4,2,34,4,17,16,4,34,2,4,32,33,4,1,17,4,17,1,4,16,18,4,2,18,4,32,34,4,33,32,4,1,33,4,18,2,4,33,17,4,18,34,4,18,16,4,34,33,4,16,17,4,33,1,4,17,18,4,18,17,4,102,102,4,34,34,4,17,33,4,17,17,4,33,34,4,0,0,4,34,18,4,18,18,4,33,33,4,66,0,4,0,4,4,64,0,4,48,0,4,49,0,4,0,3,4,0,20,4,0,19,4,1,36,4,32,19,4,1,66,4,20,32,4,66,2,4,19,0,4,0,36,4,49,32,4,34,19,4,17,36,4,18,102,4,48,1,4,2,19,4,18,66,4,64,16,4,64,2,4,1,4,4,36,0,4,66,16,4,33,19,4,19,18,4,49,33,4,33,36,4,0,64,4,16,36,4,16,66,4,50,1,4,17,66,4,32,49,4,18,64,2,0,2,16,2,32,2,48,2,64,2,80,2,96,2,112,2,1,2,17,2,33,2,49,2,65,2,81,2,97,2,113,2,2,2,18,2,34,2,50,2,66,2,82,2,98,2,114,2,3,2,19,2,35,2,51,2,67,2,83,2,99,2,115,2,4,2,20,2,36,2,52,2,68,2,84,2,100,2,116,2,5,2,21,2,37,2,53,2,69,2,85,2,101,2,117,2,6,2,22,2,38,2,54,2,70,2,86,2,102,2,118,2,7,2,23,2,39,2,55,2,71,2,87,2,103,2,119,0,0,0,0,0,0,0,6,0,0,0,6,0,0,0,6,0,0,1,6,0,0,16,6,0,0,17,6,0,1,0,6,0,1,1,6,0,1,16,6,0,1,17,6,0,16,0,6,0,16,1,6,0,16,16,6,0,16,17,6,0,17,0,6,0,17,1,6,0,17,16,6,0,17,17,6,1,0,0,6,1,0,1,6,1,0,16,6,1,0,17,6,1,1,0,6,1,1,1,6,1,1,16,6,1,1,17,6,1,16,0,6,1,16,1,6,1,16,16,6,1,16,17,6,1,17,0,6,1,17,1,6,1,17,16,6,1,17,17,6,16,0,0,6,16,0,1,6,16,0,16,6,16,0,17,6,16,1,0,6,16,1,1,6,16,1,16,6,16,1,17,6,16,16,0,6,16,16,1,6,16,16,16,6,16,16,17,6,16,17,0,6,16,17,1,6,16,17,16,6,16,17,17,6,17,0,0,6,17,0,1,6,17,0,16,6,17,0,17,6,17,1,0,6,17,1,1,6,17,1,16,6,17,1,17,6,17,16,0,6,17,16,1,6,17,16,16,6,17,16,17,6,17,17,0,6,17,17,1,6,17,17,16,4,0,0,4,0,1,4,0,2,4,0,3,4,0,16,4,0,17,4,0,18,4,0,19,4,0,32,4,0,33,4,0,34,4,0,35,4,0,48,4,0,49,4,0,50,4,0,51,4,1,0,4,1,1,4,1,2,4,1,3,4,1,16,4,1,17,4,1,18,4,1,19,4,1,32,4,1,33,4,1,34,4,1,35,4,1,48,4,1,49,4,1,50,4,1,51,4,2,0,4,2,1,4,2,2,4,2,3,4,2,16,4,2,17,4,2,18,4,2,19,4,2,32,4,2,33,4,2,34,4,2,35,4,2,48,4,2,49,4,2,50,4,2,51,4,3,0,4,3,1,4,3,2,4,3,3,4,3,16,4,3,17,4,3,18,4,3,19,4,3,32,4,3,33,4,3,34,4,3,35,4,3,48,4,3,49,4,3,50,4,3,51,4,16,0,4,16,1,4,16,2,4,16,3,4,16,16,4,16,17,4,16,18,4,16,19,4,16,32,4,16,33,4,16,34,4,16,35,4,16,48,4,16,49,4,16,50,4,16,51,4,17,0,4,17,1,4,17,2,4,17,3,4,17,16,4,17,17,4,17,18,4,17,19,4,17,32,4,17,33,4,17,34,4,17,35,4,17,48,4,17,49,4,17,50,4,17,51,4,18,0,4,18,1,4,18,2,4,18,3,4,18,16,4,18,17,4,18,18,4,18,19,4,18,32,4,18,33,4,18,34,4,18,35,4,18,48,4,18,49,4,18,50,4,18,51,4,19,0,4,19,1,4,19,2,4,19,3,4,19,16,4,19,17,4,19,18,4,19,19,4,19,32,4,19,33,4,19,34,4,19,35,4,19,48,4,19,49,4,19,50,4,19,51,2,0,2,16,2,32,2,48,2,64,2,80,2,96,2,112,2,1,2,17,2,33,2,49,2,65,2,81,2,97,2,113,2,2,2,18,2,34,2,50,2,66,2,82,2,98,2,114,2,3,2,19,2,35,2,51,2,67,2,83,2,99,2,115,2,4,2,20,2,36,2,52,2,68,2,84,2,100,2,116,2,5,2,21,2,37,2,53,2,69,2,85,2,101,2,117,2,6,2,22,2,38,2,54,2,70,2,86,2,102,2,118,2,7,2,23,2,39,2,55,2,71,2,87,2,103,2,119,8,0,0,0,0,8,0,0,0,0,8,16,0,0,0,8,1,0,0,0,8,0,16,0,0,8,0,1,0,0,8,0,0,16,0,8,0,0,1,0,8,0,0,0,16,8,0,0,0,1,6,0,0,0,6,16,0,0,6,1,0,0,6,0,16,0,6,0,1,0,6,0,0,1,6,0,0,16,6,0,0,2,6,0,0,32,6,32,16,0,6,0,2,1,6,0,32,16,6,2,1,0,6,17,0,0,6,0,32,0,6,0,2,0,6,32,0,0,6,1,16,0,6,2,0,0,6,1,0,2,6,16,0,32,6,0,1,2,6,16,1,0,6,0,16,32,6,16,16,0,6,16,0,1,6,32,0,16,6,2,0,1,6,1,1,0,6,1,0,16,6,0,17,0,6,16,0,2,6,0,1,16,6,0,0,17,6,16,0,16,6,1,0,1,6,0,0,34,6,2,1,1,6,16,32,16,6,1,2,1,6,32,16,16,6,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+724105);
/* memory initializer */ allocate([32,6,0,16,1,6,33,16,0,6,16,2,1,6,18,1,0,6,1,32,16,6,1,2,0,6,16,32,0,6,0,16,2,6,0,1,32,6,0,2,33,6,0,2,32,6,0,0,18,6,0,0,33,6,32,17,0,6,0,1,1,6,17,16,0,6,0,32,18,6,0,32,17,6,32,16,2,6,2,1,32,6,0,34,17,6,0,16,16,6,2,17,0,6,0,33,16,6,0,2,3,6,32,16,1,6,0,18,1,4,17,0,4,0,34,4,32,0,4,1,16,4,2,32,4,0,32,4,2,0,4,16,1,4,0,17,4,2,1,4,2,33,4,0,2,4,32,2,4,1,1,4,16,16,4,16,2,4,34,0,4,16,0,4,1,0,4,33,0,4,18,0,4,0,16,4,32,18,4,1,17,4,0,1,4,1,2,4,17,2,4,17,1,4,16,32,4,32,1,4,34,17,4,0,18,4,32,16,4,34,1,4,1,32,4,0,33,4,16,17,4,33,16,4,16,34,4,2,3,4,18,1,4,32,17,4,17,16,4,32,48,4,17,32,4,2,16,4,34,16,4,17,17,4,48,32,4,48,0,4,1,34,4,1,18,4,2,17,4,3,2,4,3,0,4,16,33,4,18,32,4,0,0,4,18,33,4,33,17,4,2,34,4,16,18,4,49,0,4,32,32,4,0,3,4,2,2,4,34,32,4,1,33,4,33,2,4,33,18,4,17,34,4,0,48,4,18,17,4,32,34,4,49,32,4,33,48,4,34,2,4,34,34,4,32,49,4,19,2,4,3,16,4,17,18,4,0,19,4,33,1,4,18,3,4,19,0,4,19,16,4,2,19,4,48,1,4,18,16,4,34,19,4,3,18,4,49,1,4,48,34,4,0,49,4,1,49,4,2,35,4,1,48,4,17,33,4,34,33,4,1,19,4,16,3,4,34,3,4,48,33,4,33,49,4,51,0,4,19,18,4,17,49,4,48,2,4,18,2,4,17,19,4,18,34,4,32,50,4,16,19,4,34,49,4,33,32,4,1,51,4,51,16,4,32,19,4,49,34,4,19,48,4,1,3,4,17,51,4,32,33,4,19,49,4,3,34,4,49,2,4,0,36,2,0,2,16,2,32,2,48,2,64,2,80,2,96,2,1,2,17,2,33,2,49,2,65,2,81,2,97,2,2,2,18,2,34,2,50,2,66,2,82,2,98,2,3,2,19,2,35,2,51,2,67,2,83,2,99,2,4,2,20,2,36,2,52,2,68,2,84,2,100,2,5,2,21,2,37,2,53,2,69,2,85,2,101,2,6,2,22,2,38,2,54,2,70,2,86,2,102,255,0,1,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,15,15,15,14,14,15,14,14,14,12,12,14,12,12,12,8,8,12,8,8,8,0,0,8,0,0,0,0,0,0,0,0,2,2,2,1,2,2,2,2,2,1,2,2,0,0,0,0,2,2,2,1,2,2,2,2,1,2,2,2,0,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,109,29,155,5,66,213,68,230,128,226,20,29,175,247,87,178,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,224,202,32,0,184,109,32,0,1,128,9,128,25,128,49,128,81,128,121,128,169,128,225,128,33,129,105,129,185,129,17,130,113,130,217,130,73,131,193,131,65,132,201,132,89,133,241,133,145,134,57,135,233,135,161,136,97,137,41,138,249,138,209,139,177,140,153,141,137,142,129,143,129,144,137,145,153,146,177,147,209,148,249,149,41,151,97,152,161,153,233,154,57,156,145,157,241,158,89,160,201,161,65,163,193,164,73,166,217,167,113,169,17,171,185,172,105,174,33,176,225,177,169,179,121,181,81,183,49,185,25,187,9,189,1,191,1,193,9,195,25,197,49,199,81,201,121,203,169,205,225,207,33,210,105,212,185,214,17,217,113,219,217,221,73,224,193,226,65,229,201,231,89,234,241,236,145,239,57,242,233,244,161,247,97,250,41,253,249,255,209,2,177,5,153,8,137,11,129,14,129,17,137,20,153,23,177,26,209,29,249,32,41,36,97,39,161,42,233,45,57,49,145,52,241,55,89,59,201,62,65,66,193,69,73,73,217,76,113,80,17,84,185,87,105,91,33,95,225,98,169,102,121,106,81,110,49,114,25,118,9,122,1,126,204,4,227,5,225,4,19,4,240,4,12,3,249,3,9,3,251,3,6,3,252,3,3,3,253,2,3,2,254,2,3,2,255,2,2,2,255,2,2,2,198,3,214,4,210,4,37,5,220,4,29,4,227,4,25,4,233,4,20,4,239,4,16,4,244,4,12,3,246,4,7,3,252,4,3,3,255,3,1,3,197,3,211,5,206,4,38,4,217,4,32,4,226,4,25,3,233,3,20,3,236,3,16,3,243,3,10,3,249,3,3,3,0,3,255,3,2,3,255,2,32,73,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,132,38,0,0,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,73,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,0,0,0,0,0,0,0,0,0,0,0,246,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,34,34,0,112,0,0,0,88,58,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,1,2,0,3,1,2,1,3,1,2,2,3,1,0,2,3,1,0,0,2,1,0,1,2,1,1,2,3,0,1,2,3,0,1,0,2,1,1,0,2,0,1,1,2,0,0,1,2,0,0,0,1,1,1,1,2,0,0,0,0,48,5,37,0,144,191,35,0,28,0,0,0,5,0,0,0,184,214,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,24,22,34,0,144,191,35,0,28,0,0,0,5,0,0,0,184,214,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,176,123,33,0,72,2,33,0,32,0,0,0,5,0,0,0,96,157,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,88,66,32,0,72,2,33,0,32,0,0,0,5,0,0,0,96,157,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,248,41,40,0,40,203,39,0,36,0,0,0,5,0,0,0,88,100,39,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,104,21,39,0,40,209,38,0,40,0,0,0,5,0,0,0,88,100,39,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,208,140,38,0,120,81,38,0,44,0,0,0,82,76,79,67,136,26,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,162,35,0,112,0,0,0,160,59,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,1,0,16,16,2,0,32,16,2,0,64,16,4,0,8,16,1,0,16,16,2,0,32,16,2,0,64,16,4,0,8,16,1,0,16,48,2,0,32,48,2,0,64,48,4,0,64,50,4,0,0,0,0,0,8,16,1,0,16,48,2,0,32,48,2,0,64,48,4,0,64,50,4,0,0,0,0,0,140,32,0,0,1,0,0,128,193,17,0,0,0,0,0,0,52,12,0,0,0,0,0,176,76,9,0,0,195,109,219,182,130,7,0,0,102,39,118,226,76,6,0,0,243,123,239,189,108,5,0,0,24,0,0,192,195,4,0,0,64,6,231,99,62,4,0,0,129,33,11,217,0,42,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,5,37,0,240,191,35,0,24,0,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,64,0,0,0,0,0,0,48,64,16,0,1,0,0,0,0,0,208,214,34,0,32,22,34,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,64,143,64,16,0,1,0,0,0,0,0,192,123,33,0,32,22,34,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,64,143,64,16,0,1,0,0,0,0,0,152,2,33,0,104,157,32,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,64,143,64,16,0,1,0,0,0,0,0,96,66,32,0,104,157,32,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,64,143,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,0,0,0,0,0,0,0,0,0,0,0,62,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,166,35,0,112,0,0,0,96,62,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,7,37,0,112,225,36,0,128,2,0,0,5,0,0,0,160,159,37,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,193,35,0,112,190,36,0,132,2,0,0,5,0,0,0,160,159,37,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,120,161,36,0,24,134,36,0,136,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,120,161,36,0,208,107,36,0,64,80,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,161,36,0,248,55,36,0,16,23,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,161,36,0,144,221,35,0,48,194,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,161,36,0,240,170,35,0,248,148,35,0,32,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,240,170,35,0,192,126,35,0,192,103,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,170,35,0,216,85,35,0,40,68,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,240,170,35,0,80,50,35,0,8,24,35,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,248,236,34,0,24,216,34,0,212,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,136,201,34,0,0,185,34,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,136,201,34,0,200,166,34,0,216,25,156,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,136,201,34,0,104,135,34,0,216,25,156,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,136,201,34,0,248,119,34,0,216,25,156,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,136,201,34,0,80,50,35,0,216,25,156,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,136,201,34,0,248,102,34,0,160,80,34,0,216,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,182,35,0,112,0,0,0,40,64,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,21,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,171,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,45,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,191,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,172,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,64,66,15,0,2,0,0,0,3,0,0,0,41,0,0,0,67,0,0,0,42,0,0,0,68,0,0,0,35,1,0,0,37,1,0,0,36,1,0,0,38,1,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,40,1,0,0,42,1,0,0,39,1,0,0,41,1,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,57,1,0,0,58,1,0,0,59,1,0,0,60,1,0,0,87,0,0,0,88,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,35,0,0,0,4,0,0,0,44,1,0,0,33,0,0,0,5,0,0,0,43,1,0,0,64,1,0,0,12,0,0,0,13,0,0,0,34,0,0,0,14,0,0,0,70,0,0,0,92,0,0,0,69,0,0,0,91,0,0,0,80,0,0,0,94,0,0,0,79,0,0,0,93,0,0,0,76,0,0,0,96,0,0,0,75,0,0,0,95,0,0,0,72,0,0,0,98,0,0,0,71,0,0,0,97,0,0,0,74,0,0,0,100,0,0,0,73,0,0,0,99,0,0,0,78,0,0,0,102,0,0,0,77,0,0,0,101,0,0,0,45,1,0,0,46,1,0,0,49,1,0,0,50,1,0,0,53,1,0,0,54,1,0,0,47,1,0,0,48,1,0,0,51,1,0,0,52,1,0,0,55,1,0,0,56,1,0,0,54,0,0,0,104,0,0,0,55,0,0,0,103,0,0,0,56,0,0,0,106,0,0,0,57,0,0,0,105,0,0,0,58,0,0,0,108,0,0,0,59,0,0,0,107,0,0,0,255,255,255,255,1,0,0,0,7,0,8,0,2,0,47,0,32,0,2,0,6,0,3,0,5,0,4,0,60,0,8,0,4,0,69,0,50,0,67,0,41,0,51,0,49,0,59,0,53,0,6,0,6,0,40,0,55,0,43,0,54,0,42,0,62,0,7,0,8,0,63,0,48,0,52,0,61,0,77,0,78,0,72,0,7,0,10,0,85,0,56,0,86,0,68,0,74,0,73,0,81,0,5,0,12,0,82,0,95,0,80,0,94,0,91,0,5,0,14,0,90,0,89,0,88,0,103,0,87,0,8,0,16,0,1,0,0,0,15,0,35,0,33,0,58,0,64,0,84,0,5,0,32,0,102,0,118,0,134,0,150,0,166,0,5,0,34,0,101,0,114,0,130,0,146,0,162,0,5,0,36,0,100,0,126,0,142,0,158,0,174,0,5,0,38,0,99,0,122,0,138,0,154,0,170,0,6,0,20,0,11,0,39,0,19,0,31,0,27,0,23,0,5,0,40,0,46,0,71,0,66,0,76,0,93,0,5,0,56,0,98,0,117,0,133,0,149,0,165,0,5,0,58,0,97,0,113,0,129,0,145,0,161,0,5,0,60,0,96,0,125,0,141,0,157,0,173,0,5,0,62,0,111,0,121,0,137,0,153,0,169,0,6,0,44,0,10,0,38,0,18,0,30,0,26,0,22,0,8,0,64,0,14,0,13,0,12,0,34,0,45,0,57,0,79,0,83,0,5,0,80,0,110,0,116,0,132,0,148,0,164,0,5,0,82,0,109,0,112,0,128,0,144,0,160,0,5,0,84,0,108,0,124,0,140,0,156,0,172,0,5,0,86,0,107,0,120,0,136,0,152,0,168,0,6,0,68,0,9,0,37,0,17,0,29,0,25,0,21,0,5,0,88,0,44,0,70,0,65,0,75,0,92,0,5,0,104,0,106,0,115,0,131,0,147,0,163,0,5,0,106,0,105,0,127,0,143,0,159,0,175,0,5,0,108,0,104,0,123,0,139,0,155,0,171,0,5,0,110,0,119,0,135,0,151,0,167,0,183,0,6,0,92,0,8,0,36,0,16,0,28,0,24,0,20,0,0,0,0,0,0,0,9,0,67,68,1,2,3,4,5,6,7,9,2,14,13,9,12,11,0,10,15,8,9,4,18,19,23,17,22,20,21,66,65,8,10,44,42,40,54,52,56,64,78,4,12,36,32,72,80,5,14,16,28,24,60,84,13,16,135,109,144,156,120,97,148,121,101,122,123,89,124,4,18,125,126,127,112,6,36,50,48,62,70,76,74,4,38,35,47,87,95,5,40,31,27,39,59,83,13,42,129,108,159,155,130,96,147,131,100,132,133,88,134,4,44,113,114,115,116,8,62,43,41,55,53,51,71,79,77,4,64,34,46,86,94,5,66,30,26,38,58,82,13,68,139,107,158,154,140,111,146,141,99,142,143,103,128,4,70,105,90,91,92,6,88,49,63,61,69,75,73,4,90,33,45,85,93,5,92,29,25,37,57,81,13,94,149,106,157,153,150,110,145,151,98,136,137,102,138,4,96,117,118,119,104,0,0,0,8,0,7,6,5,4,3,2,1,0,9,2,15,14,13,12,11,10,9,8,23,9,4,53,52,51,58,40,55,54,57,56,8,10,22,20,18,16,30,50,95,94,7,12,28,24,73,36,32,62,67,13,16,127,123,135,131,143,139,151,103,102,101,100,99,98,4,18,83,75,79,71,5,36,44,42,49,93,92,7,38,27,39,72,35,47,61,66,13,42,126,122,134,130,142,138,150,97,96,111,110,109,108,4,44,82,74,78,70,8,62,21,19,17,31,29,48,91,90,7,64,26,38,87,34,46,60,65,13,68,125,121,133,129,141,137,149,107,106,105,104,119,118,4,70,81,85,77,69,5,88,43,41,63,89,88,7,90,25,37,86,33,45,59,64,13,94,124,120,132,128,140,136,148,117,116,115,114,113,112,4,96,80,84,76,68,0,0,0,0,0,0,8,0,7,6,15,4,5,3,2,0,9,2,14,13,8,12,10,1,9,11,29,9,4,57,58,50,56,60,59,49,71,70,8,10,17,19,23,21,31,24,32,52,7,12,36,82,69,46,42,48,77,11,16,109,97,133,121,101,89,125,113,93,117,105,3,18,81,73,65,4,36,28,26,38,54,7,38,35,83,68,45,41,63,76,11,42,108,96,132,120,100,88,124,112,92,116,104,3,44,80,72,64,8,62,16,18,22,20,30,39,47,51,7,64,34,84,67,44,40,62,75,11,68,107,111,131,135,99,103,123,127,91,115,119,3,70,95,87,79,4,88,27,25,37,53,7,90,33,85,66,43,55,61,74,11,94,106,110,130,134,98,102,122,126,90,114,118,3,96,94,86,78,0,0,0,0,1,0,0,0,7,0,8,0,2,0,24,0,33,0,39,0,12,0,6,0,5,0,4,0,13,0,8,0,4,0,65,0,79,0,64,0,78,0,51,0,61,0,71,0,70,0,7,0,6,0,52,0,55,0,44,0,54,0,53,0,43,0,42,0,7,0,8,0,60,0,59,0,58,0,57,0,56,0,75,0,74,0,6,0,10,0,73,0,72,0,86,0,87,0,85,0,84,0,8,0,16,0,11,0,10,0,9,0,8,0,28,0,27,0,49,0,69,0,6,0,32,0,83,0,91,0,99,0,107,0,115,0,123,0,6,0,34,0,82,0,103,0,111,0,119,0,127,0,135,0,6,0,20,0,38,0,23,0,34,0,19,0,3,0,15,0,5,0,40,0,32,0,41,0,63,0,67,0,77,0,6,0,56,0,81,0,90,0,98,0,106,0,114,0,122,0,6,0,58,0,80,0,102,0,110,0,118,0,126,0,134,0,6,0,44,0,26,0,22,0,36,0,18,0,2,0,14,0,5,0,64,0,45,0,40,0,50,0,48,0,68,0,6,0,80,0,95,0,89,0,97,0,105,0,113,0,121,0,6,0,82,0,94,0,101,0,109,0,117,0,125,0,133,0,6,0,68,0,37,0,21,0,35,0,17,0,1,0,31,0,5,0,88,0,47,0,46,0,62,0,66,0,76,0,6,0,104,0,93,0,88,0,96,0,104,0,112,0,120,0,6,0,106,0,92,0,100,0,108,0,116,0,124,0,132,0,6,0,92,0,25,0,20,0,29,0,16,0,0,0,30,0,0,0,0,0,0,0,0,0,8,0,7,6,0,3,5,4,2,1,9,2,13,12,8,11,10,15,9,14,23,9,4,71,56,60,70,59,57,58,69,76,8,10,16,18,22,20,30,38,44,42,6,12,75,48,52,40,34,26,9,16,101,89,93,117,105,81,85,109,97,2,18,67,78,4,36,28,36,46,87,6,38,74,63,51,55,33,25,9,42,100,88,92,116,104,80,84,108,96,2,44,64,79,8,62,31,17,21,19,29,37,43,41,6,64,73,62,50,54,32,24,9,68,99,103,91,115,119,95,83,107,111,2,70,66,77,4,88,27,35,45,86,6,90,72,61,49,53,47,39,9,94,98,102,90,114,118,94,82,106,110,2,96,65,68,0,0,0,0,8,0,0,1,2,3,4,5,6,7,8,2,8,9,10,11,12,13,14,15,7,4,70,51,43,71,50,60,49,8,10,23,22,21,20,19,47,54,59,6,12,48,42,35,29,30,31,7,16,92,84,82,100,79,72,88,2,18,67,68,4,36,18,46,53,58,6,38,63,41,34,26,27,28,7,42,91,83,81,99,78,87,103,2,44,65,66,4,62,17,45,52,57,6,64,62,40,33,39,24,25,7,68,90,80,95,98,77,86,102,2,70,75,64,4,88,16,44,56,69,6,90,61,55,32,36,37,38,7,94,89,94,93,97,76,85,101,2,96,73,74,0,0,0,8,0,7,6,5,4,3,2,1,0,8,2,15,14,13,12,11,10,9,8,7,4,51,35,34,50,33,49,32,8,10,23,22,21,20,19,18,43,42,8,12,54,55,40,41,24,25,26,27,7,16,92,68,67,84,66,65,80,2,18,53,52,4,36,17,16,48,63,7,42,91,64,79,83,78,77,95,2,44,62,61,4,62,31,30,60,59,8,64,44,45,46,47,36,37,38,39,7,68,90,76,75,82,74,73,94,2,70,58,57,4,88,29,28,56,71,7,94,89,72,87,81,86,85,93,2,96,70,69,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,93,0,58,0,91,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,101,0,102,0,96,0,7,0,10,0,109,0,64,0,110,0,92,0,98,0,97,0,105,0,5,0,12,0,106,0,119,0,104,0,118,0,115,0,5,0,14,0,114,0,113,0,112,0,127,0,111,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,88,0,108,0,1,0,18,0,126,0,11,0,24,0,134,0,145,0,147,0,169,0,186,0,42,1,58,1,226,0,207,0,117,1,77,1,11,0,26,0,142,0,162,0,151,0,181,0,203,0,33,1,105,1,55,1,188,0,98,1,100,1,11,0,28,0,135,0,153,0,157,0,183,0,224,0,64,1,126,1,16,1,193,0,99,1,88,1,11,0,30,0,132,0,146,0,136,0,182,0,206,0,12,1,71,1,255,0,189,0,103,1,78,1,11,0,32,0,5,1,196,0,102,1,184,1,19,1,37,1,26,1,140,1,158,1,183,1,200,1,11,0,34,0,234,0,223,0,127,1,194,1,217,0,0,1,35,1,123,1,159,1,179,1,212,1,11,0,36,0,34,1,204,0,108,1,185,1,2,1,220,0,22,1,125,1,162,1,191,1,223,1,11,0,38,0,237,0,199,0,97,1,199,1,3,1,232,0,11,1,114,1,150,1,171,1,222,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,4,0,22,0,79,0,78,0,77,0,76,0,6,0,40,0,35,0,54,0,95,0,90,0,100,0,117,0,1,0,42,0,125,0,11,0,48,0,131,0,156,0,158,0,177,0,246,0,51,1,111,1,251,0,197,0,53,1,70,1,11,0,50,0,120,0,154,0,148,0,178,0,227,0,75,1,107,1,249,0,192,0,80,1,89,1,11,0,52,0,122,0,150,0,141,0,170,0,221,0,27,1,66,1,236,0,201,0,90,1,57,1,11,0,54,0,121,0,164,0,138,0,168,0,231,0,62,1,110,1,14,1,194,0,79,1,73,1,11,0,56,0,29,1,205,0,142,1,192,1,32,1,244,0,23,1,143,1,166,1,182,1,213,1,11,0,58,0,46,1,222,0,137,1,206,1,242,0,238,0,25,1,128,1,164,1,176,1,214,1,11,0,60,0,7,1,211,0,118,1,205,1,240,0,252,0,69,1,101,1,135,1,168,1,209,1,11,0,62,0,241,0,208,0,119,1,196,1,10,1,18,1,50,1,149,1,160,1,180,1,208,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,4,0,46,0,75,0,74,0,73,0,72,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,103,0,107,0,1,0,66,0,124,0,11,0,72,0,155,0,160,0,161,0,185,0,250,0,87,1,155,1,59,1,4,1,116,1,139,1,11,0,74,0,143,0,172,0,174,0,187,0,247,0,68,1,157,1,115,1,21,1,131,1,95,1,11,0,76,0,139,0,171,0,173,0,209,0,1,1,122,1,144,1,83,1,254,0,152,1,121,1,11,0,78,0,130,0,163,0,137,0,191,0,212,0,93,1,133,1,63,1,200,0,113,1,82,1,11,0,80,0,31,1,219,0,145,1,202,1,67,1,36,1,94,1,165,1,172,1,187,1,219,1,11,0,82,0,38,1,216,0,148,1,207,1,52,1,48,1,56,1,163,1,175,1,189,1,220,1,11,0,84,0,72,1,230,0,153,1,193,1,39,1,61,1,74,1,151,1,170,1,186,1,210,1,11,0,86,0,40,1,202,0,136,1,197,1,28,1,20,1,15,1,124,1,174,1,177,1,201,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,4,0,70,0,87,0,86,0,85,0,84,0,6,0,88,0,34,0,53,0,94,0,89,0,99,0,116,0,1,0,90,0,123,0,11,0,96,0,128,0,175,0,159,0,180,0,229,0,41,1,92,1,44,1,184,0,104,1,85,1,11,0,98,0,129,0,166,0,165,0,195,0,215,0,76,1,84,1,45,1,253,0,120,1,96,1,11,0,100,0,140,0,152,0,167,0,190,0,225,0,86,1,109,1,8,1,214,0,134,1,91,1,11,0,102,0,133,0,144,0,149,0,179,0,218,0,60,1,132,1,65,1,210,0,147,1,81,1,11,0,104,0,9,1,198,0,112,1,188,1,13,1,24,1,49,1,173,1,167,1,178,1,221,1,11,0,106,0,47,1,228,0,129,1,204,1,239,0,6,1,233,0,106,1,154,1,161,1,211,1,11,0,108,0,235,0,213,0,138,1,195,1,245,0,17,1,43,1,156,1,169,1,190,1,215,1,11,0,110,0,248,0,176,0,130,1,198,1,243,0,30,1,54,1,141,1,146,1,181,1,203,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,4,0,94,0,83,0,82,0,81,0,80,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,11,0,24,0,118,0,129,0,131,0,153,0,170,0,26,1,42,1,210,0,191,0,101,1,61,1,11,0,26,0,126,0,146,0,135,0,165,0,187,0,17,1,89,1,39,1,172,0,82,1,84,1,11,0,28,0,119,0,137,0,141,0,167,0,208,0,48,1,110,1,0,1,177,0,83,1,72,1,11,0,30,0,116,0,130,0,120,0,166,0,190,0,252,0,55,1,239,0,173,0,87,1,62,1,11,0,32,0,245,0,180,0,86,1,168,1,3,1,21,1,10,1,124,1,142,1,167,1,184,1,11,0,34,0,218,0,207,0,111,1,178,1,201,0,240,0,19,1,107,1,143,1,163,1,196,1,11,0,36,0,18,1,188,0,92,1,169,1,242,0,204,0,6,1,109,1,146,1,175,1,207,1,11,0,38,0,221,0,183,0,81,1,183,1,243,0,216,0,251,0,98,1,134,1,155,1,206,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,11,0,48,0,115,0,140,0,142,0,161,0,230,0,35,1,95,1,235,0,181,0,37,1,54,1,11,0,50,0,104,0,138,0,132,0,162,0,211,0,59,1,91,1,233,0,176,0,64,1,73,1,11,0,52,0,106,0,134,0,125,0,154,0,205,0,11,1,50,1,220,0,185,0,74,1,41,1,11,0,54,0,105,0,148,0,122,0,152,0,215,0,46,1,94,1,254,0,178,0,63,1,57,1,11,0,56,0,13,1,189,0,126,1,176,1,16,1,228,0,7,1,127,1,150,1,166,1,197,1,11,0,58,0,30,1,206,0,121,1,190,1,226,0,222,0,9,1,112,1,148,1,160,1,198,1,11,0,60,0,247,0,195,0,102,1,189,1,224,0,236,0,53,1,85,1,119,1,152,1,193,1,11,0,62,0,225,0,192,0,103,1,180,1,250,0,2,1,34,1,133,1,144,1,164,1,192,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,11,0,72,0,139,0,144,0,145,0,169,0,234,0,71,1,139,1,43,1,244,0,100,1,123,1,11,0,74,0,127,0,156,0,158,0,171,0,231,0,52,1,141,1,99,1,5,1,115,1,79,1,11,0,76,0,123,0,155,0,157,0,193,0,241,0,106,1,128,1,67,1,238,0,136,1,105,1,11,0,78,0,114,0,147,0,121,0,175,0,196,0,77,1,117,1,47,1,184,0,97,1,66,1,11,0,80,0,15,1,203,0,129,1,186,1,51,1,20,1,78,1,149,1,156,1,171,1,203,1,11,0,82,0,22,1,200,0,132,1,191,1,36,1,32,1,40,1,147,1,159,1,173,1,204,1,11,0,84,0,56,1,214,0,137,1,177,1,23,1,45,1,58,1,135,1,154,1,170,1,194,1,11,0,86,0,24,1,186,0,120,1,181,1,12,1,4,1,255,0,108,1,158,1,161,1,185,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,11,0,96,0,112,0,159,0,143,0,164,0,213,0,25,1,76,1,28,1,168,0,88,1,69,1,11,0,98,0,113,0,150,0,149,0,179,0,199,0,60,1,68,1,29,1,237,0,104,1,80,1,11,0,100,0,124,0,136,0,151,0,174,0,209,0,70,1,93,1,248,0,198,0,118,1,75,1,11,0,102,0,117,0,128,0,133,0,163,0,202,0,44,1,116,1,49,1,194,0,131,1,65,1,11,0,104,0,249,0,182,0,96,1,172,1,253,0,8,1,33,1,157,1,151,1,162,1,205,1,11,0,106,0,31,1,212,0,113,1,188,1,223,0,246,0,217,0,90,1,138,1,145,1,195,1,11,0,108,0,219,0,197,0,122,1,179,1,229,0,1,1,27,1,140,1,153,1,174,1,199,1,11,0,110,0,232,0,160,0,114,1,182,1,227,0,14,1,38,1,125,1,130,1,165,1,187,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,10,0,24,0,134,0,153,0,7,1,86,1,143,1,154,0,106,0,177,0,61,1,9,1,10,0,26,0,128,0,167,0,14,1,95,1,129,1,160,0,105,0,213,0,73,1,3,1,2,0,28,0,123,0,147,0,2,0,30,0,131,0,143,0,10,0,32,0,90,1,118,0,170,0,201,0,40,1,112,1,250,0,28,1,85,1,135,1,10,0,34,0,89,1,104,0,166,0,196,0,25,1,118,1,242,0,13,1,71,1,134,1,14,0,36,0,141,0,171,0,35,1,108,1,229,0,210,0,52,1,228,0,206,0,200,0,2,1,39,1,57,1,105,1,14,0,38,0,144,0,188,0,26,1,110,1,217,0,216,0,53,1,218,0,193,0,182,0,245,0,31,1,44,1,111,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,10,0,48,0,139,0,169,0,11,1,92,1,133,1,163,0,116,0,189,0,87,1,12,1,10,0,50,0,120,0,161,0,249,0,83,1,141,1,152,0,114,0,230,0,78,1,47,1,2,0,52,0,125,0,138,0,2,0,54,0,112,0,129,0,10,0,56,0,93,1,122,0,162,0,203,0,32,1,116,1,22,1,18,1,56,1,121,1,10,0,58,0,101,1,126,0,165,0,214,0,42,1,106,1,252,0,4,1,65,1,122,1,14,0,60,0,150,0,199,0,10,1,99,1,211,0,180,0,29,1,241,0,195,0,198,0,243,0,19,1,67,1,119,1,14,0,62,0,142,0,191,0,0,1,97,1,208,0,220,0,58,1,237,0,190,0,212,0,255,0,48,1,62,1,115,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,10,0,72,0,159,0,168,0,46,1,100,1,139,1,178,0,132,0,185,0,74,1,30,1,10,0,74,0,158,0,181,0,36,1,102,1,140,1,176,0,133,0,235,0,75,1,20,1,2,0,76,0,130,0,157,0,2,0,78,0,124,0,136,0,10,0,80,0,98,1,121,0,194,0,246,0,66,1,123,1,16,1,17,1,76,1,142,1,10,0,82,0,103,1,140,0,186,0,236,0,77,1,120,1,34,1,45,1,82,1,131,1,14,0,84,0,155,0,227,0,63,1,113,1,253,0,254,0,94,1,248,0,224,0,239,0,240,0,37,1,59,1,127,1,14,0,86,0,156,0,209,0,41,1,117,1,225,0,215,0,70,1,247,0,197,0,184,0,232,0,33,1,54,1,109,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,10,0,96,0,148,0,164,0,8,1,84,1,132,1,183,0,117,0,205,0,80,1,5,1,10,0,98,0,146,0,174,0,1,1,79,1,128,1,173,0,113,0,187,0,64,1,23,1,2,0,100,0,127,0,151,0,2,0,102,0,119,0,137,0,10,0,104,0,96,1,135,0,172,0,238,0,50,1,125,1,6,1,15,1,72,1,126,1,10,0,106,0,91,1,115,0,179,0,219,0,49,1,124,1,21,1,38,1,81,1,130,1,14,0,108,0,145,0,192,0,51,1,114,1,234,0,223,0,68,1,244,0,202,0,204,0,251,0,43,1,69,1,104,1,14,0,110,0,149,0,221,0,55,1,107,1,226,0,222,0,60,1,231,0,207,0,175,0,233,0,24,1,27,1,88,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+734345);
/* memory initializer */ allocate([0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,2,0,24,0,124,0,115,0,2,0,26,0,150,0,117,0,2,0,28,0,129,0,114,0,2,0,30,0,121,0,131,0,14,0,32,0,161,0,1,1,87,1,199,0,177,0,47,1,204,0,173,0,168,0,4,1,21,1,51,1,82,1,128,0,14,0,34,0,194,0,30,1,91,1,222,0,214,0,60,1,236,0,152,0,166,0,242,0,28,1,52,1,88,1,142,0,14,0,36,0,169,0,17,1,97,1,202,0,189,0,55,1,240,0,200,0,171,0,5,1,53,1,40,1,89,1,130,0,14,0,38,0,198,0,19,1,93,1,187,0,163,0,26,1,193,0,195,0,175,0,234,0,9,1,33,1,72,1,119,0,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,2,0,48,0,139,0,104,0,2,0,50,0,135,0,118,0,2,0,52,0,112,0,127,0,2,0,54,0,140,0,141,0,14,0,56,0,179,0,20,1,84,1,225,0,223,0,65,1,235,0,190,0,182,0,15,1,54,1,59,1,96,1,125,0,14,0,58,0,153,0,8,1,73,1,232,0,209,0,67,1,231,0,165,0,191,0,23,1,34,1,56,1,111,1,134,0,14,0,60,0,167,0,13,1,85,1,205,0,197,0,42,1,224,0,160,0,170,0,3,1,24,1,61,1,101,1,148,0,14,0,62,0,203,0,16,1,86,1,227,0,192,0,43,1,233,0,172,0,183,0,0,1,27,1,70,1,99,1,106,0,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,2,0,72,0,144,0,120,0,2,0,74,0,157,0,123,0,2,0,76,0,145,0,138,0,2,0,78,0,132,0,154,0,14,0,80,0,241,0,63,1,109,1,252,0,253,0,75,1,254,0,230,0,220,0,7,1,29,1,58,1,108,1,156,0,14,0,82,0,247,0,35,1,83,1,249,0,250,0,76,1,11,1,196,0,207,0,12,1,48,1,68,1,100,1,158,0,14,0,84,0,210,0,44,1,92,1,243,0,237,0,77,1,246,0,206,0,219,0,10,1,62,1,79,1,107,1,159,0,14,0,86,0,239,0,50,1,110,1,221,0,226,0,41,1,251,0,184,0,178,0,2,1,36,1,49,1,90,1,116,0,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,2,0,96,0,143,0,126,0,2,0,98,0,137,0,122,0,2,0,100,0,149,0,105,0,2,0,102,0,133,0,136,0,14,0,104,0,162,0,31,1,81,1,244,0,229,0,66,1,218,0,180,0,186,0,6,1,18,1,32,1,95,1,146,0,14,0,106,0,212,0,38,1,102,1,248,0,228,0,78,1,215,0,174,0,176,0,14,1,37,1,45,1,98,1,147,0,14,0,108,0,185,0,71,1,80,1,211,0,213,0,57,1,245,0,181,0,188,0,255,0,25,1,69,1,94,1,151,0,14,0,110,0,201,0,39,1,103,1,216,0,208,0,64,1,238,0,164,0,155,0,217,0,22,1,46,1,74,1,113,0,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,13,0,32,0,122,0,154,0,170,0,218,0,10,1,138,0,106,0,182,0,230,0,22,1,178,0,226,0,18,1,13,0,34,0,134,0,166,0,190,0,238,0,30,1,150,0,118,0,186,0,234,0,26,1,198,0,246,0,38,1,13,0,36,0,130,0,162,0,194,0,242,0,34,1,146,0,114,0,206,0,254,0,46,1,202,0,250,0,42,1,13,0,38,0,142,0,174,0,214,0,6,1,54,1,158,0,126,0,210,0,2,1,50,1,222,0,14,1,62,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,13,0,56,0,121,0,153,0,169,0,217,0,9,1,137,0,105,0,181,0,229,0,21,1,177,0,225,0,17,1,13,0,58,0,133,0,165,0,189,0,237,0,29,1,149,0,117,0,185,0,233,0,25,1,197,0,245,0,37,1,13,0,60,0,129,0,161,0,193,0,241,0,33,1,145,0,113,0,205,0,253,0,45,1,201,0,249,0,41,1,13,0,62,0,141,0,173,0,213,0,5,1,53,1,157,0,125,0,209,0,1,1,49,1,221,0,13,1,61,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,13,0,80,0,120,0,152,0,168,0,216,0,8,1,136,0,104,0,180,0,228,0,20,1,176,0,224,0,16,1,13,0,82,0,132,0,164,0,188,0,236,0,28,1,148,0,116,0,184,0,232,0,24,1,196,0,244,0,36,1,13,0,84,0,128,0,160,0,192,0,240,0,32,1,144,0,112,0,204,0,252,0,44,1,200,0,248,0,40,1,13,0,86,0,140,0,172,0,212,0,4,1,52,1,156,0,124,0,208,0,0,1,48,1,220,0,12,1,60,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,13,0,104,0,135,0,167,0,183,0,231,0,23,1,151,0,119,0,179,0,227,0,19,1,191,0,239,0,31,1,13,0,106,0,131,0,163,0,187,0,235,0,27,1,147,0,115,0,199,0,247,0,39,1,195,0,243,0,35,1,13,0,108,0,143,0,175,0,207,0,255,0,47,1,159,0,127,0,203,0,251,0,43,1,215,0,7,1,55,1,13,0,110,0,139,0,171,0,211,0,3,1,51,1,155,0,123,0,223,0,15,1,63,1,219,0,11,1,59,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,13,0,32,0,114,0,186,0,210,0,234,0,2,1,106,0,126,0,162,0,170,0,198,0,222,0,246,0,14,1,13,0,34,0,122,0,194,0,218,0,242,0,10,1,118,0,134,0,174,0,182,0,206,0,230,0,254,0,22,1,9,0,36,0,130,0,138,0,146,0,154,0,178,0,202,0,226,0,250,0,18,1,9,0,38,0,142,0,150,0,158,0,166,0,190,0,214,0,238,0,6,1,30,1,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,13,0,56,0,113,0,185,0,209,0,233,0,1,1,105,0,125,0,161,0,169,0,197,0,221,0,245,0,13,1,13,0,58,0,121,0,193,0,217,0,241,0,9,1,117,0,133,0,173,0,181,0,205,0,229,0,253,0,21,1,9,0,60,0,129,0,137,0,145,0,153,0,177,0,201,0,225,0,249,0,17,1,9,0,62,0,141,0,149,0,157,0,165,0,189,0,213,0,237,0,5,1,29,1,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,13,0,80,0,112,0,184,0,208,0,232,0,0,1,104,0,124,0,160,0,168,0,196,0,220,0,244,0,12,1,13,0,82,0,120,0,192,0,216,0,240,0,8,1,116,0,132,0,172,0,180,0,204,0,228,0,252,0,20,1,9,0,84,0,128,0,136,0,144,0,152,0,176,0,200,0,224,0,248,0,16,1,9,0,86,0,140,0,148,0,156,0,164,0,188,0,212,0,236,0,4,1,28,1,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,13,0,104,0,127,0,199,0,223,0,247,0,15,1,119,0,123,0,175,0,183,0,195,0,219,0,243,0,11,1,13,0,106,0,135,0,207,0,231,0,255,0,23,1,115,0,131,0,171,0,179,0,203,0,227,0,251,0,19,1,9,0,108,0,143,0,151,0,159,0,167,0,191,0,215,0,239,0,7,1,31,1,9,0,110,0,139,0,147,0,155,0,163,0,187,0,211,0,235,0,3,1,27,1,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,1,0,0,0,7,0,8,0,2,0,55,0,40,0,14,0,6,0,15,0,5,0,0,0,68,0,8,0,4,0,77,0,58,0,75,0,49,0,59,0,57,0,67,0,61,0,6,0,6,0,48,0,63,0,51,0,62,0,50,0,70,0,7,0,8,0,71,0,56,0,60,0,69,0,85,0,86,0,80,0,7,0,10,0,93,0,64,0,94,0,76,0,82,0,81,0,89,0,5,0,12,0,90,0,103,0,88,0,102,0,99,0,5,0,14,0,98,0,97,0,96,0,111,0,95,0,9,0,16,0,13,0,12,0,11,0,10,0,9,0,41,0,66,0,72,0,92,0,1,0,18,0,110,0,9,0,32,0,106,0,122,0,154,0,186,0,218,0,134,0,166,0,198,0,230,0,9,0,34,0,105,0,130,0,162,0,194,0,226,0,142,0,174,0,206,0,238,0,9,0,36,0,104,0,138,0,170,0,202,0,234,0,150,0,182,0,214,0,246,0,9,0,38,0,119,0,146,0,178,0,210,0,242,0,158,0,190,0,222,0,254,0,7,0,20,0,4,0,19,0,45,0,27,0,39,0,33,0,31,0,6,0,40,0,35,0,54,0,79,0,74,0,84,0,101,0,1,0,42,0,109,0,9,0,56,0,118,0,121,0,153,0,185,0,217,0,133,0,165,0,197,0,229,0,9,0,58,0,117,0,129,0,161,0,193,0,225,0,141,0,173,0,205,0,237,0,9,0,60,0,116,0,137,0,169,0,201,0,233,0,149,0,181,0,213,0,245,0,9,0,62,0,115,0,145,0,177,0,209,0,241,0,157,0,189,0,221,0,253,0,7,0,44,0,3,0,18,0,44,0,26,0,38,0,32,0,30,0,9,0,64,0,8,0,23,0,22,0,21,0,20,0,52,0,65,0,87,0,91,0,1,0,66,0,108,0,9,0,80,0,114,0,120,0,152,0,184,0,216,0,132,0,164,0,196,0,228,0,9,0,82,0,113,0,128,0,160,0,192,0,224,0,140,0,172,0,204,0,236,0,9,0,84,0,112,0,136,0,168,0,200,0,232,0,148,0,180,0,212,0,244,0,9,0,86,0,127,0,144,0,176,0,208,0,240,0,156,0,188,0,220,0,252,0,7,0,68,0,2,0,17,0,43,0,25,0,37,0,47,0,29,0,6,0,88,0,34,0,53,0,78,0,73,0,83,0,100,0,1,0,90,0,107,0,9,0,104,0,126,0,135,0,167,0,199,0,231,0,131,0,163,0,195,0,227,0,9,0,106,0,125,0,143,0,175,0,207,0,239,0,139,0,171,0,203,0,235,0,9,0,108,0,124,0,151,0,183,0,215,0,247,0,147,0,179,0,211,0,243,0,9,0,110,0,123,0,159,0,191,0,223,0,255,0,155,0,187,0,219,0,251,0,7,0,92,0,1,0,16,0,42,0,24,0,36,0,46,0,28,0,0,0,0,0,0,0,7,0,7,6,5,4,3,2,1,8,2,0,15,14,13,12,11,10,9,9,4,23,22,21,20,19,18,17,16,8,8,6,31,30,29,28,27,86,85,84,6,8,83,82,81,80,127,126,9,10,26,24,38,36,34,32,46,44,42,4,12,40,52,48,95,5,14,60,56,68,91,111,3,16,191,176,177,4,18,103,123,124,125,3,20,188,189,190,4,22,99,120,121,122,3,24,185,186,187,4,26,107,133,134,135,3,28,198,199,184,4,30,119,130,131,132,3,32,195,196,197,4,34,115,143,128,129,6,36,64,78,76,74,72,245,4,38,55,51,63,94,5,40,59,71,67,90,110,3,42,192,193,194,4,44,102,140,141,142,3,46,205,206,207,4,48,98,137,138,139,3,50,202,203,204,4,52,106,150,151,136,3,54,215,200,201,4,56,118,147,148,149,3,58,212,213,214,4,60,114,144,145,146,9,62,25,39,37,35,33,47,45,43,41,4,64,54,50,62,93,5,66,58,70,66,89,109,3,68,209,210,211,4,70,101,157,158,159,3,72,222,223,208,4,74,97,154,155,156,3,76,219,220,221,4,78,105,167,152,153,3,80,216,217,218,4,82,117,164,165,166,3,84,229,230,231,4,86,113,161,162,163,6,88,79,77,75,73,87,244,4,90,53,49,61,92,5,92,57,69,65,88,108,3,94,226,227,228,4,96,100,174,175,160,3,98,239,224,225,4,100,96,171,172,173,3,102,236,237,238,4,104,104,168,169,170,3,106,233,234,235,4,108,116,181,182,183,3,110,246,247,232,4,112,112,178,179,180,0,0,8,0,0,1,2,3,4,5,6,7,9,2,23,8,9,10,11,12,13,14,15,9,4,57,58,62,56,60,59,61,71,70,8,10,22,21,20,19,18,17,42,41,7,12,38,50,84,37,36,85,83,1,16,66,1,18,67,1,20,68,1,22,69,10,24,145,144,156,153,154,163,161,192,206,195,10,26,158,159,157,152,155,165,160,205,204,194,7,28,167,166,162,164,196,207,193,5,36,26,25,54,53,89,7,38,35,49,81,34,33,82,80,1,42,78,1,44,79,1,46,64,1,48,65,10,50,103,102,98,111,96,105,119,185,199,188,10,52,100,101,99,110,97,107,118,198,197,187,7,54,109,108,104,106,189,184,186,8,62,16,31,30,29,28,27,40,55,7,64,32,48,94,47,46,95,93,1,68,74,1,70,75,1,72,76,1,74,77,10,76,117,116,112,125,126,135,133,178,176,181,10,78,114,115,113,124,127,121,132,191,190,180,7,80,123,122,134,120,182,177,179,5,88,24,39,52,51,88,7,90,45,63,91,44,43,92,90,1,94,86,1,96,87,1,98,72,1,100,73,10,102,131,130,142,139,140,149,147,171,169,174,10,104,128,129,143,138,141,151,146,168,183,173,7,106,137,136,148,150,175,170,172,0,0,0,0,0,0,232,8,40,0,112,0,0,0,16,114,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,112,34,0,16,193,33,0,128,0,0,0,5,0,0,0,40,65,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,1,0,0,0,0,0,0,0,248,212,32,0,120,117,32,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,48,27,32,0,56,3,40,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,112,150,39,0,136,60,39,0,32,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,1,0,0,0,64,246,38,0,80,175,38,0,72,114,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,64,246,38,0,16,58,38,0,40,4,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,64,246,38,0,0,218,37,0,72,178,37,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,80,148,37,0,96,81,37,0,40,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,248,27,37,0,104,250,36,0,44,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,16,64,1,0,0,0,8,208,36,0,184,178,36,0,16,150,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,8,208,36,0,8,122,36,0,16,95,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,8,208,36,0,200,68,36,0,88,47,36,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,8,208,36,0,152,244,35,0,80,207,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,8,208,36,0,40,183,35,0,240,160,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,8,208,36,0,136,140,35,0,0,117,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,8,208,36,0,136,97,35,0,184,77,35,0,52,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,136,60,35,0,104,45,35,0,96,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,96,255,34,0,200,225,34,0,64,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,24,210,34,0,40,194,34,0,76,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,152,177,34,0,96,158,34,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,24,143,34,0,72,128,34,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,32,111,34,0,56,98,34,0,104,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,40,56,34,0,48,31,34,0,108,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,16,17,34,0,80,1,34,0,112,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,40,242,33,0,192,225,33,0,120,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,246,38,0,248,176,38,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,224,246,38,0,240,114,38,0,152,58,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,224,246,38,0,240,4,38,0,128,218,37,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,224,246,38,0,152,178,37,0,128,148,37,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,224,246,38,0,56,82,37,0,128,28,37,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,224,246,38,0,208,250,36,0,144,208,36,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,224,246,38,0,224,178,36,0,56,150,36,0,12,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,192,95,64,1,0,0,0,0,0,0,0,120,122,36,0,224,95,36,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,104,69,36,0,240,47,36,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,80,245,35,0,128,208,35,0,24,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,160,39,0,120,66,39,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,192,239,64,1,0,0,0,0,0,0,0,168,250,38,0,152,180,38,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,192,239,64,1,0,0,0,0,0,0,0,88,118,38,0,208,61,38,0,16,0,0,0,2,0,0,0,64,66,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,210,35,0,128,185,35,0,88,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,48,163,35,0,200,142,35,0,92,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,112,119,35,0,232,98,35,0,96,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,8,80,35,0,16,62,35,0,100,0,0,0,1,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,48,64,0,0,0,0,0,0,191,64,1,0,0,0,0,0,0,0,216,46,35,0,8,7,35,0,104,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,112,64,0,0,0,0,0,0,174,64,1,0,0,0,0,0,0,0,232,227,34,0,144,211,34,0,108,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,8,196,34,0,0,0,0,0,80,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,240,179,34,0,152,159,34,0,84,0,0,0,1,0,0,0,114,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,72,144,34,0,32,130,34,0,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,72,144,34,0,240,112,34,0,120,99,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,72,144,34,0,88,211,36,0,152,63,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,72,144,34,0,240,112,34,0,120,99,34,0,112,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,16,33,34,0,168,18,34,0,120,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,48,3,34,0,224,244,33,0,124,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,253,38,0,0,0,0,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,255,255,216,65,1,0,0,0,0,0,0,0,24,184,38,0,48,121,38,0,80,0,0,0,1,0,0,0,32,161,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,211,35,0,128,186,35,0,32,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,1,0,0,0,0,0,0,0,56,164,35,0,72,143,35,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,224,119,35,0,80,99,35,0,40,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,127,32,0,168,37,32,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,164,35,0,192,143,35,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,88,120,35,0,144,99,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,40,81,35,0,144,62,35,0,104,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,64,47,35,0,240,7,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,112,228,34,0,240,211,34,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,192,196,34,0,64,180,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,64,160,34,0,200,144,34,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,160,130,34,0,104,113,34,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,248,99,34,0,192,64,34,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,176,33,34,0,40,19,34,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,164,35,0,80,4,34,0,104,245,33,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,80,4,34,0,120,227,33,0,104,214,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,80,4,34,0,128,203,33,0,168,193,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,80,4,34,0,240,186,33,0,80,158,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,80,4,34,0,192,132,33,0,232,121,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,80,4,34,0,72,112,33,0,160,102,33,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,80,4,34,0,200,91,33,0,32,83,33,0,60,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,72,74,33,0,160,65,33,0,68,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,224,111,64,1,0,0,0,0,0,0,0,8,59,33,0,64,34,33,0,64,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,224,111,64,1,0,0,0,0,0,0,0,24,9,33,0,104,0,33,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,240,247,32,0,16,241,32,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,88,233,32,0,216,226,32,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,16,220,32,0,120,213,32,0,88,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,16,205,32,0,224,182,32,0,96,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,128,163,32,0,208,155,32,0,100,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,40,149,32,0,104,142,32,0,120,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,123,38,0,208,65,38,0,104,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,120,9,38,0,24,27,156,0,108,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,73,39,0,16,0,39,0,188,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,80,188,38,0,184,123,38,0,192,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,128,66,38,0,56,10,38,0,208,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,15,40,0,88,171,39,0,20,0,0,0,1,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,221,33,0,152,88,33,0,48,4,0,0,84,65,82,86,0,231,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,168,132,32,0,224,41,32,0,56,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,96,17,40,0,120,172,39,0,60,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,96,17,40,0,144,75,39,0,200,1,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,96,17,40,0,144,189,38,0,88,125,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,96,17,40,0,160,67,38,0,72,11,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,96,17,40,0,152,228,37,0,104,184,37,0,36,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,216,152,37,0,240,96,37,0,104,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,0,35,37,0,72,0,37,0,108,4,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,128,213,36,0,24,184,36,0,40,4,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,32,154,36,0,248,126,36,0,112,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,48,101,36,0,112,73,36,0,116,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,12,38,0,0,229,37,0,8,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,128,185,37,0,168,153,37,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,1,0,0,0,0,0,0,0,208,97,37,0,128,35,37,0,28,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,192,0,37,0,24,214,36,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,51,36,0,96,5,36,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,176,213,35,0,192,188,35,0,8,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,208,165,35,0,112,145,35,0,12,0,0,0,2,0,0,0,128,150,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,200,121,35,0,88,100,35,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,120,35,0,224,25,156,0,4,0,0,0,1,0,0,0,64,31,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,240,193,7,143,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,92,33,0,176,233,32,0,8,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,183,64,2,0,0,0,0,0,0,0,16,135,32,0,192,44,32,0,12,0,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,183,64,2,0,0,0,0,0,0,0,136,20,40,0,48,175,39,0,24,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,78,39,0,96,4,39,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,208,192,38,0,56,127,38,0,8,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,224,255,239,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,122,35,0,144,100,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,14,38,0,112,230,37,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+744585);
/* memory initializer */ allocate([240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,187,37,0,128,155,37,0,4,0,0,0,1,0,0,0,112,23,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,232,100,37,0,216,36,37,0,8,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,104,2,37,0,232,215,36,0,16,0,0,0,84,65,82,86,120,185,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,213,34,0,216,198,34,0,80,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,196,38,0,32,130,38,0,24,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,192,71,38,0,56,16,38,0,32,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,187,33,0,200,163,33,0,208,107,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,110,33,0,0,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,190,37,0,136,157,37,0,4,0,0,0,69,90,73,83,136,108,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,44,37,0,136,157,37,0,4,0,0,0,69,90,73,83,136,108,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,240,5,37,0,112,219,36,0,24,0,0,0,84,65,82,86,24,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,224,158,36,0,112,219,36,0,24,0,0,0,84,65,82,86,24,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,128,131,36,0,8,105,36,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,72,77,36,0,8,105,36,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,32,54,36,0,144,15,36,0,48,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,103,39,0,32,25,39,0,4,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,40,212,38,0,32,143,38,0,8,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,56,84,38,0,168,28,38,0,12,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,48,240,37,0,112,194,37,0,16,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,192,160,37,0,136,119,37,0,4,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,52,37,0,120,10,37,0,8,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,168,226,36,0,200,191,36,0,12,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,168,162,36,0,80,135,36,0,4,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,144,108,36,0,248,80,36,0,8,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,168,56,36,0,0,26,36,0,12,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,223,35,0,24,195,35,0,16,4,0,0,5,0,0,0,200,69,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,33,37,0,248,211,35,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,0,0,248,33,37,0,136,228,34,0,208,33,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,248,33,37,0,248,132,33,0,64,9,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,248,33,37,0,224,163,32,0,96,72,32,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,248,33,37,0,72,47,40,0,160,210,39,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,248,33,37,0,224,106,39,0,168,26,39,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,248,33,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,229,34,0,160,34,34,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,75,32,0,176,203,34,0,208,22,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,40,187,34,0,176,203,34,0,208,22,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,16,50,40,0,16,169,34,0,48,25,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,8,151,34,0,16,169,34,0,48,25,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,104,213,39,0,32,137,34,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,24,122,34,0,32,137,34,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,88,13,33,0,32,105,34,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,120,84,34,0,32,105,34,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,136,234,34,0,152,44,34,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,240,24,34,0,152,44,34,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,112,136,33,0,232,10,34,0,12,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,16,252,33,0,232,10,34,0,12,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,200,219,35,0,136,233,33,0,20,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,88,219,33,0,136,233,33,0,20,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,144,166,32,0,192,207,33,0,16,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,184,197,33,0,192,207,33,0,16,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,56,39,34,0,216,188,33,0,24,0,0,0,65,76,72,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,0,0,152,174,33,0,184,140,33,0,216,188,33,0,24,0,0,0,65,76,72,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,0,0,152,174,33,0,224,46,37,0,184,125,33,0,32,0,0,0,65,76,72,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,0,0,152,174,33,0,56,116,33,0,184,125,33,0,32,0,0,0,65,76,72,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,0,0,152,174,33,0,168,106,33,0,168,96,33,0,56,0,0,0,4,0,0,0,205,59,127,102,158,160,230,63,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,176,86,33,0,168,96,33,0,56,0,0,0,4,0,0,0,205,59,127,102,158,160,230,63,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,240,77,33,0,224,69,33,0,52,0,0,0,4,0,0,0,205,59,127,102,158,160,230,63,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,88,61,33,0,96,48,33,0,52,0,0,0,4,0,0,0,205,59,127,102,158,160,230,63,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,144,17,33,0,216,3,33,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,192,0,0,0,0,0,0,64,64,8,0,0,0,0,0,0,0,224,251,32,0,0,244,32,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,64,143,192,0,0,0,0,0,64,143,64,8,0,0,0,0,0,0,0,80,236,32,0,0,244,32,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,64,143,192,0,0,0,0,0,64,143,64,8,0,0,0,0,0,0,0,224,229,32,0,248,222,32,0,68,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,143,64,8,0,0,0,0,0,0,0,72,216,32,0,8,207,32,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,8,0,0,0,72,216,32,0,216,196,32,0,8,207,32,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,8,0,0,0,72,216,32,0,40,170,32,0,144,158,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,72,216,32,0,0,152,32,0,200,144,32,0,96,0,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,112,137,32,0,176,131,32,0,88,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,81,64,8,0,0,0,112,137,32,0,152,125,32,0,208,119,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,128,112,32,0,0,103,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,160,78,32,0,64,67,32,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,184,60,32,0,240,52,32,0,0,0,0,0,128,0,0,0,65,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,32,47,32,0,160,40,32,0,0,0,0,0,128,0,0,0,69,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,184,35,32,0,184,29,32,0,0,0,0,0,128,0,0,0,70,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,48,88,40,0,192,76,40,0,0,0,0,0,128,0,0,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,88,53,40,0,240,42,40,0,0,0,0,0,128,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,0,35,40,0,24,27,40,0,0,0,0,0,128,0,0,0,67,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,208,21,40,0,0,16,40,0,0,0,0,0,128,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,112,137,32,0,120,11,40,0,136,5,40,0,252,21,0,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,128,255,39,0,16,244,39,0,0,22,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,64,8,0,0,0,0,0,0,0,176,217,39,0,8,206,39,0,4,22,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,0,0,0,0,0,195,39,0,16,186,39,0,8,22,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,0,0,0,0,120,178,39,0,16,186,39,0,8,22,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,0,0,0,0,224,171,39,0,176,165,39,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,224,171,39,0,112,155,39,0,48,148,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,224,171,39,0,176,137,39,0,224,113,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,224,171,39,0,240,101,39,0,176,94,39,0,24,22,0,0,3,0,0,0,0,0,0,0,0,0,52,64,0,0,0,0,0,0,46,64,0,0,0,0,0,128,64,64,8,0,0,0,0,0,0,0,184,85,39,0,0,80,39,0,32,22,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,0,0,0,0,0,0,8,75,39,0,112,69,39,0,36,22,0,0,4,0,0,0,0,0,0,224,255,255,239,71,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,8,0,0,0,0,0,0,0,72,64,39,0,128,58,39,0,40,22,0,0,4,0,0,0,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,184,51,39,0,152,32,39,0,44,22,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,40,23,39,0,224,16,39,0,48,22,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,232,10,39,0,216,5,39,0,52,22,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,0,0,0,0,64,1,39,0,240,252,38,0,56,22,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,0,0,0,0,0,0,24,248,38,0,176,244,38,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,8,0,0,0,24,248,38,0,80,237,38,0,168,218,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,24,248,38,0,192,210,38,0,120,205,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,24,248,38,0,240,198,38,0,80,194,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,24,248,38,0,48,189,38,0,144,183,38,0,16,22,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,8,0,0,0,48,189,38,0,112,178,38,0,200,173,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,48,189,38,0,24,166,38,0,192,149,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,48,189,38,0,8,142,38,0,136,137,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,0,0,48,189,38,0,88,132,38,0,104,128,38,0,20,22,0,0,1,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,48,64,8,0,0,0,0,0,0,0,216,124,38,0,168,120,38,0,248,21,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,64,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,139,33,0,56,16,33,0,212,175,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,10,0,0,0,0,0,0,0,184,168,32,0,192,77,32,0,116,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,184,168,32,0,112,52,40,0,216,216,39,0,120,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,8,113,39,0,208,31,39,0,124,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,16,218,38,0,216,148,38,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,104,90,38,0,248,36,38,0,132,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,32,0,40,223,32,0,60,22,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,10,0,0,0,0,230,32,0,112,216,32,0,64,207,32,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,0,230,32,0,0,198,32,0,16,171,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,0,230,32,0,208,158,32,0,144,152,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,0,230,32,0,240,144,32,0,168,137,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,0,230,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,20,33,0,0,25,156,0,196,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,176,80,32,0,88,56,40,0,104,220,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,176,80,32,0,96,116,39,0,216,34,39,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,176,80,32,0,80,220,38,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,176,80,32,0,80,151,38,0,0,25,156,0,188,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,16,92,38,0,88,56,40,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,16,92,38,0,96,116,39,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,16,92,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,154,38,0,232,94,38,0,48,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,121,39,0,0,39,39,0,216,1,0,0,1,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,64,17,0,0,0,0,0,0,0,128,224,38,0,0,0,0,0,20,0,0,0,1,0,0,0,5,128,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,64,22,224,64,17,0,0,0,128,224,38,0,168,154,38,0,0,0,0,0,0,0,0,0,128,0,0,0,5,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,128,224,38,0,40,95,38,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,128,224,38,0,24,41,38,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,128,224,38,0,96,247,37,0,0,0,0,0,0,0,0,0,128,0,0,0,178,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,128,224,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,85,32,0,248,61,40,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,96,38,0,232,41,38,0,48,182,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,48,248,37,0,104,205,37,0,52,182,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,154,33,0,32,30,33,0,88,23,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,124,39,0,88,41,39,0,28,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,43,38,0,8,249,37,0,128,79,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,32,64,17,0,0,0,0,0,0,0,72,206,37,0,0,0,0,0,184,79,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,17,0,0,0,72,206,37,0,240,229,39,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,72,206,37,0,72,169,37,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,72,206,37,0,168,41,39,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,72,206,37,0,192,131,37,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,72,206,37,0,8,157,38,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,72,206,37,0,128,65,37,0,208,19,37,0,172,79,0,0,5,0,0,0,240,234,36,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,17,0,0,0,0,0,0,0,104,199,36,0,136,169,36,0,160,79,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,64,17,0,0,0,0,0,0,0,160,142,36,0,88,114,36,0,176,79,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,16,64,17,0,0,0,160,142,36,0,216,87,36,0,0,0,0,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,142,36,0,240,229,39,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,142,36,0,72,169,37,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,142,36,0,168,41,39,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,142,36,0,192,131,37,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,142,36,0,72,62,36,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,160,142,36,0,240,35,36,0,64,233,35,0,168,79,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,181,32,0,112,89,32,0,40,21,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,64,17,0,0,0,0,0,0,0,248,64,40,0,128,230,39,0,44,21,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,65,40,0,200,230,39,0,8,4,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,10,35,0,120,67,34,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,36,33,0,8,185,32,0,112,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,224,92,32,0,136,66,40,0,120,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,64,234,39,0,24,128,39,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,64,234,39,0,192,44,39,0,80,229,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,64,234,39,0,96,159,38,0,208,99,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,64,234,39,0,56,45,38,0,104,250,37,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,64,234,39,0,216,207,37,0,72,170,37,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,64,234,39,0,240,133,37,0,192,67,37,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,80,21,37,0,152,236,36,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,152,200,36,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,170,36,0,120,143,36,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,11,35,0,152,68,34,0,4,0,0,0,5,0,0,0,80,162,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,98,33,0,176,88,33,0,168,11,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,13,35,0,152,70,34,0,48,4,0,0,5,0,0,0,192,163,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,136,38,33,0,8,187,32,0,52,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,64,94,32,0,216,67,40,0,56,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,248,235,39,0,72,129,39,0,64,4,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,176,45,39,0,112,230,38,0,60,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,96,160,38,0,216,100,38,0,176,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,136,46,38,0,120,251,37,0,68,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,144,208,37,0,8,171,37,0,72,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,8,135,37,0,96,69,37,0,76,4,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,40,22,37,0,216,237,36,0,80,4,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,144,201,36,0,104,171,36,0,84,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,104,144,36,0,80,117,36,0,88,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,88,90,36,0,136,64,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,88,90,36,0,64,38,36,0,112,236,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,88,90,36,0,56,202,35,0,136,178,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,88,90,36,0,56,156,35,0,208,134,35,0,92,4,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,184,112,35,0,240,92,35,0,100,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,224,74,35,0,128,56,35,0,96,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,32,37,35,0,72,249,34,0,104,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,192,222,34,0,208,206,34,0,112,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,48,191,34,0,72,173], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+754830);
/* memory initializer */ allocate([34,0,108,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,48,191,34,0,136,64,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,48,191,34,0,248,154,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,48,191,34,0,104,140,34,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,48,191,34,0,136,125,34,0,48,108,34,0,116,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,224,91,34,0,224,50,34,0,120,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,48,28,34,0,40,14,34,0,124,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,64,255,33,0,40,236,33,0,128,4,0,0,1,0,0,0,0,0,0,128,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,168,222,33,0,24,211,33,0,132,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,48,200,33,0,136,64,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,48,200,33,0,232,190,33,0,72,180,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,48,200,33,0,176,146,33,0,224,128,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,48,200,33,0,184,118,33,0,248,108,33,0,136,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,232,98,33,0,208,88,33,0,140,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,80,33,0,0,0,0,0,144,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,208,71,33,0,160,62,33,0,148,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,32,53,33,0,128,22,33,0,152,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,120,5,33,0,56,253,32,0,156,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,144,245,32,0,32,238,32,0,160,4,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,8,231,32,0,160,224,32,0,164,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,112,217,32,0,80,208,32,0,168,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,112,217,32,0,136,64,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,112,217,32,0,248,199,32,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,112,217,32,0,16,174,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,112,217,32,0,32,160,32,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,112,217,32,0,80,153,32,0,240,145,32,0,172,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,160,138,32,0,216,100,38,0,176,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,192,132,32,0,216,126,32,0,180,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,192,132,32,0,136,64,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,192,132,32,0,8,121,32,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,192,132,32,0,56,116,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,192,132,32,0,144,106,32,0,8,82,32,0,184,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,191,34,0,208,173,34,0,112,10,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,14,36,0,232,16,35,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,32,75,34,0,232,16,35,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,248,166,33,0,104,41,33,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,64,190,32,0,104,41,33,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,140,34,0,192,125,34,0,56,29,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,120,108,34,0,32,92,34,0,56,29,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,48,39,0,56,234,38,0,112,8,0,0,1,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,234,38,0,144,163,38,0,120,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,20,64,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,191,32,0,184,98,32,0,84,5,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,18,36,0,104,20,35,0,4,0,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,0,0,0,0,0,0,32,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,114,35,0,96,94,35,0,104,37,64,0,1,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,64,9,0,0,0,0,0,0,0,224,75,35,0,176,57,35,0,96,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,8,64,9,0,0,0,224,75,35,0,248,37,35,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,75,35,0,240,250,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,75,35,0,128,223,34,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,75,35,0,216,207,34,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,75,35,0,240,191,34,0,176,174,34,0,100,37,64,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,160,155,34,0,0,0,0,0,120,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,32,64,9,0,0,0,0,0,0,0,16,141,34,0,0,0,0,0,124,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,32,64,9,0,0,0,0,0,0,0,56,126,34,0,216,108,34,0,116,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,20,64,9,0,0,0,184,92,34,0,32,52,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,92,34,0,200,28,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,92,34,0,176,14,34,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,92,34,0,160,255,33,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,92,34,0,112,237,33,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,92,34,0,32,223,33,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,92,34,0,136,211,33,0,160,200,33,0,128,37,64,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,8,64,9,0,0,0,136,211,33,0,48,191,33,0,0,0,0,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,211,33,0,216,180,33,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,211,33,0,176,147,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,211,33,0,80,129,33,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,211,33,0,40,119,33,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,211,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,22,35,0,72,79,34,0,16,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,24,0,1,0,184,22,35,0,216,170,33,0,184,44,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,184,22,35,0,208,192,32,0,224,99,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,184,22,35,0,80,74,40,0,112,241,39,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,184,22,35,0,120,134,39,0,232,49,39,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,184,22,35,0,16,235,38,0,32,164,38,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,184,22,35,0,88,104,38,0,144,49,38,0,8,1,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,66,36,0,0,40,36,0,96,150,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,126,34,0,8,109,34,0,104,0,0,0,5,0,0,0,8,25,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,242,39,0,160,135,39,0,68,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,105,38,0,208,50,38,0,0,58,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,109,34,0,232,92,34,0,248,111,4,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,29,36,0,16,29,35,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,197,32,0,128,103,32,0,108,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,24,77,40,0,80,244,39,0,112,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,216,137,39,0,216,51,39,0,120,1,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,64,64,17,0,0,0,0,0,0,0,96,237,38,0,72,166,38,0,116,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,64,64,17,0,0,0,0,0,0,0,56,106,38,0,216,51,38,0,124,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,37,0,56,75,37,0,72,14,0,0,1,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,10,0,0,0,32,140,37,0,96,25,37,0,88,244,36,0,0,0,0,0,128,0,0,0,255,255,255,127,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,10,0,0,0,32,140,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,25,37,0,240,244,36,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,80,205,36,0,56,176,36,0,44,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,0,16,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,247,39,0,112,141,39,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,143,39,0,128,54,39,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,32,0,0,0,136,240,38,0,136,169,38,0,248,108,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,136,240,38,0,0,54,38,0,24,1,38,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,136,240,38,0,200,214,37,0,56,176,37,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,136,240,38,0,24,141,37,0,208,76,37,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,136,240,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,93,36,0,72,67,36,0,52,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,144,42,36,0,184,241,35,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,1,0,0,0,144,42,36,0,64,205,35,0,104,181,35,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,144,42,36,0,200,158,35,0,168,138,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,144,42,36,0,136,115,35,0,232,95,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,144,42,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,184,33,0,80,25,156,0,4,0,0,0,1,0,0,0,112,23,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,200,202,32,0,112,109,32,0,16,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,88,85,40,0,80,25,156,0,24,0,0,0,84,65,82,86,168,250,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,2,38,0,208,215,37,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,128,2,38,0,32,177,37,0,184,142,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,128,2,38,0,48,78,37,0,72,26,37,0,60,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,39,65,1,0,0,0,0,0,0,0,40,246,36,0,88,206,36,0,64,0,0,0,1,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,40,35,0,104,253,34,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,8,225,34,0,176,208,34,0,8,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,40,193,34,0,136,176,34,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,240,156,34,0,64,142,34,0,16,0,0,0,2,0,0,0,64,75,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,64,127,34,0,240,109,34,0,20,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,225,36,0,0,8,0,0,254,0,0,0,96,190,36,0,0,0,0,0,32,161,36,0,0,8,0,0,224,0,0,0,200,133,36,0,16,107,36,0,56,79,36,0,0,8,0,0,224,0,0,0,200,133,36,0,16,107,36,0,64,55,36,0,0,8,0,0,224,0,0,0,200,133,36,0,16,107,36,0,176,18,36,0,0,8,0,0,224,0,0,0,200,133,36,0,16,107,36,0,184,219,35,0,0,8,0,0,70,1,0,0,160,192,35,0,0,0,0,0,168,169,35,0,0,8,0,0,184,0,0,0,96,147,35,0,0,0,0,0,24,125,35,0,0,8,0,0,70,0,0,0,32,102,35,0,0,0,0,0,208,83,35,0,0,8,0,0,38,0,0,0,136,66,35,0,0,0,0,0,64,49,35,0,0,8,0,0,150,1,0,0,248,15,35,0,0,0,0,0,248,230,34,0,0,8,0,0,158,1,0,0,80,214,34,0,0,0,0,0,56,199,34,0,0,8,0,0,66,1,0,0,224,182,34,0,0,0,0,0,128,163,34,0,0,8,0,0,188,0,0,0,152,146,34,0,0,0,0,0,232,132,34,0,0,8,0,0,172,0,0,0,224,116,34,0,0,0,0,0,48,101,34,0,0,8,0,0,176,0,0,0,40,70,34,0,0,0,0,0,208,35,34,0,0,8,0,0,190,1,0,0,136,20,34,0,0,0,0,0,240,5,34,0,0,8,0,0,246,0,0,0,184,246,33,0,0,0,0,0,24,229,33,0,0,8,0,0,184,1,0,0,160,225,33,0,0,0,0,0,88,204,33,0,1,0,0,0,136,0,0,0,128,194,33,0,88,204,33,0,104,187,33,0,1,0,0,0,136,0,0,0,128,194,33,0,88,204,33,0,72,161,33,0,0,0,0,0,54,8,0,0,168,150,33,0,0,0,0,0,128,122,33,0,1,0,0,0,190,0,0,0,88,120,33,0,168,103,33,0,176,92,33,0,5,0,0,0,90,0,0,0,112,83,33,0,8,75,33,0,248,65,33,0,6,0,0,0,144,200,90,0,248,63,33,0,248,65,33,0,0,58,33,0,9,64,12,0,16,0,0,0,144,26,33,0,40,7,33,0,48,248,32,0,2,0,0,0,8,177,92,0,48,241,32,0,0,0,0,0,80,233,32,0,2,0,0,0,72,176,83,0,160,226,32,0,0,0,0,0,16,226,32,0,9,128,12,0,20,0,0,0,80,213,32,0,16,212,32,0,16,212,32,0,9,128,12,0,20,0,0,0,80,213,32,0,16,212,32,0,160,182,32,0,9,128,8,0,84,1,0,0,32,177,32,0,168,155,32,0,184,148,32,0,5,32,8,0,208,1,0,0,24,142,32,0,16,134,32,0,192,128,32,0,5,32,8,0,178,1,0,0,8,123,32,0,72,117,32,0,88,111,32,0,9,128,8,0,76,1,0,0,144,87,32,0,80,71,32,0,176,63,32,0,133,64,8,0,156,0,0,0,176,56,32,0,208,49,32,0,144,43,32,0,1,64,13,0,160,0,0,0,104,38,32,0,240,32,32,0,232,26,32,0,1,64,9,0,168,0,0,0,216,89,40,0,80,84,40,0,248,59,40,0,1,68,8,0,176,0,0,0,72,45,40,0,192,36,40,0,144,29,40,0,1,64,13,0,8,0,0,0,136,23,40,0,96,18,40,0,88,13,40,0,6,64,4,0,84,0,0,0,200,7,40,0,0,0,0,0,48,2,40,0,5,64,5,0,72,0,0,0,0,248,39,0,96,18,40,0,136,226,39,0,5,128,6,0,88,0,0,0,32,208,39,0,128,198,39,0,24,189,39,0,1,32,0,0,152,0,0,0,160,181,39,0,168,173,39,0,24,167,39,0,9,128,8,0,220,0,0,0,128,157,39,0,120,149,39,0,168,141,39,0,5,32,8,0,194,0,0,0,88,119,39,0,160,103,39,0,240,95,39,0,6,0,0,0,240,112,142,0,128,87,39,0,0,0,0,0,112,81,39,0,6,0,0,0,232,112,142,0,0,76,39,0,0,0,0,0,0,71,39,0,5,0,0,0,160,0,0,0,48,65,39,0,120,59,39,0,232,53,39,0,6,0,0,0,224,127,8,0,56,37,39,0,0,0,0,0,64,24,39,0,5,0,0,0,162,0,0,0,128,18,39,0,104,11,39,0,88,7,39,0,6,0,0,0,208,112,142,0,40,2,39,0,0,0,0,0,32,254,38,0,6,0,0,0,216,112,142,0,224,248,38,0,0,0,0,0,80,245,38,0,6,64,4,0,80,0,0,0,80,239,38,0,120,27,156,0,208,211,38,0,1,32,8,0,106,1,0,0,72,206,38,0,184,199,38,0,48,195,38,0,5,0,0,0,76,1,0,0,200,189,38,0,120,27,156,0,96,184,38,0,133,0,0,0,152,131,155,0,80,179,38,0,120,27,156,0,88,174,38,0,5,1,0,0,8,151,30,0,48,168,38,0,232,152,38,0,224,142,38,0,6,0,0,0,128,110,149,0,96,138,38,0,0,0,0,0,8,133,38,0,133,0,0,0,16,251,24,0,96,129,38,0,144,125,38,0,72,122,38,0,6,64,8,0,192,0,0,0,232,116,38,0,0,0,0,0,80,113,38,0,9,128,8,0,172,1,0,0,216,107,38,0,120,27,156,0,0,93,38,0,5,1,0,0,208,43,23,0,216,83,38,0,232,152,38,0,232,78,38,0,5,1,0,0,200,43,23,0,232,73,38,0,232,152,38,0,72,71,38,0,6,0,0,0,120,248,136,0,176,67,38,0,136,64,38,0,128,60,38,0,6,128,8,0,92,1,0,0,240,56,38,0,0,0,0,0,64,53,38,0,133,128,8,0,100,1,0,0,32,39,38,0,0,0,0,0,120,28,38,0,1,132,8,0,228,0,0,0,232,23,38,0,160,103,39,0,40,19,38,0,13,128,12,0,244,0,0,0,8,15,38,0,104,11,38,0,32,8,38,0,5,128,10,0,4,1,0,0,184,5,38,0,32,8,38,0,216,3,38,0,5,32,8,0,48,1,0,0,184,5,38,0,32,8,38,0,120,0,38,0,5,32,8,0,64,1,0,0,128,245,37,0,120,0,38,0,0,240,37,0,9,128,8,0,108,1,0,0,176,236,37,0,200,233,37,0,192,230,37,0,9,128,8,0,116,1,0,0,24,228,37,0,248,225,37,0,120,219,37,0,129,128,4,0,124,1,0,0,32,217,37,0,120,27,156,0,232,213,37,0,5,0,0,0,216,0,0,0,152,201,37,0,32,194,37,0,184,191,37,0,5,0,0,0,216,0,0,0,152,201,37,0,32,194,37,0,80,189,37,0,5,0,0,0,12,0,0,0,8,187,37,0,248,225,37,0,80,184,37,0,2,0,0,0,168,172,10,0,200,181,37,0,0,0,0,0,80,179,37,0,5,32,8,0,206,0,0,0,144,177,37,0,248,225,37,0,96,175,37,0,13,128,4,0,96,0,0,0,32,165,37,0,248,225,37,0,72,160,37,0,6,0,0,0,136,160,144,0,56,158,37,0,0,0,0,0,184,156,37,0,1,1,0,0,128,182,12,0,192,155,37,0,32,153,37,0,144,151,37,0,17,32,8,0,66,0,0,0,80,149,37,0,160,103,39,0,64,148,37,0,25,128,12,0,44,0,0,0,16,143,37,0,208,126,37,0,72,120,37,0,25,130,12,0,52,0,0,0,192,112,37,0,192,106,37,0,216,101,37,0,25,128,8,0,28,1,0,0,128,97,37,0,216,101,37,0,120,93,37,0,29,128,12,0,60,0,0,0,8,88,37,0,40,81,37,0,96,78,37,0,145,0,0,0,168,48,92,0,208,63,37,0,160,103,39,0,200,52,37,0,22,0,0,0,160,3,90,0,136,47,37,0,0,0,0,0,64,43,37,0,18,64,12,0,196,0,0,0,96,37,37,0,0,0,0,0,96,35,37,0,149,0,0,0,24,178,51,0,24,33,37,0,80,233,32,0,56,30,37,0,29,128,8,0,36,1,0,0,160,27,37,0,192,26,37,0,56,18,37,0,17,32,12,0,112,0,0,0,216,10,37,0,16,212,32,0,208,7,37,0,20,0,0,0,236,0,0,0,184,4,37,0,0,0,0,0,208,2,37,0,20,0,0,0,236,0,0,0,184,4,37,0,0,0,0,0,160,0,37,0,17,32,8,0,222,0,0,0,184,254,36,0,48,252,36,0,80,250,36,0,145,128,8,0,148,1,0,0,72,246,36,0,80,233,32,0,88,233,36,0,29,128,8,0,156,1,0,0,248,226,36,0,64,224,36,0,136,218,36,0,22,0,0,0,224,112,142,0,72,216,36,0,0,0,0,0,0,214,36,0,22,0,0,0,200,112,142,0,128,212,36,0,0,0,0,0,232,209,36,0,20,0,0,0,46,1,0,0,200,207,36,0,0,0,0,0,184,206,36,0,21,0,0,0,118,1,0,0,200,207,36,0,64,198,36,0,24,192,36,0,17,32,8,0,154,1,0,0,152,189,36,0,200,233,37,0,160,187,36,0,29,128,8,0,44,1,0,0,144,185,36,0,88,184,36,0,240,182,36,0,29,128,8,0,52,1,0,0,208,179,36,0,88,184,36,0,136,178,36,0,29,128,8,0,60,1,0,0,144,185,36,0,88,184,36,0,168,177,36,0,149,128,12,0,68,1,0,0,64,168,36,0,120,27,156,0,0,163,36,0,149,0,0,0,168,68,16,0,64,160,36,0,136,158,36,0,136,156,36,0,21,32,8,0,210,1,0,0,144,154,36,0,104,11,38,0,64,153,36,0,22,0,0,0,40,158,82,0,72,151,36,0,0,0,0,0,248,149,36,0,22,128,8,0,20,1,0,0,200,148,36,0,0,0,0,0,192,141,36,0,21,32,8,0,162,1,0,0,168,135,36,0,0,133,36,0,160,130,36,0,29,128,8,0,12,1,0,0,248,128,36,0,64,127,36,0,8,126,36,0,17,32,8,0,32,1,0,0,72,123,36,0,200,121,36,0,32,121,36,0,29,128,4,0,104,0,0,0,120,113,36,0,232,108,36,0,200,106,36,0,29,128,4,0,112,0,0,0,184,104,36,0,0,0,0,0,48,103,36,0,33,32,8,0,98,1,0,0,112,101,36,0,160,103,39,0,224,99,36,0,33,32,8,0,208,0,0,0,112,96,36,0,232,94,36,0,72,94,36,0,161,128,12,0,36,0,0,0,168,86,36,0,208,126,37,0,72,81,36,0,161,128,12,0,28,0,0,0,248,78,36,0,216,76,36,0,96,75,36,0,34,64,12,0,200,0,0,0,240,73,36,0,0,0,0,0,144,72,36,0,33,32,12,0,220,0,0,0,24,70,36,0,16,212,32,0,112,68,36,0,37,32,8,0,210,1,0,0,200,67,36,0,104,11,38,0,24,61,36,0,161,0,0,0,0,151,30,0,248,56,36,0,72,55,36,0,200,53,36,0,45,128,12,0,252,0,0,0,136,52,36,0,40,81,37,0,112,51,36,0,37,32,12,0,20,1,0,0,160,50,36,0,136,48,36,0,56,47,36,0,33,32,8,0,36,0,0,0,192,43,36,0,200,233,37,0,64,34,36,0,165,128,4,0,164,1,0,0,40,25,36,0,0,0,0,0,232,19,36,0,2,66,12,0,204,0,0,0,200,13,36,0,0,0,0,0,48,9,36,0,1,34,12,0,164,0,0,0,160,4,36,0,16,212,32,0,96,1,36,0,5,34,8,0,210,1,0,0,248,250,35,0,104,11,38,0,88,244,35,0,6,130,4,0,132,1,0,0,128,242,35,0,0,0,0,0,136,232,35,0,9,130,4,0,140,1,0,0,0,224,35,0,192,106,37,0,136,220,35,0,21,0,0,0,226,0,0,0,64,217,35,0,192,214,35,0,120,213,35,0,21,0,0,0,64,0,0,0,96,211,35,0,112,209,35,0,248,206,35,0,6,0,0,0,136,18,90,0,152,205,35,0,120,27,156,0,224,199,35,0,5,65,8,0,188,0,0,0,88,195,35,0,48,193,35,0,80,191,35,0,5,65,8,0,184,0,0,0,72,190,35,0,48,193,35,0,104,188,35,0,6,0,8,0,80,109,83,0,192,186,35,0,120,27,156,0,40,184,35,0,13,128,8,0,236,0,0,0,208,182,35,0,184,181,35,0,8,176,35,0,37,32,8,0,210,1,0,0,224,171,35,0,104,170,35,0,176,168,35,0,21,32,8,0,210,1,0,0,224,171,35,0,136,167,35,0,136,165,35,0,37,32,8,0,120,0,0,0,72,164,35,0,168,155,32,0,88,162,35,0,21,32,8,0,120,0,0,0,32,160,35,0,168,155,32,0,88,159,35,0,5,34,8,0,120,0,0,0,248,153,35,0,168,155,32,0,104,150,35,0,5,32,8,0,120,0,0,0,120,148,35,0,248,225,37,0,176,146,35,0,5,48,12,0,120,1,0,0,232,145,35,0,16,212,32,0,88,145,35,0,18,64,12,0,208,0,0,0,176,143,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,59,35,0,216,54,35,0,56,51,35,0,0,0,0,0,56,255,34,0,248,255,255,255,192,225,34,0,0,0,0,0,16,210,34,0,8,0,0,0,8,194,34,0,16,0,0,0,144,177,34,0,24,0,0,0,88,158,34,0,32,0,0,0,16,143,34,0,40,0,0,0,160,178,36,0,48,0,0,0,6,14,43,52,4,1,1,1,13,1,2,1,1,1,9,0,176,162,35,0,112,0,0,0,16,114,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,236,19,0,144,101,21,0,176,228,19,0,0,38,19,0,176,181,19,0,224,49,21,0,200,141,21,0,32,93,20,0,184,23,19,0,200,94,20,0,128,94,20,0,240,94,20,0,104,95,20,0,24,95,20,0,64,95,20,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,7,0,0,0,15,0,0,0,31,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,7,0,0,0,15,0,0,0,31,0,0,0,63,0,0,0,127,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,0,0,0,2,4,10,20,0,0,0,0,0,0,0,0,8,8,0,0,4,4,12,8,8,12,0,0,10,2,4,4,14,6,8,8,2,10,12,12,6,14,0,0,10,2,4,4,14,6,8,8,2,10,12,12,6,14,5,1,15,3,9,5,3,7,13,9,7,11,1,13,11,15,0,0,8,0,0,8,8,8,5,1,13,1,5,9,13,9,2,2,10,2,2,10,10,10,7,3,15,3,7,11,15,11,4,4,12,4,4,12,12,12,1,5,9,5,1,13,9,13,6,6,14,6,6,14,14,14,3,7,11,7,3,15,11,15,0,0,8,0,0,8,8,8,4,0,12,0,4,8,12,8,1,1,9,1,1,9,9,9,5,1,13,1,5,9,13,9,3,2,11,2,3,10,11,10,7,2,15,2,7,10,15,10,2,3,10,3,2,11,10,11,6,3,14,3,6,11,14,11,0,4,8,4,0,12,8,12,4,4,12,4,4,12,12,12,1,5,9,5,1,13,9,13,5,5,13,5,5,13,13,13,3,6,11,6,3,14,11,14,7,6,15,6,7,14,15,14,2,7,10,7,2,15,10,15,6,7,14,7,6,15,14,15,0,0,8,0,0,8,8,8,0,2,8,2,0,10,8,10,0,4,8,4,0,12,8,12,0,6,8,6,0,14,8,14,1,1,9,1,1,9,9,9,1,3,9,3,1,11,9,11,1,5,9,5,1,13,9,13,1,7,9,7,1,15,9,15,2,0,10,0,2,8,10,8,2,2,10,2,2,10,10,10,2,4,10,4,2,12,10,12,2,6,10,6,2,14,10,14,3,1,11,1,3,9,11,9,3,3,11,3,3,11,11,11,3,5,11,5,3,13,11,13,3,7,11,7,3,15,11,15,4,0,12,0,4,8,12,8,4,2,12,2,4,10,12,10,4,4,12,4,4,12,12,12,4,6,12,6,4,14,12,14,5,1,13,1,5,9,13,9,5,3,13,3,5,11,13,11,5,5,13,5,5,13,13,13,5,7,13,7,5,15,13,15,6,0,14,0,6,8,14,8,6,2,14,2,6,10,14,10,6,4,14,4,6,12,14,12,6,6,14,6,6,14,14,14,7,1,15,1,7,9,15,9], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+765070);
/* memory initializer */ allocate([7,3,15,3,7,11,15,11,7,5,15,5,7,13,15,13,7,7,15,7,7,15,15,15,0,0,8,0,0,8,8,8,4,4,12,4,4,12,12,12,0,4,8,4,0,12,8,12,4,0,12,0,4,8,12,8,2,2,10,2,2,10,10,10,6,6,14,6,6,14,14,14,2,6,10,6,2,14,10,14,6,2,14,2,6,10,14,10,0,2,8,2,0,10,8,10,4,6,12,6,4,14,12,14,0,6,8,6,0,14,8,14,4,2,12,2,4,10,12,10,2,0,10,0,2,8,10,8,6,4,14,4,6,12,14,12,2,4,10,4,2,12,10,12,6,0,14,0,6,8,14,8,1,1,9,1,1,9,9,9,5,5,13,5,5,13,13,13,1,5,9,5,1,13,9,13,5,1,13,1,5,9,13,9,3,3,11,3,3,11,11,11,7,7,15,7,7,15,15,15,3,7,11,7,3,15,11,15,7,3,15,3,7,11,15,11,1,3,9,3,1,11,9,11,5,7,13,7,5,15,13,15,1,7,9,7,1,15,9,15,5,3,13,3,5,11,13,11,3,1,11,1,3,9,11,9,7,5,15,5,7,13,15,13,3,5,11,5,3,13,11,13,7,1,15,1,7,9,15,9,0,1,8,1,0,9,8,9,4,5,12,5,4,13,12,13,0,5,8,5,0,13,8,13,4,1,12,1,4,9,12,9,2,3,10,3,2,11,10,11,6,7,14,7,6,15,14,15,2,7,10,7,2,15,10,15,6,3,14,3,6,11,14,11,0,3,8,3,0,11,8,11,4,7,12,7,4,15,12,15,0,7,8,7,0,15,8,15,4,3,12,3,4,11,12,11,2,1,10,1,2,9,10,9,6,5,14,5,6,13,14,13,2,5,10,5,2,13,10,13,6,1,14,1,6,9,14,9,1,0,9,0,1,8,9,8,5,4,13,4,5,12,13,12,1,4,9,4,1,12,9,12,5,0,13,0,5,8,13,8,3,2,11,2,3,10,11,10,7,6,15,6,7,14,15,14,3,6,11,6,3,14,11,14,7,2,15,2,7,10,15,10,1,2,9,2,1,10,9,10,5,6,13,6,5,14,13,14,1,6,9,6,1,14,9,14,5,2,13,2,5,10,13,10,3,0,11,0,3,8,11,8,7,4,15,4,7,12,15,12,3,4,11,4,3,12,11,12,7,0,15,0,7,8,15,8,0,0,0,0,0,0,4,4,0,0,2,2,6,4,4,6,0,0,5,1,2,2,7,3,4,4,1,5,6,6,3,7,0,0,4,0,1,1,5,1,3,2,7,2,2,3,6,3,0,4,4,4,1,5,5,5,3,6,7,6,2,7,6,7,0,0,0,2,0,4,0,6,1,1,1,3,1,5,1,7,2,0,2,2,2,4,2,6,3,1,3,3,3,5,3,7,4,0,4,2,4,4,4,6,5,1,5,3,5,5,5,7,6,0,6,2,6,4,6,6,7,1,7,3,7,5,7,7,0,0,4,4,0,4,4,0,2,2,6,6,2,6,6,2,0,2,4,6,0,6,4,2,2,0,6,4,2,4,6,0,1,1,5,5,1,5,5,1,3,3,7,7,3,7,7,3,1,3,5,7,1,7,5,3,3,1,7,5,3,5,7,1,0,1,4,5,0,5,4,1,2,3,6,7,2,7,6,3,0,3,4,7,0,7,4,3,2,1,6,5,2,5,6,1,1,0,5,4,1,4,5,0,3,2,7,6,3,6,7,2,1,2,5,6,1,6,5,2,3,0,7,4,3,4,7,0,0,0,4,12,20,28,28,20,12,4,12,36,60,84,84,60,36,12,20,60,100,140,140,100,60,20,28,84,140,196,196,140,84,28,28,84,140,196,196,140,84,28,20,60,100,140,140,100,60,20,12,36,60,84,84,60,36,12,4,12,20,28,28,20,12,4,16,48,48,16,48,144,144,48,48,144,144,48,16,48,48,16,0,0,0,0,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,8,4,4,4,4,4,4,4,4,0,0,0,0,0,4,4,4,8,8,8,12,12,16,16,16,20,20,20,24,24,20,20,20,16,16,16,12,12,8,8,8,4,4,4,0,0,4,8,8,12,12,16,20,20,24,28,28,32,32,36,40,40,36,32,32,28,28,24,20,20,16,12,12,8,8,4,0,0,4,8,12,16,20,24,28,28,32,36,40,44,48,52,56,56,52,48,44,40,36,32,28,28,24,20,16,12,8,4,0,4,8,12,16,20,24,28,32,40,44,48,52,56,60,64,68,68,64,60,56,52,48,44,40,32,28,24,20,16,12,8,4,4,8,12,20,24,32,36,40,48,52,56,64,68,76,80,84,84,80,76,68,64,56,52,48,40,36,32,24,20,12,8,4,4,8,16,24,28,36,44,48,56,60,68,76,80,88,96,100,100,96,88,80,76,68,60,56,48,44,36,28,24,16,8,4,4,12,20,28,32,40,48,56,64,72,80,88,92,100,108,116,116,108,100,92,88,80,72,64,56,48,40,32,28,20,12,4,4,12,20,28,40,48,56,64,72,80,88,96,108,116,124,132,132,124,116,108,96,88,80,72,64,56,48,40,28,20,12,4,4,16,24,32,44,52,60,72,80,92,100,108,120,128,136,148,148,136,128,120,108,100,92,80,72,60,52,44,32,24,16,4,4,16,28,36,48,56,68,80,88,100,112,120,132,140,152,164,164,152,140,132,120,112,100,88,80,68,56,48,36,28,16,4,4,16,28,40,52,64,76,88,96,108,120,132,144,156,168,180,180,168,156,144,132,120,108,96,88,76,64,52,40,28,16,4,8,20,32,44,56,68,80,92,108,120,132,144,156,168,180,192,192,180,168,156,144,132,120,108,92,80,68,56,44,32,20,8,8,20,32,48,60,76,88,100,116,128,140,156,168,184,196,208,208,196,184,168,156,140,128,116,100,88,76,60,48,32,20,8,8,20,36,52,64,80,96,108,124,136,152,168,180,196,212,224,224,212,196,180,168,152,136,124,108,96,80,64,52,36,20,8,8,24,40,56,68,84,100,116,132,148,164,180,192,208,224,240,240,224,208,192,180,164,148,132,116,100,84,68,56,40,24,8,8,24,40,56,68,84,100,116,132,148,164,180,192,208,224,240,240,224,208,192,180,164,148,132,116,100,84,68,56,40,24,8,8,20,36,52,64,80,96,108,124,136,152,168,180,196,212,224,224,212,196,180,168,152,136,124,108,96,80,64,52,36,20,8,8,20,32,48,60,76,88,100,116,128,140,156,168,184,196,208,208,196,184,168,156,140,128,116,100,88,76,60,48,32,20,8,8,20,32,44,56,68,80,92,108,120,132,144,156,168,180,192,192,180,168,156,144,132,120,108,92,80,68,56,44,32,20,8,4,16,28,40,52,64,76,88,96,108,120,132,144,156,168,180,180,168,156,144,132,120,108,96,88,76,64,52,40,28,16,4,4,16,28,36,48,56,68,80,88,100,112,120,132,140,152,164,164,152,140,132,120,112,100,88,80,68,56,48,36,28,16,4,4,16,24,32,44,52,60,72,80,92,100,108,120,128,136,148,148,136,128,120,108,100,92,80,72,60,52,44,32,24,16,4,4,12,20,28,40,48,56,64,72,80,88,96,108,116,124,132,132,124,116,108,96,88,80,72,64,56,48,40,28,20,12,4,4,12,20,28,32,40,48,56,64,72,80,88,92,100,108,116,116,108,100,92,88,80,72,64,56,48,40,32,28,20,12,4,4,8,16,24,28,36,44,48,56,60,68,76,80,88,96,100,100,96,88,80,76,68,60,56,48,44,36,28,24,16,8,4,4,8,12,20,24,32,36,40,48,52,56,64,68,76,80,84,84,80,76,68,64,56,52,48,40,36,32,24,20,12,8,4,4,8,12,16,20,24,28,32,40,44,48,52,56,60,64,68,68,64,60,56,52,48,44,40,32,28,24,20,16,12,8,4,0,4,8,12,16,20,24,28,28,32,36,40,44,48,52,56,56,52,48,44,40,36,32,28,28,24,20,16,12,8,4,0,0,4,8,8,12,12,16,20,20,24,28,28,32,32,36,40,40,36,32,32,28,28,24,20,20,16,12,12,8,8,4,0,0,4,4,4,8,8,8,12,12,16,16,16,20,20,20,24,24,20,20,20,16,16,16,12,12,8,8,8,4,4,4,0,0,0,0,0,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,8,4,4,4,4,4,4,4,4,0,0,0,0,0,4,4,8,8,12,12,16,16,12,12,8,8,4,4,0,4,8,16,20,28,32,40,44,44,40,32,28,20,16,8,4,4,16,24,36,44,56,64,76,76,64,56,44,36,24,16,4,8,20,36,48,64,76,92,104,104,92,76,64,48,36,20,8,8,28,44,64,80,100,116,136,136,116,100,80,64,44,28,8,12,32,56,76,100,120,144,164,164,144,120,100,76,56,32,12,12,40,64,92,116,144,168,196,196,168,144,116,92,64,40,12,16,44,76,104,136,164,196,224,224,196,164,136,104,76,44,16,16,44,76,104,136,164,196,224,224,196,164,136,104,76,44,16,12,40,64,92,116,144,168,196,196,168,144,116,92,64,40,12,12,32,56,76,100,120,144,164,164,144,120,100,76,56,32,12,8,28,44,64,80,100,116,136,136,116,100,80,64,44,28,8,8,20,36,48,64,76,92,104,104,92,76,64,48,36,20,8,4,16,24,36,44,56,64,76,76,64,56,44,36,24,16,4,4,8,16,20,28,32,40,44,44,40,32,28,20,16,8,4,0,4,4,8,8,12,12,16,16,12,12,8,8,4,4,0,0,0,1,0,82,65,87,65,1,80,1,0,76,65,77,69,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,1,0,65,76,65,87,6,0,1,0,85,76,65,87,1,80,1,0,77,80,51,32,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,0,1,2,4,1,2,3,4,0,1,1,1,2,2,3,3,2,3,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,4,0,0,0,8,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,16,0,0,0,16,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,0,218,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,7,0,0,78,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,198,34,0,112,0,0,0,64,135,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,128,128,0,0,0,0,0,0,0,0,0,0,0,0,0,128,128,128,0,0,0,0,0,0,0,0,30,0,0,0,86,80,51,32,30,0,0,0,86,80,51,48,30,0,0,0,86,80,51,49,91,0,0,0,86,80,53,32,91,0,0,0,86,80,53,48,92,0,0,0,86,80,54,32,92,0,0,0,86,80,54,48,92,0,0,0,86,80,54,49,92,0,0,0,86,80,54,50,141,0,0,0,86,80,56,48,13,0,0,0,88,86,73,68,14,0,0,0,82,71,66,51,0,0,0,0,0,0,0,0,1,80,1,0,77,80,51,32,2,80,1,0,65,65,67,32,2,80,1,0,65,65,67,80,2,80,1,0,86,76,66,32,36,80,1,0,83,80,88,32,2,0,1,0,80,67,77,32,0,0,0,0,0,0,0,0,5,11,17,5,11,17,0,0,10,20,34,10,20,34,0,0,0,1,2,3,4,5,6,7,8,10,12,14,16,18,20,22,24,28,32,36,40,44,48,52,56,64,72,80,88,96,104,112,30,51,22,54,3,7,252,38,14,55,46,81,22,58,253,2,52,31,249,51,15,44,74,30,85,239,10,33,18,80,28,62,10,32,23,69,72,26,35,17,73,60,8,56,2,6,254,251,51,4,11,50,66,76,21,44,33,47,1,26,64,48,57,40,38,16,246,228,92,22,238,29,246,5,243,49,19,24,70,34,61,48,30,14,250,25,58,33,42,60,67,17,54,17,22,30,67,44,247,50,245,43,40,32,59,82,13,49,242,55,60,36,48,49,31,47,15,12,4,65,1,23,29,39,45,254,84,69,0,72,37,57,27,41,241,240,35,31,14,61,24,0,27,24,16,41,55,34,53,9,56,12,25,29,53,5,20,236,248,20,13,28,253,78,38,16,11,62,46,29,21,24,46,65,43,233,89,18,74,21,38,244,19,12,237,8,15,33,4,57,9,248,36,35,26,28,7,83,63,79,75,11,3,87,37,47,34,40,39,19,20,42,27,34,39,77,13,42,59,64,45,255,32,37,45,251,53,250,7,36,50,23,6,32,9,235,18,71,27,52,231,31,35,42,255,68,63,52,26,43,66,37,41,25,40,70,254,127,94,188,0,32,101,189,254,255,138,60,0,72,24,190,0,60,135,190,0,160,202,189,0,180,131,62,2,128,164,60,0,236,56,191,0,20,227,190,0,96,107,190,0,96,44,62,0,36,240,62,255,95,114,61,0,112,27,190,0,116,211,62,2,0,83,188,0,208,8,62,0,4,223,62,0,48,195,189,0,144,21,191,0,12,201,62,0,224,170,189,0,24,131,190,0,248,105,62,0,48,133,62,0,232,39,191,0,8,49,62,0,160,177,189,0,32,85,189,0,128,149,61,0,196,146,190,0,84,183,190,0,48,134,61,0,64,192,189,0,16,88,62,0,36,145,190,0,90,57,191,0,224,78,61,0,208,217,189,0,16,65,190,0,48,152,62,0,0,84,62,0,136,152,190,0,176,192,190,0,156,245,62,0,80,204,189,0,32,167,62,0,192,149,190,0,148,144,190,0,68,133,62,0,32,185,190,0,184,97,62,255,255,3,189,0,208,190,190,1,0,26,189,1,240,202,61,0,112,110,62,0,216,69,62,0,0,20,62,255,63,175,188,0,192,73,190,0,116,161,62,0,112,43,190,0,92,179,62,0,144,182,190,0,74,41,191,250,255,229,187,0,0,86,62,0,104,137,62,0,148,172,190,255,31,59,189,0,8,1,62,0,160,210,61,0,240,149,61,0,48,59,190,0,20,195,62,0,32,90,62,1,0,58,61,254,127,61,60,0,32,135,190,1,64,192,188,0,144,98,190,0,96,152,62,0,132,185,190,0,84,160,190,0,8,15,190,0,240,230,189,0,0,71,190,0,152,176,62,0,0,192,60,0,232,96,62,2,128,227,188,0,66,45,191,0,80,184,189,0,192,17,62,0,208,141,190,0,164,3,63,255,191,78,189,0,112,247,62,0,76,190,62,0,170,27,191,0,200,63,62,0,144,27,190,248,255,208,59,255,255,231,60,0,240,31,190,0,64,27,63,0,128,95,62,0,192,130,61,0,36,163,190,0,144,180,61,0,48,30,62,0,176,143,189,0,0,167,189,0,192,209,190,0,180,203,190,0,208,239,189,0,208,97,62,0,24,61,62,0,184,48,190,1,0,26,61,255,191,125,189,8,0,142,59,0,96,249,61,0,36,174,62,0,32,131,62,1,224,88,189,0,24,210,62,0,152,44,62,0,10,67,191,0,200,13,62,0,216,70,190,0,104,92,190,0,100,227,190,255,31,167,189,0,92,144,190,254,127,153,188,0,248,30,62,0,176,191,190,0,176,229,190,0,168,220,62,0,104,125,190,0,68,255,62,0,40,24,62,0,96,195,62,0,88,82,62,0,148,200,190,0,148,40,191,0,212,223,190,0,128,5,62,255,95,81,189,0,148,204,62,0,160,91,62,255,31,71,189,0,80,172,62,1,224,216,61,0,128,97,191,0,208,157,190,0,132,197,62,0,216,153,62,0,216,198,62,0,192,186,61,0,196,186,190,2,128,134,188,0,216,107,190,0,108,133,62,0,32,65,62,0,240,95,190,0,232,54,190,0,88,152,190,0,64,200,61,255,79,221,61,0,28,4,191,9,0,72,58,0,200,7,62,0,32,227,61,0,160,118,190,0,144,127,62,5,0,98,60,255,159,41,189,0,64,74,189,0,238,18,63,0,88,140,62,0,64,141,62,0,120,230,62,0,224,166,190,0,144,228,61,0,0,31,188,0,244,148,62,1,128,9,61,0,146,53,191,255,255,71,61,0,184,222,62,0,32,158,61,0,20,141,190,2,192,142,188,0,80,172,189,255,255,36,189,0,76,7,191,0,32,150,189,1,64,84,61,0,192,90,62,0,40,64,190,0,144,144,61,255,127,246,188,0,60,167,62,0,92,138,62,0,96,143,190,0,232,51,62,0,192,8,61,0,216,154,62,1,160,32,189,0,188,164,62,0,8,115,190,255,159,175,61,0,240,195,190,0,80,188,61,1,64,148,189,0,184,55,62,0,70,3,191,0,192,128,190,0,168,74,62,0,144,68,190,0,120,41,62,0,96,217,62,0,88,200,62,254,255,234,188,0,32,56,62,0,0,127,62,0,14,68,191,0,160,86,190,0,50,28,63,0,128,189,62,0,184,188,62,0,192,55,189,1,176,218,61,0,200,35,190,0,64,90,189,0,188,145,62,255,127,131,189,0,96,189,190,0,104,143,190,0,240,240,189,1,160,48,61,0,160,164,189,255,31,72,61,2,64,251,188,134,0,224,185,0,144,175,62,5,0,34,188,0,96,178,62,0,124,166,62,0,160,38,190,0,240,195,62,1,192,4,61,1,80,254,61,0,192,18,190,0,180,178,190,0,168,59,190,0,164,150,62,0,188,226,62,0,112,64,63,0,38,44,191,0,96,249,189,0,236,142,62,0,156,152,190,0,104,75,62,0,12,154,62,0,64,104,62,0,144,187,190,0,148,166,190,0,86,19,191,0,104,42,190,0,80,224,62,0,160,170,61,0,64,35,62,0,196,135,62,0,56,120,190,1,224,240,189,0,80,44,190,0,8,18,190,0,72,237,62,0,192,241,61,0,30,14,191,0,128,206,188,0,136,18,190,247,255,146,59,1,64,225,60,0,100,156,190,0,172,53,63,0,244,230,62,0,22,42,63,0,188,46,191,0,240,255,189,0,80,187,61,0,40,88,190,0,160,115,190,0,168,76,63,0,64,180,190,0,160,127,190,0,176,63,62,0,96,67,190,0,192,152,61,0,32,156,61,0,92,147,190,0,16,190,190,0,128,72,190,254,63,145,188,0,48,43,190,0,136,5,62,0,64,22,62,0,252,216,62,1,192,18,61,0,32,234,61,1,192,82,61,0,224,228,62,0,144,183,61,5,0,96,60,0,146,11,191,0,248,1,190,0,216,88,62,0,192,73,61,0,8,157,62,0,224,225,189,0,64,72,62,0,8,142,190,0,248,107,62,0,72,31,62,0,160,69,190,0,188,131,190,0,72,54,62,0,160,18,189,0,128,79,189,0,0,142,189,0,144,194,189,0,48,160,189,0,160,116,62,0,84,163,190,255,191,251,60,255,255,135,187,0,248,28,63,0,88,190,62,0,168,9,190,0,24,31,190,0,200,68,190,0,12,194,190,0,184,76,62,255,127,215,60,0,192,0,190,0,192,132,62,1,128,200,188,0,180,151,62,0,140,208,190,0,128,49,190,0,240,120,62,0,64,217,189,0,216,23,62,0,16,180,61,0,240,63,190,1,64,100,189,255,255,69,189,0,128,214,61,0,160,148,190,0,72,45,191,0,60,144,190,0,112,213,190,255,191,93,61,0,112,110,190,0,176,195,61,0,176,183,189,0,192,26,190,0,112,2,62,0,64,184,62,0,56,148,62,0,36,157,62,0,80,117,62,1,208,142,61,0,188,159,190,0,240,60,190,0,40,100,62,0,48,93,190,0,224,112,62,0,80,30,191,0,64,5,190,0,60,135,62,0,72,242,62,0,96,135,190,0,112,198,62,0,176,49,62,0,168,133,190,0,112,132,190,0,96,251,189,0,60,152,190,0,112,157,61,0,88,62,62,0,224,181,189,0,172,159,62,255,159,89,61,0,240,222,189,0,152,24,190,0,152,100,190,0,224,174,189,0,224,74,62,0,16,74,62,0,208,65,190,0,200,148,62,0,216,130,62,0,212,248,190,0,48,64,62,254,127,92,60,0,160,178,62,0,120,92,62,0,88,75,62,0,24,63,62,253,127,100,188,0,160,185,189,0,144,198,190,0,16,139,62,0,176,80,190,0,116,164,190,0,160,116,190,0,188,138,62,0,128,127,62,0,64,162,61,255,47,153,61,0,108,2,191,0,80,209,61,0,106,21,63,0,184,71,190,0,16,62,190,251,255,62,188,0,164,241,62,0,176,101,62,0,208,197,190,1,224,24,189,1,0,188,189,0,48,143,61,0,176,26,62,0,0,83,62,255,127,116,189,0,32,214,190,0,128,250,61,255,95,63,189,0,160,81,189,1,0,236,189,0,188,4,191,255,255,38,189,0,188,226,62,0,16,36,191,0,72,46,62,253,63,183,60,0,248,105,62,0,184,109,190,0,168,165,190,0,16,16,190,0,4,152,190,0,176,75,190,1,64,227,60,0,176,86,190,0,156,5,191,0,160,69,190,255,79,149,189,0,40,251,62,0,96,100,190,255,31,103,61,0,96,6,62,0,48,85,190,0,254,85,191,0,144,167,189,0,52,137,62,46,0,112,186,255,175,193,189,0,0,47,62,0,88,138,190,0,252,154,62,0,32,97,61,0,224,195,61,0,240,175,189,0,128,174,60,0,248,183,62,0,128,94,62,0,168,29,190,0,0,79,189,255,191,222,60,0,240,38,62,0,64,221,62,0,128,209,61,0,0,209,190,0,168,93,62,1,192,172,61,1,64,228,189,0,156,204,190,0,32,102,189,0,96,209,189,0,192,27,191,0,172,172,62,0,224,129,189,0,136,242,190,0,52,168,190,0,192,86,61,0,16,73,62,0,248,67,190,0,212,45,191,0,176,37,62,1,64,82,61,0,48,100,190,255,143,197,61,0,184,120,62,0,112,230,190,0,80,180,61,0,232,15,62,0,160,103,62,5,0,36,188,0,36,186,62,0,104,75,190,0,120,155,190,0,248,118,190,0,26,19,191,0,172,135,62,0,0,50,61,1,160,200,189,0,76,244,190,0,24,115,190,0,224,63,62,1,208,182,61,255,255,228,188,9,0,72,59,1,48,178,189,0,52,198,190,255,255,3,61,0,16,224,61,0,144,214,190,254,191,132,188,0,244,240,190,0,124,194,62,0,112,93,190,0,164,245,62,0,72,77,190,0,22,32,191,0,196,137,190,2,192,235,188,6,0,220,59,0,216,148,190,0,200,124,190,0,0,33,190,0,104,133,190,0,112,153,62,0,132,144,62,1,32,184,189,0,128,43,190,0,104,239,190,0,88,128,190,0,240,128,190,0,44,235,190,255,191,110,61,0,132,148,62,0,32,116,62,0,16,56,190,0,228,137,62,0,16,219,61,1,64,140,189,0,96,47,190,0,128,215,189,0,202,13,191,0,156,216,190,0,208,155,189,0,168,121,62,0,144,197,62,0,224,44,62,0,248,136,62,0,48,49,62,0,88,183,62,0,64,98,190,0,52,157,190,0,232,145,190,0,0,49,189,0,216,27,62,0,208,46,190,0,100,201,190,0,224,12,61,0,96,221,189,0,160,156,190,0,108,135,62,0,208,151,189,0,168,11,62,3,0,46,188,0,88,143,62,0,32,52,61,0,160,99,189,0,192,17,191,0,192,9,61,3,128,27,188,0,196,6,63,0,248,226,190,0,240,144,62,1,64,97,189,0,184,110,190,0,240,152,190,255,223,81,189,0,96,137,62,0,108,180,190,0,176,158,190,0,100,177,62,0,128,74,190,0,84,228,62,0,0,13,62,0,60,232,62,0,104,76,62,0,136,218,62,0,0,33,62,15,0,168,58,0,72,115,62,0,220,209,62,0,216,128,62,3,0,240,187,1,16,254,189,0,80,222,190,255,255,131,187,0,84,175,62,0,172,185,62,0,152,64,62,0,128,190,189,0,224,210,189,0,160,98,61,0,16,162,190,0,208,18,62,0,104,179,62,0,156,166,62,255,159,106,61,0,96,246,189,0,212,132,190,0,0,80,190,0,224,40,190,0,200,235,190,0,240,163,189,0,250,1,63,0,144,37,62,0,156,145,62,0,0,166,61,0,160,67,190,0,148,197,62,0,240,39,190,0,84,130,190,0,176,79,62,0,72,84,190,0,64,129,189,0,164,168,62,0,240,25,62,0,192,90,189,0,24,156,62,1,144,238,189,0,156,194,62,0,112,77,190,0,140,222,62,3,128,60,60,0,16,183,62,0,160,6,190,0,198,44,63,255,127,85,61,0,236,142,62,0,228,201,190,0,202,64,63,0,224,8,190,0,104,122,62,0,80,216,62,0,184,40,191,8,0,179,187,0,0,15,189,0,224,11,190,0,224,169,189,0,208,233,190,0,52,139,62,0,96,2,62,0,138,28,63,0,0,214,61,0,164,147,190,46,0,112,58,0,24,124,62,0,88,6,62,1,224,104,61,0,184,49,62,0,56,215,62,0,96,174,61,0,64,123,62,0,16,66,62,0,168,67,190,0,248,25,190,1,64,191,60,0,196,12,63,0,124,165,62,0,232,36,190,2,64,250,188,0,52,223,62,0,64,49,62,0,76,28,63,0,64,125,62,0,172,170,62,0,16,28,62,0,160,31,62,0,128,186,62,0,176,155,190,0,56,8,190,254,255,139,59,0,224,42,61,0,224,169,190,0,48,175,62,0,64,255,189,2,128,226,188,255,223,113,61,0,244,160,190,0,72,41,62,0,220,176,62,1,224,6,189,0,72,0,62,0,48,252,189,0,224,6,190,255,223,66,61,0,228,230,190,0,112,67,190,0,244,180,62,0,248,109,190,0,16,176,190,0,176,230,61,0,48,33,190,1,0,88,61,0,218,63,63,0,56,92,62,0,96,174,61,0,12,217,190,0,0,72,190,0,180,180,62,0,144,129,62,0,24,33,62,0,8,52,191,0,24,93,190,0,76,182,62,0,184,16,62,1,32,240,61,0,88,34,62,0,224,123,190,0,192,143,61,255,63,174,60,0,160,1,62,0,224,130,61,255,191,251,189,0,32,30,62,0,236,243,190,255,191,125,61,0,254,22,63,0,40,27,190,0,160,19,189,0,180,230,190,254,255,136,188,0,160,240,190,0,216,131,62,0,48,57,62,0,112,136,61,0,184,7,62,0,164,45,63,1,224,232,61,0,240,231,61,0,224,60,189,0,144,159,189,0,28,187,190,1,48,138,189,0,196,161,190,0,48,37,62,0,244,214,62,0,192,226,61,0,224,188,190,0,136,158,62,0,236,193,190,0,200,21,63,5,0,129,59,0,176,252,61,255,63,12,61,0,128,94,190,0,120,3,190,0,140,240,190,255,95,112,61,0,20,128,190,0,84,140,62,0,4,39,63,0,72,176,190,0,112,27,190,0,240,15,62,0,140,171,62,0,152,147,62,0,48,203,61,0,20,176,62,0,216,11,62,0,192,113,190,251,127,13,60,253,63,215,60,0,200,67,190,0,128,74,62,255,191,147,189,0,240,159,61,0,128,13,61,1,0,12,189,141,255,175,57,0,128,108,190,0,56,63,62,0,128,109,61,255,63,28,61,255,223,48,189,1,192,96,61,0,208,176,61,0,60,15,63,0,0,130,189,0,160,211,61,0,144,129,62,255,191,111,61,0,208,250,61,0,200,130,190,0,108,175,190,0,144,186,190,0,40,90,190,1,160,80,189,2,128,227,60,0,16,156,61,0,64,89,190,0,0,191,189,0,200,66,62,0,196,207,190,253,127,67,188,0,56,75,62,0,236,180,190,0,128,151,189,0,224,77,62,0,112,176,61,0,52,227,190,0,224,233,61,0,104,122,62,0,136,41,190,1,32,80,189,252,127,102,188,0,208,142,62,0,104,63,190,0,16,153,61,0,96,13,61,0,112,203,190,0,168,92,62,0,192,102,190,0,4,203,190,0,96,76,189,0,158,19,191,0,224,130,61,0,198,30,63,0,240,9,190,0,0,50,61,0,224,95,190,2,128,228,188,0,88,4,63,0,64,141,190,0,180,199,62,0,224,201,61,248,255,241,187,0,88,160,62,213,255,255,57,0,116,238,190,0,52,151,62,1,0,205,189,0,160,142,190,1,64,19,61,0,64,128,62,0,240,62,191,0,204,129,190,0,64,7,189,0,176,159,62,255,191,128,60,0,40,239,62,0,24,93,62,0,176,148,61,0,184,215,190,0,252,9,191,0,8,12,190,0,176,41,190,0,104,176,190,0,32,253,61,255,15,229,189,254,127,30,60,0,8,177,62,1,0,108,189,0,108,178,62,0,176,52,62,0,180,201,190,255,191,211,61,0,136,58,62,0,240,83,62,0,82,23,63,1,192,236,189,0,64,151,189,0,240,212,61,0,112,181,62,0,32,106,190,2,0,147,60,0,208,51,62,0,40,51,190,0,176,248,61,0,208,223,61,0,0,128,191,5,0,98,188,0,120,89,62,0,108,138,190,0,224,139,62,0,200,189,190,0,188,211,62,0,20,205,190,250,255,225,59,0,196,134,62,0,12,201,62,0,42,39,63,0,32,213,62,0,112,14,190,0,164,72,63,0,108,158,190,0,136,78,62,0,144,201,190,0,178,112,63,0,112,118,190,0,160,99,61,0,56,123,190,0,0,95,189,0,126,68,191,0,104,70,190,0,32,226,189,0,136,51,190,0,232,35,62,254,63,179,60,0,216,50,62,255,223,49,189,0,90,17,191,0,220,209,190,0,164,136,62,255,159,239,61,16,0,98,187,1,0,93,189,0,160,191,62,0,124,208,190,0,240,25,190,255,255,135,188,0,224,43,61,0,192,58,189,0,208,4,190,0,0,246,61,0,112,172,61,0,96,229,189,0,24,180,62,1,112,210,61,0,132,131,190,0,12,248,62,0,32,4,61,0,116,145,62,0,128,63,190,0,196,185,62,1,96,6,189,0,100,165,62,0,120,48,62,0,36,247,62,0,76,159,62,255,159,74,189,0,208,2,62,0,224,6,63,0,32,209,61,255,223,115,61,0,192,117,61,0,72,78,62,2,0,244,59,0,220,139,62,0,160,121,62,0,32,203,62,1,128,139,60,0,212,181,190,0,192,232,61,0,208,10,190,0,68,250,62,0,224,29,190,0,96,187,189,254,63,214,188,0,200,236,62,0,246,56,191,0,176,100,62,0,56,116,62,0,132,131,190,0,96,174,189,254,255,168,188,0,156,176,190,2,64,188,188,0,202,77,191,0,96,165,189,0,240,1,190,0,64,141,189,0,200,118,62,0,136,182,190,255,191,195,189,0,200,149,62,0,224,108,62,0,72,43,190,0,0,0,0,0,48,120,190,0,52,158,62,0,16,151,62,0,0,86,190,0,176,46,62,0,32,157,189,0,104,19,190,1,64,100,61,0,248,82,62,0,248,3,191,1,192,1,189,0,16,250,190,0,40,81,190,0,216,16,62,1,0,149,61,0,70,68,191,0,72,102,190,0,120,83,62,255,127,5,61,218,255,95,58,1,0,249,60,0,124,243,62,0,92,196,62,56,149,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,9,37,0,16,194,35,0,52,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,8,216,34,0,64,23,34,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,152,124,33,0,64,23,34,0,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,0,3,33,0,232,157,32,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,0,3,33,0,168,66,32,0,232,157,32,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,0,3,33,0,104,42,40,0,136,204,39,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,3,33,0,40,101,39,0,232,21,39,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,3,33,0,0,210,38,0,80,141,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,3,33,0,56,82,38,0,0,27,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,3,33,0,88,239,37,0,16,194,35,0,72,194,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,176,193,37,0,64,23,34,0,60,193,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,216,159,37,0,64,23,34,0,60,193,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,136,117,37,0,232,157,32,0,64,193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,136,117,37,0,232,50,37,0,232,157,32,0,64,193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,136,117,37,0,104,42,40,0,136,204,39,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,136,117,37,0,40,101,39,0,232,21,39,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,136,117,37,0,0,210,38,0,80,141,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,136,117,37,0,56,82,38,0,0,27,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,136,117,37,0,136,9,37,0,200,225,36,0,92,131,1,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,192,190,36,0,200,161,36,0,80,130,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,144,134,36,0,200,161,36,0,80,130,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,224,107,36,0,136,80,36,0,84,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,224,107,36,0,32,56,36,0,136,80,36,0,84,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,224,107,36,0,104,42,40,0,136,204,39,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,107,36,0,40,101,39,0,232,21,39,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,107,36,0,0,210,38,0,80,141,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,107,36,0,56,82,38,0,0,27,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,224,107,36,0,24,24,36,0,56,222,35,0,112,68,2,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,112,194,35,0,24,171,35,0,100,67,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,72,149,35,0,24,171,35,0,100,67,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,8,127,35,0,40,104,35,0,104,67,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,8,127,35,0,8,86,35,0,40,104,35,0,104,67,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,8,127,35,0,104,42,40,0,136,204,39,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,127,35,0,40,101,39,0,232,21,39,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,127,35,0,0,210,38,0,80,141,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,127,35,0,56,82,38,0,0,27,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,127,35,0,112,68,35,0,128,50,35,0,132,5,3,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,16,25,35,0,144,237,34,0,120,4,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,80,216,34,0,144,237,34,0,120,4,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,144,201,34,0,24,185,34,0,124,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,144,201,34,0,224,166,34,0,24,185,34,0,124,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,64,16,0,1,0,144,201,34,0,104,42,40,0,136,204,39,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,201,34,0,40,101,39,0,232,21,39,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,201,34,0,0,210,38,0,80,141,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,201,34,0,56,82,38,0,0,27,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,201,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,149,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,3,0,0,0,0,0,0,0,0,0,0,192,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,193,35,0,112,0,0,0,192,241,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,35,37,0,112,0,0,0,80,140,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,12,0,0,0,0,0,0,0,26,27,91,48,59,51,48,59,52,48,109,78,69,88,84,0,254,255,0,0,255,255,254,255,1,0,254,255,255,255,254,255,1,0,254,255,2,0,0,0,1,0,254,255,2,0,0,0,1,0,2,0,2,0,0,0,1,0,2,0,255,255,2,0,1,0,2,0,255,255,2,0,254,255,0,0,255,255,2,0,254,255,0,0,255,255,254,255,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,96,208,39,0,0,0,0,0,116,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,129,33,0,112,0,0,0,40,252,11,0,100,66], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+775310);
/* memory initializer */ allocate([52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,128,128,255,0,0,0,0,12,128,128,255,0,0,0,0,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,3,2,1,2,0,0,0,0,3,2,1,2,0,0,0,0,2,4,0,0,0,0,0,0,3,5,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,72,0,6,14,43,52,2,5,1,1,13,1,3,1,4,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,6,1,0,14,0,0,0,0,0,1,0,6,14,43,52,4,1,1,2,13,1,3,1,2,4,64,1,14,0,0,0,0,80,1,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,1,1,14,0,0,0,0,0,1,0,6,14,43,52,1,1,1,255,75,70,65,65,0,13,77,79,14,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,14,6,6,2,2,1,0,0,233,3,0,0,192,93,0,0,210,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,24,0,0,0,208,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,233,3,0,0,48,117,0,0,66,6,0,0,65,6,0,0,66,6,0,0,65,6,0,0,66,6,0,0,0,0,0,0,233,3,0,0,96,234,0,0,33,3,0,0,33,3,0,0,33,3,0,0,33,3,0,0,32,3,0,0,0,0,0,0,1,0,0,0,25,0,0,0,128,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,50,0,0,0,192,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,17,1,0,6,14,43,52,4,1,1,2,13,1,3,1,2,4,96,1,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,65,1,14,0,0,0,25,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,5,0,0,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,81,0,6,14,43,52,4,1,1,3,4,1,2,2,1,1,16,0,6,14,43,52,4,1,1,3,4,1,2,2,1,1,17,0,6,14,43,52,4,1,1,3,4,1,2,2,1,2,2,0,6,14,43,52,4,1,1,3,4,1,2,2,1,2,3,0,6,14,43,52,4,1,1,3,4,1,2,2,1,3,2,0,6,14,43,52,4,1,1,3,4,1,2,2,1,3,3,0,6,14,43,52,4,1,1,3,4,1,2,2,1,4,2,0,6,14,43,52,4,1,1,3,4,1,2,2,1,4,3,0,6,14,43,52,4,1,1,3,4,1,2,2,1,5,2,0,6,14,43,52,4,1,1,3,4,1,2,2,1,5,3,0,6,14,43,52,2,5,1,1,13,1,2,1,1,5,1,0,82,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,1,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,2,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,3,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,4,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,1,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,2,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,3,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,4,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,4,2,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,4,4,0,164,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,48,0,40,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,24,0,54,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,55,0,62,0,0,0,64,0,0,0,2,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,54,0,136,0,0,0,64,0,0,0,1,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,15,0,6,0,0,0,56,0,0,0,5,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,17,0,24,0,0,0,80,0,0,0,3,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,68,0,10,0,0,0,128,0,0,0,6,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,66,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,40,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,41,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,81,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,72,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,71,0,10,0,0,0,128,0,0,0,7,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,58,0,64,0,0,0,80,0,0,0,8,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,59,0,64,0,0,0,80,0,0,0,8,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,20,0,78,0,0,0,56,0,0,0,4,0,0,0,6,14,43,52,2,83,1,1,13,1,4,1,2,2,0,0,94,0,0,0,36,0,0,0,9,0,0,0,6,14,43,52,2,83,1,1,13,1,2,1,1,16,1,0,108,0,0,0,72,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,60,0,0,6,14,43,52,1,1,1,1,1,1,21,2,0,0,0,0,2,59,0,0,6,14,43,52,1,1,1,2,7,2,1,16,2,4,0,0,5,59,0,0,6,14,43,52,1,1,1,2,3,1,2,1,5,0,0,0,6,59,0,0,6,14,43,52,1,1,1,2,6,1,1,4,6,4,0,0,3,59,0,0,6,14,43,52,1,1,1,2,6,1,1,4,2,1,0,0,9,59,0,0,6,14,43,52,1,1,1,5,1,2,2,3,0,0,0,0,10,59,0,0,6,14,43,52,1,1,1,5,1,2,2,16,2,1,0,0,11,59,0,0,6,14,43,52,1,1,1,5,1,2,2,16,2,2,0,0,9,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,1,0,0,0,1,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,2,1,0,0,2,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,3,1,0,0,4,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,5,1,0,0,5,60,0,0,6,14,43,52,1,1,1,2,5,32,7,1,7,0,0,0,6,60,0,0,6,14,43,52,1,1,1,2,7,2,1,16,2,3,0,0,1,25,0,0,6,14,43,52,1,1,1,2,6,1,1,4,5,1,0,0,2,25,0,0,6,14,43,52,1,1,1,2,6,1,1,4,5,2,0,0,1,39,0,0,6,14,43,52,1,1,1,2,6,1,1,6,1,0,0,0,7,63,0,0,6,14,43,52,1,1,1,4,1,3,4,4,0,0,0,0,1,68,0,0,6,14,43,52,1,1,1,1,1,1,21,16,0,0,0,0,5,68,0,0,6,14,43,52,1,1,1,2,7,2,1,16,1,3,0,0,4,68,0,0,6,14,43,52,1,1,1,2,7,2,1,16,2,5,0,0,3,68,0,0,6,14,43,52,1,1,1,2,6,1,1,4,6,5,0,0,1,71,0,0,6,14,43,52,1,1,1,2,6,1,1,4,2,3,0,0,1,72,0,0,6,14,43,52,1,1,1,2,1,7,1,1,0,0,0,0,4,72,0,0,6,14,43,52,1,1,1,2,1,4,1,3,0,0,0,0,1,75,0,0,6,14,43,52,1,1,1,2,5,48,4,5,0,0,0,0,2,75,0,0,6,14,43,52,1,1,1,2,7,2,1,3,1,3,0,0,3,72,0,0,6,14,43,52,1,1,1,2,6,1,1,4,2,4,0,0,1,2,0,0,6,14,43,52,1,1,1,2,4,7,1,0,0,0,0,0,2,2,0,0,6,14,43,52,1,1,1,2,7,2,2,1,1,3,0,0,1,16,0,0,6,14,43,52,1,1,1,2,6,1,1,4,6,9,0,0,1,18,0,0,6,14,43,52,1,1,1,2,7,2,1,3,1,4,0,0,1,17,0,0,6,14,43,52,1,1,1,2,6,1,1,3,1,0,0,0,2,17,0,0,6,14,43,52,1,1,1,2,6,1,1,3,2,0,0,0,1,21,0,0,6,14,43,52,1,1,1,2,7,2,1,3,1,5,0,0,2,21,0,0,6,14,43,52,1,1,1,2,4,4,1,1,2,6,0,0,3,21,0,0,6,14,43,52,1,1,1,1,4,4,1,1,5,0,0,0,1,63,0,0,6,14,43,52,1,1,1,4,6,1,1,4,6,11,0,0,6,48,0,0,6,14,43,52,1,1,1,5,6,1,1,3,5,0,0,0,1,48,0,0,6,14,43,52,1,1,1,1,4,6,1,1,0,0,0,0,4,48,0,0,6,14,43,52,1,1,1,2,6,1,1,4,1,2,0,0,12,50,0,0,6,14,43,52,1,1,1,1,4,1,3,1,4,0,0,0,13,50,0,0,6,14,43,52,1,1,1,2,4,1,3,2,5,0,0,0,3,50,0,0,6,14,43,52,1,1,1,1,4,1,5,2,2,0,0,0,2,50,0,0,6,14,43,52,1,1,1,1,4,1,5,2,1,0,0,0,9,50,0,0,6,14,43,52,1,1,1,1,4,1,5,1,12,0,0,0,8,50,0,0,6,14,43,52,1,1,1,1,4,1,5,1,11,0,0,0,14,50,0,0,6,14,43,52,1,1,1,1,4,1,1,1,1,0,0,0,1,50,0,0,6,14,43,52,1,1,1,2,4,1,6,1,0,0,0,0,18,50,0,0,6,14,43,52,1,1,1,2,4,1,3,1,6,0,0,0,1,51,0,0,6,14,43,52,1,1,1,2,4,1,5,3,10,0,0,0,2,51,0,0,6,14,43,52,1,1,1,1,4,1,5,1,5,0,0,0,2,61,0,0,6,14,43,52,1,1,1,4,4,2,3,1,4,0,0,0,3,61,0,0,6,14,43,52,1,1,1,5,4,2,3,1,1,1,0,0,7,61,0,0,6,14,43,52,1,1,1,5,4,2,1,1,4,0,0,0,1,61,0,0,6,14,43,52,1,1,1,4,4,2,3,3,4,0,0,0,6,61,0,0,6,14,43,52,1,1,1,2,4,2,4,2,0,0,0,0,11,63,0,0,6,14,43,52,1,1,1,5,5,48,4,6,0,0,0,0,12,63,0,0,6,14,43,52,1,1,1,5,7,2,1,3,1,10,0,0,13,63,0,0,6,14,43,52,1,1,1,5,7,2,2,1,1,2,0,0,5,63,0,0,6,14,43,52,1,1,1,4,4,6,2,1,0,0,0,0,6,63,0,0,6,14,43,52,1,1,1,4,1,3,4,5,0,0,0,0,8,63,0,0,6,14,43,52,1,1,1,4,4,4,4,1,1,0,0,0,9,63,0,0,6,14,43,52,1,1,1,5,4,4,4,1,6,0,0,0,10,63,0,0,6,14,43,52,1,1,1,5,4,4,4,2,5,0,0,0,0,128,0,0,6,14,43,52,1,1,1,5,4,1,6,2,1,11,0,0,7,128,0,0,6,14,43,52,1,1,1,5,4,1,6,2,1,10,0,0,9,61,0,0,6,14,43,52,1,1,1,5,4,2,3,3,5,0,0,0,10,61,0,0,6,14,43,52,1,1,1,5,4,2,3,2,1,0,0,0,0,0,0,0,6,14,43,52,0,0,0,0,6,14,43,52,4,1,1,10,4,1,2,2,1,50,0,0,14,0,0,0,28,0,0,0,6,14,43,52,4,1,1,7,4,1,2,2,3,1,1,0,14,0,0,0,89,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,0,0,14,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,66,0,2,0,0,0,0,0,0,0,12,0,1,0,1,0,0,0,0,0,1,0,1,0,0,0,25,0,0,0,15,0,0,0,100,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,1,2,1,1,13,1,3,1,0,0,0,0,6,14,43,52,4,1,1,2,13,1,3,1,2,4,96,1,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,3,4,1,2,2,1,0,0,0,162,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,6,3,0,6,14,43,52,1,2,1,1,13,1,3,1,22,1,3,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,84,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,6,1,0,6,14,43,52,1,2,1,1,13,1,3,1,22,1,1,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,224,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,1,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,1,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,1,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,154,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,2,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,2,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,2,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,154,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,3,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,3,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,3,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,154,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,4,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,4,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,4,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,154,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,5,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,5,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,5,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,154,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,6,1,6,14,43,52,1,2,1,1,13,1,3,1,5,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,6,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,1,6,1,6,14,43,52,1,2,1,1,13,1,3,1,6,1,16,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,154,0,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,127,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,0,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,64,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,1,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,65,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,2,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,80,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,3,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,81,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,4,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,96,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,5,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,97,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,6,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,98,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,7,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,2,99,1,6,14,43,52,1,2,1,1,13,1,3,1,24,1,1,0,6,14,43,52,4,1,1,1,4,1,2,2,2,2,8,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,1,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,3,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,4,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,7,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,8,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,9,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,16,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,17,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,18,0,0,220,1,0,0,6,14,43,52,4,1,1,1,13,1,3,1,2,17,1,0,6,14,43,52,1,2,1,1,13,1,3,1,21,1,5,0,6,14,43,52,4,1,1,10,4,1,2,2,113,19,0,0,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,4,1,7,13,1,3,1,2,126,1,0,6,14,43,52,4,1,1,7,13,1,3,1,2,11,1,0,67,72,85,75,67,72,85,75,67,72,85,75,67,72,85,75,6,14,43,52,1,1,1,9,6,1,1,2,2,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,40,0,6,14,43,52,1,2,1,1,14,4,3,1,0,0,0,0,6,14,43,52,2,83,1,1,13,1,1,1,1,1,71,0,0,0,0,0,255,255,255,255,254,255,255,255,253,255,255,255,252,255,255,255,251,255,255,255,250,255,255,255,249,255,255,255,248,255,255,255,247,255,255,255,246,255,255,255,245,255,255,255,244,255,255,255,243,255,255,255,242,255,255,255,241,255,255,255,240,255,255,255,0,0,0,0,5,6,9,10,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,0,0,0,0,0,0,0,0,254,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,0,0,0,0,0,0,0,0,254,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,0,0,0,0,0,0,0,0,254,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,0,0,0,0,0,0,0,0,254,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,254,255,255,255,0,0,0,0,254,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,1,0,0,0,255,255,255,255,255,255,255,255,254,255,255,255,0,0,0,0,0,0,0,0,254,255,255,255,255,255,255,255,254,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,1,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,0,0,0,0,0,0,0,0,253,255,255,255,253,255,255,255,253,255,255,255,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,0,0,0,0,253,255,255,255,253,255,255,255,0,0,0,0,253,255,255,255,253,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,2,0,0,0,255,255,255,255,255,255,255,255,1,0,0,0,255,255,255,255,253,255,255,255,0,0,0,0,0,0,0,0,253,255,255,255,253,255,255,255,253,255,255,255,255,255,255,255,1,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,2,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,0,0,0,0,0,0,0,0,253,255,255,255,253,255,255,255,253,255,255,255,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,4,0,0,0,255,255,255,255,255,255,255,255,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,253,255,255,255,253,255,255,255,0,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,4,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,0,0,0,0,0,0,0,0,253,255,255,255,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,3,0,0,0,255,255,255,255,255,255,255,255,4,0,0,0,4,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,6,0,0,0,0,0,0,255,255,0,1,0,0,1,255,255,1,255,255,1,1,1,0,254,254,0,2,0,0,2,255,254,1,254,254,255,2,255,254,1,2,1,255,2,1,2,254,254,2,254,254,2,2,2,0,253,253,0,3,0,0,3,255,253,1,253,253,255,3,255,253,1,3,1,255,3,1,3,254,253,2,253,253,254,3,254,253,2,3,2,254,3,2,3,0,252,252,0,4,0,0,4,255,252,1,252,252,255,4,255,4,1,255,4,1,4,253,253,253,3,3,3,254,252,252,254,4,254,252,2,254,4,2,4,253,252,3,252,4,253,251,0,252,3,253,4,3,4,255,251,251,255,251,1,255,5,254,251,2,251,5,254,5,2,252,252,252,4,253,251,251,253,251,3,3,5,250,0,0,6,250,255,250,1,1,6,2,250,250,2,2,6,251,252,5,4,4,5,250,253,6,3,249,0,255,249,5,251,249,1,255,7,4,250,6,4,254,249,249,2,253,249,7,253,3,7,6,251,0,248,255,248,249,252,248,1,4,7,2,248,254,8,6,6,248,3,5,249,251,7,8,252,0,247,247,255,1,9,7,250,249,6,251,248,251,8,247,3,9,252,7,249,8,250,6,8,10,1,246,2,9,251,10,253,248,249,246,252,6,247,245,0,11,1,245,254,254,11,7,247,249,9,10,6,252,11,8,247,8,9,5,11,7,246,12,253,11,6,247,247,8,10,5,12,245,7,13,2,6,244,10,9,245,8,249,12,0,14,14,254,247,11,250,13,242,252,251,242,5,14,241,255,242,250,3,241,11,245,249,14,251,15,8,242,15,6,3,16,7,241,240,5,0,17,240,250,246,14,240,7,12,13,240,8,239,6,238,3,249,17,15,11,16,10,2,237,3,237,245,240,238,8,237,250,2,236,239,245,246,238,8,19,235,255,236,7,252,21,21,5,15,16,2,234,246,236,234,5,20,245,249,234,244,20,23,251,13,236,24,254,241,19,245,22,16,19,23,246,238,238,247,232,24,246,253,26,233,13,238,236,17,21,252,27,27,6,1,228,245,26,239,233,7,28,11,229,29,5,233,237,228,245,235,22,226,7,239,26,229,16,13,29,19,230,10,225,242,226,20,229,227,18,240,225,228,234,21,226,231,28,26,227,25,224,224,224,240,124,38,0,56,67,38,0,16,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,232,10,38,0,56,67,38,0,16,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,232,227,37,0,232,183,37,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,152,152,37,0,152,96,37,0,20,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,3,13,1,3,1,2,127,1,0,0,159,34,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,6,5,8,4,3,1,2,0,2,3,4,5,6,7,1,8,0,0,0,0,0,0,0,2,2,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,5,1,2,0,0,0,0,0,0,0,0,0,0,0,0,1,5,1,1,1,1,2,0,0,0,0,0,0,0,0,0,3,1,1,1,1,1,1,1,2,0,0,0,0,0,0,1,2,3,0,4,17,5,18,33,49,65,6,19,81,97,7,34,113,20,50,129,145,161,8,35,66,177,193,21,82,209,240,36,51,98,114,130,9,10,22,23,24,25,26,37,38,39,40,41,42,52,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,225,226,227,228,229,230,231,232,233,234,241,242,243,244,245,246,247,248,249,250,0,1,2,3,17,4,5,33,49,6,18,65,81,7,97,113,19,34,50,129,8,20,66,145,161,177,193,9,35,51,82,240,21,98,114,209,10,22,36,52,225,37,241,23,24,25,26,38,39,40,41,42,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,130,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,226,227,228,229,230,231,232,233,234,242,243,244,245,246,247,248,249,250,0,0,0,0,0,2,1,3,3,2,4,3,5,5,4,4,0,0,1,125,0,2,1,2,4,4,3,4,7,5,4,4,0,1,2,119,112,138,32,0,112,0,0,0,160,122,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,132,32,0,112,0,0,0,160,122,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,7,0,0,238,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,168,35,0,40,199,34,0,4,0,0,0,84,65,82,86,224,6,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,224,113,33,0,40,199,34,0,4,0,0,0,84,65,82,86,224,6,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,128,249,32,0,88,150,32,0,32,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,224,58,32,0,88,150,32,0,32,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,144,33,40,0,136,192,39,0,48,0,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,152,92,39,0,136,192,39,0,48,0,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,248,14,39,0,112,27,156,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,160,135,38,0,112,27,156,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,136,76,38,0,112,27,156,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,208,21,38,0,112,27,156,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,112,235,37,0,112,27,156,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,88,190,37,0,112,27,156,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,152,157,37,0,112,27,156,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,168,108,37,0,112,27,156,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,200,44,37,0,112,27,156,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,248,5,37,0,112,27,156,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,128,219,36,0,112,27,156,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,33,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,184,34,0,112,0,0,0,232,26,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,62,63,152,108,36,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,36,32,0,224,11,40,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,166,39,0,32,70,39,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,126,32,0,112,0,0,0,232,30,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,110,100,0,0,0,0,0,168,7,38,0,136,225,37,0,48,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,166,39,0,32,70,39,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,36,0,112,0,0,0,208,114,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,63,38,0,112,0,0,0,176,31,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,176,0,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,136,119,35,0,112,0,0,0,160,117,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,161,33,0,112,0,0,0,208,165,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,1,0,136,88,1,0,0,250,0,0,128,187,0,0,68,172,0,0,0,125,0,0,192,93,0,0,34,86,0,0,128,62,0,0,224,46,0,0,17,43,0,0,64,31,0,0,182,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,237,32,0,1,0,0,0,200,230,32,0,2,0,0,0,56,224,32,0,3,0,0,0,8,217,32,0,4,0,0,0,16,208,32,0,5,0,0,0,176,199,32,0,6,0,0,0,144,173,32,0,7,0,0,0,232,159,32,0,8,0,0,0,64,153,32,0,9,0,0,0,184,145,32,0,10,0,0,0,136,138,32,0,11,0,0,0,144,132,32,0,12,0,0,0,192,126,32,0,13,0,0,0,200,120,32,0,14,0,0,0,32,116,32,0,15,0,0,0,40,106,32,0,157,255,255,255,0,0,0,0,136,68,32,0,0,62,32,0,100,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,160,54,32,0,40,48,32,0,188,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,254,1,2,0,0,0,0,128,81,32,0,112,0,0,0,232,33,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,6,0,3,0,7,0,4,0,28,0,5,0,29,0,5,0,5,0,6,0,4,0,6,0,123,0,7,0,124,0,7,0,35,0,8,0,34,0,8,0,250,0,8,0,251,0,8,0,254,0,8,0,255,0,8,0,31,0,14,0,30,0,14,0,29,0,14,0,28,0,14,0,27,0,14,0,26,0,14,0,25,0,14,0,24,0,14,0,23,0,14,0,22,0,14,0,21,0,14,0,20,0,14,0,19,0,14,0,18,0,14,0,17,0,14,0,16,0,14,0,24,0,15,0,23,0,15,0,22,0,15,0,21,0,15,0,20,0,15,0,19,0,15,0,18,0,15,0,17,0,15,0,16,0,15,0,2,0,3,0,6,0,5,0,121,0,7,0,39,0,8,0,32,0,8,0,22,0,13,0,21,0,13,0,31,0,15,0,30,0,15,0,29,0,15,0,28,0,15,0,27,0,15,0,26,0,15,0,25,0,15,0,19,0,16,0,18,0,16,0,17,0,16,0,16,0,16,0,5,0,5,0,7,0,7,0,252,0,8,0,12,0,10,0,20,0,13,0,7,0,5,0,38,0,8,0,28,0,12,0,19,0,13,0,6,0,6,0,253,0,8,0,18,0,12,0,7,0,6,0,4,0,9,0,18,0,13,0,6,0,7,0,30,0,12,0,20,0,16,0,4,0,7,0,21,0,12,0,5,0,7,0,17,0,12,0,120,0,7,0,17,0,13,0,122,0,7,0,16,0,13,0,33,0,8,0,26,0,16,0,37,0,8,0,25,0,16,0,36,0,8,0,24,0,16,0,5,0,9,0,23,0,16,0,7,0,9,0,22,0,16,0,13,0,10,0,21,0,16,0,31,0,12,0,26,0,12,0,25,0,12,0,23,0,12,0,22,0,12,0,31,0,13,0,30,0,13,0,29,0,13,0,28,0,13,0,27,0,13,0,31,0,16,0,30,0,16,0,29,0,16,0,28,0,16,0,27,0,16,0,1,0,6,0,6,0,4,0,0,0,0,0,0,0,0,0,0,68,34,0,1,0,0,0,16,162,33,0,2,0,0,0,72,37,33,0,3,0,0,0,120,185], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+785550);
/* memory initializer */ allocate([32,0,4,0,0,0,56,93,32,0,5,0,0,0,216,66,40,0,156,255,255,255,128,234,39,0,156,255,255,255,128,234,39,0,157,255,255,255,0,0,0,0,40,93,32,0,168,66,40,0,176,55,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,17,0,0,0,0,0,0,0,88,234,39,0,80,128,39,0,116,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,208,44,39,0,120,229,38,0,164,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,112,159,38,0,240,99,38,0,168,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,136,45,38,0,168,250,37,0,112,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,224,207,37,0,120,170,37,0,120,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,48,134,37,0,64,68,37,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,48,134,37,0,136,21,37,0,40,237,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,48,134,37,0,32,201,36,0,216,170,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,48,134,37,0,216,143,36,0,152,116,36,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,48,134,37,0,200,89,36,0,200,63,36,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,48,134,37,0,192,37,36,0,80,235,35,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,200,201,35,0,160,177,35,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,232,155,35,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,104,134,35,0,24,112,35,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,96,185,32,0,112,0,0,0,192,36,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,2,0,4,0,4,0,5,0,5,0,6,0,7,0,38,0,8,0,33,0,8,0,10,0,10,0,29,0,12,0,24,0,12,0,19,0,12,0,16,0,12,0,26,0,13,0,25,0,13,0,24,0,13,0,23,0,13,0,31,0,14,0,30,0,14,0,29,0,14,0,28,0,14,0,27,0,14,0,26,0,14,0,25,0,14,0,24,0,14,0,23,0,14,0,22,0,14,0,21,0,14,0,20,0,14,0,19,0,14,0,18,0,14,0,17,0,14,0,16,0,14,0,24,0,15,0,23,0,15,0,22,0,15,0,21,0,15,0,20,0,15,0,19,0,15,0,18,0,15,0,17,0,15,0,16,0,15,0,3,0,3,0,6,0,6,0,37,0,8,0,12,0,10,0,27,0,12,0,22,0,13,0,21,0,13,0,31,0,15,0,30,0,15,0,29,0,15,0,28,0,15,0,27,0,15,0,26,0,15,0,25,0,15,0,19,0,16,0,18,0,16,0,17,0,16,0,16,0,16,0,5,0,4,0,4,0,7,0,11,0,10,0,20,0,12,0,20,0,13,0,7,0,5,0,36,0,8,0,28,0,12,0,19,0,13,0,6,0,5,0,15,0,10,0,18,0,12,0,7,0,6,0,9,0,10,0,18,0,13,0,5,0,6,0,30,0,12,0,20,0,16,0,4,0,6,0,21,0,12,0,7,0,7,0,17,0,12,0,5,0,7,0,17,0,13,0,39,0,8,0,16,0,13,0,35,0,8,0,26,0,16,0,34,0,8,0,25,0,16,0,32,0,8,0,24,0,16,0,14,0,10,0,23,0,16,0,13,0,10,0,22,0,16,0,8,0,10,0,21,0,16,0,31,0,12,0,26,0,12,0,25,0,12,0,23,0,12,0,22,0,12,0,31,0,13,0,30,0,13,0,29,0,13,0,28,0,13,0,27,0,13,0,31,0,16,0,30,0,16,0,29,0,16,0,28,0,16,0,27,0,16,0,1,0,6,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,0,40,93,32,0,168,66,40,0,176,55,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,17,0,0,0,0,0,0,0,88,234,39,0,80,128,39,0,116,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,208,44,39,0,120,229,38,0,164,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,112,159,38,0,240,99,38,0,168,55,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,48,134,37,0,64,68,37,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,48,134,37,0,136,21,37,0,40,237,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,48,134,37,0,32,201,36,0,216,170,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,48,134,37,0,216,143,36,0,152,116,36,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,48,134,37,0,200,89,36,0,200,63,36,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,48,134,37,0,192,37,36,0,80,235,35,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,200,201,35,0,160,177,35,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,232,155,35,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,104,134,35,0,24,112,35,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,1,2,3,4,5,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,255,255,255,255,152,190,34,0,112,0,0,0,176,43,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,204,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,195,35,0,112,216,34,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,136,23,34,0,160,124,33,0,8,0,0,0,1,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,16,3,33,0,0,158,32,0,4,0,0,0,1,0,0,0,64,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,176,66,32,0,112,42,40,0,12,0,0,0,4,0,0,0,31,133,235,81,184,30,213,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,204,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,3,0,0,0,0,0,0,0,0,0,0,40,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,204,35,0,112,0,0,0,112,47,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,172,0,0,128,187,0,0,168,147,0,0,0,125,0,0,63,170,153,67,255,255,127,67,56,62,85,67,153,160,49,67,203,245,19,67,240,126,246,66,135,83,205,66,103,8,171,66,144,119,142,66,54,88,109,66,21,180,69,66,227,174,36,66,138,45,9,66,118,136,228,65,22,93,190,65,184,145,158,65,200,21,132,65,116,12,92,65,216,75,55,65,168,174,24,65,220,92,254,64,22,225,211,64,199,125,176,64,140,3,147,64,94,235,116,64,92,3,76,64,97,240,41,64,78,142,13,64,157,211,235,63,99,112,196,63,65,161,163,63,240,76,136,63,73,18,99,63,103,37,61,63,24,142,29,63,133,61,3,63,43,164,218,62,188,31,182,62,171,180,151,62,99,188,124,62,44,134,82,62,206,92,47,62,215,18,18,62,91,90,243,61,83,181,202,61,35,218,168,61,137,166,140,61,127,81,106,61,194,46,67,61,88,149,34,61,198,109,7,61,128,158,225,60,183,239,187,60,33,140,156,60,164,102,130,60,48,62,89,60,139,245,52,60,72,188,22,60,150,30,251,59,124,45,209,59,175,61,174,59,172,35,145,59,234,203,113,59,110,105,73,59,173,197,39,59,64,192,11,59,217,209,232,58,48,239,193,58,38,139,161,58,10,144,134,58,26,45,96,58,3,188,58,58,209,139,27,58,35,145,1,58,128,218,215,57,67,205,179,57,124,197,149,57,110,131,121,57,255,214,79,57,102,32,45,57,9,54,16,57,5,64,240,56,169,31,200,56,251,178,166,56,111,219,138,56,166,84,103,56,168,177,64,56,166,130,32,56,183,179,5,56,13,190,222,55,68,138,185,55,35,141,154,55,254,188,128,55,19,121,86,55,221,166,50,55,66,208,20,55,228,234,247,54,177,130,206,54,239,4,172,54,234,73,143,54,166,182,110,54,253,215,70,54,10,162,37,54,20,248,9,54,226,217,229,53,39,118,191,53,215,123,159,53,205,216,132,53,89,81,93,53,122,90,56,53,22,144,25,53,106,212,255,52,234,25,213,52,91,130,177,52,154,220,147,52,248,84,118,52,145,48,77,52,72,235,42,52,78,95,14,52,205,47,237,51,108,146,197,51,217,146,164,51,46,22,137,51,140,97,100,51,172,60,62,51,184,118,30,51,75,255,3,51,253,230,219,50,165,44,183,50,42,194,86,84,192,227,50,84,249,2,21,84,98,63,248,83,18,201,206,83,143,63,172,83,191,122,143,83,1,8,111,83,193,27,71,83,125,218,37,83,25,39,10,83,56,40,230,82,103,183,191,82,50,178,159,82,20,6,133,82,198,156,93,82,78,153,56,82,108,196,25,82,205,21,0,82,139,98,213,81,218,190,177,81,255,14,148,81,237,168,118,81,129,118,77,81,137,37,43,81,212,143,14,81,164,128,237,80,194,213,197,80,240,202,164,80,231,68,137,80,98,175,100,80,130,125,62,80,185,172,30,80,71,44,4,80,238,49,220,79,16,107,183,79,169,200,152,79,45,136,126,79,43,5,84,79,213,155,48,79,149,28,19,79,18,21,245,78,26,38,204,78,82,13,170,78,106,166,141,78,199,251,107,78,216,145,68,78,31,189,35,78,39,100,8,78,245,56,227,77,158,69,189,77,237,168,157,77,223,83,131,77,104,201,90,77,193,62,54,77,130,206,23,77,111,231,252,76,7,170,210,76,172,122,175,76,183,43,146,76,205,131,115,76,217,215,74,76,229,246,40,76,125,190,12,76,103,121,234,75,0,80,195,75,9,177,162,75,215,132,135,75,238,196,97,75,185,15,60,75,203,166,28,75,218,124,2,75,48,99,217,74,93,20,181,74,244,213,150,74,91,73,123,74,28,81,81,74,92,91,46,74,100,60,17,74,24,245,241,73,188,139,201,73,64,226,167,73,13,216,139,73,128,249,104,73,55,16,66,73,169,166,33,73,244,166,6,73,71,83,224,72,208,219,186,72,79,166,155,72,52,167,129,72,67,255,87,72,226,235,51,72,254,222,21,72,237,173,249,71,101,250,207,71,227,61,173,71,153,78,144,71,240,104,112,71,191,65,72,71,96,207,38,71,22,243,10,71,13,124,231,70,122,210,192,70,253,157,160,70,125,202,133,70,254,227,94,70,223,169,57,70,118,167,26,70,236,210,0,70,156,157,214,69,76,197,178,69,156,233,148,69,32,21,120,69,224,165,78,69,61,34,44,69,83,98,15,69,81,223,238,68,221,249,198,68,66,190,165,68,149,15,138,68,11,1,102,68,197,150,63,68,3,151,31,68,111,239,4,68,14,119,221,67,226,121,184,67,106,146,222,66,0,0,128,71,171,170,170,70,205,204,76,70,37,73,18,70,57,142,227,69,137,136,136,69,8,33,4,69,32,8,130,68,4,2,1,68,128,128,128,67,33,64,0,67,13,32,128,66,249,15,0,66,253,7,128,65,25,4,0,65,163,1,128,64,163,1,0,64,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,8,0,0,0,0,0,0,0,1,0,2,3,1,3,4,5,4,6,2,2,5,7,3,3,6,7,6,6,7,5,5,5,6,5,2,3,6,5,3,2,0,1,1,1,0,0,0,0,3,3,1,2,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,2,1,1,1,1,1,1,0,1,2,3,1,1,1,1,3,0,0,0,0,0,0,1,2,4,5,6,7,9,10,11,12,13,14,15,16,16,8,3,2,2,3,5,7,8,10,12,14,14,14,14,11,9,6,4,2,0,0,0,0,0,0,68,172,0,0,128,187,0,0,168,147,0,0,0,125,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,2,3,4,5,5,6,7,8,9,10,11,12,13,14,15,16,17,18,38,39,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,40,38,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,62,63,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,107,123,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,6,7,8,9,0,1,10,10,10,10,10,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,9,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,11,11,3,4,10,11,12,13,14,26,15,27,16,0,1,5,6,7,8,9,10,11,17,12,18,19,20,21,22,23,24,25,28,26,27,28,29,30,29,30,31,32,33,34,35,36,25,37,26,27,28,29,30,31,20,21,22,23,14,15,16,17,11,7,4,3,5,12,13,18,19,20,21,24,25,26,27,32,33,34,35,36,37,38,39,38,39,40,41,42,43,44,45,46,31,32,47,33,34,35,36,37,38,39,40,41,13,14,42,15,16,17,18,2,19,3,4,5,43,44,48,49,45,46,47,48,49,50,51,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,49,63,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,4,5,6,7,0,0,11,11,10,10,10,10,10,9,10,9,10,12,12,11,11,11,11,11,11,11,10,11,10,10,10,10,10,10,10,10,9,10,10,10,10,10,9,9,9,9,9,9,9,9,8,9,8,8,8,8,8,8,7,7,7,7,6,6,6,6,5,4,3,2,3,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,10,10,9,10,10,10,10,10,10,10,10,10,11,11,10,11,11,11,11,12,11,12,12,12,10,10,9,9,10,10,10,10,10,10,10,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,0,0,0,1,2,8,9,3,4,5,6,7,10,11,12,13,10,11,12,13,14,10,11,12,13,14,10,11,12,8,9,6,4,3,5,7,10,11,13,14,15,15,16,17,18,15,19,16,17,18,19,14,15,16,17,8,9,10,11,12,18,19,13,14,15,0,1,2,3,4,5,6,7,8,8,9,10,11,12,9,10,11,12,13,14,15,16,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,17,18,19,20,21,22,23,13,14,15,16,17,9,10,11,12,13,14,15,2,3,0,0,10,10,10,9,9,10,10,10,10,10,9,9,9,9,8,8,8,8,8,7,7,7,7,7,6,6,6,5,5,4,3,2,3,4,5,5,6,6,6,7,7,7,7,8,7,8,8,8,8,9,9,9,9,10,10,10,10,10,9,9,10,10,10,9,9,8,8,8,8,8,8,8,7,7,7,7,7,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,8,9,9,0,0,0,1,2,3,4,5,4,3,4,5,5,6,4,5,4,3,5,6,7,7,6,7,8,9,5,6,7,4,5,6,7,0,1,2,3,4,4,5,4,5,6,5,6,7,8,9,10,11,12,13,14,15,7,8,9,6,7,5,6,7,2,3,0,0,9,9,9,9,8,8,7,6,6,6,5,5,4,4,3,2,3,4,4,5,6,6,6,6,7,8,8,9,9,9,9,8,8,7,7,7,6,6,5,5,5,4,4,4,4,4,4,4,4,4,4,4,5,5,5,6,6,7,7,7,8,8,0,0,0,1,2,2,2,2,3,3,4,5,3,3,3,2,3,0,1,2,2,3,3,4,5,6,7,4,5,3,2,3,0,0,7,7,6,5,4,3,3,2,3,3,4,5,6,7,7,6,6,5,4,4,3,3,3,3,3,4,4,5,6,6,0,0,64,96,81,80,95,66,65,79,78,49,48,63,32,113,112,98,97,111,110,83,82,94,93,67,77,51,50,62,61,34,33,47,46,17,16,31,128,114,127,126,99,109,68,76,35,45,18,30,0,15,130,129,143,142,115,125,100,108,84,92,52,60,36,44,19,29,2,1,14,131,141,116,124,20,28,3,13,132,140,4,12,0,0,0,0,0,0,0,15,29,28,27,26,25,24,23,22,21,20,19,18,35,34,33,32,31,30,29,28,27,26,25,24,23,22,21,20,19,18,17,16,15,14,13,25,24,23,22,21,20,19,18,17,16,15,14,13,12,23,22,21,20,19,18,17,16,15,14,13,12,11,10,9,8,7,6,5,9,8,7,6,5,4,3,2,3,2,1,0,0,0,0,0,0,0,0,4,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,0,0,0,0,0,0,0,48,65,64,49,63,32,47,80,79,50,62,33,16,82,81,95,94,66,78,34,46,17,31,30,97,96,111,67,77,51,61,35,45,18,1,0,15,98,110,83,93,19,29,2,14,99,109,3,13,0,0,0,0,0,0,0,7,13,12,11,10,9,8,15,14,13,12,11,10,19,18,17,16,15,14,13,12,11,10,9,17,16,15,14,13,12,11,10,9,8,7,6,5,9,8,7,6,5,4,3,2,3,2,1,0,0,0,0,0,0,0,0,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,9,9,9,9,0,0,0,0,0,0,0,2,3,15,4,0,5,12,18,13,6,7,19,21,20,8,9,14,21,15,10,3,11,16,12,1,13,16,22,17,14,18,15,16,22,19,23,17,8,18,24,20,19,20,23,21,15,22,25,23,16,17,26,24,27,18,28,21,9,22,29,25,10,7,11,26,30,23,12,24,31,19,32,27,33,20,17,24,34,25,18,26,25,26,27,27,35,28,13,29,36,28,28,30,31,29,19,30,37,31,20,2,21,21,22,4,23,32,38,33,24,22,39,29,40,25,26,34,41,35,27,3,28,23,29,5,2,3,15,4,0,5,12,13,14,6,7,15,30,16,16,8,17,18,19,9,3,10,17,11,1,12,20,21,22,13,23,18,14,19,24,25,20,15,16,26,27,21,17,22,28,14,29,30,31,15,18,32,31,33,19,34,18,19,20,35,32,21,15,22,33,36,23,24,25,37,20,38,34,39,21,16,40,41,42,17,43,23,26,24,44,45,27,28,25,46,47,26,29,27,48,18,49,50,51,19,2,20,21,22,4,23,52,53,54,24,22,55,35,56,25,26,57,58,59,27,3,28,23,29,5,0,0,0,0,0,0,12,11,10,11,13,11,9,8,9,11,11,8,7,8,11,11,9,8,9,11,12,11,10,11,13,11,9,8,9,11,9,6,6,7,9,8,6,4,6,8,9,6,6,7,9,11,9,8,9,11,10,8,7,8,10,8,6,4,6,8,7,4,3,4,7,8,6,4,6,8,10,8,7,8,10,11,9,8,9,11,9,6,6,6,9,8,6,4,6,8,9,7,6,6,9,11,9,8,9,11,13,11,10,11,12,11,9,8,9,11,10,8,7,8,11,11,9,8,9,11,13,11,10,11,12,11,10,9,10,12,10,8,8,8,10,10,8,7,8,9,10,8,8,8,10,11,10,9,10,12,10,8,8,8,10,8,6,5,6,8,8,6,5,5,8,8,6,5,6,8,10,8,8,8,10,9,8,7,8,9,8,5,5,5,8,7,5,4,5,7,8,5,5,5,8,9,8,7,8,9,10,8,8,8,10,8,6,5,6,8,8,5,5,6,8,8,6,5,6,8,10,8,8,8,10,12,10,10,10,11,10,8,8,8,10,9,8,7,8,10,10,8,8,8,10,12,10,9,10,11,0,0,0,0,0,0,1,1,2,3,4,5,6,7,3,4,5,1,1,1,1,1,1,0,1,0,0,0,0,0,6,4,4,3,3,3,3,3,4,4,4,5,7,8,9,10,11,12,12,0,0,0,0,0,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,0,0,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,0,0,0,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,0,0,0,6,5,4,5,6,5,4,3,4,5,4,3,2,3,4,5,4,3,4,5,6,5,4,5,6,5,4,3,4,5,4,3,2,3,4,3,2,1,2,3,4,3,2,3,4,5,4,3,4,5,4,3,2,3,4,3,2,1,2,3,2,1,0,1,2,3,2,1,2,3,4,3,2,3,4,5,4,3,4,5,4,3,2,3,4,3,2,1,2,3,4,3,2,3,4,5,4,3,4,5,6,5,4,5,6,5,4,3,4,5,4,3,2,3,4,5,4,3,4,5,6,5,4,5,6,0,0,0,0,3,4,4,5,6,5,6,7,8,7,8,9,10,7,8,9,10,7,8,9,6,7,5,6,4,3,3,4,3,4,5,6,7,5,4,5,5,7,8,9,10,11,11,12,13,11,12,13,9,10,11,12,7,8,9,5,6,7,1,2,3,4,5,13,0,0,0,0,0,0,0,15,14,14,13,13,13,12,12,12,12,11,11,11,11,10,10,10,10,9,9,9,8,8,7,7,6,5,4,4,3,3,3,3,3,4,5,5,6,7,8,8,9,9,10,10,10,11,11,11,12,12,12,12,13,13,13,14,14,14,15,15,15,15,15,12,0,0,0,0,0,0,0,3,4,5,4,5,6,5,6,7,8,9,7,8,9,10,7,8,9,10,7,8,9,10,6,7,5,4,5,6,6,7,10,8,5,6,7,9,7,8,9,11,11,12,13,11,12,13,11,12,13,7,8,9,6,7,3,4,5,0,1,2,3,4,5,12,12,12,11,11,11,10,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,5,4,4,5,4,4,10,4,3,3,3,4,5,6,6,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,13,13,13,14,14,14,14,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,15,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,1,0,0,0,11,0,0,0,4,0,0,0,28,0,0,0,19,0,0,0,9,0,0,0,62,0,0,0,50,0,0,0,37,0,0,0,23,0,0,0,8,0,0,0,120,0,0,0,103,0,0,0,85,0,0,0,66,0,0,0,46,0,0,0,25,0,0,0,3,0,0,0,236,0,0,0,212,0,0,0,187,0,0,0,161,0,0,0,134,0,0,0,106,0,0,0,77,0,0,0,47,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,12,0,0,0,29,0,0,0,8,0,0,0,44,0,0,0,8,0,0,0,91,0,0,0,36,0,0,0,226,0,0,0,148,0,0,0,57,0,0,0,208,1,0,0,88,1,0,0,208,0,0,0,55,0,0,0,140,3,0,0,206,2,0,0,252,1,0,0,21,1,0,0,24,0,0,0,4,7,0,0,216,5,0,0,147,4,0,0,52,3,0,0,186,1,0,0,36,0,0,0,113,14,0,0,160,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,29,0,0,0,58,0,0,0,2,0,0,0,46,0,0,0,182,0,0,0,17,0,0,0,53,1,0,0,23,0,0,0,171,2,0,0,228,0,0,0,180,6,0,0,12,4,0,0,220,0,0,0,19,13,0,0,159,8,0,0,109,3,0,0,105,29,0,0,126,22,0,0,150,14,0,0,154,5,0,0,114,59,0,0,5,48,0,0,57,35,0,0,243,20,0,0,23,5,0,0,136,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,11,0,0,0,8,0,0,0,2,0,0,0,4,0,0,0,50,0,0,0,232,0,0,0,249,2,0,0,46,0,0,0,69,4,0,0,240,14,0,0,212,7,0,0,136,30,0,0,148,18,0,0,112,3,0,0,131,48,0,0,34,25,0,0,143,124,0,0,248,89,0,0,118,48,0,0,12,255,0,0,166,196,0,0,24,128,0,0,29,48,0,0,86,211,1,0,73,104,1,0,96,237,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,44,0,0,0,46,0,0,0,50,0,0,0,100,0,0,0,76,1,0,0,69,4,0,0,115,12,0,0,184,0,0,0,168,15,0,0,124,55,0,0,4,22,0,0,152,104,0,0,8,44,0,0,139,220,0,0,173,117,0,0,60,242,1,0,52,76,1,0,170,124,0,0,182,123,3,0,92,64,2,0,116,192,0,0,145,240,6,0,231,195,4,0,48,44,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,8,0,0,0,182,0,0,0,232,0,0,0,76,1,0,0,152,2,0,0,221,6,0,0,80,19,0,0,8,52,0,0,176,3,0,0,44,59,0,0,48,209,0,0,200,57,0,0,208,101,1,0,91,66,0,0,8,184,2,0,68,170,0,0,120,246,5,0,34,115,2,0,216,238,13,0,52,47,8,0,168,239,0,0,57,224,23,0,32,164,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,19,0,0,0,91,0,0,0,17,0,0,0,249,2,0,0,69,4,0,0,221,6,0,0,186,13,0,0,10,33,0,0,18,85,0,0,194,216,0,0,238,19,0,0,30,229,0,0,230,30,3,0,182,132,0,0,17,199,4,0,25,127,15,0,93,41,8,0,213,31,30,0,247,146,16,0,207,129,62,0,3,177,38,0,171,160,7,0,228,128,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,9,0,0,0,36,0,0,0,53,1,0,0,46,0,0,0,115,12,0,0,80,19,0,0,10,33,0,0,20,66,0,0,38,151,0,0,232,111,1,0,214,131,3,0,244,104,0,0,218,135,3,0,144,12,12,0,161,211,0,0,186,82,16,0,23,124,56,0,236,155,22,0,227,46,103,0,178,176,37,0,181,97,204,0,96,2,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,62,0,0,0,226,0,0,0,23,0,0,0,69,4,0,0,184,0,0,0,8,52,0,0,18,85,0,0,38,151,0,0,76,46,1,0,52,158,2,0,10,34,6,0,254,138,14,0,216,18,2,0,104,31,14,0,9,243,46,0,195,69,127,0,218,193,55,0,198,93,206,0,169,140,53,0,91,61,91,1,16,159,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,50,0,0,0,148,0,0,0,171,2,0,0,240,14,0,0,168,15,0,0,176,3,0,0,194,216,0,0,232,111,1,0,52,158,2,0,104,60,5,0,114,94,11,0,112,233,25,0,72,252,59,0,176,27,10,0,185,14,57,0,124,84,184,0,86,22,240,1,28,116,190,0,197,0,244,2,32,62,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,37,0,0,0,57,0,0,0,228,0,0,0,212,7,0,0,124,55,0,0,44,59,0,0,238,19,0,0,214,131,3,0,10,34,6,0,114,94,11,0,228,188,22,0,84,166,48,0,156,162,108,0,76,190,246,0,5,205,47,0,129,33,232,0,215,55,216,2,243,171,150,7,184,172,138,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,23,0,0,0,208,1,0,0,180,6,0,0,136,30,0,0,4,22,0,0,48,209,0,0,30,229,0,0,244,104,0,0,254,138,14,0,112,233,25,0,84,166,48,0,168,76,97,0,68,239,205,0,144,173,196,1,149,122,244,3,22,156,220,0,237,211,180,3,224,127,75,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,8,0,0,0,88,1,0,0,12,4,0,0,148,18,0,0,152,104,0,0,200,57,0,0,230,30,3,0,218,135,3,0,216,18,2,0,72,252,59,0,156,162,108,0,68,239,205,0,136,222,155,1,24,140,96,3,173,6,85,7,195,162,49,0,176,118,230,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,0,0,0,208,0,0,0,220,0,0,0,112,3,0,0,8,44,0,0,208,101,1,0,182,132,0,0,144,12,12,0,104,31,14,0,176,27,10,0,76,190,246,0,144,173,196,1,24,140,96,3,48,24,193,6,221,30,22,14,160,193,71,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,103,0,0,0,55,0,0,0,19,13,0,0,131,48,0,0,139,220,0,0,91,66,0,0,17,199,4,0,161,211,0,0,9,243,46,0,185,14,57,0,5,205,47,0,149,122,244,3,173,6,85,7,221,30,22,14,0,0,0,0,0,0,0,0,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,0,0,2,3,4,4,5,5,6,6,6,7,7,7,7,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,0,0,0,0,2,4,5,6,6,7,7,8,8,9,9,9,10,10,10,10,11,11,11,11,11,12,12,12,12,12,12,13,13,0,0,0,0,0,3,4,6,7,7,8,9,9,10,10,11,11,12,12,12,13,13,13,14,14,14,14,15,15,15,15,15,16,0,0,0,0,0,0,3,5,6,7,8,9,10,11,11,12,13,13,14,14,14,15,15,16,16,16,17,17,17,17,18,18,18,0,0,0,0,0,0,0,3,5,7,8,9,10,11,12,13,13,14,15,15,16,16,17,17,18,18,18,19,19,19,20,20,20,0,0,0,0,0,0,0,0,3,6,7,9,10,11,12,13,14,15,15,16,17,17,18,18,19,19,20,20,21,21,21,22,22,0,0,0,0,0,0,0,0,0,4,6,8,9,11,12,13,14,15,16,17,17,18,19,19,20,21,21,22,22,23,23,23,24,0,0,0,0,0,0,0,0,0,0,4,6,8,10,11,13,14,15,16,17,18,19,19,20,21,21,22,23,23,24,24,25,25,0,0,0,0,0,0,0,0,0,0,0,4,7,9,10,12,13,15,16,17,18,19,20,21,21,22,23,24,24,25,25,26,26,0,0,0,0,0,0,0,0,0,0,0,0,4,7,9,11,13,14,15,17,18,19,20,21,22,23,23,24,25,26,26,27,27], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+795790);
/* memory initializer */ allocate([4,7,9,11,13,15,16,17,19,20,21,22,23,24,25,25,26,27,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,10,12,14,15,17,18,19,21,22,23,24,25,26,27,27,28,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,10,12,14,16,17,19,20,21,23,24,25,26,27,28,28,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,8,10,12,14,16,18,19,21,22,23,25,26,27,28,29,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,8,10,13,15,17,18,20,21,23,24,25,27,28,29,30,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,6,0,0,0,10,0,0,0,15,0,0,0,21,0,0,0,28,0,0,0,36,0,0,0,45,0,0,0,55,0,0,0,66,0,0,0,78,0,0,0,91,0,0,0,105,0,0,0,120,0,0,0,136,0,0,0,153,0,0,0,171,0,0,0,190,0,0,0,210,0,0,0,231,0,0,0,253,0,0,0,20,1,0,0,44,1,0,0,69,1,0,0,95,1,0,0,122,1,0,0,150,1,0,0,179,1,0,0,209,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,10,0,0,0,20,0,0,0,35,0,0,0,56,0,0,0,84,0,0,0,120,0,0,0,165,0,0,0,220,0,0,0,30,1,0,0,108,1,0,0,199,1,0,0,48,2,0,0,168,2,0,0,48,3,0,0,201,3,0,0,116,4,0,0,50,5,0,0,4,6,0,0,235,6,0,0,232,7,0,0,252,8,0,0,40,10,0,0,109,11,0,0,204,12,0,0,70,14,0,0,220,15,0,0,143,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,15,0,0,0,35,0,0,0,70,0,0,0,126,0,0,0,210,0,0,0,74,1,0,0,239,1,0,0,203,2,0,0,233,3,0,0,85,5,0,0,28,7,0,0,76,9,0,0,244,11,0,0,36,15,0,0,237,18,0,0,97,23,0,0,147,28,0,0,151,34,0,0,130,41,0,0,106,49,0,0,102,58,0,0,142,68,0,0,251,79,0,0,199,92,0,0,13,107,0,0,233,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,6,0,0,0,21,0,0,0,56,0,0,0,126,0,0,0,252,0,0,0,206,1,0,0,24,3,0,0,7,5,0,0,210,7,0,0,187,11,0,0,16,17,0,0,44,24,0,0,120,33,0,0,108,45,0,0,144,60,0,0,125,79,0,0,222,102,0,0,113,131,0,0,8,166,0,0,138,207,0,0,244,0,1,0,90,59,1,0,232,127,1,0,227,207,1,0,170,44,2,0,183,151,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,7,0,0,0,28,0,0,0,84,0,0,0,210,0,0,0,206,1,0,0,156,3,0,0,180,6,0,0,187,11,0,0,141,19,0,0,72,31,0,0,88,48,0,0,132,72,0,0,252,105,0,0,104,151,0,0,248,211,0,0,117,35,1,0,83,138,1,0,196,13,2,0,204,179,2,0,86,131,3,0,74,132,4,0,164,191,5,0,140,63,7,0,111,15,9,0,25,60,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,8,0,0,0,36,0,0,0,120,0,0,0,74,1,0,0,24,3,0,0,180,6,0,0,104,13,0,0,35,25,0,0,176,44,0,0,248,75,0,0,80,124,0,0,212,196,0,0,208,46,1,0,56,198,1,0,48,154,2,0,165,189,3,0,248,71,5,0,188,85,7,0,136,9,10,0,222,140,13,0,40,17,18,0,204,208,23,0,88,16,31,0,199,31,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,9,0,0,0,45,0,0,0,165,0,0,0,239,1,0,0,7,5,0,0,187,11,0,0,35,25,0,0,70,50,0,0,246,94,0,0,238,170,0,0,62,39,1,0,18,236,1,0,226,26,3,0,26,225,4,0,74,123,7,0,239,56,11,0,231,128,16,0,163,214,23,0,43,224,33,0,9,109,47,0,49,126,65,0,253,78,89,0,85,95,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,10,0,0,0,55,0,0,0,220,0,0,0,203,2,0,0,210,7,0,0,141,19,0,0,176,44,0,0,246,94,0,0,236,189,0,0,218,104,1,0,24,144,2,0,42,124,4,0,12,151,7,0,38,120,12,0,112,243,19,0,95,44,31,0,70,173,47,0,233,131,71,0,20,100,105,0,29,209,152,0,78,79,218,0,75,158,51,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,11,0,0,0,66,0,0,0,30,1,0,0,233,3,0,0,187,11,0,0,72,31,0,0,248,75,0,0,238,170,0,0,218,104,1,0,180,209,2,0,204,97,5,0,246,221,9,0,2,117,17,0,40,237,29,0,152,224,49,0,247,12,81,0,61,186,128,0,38,62,200,0,58,162,49,1,87,115,202,1,165,194,164,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,12,0,0,0,78,0,0,0,108,1,0,0,85,5,0,0,16,17,0,0,88,48,0,0,80,124,0,0,62,39,1,0,24,144,2,0,204,97,5,0,152,195,10,0,142,161,20,0,144,22,38,0,184,3,68,0,80,228,117,0,71,241,198,0,132,171,71,1,170,233,15,2,228,139,65,3,59,255,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,13,0,0,0,91,0,0,0,199,1,0,0,28,7,0,0,44,24,0,0,132,72,0,0,212,196,0,0,18,236,1,0,42,124,4,0,246,221,9,0,142,161,20,0,28,67,41,0,172,89,79,0,100,93,147,0,180,65,9,1,251,50,208,1,127,222,23,3,41,200,39,5,13,84,105,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,14,0,0,0,105,0,0,0,48,2,0,0,76,9,0,0,120,33,0,0,252,105,0,0,208,46,1,0,226,26,3,0,12,151,7,0,2,117,17,0,144,22,38,0,172,89,79,0,88,179,158,0,188,16,50,1,112,82,59,2,107,133,11,4,234,99,35,7,19,44,75,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,15,0,0,0,120,0,0,0,168,2,0,0,244,11,0,0,108,45,0,0,104,151,0,0,56,198,1,0,26,225,4,0,38,120,12,0,40,237,29,0,184,3,68,0,100,93,147,0,188,16,50,1,120,33,100,2,232,115,159,4,83,249,170,8,61,93,206,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,16,0,0,0,136,0,0,0,48,3,0,0,36,15,0,0,144,60,0,0,248,211,0,0,48,154,2,0,74,123,7,0,112,243,19,0,152,224,49,0,80,228,117,0,180,65,9,1,112,82,59,2,232,115,159,4,208,231,62,9,35,225,233,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,17,0,0,0,153,0,0,0,201,3,0,0,237,18,0,0,125,79,0,0,117,35,1,0,165,189,3,0,239,56,11,0,95,44,31,0,247,12,81,0,71,241,198,0,251,50,208,1,107,133,11,4,83,249,170,8,35,225,233,17,1,1,2,2,3,3,4,4,5,6,1,2,3,0,4,5,6,7,8,1,9,10,11,7,8,9,6,7,5,5,3,3,1,0,0,0,0,0,0,0,1,3,5,6,7,8,8,9,10,11,12,12,12,13,12,12,12,12,12,13,12,12,12,11,11,11,10,10,9,8,6,5,2,0,0,0,0,0,0,0,2,3,1,1,3,3,0,2,27,25,7,9,15,31,63,0,0,0,0,0,0,0,0,0,0,0,3,4,7,15,31,0,54,0,6,0,9,0,5,0,32,0,6,0,5,0,5,0,10,0,4,0,7,0,5,0,52,0,6,0,0,0,5,0,35,0,6,0,10,0,5,0,6,0,4,0,4,0,5,0,11,0,4,0,7,0,3,0,12,0,4,0,3,0,5,0,7,0,4,0,11,0,5,0,34,0,6,0,1,0,5,0,53,0,6,0,6,0,5,0,9,0,4,0,2,0,5,0,33,0,6,0,8,0,5,0,55,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,0,8,0,62,0,7,0,225,0,9,0,55,0,7,0,3,0,4,0,52,0,7,0,101,0,8,0,60,0,7,0,227,0,9,0,24,0,6,0,0,0,4,0,61,0,7,0,4,0,4,0,1,0,1,0,5,0,4,0,63,0,7,0,1,0,4,0,59,0,7,0,226,0,9,0,57,0,7,0,100,0,8,0,53,0,7,0,2,0,4,0,54,0,7,0,224,0,9,0,58,0,7,0,102,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,0,7,0,47,0,6,0,15,0,5,0,0,0,5,0,91,0,7,0,4,0,5,0,6,0,4,0,13,0,4,0,4,0,4,0,5,0,5,0,20,0,5,0,12,0,4,0,4,0,3,0,15,0,4,0,14,0,5,0,3,0,5,0,3,0,4,0,14,0,4,0,5,0,4,0,1,0,5,0,90,0,7,0,2,0,5,0,21,0,5,0,46,0,6,0,88,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,3,10,0,113,0,7,0,51,0,6,0,231,0,8,0,154,3,10,0,104,0,7,0,30,0,5,0,0,0,3,0,29,0,5,0,105,0,7,0,50,0,6,0,1,0,3,0,2,0,2,0,3,0,3,0,49,0,6,0,107,0,7,0,27,0,5,0,2,0,3,0,31,0,5,0,112,0,7,0,152,3,10,0,106,0,7,0,48,0,6,0,114,0,7,0,155,3,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,4,0,4,0,3,0,0,0,2,0,1,0,2,0,7,0,3,0,5,0,3,0,13,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,0,3,0,4,0,2,0,2,0,3,0,2,0,1,0,2,0,0,0,3,0,5,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,4,0,0,0,3,0,4,0,3,0,6,0,3,0,7,0,3,0,5,0,3,0,3,0,3,0,1,0,3,0,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,5,0,12,0,4,0,3,0,3,0,0,0,2,0,2,0,2,0,7,0,3,0,13,0,4,0,5,0,4,0,8,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,0,6,0,23,0,5,0,8,0,4,0,10,0,4,0,13,0,4,0,0,0,3,0,2,0,3,0,3,0,3,0,1,0,3,0,15,0,4,0,12,0,4,0,9,0,4,0,29,0,5,0,22,0,5,0,56,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,229,0,8,0,56,0,6,0,7,0,5,0,2,0,4,0,0,0,3,0,3,0,3,0,5,0,3,0,6,0,3,0,4,0,3,0,2,0,3,0,15,0,4,0,29,0,5,0,6,0,5,0,115,0,7,0,228,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,7,0,6,0,6,0,44,0,6,0,45,0,6,0,59,0,6,0,13,0,5,0,17,0,5,0,19,0,5,0,23,0,5,0,21,0,5,0,26,0,5,0,30,0,5,0,0,0,4,0,2,0,4,0,5,0,4,0,7,0,4,0,3,0,4,0,4,0,4,0,31,0,5,0,28,0,5,0,25,0,5,0,27,0,5,0,24,0,5,0,20,0,5,0,18,0,5,0,12,0,5,0,2,0,5,0,58,0,6,0,33,0,6,0,7,0,6,0,64,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,25,13,0,74,25,13,0,40,3,10,0,149,1,9,0,203,0,8,0,102,0,7,0,49,0,6,0,9,0,5,0,15,0,5,0,31,0,5,0,2,0,4,0,6,0,4,0,8,0,4,0,11,0,4,0,13,0,4,0,0,0,3,0,14,0,4,0,10,0,4,0,9,0,4,0,5,0,4,0,3,0,4,0,30,0,5,0,14,0,5,0,8,0,5,0,48,0,6,0,103,0,7,0,201,0,8,0,200,0,8,0,83,6,11,0,73,25,13,0,75,25,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,0,8,0,153,0,8,0,181,0,8,0,233,0,8,0,64,0,7,0,65,0,7,0,77,0,7,0,81,0,7,0,91,0,7,0,113,0,7,0,112,0,7,0,24,0,6,0,29,0,6,0,35,0,6,0,37,0,6,0,41,0,6,0,44,0,6,0,46,0,6,0,51,0,6,0,49,0,6,0,54,0,6,0,55,0,6,0,57,0,6,0,60,0,6,0,0,0,5,0,2,0,5,0,10,0,5,0,5,0,5,0,9,0,5,0,6,0,5,0,13,0,5,0,7,0,5,0,11,0,5,0,15,0,5,0,8,0,5,0,4,0,5,0,3,0,5,0,1,0,5,0,63,0,6,0,62,0,6,0,61,0,6,0,53,0,6,0,59,0,6,0,52,0,6,0,48,0,6,0,47,0,6,0,43,0,6,0,42,0,6,0,39,0,6,0,36,0,6,0,33,0,6,0,28,0,6,0,117,0,7,0,101,0,7,0,100,0,7,0,80,0,7,0,69,0,7,0,68,0,7,0,50,0,7,0,232,0,8,0,180,0,8,0,152,0,8,0,102,0,8,0,0,0,0,0,164,55,14,0,173,55,14,0,166,55,14,0,174,55,14,0,234,13,12,0,240,2,10,0,241,2,10,0,160,0,9,0,162,0,9,0,188,1,9,0,122,0,8,0,223,0,8,0,60,0,7,0,73,0,7,0,110,0,7,0,14,0,6,0,24,0,6,0,25,0,6,0,34,0,6,0,37,0,6,0,54,0,6,0,3,0,5,0,9,0,5,0,11,0,5,0,16,0,5,0,19,0,5,0,21,0,5,0,24,0,5,0,26,0,5,0,29,0,5,0,31,0,5,0,2,0,4,0,0,0,4,0,30,0,5,0,28,0,5,0,25,0,5,0,22,0,5,0,20,0,5,0,14,0,5,0,13,0,5,0,8,0,5,0,6,0,5,0,2,0,5,0,46,0,6,0,35,0,6,0,31,0,6,0,21,0,6,0,15,0,6,0,95,0,7,0,72,0,7,0,41,0,7,0,189,0,8,0,123,0,8,0,121,1,9,0,161,0,9,0,123,3,10,0,71,1,10,0,70,1,10,0,232,13,12,0,175,55,14,0,167,55,14,0,172,55,14,0,165,55,14,0,0,0,0,0,254,254,254,254,254,255,255,255,255,255,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,0,0,0,0,0,0,0,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,254,255,0,1,2,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,0,0,0,255,255,255,0,0,0,1,1,1,255,255,255,0,0,0,1,1,1,255,255,255,0,0,0,1,1,1,0,0,0,0,0,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,255,0,1,0,0,0,0,0,92,8,47,7,10,5,4,4,0,2,1,1,3,3,22,6,187,9,186,9,0,0,0,0,32,6,4,5,17,5,30,5,13,4,0,3,3,3,9,4,5,3,2,3,14,4,3,4,31,5,5,5,33,6,12,4,0,0,0,0,0,0,0,0,1,5,4,5,6,5,4,4,7,3,6,0,7,2,3,1,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,1,5,4,5,6,5,4,4,7,3,6,0,7,2,3,1,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,1,4,4,5,4,6,5,6,4,5,5,6,5,6,6,6,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,1,4,4,5,4,6,5,6,4,5,5,6,5,6,6,6,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,3,3,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,3,3,3,2,0,0,0,0,0,7,0,5,0,9,0,14,0,15,0,7,0,6,0,4,0,5,0,5,0,6,0,7,0,7,0,6,0,8,0,8,0,8,0,5,0,15,0,6,0,9,0,10,0,5,0,1,0,11,0,7,0,9,0,6,0,4,0,1,0,14,0,4,0,6,0,2,0,6,0,0,0,7,0,5,0,9,0,14,0,15,0,7,0,6,0,4,0,5,0,5,0,6,0,7,0,7,0,6,0,8,0,8,0,8,0,5,0,15,0,6,0,9,0,10,0,5,0,1,0,11,0,7,0,9,0,6,0,4,0,1,0,14,0,4,0,6,0,2,0,6,0,0,0,3,0,4,0,6,0,18,0,12,0,5,0,5,0,1,0,2,0,16,0,9,0,3,0,7,0,3,0,5,0,14,0,7,0,3,0,19,0,17,0,15,0,13,0,10,0,4,0,13,0,5,0,8,0,11,0,5,0,1,0,12,0,4,0,4,0,1,0,1,0,0,0,3,0,4,0,6,0,18,0,12,0,5,0,5,0,1,0,2,0,16,0,9,0,3,0,7,0,3,0,5,0,14,0,7,0,3,0,19,0,17,0,15,0,13,0,10,0,4,0,13,0,5,0,8,0,11,0,5,0,1,0,12,0,4,0,4,0,1,0,1,0,0,0,1,0,2,0,10,0,19,0,16,0,10,0,3,0,3,0,7,0,10,0,5,0,3,0,11,0,4,0,13,0,17,0,8,0,4,0,12,0,11,0,18,0,15,0,11,0,2,0,7,0,6,0,9,0,14,0,3,0,1,0,6,0,4,0,5,0,3,0,2,0,0,0,1,0,2,0,10,0,19,0,16,0,10,0,3,0,3,0,7,0,10,0,5,0,3,0,11,0,4,0,13,0,17,0,8,0,4,0,12,0,11,0,18,0,15,0,11,0,2,0,7,0,6,0,9,0,14,0,3,0,1,0,6,0,4,0,5,0,3,0,2,0,0,0,7,0,3,0,5,0,1,0,6,0,2,0,3,0,2,0,5,0,4,0,4,0,1,0,3,0,3,0,2,0,0,0,7,0,3,0,5,0,1,0,6,0,2,0,3,0,2,0,5,0,4,0,4,0,1,0,3,0,3,0,2,0,0,0,1,0,2,0,6,0,5,0,3,0,1,0,4,0,4,0,7,0,5,0,7,0,1,0,6,0,1,0,1,0,0,0,1,0,2,0,6,0,5,0,3,0,1,0,4,0,4,0,7,0,5,0,7,0,1,0,6,0,1,0,1,0,0,0,3,0,2,0,1,0,1,0,1,0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,3,0,2,0,1,0,1,0,1,0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,15,0,13,0,46,0,80,0,146,0,6,1,248,0,178,1,170,1,157,2,141,2,137,2,109,2,5,2,8,4,88,0,14,0,12,0,21,0,38,0,71,0,130,0,122,0,216,0,209,0,198,0,71,1,89,1,63,1,41,1,23,1,42,0,47,0,22,0,41,0,74,0,68,0,128,0,120,0,221,0,207,0,194,0,182,0,84,1,59,1,39,1,29,2,18,0,81,0,39,0,75,0,70,0,134,0,125,0,116,0,220,0,204,0,190,0,178,0,69,1,55,1,37,1,15,1,16,0,147,0,72,0,69,0,135,0,127,0,118,0,112,0,210,0,200,0,188,0,96,1,67,1,50,1,29,1,28,2,14,0,7,1,66,0,129,0,126,0,119,0,114,0,214,0,202,0,192,0,180,0,85,1,61,1,45,1,25,1,6,1,12,0,249,0,123,0,121,0,117,0,113,0,215,0,206,0,195,0,185,0,91,1,74,1,52,1,35,1,16,1,8,2,10,0,179,1,115,0,111,0,109,0,211,0,203,0,196,0,187,0,97,1,76,1,57,1,42,1,27,1,19,2,125,1,17,0,171,1,212,0,208,0,205,0,201,0,193,0,186,0,177,0,169,0,64,1,47,1,30,1,12,1,2,2,121,1,16,0,79,1,199,0,197,0,191,0,189,0,181,0,174,0,77,1,65,1,49,1,33,1,19,1,9,2,123,1,115,1,11,0,156,2,184,0,183,0,179,0,175,0,88,1,75,1,58,1,48,1,34,1,21,1,18,2,127,1,117,1,110,1,10,0,140,2,90,1,171,0,168,0,164,0,62,1,53,1,43,1,31,1,20,1,7,1,1,2,119,1,112,1,106,1,6,0,136,2,66,1,60,1,56,1,51,1,46,1,36,1,28,1,13,1,5,1,0,2,120,1,114,1,108,1,103,1,4,0,108,2,44,1,40,1,38,1,32,1,26,1,17,1,10,1,3,2,124,1,118,1,113,1,109,1,105,1,101,1,2,0,9,4,24,1,22,1,18,1,11,1,8,1,3,1,126,1,122,1,116,1,111,1,107,1,104,1,102,1,100,1,0,0,43,0,20,0,19,0,17,0,15,0,13,0,11,0,9,0,7,0,6,0,4,0,7,0,5,0,3,0,1,0,3,0,15,0,13,0,46,0,80,0,146,0,6,1,248,0,178,1,170,1,157,2,141,2,137,2,109,2,5,2,8,4,88,0,14,0,12,0,21,0,38,0,71,0,130,0,122,0,216,0,209,0,198,0,71,1,89,1,63,1,41,1,23,1,42,0,47,0,22,0,41,0,74,0,68,0,128,0,120,0,221,0,207,0,194,0,182,0,84,1,59,1,39,1,29,2,18,0,81,0,39,0,75,0,70,0,134,0,125,0,116,0,220,0,204,0,190,0,178,0,69,1,55,1,37,1,15,1,16,0,147,0,72,0,69,0,135,0,127,0,118,0,112,0,210,0,200,0,188,0,96,1,67,1,50,1,29,1,28,2,14,0,7,1,66,0,129,0,126,0,119,0,114,0,214,0,202,0,192,0,180,0,85,1,61,1,45,1,25,1,6,1,12,0,249,0,123,0,121,0,117,0,113,0,215,0,206,0,195,0,185,0,91,1,74,1,52,1,35,1,16,1,8,2,10,0,179,1,115,0,111,0,109,0,211,0,203,0,196,0,187,0,97,1,76,1,57,1,42,1,27,1,19,2,125,1,17,0,171,1,212,0,208,0,205,0,201,0,193,0,186,0,177,0,169,0,64,1,47,1,30,1,12,1,2,2,121,1,16,0,79,1,199,0,197,0,191,0,189,0,181,0,174,0,77,1,65,1,49,1,33,1,19,1,9,2,123,1,115,1,11,0,156,2,184,0,183,0,179,0,175,0,88,1,75,1,58,1,48,1,34,1,21,1,18,2,127,1,117,1,110,1,10,0,140,2,90,1,171,0,168,0,164,0,62,1,53,1,43,1,31,1,20,1,7,1,1,2,119,1,112,1,106,1,6,0,136,2,66,1,60,1,56,1,51,1,46,1,36,1,28,1,13,1,5,1,0,2,120,1,114,1,108,1,103,1,4,0,108,2,44,1,40,1,38,1,32,1,26,1,17,1,10,1,3,2,124,1,118,1,113,1,109,1,105,1,101,1,2,0,9,4,24,1,22,1,18,1,11,1,8,1,3,1,126,1,122,1,116,1,111,1,107,1,104,1,102,1,100,1,0,0,43,0,20,0,19,0,17,0,15,0,13,0,11,0,9,0,7,0,6,0,4,0,7,0,5,0,3,0,1,0,3,0,1,0,2,0,1,0,3,0,1,0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,1,0,2,0,1,0,3,0,1,0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,1,0,5,0,14,0,44,0,74,0,63,0,110,0,93,0,172,0,149,0,138,0,242,0,225,0,195,0,120,1,17,0,3,0,4,0,12,0,20,0,35,0,62,0,53,0,47,0,83,0,75,0,68,0,119,0,201,0,107,0,207,0,9,0,15,0,13,0,23,0,38,0,67,0,58,0,103,0,90,0,161,0,72,0,127,0,117,0,110,0,209,0,206,0,16,0,45,0,21,0,39,0,69,0,64,0,114,0,99,0,87,0,158,0,140,0,252,0,212,0,199,0,131,1,109,1,26,0,75,0,36,0,68,0,65,0,115,0,101,0,179,0,164,0,155,0,8,1,246,0,226,0,139,1,126,1,106,1,9,0,66,0,30,0,59,0,56,0,102,0,185,0,173,0,9,1,142,0,253,0,232,0,144,1,132,1,122,1,189,1,16,0,111,0,54,0,52,0,100,0,184,0,178,0,160,0,133,0,1,1,244,0,228,0,217,0,129,1,110,1,203,2,10,0,98,0,48,0,91,0,88,0,165,0,157,0,148,0,5,1,248,0,151,1,141,1,116,1,124,1,121,3,116,3,8,0,85,0,84,0,81,0,159,0,156,0,143,0,4,1,249,0,171,1,145,1,136,1,127,1,215,2,201,2,196,2,7,0,154,0,76,0,73,0,141,0,131,0,0,1,245,0,170,1,150,1,138,1,128,1,223,2,103,1,198,2,96,1,11,0,139,0,129,0,67,0,125,0,247,0,233,0,229,0,219,0,137,1,231,2,225,2,208,2,117,3,114,3,183,1,4,0,243,0,120,0,118,0,115,0,227,0,223,0,140,1,234,2,230,2,224,2,209,2,200,2,194,2,223,0,180,1,6,0,202,0,224,0,222,0,218,0,216,0,133,1,130,1,125,1,108,1,120,3,187,1,195,2,184,1,181,1,192,6,4,0,235,2,211,0,210,0,208,0,114,1,123,1,222,2,211,2,202,2,199,6,115,3,109,3,108,3,131,13,97,3,2,0,121,1,113,1,102,0,187,0,214,2,210,2,102,1,199,2,197,2,98,3,198,6,103,3,130,13,102,3,178,1,0,0,12,0,10,0,7,0,11,0,10,0,17,0,11,0,9,0,13,0,12,0,10,0,7,0,5,0,3,0,1,0,3,0,1,0,5,0,14,0,44,0,74,0,63,0,110,0,93,0,172,0,149,0,138,0,242,0,225,0,195,0,120,1,17,0,3,0,4,0,12,0,20,0,35,0,62,0,53,0,47,0,83,0,75,0,68,0,119,0,201,0,107,0,207,0,9,0,15,0,13,0,23,0,38,0,67,0,58,0,103,0,90,0,161,0,72,0,127,0,117,0,110,0,209,0,206,0,16,0,45,0,21,0,39,0,69,0,64,0,114,0,99,0,87,0,158,0,140,0,252,0,212,0,199,0,131,1,109,1,26,0,75,0,36,0,68,0,65,0,115,0,101,0,179,0,164,0,155,0,8,1,246,0,226,0,139,1,126,1,106,1,9,0,66,0,30,0,59,0,56,0,102,0,185,0,173,0,9,1,142,0,253,0,232,0,144,1,132,1,122,1,189,1,16,0,111,0,54,0,52,0,100,0,184,0,178,0,160,0,133,0,1,1,244,0,228,0,217,0,129,1,110,1,203,2,10,0,98,0,48,0,91,0,88,0,165,0,157,0,148,0,5,1,248,0,151,1,141,1,116,1,124,1,121,3,116,3,8,0,85,0,84,0,81,0,159,0,156,0,143,0,4,1,249,0,171,1,145,1,136,1,127,1,215,2,201,2,196,2,7,0,154,0,76,0,73,0,141,0,131,0,0,1,245,0,170,1,150,1,138,1,128,1,223,2,103,1,198,2,96,1,11,0,139,0,129,0,67,0,125,0,247,0,233,0,229,0,219,0,137,1,231,2,225,2,208,2,117,3,114,3,183,1,4,0,243,0,120,0,118,0,115,0,227,0,223,0,140,1,234,2,230,2,224,2,209,2,200,2,194,2,223,0,180,1,6,0,202,0,224,0,222,0,218,0,216,0,133,1,130,1,125,1,108,1,120,3,187,1,195,2,184,1,181,1,192,6,4,0,235,2,211,0,210,0,208,0,114,1,123,1,222,2,211,2,202,2,199,6,115,3,109,3,108,3,131,13,97,3,2,0,121,1,113,1,102,0,187,0,214,2,210,2,102,1,199,2,197,2,98,3,198,6,103,3,130,13,102,3,178,1,0,0,12,0,10,0,7,0,11,0,10,0,17,0,11,0,9,0,13,0,12,0,10,0,7,0,5,0,3,0,1,0,3,0,7,0,12,0,18,0,53,0,47,0,76,0,124,0,108,0,89,0,123,0,108,0,119,0,107,0,81,0,122,0,63,0,13,0,5,0,16,0,27,0,46,0,36,0,61,0,51,0,42,0,70,0,52,0,83,0,65,0,41,0,59,0,36,0,19,0,17,0,15,0,24,0,41,0,34,0,59,0,48,0,40,0,64,0,50,0,78,0,62,0,80,0,56,0,33,0,29,0,28,0,25,0,43,0,39,0,63,0,55,0,93,0,76,0,59,0,93,0,72,0,54,0,75,0,50,0,29,0,52,0,22,0,42,0,40,0,67,0,57,0,95,0,79,0,72,0,57,0,89,0,69,0,49,0,66,0,46,0,27,0,77,0,37,0,35,0,66,0,58,0,52,0,91,0,74,0,62,0,48,0,79,0,63,0,90,0,62,0,40,0,38,0,125,0,32,0,60,0,56,0,50,0,92,0,78,0,65,0,55,0,87,0,71,0,51,0,73,0,51,0,70,0,30,0,109,0,53,0,49,0,94,0,88,0,75,0,66,0,122,0,91,0,73,0,56,0,42,0,64,0,44,0,21,0,25,0,90,0,43,0,41,0,77,0,73,0,63,0,56,0,92,0,77,0,66,0,47,0,67,0,48,0,53,0,36,0,20,0,71,0,34,0,67,0,60,0,58,0,49,0,88,0,76,0,67,0,106,0,71,0,54,0,38,0,39,0,23,0,15,0,109,0,53,0,51,0,47,0,90,0,82,0,58,0,57,0,48,0,72,0,57,0,41,0,23,0,27,0,62,0,9,0,86,0,42,0,40,0,37,0,70,0,64,0,52,0,43,0,70,0,55,0,42,0,25,0,29,0,18,0,11,0,11,0,118,0,68,0,30,0,55,0,50,0,46,0,74,0,65,0,49,0,39,0,24,0,16,0,22,0,13,0,14,0,7,0,91,0,44,0,39,0,38,0,34,0,63,0,52,0,45,0,31,0,52,0,28,0,19,0,14,0,8,0,9,0,3,0,123,0,60,0,58,0,53,0,47,0,43,0,32,0,22,0,37,0,24,0,17,0,12,0,15,0,10,0,2,0,1,0,71,0,37,0,34,0,30,0,28,0,20,0,17,0,26,0,21,0,16,0,10,0,6,0,8,0,6,0,2,0,0,0,7,0,12,0,18,0,53,0,47,0,76,0,124,0,108,0,89,0,123,0,108,0,119,0,107,0,81,0,122,0,63,0,13,0,5,0,16,0,27,0,46,0,36,0,61,0,51,0,42,0,70,0,52,0,83,0,65,0,41,0,59,0,36,0,19,0,17,0,15,0,24,0,41,0,34,0,59,0,48,0,40,0,64,0,50,0,78,0,62,0,80,0,56,0,33,0,29,0,28,0,25,0,43,0,39,0,63,0,55,0,93,0,76,0,59,0,93,0,72,0,54,0,75,0,50,0,29,0,52,0,22,0,42,0,40,0,67,0,57,0,95,0,79,0,72,0,57,0,89,0,69,0,49,0,66,0,46,0,27,0,77,0,37,0,35,0,66,0,58,0,52,0,91,0,74,0,62,0,48,0,79,0,63,0,90,0,62,0,40,0,38,0,125,0,32,0,60,0,56,0,50,0,92,0,78,0,65,0,55,0,87,0,71,0,51,0,73,0,51,0,70,0,30,0,109,0,53,0,49,0,94,0,88,0,75,0,66,0,122,0,91,0,73,0,56,0,42,0,64,0,44,0,21,0,25,0,90,0,43,0,41,0,77,0,73,0,63,0,56,0,92,0,77,0,66,0,47,0,67,0,48,0,53,0,36,0,20,0,71,0,34,0,67,0,60,0,58,0,49,0,88,0,76,0,67,0,106,0,71,0,54,0,38,0,39,0,23,0,15,0,109,0,53,0,51,0,47,0,90,0,82,0,58,0,57,0,48,0,72,0,57,0,41,0,23,0,27,0,62,0,9,0,86,0,42,0,40,0,37,0,70,0,64,0,52,0,43,0,70,0,55,0,42,0,25,0,29,0,18,0,11,0,11,0,118,0,68,0,30,0,55,0,50,0,46,0,74,0,65,0,49,0,39,0,24,0,16,0,22,0,13,0,14,0,7,0,91,0,44,0,39,0,38,0,34,0,63,0,52,0,45,0,31,0,52,0,28,0,19,0,14,0,8,0,9,0,3,0,123,0,60,0,58,0,53,0,47,0,43,0,32,0,22,0,37,0,24,0,17,0,12,0,15,0,10,0,2,0,1,0,71,0,37,0,34,0,30,0,28,0,20,0,17,0,26,0,21,0,16,0,10,0,6,0,8,0,6,0,2,0,0,0,1,0,5,0,14,0,21,0,34,0,51,0,46,0,71,0,42,0,52,0,68,0,52,0,67,0,44,0,43,0,19,0,3,0,4,0,12,0,19,0,31,0,26,0,44,0,33,0,31,0,24,0,32,0,24,0,31,0,35,0,22,0,14,0,15,0,13,0,23,0,36,0,59,0,49,0,77,0,65,0,29,0,40,0,30,0,40,0,27,0,33,0,42,0,16,0,22,0,20,0,37,0,61,0,56,0,79,0,73,0,64,0,43,0,76,0,56,0,37,0,26,0,31,0,25,0,14,0,35,0,16,0,60,0,57,0,97,0,75,0,114,0,91,0,54,0,73,0,55,0,41,0,48,0,53,0,23,0,24,0,58,0,27,0,50,0,96], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+806039);
/* memory initializer */ allocate([0,76,0,70,0,93,0,84,0,77,0,58,0,79,0,29,0,74,0,49,0,41,0,17,0,47,0,45,0,78,0,74,0,115,0,94,0,90,0,79,0,69,0,83,0,71,0,50,0,59,0,38,0,36,0,15,0,72,0,34,0,56,0,95,0,92,0,85,0,91,0,90,0,86,0,73,0,77,0,65,0,51,0,44,0,43,0,42,0,43,0,20,0,30,0,44,0,55,0,78,0,72,0,87,0,78,0,61,0,46,0,54,0,37,0,30,0,20,0,16,0,53,0,25,0,41,0,37,0,44,0,59,0,54,0,81,0,66,0,76,0,57,0,54,0,37,0,18,0,39,0,11,0,35,0,33,0,31,0,57,0,42,0,82,0,72,0,80,0,47,0,58,0,55,0,21,0,22,0,26,0,38,0,22,0,53,0,25,0,23,0,38,0,70,0,60,0,51,0,36,0,55,0,26,0,34,0,23,0,27,0,14,0,9,0,7,0,34,0,32,0,28,0,39,0,49,0,75,0,30,0,52,0,48,0,40,0,52,0,28,0,18,0,17,0,9,0,5,0,45,0,21,0,34,0,64,0,56,0,50,0,49,0,45,0,31,0,19,0,12,0,15,0,10,0,7,0,6,0,3,0,48,0,23,0,20,0,39,0,36,0,35,0,53,0,21,0,16,0,23,0,13,0,10,0,6,0,1,0,4,0,2,0,16,0,15,0,17,0,27,0,25,0,20,0,29,0,11,0,17,0,12,0,16,0,8,0,1,0,1,0,0,0,1,0,1,0,5,0,14,0,21,0,34,0,51,0,46,0,71,0,42,0,52,0,68,0,52,0,67,0,44,0,43,0,19,0,3,0,4,0,12,0,19,0,31,0,26,0,44,0,33,0,31,0,24,0,32,0,24,0,31,0,35,0,22,0,14,0,15,0,13,0,23,0,36,0,59,0,49,0,77,0,65,0,29,0,40,0,30,0,40,0,27,0,33,0,42,0,16,0,22,0,20,0,37,0,61,0,56,0,79,0,73,0,64,0,43,0,76,0,56,0,37,0,26,0,31,0,25,0,14,0,35,0,16,0,60,0,57,0,97,0,75,0,114,0,91,0,54,0,73,0,55,0,41,0,48,0,53,0,23,0,24,0,58,0,27,0,50,0,96,0,76,0,70,0,93,0,84,0,77,0,58,0,79,0,29,0,74,0,49,0,41,0,17,0,47,0,45,0,78,0,74,0,115,0,94,0,90,0,79,0,69,0,83,0,71,0,50,0,59,0,38,0,36,0,15,0,72,0,34,0,56,0,95,0,92,0,85,0,91,0,90,0,86,0,73,0,77,0,65,0,51,0,44,0,43,0,42,0,43,0,20,0,30,0,44,0,55,0,78,0,72,0,87,0,78,0,61,0,46,0,54,0,37,0,30,0,20,0,16,0,53,0,25,0,41,0,37,0,44,0,59,0,54,0,81,0,66,0,76,0,57,0,54,0,37,0,18,0,39,0,11,0,35,0,33,0,31,0,57,0,42,0,82,0,72,0,80,0,47,0,58,0,55,0,21,0,22,0,26,0,38,0,22,0,53,0,25,0,23,0,38,0,70,0,60,0,51,0,36,0,55,0,26,0,34,0,23,0,27,0,14,0,9,0,7,0,34,0,32,0,28,0,39,0,49,0,75,0,30,0,52,0,48,0,40,0,52,0,28,0,18,0,17,0,9,0,5,0,45,0,21,0,34,0,64,0,56,0,50,0,49,0,45,0,31,0,19,0,12,0,15,0,10,0,7,0,6,0,3,0,48,0,23,0,20,0,39,0,36,0,35,0,53,0,21,0,16,0,23,0,13,0,10,0,6,0,1,0,4,0,2,0,16,0,15,0,17,0,27,0,25,0,20,0,29,0,11,0,17,0,12,0,16,0,8,0,1,0,1,0,0,0,1,0,9,0,6,0,16,0,33,0,41,0,39,0,38,0,26,0,7,0,5,0,6,0,9,0,23,0,16,0,26,0,11,0,17,0,7,0,11,0,14,0,21,0,30,0,10,0,7,0,17,0,10,0,15,0,12,0,18,0,28,0,14,0,5,0,32,0,13,0,22,0,19,0,18,0,16,0,9,0,5,0,40,0,17,0,31,0,29,0,17,0,13,0,4,0,2,0,27,0,12,0,11,0,15,0,10,0,7,0,4,0,1,0,27,0,12,0,8,0,12,0,6,0,3,0,1,0,0,0,9,0,6,0,16,0,33,0,41,0,39,0,38,0,26,0,7,0,5,0,6,0,9,0,23,0,16,0,26,0,11,0,17,0,7,0,11,0,14,0,21,0,30,0,10,0,7,0,17,0,10,0,15,0,12,0,18,0,28,0,14,0,5,0,32,0,13,0,22,0,19,0,18,0,16,0,9,0,5,0,40,0,17,0,31,0,29,0,17,0,13,0,4,0,2,0,27,0,12,0,11,0,15,0,10,0,7,0,4,0,1,0,27,0,12,0,8,0,12,0,6,0,3,0,1,0,0,0,1,0,1,0,1,0,0,0,3,0,4,0,10,0,24,0,34,0,33,0,21,0,15,0,5,0,3,0,4,0,10,0,32,0,17,0,11,0,10,0,11,0,7,0,13,0,18,0,30,0,31,0,20,0,5,0,25,0,11,0,19,0,59,0,27,0,18,0,12,0,5,0,35,0,33,0,31,0,58,0,30,0,16,0,7,0,5,0,28,0,26,0,32,0,19,0,17,0,15,0,8,0,14,0,14,0,12,0,9,0,13,0,14,0,9,0,4,0,1,0,11,0,4,0,6,0,6,0,6,0,3,0,2,0,0,0,3,0,4,0,10,0,24,0,34,0,33,0,21,0,15,0,5,0,3,0,4,0,10,0,32,0,17,0,11,0,10,0,11,0,7,0,13,0,18,0,30,0,31,0,20,0,5,0,25,0,11,0,19,0,59,0,27,0,18,0,12,0,5,0,35,0,33,0,31,0,58,0,30,0,16,0,7,0,5,0,28,0,26,0,32,0,19,0,17,0,15,0,8,0,14,0,14,0,12,0,9,0,13,0,14,0,9,0,4,0,1,0,11,0,4,0,6,0,6,0,6,0,3,0,2,0,0,0,1,0,2,0,10,0,23,0,35,0,30,0,12,0,17,0,3,0,3,0,8,0,12,0,18,0,21,0,12,0,7,0,11,0,9,0,15,0,21,0,32,0,40,0,19,0,6,0,14,0,13,0,22,0,34,0,46,0,23,0,18,0,7,0,20,0,19,0,33,0,47,0,27,0,22,0,9,0,3,0,31,0,22,0,41,0,26,0,21,0,20,0,5,0,3,0,14,0,13,0,10,0,11,0,16,0,6,0,5,0,1,0,9,0,8,0,7,0,8,0,4,0,4,0,2,0,0,0,1,0,2,0,10,0,23,0,35,0,30,0,12,0,17,0,3,0,3,0,8,0,12,0,18,0,21,0,12,0,7,0,11,0,9,0,15,0,21,0,32,0,40,0,19,0,6,0,14,0,13,0,22,0,34,0,46,0,23,0,18,0,7,0,20,0,19,0,33,0,47,0,27,0,22,0,9,0,3,0,31,0,22,0,41,0,26,0,21,0,20,0,5,0,3,0,14,0,13,0,10,0,11,0,16,0,6,0,5,0,1,0,9,0,8,0,7,0,8,0,4,0,4,0,2,0,0,0,1,0,1,0,1,0,0,0,3,3,5,6,8,9,3,3,4,5,6,8,4,4,5,6,7,8,6,5,6,7,7,8,7,6,7,7,8,9,8,7,8,8,9,9,0,0,0,0,3,3,5,6,8,9,3,3,4,5,6,8,4,4,5,6,7,8,6,5,6,7,7,8,7,6,7,7,8,9,8,7,8,8,9,9,0,0,0,0,2,3,6,8,8,9,3,2,4,8,8,8,6,4,6,8,8,9,8,8,8,9,9,10,8,7,8,9,10,10,9,8,9,9,11,11,0,0,0,0,2,3,6,8,8,9,3,2,4,8,8,8,6,4,6,8,8,9,8,8,8,9,9,10,8,7,8,9,10,10,9,8,9,9,11,11,0,0,0,0,1,3,6,8,8,9,3,4,6,7,7,8,6,5,7,8,8,9,7,7,8,9,9,9,7,7,8,9,9,10,8,8,9,10,10,10,0,0,0,0,1,3,6,8,8,9,3,4,6,7,7,8,6,5,7,8,8,9,7,7,8,9,9,9,7,7,8,9,9,10,8,8,9,10,10,10,0,0,0,0,3,3,5,7,3,2,4,5,4,4,5,6,6,5,6,7,3,3,5,7,3,2,4,5,4,4,5,6,6,5,6,7,1,3,6,7,3,3,6,7,6,6,7,8,7,6,7,8,1,3,6,7,3,3,6,7,6,6,7,8,7,6,7,8,2,2,6,3,2,5,5,5,6,0,0,0,0,0,0,0,2,2,6,3,2,5,5,5,6,0,0,0,0,0,0,0,4,4,6,7,8,9,9,10,10,11,11,11,11,11,12,9,4,4,5,6,7,8,8,9,9,9,10,10,10,10,10,8,6,5,6,7,7,8,8,9,9,9,9,10,10,10,11,7,7,6,7,7,8,8,8,9,9,9,9,10,10,10,10,7,8,7,7,8,8,8,8,9,9,9,10,10,10,10,11,7,9,7,8,8,8,8,9,9,9,9,10,10,10,10,10,7,9,8,8,8,8,9,9,9,9,10,10,10,10,10,11,7,10,8,8,8,9,9,9,9,10,10,10,10,10,11,11,8,10,9,9,9,9,9,9,9,9,10,10,10,10,11,11,8,10,9,9,9,9,9,9,10,10,10,10,10,11,11,11,8,11,9,9,9,9,10,10,10,10,10,10,11,11,11,11,8,11,10,9,9,9,10,10,10,10,10,10,11,11,11,11,8,11,10,10,10,10,10,10,10,10,10,11,11,11,11,11,8,11,10,10,10,10,10,10,10,11,11,11,11,11,11,11,8,12,10,10,10,10,10,10,11,11,11,11,11,11,11,11,8,8,7,7,7,7,7,7,7,7,7,7,8,8,8,8,4,4,4,6,7,8,9,9,10,10,11,11,11,11,11,12,9,4,4,5,6,7,8,8,9,9,9,10,10,10,10,10,8,6,5,6,7,7,8,8,9,9,9,9,10,10,10,11,7,7,6,7,7,8,8,8,9,9,9,9,10,10,10,10,7,8,7,7,8,8,8,8,9,9,9,10,10,10,10,11,7,9,7,8,8,8,8,9,9,9,9,10,10,10,10,10,7,9,8,8,8,8,9,9,9,9,10,10,10,10,10,11,7,10,8,8,8,9,9,9,9,10,10,10,10,10,11,11,8,10,9,9,9,9,9,9,9,9,10,10,10,10,11,11,8,10,9,9,9,9,9,9,10,10,10,10,10,11,11,11,8,11,9,9,9,9,10,10,10,10,10,10,11,11,11,11,8,11,10,9,9,9,10,10,10,10,10,10,11,11,11,11,8,11,10,10,10,10,10,10,10,10,10,11,11,11,11,11,8,11,10,10,10,10,10,10,10,11,11,11,11,11,11,11,8,12,10,10,10,10,10,10,11,11,11,11,11,11,11,11,8,8,7,7,7,7,7,7,7,7,7,7,8,8,8,8,4,1,3,6,3,3,5,5,5,6,0,0,0,0,0,0,0,1,3,6,3,3,5,5,5,6,0,0,0,0,0,0,0,1,4,6,8,9,9,10,10,11,11,11,12,12,12,13,9,3,4,6,7,8,9,9,9,10,10,10,11,12,11,12,8,6,6,7,8,9,9,10,10,11,10,11,11,11,12,12,9,8,7,8,9,9,10,10,10,11,11,12,12,12,13,13,10,9,8,9,9,10,10,11,11,11,12,12,12,13,13,13,9,9,8,9,9,10,11,11,12,11,12,12,13,13,13,14,10,10,9,9,10,11,11,11,11,12,12,12,12,13,13,14,10,10,9,10,10,11,11,11,12,12,13,13,13,13,15,15,10,10,10,10,11,11,11,12,12,13,13,13,13,14,14,14,10,11,10,10,11,11,12,12,13,13,13,13,14,13,14,13,11,11,11,10,11,12,12,12,12,13,14,14,14,15,15,14,10,12,11,11,11,12,12,13,14,14,14,14,14,14,13,14,11,12,12,12,12,12,13,13,13,13,15,14,14,14,14,16,11,14,12,12,12,13,13,14,14,14,16,15,15,15,17,15,11,13,13,11,12,14,14,13,14,14,15,16,15,17,15,14,11,9,8,8,9,9,10,10,10,11,11,11,11,11,11,11,8,1,4,6,8,9,9,10,10,11,11,11,12,12,12,13,9,3,4,6,7,8,9,9,9,10,10,10,11,12,11,12,8,6,6,7,8,9,9,10,10,11,10,11,11,11,12,12,9,8,7,8,9,9,10,10,10,11,11,12,12,12,13,13,10,9,8,9,9,10,10,11,11,11,12,12,12,13,13,13,9,9,8,9,9,10,11,11,12,11,12,12,13,13,13,14,10,10,9,9,10,11,11,11,11,12,12,12,12,13,13,14,10,10,9,10,10,11,11,11,12,12,13,13,13,13,15,15,10,10,10,10,11,11,11,12,12,13,13,13,13,14,14,14,10,11,10,10,11,11,12,12,13,13,13,13,14,13,14,13,11,11,11,10,11,12,12,12,12,13,14,14,14,15,15,14,10,12,11,11,11,12,12,13,14,14,14,14,14,14,13,14,11,12,12,12,12,12,13,13,13,13,15,14,14,14,14,16,11,14,12,12,12,13,13,14,14,14,16,15,15,15,17,15,11,13,13,11,12,14,14,13,14,14,15,16,15,17,15,14,11,9,8,8,9,9,10,10,10,11,11,11,11,11,11,11,8,3,4,5,7,7,8,9,9,9,10,10,11,11,11,12,13,4,3,5,6,7,7,8,8,8,9,9,10,10,10,11,11,5,5,5,6,7,7,8,8,8,9,9,10,10,11,11,11,6,6,6,7,7,8,8,9,9,9,10,10,10,11,11,11,7,6,7,7,8,8,9,9,9,9,10,10,10,11,11,11,8,7,7,8,8,8,9,9,9,9,10,10,11,11,11,12,9,7,8,8,8,9,9,9,9,10,10,10,11,11,12,12,9,8,8,9,9,9,9,10,10,10,10,10,11,11,11,12,9,8,8,9,9,9,9,10,10,10,10,11,11,12,12,12,9,8,9,9,9,9,10,10,10,11,11,11,11,12,12,12,10,9,9,9,10,10,10,10,10,11,11,11,11,12,13,12,10,9,9,9,10,10,10,10,11,11,11,11,12,12,12,13,11,10,9,10,10,10,11,11,11,11,11,11,12,12,13,13,11,10,10,10,10,11,11,11,11,12,12,12,12,12,13,13,12,11,11,11,11,11,11,11,12,12,12,12,13,13,12,13,12,11,11,11,11,11,11,12,12,12,12,12,13,13,13,13,3,4,5,7,7,8,9,9,9,10,10,11,11,11,12,13,4,3,5,6,7,7,8,8,8,9,9,10,10,10,11,11,5,5,5,6,7,7,8,8,8,9,9,10,10,11,11,11,6,6,6,7,7,8,8,9,9,9,10,10,10,11,11,11,7,6,7,7,8,8,9,9,9,9,10,10,10,11,11,11,8,7,7,8,8,8,9,9,9,9,10,10,11,11,11,12,9,7,8,8,8,9,9,9,9,10,10,10,11,11,12,12,9,8,8,9,9,9,9,10,10,10,10,10,11,11,11,12,9,8,8,9,9,9,9,10,10,10,10,11,11,12,12,12,9,8,9,9,9,9,10,10,10,11,11,11,11,12,12,12,10,9,9,9,10,10,10,10,10,11,11,11,11,12,13,12,10,9,9,9,10,10,10,10,11,11,11,11,12,12,12,13,11,10,9,10,10,10,11,11,11,11,11,11,12,12,13,13,11,10,10,10,10,11,11,11,11,12,12,12,12,12,13,13,12,11,11,11,11,11,11,11,12,12,12,12,13,13,12,13,12,11,11,11,11,11,11,12,12,12,12,12,13,13,13,13,1,4,6,7,8,9,9,10,9,10,11,11,12,12,13,13,3,4,6,7,8,8,9,9,9,9,10,10,11,12,12,12,6,6,7,8,9,9,10,10,9,10,10,11,11,12,13,13,7,7,8,9,9,10,10,10,10,11,11,11,11,12,13,13,8,7,9,9,10,10,11,11,10,11,11,12,12,13,13,14,9,8,9,10,10,10,11,11,11,11,12,11,13,13,14,14,9,9,10,10,11,11,11,11,11,12,12,12,13,13,14,14,10,9,10,11,11,11,12,12,12,12,13,13,13,14,16,16,9,8,9,10,10,11,11,12,12,12,12,13,13,14,15,15,10,9,10,10,11,11,11,13,12,13,13,14,14,14,16,15,10,10,10,11,11,12,12,13,12,13,14,13,14,15,16,17,11,10,10,11,12,12,12,12,13,13,13,14,15,15,15,16,11,11,11,12,12,13,12,13,14,14,15,15,15,16,16,16,12,11,12,13,13,13,14,14,14,14,14,15,16,15,16,16,13,12,12,13,13,13,15,14,14,17,15,15,15,17,16,16,12,12,13,14,14,14,15,14,15,15,16,16,19,18,19,16,1,4,6,7,8,9,9,10,9,10,11,11,12,12,13,13,3,4,6,7,8,8,9,9,9,9,10,10,11,12,12,12,6,6,7,8,9,9,10,10,9,10,10,11,11,12,13,13,7,7,8,9,9,10,10,10,10,11,11,11,11,12,13,13,8,7,9,9,10,10,11,11,10,11,11,12,12,13,13,14,9,8,9,10,10,10,11,11,11,11,12,11,13,13,14,14,9,9,10,10,11,11,11,11,11,12,12,12,13,13,14,14,10,9,10,11,11,11,12,12,12,12,13,13,13,14,16,16,9,8,9,10,10,11,11,12,12,12,12,13,13,14,15,15,10,9,10,10,11,11,11,13,12,13,13,14,14,14,16,15,10,10,10,11,11,12,12,13,12,13,14,13,14,15,16,17,11,10,10,11,12,12,12,12,13,13,13,14,15,15,15,16,11,11,11,12,12,13,12,13,14,14,15,15,15,16,16,16,12,11,12,13,13,13,14,14,14,14,14,15,16,15,16,16,13,12,12,13,13,13,15,14,14,17,15,15,15,17,16,16,12,12,13,14,14,14,15,14,15,15,16,16,19,18,19,16,4,3,5,7,8,9,9,9,3,3,4,5,7,7,8,8,5,4,5,6,7,8,7,8,6,5,6,6,7,8,8,8,7,6,7,7,8,8,8,9,8,7,8,8,8,9,8,9,8,7,7,8,8,9,9,10,9,8,8,9,9,9,9,10,4,3,5,7,8,9,9,9,3,3,4,5,7,7,8,8,5,4,5,6,7,8,7,8,6,5,6,6,7,8,8,8,7,6,7,7,8,8,8,9,8,7,8,8,8,9,8,9,8,7,7,8,8,9,9,10,9,8,8,9,9,9,9,10,1,3,2,3,0,0,0,0,2,3,5,7,8,9,8,9,3,3,4,6,8,8,7,8,5,5,6,7,8,9,8,8,7,6,7,9,8,10,8,9,8,8,8,9,9,10,9,10,8,8,9,10,10,11,10,11,8,7,7,8,9,10,10,10,8,7,8,9,10,10,10,10,2,3,5,7,8,9,8,9,3,3,4,6,8,8,7,8,5,5,6,7,8,9,8,8,7,6,7,9,8,10,8,9,8,8,8,9,9,10,9,10,8,8,9,10,10,11,10,11,8,7,7,8,9,10,10,10,8,7,8,9,10,10,10,10,1,3,6,8,9,9,9,10,3,4,6,7,8,9,8,8,6,6,7,8,9,10,9,9,7,7,8,9,10,10,9,10,8,8,9,10,10,10,10,10,9,9,10,10,11,11,10,11,8,8,9,10,10,10,11,11,9,8,9,10,10,11,11,11,1,3,6,8,9,9,9,10,3,4,6,7,8,9,8,8,6,6,7,8,9,10,9,9,7,7,8,9,10,10,9,10,8,8,9,10,10,10,10,10,9,9,10,10,11,11,10,11,8,8,9,10,10,10,11,11,9,8,9,10,10,11,11,11,1,3,2,3,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,248,132,12,0,248,120,12,0,3,0,0,0,88,126,12,0,200,107,12,0,3,0,0,0,56,124,12,0,152,103,12,0,4,0,0,0,24,124,12,0,88,103,12,0,4,0,0,0,248,123,12,0,24,103,12,0,6,0,0,0,168,123,12,0,136,102,12,0,6,0,0,0,88,123,12,0,248,101,12,0,6,0,0,0,8,123,12,0,104,101,12,0,8,0,0,0,128,133,12,0,0,122,12,0,8,0,0,0,0,133,12,0,0,121,12,0,8,0,0,0,120,132,12,0,248,119,12,0,16,0,0,0,120,130,12,0,248,115,12,0,16,0,0,0,120,128,12,0,248,111,12,0,16,0,0,0,120,126,12,0,248,107,12,0,16,0,0,0,88,124,12,0,200,103,12,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,134,12,0,0,123,12,0,3,0,0,0,104,126,12,0,224,107,12,0,3,0,0,0,72,124,12,0,176,103,12,0,4,0,0,0,40,124,12,0,120,103,12,0,4,0,0,0,8,124,12,0,56,103,12,0,6,0,0,0,208,123,12,0,208,102,12,0,6,0,0,0,128,123,12,0,64,102,12,0,6,0,0,0,48,123,12,0,176,101,12,0,8,0,0,0,192,133,12,0,128,122,12,0,8,0,0,0,64,133,12,0,128,121,12,0,8,0,0,0,184,132,12,0,120,120,12,0,16,0,0,0,120,131,12,0,248,117,12,0,16,0,0,0,120,129,12,0,248,113,12,0,16,0,0,0,120,127,12,0,248,109,12,0,16,0,0,0,88,125,12,0,200,105,12,0,0,0,1,0,2,0,3,0,0,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,0,0,13,0,14,1,14,2,14,3,14,4,14,6,14,8,14,10,14,13,15,4,15,5,15,6,15,7,15,8,15,9,15,11,15,13,0,0,1,0,2,0,3,0,0,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,0,0,13,0,14,1,14,2,14,3,14,4,14,6,14,8,14,10,14,13,15,4,15,5,15,6,15,7,15,8,15,9,15,11,15,13,88,216,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,9,0,0,136,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,25,35,0,176,237,34,0,108,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,216,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,3,0,0,0,0,0,0,0,0,0,0,240,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,36,0,112,0,0,0,128,136,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,111,32,0,112,0,0,0,80,119,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,80,1,0,29,0,0,0,14,80,1,0,32,0,0,0,14,80,1,0,33,0,0,0,14,80,1,0,34,0,0,0,46,80,1,0,36,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,40,1,36,0,112,0,0,0,48,118,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,3,3,4,5,0,1,1,2,3,3,4,5,64,66,40,0,16,233,39,0,0,0,0,0,0,0,0,0,72,66,40,0,192,233,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,168,10,35,0,0,0,0,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,24,67,34,0,56,161,33,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,152,36,33,0,56,161,33,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,160,184,32,0,32,92,32,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,80,66,40,0,32,92,32,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,200,233,39,0,192,127,39,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,181,160,247,198,160,66,24,0,1,0,0,0,0,0,128,44,39,0,192,127,39,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,181,160,247,198,160,66,24,0,1,0,0,0,0,0,208,228,38,0,0,159,38,0,32,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,95,64,0,0,0,0,0,192,95,64,24,0,1,0,0,0,0,0,40,99,38,0,0,159,38,0,32,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,95,64,0,0,0,0,0,192,95,64,24,0,1,0,0,0,0,0,224,44,38,0,248,249,37,0,40,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,58,38,0,112,0,0,0,120,138,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,29,155,5,66,213,68,230,128,226,20,29,175,247,87,178,212,128,126,242,202,57,70,149,142,84,38,203,158,70,167,159,165,212,11,48,232,20,17,221,186,47,8,0,32,12,154,102,0,0,0,0,1,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,255,255,255,255,0,0,0,18,102,116,97,98,0,1,0,1,5,83,101,114,105,102,228,8,0,0,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,165,212,11,48,232,20,17,221,186,47,8,0,32,12,154,102,1,0,0,0,121,117,118,50,0,0,0,0,1,0,0,0,121,117,118,115,0,0,0,0,17,0,0,0,50,118,117,121,0,0,0,0,45,0,0,0,114,97,119,32,16,0,0,0,46,0,0,0,76,53,53,53,16,0,0,0,44,0,0,0,76,53,54,53,16,0,0,0,43,0,0,0,66,53,54,53,16,0,0,0,31,0,0,0,98,49,54,103,16,0,0,0,2,0,0,0,114,97,119,32,24,0,0,0,3,0,0,0,50,52,66,71,24,0,0,0,27,0,0,0,114,97,119,32,32,0,0,0,30,0,0,0,66,71,82,65,32,0,0,0,28,0,0,0,82,71,66,65,32,0,0,0,29,0,0,0,65,66,71,82,32,0,0,0,41,0,0,0,98,52,56,114,48,0,0,0,0,0,0,0,56,142,35,0,112,0,0,0,80,119,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,110,103,0,102,114,97,0,103,101,114,0,105,116,97,0,100,117,116,0,115,118,101,0,115,112,97,0,100,97,110,0,112,111,114,0,110,111,114,0,104,101,98,0,106,112,110,0,97,114,97,0,102,105,110,0,103,114,101,0,105,99,101,0,109,108,116,0,116,117,114,0,104,114,32,0,99,104,105,0,117,114,100,0,104,105,110,0,116,104,97,0,107,111,114,0,108,105,116,0,112,111,108,0,104,117,110,0,101,115,116,0,108,97,118,0,0,0,0,0,102,111,32,0,0,0,0,0,114,117,115,0,99,104,105,0,0,0,0,0,105,114,105,0,97,108,98,0,114,111,110,0,99,101,115,0,115,108,107,0,115,108,118,0,121,105,100,0,115,114,32,0,109,97,99,0,98,117,108,0,117,107,114,0,98,101,108,0,117,122,98,0,107,97,122,0,97,122,101,0,97,122,101,0,97,114,109,0,103,101,111,0,109,111,108,0,107,105,114,0,116,103,107,0,116,117,107,0,109,111,110,0,0,0,0,0,112,117,115,0,107,117,114,0,107,97,115,0,115,110,100,0,116,105,98,0,110,101,112,0,115,97,110,0,109,97,114,0,98,101,110,0,97,115,109,0,103,117,106,0,112,97,32,0,111,114,105,0,109,97,108,0,107,97,110,0,116,97,109,0,116,101,108,0,0,0,0,0,98,117,114,0,107,104,109,0,108,97,111,0,118,105,101,0,105,110,100,0,116,103,108,0,109,97,121,0,109,97,121,0,97,109,104,0,116,105,114,0,111,114,109,0,115,111,109,0,115,119,97,0,0,0,0,0,114,117,110,0,0,0,0,0,109,108,103,0,101,112,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,101,108,0,98,97,113,0,99,97,116,0,108,97,116,0,113,117,101,0,103,114,110,0,97,121,109,0,116,97,116,0,117,105,103,0,100,122,111,0,106,97,118,0,0,0,0,0,65,67,76,82,68,1,0,0,65,80,82,71,68,1,0,0,65,65,76,80,68,1,0,0,65,82,69,83,196,1,0,0,97,118,115,115,80,0,0,0,99,104,112,108,128,1,0,0,99,111,54,52,202,1,0,0,99,116,116,115,90,1,0,0,100,105,110,102,172,1,0,0,100,114,101,102,58,1,0,0,101,100,116,115,172,1,0,0,101,108,115,116,138,0,0,0,101,110,100,97,60,1,0,0,102,105,101,108,144,1,0,0,102,116,121,112,148,0,0,0,103,108,98,108,38,1,0,0,104,100,108,114,54,0,0,0,105,108,115,116,92,1,0,0,106,112,50,104,16,0,0,0,109,100,97,116,138,1,0,0,109,100,104,100,78,0,0,0,109,100,105,97,172,1,0,0,109,101,116,97,20,0,0,0,109,105,110,102,172,1,0,0,109,111,111,102,104,1,0,0,109,111,111,118,102,1,0,0,109,118,101,120,172,1,0,0,109,118,104,100,96,1,0,0,83,77,73,32,126,0,0,0,97,108,97,99,52,0,0,0,97,118,99,67,38,1,0,0,112,97,115,112,156,1,0,0,115,116,98,108,172,1,0,0,115,116,99,111,202,1,0,0,115,116,112,115,86,0,0,0,115,116,114,102,100,0,0,0,115,116,115,99,80,1,0,0,115,116,115,100,78,1,0,0,115,116,115,115,82,1,0,0,115,116,115,122,122,0,0,0,115,116,116,115,124,0,0,0,115,116,122,50,122,0,0,0,116,107,104,100,76,0,0,0,116,102,104,100,200,1,0,0,116,114,97,107,68,0,0,0,116,114,97,102,172,1,0,0,116,114,101,102,172,1,0,0,116,109,99,100,6,0,0,0,99,104,97,112,10,0,0,0,116,114,101,120,110,0,0,0,116,114,117,110,244,0,0,0,117,100,116,97,172,1,0,0,119,97,118,101,122,1,0,0,101,115,100,115,52,1,0,0,100,97,99,51,150,0,0,0,100,101,99,51,40,0,0,0,119,105,100,101,132,1,0,0,119,102,101,120,168,1,0,0,99,109,111,118,94,1,0,0,99,104,97,110,8,0,0,0,100,118,99,49,18,1,0,0,115,98,103,112,182,0,0,0,104,118,99,67,38,1,0,0,117,117,105,100,32,0,0,0,67,105,110,142,252,0,0,0,0,0,0,0,0,0,0,0,2,80,1,0,56,149,12,0,3,80,1,0,248,148,12,0,16,80,1,0,208,148,12,0,5,0,1,0,160,148,12,0,4,0,1,0,160,148,12,0,0,0,1,0,160,148,12,0,1,0,1,0,160,148,12,0,12,0,1,0,160,148,12,0,13,0,1,0,160,148,12,0,8,0,1,0,160,148,12,0,9,0,1,0,160,148,12,0,21,0,1,0,160,148,12,0,20,0,1,0,160,148,12,0,23,0,1,0,160,148,12,0,22,0,1,0,160,148,12,0,0,0,0,0,0,0,0,0,240,127,36,0,112,0,0,0,96,124,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,1,0,100,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,101,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,102,0,0,0,0,0,3,1,0,0,0,0,0,0,3,0,131,0,0,0,0,0,51,0,0,0,0,0,0,0,4,0,132,0,0,0,0,0,3,6,0,0,0,0,0,0,4,0,132,0,0,0,0,0,51,0,0,0,0,0,0,0,4,0,108,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,113,0,0,0,0,0,7,1,0,0,0,0,0,0,4,0,115,0,0,0,0,0,55,0,0,0,0,0,0,0,5,0,117,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,117,0,0,0,0,0,63,0,0,0,0,0,0,0,6,0,121,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,121,0,0,0,0,0,63,6,0,0,0,0,0,0,8,0,128,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,126,0,0,0,0,0,63,0,0,96,0,0,0,0,8,0,130,0,0,0,0,0,11,0,0,0,0,0,0,0,3,0,133,0,0,0,0,0,11,1,0,0,0,0,0,0,4,0,134,0,0,0,0,0,59,0,0,0,0,0,0,0,4,0,135,0,0,0,0,0,11,6,0,0,0,0,0,0,4,0,135,0,0,0,0,0,15,0,0,0,0,0,0,0,4,0,136,0,0,0,0,0,15,1,0,0,0,0,0,0,5,0,137,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,0,2,0,101,0,2,0,103,0,3,0,113,0,4,0,108,0,5,0,117,0,6,0,121,0,7,0,125,0,8,0,126,0,8,0,128,0,8,0,130,0,0,0,0,0,1,0,100,0,2,0,101,0,3,0,114,0,4,0,116,0,5,0,120,0,6,0,124,0,7,0,142,0,8,0,127,0,0,0,0,0,0,0,0,0,1,0,100,0,2,0,101,0,2,0,149,0,3,0,150,0,3,0,131,0,3,0,133,0,4,0,151,0,4,0,132,0,4,0,153,0,4,0,152,0,5,0,119,0,5,0,138,0,5,0,154,0,6,0,123,0,0,0,0,0,0,0,0,0,1,0,100,0,2,0,101,0,2,0,149,0,3,0,114,0,3,0,131,0,3,0,133,0,4,0,108,0,4,0,116,0,4,0,132,0,4,0,153,0,4,0,168,0,5,0,120,0,5,0,138,0,5,0,169,0,6,0,124,0,6,0,141,0,6,0,170,0,7,0,142,0,7,0,143,0,7,0,173,0,8,0,144,0,8,0,127,0,8,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,16,0,145,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,146,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,180,0,0,0,0,0,251,6,0,0,0,0,0,0,9,0,181,0,0,0,0,0,207,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,0,0,0,0,0,55,7,0,0,0,0,0,0,8,0,144,0,0,0,0,0,55,7,0,0,0,0,0,0,8,0,112,0,0,0,0,0,51,208,2,0,0,0,0,0,8,0,126,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,127,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,129,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,161,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,177,0,0,0,0,0,207,6,0,0,0,0,0,0,8,0,128,0,0,0,0,0,63,6,0,0,0,0,0,0,8,0,160,0,0,0,0,0,63,6,0,0,0,0,0,0,8,0,130,0,0,0,0,0,15,6,0,96,0,0,0,0,8,0,162,0,0,0,0,0,15,6,0,0,6,0,0,0,8,0,163,0,0,0,0,0,15,6,0,128,1,0,0,0,8,0,164,0,0,0,0,0,15,86,0,0,0,0,0,0,8,0,165,0,0,0,0,0,15,15,0,0,0,0,0,0,8,0,166,0,0,0,0,0,15,39,0,0,0,0,0,0,8,0,167,0,0,0,0,0,15,46,0,0,0,0,0,0,8,0,178,0,0,0,0,0,243,6,0,0,0,0,0,0,8,0,179,0,0,0,0,0,199,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,125,0,0,0,0,0,15,7,0,0,0,0,0,0,7,0,142,0,0,0,0,0,15,7,0,0,0,0,0,0,7,0,157,0,0,0,0,0,15,7,0,0,0,0,0,0,7,0,182,0,0,0,0,0,15,7,0,0,0,0,0,0,7,0,140,0,0,0,0,0,55,6,0,0,0,0,0,0,7,0,143,0,0,0,0,0,55,6,0,0,0,0,0,0,7,0,156,0,0,0,0,0,55,6,0,0,0,0,0,0,7,0,148,0,0,0,0,0,199,6,0,0,0,0,0,0,7,0,176,0,0,0,0,0,199,6,0,0,0,0,0,0,7,0,158,0,0,0,0,0,15,14,0,0,0,0,0,0,7,0,159,0,0,0,0,0,15,38,0,0,0,0,0,0,7,0,173,0,0,0,0,0,203,6,0,0,0,0,0,0,7,0,174,0,0,0,0,0,63,8,0,0,0,0,0,0,7,0,175,0,0,0,0,0,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,110,0,0,0,0,0,55,1,0,0,0,0,0,0,6,0,172,0,0,0,0,0,55,1,0,0,0,0,0,0,6,0,121,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,122,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,123,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,124,0,0,0,0,0,15,6,0,0,0,0,0,0,6,0,139,0,0,0,0,0,7,7,0,0,0,0,0,0,6,0,141,0,0,0,0,0,7,7,0,0,0,0,0,0,6,0,155,0,0,0,0,0,7,7,0,0,0,0,0,0,6,0,170,0,0,0,0,0,195,6,0,0,0,0,0,0,6,0,171,0,0,0,0,0,55,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,109,0,0,0,0,0,55,0,0,0,0,0,0,0,5,0,117,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,118,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,119,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,120,0,0,0,0,0,7,6,0,0,0,0,0,0,5,0,135,0,0,0,0,0,11,6,0,0,0,0,0,0,5,0,138,0,0,0,0,0,11,6,0,0,0,0,0,0,5,0,137,0,0,0,0,0,15,1,0,0,0,0,0,0,5,0,154,0,0,0,0,0,15,1,0,0,0,0,0,0,5,0,169,0,0,0,0,0,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,0,0,0,0,0,51,0,0,0,0,0,0,0,4,0,115,0,0,0,0,0,7,1,0,0,0,0,0,0,4,0,116,0,0,0,0,0,7,1,0,0,0,0,0,0,4,0,151,0,0,0,0,0,7,1,0,0,0,0,0,0,4,0,132,0,0,0,0,0,3,6,0,0,0,0,0,0,4,0,134,0,0,0,0,0,11,1,0,0,0,0,0,0,4,0,153,0,0,0,0,0,11,1,0,0,0,0,0,0,4,0,136,0,0,0,0,0,15,0,0,0,0,0,0,0,4,0,152,0,0,0,0,0,15,0,0,0,0,0,0,0,4,0,168,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,113,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,114,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,150,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,131,0,0,0,0,0,3,1,0,0,0,0,0,0,3,0,133,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,102,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,106,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,104,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,105,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,103,0,0,0,0,0,0,0,0,96,0,0,0,0,2,0,149,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,149,12,0,120,155,12,0,248,154,12,0,152,154,12,0,216,153,12,0,40,153,12,0,104,152,12,0,120,151,12,0,56,150,12,0,8,150,12,0,0,0,255,213,6,213,247,214,13,215,240,216,19,217,233,220,26,222,254,223,4,223,227,224,247,224,11,225,240,227,32,227,18,228,222,230,234,231,255,231,3,231,249,232,8,232,24,233,36,233,244,234,13,235,218,236,0,236,229,237,252,237,4,237,239,238,248,239,8,239,18,239,28,239,39,239,244,241,12,241,235,242,255,242,1,242,215,243,251,243,5,243,21,243,225,244,241,245,248,245,8,245,15,245,254,246,1,246,31,246,233,247,245,247,251,247,4,247,11,247,42,247,6,248,24,248,238,249,249,249,253,249,255,249,2,249,18,249,213,250,243,250,252,250,4,250,8,250,223,251,247,251,254,251,0,251,2,251,5,251,13,251,231,252,250,252,253,252,3,252,9,252,237,253,249,253,252,253,254,253,255,253,0,253,1,253,2,253,4,253,6,253,33,253,242,254,246,254,251,254,253,254,254,254,255,254,0,254,1,254,2,254,3,254,5,254,7,254,14,254,19,254,25], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+816279);
/* memory initializer */ allocate([254,43,254,249,255,253,255,254,255,255,255,0,255,1,255,2,255,3,255,10,255,251,0,253,0,254,0,255,0,1,0,2,0,3,0,5,0,7,0,246,1,249,1,253,1,254,1,255,1,0,1,1,1,2,1,3,1,213,2,231,2,237,2,242,2,251,2,253,2,254,2,255,2,0,2,1,2,2,2,3,2,5,2,7,2,10,2,14,2,223,3,250,3,252,3,254,3,255,3,0,3,1,3,2,3,4,3,19,3,247,4,253,4,3,4,7,4,25,4,243,5,251,5,254,5,0,5,2,5,5,5,9,5,33,5,248,6,252,6,4,6,13,6,43,6,238,7,254,7,0,7,2,7,7,7,18,7,232,8,250,8,214,9,245,9,252,9,5,9,11,9,23,9,225,10,255,10,2,10,241,11,248,11,8,11,15,11,31,12,235,13,251,13,5,13,41,13,255,14,1,14,21,14,244,15,12,15,217,17,228,17,238,17,248,17,8,17,17,18,252,19,0,19,4,19,27,19,38,20,243,21,12,22,220,23,232,23,248,24,7,24,253,25,1,25,22,25,34,26,238,28,224,29,16,29,245,31,9,32,29,32,252,33,2,33,230,34,23,36,237,39,16,40,243,41,9,42,250,43,1,43,0,0,0,0,0,0,0,0,0,3,1,3,2,3,6,4,7,4,8,4,9,4,40,6,41,6,42,6,43,6,44,6,45,6,46,6,47,6,96,7,97,7,98,7,99,7,100,7,101,7,102,7,103,7,104,7,105,7,106,7,107,7,108,7,109,7,110,7,111,7,224,8,225,8,226,8,227,8,228,8,229,8,230,8,231,8,232,8,233,8,234,8,235,8,236,8,237,8,238,8,239,8,240,8,241,8,242,8,243,8,244,8,245,8,246,8,247,8,248,8,249,8,250,8,251,8,252,8,253,8,254,8,255,8,0,0,0,0,0,0,1,0,0,0,255,255,255,255,2,0,0,0,254,255,255,255,3,0,0,0,253,255,255,255,4,0,0,0,252,255,255,255,5,0,0,0,251,255,255,255,6,0,0,0,250,255,255,255,7,0,0,0,249,255,255,255,8,0,0,0,248,255,255,255,9,0,0,0,247,255,255,255,10,0,0,0,246,255,255,255,11,0,0,0,245,255,255,255,12,0,0,0,244,255,255,255,13,0,0,0,243,255,255,255,14,0,0,0,242,255,255,255,15,0,0,0,241,255,255,255,16,0,0,0,240,255,255,255,17,0,0,0,239,255,255,255,18,0,0,0,238,255,255,255,19,0,0,0,237,255,255,255,20,0,0,0,236,255,255,255,21,0,0,0,235,255,255,255,22,0,0,0,234,255,255,255,23,0,0,0,233,255,255,255,24,0,0,0,232,255,255,255,25,0,0,0,231,255,255,255,26,0,0,0,230,255,255,255,27,0,0,0,229,255,255,255,28,0,0,0,228,255,255,255,29,0,0,0,227,255,255,255,30,0,0,0,226,255,255,255,31,0,0,0,225,255,255,255,0,0,0,0,252,252,254,252,0,252,2,252,252,254,252,0,253,253,255,253,1,253,3,253,253,255,254,254,0,254,2,254,4,254,254,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,1,0,0,0,74,97,110,0,70,101,98,0,77,97,114,0,65,112,114,0,77,97,121,0,74,117,110,0,74,117,108,0,65,117,103,0,83,101,112,0,79,99,116,0,78,111,118,0,68,101,99,0,0,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,0,0,1,2,4,5,6,8,9,10,16,17,18,20,21,22,24,25,26,32,33,34,36,37,38,40,41,42,64,65,66,68,69,70,72,73,74,80,81,82,84,85,86,88,89,90,96,97,98,100,101,102,104,105,106,128,129,130,132,133,134,136,137,138,144,145,146,148,149,150,152,153,154,160,161,162,164,165,166,168,169,170,192,193,194,196,197,198,200,201,202,208,209,210,212,213,214,216,217,218,224,225,226,228,229,230,232,233,234,0,0,0,0,56,248,35,0,160,0,2,1,0,0,0,0,10,1,7,8,7,7,7,9,6,0,0,0,4,4,5,4,5,4,5,4,5,4,5,5,216,1,35,0,152,0,3,1,205,204,76,63,3,0,6,7,7,7,5,8,5,5,0,0,0,9,9,9,0,0,0,0,0,0,0,7,184,58,34,0,232,0,3,2,205,204,76,63,3,0,6,7,7,7,5,8,5,5,0,0,0,5,5,5,0,0,0,0,0,0,0,7,48,153,33,0,40,1,5,2,154,153,89,63,1,0,6,7,7,7,5,8,5,8,5,5,0,10,0,0,0,0,0,0,0,0,0,7,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,192,0,0,0,208,0,0,0,224,0,0,0,0,1,0,0,32,1,0,0,64,1,0,0,96,1,0,0,128,1,0,0,160,1,0,0,192,1,0,0,224,1,0,0,32,2,0,0,96,2,0,0,160,2,0,0,224,2,0,0,32,3,0,0,96,3,0,0,160,3,0,0,224,3,0,0,96,4,0,0,224,4,0,0,96,5,0,0,224,5,0,0,96,6,0,0,224,6,0,0,96,7,0,0,224,7,0,0,224,8,0,0,224,9,0,0,224,10,0,0,224,11,0,0,224,12,0,0,224,13,0,0,224,14,0,0,224,15,0,0,224,17,0,0,224,19,0,0,224,21,0,0,224,23,0,0,224,25,0,0,224,27,0,0,224,29,0,0,224,31,0,0,224,35,0,0,224,39,0,0,224,43,0,0,224,47,0,0,224,51,0,0,224,55,0,0,224,59,0,0,224,63,0,0,224,71,0,0,224,79,0,0,224,87,0,0,224,95,0,0,224,103,0,0,224,111,0,0,224,119,0,0,224,127,0,0,224,143,0,0,224,159,0,0,224,175,0,0,224,191,0,0,224,207,0,0,224,223,0,0,224,239,0,0,224,255,0,0,224,31,1,0,224,63,1,0,224,95,1,0,224,127,1,0,224,159,1,0,224,191,1,0,224,223,1,0,224,255,1,0,224,63,2,0,224,127,2,0,224,191,2,0,224,255,2,0,224,63,3,0,224,127,3,0,224,191,3,0,0,0,1,0,198,23,0,0,198,21,0,0,155,20,0,0,199,19,0,0,35,19,0,0,156,18,0,0,43,18,0,0,201,17,0,0,37,17,0,0,159,16,0,0,46,16,0,0,204,15,0,0,118,15,0,0,41,15,0,0,227,14,0,0,164,14,0,0,51,14,0,0,210,13,0,0,125,13,0,0,48,13,0,0,235,12,0,0,172,12,0,0,114,12,0,0,61,12,0,0,221,11,0,0,136,11,0,0,61,11,0,0,249,10,0,0,187,10,0,0,130,10,0,0,78,10,0,0,29,10,0,0,197,9,0,0,119,9,0,0,49,9,0,0,242,8,0,0,184,8,0,0,131,8,0,0,82,8,0,0,36,8,0,0,209,7,0,0,136,7,0,0,70,7,0,0,10,7,0,0,212,6,0,0,162,6,0,0,115,6,0,0,72,6,0,0,250,5,0,0,180,5,0,0,118,5,0,0,62,5,0,0,10,5,0,0,219,4,0,0,175,4,0,0,135,4,0,0,62,4,0,0,253,3,0,0,195,3,0,0,143,3,0,0,96,3,0,0,53,3,0,0,13,3,0,0,233,2,0,0,168,2,0,0,111,2,0,0,62,2,0,0,18,2,0,0,234,1,0,0,199,1,0,0,168,1,0,0,139,1,0,0,89,1,0,0,48,1,0,0,13,1,0,0,239,0,0,0,213,0,0,0,190,0,0,0,171,0,0,0,154,0,0,0,126,0,0,0,104,0,0,0,87,0,0,0,73,0,0,0,61,0,0,0,52,0,0,0,44,0,0,0,38,0,0,0,28,0,0,0,21,0,0,0,16,0,0,0,12,0,0,0,10,0,0,0,8,0,0,0,6,0,0,0,5,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,21,0,0,0,24,0,0,0,26,0,0,0,29,0,0,0,31,0,0,0,34,0,0,0,36,0,0,0,39,0,0,0,44,0,0,0,49,0,0,0,54,0,0,0,59,0,0,0,64,0,0,0,69,0,0,0,73,0,0,0,78,0,0,0,88,0,0,0,97,0,0,0,106,0,0,0,115,0,0,0,124,0,0,0,133,0,0,0,142,0,0,0,151,0,0,0,167,0,0,0,184,0,0,0,200,0,0,0,215,0,0,0,231,0,0,0,245,0,0,0,4,1,0,0,18,1,0,0,45,1,0,0,71,1,0,0,95,1,0,0,119,1,0,0,141,1,0,0,162,1,0,0,183,1,0,0,202,1,0,0,239,1,0,0,16,2,0,0,47,2,0,0,75,2,0,0,101,2,0,0,125,2,0,0,147,2,0,0,168,2,0,0,205,2,0,0,237,2,0,0,9,3,0,0,33,3,0,0,55,3,0,0,74,3,0,0,91,3,0,0,106,3,0,0,131,3,0,0,151,3,0,0,168,3,0,0,181,3,0,0,192,3,0,0,201,3,0,0,209,3,0,0,215,3,0,0,226,3,0,0,233,3,0,0,238,3,0,0,242,3,0,0,245,3,0,0,247,3,0,0,249,3,0,0,250,3,0,0,252,3,0,0,254,3,0,0,254,3,0,0,255,3,0,0,255,3,0,0,255,3,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,1,2,2,6,3,14,4,30,5,62,6,126,7,127,7,0,0,0,0,17,0,0,0,2,0,0,0,18,0,0,0,4,0,0,0,19,0,0,0,8,0,0,0,255,255,255,127,0,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,0,0,0,0,10,0,0,0,2,0,0,0,12,0,0,0,4,0,0,0,255,255,255,127,0,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,15,0,0,0,8,0,0,0,4,0,0,0,9,0,0,0,15,0,0,0,255,255,255,127,0,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,7,0,0,0,8,0,0,0,2,0,0,0,9,0,0,0,7,0,0,0,255,255,255,127,0,0,0,0,6,0,0,0,4,0,0,0,7,0,0,0,0,0,0,0,10,0,0,0,4,0,0,0,17,0,0,0,8,0,0,0,18,0,0,0,16,0,0,0,19,0,0,0,32,0,0,0,255,255,255,127,0,0,0,0,17,0,0,0,2,0,0,0,18,0,0,0,4,0,0,0,19,0,0,0,8,0,0,0,255,255,255,127,0,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,0,0,0,0,10,0,0,0,2,0,0,0,17,0,0,0,4,0,0,0,18,0,0,0,8,0,0,0,19,0,0,0,16,0,0,0,255,255,255,127,16,0,0,0,248,218,29,0,10,0,0,0,8,160,7,0,1,6,0,0,168,227,7,0,40,235,7,0,15,0,0,0,4,0,0,0,96,220,29,0,20,0,0,0,8,155,7,0,2,6,0,0,168,213,7,0,168,220,7,0,14,0,0,0,1,0,0,0,232,222,29,0,40,0,0,0,8,150,7,0,4,6,0,0,168,199,7,0,168,206,7,0,14,0,0,0,0,8,20,0,8,174,7,0,1,6,4,4,8,165,7,0,9,84,54,7,176,1,0,0,16,0,0,0,248,218,29,0,10,0,0,0,8,160,7,0,1,6,0,0,8,132,7,0,8,141,7,0,18,0,0,0,4,0,0,0,96,220,29,0,20,0,0,0,8,155,7,0,2,6,0,0,8,115,7,0,136,123,7,0,17,0,0,0,1,0,0,0,232,222,29,0,40,0,0,0,8,150,7,0,4,6,0,0,8,98,7,0,136,106,7,0,17,0,0,0,0,8,20,0,8,174,7,0,1,6,4,4,8,165,7,0,9,84,54,7,176,1,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,4,0,0,0,64,219,29,0,10,0,0,0,136,29,7,0,1,6,0,0,8,87,7,0,136,92,7,0,11,0,0,0,2,0,0,0,40,221,29,0,20,0,0,0,136,24,7,0,2,6,0,0,8,76,7,0,136,81,7,0,11,0,0,0,1,0,0,0,200,223,29,0,32,0,0,0,136,20,7,0,4,6,0,0,8,64,7,0,8,70,7,0,12,0,0,0,0,2,16,0,136,43,7,0,1,6,4,4,136,34,7,0,9,56,36,7,72,0,0,0,8,0,0,0,64,219,29,0,10,0,0,0,8,198,6,0,1,6,0,0,136,5,7,0,8,13,7,0,15,0,0,0,2,0,0,0,216,220,29,0,20,0,0,0,8,193,6,0,2,6,0,0,136,247,6,0,136,254,6,0,14,0,0,0,1,0,0,0,8,224,29,0,32,0,0,0,8,189,6,0,4,6,0,0,136,232,6,0,8,240,6,0,15,0,0,0,0,4,16,0,8,212,6,0,1,6,4,3,8,203,6,0,9,56,36,7,144,0,0,0,8,0,0,0,64,219,29,0,10,0,0,0,8,198,6,0,1,6,0,0,8,171,6,0,8,180,6,0,18,0,0,0,2,0,0,0,216,220,29,0,20,0,0,0,8,193,6,0,2,6,0,0,8,154,6,0,136,162,6,0,17,0,0,0,1,0,0,0,8,224,29,0,32,0,0,0,8,189,6,0,4,6,0,0,8,136,6,0,8,145,6,0,18,0,0,0,0,4,16,0,8,212,6,0,1,6,4,3,8,203,6,0,9,56,36,7,144,0,0,0,8,0,0,0,136,219,29,0,10,0,0,0,168,49,6,0,1,5,0,0,8,120,6,0,8,128,6,0,16,0,0,0,2,0,0,0,120,221,29,0,20,0,0,0,40,47,6,0,2,5,0,0,8,105,6,0,136,112,6,0,15,0,0,0,1,0,0,0,200,224,29,0,30,0,0,0,40,42,6,0,3,6,0,0,8,89,6,0,8,97,6,0,16,0,0,0,0,4,16,0,40,67,6,0,1,6,4,3,40,52,6,0,9,56,60,7,180,0,0,0,8,0,0,0,208,219,29,0,10,0,0,0,40,206,5,0,1,5,0,0,40,21,6,0,168,31,6,0,21,0,0,0,2,0,0,0,248,221,29,0,20,0,0,0,168,203,5,0,2,5,0,0,40,3,6,0,40,12,6,0,18,0,0,0,1,0,0,0,136,225,29,0,30,0,0,0,168,198,5,0,3,6,0,0,40,239,5,0,40,249,5,0,20,0,0,0,0,2,16,0,168,218,5,0,1,6,4,3,168,208,5,0,9,36,30,7,90,0,0,0,8,0,0,0,208,219,29,0,10,0,0,0,40,206,5,0,1,5,0,0,168,169,5,0,40,184,5,0,29,0,0,0,2,0,0,0,248,221,29,0,20,0,0,0,168,203,5,0,2,5,0,0,168,145,5,0,168,157,5,0,24,0,0,0,1,0,0,0,136,225,29,0,30,0,0,0,168,198,5,0,3,6,0,0,168,118,5,0,40,132,5,0,27,0,0,0,0,2,16,0,168,218,5,0,1,6,4,3,168,208,5,0,9,36,30,7,90,0,0,0,8,0,0,0,248,219,29,0,10,0,0,0,40,55,5,0,1,5,0,0,168,84,5,0,168,93,5,0,18,0,0,0,2,0,0,0,64,222,29,0,20,0,0,0,168,52,5,0,2,5,0,0,168,102,5,0,168,110,5,0,16,0,0,0,1,0,0,0,248,225,29,0,30,0,0,0,168,47,5,0,3,6,0,0,168,67,5,0,40,76,5,0,17,0,0,0,0,2,12,0,200,39,5,0,1,5,3,3,168,57,5,0,8,28,20,6,40,0,0,0,35,33,105,76,66,67,51,48,10,0,0,0,0,0,0,0,0,0,102,2,198,4,2,7,106,9,198,11,2,14,106,16,184,18,6,21,78,23,142,25,226,27,36,30,100,32,160,34,228,36,46,39,146,41,204,43,38,46,0,0,0,0,0,0,35,33,105,76,66,67,50,48,10,0,0,0,0,0,0,0,5,0,1,2,3,4,5,0,23,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,0,0,0,0,160,15,0,0,64,31,0,0,17,43,0,0,34,86,0,0,68,172,0,0,0,0,0,0,16,20,24,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,3,4,5,3,4,5,4,5,6,4,5,4,5,6,5,5,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,202,154,59,136,170,39,0,112,0,0,0,240,124,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,108,33,0,112,0,0,0,112,168,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,148,37,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,100,59,223,79,141,151,250,63,104,145,237,124,63,53,244,191,106,222,113,138,142,228,222,63,134,201,84,193,168,164,210,191,151,255,144,126,251,58,192,63,188,5,18,20,63,198,188,191,17,141,238,32,118,166,160,63,99,238,90,66,62,232,137,191,9,167,5,47,250,10,162,191,232,101,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,10,0,0,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,158,32,0,104,67,32,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,153,153,153,201,65,16,0,1,0,0,0,0,0,232,42,40,0,240,205,39,0,16,0,0,0,84,77,70,80,43,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,223,35,0,112,0,0,0,192,174,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,138,139,184,73,176,128,76,173,207,88,152,152,94,34,193,108,23,95,69,6,75,206,71,154,239,140,174,247,61,247,181,32,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,227,118,42,247,10,235,208,17,172,228,0,0,192,204,22,186,121,133,159,74,248,107,146,67,138,109,210,221,9,250,120,97,129,235,54,228,79,82,206,17,159,83,0,32,175,11,167,112,195,203,255,52,179,213,113,65,144,2,212,198,3,1,105,127,170,221,42,245,240,54,245,67,149,234,109,134,100,132,38,42,23,182,6,62,164,136,124,62,195,45,223,62,165,248,36,63,91,235,83,63,195,73,130,63,226,117,153,63,72,136,176,63,195,244,199,63,0,83,222,63,123,105,248,63,21,114,8,64,231,55,22,64,154,96,33,64,149,241,45,64,93,54,54,64,45,36,152,62,234,148,231,62,19,244,67,63,58,65,145,63,109,231,181,63,153,12,227,63,167,37,3,64,250,14,24,64,59,114,37,64,246,37,155,61,7,7,8,0,0,0,0,0,8,10,38,0,112,0,0,0,192,110,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,83,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,37,0,80,199,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,128,17,37,0,208,219,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,128,17,37,0,104,26,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,128,17,37,0,16,127,33,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,128,17,37,0,112,4,33,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,128,17,37,0,0,159,32,0,200,67,32,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,159,32,0,144,43,40,0,152,206,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,0,159,32,0,96,102,39,0,56,23,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,0,159,32,0,200,210,38,0,16,142,38,0,12,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,83,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,1,0,0,0,0,0,0,0,0,0,0,54,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,35,0,112,0,0,0,24,177,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,192,0,179,0,166,0,153,0,140,0,128,0,115,0,102,0,89,0,76,0,64,0,51,0,38,0,25,0,12,0,0,0,244,255,231,255,218,255,205,255,192,255,180,255,167,255,154,255,141,255,128,255,116,255,103,255,90,255,77,255,64,255,1,3,4,6,0,0,0,0,0,0,0,0,11,0,0,0,12,0,0,0,15,0,0,0,1,0,0,0,0,0,0,0,8,7,6,5,4,3,2,1,7,7,0,0,0,0,0,1,6,0,6,0,0,0,2,0,5,0,0,5,0,3,0,0,4,0,0,0,4,0,0,0,3,0,0,5,0,3,0,0,2,0,6,0,0,0,2,0,1,7,0,0,0,0,0,1,0,1,0,0,2,4,2,0,0,1,0,0,15,0,0,0,0,1,1,1,1,1,1,1,17,18,18,18,18,18,18,18,4,5,204,204,204,204,204,65,21,22,204,204,204,204,204,82,4,204,5,204,204,204,65,204,21,204,22,204,204,204,82,204,4,204,204,5,204,65,204,204,21,204,204,22,204,82,204,204,4,204,204,204,65,204,204,204,21,204,204,204,22,204,204,204,4,204,204,65,204,5,204,204,21,204,204,82,204,22,204,204,4,204,65,204,204,204,5,204,21,204,82,204,204,204,22,204,4,65,204,204,204,204,204,5,21,82,204,204,204,204,204,22,68,69,69,69,69,69,69,69,85,86,86,86,86,86,86,86,72,73,204,204,204,204,204,133,89,90,204,204,204,204,204,150,72,204,73,204,204,204,133,204,89,204,90,204,204,204,150,204,72,204,204,73,204,133,204,204,89,204,204,90,204,150,204,204,72,204,204,204,73,204,204,204,89,204,204,204,150,204,204,204,72,204,204,133,204,73,204,204,89,204,204,150,204,90,204,204,72,204,133,204,204,204,73,204,89,204,150,204,204,204,90,204,72,133,204,204,204,204,204,73,89,150,204,204,204,204,204,90,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,1,4,5,8,9,12,13,2,3,6,7,10,11,14,15,0,1,4,5,2,3,6,7,8,9,12,13,10,11,14,15,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,8,8,4,1,0,0,0,0,4,8,12,10,6,14,16,18,20,5,9,13,11,7,15,17,19,21,1,255,255,255,2,255,255,255,3,0,0,0,0,0,4,8,12,10,6,14,16,18,20,5,9,13,11,7,15,17,19,21,1,255,255,255,2,255,255,255,3,0,0,0,0,0,0,241,0,0,8,240,0,0,8,192,0,0,8,48,0,0,1,0,0,0,6,0,0,0,21,0,0,0,43,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,111,15,9,0,170,44,2,0,111,15,9,0,170,44,2,0,3,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,0,0,0,0,171,170,42,63,0,0,0,0,255,255,255,127,0,0,0,0,174,0,0,0,6,0,0,0,40,1,0,0,56,1,0,0,40,187,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,131,35,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,84,0,0,1,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,255,255,255,255,186,84,0,0,1,0,0,0,0,0,0,0,16,0,0,0,255,255,255,255,255,255,255,255,176,0,0,0,1,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,186,0,0,0,1,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,36,181,46,0,5,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,184,83,0,0,1,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,192,83,0,0,1,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,170,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,221,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,179,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,229,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,128,186,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,98,0,0,6,0,0,0,64,0,0,0,0,1,0,0,240,185,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,225,71,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,71,0,0,5,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,231,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,229,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,66,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,66,0,0,5,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,80,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,51,80,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,52,80,0,0,6,0,0,0,0,0,0,0,16,0,0,0,168,185,12,0,0,0,0,0,53,80,0,0,6,0,0,0,0,0,0,0,40,0,0,0,232,184,12,0,0,0,0,0,49,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,0,0,0,6,0,0,0,16,0,0,0,0,0,0,0,64,184,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,181,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,191,64,181,120,0,0,2,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,100,98,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,159,0,0,0,1,0,0,0,0,0,0,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,215,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,83,0,0,4,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,197,115,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,134,0,0,0,3,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,162,99,0,0,5,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,156,181,34,0,4,0,0,0,0,0,0,0,48,0,0,0,192,126,36,0,0,0,0,0,131,227,35,0,1,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,79,49,35,0,2,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,240,63,136,0,0,0,1,0,0,0,0,0,0,0,72,0,0,0,1,0,0,0,0,0,0,0,170,85,0,0,1,0,0,0,0,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,6,0,0,0,0,0,0,0,104,0,0,0,192,182,12,0,0,0,0,0,225,0,0,0,6,0,0,0,0,0,0,0,176,0,0,0,176,186,12,0,0,0,0,0,226,0,0,0,6,0,0,0,0,0,0,0,248,0,0,0,136,184,12,0,0,0,0,0,128,109,0,0,6,0,0,0,0,0,0,0,0,0,0,0,184,184,12,0,0,0,0,0,238,85,0,0,1,0,0,0,0,0,0,0,32,1,0,0,0,0,0,0,0,0,0,0,170,86,0,0,1,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,187,86,0,0,1,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,185,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,134,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,64,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,178,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,99,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,104,0,0,1,0,0,0,0,0,0,0,8,0,0,0,50,0,0,0,0,0,0,0,197,99,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,196,99,0,0,1,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,198,99,0,0,1,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,115,0,0,6,0,0,0,48,0,0,0,88,1,0,0,112,190,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,103,0,0,6,0,0,0,32,0,0,0,40,0,0,0,184,190,12,0,0,0,0,0,192,99,0,0,6,0,0,0,0,0,0,0,0,0,0,0,176,189,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,69,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,68,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,122,68,0,0,3,0,0,0,0,0,0,0,8,0,0,0,224,153,36,0,0,0,0,0,132,68,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,180,68,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,200,103,0,0,6,0,0,0,32,0,0,0,24,0,0,0,184,190,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,128,83,24,6,0,0,0,0,0,0,0,0,0,0,0,144,191,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,169,73,21,6,0,0,0,0,0,0,0,0,0,0,0,240,192,12,0,0,0,0,0,107,174,84,22,6,0,0,0,0,0,0,0,0,0,0,0,144,182,12,0,0,0,0,0,105,164,65,25,6,0,0,0,0,0,0,0,0,0,0,0,104,201,12,0,0,0,0,0,112,167,67,16,6,0,0,0,0,0,0,0,0,0,0,0,56,198,12,0,0,0,0,0,107,187,83,28,6,0,0,0,0,0,0,0,0,0,0,0,136,194,12,0,0,0,0,0,103,195,84,18,6,0,0,0,0,0,0,0,0,0,0,0,64,190,12,0,0,0,0,0,116,155,77,17,6,0,0,0,0,0,0,0,0,0,0,0,176,192,12,0,0,0,0,0,117,182,67,31,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,83,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,83,0,0,1,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,77,0,0,6,0,0,0,16,0,0,0,96,1,0,0,104,192,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,25,0,0,48,33,0,0,136,19,0,0,128,62,0,0,177,215,42,0,1,0,0,0,0,0,0,0,16,1,0,0,64,66,15,0,0,0,0,0,137,68,0,0,2,0,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,169,123,0,0,4,0,0,0,0,0,0,0,32,1,0,0,0,0,0,0,0,0,0,0,65,87,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,77,0,0,4,0,0,0,0,0,0,0,36,1,0,0,0,0,0,0,0,0,0,0,97,68,0,0,5,0,0,0,0,0,0,0,40,1,0,0,0,0,0,0,0,0,0,0,164,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,241,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,179,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,183,0,0,0,6,0,0,0,16,0,0,0,8,0,0,0,176,193,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,0,0,0,6,0,0,0,16,0,0,0,80,1,0,0,64,194,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,103,33,0,144,92,33,0,117,182,67,31,6,0,0,0,0,0,0,0,0,0,0,0,232,196,12,0,0,0,0,0,102,169,73,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,187,83,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,195,84,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,155,77,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,182,67,31,6,0,0,0,0,0,0,0,0,0,0,0,120,197,12,0,0,0,0,0,102,169,73,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,187,83,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,195,84,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,155,77,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,0,0,0,6,0,0,0,72,0,0,0,8,0,0,0,96,200,12,0,0,0,0,0,163,0,0,0,7,0,0,0,72,0,0,0,8,0,0,0,96,200,12,0,0,0,0,0,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,169,73,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,187,83,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,195,84,18], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+826519);
/* memory initializer */ allocate([116,155,77,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,182,67,31,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,0,0,0,6,0,0,0,72,0,0,0,8,0,0,0,96,200,12,0,0,0,0,0,163,0,0,0,7,0,0,0,72,0,0,0,8,0,0,0,96,200,12,0,0,0,0,0,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,233,32,0,112,0,0,0,240,124,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,185,69,0,0,6,0,0,0,0,0,0,0,0,0,0,0,136,199,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,146,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,128,196,115,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,64,199,12,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,195,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,4,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,124,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,6,0,0,0,32,0,0,0,72,1,0,0,104,198,12,0,0,0,0,0,188,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,189,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,219,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,221,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,0,0,0,1,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,165,0,0,0,5,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,0,0,0,5,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,161,117,0,0,6,0,0,0,0,0,0,0,0,0,0,0,56,201,12,0,0,0,0,0,163,0,0,0,5,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,155,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,117,0,0,9,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,251,0,0,0,9,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,166,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,24,200,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,167,97,0,0,6,0,0,0,40,0,0,0,64,1,0,0,152,201,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,70,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,70,0,0,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,96,70,0,0,3,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,92,70,0,0,5,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,126,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,187,33,0,152,160,33,0,32,133,33,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,1,0,2,0,16,0,32,0,4,0,8,0,64,0,128,0,0,1,0,2,0,16,0,32,0,4,0,8,0,64,0,128,255,0,0,0,85,0,0,0,17,0,0,0,1,0,0,0,0,0,1,0,3,0,7,0,15,0,31,0,63,0,127,0,255,0,255,1,255,3,255,7,255,15,255,31,255,63,255,127,255,255,0,0,0,0,0,0,4,0,0,0,1,0,0,0,2,0,0,0,0,2,0,0,0,4,0,0,8,0,0,0,0,1,0,0,16,0,0,0,32,0,0,0,0,2,0,0,0,4,0,0,64,0,0,0,128,0,0,0,0,16,0,0,0,32,0,0,0,64,0,0,8,0,0,0,64,0,0,0,128,0,0,0,0,8,0,0,0,16,0,0,0,64,0,0,0,0,1,0,0,128,0,0,0,0,2,0,0,1,0,0,16,0,0,0,32,0,0,0,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,62,255,255,255,63,52,53,54,55,56,57,58,59,60,61,255,255,255,254,255,255,255,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,255,255,255,255,255,255,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,1,0,255,1,0,255,0,1,1,1,255,255,1,255,255,0,0,0,0,0,0,0,1,254,255,0,0,0,0,112,102,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,1,0,0,14,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,218,36,0,232,168,35,0,4,0,0,0,69,90,73,83,24,200,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,192,7,34,0,232,168,35,0,4,0,0,0,69,90,73,83,24,200,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,88,114,33,0,0,250,32,0,12,0,0,0,84,65,82,86,240,150,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,88,59,32,0,0,250,32,0,12,0,0,0,84,65,82,86,240,150,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,8,34,40,0,56,193,39,0,32,0,0,0,1,0,0,0,21,28,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,56,93,39,0,120,15,39,0,40,0,0,0,3,0,0,0,190,60,214,67,238,203,231,191,0,0,0,0,0,0,89,192,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,136,204,38,0,80,136,38,0,48,0,0,0,3,0,0,0,174,233,169,213,171,223,192,191,0,0,0,0,0,0,89,192,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,0,77,38,0,72,22,38,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,232,235,37,0,192,190,37,0,64,0,0,0,3,0,0,0,51,51,51,51,51,51,211,63,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,176,157,37,0,248,108,37,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,121,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,72,45,37,0,32,6,37,0,80,0,0,0,3,0,0,0,0,0,0,0,0,0,36,64,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,160,219,36,0,72,188,36,0,120,0,0,0,3,0,0,0,123,20,174,71,225,122,132,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,8,159,36,0,192,131,36,0,128,0,0,0,3,0,0,0,141,40,237,13,190,48,137,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,192,105,36,0,136,77,36,0,136,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,56,54,36,0,8,16,36,0,88,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,56,54,36,0,96,218,35,0,56,192,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,56,54,36,0,56,169,35,0,24,147,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,56,54,36,0,104,125,35,0,120,102,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,56,54,36,0,128,84,35,0,88,67,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,56,54,36,0,160,49,35,0,112,17,35,0,92,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,160,49,35,0,96,233,34,0,56,215,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,160,49,35,0,104,200,34,0,8,184,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,160,49,35,0,80,165,34,0,176,147,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,160,49,35,0,72,134,34,0,208,118,34,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,160,49,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,196,34,0,112,0,0,0,184,204,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,0,0,0,197,0,0,0,199,0,0,0,201,0,0,0,209,0,0,0,214,0,0,0,220,0,0,0,225,0,0,0,224,0,0,0,226,0,0,0,228,0,0,0,227,0,0,0,229,0,0,0,231,0,0,0,233,0,0,0,232,0,0,0,234,0,0,0,235,0,0,0,237,0,0,0,236,0,0,0,238,0,0,0,239,0,0,0,241,0,0,0,243,0,0,0,242,0,0,0,244,0,0,0,246,0,0,0,245,0,0,0,250,0,0,0,249,0,0,0,251,0,0,0,252,0,0,0,32,32,0,0,176,0,0,0,162,0,0,0,163,0,0,0,167,0,0,0,34,32,0,0,182,0,0,0,223,0,0,0,174,0,0,0,169,0,0,0,34,33,0,0,180,0,0,0,168,0,0,0,96,34,0,0,198,0,0,0,216,0,0,0,30,34,0,0,177,0,0,0,100,34,0,0,101,34,0,0,165,0,0,0,181,0,0,0,2,34,0,0,17,34,0,0,15,34,0,0,192,3,0,0,43,34,0,0,170,0,0,0,186,0,0,0,169,3,0,0,230,0,0,0,248,0,0,0,191,0,0,0,161,0,0,0,172,0,0,0,26,34,0,0,146,1,0,0,72,34,0,0,6,34,0,0,171,0,0,0,187,0,0,0,38,32,0,0,160,0,0,0,192,0,0,0,195,0,0,0,213,0,0,0,82,1,0,0,83,1,0,0,19,32,0,0,20,32,0,0,28,32,0,0,29,32,0,0,24,32,0,0,25,32,0,0,247,0,0,0,202,37,0,0,255,0,0,0,120,1,0,0,68,32,0,0,172,32,0,0,57,32,0,0,58,32,0,0,1,251,0,0,2,251,0,0,33,32,0,0,183,0,0,0,26,32,0,0,30,32,0,0,48,32,0,0,194,0,0,0,202,0,0,0,193,0,0,0,203,0,0,0,200,0,0,0,205,0,0,0,206,0,0,0,207,0,0,0,204,0,0,0,211,0,0,0,212,0,0,0,255,248,0,0,210,0,0,0,218,0,0,0,219,0,0,0,217,0,0,0,49,1,0,0,198,2,0,0,220,2,0,0,175,0,0,0,216,2,0,0,217,2,0,0,218,2,0,0,184,0,0,0,221,2,0,0,219,2,0,0,199,2,0,0,195,21,143,18,225,10,20,6,80,133,36,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,255,1,0,2,2,0,1,2,255,2,2,1,254,1,2,2,254,2,0,3,3,0,1,3,255,3,3,1,253,1,2,3,254,3,3,2,253,2,0,4,4,0,1,4,255,4,4,1,252,1,3,3,253,3,2,4,254,4,4,2,252,2,0,5,3,4,253,4,4,3,252,3,5,0,1,5,255,5,5,1,251,1,2,5,254,5,5,2,251,2,4,4,252,4,3,5,253,5,5,3,251,3,0,6,6,0,1,6,255,6,6,1,250,1,2,6,254,6,6,2,250,2,4,5,252,5,5,4,251,4,3,6,253,6,6,3,250,3,0,7,7,0,1,7,255,7,5,5,251,5,7,1,249,1,4,6,252,6,6,4,250,4,2,7,254,7,7,2,249,2,3,7,253,7,7,3,249,3,5,6,251,6,6,5,250,5,8,0,4,7,252,7,7,4,249,4,8,1,8,2,6,6,250,6,8,3,5,7,251,7,7,5,249,5,8,4,6,7,250,7,7,6,249,6,8,5,7,7,249,7,8,6,8,7,8,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,25,0,0,0,4,0,0,0,25,0,0,0,5,0,0,0,25,0,0,0,6,0,0,0,14,0,0,0,7,0,0,0,14,0,0,0,8,0,0,0,2,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,208,26,37,0,112,0,0,0,192,136,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,225,34,0,112,0,0,0,192,136,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,152,50,36,0,112,0,0,0,192,136,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,28,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,82,34,0,224,41,34,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,160,32,0,224,68,32,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,192,44,40,0,176,207,39,0,80,103,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,44,40,0,0,24,39,0,104,211,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,44,40,0,192,142,38,0,176,83,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,44,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,28,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,0,0,0,0,0,0,136,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,17,36,0,112,0,0,0,48,214,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,11,10,16,24,40,51,61,12,12,14,19,26,58,60,55,14,13,16,24,40,57,69,56,14,17,22,29,51,87,80,62,18,22,37,56,68,109,103,77,24,35,55,64,81,104,113,92,49,64,78,87,103,121,120,101,72,92,95,98,112,100,103,99,8,6,5,8,12,20,26,31,6,6,7,10,13,29,30,28,7,7,8,12,20,29,35,28,7,9,11,15,26,44,40,31,9,11,19,28,34,55,52,39,12,18,28,32,41,52,57,46,25,32,39,44,52,61,60,51,36,46,48,49,56,50,52,50,0,16,32,128,48,64,80,96,144,160,176,192,112,208,224,240,252,253,254,255,1,2,3,4,0,8,16,24,32,40,48,56,64,70,76,82,88,92,96,100,217,33,18,63,109,85,50,63,8,33,80,63,56,75,105,63,104,34,124,63,192,176,136,63,176,232,152,63,219,76,175,63,30,26,21,15,8,0,248,241,235,230,0,0,0,0,0,0,48,117,144,101,8,82,152,58,64,31,0,0,192,224,104,197,248,173,112,154,0,0,0,0,0,0,0,0,0,0,0,0,89,2,0,2,226,253,78,1,172,1,63,4,28,254,124,255,140,2,110,2,121,254,196,253,122,1,31,3,141,0,164,252,16,4,153,1,112,0,214,253,99,4,158,2,181,255,177,252,141,5,238,1,197,254,185,251,19,3,233,3,114,0,52,254,220,3,136,6,216,0,87,253,239,3,217,4,124,255,33,251,49,4,143,1,186,0,251,255,238,4,193,0,74,253,127,255,69,1,196,0,51,0,127,253,93,3,197,255,94,1,54,254,237,4,55,2,74,2,166,254,252,5,117,3,210,0,251,253,235,7,169,3,113,0,232,252,103,5,40,4,78,1,38,0,172,7,188,5,203,1,133,0,14,8,162,4,158,255,135,255,17,10,165,5,250,1,139,254,6,9,146,6,254,255,64,252,60,11,147,7,253,2,138,0,253,13,56,9,137,2,98,254,219,0,176,0,114,254,203,254,178,1,178,255,77,254,144,252,168,254,45,1,9,1,216,253,109,252,214,1,145,2,132,254,163,1,80,254,93,255,59,254,95,1,71,252,8,0,206,253,21,3,213,255,20,0,66,252,46,1,174,253,160,254,121,251,16,4,108,0,100,253,100,252,53,5,210,0,63,251,129,249,227,1,77,2,162,254,140,251,235,3,56,3,222,252,96,251,233,2,58,0,179,253,93,250,90,1,247,0,109,252,109,249,14,1,28,3,48,253,5,248,184,4,210,2,34,255,63,255,206,5,156,4,100,254,96,253,186,6,179,0,187,255,247,253,255,7,92,3,102,253,126,250,110,255,222,0,231,254,219,252,67,255,90,0,142,255,229,250,104,255,62,4,15,255,4,253,73,254,221,2,167,253,234,250,191,252,89,255,161,254,167,253,168,252,90,254,101,254,221,251,21,253,157,254,186,253,148,249,187,252,210,0,108,252,136,251,248,248,32,0,146,252,105,249,208,255,233,255,134,251,52,0,162,254,103,254,136,249,148,254,9,1,40,253,166,252,191,253,202,1,9,255,139,251,27,252,179,2,105,254,60,248,119,251,190,255,152,255,63,253,31,251,81,254,163,255,89,251,204,248,203,0,36,253,24,252,99,249,10,0,192,252,202,248,229,248,237,1,128,255,100,250,24,249,232,1,201,254,62,249,20,246,115,253,236,253,130,251,108,251,194,251,223,254,86,249,3,250,69,253,75,251,64,251,26,249,248,251,55,250,230,247,13,250,47,253,60,251,27,247,216,245,12,0,229,253,52,250,149,251,216,255,113,252,198,247,71,254,41,254,28,254,37,247,243,249,115,255,36,252,66,244,71,249,247,249,202,247,185,253,86,1,153,250,44,245,126,254,243,255,186,247,227,245,75,251,72,0,157,247,97,243,59,252,134,1,123,244,28,243,147,253,125,2,189,240,214,239,159,252,35,3,249,250,179,252,137,254,220,253,120,250,111,251,25,254,3,251,136,250,102,249,253,251,94,254,30,248,139,248,92,251,20,251,118,250,82,247,19,248,128,255,237,247,74,244,123,245,202,254,74,252,252,251,254,249,185,0,176,249,109,252,99,247,219,253,19,0,203,252,135,251,96,1,184,0,105,251,180,250,141,253,221,253,192,251,131,249,113,252,40,255,34,250,107,247,76,252,229,252,230,250,186,246,61,254,100,252,159,248,20,245,88,253,168,253,178,249,231,241,139,252,168,246,32,246,63,1,47,1,164,244,209,247,202,254,61,2,124,242,163,247,49,0,143,255,73,247,64,254,163,2,110,255,11,245,236,253,207,4,223,1,132,245,26,254,56,255,99,2,59,242,53,252,58,255,192,2,133,241,173,0,93,1,254,0,130,237,89,250,222,255,112,3,9,3,0,254,114,0,246,255,226,4,190,255,186,1,251,255,92,2,101,2,196,1,160,254,200,4,9,3,163,2,10,252,164,250,177,255,72,251,18,255,171,246,239,255,123,251,206,252,32,250,95,253,147,251,220,251,64,248,225,252,43,248,75,248,11,248,226,252,212,251,151,255,138,243,125,252,231,248,62,255,100,255,138,252,138,1,194,254,254,254,253,250,39,2,202,0,232,253,63,249,142,3,75,1,177,252,171,251,27,3,93,255,109,251,152,251,203,2,7,2,200,251,217,250,149,6,156,2,24,252,127,248,96,0,211,0,49,250,156,247,63,3,174,0,141,251,138,254,158,1,252,255,19,250,153,250,140,1,160,254,12,252,183,1,197,255,57,252,236,248,194,2,72,254,250,251,77,248,183,254,222,255,197,252,88,246,204,249,105,255,162,253,143,247,118,1,231,254,76,0,60,244,231,0,241,255,78,253,80,4,54,2,209,2,209,0,149,6,52,2,127,1,98,0,106,7,238,2,24,3,159,255,44,2,192,255,49,2,163,255,108,3,162,0,145,3,234,255,193,3,163,2,16,5,140,0,244,2,116,254,83,3,32,2,104,1,209,254,61,5,140,1,110,3,234,255,184,5,95,3,203,254,239,254,130,2,127,255,82,253,174,255,74,3,198,1,251,255,209,255,45,4,230,3,162,255,199,3,253,4,42,1,23,254,129,1,193,5,234,2,143,254,51,253,53,5,242,0,25,1,31,252,190,6,156,3,208,1,89,2,39,6,96,5,6,255,206,0,35,9,151,4,74,254,121,1,171,253,227,254,4,252,19,3,234,252,225,254,54,254,102,254,215,0,39,1,179,253,164,252,135,255,29,3,105,251,122,0,75,254,210,1,56,250,135,255,111,1,156,3,234,0,67,1,2,3,213,253,145,0,30,0,228,3,26,0,66,0,81,3,93,0,111,255,139,255,237,4,218,1,113,254,41,250,27,4,218,0,6,254,146,250,182,2,226,3,88,0,104,2,7,0,78,0,48,1,36,4,52,0,194,255,67,3,65,3,198,1,137,2,79,5,254,252,208,1,47,0,93,0,194,253,175,4,217,255,123,1,114,0,158,255,232,1,229,1,215,2,244,0,94,2,184,2,180,255,199,1,159,2,34,2,203,253,243,255,145,0,51,3,136,254,57,2,192,1,104,4,218,0,122,0,9,1,143,4,230,0,226,2,164,3,235,3,138,0,221,1,36,0,194,1,148,1,19,3,183,255,232,3,241,1,235,4,131,1,207,4,17,0,207,0,195,0,177,255,50,2,102,1,53,0,98,255,237,1,131,1,222,1,189,0,166,2,63,3,128,2,46,2,59,255,11,2,101,2,57,0,173,1,126,3,1,3,111,0,67,0,150,4,56,2,255,1,218,4,56,3,251,0,72,3,139,5,50,4,96,3,225,1,156,3,194,5,157,2,212,2,3,6,87,7,142,2,54,6,189,1,81,1,87,4,29,2,216,1,141,5,240,4,70,4,26,3,223,2,79,4,156,2,31,4,95,3,168,4,252,3,10,3,81,4,38,3,6,7,28,4,247,5,51,6,103,8,113,3,16,6,241,4,135,1,214,2,104,3,20,7,89,2,189,5,24,1,240,3,104,2,123,5,65,2,11,7,220,4,114,6,34,5,124,4,48,4,17,5,133,6,119,7,2,4,45,8,20,4,67,8,165,4,108,6,169,7,27,10,232,5,25,0,197,254,247,255,150,255,34,1,173,254,172,1,68,254,188,255,241,252,223,2,4,3,245,0,213,253,212,1,47,0,78,1,129,252,46,3,146,0,235,0,112,1,60,252,65,252,53,255,59,1,226,249,63,251,33,3,17,0,236,254,158,254,126,3,17,254,235,252,133,253,204,2,35,1,91,251,155,254,48,2,252,254,35,253,254,255,167,2,4,254,107,250,211,0,205,255,194,255,84,254,45,2,66,1,130,253,45,255,102,2,146,252,223,251,172,255,185,255,124,254,121,250,89,255,194,254,14,253,218,249,214,0,229,253,117,250,44,248,164,255,237,252,209,255,168,252,165,254,1,255,23,0,69,251,83,255,64,1,110,253,25,254,131,252,97,1,241,252,205,249,184,253,251,1,116,250,165,252,134,254,185,1,209,247,45,250,119,255,183,1,191,254,86,250,248,250,244,255,153,254,191,247,215,253,248,255,193,252,130,248,231,249,32,0,10,252,73,246,177,250,85,252,37,254,201,254,87,255,20,255,117,252,86,254,20,1,157,253,160,255,112,254,50,0,58,253,86,254,2,252,246,255,39,252,59,255,254,254,24,253,193,253,157,253,94,252,253,252,118,254,245,254,248,252,156,253,85,252,0,255,190,250,222,252,158,251,228,252,222,249,199,252,14,253,200,2,108,3,141,0,227,0,213,3,229,5,85,0,124,0,182,5,204,4,211,3,217,255,198,6,231,3,201,5,184,1,245,8,92,4,1,3,184,1,200,9,200,5,217,4,100,1,170,9,117,7,22,6,42,3,149,3,110,4,95,2,122,255,253,1,17,7,13,3,133,255,176,6,226,5,47,2,89,254,245,7,13,9,214,2,101,255,215,11,116,10,179,4,75,1,80,14,202,12,232,6,19,2,74,6,47,7,99,3,183,0,238,6,180,7,2,6,97,0,30,7,110,8,2,5,147,2,174,8,198,10,26,7,132,3,179,12,76,8,187,6,228,3,49,14,32,9,104,9,173,5,107,11,189,13,7,10,38,5,0,0,0,0,0,0,190,247,234,250,76,0,164,245,2,251,168,250,225,244,196,252,163,254,28,241,114,247,163,254,150,240,148,254,63,254,91,245,116,238,233,241,89,242,100,237,48,249,205,255,12,253,84,0,103,255,89,251,248,1,108,0,118,250,143,4,189,252,128,252,134,1,199,253,90,249,87,0,129,251,230,248,165,3,222,248,13,246,155,1,206,248,230,248,171,5,122,246,181,249,13,3,69,245,83,246,31,5,84,252,228,4,221,1,163,249,152,6,90,2,78,251,105,2,24,1,55,249,137,1,68,2,8,250,53,4,175,4,139,247,95,255,128,5,56,246,193,251,67,9,126,242,81,255,115,5,139,250,158,255,181,252,52,247,79,255,131,251,47,250,42,253,253,250,234,249,247,254,48,249,181,248,203,252,151,248,242,247,20,250,220,246,221,245,138,251,211,244,170,0,46,0,205,252,63,255,52,255,129,251,70,1,60,255,4,250,12,3,73,1,208,252,201,0,113,1,37,251,138,2,47,255,220,251,120,4,241,255,64,251,179,4,253,254,181,248,134,252,204,253,106,250,130,253,172,252,127,248,177,0,29,253,178,250,251,254,242,253,126,249,206,0,105,254,49,247,82,1,242,253,202,252,165,1,185,251,15,252,253,2,161,253,128,250,57,3,241,250,44,248,101,1,119,252,233,248,198,255,32,251,204,249,172,253,100,250,2,248,183,255,121,251,188,247,141,255,154,250,235,245,96,255,69,249,96,248,250,255,108,247,118,244,119,253,87,249,213,245,151,253,83,250,46,243,75,252,29,248,226,243,212,252,8,6,145,7,194,248,62,2,208,7,73,250,116,4,89,10,133,245,212,6,172,5,74,246,193,8,219,9,15,3,118,7,155,5,69,2,122,10,96,5,236,0,149,8,93,7,59,254,127,11,9,8,86,253,130,8,5,10,194,250,129,12,0,13,224,254,72,255,6,1,121,0,107,255,73,255,246,2,100,254,206,0,14,4,52,255,85,3,41,6,55,254,188,2,169,3,128,253,201,253,228,5,240,253,0,252,31,255,241,253,85,254,204,253,185,251,180,254,26,253,159,254,70,255,248,250,53,254,84,0,195,248,28,254,238,254,238,249,37,253,57,3,135,246,22,255,126,1,70,249,37,1,241,254,45,246,169,1,204,253,217,245,50,3,208,1,154,254,118,0,137,254,155,253,198,0,150,252,78,253,171,2,188,254,184,250,131,4,88,255,187,251,129,0,188,254,96,251,99,2,166,252,177,1,130,1,140,254,136,255,230,1,134,253,234,0,83,3,137,253,90,2,128,0,46,0,75,4,154,1,159,0,203,2,111,255,88,254,174,4,171,255,175,253,110,5,111,1,154,254,147,6,106,1,60,252,175,6,110,2,45,0,241,7,65,3,129,254,74,11,37,2,6,254,7,0,145,1,52,0,72,0,43,3,159,1,54,2,156,2,41,0,211,1,194,4,130,0,68,0,189,3,69,255,231,255,113,6,153,255,107,253,4,1,214,0,99,252,162,255,100,2,191,254,90,254,197,3,236,252,96,253,247,6,144,1,95,253,11,3,229,2,173,253,99,6,95,255,51,1,145,2,130,254,68,3,103,3,210,252,144,1,199,4,108,1,94,2,223,4,57,0,75,0,35,6,151,0,215,1,239,8,175,255,253,3,222,5,227,0,190,5,73,4,146,2,251,4,117,6,152,2,198,5,73,9,7,1,129,255,188,1,8,1,89,0,201,3,26,3,171,0,64,2,53,3,186,0,202,4,148,1,206,1,5,2,83,1,150,3,26,3,0,5,143,5,196,0,173,5,227,7,109,1,79,6,201,5,160,2,90,9,172,6,252,1,38,3,214,4,61,2,201,2,134,4,54,4,5,5,156,5,208,4,254,6,164,4,117,4,253,2,131,2,96,3,8,4,29,3,255,4,132,3,51,2,35,7,234,5,161,2,8,9,8,6,105,4,168,12,189,5,26,4,58,6,153,7,38,5,196,7,93,9,234,7,12,8,210,13,9,8,60,10,225,4,138,255,74,0,191,6,194,0,165,1,30,8,206,255,49,254,202,3,176,2,80,254,125,4,184,3,146,255,230,4,251,4,117,253,106,5,161,3,145,1,168,7,143,4,232,0,151,1,16,253,13,255,91,3,162,251,172,0,29,255,164,252,32,252,228,252,105,251,156,250,8,0,254,250,124,254,97,1,11,249,243,251,36,253,115,254,217,252,171,252,228,255,194,250,51,251,73,251,89,248,9,252,155,251,17,246,84,250,1,249,91,245,157,248,144,246,59,243,106,252,163,249,241,252,188,253,149,247,70,253,183,251,196,246,160,255,149,250,23,250,7,0,204,249,228,247,104,253,63,250,76,245,240,252,182,246,179,243,200,255,216,244,212,247,87,255,193,242,132,241,60,1,104,251,134,252,154,253,104,248,219,251,224,252,213,254,19,250,24,252,128,253,198,248,10,250,82,250,0,250,47,251,158,248,93,248,36,249,194,251,127,248,182,247,18,253,235,246,44,247,211,250,147,246,143,245,166,251,18,246,125,242,195,250,171,244,133,240,120,251,78,247,143,250,23,252,44,245,219,249,198,249,175,245,70,248,2,250,26,244,192,245,80,247,108,247,93,253,9,245,18,244,178,251,40,248,232,244,94,251,68,248,252,242,97,249,77,249,22,242,7,254,33,246,96,240,161,248,227,246,82,245,8,247,144,242,159,246,117,243,40,248,56,242,247,242,57,247,37,243,98,238,37,254,181,3,155,0,107,255,85,5,33,2,11,253,108,6,59,4,39,255,5,8,73,5,103,250,253,8,182,5,239,1,125,6,17,2,10,0,245,7,228,2,34,8,106,7,210,3,15,11,246,8,143,3,74,3,25,3,164,1,199,4,255,3,95,3,213,4,195,1,12,3,208,6,196,2,54,3,253,5,28,1,104,5,87,8,97,2,2,6,1,9,114,2,28,2,64,9,163,4,187,3,26,10,231,4,249,255,44,12,107,4,214,2,103,13,194,6,172,1,174,10,112,6,27,5,172,11,207,4,218,7,195,13,232,7,208,5,10,4,121,6,103,3,182,4,115,8,12,4,15,7,68,9,209,4,16,7,233,6,213,5,37,6,28,9,243,6,192,4,73,6,74,7,200,5,106,7,209,9,209,1,148,10,216,10,3,3,54,14,10,13,77,7,39,10,63,10,9,11,185,10,164,9,78,10,135,9,49,6,46,8,154,11,28,5,230,7,241,11,207,7,100,13,96,11,24,7,184,17,158,11,81,8,22,4,3,10,38,8,83,5,234,13,14,9,207,9,99,7,168,11,74,7,2,9,146,15,200,12,108,11,98,14,74,12,236,13,224,8,8,14,128,15,6,11,127,9,41,13,253,11,139,7,101,18,18,12,69,10,124,16,146,15,31,18,216,15,80,14,195,15,214,20,48,19,0,0,0,0,0,0,242,254,164,250,248,251,227,253,142,249,154,250,45,253,37,248,91,247,83,252,158,251,106,248,244,252,135,251,106,246,140,252,227,250,163,250,229,251,13,250,26,249,197,251,170,249,4,247,247,252,159,250,157,247,89,252,69,250,53,245,222,252,209,250,113,242,89,252,89,248,97,240,16,255,167,255,222,0,107,253,255,254,96,255,30,252,46,254,93,254,68,255,92,255,234,254,170,254,0,254,97,254,161,253,1,254,227,252,16,0,19,0,52,253,118,1,169,1,52,252,166,254,245,0,230,254,247,254,250,1,14,253,148,253,109,255,163,7,26,253,164,252,37,10,106,255,160,254,144,10,49,1,112,3,162,7,123,0,219,2,206,10,164,254,253,2,255,12,106,2,221,0,186,12,78,255,209,255,123,16,137,1,24,5,2,15,186,2,166,6,193,18,63,0,184,253,205,4,41,255,36,253,168,6,172,0,177,254,117,7,254,255,216,0,5,7,97,1,127,0,157,8,72,251,188,0,11,0,255,253,181,255,85,253,51,252,222,0,122,253,152,253,181,252,124,254,74,252,167,251,153,254,105,250,145,253,63,253,138,250,217,251,78,255,211,255,51,254,35,0,247,255,111,253,40,255,127,0,202,251,95,0,74,252,124,251,72,2,56,250,42,250,193,1,136,255,63,253,4,2,144,254,63,252,215,2,134,254,242,253,205,3,231,252,154,253,164,2,223,252,13,253,7,5,60,250,172,254,100,6,7,254,26,251,7,6,37,251,170,249,252,5,248,252,59,250,113,253,129,251,240,250,201,252,127,251,120,249,156,251,245,250,45,248,90,249,146,253,253,250,57,0,41,254,181,249,253,1,220,251,222,249,117,255,151,252,148,247,232,253,76,249,27,248,148,254,154,247,110,243,245,250,32,251,103,248,168,244,65,251,183,245,217,244,167,0,12,255,84,0,93,1,100,254,39,255,216,255,160,254,120,2,227,0,239,253,149,1,68,0,129,254,69,254,167,0,210,253,62,253,237,254,170,252,242,255,161,254,191,251,63,254,85,1,184,255,223,254,91,2,150,255,38,254,66,1,37,255,119,253,179,0,195,254,26,252,194,1,221,254,28,252,43,2,195,0,243,253,16,3,16,1,193,252,108,255,128,254,175,252,82,0,232,253,179,250,238,0,84,255,182,250,166,1,244,254,207,248,41,1,31,253,225,247,145,255,223,252,170,253,1,0,100,253,40,252,125,255,206,252,237,250,183,254,247,253,226,250,105,255,246,252,214,248,163,255,160,254,46,249,200,253,128,253,227,248,3,254,83,252,121,247,208,1,209,252,30,251,79,0,147,251,195,249,72,255,183,250,181,247,60,255,102,254,133,246,64,255,191,252,6,245,253,254,154,250,27,244,39,255,4,0,114,251,224,252,187,254,61,251,149,254,194,252,126,252,107,253,146,251,64,252,126,254,44,252,35,250,141,253,121,251,70,249,121,252,195,252,169,252,83,253,195,252,223,250,215,251,65,252,131,250,185,1,25,0,177,252,143,2,229,255,99,251,135,4,146,255,63,253,88,3,253,0,121,249,159,1,148,1,255,255,66,1,135,3,114,254,158,2,243,1,220,254,35,3,79,2,158,253,120,4,79,2,210,252,205,2,183,0,137,1,89,3,125,1,106,0,97,2,62,0,229,255,24,3,198,0,187,254,223,2,37,3,88,0,118,4,44,3,78,0,4,4,110,1,220,254,29,5,231,2,19,255,79,6,77,2,177,255,242,3,127,2,13,255,231,3,196,3,201,254,220,5,113,4,153,253,220,3,101,1,134,2,203,4,155,2,171,2,140,4,29,6,126,3,112,5,223,7,221,1,114,4,21,2,250,0,157,5,128,3,135,1,229,6,94,4,99,0,88,4,66,4,34,3,60,6,78,3,110,4,169,3,137,4,23,1,183,6,230,4,171,2,58,5,62,4,35,0,139,5,44,5,172,1,148,5,244,5,40,0,60,8,58,6,89,0,247,3,32,2,198,4,97,4,157,3,239,4,6,4,38,5,205,5,15,5,21,3,25,7,43,5,248,4,117,7,188,6,213,4,11,7,5,7,153,6,90,3,101,8,87,5,21,5,254,8,75,7,249,2,47,11,47,9,29,4,52,0,163,0,180,255,230,0,53,1,20,254,185,255,107,2,39,0,38,255,88,3,243,1,114,253,224,2,49,255,233,253,235,4,155,0,32,254,196,5,131,2,6,1,57,4,102,0,53,1,56,6,74,255,115,2,93,6,22,2,81,1,131,2,200,1,246,2,158,2,201,2,202,0,102,4,146,2,100,2,107,4,154,2,174,2,199,4,112,4,125,255,121,1,13,2,42,0,196,2,139,3,87,0,208,5,11,4,176,1,69,8,136,3,137,0,213,3,52,5,65,254,246,3,112,4,185,252,1,7,222,4,209,253,41,1,198,0,174,252,173,2,190,1,7,251,120,2,58,3,111,254,224,253,173,0,15,253,231,252,144,0,76,254,247,255,4,3,141,255,13,255,30,5,98,253,243,254,118,1,253,251,243,255,127,2,137,252,175,255,113,4,3,251,57,254,158,0,125,250,48,253,224,2,172,0,88,0,147,1,130,1,255,0,244,2,12,254,10,2,142,3,66,252,147,2,108,5,117,254,45,1,64,5,156,254,0,3,21,7,155,253,73,3,115,9,189,1,134,255,252,0,117,2,169,255,211,2,27,1,3,255,102,3,200,1,140,255,101,5,245,2,180,0,35,4,20,2,152,1,229,5,179,3,32,1,14,7,45,5,226,3,220,9,124,3,195,4,207,11,117,5,60,6,78,13,119,4,16,6,242,9,58,7,153,5,150,10,246,255,134,0,234,3,154,0,243,1,43,5,252,1,24,3,93,4,253,1,60,5,80,6,250,2,94,3,72,6,19,3,228,2,16,9,26,3,191,6,3,5,209,1,60,8,124,6,136,255,171,5,77,6,126,254,224,7,121,8,123,3,201,4,2,8,200,1,200,5,137,8,213,5,3,5,185,4,117,5,100,6,238,5,240,6,202,6,16,6,36,6,162,6,93,8,109,5,78,8,247,4,167,7,109,9,95,4,85,5,76,11,225,5,158,8,179,7,87,6,28,8,158,7,232,8,181,6,243,8,75,7,62,9,211,9,161,7,49,11,22,11,218,9,231,9,137,13,219,7,53,13,31,16,78,10,68,3,107,10,241,8,225,6,213,10,33,9,135,5,253,12,95,11,50,9,66,12,54,12,99,10,96,16,170,15,24,4,250,6,26,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+836760);
/* memory initializer */ allocate([218,4,63,8,192,8,232,5,31,8,220,10,37,6,187,9,66,12,182,8,73,9,222,10,160,1,237,6,144,10,213,2,32,9,225,12,228,4,69,9,138,15,46,8,220,8,240,13,219,7,152,10,176,17,61,5,179,13,36,15,192,4,79,15,58,19,157,6,185,18,124,23,104,5,29,8,92,13,244,19,86,26,186,31,135,38,84,43,170,49,133,53,0,0,0,0,168,87,138,62,37,117,2,63,134,201,36,63,56,103,68,63,39,194,118,63,167,232,136,63,154,153,161,63,101,25,202,63,23,217,246,63,79,64,15,64,91,211,32,64,63,53,54,64,14,45,50,62,45,67,188,62,255,178,27,63,11,181,86,63,13,224,141,63,249,160,175,63,0,111,209,63,75,200,239,63,147,24,4,64,95,7,22,64,241,244,38,64,11,181,54,64,82,73,29,62,130,226,167,62,42,169,3,63,36,151,47,63,204,238,121,63,138,31,163,63,119,190,199,63,18,165,237,63,222,113,6,64,123,20,22,64,72,225,38,64,215,163,56,64,225,122,84,62,240,22,232,62,180,89,69,63,91,211,132,63,100,204,165,63,138,176,193,63,61,44,228,63,20,63,2,64,117,147,16,64,114,249,31,64,238,124,43,64,185,252,55,64,169,164,14,62,236,47,123,62,110,52,192,62,200,152,11,63,188,150,80,63,204,127,144,63,224,45,184,63,119,45,225,63,91,66,2,64,117,147,20,64,68,250,37,64,148,246,54,64,0,0,0,62,208,179,185,62,143,228,66,63,252,169,145,63,82,73,181,63,100,59,199,63,117,147,216,63,98,16,232,63,18,20,239,63,153,187,2,64,156,162,27,64,125,174,54,64,176,3,103,62,181,55,216,62,212,43,37,63,104,34,92,63,73,157,136,63,16,233,167,63,134,56,198,63,181,21,235,63,140,219,4,64,204,93,19,64,78,209,33,64,90,100,51,64,250,237,107,62,28,124,225,62,220,104,48,63,120,122,101,63,248,83,147,63,29,201,181,63,127,251,210,63,242,210,237,63,243,142,7,64,36,151,23,64,50,230,38,64,81,107,58,64,29,90,100,62,19,97,195,62,223,79,13,63,236,47,27,63,108,120,74,63,122,165,140,63,139,108,183,63,198,109,228,63,46,144,4,64,243,31,22,64,11,181,38,64,48,187,55,64,163,146,122,62,225,122,20,63,165,44,83,63,104,145,125,63,95,7,150,63,111,18,179,63,230,174,213,63,234,4,244,63,100,93,8,64,100,59,27,64,178,157,43,64,75,89,58,64,58,35,74,62,165,44,195,62,253,135,20,63,98,161,70,63,104,145,109,63,54,205,147,63,66,96,181,63,240,133,209,63,193,202,241,63,138,142,16,64,163,1,36,64,199,186,52,64,107,154,247,61,18,131,128,62,245,219,247,62,95,7,78,63,84,82,143,63,61,155,173,63,2,188,205,63,184,64,242,63,215,163,8,64,74,123,23,64,45,67,40,64,6,129,57,64,69,216,112,62,0,145,222,62,204,127,40,63,87,91,81,63,198,109,116,63,212,43,149,63,242,65,191,63,41,203,240,63,50,230,10,64,131,47,24,64,108,9,41,64,63,198,56,64,79,30,86,62,206,25,209,62,186,73,44,63,254,67,106,63,126,29,144,63,236,192,169,63,93,254,203,63,27,13,232,63,77,132,1,64,147,58,21,64,173,250,36,64,2,43,55,64,105,0,239,61,217,95,118,62,139,108,231,62,44,212,58,63,218,27,124,63,155,85,159,63,236,192,193,63,134,201,228,63,193,202,1,64,248,83,19,64,127,217,37,64,23,72,56,64,236,192,153,62,91,66,254,62,121,233,38,63,94,186,89,63,225,122,148,63,241,244,178,63,211,77,202,63,44,212,234,63,69,216,4,64,81,218,19,64,47,221,36,64,195,100,54,64,127,251,122,62,70,37,213,62,117,147,24,63,217,206,71,63,19,97,115,63,215,52,159,63,123,131,199,63,57,214,237,63,57,180,4,64,154,119,20,64,111,129,36,64,166,155,52,64,155,85,159,62,54,60,13,63,234,4,52,63,26,81,90,63,40,15,147,63,86,125,182,63,135,167,215,63,153,42,248,63,194,23,10,64,199,75,27,64,60,189,42,64,41,237,57,64,48,76,102,62,194,134,199,62,118,79,14,63,14,79,63,63,188,5,130,63,57,214,173,63,204,127,216,63,160,26,255,63,146,203,11,64,27,158,22,64,220,70,35,64,178,157,51,64,184,30,133,62,85,48,234,62,104,34,60,63,240,22,120,63,116,181,149,63,32,65,177,63,135,22,209,63,3,120,243,63,123,131,7,64,69,71,22,64,214,197,37,64,45,178,53,64,139,253,101,62,122,165,172,62,213,120,233,62,217,95,6,63,52,162,52,63,145,126,131,63,156,196,176,63,35,74,219,63,230,174,253,63,62,121,16,64,190,159,34,64,168,87,54,64,60,78,17,62,52,128,247,62,14,45,98,63,49,153,146,63,214,86,164,63,52,17,182,63,36,151,199,63,91,211,228,63,88,57,8,64,74,12,26,64,218,172,38,64,108,120,54,64,92,32,65,62,45,67,188,62,146,203,15,63,155,85,79,63,121,88,144,63,48,42,177,63,140,74,202,63,11,36,232,63,253,246,1,64,182,243,17,64,185,141,34,64,196,66,53,64,14,190,112,62,253,135,212,62,72,225,42,63,132,13,95,63,111,240,133,63,58,35,170,63,1,77,212,63,251,203,246,63,8,172,8,64,53,94,22,64,32,210,39,64,110,52,56,64,113,61,138,62,57,214,229,62,164,223,30,63,48,76,54,63,52,17,70,63,218,27,124,63,137,210,174,63,116,36,223,63,189,227,0,64,238,90,14,64,39,194,30,64,236,81,52,64,127,217,125,62,92,143,226,62,221,36,38,63,59,223,95,63,93,220,142,63,103,68,177,63,196,177,214,63,222,113,250,63,219,138,9,64,144,49,23,64,78,98,36,64,250,237,51,64,78,98,80,62,191,125,189,62,228,131,14,63,200,152,75,63,179,12,129,63,106,77,163,63,63,198,196,63,33,31,228,63,184,30,1,64,122,165,16,64,37,117,30,64,2,188,49,64,237,13,62,62,5,52,177,62,126,140,25,63,25,115,103,63,157,128,158,63,154,8,187,63,109,86,213,63,160,26,247,63,75,89,10,64,233,72,26,64,235,115,41,64,254,101,55,64,190,193,87,62,63,53,190,62,254,101,7,63,254,67,42,63,80,141,87,63,77,243,142,63,50,85,184,63,68,139,220,63,153,187,254,63,97,50,17,64,143,228,34,64,90,100,55,64,71,114,249,61,126,140,153,62,65,130,34,63,60,189,114,63,209,34,163,63,122,54,203,63,232,217,244,63,247,6,15,64,94,186,25,64,52,128,31,64,122,165,40,64,28,124,53,64,175,148,37,62,97,84,178,62,20,63,22,63,9,249,80,63,79,175,132,63,210,0,158,63,197,254,186,63,161,248,217,63,245,74,249,63,241,244,14,64,181,166,33,64,95,7,54,64,137,65,128,62,163,146,250,62,137,65,64,63,140,74,106,63,229,208,138,63,66,207,174,63,243,142,211,63,44,212,234,63,37,6,1,64,139,253,17,64,199,41,34,64,6,18,52,64,19,242,193,61,141,40,237,61,177,191,108,61,3,9,10,189,208,68,216,187,195,100,42,60,89,23,55,189,23,217,78,189,155,85,159,189,142,6,240,188,132,158,205,60,140,74,106,188,77,243,14,61,90,245,185,188,199,41,186,189,134,56,86,61,184,30,5,61,158,239,39,189,25,4,214,189,126,29,184,189,250,237,107,186,143,194,245,59,31,133,107,189,160,26,175,189,134,90,83,188,31,133,107,61,253,135,116,61,82,39,32,61,43,246,23,61,153,187,150,188,185,252,7,188,67,28,235,60,140,74,106,60,112,206,136,60,166,155,68,60,39,160,137,188,163,35,57,61,125,174,182,60,224,45,16,189,56,248,66,60,95,41,75,189,203,161,197,189,112,95,135,189,250,237,235,187,64,19,225,61,122,165,172,61,114,138,14,188,239,201,67,189,23,183,81,188,166,155,68,188,23,183,209,185,116,181,149,61,244,108,214,61,37,6,129,61,46,144,160,60,85,193,40,188,47,110,35,189,204,238,201,189,17,199,186,189,119,190,31,189,168,87,202,188,150,33,142,189,44,101,153,189,208,68,216,187,125,174,182,60,220,215,129,61,40,126,12,61,172,139,91,188,189,227,148,61,93,109,197,60,208,68,216,59,197,254,50,61,35,219,121,61,43,24,21,61,95,41,203,60,5,163,18,189,40,126,140,189,195,100,42,188,86,125,46,61,224,45,16,60,247,117,96,188,2,43,135,188,186,107,137,61,121,233,166,61,14,190,176,189,38,228,131,189,224,45,16,188,153,187,22,59,93,109,69,61,105,111,240,61,74,12,2,62,106,77,115,61,2,43,135,60,238,90,194,61,211,222,224,61,247,117,96,60,191,125,253,62,229,242,255,62,127,217,253,62,8,61,251,62,73,46,255,62,63,53,254,62,127,217,253,62,146,203,255,62,155,85,255,62,127,217,253,62,128,72,255,62,137,210,254,62,142,117,145,62,174,216,95,62,7,240,22,62,177,191,44,62,83,5,99,62,39,194,134,62,21,140,138,62,75,89,134,62,136,99,93,62,236,47,123,62,109,231,123,62,83,150,129,62,168,87,138,62,37,117,2,63,134,201,36,63,56,103,68,63,39,194,118,63,167,232,136,63,154,153,161,63,101,25,202,63,23,217,246,63,79,64,15,64,91,211,32,64,63,53,54,64,14,45,50,62,45,67,188,62,255,178,27,63,11,181,86,63,13,224,141,63,249,160,175,63,0,111,209,63,75,200,239,63,147,24,4,64,95,7,22,64,241,244,38,64,11,181,54,64,82,73,29,62,130,226,167,62,42,169,3,63,36,151,47,63,204,238,121,63,138,31,163,63,119,190,199,63,18,165,237,63,222,113,6,64,123,20,22,64,72,225,38,64,215,163,56,64,225,122,84,62,240,22,232,62,180,89,69,63,91,211,132,63,100,204,165,63,138,176,193,63,61,44,228,63,20,63,2,64,117,147,16,64,114,249,31,64,238,124,43,64,185,252,55,64,169,164,14,62,236,47,123,62,110,52,192,62,200,152,11,63,188,150,80,63,204,127,144,63,224,45,184,63,119,45,225,63,91,66,2,64,117,147,20,64,68,250,37,64,148,246,54,64,0,0,0,62,208,179,185,62,143,228,66,63,252,169,145,63,82,73,181,63,100,59,199,63,117,147,216,63,98,16,232,63,18,20,239,63,153,187,2,64,156,162,27,64,125,174,54,64,176,3,103,62,181,55,216,62,212,43,37,63,104,34,92,63,73,157,136,63,16,233,167,63,134,56,198,63,181,21,235,63,140,219,4,64,204,93,19,64,78,209,33,64,90,100,51,64,250,237,107,62,28,124,225,62,220,104,48,63,120,122,101,63,248,83,147,63,29,201,181,63,127,251,210,63,242,210,237,63,243,142,7,64,36,151,23,64,50,230,38,64,81,107,58,64,29,90,100,62,19,97,195,62,223,79,13,63,236,47,27,63,108,120,74,63,122,165,140,63,139,108,183,63,198,109,228,63,46,144,4,64,243,31,22,64,11,181,38,64,48,187,55,64,163,146,122,62,225,122,20,63,165,44,83,63,104,145,125,63,95,7,150,63,111,18,179,63,230,174,213,63,234,4,244,63,100,93,8,64,100,59,27,64,178,157,43,64,75,89,58,64,58,35,74,62,165,44,195,62,253,135,20,63,98,161,70,63,104,145,109,63,54,205,147,63,66,96,181,63,240,133,209,63,193,202,241,63,138,142,16,64,163,1,36,64,199,186,52,64,107,154,247,61,18,131,128,62,245,219,247,62,95,7,78,63,84,82,143,63,61,155,173,63,2,188,205,63,184,64,242,63,215,163,8,64,74,123,23,64,45,67,40,64,6,129,57,64,69,216,112,62,0,145,222,62,204,127,40,63,87,91,81,63,198,109,116,63,212,43,149,63,242,65,191,63,41,203,240,63,50,230,10,64,131,47,24,64,108,9,41,64,63,198,56,64,79,30,86,62,206,25,209,62,186,73,44,63,254,67,106,63,126,29,144,63,236,192,169,63,93,254,203,63,27,13,232,63,77,132,1,64,147,58,21,64,173,250,36,64,2,43,55,64,105,0,239,61,217,95,118,62,139,108,231,62,44,212,58,63,218,27,124,63,155,85,159,63,236,192,193,63,134,201,228,63,193,202,1,64,248,83,19,64,127,217,37,64,23,72,56,64,236,192,153,62,91,66,254,62,121,233,38,63,94,186,89,63,225,122,148,63,241,244,178,63,211,77,202,63,44,212,234,63,69,216,4,64,81,218,19,64,47,221,36,64,195,100,54,64,127,251,122,62,70,37,213,62,117,147,24,63,217,206,71,63,19,97,115,63,215,52,159,63,123,131,199,63,57,214,237,63,57,180,4,64,154,119,20,64,111,129,36,64,166,155,52,64,155,85,159,62,54,60,13,63,234,4,52,63,26,81,90,63,40,15,147,63,86,125,182,63,135,167,215,63,153,42,248,63,194,23,10,64,199,75,27,64,60,189,42,64,41,237,57,64,48,76,102,62,194,134,199,62,118,79,14,63,14,79,63,63,188,5,130,63,57,214,173,63,204,127,216,63,160,26,255,63,146,203,11,64,27,158,22,64,220,70,35,64,178,157,51,64,184,30,133,62,85,48,234,62,104,34,60,63,240,22,120,63,116,181,149,63,32,65,177,63,135,22,209,63,3,120,243,63,123,131,7,64,69,71,22,64,214,197,37,64,45,178,53,64,139,253,101,62,122,165,172,62,213,120,233,62,217,95,6,63,52,162,52,63,145,126,131,63,156,196,176,63,35,74,219,63,230,174,253,63,62,121,16,64,190,159,34,64,168,87,54,64,60,78,17,62,52,128,247,62,14,45,98,63,49,153,146,63,214,86,164,63,52,17,182,63,36,151,199,63,91,211,228,63,88,57,8,64,74,12,26,64,218,172,38,64,108,120,54,64,92,32,65,62,45,67,188,62,146,203,15,63,155,85,79,63,121,88,144,63,48,42,177,63,140,74,202,63,11,36,232,63,253,246,1,64,182,243,17,64,185,141,34,64,196,66,53,64,14,190,112,62,253,135,212,62,72,225,42,63,132,13,95,63,111,240,133,63,58,35,170,63,1,77,212,63,251,203,246,63,8,172,8,64,53,94,22,64,32,210,39,64,110,52,56,64,113,61,138,62,57,214,229,62,164,223,30,63,48,76,54,63,52,17,70,63,218,27,124,63,137,210,174,63,116,36,223,63,189,227,0,64,238,90,14,64,39,194,30,64,236,81,52,64,127,217,125,62,92,143,226,62,221,36,38,63,59,223,95,63,93,220,142,63,103,68,177,63,196,177,214,63,222,113,250,63,219,138,9,64,144,49,23,64,78,98,36,64,250,237,51,64,78,98,80,62,191,125,189,62,228,131,14,63,200,152,75,63,179,12,129,63,106,77,163,63,63,198,196,63,33,31,228,63,184,30,1,64,122,165,16,64,37,117,30,64,2,188,49,64,237,13,62,62,5,52,177,62,126,140,25,63,25,115,103,63,157,128,158,63,154,8,187,63,109,86,213,63,160,26,247,63,75,89,10,64,233,72,26,64,235,115,41,64,254,101,55,64,190,193,87,62,63,53,190,62,254,101,7,63,254,67,42,63,80,141,87,63,77,243,142,63,50,85,184,63,68,139,220,63,153,187,254,63,97,50,17,64,143,228,34,64,90,100,55,64,71,114,249,61,126,140,153,62,65,130,34,63,60,189,114,63,209,34,163,63,122,54,203,63,232,217,244,63,247,6,15,64,94,186,25,64,52,128,31,64,122,165,40,64,28,124,53,64,175,148,37,62,97,84,178,62,20,63,22,63,9,249,80,63,79,175,132,63,210,0,158,63,197,254,186,63,161,248,217,63,245,74,249,63,241,244,14,64,181,166,33,64,95,7,54,64,137,65,128,62,163,146,250,62,137,65,64,63,140,74,106,63,229,208,138,63,66,207,174,63,243,142,211,63,44,212,234,63,37,6,1,64,139,253,17,64,199,41,34,64,6,18,52,64,19,242,193,61,141,40,237,61,177,191,108,61,3,9,10,189,208,68,216,187,195,100,42,60,89,23,55,189,23,217,78,189,155,85,159,189,142,6,240,188,132,158,205,60,140,74,106,188,77,243,14,61,90,245,185,188,199,41,186,189,134,56,86,61,184,30,5,61,158,239,39,189,25,4,214,189,126,29,184,189,250,237,107,186,143,194,245,59,31,133,107,189,160,26,175,189,134,90,83,188,31,133,107,61,253,135,116,61,82,39,32,61,43,246,23,61,153,187,150,188,185,252,7,188,67,28,235,60,140,74,106,60,112,206,136,60,166,155,68,60,39,160,137,188,163,35,57,61,125,174,182,60,224,45,16,189,56,248,66,60,95,41,75,189,203,161,197,189,112,95,135,189,250,237,235,187,64,19,225,61,122,165,172,61,114,138,14,188,239,201,67,189,23,183,81,188,166,155,68,188,23,183,209,185,116,181,149,61,244,108,214,61,37,6,129,61,46,144,160,60,85,193,40,188,47,110,35,189,204,238,201,189,17,199,186,189,119,190,31,189,168,87,202,188,150,33,142,189,44,101,153,189,208,68,216,187,125,174,182,60,220,215,129,61,40,126,12,61,172,139,91,188,189,227,148,61,93,109,197,60,208,68,216,59,197,254,50,61,35,219,121,61,43,24,21,61,95,41,203,60,5,163,18,189,40,126,140,189,195,100,42,188,86,125,46,61,224,45,16,60,247,117,96,188,2,43,135,188,186,107,137,61,121,233,166,61,14,190,176,189,38,228,131,189,224,45,16,188,153,187,22,59,93,109,69,61,105,111,240,61,74,12,2,62,106,77,115,61,2,43,135,60,238,90,194,61,211,222,224,61,247,117,96,60,191,125,253,62,229,242,255,62,127,217,253,62,8,61,251,62,73,46,255,62,63,53,254,62,127,217,253,62,146,203,255,62,155,85,255,62,127,217,253,62,128,72,255,62,137,210,254,62,142,117,145,62,174,216,95,62,7,240,22,62,177,191,44,62,83,5,99,62,39,194,134,62,21,140,138,62,75,89,134,62,136,99,93,62,236,47,123,62,109,231,123,62,83,150,129,62,127,217,189,61,49,153,106,62,32,210,207,62,65,241,19,63,163,146,58,63,78,209,97,63,91,211,132,63,18,131,152,63,65,241,171,63,231,29,191,63,72,225,210,63,91,66,230,63,169,19,248,63,191,125,5,64,186,218,14,64,147,24,24,64,97,50,33,64,193,202,41,64,43,135,50,64,152,221,59,64,202,84,193,61,58,35,74,62,136,244,155,62,87,91,241,62,209,145,28,63,34,108,72,63,89,23,103,63,205,204,132,63,87,236,151,63,122,165,172,63,247,117,192,63,251,203,214,63,204,238,233,63,75,200,255,63,11,70,9,64,5,197,19,64,129,4,29,64,138,31,39,64,214,86,48,64,46,255,57,64,215,52,239,61,197,143,145,62,8,61,251,62,113,172,43,63,41,92,79,63,64,19,113,63,110,163,137,63,122,199,153,63,50,85,168,63,126,140,185,63,76,166,202,63,130,115,222,63,27,158,238,63,213,120,1,64,39,194,10,64,205,204,20,64,41,237,29,64,229,242,39,64,30,167,48,64,188,5,58,64,21,140,10,62,160,26,111,62,68,139,172,62,137,65,224,62,102,247,20,63,159,60,60,63,68,250,93,63,74,12,130,63,53,94,146,63,9,27,166,63,63,53,190,63,91,66,214,63,113,172,235,63,224,45,0,64,57,214,9,64,93,254,19,64,168,87,30,64,11,36,40,64,26,81,50,64,200,7,61,64,22,106,205,61,65,241,99,62,52,128,183,62,228,131,254,62,179,12,33,63,66,96,69,63,81,107,106,63,46,144,136,63,47,110,155,63,32,99,174,63,202,84,193,63,77,132,213,63,204,127,232,63,2,188,253,63,238,235,8,64,140,185,19,64,204,238,29,64,192,91,40,64,27,158,50,64,120,11,60,64,208,68,216,61,151,144,79,62,226,88,151,62,86,14,205,62,6,129,5,63,140,185,43,63,131,192,90,63,45,33,135,63,210,0,158,63,145,126,179,63,30,167,200,63,141,40,221,63,14,190,240,63,59,112,2,64,125,208,11,64,61,155,21,64,220,70,31,64,20,208,40,64,81,107,50,64,91,211,60,64,59,223,207,61,218,27,124,62,225,11,211,62,120,11,20,63,48,42,57,63,243,31,98,63,91,211,132,63,192,91,152,63,202,195,170,63,111,129,188,63,0,145,206,63,179,12,225,63,215,18,242,63,53,94,2,64,235,226,10,64,0,0,20,64,205,204,28,64,59,112,38,64,120,11,48,64,147,169,58,64,34,253,54,62,107,154,119,62,2,43,167,62,208,179,9,63,231,140,40,63,52,162,68,63,29,90,116,63,164,112,141,63,51,51,155,63,141,40,173,63,102,247,188,63,242,210,213,63,11,36,232,63,159,205,250,63,139,253,5,64,0,111,17,64,33,31,28,64,177,225,37,64,108,9,45,64,22,251,55,64,87,236,175,61,10,215,35,62,117,147,152,62,209,145,252,62,232,106,43,63,147,24,84,63,192,236,126,63,168,198,147,63,5,197,167,63,202,195,186,63,244,108,206,63,19,242,225,63,200,7,245,63,29,90,4,64,247,228,13,64,177,80,23,64,4,231,32,64,118,79,42,64,126,29,52,64,188,5,62,64,53,94,186,61,98,16,88,62,159,60,172,62,197,143,241,62,226,233,21,63,44,212,58,63,147,24,100,63,70,148,134,63,71,114,153,63,187,184,173,63,69,71,194,63,32,210,215,63,216,129,235,63,52,162,0,64,86,125,10,64,215,163,20,64,185,141,30,64,84,116,40,64,189,82,50,64,159,60,60,64,56,248,66,62,24,38,147,62,154,119,188,62,247,6,255,62,229,242,31,63,94,186,73,63,99,127,105,63,154,153,137,63,207,247,155,63,85,193,176,63,239,201,195,63,138,176,217,63,68,250,237,63,12,2,3,64,66,62,12,64,205,204,20,64,238,235,28,64,48,76,38,64,68,105,47,64,72,191,57,64,54,205,187,61,42,169,83,62,249,49,166,62,210,0,254,62,55,137,33,63,22,106,77,63,224,156,113,63,4,231,140,63,205,59,158,63,78,209,177,63,168,53,197,63,188,5,218,63,152,221,235,63,241,99,0,64,83,150,9,64,229,242,19,64,184,30,29,64,60,189,38,64,190,193,47,64,29,201,57,64,21,140,202,61,46,144,96,62,165,78,192,62,250,126,10,63,229,97,49,63,134,56,86,63,213,231,122,63,0,0,144,63,254,67,162,63,34,142,181,63,101,170,200,63,109,86,221,63,137,65,240,63,139,253,1,64,9,138,11,64,141,40,21,64,77,243,30,64,209,145,40,64,208,213,50,64,21,29,61,64,50,85,176,61,148,246,70,62,182,132,156,62,190,48,249,62,0,145,30,63,238,90,66,63,67,28,107,63,50,119,141,63,32,210,159,63,234,4,180,63,146,203,199,63,43,24,221,63,254,101,239,63,198,220,1,64,88,202,10,64,215,163,20,64,132,158,29,64,209,34,39,64,125,208,47,64,203,161,57,64,164,223,190,61,98,16,88,62,155,85,191,62,45,67,12,63,162,69,54,63,90,100,91,63,41,92,127,63,142,117,145,63,74,123,163,63,25,4,182,63,103,213,199,63,60,189,218,63,227,165,235,63,29,201,253,63,77,21,8,64,48,76,18,64,160,137,28,64,52,128,39,64,220,215,49,64,197,32,60,64,143,83,244,61,233,183,111,62,170,96,180,62,14,190,0,63,134,201,36,63,190,193,71,63,146,203,111,63,189,227,140,63,27,158,158,63,240,133,177,63,164,112,197,63,26,192,219,63,167,121,239,63,83,150,1,64,58,35,10,64,164,223,18,64,58,146,27,64,103,68,37,64,211,77,46,64,78,209,57,64,159,205,170,61,58,146,75,62,79,30,182,62,125,174,6,63,54,60,45,63,48,187,87,63,7,95,128,63,219,138,149,63,153,42,168,63,19,242,185,63,136,99,205,63,249,15,225,63,63,87,243,63,14,79,3,64,214,86,12,64,165,189,21,64,56,248,30,64,45,67,40,64,2,188,49,64,162,180,59,64,55,26,192,61,186,107,73,62,111,129,164,62,41,92,239,62,63,87,27,63,202,50,68,63,206,25,113,63,4,86,142,63,176,114,160,63,97,84,178,63,67,28,195,63,132,13,215,63,44,212,234,63,231,29,255,63,112,206,8,64,139,108,19,64,159,171,29,64,43,246,39,64,9,27,50,64,114,249,59,64,23,72,208,61,147,169,130,62,219,138,221,62,3,9,26,63,187,39,63,63,5,52,97,63,217,61,129,63,37,117,146,63,110,163,161,63,195,211,179,63,192,236,198,63,131,192,218,63,1,77,236,63,5,197,255,63,170,130,9,64,183,98,19,64,25,226,28,64,72,225,38,64,2,154,48,64,7,240,58,64,24,38,211,61,12,2,107,62,174,216,191,62,138,31,3,63,140,219,40,63,209,34,75,63,100,59,111,63,164,112,141,63,228,131,158,63,180,89,173,63,193,168,188,63,114,138,206,63,84,82,223,63,101,25,242,63,17,199,2,64,45,67,12,64,202,195,22,64,206,136,34,64,74,123,47,64,153,42,60,64,205,59,206,61,252,24,115,62,63,53,190,62,198,109,4,63,6,129,37,63,0,145,78,63,138,142,116,63,240,167,142,63,5,52,161,63,200,7,181,63,201,229,199,63,140,185,219,63,230,63,236,63,169,19,0,64,87,91,9,64,97,84,18,64,79,64,27,64,242,210,37,64,73,46,47,64,23,183,57,64,120,122,165,61,14,190,48,62,106,222,145,62,67,28,235,62,237,158,28,63,108,9,73,63,235,115,117,63,169,19,144,63,122,54,163,63,181,55,184,63,145,126,203,63,224,45,224,63,213,231,242,63,172,139,3,64,149,101,12,64,182,243,21,64,28,235,30,64,93,254,39,64,122,165,48,64,141,151,58,64,213,231,42,62,239,201,131,62,255,33,189,62,0,145,14,63,136,99,45,63,146,92,78,63,74,12,130,63,109,86,149,63,140,185,163,63,140,185,179,63,29,201,197,63,230,63,220,63,113,27,237,63,66,62,0,64,179,12,9,64,251,92,21,64,124,97,30,64,161,103,39,64,60,189,46,64,144,160,56,64,156,162,35,62,64,19,129,62,50,230,174,62,125,208,3,63,200,152,43,63,35,74,75,63,69,216,112,63,50,230,142,63,78,209,153,63,129,38,170,63,137,210,190,63,137,210,214,63,163,1,236,63,203,16,255,63,134,90,7,64,103,68,17,64,186,73,28,64,156,162,39,64,253,135,48,64,91,66,58,64,199,186,184,61,21,140,74,62,2,43,167,62,195,100,234,62,16,122,22,63,59,112,62,63,76,55,105,63,200,152,139,63,128,183,160,63,205,204,180,63,112,206,200,63,66,96,221,63,222,2,241,63,83,5,3,64,212,43,13,64,5,163,22,64,225,122,32,64,62,232,41,64,58,146,51,64,15,11,61,64,194,134,167,61,104,145,45,62,132,13,143,62,47,221,228,62,204,93,27,63,15,156,67,63,173,105,110,63,218,27,140,63,93,220,158,63,33,31,180,63,39,49,200,63,22,251,219,63,153,187,238,63,39,160,1,64,225,11,11,64,200,7,21,64,27,158,30,64,159,60,40,64,154,153,49,64,5,197,59,64,131,192,74,62,247,117,160,62,106,222,209,62,82,184,254,62,107,43,38,63,244,108,86,63,138,176,113,63,125,208,131,63,219,249,150,63,28,124,177,63,3,9,202,63,116,70,220,63,82,39,232,63,54,171,246,63,240,133,5,64,131,192,18,64,237,13,30,64,222,147,39,64,138,142,48,64,215,52,59,64,222,2,9,62,233,183,111,62,70,148,182,62,61,155,245,62,4,231,28,63,74,12,66,63,227,199,104,63,233,72,134,63,247,117,152,63,10,104,170,63,253,246,189,63,8,61,211,63,23,217,230,63,207,247,251,63,29,56,7,64,217,61,17,64,249,49,26,64,193,168,36,64,79,30,46,64,197,143,57,64,201,229,191,61,23,72,80,62,133,124,176,62,183,209,0,63,111,18,35,63,237,158,76,63,135,167,119,63,53,239,144,63,88,57,164,63,72,191,181,63,48,76,198,63,94,186,217,63,102,247,236,63,138,142,0,64,133,235,9,64,158,239,19,64,23,183,29,64,179,234,39,64,46,255,49,64,218,27,60,64,63,53,222,61,100,93,92,62,27,13,160,62,204,238,233,62,124,97,18,63,30,167,56,63,42,58,98,63,48,187,135,63,69,71,154,63,98,16,176,63,228,20,197,63,224,156,217,63,156,162,235,63,230,63,0,64,83,150,9,64,70,182,19,64,37,6,29,64,159,205,38,64,49,8,48,64,211,77,58,64,249,49,102,61,243,142,83,62,114,138,206,62,68,139,12,63,40,15,43,63,186,218,74,63,111,18,115,63,113,61,138,63,87,236,151,63,149,101,168,63,13,224,189,63,36,185,212,63,58,146,235,63,11,70,1,64,88,168,9,64,203,161,17,64,145,15,26,64,70,182,35,64,85,193,44,64,15,11,57,64,165,78,192,61,195,211,107,62,36,151,191,62,240,167,6,63,21,140,42,63,143,83,84,63,30,22,122,63,254,212,144,63,211,188,163,63,141,40,181,63,175,148,197,63,214,197,213,63,233,38,233,63,219,249,254,63,78,98,8,64,100,59,19,64,129,4,29,64,200,7,37,64,9,27,46,64,3,9,58,64,242,210,205,61,145,15,122,62,222,147,199,62,85,48,10,63,243,31,50,63,53,239,88,63,55,26,128,63,179,234,147,63,240,167,166,63,108,9,185,63,17,54,204,63,178,157,223,63,156,51,242,63,51,51,3,64,238,235,12,64,75,89,22,64,97,195,31,64,108,9,41,64,250,126,50,64,165,78,60,64,60,78,209,61,114,249,79,62,111,129,164,62,229,97,225,62,165,78,16,63,249,49,54,63,95,7,94,63,252,24,131,63,9,27,150,63,108,9,169,63,95,7,190,63,131,192,210,63,141,151,230,63,129,149,251,63,38,228,7,64,32,99,18,64,209,145,28,64,164,223,38,64,27,47,49,64,181,55,60,64,150,67,75,62,225,11,179,62,122,165,236,62,163,35,25,63,233,183,63,63,27,13,96,63,123,20,126,63,191,125,149,63,30,22,170,63,241,244,186,63,250,126,202,63,201,229,223,63,156,51,242,63,57,69,3,64,90,100,11,64,83,150,21,64,201,118,30,64,38,228,39,64,75,200,47,64,142,117,57,64,74,123,3,62,163,35,121,62,35,219,185,62,34,108,248,62,95,152,28,63,219,249,62,63,65,241,99,63,166,155,132,63,20,63,150,63,181,55,168,63,218,27,188,63,2,43,207,63,159,205,226,63,57,69,247,63,129,38,6,64,196,66,17,64,17,54,28,64,196,177,38,64,141,40,49,64,133,124,60,64,207,102,213,61,30,22,106,62,181,55,184,62,110,163,1,63,20,208,36,63,227,54,74,63,41,92,111,63,161,103,139,63,2,188,157,63,199,186,176,63,72,225,194,63,146,92,214,63,192,91,232,63,97,195,251,63,248,83,7,64,243,31,18,64,29,90,28,64,170,241,38,64,83,150,49,64,125,208,59,64,119,190,159,61,160,137,48,62,35,219,121,62,5,163,178,62,2,43,7,63,9,27,62,63,251,92,109,63,255,178,139,63,41,203,160,63,61,155,181,63,140,74,202,63,173,105,222,63,3,9,242,63,247,6,3,64,84,116,12,64,243,31,22,64,20,174,31,64,21,29,41,64,245,185,50,64,21,29,61,64,247,228,225,61,148,135,133,62,32,65,209,62,214,197,13,63,147,58,49,63,52,128,87,63,201,118,126,63,35,74,147,63,251,92,165,63,149,101,184,63,254,67,202,63,31,244,220,63,0,145,238,63,68,139,0,64,145,15,10,64,61,10,19,64,162,180,27,64,219,138,37,64,100,59,47,64,233,72,58,64,20,208,4,62,110,163,129,62,31,244,204,62,34,108,8,63,100,93,44,63,31,133,75,63,193,168,116,63,197,254,138,63,166,155,156,63,82,73,173,63,62,121,192,63,122,199,209,63,111,240,229,63,23,217,246,63,72,191,5,64,45,67,16,64,18,20,27,64,231,140,36,64,0,0,44,64,196,66,57,64,124,97,178,61,240,133,73,62,41,92,175,62,136,99,253,62,84,116,36,63,26,192,75,63,6,18,116,63,86,125,142,63,46,255,161,63,150,33,182,63,74,12,202,63,157,17,221,63,48,187,239,63,162,69,2,64,134,201,12,64,251,203,22,64,102,247,32,64,169,164,42,64,197,32,52,64,129,4,61,64,24,149,212,61,138,176,97,62,48,76,166,62,122,199,233,62,66,62,24,63,114,138,62,63,197,143,97,63,232,217,132,63,46,255,153,63,23,72,176,63,6,129,197,63,17,199,218,63,102,102,238,63,145,15,2,64,131,47,12,64,106,222,21,64,119,190,31,64,202,84,41,64,203,16,51,64,57,180,60,64,240,22,8,62,50,119,141,62,177,225,201,62,97,195,3,63,11,181,38,63,27,158,78,63,96,229,112,63,79,64,139,63,22,106,157,63,174,71,177,63,15,156,195,63,93,109,213,63,82,39,232,63,16,233,255,63,2,154,8,64,246,151,17,64,171,62,27,64,240,133,37,64,139,108,47,64,17,199,58,64,25,115,215,61,63,87,91,62,52,128,183,62,69,216,0,63,216,129,35,63,75,200,71,63,141,151,110,63,231,251,137,63,54,205,155,63,224,45,176,63,136,99,197,63,82,39,216,63,126,140,233,63,198,220,253,63,207,247,7,64,155,230,17,64,231,29,27,64,80,252,36,64,222,113,46,64,134,56,58,64,64,164,223,61,222,2,137,62,105,111,208,62,135,22,9,63,136,133,42,63,105,111,80,63,48,76,118,63,176,3,143,63,110,163,161,63,104,145,181,63,167,232,200,63,127,106,220,63,25,4,238,63,163,35,1,64,12,2,11,64,73,157,20,64,249,49,30,64,191,14,40,64,143,194,49,64,211,188,59,64,91,66,190,61,114,138,78,62,109,86,157,62,231,251,233,62,10,215,19,63,188,116,67,63,237,13,110,63,76,166,138,63,13,224,157,63,53,94,178,63,66,96,197,63,154,8,219,63,194,23,238,63,68,250,1,64,160,26,11,64,8,172,20,64,64,19,29,64,27,158,38,64,167,121,47,64,240,133,57,64,82,184,158,61,223,79,77,62,33,176,178,62,184,30,5,63,36,185,44,63,212,154,86,63,86,14,125,63,20,63,150,63,110,52,168,63,134,56,182,63,232,106,203,63,224,190,222,63,154,119,236,63,16,88,1,64,249,49,10,64,213,120,17,64,160,26,27,64,152,221,35,64,132,158,45,64,203,161,57,64,101,25,226,61,104,179,106,62,113,172,171,62,69,71,242,62,191,125,29,63,225,122,68,63,49,153,106,63,15,156,139,63,5,52,161,63,234,4,180,63,88,202,194,63,184,64,210,63,98,161,230,63,144,49,255,63,128,183,8,64,77,243,18,64,124,242,28,64,99,238,38,64,36,185,48,64,143,228,58,64,48,42,169,61,205,204,76,62,196,66,173,62,184,175,3,63,204,93,43,63,130,115,86,63,8,172,124,63,104,179,146,63,143,194,165,63,55,137,185,63,95,41,203,63,185,141,222,63,231,140,240,63,9,27,2,64,247,6,11,64,250,237,19,64,137,65,28,64,171,207,37,64,203,16,47,64,122,199,57,64,208,179,217,61,66,62,104,62,251,58,176,62,152,110,242,62,209,145,28,63,224,45,64,63,231,29,103,63,149,212,137,63,132,13,159,63,152,221,179,63,171,62,199,63,193,202,217,63,170,130,233,63,150,178,252,63,153,42,8,64,215,18,18,64,220,70,27,64,101,25,38,64,20,208,48,64,188,116,59,64,31,133,235,61,169,19,144,62,2,154,232,62,49,8,28,63,177,191,60,63,136,244,91,63,18,165,125,63,178,46,142,63,111,240,157,63,182,243,173,63,91,66,190,63,77,243,206,63,27,158,222,63,142,6,240,63,87,91,1,64,159,205,10,64,234,4,20,64,95,41,31,64,238,235,44,64,45,33,59,64,129,38,194,61,170,96,84,62,5,197,175,62,228,20,253,62,37,117,34,63,70,182,67,63,170,130,97,63,217,206,135,63,148,135,157,63,52,162,172,63,129,149,187,63,73,46,207,63,105,111,224,63,44,101,241,63,67,28,3,64,123,20,14,64,68,139,24,64,233,183,35,64,127,106,48,64,20,208,60,64,99,127,217,61,11,70,101,62,209,145,188,62,15,11,5,63,86,159,43,63,170,130,81,63,208,213,118,63,244,108,142,63,128,183,160,63,143,228,178,63,27,47,197,63,254,212,216,63,51,51,235,63,0,145,254,63,20,208,8,64,111,18,19,64,233,38,29,64,222,147,39,64,205,59,50,64,40,126,60,64,198,220,181,61,223,79,77,62,51,196,145,62,82,73,221,62,102,136,19,63,161,248,65,63,113,27,109,63,25,4,142,63,159,205,162,63,210,111,183,63,88,202,202,63,183,98,223,63,76,55,241,63,201,118,2,64,80,141,11,64,115,104,21,64,102,102,30,64,239,201,39,64,29,90,48,64,230,174,57,64,68,105,47,62,139,253,133,62,166,10,198,62,139,253,21,63,157,17,53,63,250,126,90,63,36,151,135,63,39,194,150,63,146,203,167,63,208,179,185,63,227,165,203,63,194,134,223,63,145,15,242,63,153,42,4,64,37,6,13,64,213,120,21,64,42,169,31,64,76,55,41,64,123,131,47,64,54,60,57,64,149,212,9,62,65,130,130,62,87,91,209,62,40,126,12,63,247,228,49,63,235,226,86,63,209,34,123,63,240,167,142,63,192,91,160,63,97,195,179,63,22,106,197,63,43,246,215,63,62,232,233,63,40,126,252,63,173,250,8,64,68,250,17,64,81,107,26,64,15,156,35,64,169,19,44,64,145,237,56,64,192,236,158,61,139,253,37,62,174,182,130,62,70,148,214,62,245,74,25,63,17,199,74,63,203,16,119,63,174,71,145,63,6,129,165,63,174,71,185,63,216,240,204,63,135,22,225,63,6,18,244,63,77,21,4,64,235,115,13,64,105,0,23,64,73,157,32,64,79,30,42,64,103,213,51,64,29,201,61,64,124,242,176,61,52,17,54,62,243,31,146,62,254,212,216,62,114,138,14,63,254,212,56,63,235,115,101,63,146,203,135,63,170,96,156,63,37,6,177,63,207,102,197,63,149,212,217,63,235,115,237,63,131,81,1,64,68,105,11,64,152,76,21,64,95,41,31,64,14,190,40,64,11,181,50,64,179,12,61,64,140,74,234,61,38,228,131,62,189,82,214,62,215,52,15,63,0,0,48,63,37,117,82,63,116,181,117,63,77,21,140,63,43,24,157,63,194,134,175,63,19,242,193,63,161,214,212,63,199,75,231,63,133,235,249,63,14,45,6,64,88,57,16,64,222,113,26,64,215,163,36,64,102,102,46,64,92,143,58,64,173,250,220,61,47,110,99,62,104,179,170,62,98,16,248,62,140,185,27,63,220,104,64,63,93,220,102,63,107,154,135,63,53,94,154,63,176,3,175,63,174,182,194,63,98,16,216,63,249,15,233,63,57,214,253,63,33,31,8,64,27,158,18,64,65,241,27,64,163,146,38,64,56,248,46,64,21,29,57,64,58,146,203,61,193,168,100,62,145,15,186,62,70,182,3,63,11,36,40,63,82,39,80,63,99,127,121,63,188,150,144,63,243,31,162,63,79,175,180,63,12,147,201,63,173,250,220,63,11,181,238,63,136,99,1,64,127,251,10,64,64,19,21,64,41,92,31,64,223,79,41,64,3,9,50,64,179,234,59,64,66,96,229,61,189,227,84,62,82,39,160,62,24,38,211,62,25,115,7,63,86,125,46,63,108,9,89,63,133,235,129,63,125,174,150,63,159,60,172,63,147,169,194,63,240,22,216,63,45,67,236,63,204,127,0,64,173,105,10,64,154,119,20,64,140,74,30,64,163,1,40,64,247,228,49,64,199,186,60,64,196,177,174,61,59,223,79,62,81,218,187,62,121,88,8,63,241,244,42,63,105,0,79,63,152,221,115,63,27,158,142,63,30,167,160,63,239,56,181,63,25,226,200,63,206,136,218,63,179,234,235,63,22,251,251,63,19,97,7,64,215,52,15,64,36,151,23,64,75,200,35,64,23,217,46,64,254,67,58,64,16,88,185,61,100,204,93,62,97,50,181,62,70,37,5,63,31,133,43,63,88,168,85,63,59,1,125,63,76,166,146,63,60,189,162,63,76,55,177,63,156,51,194,63,61,155,213,63,157,128,230,63,74,12,250,63,136,133,6,64,202,84,17,64,201,118,26,64,205,59,38,64,16,233,47,64,171,207,57,64,39,160,9,60,190,48,25,61,75,89,134,60,218,172,122,188,250,237,235,60,14,79,47,60,96,229,208,188,20,63,198,188,0,0,0,0,88,57,180,187,221,181,4,188,143,194,245,187,224,45,16,187,195,100,170,187,101,25,226,187,137,210,222,186,82,73,157,57,43,24,21,60,52,128,55,59,124,242,48,187,150,67,11,60,4,231,140,59,18,131,192,188,121,88,40,189,120,122,165,60,225,11,19,61,117,2,26,61,74,123,3,61,218,172,250,60,5,163,18,189,101,25,226,188,188,116,19,188,23,183,81,59,82,73,157,59,255,33,253,60,185,252,7,61,30,167,232,60,129,38,194,60,231,29,167,59,120,122,37,188,164,223,190,188,14,79,47,189,178,157,111,189,228,131,30,189,36,151,127,59,221,181,4,60,237,13,62,59,137,210,222,186,82,73,29,186,137,210,222,187,224,45,144,59,43,24,149,60,117,2,26,61,228,131,30,61,112,206,8,189,100,93,220,188,43,24,149,188,101,25,226,187,195,100,42,187,66,96,101,59,46,144,160,187,159,171,173,188,231,29,39,189,57,180,200,188,7,95,152,60,44,212,154,60,218,172,122,60,166,155,68,60,73,157,128,60,88,57,180,59,153,187,150,187,5,163,146,60,30,167,232,60,23,183,81,187,171,207,213,188,158,239,167,188,36,151,127,187,114,138,142,60,216,240,244,60,12,147,169,60,82,73,157,58,52,128,183,187,111,18,131,58,176,3,103,60,56,248,66,188,227,165,155,60,37,6,1,61,208,68,88,59,23,183,81,188,143,194,245,60,75,89,6,61,72,80,252,60,188,150,16,61,62,232,217,60,208,68,216,59,75,89,6,189,64,164,223,188,124,242,176,59,104,145,109,60,41,92,143,60,166,155,196,58,77,21,140,188,95,41,203,59,75,89,134,188,188,116,147,59,30,167,232,187,10,215,35,59,211,188,227,60,103,213,231,60,91,177,63,60,195,100,42,187,213,120,233,188,231,29,39,189,226,233,21,189,202,84,193,187,195,100,170,188,151,255,16,189,112,206,8,189,25,115,215,188,23,183,209,187,250,237,235,59,82,73,29,186,18,131,192,188,179,123,114,187,145,126,251,188,69,216,240,188,148,135,133,188,229,97,161,188,18,131,192,188,82,73,157,60,195,100,170,58,161,103,179,188,240,133,73,188,23,183,209,185,221,181,4,188,82,73,29,188,240,133,73,188,120,122,37,188,39,160,9,59,254,101,119,60,159,171,45,60,254,101,119,60,215,52,239,60,208,68,88,59,103,213,231,60,95,41,75,60,237,13,190,59,137,210,222,186,108,9,121,187,108,9,121,60,176,3,103,60,208,68,88,60,78,209,145,60,73,157,128,60,215,52,239,59,224,45,144,60,176,3,103,60,192,236,30,60,153,187,22,188,148,135,133,188,127,106,188,188,172,139,91,188,156,51,34,188,69,216,112,188,111,18,131,59,226,233,149,188,41,92,143,188,111,18,3,188,185,252,7,188,104,145,237,188,159,205,42,189,83,5,35,189,100,93,220,188,83,5,163,188,140,74,106,188,159,171,173,187,156,51,34,188,124,242,176,187,83,5,163,188,161,103,179,188,150,67,139,188,14,79,47,60,192,236,158,60,66,96,101,59,197,254,50,61,48,76,38,61,197,32,176,60,166,155,68,60,159,171,173,59,52,128,55,187,56,248,194,60,3,9,10,61,51,196,177,60,224,45,144,58,90,245,185,60,130,226,199,60,111,240,5,61,44,212,26,61,197,254,50,61,78,209,17,61,208,68,88,187,163,35,57,60,11,181,38,61,112,206,8,61,205,204,76,188,82,73,157,185,176,3,103,188,64,164,223,188,247,117,96,188,0,111,1,188,104,145,109,188,30,167,232,187,17,199,58,60,116,70,148,60,143,194,117,60,150,67,11,60,72,80,252,187,108,9,121,187,161,103,179,188,25,115,215,188,190,48,153,188,164,223,190,188,62,232,89,60,135,22,217,60,36,151,127,188,43,24,21,188,88,57,52,188,23,183,209,186,140,74,106,60,151,255,144,60,166,155,196,60,75,89,6,60,140,74,106,188,206,136,210,188,52,128,183,186,23,183,81,57,75,89,6,60,188,116,147,60,184,30,5,61,150,67,11,61,218,172,122,188,155,85,31,189,166,155,196,188,75,89,6,60,66,96,101,60,153,187,150,59,101,25,98,188,44,212,26,189], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+847000);
/* memory initializer */ allocate([226,233,21,189,106,77,243,60,59,112,206,60,36,151,255,59,59,112,206,59,82,73,29,58,224,45,144,59,179,123,242,59,117,2,26,60,163,35,57,60,49,8,44,60,247,117,96,60,161,103,51,61,98,161,214,60,36,151,255,187,80,141,151,188,197,32,176,188,11,181,38,189,14,45,50,189,195,100,170,188,23,183,209,185,250,237,107,188,158,239,167,188,95,41,203,188,184,64,130,188,101,25,226,187,218,172,122,188,208,68,88,60,115,104,17,61,33,31,244,60,166,155,68,60,250,237,235,59,202,84,193,60,25,115,87,61,202,50,68,61,164,223,190,60,62,232,89,188,103,213,231,188,91,177,63,189,211,222,96,189,80,141,23,189,23,183,81,59,52,128,183,59,153,187,22,59,10,215,163,59,82,73,29,59,138,142,228,60,237,13,62,60,188,116,147,187,82,73,157,186,14,79,47,60,227,165,155,60,242,65,207,60,154,119,156,60,4,231,140,59,9,27,158,60,114,138,14,189,240,133,201,188,240,133,73,60,49,8,172,60,27,47,93,60,82,73,29,188,234,149,50,188,108,9,249,187,36,151,127,188,104,145,237,188,111,18,131,60,192,236,158,60,161,103,179,60,61,44,212,60,205,204,204,60,119,190,159,60,109,86,253,62,210,0,254,62,145,237,252,62,236,192,249,62,208,68,248,62,188,5,242,62,3,9,234,62,222,2,233,62,11,36,232,62,248,194,228,62,247,228,225,62,192,236,222,62,191,14,220,62,245,185,218,62,48,76,230,62,11,181,230,62,213,120,233,62,67,28,235,62,15,156,243,62,173,250,252,62,219,138,125,62,180,89,53,62,58,35,74,62,73,157,64,62,104,179,42,62,127,251,58,62,42,169,83,62,114,249,79,62,197,143,49,62,228,20,29,62,96,229,16,62,143,83,52,62,184,64,66,62,235,115,53,62,249,15,41,62,183,98,255,61,97,50,213,61,218,27,252,61,217,61,57,62,248,194,100,62,185,252,135,61,0,0,64,62,246,40,220,62,186,73,44,63,206,25,97,63,39,49,136,63,112,206,160,63,14,190,184,63,220,215,209,63,30,167,232,63,131,47,0,64,94,75,12,64,94,75,24,64,94,75,36,64,166,155,48,64,200,7,61,64,62,232,89,62,96,118,207,62,43,246,7,63,65,241,35,63,154,153,73,63,215,163,96,63,154,119,140,63,165,189,169,63,215,52,199,63,121,233,214,63,60,189,234,63,227,165,7,64,122,165,20,64,99,127,29,64,76,55,41,64,196,66,57,64,242,65,79,62,104,34,172,62,52,128,247,62,159,171,45,63,30,167,104,63,72,225,138,63,163,1,156,63,38,228,179,63,9,27,206,63,232,106,227,63,38,228,251,63,190,48,9,64,74,12,22,64,34,253,34,64,172,139,47,64,227,165,59,64,106,222,241,61,158,94,105,62,19,242,225,62,182,132,28,63,66,96,69,63,202,84,113,63,27,158,142,63,76,166,162,63,27,158,190,63,192,236,222,63,204,238,249,63,229,97,9,64,193,57,23,64,23,217,34,64,218,172,46,64,121,233,58,64,68,139,236,61,150,67,139,62,199,41,250,62,32,99,46,63,163,1,92,63,207,102,133,63,203,161,157,63,79,175,180,63,185,141,206,63,240,167,230,63,4,231,252,63,187,39,11,64,132,13,23,64,156,162,35,64,32,210,47,64,93,254,59,64,248,83,227,61,12,147,169,62,152,110,242,62,206,170,15,63,157,128,54,63,160,137,80,63,127,251,130,63,78,98,168,63,193,202,201,63,24,38,227,63,21,140,250,63,249,15,9,64,166,155,20,64,37,117,34,64,7,240,46,64,156,162,59,64,12,147,41,62,31,133,171,62,217,206,215,62,36,151,15,63,200,7,45,63,67,173,89,63,231,251,145,63,56,103,180,63,148,135,205,63,217,206,215,63,122,199,225,63,202,50,0,64,233,38,17,64,133,124,32,64,179,123,46,64,136,244,59,64,79,30,22,62,254,67,186,62,186,218,234,62,32,65,17,63,31,244,60,63,41,237,93,63,20,63,118,63,239,56,149,63,211,188,187,63,100,59,223,63,238,124,247,63,228,131,6,64,63,87,19,64,100,204,33,64,252,24,47,64,57,69,59,64,245,74,217,61,19,97,131,62,5,163,242,62,91,211,44,63,105,0,95,63,222,2,137,63,229,208,162,63,129,149,187,63,68,139,212,63,36,185,236,63,35,219,1,64,145,15,14,64,181,166,25,64,57,214,37,64,165,189,49,64,25,226,60,64,138,142,228,61,215,18,114,62,177,80,203,62,138,176,33,63,140,185,91,63,186,73,132,63,175,148,149,63,254,67,170,63,103,213,199,63,91,211,228,63,171,207,253,63,255,33,13,64,176,3,23,64,170,241,34,64,127,251,46,64,188,116,59,64,66,62,136,62,189,82,214,62,193,57,3,63,171,207,37,63,165,189,97,63,66,96,141,63,111,129,164,63,161,214,180,63,143,228,202,63,190,48,225,63,165,78,248,63,171,62,11,64,222,147,23,64,211,222,32,64,50,85,44,64,117,2,58,64,135,22,25,62,177,191,140,62,183,209,224,62,229,97,33,63,28,235,82,63,26,81,130,63,55,137,153,63,126,29,176,63,46,144,200,63,115,215,226,63,239,201,251,63,201,118,10,64,77,243,22,64,19,97,35,64,227,165,47,64,36,151,59,64,17,199,186,61,33,31,52,62,173,250,156,62,96,229,16,63,145,237,76,63,216,240,116,63,25,115,151,63,181,166,185,63,126,29,208,63,2,188,229,63,36,185,0,64,20,208,12,64,183,98,23,64,48,187,35,64,224,190,50,64,211,77,62,64,21,140,10,62,122,165,140,62,41,203,208,62,222,2,25,63,120,11,68,63,12,147,105,63,57,214,141,63,201,118,174,63,51,51,203,63,13,113,228,63,155,85,247,63,243,142,7,64,32,65,21,64,94,75,32,64,161,248,45,64,61,10,59,64,130,115,70,62,142,6,208,62,18,20,255,62,181,166,25,63,212,43,69,63,181,55,104,63,118,224,148,63,94,186,177,63,180,89,205,63,16,233,231,63,231,29,247,63,23,183,5,64,0,111,17,64,99,127,29,64,17,54,40,64,50,85,56,64,36,40,62,62,58,146,171,62,165,78,224,62,131,47,28,63,197,143,65,63,12,2,91,63,75,234,132,63,188,150,168,63,160,137,200,63,7,95,216,63,101,170,224,63,234,4,252,63,237,158,16,64,252,169,33,64,114,138,46,64,190,193,59,64,170,96,212,61,228,20,93,62,244,108,214,62,237,13,30,63,45,178,77,63,227,165,131,63,118,224,156,63,221,36,182,63,133,235,209,63,136,133,234,63,238,235,0,64,36,185,12,64,78,98,24,64,100,93,36,64,36,185,48,64,56,103,60,64,102,102,38,62,150,33,142,62,236,81,216,62,39,160,25,63,208,179,73,63,144,160,104,63,184,64,138,63,177,80,163,63,11,181,190,63,155,85,223,63,93,220,254,63,248,83,11,64,195,211,23,64,9,249,36,64,176,3,51,64,13,113,60,64,153,42,88,62,53,94,186,62,120,122,21,63,190,159,58,63,9,27,78,63,94,75,128,63,203,161,157,63,200,7,181,63,8,61,203,63,150,67,227,63,191,125,253,63,83,150,9,64,97,50,21,64,113,61,34,64,36,185,48,64,237,158,60,64,23,183,17,62,167,121,135,62,97,195,211,62,92,143,34,63,141,151,78,63,243,142,115,63,77,243,142,63,92,32,169,63,204,238,201,63,44,212,226,63,7,95,248,63,84,227,9,64,252,169,21,64,118,224,32,64,155,85,47,64,163,35,61,64,103,213,231,61,143,83,116,62,215,18,210,62,103,213,23,63,130,226,71,63,31,244,124,63,80,141,151,63,115,104,177,63,157,17,205,63,162,69,230,63,105,0,255,63,98,16,12,64,30,167,24,64,188,150,36,64,96,229,48,64,47,221,60,64,165,189,1,62,239,56,133,62,121,88,200,62,153,42,24,63,65,130,66,63,3,120,107,63,46,255,137,63,131,192,162,63,195,211,195,63,53,239,224,63,116,36,247,63,73,157,8,64,167,232,20,64,125,174,34,64,75,200,47,64,227,165,59,64,187,39,79,62,77,243,174,62,211,222,224,62,168,53,29,63,59,112,62,63,22,251,91,63,95,7,142,63,180,89,173,63,53,94,194,63,223,224,211,63,52,162,228,63,178,46,2,64,44,101,17,64,7,240,30,64,142,117,45,64,24,149,60,64,65,241,227,61,145,237,124,62,45,67,188,62,197,143,17,63,184,30,69,63,123,131,111,63,26,81,138,63,183,98,159,63,242,210,189,63,210,0,222,63,98,161,246,63,80,252,8,64,12,147,21,64,228,20,33,64,213,231,46,64,67,173,57,64,195,100,42,62,253,246,181,62,54,171,14,63,242,65,63,63,8,172,108,63,63,198,140,63,113,172,163,63,129,149,187,63,212,43,213,63,44,212,234,63,70,37,1,64,78,209,13,64,227,54,26,64,237,13,38,64,35,219,49,64,244,253,60,64,130,115,6,62,102,102,134,62,42,58,242,62,102,247,36,63,178,157,79,63,118,224,124,63,67,28,147,63,21,29,169,63,5,52,201,63,153,42,232,63,134,56,254,63,105,111,12,64,5,197,23,64,255,178,35,64,176,3,47,64,145,126,59,64,143,228,242,61,90,100,155,62,32,65,1,63,178,157,47,63,182,243,93,63,41,92,127,63,142,117,145,63,198,109,172,63,96,229,200,63,164,223,222,63,249,160,247,63,110,163,9,64,220,215,21,64,254,101,35,64,177,225,49,64,224,156,61,64,28,235,226,61,30,22,138,62,43,24,245,62,10,104,34,63,108,120,74,63,207,102,117,63,152,110,146,63,216,240,172,63,227,199,200,63,245,74,225,63,75,89,246,63,65,241,7,64,64,19,21,64,250,126,34,64,229,208,46,64,48,187,59,64,94,186,201,61,140,185,107,62,235,115,181,62,47,110,19,63,111,18,67,63,203,16,119,63,95,41,147,63,139,108,167,63,102,102,198,63,127,106,228,63,149,212,249,63,252,24,11,64,229,208,22,64,137,65,36,64,8,172,48,64,184,64,58,64,254,101,247,61,86,159,139,62,165,78,224,62,115,215,18,63,173,250,60,63,180,200,86,63,60,78,129,63,247,228,161,63,174,71,193,63,100,59,223,63,138,31,251,63,233,38,9,64,48,42,21,64,129,4,33,64,86,125,46,64,77,243,58,64,46,255,33,62,178,46,142,62,184,30,229,62,162,180,39,63,250,237,91,63,64,19,129,63,101,25,146,63,243,31,170,63,172,139,203,63,61,44,228,63,129,38,250,63,27,158,10,64,242,176,20,64,23,72,32,64,78,98,44,64,164,223,58,64,150,67,11,62,252,24,147,62,131,192,234,62,233,38,33,63,238,90,66,63,172,173,104,63,48,76,134,63,127,251,162,63,59,1,197,63,47,110,227,63,43,246,247,63,111,129,8,64,116,70,20,64,147,24,32,64,130,226,43,64,138,142,56,64,235,115,181,61,35,74,59,62,54,60,189,62,91,211,28,63,180,89,85,63,94,186,129,63,120,122,157,63,195,211,187,63,118,79,214,63,132,158,237,63,90,100,3,64,2,43,15,64,16,88,25,64,108,9,37,64,110,163,49,64,71,3,60,64,223,79,77,62,43,24,181,62,215,163,240,62,114,249,31,63,86,14,61,63,25,226,104,63,228,131,150,63,227,199,176,63,234,4,196,63,242,210,213,63,136,99,237,63,152,221,7,64,157,17,21,64,61,155,33,64,235,226,50,64,2,188,61,64,150,178,76,62,155,85,159,62,51,196,241,62,7,240,54,63,120,11,100,63,192,91,128,63,210,111,151,63,90,245,177,63,102,102,206,63,224,45,224,63,45,67,244,63,185,252,7,64,53,239,20,64,107,43,34,64,176,114,44,64,64,19,57,64,0,145,254,61,93,109,133,62,192,91,224,62,143,194,21,63,125,63,69,63,222,2,121,63,9,138,143,63,187,39,167,63,88,202,194,63,251,203,222,63,31,244,244,63,193,168,8,64,50,119,21,64,226,233,33,64,5,163,46,64,3,9,58,64,134,201,212,61,34,108,120,62,53,94,218,62,211,222,32,63,242,176,80,63,86,125,126,63,181,166,153,63,184,175,179,63,113,172,203,63,204,93,227,63,31,133,251,63,42,58,10,64,205,59,22,64,138,31,35,64,74,123,47,64,42,169,59,64,113,172,11,62,217,206,119,62,148,246,198,62,79,30,22,63,61,44,68,63,10,104,98,63,12,2,139,63,99,127,169,63,98,161,198,63,200,7,229,63,142,6,0,64,46,255,9,64,95,41,23,64,106,77,35,64,97,50,49,64,39,194,58,64,245,219,23,62,161,248,145,62,38,83,229,62,83,150,33,63,186,218,74,63,232,106,123,63,242,210,149,63,63,87,171,63,205,204,196,63,40,126,220,63,223,224,243,63,168,87,6,64,21,140,18,64,255,178,31,64,205,204,44,64,206,136,58,64,251,203,110,62,240,133,233,62,81,107,10,63,247,6,31,63,73,157,64,63,211,77,82,63,97,195,115,63,104,145,149,63,202,195,194,63,35,74,219,63,243,31,234,63,11,36,4,64,139,253,17,64,181,21,31,64,32,65,45,64,254,101,59,64,3,9,10,62,27,13,160,62,24,149,4,63,126,29,56,63,17,54,108,63,71,114,145,63,32,65,169,63,118,224,188,63,177,80,211,63,69,216,232,63,130,226,255,63,122,165,12,64,20,208,24,64,75,234,36,64,117,147,48,64,6,18,60,64,174,216,223,61,10,104,98,62,152,221,243,62,200,152,43,63,234,4,84,63,33,31,116,63,183,98,143,63,188,150,176,63,180,89,205,63,251,203,230,63,127,217,253,63,254,67,10,64,50,230,22,64,120,122,37,64,195,245,48,64,96,118,59,64,219,249,62,62,127,251,154,62,250,126,234,62,163,1,44,63,61,10,87,63,179,12,129,63,50,85,152,63,220,104,176,63,2,188,197,63,197,32,216,63,60,78,249,63,161,214,8,64,155,230,17,64,36,185,32,64,168,198,47,64,230,63,60,64,174,71,33,62,229,242,159,62,95,7,238,62,165,78,32,63,100,59,79,63,100,93,124,63,235,115,149,63,9,27,174,63,208,68,200,63,179,12,225,63,113,61,250,63,196,177,10,64,29,56,23,64,150,178,36,64,135,22,49,64,238,235,60,64,105,111,240,61,178,46,142,62,224,190,238,62,243,31,34,63,92,32,81,63,147,58,129,63,197,32,152,63,217,61,177,63,69,71,202,63,167,232,224,63,98,16,248,63,124,242,8,64,127,217,21,64,212,154,34,64,160,26,47,64,0,0,60,64,26,192,219,61,103,213,103,62,179,12,209,62,167,232,24,63,155,85,63,63,243,142,115,63,103,68,145,63,174,182,170,63,219,138,197,63,237,13,222,63,98,16,248,63,190,48,9,64,188,5,22,64,159,205,34,64,140,185,47,64,27,13,60,64,153,187,22,62,188,116,147,62,207,102,245,62,247,117,32,63,27,47,77,63,112,206,128,63,182,243,149,63,169,164,174,63,82,184,198,63,23,217,222,63,157,128,246,63,81,218,7,64,209,145,20,64,31,244,32,64,72,191,45,64,186,218,58,64,41,203,16,62,248,83,131,62,54,171,222,62,13,113,28,63,244,253,68,63,252,24,115,63,123,131,143,63,193,202,169,63,88,202,194,63,116,70,220,63,90,100,243,63,67,173,5,64,17,54,20,64,40,126,32,64,140,74,46,64,94,75,60,64,110,52,0,62,231,140,136,62,120,11,228,62,52,162,36,63,48,76,86,63,83,150,129,63,12,2,155,63,125,63,181,63,59,223,207,63,99,127,233,63,1,77,0,64,52,162,12,64,9,249,24,64,173,250,36,64,118,224,48,64,172,173,60,64,57,69,7,62,248,83,131,62,75,234,196,62,230,174,21,63,46,255,65,63,200,7,109,63,82,39,136,63,193,168,156,63,49,8,188,63,95,7,222,63,205,204,252,63,120,11,12,64,190,193,23,64,242,65,35,64,141,151,46,64,47,221,56,64,24,38,19,62,25,4,150,62,174,182,226,62,246,151,29,63,182,243,77,63,153,187,118,63,92,143,146,63,153,42,168,63,220,215,193,63,221,36,222,63,5,52,249,63,78,209,9,64,127,217,21,64,143,228,34,64,40,15,47,64,211,188,59,64,196,66,45,62,242,210,141,62,175,37,196,62,246,40,28,63,236,81,72,63,150,33,110,63,254,212,136,63,190,193,159,63,111,18,187,63,247,6,215,63,223,79,245,63,45,33,11,64,231,251,21,64,205,59,34,64,197,32,48,64,169,164,58,64,145,237,252,61,164,223,126,62,192,236,222,62,124,97,34,63,115,215,82,63,69,216,128,63,34,108,152,63,154,119,172,63,149,101,200,63,133,235,233,63,207,247,3,64,165,78,16,64,201,118,26,64,220,215,37,64,189,227,48,64,211,188,59,64,100,59,223,61,112,206,72,62,38,83,197,62,19,242,17,63,125,208,51,63,124,97,98,63,149,212,145,63,176,114,176,63,49,8,204,63,54,205,227,63,140,219,248,63,209,34,11,64,193,168,24,64,124,242,36,64,235,115,49,64,202,50,60,64,119,190,31,62,188,5,178,62,23,72,0,63,124,242,32,63,1,222,66,63,109,86,125,63,248,83,147,63,168,198,171,63,104,145,197,63,171,62,215,63,190,193,239,63,153,42,4,64,36,185,16,64,93,254,31,64,9,249,44,64,22,106,57,64,207,102,21,62,254,101,119,62,230,63,196,62,31,133,11,63,76,166,74,63,218,27,108,63,62,121,136,63,151,255,152,63,58,146,179,63,79,175,212,63,199,75,247,63,109,86,9,64,159,171,21,64,182,132,32,64,123,131,43,64,23,217,58,64,118,79,30,62,38,83,197,62,118,79,30,63,117,147,88,63,206,170,135,63,18,20,159,63,46,255,177,63,61,10,199,63,0,145,222,63,250,126,242,63,69,216,4,64,57,69,15,64,138,176,25,64,18,131,36,64,62,121,48,64,246,40,60,64,27,47,221,61,159,60,108,62,206,136,210,62,177,80,27,63,143,194,69,63,238,90,114,63,176,114,144,63,37,6,169,63,84,116,196,63,44,101,225,63,144,49,255,63,234,4,12,64,99,238,22,64,199,75,35,64,215,18,46,64,226,233,57,64,190,193,23,62,174,182,162,62,45,33,255,62,238,90,34,63,171,62,71,63,145,237,124,63,220,215,153,63,58,146,171,63,186,218,194,63,136,99,221,63,155,230,245,63,3,9,6,64,60,189,18,64,27,13,32,64,159,171,45,64,154,8,59,64,250,126,234,61,244,253,148,62,81,107,250,62,249,49,38,63,142,6,80,63,207,247,115,63,160,26,143,63,78,98,168,63,242,176,192,63,251,58,216,63,62,232,241,63,107,154,7,64,138,176,21,64,220,70,35,64,159,205,46,64,154,8,59,64,165,78,192,61,31,244,44,62,102,102,166,62,116,70,20,63,157,17,69,63,8,172,108,63,175,37,148,63,213,120,177,63,116,70,204,63,9,27,230,63,116,181,253,63,122,199,9,64,82,73,21,64,188,116,35,64,214,86,48,64,224,190,58,64,0,145,254,61,109,86,125,62,140,219,200,62,196,177,30,63,222,113,74,63,55,26,112,63,95,41,147,63,146,203,175,63,25,115,199,63,219,249,222,63,101,25,250,63,47,221,8,64,106,188,20,64,214,197,33,64,88,202,46,64,60,189,58,64,112,206,72,62,201,229,191,62,111,129,4,63,216,129,35,63,92,32,81,63,9,27,134,63,236,47,155,63,240,133,177,63,48,187,199,63,225,122,220,63,137,65,240,63,87,91,5,64,170,241,18,64,193,168,32,64,176,114,44,64,128,183,56,64,166,155,4,62,52,17,118,62,198,109,212,62,59,112,30,63,163,146,74,63,94,186,105,63,76,166,138,63,113,172,163,63,63,53,190,63,154,8,219,63,39,160,249,63,144,160,8,64,51,196,17,64,130,226,31,64,243,142,47,64,216,240,60,64,111,18,131,60,116,70,20,61,192,236,30,60,17,199,186,59,52,128,183,186,215,52,239,187,153,187,150,187,23,183,209,187,20,63,70,188,108,9,249,58,33,31,116,60,88,57,52,189,202,50,68,189,154,119,28,189,166,155,68,189,43,24,149,188,150,67,139,60,17,199,58,60,33,31,244,188,41,92,143,188,208,68,88,187,151,255,16,189,96,229,80,189,10,215,35,187,145,126,251,60,5,197,15,61,222,113,10,61,49,8,44,61,101,25,98,60,41,92,143,188,231,29,39,188,159,171,173,59,39,160,9,60,82,73,157,185,85,193,40,61,124,242,48,187,104,145,109,60,36,151,127,187,185,252,7,60,10,215,35,61,23,183,209,56,98,161,214,188,88,57,180,59,75,89,6,188,114,138,14,61,87,91,49,61,247,117,96,60,82,73,29,187,88,57,180,187,98,161,214,60,207,102,85,61,77,243,14,61,80,141,151,60,108,9,249,59,147,169,2,189,29,201,101,189,127,106,60,189,242,65,207,188,192,236,30,188,148,135,133,60,153,187,150,60,179,123,114,187,166,155,68,189,43,246,23,189,73,157,128,61,39,49,136,61,179,123,242,60,17,199,186,187,242,65,207,60,90,245,185,60,41,92,15,61,187,184,141,61,100,59,95,61,234,149,178,60,117,2,26,60,16,233,55,189,7,95,24,189,111,18,3,58,134,90,211,60,202,84,65,60,213,120,233,60,227,165,155,61,121,88,168,61,245,219,87,61,216,240,244,188,46,144,160,187,150,67,139,60,119,190,159,60,137,210,94,60,140,74,234,60,177,191,236,60,211,188,99,60,124,242,176,59,108,9,121,60,130,226,199,60,52,128,55,59,52,128,183,187,244,253,212,188,145,126,251,60,140,74,106,61,114,138,14,188,224,45,16,60,95,41,203,59,0,0,0,0,205,204,76,60,0,0,0,0,215,52,239,188,158,239,167,61,234,149,178,61,1,77,132,61,187,184,13,61,108,9,249,59,224,45,16,187,242,65,207,188,66,62,104,189,117,2,154,188,39,160,9,189,149,212,137,189,211,222,96,189,185,252,135,188,61,44,212,188,66,96,101,188,111,18,131,59,237,13,62,187,197,32,48,189,99,127,89,189,242,65,207,188,108,9,249,186,30,167,232,187,9,249,32,61,250,237,235,59,111,240,5,189,202,84,193,188,18,131,192,188,151,255,144,188,7,95,152,188,66,96,229,188,193,168,164,188,72,80,252,187,118,224,28,61,122,54,43,61,74,123,3,61,69,216,240,60,222,113,138,60,91,177,63,61,70,148,246,60,62,232,89,60,79,175,20,61,134,90,83,61,201,229,191,61,182,243,253,61,5,197,15,62,20,174,7,62,32,65,241,61,95,152,204,61,132,158,205,60,179,123,114,187,131,192,74,189,114,249,143,189,161,103,179,188,171,207,213,188,108,9,249,188,231,29,167,188,7,95,24,189,115,104,17,61,98,161,86,60,7,95,24,188,156,51,34,188,101,25,226,187,137,210,94,187,244,253,212,187,195,100,170,188,54,60,189,188,91,177,63,188,232,217,172,188,203,16,199,188,153,187,150,59,14,79,47,188,66,96,229,187,240,133,73,60,127,106,188,60,108,9,121,60,75,89,134,60,85,193,40,61,219,138,125,61,233,183,175,61,160,137,176,61,52,128,183,187,205,204,76,60,43,24,149,60,150,33,14,61,192,236,30,61,17,199,58,61,11,181,38,61,22,251,203,188,127,106,60,189,85,193,168,60,216,240,244,60,242,65,207,60,12,147,169,60,151,255,144,60,56,248,194,60,242,65,207,60,166,155,68,59,39,160,137,59,111,18,3,59,221,181,4,188,137,210,94,188,104,145,237,188,39,160,137,187,130,226,71,60,231,29,167,59,14,79,47,60,17,199,186,60,232,217,172,60,137,210,222,187,234,149,50,189,216,240,244,188,36,151,255,187,9,138,159,189,31,244,236,189,40,15,139,189,4,231,140,60,143,194,117,60,231,29,167,187,221,181,4,60,23,183,81,189,72,80,124,189,250,237,107,61,156,162,163,61,84,116,164,61,39,160,9,61,23,183,209,56,33,31,244,188,80,252,152,189,127,106,60,188,120,122,37,188,150,67,139,188,10,215,163,187,114,138,142,60,104,145,237,188,107,43,118,189,143,194,117,188,20,63,70,60,2,43,135,60,127,106,188,60,52,128,55,59,220,215,1,189,2,43,135,188,78,209,17,61,199,186,56,61,166,155,68,60,74,123,3,61,39,160,9,60,237,13,190,187,130,226,71,60,221,36,70,62,89,134,56,62,156,196,96,62,180,200,118,62,229,97,97,62,147,24,68,62,127,106,60,62,221,36,70,62,120,156,98,62,189,227,84,62,91,66,62,62,58,35,74,62,11,70,101,62,228,131,94,62,127,106,60,62,135,22,89,62,145,126,251,62,24,149,244,62,223,224,235,62,37,6,225,62,120,156,226,62,101,170,224,62,101,25,226,62,201,118,222,62,108,9,217,62,72,191,221,62,194,134,231,62,37,117,226,62,184,30,229,62,73,157,224,62,20,174,231,62,156,162,227,62,185,252,135,61,0,0,64,62,246,40,220,62,186,73,44,63,206,25,97,63,39,49,136,63,112,206,160,63,14,190,184,63,220,215,209,63,30,167,232,63,131,47,0,64,94,75,12,64,94,75,24,64,94,75,36,64,166,155,48,64,200,7,61,64,62,232,89,62,96,118,207,62,43,246,7,63,65,241,35,63,154,153,73,63,215,163,96,63,154,119,140,63,165,189,169,63,215,52,199,63,121,233,214,63,60,189,234,63,227,165,7,64,122,165,20,64,99,127,29,64,76,55,41,64,196,66,57,64,242,65,79,62,104,34,172,62,52,128,247,62,159,171,45,63,30,167,104,63,72,225,138,63,163,1,156,63,38,228,179,63,9,27,206,63,232,106,227,63,38,228,251,63,190,48,9,64,74,12,22,64,34,253,34,64,172,139,47,64,227,165,59,64,106,222,241,61,158,94,105,62,19,242,225,62,182,132,28,63,66,96,69,63,202,84,113,63,27,158,142,63,76,166,162,63,27,158,190,63,192,236,222,63,204,238,249,63,229,97,9,64,193,57,23,64,23,217,34,64,218,172,46,64,121,233,58,64,68,139,236,61,150,67,139,62,199,41,250,62,32,99,46,63,163,1,92,63,207,102,133,63,203,161,157,63,79,175,180,63,185,141,206,63,240,167,230,63,4,231,252,63,187,39,11,64,132,13,23,64,156,162,35,64,32,210,47,64,93,254,59,64,248,83,227,61,12,147,169,62,152,110,242,62,206,170,15,63,157,128,54,63,160,137,80,63,127,251,130,63,78,98,168,63,193,202,201,63,24,38,227,63,21,140,250,63,249,15,9,64,166,155,20,64,37,117,34,64,7,240,46,64,156,162,59,64,12,147,41,62,31,133,171,62,217,206,215,62,36,151,15,63,200,7,45,63,67,173,89,63,231,251,145,63,56,103,180,63,148,135,205,63,217,206,215,63,122,199,225,63,202,50,0,64,233,38,17,64,133,124,32,64,179,123,46,64,136,244,59,64,79,30,22,62,254,67,186,62,186,218,234,62,32,65,17,63,31,244,60,63,41,237,93,63,20,63,118,63,239,56,149,63,211,188,187,63,100,59,223,63,238,124,247,63,228,131,6,64,63,87,19,64,100,204,33,64,252,24,47,64,57,69,59,64,245,74,217,61,19,97,131,62,5,163,242,62,91,211,44,63,105,0,95,63,222,2,137,63,229,208,162,63,129,149,187,63,68,139,212,63,36,185,236,63,35,219,1,64,145,15,14,64,181,166,25,64,57,214,37,64,165,189,49,64,25,226,60,64,138,142,228,61,215,18,114,62,177,80,203,62,138,176,33,63,140,185,91,63,186,73,132,63,175,148,149,63,254,67,170,63,103,213,199,63,91,211,228,63,171,207,253,63,255,33,13,64,176,3,23,64,170,241,34,64,127,251,46,64,188,116,59,64,66,62,136,62,189,82,214,62,193,57,3,63,171,207,37,63,165,189,97,63,66,96,141,63,111,129,164,63,161,214,180,63,143,228,202,63,190,48,225,63,165,78,248,63,171,62,11,64,222,147,23,64,211,222,32,64,50,85,44,64,117,2,58,64,135,22,25,62,177,191,140,62,183,209,224,62,229,97,33,63,28,235,82,63,26,81,130,63,55,137,153,63,126,29,176,63,46,144,200,63,115,215,226,63,239,201,251,63,201,118,10,64,77,243,22,64,19,97,35,64,227,165,47,64,36,151,59,64,17,199,186,61,33,31,52,62,173,250,156,62,96,229,16,63,145,237,76,63,216,240,116,63,25,115,151,63,181,166,185,63,126,29,208,63,2,188,229,63,36,185,0,64,20,208,12,64,183,98,23,64,48,187,35,64,224,190,50,64,211,77,62,64,21,140,10,62,122,165,140,62,41,203,208,62,222,2,25,63,120,11,68,63,12,147,105,63,57,214,141,63,201,118,174,63,51,51,203,63,13,113,228,63,155,85,247,63,243,142,7,64,32,65,21,64,94,75,32,64,161,248,45,64,61,10,59,64,130,115,70,62,142,6,208,62,18,20,255,62,181,166,25,63,212,43,69,63,181,55,104,63,118,224,148,63,94,186,177,63,180,89,205,63,16,233,231,63,231,29,247,63,23,183,5,64,0,111,17,64,99,127,29,64,17,54,40,64,50,85,56,64,36,40,62,62,58,146,171,62,165,78,224,62,131,47,28,63,197,143,65,63,12,2,91,63,75,234,132,63,188,150,168,63,160,137,200,63,7,95,216,63,101,170,224,63,234,4,252,63,237,158,16,64,252,169,33,64,114,138,46,64,190,193,59,64,170,96,212,61,228,20,93,62,244,108,214,62,237,13,30,63,45,178,77,63,227,165,131,63,118,224,156,63,221,36,182,63,133,235,209,63,136,133,234,63,238,235,0,64,36,185,12,64,78,98,24,64,100,93,36,64,36,185,48,64,56,103,60,64,102,102,38,62,150,33,142,62,236,81,216,62,39,160,25,63,208,179,73,63,144,160,104,63,184,64,138,63,177,80,163,63,11,181,190,63,155,85,223,63,93,220,254,63,248,83,11,64,195,211,23,64,9,249,36,64,176,3,51,64,13,113,60,64,153,42,88,62,53,94,186,62,120,122,21,63,190,159,58,63,9,27,78,63,94,75,128,63,203,161,157,63,200,7,181,63,8,61,203,63,150,67,227,63,191,125,253,63,83,150,9,64,97,50,21,64,113,61,34,64,36,185,48,64,237,158,60,64,23,183,17,62,167,121,135,62,97,195,211,62,92,143,34,63,141,151,78,63,243,142,115,63,77,243,142,63,92,32,169,63,204,238,201,63,44,212,226,63,7,95,248,63,84,227,9,64,252,169,21,64,118,224,32,64,155,85,47,64,163,35,61,64,103,213,231,61,143,83,116,62,215,18,210,62,103,213,23,63,130,226,71,63,31,244,124,63,80,141,151,63,115,104,177,63,157,17,205,63,162,69,230,63,105,0,255,63,98,16,12,64,30,167,24,64,188,150,36,64,96,229,48,64,47,221,60,64,165,189,1,62,239,56,133,62,121,88,200,62,153,42,24,63,65,130,66,63,3,120,107,63,46,255,137,63,131,192,162,63,195,211,195,63,53,239,224,63,116,36,247,63,73,157,8,64,167,232,20,64,125,174,34,64,75,200,47,64,227,165,59,64,187,39,79,62,77,243,174,62,211,222,224,62,168,53,29,63,59,112,62,63,22,251,91,63,95,7,142,63,180,89,173,63,53,94,194,63,223,224,211,63,52,162,228,63,178,46,2,64,44,101,17,64,7,240,30,64,142,117,45,64,24,149,60,64,65,241,227,61,145,237,124,62,45,67,188,62,197,143,17,63,184,30,69,63,123,131,111,63,26,81,138,63,183,98,159,63,242,210,189,63,210,0,222,63,98,161,246,63,80,252,8,64,12,147,21,64,228,20,33,64,213,231,46,64,67,173,57,64,195,100,42,62,253,246,181,62,54,171,14,63,242,65,63,63,8,172,108,63,63,198,140,63,113,172,163,63,129,149,187,63,212,43,213,63,44,212,234,63,70,37,1,64,78,209,13,64,227,54,26,64,237,13,38,64,35,219,49,64,244,253,60,64,130,115,6,62,102,102,134,62,42,58,242,62,102,247,36,63,178,157,79,63,118,224,124,63,67,28,147,63,21,29,169,63,5,52,201,63,153,42,232,63,134,56,254,63,105,111,12,64,5,197,23,64,255,178,35,64,176,3,47,64,145,126,59,64,143,228,242,61,90,100,155,62,32,65,1,63,178,157,47,63,182,243,93,63,41,92,127,63,142,117,145,63,198,109,172,63,96,229,200,63,164,223,222,63,249,160,247,63,110,163,9,64,220,215,21,64,254,101,35,64,177,225,49,64,224,156,61,64,28,235,226,61,30,22,138,62,43,24,245,62,10,104,34,63,108,120,74,63,207,102,117,63,152,110,146,63,216,240,172,63,227,199,200,63,245,74,225,63,75,89,246,63,65,241,7,64,64,19,21,64,250,126,34,64,229,208,46,64,48,187,59,64,94,186,201,61,140,185,107,62,235,115,181,62,47,110,19,63,111,18,67,63,203,16,119,63,95,41,147,63,139,108,167,63,102,102,198,63,127,106,228,63,149,212,249,63,252,24,11,64,229,208,22,64,137,65,36,64,8,172,48,64,184,64,58,64,254,101,247,61,86,159,139,62,165,78,224,62,115,215,18,63,173,250,60,63,180,200,86,63,60,78,129,63,247,228,161,63,174,71,193,63,100,59,223,63,138,31,251,63,233,38,9,64,48,42,21,64,129,4,33,64,86,125,46,64,77,243,58,64,46,255,33,62,178,46,142,62,184,30,229,62,162,180,39,63,250,237,91,63,64,19,129,63,101,25,146,63,243,31,170,63,172,139,203,63,61,44,228,63,129,38,250,63,27,158,10,64,242,176,20,64,23,72,32,64,78,98,44,64,164,223,58,64,150,67,11,62,252,24,147,62,131,192,234,62,233,38,33,63,238,90,66,63,172,173,104,63,48,76,134,63,127,251,162,63,59,1,197,63,47,110,227,63,43,246,247,63,111,129,8,64,116,70,20,64,147,24,32,64,130,226,43,64,138,142,56,64,235,115,181,61,35,74,59,62,54,60,189,62,91,211,28,63,180,89,85,63,94,186,129,63,120,122,157,63,195,211,187,63,118,79,214,63,132,158,237,63,90,100,3,64,2,43,15,64,16,88,25,64,108,9,37,64,110,163,49,64,71,3,60,64,223,79,77,62,43,24,181,62,215,163,240,62,114,249,31,63,86,14,61,63,25,226,104,63,228,131,150,63,227,199,176,63,234,4,196,63,242,210,213,63,136,99,237,63,152,221,7,64,157,17,21,64,61,155,33,64,235,226,50,64,2,188,61,64,150,178,76,62,155,85,159,62,51,196,241,62,7,240,54,63,120,11,100,63,192,91,128,63,210,111,151,63,90,245,177,63,102,102,206,63,224,45,224,63,45,67,244,63,185,252,7,64,53,239,20,64,107,43,34,64,176,114,44,64,64,19,57,64,0,145,254,61,93,109,133,62,192,91,224,62,143,194,21,63,125,63,69,63,222,2,121,63,9,138,143,63,187,39,167,63,88,202,194,63,251,203,222,63,31,244,244,63,193,168,8,64,50,119,21,64,226,233,33,64,5,163,46,64,3,9,58,64,134,201,212,61,34,108,120,62,53,94,218,62,211,222,32,63,242,176,80,63,86,125,126,63,181,166,153,63,184,175,179,63,113,172,203,63,204,93,227,63,31,133,251,63,42,58,10,64,205,59,22,64,138,31,35,64,74,123,47,64,42,169,59,64,113,172,11,62,217,206,119,62,148,246,198,62,79,30,22,63,61,44,68,63,10,104,98,63,12,2,139,63,99,127,169,63,98,161,198,63,200,7,229,63,142,6,0,64,46,255,9,64,95,41,23,64,106,77,35,64,97,50,49,64,39,194,58,64,245,219,23,62,161,248,145,62,38,83,229,62,83,150,33,63,186,218,74,63,232,106,123,63,242,210,149,63,63,87,171,63,205,204,196,63,40,126,220,63,223,224,243,63,168,87,6,64,21,140,18,64,255,178,31,64,205,204,44,64,206,136,58,64,251,203,110,62,240,133,233,62,81,107,10,63,247,6,31,63,73,157,64,63,211,77,82,63,97,195,115,63,104,145,149,63,202,195,194,63,35,74,219,63,243,31,234,63,11,36,4,64,139,253,17,64,181,21,31,64,32,65,45,64,254,101,59,64,3,9,10,62,27,13,160,62,24,149,4,63,126,29,56,63,17,54,108,63,71,114,145,63,32,65,169,63,118,224,188,63,177,80,211,63,69,216,232,63,130,226,255,63,122,165,12,64,20,208,24,64,75,234,36,64,117,147,48,64,6,18,60,64,174,216,223,61,10,104,98,62,152,221,243,62,200,152,43,63,234,4,84,63,33,31,116,63,183,98,143,63,188,150,176,63,180,89,205,63,251,203,230,63,127,217,253,63,254,67,10,64,50,230,22,64,120,122,37,64,195,245,48,64,96,118,59,64,219,249,62,62,127,251,154,62,250,126,234,62,163,1,44,63,61,10,87,63,179,12,129,63,50,85,152,63,220,104,176,63,2,188,197,63,197,32,216,63,60,78,249,63,161,214,8,64,155,230,17,64,36,185,32,64,168,198,47,64,230,63,60,64,174,71,33,62,229,242,159,62,95,7,238,62,165,78,32,63,100,59,79,63,100,93,124,63,235,115,149,63,9,27,174,63,208,68,200,63,179,12,225,63,113,61,250,63,196,177,10,64,29,56,23,64,150,178,36,64,135,22,49,64,238,235,60,64,105,111,240,61,178,46,142,62,224,190,238,62,243,31,34,63,92,32,81,63,147,58,129,63,197,32,152,63,217,61,177,63,69,71,202,63,167,232,224,63,98,16,248,63,124,242,8,64,127,217,21,64,212,154,34,64,160,26,47,64,0,0,60,64,26,192,219,61,103,213,103,62,179,12,209,62,167,232,24,63,155,85,63,63,243,142,115,63,103,68,145,63,174,182,170,63,219,138,197,63,237,13,222,63,98,16,248,63,190,48,9,64,188,5,22,64,159,205,34,64,140,185,47,64,27,13,60,64,153,187,22,62,188,116,147,62,207,102,245,62,247,117,32,63,27,47,77,63,112,206,128,63,182,243,149,63,169,164,174,63,82,184,198,63,23,217,222,63,157,128,246,63,81,218,7,64,209,145,20,64,31,244,32,64,72,191,45,64,186,218,58,64,41,203,16,62,248,83,131,62,54,171,222,62,13,113,28,63,244,253,68,63,252,24,115,63,123,131,143,63,193,202,169,63,88,202,194,63,116,70,220,63,90,100,243,63,67,173,5,64,17,54,20,64,40,126,32,64,140,74,46,64,94,75,60,64,110,52,0,62,231,140,136,62,120,11,228,62,52,162,36,63,48,76,86,63,83,150,129,63,12,2,155,63,125,63,181,63,59,223,207,63,99,127,233,63,1,77,0,64,52,162,12,64,9,249,24,64,173,250,36,64,118,224,48,64,172,173,60,64,57,69,7,62,248,83,131,62,75,234,196,62,230,174,21,63,46,255,65,63,200,7,109,63,82,39,136,63,193,168,156,63,49,8,188,63,95,7,222,63,205,204,252,63,120,11,12,64,190,193,23,64,242,65,35,64,141,151,46,64,47,221,56,64,24,38,19,62,25,4,150,62,174,182,226,62,246,151,29,63,182,243,77,63,153,187,118,63,92,143,146,63,153,42,168,63,220,215,193,63,221,36,222,63,5,52,249,63,78,209,9,64,127,217,21,64,143,228,34,64,40,15,47,64,211,188,59,64,196,66,45,62,242,210,141,62,175,37,196,62,246,40,28,63,236,81,72,63,150,33,110,63,254,212,136,63,190,193,159,63,111,18,187,63,247,6,215,63,223,79,245,63,45,33,11,64,231,251,21,64,205,59,34,64,197,32,48,64,169,164,58,64,145,237,252,61,164,223,126,62,192,236,222,62,124,97,34,63,115,215,82,63,69,216,128,63,34,108,152,63,154,119,172,63,149,101,200,63,133,235,233,63,207,247,3,64,165,78,16,64,201,118,26,64,220,215,37,64,189,227,48,64,211,188,59,64,100,59,223,61,112,206,72,62,38,83,197,62,19,242,17,63,125,208,51,63,124,97,98,63,149,212,145,63,176,114,176,63,49,8,204,63,54,205,227,63,140,219,248,63,209,34,11,64,193,168,24,64,124,242,36,64,235,115,49,64,202,50,60,64,119,190,31,62,188,5,178,62,23,72,0,63,124,242,32,63,1,222,66,63,109,86,125,63,248,83,147,63,168,198,171,63,104,145,197,63,171,62,215,63,190,193,239,63,153,42,4,64,36,185,16,64,93,254,31,64,9,249,44,64,22,106,57,64,207,102,21,62,254,101,119,62,230,63,196,62,31,133,11,63,76,166,74,63,218,27,108,63,62,121,136,63,151,255,152,63,58,146,179,63,79,175,212,63,199,75,247,63,109,86,9,64,159,171,21,64,182,132,32,64,123,131,43,64,23,217,58,64,118,79,30,62,38,83,197,62,118,79,30,63,117,147,88,63,206,170,135,63,18,20,159,63,46,255,177,63,61,10,199,63,0,145,222,63,250,126,242,63,69,216,4,64,57,69,15,64,138,176,25,64,18,131,36,64,62,121,48,64,246,40,60,64,27,47,221,61,159,60,108,62,206,136,210,62,177,80,27,63,143,194,69,63,238,90,114,63,176,114,144,63,37,6,169,63,84,116,196,63,44,101,225,63,144,49,255,63,234,4,12,64,99,238,22,64,199,75,35,64,215,18,46,64,226,233,57,64,190,193,23,62,174,182,162,62,45,33,255,62,238,90,34,63,171,62,71,63,145,237,124,63,220,215,153,63,58,146,171,63,186,218,194,63,136,99,221,63,155,230,245,63,3,9,6,64,60,189,18,64,27,13,32,64,159,171,45,64,154,8,59,64,250,126,234,61,244,253,148,62,81,107,250,62,249,49,38,63,142,6,80,63,207,247,115,63,160,26,143,63,78,98,168,63,242,176,192,63,251,58,216,63,62,232,241,63,107,154,7,64,138,176,21,64,220,70,35,64,159,205,46,64,154,8,59,64,165,78,192,61,31,244,44,62,102,102,166,62,116,70,20,63,157,17,69,63,8,172,108,63,175,37,148,63,213,120,177,63,116,70,204,63,9,27,230,63,116,181,253,63,122,199,9,64,82,73,21,64,188,116,35,64,214,86,48,64,224,190,58,64,0,145,254,61,109,86,125,62,140,219,200,62,196,177,30,63,222,113,74,63,55,26,112,63,95,41,147,63,146,203,175,63,25,115,199,63,219,249,222,63,101,25,250,63,47,221,8,64,106,188,20,64,214,197,33,64,88,202,46,64,60,189,58,64,112,206,72,62,201,229,191,62,111,129,4,63,216,129,35,63,92,32,81,63,9,27,134,63,236,47,155,63,240,133,177,63,48,187,199,63,225,122,220,63,137,65,240,63,87,91,5,64,170,241,18,64,193,168,32,64,176,114,44,64,128,183,56,64,166,155,4,62,52,17,118,62,198,109,212,62,59,112,30,63,163,146,74,63,94,186,105,63,76,166,138,63,113,172,163,63,63,53,190,63,154,8,219,63,39,160,249,63,144,160,8,64,51,196,17,64,130,226,31,64,243,142,47,64,216,240,60,64,111,18,131,60,116,70,20,61,192,236,30,60,17,199,186,59,52,128,183,186,215,52,239,187,153,187,150,187,23,183,209,187,20,63,70,188,108,9,249,58,33,31,116,60,88,57,52,189,202,50,68,189,154,119,28,189,166,155,68,189,43,24,149,188,150,67,139,60,17,199,58,60,33,31,244,188,41,92,143,188,208,68,88,187,151,255,16,189,96,229,80,189,10,215,35,187,145,126,251,60,5,197,15,61,222,113,10,61,49,8,44,61,101,25,98,60,41,92,143,188,231,29,39,188,159,171,173,59,39,160,9,60,82,73,157,185,85,193,40,61,124,242,48,187,104,145,109,60,36,151,127,187,185,252,7,60,10,215,35,61,23,183,209,56,98,161,214,188,88,57,180,59,75,89,6,188,114,138,14,61,87,91,49,61,247,117,96,60,82,73,29,187,88,57,180,187,98,161,214,60,207,102,85,61,77,243,14,61,80,141,151,60,108,9,249,59,147,169,2,189,29,201,101,189,127,106,60,189,242,65,207,188,192,236,30,188,148,135,133,60,153,187,150,60,179,123,114,187,166,155,68,189,43,246,23,189,73,157,128,61,39,49,136,61,179,123,242,60,17,199,186,187,242,65,207,60,90,245,185,60,41,92,15,61,187,184,141,61,100,59,95,61,234,149,178,60,117,2,26,60,16,233,55,189,7,95,24,189,111,18,3,58,134,90,211,60,202,84,65,60,213,120,233,60,227,165,155,61,121,88,168,61,245,219,87,61,216,240,244,188,46,144,160,187,150,67,139,60,119,190,159,60,137,210,94,60,140,74,234,60,177,191,236,60,211,188,99,60,124,242,176,59,108,9,121,60,130,226,199,60,52,128,55,59,52,128,183,187,244,253,212,188,145,126,251,60,140,74,106,61,114,138,14,188,224,45,16,60,95,41,203,59,0,0,0,0,205,204,76,60,0,0,0,0,215,52,239,188,158,239,167,61,234,149,178,61,1,77,132,61,187,184,13,61,108,9,249,59], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+857240);
/* memory initializer */ allocate([224,45,16,187,242,65,207,188,66,62,104,189,117,2,154,188,39,160,9,189,149,212,137,189,211,222,96,189,185,252,135,188,61,44,212,188,66,96,101,188,111,18,131,59,237,13,62,187,197,32,48,189,99,127,89,189,242,65,207,188,108,9,249,186,30,167,232,187,9,249,32,61,250,237,235,59,111,240,5,189,202,84,193,188,18,131,192,188,151,255,144,188,7,95,152,188,66,96,229,188,193,168,164,188,72,80,252,187,118,224,28,61,122,54,43,61,74,123,3,61,69,216,240,60,222,113,138,60,91,177,63,61,70,148,246,60,62,232,89,60,79,175,20,61,134,90,83,61,201,229,191,61,182,243,253,61,5,197,15,62,20,174,7,62,32,65,241,61,95,152,204,61,132,158,205,60,179,123,114,187,131,192,74,189,114,249,143,189,161,103,179,188,171,207,213,188,108,9,249,188,231,29,167,188,7,95,24,189,115,104,17,61,98,161,86,60,7,95,24,188,156,51,34,188,101,25,226,187,137,210,94,187,244,253,212,187,195,100,170,188,54,60,189,188,91,177,63,188,232,217,172,188,203,16,199,188,153,187,150,59,14,79,47,188,66,96,229,187,240,133,73,60,127,106,188,60,108,9,121,60,75,89,134,60,85,193,40,61,219,138,125,61,233,183,175,61,160,137,176,61,52,128,183,187,205,204,76,60,43,24,149,60,150,33,14,61,192,236,30,61,17,199,58,61,11,181,38,61,22,251,203,188,127,106,60,189,85,193,168,60,216,240,244,60,242,65,207,60,12,147,169,60,151,255,144,60,56,248,194,60,242,65,207,60,166,155,68,59,39,160,137,59,111,18,3,59,221,181,4,188,137,210,94,188,104,145,237,188,39,160,137,187,130,226,71,60,231,29,167,59,14,79,47,60,17,199,186,60,232,217,172,60,137,210,222,187,234,149,50,189,216,240,244,188,36,151,255,187,9,138,159,189,31,244,236,189,40,15,139,189,4,231,140,60,143,194,117,60,231,29,167,187,221,181,4,60,23,183,81,189,72,80,124,189,250,237,107,61,156,162,163,61,84,116,164,61,39,160,9,61,23,183,209,56,33,31,244,188,80,252,152,189,127,106,60,188,120,122,37,188,150,67,139,188,10,215,163,187,114,138,142,60,104,145,237,188,107,43,118,189,143,194,117,188,20,63,70,60,2,43,135,60,127,106,188,60,52,128,55,59,220,215,1,189,2,43,135,188,78,209,17,61,199,186,56,61,166,155,68,60,74,123,3,61,39,160,9,60,237,13,190,187,130,226,71,60,221,36,70,62,89,134,56,62,156,196,96,62,180,200,118,62,229,97,97,62,147,24,68,62,127,106,60,62,221,36,70,62,120,156,98,62,189,227,84,62,91,66,62,62,58,35,74,62,11,70,101,62,228,131,94,62,127,106,60,62,135,22,89,62,145,126,251,62,24,149,244,62,223,224,235,62,37,6,225,62,120,156,226,62,101,170,224,62,101,25,226,62,201,118,222,62,108,9,217,62,72,191,221,62,194,134,231,62,37,117,226,62,184,30,229,62,73,157,224,62,20,174,231,62,156,162,227,62,181,166,57,62,66,62,200,62,60,78,33,63,113,27,77,63,199,186,128,63,243,31,154,63,54,171,182,63,211,222,216,63,121,88,248,63,89,23,11,64,206,136,22,64,250,237,31,64,158,94,37,64,125,208,43,64,140,219,48,64,174,71,57,64,20,63,6,62,56,248,162,62,114,138,238,62,183,98,15,63,222,113,42,63,149,101,72,63,254,212,128,63,17,199,162,63,53,94,194,63,111,240,221,63,231,251,249,63,117,2,14,64,250,237,23,64,65,241,31,64,150,178,44,64,8,61,59,64,212,154,38,62,112,95,231,62,106,222,33,63,216,129,51,63,167,232,72,63,213,231,122,63,2,43,151,63,217,61,169,63,82,73,197,63,27,13,232,63,194,134,247,63,119,45,5,64,29,90,20,64,168,53,33,64,239,56,45,64,189,227,60,64,61,10,23,62,163,146,122,62,135,22,217,62,92,32,17,63,240,133,73,63,81,218,123,63,155,85,151,63,183,209,176,63,24,149,196,63,199,75,215,63,46,144,240,63,228,20,9,64,222,113,26,64,231,29,39,64,98,161,50,64,211,222,60,64,218,172,250,61,79,64,147,62,50,85,0,63,229,208,50,63,38,228,99,63,102,136,139,63,186,73,164,63,200,7,189,63,198,109,212,63,82,73,237,63,34,253,2,64,224,190,14,64,195,100,26,64,95,7,38,64,50,119,49,64,151,255,60,64,69,71,50,62,63,87,155,62,96,118,239,62,157,128,22,63,7,206,57,63,34,253,118,63,58,35,146,63,76,55,169,63,108,9,193,63,102,136,219,63,226,233,245,63,251,58,8,64,253,135,20,64,107,154,31,64,199,75,43,64,4,231,56,64,67,173,41,62,65,130,162,62,8,61,251,62,16,233,39,63,29,90,84,63,79,64,131,63,65,130,154,63,252,169,177,63,0,111,201,63,127,106,228,63,172,139,243,63,35,74,7,64,103,68,21,64,59,1,33,64,1,222,46,64,45,178,57,64,83,5,35,62,168,53,141,62,129,38,226,62,252,169,33,63,19,97,83,63,177,191,124,63,121,88,144,63,88,57,164,63,123,131,183,63,254,212,208,63,62,232,241,63,172,173,8,64,93,220,22,64,120,11,36,64,146,203,47,64,186,73,60,64,191,14,28,62,164,112,221,62,103,213,23,63,33,31,52,63,129,4,69,63,198,109,100,63,91,66,150,63,43,24,189,63,95,152,212,63,196,66,229,63,140,185,251,63,237,158,12,64,142,6,24,64,186,73,32,64,189,82,42,64,69,216,56,64,172,28,90,62,254,67,154,62,228,131,190,62,90,245,217,62,188,5,2,63,129,149,51,63,150,67,123,63,242,176,160,63,145,126,187,63,48,42,217,63,102,247,244,63,72,225,6,64,54,60,21,64,106,222,33,64,255,178,47,64,32,210,59,64,177,225,233,61,201,229,191,62,23,217,30,63,156,162,67,63,201,229,79,63,148,246,102,63,22,251,123,63,65,241,147,63,119,45,185,63,105,0,223,63,21,140,250,63,50,85,8,64,149,101,24,64,72,191,37,64,115,104,49,64,202,84,61,64,18,131,0,62,123,131,111,62,180,200,182,62,208,68,8,63,192,236,62,63,213,9,128,63,150,33,150,63,88,168,173,63,17,199,194,63,60,78,217,63,42,58,242,63,95,7,6,64,197,32,20,64,120,156,34,64,214,86,48,64,190,193,59,64,39,194,6,62,195,100,106,62,219,138,221,62,163,146,42,63,149,212,89,63,174,216,127,63,187,184,149,63,242,176,176,63,146,203,199,63,192,91,216,63,187,184,237,63,136,133,6,64,200,152,23,64,179,12,37,64,66,96,49,64,237,158,60,64,7,206,25,62,238,90,130,62,66,207,198,62,89,134,8,63,234,149,50,63,163,146,106,63,116,181,141,63,40,15,171,63,66,96,197,63,236,81,224,63,206,136,242,63,158,94,5,64,166,10,18,64,51,196,29,64,0,0,44,64,77,132,57,64,138,31,35,62,26,81,154,62,58,35,234,62,147,169,34,63,183,209,80,63,12,2,123,63,137,210,150,63,43,246,175,63,172,173,200,63,214,197,221,63,93,220,246,63,117,147,8,64,183,209,20,64,193,202,33,64,182,243,45,64,216,129,59,64,71,114,57,62,129,38,162,62,4,86,238,62,70,148,38,63,106,222,81,63,195,245,128,63,181,55,152,63,16,233,175,63,213,231,194,63,131,192,218,63,103,68,241,63,85,193,4,64,154,153,17,64,121,233,30,64,104,34,44,64,152,76,57,64,200,7,61,62,116,36,183,62,98,16,8,63,190,159,58,63,213,231,106,63,59,1,141,63,161,248,161,63,133,235,185,63,254,212,208,63,149,212,233,63,240,133,1,64,170,96,12,64,85,193,24,64,183,209,36,64,48,42,49,64,2,154,60,64,161,103,179,61,134,90,19,62,23,183,81,62,181,21,187,62,41,203,32,63,5,163,98,63,15,156,139,63,48,76,166,63,213,231,194,63,217,95,222,63,137,65,248,63,228,20,9,64,189,82,22,64,67,28,35,64,75,200,47,64,195,211,59,64,59,112,14,62,6,129,213,62,43,246,39,63,200,152,75,63,36,151,95,63,64,164,127,63,158,239,151,63,35,219,185,63,109,86,205,63,125,63,229,63,47,221,0,64,207,247,11,64,191,125,21,64,34,108,32,64,232,106,47,64,70,182,63,64,193,168,164,61,131,192,10,62,157,17,133,62,201,229,255,62,18,165,61,63,206,136,114,63,50,85,144,63,223,224,171,63,231,29,199,63,174,182,226,63,175,37,252,63,242,210,9,64,111,18,23,64,216,129,35,64,250,237,47,64,20,174,59,64,148,135,5,62,237,13,158,62,192,236,254,62,231,140,40,63,254,101,87,63,17,54,132,63,36,185,156,63,132,158,181,63,118,79,206,63,195,245,232,63,217,206,255,63,126,29,12,64,86,14,25,64,228,20,37,64,216,240,48,64,54,205,59,64,74,12,66,62,106,222,145,62,45,178,189,62,79,64,211,62,78,98,32,63,255,178,107,63,11,181,150,63,82,39,176,63,138,176,201,63,28,235,226,63,108,120,250,63,5,163,10,64,209,34,23,64,20,174,35,64,241,99,48,64,45,67,60,64,236,81,56,62,246,151,157,62,25,4,246,62,68,250,45,63,67,173,89,63,188,150,128,63,100,204,149,63,220,215,169,63,205,59,190,63,193,57,211,63,17,54,236,63,83,150,5,64,236,81,20,64,69,71,34,64,55,26,48,64,2,154,60,64,20,174,71,62,148,135,165,62,177,225,233,62,98,16,24,63,69,71,66,63,210,111,127,63,214,197,149,63,106,77,171,63,181,55,192,63,49,8,212,63,170,130,233,63,59,223,3,64,159,205,18,64,216,240,32,64,74,123,47,64,104,34,60,64,83,150,129,62,183,209,224,62,88,57,20,63,80,141,55,63,75,89,102,63,211,77,146,63,29,201,173,63,61,44,196,63,151,255,208,63,39,160,225,63,40,126,252,63,220,70,11,64,159,205,22,64,40,15,35,64,150,67,47,64,95,7,58,64,254,212,56,62,224,190,142,62,245,219,183,62,11,181,198,62,35,74,11,63,63,53,78,63,7,206,137,63,18,131,168,63,120,11,196,63,55,26,224,63,60,78,249,63,41,203,8,64,210,0,22,64,252,24,35,64,163,1,48,64,88,57,60,64,60,78,81,62,136,244,187,62,58,35,10,63,116,70,52,63,255,178,91,63,113,172,123,63,11,36,144,63,25,226,168,63,15,11,189,63,202,84,217,63,222,147,239,63,148,246,2,64,156,196,16,64,97,84,30,64,70,37,45,64,99,238,58,64,98,161,214,61,82,184,94,62,226,88,215,62,249,160,23,63,151,144,63,63,215,163,112,63,87,91,145,63,144,160,176,63,45,67,204,63,45,178,221,63,197,254,242,63,94,75,8,64,105,0,23,64,24,38,35,64,220,70,47,64,80,141,59,64,13,113,172,61,179,12,49,62,140,74,202,62,15,11,37,63,173,105,94,63,119,190,135,63,64,164,159,63,139,108,183,63,5,197,207,63,66,62,232,63,229,97,1,64,137,65,12,64,183,209,24,64,25,226,36,64,27,47,49,64,209,145,60,64,61,155,21,62,248,194,132,62,14,45,210,62,202,84,17,63,200,152,59,63,143,83,100,63,249,49,134,63,50,119,157,63,11,36,184,63,145,237,212,63,12,147,241,63,185,141,6,64,65,241,19,64,23,183,33,64,21,140,46,64,84,82,59,64,62,232,25,62,45,33,159,62,216,129,243,62,72,80,44,63,246,40,92,63,127,251,130,63,111,18,155,63,44,212,178,63,70,182,203,63,129,4,229,63,78,209,249,63,91,66,10,64,26,81,22,64,170,241,34,64,109,197,46,64,83,150,57,64,191,125,93,62,81,218,187,62,51,51,3,63,26,192,43,63,247,117,80,63,63,53,126,63,229,208,154,63,242,210,181,63,132,13,207,63,154,8,219,63,145,126,235,63,2,188,5,64,179,123,22,64,35,219,33,64,54,171,42,64,16,88,57,64,81,107,90,62,192,91,224,62,124,242,32,63,109,197,94,63,41,237,141,63,185,252,175,63,246,151,205,63,14,79,223,63,147,169,234,63,248,194,244,63,40,15,251,63,23,72,4,64,25,115,11,64,215,18,22,64,169,164,38,64,52,162,56,64,156,162,35,62,122,54,139,62,157,128,198,62,43,135,246,62,162,180,23,63,80,141,71,63,72,191,133,63,219,249,166,63,33,176,194,63,212,154,222,63,21,29,249,63,216,240,8,64,60,189,22,64,99,238,34,64,137,65,48,64,218,27,60,64,207,102,149,62,9,138,15,63,9,27,46,63,219,138,61,63,147,24,84,63,0,111,113,63,17,54,148,63,88,57,180,63,179,12,209,63,13,113,236,63,122,165,252,63,53,239,4,64,250,126,18,64,163,35,33,64,227,165,47,64,121,233,62,64,195,100,42,62,170,130,145,62,12,2,203,62,81,218,11,63,124,242,80,63,198,109,132,63,206,170,151,63,218,27,172,63,197,143,193,63,112,206,224,63,238,124,255,63,20,208,12,64,94,75,24,64,220,104,36,64,87,91,49,64,184,30,61,64,163,146,186,61,235,115,117,62,202,84,1,63,186,107,73,63,195,211,131,63,227,199,144,63,36,185,156,63,147,169,170,63,137,65,184,63,121,233,214,63,87,236,247,63,34,253,10,64,15,156,23,64,118,113,35,64,219,249,46,64,184,175,59,64,30,167,40,62,52,17,150,62,56,103,196,62,164,223,254,62,197,32,32,63,237,158,108,63,163,35,145,63,173,105,166,63,118,113,195,63,43,135,230,63,29,90,252,63,228,20,9,64,181,55,24,64,29,56,35,64,105,0,43,64,207,247,55,64,35,219,121,62,147,169,194,62,216,129,243,62,245,74,41,63,232,217,92,63,211,188,131,63,38,83,157,63,207,247,179,63,206,136,194,63,150,33,222,63,97,195,243,63,201,118,6,64,11,36,20,64,114,249,31,64,247,228,45,64,198,220,57,64,229,208,34,62,79,64,147,62,30,22,234,62,99,127,25,63,235,115,69,63,170,241,114,63,139,108,143,63,49,8,164,63,7,206,185,63,94,186,209,63,242,176,232,63,192,236,2,64,88,168,17,64,190,159,30,64,16,233,43,64,172,28,58,64,122,54,107,62,237,158,220,62,42,58,18,63,136,244,43,63,50,85,80,63,41,237,133,63,201,229,159,63,53,94,186,63,34,253,214,63,45,67,236,63,232,106,251,63,245,74,9,64,57,69,23,64,43,135,34,64,233,183,47,64,156,196,60,64,236,81,152,62,123,131,239,62,146,203,255,62,221,181,20,63,14,190,32,63,251,58,48,63,72,80,92,63,165,189,145,63,62,121,184,63,71,3,216,63,197,32,240,63,253,246,5,64,214,86,20,64,249,15,33,64,12,2,47,64,90,100,59,64,1,222,2,62,155,85,191,62,208,179,25,63,102,247,52,63,46,144,80,63,211,77,130,63,108,9,161,63,41,203,176,63,221,36,190,63,200,7,221,63,178,157,255,63,27,13,8,64,88,202,18,64,40,126,36,64,56,103,48,64,191,125,57,64,185,141,6,62,220,104,128,62,177,191,204,62,115,104,17,63,237,13,62,63,146,203,111,63,247,117,144,63,215,163,168,63,1,77,196,63,109,197,222,63,242,65,247,63,80,252,8,64,86,125,22,64,200,152,35,64,98,16,48,64,61,44,60,64,61,155,213,61,124,97,114,62,54,205,219,62,193,57,35,63,96,229,80,63,54,205,123,63,109,197,150,63,174,71,177,63,33,176,202,63,205,204,228,63,244,253,252,63,249,49,10,64,183,98,23,64,91,177,35,64,168,198,47,64,175,37,60,64,209,145,28,62,156,196,128,62,69,216,176,62,229,242,223,62,74,123,51,63,180,200,102,63,240,133,137,63,168,53,173,63,124,242,200,63,117,147,224,63,104,34,0,64,191,14,8,64,70,148,14,64,43,24,29,64,86,125,46,64,236,81,60,64,97,84,18,62,5,197,143,62,37,6,225,62,129,38,34,63,0,145,78,63,176,114,120,63,188,116,147,63,154,153,169,63,44,101,193,63,125,63,221,63,190,193,247,63,207,102,9,64,254,67,22,64,172,139,35,64,169,19,48,64,195,211,59,64,102,102,38,62,245,185,154,62,216,129,243,62,252,169,33,63,132,158,77,63,237,13,126,63,198,109,148,63,222,2,169,63,87,236,191,63,242,176,216,63,190,159,242,63,219,249,6,64,41,92,19,64,126,29,32,64,17,54,44,64,213,120,57,64,196,66,45,62,96,118,175,62,57,214,5,63,185,141,70,63,71,3,120,63,246,40,140,63,231,29,167,63,217,206,183,63,215,163,200,63,247,6,231,63,71,3,248,63,204,93,7,64,7,206,21,64,169,19,32,64,95,7,46,64,79,64,59,64,129,38,66,61,55,26,0,62,185,141,70,62,193,168,196,62,244,108,38,63,72,80,108,63,39,194,142,63,213,120,169,63,79,30,198,63,103,68,225,63,102,136,251,63,252,169,9,64,248,83,23,64,102,136,35,64,208,68,48,64,126,29,60,64,211,222,96,62,32,99,238,62,146,203,63,63,210,0,126,63,120,122,149,63,245,219,159,63,103,213,167,63,66,207,174,63,237,13,182,63,152,221,195,63,72,80,220,63,229,242,255,63,175,37,16,64,105,0,31,64,200,7,45,64,43,135,58,64,176,3,231,61,179,123,114,62,18,165,189,62,131,47,12,63,116,181,69,63,73,46,127,63,57,180,152,63,252,24,179,63,102,247,204,63,127,217,229,63,0,145,254,63,130,226,11,64,225,122,24,64,18,131,36,64,14,190,48,64,170,96,60,64,131,81,9,62,187,184,141,62,121,233,230,62,88,202,34,63,152,76,85,63,186,73,132,63,181,166,153,63,234,149,178,63,236,192,201,63,26,81,226,63,203,161,253,63,160,26,11,64,161,103,23,64,102,136,35,64,240,22,48,64,134,201,60,64,183,98,255,61,83,5,131,62,234,4,180,62,161,248,241,62,64,164,47,63,202,195,114,63,162,180,151,63,229,97,177,63,143,228,202,63,49,8,228,63,141,40,253,63,231,29,11,64,152,221,23,64,230,63,36,64,156,196,48,64,121,88,60,64,58,146,75,62,231,251,169,62,24,149,244,62,154,119,44,63,20,174,87,63,90,100,131,63,230,174,149,63,180,200,174,63,41,237,197,63,248,83,219,63,197,32,248,63,92,143,10,64,234,149,22,64,75,89,34,64,186,73,48,64,16,88,61,64,4,231,12,62,221,36,134,62,17,199,218,62,41,237,29,63,43,135,70,63,138,176,113,63,148,246,142,63,220,104,168,63,140,74,194,63,35,219,217,63,26,81,242,63,17,199,6,64,179,234,19,64,211,222,32,64,177,225,45,64,1,222,58,64,208,68,88,62,18,131,224,62,250,237,27,63,83,5,67,63,138,142,116,63,26,192,147,63,147,24,172,63,157,17,197,63,243,142,219,63,88,168,245,63,77,21,8,64,197,254,22,64,150,33,38,64,94,75,52,64,33,31,60,64,27,158,66,64,204,238,9,62,7,240,86,62,167,121,135,62,41,203,176,62,66,207,6,63,71,114,73,63,0,145,134,63,168,198,163,63,201,118,190,63,179,234,219,63,148,246,246,63,89,134,8,64,77,132,21,64,44,212,34,64,58,146,47,64,179,234,59,64,183,209,160,62,158,239,23,63,105,111,64,63,20,208,84,63,63,87,91,63,244,253,116,63,51,51,131,63,236,81,144,63,54,205,171,63,172,173,208,63,29,201,237,63,18,131,4,64,192,236,18,64,166,155,32,64,146,92,46,64,220,70,59,64,129,4,197,61,172,173,88,62,159,205,202,62,220,104,16,63,189,82,54,63,161,103,99,63,43,24,141,63,138,142,172,63,114,249,199,63,242,176,224,63,67,28,251,63,82,184,10,64,233,183,23,64,243,142,35,64,80,141,47,64,190,193,59,64,16,233,183,61,190,159,26,62,8,172,156,62,244,253,20,63,37,117,82,63,102,247,132,63,216,240,156,63,50,230,182,63,191,125,205,63,233,183,231,63,171,62,255,63,54,205,11,64,229,242,23,64,231,140,36,64,69,216,48,64,52,162,60,64,75,200,7,62,141,40,109,62,46,144,192,62,253,135,4,63,132,158,45,63,23,72,96,63,131,47,140,63,215,163,168,63,151,255,192,63,3,9,218,63,81,218,243,63,207,247,7,64,226,233,21,64,252,24,35,64,64,164,47,64,240,22,60,64,14,45,50,62,2,154,168,62,84,116,4,63,196,177,46,63,235,226,86,63,248,194,132,63,85,48,154,63,135,167,175,63,149,101,200,63,128,72,223,63,140,219,248,63,211,222,8,64,240,22,20,64,119,190,31,64,32,65,45,64,52,128,59,64,250,237,107,62,174,71,193,62,135,22,249,62,91,66,30,63,85,193,72,63,140,185,107,63,153,187,142,63,241,99,164,63,161,103,187,63,71,114,217,63,13,224,245,63,98,16,8,64,103,213,19,64,50,119,33,64,25,115,47,64,204,93,59,64,117,2,26,60,171,207,213,60,179,123,114,187,75,89,134,59,153,187,22,188,224,45,144,187,237,13,190,188,215,52,239,187,117,2,154,187,39,160,9,187,205,204,204,60,104,145,109,189,66,96,101,188,77,21,12,189,142,6,112,189,111,18,3,59,16,233,55,61,182,243,125,60,134,56,86,189,138,142,228,188,216,240,244,60,226,233,149,188,153,187,150,189,1,222,130,189,137,210,222,186,39,160,9,61,122,54,171,60,153,187,150,59,72,80,252,59,179,123,114,188,17,199,58,188,166,155,68,188,127,106,60,60,10,215,163,187,162,69,54,61,82,73,157,59,117,2,154,60,247,117,96,188,111,18,3,188,239,201,195,60,153,187,150,188,98,161,86,189,119,190,159,188,59,112,78,188,30,167,232,60,0,111,129,61,176,3,103,60,7,95,24,188,82,73,29,188,46,144,160,60,127,106,188,60,8,61,27,61,72,80,252,60,129,38,194,60,52,128,183,188,143,194,117,189,190,159,154,189,136,244,219,189,168,87,202,189,181,55,120,189,24,149,212,189,192,236,30,190,80,141,23,190,39,160,137,189,59,112,78,61,222,113,138,61,39,160,9,61,39,160,137,187,152,76,149,61,96,118,207,61,51,196,177,61,196,66,173,61,19,97,195,61,170,241,82,61,208,68,216,187,233,72,174,189,240,167,70,189,69,216,240,60,193,202,33,61,114,138,14,60,36,151,255,59,125,174,54,61,198,109,180,61,39,160,137,61,82,73,29,189,10,215,35,187,231,251,41,61,188,150,16,61,111,18,3,60,195,100,170,59,227,165,155,60,43,24,149,60,101,25,226,59,39,160,137,60,190,48,25,61,179,123,114,59,215,52,239,188,233,183,47,189,254,101,247,60,3,120,139,61,164,223,190,188,56,248,194,188,82,73,157,185,4,231,140,187,124,242,176,59,237,13,62,187,33,31,116,188,74,123,131,61,109,197,126,61,113,172,11,61,237,13,190,188,91,211,60,189,75,89,6,188,55,26,64,189,255,33,125,189,148,135,5,189,163,35,57,189,75,234,132,189,253,135,116,189,83,5,35,189,184,64,2,189,237,13,62,188,224,45,144,58,250,237,107,58,82,73,29,189,82,73,29,189,36,151,127,188,244,253,212,188,52,128,55,186,165,189,65,61,198,220,53,60,5,163,18,189,20,63,70,189,231,29,167,188,237,13,62,187,188,116,19,188,213,120,233,188,131,192,74,189,117,2,26,189,54,205,187,61,33,31,244,61,243,31,210,61,117,147,152,61,120,156,34,61,18,165,61,61,242,65,207,60,10,215,35,59,201,118,62,61,10,215,35,60,130,226,71,61,195,100,42,61,125,174,182,60,25,115,215,60,250,237,235,59,159,171,173,187,70,182,115,61,166,155,196,59,61,44,84,189,0,111,1,189,4,231,140,187,62,232,89,188,164,223,190,188,143,194,245,187,132,158,205,188,28,235,226,60,172,139,219,187,137,210,94,188,23,183,209,185,18,131,192,60,52,128,55,60,43,24,149,188,221,181,4,189,49,8,172,188,66,96,101,187,193,202,33,189,82,73,29,189,111,18,3,58,143,194,117,188,78,209,17,189,169,19,80,60,208,68,88,187,137,210,94,187,158,239,167,60,80,252,152,61,249,15,233,61,59,223,207,61,168,198,203,61,38,228,131,188,188,116,147,187,134,90,83,60,202,84,65,61,31,133,107,61,198,220,181,60,43,24,21,60,179,123,114,59,238,235,64,189,43,246,23,61,208,68,88,60,195,100,170,60,168,87,202,60,91,177,63,60,75,89,134,60,236,81,184,60,95,41,75,60,153,187,22,187,224,45,16,60,153,187,150,187,117,2,154,59,9,249,32,189,250,237,235,58,179,123,114,60,111,18,3,59,224,45,144,59,2,43,135,60,200,152,187,60,195,100,170,188,19,97,67,189,182,243,253,188,75,89,134,188,119,190,31,189,154,119,156,189,61,10,87,189,117,2,26,188,143,194,245,59,231,29,39,188,188,116,147,187,59,112,78,189,5,52,145,189,121,88,168,61,115,104,145,61,86,125,46,61,52,128,183,58,43,246,23,189,10,215,35,189,73,157,128,188,182,243,125,188,187,184,141,188,101,25,98,188,166,155,196,186,172,139,91,60,122,54,43,189,113,172,139,189,23,183,209,188,10,215,163,59,188,116,19,61,151,255,16,61,179,123,242,59,156,51,34,189,18,131,192,188,30,167,232,60,168,87,74,61,218,172,122,60,52,128,55,61,10,215,35,59,130,226,199,187,59,112,206,60,205,204,204,61,139,108,103,62,173,250,92,62,172,173,88,62,64,19,97,62,152,110,82,62,98,16,88,62,146,203,63,62,220,70,67,62,6,18,84,62,246,151,93,62,187,184,77,62,115,215,82,62,99,127,89,62,8,61,91,62,189,82,86,62,51,51,179,61,167,232,200,61,179,12,241,61,63,87,219,61,243,142,211,61,36,151,255,61,98,161,214,61,219,138,253,61,251,203,238,61,59,112,206,61,99,127,217,61,95,41,203,61,58,146,203,61,136,133,218,61,95,152,204,61,252,24,243,61,154,153,153,61,120,156,162,61,12,147,169,61,50,230,174,61,87,236,175,61,120,11,164,61,16,122,182,61,18,20,191,61,130,115,198,61,127,106,188,61,90,100,187,61,160,137,176,61,51,196,177,61,16,122,182,61,13,113,172,61,85,193,168,61,0,0,128,61,201,118,190,61,121,233,166,61,196,177,174,61,16,233,183,61,12,147,169,61,121,88,168,61,53,94,186,61,88,202,178,61,126,140,185,61,14,79,175,61,49,8,172,61,228,131,158,61,156,196,160,61,77,21,140,61,224,156,145,61,204,238,169,62,71,3,216,62,213,231,234,62,115,104,209,62,170,130,209,62,77,132,205,62,88,168,181,62,113,172,171,62,127,217,189,62,86,159,171,62,201,118,190,62,70,37,181,62,206,25,209,62,200,152,219,62,59,223,207,62,80,141,215,62,69,216,112,61,122,54,171,60,75,89,6,188,127,106,60,188,40,126,12,189,146,92,126,189,246,151,93,189,187,184,13,189,187,184,13,189,226,233,21,189,88,57,180,188,135,22,217,188,231,29,39,188,190,48,25,61,218,172,250,60,120,122,37,61,218,172,250,60,188,116,19,60,124,242,176,187,149,101,8,61,117,2,154,59,56,248,194,60,176,3,103,60,2,43,135,60,218,172,250,60,49,8,44,61,184,64,130,60,95,41,75,60,12,147,41,61,0,111,129,60,129,38,194,188,176,3,103,60,8,172,156,61,17,199,186,59,244,253,212,188,86,125,46,189,193,202,33,189,59,112,78,188,141,40,109,189,159,205,42,189,233,183,47,189,109,231,123,189,235,226,182,189,255,33,125,189,82,73,29,189,172,139,91,188,237,13,190,188,56,248,194,188,247,228,225,61,2,188,197,62,91,177,47,63,66,62,88,63,72,80,108,63,63,87,131,63,114,249,143,63,250,237,179,63,177,191,212,63,43,135,230,63,242,65,239,63,111,129,4,64,4,86,22,64,180,200,38,64,230,63,48,64,235,115,57,64,238,90,2,62,16,122,118,62,165,44,195,62,208,179,25,63,208,213,70,63,110,52,112,63,5,52,145,63,143,228,170,63,127,251,194,63,31,244,220,63,48,42,249,63,45,33,11,64,53,94,22,64,108,9,33,64,127,217,45,64,143,228,58,64,242,210,77,62,250,126,170,62,29,201,229,62,6,129,37,63,68,250,77,63,141,40,125,63,99,238,146,63,111,240,165,63,86,14,189,63,138,142,212,63,204,127,240,63,90,100,7,64,108,9,21,64,11,70,33,64,71,114,45,64,146,92,58,64,215,52,239,61,9,249,96,62,130,226,167,62,224,45,240,62,247,117,32,63,193,57,83,63,137,210,134,63,60,189,162,63,72,80,188,63,185,141,214,63,108,9,241,63,45,33,7,64,8,172,20,64,155,230,33,64,209,34,47,64,248,83,59,64,59,223,15,62,73,46,159,62,128,72,255,62,220,104,48,63,200,7,93,63,96,118,135,63,5,52,161,63,206,170,183,63,5,197,207,63,130,226,231,63,180,200,254,63,78,98,12,64,72,80,24,64,202,50,36,64,200,7,49,64,221,181,60,64,32,99,46,62,182,132,156,62,0,111,225,62,143,194,5,63,112,206,24,63,178,157,79,63,202,84,137,63,233,38,169,63,168,53,197,63,16,122,222,63,60,78,249,63,131,192,10,64,77,243,22,64,179,234,35,64,254,212,48,64,88,57,60,64,176,3,231,61,185,141,134,62,222,147,231,62,162,69,38,63,60,78,81,63,35,74,123,63,75,89,150,63,238,124,175,63,57,69,199,63,251,58,224,63,197,143,249,63,245,74,9,64,22,106,21,64,86,125,34,64,231,29,47,64,35,74,59,64,217,61,57,62,94,75,168,62,125,63,5,63,90,245,57,63,95,7,110,63,222,147,143,63,25,4,166,63,169,164,190,63,185,252,215,63,221,181,236,63,184,175,3,64,171,62,15,64,134,56,26,64,147,169,38,64,247,228,49,64,240,22,60,64,55,26,128,62,206,25,241,62,105,111,48,63,88,168,85,63,26,192,107,63,242,210,133,63,11,181,158,63,181,21,187,63,245,185,210,63,150,67,235,63,61,10,3,64,63,87,15,64,35,219,29,64,133,235,41,64,82,73,49,64,145,237,56,64,244,253,212,61,178,157,111,62,241,244,202,62,170,241,18,63,39,194,70,63,86,125,126,63,154,153,153,63,19,97,179,63,113,27,205,63,52,17,230,63,29,56,255,63,160,137,12,64,17,54,24,64,66,62,36,64,36,185,48,64,150,178,60,64,239,201,67,62,187,184,173,62,115,215,242,62,224,156,33,63,141,40,77,63,4,231,124,63,119,190,151,63,156,51,178,63,172,173,200,63,152,76,221,63,54,171,246,63,188,116,7,64,5,197,19,64,76,166,34,64,206,170,47,64,84,82,59,64,203,161,197,61,41,92,79,62,68,250,173,62,238,124,255,62,170,130,49,63,23,72,112,63,221,36,150,63,110,52,176,63,188,5,202,63,86,159,227,63,223,79,253,63,233,183,11,64,238,124,23,64,255,178,35,64,4,231,48,64,4,231,60,64,208,179,89,62,127,251,186,62,182,243,13,63,80,141,55,63,237,13,94,63,39,49,136,63,14,190,160,63,22,251,179,63,58,146,203,63,178,157,231,63,145,237,252,63,203,161,9,64,174,182,22,64,20,174,35,64,124,242,44,64,20,208,56,64,181,21,59,62,68,105,175,62,163,146,250,62,194,23,38,63,168,198,75,63,147,24,116,63,222,147,143,63,125,208,163,63,222,113,186,63,49,153,210,63,148,246,230,63,208,68,0,64,193,57,15,64,170,130,29,64,93,220,42,64,229,97,57,64,23,72,80,62,184,175,195,62,226,233,5,63,14,45,50,63,31,133,107,63,15,11,133,63,79,175,148,63,23,72,176,63,118,79,198,63,242,210,221,63,3,120,251,63,38,228,7,64,109,86,21,64,118,79,34,64,87,91,45,64,166,155,60,64,61,10,215,61,170,241,82,62,45,178,189,62,126,140,25,63,93,109,85,63,183,98,135,63,85,193,160,63,183,98,183,63,64,19,209,63,18,131,232,63,79,30,254,63,212,43,13,64,210,0,26,64,54,60,37,64,205,204,48,64,253,135,60,64,60,78,17,62,123,131,207,62,250,126,42,63,33,31,100,63,27,47,133,63,54,205,147,63,169,19,160,63,184,64,178,63,46,144,200,63,121,88,224,63,77,21,252,63,70,37,13,64,189,227,24,64,85,193,36,64,231,140,48,64,174,182,58,64,154,8,27,62,215,163,144,62,237,158,220,62,97,195,19,63,100,59,63,63,149,101,120,63,174,182,146,63,222,113,170,63,218,27,196,63,75,234,220,63,66,207,246,63,55,26,8,64,223,224,19,64,220,104,32,64,147,58,45,64,156,51,58,64,251,92,45,62,83,150,161,62,236,192,249,62,35,219,41,63,215,18,82,63,102,247,116,63,109,197,142,63,29,56,167,63,44,101,193,63,136,244,219,63,191,125,245,63,98,161,6,64,230,174,17,64,23,217,30,64,62,121,44,64,162,69,58,64,5,163,18,62,95,41,139,62,163,35,217,62,59,112,14,63,110,163,49,63,125,174,102,63,230,63,148,63,206,136,178,63,231,29,207,63,11,181,230,63,132,158,253,63,209,34,11,64,58,35,22,64,28,235,34,64,65,241,47,64,151,144,59,64,213,231,106,62,120,122,197,62,160,26,15,63,118,79,62,63,8,61,107,63,120,11,140,63,111,18,163,63,108,9,185,63,18,20,207,63,189,82,230,63,234,4,252,63,136,133,10,64,92,143,22,64,201,118,34,64,146,203,47,64,39,49,60,64,104,179,42,62,73,46,159,62,104,34,236,62,81,107,26,63,205,204,60,63,56,248,98,63,131,192,138,63,18,20,167,63,5,197,191,63,199,41,218,63,157,17,245,63,24,38,7,64,44,212,18,64,38,228,31,64,109,86,45,64,222,113,58,64,16,88,57,62,147,24,164,62,105,111,240,62,123,131,31,63,15,156,67,63,77,243,126,63,203,16,159,63,32,210,183,63,19,97,203,63,46,144,224,63,45,67,244,63,242,176,4,64,140,185,15,64,231,140,28,64,167,121,43,64,42,58,58,64,32,99,238,61,82,39,192,62,63,87,27,63,169,19,64,63,174,71,129,63,220,70,155,63,231,140,176,63,152,221,195,63,215,163,208,63,143,194,229,63,250,237,243,63,49,153,6,64,18,131,24,64,156,196,36,64,62,121,44,64,131,47,56,64,211,222,32,62,82,39,224,62,127,106,44,63,134,201,84,63,102,247,100,63,63,87,123,63,248,194,148,63,56,103,180,63,227,54,210,63,171,62,231,63,157,128,246,63,97,195,11,64,87,236,27,64,131,47,40,64,89,23,47,64,137,65,56,64,187,39,15,62,240,133,137,62,99,127,217,62,246,151,29,63,213,120,73,63,176,114,128,63,236,192,153,63,29,56,175,63,122,165,196,63,196,177,222,63,99,238,250,63,146,92,10,64,115,104,21,64,237,158,32,64,206,136,46,64,136,244,59,64,38,228,67,62,213,231,170,62,155,85,255,62,129,4,37,63,222,2,73,63,30,22,130,63,11,36,152,63,63,53,174,63,232,217,196,63,68,139,220,63,252,169,241,63,77,132,5,64,170,241,18,64,9,138,31,64,175,148,45,64,0,145,58,64,90,245,185,61,161,103,51,62,198,109,148,62,16,88,9,63,125,174,70,63,174,71,129,63,236,47,155,63,207,247,179,63,15,11,205,63,43,135,230,63,113,27,253,63,39,49,12,64,38,228,23,64,185,252,35,64,37,6,49,64,76,55,61,64,34,142,53,62,202,195,162,62,246,40,252,62,233,183,47,63,7,95,88,63,251,92,125,63,217,206,151,63,64,164,175,63,141,151,198,63,188,5,226,63,50,119,253,63,64,164,11,64,2,43,23,64,44,212,34,64,102,102,46,64,12,2,59,64,184,175,3,62,233,183,111,62,118,224,188,62,131,81,9,63,162,180,55,63,41,92,111,63,198,220,141,63,159,171,165,63,206,170,191,63,238,90,218,63,54,205,243,63,248,83,7,64,177,191,20,64,118,79,34,64,255,178,47,64,162,180,59,64,85,193,104,62,1,77,196,62,201,118,14,63,126,29,56,63,103,213,87,63,247,6,127,63,0,145,150,63,116,181,173,63,62,232,201,63,148,246,222,63,29,201,245,63,8,61,7,64,125,174,18,64,226,88,31,64,197,32,44,64,131,192,58,64,143,194,53,62,209,145,156,62,44,212,218,62,85,48,26,63,101,170,80,63,44,101,137,63,206,25,169,63,69,71,194,63,57,214,213,63,7,95,232,63,22,251,251,63,57,214,9,64,129,38,22,64,51,196,33,64,90,245,45,64,217,95,58,64,103,68,41,62,100,93,220,62,115,215,34,63,94,75,72,63,181,21,107,63,29,201,133,63,65,130,154,63,131,47,180,63,210,111,207,63,42,58,234,63,209,145,0,64,154,119,12,64,195,245,24,64,233,72,38,64,156,51,50,64,128,183,60,64,227,199,24,62,175,148,133,62,129,149,195,62,127,106,12,63,186,107,57,63,0,145,110,63,184,175,147,63,171,207,173,63,161,103,195,63,39,160,217,63,12,147,241,63,157,128,6,64,236,81,20,64,22,106,33,64,168,87,46,64,187,39,59,64,170,96,84,62,83,150,193,62,180,89,5,63,174,216,47,63,58,146,91,63,205,204,124,63,206,170,151,63,159,171,173,63,66,207,190,63,84,227,221,63,19,242,241,63,103,213,7,64,103,213,19,64,167,121,31,64,124,242,44,64,147,24,56,64,95,41,11,62,66,207,102,62,66,62,168,62,28,235,226,62,2,154,40,63,120,122,101,63,102,102,142,63,43,24,173,63,71,3,200,63,222,2,225,63,95,7,254,63,39,49,12,64,11,181,22,64,3,120,35,64,15,11,49,64,125,208,59,64,152,110,18,62,245,219,151,62,59,223,239,62,134,56,38,63,47,221,84,63,38,228,131,63,127,106,156,63,230,63,180,63,106,188,204,63,102,247,228,63,113,27,253,63,231,29,11,64,181,21,23,64,91,177,35,64,7,95,48,64,39,49,60,64,171,62,23,62,204,238,137,62,206,170,207,62,142,6,16,63,111,129,52,63,251,92,93,63,233,72,134,63,174,216,159,63,132,158,189,63,136,133,218,63,184,30,245,63,63,87,7,64,118,113,19,64,238,235,32,64,68,250,45,64,143,228,58,64,86,14,45,62,35,74,155,62,250,126,234,62,95,41,43,63,136,133,90,63,26,192,131,63,236,47,155,63,165,44,179,63,190,48,201,63,158,94,225,63,190,159,250,63,207,247,7,64,176,3,19,64,16,122,30,64,104,34,44,64,153,187,58,64,64,164,223,61,233,72,142,62,62,121,248,62,197,32,48,63,125,174,102,63,202,50,140,63,193,57,163,63,67,28,187,63,63,198,212,63,95,152,236,63,138,176,1,64,214,197,13,64,116,181,25,64,16,88,37,64,43,24,49,64,241,99,60,64,245,74,25,62,227,54,186,62,90,245,25,63,132,158,77,63,132,13,127,63,238,124,151,63,130,226,175,63,53,239,200,63,86,125,222,63,56,103,244,63,68,139,4,64,14,79,15,64,243,31,26,64,41,237,37,64,67,173,49,64,200,7,61,64,115,215,18,62,73,46,127,62,40,15,203,62,16,233,23,63,18,165,77,63,220,104,136,63,239,201,163,63,153,187,182,63,55,137,201,63,45,67,228,63,235,226,246,63,22,251,7,64,218,172,22,64,5,163,34,64,21,29,45,64,227,199,56,64,157,17,37,62,171,207,149,62,85,48,234,62,216,129,35,63,129,149,83,63,211,77,130,63,116,36,151,63,255,33,173,63,29,56,199,63,247,117,224,63,246,151,245,63,249,160,7,64,82,39,20,64,213,9,32,64,71,114,45,64,34,253,58,64,12,147,169,61,109,197,62,62,203,161,165,62,174,71,1,63,154,153,57,63,95,152,124,63,88,202,154,63,222,113,178,63,68,139,204,63,148,135,229,63,34,142,253,63,33,31,12,64,64,19,25,64,124,242,36,64,137,65,48,64,162,180,59,64,4,231,76,62,209,34,187,62,139,108,7,63,228,20,45,63,191,125,77,63,128,72,127,63,131,192,154,63,201,118,182,63,84,227,205,63,246,40,228,63,191,125,253,63,39,194,10,64,243,31,22,64,123,20,34,64,115,215,46,64,186,218,58,64,172,28,26,62,159,171,141,62,7,206,217,62,127,251,26,63,181,55,72,63,75,234,116,63,46,144,144,63,139,108,167,63,146,203,191,63,222,2,217,63,192,236,238,63,221,181,4,64,102,102,18,64,54,205,31,64,196,66,45,64,169,164,58,64,174,182,34,62,253,135,212,62,165,44,19,63,254,67,42,63,146,92,78,63,25,4,134,63,28,124,161,63,100,59,175,63,217,206,191,63,65,241,227,63,143,194,253,63,208,213,6,64,61,155,17,64,1,222,34,64,181,166,45,64,15,156,55,64,200,152,187,61,200,7,61,62,19,242,193,62,188,5,34,63,73,157,96,63,41,203,136,63,90,245,161,63,124,97,186,63,104,34,212,63,175,37,236,63,163,146,2,64,244,108,14,64,44,101,25,64,170,130,37,64,106,222,49,64,232,217,60,64,67,173,105,62,216,240,212,62,180,89,21,63,73,157,48,63,151,144,79,63,218,27,132,63,168,198,163,63,134,90,195,63,227,199,216,63,56,103,236,63,155,230,5,64,79,175,16,64,186,73,24,64,41,237,33,64,57,69,47,64,244,253,60,64,249,15,41,62,7,206,153,62,76,55,233,62,178,46,30,63,117,2,74,63,180,89,117,63,197,143,145,63,25,115,175,63,61,44,204,63,47,221,228,63,85,193,248,63,66,96,9,64,190,48,21,64,182,132,32,64,30,167,44,64,115,104,57,64,56,248,2,62,93,254,195,62,74,12,34,63,157,17,85,63,89,23,119,63,61,10,143,63,230,174,157,63,216,240,172,63,213,120,193,63,78,209,209,63,186,73,228,63,168,87,250,63,232,217,12,64,252,169,29,64,88,57,44,64,161,248,57,64,143,83,244,61,119,190,95,62,116,70,180,62,43,246,7,63,118,224,60,63,182,132,108,63,221,36,142,63,119,45,169,63,52,162,196,63,27,13,224,63,145,15,250,63,173,105,10,64,180,200,22,64,8,61,35,64,165,78,48,64,204,127,60,64,53,239,56,62,233,183,175,62,247,6,255,62,106,222,49,63,138,142,100,63,224,190,134,63,222,147,159,63,244,253,180,63,9,249,208,63,143,194,229,63,2,43,255,63,2,154,12,64,16,122,22,64,100,93,36,64,227,165,47,64,112,95,59,64,200,7,61,62,155,85,159,62,177,225,233,62,66,207,22,63,177,80,59,63,186,107,89,63,120,156,130,63,177,225,153,63,215,52,175,63,86,14,205,63,223,224,235,63,68,139,4,64,164,112,17,64,193,57,31,64,48,42,45,64,190,159,58,64,88,57,180,61,128,183,128,62,204,127,8,63,199,41,58,63,93,254,99,63,202,84,145,63,124,242,168,63,171,62,191,63,145,237,204,63,102,136,219,63,123,131,239,63,126,29,4,64,203,161,17,64,102,102,34,64,70,37,45,64,4,231,56,64,77,132,13,62,179,12,145,62,86,125,238,62,46,144,48,63,181,55,104,63,48,42,137,63,107,154,159,63,200,7,181,63,227,165,203,63,187,184,229,63,6,129,253,63,79,30,10,64,251,92,21,64,66,96,33,64,54,171,46,64,77,243,58,64,245,74,217,61,143,228,178,62,161,248,33,63,90,100,91,63,126,140,121,63,2,43,135,63,58,146,147,63,154,153,169,63,168,53,205,63,131,192,234,63,1,77,252,63,161,103,7,64,57,69,19,64,56,248,34,64,255,178,51,64,60,189,62,64,175,37,36,62,87,91,145,62,182,132,220,62,135,22,25,63,186,73,76,63,113,27,133,63,147,58,153,63,113,27,173,63,233,38,201,63,143,83,228,63,190,48,249,63,83,150,9,64,122,54,23,64,35,74,35,64,143,228,46,64,21,140,58,64,141,40,45,62,36,151,159,62,34,142,245,62,18,131,48,63,9,138,95,63,101,25,130,63,89,134,152,63,25,115,175,63,75,234,196,63,131,47,220,63,158,94,241,63,1,77,4,64,179,234,15,64,44,101,29,64,25,115,43,64,76,55,57,64,203,161,197,61,233,72,46,62,19,97,163,62,37,117,18,63,41,92,79,63,181,21,131,63,228,20,157,63,116,181,181,63,139,253,205,63,45,33,231,63,228,131,254,63,108,9,13,64,184,30,25,64,233,38,37,64,204,127,48,64,65,241,59,64,20,174,71,62,61,44,180,62,148,246,6,63,65,130,50,63,9,138,95,63,149,101,136,63,154,8,155,63,218,172,178,63,233,72,206,63,218,27,228,63,96,229,248,63,85,48,10,64,93,109,21,64,167,232,32,64,178,157,47,64,52,128,59,64], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+867480);
/* memory initializer */ allocate([150,33,14,62,28,235,130,62,170,241,210,62,120,156,18,63,45,67,60,63,232,106,107,63,166,155,140,63,109,231,163,63,47,110,187,63,227,165,211,63,131,192,234,63,145,126,3,64,181,166,17,64,70,148,30,64,94,75,44,64,124,97,58,64,218,172,58,62,159,205,170,62,100,204,253,62,109,86,45,63,122,54,91,63,236,192,129,63,93,109,157,63,103,68,177,63,190,48,201,63,58,35,226,63,159,171,245,63,133,124,8,64,98,16,20,64,23,183,33,64,181,166,45,64,83,150,57,64,193,202,161,61,147,169,66,62,179,12,209,62,11,70,37,63,30,167,88,63,227,165,131,63,207,102,157,63,77,132,181,63,208,213,206,63,231,29,231,63,249,160,255,63,159,60,12,64,34,108,24,64,63,198,36,64,147,58,49,64,227,199,60,64,46,144,160,59,237,13,62,60,188,116,147,59,36,151,127,59,111,18,131,186,130,226,71,188,158,239,167,188,137,210,94,187,66,96,101,188,75,89,134,187,154,119,156,60,38,228,3,189,23,183,81,57,95,41,75,188,100,93,220,188,202,84,193,59,142,6,112,61,186,218,10,61,155,85,31,189,147,169,2,189,0,111,1,188,158,239,167,188,79,175,20,189,232,217,172,188,93,109,197,60,70,182,115,61,55,26,64,61,103,213,231,60,224,45,144,60,226,233,149,188,187,184,141,188,23,183,209,185,82,73,29,59,104,145,109,60,245,185,90,61,229,97,161,60,244,253,212,187,172,139,219,187,62,232,89,60,5,163,18,61,195,100,42,188,9,27,30,189,234,149,50,188,36,151,255,187,174,71,225,60,139,108,103,61,132,158,205,60,124,242,48,187,159,171,173,187,77,21,140,60,224,45,16,60,131,192,74,61,176,3,103,60,36,151,127,59,162,69,54,189,86,125,46,189,153,187,150,188,66,96,229,188,125,174,182,188,36,151,127,59,77,21,140,188,181,55,120,189,9,249,160,189,197,32,48,189,137,210,94,61,70,182,115,61,111,18,3,61,82,73,157,186,124,242,48,60,80,141,151,60,208,68,216,59,231,29,39,61,101,25,98,61,215,52,239,187,168,87,202,188,166,155,68,189,250,237,235,188,7,95,152,60,159,171,173,60,195,100,170,186,157,17,37,61,216,240,116,61,223,79,141,61,134,90,83,61,33,31,244,188,151,255,144,188,211,188,227,60,39,160,137,60,159,171,45,188,132,158,205,60,9,27,30,61,222,147,7,61,195,100,170,187,62,232,89,60,32,99,238,60,0,111,129,188,39,194,6,189,189,82,22,189,67,28,235,60,54,60,61,61,224,45,144,188,46,144,160,59,20,63,198,60,137,210,94,187,27,47,93,60,4,231,12,60,33,31,116,188,93,109,197,60,59,112,78,61,240,133,201,60,64,164,223,188,116,36,23,189,124,242,48,188,16,233,55,189,0,0,128,189,12,147,41,189,215,52,239,188,177,225,105,189,88,57,52,189,224,45,16,188,46,144,32,60,250,237,107,58,23,183,209,185,52,128,55,58,73,157,0,189,195,100,170,188,101,25,98,188,28,235,226,188,224,45,144,187,171,207,85,61,37,6,1,61,27,47,221,188,28,235,226,188,23,183,209,188,85,193,40,188,193,168,164,188,67,28,235,188,138,142,228,188,43,24,149,188,202,84,65,61,181,21,123,61,236,81,56,61,48,42,41,61,149,101,8,61,198,220,53,61,125,174,182,60,130,226,199,59,0,111,1,61,74,123,3,61,168,53,77,61,127,106,60,61,205,204,204,60,90,245,185,60,18,131,192,60,156,51,34,60,80,141,151,60,150,33,14,189,77,21,140,189,44,212,154,188,20,63,198,60,227,165,155,188,64,164,223,188,82,73,157,186,242,65,207,188,142,6,240,60,54,60,189,188,161,103,179,188,111,18,131,186,218,172,122,60,23,183,81,60,185,252,135,188,14,45,50,189,159,205,42,189,20,63,70,188,5,197,15,189,119,190,31,189,72,80,252,59,211,188,227,188,115,104,17,189,153,187,22,60,59,112,206,187,111,18,3,58,124,242,176,60,91,211,60,61,100,93,92,61,199,186,56,61,33,31,244,60,244,253,84,188,237,13,190,59,85,193,168,60,238,235,64,61,241,99,76,61,66,96,229,60,4,231,12,60,52,128,55,186,220,215,1,189,61,44,212,60,224,45,144,60,4,231,140,59,159,171,173,60,101,25,98,60,159,171,45,60,88,57,180,60,10,215,35,187,10,215,163,59,130,226,71,60,231,29,167,187,4,231,12,188,202,84,65,189,111,18,3,186,9,27,158,60,23,183,81,59,240,133,201,60,198,220,181,60,188,116,19,60,111,18,3,189,188,5,146,189,25,115,87,189,254,101,119,188,88,57,52,189,221,181,132,189,164,223,62,189,153,187,22,188,127,106,60,60,134,90,83,188,159,171,173,59,4,231,12,189,45,178,29,189,46,144,32,61,180,89,117,61,12,147,41,61,2,43,135,60,46,144,32,188,111,18,3,189,171,207,213,188,88,57,180,187,211,188,99,188,88,57,52,188,39,160,9,60,4,231,140,60,240,133,73,189,136,244,91,189,111,18,3,189,250,237,107,187,135,22,217,60,45,178,29,61,23,183,209,59,66,96,229,188,127,106,188,188,172,139,91,60,93,109,197,60,159,171,45,60,228,131,30,61,49,8,44,60,137,210,222,59,244,253,212,60,145,237,252,62,118,113,251,62,208,68,248,62,180,200,246,62,135,167,247,62,190,193,247,62,34,253,246,62,116,181,245,62,217,95,246,62,161,214,244,62,70,37,245,62,5,52,241,62,124,242,240,62,187,39,239,62,58,146,235,62,195,100,234,62,171,62,151,62,190,48,89,62,146,92,62,62,204,127,72,62,7,240,22,62,173,105,222,61,168,87,10,62,3,120,11,62,153,42,24,62,186,107,9,62,254,212,248,61,23,183,17,62,84,82,39,62,120,156,34,62,246,151,29,62,36,40,62,62,247,228,225,61,2,188,197,62,91,177,47,63,66,62,88,63,72,80,108,63,63,87,131,63,114,249,143,63,250,237,179,63,177,191,212,63,43,135,230,63,242,65,239,63,111,129,4,64,4,86,22,64,180,200,38,64,230,63,48,64,235,115,57,64,238,90,2,62,16,122,118,62,165,44,195,62,208,179,25,63,208,213,70,63,110,52,112,63,5,52,145,63,143,228,170,63,127,251,194,63,31,244,220,63,48,42,249,63,45,33,11,64,53,94,22,64,108,9,33,64,127,217,45,64,143,228,58,64,242,210,77,62,250,126,170,62,29,201,229,62,6,129,37,63,68,250,77,63,141,40,125,63,99,238,146,63,111,240,165,63,86,14,189,63,138,142,212,63,204,127,240,63,90,100,7,64,108,9,21,64,11,70,33,64,71,114,45,64,146,92,58,64,215,52,239,61,9,249,96,62,130,226,167,62,224,45,240,62,247,117,32,63,193,57,83,63,137,210,134,63,60,189,162,63,72,80,188,63,185,141,214,63,108,9,241,63,45,33,7,64,8,172,20,64,155,230,33,64,209,34,47,64,248,83,59,64,59,223,15,62,73,46,159,62,128,72,255,62,220,104,48,63,200,7,93,63,96,118,135,63,5,52,161,63,206,170,183,63,5,197,207,63,130,226,231,63,180,200,254,63,78,98,12,64,72,80,24,64,202,50,36,64,200,7,49,64,221,181,60,64,32,99,46,62,182,132,156,62,0,111,225,62,143,194,5,63,112,206,24,63,178,157,79,63,202,84,137,63,233,38,169,63,168,53,197,63,16,122,222,63,60,78,249,63,131,192,10,64,77,243,22,64,179,234,35,64,254,212,48,64,88,57,60,64,176,3,231,61,185,141,134,62,222,147,231,62,162,69,38,63,60,78,81,63,35,74,123,63,75,89,150,63,238,124,175,63,57,69,199,63,251,58,224,63,197,143,249,63,245,74,9,64,22,106,21,64,86,125,34,64,231,29,47,64,35,74,59,64,217,61,57,62,94,75,168,62,125,63,5,63,90,245,57,63,95,7,110,63,222,147,143,63,25,4,166,63,169,164,190,63,185,252,215,63,221,181,236,63,184,175,3,64,171,62,15,64,134,56,26,64,147,169,38,64,247,228,49,64,240,22,60,64,55,26,128,62,206,25,241,62,105,111,48,63,88,168,85,63,26,192,107,63,242,210,133,63,11,181,158,63,181,21,187,63,245,185,210,63,150,67,235,63,61,10,3,64,63,87,15,64,35,219,29,64,133,235,41,64,82,73,49,64,145,237,56,64,244,253,212,61,178,157,111,62,241,244,202,62,170,241,18,63,39,194,70,63,86,125,126,63,154,153,153,63,19,97,179,63,113,27,205,63,52,17,230,63,29,56,255,63,160,137,12,64,17,54,24,64,66,62,36,64,36,185,48,64,150,178,60,64,239,201,67,62,187,184,173,62,115,215,242,62,224,156,33,63,141,40,77,63,4,231,124,63,119,190,151,63,156,51,178,63,172,173,200,63,152,76,221,63,54,171,246,63,188,116,7,64,5,197,19,64,76,166,34,64,206,170,47,64,84,82,59,64,203,161,197,61,41,92,79,62,68,250,173,62,238,124,255,62,170,130,49,63,23,72,112,63,221,36,150,63,110,52,176,63,188,5,202,63,86,159,227,63,223,79,253,63,233,183,11,64,238,124,23,64,255,178,35,64,4,231,48,64,4,231,60,64,208,179,89,62,127,251,186,62,182,243,13,63,80,141,55,63,237,13,94,63,39,49,136,63,14,190,160,63,22,251,179,63,58,146,203,63,178,157,231,63,145,237,252,63,203,161,9,64,174,182,22,64,20,174,35,64,124,242,44,64,20,208,56,64,181,21,59,62,68,105,175,62,163,146,250,62,194,23,38,63,168,198,75,63,147,24,116,63,222,147,143,63,125,208,163,63,222,113,186,63,49,153,210,63,148,246,230,63,208,68,0,64,193,57,15,64,170,130,29,64,93,220,42,64,229,97,57,64,23,72,80,62,184,175,195,62,226,233,5,63,14,45,50,63,31,133,107,63,15,11,133,63,79,175,148,63,23,72,176,63,118,79,198,63,242,210,221,63,3,120,251,63,38,228,7,64,109,86,21,64,118,79,34,64,87,91,45,64,166,155,60,64,61,10,215,61,170,241,82,62,45,178,189,62,126,140,25,63,93,109,85,63,183,98,135,63,85,193,160,63,183,98,183,63,64,19,209,63,18,131,232,63,79,30,254,63,212,43,13,64,210,0,26,64,54,60,37,64,205,204,48,64,253,135,60,64,60,78,17,62,123,131,207,62,250,126,42,63,33,31,100,63,27,47,133,63,54,205,147,63,169,19,160,63,184,64,178,63,46,144,200,63,121,88,224,63,77,21,252,63,70,37,13,64,189,227,24,64,85,193,36,64,231,140,48,64,174,182,58,64,154,8,27,62,215,163,144,62,237,158,220,62,97,195,19,63,100,59,63,63,149,101,120,63,174,182,146,63,222,113,170,63,218,27,196,63,75,234,220,63,66,207,246,63,55,26,8,64,223,224,19,64,220,104,32,64,147,58,45,64,156,51,58,64,251,92,45,62,83,150,161,62,236,192,249,62,35,219,41,63,215,18,82,63,102,247,116,63,109,197,142,63,29,56,167,63,44,101,193,63,136,244,219,63,191,125,245,63,98,161,6,64,230,174,17,64,23,217,30,64,62,121,44,64,162,69,58,64,5,163,18,62,95,41,139,62,163,35,217,62,59,112,14,63,110,163,49,63,125,174,102,63,230,63,148,63,206,136,178,63,231,29,207,63,11,181,230,63,132,158,253,63,209,34,11,64,58,35,22,64,28,235,34,64,65,241,47,64,151,144,59,64,213,231,106,62,120,122,197,62,160,26,15,63,118,79,62,63,8,61,107,63,120,11,140,63,111,18,163,63,108,9,185,63,18,20,207,63,189,82,230,63,234,4,252,63,136,133,10,64,92,143,22,64,201,118,34,64,146,203,47,64,39,49,60,64,104,179,42,62,73,46,159,62,104,34,236,62,81,107,26,63,205,204,60,63,56,248,98,63,131,192,138,63,18,20,167,63,5,197,191,63,199,41,218,63,157,17,245,63,24,38,7,64,44,212,18,64,38,228,31,64,109,86,45,64,222,113,58,64,16,88,57,62,147,24,164,62,105,111,240,62,123,131,31,63,15,156,67,63,77,243,126,63,203,16,159,63,32,210,183,63,19,97,203,63,46,144,224,63,45,67,244,63,242,176,4,64,140,185,15,64,231,140,28,64,167,121,43,64,42,58,58,64,32,99,238,61,82,39,192,62,63,87,27,63,169,19,64,63,174,71,129,63,220,70,155,63,231,140,176,63,152,221,195,63,215,163,208,63,143,194,229,63,250,237,243,63,49,153,6,64,18,131,24,64,156,196,36,64,62,121,44,64,131,47,56,64,211,222,32,62,82,39,224,62,127,106,44,63,134,201,84,63,102,247,100,63,63,87,123,63,248,194,148,63,56,103,180,63,227,54,210,63,171,62,231,63,157,128,246,63,97,195,11,64,87,236,27,64,131,47,40,64,89,23,47,64,137,65,56,64,187,39,15,62,240,133,137,62,99,127,217,62,246,151,29,63,213,120,73,63,176,114,128,63,236,192,153,63,29,56,175,63,122,165,196,63,196,177,222,63,99,238,250,63,146,92,10,64,115,104,21,64,237,158,32,64,206,136,46,64,136,244,59,64,38,228,67,62,213,231,170,62,155,85,255,62,129,4,37,63,222,2,73,63,30,22,130,63,11,36,152,63,63,53,174,63,232,217,196,63,68,139,220,63,252,169,241,63,77,132,5,64,170,241,18,64,9,138,31,64,175,148,45,64,0,145,58,64,90,245,185,61,161,103,51,62,198,109,148,62,16,88,9,63,125,174,70,63,174,71,129,63,236,47,155,63,207,247,179,63,15,11,205,63,43,135,230,63,113,27,253,63,39,49,12,64,38,228,23,64,185,252,35,64,37,6,49,64,76,55,61,64,34,142,53,62,202,195,162,62,246,40,252,62,233,183,47,63,7,95,88,63,251,92,125,63,217,206,151,63,64,164,175,63,141,151,198,63,188,5,226,63,50,119,253,63,64,164,11,64,2,43,23,64,44,212,34,64,102,102,46,64,12,2,59,64,184,175,3,62,233,183,111,62,118,224,188,62,131,81,9,63,162,180,55,63,41,92,111,63,198,220,141,63,159,171,165,63,206,170,191,63,238,90,218,63,54,205,243,63,248,83,7,64,177,191,20,64,118,79,34,64,255,178,47,64,162,180,59,64,85,193,104,62,1,77,196,62,201,118,14,63,126,29,56,63,103,213,87,63,247,6,127,63,0,145,150,63,116,181,173,63,62,232,201,63,148,246,222,63,29,201,245,63,8,61,7,64,125,174,18,64,226,88,31,64,197,32,44,64,131,192,58,64,143,194,53,62,209,145,156,62,44,212,218,62,85,48,26,63,101,170,80,63,44,101,137,63,206,25,169,63,69,71,194,63,57,214,213,63,7,95,232,63,22,251,251,63,57,214,9,64,129,38,22,64,51,196,33,64,90,245,45,64,217,95,58,64,103,68,41,62,100,93,220,62,115,215,34,63,94,75,72,63,181,21,107,63,29,201,133,63,65,130,154,63,131,47,180,63,210,111,207,63,42,58,234,63,209,145,0,64,154,119,12,64,195,245,24,64,233,72,38,64,156,51,50,64,128,183,60,64,227,199,24,62,175,148,133,62,129,149,195,62,127,106,12,63,186,107,57,63,0,145,110,63,184,175,147,63,171,207,173,63,161,103,195,63,39,160,217,63,12,147,241,63,157,128,6,64,236,81,20,64,22,106,33,64,168,87,46,64,187,39,59,64,170,96,84,62,83,150,193,62,180,89,5,63,174,216,47,63,58,146,91,63,205,204,124,63,206,170,151,63,159,171,173,63,66,207,190,63,84,227,221,63,19,242,241,63,103,213,7,64,103,213,19,64,167,121,31,64,124,242,44,64,147,24,56,64,95,41,11,62,66,207,102,62,66,62,168,62,28,235,226,62,2,154,40,63,120,122,101,63,102,102,142,63,43,24,173,63,71,3,200,63,222,2,225,63,95,7,254,63,39,49,12,64,11,181,22,64,3,120,35,64,15,11,49,64,125,208,59,64,152,110,18,62,245,219,151,62,59,223,239,62,134,56,38,63,47,221,84,63,38,228,131,63,127,106,156,63,230,63,180,63,106,188,204,63,102,247,228,63,113,27,253,63,231,29,11,64,181,21,23,64,91,177,35,64,7,95,48,64,39,49,60,64,171,62,23,62,204,238,137,62,206,170,207,62,142,6,16,63,111,129,52,63,251,92,93,63,233,72,134,63,174,216,159,63,132,158,189,63,136,133,218,63,184,30,245,63,63,87,7,64,118,113,19,64,238,235,32,64,68,250,45,64,143,228,58,64,86,14,45,62,35,74,155,62,250,126,234,62,95,41,43,63,136,133,90,63,26,192,131,63,236,47,155,63,165,44,179,63,190,48,201,63,158,94,225,63,190,159,250,63,207,247,7,64,176,3,19,64,16,122,30,64,104,34,44,64,153,187,58,64,64,164,223,61,233,72,142,62,62,121,248,62,197,32,48,63,125,174,102,63,202,50,140,63,193,57,163,63,67,28,187,63,63,198,212,63,95,152,236,63,138,176,1,64,214,197,13,64,116,181,25,64,16,88,37,64,43,24,49,64,241,99,60,64,245,74,25,62,227,54,186,62,90,245,25,63,132,158,77,63,132,13,127,63,238,124,151,63,130,226,175,63,53,239,200,63,86,125,222,63,56,103,244,63,68,139,4,64,14,79,15,64,243,31,26,64,41,237,37,64,67,173,49,64,200,7,61,64,115,215,18,62,73,46,127,62,40,15,203,62,16,233,23,63,18,165,77,63,220,104,136,63,239,201,163,63,153,187,182,63,55,137,201,63,45,67,228,63,235,226,246,63,22,251,7,64,218,172,22,64,5,163,34,64,21,29,45,64,227,199,56,64,157,17,37,62,171,207,149,62,85,48,234,62,216,129,35,63,129,149,83,63,211,77,130,63,116,36,151,63,255,33,173,63,29,56,199,63,247,117,224,63,246,151,245,63,249,160,7,64,82,39,20,64,213,9,32,64,71,114,45,64,34,253,58,64,12,147,169,61,109,197,62,62,203,161,165,62,174,71,1,63,154,153,57,63,95,152,124,63,88,202,154,63,222,113,178,63,68,139,204,63,148,135,229,63,34,142,253,63,33,31,12,64,64,19,25,64,124,242,36,64,137,65,48,64,162,180,59,64,4,231,76,62,209,34,187,62,139,108,7,63,228,20,45,63,191,125,77,63,128,72,127,63,131,192,154,63,201,118,182,63,84,227,205,63,246,40,228,63,191,125,253,63,39,194,10,64,243,31,22,64,123,20,34,64,115,215,46,64,186,218,58,64,172,28,26,62,159,171,141,62,7,206,217,62,127,251,26,63,181,55,72,63,75,234,116,63,46,144,144,63,139,108,167,63,146,203,191,63,222,2,217,63,192,236,238,63,221,181,4,64,102,102,18,64,54,205,31,64,196,66,45,64,169,164,58,64,174,182,34,62,253,135,212,62,165,44,19,63,254,67,42,63,146,92,78,63,25,4,134,63,28,124,161,63,100,59,175,63,217,206,191,63,65,241,227,63,143,194,253,63,208,213,6,64,61,155,17,64,1,222,34,64,181,166,45,64,15,156,55,64,200,152,187,61,200,7,61,62,19,242,193,62,188,5,34,63,73,157,96,63,41,203,136,63,90,245,161,63,124,97,186,63,104,34,212,63,175,37,236,63,163,146,2,64,244,108,14,64,44,101,25,64,170,130,37,64,106,222,49,64,232,217,60,64,67,173,105,62,216,240,212,62,180,89,21,63,73,157,48,63,151,144,79,63,218,27,132,63,168,198,163,63,134,90,195,63,227,199,216,63,56,103,236,63,155,230,5,64,79,175,16,64,186,73,24,64,41,237,33,64,57,69,47,64,244,253,60,64,249,15,41,62,7,206,153,62,76,55,233,62,178,46,30,63,117,2,74,63,180,89,117,63,197,143,145,63,25,115,175,63,61,44,204,63,47,221,228,63,85,193,248,63,66,96,9,64,190,48,21,64,182,132,32,64,30,167,44,64,115,104,57,64,56,248,2,62,93,254,195,62,74,12,34,63,157,17,85,63,89,23,119,63,61,10,143,63,230,174,157,63,216,240,172,63,213,120,193,63,78,209,209,63,186,73,228,63,168,87,250,63,232,217,12,64,252,169,29,64,88,57,44,64,161,248,57,64,143,83,244,61,119,190,95,62,116,70,180,62,43,246,7,63,118,224,60,63,182,132,108,63,221,36,142,63,119,45,169,63,52,162,196,63,27,13,224,63,145,15,250,63,173,105,10,64,180,200,22,64,8,61,35,64,165,78,48,64,204,127,60,64,53,239,56,62,233,183,175,62,247,6,255,62,106,222,49,63,138,142,100,63,224,190,134,63,222,147,159,63,244,253,180,63,9,249,208,63,143,194,229,63,2,43,255,63,2,154,12,64,16,122,22,64,100,93,36,64,227,165,47,64,112,95,59,64,200,7,61,62,155,85,159,62,177,225,233,62,66,207,22,63,177,80,59,63,186,107,89,63,120,156,130,63,177,225,153,63,215,52,175,63,86,14,205,63,223,224,235,63,68,139,4,64,164,112,17,64,193,57,31,64,48,42,45,64,190,159,58,64,88,57,180,61,128,183,128,62,204,127,8,63,199,41,58,63,93,254,99,63,202,84,145,63,124,242,168,63,171,62,191,63,145,237,204,63,102,136,219,63,123,131,239,63,126,29,4,64,203,161,17,64,102,102,34,64,70,37,45,64,4,231,56,64,77,132,13,62,179,12,145,62,86,125,238,62,46,144,48,63,181,55,104,63,48,42,137,63,107,154,159,63,200,7,181,63,227,165,203,63,187,184,229,63,6,129,253,63,79,30,10,64,251,92,21,64,66,96,33,64,54,171,46,64,77,243,58,64,245,74,217,61,143,228,178,62,161,248,33,63,90,100,91,63,126,140,121,63,2,43,135,63,58,146,147,63,154,153,169,63,168,53,205,63,131,192,234,63,1,77,252,63,161,103,7,64,57,69,19,64,56,248,34,64,255,178,51,64,60,189,62,64,175,37,36,62,87,91,145,62,182,132,220,62,135,22,25,63,186,73,76,63,113,27,133,63,147,58,153,63,113,27,173,63,233,38,201,63,143,83,228,63,190,48,249,63,83,150,9,64,122,54,23,64,35,74,35,64,143,228,46,64,21,140,58,64,141,40,45,62,36,151,159,62,34,142,245,62,18,131,48,63,9,138,95,63,101,25,130,63,89,134,152,63,25,115,175,63,75,234,196,63,131,47,220,63,158,94,241,63,1,77,4,64,179,234,15,64,44,101,29,64,25,115,43,64,76,55,57,64,203,161,197,61,233,72,46,62,19,97,163,62,37,117,18,63,41,92,79,63,181,21,131,63,228,20,157,63,116,181,181,63,139,253,205,63,45,33,231,63,228,131,254,63,108,9,13,64,184,30,25,64,233,38,37,64,204,127,48,64,65,241,59,64,20,174,71,62,61,44,180,62,148,246,6,63,65,130,50,63,9,138,95,63,149,101,136,63,154,8,155,63,218,172,178,63,233,72,206,63,218,27,228,63,96,229,248,63,85,48,10,64,93,109,21,64,167,232,32,64,178,157,47,64,52,128,59,64,150,33,14,62,28,235,130,62,170,241,210,62,120,156,18,63,45,67,60,63,232,106,107,63,166,155,140,63,109,231,163,63,47,110,187,63,227,165,211,63,131,192,234,63,145,126,3,64,181,166,17,64,70,148,30,64,94,75,44,64,124,97,58,64,218,172,58,62,159,205,170,62,100,204,253,62,109,86,45,63,122,54,91,63,236,192,129,63,93,109,157,63,103,68,177,63,190,48,201,63,58,35,226,63,159,171,245,63,133,124,8,64,98,16,20,64,23,183,33,64,181,166,45,64,83,150,57,64,193,202,161,61,147,169,66,62,179,12,209,62,11,70,37,63,30,167,88,63,227,165,131,63,207,102,157,63,77,132,181,63,208,213,206,63,231,29,231,63,249,160,255,63,159,60,12,64,34,108,24,64,63,198,36,64,147,58,49,64,227,199,60,64,46,144,160,59,237,13,62,60,188,116,147,59,36,151,127,59,111,18,131,186,130,226,71,188,158,239,167,188,137,210,94,187,66,96,101,188,75,89,134,187,154,119,156,60,38,228,3,189,23,183,81,57,95,41,75,188,100,93,220,188,202,84,193,59,142,6,112,61,186,218,10,61,155,85,31,189,147,169,2,189,0,111,1,188,158,239,167,188,79,175,20,189,232,217,172,188,93,109,197,60,70,182,115,61,55,26,64,61,103,213,231,60,224,45,144,60,226,233,149,188,187,184,141,188,23,183,209,185,82,73,29,59,104,145,109,60,245,185,90,61,229,97,161,60,244,253,212,187,172,139,219,187,62,232,89,60,5,163,18,61,195,100,42,188,9,27,30,189,234,149,50,188,36,151,255,187,174,71,225,60,139,108,103,61,132,158,205,60,124,242,48,187,159,171,173,187,77,21,140,60,224,45,16,60,131,192,74,61,176,3,103,60,36,151,127,59,162,69,54,189,86,125,46,189,153,187,150,188,66,96,229,188,125,174,182,188,36,151,127,59,77,21,140,188,181,55,120,189,9,249,160,189,197,32,48,189,137,210,94,61,70,182,115,61,111,18,3,61,82,73,157,186,124,242,48,60,80,141,151,60,208,68,216,59,231,29,39,61,101,25,98,61,215,52,239,187,168,87,202,188,166,155,68,189,250,237,235,188,7,95,152,60,159,171,173,60,195,100,170,186,157,17,37,61,216,240,116,61,223,79,141,61,134,90,83,61,33,31,244,188,151,255,144,188,211,188,227,60,39,160,137,60,159,171,45,188,132,158,205,60,9,27,30,61,222,147,7,61,195,100,170,187,62,232,89,60,32,99,238,60,0,111,129,188,39,194,6,189,189,82,22,189,67,28,235,60,54,60,61,61,224,45,144,188,46,144,160,59,20,63,198,60,137,210,94,187,27,47,93,60,4,231,12,60,33,31,116,188,93,109,197,60,59,112,78,61,240,133,201,60,64,164,223,188,116,36,23,189,124,242,48,188,16,233,55,189,0,0,128,189,12,147,41,189,215,52,239,188,177,225,105,189,88,57,52,189,224,45,16,188,46,144,32,60,250,237,107,58,23,183,209,185,52,128,55,58,73,157,0,189,195,100,170,188,101,25,98,188,28,235,226,188,224,45,144,187,171,207,85,61,37,6,1,61,27,47,221,188,28,235,226,188,23,183,209,188,85,193,40,188,193,168,164,188,67,28,235,188,138,142,228,188,43,24,149,188,202,84,65,61,181,21,123,61,236,81,56,61,48,42,41,61,149,101,8,61,198,220,53,61,125,174,182,60,130,226,199,59,0,111,1,61,74,123,3,61,168,53,77,61,127,106,60,61,205,204,204,60,90,245,185,60,18,131,192,60,156,51,34,60,80,141,151,60,150,33,14,189,77,21,140,189,44,212,154,188,20,63,198,60,227,165,155,188,64,164,223,188,82,73,157,186,242,65,207,188,142,6,240,60,54,60,189,188,161,103,179,188,111,18,131,186,218,172,122,60,23,183,81,60,185,252,135,188,14,45,50,189,159,205,42,189,20,63,70,188,5,197,15,189,119,190,31,189,72,80,252,59,211,188,227,188,115,104,17,189,153,187,22,60,59,112,206,187,111,18,3,58,124,242,176,60,91,211,60,61,100,93,92,61,199,186,56,61,33,31,244,60,244,253,84,188,237,13,190,59,85,193,168,60,238,235,64,61,241,99,76,61,66,96,229,60,4,231,12,60,52,128,55,186,220,215,1,189,61,44,212,60,224,45,144,60,4,231,140,59,159,171,173,60,101,25,98,60,159,171,45,60,88,57,180,60,10,215,35,187,10,215,163,59,130,226,71,60,231,29,167,187,4,231,12,188,202,84,65,189,111,18,3,186,9,27,158,60,23,183,81,59,240,133,201,60,198,220,181,60,188,116,19,60,111,18,3,189,188,5,146,189,25,115,87,189,254,101,119,188,88,57,52,189,221,181,132,189,164,223,62,189,153,187,22,188,127,106,60,60,134,90,83,188,159,171,173,59,4,231,12,189,45,178,29,189,46,144,32,61,180,89,117,61,12,147,41,61,2,43,135,60,46,144,32,188,111,18,3,189,171,207,213,188,88,57,180,187,211,188,99,188,88,57,52,188,39,160,9,60,4,231,140,60,240,133,73,189,136,244,91,189,111,18,3,189,250,237,107,187,135,22,217,60,45,178,29,61,23,183,209,59,66,96,229,188,127,106,188,188,172,139,91,60,93,109,197,60,159,171,45,60,228,131,30,61,49,8,44,60,137,210,222,59,244,253,212,60,145,237,252,62,118,113,251,62,208,68,248,62,180,200,246,62,135,167,247,62,190,193,247,62,34,253,246,62,116,181,245,62,217,95,246,62,161,214,244,62,70,37,245,62,5,52,241,62,124,242,240,62,187,39,239,62,58,146,235,62,195,100,234,62,171,62,151,62,190,48,89,62,146,92,62,62,204,127,72,62,7,240,22,62,173,105,222,61,168,87,10,62,3,120,11,62,153,42,24,62,186,107,9,62,254,212,248,61,23,183,17,62,84,82,39,62,120,156,34,62,246,151,29,62,36,40,62,62,6,5,5,5,9,9,9,9,6,9,9,9,6,5,7,3,9,9,12,6,6,9,12,6,11,10,0,0,18,18,0,0,15,18,0,0,7,7,7,0,12,12,12,0,6,15,12,0,6,6,6,3,12,9,9,6,6,12,9,6,8,8,5,0,15,12,9,0,6,18,9,0,6,5,5,5,9,9,9,9,6,9,9,9,6,5,7,3,9,9,12,6,6,9,12,6,11,10,0,0,18,18,0,0,15,18,0,0,7,7,7,0,12,12,12,0,6,15,12,0,6,6,6,3,12,9,9,6,6,12,9,6,8,8,5,0,15,12,9,0,6,18,9,0,32,172,13,0,32,156,13,0,32,146,13,0,32,136,13,0,32,127,13,0,0,0,0,0,32,178,13,0,32,168,13,0,32,152,13,0,32,142,13,0,32,135,13,0,0,0,0,0,143,27,78,190,4,175,142,190,152,107,49,190,142,88,75,190,171,209,91,190,113,145,27,190,148,190,240,189,143,86,69,190,57,211,36,190,166,182,84,190,238,124,255,189,236,220,4,190,35,48,6,190,41,32,13,190,252,1,31,190,165,76,42,190,231,110,55,190,38,172,45,190,56,48,41,190,160,196,135,189,215,191,11,190,170,72,53,190,165,16,128,190,74,152,9,190,145,39,137,189,218,200,21,190,186,187,46,190,151,169,9,190,230,146,170,189,52,215,41,190,199,214,211,189,203,186,15,190,250,154,5,190,121,92,244,189,194,193,254,189,173,246,176,189,239,171,2,190,22,164,9,190,103,183,150,189,105,199,237,189,179,122,231,189,146,234,187,189,232,190,220,189,248,25,7,190,240,138,0,190,14,134,58,190,30,24,192,189,50,174,56,189,36,242,157,189,129,93,13,190,242,66,42,190,237,70,31,189,46,143,149,189,141,209,218,189,146,93,137,189,165,73,233,189,81,77,73,189,199,44,219,189,167,118,230,189,145,209,129,189,174,243,207,189,129,233,244,189,58,4,78,189,150,149,38,189,220,189,220,189,175,9,137,189,168,223,165,189,13,111,86,189,133,206,27,190,232,246,210,189,158,67,185,189,196,96,126,188,215,194,28,190,253,132,179,189,199,217,244,188,36,14,25,189,159,114,92,190,32,96,13,190,145,154,182,189,142,60,80,189,136,133,90,189,197,115,118,189,203,246,129,189,32,178,200,188,30,168,83,189,3,96,156,189,157,43,10,189,205,32,158,189,52,131,56,189,246,37,219,189,137,12,171,188,167,232,200,188,122,253,169,189,119,102,130,189,43,249,88,188,188,7,232,188,122,52,213,189,136,133,154,189,171,32,6,189,72,138,200,60,220,128,175,189,169,194,159,188,204,208,56,189,91,238,204,188,87,38,252,189,142,172,252,188,231,137,103,187,50,232,132,188,251,115,209,188,148,104,73,189,217,39,128,187,209,117,225,188,223,220,31,189,38,171,162,188,4,254,48,189,162,236,109,189,247,86,36,189,1,247,188,188,207,187,177,186,96,4,13,60,43,190,129,189,172,200,232,186,228,49,131,60,167,231,221,188,65,125,139,189,152,20,31,189,178,46,46,61,146,8,141,58,8,174,50,189,139,222,169,188,242,10,68,189,205,117,26,61,36,38,40,189,224,216,179,60,236,52,210,188,133,180,70,58,193,144,85,188,141,71,41,59,180,227,6,188,227,199,24,189,72,250,180,187,113,90,112,188,34,251,160,60,64,137,79,188,95,121,144,187,43,137,108,188,255,89,115,189,254,99,161,188,142,91,204,60,43,22,63,188,117,32,107,188,73,158,235,188,227,107,79,60,62,118,151,60,223,50,39,188,176,254,79,60,208,238,144,187,238,9,146,60,119,17,38,61,132,212,109,59,126,113,169,60,35,20,219,60,125,4,254,59,155,172,209,188,226,92,3,61,230,90,52,56,55,136,214,60,49,40,211,187,238,208,112,61,242,152,129,60,105,171,146,186,231,169,142,188,50,30,165,60,187,237,66,189,165,130,138,59,158,12,14,60,130,86,96,61,253,159,3,61,55,224,243,60,196,5,32,188,113,0,253,60,216,156,67,61,80,114,7,61,47,252,224,59,155,28,126,61,221,206,62,60,14,135,101,61,227,27,138,60,2,17,98,60,76,251,230,188,13,171,120,61,90,70,106,60,88,227,204,61,59,194,41,61,81,133,191,60,254,240,115,188,138,119,128,61,19,101,47,189,85,222,14,59,36,214,98,189,88,146,124,61,64,189,153,60,130,29,127,188,31,191,151,189,169,251,128,61,156,219,164,61,87,118,65,60,22,51,2,189,155,1,174,61,160,137,48,61,1,252,211,188,15,95,166,60,161,245,112,60,156,21,17,61,253,188,41,189,166,157,90,189,214,111,166,61,110,194,189,59,13,195,135,189,138,31,35,189,183,236,144,60,255,31,167,188,246,240,37,189,56,243,171,189,202,140,247,61,66,93,100,61,201,228,212,188,204,236,115,189,231,168,163,61,214,85,1,60,182,219,174,189,151,172,234,189,81,246,22,61,139,25,33,189,53,122,213,189,176,140,141,189,163,176,11,60,144,161,131,189,206,226,69,189,202,21,30,189,103,14,9,61,34,53,237,188,198,51,136,189,246,154,30,61,77,75,44,189,207,45,52,189,41,35,206,189,206,136,146,189,3,93,123,188,20,208,132,189,157,128,134,189,80,110,251,189,110,165,215,187,144,47,161,187,62,148,232,189,70,64,21,190,122,139,7,60,54,204,144,189,60,245,40,190,0,171,195,189,109,143,222,186,55,140,130,189,30,23,5,190,210,224,54,188,135,137,70,189,51,51,179,189,29,87,227,189,238,180,37,190,207,220,3,189,231,82,188,189,162,39,165,189,156,83,73,60,16,89,196,189,18,245,130,188,70,239,148,189,175,95,208,189,214,196,162,189,19,15,168,189,84,225,79,190,131,104,205,189,72,166,195,188,247,29,131,189,149,97,44,190,28,210,88,190,8,114,144,189,115,16,212,189,67,169,253,189,15,123,97,61,113,58,9,189,156,79,157,189,81,108,133,188,17,224,52,61,55,25,181,189,247,143,37,190,137,240,111,189,148,75,99,60,142,31,170,189,99,66,44,190,136,103,137,188,158,68,164,189,90,246,164,189,156,109,14,190,105,55,250,60,181,250,234,59,103,154,240,189,88,116,171,189,75,202,221,60,126,199,112,187,193,255,38,190,220,158,32,190,186,187,78,188,79,235,182,188,231,198,52,190,144,130,231,189,107,13,165,188,200,12,84,61,154,149,29,190,119,19,76,190,159,32,49,189,106,22,232,60,200,209,220,189,210,58,26,190,53,152,134,60,81,76,190,61,240,250,12,190,18,159,59,190,164,56,135,61,187,96,240,60,75,177,67,190,150,67,203,189,229,213,57,61,19,211,133,59,35,187,114,190,94,244,5,190,25,172,184,188,253,18,241,188,157,214,77,190,61,130,91,189,200,94,239,187,148,104,9,189,212,68,127,190,201,227,105,190,209,231,163,59,254,40,234,59,24,119,83,190,1,22,89,190,60,76,123,189,100,119,65,189,95,235,130,190,83,91,10,190,127,106,156,61,87,9,22,61,213,176,151,190,0,113,151,189,89,82,238,187,71,146,160,188,240,23,155,190,76,80,51,190,190,104,143,189,187,213,51,189,129,4,117,190,128,17,52,189,11,11,174,189,33,33,138,189,180,88,130,190,138,229,150,190,218,200,181,189,157,72,144,189,90,132,82,190,94,187,116,190,128,126,255,189,179,122,7,61,90,132,82,190,44,16,93,190,29,62,233,188,250,13,243,61,206,83,29,190,3,95,81,190,60,108,34,189,231,170,9,190,105,110,21,190,201,147,68,190,241,131,51,190,192,7,175,60,175,238,24,190,176,171,89,190,218,83,242,189,99,155,212,61,250,99,42,190,252,223,97,190,41,208,135,190,99,126,238,188,113,28,40,190,242,207,108,190,27,133,132,190,225,154,123,61,180,0,77,190,80,227,134,190,185,26,89,190,87,65,236,61,202,53,5,190,145,66,89,190,143,57,79,190,40,209,242,61,29,87,83,190,201,229,159,189,21,83,105,190,122,170,227,189,44,183,4,190,164,23,53,190,204,97,119,190,157,17,133,190,224,17,53,190,176,2,60,189,243,28,17,190,137,94,86,190,243,204,179,190,35,191,254,188,66,38,9,190,54,202,58,190,111,44,40,190,176,59,221,60,213,3,102,188,18,105,91,189,83,36,47,190,146,94,212,188,254,184,253,60,140,245,141,60,250,154,165,189,64,194,176,188,161,189,250,59,168,1,131,61,106,21,125,189,92,33,44,61,206,222,153,188,99,123,109,189,188,234,225,189,6,76,96,61,133,205,0,61,143,223,219,187,146,234,11,190,245,159,181,60,195,15,174,61,12,178,229,60,6,74,130,190,140,100,143,187,74,208,159,61,137,211,9,61,85,23,112,190,168,139,180,61,145,238,39,61,19,243,44,59,237,240,23,189,129,122,115,61,28,211,147,61,206,51,118,60,89,220,63,189,95,182,157,187,206,196,180,61,18,222,30,61,195,186,177,189,253,246,245,61,6,71,169,61,94,15,166,60,65,103,242,189,192,206,141,189,161,73,194,61,46,144,32,61,185,55,191,188,13,167,172,189,46,203,87,61,158,6,140,60,243,141,104,188,22,165,132,58,40,185,67,60,217,206,151,61,3,93,123,188,130,117,156,61,206,54,183,60,90,98,229,188,177,247,226,60,152,190,23,61,60,79,220,61,38,25,121,61,79,204,250,60,75,143,38,61,200,125,43,60,213,36,152,61,69,75,30,61,78,183,236,61,154,152,142,61,190,105,250,59,101,142,197,61,189,252,142,61,181,249,127,61,207,134,124,60,158,153,96,61,91,152,133,61,255,90,94,61,209,117,225,61,173,247,27,62,2,45,189,61,193,110,216,60,180,1,88,188,241,185,19,62,16,205,252,61,185,27,164,61,34,83,190,60,12,200,254,61,247,231,34,60,91,10,24,190,193,27,82,190,81,102,67,189,210,26,3,60,218,169,57,60,102,45,133,61,134,141,178,188,84,114,14,189,116,238,22,190,13,169,162,186,87,179,206,186,60,191,168,60,125,173,171,189,251,92,237,188,211,248,53,190,32,67,135,61,122,29,49,189,130,27,41,190,43,104,90,61,193,171,197,61,165,16,200,189,73,20,218,61,148,160,191,188,167,206,227,61,216,68,22,190,69,47,35,190,133,40,223,60,244,109,65,188,89,196,48,189,59,52,108,61,5,224,159,60,89,109,126,189,251,232,212,60,13,111,38,62,199,47,188,61,163,64,31,60,35,192,201,189,217,38,21,61,61,210,96,60,216,157,238,189,145,152,96,61,131,81,57,190,216,186,244,61,85,221,3,62,42,112,242,61,92,5,1,190,36,237,134,61,27,101,253,188,44,243,246,61,75,177,35,189,13,25,79,189,220,103,181,189,79,89,77,61,111,246,7,61,5,196,4,190,82,212,153,189,245,189,102,190,104,204,36,189,240,165,144,61,190,246,172,189,179,153,195,61,116,37,130,61,88,32,26,62,93,195,12,61,231,142,62,62,122,222,141,189,134,2,70,190,43,250,155,190,15,239,129,190,98,16,40,190,247,57,142,190,113,202,28,190,246,239,10,190,142,35,86,190,45,206,88,190,208,125,249,189,96,233,92,190,40,156,149,190,63,141,75,190,222,141,37,190,226,91,120,190,39,22,40,190,88,231,56,190,57,98,13,190,21,111,196,189,180,118,75,190,46,3,30,190,230,88,126,190,206,22,112,190,137,69,12,190,95,237,40,190,212,213,221,189,169,217,51,190,94,77,254,189,30,252,228,189,163,201,101,190,246,7,138,189,16,201,32,190,12,117,72,190,32,151,184,189,128,17,244,189,21,56,41,190,175,177,203,189,165,107,22,190,111,185,218,189,138,227,16,190,27,101,221,189,122,252,222,189,158,66,174,189,123,102,201,189,10,47,225,189,4,30,216,189,152,20,95,189,192,4,30,190,91,206,37,189,114,191,19,190,187,9,254,189,28,207,39,189,164,28,172,189,34,79,18,190,53,10,73,189,234,203,242,189,171,146,136,189,207,75,197,189,16,59,179,189,173,80,100,189,204,11,112,189,222,0,115,189,208,213,182,189,76,136,249,189,125,91,112,189,81,18,178,189,0,85,92,189,198,109,180,188,42,224,254,189,224,128,22,189,185,22,141,189,240,220,59,189,36,151,127,59,123,48,201,189,12,177,186,189,147,26,218,186,62,175,56,189,103,156,166,189,95,39,149,189,207,158,11,189,24,90,29,189,196,123,206,189,127,48,240,187,54,176,181,189,106,23,19,189,204,38,192,187,95,40,128,189,245,132,165,188,24,121,217,188,123,215,160,188,132,155,140,59,180,31,41,189,82,127,13,190,191,185,191,60,34,28,51,188,66,237,55,189,46,30,94,60,43,220,114,60,230,88,190,189,173,107,116,61,11,38,254,188,207,18,196,189,210,24,173,60,72,21,165,189,112,178,13,189,72,249,201,60,143,171,17,189,131,136,84,59,226,33,140,60,154,205,227,59,15,123,161,185,167,6,154,61,248,54,253,188,76,111,255,188,102,131,204,60,89,50,71,61,58,148,33,189,49,150,105,61,86,131,176,60,244,77,26,188,203,46,152,188,54,32,194,60,54,228,31,188,33,61,197,60,149,98,7,61,32,67,199,60,215,195,23,61,132,46,97,187,23,101,54,61,227,224,82,188,209,61,235,187,121,59,2,61,250,125,159,61,86,131,176,60,57,125,189,60,66,149,90,61,190,79,85,61,122,29,241,60,179,64,59,60,130,59,144,61,145,99,235,60,242,119,239,186,152,163,7,61,171,236,123,61,155,201,55,189,123,249,29,61,44,243,214,60,226,114,124,61,101,137,14,61,17,224,116,61,67,85,12,61,44,41,119,61,183,127,133,61,16,150,113,61,204,235,168,61,80,139,65,61,29,86,184,61,153,12,135,61,45,38,54,61,217,34,137,61,181,254,150,61,48,101,224,185,88,29,153,61,203,245,118,61,212,95,175,61,230,234,135,61,70,182,211,61,88,27,163,61,217,118,250,61,215,189,21,61,153,158,112,61,253,105,227,61,65,155,188,61,125,236,174,61,234,63,203,61,174,126,236,61,205,200,32,61,107,158,163,60,163,149,251,61,48,216,77,61,149,102,35,62,41,174,202,61,82,237,83,61,78,237,12,62,19,73,148,61,242,209,226,187,162,93,5,62,225,152,21,62,150,179,183,61,177,167,13,62,2,102,190,61,46,118,11,62,67,59,135,61,38,227,24,62,200,124,0,62,111,157,79,62,192,63,21,62,36,242,157,61,135,192,17,59,208,152,169,61,75,89,6,62,70,237,254,61,197,88,54,62,105,59,38,62,83,234,50,62,123,221,66,62,19,40,2,62,175,11,79,62,49,65,29,62,172,197,39,62,47,109,120,62,9,139,74,62,30,55,12,62,183,68,62,62,52,218,106,62,84,254,69,62,243,230,112,189,190,220,71,62,134,57,17,62,227,221,129,62,113,27,125,62,83,180,82,62,43,161,123,61,117,61,209,188,83,89,244,61,120,208,108,189,237,216,168,61,109,0,150,61,45,205,141,189,12,63,24,62,229,37,255,60,164,137,247,188,43,80,11,188,61,124,217,61,188,202,218,188,242,34,179,61,46,27,29,188,19,45,185,189,179,239,138,57,117,174,104,61,73,73,79,189,25,201,158,188,7,239,43,60,229,154,162,189,180,227,6,60,121,232,59,188,34,193,148,189,39,136,122,189,10,44,64,61,25,30,155,189,145,40,148,189,182,160,247,187,138,32,206,188,87,63,150,189,69,130,169,59,239,169,252,189,26,253,40,189,76,55,9,188,255,66,15,190,109,202,149,60,127,135,34,60,244,220,18,190,188,122,213,189,53,10,9,61,184,176,206,189,39,160,9,190,119,133,190,188,247,147,33,190,97,165,194,189,82,98,23,189,216,42,97,190,111,12,161,189,75,229,237,58,121,3,60,190,165,217,188,188,180,231,50,189,79,202,20,190,182,188,34,190,43,217,113,189,150,91,74,190,237,41,41,190,224,47,230,60,190,136,102,190,59,200,43,190,188,4,103,189,13,197,93,190,177,135,214,189,202,222,210,189], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+877720);
/* memory initializer */ allocate([180,114,47,190,50,198,119,190,245,217,129,189,121,64,9,190,122,140,82,190,208,214,65,60,151,31,152,190,188,61,88,190,244,134,123,188,10,20,177,189,253,103,77,190,48,74,144,189,239,0,95,190,215,138,142,190,58,5,249,60,255,234,113,190,56,187,165,190,86,97,179,189,94,103,99,190,6,216,87,190,161,132,217,61,206,25,145,190,78,208,198,189,86,45,41,61,24,153,160,189,208,43,30,190,19,239,128,61,33,144,91,190,46,57,206,189,109,171,249,61,160,220,54,190,139,80,236,188,45,7,122,61,215,164,27,189,209,177,19,190,33,201,44,188,38,141,177,189,90,102,145,189,237,73,0,62,39,192,48,60,160,23,174,189,2,186,111,61,28,182,29,190,156,80,136,61,95,124,145,61,115,242,18,190,163,59,8,61,51,25,30,62,98,73,9,190,213,202,4,61,125,147,102,189,217,5,227,189,210,252,177,61,88,115,128,59,44,131,106,189,208,69,67,61,107,158,99,189,209,88,91,190,160,222,140,61,15,40,155,187,27,184,131,190,137,183,78,61,97,83,167,61,68,107,149,190,17,1,135,59,231,56,183,188,234,119,49,190,71,59,238,188,129,93,237,189,221,154,84,190,65,182,44,62,115,75,11,62,143,109,185,61,15,41,6,61,221,210,106,189,146,149,15,62,4,173,64,186,199,16,128,188,76,250,11,62,107,153,140,188,97,169,206,189,210,110,244,60,164,83,183,189,63,169,22,190,130,200,98,189,211,218,148,189,192,38,91,190,174,100,71,61,149,16,108,189,253,134,89,190,253,47,87,188,91,67,233,189,222,29,73,190,128,216,146,189,218,59,35,190,153,129,130,190,80,137,107,187,197,226,183,188,121,177,144,61,180,28,232,60,231,171,148,190,115,76,150,188,4,226,101,190,137,153,189,190,29,3,138,190,95,96,6,190,122,81,251,189,77,20,137,190,28,124,49,62,217,6,14,62,44,213,37,62,201,119,169,60,30,198,228,61,228,102,184,60,111,246,199,61,163,147,101,61,172,27,15,62,173,110,117,61,237,159,103,61,68,51,79,189,91,176,20,61,221,34,176,60,240,224,135,189,154,234,73,60,158,40,137,189,243,226,196,61,17,227,245,189,147,113,172,189,16,233,55,60,184,64,66,61,7,120,82,188,197,3,138,189,202,250,237,189,93,165,251,61,172,228,227,188,42,55,17,61,213,177,202,188,132,42,149,61,140,131,11,189,78,180,171,186,17,168,158,61,159,34,167,61,101,109,3,62,28,239,14,62,103,209,59,62,241,71,177,61,66,148,31,190,45,67,92,189,1,249,66,190,209,176,152,188,190,104,79,190,200,178,128,189,239,89,191,190,31,217,140,190,114,220,201,190,68,253,62,190,59,112,238,190,206,79,97,190,38,228,131,61,230,63,196,189,208,43,134,190,18,162,76,190,33,63,43,190,214,85,193,189,203,16,71,61,96,203,107,61,171,95,233,187,214,140,44,62,93,164,80,61,177,52,32,62,200,38,121,189,237,156,22,62,172,3,48,190,144,133,72,62,60,48,96,190,219,192,13,62,44,131,138,190,62,121,72,62,96,199,207,190,184,234,154,61,49,96,225,190,62,7,70,62,186,77,248,190,187,99,33,62,246,11,246,190,226,175,137,61,157,158,223,190,10,16,229,189,141,213,38,189,172,83,37,189,182,44,79,190,72,140,46,190,194,81,34,190,189,199,9,190,144,162,182,190,45,209,193,190,198,162,137,190,187,100,148,190,121,2,65,190,235,31,148,190,192,177,23,190,248,224,53,190,77,158,146,189,15,183,67,190,17,25,86,189,1,52,26,190,203,73,168,188,192,4,238,189,213,34,34,61,173,78,78,188,235,84,137,190,100,234,46,61,4,202,86,190,165,45,142,61,230,4,45,190,244,251,254,61,152,250,185,190,205,200,64,62,36,98,6,191,198,225,204,188,244,222,216,189,181,225,48,187,221,239,128,190,150,6,126,189,60,247,158,190,2,154,168,189,241,14,112,60,125,62,170,61,205,201,11,190,165,164,7,61,221,12,151,189,186,187,206,188,73,217,226,61,136,131,196,61,212,156,60,59,44,244,65,60,139,141,153,189,193,116,122,190,48,155,64,189,16,149,166,189,160,165,59,190,106,222,241,60,244,224,134,62,130,230,83,62,120,123,32,190,73,131,107,190,178,213,229,189,161,244,85,190,97,169,238,189,144,75,252,189,5,135,151,189,49,178,228,189,110,136,241,60,240,223,12,190,145,152,32,188,193,144,37,190,5,167,190,188,96,143,233,61,59,81,170,190,185,255,72,61,140,187,201,190,206,111,152,60,89,249,221,190,155,169,16,189,168,166,188,190,176,59,221,189,97,79,179,190,73,20,26,189,118,108,164,190,103,210,54,190,222,90,166,60,78,154,70,189,117,144,87,190,60,217,109,190,4,57,168,189,251,6,134,189,43,219,167,61,205,6,25,188,43,81,22,62,56,215,208,61,142,34,91,62,230,91,255,61,146,62,205,61,184,146,93,189,80,80,234,189,49,150,41,189,195,242,199,189,70,205,23,61,211,21,204,189,252,196,33,190,14,248,92,190,196,177,238,189,63,87,219,189,45,67,156,61,141,94,173,61,54,29,1,62,129,90,124,62,241,69,187,61,58,235,35,62,149,15,65,62,159,60,140,62,254,241,142,62,178,13,164,62,150,33,110,62,33,229,7,62,185,140,155,188,8,61,155,60,64,195,187,189,250,94,3,189,151,198,79,190,92,229,89,62,234,118,54,62,255,149,85,62,188,122,117,62,160,108,74,61,234,120,204,61,18,49,21,190,80,251,45,188,162,180,7,190,177,51,165,190,151,26,161,60,56,164,1,62,194,136,133,62,191,69,23,62,208,97,110,190,85,222,142,186,89,22,76,189,35,105,103,62,19,125,30,190,205,231,156,61,121,115,56,61,229,181,98,62,242,91,164,62,220,130,37,62,31,129,127,189,254,124,91,61,17,109,7,62,95,152,124,62,104,6,201,62,34,55,139,62,175,119,135,190,187,153,209,61,194,134,167,190,1,22,249,61,224,157,204,190,5,221,254,61,190,222,221,189,154,120,55,62,226,144,205,61,214,29,59,62,148,190,80,62,193,197,74,61,30,198,100,190,161,248,113,190,163,148,64,190,16,36,79,190,199,245,95,190,224,213,210,189,136,216,128,190,109,226,36,190,102,73,0,190,203,72,45,190,129,120,13,190,226,204,15,190,72,169,52,190,167,37,22,190,165,249,99,190,191,244,246,189,72,197,63,190,233,124,56,190,158,64,72,190,71,3,152,189,233,42,45,190,45,5,20,190,89,51,18,190,72,51,150,189,126,84,227,189,127,246,227,189,44,213,5,190,58,3,195,189,93,224,50,190,229,12,229,189,24,179,229,189,91,11,211,189,41,208,71,190,7,183,117,189,3,149,17,190,110,163,33,190,13,169,2,190,63,1,84,189,155,200,28,190,239,144,130,189,27,14,139,189,73,14,40,190,179,39,17,190,61,211,139,189,249,105,188,189,249,187,119,189,102,245,206,189,140,185,203,189,110,108,214,189,7,237,213,189,14,47,136,189,73,213,150,189,199,129,87,189,18,159,187,189,218,197,180,189,226,60,156,188,48,19,5,190,13,80,154,188,63,58,213,189,180,231,2,190,102,49,177,188,174,100,7,189,30,252,4,190,143,142,171,189,189,194,66,189,99,154,41,189,3,239,100,189,225,66,222,189,124,242,48,189,97,222,227,188,244,254,127,189,225,98,69,189,46,83,19,187,19,40,226,189,240,192,128,189,33,118,166,58,233,43,8,189,140,72,148,189,122,23,47,189,50,172,98,188,71,144,10,189,48,18,26,189,137,97,23,190,14,218,171,189,10,106,56,189,236,247,196,59,235,201,188,189,196,123,78,189,137,151,167,189,224,160,189,59,187,43,187,57,205,145,213,189,230,119,26,188,180,33,127,187,103,42,68,189,249,100,197,186,200,39,36,189,1,164,22,190,94,133,20,188,61,70,121,189,254,184,253,188,194,249,84,60,56,107,112,188,146,145,179,58,84,254,181,59,225,150,207,189,35,22,1,190,80,198,248,186,123,245,209,189,234,120,204,185,84,201,128,188,26,223,7,190,164,142,142,189,12,64,163,188,100,92,209,189,146,234,155,189,162,97,49,61,14,18,98,189,51,49,221,60,221,67,66,60,102,46,32,190,138,57,136,188,56,50,143,60,87,64,161,189,51,23,56,59,99,123,109,61,113,147,33,190,194,191,136,188,58,148,97,189,217,179,55,190,253,159,195,189,169,193,180,60,128,186,225,189,81,134,42,60,88,201,167,189,195,102,0,190,158,40,73,61,63,169,54,61,20,117,230,189,217,96,129,61,85,108,204,188,68,250,61,190,12,120,89,61,99,125,3,189,222,33,53,190,181,192,158,188,168,198,235,189,238,178,127,190,24,180,144,188,30,111,114,189,128,12,77,190,184,148,211,189,142,230,136,189,78,239,98,189,18,193,56,61,163,121,64,189,57,155,14,186,97,224,185,60,182,160,55,189,76,170,182,60,22,20,134,188,203,100,184,188,68,167,231,60,107,14,144,60,170,13,206,189,19,14,125,61,74,155,170,188,51,167,139,189,169,218,238,60,102,135,152,189,9,139,202,189,80,109,48,61,251,177,137,189,170,69,4,189,48,103,118,61,122,222,13,61,147,227,14,189,170,184,145,61,34,109,99,188,187,11,20,188,160,252,93,61,126,171,245,188,77,73,6,190,79,87,247,60,120,154,204,60,8,144,33,60,125,36,101,61,176,144,57,189,227,197,2,61,141,14,8,61,79,119,30,187,231,82,28,61,234,176,130,61,72,225,58,61,210,84,207,60,122,253,9,61,172,0,31,61,58,146,75,61,41,178,150,61,117,177,233,60,70,148,118,61,20,94,2,188,239,146,184,60,36,241,50,61,144,249,128,186,68,78,95,61,211,136,153,60,7,125,105,61,14,131,121,61,101,27,120,61,78,236,33,60,206,168,121,60,170,69,164,61,110,77,186,60,94,16,145,61,218,3,141,61,148,23,89,61,40,10,244,60,10,72,187,61,232,220,45,189,248,79,119,61,148,191,123,61,243,86,157,61,114,222,127,61,254,155,183,61,159,2,32,61,134,226,142,61,98,249,243,61,116,94,131,61,111,72,195,61,8,174,146,61,142,90,193,61,44,100,142,61,172,253,93,61,163,91,47,61,62,150,190,61,80,54,229,60,201,33,194,61,154,35,203,61,207,19,207,61,9,222,240,61,216,17,71,61,251,176,190,61,223,168,245,61,140,104,251,61,230,33,83,61,55,22,212,61,238,148,174,61,14,79,47,188,161,186,25,62,49,205,116,61,62,34,166,60,181,81,221,61,26,168,140,60,46,0,13,60,91,12,222,61,19,125,190,60,6,244,130,189,59,253,160,60,162,9,148,61,184,120,248,188,33,88,69,62,193,224,154,61,61,186,145,61,134,114,98,62,3,180,141,61,74,181,15,189,71,227,64,62,147,58,1,62,23,72,16,61,223,55,62,62,218,83,50,61,110,79,208,189,91,39,46,189,52,19,204,61,74,153,84,59,104,206,122,188,184,115,225,188,202,112,60,61,195,157,11,61,170,128,59,189,225,149,196,61,224,19,235,59,123,50,191,189,203,75,62,61,108,233,81,189,84,87,126,189,80,80,170,61,84,226,58,189,15,128,8,190,98,19,89,61,30,254,26,189,186,243,196,60,75,62,6,62,31,158,165,188,0,115,237,189,181,50,1,62,122,199,9,190,223,165,20,189,202,252,227,61,171,117,226,189,85,221,35,190,34,23,188,61,68,24,191,189,161,101,61,190,103,96,100,60,248,112,169,189,93,111,43,190,152,221,83,189,46,3,46,190,179,39,49,190,126,116,234,187,101,82,3,190,234,60,90,190,230,119,90,189,114,137,163,189,150,208,29,190,142,118,124,190,48,16,4,189,119,187,222,189,62,8,81,190,213,122,15,190,107,72,76,190,164,170,145,190,165,162,49,60,151,142,153,189,51,83,42,190,227,26,191,189,116,124,20,62,237,182,11,61,238,181,32,189,56,220,231,61,193,111,227,61,209,89,38,61,228,46,2,189,67,60,50,62,111,44,40,190,58,147,6,62,46,112,25,62,181,78,220,60,36,182,219,61,162,153,55,62,64,221,64,61,156,105,34,62,166,125,211,61,110,133,144,189,144,130,87,62,182,247,9,62,152,80,193,61,214,86,12,62,189,229,42,62,55,53,176,61,154,94,130,61,118,224,44,62,39,50,35,62,217,152,247,61,195,15,30,62,165,161,22,62,89,138,36,62,65,71,235,61,102,21,246,61,13,113,76,62,111,74,57,62,209,2,68,62,33,176,50,62,229,212,46,62,1,249,34,62,180,147,17,62,132,242,110,62,239,145,109,62,12,201,25,62,65,103,210,61,116,209,64,62,73,15,99,62,234,60,106,62,116,121,131,62,170,183,86,62,43,105,37,62,91,6,132,62,115,189,125,62,162,67,128,62,119,104,40,190,69,242,21,185,66,10,110,62,183,150,201,60,152,24,203,59,150,208,93,190,207,220,203,190,187,128,183,189,240,51,78,190,44,155,249,189,203,77,156,190,169,74,27,61,135,249,114,61,79,2,123,62,120,242,121,62,245,160,136,62,253,218,58,62,107,131,163,62,83,93,80,62,254,43,179,62,142,90,129,62,147,166,201,62,189,252,142,62,181,51,228,62,213,32,132,62,240,78,198,62,239,172,77,62,160,255,30,189,166,182,4,62,213,207,27,188,25,141,156,61,40,185,195,188,151,1,231,188,243,227,239,189,103,126,21,190,35,16,63,190,254,158,88,189,186,73,12,189,250,38,173,189,81,21,179,189,181,110,195,189,210,25,232,190,75,174,50,190,238,90,186,190,18,190,23,190,46,56,171,190,168,86,79,190,224,159,98,190,243,171,57,190,35,75,6,190,123,77,79,189,25,112,214,189,255,205,235,61,48,100,69,62,117,3,141,62,2,100,104,60,188,233,70,62,137,234,29,62,82,101,104,62,114,24,172,61,203,20,99,62,9,252,65,62,253,131,40,62,236,223,5,62,170,16,47,62,77,214,136,189,7,238,128,61,160,109,53,190,168,166,20,190,244,140,125,190,164,225,4,190,48,101,64,190,120,98,150,190,147,228,121,190,159,118,176,190,191,239,79,190,242,149,112,190,190,222,149,190,29,57,34,190,122,25,133,61,48,184,230,188,59,53,23,62,38,30,176,61,12,35,221,61,17,167,19,59,101,254,145,61,227,140,225,60,216,43,172,60,109,2,76,189,237,74,139,190,232,21,95,190,50,87,134,189,76,55,9,60,9,112,26,190,210,52,72,190,174,44,81,188,232,103,26,190,24,68,116,62,113,226,11,62,20,95,149,62,106,133,233,61,143,138,79,62,49,97,212,61,95,94,16,62,46,169,26,61,252,194,131,190,6,128,226,190,85,46,164,190,57,181,163,190,42,58,250,190,118,137,26,191,64,106,163,190,105,138,240,190,187,68,117,60,227,255,206,189,244,82,209,61,50,201,136,61,203,15,156,189,73,216,55,189,27,72,151,61,0,58,28,62,255,231,144,61,231,25,187,189,101,57,137,188,23,244,222,60,212,209,145,61,249,157,198,61,236,192,121,189,33,34,21,190,159,202,233,61,116,209,240,61,171,203,145,190,56,101,238,188,223,137,129,190,49,211,150,189,183,236,80,190,44,182,201,189,44,131,234,189,218,198,159,58,217,176,102,190,66,147,68,188,122,83,113,190,53,181,172,61,158,206,37,62,253,105,3,62,117,172,210,60,89,165,244,61,162,181,130,190,248,28,144,190,122,29,201,190,130,55,196,189,151,174,32,61,185,194,27,190,241,46,159,190,172,58,203,189,157,156,137,190,101,85,4,61,36,40,174,190,4,27,87,60,108,149,176,190,140,246,56,189,245,241,64,190,30,253,135,62,204,69,44,190,230,93,117,186,151,56,242,57,98,16,152,62,71,0,135,62,195,15,190,62,244,81,22,190,48,42,201,189,205,234,197,190,36,154,144,190,254,72,145,189,115,215,130,190,234,37,150,62,9,109,129,62,228,16,209,62,77,135,198,62,59,138,195,190,26,196,183,190,187,95,237,190,21,145,161,190,132,185,165,190,134,85,132,190,53,7,128,62,175,206,145,61,183,125,207,190,183,8,220,190,134,1,11,190,252,166,128,190,148,79,63,62,40,124,118,61,110,22,239,61,20,62,91,189,23,128,206,190,140,160,97,190,175,10,212,190,175,234,172,188,231,112,213,190,189,141,77,61,184,174,240,190,115,242,162,189,75,144,161,190,108,122,96,62,164,222,139,190,110,194,13,62,126,167,129,62,14,221,156,62,186,17,54,62,249,77,177,62,22,104,87,62,134,174,84,62,44,159,165,190,72,194,158,61,114,197,69,190,232,77,69,61,200,122,234,61,255,230,149,62,134,231,5,190,36,38,104,61,146,176,47,190,32,211,178,190,154,122,189,190,252,80,9,191,174,73,159,190,235,167,199,190,175,123,171,62,117,62,188,62,132,214,179,62,145,152,224,62,70,208,4,63,254,153,169,62,118,198,223,62,59,142,167,62,166,71,163,62,23,98,157,62,59,195,212,188,95,184,83,190,75,30,191,62,207,159,166,62,5,109,242,62,208,100,199,62,230,4,245,62,27,187,244,62,137,98,170,62,77,132,29,62,56,48,89,62,150,152,231,62,6,102,37,62,137,178,55,188,145,100,86,62,201,119,169,60,34,170,176,189,157,102,81,62,55,252,198,190,237,216,8,62,175,67,53,190,52,161,9,62,142,31,90,190,143,54,150,190,3,68,169,190,25,175,89,190,155,198,118,190,170,45,173,190,228,187,100,190,21,200,156,190,28,236,141,190,113,175,108,190,55,81,147,190,251,234,106,190,110,48,116,190,132,14,106,190,195,155,133,190,55,80,16,190,73,242,124,190,195,98,132,190,61,130,11,190,59,169,127,190,241,69,179,190,235,84,25,190,237,153,69,190,126,29,144,190,65,17,43,190,156,168,133,190,33,3,73,190,85,76,53,190,225,39,78,190,243,226,84,190,34,113,239,189,176,113,77,190,106,160,89,190,20,36,38,190,158,65,19,190,169,249,122,190,163,5,168,189,59,114,68,190,116,93,136,190,198,111,202,189,232,131,85,190,22,22,164,190,238,119,232,189,24,33,28,190,57,208,99,190,75,146,135,189,35,105,55,190,238,204,84,190,7,153,4,190,57,98,45,190,182,246,30,190,112,120,161,189,232,219,66,190,105,229,30,190,62,203,179,189,69,70,23,190,89,106,45,190,1,108,16,190,141,66,2,190,10,46,54,190,197,143,1,190,8,86,101,190,139,83,29,190,92,204,207,189,10,131,66,190,233,157,234,189,78,209,209,189,99,181,217,189,146,204,26,190,183,94,211,189,137,236,19,190,108,208,215,189,159,228,46,190,201,229,15,190,200,179,11,190,58,176,44,190,2,240,79,190,233,157,10,190,119,130,13,190,110,167,237,189,115,46,229,189,42,145,20,190,127,160,44,190,226,171,189,189,127,105,1,190,170,184,97,190,166,9,187,189,95,11,90,190,109,59,61,190,112,36,208,189,45,92,70,190,233,237,15,190,217,93,160,189,153,215,49,190,184,2,74,190,92,85,118,189,131,165,74,190,120,182,119,190,236,104,188,189,42,200,31,190,154,92,132,190,57,157,228,189,105,197,119,190,3,182,67,190,139,79,129,189,91,206,133,190,153,160,118,190,223,54,211,189,158,240,98,190,167,205,120,190,1,251,40,189,198,139,101,190,235,83,110,190,21,114,37,190,41,122,80,190,198,196,150,190,82,15,1,190,167,145,86,190,89,54,155,190,201,200,89,189,207,249,129,190,228,18,151,190,146,203,31,190,194,104,142,190,152,134,169,190,188,144,174,189,98,189,153,190,31,133,75,190,84,56,194,189,62,93,133,190,63,201,45,190,202,167,7,190,110,249,88,190,200,151,48,190,71,57,40,190,211,217,105,190,65,41,250,189,9,81,254,189,187,94,130,190,141,236,10,190,35,78,167,189,127,18,135,190,114,165,30,190,233,184,90,190,137,207,157,190,84,226,218,189,1,220,172,189,171,119,120,190,141,179,169,189,67,202,175,189,39,17,129,190,0,228,132,189,146,3,22,190,251,234,74,190,64,132,216,189,152,107,65,190,155,199,65,190,6,72,180,189,69,189,224,189,33,87,74,190,50,116,204,189,205,88,52,189,153,188,137,190,207,17,217,189,8,60,176,188,193,230,108,190,124,242,112,189,99,154,41,189,206,0,103,190,199,73,225,188,241,128,178,189,1,50,36,190,249,246,110,189,106,104,163,189,219,137,34,190,180,33,223,189,169,192,137,189,24,147,46,190,165,46,89,189,22,220,143,188,119,105,51,190,14,160,95,188,37,206,74,189,131,191,31,190,73,245,221,189,164,198,132,187,172,60,97,190,105,173,168,189,216,240,116,60,8,3,95,190,67,174,84,188,103,44,26,188,120,127,252,189,72,81,39,189,63,145,39,189,175,121,245,189,65,184,194,189,130,196,118,189,61,183,240,189,219,25,134,189,199,130,66,59,198,106,211,189,200,8,232,189,229,185,190,188,68,163,11,190,210,28,25,190,45,123,82,189,86,100,244,189,121,88,40,190,192,36,21,188,161,15,214,189,156,164,121,189,68,25,170,189,37,90,146,189,198,248,144,189,43,249,24,189,37,32,166,189,99,151,24,190,52,104,104,189,255,117,142,189,2,99,221,189,110,167,141,189,254,213,99,189,41,95,240,189,164,139,205,188,144,75,188,189,55,167,66,190,136,215,117,189,79,118,147,189,179,121,44,190,127,77,214,187,211,106,8,189,29,34,30,190,163,172,95,189,218,255,128,189,171,36,2,190,15,208,221,189,198,51,104,189,154,233,46,190,162,154,210,189,66,177,149,188,133,238,2,190,80,142,194,189,222,90,102,189,228,74,253,189,181,197,21,190,112,9,192,188,235,83,30,190,11,183,12,190,61,152,84,189,43,133,160,189,225,69,191,189,165,48,111,188,245,213,213,189,214,56,11,190,166,71,83,189,33,118,166,189,184,4,16,190,167,231,189,189,204,69,188,189,163,206,220,189,187,70,203,188,120,96,16,190,14,164,59,190,99,179,131,189,32,121,231,189,129,118,71,190,197,118,247,184,16,118,202,189,41,6,72,190,0,29,230,188,46,170,69,189,24,10,40,190,215,79,191,189,192,63,101,189,138,227,48,190,36,98,234,189,29,174,213,189,112,94,92,190,207,186,70,189,134,59,7,190,162,210,120,190,109,115,35,190,56,190,118,189,210,224,54,190,72,252,10,190,73,47,138,189,129,10,7,190,188,177,160,189,213,207,27,189,134,27,0,190,50,57,53,188,51,24,131,189,108,233,209,189,24,205,10,189,18,247,216,188,222,61,224,189,33,58,4,190,58,234,104,188,117,0,228,189,116,67,67,190,174,42,251,188,181,21,11,190,4,3,168,189,195,44,52,60,91,36,205,189,255,205,59,190,94,102,216,58,151,172,202,189,163,35,153,189,27,129,248,188,65,215,126,189,186,21,2,189,145,14,79,189,99,98,115,189,179,177,82,189,187,99,49,60,36,153,85,189,46,201,1,190,79,92,14,60,52,186,67,189,1,107,21,190,29,28,44,61,37,148,158,189,49,152,191,189,13,197,93,61,137,178,119,189,243,171,185,189,78,212,82,60,174,13,149,188,69,101,163,189,117,117,7,189,171,63,194,58,126,53,7,189,128,239,182,188,147,170,109,188,139,56,157,187,133,10,142,188,100,64,118,189,215,248,204,188,215,47,216,60,14,216,85,187,184,89,188,186,94,241,212,60,95,126,39,189,193,59,153,189,96,176,155,60,113,174,225,60,90,103,252,188,204,121,70,188,97,109,12,61,181,84,222,59,151,82,151,59,101,84,153,60,31,106,91,60,111,132,5,189,132,103,194,188,114,110,19,61,69,101,195,59,111,160,64,188,58,60,4,60,90,100,59,189,4,228,203,60,164,228,85,60,120,151,139,60,251,173,93,61,209,207,84,188,80,195,55,61,159,203,20,61,12,62,205,60,186,18,65,61,253,105,35,60,112,94,92,61,241,16,198,60,116,37,2,61,186,47,103,61,107,15,251,188,119,106,174,60,110,21,4,61,252,198,87,61,67,85,76,61,22,223,16,61,115,190,184,61,255,150,0,61,235,139,132,61,162,40,144,61,155,174,39,61,58,36,181,60,158,153,96,61,36,125,186,61,199,17,43,61,203,162,176,61,236,194,143,61,83,174,144,61,242,63,121,61,0,111,161,61,253,163,111,61,208,155,138,60,49,36,167,61,181,254,22,55,233,38,177,61,58,36,117,61,24,237,145,61,86,240,219,61,56,218,113,61,31,243,193,61,137,239,196,61,197,84,186,61,29,33,67,61,123,19,227,61,251,202,227,61,235,195,250,61,127,46,186,61,17,24,107,61,86,185,208,61,122,55,86,61,184,3,245,60,125,203,156,61,13,82,176,61,47,162,237,187,232,190,252,61,69,15,252,60,79,120,169,61,57,213,10,62,51,253,210,61,169,77,28,60,141,240,246,61,158,179,133,61,225,98,197,188,104,175,158,61,92,175,233,60,89,167,74,188,65,214,3,62,30,165,146,60,239,226,125,187,86,13,34,62,58,91,64,61,119,75,242,60,217,123,209,61,109,230,16,187,75,230,24,61,132,156,183,61,85,20,175,188,175,176,224,187,29,58,13,62,65,13,223,60,92,0,90,189,232,49,202,61,244,192,71,188,207,186,70,189,143,250,171,61,43,21,20,61,162,10,127,189,210,140,69,61,222,201,39,188,47,49,86,189,117,142,225,61,28,206,252,59,133,9,195,189,186,221,139,61,218,145,106,188,40,13,213,189,185,226,130,61,119,20,103,189,52,18,129,189,114,53,114,61,34,253,54,189,70,206,194,188,59,227,251,60,73,244,178,60,213,206,176,189,17,143,196,60,205,171,58,189,134,31,156,189,24,152,85,61,15,11,117,189,24,153,224,189,219,106,86,60,216,71,167,188,77,190,249,189,146,202,148,60,186,44,198,189,193,198,181,189,21,114,165,60,78,156,156,189,23,17,69,189,112,38,166,60,38,115,172,189,176,201,10,190,187,38,36,61,17,253,90,189,245,213,37,190,235,200,145,188,93,22,211,189,35,244,115,189,116,9,135,188,131,164,143,189,145,42,138,188,92,228,158,59,112,92,230,189,154,64,145,188,208,126,36,61,186,74,151,189,29,142,174,187,110,79,16,59,34,254,193,189,179,209,57,61,217,34,105,189,94,18,167,189,152,110,146,60,84,195,254,188,231,27,17,190,224,128,22,60,219,137,210,189,8,61,251,189,100,64,246,60,247,202,124,189,74,153,20,190,103,10,157,61,68,191,150,189,87,179,78,189,244,51,149,61,252,112,240,189,95,153,71,190,242,64,36,61,130,174,61,190,174,211,8,190,136,42,60,61,167,4,36,190,207,101,106,189,101,0,104,61,210,197,54,190,242,152,49,190,121,201,255,187,200,182,76,190,101,200,81,190,175,233,65,61,59,254,27,190,131,164,127,190,115,243,13,61,160,23,62,190,15,124,108,190,100,202,7,187,114,250,250,189,192,95,92,190,71,33,201,188,96,145,127,190,68,191,86,190,15,40,27,60,90,243,35,190,132,241,131,190,58,231,39,189,8,229,93,190,20,38,148,190,201,172,222,60,200,210,103,190,107,100,23,190,110,77,186,188,86,213,147,190,63,87,139,190,39,134,100,188,122,109,134,190,78,185,114,190,185,108,148,61,7,207,156,190,228,218,64,190,220,187,6,189,241,242,132,190,203,14,177,190,14,189,197,60,180,204,138,190,55,111,12,190,170,126,37,61,11,38,78,190,23,213,146,190,65,101,220,61,229,97,113,190,72,81,39,190,11,39,233,61,229,211,35,190,170,210,86,190,168,169,229,61,248,165,134,190,64,105,104,189,19,128,191,61,145,240,141,190,45,206,24,189,54,35,131,60,204,67,150,190,138,145,37,189,150,6,126,189,64,20,92,190,200,152,187,60,3,125,98,61,189,253,129,190,87,236,111,61,193,85,30,185,11,156,124,190,41,151,198,60,29,145,111,189,176,61,19,190,182,189,221,59,28,96,102,60,29,145,63,190,126,56,72,61,133,235,17,189,245,20,73,190,210,140,229,61,97,54,1,61,32,126,254,189,14,136,176,61,195,100,170,188,107,71,1,190,179,239,138,60,219,19,196,61,146,118,163,189,181,167,164,61,57,13,81,61,83,122,102,189,212,96,154,61,182,133,231,188,9,197,246,189,19,15,24,62,8,230,232,60,203,161,37,190,34,113,207,61,70,68,241,61,159,203,84,187,243,201,170,61,131,195,139,188,237,74,11,189,136,246,17,62,122,140,242,59,85,21,26,189,107,239,211,60,174,73,183,61,2,157,169,189,135,220,60,62,119,246,149,61,191,73,211,59,251,5,43,62,90,246,164,61,118,166,16,61,129,122,19,62,21,229,82,59,23,45,192,188,106,134,180,61,57,68,28,62,162,179,204,59,68,107,197,188,105,81,159,61,228,103,35,61,76,223,107,61,75,229,45,189,141,65,167,188,151,255,16,61,222,115,192,189,101,141,154,61,3,64,85,61,115,19,21,62,159,204,159,61,61,39,61,62,212,156,188,61,123,189,219,61,237,240,23,62,254,98,182,60,140,17,137,61,82,101,88,189,88,87,133,61,115,17,191,61,76,252,241,61,26,105,25,62,213,121,244,61,157,103,12,62,136,217,203,61,13,251,13,62,118,164,154,61,150,236,248,61,156,51,50,62,147,200,158,61,200,10,158,61,179,209,41,62,146,174,25,62,10,160,8,62,68,111,49,62,215,160,31,62,239,56,69,61,225,209,38,62,44,102,196,61,129,5,48,62,19,186,91,62,211,49,231,61,175,180,236,61,75,171,81,62,13,228,217,61,205,115,4,61,62,37,55,62,111,244,81,62,74,7,235,61,156,168,53,62,103,100,144,61,31,189,97,188,72,108,119,62,87,237,42,62,159,88,135,61,131,221,96,62,81,245,59,62,205,119,48,62,57,71,253,61,53,241,46,62,172,58,43,62,192,90,53,62,52,246,117,62,229,212,62,62,250,67,139,62,199,127,97,62,72,25,1,62,244,254,191,61,212,128,113,62,169,220,36,62,255,231,16,62,129,146,66,62,157,47,118,62,37,3,64,61,36,10,45,62,93,251,66,62,226,89,194,61,189,54,219,61,160,164,112,62,124,101,222,61,159,0,138,62,18,106,134,62,91,92,227,188,194,250,111,62,231,197,9,62,186,190,135,62,1,251,136,62,103,209,75,62,194,79,76,62,104,64,149,62,126,196,135,62,90,72,136,62,246,92,86,62,145,99,179,62,6,242,164,62,215,136,176,62,80,169,138,62,42,199,204,62,135,51,135,62,148,18,226,61,8,62,142,62,251,118,2,62,133,235,17,189,115,73,53,190,150,38,85,62,164,222,243,61,222,2,73,61,7,64,156,189,68,53,21,62,106,189,63,62,54,147,47,61,183,37,2,190,177,109,241,61,1,108,192,188,93,252,13,190,1,138,145,190,205,147,139,61,129,123,254,61,212,44,208,60,145,184,199,59,224,244,142,189,86,125,46,60,18,46,52,190,91,66,62,190,35,164,14,190,72,169,68,189,201,229,31,190,238,204,4,190,36,96,36,190,30,79,139,61,179,121,76,62,92,28,133,62,143,29,132,62,133,208,113,62,23,243,187,62,188,3,156,62,54,231,128,62,196,152,156,62,134,227,201,62,143,169,195,62,38,172,229,62,172,196,172,62,190,133,165,62,101,227,217,62,66,206,123,60,87,149,253,61,194,76,219,188,205,201,171,61,171,180,229,189,142,176,200,189,220,43,99,190,182,46,37,190,123,219,76,189,111,46,190,189,121,30,92,190,238,7,204,190,86,153,233,189,149,44,119,190,196,66,13,62,56,47,14,62,141,36,1,61,175,151,134,61,94,190,85,62,167,150,173,61,147,166,33,62,210,169,107,61,238,124,255,61,126,84,67,60,48,74,16,189,63,26,30,190,113,28,216,189,235,53,149,190,224,128,150,189,117,203,78,190,126,144,101,190,171,236,139,190,44,13,44,190,107,16,118,190,250,13,139,190,10,245,196,190,193,142,255,189,106,133,105,60,10,244,137,59,213,34,226,189,223,26,152,61,27,213,105,188,88,83,89,61,232,163,140,189,77,133,184,189,220,127,20,190,222,62,155,62,234,94,87,62,205,174,211,62,217,67,139,62,31,188,182,62,119,46,108,62,50,31,16,189,130,30,234,188,64,194,240,189,44,188,235,61,225,11,35,190,81,160,95,62,200,179,107,190,246,12,49,62,231,85,93,190,235,173,225,189,114,111,158,62,109,227,207,61,24,64,128,62,49,91,242,61,144,46,150,62,124,213,26,62,23,156,193,188,23,131,7,61,21,25,157,61,106,133,233,61,208,37,252,61,40,158,179,61,111,216,118,189,125,148,1,62,234,34,101,190,236,109,179,188,113,203,119,190,72,251,167,190,72,136,82,62,167,121,23,62,77,50,178,189,135,77,132,61,149,102,147,190,145,123,146,190,1,194,55,190,145,153,179,190,123,215,96,190,104,120,51,61,49,122,94,190,118,113,123,62,250,207,146,190,21,83,57,190,133,205,48,62,81,165,230,61,125,231,215,189,189,25,53,62,11,96,202,59,58,232,82,189,254,100,204,61,193,141,52,62,80,25,63,190,99,69,141,189,60,164,40,62,92,117,61,62,169,22,5,63,159,145,192,62,237,157,5,63,152,162,8,63,53,94,242,62,154,10,225,62,107,96,91,62,222,85,79,62,111,71,20,63,144,22,239,62,149,238,158,62,252,199,138,62,125,208,131,62,5,106,113,61,110,21,196,60,249,135,45,190,98,162,137,190,212,40,132,189,196,92,50,190,56,158,79,185,97,108,137,190,95,40,112,190,187,209,151,190,69,18,125,62,50,119,237,61,115,218,147,189,28,122,155,190,122,169,24,62,220,13,178,190,188,65,52,188,110,51,101,190,187,70,91,190,149,211,142,190,179,123,234,190,131,192,10,62,110,48,116,62,38,30,160,62,61,126,175,62,195,243,146,61,19,239,0,190,222,204,248,62,243,86,133,62,89,191,25,61,228,21,56,62,197,113,200,62,91,180,32,62,135,109,203,62,78,9,248,62,192,4,158,190,105,81,175,190,225,8,138,190,47,137,3,190,219,134,177,189,176,169,51,189,99,156,215,62,64,165,90,62,62,202,168,61,132,186,72,61,194,246,179,189,77,215,115,62,43,132,173,62,63,30,42,62,231,254,42,190,177,162,22,62,38,58,43,190,0,145,150,190,112,181,22,63,85,23,168,62,150,62,84,62,198,194,144,60,203,14,17,190,56,17,149,62,251,58,16,190,1,167,191,62,190,217,230,60,8,32,165,62,229,95,107,190,86,244,167,62,167,205,120,189,200,150,133,190,204,94,54,188,75,91,124,62,190,47,110,189,239,27,159,62,204,152,2,190,8,232,62,190,137,155,3,190,234,117,171,190,54,91,145,190,98,48,159,61,194,105,1,189,255,91,57,62,241,157,168,190,104,121,222,189,175,234,92,190,241,18,220,61,157,243,51,62,28,126,167,62,89,248,130,62,135,77,52,62,77,190,105,62,26,49,203,62,201,231,189,190,224,133,61,190,166,212,181,190,175,206,153,190,162,152,124,61,84,112,120,62,84,254,213,61,133,177,157,62,203,217,163,190,56,158,111,190,39,105,158,61,112,35,213,62,37,207,173,190,32,178,208,190,50,203,158,188,15,70,92,190,57,68,44,62,112,237,4,189,215,105,36,189,249,159,204,62,72,223,140,190,202,164,6,60,173,76,184,189,232,159,48,190,187,69,80,190,81,247,193,189,186,249,54,190,233,181,9,190,151,1,103,189,109,30,7,190,63,53,30,190,246,96,82,189,156,54,3,190,110,80,75,190,36,185,124,189,7,66,18,190,187,212,128,190,125,8,42,189,23,211,236,189,20,237,106,190,41,175,21,189,64,47,220,189,174,71,49,190,255,230,197,188,70,37,181,189,32,11,81,190,104,121,30,189,154,178,211,189,177,219,7,190,153,72,105,189,42,142,3,190,179,92,214,189,153,186,171,188,116,65,157,189,163,29,39,190,160,52,84,188,185,52,158,189,92,119,3,190,169,75,6,189,1,191,198,189,197,113,192,189,142,60,16,189,60,133,92,189,204,64,229,189,28,235,98,188,184,63,23,189,0,172,14,190,241,101,162,187,244,78,133,189,199,160,179,189,81,216,133,189,172,86,134,189,78,236,161,189,105,141,193,188,237,210,166,189,148,251,93,189,166,237,223,188,3,92,16,189,105,85,139,189,90,158,135,60,183,209,64,189,104,93,3,190,155,146,172,60,142,149,24,189,254,127,188,189,148,136,112,60,232,78,48,189,187,127,108,189,57,38,11,188,56,106,5,188,46,228,209,189,238,237,22,187,94,17,124,189,213,5,188,188,90,155,198,187,70,238,105,188,174,214,9,189,76,226,172,187,37,65,56,60,93,137,128,189,188,207,49,61,101,137,206,187,224,132,130,189,38,252,18,61,37,177,36,188,42,29,236,189,146,231,250,60,253,45,1,189,252,223,145,188,221,12,183,60,168,24,231,60,180,113,4,189,238,95,217,60,45,147,225,60,218,172,186,189,85,135,92,187,101,85,4,188,6,130,128,60,55,25,213,188,123,77,143,60,5,168,41,188,86,242,113,61,59,58,46,60,56,190,246,187,49,97,52,61,21,31,159,188,146,120,249,60,229,184,19,189,7,37,12,189,210,54,254,187,143,52,184,60,146,65,46,61,160,79,228,60,18,189,76,189,177,196,131,188,206,82,178,60,168,227,177,188,131,104,173,60,165,77,85,61,221,8,139,187,54,202,122,189,72,109,226,60,40,15,11,189,119,157,141,188,93,106,132,61,26,79,132,60,37,148,62,58,190,134,128,61,56,245,129,189,39,192,48,189,153,69,104,61,41,174,138,189,157,188,200,59,14,76,110,61,29,118,31,189,17,167,83,61,89,248,250,60,240,137,149,189,180,4,153,189,141,41,216,60,216,102,35,189,187,71,214,189,99,68,34,61,223,222,149,189,105,200,152,189,203,19,168,61,192,123,135,189,151,168,222,188,173,166,203,61,40,241,153,189,248,28,248,189,59,84,147,61,172,227,248,188,162,155,189,189,86,129,186,61,76,24,173,189,207,215,12,190,80,139,193,60,0,173,121,189,163,86,248,189,219,21,122,188,67,83,246,188,70,38,192,189,228,104,14,188,216,45,130,189,175,148,133,189,119,132,211,188,140,75,85,189,166,213,240,189,116,124,116,189,11,180,187,189,28,35,41,190,193,170,58,189,183,179,143,189,40,130,248,189,51,222,6,62,77,244,121,189,192,34,191,187,19,10,81,189,195,102,0,60,4,61,84,189,199,186,152,61,71,173,144,189,143,226,92,189,1,22,25,62,209,61,107,188,12,144,136,189,157,15,15,62,113,84,110,189,94,73,242,60,106,78,190,61,138,116,191,188,204,70,231,59,3,94,230,61,231,112,109,189,181,169,186,60,106,251,23,62,15,42,241,60,248,198,144,188,159,172,248,61,18,134,129,188,99,151,104,61,163,149,187,61,71,113,142,59,74,41,104,61,7,40,13,62,191,70,146,187,61,124,25,59,231,109,60,62,135,249,242,60,194,250,63,61,128,70,169,61,206,85,115,61,78,43,133,58,204,65,176,61,117,91,98,61,223,226,225,60,5,194,30,62,199,161,126,61,199,187,131,61,53,96,240,61,74,37,188,60,4,231,204,61,48,41,158,61,60,49,43,61,123,79,197,61,216,130,46,62,181,220,89,61,64,195,251,61,209,201,242,61,146,4,193,61,244,109,193,61,143,141,160,61,0,197,168,61,212,214,8,61,191,72,40,61,144,73,198,61,112,124,237,61,247,4,25,62,211,220,138,61,248,139,249,61,113,141,207,60,60,248,9,188,161,163,213,61,175,91,4,61,250,14,254,60,82,243,149,61,202,135,160,187,230,61,174,61,64,21,119,61,57,182,30,188,41,205,230,60,26,252,189,61,87,178,99,189,228,161,143,61,60,102,32,61,214,255,121,189,183,155,32,189,203,131,148,61,180,145,235,188,104,204,4,62,246,70,205,61,250,128,64,189,185,227,29,62,199,101,220,61,49,180,186,60,77,15,74,189,138,227,192,61,245,48,180,61,187,236,87,188,217,150,1,62,244,25,0,62,48,128,112,189,243,198,201,61,220,129,26,62,128,100,186,188,207,220,163,61,204,182,67,62,149,97,92,60,17,139,40,62,92,117,29,62,46,58,153,61,42,144,57,62,187,157,221,61,142,7,187,61,156,79,45,62,199,128,44,62,255,202,10,61,150,63,31,62,248,223,90,62,166,152,3,189,20,177,104,62,22,19,11,62,137,98,114,189,24,9,45,62,208,155,106,62,141,236,10,61,95,68,107,62,45,153,99,62,171,95,169,61,101,83,238,61,248,22,102,62,125,205,2,62,70,35,63,62,201,227,89,62,184,172,66,61,125,232,130,61,128,15,94,62,18,77,32,187,15,212,233,61,209,205,134,62,178,76,159,189,210,1,169,61,146,176,127,62,130,55,36,60,150,203,198,60,253,132,131,62,194,221,89,61,56,49,228,61,171,237,158,62,254,99,161,189,249,158,145,59,180,116,101,62,248,80,98,189,186,102,114,189,21,31,95,62,59,225,133,189,135,26,5,60,15,180,170,62,116,8,156,189,90,70,202,189,112,239,146,62,19,70,147,189,166,42,237,189,163,200,74,62,176,227,127,189,221,11,60,62,224,133,189,62,139,194,46,189,227,170,130,62,60,131,134,62,116,151,68,60,47,192,94,62,10,247,162,62,48,159,44,189,150,232,164,62,50,28,167,62,134,173,185,61,105,198,82,62,238,237,150,62,255,117,110,61,41,89,150,62,115,76,142,62,65,73,33,62,86,212,144,62,31,215,150,62,2,44,242,61,182,162,133,62,69,46,24,62,143,167,133,61,90,43,170,62,33,230,210,62,210,168,16,62,226,88,231,62,215,166,161,62,220,155,223,58,73,160,233,62,9,22,183,62,244,222,88,189,231,142,182,62,144,244,233,62,231,166,125,62,165,21,135,62,209,64,28,62,13,27,157,62,234,177,213,62,15,97,132,62,222,86,42,62,167,205,24,62,30,168,243,61,56,105,194,62,146,151,149,62,100,59,15,62,68,164,38,60,240,249,97,189,40,182,50,190,94,156,248,59,163,118,191,187,28,179,44,61,235,196,229,188,222,119,140,188,206,165,120,189,38,168,97,60,34,23,28,189,247,61,42,189,213,233,160,189,109,140,157,189,26,106,244,189,185,82,79,60,168,58,52,62,201,174,116,61,68,162,32,62,176,227,47,62,174,102,109,62,144,136,233,61,43,219,119,62,79,8,45,62,157,242,144,62,19,184,21,62,139,193,203,62,198,110,127,62,122,110,137,62,32,93,12,62,148,52,63,62,149,124,108,189,176,228,10,190,133,151,224,189,13,52,255,189,237,242,173,188,158,96,255,188,80,54,101,188,154,11,188,189,70,7,36,189,81,51,228,189,17,223,137,188,55,194,98,61,108,207,108,61,43,166,146,61,27,129,120,61,108,93,234,61,232,130,218,61,214,55,16,62,226,177,191,61,66,10,190,61,69,44,34,61,213,66,201,59,208,95,136,189,62,93,189,189,46,26,210,189,61,126,47,190,38,53,116,189,101,140,79,189,63,30,42,62,167,32,15,62,195,46,90,62,218,86,67,62,248,54,125,61,108,66,26,61,14,191,11,62,105,1,186,61,138,28,162,188,5,110,93,60,140,132,182,60,189,194,162,61,159,114,92,62,228,133,236,62,243,115,83,62,147,30,174,62,8,176,72,60,50,87,134,189,22,19,187,61,176,115,67,62,12,203,159,60,60,164,24,61,230,172,79,189,72,165,88,188,14,215,106,189,223,25,237,60,16,65,149,62,27,42,190,62,55,0,91,189,20,92,172,61,241,216,207,60,162,40,192,62,201,60,138,62,116,7,17,63,39,23,195,189,61,100,74,188,17,195,78,61,159,0,90,62,232,75,207,61,197,3,74,61,21,84,148,61,211,20,145,62,2,69,172,189,175,39,26,190,106,246,0,189,111,102,20,62,98,78,80,60,181,137,131,62,84,27,28,188,7,120,210,61,64,22,34,189,223,226,81,62,168,87,202,189,135,111,97,61,228,186,169,60,226,119,3,62,19,156,58,189,105,167,54,190,211,160,168,189,42,56,12,62,134,172,110,189,171,234,149,62,18,135,172,61,5,79,1,63,99,127,249,61,17,28,167,62,92,62,210,189,167,2,142,189,88,202,146,61,142,115,155,59,186,45,241,189,121,120,79,190,22,252,95,252,184,251,77,251,127,253,93,252,164,253,63,252,245,252,95,253,189,252,236,252,96,254,104,253,54,254,2,253,116,253,247,253,106,253,17,254,1,252,3,254,1,252,84,254,68,254,216,253,144,254,63,254,33,254,45,255,226,251,121,252,196,254,7,255,199,253,177,253,199,253,237,254,227,253,65,255,52,253,68,255,182,252,248,254,179,254,8,255,194,254,28,255,237,254,1,0,201,253,28,255,141,255,35,255,18,255,138,254,59,255,5,254,34,255,189,253,254,254,80,254,195,255,12,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+887960);
/* memory initializer */ allocate([167,254,2,0,174,254,39,0,41,255,87,255,198,255,0,0,200,255,250,255,53,255,125,255,1,0,70,255,251,255,45,255,6,0,132,254,11,0,94,254,140,255,131,0,122,255,113,0,89,0,252,255,71,0,254,255,237,255,64,255,6,1,24,0,189,0,151,0,123,255,147,255,186,0,103,255,166,0,37,255,37,0,139,0,193,0,171,0,81,1,124,0,158,0,195,255,141,0,226,0,243,255,190,0,231,0,34,0,98,1,109,0,60,1,201,0,244,0,164,0,74,1,171,255,134,1,172,255,254,0,71,1,1,1,79,1,235,1,147,0,220,1,105,0,54,0,77,0,181,1,114,1,165,1,58,1,193,1,86,1,73,1,126,0,161,2,36,1,59,2,132,1,243,0,193,0,141,2,64,1,109,2,24,1,194,0,124,1,5,2,69,2,45,0,67,1,111,0,166,1,233,1,139,1,222,2,22,2,110,2,34,2,230,1,246,1,62,1,60,2,189,0,38,2,129,1,166,1,99,255,153,0,131,255,126,1,59,255,130,1,249,254,78,1,228,0,185,2,68,255,1,0,51,0,41,1,5,254,213,0,136,254,141,1,232,255,255,0,221,253,89,0,10,254,162,255,131,1,179,0,148,253,68,0,84,253,112,0,126,253,162,254,252,254,172,0,74,254,188,254,8,1,136,2,60,252,252,255,159,251,7,0,122,255,134,0,147,251,206,254,143,0,96,0,92,254,15,254,59,251,162,254,9,250,83,253,95,255,72,0,105,3,179,2,220,2,27,1,153,3,97,1,78,1,219,1,71,4,53,3,96,3,12,2,75,3,241,1,202,2,199,2,20,3,238,2,52,4,202,2,180,4,241,2,191,248,111,249,191,248,37,249,248,247,130,251,170,247,138,249,173,249,181,251,88,249,149,251,191,250,184,249,177,250,154,249,198,250,243,250,211,250,15,251,128,249,143,249,49,250,173,252,190,250,216,248,123,250,116,247,254,250,87,253,7,249,143,249,58,252,198,251,97,251,116,249,226,251,207,251,138,251,122,251,73,251,24,253,6,251,27,252,90,252,153,250,97,252,120,250,14,252,231,250,241,252,69,252,231,251,124,252,31,252,207,252,31,253,201,252,52,252,91,251,30,253,186,251,30,253,126,251,240,252,223,252,214,252,238,252,132,252,248,253,24,252,206,252,124,253,59,252,191,253,142,252,227,253,74,253,97,253,107,252,173,253,126,253,122,253,153,253,68,252,147,253,99,252,253,253,41,253,29,254,209,252,27,254,184,252,190,253,72,254,55,253,190,253,187,254,111,253,98,253,126,254,198,253,71,254,102,253,254,253,237,252,120,254,239,253,246,253,59,254,25,254,89,254,152,253,183,253,151,253,99,255,106,253,244,254,88,253,164,254,190,254,189,254,136,253,68,254,208,254,82,254,180,254,54,254,235,254,44,254,109,253,231,252,193,254,132,253,29,255,214,253,139,254,165,254,178,254,46,255,56,254,64,255,238,253,14,255,40,255,58,255,146,254,142,254,174,254,95,255,103,254,20,253,149,255,132,254,218,254,125,253,33,255,103,253,22,255,27,253,115,255,16,254,126,255,2,254,117,255,185,254,84,255,207,254,206,254,188,253,92,255,249,254,250,254,84,255,189,255,110,254,31,0,146,254,246,255,76,254,170,255,241,253,71,0,135,254,234,255,159,253,244,255,90,253,189,255,193,254,63,0,65,255,35,0,75,255,217,255,14,255,126,0,89,255,116,255,224,253,155,0,215,254,174,0,215,254,38,0,248,255,117,0,132,254,197,0,60,254,240,0,246,253,223,0,153,255,110,0,69,255,87,0,101,255,169,0,209,255,157,0,26,0,173,255,156,255,128,0,80,0,209,0,194,255,6,0,7,0,22,0,5,0,62,1,236,255,248,0,211,255,56,255,193,255,156,0,187,255,250,0,73,255,113,1,130,255,143,255,180,255,114,255,134,255,192,255,2,255,225,255,35,0,79,255,185,255,249,255,171,0,93,0,27,0,108,0,212,0,182,254,47,255,133,255,186,255,233,254,95,0,160,255,20,0,68,255,195,255,198,254,87,0,212,254,178,255,158,254,122,255,11,0,122,0,116,255,122,0,237,254,152,0,219,254,140,0,174,255,138,0,191,254,145,255,32,254,100,255,153,254,76,0,2,255,216,255,133,253,160,255,246,253,79,0,5,254,8,0,244,254,47,1,229,253,68,0,66,254,61,0,246,253,50,1,111,0,189,0,77,254,122,0,133,254,166,0,197,253,114,254,136,253,182,255,21,253,161,255,57,254,194,0,72,252,83,0,226,252,192,0,13,253,192,0,243,252,94,255,149,253,234,0,105,253,215,254,24,254,147,255,60,252,124,255,186,252,188,255,181,252,58,0,168,251,170,255,219,252,213,254,80,252,3,255,246,252,206,255,59,252,219,253,160,254,158,255,32,252,169,254,163,251,197,254,163,251,205,254,125,251,138,254,131,253,26,255,114,251,213,255,237,250,156,255,99,252,119,254,6,251,168,253,79,253,126,255,57,250,200,254,215,250,2,255,72,250,70,254,244,250,155,253,19,251,9,254,35,250,144,254,214,250,26,0,104,250,190,255,49,249,95,255,148,249,45,254,32,249,220,253,143,250,200,253,236,249,153,252,41,250,246,251,149,250,197,253,131,248,240,253,9,249,133,255,151,248,25,255,250,247,189,254,252,247,118,252,72,248,201,253,131,248,148,253,1,248,35,252,203,251,142,254,17,248,64,253,205,246,19,253,76,245,191,251,139,248,159,0,36,248,248,0,142,253,133,255,221,246,62,252,99,253,104,254,157,250,106,251,60,254,148,254,236,251,33,253,124,255,183,0,172,249,16,253,221,253,205,254,247,252,19,251,158,255,41,0,144,252,189,251,255,254,97,0,190,249,215,248,31,0,230,255,124,253,207,253,76,255,222,253,127,254,185,251,102,254,222,252,98,254,197,252,55,254,54,252,22,254,171,251,41,255,108,252,112,255,87,252,19,254,11,251,251,253,29,250,181,0,101,0,180,254,135,252,188,252,87,252,209,253,83,254,139,253,221,253,73,255,175,254,223,253,174,255,6,255,226,254,5,0,124,255,164,254,4,255,219,254,40,254,98,255,100,0,227,255,197,0,20,255,88,254,163,252,43,255,116,255,249,255,85,254,69,254,187,0,159,255,84,253,32,253,219,254,2,1,144,254,104,255,106,255,136,1,159,253,175,0,114,255,43,1,118,255,152,0,137,255,73,1,26,254,204,255,37,1,198,0,73,255,117,0,175,0,75,1,198,255,238,254,231,0,44,1,224,254,74,1,207,254,116,1,145,255,153,1,247,255,167,1,83,0,0,1,67,0,111,1,237,255,248,0,91,0,113,0,221,255,150,1,65,255,154,0,238,0,40,1,5,0,197,0,141,0,221,0,57,1,198,0,211,0,165,1,244,0,78,1,88,0,170,1,13,255,198,1,202,0,40,2,251,255,147,1,35,1,185,0,219,0,45,1,251,0,138,0,128,0,69,0,197,0,32,1,116,255,195,255,188,0,105,1,197,0,86,2,186,1,17,1,34,1,143,0,216,1,226,1,157,0,114,1,159,1,65,1,116,1,129,1,146,1,40,2,155,0,24,0,38,2,7,1,245,255,21,0,104,1,227,0,147,0,2,255,168,1,97,0,110,1,243,255,119,1,141,0,193,1,232,0,140,1,251,1,218,1,16,1,189,2,68,1,106,1,209,255,75,2,148,0,31,2,69,0,144,1,205,255,49,2,59,0,220,0,246,255,96,1,147,0,206,0,211,0,141,2,185,0,51,2,41,1,53,2,28,1,82,2,121,0,254,2,192,0,142,1,118,0,130,2,178,1,233,0,8,1,225,1,211,1,129,0,91,255,187,2,239,0,90,0,26,0,86,1,218,1,201,255,27,0,132,1,94,0,84,255,0,0,213,2,123,1,196,255,81,1,114,1,209,1,95,0,63,1,38,3,83,2,78,0,4,1,241,1,83,3,210,0,48,2,202,1,62,2,48,254,202,0,241,1,113,2,54,255,152,0,48,0,200,2,236,255,54,2,100,0,203,2,199,1,212,1,155,1,93,2,63,1,134,2,195,0,103,2,145,1,26,2,168,2,227,2,201,0,155,2,178,1,186,3,198,1,169,1,134,2,235,1,94,2,169,2,160,1,252,1,241,1,54,3,170,1,47,3,148,2,135,2,116,2,204,2,185,2,210,1,106,2,201,1,173,2,204,1,109,1,53,1,209,2,55,2,68,3,89,2,97,2,44,1,57,3,203,1,175,3,175,2,169,2,21,2,147,3,86,2,79,2,243,0,108,3,195,1,106,3,164,1,18,3,61,1,220,2,220,0,154,3,61,1,84,4,111,1,19,2,210,1,4,4,137,2,29,4,103,2,10,4,41,2,61,3,90,2,253,3,31,3,159,3,35,3,110,3,251,2,31,3,240,1,93,5,5,3,73,2,2,3,35,3,162,3,75,4,25,3,198,4,94,3,185,4,127,3,1,4,215,2,4,3,77,3,148,4,91,4,99,3,253,3,62,3,245,3,73,3,142,3,250,1,191,2,215,4,53,4,108,2,51,3,172,4,59,4,131,4,57,4,118,4,139,3,11,6,97,4,29,5,136,2,63,5,100,2,204,5,220,3,199,5,169,3,217,3,48,5,187,3,61,5,173,1,142,3,73,3,58,5,52,2,155,4,156,1,132,4,147,5,40,5,154,5,50,5,128,2,248,2,190,6,130,5,190,0,43,2,49,4,237,3,170,1,1,1,71,3,212,3,235,0,231,0,240,5,143,4,109,0,37,1,246,3,33,6,49,1,142,0,124,4,27,2,221,254,148,255,189,4,204,3,22,0,40,255,155,2,60,3,30,254,182,1,197,1,151,5,187,253,90,254,21,3,131,1,154,254,58,254,174,0,12,3,220,255,140,254,134,1,122,255,139,253,160,0,206,254,239,2,22,251,181,254,177,0,10,2,8,255,62,2,5,255,127,2,237,253,151,1,172,253,138,1,93,254,21,3,151,253,33,3,38,252,143,1,167,252,215,2,249,255,6,2,65,253,54,1,137,251,232,255,22,252,31,1,64,252,107,1,237,250,56,1,2,250,245,0,235,249,49,1,28,0,153,0,165,252,81,255,223,255,76,1,138,250,102,255,212,0,154,1,175,253,59,255,188,251,64,253,120,252,191,255,26,1,111,1,106,252,82,253,89,1,93,0,254,254,155,254,184,2,132,2,75,253,228,255,192,1,237,1,239,254,193,0,15,2,34,2,13,255,255,253,128,1,120,255,17,1,159,254,0,2,114,255,25,2,58,255,173,3,238,2,83,0,248,0,66,2,93,3,200,255,80,2,74,3,44,0,124,3,24,0,33,0,122,3,240,255,214,3,63,3,118,5,255,5,106,7,180,6,96,5,156,7,185,5,236,248,29,247,169,248,23,246,152,249,200,248,97,249,44,248,60,251,136,248,59,251,198,247,233,249,204,249,219,249,236,249,85,251,177,249,56,251,65,249,177,250,129,251,176,249,100,248,6,251,145,250,231,250,133,250,185,249,101,251,116,249,225,250,93,250,58,250,169,250,126,252,24,251,221,251,205,250,146,251,42,252,147,251,131,251,32,250,200,251,228,250,4,252,97,251,44,252,50,250,57,252,41,250,36,252,102,252,233,251,203,251,186,252,101,251,166,252,58,251,149,251,239,251,216,251,1,253,152,252,123,251,67,253,144,252,62,253,118,252,250,252,8,252,190,253,200,251,223,252,58,250,177,253,169,251,176,253,134,251,55,253,148,250,128,253,160,250,171,253,221,251,96,254,121,252,82,253,192,252,107,253,60,253,68,254,156,252,22,254,103,252,138,254,248,252,149,253,110,251,183,253,219,253,255,252,229,252,77,254,109,253,238,253,27,253,14,254,187,252,155,254,171,253,233,254,153,252,13,255,137,252,230,254,103,253,232,254,101,253,91,255,208,253,118,254,121,252,150,254,102,254,64,254,185,253,103,254,194,253,199,254,155,254,131,253,220,253,198,253,76,254,128,252,8,254,130,254,11,253,198,255,31,254,91,255,150,253,65,255,138,254,22,255,130,254,34,255,85,253,231,255,32,254,94,254,153,254,38,253,159,254,188,254,99,255,80,254,190,254,118,254,209,254,228,254,152,255,167,253,223,254,212,253,60,255,180,253,106,255,109,253,160,253,39,254,232,255,188,255,64,254,38,254,248,255,6,254,211,255,20,253,72,255,180,252,4,255,123,252,165,255,184,253,159,255,116,253,138,0,4,253,125,255,90,253,244,255,98,253,165,0,253,254,253,255,184,252,149,255,115,252,37,0,32,252,44,0,170,252,97,254,185,252,13,0,23,252,241,254,254,251,203,254,226,252,34,254,192,252,24,254,81,252,168,0,168,251,125,254,95,251,155,255,97,251,216,255,83,252,196,254,250,251,254,252,236,251,143,253,199,251,230,253,56,251,213,254,224,250,76,254,83,251,105,253,113,251,95,255,64,251,78,253,43,251,193,252,104,250,48,253,133,250,19,254,126,252,28,253,102,252,223,252,178,251,110,254,213,249,60,252,219,251,130,253,11,251,98,250,37,250,90,252,34,250,129,252,194,249,204,253,69,249,51,253,162,253,171,253,114,251,195,251,167,250,44,254,102,248,43,250,210,248,71,252,116,248,93,252,37,250,68,255,157,249,91,254,79,250,174,254,88,250,234,255,106,248,90,254,42,248,7,255,16,254,142,255,138,248,13,253,247,250,174,0,85,250,147,255,30,254,255,254,59,251,4,254,175,249,151,0,98,249,208,0,114,253,107,0,141,249,29,0,139,251,23,1,65,251,50,1,52,251,6,254,38,253,81,255,44,251,155,255,55,252,39,2,154,252,22,1,201,252,59,1,205,253,120,1,229,251,228,0,5,254,24,1,169,253,25,1,10,253,253,0,207,254,123,1,13,253,122,255,157,253,148,2,200,252,24,2,207,252,134,2,99,254,49,0,171,254,177,0,59,254,14,2,30,254,77,2,185,255,83,1,111,253,8,1,12,255,39,1,19,255,59,1,125,254,57,2,6,254,247,255,135,254,14,0,96,255,149,2,40,255,40,0,204,254,210,255,95,0,214,0,14,255,167,0,170,255,192,0,200,255,27,0,180,255,31,0,36,0,53,1,150,255,74,255,143,255,74,0,71,254,234,255,23,0,139,0,81,0,245,255,44,0,15,0,169,255,119,255,138,255,49,255,98,255,198,255,16,1,164,255,100,255,71,254,8,0,120,255,128,0,35,255,101,0,38,255,40,0,59,255,180,255,56,254,9,0,67,254,33,0,89,254,226,0,60,0,73,0,34,255,156,0,113,254,24,1,194,254,245,0,171,254,166,0,13,254,83,1,66,255,71,1,37,255,69,1,119,255,167,255,172,253,100,0,141,253,144,0,91,253,231,1,28,0,252,0,121,254,214,0,215,255,26,1,228,255,99,0,226,254,75,1,49,0,203,1,124,254,53,2,143,254,180,1,28,0,80,1,247,255,141,1,89,255,106,2,34,0,84,2,239,255,49,2,116,255,43,1,79,0,10,2,125,0,203,0,2,0,244,0,32,1,255,0,211,0,175,0,82,0,84,2,187,0,5,2,108,0,125,1,255,0,109,1,41,1,241,1,96,1,71,1,174,255,25,0,210,0,115,1,245,0,5,1,3,0,33,2,193,1,140,0,38,1,44,0,39,1,212,0,91,1,244,0,238,1,75,1,16,2,201,0,51,1,93,1,155,1,101,2,28,1,102,2,157,1,208,1,66,1,112,2,141,1,97,0,200,0,96,255,128,1,149,0,106,1,239,1,13,2,13,1,73,2,33,0,235,1,135,255,177,1,171,1,99,2,242,1,4,2,171,0,187,1,241,1,154,2,184,1,19,1,54,2,63,2,146,0,127,2,155,0,158,2,223,255,173,0,212,0,184,2,90,255,89,2,65,255,183,2,23,254,247,1,175,0,230,2,214,0,220,1,116,1,59,4,66,2,18,2,74,2,9,3,169,1,106,3,59,1,73,3,118,1,80,3,91,255,53,2,35,0,223,3,217,255,38,4,73,1,200,2,18,3,72,3,133,2,27,3,149,2,164,2,59,2,150,3,120,2,55,4,161,2,49,3,62,1,132,1,106,3,244,3,52,2,80,3,112,3,108,2,45,2,223,1,159,2,197,1,180,2,212,1,72,3,130,2,76,3,133,2,250,1,172,1,129,3,55,2,69,3,131,1,194,3,243,1,179,2,49,2,171,3,158,3,15,3,40,1,22,3,12,1,4,4,18,2,106,3,73,1,36,2,143,0,163,2,35,1,247,1,66,0,17,4,103,1,18,3,97,0,37,3,33,0,69,3,214,1,255,1,49,0,68,4,71,1,150,4,67,1,3,0,242,0,104,3,218,1,177,2,173,1,49,5,166,2,18,4,108,2,85,4,152,2,65,1,193,0,121,3,182,3,129,4,106,3,125,3,123,2,109,3,94,3,180,3,145,3,13,5,153,2,40,5,127,2,229,3,25,3,122,5,6,4,152,4,244,3,86,4,191,3,130,5,157,3,123,5,147,3,31,2,94,3,92,4,198,4,67,3,166,4,67,3,166,4,191,3,124,4,123,4,96,5,20,5,169,4,135,5,207,4,55,5,61,5,234,2,68,4,175,6,3,5,109,5,49,4,54,5,30,6,129,4,195,5,109,6,113,4,33,7,196,4,32,4,102,5,241,5,194,6,96,6,9,6,84,6,6,6,87,3,60,6,97,3,131,6,181,2,117,3,180,6,239,5,143,4,16,5,161,8,224,6,160,7,213,5,228,7,202,5,254,5,74,7,158,6,216,7,30,6,236,2,225,6,57,3,38,1,112,5,60,4,10,8,109,2,35,5,109,1,7,5,198,0,4,4,232,1,128,5,249,0,147,1,246,3,25,6,68,1,107,1,109,6,20,4,193,0,111,1,242,7,67,7,5,255,67,2,238,2,226,3,13,255,30,0,45,5,111,3,228,255,87,255,112,2,149,3,59,254,159,0,186,0,90,5,154,253,6,0,25,2,136,1,162,255,221,254,13,3,229,0,128,255,214,254,245,0,235,1,67,253,120,253,204,3,21,3,11,254,128,253,178,0,255,0,147,254,122,254,1,255,61,1,66,252,218,254,65,255,228,0,249,252,65,254,157,0,19,255,111,253,48,253,105,254,92,0,139,255,157,253,78,1,26,255,89,253,196,251,112,255,195,254,123,252,163,252,30,253,152,254,171,255,41,253,166,255,237,252,100,0,234,255,121,254,249,254,200,255,183,255,175,254,14,253,5,0,67,255,62,253,144,253,89,0,168,254,121,255,167,251,159,254,19,255,84,253,145,251,237,254,178,251,243,254,77,251,152,0,145,0,46,253,48,251,49,0,80,0,32,251,248,252,8,255,135,1,36,253,221,253,213,1,218,0,1,255,160,252,69,0,110,1,90,255,27,254,80,253,191,0,68,251,84,251,86,255,87,255,228,250,161,249,65,1,214,1,117,250,37,251,192,255,16,1,175,250,8,255,236,1,53,2,47,253,159,253,195,0,229,1,195,253,123,255,171,1,202,0,85,255,138,255,199,0,63,2,2,0,225,255,182,2,243,2,170,250,217,255,40,2,45,2,23,254,15,1,168,2,25,2,13,0,59,254,87,3,186,3,123,255,204,255,175,255,226,2,111,251,125,2,31,4,35,4,161,255,164,2,235,4,57,4,233,1,49,1,63,254,186,3,234,253,228,3,55,252,98,3,222,251,35,4,242,250,106,2,120,250,105,2,54,254,86,5,97,255,29,7,250,252,240,253,242,255,86,4,78,251,123,252,252,252,177,1,24,251,25,251,13,252,210,254,166,253,183,253,9,253,174,249,8,253,243,249,184,252,127,248,208,252,229,253,23,249,69,247,29,255,220,255,14,248,217,248,197,247,154,251,89,246,232,248,66,250,252,0,115,245,97,254,197,253,45,254,229,5,18,6,132,8,183,7,22,9,228,7,161,249,192,249,252,248,14,247,253,251,22,249,180,251,23,248,3,251,148,250,169,250,2,250,77,252,75,250,52,252,12,250,25,252,58,251,4,252,108,251,209,252,37,252,32,252,165,250,64,251,18,252,247,250,186,251,24,253,12,251,13,253,243,250,162,252,101,252,119,252,40,252,90,253,229,251,83,253,230,251,193,251,39,252,218,251,89,253,35,252,127,253,153,251,48,252,6,253,114,253,134,252,218,252,191,252,189,251,62,253,139,253,147,253,218,252,128,253,212,252,249,252,134,253,245,252,225,253,28,252,203,253,205,251,188,253,222,253,157,253,196,253,149,253,8,253,222,254,145,252,242,253,201,252,50,254,229,252,3,255,215,253,97,254,179,253,73,254,235,253,172,254,76,253,89,252,7,254,252,252,66,253,149,251,249,254,206,254,53,252,29,254,67,254,182,255,213,253,220,253,154,253,127,255,75,253,22,255,116,254,10,255,37,254,6,255,247,254,108,254,136,254,254,253,95,254,2,254,212,254,199,254,178,254,104,253,49,254,210,252,126,254,64,253,175,254,153,253,22,255,55,255,23,255,17,255,89,255,201,253,53,255,149,253,109,255,97,254,141,255,160,254,90,255,18,253,85,255,7,253,242,254,145,252,248,254,121,252,145,254,24,253,43,0,37,254,14,0,115,253,43,0,98,253,11,0,64,254,197,255,247,253,130,255,137,255,101,255,155,253,214,255,161,252,229,255,93,252,136,0,29,254,183,0,44,254,55,0,214,254,55,0,208,254,57,1,159,253,57,1,48,253,66,1,89,255,100,0,227,253,253,255,137,255,145,255,69,255,233,0,20,255,4,1,22,255,26,0,91,255,134,0,211,255,216,255,219,253,104,1,53,255,122,1,124,254,194,1,129,254,19,1,20,0,182,0,153,255,246,0,145,255,175,1,37,0,206,1,110,255,231,1,99,255,228,254,197,255,247,1,72,255,24,0,53,0,253,255,54,0,122,0,3,1,77,1,66,0,228,1,104,0,180,1,68,0,195,0,116,0,190,0,206,0,13,1,247,255,226,1,96,1,126,1,29,1,143,1,21,1,196,1,0,1,69,0,186,0,13,0,41,1,243,255,3,1,161,255,30,0,56,0,138,1,196,0,169,1,205,0,200,1,25,1,65,2,15,0,191,0,119,1,34,1,151,1,64,2,200,255,227,0,32,2,149,1,0,0,37,2,164,255,16,2,27,255,95,1,11,255,82,1,150,254,179,1,167,0,15,2,181,255,46,1,91,0,56,3,129,0,87,2,240,1,167,2,186,0,237,2,153,0,225,2,231,254,88,2,164,254,103,2,20,255,1,3,41,0,113,3,38,0,122,3,36,255,73,3,155,254,115,3,119,254,135,3,134,253,218,1,68,254,82,3,81,255,166,2,19,254,242,0,249,253,17,3,54,253,70,2,227,253,110,1,225,253,178,1,171,253,244,1,3,253,222,0,66,253,149,3,25,253,194,3,155,252,245,1,125,252,36,2,133,254,200,0,77,254,157,0,205,252,214,0,163,252,157,0,154,253,40,0,136,253,94,0,141,252,202,255,27,253,4,2,11,254,42,1,154,253,85,255,154,252,95,255,159,252,233,255,206,252,93,0,9,252,245,254,106,253,153,254,219,253,2,0,70,254,135,255,135,254,0,0,29,255,33,0,98,254,130,255,127,255,212,0,90,252,34,0,198,251,230,254,161,251,244,254,58,253,199,252,92,254,65,255,204,251,96,252,107,252,163,255,140,253,154,254,97,0,7,0,50,255,119,254,155,255,24,0,53,255,38,0,88,255,83,0,169,253,89,254,233,254,170,1,68,253,118,0,181,255,206,0,43,252,95,253,88,253,161,1,145,254,37,0,233,254,218,1,127,255,194,254,63,1,40,1,142,253,217,255,87,1,90,2,72,253,217,255,209,254,172,3,104,0,233,0,132,254,137,0,220,255,13,1,181,255,42,255,120,0,43,0,239,253,35,254,203,1,164,0,54,255,27,255,207,255,89,255,97,2,24,3,98,0,36,255,147,3,148,0,37,1,27,1,101,3,91,0,63,2,138,1,70,1,178,255,205,2,67,0,109,1,189,254,104,2,220,255,219,2,27,0,107,2,238,0,120,2,17,1,192,1,99,0,33,3,220,1,101,3,17,1,173,2,64,0,21,3,72,0,253,3,217,0,25,3,203,1,222,2,104,1,134,2,224,1,104,1,66,1,173,1,208,1,126,2,174,1,244,2,107,1,232,3,148,1,171,2,16,2,90,2,103,2,143,2,157,1,178,3,175,2,169,3,90,2,136,3,92,2,43,2,225,2,18,3,150,2,211,1,142,2,106,1,77,2,161,3,198,2,242,1,222,1,159,1,164,1,181,2,115,3,45,3,171,2,13,3,157,3,145,3,171,3,214,2,220,2,235,1,85,3,19,2,180,3,222,2,195,3,59,1,40,3,249,2,243,2,120,4,248,2,143,2,52,4,58,3,33,4,67,4,70,3,235,3,40,3,23,4,109,4,147,2,77,4,224,3,26,4,50,4,51,4,203,3,182,2,202,4,30,4,59,2,73,3,116,3,124,5,99,5,72,4,56,4,93,3,207,4,223,2,4,5,248,2,248,4,223,3,87,5,29,4,233,4,188,2,26,4,22,2,220,3,197,1,240,4,87,2,116,4,167,2,85,6,47,3,104,5,9,2,37,5,137,1,28,6,37,3,168,5,174,2,44,4,136,2,107,3,51,1,59,4,105,1,23,4,61,1,137,5,196,3,163,2,59,2,128,4,79,0,90,4,209,255,250,5,55,1,185,6,58,1,142,4,177,2,2,2,162,255,93,1,26,1,132,5,72,1,1,4,231,1,191,255,57,0,37,3,202,3,36,0,62,0,1,3,249,254,23,3,166,254,125,2,187,2,119,255,108,2,22,2,29,2,33,253,194,0,199,2,44,1,244,254,161,252,158,3,1,3,60,253,84,254,250,1,174,0,132,252,138,253,179,1,35,2,101,250,254,254,109,2,215,1,6,252,168,250,119,254,9,2,104,252,82,253,231,255,20,0,42,252,124,251,84,1,9,0,234,249,145,251,160,254,48,0,213,249,110,254,137,252,6,0,124,251,136,252,220,253,160,254,149,249,112,251,97,255,98,2,24,248,61,252,31,255,193,0,136,249,88,248,11,255,19,254,60,252,112,249,88,252,133,253,237,250,48,249,148,250,164,253,252,249,189,252,139,250,121,255,204,249,222,254,122,249,56,253,37,248,160,249,129,249,229,255,46,247,213,252,123,251,184,0,15,251,189,0,169,250,74,2,37,248,201,0,234,252,200,2,70,251,3,0,247,251,40,3,29,251,62,3,145,255,123,2,156,249,191,1,49,254,75,252,67,254,96,252,8,254,118,251,11,254,69,251,144,0,161,254,140,254,228,251,229,254,221,251,233,254,157,251,193,253,98,250,181,253,178,249,89,252,40,252,229,0,178,2,103,252,49,253,109,254,82,5,83,253,47,254,106,3,141,1,3,254,210,255,61,1,54,5,27,254,200,1,45,3,183,1,101,254,83,1,130,3,43,4,87,254,46,0,161,5,241,1,115,252,224,252,185,5,22,4,2,255,191,254,150,5,141,4,68,0,94,1,10,4,154,2,114,1,11,0,31,5,22,3,143,0,232,0,17,4,26,6,142,255,151,2,80,6,54,4,198,1,67,2,251,4,16,4,180,255,141,3,240,2,43,4,153,0,0,2,92,1,190,4,102,2,129,1,51,7,40,3,13,1,10,4,203,0,62,4,140,2,249,3,247,6,106,4,173,1,47,5,131,1,104,5,207,255,159,4,184,255,191,4,96,254,233,3,32,2,213,6,160,254,199,4,10,254,175,4,179,253,57,2,29,255,94,6,114,255,42,6,26,255,179,6,54,253,8,5,186,252,118,5,107,4,77,5,48,255,208,4,181,1,197,3,95,252,50,3,43,3,130,5,91,3,227,5,164,0,188,4,107,5,1,7,228,1,82,7,200,1,15,8,228,3,146,4,46,5,122,5,36,5,80,5,111,4,238,4,210,4,82,6,81,5,232,6,141,5,203,4,48,6,67,5,86,3,160,2,149,6,30,6,115,4,246,4,224,7,33,7,237,6,45,6,252,5,180,5,207,5,178,3,123,6,253,3,208,6,188,4,112,5,209,3,236,6,137,4,34,7,140,4,182,6,149,5,181,7,55,6,161,4,96,3,84,8,37,4,7,7,46,3,46,7,245,2,56,8,35,5,6,8,234,4,65,8,147,3,27,9,162,3,187,5,123,4,30,10,159,5,197,8,208,6,42,8,84,6,54,9,174,5,106,10,226,5,84,7,45,7,22,8,183,7,203,6,41,6,170,2,9,5,48,6,253,7,174,5,50,8,194,9,212,7,151,10,18,8,214,2,52,6,196,10,32,9,228,0,79,3,152,9,123,6,36,0,45,1,150,7,165,7,66,254,160,255,106,8,116,5,253,5,77,4,14,0,96,2,101,252,36,253,103,5,190,7,65,5,184,3,88,253,65,1,1,5,244,4,198,249,109,1,173,3,178,3,55,249,202,252,70,9,227,10,29,7,228,10,61,254,215,251,239,253,231,250,62,254,12,253,15,254,161,252,128,254,149,253,99,254,99,253,195,254,230,253,181,254,212,253,98,254,4,254,88,254,134,254,238,254,188,254,78,254,154,253,30,255,12,254,24,255,254,253,249,254,135,254,214,254,102,254,105,255,58,253,82,255,206,252,107,255,100,254,100,255,83,254,224,254,50,254,70,255,53,255,86,255,210,254,65,255,191,254,125,255,109,255,215,254,117,254,28,255,42,255,11,255,64,255,189,255,196,254,185,255,185,254,152,255,51,255,162,255,73,255,113,255,218,255,63,255,161,255,16,0,180,255,132,255,8,255,23,0,19,255,24,0,12,255,18,0,120,255,44,0,145,255,223,255,232,255,231,255,0,0,149,0,19,0,23,0,113,255,158,0,87,255,174,0,75,255,133,0,201,255,165,0,230,255,111,0,84,0,98,0,75,0,87,0,183,0,141,255,245,255,248,255,130,0,11,0,170,0,254,0,77,0,205,0,17,0,183,0,112,0,6,1,194,0,202,0,31,1,95,0,189,0,214,255,151,255,234,0,179,0,39,0,186,0,163,0,89,1,76,1,199,0,43,1,161,0,202,255,29,1,178,255,25,1,123,255,141,0,74,255,111,0,249,0,85,1,15,1,108,1,93,0,147,1,75,0,135,1,92,0,254,1,118,255,220,0,71,255,227,255,222,255,105,1,141,255,64,1,3,0,42,2,99,0,30,1,218,0,79,2,11,255,150,1,244,254,197,1,0,0,68,2,25,0,94,2,19,1,20,2,148,0,194,1,183,255,227,2,227,254,6,2,224,254,94,0,53,255,162,2,116,255,182,255,205,0,202,2,142,255,43,1,176,0,155,3,182,0,45,2,240,0,193,2,240,255,1,2,229,1,81,2,37,1,128,1,195,1,105,2,218,255,50,0,51,2,17,2,47,1,209,0,203,1,107,1,177,1,196,1,194,1,198,1,111,1,94,2,221,1,229,2,176,1,97,1,112,1,11,1,105,1,204,2,17,1,71,2,197,1,166,0,254,1,172,0,201,0,117,2,18,1,191,0,56,2,127,2,46,1,42,1,122,2,131,1,131,2,94,1,75,2,48,2,100,2,53,2,88,2,20,3,231,1,160,2,0,2,247,3,65,1,77,1,101,1,86,3,131,255,157,1,218,1,200,2,17,0,105,255,52,2,29,1,14,1,15,255,203,3,121,3,233,1,220,0,254,1,128,3,37,2,156,3,71,1,57,3,34,1,143,3,28,2,84,4,158,0,37,3,199,0,189,3,255,1,218,2,100,0,106,3,13,0,23,3,179,1,120,2,164,2,204,3,249,0,132,3,211,1,194,4,13,3,50,4,73,2,17,3,233,255,157,2,11,1,19,4,107,2,60,4,103,2,121,4,110,2,137,3,148,3,25,4,80,0,75,1,72,2,51,4,89,0,127,2,220,3,193,3,2,3,208,2,30,3,187,2,236,1,191,1,131,3,115,2,15,1,164,4,213,2,53,5,87,0,91,2,64,3,67,6,104,2,103,4,122,3,225,5,232,3,132,4,98,3,241,3,227,3,59,3,125,4,90,3,49,3,170,5,5,3,40,5,244,1,109,5,56,1,129,4,236,255,60,4,64,0,3,5,2,0,148,4,143,1,77,7,2,2,170,6,246,1,100,6,118,3,242,5,160,1,88,2,107,4,70,5,251,4,110,5,121,3,3,7,146,3,230,6,227,0,159,4,226,4,34,7,249,1,62,7,151,3,49,9,57,255,175,1,152,0,199,6,43,255,228,255,136,1,54,5,103,255,204,255,210,3,127,4,189,254,112,254,45,3,167,6,120,255,84,0,169,5,223,7,181,254,113,255,119,255,168,4,0,255,22,2,99,255,7,4,205,254,73,254,30,2,219,2,183,254,92,254,159,255,104,2,150,254,88,255,190,254,110,1,9,255,146,255,45,255,89,0,60,255,203,254,20,0,59,0,148,254,49,254,226,254,89,0,176,254,175,0,80,254,141,0,133,254,66,255,78,254,60,255,177,255,150,0,234,254,29,255,232,254,166,0,213,253,90,254,101,255,29,2,146,254,54,0,227,255,173,255,211,254,250,252,186,0,116,2,115,254,248,254,242,0,37,1,59,255,183,253,124,0,154,1,53,0,123,255,10,0,84,1,198,253,215,251,65,0,66,254,68,0,19,254,127,1,169,3,155,254,57,253,153,254,6,255,91,253,212,251,36,1,230,255,107,1,6,0,95,2,33,5,129,255,246,255,233,5,94,7,201,2,204,3,189,5,133,8,163,5,224,7,115,184,188,67,8,172,10,68,59,151,102,68,225,122,167,68,205,196,212,68,123,204,255,68,20,78,25,69,92,87,43,69,51,203,66,69,61,66,81,69,163,1,163,0,226,255,250,254,57,254,235,252,106,250,47,253,238,3,152,2,13,1,25,0,107,2,4,1,183,0,96,0,56,252,178,250,124,254,135,0,75,253,67,3,200,1,154,0,81,4,191,2,57,2,107,1,89,6,46,5,217,3,236,2,36,255,219,0,76,0,48,255,81,250,130,249,49,0,149,0,60,252,84,255,16,253,176,254,113,2,209,0,6,255,190,255,7,252,186,252,254,255,61,1,136,247,51,250,118,255,123,0,172,248,205,247,247,253,85,0,57,252,146,254,73,253,143,252,103,252,13,252,5,253,75,252,132,255,0,255,160,254,108,253,178,0,207,1,98,1,48,1,48,249,177,253,230,254,79,0,55,247,175,0,99,3,243,1,118,255,76,255,75,255,235,255,13,247,39,251,52,254,248,253,253,252,195,1,246,255,204,254,15,1,191,255,4,0,214,0,233,254,77,254,213,255,164,254,98,253,35,0,191,255,45,255,38,3,23,2,85,0,41,1,57,0,239,0,210,2,237,1,225,0,149,2,72,3,35,2,228,253,136,254,14,0,93,1,213,1,209,2,75,1,162,0,224,253,16,253,194,255,246,255,142,1,168,255,212,2,189,2,237,255,235,253,162,255,89,2,136,0,185,255,87,253,21,253,90,255,168,254,5,1,206,255,161,0,204,255,229,1,81,1,117,249,50,0,190,0,163,255,22,247,25,255,62,255,174,255,161,255,173,253,102,255,128,0,126,3,245,1,76,2,201,1,167,254,206,0,122,0,110,0,137,253,29,255,199,253,3,0,152,1,239,0,141,1,226,0,59,255,254,255,128,0,235,1,1,5,136,3,36,1,215,0,26,2,50,1,3,1,253,1,91,253,233,251,13,0,65,1,89,253,180,253,154,254,44,255,210,253,243,0,134,2,223,1,230,1,86,1,122,2,20,2,107,0,34,3,75,1,136,0,144,255,114,254,249,251,226,254,186,254,63,253,32,1,16,1,19,5,120,4,154,4,92,3,89,254,121,0,127,254,108,255,217,254,210,254,190,252,205,252,16,0,232,255,55,255,36,254,43,2,91,0,11,255,38,1,218,255,133,254,62,252,59,251,89,251,18,250,239,254,117,254,122,254,11,252,123,253,61,2,205,248,250,251,249,1,212,1,232,2,179,3,97,2,237,1,79,253,108,251,140,253,121,255,254,251,195,0,155,1,196,0,46,6,123,4,63,2,81,1,41,251,247,252,120,253,114,255,83,2,57,3,199,3,223,2,74,251,54,252,175,255,170,254,23,253,13,0,184,255,119,1,198,1,19,0,127,5,153,3,145,249,84,255,93,3,50,2,160,3,1,6,39,4,228,2,88,246,72,252,8,1,82,0,10,254,59,252,202,250,123,0,99,3,212,4,22,2,171,0,240,246,52,254,12,3,107,1,90,251,151,253,252,0,195,255,82,255,34,0,243,3,20,3,227,246,247,0,167,1,153,0,240,255,157,254,6,1,193,1,216,249,207,251,224,253,141,254,153,253,207,254,27,4,37,3,175,2,16,2,6,0,74,255,167,3,107,3,234,3,41,3,199,0,1,1,126,0,76,0,184,253,142,251,87,2,44,2,175,251,145,250,201,249,249,253,47,252,211,250,108,0,91,1,46,253,49,252,109,1,101,0,111,255,169,2,249,0,103,255,0,0,178,254,198,253,159,0,156,1,29,1,176,254,151,253,71,252,58,252,119,3,177,2,29,251,84,0,71,255,114,254,176,253,177,1,20,4,141,2,85,0,73,1,216,255,105,1,79,254,63,253,210,1,62,2,102,255,142,2,80,2,34,1,89,255,72,0,93,1,175,0,162,2,41,1,209,3,208,2,211,4,180,4,245,2,232,1,112,254,243,254,26,2,116,1,186,250,149,250,86,251,165,255,238,4,108,3,7,3,188,2,169,253,218,255,82,254,46,253,184,7,94,6,223,3,96,2,111,0,20,1,30,255,160,255,77,252,124,254,245,255,249,255,209,254,237,253,185,252,82,1,198,6,174,6,125,5,245,3,252,253,169,252,123,253,210,0,80,253,96,254,1,2,230,0,202,252,131,253,134,251,192,254,72,252,110,253,74,253,183,0,142,255,145,253,50,3,162,2,65,255,52,255,219,2,123,2,51,0,197,4,115,3,64,2,70,252,81,254,58,3,86,2,170,254,13,253,124,252,105,254,154,251,158,254,50,255,0,254,221,253,214,252,155,254,148,253,66,0,3,2,183,255,102,254,152,252,79,252,92,250,53,251,191,0,239,255,224,253,25,255,252,249,224,253,123,252,138,252,67,0,239,255,66,0,244,255,102,249,187,253,152,255,240,254,204,251,94,251,203,248,136,254,140,251,98,252,92,254,198,255,253,254,112,253,146,251,215,253,252,6,203,4,199,1,129,0,206,1,185,1,16,255,240,253,72,3,2,2,130,0,181,255,90,4,111,2,153,0,216,0,44,4,52,2,250,255,236,254,95,4,215,2,190,0,188,255,192,2,50,1,119,0,248,254,73,1,61,0,156,255,156,0,108,1,123,0,183,0,48,255,85,255,133,255,220,0,191,255,206,254,194,255,146,1,17,0,108,253,86,252,246,254,0,0,129,1,235,0,20,1,29,1,64,1,12,1,176,254,56,255,44,253,17,0,172,255,125,1,224,253,173,1,238,1,7,2,139,255,32,1,48,1,73,1,131,2,157,0,189,2,252,1,176,4,113,2,28,3,96,2,230,3,165,1,236,1,120,2,180,4,12,3,190,1,132,0,233,4,76,3,35,2,193,1,61,3,146,2,29,2,214,1,108,4,234,4,150,3,127,2,35,2,51,0,167,1,23,1,9,0,136,1,83,0,94,0,30,2,31,2,229,0,109,255,58,255,129,0,194,0,71,255,161,252,215,250,210,254,30,0,171,253,139,253,237,255,114,0,124,252,199,251,210,1,97,1,53,250,219,249,15,0,113,255,84,249,245,247,17,253,196,0,172,248,237,247,126,253,254,254,225,246,66,250,62,254,204,253,184,253,70,255,152,252,98,254,243,248,36,252,155,251,226,250,42,253,151,251,28,0,169,0,241,251,160,252,50,253,10,255,228,1,36,0,23,255,207,255,9,1,67,0,33,1,211,1,178,0,31,2,42,3,28,2,84,0,26,1,160,2,191,2,49,252,247,252,129,0,31,1,86,252,29,255,187,3,83,2,175,249,223,254,68,3,137,2,201,248,41,255,82,4,206,2,14,248,195,251,138,2,184,1,203,247,239,253,139,3,63,2,37,248,176,254,158,2,204,0,171,246,76,253,104,1,137,0,148,247,100,247,247,255,24,1,246,254,119,0,39,0,193,0,78,0,197,255,136,255,226,0,49,252,166,252,243,252,185,251,149,253,99,254,61,254,182,252,64,251,215,250,211,252,141,252,160,250,177,249,118,254,84,254,31,253,167,251,219,253,234,252,144,252,49,252,57,252,126,253,39,252,138,252,7,251,175,250,39,254,220,252,135,250,129,250,160,0,247,254,105,252,237,254,8,255,6,255,50,253,132,254,97,0,153,255,137,254,27,255,97,254,63,255,121,255,213,253,116,2,105,1,119,0,216,0,67,2,108,1,135,1,209,0,122,2,10,2,102,255,108,255,14,2,133,1,170,0,33,0,105,0,11,1,64,0,124,1,33,250,24,252,226,255,143,254,210,251,58,0,135,2,223,0,16,250,221,254,109,2,51,1,5,250,156,0,250,2,148,1,19,248,141,0,222,2,243,1,199,248,118,253,50,1,0,2,69,255,152,255,197,255,182,1,134,0,26,255,156,0,70,255,195,255,252,254,240,255,10,0,199,253,253,255,91,254,215,254,67,249,247,253,166,254,178,0,174,250,197,255,212,255,157,0,158,247,51,254,42,254,163,254,134,247,255,255,143,254,135,255,213,249,139,254,124,252,9,252,163,251,177,253,155,253,240,252,207,253,122,0,181,255,63,254,252,255,85,255,133,255,140,254,192,0,168,0,180,255,124,255,252,0,149,255,84,1,210,0,136,1,253,1,16,1,181,0,147,255,145,0,218,0,119,0,96,254,249,254,229,1,9,1,75,255,248,255,226,254,226,0,12,255,38,255,69,0,222,254,98,255,191,0,255,255,192,255,176,253,166,255,213,0,160,255,255,0,179,1,178,0,176,255,143,254,238,255,223,255,176,255,214,255,159,1,140,0,34,255,119,4,139,2,137,2,73,1,255,2,44,2,249,0,235,0,180,3,157,1,186,1,23,1,141,0,83,1,100,1,45,2,42,254,86,255,99,0,237,0,199,253,224,252,96,1,53,2,26,1,217,1,214,1,76,1,57,255,78,253,252,250,107,252,63,255,86,254,224,252,158,251,230,255,141,254,22,254,63,255,125,2,83,2,7,2,74,1,152,1,141,255,79,0,12,0,221,1,87,0,153,255,136,254,102,253,165,254,235,254,221,254,2,254,31,254,169,0,41,1,195,252,30,253,51,255,85,255,192,254,228,253,72,1,27,1,165,252,66,252,186,1,254,255,44,2,174,2,130,0,56,0,103,5,244,3,243,2,171,1,100,2,229,2,116,2,41,2,173,254,228,252,134,0,21,1,135,253,195,251,254,255,10,255,144,252,245,251,185,249,216,251,30,252,38,254,142,251,24,254,98,254,229,252,73,0,50,255,248,255,117,255,183,1,204,0,80,255,190,253,23,0,131,0,243,254,11,253,65,255,245,0,147,255,174,254,112,0,60,1,120,0,106,254,138,255,99,2,76,255,70,255,123,253,115,0,83,255,34,0,250,253,23,254,105,255,61,0,185,253,180,252,220,0,118,255,87,253,4,252,135,1,239,255,170,253,191,254,157,0,217,254,129,0,155,0,98,252,149,252,37,252,29,1,241,0,173,255,131,255,131,255,108,2,85,2,176,1,92,0,137,1,78,0,153,1,61,0,119,254,29,253,99,254,20,253,83,0,54,0,105,1,27,0,196,251,130,0,175,254,74,253,227,249,41,1,62,1,237,255,175,248,36,0,51,0,195,254,237,246,10,255,231,0,172,255,254,246,241,252,40,0,77,255,71,247,94,252,38,254,50,254,14,253,170,255,224,254,142,253,149,246,57,254,193,255,171,0,181,251,186,251,230,255,113,255,87,251,57,254,106,254,131,254,163,253,46,255,160,255,205,255,188,253,36,254,236,254,241,255,85,251,134,253,77,251,143,252,134,254,35,255,99,253,72,252,82,2,178,0,109,254,92,253,251,2,71,1,89,2,34,1,172,0,44,1,203,0,157,0,200,255,176,254,100,1,24,0,28,255,216,254,253,254,227,255,70,255,7,1,160,1,14,0,159,254,117,1,244,255,40,255,1,1,96,0,174,0,57,0,10,250,152,253,70,252,13,254,15,254,104,255,179,254,125,0,105,0,200,0,179,0,159,255,181,254,32,255,253,2,185,2,248,2,0,1,45,1,59,0,199,1,171,255,204,0,32,1,254,253,240,0,251,0,147,255,0,1,161,1,222,255,99,254,101,0,174,1,128,1,156,0,225,255,246,255,206,0,170,1,77,2,145,0,143,0,71,0,40,3,138,3,77,1,93,1,218,3,170,3,77,2,75,1,20,5,56,3,187,0,253,1,38,4,141,2,123,1,210,1,182,5,169,3,145,1,18,1,19,3,93,3,9,1,2,0,97,2,41,2,28,0,49,1,158,3,84,1,106,0,130,1,241,0,245,254,109,255,225,0,78,255,234,253,91,1,246,1,125,253,131,254,141,1,30,0,117,253,35,253,77,254,142,1,105,254,42,253,28,254,8,255,235,252,110,252,74,254,36,254,14,254,122,254,75,0,217,254,60,252,178,253,162,253,150,0,135,255,207,255,101,255,178,255,167,3,38,2,133,1,38,0,191,254,127,0,168,1,59,1,227,254,143,255,27,1,3,1,146,2,203,0,66,1,230,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+898200);
/* memory initializer */ allocate([135,3,249,1,236,2,161,1,99,2,167,1,43,2,0,2,239,0,173,255,190,253,237,255,173,254,37,253,93,1,13,0,90,252,137,250,142,255,152,254,107,0,180,2,182,0,90,0,37,251,254,249,241,249,43,253,200,253,121,252,173,250,243,253,251,253,171,252,163,252,20,252,88,255,78,253,189,252,63,0,119,255,212,253,221,253,144,0,226,254,207,252,229,1,63,1,109,255,104,254,14,2,246,0,165,254,78,254,41,1,228,255,222,254,41,254,170,251,251,250,52,254,153,254,36,252,230,252,67,5,19,5,178,2,11,2,192,4,44,4,70,4,245,2,57,3,116,4,240,2,238,1,228,4,85,5,171,4,130,3,9,2,29,4,20,2,176,1,178,254,40,255,199,254,249,254,96,255,52,0,40,254,101,255,127,0,136,0,132,254,44,0,83,3,154,1,94,255,23,254,123,0,1,255,228,252,101,253,66,4,149,3,21,3,237,1,117,5,173,4,46,2,202,0,205,255,138,255,170,254,67,253,83,0,108,0,214,255,71,254,61,0,95,0,31,1,0,1,229,255,89,0,12,2,19,2,95,1,227,0,80,2,33,2,185,2,155,0,92,255,51,1,126,2,18,1,23,254,206,255,242,2,240,0,90,255,132,255,140,255,189,253,68,251,193,255,190,0,217,254,240,251,240,250,147,0,136,254,79,255,143,255,73,3,217,4,27,4,156,2,2,0,37,1,39,2,48,1,184,251,71,252,8,255,120,1,18,253,59,252,87,0,4,2,237,254,252,253,177,2,135,1,133,254,125,253,108,3,82,2,122,254,11,252,123,253,61,2,149,255,200,253,79,253,198,252,255,251,229,255,184,254,53,255,93,3,237,2,36,2,233,0,132,249,237,251,195,1,108,0,108,253,148,253,174,1,236,0,21,0,116,254,122,251,137,253,92,5,18,5,199,3,65,2,101,4,101,4,77,2,198,1,189,254,159,252,45,254,153,0,44,254,69,253,220,252,3,254,120,254,50,253,52,255,221,255,165,253,187,251,201,253,94,255,7,254,20,252,154,255,94,1,219,0,224,0,167,1,252,0,139,1,79,2,96,2,107,1,22,253,160,255,117,1,172,0,171,0,39,1,202,2,83,1,233,0,77,0,107,0,21,1,157,0,153,0,13,254,156,254,11,6,49,4,64,2,238,1,220,254,173,254,8,254,176,253,121,252,184,255,149,253,31,254,198,249,163,251,201,253,2,255,231,252,5,254,204,253,221,254,20,254,236,253,246,1,48,2,130,254,171,1,88,2,230,0,29,255,221,1,251,0,75,0,29,1,74,3,45,3,220,1,226,250,203,250,186,0,121,1,181,253,107,252,131,2,125,1,94,251,215,253,155,1,82,0,153,251,204,252,82,255,228,253,164,253,119,0,31,2,205,0,132,254,145,2,141,3,55,2,112,0,214,254,138,254,114,0,167,252,5,255,56,0,159,0,145,1,89,1,222,255,116,255,145,255,161,253,41,0,102,2,99,1,142,255,179,255,218,1,66,2,56,0,170,5,156,3,74,4,140,5,229,2,144,1,246,0,22,0,76,2,57,1,135,255,71,1,63,3,216,1,142,251,160,253,88,3,40,2,39,251,208,251,126,2,88,2,154,254,254,0,179,254,209,254,122,253,227,2,102,1,74,0,202,4,135,6,197,4,81,3,193,8,88,6,215,3,124,2,49,7,197,5,237,2,128,1,94,1,7,1,87,0,128,0,146,248,83,252,112,255,192,255,58,249,1,255,32,1,225,255,172,245,42,251,110,1,235,0,149,249,188,251,192,250,208,254,227,253,205,251,164,251,123,0,102,251,4,255,208,252,76,255,8,252,21,2,53,2,233,0,25,254,82,254,68,255,78,1,99,3,212,4,22,2,171,0,202,249,185,249,123,2,118,2,108,247,54,1,156,3,156,1,202,246,184,254,188,3,17,2,177,245,135,254,118,2,22,1,214,245,61,1,31,3,43,1,154,246,133,0,84,1,31,0,148,247,68,250,131,0,125,0,96,251,22,254,117,255,46,0,24,253,191,1,123,3,52,2,67,0,61,254,134,2,92,2,215,253,83,254,148,252,140,1,162,0,190,255,25,5,147,3,223,1,67,2,64,4,26,3,194,1,22,1,54,2,68,1,223,251,102,255,148,0,79,255,15,246,168,0,46,4,80,2,209,246,214,255,51,3,89,1,216,246,61,253,209,2,250,0,129,247,39,250,203,254,122,0,178,255,183,255,120,0,173,0,252,255,6,1,249,254,251,254,81,254,192,255,107,254,36,253,207,245,116,0,173,255,63,255,11,250,80,252,35,254,43,253,4,254,51,1,170,0,172,0,64,3,161,1,64,3,174,2,31,255,177,0,126,3,50,3,30,254,123,254,255,4,15,4,129,254,201,0,162,254,40,0,218,2,123,2,226,0,14,2,247,1,206,1,82,1,142,1,23,2,202,2,40,0,230,254,202,5,191,5,61,4,219,2,25,6,48,4,141,3,181,2,139,5,2,5,121,3,111,3,129,4,216,2,162,4,72,3,30,255,106,4,181,3,177,2,18,254,38,252,236,249,128,255,200,253,47,253,55,253,230,255,61,1,12,2,70,0,135,0,107,254,159,252,26,249,116,253,82,255,223,252,117,3,5,3,103,255,165,255,75,4,239,2,6,254,131,251,85,3,134,2,241,0,14,3,7,2,27,2,61,7,164,6,77,4,172,2,31,251,50,250,48,254,188,0,131,252,127,250,224,250,171,254,121,255,182,1,81,255,18,0,87,4,208,3,63,1,208,0,106,250,24,249,83,0,202,1,238,253,24,252,51,1,129,0,184,252,241,255,227,255,156,254,113,252,100,252,133,251,14,255,137,255,240,253,127,0,123,255,7,253,3,253,190,0,173,255,197,254,127,3,10,2,231,0,34,255,102,0,193,255,84,254,60,1,187,2,123,1,70,0,25,0,204,2,58,1,148,255,251,1,106,3,54,2,238,0,108,0,173,3,7,2,195,0,169,1,196,255,85,254,1,1,139,0,153,255,138,253,190,1,78,1,114,1,156,1,48,0,84,255,78,253,229,254,45,2,187,0,226,254,158,0,227,1,140,0,14,1,168,254,137,253,156,3,67,2,140,255,132,0,142,0,210,1,188,255,192,255,230,0,111,255,210,254,226,253,221,252,112,252,250,3,225,2,251,252,247,3,118,2,41,1,220,245,95,0,189,1,80,1,182,247,235,1,254,1,191,0,27,251,161,0,254,255,188,254,86,250,135,253,56,253,151,255,182,252,2,255,101,254,100,0,128,253,222,254,242,3,251,2,118,253,57,1,145,4,218,2,140,0,249,1,6,4,254,2,4,3,31,1,43,4,55,3,239,1,237,2,49,1,67,1,92,255,206,1,78,0,143,1,170,254,150,252,69,0,85,2,240,255,108,2,109,2,81,1,118,255,68,254,247,254,218,0,84,0,62,254,185,3,154,2,34,255,221,252,29,2,92,2,103,252,160,250,244,0,116,0,183,252,45,253,118,2,76,2,140,0,151,2,38,1,112,1,167,3,22,4,113,3,247,2,210,6,184,5,148,3,116,2,180,1,195,3,25,1,1,0,137,255,74,0,30,2,213,0,1,0,201,253,45,1,241,0,4,1,179,1,222,0,140,1,168,3,189,3,84,4,191,2,254,1,250,1,40,3,222,1,89,2,182,2,192,3,108,2,204,3,229,2,212,3,88,2,66,3,205,2,255,2,172,2,131,2,204,3,167,3,126,2,245,1,149,2,208,2,83,3,151,255,136,253,209,254,139,255,83,254,130,0,21,3,186,1,246,253,68,255,192,2,117,1,9,253,42,0,46,3,11,2,237,253,143,251,117,1,66,2,86,253,77,251,57,254,29,1,117,251,215,249,182,251,44,0,81,0,174,255,200,2,107,1,221,1,246,0,186,3,110,2,68,6,86,6,253,4,123,3,129,5,91,3,156,3,124,3,6,3,17,4,179,3,118,4,40,0,222,253,181,255,32,1,152,253,150,255,71,253,230,255,87,255,96,255,133,252,29,253,233,254,128,254,251,251,162,254,245,6,28,5,22,4,48,3,44,6,253,5,192,5,154,4,225,5,52,4,192,4,131,3,122,3,136,3,52,2,142,2,152,3,180,2,253,3,88,3,19,254,132,0,177,0,249,1,71,0,195,0,228,255,97,0,200,1,95,1,92,255,88,0,183,1,22,1,216,255,94,1,115,5,181,3,234,0,161,255,219,252,40,254,38,0,93,255,111,1,158,255,233,1,11,2,1,4,154,4,188,4,138,3,63,1,34,5,46,3,205,1,133,255,225,253,220,252,191,1,20,253,188,254,127,252,153,251,31,253,11,254,235,252,55,253,203,2,9,3,215,4,154,3,157,7,147,7,88,5,97,3,218,2,112,3,246,2,132,1,153,252,198,1,17,0,5,255,131,254,214,252,209,249,239,0,247,253,58,252,232,252,3,1,134,252,178,250,254,252,183,255,166,0,93,1,44,255,67,1,184,252,211,254,217,1,179,1,89,253,48,254,216,2,95,1,100,255,57,255,155,2,176,1,29,0,4,255,159,1,224,1,37,253,133,254,145,0,47,2,240,253,137,253,122,251,97,255,189,1,17,1,123,0,127,2,117,1,130,255,32,3,56,2,84,0,94,255,208,2,200,2,194,252,232,253,71,255,222,0,152,1,196,1,245,1,3,3,127,252,181,250,189,255,186,1,232,252,130,250,54,2,90,2,167,0,186,254,253,1,74,1,161,255,142,253,38,253,168,254,132,6,193,4,11,3,199,1,36,5,60,3,72,2,207,2,148,1,225,255,245,3,21,3,89,0,107,0,123,3,37,2,103,3,45,6,149,3,159,2,98,3,199,5,9,5,86,3,135,1,44,4,98,4,44,3,78,0,206,253,89,1,51,2,173,1,153,255,161,1,19,3,134,255,75,254,155,1,20,3,111,252,95,254,90,2,242,2,30,255,240,255,151,0,248,2,68,253,118,0,152,255,242,255,152,251,48,0,28,1,137,1,122,254,93,254,129,253,140,255,114,252,50,1,60,1,243,255,183,4,216,3,53,3,157,2,85,251,75,253,140,0,43,255,140,252,96,254,57,255,210,253,152,253,245,0,108,254,104,253,6,1,56,0,151,253,44,253,171,255,21,254,192,254,112,253,198,253,193,252,127,255,240,253,30,250,193,255,145,254,127,254,154,254,191,254,4,0,51,0,146,254,42,255,63,1,255,1,146,0,159,2,239,255,221,254,146,255,208,1,117,255,16,254,54,255,220,0,200,254,137,253,108,253,183,255,113,253,204,252,106,253,115,253,248,250,167,252,82,254,71,252,65,252,248,254,207,255,44,254,184,255,131,254,162,254,205,253,63,255,105,254,55,0,104,254,221,252,11,0,203,254,137,2,188,0,58,255,0,254,205,1,177,255,54,254,218,250,249,254,122,255,245,253,135,249,77,254,17,254,3,253,57,0,165,254,98,254,178,1,139,251,14,255,104,253,167,252,34,0,188,255,61,253,174,254,50,0,71,0,247,255,174,254,70,253,129,250,102,0,118,255,204,252,202,254,43,254,133,251,158,1,67,0,245,254,36,4,46,3,161,5,12,6,80,5,248,4,218,6,103,7,125,6,227,7,85,8,28,7,16,7,14,9,53,7,132,2,163,255,198,1,90,3,73,1,120,255,233,1,254,254,128,255,58,255,23,253,215,255,204,255,247,254,39,252,90,1,137,0,223,1,51,249,20,253,84,253,117,251,67,249,145,254,129,252,135,251,240,252,24,254,78,252,56,252,171,255,122,254,43,253,215,0,172,254,85,255,252,3,148,3,177,7,52,2,179,0,234,2,150,2,209,3,198,6,119,3,110,2,146,3,171,3,88,3,141,4,53,1,176,2,35,3,149,3,161,0,58,2,118,0,236,255,229,254,208,252,214,255,204,0,52,251,187,254,50,254,61,252,54,255,113,255,36,252,28,254,151,254,66,253,46,252,35,254,210,254,234,252,92,251,156,255,238,252,192,251,226,251,77,252,108,249,54,255,181,252,242,252,241,251,158,250,123,252,144,253,146,255,171,255,100,1,213,0,246,255,19,254,108,1,6,3,169,1,54,3,223,1,173,255,45,2,8,2,32,252,232,249,196,253,165,253,27,253,230,255,10,254,130,253,121,252,209,0,50,1,147,0,196,254,175,253,172,253,171,255,45,255,31,255,106,252,239,253,117,0,233,0,73,254,30,253,77,4,239,2,121,2,177,5,180,6,231,5,229,6,177,5,142,3,98,4,132,4,81,3,74,5,100,3,214,1,153,252,130,251,252,248,153,252,163,252,32,252,138,255,155,0,212,0,229,251,175,252,162,253,163,251,199,248,66,245,5,252,109,250,179,248,114,1,72,255,98,254,191,3,237,1,104,0,190,3,15,4,31,2,154,0,141,2,201,0,225,4,251,1,150,0,151,2,247,1,230,0,111,2,9,3,163,2,147,2,88,0,146,255,75,3,244,0,224,0,126,1,29,2,46,1,212,2,177,1,154,2,142,4,222,2,85,1,118,255,20,0,115,254,97,251,88,254,210,255,191,254,160,254,132,255,53,5,253,3,56,4,6,1,110,1,211,2,154,3,27,1,217,253,31,0,132,253,157,253,79,253,71,253,97,254,72,252,245,252,55,255,207,250,170,253,153,254,71,252,251,250,166,0,237,1,49,1,221,0,78,3,191,2,98,2,72,3,168,3,6,3,45,253,212,250,19,251,155,254,255,251,148,250,184,251,160,250,147,254,120,250,167,248,160,253,250,248,65,249,94,253,223,253,107,251,65,253,166,2,18,3,148,0,133,255,184,2,8,5,132,2,94,1,246,255,158,1,102,2,15,0,137,0,88,1,45,255,210,252,24,250,205,252,121,254,94,252,180,253,47,0,177,253,126,252,115,252,183,251,93,255,8,251,113,251,99,255,72,250,11,250,123,254,6,251,92,251,144,253,159,2,213,0,198,1,124,0,238,254,243,253,39,253,16,254,104,255,192,250,122,0,135,0,167,244,179,253,118,254,64,249,185,1,206,255,196,5,136,3,19,3,60,1,236,0,72,254,165,254,217,0,157,1,113,252,107,252,121,0,57,254,92,252,202,0,164,255,47,254,137,254,232,1,134,1,218,1,108,3,217,2,60,1,233,248,224,250,99,253,87,0,194,3,176,1,51,2,7,255,222,251,250,0,29,1,81,4,117,4,171,1,184,2,242,251,128,249,210,249,76,252,90,1,160,0,203,254,240,254,166,252,158,2,112,2,226,4,80,252,104,254,102,253,162,253,192,254,128,254,20,254,230,0,65,0,78,1,206,255,240,255,240,255,78,253,139,250,255,6,180,6,119,5,174,9,15,8,124,5,221,4,191,5,146,5,130,254,243,251,254,255,173,0,114,254,121,4,211,5,232,7,9,7,4,3,250,4,226,5,149,5,199,6,209,7,55,4,194,4,249,4,126,251,197,248,207,250,216,252,147,251,184,251,61,254,247,251,70,249,65,0,66,2,172,255,60,250,126,246,14,249,3,253,170,250,18,254,38,255,174,253,93,252,81,1,20,255,50,2,53,9,102,10,146,7,209,5,252,4,106,3,189,0,102,1,118,1,17,250,23,247,214,246,57,252,9,251,209,247,140,253,92,251,250,249,125,6,19,4,34,2,53,2,37,4,220,2,192,255,188,252,78,254,76,254,160,255,203,0,54,4,192,4,100,6,139,3,254,5,218,3,70,1,197,3,77,3,142,0,172,255,197,0,214,1,75,9,34,6,109,4,214,1,190,4,139,1,96,5,176,4,101,4,18,4,92,1,225,253,46,251,136,254,41,255,75,255,225,1,101,248,171,249,46,255,18,253,95,251,134,1,29,0,113,254,27,0,52,3,212,4,243,2,183,2,211,3,153,1,82,255,173,4,11,4,144,3,76,5,54,7,32,252,99,250,228,1,51,250,92,249,208,0,100,254,180,4,152,5,241,254,128,3,120,4,96,254,241,6,154,5,96,249,172,245,52,255,3,249,241,249,9,4,136,249,233,249,23,5,27,251,203,249,57,4,99,253,185,251,190,255,86,253,64,1,167,254,147,2,49,1,45,4,244,250,220,252,237,255,157,249,245,250,29,0,109,249,15,254,71,0,225,254,249,255,156,255,18,254,62,252,19,255,84,3,89,7,204,6,63,251,149,250,227,0,108,253,46,1,117,1,96,0,63,4,233,4,206,251,123,249,160,0,229,1,28,8,6,7,90,252,36,255,40,2,172,253,156,253,237,0,80,1,184,6,111,3,131,2,117,2,178,1,243,4,10,2,97,6,15,0,244,0,71,254,195,5,205,2,184,0,27,7,54,6,173,6,220,3,5,1,169,3,45,8,41,9,240,5,91,8,66,7,70,6,191,253,189,253,77,251,68,252,135,0,24,254,48,254,51,0,174,254,139,253,164,254,45,253,122,4,25,8,162,5,144,8,186,5,143,3,92,250,220,249,26,247,120,5,198,2,17,5,55,5,121,2,160,3,154,5,146,8,34,10,118,9,156,8,89,7,214,3,194,8,62,7,124,1,24,3,121,4,193,255,229,253,158,1,4,255,60,252,198,254,19,251,85,253,244,252,193,252,242,253,19,252,126,249,145,251,88,254,181,249,60,254,213,254,244,4,24,4,130,2,123,4,85,3,88,3,93,253,176,254,139,0,220,8,63,5,138,5,29,0,0,3,29,3,56,251,167,1,52,2,218,250,198,251,245,0,234,250,212,252,61,2,238,250,175,249,134,2,56,252,66,3,211,2,225,3,116,6,235,7,65,255,207,252,176,1,150,2,60,0,198,0,114,2,229,3,50,5,112,6,171,7,9,5,195,249,163,255,211,255,192,251,37,0,172,255,117,6,47,10,33,9,41,4,248,7,73,9,115,4,22,9,70,8,91,3,101,1,230,5,152,2,203,4,75,4,223,1,80,5,144,3,105,7,218,6,227,7,144,4,117,7,248,6,143,1,34,0,0,1,175,253,208,254,227,251,35,2,158,6,127,5,135,2,157,255,171,254,212,5,111,6,166,4,38,0,124,253,44,255,139,1,78,3,222,0,64,253,3,253,52,253,44,253,84,248,12,245,106,255,35,1,174,255,209,4,179,5,239,3,116,255,101,255,153,0,183,1,41,1,32,6,7,250,102,254,132,253,0,6,199,1,19,255,208,250,117,255,252,254,19,2,42,2,100,3,13,1,240,4,94,2,23,255,115,3,207,1,230,2,88,2,136,255,183,255,165,1,212,0,73,254,198,255,36,3,250,250,39,251,216,2,38,1,22,254,50,0,177,253,119,252,26,251,42,0,81,253,147,0,231,255,17,1,84,2,201,254,189,4,89,2,14,253,81,3,72,2,173,1,95,2,75,2,166,253,90,255,205,1,228,252,201,252,9,3,100,5,142,3,219,6,119,0,137,5,204,3,37,255,144,252,196,249,231,251,14,252,182,1,55,253,157,250,78,0,0,0,65,254,101,251,144,251,217,250,219,249,200,8,231,6,29,5,178,3,47,6,152,5,126,4,226,1,180,1,43,254,172,251,106,2,65,254,58,252,64,4,28,251,21,250,142,255,176,251,40,248,189,253,210,0,101,2,241,1,73,248,99,250,130,2,11,251,168,252,243,3,146,249,95,251,39,4,237,249,96,253,180,4,100,249,166,251,111,2,45,252,210,250,3,251,27,2,109,255,126,3,182,250,127,252,78,254,120,3,219,1,172,1,153,0,128,254,82,1,44,250,1,254,103,1,50,252,165,251,42,254,105,0,218,253,165,2,87,252,135,251,109,3,124,1,252,254,210,0,149,6,156,3,232,4,239,6,166,4,71,4,139,5,119,2,21,2,115,2,43,1,165,254,101,254,234,253,135,2,118,253,29,0,173,253,134,254,169,250,27,6,122,5,97,4,185,5,65,4,130,5,136,2,208,247,190,251,250,255,55,1,62,255,155,252,129,253,193,252,160,1,118,251,56,251,69,5,33,251,83,252,21,7,111,247,61,248,197,1,149,253,169,250,68,252,186,249,76,248,29,250,105,251,223,251,176,251,135,254,89,2,201,0,84,7,57,3,118,1,82,254,213,250,29,0,139,250,31,251,205,250,17,252,32,250,192,3,135,250,39,248,197,0,157,250,99,248,20,255,203,251,123,0,166,1,103,2,245,4,34,2,206,254,246,5,136,3,170,4,252,6,153,4,142,253,140,252,10,250,199,0,254,2,224,5,215,251,94,3,197,0,246,251,19,249,137,252,224,252,145,0,87,2,146,251,249,253,114,2,75,251,122,248,244,1,114,252,239,251,141,250,60,250,225,249,55,252,245,253,74,3,34,0,2,7,134,2,94,3,73,251,160,248,22,252,178,255,247,255,96,253,20,4,247,2,80,0,168,253,115,4,251,3,57,0,208,7,142,5,191,252,134,5,97,4,78,251,94,6,236,4,51,254,140,5,220,4,1,6,207,3,253,0,229,254,68,1,153,254,87,2,61,255,106,0,76,2,62,0,181,253,11,253,133,2,205,0,51,0,177,4,246,2,71,251,161,2,122,254,144,253,45,6,173,3,105,255,255,3,223,2,4,11,21,5,178,2,210,254,12,2,157,255,124,252,204,249,91,251,60,4,251,0,238,0,222,7,0,7,242,3,221,4,97,6,205,6,53,251,252,249,72,251,147,253,200,1,147,255,40,0,191,255,20,3,219,252,69,253,186,250,185,253,136,3,64,3,223,252,20,2,82,2,180,7,128,5,71,5,103,251,168,248,190,247,251,252,56,2,180,3,9,252,55,4,236,4,169,251,226,1,126,255,242,6,20,4,12,3,45,250,245,0,144,3,196,254,139,251,107,252,232,253,94,250,214,246,239,252,246,249,60,248,45,248,1,1,141,3,199,248,135,253,71,251,254,249,130,248,226,251,70,6,191,8,40,6,201,253,36,250,248,249,1,251,195,0,89,5,207,252,37,1,195,4,243,253,118,2,173,4,94,249,135,246,208,248,209,254,219,2,235,2,111,251,5,255,13,1,74,252,181,255,148,6,98,251,59,254,237,3,193,249,73,2,122,1,229,247,197,253,85,254,239,253,121,251,109,251,229,254,51,255,204,253,228,252,222,4,205,2,229,8,159,3,27,2,58,254,47,2,184,1,51,253,180,5,79,6,250,251,28,4,74,6,111,251,118,255,79,3,226,0,39,0,156,253,29,251,150,255,39,253,117,253,200,3,22,5,54,253,132,253,191,6,97,1,45,4,154,1,226,252,100,255,75,4,194,253,150,3,190,1,226,250,244,3,210,1,128,5,55,6,253,2,149,5,100,5,221,6,157,7,164,7,74,9,42,6,255,7,100,8,148,3,98,0,249,255,101,7,138,5,93,8,92,1,125,5,43,6,152,0,110,4,9,7,245,254,154,0,115,5,114,251,213,1,30,4,138,251,107,254,207,251,195,250,40,247,211,249,148,254,101,3,170,6,118,251,37,2,14,6,55,251,116,248,126,249,51,250,71,248,249,247,65,249,118,252,158,255,151,248,233,0,212,5,124,3,108,0,181,254,64,249,110,251,92,249,220,251,188,7,254,6,210,251,51,249,139,248,245,255,3,6,37,5,192,249,94,0,241,1,165,1,187,1,59,255,214,249,163,254,30,252,169,253,229,253,116,4,59,252,117,250,127,255,195,250,175,0,65,254,137,254,31,5,7,8,141,254,118,253,205,254,207,251,93,2,109,1,247,247,143,255,174,1,140,2,146,3,199,3,12,252,206,249,237,246,225,5,224,4,47,2,6,1,26,254,111,254,65,249,62,5,10,6,50,0,56,0,176,1,182,254,119,0,164,253,19,250,200,251,214,252,178,3,103,4,31,4,136,250,89,249,80,249,10,251,64,253,219,250,39,3,29,7,119,4,200,10,70,6,123,8,96,4,153,1,106,255,109,255,148,1,191,3,135,9,119,7,141,8,118,252,115,255,158,252,120,252,114,255,54,254,211,253,60,253,113,249,194,252,105,250,209,249,206,248,190,250,194,251,188,249,240,254,147,3,84,251,4,3,32,4,130,253,46,251,151,248,12,254,175,255,202,252,247,250,179,249,33,253,139,255,17,3,168,0,190,251,109,4,154,3,184,251,22,253,104,5,31,1,221,253,217,251,160,250,103,247,76,251,128,247,222,249,35,249,25,250,63,247,253,252,55,249,75,4,62,3,204,249,212,2,219,4,250,249,181,2,37,3,102,249,16,255,129,6,92,249,252,255,100,253,101,8,48,3,18,4,206,252,207,248,22,0,4,253,5,254,193,1,129,251,151,253,33,1,181,252,196,249,16,255,242,1,22,255,111,253,16,253,224,1,142,6,193,254,31,254,193,0,213,252,171,0,137,255,176,247,54,255,176,252,181,6,116,4,164,6,134,252,242,249,19,246,205,252,54,252,175,0,198,252,46,251,6,253,169,253,234,255,122,2,213,252,37,252,122,252,189,254,203,0,26,0,129,254,21,255,243,252,113,254,238,4,138,3,92,252,137,250,156,250,144,253,93,0,87,0,98,254,229,253,77,253,37,0,121,2,254,1,125,254,36,254,206,250,143,1,66,0,7,1,105,254,207,255,177,254,95,254,17,4,73,7,245,252,191,251,96,250,22,253,166,252,64,3,187,253,9,253,141,254,95,253,6,254,40,8,208,253,134,253,101,251,15,1,241,0,14,0,74,254,12,255,115,254,207,1,178,4,23,4,162,253,227,252,98,250,205,255,189,254,225,1,32,255,184,253,241,253,238,1,113,3,170,2,79,254,206,254,22,252,42,2,147,2,222,0,171,0,96,255,159,254,169,2,6,7,29,6,172,252,99,251,97,249,176,254,102,253,114,0,187,253,12,253,24,253,61,255,119,1,241,1,47,254,220,252,182,251,154,0,26,1,125,255,206,255,65,255,49,253,67,1,220,2,6,6,46,253,205,252,132,250,105,0,6,255,185,0,78,255,10,254,26,253,65,1,254,1,87,4,189,254,201,253,58,252,127,0,228,1,82,1,96,255,52,0,174,254,220,2,87,5,18,6,142,253,222,252,96,249,226,254,182,253,164,2,73,253,169,254,142,254,22,254,39,1,101,7,138,253,194,253,10,252,176,255,133,2,187,255,250,255,194,254,148,254,14,3,170,5,14,4,199,254,35,253,141,250,120,0,60,0,221,1,248,254,183,253,133,255,199,2,221,4,121,2,165,255,157,254,8,252,3,3,246,2,5,1,253,0,81,0,38,254,162,3,167,8,184,6,216,252,181,251,123,248,208,253,242,252,169,0,220,252,206,251,68,255,142,253,201,255,125,5,74,253,52,253,86,251,108,253,98,1,73,1,254,253,201,255,225,253,110,1,9,4,158,4,110,253,65,252,179,250,201,255,72,255,93,0,163,253,226,254,106,253,148,1,193,1,59,3,226,254,162,254,17,251,116,2,50,1,227,0,240,255,147,0,145,253,186,0,155,3,98,8,94,253,134,252,186,249,69,254,28,255,83,1,143,254,234,252,103,254,231,0,86,0,189,5,64,254,187,253,219,251,82,2,194,1,79,255,132,255,86,255,65,254,159,2,135,4,124,5,36,254,101,253,25,250,179,255,118,255,204,2,79,255,140,254,131,254,195,1,166,3,147,3,6,255,80,254,202,252,16,1,60,3,190,1,26,0,19,0,225,255,186,2,156,6,120,8,122,253,47,252,124,248,77,255,39,254,12,1,133,254,23,253,77,253,11,0,127,0,9,4,24,254,107,252,199,252,61,0,67,1,135,0,147,0,111,255,82,253,173,2,18,3,146,6,6,254,176,252,239,250,35,0,90,0,222,0,233,255,166,254,98,253,199,1,79,2,7,5,53,255,175,253,194,251,140,2,96,1,181,1,39,0,63,0,55,254,73,3,241,4,57,8,248,253,142,252,208,249,184,254,57,253,141,5,172,253,170,254,186,255,209,0,173,0,136,7,89,254,170,253,103,252,165,1,93,2,218,255,254,255,11,255,129,255,128,3,177,7,111,4,133,254,250,253,213,249,173,0,118,0,241,2,201,255,131,254,204,255,217,3,253,3,241,2,254,255,221,254,133,252,241,2,224,3,167,1,8,1,131,0,60,255,127,3,226,8,239,9,133,253,192,251,61,246,239,253,42,252,14,2,4,253,194,252,220,253,76,254,60,1,87,2,93,253,84,252,22,253,199,255,236,0,245,255,55,255,175,255,226,252,16,0,77,3,22,6,31,253,39,252,68,251,44,254,17,0,34,1,233,254,184,253,68,253,183,0,54,3,193,2,247,254,20,254,93,251,165,1,152,0,212,1,122,254,166,0,244,254,39,0,14,6,76,7,133,253,58,252,221,249,59,254,20,254,142,3,228,254,253,251,181,255,75,255,123,255,60,7,67,254,144,253,106,251,164,1,111,1,207,255,123,254,44,255,87,255,195,2,49,4,184,4,229,253,58,253,87,250,83,0,93,255,228,1,20,255,225,253,157,254,82,1,151,4,46,3,10,255,203,254,66,252,94,2,248,2,60,0,166,0,248,255,93,255,206,254,57,7,3,10,21,253,255,251,9,249,93,254,66,254,209,0,50,253,202,253,234,253,6,254,181,2,89,3,49,254,71,253,198,251,69,1,175,1,50,255,241,255,248,255,5,253,33,2,151,3,238,5,157,253,241,252,223,250,0,1,201,255,208,0,91,255,164,254,106,253,65,1,168,2,162,3,186,254,83,254,73,252,228,1,190,1,58,2,59,255,72,0,183,255,141,3,175,5,205,6,205,253,31,253,74,248,132,255,96,254,206,2,34,254,108,254,198,254,240,255,190,1,100,6,217,253,231,253,18,253,198,255,126,2,214,0,55,0,71,255,241,254,124,4,21,5,188,4,29,254,97,253,16,251,117,0,29,1,31,2,52,255,121,254,145,255,1,2,2,6,86,3,142,255,66,255,46,252,109,3,83,2,208,1,4,1,4,1,201,254,236,2,235,8,168,8,251,253,79,252,133,247,186,254,60,253,122,1,212,252,77,253,24,255,208,253,175,2,129,5,36,253,78,253,188,252,153,254,133,2,130,1,247,254,62,0,90,253,145,0,108,6,184,4,213,253,36,252,47,251,178,255,14,0,114,0,185,254,154,254,23,254,136,1,165,2,185,2,55,255,20,255,140,251,181,2,193,1,178,0,13,255,0,1,79,254,99,2,105,5,152,9,156,253,123,252,72,250,205,254,239,255,243,1,197,254,101,253,2,255,0,1,172,1,183,5,26,254,90,254,224,251,143,2,114,1,18,0,154,255,71,255,236,254,243,2,42,6,55,5,24,254,165,253,118,250,182,0,163,255,102,3,183,255,54,254,164,254,67,3,94,3,189,3,230,254,179,254,22,253,35,2,71,3,172,1,17,1,167,255,13,0,172,3,172,6,16,10,94,254,196,251,34,249,212,255,154,254,3,1,15,254,125,253,208,253,99,0,45,2,193,3,91,254,2,253,107,252,39,1,70,1,184,0,175,0,15,0,142,253,20,2,110,3,189,7,69,254,0,253,5,251,221,0,156,0,12,1,39,0,149,254,7,254,183,2,4,3,116,4,94,255,53,254,112,252,197,2,188,1,146,2,25,0,47,1,200,254,244,4,130,5,179,6,215,254,2,253,212,248,249,254,148,255,46,4,106,254,243,255,127,255,57,0,182,1,174,10,138,254,25,254,189,252,48,1,184,2,164,0,104,0,21,255,5,0,75,6,108,7,119,5,27,255,186,253,211,250,149,1,192,0,49,3,169,255,74,254,111,0,4,4,175,4,225,3,68,0,81,255,90,252,9,4,93,4,195,1,222,1,200,0,8,255,79,8,136,10,250,7,189,252,213,250,173,247,225,252,76,253,210,1,212,252,248,251,43,254,146,253,32,1,152,3,67,253,183,252,210,251,101,254,0,2,8,0,122,254,165,255,24,253,226,255,19,4,137,4,202,252,132,251,124,251,218,254,210,255,110,0,101,254,138,254,90,253,214,0,19,2,156,2,106,254,92,254,86,251,231,1,232,0,47,1,194,254,91,0,40,254,123,0,208,4,141,9,46,253,72,252,41,250,30,253,93,253,52,5,225,253,162,253,45,255,161,255,158,255,228,5,219,253,254,253,87,251,217,1,211,0,73,0,224,254,144,255,123,254,25,2,52,5,234,4,201,253,13,253,247,249,71,0,229,254,120,2,86,255,31,254,19,254,169,2,234,3,49,3,156,254,181,254,147,252,163,1,194,2,90,1,241,0,222,255,186,254,121,1,158,7,91,7,41,253,205,251,167,249,23,255,225,253,116,0,244,253,218,252,183,253,183,255,222,1,217,2,224,254,99,252,137,251,173,0,191,1,204,255,68,0,27,255,162,253,193,1,17,2,5,7,177,253,149,252,173,250,183,0,112,255,68,1,153,255,60,254,102,253,111,2,232,1,152,4,18,255,1,254,20,252,70,1,40,2,202,1,136,0,108,0,193,254,114,2,63,5,91,7,22,254,122,253,62,249,70,255,63,254,216,3,30,253,180,255,86,255,218,253,243,2,0,10,16,254,2,254,77,252,210,0,182,2,204,255,84,0,190,254,57,255,66,4,89,6,200,4,136,254,165,253,140,250,87,1,74,0,120,2,81,255,10,254,224,255,204,3,52,5,222,2,52,0,217,254,167,251,41,4,150,3,160,0,137,1,107,0,115,254,190,4,89,10,205,6,136,253,79,251,157,248,49,253,235,254,97,1,117,253,144,252,134,255,45,255,209,0,58,5,206,253,54,253,221,251,48,255,132,1,159,0,192,254,195,255,217,253,37,1,68,4,163,5,120,253,159,252,27,251,207,255,113,255,49,1,111,254,29,255,183,253,49,2,20,2,159,3,139,255,69,254,92,251,251,1,180,1,36,1,177,255,233,0,54,254,159,2,1,4,92,9,135,253,182,252,11,250,204,254,226,254,128,2,139,254,147,253,105,254,162,1,253,0,25,5,197,254,187,253,143,251,60,2,173,2,231,254,61,0,188,255,141,254,223,3,77,4,218,5,19,254,85,253,174,250,209,255,164,0,192,2,0,255,198,254,244,254,119,2,181,3,28,4,138,255,164,254,191,252,68,0,156,4,56,2,152,0,117,0,34,0,89,4,110,7,191,8,167,253,65,252,86,249,113,255,23,254,224,1,180,254,113,253,194,253,54,0,97,1,168,4,50,254,116,253,228,252,150,0,37,2,112,0,195,0,145,255,253,253,167,2,84,4,111,6,210,253,19,253,63,251,247,255,16,1,85,1,203,255,247,254,233,253,233,1,75,3,18,5,136,255,30,254,248,251,120,2,31,2,152,1,179,0,50,1,242,253,100,4,184,5,196,8,95,254,238,252,230,249,32,255,128,254,84,5,135,254,53,254,231,255,129,1,233,1,126,8,180,254,117,253,195,252,32,2,41,2,61,0,22,0,143,255,167,255,104,4,189,6,244,5,40,255,139,254,139,249,161,0,60,1,140,3,91,255,34,255,189,255,82,5,151,4,21,3,73,0,4,255,1,253,226,2,164,3,104,2,106,1,246,0,130,255,19,3,94,10,211,11,77,253,174,251,114,247,203,253,180,253,12,2,178,253,45,252,22,254,249,254,141,1,214,3,191,253,187,252,79,252,234,255,179,1,207,255,66,255,138,255,139,253,168,255,216,4,233,5,132,253,229,251,5,252,221,254,189,0,3,1,255,254,42,254,139,253,145,0,177,3,126,3,186,254,148,254,186,251,31,2,4,1,118,2,54,255,189,0,47,255,101,1,99,5,43,8,199,253,205,251,87,250,54,253,17,255,151,3,92,254,63,253,172,255,147,255,142,255,103,9,99,254,239,253,103,251,226,1,112,1,131,0,70,255,184,255,125,255,93,3,231,4,196,4,157,253,110,253,195,250,227,0,135,255,119,2,80,255,23,254,38,255,233,2,151,4,189,3,191,254,108,255,88,252,159,2,198,3,216,0,84,1,253,255,113,255,213,1,56,7,133,9,39,253,63,252,109,249,43,255,2,255,65,1,1,254,74,254,247,253,130,255,213,2,135,3,172,254,83,253,248,251,60,1,224,1,20,0,23,0,167,255,217,253,97,1,27,4,253,6,224,253,11,253,172,250,42,1,231,255,180,1,156,255,120,254,249,253,211,1,242,2,54,4,46,255,114,254,202,251,108,2,146,2,118,2,33,0,147,0,78,255,153,3,151,6,129,7,187,254,240,253,70,248,2,0,227,254,142,3,141,254,22,254,26,255,0,0,85,2,218,7,16,254,117,254,190,252,37,0,177,3,245,0,181,0,96,255,112,255,201,5,93,5,77,5,157,254,167,253,10,251,42,1,66,1,160,2,63,255,176,254,77,0,65,4,253,5,154,3,177,0,217,255,155,251,228,3,13,3,24,2,200,1,110,1,80,254,135,5,136,9,231,8,46,254,10,253,235,246,209,254,3,254,131,1,41,253,211,253,66,0,111,255,131,2,224,4,224,253,92,253,108,252,31,255,94,3,76,2,104,255,40,0,235,253,167,1,143,5,22,6,196,253,181,252,135,251,128,255,85,0,205,1,18,255,255,254,184,253,93,2,236,2,93,3,24,0,54,255,127,250,29,3,231,1,47,1,75,255,108,1,74,255,104,2,98,5,126,11,18,254,172,252,95,250,220,254,61,0,44,3,172,255,45,253,74,255,43,2,20,2,226,5,147,254,19,254,223,251,54,3,76,2,11,0,242,255,238,255,26,255,233,3,121,5,171,5,38,254,199,253,244,250,46,1,62,0,38,4,186,255,136,254,34,255,214,3,206,3,125,4,60,255,22,255,229,252,223,1,74,4,243,1,106,1,58,0,70,0,123,4,21,8,41,11,25,254,146,252,224,248,73,0,224,254,92,1,154,254,12,254,4,254,199,0,209,2,218,4,178,255,71,253,229,252,105,1,24,2,196,0,118,1,110,0,33,253,79,3,27,4,104,7,146,254,55,253,98,251,59,1,64,1,173,1,72,0,41,255,62,254,247,2,118,3,83,5,226,255,84,254,190,252,93,3,115,2,28,3,118,0,212,1,233,254,75,5,91,7,101,7,68,255,126,253,180,249,63,0,81,255,174,4,94,254,45,255,51,0,158,1,75,2,41,10,22,255,211,253,166,252,168,1,121,3,222,0,136,0,155,255,83,0,133,5,230,8,103,5,172,255,67,254,147,250,158,1,57,1,21,4,29,0,169,254,65,0,16,6,111,6,212,3,183,0,165,255,195,252,249,4,133,5,104,1,41,2,16,1,149,255,51,6,77,12,43,10,6,0,82,0,125,255,154,0,200,255,33,253,183,0,191,255,247,254,9,0,46,255,151,254,113,0,206,2,25,7,242,3,190,4,37,6,89,3,53,5,228,8,59,3,32,6,141,7,205,2,197,7,158,8,70,3,148,4,31,7,209,2,232,3,106,8,30,1,220,1,229,5,9,255,237,253,230,0,147,0,174,255,57,2,26,0,79,255,80,252,229,255,239,254,180,2,92,255,248,254,73,255,224,0,22,3,15,4,131,3,178,3,89,2,229,1,3,3,126,4,12,2,165,2,135,3,116,255,119,1,10,3,154,1,164,2,173,1,45,1,18,2,241,3,207,2,134,2,38,0,226,0,111,1,40,0,145,0,211,255,7,254,34,1,121,0,135,255,46,1,127,0,166,0,132,255,129,254,68,252,154,254,57,254,47,252,203,2,110,3,126,3,210,3,155,3,211,0,221,1,16,1,64,0,188,0,178,255,17,0,113,255,191,255,38,0,131,2,74,2,109,2,122,255,86,254,117,253,91,1,33,2,4,11,164,4,166,10,138,9,142,0,176,255,199,6,27,1,130,0,205,1,250,254,113,254,135,251,101,254,155,0,174,1,73,1,119,1,11,3,53,0,30,255,117,255,127,255,20,255,146,6,29,1,232,2,47,5,226,2,185,2,128,6,56,1,153,1,10,1,69,1,208,2,135,0,1,0,221,0,197,1,8,0,203,0,145,0,43,1,128,2,248,2,29,0,212,1,126,2,103,0,173,1,123,1,164,1,186,3,164,3,46,5,186,4,234,4,192,2,244,3,128,4,90,255,68,254,246,254,196,254,126,255,136,254,191,0,127,4,112,7,16,255,225,253,20,251,144,255,12,1,183,4,70,0,38,4,47,6,22,1,80,5,38,6,254,254,240,254,0,253,19,0,51,2,192,8,253,255,247,254,135,0,217,254,177,253,124,254,140,0,98,1,50,255,252,254,8,254,229,252,79,254,50,253,217,250,109,0,75,1,194,3,83,254,169,255,140,2,216,254,170,1,251,3,17,255,7,3,83,3,233,1,54,5,49,4,178,254,180,254,25,0,31,2,182,4,15,7,70,1,61,0,215,2,66,2,81,3,125,5,48,255,235,254,73,1,104,255,64,0,157,2,78,254,90,253,41,253,58,254,185,255,251,0,93,2,224,1,254,0,30,254,11,0,228,3,223,254,139,1,230,1,210,2,25,4,160,5,226,255,196,254,238,252,150,255,141,255,149,253,93,3,194,5,132,5,31,4,86,5,160,4,44,3,213,4,157,3,42,0,5,255,192,253,86,1,141,0,58,254,88,255,176,255,79,5,170,254,112,253,29,249,100,0,53,3,213,2,222,3,235,2,32,3,76,1,184,1,56,2,151,2,123,1,84,3,112,0,165,0,143,254,85,2,142,3,26,1,248,255,66,3,1,5,160,254,60,2,183,2,206,1,198,8,14,7,89,1,190,0,94,5,160,1,147,3,118,8,168,0,174,255,24,1,252,253,66,254,72,3,47,0,21,2,44,0,150,254,57,253,137,251,22,0,193,0,192,5,171,255,233,0,21,7,194,255,67,2,224,5,38,2,176,3,213,6,211,2,138,2,124,4,204,3,116,3,115,5,87,254,131,2,0,0,232,3,184,3,74,4,249,0,166,5,160,2,178,254,169,255,124,8,214,253,90,7,112,10,140,0,34,7,61,7,152,3,213,6,30,10,52,4,141,7,246,7,119,255,69,254,237,249,245,4,150,4,212,1,19,254,134,255,241,5,61,254,9,4,190,4,226,1,159,6,94,4,47,3,137,2,128,1,66,254,76,253,107,0,193,254,163,253,138,255,49,255,7,254,13,2,44,254,244,255,176,10,75,0,142,7,25,5,112,3,54,9,219,8,5,5,39,6,212,7,208,255,208,254,94,251,77,254,51,254,5,255,146,254,108,254,221,253,223,254,163,253,171,253,230,253,214,252,91,255,136,255,3,0,100,1,127,2,217,4,222,5,96,0,177,0,238,2,77,254,183,253,106,251,156,254,109,0,177,255,27,254,32,1,213,7,9,0,92,4,219,2,112,3,86,8,178,3,247,254,49,6,41,4,133,4,186,4,75,3,14,254,100,253,175,1,118,1,65,1,27,255,160,5,53,8,101,5,193,1,205,1,131,4,151,255,39,0,128,254,249,254,111,1,182,0,141,254,108,253,5,3,68,255,127,4,203,3,53,5,96,6,155,5,6,3,243,4,197,4,30,254,192,252,47,250,19,255,46,255,92,3,122,3,79,6,40,4,216,1,38,4,168,4,185,0,53,4,221,3,200,253,32,252,88,249,63,254,122,252,5,248,114,255,135,254,54,254,46,255,214,253,251,251,245,255,109,4,217,8,183,254,93,253,131,252,6,255,145,2,163,4,7,2,230,5,243,6,8,2,27,2,123,5,15,2,141,5,22,5,205,253,153,252,32,251,109,255,49,254,111,3,180,255,30,9,24,11,51,2,13,10,81,9,120,2,134,7,104,11,207,2,231,7,48,7,223,253,45,253,84,4,129,0,131,255,116,3,137,5,96,6,157,3,162,255,30,6,215,6,171,254,253,5,15,6,79,2,139,1,238,254,180,255,213,3,15,11,153,0,169,11,52,7,8,4,5,10,189,10,228,5,16,11,87,7,23,3,175,4,26,2,66,255,59,254,209,5,234,254,220,253,134,4,11,255,149,7,252,7,0,4,24,6,114,6,0,2,253,0,210,1,194,255,189,254,127,4,39,254,136,254,251,1,79,254,100,5,114,8,131,3,151,7,165,5,134,0,192,2,184,1,204,1,13,2,228,255,62,254,23,1,58,5,0,0,203,3,252,0,67,254,141,253,33,252,164,254,166,253,112,250,142,1,200,2,120,6,149,255,58,1,78,255,93,0,178,8,190,8,6,2,81,3,144,2,50,254,57,253,65,254,174,0,222,255,167,4,137,255,42,0,237,3,140,254,18,1,246,2,12,4,48,9,46,7,163,2,188,6,218,5,174,1,6,5,85,8,127,255,73,254,0,0,139,254,32,3,96,8,6,0,51,6,174,9,222,1,84,2,80,8,84,254,32,253,225,5,129,1,178,0,212,3,139,0,193,1,201,4,242,253,182,252,42,252,145,0,18,6,218,4,111,2,168,5,144,2,93,1,248,3,202,5,31,0,232,254,159,1,196,254,212,2,105,6,104,1,34,4,44,2,76,254,154,254,177,4,157,254,99,4,147,7,145,1,48,6,200,8,241,253,12,252,99,1,233,0,238,0,185,8,218,253,127,252,129,253,147,254,11,254,165,7,133,1,68,7,85,6,162,0,108,4,240,4,19,255,150,4,110,5,128,253,101,254,116,0,28,255,158,6,250,8,103,6,138,8,219,8,50,2,249,4,98,10,67,1,82,1,238,6,66,2,83,4,84,3,22,0,82,2,166,3,113,255,206,2,190,1,0,0,1,2,2,4,4,5,6,7,8,9,9,11,11,12,13,13,15,15,16,16,18,18,19,19,21,21,22,22,23,24,24,25,26,26,27,27,28,29,29,30,30,30,31,32,32,33,33,33,34,34,35,35,35,36,36,36,37,37,37,38,38,63,128,176,208,240,128,167,197,227,128,158,187,216,123,150,178,205,116,142,169,195,111,135,160,185], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+908440);
/* memory initializer */ allocate([105,128,152,175,100,122,144,166,95,116,137,158,90,110,130,150,85,104,123,142,81,99,117,135,77,94,111,128,73,89,105,122,69,85,100,116,66,80,95,110,62,76,90,104,59,72,86,99,56,69,81,94,53,65,77,89,51,62,73,85,48,59,69,80,46,56,66,76,43,53,63,72,41,50,59,69,39,48,56,65,37,45,54,62,35,43,51,59,33,41,48,56,32,39,46,53,30,37,43,50,29,35,41,48,27,33,39,45,26,31,37,43,24,30,35,41,23,28,33,39,22,27,32,37,21,26,30,35,20,24,29,33,19,23,27,31,18,22,26,30,17,21,25,28,16,20,23,27,15,19,22,25,14,18,21,24,14,17,20,23,13,16,19,22,12,15,18,21,12,14,17,20,11,14,16,19,11,13,15,18,10,12,15,17,10,12,14,16,9,11,13,15,9,11,12,14,8,10,12,14,8,9,11,13,7,9,11,12,7,9,10,12,7,8,10,11,6,8,9,11,6,7,9,10,6,7,8,9,2,2,2,2,255,255,39,186,255,255,187,58,254,255,49,187,255,255,145,59,255,255,202,187,255,255,228,59,255,255,176,187,0,0,0,0,1,128,39,60,1,192,209,188,255,159,57,61,1,48,138,189,0,48,183,61,5,96,221,189,2,16,247,61,0,20,96,63,2,16,247,61,5,96,221,189,0,48,183,61,1,48,138,189,255,159,57,61,1,192,209,188,1,128,39,60,0,0,0,0,255,255,176,187,255,255,228,59,255,255,202,187,255,255,145,59,254,255,49,187,255,255,187,58,255,255,39,186,0,0,0,0,128,187,0,0,0,119,1,0,68,172,0,0,0,125,0,0,104,247,184,249,218,251,199,253,136,255,82,1,95,3,85,6,223,249,160,252,216,254,200,0,158,2,127,4,173,6,81,9,171,246,5,249,49,251,51,253,17,255,234,0,2,3,194,5,164,250,38,254,133,0,120,2,76,4,35,6,27,8,112,10,125,245,117,247,4,249,101,250,162,251,187,252,197,253,196,254,197,255,201,0,214,1,247,2,53,4,177,5,116,7,191,9,203,248,223,251,246,253,179,255,45,1,135,2,207,3,5,5,46,6,81,7,115,8,148,9,175,10,201,11,227,12,241,13,59,242,33,243,247,243,182,244,120,245,49,246,232,246,155,247,69,248,231,248,134,249,38,250,195,250,92,251,248,251,148,252,47,253,207,253,118,254,28,255,202,255,119,0,40,1,228,1,171,2,127,3,99,4,93,5,115,6,173,7,56,9,38,11,237,243,174,246,177,248,111,250,3,252,119,253,196,254,236,255,11,1,32,2,42,3,41,4,25,5,254,5,220,6,178,7,123,8,55,9,232,9,140,10,38,11,180,11,61,12,191,12,58,13,171,13,19,14,117,14,205,14,30,15,107,15,180,15,151,253,190,0,34,3,203,5,55,240,78,240,98,240,119,240,142,240,166,240,190,240,217,240,244,240,15,241,45,241,76,241,109,241,141,241,174,241,209,241,246,241,29,242,71,242,116,242,164,242,212,242,7,243,60,243,116,243,175,243,238,243,51,244,128,244,209,244,44,245,140,245,251,245,115,246,232,246,102,247,232,247,107,248,240,248,132,249,28,250,188,250,95,251,30,252,226,252,168,253,138,254,146,255,152,0,191,1,208,2,214,3,205,4,176,5,146,6,124,7,82,8,49,9,35,10,37,11,46,12,35,13,4,14,230,14,96,187,36,0,168,15,35,0,32,0,0,0,3,0,0,0,0,0,0,0,0,64,127,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,130,36,0,168,15,35,0,32,0,0,0,3,0,0,0,0,0,0,0,0,64,127,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,104,36,0,184,76,36,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,152,104,36,0,184,53,36,0,0,13,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,80,216,35,0,56,191,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,112,168,35,0,160,146,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,16,124,35,0,232,101,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,160,83,35,0,72,231,34,0,40,0,0,0,3,0,0,0,57,180,200,118,190,159,230,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,0,49,35,0,72,231,34,0,40,0,0,0,3,0,0,0,57,180,200,118,190,159,230,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,128,214,34,0,136,199,34,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,112,183,34,0,136,199,34,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,29,40,0,112,0,0,0,160,7,14,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,0,72,0,110,0,150,0,190,0,233,0,20,1,67,1,114,1,166,1,217,1,18,2,75,2,138,2,202,2,18,3,90,3,172,3,255,3,97,4,195,4,59,5,178,5,76,6,229,6,188,7,147,8,253,9,103,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,255,226,11,174,4,26,2,78,1,172,0,58,0,226,255,226,11,174,4,26,2,78,1,172,0,58,0,226,255,196,255,240,37,21,0,136,10,14,0,112,38,21,0,0,0,0,0,221,255,221,255,153,244,109,247,27,249,78,250,61,251,1,252,166,252,54,253,181,253,39,254,142,254,236,254,66,255,146,255,103,11,147,8,229,6,178,5,195,4,255,3,90,3,202,2,75,2,217,1,114,1,20,1,190,0,110,0,35,0,221,255,0,0,0,0,205,204,204,63,0,0,128,63,205,204,76,63,61,10,23,63,0,0,0,63,61,10,215,62,123,20,174,62,92,143,66,62,174,71,225,61,143,194,117,61,41,92,15,61,227,165,155,60,88,57,52,60,244,253,212,59,111,18,131,59,10,215,35,59,52,128,183,58,23,183,81,58,250,237,235,57,82,73,157,57,7,66,50,57,172,197,167,56,172,197,39,56,172,197,167,55,172,197,39,55,172,197,167,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,63,195,245,168,62,0,0,128,62,231,251,41,62,0,0,0,62,231,251,169,61,0,0,128,61,0,0,0,61,36,151,127,60,243,1,1,60,31,132,128,59,3,65,0,59,117,31,128,58,174,14,0,58,248,7,128,57,248,7,0,57,154,2,128,56,154,2,0,56,154,2,128,55,156,252,255,54,154,2,128,54,5,244,255,53,226,0,128,53,229,250,255,52,229,250,127,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,237,221,221,221,221,255,255,255,255,191,255,254,237,221,204,222,239,255,255,255,254,237,220,203,203,187,204,222,239,255,254,237,220,187,170,170,170,187,221,255,255,254,220,187,169,153,153,153,171,205,239,254,236,203,169,136,135,120,137,171,205,255,254,203,169,135,119,102,119,137,171,222,253,220,170,135,118,101,102,103,137,188,239,221,186,152,118,85,85,86,120,154,205,237,220,169,135,101,84,69,86,121,172,221,221,202,152,101,84,68,85,103,154,189,222,235,169,135,101,68,85,102,137,171,221,237,202,152,118,85,85,86,120,154,204,222,252,186,135,118,101,102,119,137,187,221,254,219,169,135,118,103,119,137,171,205,223,239,203,169,136,135,136,137,171,204,237,255,237,203,169,153,153,153,170,188,222,239,255,253,219,186,170,170,171,204,222,253,255,255,253,220,204,188,204,220,222,239,239,255,255,255,222,221,205,221,238,255,254,223,255,255,239,221,221,221,221,221,253,176,0,0,0,189,205,204,204,204,204,205,239,255,255,207,254,220,220,204,187,204,204,222,239,255,238,221,204,203,186,170,187,188,221,255,220,221,203,186,169,153,154,154,188,223,255,189,219,186,153,136,136,136,154,188,239,221,204,186,152,135,119,119,137,154,188,221,204,186,152,135,118,102,103,120,154,204,220,203,169,135,102,101,102,103,136,171,204,204,169,135,102,85,85,86,103,137,188,204,202,152,118,101,85,85,102,120,154,204,187,169,135,102,85,85,86,103,137,172,188,202,152,118,101,85,85,102,120,154,188,204,185,135,102,85,85,86,119,137,171,205,203,169,135,102,102,102,103,137,171,189,223,202,152,135,118,102,119,137,154,188,207,221,170,152,135,119,119,136,154,188,221,255,220,186,153,136,136,137,154,171,188,223,255,220,186,170,153,153,170,187,204,221,255,255,236,187,186,170,171,187,220,223,223,255,253,238,204,188,187,204,221,206,254,207,255,221,221,205,220,203,189,205,221,176,0,0,0,189,221,204,204,204,204,205,221,239,255,221,238,221,205,204,204,204,205,223,255,255,222,221,204,187,187,186,187,205,222,255,253,221,204,186,170,153,154,170,188,222,255,205,203,186,153,152,136,137,154,188,223,237,204,186,152,136,119,119,136,154,188,222,204,186,153,135,118,102,103,120,154,205,220,203,169,135,118,101,86,103,137,171,204,204,186,152,118,85,85,86,103,137,188,204,202,152,118,101,85,85,86,120,154,204,204,185,135,101,85,69,86,103,137,172,204,203,152,118,101,85,85,102,120,155,204,204,186,135,118,85,85,86,120,153,188,205,203,169,135,102,102,102,119,137,171,204,221,203,152,135,118,102,119,137,155,188,206,237,186,152,135,119,120,137,154,188,220,238,220,186,153,136,136,153,154,188,205,207,254,221,187,170,153,154,170,188,204,220,255,254,220,203,187,187,187,188,205,222,223,255,255,237,204,204,204,204,221,222,253,223,255,237,221,220,204,204,204,204,221,176,0,0,0,189,205,220,204,204,204,205,223,255,255,221,255,223,236,204,220,205,221,223,255,255,238,204,204,187,187,187,172,204,239,239,253,221,204,187,170,153,154,171,188,223,255,221,203,186,153,152,136,137,154,188,221,252,219,186,169,136,119,119,136,154,188,237,188,186,169,135,118,102,103,136,154,189,221,203,169,135,102,101,86,103,137,172,206,204,186,152,118,85,85,86,103,138,188,220,219,169,118,101,85,85,86,120,170,204,204,185,135,102,85,69,85,103,137,188,204,219,168,118,101,85,85,102,120,155,204,204,186,151,102,85,85,86,120,154,188,207,220,169,135,102,101,102,119,137,171,204,253,203,168,135,118,102,119,137,171,188,207,253,203,153,135,119,120,137,170,204,204,255,220,186,169,152,136,153,154,188,221,207,254,221,187,170,169,170,170,187,189,220,255,255,221,188,187,187,187,204,205,254,207,255,253,253,221,220,204,204,221,222,254,207,255,221,205,221,204,205,204,205,205,176,0,0,0,191,238,221,221,205,221,221,239,255,255,222,255,253,237,221,204,221,239,255,255,255,254,239,221,204,203,187,204,222,255,255,254,253,220,187,170,170,170,187,205,223,255,255,220,186,169,153,137,153,171,205,255,253,221,202,169,136,135,120,137,171,205,255,222,203,169,135,118,102,119,137,171,223,254,220,169,135,118,101,86,103,137,172,239,237,202,152,118,85,85,86,120,154,205,237,219,169,118,101,84,85,86,121,171,206,221,186,135,102,84,68,85,103,154,189,221,219,169,134,101,84,85,102,121,171,205,221,202,152,118,85,85,86,120,154,205,223,252,185,135,102,101,102,119,137,188,221,255,220,169,135,118,102,119,137,171,205,223,255,203,169,136,135,120,137,171,188,237,255,253,203,169,153,153,153,171,188,223,239,255,237,203,186,170,170,171,204,205,237,255,255,253,220,203,188,204,205,222,239,239,255,255,255,237,222,221,222,221,223,255,191,255,239,223,237,220,221,221,222,237,176,0,0,0,172,203,186,170,170,170,170,171,188,205,188,220,204,187,170,170,170,171,187,205,221,188,203,186,169,153,153,153,170,171,205,219,203,170,169,152,136,136,153,154,187,204,187,186,153,136,136,136,136,137,154,187,186,186,153,136,119,119,119,120,137,154,187,171,169,136,119,118,102,103,120,137,171,170,169,152,119,118,102,102,103,120,153,170,170,152,135,118,102,102,102,103,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,102,101,85,86,103,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,118,102,102,102,119,136,154,170,169,152,119,102,102,102,119,120,153,170,186,169,136,119,118,102,119,120,137,171,171,186,153,136,119,119,119,136,137,170,186,188,186,153,136,136,136,136,137,154,171,188,203,186,153,152,136,137,153,154,171,203,204,203,186,169,153,153,153,170,187,204,189,221,203,187,170,170,170,171,187,204,220,189,204,187,170,170,170,170,171,187,204,160,0,0,0,155,187,170,170,154,154,170,171,187,205,187,204,187,186,170,170,170,170,187,205,220,188,187,170,153,153,153,153,154,187,205,202,187,170,153,152,136,136,153,154,171,203,171,170,153,136,136,119,136,137,154,171,186,186,153,136,119,119,119,120,137,154,186,170,169,136,119,118,102,103,120,137,170,170,169,152,119,118,102,102,103,120,137,170,170,152,135,118,102,102,102,103,136,154,169,169,136,118,102,101,102,102,119,137,170,170,152,119,102,101,85,102,103,120,154,153,169,136,118,102,101,102,102,120,137,169,170,152,135,118,102,102,102,119,136,154,170,169,136,119,102,102,102,119,120,137,170,171,169,136,119,102,102,119,120,137,170,171,186,153,136,119,119,119,120,137,154,170,187,186,153,136,135,120,136,137,154,171,171,203,170,153,152,136,136,153,154,171,186,204,203,170,169,153,153,153,154,171,188,189,220,204,186,170,170,170,170,187,188,219,189,204,186,170,169,153,170,170,171,187,144,0,0,0,155,187,170,169,153,153,154,170,187,204,187,220,187,170,170,153,154,170,187,188,221,188,187,170,153,153,153,153,154,171,188,203,187,170,153,136,136,136,137,153,171,187,171,170,153,136,135,119,120,136,153,171,186,170,153,136,119,119,119,119,136,154,170,170,153,136,119,118,102,103,119,137,154,170,169,136,119,118,102,102,103,120,137,170,154,152,135,118,102,102,102,119,120,153,153,153,135,118,102,102,102,102,119,137,153,153,152,119,102,102,102,102,103,120,153,153,169,135,118,102,102,102,102,119,137,153,154,152,135,118,102,102,102,119,136,154,154,169,136,119,102,102,102,119,120,137,169,170,153,136,119,118,102,119,120,137,154,170,170,152,135,119,119,119,120,137,154,186,187,170,152,136,135,119,136,137,154,171,171,187,169,153,136,136,136,137,154,171,187,204,187,170,153,153,153,153,154,171,188,188,220,187,186,170,153,170,170,187,188,203,188,203,186,170,153,153,153,170,170,187,160,0,0,0,155,187,170,169,153,153,170,171,187,205,187,204,203,186,170,170,170,170,187,188,220,188,187,170,169,153,153,153,154,187,188,203,187,170,153,152,136,136,137,154,171,203,171,170,153,136,136,120,136,136,154,171,186,186,153,136,119,119,119,120,137,154,187,170,169,136,119,119,102,119,120,137,154,170,169,152,119,118,102,102,103,120,137,170,170,152,135,118,102,102,102,103,136,154,153,169,136,118,102,101,102,102,119,137,169,154,152,119,102,101,85,102,103,136,154,153,169,136,118,102,85,102,102,120,137,169,170,152,135,118,102,102,102,119,136,154,154,169,136,119,102,102,102,119,120,153,170,170,169,136,119,118,102,119,120,137,170,170,186,153,136,119,119,119,120,137,154,186,187,170,153,136,135,119,136,137,154,171,171,187,170,153,152,136,136,153,154,171,203,205,203,170,169,153,153,153,154,171,188,189,220,203,186,170,170,170,170,187,188,219,188,203,186,170,154,153,153,170,170,187,144,0,0,0,172,187,186,170,170,170,170,171,188,221,204,220,203,186,170,170,170,170,187,205,237,188,203,170,169,153,153,153,170,187,205,203,203,170,153,152,136,136,153,154,187,204,187,170,153,136,136,120,136,137,154,188,186,186,153,136,119,119,119,120,137,170,187,170,169,136,119,118,102,119,120,137,170,186,169,152,119,102,102,102,103,120,153,170,170,152,135,118,102,102,102,119,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,102,101,85,102,103,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,118,102,102,102,119,136,154,170,169,152,119,102,102,102,103,120,153,170,171,169,136,119,118,102,119,120,137,170,171,186,153,136,119,119,119,120,137,154,186,188,186,153,136,136,120,136,137,154,187,188,203,186,169,152,136,136,153,154,171,203,221,203,186,169,153,153,153,170,187,204,205,237,203,187,170,170,170,171,187,204,220,189,220,187,170,170,170,170,170,187,188,160,0,0,0,191,238,221,221,221,222,238,255,255,255,191,255,254,237,221,221,222,255,255,255,255,239,254,221,204,203,188,205,222,255,255,254,254,220,203,186,170,171,188,221,255,255,238,221,187,169,153,153,154,188,222,255,253,220,187,169,136,119,136,153,172,223,255,221,203,169,135,118,102,120,138,188,239,253,220,185,135,102,85,86,120,154,205,255,221,186,152,118,85,69,86,120,171,222,253,219,169,118,85,68,69,103,137,188,239,237,186,151,101,68,68,86,120,155,205,238,220,169,134,85,68,85,103,137,188,221,238,203,152,118,85,85,102,120,171,206,239,253,186,152,118,102,102,120,154,205,238,255,220,186,136,119,119,120,154,188,223,239,255,220,186,152,136,137,154,188,205,239,255,254,220,186,169,153,170,187,205,239,239,255,254,220,203,187,187,188,221,239,254,255,255,254,221,220,204,205,221,223,255,255,255,255,255,254,239,238,238,255,255,255,207,255,255,255,254,237,222,238,239,239,176,0,0,0,173,205,203,188,203,204,205,221,222,239,189,222,221,204,204,204,220,221,255,255,255,221,221,203,187,187,187,187,221,239,239,221,220,204,187,170,169,170,187,204,255,254,205,204,170,153,152,136,153,171,206,254,204,203,186,152,136,119,119,137,171,205,254,205,187,153,135,118,102,119,137,172,222,220,219,169,135,102,85,86,103,138,188,253,204,186,152,118,85,85,86,120,155,205,220,203,153,118,85,68,69,103,137,171,221,204,186,135,101,84,68,86,120,154,205,220,203,168,118,101,84,85,103,137,171,220,205,186,152,118,85,85,102,120,154,189,205,236,185,135,118,102,102,120,154,187,220,222,203,169,135,119,119,120,137,171,205,206,253,203,169,152,136,136,153,171,204,221,239,253,219,170,153,153,154,171,204,221,223,253,253,204,187,170,170,187,188,221,252,239,239,237,221,204,188,188,204,237,238,223,255,255,253,237,220,220,221,221,221,237,190,221,221,221,220,220,205,204,204,221,176,0,0,0,189,221,220,204,204,204,205,221,239,255,221,254,221,204,204,203,204,221,222,255,255,222,221,203,186,170,170,187,205,222,255,253,221,203,170,169,153,153,171,188,239,255,205,203,170,152,136,136,137,154,188,222,236,203,170,152,135,119,119,136,154,188,238,204,186,152,119,102,102,103,137,171,205,236,202,153,135,102,85,86,103,137,171,221,203,169,135,102,85,85,86,120,154,189,220,186,152,118,85,85,85,102,120,171,205,203,169,135,101,85,69,86,103,138,188,204,202,152,118,85,85,85,103,121,171,204,204,185,135,118,85,85,102,120,154,188,221,203,169,135,102,102,102,119,137,171,204,221,203,153,135,118,103,119,137,171,205,222,221,186,153,136,119,136,137,170,188,221,239,220,186,169,152,136,153,170,188,221,223,255,220,203,170,170,170,171,188,205,237,255,254,220,204,187,187,187,204,205,239,239,255,255,237,220,204,204,205,222,238,254,223,255,254,237,221,220,205,221,221,238,192,0,0,0,190,221,204,204,204,204,205,221,239,239,205,253,237,204,204,204,204,221,238,255,255,222,220,203,187,186,171,187,204,221,255,253,221,203,170,169,153,154,171,188,222,254,205,203,186,153,136,136,137,170,189,239,220,220,170,152,135,119,119,137,154,205,253,204,186,152,119,102,102,119,137,171,205,220,203,169,135,102,85,86,103,137,172,221,204,185,135,102,85,85,86,120,154,189,204,202,152,118,85,84,85,103,121,171,221,203,169,135,101,84,69,86,103,138,188,204,203,152,118,85,85,85,103,137,171,204,204,186,151,118,85,85,102,120,154,188,205,219,169,135,102,102,102,119,137,171,220,221,203,169,135,119,119,120,137,171,205,221,237,186,169,136,119,136,137,155,188,221,222,220,187,169,153,153,153,171,188,206,207,254,220,203,170,170,170,171,188,221,237,255,238,237,203,187,187,187,204,206,238,223,255,255,237,221,220,204,205,221,254,254,191,254,221,221,205,204,221,204,221,238,176,0,0,0,191,255,254,238,238,222,255,255,255,255,207,255,255,238,221,221,238,255,255,255,255,255,254,237,204,203,204,205,223,255,255,255,254,220,203,186,170,171,188,223,255,255,238,220,187,169,153,153,154,188,223,255,254,237,203,169,136,119,136,154,188,223,255,238,203,169,135,118,102,120,138,188,239,253,220,185,135,102,85,86,120,154,205,255,221,202,152,118,85,69,86,120,171,223,254,220,169,118,85,68,69,103,137,188,239,237,202,151,101,68,68,86,120,155,206,238,220,169,118,85,68,85,103,137,188,238,238,203,152,118,85,85,102,120,171,206,239,253,186,152,118,102,102,120,154,189,239,255,236,185,152,119,119,120,154,188,223,255,255,220,186,152,136,136,154,187,222,255,255,254,220,186,169,153,170,187,205,255,255,255,254,236,203,187,187,188,205,239,255,255,255,255,237,220,204,205,222,255,255,255,255,255,255,254,238,238,255,255,255,255,191,255,255,255,255,255,238,255,255,255,192,0,0,0,172,187,187,170,170,170,187,188,205,222,188,221,203,187,186,170,187,187,204,221,237,204,203,186,170,169,153,170,187,204,222,219,203,186,169,153,153,153,154,171,205,220,188,186,169,152,136,136,136,153,171,205,203,186,169,136,119,119,119,136,154,171,204,171,169,136,119,102,102,103,120,154,188,202,186,152,119,102,102,102,103,137,154,187,170,169,135,102,85,85,102,119,137,171,186,169,152,118,101,85,85,102,120,154,187,170,153,135,102,85,85,86,103,137,171,187,169,152,118,101,85,85,103,120,154,187,187,169,135,102,101,85,102,120,137,171,187,186,152,135,102,102,102,119,137,170,187,187,170,152,135,119,103,119,136,154,187,188,203,169,152,135,119,120,136,154,171,203,204,203,170,153,136,136,137,154,171,188,189,220,203,170,153,153,153,154,171,188,220,222,237,203,186,170,170,170,187,188,205,205,238,221,204,187,187,187,187,204,221,220,174,221,204,187,187,187,187,187,188,204,160,0,0,0,155,186,170,170,169,170,170,187,188,220,171,203,187,170,170,170,170,171,188,205,237,187,187,170,153,153,153,153,170,188,205,218,186,170,153,152,136,136,153,170,188,204,171,170,153,136,135,119,136,137,170,188,202,186,153,136,119,119,119,136,137,171,187,170,153,136,119,102,102,119,120,137,171,186,169,152,119,102,102,102,103,136,154,186,154,152,135,102,102,86,102,119,137,171,170,169,135,118,101,85,86,102,120,153,170,170,152,119,102,85,85,102,103,137,154,170,169,136,118,102,85,86,103,120,154,170,170,153,135,102,102,102,102,119,137,154,170,169,152,119,102,102,102,119,136,154,186,187,169,136,119,118,103,119,136,153,171,171,186,169,136,135,119,119,136,137,170,186,187,186,169,136,136,136,136,153,170,187,172,219,186,169,153,153,153,153,170,187,203,205,204,187,170,169,153,154,170,187,204,188,237,220,187,186,170,170,186,187,204,204,172,204,203,187,170,170,170,170,187,187,160,0,0,0,155,186,170,153,153,153,153,170,187,204,187,204,186,170,169,153,154,170,187,204,220,187,186,170,153,153,153,153,154,171,204,202,186,169,153,136,136,136,137,154,171,203,171,169,152,136,119,119,136,137,154,171,186,170,152,136,119,119,119,120,137,154,186,154,153,135,119,102,102,103,120,137,170,169,169,136,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,153,135,118,102,85,102,102,120,137,169,153,152,119,102,101,86,102,119,136,154,153,153,135,118,102,102,102,103,120,137,169,153,152,119,118,102,102,102,119,136,154,170,169,136,119,102,102,102,119,136,153,170,170,153,136,119,119,103,119,120,137,170,170,186,153,136,119,119,119,136,137,154,186,171,170,153,136,136,136,136,137,154,171,171,187,170,153,152,136,136,153,154,171,187,204,203,170,169,153,153,153,170,171,188,188,220,203,186,170,170,170,170,187,204,203,188,203,187,170,170,153,154,170,171,187,144,0,0,0,155,187,170,170,169,170,170,171,187,204,171,220,187,186,170,170,170,171,187,204,236,188,187,170,169,153,153,153,171,188,205,203,187,170,153,136,136,136,153,170,188,204,171,170,153,136,136,120,136,137,170,188,186,186,153,136,119,119,119,120,137,170,187,170,169,136,119,102,102,119,120,153,171,170,169,136,119,102,102,102,103,136,154,186,154,152,135,102,101,85,102,119,137,170,169,169,135,118,101,85,86,102,120,153,170,170,152,119,102,85,85,102,103,137,154,170,169,136,118,102,85,86,103,120,153,170,170,153,135,102,102,102,102,119,137,171,170,170,152,119,118,102,102,119,136,154,186,171,169,136,119,119,119,119,136,153,171,171,186,169,136,135,119,119,136,153,171,186,188,186,169,152,136,136,136,153,170,187,187,203,186,169,153,152,153,153,170,187,203,205,203,186,170,170,153,154,170,187,205,205,237,220,187,187,170,170,171,188,205,220,172,204,187,186,170,170,170,170,187,188,160,0,0,0,172,187,187,170,170,170,187,187,204,206,172,221,203,187,170,170,171,187,204,222,254,188,203,186,170,153,154,170,171,204,222,219,203,186,169,153,152,153,154,171,204,221,187,186,153,136,136,136,136,153,171,205,203,186,169,136,119,119,119,136,153,171,204,171,169,136,119,102,102,103,120,154,188,202,170,152,119,102,101,102,103,136,154,187,170,169,135,102,85,85,102,119,137,171,186,169,136,118,101,85,85,103,120,154,187,170,153,135,102,85,85,86,119,137,171,186,170,152,118,101,85,85,103,120,154,187,187,169,135,118,101,85,102,120,137,171,187,186,152,135,102,102,102,119,137,154,187,187,170,152,135,119,119,119,136,154,187,188,203,169,152,135,119,120,136,154,171,203,204,203,169,153,136,136,137,153,171,188,189,220,203,170,153,153,153,154,171,188,220,222,220,203,186,170,170,170,171,188,205,206,254,220,204,187,187,187,187,204,205,236,190,220,204,203,187,187,187,187,188,204,160,0,0,0,206,237,222,221,221,238,239,255,255,255,190,255,238,221,221,221,222,255,255,255,255,239,237,220,204,188,204,205,238,255,255,253,237,204,187,170,170,171,188,223,255,255,221,220,186,153,152,153,154,188,223,255,253,220,186,152,135,119,136,154,188,239,255,221,203,152,135,102,102,120,154,189,239,253,220,169,135,102,85,102,120,155,205,255,221,186,151,102,84,69,86,121,172,222,254,219,169,118,85,68,69,103,138,189,255,221,202,151,101,68,68,86,120,171,206,238,220,169,135,101,68,85,103,138,189,239,238,203,152,118,85,85,102,121,171,222,239,237,186,152,118,102,103,120,154,189,254,239,236,186,152,119,119,120,154,188,222,239,255,220,186,153,136,137,154,171,205,238,255,254,220,187,170,170,170,187,205,239,239,255,255,220,204,187,187,188,205,222,255,255,255,255,237,221,205,205,221,223,255,239,255,255,255,254,254,238,239,255,255,255,191,255,255,255,238,238,238,239,239,255,192,0,0,0,206,221,221,204,204,205,221,238,239,255,206,254,221,220,204,204,204,205,238,255,255,223,237,203,186,170,170,187,204,223,255,254,237,203,170,153,153,153,171,205,223,255,221,203,169,152,136,136,137,154,188,239,253,219,185,152,119,119,119,137,171,205,254,220,186,152,119,102,102,103,137,171,205,252,203,152,119,102,85,86,103,137,172,222,203,169,135,102,85,85,86,120,154,189,220,202,152,118,85,84,85,103,121,171,205,220,169,135,101,84,69,86,120,154,189,220,202,152,118,85,85,85,103,137,171,205,220,186,135,102,85,85,102,120,154,204,221,219,169,135,102,102,102,120,137,188,221,237,203,169,135,119,119,120,137,171,206,222,236,186,169,136,136,136,137,171,205,238,255,236,187,169,153,153,153,171,204,223,239,255,220,203,186,170,170,171,189,222,255,255,255,237,204,203,187,204,204,223,255,255,255,255,238,221,220,221,221,238,255,255,191,255,255,239,237,221,221,223,255,255,208,0,0,0,206,237,220,204,204,204,205,221,239,255,206,254,221,204,187,187,188,205,222,255,255,238,221,203,186,170,170,171,204,222,255,253,220,203,170,153,153,153,170,188,222,255,221,203,169,152,136,136,137,154,188,223,237,203,169,136,119,119,119,136,154,188,238,204,186,152,118,102,102,103,137,155,205,236,186,152,118,102,85,86,103,137,171,221,203,169,135,102,85,85,86,120,154,188,220,186,152,118,85,85,85,103,120,171,205,203,169,135,101,85,85,86,103,138,188,220,186,152,118,85,85,85,103,120,171,205,204,169,135,102,85,85,102,120,154,188,221,203,169,135,102,102,102,119,137,171,205,221,202,152,135,119,103,119,137,171,205,222,236,186,153,136,119,120,137,170,188,221,238,220,186,169,152,137,153,170,188,222,239,254,220,187,170,170,170,171,204,222,254,255,254,237,203,187,187,187,204,222,255,239,255,255,237,220,204,204,221,222,255,255,223,255,238,221,221,205,221,222,238,255,208,0,0,0,189,220,220,204,188,204,205,221,222,238,190,254,221,204,203,187,204,205,238,255,255,222,220,203,186,170,170,187,204,239,255,253,221,203,170,153,153,154,171,204,222,254,205,203,170,152,136,136,137,170,204,238,236,203,169,152,119,119,119,137,171,205,237,204,186,152,119,102,102,119,137,171,206,220,186,152,119,102,85,86,119,138,172,221,203,169,135,102,85,85,86,120,154,189,220,186,152,118,85,68,85,103,137,171,204,203,169,135,101,84,69,86,120,154,188,220,202,152,118,85,85,85,103,137,171,220,204,186,135,118,85,85,102,120,154,188,220,203,169,135,118,102,102,120,153,172,220,221,203,169,135,119,119,120,137,171,205,221,236,202,169,136,136,136,137,171,188,221,222,220,203,169,153,153,153,171,188,222,222,254,221,203,186,170,170,171,188,222,221,239,238,221,204,187,187,188,204,222,239,239,255,254,238,221,205,205,205,221,255,254,206,237,238,221,221,204,221,205,222,222,192,0,0,0,190,238,237,221,221,221,221,238,239,255,190,255,254,221,220,205,221,238,255,255,255,239,237,220,203,187,187,204,221,255,255,253,238,204,187,170,170,170,188,222,255,255,221,220,186,153,152,137,154,171,221,255,253,220,186,152,135,119,120,153,172,222,255,221,203,152,135,102,102,120,154,188,223,237,220,169,135,102,85,86,120,154,189,238,220,186,151,102,85,69,86,120,171,206,237,219,168,118,85,68,69,103,137,188,222,220,186,135,101,84,68,86,120,155,206,221,219,169,118,101,68,85,103,137,188,222,221,202,152,118,85,85,102,120,171,221,238,236,186,152,118,102,103,120,154,189,238,239,220,185,152,119,119,120,154,188,222,238,254,219,170,152,136,136,154,171,206,254,255,237,219,186,170,153,170,187,205,239,239,255,254,220,187,187,187,188,205,239,254,255,255,254,237,204,204,204,221,239,255,255,255,255,255,238,222,222,238,239,255,255,191,255,254,238,237,222,237,222,238,254,192,0,0,0,172,204,187,187,187,187,187,204,221,238,188,221,204,187,187,187,187,188,205,238,254,205,203,186,170,170,170,170,187,205,238,236,203,186,169,153,153,153,154,187,205,237,188,186,153,136,136,136,137,154,187,205,219,186,169,136,119,119,119,136,154,188,221,187,169,136,119,102,102,119,136,154,188,203,186,152,119,102,85,102,119,137,171,204,187,169,135,102,85,85,102,120,154,188,203,169,152,118,101,68,85,103,120,154,187,187,169,135,102,84,69,86,119,137,171,187,186,152,118,101,85,86,103,120,154,187,187,169,135,118,101,86,102,120,153,171,187,186,153,135,118,102,102,119,137,171,204,204,186,152,135,119,119,119,137,154,188,204,203,186,153,136,135,136,136,154,171,204,221,203,186,153,152,136,153,154,171,205,205,237,203,186,170,153,153,170,171,204,220,223,237,204,187,186,170,171,187,204,221,222,254,237,220,203,187,187,204,205,222,253,174,221,221,204,203,187,187,204,204,221,176,0,0,0,171,186,170,153,153,153,154,170,187,204,187,204,186,170,169,153,154,170,187,204,221,188,186,169,153,153,153,153,170,187,204,202,186,169,152,136,136,136,137,154,187,203,171,169,152,136,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,154,187,154,152,135,119,102,102,119,120,137,170,169,169,136,119,102,102,102,103,120,154,170,153,152,119,102,102,102,102,119,137,154,169,153,135,118,102,85,86,103,120,137,170,153,152,119,102,101,86,102,119,136,154,169,153,135,118,102,85,102,103,120,137,170,154,152,119,102,102,102,102,119,137,154,170,169,136,119,102,102,102,119,136,154,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,137,170,187,187,170,153,136,136,136,136,153,170,187,187,203,170,153,153,136,137,153,170,187,203,204,203,186,169,153,153,153,170,187,204,204,220,203,187,170,170,170,171,187,205,220,173,204,187,170,170,170,170,170,187,188,176,0,0,0,155,170,169,153,153,153,153,170,171,188,171,203,186,169,153,153,153,170,171,188,220,171,170,169,153,136,136,153,154,171,188,202,186,153,152,136,136,136,137,154,171,187,170,169,136,135,119,119,120,136,154,171,185,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,119,120,137,170,169,153,135,119,102,102,102,103,120,153,170,153,136,119,102,102,102,102,119,136,154,169,152,135,118,102,102,102,103,120,137,169,153,136,119,102,102,86,102,119,136,154,153,152,135,118,102,102,102,103,120,137,169,153,152,119,102,102,102,102,119,136,154,153,169,136,119,102,102,102,119,120,153,170,170,153,136,119,119,119,119,120,137,170,170,170,152,136,119,119,119,136,137,154,186,171,170,153,136,136,136,136,137,154,171,171,187,170,153,152,136,136,153,154,171,203,188,187,170,153,153,153,153,170,171,188,188,220,203,186,170,170,170,170,187,204,204,188,203,186,170,153,153,154,170,187,188,160,0,0,0,155,187,170,169,153,153,170,171,187,188,171,220,187,170,170,154,170,170,187,205,220,188,187,170,153,153,153,153,170,187,205,202,187,169,152,136,136,136,153,154,171,204,171,169,152,136,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,170,187,170,153,135,119,102,102,119,120,137,171,170,169,136,119,102,102,102,103,136,154,170,154,152,135,102,102,86,102,119,136,154,169,169,135,118,102,85,86,103,120,137,170,154,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,170,152,135,102,102,102,102,119,137,154,170,169,152,119,102,102,102,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,153,171,187,187,186,153,136,136,136,136,153,170,187,187,203,170,169,153,137,153,153,170,187,203,204,203,186,170,153,153,170,170,187,204,205,221,204,187,170,170,170,187,188,205,220,173,203,187,170,170,170,170,170,187,204,160,0,0,0,172,204,187,187,171,171,187,188,204,221,172,221,204,187,187,186,187,188,205,222,253,205,203,186,170,169,170,170,188,205,222,219,204,186,169,153,153,153,154,187,205,237,188,186,153,136,136,136,137,154,171,205,203,186,169,136,119,119,119,136,154,187,220,187,169,136,119,102,102,119,136,154,188,203,186,152,119,102,85,102,119,137,171,204,170,169,135,102,85,85,102,120,153,171,186,170,152,118,101,68,85,103,136,154,187,187,169,135,102,84,69,86,119,137,171,187,186,152,118,101,85,86,103,136,154,187,187,169,135,118,101,86,102,120,153,171,187,186,153,135,118,102,102,119,137,171,203,204,186,152,135,119,119,119,137,154,188,204,203,186,152,136,135,136,137,154,172,204,205,203,186,153,152,136,153,154,171,205,205,221,203,186,170,153,153,170,187,204,220,222,221,204,187,170,170,170,187,204,222,221,254,237,220,203,187,187,204,204,221,237,189,237,220,204,187,187,187,204,204,221,176,0,0,0,207,255,255,239,238,255,255,255,255,255,207,255,255,254,238,238,239,255,255,255,255,255,255,238,221,220,205,222,255,255,255,255,255,237,204,187,187,188,206,239,255,255,255,253,203,170,153,154,171,205,255,255,255,254,203,169,136,136,137,171,205,255,255,239,220,169,135,119,119,136,171,206,255,254,237,186,135,102,85,102,121,172,223,255,255,203,152,118,84,69,103,138,188,255,255,236,185,134,84,51,69,104,155,222,255,254,219,152,117,67,52,86,137,188,239,255,237,186,135,101,68,85,120,155,206,255,255,220,169,134,101,85,103,138,188,239,255,254,219,168,135,102,119,137,172,223,255,255,237,203,169,136,136,137,171,205,255,255,255,237,203,169,153,154,171,205,239,255,255,255,237,204,187,187,187,205,223,255,255,255,255,254,221,204,204,221,239,255,255,255,255,255,255,253,238,238,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,192,0,0,0,206,221,204,204,204,188,220,221,238,255,189,253,220,204,187,187,188,205,222,255,255,222,220,203,186,170,171,187,204,222,255,237,220,187,170,153,153,153,171,188,221,238,204,203,169,152,136,136,137,154,188,223,236,203,169,152,119,119,119,137,155,205,253,204,186,152,119,102,102,119,137,171,205,220,203,152,119,102,85,86,103,137,188,221,203,169,135,102,85,85,86,120,154,205,220,202,152,118,85,68,85,103,137,171,220,203,169,135,101,84,69,86,120,154,189,204,202,152,118,85,85,85,103,137,171,205,204,185,135,118,85,85,102,120,154,189,221,219,169,135,118,102,103,120,154,187,221,221,203,169,135,119,119,120,137,171,205,221,236,186,169,136,136,136,153,170,204,238,238,220,187,169,153,153,154,171,204,222,238,254,220,187,186,170,170,187,204,221,238,255,254,221,204,188,187,188,205,222,239,239,255,254,237,221,205,204,206,222,254,254,175,254,238,221,221,205,221,222,238,255,208,0,0,0,222,237,220,204,204,204,204,221,239,255,206,254,221,204,187,187,188,205,222,255,255,238,220,203,170,170,170,171,188,222,255,253,220,187,169,153,153,153,170,188,222,255,221,203,169,152,136,136,137,154,188,222,236,203,169,136,119,119,119,136,154,188,222,204,169,136,118,102,102,103,137,171,205,220,186,152,118,101,85,86,103,137,171,221,203,169,135,101,85,85,86,120,154,188,220,186,152,118,85,85,85,103,121,171,205,203,169,135,101,85,85,86,119,138,188,220,186,152,118,85,85,85,103,137,171,205,204,169,135,102,85,85,102,120,154,188,220,203,169,135,102,102,102,120,137,171,221,221,186,152,135,119,119,120,137,171,205,221,220,186,153,136,119,136,137,171,205,238,238,220,186,169,152,137,153,170,188,222,238,254,220,187,170,170,170,171,204,222,255,255,254,221,203,187,187,187,205,222,239,255,255,255,237,220,204,205,221,238,255,255,207,255,254,221,221,221,221,222,238,255,208,0,0,0,223,253,221,204,204,204,205,238,255,255,191,254,237,204,204,187,204,221,223,255,255,254,237,203,186,170,170,187,204,239,255,253,237,203,170,153,153,153,171,188,222,255,221,203,169,152,136,136,137,170,189,223,253,219,169,152,119,119,119,137,155,205,255,204,186,152,118,102,102,119,137,171,205,236,187,152,119,101,85,86,103,137,188,222,203,169,135,101,85,85,86,120,154,189,220,202,152,118,85,84,85,103,137,171,205,203,169,135,101,85,69,86,120,154,189,220,202,152,118,85,85,85,103,137,171,221,220,169,135,102,85,85,102,120,154,189,221,203,169,135,102,102,102,120,153,188,221,221,202,153,135,119,119,120,137,171,205,238,236,186,153,136,136,136,137,171,205,221,255,220,186,169,153,153,153,171,188,222,255,255,221,203,186,170,170,187,205,222,255,255,254,237,204,203,187,188,205,238,239,255,255,255,254,221,220,221,221,238,255,255,207,255,254,238,221,221,221,222,239,255,208,0,0,0,207,238,238,221,222,222,238,238,254,239,175,255,254,237,221,221,222,239,255,255,255,239,254,220,204,203,188,205,222,255,255,254,254,220,187,170,170,171,204,222,255,255,238,220,186,169,153,153,154,188,222,255,254,236,186,153,135,119,136,154,188,223,255,237,203,169,135,102,102,120,154,189,239,253,220,169,135,101,85,102,120,155,205,255,221,186,152,102,84,69,86,137,172,222,237,219,169,118,84,68,69,103,154,189,238,237,186,151,101,68,68,86,120,171,222,254,220,169,135,101,68,85,103,154,189,238,237,203,152,118,85,85,103,137,172,222,238,237,186,152,118,102,103,120,155,205,254,255,220,186,152,135,119,136,154,188,223,255,254,220,186,153,152,153,154,188,223,255,255,254,220,187,170,170,171,188,222,255,255,255,254,221,204,187,187,204,221,239,255,255,255,254,238,221,220,221,222,255,255,255,255,255,255,238,238,238,239,255,255,255,207,255,255,255,254,238,238,255,255,255,192,0,0,0,188,204,187,186,170,170,187,188,205,222,188,220,203,187,170,170,171,187,205,222,254,204,203,186,170,153,153,170,187,204,222,235,203,170,153,152,136,153,154,171,205,221,187,186,153,136,136,136,136,154,171,205,219,186,153,136,119,119,119,136,154,171,204,171,169,136,119,102,102,119,136,154,188,202,170,152,119,102,102,102,119,137,171,204,170,153,135,102,85,85,102,120,137,171,186,169,136,118,101,68,85,103,136,154,187,170,152,135,102,84,69,86,119,137,171,187,169,152,118,101,85,86,103,136,154,187,187,169,135,118,101,86,102,120,153,171,187,186,152,135,118,102,103,119,137,170,187,187,186,152,135,119,119,119,137,154,188,204,203,170,152,136,135,136,137,154,187,204,205,203,170,153,136,136,153,154,171,204,205,221,203,170,169,153,153,170,171,204,221,222,220,203,187,170,170,171,187,204,222,222,254,237,204,187,187,187,188,205,222,237,174,221,220,204,187,187,187,204,205,221,176,0,0,0,171,186,170,153,153,153,154,170,187,204,171,203,186,170,153,153,154,170,187,204,221,187,186,169,153,152,137,153,170,187,205,202,186,169,152,136,136,136,137,154,187,204,171,169,152,135,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,154,187,154,152,135,119,102,102,103,120,137,171,169,153,135,119,102,102,102,103,136,154,170,153,152,119,102,102,102,102,119,137,154,169,153,135,118,102,85,86,103,120,137,170,153,152,119,102,101,85,102,119,136,154,169,153,135,118,102,101,102,103,120,153,170,154,152,135,118,102,102,102,119,137,154,170,169,136,119,102,102,102,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,137,170,187,187,186,153,136,136,136,136,153,170,187,187,203,170,169,153,136,137,153,170,187,203,205,203,170,169,153,153,154,170,187,204,205,220,203,187,170,170,170,171,188,205,220,172,204,187,170,170,170,170,171,187,204,176,0,0,0,171,186,169,153,153,153,153,170,171,204,171,203,186,170,153,153,153,170,171,204,220,187,186,169,153,136,136,153,154,171,204,202,186,153,152,136,136,136,137,154,171,187,170,169,136,135,119,119,120,137,154,171,185,169,152,135,119,119,119,120,137,154,187,154,152,135,118,102,102,119,120,137,170,169,153,135,118,102,102,102,103,120,153,170,153,136,119,102,102,102,102,119,136,154,169,152,135,118,102,101,102,103,120,137,170,153,136,119,102,101,86,102,119,136,154,169,153,135,118,102], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+918680);
/* memory initializer */ allocate([102,102,103,120,137,170,153,152,119,118,102,102,102,119,137,154,169,169,136,119,118,102,102,119,136,153,170,170,153,136,119,119,119,119,120,137,171,170,170,153,136,119,119,119,136,137,154,186,187,170,153,136,136,136,136,137,154,187,187,203,170,153,152,136,136,153,154,187,203,204,203,170,169,153,153,153,170,187,204,204,220,203,186,170,170,170,170,187,205,220,188,203,186,170,170,170,170,170,187,204,176,0,0,0,171,187,170,153,153,153,154,170,187,204,171,204,187,170,153,153,170,170,187,205,220,188,187,169,153,153,153,153,170,187,205,202,186,169,152,136,136,136,137,154,187,204,171,169,152,135,119,119,136,137,154,187,186,170,152,135,119,119,119,120,137,170,187,154,152,135,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,136,154,170,153,152,119,102,102,86,102,119,137,154,169,153,135,118,102,85,86,103,120,153,170,153,152,119,102,101,85,102,119,136,154,169,169,135,118,102,86,102,103,120,153,170,154,152,135,102,102,102,102,119,137,154,170,169,136,119,102,102,102,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,153,170,187,187,186,153,136,136,136,136,153,170,188,187,203,170,169,153,136,153,153,170,187,203,205,204,186,170,169,153,154,170,187,205,204,220,204,187,170,170,170,171,187,204,220,173,204,187,170,170,170,170,171,187,204,176,0,0,0,188,203,187,170,170,170,171,188,204,221,172,220,203,186,170,170,170,187,204,222,238,204,203,170,169,153,153,170,171,188,222,235,203,170,153,152,136,137,154,171,188,221,187,170,153,136,135,120,136,153,171,205,203,186,153,135,119,119,119,136,153,171,204,171,169,135,119,102,102,119,136,154,188,202,169,152,119,102,86,102,119,137,154,187,170,152,135,102,85,85,102,120,137,171,186,169,135,118,85,85,85,103,120,154,187,170,152,119,101,85,85,86,119,137,171,186,169,136,118,101,85,86,103,120,154,187,170,169,135,118,101,86,102,120,137,171,187,186,152,135,118,102,102,119,137,170,187,187,170,152,135,119,119,119,136,154,188,188,203,169,152,136,119,120,137,154,171,204,204,203,169,153,136,136,137,154,171,204,205,220,187,170,153,153,153,154,171,188,221,222,220,203,186,170,170,170,187,204,222,222,238,221,204,187,187,187,188,204,222,237,190,221,204,203,187,187,187,188,204,222,192,0,0,0,223,255,255,255,255,255,255,255,255,255,191,255,255,254,237,222,239,255,255,255,255,255,255,237,204,204,204,221,255,255,255,255,255,236,203,186,170,187,205,239,255,255,255,221,187,169,153,153,170,189,239,255,255,253,203,169,136,119,136,154,205,255,255,254,219,169,135,102,103,120,154,205,255,255,220,185,135,101,85,86,120,171,223,255,253,202,152,101,84,69,86,137,188,239,254,220,169,118,84,68,69,103,154,205,255,254,202,151,101,68,68,86,121,172,223,255,236,185,135,85,68,85,103,154,205,255,255,219,168,118,85,85,103,137,172,223,255,253,203,152,118,102,103,137,171,207,255,255,253,202,152,135,119,137,154,205,255,255,255,236,187,169,153,153,170,188,223,255,255,255,221,203,186,170,171,204,223,255,255,255,255,254,220,204,204,205,239,255,255,255,255,255,255,253,221,222,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,224,0,0,0,206,237,221,220,204,204,205,222,238,222,175,254,221,220,204,204,204,221,239,255,255,239,221,203,187,170,171,187,205,238,255,238,237,203,170,153,153,154,171,205,238,255,221,203,169,152,136,136,153,171,205,239,237,220,169,152,119,119,119,137,171,206,238,204,186,152,119,102,102,119,137,171,222,236,203,152,118,101,85,86,120,154,188,221,204,169,135,101,85,85,86,120,155,205,220,202,152,118,85,68,85,103,137,172,221,204,169,135,101,84,69,86,120,154,205,220,203,152,118,85,85,85,103,137,172,222,220,186,152,118,85,85,102,120,155,205,221,219,169,135,118,102,102,120,154,188,221,221,203,169,135,119,119,120,153,171,222,237,237,203,169,152,136,136,153,171,205,238,222,236,203,170,153,153,154,171,204,239,238,254,237,203,187,170,171,187,205,239,255,255,255,237,220,204,204,204,205,239,255,254,255,255,238,237,221,221,222,238,255,255,175,238,238,237,221,221,221,237,239,255,208,0,0,0,206,221,204,204,204,188,204,221,221,238,190,254,221,204,187,187,188,205,238,255,254,222,220,203,186,170,170,187,204,222,255,237,220,203,170,153,153,153,171,188,222,254,221,203,169,152,136,136,137,171,204,222,220,203,169,136,119,119,119,137,171,205,237,204,186,152,119,102,102,119,137,171,205,220,186,152,119,101,85,102,119,138,188,221,188,169,135,101,85,85,86,120,154,189,220,186,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,188,204,186,152,118,101,85,85,103,137,171,204,204,185,135,118,85,85,102,120,154,189,220,203,169,135,118,102,102,120,154,188,221,221,203,169,135,119,119,120,137,171,205,221,221,186,169,136,136,136,153,171,205,221,222,220,187,169,153,153,154,171,188,222,237,238,220,203,186,170,170,171,204,222,254,239,254,221,204,203,187,188,204,222,239,238,255,238,237,220,204,221,221,222,255,255,190,238,237,221,221,205,205,221,238,239,208,0,0,0,206,237,221,204,204,220,221,222,239,239,174,254,237,220,204,204,204,222,239,255,254,238,221,219,187,186,171,188,205,238,255,237,237,203,170,153,153,154,187,205,239,254,221,203,170,152,136,136,153,171,205,239,237,219,185,152,119,119,120,137,171,205,238,204,186,152,118,102,102,119,137,172,222,220,203,152,118,101,85,86,119,154,188,237,204,185,135,101,85,85,86,120,155,205,220,202,152,118,85,68,85,103,137,188,221,204,169,135,101,84,69,86,120,154,189,220,203,152,118,85,85,85,103,137,172,221,220,186,152,118,85,85,102,120,154,205,221,220,185,135,118,102,102,120,154,188,221,222,219,169,136,119,119,120,153,171,221,238,237,203,169,152,136,136,153,171,205,238,255,237,203,170,153,153,154,171,205,222,238,255,221,204,187,170,171,187,204,222,238,255,254,237,220,203,204,204,205,238,255,238,255,255,254,237,221,221,222,238,239,255,174,238,238,237,237,221,221,222,238,254,208,0,0,0,255,255,255,255,255,255,255,255,255,255,175,255,255,255,237,223,255,255,255,255,255,255,255,253,204,204,204,221,255,255,255,255,255,221,203,186,170,187,205,255,255,255,255,252,187,169,153,153,171,189,255,255,255,253,202,169,135,119,136,154,189,255,255,253,203,169,135,102,103,120,154,205,255,255,252,185,135,101,85,86,120,171,223,255,253,202,151,101,84,69,86,137,172,255,255,220,169,118,84,68,69,103,154,207,255,253,202,151,101,68,68,86,121,172,223,255,252,185,134,101,68,85,103,154,205,255,255,219,168,118,85,85,103,137,172,239,255,255,202,152,118,102,103,137,171,207,255,255,253,186,152,135,119,137,155,205,255,255,255,252,186,169,153,153,171,188,255,255,255,255,237,203,186,170,171,205,239,255,255,255,255,253,220,204,204,205,255,255,255,255,255,255,255,253,221,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,240,0,0,0,206,221,204,204,188,188,204,221,222,238,174,238,221,204,187,187,204,205,222,255,254,222,220,203,186,170,170,187,205,222,239,237,220,187,170,153,153,154,171,188,222,254,205,203,169,152,136,136,153,171,205,223,236,203,169,136,119,119,120,137,171,205,238,204,186,152,119,102,102,119,137,171,205,219,186,152,119,101,85,102,120,154,188,221,187,169,135,101,85,85,102,120,154,189,219,186,152,118,85,68,85,103,137,171,204,203,169,135,101,84,68,86,120,154,188,220,186,152,118,101,84,85,103,137,171,204,204,186,152,118,101,85,103,120,154,188,204,203,169,135,118,102,102,120,154,172,221,221,203,169,136,119,119,120,137,171,205,221,221,203,169,152,136,136,153,171,188,237,238,220,203,170,153,153,154,171,188,222,238,254,220,203,186,170,170,187,188,221,238,239,254,221,204,203,187,188,205,221,239,238,255,254,237,221,204,204,221,238,239,254,158,237,221,221,220,204,221,221,222,239,192,0,0,0,172,187,186,170,170,170,170,187,204,205,156,220,187,187,170,170,170,187,204,222,237,188,203,170,169,153,153,154,171,188,221,219,187,170,153,152,136,137,153,171,188,220,187,170,153,136,135,120,136,153,171,188,202,186,153,135,119,119,119,136,153,171,204,171,169,135,118,102,102,103,120,154,172,202,169,152,118,102,102,102,119,137,154,187,170,152,119,102,85,85,102,120,137,171,186,169,135,118,101,85,85,103,120,154,187,170,152,119,102,85,85,86,119,137,171,186,169,136,118,101,85,86,103,120,154,187,170,153,135,118,101,86,102,120,137,171,186,186,152,135,118,102,102,119,137,170,187,187,169,152,135,119,119,119,136,154,188,187,187,169,152,136,119,120,136,154,171,203,188,187,170,153,136,136,137,154,171,204,204,204,187,170,153,153,153,154,171,189,220,205,204,187,186,170,170,170,187,204,222,204,238,220,203,187,187,187,187,204,221,237,157,204,203,187,187,187,187,188,204,221,192,0,0,0,171,186,170,153,153,153,154,170,187,188,155,203,186,170,169,153,170,170,187,204,220,187,186,169,153,153,153,153,170,187,205,186,186,169,152,136,136,136,153,154,187,203,170,169,152,136,119,119,136,137,154,188,186,169,152,135,119,119,119,120,137,170,187,154,152,135,119,102,102,119,120,153,171,169,169,136,119,102,102,102,119,136,154,170,153,152,119,102,101,86,102,119,137,170,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,153,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,102,120,137,170,170,169,152,119,118,102,103,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,135,119,120,136,153,170,186,171,186,153,152,136,136,136,153,170,187,187,203,186,169,153,153,153,153,170,187,203,188,203,186,170,169,153,170,170,187,204,188,220,204,187,170,170,170,171,188,204,220,156,203,186,170,170,170,170,171,187,204,160,0,0,0,171,187,170,170,169,170,170,171,187,204,155,204,187,186,170,170,170,171,188,205,220,188,187,170,153,153,153,154,171,188,205,202,187,170,153,136,136,136,153,170,188,203,171,169,152,136,119,119,136,153,170,204,186,170,152,135,119,119,119,120,153,171,187,170,153,135,118,102,102,119,120,154,172,186,169,136,118,102,102,102,119,136,154,187,154,152,119,102,85,85,102,119,137,171,185,169,135,118,101,85,86,103,120,154,186,154,152,119,102,85,85,102,119,137,171,170,169,135,118,101,85,86,103,120,154,186,170,152,135,118,102,102,102,120,137,171,170,186,152,119,118,102,102,119,137,154,186,171,169,152,135,119,119,119,136,154,171,187,187,169,152,136,119,120,136,154,171,203,188,186,169,152,136,136,137,153,171,188,187,204,187,170,153,153,153,154,171,188,203,205,204,187,170,170,170,170,187,188,205,204,220,204,203,187,187,171,187,204,205,220,156,203,187,186,170,170,170,187,187,204,160,0,0,0,206,221,204,204,204,204,205,222,238,239,158,254,221,204,203,187,204,221,239,255,255,222,220,203,186,170,171,187,205,238,255,253,220,203,170,153,153,154,171,205,239,255,221,203,169,152,136,136,153,171,205,239,236,203,169,152,119,119,120,137,171,205,238,204,186,152,119,102,102,120,137,171,222,236,202,152,119,101,85,102,120,154,188,221,203,169,135,101,85,85,102,120,155,205,220,186,152,118,85,68,85,103,137,172,221,204,169,135,101,84,68,86,120,154,189,220,203,152,118,101,68,85,103,137,171,221,204,186,152,118,101,85,103,120,155,189,221,219,185,136,118,102,103,120,154,188,221,221,203,169,136,119,119,120,153,171,205,221,237,203,169,152,136,136,153,171,205,237,238,237,203,170,153,153,154,171,204,222,238,254,221,203,186,170,170,187,204,222,254,239,254,221,220,203,187,204,205,238,255,254,255,255,238,221,220,221,221,238,255,255,174,254,238,237,221,221,221,222,238,255,192,0,0,0,223,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,237,221,255,255,255,255,255,255,255,221,204,204,205,222,255,255,255,255,255,220,187,170,171,188,221,255,255,255,255,236,186,153,137,154,187,223,255,255,255,253,186,152,119,119,137,188,239,255,255,255,203,152,101,85,103,138,188,255,255,255,220,169,117,68,68,103,155,207,255,255,254,202,135,84,51,69,121,172,223,255,255,220,169,117,67,52,87,138,206,255,255,255,203,151,100,68,69,121,172,223,255,255,253,186,135,101,85,104,155,205,255,255,255,220,185,135,119,120,154,189,255,255,255,255,220,186,152,137,154,188,223,255,255,255,254,220,187,170,171,188,223,255,255,255,255,255,221,204,204,205,255,255,255,255,255,255,255,254,221,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,208,0,0,0,189,221,220,204,204,204,204,204,221,205,158,254,221,221,204,204,205,221,238,254,253,222,237,220,187,187,187,188,205,222,239,236,221,204,186,170,170,170,187,205,237,237,205,204,186,169,153,153,154,187,205,223,220,220,186,153,136,119,136,154,188,205,237,205,203,169,135,102,102,120,154,188,222,220,203,169,135,101,85,102,120,155,189,237,204,186,151,101,84,69,102,137,171,205,220,203,168,118,84,68,69,103,138,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,237,205,202,152,118,101,85,103,137,171,205,220,220,186,152,119,102,103,136,155,204,237,205,203,170,152,135,119,137,154,188,221,220,220,204,170,153,153,153,170,188,222,237,222,221,204,186,170,170,171,188,221,238,220,254,221,204,203,187,187,188,205,238,254,223,238,221,221,204,204,204,221,238,239,237,255,238,237,221,221,222,239,239,255,238,157,221,205,221,221,221,221,222,238,254,192,0,0,0,206,221,204,203,187,188,204,205,221,222,174,238,220,204,187,187,188,205,221,239,254,222,220,203,186,170,170,187,204,221,239,237,220,203,170,153,153,154,171,188,222,238,204,203,169,152,136,136,153,170,188,222,220,203,169,152,119,119,120,137,171,204,221,204,186,152,119,102,102,119,137,171,205,219,186,152,119,101,85,86,119,154,188,221,187,169,135,101,85,85,86,120,154,205,219,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,85,85,85,103,137,171,204,204,186,136,118,85,85,103,120,154,189,204,203,169,135,118,102,103,120,154,188,221,205,203,169,136,119,119,120,153,171,205,220,220,186,169,136,136,136,153,171,205,221,221,220,187,169,153,153,154,171,204,222,221,237,220,187,186,170,170,187,204,222,254,223,238,220,204,187,187,188,204,222,255,254,254,254,221,221,204,204,221,222,255,254,174,237,221,221,204,204,205,221,238,239,208,0,0,0,222,237,221,204,204,204,204,221,221,222,159,255,237,221,221,204,205,221,238,239,254,239,237,220,187,187,187,204,206,238,255,237,237,220,186,170,170,170,187,205,238,253,222,220,186,153,152,137,154,171,205,239,221,220,186,152,135,119,120,154,187,205,237,205,203,168,135,102,102,120,154,188,222,220,219,169,135,101,85,102,120,154,188,237,205,186,151,101,84,69,102,121,171,205,220,203,168,118,84,68,69,103,138,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,118,101,69,86,103,154,188,221,221,202,152,118,101,85,103,137,171,205,221,220,186,152,118,102,103,136,154,189,221,221,203,170,152,135,119,136,154,188,206,222,237,203,170,153,136,137,154,188,205,237,239,237,203,186,170,170,170,188,205,238,222,254,221,204,187,187,187,204,205,222,254,223,254,221,220,204,204,204,222,238,239,238,255,239,238,222,221,221,222,239,255,255,174,221,221,237,221,221,221,222,238,238,192,0,0,0,223,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,254,254,255,255,255,255,255,255,255,255,221,204,204,205,221,255,255,255,255,255,220,203,170,171,188,223,255,255,255,255,220,186,153,137,154,188,223,255,255,255,253,186,152,119,119,137,188,223,255,255,255,203,152,102,85,103,138,189,255,255,255,252,169,118,68,69,103,155,205,255,255,255,202,135,84,51,69,120,172,255,255,255,252,169,117,67,36,87,138,206,255,255,255,203,151,101,68,70,121,172,223,255,255,253,186,135,101,86,104,155,205,255,255,255,220,185,135,119,120,154,189,255,255,255,255,220,186,153,137,154,188,255,255,255,255,255,220,187,170,171,188,223,255,255,255,255,255,221,204,204,205,223,255,255,255,255,255,255,255,221,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,208,0,0,0,206,237,205,204,204,204,204,205,221,221,158,254,221,220,204,188,204,221,238,239,254,222,221,204,187,187,187,188,204,222,239,237,237,203,186,170,170,170,187,205,222,238,221,204,186,153,152,153,154,171,204,222,220,220,186,152,136,119,136,153,171,205,237,204,186,153,135,118,103,120,154,188,221,220,203,169,135,102,85,102,120,154,188,221,204,186,152,118,84,69,103,137,171,205,220,203,168,118,84,52,85,103,154,188,220,204,186,151,101,68,52,86,120,155,205,220,203,169,135,101,68,86,104,154,188,221,204,186,152,118,101,86,103,137,171,205,220,203,186,152,119,102,119,136,154,188,221,205,203,169,152,135,120,137,154,188,222,221,236,203,170,153,136,153,154,187,205,237,222,220,203,186,170,170,170,187,205,239,237,238,220,203,187,187,187,188,205,239,238,239,254,221,204,204,204,204,221,222,255,237,255,238,237,221,205,221,221,238,255,255,142,221,221,204,204,205,221,221,222,238,192,0,0,0,155,187,170,170,169,170,170,170,187,187,155,204,187,186,170,170,170,187,188,204,236,188,187,170,169,153,153,170,170,188,205,187,187,170,153,152,136,137,154,171,188,203,171,170,153,136,136,136,136,153,171,188,186,186,153,136,119,119,119,136,153,171,203,170,169,136,119,102,102,119,136,154,171,186,169,152,119,102,85,102,119,137,170,187,154,152,135,102,85,85,102,120,153,171,169,169,135,118,85,85,85,103,120,154,186,154,152,135,101,85,85,86,119,137,171,170,169,136,118,101,85,86,103,136,154,186,170,169,135,118,101,86,102,120,153,171,170,170,152,135,118,102,102,120,137,170,186,171,169,152,135,119,119,120,137,154,187,186,187,169,152,136,136,136,137,154,171,203,188,187,169,153,136,136,153,154,171,188,187,204,187,170,169,153,153,170,171,188,204,188,204,187,186,170,170,171,187,188,221,204,221,220,203,187,187,187,188,204,205,236,140,187,187,186,170,170,170,187,188,204,160,0,0,0,155,170,169,153,153,153,153,170,171,187,155,203,186,170,169,153,170,170,187,204,203,171,186,169,153,153,153,153,170,171,204,186,186,169,152,136,136,136,153,154,187,203,170,169,152,136,119,119,136,137,154,187,185,169,152,135,119,119,119,120,137,170,186,154,153,135,119,102,102,119,120,153,171,169,169,136,119,102,102,102,119,136,154,170,153,152,119,102,101,86,102,119,137,170,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,103,120,137,170,169,169,152,119,118,102,103,119,136,154,170,170,169,136,119,119,119,119,136,153,171,170,186,153,136,135,119,120,136,153,170,186,171,186,153,152,136,136,136,153,170,187,187,203,170,169,153,153,153,153,170,187,203,188,203,186,170,169,153,170,170,187,204,187,220,203,187,170,170,170,187,187,204,220,155,187,170,170,170,170,170,170,187,188,160,0,0,0,155,187,170,170,170,170,170,170,187,188,139,220,203,187,170,170,171,187,188,221,220,188,203,186,169,153,153,170,171,188,205,203,203,186,153,152,136,153,154,171,188,203,171,170,153,136,135,136,136,154,171,188,186,186,153,136,119,119,119,136,154,171,203,170,169,136,118,102,102,119,136,154,187,186,169,152,118,102,85,102,119,137,154,186,170,152,135,102,85,85,102,120,137,171,186,169,136,118,85,85,85,103,136,154,186,170,152,135,101,85,85,86,119,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,101,86,102,120,153,171,170,186,152,135,118,102,102,119,137,171,187,171,170,152,135,119,119,120,137,154,188,187,203,170,152,136,135,136,137,154,171,203,188,187,170,153,152,136,153,154,171,204,187,204,187,170,169,153,154,170,171,204,204,189,204,187,186,170,170,171,187,204,205,204,221,204,203,187,187,187,188,204,221,220,140,187,187,187,170,170,187,187,187,204,160,0,0,0,189,221,221,204,204,204,204,205,205,221,142,254,237,221,204,204,205,221,239,255,253,222,237,204,203,187,187,204,205,238,239,237,221,204,187,170,170,170,187,205,238,253,221,220,186,169,153,153,154,187,205,238,236,220,186,169,136,119,136,154,188,206,237,205,203,169,135,118,103,120,154,188,222,220,203,169,135,102,85,102,120,154,188,237,204,186,152,118,84,69,103,137,171,205,220,203,169,118,84,52,69,104,154,188,221,204,186,152,101,68,52,86,121,171,205,220,219,169,135,101,68,86,120,154,188,221,221,186,152,118,101,85,103,137,171,206,220,220,186,152,119,102,119,137,171,204,221,221,219,170,152,135,120,137,154,188,222,221,237,203,170,153,153,153,170,188,205,237,222,221,203,186,170,170,171,188,205,239,237,255,237,220,203,187,187,188,221,238,254,223,254,221,220,204,204,221,221,238,255,253,255,254,238,237,221,221,238,238,255,255,157,221,222,221,221,205,221,238,222,239,192,0,0,0,207,254,238,222,221,221,221,237,221,221,159,255,255,255,238,238,238,239,255,255,255,255,255,238,221,221,205,221,222,239,255,238,255,237,220,203,187,204,205,238,255,254,239,237,204,186,170,170,187,205,238,255,254,238,220,186,152,136,153,171,205,222,254,239,220,186,152,119,119,137,171,205,255,238,237,202,152,118,85,103,137,172,222,255,238,203,168,118,84,69,103,138,189,223,238,237,186,135,84,51,69,120,171,222,255,222,203,168,117,67,36,87,138,189,239,237,237,186,151,101,68,70,120,171,221,254,223,220,169,135,101,86,120,154,205,239,238,237,219,169,135,119,120,154,188,223,254,223,237,203,169,152,136,154,187,221,255,253,254,221,203,170,170,170,188,221,254,254,223,238,221,204,203,187,188,205,239,255,253,254,254,221,220,204,221,222,255,255,255,223,254,255,238,237,238,239,255,255,255,253,255,255,255,239,255,255,255,255,255,255,140,221,221,221,221,221,237,254,239,255,192,0,0,0,205,221,220,204,204,204,204,204,221,221,158,254,221,220,204,204,204,221,221,238,238,222,221,204,187,187,187,187,205,221,239,237,221,203,186,170,170,170,171,204,222,237,205,203,186,153,152,137,154,171,204,222,220,220,186,152,135,119,136,153,171,205,237,204,186,152,135,102,102,120,153,171,205,220,203,169,135,102,85,102,120,154,188,221,204,186,151,102,84,69,102,137,171,205,220,203,168,118,84,68,69,103,137,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,134,101,68,85,103,154,188,221,204,186,152,118,101,86,103,137,171,205,220,220,170,152,119,102,103,136,154,189,237,205,203,169,152,119,119,136,154,188,222,221,220,203,170,153,136,137,154,188,205,238,221,220,203,170,170,170,170,188,205,239,237,238,220,203,187,187,187,188,205,238,254,222,238,221,220,204,204,204,221,238,255,237,255,238,238,221,221,221,222,238,255,255,157,237,221,221,221,221,221,222,238,255,208,0,0,0,206,221,204,203,187,187,188,204,205,221,174,238,220,204,187,187,188,204,221,222,237,222,220,203,186,170,170,171,188,205,222,221,220,203,170,153,153,153,170,188,205,237,205,203,169,152,136,136,137,170,188,221,220,203,169,152,119,119,119,137,170,188,221,204,186,152,119,102,102,119,137,171,205,203,186,152,119,101,85,86,120,137,171,220,187,169,135,101,85,85,86,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,85,85,85,103,137,171,204,188,170,136,118,101,85,103,120,154,188,204,203,169,135,118,102,103,120,154,188,220,204,186,169,136,119,119,120,153,171,205,220,204,186,169,136,136,136,153,171,204,221,205,204,186,169,153,153,154,171,204,222,221,237,204,187,170,170,170,187,204,222,238,222,221,220,203,187,187,188,204,222,239,237,254,237,221,204,204,204,221,222,239,254,173,221,221,204,204,204,205,221,222,238,208,0,0,0,189,221,220,204,204,204,204,204,221,221,158,254,237,220,204,204,204,205,222,238,237,222,237,204,203,187,187,187,204,221,239,221,237,203,187,170,170,170,187,204,221,237,221,204,186,153,152,153,154,171,205,222,220,220,186,153,136,119,136,153,171,205,237,204,186,169,135,102,103,120,154,188,205,204,203,169,135,101,85,102,120,154,188,220,204,186,152,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,138,188,220,204,186,151,101,68,68,86,120,171,205,204,203,169,135,101,68,85,103,154,188,220,204,186,152,118,101,85,103,137,171,205,204,204,186,152,119,102,103,136,154,188,220,205,203,169,152,135,119,136,154,188,221,220,220,203,170,153,136,153,154,187,205,237,222,220,203,186,170,170,171,187,205,222,221,237,220,203,187,187,187,204,205,222,237,223,237,221,204,204,204,204,221,222,239,221,238,238,221,221,221,221,222,238,239,254,157,221,204,204,204,204,205,221,221,222,176,0,0,0,223,255,255,254,253,221,221,221,221,221,143,255,255,255,254,254,255,255,255,255,254,255,255,255,255,255,238,254,255,255,255,239,255,255,238,221,221,221,254,255,239,255,255,254,253,204,187,188,204,223,255,255,255,255,237,203,186,170,171,205,222,255,255,255,253,203,169,136,136,154,205,239,255,255,255,236,169,134,102,120,155,206,255,255,255,237,202,134,84,69,120,172,222,255,255,255,203,168,100,34,70,138,189,255,255,239,254,186,134,66,36,104,172,222,255,255,254,220,168,117,68,86,138,189,255,255,255,237,203,152,118,102,121,172,223,255,255,255,237,202,152,136,137,171,221,255,255,255,255,221,187,170,170,171,205,255,255,255,255,255,221,204,187,204,221,255,255,255,255,255,254,237,221,221,222,239,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,158,254,255,239,255,254,255,255,255,255,224,0,0,0,189,221,204,203,187,187,204,204,205,221,157,254,221,204,203,187,188,204,221,238,254,222,221,204,187,170,171,187,188,221,238,237,221,203,170,169,153,154,171,204,221,237,205,203,170,152,136,136,153,171,188,222,220,203,186,152,135,119,120,137,171,205,237,204,186,152,119,102,102,120,137,171,205,204,203,169,135,102,85,102,120,154,188,221,187,169,135,102,84,85,102,120,154,205,203,186,152,118,84,68,69,103,137,171,204,188,169,135,101,84,68,86,120,154,188,203,202,152,118,101,84,85,103,137,171,204,204,186,152,118,101,86,103,137,171,205,204,203,169,136,118,102,103,120,154,188,220,204,202,169,136,119,119,136,154,187,205,220,220,186,169,152,136,137,154,171,205,221,222,220,187,170,153,153,170,187,205,222,221,237,220,203,186,170,171,187,205,222,254,222,237,220,204,203,187,204,221,222,239,237,239,238,221,221,220,221,221,238,255,254,141,220,204,204,204,204,204,205,222,238,192,0,0,0,172,203,186,170,170,170,170,171,187,188,156,220,203,187,170,170,170,187,188,205,220,188,203,170,169,153,153,170,171,188,205,203,203,170,153,152,136,153,153,171,188,220,187,186,153,136,136,136,136,153,171,188,186,186,153,136,119,119,119,136,154,171,203,171,169,135,118,102,102,119,136,154,187,186,169,152,118,102,85,102,119,137,171,187,170,152,135,102,85,85,102,120,137,171,186,169,136,118,85,85,85,103,120,154,187,170,152,135,101,85,85,86,119,137,171,186,169,152,118,101,85,86,103,136,154,187,170,153,135,118,101,86,102,120,153,171,186,186,152,135,118,102,102,119,137,170,187,171,170,152,135,119,119,119,137,154,188,187,187,169,152,136,135,136,137,154,187,203,188,187,170,153,136,136,153,154,171,205,203,220,187,170,169,153,153,170,187,204,220,189,204,187,186,170,170,187,187,204,222,204,237,204,203,187,187,187,188,205,222,237,140,204,187,187,187,187,187,188,204,221,176,0,0,0,171,186,170,153,153,153,153,170,171,187,155,203,187,170,170,170,170,170,187,204,219,187,186,170,153,153,153,153,170,187,204,186,186,169,153,136,136,136,153,170,187,203,171,169,152,136,119,120,136,137,170,187,186,170,152,135,119,119,119,136,153,170,186,154,153,135,119,102,102,119,136,153,171,169,169,136,119,102,102,102,119,136,154,186,154,152,119,102,85,85,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,101,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,103,119,137,154,186,170,169,136,135,119,119,119,136,154,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,152,136,136,137,153,170,188,186,203,170,169,153,153,153,154,170,187,203,188,203,186,170,170,170,170,171,187,205,187,204,203,187,186,170,170,187,188,205,220,155,187,186,170,170,170,170,171,187,204,160,0,0,0,172,187,170,170,170,170,170,170,187,188,156,220,203,187,170,170,170,187,188,205,220,188,187,170,169,153,153,170,171,188,205,187,203,170,153,152,136,137,153,171,188,203,171,170,153,136,136,120,136,153,171,188,186,186,153,135,119,119,119,136,154,171,203,170,169,136,118,102,102,119,136,154,187,186,169,152,118,102,85,102,119,137,154,187,170,152,135,102,85,85,102,120,137,171,170,169,135,118,85,85,85,103,136,154,186,170,152,135,101,85,85,86,119,137,171,170,169,136,118,101,85,86,103,136,154,186,170,153,135,118,101,86,103,120,153,171,170,186,152,135,118,102,103,120,137,170,187,171,170,152,135,119,119,120,137,154,188,186,187,169,152,136,135,136,137,154,171,203,188,187,170,153,136,136,153,154,171,188,187,204,187,170,169,153,153,170,171,188,219,189,204,187,186,170,170,170,187,204,221,204,221,204,203,187,187,187,188,204,205,220,140,203,187,186,170,170,187,187,188,204,160,0,0,0,189,220,204,203,187,187,187,204,204,205,141,238,221,204,203,187,204,204,221,238,253,221,220,203,186,170,171,187,188,221,239,221,220,203,170,169,153,154,171,188,221,237,204,203,170,152,136,136,153,171,188,221,220,203,169,152,135,119,120,137,171,204,220,204,186,152,119,102,102,119,137,171,205,203,187,169,135,102,85,102,120,154,188,220,187,169,135,102,84,85,102,120,154,188,203,186,152,118,84,68,69,103,137,171,204,187,169,135,101,84,68,86,120,154,188,203,186,152,118,101,84,86,103,137,171,204,188,186,152,118,101,86,103,136,155,189,204,203,169,136,118,102,103,120,154,188,221,205,187,169,136,119,119,136,154,171,205,204,220,187,169,152,136,137,153,171,205,221,221,204,186,170,153,153,170,171,204,222,221,237,220,203,186,170,171,187,205,222,238,222,221,220,203,187,187,188,205,222,255,237,255,222,221,220,204,205,221,238,239,254,157,221,204,204,204,204,205,221,222,238,192,0,0,0,239,255,255,254,239,221,221,221,221,221,159,255,255,255,255,238,222,255,239,255,255,255,255,253,221,221,221,221,238,255,255,239,255,253,220,204,187,188,205,222,255,254,255,254,220,186,170,170,171,205,239,255,255,255,220,186,152,136,137,171,205,239,255,239,220,186,152,118,119,137,171,205,255,238,237,202,152,102,85,102,137,171,222,255,238,219,168,118,68,69,103,138,205,255,254,253,186,134,84,51,69,120,171,222,255,222,219,168,117,67,52,86,138,189,239,254,253,186,135,101,68,69,120,171,222,255,238,220,169,135,101,85,104,154,205,255,254,253,203,169,135,118,119,154,188,239,255,239,253,203,169,136,136,154,188,223,255,253,254,220,203,170,154,170,188,223,255,255,223,254,221,204,187,187,205,221,255,255,253,255,254,237,220,220,221,238,255,255,255,223,255,238,239,237,238,239,255,255,255,253,255,255,255,255,255,255,255,255,255,255,141,221,205,222,221,223,255,255,255,255,224,0,0,0,222,221,221,220,204,204,204,204,205,221,158,254,237,221,204,204,204,221,222,239,253,238,237,220,203,187,187,188,205,222,239,237,237,204,186,170,170,170,187,204,222,253,222,204,186,153,152,153,154,171,205,222,221,220,186,152,135,119,136,154,171,205,237,205,203,168,135,102,103,120,154,188,221,220,203,169,135,101,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,135,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,205,186,152,118,101,85,103,137,172,206,220,204,186,152,118,102,103,137,171,205,237,205,203,169,152,135,119,136,154,188,222,236,221,203,170,153,137,153,170,188,222,238,221,220,203,186,170,170,171,188,221,239,236,237,220,203,187,187,187,204,221,239,254,223,238,221,204,204,204,205,237,254,255,252,255,254,237,221,221,221,238,254,255,255,157,237,221,221,221,221,237,222,239,255,208,0,0,0,206,221,220,204,187,187,188,204,205,221,174,238,221,204,203,187,188,204,221,238,238,222,221,203,186,170,170,187,188,205,222,221,220,203,170,153,153,154,170,188,205,237,221,203,169,152,136,136,137,170,188,205,220,203,169,152,119,119,120,137,170,188,221,204,186,152,119,102,102,119,137,171,205,220,202,152,119,101,85,102,120,153,171,220,187,169,135,101,85,85,102,120,154,188,203,186,152,118,84,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,84,85,103,137,171,204,188,170,152,118,101,85,103,120,154,205,220,203,169,135,118,102,103,120,154,188,221,204,186,169,136,119,119,120,153,171,205,220,220,186,169,152,136,136,153,171,205,237,205,204,186,170,153,153,154,171,204,222,237,237,204,187,170,170,170,187,205,222,254,222,221,204,204,187,187,204,205,222,255,237,254,237,221,204,204,205,221,238,239,255,173,221,220,204,204,204,205,221,238,239,208,0,0,0,206,237,221,204,204,204,204,204,204,221,158,255,238,221,204,204,204,205,222,239,253,239,237,220,203,187,187,187,204,221,239,221,237,204,187,170,170,170,171,204,221,237,222,220,186,169,152,137,154,171,204,222,221,220,186,152,135,119,136,153,171,205,237,205,203,168,135,102,103,120,154,187,205,220,219,169,135,101,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,168,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,136,154,188,221,205,203,169,152,135,120,137,154,188,205,221,220,203,170,153,152,153,154,187,205,221,222,220,203,186,170,170,171,187,205,221,221,237,220,203,187,187,187,188,204,222,237,222,237,221,204,204,204,204,205,222,239,221,254,238,221,221,221,221,222,238,239,254,157,221,221,221,221,204,221,221,222,222,192,0,0,0,223,255,254,238,221,221,220,204,221,205,143,255,255,255,254,222,238,223,239,255,254,239,255,255,221,220,204,221,222,238,255,223,255,238,220,203,187,188,205,221,255,254,255,253,220,186,170,170,171,205,238,255,238,238,204,186,152,136,137,171,204,239,255,255,220,186,136,119,119,137,171,205,239,254,237,202,151,101,85,103,137,172,222,254,238,219,168,117,68,69,103,138,189,238,237,252,186,135,84,51,69,120,155,222,255,221,203,168,117,67,52,87,138,188,239,253,220,186,135,101,68,69,120,171,222,255,222,220,169,135,101,85,104,154,205,239,253,237,203,169,135,119,120,154,188,239,255,222,236,203,169,136,136,154,188,221,255,255,255,220,187,170,170,170,188,221,239,255,239,254,221,204,187,187,204,221,255,255,254,254,238,221,220,204,205,223,239,255,255,239,255,255,238,237,238,238,255,255,255,253,255,255,255,239,255,255,255,255,255,255,141,221,222,237,222,255,239,255,255,255,208,0,0,0,207,221,220,204,204,203,204,204,204,205,142,254,237,221,204,204,204,204,238,239,253,222,237,204,187,187,187,188,205,222,239,237,237,203,186,170,170,170,187,204,222,253,221,204,186,153,153,153,154,171,205,238,220,220,186,152,136,119,136,153,171,205,237,204,202,152,135,102,103,120,154,187,221,220,203,169,135,102,85,102,120,154,188,221,204,186,152,102,84,69,103,137,171,205,220,203,168,118,84,68,69,103,154,188,221,204,186,151,101,68,52,86,121,171,205,220,203,169,135,101,68,86,104,154,188,221,204,186,152,118,101,86,103,137,171,205,220,204,186,152,119,102,103,136,154,188,237,205,203,170,152,135,119,136,154,188,222,220,220,203,170,153,136,153,154,188,205,238,222,220,203,186,170,170,170,188,205,223,237,237,220,203,187,187,187,188,205,238,254,222,237,221,204,204,204,204,221,239,255,237,254,238,237,221,205,221,222,255,255,255,124,204,204,204,220,205,221,222,238,255,208,0,0,0,188,203,186,170,170,170,170,171,187,188,140,221,203,187,186,170,171,187,188,205,220,204,203,186,170,153,154,170,171,188,221,203,203,186,169,153,137,153,154,171,188,220,187,186,153,136,136,136,137,154,171,204,187,186,169,136,119,119,119,136,154,171,203,171,169,136,119,102,102,119,137,154,188,186,170,152,119,102,85,102,120,137,171,203,170,169,135,102,85,85,102,120,154,171,186,169,152,118,85,68,85,103,137,154,187,170,153,135,102,84,69,86,120,153,171,186,170,152,118,101,85,86,103,137,170,187,170,169,136,118,101,86,102,120,154,171,186,186,153,135,118,102,103,120,137,171,203,187,170,153,135,119,119,120,137,154,188,187,203,170,153,136,136,136,137,154,187,204,188,187,170,153,153,137,153,170,187,205,203,204,203,170,169,153,170,170,187,204,220,189,220,187,186,170,170,187,187,204,222,204,221,220,204,187,187,187,204,205,221,237,140,203,187,187,187,187,187,188,204,221,176,0,0,0,171,186,170,169,153,153,153,170,170,187,155,204,187,170,170,170,170,170,187,204,203,188,186,170,153,153,153,153,170,187,204,186,187,169,153,136,136,136,153,170,187,203,171,169,152,136,119,120,136,153,170,187,186,170,152,135,119,119,119,136,153,170,186,170,153,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,101,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,102,119,136,154,186,170,169,152,135,119,119,119,136,154,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,152,136,136,137,153,170,188,187,203,186,169,153,153,153,154,170,188,203,188,203,186,170,170,170,170,171,188,205,203,220,203,187,186,170,171,187,188,205,220,155,187,186,170,170,170,170,187,188,204,176,0,0,0,172,203,187,170,170,170,170,171,187,188,140,220,203,187,170,170,187,187,204,205,220,189,203,186,170,153,170,170,187,204,221,203,203,186,169,153,153,153,154,171,188,219,187,186,153,136,136,136,137,154,171,188,187,186,169,136,119,119,120,136,154,187,203,171,169,136,119,102,102,119,137,154,187,186,186,152,119,102,85,102,120,137,171,187,170,153,135,102,85,85,102,120,153,187,186,169,152,118,85,68,85,103,137,170,187,170,153,135,101,84,69,86,120,153,171,186,170,152,118,101,85,86,103,137,154,187,171,169,136,118,101,86,103,120,154,171,186,186,153,135,118,102,103,120,137,171,187,187,186,152,136,119,119,120,137,154,188,187,187,170,153,136,136,136,137,154,171,203,188,187,170,153,153,153,153,154,171,204,203,220,187,170,170,153,154,170,187,204,220,205,204,203,187,170,170,171,187,204,221,204,221,204,204,187,187,187,204,204,222,237,140,203,187,187,187,187,187,187,204,205,176,0,0,0,223,238,237,220,204,188,204,204,220,205,126,255,238,221,204,204,205,222,238,239,253,239,237,220,204,187,187,187,204,238,255,237,238,220,187,170,170,170,187,205,223,254,222,220,186,169,153,153,154,171,205,239,237,236,186,153,136,119,136,154,187,221,237,221,203,153,135,118,103,120,154,188,206,221,219,169,135,102,85,102,120,154,205,237,204,186,152,118,84,69,103,137,171,205,220,203,169,118,84,52,69,103,154,188,221,204,186,151,101,68,52,86,121,171,205,236,203,169,135,101,68,86,120,154,188,221,204,186,152,118,101,86,103,137,171,206,221,220,186,152,119,102,119,137,171,205,237,221,203,170,152,135,120,137,154,188,223,237,237,203,170,153,137,153,170,188,222,239,222,221,204,186,170,170,171,188,222,254,253,254,221,204,187,187,187,204,221,255,255,223,239,237,221,204,204,205,238,254,255,253,239,238,254,221,221,237,238,255,255,255,141,221,221,221,221,221,237,254,239,255,208,0,0,0,255,255,255,255,254,237,221,221,221,204,143,255,255,255,255,253,254,239,255,255,253,255,255,255,254,205,220,221,221,255,255,239,255,255,220,204,188,188,221,221,255,255,255,254,221,187,170,170,187,204,223,255,255,255,220,186,152,136,137,171,204,222,255,255,253,186,152,119,119,137,171,221,255,255,254,203,152,101,85,103,137,172,223,255,255,219,168,117,68,69,103,138,205,255,255,253,186,135,84,51,69,120,171,206,255,239,203,168,117,67,52,87,138,189,255,254,253,202,151,101,68,69,120,171,221,255,239,220,169,135,101,85,103,154,206,255,254,255,219,169,135,118,119,154,188,255,255,239,252,203,169,136,136,154,188,223,255,254,254,220,203,170,170,170,188,222,255,255,223,254,220,220,187,187,204,223,255,255,253,255,254,237,221,220,222,254,255,255,255,223,255,255,239,238,239,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,140,220,220,222,254,255,255,255,255,255,240,0,0,0,222,238,221,220,204,204,204,204,204,204,143,255,238,221,221,221,221,221,221,254,237,255,254,221,204,204,204,204,205,221,239,221,238,220,203,187,171,187,188,205,222,237,222,221,203,170,153,153,170,188,205,238,221,221,203,169,136,136,137,154,188,221,237,205,203,169,135,119,119,136,154,188,222,221,220,186,135,102,85,103,137,171,205,221,205,202,152,118,84,69,103,138,172,222,220,219,169,135,84,51,69,120,154,205,221,205,202,152,117,67,52,86,137,172,206,220,220,186,135,101,68,85,120,154,205,237,205,203,169,135,101,85,103,138,188,222,220,220,186,152,135,118,119,137,171,205,238,205,220,186,153,136,136,137,171,205,223,220,237,203,186,169,153,154,171,188,239,254,206,221,204,187,170,187,187,204,222,255,237,237,237,220,204,204,204,221,222,255,255,222,238,221,221,221,221,222,238,255,255,253,238,238,238,238,222,238,239,255,255,255,141,221,221,221,221,221,237,238,239,255,224,0,0,0,223,237,220,204,187,187,187,188,204,204,174,254,237,204,187,187,187,204,205,222,237,238,221,203,186,170,170,171,188,205,222,221,220,203,170,153,153,153,170,187,205,220,221,203,169,152,136,136,137,154,188,205,204,203,169,136,119,119,119,137,154,188,220,204,186,152,118,102,102,119,137,171,188,204,186,152,118,101,85,102,119,137,171,204,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,204,187,169,136,118,101,85,102,120,154,189,219,203,169,135,118,102,102,120,154,188,221,204,186,153,136,119,119,120,137,171,205,220,203,186,153,136,136,136,153,171,205,237,205,203,186,169,153,153,154,171,204,222,236,221,204,187,170,170,170,187,205,222,254,206,221,204,203,187,187,188,205,222,255,252,238,221,220,204,204,204,221,238,255,255,157,204,204,204,204,204,221,222,238,255,224,0,0,0,239,255,237,221,220,204,204,204,204,204,143,255,238,221,220,204,204,221,221,238,237,255,253,220,203,187,187,188,204,221,238,223,254,220,187,170,170,170,187,204,222,253,239,220,186,153,152,153,154,171,204,222,222,236,186,152], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+928920);
/* memory initializer */ allocate([135,119,136,154,171,205,237,221,203,168,119,102,103,120,154,188,221,221,219,169,135,101,85,102,120,154,189,221,221,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,237,205,186,152,118,101,85,103,137,171,222,236,220,186,152,119,102,103,136,171,205,238,221,203,169,152,135,119,136,154,188,239,237,221,203,170,153,152,153,154,188,222,254,221,220,203,186,170,170,171,188,222,255,253,254,220,203,187,187,187,204,222,255,255,222,221,221,220,204,204,205,222,255,255,253,254,237,221,237,221,238,255,255,255,255,140,220,221,205,221,222,222,239,255,255,224,0,0,0,255,255,255,255,253,221,220,221,204,204,127,255,255,255,255,253,255,255,255,255,253,255,255,255,253,221,221,221,223,255,255,223,255,255,221,203,187,188,204,223,255,255,255,253,220,186,170,170,187,204,223,255,255,255,251,186,152,136,137,171,204,223,255,255,220,186,151,119,119,137,171,205,255,255,253,203,152,101,85,103,137,188,223,255,255,220,168,117,68,69,103,138,189,255,255,253,186,135,84,51,69,120,171,223,255,255,220,152,117,67,52,86,138,205,255,255,253,202,151,101,68,69,120,172,223,255,239,220,169,135,101,85,104,154,206,255,255,254,203,169,135,119,120,154,188,223,255,255,253,203,169,152,136,154,188,223,255,253,255,221,187,170,170,170,188,222,255,255,223,253,221,203,187,187,205,223,255,255,253,255,223,221,220,220,221,223,255,255,255,223,255,254,239,239,223,255,255,255,255,253,255,255,254,255,255,255,255,255,255,255,140,205,221,237,255,255,255,255,255,255,240,0,0,0,239,255,239,238,221,221,221,221,220,221,127,255,255,254,237,238,222,239,255,255,255,255,255,254,220,204,205,221,238,239,255,239,255,253,220,203,187,188,205,207,255,254,255,253,219,186,170,170,171,204,222,255,255,253,220,170,153,137,153,171,188,223,255,253,220,186,152,119,120,137,171,205,255,239,237,202,152,118,86,103,137,188,222,254,222,203,169,118,84,69,104,154,188,239,238,237,186,135,100,35,70,120,171,221,254,254,219,169,118,67,36,87,138,189,222,237,253,186,152,101,68,86,121,171,205,255,221,220,185,135,102,86,120,154,189,239,253,253,203,169,136,119,120,154,188,222,255,222,220,187,169,152,137,154,172,222,255,254,254,221,203,170,170,170,187,205,239,255,223,237,220,204,187,187,188,221,255,255,253,255,239,221,220,204,221,221,239,255,255,223,255,238,238,221,222,238,255,255,255,253,255,255,255,237,221,255,255,255,255,255,124,204,204,221,220,206,239,255,255,255,224,0,0,0,188,204,187,187,170,170,170,186,187,187,141,237,220,203,187,187,187,187,204,205,236,205,204,187,170,170,170,170,187,204,221,204,220,186,169,153,153,153,170,187,204,220,188,186,169,136,136,136,137,154,171,205,187,187,169,136,119,119,120,137,154,188,204,187,169,136,119,102,103,120,137,154,188,187,186,152,119,101,85,102,120,137,171,203,171,169,135,101,85,85,102,120,154,188,186,186,152,118,85,68,85,103,137,171,203,171,169,135,101,84,69,86,120,154,188,186,186,152,119,101,85,85,103,137,171,203,171,169,136,118,101,85,102,120,154,188,203,186,169,135,119,102,102,120,137,171,204,187,186,153,136,119,119,120,137,171,188,203,203,186,153,136,136,136,137,170,188,220,188,203,186,169,153,153,153,170,187,221,219,204,187,186,170,170,170,170,188,205,237,205,204,204,187,187,187,187,204,205,239,236,221,221,204,204,203,204,205,222,238,254,140,204,203,187,187,187,204,204,222,222,192,0,0,0,172,186,170,153,153,153,153,170,170,187,155,204,187,170,170,169,170,170,187,204,203,188,186,169,153,153,153,153,170,187,188,187,186,169,152,136,136,136,153,170,171,203,171,169,152,136,119,120,136,153,154,187,170,169,152,135,119,119,119,136,153,170,186,170,152,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,102,119,136,154,186,170,169,152,135,119,119,119,136,153,171,186,186,153,152,136,119,120,136,153,171,187,171,186,169,152,136,136,136,153,170,188,186,187,170,169,153,153,153,153,170,188,204,188,203,186,170,170,170,170,171,188,205,203,204,203,187,186,170,171,187,188,205,220,155,187,170,170,170,170,170,187,188,205,176,0,0,0,188,204,187,187,170,170,171,171,187,188,141,237,204,203,186,186,187,187,204,205,220,205,204,187,170,170,170,170,187,188,205,204,203,186,169,153,153,153,170,171,188,220,188,186,153,136,136,136,137,154,171,188,187,186,169,136,119,119,120,137,154,171,203,187,169,136,118,102,102,119,137,154,188,186,186,152,118,101,85,102,120,137,171,203,171,169,135,102,85,85,103,120,154,187,186,186,152,118,85,68,85,103,137,171,187,170,169,135,101,84,69,86,120,154,171,186,186,152,119,101,85,86,103,137,171,187,171,169,136,118,101,85,103,120,154,188,186,186,153,135,119,102,102,120,137,171,203,187,170,153,136,119,119,120,137,170,188,203,203,170,153,136,136,136,137,154,188,220,188,203,170,153,153,153,153,170,188,205,203,204,187,170,170,169,170,170,187,204,221,189,204,204,187,186,171,187,188,205,222,220,237,204,203,187,187,204,204,205,222,238,140,187,187,187,187,187,187,204,205,221,192,0,0,0,239,255,239,237,220,204,204,204,204,204,127,255,255,255,221,220,222,222,255,255,253,255,255,254,221,204,188,204,222,238,255,239,254,237,203,187,171,187,188,221,239,254,239,237,203,170,153,154,171,188,222,239,237,237,203,169,152,136,137,154,188,222,253,238,219,169,135,119,119,137,171,205,239,237,236,186,135,102,85,103,137,171,205,238,222,203,152,118,68,69,103,138,188,223,237,220,185,134,84,51,69,120,155,205,237,221,203,152,117,67,52,87,137,188,222,253,221,186,135,101,68,70,120,155,205,239,238,203,169,135,101,86,103,138,188,223,254,221,203,169,135,119,119,137,172,206,239,222,220,186,169,136,136,137,171,205,239,253,237,220,187,169,169,154,187,205,239,255,239,237,204,203,187,187,188,205,222,255,237,255,237,220,204,204,204,222,239,255,255,223,255,221,221,221,222,222,239,255,255,253,255,255,254,238,254,255,255,255,255,255,141,222,220,237,221,222,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,253,220,204,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,252,203,206,255,255,255,255,255,255,252,187,170,171,188,223,255,255,255,255,252,186,152,137,171,205,255,255,255,255,253,186,135,102,120,171,205,255,255,255,255,219,151,84,69,121,172,255,255,255,255,252,168,100,34,70,138,207,255,255,255,255,202,150,66,36,104,172,255,255,255,255,252,169,117,67,87,154,207,255,255,255,255,203,168,118,103,137,189,255,255,255,255,253,203,169,136,154,188,255,255,255,255,255,252,203,170,171,189,255,255,255,255,255,255,253,204,187,205,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,220,221,255,255,255,255,255,255,255,240,0,0,0,223,255,223,221,221,204,219,204,204,204,143,255,254,253,221,204,204,221,221,222,253,255,255,221,204,187,187,188,221,221,255,223,253,221,203,186,170,170,172,204,255,253,255,221,202,169,153,153,154,171,205,239,223,221,203,169,136,136,136,153,172,205,253,222,203,169,135,118,119,120,154,188,223,237,236,169,135,102,85,103,120,155,190,255,221,202,152,118,84,69,103,137,172,223,253,203,169,134,84,52,69,120,154,189,239,220,186,152,101,67,52,86,137,172,222,252,219,169,135,101,68,85,120,154,189,223,221,187,168,119,101,85,103,138,172,223,252,220,186,152,119,118,119,137,171,206,239,205,203,170,152,136,136,137,171,205,223,253,237,203,186,169,153,154,170,205,255,255,222,220,203,186,170,170,187,205,222,255,253,253,221,204,203,187,204,221,254,255,255,206,237,237,220,204,221,223,255,255,255,252,255,255,239,239,239,254,255,255,255,255,141,221,222,239,223,223,255,255,255,255,240,0,0,0,255,255,237,220,204,204,204,204,204,221,175,255,237,220,204,187,188,204,205,222,237,255,237,204,187,170,170,171,188,205,222,239,253,203,170,153,153,153,170,188,205,221,238,219,169,152,136,136,137,154,188,205,221,220,169,152,119,119,119,137,154,188,221,220,186,152,118,102,102,119,137,171,205,220,203,152,118,101,85,102,119,137,172,205,204,169,135,101,85,85,102,120,154,189,220,186,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,189,220,186,152,118,101,85,85,103,137,172,221,204,169,135,118,85,85,102,120,155,205,236,203,169,135,118,102,102,120,154,188,238,204,186,153,135,119,119,120,153,172,222,252,204,186,153,136,136,136,154,171,206,255,221,204,186,169,153,153,154,171,205,239,253,237,204,187,170,170,171,187,205,239,255,222,237,220,203,187,188,204,221,239,255,253,254,237,221,220,221,221,222,255,255,255,173,221,221,221,221,221,238,239,255,255,240,0,0,0,255,255,255,255,239,221,221,221,220,204,143,255,255,255,221,222,237,221,221,255,253,255,255,253,204,204,204,203,205,222,239,223,255,236,219,187,170,171,187,204,223,253,255,253,203,169,153,153,170,188,221,239,223,237,203,169,136,136,136,154,188,204,253,254,219,169,135,118,119,120,154,188,222,223,252,186,135,102,85,103,120,155,189,254,239,202,152,118,84,69,103,137,171,206,237,220,169,134,84,51,69,104,154,188,237,237,186,152,117,67,52,87,137,172,221,237,220,169,135,101,68,86,120,154,189,255,255,203,169,135,101,86,103,137,188,223,237,220,186,152,135,118,119,137,171,206,255,206,203,186,153,136,136,137,171,221,255,255,253,203,186,169,153,154,171,205,223,255,223,238,204,186,170,171,187,204,223,255,254,253,221,204,187,204,204,205,255,255,255,221,222,221,220,205,204,221,239,255,255,252,255,237,221,221,255,255,255,255,255,255,140,205,205,221,238,222,254,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,253,223,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,207,255,255,255,255,255,255,255,255,203,187,188,205,255,255,255,255,255,255,202,153,153,171,207,255,255,255,255,255,202,151,119,137,188,255,255,255,255,255,220,151,84,70,138,191,255,255,255,255,253,185,116,18,87,155,255,255,255,255,255,203,151,66,36,121,189,255,255,255,255,253,185,134,68,87,155,255,255,255,255,255,252,169,135,119,138,207,255,255,255,255,255,220,170,153,154,207,255,255,255,255,255,254,204,187,187,207,255,255,255,255,255,255,255,255,204,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,143,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,223,253,220,221,205,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,204,207,223,255,255,255,255,255,255,204,187,188,207,223,255,255,255,255,253,204,186,169,170,188,223,255,255,255,255,204,169,136,136,154,189,223,255,255,255,251,185,135,102,120,154,205,255,255,255,253,202,135,84,69,120,171,223,255,255,255,219,168,100,34,70,138,189,255,255,255,252,186,134,66,36,104,171,205,255,255,255,219,168,117,68,86,138,189,255,255,255,255,202,152,118,102,121,172,255,255,255,255,252,186,152,136,137,171,207,255,255,255,253,252,186,170,154,172,204,255,255,255,255,255,220,203,187,204,223,255,255,255,255,255,221,223,220,204,254,255,255,255,255,255,255,255,255,207,223,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,125,220,220,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,203,204,255,255,255,255,255,255,255,251,169,154,188,255,255,255,255,255,255,203,152,119,137,191,255,255,255,255,255,252,168,84,70,138,207,255,255,255,255,255,202,116,18,71,171,255,255,255,255,255,252,167,66,36,122,207,255,255,255,255,255,202,134,68,88,172,255,255,255,255,255,254,186,135,120,155,255,255,255,255,255,255,252,186,153,171,207,255,255,255,255,255,255,252,204,204,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,240,0,0,0,204,203,186,170,169,153,154,170,171,188,156,204,187,170,170,170,170,170,187,188,220,204,187,170,153,153,153,153,170,187,204,187,187,169,152,136,136,136,153,154,187,203,187,169,152,136,119,119,136,137,170,187,186,186,152,135,119,119,119,120,137,171,187,170,153,135,118,102,102,119,136,153,171,186,169,136,118,102,102,102,119,136,154,170,154,152,119,102,85,86,102,119,137,171,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,171,169,169,135,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,171,186,169,152,119,118,102,102,119,136,154,187,170,169,136,135,119,119,119,136,154,187,186,186,153,136,135,119,120,136,153,171,204,187,186,153,152,136,136,136,153,171,188,203,203,186,169,153,153,153,154,170,188,204,188,203,186,170,170,170,170,171,188,205,220,220,203,187,187,186,187,187,204,221,238,156,203,187,186,170,170,187,187,204,221,208,0,0,0,223,255,255,237,238,237,221,220,205,220,127,255,255,254,237,221,221,253,255,238,253,255,255,222,221,204,204,221,221,255,255,239,255,221,220,204,187,204,189,221,239,254,255,253,220,187,170,170,187,205,222,239,223,254,220,186,153,153,153,171,204,222,253,253,236,202,152,135,120,137,171,205,255,222,253,202,152,118,102,120,154,188,221,254,221,203,169,134,84,69,120,154,206,223,238,220,186,151,100,35,70,121,171,221,253,238,219,169,118,66,36,103,154,188,222,239,238,202,152,117,68,86,137,171,222,254,238,220,186,136,118,102,120,155,205,239,221,253,203,169,152,119,136,154,188,223,255,223,221,203,169,153,153,154,188,222,255,253,238,221,203,170,170,171,204,222,255,255,223,253,220,204,188,203,204,206,255,255,253,239,254,221,220,205,205,221,255,255,255,207,238,221,238,222,222,255,255,255,255,252,255,255,223,255,254,239,239,255,255,255,124,205,204,221,238,239,255,255,255,255,240,0,0,0,255,255,255,255,252,207,223,220,203,205,127,255,255,255,255,253,255,255,255,255,255,255,255,255,255,253,223,255,255,255,255,255,255,255,255,253,204,221,255,255,255,255,255,255,255,220,204,188,205,223,255,255,255,255,255,220,187,170,187,188,255,255,255,255,255,252,169,152,137,171,205,223,255,255,255,253,186,135,102,120,171,207,255,255,255,255,203,151,84,69,121,188,223,255,255,255,252,185,100,34,70,154,207,255,255,255,253,186,134,66,35,104,172,223,255,255,255,220,169,117,68,87,155,207,223,255,255,253,203,168,118,103,138,188,255,255,255,255,255,187,169,136,154,188,207,255,255,255,255,252,203,187,171,188,207,255,255,253,255,253,223,204,204,205,221,255,255,255,255,255,255,253,255,205,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,125,221,223,253,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,223,255,253,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,205,221,204,255,255,255,255,255,255,253,220,187,187,207,255,255,255,255,255,252,203,169,170,188,221,255,255,255,255,255,203,151,119,137,172,223,255,255,255,255,252,168,100,70,138,189,255,255,255,255,255,185,116,18,71,155,207,255,255,255,255,203,151,66,36,121,189,255,255,255,255,221,186,134,68,88,156,207,255,255,255,255,219,169,135,120,154,223,255,255,255,255,255,188,186,153,171,189,255,255,255,255,255,223,204,187,188,206,255,255,255,255,255,255,239,220,204,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,141,255,255,255,223,223,255,255,255,255,240,0,0,0,207,237,204,237,187,203,187,204,188,204,109,255,237,220,204,189,204,220,238,255,252,237,223,205,204,203,204,205,205,222,255,207,237,236,203,186,187,187,204,204,221,252,221,220,186,186,169,154,170,187,205,239,220,220,203,169,152,136,153,155,188,205,253,188,203,170,152,119,119,137,170,189,205,220,204,186,152,118,86,103,137,171,204,220,188,187,168,118,68,69,103,154,188,206,220,219,185,135,100,35,70,120,171,188,236,204,186,152,118,67,52,87,137,187,205,219,203,186,151,101,68,86,120,155,189,221,205,203,169,135,102,86,120,154,187,223,235,220,186,169,135,119,120,138,187,205,253,204,219,187,153,152,136,154,170,188,223,220,221,188,187,170,153,170,171,188,206,254,223,253,204,187,170,187,187,204,220,255,236,255,220,220,204,187,188,205,237,237,254,222,238,237,205,204,204,221,221,239,239,236,239,254,237,237,222,237,238,254,255,255,108,204,221,221,221,188,204,237,221,239,192,0,0,0,255,255,255,255,237,221,221,222,239,255,207,255,255,221,220,204,205,222,221,255,255,255,255,236,203,186,170,187,204,223,255,255,255,220,186,169,153,154,170,188,239,255,253,220,186,152,136,136,153,170,188,223,255,221,186,152,119,119,119,137,171,188,255,253,202,152,118,102,102,119,137,171,205,237,219,168,118,101,85,86,120,137,188,223,220,185,135,101,85,85,86,120,155,205,237,202,152,118,85,68,85,103,137,172,239,220,169,135,101,84,69,86,120,154,205,253,218,152,118,85,85,85,103,137,172,223,220,185,135,118,85,85,102,120,171,223,253,203,169,135,118,102,102,120,154,190,239,222,203,169,135,119,119,120,154,188,223,254,220,186,169,152,136,136,154,188,254,255,254,220,186,169,153,153,170,188,223,255,255,253,220,187,187,170,187,188,223,255,255,255,255,222,220,204,205,206,239,255,255,254,255,255,223,221,237,222,255,255,255,255,190,254,255,255,255,255,255,255,255,255,240,0,0,0,239,254,255,253,236,221,204,204,204,221,111,255,255,255,253,221,255,223,255,255,255,255,255,253,237,204,205,255,237,255,223,255,255,255,221,204,204,204,221,239,255,254,255,254,253,204,203,187,189,253,239,255,223,238,253,203,186,169,171,188,221,223,255,255,220,203,169,136,136,154,188,223,255,255,254,220,169,135,102,120,155,204,221,254,237,220,186,151,84,69,121,171,221,255,253,221,203,168,100,34,70,138,188,223,254,221,220,186,134,66,36,104,171,205,255,237,221,203,169,117,68,87,138,189,223,255,223,221,203,152,118,103,137,188,205,255,255,255,220,186,152,136,137,171,205,222,254,223,253,237,187,169,170,188,205,223,255,239,255,255,220,202,187,188,205,223,255,255,223,255,220,221,204,204,221,239,255,255,253,255,255,239,221,220,223,255,255,255,255,207,255,255,223,221,253,253,255,255,255,253,237,255,254,223,255,255,255,255,255,255,108,221,220,204,253,253,221,223,255,255,224,0,0,0,255,255,255,223,253,205,220,253,221,221,143,255,255,255,223,255,255,255,255,255,255,255,255,255,205,255,221,223,255,255,255,255,255,255,253,204,204,205,222,223,255,255,255,255,252,203,187,203,204,207,253,255,255,253,253,203,170,169,170,188,205,255,255,255,223,187,169,136,136,154,188,223,255,255,255,220,169,135,102,120,154,204,255,253,255,220,186,135,84,69,121,171,220,223,255,253,202,152,100,34,70,138,189,255,255,223,220,185,134,66,36,104,156,207,223,255,255,203,169,117,68,86,138,189,255,255,255,221,187,152,118,102,121,171,223,255,255,255,204,186,153,136,137,171,221,255,255,239,255,204,186,170,170,171,205,255,255,255,255,255,220,187,187,188,205,255,255,255,223,255,221,220,221,205,221,255,255,255,255,255,253,255,221,223,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,253,255,255,255,255,255,125,221,223,253,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,187,188,255,255,255,255,255,255,255,203,169,154,191,255,255,255,255,255,255,250,152,119,137,175,255,255,255,255,255,251,168,100,70,138,207,255,255,255,255,255,185,116,18,71,154,255,255,255,255,255,251,151,66,36,121,191,255,255,255,255,255,234,134,68,87,155,255,255,255,255,255,255,185,135,120,155,255,255,255,255,255,255,255,170,153,170,255,255,255,255,255,255,255,253,251,187,239,255,255,255,255,255,255,255,255,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,253,205,204,207,187,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,254,254,252,255,255,255,255,255,255,255,255,255,188,188,204,255,255,255,255,255,255,252,186,153,170,188,223,255,255,255,255,255,185,152,136,170,191,255,255,255,255,205,185,135,102,120,154,207,255,255,255,255,202,135,84,69,121,171,223,255,255,253,251,168,100,34,70,138,189,255,255,255,255,185,134,66,36,104,171,255,255,255,255,252,168,117,68,86,155,205,255,255,255,255,202,152,118,102,137,204,255,255,255,255,255,186,152,136,137,187,255,255,255,255,223,251,203,170,170,188,223,255,255,255,255,255,220,204,171,188,255,255,255,255,255,255,255,252,205,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,108,188,207,255,205,255,255,255,255,255,240,0,0,0,220,219,186,170,169,170,169,171,187,204,175,253,187,186,169,170,154,171,187,205,220,203,187,170,153,153,137,154,170,187,204,204,187,170,153,136,136,136,153,170,171,203,187,185,136,135,119,119,136,137,170,187,202,170,152,135,119,119,119,120,137,171,202,170,152,135,102,102,102,103,120,154,171,187,170,136,119,102,102,102,103,120,154,187,170,152,119,102,85,86,102,119,137,155,170,169,135,118,101,85,86,102,120,153,171,170,152,119,102,85,85,102,119,137,156,169,169,135,118,102,85,102,103,120,154,187,154,152,135,118,102,102,102,120,137,154,186,169,152,135,118,102,103,119,136,155,188,170,153,152,119,119,119,119,137,154,188,202,170,153,136,135,119,119,137,153,171,221,203,203,169,137,136,136,136,153,170,188,203,220,186,169,153,152,153,154,186,188,220,236,204,171,186,154,154,170,171,188,239,236,236,203,187,187,186,187,187,204,220,238,172,188,203,186,202,186,188,187,221,221,240,0,0,0,191,223,204,237,186,188,203,187,187,207,111,255,220,255,239,237,253,255,255,255,253,223,255,253,255,220,223,253,253,253,255,239,255,255,255,220,187,203,252,255,255,252,207,252,255,203,187,171,204,191,253,255,255,255,203,187,169,169,172,190,238,254,237,207,255,218,169,136,136,170,205,205,255,220,255,251,169,134,102,120,171,204,253,252,207,221,218,134,84,70,121,173,207,255,204,255,203,169,100,34,71,138,203,255,255,207,253,185,134,66,36,104,155,206,253,204,253,187,169,118,68,87,138,188,238,222,237,255,219,168,118,102,120,172,205,223,253,255,251,203,169,136,137,155,207,207,255,223,252,223,202,169,170,170,207,221,255,252,255,253,204,204,187,171,204,207,255,252,207,221,252,255,203,205,255,223,255,255,252,255,223,223,207,252,207,255,255,223,253,207,255,207,255,252,223,255,255,255,255,204,255,255,255,207,253,252,255,255,255,255,109,204,205,189,220,253,205,207,255,255,176,0,0,0,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,204,255,255,255,255,255,255,255,255,204,203,204,204,207,255,255,255,255,255,188,186,169,170,207,255,255,255,255,255,251,169,136,136,154,191,255,255,255,255,251,185,134,102,120,154,207,255,255,255,255,185,135,84,69,120,172,255,255,255,255,251,168,100,34,70,138,188,255,255,255,252,202,134,66,36,104,156,255,255,255,255,252,168,117,68,86,138,204,255,255,255,255,186,152,118,102,137,188,255,255,255,255,255,186,152,136,137,172,255,255,255,255,255,251,203,170,169,187,207,255,255,255,255,255,255,188,187,207,239,255,255,255,255,255,255,255,255,222,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,207,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,249,255,255,159,111,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,156,255,255,255,255,255,255,255,255,255,120,255,255,255,255,255,255,255,255,255,101,71,255,255,255,255,255,255,255,255,148,18,88,255,255,255,255,255,255,255,248,82,20,255,255,255,255,255,255,255,255,248,84,120,159,255,255,255,255,255,255,255,223,135,255,255,255,255,255,255,255,255,255,153,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,249,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,152,152,255,255,255,255,255,255,255,255,249,116,87,159,255,255,255,255,255,255,250,133,18,89,159,255,255,255,255,255,255,249,82,20,137,255,255,255,255,255,255,255,151,84,103,255,255,255,255,255,255,255,255,248,137,159,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,255,252,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,246,255,255,255,255,95,255,255,255,246,246,111,104,245,255,255,255,255,246,102,246,255,111,255,255,255,246,255,255,255,255,246,111,255,255,255,255,255,255,255,102,246,111,255,255,255,255,111,255,111,102,102,255,111,246,255,255,111,207,255,111,255,246,111,111,255,111,255,246,86,246,246,86,255,255,102,255,255,255,255,255,255,101,86,111,255,246,255,111,255,255,246,102,246,255,102,111,255,111,255,111,246,255,102,111,86,246,255,255,255,255,255,255,246,111,70,245,111,111,255,245,107,175,255,95,255,255,111,111,246,255,255,255,255,111,246,102,245,255,95,255,255,111,255,255,255,245,85,246,246,255,255,111,255,255,111,246,255,246,246,255,255,255,255,111,255,255,255,246,111,111,255,255,255,255,255,255,255,255,111,246,255,111,255,255,255,111,246,255,246,255,255,255,255,255,255,255,255,255,246,255,255,255,255,255,246,255,255,255,111,111,255,255,255,255,240,0,0,0,255,255,255,159,255,255,255,249,255,159,79,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,255,255,249,255,255,255,255,255,255,152,152,255,255,255,255,255,255,255,255,249,248,103,143,255,255,255,255,255,255,248,151,84,71,159,255,255,255,255,255,255,143,116,18,87,143,249,255,255,159,255,159,152,82,36,127,255,255,255,255,255,255,255,247,84,88,255,255,255,255,255,255,255,255,247,248,159,159,255,255,255,255,255,255,249,255,137,255,159,255,255,255,255,255,249,249,255,255,255,255,255,255,255,255,255,249,249,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,249,153,255,159,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,186,255,255,255,255,255,255,255,255,255,170,186,255,255,191,255,255,255,255,255,168,119,154,255,255,255,255,255,255,255,248,84,69,154,255,255,255,255,255,255,250,132,34,71,175,255,255,255,255,255,255,168,66,20,122,223,255,255,255,255,255,255,150,68,89,175,255,255,255,255,255,255,251,151,120,171,255,255,255,255,255,255,255,191,250,191,255,255,255,255,255,255,255,255,251,191,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,255,251,255,255,255,255,255,255,255,240,0,0,0,255,251,255,255,255,255,255,248,255,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,247,255,255,255,255,255,255,255,255,255,247,255,255,255,255,255,255,255,255,246,255,255,255,255,255,255,255,255,255,247,118,247,255,255,255,255,255,239,255,255,111,103,111,255,255,255,255,255,255,255,247,247,85,95,255,255,255,255,255,255,247,85,68,70,127,127,255,255,255,255,247,245,84,68,87,102,127,255,255,255,255,246,117,68,52,70,111,255,255,255,255,255,127,85,69,69,86,255,255,255,253,207,111,127,117,87,86,127,255,255,255,255,255,255,255,118,102,127,255,255,255,255,255,255,247,127,247,127,255,255,255,255,255,255,255,255,247,255,255,247,255,255,255,255,255,255,111,127,255,247,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,127,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,143,255,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,167,120,255,255,255,255,255,255,255,255,252,68,69,143,255,255,255,255,255,255,255,115,34,72,255,255,255,255,255,255,255,247,66,36,127,255,255,255,255,255,255,255,134,67,76,255,255,255,255,255,255,255,255,248,119,143,255,255,255,255,255,255,255,255,248,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,79,249,255,255,255,255,255,255,255,255,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,143,255,255,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,207,255,255,255,247,127,255,255,255,255,255,255,255,248,117,103,120,255,255,255,255,255,255,249,118,67,70,143,255,255,255,255,255,255,246,99,35,88,143,255,255,255,255,255,255,175,67,35,87,255,255,255,255,255,252,255,133,84,69,143,255,255,255,255,255,255,143,247,85,104,255,255,255,255,255,255,255,255,248,191,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,79,248,248,255,255,255,255,255,255,255,240,0,0,0,255,255,251,255,255,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,191,191,255,255,255,255,255,255,255,255,250,175,255,255,255,255,255,255,255,255,249,135,136,159,255,255,255,255,255,255,170,135,102,120,175,191,255,255,255,255,191,167,84,69,106,255,255,255,255,255,255,247,100,34,70,137,223,255,255,255,251,255,118,66,36,104,191,255,255,255,255,255,249,117,68,87,169,255,255,250,255,255,255,151,118,103,143,255,255,255,255,255,255,175,186,152,138,187,255,255,255,255,255,255,175,250,175,191,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,207,255,255,255,255,255,79,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,249,159,255,207,153,255,63,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,120,143,255,255,255,255,255,255,255,255,100,71,255,255,255,255,255,255,255,250,132,34,72,255,255,255,255,255,255,255,247,66,20,127,255,255,255,255,255,255,255,247,68,111,255,255,255,255,255,255,255,255,153,136,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,239,255,255,238,239,255,255,63,255,254,238,238,239,255,255,255,255,255,255,255,255,255,254,238,238,238,238,238,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,255,255,254,238,238,238,238,238,238,238,238,238,238,238,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,246,255,255,255,255,255,255,255,255,255,100,86,255,255,255,255,255,255,255,255,243,18,70,255,254,238,238,238,238,238,238,82,36,238,238,238,238,238,238,238,238,238,68,110,238,238,238,238,238,239,255,255,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,254,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,131,71,255,255,255,255,255,255,255,255,244,18,79,255,255,255,255,255,255,255,247,66,36,255,255,255,255,255,255,255,255,247,68,119,255,255,255,255,255,255,255,255,253,143,255,255,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,156,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,255,255,255,255,255,255,255,255,255,240,0,0,0,190,221,236,221,221,220,222,238,255,255,205,254,253,221,220,205,221,238,239,255,255,222,253,204,204,187,187,204,205,255,255,253,237,220,187,170,170,170,187,205,255,255,223,236,187,169,153,153,153,171,205,255,253,236,187,169,136,119,120,137,171,205,254,237,203,169,135,118,102,119,137,171,205,252,220,169,135,118,101,102,103,137,188,223,220,202,152,118,85,85,86,120,154,205,221,219,169,135,101,84,85,86,121,172,221,220,186,151,101,84,68,85,103,138,189,222,203,169,118,101,84,85,102,121,171,205,237,202,152,118,85,85,86,120,154,189,222,220,185,135,102,101,102,119,137,172,220,239,203,169,135,118,102,119,137,171,205,223,254,203,169,136,119,120,137,171,204,237,255,237,203,169,153,153,153,171,188,223,223,255,237,204,186,170,170,171,188,222,253,255,255,254,220,203,187,188,204,238,239,239,255,255,254,238,204,221,221,223,239,255,223,255,254,255,221,221,221,221,222,222,176,0,0,0,173,203,187,188,203,252,219,205,255,255,207,255,189,204,220,219,255,255,255,255,255,207,204,220,187,171,186,188,205,221,221,251,221,251,171,170,154,170,170,188,255,255,207,252,203,186,153,153,153,171,188,207,251,219,186,169,152,135,120,136,170,188,223,207,251,169,136,119,119,119,137,170,191,207,204,169,152,118,101,86,103,137,171,252,203,218,168,118,101,85,86,120,154,188,203,251,169,135,101,68,69,86,121,155,204,191,186,151,117,84,68,86,104,154,190,251,219,169,134,101,68,69,103,137,170,204,223,187,152,118,85,85,102,120,154,172,220,252,169,135,102,102,102,120,138,171,187,252,188,185,135,118,119,119,137,171,220,188,252,187,169,152,136,136,153,154,203,203,255,252,202,170,153,153,169,155,188,205,223,255,207,187,186,170,170,187,188,207,221,255,255,253,204,203,187,204,187,219,255,207,255,255,221,253,191,220,203,191,223,252,255,255,254,237,255,203,188,220,188,188,160,0,0,0,205,223,221,221,220,221,221,222,255,255,223,255,254,221,220,204,205,222,239,255,255,239,253,220,187,187,187,187,205,223,255,253,254,220,187,170,154,170,171,205,239,255,223,220,186,169,152,136,137,170,189,223,253,236,186,153,136,119,119,137,154,188,239,221,203,153,135,118,102,103,136,171,205,253,219,169,135,102,101,86,103,137,171,237,220,186,152,118,85,85,86,119,138,189,221,203,168,118,101,85,85,102,120,171,205,220,185,135,101,85,68,85,103,137,189,221,203,168,118,101,85,85,102,120,155,205,220,186,152,118,85,85,86,120,154,188,222,219,169,135,102,101,102,103,137,171,221,237,203,169,135,118,102,119,137,155,204,222,236,203,169,136,119,120,137,154,188,237,255,221,186,169,152,136,137,170,188,221,223,255,253,187,170,170,170,171,188,221,237,255,254,253,203,187,187,188,188,221,239,239,255,255,254,220,204,204,204,222,223,254,223,255,255,254,221,220,205,221,222,222,192,0,0,0,238,238,238,222,238,238,221,222,238,238,238,238,237,221,221,222,238,238,238,238,238,238,238,238,238,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,221,221,221,221,221,221,221,221,77,221,221,221,221,222,238,238,227,238,228,238,238,238,238,238,238,238,238,238,94,238,238,238,238,238,238,238,238,238,238,62,78,238,238,238,238,238,238,238,68,68,77,221,221,221,221,221,221,221,68,77,221,212,77,221,221,221,221,221,212,211,61,77,221,221,221,221,221,222,238,228,228,238,238,238,238,238,238,238,238,238,78,238,68,238,228,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,228,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,237,237,238,238,238,238,238,238,238,238,238,78,238,238,238,238,238], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+939160);
/* memory initializer */ allocate([237,237,237,238,224,0,0,0,173,221,221,221,221,220,253,255,255,255,221,255,223,221,204,204,204,223,255,255,255,239,221,220,204,187,187,188,204,223,255,254,253,236,187,170,154,170,171,205,223,255,205,205,186,169,152,136,153,154,205,223,253,220,186,169,136,119,120,137,154,189,255,204,203,169,135,118,102,119,137,154,223,252,219,185,135,102,101,102,103,137,172,221,221,186,152,118,85,85,86,120,138,205,237,203,168,118,101,85,85,102,120,155,222,220,186,135,101,85,69,85,103,138,189,205,203,168,118,85,84,85,86,120,171,205,237,186,152,118,85,85,86,120,154,188,205,251,169,135,102,101,102,103,137,171,205,255,219,168,135,118,102,119,137,171,204,223,253,202,152,136,119,119,137,154,188,237,255,253,203,169,152,136,153,170,188,221,223,255,220,203,170,170,154,171,188,206,237,255,255,253,204,187,188,187,204,221,255,239,255,255,255,220,204,205,220,223,255,239,223,255,254,252,236,205,204,221,205,221,176,0,0,0,172,203,187,187,186,171,187,204,204,239,188,221,204,203,187,187,187,188,204,238,254,204,204,187,170,170,170,170,171,204,222,236,204,186,170,153,152,153,154,171,188,221,188,186,169,152,136,136,136,153,171,188,219,187,169,152,135,119,119,120,153,171,204,187,170,152,119,118,102,119,120,154,172,203,186,152,135,102,102,102,103,120,154,187,187,169,135,118,101,85,102,119,137,171,187,186,152,118,101,85,85,102,120,154,171,187,153,135,102,85,85,86,103,137,170,171,186,152,118,101,85,85,102,120,154,187,187,169,135,118,101,85,102,119,137,171,187,186,152,135,102,102,102,103,136,154,187,204,170,152,119,118,102,119,120,153,171,188,203,169,152,135,119,119,136,153,171,187,204,203,169,152,136,136,136,153,170,188,189,221,187,170,153,153,153,153,170,187,204,238,220,203,186,170,170,170,171,188,205,207,254,221,204,187,186,187,187,188,205,220,206,221,220,203,187,187,187,187,187,204,160,0,0,0,155,187,186,170,170,170,171,187,204,221,188,220,204,187,186,170,170,171,203,205,238,189,204,187,170,153,153,154,170,188,205,219,204,170,169,153,136,137,153,154,188,220,188,186,153,152,136,119,136,137,154,188,203,186,169,136,135,119,119,120,137,154,187,171,169,136,119,118,102,103,120,137,171,186,170,152,119,102,102,102,103,120,154,186,170,153,135,118,102,102,102,103,137,170,170,169,136,118,102,85,86,102,120,137,170,170,152,119,102,85,85,102,103,136,154,170,169,136,118,102,85,86,102,120,137,170,186,152,135,102,102,102,102,119,136,154,171,186,152,119,102,102,102,103,136,154,170,186,169,136,119,102,102,119,120,153,171,171,187,169,136,119,119,119,120,137,171,187,204,186,169,136,136,136,136,137,154,188,188,203,186,153,153,136,137,153,170,187,203,221,220,186,169,153,153,170,170,187,205,190,238,204,203,186,170,170,187,188,205,219,205,236,187,187,186,170,170,171,187,188,144,0,0,0,155,186,170,170,153,153,170,170,187,204,187,203,187,170,170,170,170,170,187,204,220,188,187,170,153,153,153,153,170,171,204,202,187,170,153,152,136,136,137,154,171,203,171,170,153,136,135,119,136,136,154,171,186,170,153,136,119,119,119,120,137,154,170,170,169,136,119,118,102,119,119,137,154,170,169,152,119,118,102,102,103,120,137,170,154,152,135,118,102,102,102,119,136,154,153,169,136,118,102,102,102,102,119,137,169,154,152,119,102,101,86,102,103,120,154,153,169,135,118,102,101,102,102,119,137,169,170,152,135,102,102,102,102,119,136,154,154,169,136,119,102,102,102,119,120,153,170,170,153,136,119,102,102,119,120,137,154,170,186,153,136,119,119,119,120,137,154,170,187,170,153,136,135,120,136,137,154,171,171,203,170,153,136,136,136,137,154,171,186,205,203,170,169,153,153,153,154,171,188,189,220,203,186,170,170,170,170,187,188,203,204,203,186,170,153,153,153,170,170,187,144,0,0,0,155,187,186,170,170,170,170,187,188,221,204,203,188,186,170,170,170,171,172,205,222,189,203,170,153,153,153,153,170,187,204,202,188,186,153,152,136,137,137,154,187,204,171,170,153,136,135,119,136,137,154,187,186,186,153,136,119,119,119,120,137,170,204,170,169,136,135,118,102,119,120,137,171,186,185,152,119,102,102,102,119,120,153,170,170,153,135,118,102,102,102,103,136,154,170,169,135,118,102,101,86,102,120,137,170,170,152,135,102,101,85,102,103,136,154,170,169,136,118,102,85,86,102,120,137,170,170,153,135,118,102,102,102,119,136,154,170,169,152,119,102,102,102,103,120,154,186,171,169,135,119,102,102,119,120,153,170,187,186,153,136,119,119,119,120,137,171,186,187,170,153,136,135,136,136,137,154,171,189,187,186,169,152,136,136,153,154,171,187,221,203,171,169,153,153,154,170,188,188,189,220,187,187,170,169,170,170,187,220,220,190,220,187,170,170,170,170,170,171,187,144,0,0,0,156,187,187,170,170,170,171,187,204,222,203,236,204,187,170,170,171,187,188,221,238,189,203,186,170,153,153,170,171,188,206,219,203,186,169,153,136,137,153,170,188,220,188,186,169,152,136,136,136,153,170,188,203,187,169,136,135,119,119,120,137,171,188,171,169,152,119,118,102,119,120,153,171,186,186,152,135,118,102,102,103,120,154,187,170,153,135,118,102,85,102,103,137,154,170,169,136,118,102,85,85,102,120,153,170,170,152,135,102,85,85,86,103,136,154,170,169,136,118,101,85,86,102,120,153,170,171,153,135,118,102,86,102,119,137,154,171,186,152,119,102,102,102,119,136,154,170,187,169,152,119,118,102,119,120,153,171,187,203,169,136,119,119,119,136,153,170,187,204,186,169,152,136,136,136,153,170,188,188,220,186,169,153,136,153,153,170,187,203,205,220,187,170,153,153,170,170,187,205,189,237,204,187,187,170,170,171,188,204,220,189,220,203,187,170,170,170,187,187,188,144,0,0,0,189,237,221,221,221,222,238,255,255,239,191,255,253,221,221,221,238,255,255,255,255,239,237,220,204,204,204,221,255,255,255,253,254,220,203,187,187,187,204,239,255,255,222,220,187,170,153,153,170,188,223,255,237,236,203,169,152,136,136,154,189,239,255,221,203,169,136,118,103,120,154,205,239,253,220,186,152,118,85,86,120,155,205,238,222,203,152,118,84,68,86,121,172,222,237,220,185,135,84,68,69,103,154,205,237,222,203,152,101,68,68,86,120,171,222,222,252,185,135,85,68,69,103,154,188,237,238,219,168,118,85,85,103,137,171,206,239,253,202,152,118,102,103,120,155,189,237,255,253,186,152,135,119,136,154,188,222,223,254,220,186,153,153,153,154,187,205,237,255,255,236,187,170,170,170,187,205,254,239,255,255,236,220,187,187,204,204,222,253,255,255,255,254,237,220,205,221,222,239,239,255,255,255,255,238,254,222,238,255,255,207,255,255,238,221,222,254,221,222,238,176,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,191,221,220,204,188,205,221,223,255,255,205,223,220,203,203,203,204,205,255,255,255,222,220,204,187,186,171,187,205,255,255,252,221,187,170,153,153,154,171,205,223,255,220,187,169,152,136,136,137,171,188,223,252,204,169,152,135,119,119,137,171,189,255,204,186,152,119,102,102,119,137,171,221,252,202,153,135,102,85,86,103,137,171,255,204,169,135,102,85,85,86,120,154,190,236,186,152,118,85,84,85,103,137,171,205,204,169,135,101,84,69,86,120,154,188,221,203,152,118,85,85,85,103,120,171,204,204,186,151,118,85,85,102,120,154,188,223,219,169,135,118,102,102,119,137,171,205,221,219,168,135,119,103,119,137,170,189,255,221,202,169,136,119,136,137,154,188,220,255,253,203,170,153,137,153,170,188,207,207,255,253,203,186,170,170,171,188,220,255,255,255,253,203,187,187,187,204,205,223,255,255,255,254,220,204,204,221,204,254,223,223,255,255,221,204,205,204,207,221,221,192,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,191,221,237,237,221,222,238,255,255,255,206,255,255,254,222,238,239,255,255,255,255,239,254,221,204,204,204,221,222,255,255,254,254,237,204,187,187,187,205,239,255,255,222,221,187,170,153,153,171,205,237,255,254,253,203,169,152,136,136,154,189,239,255,223,220,185,135,118,103,120,154,206,255,254,221,186,151,118,85,86,120,155,206,255,237,219,168,118,84,68,86,121,172,239,238,236,185,134,84,68,69,103,154,205,254,238,203,152,101,68,68,86,121,172,239,253,236,185,135,85,68,69,103,154,205,253,239,219,168,118,85,85,103,137,172,223,238,253,203,152,118,102,103,120,171,205,238,255,253,186,152,135,119,136,154,188,223,239,255,237,186,169,153,153,170,188,221,238,255,255,220,203,170,170,171,188,205,238,239,255,255,237,204,204,204,204,205,239,254,255,255,255,237,221,221,221,221,239,255,255,255,255,255,255,238,254,239,255,255,255,191,239,255,238,237,238,237,254,254,238,176,0,0,0,172,203,187,187,187,171,187,204,205,222,188,221,204,187,187,187,187,188,205,223,253,188,203,186,170,170,170,170,187,205,238,235,203,186,169,153,153,153,170,171,205,221,188,186,153,136,136,136,137,154,171,205,203,186,169,136,119,119,119,136,154,188,204,187,169,152,119,102,102,119,136,154,188,203,186,152,119,102,101,102,119,137,171,187,187,169,135,102,85,85,102,120,153,171,186,186,152,118,101,84,85,103,120,154,187,187,169,135,102,84,69,86,119,137,171,187,186,152,118,101,85,85,103,120,154,187,187,169,135,118,101,85,102,120,137,171,187,186,153,135,118,102,102,119,137,170,187,204,186,152,135,119,119,119,136,154,171,188,203,186,153,136,135,120,136,154,171,203,205,203,186,153,152,136,153,154,171,188,205,221,203,186,170,153,153,170,171,188,220,222,221,203,187,186,170,170,187,204,221,206,238,221,204,203,187,187,187,204,221,236,189,221,204,204,187,187,187,187,204,204,160,0,0,0,155,186,169,153,153,153,154,171,188,204,187,204,187,170,170,153,169,170,187,189,220,171,186,169,153,153,153,153,154,187,205,202,186,169,153,136,136,136,137,154,187,203,171,169,152,136,136,119,136,137,154,187,185,169,152,135,119,119,119,120,137,170,187,154,152,135,119,102,102,119,120,137,170,169,169,136,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,153,135,118,102,85,86,103,120,137,170,154,152,119,102,101,85,102,119,136,154,153,169,136,118,102,101,102,103,120,137,169,153,152,135,118,102,102,102,119,136,154,154,169,152,119,102,102,102,119,136,153,170,170,169,136,119,119,119,119,120,137,170,170,186,153,136,119,119,119,136,137,154,170,187,186,153,136,136,136,136,137,154,171,187,203,170,169,152,136,137,153,154,171,187,204,187,170,169,153,153,153,154,171,188,189,221,203,187,170,170,170,170,187,188,219,189,203,186,170,170,170,170,170,171,187,160,0,0,0,155,170,169,153,153,153,154,170,187,204,187,203,186,170,169,153,154,170,171,204,220,171,170,169,153,153,153,153,154,171,188,202,186,153,152,136,136,136,137,154,171,203,170,169,136,136,119,119,120,137,154,171,185,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,119,120,137,170,169,153,135,119,102,102,102,103,120,137,170,153,152,119,102,102,102,102,119,136,154,169,153,135,118,102,102,102,102,120,137,170,153,152,119,102,101,86,102,103,136,154,153,153,135,118,102,102,102,103,120,137,169,154,152,119,118,102,102,102,119,136,154,170,169,136,119,118,102,102,119,120,137,170,170,153,136,119,119,103,119,120,137,154,170,170,153,136,119,119,119,120,137,154,170,187,170,153,136,136,136,136,136,153,171,171,187,170,153,152,136,136,153,153,170,187,204,203,186,169,153,153,153,154,171,187,189,220,203,187,170,170,170,170,187,188,203,205,203,187,170,170,153,170,170,171,187,160,0,0,0,155,186,170,169,170,170,171,187,188,205,171,204,187,187,170,170,186,188,205,237,236,188,187,186,169,169,169,170,171,188,222,219,187,186,153,153,153,153,154,171,188,220,171,170,153,136,136,136,136,153,171,204,186,186,153,136,135,119,119,120,137,171,204,170,169,136,119,102,102,119,120,154,187,186,170,152,119,102,102,102,103,137,154,186,170,153,135,102,85,85,102,119,137,171,170,170,152,118,101,85,85,103,120,154,186,170,153,135,102,85,85,86,103,137,170,186,169,152,118,101,85,86,103,120,154,186,171,169,135,118,101,85,102,120,137,170,171,186,152,135,102,102,102,119,137,154,170,187,169,152,135,119,103,119,136,154,171,172,203,170,152,135,119,120,137,153,170,186,204,203,169,153,136,136,137,153,170,187,172,204,187,170,153,153,153,154,171,187,203,206,220,203,186,170,170,170,170,187,204,190,237,220,204,187,187,187,170,188,204,219,173,221,187,187,187,186,170,187,187,188,144,0,0,0,155,187,170,170,170,170,187,188,205,205,171,204,203,187,170,170,187,188,205,222,253,188,187,170,170,154,170,170,187,205,222,219,187,170,153,153,137,153,154,171,205,220,187,170,153,136,136,136,137,154,187,204,202,186,153,136,119,119,119,136,154,187,204,171,169,136,119,102,102,119,136,154,188,202,170,152,119,102,101,102,103,137,170,203,170,153,135,102,85,85,102,119,137,171,186,170,152,118,101,85,85,103,120,154,187,170,169,135,102,85,69,86,103,137,171,187,186,152,118,101,85,85,103,120,154,187,187,169,135,118,101,85,102,120,137,171,187,186,153,135,118,102,102,119,137,154,187,188,186,152,135,119,119,119,136,154,171,188,203,186,153,136,119,120,136,153,171,187,205,203,170,153,152,136,137,153,170,187,189,237,203,186,169,153,153,170,170,188,203,222,237,204,187,170,170,170,187,187,205,189,254,237,204,204,187,187,187,188,204,219,173,221,204,204,187,187,171,187,187,188,144,0,0,0,175,223,223,253,221,205,223,253,255,221,159,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,223,255,255,255,255,255,255,255,223,223,205,255,255,255,255,255,255,255,253,223,204,205,253,255,255,255,253,255,255,253,186,136,172,223,253,255,255,255,255,255,202,116,70,156,255,255,255,255,255,223,252,133,34,71,223,255,255,253,255,255,255,216,66,19,123,223,255,255,255,255,255,220,166,67,88,207,253,255,255,255,255,255,253,168,120,171,223,255,255,255,255,255,255,252,219,188,223,223,255,255,255,255,255,252,255,221,253,223,223,255,253,255,255,255,255,255,255,223,255,255,253,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,175,255,255,255,253,223,221,253,255,221,160,0,0,0,223,255,253,221,205,222,221,255,255,255,207,255,255,237,220,204,205,239,255,255,255,255,238,221,187,186,187,189,221,255,255,255,253,204,186,170,153,170,187,206,255,255,255,236,186,153,136,137,154,171,206,255,254,252,202,152,135,119,120,153,171,221,255,221,187,152,119,102,102,119,153,188,223,237,203,169,135,102,85,86,120,154,188,255,252,185,135,101,85,85,86,120,171,207,252,219,168,118,85,68,69,103,138,188,237,220,202,135,101,84,69,86,120,155,206,254,219,169,118,85,68,85,103,137,188,221,220,202,152,118,85,85,102,120,171,207,237,253,186,135,118,102,102,120,154,190,239,223,203,169,136,119,119,120,154,188,207,254,255,220,169,152,136,136,154,188,223,239,255,254,203,186,153,154,170,188,205,255,255,255,253,205,203,187,187,188,239,255,255,255,255,254,237,220,220,221,207,255,255,254,255,255,223,239,221,238,255,222,255,255,191,255,253,255,254,237,254,255,255,255,192,0,0,0,223,238,237,221,204,204,221,238,239,255,222,255,237,204,204,188,204,221,238,255,255,239,237,204,187,170,170,187,205,222,255,254,253,203,170,169,153,153,171,188,239,255,221,203,170,152,136,136,137,170,188,239,253,219,169,152,119,119,119,137,155,205,238,221,186,152,119,102,102,103,137,171,206,236,203,152,119,102,85,86,103,137,188,222,204,169,135,102,85,85,86,120,154,205,220,186,152,118,85,84,85,103,137,171,205,203,169,135,101,84,69,86,119,154,189,220,202,152,118,85,85,85,103,137,171,221,220,185,135,102,85,85,102,120,154,205,221,203,169,135,102,102,102,120,154,188,237,237,203,153,135,119,119,120,137,171,205,222,236,186,153,136,135,136,137,171,205,239,255,221,187,169,153,153,153,171,204,239,255,255,220,203,186,170,170,187,205,239,255,255,255,237,204,187,187,188,220,222,255,239,255,255,238,237,220,221,237,239,255,255,223,255,254,237,221,221,221,221,239,255,208,0,0,0,205,205,220,204,205,222,221,255,255,255,221,254,220,204,203,204,205,221,255,255,255,223,221,203,187,186,187,188,205,239,239,253,252,203,169,169,153,154,171,205,223,254,206,203,169,152,136,136,153,171,205,239,252,203,170,152,119,119,119,137,171,206,254,204,186,152,119,102,102,119,137,172,222,236,202,152,119,101,85,86,119,154,188,221,204,169,135,101,85,85,86,120,154,205,236,186,152,118,85,68,85,103,137,171,221,204,185,135,101,84,69,86,120,154,189,220,203,152,118,85,85,85,103,137,171,221,220,186,152,118,85,85,102,120,154,205,221,220,185,135,118,102,102,120,153,187,223,222,203,169,136,119,119,120,137,171,205,221,237,187,169,152,136,136,137,170,189,221,255,237,203,170,153,153,154,171,188,222,239,255,253,204,186,170,170,171,188,221,238,255,255,237,220,203,188,203,205,205,255,239,255,255,255,221,236,220,204,239,239,255,207,255,255,253,237,221,220,221,221,223,208,0,0,0,191,238,237,239,237,238,254,239,254,255,174,255,254,238,238,255,255,255,255,255,255,255,253,221,221,221,221,238,255,255,255,254,254,237,204,203,187,204,222,239,255,255,255,221,203,170,170,170,187,205,239,255,254,254,203,169,152,136,137,171,205,255,255,238,220,169,136,119,119,137,171,222,255,255,253,186,151,118,85,102,137,172,223,254,238,219,168,118,84,69,103,138,189,255,238,237,186,135,84,51,69,104,155,223,254,255,219,168,117,67,52,86,137,188,239,238,253,202,135,101,68,69,104,155,206,255,255,236,185,134,101,85,103,138,189,239,255,255,220,169,135,102,119,137,171,207,255,255,254,203,169,136,136,137,171,205,239,255,255,254,203,170,153,154,170,188,222,255,255,255,254,220,187,187,187,204,222,255,255,255,255,255,237,221,205,221,222,255,255,255,255,255,255,239,239,239,239,255,255,255,255,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,239,255,192,0,0,0,174,221,237,221,221,221,221,254,238,255,189,255,238,237,237,238,239,254,255,255,254,238,237,221,204,204,221,222,238,255,255,238,238,220,203,187,187,188,221,238,255,254,222,220,187,170,153,170,187,205,239,255,237,221,203,169,152,136,137,171,205,239,254,221,219,169,135,119,119,137,171,206,255,237,220,186,151,118,85,103,137,172,222,254,221,203,168,118,84,69,103,138,188,239,221,220,185,135,84,51,69,104,155,205,238,222,203,168,117,67,52,86,137,188,223,221,237,186,151,101,68,69,120,154,205,238,222,220,185,135,101,85,103,137,188,222,221,238,219,169,135,102,119,137,171,205,253,222,237,203,169,136,136,137,154,188,223,221,254,237,203,170,153,153,170,188,222,254,223,255,237,204,187,171,187,188,222,239,221,255,255,238,220,204,204,205,221,238,254,223,255,255,238,237,221,221,221,222,254,237,255,255,255,239,238,238,254,255,255,254,157,238,221,222,221,221,221,221,254,237,176,0,0,0,171,170,169,153,153,153,153,154,171,204,187,203,186,169,153,153,153,170,171,188,220,171,186,169,153,136,153,153,154,171,204,202,186,169,152,136,136,136,137,154,171,187,170,169,152,135,119,119,136,137,153,171,186,169,152,135,119,119,119,120,137,154,170,154,152,135,119,102,102,119,120,137,170,169,153,135,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,85,102,103,120,137,169,153,152,119,102,101,86,102,119,136,154,153,153,135,118,102,101,102,103,120,137,170,153,152,135,118,102,102,102,119,137,154,169,169,136,119,118,102,103,119,136,154,170,170,153,136,119,119,119,119,120,137,170,170,169,153,136,119,119,119,136,137,154,186,171,170,153,136,136,136,136,153,154,171,171,203,169,153,152,136,137,153,170,171,203,188,186,170,169,153,153,153,170,187,204,188,204,203,186,170,170,170,171,187,204,220,172,187,186,170,153,153,170,170,171,204,160,0,0,0,155,170,169,153,153,153,153,154,171,188,171,203,186,170,153,153,153,170,171,187,204,171,186,169,153,136,137,153,154,171,188,186,186,169,152,136,136,136,137,153,171,187,170,169,152,136,119,119,120,137,153,171,169,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,119,120,137,154,169,169,136,119,102,102,102,103,120,137,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,86,102,103,120,137,169,153,136,119,102,101,86,102,119,136,154,153,152,135,118,102,102,102,103,120,137,169,153,152,119,118,102,102,102,119,137,154,169,169,136,119,102,102,102,119,136,153,170,154,153,136,119,119,119,119,136,137,170,170,170,152,136,119,119,119,136,137,154,186,171,169,153,136,136,136,136,137,154,171,171,187,170,153,152,136,136,153,154,171,203,188,187,170,169,153,153,154,170,171,188,188,220,187,186,170,170,170,170,187,204,220,172,187,186,170,169,153,170,170,171,188,160,0,0,0,171,186,169,153,153,153,153,170,187,189,171,203,186,170,153,153,154,170,187,188,220,188,186,169,153,137,136,153,154,171,205,186,186,169,152,136,136,136,137,154,187,188,171,169,152,135,119,119,120,137,154,188,185,169,152,135,119,119,119,120,137,154,186,154,153,135,119,102,102,119,120,137,171,169,153,135,119,102,102,102,103,120,154,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,101,102,102,120,137,170,153,152,119,102,101,86,102,103,136,154,153,153,135,118,102,102,102,103,120,137,170,154,152,135,102,102,102,102,119,136,154,169,169,136,119,102,102,102,119,136,153,170,154,153,136,119,119,119,119,120,137,170,170,170,153,136,119,119,119,136,137,154,186,171,170,153,136,136,136,136,153,154,187,187,203,170,153,152,136,136,153,170,187,203,204,203,170,153,153,153,153,170,187,204,188,220,188,186,170,170,170,171,187,204,220,173,203,186,170,170,154,170,170,187,204,160,0,0,0,172,204,204,188,203,203,204,204,205,221,156,237,205,204,203,204,204,205,238,239,253,205,204,203,187,187,187,188,205,222,239,220,204,186,170,153,154,170,187,188,222,253,205,187,169,152,136,137,154,171,204,238,220,203,169,152,135,119,136,153,171,205,237,188,186,152,119,102,103,120,137,187,206,220,203,168,135,102,85,102,120,154,188,220,188,186,135,102,85,69,102,120,154,205,204,203,168,118,85,68,69,103,137,172,204,204,186,135,101,84,68,86,120,154,189,204,203,169,135,101,68,85,103,137,171,220,204,186,152,118,101,85,102,120,154,189,205,204,170,152,118,102,102,120,154,188,220,221,203,169,152,135,119,120,137,171,205,221,237,203,170,153,136,136,153,170,188,220,222,221,203,186,169,153,153,170,188,221,221,238,221,204,187,170,170,171,188,205,221,223,254,238,220,204,203,204,204,205,222,222,255,255,238,221,220,205,221,221,237,237,174,221,221,205,204,204,204,205,221,221,160,0,0,0,223,254,238,221,221,221,238,239,239,255,191,255,255,221,221,221,221,255,255,255,255,255,255,221,204,187,188,205,222,239,255,255,254,220,203,170,170,171,188,222,255,255,239,220,187,169,153,153,154,188,222,255,254,237,186,153,136,119,120,154,188,223,255,237,203,169,135,102,102,120,154,188,239,253,220,169,135,102,85,86,120,154,206,255,237,186,151,101,85,69,86,121,171,222,253,203,169,118,85,68,69,103,138,188,239,221,186,135,101,68,68,86,120,171,222,238,220,169,118,85,68,85,103,154,189,239,238,202,152,118,85,85,103,137,172,223,254,237,186,152,118,102,103,120,155,205,238,255,220,186,152,119,119,136,154,188,239,255,254,220,186,153,136,137,170,188,222,255,255,255,220,186,170,170,171,188,222,255,255,255,255,220,203,187,187,204,221,255,255,255,255,255,237,221,205,221,222,255,255,255,255,255,255,255,255,254,255,255,255,255,191,255,255,255,255,254,255,255,255,255,192,0,0,0,255,255,255,255,255,255,255,250,175,250,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,250,255,255,255,255,255,255,250,255,159,170,186,255,255,255,255,255,250,255,255,152,137,255,255,255,255,255,255,255,250,118,120,120,143,255,255,255,255,255,255,247,100,86,120,255,255,255,255,255,255,169,116,34,87,159,255,255,255,255,255,255,151,82,20,105,175,255,255,255,255,255,249,134,68,87,138,255,255,255,255,255,255,153,118,119,137,255,255,255,255,255,255,255,201,137,153,255,255,255,255,255,255,255,255,159,175,250,255,255,255,250,255,255,255,255,255,250,255,255,255,255,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,255,250,255,255,255,255,255,250,255,255,175,255,255,255,255,255,255,255,121,250,207,255,255,255,255,255,255,175,160,0,0,0,205,221,204,203,187,204,204,221,238,238,205,238,221,204,187,187,188,205,222,239,255,222,220,203,186,170,170,171,188,222,255,253,220,187,170,153,153,153,170,188,222,254,204,203,169,152,136,136,137,154,188,222,236,203,169,136,119,119,119,136,154,188,221,204,186,152,119,102,102,103,136,171,205,220,202,152,119,101,85,86,103,137,171,221,187,169,135,101,85,85,86,120,154,188,220,186,152,118,85,85,85,103,137,171,205,187,169,135,101,85,69,86,119,154,188,220,186,152,118,85,85,85,103,137,171,204,204,169,135,102,85,85,102,120,154,189,220,203,169,135,102,102,102,120,153,172,221,221,186,152,135,119,119,120,137,171,205,221,220,186,153,136,120,136,137,170,188,221,238,220,186,169,153,153,153,171,188,222,222,254,220,187,170,170,170,171,204,221,237,255,254,220,203,187,187,188,204,222,239,239,255,255,237,221,204,204,221,238,239,254,207,255,238,221,221,221,221,221,221,238,192,0,0,0,206,222,220,204,204,204,221,221,239,255,191,239,237,220,204,204,205,221,255,255,255,254,221,203,187,186,187,188,205,239,255,253,237,203,186,169,153,154,187,205,239,255,221,204,186,153,136,136,137,171,205,239,237,204,186,152,135,119,119,137,171,222,255,204,186,152,119,102,102,103,137,172,222,237,203,169,119,102,85,86,103,138,188,222,220,186,135,101,85,85,86,120,154,206,237,203,152,118,85,68,85,103,137,172,221,220,185,135,101,84,69,86,120,154,189,236,203,152,118,85,85,85,103,137,172,223,221,186,151,102,85,85,102,120,171,205,221,219,169,135,102,102,102,120,154,189,223,222,203,169,135,119,119,120,154,172,223,223,253,203,169,136,136,136,153,187,205,238,255,252,203,170,153,153,154,187,205,239,255,254,236,203,186,170,170,187,205,239,237,239,255,237,221,203,203,204,221,222,255,239,255,255,238,237,221,222,238,238,255,254,174,255,238,238,238,237,253,237,254,255,208,0,0,0,207,254,255,238,239,239,223,255,255,255,191,255,255,254,238,221,223,239,255,255,255,239,255,253,221,203,188,205,223,255,255,255,255,221,203,186,170,187,188,223,255,255,239,221,203,169,153,153,154,188,223,255,255,253,203,169,136,119,136,154,188,223,255,254,203,169,135,102,102,120,154,189,255,254,220,185,135,102,85,86,120,155,222,255,238,202,152,101,84,69,86,121,172,239,255,220,169,118,84,68,69,103,138,205,255,237,202,151,101,68,68,86,121,172,223,254,236,169,134,101,68,85,103,154,205,255,238,203,152,118,85,85,103,137,172,223,255,253,202,152,118,102,103,137,171,206,239,255,236,186,152,135,119,137,155,205,239,255,255,236,186,153,153,153,170,188,223,255,255,254,220,187,170,170,171,204,223,255,255,255,255,221,203,203,204,205,223,255,255,255,255,255,254,221,221,223,255,255,255,255,255,255,255,255,254,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,192,0,0,0,171,187,170,170,153,170,170,171,204,205,187,204,187,170,170,170,170,187,188,221,238,188,187,169,153,153,153,153,170,187,205,218,186,169,153,136,136,136,153,170,188,204,171,169,152,136,119,119,136,137,154,188,202,169,152,135,119,119,119,120,137,171,187,170,153,135,118,102,102,103,120,153,171,186,169,136,118,102,102,102,103,136,154,187,154,152,119,102,101,86,102,119,137,170,185,169,135,118,101,85,86,103,120,154,171,154,152,119,102,85,85,102,119,137,170,170,169,135,118,102,85,102,103,120,154,170,170,152,135,118,102,102,102,119,137,170,170,169,152,119,102,102,102,119,136,154,187,187,169,136,119,119,119,119,136,153,171,187,186,169,136,135,119,119,136,153,170,187,188,186,169,152,136,136,136,153,170,188,188,204,187,169,153,153,153,154,170,187,204,221,204,187,170,170,169,170,171,187,205,205,221,220,203,187,170,170,187,188,205,236,174,221,204,187,170,170,171,187,188,205,176,0,0,0,155,186,170,169,153,153,170,170,187,203,155,203,186,170,170,169,170,170,187,205,220,188,187,170,153,153,153,153,170,187,205,202,187,170,153,136,136,136,153,154,188,204,171,169,152,136,135,119,136,137,154,188,186,170,153,135,119,119,119,120,137,170,187,170,153,136,119,102,102,103,120,137,171,185,169,136,119,102,102,102,103,136,154,187,154,152,135,102,101,86,102,119,137,171,169,169,135,118,101,85,86,103,120,153,170,154,152,119,102,85,85,102,119,137,170,169,169,135,118,101,85,102,103,120,154,186,170,152,135,102,102,102,103,120,137,170,170,169,152,119,102,102,103,119,136,154,186,170,169,136,119,119,119,119,136,154,171,170,186,153,136,119,119,120,136,153,170,187,187,186,153,152,136,136,137,153,170,188,187,203,186,169,153,153,153,153,170,187,203,205,204,187,170,169,153,170,171,187,221,188,220,204,203,186,170,186,187,188,204,220,156,204,187,186,170,170,170,170,187,188,160,0,0,0,155,170,169,153,153,153,153,170,171,188,171,203,186,170,153,153,153,170,171,204,220,171,186,169,153,152,153,153,154,171,188,202,186,169,152,136,136,136,137,154,171,203,170,169,152,136,119,119,120,137,154,171,185,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,85,102,103,120,137,170,153,136,119,102,101,85,102,119,136,154,169,153,135,118,102,102,102,103,120,137,170,153,152,119,102,102,102,102,119,137,154,169,169,136,119,102,102,103,119,136,154,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,153,170,186,171,170,153,136,136,136,136,153,154,187,171,187,170,153,153,136,137,153,170,187,203,188,203,170,169,153,153,154,170,187,188,188,220,203,186,170,170,170,171,187,204,203,172,187,186,170,170,170,170,170,171,187,160,0,0,0,172,203,187,170,170,170,170,187,188,204,156,220,203,186,170,170,170,171,188,221,236,188,203,170,169,153,153,154,171,188,206,203,203,186,153,152,136,137,153,171,188,220,187,186,152,136,119,119,136,137,170,188,203,186,152,135,119,119,119,120,153,171,203,171,169,136,119,102,102,103,120,153,188,186,169,136,119,102,102,102,103,137,154,187,170,152,135,102,85,85,102,119,137,171,186,169,135,118,101,85,85,103,120,154,187,170,152,119,102,85,85,102,119,137,171,186,169,136,118,101,85,86,103,120,154,187,170,152,135,118,101,102,102,120,137,171,187,170,152,119,102,102,102,119,137,170,203,187,169,152,119,119,119,119,137,154,188,187,186,169,152,135,119,120,136,153,171,204,188,187,153,152,136,136,137,154,171,205,204,220,187,170,153,153,153,170,171,204,220,221,220,187,170,170,170,170,188,204,205,221,222,205,203,187,187,187,188,205,221,237,157,204,204,187,187,187,187,188,204,221,176,0,0,0,174,222,221,237,220,204,220,221,221,221,158,255,255,253,238,238,238,222,238,239,253,239,238,237,221,221,221,222,239,238,239,222,239,221,220,204,204,204,221,238,239,253,223,237,204,187,187,187,188,205,221,255,222,238,220,186,153,153,154,188,206,254,253,223,220,186,152,135,136,154,188,222,254,221,238,203,168,118,102,103,154,188,238,253,222,220,169,134,84,69,104,155,205,239,237,237,203,151,100,50,70,121,188,222,254,222,236,185,134,66,36,87,154,205,239,221,237,203,152,117,68,86,121,172,222,238,223,237,202,152,118,102,120,155,205,255,237,239,220,186,152,119,120,154,188,222,254,223,237,220,186,153,153,154,188,221,239,238,255,237,204,187,170,187,188,221,239,254,223,254,238,220,204,204,204,222,239,255,238,254,254,238,238,221,221,237,238,238,254,238,239,255,238,238,222,238,254,255,255,238,255,255,254,239,239,254,255,255,255,255,174,221,221,238,221,221,238,222,238,254,176,0,0,0,207,255,255,255,254,239,254,239,255,239,175,255,255,255,255,239,255,255,255,255,255,255,255,255,238,222,222,255,255,255,255,239,255,255,236,204,204,204,223,255,255,255,255,254,236,186,170,170,188,223,255,255,255,255,236,186,152,136,137,171,222,255,255,255,253,186,152,119,119,137,172,223,255,255,254,203,152,102,85,102,137,188,223,255,255,220,168,118,68,69,103,138,205,255,255,253,202,134,84,51,69,104,172,223,255,255,220,168,117,67,52,86,138,189,239,254,254,202,135,101,68,69,120,172,223,255,255,237,185,134,101,85,103,155,206,255,255,255,219,169,135,102,119,138,189,239,255,255,255,219,169,152,136,154,188,239,255,255,255,254,220,186,170,171,188,222,255,255,255,255,254,221,204,188,205,222,239,255,254,255,255,255,237,221,221,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,254,255,255,255,255,255,255,192,0,0,0,206,222,221,221,204,221,221,238,222,239,174,254,238,221,204,204,221,238,255,255,255,223,222,220,204,187,187,204,221,254,239,238,253,220,186,170,154,170,188,221,239,255,221,220,186,169,136,136,153,171,205,255,252,220,186,152,135,119,120,137,172,221,254,221,202,152,119,102,102,119,137,188,222,252,219,169,135,102,85,86,120,154,205,239,221,186,135,102,85,85,86,120,171,222,236,203,168,118,85,68,69,103,137,189,239,204,186,135,101,84,68,86,120,155,205,221,219,168,118,85,68,85,103,137,188,238,221,202,152,118,85,85,103,137,171,206,237,220,185,135,118,102,103,120,154,188,254,237,203,169,136,119,119,136,154,188,222,237,238,203,170,152,136,137,154,188,221,238,239,237,204,186,169,153,170,187,205,239,237,254,237,220,187,187,187,204,205,239,254,255,255,237,221,220,205,205,221,238,255,238,255,255,254,238,222,221,238,239,255,255,159,238,237,254,239,238,223,238,238,255,208,0,0,0,206,221,220,204,203,204,204,221,238,238,190,254,221,204,203,187,188,205,222,255,255,222,220,203,186,170,170,187,204,222,255,253,220,203,170,153,153,154,171,188,222,238,205,203,169,152,136,136,137,170,188,222,236,203,170,152,135,119,119,137,171,205,238,204,186,152,119,102,102,103,137,171,205,236,202,152,135,102,85,86,103,137,188,221,203,169,135,102,85,85,86,120,154,205,220,186,152,118,85,68,85,103,137,171,205,204,169,135,101,84,69,86,120,154,204,220,186,152,118,85,85,85,103,137,171,205,204,186,135,102,85,85,103,120,154,205,221,203,169,135,102,102,103,120,154,188,221,221,202,169,135,119,119,120,153,171,205,221,236,186,169,136,136,136,153,171,205,221,222,220,187,169,153,153,154,171,204,222,238,238,220,203,186,170,170,187,204,222,238,239,254,221,204,187,187,188,205,222,239,238,255,255,237,221,220,205,221,222,239,254,190,254,238,237,221,221,221,221,238,238,208,0,0,0,206,237,220,204,204,204,205,221,221,221,157,255,221,204,204,204,204,205,238,239,253,238,221,204,187,170,170,187,204,222,239,222,237,203,186,169,153,154,171,205,222,254,221,203,170,153,136,136,153,171,205,239,220,203,186,152,135,119,119,137,171,205,253,220,186,152,119,102,102,103,137,171,206,236,219,169,135,101,85,86,119,138,189,237,204,185,135,101,85,85,86,120,155,205,220,203,152,118,85,68,85,103,137,187,221,204,185,135,101,84,69,86,120,154,205,220,219,152,118,85,69,85,103,137,171,221,204,186,151,118,85,85,103,136,170,205,220,219,169,135,118,102,103,120,154,188,221,204,203,169,135,119,119,136,154,171,205,222,237,203,169,152,136,137,154,171,204,221,238,220,203,170,153,153,170,171,204,238,222,253,221,203,186,186,171,187,204,221,253,255,254,221,220,204,204,204,220,221,254,239,255,239,238,221,221,221,221,223,255,239,173,221,221,222,220,221,221,220,221,222,192,0,0,0,207,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,253,221,253,255,255,255,255,255,255,255,221,204,188,204,223,255,255,255,255,255,220,186,170,170,188,223,255,255,255,255,220,186,152,136,137,172,223,255,255,255,252,186,136,118,119,137,172,223,255,255,253,202,152,102,85,103,137,188,255,255,255,252,168,118,68,69,103,138,207,255,255,253,186,135,84,51,69,104,171,223,255,255,220,168,117,67,52,86,138,189,255,255,255,202,135,101,68,69,120,171,223,255,255,252,185,134,101,85,103,154,205,255,255,255,220,169,135,102,119,138,188,223,255,255,255,220,169,136,136,153,188,223,255,255,255,253,204,186,170,170,188,207,255,255,255,255,255,236,204,188,204,222,255,255,255,255,255,255,253,221,221,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,208,0,0,0,206,237,221,205,204,204,221,222,222,238,158,255,237,221,220,204,205,222,254,255,255,223,237,204,203,187,187,188,221,239,255,254,238,220,186,170,154,170,187,205,223,254,221,220,186,169,152,137,154,171,205,239,237,220,186,153,136,119,136,153,171,205,238,204,203,168,135,102,103,120,154,188,222,236,219,169,135,102,85,102,120,154,189,237,204,186,152,118,84,85,102,121,171,206,220,203,168,118,84,52,69,103,138,188,237,220,186,135,101,84,52,86,120,171,205,220,219,169,135,101,68,86,103,154,188,221,205,202,152,118,101,86,103,137,171,205,221,220,186,152,119,102,103,136,154,188,237,222,220,169,152,119,119,137,154,188,221,221,253,203,170,153,136,153,154,188,205,254,239,237,203,186,170,170,170,188,205,239,237,255,237,204,187,187,187,204,221,238,254,239,255,237,221,204,204,204,221,223,255,237,255,255,238,237,221,221,238,239,255,254,158,221,237,221,221,221,237,221,222,238,176,0,0,0,171,187,170,170,170,170,170,171,188,205,155,220,203,186,170,170,170,171,188,221,237,188,187,170,153,153,153,154,170,188,205,203,187,170,153,136,136,136,153,170,188,220,171,170,153,136,119,119,136,137,170,204,202,186,153,135,119,119,119,120,137,171,203,170,153,135,119,102,102,103,120,154,171,186,169,136,119,102,102,102,103,136,154,187,170,152,135,102,85,85,102,119,137,171,186,169,135,118,101,85,86,103,120,154,186,170,152,119,102,85,85,102,119,137,171,170,169,135,118,101,85,86,103,120,154,186,170,152,135,102,102,102,103,120,137,171,186,186,152,119,102,102,102,119,137,154,187,187,169,136,119,119,119,119,137,154,188,187,187,169,136,135,119,120,136,154,171,203,188,187,169,152,136,136,137,154,171,188,204,220,187,170,153,153,153,154,171,188,220,205,220,187,170,170,170,170,171,188,221,204,221,204,187,187,187,187,188,204,221,236,141,204,203,187,186,170,187,187,188,205,176,0,0,0,155,186,169,153,153,153,154,170,187,188,155,204,187,170,170,153,170,170,187,205,220,171,186,170,153,153,153,153,154,187,204,202,186,169,153,136,136,136,153,154,187,203,171,169,152,136,119,119,136,137,154,187,186,169,152,136,119,119,119,120,137,170,187,154,153,135,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,120,154,186,154,152,119,102,101,86,102,119,137,154,169,153,135,118,102,85,86,103,120,153,170,154,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,154,152,135,102,102,102,103,120,137,170,170,169,136,119,102,102,103,119,137,154,170,170,169,136,119,119,119,119,136,154,171,170,186,153,136,135,119,120,136,153,170,187,187,186,153,136,136,136,137,153,170,187,187,203,186,169,153,153,153,153,170,187,203,188,203,186,170,169,154,170,171,187,204,188,220,204,187,170,170,170,187,188,204,220,156,203,187,170,170,170,170,170,187,188,160,0,0,0,171,186,170,170,153,154,170,171,187,204,139,204,187,170,170,170,170,171,188,205,220,188,187,170,153,153,153,153,170,188,205,203,187,170,153,136,136,136,153,170,188,204,171,170,153,136,135,119,136,137,154,188,186,170,153,135,119,119,119,120,137,171,187,170,169,136,119,102,102,103,120,154,171,186,169,136,119,102,102,102,103,136,154,186,154,152,119,102,85,85,102,119,137,171,170,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,171,169,169,135,118,101,85,86,103,120,154,186,170,152,135,102,102,102,103,120,137,171,170,169,152,119,102,102,103,119,137,170,186,171,169,152,119,119,119,120,137,154,171,187,186,169,136,135,119,136,137,154,171,187,188,186,169,152,136,136,137,154,171,188,187,204,186,169,153,153,153,154,171,188,203,205,204,187,170,170,170,170,171,187,205,205,221,204,203,187,186,187,187,188,205,220,156,203,187,186,170,170,170,171,187,188,160,0,0,0,189,220,204,204,187,187,204,204,221,221,141,238,221,204,204,203,204,221,239,238,254,222,220,204,187,171,187,187,204,221,255,237,221,203,186,169,153,170,171,188,221,253,205,203,170,153,136,136,153,170,188,222,220,203,170,152,135,119,120,137,170,205,221,204,186,152,135,102,102,119,137,171,206,220,203,169,135,102,85,102,120,138,188,221,204,169,135,102,85,85,102,120,155,188,219,186,152,118,85,68,69,103,137,172,204,203,185,135,101,84,52,86,120,154,204,204,202,152,118,85,84,86,103,137,171,220,204,186,152,118,101,86,103,137,154,204,204,203,169,135,118,102,103,120,154,188,220,204,187,169,136,119], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+949400);
/* memory initializer */ allocate([119,136,154,187,205,221,236,203,169,152,136,137,154,171,204,221,221,236,187,170,153,153,170,171,204,221,221,254,220,203,187,170,171,187,188,221,237,239,238,221,204,203,187,204,204,221,222,238,255,238,222,221,205,220,221,237,239,238,158,238,221,221,220,204,204,205,221,222,192,0,0,0,239,255,255,255,255,255,255,255,255,254,175,255,255,255,255,239,255,255,255,255,255,255,255,255,237,221,221,223,255,255,255,255,255,253,220,203,187,204,221,255,255,255,255,237,220,186,170,170,187,205,255,255,255,255,220,186,152,136,137,171,205,255,255,255,236,186,152,118,103,137,171,221,255,255,237,202,152,102,85,102,137,188,223,255,255,219,168,118,84,68,103,138,188,255,255,253,186,135,84,51,69,104,171,239,255,255,219,168,101,67,52,86,138,189,239,254,253,202,135,100,68,86,120,171,222,255,239,220,185,134,101,86,103,154,205,255,254,255,220,169,135,102,119,138,188,223,255,239,253,203,169,136,136,154,187,222,255,255,255,237,203,170,169,170,187,205,255,255,255,255,221,220,203,187,188,206,255,255,253,255,255,255,221,221,221,223,255,255,255,239,255,255,255,255,238,239,255,255,255,253,255,255,255,255,255,255,255,255,255,255,141,221,221,223,238,239,255,255,255,255,208,0,0,0,239,237,237,221,204,205,221,221,237,222,158,255,254,221,220,204,221,222,238,254,254,254,237,221,204,187,187,204,221,238,239,237,254,220,187,170,170,170,188,205,239,255,222,220,186,169,153,153,154,188,205,239,236,220,187,169,136,119,136,154,188,206,238,221,203,169,135,102,102,120,154,188,239,221,203,169,135,102,85,102,120,154,205,238,220,186,152,102,84,69,86,137,172,205,220,203,169,118,84,68,69,103,154,188,237,204,186,151,101,68,68,86,121,171,221,221,219,169,134,85,68,85,103,154,189,221,222,203,152,118,85,85,103,137,171,222,237,220,186,152,118,102,103,137,171,205,238,222,220,170,152,135,120,137,154,188,222,237,237,219,186,153,153,153,154,188,221,239,238,237,203,186,170,170,187,188,205,239,253,239,221,220,203,187,187,204,222,238,255,223,255,237,221,204,221,205,222,239,255,253,255,255,238,238,223,222,238,239,255,255,157,237,222,222,222,237,238,238,255,239,224,0,0,0,222,237,220,204,188,204,204,221,221,221,174,254,221,204,203,187,204,204,222,239,254,222,220,203,186,170,170,187,204,222,239,237,220,203,170,153,153,153,171,188,222,238,205,203,169,152,136,136,137,170,188,222,236,203,169,152,135,119,119,137,170,204,237,204,186,152,119,102,102,119,137,171,205,220,186,152,135,101,85,86,119,137,188,221,203,169,135,101,85,85,86,120,154,189,219,186,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,188,204,186,152,118,85,85,85,103,137,171,221,204,186,135,118,85,85,103,120,154,189,220,203,169,135,118,102,103,120,154,188,221,221,203,169,135,119,119,136,153,171,205,221,220,186,169,136,136,136,153,171,205,222,222,220,187,170,153,153,154,171,204,222,238,238,220,203,186,170,170,187,204,222,254,223,237,221,204,203,187,188,204,222,239,237,255,238,237,221,205,205,221,238,255,255,174,238,221,221,221,221,221,222,238,239,224,0,0,0,207,237,221,220,220,220,204,205,221,221,142,254,238,221,220,204,205,221,238,238,254,239,238,220,204,187,187,204,205,222,239,222,254,220,187,170,170,171,188,205,221,237,222,220,187,169,153,153,154,187,205,223,221,236,186,153,136,119,136,154,187,221,253,221,203,169,135,102,102,120,154,188,221,236,220,169,135,102,85,86,120,154,189,236,204,186,152,117,84,69,86,137,171,206,220,203,168,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,121,171,205,220,220,169,134,85,68,85,120,154,188,221,221,202,152,118,85,86,103,137,172,221,221,220,186,152,118,102,119,137,171,189,237,205,220,185,152,135,120,137,154,188,222,237,222,203,186,153,152,153,171,187,205,238,222,237,220,186,170,170,171,188,205,238,221,238,220,220,188,188,187,204,205,221,253,223,238,222,220,205,205,221,221,222,238,237,239,239,255,238,237,222,237,221,255,253,157,221,222,205,220,221,221,237,222,239,192,0,0,0,223,255,255,255,254,255,255,253,223,221,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,220,205,223,255,255,255,255,255,255,253,204,187,187,204,223,255,255,255,255,253,187,169,153,154,188,255,255,255,255,255,203,152,135,120,138,188,255,255,255,255,203,168,118,85,103,154,205,255,255,255,253,185,118,84,69,104,155,207,255,255,255,203,151,84,35,69,121,188,255,255,255,252,169,117,67,36,87,155,207,255,255,255,219,152,101,68,86,121,188,255,255,255,253,202,135,101,86,120,171,207,255,255,255,220,186,136,119,120,154,207,255,255,255,255,252,186,153,153,170,205,255,255,255,255,255,220,187,186,187,205,255,255,255,255,255,255,221,252,204,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,240,0,0,0,206,221,221,204,204,204,204,205,221,221,158,239,221,204,203,204,204,205,222,255,254,222,237,204,203,186,186,187,205,205,238,238,237,204,186,169,153,154,187,189,221,254,222,203,186,153,136,136,153,171,188,222,220,204,186,152,135,119,120,137,171,205,238,205,186,152,135,102,102,120,137,187,206,220,203,169,135,102,85,102,120,154,188,221,204,186,135,102,84,69,86,120,155,205,203,203,152,118,85,68,69,103,137,188,205,204,185,135,101,84,68,86,120,154,189,220,203,168,118,101,68,86,103,137,172,221,204,186,152,118,101,86,103,137,171,205,220,204,169,136,118,102,103,136,154,188,221,205,203,169,136,119,119,136,154,188,221,220,236,187,169,152,136,153,153,187,205,221,206,220,203,170,169,153,170,187,189,223,221,238,221,203,187,186,171,188,205,222,254,222,238,221,204,204,204,204,221,222,239,237,255,238,221,221,220,222,221,238,239,253,141,221,220,204,204,204,220,221,222,222,192,0,0,0,172,187,186,170,170,170,170,170,187,188,140,220,203,187,186,170,170,187,188,205,220,188,203,186,170,153,153,154,171,188,220,203,203,186,169,152,136,153,153,171,188,220,188,186,153,136,136,136,136,153,171,204,186,186,153,136,119,119,119,136,153,171,203,171,169,136,119,102,102,119,136,154,188,186,169,152,119,102,85,102,119,137,154,187,170,153,135,102,85,85,102,120,137,171,186,169,135,118,85,85,85,103,120,154,187,170,152,119,101,85,85,86,119,137,171,186,169,136,118,101,85,86,103,136,154,187,170,169,135,102,101,86,102,120,153,171,186,186,152,135,118,102,102,120,137,171,187,171,169,152,135,119,119,119,137,154,188,187,187,169,152,136,119,136,137,154,171,203,188,187,169,153,136,136,153,154,171,205,204,204,186,170,153,153,153,170,187,205,236,205,220,187,186,170,170,171,188,204,222,204,237,204,204,203,187,187,188,204,222,221,140,203,203,187,187,187,187,203,204,204,176,0,0,0,155,170,169,153,153,153,153,170,171,187,155,203,186,170,169,153,170,170,187,204,220,171,186,169,153,153,153,153,170,171,204,186,186,169,152,136,136,136,153,154,171,203,170,169,152,136,119,119,136,137,170,187,169,170,152,135,119,119,119,120,137,170,186,154,152,135,119,102,102,119,120,153,170,169,169,136,119,102,102,102,119,136,154,170,153,152,119,102,101,86,102,119,137,170,169,153,135,118,101,85,86,103,120,153,170,154,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,103,120,137,170,169,169,152,119,118,102,103,119,136,154,186,170,169,136,119,119,119,119,136,153,171,170,186,153,136,135,119,120,136,153,170,186,171,186,153,152,136,136,136,153,170,187,187,187,170,169,153,153,153,153,170,187,203,188,203,186,170,169,153,170,170,187,204,187,204,203,187,186,170,170,171,187,204,220,155,187,170,170,170,170,170,170,187,188,160,0,0,0,172,187,170,170,170,170,170,170,187,187,139,220,203,186,170,170,170,187,188,204,219,188,203,170,169,153,153,170,171,188,205,187,187,170,153,152,136,153,154,171,187,219,187,170,153,136,136,136,136,153,171,188,186,186,153,136,119,119,119,136,154,171,203,170,169,136,119,102,102,119,136,154,187,186,169,152,119,102,85,102,119,137,170,186,170,152,135,102,85,85,102,120,137,171,170,169,136,118,85,85,85,103,136,154,186,170,152,135,101,84,85,86,120,137,171,170,170,152,118,101,85,86,103,136,154,186,171,169,135,118,101,86,103,120,153,171,170,186,152,135,118,102,102,120,137,170,186,171,170,152,135,119,119,120,137,154,187,186,187,170,152,136,136,136,137,154,171,203,188,187,170,153,152,136,153,154,171,204,187,204,187,170,169,153,153,170,171,204,203,188,204,187,171,170,170,170,171,188,205,188,220,204,203,187,187,187,187,204,205,220,139,187,187,170,170,170,170,187,188,204,160,0,0,0,190,221,204,204,204,188,204,204,204,220,142,238,221,220,204,204,204,205,221,239,253,238,237,204,187,187,187,188,204,221,238,221,237,204,186,170,169,170,171,204,222,253,205,220,186,153,152,137,154,171,204,222,220,220,186,152,135,119,120,153,171,205,237,205,187,153,135,102,102,120,138,187,205,221,203,169,135,102,85,102,120,154,188,221,188,186,151,102,84,69,102,137,171,205,204,203,152,118,84,68,69,103,137,188,221,188,186,135,101,68,68,86,120,154,205,204,203,169,134,101,68,86,103,154,172,221,204,186,152,118,101,86,103,137,171,205,220,204,169,152,118,102,103,136,154,188,221,205,203,169,152,135,119,136,154,188,221,220,221,203,169,153,136,153,154,171,205,221,205,221,203,186,170,170,170,188,205,239,221,238,220,203,187,186,187,188,204,222,238,238,254,221,204,188,204,204,221,222,255,237,254,238,221,221,221,221,221,238,239,253,157,237,204,220,204,220,221,221,238,237,192,0,0,0,223,255,255,255,254,255,254,255,238,254,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,238,255,255,255,255,255,255,255,254,220,220,221,238,255,255,255,255,255,253,220,187,187,205,223,255,255,255,255,253,219,170,154,171,204,223,255,255,255,253,203,169,136,136,154,189,239,255,255,255,220,169,135,102,120,155,205,255,255,255,253,186,134,84,69,120,172,222,255,255,255,219,152,100,34,70,137,188,255,255,255,253,186,134,66,36,104,155,222,255,253,255,204,168,117,68,86,138,189,255,255,255,237,203,152,118,102,121,172,223,255,255,255,252,202,152,136,137,171,223,255,255,255,255,220,187,170,154,171,205,255,255,255,255,254,221,203,187,188,205,239,255,255,239,254,254,221,220,205,222,255,255,255,254,255,255,255,239,222,255,255,255,255,255,239,255,255,239,253,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,141,221,221,222,222,222,255,255,255,255,208,0,0,0,206,237,220,204,204,204,204,205,204,221,158,238,238,237,220,205,205,221,221,239,237,238,221,204,204,187,203,204,221,222,239,221,238,204,187,170,170,171,188,204,222,238,222,220,186,169,153,153,170,188,204,222,220,220,186,153,136,120,136,154,188,205,221,205,203,169,135,102,103,120,154,188,222,220,219,169,135,101,85,86,120,171,205,237,205,186,152,101,84,69,87,137,187,205,220,219,169,118,84,68,69,104,154,188,221,221,186,152,101,68,68,86,121,171,205,220,219,169,135,85,68,85,104,154,204,237,204,203,168,118,85,85,103,137,171,221,220,220,186,152,119,102,103,137,171,205,237,205,204,186,152,136,120,137,154,204,222,236,220,203,186,153,153,153,170,188,221,238,221,221,203,186,170,170,187,188,222,238,237,237,221,220,203,187,187,189,205,254,238,206,238,221,221,220,221,221,222,238,238,236,254,238,254,253,221,221,238,239,239,254,141,220,221,221,205,221,221,221,222,254,208,0,0,0,206,221,204,203,187,187,187,204,205,221,173,238,221,204,187,187,187,204,221,222,253,222,220,203,186,170,170,171,188,205,238,221,220,203,170,153,153,153,170,188,205,221,205,203,169,152,136,136,137,170,188,221,204,203,169,136,119,119,119,137,154,188,220,204,170,152,119,102,102,119,137,171,205,203,186,152,119,101,85,102,120,137,172,204,187,169,135,101,85,85,86,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,220,187,185,136,118,85,85,102,120,154,188,203,203,169,135,118,102,103,120,154,188,220,204,186,169,136,119,119,120,137,171,205,220,220,186,153,136,136,136,153,171,204,237,205,204,186,169,153,153,154,171,188,222,221,221,220,187,170,170,170,187,204,222,254,222,221,204,203,187,187,188,205,222,239,237,238,237,221,204,204,204,221,222,239,255,173,221,205,204,204,204,205,221,222,238,208,0,0,0,205,221,220,204,204,203,204,204,204,220,157,254,237,220,204,204,204,205,221,222,237,222,237,204,187,187,187,187,204,205,222,221,236,203,186,170,170,170,171,188,222,220,205,220,186,153,152,153,154,171,188,222,204,220,186,152,135,119,136,154,171,204,220,204,186,168,135,102,103,120,154,187,205,204,203,169,135,101,85,102,120,154,188,220,204,186,152,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,220,204,186,151,101,68,68,86,121,171,205,204,203,169,135,101,68,85,104,154,188,220,204,186,152,118,101,85,103,137,171,205,204,203,186,152,119,102,103,136,170,188,220,205,203,169,152,135,119,137,154,188,222,220,220,187,170,153,152,153,154,187,205,237,205,220,203,170,170,170,170,187,205,238,220,237,204,203,187,187,187,188,205,222,237,222,221,220,204,204,204,204,221,222,239,221,238,237,221,221,220,221,221,238,239,254,157,220,220,204,204,204,204,221,221,222,192,0,0,0,223,255,254,238,221,221,221,220,221,221,143,255,255,255,238,237,223,222,255,255,254,255,255,237,220,221,220,221,222,255,255,238,255,221,220,203,187,187,204,222,255,254,255,237,220,186,170,170,171,205,222,255,237,254,220,186,152,136,137,171,205,239,255,223,220,186,152,118,119,137,171,205,255,254,237,202,152,102,85,103,137,188,222,254,237,219,168,118,68,68,103,138,189,223,253,252,186,134,84,51,69,120,171,206,254,238,203,168,117,67,52,87,137,188,255,254,237,186,135,101,68,69,120,171,222,255,223,220,169,135,101,86,104,154,205,239,254,238,203,169,135,118,120,138,188,223,255,222,237,203,169,152,136,154,188,222,255,254,238,221,203,170,153,170,188,206,255,255,239,255,221,204,187,187,204,222,239,255,254,254,239,221,220,205,205,222,255,255,255,255,254,255,238,237,222,238,239,255,255,254,255,255,255,255,255,255,255,255,255,255,158,223,255,255,253,254,255,255,255,255,224,0,0,0,206,237,221,220,204,204,204,204,221,221,158,255,238,222,220,204,205,221,238,239,254,255,237,220,203,187,187,204,205,238,255,221,254,204,187,170,170,170,187,205,221,238,222,220,186,169,153,153,154,171,222,222,221,236,202,153,136,119,136,154,187,205,237,205,203,169,135,102,103,120,154,188,221,220,219,169,135,101,85,102,120,154,188,237,204,202,152,101,84,69,102,137,171,221,220,203,168,118,84,68,69,103,154,189,220,204,186,135,101,68,68,86,120,171,205,236,203,169,134,101,68,85,104,154,189,221,205,203,152,118,85,85,103,137,172,222,220,220,186,152,119,102,103,137,171,205,253,206,203,186,152,135,119,137,154,188,238,220,221,203,170,153,153,153,170,188,222,254,222,221,204,170,170,170,171,188,222,255,237,238,221,204,187,187,187,205,222,239,255,222,238,222,221,204,205,222,238,239,255,237,255,254,238,221,221,238,238,255,255,255,141,205,205,221,220,205,237,238,238,255,176,0,0,0,155,187,186,170,170,170,170,170,187,187,139,204,203,187,170,170,170,187,188,205,220,188,203,170,170,153,153,170,171,188,205,187,187,170,153,152,136,153,154,171,188,203,187,170,153,136,135,136,137,153,171,188,186,186,153,135,119,119,119,136,153,171,203,171,169,136,118,102,102,119,136,154,187,186,170,152,118,102,85,102,119,137,170,187,170,152,135,102,85,85,102,120,153,171,186,169,136,118,85,85,85,103,136,154,186,170,152,135,101,85,85,86,119,137,171,186,169,152,118,101,85,86,103,136,154,187,170,169,135,118,101,86,102,120,153,171,186,186,152,135,118,102,102,119,137,170,187,171,170,152,135,119,119,119,137,154,188,186,203,170,152,136,136,136,137,154,171,203,188,187,170,153,152,136,137,154,171,204,203,204,187,170,169,153,153,170,171,204,220,188,204,187,186,170,170,170,187,204,222,204,221,204,203,187,187,187,188,204,221,237,140,187,187,187,171,171,187,188,204,205,160,0,0,0,155,186,170,153,153,153,153,170,170,187,139,204,187,170,170,170,170,170,187,204,203,187,186,170,153,153,153,153,170,187,204,186,186,169,153,136,136,137,153,170,187,203,171,169,152,136,119,136,136,153,170,187,170,170,152,135,119,119,119,136,153,170,186,154,153,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,137,154,186,154,152,119,102,85,85,102,120,137,171,169,169,135,118,101,85,86,103,136,154,170,154,152,135,102,85,85,102,119,137,170,169,169,136,118,101,85,86,103,120,154,170,154,153,135,118,102,102,102,120,137,171,169,169,152,135,118,102,102,119,137,154,186,171,169,152,135,119,119,119,136,154,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,153,136,136,137,153,170,188,186,203,186,170,153,153,153,154,170,187,203,188,203,187,170,170,170,170,171,187,205,187,220,203,187,186,170,187,187,188,205,220,155,187,170,170,170,170,170,171,187,188,160,0,0,0,155,187,170,170,170,170,170,170,187,187,139,204,203,187,170,170,170,187,188,205,219,188,187,170,169,153,153,170,171,187,205,187,203,170,153,152,136,153,153,171,188,203,171,170,153,136,136,136,136,154,171,188,186,186,153,135,119,119,119,136,154,171,187,171,169,135,118,102,102,119,136,154,187,186,170,152,118,102,85,102,119,137,170,187,170,168,135,102,85,85,102,120,153,171,170,169,136,118,85,85,85,103,136,154,186,170,152,135,101,85,85,86,120,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,101,86,102,120,153,171,170,186,152,135,118,102,102,119,137,170,187,171,170,152,135,119,119,119,137,154,187,186,187,169,153,136,136,136,137,154,187,203,188,187,170,153,152,136,153,154,171,205,187,204,187,170,169,153,154,170,171,188,220,188,204,187,186,170,170,170,187,204,221,203,221,204,203,187,187,187,204,204,221,220,139,187,187,187,170,170,171,187,187,204,160,0,0,0,189,236,204,203,203,187,204,204,204,205,141,237,237,220,203,187,188,205,205,239,253,222,237,203,187,170,170,187,204,206,238,221,221,203,186,153,153,154,170,188,222,237,221,203,186,153,136,136,153,170,188,221,220,219,170,152,135,119,120,137,171,188,220,205,186,152,119,102,102,120,137,171,205,203,202,169,135,101,85,102,120,153,188,220,187,169,135,102,84,85,102,120,154,188,203,186,152,118,84,68,85,103,137,172,204,204,169,135,101,84,68,86,120,154,188,219,203,152,118,101,84,85,103,137,172,220,204,186,152,118,101,85,103,137,171,205,220,203,169,136,118,102,103,120,154,188,220,204,187,169,136,119,119,136,154,188,221,220,220,186,169,152,136,137,154,171,205,221,205,220,187,170,153,153,170,187,205,222,236,237,220,203,186,170,171,187,204,222,237,222,237,220,204,188,188,204,221,222,255,237,255,221,221,221,205,221,221,238,239,254,157,221,221,221,204,204,204,221,238,238,192,0,0,0,223,254,237,222,221,221,221,221,204,221,159,255,255,238,222,221,221,222,238,239,253,239,239,238,221,204,204,205,205,238,255,223,255,237,204,203,187,187,204,221,222,254,222,221,204,170,170,170,171,188,221,255,238,253,203,186,152,136,137,170,188,223,255,238,220,185,135,119,119,137,171,205,239,238,236,186,151,102,85,103,137,171,206,254,222,203,168,118,68,69,103,138,188,222,237,236,185,135,84,51,69,120,155,206,238,221,203,152,117,67,52,86,138,188,223,237,236,202,135,101,68,69,120,171,222,238,221,219,169,135,101,85,103,154,205,255,237,222,203,169,135,119,119,138,188,239,255,223,220,186,169,136,136,154,187,206,239,253,237,220,203,170,170,170,187,205,239,255,223,237,220,203,187,187,188,205,239,255,253,238,221,221,204,205,205,221,255,255,255,223,239,239,221,238,222,238,239,255,255,253,255,255,254,254,255,239,255,255,255,255,140,221,222,222,237,221,238,255,255,255,224,0,0,0,205,221,204,204,204,204,204,204,204,205,157,254,237,220,204,204,204,205,222,239,237,222,221,204,203,187,187,187,188,221,239,221,221,204,187,170,170,170,187,188,221,237,205,219,186,153,152,137,154,171,204,238,220,220,186,152,136,119,136,153,171,205,221,204,186,152,135,102,103,120,154,171,221,220,203,169,135,101,85,102,120,154,189,221,204,186,152,101,84,69,103,137,171,206,219,203,169,118,84,68,69,103,138,188,220,204,186,151,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,206,220,204,170,152,119,102,103,136,155,189,237,205,203,169,152,135,119,136,154,188,238,220,221,203,170,153,152,153,170,188,222,238,205,220,187,170,170,170,171,188,221,255,236,221,220,203,187,187,187,204,221,239,254,207,238,221,204,204,204,205,222,239,255,237,238,237,221,221,221,221,238,254,255,254,140,221,221,221,221,221,221,238,238,239,208,0,0,0,222,221,204,204,187,187,187,204,204,204,158,238,221,204,203,187,188,204,221,222,237,222,220,203,187,170,170,187,188,205,222,221,221,203,170,169,153,154,170,188,205,237,205,203,170,152,136,136,153,170,188,221,220,203,169,152,119,119,120,137,171,188,220,204,186,152,119,102,103,120,137,171,204,204,203,153,135,101,85,102,120,154,188,220,203,169,135,101,84,85,103,120,154,188,203,186,152,118,84,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,203,186,152,135,101,84,85,103,137,172,220,188,186,152,118,101,85,103,137,155,205,203,203,169,136,119,102,103,120,154,188,221,204,187,169,136,119,119,120,153,171,205,220,204,186,169,152,136,136,153,171,205,221,205,204,187,170,153,153,170,171,188,222,236,221,204,187,186,170,171,187,204,222,238,222,221,204,203,187,187,204,205,222,239,237,238,221,221,204,204,205,221,238,239,254,173,221,204,204,204,204,205,221,222,239,208,0,0,0,206,221,221,204,204,204,204,204,204,204,157,255,237,221,204,204,204,221,222,238,253,222,237,204,203,187,187,188,204,221,239,221,221,204,186,170,170,170,187,204,222,236,221,220,186,153,153,153,154,171,205,222,220,220,186,152,135,119,136,154,171,205,237,204,186,152,119,102,103,120,154,172,205,220,203,169,135,101,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,220,186,152,119,102,103,136,154,204,221,205,203,186,152,135,119,136,154,188,221,220,221,203,170,153,153,153,154,187,205,237,205,220,203,186,170,170,171,188,205,238,220,237,220,204,187,187,187,188,205,222,253,206,237,221,204,204,204,205,221,238,255,237,238,238,222,221,221,222,222,238,255,254,157,220,205,221,204,205,221,221,222,238,208,0,0,0,207,255,238,221,205,204,220,204,221,205,143,255,255,254,237,238,221,222,238,255,253,239,255,238,221,204,205,221,222,238,239,222,254,237,220,203,187,188,204,222,239,254,238,238,204,186,170,170,171,204,206,239,237,237,220,186,152,136,137,170,205,222,254,222,220,186,136,119,119,137,171,205,239,238,237,203,152,101,85,103,137,172,222,254,238,219,169,117,68,69,103,138,189,239,237,236,202,135,84,51,69,120,171,206,254,221,203,168,117,67,52,87,138,189,239,237,220,186,151,101,68,69,120,171,222,238,222,203,169,135,101,85,104,154,205,239,253,237,203,169,135,118,120,154,188,238,255,223,220,186,169,136,136,154,188,222,239,237,254,221,203,186,170,170,188,222,222,254,223,237,220,204,187,187,204,222,238,255,237,239,237,221,205,221,221,238,255,254,254,223,254,222,238,238,222,238,255,239,254,254,255,238,238,239,255,239,255,255,255,255,157,221,221,221,221,238,238,254,255,255,224,0,0,0,189,220,204,187,187,204,204,188,188,205,141,238,221,220,204,204,204,205,221,238,237,222,237,220,187,187,187,188,204,205,223,220,220,204,186,170,170,170,187,204,221,237,205,204,186,153,153,153,154,171,204,222,220,220,186,153,136,119,136,153,171,205,237,205,203,152,135,102,103,120,154,188,205,204,203,169,135,101,85,102,120,154,189,220,205,186,151,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,237,204,186,151,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,205,186,152,118,101,85,103,137,172,206,204,220,186,152,119,102,103,137,154,188,237,204,203,169,152,135,119,137,154,188,223,220,220,203,170,153,153,153,170,188,221,237,206,220,203,186,170,170,170,187,205,223,220,237,221,204,187,187,187,204,221,238,238,222,237,221,204,204,204,205,221,223,239,237,255,238,237,220,221,221,238,238,255,254,124,205,204,204,204,205,221,221,237,238,192,0,0,0,171,187,170,170,170,170,170,170,170,187,139,220,203,186,170,170,170,171,188,204,220,188,187,170,169,153,153,154,170,188,205,187,203,170,153,152,136,153,154,171,188,203,171,170,152,136,136,136,136,153,171,188,186,186,153,136,119,119,119,136,153,171,203,170,169,135,118,102,102,119,136,154,187,186,169,152,118,102,85,102,119,137,154,187,170,152,135,102,85,85,102,120,153,171,169,169,136,118,85,85,85,103,136,154,187,170,152,135,102,85,85,86,119,137,171,170,169,152,118,101,85,86,103,136,154,187,170,169,135,118,101,86,102,120,153,171,186,186,152,135,118,102,102,119,137,154,187,171,170,152,135,119,119,119,137,154,187,186,187,169,152,136,135,136,137,154,171,203,171,187,170,153,152,136,153,154,171,188,203,203,187,170,169,153,153,170,171,188,220,188,204,187,170,170,170,170,187,204,221,203,221,204,187,187,187,187,188,204,222,237,139,187,187,187,186,170,187,187,204,205,176,0,0,0,171,186,170,153,153,153,153,170,170,187,139,204,187,170,170,170,170,170,187,204,203,187,186,169,153,153,153,153,170,171,188,186,186,169,152,136,136,136,153,170,171,203,171,169,152,136,119,120,136,153,170,187,170,169,152,135,119,119,119,136,153,170,186,154,152,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,153,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,102,119,137,154,186,170,169,152,135,119,119,119,136,154,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,153,136,136,136,153,170,188,186,187,186,169,153,153,153,154,170,188,203,188,187,186,170,170,170,170,171,188,205,203,204,203,187,186,170,171,187,188,204,220,139,187,170,170,170,170,170,171,187,204,176,0,0,0,172,187,186,170,170,170,170,170,187,187,140,220,187,187,170,170,170,187,188,205,220,188,187,170,169,153,153,170,171,187,204,187,187,170,153,152,136,137,154,171,187,203,187,170,153,136,135,136,137,153,171,188,186,186,153,135,119,119,119,136,154,171,187,170,169,135,118,102,102,119,137,154,187,186,169,152,118,102,85,102,119,137,170,187,170,152,135,101,85,85,102,120,153,171,170,169,136,118,85,85,86,103,120,154,186,170,152,135,101,85,85,86,120,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,102,86,102,120,137,171,170,186,152,135,118,102,102,119,137,170,187,171,169,152,135,119,119,119,137,154,187,186,187,169,152,136,136,136,137,154,171,203,188,187,170,153,152,136,137,154,171,204,187,204,187,170,169,153,153,170,171,188,219,189,204,187,170,170,170,171,187,188,205,203,220,204,187,187,187,187,187,204,221,220,140,187,187,186,170,170,187,187,188,204,160,0,0,0,189,221,205,203,203,187,203,203,204,204,125,255,221,204,203,187,204,205,221,222,237,221,220,204,187,171,171,187,204,221,238,221,221,203,186,169,153,170,171,188,205,236,205,203,170,153,136,137,153,170,188,221,220,219,186,152,135,119,120,153,171,188,221,204,186,152,119,102,103,120,137,171,205,204,203,169,135,101,85,102,120,154,188,220,188,185,135,101,84,85,103,121,155,188,204,186,152,118,84,68,69,103,137,172,205,204,169,135,101,84,68,86,120,155,189,219,202,168,135,101,84,85,103,137,187,205,187,186,152,118,101,85,103,137,170,205,220,203,169,136,119,102,103,120,154,188,221,204,187,169,152,119,119,136,154,187,222,220,220,186,169,152,136,137,154,187,221,237,221,220,187,170,169,153,170,188,205,239,220,237,220,187,187,170,187,188,204,238,238,222,237,221,204,204,204,204,205,238,239,253,254,221,221,220,221,221,222,237,255,254,141,205,205,204,204,204,205,221,238,239,192,0,0,0,223,255,255,255,255,254,237,221,221,220,143,255,255,255,255,255,255,255,239,255,253,255,255,255,255,238,237,221,239,255,255,255,255,255,221,220,204,204,205,223,255,255,255,255,236,203,187,171,188,221,255,255,255,255,237,187,169,153,154,171,205,255,255,239,253,202,152,119,119,137,172,223,255,255,254,219,168,118,86,103,138,189,223,255,255,252,185,118,84,69,104,155,205,255,255,253,203,151,84,35,70,121,172,239,255,255,236,169,118,67,36,87,155,205,255,255,253,203,152,101,68,70,121,188,239,255,239,221,186,135,102,86,120,171,223,255,255,254,220,169,136,119,120,154,205,255,255,223,253,203,170,153,153,171,189,223,255,253,255,221,203,187,170,187,204,254,255,255,239,253,237,220,204,204,205,239,255,255,253,255,239,221,221,222,238,255,255,255,255,207,255,255,239,238,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,124,205,221,221,253,239,255,255,255,255,240,0,0,0,222,238,221,220,204,204,204,204,204,204,158,255,238,237,204,204,204,205,221,238,253,239,237,220,203,187,187,188,204,221,239,221,237,220,187,170,170,170,187,204,221,254,222,220,186,153,153,153,154,171,204,222,221,220,186,152,136,119,136,153,171,205,237,221,202,152,119,102,103,120,154,188,221,220,219,169,135,101,85,102,120,154,205,237,204,186,151,101,84,69,103,137,171,205,220,203,168,118,84,68,69,103,154,188,237,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,237,204,186,152,118,101,85,103,137,172,222,236,220,186,152,119,102,103,120,155,205,237,205,203,169,152,135,119,136,154,188,239,236,220,203,170,153,153,153,170,188,222,254,206,220,203,186,170,170,171,188,222,255,236,237,220,204,187,187,187,205,222,239,255,207,237,221,220,204,204,205,222,239,255,252,254,254,221,221,222,238,238,255,255,255,141,221,205,221,221,221,221,238,255,255,208,0,0,0,222,237,220,204,187,187,187,188,204,204,158,254,237,204,203,187,187,204,205,222,237,238,221,203,186,170,170,171,187,204,222,221,220,203,170,153,153,153,170,187,205,221,221,203,169,152,136,136,137,154,187,205,204,203,169,136,119,119,119,137,154,188,220,204,186,152,118,102,102,119,137,171,205,204,186,152,118,101,85,102,120,137,171,204,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,204,187,169,135,118,101,85,102,120,154,189,203,203,169,135,118,102,102,120,154,188,221,204,186,153,136,119,119,120,137,171,205,220,203,186,153,136,136,136,153,171,205,238,205,203,186,169,153,153,154,171,204,222,236,221,204,187,170,170,170,187,204,222,255,206,221,204,187,187,187,188,205,222,255,253,238,221,205,204,204,204,221,239,255,255,173,220,204,204,204,204,221,222,239,255,224,0,0,0,223,237,238,221,220,204,204,204,204,204,159,255,254,237,220,204,204,205,221,238,237,239,238,220,204,187,187,188,204,221,238,222,238,220,187,170,170,170,187,188,221,237,222,220,186,153,152,153,154,171,204,222,221,220,186,152,135,119,136,153,171,205,221,221,203,168,119,102,103,120,154,188,221,204,219,169,135,101,85,102,120,154,188,220,204,186,151,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,220,204,186,151,101,68,68,86,121,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,172,205,220,220,186,152,119,102,103,136,155,205,221,205,203,170,152,135,119,136,154,188,223,221,220,203,170,153,137,153,170,188,221,237,205,220,203,186,170,170,171,188,221,239,237,237,220,204,187,187,187,204,221,238,254,205,237,221,204,204,204,205,222,255,255,253,254,238,237,221,221,238,222,254,255,254,156,205,204,204,204,221,221,222,239,255,208,0,0,0,239,255,255,255,238,221,221,221,204,205,127,255,255,255,255,255,239,238,254,255,253,255,255,255,239,220,221,221,255,239,255,223,255,254,221,204,187,188,205,221,223,254,255,255,220,186,170,170,171,204,223,255,239,255,220,186,152,136,153,171,205,223,254,255,252,186,152,119,119,137,171,205,255,255,253,203,151,101,85,103,137,187,223,255,255,220,168,117,68,69,103,154,205,255,255,253,186,135,84,51,69,120,171,223,255,254,219,168,117,67,52,87,138,189,255,255,237,186,135,101,68,69,120,171,223,255,255,220,169,135,101,85,103,155,207,255,255,253,203,169,135,118,120,154,188,223,255,239,236,203,169,152,136,154,188,223,255,254,255,205,203,170,170,171,188,223,255,255,239,255,221,203,187,187,220,238,255,255,253,254,239,221,220,221,221,238,255,255,255,239,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,141,220,221,222,255,255,255,255,255,255,240,0,0,0,207,222,221,220,204,204,204,220,204,205,143,255,238,220,220,188,205,222,221,239,237,238,238,220,187,187,187,187,205,237,238,237,254,220,186,170,170,170,171,204,221,237,222,204,186,153,136,137,153,171,188,222,221,220,186,152,135,119,136,153,171,206,221,221,202,152,119,102,103,120,153,171,206,221,203,169,135,101,85,102,120,155,189,221,204,186,135,101,84,69,103,137,171,206,220,203,169,118,84,68,69,103,138,188,205,204,186,135,101,84,68,86,120,155,205,236,203,169,135,101,68,85,103,138,188,221,205,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,120,154,189,237,205,203,169,152,135,119,136,154,188,222,220,220,203,170,153,136,153,154,188,221,238,206,220,187,170,170,170,170,188,205,239,237,238,220,204,187,187,187,188,221,238,254,222,238,221,204,204,204,205,223,238,255,236,239,238,221,221,221,221,239,255,255,254,141,221,220,220,221,221,221,222,239,239,208,0,0,0,172,187,170,170,170,154,170,170,171,187,139,220,203,187,170,170,170,171,187,204,219,188,187,170,169,153,153,154,170,188,205,187,203,170,153,136,136,153,153,170,188,203,171,170,153,136,135,136,136,153,171,188,186,186,153,135,119,119,119,136,153,171,203,171,169,135,118,102,102,119,136,154,187,170,169,152,118,102,86,102,119,137,170,186,170,152,135,102,85,85,102,120,153,171,170,169,136,118,85,85,85,103,136,154,186,170,152,135,102,85,85,86,119,137,171,170,169,152,118,101,85,86,103,120,154,187,170,153,135,118,102,86,102,120,137,171,186,170,152,135,118,102,102,119,137,170,187,171,169,152,135,119,119,119,136,154,187,186,186,169,152,136,119,120,137,154,171,203,172,186,169,153,136,136,153,154,171,204,203,203,186,170,153,153,153,170,171,188,220,188,203,187,170,170,170,170,187,204,222,219,220,204,187,187,187,187,188,205,221,236,139,187,187,187,170,170,187,187,204,205,176,0,0,0,171,186,170,153,153,153,153,154,170,187,155,204,187,170,170,153,170,170,187,188,203,188,186,169,153,153,153,153,170,171,188,186,186,169,152,136,136,136,153,154,171,203,171,169,152,136,119,119,136,153,154,187,170,169,152,135,119,119,119,136,153,170,186,154,152,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,170,153,152,119,102,101,86,102,120,137,170,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,169,136,118,102,85,102,103,120,153,170,154,152,135,118,102,102,102,119,137,170,169,169,152,135,118,102,102,119,136,154,186,154,169,136,135,119,119,119,136,153,171,170,186,153,136,136,119,120,136,153,170,187,171,170,153,152,136,136,136,153,170,188,186,187,170,169,153,153,153,153,170,188,203,188,187,186,170,169,154,170,171,187,205,203,220,203,187,170,170,170,187,188,205,220,155,187,170,170,170,170,170,171,187,204,176,0,0,0,188,203,187,170,170,170,170,170,187,187,140,221,203,186,170,170,170,187,188,204,220,205,203,170,169,153,153,154,170,188,205,203,203,170,153,152,136,137,153,170,188,203,188,170,152,136,119,120,136,153,171,188,187,186,152,135,119,119,119,136,153,171,203,171,169,135,118,102,102,119,136,154,171,186,169,136,118,102,86,102,119,137,170,187,170,152,119,102,85,85,102,120,137,171,186,169,135,118,85,85,86,103,120,154,186,170,152,119,102,85,85,86,119,137,171,186,169,136,118,101,85,86,103,136,154,187,170,169,135,118,102,86,102,120,137,171,186,186,152,135,118,102,102,119,137,170,187,171,169,152,135,119,119,119,136,154,188,187,187,169,152,136,119,120,137,154,171,204,188,187,169,153,136,136,153,154,171,204,203,204,187,170,153,153,153,154,171,204,220,189,204,187,186,170,170,171,187,188,221,204,220,204,203,187,187,187,188,204,222,237,139,187,187,186,170,187,187,188,204,205,176,0,0,0,207,237,237,220,204,204,204,204,204,204,126,255,254,221,220,205,221,206,238,255,253,223,221,220,220,204,188,204,205,221,254,221,238,220,187,187,170,187,187,221,222,237,222,221,186,169,153,153,170,187,205,221,221,220,187,169,136,136,137,154,188,222,237,205,203,169,135,118,119,136,154,188,222,221,220,186,135,101,85,103,137,171,205,220,221,186,152,118,84,69,103,137,188,206,220,219,169,134,84,51,69,120,154,205,221,205,202,152,117,67,52,87,137,172,206,204,219,185,135,101,68,86,120,154,189,253,205,203,169,135,101,86,103,137,188,221,220,221,186,152,135,119,119,137,171,205,237,205,203,186,153,136,136,137,171,205,223,236,237,219,186,169,153,154,171,188,222,222,207,221,203,187,170,170,171,188,222,223,237,254,221,204,203,203,204,205,222,238,253,223,239,253,221,221,220,237,237,238,255,253,255,253,238,237,221,223,238,254,255,255,141,221,220,205,221,205,205,221,237,238,208,0,0,0,255,255,255,255,253,254,207,205,204,204,143,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,221,255,205,221,255,255,255,255,255,255,219,204,187,204,207,255,255,255,255,255,204,186,170,171,188,223,255,255,255,255,203,169,136,136,154,189,255,255,255,255,253,169,135,102,120,155,205,255,255,255,220,186,134,84,69,120,172,223,255,255,255,251,168,100,34,70,137,189,255,255,223,220,185,134,66,36,104,155,221,255,255,255,204,168,117,68,86,138,191,255,255,255,207,202,152,118,102,121,173,255,255,255,253,253,186,152,136,137,171,220,255,255,223,255,220,202,170,170,171,207,255,255,255,255,255,219,204,187,204,253,223,255,255,255,255,255,255,221,207,223,255,255,255,255,255,255,253,255,205,255,255,255,255,255,239,255,255,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,141,255,223,255,255,255,255,255,255,255,240,0,0,0,223,253,221,220,204,203,204,204,204,204,143,255,238,221,220,204,205,220,237,223,252,255,238,220,204,203,187,188,204,222,239,223,253,204,187,171,170,171,187,204,222,237,221,220,187,170,153,153,154,188,205,221,221,253,203,169,136,136,137,154,187,205,221,220,203,169,135,119,119,136,154,188,222,221,220,169,135,102,85,103,137,171,205,237,204,202,152,118,84,69,103,137,172,222,220,203,169,135,84,51,69,120,154,188,221,220,186,152,117,67,52,86,137,171,205,220,203,169,135,101,68,86,120,154,189,221,221,203,169,135,101,85,103,137,188,222,220,204,186,152,135,118,119,137,171,205,238,205,203,186,153,136,136,137,171,205,222,252,237,187,186,169,153,154,171,189,223,254,205,237,203,187,186,170,187,204,237,255,236,238,220,204,204,188,204,221,223,239,255,205,237,221,205,205,220,221,223,239,255,252,255,253,238,237,238,238,239,255,255,255,141,220,205,205,221,237,238,254,255,255,224,0,0,0,255,255,237,220,204,204,204,204,221,221,175,255,253,220,203,187,188,204,221,239,254,255,237,203,187,170,170,171,188,205,239,238,237,203,170,153,153,153,170,188,205,254,237,203,169,152,136,136,137,154,188,221,221,219,169,152,119,119,119,137,154,188,221,204,186,152,118,102,102,119,137,171,205,220,202,152,118,101,85,102,119,137,171,221,203,169,135,101,85,85,86,120,154,188,220,186,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,189,220,186,152,118,101,85,85,103,137,171,221,203,169,135,118,101,85,102,120,155,205,236,203,169,135,118,102,102,120,154,188,222,204,186,169,135,119,119,120,153,171,223,237,220,186,153,136,136,136,154,171,205,255,221,204,186,169,153,153,154,171,205,255,253,237,204,187,186,170,171,188,205,239,255,223,237,220,204,187,187,204,221,239,255,253,255,237,221,221,221,221,222,255,255,255,173,221,221,221,220,221,222,239,255,255,240,0,0,0,239,255,237,220,220,204,204,204,205,221,159,255,254,221,204,204,204,205,221,238,253,254,238,204,203,187,187,187,188,222,238,222,255,220,187,170,153,170,171,204,206,221,237,236,186,153,136,136,154,171,188,238,205,220,186,152,135,119,120,137,171,204,237,221,202,152,119,102,102,120,137,171,205,221,219,169,135,101,85,102,120,154,188,221,220,186,151,101,84,85,102,120,171,189,204,203,168,118,84,68,85,103,137,172,222,204,169,135,101,68,68,86,120,155,205,220,203,168,118,101,84,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,220,169,136,118,102,103,120,154,189,221,221,203,169,136,135,119,136,154,188,223,221,220,203,169,152,136,137,154,188,206,254,221,220,187,186,169,170,170,188,222,223,253,253,204,203,187,186,187,188,221,239,255,223,221,220,204,204,204,204,221,238,255,253,238,222,221,221,221,221,239,239,255,255,156,204,204,205,220,237,238,239,255,254,240,0,0,0,255,255,255,255,254,221,237,221,204,221,143,255,255,254,254,221,221,223,255,255,254,255,255,255,254,221,221,220,238,239,255,255,255,254,221,204,187,187,205,223,255,253,255,222,220,187,170,170,170,204,207,255,223,255,204,186,152,136,153,171,205,253,255,237,237,186,135,119,119,137,171,205,255,221,237,203,151,101,85,103,137,188,255,239,239,219,168,117,68,69,103,154,205,239,237,236,202,135,84,51,69,120,171,223,254,222,203,168,117,67,52,87,137,205,239,253,236,202,151,101,68,69,121,171,222,223,254,220,169,135,101,85,103,154,205,255,254,222,203,169,135,119,120,154,188,239,255,255,253,203,169,152,136,154,188,222,255,255,223,204,187,170,169,171,188,221,254,255,223,238,236,204,187,188,189,237,255,255,255,239,253,221,204,220,205,223,255,255,255,207,222,239,222,253,239,255,255,255,255,253,255,253,255,238,238,255,255,255,255,255,124,203,205,222,255,238,223,255,255,255,240,0,0,0,205,237,219,204,186,171,187,187,187,187,127,253,205,203,186,187,187,191,220,220,253,221,220,187,170,170,170,187,187,237,207,236,220,186,170,153,152,153,170,187,205,223,220,186,169,136,136,136,153,154,188,206,220,219,169,136,119,119,119,137,154,205,207,204,185,152,119,102,102,119,137,170,204,220,202,152,119,101,85,102,119,137,172,204,187,169,135,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+959640);
/* memory initializer */ allocate([85,85,102,120,154,188,219,202,152,118,85,68,85,103,137,170,204,203,169,135,101,84,69,86,120,154,188,219,186,152,118,101,85,85,103,137,171,205,187,169,136,118,101,85,103,120,154,189,203,203,169,135,118,102,102,120,137,172,207,204,186,153,136,119,119,120,137,171,205,204,219,170,153,136,136,136,153,171,204,221,223,203,170,169,152,153,154,171,189,223,252,238,219,186,170,170,170,187,189,222,255,207,221,221,188,187,187,188,204,222,255,221,221,237,205,205,220,204,206,223,255,255,141,187,237,204,203,205,207,221,223,255,240,0,0,0,189,203,186,170,153,153,154,170,170,187,124,220,203,186,170,170,170,171,187,188,220,204,187,170,153,153,153,154,170,187,204,203,186,169,153,136,136,136,153,154,188,220,187,170,152,136,119,119,136,153,170,187,186,170,152,135,119,119,119,136,153,171,187,170,153,135,118,102,102,119,136,154,171,185,169,136,118,102,102,102,119,136,154,171,154,152,119,102,85,85,102,120,137,171,185,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,154,185,169,136,118,101,85,86,103,120,154,186,154,152,135,118,102,102,102,120,137,171,186,170,152,135,118,102,102,119,136,154,187,171,169,152,135,119,119,119,136,154,172,186,186,169,136,135,119,120,136,154,171,204,187,186,169,152,136,136,137,153,171,205,203,203,186,169,153,153,153,154,187,204,222,188,204,187,170,170,170,171,187,205,206,219,222,204,203,187,187,187,188,204,221,237,156,203,187,171,170,186,187,187,205,221,208,0,0,0,188,187,170,153,153,153,153,170,171,187,156,204,187,170,153,153,154,170,171,188,220,188,186,169,153,153,153,153,154,171,188,187,186,169,152,136,136,136,153,154,171,187,170,169,152,135,119,119,136,137,154,171,186,169,152,135,119,119,119,120,137,154,186,170,152,135,118,102,102,119,120,137,171,169,169,136,118,102,102,102,119,136,154,170,153,152,119,102,101,102,102,119,137,154,169,153,135,118,101,85,102,103,120,153,170,153,152,119,102,101,85,102,119,137,154,169,153,135,118,102,85,102,103,120,154,170,154,152,135,118,102,102,102,119,137,170,169,169,136,119,118,102,102,119,136,154,187,170,153,136,119,119,119,119,136,153,171,186,186,153,136,135,119,119,136,153,171,187,171,170,153,136,136,136,136,153,170,188,187,187,170,153,153,153,153,153,170,187,220,188,187,170,170,153,153,170,170,188,205,219,205,203,187,170,170,170,171,188,205,221,156,187,186,170,170,170,170,187,204,221,192,0,0,0,204,203,186,170,170,154,170,170,187,187,140,205,187,186,170,170,170,171,188,204,220,204,186,186,169,153,153,154,170,171,204,204,203,169,153,136,136,137,153,154,187,203,187,170,152,136,119,120,136,153,170,188,187,170,152,135,119,119,119,136,153,171,187,170,169,135,118,102,102,119,136,153,171,170,169,136,118,102,86,102,119,137,154,187,154,152,119,102,85,85,102,120,137,171,170,169,135,118,85,85,86,103,121,154,187,170,152,119,102,85,85,102,119,137,170,169,169,136,118,101,85,86,103,120,154,170,170,152,135,118,102,102,102,120,153,171,186,186,152,135,118,102,102,119,137,170,188,171,170,152,135,119,119,119,136,154,188,186,186,169,152,136,119,120,136,154,187,203,171,186,169,153,136,136,137,154,171,204,203,219,170,170,153,153,153,154,187,205,220,188,187,186,170,170,170,171,187,204,222,219,204,204,187,187,187,187,188,204,206,221,123,187,186,170,170,170,187,203,204,204,192,0,0,0,255,255,255,255,223,220,254,205,204,221,127,255,255,255,255,223,255,255,223,255,255,255,255,255,253,255,223,255,221,255,255,255,255,255,252,220,189,223,253,223,255,255,255,255,252,220,204,187,204,255,223,255,253,255,253,203,170,170,172,187,190,223,255,239,223,220,169,152,137,170,203,255,255,255,255,204,169,134,102,120,171,205,255,253,255,253,186,134,84,69,121,172,207,223,255,255,204,168,100,34,70,138,190,223,255,255,253,202,134,66,36,104,171,207,255,255,255,220,169,117,68,86,138,205,223,254,255,253,219,152,118,102,137,188,223,255,255,255,252,186,153,136,137,187,221,255,255,255,253,204,186,169,154,188,221,255,255,255,255,255,220,188,187,204,204,255,255,255,255,255,220,253,221,221,223,255,255,255,255,255,255,255,220,253,255,255,255,255,255,255,255,255,253,223,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,127,205,223,253,238,223,255,255,255,255,240,0,0,0,255,255,223,255,253,255,252,255,252,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,253,255,223,255,223,255,255,255,255,252,252,204,207,221,255,252,255,255,255,207,221,187,186,172,203,253,255,255,255,255,255,170,153,137,170,175,255,255,255,207,252,186,135,102,121,171,221,255,255,255,255,203,151,84,69,121,188,255,255,255,255,255,185,100,34,70,138,221,221,255,255,253,220,150,66,35,105,187,207,255,255,255,252,185,117,68,87,155,191,255,255,207,255,255,169,118,102,137,251,255,255,255,255,255,203,169,136,153,173,255,255,255,255,255,255,220,170,171,204,255,255,255,255,255,223,255,219,187,191,207,255,255,255,255,255,255,221,253,253,252,255,255,255,255,255,255,255,220,220,223,255,255,255,255,255,255,255,255,255,255,255,221,255,255,255,255,255,255,255,255,255,255,255,255,255,127,223,253,255,250,189,255,255,255,255,240,0,0,0,137,153,152,136,136,136,136,152,152,154,106,203,154,169,153,153,170,154,171,170,218,154,169,137,153,137,153,137,138,153,170,154,170,153,136,136,136,136,137,169,170,170,137,169,152,136,136,136,136,137,154,185,169,169,152,120,119,119,119,136,137,154,169,137,152,135,118,118,119,119,136,153,154,168,152,136,118,102,102,119,119,136,137,152,137,152,135,118,102,102,103,120,136,155,168,153,135,118,101,85,102,119,136,152,168,137,136,135,118,101,86,103,119,136,153,152,153,120,119,102,101,102,103,120,138,153,137,152,120,119,102,102,103,119,136,171,152,153,137,135,119,118,103,119,136,137,169,154,154,152,119,119,119,119,120,137,155,152,169,153,136,136,135,120,136,136,154,169,138,153,153,137,136,136,136,153,138,170,169,171,170,152,136,137,136,137,154,186,169,172,186,185,170,153,153,154,153,170,173,169,186,171,171,169,154,154,186,170,156,187,139,169,168,153,152,136,153,154,170,171,160,0,0,0,255,255,254,221,204,204,220,221,237,239,223,255,237,220,187,187,188,204,222,255,255,255,254,203,186,170,170,171,188,222,255,255,253,203,170,153,153,153,170,188,221,255,253,203,169,152,135,136,137,154,188,255,254,220,169,136,119,119,119,136,154,188,223,220,186,152,118,102,102,103,137,171,205,238,187,152,118,101,85,86,103,137,171,223,203,169,135,101,85,85,86,120,154,189,220,186,152,118,85,69,85,103,137,171,221,203,169,135,101,85,69,86,120,154,188,220,186,152,118,101,85,85,103,137,172,221,204,169,135,118,85,85,102,120,155,205,236,202,169,135,102,102,102,120,154,188,223,220,186,153,135,119,119,120,137,171,223,255,220,186,153,136,136,136,153,171,205,255,254,203,186,153,153,153,154,171,205,255,255,253,220,203,170,170,170,188,205,255,255,255,239,221,203,187,187,204,221,255,255,255,255,255,253,221,221,222,222,255,255,255,207,254,254,254,239,221,223,255,255,255,240,0,0,0,155,170,153,169,137,137,153,152,153,187,107,171,186,170,153,153,153,186,171,190,251,155,170,153,153,153,153,169,172,155,186,201,185,169,153,136,137,136,137,170,170,186,153,153,136,136,119,135,136,137,170,170,169,154,136,135,119,119,120,136,153,170,169,154,153,135,118,102,103,119,136,153,187,169,153,136,119,102,102,102,120,136,153,185,154,152,135,102,85,86,103,120,137,170,153,153,135,118,101,85,86,119,120,138,169,153,153,135,102,85,85,102,120,153,171,168,153,152,118,102,85,86,103,120,153,169,153,152,152,119,102,102,103,120,152,155,169,153,152,135,119,102,119,119,137,153,202,154,169,136,135,119,119,119,136,154,171,153,186,153,136,136,135,136,136,137,155,185,171,169,170,136,136,136,136,154,186,171,169,234,170,154,169,154,137,153,154,172,171,172,218,186,170,154,153,170,171,186,204,170,251,219,186,170,170,186,187,187,252,251,122,153,153,153,153,153,153,154,170,171,160,0,0,0,255,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,251,169,170,187,255,255,255,255,255,255,251,152,119,137,175,255,255,255,255,255,255,168,84,70,138,255,255,255,255,255,255,218,116,18,71,171,255,255,255,255,255,255,167,66,36,121,191,255,255,255,255,255,186,134,68,87,175,255,255,255,255,255,255,185,135,119,155,255,255,255,255,255,255,251,186,154,171,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,240,0,0,0,138,152,136,135,119,247,111,136,143,170,89,250,175,175,138,135,138,168,250,169,249,154,175,152,154,121,137,120,154,250,255,172,136,143,135,136,168,137,154,135,175,250,122,169,135,120,119,152,120,137,170,250,168,152,153,135,120,135,119,135,135,250,232,139,151,118,136,119,103,119,120,120,138,135,169,143,119,119,103,151,136,120,153,168,121,137,119,118,102,118,119,119,143,137,152,249,136,151,102,87,103,120,119,169,136,120,135,135,102,102,102,103,104,151,249,136,168,120,135,118,102,119,104,119,136,137,153,168,120,119,119,118,103,118,119,137,169,138,135,135,119,104,118,118,136,154,154,170,167,151,135,135,135,119,153,119,154,135,154,153,121,121,118,135,152,153,168,136,152,154,169,153,151,152,138,152,154,255,168,250,127,138,143,152,138,168,255,249,168,175,153,153,136,153,170,152,154,170,175,170,250,249,154,250,249,138,168,152,175,169,159,250,137,135,120,152,135,138,135,153,144,0,0,0,255,255,255,255,255,251,255,191,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,250,191,255,255,255,255,255,255,255,255,186,136,171,255,255,255,255,255,255,255,248,101,87,159,255,255,255,255,255,255,255,132,18,88,175,255,255,255,255,255,255,248,82,20,143,255,255,255,255,255,255,251,150,84,104,175,255,255,255,255,255,255,250,168,137,175,255,255,255,255,255,255,255,255,235,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,255,255,255,255,255,111,251,255,255,255,191,255,255,255,255,240,0,0,0,255,239,254,239,255,254,238,229,255,255,255,254,238,238,238,239,255,255,255,255,255,255,254,238,238,238,78,238,238,238,238,239,255,255,95,255,255,245,255,255,255,255,255,255,255,254,238,94,238,238,238,238,238,238,238,238,238,238,229,229,238,238,238,239,255,85,245,95,245,255,95,95,255,255,244,255,255,255,255,255,85,255,255,255,255,245,255,245,255,95,79,254,238,238,238,238,238,238,238,227,229,238,94,238,238,238,229,78,238,94,94,229,94,94,85,238,238,84,238,229,94,229,230,94,238,238,238,239,245,255,245,255,245,255,255,255,255,255,255,95,245,255,95,255,245,255,255,255,255,255,245,255,95,245,95,255,255,255,255,255,244,255,255,255,255,255,255,255,255,255,255,255,255,245,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,95,255,255,255,254,255,254,255,95,254,255,255,255,255,255,255,254,255,254,254,255,255,255,254,255,240,0,0,0,120,246,102,104,118,103,103,152,120,127,104,152,159,248,247,254,143,255,159,255,159,136,127,136,159,121,159,255,143,159,249,150,153,151,120,103,247,152,255,121,153,248,119,248,137,151,120,137,247,143,255,255,120,153,121,151,151,119,153,127,121,153,152,119,159,103,103,103,120,152,159,153,137,246,159,121,120,118,102,248,120,137,120,248,135,136,153,135,119,105,121,120,247,159,119,249,153,118,119,119,104,135,120,159,151,136,120,137,151,118,119,119,137,143,143,103,137,152,137,120,119,135,120,121,120,150,104,159,168,151,120,120,143,137,121,143,103,255,143,153,119,102,102,118,134,248,246,153,159,127,137,151,121,136,111,136,137,104,255,255,249,152,137,248,255,152,159,247,120,121,249,119,137,248,151,137,249,152,119,159,159,137,159,153,152,159,153,159,152,137,152,255,159,248,249,136,159,127,249,103,255,153,152,249,255,137,159,255,159,249,89,119,152,104,150,119,104,137,247,111,96,0,0,0,104,137,120,119,103,136,136,255,121,153,105,249,249,136,135,121,143,249,248,249,247,143,152,120,121,249,248,136,121,127,249,151,255,143,152,120,119,103,248,249,255,249,120,248,136,135,136,119,152,247,152,255,152,159,248,152,135,118,121,151,120,137,140,119,136,120,119,119,136,119,120,121,159,136,121,119,119,119,103,119,119,143,153,151,135,119,120,135,120,118,119,120,159,153,247,119,152,118,118,119,104,127,120,255,249,120,136,135,136,118,103,136,121,120,249,135,137,151,119,104,103,119,119,119,142,120,120,138,136,119,135,119,103,136,136,143,135,137,136,119,118,119,121,119,119,143,136,121,248,119,120,119,136,119,120,152,137,137,255,248,136,153,119,152,120,135,153,153,152,248,152,255,255,121,136,119,121,143,136,248,136,255,136,120,153,159,136,249,248,136,153,185,247,136,153,249,153,159,255,153,255,143,152,143,137,153,248,153,143,249,95,137,119,135,153,120,136,119,248,143,128,0,0,0,94,222,229,222,238,237,221,222,238,238,78,237,221,221,221,222,238,238,238,238,238,238,238,237,221,77,221,221,221,221,221,222,238,238,238,238,238,94,238,238,238,238,238,238,238,238,238,221,93,221,221,221,221,221,221,221,221,213,69,221,221,221,221,222,238,238,229,238,238,229,238,238,94,238,238,238,229,229,238,229,84,238,238,238,238,238,69,238,238,85,238,238,229,237,221,221,221,221,221,221,221,93,221,221,221,85,221,221,85,93,77,221,221,69,221,93,221,221,221,221,84,221,221,221,221,221,221,222,94,238,94,238,238,94,238,238,229,238,238,238,78,238,78,238,238,238,238,238,238,94,238,228,229,238,238,238,238,238,238,238,238,238,229,238,238,238,94,238,238,238,238,238,238,238,85,238,238,238,238,238,238,238,238,238,238,229,94,238,238,238,238,237,238,237,238,238,238,238,238,238,238,229,237,237,238,238,238,94,238,238,237,237,238,229,238,238,237,237,237,238,224,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,159,255,249,248,249,79,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,254,255,255,255,255,255,255,255,248,100,104,159,255,255,255,255,255,255,255,133,18,111,255,255,255,255,255,255,255,255,82,20,223,255,255,255,255,255,255,255,249,84,95,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,89,255,255,255,250,255,255,255,255,255,240,0,0,0,247,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,247,127,255,255,255,111,255,246,246,255,127,255,255,255,255,246,255,255,255,255,247,246,255,246,255,255,255,246,255,255,102,246,255,246,255,255,255,255,255,255,87,103,111,255,255,255,253,191,247,247,111,102,111,102,246,255,255,246,246,255,117,118,245,102,102,102,255,255,246,255,255,245,87,102,255,255,127,255,255,246,255,86,86,117,119,255,111,255,255,255,247,246,246,246,68,245,246,255,255,255,255,255,255,102,86,117,86,246,255,253,198,175,246,111,255,85,87,95,127,255,255,247,255,255,101,111,255,104,127,255,255,111,255,246,246,95,101,111,111,255,255,255,246,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,246,111,255,255,255,255,111,255,255,255,255,255,111,255,255,255,255,255,255,255,111,255,255,255,255,255,246,255,255,111,255,255,255,255,255,95,127,127,255,255,127,255,127,255,255,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,253,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,246,111,255,255,255,255,255,255,255,255,255,18,255,255,255,255,255,255,255,255,255,97,21,255,255,255,255,255,255,255,255,255,245,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,159,255,255,255,255,255,255,255,255,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,238,238,238,222,238,238,221,222,238,238,238,237,221,221,221,222,238,238,238,238,238,238,238,237,221,221,221,221,221,221,221,222,238,238,238,238,94,238,238,238,238,238,238,238,238,238,94,237,213,85,221,221,221,221,221,221,221,221,221,221,221,221,221,222,238,238,229,229,238,238,238,238,238,238,238,238,238,229,238,229,238,238,238,238,238,238,94,94,238,85,84,238,238,238,238,237,221,221,213,93,68,93,221,221,221,221,93,213,213,93,221,211,221,221,221,221,221,221,221,93,212,53,93,221,221,221,221,213,94,228,84,83,238,238,238,238,238,238,238,229,238,238,94,238,238,238,238,238,229,238,94,238,229,94,238,94,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,94,238,228,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,229,238,238,237,238,237,221,237,237,237,237,238,238,238,238,238,238,238,238,238,237,238,238,237,238,237,237,238,224,0,0,0,189,220,205,204,204,220,221,255,255,255,221,239,237,220,204,204,204,223,239,255,255,223,253,220,187,187,170,187,205,223,255,253,237,204,187,169,153,153,170,188,223,255,205,204,186,153,136,136,137,154,188,223,236,220,186,152,135,119,119,136,154,188,238,221,186,168,135,118,102,103,136,154,205,221,219,169,135,102,102,102,103,137,171,205,204,169,135,118,85,85,86,119,137,189,220,203,152,118,101,85,85,102,120,154,189,204,169,135,101,85,85,86,103,137,173,205,202,152,118,101,85,85,102,120,154,204,220,185,135,102,85,85,86,119,138,188,221,219,169,135,102,85,102,103,137,171,205,236,202,152,135,102,102,119,136,154,188,222,220,186,153,135,119,119,137,154,188,220,254,236,186,153,136,136,137,154,188,205,223,254,220,187,169,153,154,170,188,205,238,255,255,220,203,186,171,187,204,221,222,223,255,255,237,204,204,204,204,221,239,237,223,255,223,221,221,220,204,205,237,206,176,0,0,0,238,238,238,222,238,238,221,222,238,238,238,238,237,221,221,222,238,238,238,238,238,238,238,238,238,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,78,238,237,221,221,221,221,221,221,221,221,212,221,221,221,221,222,238,238,238,78,78,78,238,238,238,238,238,238,238,238,238,238,78,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,228,227,77,221,221,221,221,221,221,221,221,221,221,77,77,221,221,221,221,221,221,221,68,77,77,221,221,221,221,78,228,238,62,78,238,238,238,238,238,238,238,227,238,229,238,238,238,238,238,238,238,238,228,238,238,238,78,238,238,238,238,238,238,238,238,78,62,238,238,238,238,238,238,238,238,238,228,238,238,238,238,238,238,238,238,78,238,78,238,238,238,238,238,238,238,238,238,238,238,238,238,237,237,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,224,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,156,187,170,170,170,154,170,171,188,205,187,204,187,187,170,170,170,171,188,205,220,188,203,170,169,153,153,170,171,171,205,219,203,170,153,153,136,136,137,154,187,204,171,170,169,152,136,136,136,137,154,187,186,186,153,136,119,119,119,120,137,154,187,170,169,136,119,118,102,119,120,137,171,186,170,152,119,102,102,102,103,120,153,170,170,153,135,118,102,102,102,119,136,154,170,169,136,118,102,85,86,102,120,137,170,170,152,135,102,101,85,86,103,136,154,170,169,136,118,102,85,86,102,120,153,170,170,153,135,118,102,86,102,119,137,154,170,169,152,119,102,102,102,119,136,153,170,171,169,136,119,118,102,119,120,137,171,171,186,153,136,119,119,119,136,137,170,186,187,186,153,152,136,136,136,137,154,171,188,204,186,153,152,136,136,153,170,187,187,221,204,186,169,153,153,153,170,187,204,189,221,203,187,170,170,170,170,187,188,203,188,203,186,170,169,154,170,170,186,188,144,0,0,0,155,186,169,153,153,153,153,154,187,204,187,204,202,170,170,154,169,170,187,189,220,188,187,170,169,153,152,153,169,171,187,203,186,170,153,136,136,136,137,153,171,187,170,169,152,136,136,119,136,136,154,171,170,170,152,136,119,119,119,120,136,153,186,154,153,136,119,118,102,119,119,137,154,169,153,152,119,102,102,102,119,120,137,170,153,152,135,118,102,102,102,119,136,154,153,153,136,118,102,102,102,103,119,137,153,153,152,119,102,102,86,102,103,120,153,153,169,135,118,102,102,102,102,119,137,169,153,152,135,118,102,102,102,119,136,153,153,169,136,119,102,102,102,119,120,137,169,170,153,136,119,118,103,119,120,137,154,154,169,152,135,119,119,119,120,136,154,185,171,170,153,136,135,119,136,137,153,171,171,202,170,153,136,136,136,137,153,171,187,187,187,170,153,153,153,153,153,170,188,188,204,203,170,154,153,154,154,171,188,204,188,202,170,169,153,153,153,154,170,171,160,0,0,0,171,186,170,153,153,153,153,154,171,188,187,204,187,170,153,153,153,170,171,187,204,188,186,170,153,153,137,153,153,170,188,186,186,169,153,136,136,136,136,153,170,187,170,169,152,136,135,119,136,136,153,170,170,169,152,136,119,119,119,119,136,153,170,154,153,136,119,119,103,119,119,137,154,153,169,136,119,118,102,102,119,120,137,169,153,152,135,118,102,102,102,119,120,153,153,152,135,119,102,102,102,102,119,137,153,153,136,119,118,102,102,102,103,120,153,153,153,135,119,102,102,102,103,119,137,153,153,152,119,118,102,102,102,119,136,153,153,153,136,119,102,102,102,119,120,137,169,154,152,135,119,119,103,119,120,137,154,154,169,152,135,119,119,119,120,136,153,169,171,169,152,136,119,119,136,136,153,171,170,186,169,152,136,136,136,137,153,170,186,187,186,169,153,153,137,153,153,170,187,188,203,187,170,169,153,153,170,170,188,203,188,187,170,153,153,153,153,154,170,187,160,0,0,0,156,186,170,154,153,153,153,154,171,203,171,204,186,170,169,153,169,170,170,188,204,172,186,170,153,153,153,153,154,170,188,187,203,169,153,136,136,136,137,154,171,204,170,170,153,136,119,119,120,136,153,170,170,186,152,136,119,119,119,120,137,154,170,154,153,136,119,118,103,119,119,136,154,153,153,136,119,102,102,102,103,120,137,169,153,152,119,118,102,102,102,103,136,137,153,152,135,119,102,102,102,102,119,136,169,153,152,135,102,102,102,102,103,120,137,153,153,135,118,102,102,102,103,119,137,153,154,136,135,118,102,102,102,119,136,154,153,169,136,119,118,102,102,119,120,137,169,170,153,135,119,119,103,119,119,137,154,170,186,152,136,119,119,119,120,137,153,170,171,170,152,136,135,119,136,137,154,171,170,186,170,153,136,136,136,137,154,170,187,204,186,169,169,153,152,153,153,171,171,172,204,186,170,169,153,154,154,187,188,203,188,187,170,169,153,153,154,154,170,187,160,0,0,0,155,187,170,170,169,170,170,187,188,221,203,220,187,186,170,170,170,171,187,205,221,204,187,170,169,153,153,154,170,188,205,219,187,170,153,136,136,136,153,154,188,204,171,170,153,136,136,136,136,137,154,171,186,170,153,136,119,119,119,120,137,154,187,170,153,136,119,119,102,119,120,137,171,170,169,152,119,102,102,102,103,120,153,170,170,152,135,118,102,102,102,119,136,154,169,169,136,118,102,85,86,102,120,137,170,170,152,135,102,101,85,102,103,136,154,169,169,136,118,102,85,86,102,120,137,170,170,153,135,118,102,102,102,119,136,154,170,185,152,119,102,102,102,103,120,153,170,170,169,136,119,118,102,119,120,137,154,170,186,169,136,119,119,119,120,137,154,186,188,186,153,136,136,136,136,137,154,171,172,203,186,153,152,136,136,137,154,171,187,220,203,186,169,153,153,153,170,171,188,205,221,203,186,170,170,170,170,187,188,219,189,204,187,170,170,170,154,170,187,188,144,0,0,0,189,220,221,204,204,205,222,237,255,255,207,255,238,221,220,205,205,222,255,255,255,255,237,220,203,187,187,188,205,239,255,255,254,220,187,170,169,170,171,205,239,255,221,204,186,153,136,136,153,171,205,239,253,220,186,153,136,119,120,137,171,206,254,221,202,152,135,118,102,119,137,171,223,253,203,169,135,102,85,86,119,154,188,238,220,186,151,118,85,85,86,120,154,205,237,203,152,118,85,68,85,103,137,172,221,220,185,135,101,84,68,86,120,154,188,221,203,168,118,85,68,85,103,137,171,205,221,186,152,118,85,85,102,120,154,205,222,220,169,135,118,102,102,120,154,188,221,253,219,169,135,119,119,120,153,172,205,223,253,203,169,136,136,136,153,171,205,239,255,253,203,170,153,153,154,171,205,239,223,254,237,203,186,170,171,188,204,222,255,255,255,253,220,188,203,204,205,222,255,239,255,255,254,238,221,222,222,239,255,255,223,255,255,238,237,221,238,223,238,254,176,0,0,0,189,220,204,204,203,204,204,239,255,223,205,255,205,204,204,204,189,223,255,255,255,253,220,187,187,171,186,188,220,223,255,253,220,203,170,169,153,154,187,188,255,255,204,219,169,153,136,136,137,171,204,223,252,220,169,152,135,119,120,137,171,205,255,188,186,152,119,102,102,119,137,171,207,252,187,169,135,102,85,86,119,137,171,207,204,169,135,102,85,85,86,120,154,189,252,187,152,118,85,68,85,103,137,171,205,203,169,135,101,84,69,86,120,154,189,220,203,168,118,85,85,85,103,137,171,205,236,186,135,118,85,85,102,120,154,189,205,203,169,135,102,102,102,119,137,171,204,221,219,153,135,119,119,119,137,171,188,207,253,187,169,136,136,136,137,155,204,252,255,221,186,154,153,153,153,170,188,253,223,253,253,203,170,170,170,170,188,207,253,255,255,220,203,187,187,187,205,221,223,223,255,255,253,253,204,204,252,205,254,254,223,255,253,221,252,220,221,204,206,253,176,0,0,0,207,221,220,204,204,205,221,239,255,255,253,254,221,204,204,204,204,206,255,255,255,239,221,203,187,170,170,187,204,223,255,253,237,203,170,169,153,153,170,188,223,255,221,203,170,153,136,136,137,154,189,239,252,219,186,152,135,119,119,136,154,189,255,204,186,152,119,102,102,103,137,171,205,252,203,169,135,102,85,86,103,137,171,223,204,169,135,102,85,85,86,120,154,189,220,202,152,118,85,85,85,102,120,171,205,204,169,135,101,85,69,86,103,138,189,220,202,152,118,85,85,85,103,121,171,205,220,185,135,102,85,85,102,120,154,189,222,219,169,135,102,102,102,119,137,172,205,253,203,152,135,118,103,119,137,171,205,223,253,186,153,136,119,120,137,170,188,221,255,253,186,169,153,137,153,170,188,221,239,255,237,203,170,170,170,171,188,221,255,255,255,237,203,187,187,187,204,221,239,239,255,255,254,221,204,204,221,238,255,254,255,255,255,253,237,221,221,221,237,238,192,0,0,0,174,205,204,236,205,204,205,239,255,255,221,253,220,220,205,204,221,237,223,255,255,207,223,204,187,187,187,188,204,223,255,253,253,203,187,170,153,169,171,205,255,255,222,203,186,153,136,136,137,170,205,255,253,220,170,152,135,119,119,136,154,189,253,204,186,153,135,102,102,103,136,172,207,236,203,169,135,102,85,86,103,137,172,221,221,186,151,102,85,85,86,120,154,188,220,203,152,118,85,84,85,103,121,171,221,220,185,135,101,84,69,86,119,154,188,221,203,152,118,85,85,85,103,137,172,189,220,185,151,102,85,85,102,120,154,205,205,219,169,135,102,102,102,120,153,172,220,254,202,152,135,118,103,120,153,172,205,205,237,186,153,136,120,136,153,171,205,220,255,252,186,169,153,137,153,171,188,221,207,255,253,187,170,170,170,171,203,205,220,255,255,221,204,187,187,188,204,221,255,223,255,255,238,222,220,205,223,238,255,253,223,255,238,220,221,204,204,204,204,253,176,0,0,0,174,237,222,221,221,222,223,255,255,255,205,254,255,238,221,221,206,255,255,255,255,239,238,220,203,203,187,204,222,239,255,253,254,220,203,170,170,170,188,205,239,255,223,220,187,169,153,153,154,171,223,255,253,221,186,169,136,119,120,137,171,222,255,221,219,169,135,118,102,119,137,188,254,253,219,185,135,102,85,86,119,154,189,255,221,202,152,102,85,85,86,120,155,206,253,235,169,118,85,68,69,103,137,189,255,221,186,151,101,84,68,86,120,155,205,237,219,169,118,85,68,85,103,137,188,253,237,203,152,118,85,85,102,120,171,223,253,236,185,135,102,102,102,120,154,188,237,223,252,169,135,119,119,120,154,172,222,239,255,203,169,136,136,136,154,187,206,254,255,254,203,186,153,153,170,171,205,239,239,255,237,220,203,187,187,188,205,238,255,255,255,254,220,204,204,204,221,223,255,255,255,255,255,239,222,222,239,255,255,255,191,255,255,221,237,205,221,204,221,222,176,0,0,0,172,187,187,170,170,170,171,187,204,222,172,220,203,187,186,170,170,187,205,221,254,204,203,186,170,153,153,170,171,188,222,219,203,170,169,153,136,137,153,171,188,237,187,186,153,136,136,136,136,153,171,204,203,186,169,136,119,119,119,120,153,171,204,171,169,136,119,102,102,119,120,153,188,186,170,152,119,102,102,102,103,136,154,187,170,152,135,102,85,85,102,119,137,171,186,169,136,118,101,85,85,103,120,154,187,170,152,135,102,85,85,86,119,137,171,186,169,136,118,101,85,86,103,120,154,187,187,169,135,102,101,86,102,119,137,171,187,186,152,119,102,102,102,119,137,154,187,187,169,152,119,119,103,119,136,154,187,188,203,169,152,135,119,119,136,153,171,203,204,203,169,152,136,136,137,154,171,188,189,220,187,170,153,153,153,154,171,188,204,238,220,203,170,170,170,170,187,188,205,205,253,220,203,187,187,187,187,204,221,236,189,221,204,203,187,187,187,187,203,204,160,0,0,0,138,169,153,153,152,153,153,154,171,188,170,187,186,169,153,153,153,154,187,205,220,171,186,169], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+969880);
/* memory initializer */ allocate([153,153,136,153,154,170,188,201,170,169,152,136,136,136,137,153,171,203,171,169,152,136,119,119,120,136,153,171,185,169,136,135,119,119,119,119,136,154,170,154,152,135,119,118,102,119,120,137,170,169,153,136,119,102,102,102,119,120,137,169,153,152,135,102,102,102,102,119,136,154,153,153,135,118,102,102,102,103,120,137,153,137,136,119,102,102,102,102,119,120,154,153,152,135,118,102,102,102,103,120,137,153,153,152,135,118,102,102,102,119,136,153,153,169,136,119,118,102,102,119,120,137,169,154,153,135,119,119,103,119,120,137,154,154,170,153,136,119,119,119,120,137,154,186,171,169,152,136,136,136,136,153,153,171,171,187,170,153,136,136,136,137,153,170,186,188,187,170,153,153,153,153,154,170,171,173,221,187,170,169,169,154,170,171,187,219,172,203,170,169,153,153,153,154,170,171,144,0,0,0,155,170,170,153,153,153,154,170,187,204,186,203,187,170,170,169,170,170,187,204,220,171,187,170,153,153,153,153,170,171,204,202,186,169,153,136,136,136,137,154,171,203,171,169,152,136,119,119,136,137,154,187,186,170,152,136,119,119,119,120,137,154,187,154,153,136,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,120,153,170,154,152,135,102,102,102,102,119,136,154,169,153,135,118,102,85,102,102,120,137,170,154,152,119,102,101,85,102,119,136,154,169,169,135,118,102,86,102,103,120,137,170,170,152,119,102,102,102,102,119,137,154,170,169,136,119,102,102,102,119,136,154,170,170,169,136,119,119,103,119,136,137,171,171,186,153,136,119,119,119,136,137,170,186,187,170,153,136,136,136,136,153,154,171,171,203,170,153,152,136,137,153,154,171,187,204,203,186,169,153,153,154,170,171,188,189,220,203,187,170,170,170,170,187,188,219,188,203,187,170,170,154,170,170,170,187,144,0,0,0,171,186,170,169,153,154,170,170,188,189,187,204,187,186,170,169,169,170,187,205,221,188,186,170,153,153,153,153,170,171,189,203,187,169,153,136,136,136,137,154,171,204,171,170,153,136,119,119,136,137,154,171,186,170,152,136,119,119,119,120,137,154,187,170,153,135,119,102,102,103,120,137,171,170,169,136,119,102,102,102,103,120,153,170,154,152,119,102,102,102,102,119,136,154,170,153,135,118,102,85,86,102,120,137,170,153,152,119,102,101,86,102,103,136,154,169,169,135,118,102,101,102,103,120,153,170,154,152,119,118,102,102,102,119,136,154,170,169,136,119,102,102,102,119,136,154,170,170,169,136,119,118,103,119,120,153,171,171,186,153,136,119,119,119,136,153,170,187,188,186,153,136,136,136,136,137,170,187,188,204,170,153,152,136,137,153,154,187,203,205,203,170,169,153,153,153,170,171,204,189,220,203,187,170,170,170,187,187,204,219,173,203,187,186,170,170,170,170,187,188,160,0,0,0,172,187,186,170,170,170,171,187,205,222,188,220,203,187,170,170,170,187,204,221,253,188,203,186,169,153,153,170,171,188,206,219,187,170,153,152,136,137,153,171,188,221,187,186,153,136,136,136,136,153,171,188,203,186,153,136,119,119,119,136,137,171,204,171,169,136,119,102,102,119,120,154,171,186,169,152,119,102,102,102,103,136,154,187,170,153,135,102,101,85,102,119,137,171,186,169,136,118,101,85,85,103,120,153,187,170,152,119,102,85,85,86,119,137,171,186,169,136,118,101,85,86,103,120,154,187,170,153,135,118,101,86,102,119,137,171,187,186,152,119,102,102,102,119,137,154,187,187,170,152,119,118,103,119,136,154,171,187,203,169,152,135,119,119,136,153,171,187,204,186,169,152,136,136,137,153,170,188,188,204,187,170,153,153,153,154,171,188,220,221,220,187,170,170,170,170,171,188,205,206,253,220,203,187,171,187,187,204,205,220,189,220,204,187,187,170,171,187,188,204,160,0,0,0,190,237,221,221,221,221,221,239,255,255,190,255,237,221,205,221,222,255,255,255,255,239,237,220,204,188,188,221,222,255,255,253,221,220,187,170,170,187,204,222,255,255,222,220,186,169,153,153,154,188,222,255,253,220,186,153,136,136,136,154,188,223,255,221,203,169,135,118,103,120,154,189,255,253,220,169,135,102,85,102,120,155,205,254,221,186,152,118,84,69,86,137,171,238,253,219,169,118,84,68,69,103,154,189,238,221,186,152,101,68,68,86,120,171,222,237,236,169,135,85,68,69,103,154,188,237,237,203,152,118,85,85,103,137,171,206,238,253,186,152,118,102,103,120,154,189,238,255,220,186,152,135,119,136,154,188,222,239,254,220,186,153,136,153,154,187,205,254,239,254,220,186,170,170,170,187,205,223,239,255,254,220,204,203,187,188,205,223,255,255,255,255,237,221,204,205,221,222,255,255,255,255,255,255,222,237,238,239,255,255,190,255,255,238,238,222,237,221,238,254,176,0,0,0,172,220,204,204,204,204,221,223,254,255,188,237,221,204,204,204,204,222,255,255,255,205,220,204,187,171,171,188,205,239,255,252,220,203,170,169,153,154,171,204,255,254,205,203,170,153,136,136,153,171,205,239,252,203,186,152,135,119,119,137,171,206,254,204,186,152,119,102,102,119,137,171,222,220,203,169,135,102,85,86,119,138,188,222,204,185,135,102,85,85,86,120,155,205,220,186,152,118,85,68,69,103,137,172,221,204,185,135,101,84,69,86,120,154,205,221,203,152,118,85,85,85,103,137,172,205,204,186,152,118,85,85,102,120,154,204,205,219,169,135,102,102,102,120,154,188,221,221,203,169,135,119,119,120,137,171,221,222,237,187,169,136,136,136,153,171,204,221,255,236,203,170,153,153,154,170,188,221,223,255,254,203,186,170,170,187,204,237,221,255,255,238,204,203,187,204,204,221,238,223,255,255,254,237,220,205,205,221,222,237,207,255,254,238,221,221,205,204,221,221,176,0,0,0,205,221,220,204,204,204,205,222,255,255,221,237,220,204,203,187,204,205,238,255,255,222,221,203,187,170,170,187,205,223,255,253,220,187,170,153,153,153,171,188,222,255,205,203,169,152,136,136,137,170,188,239,252,203,169,152,119,119,119,137,155,205,238,204,186,152,119,102,102,103,137,171,205,236,202,152,135,102,85,86,103,137,172,222,203,169,135,102,85,85,86,120,154,205,220,186,152,118,85,84,85,103,137,171,205,204,169,135,101,84,69,86,120,154,188,220,202,152,118,85,85,85,103,137,171,204,204,186,135,102,85,85,102,120,154,188,221,203,169,135,102,102,102,120,153,171,221,221,202,169,135,119,119,120,137,171,205,222,220,186,169,136,136,136,137,170,188,221,238,220,187,169,153,153,153,170,188,222,223,255,221,203,186,170,170,171,188,221,253,255,255,237,204,187,187,187,204,221,239,223,255,254,237,221,204,204,205,222,239,254,207,255,255,222,221,221,205,221,222,238,192,0,0,0,190,221,204,204,204,205,223,238,255,255,205,222,204,204,204,204,205,222,255,255,255,221,204,187,187,187,187,187,205,223,255,253,220,203,186,169,153,170,171,205,255,255,204,187,169,152,136,136,153,171,207,255,252,203,169,152,119,119,119,137,171,206,255,205,186,152,119,102,102,119,137,171,221,252,203,152,135,101,85,86,119,138,189,255,204,185,135,101,85,85,86,120,154,205,237,203,152,118,85,68,85,103,137,171,221,204,185,135,101,84,69,86,120,154,189,221,203,168,118,85,85,85,103,137,171,205,237,186,152,118,85,85,102,120,154,189,205,252,185,135,118,102,102,120,153,171,253,255,203,169,135,119,119,120,137,171,205,223,253,187,169,152,136,136,137,171,204,221,255,222,204,170,153,153,153,170,188,221,207,255,221,203,187,186,170,187,188,205,237,255,255,221,221,204,187,204,204,205,221,223,255,255,254,237,220,205,237,222,223,238,191,255,255,254,237,220,221,204,204,221,176,0,0,0,189,221,220,204,220,205,221,222,255,239,190,238,221,220,204,205,221,222,255,255,254,222,221,203,187,187,187,204,222,239,255,253,221,203,186,170,170,171,188,206,255,254,205,219,186,153,152,153,154,172,221,255,253,220,186,153,135,119,120,153,188,222,238,220,186,152,135,118,102,120,154,188,223,252,219,169,135,102,85,102,120,154,189,254,204,186,152,102,85,69,86,120,171,206,221,203,168,118,85,68,69,103,138,188,222,221,186,135,101,68,68,86,120,155,205,221,219,169,134,85,68,85,103,137,188,222,221,203,152,118,85,85,103,137,171,205,222,252,186,152,118,102,103,120,154,188,221,255,220,170,152,119,119,136,153,171,205,222,254,219,186,152,136,137,154,171,205,222,239,238,204,186,169,153,154,171,204,237,239,255,253,220,187,187,187,187,205,222,239,255,255,254,221,205,204,204,204,222,239,239,255,255,254,237,221,221,221,238,255,254,191,238,238,254,237,221,221,221,222,238,192,0,0,0,156,203,187,186,186,187,187,204,205,222,172,221,204,187,187,187,187,188,205,239,254,205,203,187,170,170,170,170,187,205,239,219,203,186,169,153,153,153,154,187,205,237,188,186,169,136,136,136,137,154,187,205,219,186,169,136,119,119,119,136,154,188,220,187,169,152,119,102,102,119,137,154,188,203,186,152,119,102,85,102,119,137,171,204,187,169,135,102,85,85,102,120,154,188,187,186,152,118,85,84,85,103,136,154,187,187,169,135,101,84,69,86,120,137,171,187,186,152,118,101,85,85,103,136,170,187,187,169,135,118,101,85,102,120,154,188,187,186,169,135,118,102,102,119,137,171,203,204,186,152,135,119,119,120,137,154,188,188,203,186,153,136,136,136,137,154,187,204,205,203,170,153,152,137,153,154,187,205,204,221,203,186,170,169,154,170,188,204,220,222,237,204,187,186,170,171,187,204,205,205,254,237,220,204,187,203,204,205,221,236,173,221,204,204,187,187,187,203,204,204,160,0,0,0,155,186,170,169,169,154,170,171,187,204,171,220,187,170,170,170,170,171,187,205,237,187,187,170,153,153,153,153,170,187,205,202,187,169,153,136,136,136,153,154,187,220,171,170,152,136,119,119,136,137,154,187,186,170,152,136,119,119,119,120,137,171,187,170,153,135,119,102,102,103,120,137,171,186,169,136,119,102,102,102,103,120,154,187,154,152,135,102,101,86,102,119,137,154,169,169,135,118,101,85,86,103,120,153,170,170,152,119,102,85,85,102,119,137,154,170,169,135,118,102,85,102,103,120,153,170,170,152,135,118,102,102,102,120,137,171,170,169,152,119,102,102,102,119,136,154,186,170,169,136,119,119,119,119,136,153,171,187,186,153,136,119,119,119,136,153,171,187,188,186,153,152,136,136,136,153,170,188,188,203,186,169,153,153,153,153,170,187,203,205,203,187,170,169,153,170,170,187,204,205,236,220,187,187,170,170,187,188,205,220,173,204,203,186,170,170,170,171,187,188,160,0,0,0,171,186,170,153,153,153,153,170,187,204,171,203,186,170,169,153,154,170,187,204,220,188,186,169,153,153,137,153,154,171,204,202,186,169,152,136,136,136,137,154,171,203,170,169,152,136,119,119,120,137,154,187,186,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,103,120,137,171,169,169,136,119,102,102,102,103,120,153,170,153,152,119,102,102,102,102,119,136,154,169,153,135,118,102,85,86,103,120,137,170,153,136,119,102,101,86,102,119,136,154,169,153,135,118,102,102,102,103,120,137,170,154,152,119,102,102,102,102,119,137,154,169,169,136,119,102,102,102,119,136,153,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,137,170,186,187,170,153,136,136,136,136,153,154,187,187,203,170,153,152,136,137,153,170,171,203,188,203,186,169,153,153,153,170,187,205,188,220,203,186,170,170,170,170,187,204,220,172,203,186,170,170,170,170,170,187,204,160,0,0,0,155,186,170,169,153,153,154,170,187,204,171,204,186,170,170,170,170,170,187,204,221,171,186,170,153,153,153,153,170,171,205,202,186,169,152,136,136,136,153,154,187,203,171,169,152,136,119,119,136,137,154,188,186,186,152,136,119,119,119,120,137,154,187,154,153,135,119,102,102,119,120,137,171,169,169,136,119,102,102,102,103,136,154,170,154,152,119,102,102,86,102,119,137,170,169,169,135,118,101,85,86,103,120,154,170,153,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,137,170,154,152,135,118,102,102,103,119,137,170,170,169,136,119,102,102,103,119,136,154,170,170,169,136,119,119,119,119,136,153,171,171,170,153,136,119,119,119,136,137,170,186,187,170,153,136,136,136,136,153,170,172,187,203,170,169,153,153,153,153,170,187,203,189,203,186,170,153,153,154,170,171,205,205,220,203,187,170,170,170,187,187,204,220,172,204,187,170,170,170,170,170,171,204,160,0,0,0,155,187,170,170,170,170,171,187,188,204,155,204,203,187,170,170,171,187,205,221,237,188,203,186,170,153,154,170,187,204,221,203,203,170,153,153,137,153,154,171,204,220,187,186,153,136,136,136,136,154,171,205,202,186,153,136,119,119,119,136,154,187,204,171,169,136,119,102,102,119,136,154,188,186,170,152,119,102,85,102,119,137,171,187,170,153,135,102,85,85,102,120,154,171,186,169,152,118,85,85,85,103,136,154,187,170,153,135,101,84,69,86,120,137,171,186,186,152,118,101,85,86,103,136,154,187,171,169,135,118,101,86,102,120,153,171,187,186,153,135,118,102,102,119,137,170,187,188,186,152,135,119,119,119,137,154,171,187,203,170,152,136,136,136,137,154,171,203,204,203,170,153,152,136,153,154,171,188,188,220,203,170,169,153,153,170,171,188,220,206,220,203,187,170,170,170,187,188,205,205,237,221,204,203,187,187,187,204,205,236,173,204,204,187,187,187,187,187,187,204,160,0,0,0,206,254,237,221,221,221,221,222,238,238,191,255,254,253,221,221,222,238,255,255,254,255,254,237,204,203,204,204,222,239,255,238,255,236,203,186,170,171,188,221,255,254,239,237,203,170,153,153,170,188,222,255,238,253,203,169,136,136,137,154,188,222,255,222,203,169,135,118,119,120,154,189,239,237,236,185,135,102,85,102,121,171,206,254,221,202,152,118,84,69,103,137,172,222,237,219,169,134,84,67,69,104,154,205,238,221,186,152,117,67,52,86,121,171,222,237,220,185,135,101,68,85,120,154,205,238,221,203,169,118,101,85,103,137,188,223,237,237,186,152,119,102,119,137,171,205,254,222,236,186,153,136,120,137,171,189,239,237,254,220,186,169,153,153,171,188,223,254,239,254,220,187,186,170,187,205,222,239,253,254,238,221,204,204,204,221,222,255,255,239,255,238,238,221,221,221,238,239,255,254,255,255,255,238,254,238,239,255,255,255,174,238,238,238,221,222,239,254,238,255,192,0,0,0,190,220,220,204,203,203,204,204,221,205,173,237,221,204,204,204,188,205,206,239,254,238,220,203,187,186,171,187,204,222,223,220,220,203,170,153,153,154,171,205,222,253,205,203,169,153,136,136,153,170,188,239,220,219,170,152,119,119,119,137,171,205,221,204,186,152,119,102,102,119,137,171,222,220,203,152,119,101,85,86,119,137,188,221,204,169,135,101,85,85,86,120,155,188,219,202,152,118,85,68,85,103,137,172,221,203,169,135,101,84,69,86,120,154,188,220,186,152,118,101,85,85,103,137,172,221,204,186,136,118,85,85,102,120,154,189,204,203,169,135,118,102,102,120,154,188,220,205,203,169,135,119,119,120,137,172,206,220,221,202,169,136,136,136,153,171,205,237,221,220,203,170,153,153,154,172,205,238,221,239,220,203,186,170,170,187,204,237,253,238,238,221,220,203,187,188,205,222,239,237,255,237,237,221,220,205,221,238,239,254,173,237,221,221,205,220,221,222,237,237,176,0,0,0,205,221,204,204,187,188,204,205,222,239,206,254,221,204,187,187,187,204,222,255,255,222,220,203,186,170,170,171,188,206,255,237,220,187,170,153,153,153,170,188,222,254,221,203,169,152,136,136,136,154,188,222,236,203,169,136,119,119,119,136,154,188,222,204,185,152,119,102,102,103,136,155,205,220,186,152,118,101,85,86,103,137,171,221,187,169,135,101,85,85,86,120,154,188,219,186,152,118,85,85,85,103,120,171,204,203,169,135,101,85,85,86,119,138,188,204,186,152,118,85,85,85,103,137,171,204,203,169,135,102,85,85,102,120,154,188,220,203,169,135,102,102,102,120,137,172,221,221,186,152,135,119,119,120,137,171,205,221,220,186,153,136,119,136,137,171,189,221,222,220,186,153,152,137,153,171,188,222,237,253,220,187,170,170,170,171,204,222,254,239,238,220,203,187,187,188,205,222,255,254,255,238,221,220,204,204,221,238,239,255,207,238,237,221,221,204,205,221,223,238,192,0,0,0,189,204,204,187,187,188,188,204,204,221,172,221,221,204,204,188,188,204,221,223,253,222,236,203,187,170,170,187,204,205,222,204,221,203,170,169,153,154,171,204,221,237,205,187,170,153,136,136,153,170,188,221,219,203,170,152,135,119,120,137,171,204,237,188,186,152,119,102,103,119,137,171,205,203,203,169,135,102,85,102,120,154,188,220,188,169,135,102,85,85,102,120,154,188,203,202,152,118,85,68,69,103,137,171,204,187,185,135,101,68,68,86,120,154,188,203,202,168,118,101,68,86,103,137,171,204,204,186,152,118,101,86,103,120,154,189,204,203,169,135,118,102,103,120,154,188,220,205,187,169,136,119,119,120,154,171,205,204,220,187,169,152,136,136,153,171,205,220,205,220,187,170,153,153,154,171,188,205,204,237,220,203,187,170,170,187,204,221,221,222,221,221,204,187,187,204,204,205,223,221,255,237,221,220,204,205,221,238,238,253,173,220,220,204,204,188,204,204,220,222,176,0,0,0,174,237,221,221,221,220,221,221,221,221,158,255,255,237,237,221,238,239,254,255,253,223,238,221,221,221,221,221,239,254,255,237,254,221,204,203,188,204,222,238,238,254,223,221,203,186,170,171,188,221,223,239,237,237,219,186,153,136,153,171,205,239,253,222,220,186,152,119,119,137,171,221,255,221,237,186,152,118,85,103,137,188,221,254,222,203,169,118,84,69,103,154,205,239,237,237,202,135,84,51,69,120,171,206,237,222,219,168,117,67,36,87,138,188,222,237,237,202,151,101,68,70,120,172,205,237,222,221,186,135,101,86,104,154,189,239,221,254,220,169,135,119,120,138,188,222,238,239,253,219,170,152,136,154,171,205,255,221,254,237,203,186,170,170,187,205,223,254,223,254,237,220,203,187,188,204,222,255,238,255,255,254,221,205,221,221,239,239,254,255,255,254,254,238,237,238,238,255,255,239,255,255,255,239,254,239,254,255,255,254,173,221,221,221,237,222,222,238,221,238,176,0,0,0,189,220,203,187,170,171,187,188,205,205,173,237,204,187,170,186,171,188,205,223,253,221,204,187,170,169,154,170,187,205,238,220,219,186,169,153,153,153,154,171,205,221,188,186,169,136,136,136,137,154,187,205,203,186,169,136,119,119,119,136,154,187,204,187,169,136,119,102,102,119,137,154,188,203,186,152,119,102,85,102,119,137,171,204,187,169,135,102,85,85,102,120,154,172,202,169,152,118,85,68,85,103,136,154,187,171,169,135,101,84,69,86,120,153,171,187,186,152,118,101,85,86,103,137,154,187,187,169,135,118,101,85,103,120,154,172,187,186,152,135,118,102,103,120,137,171,204,188,186,152,135,119,119,120,137,154,188,204,203,170,153,136,136,136,137,154,187,204,205,203,170,153,152,153,153,170,188,205,204,221,203,186,170,153,154,170,187,205,221,206,221,204,187,186,170,187,188,205,238,221,253,237,204,204,188,188,204,221,238,254,157,221,204,204,187,187,188,204,221,238,176,0,0,0,155,186,170,170,153,153,170,170,187,204,155,220,187,170,170,170,170,171,188,204,220,187,187,170,153,153,153,154,170,187,205,202,187,169,153,136,136,136,153,170,188,220,171,169,152,136,119,120,136,137,170,188,186,186,152,135,119,119,119,120,153,171,187,154,153,135,119,102,102,119,120,154,171,186,169,136,119,102,102,102,119,136,154,186,154,152,119,102,101,86,102,119,137,171,170,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,69,102,119,137,171,169,169,135,118,102,85,86,103,120,154,170,170,152,135,118,102,102,102,119,137,171,170,169,152,119,118,102,102,119,137,154,186,171,169,152,119,119,119,119,136,154,171,187,186,169,136,135,119,120,136,153,171,187,187,186,169,152,136,136,136,153,171,188,187,204,186,169,153,153,153,153,170,188,204,204,204,187,170,170,170,170,171,188,205,204,221,220,203,187,170,171,187,188,204,221,156,203,187,186,170,170,170,187,187,204,160,0,0,0,155,170,169,153,153,153,153,170,171,188,171,203,186,170,153,153,153,170,171,204,204,171,186,169,153,136,137,153,154,171,188,186,186,169,152,136,136,136,137,154,171,203,170,169,152,135,119,119,120,137,154,171,185,169,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,103,120,137,170,169,153,135,119,102,102,102,119,120,153,170,153,152,119,102,102,102,102,119,136,154,169,152,135,118,102,85,102,103,120,137,170,153,136,119,102,101,86,102,119,136,154,169,153,135,118,102,102,102,103,120,137,170,153,152,119,102,102,102,102,119,137,154,169,169,136,119,102,102,102,119,136,154,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,137,170,186,171,170,153,136,136,136,136,153,170,187,187,187,170,153,152,136,137,153,170,187,203,188,203,170,169,153,153,154,170,187,204,188,220,203,186,170,170,170,171,187,204,220,172,187,186,170,170,154,170,170,187,188,160,0,0,0,155,186,169,169,153,153,153,170,171,187,155,204,187,170,169,153,170,170,187,188,220,188,186,170,153,153,153,153,170,171,204,186,186,169,153,136,136,136,137,154,171,203,171,169,152,136,119,119,136,137,154,187,186,170,152,135,119,119,119,120,137,154,186,154,152,135,119,102,102,119,120,137,171,169,169,136,119,102,102,102,119,136,154,170,154,152,119,102,102,86,102,119,137,154,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,153,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,103,120,137,170,169,169,136,119,102,102,103,119,136,154,170,170,169,136,119,119,119,119,136,153,171,186,186,153,136,135,119,119,136,153,170,187,171,170,153,136,136,136,136,153,170,187,187,203,186,169,153,153,153,153,170,187,203,188,203,170,170,153,153,170,170,187,204,187,204,203,187,170,170,170,171,188,204,220,156,187,186,170,170,170,170,170,187,188,160,0,0,0,173,204,204,204,203,187,188,188,204,220,157,237,237,204,204,204,204,205,221,238,237,223,221,204,187,187,187,187,205,221,238,220,221,203,186,170,170,170,187,204,222,236,204,203,186,153,153,153,154,171,204,222,204,204,186,153,136,136,136,154,171,205,220,204,186,153,135,119,119,136,154,187,205,204,203,169,135,102,86,103,136,170,188,220,188,186,152,118,84,69,103,137,171,205,203,203,169,135,84,51,69,120,154,188,220,188,186,152,118,67,52,86,137,171,205,204,203,169,135,101,68,86,120,154,188,204,205,186,153,135,101,86,103,137,171,205,204,204,186,152,135,118,119,136,154,188,220,205,204,170,152,136,136,136,154,187,205,220,220,187,170,153,153,153,154,171,205,220,206,221,203,186,170,170,170,187,205,222,221,221,221,204,187,187,187,188,205,221,237,223,238,221,220,203,204,204,204,238,239,221,238,238,237,221,205,205,222,238,238,254,157,205,205,204,204,204,204,221,221,222,176,0,0,0,207,255,254,255,238,222,222,239,238,238,175,255,255,254,238,237,239,239,255,255,255,255,255,254,221,205,204,222,239,255,255,239,255,238,220,187,187,187,205,222,255,255,255,253,203,186,153,154,171,205,254,255,255,254,203,169,152,136,137,155,205,239,254,255,220,185,135,118,119,120,171,205,239,254,237,186,151,102,85,103,121,171,222,255,239,203,152,118,84,69,103,137,188,239,254,236,185,134,84,51,69,104,155,206,255,254,203,152,117,67,52,86,137,188,239,254,237,185,135,101,68,85,120,155,206,255,255,219,169,135,101,85,103,138,189,255,255,237,203,152,135,102,119,137,172,239,255,255,237,203,153,136,136,137,171,206,239,254,255,221,203,169,153,154,171,205,255,255,255,255,237,203,187,187,188,221,239,255,255,255,255,238,220,204,204,221,255,255,255,239,255,255,238,238,222,222,255,255,255,255,255,255,255,255,239,255,255,255,255,255,159,255,255,238,254,239,255,255,255,255,192,0,0,0,206,221,221,204,204,204,204,205,221,221,158,238,221,204,204,187,188,205,222,255,254,239,221,204,186,170,170,187,204,222,255,221,236,203,170,153,153,154,171,204,222,237,221,203,170,152,136,136,137,171,188,223,236,219,169,152,119,119,119,137,171,205,237,204,186,152,119,102,102,119,137,171,206,236,202,152,119,101,85,102,119,138,188,221,204,169,135,101,85,85,86,120,154,205,220,186,152,118,85,68,85,103,137,172,221,187,169,135,101,84,69,86,120,154,189,220,202,152,118,85,85,85,103,137,172,221,204,186,136,118,85,85,102,120,155,205,220,219,169,135,118,102,102,120,154,188,221,221,203,169,135,119,119,120,137,188,222,237,237,202,169,136,136,136,153,171,205,221,222,220,203,169,153,153,154,171,204,222,253,254,220,187,187,170,170,188,204,222,254,223,238,221,220,204,204,204,205,238,255,237,254,254,237,221,205,221,222,254,255,255,174,238,237,221,221,221,221,238,254,239,208,0,0,0,222,221,220,204,187,187,204,205,222,238,190,238,221,204,187,187,187,205,222,239,254,222,220,203,186,170,170,171,188,221,239,237,220,203,170,153,153,153,170,188,222,238,220,203,169,152,136,136,137,154,188,222,236,203,169,136,119,119,119,137,154,188,221,204,186,152,118,102,102,103,137,171,205,220,186,152,118,101,85,86,103,137,171,221,203,169,135,101,85,85,86,120,154,188,219,186,152,118,85,85,85,103,137,171,220,203,169,135,101,85,69,86,120,154,188,204,186,152,118,85,85,85,103,137,171,205,204,169,135,102,85,85,102,120,154,189,220,203,169,135,102,102,102,120,153,172,221,220,186,153,135,119,119,120,137,171,205,221,220,186,153,136,136,136,153,171,205,238,222,220,186,169,153,153,153,171,188,222,238,237,220,187,170,170,170,171,188,222,254,223,238,220,203,187,187,188,204,222,255,254,255,238,237,220,204,204,221,238,255,255,191,238,221,221,220,221,221,222,239,255,224,0,0,0,223,238,221,221,204,221,205,222,239,254,175,255,253,220,204,204,204,237,238,255,255,255,221,204,187,170,187,187,205,238,255,254,237,203,170,169,153,154,171,205,238,254,221,203,169,152,136,136,153,171,205,239,237,220,170,152,119,119,119,137,171,205,253,221,186,152,119,102,102,119,137,171,207,236,203,168,119,101,85,86,119,138,188,222,204,169,135,101,85,85,86,120,154,206,220,202,152,118,85,68,85,103,137,172,221,204,169,135,101,84,69,86,120,154,205,220,202,152,118,85,85,85,103,137,172,221,220,186,135,118,85,85,102,120,155,205,221,220,169,135,118,102,102,120,154,188,222,222,203,169,135,119,119,120,153,187,205,237,237,203,169,152,136,136,153,171,205,238,238,237,203,170,153,153,154,171,205,239,237,255,221,203,187,170,170,188,205,222,255,239,255,253,220,203,188,204,221,239,255,254,255,255,238,221,221,221,222,255,255,255,174,238,237,237,221,221,222,238,239,255,208,0,0,0,223,255,255,238,254,222,238,255,222,255,159,255,255,255,221,222,239,255,255,255,255,255,255,254,220,204,204,221,239,255,255,255,255,236,203,186,170,171,205,239,255,255,255,253,203,169,153,153,154,188,223,255,255,253,203,169,135,119,136,154,189,255,255,239,219,169,135,102,102,120,154,205,255,255,252,185,135,101,85,102,120,155,206,255,238,202,152,101,84,69,86,137,172,223,254,220,169,118,84,68,69,103,154,205,255,237,202,151,101,68,68,86,121,172,223,254,220,169,134,101,68,85,103,154,205,255,238,203,152,118,85,85,103,137,172,255,255,253,202,152,118,102,103,136,171,206,255,255,252,186,152,135,119,137,155,205,255,254,255,220,186,153,152,153,171,205,255,255,255,255,237,203,186,170,171,205,239,255,255,255,255,221,204,204,204,206,255,255,255,255,255,255,254,237,221,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,238,222,254,255,255,255,255,208,0,0,0,190,238,221,221,204,204,221,221,221,237,159,255,254,221,221,205,221,239,238,255,254,239,237,220,204,187,188,204,221,238,255,238,238,220,187,170,170,171,188,221,239,254,221,204,202,169,153,153,154,188,205,239,222,220,186,153,136,136,136,154,188,222,254,222,203,169,135,119,119,120,154,188,222,237,220,169,135,102,85,103,137,171,205,238,221,186,152,118,84,69,103,137,172,223,237,219,169,135,84,51,69,120,154,204,253,220,202,152,117,67,52,86,137,171,206,221,220,169,135,101,68,86,120,154,189,238,221,202,169,119,101,86,103,137,172,222,237,237,202,152,119,118,119,137,171,205,254,238,220,186,152,136,120,137,154,188,222,237,254,204,186,169,153,153,170,188,222,238,239,253,220,187,170,170,171,188,222,255,238,255,237,220,204,187,187,205,221,239,255,239,255,254,237,221,220,221,222,255,255,254,255,255,254,238,238,238,255,255,255,255,158,222,221,222,221,205,221,254,239,255,176,0,0,0,171,186,170,169,153,153,154,170,187,204,139,203,187,170,170,170,170,171,188,205,220,188,187,170,153,153,153,153,170,188,205,202,187,169,153,136,136,136,153,170,187,204,171,169,152,136,119,119,136,137,170,188,186,170,152,135,119,119,119,120,137,171,203,170,153,135,119,102,102,119,120,153,171,185,169,136,119,102,102,102,119,136,154,186,154,152,119,102,101,86,102,119,137,171,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,135,118,101,85,86,103,120,154,186,154,152,135,118,102,102,102,120,137,171,170,169,152,119,118,102,102,119,136,154,186,171,169,136,119,119,119,119,136,153,171,170,186,169,136,135,119,120,136,153,170,187,188,186,169,152,136,136,136,153,170,188,187,203,186,169,153,153,153,154,170,188,203,189,203,187,170,170,170,170,171,188,205,204,221,204,187,186,170,187,187,187,204,220,156,204,187,186,170,170,170,187,187,204,176,0,0,0,171,170,169,153,153,153,153,170,171,188,171,203,186,170,169,153,153,170,187,204,220,187,186,169,153,153,153,153,154,171,204,202,186,169,152,136,136,136,137,154,171,203,170,169,152,135,119,119,120,137,154,187,185,169,152,135,119,119,119,120,137,154,187,154,152,135,118,102,102,103,120,137,171,169,153,135,119,102,102,102,103,120,154,170,153,152,119,102,102,102,102,119,137,154,169,153,135,118,102,85,86,103,120,137,170,153,152,119,102,101,86,102,119,136,154,169,153,135,118,102,102,102,103,120,153,170,154,152,119,102,102,102,102,119,137,170,169,169,136,119,102,102,102,119,136,154,170,170,153,136,119,119,119,119,136,153,171,170,186,153,136,119,119,119,136,153,170,186,171,170,153,136,136,136,136,153,170,188,187,203,170,153,153,136,153,153,170,187,203,188,203,186,170,153,153,170,170,187,204,188,220,203,187,170,170,170,171,187,205,220,156,203,186,170,170,170,170,170,187,188,160,0,0,0,172,187,170,170,153,153,170,170,188,204,156,204,187,170,170,170,170,170,187,221,237,188,186,170,153,153,153,153,170,187,205,203,187,169,153,136,136,136,153,170,188,203,171,169,152,136,119,119,136,137,170,188,186,186,152,135,119,119,119,120,153,171,187,170,153,135,118,102,102,119,120,153,171,186,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,119,137,170,169,153,135,118,101,85,86,103,120,154,170,153,152,119,102,85,85,102,119,137,170,170,169,135,118,102,85,86,103,120,154,170,170,152,135,118,102,102,102,120,137,171,170,169,152,119,118,102,102,119,136,154,187,171,169,152,119,119,119,119,136,154,171,187,186,169,136,135,119,120,136,153,171,203,188,186,169,152,136,136,137,153,170,188,187,203,186,169,153,153,153,153,171,188,204,205,203,186,170,170,170,170,171,188,205,204,237,204,187,187,187,171,187,188,220,221,156,203,187,187,170,170,170,187,188,205,176,0,0,0,188,220,187,187,187,187,187,204,205,222,157,237,204,187,186,171,187,188,221,239,254,221,204,186,170,170,154,170,188,205,223,236,220,170,153,153,137,153,154,187,205,221,204,186,153,136,136,136,137,154,187,205,219,186,169,136,119,119,119,137,154,188,221,187,169,136,118,102,102,119,137,155,188,203,186,152,118,102,85,102,119,137,171,204,187,153,135,102,85,85,102,120,154,188,219,169,136,118,85,68,85,103,137,155,204,187,169,135,102,84,69,86,119,137,172,203,186,152,118,101,85,86,103,136,170,204,187,169,135,118,101,86,102,120,154,188,203,187,153,135,118,102,102,119,137,171,204,204,186,152,135,119,119,120,137,170,188,220,220,170,153,136,136,136,137,154,187,221,205,204,186,153,152,137,153,170,188,205,205,237,203,186,170,153,154,170,188,205,237,223,237,204,187,187,171,187,187,205,222,237,238,221,220,204,187,204,204,221,238,238,157,205,204,204,203,188,204,204,205,221,192,0,0,0,255,255,254,255,253,221,220,237,221,221,159,255,255,255,254,239,255,255,255,255,254,255,255,254,237,221,205,221,239,255,255,255,255,254,205,187,187,188,221,239,255,254,255,255,220,186,170,170,171,205,222,255,239,253,220,186,152,136,137,171,205,239,255,255,237,186,136,119,119,137,171,205,255,255,253,202,152,102,85,103,137,172,223,255,239,203,168,117,68,69,103,138,189,255,255,252,186,135,84,51,69,104,171,223,255,255,219,168,117,67,52,86,138,189,239,255,253,186,135,101,68,69,120,171,223,255,255,236,169,135,101,85,104,154,205,255,255,255,204,169,135,118,119,138,188,255,255,255,254,203,169,152,136,154,188,223,255,255,255,222,203,186,169,170,188,205,255,255,255,255,221,220,187,187,204,222,255,255,254,255,255,254,221,204,220,223,255,255,255,239,255,255,255,237,239,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,141,221,221,254,237,223,255,255,255,255,208,0,0,0,206,221,220,204,204,204,204,204,204,220,157,238,238,220,204,204,204,221,222,238,238,238,237,220,203,187,187,188,205,222,239,221,237,203,187,170,170,170,187,204,222,238,221,203,186,153,153,137,154,171,205,238,220,204,186,153,136,119,136,153,171,205,221,205,186,153,135,102,102,120,154,188,221,220,203,169,135,102,85,102,120,154,188,221,204,186,151,102,84,69,102,121,171,205,220,203,168,118,84,68,69,103,138,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,138,188,221,204,186,152,118,101,85,103,137,171,205,220,220,186,152,118,102,103,136,154,189,237,205,203,169,152,135,119,136,154,188,222,220,221,203,170,153,152,137,154,187,205,238,222,221,203,186,170,170,170,188,221,223,237,237,220,204,187,187,187,188,205,255,254,206,255,221,204,204,204,205,221,239,255,253,254,255,222,221,221,221,222,239,255,254,157,221,221,221,221,221,221,238,239,239,208,0,0,0,206,221,204,204,187,188,204,204,221,221,174,254,221,204,203,187,188,204,222,239,254,222,221,203,186,170,170,187,204,222,238,237,221,203,170,153,153,153,171,188,222,237,205,203,169,152,136,136,137,170,188,222,220,203,169,152,119,119,119,137,171,204,221,204,186,152,119,102,102,119,137,171,205,220,202,152,119,102,85,86,119,137,188,221,203,169,135,101,85,85,86,120,154,189,219,186,152,118,85,68,85,103,137,171,220,187,169,135,101,84,69,86,120,154,188,204,186,152,118,85,85,85,103,137,171,205,204,185,135,118,85,85,103,120,154,189,204,203,169,135,118,102,103,120,154,188,221,205,203,169,135,119,119,120,153,171,205,221,220,186,169,136,136,136,153,171,205,237,222,220,187,169,153,153,154,171,205,222,237,237,220,187,186,170,170,187,204,222,254,223,238,221,204,187,187,188,205,222,255,237,255,238,221,221,204,221,221,238,255,255,174,221,221,221,221,204,221,221,238,239,208,0,0,0,206,237,221,220,204,204,204,221,221,221,159,254,237,221,205,220,204,221,222,239,253,239,222,204,203,187,187,204,205,222,239,221,237,220,187,170,170,170,171,205,239,253,221,219,186,153,152,137,154,171,205,238,221,220,186,152,135,119,120,153,171,205,253,221,203,152,119,102,102,120,154,188,221,220,203,169,135,101,85,86,120,154,189,221,204,186,151,101,84,85,86,121,171,205,220,203,168,118,85,68,85,103,138,188,237,204,186,135,101,84,68,86,120,171,205,220,203,169,118,85,68,85,103,138,188,220,205,202,152,118,85,85,103,137,171,205,220,220,186,152,118,102,103,136,154,204,221,221,204,170,152,119,119,136,154,188,221,220,237,203,169,153,136,137,154,188,206,237,223,220,203,186,169,170,170,188,221,239,237,238,221,204,204,187,187,188,221,238,238,239,254,237,220,220,204,205,221,239,255,254,255,238,253,221,221,221,237,223,255,255,157,221,205,221,221,221,221,222,222,239,208,0,0,0,223,255,254,254,222,205,221,237,221,222,143,255,255,239,237,238,238,255,255,255,255,255,255,254,221,220,221,221,255,255,255,255,255,254,204,187,187,187,205,223,255,255,255,253,204,186,169,154,171,205,239,255,255,254,220,169,136,136,137,170,205,255,255,239,236,185,135,118,119,136,171,206,255,255,253,186,151,102,85,102,137,172,223,255,238,219,168,118,84,69,103,138,189,255,253,221,185,134,84,51,69,104,155,207,255,239,203,152,101,67,52,86,137,188,255,253,237,186,135,101,68,85,120,155,221,254,239,220,169,135,101,85,103,154,189,255,255,253,203,168,135,102,119,137,188,223,255,255,221,187,169,136,136,137,171,207,255,255,255,236,203,170,169,154,187,221,255,255,255,253,237,203,187,187,204,205,255,255,255,255,255,237,220,205,205,221,255,255,255,255,255,255,239,238,237,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,157,222,239,254,237,239,255,255,255,255,240,0,0,0,188,204,203,187,187,187,187,187,204,221,157,237,220,187,187,187,187,188,205,223,237,221,220,187,170,170,170,170,187,205,223,220,204,187,169,153,153,153,170,187,205,221,204,186,169,152,136,136,137,154,188,205,219,203,169,136,119,119,119,136,154,188,204,187,170,152,119,102,102,119,137,170,188,203,186,152,119,101,85,102,119,137,171,203,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,170,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,86,103,137,171,204,187,169,135,118,101,85,103,120,154,188,187,186,169,135,118,102,102,120,137,171,204,188,186,153,135,119,119,120,137,171,188,220,203,186,153,136,136,136,153,170,188,204,205,203,186,153,152,153,154,171,187,221,204,220,204,187,170,170,170,171,188,205,222,205,221,204,187,187,187,187,189,221,239,221,237,221,204,204,188,204,205,221,238,253,141,204,204,187,187,187,203,204,221,222,176,0,0,0,171,186,170,170,153,153,154,170,171,187,139,204,187,186,170,170,170,171,188,204,220,188,187,170,169,153,153,154,170,187,205,202,187,170,153,152,136,137,153,170,187,203,171,170,153,136,119,120,136,153,170,188,186,186,153,136,119,119,119,120,153,171,187,170,153,135,118,102,102,119,120,154,171,186,169,136,119,102,102,102,119,137,154,186,154,152,135,102,85,85,102,120,137,171,169,169,135,118,101,85,86,103,120,154,186,154,152,119,102,85,85,102,119,137,171,169,169,136,118,101,85,86,103,120,154,186,154,152,135,118,101,86,102,120,137,171,170,170,152,135,118,102,102,119,137,170,186,171,169,152,119,119,119,119,136,154,187,186,186,169,152,136,119,136,136,154,171,203,187,186,169,153,136,136,137,154,171,188,187,203,186,170,153,153,153,154,171,188,204,188,203,187,170,170,170,170,187,204,205,203,220,204,187,187,187,187,187,204,205,220,140,187,186,171,170,170,171,187,187,204,176,0,0,0,155,186,170,153,153,153,153,170,171,187,155,203,187,170,170,154,170,170,187,204,220,188,186,169,153,153,153,153,170,187,204,186,186,169,153,136,136,136,153,154,187,203,170,169,152,136,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,170,186,154,153,135,119,102,102,119,120,153,171,169,169,136,119,102,102,102,119,136,154,170,154,152,119,102,101,86,102,119,137,170,169,153,135,118,101,85,86,103,120,153,170,153,152,119,102,85,85,102,119,137,154,169,169,135,118,102,85,102,103,120,153,170,154,152,135,118,102,102,102,120,137,170,169,169,152,119,118,102,102,119,137,154,186,170,169,136,119,119,119,119,136,153,171,170,186,153,136,135,119,120,136,153,171,187,171,186,153,152,136,136,136,153,170,188,187,203,186,169,153,153,153,153,170,187,203,188,203,186,170,169,153,170,171,187,204,203,220,203,187,170,170,170,187,188,205,220,155,187,186,170,170,170,170,171,187,188,160,0,0,0,172,187,186,170,170,170,170,171,187,188,140,204,187,186,170,170,170,171,188,204,220,188,187,170,169,153,153,170,171,188,205,203,187,170,153,136,136,137,153,170,188,203,187,186,153,136,119,120,136,153,171,188,186,186,153,135,119,119,119,136,153,171,203,170,169,135,118,102,102,103,136,154,188,186,169,136,118,102,86,102,119,136,154,187,170,152,135,102,85,85,102,120,137,171,170,169,135,118,85,85,86,103,120,154,186,170,152,119,101,85,85,102,119,137,171,170,169,136,118,101,85,86,103,136,154,186,170,153,135,118,101,102,103,120,153,171,170,186,152,135,102,102,102,119,137,170,187,187,169,152,135,119,119,120,136,154,187,187,187,169,152,136,119,136,137,154,171,203,188,187,169,153,136,136,137,154,171,204,187,204,187,170,169,153,153,170,171,188,204,205,204,187,170,170,170,170,187,204,221,204,221,204,203,187,187,187,187,204,206,236,156,203,187,186,170,170,171,187,188,204,176,0,0,0,191,220,204,203,187,187,187,204,204,205,125,253,221,204,203,187,188,204,221,239,253,222,220,203,187,170,170,187,204,206,238,220,220,203,170,153,153,154,171,204,205,237,205,203,169,153,136,136,153,171,188,222,204,203,169,152,119,119,120,137,170,189,221,204,186,152,119,102,102,120,137,171,205,204,202,168,119,102,85,102,120,154,188,220,188,169,135,101,84,85,102,120,154,189,203,186,152,118,84,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,204,202,152,118,101,84,86,103,137,172,204,204,186,152,118,101,86,103,136,154,189,220,203,169,136,118,102,103,120,154,188,220,205,187,169,136,119,119,136,153,171,205,220,220,186,169,152,136,136,153,171,205,253,221,220,187,170,153,153,154,171,188,221,237,237,220,203,186,170,170,187,204,222,238,223,238,220,204,187,187,188,205,222,239,237,238,253,221,204,204,204,221,238,255,238,141,220,220,204,204,204,205,221,221,238,192,0,0,0,206,239,253,221,221,221,221,221,220,221,143,255,255,254,253,222,254,254,239,255,253,255,255,238,220,205,220,221,238,255,255,223,255,237,220,203,187,188,205,222,239,254,239,238,204,186,169,154,171,204,222,255,238,254,220,186,152,136,137,155,205,222,255,222,220,186,151,118,119,137,171,205,255,221,237,186,151,102,85,102,137,172,205,254,222,219,168,118,84,69,103,138,188,238,237,236,185,134,84,51,69,104,155,206,254,221,203,168,117,67,52,86,138,188,239,238,236,186,135,101,68,70,120,171,205,254,237,219,169,135,101,85,103,154,189,223,253,237,203,169,135,102,119,138,188,222,255,222,221,186,169,136,136,153,171,221,239,253,254,220,203,170,153,170,188,205,255,255,223,254,221,204,187,187,204,221,239,255,237,255,238,221,220,204,205,221,239,255,255,223,254,238,238,237,238,223,254,255,255,252,255,239,239,254,238,255,255,255,255,255,140,204,221,221,221,221,222,255,239,255,208,0,0,0,206,237,221,205,204,204,204,204,204,221,158,254,237,221,204,204,204,221,222,239,253,239,237,220,203,187,187,187,204,221,223,221,237,204,186,170,170,170,187,204,222,237,221,220,186,153,152,137,154,171,205,221,221,220,186,152,135,119,136,153,171,205,237,204,202,152,135,102,103,120,154,172,221,220,203,169,135,102,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,168,118,84,68,69,103,138,188,221,204,186,135,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,120,155,188,221,204,203,169,152,135,119,136,154,188,222,220,236,203,170,153,136,153,154,188,221,254,206,220,203,186,170,170,170,188,206,239,252,237,220,203,187,187], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+980120);
/* memory initializer */ allocate([187,204,221,239,255,222,237,221,204,204,204,205,221,238,255,253,254,238,237,237,221,221,223,255,255,255,157,221,220,220,221,221,221,238,239,239,208,0,0,0,206,221,220,204,187,187,187,204,204,221,174,238,221,204,203,187,187,204,221,238,237,222,220,203,186,170,170,187,188,205,222,221,220,203,170,153,153,153,170,188,221,237,205,203,169,152,136,136,153,170,188,221,220,203,169,152,119,119,120,137,171,188,221,204,186,152,119,102,102,119,137,171,205,203,202,152,119,101,85,102,120,154,172,220,187,169,135,101,84,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,203,186,152,118,101,85,85,103,137,171,204,187,186,152,118,101,85,103,120,154,189,204,203,169,135,118,102,103,120,154,188,221,204,186,169,136,119,119,120,153,171,205,220,220,186,169,152,136,136,153,171,205,237,205,204,186,170,153,153,154,171,204,222,220,237,204,187,170,170,170,187,204,222,238,222,221,220,203,187,187,188,205,222,255,253,238,237,221,204,204,204,221,238,255,255,157,221,221,204,204,204,205,222,238,239,224,0,0,0,222,238,221,204,204,204,204,204,204,220,158,254,237,221,204,204,204,221,221,239,253,223,237,220,203,187,187,188,204,221,222,222,237,204,187,170,170,170,187,204,205,237,222,220,186,153,153,153,154,171,204,222,220,220,186,152,135,119,136,153,171,205,221,205,186,168,119,102,103,120,154,187,221,204,203,169,135,101,85,102,120,154,188,220,205,186,151,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,220,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,136,155,204,237,205,203,170,152,135,120,137,154,188,222,221,220,203,170,153,136,153,170,188,205,237,222,220,203,186,170,170,170,188,221,222,236,221,220,203,187,187,187,204,221,239,254,222,238,221,204,204,204,204,221,238,255,253,238,238,221,220,221,221,221,239,255,255,157,220,220,204,204,205,221,237,238,238,208,0,0,0,223,255,239,237,221,205,220,204,205,221,143,255,255,255,238,221,222,239,239,255,254,255,255,238,221,204,204,221,238,239,255,223,255,237,204,187,187,187,205,222,255,254,239,253,203,170,153,154,171,188,222,255,238,253,203,169,152,136,137,155,204,238,253,239,219,169,135,118,103,136,155,205,255,253,221,186,151,102,85,102,137,171,222,255,221,203,152,118,84,69,103,138,188,223,254,236,169,134,84,51,69,104,155,205,254,221,203,152,101,67,52,86,137,188,223,237,220,186,135,101,68,86,120,171,205,238,222,203,169,118,101,86,103,138,189,223,253,253,203,152,135,102,119,137,172,239,255,223,221,187,169,136,136,153,171,206,255,253,239,221,203,170,153,154,187,205,239,255,239,254,221,204,187,187,188,205,239,255,254,255,222,221,204,204,204,222,239,255,255,223,255,255,238,237,238,239,255,255,255,254,255,255,255,255,255,254,239,255,255,255,157,221,221,238,221,223,255,255,255,255,224,0,0,0,189,204,203,187,187,187,187,187,204,204,141,238,204,204,187,187,187,204,205,239,237,205,220,203,170,170,170,171,188,205,221,204,220,187,170,153,153,153,170,188,204,237,205,203,169,152,136,136,137,154,188,205,204,203,169,136,119,119,120,137,154,188,220,187,186,152,119,102,102,119,137,171,188,203,186,152,119,101,85,102,120,137,171,220,187,169,135,102,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,187,186,152,118,101,85,85,103,137,171,204,187,169,136,118,101,85,102,120,154,188,203,203,169,135,118,102,103,120,154,171,204,188,186,169,136,119,119,120,153,171,205,204,204,186,153,152,136,136,153,171,188,220,205,204,186,169,153,153,153,170,204,221,220,237,204,187,170,170,170,171,188,221,237,206,237,204,187,187,187,187,204,205,238,220,238,237,220,204,204,204,204,221,238,254,124,204,204,203,203,187,204,204,222,222,192,0,0,0,172,187,186,170,170,154,170,170,171,187,140,220,203,187,170,170,170,187,187,204,220,188,203,186,169,153,153,170,171,188,205,187,187,170,153,153,136,153,154,171,188,203,171,170,153,136,136,136,136,154,171,188,186,186,153,136,119,119,119,136,154,171,203,170,169,136,118,102,102,119,137,154,187,186,170,152,118,102,86,102,119,137,170,187,170,152,135,102,85,85,102,120,153,171,170,169,152,118,85,69,86,103,136,154,186,170,152,135,102,84,69,86,120,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,102,86,102,120,153,171,170,186,153,135,118,102,103,120,137,170,187,171,170,152,135,119,119,120,137,154,188,186,187,169,152,136,136,136,137,154,187,203,188,186,170,153,152,137,153,154,171,204,187,203,187,170,169,153,153,170,171,204,220,189,204,187,170,170,170,171,187,204,221,203,221,204,203,187,187,187,188,204,222,237,139,187,187,186,170,170,187,187,188,204,160,0,0,0,155,186,170,153,153,153,153,170,170,187,155,203,187,170,170,154,170,170,187,188,219,187,186,169,153,153,153,153,170,187,204,186,186,169,152,136,136,136,153,170,187,203,171,169,152,136,119,120,136,153,170,187,170,170,152,135,119,119,119,136,153,170,186,154,152,135,118,102,102,119,136,153,171,169,169,136,119,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,153,152,119,102,85,85,102,119,137,154,169,169,136,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,170,169,169,152,135,118,102,102,119,136,154,186,170,169,152,135,119,119,119,136,153,171,170,186,169,152,136,119,120,136,153,170,186,171,186,169,152,136,136,136,153,170,188,186,203,170,169,153,153,153,154,170,187,203,188,203,186,170,170,153,170,170,187,204,203,204,203,187,186,170,170,187,188,204,220,155,187,170,170,170,170,170,170,187,188,160,0,0,0,171,187,170,170,153,153,170,170,187,187,139,204,187,186,170,170,170,171,187,204,219,188,187,170,169,153,153,154,170,187,204,187,187,170,153,136,136,137,153,170,188,203,171,170,152,136,135,136,136,153,171,188,186,186,152,135,119,119,119,136,153,171,186,170,169,135,118,102,102,119,136,154,171,170,169,152,118,102,86,102,119,137,154,186,154,152,135,102,85,85,102,120,153,171,169,169,135,118,85,85,86,103,136,154,186,154,152,135,102,85,85,86,119,137,171,169,169,136,118,101,85,86,103,136,154,186,170,153,135,118,102,86,102,120,137,171,170,186,152,135,118,102,102,119,137,170,186,171,169,152,135,119,119,119,136,154,187,186,186,169,152,136,136,136,136,154,171,203,172,186,169,153,136,136,153,154,171,188,187,203,186,170,153,153,153,170,171,188,203,188,203,187,170,170,170,170,187,188,205,203,221,204,187,187,187,187,187,204,220,220,139,187,170,170,170,170,170,187,187,204,160,0,0,0,189,204,204,187,187,187,187,187,187,204,125,254,220,203,187,187,187,188,205,238,237,221,220,187,186,170,170,171,188,205,222,220,220,203,169,153,153,153,170,187,205,237,205,186,169,152,136,136,137,154,172,205,204,187,169,136,119,119,119,137,154,188,221,188,169,152,119,102,102,119,137,171,204,203,186,152,119,101,85,102,120,137,171,204,187,169,135,101,84,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,86,103,137,171,204,187,169,136,118,101,85,103,120,154,188,203,203,169,135,118,102,103,120,153,187,204,204,186,153,136,119,119,120,137,171,204,204,220,186,153,136,136,136,153,171,188,221,204,204,186,169,153,153,154,171,188,222,220,221,204,187,186,170,170,171,204,222,237,222,221,204,203,187,187,187,204,221,239,237,237,238,236,204,204,204,221,222,255,254,141,204,204,204,204,204,204,204,221,239,208,0,0,0,223,255,255,237,220,221,221,205,204,204,143,255,255,238,238,237,238,239,255,255,253,255,255,254,221,221,205,205,238,239,239,238,255,237,221,203,187,188,205,221,239,253,239,222,220,186,170,170,171,205,222,255,222,254,220,169,152,136,153,171,204,239,253,239,220,185,135,119,119,137,171,205,239,238,221,202,152,102,85,103,137,172,222,254,237,219,168,118,68,69,103,138,189,239,221,237,186,135,84,51,69,120,171,206,254,222,203,168,117,67,52,86,137,188,239,237,237,202,135,101,68,69,120,171,206,238,221,220,169,135,101,85,104,154,205,223,253,253,203,169,135,118,119,137,188,222,239,206,220,203,169,152,136,153,187,221,255,237,239,236,203,170,169,170,187,221,239,255,205,237,220,204,187,187,188,221,255,255,252,254,221,221,220,205,205,221,255,255,255,206,222,237,221,238,222,238,239,255,255,252,254,254,222,238,222,255,239,255,255,255,124,204,204,205,221,222,238,222,255,255,192,0,0,0,206,221,221,204,204,204,204,204,204,204,158,254,237,220,204,204,204,205,222,238,253,223,237,204,203,187,187,188,204,221,238,221,237,220,186,170,170,170,187,204,222,237,221,220,186,153,152,153,154,171,205,222,220,220,186,152,135,119,136,153,171,205,237,204,203,153,135,102,103,120,154,188,205,220,203,169,135,101,85,102,120,154,188,221,204,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,121,171,205,204,203,169,135,101,68,85,103,154,188,220,204,186,152,118,101,85,103,137,171,205,220,204,186,152,119,102,103,136,154,205,237,205,203,169,152,135,119,136,154,188,222,220,220,203,170,153,152,153,154,188,222,237,205,220,203,186,170,170,171,188,205,239,220,237,220,204,187,187,187,204,205,222,254,206,237,221,220,204,204,205,221,238,255,236,254,238,237,221,221,221,238,238,255,255,141,221,220,221,221,221,221,221,238,238,208,0,0,0,205,221,204,203,187,187,187,188,204,204,174,238,221,204,187,187,187,204,205,222,237,222,220,203,186,170,170,171,188,205,222,221,220,203,170,153,153,153,170,188,205,221,205,203,169,152,136,136,137,154,188,205,204,203,169,136,119,119,119,137,154,188,220,204,186,152,118,102,102,119,137,171,205,203,186,152,118,101,85,102,120,137,171,204,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,204,187,169,136,118,101,85,102,120,154,188,203,203,169,135,118,102,102,120,154,188,221,204,186,153,135,119,119,120,137,171,205,220,204,186,153,136,136,136,153,171,205,237,205,203,186,169,153,153,154,171,204,222,220,221,204,187,170,170,170,187,204,222,254,206,221,204,203,187,187,188,205,222,255,237,238,221,220,204,204,204,221,238,239,254,173,220,204,204,204,204,204,221,238,239,208,0,0,0,206,221,221,204,204,204,204,204,204,205,158,255,237,221,204,204,204,221,221,222,253,238,237,204,203,187,187,187,205,221,238,221,237,204,186,170,170,170,187,188,221,237,221,204,186,153,152,153,154,171,205,222,221,220,186,152,135,119,136,154,171,205,221,205,203,152,135,102,103,120,154,187,205,220,203,169,135,101,85,102,120,154,188,220,204,186,152,101,84,69,103,137,171,205,204,203,168,118,84,68,69,103,154,188,220,204,186,151,101,68,68,86,120,171,205,204,203,169,135,101,68,85,103,154,188,221,204,186,152,118,101,85,103,137,171,205,220,219,186,152,119,102,103,136,154,205,237,205,203,169,152,135,119,136,154,188,222,220,220,203,170,153,153,153,154,188,205,237,206,220,187,186,170,170,170,188,205,239,236,237,220,203,187,187,187,188,205,238,254,206,237,221,204,204,204,204,221,239,255,253,238,238,221,221,221,221,222,239,239,255,156,205,220,220,204,205,221,221,238,254,208,0,0,0,207,254,237,237,220,204,204,204,204,204,126,255,255,254,238,221,221,222,238,239,253,223,254,254,220,204,204,204,221,238,239,222,254,238,204,187,187,187,204,205,239,253,239,237,203,186,169,154,171,188,221,238,222,237,203,169,152,136,137,170,204,222,237,222,219,185,135,118,119,137,171,205,239,222,220,186,151,102,85,103,137,172,206,253,221,203,168,117,84,69,103,138,189,223,237,236,185,135,84,51,69,120,171,205,237,221,203,168,117,67,52,86,137,188,239,237,220,186,135,101,68,70,120,171,205,237,221,219,169,135,101,85,103,154,188,239,221,237,203,169,135,118,119,137,188,222,254,223,220,203,169,136,136,153,171,205,255,237,238,221,187,170,153,170,171,205,239,255,222,237,204,203,187,187,188,221,239,255,254,255,237,221,204,204,205,222,254,255,255,223,254,238,222,222,222,238,255,255,255,253,255,239,238,254,238,239,255,255,255,255,140,221,220,222,222,237,237,255,238,255,208,0,0,0,207,238,221,204,204,204,204,204,204,221,142,255,237,220,204,204,204,221,222,239,254,239,237,204,187,187,187,188,205,238,238,222,237,203,186,170,169,170,171,205,222,253,237,220,186,153,152,153,154,171,204,223,220,204,186,152,135,119,136,154,171,205,237,220,186,152,135,102,103,120,154,188,206,220,219,169,135,102,85,102,120,154,188,220,204,186,152,102,84,85,103,137,171,205,220,203,168,118,84,52,85,103,154,188,220,204,186,152,101,83,52,86,120,154,205,220,203,169,135,101,84,86,103,153,188,221,204,202,152,119,101,86,103,137,171,205,220,220,186,152,119,102,103,136,154,189,237,205,203,169,152,135,119,136,154,188,222,236,221,203,170,153,153,153,154,187,205,238,222,220,203,170,170,154,170,187,206,239,253,238,221,204,187,187,187,188,205,222,255,222,237,221,220,204,204,204,221,239,255,253,255,253,237,221,221,221,222,239,255,254,124,204,204,204,204,204,221,221,238,254,208,0,0,0,171,187,170,170,170,170,170,170,171,187,139,220,203,186,170,170,170,187,204,205,235,188,187,170,169,153,153,170,171,188,205,187,203,170,153,152,136,153,154,171,188,203,171,170,152,136,136,136,137,154,171,188,186,186,153,135,119,119,119,136,154,171,203,170,169,135,118,102,102,119,137,154,187,186,169,152,118,102,86,102,119,137,170,187,170,152,135,102,85,85,102,120,154,171,170,169,136,118,85,69,86,103,136,154,186,170,152,135,102,85,69,86,120,137,171,170,169,152,118,101,85,86,103,136,154,186,170,169,135,118,102,86,102,120,153,171,186,186,153,135,118,102,102,119,137,170,187,171,170,152,135,119,119,119,136,154,188,186,187,170,153,136,136,136,136,154,171,203,188,187,170,153,152,136,153,154,171,204,187,204,187,170,169,153,153,170,171,188,220,189,204,187,187,170,170,170,187,188,221,203,220,204,203,187,187,187,187,204,205,236,139,187,187,186,170,170,171,187,188,204,160,0,0,0,171,186,170,153,153,153,153,170,170,187,139,203,187,170,170,170,170,170,187,188,203,187,186,170,153,153,153,153,170,187,204,186,186,169,152,136,136,137,153,170,187,203,171,169,152,136,119,120,136,153,170,187,170,169,152,135,119,119,119,136,153,170,186,154,152,135,118,102,102,119,136,153,171,169,169,136,118,102,102,102,119,136,154,186,154,152,119,102,85,86,102,120,137,170,169,169,135,118,101,85,86,103,120,154,170,154,152,119,102,85,85,102,119,137,170,169,169,136,118,102,85,86,103,120,154,170,154,152,135,118,102,102,102,120,137,171,169,169,152,135,118,102,102,119,136,154,186,170,169,152,135,119,119,119,136,153,171,170,186,169,152,136,119,120,136,153,171,187,171,186,169,152,136,136,136,153,170,188,186,203,186,169,153,153,153,154,170,188,203,188,203,186,170,170,170,170,171,187,205,203,204,203,187,186,170,171,187,188,204,220,139,187,170,170,170,170,170,171,187,204,160,0,0,0,172,203,186,170,170,170,170,170,187,187,140,220,203,187,170,170,171,187,188,205,220,188,203,186,169,153,154,170,171,188,205,203,203,170,153,152,137,153,154,171,188,203,187,186,153,136,136,136,137,154,171,188,187,186,153,135,119,119,120,136,154,171,203,170,169,135,118,102,102,119,137,154,188,186,169,152,118,102,86,102,119,137,170,187,170,152,135,102,85,85,102,120,153,171,186,169,136,118,85,69,86,103,136,154,187,170,152,135,102,84,69,86,120,137,171,186,169,152,118,101,85,86,103,136,154,187,170,169,135,118,102,86,102,120,153,171,186,186,153,135,118,102,102,119,137,170,203,171,170,153,136,119,119,119,137,154,188,187,187,170,153,136,136,136,137,154,171,203,188,187,170,153,152,136,153,154,171,204,203,204,187,170,169,153,153,170,171,204,220,189,204,187,186,170,170,171,187,205,221,220,221,204,203,187,187,187,188,204,222,237,140,187,187,187,187,171,187,188,204,205,176,0,0,0,206,220,204,203,187,187,187,204,188,204,125,254,221,204,203,187,188,204,221,238,253,222,220,203,187,170,170,187,204,205,222,221,221,203,170,153,153,154,171,204,221,253,205,203,169,152,136,136,153,171,188,221,204,203,169,152,135,119,120,137,171,189,220,204,186,152,119,102,103,120,137,171,205,219,203,169,135,101,85,102,120,154,188,220,203,169,135,101,84,85,103,120,155,188,203,186,152,118,84,68,85,103,137,171,204,187,169,135,101,84,68,86,120,154,188,203,203,152,119,101,84,85,103,137,172,204,188,186,152,118,101,85,103,137,154,189,204,203,169,136,119,102,103,120,154,188,221,204,187,169,136,119,119,136,153,187,205,220,220,186,169,152,136,137,153,171,205,221,222,220,187,170,153,153,170,171,204,222,252,221,220,187,186,170,171,188,205,223,238,222,222,220,204,203,188,188,205,222,255,237,254,237,221,204,205,204,222,222,255,255,140,204,220,204,204,204,221,205,222,255,208,0,0,0,239,255,238,237,237,221,220,204,204,204,143,255,255,255,254,237,237,221,255,255,253,255,255,238,221,220,205,221,221,255,255,222,255,237,220,203,187,204,204,221,255,253,239,238,220,187,170,170,187,205,222,255,239,254,219,186,152,136,153,171,204,222,255,239,221,185,135,119,119,137,171,206,239,237,237,202,151,102,85,103,137,172,221,255,221,219,168,117,68,69,103,138,189,255,237,236,186,135,84,51,69,120,171,222,254,221,203,168,117,67,52,87,138,189,254,253,236,202,135,101,68,69,120,172,223,255,222,220,169,135,101,85,103,154,205,255,253,253,203,169,135,119,119,138,189,239,255,207,221,203,169,136,136,154,188,222,255,237,253,237,203,170,170,170,188,222,238,255,222,253,221,203,187,187,204,238,255,255,253,254,238,221,221,205,221,238,254,255,255,223,238,238,221,237,221,239,239,255,255,253,238,238,239,239,254,255,255,255,255,255,124,204,204,221,221,222,254,255,255,255,240,0,0,0,239,239,237,221,204,204,204,204,204,204,143,255,239,221,220,204,204,221,222,238,237,239,237,220,203,187,187,188,204,221,238,222,254,220,187,170,170,170,187,204,221,253,238,220,186,153,153,153,154,171,205,222,221,221,186,152,135,119,136,154,171,205,237,221,202,152,135,102,103,120,154,188,222,220,203,169,135,101,85,102,120,154,188,238,204,186,151,101,84,69,103,137,171,206,220,203,169,118,84,68,69,103,154,188,237,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,238,204,186,152,118,101,85,103,137,172,222,236,204,186,152,119,102,103,120,155,205,238,205,203,169,152,135,119,136,154,189,239,252,220,203,170,153,152,153,154,188,223,255,206,220,203,186,170,170,171,188,222,255,252,237,221,204,187,187,187,205,222,239,255,206,237,221,220,204,205,221,223,255,255,252,254,238,238,238,221,238,255,255,255,255,141,221,221,221,221,222,239,239,255,255,240,0,0,0,223,238,221,204,203,187,187,204,204,204,175,254,237,204,187,187,187,204,205,222,237,239,221,203,186,170,170,171,188,205,222,221,237,203,170,153,153,153,170,187,205,237,221,203,169,152,136,136,137,154,188,205,220,203,169,136,119,119,120,137,154,188,220,204,186,152,118,102,102,119,137,171,204,204,186,152,118,101,85,102,119,137,171,204,187,169,135,101,85,85,102,120,154,188,203,186,152,118,85,68,85,103,137,171,204,187,169,135,101,84,69,86,120,154,188,203,186,152,118,101,85,85,103,137,171,221,187,169,135,118,101,85,102,120,154,189,219,203,169,135,118,102,102,120,154,188,221,204,186,153,135,119,119,120,137,171,205,236,204,186,153,136,136,136,153,171,205,238,205,203,186,169,153,153,154,171,205,239,236,221,203,187,170,170,170,187,205,223,255,206,221,204,203,187,187,188,205,239,255,252,238,221,221,204,204,205,221,239,255,255,173,221,204,204,204,205,221,238,239,255,224,0,0,0,223,254,237,221,204,204,204,204,204,204,143,255,254,221,220,204,221,221,221,238,236,239,238,220,203,187,187,188,204,221,239,222,238,220,187,170,170,170,187,204,221,237,238,220,186,153,153,153,154,171,204,222,221,236,186,152,135,119,136,154,171,205,221,221,203,168,119,102,103,120,154,188,205,221,220,169,135,101,85,102,120,154,204,221,204,186,151,101,84,69,103,137,171,205,220,203,169,118,84,68,69,103,154,188,221,204,186,151,101,68,68,86,120,171,205,220,203,169,135,101,68,85,103,154,188,238,204,202,152,118,101,85,103,137,171,222,221,220,186,152,119,102,103,120,155,205,238,205,203,170,152,135,119,136,154,188,239,236,221,203,170,153,153,153,170,188,222,254,206,220,203,186,170,170,171,188,222,239,252,237,220,204,187,187,187,204,222,239,255,206,237,221,220,204,204,221,222,255,255,253,254,238,221,221,221,221,239,255,255,255,140,204,204,220,221,221,222,238,255,255,224,0,0,0,239,255,255,253,237,221,220,204,204,204,127,255,255,255,254,222,223,222,239,255,253,255,255,255,237,221,204,205,238,238,255,223,255,255,237,204,188,187,205,221,239,253,255,254,236,186,170,170,187,204,223,239,223,255,220,186,152,136,153,171,204,239,255,255,237,186,135,119,119,137,171,221,239,223,255,202,151,101,85,103,137,188,223,254,239,220,168,117,68,69,103,154,189,239,254,253,202,135,84,51,69,120,171,207,255,223,220,168,117,67,52,87,138,205,239,237,253,202,151,101,68,69,120,171,223,255,239,220,185,135,101,85,104,155,207,255,253,238,203,169,135,118,120,154,205,255,255,223,237,203,169,152,136,154,188,223,255,253,253,220,203,170,170,170,205,223,255,255,223,253,221,204,203,204,205,222,255,255,253,254,254,221,220,221,221,239,255,255,255,223,254,238,238,222,238,255,255,255,255,252,239,255,255,255,255,255,255,255,255,255,141,204,205,222,239,255,255,255,255,255,240,0,0,0,239,255,223,222,221,204,204,204,204,204,127,255,239,255,253,238,254,221,239,255,253,255,255,238,221,221,221,205,223,255,255,223,254,237,220,203,187,188,204,221,255,253,255,253,219,186,170,170,187,204,221,255,255,254,219,170,152,137,153,171,204,255,255,254,220,186,152,119,120,137,172,204,255,253,253,202,152,118,102,103,137,172,205,254,221,203,169,118,84,69,103,154,204,223,221,237,186,151,100,35,70,120,171,221,255,221,203,169,118,67,36,87,154,205,255,254,220,202,152,101,68,86,120,172,222,253,221,220,170,135,102,86,120,154,189,255,254,221,203,169,135,119,120,153,188,239,255,223,237,203,169,152,137,154,188,221,255,253,255,236,203,186,170,170,172,222,239,255,223,254,204,220,187,187,188,221,239,255,254,255,222,237,221,204,221,223,255,255,255,223,254,255,255,236,237,255,255,255,255,254,255,255,237,254,237,255,255,255,255,255,108,203,188,205,220,207,223,239,255,255,224,0,0,0,189,204,187,170,170,170,170,170,171,187,141,220,203,187,170,170,170,187,188,205,220,205,203,170,169,153,153,170,171,188,205,203,203,186,153,153,137,153,154,171,188,219,188,170,153,136,136,136,137,154,171,205,187,186,153,136,119,119,120,137,154,171,203,171,169,136,118,102,102,119,137,154,188,186,186,152,118,102,86,102,120,137,171,187,170,153,135,102,85,85,102,120,154,187,186,169,152,118,85,68,86,103,136,154,187,170,153,135,102,84,69,86,120,137,171,186,169,152,118,101,85,86,103,137,154,187,170,169,135,118,102,86,102,120,154,171,186,186,153,135,118,102,102,119,137,171,204,171,170,152,135,119,119,119,137,154,188,202,203,170,153,136,136,136,137,154,188,204,188,187,170,153,153,136,153,154,187,205,219,220,203,170,170,153,154,170,187,205,221,189,204,187,186,170,170,171,187,204,222,219,221,204,203,187,187,187,204,205,222,237,140,187,187,187,187,187,187,188,221,222,192,0,0,0,188,187,170,153,153,153,153,154,170,187,155,203,186,170,169,153,154,170,187,188,219,188,186,169,153,153,153,153,170,171,188,186,186,169,152,136,136,136,153,154,171,203,171,169,152,135,119,119,136,137,154,187,186,169,152,135,119,119,119,120,137,170,186,154,152,135,118,102,102,119,120,153,171,169,169,135,118,102,102,102,119,136,154,170,153,152,119,102,101,86,102,119,137,154,169,153,135,118,101,85,102,103,120,153,170,153,152,119,102,101,85,102,119,137,154,169,153,135,118,102,101,102,103,120,153,170,154,152,135,118,102,102,102,119,137,170,169,169,152,119,118,102,102,119,136,154,186,154,169,136,119,119,119,119,136,153,171,186,186,153,136,135,119,119,136,153,170,187,171,170,153,152,136,136,136,153,170,188,186,187,170,169,153,153,153,153,170,188,204,188,187,170,170,153,153,170,170,187,205,203,204,203,187,170,170,170,187,188,205,221,155,187,170,170,170,170,170,187,188,205,192,0,0,0,189,203,187,170,170,170,170,171,187,187,141,220,203,187,186,170,171,187,204,205,219,204,203,170,170,153,154,170,171,187,205,188,203,170,153,152,153,153,154,171,188,219,187,186,152,136,136,136,137,154,171,188,187,186,152,135,119,119,120,136,154,187,203,171,169,135,118,102,103,119,137,154,187,186,185,152,118,102,86,102,120,137,171,187,170,153,135,101,85,85,103,120,154,171,186,169,136,118,85,68,86,103,137,154,187,170,153,135,102,84,69,86,120,137,171,186,170,152,119,101,85,86,103,136,154,187,170,169,136,118,102,86,102,120,153,187,186,186,153,135,118,102,102,119,137,171,203,171,170,152,136,119,119,119,137,154,188,203,187,170,153,136,136,136,137,154,188,204,188,187,170,153,153,136,153,154,171,205,203,203,187,170,169,153,154,170,187,204,221,189,220,187,187,170,170,171,187,204,222,219,221,204,203,187,187,188,204,205,221,237,139,187,187,187,187,187,187,188,205,221,192,0,0,0,238,255,223,221,204,204,221,204,204,204,127,255,255,253,222,221,222,222,239,255,254,255,255,237,205,204,204,220,221,238,255,223,255,222,204,187,187,187,188,221,254,254,255,237,203,170,153,170,170,188,206,239,238,237,203,169,136,136,137,171,204,222,255,223,219,169,135,119,119,137,171,205,222,237,252,186,151,102,85,103,137,171,206,237,222,203,168,117,68,69,103,138,188,222,237,236,185,135,84,51,69,120,171,206,255,222,203,152,117,67,52,87,137,188,222,253,220,186,151,101,68,70,120,171,205,254,222,203,169,135,101,86,103,154,188,223,221,237,203,169,135,119,119,137,172,223,255,239,220,187,169,136,136,153,171,205,255,255,253,220,187,170,153,154,171,206,223,255,223,253,220,187,187,187,188,205,239,255,253,255,222,204,204,204,205,221,238,255,255,223,239,238,237,221,221,221,255,255,255,253,254,239,254,238,239,239,255,255,255,255,124,204,221,221,237,222,238,239,255,255,240,0,0,0,255,255,255,255,255,255,220,204,203,187,127,255,255,255,255,255,255,221,255,255,252,255,255,255,255,221,253,223,255,223,223,255,255,255,255,204,204,205,255,253,255,253,255,255,252,219,186,187,203,221,253,255,255,255,253,203,169,153,154,188,221,255,255,255,255,203,152,119,120,154,188,221,253,255,255,221,168,118,85,104,154,188,255,255,255,252,201,118,84,69,104,171,204,255,255,253,202,151,84,35,69,121,188,255,255,255,220,185,118,67,36,87,154,207,255,255,253,219,168,101,68,86,121,189,255,255,255,220,186,135,101,86,120,172,223,255,253,252,253,186,136,119,120,154,205,255,255,223,255,220,186,153,153,171,205,255,255,253,255,253,220,187,186,187,221,255,255,255,223,253,255,221,220,203,220,255,255,255,252,255,223,221,253,253,221,255,255,255,255,207,255,253,255,255,255,255,255,255,255,252,255,255,255,255,253,255,255,255,255,255,124,203,221,207,255,223,255,255,255,255,240,0,0,0,239,239,253,220,220,204,204,204,204,204,159,255,254,221,220,204,204,204,221,223,253,255,255,204,203,187,187,187,188,220,239,239,253,220,186,170,153,170,171,204,222,253,254,220,186,153,136,137,154,170,204,221,237,220,186,152,135,119,120,137,171,205,238,221,186,152,119,102,102,120,137,172,205,221,203,169,135,101,85,102,120,154,188,237,220,186,135,101,84,69,102,121,171,205,236,203,168,118,84,68,85,103,137,189,238,204,186,135,101,84,68,86,120,171,222,236,203,152,118,101,84,85,103,138,188,254,204,186,152,118,101,85,103,137,171,223,252,203,169,136,118,102,103,120,154,190,255,204,203,169,136,119,119,120,154,188,255,252,221,187,170,153,136,137,154,188,223,255,221,220,187,186,169,154,170,188,222,255,252,237,204,204,187,187,188,204,222,255,255,221,221,237,220,220,221,221,255,255,255,252,255,254,222,221,221,222,255,255,255,255,156,221,221,223,222,238,255,255,255,255,240,0,0,0,255,255,254,220,204,204,204,205,221,222,191,255,254,220,204,187,188,204,221,239,255,255,253,204,187,170,170,171,188,205,239,239,253,203,170,153,153,153,170,188,221,254,254,203,169,152,136,136,137,154,188,223,221,220,169,136,119,119,119,137,154,188,221,220,186,152,118,102,102,119,137,171,205,220,203,152,118,101,85,86,119,137,172,221,204,169,135,101,85,85,102,120,154,189,220,186,152,118,85,68,85,103,137,171,221,203,169,135,101,84,69,86,120,154,189,220,186,152,118,101,85,85,103,137,172,222,204,169,135,118,101,85,102,120,155,205,236,203,169,135,118,102,102,120,154,188,239,204,186,153,135,119,119,120,137,172,223,253,220,186,153,136,136,136,153,171,206,255,221,220,186,169,153,153,154,187,205,255,253,237,204,187,170,170,171,188,221,255,255,223,237,220,204,187,188,204,222,255,255,254,255,238,221,220,221,221,239,255,255,255,190,237,221,221,221,221,239,255,255,255,240,0,0,0,255,255,255,254,221,253,236,220,205,206,159,255,255,253,221,204,220,221,222,239,253,255,255,237,220,203,187,204,204,221,239,223,254,221,203,170,170,170,188,205,221,253,255,220,186,153,152,153,154,171,204,221,223,237,186,152,135,119,136,154,171,205,253,237,203,152,119,102,103,120,154,172,221,221,235,169,135,101,85,102,120,154,188,221,221,186,151,101,84,69,103,137,171,222,221,203,169,118,84,68,69,103,138,188,253,221,186,151,101,68,68,86,120,171,205,221,220,169,135,101,68,85,103,154,189,238,221,186,152,118,101,85,103,137,172,221,237,220,186,152,119,102,103,120,155,207,254,221,219,170,152,135,119,136,154,189,223,253,221,187,169,153,137,137,170,189,238,255,222,220,187,170,170,170,171,189,223,255,253,221,220,203,187,187,188,205,223,255,255,222,221,220,204,204,204,221,254,255,255,252,255,223,254,222,221,223,255,255,255,255,156,204,220,220,221,221,221,255,255,255,240,0,0,0,255,255,255,255,255,255,252,187,187,203,127,255,255,255,255,255,255,255,255,255,252,255,255,255,255,253,255,207,255,255,255,223,255,255,253,255,205,220,255,255,255,255,255,255,255,252,187,204,204,205,255,255,223,255,255,203,170,169,171,189,207,255,255,255,255,204,169,136,136,154,188,255,255,255,255,252,185,118,102,120,155,205,255,255,255,255,202,134,84,69,121,171,255,255,255,255,251,168,100,34,70,138,207,255,255,255,253,186,134,66,36,104,171,223,255,255,255,220,184,117,68,86,138,207,255,255,223,253,203,152,118,103,137,188,255,255,255,255,253,186,169,136,137,187,207,255,255,223,255,204,187,170,170,188,223,255,255,255,255,253,204,204,188,204,207,255,255,255,207,253,255,204,221,253,255,255,255,255,255,255,255,255,221,223,223,255,255,255,255,223,255,255,223,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,123,205,220,205,223,255,255,255,255,255,240,0,0,0,255,223,253,203,191,188,220,186,203,203,127,223,221,223,204,188,252,252,255,255,252,221,255,221,220,251,219,203,207,220,255,188,255,250,251,251,171,204,204,255,255,255,253,252,187,170,169,154,187,204,204,255,204,253,203,155,137,136,153,171,173,205,255,252,186,170,151,119,120,137,170,191,255,203,252,185,151,118,102,119,137,170,252,251,188,187,169,118,84,85,103,138,172,220,221,204,185,151,100,35,70,120,156,203,252,207,187,168,118,67,36,103,153,172,207,207,188,201,151,101,68,86,120,154,205,255,220,202,169,135,102,102,120,154,187,255,255,255,203,169,135,119,119,138,188,188,252,252,207,204,153,152,136,153,154,207,207,255,255,252,203,170,154,169,170,207,255,255,255,255,254,236,170,171,172,204,223,255,252,223,205,205,188,203,207,251,220,253,255,223,255,220,253,220,252,223,221,207,255,250,220,223,253,253,205,223,223,221,223,255,108,187,204,204,219,253,207,255,221,255,208,0,0,0,188,203,170,170,153,153,169,170,170,171,140,204,187,186,170,170,170,171,203,205,219,188,202,186,154,153,153,154,170,187,206,203,187,170,153,152,136,137,154,171,188,203,187,169,152,136,136,136,137,153,171,188,186,186,152,135,119,119,120,137,154,171,203,171,169,135,119,102,103,119,137,154,188,186,169,152,118,102,102,102,119,137,154,187,170,152,135,102,85,86,103,120,137,171,186,169,136,118,101,68,86,103,136,154,187,154,152,135,102,84,69,86,120,137,170,185,169,136,119,101,85,86,103,136,154,187,154,169,135,118,102,86,102,120,153,171,186,186,153,135,118,102,102,119,137,171,203,171,169,152,136,119,119,119,136,154,188,218,187,169,152,136,135,136,136,154,171,203,172,186,170,153,152,136,137,153,171,205,202,203,186,186,169,153,153,170,171,204,220,189,204,187,186,170,186,170,187,190,237,203,204,221,203,187,187,187,187,205,254,254,140,187,187,170,171,187,187,204,205,221,192,0,0,0,188,187,170,169,153,153,153,170,171,188,172,204,186,170,153,153,154,170,187,188,220,188,186,169,153,152,153,153,154,171,188,187,186,169,152,136,136,136,137,154,171,203,171,169,152,135,119,119,136,137,154,187,186,169,152,119,119,119,119,120,137,154,186,170,152,135,118,102,102,119,120,137,171,169,169,135,118,102,102,102,119,136,154,170,153,152,119,102,101,102,102,119,137,154,169,153,135,118,101,85,102,103,120,153,170,153,136,119,102,101,85,102,119,136,154,169,153,135,118,102,101,102,103,120,153,170,153,152,135,118,102,102,102,119,137,170,169,169,136,119,118,102,102,119,136,154,186,170,153,136,119,119,119,119,136,153,171,186,170,153,136,135,119,119,136,153,171,187,171,170,153,136,136,136,136,153,170,188,203,187,170,153,153,152,153,153,170,188,220,188,187,186,170,153,153,154,171,188,205,220,220,203,186,170,170,170,171,188,205,237,172,187,186,170,170,170,170,187,204,222,208,0,0,0,188,186,186,170,170,170,170,170,170,187,140,204,187,186,170,170,187,187,205,220,219,188,188,169,153,153,153,154,170,187,204,171,202,170,152,136,136,137,153,170,204,186,187,169,152,136,120,136,136,153,170,187,170,170,152,135,119,119,119,136,153,170,186,186,152,135,118,102,103,119,136,154,186,170,169,136,118,102,102,102,119,136,170,170,170,152,135,102,85,86,103,120,153,170,170,169,136,118,101,68,86,103,136,154,170,154,152,135,102,84,69,102,120,137,171,170,185,152,118,102,85,86,103,136,154,186,170,153,136,119,102,102,102,120,153,171,186,170,152,135,119,102,102,119,137,154,187,171,169,152,135,119,119,119,137,154,187,171,218,169,152,136,119,136,136,154,172,187,188,171,169,153,152,136,137,154,170,189,203,187,187,169,169,153,153,170,172,188,204,188,204,186,170,170,170,170,171,188,205,203,205,187,203,186,187,187,172,187,221,221,122,170,170,186,170,170,171,187,187,205,176,0,0,0,255,255,255,255,252,191,223,187,171,191,111,255,255,255,255,223,255,255,255,255,253,255,255,255,255,204,253,255,223,255,255,223,255,255,255,252,187,223,252,255,255,255,255,255,255,255,188,191,207,191,255,255,253,255,253,255,187,186,171,252,252,255,255,255,255,220,202,153,153,172,223,255,255,255,255,205,186,135,119,137,155,191,255,255,255,255,203,151,84,70,138,219,255,255,255,255,205,169,100,18,87,155,191,223,255,255,255,186,151,82,36,121,171,207,255,255,255,252,169,134,84,87,155,253,255,253,255,252,204,169,135,119,138,172,223,255,255,255,255,187,153,153,154,175,207,255,255,223,255,191,172,186,170,204,191,255,255,253,255,255,203,188,187,223,221,255,255,255,223,255,223,252,205,255,255,255,255,255,255,255,253,253,223,252,255,255,255,255,255,207,255,253,223,252,255,255,255,255,255,253,255,255,255,255,255,255,255,255,255,255,107,207,223,223,255,207,255,255,255,255,240,0,0,0,255,255,175,255,191,171,251,159,187,171,107,255,251,255,175,170,251,250,187,255,255,255,251,191,185,251,186,187,191,255,255,250,255,250,251,187,170,255,250,191,191,255,191,250,175,187,153,154,169,191,251,251,171,251,186,169,152,154,153,170,251,187,255,175,250,170,152,120,120,137,175,191,175,251,191,186,153,118,102,136,153,191,255,191,255,250,152,119,84,86,121,155,191,187,187,175,171,168,100,34,87,136,154,255,171,175,153,184,119,82,37,121,169,170,255,250,187,186,152,118,84,102,120,153,191,251,159,250,154,152,118,102,120,138,250,171,175,251,186,184,152,136,120,154,171,255,251,175,191,186,170,153,169,159,138,250,255,170,255,187,175,169,168,137,171,250,187,255,251,255,255,251,169,171,175,191,187,187,187,255,191,251,255,250,191,175,175,251,255,175,191,255,255,187,255,255,191,255,255,255,255,255,255,255,251,255,251,255,255,251,111,170,171,171,186,250,250,187,255,251,240,0,0,0,255,222,255,255,255,220,204,207,205,207,111,255,255,255,255,223,255,255,255,255,255,255,255,255,255,255,220,255,255,255,255,255,255,255,255,255,253,205,255,255,255,255,255,255,255,255,207,220,252,223,255,255,255,255,255,255,221,204,220,221,223,255,255,255,255,207,235,186,187,188,221,253,223,252,255,221,203,152,120,154,204,255,255,255,223,255,253,184,84,70,155,205,223,255,255,255,205,218,116,34,72,172,252,255,255,255,255,252,167,66,20,122,223,255,255,221,255,253,218,150,68,88,188,253,255,255,255,223,252,218,151,120,172,221,255,255,255,255,252,252,202,170,171,207,255,253,255,223,255,253,252,220,188,205,223,223,255,252,255,253,255,223,204,253,253,255,255,255,255,255,255,255,252,223,255,253,255,255,255,255,221,255,255,207,255,255,255,255,255,255,255,255,223,255,255,223,255,255,255,252,255,255,255,255,255,255,255,255,255,255,107,221,205,221,255,223,255,255,255,255,240,0,0,0,255,255,255,221,221,205,221,222,223,255,207,255,255,220,204,203,204,189,238,239,255,255,255,220,187,186,170,187,204,223,239,255,253,204,186,153,153,153,170,188,223,255,254,220,170,152,136,136,137,171,188,222,255,220,185,152,119,119,119,137,170,204,255,252,202,152,118,102,102,119,137,171,205,254,203,168,118,101,85,86,119,153,188,222,220,185,135,101,85,85,102,120,154,205,220,202,152,118,85,68,85,103,137,171,221,204,169,135,101,84,69,86,120,154,205,236,202,152,118,85,85,85,103,137,171,223,204,185,135,118,85,85,102,120,171,207,253,203,169,135,118,102,102,120,154,188,255,221,202,169,135,119,119,120,154,188,223,253,220,186,169,136,136,136,154,172,223,255,255,220,186,169,153,153,170,187,223,255,255,255,221,203,186,170,171,188,223,255,255,255,255,220,220,204,204,205,222,255,255,255,255,255,238,221,221,222,239,255,255,255,223,255,254,254,221,239,255,255,255,255,240,0,0,0,207,254,253,220,207,253,237,204,188,236,127,239,255,239,239,238,255,255,255,255,253,223,221,255,221,253,239,239,238,239,255,207,239,255,223,239,223,222,239,239,255,253,238,253,253,221,221,204,221,238,254,253,237,255,238,220,204,188,188,206,237,255,254,239,205,255,187,170,170,188,221,238,255,255,255,252,203,152,119,137,188,222,255,253,222,223,220,168,84,70,138,207,239,239,220,255,220,202,116,18,71,172,237,238,254,238,239,251,167,66,36,122,189,238,239,222,237,222,202,134,68,104,173,221,238,253,222,238,252,185,135,120,171,207,221,255,253,255,252,204,186,154,171,190,239,239,253,223,255,253,204,204,204,220,205,255,255,239,255,254,222,221,204,253,239,223,255,254,255,255,237,221,221,239,239,255,255,255,222,255,254,255,237,254,254,255,239,255,255,206,239,255,255,253,222,255,239,255,255,253,255,239,254,238,255,254,255,255,255,255,126,221,204,204,206,206,206,237,255,255,192,0,0,0,255,255,255,248,255,143,248,248,249,248,95,255,249,248,255,255,255,255,255,255,255,143,255,255,248,153,255,255,255,255,255,255,255,255,249,255,136,159,255,255,255,255,255,255,248,254,143,143,143,248,255,255,255,255,255,255,136,120,255,255,248,143,255,255,255,249,143,248,249,249,143,255,143,143,248,137,143,104,104,136,136,248,255,255,255,248,136,120,100,86,255,143,248,255,255,248,255,136,100,34,72,136,143,255,255,233,143,255,247,82,37,120,143,248,255,255,159,255,248,135,68,88,143,255,255,255,255,255,249,143,247,118,136,249,255,255,159,255,255,255,121,136,249,255,255,255,255,255,255,248,255,248,255,255,255,255,248,255,255,152,255,255,143,249,255,143,255,255,143,255,255,248,255,152,248,255,255,255,255,255,255,255,255,143,255,255,255,159,255,143,255,255,255,143,255,143,255,248,255,255,255,255,255,255,143,255,255,255,255,255,111,153,255,207,248,255,255,255,255,255,240,0,0,0,127,135,135,102,104,135,119,119,104,255,87,255,136,255,136,136,143,136,255,255,248,111,247,120,248,143,135,120,135,255,247,135,247,248,127,248,136,136,135,136,143,135,248,136,247,247,255,143,136,127,143,248,247,143,143,247,119,247,104,143,143,255,247,105,143,136,118,120,111,119,111,255,127,136,248,143,247,135,136,247,127,248,143,119,104,135,247,134,135,103,103,127,120,248,119,119,136,103,247,118,136,120,119,255,143,127,136,135,103,103,119,119,120,143,127,119,127,135,118,104,135,119,103,127,126,232,203,136,127,247,119,135,111,143,135,127,104,136,247,136,247,246,135,248,135,255,247,136,248,143,143,247,136,127,255,143,255,119,248,136,120,143,247,120,119,136,143,247,143,248,255,248,143,136,120,119,127,248,120,248,136,136,127,143,127,143,167,120,127,255,255,135,143,120,135,143,143,135,143,119,248,247,136,143,143,255,248,135,127,248,143,135,143,135,120,127,247,119,120,248,112,0,0,0,87,120,102,119,102,118,119,118,135,121,104,173,152,137,152,218,185,153,153,157,152,121,170,137,152,136,136,152,170,136,154,135,137,169,153,137,152,152,153,137,169,153,122,136,121,152,136,135,135,152,136,154,118,152,119,136,135,151,136,152,152,153,136,121,137,153,120,135,136,136,137,169,152,135,153,135,120,120,135,135,135,151,153,151,121,152,152,120,135,152,135,120,136,154,118,153,119,120,120,119,135,120,136,153,167,121,136,137,135,119,135,136,120,136,137,119,136,151,136,135,135,103,136,137,137,136,121,137,136,120,135,119,119,120,137,138,118,137,151,119,151,135,119,153,137,153,150,106,168,136,136,136,137,135,136,136,153,135,154,168,136,152,120,136,136,136,153,152,121,153,136,136,152,136,135,136,136,169,120,170,152,152,168,136,136,136,136,136,167,138,152,137,138,136,136,154,137,137,153,120,169,153,216,137,152,138,137,152,170,135,105,136,135,135,120,119,103,135,119,121,80,0,0,0,255,255,255,255,255,255,255,255,255,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,171,191,255,255,255,255,255,255,255,255,133,104,255,255,255,255,255,255,255,255,245,18,111,255,255,255,255,255,255,255,255,97,21,191,255,255,255,255,255,255,255,248], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+990360);
/* memory initializer */ allocate([101,159,255,255,255,255,255,255,255,255,187,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,251,187,255,111,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,239,255,251,255,255,255,255,255,255,255,169,153,191,255,255,255,255,255,255,255,151,102,136,191,255,255,255,255,255,251,183,83,69,122,255,255,255,255,255,255,249,99,34,70,175,255,255,255,255,255,255,150,66,36,121,255,255,255,255,255,255,186,133,68,87,175,255,255,255,255,255,255,250,134,103,159,255,255,255,255,255,255,252,249,153,191,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,187,191,253,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,255,255,143,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,136,255,255,255,255,255,255,255,255,246,18,255,255,255,255,255,255,255,255,255,243,7,255,255,255,255,255,255,255,255,248,188,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,143,255,255,255,255,255,255,255,255,255,249,255,255,255,255,255,111,255,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,239,255,255,229,239,255,255,63,255,238,238,229,239,255,255,255,255,255,255,255,254,238,238,238,238,238,238,238,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,94,94,238,238,238,238,238,238,238,238,238,238,238,238,238,238,239,255,255,255,244,95,95,255,245,255,255,255,255,255,84,85,95,95,255,255,255,255,255,255,95,79,255,84,255,255,255,255,254,238,238,78,229,230,238,94,238,238,238,238,229,229,229,238,94,238,238,238,238,238,238,238,94,238,68,238,238,238,238,94,239,255,245,69,63,63,255,255,255,255,245,255,255,255,79,79,255,255,255,255,255,255,255,255,255,95,95,255,255,255,255,255,255,255,255,245,255,95,255,255,255,255,255,255,255,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,254,255,255,254,255,254,255,255,254,255,255,255,255,255,255,255,255,255,255,254,255,254,255,254,240,0,0,0,255,255,255,255,255,255,255,255,159,175,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,255,175,255,255,255,255,255,255,159,255,255,251,255,255,255,255,255,175,153,155,255,255,255,255,255,255,255,255,167,103,127,171,255,255,255,255,255,255,167,84,69,121,255,255,255,255,255,255,255,100,34,71,255,255,255,255,255,255,255,166,66,35,105,255,255,255,255,255,255,250,117,67,87,159,255,255,255,255,255,255,249,119,103,154,190,255,255,255,255,255,255,250,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,255,239,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,223,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,255,255,191,186,170,175,95,255,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,255,250,153,170,255,255,255,255,255,255,255,252,101,86,255,255,255,255,239,255,255,255,148,18,89,255,255,255,255,255,255,255,249,82,20,157,255,255,255,255,255,255,255,151,84,111,255,255,255,255,255,255,255,255,170,170,175,255,255,255,255,255,255,255,250,250,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,191,251,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,254,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,255,111,249,255,255,255,255,255,255,255,255,240,0,0,0,255,255,255,255,170,175,255,169,170,255,95,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,175,255,251,255,255,255,255,255,255,255,255,159,175,255,255,255,175,250,255,175,255,175,255,255,255,255,255,255,255,255,255,159,255,255,255,255,255,255,255,255,168,167,103,127,255,255,255,255,255,255,255,215,83,69,122,255,255,255,255,255,255,250,100,34,71,175,255,255,255,255,175,249,151,66,36,104,175,255,255,255,255,255,250,118,68,88,159,255,255,255,255,255,255,255,118,103,255,250,255,255,255,255,255,255,249,169,175,255,255,255,255,255,255,255,175,255,255,175,255,255,255,255,255,255,255,255,255,175,255,255,255,255,255,255,255,255,255,202,175,255,250,255,255,255,255,255,255,250,250,175,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,79,169,175,255,250,159,255,255,255,255,240,0,0,0,95,239,86,111,246,102,238,239,111,255,86,230,230,238,238,239,255,255,255,255,254,238,230,238,238,238,230,238,238,238,238,239,255,255,111,255,255,255,255,255,255,254,238,238,230,238,238,110,238,238,238,238,238,238,110,78,110,238,238,238,230,238,238,239,246,245,111,86,255,255,255,255,255,245,255,255,255,244,111,111,255,255,255,254,238,229,230,102,101,110,229,238,230,238,238,238,238,229,86,69,238,238,238,238,238,238,238,238,230,230,101,101,238,238,238,230,238,238,230,102,110,110,238,238,230,238,110,239,246,246,255,86,255,111,255,255,255,255,255,255,255,255,85,111,102,245,246,255,246,255,255,255,255,111,255,255,255,255,255,255,255,255,246,245,246,255,111,254,238,238,238,238,238,238,230,238,238,254,110,254,255,254,255,110,246,254,255,102,255,254,255,254,239,255,255,254,254,254,254,254,255,255,255,255,255,95,255,254,255,255,95,255,101,111,246,254,102,254,102,94,80,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,127,168,255,255,247,255,63,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,239,255,255,255,255,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,223,255,255,255,255,255,255,255,255,255,255,255,255,255,248,118,119,255,255,255,255,255,255,255,134,84,69,127,255,255,255,255,255,255,249,100,34,72,255,255,255,255,255,255,255,246,66,36,95,255,255,255,255,255,255,127,245,68,91,255,255,255,255,255,255,255,255,247,246,127,255,255,255,255,255,255,255,255,135,127,143,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,143,255,255,255,255,240,0,0,0,238,238,238,222,238,238,237,213,238,238,62,238,238,221,221,222,238,238,238,238,238,238,238,238,238,238,237,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,237,221,221,221,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,228,33,238,238,238,238,238,238,238,221,221,209,29,221,221,221,221,221,221,221,221,221,221,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,237,224,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,117,79,255,255,255,255,255,255,255,255,244,18,71,255,255,255,255,255,255,255,255,66,20,255,255,255,255,255,255,255,255,255,84,191,255,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,95,255,255,255,255,255,255,255,255,255,240,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,255,255,255,255,127,255,255,255,255,255,79,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,207,255,255,255,255,255,255,255,255,255,255,255,255,255,119,103,175,255,255,255,255,255,255,255,246,68,69,247,255,255,255,255,255,255,246,84,34,70,159,255,255,255,255,255,255,245,66,52,95,255,255,255,255,255,255,255,117,67,79,127,255,255,255,255,255,255,255,247,86,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,111,255,255,255,255,127,255,255,255,255,240,0,0,0,238,238,238,222,238,238,237,222,238,238,238,238,238,221,221,222,238,238,238,238,238,238,238,238,238,238,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,221,221,221,221,221,221,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,83,78,238,238,238,238,238,238,238,238,229,18,238,238,238,238,237,221,221,221,221,210,36,221,221,221,221,221,221,221,221,221,211,61,221,221,221,221,221,222,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,238,62,229,238,238,238,238,238,238,238,237,224,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,136,136,136,120,136,136,135,120,136,136,136,136,136,135,119,120,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,135,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,119,120,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,136,128,0,0,0,0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,221,36,6,129,149,67,0,64,82,184,30,133,235,81,1,192,242,210,77,98,16,88,255,63,113,61,10,215,163,112,249,191,204,238,201,195,66,173,227,63,72,215,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,11,0,0,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,15,39,0,152,204,38,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,144,136,38,0,152,204,38,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,136,200,34,0,40,77,38,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,104,22,38,0,40,77,38,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,248,235,37,0,224,190,37,0,56,0,0,0,84,65,82,86,184,157,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,109,37,0,224,190,37,0,56,0,0,0,84,65,82,86,184,157,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,80,45,37,0,56,6,37,0,16,0,0,0,5,0,0,0,168,219,36,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,128,188,36,0,32,159,36,0,64,0,0,0,3,0,0,0,79,233,47,55,239,198,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,216,131,36,0,32,159,36,0,64,0,0,0,3,0,0,0,79,233,47,55,239,198,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,208,105,36,0,160,77,36,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,96,54,36,0,160,77,36,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,80,16,36,0,120,218,35,0,76,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,144,192,35,0,104,169,35,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,128,147,35,0,128,125,35,0,84,0,0,0,82,76,79,67,144,102,35,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,136,84,35,0,104,67,35,0,88,0,0,0,82,76,79,67,168,49,35,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,168,17,35,0,104,233,34,0,92,0,0,0,82,76,79,67,168,49,35,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,202,34,0,112,0,0,0,152,88,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,96,11,46,194,239,147,48,155,152,34,50,21,86,248,50,12,160,47,51,34,148,245,50,173,165,30,50,163,68,141,48,162,136,43,45,44,216,154,48,55,154,38,50,27,20,251,50,107,152,47,51,136,206,242,50,125,193,26,50,147,213,134,48,252,244,69,45,111,255,161,48,107,170,42,50,240,205,253,50,44,137,47,51,140,5,240,50,27,236,22,50,235,160,128,48,147,242,98,45,252,102,169,48,34,201,46,50,167,65,0,51,78,114,47,51,116,57,237,50,147,37,19,50,233,74,117,48,16,84,129,45,51,16,177,48,67,246,50,50,248,153,1,51,214,83,47,51,133,106,234,50,242,109,15,50,87,195,105,48,121,137,146,45,142,252,184,48,179,49,55,50,198,239,2,51,199,45,47,51,2,153,231,50,64,197,11,50,134,168,94,48,77,64,165,45,147,45,193,48,86,123,59,50,241,66,4,51,37,0,47,51,48,197,228,50,130,43,8,50,81,247,83,48,254,150,185,45,166,164,201,48,11,211,63,50,85,147,5,51,246,202,46,51,83,239,225,50,189,160,4,50,120,173,73,48,228,204,207,45,79,99,210,48,175,56,68,50,207,224,6,51,64,142,46,51,176,23,223,50,247,36,1,50,224,199,63,48,211,237,231,45,230,106,219,48,30,172,72,50,63,43,8,51,11,74,46,51,135,62,220,50,88,112,251,49,86,68,54,48,170,252,0,46,14,189,228,48,51,45,77,50,127,114,9,51,94,254,45,51,28,100,217,50,183,180,244,49,102,31,45,48,79,237,14,46,26,91,238,48,195,187,81,50,112,182,10,51,67,171,45,51,179,136,214,50,5,23,238,49,123,87,36,48,99,3,30,46,153,70,248,48,161,87,86,50,237,246,11,51,196,80,45,51,138,172,211,50,55,151,231,49,25,233,27,48,248,128,46,46,120,64,1,49,161,0,91,50,213,51,13,51,235,238,44,51,229,207,208,50,63,53,225,49,90,210,19,48,38,214,63,46,209,133,6,49,145,182,95,50,6,109,14,51,195,133,44,51,3,243,205,50,9,241,218,49,105,16,12,48,118,172,82,46,4,244,11,49,61,121,100,50,96,162,15,51,91,21,44,51,34,22,203,50,128,202,212,49,226,160,4,48,249,200,102,46,229,139,17,49,112,72,105,50,194,211,16,51,192,157,43,51,133,57,200,50,136,193,206,49,69,2,251,47,253,83,124,46,9,78,23,49,242,35,110,50,7,1,18,51,253,30,43,51,103,93,197,50,8,214,200,49,135,94,237,47,169,176,137,46,71,59,29,49,137,11,115,50,18,42,19,51,36,153,42,51,9,130,194,50,220,7,195,49,171,80,224,47,245,252,149,46,58,84,35,49,246,254,119,50,194,78,20,51,69,12,42,51,165,167,191,50,228,86,189,49,137,212,211,47,2,28,163,46,173,153,41,49,251,253,124,50,246,110,21,51,111,120,41,51,118,206,188,50,244,194,183,49,19,229,199,47,127,23,177,46,62,12,48,49,42,4,129,50,144,138,22,51,179,221,40,51,186,246,185,50,233,75,178,49,120,126,188,47,136,255,191,46,175,172,54,49,222,142,131,50,110,161,23,51,38,60,40,51,170,32,183,50,142,241,172,49,210,155,177,47,96,215,207,46,160,123,61,49,246,30,134,50,116,179,24,51,218,147,39,51,129,76,180,50,187,179,167,49,49,56,167,47,10,169,224,46,203,121,68,49,78,180,136,50,127,192,25,51,225,228,38,51,117,122,177,50,57,146,162,49,151,80,157,47,179,131,242,46,204,167,75,49,192,78,139,50,119,200,26,51,80,47,38,51,192,170,174,50,210,140,157,49,111,223,147,47,199,189,2,47,88,6,83,49,37,238,141,50,59,203,27,51,62,115,37,51,152,221,171,50,77,163,152,49,120,225,138,47,31,195,12,47,4,150,90,49,84,146,144,50,173,200,28,51,191,176,36,51,49,19,169,50,117,213,147,49,62,83,130,47,41,100,23,47,125,87,98,49,34,59,147,50,179,192,29,51,234,231,35,51,193,75,166,50,5,35,143,49,33,94,116,47,53,158,34,47,95,75,106,49,104,232,149,50,47,179,30,51,215,24,35,51,124,135,163,50,194,139,138,49,7,229,100,47,163,125,46,47,65,114,114,49,246,153,152,50,4,160,31,51,158,67,34,51,148,198,160,50,104,15,134,49,10,51,86,47,157,6,59,47,189,204,122,49,162,79,155,50,28,135,32,51,87,104,33,51,59,9,158,50,180,173,129,49,118,65,72,47,231,96,11,46,194,239,147,48,155,152,34,50,21,86,248,50,12,160,47,51,34,148,245,50,173,165,30,50,163,68,141,48,162,136,43,45,44,216,154,48,55,154,38,50,27,20,251,50,107,152,47,51,136,206,242,50,125,193,26,50,147,213,134,48,252,244,69,45,111,255,161,48,107,170,42,50,240,205,253,50,44,137,47,51,140,5,240,50,27,236,22,50,235,160,128,48,147,242,98,45,252,102,169,48,34,201,46,50,167,65,0,51,78,114,47,51,116,57,237,50,147,37,19,50,233,74,117,48,16,84,129,45,51,16,177,48,67,246,50,50,248,153,1,51,214,83,47,51,133,106,234,50,242,109,15,50,87,195,105,48,121,137,146,45,142,252,184,48,179,49,55,50,198,239,2,51,199,45,47,51,2,153,231,50,64,197,11,50,134,168,94,48,77,64,165,45,147,45,193,48,86,123,59,50,241,66,4,51,37,0,47,51,48,197,228,50,130,43,8,50,81,247,83,48,254,150,185,45,166,164,201,48,11,211,63,50,85,147,5,51,246,202,46,51,83,239,225,50,189,160,4,50,120,173,73,48,228,204,207,45,79,99,210,48,175,56,68,50,207,224,6,51,64,142,46,51,176,23,223,50,247,36,1,50,224,199,63,48,211,237,231,45,230,106,219,48,30,172,72,50,63,43,8,51,11,74,46,51,135,62,220,50,88,112,251,49,86,68,54,48,170,252,0,46,14,189,228,48,51,45,77,50,127,114,9,51,94,254,45,51,28,100,217,50,183,180,244,49,102,31,45,48,79,237,14,46,26,91,238,48,195,187,81,50,112,182,10,51,67,171,45,51,179,136,214,50,5,23,238,49,123,87,36,48,99,3,30,46,153,70,248,48,161,87,86,50,237,246,11,51,196,80,45,51,138,172,211,50,55,151,231,49,25,233,27,48,248,128,46,46,120,64,1,49,161,0,91,50,213,51,13,51,235,238,44,51,229,207,208,50,63,53,225,49,90,210,19,48,38,214,63,46,209,133,6,49,145,182,95,50,6,109,14,51,195,133,44,51,3,243,205,50,9,241,218,49,105,16,12,48,118,172,82,46,4,244,11,49,61,121,100,50,96,162,15,51,91,21,44,51,34,22,203,50,128,202,212,49,226,160,4,48,249,200,102,46,229,139,17,49,112,72,105,50,194,211,16,51,192,157,43,51,133,57,200,50,136,193,206,49,69,2,251,47,253,83,124,46,9,78,23,49,242,35,110,50,7,1,18,51,253,30,43,51,103,93,197,50,8,214,200,49,135,94,237,47,169,176,137,46,71,59,29,49,137,11,115,50,18,42,19,51,36,153,42,51,9,130,194,50,220,7,195,49,171,80,224,47,245,252,149,46,58,84,35,49,246,254,119,50,194,78,20,51,69,12,42,51,165,167,191,50,228,86,189,49,137,212,211,47,2,28,163,46,173,153,41,49,251,253,124,50,246,110,21,51,111,120,41,51,118,206,188,50,244,194,183,49,19,229,199,47,127,23,177,46,62,12,48,49,42,4,129,50,144,138,22,51,179,221,40,51,186,246,185,50,233,75,178,49,120,126,188,47,136,255,191,46,175,172,54,49,222,142,131,50,110,161,23,51,38,60,40,51,170,32,183,50,142,241,172,49,210,155,177,47,96,215,207,46,160,123,61,49,246,30,134,50,116,179,24,51,218,147,39,51,129,76,180,50,187,179,167,49,49,56,167,47,10,169,224,46,203,121,68,49,78,180,136,50,127,192,25,51,225,228,38,51,117,122,177,50,57,146,162,49,151,80,157,47,179,131,242,46,204,167,75,49,192,78,139,50,119,200,26,51,80,47,38,51,192,170,174,50,210,140,157,49,111,223,147,47,199,189,2,47,88,6,83,49,37,238,141,50,59,203,27,51,62,115,37,51,152,221,171,50,77,163,152,49,120,225,138,47,31,195,12,47,4,150,90,49,84,146,144,50,173,200,28,51,191,176,36,51,49,19,169,50,117,213,147,49,62,83,130,47,41,100,23,47,125,87,98,49,34,59,147,50,179,192,29,51,234,231,35,51,193,75,166,50,5,35,143,49,33,94,116,47,53,158,34,47,95,75,106,49,104,232,149,50,47,179,30,51,215,24,35,51,124,135,163,50,194,139,138,49,7,229,100,47,163,125,46,47,65,114,114,49,246,153,152,50,4,160,31,51,158,67,34,51,148,198,160,50,104,15,134,49,10,51,86,47,157,6,59,47,189,204,122,49,162,79,155,50,28,135,32,51,87,104,33,51,59,9,158,50,180,173,129,49,118,65,72,47,211,96,139,46,134,152,162,50,244,159,175,51,152,165,158,50,135,136,171,45,33,154,166,50,83,152,175,51,104,193,154,50,225,244,197,45,84,170,170,50,20,137,175,51,7,236,150,50,118,242,226,45,11,201,174,50,55,114,175,51,128,37,147,50,0,84,1,46,44,246,178,50,190,83,175,51,222,109,143,50,102,137,18,46,156,49,183,50,175,45,175,51,44,197,139,50,55,64,37,46,62,123,187,50,13,0,175,51,111,43,136,50,229,150,57,46,241,210,191,50,222,202,174,51,173,160,132,50,200,204,79,46,149,56,196,50,41,142,174,51,229,36,129,50,181,237,103,46,2,172,200,50,243,73,174,51,53,112,123,50,153,252,128,46,23,45,205,50,70,254,173,51,149,180,116,50,60,237,142,46,166,187,209,50,43,171,173,51,231,22,110,50,78,3,158,46,132,87,214,50,172,80,173,51,24,151,103,50,223,128,174,46,132,0,219,50,212,238,172,51,32,53,97,50,13,214,191,46,115,182,223,50,172,133,172,51,236,240,90,50,90,172,210,46,31,121,228,50,68,21,172,51,99,202,84,50,217,200,230,46,81,72,233,50,168,157,171,51,108,193,78,50,217,83,252,46,210,35,238,50,230,30,171,51,237,213,72,50,151,176,9,47,105,11,243,50,13,153,170,51,193,7,67,50,225,252,21,47,213,254,247,50,45,12,170,51,204,86,61,50,235,27,35,47,214,253,252,50,87,120,169,51,220,194,55,50,103,23,49,47,23,4,1,51,157,221,168,51,210,75,50,50,111,255,63,47,203,142,3,51,16,60,168,51,119,241,44,50,68,215,79,47,228,30,6,51,194,147,167,51,165,179,39,50,236,168,96,47,60,180,8,51,202,228,166,51,35,146,34,50,147,131,114,47,173,78,11,51,57,47,166,51,189,140,29,50,182,189,130,47,17,238,13,51,39,115,165,51,56,163,24,50,13,195,140,47,63,146,16,51,168,176,164,51,96,213,19,50,21,100,151,47,14,59,19,51,212,231,163,51,241,34,15,50,32,158,162,47,83,232,21,51,193,24,163,51,175,139,10,50,139,125,174,47,225,153,24,51,136,67,162,51,85,15,6,50,132,6,187,47,140,79,27,51,65,104,161,51,161,173,1,50,91,65,200,47,37,9,30,51,6,135,160,51,154,204,250,49,238,50,214,47,127,198,32,51,239,159,159,51,32,114,242,49,231,228,228,47,102,135,35,51,24,179,158,51,64,75,234,49,255,93,244,47,170,75,38,51,157,192,157,51,96,87,226,49,45,83,2,48,25,19,41,51,152,200,156,51,230,149,218,49,101,225,10,48,128,221,43,51,37,203,155,51,59,6,211,49,91,223,19,48,168,170,46,51,99,200,154,51,176,167,203,49,129,80,29,48,93,122,49,51,107,192,153,51,176,121,196,49,25,56,39,48,105,76,52,51,94,179,152,51,135,123,189,49,185,155,49,48,146,32,55,51,90,161,151,51,150,172,182,49,95,126,60,48,160,246,57,51,123,138,150,51,39,12,176,49,248,228,71,48,93,206,60,51,226,110,149,51,150,153,169,49,109,212,83,48,138,167,63,51,174,78,148,51,35,84,163,49,141,80,96,48,238,129,66,51,253,41,147,51,49,59,157,49,102,94,109,48,77,93,69,51,243,0,146,51,246,77,151,49,33,2,123,48,105,57,72,51,173,211,144,51,209,139,145,49,207,160,132,48,7,22,75,51,77,162,143,51,242,243,139,49,85,16,140,48,230,242,77,51,244,108,142,51,191,133,134,49,70,210,147,48,199,207,80,51,194,51,141,51,101,64,129,49,4,233,155,48,109,172,83,51,217,246,139,51,119,70,120,49,101,87,164,48,149,136,86,51,92,182,138,51,249,90,110,49,78,31,173,48,0,100,89,51,109,114,137,51,240,188,100,49,61,68,182,48,104,62,92,51,45,43,136,51,199,106,91,49,198,199,191,48,145,23,95,51,190,224,134,51,50,99,82,49,93,173,201,48,52,239,97,51,67,147,133,51,140,164,73,49,53,247,211,48,18,197,100,51,223,66,132,51,123,45,65,49,103,168,222,48,227,152,103,51,181,239,130,51,116,252,56,49,54,195,233,48,100,106,106,51,230,153,129,51,27,16,49,49,202,74,245,48,84,57,109,51,150,65,128,51,229,102,41,49,218,160,0,49,108,5,112,51,207,205,125,51,88,255,33,49,128,213,6,49,102,206,114,51,249,19,123,51,23,216,26,49,143,68,13,49,1,148,117,51,243,85,120,51,174,239,19,49,5,0,0,0,43,1,0,0,14,0,0,0,8,0,0,0,82,0,0,0,61,1,0,0,255,255,255,255,0,0,0,0,214,0,72,0,42,0,40,0,18,0,4,0,4,0,2,0,2,0,2,0,2,0,2,0,1,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,113,0,68,0,49,0,42,0,40,0,32,0,27,0,15,0,10,0,5,0,3,0,3,0,3,0,3,0,2,0,2,0,2,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,95,1,122,0,76,0,61,0,41,0,42,0,24,0,30,0,22,0,19,0,11,0,9,0,10,0,8,0,5,0,5,0,4,0,5,0,5,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,2,0,2,0,3,0,2,0,2,0,2,0,3,0,3,0,2,0,2,0,2,0,3,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,1,0,2,0,2,0,1,0,2,0,1,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,2,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,181,0,110,0,78,0,63,0,61,0,62,0,60,0,61,0,33,0,41,0,41,0,19,0,17,0,19,0,12,0,11,0,9,0,11,0,10,0,6,0,8,0,7,0,6,0,4,0,5,0,5,0,4,0,4,0,3,0,4,0,3,0,5,0,3,0,4,0,3,0,3,0,3,0,3,0,3,0,3,0,2,0,2,0,4,0,2,0,3,0,2,0,3,0,3,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,3,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,2,0,1,0,2,0,2,0,2,0,2,0,1,0,2,0,1,0,1,0,1,0,2,0,2,0,1,0,2,0,1,0,2,0,2,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1000600);
/* memory initializer */ allocate([1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,55,1,91,0,61,0,28,0,10,0,6,0,5,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,61,1,92,0,62,0,60,0,19,0,17,0,10,0,7,0,6,0,5,0,5,0,3,0,3,0,3,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,1,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,4,10,5,6,4,40,40,40,40,76,0,0,0,0,0,0,4,10,5,6,4,40,40,40,40,76,0,0,0,0,0,0,0,0,1,0,160,0,167,0,168,0,169,0,175,0,176,0,178,0,183,0,184,0,198,0,215,0,216,0,230,0,247,0,248,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,46,1,47,1,48,1,49,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,65,1,66,1,67,1,68,1,69,1,70,1,71,1,72,1,74,1,75,1,76,1,77,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,123,1,124,1,125,1,126,1,146,1,160,1,161,1,175,1,176,1,24,2,25,2,26,2,27,2,198,2,199,2,216,2,217,2,219,2,220,2,221,2,0,3,1,3,3,3,9,3,35,3,122,3,132,3,133,3,134,3,136,3,137,3,138,3,140,3,142,3,143,3,144,3,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,170,3,171,3,172,3,173,3,174,3,175,3,176,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,194,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,202,3,203,3,204,3,205,3,206,3,1,4,2,4,3,4,4,4,5,4,6,4,7,4,8,4,9,4,10,4,11,4,12,4,14,4,15,4,16,4,17,4,18,4,19,4,20,4,21,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,4,50,4,51,4,52,4,53,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,81,4,82,4,83,4,84,4,85,4,86,4,87,4,88,4,89,4,90,4,91,4,92,4,94,4,95,4,144,4,145,4,176,5,177,5,178,5,179,5,180,5,181,5,182,5,183,5,184,5,185,5,187,5,188,5,189,5,190,5,191,5,192,5,193,5,194,5,195,5,208,5,209,5,210,5,211,5,212,5,213,5,214,5,215,5,216,5,217,5,218,5,219,5,220,5,221,5,222,5,223,5,224,5,225,5,226,5,227,5,228,5,229,5,230,5,231,5,232,5,233,5,234,5,240,5,241,5,242,5,243,5,244,5,12,6,27,6,31,6,33,6,34,6,35,6,36,6,37,6,38,6,39,6,40,6,41,6,42,6,43,6,44,6,45,6,46,6,47,6,48,6,49,6,50,6,51,6,52,6,53,6,54,6,55,6,56,6,57,6,58,6,64,6,65,6,66,6,67,6,68,6,69,6,70,6,71,6,72,6,73,6,74,6,75,6,76,6,77,6,78,6,79,6,80,6,81,6,82,6,121,6,126,6,134,6,136,6,145,6,152,6,169,6,175,6,186,6,190,6,193,6,210,6,1,14,2,14,3,14,4,14,5,14,6,14,7,14,8,14,9,14,10,14,11,14,12,14,13,14,14,14,15,14,16,14,17,14,18,14,19,14,20,14,21,14,22,14,23,14,24,14,25,14,26,14,27,14,28,14,29,14,30,14,31,14,32,14,33,14,34,14,35,14,36,14,37,14,38,14,39,14,40,14,41,14,42,14,43,14,44,14,45,14,46,14,47,14,48,14,49,14,50,14,51,14,52,14,53,14,54,14,55,14,56,14,57,14,58,14,63,14,64,14,65,14,66,14,67,14,68,14,69,14,70,14,71,14,72,14,73,14,74,14,75,14,76,14,77,14,78,14,79,14,80,14,81,14,82,14,83,14,84,14,85,14,86,14,87,14,88,14,89,14,90,14,91,14,2,30,3,30,10,30,11,30,30,30,31,30,64,30,65,30,86,30,87,30,96,30,97,30,106,30,107,30,128,30,129,30,130,30,131,30,132,30,133,30,242,30,243,30,12,32,13,32,14,32,15,32,19,32,20,32,21,32,23,32,24,32,25,32,26,32,28,32,29,32,30,32,32,32,33,32,34,32,38,32,48,32,57,32,58,32,170,32,171,32,172,32,175,32,22,33,34,33,25,34,26,34,72,34,100,34,101,34,32,35,33,35,0,37,2,37,12,37,16,37,20,37,24,37,28,37,36,37,44,37,52,37,60,37,80,37,81,37,82,37,83,37,84,37,85,37,86,37,87,37,88,37,89,37,90,37,91,37,92,37,93,37,94,37,95,37,96,37,97,37,98,37,99,37,100,37,101,37,102,37,103,37,104,37,105,37,106,37,107,37,108,37,128,37,132,37,136,37,140,37,144,37,145,37,146,37,147,37,160,37,0,0,108,0,101,0,103,0,97,0,99,0,121,0,95,0,97,0,116,0,116,0,114,0,105,0,98,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,17,0,1,0,17,0,17,17,17,0,17,17,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,255,6,255,255,7,6,7,5,255,2,255,6,5,6,0,4,4,5,5,3,3,7,7,17,17,33,33,0,0,1,1,0,0,0,0,6,6,3,3,11,11,15,15,21,21,37,37,2,2,3,3,1,1,1,1,4,6,4,6,3,11,3,11,17,17,33,33,0,2,0,2,0,1,0,1,4,5,6,3,3,7,11,15,17,21,33,37,0,1,2,3,0,0,1,1,255,255,255,255,85,85,17,17,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,85,85,85,85,85,85,85,85,17,17,17,17,17,17,17,17,32,70,234,172,131,130,158,215,216,208,175,69,244,98,151,122,241,121,140,11,166,96,77,53,238,122,176,0,222,28,78,88,35,246,125,218,147,205,115,21,53,213,13,98,121,141,249,71,0,48,12,60,3,51,15,63,32,16,44,28,35,19,47,31,8,56,4,52,11,59,7,55,40,24,36,20,43,27,39,23,2,50,14,62,1,49,13,61,34,18,46,30,33,17,45,29,10,58,6,54,9,57,5,53,42,26,38,22,41,25,37,21,64,40,32,0,112,0,0,0,176,125,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,48,92,0,0,0,0,0,216,48,92,0,0,0,0,0,232,48,92,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,0,4,7,10,0,0,0,0,0,248,48,92,0,0,0,0,0,0,0,228,1,248,1,0,0,228,1,20,0,184,0,0,0,97,97,114,0,248,1,97,98,107,0,249,1,97,99,101,0,2,0,97,99,104,0,3,0,97,100,97,0,4,0,97,100,121,0,5,0,97,102,97,0,6,0,97,102,104,0,7,0,97,102,114,0,251,1,97,105,110,0,9,0,97,107,97,0,252,1,97,107,107,0,11,0,97,108,98,0,246,1,97,108,101,0,13,0,97,108,103,0,14,0,97,108,116,0,15,0,97,109,104,0,253,1,97,110,103,0,17,0,97,110,112,0,18,0,97,112,97,0,19,0,97,114,97,0,255,1,97,114,99,0,21,0,97,114,103,0,254,1,97,114,109,0,236,1,97,114,110,0,24,0,97,114,112,0,25,0,97,114,116,0,26,0,97,114,119,0,27,0,97,115,109,0,0,2,97,115,116,0,29,0,97,116,104,0,30,0,97,117,115,0,31,0,97,118,97,0,1,2,97,118,101,0,250,1,97,119,97,0,34,0,97,121,109,0,2,2,97,122,101,0,3,2,98,97,100,0,37,0,98,97,105,0,38,0,98,97,107,0,4,2,98,97,108,0,40,0,98,97,109,0,9,2,98,97,110,0,42,0,98,97,113,0,233,1,98,97,115,0,44,0,98,97,116,0,45,0,98,101,106,0,46,0,98,101,108,0,5,2,98,101,109,0,48,0,98,101,110,0,10,2,98,101,114,0,50,0,98,104,111,0,51,0,98,105,104,0,7,2,98,105,107,0,53,0,98,105,110,0,54,0,98,105,115,0,8,2,98,108,97,0,56,0,98,110,116,0,57,0,98,111,115,0,13,2,98,114,97,0,59,0,98,114,101,0,12,2,98,116,107,0,61,0,98,117,97,0,62,0,98,117,103,0,63,0,98,117,108,0,6,2,98,117,114,0,242,1,98,121,110,0,66,0,99,97,100,0,67,0,99,97,105,0,68,0,99,97,114,0,69,0,99,97,116,0,14,2,99,97,117,0,71,0,99,101,98,0,72,0,99,101,108,0,73,0,99,104,97,0,16,2,99,104,98,0,75,0,99,104,101,0,15,2,99,104,103,0,77,0,99,104,105,0,247,1,99,104,107,0,79,0,99,104,109,0,80,0,99,104,110,0,81,0,99,104,111,0,82,0,99,104,112,0,83,0,99,104,114,0,84,0,99,104,117,0,20,2,99,104,118,0,21,2,99,104,121,0,87,0,99,109,99,0,88,0,99,111,112,0,89,0,99,111,114,0,81,2,99,111,115,0,17,2,99,112,101,0,92,0,99,112,102,0,93,0,99,112,112,0,94,0,99,114,101,0,18,2,99,114,104,0,96,0,99,114,112,0,97,0,99,115,98,0,98,0,99,117,115,0,99,0,99,122,101,0,229,1,100,97,107,0,101,0,100,97,110,0,23,2,100,97,114,0,103,0,100,97,121,0,104,0,100,101,108,0,105,0,100,101,110,0,106,0,100,103,114,0,107,0,100,105,110,0,108,0,100,105,118,0,25,2,100,111,105,0,110,0,100,114,97,0,111,0,100,115,98,0,112,0,100,117,97,0,113,0,100,117,109,0,114,0,100,117,116,0,243,1,100,121,117,0,116,0,100,122,111,0,26,2,101,102,105,0,118,0,101,103,121,0,119,0,101,107,97,0,120,0,101,108,120,0,121,0,101,110,103,0,29,2,101,110,109,0,123,0,101,112,111,0,30,2,101,115,116,0,32,2,101,119,101,0,27,2,101,119,111,0,127,0,102,97,110,0,128,0,102,97,111,0,38,2,102,97,116,0,130,0,102,105,106,0,37,2,102,105,108,0,132,0,102,105,110,0,36,2,102,105,117,0,134,0,102,111,110,0,135,0,102,114,101,0,235,1,102,114,109,0,137,0,102,114,111,0,138,0,102,114,114,0,139,0,102,114,115,0,140,0,102,114,121,0,40,2,102,117,108,0,35,2,102,117,114,0,143,0,103,97,97,0,144,0,103,97,121,0,145,0,103,98,97,0,146,0,103,101,109,0,147,0,103,101,111,0,238,1,103,101,114,0,231,1,103,101,122,0,150,0,103,105,108,0,151,0,103,108,97,0,42,2,103,108,101,0,41,2,103,108,103,0,43,2,103,108,118,0,46,2,103,109,104,0,156,0,103,111,104,0,157,0,103,111,110,0,158,0,103,111,114,0,159,0,103,111,116,0,160,0,103,114,98,0,161,0,103,114,99,0,162,0,103,114,101,0,232,1,103,114,110,0,44,2,103,115,119,0,165,0,103,117,106,0,45,2,103,119,105,0,167,0,104,97,105,0,168,0,104,97,116,0,52,2,104,97,117,0,47,2,104,97,119,0,171,0,104,101,98,0,48,2,104,101,114,0,55,2,104,105,108,0,174,0,104,105,109,0,175,0,104,105,110,0,49,2,104,105,116,0,177,0,104,109,110,0,178,0,104,109,111,0,50,2,104,114,118,0,51,2,104,115,98,0,181,0,104,117,110,0,53,2,104,117,112,0,183,0,105,98,97,0,184,0,105,98,111,0,59,2,105,99,101,0,237,1,105,100,111,0,62,2,105,105,105,0,60,2,105,106,111,0,189,0,105,107,117,0,65,2,105,108,101,0,58,2,105,108,111,0,192,0,105,110,97,0,56,2,105,110,99,0,194,0,105,110,100,0,57,2,105,110,101,0,196,0,105,110,104,0,197,0,105,112,107,0,61,2,105,114,97,0,199,0,105,114,111,0,200,0,105,116,97,0,64,2,106,97,118,0,67,2,106,98,111,0,203,0,106,112,110,0,66,2,106,112,114,0,205,0,106,114,98,0,206,0,107,97,97,0,207,0,107,97,98,0,208,0,107,97,99,0,209,0,107,97,108,0,73,2,107,97,109,0,211,0,107,97,110,0,75,2,107,97,114,0,213,0,107,97,115,0,78,2,107,97,117,0,77,2,107,97,119,0,216,0,107,97,122,0,72,2,107,98,100,0,218,0,107,104,97,0,219,0,107,104,105,0,220,0,107,104,109,0,74,2,107,104,111,0,222,0,107,105,107,0,70,2,107,105,110,0,128,2,107,105,114,0,82,2,107,109,98,0,226,0,107,111,107,0,227,0,107,111,109,0,80,2,107,111,110,0,69,2,107,111,114,0,76,2,107,111,115,0,231,0,107,112,101,0,232,0,107,114,99,0,233,0,107,114,108,0,234,0,107,114,111,0,235,0,107,114,117,0,236,0,107,117,97,0,71,2,107,117,109,0,238,0,107,117,114,0,79,2,107,117,116,0,240,0,108,97,100,0,241,0,108,97,104,0,242,0,108,97,109,0,243,0,108,97,111,0,88,2,108,97,116,0,83,2,108,97,118,0,91,2,108,101,122,0,247,0,108,105,109,0,86,2,108,105,110,0,87,2,108,105,116,0,89,2,108,111,108,0,251,0,108,111,122,0,252,0,108,116,122,0,84,2,108,117,97,0,254,0,108,117,98,0,90,2,108,117,103,0,85,2,108,117,105,0,1,1,108,117,110,0,2,1,108,117,111,0,3,1,108,117,115,0,4,1,109,97,99,0,239,1,109,97,100,0,6,1,109,97,103,0,7,1,109,97,104,0,93,2,109,97,105,0,9,1,109,97,107,0,10,1,109,97,108,0,96,2,109,97,110,0,12,1,109,97,111,0,240,1,109,97,112,0,14,1,109,97,114,0,98,2,109,97,115,0,16,1,109,97,121,0,241,1,109,100,102,0,18,1,109,100,114,0,19,1,109,101,110,0,20,1,109,103,97,0,21,1,109,105,99,0,22,1,109,105,110,0,23,1,109,105,115,0,24,1,109,107,104,0,25,1,109,108,103,0,92,2,109,108,116,0,100,2,109,110,99,0,28,1,109,110,105,0,29,1,109,110,111,0,30,1,109,111,104,0,31,1,109,111,110,0,97,2,109,111,115,0,33,1,109,117,108,0,34,1,109,117,110,0,35,1,109,117,115,0,36,1,109,119,108,0,37,1,109,119,114,0,38,1,109,121,110,0,39,1,109,121,118,0,40,1,110,97,104,0,41,1,110,97,105,0,42,1,110,97,112,0,43,1,110,97,117,0,102,2,110,97,118,0,111,2,110,98,108,0,110,2,110,100,101,0,104,2,110,100,111,0,106,2,110,100,115,0,49,1,110,101,112,0,105,2,110,101,119,0,51,1,110,105,97,0,52,1,110,105,99,0,53,1,110,105,117,0,54,1,110,110,111,0,108,2,110,111,98,0,103,2,110,111,103,0,57,1,110,111,110,0,58,1,110,111,114,0,109,2,110,113,111,0,60,1,110,115,111,0,61,1,110,117,98,0,62,1,110,119,99,0,63,1,110,121,97,0,112,2,110,121,109,0,65,1,110,121,110,0,66,1,110,121,111,0,67,1,110,122,105,0,68,1,111,99,105,0,113,2,111,106,105,0,114,2,111,114,105,0,116,2,111,114,109,0,115,2,111,115,97,0,73,1,111,115,115,0,117,2,111,116,97,0,75,1,111,116,111,0,76,1,112,97,97,0,77,1,112,97,103,0,78,1,112,97,108,0,79,1,112,97,109,0,80,1,112,97,110,0,118,2,112,97,112,0,82,1,112,97,117,0,83,1,112,101,111,0,84,1,112,101,114,0,234,1,112,104,105,0,86,1,112,104,110,0,87,1,112,108,105,0,119,2,112,111,108,0,120,2,112,111,110,0,90,1,112,111,114,0,122,2,112,114,97,0,92,1,112,114,111,0,93,1,112,117,115,0,121,2,113,117,101,0,123,2,114,97,106,0,96,1,114,97,112,0,97,1,114,97,114,0,98,1,114,111,97,0,99,1,114,111,104,0,124,2,114,111,109,0,101,1,114,117,109,0,244,1,114,117,110,0,125,2,114,117,112,0,104,1,114,117,115,0,127,2,115,97,100,0,106,1,115,97,103,0,133,2,115,97,104,0,108,1,115,97,105,0,109,1,115,97,108,0,110,1,115,97,109,0,111,1,115,97,110,0,129,2,115,97,115,0,113,1,115,97,116,0,114,1,115,99,110,0,115,1,115,99,111,0,116,1,115,101,108,0,117,1,115,101,109,0,118,1,115,103,97,0,119,1,115,103,110,0,120,1,115,104,110,0,121,1,115,105,100,0,122,1,115,105,110,0,134,2,115,105,111,0,124,1,115,105,116,0,125,1,115,108,97,0,126,1,115,108,111,0,245,1,115,108,118,0,136,2,115,109,97,0,129,1,115,109,101,0,132,2,115,109,105,0,131,1,115,109,106,0,132,1,115,109,110,0,133,1,115,109,111,0,137,2,115,109,115,0,135,1,115,110,97,0,138,2,115,110,100,0,131,2,115,110,107,0,138,1,115,111,103,0,139,1,115,111,109,0,139,2,115,111,110,0,141,1,115,111,116,0,143,2,115,112,97,0,31,2,115,114,100,0,130,2,115,114,110,0,145,1,115,114,112,0,141,2,115,114,114,0,147,1,115,115,97,0,148,1,115,115,119,0,142,2,115,117,107,0,150,1,115,117,110,0,144,2,115,117,115,0,152,1,115,117,120,0,153,1,115,119,97,0,146,2,115,119,101,0,145,2,115,121,99,0,156,1,115,121,114,0,157,1,116,97,104,0,160,2,116,97,105,0,159,1,116,97,109,0,147,2,116,97,116,0,158,2,116,101,108,0,148,2,116,101,109,0,163,1,116,101,114,0,164,1,116,101,116,0,165,1,116,103,107,0,149,2,116,103,108,0,153,2,116,104,97,0,150,2,116,105,98,0,228,1,116,105,103,0,170,1,116,105,114,0,151,2,116,105,118,0,172,1,116,107,108,0,173,1,116,108,104,0,174,1,116,108,105,0,175,1,116,109,104,0,176,1,116,111,103,0,177,1,116,111,110,0,155,2,116,112,105,0,179,1,116,115,105,0,180,1,116,115,110,0,154,2,116,115,111,0,157,2,116,117,107,0,152,2,116,117,109,0,184,1,116,117,112,0,185,1,116,117,114,0,156,2,116,117,116,0,187,1,116,118,108,0,188,1,116,119,105,0,159,2,116,121,118,0,190,1,117,100,109,0,191,1,117,103,97,0,192,1,117,105,103,0,161,2,117,107,114,0,162,2,117,109,98,0,195,1,117,110,100,0,196,1,117,114,100,0,163,2,117,122,98,0,164,2,118,97,105,0,199,1,118,101,110,0,165,2,118,105,101,0,166,2,118,111,108,0,167,2,118,111,116,0,203,1,119,97,107,0,204,1,119,97,108,0,205,1,119,97,114,0,206,1,119,97,115,0,207,1,119,101,108,0,230,1,119,101,110,0,209,1,119,108,110,0,168,2,119,111,108,0,169,2,120,97,108,0,212,1,120,104,111,0,170,2,121,97,111,0,214,1,121,97,112,0,215,1,121,105,100,0,171,2,121,111,114,0,172,2,121,112,107,0,218,1,122,97,112,0,219,1,122,98,108,0,220,1,122,101,110,0,221,1,122,104,97,0,173,2,122,110,100,0,223,1,122,117,108,0,175,2,122,117,110,0,225,1,122,120,120,0,226,1,122,122,97,0,227,1,98,111,100,0,11,2,99,101,115,0,19,2,99,121,109,0,22,2,100,101,117,0,24,2,101,108,108,0,28,2,101,117,115,0,33,2,102,97,115,0,34,2,102,114,97,0,39,2,104,121,101,0,54,2,105,115,108,0,63,2,107,97,116,0,68,2,109,107,100,0,95,2,109,114,105,0,94,2,109,115,97,0,99,2,109,121,97,0,101,2,110,108,100,0,107,2,114,111,110,0,126,2,115,108,107,0,135,2,115,113,105,0,140,2,122,104,111,0,174,2,97,97,0,0,0,0,97,98,0,0,1,0,97,101,0,0,33,0,97,102,0,0,8,0,97,107,0,0,10,0,97,109,0,0,16,0,97,110,0,0,22,0,97,114,0,0,20,0,97,115,0,0,28,0,97,118,0,0,32,0,97,121,0,0,35,0,97,122,0,0,36,0,98,97,0,0,39,0,98,101,0,0,47,0,98,103,0,0,64,0,98,104,0,0,52,0,98,105,0,0,55,0,98,109,0,0,41,0,98,110,0,0,49,0,98,111,0,0,169,1,98,114,0,0,60,0,98,115,0,0,58,0,99,97,0,0,70,0,99,101,0,0,76,0,99,104,0,0,74,0,99,111,0,0,91,0,99,114,0,0,95,0,99,115,0,0,100,0,99,117,0,0,85,0,99,118,0,0,86,0,99,121,0,0,208,1,100,97,0,0,102,0,100,101,0,0,149,0,100,118,0,0,109,0,100,122,0,0,117,0,101,101,0,0,126,0,101,108,0,0,163,0,101,110,0,0,122,0,101,111,0,0,124,0,101,115,0,0,143,1,101,116,0,0,125,0,101,117,0,0,43,0,102,97,0,0,85,1,102,102,0,0,142,0,102,105,0,0,133,0,102,106,0,0,131,0,102,111,0,0,129,0,102,114,0,0,136,0,102,121,0,0,141,0,103,97,0,0,153,0,103,100,0,0,152,0,103,108,0,0,154,0,103,110,0,0,164,0,103,117,0,0,166,0,103,118,0,0,155,0,104,97,0,0,170,0,104,101,0,0,172,0,104,105,0,0,176,0,104,111,0,0,179,0,104,114,0,0,180,0,104,116,0,0,169,0,104,117,0,0,182,0,104,121,0,0,23,0,104,122,0,0,173,0,105,97,0,0,193,0,105,100,0,0,195,0,105,101,0,0,191,0,105,103,0,0,185,0,105,105,0,0,188,0,105,107,0,0,198,0,105,111,0,0,187,0,105,115,0,0,186,0,105,116,0,0,201,0,105,117,0,0,190,0,106,97,0,0,204,0,106,118,0,0,202,0,107,97,0,0,148,0,107,103,0,0,229,0,107,105,0,0,223,0,107,106,0,0,237,0,107,107,0,0,217,0,107,108,0,0,210,0,107,109,0,0,221,0,107,110,0,0,212,0,107,111,0,0,230,0,107,114,0,0,215,0,107,115,0,0,214,0,107,117,0,0,239,0,107,118,0,0,228,0,107,119,0,0,90,0,107,121,0,0,225,0,108,97,0,0,245,0,108,98,0,0,253,0,108,103,0,0,0,1,108,105,0,0,248,0,108,110,0,0,249,0,108,111,0,0,244,0,108,116,0,0,250,0,108,117,0,0,255,0,108,118,0,0,246,0,109,103,0,0,26,1,109,104,0,0,8,1,109,105,0,0,13,1,109,107,0,0,5,1,109,108,0,0,11,1,109,110,0,0,32,1,109,114,0,0,15,1,109,115,0,0,17,1,109,116,0,0,27,1,109,121,0,0,65,0,110,97,0,0,44,1,110,98,0,0,56,1,110,100,0,0,47,1,110,101,0,0,50,1,110,103,0,0,48,1,110,108,0,0,115,0,110,110,0,0,55,1,110,111,0,0,59,1,110,114,0,0,46,1,110,118,0,0,45,1,110,121,0,0,64,1,111,99,0,0,69,1,111,106,0,0,70,1,111,109,0,0,72,1,111,114,0,0,71,1,111,115,0,0,74,1,112,97,0,0,81,1,112,105,0,0,88,1,112,108,0,0,89,1,112,115,0,0,94,1,112,116,0,0,91,1,113,117,0,0,95,1,114,109,0,0,100,1,114,110,0,0,103,1,114,111,0,0,102,1,114,117,0,0,105,1,114,119,0,0,224,0,115,97,0,0,112,1,115,99,0,0,144,1,115,100,0,0,137,1,115,101,0,0,130,1,115,103,0,0,107,1,115,105,0,0,123,1,115,107,0,0,127,1,115,108,0,0,128,1,115,109,0,0,134,1,115,110,0,0,136,1,115,111,0,0,140,1,115,113,0,0,12,0,115,114,0,0,146,1,115,115,0,0,149,1,115,116,0,0,142,1,115,117,0,0,151,1,115,118,0,0,155,1,115,119,0,0,154,1,116,97,0,0,160,1,116,101,0,0,162,1,116,103,0,0,166,1,116,104,0,0,168,1,116,105,0,0,171,1,116,107,0,0,183,1,116,108,0,0,167,1,116,110,0,0,181,1,116,111,0,0,178,1,116,114,0,0,186,1,116,115,0,0,182,1,116,116,0,0,161,1,116,119,0,0,189,1,116,121,0,0,158,1,117,103,0,0,193,1,117,107,0,0,194,1,117,114,0,0,197,1,117,122,0,0,198,1,118,101,0,0,200,1,118,105,0,0,201,1,118,111,0,0,202,1,119,97,0,0,210,1,119,111,0,0,211,1,120,104,0,0,213,1,121,105,0,0,216,1,121,111,0,0,217,1,122,97,0,0,222,1,122,104,0,0,78,0,122,117,0,0,224,1,0,0,0,0,0,0,0,0,1,2,3,5,8,13,21,0,254,255,255,255,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,1,0,0,0,0,1,1,0,0,2,2,0,1,2,2,1,0,3,3,0,1,3,3,1,2,3,3,2,0,48,1,48,2,48,183,0,37,32,38,32,168,0,3,48,173,0,21,32,37,34,60,255,60,34,24,32,25,32,28,32,29,32,20,48,21,48,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,16,48,17,48,177,0,215,0,247,0,96,34,100,34,101,34,30,34,52,34,176,0,50,32,51,32,3,33,43,33,224,255,225,255,229,255,66,38,64,38,32,34,165,34,18,35,2,34,7,34,97,34,82,34,167,0,59,32,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,189,37,188,37,146,33,144,33,145,33,147,33,148,33,19,48,106,34,107,34,26,34,61,34,29,34,53,34,43,34,44,34,8,34,11,34,134,34,135,34,130,34,131,34,42,34,41,34,39,34,40,34,226,255,210,33,212,33,0,34,3,34,180,0,94,255,199,2,216,2,221,2,218,2,217,2,184,0,219,2,161,0,191,0,208,2,46,34,17,34,15,34,164,0,9,33,48,32,193,37,192,37,183,37,182,37,100,38,96,38,97,38,101,38,103,38,99,38,153,34,200,37,163,37,208,37,209,37,146,37,164,37,165,37,168,37,167,37,166,37,169,37,104,38,15,38,14,38,28,38,30,38,182,0,32,32,33,32,149,33,151,33,153,33,150,33,152,33,109,38,105,38,106,38,108,38,127,50,28,50,22,33,199,51,34,33,194,51,216,51,33,33,172,32,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,2,255,3,255,4,255,5,255,6,255,7,255,8,255,9,255,10,255,11,255,12,255,13,255,14,255,15,255,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,26,255,27,255,28,255,29,255,30,255,31,255,32,255,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,59,255,230,255,61,255,62,255,63,255,64,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,91,255,92,255,93,255,227,255,49,49,50,49,51,49,52,49,53,49,54,49,55,49,56,49,57,49,58,49,59,49,60,49,61,49,62,49,63,49,64,49,65,49,66,49,67,49,68,49,69,49,70,49,71,49,72,49,73,49,74,49,75,49,76,49,77,49,78,49,79,49,80,49,81,49,82,49,83,49,84,49,85,49,86,49,87,49,88,49,89,49,90,49,91,49,92,49,93,49,94,49,95,49,96,49,97,49,98,49,99,49,100,49,101,49,102,49,103,49,104,49,105,49,106,49,107,49,108,49,109,49,110,49,111,49,112,49,113,49,114,49,115,49,116,49,117,49,118,49,119,49,120,49,121,49,122,49,123,49,124,49,125,49,126,49,127,49,128,49,129,49,130,49,131,49,132,49,133,49,134,49,135,49,136,49,137,49,138,49,139,49,140,49,141,49,142,49,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,0,0,0,0,0,0,0,0,0,0,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,37,12,37,16,37,24,37,20,37,28,37,44,37,36,37,52,37,60,37,1,37,3,37,15,37,19,37,27,37,23,37,35,37,51,37,43,37,59,37,75,37,32,37,47,37,40,37,55,37,63,37,29,37,48,37,37,37,56,37,66,37,18,37,17,37,26,37,25,37,22,37,21,37,14,37,13,37,30,37,31,37,33,37,34,37,38,37,39,37,41,37,42,37,45,37,46,37,49,37,50,37,53,37,54,37,57,37,58,37,61,37,62,37,64,37,65,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,51,150,51,151,51,19,33,152,51,196,51,163,51,164,51,165,51,166,51,153,51,154,51,155,51,156,51,157,51,158,51,159,51,160,51,161,51,162,51,202,51,141,51,142,51,143,51,207,51,136,51,137,51,200,51,167,51,168,51,176,51,177,51,178,51,179,51,180,51,181,51,182,51,183,51,184,51,185,51,128,51,129,51,130,51,131,51,132,51,186,51,187,51,188,51,189,51,190,51,191,51,144,51,145,51,146,51,147,51,148,51,38,33,192,51,193,51,138,51,139,51,140,51,214,51,197,51,173,51,174,51,175,51,219,51,169,51,170,51,171,51,172,51,221,51,208,51,211,51,195,51,201,51,220,51,198,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,0,208,0,170,0,38,1,0,0,50,1,0,0,63,1,65,1,216,0,82,1,186,0,222,0,102,1,74,1,0,0,96,50,97,50,98,50,99,50,100,50,101,50,102,50,103,50,104,50,105,50,106,50,107,50,108,50,109,50,110,50,111,50,112,50,113,50,114,50,115,50,116,50,117,50,118,50,119,50,120,50,121,50,122,50,123,50,208,36,209,36,210,36,211,36,212,36,213,36,214,36,215,36,216,36,217,36,218,36,219,36,220,36,221,36,222,36,223,36,224,36,225,36,226,36,227,36,228,36,229,36,230,36,231,36,232,36,233,36,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,106,36,107,36,108,36,109,36,110,36,189,0,83,33,84,33,188,0,190,0,91,33,92,33,93,33,94,33,230,0,17,1,240,0,39,1,49,1,51,1,56,1,64,1,66,1,248,0,83,1,223,0,254,0,103,1,75,1,73,1,0,50,1,50,2,50,3,50,4,50,5,50,6,50,7,50,8,50,9,50,10,50,11,50,12,50,13,50,14,50,15,50,16,50,17,50,18,50,19,50,20,50,21,50,22,50,23,50,24,50,25,50,26,50,27,50,156,36,157,36,158,36,159,36,160,36,161,36,162,36,163,36,164,36,165,36,166,36,167,36,168,36,169,36,170,36,171,36,172,36,173,36,174,36,175,36,176,36,177,36,178,36,179,36,180,36,181,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,126,36,127,36,128,36,129,36,130,36,185,0,178,0,179,0,116,32,127,32,129,32,130,32,131,32,132,32,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,1,172,4,172,7,172,8,172,9,172,10,172,16,172,17,172,18,172,19,172,20,172,21,172,22,172,23,172,25,172,26,172,27,172,28,172,29,172,32,172,36,172,44,172,45,172,47,172,48,172,49,172,56,172,57,172,60,172,64,172,75,172,77,172,84,172,88,172,92,172,112,172,113,172,116,172,119,172,120,172,122,172,128,172,129,172,131,172,132,172,133,172,134,172,137,172,138,172,139,172,140,172,144,172,148,172,156,172,157,172,159,172,160,172,161,172,168,172,169,172,170,172,172,172,175,172,176,172,184,172,185,172,187,172,188,172,189,172,193,172,196,172,200,172,204,172,213,172,215,172,224,172,225,172,228,172,231,172,232,172,234,172,236,172,239,172,240,172,241,172,243,172,245,172,246,172,252,172,253,172,0,173,4,173,6,173,12,173,13,173,15,173,17,173,24,173,28,173,32,173,41,173,44,173,45,173,52,173,53,173,56,173,60,173,68,173,69,173,71,173,73,173,80,173,84,173,88,173,97,173,99,173,108,173,109,173,112,173,115,173,116,173,117,173,118,173,123,173,124,173,125,173,127,173,129,173,130,173,136,173,137,173,140,173,144,173,156,173,157,173,164,173,183,173,192,173,193,173,196,173,200,173,208,173,209,173,211,173,220,173,224,173,228,173,248,173,249,173,252,173,255,173,0,174,1,174,8,174,9,174,11,174,13,174,20,174,48,174,49,174,52,174,55,174,56,174,58,174,64,174,65,174,67,174,69,174,70,174,74,174,76,174,77,174,78,174,80,174,84,174,86,174,92,174,93,174,95,174,96,174,97,174,101,174,104,174,105,174,108,174,112,174,120,174,121,174,123,174,124,174,125,174,132,174,133,174,140,174,188,174,189,174,190,174,192,174,196,174,204,174,205,174,207,174,208,174,209,174,216,174,217,174,220,174,232,174,235,174,237,174,244,174,248,174,252,174,7,175,8,175,13,175,16,175,44,175,45,175,48,175,50,175,52,175,60,175,61,175,63,175,65,175,66,175,67,175,72,175,73,175,80,175,92,175,93,175,100,175,101,175,121,175,128,175,132,175,136,175,144,175,145,175,149,175,156,175,184,175,185,175,188,175,192,175,199,175,200,175,201,175,203,175,205,175,206,175,212,175,220,175,232,175,233,175,240,175,241,175,244,175,248,175,0,176,1,176,4,176,12,176,16,176,20,176,28,176,29,176,40,176,68,176,69,176,72,176,74,176,76,176,78,176,83,176,84,176,85,176,87,176,89,176,93,176,124,176,125,176,128,176,132,176,140,176,141,176,143,176,145,176,152,176,153,176,154,176,156,176,159,176,160,176,161,176,162,176,168,176,169,176,171,176,172,176,173,176,174,176,175,176,177,176,179,176,180,176,181,176,184,176,188,176,196,176,197,176,199,176,200,176,201,176,208,176,209,176,212,176,216,176,224,176,229,176,8,177,9,177,11,177,12,177,16,177,18,177,19,177,24,177,25,177,27,177,28,177,29,177,35,177,36,177,37,177,40,177,44,177,52,177,53,177,55,177,56,177,57,177,64,177,65,177,68,177,72,177,80,177,81,177,84,177,85,177,88,177,92,177,96,177,120,177,121,177,124,177,128,177,130,177,136,177,137,177,139,177,141,177,146,177,147,177,148,177,152,177,156,177,168,177,204,177,208,177,212,177,220,177,221,177,223,177,232,177,233,177,236,177,240,177,249,177,251,177,253,177,4,178,5,178,8,178,11,178,12,178,20,178,21,178,23,178,25,178,32,178,52,178,60,178,88,178,92,178,96,178,104,178,105,178,116,178,117,178,124,178,132,178,133,178,137,178,144,178,145,178,148,178,152,178,153,178,154,178,160,178,161,178,163,178,165,178,166,178,170,178,172,178,176,178,180,178,200,178,201,178,204,178,208,178,210,178,216,178,217,178,219,178,221,178,226,178,228,178,229,178,230,178,232,178,235,178,236,178,237,178,238,178,239,178,243,178,244,178,245,178,247,178,248,178,249,178,250,178,251,178,255,178,0,179,1,179,4,179,8,179,16,179,17,179,19,179,20,179,21,179,28,179,84,179,85,179,86,179,88,179,91,179,92,179,94,179,95,179,100,179,101,179,103,179,105,179,107,179,110,179,112,179,113,179,116,179,120,179,128,179,129,179,131,179,132,179,133,179,140,179,144,179,148,179,160,179,161,179,168,179,172,179,196,179,197,179,200,179,203,179,204,179,206,179,208,179,212,179,213,179,215,179,217,179,219,179,221,179,224,179,228,179,232,179,252,179,16,180,24,180,28,180], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1010840);
/* memory initializer */ allocate([32,180,40,180,41,180,43,180,52,180,80,180,81,180,84,180,88,180,96,180,97,180,99,180,101,180,108,180,128,180,136,180,157,180,164,180,168,180,172,180,181,180,183,180,185,180,192,180,196,180,200,180,208,180,213,180,220,180,221,180,224,180,227,180,228,180,230,180,236,180,237,180,239,180,241,180,248,180,20,181,21,181,24,181,27,181,28,181,36,181,37,181,39,181,40,181,41,181,42,181,48,181,49,181,52,181,56,181,64,181,65,181,67,181,68,181,69,181,75,181,76,181,77,181,80,181,84,181,92,181,93,181,95,181,96,181,97,181,160,181,161,181,164,181,168,181,170,181,171,181,176,181,177,181,179,181,180,181,181,181,187,181,188,181,189,181,192,181,196,181,204,181,205,181,207,181,208,181,209,181,216,181,236,181,16,182,17,182,20,182,24,182,37,182,44,182,52,182,72,182,100,182,104,182,156,182,157,182,160,182,164,182,171,182,172,182,177,182,212,182,240,182,244,182,248,182,0,183,1,183,5,183,40,183,41,183,44,183,47,183,48,183,56,183,57,183,59,183,68,183,72,183,76,183,84,183,85,183,96,183,100,183,104,183,112,183,113,183,115,183,117,183,124,183,125,183,128,183,132,183,140,183,141,183,143,183,144,183,145,183,146,183,150,183,151,183,152,183,153,183,156,183,160,183,168,183,169,183,171,183,172,183,173,183,180,183,181,183,184,183,199,183,201,183,236,183,237,183,240,183,244,183,252,183,253,183,255,183,0,184,1,184,7,184,8,184,9,184,12,184,16,184,24,184,25,184,27,184,29,184,36,184,37,184,40,184,44,184,52,184,53,184,55,184,56,184,57,184,64,184,68,184,81,184,83,184,92,184,93,184,96,184,100,184,108,184,109,184,111,184,113,184,120,184,124,184,141,184,168,184,176,184,180,184,184,184,192,184,193,184,195,184,197,184,204,184,208,184,212,184,221,184,223,184,225,184,232,184,233,184,236,184,240,184,248,184,249,184,251,184,253,184,4,185,24,185,32,185,60,185,61,185,64,185,68,185,76,185,79,185,81,185,88,185,89,185,92,185,96,185,104,185,105,185,107,185,109,185,116,185,117,185,120,185,124,185,132,185,133,185,135,185,137,185,138,185,141,185,142,185,172,185,173,185,176,185,180,185,188,185,189,185,191,185,193,185,200,185,201,185,204,185,206,185,207,185,208,185,209,185,210,185,216,185,217,185,219,185,221,185,222,185,225,185,227,185,228,185,229,185,232,185,236,185,244,185,245,185,247,185,248,185,249,185,250,185,0,186,1,186,8,186,21,186,56,186,57,186,60,186,64,186,66,186,72,186,73,186,75,186,77,186,78,186,83,186,84,186,85,186,88,186,92,186,100,186,101,186,103,186,104,186,105,186,112,186,113,186,116,186,120,186,131,186,132,186,133,186,135,186,140,186,168,186,169,186,171,186,172,186,176,186,178,186,184,186,185,186,187,186,189,186,196,186,200,186,216,186,217,186,252,186,0,187,4,187,13,187,15,187,17,187,24,187,28,187,32,187,41,187,43,187,52,187,53,187,54,187,56,187,59,187,60,187,61,187,62,187,68,187,69,187,71,187,73,187,77,187,79,187,80,187,84,187,88,187,97,187,99,187,108,187,136,187,140,187,144,187,164,187,168,187,172,187,180,187,183,187,192,187,196,187,200,187,208,187,211,187,248,187,249,187,252,187,255,187,0,188,2,188,8,188,9,188,11,188,12,188,13,188,15,188,17,188,20,188,21,188,22,188,23,188,24,188,27,188,28,188,29,188,30,188,31,188,36,188,37,188,39,188,41,188,45,188,48,188,49,188,52,188,56,188,64,188,65,188,67,188,68,188,69,188,73,188,76,188,77,188,80,188,93,188,132,188,133,188,136,188,139,188,140,188,142,188,148,188,149,188,151,188,153,188,154,188,160,188,161,188,164,188,167,188,168,188,176,188,177,188,179,188,180,188,181,188,188,188,189,188,192,188,196,188,205,188,207,188,208,188,209,188,213,188,216,188,220,188,244,188,245,188,246,188,248,188,252,188,4,189,5,189,7,189,9,189,16,189,20,189,36,189,44,189,64,189,72,189,73,189,76,189,80,189,88,189,89,189,100,189,104,189,128,189,129,189,132,189,135,189,136,189,137,189,138,189,144,189,145,189,147,189,149,189,153,189,154,189,156,189,164,189,176,189,184,189,212,189,213,189,216,189,220,189,233,189,240,189,244,189,248,189,0,190,3,190,5,190,12,190,13,190,16,190,20,190,28,190,29,190,31,190,68,190,69,190,72,190,76,190,78,190,84,190,85,190,87,190,89,190,90,190,91,190,96,190,97,190,100,190,104,190,106,190,112,190,113,190,115,190,116,190,117,190,123,190,124,190,125,190,128,190,132,190,140,190,141,190,143,190,144,190,145,190,152,190,153,190,168,190,208,190,209,190,212,190,215,190,216,190,224,190,227,190,228,190,229,190,236,190,1,191,8,191,9,191,24,191,25,191,27,191,28,191,29,191,64,191,65,191,68,191,72,191,80,191,81,191,85,191,148,191,176,191,197,191,204,191,205,191,208,191,212,191,220,191,223,191,225,191,60,192,81,192,88,192,92,192,96,192,104,192,105,192,144,192,145,192,148,192,152,192,160,192,161,192,163,192,165,192,172,192,173,192,175,192,176,192,179,192,180,192,181,192,182,192,188,192,189,192,191,192,192,192,193,192,197,192,200,192,201,192,204,192,208,192,216,192,217,192,219,192,220,192,221,192,228,192,229,192,232,192,236,192,244,192,245,192,247,192,249,192,0,193,4,193,8,193,16,193,21,193,28,193,29,193,30,193,31,193,32,193,35,193,36,193,38,193,39,193,44,193,45,193,47,193,48,193,49,193,54,193,56,193,57,193,60,193,64,193,72,193,73,193,75,193,76,193,77,193,84,193,85,193,88,193,92,193,100,193,101,193,103,193,104,193,105,193,112,193,116,193,120,193,133,193,140,193,141,193,142,193,144,193,148,193,150,193,156,193,157,193,159,193,161,193,165,193,168,193,169,193,172,193,176,193,189,193,196,193,200,193,204,193,212,193,215,193,216,193,224,193,228,193,232,193,240,193,241,193,243,193,252,193,253,193,0,194,4,194,12,194,13,194,15,194,17,194,24,194,25,194,28,194,31,194,32,194,40,194,41,194,43,194,45,194,47,194,49,194,50,194,52,194,72,194,80,194,81,194,84,194,88,194,96,194,101,194,108,194,109,194,112,194,116,194,124,194,125,194,127,194,129,194,136,194,137,194,144,194,152,194,155,194,157,194,164,194,165,194,168,194,172,194,173,194,180,194,181,194,183,194,185,194,220,194,221,194,224,194,227,194,228,194,235,194,236,194,237,194,239,194,241,194,246,194,248,194,249,194,251,194,252,194,0,195,8,195,9,195,12,195,13,195,19,195,20,195,21,195,24,195,28,195,36,195,37,195,40,195,41,195,69,195,104,195,105,195,108,195,112,195,114,195,120,195,121,195,124,195,125,195,132,195,136,195,140,195,192,195,216,195,217,195,220,195,223,195,224,195,226,195,232,195,233,195,237,195,244,195,245,195,248,195,8,196,16,196,36,196,44,196,48,196,52,196,60,196,61,196,72,196,100,196,101,196,104,196,108,196,116,196,117,196,121,196,128,196,148,196,156,196,184,196,188,196,233,196,240,196,241,196,244,196,248,196,250,196,255,196,0,197,1,197,12,197,16,197,20,197,28,197,40,197,41,197,44,197,48,197,56,197,57,197,59,197,61,197,68,197,69,197,72,197,73,197,74,197,76,197,77,197,78,197,83,197,84,197,85,197,87,197,88,197,89,197,93,197,94,197,96,197,97,197,100,197,104,197,112,197,113,197,115,197,116,197,117,197,124,197,125,197,128,197,132,197,135,197,140,197,141,197,143,197,145,197,149,197,151,197,152,197,156,197,160,197,169,197,180,197,181,197,184,197,185,197,187,197,188,197,189,197,190,197,196,197,197,197,198,197,199,197,200,197,201,197,202,197,204,197,206,197,208,197,209,197,212,197,216,197,224,197,225,197,227,197,229,197,236,197,237,197,238,197,240,197,244,197,246,197,247,197,252,197,253,197,254,197,255,197,0,198,1,198,5,198,6,198,7,198,8,198,12,198,16,198,24,198,25,198,27,198,28,198,36,198,37,198,40,198,44,198,45,198,46,198,48,198,51,198,52,198,53,198,55,198,57,198,59,198,64,198,65,198,68,198,72,198,80,198,81,198,83,198,84,198,85,198,92,198,93,198,96,198,108,198,111,198,113,198,120,198,121,198,124,198,128,198,136,198,137,198,139,198,141,198,148,198,149,198,152,198,156,198,164,198,165,198,167,198,169,198,176,198,177,198,180,198,184,198,185,198,186,198,192,198,193,198,195,198,197,198,204,198,205,198,208,198,212,198,220,198,221,198,224,198,225,198,232,198,233,198,236,198,240,198,248,198,249,198,253,198,4,199,5,199,8,199,12,199,20,199,21,199,23,199,25,199,32,199,33,199,36,199,40,199,48,199,49,199,51,199,53,199,55,199,60,199,61,199,64,199,68,199,74,199,76,199,77,199,79,199,81,199,82,199,83,199,84,199,85,199,86,199,87,199,88,199,92,199,96,199,104,199,107,199,116,199,117,199,120,199,124,199,125,199,126,199,131,199,132,199,133,199,135,199,136,199,137,199,138,199,142,199,144,199,145,199,148,199,150,199,151,199,152,199,154,199,160,199,161,199,163,199,164,199,165,199,166,199,172,199,173,199,176,199,180,199,188,199,189,199,191,199,192,199,193,199,200,199,201,199,204,199,206,199,208,199,216,199,221,199,228,199,232,199,236,199,0,200,1,200,4,200,8,200,10,200,16,200,17,200,19,200,21,200,22,200,28,200,29,200,32,200,36,200,44,200,45,200,47,200,49,200,56,200,60,200,64,200,72,200,73,200,76,200,77,200,84,200,112,200,113,200,116,200,120,200,122,200,128,200,129,200,131,200,133,200,134,200,135,200,139,200,140,200,141,200,148,200,157,200,159,200,161,200,168,200,188,200,189,200,196,200,200,200,204,200,212,200,213,200,215,200,217,200,224,200,225,200,228,200,245,200,252,200,253,200,0,201,4,201,5,201,6,201,12,201,13,201,15,201,17,201,24,201,44,201,52,201,80,201,81,201,84,201,88,201,96,201,97,201,99,201,108,201,112,201,116,201,124,201,136,201,137,201,140,201,144,201,152,201,153,201,155,201,157,201,192,201,193,201,196,201,199,201,200,201,202,201,208,201,209,201,211,201,213,201,214,201,217,201,218,201,220,201,221,201,224,201,226,201,228,201,231,201,236,201,237,201,239,201,240,201,241,201,248,201,249,201,252,201,0,202,8,202,9,202,11,202,12,202,13,202,20,202,24,202,41,202,76,202,77,202,80,202,84,202,92,202,93,202,95,202,96,202,97,202,104,202,125,202,132,202,152,202,188,202,189,202,192,202,196,202,204,202,205,202,207,202,209,202,211,202,216,202,217,202,224,202,236,202,244,202,8,203,16,203,20,203,24,203,32,203,33,203,65,203,72,203,73,203,76,203,80,203,88,203,89,203,93,203,100,203,120,203,121,203,156,203,184,203,212,203,228,203,231,203,233,203,12,204,13,204,16,204,20,204,28,204,29,204,33,204,34,204,39,204,40,204,41,204,44,204,46,204,48,204,56,204,57,204,59,204,60,204,61,204,62,204,68,204,69,204,72,204,76,204,84,204,85,204,87,204,88,204,89,204,96,204,100,204,102,204,104,204,112,204,117,204,152,204,153,204,156,204,160,204,168,204,169,204,171,204,172,204,173,204,180,204,181,204,184,204,188,204,196,204,197,204,199,204,201,204,208,204,212,204,228,204,236,204,240,204,1,205,8,205,9,205,12,205,16,205,24,205,25,205,27,205,29,205,36,205,40,205,44,205,57,205,92,205,96,205,100,205,108,205,109,205,111,205,113,205,120,205,136,205,148,205,149,205,152,205,156,205,164,205,165,205,167,205,169,205,176,205,196,205,204,205,208,205,232,205,236,205,240,205,248,205,249,205,251,205,253,205,4,206,8,206,12,206,20,206,25,206,32,206,33,206,36,206,40,206,48,206,49,206,51,206,53,206,88,206,89,206,92,206,95,206,96,206,97,206,104,206,105,206,107,206,109,206,116,206,117,206,120,206,124,206,132,206,133,206,135,206,137,206,144,206,145,206,148,206,152,206,160,206,161,206,163,206,164,206,165,206,172,206,173,206,193,206,228,206,229,206,232,206,235,206,236,206,244,206,245,206,247,206,248,206,249,206,0,207,1,207,4,207,8,207,16,207,17,207,19,207,21,207,28,207,32,207,36,207,44,207,45,207,47,207,48,207,49,207,56,207,84,207,85,207,88,207,92,207,100,207,101,207,103,207,105,207,112,207,113,207,116,207,120,207,128,207,133,207,140,207,161,207,168,207,176,207,196,207,224,207,225,207,228,207,232,207,240,207,241,207,243,207,245,207,252,207,0,208,4,208,17,208,24,208,45,208,52,208,53,208,56,208,60,208,68,208,69,208,71,208,73,208,80,208,84,208,88,208,96,208,108,208,109,208,112,208,116,208,124,208,125,208,129,208,164,208,165,208,168,208,172,208,180,208,181,208,183,208,185,208,192,208,193,208,196,208,200,208,201,208,208,208,209,208,211,208,212,208,213,208,220,208,221,208,224,208,228,208,236,208,237,208,239,208,240,208,241,208,248,208,13,209,48,209,49,209,52,209,56,209,58,209,64,209,65,209,67,209,68,209,69,209,76,209,77,209,80,209,84,209,92,209,93,209,95,209,97,209,104,209,108,209,124,209,132,209,136,209,160,209,161,209,164,209,168,209,176,209,177,209,179,209,181,209,186,209,188,209,192,209,216,209,244,209,248,209,7,210,9,210,16,210,44,210,45,210,48,210,52,210,60,210,61,210,63,210,65,210,72,210,92,210,100,210,128,210,129,210,132,210,136,210,144,210,145,210,149,210,156,210,160,210,164,210,172,210,177,210,184,210,185,210,188,210,191,210,192,210,194,210,200,210,201,210,203,210,212,210,216,210,220,210,228,210,229,210,240,210,241,210,244,210,248,210,0,211,1,211,3,211,5,211,12,211,13,211,14,211,16,211,20,211,22,211,28,211,29,211,31,211,32,211,33,211,37,211,40,211,41,211,44,211,48,211,56,211,57,211,59,211,60,211,61,211,68,211,69,211,124,211,125,211,128,211,132,211,140,211,141,211,143,211,144,211,145,211,152,211,153,211,156,211,160,211,168,211,169,211,171,211,173,211,180,211,184,211,188,211,196,211,197,211,200,211,201,211,208,211,216,211,225,211,227,211,236,211,237,211,240,211,244,211,252,211,253,211,255,211,1,212,8,212,29,212,64,212,68,212,92,212,96,212,100,212,109,212,111,212,120,212,121,212,124,212,127,212,128,212,130,212,136,212,137,212,139,212,141,212,148,212,169,212,204,212,208,212,212,212,220,212,223,212,232,212,236,212,240,212,248,212,251,212,253,212,4,213,8,213,12,213,20,213,21,213,23,213,60,213,61,213,64,213,68,213,76,213,77,213,79,213,81,213,88,213,89,213,92,213,96,213,101,213,104,213,105,213,107,213,109,213,116,213,117,213,120,213,124,213,132,213,133,213,135,213,136,213,137,213,144,213,165,213,200,213,201,213,204,213,208,213,210,213,216,213,217,213,219,213,221,213,228,213,229,213,232,213,236,213,244,213,245,213,247,213,249,213,0,214,1,214,4,214,8,214,16,214,17,214,19,214,20,214,21,214,28,214,32,214,36,214,45,214,56,214,57,214,60,214,64,214,69,214,72,214,73,214,75,214,77,214,81,214,84,214,85,214,88,214,92,214,103,214,105,214,112,214,113,214,116,214,131,214,133,214,140,214,141,214,144,214,148,214,157,214,159,214,161,214,168,214,172,214,176,214,185,214,187,214,196,214,197,214,200,214,204,214,209,214,212,214,215,214,217,214,224,214,228,214,232,214,240,214,245,214,252,214,253,214,0,215,4,215,17,215,24,215,25,215,28,215,32,215,40,215,41,215,43,215,45,215,52,215,53,215,56,215,60,215,68,215,71,215,73,215,80,215,81,215,84,215,86,215,87,215,88,215,89,215,96,215,97,215,99,215,101,215,105,215,108,215,112,215,116,215,124,215,125,215,129,215,136,215,137,215,140,215,144,215,152,215,153,215,155,215,157,215,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,79,115,79,71,80,249,80,160,82,239,83,117,84,229,84,9,86,193,90,182,91,135,102,182,103,183,103,239,103,76,107,194,115,194,117,60,122,219,130,4,131,87,136,136,136,54,138,200,140,207,141,251,142,230,143,213,153,59,82,116,83,4,84,106,96,100,97,188,107,207,115,26,129,186,137,210,137,163,149,131,79,10,82,190,88,120,89,230,89,114,94,121,94,199,97,192,99,70,103,236,103,127,104,151,111,78,118,11,119,245,120,8,122,255,122,33,124,157,128,110,130,113,130,235,138,147,149,107,78,157,85,247,102,52,110,163,120,237,122,91,132,16,137,78,135,168,151,216,82,78,87,42,88,76,93,31,97,190,97,33,98,98,101,209,103,68,106,27,110,24,117,179,117,227,118,176,119,58,125,175,144,81,148,82,148,149,159,35,83,172,92,50,117,219,128,64,146,152,149,91,82,8,88,220,89,161,92,23,93,183,94,58,95,74,95,119,97,95,108,122,117,134,117,224,124,115,125,177,125,140,127,84,129,33,130,145,133,65,137,27,139,252,146,77,150,71,156,203,78,247,78,11,80,241,81,79,88,55,97,62,97,104,97,57,101,234,105,17,111,165,117,134,118,214,118,135,123,165,130,203,132,0,249,167,147,139,149,128,85,162,91,81,87,1,249,179,124,185,127,181,145,40,80,187,83,69,92,232,93,210,98,110,99,218,100,231,100,32,110,172,112,91,121,221,141,30,142,2,249,125,144,69,146,248,146,126,78,246,78,101,80,254,93,250,94,6,97,87,105,113,129,84,134,71,142,117,147,43,154,94,78,145,80,112,103,64,104,9,81,141,82,146,82,162,106,188,119,16,146,212,158,171,82,47,96,242,143,72,80,169,97,237,99,202,100,60,104,132,106,192,111,136,129,161,137,148,150,5,88,125,114,172,114,4,117,121,125,109,126,169,128,139,137,116,139,99,144,81,157,137,98,122,108,84,111,80,125,58,127,35,138,124,81,74,97,157,123,25,139,87,146,140,147,172,78,211,79,30,80,190,80,6,81,193,82,205,82,127,83,112,87,131,88,154,94,145,95,118,97,172,97,206,100,108,101,111,102,187,102,244,102,151,104,135,109,133,112,241,112,159,116,165,116,202,116,217,117,108,120,236,120,223,122,246,122,69,125,147,125,21,128,63,128,27,129,150,131,102,139,21,143,21,144,225,147,3,152,56,152,90,154,232,155,194,79,83,85,58,88,81,89,99,91,70,92,184,96,18,98,66,104,176,104,232,104,170,110,76,117,120,118,206,120,61,122,251,124,107,126,124,126,8,138,161,138,63,140,142,150,196,157,228,83,233,83,74,84,113,84,250,86,209,89,100,91,59,92,171,94,247,98,55,101,69,101,114,101,160,102,175,103,193,105,189,108,252,117,144,118,126,119,63,122,148,127,3,128,161,128,143,129,230,130,253,130,240,131,193,133,49,136,180,136,165,138,3,249,156,143,46,147,199,150,103,152,216,154,19,159,237,84,155,101,242,102,143,104,64,122,55,140,96,157,240,86,100,87,17,93,6,102,177,104,205,104,254,110,40,116,158,136,228,155,104,108,4,249,168,154,155,79,108,81,113,81,159,82,84,91,229,93,80,96,109,96,241,98,167,99,59,101,217,115,122,122,163,134,162,140,143,151,50,78,225,91,8,98,156,103,220,116,209,121,211,131,135,138,178,138,232,141,78,144,75,147,70,152,211,94,232,105,255,133,237,144,5,249,160,81,152,91,236,91,99,97,250,104,62,107,76,112,47,116,216,116,161,123,80,127,197,131,192,137,171,140,220,149,40,153,46,82,93,96,236,98,2,144,138,79,73,81,33,83,217,88,227,94,224,102,56,109,154,112,194,114,214,115,80,123,241,128,91,148,102,83,155,99,107,127,86,78,128,80,74,88,222,88,42,96,39,97,208,98,208,105,65,155,143,91,24,125,177,128,95,143,164,78,209,80,172,84,172,85,12,91,160,93,231,93,42,101,78,101,33,104,75,106,225,114,142,118,239,119,94,125,249,127,160,129,78,133,223,134,3,143,78,143,202,144,3,153,85,154,171,155,24,78,69,78,93,78,199,78,241,79,119,81,254,82,64,83,227,83,229,83,142,84,20,86,117,87,162,87,199,91,135,93,208,94,252,97,216,98,81,101,184,103,233,103,203,105,80,107,198,107,236,107,66,108,157,110,120,112,215,114,150,115,3,116,191,119,233,119,118,122,127,125,9,128,252,129,5,130,10,130,223,130,98,136,51,139,252,140,192,142,17,144,177,144,100,146,182,146,210,153,69,154,233,156,215,157,156,159,11,87,64,92,202,131,160,151,171,151,180,158,27,84,152,122,164,127,217,136,205,142,225,144,0,88,72,92,152,99,159,122,174,91,19,95,121,122,174,122,142,130,172,142,38,80,56,82,248,82,119,83,8,87,243,98,114,99,10,107,195,109,55,119,165,83,87,115,104,133,118,142,213,149,58,103,195,106,112,111,109,138,204,142,75,153,6,249,119,102,120,107,180,140,60,155,7,249,235,83,45,87,78,89,198,99,251,105,234,115,69,120,186,122,197,122,254,124,117,132,143,137,115,141,53,144,168,149,251,82,71,87,71,117,96,123,204,131,30,146,8,249,88,106,75,81,75,82,135,82,31,98,216,104,117,105,153,150,197,80,164,82,228,82,195,97,164,101,57,104,255,105,126,116,75,123,185,130,235,131,178,137,57,139,209,143,73,153,9,249,202,78,151,89,210,100,17,102,142,106,52,116,129,121,189,121,169,130,126,136,127,136,95,137,10,249,38,147,11,79,202,83,37,96,113,98,114,108,26,125,102,125,152,78,98,81,220,119,175,128,1,79,14,79,118,81,128,81,220,85,104,86,59,87,250,87,252,87,20,89,71,89,147,89,196,91,144,92,14,93,241,93,126,94,204,95,128,98,215,101,227,101,30,103,31,103,94,103,203,104,196,104,95,106,58,107,35,108,125,108,130,108,199,109,152,115,38,116,42,116,130,116,163,116,120,117,127,117,129,120,239,120,65,121,71,121,72,121,122,121,149,123,0,125,186,125,136,127,6,128,45,128,140,128,24,138,79,139,72,140,119,141,33,147,36,147,226,152,81,153,14,154,15,154,101,154,146,158,202,125,118,79,9,84,238,98,84,104,209,145,171,85,58,81,11,249,12,249,28,90,230,97,13,249,207,98,255,98,14,249,15,249,16,249,17,249,18,249,19,249,163,144,20,249,21,249,22,249,23,249,24,249,254,138,25,249,26,249,27,249,28,249,150,102,29,249,86,113,30,249,31,249,227,150,32,249,79,99,122,99,87,83,33,249,143,103,96,105,115,110,34,249,55,117,35,249,36,249,37,249,13,125,38,249,39,249,114,136,202,86,24,90,40,249,41,249,42,249,43,249,44,249,67,78,45,249,103,81,72,89,240,103,16,128,46,249,115,89,116,94,154,100,202,121,245,95,108,96,200,98,123,99,231,91,215,91,170,82,47,249,116,89,41,95,18,96,48,249,49,249,50,249,89,116,51,249,52,249,53,249,54,249,55,249,56,249,209,153,57,249,58,249,59,249,60,249,61,249,62,249,63,249,64,249,65,249,66,249,67,249,195,111,68,249,69,249,191,129,178,143,241,96,70,249,71,249,102,129,72,249,73,249,63,92,74,249,75,249,76,249,77,249,78,249,79,249,80,249,81,249,233,90,37,138,123,103,16,125,82,249,83,249,84,249,85,249,86,249,87,249,253,128,88,249,89,249,60,92,229,108,63,83,186,110,26,89,54,131,57,78,182,78,70,79,174,85,24,87,199,88,86,95,183,101,230,101,128,106,181,107,77,110,237,119,239,122,30,124,222,125,203,134,146,136,50,145,91,147,187,100,190,111,122,115,184,117,84,144,86,85,77,87,186,97,212,100,199,102,225,109,91,110,109,111,185,111,240,117,67,128,189,129,65,133,131,137,199,138,90,139,31,147,147,108,83,117,84,123,15,142,93,144,16,85,2,88,88,88,98,94,7,98,158,100,224,104,118,117,214,124,179,135,232,158,227,78,136,87,110,87,39,89,13,92,177,92,54,94,133,95,52,98,225,100,179,115,250,129,139,136,184,140,138,150,219,158,133,91,183,95,179,96,18,80,0,82,48,82,22,87,53,88,87,88,14,92,96,92,246,92,139,93,166,94,146,95,188,96,17,99,137,99,23,100,67,104,249,104,194,106,216,109,33,110,212,110,228,111,254,113,220,118,121,119,177,121,59,122,4,132,169,137,237,140,243,141,72,142,3,144,20,144,83,144,253,144,77,147,118,150,220,151,210,107,6,112,88,114,162,114,104,115,99,119,191,121,228,123,155,126,128,139,169,88,199,96,102,101,253,101,190,102,140,108,30,113,201,113,90,140,19,152,109,78,129,122,221,78,172,81,205,81,213,82,12,84,167,97,113,103,80,104,223,104,30,109,124,111,188,117,179,119,229,122,244,128,99,132,133,146,92,81,151,101,92,103,147,103,216,117,199,122,115,131,90,249,70,140,23,144,45,152,111,92,192,129,154,130,65,144,111,144,13,146,151,95,157,93,89,106,200,113,123,118,73,123,228,133,4,139,39,145,48,154,135,85,246,97,91,249,105,118,133,127,63,134,186,135,248,136,143,144,92,249,27,109,217,112,222,115,97,125,61,132,93,249,106,145,241,153,94,249,130,78,117,83,4,107,18,107,62,112,27,114,45,134,30,158,76,82,163,143,80,93,229,100,44,101,22,107,235,111,67,124,156,126,205,133,100,137,189,137,201,98,216,129,31,136,202,94,23,103,106,109,252,114,5,116,111,116,130,135,222,144,134,79,13,93,160,95,10,132,183,81,160,99,101,117,174,78,6,80,105,81,201,81,129,104,17,106,174,124,177,124,231,124,111,130,210,138,27,143,207,145,182,79,55,81,245,82,66,84,236,94,110,97,62,98,197,101,218,106,254,111,42,121,220,133,35,136,173,149,98,154,106,154,151,158,206,158,155,82,198,102,119,107,29,112,43,121,98,143,66,151,144,97,0,98,35,101,35,111,73,113,137,116,244,125,111,128,238,132,38,143,35,144,74,147,189,81,23,82,163,82,12,109,200,112,194,136,201,94,130,101,174,107,194,111,62,124,117,115,228,78,54,79,249,86,95,249,186,92,186,93,28,96,178,115,45,123,154,127,206,127,70,128,30,144,52,146,246,150,72,151,24,152,97,159,139,79,167,111,174,121,180,145,183,150,222,82,96,249,136,100,196,100,211,106,94,111,24,112,16,114,231,118,1,128,6,134,92,134,239,141,5,143,50,151,111,155,250,157,117,158,140,120,127,121,160,125,201,131,4,147,127,158,147,158,214,138,223,88,4,95,39,103,39,112,207,116,96,124,126,128,33,81,40,112,98,114,202,120,194,140,218,140,244,140,247,150,134,78,218,80,238,91,214,94,153,101,206,113,66,118,173,119,74,128,252,132,124,144,39,155,141,159,216,88,65,90,98,92,19,106,218,109,15,111,59,118,47,125,55,126,30,133,56,137,228,147,75,150,137,82,210,101,243,103,180,105,65,109,156,110,15,112,9,116,96,116,89,117,36,118,107,120,44,139,94,152,109,81,46,98,120,150,150,79,43,80,25,93,234,109,184,125,42,143,139,95,68,97,23,104,97,249,134,150,210,82,139,128,220,81,204,81,94,105,28,122,190,125,241,131,117,150,218,79,41,82,152,83,15,84,14,85,101,92,167,96,78,103,168,104,108,109,129,114,248,114,6,116,131,116,98,249,226,117,108,124,121,127,184,127,137,131,207,136,225,136,204,145,208,145,226,150,201,155,29,84,126,111,208,113,152,116,250,133,170,142,163,150,87,156,159,158,151,103,203,109,51,116,232,129,22,151,44,120,203,122,32,123,146,124,105,100,106,116,242,117,188,120,232,120,172,153,84,155,187,158,222,91,85,94,32,111,156,129,171,131,136,144,7,78,77,83,41,90,210,93,78,95,98,97,61,99,105,102,252,102,255,110,43,111,99,112,158,119,44,132,19,133,59,136,19,143,69,153,59,156,28,85,185,98,43,103,171,108,9,131,106,137,122,151,161,78,132,89,216,95,217,95,27,103,178,125,84,127,146,130,43,131,189,131,30,143,153,144,203,87,185,89,146,90,208,91,39,102,154,103,133,104,207,107,100,113,117,127,183,140,227,140,129,144,69,155,8,129,138,140,76,150,64,154,165,158,95,91,19,108,27,115,242,118,223,118,12,132,170,81,147,137,77,81,149,81,201,82,201,104,148,108,4,119,32,119,191,125,236,125,98,151,181,158,197,110,17,133,165,81,13,84,125,84,14,102,157,102,39,105,159,110,191,118,145,119,23,131,194,132,159,135,105,145,152,146,244,156,130,136,174,79,146,81,223,82,198,89,61,94,85,97,120,100,121,100,174,102,208,103,33,106,205,107,219,107,95,114,97,114,65,116,56,119,219,119,23,128,188,130,5,131,0,139,40,139,140,140,40,103,144,108,103,114,238,118,102,119,70,122,169,157,127,107,146,108,34,89,38,103,153,132,111,83,147,88,153,89,223,94,207,99,52,102,115,103,58,110,43,115,215,122,215,130,40,147,217,82,235,93,174,97,203,97,10,98,199,98,171,100,224,101,89,105,102,107,203,107,33,113,247,115,93,117,70,126,30,130,2,131,106,133,163,138,191,140,39,151,97,157,168,88,216,158,17,80,14,82,59,84,79,85,135,101,118,108,10,125,11,125,94,128,138,134,128,149,239,150,255,82,149,108,105,114,115,84,154,90,62,92,75,93,76,95,174,95,42,103,182,104,99,105,60,110,68,110,9,119,115,124,142,127,135,133,14,139,247,143,97,151,244,158,183,92,182,96,13,97,171,97,79,101,251,101,252,101,17,108,239,108,159,115,201,115,225,125,148,149,198,91,28,135,16,139,93,82,90,83,205,98,15,100,178,100,52,103,56,106,202,108,192,115,158,116,148,123,149,124,27,126,138,129,54,130,132,133,235,143,249,150,193,153,52,79,74,83,205,83,219,83,204,98,44,100,0,101,145,101,195,105,238,108,88,111,237,115,84,117,34,118,228,118,252,118,208,120,251,120,44,121,70,125,44,130,224,135,212,143,18,152,239,152,195,82,212,98,165,100,36,110,81,111,124,118,203,141,177,145,98,146,238,154,67,155,35,80,141,80,74,87,168,89,40,92,71,94,119,95,63,98,62,101,185,101,193,101,9,102,139,103,156,105,194,110,197,120,33,125,170,128,128,129,43,130,179,130,161,132,140,134,42,138,23,139,166,144,50,150,144,159,13,80,243,79,99,249,249,87,152,95,220,98,146,99,111,103,67,110,25,113,195,118,204,128,218,128,244,136,245,136,25,137,224,140,41,143,77,145,106,150,47,79,112,79,27,94,207,103,34,104,125,118,126,118,68,155,97,94,10,106,105,113,212,113,106,117,100,249,65,126,67,133,233,133,220,152,16,79,79,123,112,127,165,149,225,81,6,94,181,104,62,108,78,108,219,108,175,114,196,123,3,131,213,108,58,116,251,80,136,82,193,88,216,100,151,106,167,116,86,118,167,120,23,134,226,149,57,151,101,249,94,83,1,95,138,139,168,143,175,143,138,144,37,82,165,119,73,156,8,159,25,78,2,80,117,81,91,92,119,94,30,102,58,102,196,103,197,104,179,112,1,117,197,117,201,121,221,122,39,143,32,153,8,154,221,79,33,88,49,88,246,91,110,102,101,107,17,109,122,110,125,111,228,115,43,117,233,131,220,136,19,137,92,139,20,143,15,79,213,80,16,83,92,83,147,91,169,95,13,103,143,121,121,129,47,131,20,133,7,137,134,137,57,143,59,143,165,153,18,156,44,103,118,78,248,79,73,89,1,92,239,92,240,92,103,99,210,104,253,112,162,113,43,116,43,126,236,132,2,135,34,144,210,146,243,156,13,78,216,78,239,79,133,80,86,82,111,82,38,84,144,84,224,87,43,89,102,90,90,91,117,91,204,91,156,94,102,249,118,98,119,101,167,101,110,109,165,110,54,114,38,123,63,124,54,127,80,129,81,129,154,129,64,130,153,130,169,131,3,138,160,140,230,140,251,140,116,141,186,141,232,144,220,145,28,150,68,150,217,153,231,156,23,83,6,82,41,84,116,86,179,88,84,89,110,89,255,95,164,97,110,98,16,102,126,108,26,113,198,118,137,124,222,124,27,125,172,130,193,140,240,150,103,249,91,79,23,95,127,95,194,98,41,93,11,103,218,104,124,120,67,126,108,157,21,78,153,80,21,83,42,83,81,83,131,89,98,90,135,94,178,96,138,97,73,98,121,98,144,101,135,103,167,105,212,107,214,107,215,107,216,107,184,108,104,249,53,116,250,117,18,120,145,120,213,121,216,121,131,124,203,125,225,127,165,128,62,129,194,129,242,131,26,135,232,136,185,138,108,139,187,140,25,145,94,151,219,152,59,159,172,86,42,91,108,95,140,101,179,106,175,107,92,109,241,111,21,112,93,114,173,115,167,140,211,140,59,152,145,97,55,108,88,128,1,154,77,78,139,78,155,78,213,78,58,79,60,79,127,79,223,79,255,80,242,83,248,83,6,85,227,85,219,86,235,88,98,89,17,90,235,91,250,91,4,92,243,93,43,94,153,95,29,96,104,99,156,101,175,101,246,103,251,103,173,104,123,107,153,108,215,108,35,110,9,112,69,115,2,120,62,121,64,121,96,121,193,121,233,123,23,125,114,125,134,128,13,130,142,131,209,132,199,134,223,136,80,138,94,138,29,139,220,140,102,141,173,143,170,144,252,152,223,153,157,158,74,82,105,249,20,103,106,249,152,80,42,82,113,92,99,101,85,108,202,115,35,117,157,117,151,123,156,132,120,145,48,151,119,78,146,100,186,107,94,113,169,133,9,78,107,249,73,103,238,104,23,110,159,130,24,133,107,136,247,99,129,111,18,146,175,152,10,78,183,80,207,80,31,81,70,85,170,85,23,86,64,91,25,92,224,92,56,94,138,94,160,94,194,94,243,96,81,104,97,106,88,110,61,114,64,114,192,114,248,118,101,121,177,123,212,127,243,136,244,137,115,138,97,140,222,140,28,151,94,88,189,116,253,140,199,85,108,249,97,122,34,125,114,130,114,114,31,117,37,117,109,249,25,123,133,88,251,88,188,93,143,94,182,94,144,95,85,96,146,98,127,99,77,101,145,102,217,102,248,102,22,104,242,104,128,114,94,116,110,123,110,125,214,125,114,127,229,128,18,130,175,133,127,137,147,138,29,144,228,146,205,158,32,159,21,89,109,89,45,94,220,96,20,102,115,102,144,103,80,108,197,109,95,111,243,119,169,120,198,132,203,145,43,147,217,78,202,80,72,81,132,85,11,91,163,91,71,98,126,101,203,101,50,110,125,113,1,116,68,116,135,116,191,116,108,118,170,121,218,125,85,126,168,127,122,129,179,129,57,130,26,134,236,135,117,138,227,141,120,144,145,146,37,148,77,153,174,155,104,83,81,92,84,105,196,108,41,109,43,110,12,130,155,133,59,137,45,138,170,138,234,150,103,159,97,82,185,102,178,107,150,126,254,135,13,141,131,149,93,150,29,101,137,109,238,113,110,249,206,87,211,89,172,91,39,96,250,96,16,98,31,102,95,102,41,115,249,115,219,118,1,119,108,123,86,128,114,128,101,129,160,138,146,145,22,78,226,82,114,107,23,109,5,122,57,123,48,125,111,249,176,140,236,83,47,86,81,88,181,91,15,92,17,92,226,93,64,98,131,99,20,100,45,102,179,104,188,108,136,109,175,110,31,112,164,112,210,113,38,117,143,117,142,117,25,118,17,123,224,123,43,124,32,125,57,125,44,133,109,133,7,134,52,138,13,144,97,144,181,144,183,146,246,151,55,154,215,79,108,92,95,103,145,109,159,124,140,126,22,139,22,141,31,144,107,91,253,93,13,100,192,132,92,144,225,152,135,115,139,91,154,96,126,103,222,109,31,138,166,138,1,144,12,152,55,82,112,249,81,112,142,120,150,147,112,136,215,145,238,79,215,83,253,85,218,86,130,87,253,88,194,90,136,91,171,92,192,92,37,94,1,97,13,98,75,98,136,99,28,100,54,101,120,101,57,106,138,107,52,108,25,109,49,111,231,113,233,114,120,115,7,116,178,116,38,118,97,119,192,121,87,122,234,122,185,124,143,125,172,125,97,126,158,127,41,129,49,131,144,132,218,132,234,133,150,136,176,138,144,139,56,143,66,144,131,144,108,145,150,146,185,146,139,150,167,150,168,150,214,150,0,151,8,152,150,153,211,154,26,155,212,83,126,88,25,89,112,91,191,91,209,109,90,111,159,113,33,116,185,116,133,128,253,131,225,93,135,95,170,95,66,96,236,101,18,104,111,105,83,106,137,107,53,109,243,109,227,115,254,118,172,119,77,123,20,125,35,129,28,130,64,131,244,132,99,133,98,138,196,138,135,145,30,147,6,152,180,153,12,98,83,136,240,143,101,146,7,93,39,93,105,93,95,116,157,129,104,135,213,111,254,98,210,127,54,137,114,137,30,78,88,78,231,80,221,82,71,83,127,98,7,102,105,126,5,136,94,150,141,79,25,83,54,86,203,89,164,90,56,92,78,92,77,92,2,94,17,95,67,96,189,101,47,102,66,102,190,103,244,103,28,115,226,119,58,121,197,127,148,132,205,132,150,137,102,138,105,138,225,138,85,140,122,140,244,87,212,91,15,95,111,96,237,98,13,105,150,107,92,110,132,113,210,123,85,135,88,139,254,142,223,152,254,152,56,79,129,79,225,79,123,84,32,90,184,91,60,97,176,101,104,102,252,113,51,117,94,121,51,125,78,129,227,129,152,131,170,133,206,133,3,135,10,138,171,142,155,143,113,249,197,143,49,89,164,91,230,91,137,96,233,91,11,92,195,95,129,108,114,249,241,109,11,112,26,117,175,130,246,138,192,78,65,83,115,249,217,150,15,108,158,78,196,79,82,81,94,85,37,90,232,92,17,98,89,114,189,130,170,131,254,134,89,136,29,138,63,150,197,150,19,153,9,157,93,157,10,88,179,92,189,93,68,94,225,96,21,97,225,99,2,106,37,110,2,145,84,147,78,152,16,156,119,159,137,91,184,92,9,99,79,102,72,104,60,119,193,150,141,151,84,152,159,155,161,101,1,139,203,142,188,149,53,85,169,92,214,93,181,94,151,102,76,118,244,131,199,149,211,88,188,98,206,114,40,157,240,78,46,89,15,96,59,102,131,107,231,121,38,157,147,83,192,84,195,87,22,93,27,97,214,102,175,109,141,120,126,130,152,150,68,151,132,83,124,98,150,99,178,109,10,126,75,129,77,152,251,106,76,127,175,157,26,158,95,78,59,80,182,81,28,89,249,96,246,99,48,105,58,114,54,128,116,249,206,145,49,95,117,249,118,249,4,125,229,130,111,132,187,132,229,133,141,142,119,249,111,79,120,249,121,249,228,88,67,91,89,96,218,99,24,101,109,101,152,102,122,249,74,105,35,106,11,109,1,112,108,113,210,117,13,118,179,121,112,122,123,249,138,127,124,249,68,137,125,249,147,139,192,145,125,150,126,249,10,153,4,87,161,95,188,101,1,111,0,118,166,121,158,138,173,153,90,155,108,159,4,81,182,97,145,98,141,106,198,129,67,80,48,88,102,95,9,113,0,138,250,138,124,91,22,134,250,79,60,81,180,86,68,89,169,99,249,109,170,93,109,105,134,81,136,78,89,79,127,249,128,249,129,249,130,89,130,249,131,249,95,107,93,108,132,249,181,116,22,121,133,249,7,130,69,130,57,131,63,143,93,143,134,249,24,153,135,249,136,249,137,249,166,78,138,249,223,87,121,95,19,102,139,249,140,249,171,117,121,126,111,139,141,249,6,144,91,154,165,86,39,88,248,89,31,90,180,91,142,249,246,94,143,249,144,249,80,99,59,99,145,249,61,105,135,108,191,108,142,109,147,109,245,109,20,111,146,249,223,112,54,113,89,113,147,249,195,113,213,113,148,249,79,120,111,120,149,249,117,123,227,125,150,249,47,126,151,249,77,136,223,142,152,249,153,249,154,249,91,146,155,249,246,156,156,249,157,249,158,249,133,96,133,109,159,249,177,113,160,249,161,249,177,149,173,83,162,249,163,249,164,249,211,103,165,249,142,112,48,113,48,116,118,130,210,130,166,249,187,149,229,154,125,158,196,102,167,249,193,113,73,132,168,249,169,249,75,88,170,249,171,249,184,93,113,95,172,249,32,102,142,102,121,105,174,105,56,108,243,108,54,110,65,111,218,111,27,112,47,112,80,113,223,113,112,115,173,249,91,116,174,249,212,116,200,118,78,122,147,126,175,249,176,249,241,130,96,138,206,143,177,249,72,147,178,249,25,151,179,249,180,249,66,78,42,80,181,249,8,82,225,83,243,102,109,108,202,111,10,115,127,119,98,122,174,130,221,133,2,134,182,249,212,136,99,138,125,139,107,140,183,249,179,146,184,249,19,151,16,152,148,78,13,79,201,79,178,80,72,83,62,84,51,84,218,85,98,88,186,88,103,89,27,90,228,91,159,96,185,249,202,97,86,101,255,101,100,102,167,104,90,108,179,111,207,112,172,113,82,115,125,123,8,135,164,138,50,156,7,159,75,92,131,108,68,115,137,115,58,146,171,110,101,116,31,118,105,122,21,126,10,134,64,81,197,88,193,100,238,116,21,117,112,118,193,127,149,144,205,150,84,153,38,110,230,116,169,122,170,122,229,129,217,134,120,135,27,138,73,90,140,91,155,91,161,104,0,105,99,109,169,115,19,116,44,116,151,120,233,125,235,127,24,129,85,129,158,131,76,140,46,150,17,152,240,102,128,95,250,101,137,103,106,108,139,115,45,80,3,90,106,107,238,119,22,89,108,93,205,93,37,115,79,117,186,249,187,249,229,80,249,81,47,88,45,89,150,89,218,89,229,91,188,249,189,249,162,93,215,98,22,100,147,100,254,100,190,249,220,102,191,249,72,106,192,249,255,113,100,116,193,249,136,122,175,122,71,126,94,126,0,128,112,129,194,249,239,135,129,137,32,139,89,144,195,249,128,144,82,153,126,97,50,107,116,109,31,126,37,137,177,143,209,79,173,80,151,81,199,82,199,87,137,88,185,91,184,94,66,97,149,105,140,109,103,110,182,110,148,113,98,116,40,117,44,117,115,128,56,131,201,132,10,142,148,147,222,147,196,249,142,78,81,79,118,80,42,81,200,83,203,83,243,83,135,91,211,91,36,92,26,97,130,97,244,101,91,114,151,115,64,116,194,118,80,121,145,121,185,121,6,125,189,127,139,130,213,133,94,134,194,143,71,144,245,144,234,145,133,150,232,150,233,150,214,82,103,95,237,101,49,102,47,104,92,113,54,122,193,144,10,152,145,78,197,249,82,106,158,107,144,111,137,113,24,128,184,130,83,133,75,144,149,150,242,150,251,151,26,133,49,155,144,78,138,113,196,150,67,81,159,83,225,84,19,87,18,87,163,87,155,90,196,90,195,91,40,96,63,97,244,99,133,108,57,109,114,110,144,110,48,114,63,115,87,116,209,130,129,136,69,143,96,144,198,249,98,150,88,152,27,157,8,103,138,141,94,146,77,79,73,80,222,80,113,83,13,87,212,89,1,90,9,92,112,97,144,102,45,110,50,114,75,116,239,125,195,128,14,132,102,132,63,133,95,135,91,136,24,137,2,139,85,144,203,151,79,155,115,78,145,79,18,81,106,81,199,249,47,85,169,85,122,91,165,91,124,94,125,94,190,94,160,96,223,96,8,97,9,97,196,99,56,101,9,103,200,249,212,103,218,103,201,249,97,105,98,105,185,108,39,109,202,249,56,110,203,249,225,111,54,115,55,115,204,249,92,116,49,117,205,249,82,118,206,249,207,249,173,125,254,129,56,132,213,136,152,138,219,138,237,138,48,142,66,142,74,144,62,144,122,144,73,145,201,145,110,147,208,249,209,249,9,88,210,249,211,107,137,128,178,128,211,249,212,249,65,81,107,89,57,92,213,249,214,249,100,111,167,115,228,128,7,141,215,249,23,146,143,149,216,249,217,249,218,249,219,249,127,128,14,98,28,112,104,125,141,135,220,249,160,87,105,96,71,97,183,107,190,138,128,146,177,150,89,78,31,84,235,109,45,133,112,150,243,151,238,152,214,99,227,108,145,144,221,81,201,97,186,129,249,157,157,79,26,80,0,81,156,91,15,97,255,97,236,100], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1021080);
/* memory initializer */ allocate([5,105,197,107,145,117,227,119,169,127,100,130,143,133,251,135,99,136,188,138,112,139,171,145,140,78,229,78,10,79,221,249,222,249,55,89,232,89,223,249,242,93,27,95,91,95,33,96,224,249,225,249,226,249,227,249,62,114,229,115,228,249,112,117,205,117,229,249,251,121,230,249,12,128,51,128,132,128,225,130,81,131,231,249,232,249,189,140,179,140,135,144,233,249,234,249,244,152,12,153,235,249,236,249,55,112,202,118,202,127,204,127,252,127,26,139,186,78,193,78,3,82,112,83,237,249,189,84,224,86,251,89,197,91,21,95,205,95,110,110,238,249,239,249,106,125,53,131,240,249,147,134,141,138,241,249,109,151,119,151,242,249,243,249,0,78,90,79,126,79,249,88,229,101,162,110,56,144,176,147,185,153,251,78,236,88,138,89,217,89,65,96,244,249,245,249,20,122,246,249,79,131,195,140,101,81,68,83,247,249,248,249,249,249,205,78,105,82,85,91,191,130,212,78,58,82,168,84,201,89,255,89,80,91,87,91,92,91,99,96,72,97,203,110,153,112,110,113,134,115,247,116,181,117,193,120,43,125,5,128,234,129,40,131,23,133,201,133,238,138,199,140,204,150,92,79,250,82,188,86,171,101,40,102,124,112,184,112,53,114,189,125,141,130,76,145,192,150,114,157,113,91,231,104,152,107,122,111,222,118,145,92,171,102,91,111,180,123,42,124,54,136,220,150,8,78,215,78,32,83,52,88,187,88,239,88,108,89,7,92,51,94,132,94,53,95,140,99,178,102,86,103,31,106,163,106,12,107,63,111,70,114,250,249,80,115,139,116,224,122,167,124,120,129,223,129,231,129,138,131,108,132,35,133,148,133,207,133,221,136,19,141,172,145,119,149,156,150,141,81,201,84,40,87,176,91,77,98,80,103,61,104,147,104,61,110,211,110,125,112,33,126,193,136,161,140,9,143,75,159,78,159,45,114,143,123,205,138,26,147,71,79,78,79,50,81,128,84,208,89,149,94,181,98,117,103,110,105,23,106,174,108,26,110,217,114,42,115,189,117,184,123,53,125,231,130,249,131,87,132,247,133,91,138,175,140,135,142,25,144,184,144,206,150,95,159,227,82,10,84,225,90,194,91,88,100,117,101,244,110,196,114,251,249,132,118,77,122,27,123,77,124,62,126,223,127,123,131,43,139,202,140,100,141,225,141,95,142,234,143,249,143,105,144,209,147,67,79,122,79,179,80,104,81,120,81,77,82,106,82,97,88,124,88,96,89,8,92,85,92,219,94,155,96,48,98,19,104,191,107,8,108,177,111,78,113,32,116,48,117,56,117,81,117,114,118,76,123,139,123,173,123,198,123,143,126,110,138,62,143,73,143,63,146,147,146,34,147,43,148,251,150,90,152,107,152,30,153,7,82,42,98,152,98,89,109,100,118,202,122,192,123,118,125,96,83,190,92,151,94,56,111,185,112,152,124,17,151,142,155,222,158,165,99,122,100,118,135,1,78,149,78,173,78,92,80,117,80,72,84,195,89,154,91,64,94,173,94,247,94,129,95,197,96,58,99,63,101,116,101,204,101,118,102,120,102,254,103,104,105,137,106,99,107,64,108,192,109,232,109,31,110,94,110,30,112,161,112,142,115,253,115,58,117,91,119,135,120,142,121,11,122,125,122,190,124,142,125,71,130,2,138,234,138,158,140,45,145,74,145,216,145,102,146,204,146,32,147,6,151,86,151,92,151,2,152,14,159,54,82,145,82,124,85,36,88,29,94,31,95,140,96,208,99,175,104,223,111,109,121,44,123,205,129,186,133,253,136,248,138,68,142,141,145,100,150,155,150,61,151,76,152,74,159,206,79,70,81,203,81,169,82,50,86,20,95,107,95,170,99,205,100,233,101,65,102,250,102,249,102,29,103,157,104,215,104,253,105,21,111,110,111,103,113,229,113,42,114,170,116,58,119,86,121,90,121,223,121,32,122,149,122,151,124,223,124,68,125,112,126,135,128,251,133,164,134,84,138,191,138,153,141,129,142,32,144,109,144,227,145,59,150,213,150,229,156,207,101,7,124,179,141,195,147,88,91,10,92,82,83,217,98,29,115,39,80,151,91,158,95,176,96,107,97,213,104,217,109,46,116,46,122,66,125,156,125,49,126,107,129,42,142,53,142,126,147,24,148,80,79,80,87,230,93,167,94,43,99,106,127,59,78,79,79,143,79,90,80,221,89,196,128,106,84,104,84,254,85,79,89,153,91,222,93,218,94,93,102,49,103,241,103,42,104,232,108,50,109,74,110,141,111,183,112,224,115,135,117,76,124,2,125,44,125,162,125,31,130,219,134,59,138,133,138,112,141,138,142,51,143,49,144,78,145,82,145,68,148,208,153,249,122,165,124,202,79,1,81,198,81,200,87,239,91,251,92,89,102,61,106,90,109,150,110,236,111,12,113,111,117,227,122,34,136,33,144,117,144,203,150,255,153,1,131,45,78,242,78,70,136,205,145,125,83,219,106,107,105,65,108,122,132,158,88,142,97,254,102,239,98,221,112,17,117,199,117,82,126,184,132,73,139,8,141,75,78,234,83,171,84,48,87,64,87,215,95,1,99,7,99,111,100,47,101,232,101,122,102,157,103,179,103,98,107,96,108,154,108,44,111,229,119,37,120,73,121,87,121,25,125,162,128,2,129,243,129,157,130,183,130,24,135,140,138,252,249,4,141,190,141,114,144,244,118,25,122,55,122,84,126,119,128,7,85,212,85,117,88,47,99,34,100,73,102,75,102,109,104,155,105,132,107,37,109,177,110,205,115,104,116,161,116,91,117,185,117,225,118,30,119,139,119,230,121,9,126,29,126,251,129,47,133,151,136,58,138,209,140,235,142,176,143,50,144,173,147,99,150,115,150,7,151,132,79,241,83,234,89,201,90,25,94,78,104,198,116,190,117,233,121,146,122,163,129,237,134,234,140,204,141,237,143,159,101,21,103,253,249,247,87,87,111,221,125,47,143,246,147,198,150,181,95,242,97,132,111,20,78,152,79,31,80,201,83,223,85,111,93,238,93,33,107,100,107,203,120,154,123,254,249,73,142,202,142,110,144,73,99,62,100,64,119,132,122,47,147,127,148,106,159,176,100,175,111,230,113,168,116,218,116,196,122,18,124,130,126,178,124,152,126,154,139,10,141,125,148,16,153,76,153,57,82,223,91,230,100,45,103,46,125,237,80,195,83,121,88,88,97,89,97,250,97,172,101,217,122,146,139,150,139,9,80,33,80,117,82,49,85,60,90,224,94,112,95,52,97,94,101,12,102,54,102,162,102,205,105,196,110,50,111,22,115,33,118,147,122,57,129,89,130,214,131,188,132,181,80,240,87,192,91,232,91,105,95,161,99,38,120,181,125,220,131,33,133,199,145,245,145,138,81,245,103,86,123,172,140,196,81,187,89,189,96,85,134,28,80,255,249,84,82,58,92,125,97,26,98,211,98,242,100,165,101,204,110,32,118,10,129,96,142,95,150,187,150,223,78,67,83,152,85,41,89,221,93,197,100,201,108,250,109,148,115,127,122,27,130,166,133,228,140,16,142,119,144,231,145,225,149,33,150,198,151,248,81,242,84,134,85,185,95,164,100,136,111,180,125,31,143,77,143,53,148,201,80,22,92,190,108,251,109,27,117,187,119,61,124,100,124,121,138,194,138,30,88,190,89,22,94,119,99,82,114,138,117,107,119,220,138,188,140,18,143,243,94,116,102,248,109,125,128,193,131,203,138,81,151,214,155,0,250,67,82,255,102,149,109,239,110,224,125,230,138,46,144,94,144,212,154,29,82,127,82,232,84,148,97,132,98,219,98,162,104,18,105,90,105,53,106,146,112,38,113,93,120,1,121,14,121,210,121,13,122,150,128,120,130,213,130,73,131,73,133,130,140,133,141,98,145,139,145,174,145,195,79,209,86,237,113,215,119,0,135,248,137,248,91,214,95,81,103,168,144,226,83,90,88,245,91,164,96,129,97,96,100,61,126,112,128,37,133,131,146,174,100,172,80,20,93,0,103,156,88,189,98,168,99,14,105,120,105,30,106,107,110,186,118,203,121,187,130,41,132,207,138,168,141,253,143,18,145,75,145,156,145,16,147,24,147,154,147,219,150,54,154,13,156,17,78,92,117,93,121,250,122,81,123,201,123,46,126,196,132,89,142,116,142,248,142,16,144,37,102,63,105,67,116,250,81,46,103,220,158,69,81,224,95,150,108,242,135,93,136,119,136,180,96,181,129,3,132,5,141,214,83,57,84,52,86,54,90,49,92,138,112,224,127,90,128,6,129,237,129,163,141,137,145,95,154,242,157,116,80,196,78,160,83,251,96,44,110,100,92,136,79,36,80,228,85,217,92,95,94,101,96,148,104,187,108,196,109,190,113,212,117,244,117,97,118,26,122,73,122,199,125,251,125,110,127,244,129,169,134,28,143,201,150,179,153,82,159,71,82,197,82,237,152,170,137,3,78,210,103,6,111,181,79,226,91,149,103,136,108,120,109,27,116,39,120,221,145,124,147,196,135,228,121,49,122,235,95,214,78,164,84,62,85,174,88,165,89,240,96,83,98,214,98,54,103,85,105,53,130,64,150,177,153,221,153,44,80,83,83,68,85,124,87,1,250,88,98,2,250,226,100,107,102,221,103,193,111,239,111,34,116,56,116,23,138,56,148,81,84,6,86,102,87,72,95,154,97,78,107,88,112,173,112,187,125,149,138,106,89,43,129,162,99,8,119,61,128,170,140,84,88,45,100,187,105,149,91,17,94,111,110,3,250,105,133,76,81,240,83,42,89,32,96,75,97,134,107,112,108,240,108,30,123,206,128,212,130,198,141,176,144,177,152,4,250,199,100,164,111,145,100,4,101,78,81,16,84,31,87,14,138,95,97,118,104,5,250,219,117,82,123,113,125,26,144,6,88,204,105,127,129,42,137,0,144,57,152,120,80,87,89,172,89,149,98,15,144,42,155,93,97,121,114,214,149,97,87,70,90,244,93,138,98,173,100,250,100,119,103,226,108,62,109,44,114,54,116,52,120,119,127,173,130,219,141,23,152,36,82,66,87,127,103,72,114,227,116,169,140,166,143,17,146,42,150,107,81,237,83,76,99,105,79,4,85,150,96,87,101,155,108,127,109,76,114,253,114,23,122,135,137,157,140,109,95,142,111,249,112,168,129,14,97,191,79,79,80,65,98,71,114,199,123,232,125,233,127,77,144,173,151,25,154,182,140,106,87,115,94,176,103,13,132,85,138,32,84,22,91,99,94,226,94,10,95,131,101,186,128,61,133,137,149,91,150,72,79,5,83,13,83,15,83,134,84,250,84,3,87,3,94,22,96,155,98,177,98,85,99,6,250,225,108,102,109,177,117,50,120,222,128,47,129,222,130,97,132,178,132,141,136,18,137,11,144,234,146,253,152,145,155,69,94,180,102,221,102,17,112,6,114,7,250,245,79,125,82,106,95,83,97,83,103,25,106,2,111,226,116,104,121,104,136,121,140,199,152,196,152,67,154,193,84,31,122,83,105,247,138,74,140,168,152,174,153,124,95,171,98,178,117,174,118,171,136,127,144,66,150,57,83,60,95,197,95,204,108,204,115,98,117,139,117,70,123,254,130,157,153,79,78,60,144,11,78,85,79,166,83,15,89,200,94,48,102,179,108,85,116,119,131,102,135,192,140,80,144,30,151,21,156,209,88,120,91,80,134,20,139,180,157,210,91,104,96,141,96,241,101,87,108,34,111,163,111,26,112,85,127,240,127,145,149,146,149,80,150,211,151,114,82,68,143,253,81,43,84,184,84,99,85,138,85,187,106,181,109,216,125,102,130,156,146,119,150,121,158,8,84,200,84,210,118,228,134,164,149,212,149,92,150,162,78,9,79,238,89,230,90,247,93,82,96,151,98,109,103,65,104,134,108,47,110,56,127,155,128,42,130,8,250,9,250,5,152,165,78,85,80,179,84,147,87,90,89,105,91,179,91,200,97,119,105,119,109,35,112,249,135,227,137,114,138,231,138,130,144,237,153,184,154,190,82,56,104,22,80,120,94,79,103,71,131,76,136,171,78,17,84,174,86,230,115,21,145,255,151,9,153,87,153,153,153,83,86,159,88,91,134,49,138,178,97,246,106,123,115,210,142,71,107,170,150,87,154,85,89,0,114,107,141,105,151,212,79,244,92,38,95,248,97,91,102,235,108,171,112,132,115,185,115,254,115,41,119,77,119,67,125,98,125,35,126,55,130,82,136,10,250,226,140,73,146,111,152,81,91,116,122,64,136,1,152,204,90,224,79,84,83,62,89,253,92,62,99,121,109,249,114,5,129,7,129,162,131,207,146,48,152,168,78,68,81,17,82,139,87,98,95,194,108,206,110,5,112,80,112,175,112,146,113,233,115,105,116,74,131,162,135,97,136,8,144,162,144,163,147,168,153,110,81,87,95,224,96,103,97,179,102,89,133,74,142,175,145,139,151,78,78,146,78,124,84,213,88,250,88,125,89,181,92,39,95,54,98,72,98,10,102,103,102,235,107,105,109,207,109,86,110,248,110,148,111,224,111,233,111,93,112,208,114,37,116,90,116,224,116,147,118,92,121,202,124,30,126,225,128,166,130,107,132,191,132,78,134,95,134,116,135,119,139,106,140,172,147,0,152,101,152,209,96,22,98,119,145,90,90,15,102,247,109,62,110,63,116,66,155,253,95,218,96,15,123,196,84,24,95,94,108,211,108,42,109,216,112,5,125,121,134,12,138,59,157,22,83,140,84,5,91,58,106,107,112,117,117,141,121,190,121,177,130,239,131,113,138,65,139,168,140,116,151,11,250,244,100,43,101,186,120,187,120,107,122,56,78,154,85,80,89,166,91,123,94,163,96,219,99,97,107,101,102,83,104,25,110,101,113,176,116,8,125,132,144,105,154,37,156,59,109,209,110,62,115,65,140,202,149,240,81,76,94,168,95,77,96,246,96,48,97,76,97,67,102,68,102,165,105,193,108,95,110,201,110,98,111,76,113,156,116,135,118,193,123,39,124,82,131,87,135,81,144,141,150,195,158,47,83,222,86,251,94,138,95,98,96,148,96,247,97,102,102,3,103,156,106,238,109,174,111,112,112,106,115,106,126,190,129,52,131,212,134,168,138,196,140,131,82,114,115,150,91,107,106,4,148,238,84,134,86,93,91,72,101,133,101,201,102,159,104,141,109,198,109,59,114,180,128,117,145,77,154,175,79,25,80,154,83,14,84,60,84,137,85,197,85,63,94,140,95,61,103,102,113,221,115,5,144,219,82,243,82,100,88,206,88,4,113,143,113,251,113,176,133,19,138,136,102,168,133,167,85,132,102,74,113,49,132,73,83,153,85,193,107,89,95,189,95,238,99,137,102,71,113,241,138,29,143,190,158,17,79,58,100,203,112,102,117,103,134,100,96,78,139,248,157,71,81,246,81,8,83,54,109,248,128,209,158,21,102,35,107,152,112,213,117,3,84,121,92,7,125,22,138,32,107,61,107,70,107,56,84,112,96,61,109,213,127,8,130,214,80,222,81,156,85,107,86,205,86,236,89,9,91,12,94,153,97,152,97,49,98,94,102,230,102,153,113,185,113,186,113,167,114,167,121,0,122,178,127,112,138,0,0,0,0,13,0,0,0,9,0,0,0,6,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,6,14,43,52,1,1,1,1,3,1,2,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,3,3,4,4,4,5,5,5,5,5,6,6,6,6,7,7,8,8,8,8,9,9,10,10,10,10,11,11,11,11,12,12,13,13,13,13,14,14,15,15,15,15,16,16,16,16,17,17,18,18,18,18,19,20,20,21,21,22,23,23,144,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,5,5,5,5,5,5,6,6,6,6,7,7,8,8,8,8,9,9,10,10,10,10,11,11,11,11,12,12,13,13,13,13,14,14,15,15,15,15,16,16,16,16,17,17,18,18,18,18,19,19,20,20,20,20,21,21,21,21,22,22,23,23,24,25,25,26,26,27,28,28,29,30,136,19,0,0,0,0,0,0,150,0,0,0,155,0,0,0,160,0,0,0,165,0,0,0,170,0,0,0,175,0,0,0,180,0,0,0,185,0,0,0,190,0,0,0,195,0,0,0,200,0,0,0,205,0,0,0,210,0,0,0,215,0,0,0,220,0,0,0,225,0,0,0,230,0,0,0,235,0,0,0,240,0,0,0,245,0,0,0,250,0,0,0,255,0,0,0,4,1,0,0,9,1,0,0,14,1,0,0,19,1,0,0,24,1,0,0,29,1,0,0,34,1,0,0,39,1,0,0,44,1,0,0,49,1,0,0,54,1,0,0,64,1,0,0,74,1,0,0,84,1,0,0,94,1,0,0,104,1,0,0,114,1,0,0,124,1,0,0,134,1,0,0,144,1,0,0,154,1,0,0,164,1,0,0,174,1,0,0,184,1,0,0,194,1,0,0,204,1,0,0,214,1,0,0,224,1,0,0,234,1,0,0,244,1,0,0,254,1,0,0,8,2,0,0,18,2,0,0,28,2,0,0,38,2,0,0,48,2,0,0,58,2,0,0,68,2,0,0,78,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,88,2,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,162,0,0,0,163,0,0,0,164,0,0,0,165,0,0,0,166,0,0,0,167,0,0,0,168,0,0,0,169,0,0,0,170,0,0,0,171,0,0,0,172,0,0,0,173,0,0,0,174,0,0,0,175,0,0,0,176,0,0,0,177,0,0,0,178,0,0,0,179,0,0,0,180,0,0,0,181,0,0,0,182,0,0,0,183,0,0,0,184,0,0,0,185,0,0,0,186,0,0,0,187,0,0,0,188,0,0,0,189,0,0,0,190,0,0,0,191,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,196,0,0,0,197,0,0,0,198,0,0,0,199,0,0,0,200,0,0,0,200,0,0,0,201,0,0,0,201,0,0,0,202,0,0,0,203,0,0,0,203,0,0,0,203,0,0,0,204,0,0,0,204,0,0,0,205,0,0,0,205,0,0,0,206,0,0,0,206,0,0,0,207,0,0,0,207,0,0,0,208,0,0,0,208,0,0,0,209,0,0,0,209,0,0,0,210,0,0,0,210,0,0,0,211,0,0,0,211,0,0,0,212,0,0,0,212,0,0,0,213,0,0,0,213,0,0,0,214,0,0,0,214,0,0,0,215,0,0,0,215,0,0,0,216,0,0,0,216,0,0,0,217,0,0,0,217,0,0,0,218,0,0,0,218,0,0,0,219,0,0,0,219,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,24,104,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,26,37,0,80,206,35,0,8,0,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,72,225,34,0,112,30,34,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,130,33,0,184,6,33,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,144,161,32,0,208,69,32,0,20,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,45,40,0,168,208,39,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,104,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,170,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,52,36,0,112,0,0,0,168,207,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,6,7,2,1,0,10,10,4,5,6,7,8,9,10,11,12,9,14,11,12,13,14,15,16,13,16,17,18,19,20,21,22,22,23,23,24,24,25,25,26,26,27,27,27,28,28,28,29,29,29,30,30,30,31,31,31,31,32,32,32,32,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,33,0,0,0,0,0,1,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,14,15,15,15,16,16,16,16,17,17,17,17,17,18,18,18,18,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,254,254,243,230,196,177,153,140,133,130,129,0,0,0,0,0,180,157,141,134,130,0,0,0,176,155,140,135,0,0,0,0,88,210,15,0,64,210,15,0,56,210,15,0,40,210,15,0,173,148,140,0,0,0,0,0,0,1,2,3,6,4,5,6,6,6,6,6,6,6,6,7,0,0,0,0,0,0,0,0,240,134,38,0,112,0,0,0,192,178,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,127,255,255,255,127,208,18,38,0,56,233,37,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,240,188,37,0,72,156,37,0,12,0,0,0,5,0,0,0,120,104,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,240,41,37,0,168,3,37,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,40,34,0,112,0,0,0,176,210,15,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,1,48,2,48,12,255,14,255,251,48,26,255,27,255,31,255,1,255,155,48,156,48,180,0,64,255,168,0,62,255,227,255,63,255,253,48,254,48,157,48,158,48,3,48,221,78,5,48,6,48,7,48,252,48,21,32,16,32,15,255,92,0,28,48,22,32,92,255,38,32,37,32,24,32,25,32,28,32,29,32,8,255,9,255,20,48,21,48,59,255,61,255,91,255,93,255,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,16,48,17,48,11,255,18,34,177,0,215,0,247,0,29,255,96,34,28,255,30,255,102,34,103,34,30,34,52,34,66,38,64,38,176,0,50,32,51,32,3,33,229,255,4,255,162,0,163,0,5,255,3,255,6,255,10,255,32,255,167,0,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,189,37,188,37,59,32,18,48,146,33,144,33,145,33,147,33,19,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,34,11,34,134,34,135,34,130,34,131,34,42,34,41,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,34,40,34,172,0,210,33,212,33,0,34,3,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,34,165,34,18,35,2,34,7,34,97,34,82,34,106,34,107,34,26,34,61,34,29,34,53,34,43,34,44,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,33,48,32,111,38,109,38,106,38,32,32,33,32,182,0,0,0,0,0,0,0,0,0,239,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,0,0,0,0,0,0,0,0,0,0,0,0,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,0,0,0,0,0,0,0,0,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,37,12,37,16,37,24,37,20,37,28,37,44,37,36,37,52,37,60,37,1,37,3,37,15,37,19,37,27,37,23,37,35,37,51,37,43,37,59,37,75,37,32,37,47,37,40,37,55,37,63,37,29,37,48,37,37,37,56,37,66,37], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1031320);
/* memory initializer */ allocate([156,78,22,85,3,90,63,150,192,84,27,97,40,99,246,89,34,144,117,132,28,131,80,122,170,96,225,99,37,110,237,101,102,132,166,130,245,155,147,104,39,87,161,101,113,98,155,91,208,89,123,134,244,152,98,125,190,125,142,155,22,98,159,124,183,136,137,91,181,94,9,99,151,102,72,104,199,149,141,151,79,103,229,78,10,79,77,79,157,79,73,80,242,86,55,89,212,89,1,90,9,92,223,96,15,97,112,97,19,102,5,105,186,112,79,117,112,117,251,121,173,125,239,125,195,128,14,132,99,136,2,139,85,144,122,144,59,83,149,78,165,78,223,87,178,128,193,144,239,120,0,78,241,88,162,110,56,144,50,122,40,131,139,130,47,156,65,81,112,83,189,84,225,84,224,86,251,89,21,95,242,152,235,109,228,128,45,133,98,150,112,150,160,150,251,151,11,84,243,83,135,91,207,112,189,127,194,143,232,150,111,83,92,157,186,122,17,78,147,120,252,129,38,110,24,86,4,85,29,107,26,133,59,156,229,89,169,83,102,109,220,116,143,149,66,86,145,78,75,144,242,150,79,131,12,153,225,83,182,85,48,91,113,95,32,102,243,102,4,104,56,108,243,108,41,109,91,116,200,118,78,122,52,152,241,130,91,136,96,138,237,146,178,109,171,117,202,118,197,153,166,96,1,139,138,141,178,149,142,105,173,83,134,81,18,87,48,88,68,89,180,91,246,94,40,96,169,99,244,99,191,108,20,111,142,112,20,113,89,113,213,113,63,115,1,126,118,130,209,130,151,133,96,144,91,146,27,157,105,88,188,101,90,108,37,117,249,81,46,89,101,89,128,95,220,95,188,98,250,101,42,106,39,107,180,107,139,115,193,127,86,137,44,157,14,157,196,158,161,92,150,108,123,131,4,81,75,92,182,97,198,129,118,104,97,114,89,78,250,79,120,83,105,96,41,110,79,122,243,151,11,78,22,83,238,78,85,79,61,79,161,79,115,79,160,82,239,83,9,86,15,89,193,90,182,91,225,91,209,121,135,102,156,103,182,103,76,107,179,108,107,112,194,115,141,121,190,121,60,122,135,123,177,130,219,130,4,131,119,131,239,131,211,131,102,135,178,138,41,86,168,140,230,143,78,144,30,151,138,134,196,79,232,92,17,98,89,114,59,117,229,129,189,130,254,134,192,140,197,150,19,153,213,153,203,78,26,79,227,137,222,86,74,88,202,88,251,94,235,95,42,96,148,96,98,96,208,97,18,98,208,98,57,101,65,155,102,102,176,104,119,109,112,112,76,117,134,118,117,125,165,130,249,135,139,149,142,150,157,140,241,81,190,82,22,89,179,84,179,91,22,93,104,97,130,105,175,109,141,120,203,132,87,136,114,138,167,147,184,154,108,109,168,153,217,134,163,87,255,103,206,134,14,146,131,82,135,86,4,84,211,94,225,98,185,100,60,104,56,104,187,107,114,115,186,120,107,122,154,137,210,137,107,141,3,143,237,144,163,149,148,150,105,151,102,91,179,92,125,105,77,152,78,152,155,99,32,123,43,106,127,106,182,104,13,156,95,111,114,82,157,85,112,96,236,98,59,109,7,110,209,110,91,132,16,137,68,143,20,78,57,156,246,83,27,105,58,106,132,151,42,104,92,81,195,122,178,132,220,145,140,147,91,86,40,157,34,104,5,131,49,132,165,124,8,82,197,130,230,116,126,78,131,79,160,81,210,91,10,82,216,82,231,82,251,93,154,85,42,88,230,89,140,91,152,91,219,91,114,94,121,94,163,96,31,97,99,97,190,97,219,99,98,101,209,103,83,104,250,104,62,107,83,107,87,108,34,111,151,111,69,111,176,116,24,117,227,118,11,119,255,122,161,123,33,124,233,125,54,127,240,127,157,128,102,130,158,131,179,137,204,138,171,140,132,144,81,148,147,149,145,149,162,149,101,150,211,151,40,153,24,130,56,78,43,84,184,92,204,93,169,115,76,118,60,119,169,92,235,127,11,141,193,150,17,152,84,152,88,152,1,79,14,79,113,83,156,85,104,86,250,87,71,89,9,91,196,91,144,92,12,94,126,94,204,95,238,99,58,103,215,101,226,101,31,103,203,104,196,104,95,106,48,94,197,107,23,108,125,108,127,117,72,121,99,91,0,122,0,125,189,95,143,137,24,138,180,140,119,141,204,142,29,143,226,152,14,154,60,155,128,78,125,80,0,81,147,89,156,91,47,98,128,98,236,100,58,107,160,114,145,117,71,121,169,127,251,135,188,138,112,139,172,99,202,131,160,151,9,84,3,84,171,85,84,104,88,106,112,138,39,120,117,103,205,158,116,83,162,91,26,129,80,134,6,144,24,78,69,78,199,78,17,79,202,83,56,84,174,91,19,95,37,96,81,101,61,103,66,108,114,108,227,108,120,112,3,116,118,122,174,122,8,123,26,125,254,124,102,125,231,101,91,114,187,83,69,92,232,93,210,98,224,98,25,99,32,110,90,134,49,138,221,141,248,146,1,111,166,121,90,155,168,78,171,78,172,78,155,79,160,79,209,80,71,81,246,122,113,81,246,81,84,83,33,83,127,83,235,83,172,85,131,88,225,92,55,95,74,95,47,96,80,96,109,96,31,99,89,101,75,106,193,108,194,114,237,114,239,119,248,128,5,129,8,130,78,133,247,144,225,147,255,151,87,153,90,154,240,78,221,81,45,92,129,102,109,105,64,92,242,102,117,105,137,115,80,104,129,124,197,80,228,82,71,87,254,93,38,147,164,101,35,107,61,107,52,116,129,121,189,121,75,123,202,125,185,130,204,131,127,136,95,137,57,139,209,143,209,145,31,84,128,146,93,78,54,80,229,83,58,83,215,114,150,115,233,119,230,130,175,142,198,153,200,153,210,153,119,81,26,97,94,134,176,85,122,122,118,80,211,91,71,144,133,150,50,78,219,106,231,145,81,92,72,92,152,99,159,122,147,108,116,151,97,143,170,122,138,113,136,150,130,124,23,104,112,126,81,104,108,147,242,82,27,84,171,133,19,138,164,127,205,142,225,144,102,83,136,136,65,121,194,79,190,80,17,82,68,81,83,85,45,87,234,115,139,87,81,89,98,95,132,95,117,96,118,97,103,97,169,97,178,99,58,100,108,101,111,102,66,104,19,110,102,117,61,122,251,124,76,125,153,125,75,126,107,127,14,131,74,131,205,134,8,138,99,138,102,139,253,142,26,152,143,157,184,130,206,143,232,155,135,82,31,98,131,100,192,111,153,150,65,104,145,80,32,107,122,108,84,111,116,122,80,125,64,136,35,138,8,103,246,78,57,80,38,80,101,80,124,81,56,82,99,82,167,85,15,87,5,88,204,90,250,94,178,97,248,97,243,98,114,99,28,105,41,106,125,114,172,114,46,115,20,120,111,120,121,125,12,119,169,128,139,137,25,139,226,140,210,142,99,144,117,147,122,150,85,152,19,154,120,158,67,81,159,83,179,83,123,94,38,95,27,110,144,110,132,115,254,115,67,125,55,130,0,138,250,138,80,150,78,78,11,80,228,83,124,84,250,86,209,89,100,91,241,93,171,94,39,95,56,98,69,101,175,103,86,110,208,114,202,124,180,136,161,128,225,128,240,131,78,134,135,138,232,141,55,146,199,150,103,152,19,159,148,78,146,78,13,79,72,83,73,84,62,84,47,90,140,95,161,95,159,96,167,104,142,106,90,116,129,120,158,138,164,138,119,139,144,145,94,78,201,155,164,78,124,79,175,79,25,80,22,80,73,81,108,81,159,82,185,82,254,82,154,83,227,83,17,84,14,84,137,85,81,87,162,87,125,89,84,91,93,91,143,91,229,93,231,93,247,93,120,94,131,94,154,94,183,94,24,95,82,96,76,97,151,98,216,98,167,99,59,101,2,102,67,102,244,102,109,103,33,104,151,104,203,105,95,108,42,109,105,109,47,110,157,110,50,117,135,118,108,120,63,122,224,124,5,125,24,125,94,125,177,125,21,128,3,128,175,128,177,128,84,129,143,129,42,130,82,131,76,136,97,136,27,139,162,140,252,140,202,144,117,145,113,146,63,120,252,146,164,149,77,150,5,152,153,153,216,154,59,157,91,82,171,82,247,83,8,84,213,88,247,98,224,111,106,140,95,143,185,158,75,81,59,82,74,84,253,86,64,122,119,145,96,157,210,158,68,115,9,111,112,129,17,117,253,95,218,96,168,154,219,114,188,143,100,107,3,152,202,78,240,86,100,87,190,88,90,90,104,96,199,97,15,102,6,102,57,104,177,104,247,109,213,117,58,125,110,130,66,155,155,78,80,79,201,83,6,85,111,93,230,93,238,93,251,103,153,108,115,116,2,120,80,138,150,147,223,136,80,87,167,94,43,99,181,80,172,80,141,81,0,103,201,84,94,88,187,89,176,91,105,95,77,98,161,99,61,104,115,107,8,110,125,112,199,145,128,114,21,120,38,120,109,121,142,101,48,125,220,131,193,136,9,143,155,150,100,82,40,87,80,103,106,127,161,140,180,81,66,87,42,150,58,88,138,105,180,128,178,84,14,93,252,87,149,120,250,157,92,79,74,82,139,84,62,100,40,102,20,103,245,103,132,122,86,123,34,125,47,147,92,104,173,155,57,123,25,83,138,81,55,82,223,91,246,98,174,100,230,100,45,103,186,107,169,133,209,150,144,118,214,155,76,99,6,147,171,155,191,118,82,102,9,78,152,80,194,83,113,92,232,96,146,100,99,101,95,104,230,113,202,115,35,117,151,123,130,126,149,134,131,139,219,140,120,145,16,153,172,101,171,102,139,107,213,78,212,78,58,79,127,79,58,82,248,83,242,83,227,85,219,86,235,88,203,89,201,89,255,89,80,91,77,92,2,94,43,94,215,95,29,96,7,99,47,101,92,91,175,101,189,101,232,101,157,103,98,107,123,107,15,108,69,115,73,121,193,121,248,124,25,125,43,125,162,128,2,129,243,129,150,137,94,138,105,138,102,138,140,138,238,138,199,140,220,140,204,150,252,152,111,107,139,78,60,79,141,79,80,81,87,91,250,91,72,97,1,99,66,102,33,107,203,110,187,108,62,114,189,116,212,117,193,120,58,121,12,128,51,128,234,129,148,132,158,143,80,108,127,158,15,95,88,139,43,157,250,122,248,142,141,91,235,150,3,78,241,83,247,87,49,89,201,90,164,91,137,96,127,110,6,111,190,117,234,140,159,91,0,133,224,123,114,80,244,103,157,130,97,92,74,133,30,126,14,130,153,81,4,92,104,99,102,141,156,101,110,113,62,121,23,125,5,128,29,139,202,142,110,144,199,134,170,144,31,80,250,82,58,92,83,103,124,112,53,114,76,145,200,145,43,147,229,130,194,91,49,95,249,96,59,78,214,83,136,91,75,98,49,103,138,107,233,114,224,115,46,122,107,129,163,141,82,145,150,153,18,81,215,83,106,84,255,91,136,99,57,106,172,125,0,151,218,86,206,83,104,84,151,91,49,92,222,93,238,79,1,97,254,98,50,109,192,121,203,121,66,125,77,126,210,127,237,129,31,130,144,132,70,136,114,137,144,139,116,142,47,143,49,144,75,145,108,145,198,150,156,145,192,78,79,79,69,81,65,83,147,95,14,98,212,103,65,108,11,110,99,115,38,126,205,145,131,146,212,83,25,89,191,91,209,109,93,121,46,126,155,124,126,88,159,113,250,81,83,136,240,143,202,79,251,92,37,102,172,119,227,122,28,130,255,153,198,81,170,95,236,101,111,105,137,107,243,109,150,110,100,111,254,118,20,125,225,93,117,144,135,145,6,152,230,81,29,82,64,98,145,102,217,102,26,110,182,94,210,125,114,127,248,102,175,133,247,133,248,138,169,82,217,83,115,89,143,94,144,95,85,96,228,146,100,150,183,80,31,81,221,82,32,83,71,83,236,83,232,84,70,85,49,85,23,86,104,89,190,89,60,90,181,91,6,92,15,92,17,92,26,92,132,94,138,94,224,94,112,95,127,98,132,98,219,98,140,99,119,99,7,102,12,102,45,102,118,102,126,103,162,104,31,106,53,106,188,108,136,109,9,110,88,110,60,113,38,113,103,113,199,117,1,119,93,120,1,121,101,121,240,121,224,122,17,123,167,124,57,125,150,128,214,131,139,132,73,133,93,136,243,136,31,138,60,138,84,138,115,138,97,140,222,140,164,145,102,146,126,147,24,148,156,150,152,151,10,78,8,78,30,78,87,78,151,81,112,82,206,87,52,88,204,88,34,91,56,94,197,96,254,100,97,103,86,103,68,109,182,114,115,117,99,122,184,132,114,139,184,145,32,147,49,86,244,87,254,152,237,98,13,105,150,107,237,113,84,126,119,128,114,130,230,137,223,152,85,135,177,143,59,92,56,79,225,79,181,79,7,85,32,90,221,91,233,91,195,95,78,97,47,99,176,101,75,102,238,104,155,105,120,109,241,109,51,117,185,117,31,119,94,121,230,121,51,125,227,129,175,130,170,133,170,137,58,138,171,142,155,143,50,144,221,145,7,151,186,78,193,78,3,82,117,88,236,88,11,92,26,117,61,92,78,129,10,138,197,143,99,150,109,151,37,123,207,138,8,152,98,145,243,86,168,83,23,144,57,84,130,87,37,94,168,99,52,108,138,112,97,119,139,124,224,127,112,136,66,144,84,145,16,147,24,147,143,150,94,116,196,154,7,93,105,93,112,101,162,103,168,141,219,150,110,99,73,103,25,105,197,131,23,152,192,150,254,136,132,111,122,100,248,91,22,78,44,112,93,117,47,102,196,81,54,82,226,82,211,89,129,95,39,96,16,98,63,101,116,101,31,102,116,102,242,104,22,104,99,107,5,110,114,114,31,117,219,118,190,124,86,128,240,88,253,136,127,137,160,138,147,138,203,138,29,144,146,145,82,151,89,151,137,101,14,122,6,129,187,150,45,94,220,96,26,98,165,101,20,102,144,103,243,119,77,122,77,124,62,126,10,129,172,140,100,141,225,141,95,142,169,120,7,82,217,98,165,99,66,100,152,98,45,138,131,122,192,123,172,138,234,150,118,125,12,130,73,135,217,78,72,81,67,83,96,83,163,91,2,92,22,92,221,93,38,98,71,98,176,100,19,104,52,104,201,108,69,109,23,109,211,103,92,111,78,113,125,113,203,101,127,122,173,123,218,125,74,126,168,127,122,129,27,130,57,130,166,133,110,138,206,140,245,141,120,144,119,144,173,146,145,146,131,149,174,155,77,82,132,85,56,111,54,113,104,81,133,121,85,126,179,129,206,124,76,86,81,88,168,92,170,99,254,102,253,102,90,105,217,114,143,117,142,117,14,121,86,121,223,121,151,124,32,125,68,125,7,134,52,138,59,150,97,144,32,159,231,80,117,82,204,83,226,83,9,80,170,85,238,88,79,89,61,114,139,91,100,92,29,83,227,96,243,96,92,99,131,99,63,99,187,99,205,100,233,101,249,102,227,93,205,105,253,105,21,111,229,113,137,78,233,117,248,118,147,122,223,124,207,125,156,125,97,128,73,131,88,131,108,132,188,132,251,133,197,136,112,141,1,144,109,144,151,147,28,151,18,154,207,80,151,88,142,97,211,129,53,133,8,141,32,144,195,79,116,80,71,82,115,83,111,96,73,99,95,103,44,110,179,141,31,144,215,79,94,92,202,140,207,101,154,125,82,83,150,136,118,81,195,99,88,91,107,91,10,92,13,100,81,103,92,144,214,78,26,89,42,89,112,108,81,138,62,85,21,88,165,89,240,96,83,98,193,103,53,130,85,105,64,150,196,153,40,154,83,79,6,88,254,91,16,128,177,92,47,94,133,95,32,96,75,97,52,98,255,102,240,108,222,110,206,128,127,129,212,130,139,136,184,140,0,144,46,144,138,150,219,158,219,155,227,78,240,83,39,89,44,123,141,145,76,152,249,157,221,110,39,112,83,83,68,85,133,91,88,98,158,98,211,98,162,108,239,111,34,116,23,138,56,148,193,111,254,138,56,131,231,81,248,134,234,83,233,83,70,79,84,144,176,143,106,89,49,129,253,93,234,122,191,143,218,104,55,140,248,114,72,156,61,106,176,138,57,78,88,83,6,86,102,87,197,98,162,99,230,101,78,107,225,109,91,110,173,112,237,119,239,122,170,123,187,125,61,128,198,128,203,134,149,138,91,147,227,86,199,88,62,95,173,101,150,102,128,106,181,107,55,117,199,138,36,80,229,119,48,87,27,95,101,96,122,102,96,108,244,117,26,122,110,127,244,129,24,135,69,144,179,153,201,123,92,117,249,122,81,123,196,132,16,144,233,121,146,122,54,131,225,90,64,119,45,78,242,78,153,91,224,95,189,98,60,102,241,103,232,108,107,134,119,136,59,138,78,145,243,146,208,153,23,106,38,112,42,115,231,130,87,132,175,140,1,78,70,81,203,81,139,85,245,91,22,94,51,94,129,94,20,95,53,95,107,95,180,95,242,97,17,99,162,102,29,103,110,111,82,114,58,117,58,119,116,128,57,129,120,129,118,135,191,138,220,138,133,141,243,141,154,146,119,149,2,152,229,156,197,82,87,99,244,118,21,103,136,108,205,115,195,140,174,147,115,150,37,109,156,88,14,105,204,105,253,143,154,147,219,117,26,144,90,88,2,104,180,99,251,105,67,79,44,111,216,103,187,143,38,133,180,125,84,147,63,105,112,111,106,87,247,88,44,91,44,125,42,114,10,84,227,145,180,157,173,78,78,79,92,80,117,80,67,82,158,140,72,84,36,88,154,91,29,94,149,94,173,94,247,94,31,95,140,96,181,98,58,99,208,99,175,104,64,108,135,120,142,121,11,122,224,125,71,130,2,138,230,138,68,142,19,144,184,144,45,145,216,145,14,159,229,108,88,100,226,100,117,101,244,110,132,118,27,123,105,144,209,147,186,110,242,84,185,95,164,100,77,143,237,143,68,146,120,81,107,88,41,89,85,92,151,94,251,109,143,126,28,117,188,140,226,142,91,152,185,112,29,79,191,107,177,111,48,117,251,150,78,81,16,84,53,88,87,88,172,89,96,92,146,95,151,101,92,103,33,110,123,118,223,131,237,140,20,144,253,144,77,147,37,120,58,120,170,82,166,94,31,87,116,89,18,96,18,80,90,81,172,81,205,81,0,82,16,85,84,88,88,88,87,89,149,91,246,92,139,93,188,96,149,98,45,100,113,103,67,104,188,104,223,104,215,118,216,109,111,110,155,109,111,112,200,113,83,95,216,117,119,121,73,123,84,123,82,123,214,124,113,125,48,82,99,132,105,133,228,133,14,138,4,139,70,140,15,142,3,144,15,144,25,148,118,150,45,152,48,154,216,149,205,80,213,82,12,84,2,88,14,92,167,97,158,100,30,109,179,119,229,122,244,128,4,132,83,144,133,146,224,92,7,157,63,83,151,95,179,95,156,109,121,114,99,119,191,121,228,123,210,107,236,114,173,138,3,104,97,106,248,81,129,122,52,105,74,92,246,156,235,130,197,91,73,145,30,112,120,86,111,92,199,96,102,101,140,108,90,140,65,144,19,152,81,84,199,102,13,146,72,89,163,144,133,81,77,78,234,81,153,133,14,139,88,112,122,99,75,147,98,105,180,153,4,126,119,117,87,83,96,105,223,142,227,150,93,108,140,78,60,92,16,95,233,143,2,83,209,140,137,128,121,134,255,94,229,101,115,78,101,81,130,89,63,92,238,151,251,78,138,89,205,95,141,138,225,111,176,121,98,121,231,91,113,132,43,115,177,113,116,94,245,95,123,99,154,100,195,113,152,124,67,78,252,94,75,78,220,87,162,86,169,96,195,111,13,125,253,128,51,129,191,129,178,143,151,137,164,134,244,93,138,98,173,100,135,137,119,103,226,108,62,109,54,116,52,120,70,90,117,127,173,130,172,153,243,79,195,94,221,98,146,99,87,101,111,103,195,118,76,114,204,128,186,128,41,143,77,145,13,80,249,87,146,90,133,104,115,105,100,113,253,114,183,140,242,88,224,140,106,150,25,144,127,135,228,121,231,119,41,132,47,79,101,82,90,83,205,98,207,103,202,108,125,118,148,123,149,124,54,130,132,133,235,143,221,102,32,111,6,114,27,126,171,131,193,153,166,158,253,81,177,123,114,120,184,123,135,128,72,123,232,106,97,94,140,128,81,117,96,117,107,81,98,146,140,110,122,118,151,145,234,154,16,79,112,127,156,98,79,123,165,149,233,156,122,86,89,88,228,134,188,150,52,79,36,82,74,83,205,83,219,83,6,94,44,100,145,101,127,103,62,108,78,108,72,114,175,114,237,115,84,117,65,126,44,130,233,133,169,140,196,123,198,145,105,113,18,152,239,152,61,99,105,102,106,117,228,118,208,120,67,133,238,134,42,83,81,83,38,84,131,89,135,94,124,95,178,96,73,98,121,98,171,98,144,101,212,107,204,108,178,117,174,118,145,120,216,121,203,125,119,127,165,128,171,136,185,138,187,140,127,144,94,151,219,152,11,106,56,124,153,80,62,92,174,95,135,103,216,107,53,116,9,119,142,127,59,159,202,103,23,122,57,83,139,117,237,154,102,95,157,129,241,131,152,128,60,95,197,95,98,117,70,123,60,144,103,104,235,89,155,90,16,125,126,118,44,139,245,79,106,95,25,106,55,108,2,111,226,116,104,121,104,136,85,138,121,140,223,94,207,99,197,117,210,121,215,130,40,147,242,146,156,132,237,134,45,156,193,84,108,95,140,101,92,109,21,112,167,140,211,140,59,152,79,101,246,116,13,78,216,78,224,87,43,89,102,90,204,91,168,81,3,94,156,94,22,96,118,98,119,101,167,101,110,102,110,109,54,114,38,123,80,129,154,129,153,130,92,139,160,140,230,140,116,141,28,150,68,150,174,79,171,100,102,107,30,130,97,132,106,133,232,144,1,92,83,105,168,152,122,132,87,133,15,79,111,82,169,95,69,94,13,103,143,121,121,129,7,137,134,137,245,109,23,95,85,98,184,108,207,78,105,114,146,155,6,82,59,84,116,86,179,88,164,97,110,98,26,113,110,89,137,124,222,124,27,125,240,150,135,101,94,128,25,78,117,79,117,81,64,88,99,94,115,94,10,95,196,103,38,78,61,133,137,149,91,150,115,124,1,152,251,80,193,88,86,118,167,120,37,82,165,119,17,133,134,123,79,80,9,89,71,114,199,123,232,125,186,143,212,143,77,144,191,79,201,82,41,90,1,95,173,151,221,79,23,130,234,146,3,87,85,99,105,107,43,117,220,136,20,143,66,122,223,82,147,88,85,97,10,98,174,102,205,107,63,124,233,131,35,80,248,79,5,83,70,84,49,88,73,89,157,91,240,92,239,92,41,93,150,94,177,98,103,99,62,101,185,101,11,103,213,108,225,108,249,112,50,120,43,126,222,128,179,130,12,132,236,132,2,135,18,137,42,138,74,140,166,144,210,146,253,152,243,156,108,157,79,78,161,78,141,80,86,82,74,87,168,89,61,94,216,95,217,95,63,98,180,102,27,103,208,103,210,104,146,81,33,125,170,128,168,129,0,139,140,140,191,140,126,146,50,150,32,84,44,152,23,83,213,80,92,83,168,88,178,100,52,103,103,114,102,119,70,122,230,145,195,82,161,108,134,107,0,88,76,94,84,89,44,103,251,127,225,81,198,118,105,100,232,120,84,155,187,158,203,87,185,89,39,102,154,103,206,107,233,84,217,105,85,94,156,129,149,103,170,155,254,103,82,156,93,104,166,78,227,79,200,83,185,98,43,103,171,108,196,143,173,79,109,126,191,158,7,78,98,97,128,110,43,111,19,133,115,84,42,103,69,155,243,93,149,123,172,92,198,91,28,135,74,110,209,132,20,122,8,129,153,89,141,124,17,108,32,119,217,82,34,89,33,113,95,114,219,119,39,151,97,157,11,105,127,90,24,90,165,81,13,84,125,84,14,102,223,118,247,143,152,146,244,156,234,89,93,114,197,110,77,81,201,104,191,125,236,125,98,151,186,158,120,100,33,106,2,131,132,89,95,91,219,107,27,115,242,118,178,125,23,128,153,132,50,81,40,103,217,158,238,118,98,103,255,82,5,153,36,92,59,98,126,124,176,140,79,85,182,96,11,125,128,149,1,83,95,78,182,81,28,89,58,114,54,128,206,145,37,95,226,119,132,83,121,95,4,125,172,133,51,138,141,142,86,151,243,103,174,133,83,148,9,97,8,97,185,108,82,118,237,138,56,143,47,85,81,79,42,81,199,82,203,83,165,91,125,94,160,96,130,97,214,99,9,103,218,103,103,110,140,109,54,115,55,115,49,117,80,121,213,136,152,138,74,144,145,144,245,144,196,150,141,135,21,89,136,78,89,79,14,78,137,138,63,143,16,152,173,80,124,94,150,89,185,91,184,94,218,99,250,99,193,100,220,102,74,105,216,105,11,109,182,110,148,113,40,117,175,122,138,127,0,128,73,132,201,132,129,137,33,139,10,142,101,144,125,150,10,153,126,97,145,98,50,107,131,108,116,109,204,127,252,127,192,109,133,127,186,135,248,136,101,103,177,131,60,152,247,150,27,109,97,125,61,132,106,145,113,78,117,83,80,93,4,107,235,111,205,133,45,134,167,137,41,82,15,84,101,92,78,103,168,104,6,116,131,116,226,117,207,136,225,136,204,145,226,150,120,150,139,95,135,115,203,122,78,132,160,99,101,117,137,82,65,109,156,110,9,116,89,117,107,120,146,124,134,150,220,122,141,159,182,79,110,97,197,101,92,134,134,78,174,78,218,80,33,78,204,81,238,91,153,101,129,104,188,109,31,115,66,118,173,119,28,122,231,124,111,130,210,138,124,144,207,145,117,150,24,152,155,82,209,125,43,80,152,83,151,103,203,109,208,113,51,116,232,129,42,143,163,150,87,156,159,158,96,116,65,88,153,109,47,125,94,152,228,78,54,79,139,79,183,81,177,82,186,93,28,96,178,115,60,121,211,130,52,146,183,150,246,150,10,151,151,158,98,159,166,102,116,107,23,82,163,82,200,112,194,136,201,94,75,96,144,97,35,111,73,113,62,124,244,125,111,128,238,132,35,144,44,147,66,84,111,155,211,106,137,112,194,140,239,141,50,151,180,82,65,90,202,94,4,95,23,103,124,105,148,105,106,109,15,111,98,114,252,114,237,123,1,128,126,128,75,135,206,144,109,81,147,158,132,121,139,128,50,147,214,138,45,80,140,84,113,138,106,107,196,140,7,129,209,96,160,103,242,157,153,78,152,78,16,156,107,138,193,133,104,133,0,105,126,110,151,120,85,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,95,16,78,21,78,42,78,49,78,54,78,60,78,63,78,66,78,86,78,88,78,130,78,133,78,107,140,138,78,18,130,13,95,142,78,158,78,159,78,160,78,162,78,176,78,179,78,182,78,206,78,205,78,196,78,198,78,194,78,215,78,222,78,237,78,223,78,247,78,9,79,90,79,48,79,91,79,93,79,87,79,71,79,118,79,136,79,143,79,152,79,123,79,105,79,112,79,145,79,111,79,134,79,150,79,24,81,212,79,223,79,206,79,216,79,219,79,209,79,218,79,208,79,228,79,229,79,26,80,40,80,20,80,42,80,37,80,5,80,28,79,246,79,33,80,41,80,44,80,254,79,239,79,17,80,6,80,67,80,71,80,3,103,85,80,80,80,72,80,90,80,86,80,108,80,120,80,128,80,154,80,133,80,180,80,178,80,201,80,202,80,179,80,194,80,214,80,222,80,229,80,237,80,227,80,238,80,249,80,245,80,9,81,1,81,2,81,22,81,21,81,20,81,26,81,33,81,58,81,55,81,60,81,59,81,63,81,64,81,82,81,76,81,84,81,98,81,248,122,105,81,106,81,110,81,128,81,130,81,216,86,140,81,137,81,143,81,145,81,147,81,149,81,150,81,164,81,166,81,162,81,169,81,170,81,171,81,179,81,177,81,178,81,176,81,181,81,189,81,197,81,201,81,219,81,224,81,85,134,233,81,237,81,240,81,245,81,254,81,4,82,11,82,20,82,14,82,39,82,42,82,46,82,51,82,57,82,79,82,68,82,75,82,76,82,94,82,84,82,106,82,116,82,105,82,115,82,127,82,125,82,141,82,148,82,146,82,113,82,136,82,145,82,168,143,167,143,172,82,173,82,188,82,181,82,193,82,205,82,215,82,222,82,227,82,230,82,237,152,224,82,243,82,245,82,248,82,249,82,6,83,8,83,56,117,13,83,16,83,15,83,21,83,26,83,35,83,47,83,49,83,51,83,56,83,64,83,70,83,69,83,23,78,73,83,77,83,214,81,94,83,105,83,110,83,24,89,123,83,119,83,130,83,150,83,160,83,166,83,165,83,174,83,176,83,182,83,195,83,18,124,217,150,223,83,252,102,238,113,238,83,232,83,237,83,250,83,1,84,61,84,64,84,44,84,45,84,60,84,46,84,54,84,41,84,29,84,78,84,143,84,117,84,142,84,95,84,113,84,119,84,112,84,146,84,123,84,128,84,118,84,132,84,144,84,134,84,199,84,162,84,184,84,165,84,172,84,196,84,200,84,168,84,171,84,194,84,164,84,190,84,188,84,216,84,229,84,230,84,15,85,20,85,253,84,238,84,237,84,250,84,226,84,57,85,64,85,99,85,76,85,46,85,92,85,69,85,86,85,87,85,56,85,51,85,93,85,153,85,128,85,175,84,138,85,159,85,123,85,126,85,152,85,158,85,174,85,124,85,131,85,169,85,135,85,168,85,218,85,197,85,223,85,196,85,220,85,228,85,212,85,20,86,247,85,22,86,254,85,253,85,27,86,249,85,78,86,80,86,223,113,52,86,54,86,50,86,56,86,107,86,100,86,47,86,108,86,106,86,134,86,128,86,138,86,160,86,148,86,143,86,165,86,174,86,182,86,180,86,194,86,188,86,193,86,195,86,192,86,200,86,206,86,209,86,211,86,215,86,238,86,249,86,0,87,255,86,4,87,9,87,8,87,11,87,13,87,19,87,24,87,22,87,199,85,28,87,38,87,55,87,56,87,78,87,59,87,64,87,79,87,105,87,192,87,136,87,97,87,127,87,137,87,147,87,160,87,179,87,164,87,170,87,176,87,195,87,198,87,212,87,210,87,211,87,10,88,214,87,227,87,11,88,25,88,29,88,114,88,33,88,98,88,75,88,112,88,192,107,82,88,61,88,121,88,133,88,185,88,159,88,171,88,186,88,222,88,187,88,184,88,174,88,197,88,211,88,209,88,215,88,217,88,216,88,229,88,220,88,228,88,223,88,239,88,250,88,249,88,251,88,252,88,253,88,2,89,10,89,16,89,27,89,166,104,37,89,44,89,45,89,50,89,56,89,62,89,210,122,85,89,80,89,78,89,90,89,88,89,98,89,96,89,103,89,108,89,105,89,120,89,129,89,157,89,94,79,171,79,163,89,178,89,198,89,232,89,220,89,141,89,217,89,218,89,37,90,31,90,17,90,28,90,9,90,26,90,64,90,108,90,73,90,53,90,54,90,98,90,106,90,154,90,188,90,190,90,203,90,194,90,189,90,227,90,215,90,230,90,233,90,214,90,250,90,251,90,12,91,11,91,22,91,50,91,208,90,42,91,54,91,62,91,67,91,69,91,64,91,81,91,85,91,90,91,91,91,101,91,105,91,112,91,115,91,117,91,120,91,136,101,122,91,128,91,131,91,166,91,184,91,195,91,199,91,201,91,212,91,208,91,228,91,230,91,226,91,222,91,229,91,235,91,240,91,246,91,243,91,5,92,7,92,8,92,13,92,19,92,32,92,34,92,40,92,56,92,57,92,65,92,70,92,78,92,83,92,80,92,79,92,113,91,108,92,110,92,98,78,118,92,121,92,140,92,145,92,148,92,155,89,171,92,187,92,182,92,188,92,183,92,197,92,190,92,199,92,217,92,233,92,253,92,250,92,237,92,140,93,234,92,11,93,21,93,23,93,92,93,31,93,27,93,17,93,20,93,34,93,26,93,25,93,24,93,76,93,82,93,78,93,75,93,108,93,115,93,118,93,135,93,132,93,130,93,162,93,157,93,172,93,174,93,189,93,144,93,183,93,188,93,201,93,205,93,211,93,210,93,214,93,219,93,235,93,242,93,245,93,11,94,26,94,25,94,17,94,27,94,54,94,55,94,68,94,67,94,64,94,78,94,87,94,84,94,95,94,98,94,100,94,71,94,117,94,118,94,122,94,188,158,127,94,160,94,193,94,194,94,200,94,208,94,207,94,214,94,227,94,221,94,218,94,219,94,226,94,225,94,232,94,233,94,236,94,241,94,243,94,240,94,244,94,248,94,254,94,3,95,9,95,93,95,92,95,11,95,17,95,22,95,41,95,45,95,56,95,65,95,72,95,76,95,78,95,47,95,81,95,86,95,87,95,89,95,97,95,109,95,115,95,119,95,131,95,130,95,127,95,138,95,136,95,145,95,135,95,158,95,153,95,152,95,160,95,168,95,173,95,188,95,214,95,251,95,228,95,248,95,241,95,221,95,179,96,255,95,33,96,96,96,25,96,16,96,41,96,14,96,49,96,27,96,21,96,43,96,38,96,15,96,58,96,90,96,65,96,106,96,119,96,95,96,74,96,70,96,77,96,99,96,67,96,100,96,66,96,108,96,107,96,89,96,129,96,141,96,231,96,131,96,154,96,132,96,155,96,150,96,151,96,146,96,167,96,139,96,225,96,184,96,224,96,211,96,180,96,240,95,189,96,198,96,181,96,216,96,77,97,21,97,6,97,246,96,247,96,0,97,244,96,250,96,3,97,33,97,251,96,241,96,13,97,14,97,71,97,62,97,40,97,39,97,74,97,63,97,60,97,44,97,52,97,61,97,66,97,68,97,115,97,119,97,88,97,89,97,90,97,107,97,116,97,111,97,101,97,113,97,95,97,93,97,83,97,117,97,153,97,150,97,135,97,172,97,148,97,154,97,138,97,145,97,171,97,174,97,204,97,202,97,201,97,247,97,200,97,195,97,198,97,186,97,203,97,121,127,205,97,230,97,227,97,246,97,250,97,244,97,255,97,253,97,252,97,254,97,0,98,8,98,9,98,13,98,12,98,20,98,27,98,30,98,33,98,42,98,46,98,48,98,50,98,51,98,65,98,78,98,94,98,99,98,91,98,96,98,104,98,124,98,130,98,137,98,126,98,146,98,147,98,150,98,212,98,131,98,148,98,215,98,209,98,187,98,207,98,255,98,198,98,212,100,200,98,220,98,204,98,202,98,194,98,199,98,155,98,201,98,12,99,238,98,241,98,39,99,2,99,8,99,239,98,245,98,80,99,62,99,77,99,28,100,79,99,150,99,142,99,128,99,171,99,118,99,163,99,143,99,137,99,159,99,181,99,107,99,105,99,190,99,233,99,192,99,198,99,227,99,201,99,210,99,246,99,196,99,22,100,52,100,6,100,19,100,38,100,54,100,29,101,23,100,40,100,15,100,103,100,111,100,118,100,78,100,42,101,149,100,147,100,165,100,169,100,136,100,188,100,218,100,210,100,197,100,199,100,187,100,216,100,194,100,241,100,231,100,9,130,224,100,225,100,172,98,227,100,239,100,44,101,246,100,244,100,242,100,250,100,0,101,253,100,24,101,28,101,5,101,36,101,35,101,43,101,52,101,53,101,55,101,54,101,56,101,75,117,72,101,86,101,85,101,77,101,88,101,94,101,93,101,114,101,120,101,130,101,131,101,138,139,155,101,159,101,171,101,183,101,195,101,198,101,193,101,196,101,204,101,210,101,219,101,217,101,224,101,225,101,241,101,114,103,10,102,3,102,251,101,115,103,53,102,54,102,52,102,28,102,79,102,68,102,73,102,65,102,94,102,93,102,100,102,103,102,104,102,95,102,98,102,112,102,131,102,136,102,142,102,137,102,132,102,152,102,157,102,193,102,185,102,201,102,190,102,188,102,196,102,184,102,214,102,218,102,224,102,63,102,230,102,233,102,240,102,245,102,247,102,15,103,22,103,30,103,38,103,39,103,56,151,46,103,63,103,54,103,65,103,56,103,55,103,70,103,94,103,96,103,89,103,99,103,100,103,137,103,112,103,169,103,124,103,106,103,140,103,139,103,166,103,161,103,133,103,183,103,239,103,180,103,236,103,179,103,233,103,184,103,228,103,222,103,221,103,226,103,238,103,185,103,206,103,198,103,231,103,156,106,30,104,70,104,41,104,64,104,77,104,50,104,78,104,179,104,43,104,89,104,99,104,119,104,127,104,159,104,143,104,173,104,148,104,157,104,155,104,131,104,174,106,185,104,116,104,181,104,160,104,186,104,15,105,141,104,126,104,1,105,202,104,8,105,216,104,34,105,38,105,225,104,12,105,205,104,212,104,231,104,213,104,54,105,18,105,4,105,215,104,227,104,37,105,249,104,224,104,239,104,40,105,42,105,26,105,35,105,33,105,198,104,121,105,119,105,92,105,120,105,107,105,84,105,126,105,110,105,57,105,116,105,61,105,89,105,48,105,97,105,94,105,93,105,129,105,106,105,178,105,174,105,208,105,191,105,193,105,211,105,190,105,206,105,232,91,202,105,221,105,187,105,195,105,167,105,46,106,145,105,160,105,156,105,149,105,180,105,222,105,232,105,2,106,27,106,255,105,10,107,249,105,242,105,231,105,5,106,177,105,30,106,237,105,20,106,235,105,10,106,18,106,193,106,35,106,19,106,68,106,12,106,114,106,54,106,120,106,71,106,98,106,89,106,102,106,72,106,56,106,34,106,144,106,141,106,160,106,132,106,162,106,163,106,151,106,23,134,187,106,195,106,194,106,184,106,179,106,172,106,222,106,209,106,223,106,170,106,218,106,234,106,251,106,5,107,22,134,250,106,18,107,22,107,49,155,31,107,56,107,55,107,220,118,57,107,238,152,71,107,67,107,73,107,80,107,89,107,84,107,91,107,95,107,97,107,120,107,121,107,127,107,128,107,132,107,131,107,141,107,152,107,149,107,158,107,164,107,170,107,171,107,175,107,178,107,177,107,179,107,183,107,188,107,198,107,203,107,211,107,223,107,236,107,235,107,243,107,239,107,190,158,8,108,19,108,20,108,27,108,36,108,35,108,94,108,85,108,98,108,106,108,130,108,141,108,154,108,129,108,155,108,126,108,104,108,115,108,146,108,144,108,196,108,241,108,211,108,189,108,215,108,197,108,221,108,174,108,177,108,190,108,186,108,219,108,239,108,217,108,234,108,31,109,77,136,54,109,43,109,61,109,56,109,25,109,53,109,51,109,18,109,12,109,99,109,147,109,100,109,90,109,121,109,89,109,142,109,149,109,228,111,133,109,249,109,21,110,10,110,181,109,199,109,230,109,184,109,198,109,236,109,222,109,204,109,232,109,210,109,197,109,250,109,217,109,228,109,213,109,234,109,238,109,45,110,110,110,46,110,25,110,114,110,95,110,62,110,35,110,107,110,43,110,118,110,77,110,31,110,67,110,58,110,78,110,36,110,255,110,29,110,56,110,130,110,170,110,152,110,201,110,183,110,211,110,189,110,175,110,196,110,178,110,212,110,213,110,143,110,165,110,194,110,159,110,65,111,17,111,76,112,236,110,248,110,254,110,63,111,242,110,49,111,239,110,50,111,204,110,62,111,19,111,247,110,134,111,122,111,120,111,129,111,128,111,111,111,91,111,243,111,109,111,130,111,124,111,88,111,142,111,145,111,194,111,102,111,179,111,163,111,161,111,164,111,185,111,198,111,170,111,223,111,213,111,236,111,212,111,216,111,241,111,238,111,219,111,9,112,11,112,250,111,17,112,1,112,15,112,254,111,27,112,26,112,116,111,29,112,24,112,31,112,48,112,62,112,50,112,81,112,99,112,153,112,146,112,175,112,241,112,172,112,184,112,179,112,174,112,223,112,203,112,221,112,217,112,9,113,253,112,28,113,25,113,101,113,85,113,136,113,102,113,98,113,76,113,86,113,108,113,143,113,251,113,132,113,149,113,168,113,172,113,215,113,185,113,190,113,210,113,201,113,212,113,206,113,224,113,236,113,231,113,245,113,252,113,249,113,255,113,13,114,16,114,27,114,40,114,45,114,44,114,48,114,50,114,59,114,60,114,63,114,64,114,70,114,75,114,88,114,116,114,126,114,130,114,129,114,135,114,146,114,150,114,162,114,167,114,185,114,178,114,195,114,198,114,196,114,206,114,210,114,226,114,224,114,225,114,249,114,247,114,15,80,23,115,10,115,28,115,22,115,29,115,52,115,47,115,41,115,37,115,62,115,78,115,79,115,216,158,87,115,106,115,104,115,112,115,120,115,117,115,123,115,122,115,200,115,179,115,206,115,187,115,192,115,229,115,238,115,222,115,162,116,5,116,111,116,37,116,248,115,50,116,58,116,85,116,63,116,95,116,89,116,65,116,92,116,105,116,112,116,99,116,106,116,118,116,126,116,139,116,158,116,167,116,202,116,207,116,212,116,241,115,224,116,227,116,231,116,233,116,238,116,242,116,240,116,241,116,248,116,247,116,4,117,3,117,5,117,12,117,14,117,13,117,21,117,19,117,30,117,38,117,44,117,60,117,68,117,77,117,74,117,73,117,91,117,70,117,90,117,105,117,100,117,103,117,107,117,109,117,120,117,118,117,134,117,135,117,116,117,138,117,137,117,130,117,148,117,154,117,157,117,165,117,163,117,194,117,179,117,195,117,181,117,189,117,184,117,188,117,177,117,205,117,202,117,210,117,217,117,227,117,222,117,254,117,255,117,252,117,1,118,240,117,250,117,242,117,243,117,11,118,13,118,9,118,31,118,39,118,32,118,33,118,34,118,36,118,52,118,48,118,59,118,71,118,72,118,70,118,92,118,88,118,97,118,98,118,104,118,105,118,106,118,103,118,108,118,112,118,114,118,118,118,120,118,124,118,128,118,131,118,136,118,139,118,142,118,150,118,147,118,153,118,154,118,176,118,180,118,184,118,185,118,186,118,194,118,205,118,214,118,210,118,222,118,225,118,229,118,231,118,234,118,47,134,251,118,8,119,7,119,4,119,41,119,36,119,30,119,37,119,38,119,27,119,55,119,56,119,71,119,90,119,104,119,107,119,91,119,101,119,127,119,126,119,121,119,142,119,139,119,145,119,160,119,158,119,176,119,182,119,185,119,191,119,188,119,189,119,187,119,199,119,205,119,215,119,218,119,220,119,227,119,238,119,252,119,12,120,18,120,38,121,32,120,42,121,69,120,142,120,116,120,134,120,124,120,154,120,140,120,163,120,181,120,170,120,175,120,209,120,198,120,203,120,212,120,190,120,188,120,197,120,202,120,236,120,231,120,218,120,253,120,244,120,7,121,18,121,17,121,25,121,44,121,43,121,64,121,96,121,87,121,95,121,90,121,85,121,83,121,122,121,127,121,138,121,157,121,167,121,75,159,170,121,174,121,179,121,185,121,186,121,201,121,213,121,231,121,236,121,225,121,227,121,8,122,13,122,24,122,25,122,32,122,31,122,128,121,49,122,59,122,62,122,55,122,67,122,87,122,73,122,97,122,98,122,105,122,157,159,112,122,121,122,125,122,136,122,151,122,149,122,152,122,150,122,169,122,200,122,176,122,182,122,197,122,196,122,191,122,131,144,199,122,202,122,205,122,207,122,213,122,211,122,217,122,218,122,221,122,225,122,226,122,230,122,237,122,240,122,2,123,15,123,10,123,6,123,51,123,24,123,25,123,30,123,53,123,40,123,54,123,80,123,122,123,4,123,77,123,11,123,76,123,69,123,117,123,101,123,116,123,103,123,112,123,113,123,108,123,110,123,157,123,152,123,159,123,141,123,156,123,154,123,139,123,146,123,143,123,93,123,153,123,203,123,193,123,204,123,207,123,180,123,198,123,221,123,233,123,17,124,20,124,230,123,229,123,96,124,0,124,7,124,19,124,243,123,247,123,23,124,13,124,246,123,35,124,39,124,42,124,31,124,55,124,43,124,61,124,76,124,67,124,84,124,79,124,64,124,80,124,88,124,95,124,100,124,86,124,101,124,108,124,117,124,131,124,144,124,164,124,173,124,162,124,171,124,161,124,168,124,179,124,178,124,177,124,174,124,185,124,189,124,192,124,197,124,194,124,216,124,210,124,220,124,226,124,59,155,239,124,242,124,244,124,246,124,250,124,6,125,2,125,28,125,21,125,10,125,69,125,75,125,46,125,50,125,63,125,53,125,70,125,115,125,86,125,78,125,114,125,104,125,110,125,79,125,99,125,147,125,137,125,91,125,143,125,125,125,155,125,186,125,174,125,163,125,181,125,199,125,189,125,171,125,61,126,162,125,175,125,220,125,184,125,159,125,176,125,216,125,221,125,228,125,222,125,251,125,242,125,225,125,5,126,10,126,35,126,33,126,18,126,49,126,31,126,9,126,11,126,34,126,70,126,102,126,59,126,53,126,57,126,67,126,55,126,50,126,58,126,103,126,93,126,86,126,94,126,89,126,90,126,121,126,106,126,105,126,124,126,123,126,131,126,213,125,125,126,174,143,127,126,136,126,137,126,140,126,146,126,144,126,147,126,148,126,150,126,142,126,155,126,156,126,56,127,58,127,69,127,76,127,77,127,78,127,80,127,81,127,85,127,84,127,88,127,95,127,96,127,104,127,105,127,103,127,120,127,130,127,134,127,131,127,136,127,135,127,140,127,148,127,158,127,157,127,154,127,163,127,175,127,178,127,185,127,174,127,182,127,184,127,113,139,197,127,198,127,202,127,213,127,212,127,225,127,230,127,233,127,243,127,249,127,220,152], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1040028);
/* memory initializer */ allocate([6,128,4,128,11,128,18,128,24,128,25,128,28,128,33,128,40,128,63,128,59,128,74,128,70,128,82,128,88,128,90,128,95,128,98,128,104,128,115,128,114,128,112,128,118,128,121,128,125,128,127,128,132,128,134,128,133,128,155,128,147,128,154,128,173,128,144,81,172,128,219,128,229,128,217,128,221,128,196,128,218,128,214,128,9,129,239,128,241,128,27,129,41,129,35,129,47,129,75,129,139,150,70,129,62,129,83,129,81,129,252,128,113,129,110,129,101,129,102,129,116,129,131,129,136,129,138,129,128,129,130,129,160,129,149,129,164,129,163,129,95,129,147,129,169,129,176,129,181,129,190,129,184,129,189,129,192,129,194,129,186,129,201,129,205,129,209,129,217,129,216,129,200,129,218,129,223,129,224,129,231,129,250,129,251,129,254,129,1,130,2,130,5,130,7,130,10,130,13,130,16,130,22,130,41,130,43,130,56,130,51,130,64,130,89,130,88,130,93,130,90,130,95,130,100,130,98,130,104,130,106,130,107,130,46,130,113,130,119,130,120,130,126,130,141,130,146,130,171,130,159,130,187,130,172,130,225,130,227,130,223,130,210,130,244,130,243,130,250,130,147,131,3,131,251,130,249,130,222,130,6,131,220,130,9,131,217,130,53,131,52,131,22,131,50,131,49,131,64,131,57,131,80,131,69,131,47,131,43,131,23,131,24,131,133,131,154,131,170,131,159,131,162,131,150,131,35,131,142,131,135,131,138,131,124,131,181,131,115,131,117,131,160,131,137,131,168,131,244,131,19,132,235,131,206,131,253,131,3,132,216,131,11,132,193,131,247,131,7,132,224,131,242,131,13,132,34,132,32,132,189,131,56,132,6,133,251,131,109,132,42,132,60,132,90,133,132,132,119,132,107,132,173,132,110,132,130,132,105,132,70,132,44,132,111,132,121,132,53,132,202,132,98,132,185,132,191,132,159,132,217,132,205,132,187,132,218,132,208,132,193,132,198,132,214,132,161,132,33,133,255,132,244,132,23,133,24,133,44,133,31,133,21,133,20,133,252,132,64,133,99,133,88,133,72,133,65,133,2,134,75,133,85,133,128,133,164,133,136,133,145,133,138,133,168,133,109,133,148,133,155,133,234,133,135,133,156,133,119,133,126,133,144,133,201,133,186,133,207,133,185,133,208,133,213,133,221,133,229,133,220,133,249,133,10,134,19,134,11,134,254,133,250,133,6,134,34,134,26,134,48,134,63,134,77,134,85,78,84,134,95,134,103,134,113,134,147,134,163,134,169,134,170,134,139,134,140,134,182,134,175,134,196,134,198,134,176,134,201,134,35,136,171,134,212,134,222,134,233,134,236,134,223,134,219,134,239,134,18,135,6,135,8,135,0,135,3,135,251,134,17,135,9,135,13,135,249,134,10,135,52,135,63,135,55,135,59,135,37,135,41,135,26,135,96,135,95,135,120,135,76,135,78,135,116,135,87,135,104,135,110,135,89,135,83,135,99,135,106,135,5,136,162,135,159,135,130,135,175,135,203,135,189,135,192,135,208,135,214,150,171,135,196,135,179,135,199,135,198,135,187,135,239,135,242,135,224,135,15,136,13,136,254,135,246,135,247,135,14,136,210,135,17,136,22,136,21,136,34,136,33,136,49,136,54,136,57,136,39,136,59,136,68,136,66,136,82,136,89,136,94,136,98,136,107,136,129,136,126,136,158,136,117,136,125,136,181,136,114,136,130,136,151,136,146,136,174,136,153,136,162,136,141,136,164,136,176,136,191,136,177,136,195,136,196,136,212,136,216,136,217,136,221,136,249,136,2,137,252,136,244,136,232,136,242,136,4,137,12,137,10,137,19,137,67,137,30,137,37,137,42,137,43,137,65,137,68,137,59,137,54,137,56,137,76,137,29,137,96,137,94,137,102,137,100,137,109,137,106,137,111,137,116,137,119,137,126,137,131,137,136,137,138,137,147,137,152,137,161,137,169,137,166,137,172,137,175,137,178,137,186,137,189,137,191,137,192,137,218,137,220,137,221,137,231,137,244,137,248,137,3,138,22,138,16,138,12,138,27,138,29,138,37,138,54,138,65,138,91,138,82,138,70,138,72,138,124,138,109,138,108,138,98,138,133,138,130,138,132,138,168,138,161,138,145,138,165,138,166,138,154,138,163,138,196,138,205,138,194,138,218,138,235,138,243,138,231,138,228,138,241,138,20,139,224,138,226,138,247,138,222,138,219,138,12,139,7,139,26,139,225,138,22,139,16,139,23,139,32,139,51,139,171,151,38,139,43,139,62,139,40,139,65,139,76,139,79,139,78,139,73,139,86,139,91,139,90,139,107,139,95,139,108,139,111,139,116,139,125,139,128,139,140,139,142,139,146,139,147,139,150,139,153,139,154,139,58,140,65,140,63,140,72,140,76,140,78,140,80,140,85,140,98,140,108,140,120,140,122,140,130,140,137,140,133,140,138,140,141,140,142,140,148,140,124,140,152,140,29,98,173,140,170,140,189,140,178,140,179,140,174,140,182,140,200,140,193,140,228,140,227,140,218,140,253,140,250,140,251,140,4,141,5,141,10,141,7,141,15,141,13,141,16,141,78,159,19,141,205,140,20,141,22,141,103,141,109,141,113,141,115,141,129,141,153,141,194,141,190,141,186,141,207,141,218,141,214,141,204,141,219,141,203,141,234,141,235,141,223,141,227,141,252,141,8,142,9,142,255,141,29,142,30,142,16,142,31,142,66,142,53,142,48,142,52,142,74,142,71,142,73,142,76,142,80,142,72,142,89,142,100,142,96,142,42,142,99,142,85,142,118,142,114,142,124,142,129,142,135,142,133,142,132,142,139,142,138,142,147,142,145,142,148,142,153,142,170,142,161,142,172,142,176,142,198,142,177,142,190,142,197,142,200,142,203,142,219,142,227,142,252,142,251,142,235,142,254,142,10,143,5,143,21,143,18,143,25,143,19,143,28,143,31,143,27,143,12,143,38,143,51,143,59,143,57,143,69,143,66,143,62,143,76,143,73,143,70,143,78,143,87,143,92,143,98,143,99,143,100,143,156,143,159,143,163,143,173,143,175,143,183,143,218,143,229,143,226,143,234,143,239,143,135,144,244,143,5,144,249,143,250,143,17,144,21,144,33,144,13,144,30,144,22,144,11,144,39,144,54,144,53,144,57,144,248,143,79,144,80,144,81,144,82,144,14,144,73,144,62,144,86,144,88,144,94,144,104,144,111,144,118,144,168,150,114,144,130,144,125,144,129,144,128,144,138,144,137,144,143,144,168,144,175,144,177,144,181,144,226,144,228,144,72,98,219,144,2,145,18,145,25,145,50,145,48,145,74,145,86,145,88,145,99,145,101,145,105,145,115,145,114,145,139,145,137,145,130,145,162,145,171,145,175,145,170,145,181,145,180,145,186,145,192,145,193,145,201,145,203,145,208,145,214,145,223,145,225,145,219,145,252,145,245,145,246,145,30,146,255,145,20,146,44,146,21,146,17,146,94,146,87,146,69,146,73,146,100,146,72,146,149,146,63,146,75,146,80,146,156,146,150,146,147,146,155,146,90,146,207,146,185,146,183,146,233,146,15,147,250,146,68,147,46,147,25,147,34,147,26,147,35,147,58,147,53,147,59,147,92,147,96,147,124,147,110,147,86,147,176,147,172,147,173,147,148,147,185,147,214,147,215,147,232,147,229,147,216,147,195,147,221,147,208,147,200,147,228,147,26,148,20,148,19,148,3,148,7,148,16,148,54,148,43,148,53,148,33,148,58,148,65,148,82,148,68,148,91,148,96,148,98,148,94,148,106,148,41,146,112,148,117,148,119,148,125,148,90,148,124,148,126,148,129,148,127,148,130,149,135,149,138,149,148,149,150,149,152,149,153,149,160,149,168,149,167,149,173,149,188,149,187,149,185,149,190,149,202,149,246,111,195,149,205,149,204,149,213,149,212,149,214,149,220,149,225,149,229,149,226,149,33,150,40,150,46,150,47,150,66,150,76,150,79,150,75,150,119,150,92,150,94,150,93,150,95,150,102,150,114,150,108,150,141,150,152,150,149,150,151,150,170,150,167,150,177,150,178,150,176,150,180,150,182,150,184,150,185,150,206,150,203,150,201,150,205,150,77,137,220,150,13,151,213,150,249,150,4,151,6,151,8,151,19,151,14,151,17,151,15,151,22,151,25,151,36,151,42,151,48,151,57,151,61,151,62,151,68,151,70,151,72,151,66,151,73,151,92,151,96,151,100,151,102,151,104,151,210,82,107,151,113,151,121,151,133,151,124,151,129,151,122,151,134,151,139,151,143,151,144,151,156,151,168,151,166,151,163,151,179,151,180,151,195,151,198,151,200,151,203,151,220,151,237,151,79,159,242,151,223,122,246,151,245,151,15,152,12,152,56,152,36,152,33,152,55,152,61,152,70,152,79,152,75,152,107,152,111,152,112,152,113,152,116,152,115,152,170,152,175,152,177,152,182,152,196,152,195,152,198,152,233,152,235,152,3,153,9,153,18,153,20,153,24,153,33,153,29,153,30,153,36,153,32,153,44,153,46,153,61,153,62,153,66,153,73,153,69,153,80,153,75,153,81,153,82,153,76,153,85,153,151,153,152,153,165,153,173,153,174,153,188,153,223,153,219,153,221,153,216,153,209,153,237,153,238,153,241,153,242,153,251,153,248,153,1,154,15,154,5,154,226,153,25,154,43,154,55,154,69,154,66,154,64,154,67,154,62,154,85,154,77,154,91,154,87,154,95,154,98,154,101,154,100,154,105,154,107,154,106,154,173,154,176,154,188,154,192,154,207,154,209,154,211,154,212,154,222,154,223,154,226,154,227,154,230,154,239,154,235,154,238,154,244,154,241,154,247,154,251,154,6,155,24,155,26,155,31,155,34,155,35,155,37,155,39,155,40,155,41,155,42,155,46,155,47,155,50,155,68,155,67,155,79,155,77,155,78,155,81,155,88,155,116,155,147,155,131,155,145,155,150,155,151,155,159,155,160,155,168,155,180,155,192,155,202,155,185,155,198,155,207,155,209,155,210,155,227,155,226,155,228,155,212,155,225,155,58,156,242,155,241,155,240,155,21,156,20,156,9,156,19,156,12,156,6,156,8,156,18,156,10,156,4,156,46,156,27,156,37,156,36,156,33,156,48,156,71,156,50,156,70,156,62,156,90,156,96,156,103,156,118,156,120,156,231,156,236,156,240,156,9,157,8,157,235,156,3,157,6,157,42,157,38,157,175,157,35,157,31,157,68,157,21,157,18,157,65,157,63,157,62,157,70,157,72,157,93,157,94,157,100,157,81,157,80,157,89,157,114,157,137,157,135,157,171,157,111,157,122,157,154,157,164,157,169,157,178,157,196,157,193,157,187,157,184,157,186,157,198,157,207,157,194,157,217,157,211,157,248,157,230,157,237,157,239,157,253,157,26,158,27,158,30,158,117,158,121,158,125,158,129,158,136,158,139,158,140,158,146,158,149,158,145,158,157,158,165,158,169,158,184,158,170,158,173,158,97,151,204,158,206,158,207,158,208,158,212,158,220,158,222,158,221,158,224,158,229,158,232,158,239,158,244,158,246,158,247,158,249,158,251,158,252,158,253,158,7,159,8,159,183,118,21,159,33,159,44,159,62,159,74,159,82,159,84,159,99,159,95,159,96,159,97,159,102,159,103,159,108,159,106,159,119,159,114,159,118,159,149,159,156,159,160,159,47,88,199,105,89,144,100,116,220,81,153,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,4,5,4,4,4,6,6,0,0,0,0,0,0,0,0,12,0,0,0,0,2,2,3,3,3,3,5,3,2,2,2,0,0,0,0,12,0,0,0,0,2,3,4,3,3,3,3,4,3,2,2,0,0,0,0,12,0,0,0,0,3,4,4,3,3,3,3,3,2,2,2,0,0,0,0,13,0,0,0,0,4,4,3,3,3,3,2,3,3,2,1,1,0,0,0,9,0,0,0,0,4,4,4,4,3,3,3,2,0,0,0,0,0,0,0,10,0,0,0,0,4,4,4,4,3,3,2,2,2,0,0,0,0,0,0,12,0,0,0,0,4,4,4,3,3,2,3,2,2,2,2,0,0,0,0,10,0,0,0,1,2,3,4,4,7,5,5,4,1,0,0,0,0,0,0,11,0,0,0,2,3,4,4,4,7,5,4,3,3,2,0,0,0,0,0,12,0,0,0,2,4,5,5,5,5,6,4,4,3,1,1,0,0,0,0,13,0,0,0,3,3,4,4,5,6,6,4,4,3,2,1,1,0,0,0,11,0,0,0,3,4,4,5,5,5,6,5,4,2,2,0,0,0,0,0,13,0,0,0,3,4,5,5,5,5,6,4,3,3,2,1,1,0,0,0,13,0,0,0,3,4,5,5,5,6,5,4,3,3,2,1,1,0,0,0,9,0,0,0,3,4,4,5,5,5,6,5,5,0,0,0,0,0,0,0,11,14,16,18,20,22,23,24,26,28,30,32,34,36,39,40,42,45,47,49,52,55,57,60,1,16,18,20,22,24,27,30,34,37,40,44,48,52,56,61,66,71,76,82,88,94,101,108,19,34,39,42,45,51,54,60,65,69,73,78,83,88,93,99,105,111,117,124,130,136,142,149,19,31,33,36,39,41,45,47,52,55,58,61,64,68,72,76,79,82,86,90,94,98,102,107,49,66,71,71,77,82,88,88,93,99,103,107,111,115,120,124,128,132,137,142,147,152,157,164,11,17,19,20,21,22,24,26,27,29,32,34,35,37,40,42,46,50,53,57,61,65,68,74,7,20,22,24,27,30,34,37,41,45,49,53,58,63,68,74,80,86,92,99,106,113,120,126,21,37,40,45,48,52,58,61,66,72,76,81,86,91,96,101,107,112,118,124,130,136,143,151,19,31,32,34,37,40,43,45,48,51,54,57,60,63,66,69,72,75,78,82,86,90,94,98,60,82,88,93,99,104,104,109,115,120,124,128,132,137,142,147,152,157,163,169,173,177,181,186,1,11,11,13,13,13,14,15,16,17,19,20,21,22,23,24,25,26,27,28,29,30,31,32,11,13,13,14,17,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,160,120,80,60,40,30,176,120,88,60,88,72,44,36,60,45,160,60,176,60,20,15,22,18,0,0,0,0,0,0,0,0,26,0,46,0,54,0,66,0,70,0,74,0,78,0,90,0,46,0,50,0,62,0,66,0,70,0,78,0,86,0,106,0,54,0,62,0,62,0,68,0,74,0,84,0,102,0,114,0,66,0,66,0,68,0,74,0,82,0,98,0,108,0,122,0,70,0,70,0,74,0,82,0,94,0,102,0,114,0,142,0,74,0,78,0,84,0,98,0,102,0,110,0,134,0,166,0,78,0,86,0,102,0,108,0,114,0,134,0,154,0,202,0,90,0,106,0,114,0,122,0,142,0,166,0,202,0,254,0,38,0,58,0,62,0,70,0,74,0,78,0,82,0,90,0,58,0,62,0,66,0,70,0,74,0,78,0,86,0,94,0,62,0,66,0,70,0,72,0,76,0,82,0,90,0,98,0,70,0,70,0,72,0,74,0,78,0,86,0,94,0,102,0,74,0,74,0,76,0,78,0,82,0,90,0,98,0,106,0,78,0,78,0,82,0,86,0,90,0,94,0,102,0,110,0,82,0,86,0,90,0,94,0,98,0,102,0,106,0,114,0,90,0,94,0,98,0,102,0,106,0,110,0,114,0,118,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,78,0,78,0,78,0,78,0,78,0,78,0,78,0,170,0,170,0,170,0,170,0,170,0,170,0,170,0,170,0,242,0,242,0,242,0,242,0,242,0,242,0,242,0,242,0,212,0,212,0,212,0,212,0,212,0,212,0,212,0,212,0,222,0,222,0,222,0,222,0,222,0,222,0,222,0,222,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,214,0,214,0,214,0,214,0,214,0,214,0,214,0,214,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,38,0,58,0,62,0,70,0,74,0,78,0,82,0,90,0,58,0,62,0,66,0,70,0,74,0,78,0,86,0,94,0,62,0,66,0,70,0,72,0,76,0,82,0,90,0,98,0,70,0,70,0,72,0,74,0,78,0,86,0,94,0,102,0,74,0,74,0,76,0,78,0,82,0,90,0,98,0,106,0,78,0,78,0,82,0,86,0,90,0,94,0,102,0,110,0,82,0,86,0,90,0,94,0,98,0,102,0,106,0,114,0,90,0,94,0,98,0,102,0,106,0,110,0,114,0,118,0,38,0,58,0,62,0,70,0,74,0,78,0,82,0,90,0,58,0,62,0,66,0,70,0,74,0,78,0,86,0,94,0,62,0,66,0,70,0,72,0,76,0,82,0,90,0,98,0,70,0,70,0,72,0,74,0,78,0,86,0,94,0,102,0,74,0,74,0,76,0,78,0,82,0,90,0,98,0,106,0,78,0,78,0,82,0,86,0,90,0,94,0,102,0,110,0,82,0,86,0,90,0,94,0,98,0,102,0,106,0,114,0,90,0,94,0,98,0,102,0,106,0,110,0,114,0,118,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,170,0,242,0,212,0,222,0,194,0,214,0,194,0,78,0,78,0,78,0,78,0,78,0,78,0,78,0,78,0,170,0,170,0,170,0,170,0,170,0,170,0,170,0,170,0,242,0,242,0,242,0,242,0,242,0,242,0,242,0,242,0,212,0,212,0,212,0,212,0,212,0,212,0,212,0,212,0,222,0,222,0,222,0,222,0,222,0,222,0,222,0,222,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,214,0,214,0,214,0,214,0,214,0,214,0,214,0,214,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,194,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,94,0,30,0,62,0,74,0,82,0,62,0,74,0,82,0,94,0,74,0,82,0,94,0,122,0,82,0,94,0,122,0,146,0,30,0,62,0,74,0,82,0,62,0,74,0,82,0,86,0,74,0,82,0,86,0,94,0,82,0,86,0,94,0,102,0,0,4,8,12,1,5,9,13,2,6,10,14,3,7,11,15,43,0,86,1,129,1,214,1,43,2,43,2,86,2,214,2,86,1,86,1,214,1,1,2,43,2,86,2,214,2,1,3,129,1,214,1,43,2,43,2,86,2,214,2,214,2,43,3,214,1,214,1,43,2,43,2,86,2,214,2,1,3,86,3,214,1,43,2,43,2,86,2,171,2,214,2,86,3,1,4,43,2,43,2,86,2,171,2,214,2,86,3,1,4,129,4,43,2,43,2,86,2,214,2,43,3,214,3,171,4,171,5,43,2,86,2,214,2,43,3,214,3,171,4,171,5,1,7,86,0,171,4,86,9,86,9,1,19,1,19,1,19,1,19,171,4,171,4,86,9,86,9,1,19,1,19,1,19,1,19,86,9,86,9,1,19,1,19,171,26,171,26,171,26,171,26,86,9,86,9,1,19,1,19,171,26,171,26,171,26,171,26,1,19,1,19,171,26,171,26,171,26,171,26,171,26,171,26,1,19,1,19,171,26,171,26,171,26,171,26,171,26,171,26,1,19,1,19,171,26,171,26,171,26,171,26,171,26,171,26,1,19,1,19,171,26,171,26,171,26,171,26,171,26,171,26,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,235,0,43,4,171,4,43,5,171,5,43,6,171,6,43,7,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,129,3,129,3,129,3,129,3,129,3,129,3,129,3,129,3,43,4,43,4,43,4,43,4,43,4,43,4,43,4,43,4,214,4,214,4,214,4,214,4,214,4,214,4,214,4,214,4,129,5,129,5,129,5,129,5,129,5,129,5,129,5,129,5,43,6,43,6,43,6,43,6,43,6,43,6,43,6,43,6,214,6,214,6,214,6,214,6,214,6,214,6,214,6,214,6,129,7,129,7,129,7,129,7,129,7,129,7,129,7,129,7,43,8,43,8,43,8,43,8,43,8,43,8,43,8,43,8,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,86,9,22,0,171,0,214,0,1,1,1,1,43,1,43,1,86,1,171,0,171,0,1,1,1,1,43,1,43,1,86,1,129,1,214,0,1,1,1,1,43,1,43,1,86,1,86,1,129,1,1,1,1,1,1,1,43,1,43,1,86,1,129,1,171,1,1,1,1,1,43,1,43,1,86,1,129,1,171,1,1,2,1,1,43,1,43,1,86,1,129,1,171,1,1,2,86,2,43,1,43,1,43,1,129,1,129,1,214,1,86,2,214,2,43,1,43,1,129,1,129,1,214,1,86,2,214,2,129,3,86,0,86,2,171,4,171,4,86,9,86,9,86,9,86,9,86,2,86,2,171,4,171,4,86,9,86,9,86,9,86,9,171,4,171,4,86,9,86,9,86,13,86,13,86,13,86,13,171,4,171,4,86,9,86,9,86,13,86,13,86,13,86,13,86,9,86,9,86,13,86,13,86,13,86,13,86,13,86,13,86,9,86,9,86,13,86,13,86,13,86,13,86,13,86,13,86,9,86,9,86,13,86,13,86,13,86,13,86,13,86,13,86,9,86,9,86,13,86,13,86,13,86,13,86,13,86,13,171,1,171,1,214,1,171,1,171,1,171,1,214,1,214,1,171,1,171,1,214,1,171,1,171,1,171,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,171,1,171,1,214,1,214,1,171,1,171,1,214,1,214,1,171,1,171,1,214,1,171,1,171,1,171,1,214,1,214,1,171,1,171,1,214,1,171,1,171,1,171,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,214,1,171,6,171,6,129,9,129,9,86,13,86,13,86,13,86,13,171,6,171,6,129,9,129,9,86,13,86,13,86,13,86,13,129,9,129,9,86,13,86,13,214,18,214,18,214,18,214,18,129,9,129,9,86,13,86,13,214,18,214,18,214,18,214,18,86,13,86,13,214,18,214,18,86,13,86,13,86,13,86,13,86,13,86,13,214,18,214,18,86,13,86,13,86,13,86,13,86,13,86,13,214,18,214,18,86,13,86,13,86,13,86,13,86,13,86,13,214,18,214,18,86,13,86,13,86,13,86,13,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,171,4,171,4,1,5,214,4,171,4,171,4,1,5,1,5,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,129,9,129,9,129,9,129,9,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,214,4,214,4,214,4,214,4,214,4,214,4,214,4,214,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,171,4,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,86,13,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,129,9,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,171,6,86,0,171,0,171,0,214,0,214,0,214,0,214,0,1,1,171,0,171,0,214,0,214,0,214,0,214,0,1,1,1,1,171,0,214,0,214,0,214,0,214,0,1,1,1,1,1,1,214,0,214,0,214,0,214,0,1,1,1,1,1,1,43,1,214,0,214,0,214,0,1,1,1,1,1,1,43,1,43,1,214,0,214,0,1,1,1,1,1,1,43,1,43,1,43,1,214,0,1,1,1,1,1,1,43,1,43,1,43,1,86,1,1,1,1,1,1,1,43,1,43,1,43,1,86,1,86,1,86,3,86,3,171,4,171,4,171,6,171,6,171,6,171,6,86,3,86,3,171,4,171,4,171,6,171,6,171,6,171,6,171,4,171,4,171,6,171,6,86,9,86,9,86,9,86,9,171,4,171,4,171,6,171,6,86,9,86,9,86,9,86,9,171,6,171,6,86,9,86,9,171,6,171,6,171,6,171,6,171,6,171,6,86,9,86,9,171,6,171,6,171,6,171,6,171,6,171,6,86,9,86,9,171,6,171,6,171,6,171,6,171,6,171,6,86,9,86,9,171,6,171,6,171,6,171,6,22,0,214,0,1,1,43,1,214,0,1,1,43,1,86,1,1,1,43,1,86,1,171,1,43,1,86,1,171,1,1,2,129,0,1,4,171,5,171,5,1,4,1,4,171,5,171,5,171,5,171,5,1,8,1,8,171,5,171,5,1,8,1,8,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,43,0,43,0,43,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,107,0,214,0,1,1,43,1,214,0,1,1,43,1,43,1,1,1,43,1,43,1,86,1,43,1,43,1,86,1,86,1,1,2,1,4,214,4,214,4,1,4,1,4,214,4,214,4,214,4,214,4,171,5,171,5,214,4,214,4,171,5,171,5,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,171,0,171,0,171,0,43,0,43,0,43,0,43,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,171,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,43,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,128,2,224,1,64,1,240,0,160,0,120,0,192,2,224,1,96,1,240,0,96,1,32,1,176,0,144,0,0,0,0,0,0,8,1,9,16,24,2,3,17,25,10,11,32,40,48,56,4,5,6,7,33,41,49,57,18,19,26,27,12,13,14,15,34,35,43,42,50,51,59,58,20,21,22,23,31,30,29,28,36,37,38,39,47,46,45,44,52,53,54,55,63,62,61,60,0,1,4,5,8,12,2,3,9,13,6,7,10,11,14,15,0,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,8,0,0,0,6,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,1,0,0,0,255,255,255,255,255,255,255,255,1,0,0,0,168,134,32,0,112,0,0,0,80,119,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,59,35,0,112,0,0,0,192,196,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,102,230,62,205,204,76,63,143,194,117,63,0,0,128,63,226,2,46,5,32,9,250,13,244,17,30,22,55,26,50,30,46,34,25,38,209,41,208,45,33,50,147,54,195,58,197,15,0,37,16,0,64,40,16,0,64,38,16,0,64,39,16,0,160,37,16,0,64,40,16,0,253,49,81,63,225,64,200,60,63,144,156,61,9,193,170,188,177,191,44,189,132,127,145,60,206,0,151,60,150,63,31,189,227,111,219,61,26,48,56,190,20,176,13,62,220,126,121,188,229,127,114,189,199,47,188,61,6,16,30,190,21,112,47,62,5,192,120,189,216,159,4,189,217,95,54,189,250,207,10,62,92,255,174,188,237,183,38,190,32,8,16,62,59,0,98,60,79,64,147,188,10,128,209,189,201,143,184,61,61,96,30,61,174,127,23,189,63,224,161,189,19,96,88,61,66,96,229,61,245,215,11,190,194,192,243,188,21,56,9,62,243,143,158,189,158,63,237,60,133,95,42,189,156,192,244,188,14,48,51,62,249,135,229,62,240,247,179,62,178,127,30,61,252,143,172,189,244,55,49,190,250,207,106,62,34,252,139,186,21,112,175,189,197,255,189,189,237,183,22,62,15,128,184,61,253,159,131,190,252,143,236,61,236,223,53,61,26,48,136,61,245,243,134,190,255,151,123,62,193,111,131,189,118,192,53,189,171,63,194,60,128,127,10,61,199,15,149,189,51,224,140,61,128,128,53,188,82,128,168,188,193,111,131,189,237,239,60,62,232,135,49,190,42,0,6,61,203,47,195,61,6,16,30,190,231,255,37,62,197,143,145,189,63,0,233,189,19,96,88,62,19,16,243,189,60,191,168,60,80,224,93,189,88,255,103,58,6,132,158,62,1,172,29,63,1,116,151,62,0,96,204,61,254,207,214,189,255,255,178,61,255,191,35,190,0,160,70,61,255,159,41,189,2,0,150,60,252,79,243,61,255,31,59,189,0,128,174,188,1,96,22,61,2,8,36,190,1,224,21,61,255,215,39,62,1,0,58,189,255,63,176,188,0,112,180,189,255,255,118,61,3,128,224,60,254,63,180,60,252,63,242,189,0,24,4,62,3,192,31,190,0,0,72,62,0,0,1,189,3,168,19,190,250,207,255,61,0,0,8,190,0,80,200,61,0,32,133,61,1,128,121,189,1,96,101,189,0,128,165,61,255,63,95,189,4,0,75,188,255,63,143,60,255,63,155,61,253,127,225,189,0,48,196,61,0,96,42,189,1,96,160,189,251,255,237,61,255,191,159,188,0,48,128,189,0,64,135,188,1,128,148,61,254,191,245,61,2,176,67,190,255,255,50,61,0,16,225,189,253,199,24,62,252,255,56,60,2,192,141,60,255,95,17,189,0,96,178,189,255,63,111,61,4,0,156,58,255,31,151,189,254,223,215,61,255,239,185,61,2,80,251,189,255,111,214,61,0,68,60,63,1,112,163,62,255,119,36,190,255,191,190,188,0,0,128,61,253,191,231,188,255,31,91,61,254,175,207,189,0,64,138,61,255,255,162,60,0,32,134,189,0,112,155,61,255,47,221,189,254,103,0,62,0,176,131,189,251,255,58,188,254,127,156,188,3,112,5,62,255,103,43,190,0,176,139,61,0,64,104,61,255,15,173,189,1,0,186,60,0,128,14,61,255,191,190,188,0,224,73,189,4,192,253,61,0,240,14,190,0,96,186,61,255,95,17,189,0,192,182,60,0,64,9,189,3,192,200,60,1,0,167,59,0,128,178,188,255,127,151,60,254,255,139,188,255,191,159,60,1,0,172,58,255,191,92,189,0,192,201,61,0,224,173,189,0,64,166,60,255,191,190,60,1,0,233,59,0,64,122,189,255,95,33,61,0,224,105,61,1,224,216,189,0,0,1,61,0,96,169,61,254,127,252,189,0,128,226,61,2,176,3,190,254,95,37,62,3,112,5,190,255,95,67,61,254,255,87,59,3,0,145,188,255,63,77,61,0,160,153,189,255,63,239,60,255,255,135,60,0,192,158,61,253,131,108,63,21,112,239,61,7,64,252,189,223,191,185,61,143,255,2,189,208,128,250,188,250,207,154,61,1,48,190,189,2,240,175,61,38,112,139,189,172,31,91,61,49,96,73,189,221,63,86,61,80,224,93,189,101,224,64,61,151,0,252,188,212,127,86,60,13,252,168,187,193,254,107,60,197,255,29,189,222,255,135,61,58,32,169,189,20,176,157,61,2,160,74,189,206,255,43,60,2,129,206,60,155,31,63,189,174,127,87,61,100,32,79,189,149,159,84,61,32,240,128,189,192,63,165,61,28,64,191,189,199,15,181,61,62,64,119,189,100,63,139,60,155,0,195,60,117,32,43,189,107,128,210,60,249,191,163,60,128,128,132,132,124,124,127,133,129,123,133,127,123,129,140,140,116,116,131,141,125,115,141,131,115,125,119,137,137,119,137,119,119,137,140,149,116,107,149,140,107,116,124,144,132,112,144,124,112,132,150,150,106,106,130,152,126,104,152,130,104,126,151,162,105,94,162,151,94,105,162,162,94,94,139,163,117,93,163,139,93,117,113,149,143,107,149,113,107,143,120,157,136,99,157,120,99,136,127,167,129,89,167,127,89,129,164,177,92,79,177,164,79,92,150,177,106,79,177,150,79,106,178,178,78,78,101,155,155,101,155,101,101,155,137,180,119,76,180,137,76,119,106,163,150,93,163,106,93,150,115,172,141,84,172,115,84,141,180,195,76,61,195,180,61,76,164,195,92,61,195,164,61,92,196,196,60,60,150,198,106,58,198,150,58,106,124,186,132,70,186,124,70,132,91,171,165,85,171,91,85,165,99,180,157,76,180,99,76,157,134,202,122,54,202,134,54,122,182,215,74,41,215,182,41,74,200,215,56,41,215,200,41,56,164,216,92,40,216,164,40,92,108,193,148,63,193,108,63,148,217,217,39,39,128,128,0,0,3,0,4,0,3,0,6,0,3,0,1,0,5,0,9,0,5,0,25,0,5,0,13,0,5,0,29,0,5,0,35,0,6,0,19,0,6,0,51,0,6,0,11,0,6,0,43,0,6,0,27,0,6,0,7,0,8,0,135,0,8,0,39,0,8,0,167,0,8,0,103,0,8,0,231,0,8,0,151,0,8,0,87,0,8,0,55,0,8,0,183,0,8,0,247,0,8,0,15,0,9,0,143,0,9,0,143,1,9,0,79,1,9,0,207,0,9,0,47,0,9,0,47,1,9,0,175,1,9,0,111,0,9,0,239,0,9,0,239,1,9,0,31,0,10,0,31,2,10,0,31,1,10,0,31,3,10,0,159,0,10,0,159,2,10,0,159,1,10,0,159,3,10,0,95,0,10,0,95,2,10,0,95,1,10,0,95,3,10,0,223,0,10,0,223,2,10,0,223,1,10,0,223,3,10,0,63,0,13,0,63,16,13,0,63,8,13,0,63,24,13,0,63,4,13,0,63,20,13,0,63,12,13,0,63,28,13,0,63,2,13,0,63,18,13,0,63,10,13,0,63,26,13,0,63,6,13,0,63,22,13,0,63,14,13,0,63,30,13,0,63,1,13,0,63,17,13,0,63,9,13,0,63,25,13,0,63,5,13,0,63,21,13,0,63,13,13,0,63,29,13,0,63,3,13,0,63,19,13,0,63,11,13,0,63,27,13,0,63,7,13,0,63,23,13,0,63,15,13,0,63,31,13,0,191,0,13,0,191,16,13,0,191,8,13,0,191,24,13,0,191,4,13,0,191,20,13,0,191,12,13,0,191,28,13,0,191,2,13,0,191,18,13,0,191,10,13,0,191,26,13,0,191,6,13,0,191,22,13,0,191,14,13,0,191,30,13,0,191,1,13,0,191,17,13,0,191,9,13,0,191,25,13,0,191,5,13,0,191,21,13,0,191,13,13,0,191,29,13,0,191,3,13,0,191,19,13,0,191,11,13,0,191,27,13,0,191,7,13,0,191,23,13,0,191,15,13,0,191,31,13,0,127,0,14,0,127,32,14,0,127,16,14,0,127,48,14,0,127,8,14,0,127,40,14,0,127,24,14,0,127,56,14,0,127,4,14,0,127,36,14,0,127,20,14,0,2,0,3,0,17,0,5,0,5,0,5,0,21,0,5,0,3,0,6,0,59,0,6,0,71,0,8,0,199,0,8,0,23,0,8,0,215,0,8,0,119,0,8,0,15,1,9,0,79,0,9,0,207,1,9,0,175,0,9,0,111,1,9,0,0,0,0,0,0,128,190,255,28,0,104,0,169,0,224,0,18,1,62,1,102,1,139,1,173,1,203,1,232,1,2,2,27,2,54,2,54,2,27,2,2,2,232,1,203,1,173,1,139,1,102,1,62,1,18,1,224,0,169,0,104,0,28,0,190,255,0,128,0,128,4,0,135,0,213,0,17,1,67,1,117,1,169,1,169,1,117,1,67,1,17,1,213,0,135,0,4,0,0,128,0,128,135,0,17,1,117,1,117,1,17,1,135,0,0,128,116,0,109,1,109,1,116,0,60,2,0,0,236,2,0,0,238,2,0,0,240,2,0,0,242,2,0,0,244,2,0,0,114,1,0,0,204,3,0,0,76,0,0,0,200,3,0,0,12,3,0,0,228,0,0,0,30,2,0,0,224,0,0,0,20,2,0,0,236,2,0,0,60,2,0,0,236,2,0,0,238,2,0,0,240,2,0,0,242,2,0,0,244,2,0,0,246,2,0,0,248,2,0,0,250,2,0,0,252,2,0,0,254,2,0,0,0,3,0,0,2,3,0,0,4,3,0,0,6,3,0,0,8,3,0,0,111,78,12,53,182,49,118,53,128,68,146,53,208,239,125,52,250,53,149,180,185,42,13,181,156,145,248,180,181,225,53,55,246,189,76,183,246,58,184,183,36,22,179,183,47,254,166,183,185,134,145,183,29,15,73,183,232,241,243,182,45,92,211,182,151,109,38,55,1,78,92,55,92,32,120,55,225,112,166,55,240,150,222,55,254,9,14,56,235,99,46,56,45,211,80,56,117,9,249,183,148,108,24,184,112,148,37,184,36,13,52,184,143,177,69,184,152,157,99,184,18,127,129,184,222,134,134,184,253,139,236,56,206,12,26,57,55,246,61,57,191,100,102,57,58,62,136,57,182,75,157,57,246,222,177,57,157,175,193,57,30,210,222,185,185,207,237,185,12,26,254,185,166,12,6,186,137,169,11,186,143,156,15,186,64,107,17,186,10,80,17,186,118,96,128,58,13,144,147,58,99,69,166,58,150,29,184,58,225,207,200,58,82,5,216,58,4,102,229,58,187,235,240,58,7,232,248,186,114,241,254,186,141,204,0,187,237,104,0,187,119,87,252,186,156,231,243,186,242,93,231,186,162,167,214,186,6,255,138,59,148,153,150,59,20,11,161,59,24,29,170,59,238,149,177,59,48,61,183,59,204,220,186,59,21,61,188,59,178,62,187,187,236,156,183,187,56,63,177,187,251,254,167,187,219,190,155,187,97,103,140,187,159,208,115,187,24,116,72,187,82,35,161,60,122,12,174,60,215,160,186,60,37,200,198,60,125,106,210,60,172,112,221,60,135,196,231,60,49,81,241,60,199,2,250,188,236,227,0,189,0,72,4,189,146,38,7,189,158,121,9,189,59,60,11,189,177,106,12,189,147,2,13,189,43,254,147,188,168,181,134,188,76,196,114,188], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1050268);
/* memory initializer */ allocate([177,55,88,188,47,244,61,188,148,38,36,188,149,249,10,188,213,41,229,187,6,61,182,59,119,112,137,59,248,1,62,59,150,148,220,58,44,92,16,58,60,38,1,186,94,53,189,186,114,179,22,187,149,233,124,187,68,108,98,187,180,235,70,187,81,214,42,187,138,146,14,187,220,249,228,186,40,217,173,186,177,207,112,186,251,84,10,58,99,96,37,57,245,183,69,185,127,31,5,186,240,35,81,186,94,128,138,186,244,49,168,186,179,156,193,186,63,211,89,186,207,93,51,186,197,94,13,186,89,109,209,185,246,184,139,185,235,56,20,185,96,101,210,183,121,206,176,56,133,90,63,185,99,219,140,185,204,214,179,185,6,237,212,185,49,2,240,185,26,94,2,186,35,185,9,186,166,214,14,186,215,112,169,184,170,246,95,184,238,253,218,183,59,146,223,181,49,119,155,55,170,97,21,56,180,63,81,56,185,31,108,56,105,103,116,184,22,159,130,184,232,60,147,184,49,249,156,184,212,166,159,184,81,67,153,184,4,64,143,184,36,49,135,184,95,200,75,184,80,31,65,184,36,41,62,184,122,97,46,184,19,15,27,184,91,124,7,184,29,64,233,183,30,100,197,183,51,24,243,53,249,117,25,181,26,35,207,181,252,189,48,182,91,246,139,182,162,229,4,183,195,53,48,183,180,183,25,183,203,229,235,182,192,100,214,182,253,254,154,182,100,146,90,182,107,20,27,182,103,98,192,181,184,52,33,181,122,158,70,55,61,113,48,55,237,128,89,50,44,166,23,51,246,144,10,51,242,178,62,179,204,131,225,180,206,94,88,181,86,152,28,181,86,152,28,181,206,94,88,181,204,131,225,180,242,178,62,179,246,144,10,51,44,166,23,51,237,128,89,50,61,113,48,55,122,158,70,183,184,52,33,53,103,98,192,53,107,20,27,54,100,146,90,54,253,254,154,54,192,100,214,54,203,229,235,54,180,183,25,183,195,53,48,183,162,229,4,183,91,246,139,182,252,189,48,182,26,35,207,181,249,117,25,181,51,24,243,53,30,100,197,55,29,64,233,55,91,124,7,56,19,15,27,56,122,97,46,56,36,41,62,56,80,31,65,56,95,200,75,56,36,49,135,184,4,64,143,184,81,67,153,184,212,166,159,184,49,249,156,184,232,60,147,184,22,159,130,184,105,103,116,184,185,31,108,184,180,63,81,184,170,97,21,184,49,119,155,183,59,146,223,53,238,253,218,55,170,246,95,56,215,112,169,56,166,214,14,186,35,185,9,186,26,94,2,186,49,2,240,185,6,237,212,185,204,214,179,185,99,219,140,185,133,90,63,185,121,206,176,184,96,101,210,55,235,56,20,57,246,184,139,57,89,109,209,57,197,94,13,58,207,93,51,58,63,211,89,58,179,156,193,186,244,49,168,186,94,128,138,186,240,35,81,186,127,31,5,186,245,183,69,185,99,96,37,57,251,84,10,58,177,207,112,58,40,217,173,58,220,249,228,58,138,146,14,59,81,214,42,59,180,235,70,59,68,108,98,59,149,233,124,59,114,179,22,187,94,53,189,186,60,38,1,186,44,92,16,58,150,148,220,58,248,1,62,59,119,112,137,59,6,61,182,59,213,41,229,59,149,249,10,60,148,38,36,60,47,244,61,60,177,55,88,60,76,196,114,60,168,181,134,60,43,254,147,60,147,2,13,189,177,106,12,189,59,60,11,189,158,121,9,189,146,38,7,189,0,72,4,189,236,227,0,189,199,2,250,188,49,81,241,188,135,196,231,188,172,112,221,188,125,106,210,188,37,200,198,188,215,160,186,188,122,12,174,188,82,35,161,188,24,116,72,187,159,208,115,187,97,103,140,187,219,190,155,187,251,254,167,187,56,63,177,187,236,156,183,187,178,62,187,187,21,61,188,187,204,220,186,187,48,61,183,187,238,149,177,187,24,29,170,187,20,11,161,187,148,153,150,187,6,255,138,187,162,167,214,186,242,93,231,186,156,231,243,186,119,87,252,186,237,104,0,187,141,204,0,187,114,241,254,186,7,232,248,186,187,235,240,186,4,102,229,186,82,5,216,186,225,207,200,186,150,29,184,186,99,69,166,186,13,144,147,186,118,96,128,186,10,80,17,186,64,107,17,186,143,156,15,186,137,169,11,186,166,12,6,186,12,26,254,185,185,207,237,185,30,210,222,185,157,175,193,185,246,222,177,185,182,75,157,185,58,62,136,185,191,100,102,185,55,246,61,185,206,12,26,185,253,139,236,184,222,134,134,184,18,127,129,184,152,157,99,184,143,177,69,184,36,13,52,184,112,148,37,184,148,108,24,184,117,9,249,183,45,211,80,184,235,99,46,184,254,9,14,184,240,150,222,183,225,112,166,183,92,32,120,183,1,78,92,183,151,109,38,183,45,92,211,182,232,241,243,182,29,15,73,183,185,134,145,183,47,254,166,183,36,22,179,183,246,58,184,183,246,189,76,183,181,225,53,183,156,145,248,52,185,42,13,53,250,53,149,52,208,239,125,180,128,68,146,181,182,49,118,181,111,78,12,181,232,128,32,0,112,0,0,0,80,119,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,36,1,0,154,153,1,0,37,73,2,0,52,51,3,0,0,0,4,0,86,85,5,0,0,0,8,0,0,0,0,0,74,0,0,0,72,0,0,0,78,0,0,0,76,0,0,0,80,0,0,0,150,1,0,0,84,0,0,0,82,0,0,0,70,0,0,0,68,0,0,0,134,1,0,0,132,1,0,0,138,1,0,0,136,1,0,0,6,0,0,0,19,0,0,0,32,0,0,0,45,0,0,0,58,0,0,0,71,0,0,0,84,0,0,0,97,0,0,0,110,0,0,0,123,0,0,0,136,0,0,0,149,0,0,0,162,0,0,0,175,0,0,0,188,0,0,0,201,0,0,0,214,0,0,0,227,0,0,0,240,0,0,0,253,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,72,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,147,0,0,0,148,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,155,0,0,0,156,0,0,0,157,0,0,0,158,0,0,0,159,0,0,0,160,0,0,0,161,0,0,0,163,0,0,0,164,0,0,0,165,0,0,0,166,0,0,0,167,0,0,0,168,0,0,0,169,0,0,0,170,0,0,0,171,0,0,0,172,0,0,0,173,0,0,0,174,0,0,0,176,0,0,0,177,0,0,0,178,0,0,0,179,0,0,0,180,0,0,0,181,0,0,0,182,0,0,0,183,0,0,0,184,0,0,0,185,0,0,0,186,0,0,0,187,0,0,0,189,0,0,0,190,0,0,0,191,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,196,0,0,0,197,0,0,0,198,0,0,0,199,0,0,0,200,0,0,0,202,0,0,0,203,0,0,0,204,0,0,0,205,0,0,0,206,0,0,0,207,0,0,0,208,0,0,0,209,0,0,0,210,0,0,0,211,0,0,0,212,0,0,0,213,0,0,0,215,0,0,0,216,0,0,0,217,0,0,0,218,0,0,0,219,0,0,0,220,0,0,0,221,0,0,0,222,0,0,0,223,0,0,0,224,0,0,0,225,0,0,0,226,0,0,0,228,0,0,0,229,0,0,0,230,0,0,0,231,0,0,0,232,0,0,0,233,0,0,0,234,0,0,0,235,0,0,0,236,0,0,0,237,0,0,0,238,0,0,0,239,0,0,0,241,0,0,0,242,0,0,0,243,0,0,0,244,0,0,0,245,0,0,0,246,0,0,0,247,0,0,0,248,0,0,0,249,0,0,0,250,0,0,0,251,0,0,0,252,0,0,0,0,2,4,6,8,9,10,11,12,13,14,15,16,0,0,0,0,0,0,0,171,170,42,63,205,204,204,62,37,73,146,62,57,142,99,62,137,136,8,62,8,33,132,61,33,8,2,61,0,8,45,8,91,8,138,8,185,8,234,8,28,9,79,9,131,9,185,9,239,9,39,10,96,10,154,10,214,10,18,11,80,11,144,11,209,11,19,12,86,12,156,12,226,12,43,13,116,13,192,13,13,14,92,14,172,14,254,14,82,15,168,15,2,0,2,0,6,0,3,0,14,0,4,0,12,0,5,0,13,0,5,0,16,0,6,0,17,0,6,0,18,0,6,0,22,0,7,0,27,0,8,0,32,0,9,0,33,0,9,0,26,0,9,0,27,0,9,0,28,0,9,0,29,0,9,0,30,0,9,0,31,0,9,0,35,0,11,0,34,0,11,0,87,0,12,0,86,0,12,0,85,0,12,0,84,0,12,0,83,0,12,0,15,0,4,0,20,0,6,0,20,0,7,0,30,0,8,0,15,0,10,0,33,0,11,0,80,0,12,0,11,0,5,0,21,0,7,0,14,0,10,0,9,0,10,0,21,0,6,0,29,0,8,0,13,0,10,0,81,0,12,0,19,0,6,0,35,0,9,0,7,0,11,0,23,0,7,0,34,0,9,0,82,0,12,0,28,0,8,0,12,0,10,0,31,0,8,0,11,0,10,0,37,0,9,0,10,0,10,0,36,0,9,0,6,0,11,0,33,0,10,0,32,0,10,0,8,0,10,0,32,0,11,0,7,0,4,0,12,0,6,0,16,0,7,0,19,0,8,0,17,0,9,0,18,0,9,0,4,0,10,0,39,0,11,0,38,0,11,0,95,0,12,0,15,0,6,0,19,0,9,0,5,0,10,0,37,0,11,0,14,0,6,0,20,0,9,0,36,0,11,0,13,0,6,0,6,0,10,0,94,0,12,0,17,0,7,0,7,0,10,0,19,0,7,0,93,0,12,0,18,0,7,0,92,0,12,0,20,0,8,0,91,0,12,0,21,0,8,0,26,0,8,0,25,0,8,0,24,0,8,0,23,0,8,0,22,0,8,0,25,0,9,0,21,0,9,0,22,0,9,0,24,0,9,0,23,0,9,0,4,0,11,0,5,0,11,0,88,0,12,0,89,0,12,0,90,0,12,0,3,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,7,7,7,7,7,8,8,8,8,9,9,9,9,10,10,11,11,12,12,13,14,15,16,17,18,19,0,0,0,0,0,1,1,1,1,1,2,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,1,2,3,4,5,6,7,8,9,10,11,12,13,1,2,3,4,5,6,7,8,9,10,11,1,2,3,4,5,6,7,8,9,1,2,3,4,5,6,1,2,3,4,5,6,1,2,3,4,5,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,1,2,1,2,1,1,1,1,1,1,1,1,2,3,4,5,1,2,3,4,5,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,6,0,3,0,7,0,3,0,10,0,4,0,9,0,5,0,20,0,6,0,21,0,6,0,52,0,7,0,116,0,8,0,117,0,8,0,221,0,9,0,236,0,9,0,236,1,10,0,237,1,10,0,244,1,10,0,236,3,11,0,237,3,11,0,244,3,11,0,125,7,12,0,188,7,12,0,189,15,13,0,220,15,13,0,189,7,12,0,221,15,13,0,189,31,14,0,220,31,14,0,221,31,14,0,252,31,15,0,1,0,4,0,8,0,5,0,45,0,7,0,108,0,8,0,109,0,8,0,220,0,9,0,221,1,10,0,220,3,11,0,221,3,11,0,124,7,12,0,188,15,13,0,125,31,14,0,188,31,14,0,4,0,5,0,44,0,7,0,188,0,9,0,220,1,10,0,188,3,11,0,189,3,11,0,253,14,13,0,124,15,13,0,125,15,13,0,253,30,14,0,124,31,14,0,5,0,5,0,92,0,8,0,189,0,9,0,125,3,11,0,252,6,12,0,252,14,13,0,253,29,14,0,252,30,14,0,253,31,15,0,12,0,6,0,93,0,8,0,189,1,10,0,253,3,12,0,253,6,12,0,253,27,14,0,13,0,6,0,125,0,9,0,252,2,11,0,252,5,12,0,252,27,14,0,252,29,14,0,28,0,7,0,124,1,10,0,253,2,11,0,253,5,12,0,252,47,15,0,29,0,7,0,125,1,10,0,124,3,11,0,253,13,13,0,253,47,15,0,60,0,8,0,188,1,10,0,253,11,13,0,253,23,14,0,61,0,8,0,253,1,11,0,252,13,13,0,252,55,15,0,124,0,9,0,252,3,12,0,252,0,10,0,252,11,13,0,253,0,10,0,253,55,15,0,252,1,11,0,252,7,13,0,253,7,13,0,252,15,14,0,253,15,14,0,252,23,14,0,252,59,15,0,11,0,4,0,120,0,8,0,245,3,11,0,236,15,13,0,236,31,14,0,18,0,5,0,237,0,9,0,220,7,12,0,237,31,14,0,253,59,15,0,19,0,5,0,248,3,11,0,252,61,15,0,24,0,6,0,221,7,12,0,25,0,6,0,236,7,12,0,34,0,6,0,237,15,13,0,35,0,6,0,244,15,13,0,53,0,7,0,245,15,13,0,56,0,7,0,248,15,13,0,57,0,7,0,249,15,13,0,66,0,7,0,244,31,14,0,67,0,7,0,245,31,14,0,121,0,8,0,248,31,14,0,130,0,8,0,253,61,15,0,131,0,8,0,244,0,9,0,245,0,9,0,248,0,9,0,249,0,9,0,2,1,9,0,3,1,9,0,245,1,10,0,248,1,10,0,249,1,10,0,2,2,10,0,3,2,10,0,249,3,11,0,2,4,11,0,3,4,11,0,237,7,12,0,244,7,12,0,245,7,12,0,248,7,12,0,249,7,12,0,2,8,12,0,3,8,12,0,2,16,13,0,3,16,13,0,249,31,14,0,2,32,14,0,3,32,14,0,252,62,15,0,253,62,15,0,124,63,15,0,125,63,15,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,7,7,8,8,9,9,10,11,12,13,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,3,3,3,4,4,5,5,6,6,7,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,0,0,0,26,10,1,0,0,0,0,7,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,1,2,3,4,5,6,7,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,1,1,1,1,2,3,4,5,6,7,8,9,10,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,1,1,1,255,1,1,1,2,1,255,2,1,1,3,1,255,3,1,1,4,1,255,4,1,1,5,1,255,5,1,1,6,1,255,6,1,1,7,1,255,7,1,1,8,1,255,8,1,1,9,1,255,9,1,1,10,1,255,10,1,1,11,1,255,11,1,2,1,2,254,1,2,1,12,1,255,12,1,1,13,1,255,13,1,1,14,1,255,14,1,1,15,1,255,15,1,2,2,2,254,2,2,1,16,1,255,16,1,1,17,1,255,17,1,3,1,3,253,1,3,1,18,1,255,18,1,1,19,1,255,19,1,2,3,2,254,3,2,1,20,1,255,20,1,1,21,1,255,21,1,2,4,2,254,4,2,1,22,1,255,22,1,2,5,2,254,5,2,1,23,1,255,23,1,0,0,0,0,4,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,255,255,255,2,0,0,0,0,0,0,0,23,0,0,0,1,1,0,255,1,0,1,2,0,255,2,0,2,1,1,254,1,1,1,3,0,255,3,0,0,0,0,1,4,0,255,4,0,1,5,0,255,5,0,1,6,0,255,6,0,3,1,2,253,1,2,2,2,1,254,2,1,1,7,0,255,7,0,1,8,0,255,8,0,1,9,0,255,9,0,2,3,1,254,3,1,4,1,2,252,1,2,1,10,0,255,10,0,1,11,0,255,11,0,2,4,1,254,4,1,3,2,2,253,2,2,1,12,0,255,12,0,2,5,1,254,5,1,5,1,3,251,1,3,1,13,0,255,13,0,2,6,1,254,6,1,1,14,0,255,14,0,2,7,1,254,7,1,2,8,1,254,8,1,3,3,2,253,3,2,6,1,3,250,1,3,1,15,0,255,15,0,0,7,4,4,3,3,3,3,3,2,2,2,2,2,2,2,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,1,0,0,0,15,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,1,2,0,255,2,0,3,1,1,253,1,1,0,0,0,1,3,0,255,3,0,2,2,0,254,2,0,4,1,1,252,1,1,1,4,0,255,4,0,5,1,2,251,1,2,1,5,0,255,5,0,3,2,1,253,2,1,2,3,0,254,3,0,1,6,0,255,6,0,6,1,2,250,1,2,2,4,0,254,4,0,1,7,0,255,7,0,4,2,1,252,2,1,7,1,2,249,1,2,3,3,1,253,3,1,2,5,0,254,5,0,1,8,0,255,8,0,2,6,0,254,6,0,8,1,3,248,1,3,1,9,0,255,9,0,5,2,2,251,2,2,3,4,1,253,4,1,2,7,0,254,7,0,9,1,3,247,1,3,1,10,0,255,10,0,0,10,6,4,4,3,3,3,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,2,0,0,0,10,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,1,2,0,255,2,0,0,0,0,4,1,0,252,1,0,5,1,1,251,1,1,2,2,0,254,2,0,1,3,0,255,3,0,6,1,1,250,1,1,3,2,0,253,2,0,7,1,1,249,1,1,1,4,0,255,4,0,8,1,2,248,1,2,2,3,0,254,3,0,4,2,0,252,2,0,1,5,0,255,5,0,9,1,2,247,1,2,5,2,1,251,2,1,2,4,0,254,4,0,10,1,2,246,1,2,3,3,0,253,3,0,1,6,0,255,6,0,11,1,3,245,1,3,6,2,1,250,2,1,1,7,0,255,7,0,2,5,0,254,5,0,3,4,0,253,4,0,12,1,3,244,1,3,4,3,0,252,3,0,0,13,7,5,4,3,2,2,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,2,0,0,0,4,0,0,0,7,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,0,0,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,1,2,0,255,2,0,7,1,0,249,1,0,8,1,1,248,1,1,2,2,0,254,2,0,9,1,1,247,1,1,10,1,1,246,1,1,1,3,0,255,3,0,3,2,0,253,2,0,11,1,2,245,1,2,4,2,0,252,2,0,12,1,2,244,1,2,13,1,2,243,1,2,5,2,0,251,2,0,1,4,0,255,4,0,2,3,0,254,3,0,14,1,2,242,1,2,6,2,0,250,2,0,15,1,2,241,1,2,16,1,2,240,1,2,3,3,0,253,3,0,1,5,0,255,5,0,7,2,0,249,2,0,17,1,2,239,1,2,0,18,8,4,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,7,0,0,0,5,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,7,1,0,249,1,0,8,1,0,248,1,0,9,1,0,247,1,0,10,1,0,246,1,0,1,2,0,255,2,0,11,1,1,245,1,1,12,1,1,244,1,1,13,1,1,243,1,1,2,2,0,254,2,0,14,1,1,242,1,1,15,1,1,241,1,1,3,2,0,253,2,0,16,1,1,240,1,1,1,3,0,255,3,0,17,1,1,239,1,1,4,2,0,252,2,0,18,1,1,238,1,1,5,2,0,251,2,0,19,1,1,237,1,1,20,1,1,236,1,1,6,2,0,250,2,0,21,1,1,235,1,1,2,3,0,254,3,0,0,22,7,3,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,10,0,0,0,3,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,7,1,0,249,1,0,8,1,0,248,1,0,9,1,0,247,1,0,10,1,0,246,1,0,11,1,0,245,1,0,12,1,0,244,1,0,13,1,0,243,1,0,14,1,0,242,1,0,15,1,0,241,1,0,16,1,0,240,1,0,1,2,0,255,2,0,17,1,0,239,1,0,18,1,0,238,1,0,19,1,0,237,1,0,20,1,0,236,1,0,21,1,0,235,1,0,2,2,0,254,2,0,22,1,0,234,1,0,23,1,0,233,1,0,24,1,0,232,1,0,25,1,0,231,1,0,3,2,0,253,2,0,26,1,0,230,1,0,0,27,4,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,255,255,255,127,2,0,0,0,8,0,0,0,0,0,0,0,104,179,42,62,0,0,0,63,38,83,85,63,0,0,0,0,0,0,0,0,39,160,169,62,154,153,41,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,47,0,51,0,56,0,61,0,66,0,72,0,79,0,86,0,94,0,102,0,112,0,122,0,133,0,145,0,158,0,173,0,189,0,206,0,225,0,245,0,11,1,36,1,62,1,92,1,123,1,158,1,196,1,237,1,26,2,75,2,128,2,187,2,251,2,64,3,140,3,223,3,57,4,156,4,8,5,125,5,254,5,137,6,34,7,201,7,127,8,69,9,30,10,10,11,12,12,37,13,88,14,168,15,21,17,164,18,88,20,51,22,58,24,111,26,217,28,123,31,90,34,125,37,232,40,164,44,183,48,41,53,3,58,78,63,21,69,98,75,68,82,197,89,246,97,231,106,168,116,77,127,235,138,152,151,110,165,134,180,255,196,249,214,151,234,255,255,1,0,1,0,105,21,7,41,1,59,122,75,146,90,104,104,21,117,179,128,88,139,25,149,10,158,59,166,188,173,158,180,235,186,178,192,253,197,215,202,73,207,92,211,24,215,131,218,166,221,133,224,39,227,145,229,198,231,205,233,168,235,92,237,235,238,88,240,168,241,219,242,244,243,246,244,226,245,187,246,129,247,55,248,222,248,119,249,2,250,131,250,248,250,100,251,199,251,33,252,116,252,192,252,5,253,69,253,128,253,181,253,230,253,19,254,60,254,98,254,133,254,164,254,194,254,220,254,245,254,11,255,31,255,50,255,67,255,83,255,98,255,111,255,123,255,134,255,144,255,154,255,162,255,170,255,177,255,184,255,190,255,195,255,200,255,205,255,209,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,160,45,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,5,0,0,6,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,23,35,0,112,80,34,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,224,171,33,0,112,80,34,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,20,39,0,112,0,0,0,80,71,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,0,0,1,0,1,0,1,0,1,0,0,0,0,1,0,1,0,0,1,0,1,0,1,0,1,0,0,0,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,0,1,0,1,1,1,1,1,1,0,1,0,1,0,1,0,1,1,1,1,1,1,1,1,0,1,0,1,1,0,1,0,1,1,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,248,26,37,0,104,206,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,0,0,248,26,37,0,80,225,34,0,128,30,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,248,26,37,0,8,130,33,0,200,6,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,0,0,248,26,37,0,168,161,32,0,232,69,32,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,56,36,0,112,0,0,0,48,73,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,9,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,0,0,0,0,0,1,1,1,1,1,2,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,1,2,3,4,5,6,7,8,9,10,1,2,3,4,5,6,7,1,2,3,4,5,6,7,1,2,3,4,5,1,2,3,4,1,2,3,4,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,4,5,1,2,3,4,5,1,2,3,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,6,0,3,0,1,0,4,0,4,0,5,0,28,0,7,0,60,0,8,0,61,0,8,0,124,0,9,0,252,0,10,0,253,0,10,0,252,1,11,0,253,1,11,0,252,3,12,0,252,7,13,0,253,7,13,0,252,11,13,0,253,11,13,0,252,15,14,0,253,15,14,0,252,31,15,0,7,0,3,0,12,0,6,0,92,0,8,0,125,0,9,0,124,1,10,0,252,2,11,0,253,3,12,0,252,13,13,0,252,23,14,0,253,23,14,0,10,0,4,0,29,0,7,0,188,0,9,0,253,2,11,0,252,5,12,0,252,27,14,0,253,27,14,0,5,0,5,0,93,0,8,0,125,1,10,0,253,5,12,0,253,13,13,0,252,29,14,0,253,31,15,0,8,0,5,0,108,0,8,0,124,3,11,0,252,14,13,0,252,47,15,0,9,0,5,0,189,0,9,0,125,3,11,0,253,14,13,0,13,0,6,0,188,1,10,0,252,6,12,0,253,29,14,0,20,0,6,0,189,1,10,0,253,6,12,0,253,47,15,0,21,0,6,0,220,1,10,0,124,15,13,0,44,0,7,0,221,1,10,0,252,30,14,0,45,0,7,0,188,3,11,0,52,0,7,0,124,7,12,0,109,0,8,0,125,15,13,0,116,0,8,0,253,30,14,0,117,0,8,0,124,31,14,0,220,0,9,0,125,31,14,0,221,0,9,0,188,31,14,0,236,0,9,0,252,55,15,0,236,1,10,0,237,1,10,0,244,1,10,0,189,3,11,0,220,3,11,0,221,3,11,0,236,3,11,0,237,3,11,0,244,3,11,0,125,7,12,0,188,7,12,0,189,7,12,0,188,15,13,0,189,15,13,0,220,15,13,0,221,15,13,0,189,31,14,0,220,31,14,0,221,31,14,0,253,55,15,0,252,59,15,0,11,0,4,0,120,0,8,0,245,3,11,0,236,15,13,0,236,31,14,0,18,0,5,0,237,0,9,0,220,7,12,0,237,31,14,0,253,59,15,0,19,0,5,0,248,3,11,0,252,61,15,0,24,0,6,0,221,7,12,0,25,0,6,0,236,7,12,0,34,0,6,0,237,15,13,0,35,0,6,0,244,15,13,0,53,0,7,0,245,15,13,0,56,0,7,0,248,15,13,0,57,0,7,0,249,15,13,0,66,0,7,0,244,31,14,0,67,0,7,0,245,31,14,0,121,0,8,0,248,31,14,0,130,0,8,0,253,61,15,0,131,0,8,0,244,0,9,0,245,0,9,0,248,0,9,0,249,0,9,0,2,1,9,0,3,1,9,0,245,1,10,0,248,1,10,0,249,1,10,0,2,2,10,0,3,2,10,0,249,3,11,0,2,4,11,0,3,4,11,0,237,7,12,0,244,7,12,0,245,7,12,0,248,7,12,0,249,7,12,0,2,8,12,0,3,8,12,0,2,16,13,0,3,16,13,0,249,31,14,0,2,32,14,0,3,32,14,0,252,62,15,0,253,62,15,0,124,63,15,0,125,63,15,0,0,0,4,0,0,0,1,1,1,2,2,2,3,3,3,4,4,1,1,2,2,2,3,3,3,4,4,4,4,4,0,0,0,0,0,0,0,0,1,1,2,3,3,4,4,5,6,6,7,8,8,9,9,10,11,11,12,13,13,14,15,15,16,17,17,18,19,20,20,21,22,22,23,24,24,25,26,27,27,28,29,30,30,31,32,33,33,34,35,36,36,37,38,39,39,40,41,42,42,43,44,45,46,46,47,48,49,50,50,51,52,53,54,55,55,56,57,58,59,60,60,61,62,63,64,65,66,67,67,68,69,70,71,72,73,74,75,75,76,77,78,79,80,81,82,83,84,85,86,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,1,1,1,255,1,1,1,2,1,255,2,1,1,3,1,255,3,1,1,4,1,255,4,1,1,5,1,255,5,1,1,6,1,255,6,1,1,7,1,255,7,1,1,8,1,255,8,1,1,9,1,255,9,1,1,10,1,255,10,1,1,11,1,255,11,1,1,12,1,255,12,1,1,13,1,255,13,1,2,1,2,254,1,2,1,14,1,255,14,1,1,15,1,255,15,1,1,16,1,255,16,1,1,17,1,255,17,1,1,18,1,255,18,1,1,19,1,255,19,1,3,1,3,253,1,3,1,20,1,255,20,1,1,21,1,255,21,1,2,2,2,254,2,2,1,22,1,255,22,1,1,23,1,255,23,1,1,24,1,255,24,1,1,25,1,255,25,1,1,26,1,255,26,1,0,0,0,0,4,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,0,0,0,0,0,0,0,26,0,0,0,1,1,0,255,1,0,0,0,0,1,2,0,255,2,0,1,3,0,255,3,0,1,4,0,255,4,0,1,5,0,255,5,0,1,6,0,255,6,0,2,1,1,254,1,1,1,7,0,255,7,0,1,8,0,255,8,0,1,9,0,255,9,0,1,10,0,255,10,0,2,2,1,254,2,1,1,11,0,255,11,0,1,12,0,255,12,0,3,1,2,253,1,2,1,13,0,255,13,0,1,14,0,255,14,0,2,3,1,254,3,1,1,15,0,255,15,0,2,4,1,254,4,1,1,16,0,255,16,0,2,5,1,254,5,1,1,17,0,255,17,0,4,1,3,252,1,3,2,6,1,254,6,1,1,18,0,255,18,0,1,19,0,255,19,0,2,7,1,254,7,1,3,2,2,253,2,2,0,5,4,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,255,255,255,255,255,255,255,2,0,0,0,1,0,0,0,19,0,0,0,1,1,0,255,1,0,0,0,0,1,2,0,255,2,0,2,1,0,254,1,0,1,3,0,255,3,0,1,4,0,255,4,0,3,1,1,253,1,1,2,2,0,254,2,0,1,5,0,255,5,0,1,6,0,255,6,0,1,7,0,255,7,0,2,3,0,254,3,0,4,1,2,252,1,2,1,8,0,255,8,0,3,2,1,253,2,1,2,4,0,254,4,0,1,9,0,255,9,0,1,10,0,255,10,0,5,1,2,251,1,2,2,5,0,254,5,0,1,11,0,255,11,0,2,6,0,254,6,0,1,12,0,255,12,0,3,3,1,253,3,1,6,1,2,250,1,2,4,2,2,252,2,2,1,13,0,255,13,0,2,7,0,254,7,0,3,4,1,253,4,1,1,14,0,255,14,0,0,7,5,4,4,3,3,3,2,2,2,2,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,2,0,0,0,14,0,0,0,1,1,0,255,1,0,0,0,0,2,1,0,254,1,0,1,2,0,255,2,0,3,1,0,253,1,0,1,3,0,255,3,0,2,2,0,254,2,0,4,1,1,252,1,1,1,4,0,255,4,0,5,1,1,251,1,1,1,5,0,255,5,0,3,2,0,253,2,0,2,3,0,254,3,0,1,6,0,255,6,0,6,1,1,250,1,1,2,4,0,254,4,0,1,7,0,255,7,0,4,2,1,252,2,1,7,1,2,249,1,2,3,3,0,253,3,0,1,8,0,255,8,0,2,5,0,254,5,0,8,1,2,248,1,2,1,9,0,255,9,0,3,4,0,253,4,0,2,6,0,254,6,0,5,2,1,251,2,1,1,10,0,255,10,0,9,1,2,247,1,2,4,3,1,252,3,1,0,10,6,5,4,3,3,2,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,3,0,0,0,10,0,0,0,1,1,0,255,1,0,0,0,0,2,1,0,254,1,0,3,1,0,253,1,0,1,2,0,255,2,0,4,1,0,252,1,0,5,1,0,251,1,0,2,2,0,254,2,0,1,3,0,255,3,0,6,1,0,250,1,0,3,2,0,253,2,0,7,1,1,249,1,1,1,4,0,255,4,0,8,1,1,248,1,1,2,3,0,254,3,0,4,2,0,252,2,0,1,5,0,255,5,0,9,1,1,247,1,1,5,2,0,251,2,0,2,4,0,254,4,0,1,6,0,255,6,0,10,1,2,246,1,2,3,3,0,253,3,0,11,1,2,245,1,2,1,7,0,255,7,0,6,2,0,250,2,0,3,4,0,253,4,0,2,5,0,254,5,0,12,1,2,244,1,2,4,3,0,252,3,0,0,13,7,5,4,3,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,6,0,0,0,7,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,1,2,0,255,2,0,6,1,0,250,1,0,7,1,0,249,1,0,8,1,0,248,1,0,2,2,0,254,2,0,9,1,0,247,1,0,1,3,0,255,3,0,10,1,1,246,1,1,3,2,0,253,2,0,11,1,1,245,1,1,4,2,0,252,2,0,12,1,1,244,1,1,1,4,0,255,4,0,2,3,0,254,3,0,13,1,1,243,1,1,5,2,0,251,2,0,14,1,1,242,1,1,6,2,0,250,2,0,1,5,0,255,5,0,15,1,1,241,1,1,3,3,0,253,3,0,16,1,1,240,1,1,2,4,0,254,4,0,7,2,0,249,2,0,0,17,8,4,3,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,9,0,0,0,5,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,7,1,0,249,1,0,1,2,0,255,2,0,8,1,0,248,1,0,9,1,0,247,1,0,10,1,0,246,1,0,11,1,0,245,1,0,12,1,0,244,1,0,2,2,0,254,2,0,13,1,0,243,1,0,1,3,0,255,3,0,14,1,0,242,1,0,15,1,0,241,1,0,3,2,0,253,2,0,16,1,0,240,1,0,17,1,0,239,1,0,18,1,0,238,1,0,4,2,0,252,2,0,19,1,0,237,1,0,20,1,0,236,1,0,2,3,0,254,3,0,1,4,0,255,4,0,5,2,0,251,2,0,21,1,0,235,1,0,0,22,6,3,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,255,255,255,127,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,30,5,62,191,237,18,61,36,27,33,62,28,203,208,188,154,153,153,62,31,46,62,62,90,127,53,62,30,243,50,62,154,153,25,63,158,78,144,62,56,33,35,190,244,80,241,62,72,225,58,63,194,134,40,63,73,67,190,190,76,95,121,62,20,174,71,63,30,96,67,63,215,138,220,190,130,182,44,62,195,245,104,63,164,15,116,63,93,116,81,190,255,185,7,61,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,158,9,0,0,0,0,0,0,232,21,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,171,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,0,0,0,0,0,0,0,0,106,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1060508);
/* memory initializer */ allocate([160,45,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,191,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,0,0,0,0,0,0,0,0,0,0,0,6,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,172,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,1,0,0,0,0,0,0,0,0,0,0,76,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,115,0,0,0,64,0,0,0,0,0,0,0,104,1,0,0,61,1,0,0,147,255,255,255,98,0,0,0,0,0,0,0,0,0,0,0,153,200,139,141,157,154,154,154,154,154,154,154,154,184,154,154,154,184,63,139,154,154,154,154,154,154,154,154,154,154,154,154,154,154,154,154,154,153,138,138,111,141,94,138,182,154,139,139,110,110,124,125,140,153,125,127,140,109,111,143,127,111,79,108,123,63,110,110,124,125,140,153,125,127,140,109,111,143,127,111,79,108,123,63,91,171,134,141,111,111,125,110,110,94,124,108,124,107,125,141,179,153,125,107,125,141,179,153,125,107,125,141,179,153,125,140,139,182,182,152,136,152,136,153,136,139,111,136,139,111,140,92,137,138,140,152,138,139,153,74,149,92,139,107,122,152,140,179,166,182,140,227,122,197,138,153,136,167,152,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,185,107,139,126,154,197,185,201,154,154,154,149,154,139,154,154,154,152,139,110,122,95,79,63,31,31,153,153,153,153,140,198,140,198,168,79,124,138,94,153,111,149,107,167,154,139,139,125,110,94,110,95,79,125,111,110,78,110,111,111,95,94,108,123,108,125,110,94,110,95,79,125,111,110,78,110,111,111,95,94,108,123,108,121,140,61,154,155,154,139,153,139,123,123,63,153,166,183,140,136,153,154,166,183,140,136,153,154,166,183,140,136,153,154,170,153,123,123,107,121,107,121,167,151,183,140,151,183,140,154,196,196,167,154,152,167,182,182,134,149,136,153,121,136,137,169,194,166,167,154,167,137,182,107,167,91,122,107,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,160,107,139,126,154,197,185,201,154,154,154,134,154,139,154,154,183,152,139,154,137,95,79,63,31,31,153,153,153,153,169,198,169,198,168,79,224,167,122,153,111,149,92,167,154,139,139,125,110,124,110,95,94,125,111,111,79,125,126,111,111,79,108,123,93,125,110,124,110,95,94,125,111,111,79,125,126,111,111,79,108,123,93,121,140,61,154,170,154,139,153,139,123,123,63,124,166,183,140,136,153,154,166,183,140,136,153,154,166,183,140,136,153,154,170,153,138,138,122,121,122,121,167,151,183,140,151,183,140,154,196,167,167,154,152,167,182,182,134,149,136,153,121,136,122,169,208,166,167,154,152,167,182,107,167,91,107,107,167,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,167,37,0,0,0,0,0,0,0,0,0,0,0,0,0,40,151,34,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,17,0,17,0,17,0,17,0,18,0,18,0,18,0,18,0,19,0,19,0,19,0,19,0,20,0,20,0,20,0,20,0,21,0,21,0,21,0,21,0,16,0,73,0,195,0,0,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,13,0,15,0,17,0,19,0,23,0,27,0,31,0,35,0,43,0,51,0,59,0,67,0,83,0,99,0,115,0,131,0,163,0,195,0,227,0,2,1,0,0,0,0,0,0,16,0,16,0,16,0,16,0,17,0,17,0,18,0,18,0,19,0,19,0,20,0,20,0,21,0,21,0,22,0,22,0,23,0,23,0,24,0,24,0,25,0,25,0,26,0,26,0,27,0,27,0,28,0,28,0,29,0,29,0,64,0,64,0,1,0,2,0,3,0,4,0,5,0,7,0,9,0,13,0,17,0,25,0,33,0,49,0,65,0,97,0,129,0,193,0,1,1,129,1,1,2,1,3,1,4,1,6,1,8,1,12,1,16,1,24,1,32,1,48,1,64,1,96,0,0,0,0,16,0,17,0,18,0,0,0,8,0,7,0,9,0,6,0,10,0,5,0,11,0,4,0,12,0,3,0,13,0,2,0,14,0,1,0,15,0,0,0,6,14,43,52,2,83,1,1,13,1,2,1,1,16,1,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,4,4,4,4,4,4,5,5,5,5,6,6,6,6,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,4,4,4,4,4,4,5,5,5,5,6,6,6,6,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,1,1,1,1,2,2,2,2,4,4,4,5,5,6,6,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,1,1,1,1,2,2,2,2,4,4,4,5,5,6,6,255,255,255,255,255,255,255,255,1,1,1,2,2,4,5,6,255,255,255,255,255,255,255,255,1,1,1,2,2,4,5,6,255,255,255,255,1,2,4,6,255,255,255,255,1,2,4,6,255,255,2,6,255,255,2,6,255,4,255,4,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,184,134,33,0,112,0,0,0,0,0,0,0,100,66,52,0,4,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,128,56,33,0,8,0,0,0,88,54,38,0,8,0,0,0,56,148,36,0,8,0,0,0,160,115,35,0,10,0,0,0,192,156,34,0,12,0,0,0,160,223,33,0,62,0,0,0,160,89,33,0,62,0,0,0,136,231,32,0,62,0,0,0,24,133,32,0,63,0,0,0,152,42,32,0,63,0,0,0,88,18,40,0,65,0,0,0,40,173,39,0,66,0,0,0,32,76,39,0,64,0,0,0,88,2,39,0,67,0,0,0,8,190,38,0,1,0,0,0,192,125,38,0,2,0,0,0,240,67,38,0,13,0,0,0,184,11,38,0,34,0,0,0,192,228,37,0,14,0,0,0,168,184,37,0,14,0,0,0,8,153,37,0,79,0,0,0,112,97,37,0,94,0,0,0,80,35,37,0,97,0,0,0,136,0,37,0,97,0,0,0,152,213,36,0,102,0,0,0,72,184,36,0,105,0,0,0,80,154,36,0,110,0,0,0,40,127,36,0,88,73,80,66,72,101,36,0,111,0,0,0,160,73,36,0,111,0,0,0,96,51,36,0,111,0,0,0,80,4,36,0,111,0,0,0,104,213,35,0,111,0,0,0,80,188,35,0,111,0,0,0,24,165,35,0,111,0,0,0,48,145,35,0,111,0,0,0,40,121,35,0,89,0,0,0,48,100,35,0,89,0,0,0,240,81,35,0,89,0,0,0,144,63,35,0,89,0,0,0,184,47,35,0,129,0,0,0,96,10,35,0,82,88,69,48,40,229,34,0,142,0,0,0,152,212,34,0,126,0,0,0,112,197,34,0,80,66,69,87,152,181,34,0,161,0,0,0,8,161,34,0,67,65,70,88,88,145,34,0,159,0,0,0,56,131,34,0,0,0,0,0,0,0,0,0,208,154,34,0,112,0,0,0,16,126,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,189,38,0,112,0,0,0,32,23,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,9,35,0,112,0,0,0,16,126,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,151,252,83,59,33,77,101,59,78,141,130,59,89,214,1,59,43,167,152,58,100,253,234,58,7,253,183,58,85,175,174,58,35,75,197,58,158,172,255,58,20,216,53,59,168,229,135,59,83,180,205,59,129,107,25,60,142,104,140,60,28,139,183,60,9,161,232,60,184,160,40,61,242,206,65,61,141,193,89,61,198,133,136,61,62,2,164,61,41,79,170,61,3,106,176,61,23,152,202,61,138,199,229,61,34,252,235,61,169,247,244,61,50,113,11,62,36,40,30,62,230,150,38,62,0,0,0,0,57,238,244,61,112,40,252,61,232,74,4,62,71,67,204,61,63,199,167,61,25,216,196,61,117,202,179,61,82,94,176,61,42,128,184,61,112,23,203,61,211,103,231,61,229,69,6,62,38,142,28,62,9,140,53,62,210,26,99,62,134,203,122,62,209,230,136,62,253,22,157,62,73,102,165,62,70,177,172,62,172,201,187,62,59,253,200,62,158,208,203,62,154,125,206,62,96,89,217,62,208,185,227,62,248,251,229,62,22,48,233,62,38,169,244,62,216,43,0,63,63,169,2,63,0,0,0,0,226,147,14,62,7,123,179,62,80,113,24,63,205,147,91,63,201,142,143,63,117,177,177,63,169,18,217,63,24,34,8,64,155,232,147,61,10,159,61,62,175,38,151,62,29,60,211,62,102,106,10,63,112,66,45,63,51,221,79,63,82,153,114,63,231,251,137,63,129,9,154,63,128,43,171,63,243,173,189,63,238,234,209,63,65,74,232,63,44,125,4,64,138,202,28,64,64,189,25,61,233,95,210,61,36,15,36,62,96,58,93,62,1,109,139,62,13,23,169,62,180,203,199,62,211,219,231,62,78,152,4,63,229,213,21,63,169,105,39,63,235,30,57,63,69,160,74,63,135,225,91,63,166,154,109,63,117,63,127,63,161,244,135,63,249,20,144,63,123,76,152,63,155,200,160,63,51,136,169,63,195,160,178,63,29,5,188,63,80,197,197,63,68,48,208,63,56,19,219,63,10,191,230,63,107,130,244,63,228,106,3,64,10,75,14,64,129,233,30,64,139,54,80,64,218,170,228,61,246,124,181,62,38,111,36,63,248,22,118,63,76,196,165,63,22,19,207,63,11,179,254,63,95,181,32,64,231,109,108,61,195,244,45,62,150,93,152,62,155,142,224,62,100,36,23,63,69,213,63,63,100,145,106,63,140,44,139,63,211,161,161,63,248,227,182,63,193,82,205,63,173,52,229,63,242,10,0,64,109,83,15,64,168,142,41,64,13,213,168,64,141,123,243,60,65,211,178,61,58,235,19,62,32,38,81,62,128,159,137,62,73,161,172,62,173,79,209,62,243,84,247,62,137,124,15,63,224,185,35,63,38,111,56,63,75,229,77,63,134,171,99,63,62,178,121,63,185,254,135,63,97,85,147,63,14,192,158,63,204,209,169,63,58,205,180,63,115,16,192,63,110,190,203,63,98,220,215,63,182,130,228,63,236,19,242,63,9,84,0,64,237,43,8,64,168,86,17,64,239,115,30,64,59,52,46,64,236,134,70,64,117,245,149,64,40,82,199,64,213,36,88,63,121,121,242,62,170,99,185,63,77,158,138,62,230,150,62,63,144,249,158,63,210,56,236,63,0,0,0,0,132,103,94,63,155,3,244,62,114,54,189,63,218,113,131,62,154,122,65,63,147,87,169,63,72,51,2,64,0,0,0,0,65,72,66,63,26,107,31,63,174,186,162,63,121,32,178,62,53,208,64,63,85,76,147,63,231,113,208,63,0,0,0,0,226,231,67,63,150,7,37,63,252,196,161,63,227,226,176,62,156,139,67,63,159,115,155,63,201,198,225,63,0,0,0,0,17,17,18,18,0,0,0,0,16,15,13,11,8,5,3,1,2,4,6,9,10,12,14,16,7,0,10,8,7,6,4,4,3,2,2,3,4,6,7,9,11,11,7,0,15,15,14,11,8,6,4,2,1,4,5,7,9,10,12,13,4,0,13,11,10,8,6,4,2,2,2,3,5,7,9,12,15,15,14,0,14,12,10,8,7,4,2,2,2,3,5,7,9,11,13,14,7,0,14,13,11,8,6,4,3,2,2,3,5,7,9,10,12,14,3,0,13,12,10,7,5,4,3,2,2,3,4,6,8,9,11,13,4,0,13,12,10,7,5,4,3,2,2,3,4,6,8,9,11,13,4,0,16,14,12,10,8,5,3,1,2,4,7,9,11,13,15,17,6,17,15,13,11,8,6,4,2,2,2,3,5,7,10,12,14,16,9,16,14,12,11,9,8,6,3,1,2,5,7,10,13,15,16,17,4,17,16,14,12,9,7,5,2,2,2,3,4,6,8,11,13,15,10,16,13,11,10,8,7,5,2,2,2,4,6,9,12,14,15,16,3,16,11,11,10,9,8,7,5,4,3,3,3,3,3,3,4,5,6,5,9,9,7,6,5,4,3,3,2,3,4,5,4,5,5,6,8,6,13,12,10,8,5,3,3,2,2,3,4,7,9,11,14,15,6,15,50,204,24,102,135,25,96,6,205,0,24,0,7,0,0,0,2,0,13,0,50,0,153,1,49,3,194,12,13,51,51,204,103,0,0,0,254,2,190,0,94,0,45,0,10,0,9,0,3,0,3,0,0,0,2,0,8,0,44,0,93,0,126,1,254,5,255,5,92,0,0,0,105,81,104,81,181,40,23,5,163,0,41,0,8,0,3,0,0,0,9,0,21,0,80,0,68,1,138,2,44,10,91,20,11,0,0,0,49,18,141,4,71,2,144,0,37,0,8,0,1,0,3,0,0,0,5,0,19,0,73,0,34,1,25,9,195,72,194,72,96,36,0,0,29,45,70,11,208,2,181,0,89,0,10,0,3,0,1,0,0,0,4,0,23,0,91,0,105,1,162,5,143,22,28,45,88,0,0,0,0,24,1,12,1,3,97,0,25,0,7,0,4,0,3,0,0,0,5,0,13,0,49,0,193,0,129,1,1,6,1,24,2,0,0,0,86,21,170,10,171,2,84,0,20,0,11,0,2,0,3,0,0,0,3,0,8,0,43,0,171,0,84,1,84,5,87,21,9,0,0,0,86,21,170,10,171,2,84,0,20,0,11,0,2,0,3,0,0,0,3,0,8,0,43,0,171,0,84,1,84,5,87,21,9,0,0,0,147,41,101,10,152,2,167,0,40,0,4,0,0,0,1,0,1,0,3,0,21,0,82,0,77,1,51,5,200,20,36,83,11,0,37,83,184,9,111,2,154,0,18,0,5,0,0,0,1,0,2,0,3,0,1,0,3,0,8,0,76,0,54,1,221,4,115,19,39,0,114,19,135,7,224,1,241,0,61,0,31,0,6,0,1,0,1,0,1,0,2,0,14,0,121,0,194,3,13,15,25,30,48,60,0,0,49,60,6,75,192,18,177,4,151,0,36,0,8,0,2,0,3,0,0,0,3,0,5,0,19,0,74,0,89,2,97,9,130,37,45,1,7,75,90,10,151,2,74,1,83,0,40,0,11,0,3,0,0,0,2,0,4,0,21,0,164,0,44,5,183,20,108,41,219,82,3,0,218,82,147,1,146,1,200,0,101,0,51,0,24,0,7,0,4,0,0,0,4,0,5,0,7,0,6,0,3,0,5,0,5,0,13,0,4,0,18,0,19,0,5,0,3,0,0,0,3,0,5,0,4,0,3,0,3,0,5,0,5,0,4,0,4,0,3,0,5,0,8,0,4,0,102,13,178,6,173,1,106,0,12,0,5,0,4,0,0,0,3,0,2,0,7,0,52,0,215,0,88,3,207,26,156,53,27,0,157,53,87,119,58,57,96,203,165,57,22,106,19,58,111,18,131,58,45,21,233,58,57,62,79,59,155,68,184,59,10,215,35,60,60,173,145,60,227,134,1,61,194,85,102,61,205,204,204,61,139,24,54,62,156,232,161,62,153,245,15,63,0,0,128,63,174,158,227,63,195,98,74,64,0,243,179,64,0,0,32,65,45,67,142,65,116,251,252,65,192,239,96,66,0,0,200,66,248,211,49,67,41,29,158,67,216,149,12,68,0,0,122,68,246,72,222,68,115,164,69,69,78,187,175,69,0,64,28,70,1,1,1,1,1,1,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,2,0,3,2,3,3,0,0,0,0,0,0,0,0,0,0,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,2,2,2,2,0,1,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,112,27,37,0,192,206,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,112,27,37,0,144,225,34,0,192,206,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,112,27,37,0,208,30,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,27,37,0,40,130,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,27,37,0,248,6,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,27,37,0,176,161,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,27,37,0,32,70,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,27,37,0,168,45,40,0,32,209,39,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,168,45,40,0,136,104,39,0,32,209,39,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,168,45,40,0,208,30,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,45,40,0,40,130,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,45,40,0,248,6,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,45,40,0,176,161,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,45,40,0,32,70,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,168,45,40,0,112,25,39,0,184,212,38,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,112,25,39,0,120,143,38,0,184,212,38,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,112,25,39,0,208,30,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,25,39,0,40,130,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,25,39,0,248,6,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,25,39,0,176,161,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,25,39,0,32,70,32,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,25,39,0,112,84,38,0,0,29,38,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,88,240,37,0,0,29,38,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,194,37,0,216,160,37,0,20,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,248,119,37,0,216,160,37,0,20,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,136,52,37,0,144,10,37,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,184,226,36,0,144,10,37,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,68,36,0,112,0,0,0,56,103,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,135,37,136,5,160,0,0,45,178,157,239,167,198,6,64,61,10,215,163,112,189,18,192,66,96,229,208,34,219,24,64,35,219,249,126,106,188,28,192,117,147,24,4,86,142,26,64,84,227,165,155,196,32,20,192,180,200,118,190,159,26,10,64,233,38,49,8,172,28,250,191,251,58,112,206,136,210,218,63,1,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,73,110,100,101,120,32,118,97,108,117,101,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,32,40,48,32,45,32,37,100,41,32,102,111,114,32,37,115,32,97,116,32,37,115,58,37,105,10,0,0,0,4,49,46,52,0,0,0,0,79,0,21,0,0,0,0,0,16,162,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,225,34,0,120,31,34,0,4,0,0,0,4,0,0,0,164,112,61,10,215,163,240,63,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,152,130,33,0,80,7,33,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,248,63,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,162,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,72,36,0,112,0,0,0,216,109,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,5,2,6,3,7,112,133,33,0,168,122,33,0,246,0,0,0,172,1,0,0,72,113,33,0,96,187,33,0,22,1,0,0,132,1,0,0,184,103,33,0,184,103,33,0,30,1,0,0,0,0,0,0,248,92,33,0,248,92,33,0,150,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,72,32,0,184,59,38,0,8,1,33,0,8,226,33,0,232,64,32,0,240,173,39,0,208,57,32,0,152,43,32,0,80,51,32,0,24,126,38,0,248,44,32,0,24,12,38,0,0,39,32,0,96,185,37,0,208,33,32,0,96,184,36,0,0,0,0,0,0,0,0,0,43,125,128,62,238,131,132,62,125,59,141,62,87,66,156,62,243,4,181,62,68,41,223,62,217,111,151,62,234,70,247,62,0,0,0,0,0,0,0,0,143,149,62,64,6,247,65,66,107,190,157,70,190,43,33,78,154,121,130,90,222,161,148,111,98,236,183,75,29,117,163,123,0,0,0,0,0,0,0,0,43,125,0,63,238,131,4,63,125,59,13,63,87,66,28,63,243,4,53,63,68,41,95,63,217,111,151,63,234,70,247,63,84,148,183,64,0,0,0,0,150,62,64,0,247,65,66,0,190,157,70,0,44,33,78,0,122,130,90,0,162,148,111,0,217,111,151,0,234,70,247,0,81,81,222,2,0,0,0,0,203,132,250,47,70,59,233,63,178,199,12,24,6,194,218,63,253,72,218,75,62,213,164,191,22,48,54,198,158,133,176,191,0,0,0,0,0,0,0,0,65,2,118,189,78,73,235,63,111,126,145,78,94,39,216,191,246,216,29,135,225,81,188,191,92,46,36,129,254,107,152,63,2,127,133,86,64,94,163,63,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,1,255,0,0,1,255,0,0,1,255,0,0,1,255,0,1,1,255,0,1,1,255,1,1,1,255,1,1,1,255,1,1,1,255,1,1,1,255,1,1,2,255,1,1,2,255,1,1,2,255,1,1,2,255,1,2,3,255,1,2,3,255,2,2,3,255,2,2,4,255,2,3,4,255,2,3,4,255,3,3,5,255,3,4,6,255,3,4,6,255,4,5,7,255,4,5,8,255,4,6,9,255,5,7,10,255,6,8,11,255,6,8,13,255,7,10,14,255,8,11,16,255,9,12,18,255,10,13,20,255,11,15,23,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,255,13,17,25,61,153,99,255,0,0,0,0,1,0,255,255,2,0,2,0,2,0,1,0,2,0,0,0,2,0,3,0,2,0,2,16,2,0,1,16,2,0,0,16,2,0,3,16,2,0,2,32,2,0,1,32,2,0,0,32,2,0,3,32,2,0,2,15,2,0,1,15,2,0,0,15,2,0,3,15,2,0,2,31,2,0,1,31,2,0,0,31,2,0,3,31,2,0,2,47,2,0,1,47,2,0,0,47,2,0,3,47,4,0,255,255,1,0,255,255,2,0,2,0,2,0,1,0,2,0,0,0,2,0,3,0,2,0,2,16,2,0,1,16,2,0,0,16,2,0,3,16,2,0,2,32,2,0,1,32,2,0,0,32,2,0,3,32,2,0,2,15,2,0,1,15,2,0,0,15,2,0,3,15,2,0,2,31,2,0,1,31,2,0,0,31,2,0,3,31,2,0,2,47,2,0,1,47,2,0,0,47,2,0,3,47,4,0,255,255,1,0,255,255,2,0,2,0,2,0,1,0,2,0,0,0,2,0,3,0,2,0,2,16,2,0,1,16,2,0,0,16,2,0,3,16,2,0,2,32,2,0,1,32,2,0,0,32,2,0,3,32,2,0,2,15,2,0,1,15,2,0,0,15,2,0,3,15,2,0,2,31,2,0,1,31,2,0,0,31,2,0,3,31,2,0,2,47,2,0,1,47,2,0,0,47,2,0,3,47,4,0,255,255,0,0,0,0,0,0,0,0,5,7,7,7,5,7,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,29,30,31,32,32,33,34,34,35,35,36,36,37,37,37,38,38,38,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,3,3,3,3,4,4,4,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,18,18,18,18,18,18,18,18,18,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,5,6,7,8,9,10,12,13,15,17,20,22,25,28,32,36,40,45,50,56,63,71,80,90,101,113,127,144,162,182,203,226,255,255,255,255,255,255,255,255,255,255,255,255,255,255,11,255,255,255,255,255,255,255,255,255,9,1,8,255,255,255,255,255,255,255,10,0,3,7,255,255,255,255,255,255,2,1,0,3,7,8,255,255,255,255,2,1,0,3,4,5,6,7,8,255,11,255,255,255,255,255,255,255,255,255,9,1,8,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,8,255,255,255,255,255,255,255,255,1,6,8,255,255,255,255,255,255,255,0,0,0,0,11,255,255,255,255,255,255,255,255,255,9,1,8,255,255,255,255,255,255,255,10,0,3,7,255,255,255,255,255,255,2,1,0,3,7,8,255,255,255,255,2,1,0,3,4,5,6,7,8,255,11,255,255,255,255,255,255,255,255,255,9,1,8,255,255,255,255,255,255,255,10,0,255,255,255,255,255,255,255,255,2,1,0,8,255,255,255,255,255,255,2,1,0,4,5,6,8,255,255,255,0,0,0,0,6,255,255,255,255,4,1,255,255,255,5,0,255,255,255,0,1,2,255,255,0,1,2,3,255,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,27,0,0,0,56,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,249,0,0,0,250,0,0,0,251,3,0,0,248,7,0,0,249,7,0,0,250,7,0,0,251,7,0,0,248,15,0,0,249,15,0,0,1,0,0,0,57,0,0,0,123,0,0,0,251,0,0,0,248,1,0,0,249,1,0,0,250,15,0,0,251,15,0,0,248,31,0,0,249,31,0,0,250,31,0,0,251,31,0,0,248,63,0,0,249,63,0,0,250,63,0,0,0,0,0,0,4,0,0,0,58,0,0,0,250,1,0,0,251,63,0,0,248,127,0,0,249,127,0,0,250,127,0,0,251,127,0,0,248,255,0,0,249,255,0,0,250,255,0,0,251,255,0,0,248,255,1,0,249,255,1,0,250,255,1,0,0,0,0,0,12,0,0,0,248,0,0,0,251,1,0,0,251,255,1,0,248,255,3,0,249,255,3,0,250,255,3,0,251,255,3,0,248,255,7,0,249,255,7,0,250,255,7,0,251,255,7,0,248,255,15,0,249,255,15,0,250,255,15,0,0,0,0,0,26,0,0,0,248,3,0,0,251,255,15,0,248,255,31,0,249,255,31,0,250,255,31,0,251,255,31,0,248,255,63,0,249,255,63,0,250,255,63,0,251,255,63,0,248,255,127,0,249,255,127,0,250,255,127,0,251,255,127,0,0,0,0,0,59,0,0,0,249,3,0,0,248,255,255,0,249,255,255,0,250,255,255,0,251,255,255,0,248,255,255,1,249,255,255,1,250,255,255,1,251,255,255,1,248,255,255,3,249,255,255,3,250,255,255,3,251,255,255,3,248,255,255,7,0,0,0,0,250,3,0,0,249,255,255,7,250,255,255,7,251,255,255,7,248,255,255,15,249,255,255,15,250,255,255,15,251,255,255,15,248,255,255,31,249,255,255,31,250,255,255,31,251,255,255,31,248,255,255,63,249,255,255,63,250,255,255,63,0,0,0,0,0,8,9,10,11,12,13,14,15,16,17,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,104,105,106,107,108,109,110,111,112,113,114,115,116,117,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,2,3,0,0,2,3,4,5,6,7,20,21,22,23,24,25,52,53,54,55,56,57,58,59,120,121,122,123,124,125,126,127,8,9,0,0,2,3,8,9,10,11,28,29,60,61,62,63,12,13,0,0,4,5,12,13,28,29,30,31,0,0,0,0,0,0,0,0,4,5,12,13,14,15,0,0,4,5,6,7,0,0,0,0,4,5,12,13,28,29,30,31,0,0,0,0,0,0,0,3,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,4,4,0,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,4,4,0,2,3,3,4,4,4,4,5,5,6,6,6,6,4,4,0,1,3,3,4,4,5,5,5,5,0,0,0,0,0,0,0,1,3,3,4,4,4,4,0,1,3,3,3,3,0,0,0,1,3,3,4,4,5,5,5,5,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,5,6,7,7,7,8,8,10,11,11,11,11,12,12,2,6,7,8,9,9,12,12,13,13,13,13,14,14,14,0,3,6,9,14,15,15,15,15,16,16,16,16,17,17,17,0,4,8,9,17,18,18,18,18,19,19,19,19,20,20,20,0,5,10,20,21,21,21,21,22,22,22,22,23,23,23,23,0,6,10,24,24,24,24,25,25,25,25,26,26,26,26,27,0,10,27,27,27,28,28,28,28,29,29,29,29,30,30,30,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,130,0,0,0,128,0,0,0,154,0,0,0,166,0,0,0,142,0,0,0,204,0,0,0,190,0,0,0,170,0,0,0,30,2,0,0,204,1,0,0,150,2,0,0,158,1,0,0,0,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,130,0,0,0,128,0,0,0,154,0,0,0,166,0,0,0,142,0,0,0,204,0,0,0,190,0,0,0,170,0,0,0,30,2,0,0,204,1,0,0,150,2,0,0,158,1,0,0,9,5,7,9,15,31,63,0,1,2,1,7,6,0,2,3,1,3,4,5,5,4,4,3,1,1,6,4,15,14,5,0,1,3,4,4,5,5,4,3,30,30,14,14,7,7,0,0,0,0,0,0,0,0,0,0,1,2,2,3,2,0,3,3,1,3,4,5,5,4,4,3,1,0,6,4,2,3,5,7,1,3,4,4,4,4,4,4,212,78,213,78,206,78,207,78,204,78,214,78,216,78,70,79,96,79,24,39,25,39,100,39,101,39,109,39,177,39,183,19,214,19,199,9,233,9,237,9,238,4,247,4,120,2,57,1,154,0,159,0,32,0,17,0,10,0,3,0,1,0,0,0,11,0,18,0,33,0,76,0,155,0,58,1,121,2,112,2,239,4,226,4,234,9,216,9,215,19,208,19,178,39,162,39,26,39,27,39,102,79,103,79,97,79,71,79,217,78,215,78,205,78,210,78,211,78,208,78,209,78,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,15,15,15,15,15,15,14,14,13,13,13,12,12,11,10,9,9,7,6,5,3,1,2,5,6,7,8,9,10,11,11,12,12,13,13,14,14,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,0,0,0,249,255,7,0,250,255,7,0,251,255,7,0,248,255,15,0,249,255,15,0,250,255,15,0,253,255,1,0,254,127,0,0,254,15,0,0,254,3,0,0,254,0,0,0,62,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,30,0,0,0,126,0,0,0,254,1,0,0,254,7,0,0,254,31,0,0,254,63,0,0,252,255,1,0,248,255,7,0,251,255,15,0,252,255,15,0,253,255,15,0,254,255,15,0,255,255,15,0,0,0,0,0,19,19,19,20,20,20,17,15,12,10,8,6,4,2,1,3,5,7,9,11,13,14,17,19,20,20,20,20,20,0,0,0,180,254,1,0,181,254,1,0,118,253,1,0,119,253,1,0,116,253,1,0,117,253,1,0,138,254,1,0,139,254,1,0,136,254,1,0,128,254,0,0,182,254,1,0,130,254,0,0,184,254,0,0,66,127,0,0,174,127,0,0,175,63,0,0,209,31,0,0,233,31,0,0,233,15,0,0,234,7,0,0,251,7,0,0,251,3,0,0,251,1,0,0,255,1,0,0,124,0,0,0,60,0,0,0,28,0,0,0,12,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,13,0,0,0,29,0,0,0,61,0,0,0,125,0,0,0,252,0,0,0,252,1,0,0,252,3,0,0,244,3,0,0,235,7,0,0,234,15,0,0,234,31,0,0,214,31,0,0,208,63,0,0,175,127,0,0,67,127,0,0,185,254,0,0,131,254,0,0,183,254,1,0,129,254,0,0,137,254,1,0,142,254,1,0,143,254,1,0,140,254,1,0,141,254,1,0,178,254,1,0,179,254,1,0,176,254,1,0,177,254,1,0,0,0,0,0,18,18,18,18,18,18,18,18,18,17,18,17,17,16,16,15,14,14,13,12,12,11,10,10,8,7,6,5,4,3,1,3,4,5,6,7,8,9,10,11,11,12,13,14,14,15,16,16,17,17,18,17,18,18,18,18,18,18,18,18,18,0,0,0,251,255,1,0,252,255,1,0,253,255,1,0,250,255,1,0,252,255,0,0,252,127,0,0,253,31,0,0,254,3,0,0,254,1,0,0,126,0,0,0,60,0,0,0,29,0,0,0,13,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,12,0,0,0,28,0,0,0,61,0,0,0,62,0,0,0,254,0,0,0,254,7,0,0,252,31,0,0,252,63,0,0,253,63,0,0,253,127,0,0,254,255,1,0,254,255,3,0,255,255,3,0,0,0,0,0,17,17,17,17,16,15,13,10,9,7,6,5,4,3,1,3,4,5,6,6,8,11,13,14,14,15,17,18,18,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,254,63,254,31,254,7,254,1,126,0,30,0,6,0,0,0,2,0,14,0,62,0,254,0,254,3,254,15,255,63,0,0,14,13,11,9,7,5,3,1,2,4,6,8,10,12,14,0,255,63,254,63,254,15,254,3,126,0,30,0,6,0,0,0,2,0,14,0,62,0,254,0,254,1,254,7,254,31,0,0,14,14,12,10,7,5,3,1,2,4,6,8,9,11,13,0,104,120,16,0,96,120,16,0,88,120,16,0,72,120,16,0,56,120,16,0,24,120,16,0,216,119,16,0,0,0,0,0,8,121,16,0,0,121,16,0,248,120,16,0,232,120,16,0,216,120,16,0,184,120,16,0,120,120,16,0,0,0,0,0,0,1,2,62,63,3,4,5,59,60,61,6,7,8,9,10,54,55,56,57,58,11,12,13,14,15,16,47,49,50,51,52,53,17,18,19,20,45,46,48,21,22,23,24,25,26,27,37,38,39,40,41,42,43,44,28,29,30,35,31,33,34,36,0,2,11,1,0,4,6,10,12,7,15,4,4,0,0,0,0,0,16,240,1,15,32,224,17,241,2,14,31,255,208,33,225,18,242,3,13,30,254,47,239,48,64,96,112,144,160,192,49,209,34,226,19,243,4,6,7,9,12,29,253,46,238,63,223,80,176,65,97,113,145,161,193], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1070792);
/* memory initializer */ allocate([50,98,114,146,162,210,35,211,227,20,244,5,22,38,230,246,23,39,231,247,25,41,249,10,26,42,250,11,28,44,252,45,61,237,62,78,126,158,222,79,111,127,159,175,207,81,177,66,82,178,194,51,99,115,147,163,179,195,36,52,116,164,212,228,21,37,101,149,229,245,54,214,55,71,199,215,57,89,185,201,217,233,58,106,218,234,27,43,155,171,235,251,108,124,156,172,236,77,109,125,157,173,189,221,94,110,174,206,95,67,83,68,84,100,148,180,196,53,69,85,117,165,181,197,213,70,86,102,118,150,166,182,198,87,103,119,151,167,183,73,105,121,153,169,74,90,122,154,170,186,202,59,75,91,107,123,187,203,219,60,76,92,188,204,220,93,205,190,191,0,0,0,0,0,0,0,2,12,1,4,0,0,0,8,11,24,53,64,60,0,0,0,0,1,15,2,14,5,13,3,4,11,12,0,0,0,0,0,1,6,1,0,2,2,2,4,0,64,16,4,1,5,80,20,84,65,17,81,69,21,85,68,149,106,3,128,192,144,208,148,212,36,100,88,145,161,133,213,37,101,165,229,117,181,245,25,89,153,217,105,169,233,121,185,249,77,93,157,221,109,173,237,125,189,253,2,66,82,6,70,22,86,150,214,38,102,166,230,118,182,246,26,90,154,218,170,234,122,186,250,94,158,222,110,174,238,126,190,254,7,71,87,151,215,103,167,231,119,183,247,91,155,219,107,171,235,123,187,251,95,159,223,111,175,239,127,191,255,32,96,112,176,240,132,196,164,228,116,180,244,8,136,24,152,216,104,168,232,120,184,248,28,92,156,220,108,172,236,60,124,188,252,129,209,33,97,225,113,177,241,197,53,9,73,137,201,41,57,13,141,205,29,45,61,146,210,34,98,162,226,114,178,242,134,198,54,10,74,138,202,42,58,14,78,142,206,30,46,62,19,83,147,211,99,163,227,115,179,243,135,199,23,39,55,11,75,139,203,27,43,59,15,79,143,207,31,47,63,160,224,48,52,72,200,40,56,12,76,140,204,44,193,49,130,194,18,50,67,131,195,35,51,1,11,1,0,0,0,1,4,9,4,103,110,24,0,0,0,0,3,64,192,16,48,4,12,1,80,208,112,240,196,20,52,76,28,60,193,17,49,5,13,19,51,7,15,68,204,65,67,195,84,116,220,252,241,197,21,29,83,199,55,79,63,212,244,92,124,81,209,113,69,85,53,77,205,221,61,211,115,243,71,23,119,207,31,255,213,117,245,93,125,253,87,215,247,95,223,127,0,0,0,0,0,0,0,1,12,1,0,0,1,7,0,19,5,13,23,0,12,0,0,0,1,63,62,2,3,60,61,4,5,6,7,57,58,59,8,9,10,11,12,52,53,54,55,56,13,14,15,16,17,18,25,26,27,28,29,30,31,33,34,35,36,37,38,39,46,47,48,49,50,51,19,20,21,22,23,24,40,41,42,43,44,45,0,2,9,1,2,1,4,7,10,26,12,0,0,0,0,0,0,0,16,1,17,33,2,18,32,34,19,48,49,65,209,225,50,82,3,35,45,64,80,96,128,208,224,81,97,241,66,98,210,226,242,51,67,195,211,227,4,20,212,244,37,53,22,23,247,216,28,60,13,29,61,93,14,30,46,126,47,192,240,113,129,145,193,114,130,146,178,194,83,99,115,147,163,243,36,68,100,132,164,180,5,21,149,213,6,38,54,70,150,214,230,246,7,39,55,215,231,8,24,40,56,232,248,9,25,41,233,249,10,26,202,218,234,11,27,219,235,251,44,76,92,124,140,77,109,141,157,253,62,94,110,142,158,238,15,31,63,79,95,111,127,207,112,161,162,131,179,52,116,196,228,85,101,133,165,197,229,245,86,102,118,134,166,198,87,103,119,151,167,72,136,152,73,89,121,153,58,74,138,186,250,43,123,12,172,188,204,236,125,173,189,221,78,190,206,254,143,159,175,191,223,239,255,144,160,176,177,84,148,69,117,181,182,71,135,183,199,88,104,120,168,184,200,57,105,137,169,185,201,217,42,90,106,122,154,170,59,75,91,107,139,155,171,187,203,108,156,220,252,205,237,174,222,1,12,1,0,0,3,0,3,3,10,40,85,61,50,0,0,0,240,1,16,15,17,241,32,224,2,14,31,255,208,33,225,18,242,7,10,13,30,254,47,239,48,112,144,160,192,113,145,193,209,50,146,226,3,19,99,4,6,230,231,247,9,25,57,250,12,28,221,237,253,46,126,158,63,159,64,80,96,176,49,65,97,161,177,34,66,114,162,178,194,210,35,51,115,163,195,211,227,243,20,36,52,68,116,212,228,5,37,69,101,149,165,22,38,70,118,166,182,198,214,246,23,39,55,71,103,167,215,41,105,185,217,233,249,26,42,58,154,202,218,234,11,27,59,107,235,251,44,108,236,252,29,45,77,109,157,173,62,78,110,174,206,238,79,95,111,223,81,82,98,67,147,179,84,148,164,244,21,117,181,229,245,54,86,102,150,87,119,73,89,169,201,74,90,106,122,170,186,43,75,123,155,171,219,60,76,124,156,172,188,204,61,93,125,189,205,94,190,222,191,207,83,100,180,196,53,85,197,213,151,183,199,121,153,91,187,203,92,220,127,175,0,0,0,0,0,0,0,1,12,1,0,0,2,2,2,6,12,34,92,54,20,0,0,1,0,2,5,3,4,0,0,1,5,1,1,1,1,2,0,0,1,7,2,3,5,6,0,1,5,1,1,1,0,4,0,0,64,1,16,4,2,128,80,144,5,6,32,96,68,20,84,36,8,24,65,17,21,9,160,132,148,100,164,40,81,69,85,25,18,22,10,26,72,88,104,129,145,33,97,133,149,37,101,73,89,41,105,66,70,86,136,152,168,161,165,153,169,82,34,38,102,74,90,42,106,137,130,146,98,134,150,166,138,170,162,154,0,0,0,0,0,0,0,1,12,1,0,0,2,3,5,12,14,18,15,9,2,0,0,0,1,31,2,30,3,4,13,29,5,6,7,14,15,17,18,19,26,27,28,8,9,12,20,21,22,23,24,25,10,11,0,1,9,1,0,2,0,2,4,11,9,2,0,0,0,0,0,0,7,1,2,3,5,6,0,1,5,1,1,1,0,4,0,0,1,8,56,7,57,15,48,9,63,16,49,2,58,6,14,23,17,10,62,55,18,50,22,54,0,0,0,0,0,0,0,1,9,1,0,1,3,2,3,7,4,4,0,0,0,0,0,0,1,2,62,63,3,4,60,61,5,6,7,57,58,59,8,9,10,11,12,26,27,37,38,52,53,54,55,56,13,14,15,16,17,18,25,28,29,30,31,33,34,35,36,39,46,47,48,49,50,51,19,20,21,22,23,24,40,41,42,43,44,45,0,2,9,1,1,3,4,6,14,22,12,0,0,0,0,0,0,0,7,8,56,1,9,57,15,63,16,48,49,2,58,6,14,23,55,24,40,17,25,41,10,3,11,59,5,13,61,62,31,47,18,26,42,50,19,51,21,53,22,30,46,54,27,43,29,45,0,0,0,0,0,0,0,2,9,1,1,3,4,9,15,12,4,0,0,0,0,0,0,0,7,8,56,1,57,15,16,9,63,48,49,2,58,6,14,23,17,10,62,55,18,50,22,54,0,0,0,0,0,0,0,1,9,1,0,1,3,2,3,7,4,4,0,0,0,0,0,0,1,64,192,16,48,4,12,3,80,208,112,240,196,20,52,76,28,60,193,17,49,5,13,195,19,51,7,15,68,204,65,67,84,116,220,252,113,21,77,29,55,63,212,244,92,124,81,209,241,69,197,53,205,221,61,83,211,115,243,71,199,23,119,79,207,31,85,255,213,117,245,93,125,253,87,215,247,95,223,127,0,0,0,0,0,0,0,1,12,1,0,0,1,7,0,20,4,10,24,2,12,0,0,0,1,63,2,62,3,61,4,5,6,58,59,60,7,8,9,10,25,26,27,28,29,34,35,37,38,39,55,56,57,11,13,14,15,30,31,33,36,49,50,51,52,53,54,12,16,17,18,19,21,41,43,44,45,46,47,48,20,22,23,24,40,42,0,1,11,1,0,2,0,2,2,6,17,14,13,6,0,0,0,0,16,240,1,15,17,241,2,14,31,255,32,224,33,242,254,239,48,208,225,18,34,226,3,13,29,30,46,238,47,223,64,96,112,144,160,176,192,49,113,145,193,209,50,210,19,227,243,4,5,6,7,23,247,9,25,10,26,250,12,28,45,237,253,62,126,222,63,111,127,159,175,207,80,65,81,97,161,177,98,114,146,162,194,35,51,99,115,147,163,211,20,36,52,212,228,244,21,245,22,38,214,230,246,39,55,71,231,41,57,201,217,233,249,42,234,11,27,251,44,124,236,252,61,77,109,125,221,78,94,110,158,174,206,79,95,66,82,178,67,179,195,68,100,116,148,164,37,53,101,117,149,165,229,54,70,102,118,150,166,182,198,87,167,183,199,215,89,169,185,58,74,106,202,218,43,59,107,155,171,219,235,60,108,156,172,204,220,93,157,173,189,205,190,191,83,84,180,196,69,85,181,197,213,86,103,119,151,73,105,121,153,90,122,154,170,186,75,91,123,187,203,76,92,188,0,0,0,0,0,0,0,1,12,1,0,0,0,4,6,6,14,42,63,59,30,0,0,0,64,16,4,1,80,68,20,84,65,17,81,5,69,21,85,32,149,101,73,89,82,70,22,128,144,96,132,148,36,100,164,8,72,24,88,129,145,33,97,133,37,9,25,105,2,66,18,6,86,90,87,208,116,104,92,193,213,165,229,117,181,245,153,217,169,233,121,185,249,29,93,157,221,109,173,237,125,189,253,130,146,210,98,150,214,38,102,166,230,118,182,246,10,74,26,154,218,42,106,170,234,122,186,250,94,158,222,110,174,238,126,190,254,3,19,83,23,151,215,103,167,231,119,183,247,91,155,219,107,171,235,123,187,251,95,159,223,111,175,239,127,191,255,192,160,224,48,196,212,228,52,180,244,136,200,152,216,40,168,232,56,120,184,248,12,76,28,156,220,108,172,236,124,188,252,209,161,225,49,113,177,241,197,53,137,201,41,57,13,77,141,205,45,61,34,162,226,114,178,242,134,198,54,138,202,58,14,78,142,206,30,46,62,67,131,147,211,35,99,163,227,115,179,243,7,71,135,199,39,55,75,139,203,27,43,59,79,143,207,31,112,176,240,140,204,44,60,194,50,195,15,47,63,51,11,2,12,1,0,0,4,11,8,28,92,97,13,2,0,0,0,0,64,16,4,1,80,68,20,65,17,5,128,84,81,69,21,85,2,144,32,96,132,36,8,24,9,18,6,160,148,100,72,88,129,145,33,97,133,149,37,101,73,25,89,66,82,70,22,86,10,164,40,104,161,165,41,105,38,74,26,90,136,152,168,137,153,169,130,146,34,98,134,150,102,154,42,106,162,166,138,170,0,0,0,0,0,0,0,2,11,1,0,4,6,7,10,22,11,16,4,0,0,0,0,0,1,16,17,32,33,2,18,48,49,34,3,19,64,65,81,50,66,35,51,4,20,36,21,80,97,113,209,225,82,98,210,67,83,211,52,68,5,37,53,6,22,38,23,24,29,45,61,30,46,96,112,128,208,224,240,129,145,161,193,241,114,130,146,194,226,242,99,115,227,243,84,100,116,212,228,244,69,85,101,213,229,245,54,70,86,214,230,7,39,55,71,215,8,40,56,25,41,26,27,28,44,13,77,93,109,125,14,62,78,94,110,15,31,47,63,79,144,160,192,177,162,178,131,147,163,179,195,132,148,164,196,117,133,149,197,102,118,134,150,198,246,87,103,119,231,247,72,88,104,120,216,232,248,9,57,73,89,217,233,249,10,42,58,74,218,234,11,43,59,219,235,12,60,76,92,108,220,141,157,173,189,205,126,142,158,174,190,206,95,111,127,143,159,175,176,180,165,181,166,182,135,151,167,183,199,136,152,168,200,105,121,137,153,169,201,90,106,122,154,202,250,75,91,107,123,203,251,124,140,156,172,188,204,236,252,221,237,253,222,238,254,191,207,223,239,184,185,138,170,186,139,155,171,187,255,3,12,2,2,4,5,11,26,67,78,51,10,0,0,0,0,0,16,1,17,32,33,2,18,48,49,65,34,50,3,19,35,20,64,81,97,66,82,51,67,4,36,52,21,37,22,80,96,112,113,129,209,225,98,114,130,210,83,99,115,211,68,84,5,53,69,85,6,38,54,7,23,39,55,24,40,25,29,45,61,30,46,31,128,144,208,224,240,145,161,177,193,241,146,162,178,194,226,242,131,147,163,195,227,243,100,116,132,148,212,228,244,101,117,133,213,229,70,86,102,118,214,230,71,87,103,215,8,56,72,88,9,41,57,73,10,26,42,58,27,43,12,28,44,60,13,77,93,109,125,14,62,78,94,110,15,47,63,79,160,176,192,179,164,180,196,149,165,181,197,245,134,150,166,182,198,246,119,135,151,167,199,231,247,104,120,136,152,216,232,248,89,105,121,137,217,233,249,74,90,106,122,218,234,11,59,75,91,219,235,76,92,108,124,140,220,141,157,173,189,205,126,142,158,174,190,95,111,127,143,159,183,168,184,200,153,169,185,201,138,154,170,186,202,250,107,123,139,155,171,187,203,251,156,172,188,204,236,252,221,237,253,206,222,238,254,175,191,207,223,239,255,4,12,4,4,9,13,37,76,72,39,2,0,0,0,0,0,0,16,240,1,15,241,31,255,32,224,17,2,14,48,80,176,208,33,225,18,242,3,5,11,13,30,254,47,239,64,192,49,81,177,193,209,34,82,226,19,243,4,21,245,27,235,251,12,29,253,46,94,238,63,95,191,223,65,50,66,178,210,35,83,179,227,20,36,228,244,37,53,213,229,43,59,219,28,44,188,236,252,45,189,237,62,78,190,222,79,207,194,51,67,195,211,52,68,84,180,212,69,85,197,75,203,60,76,92,204,220,61,77,93,205,221,206,196,181,91,187,0,0,0,0,0,0,0,1,12,1,0,0,4,0,3,5,16,28,34,26,4,0,0,0,64,4,1,16,80,68,20,84,65,17,81,5,69,21,85,128,144,32,96,132,148,36,100,8,72,24,129,145,97,133,149,37,101,9,73,25,89,2,66,18,82,6,70,22,86,164,88,104,33,165,41,105,26,90,160,136,152,40,161,137,153,169,146,34,98,134,150,38,102,10,74,106,168,130,162,166,138,154,42,170,0,0,0,0,0,0,0,3,10,1,3,12,0,30,9,18,8,0,0,0,0,0,0,0,1,63,2,62,3,4,60,61,5,6,7,8,56,57,58,59,9,10,11,12,25,26,27,28,29,30,31,33,34,35,36,37,38,39,51,52,53,54,55,13,14,15,16,17,18,19,45,46,47,48,49,50,20,21,22,23,24,40,41,42,43,44,0,3,9,3,2,4,8,23,13,10,0,0,0,0,0,0,0,0,16,240,1,15,17,241,31,255,32,224,2,14,48,208,33,225,18,242,3,13,30,254,47,239,64,96,112,144,160,192,49,209,34,50,210,226,19,35,227,243,4,6,7,9,10,12,29,45,253,46,62,238,63,223,80,176,65,81,97,113,145,161,177,193,66,98,114,146,162,194,51,147,163,211,20,36,228,244,5,21,245,22,38,214,230,246,23,39,215,231,247,25,41,57,233,249,26,42,234,250,11,27,251,28,44,236,252,61,125,157,221,237,78,110,126,158,174,206,222,79,95,111,127,159,175,191,207,82,178,67,83,99,115,179,195,52,68,100,116,148,164,180,196,212,37,53,101,117,149,165,213,229,54,70,86,102,166,182,198,55,71,87,183,199,73,89,105,185,201,217,58,74,90,106,170,186,202,218,43,59,107,123,155,171,219,235,60,76,108,124,156,172,204,220,77,93,109,173,189,205,94,190,84,69,85,181,197,118,150,103,119,151,167,121,153,169,122,154,75,91,187,203,92,188,0,0,0,0,0,0,0,3,11,1,4,4,4,12,30,73,75,22,0,0,0,0,0,0,16,240,1,15,17,241,31,255,32,224,2,242,14,33,225,18,226,30,46,254,47,239,48,80,176,192,208,49,177,209,34,210,3,19,227,243,244,5,229,245,11,27,12,13,29,45,253,62,238,63,95,223,64,65,81,193,50,66,82,178,194,35,51,179,195,211,4,20,36,212,228,21,37,197,213,43,59,235,251,28,44,60,92,236,252,61,93,221,237,78,94,190,206,222,79,191,207,67,83,52,84,180,196,53,69,85,181,75,91,203,219,76,188,204,220,77,189,205,68,187,0,0,0,0,0,0,0,2,11,1,0,4,4,5,9,30,45,21,2,0,0,0,0,0,8,56,1,7,48,9,57,15,63,16,24,40,49,2,58,3,5,6,14,23,55,17,25,41,10,50,11,59,13,21,61,62,31,47,18,26,42,19,27,43,51,29,45,53,22,30,46,54,0,0,0,0,0,0,0,1,9,1,0,0,4,0,5,12,13,14,0,0,0,0,0,0,64,16,4,1,80,68,20,84,65,17,5,21,128,81,69,85,144,32,96,36,8,24,9,2,6,132,148,100,72,88,129,145,33,97,149,37,101,25,89,66,18,70,22,86,160,164,40,104,133,165,73,41,105,82,10,26,90,136,152,161,137,153,169,34,98,150,38,102,74,106,168,130,146,162,134,166,138,154,42,170,0,0,0,0,0,0,0,1,12,1,0,0,4,0,8,4,9,19,13,13,10,0,0,0,1,3,64,192,16,48,4,12,80,208,112,240,52,28,5,13,19,7,15,68,196,20,76,204,60,65,193,17,49,67,195,51,84,116,220,252,113,21,77,29,211,199,55,63,212,244,92,124,81,209,241,69,197,85,53,205,221,61,83,115,243,71,23,119,79,207,31,255,245,125,215,95,213,117,93,253,87,247,223,127,0,0,0,0,0,0,0,1,12,1,0,0,2,6,0,11,13,12,24,4,8,0,0,0,16,1,17,32,33,2,18,48,49,65,34,3,19,35,20,64,81,97,50,66,51,4,36,21,22,80,96,208,113,129,209,225,241,82,98,114,210,67,83,99,211,52,68,84,5,37,53,69,6,38,54,23,39,24,13,29,45,61,30,46,31,112,128,224,240,145,161,193,130,146,194,226,242,115,131,147,227,243,100,116,132,212,228,244,85,101,213,229,245,70,86,102,214,7,55,71,87,8,40,56,72,25,41,57,26,42,27,28,44,60,77,93,109,14,62,78,94,15,47,63,79,144,160,176,192,177,162,178,163,179,195,148,164,180,196,117,133,149,165,197,118,134,150,230,246,103,119,135,215,231,247,88,104,120,136,216,232,248,9,73,89,105,217,233,249,10,58,74,90,218,234,11,43,59,75,219,12,76,92,108,220,125,141,157,173,189,205,110,126,142,158,174,190,95,111,127,143,159,175,181,166,182,198,151,167,199,152,168,184,200,121,137,153,169,185,201,106,122,138,154,170,202,250,91,107,123,139,203,235,251,124,140,156,172,188,236,252,221,237,253,206,222,238,254,191,207,223,183,186,155,171,187,204,239,255,3,12,1,3,4,8,10,36,60,78,48,8,0,0,0,0,0,1,14,15,2,3,13,4,6,10,12,5,7,9,11,0,2,6,1,3,3,4,4,0,0,16,240,1,15,17,241,31,255,32,224,2,242,14,33,225,18,226,30,46,254,47,239,48,80,176,192,208,49,177,209,34,210,3,19,227,243,244,5,229,245,11,27,12,13,29,45,253,62,238,63,95,223,64,65,81,193,50,66,82,178,194,35,51,179,195,211,4,20,36,212,228,21,37,197,213,43,59,235,251,28,44,60,92,236,252,61,93,221,237,78,94,190,206,222,79,191,207,67,83,52,84,180,196,53,69,85,181,75,91,203,219,76,188,204,220,77,189,205,68,187,0,0,0,0,0,0,0,1,12,1,0,0,4,0,4,5,9,30,45,21,2,0,0,0,8,56,1,57,7,15,9,63,16,48,49,2,58,6,14,23,17,10,50,13,22,62,55,24,40,25,41,18,42,3,59,5,21,30,31,47,26,11,43,51,53,61,46,54,19,27,29,45,0,0,0,0,0,0,0,2,10,1,1,5,2,8,7,13,8,4,0,0,0,0,0,0,64,16,4,1,80,68,20,84,65,17,5,21,81,69,85,128,144,32,100,8,25,2,6,96,132,148,36,72,24,88,129,145,33,97,133,149,37,101,9,73,89,66,18,82,70,22,86,160,164,152,40,104,161,165,153,41,105,150,38,102,10,74,26,90,136,168,137,169,130,146,34,98,134,166,42,106,162,138,154,170,0,0,0,0,0,0,0,2,11,1,0,4,8,3,8,24,17,12,4,0,0,0,0,1,3,1,1,2,0,0,0,0,1,2,62,63,3,4,60,61,5,6,7,57,58,59,8,9,10,11,12,13,26,38,52,53,54,55,56,14,15,16,17,18,19,25,27,28,29,30,31,33,34,35,36,37,39,45,46,47,48,49,50,51,20,21,22,23,24,40,41,42,43,44,0,2,9,1,1,3,4,6,13,25,10,0,0,0,0,0,0,0,1,31,2,30,3,4,15,17,28,29,5,6,7,8,24,25,26,27,9,10,11,21,22,23,12,19,20,13,14,18,0,2,10,1,2,2,6,8,6,3,1,2,0,0,0,0,0,0,1,15,14,2,3,13,4,6,10,12,5,7,9,11,0,2,7,3,0,1,3,4,4,0,16,32,224,240,2,14,239,48,1,17,33,49,241,18,242,30,238,223,255,64,192,208,209,225,34,50,66,210,226,3,19,35,179,195,227,243,228,5,245,43,12,252,29,45,189,221,253,46,78,222,254,15,31,47,63,80,176,65,81,177,193,82,178,194,51,67,83,211,4,20,36,52,68,84,180,196,212,244,21,37,53,69,85,181,197,213,229,11,27,59,75,91,187,203,219,235,251,28,44,60,76,92,188,204,220,236,13,61,77,93,205,237,62,94,190,206,79,207,95,191,0,0,0,0,0,0,0,4,9,1,7,12,36,63,2,0,64,16,80,4,68,20,1,65,5,69,85,84,17,81,21,128,144,96,36,100,164,72,97,149,37,165,2,66,82,22,86,32,132,148,24,88,129,145,133,101,9,73,25,89,153,41,105,121,93,18,98,6,70,134,102,26,90,106,71,23,192,160,224,196,212,116,8,120,12,76,28,92,209,33,225,113,197,229,117,181,137,189,146,34,150,166,54,10,74,138,154,42,122,222,110,67,19,83,35,7,119,75,27,155,107,47,208,48,112,228,52,244,200,152,40,104,168,232,56,184,248,156,44,108,124,161,177,213,53,201,217,169,233,57,185,249,205,29,45,173,125,194,210,162,178,242,198,38,118,182,218,170,234,58,250,14,78,46,126,190,254,3,131,99,163,179,135,87,151,215,39,11,139,91,43,171,207,31,159,127,191,176,240,180,136,216,140,204,220,172,236,60,188,252,193,49,241,245,13,77,141,157,221,109,237,61,253,130,226,50,114,214,230,246,202,186,142,206,30,94,158,174,238,62,195,147,211,227,51,115,243,199,103,167,231,55,183,247,203,219,235,59,123,187,251,15,79,143,95,223,111,175,239,63,255,3,11,1,1,10,4,16,29,46,75,74,0,0,0,0,0,0,8,56,1,7,57,15,9,63,16,48,49,2,58,6,14,23,55,17,10,50,22,62,18,54,0,0,0,0,0,0,0,3,8,5,2,2,9,5,2,0,64,192,16,48,4,12,1,3,112,80,208,240,68,196,20,52,76,28,60,49,5,13,19,7,15,116,204,220,252,65,193,17,67,195,51,84,212,244,92,124,81,209,113,241,69,197,21,53,77,205,29,61,83,211,115,243,71,199,23,55,79,207,31,63,85,213,117,245,93,221,253,87,215,119,247,255,125,95,223,127,0,0,0,0,0,0,0,2,11,1,0,8,0,1,16,10,29,12,4,0,0,0,0,0,1,2,61,62,63,3,4,5,6,58,59,60,7,8,9,10,54,55,56,57,11,12,13,14,15,26,27,28,36,37,38,49,50,51,52,53,16,17,18,19,20,21,23,24,25,29,30,31,33,34,35,39,43,44,45,46,47,48,22,40,41,42,0,3,9,1,5,7,8,16,22,4,0,0,0,0,0,0,0,4,0,1,2,3,28,29,30,31,5,6,7,24,25,27,8,9,14,19,21,22,23,26,10,11,12,13,15,17,18,20,0,3,7,1,8,6,8,8,0,0,1,2,3,6,7,4,5,1,6,1,1,1,0,3,2,0,1,15,31,16,224,240,17,241,47,255,32,33,225,2,18,242,3,243,14,46,254,63,48,64,208,193,209,34,194,51,227,12,204,13,29,45,253,30,62,94,239,192,82,178,210,67,195,211,36,69,245,75,91,251,28,61,189,221,238,191,207,223,80,176,49,65,81,177,50,66,226,19,35,83,179,4,20,52,68,84,180,196,212,228,244,5,21,37,53,85,181,197,213,229,11,27,43,59,187,203,219,235,44,60,76,92,188,220,236,252,77,93,205,237,78,190,206,222,79,95,0,0,0,0,0,0,0,4,9,4,7,12,19,21,58,0,1,2,6,7,3,5,0,0,8,56,1,7,9,57,15,63,16,2,6,48,17,49,10,58,14,23,55,50,22,62,18,54,0,0,0,0,0,0,0,1,10,1,0,2,2,0,4,3,8,3,2,0,0,0,0,0,64,192,48,4,1,3,16,12,208,112,52,28,13,7,80,240,68,196,20,76,204,60,65,193,17,49,5,67,195,19,51,15,116,220,29,55,84,212,244,92,124,252,209,113,241,197,21,53,77,205,221,61,83,211,115,71,199,23,119,79,31,63,81,69,85,243,207,255,213,117,245,93,125,253,87,215,247,95,223,127,0,0,0,0,0,0,0,2,11,1,0,6,2,6,18,4,26,6,12,0,0,0,0,0,1,2,62,63,3,4,5,6,8,54,56,57,58,59,60,61,7,9,10,11,12,13,14,53,55,15,16,17,18,19,20,21,36,37,39,42,52,22,25,28,35,38,40,41,43,45,46,47,48,49,50,51,23,24,26,27,29,30,31,33,34,44,0,4,9,5,12,9,12,15,10,2,0,48,33,49,65,97,18,34,66,98,67,83,36,69,38,39,16,64,176,1,17,129,50,82,114,146,3,19,51,99,20,52,84,100,116,5,21,37,53,85,101,6,70,86,87,103,136,32,81,145,209,242,35,131,147,4,68,132,148,117,133,197,54,102,150,182,7,55,151,8,40,56,72,104,9,105,121,10,42,27,155,44,77,80,96,112,128,144,160,192,208,224,240,113,161,177,193,225,241,130,162,178,194,210,226,115,163,179,195,211,227,243,164,180,196,212,228,244,149,165,181,213,229,245,22,118,134,166,198,214,230,246,23,71,119,135,167,183,199,215,231,247,24,88,120,152,168,184,200,216,232,248,25,41,57,73,89,137,153,169,185,201,217,233,249,26,58,74,90,106,122,138,154,170,186,202,218,234,250,11,43,59,75,91,107,123,139,171,187,203,219,235,251,12,28,60,76,92,108,124,140,156,172,188,204,220,236,252,13,29,45,61,93,109,125,141,157,173,189,205,221,237,253,14,30,46,62,78,94,110,126,142,158,174,190,206,222,238,254,15,31,47,63,79,95,111,127,143,159,175,191,207,223,239,255,5,9,1,16,31,36,172,0,1,2,0,3,4,5,6,7,2,4,2,2,4,0,0,0,0,16,240,1,15,17,241,31,255,32,224,33,225,2,18,242,14,30,254,47,239,48,80,208,209,34,226,3,19,243,13,29,45,253,46,238,63,223,64,176,192,49,65,81,177,193,50,178,194,210,35,179,211,227,4,20,228,244,5,21,213,229,245,11,27,43,59,235,251,12,28,44,252,61,93,237,62,78,94,190,222,79,95,191,207,66,82,51,83,195,36,180,212,37,53,197,75,203,219,60,76,92,220,236,77,189,205,221,206,67,52,68,84,196,69,85,181,91,187,188,204,0,0,0,0,0,0,0,4,10,5,4,12,17,47,24,12,0,0,0,0,0,0,0,0,7,1,2,6,3,5,0,2,4,2,3,2,0,0,0,0,64,1,16,80,4,68,20,84,65,17,81,5,69,21,85,89,128,144,32,96,132,148,36,100,8,72,24,88,129,145,33,97,133,149,37,101,9,73,25,2,66,18,82,6,70,22,86,160,164,104,161,165,153,41,105,150,102,74,26,90,136,152,40,137,169,130,146,34,98,134,38,166,10,154,42,106,168,162,138,170,0,0,0,0,0,0,0,3,10,1,2,13,1,31,13,16,4,0,0,0,0,0,0,0,64,192,16,48,4,12,1,3,80,208,112,240,196,52,76,204,28,65,193,49,5,13,67,195,19,7,15,68,20,116,220,60,17,29,51,55,84,212,244,92,124,252,209,113,241,197,21,53,77,205,221,61,211,115,71,199,23,119,31,63,81,69,85,213,117,245,93,125,253,83,243,87,215,247,79,207,95,223,127,255,0,0,0,0,0,0,0,1,12,1,0,0,6,2,0,0,0,19,9,24,20,0,0,0,1,2,3,61,62,63,4,5,6,58,59,60,7,8,9,10,54,55,56,57,11,12,13,14,15,16,25,26,27,28,29,30,35,36,37,38,48,49,50,51,52,53,17,18,19,20,21,22,23,24,31,33,34,39,40,41,42,43,44,45,46,47,0,4,8,7,6,8,22,20,0,0,16,1,17,32,33,2,18,34,49,65,50,19,35,48,64,81,66,3,51,67,4,20,36,52,21,37,80,97,113,209,82,98,114,210,83,99,211,68,84,100,5,53,69,85,22,38,54,70,23,39,29,45,61,96,112,208,129,145,161,193,225,241,130,146,194,226,242,115,131,227,243,116,132,196,212,228,244,101,117,133,213,229,6,86,102,214,230,7,55,71,87,103,215,231,24,40,56,72,88,216,25,41,42,28,44,13,77,93,109,125,141,157,30,46,62,78,94,110,126,31,47,63,128,144,160,192,224,240,177,162,178,147,163,179,195,148,164,180,149,165,181,197,245,118,134,150,166,198,246,119,135,151,167,199,247,8,104,120,136,152,200,232,248,9,57,73,89,105,121,137,217,233,249,10,26,58,74,90,106,218,234,250,27,43,59,75,91,219,235,251,12,60,76,92,108,124,140,156,220,236,173,189,205,221,237,14,142,158,174,190,15,79,95,111,127,143,159,175,176,182,183,168,184,153,169,185,201,122,138,154,170,186,202,11,107,123,139,155,203,172,188,204,252,253,206,222,238,254,191,207,223,239,255,171,187,3,12,1,3,5,5,13,27,69,96,35,2,0,0,0,0,0,240,15,16,1,255,32,224,17,241,14,31,48,64,208,33,225,2,18,34,226,242,3,19,30,46,62,238,254,47,239,210,67,243,4,13,45,61,63,223,80,96,112,144,176,49,65,145,161,193,209,66,162,194,35,51,227,36,52,180,212,244,5,21,69,229,22,54,86,166,198,214,246,87,199,247,9,41,73,89,105,249,10,42,58,74,218,234,250,11,43,171,235,251,12,28,44,60,76,92,204,220,252,29,77,109,189,205,237,253,78,110,206,222,127,160,192,81,97,113,177,50,82,98,114,146,178,83,99,115,147,163,179,195,211,20,68,84,100,116,148,164,196,228,37,53,85,101,117,149,165,181,197,213,245,6,38,70,102,118,150,182,230,7,23,39,55,71,103,119,151,167,183,215,231,25,57,121,153,169,185,201,217,233,26,90,106,122,154,170,186,202,27,59,75,91,107,123,155,187,203,219,108,124,156,172,188,236,93,125,157,173,221,94,126,158,174,190,79,95,111,159,175,191,207,0,0,0,0,0,0,0,2,10,1,0,2,3,6,19,9,75,110,0,0,0,0,0,1,0,2,3,4,5,0,0,1,5,1,1,1,1,2,0,0,16,64,80,4,68,20,84,1,65,17,81,5,69,21,85,144,32,148,100,24,33,149,25,105,2,82,6,70,22,128,96,132,212,36,8,72,88,104,129,145,97,133,37,101,165,9,73,89,41,66,18,86,150,166,10,23,27,208,196,116,244,136,200,40,161,113,197,213,117,153,185,77,29,45,109,34,98,102,74,26,154,106,142,94,67,35,7,71,87,107,192,160,224,112,176,164,228,52,180,152,216,168,56,120,12,76,28,92,156,108,124,193,209,225,49,229,53,181,245,137,169,121,249,13,205,157,221,173,61,125,130,194,146,210,226,114,242,134,214,230,118,182,138,90,218,234,250,78,30,158,238,3,19,83,151,183,11,75,139,91,155,235,123,15,79,31,95,159,47,63,191,232,184,248,140,44,60,252,177,201,217,233,57,93,237,189,162,50,38,54,42,170,186,14,46,110,131,195,147,99,179,167,55,48,240,204,220,172,236,188,241,141,253,178,198,246,202,58,122,206,222,174,62,126,190,254,211,163,227,51,115,243,135,199,215,39,103,231,119,247,203,219,43,171,59,187,251,143,207,223,111,175,239,127,255,3,12,1,1,13,1,14,28,33,81,32,52,0,0,0,0,0,64,1,16,4,128,80,32,20,5,2,144,96,68,84,36,8,24,65,17,21,9,6,160,132,148,100,164,72,88,40,81,33,69,85,37,25,18,22,10,26,104,168,129,145,97,161,133,149,101,165,73,89,41,105,66,82,70,86,42,136,152,137,153,169,130,146,34,98,134,38,102,74,90,106,162,150,166,138,154,170,0,0,0,0,0,0,0,1,11,1,0,0,2,2,6,12,18,19,15,6,0,0,0,0,4,12,1,3,5,13,7,15,0,0,0,0,0,0,0,1,6,1,0,3,1,0,4,0,2,3,1,5,6,7,9,54,55,56,58,59,60,61,62,63,4,8,10,11,12,14,49,52,53,57,13,15,16,17,18,19,22,23,25,26,30,39,43,44,45,46,47,48,50,51,20,21,24,27,28,29,31,33,34,35,36,37,38,40,41,42,0,4,8,3,14,10,20,16,0,0,1,17,16,33,18,34,32,48,49,65,2,50,3,19,35,51,20,36,64,81,97,66,82,67,83,4,52,68,21,37,53,22,38,80,96,113,129,209,98,114,130,210,99,115,211,84,100,5,69,85,101,6,54,70,86,23,39,55,71,24,40,56,25,29,45,61,30,112,128,144,208,224,145,161,177,193,225,241,146,162,194,226,242,131,147,163,195,227,243,116,132,148,164,196,212,228,244,117,133,149,213,229,102,118,134,214,230,7,87,103,119,215,8,72,88,104,216,9,41,57,73,89,105,26,42,58,74,27,43,28,44,60,76,13,77,93,109,125,141,14,46,62,78,94,110,31,47,63,79,95,160,176,192,240,178,179,180,165,181,197,245,150,166,182,198,246,135,151,167,183,199,231,247,120,136,152,168,200,232,248,121,137,153,201,217,233,249,10,90,106,122,138,218,234,250,11,59,75,91,107,123,139,219,12,92,108,124,140,156,220,157,173,189,205,126,142,158,174,190,15,111,127,143,159,175,184,169,185,154,170,186,202,155,171,187,203,235,251,172,188,204,236,252,221,237,253,206,222,238,254,191,207,223,239,255,4,11,3,4,12,15,34,83,75,30,0,0,0,0,0,0,1,0,2,3,4,5,6,7,2,4,1,5,2,0,0,0,2,4,3,1,2,0,0,0,0,8,56,1,7,9,57,15,63,16,48,2,58,6,14,24,40,17,49,10,3,5,62,23,55,25,41,18,42,50,11,51,59,13,21,61,22,30,54,31,47,26,19,27,43,29,45,53,46,0,0,0,0,0,0,0,3,9,5,0,4,6,10,16,8,0,0,0,0,0,0,0,0,8,56,1,7,9,57,15,63,16,2,6,48,17,49,10,58,14,23,55,50,22,62,18,54,0,0,0,0,0,0,0,2,9,1,4,0,4,3,8,3,2,0,0,0,0,0,0,0,64,192,16,48,4,12,1,3,208,112,52,28,13,19,7,80,240,68,196,20,116,76,204,220,60,65,193,17,49,5,29,67,195,51,55,15,84,244,252,209,113,21,77,205,221,211,115,71,199,119,63,212,92,124,81,241,69,197,85,53,61,83,243,23,79,207,31,255,117,245,93,125,215,247,95,223,213,253,87,127,0,0,0,0,0,0,0,1,12,1,0,0,2,6,0,7,21,15,17,8,4,0,0,0,1,63,2,62,3,4,59,60,61,5,6,7,8,56,57,58,9,10,11,12,13,14,26,27,36,37,38,50,51,52,53,54,55,15,16,17,18,19,20,21,25,28,29,30,31,33,34,35,39,43,44,45,46,47,48,49,22,23,24,40,41,42,0,3,9,3,2,5,7,17,23,6,0,0,0,0,0,0,0,0,1,16,17,33,18,32,49,2,34,19,48,65,50,3,35,20,36,64,81,97,209,225,66,82,210,51,67,211,4,52,5,21,37,22,29,45,30,46,80,96,208,224,240,113,129,241,98,114,226,242,83,99,227,243,68,84,212,228,244,53,69,85,213,229,245,6,38,54,214,7,23,39,55,215,24,40,28,13,61,77,93,109,141,14,62,78,94,15,31,47,63,95,112,128,144,192,145,161,177,193,130,146,162,194,115,131,147,163,195,100,116,132,148,164,196,101,117,133,70,86,102,198,230,246,71,87,231,247,8,56,72,88,104,216,232,248,9,25,41,57,89,217,233,249,26,42,58,218,234,250,27,43,219,235,251,12,44,60,220,236,125,157,173,189,205,110,126,142,158,174,190,206,79,111,127,143,175,160,178,179,180,149,165,181,197,118,134,150,166,182,103,119,135,151,199,120,136,152,200,73,105,121,137,153,201,10,74,90,106,122,202,11,59,75,91,107,203,76,92,108,124,140,156,172,188,204,252,221,237,253,222,238,254,159,191,207,223,239,255,176,167,183,168,184,169,185,138,154,170,186,123,139,155,171,187,2,12,1,1,2,2,5,7,21,54,85,62,16,0,0,0,0,16,240,1,17,241,15,31,255,32,224,33,225,2,18,242,14,30,254,47,239,48,208,49,209,34,226,3,19,243,13,29,253,46,238,63,223,64,96,112,144,160,192,65,193,50,66,194,210,35,51,211,227,4,20,36,228,244,6,22,246,7,9,10,26,250,12,28,44,236,252,45,61,221,237,62,78,206,222,79,207,80,176,81,97,113,145,161,177,82,98,114,146,162,178,67,83,99,115,147,163,195,52,68,100,164,196,212,5,21,37,53,213,229,245,38,54,70,198,214,230,23,39,55,199,215,231,247,25,41,57,201,217,233,249,42,58,74,90,202,218,234,11,27,43,59,203,219,235,251,60,76,108,124,156,172,188,204,220,77,93,109,125,157,173,189,205,94,110,126,158,174,190,95,111,127,159,175,191,179,84,116,148,180,69,85,101,117,149,165,181,197,86,102,118,150,166,182,71,87,103,167,183,73,89,105,169,185,106,122,154,170,186,75,91,107,123,155,171,187,92,119,151,121,153,0,0,0,0,0,0,0,5,11,9,12,16,44,98,42,4,0,0,0,0,0,0,0,0,16,240,1,15,241,31,255,32,224,17,2,14,48,80,176,208,33,225,18,242,3,5,11,13,30,254,47,239,64,192,49,81,177,193,209,34,82,226,19,243,4,21,245,27,235,251,12,29,253,46,94,238,63,95,191,223,65,50,66,178,210,35,83,179,227,20,36,228,244,37,53,213,229,43,59,219,28,44,188,236,252,45,189,237,62,78,190,222,79,207,194,51,67,195,211,52,68,84,180,212,69,85,197,75,203,60,76,92,204,220,61,77,93,205,221,206,196,181,91,187,0,0,0,0,0,0,0,2,11,1,0,4,3,5,16,28,34,26,4,0,0,0,0,0,8,56,1,7,57,15,9,63,16,48,49,2,58,6,14,62,23,24,40,17,41,10,50,3,11,59,5,13,61,22,31,55,25,18,26,42,19,51,21,53,30,46,54,47,27,43,29,45,0,0,0,0,0,0,0,1,10,1,0,0,4,2,2,9,15,12,4,0,0,0,0,0,64,16,80,4,68,20,84,1,65,17,81,5,69,21,85,144,148,88,145,149,25,89,6,70,22,86,128,96,132,36,100,164,8,72,24,104,129,33,97,161,133,37,101,165,9,73,153,105,169,2,66,18,82,150,38,102,26,90,32,160,136,152,40,168,137,41,130,146,34,98,134,166,10,74,154,106,170,162,138,42,0,0,0,0,0,0,0,5,10,16,11,32,19,1,2,0,64,192,16,48,4,12,1,3,208,80,112,240,196,52,76,204,28,65,193,49,5,13,67,195,19,7,15,68,20,116,220,60,17,29,51,55,84,212,244,92,124,252,209,113,241,21,53,77,205,221,61,211,115,71,199,23,119,63,81,69,197,85,83,243,79,207,31,255,213,117,245,93,125,253,87,215,247,95,223,127,0,0,0,0,0,0,0,1,11,1,0,0,0,8,1,18,9,22,10,12,0,0,0,0,1,63,2,62,3,61,4,5,6,58,59,60,7,8,9,10,26,27,28,36,37,38,54,55,56,57,11,12,13,14,15,16,25,29,30,31,33,34,35,39,47,48,49,50,51,52,53,17,18,19,20,21,22,23,41,42,43,44,45,46,24,40,0,2,10,1,2,2,2,6,14,21,13,2,0,0,0,0,0,1,0,2,3,4,5,6,7,8,9,13,14,10,11,12,15,2,6,1,3,2,6,4,0,0,16,240,1,17,241,15,31,255,32,224,225,2,242,14,30,47,48,208,33,18,34,226,3,13,46,238,254,239,64,192,49,193,209,50,210,19,35,227,243,4,244,12,28,29,45,237,253,62,222,63,223,80,96,112,144,160,176,65,81,97,113,145,161,177,66,98,146,162,194,51,195,211,20,36,52,212,228,5,21,245,6,22,38,230,246,7,23,231,247,9,25,41,249,10,26,42,234,250,11,27,251,44,60,220,236,252,61,77,205,221,78,110,126,174,206,79,95,111,127,159,175,191,207,82,114,178,67,83,99,115,147,163,179,68,100,116,148,164,180,196,37,53,165,197,213,229,54,70,182,198,214,39,55,71,183,199,215,57,73,89,201,217,233,58,74,90,202,218,43,59,75,107,123,219,235,76,92,108,124,156,172,204,93,109,125,157,173,189,94,158,190,84,69,85,101,117,149,181,86,102,118,150,166,87,103,151,167,105,121,169,185,106,122,154,170,186,91,155,171,187,203,188,119,153,0,0,0,0,0,0,0,3,12,1,3,5,8,12,23,72,68,31,2,0,0,0,0,1,2,0,3,4,5,0,0,2,3,2,4,0,0,0,0,0,8,56,1,9,57,7,15,63,16,48,17,49,2,10,58,5,6,14,62,23,55,24,40,25,41,42,50,3,11,51,59,13,21,61,22,30,54,31,47,18,26,19,43,29,53,46,27,45,0,0,0,0,0,0,0,3,9,1,8,0,13,18,7,2,0,0,0,0,0,0,0,0,64,16,4,1,80,68,20,84,65,17,81,5,69,21,85,144,128,32,96,132,148,36,100,8,72,24,88,129,145,33,133,149,101,9,73,25,89,2,66,18,82,6,70,22,86,136,97,37,41,105,90,160,164,152,40,104,161,165,137,153,169,130,146,34,98,150,38,102,10,74,26,168,134,166,138,154,42,106,162,170,0,0,0,0,0,0,0,2,12,1,0,4,11,0,1,29,6,20,7,2,0,0,0,0,3,64,192,16,48,4,12,1,80,208,112,240,196,20,52,76,28,60,65,193,49,5,13,195,19,7,15,68,204,17,67,51,84,116,220,252,113,21,77,205,29,211,199,55,63,212,244,92,124,81,209,241,69,197,53,221,61,83,115,243,71,23,119,79,207,31,85,245,125,215,95,255,213,117,93,253,87,247,223,127,0,0,0,0,0,0,0,1,12,1,0,0,1,7,0,19,5,13,21,6,8,0,0,64,161,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,29,37,0,48,213,38,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,32,226,34,0,216,143,38,0,32,0,0,0,5,0,0,0,240,84,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,208,35,0,88,32,38,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,31,34,0,168,240,37,0,44,0,0,0,5,0,0,0,24,195,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,161,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,3,0,0,0,0,0,0,0,0,0,0,198,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,77,36,0,112,0,0,0,80,165,16,0,100,66,52], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1081032);
/* memory initializer */ allocate([7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,232,208,35,0,88,226,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,224,31,34,0,56,131,33,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,160,7,33,0,72,162,32,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,64,71,32,0,152,46,40,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,83,36,0,112,0,0,0,8,167,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,128,63,0,192,228,191,0,64,93,63,0,76,253,191,0,168,122,63,0,0,0,0,2,2,3,2,2,2,3,2,2,2,3,2,0,1,1,1,0,1,1,1,2,3,3,3,0,1,1,1,0,1,2,3,16,17,18,19,4,5,6,7,20,21,22,23,8,9,10,11,24,25,26,27,12,13,14,15,28,29,30,31,32,33,34,35,48,49,50,51,36,37,38,39,52,53,54,55,40,41,42,43,56,57,58,59,44,45,46,47,60,61,62,63,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,0,1,2,3,0,1,2,3,0,1,2,3,0,1,2,3,0,0,1,1,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,68,38,0,112,0,0,0,128,128,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,80,32,48,96,112,128,144,192,208,160,176,224,240,240,67,50,76,3,70,166,69,120,69,103,114,119,77,179,69,177,124,226,76,197,124,149,59,54,71,68,71,71,76,64,76,191,66,23,54,82,115,139,110,210,112,87,76,81,163,79,71,218,69,133,76,108,124,7,77,164,74,161,70,35,107,37,114,84,90,99,26,6,62,97,63,77,102,251,86,0,0,149,125,29,89,185,139,244,61,52,151,239,123,219,91,94,29,164,90,37,54,176,158,209,90,183,91,252,92,110,103,147,133,69,153,97,116,157,116,117,56,83,29,158,54,33,96,236,62,222,88,245,58,252,122,151,159,97,65,13,137,234,49,138,10,94,50,10,67,132,132,150,159,47,148,48,73,19,134,150,88,74,151,24,146,208,121,50,122,96,102,41,106,157,136,76,116,197,123,130,103,44,122,79,82,70,144,230,52,196,115,185,93,198,116,199,159,179,87,47,73,76,84,49,65,142,54,24,88,114,122,101,123,143,139,174,70,136,110,129,65,153,93,174,123,188,36,200,159,193,36,201,36,204,36,201,159,4,133,187,53,180,64,202,159,225,68,255,173,193,98,110,112,203,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,49,193,49,194,49,195,49,196,49,12,1,197,49,209,0,205,0,198,49,199,49,203,0,232,31,200,49,202,0,201,49,202,49,203,49,204,49,14,1,205,49,206,49,0,1,193,0,205,1,192,0,18,1,201,0,26,1,200,0,76,1,211,0,209,1,210,0,0,220,190,30,4,220,192,30,202,0,1,1,225,0,206,1,224,0,81,2,19,1,233,0,27,1,232,0,43,1,237,0,208,1,236,0,77,1,243,0,210,1,242,0,107,1,250,0,212,1,249,0,214,1,216,1,218,1,220,1,252,0,8,220,191,30,12,220,193,30,234,0,97,2,218,35,219,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,163,69,17,0,0,10,101,0,0,0,0,61,78,221,110,78,157,223,145,0,0,0,0,53,119,145,100,26,79,40,79,168,79,86,81,116,81,156,81,228,81,161,82,168,82,59,83,78,83,209,83,216,83,226,86,240,88,4,89,7,89,50,89,52,89,102,91,158,91,159,91,154,92,134,94,59,96,137,101,254,103,4,104,101,104,78,109,188,112,53,117,164,126,172,126,186,126,199,126,207,126,223,126,6,127,55,127,122,130,207,130,111,131,198,137,190,139,226,139,102,143,103,143,110,143,17,116,252,124,205,125,70,105,201,122,39,82,0,0,0,0,0,0,0,0,140,145,184,120,94,145,188,128,0,0,11,141,246,128,231,9,0,0,0,0,159,128,199,158,205,76,201,157,12,158,62,76,246,157,14,112,10,158,51,161,193,53,0,0,154,110,62,130,25,117,0,0,17,73,108,154,143,154,153,159,135,121,108,132,202,29,208,5,230,42,36,78,129,78,128,78,135,78,191,78,235,78,55,79,76,52,189,79,72,62,3,80,136,80,125,52,147,52,165,52,134,81,5,89,219,81,252,81,5,82,137,78,121,82,144,82,39,83,199,53,169,83,81,53,176,83,83,53,194,83,35,84,109,53,114,53,129,54,147,84,163,84,180,84,185,84,208,84,239,84,24,85,35,85,40,85,152,53,63,85,165,53,191,53,215,85,197,53,132,125,37,85,0,0,66,12,21,13,43,81,144,85,198,44,236,57,65,3,70,142,184,77,229,148,83,64,190,128,122,119,56,44,52,58,213,71,93,129,242,105,234,77,221,100,124,13,180,15,213,12,244,16,141,100,126,142,150,14,11,12,100,15,169,44,86,130,211,68,0,0,70,13,77,154,233,128,244,71,167,78,194,44,178,154,103,58,244,149,237,63,6,53,199,82,212,151,200,120,68,45,110,157,21,152,0,0,217,67,165,96,180,100,227,84,76,45,202,43,119,16,251,57,111,16,218,102,22,103,160,121,234,100,82,80,67,12,104,142,161,33,76,139,49,7,0,0,11,72,169,1,250,63,115,88,141,45,0,0,200,69,252,4,151,96,76,15,150,13,121,85,187,64,186,67,0,0,180,74,102,42,157,16,170,129,245,152,156,13,121,99,254,57,117,39,192,141,161,86,124,100,67,62,0,0,1,166,9,14,207,42,201,44,0,0,200,16,194,57,146,57,6,58,155,130,120,53,73,94,199,32,82,86,49,15,178,44,32,151,188,52,61,108,59,78,0,0,0,0,116,117,139,46,8,34,91,166,205,140,122,14,52,12,28,104,147,127,207,16,3,40,57,41,251,53,227,81,140,14,141,15,170,14,147,63,48,15,71,13,79,17,76,14,0,0,171,14,169,11,72,13,192,16,61,17,249,63,150,38,50,100,173,15,244,51,57,118,206,43,126,13,127,13,81,44,85,44,24,58,152,14,199,16,46,15,50,166,80,107,210,140,153,141,202,140,170,149,204,84,196,130,185,85,0,0,195,158,38,156,182,154,94,119,238,45,64,113,109,129,236,128,28,92,114,101,52,129,151,55,95,83,189,128,182,145,250,14,15,14,119,14,251,14,221,53,235,77,9,54,214,12,175,86,181,39,201,16,16,14,120,14,120,16,72,17,7,130,85,20,121,14,80,78,164,45,84,90,29,16,30,16,245,16,246,16,156,87,17,14,148,118,205,130,181,15,123,14,126,81,3,55,182,15,128,17,216,82,189,162,218,73,58,24,119,65,124,130,153,88,104,82,26,54,61,87,178,123,104,91,0,72,44,75,39,159,231,73,31,156,141,155,116,91,61,49,251,85,242,53,137,86,40,78,2,89,193,27,120,248,81,151,134,0,91,78,187,78,62,53,35,92,81,95,196,95,250,56,76,98,53,101,122,107,53,108,58,108,108,112,43,114,44,78,173,114,233,72,82,127,59,121,249,124,83,127,106,98,193,52,0,0,75,99,2,128,128,128,18,102,81,105,93,83,100,136,193,137,178,120,160,139,29,141,133,148,120,149,127,149,232,149,15,142,230,151,117,152,206,152,222,152,99,153,16,152,124,156,31,158,196,158,111,107,7,249,55,78,135,0,29,150,55,98,162,148,0,0,59,80,254,109,115,156,166,159,201,61,143,136,78,65,119,112,245,92,32,75,205,81,89,53,48,93,34,97,50,138,167,143,246,145,145,113,25,103,186,115,129,50,7,161,139,60,128,25,16,75,228,120,2,116,174,81,15,135,9,64,99,106,186,162,35,66,15,134,111,10,42,122,71,153,234,138,85,151,77,112,36,83,126,32,244,147,217,118,227,137,167,159,221,119,163,78,240,79,188,80,47,78,23,79,168,159,52,84,139,125,146,88,208,88,182,29,146,94,153,94,194,95,18,39,139,101,249,51,25,105,67,106,99,60,255,108,0,0,0,114,5,69,140,115,219,62,19,74,21,91,185,116,131,139,164,92,149,86,147,122,236,123,195,124,108,126,248,130,151,133,169,159,144,136,170,159,185,142,171,159,207,143,95,133,224,153,33,146,172,159,185,141,63,20,113,64,162,66,26,90,0,0,0,0,0,0,104,152,107,103,118,66,61,87,0,0,214,133,123,73,191,130,13,113,129,76,116,109,123,93,21,107,190,111,173,159,174,159,150,91,175,159,231,102,91,126,87,110,202,121,136,61,195,68,86,50,150,39,154,67,54,69,0,0,213,92,26,59,249,138,120,92,18,61,81,53,120,93,178,159,87,113,88,69,236,64,35,30,119,76,120,57,74,52,164,1,65,108,204,138,180,79,57,2,191,89,108,129,86,152,250,152,59,95,159,11,0,0,193,33,109,137,2,65,187,70,121,144,7,63,179,159,181,161,248,64,214,55,247,70,70,108,124,65,178,134,255,115,109,69,212,56,154,84,97,69,27,69,137,77,123,76,118,77,234,69,200,63,15,75,97,54,222,68,189,68,237,65,62,93,72,93,86,93,252,61,15,56,164,93,185,93,32,56,56,56,66,94,189,94,37,95,131,95,8,57,20,57,63,57,77,57,215,96,61,97,229,92,137,57,183,97,185,97,207,97,184,57,44,98,144,98,229,98,24,99,248,57,177,86,3,58,226,99,251,99,7,100,90,100,75,58,192,100,21,93,33,86,159,159,151,58,134,101,189,58,255,101,83,102,242,58,146,102,34,59,22,103,66,59,164,103,0,104,88,59,74,104,132,104,114,59,113,59,123,59,9,105,67,105,92,114,100,105,159,105,133,105,188,59,214,105,221,59,101,106,116,106,113,106,130,106,236,59,153,106,242,59,171,106,181,106,212,106,246,106,129,107,193,107,234,107,117,108,170,108,203,60,2,109,6,109,38,109,129,109,239,60,164,109,177,109,21,110,24,110,41,110,134,110,192,137,187,110,226,110,218,110,127,159,232,110,233,110,36,111,52,111,70,61,65,63,129,111,190,111,106,61,117,61,183,113,153,92,138,61,44,112,145,61,80,112,84,112,111,112,127,112,137,112,37,3,193,67,241,53,216,14,215,62,190,87,211,110,62,113,224,87,78,54,162,105,233,139,116,91,73,122,225,88,217,148,101,122,125,122,172,89,187,122,176,122,194,122,195,122,209,113,141,100,202,65,218,122,221,122,234,122,239,65,178,84,1,92,11,123,85,123,41,123,14,83,254,92,162,123,111,123,156,131,180,91,127,108,208,123,33,132,146,123,0,0,32,93,173,61,101,92,146,132,250,123,0,0,53,124,193,92,68,124,131,124,130,72,166,124,125,102,120,69,201,124,199,124,230,124,116,124,243,124,245,124,0,0,103,126,29,69,68,110,93,125,214,110,141,116,137,125,171,125,53,113,179,125,0,0,87,64,41,96,228,125,19,61,245,125,249,23,229,125,109,131,0,0,33,97,90,97,110,126,146,126,43,67,108,148,39,126,64,127,65,127,71,127,54,121,208,98,225,153,151,127,81,99,163,127,97,22,104,0,92,69,102,55,3,69,58,131,250,127,137,100,0,0,8,128,29,128,0,0,47,128,135,160,195,108,59,128,60,128,97,128,20,39,137,73,38,102,227,61,232,102,37,103,167,128,72,138,7,129,26,129,176,88,246,38,127,108,152,100,184,79,231,100,138,20,24,130,94,24,83,106,101,74,149,74,122,68,41,130,13,11,82,106,126,61,249,79,253,20,226,132,98,131,10,107,167,73,48,53,115,23,248,61,170,130,27,105,148,249,219,65,75,133,208,130,26,131,22,14,180,23,193,54,125,49,90,53,123,130,226,130,24,131,139,62,163,109,5,107,151,107,206,53,191,61,29,131,236,85,133,131,11,69,165,109,172,131,0,0,211,131,126,52,212,110,87,106,90,133,150,52,66,110,239,46,88,132,228,91,113,132,211,61,228,68,167,106,74,132,181,60,88,121,0,0,150,107,119,110,67,110,222,132,0,0,145,131,160,68,147,132,228,132,145,92,64,66,192,92,67,69,52,133,242,90,153,110,39,69,115,133,22,69,191,103,22,134,37,134,59,134,193,133,136,112,2,134,130,21,205,112,178,249,106,69,40,134,72,54,162,24,247,83,154,115,126,134,113,135,248,160,238,135,39,44,177,135,218,135,15,136,97,86,108,134,86,104,15,70,69,136,70,136,224,117,185,61,228,117,94,136,156,136,91,70,180,136,181,136,193,99,197,136,119,119,15,119,135,137,138,137,0,0,0,0,167,137,188,137,37,138,231,137,36,121,189,122,156,138,147,119,254,145,144,138,89,122,233,122,58,123,143,63,19,71,56,123,124,113,12,139,31,139,48,84,101,85,63,139,76,139,77,139,169,138,122,74,144,139,155,139,175,138,223,22,21,70,79,136,155,140,84,125,143,125,212,249,37,55,83,125,214,140,152,125,189,125,18,141,3,141,16,25,219,140,92,112,17,141,201,76,208,62,0,0,169,141,2,128,20,16,138,73,124,59,188,129,12,113,231,122,173,142,182,142,195,142,212,146,25,143,45,143,101,131,18,132,165,143,3,147,159,162,80,10,179,143,42,73,222,137,61,133,187,61,248,94,98,50,249,143,20,160,188,134,1,133,37,35,128,57,215,110,55,144,60,133,190,122,97,144,108,133,11,134,168,144,19,135,196,144,230,134,174,144,0,0,103,145,240,58,169,145,196,145,172,124,51,137,137,30,14,146,159,108,65,146,98,146,185,85,0,0,198,138,155,60,12,139,219,85,49,13,44,147,107,147,225,138,235,139,143,112,195,90,226,138,229,138,101,73,68,146,236,139,57,140,255,139,115,147,91,148,188,142,133,149,166,149,38,148,160,149,246,111,185,66,122,38,216,134,124,18,46,62,223,73,28,108,123,150,150,150,108,65,163,150,213,110,218,97,182,150,245,120,224,138,189,150,204,83,161,73,184,108,116,2,16,100,175,144,229,144,209,74,21,25,10,51,49,151,66,134,54,151,15,74,61,69,133,69,233,74,117,112,65,91,27,151,0,0,213,145,87,151,74,91,235,145,95,151,37,148,208,80,183,48,188,48,137,151,159,151,177,151,190,151,192,151,210,151,224,151,108,84,238,151,28,116,51,148,0,0,245,151,29,148,122,121,209,74,52,152,51,152,75,152,102,152,14,59,117,113,81,61,48,6,92,65,6,87,202,152,183,152,200,152,199,152,255,74,39,109,211,22,176,85,225,152,230,152,236,152,120,147,57,153,41,74,114,75,87,152,5,153,245,153,12,154,59,154,16,154,88,154,37,87,196,54,177,144,213,155,224,154,226,154,5,155,244,154,14,76,20,155,45,155,0,134,52,80,52,155,168,105,195,56,125,48,80,155,64,155,62,157,69,90,99,24,142,155,75,66,2,156,255,155,12,156,104,158,212,157,183,159,146,161,171,161,225,160,35,161,223,161,126,157,131,157,52,161,14,158,136,104,196,157,91,33,147,161,32,162,59,25,51,162,57,157,185,160,180,162,144,158,149,158,158,158,162,158,52,77,170,158,175,158,100,67,193,158,96,59,229,57,29,61,50,79,190,55,43,140,2,159,8,159,150,75,36,148,162,109,23,159,0,0,57,159,159,86,138,86,69,159,184,153,139,144,242,151,127,132,98,159,105,159,220,122,142,159,22,114,190,75,117,73,187,73,119,113,248,73,72,67,81,74,158,115,218,139,250,24,159,121,126,137,54,142,105,147,243,147,68,138,236,146,129,147,203,147,108,137,185,68,23,114,235,62,114,119,67,122,208,112,115,68,248,67,126,113,239,23,163,112,190,24,153,53,199,62,133,24,47,84,248,23,34,55,251,22,57,24,225,54,116,23,209,24,75,95,35,55,192,22,91,87,37,74,254,19,168,18,198,19,182,20,3,133,166,54,0,0,85,132,148,73,101,113,49,62,92,85,251,62,82,112,244,68,238,54,157,153,38,111,249,103,51,55,21,60,231,61,108,88,34,25,16,104,87,64,63,55,225,64,139,64,15,65,33,108,203,84,158,86,177,102,146,86,223,15,168,11,13,14,198,147,19,139,156,147,248,78,43,81,25,56,54,68,188,78,101,4,127,3,75,79,138,79,81,86,104,90,171,1,203,3,153,57,10,3,20,4,53,52,41,79,192,2,179,142,117,2,218,138,12,2,152,78,205,80,13,81,162,79,3,79,14,74,138,62,66,79,46,80,108,80,129,80,204,79,229,79,88,80,252,80,0,0,0,0,0,0,0,0,118,110,149,53,57,62,191,62,114,109,132,24,137,62,168,81,195,81,224,5,221,68,163,4,146,4,145,4,122,141,156,138,14,7,89,82,164,82,115,8,225,82,0,0,122,70,140,113,140,67,32,12,172,73,228,16,209,105,29,14,0,0,222,62,153,116,20,116,86,116,152,115,142,75,188,74,141,64,208,83,132,53,15,114,201,64,180,85,69,3,205,84,198,11,29,87,93,146,244,150,102,147,221,87,141,87,127,87,62,54,203,88,153,90,70,138,250,22,111,23,16,23,44,90,184,89,143,146,126,90,207,90,18,90,70,89,243,25,97,24,149,66,245,54,5,109,67,116,33,90,131,94,129,90,215,139,19,4,224,147,140,116,3,19,5,113,114,73,8,148,251,137,189,147,160,55,30,92,158,92,94,94,72,94,150,25,124,25,238,58,205,94,79,91,3,25,4,25,1,55,160,24,221,54,254,22,211,54,42,129,71,138,186,29,114,52,168,137,12,95,14,95,39,25,171,23,107,90,59,23,68,91,20,134,253,117,96,136,126,96,96,40,43,38,219,95,184,62,175,37,190,37,136,144,115,111,192,97,62,0,70,0,27,38,153,97,152,97,117,96,155,44,7,45,212,70,77,145,113,100,101,70,106,43,41,58,34,43,80,52,234,152,120,46,55,99,91,164,182,100,49,99,209,99,227,73,103,45,164,98,161,44,59,100,107,101,114,105,244,59,142,48,173,50,137,73,171,50,13,85,224,50,217,24,63,148,206,102,137,50,179,49,224,58,144,65,132,85,34,139,143,85,252,22,91,85,37,84,238,120,3,49,42,24,52,50,100,52,15,50,130,49,201,66,142,102,36,109,107,102,147,75,48,102,112,120,235,29,99,102,210,50,225,50,30,102,114,88,209,56,58,56,188,55,153,59,162,55,254,51,208,116,150,59,143,103,42,70,182,104,30,104,196,59,190,106,99,56,213,55,135,68,51,106,82,106,201,106,5,107,18,25,17,101,152,104,76,106,215,59,122,106,87,107,192,63,154,60,160,147,242,146,234,139,203,138,137,146,30,128,220,137,103,148,165,109,11,111,236,73,0,0,127,63,143,61,4,110,60,64,61,90,10,110,71,88,36,109,66,120,59,113,26,67,118,66,241,112,80,114,135,114,148,114,143,71,37,71,121,81,164,74,235,5,122,116,248,62,95,54,74,74,23,73,225,95,6,63,177,62,223,74,35,140,53,63,167,96,243,62,204,116,60,116,135,147,55,116,159,68,234,109,81,69,131,117,99,63,217,76,6,77,88,63,85,117,115,118,198,165,25,59,104,116,204,138,171,73,142,73,251,58,205,61,78,74,255,62,197,73,243,72,250,145,50,87,66,147,227,138,100,24,223,80,33,82,231,81,120,119,50,50,14,119,15,119,123,119,151,70,129,55,94,58,240,72,56,116,155,116,191,62,186,74,199,74,200,64,150,74,174,97,7,147,129,85,30,120,141,120,136,120,210,120,208,115,89,121,65,119,227,86,14,65,0,0,150,132,165,121,45,106,250,62,58,122,244,121,110,65,230,22,50,65,53,146,241,121,76,13,140,73,153,2,186,61,110,23,151,53,107,85,112,53,170,54,212,1,13,12,226,122,89,90,245,38,175,90,156,90,13,90,91,2,240,120,42,90,198,91,254,122,249,65,93,124,109,124,17,66,179,91,188,94,166,94,205,124,249,73,176,23,142,124,124,124,174,124,178,106,220,125,7,126,211,125,78,127,97,98,92,97,72,123,151,125,130,94,106,66,117,107,22,9,214,103,78,0,207,53,196,87,18,100,248,99,98,73,221,127,39,123,44,8,233,90,67,93,12,123,14,94,230,153,69,134,99,154,28,106,63,52,226,57,247,73,173,101,31,154,160,101,128,132,39,113,209,108,234,68,55,129,2,68,198,128,9,129,66,129,180,103,195,152,66,106,98,130,101,130,81,106,83,132,167,109,16,134,27,114,134,90,127,65,64,24,43,91,161,24,228,90,216,24,160,134,188,249,143,61,45,136,34,116,2,90,110,136,69,79,135,136,191,136,230,136,101,137,77,137,131,86,84,137,133,119,132,119,245,139,217,139,156,139,249,137,173,62,163,132,245,70,207,70,242,55,61,138,28,138,72,148,77,95,43,146,132,66,212,101,41,113,196,112,69,24,109,157,159,140,233,140,220,125,154,89,195,119,240,89,110,67,212,54,42,142,167,142,9,76,48,143,74,143,244,66,88,108,187,111,33,35,155,72,121,111,139,110,218,23,233,155,181,54,47,73,187,144,0,0,113,85,6,73,187,145,4,148,75,138,98,64,252,138,39,148,29,140,59,140,229,132,43,138,153,149,167,149,151,149,150,149,52,141,69,116,194,62,255,72,66,74,234,67,231,62,37,50,143,150,231,142,102,142,101,142,204,62,237,73,120,74,238,63,18,116,107,116,252,62,65,151,176,144,71,104,29,74,147,144,223,87,0,0,104,147,137,137,38,140,47,139,190,99,186,146,17,91,105,139,60,73,249,115,27,66,155,151,113,151,56,153,38,15,193,93,197,139,178,74,31,152,218,148,246,146,215,149,229,145,192,68,80,139,103,74,100,139,220,152,69,138,0,63,42,146,37,73,20,132,59,153,77,153,6,123,253,61,155,153,111,75,170,153,92,154,101,139,200,88,143,106,33,154,254,90,47,154,241,152,144,75,72,153,188,153,189,75,151,75,125,147,114,88,2,19,34,88,184,73,232,20,68,120,31,39,184,61,197,104,125,61,88,148,39,57,80,97,129,39,107,41,7,97,79,156,83,156,123,156,53,156,16,156,127,155,207,155,45,158,159,155,245,161,254,160,33,157,174,76,4,65,24,158,176,76,12,157,180,161,237,160,243,160,47,153,165,157,189,132,18,110,223,111,130,107,252,133,51,69,164,109,132,110,240,109,32,132,238,133,0,110,215,55,100,96,226,121,156,53,64,54,45,73,222,73,98,61,219,147,190,146,72,147,191,2,185,120,119,146,77,148,228,79,64,52,100,144,93,85,61,120,84,120,182,120,75,120,87,23,201,49,65,73,154,54,114,79,218,111,217,111,0,0,30,112,20,84,181,65,187,87,243,88,138,87,22,157,215,87,52,113,175,52,172,65,235,113,64,108,151,79,0,0,181,23,73,138,12,97,206,90,11,90,188,66,136,68,44,55,123,75,252,137,187,147,184,147,214,24,29,15,114,132,192,108,19,20,250,66,38,44,193,67,148,89,183,61,65,103,168,125,91,97,164,96,185,73,139,73,250,137,229,146,226,115,233,62,180,116,99,139,159,24,225,62,179,74,216,106,243,115,251,115,214,62,62,74,148,74,217,23,102,74,167,3,36,20,229,73,72,116,22,73,165,112,118,73,132,146,230,115,95,147,254,4,49,147,206,138,22,138,134,147,231,139,213,85,53,73,130,138,107,113,67,73,255,12,164,86,26,6,235,11,184,12,2,85,196,121,250,23,254,125,194,22,80,74,82,24,46,69,1,148,10,55,192,138,173,73,176,89,191,24,131,24,132,116,161,90,226,54,91,61,176,54,95,146,121,90,129,138,98,24,116,147,205,60,180,10,150,74,138,57,244,80,105,61,76,61,156,19,117,113,251,66,24,130,15,110,228,144,235,68,87,109,79,126,103,112,175,108,214,60,237,63,45,62,2,110,12,111,111,61,245,3,81,117,188,54,200,52,128,70,218,62,113,72,196,89,110,146,62,73,65,143,28,140,192,107,18,88,200,87,214,54,82,20,254,112,98,67,113,74,227,47,176,18,189,35,185,104,103,105,152,19,229,52,244,123,223,54,131,138,214,55,250,51,159,76,26,106,173,54,183,108,62,132,223,68,206,68,38,109,81,109,130,108,222,111,23,111,9,113,61,131,58,23,237,131,128,108,83,112,219,23,137,89,130,90,179,23,97,90,113,90,5,25,252,65,45,55,239,89,60,23,199,54,142,113,144,147,154,102,165,66,110,90,43,90,147,66,43,106,249,62,54,119,91,68,202,66,29,113,89,66,225,137,176,79,40,109,194,92,206,68,77,126,189,67,12,106,86,66,4,19,166,112,51,113,233,67,165,61,223,108,37,248,79,74,101,126,235,89,47,93,243,61,92,95,93,74,223,23,164,125,38,132,133,84,250,58,0,51,20,2,126,87,213,8,25,6,229,63,158,31,182,162,3,112,91,145,112,93,143,115,211,124,89,138,32,148,200,79,231,127,205,114,16,115,244,122,56,115,57,115,246,86,65,115,72,115,169,62,24,123,108,144,245,113,242,72,225,115,246,129,202,62,12,119,209,62,162,108,253,86,25,116,30,116,31,116,226,62,240,62,244,62,250,62,211,116,14,63,83,63,66,117,109,117,114,117,141,117,124,63,200,117,220,117,192,63,77,118,215,63,116,118,220,63,122,118,92,79,136,113,35,86,128,137,105,88,29,64,67,119,57,64,97,103,69,64,219,53,152,119,106,64,111,64,94,92,190,119,203,119,242,88,24,120,185,112,28,120,168,64,57,120,71,120,81,120,102,120,72,132,53,85,51,121,3,104,50,121,3,65,9,65,145,121,153,121,187,143,6,122,188,143,103,65,145,122,178,65,188,122,121,130,196,65,207,122,219,122,207,65,33,78,98,123,108,123,123,123,18,124,27,124,96,66,122,66,123,124,156,124,140,66,184,124,148,66,237,124,147,143,192,112,207,12,207,125,212,125,208,125,253,125,174,127,180,127,159,114,151,67,32,128,37,128,57,123,46,128,49,128,84,128,204,61,180,87,160,112,183,128,233,128,237,67,12,129,42,115,14,129,18,129,96,117,20,129,1,68,57,59,86,129,89,129,90,129,19,68,58,88,124,129,132,129,37,68,147,129,45,68,165,129,239,87,193,129,228,129,84,130,143,68,166,130,118,130,202,130,216,130,255,130,176,68,87,131,105,150,138,105,5,132,245,112,100,132,227,96,136,132,4,69,190,132,225,132,248,132,16,133,56,133,82,133,59,69,111,133,112,133,224,133,119,69,114,134,146,134,178,134,239,134,69,150,139,135,6,70,23,70,174,136,255,136,36,137,71,137,145,137,103,121,41,138,56,138,148,138,180,138,81,140,212,140,242,140,28,141,152,71,95,88,195,141,237,71,238,78,58,142,216,85,84,87,113,142,245,85,176,142,55,72,206,142,226,142,228,142,237,142,242,142,183,143,193,143,202,143,204,143,51,144,196,153,173,72,224,152,19,146,30,73,40,146,88,146,107,146,177,146,174,146,191,146,227,146,235,146,243,146,244,146,253,146,67,147,132,147,173,147,69,73,81,73,191,158,23,148,1,83,29,148,45,148,62,148,106,73,84,148,121,148,45,149,162,149,167,73,244,149,51,150,229,73,160,103,36,74,64,151,53,74,178,151,194,151,84,86,228,74,232,96,185,152,25,75,241,152,68,88,14,153,25,153,180,81,28,153,55,153,66,153,93,153,98,153,112,75,197,153,157,75,60,154,15,155,131,122,105,155,129,155,221,155,241,155,244,155,109,76,32,156,111,55,194,27,73,157,58,156,254,158,80,86,147,157,189,157,192,157,252,157,246,148,182,143,123,158,172,158,177,158,189,158,198,158,220,148,226,158,241,158,248,158,200,122,68,159,148,0,183,2,160,3,26,105,195,148,172,89,215,4,64,88,193,148,185,55,213,5,21,6,118,6,186,22,87,87,115,113,194,10,205,10,191,11,106,84,59,248,203,11,158,84,251,11,59,12,83,12,101,12,124,12,231,96,141,12,122,86,181,12,221,12,237,12,111,13,178,13,200,13,85,105,47,156,165,135,4,14,14,14,215,14,144,15,45,15,115,14,32,92,188,15,11,94,92,16,79,16,118,16,30,103,123,16,136,16,150,16,71,54,191,16,211,16,47,17,59,17,100,83,173,132,227,18,117,19,54,19,129,139,119,21,25,22,195,23,199,23,120,78,187,112,45,24,106,25,45,26,69,26,42,28,112,28,172,28,200,30,195,98,213,30,21,31,152,113,85,104,69,32,233,105,200,54,124,34,215,35,250,35,42,39,113,40,79,41,253,130,103,41,147,41,213,42,165,137,232,42,160,143,14,43,184,151,63,43,71,152,189,154,76,44,0,0,136,44,183,44,232,91,8,45,18,45,183,45,149,45,66,46,116,47,204,47,51,48,102,48,31,51,222,51,177,95,72,102,191,102,121,122,103,53,243,53,0,0,186,73,0,0,26,54,22,55,0,0,70,3,181,88,14,103,24,105,167,58,87,118,226,95,17,62,185,62,254,117,154,32,208,72,184,74,25,65,154,138,238,66,13,67,59,64,52,67,150,67,69,74,202,5,210,81,17,6,159,89,168,30,190,59,255,60,4,68,214,68,136,87,116,70,155,57,47,71,232,133,201,153,98,55,195,33,94,139,78,139,0,0,18,72,251,72,21,74,9,114,192,74,120,12,101,89,165,78,134,79,121,7,218,142,44,80,143,82,63,87,113,113,153,82,25,84,74,63,167,74,188,85,70,84,110,84,82,107,0,0,115,52,63,85,50,118,94,85,24,71,98,85,102,85,199,87,63,73,93,88,102,80,251,52,204,51,0,0,3,89,124,71,72,137,174,90,137,91,6,92,144,29,161,87,81,113,0,0,2,97,18,124,86,144,178,97,154,79,98,139,2,100,74,100,91,93,247,107,0,0,132,100,28,25,234,138,246,73,136,100,239,63,18,101,192,75,191,101,181,102,27,39,101,148,225,87,149,97,39,90,205,248,0,0,185,86,33,69,252,102,106,78,52,73,86,150,143,109,189,108,24,54,119,137,153,103,110,104,17,100,94,104,0,0,199,104,66,123,192,144,17,10,38,105,0,0,57,105,69,122,0,0,250,105,38,154,45,106,95,54,105,100,33,0,131,121,52,106,91,107,44,93,25,53,0,0,157,107,208,70,164,108,59,117,101,136,174,109,182,88,28,55,141,37,75,112,205,113,84,60,128,114,133,114,129,146,122,33,139,114,48,147,230,114,208,73,57,108,159,148,80,116,248,14,39,136,245,136,38,41,115,132,177,23,184,110,42,74,32,24,164,57,185,54,0,0,0,0,63,69,182,102,173,156,164,152,67,137,204,119,88,120,214,86,223,64,10,22,161,57,47,55,232,128,197,19,173,113,102,131,221,121,168,145,0,0,183,76,175,112,171,137,253,121,10,122,11,123,102,125,122,65,67,123,126,121,9,128,181,111,223,162,3,106,24,131,162,83,7,110,191,147,54,104,93,151,111,129,35,128,181,105,237,19,47,50,72,128,133,93,48,140,131,128,21,87,35,152,73,137,171,93,136,73,190,101,213,105,210,83,165,74,129,63,17,60,54,103,144,128,244,128,46,129,161,31,79,129,137,129,175,129,26,130,6,131,47,131,138,131,202,53,104,132,170,134,250,72,230,99,86,137,8,120,85,146,184,137,242,67,231,137,223,67,232,137,70,139,212,139,248,89,9,140,0,0,197,143,236,144,0,0,16,145,60,145,247,61,94,145,202,74,208,143,143,114,139,86,231,148,233,149,176,149,184,149,50,151,209,152,73,153,106,153,195,153,40,154,14,155,90,157,155,157,159,126,248,158,35,159,164,76,71,149,147,162,162,113,255,162,145,77,18,144,203,165,156,77,156,12,190,143,193,85,186,143,176,36,185,143,147,74,9,69,127,126,86,111,177,106,234,78,228,52,44,139,157,120,58,55,128,142,245,23,36,128,108,139,153,139,62,122,175,102,235,61,85,118,183,60,53,86,86,89,154,78,129,94,88,98,191,86,109,14,14,142,109,91,136,62,158,76,222,99,0,0,246,23,123,24,48,101,45,86,74,92,26,84,17,83,198,61,152,157,125,76,34,86,30,86,73,127,216,94,117,89,64,61,112,135,28,78,234,15,73,13,186,54,23,129,94,157,24,141,59,118,69,156,78,118,185,119,69,147,50,84,72,129,247,130,37,86,50,129,24,132,189,128,234,85,98,121,67,86,22,84,157,14,206,53,5,86,241,85,241,102,226,130,45,54,52,117,240,85,186,85,151,84,114,85,65,12,150,12,208,94,72,81,118,14,98,44,162,14,171,158,90,125,222,85,117,16,157,98,109,151,148,84,205,140,246,113,118,145,252,99,185,99,254,99,105,85,67,43,114,156,179,46,154,81,223,52,167,13,167,81,77,84,30,85,19,85,102,118,45,142,138,104,177,117,182,128,4,136,134,135,199,136,182,129,28,132,193,16,236,68,4,115,6,71,144,91,11,131,147,104,123,86,244,38,47,125,163,65,115,125,208,110,182,114,112,145,217,17,8,146,252,60,169,166,172,14,249,14,102,114,162,28,78,71,194,79,249,127,235,15,250,64,93,156,31,101,160,45,243,72,224,71,124,157,236,15,10,14,0,0,163,117,237,15,0,0,72,96,135,17,163,113,142,126,80,157,26,78,4,78,119,53,13,91,178,108,103,83,172,54,220,57,125,83,165,54,24,70,154,88,110,75,45,130,75,84,170,87,149,90,121,9,0,0,82,58,101,36,116,115,172,158,9,77,237,155,254,60,48,159,91,76,169,79,158,149,222,159,92,132,182,61,178,114,179,103,32,55,46,99,37,125,247,62,44,62,42,58,8,144,204,82,116,62,122,54,233,69,142,4,64,118,240,90,182,14,122,120,46,127,167,88,191,64,124,86,139,155,116,93,84,118,52,164,133,158,225,76,0,0,251,55,25,97,218,48,242,67,0,0,93,86,169,18,167,87,99,73,6,158,52,82,174,112,173,53,0,0,124,157,86,124,57,155,222,87,108,23,83,92,211,100,208,148,53,99,100,113,173,134,40,13,34,109,226,74,113,13,0,0,254,81,15,31,142,93,3,151,209,29,129,158,76,144,31,123,2,155,209,92,163,123,104,98,53,99,255,154,207,123,42,155,126,124,0,0,66,124,134,124,21,156,252,123,9,155,0,0,27,156,62,73,90,159,115,85,195,91,253,79,152,158,242,79,96,82,6,62,209,82,103,87,86,80,183,89,18,94,200,151,171,157,92,143,105,84,180,151,64,153,186,151,44,83,48,97,44,105,218,83,10,156,2,157,59,76,65,150,128,105,166,80,70,117,109,23,218,153,115,82,0,0,89,145,129,150,92,145,0,0,81,145,151,142,127,99,35,109,202,106,17,86,142,145,122,117,133,98,252,3,79,115,112,124,33,92,253,60,0,0,25,73,214,118,157,155,42,78,212,12,190,131,66,136,0,0,74,92,192,105,0,0,122,87,31,82,245,93,206,78,49,108,242,1,57,79,156,84,218,84,154,82,130,141,254,53,0,0,243,53,0,0,82,107,124,145,165,159,151,155,46,152,180,152,186,154,168,158,132,158,122,113,20,123,0,0,250,107,24,136,120,127,0,0,32,86,74,166,119,142,83,159,0,0,212,141,79,142,28,158,1,142,130,98,125,131,40,142,117,142,211,122,119,74,62,122,216,120,234,108,103,138,7,118,90,138,38,159,206,108,214,135,195,117,178,162,83,120,64,248,12,141,226,114,113,115,45,139,2,115,241,116,235,140,187,74,47,134,186,95,160,136,183,68,0,0,59,24,5,110,0,0,126,138,27,37,0,0,253,96,103,118,215,154,68,157,110,147,143,155,245,135,0,0,0,0,247,140,44,115,33,151,176,155,214,53,178,114,7,76,81,124,74,153,89,97,89,97,4,76,150,158,125,97,0,0,95,87,111,97,166,98,57,98,0,0,92,58,226,97,170,83,245,51,100,99,2,104,210,53,87,93,194,139,218,143,57,142,0,0,217,80,70,29,6,121,50,83,56,150,59,15,101,64,0,0,254,119,0,0,194,124,26,95,218,124,45,122,102,128,99,128,77,125,5,117,242,116,148,137,26,130,12,103,98,128,134,116,91,128,240,116,3,129,36,119,137,137,204,103,83,117,209,110,169,135,206,135,200,129,140,135,73,138,173,140,67,139,43,119,248,116,218,132,53,54,178,105,166,141,0,0,169,137,0,0,185,109,193,135,17,64,231,116,219,61,118,113,164,96,156,97,209,60,0,0,119,96,0,0,113,127,45,139,0,0,233,96,126,75,32,82,24,60,199,60,215,94,86,118,49,85,68,25,254,18,3,153,220,109,173,112,193,92,173,97,15,138,119,54,238,0,70,104,14,79,98,69,31,91,76,99,80,159,166,158,107,98,71,5,219,146,223,5,197,63,76,133,181,66,239,115,181,81,73,54,66,73,228,137,68,147,219,25,238,130,200,60,60,120,68,103,223,98,51,73,170,137,160,2,179,107,5,19,171,79,237,36,8,80,41,109,132,122,0,54,177,74,19,37,0,0,126,3,164,95,128,3,71,3,219,110,31,4,0,0,1,81,122,52,14,81,108,152,67,55,22,132,164,73,135,4,96,81,180,51,106,81,255,11,252,32,229,2,48,37,142,5,51,50,131,25,130,91,125,135,179,5,153,60,178,81,184,81,52,157,201,81,207,81,209,81,220,60,211,81,166,74,179,81,226,81,66,83,237,81,205,131,62,105,45,55,123,95,11,82,38,82,60,82,181,82,87,82,148,82,185,82,197,82,21,124,66,133,224,82,13,134,19,107,0,0,222,138,73,85,217,110,128,63,84,9,236,63,51,83,0,0,226,11,203,108,38,23,27,104,213,115,74,96,170,62,204,56,232,22,221,113,162,68,109,83,116,83,171,134,126,83,0,0,150,21,19,22,230,119,147,83,155,138,160,83,171,83,174,83,167,115,114,87,89,63,156,115,193,83,197,83,73,108,73,78,254,87,217,83,171,58,143,11,224,83,235,63,163,45,246,83,119,12,19,84,121,112,43,85,87,102,91,109,109,84,83,107,116,13,93,85,143,84,164,84,166,71,13,23,221,14,180,61,77,13,188,137,152,38,71,85,237,76,47,84,23,116,134,85,169,85,0,0,215,24,58,64,82,69,53,68,179,102,180,16,55,86,205,102,138,50,164,102,173,102,77,86,79,86,241,120,241,86,135,151,254,83,0,87,239,86,237,86,102,139,35,54,79,18,70,87,165,65,110,108,139,112,66,87,177,54,126,108,230,87,22,20,3,88,84,20,99,67,38,88,245,75,92,88,170,88,97,53,224,88,220,88,60,18,251,88,255,91,67,87,80,161,120,66,211,147,161,53,31,89,166,104,195,54,89,110,62,22,36,90,83,85,146,22,5,133,201,89,78,13,129,108,42,109,220,23,217,89,251,23,178,23,166,109,113,109,40,24,213,22,249,89,69,110,171,90,99,90,230,54,169,73,0,0,8,55,150,90,101,116,211,90,161,111,84,37,133,61,17,25,50,55,184,22,131,94,208,82,118,91,136,101,124,91,14,122,4,64,93,72,4,2,213,91,96,97,52,26,204,89,165,5,243,91,157,91,16,77,5,92,68,27,19,92,206,115,20,92,165,28,40,107,73,92,221,72,133,92,233,92,239,92,139,93,249,29,55,30,16,93,24,93,70,93,164,30,186,92,215,93,252,130,45,56,1,73,73,32,115,33,135,130,54,56,194,59,46,94,138,106,0,0,122,94,188,68,211,12,166,83,183,78,0,0,168,83,113,23,9,94,244,94,130,132,249,94,251,94,160,56,252,94,62,104,27,148,13,95,193,1,148,248,222,58,174,72,58,19,58,95,136,104,208,35,0,0,113,36,99,95,189,151,110,110,114,95,64,147,54,138,167,95,182,93,95,61,80,82,106,31,248,112,104,38,214,145,158,2,41,138,49,96,133,102,119,24,99,57,199,61,57,54,144,87,180,39,113,121,64,62,158,96,0,0,179,96,130,73,143,73,83,122,164,116,225,80,160,90,100,97,36,132,66,97,166,248,210,110,129,97,244,81,86,6,135,97,170,91,183,63,95,40,211,97,157,139,93,153,208,97,50,57,128,41,193,40,35,96,92,97,30,101,139,99,24,1,197,98,112,23,213,98,13,46,108,99,223,73,23,58,56,100,248,99,142,19,252,23,0,0,138,111,54,46,20,152,140,64,29,87,225,100,229,100,123,148,102,58,58,100,87,58,77,101,22,111,40,74,35,74,133,101,109,101,95,101,126,48,181,101,64,73,55,75,209,101,216,64,41,24,224,101,227,101,223,95,0,52,24,102,247,49,248,49,68,102,164,49,165,49,75,102,117,14,103,102,230,81,115,102,0,0,61,30,49,50,244,133,200,49,19,83,197,119,247,40,164,153,2,103,156,67,33,74,43,59,250,105,194,55,0,0,103,103,98,103,205,65,237,144,215,103,233,68,34,104,80,110,60,146,1,104,230,51,160,109,93,104,111,52,225,105,11,106,223,138,115,105,195,104,205,53,1,105,0,105,50,61,1,58,60,54,128,59,172,103,97,105,74,138,252,66,54,105,152,105,161,59,201,3,99,131,144,80,249,105,89,54,42,33,69,106,3,55,157,106,243,59,177,103,200,106,156,145,13,60,29,107,35,9,222,96,53,107,116,107,205,39,181,110,219,58,181,3,88,25,64,55,33,84,90,59,225,107,252,62,220,107,55,108,139,36,241,72,81,107,90,108,38,130,121,108,188,61,197,68,189,61,164,65,12,73,0,73,201,60,229,54,235,60,50,13,131,155,249,49,145,36,143,127,55,104,37,109,161,109,235,109,150,109,92,109,124,110,4,111,127,73,133,64,114,110,51,133,116,111,199,81,0,0,0,0,46,132,33,139,0,0,47,62,83,116,130,63,204,121,79,110,145,90,75,48,248,111,13,55,157,111,48,62,250,110,151,20,61,64,85,69,240,147,68,111,92,111,78,61,116,111,112,145,59,61,159,111,68,65,211,111,145,64,85,65,57,64,240,63,180,63,63,65,223,81,86,65,87,65,64,65,221,97,75,112,126,112,167,112,129,112,204,112,213,112,214,112,223,112,4,65,232,61,180,113,150,113,119,66,43,113,69,113,136,90,74,113,0,0,156,92,101,67,79,113,98,147,193,66,44,113,90,68,39,74,34,74,186,113,232,139,189,112,14,114,66,148,21,114,17,89,67,148,36,114,65,147,5,86,46,114,64,114,116,73,189,104,85,114,87,114,85,62,68,48,13,104,61,111,130,114,0,0,43,115,35,72,43,136,237,72,4,136,40,115,46,115,207,115,170,115,58,12,46,106,201,115,73,116,226,65,231,22,36,74,35,102,197,54,183,73,141,73,251,73,247,115,21,116,3,105,38,74,57,116,195,5,215,62,0,0,173,40,96,116,178,142,71,116,228,115,118,116,185,131,108,116,48,55,116,116,241,147,44,106,130,116,83,73,140,74,95,65,121,74,143,139,70,91,3,140,158,24,200,116,136,25,14,117,0,0,30,117,217,142,75,26,215,91,172,142,133,147,77,117,74,117,103,117,110,117,130,79,4,63,19,77,142,117,93,116,158,117,180,117,2,118,44,118,81,118,79,118,111,118,118,118,245,99,144,118,239,129,248,55,17,105,14,105,161,118,165,118,183,118,204,118,159,111,98,132,157,80,125,81,28,30,30,119,38,119,64,119,175,100,32,82,88,119,172,50], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1091280);
/* memory initializer */ allocate([175,119,100,137,104,137,193,22,244,119,0,0,118,19,18,74,202,104,175,120,199,120,211,120,165,150,46,121,224,85,215,120,52,121,177,120,12,118,184,143,132,136,43,139,131,96,28,38,134,121,0,137,2,105,128,121,87,88,157,121,57,123,60,121,169,121,42,110,38,113,168,62,198,121,13,145,212,121,32,5,95,68,15,82,130,184,248,0,0,64,32,169,78,4,0,0,0,0,52,11,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,64,0,0,0,0,0,0,0,0,4,88,0,60,0,0,0,0,0,128,92,173,220,243,187,201,67,238,237,164,15,38,193,155,118,242,239,222,251,250,247,15,50,68,175,254,239,253,254,17,96,176,0,0,33,25,129,32,16,136,168,96,33,105,36,0,68,137,196,0,0,3,64,53,0,67,132,49,81,147,104,2,2,0,0,0,0,0,0,0,0,0,0,0,64,0,1,128,172,100,130,64,140,161,144,4,80,96,212,0,210,42,24,157,104,53,151,79,216,248,32,196,130,28,40,130,117,148,2,56,64,160,161,197,16,113,77,196,13,152,185,94,91,1,67,159,153,3,120,32,226,31,8,137,1,201,64,7,3,13,154,144,82,209,79,124,3,2,33,32,192,110,19,131,181,219,245,229,119,144,79,23,154,54,23,12,0,110,186,9,47,96,84,0,30,120,104,34,112,86,158,37,243,142,183,23,11,239,230,119,23,91,27,193,16,152,141,18,24,182,207,1,49,114,26,91,44,182,192,32,226,195,92,130,27,224,218,206,133,214,64,169,84,11,208,15,72,68,64,16,9,212,64,174,59,100,30,68,43,23,8,134,130,54,24,160,137,231,156,91,8,132,3,2,218,144,236,219,135,133,191,162,173,157,142,157,152,32,37,70,0,70,159,127,227,213,201,132,244,214,77,6,227,182,24,18,9,0,0,0,4,0,0,32,0,0,0,0,2,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,142,120,110,95,63,126,221,61,247,252,155,252,174,210,255,143,107,241,231,191,186,174,110,23,239,220,167,62,182,181,119,201,146,215,165,182,74,110,155,185,129,77,103,254,84,241,155,98,254,111,82,215,54,254,191,41,69,129,249,189,101,166,66,57,0,0,66,96,143,0,148,64,64,210,175,215,209,219,0,160,152,178,123,6,82,32,152,22,200,61,9,0,0,1,0,0,0,1,10,178,8,128,0,0,0,4,136,32,20,16,76,0,0,4,0,161,68,16,0,65,1,0,8,64,240,223,79,54,88,241,245,181,128,245,103,128,64,0,80,78,65,200,132,0,90,96,216,1,43,1,80,161,22,196,64,242,110,17,172,32,57,196,192,8,7,12,9,152,150,196,155,16,28,152,108,134,42,166,1,70,17,109,229,203,196,192,146,16,33,22,18,157,114,244,105,14,23,42,162,129,244,123,0,8,164,11,144,16,44,204,57,74,1,240,22,11,10,64,12,29,234,12,68,14,69,2,0,128,32,34,0,168,131,33,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,128,32,34,0,32,8,33,0,192,162,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,128,32,34,0,176,71,32,0,208,46,40,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,128,32,34,0,40,210,39,0,192,105,39,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,128,32,34,0,104,26,39,0,192,105,39,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,128,32,34,0,152,213,38,0,40,144,38,0,20,4,0,0,1,0,0,0,200,0,0,0,0,0,0,0,0,0,0,0,0,0,73,64,0,0,0,0,0,0,160,64,16,0,1,0,0,0,0,0,48,85,38,0,168,32,38,0,24,4,0,0,1,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,64,16,0,1,0,0,0,0,0,0,241,37,0,80,195,37,0,28,4,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,120,161,37,0,200,120,37,0,32,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,120,161,37,0,96,53,37,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,161,37,0,112,11,37,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,120,161,37,0,64,227,36,0,72,192,36,0,36,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,64,227,36,0,96,163,36,0,32,136,36,0,40,4,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,96,163,36,0,32,109,36,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,96,163,36,0,120,81,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,96,163,36,0,64,57,36,0,216,27,36,0,44,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,64,57,36,0,112,224,35,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,64,57,36,0,168,195,35,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,64,57,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,98,36,0,112,0,0,0,136,209,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,144,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,209,35,0,56,227,34,0,4,0,0,0,4,0,0,0,154,153,153,153,153,153,201,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,136,32,34,0,192,131,33,0,8,0,0,0,4,0,0,0,225,122,20,174,71,225,202,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,48,8,33,0,216,162,32,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,48,8,33,0,192,71,32,0,240,46,40,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,48,8,33,0,48,210,39,0,24,106,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,48,8,33,0,112,26,39,0,168,213,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,48,8,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,144,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,0,0,0,0,0,0,0,0,0,0,0,66,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,103,36,0,112,0,0,0,192,213,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,0,2,0,3,1,3,1,2,2,2,2,3,3,3,3,2,3,1,2,1,2,0,3,0,0,0,0,192,0,0,128,63,0,112,247,191,0,152,111,63,96,187,36,0,168,15,35,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,130,36,0,168,15,35,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,104,36,0,184,76,36,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,152,104,36,0,184,53,36,0,0,13,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,80,216,35,0,56,191,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,112,168,35,0,160,146,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,16,124,35,0,232,101,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,160,83,35,0,72,231,34,0,40,0,0,0,3,0,0,0,57,180,200,118,190,159,230,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,0,49,35,0,72,231,34,0,40,0,0,0,3,0,0,0,57,180,200,118,190,159,230,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,128,214,34,0,136,199,34,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,112,183,34,0,136,199,34,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,87,39,0,112,0,0,0,232,215,16,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,18,254,2,3,5,255,17,4,0,0,0,0,0,0,0,0,1,18,17,254,2,18,3,7,2,5,4,0,0,0,0,0,0,0,1,2,1,18,3,6,254,18,2,3,4,5,0,0,0,0,0,0,0,0,2,18,18,254,2,18,3,6,2,17,4,0,0,0,0,0,0,0,1,2,18,18,2,18,3,2,255,4,18,5,0,0,0,0,0,0,0,1,1,7,6,5,3,4,2,5,4,3,7,0,0,0,0,0,0,0,1,1,17,3,18,7,2,6,1,4,3,5,0,0,0,0,0,0,0,1,1,254,18,18,18,3,254,6,5,2,1,0,0,0,0,0,0,0,1,2,18,18,255,18,2,3,6,254,17,5,0,0,0,0,0,0,0,0,1,17,17,18,3,6,4,5,2,18,254,0,0,0,0,0,0,0,1,2,1,18,254,3,5,2,4,255,6,1,0,0,0,0,0,0,0,0,2,18,18,3,6,18,2,4,8,5,3,0,0,0,0,0,0,0,0,1,254,1,18,2,254,7,18,2,255,5,0,0,0,0,0,0,0,1,1,4,3,8,1,5,2,5,6,2,8,0,0,0,0,0,0,0,1,1,17,18,2,6,3,4,255,1,8,6,0,0,0,0,0,0,0,0,1,18,18,3,6,3,254,2,5,255,1,0,0,0,0,0,0,0,0,1,18,18,17,255,2,254,18,3,4,5,0,0,0,0,0,0,0,1,2,18,17,2,254,18,3,5,7,2,4,0,0,0,0,0,0,0,1,2,18,18,3,6,254,18,2,5,8,3,0,0,0,0,0,0,0,0,1,18,17,2,18,18,2,6,5,17,7,0,0,0,0,0,0,0,1,2,18,17,2,18,3,2,6,18,255,4,0,0,0,0,0,0,0,1,1,5,3,6,5,3,4,1,2,4,7,0,0,0,0,0,0,0,1,1,5,3,6,5,3,4,1,2,4,7,0,0,0,0,0,0,0,0,1,254,18,18,18,254,3,2,4,6,5,0,0,0,0,0,0,0,1,2,18,17,253,3,255,18,2,3,6,5,0,0,0,0,0,0,0,0,1,17,18,7,3,254,7,1,2,4,5,0,0,0,0,0,0,0,1,1,2,18,18,254,2,4,255,18,3,6,0,0,0,0,0,0,0,0,3,1,18,4,3,5,2,4,18,2,3,0,0,0,0,0,0,0,0,1,254,18,2,18,3,7,18,2,6,254,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,18,5,4,6,4,5,1,4,3,0,0,0,0,0,0,0,1,1,18,3,6,5,7,8,2,3,1,255,0,0,0,0,0,0,0,1,1,18,18,18,2,254,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,17,254,2,3,18,253,5,2,7,0,0,0,0,0,0,0,1,1,1,1,255,8,17,3,254,2,6,17,0,0,0,0,0,0,0,0,2,18,18,17,2,254,3,2,4,18,5,0,0,0,0,0,0,0,1,1,17,18,2,255,5,7,18,3,4,6,0,0,0,0,0,0,0,1,1,5,4,5,17,3,6,3,4,7,2,0,0,0,0,0,0,0,0,1,17,3,1,7,4,2,5,254,18,6,0,0,0,0,0,0,0,0,1,17,18,2,18,4,3,5,7,253,6,0,0,0,0,0,0,0,1,2,17,17,253,254,2,8,18,255,3,5,0,0,0,0,0,0,0,0,1,17,17,18,2,3,6,254,8,1,7,0,0,0,0,0,0,0,1,1,1,2,6,254,18,2,5,253,7,254,0,0,0,0,0,0,0,0,1,18,18,3,18,6,8,254,2,3,5,0,0,0,0,0,0,0,0,1,18,17,2,18,254,3,7,6,2,4,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,18,2,255,3,6,1,3,4,8,0,0,0,0,0,0,0,0,1,18,18,3,6,5,3,254,2,18,255,0,0,0,0,0,0,0,0,1,18,17,253,18,2,4,254,3,6,17,0,0,0,0,0,0,0,1,3,1,2,17,3,18,7,255,5,2,4,0,0,0,0,0,0,0,1,1,18,3,18,6,8,18,254,5,7,2,0,0,0,0,0,0,0,0,1,17,2,18,6,3,2,5,4,8,1,0,0,0,0,0,0,0,0,1,18,17,255,2,3,18,18,2,3,17,0,0,0,0,0,0,0,1,1,18,7,6,5,5,3,1,4,2,4,0,0,0,0,0,0,0,1,1,6,17,3,8,1,5,7,255,2,1,0,0,0,0,0,0,0,1,1,18,254,18,3,254,2,7,4,6,18,0,0,0,0,0,0,0,1,3,18,253,18,2,3,18,255,7,2,5,0,0,0,0,0,0,0,0,2,18,254,7,1,3,2,4,6,253,7,0,0,0,0,0,0,0,1,1,18,254,2,253,18,254,17,255,4,2,0,0,0,0,0,0,0,0,3,17,17,2,5,3,7,18,6,4,2,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,17,4,6,6,4,5,3,4,1,0,0,0,0,0,0,0,0,1,18,5,3,6,2,3,8,1,3,7,0,0,0,0,0,0,0,1,2,18,17,254,2,18,3,5,7,255,2,0,0,0,0,0,0,0,0,1,1,18,18,3,6,255,4,8,5,2,0,0,0,0,0,0,0,1,1,1,5,3,4,1,1,3,5,7,3,0,0,0,0,0,0,0,0,1,3,18,18,2,18,18,255,2,3,18,0,0,0,0,0,0,0,1,2,18,18,255,18,2,3,4,6,18,5,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,3,1,4,5,2,7,1,3,6,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,18,255,18,2,3,5,254,6,8,0,0,0,0,0,0,0,1,1,17,18,4,8,3,2,5,2,7,6,0,0,0,0,0,0,0,1,4,1,2,5,18,254,2,3,7,255,4,0,0,0,0,0,0,0,0,2,18,17,255,3,6,18,2,3,7,5,0,0,0,0,0,0,0,0,1,254,18,2,253,6,18,4,3,254,5,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,17,6,2,4,8,3,5,255,17,0,0,0,0,0,0,0,1,1,18,3,18,6,8,18,254,5,7,2,0,0,0,0,0,0,0,1,2,17,17,253,2,18,254,8,3,6,255,0,0,0,0,0,0,0,1,1,18,254,17,18,2,3,254,6,5,4,0,0,0,0,0,0,0,1,2,18,17,255,3,18,2,5,3,6,253,0,0,0,0,0,0,0,0,1,18,17,2,18,7,18,2,4,3,17,0,0,0,0,0,0,0,1,3,18,18,5,6,4,3,4,18,6,5,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,7,6,5,3,4,2,5,4,3,7,0,0,0,0,0,0,0,0,1,254,18,18,18,3,6,4,2,5,2,0,0,0,0,0,0,0,0,3,18,17,253,18,3,2,5,255,17,3,0,0,0,0,0,0,0,1,1,17,18,7,3,1,7,4,2,6,5,0,0,0,0,0,0,0,1,1,18,2,254,255,18,5,3,254,1,2,0,0,0,0,0,0,0,0,3,18,18,255,3,2,7,5,18,4,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,18,2,254,4,8,18,3,6,5,0,0,0,0,0,0,0,0,2,18,17,3,5,254,7,2,18,3,255,0,0,0,0,0,0,0,1,1,18,2,254,255,18,5,3,254,1,2,0,0,0,0,0,0,0,0,2,3,17,18,18,2,5,7,6,18,3,0,0,0,0,0,0,0,1,1,17,18,18,4,3,2,18,7,8,255,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,1,2,3,5,6,1,4,8,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,17,255,18,253,2,8,3,6,17,0,0,0,0,0,0,0,1,1,17,17,1,2,4,5,255,2,1,6,0,0,0,0,0,0,0,1,1,1,2,6,254,18,2,253,3,254,5,0,0,0,0,0,0,0,0,1,18,3,18,6,18,5,2,4,255,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,18,255,2,18,3,6,4,254,7,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,255,18,18,18,2,254,4,7,2,3,0,0,0,0,0,0,0,0,3,3,17,254,5,2,7,18,6,4,5,0,0,0,0,0,0,0,0,1,17,6,18,3,8,4,5,3,8,18,0,0,0,0,0,0,0,0,2,18,2,6,2,18,3,2,4,5,8,0,0,0,0,0,0,0,0,1,3,18,18,2,18,255,2,18,2,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,3,6,17,254,5,1,2,7,4,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,3,3,18,17,5,6,2,7,254,8,18,0,0,0,0,0,0,0,1,1,18,255,3,1,7,2,255,4,6,17,0,0,0,0,0,0,0,1,1,18,2,254,255,18,5,3,254,1,2,0,0,0,0,0,0,0,0,2,18,1,2,18,3,6,5,2,4,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,254,2,18,18,8,5,3,2,6,0,0,0,0,0,0,0,0,1,18,17,2,18,3,2,7,254,18,4,0,0,0,0,0,0,0,1,2,1,18,2,3,255,5,6,4,7,17,0,0,0,0,0,0,0,0,2,18,17,3,6,254,2,3,8,5,17,0,0,0,0,0,0,0,0,2,18,18,3,2,18,255,2,4,3,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,17,255,18,2,3,254,5,18,2,7,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,253,18,2,3,254,18,5,6,253,0,0,0,0,0,0,0,0,2,18,17,3,5,254,7,2,18,3,255,0,0,0,0,0,0,0,1,1,1,18,255,2,3,1,254,8,2,5,0,0,0,0,0,0,0,0,1,18,18,3,6,18,2,3,4,8,5,0,0,0,0,0,0,0,0,1,254,1,18,2,254,5,7,18,2,255,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,18,255,2,8,3,4,5,1,7,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,18,255,2,18,3,254,5,4,2,0,0,0,0,0,0,0,1,1,18,17,2,18,3,8,5,2,7,17,0,0,0,0,0,0,0,0,1,18,18,3,18,6,8,254,2,3,5,0,0,0,0,0,0,0,0,1,18,18,2,18,2,6,18,2,17,7,0,0,0,0,0,0,0,1,3,18,17,18,2,8,18,5,255,3,6,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,18,7,6,5,5,3,1,4,2,4,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,17,255,3,6,18,2,5,8,3,0,0,0,0,0,0,0,0,1,17,18,18,4,7,2,3,254,18,5,0,0,0,0,0,0,0,1,2,18,1,2,6,2,5,18,2,4,8,0,0,0,0,0,0,0,0,4,18,4,1,2,3,5,4,1,2,6,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,17,2,255,18,3,253,5,2,4,0,0,0,0,0,0,0,0,1,17,17,3,6,3,5,254,2,18,255,0,0,0,0,0,0,0,0,2,18,18,3,254,18,2,253,5,3,6,0,0,0,0,0,0,0,1,1,17,17,2,4,1,3,5,2,6,253,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,1,3,2,7,1,6,3,4,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,255,18,2,1,5,3,8,255,254,0,0,0,0,0,0,0,1,1,17,18,255,8,2,5,3,4,1,6,0,0,0,0,0,0,0,1,2,1,18,3,255,5,1,2,4,7,6,0,0,0,0,0,0,0,0,1,18,18,3,6,5,3,254,2,18,255,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,1,18,255,3,8,5,6,1,2,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,18,2,3,6,18,255,4,2,3,0,0,0,0,0,0,0,1,1,1,3,5,18,2,6,7,2,3,1,0,0,0,0,0,0,0,1,1,1,3,8,18,5,2,7,1,3,254,0,0,0,0,0,0,0,0,2,17,2,18,3,6,2,4,5,8,3,0,0,0,0,0,0,0,0,1,18,17,2,18,3,2,7,254,18,4,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,253,18,255,3,254,5,7,1,2,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,3,18,18,2,6,18,5,18,2,3,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,3,1,255,1,3,254,2,5,7,253,18,0,0,0,0,0,0,0,1,2,18,7,3,253,2,8,2,5,4,17,0,0,0,0,0,0,0,1,1,1,4,5,1,3,4,6,7,8,3,0,0,0,0,0,0,0,0,1,18,17,2,18,255,2,3,18,2,4,0,0,0,0,0,0,0,0,2,18,18,254,18,2,3,4,7,5,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,18,2,1,3,2,5,1,2,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,18,255,2,3,5,8,6,1,254,0,0,0,0,0,0,0,0,1,17,18,8,3,4,6,5,2,8,7,0,0,0,0,0,0,0,1,2,1,3,254,18,2,5,1,7,255,254,0,0,0,0,0,0,0,0,3,18,17,255,3,18,2,3,6,4,17,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,2,18,18,4,18,6,7,8,3,18,2,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,17,253,17,2,254,8,3,18,4,253,0,0,0,0,0,0,0,1,1,18,17,3,5,6,2,8,1,3,7,0,0,0,0,0,0,0,0,1,18,18,3,6,5,3,254,2,18,255,0,0,0,0,0,0,0,0,3,18,18,2,6,18,5,18,2,3,17,0,0,0,0,0,0,0,1,1,18,18,5,4,6,4,5,1,4,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,3,17,18,253,2,5,18,6,255,7,0,0,0,0,0,0,0,1,1,17,18,3,2,5,255,6,8,4,7,0,0,0,0,0,0,0,1,1,18,1,254,3,2,1,7,6,3,4,0,0,0,0,0,0,0,0,3,1,2,17,3,18,2,7,5,4,255,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,17,254,2,18,18,8,5,3,2,6,0,0,0,0,0,0,0,0,2,18,5,18,2,3,7,254,1,6,8,0,0,0,0,0,0,0,0,1,2,255,18,255,2,4,253,5,18,3,0,0,0,0,0,0,0,0,1,3,17,18,5,2,18,7,3,6,5,0,0,0,0,0,0,0,1,4,1,2,5,18,254,2,3,7,255,4,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,1,18,2,1,3,4,1,5,2,7,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,17,17,18,2,4,5,18,254,6,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,18,18,255,3,5,6,8,18,2,3,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,18,18,4,6,8,18,7,3,2,5,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,2,255,18,18,18,2,4,254,2,3,6,0,0,0,0,0,0,0,0,2,18,254,7,1,3,2,4,6,253,7,0,0,0,0,0,0,0,1,1,17,18,8,3,4,6,254,5,3,8,0,0,0,0,0,0,0,0,2,18,1,2,6,2,8,3,18,5,4,0,0,0,0,0,0,0,1,1,3,18,18,2,18,2,18,3,2,18,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,1,1,3,17,18,5,2,6,7,1,4,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,0,1,255,18,18,2,18,3,5,18,2,8,0,0,0,0,0,0,0,30,3,42,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,254,2,1,240,246,1,3,1,0,6,1,253,7,1,234,2,252,253,11,14,6,255,1,243,29,228,10,10,248,0,247,248,8,249,10,253,244,251,248,1,254,9,254,251,238,1,9,248,248,3,41,7,247,247,22,214,227,14,238,242,224,1,241,240,8,15,16,240,5,2,7,250,240,249,1,1,253,254,0,8,20,230,245,2,239,0,253,222,219,10,44,254,22,2,252,7,14,5,6,15,255,3,253,247,233,251,242,8,255,242,250,251,248,54,31,250,18,2,237,254,245,226,250,237,2,254,242,1,2,254,255,253,253,1,251,1,253,252,248,5,252,0,1,3,7,251,252,253,244,3,254,253,12,203,205,6,255,6,8,0,255,5,1,250,248,7,5,238,252,255,1,0,253,253,242,255,250,0,242,255,255,5,253,245,1,236,10,2,19,254,254,2,4,3,0,5,0,3,1,254,0,250,253,252,251,253,253,249,0,222,4,213,17,0,203,243,249,24,14,5,238,9,236,1,0,253,2,3,251,254,7,235,5,231,23,11,228,2,1,245,9,13,250,244,5,7,2,4,245,250,255,8,0,1,254,2,252,250,252,0,251,227,13,250,234,253,213,12,215,5,24,18,247,220,250,4,249,252,13,4,241,255,251,1,2,251,4,0,255,13,250,251,1,0,253,1,251,19,234,31,229,4,241,250,15,9,243,1,247,10,239,4,255,255,4,2,0,253,251,249,3,248,13,19,244,8,237,253,254,232,31,14,0,7,243,238,0,3,6,13,254,1,244,235,9,254,30,21,242,2,242,253,249,8,255,254,247,6,1,249,7,13,3,255,246,30,4,246,12,5,6,243,249,252,254,254,7,253,250,3,4,1,2,248,9,2,253,251,2,0,9,3,7,252,240,243,3,23,229,18,46,218,6,4,43,255,0,8,249,252,255,11,249,6,253,1,1,18,248,250,0,3,4,22,253,252,254,252,245,40,249,253,243,242,249,246,14,7,5,242,11,251,7,21,254,9,253,0,0,254,4,254,0,2,0,255,2,255,0,0,2,2,2,255,1,253,255,241,254,193,229,235,209,242,1,242,10,0,2,1,0,252,0,253,247,4,2,6,250,0,251,11,249,241,6,249,250,3,7,241,251,23,243,250,12,248,9,2,253,3,4,6,0,3,0,254,252,2,1,1,255,1,254,255,252,234,241,210,190,10,20,2,239,12,250,1,254,254,0,1,251,1,2,255,0,0,1,0,252,0,1,246,253,248,5,7,245,2,245,29,231,11,10,0,255,5,249,254,251,254,4,4,253,5,254,1,255,255,253,254,1,248,253,2,254,4,251,255,249,254,1,242,249,3,226,241,242,3,252,255,3,243,255,253,1,2,3,255,254,253,2,2,253,3,1,253,2,0,252,6,5,251,10,199,3,22,206,1,254,251,250,255,5,1,2,2,1,254,2,2,0,255,249,2,1,3,2,0,4,3,254,3,253,4,252,24,221,253,38,250,251,15,20,3,16,249,251,0,252,251,0,0,1,0,0,0,255,255,1,1,255,1,254,0,0,0,0,0,255,254,255,251,254,213,253,46,204,246,7,248,11,254,255,0,0,255,0,255,2,215,33,212,208,241,230,247,6,3,3,253,2,2,2,2,255,255,254,1,3,0,0,5,2,3,1,252,1,6,1,250,255,254,1,242,252,0,251,254,2,254,0,250,1,0,8,235,32,253,220,250,254,255,249,3,0,1,250,253,254,3,0,2,2,8,252,252,6,2,1,3,250,4,3,13,0,244,255,25,236,254,233,241,7,253,245,253,6,255,0,0,0,253,255,0,0,254,255,254,254,1,255,0,0,10,3,254,3,3,249,250,251,0,252,196,240,250,38,5,6,251,0,0,1,0,0,0,0,0,0,1,255,255,0,1,0,0,1,0,0,255,0,248,2,247,10,40,31,200,235,4,20,252,7,254,254,0,4,253,255,7,3,1,3,248,0,3,1,2,5,1,254,14,5,4,5,5,5,251,9,190,0,236,254,248,4,254,255,4,255,248,254,252,255,253,253,2,249,253,5,7,254,45,31,239,240,254,254,255,234,1,255,253,3,5,253,5,255,252,0,7,5,8,7,2,9,247,247,249,245,253,248,17,252,34,32,18,22,1,2,1,249,251,6,255,6,4,10,254,249,6,0,14,9,6,255,254,253,4,250,248,4,7,255,28,38,15,255,16,245,5,8,4,246,3,246,239,5,3,3,3,1,1,1,2,255,2,1,0,0,255,0,0,254,1,253,0,1,2,254,252,254,0,255,1,253,1,1,1,255,8,8,66,33,251,2,253,249,2,248,252,10,17,238,249,4,252,249,250,250,251,5,244,2,0,6,8,254,1,4,245,2,1,8,31,19,6,9,16,250,250,255,254,253,245,254,7,7,17,3,4,10,2,5,243,8,7,1,4,5,7,6,7,248,9,248,33,6,3,255,1,0,249,251,0,14,249,1,249,1,2,252,7,10,240,12,1,250,3,8,255,10,243,250,244,233,12,253,30,14,254,241,0,8,3,237,5,253,2,3,13,7,14,253,246,0,8,5,250,240,248,248,14,2,255,1,247,245,11,251,27,9,248,6,252,4,252,255,5,4,1,249,251,252,241,1,9,0,8,4,1,239,11,254,237,255,250,248,3,244,3,239,33,246,253,255,2,7,7,254,9,8,238,255,243,246,253,253,11,8,254,244,248,1,4,9,14,10,253,0,2,1,254,3,31,10,253,246,8,255,251,245,7,251,3,6,1,4,240,10,5,252,254,246,255,13,6,251,249,12,7,253,239,1,12,252,29,8,1,2,5,2,250,249,0,255,6,255,10,6,252,5,2,2,254,248,250,245,14,243,27,3,254,244,5,240,2,230,20,15,255,253,251,253,253,6,255,3,251,1,7,2,1,0,255,255,0,255,9,7,250,253,4,251,252,8,248,231,248,252,34,23,255,254,1,1,255,254,255,1,255,0,0,0,0,254,255,1,0,2,1,255,4,0,0,1,255,0,5,3,12,247,68,240,10,0,248,14,250,1,244,0,0,253,251,245,250,12,9,246,253,5,0,7,11,2,4,253,248,253,7,4,3,253,34,4,244,13,251,7,245,254,255,1,252,242,235,3,253,253,252,249,247,252,3,239,254,243,10,254,12,252,0,247,1,251,31,10,246,6,5,6,4,249,10,0,228,253,0,245,255,251,16,246,240,7,20,2,252,2,251,0,15,6,5,246,7,247,20,4,1,249,254,249,4,253,254,249,255,242,6,240,4,251,252,250,251,0,254,2,250,9,251,4,238,8,246,8,15,0,32,1,251,7,253,7,15,252,0,240,9,5,251,5,4,253,244,247,238,10,2,2,253,7,3,255,6,247,246,3,15,252,35,249,255,246,2,2,252,254,10,2,255,2,254,1,255,242,245,3,248,5,248,254,6,255,249,1,7,5,7,8,30,252,30,14,2,254,1,2,3,248,3,0,254,0,247,2,1,4,250,255,254,5,0,1,254,12,6,253,9,253,4,244,21,217,24,254,3,5,1,254,254,254,253,6,248,254,245,248,255,4,2,2,252,246,12,251,245,1,241,222,245,249,245,255,7,242,38,255,252,4,8,9,8,1,251,247,4,254,15,252,11,241,20,255,255,253,4,247,254,254,254,8,6,12,251,0,11,244,27,252,0,8,252,3,245,6,245,2,3,0,5,248,249,250,247,235,4,245,255,240,249,16,253,7,249,4,251,0,11,249,31,3,1,3,4,11,245,254,253,250,6,5,0,3,247,250,4,252,0,4,248,13,250,243,255,251,255,4,0,0,9,234,24,18,249,3,10,243,250,6,250,6,22,1,0,242,2,3,7,255,8,20,255,5,252,13,9,247,247,6,0,252,0,248,31,252,253,252,0,1,7,3,249,0,5,254,1,3,3,1,251,254,5,2,245,4,0,255,12,0,253,243,15,8,250,229,34,0,253,253,10,252,2,255,253,0,255,255,252,2,6,254,12,1,3,250,249,250,251,4,237,250,248,222,252,248,10,249,23,10,249,0,255,250,8,4,252,2,251,248,249,247,248,5,9,7,250,1,244,244,255,240,5,0,16,3,249,248,27,252,23,15,248,4,8,5,6,11,253,5,3,255,245,6,251,0,2,250,253,250,4,255,5,251,244,250,7,251,9,3,6,249,29,1,1,3,254,254,250,254,1,6,250,253,1,2,3,4,1,5,255,0,4,2,11,6,2,253,13,247,237,18,241,246,36,21,253,253,2,255,249,6,252,1,253,255,254,2,3,249,253,0,254,0,254,6,237,3,248,2,250,7,255,0,29,250,28,246,251,1,253,249,244,252,1,1,255,13,246,255,247,251,243,6,13,3,252,2,3,11,2,6,231,240,250,0,14,255,27,16,250,255,249,251,254,251,251,255,9,1,0,3,248,244,250,5,250,5,3,247,1,4,249,246,247,249,239,251,241,233,25,3,248,254,9,253,252,3,255,8,249,249,251,252,254,9,4,255,249,252,251,240,3,250,18,243,247,16,241,8,15,246,24,5,1,218,2,34,9,10,11,2,2,250,3,2,254,5,4,249,255,1,4,0,3,1,248,255,250,5,4,2,252,5,2,255,1,234,15,18,254,10,240,247,248,245,8,4,0,7,242,251,255,249,12,17,9,5,249,252,244,250,7,0,7,2,254,1,245,227,7,10,19,255,248,247,7,1,9,6,8,249,242,8,253,245,243,0,249,233,254,248,12,9,2,14,19,1,255,5,232,229,245,36,2,6,253,4,250,8,0,12,255,252,250,3,4,255,2,253,254,3,2,255,254,252,0,255,254,7,2,3,247,232,11,13,246,244,12,254,7,4,8,13,253,253,2,9,253,252,4,13,5,13,250,253,1,15,7,253,0,19,254,247,248,241,7,14,252,251,2,238,237,254,2,17,16,6,246,10,247,14,255,251,255,250,249,2,9,11,13,6,251,244,3,2,246,219,13,1,3,242,0,236,4,253,8,2,254,253,247,251,253,239,255,13,245,2,250,4,4,0,3,1,247,252,251,252,254,234,251,46,248,5,9,245,8,7,7,255,255,254,249,2,253,3,255,254,7,0,2,255,1,254,254,253,6,0,252,250,240,229,15,16,252,14,249,230,2,254,6,5,253,11,0,2,3,9,249,255,2,252,252,255,6,10,1,1,253,254,3,0,253,234,10,26,1,2,253,3,17,253,249,9,1,235,252,5,3,0,249,250,3,3,248,249,247,3,7,1,248,12,6,249,247,231,3,18,9,250,245,0,251,244,9,248,249,250,250,22,2,250,253,15,3,2,254,9,14,246,249,15,13,6,254,11,5,236,251,28,11,10,252,252,0,249,3,5,2,251,248,2,6,10,9,247,238,3,14,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1101520);
/* memory initializer */ allocate([3,253,255,250,7,7,2,255,248,226,7,12,10,8,7,243,240,0,1,255,250,245,241,4,1,254,10,241,1,11,254,8,9,249,249,9,251,2,7,238,246,224,10,11,3,255,3,251,5,2,14,250,3,1,5,241,245,6,20,4,0,244,249,3,1,255,10,6,255,247,252,255,1,231,242,12,245,9,9,240,232,239,22,247,11,226,253,252,6,249,9,2,255,251,250,2,255,255,10,1,253,3,4,8,242,230,250,9,8,17,245,232,249,252,248,254,10,2,2,255,2,13,12,249,4,250,246,6,6,243,245,249,240,0,254,5,252,226,243,12,16,250,12,240,243,5,15,254,254,246,249,7,11,255,252,254,252,7,4,248,1,3,0,11,3,254,251,4,252,235,20,22,2,20,248,1,244,251,247,4,246,239,253,248,253,3,244,1,253,0,7,4,7,7,253,7,5,3,1,251,244,236,2,29,11,250,9,249,250,252,0,6,17,243,254,246,239,255,238,2,0,14,250,1,0,3,2,246,1,251,254,5,16,219,255,26,254,242,1,251,242,2,2,3,6,1,1,4,0,255,0,254,254,4,9,250,0,254,10,249,254,4,1,0,247,232,244,5,5,3,239,242,4,3,2,252,10,234,248,253,6,1,12,248,4,1,9,255,18,253,6,5,3,251,9,251,242,223,254,20,243,246,2,249,255,11,247,248,18,253,1,8,0,254,10,7,254,243,9,253,252,5,254,254,255,251,1,249,246,233,8,14,1,7,1,253,249,4,1,1,8,249,15,242,13,14,2,5,243,251,248,255,6,3,6,9,6,15,14,5,243,231,246,13,239,232,249,243,250,246,248,2,0,243,246,252,248,4,247,9,252,4,253,253,3,3,251,247,1,254,11,2,244,233,1,18,245,254,5,9,251,5,14,247,253,254,250,2,254,11,243,1,253,11,247,252,254,250,8,10,1,4,2,1,251,238,16,22,2,0,8,250,247,249,10,240,23,10,245,255,7,2,7,2,1,251,6,1,0,252,9,2,253,1,0,252,253,230,14,11,2,247,17,254,255,251,240,247,251,10,243,1,6,12,10,11,0,0,253,242,6,254,0,4,251,255,249,255,246,223,1,8,11,251,1,250,7,4,5,6,1,254,246,251,250,12,245,5,246,4,12,255,255,253,4,255,9,0,16,239,242,219,7,7,254,5,248,245,2,243,4,237,1,8,8,4,247,2,252,3,12,2,4,252,248,8,1,4,8,255,6,254,250,226,18,17,1,234,253,4,249,246,7,0,248,8,255,4,2,8,6,254,2,7,4,4,3,250,2,1,253,1,255,251,239,238,253,22,248,1,9,254,239,20,251,251,244,251,4,251,247,8,254,16,253,0,19,248,8,1,2,252,0,11,0,253,247,233,3,10,4,4,253,254,254,254,1,234,11,0,254,5,254,14,247,245,252,7,5,32,1,253,249,0,21,247,7,250,0,0,0,2,255,1,0,1,3,0,0,1,0,1,0,1,253,0,255,254,0,255,255,253,255,1,252,1,255,251,187,237,253,251,248,244,4,253,237,245,251,0,242,7,18,250,7,22,8,14,15,10,3,255,253,5,255,7,249,1,250,3,230,245,255,250,4,252,251,240,0,250,253,11,1,0,9,5,16,3,252,223,252,4,249,0,1,6,245,254,243,254,238,20,231,240,4,0,255,0,251,1,0,2,0,11,246,4,246,7,16,2,16,15,2,255,2,9,2,8,253,251,254,0,253,0,223,254,253,241,10,10,247,255,7,3,5,251,248,248,253,15,247,4,12,13,243,242,10,250,9,22,229,23,255,5,232,2,226,5,0,254,7,251,251,3,5,3,253,251,2,1,252,3,253,255,1,254,10,22,253,252,254,254,249,3,8,1,14,4,219,9,253,252,255,1,252,0,6,2,6,249,246,246,255,252,11,253,7,250,4,244,255,5,1,249,10,250,17,252,8,3,216,13,2,12,4,249,14,253,16,254,18,2,13,5,5,1,11,255,0,9,2,250,255,2,250,2,251,3,5,1,255,1,224,249,240,11,7,252,2,251,247,9,11,11,15,243,245,11,9,4,3,248,246,12,12,0,0,240,247,13,2,9,4,243,223,3,6,4,5,4,3,255,5,6,4,2,245,255,241,245,255,1,11,253,254,24,252,250,231,246,241,248,0,0,251,4,226,2,10,253,250,1,247,251,6,9,246,253,8,255,4,255,11,245,3,9,11,253,6,239,5,248,223,9,243,19,254,9,231,2,0,0,255,253,0,254,1,0,0,2,1,0,254,0,255,2,0,255,4,255,2,253,4,254,3,3,1,0,241,12,193,27,254,14,9,255,3,0,1,1,237,15,3,4,0,246,1,251,3,0,251,246,2,240,252,8,244,250,7,251,246,255,223,252,0,3,1,3,1,2,4,4,9,250,248,251,1,244,3,8,246,6,255,1,13,251,251,2,252,13,238,246,249,247,223,10,250,253,244,5,255,11,250,0,254,1,2,249,3,1,3,254,1,8,246,7,255,253,3,0,13,1,6,7,240,249,217,8,250,255,11,6,253,8,3,251,3,0,251,254,250,253,252,2,253,13,245,1,7,5,19,251,253,241,255,7,255,6,223,8,249,3,252,253,252,1,6,251,251,6,248,255,249,4,255,250,254,1,7,0,1,1,251,2,254,0,243,254,225,242,217,244,246,9,0,253,1,255,255,0,1,251,255,252,254,5,2,249,18,248,254,237,249,249,244,242,245,255,247,243,249,244,225,247,253,240,10,9,1,246,244,2,254,2,7,253,253,1,252,251,247,5,7,3,255,4,245,248,4,13,246,13,10,252,220,1,249,244,4,236,249,249,2,11,255,254,3,244,1,0,250,249,6,4,13,3,253,4,3,250,244,5,251,234,243,248,219,250,249,5,3,5,7,9,242,253,10,17,255,1,244,5,250,0,252,247,0,245,242,3,13,6,231,248,244,4,246,18,226,255,246,6,246,6,6,1,246,0,249,5,254,17,238,252,0,253,240,250,253,248,5,1,252,6,249,16,6,10,255,0,224,245,255,9,9,251,4,9,6,9,252,254,7,11,4,2,251,252,250,0,2,253,255,5,10,0,12,246,238,253,255,14,223,2,4,248,238,252,251,245,4,246,252,9,13,244,1,250,1,2,4,247,8,3,250,21,13,255,254,1,254,6,249,0,226,1,6,255,2,253,255,252,6,252,0,4,2,2,247,2,6,3,254,4,255,9,250,0,7,248,5,19,254,9,251,2,223,248,2,1,12,251,248,8,3,254,252,1,254,5,252,247,248,248,7,245,252,6,246,7,255,255,254,255,16,32,249,20,223,250,238,2,6,13,9,9,255,3,239,24,254,250,28,8,254,6,3,246,222,240,243,252,241,245,244,253,246,4,248,4,225,252,245,0,18,2,240,247,243,254,254,244,253,234,30,0,8,3,9,252,240,1,0,245,15,254,252,6,251,6,1,2,231,244,14,255,5,7,3,241,248,1,5,254,12,13,11,231,3,1,0,254,252,240,233,0,251,239,7,5,247,6,251,2,224,249,3,255,6,14,2,244,247,247,4,7,4,6,5,248,4,2,4,5,254,8,8,250,0,10,236,255,3,255,8,23,223,251,253,11,250,3,252,5,7,3,4,5,254,3,255,30,6,1,8,250,0,0,247,6,247,4,2,9,250,1,244,0,222,18,239,13,0,1,9,252,245,0,7,0,246,252,255,6,250,4,1,6,247,3,251,250,245,2,252,14,23,253,2,5,226,12,242,5,229,2,0,7,1,4,30,8,7,5,1,255,0,5,8,246,48,245,12,33,6,8,241,20,254,251,32,5,237,10,240,252,244,249,254,0,8,250,236,238,16,253,0,31,254,11,2,247,49,237,244,233,10,26,16,254,4,235,242,13,245,247,251,247,255,3,251,235,2,10,0,0,10,235,249,7,230,247,22,32,58,11,253,11,251,248,243,6,251,247,1,10,14,248,7,7,10,3,254,255,245,245,250,213,253,14,237,238,19,18,224,10,45,250,6,21,236,244,2,4,6,6,252,3,3,1,21,22,253,254,245,250,255,254,8,8,32,235,7,28,252,250,253,254,50,2,2,27,251,248,12,7,251,255,252,239,27,6,13,7,2,250,244,2,246,251,239,11,4,17,244,254,5,239,37,240,48,242,238,29,8,24,11,251,247,11,255,1,243,253,1,1,255,2,0,0,0,255,1,255,7,2,253,3,0,6,2,10,54,231,7,54,251,250,255,241,9,13,232,241,244,3,21,5,8,3,253,252,254,252,3,245,251,248,9,16,8,247,246,253,46,210,2,1,246,10,17,11,236,220,10,14,0,251,7,243,250,247,232,45,2,8,8,0,17,20,12,232,1,249,241,253,46,243,254,20,1,243,245,243,2,15,1,10,255,3,0,0,0,0,0,0,0,0,0,0,0,0,255,0,254,255,240,247,31,187,222,26,7,17,255,250,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,251,236,18,174,22,3,249,9,4,6,2,252,255,0,254,2,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,255,15,251,62,220,4,52,249,5,0,6,1,2,1,1,255,0,3,237,19,236,13,252,245,8,8,240,10,1,242,30,1,223,10,245,45,226,3,252,253,243,7,12,3,234,3,254,252,254,255,0,0,0,0,0,0,0,0,0,0,1,0,0,2,1,11,8,70,48,246,21,4,9,247,247,252,250,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,255,80,2,241,220,246,251,254,8,254,2,0,0,0,0,10,8,248,248,232,12,255,0,20,9,255,254,2,254,12,246,254,243,35,213,44,15,246,231,4,10,253,251,251,7,255,3,1,1,1,1,0,0,1,0,0,0,0,0,0,0,254,255,238,9,49,184,7,248,7,251,2,3,2,254,1,254,253,1,255,4,253,10,19,4,3,20,6,232,6,9,8,15,18,18,220,19,57,245,4,253,8,7,2,253,254,247,241,254,12,252,20,3,11,247,252,22,42,231,1,5,246,237,0,9,240,5,2,10,44,227,17,253,247,254,255,8,14,249,255,16,251,1,249,16,245,12,6,33,241,14,233,2,230,8,2,10,0,251,8,248,38,218,252,5,5,5,1,22,241,7,6,0,4,28,255,244,2,10,254,0,7,17,12,22,252,10,25,29,5,18,4,1,27,217,31,17,2,2,22,233,13,16,1,249,252,251,0,1,0,0,0,0,0,0,0,0,255,0,254,0,242,0,249,245,49,234,252,19,17,217,4,227,10,2,36,252,23,255,254,254,254,254,1,15,251,249,240,248,237,16,253,236,36,247,253,20,39,236,0,2,27,240,10,10,242,234,240,253,13,248,5,247,6,231,7,37,13,246,251,3,251,7,18,234,249,9,251,252,50,245,252,251,251,8,252,254,252,229,14,20,7,247,0,242,246,229,242,239,250,26,10,2,14,244,251,0,8,9,0,228,55,249,244,249,4,246,10,7,244,11,3,5,9,248,2,23,4,254,255,236,254,14,10,247,247,232,10,0,11,244,12,11,49,231,254,29,7,243,21,246,11,239,3,1,248,5,3,0,242,250,18,254,17,247,237,9,251,9,14,6,19,253,27,1,41,235,20,241,33,0,26,14,7,10,3,20,253,244,255,16,15,248,3,248,248,21,251,240,227,4,1,250,252,228,2,31,37,230,254,13,24,8,247,250,227,10,7,2,7,8,246,246,11,13,224,2,16,9,14,23,241,243,24,13,4,229,14,12,31,238,17,23,254,249,242,9,239,250,246,20,9,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,1,89,8,10,250,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,255,4,249,64,206,7,37,2,5,0,0,0,0,0,0,0,0,254,5,3,252,252,253,2,253,3,253,5,4,1,250,255,1,6,254,50,221,249,43,7,249,251,230,24,21,3,241,5,6,248,21,237,33,248,22,245,17,3,0,0,254,1,253,6,255,10,248,4,245,252,251,0,8,252,3,1,252,4,2,8,4,249,5,236,9,234,3,242,1,6,13,23,254,252,249,2,0,11,4,6,3,249,245,249,4,5,5,244,8,2,4,7,253,249,6,252,20,236,16,254,7,6,16,11,12,249,249,5,3,247,252,1,2,5,2,1,247,254,239,252,6,246,7,249,250,247,18,239,12,232,1,255,4,14,9,4,3,2,8,244,242,4,248,252,7,7,6,255,13,247,252,255,1,0,252,15,8,231,2,245,6,251,24,228,251,8,12,254,6,8,253,8,247,255,251,255,251,6,255,255,255,252,8,244,254,243,7,2,1,242,14,238,20,246,12,254,9,1,0,12,254,15,246,26,239,16,245,10,246,9,254,4,248,2,253,4,4,2,253,251,1,238,12,238,21,250,12,250,13,231,18,1,11,247,251,0,10,251,3,253,8,247,7,4,2,247,0,5,0,2,253,9,248,252,16,1,18,226,9,1,6,248,13,13,244,250,255,13,7,6,2,241,253,5,5,1,250,1,251,0,2,240,0,3,252,235,1,254,6,213,18,255,5,255,4,6,254,255,253,255,253,0,1,2,247,0,255,0,254,0,255,255,254,6,0,1,254,233,10,4,7,224,245,238,2,254,249,250,253,253,244,19,3,251,250,16,250,16,2,16,16,8,254,13,8,241,245,2,10,248,2,243,2,227,24,236,19,1,10,252,10,1,2,247,11,255,254,9,251,19,249,16,247,254,238,11,1,1,0,7,253,250,3,4,13,230,10,246,28,249,28,1,7,0,242,5,7,4,252,3,254,3,3,245,7,6,4,0,255,2,255,253,2,250,16,225,13,246,17,250,4,242,4,4,255,246,12,251,1,242,15,0,248,1,251,3,3,9,251,7,236,7,4,11,251,237,3,239,14,244,16,234,18,14,8,254,4,10,12,242,4,253,2,3,7,249,7,250,2,254,252,251,0,251,254,2,1,247,249,245,24,220,247,245,5,7,244,243,18,254,20,1,252,255,246,15,250,14,1,0,2,1,2,247,240,245,7,13,0,232,24,238,18,234,14,245,13,244,11,246,11,249,11,251,252,255,1,5,2,3,255,1,251,7,252,5,250,8,249,8,250,250,18,234,22,5,11,255,6,19,22,8,4,248,20,254,15,250,238,0,223,247,244,255,6,5,2,5,5,251,239,253,253,1,11,240,9,238,11,252,18,20,26,246,8,1,245,8,252,0,7,3,5,2,2,10,254,252,4,252,254,1,252,251,255,246,6,255,18,239,27,253,10,254,12,249,247,1,1,255,7,244,255,249,250,255,8,3,241,8,9,3,249,4,255,1,255,242,6,240,22,2,5,0,5,238,11,6,253,22,236,247,253,6,250,249,241,1,15,248,11,8,253,248,1,248,2,6,254,235,5,237,19,249,4,249,0,248,6,12,5,253,234,243,250,255,253,254,242,6,253,1,248,249,251,250,11,253,246,251,2,255,9,244,15,250,6,237,14,247,11,3,12,239,253,8,252,253,252,1,251,4,5,249,241,249,15,250,251,1,251,253,1,244,20,241,20,242,3,242,9,250,33,243,6,254,8,250,7,251,250,253,253,0,8,253,253,1,254,2,2,6,251,251,254,249,12,238,12,238,10,252,8,2,4,8,9,0,3,248,3,6,244,252,1,25,251,247,6,249,0,247,249,3,251,252,252,238,12,246,11,234,0,241,5,254,2,253,6,252,252,253,241,254,253,21,6,244,245,19,3,3,242,7,0,245,234,246,0,241,2,226,15,239,13,240,8,249,10,248,2,11,3,10,249,7,234,12,246,3,244,6,246,12,246,7,248,5,2,9,1,247,11,242,6,246,21,5,12,251,5,7,21,6,2,254,255,255,4,2,236,238,255,242,3,255,4,249,10,1,11,4,252,234,8,226,13,235,252,4,255,12,9,254,253,2,250,4,243,254,8,8,1,249,3,252,251,255,249,254,8,8,7,8,0,250,252,221,16,243,15,245,14,249,9,255,11,7,0,13,10,255,8,1,1,254,8,255,2,2,3,246,255,7,243,253,249,241,7,240,14,238,17,250,14,3,4,7,253,10,234,5,241,4,252,245,15,241,11,245,20,1,0,2,1,11,253,11,249,244,3,5,16,219,255,15,15,241,10,3,246,1,15,7,241,243,8,9,253,2,12,248,2,251,0,253,4,5,247,252,5,240,26,252,14,234,26,6,253,248,4,21,6,16,252,245,7,246,3,3,7,252,2,247,8,254,2,5,254,252,254,7,255,249,246,4,3,2,252,244,246,252,251,16,19,240,1,2,247,246,0,9,7,248,3,12,8,250,245,243,255,253,236,6,251,242,239,3,251,14,244,244,8,250,231,21,21,10,248,244,4,10,252,3,247,11,9,0,4,2,241,1,242,4,1,0,252,252,247,253,255,6,3,250,6,246,252,14,8,2,253,244,237,0,11,236,1,6,254,229,250,10,239,242,239,247,8,248,3,244,243,16,252,254,12,249,245,2,243,3,7,240,238,255,244,254,1,244,247,254,250,2,9,234,253,252,242,249,7,255,2,249,248,248,15,15,18,15,16,252,219,11,15,244,255,253,3,6,6,0,251,253,251,9,1,1,245,255,248,250,2,3,0,250,7,251,244,13,10,238,252,253,235,6,16,241,249,244,247,1,244,255,10,254,255,253,4,252,1,240,255,12,247,5,9,242,251,9,3,4,26,228,3,250,232,4,5,3,13,5,255,3,255,3,1,1,251,3,0,249,248,249,253,3,251,4,0,252,2,246,250,25,26,250,10,250,248,15,11,250,253,2,249,5,14,9,255,0,244,4,252,246,1,253,3,254,254,250,255,246,8,241,246,19,17,248,0,253,249,7,5,243,255,7,249,1,13,244,243,17,244,1,26,238,253,251,250,4,5,8,1,2,251,3,0,0,0,2,253,254,251,7,13,252,9,0,251,4,255,245,248,252,0,243,2,209,233,248,245,252,4,254,253,238,252,4,5,255,17,244,248,1,244,7,20,244,3,254,245,16,12,250,1,243,240,250,253,253,251,4,244,251,247,10,1,245,0,4,7,7,8,3,255,3,237,32,8,237,248,2,4,244,15,240,3,1,9,254,1,254,8,5,6,252,255,11,248,3,255,4,254,14,32,247,233,246,244,22,15,255,254,10,0,4,6,248,4,241,254,255,252,0,248,4,1,248,3,4,1,239,244,6,248,16,13,236,248,255,240,10,21,237,11,247,251,7,18,250,7,249,238,13,2,254,8,244,247,2,4,251,16,4,0,17,245,12,7,244,5,255,231,30,248,249,250,252,249,9,8,7,3,3,240,8,0,254,254,238,253,252,251,1,4,253,250,6,240,17,6,253,2,247,239,12,11,11,2,236,8,1,1,0,2,254,250,235,243,247,241,255,248,250,248,0,254,245,249,6,247,3,6,8,16,4,251,23,26,246,253,4,0,2,2,252,4,254,244,12,10,245,0,246,240,3,0,0,246,251,240,10,250,27,13,253,4,254,243,15,5,2,5,3,252,13,12,245,249,0,1,11,12,2,13,241,248,9,254,3,8,251,248,4,3,9,3,245,10,14,231,14,8,254,5,244,235,2,10,249,2,253,2,0,2,255,253,251,250,255,240,2,8,255,5,1,245,5,9,249,8,243,244,4,12,252,1,255,255,27,29,10,15,2,250,253,4,235,10,247,245,250,255,247,253,250,253,255,250,11,251,0,254,251,225,11,3,255,5,253,4,5,7,246,5,246,243,4,12,241,254,2,249,1,247,253,246,253,249,17,248,251,36,8,249,248,236,12,8,1,255,3,0,1,4,246,3,1,4,254,253,254,253,246,4,255,249,3,2,243,253,251,9,22,6,233,3,246,249,17,17,18,242,248,248,2,4,248,2,253,248,6,4,255,7,0,0,253,0,244,253,253,246,241,253,9,3,233,247,243,238,12,13,254,0,1,8,255,2,249,244,251,14,2,1,234,6,246,248,247,28,249,242,253,1,2,255,13,7,254,249,1,253,6,9,253,254,4,254,2,1,246,254,254,234,254,249,246,251,245,229,244,240,4,249,2,250,253,1,8,0,254,12,253,252,58,15,246,252,254,2,254,0,254,250,2,4,255,1,252,1,255,251,252,253,3,1,10,255,0,5,21,7,242,6,253,240,15,17,240,13,3,250,252,6,244,251,1,252,249,248,2,3,250,6,255,248,5,4,250,254,248,245,15,10,0,8,250,241,33,8,254,18,241,245,5,255,0,15,241,252,252,255,10,7,243,4,252,0,8,3,249,254,0,254,0,254,252,251,242,240,12,38,7,12,6,252,0,255,0,3,254,250,0,2,247,1,0,255,0,254,4,1,248,252,18,1,14,5,244,253,20,239,5,19,245,248,11,253,3,9,249,248,9,239,2,15,246,245,5,251,7,15,250,254,249,2,38,5,19,16,251,4,243,236,0,4,252,6,4,2,249,6,248,254,251,249,6,3,252,253,254,253,7,250,252,0,245,244,8,241,253,14,249,234,245,2,22,14,237,2,237,250,1,3,238,14,2,250,254,248,253,250,5,249,248,252,1,1,8,7,25,235,12,250,251,252,246,6,0,10,1,244,18,251,241,4,1,14,255,5,8,249,1,249,253,9,10,1,255,0,9,10,32,241,8,2,11,249,238,248,2,250,247,240,253,3,255,3,1,251,4,254,1,248,0,250,253,245,1,5,0,0,14,0,23,231,22,3,7,10,0,254,7,8,0,10,0,0,3,2,3,246,0,10,0,249,0,10,255,251,249,1,255,2,12,0,25,238,251,252,13,246,3,250,7,21,0,240,3,246,250,5,249,253,2,5,3,250,4,9,248,12,254,3,2,4,31,15,27,236,10,249,15,246,9,248,4,251,3,253,5,6,11,254,244,254,6,254,1,2,255,255,1,1,3,1,1,2,12,252,13,233,12,250,2,4,253,13,6,249,5,237,249,18,1,249,7,1,16,249,3,0,3,0,244,8,245,9,4,7,29,1,3,234,251,6,0,12,242,11,1,6,253,4,6,254,4,243,12,1,1,3,245,9,246,255,249,16,245,255,3,9,4,4,36,233,251,248,241,1,250,3,13,255,251,249,4,9,2,245,253,5,1,3,250,255,252,252,254,2,3,255,251,254,19,10,6,239,2,252,254,252,253,13,2,2,243,249,253,245,9,250,1,247,251,4,251,247,238,249,245,9,4,245,8,4,16,253,9,240,18,254,244,240,245,11,238,16,243,6,2,8,3,8,252,240,10,245,255,253,248,5,247,252,9,252,0,253,14,15,3,233,251,7,248,250,2,17,2,12,248,244,13,255,247,3,1,1,19,15,4,255,1,2,253,2,253,1,5,3,32,5,246,209,251,255,4,11,249,0,2,254,1,249,6,252,6,2,252,254,2,254,0,252,1,250,251,2,254,255,253,252,20,8,10,235,249,247,240,12,1,4,6,251,9,245,249,4,245,28,253,2,4,250,10,248,251,251,247,9,254,255,6,251,38,3,23,231,250,238,3,246,248,6,246,1,246,2,2,0,249,2,252,5,255,8,253,0,3,3,255,1,0,252,252,0,20,5,16,234,24,238,2,244,242,249,253,10,2,7,246,2,248,1,8,255,4,1,4,254,5,247,238,248,243,5,245,10,14,8,244,240,9,245,253,250,231,249,6,5,249,240,10,2,249,255,247,253,16,4,3,3,253,253,241,13,253,4,13,249,16,247,19,233,7,237,253,251,241,11,235,21,240,18,255,6,10,246,18,242,16,241,6,251,247,5,239,13,246,13,0,10,8,252,4,232,8,235,238,9,245,4,250,17,5,247,254,254,2,15,254,253,254,1,7,243,15,246,248,245,3,3,255,255,14,17,6,224,5,239,254,0,15,255,251,16,1,251,254,9,253,8,4,254,254,252,253,1,0,7,253,4,251,0,249,2,24,6,22,244,8,3,242,4,249,8,6,5,6,1,6,244,15,10,4,11,9,6,249,252,10,247,2,255,251,11,15,3,17,12,3,233,5,255,254,1,247,255,253,1,8,1,251,17,11,0,254,245,7,4,0,229,249,1,2,248,9,7,5,3,12,10,12,246,252,5,255,2,232,5,248,2,6,239,19,5,12,254,16,249,250,242,4,1,253,13,240,5,255,4,1,1,31,9,11,239,10,253,249,7,1,2,2,4,253,255,11,4,251,248,1,4,15,250,228,1,8,3,250,5,17,254,2,252,11,19,16,230,0,249,249,2,243,241,244,9,253,27,8,4,250,1,4,250,11,255,250,249,253,0,250,4,250,249,253,255,10,18,16,224,19,247,252,253,249,8,8,253,245,254,250,240,13,13,250,255,10,254,254,247,0,253,9,4,11,254,250,6,9,4,19,223,4,7,244,36,253,255,8,254,2,248,247,252,248,0,1,255,0,252,252,3,0,3,6,0,250,2,0,254,25,7,15,244,2,232,255,24,252,4,9,0,254,247,4,6,3,13,253,1,5,255,253,251,255,7,254,3,4,4,1,0,19,6,8,236,9,247,5,252,243,7,11,253,5,243,247,6,245,255,0,4,11,26,3,6,249,12,6,253,1,247,7,1,15,6,19,233,253,247,3,16,250,252,6,251,246,1,16,242,2,0,2,243,253,8,250,3,1,1,2,251,12,252,248,253,14,4,16,236,1,12,0,6,253,9,4,16,10,240,5,7,5,252,252,238,253,245,252,4,249,3,13,7,3,3,2,249,22,3,255,226,18,253,247,9,254,11,240,254,242,12,0,4,251,4,255,3,236,12,4,246,254,254,244,244,10,6,11,253,15,7,2,235,5,4,9,247,223,7,7,3,250,242,248,10,12,0,2,255,5,4,254,0,249,0,2,4,0,1,253,8,249,0,12,3,0,250,8,252,0,2,14,241,2,249,225,253,14,0,14,241,255,252,241,10,1,253,1,2,5,2,248,1,254,5,1,0,253,3,3,250,255,2,252,1,237,0,245,18,11,10,21,5,6,2,10,3,250,0,254,13,5,255,254,9,247,1,251,0,0,241,8,4,8,3,8,12,243,254,217,254,4,252,5,253,252,3,253,3,10,5,3,2,253,5,254,8,247,6,6,248,12,244,23,238,4,241,251,2,236,13,249,7,7,244,14,244,6,1,1,253,248,9,0,1,249,3,7,250,238,13,4,3,246,226,246,250,242,1,249,252,221,5,231,11,9,8,19,252,249,253,238,248,1,5,10,252,242,247,3,252,250,255,4,247,247,4,20,0,0,3,11,7,240,239,236,11,250,242,1,4,19,2,248,6,241,3,6,251,242,3,7,2,1,6,254,248,251,253,3,248,21,1,3,16,242,254,247,252,13,254,18,14,14,19,243,5,246,2,253,3,5,5,1,255,255,251,250,254,245,249,5,252,5,255,0,3,253,2,237,18,16,4,14,234,254,245,234,1,255,11,1,2,11,246,7,244,1,4,5,255,247,251,1,12,5,6,12,9,232,23,1,20,14,245,13,5,254,254,5,6,2,1,247,6,10,5,252,11,255,255,1,7,253,252,8,240,15,255,249,9,234,245,245,10,16,9,254,4,13,10,6,16,4,7,1,248,249,242,249,4,1,3,250,0,15,247,252,0,4,6,12,9,250,251,234,17,7,245,15,251,1,3,237,0,241,253,16,5,5,249,245,12,254,255,13,2,4,232,37,251,254,250,12,7,254,233,252,9,2,253,3,2,3,3,242,11,0,252,254,254,3,10,246,4,2,9,8,250,228,14,28,245,18,245,0,2,254,4,244,3,6,0,7,249,250,2,5,255,255,255,5,2,3,0,253,9,249,14,5,246,253,7,4,251,7,248,249,4,244,14,240,25,3,0,1,251,12,246,0,246,0,12,12,17,12,10,255,0,252,254,5,254,239,253,5,251,7,239,1,5,252,4,236,0,11,241,13,248,10,1,1,5,244,9,248,0,6,255,245,4,253,12,13,241,249,249,0,5,33,3,3,250,243,249,241,10,3,3,3,251,2,7,255,0,244,2,11,250,247,0,5,11,248,5,10,249,242,252,13,0,18,253,250,7,1,250,0,21,8,249,10,248,253,17,247,0,251,1,4,8,253,11,251,0,248,8,253,248,8,245,16,240,17,0,8,16,239,10,240,10,248,6,11,0,10,7,4,5,7,251,251,250,249,251,255,16,250,0,6,1,248,248,8,249,251,246,245,8,237,6,249,13,5,253,4,248,7,255,238,9,0,251,6,26,3,8,2,4,254,254,23,254,236,2,7,249,250,241,3,9,237,254,246,7,254,7,9,11,0,4,252,6,9,254,4,253,4,3,2,8,250,12,10,246,249,4,17,11,250,1,12,11,238,8,244,4,1,13,6,243,23,9,251,8,254,251,1,3,0,254,252,4,7,1,7,239,248,8,255,249,5,250,4,253,240,9,232,18,253,10,13,245,250,245,252,10,0,11,8,2,6,251,245,4,252,1,251,246,0,253,9,254,4,255,1,5,215,246,249,4,253,3,1,0,244,4,253,0,2,255,254,251,3,2,249,5,254,1,4,4,253,250,1,0,12,251,11,0,239,253,255,11,4,1,27,244,0,242,2,241,253,247,0,249,253,15,248,6,250,4,9,2,4,3,7,246,28,1,254,48,7,0,246,10,1,247,2,255,0,3,251,5,252,254,7,7,1,3,2,5,253,3,255,3,247,0,255,3,2,250,39,242,244,5,237,21,7,250,4,255,252,0,252,1,0,247,1,10,0,254,0,7,4,2,227,12,5,253,16,250,15,243,252,255,243,22,240,17,16,4,9,252,4,250,252,11,248,7,8,4,3,253,249,243,0,3,3,250,252,0,9,0,5,0,10,10,4,243,244,16,23,252,244,250,252,20,2,0,252,23,1,8,11,252,251,15,250,4,241,247,255,237,12,226,239,252,1,243,243,4,253,26,5,231,11,242,250,243,0,249,9,2,8,255,248,1,248,13,1,6,1,252,252,1,2,0,253,2,10,6,250,254,245,4,32,15,15,209,248,3,244,4,251,4,255,0,251,5,1,249,2,255,0,0,255,250,0,250,4,252,5,9,251,1,253,51,4,251,4,242,255,252,253,1,252,255,0,2,248,0,1,2,0,4,254,249,254,247,6,248,11,253,250,3,245,248,244,8,11,5,19,3,232,19,242,11,251,238,248,244,251,252,255,4,16,9,10,14,238,254,238,229,10,251,12,14,4,0,254,250,244,249,255,3,4,7,11,10,5,251,249,240,253,250,6,9,7,15,247,10,237,4,251,219,254,252,8,2,4,255,1,9,251,251,244,1,255,248,3,253,4,6,9,3,3,255,2,4,13,17,3,9,249,249,241,239,248,243,252,248,19,2,16,25,7,15,2,16,251,250,246,247,249,250,254,249,7,2,4,5,24,7,9,8,243,254,0,252,1,243,3,6,7,10,252,15,5,7,252,5,251,3,13,249,5,15,245,254,7,5,8,6,17,6,241,23,254,255,250,254,0,252,11,253,12,15,6,248,241,10,247,7,255,245,2,248,252,3,4,246,4,4,11,1,21,12,253,6,248,8,245,248,251,251,3,7,255,251,12,15,246,245,3,15,8,4,2,241,0,14,1,248,255,3,10,249,16,12,5,13,250,15,233,0,239,247,0,4,247,13,6,18,0,0,252,255,0,14,5,255,8,252,248,250,5,254,254,0,14,16,255,12,241,247,250,236,4,6,8,9,3,1,247,252,255,245,9,11,244,1,242,249,2,248,11,9,252,10,4,240,13,10,3,7,0,248,223,250,4,252,19,254,14,6,5,7,6,253,255,246,246,247,4,253,5,9,2,2,10,9,254,253,11,10,25,18,255,250,235,235,245,240,6,5,14,4,8,7,0,246,249,247,251,252,3,255,1,6,255,6,254,2,253,247,15,9,5,22,239,15,247,7,7,247,13,9,10,255,8,253,254,6,1,17,8,242,7,253,12,9,1,0,1,251,17,238,25,19,239,12,252,246,1,243,237,249,253,9,6,254,3,1,4,254,245,242,255,249,251,247,7,255,253,4,251,1,0,255,20,8,253,246,232,3,250,254,0,244,14,6,7,11,4,7,244,251,248,246,5,255,252,4,16,7,242,6,255,254,249,245,16,18,17,1,241,250,251,253,255,237,8,254,2,8,12,237,244,8,0,253,255,255,4,242,9,255,244,255,249,10,253,5,18,12,249,7,0,253,243,0,255,252,9,254,6,255,0,1,15,235,1,248,25,237,13,247,2,12,5,249,253,255,253,1,13,16,252,9,254,2,255,237,249,252,18,250,14,18,251,4,250,253,237,242,255,244,10,6,7,17,244,243,246,252,5,4,27,17,4,14,247,254,252,248,0,250,14,245,249,2,253,253,254,253,243,12,16,1,251,247,246,245,254,3,249,5,11,249,7,17,240,254,242,228,249,248,15,246,7,15,8,17,13,255,4,249,244,245,0,0,2,3,253,7,250,6,1,240,1,254,23,11,247,15,233,252,250,252,2,247,249,9,248,3,243,252,8,18,250,254,1,251,6,242,251,254,250,251,253,254,4,251,12,13,18,18,221,2,7,239,3,245,6,9,253,254,10,252,3,3,254,249,0,2,252,0,252,0,250,5,10,4,253,255,19,11,1,20,242,4,247,243,254,11,0,17,255,255,255,255,251,248,0,5,255,248,5,255,3,2,244,21,254,232,5,7,15,15,241,17,242,234,3,252,245,253,249,1,18,10,1,10,250,253,8,2,249,0,254,1,1,2,247,254,1,2,253,4,45,13,8,17,251,2,240,2,8,254,8,241,4,5,255,7,250,254,250,2,253,0,0,247,255,7,2,3,253,253,255,5,1,18,248,18,244,246,3,4,234,244,20,8,253,9,2,10,246,253,9,3,6,253,10,255,253,2,254,4,2,3,253,238,9,10,251,9,221,235,238,240,255,244,250,249,241,237,12,4,4,9,249,2,14,1,4,0,255,6,249,2,1,1,252,4,31,8,239,35,248,1,251,250,249,250,10,254,253,6,9,3,250,254,3,3,5,253,0,6,0,1,251,253,254,252,255,0,18,4,248,7,248,241,255,240,12,18,3,19,2,4,8,8,0,251,248,244,10,251,0,1,0,4,253,16,11,11,254,250,27,15,239,246,233,234,255,242,252,249,20,254,249,6,15,251,32,4,9,245,253,248,11,252,255,252,248,250,252,251,254,249,22,4,249,2,241,245,239,246,2,0,15,11,7,12,248,6,246,238,250,244,7,3,22,3,249,14,251,254,243,249,255,249,18,13,9,24,252,237,247,245,13,8,2,4,255,8,14,10,244,0,0,5,10,5,4,255,5,1,255,11,2,252,0,247,15,19,251,1,252,246,248,229,6,8,5,10,4,11,5,251,245,0,245,242,252,247,248,248,6,247,4,251,255,1,5,252,18,1,243,14,242,9,241,249,12,1,13,252,236,12,10,12,244,7,1,243,10,250,5,253,4,8,10,243,253,250,9,253,19,242,5,248,250,2,251,5,253,255,228,11,18,250,252,254,11,14,213,214,9,2,20,233,6,32,0,5,0,6,9,5,8,11,242,255,7,12,249,2,240,2,10,253,255,249,249,255,1,246,196,233,238,42,243,9,18,245,0,1,0,2,251,1,251,255,2,0,3,253,3,254,250,0,253,253,7,2,0,254,254,3,222,241,37,47,10,20,9,1,3,235,231,223,242,8,5,6,2,254,254,254,6,5,251,7,253,1,251,243,9,3,239,237,254,177,244,249,248,250,254,254,255,255,249,243,6,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,0,3,4,169,6,245,16,247,255,8,0,5,0,1,2,1,251,6,2,232,5,247,249,0,7,3,253,16,242,240,0,18,15,247,242,228,239,53,14,250,228,255,253,246,249,242,19,241,0,0,0,0,0,0,0,0,0,0,0,0,0,0,253,0,243,0,203,3,234,63,19,16,1,245,0,253,0,253,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,250,213,213,254,65,243,252,9,1,1,2,1,0,0,1,0,1,0,0,255,0,1,1,0,0,1,2,255,255,253,255,233,1,195,201,3,228,250,252,252,8,2,1,1,255,0,0,0,1,255,1,255,0,255,0,1,255,0,1,255,0,247,252,208,237,204,210,11,244,5,242,0,246,0,0,255,254,255,0,0,253,255,252,2,255,249,3,1,3,255,1,253,0,249,0,3,249,195,205,252,235,240,235,245,14,249,8,3,251,1,2,0,0,0,1,0,0,255,0,0,0,0,0,1,255,9,253,56,245,250,189,255,13,0,7,1,247,255,255,0,0,1,0,14,9,254,14,246,246,9,251,1,248,233,30,8,249,23,8,2,10,255,229,239,57,22,4,251,2,244,250,2,249,252,247,1,5,12,254,254,253,2,253,6,0,4,254,248,250,0,16,241,29,201,227,232,29,3,10,6,13,10,251,21,11,242,5,4,2,26,250,10,11,233,246,229,236,3,232,245,246,243,25,246,5,247,220,249,43,3,243,6,13,254,0,1,3,253,252,255,0,255,0,0,0,0,255,1,0,255,0,0,0,255,1,244,12,230,192,241,29,37,249,253,244,251,14,8,248,246,254,19,252,245,240,8,14,5,19,3,22,245,235,255,250,245,11,10,232,233,216,248,20,17,5,13,250,3,14,236,248,3,28,2,244,10,242,238,26,234,4,254,5,235,8,3,1,19,0,244,24,242,216,15,29,241,6,15,1,237,2,4,7,244,253,0,17,13,7,251,245,2,237,3,38,235,253,250,252,7,1,1,251,216,246,254,35,8,8,246,248,247,33,4,4,0,254,254,244,7,29,232,2,16,255,249,16,10,254,254,254,13,254,219,15,234,216,245,33,10,255,8,10,6,8,9,0,244,2,15,248,247,254,7,239,7,19,14,4,12,27,11,10,4,11,241,14,243,208,5,18,0,247,220,245,2,4,5,5,241,244,244,0,3,4,7,251,5,242,232,238,250,241,248,236,1,249,223,228,216,218,238,246,251,17,244,4,3,251,5,243,4,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,253,247,207,196,251,45,255,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,253,247,207,196,251,45,255,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,255,0,0,0,3,254,9,227,245,55,8,32,220,243,249,37,4,11,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,255,217,252,226,63,28,239,250,10,7,242,247,11,9,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,13,254,206,224,22,51,4,7,6,11,236,243,9,251,21,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,253,247,207,196,251,45,255,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,253,247,207,196,251,45,255,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,255,0,0,0,3,254,9,227,245,55,8,32,220,243,249,37,4,11,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,255,217,252,226,63,28,239,250,10,7,242,247,11,9,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,13,254,206,224,22,51,4,7,6,11,236,243,9,251,21,252,248,2,1,22,225,250,231,253,253,1,241,245,254,253,4,243,247,15,238,37,249,219,12,243,245,231,246,245,234,7,16,7,14,10,4,246,255,251,249,253,16,13,251,241,5,11,255,8,229,7,244,49,17,234,9,254,247,255,2,241,255,41,238,239,252,247,241,253,3,4,4,2,7,253,249,248,251,17,237,249,36,247,218,17,1,208,11,238,243,254,248,4,246,251,21,11,15,243,4,2,1,251,254,1,246,7,255,3,250,0,11,245,8,20,239,51,239,215,2,15,4,8,254,16,224,255,17,6,248,8,238,251,4,6,253,8,0,252,2,0,255,252,5,8,30,30,248,70,2,8,2,0,7,1,13,255,250,249,245,2,248,249,9,246,243,6,245,242,13,25,230,5,2,251,251,5,248,4,0,33,12,218,252,6,13,6,25,34,255,25,237,251,18,3,239,4,248,7,20,1,255,5,251,254,248,8,221,15,24,43,251,51,5,244,253,1,254,3,253,253,247,8,247,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,10,24,76,254,234,11,255,4,33,4,1,255,1,2,0,0,255,0,1,0,1,0,1,0,0,0,0,0,1,2,0,24,13,32,70,26,5,235,247,250,241,2,254,2,4,1,1,5,252,245,4,252,22,10,254,13,245,252,235,239,0,249,4,10,222,11,52,2,210,251,0,0,255,2,4,247,1,1,249,0,1,1,0,255,0,1,0,1,1,0,1,0,0,253,1,248,9,255,64,243,195,253,3,251,10,1,3,255,255,255,255,0,1,0,255,0,255,0,0,1,0,0,0,1,1,2,1,10,254,225,79,246,27,0,255,3,8,1,1,0,255,0,255,3,12,10,26,237,10,247,6,252,241,10,3,240,6,11,237,3,10,18,44,5,226,5,247,21,4,20,10,14,231,8,239,0,0,0,1,255,0,255,0,1,0,1,1,0,0,250,254,8,248,13,69,26,237,231,239,16,6,244,22,2,250,9,5,0,255,0,1,0,255,255,0,0,1,254,1,0,0,252,255,222,241,223,56,9,214,9,10,6,9,248,245,0,250,15,5,10,2,242,253,241,221,255,7,238,14,8,255,241,230,6,241,238,22,9,33,0,224,247,3,245,7,4,255,5,30,9,1,4,15,0,6,251,245,9,6,6,6,14,2,255,10,232,231,254,252,255,37,2,227,14,247,22,17,254,33,10,231,11,245,0,5,2,18,244,21,22,33,249,21,247,249,7,241,249,16,7,0,242,44,10,231,5,252,15,248,10,252,5,9,255,16,3,13,12,12,8,25,233,8,234,253,238,248,15,12,9,19,0,0,247,49,229,241,247,241,12,248,240,249,13,5,13,2,12,250,7,254,20,247,242,12,13,251,239,22,248,252,2,7,243,254,241,43,251,226,27,4,10,229,5,27,246,246,238,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,10,238,70,254,204,255,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,10,238,70,254,204,255,249,0,0,0,0,0,0,0,0,15,243,236,16,2,13,5,245,248,251,253,2,24,233,30,249,11,30,241,43,5,241,15,253,242,1,233,8,3,9,4,245,0,255,0,1,0,255,255,0,0,1,254,1,0,0,252,255,222,241,223,56,9,214,9,10,6,9,248,245,0,250,15,5,10,2,242,253,241,221,255,7,238,14,8,255,241,230,6,241,238,22,9,33,0,224,247,3,245,7,4,255,5,30,9,1,4,15,0,6,251,245,9,6,6,6,14,2,255,10,232,231,254,252,255,37,2,227,14,247,22,17,254,33,10,231,11,245,0,5,2,18,244,21,22,33,249,21,247,249,7,241,249,16,7,0,242,44,10,231,5,252,15,248,10,252,5,9,255,16,3,13,12,12,8,25,233,8,234,253,238,248,15,12,9,19,0,0,247,49,229,241,247,241,12,248,240,249,13,5,13,2,12,250,7,254,20,247,242,12,13,251,239,22,248,252,2,7,243,254,241,43,251,226,27,4,10,229,5,27,246,246,238,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,10,238,70,254,204,255,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,10,238,70,254,204,255,249,0,0,0,0,0,0,0,0,15,243,236,16,2,13,5,245,248,251,253,2,24,233,30,249,11,30,241,43,5,241,15,253,242,1,233,8,3,9,4,245,16,238,7,252,31,241,247,243,20,244,250,0,12,250,254,4,3,253,255,0,1,3,3,254,1,6,4,0,253,2,251,1,38,251,243,252,8,241,11,1,2,252,255,9,13,4,244,249,0,254,7,2,250,254,253,254,3,252,6,15,1,1,245,254,47,234,9,230,3,251,2,249,4,254,2,254,3,0,3,252,3,253,2,253,7,253,255,1,1,251,5,0,2,251,253,254,14,240,2,250,7,254,249,252,252,249,14,253,7,237,242,239,227,6,26,16,251,13,252,255,21,14,1,3,250,0,249,255,29,245,5,253,4,11,4,246,1,234,253,246,5,4,2,8,254,249,244,244,248,253,238,254,247,251,255,253,2,242,242,7,28,244,5,3,9,249,0,254,2,1,4,0,249,253,254,4,4,14,8,255,252,14,249,17,254,254,247,2,19,249,9,248,31,238,234,8,15,251,246,241,1,10,6,7,6,248,2,255,12,253,3,255,1,5,250,252,0,1,7,246,254,4,253,252,53,226,252,12,2,3,253,253,0,1,6,5,251,252,249,1,0,2,1,3,1,5,0,2,2,255,0,4,2,0,254,0,27,238,253,254,4,248,3,254,245,2,10,248,248,252,0,254,8,0,9,0,240,11,1,250,13,253,246,243,241,25,1,0,35,251,255,248,23,11,242,253,2,254,8,250,17,254,7,0,254,10,239,13,254,254,11,11,242,2,254,253,248,255,244,251,29,247,7,3,2,246,0,3,9,0,253,5,1,246,10,251,3,6,236,247,250,252,1,0,12,17,248,9,3,255,247,0,15,240,18,237,16,241,17,238,13,240,17,242,15,247,13,239,9,249,4,251,3,252,253], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1111760);
/* memory initializer */ allocate([250,7,247,7,254,7,247,9,21,246,7,254,12,249,13,239,11,254,20,3,5,245,250,250,241,0,247,5,245,7,255,7,8,246,247,3,251,9,248,254,23,234,15,251,16,252,253,244,9,3,255,254,248,2,254,240,3,4,254,250,249,12,248,2,242,2,249,11,254,6,252,255,34,239,252,8,4,250,1,8,4,16,3,6,12,255,255,241,6,4,249,250,6,0,2,1,254,2,3,3,253,254,8,250,18,238,2,254,10,1,18,233,253,246,0,4,20,237,253,252,2,8,6,1,253,1,1,3,5,255,245,3,249,5,255,1,15,242,2,3,10,248,12,243,13,241,6,248,252,246,14,247,24,2,249,238,13,245,8,14,250,254,3,255,252,7,249,252,20,244,13,5,255,246,15,250,8,255,253,246,17,0,250,237,2,255,8,253,240,0,253,2,254,0,8,247,0,1,246,247,32,0,247,251,255,5,13,245,8,3,11,245,0,248,254,242,7,10,6,251,1,10,2,12,246,4,4,6,4,0,249,246,16,242,10,249,11,245,11,245,18,243,8,241,16,245,13,247,8,249,12,245,7,250,3,251,9,251,4,255,7,252,8,253,24,229,255,5,8,251,12,7,4,253,3,255,247,245,243,251,10,0,243,7,1,251,4,247,7,253,13,2,251,253,239,254,23,237,15,1,246,238,244,250,8,253,12,0,244,246,252,252,8,246,4,2,254,248,13,253,254,250,2,253,5,254,2,11,25,244,4,2,24,253,3,250,14,11,0,235,253,253,1,248,7,0,0,3,3,250,249,6,2,1,252,5,255,10,254,9,24,248,250,7,16,244,13,255,11,235,2,250,3,244,0,9,4,11,249,1,4,1,248,3,3,250,3,3,0,248,8,4,25,235,13,14,13,238,4,253,0,251,252,5,253,0,4,12,7,3,5,251,2,254,3,246,2,247,241,6,1,7,251,1,23,240,254,10,4,255,3,1,32,3,251,254,9,10,255,252,250,2,9,255,14,12,250,255,239,254,252,247,249,250,248,3,50,248,5,2,245,10,0,0,6,253,7,0,253,254,253,0,6,252,2,251,247,0,3,10,1,249,254,253,250,247,1,254,28,239,0,254,2,247,1,5,252,255,0,0,19,229,5,244,7,242,253,250,10,254,252,254,4,251,254,249,1,7,247,4,22,237,250,250,3,234,3,5,20,248,242,251,1,1,20,2,16,6,3,14,4,3,5,1,5,249,246,250,3,250,1,242,29,242,248,13,8,246,250,4,4,250,5,249,1,12,14,11,249,1,2,247,245,247,0,4,255,7,10,4,4,20,255,245,18,247,4,1,7,227,12,1,255,247,254,255,254,2,9,248,243,5,4,243,252,2,251,249,250,14,246,222,253,1,253,243,38,247,24,8,11,4,250,245,254,244,1,1,245,248,251,254,241,248,8,0,1,249,5,4,255,8,254,11,253,255,251,251,236,11,252,24,245,1,15,4,0,228,246,255,10,10,250,5,250,2,7,254,1,254,250,253,249,1,2,12,255,7,0,254,247,10,233,27,252,239,20,250,14,239,5,255,5,247,249,5,250,4,254,9,0,8,0,1,253,253,251,248,5,254,254,12,246,19,4,9,1,240,17,254,9,227,240,245,252,7,251,4,255,253,3,2,3,252,5,244,254,6,5,252,4,1,4,10,236,10,232,14,251,11,9,0,16,236,10,251,250,250,255,2,252,5,240,8,254,5,5,245,9,245,4,245,255,255,4,3,247,11,3,19,24,4,5,242,30,239,252,254,239,7,2,3,1,3,249,252,2,253,1,4,255,255,3,244,254,3,253,10,237,18,11,19,19,19,10,4,13,6,5,4,8,3,254,12,250,254,7,250,15,12,16,16,18,253,252,236,0,10,247,253,235,9,20,12,0,253,5,247,15,243,5,251,250,24,2,9,251,2,249,2,5,7,251,2,15,3,1,255,252,254,7,0,238,16,13,15,2,246,14,245,4,245,5,12,12,20,8,30,2,11,247,7,0,253,240,251,250,5,252,235,0,5,6,1,230,8,243,9,6,246,2,245,7,252,6,237,245,250,244,16,0,5,249,8,5,6,17,247,10,246,5,253,245,2,4,10,245,17,253,22,251,18,3,1,4,251,14,229,5,249,252,251,246,11,1,15,1,1,250,251,10,234,249,249,241,13,252,5,239,14,249,13,3,0,13,250,9,242,234,255,1,19,14,253,4,243,243,2,252,8,254,254,13,244,13,244,249,251,253,6,239,17,255,33,6,3,9,240,3,242,248,6,239,8,3,13,8,250,3,1,254,0,254,8,4,9,13,246,4,239,0,250,236,7,7,21,1,253,7,253,254,244,9,249,2,253,14,1,255,249,12,246,5,236,11,254,0,232,239,6,6,252,3,255,248,10,6,7,255,250,28,250,10,223,1,236,0,244,10,1,250,8,253,255,246,8,5,0,10,254,8,16,251,253,249,4,239,13,3,15,1,251,27,251,6,250,12,2,252,8,255,253,254,12,241,3,4,1,2,247,0,240,235,2,252,16,249,4,241,20,8,17,5,242,15,245,21,245,13,243,2,241,243,1,251,5,2,10,247,4,255,3,2,252,13,251,1,252,5,253,235,8,2,16,255,2,15,240,13,244,244,249,248,2,249,11,248,5,2,249,16,252,1,249,3,241,6,251,248,2,248,5,241,17,250,3,253,3,9,249,14,233,11,1,255,4,7,6,255,242,7,6,248,5,1,241,10,247,2,253,255,4,246,252,246,18,3,11,1,4,14,242,7,252,15,246,10,245,10,252,5,242,10,4,15,244,15,243,20,241,14,241,8,245,4,250,249,23,2,20,7,8,19,251,9,240,248,239,251,1,5,250,248,1,250,252,10,6,6,2,245,252,0,2,4,7,9,252,241,20,251,22,11,248,9,251,10,243,248,8,2,254,253,7,6,10,1,2,251,247,1,10,16,234,249,0,7,7,6,1,230,19,251,3,5,25,18,251,9,242,248,250,254,250,2,3,248,254,249,7,253,7,3,4,248,0,1,248,252,254,254,1,236,14,246,6,253,7,8,224,254,249,254,246,16,244,247,15,254,251,250,2,249,5,9,1,6,249,255,0,254,252,249,3,242,16,4,11,248,1,23,252,17,243,246,1,12,9,12,252,7,255,255,5,248,250,3,3,250,253,238,0,18,20,4,254,223,19,246,30,15,2,253,255,252,242,7,249,255,7,248,9,255,253,251,2,2,4,0,5,0,0,2,3,3,253,253,4,250,20,0,5,17,246,18,239,9,240,4,243,250,2,242,14,228,9,244,25,252,7,7,248,6,250,254,246,2,245,255,2,244,14,12,52,253,5,251,4,8,243,2,251,252,2,254,255,254,3,3,5,2,3,0,1,251,2,252,253,1,251,254,0,243,6,9,24,0,8,14,241,18,247,245,248,3,15,254,252,247,4,253,12,14,243,11,252,2,252,0,250,250,250,242,255,246,28,3,12,9,3,11,228,6,245,249,4,0,7,8,247,0,250,0,240,4,7,4,4,7,3,4,249,0,253,246,6,245,14,254,19,255,255,7,9,254,229,10,242,15,252,12,252,2,254,250,12,250,0,251,252,251,1,3,245,5,247,3,248,238,7,13,16,252,3,9,246,10,246,253,234,252,244,3,240,0,253,240,8,245,1,10,249,15,3,0,255,243,8,1,6,236,10,246,10,8,255,6,0,16,244,9,246,255,251,252,243,13,16,248,12,254,14,18,13,0,240,2,251,251,251,252,3,242,5,249,239,5,243,23,20,252,255,1,250,13,5,255,4,242,254,249,8,3,2,2,249,2,255,4,7,3,247,255,251,237,3,232,228,247,249,19,3,2,19,7,5,243,8,241,239,3,245,4,13,3,2,255,253,252,252,2,0,251,250,6,2,239,18,226,236,254,253,1,15,255,245,6,252,11,11,252,251,246,0,0,1,3,249,8,2,5,1,5,251,1,6,4,1,250,1,226,231,255,248,254,247,239,16,3,255,254,247,250,249,253,12,6,252,246,0,10,248,250,251,253,245,252,0,255,253,255,255,222,228,1,246,2,9,4,16,2,6,14,17,0,7,252,4,4,4,0,1,255,251,8,1,252,1,247,254,5,6,245,14,1,225,249,232,9,7,6,5,243,1,255,3,4,255,254,248,250,3,5,252,250,7,254,5,3,3,0,0,251,2,231,8,245,238,1,252,8,253,252,15,6,251,8,2,3,4,252,5,6,8,249,6,1,245,241,243,9,252,242,10,12,7,236,11,241,231,3,4,18,13,252,251,247,255,251,254,254,249,16,5,252,251,249,254,253,247,11,254,0,249,239,250,245,6,245,18,251,236,241,253,9,11,236,12,5,5,11,253,7,1,10,250,253,253,3,3,14,249,10,239,9,245,254,250,7,244,236,8,242,239,247,243,253,0,229,242,253,242,4,3,6,250,7,4,23,9,11,9,3,252,9,2,4,255,250,1,248,245,247,14,2,219,249,13,6,245,250,9,18,245,250,2,12,4,255,3,1,254,254,1,247,252,254,253,3,5,250,0,254,248,227,8,255,243,254,8,23,2,246,7,13,250,251,11,13,0,246,243,11,244,246,6,4,6,4,3,6,251,247,254,255,3,238,6,246,201,252,245,254,0,1,253,247,250,3,254,255,6,3,255,3,1,252,249,254,6,3,254,255,253,254,0,4,1,242,5,3,235,248,240,252,254,245,27,15,236,3,0,1,1,2,251,251,4,1,247,5,253,3,0,252,254,245,252,253,7,239,255,247,239,248,238,12,243,247,13,253,3,3,253,1,254,0,16,247,6,12,9,5,11,2,241,1,252,240,7,252,244,238,8,250,245,248,249,13,7,1,6,8,255,21,252,14,15,18,252,253,15,0,9,4,7,3,255,9,254,0,7,248,2,246,7,238,227,3,12,12,9,11,4,255,241,1,255,8,254,254,10,241,255,0,6,12,250,255,10,250,253,245,252,9,250,242,14,247,235,244,254,255,249,251,246,5,248,0,6,9,245,11,253,251,3,8,15,254,252,234,4,250,12,2,13,6,249,244,11,251,227,231,4,12,243,245,249,4,2,2,251,5,8,7,251,251,6,3,246,1,250,6,250,251,255,254,252,7,6,241,11,251,240,0,243,26,233,250,253,5,254,254,21,250,253,251,255,6,255,0,243,2,253,247,255,252,253,5,252,12,240,247,9,255,239,253,250,12,6,238,254,11,242,250,3,14,244,245,251,14,2,5,248,252,245,2,251,16,6,249,252,8,13,243,5,3,228,242,0,6,23,5,4,255,239,1,253,0,0,5,4,0,238,14,10,4,2,5,254,4,253,2,0,2,0,241,4,243,240,253,244,254,2,7,10,9,3,11,4,23,14,9,16,4,1,244,253,4,249,241,249,246,242,250,248,255,250,249,10,251,246,253,243,16,255,244,7,253,244,2,13,13,2,17,15,243,1,251,254,3,255,1,253,6,253,244,240,7,249,245,251,244,226,250,234,1,4,250,253,12,6,7,0,16,6,254,0,234,254,247,2,243,8,6,248,4,249,255,250,4,6,242,5,1,229,252,2,1,14,245,249,248,252,1,8,0,250,243,11,244,249,251,1,10,7,3,254,0,6,248,2,10,255,246,10,231,243,236,252,19,3,13,5,5,7,248,2,4,2,3,255,255,247,14,10,9,14,3,3,250,0,251,4,1,255,247,15,238,239,4,245,6,7,244,8,255,245,2,3,7,16,253,247,7,244,23,0,6,7,242,247,8,1,254,6,254,255,250,9,240,230,242,245,9,250,5,254,13,17,21,7,18,237,6,233,254,241,254,2,246,248,2,1,254,4,253,252,251,252,0,6,251,228,239,224,2,246,11,3,251,9,10,3,11,11,253,12,254,2,4,250,9,252,252,252,252,247,2,0,2,4,0,248,238,222,247,249,252,245,10,15,11,255,248,15,6,243,9,2,252,244,0,255,19,12,6,5,0,253,246,244,3,251,246,6,247,239,244,245,9,250,11,11,18,249,0,16,4,2,250,3,244,255,0,1,251,234,254,244,0,6,17,5,5,6,12,251,7,1,251,254,255,2,2,252,253,253,253,254,227,11,5,243,183,24,12,4,242,246,5,1,0,245,249,249,7,3,10,253,255,253,4,245,251,254,248,7,9,2,248,250,6,7,21,17,202,47,242,246,14,19,13,21,252,3,1,2,252,2,244,4,240,244,5,247,252,19,249,234,234,239,3,0,250,8,23,252,201,228,2,230,2,1,4,0,243,6,0,10,249,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,255,35,255,189,221,232,232,250,2,2,254,1,3,2,0,255,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,0,41,252,183,241,18,4,17,8,255,240,255,254,1,0,0,0,252,252,4,6,255,2,240,246,241,246,21,254,250,254,14,249,10,251,201,34,244,11,243,254,2,28,230,0,7,4,21,249,2,1,15,234,10,253,14,250,254,15,254,249,20,6,241,249,23,10,196,8,252,29,234,2,243,9,246,12,255,253,4,7,0,0,0,0,0,0,0,0,0,0,255,0,255,254,11,251,235,245,196,229,239,217,6,36,0,248,2,2,0,0,254,3,2,251,9,239,255,2,253,250,8,12,7,250,223,245,242,216,10,36,210,0,237,5,0,246,3,12,250,248,6,244,249,1,1,1,0,0,0,0,1,0,0,0,255,0,1,0,254,0,4,254,169,253,254,2,254,20,2,6,255,6,0,0,2,255,1,0,0,0,0,255,0,0,0,0,0,0,255,0,0,1,1,7,180,41,249,232,0,250,3,6,0,254,255,1,0,0,0,253,4,2,3,2,2,0,3,255,4,0,255,4,254,252,224,245,192,227,247,213,2,245,255,249,0,252,254,254,254,2,10,236,3,253,13,13,0,252,2,7,248,7,254,2,236,236,237,3,209,238,240,250,241,214,239,14,250,8,12,246,11,244,253,254,254,255,255,4,253,255,250,254,3,2,253,6,255,247,10,13,188,247,26,3,5,3,235,10,241,21,234,19,11,242,1,5,18,237,227,243,254,18,246,20,2,10,246,11,1,8,240,239,215,10,242,231,0,242,237,17,7,244,14,245,14,5,0,0,0,0,0,0,0,0,0,0,0,0,3,255,213,5,6,244,208,19,8,218,248,253,22,235,246,15,20,247,251,8,0,0,0,0,255,1,255,0,0,0,0,0,0,0,6,253,22,242,185,232,254,223,23,7,248,7,253,2,252,1,248,254,1,0,255,2,0,254,0,0,255,0,4,0,26,255,10,245,239,224,198,14,242,245,254,15,2,248,12,10,247,13,223,242,15,239,237,7,248,241,224,234,7,12,18,0,0,241,252,16,37,254,210,11,2,248,246,248,14,9,252,5,7,239,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,251,3,171,23,247,239,254,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,251,3,171,23,247,239,254,254,0,0,0,0,0,0,0,0,1,0,0,0,0,255,0,0,0,0,0,0,255,0,0,1,1,7,180,41,249,232,0,250,3,6,0,254,255,1,0,0,0,253,4,2,3,2,2,0,3,255,4,0,255,4,254,252,224,245,192,227,247,213,2,245,255,249,0,252,254,254,254,2,10,236,3,253,13,13,0,252,2,7,248,7,254,2,236,236,237,3,209,238,240,250,241,214,239,14,250,8,12,246,11,244,253,254,254,255,255,4,253,255,250,254,3,2,253,6,255,247,10,13,188,247,26,3,5,3,235,10,241,21,234,19,11,242,1,5,18,237,227,243,254,18,246,20,2,10,246,11,1,8,240,239,215,10,242,231,0,242,237,17,7,244,14,245,14,5,0,0,0,0,0,0,0,0,0,0,0,0,3,255,213,5,6,244,208,19,8,218,248,253,22,235,246,15,20,247,251,8,0,0,0,0,255,1,255,0,0,0,0,0,0,0,6,253,22,242,185,232,254,223,23,7,248,7,253,2,252,1,248,254,1,0,255,2,0,254,0,0,255,0,4,0,26,255,10,245,239,224,198,14,242,245,254,15,2,248,12,10,247,13,223,242,15,239,237,7,248,241,224,234,7,12,18,0,0,241,252,16,37,254,210,11,2,248,246,248,14,9,252,5,7,239,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,251,3,171,23,247,239,254,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,251,3,171,23,247,239,254,254,0,0,0,0,0,0,0,0,16,65,254,254,4,3,0,249,3,1,3,1,0,5,1,251,0,2,255,3,0,0,255,254,6,0,254,0,0,255,1,1,5,37,252,8,252,255,9,17,6,249,5,255,11,6,252,7,254,4,1,253,11,3,3,247,6,0,254,252,251,4,244,245,15,24,242,2,6,17,26,5,8,11,247,249,250,248,3,251,9,10,253,10,0,1,4,247,4,9,3,0,4,0,251,3,9,36,247,248,7,7,4,3,255,240,254,7,251,250,6,12,245,244,9,255,253,247,12,6,250,2,2,5,0,5,6,250,25,39,251,24,3,10,3,250,13,248,3,249,2,246,251,2,254,3,5,254,1,5,254,3,252,1,251,252,0,1,254,0,16,27,255,0,242,6,4,251,7,254,250,0,253,251,2,255,255,237,5,248,0,11,12,5,0,3,10,6,242,14,243,241,12,23,242,2,1,4,253,16,7,248,2,248,8,6,248,249,253,0,2,8,243,7,13,250,252,6,243,240,14,11,249,5,16,28,249,255,6,253,9,0,249,3,0,3,244,20,8,9,8,23,8,243,254,4,9,3,251,13,5,254,12,14,5,255,19,37,19,5,7,5,10,5,19,10,14,0,2,5,1,252,252,2,2,251,254,255,2,250,252,252,251,253,2,254,254,254,24,21,1,245,246,17,242,14,6,255,250,255,0,243,255,244,254,251,6,252,244,14,5,254,248,248,15,249,226,244,4,0,11,26,253,3,5,255,254,3,254,10,15,252,10,228,10,239,248,1,2,249,255,250,241,255,4,5,249,9,0,251,252,4,18,32,1,2,249,4,15,2,247,254,12,245,7,11,13,2,0,5,9,246,16,3,253,5,247,233,2,254,255,5,2,11,35,24,236,2,4,255,5,14,246,247,8,249,0,5,249,249,11,1,5,3,2,0,254,3,0,1,4,0,254,248,0,252,9,35,255,2,255,237,253,12,255,8,8,243,255,254,2,5,248,255,13,254,11,1,0,246,0,253,249,2,1,244,3,12,20,27,244,244,7,4,255,243,255,247,2,13,245,5,7,247,9,1,1,8,247,0,250,7,4,2,254,7,3,254,1,247,8,37,236,251,0,235,10,248,3,19,247,7,253,248,10,254,0,5,6,252,254,255,0,249,6,1,0,4,251,6,248,2,8,27,1,253,251,1,6,0,15,2,17,255,3,239,10,5,5,250,250,6,246,18,251,0,0,13,7,10,251,250,254,252,14,29,236,252,253,1,251,255,2,12,246,253,4,238,4,14,252,255,247,15,254,2,251,253,2,9,254,242,253,4,252,249,23,23,233,245,27,4,4,255,7,0,251,9,2,245,3,7,254,251,2,249,249,13,253,250,2,3,3,252,255,248,5,254,16,26,250,8,247,255,254,255,248,4,254,0,244,9,255,0,239,247,30,251,241,240,243,0,10,245,249,253,255,0,245,254,12,32,252,251,10,19,246,4,244,5,250,9,244,250,250,248,4,1,3,0,8,0,253,252,249,252,10,8,6,5,255,4,46,42,253,242,254,250,6,254,251,255,253,253,1,255,3,1,1,4,255,2,3,1,254,6,0,255,254,4,254,255,2,2,9,33,243,4,245,3,248,22,12,254,4,0,240,5,4,255,7,250,247,1,7,5,0,251,5,255,10,3,254,255,3,254,9,30,6,253,6,1,249,5,11,14,7,1,0,2,2,255,8,7,250,243,246,254,1,250,10,7,6,5,254,251,255,240,9,28,245,246,9,246,15,8,4,9,252,249,0,251,9,8,249,2,241,233,4,252,4,16,248,253,0,248,14,5,253,15,17,26,251,251,255,248,20,18,249,254,4,249,248,251,252,16,0,0,249,254,243,251,254,3,12,1,3,251,2,2,0,255,11,37,7,233,6,255,15,13,4,247,7,5,3,253,251,248,254,3,251,255,248,7,2,13,1,3,0,253,255,2,0,254,21,33,7,20,21,246,6,251,251,250,247,2,10,0,8,252,10,2,254,254,0,246,250,254,0,251,3,245,3,247,253,1,6,30,241,248,16,1,4,6,4,5,8,253,8,247,255,250,8,2,254,4,254,5,11,235,3,246,16,245,24,10,14,250,15,36,253,247,236,12,0,249,238,252,248,247,9,249,253,255,2,7,251,248,6,2,2,255,7,1,1,253,3,252,248,1,16,34,21,3,247,10,7,9,249,1,252,247,252,251,251,3,3,237,1,5,4,254,250,251,246,245,248,254,2,251,248,249,28,29,253,18,254,0,250,12,254,10,245,252,243,244,250,252,0,4,255,248,6,4,12,11,10,10,253,250,1,2,1,7,3,8,22,248,3,36,248,255,9,6,243,242,8,255,1,2,254,248,0,3,1,2,255,5,255,248,0,254,2,2,255,1,0,6,0,0,4,13,249,240,250,15,242,235,247,246,246,250,235,5,4,2,12,4,12,11,252,250,250,246,249,238,1,4,255,3,10,1,255,15,4,249,240,3,0,234,10,2,253,254,13,5,248,16,251,4,0,245,246,234,0,252,239,5,2,1,12,8,252,247,14,40,235,0,1,241,246,244,12,6,246,2,8,6,244,246,245,1,0,245,2,1,13,0,6,3,8,4,246,3,5,252,253,3,0,247,2,8,234,233,17,8,239,253,14,248,252,1,248,3,0,5,255,253,254,252,1,246,0,254,0,255,5,249,4,12,254,0,249,2,240,241,12,21,249,252,7,249,245,241,249,247,251,248,0,250,8,253,248,22,249,247,7,19,4,247,24,22,2,250,8,13,242,236,252,11,8,252,255,2,0,249,5,239,253,3,250,5,3,4,251,249,253,14,254,6,2,8,254,5,252,254,246,3,211,226,253,253,244,252,253,253,255,9,250,250,5,252,0,5,255,254,255,0,250,255,253,14,240,246,10,0,254,216,247,12,2,237,15,252,4,3,3,252,7,1,252,251,0,4,255,0,247,254,252,255,254,0,7,16,2,249,8,2,0,1,5,21,246,230,7,2,247,249,253,240,8,5,5,250,10,4,242,250,5,3,254,254,252,1,247,14,255,3,3,11,1,251,253,13,240,238,20,6,251,0,253,2,8,4,237,247,12,0,248,2,2,1,6,13,249,245,2,5,16,252,19,15,4,0,245,7,246,246,240,18,245,244,247,252,7,252,252,239,1,1,248,253,253,5,254,250,245,251,2,12,0,247,246,14,6,2,253,2,244,228,12,1,255,2,0,253,252,7,16,5,249,8,252,253,255,3,244,4,239,251,252,7,11,6,1,14,252,250,5,5,250,232,23,247,241,13,249,247,241,10,255,8,251,1,12,6,2,0,4,254,9,246,1,5,11,3,6,12,253,8,235,5,249,236,12,254,247,253,17,249,248,247,242,3,243,18,248,9,2,248,4,248,251,254,253,253,255,5,254,15,3,2,1,248,1,217,250,13,243,0,254,251,250,253,0,251,254,15,247,5,253,250,254,7,0,243,2,8,5,244,243,22,8,240,11,5,254,224,254,252,11,5,5,250,1,3,1,5,3,6,251,4,4,248,8,4,1,3,13,9,5,252,9,18,245,2,255,15,246,237,254,14,0,246,1,1,238,3,2,250,248,20,7,248,16,9,9,243,253,254,243,11,11,247,246,13,253,238,2,10,5,235,6,15,245,235,3,14,0,244,9,255,254,252,3,253,247,248,251,254,248,2,3,3,11,4,0,13,1,248,10,13,250,230,2,12,253,251,12,254,1,8,249,239,237,5,10,7,253,2,253,0,5,0,5,0,3,253,247,5,241,251,251,17,251,225,0,13,13,5,255,250,242,7,248,9,242,254,240,252,252,250,6,250,246,6,13,3,1,7,253,4,255,254,255,4,248,224,255,252,0,3,246,7,10,246,4,255,6,2,240,247,4,3,13,233,253,252,4,11,252,247,4,11,244,244,244,6,1,228,253,14,18,254,244,7,15,253,251,249,253,2,250,4,4,254,251,253,2,243,8,7,249,0,13,7,248,249,8,36,246,234,3,23,253,246,253,11,1,249,3,3,255,249,252,2,3,2,5,3,252,255,255,1,13,1,250,255,250,247,238,17,251,219,255,255,250,252,1,250,241,2,17,247,0,253,0,4,0,251,0,4,1,251,0,14,5,0,249,2,250,17,250,247,7,240,251,23,242,243,8,241,11,10,245,243,223,251,254,1,6,8,0,243,247,5,11,7,254,248,9,11,25,242,7,3,255,223,14,8,250,237,3,3,2,255,253,255,254,246,253,1,2,1,4,2,253,4,254,8,4,254,9,13,252,254,241,253,19,219,9,25,247,2,251,254,254,252,4,2,2,0,3,3,3,5,254,253,252,253,10,13,255,241,4,6,238,252,25,1,233,239,15,13,248,248,7,4,251,3,6,9,249,6,0,251,8,0,250,255,254,254,1,3,9,251,27,15,247,225,255,23,254,247,1,8,255,249,254,248,252,252,254,255,3,5,0,0,255,1,249,7,253,253,248,7,3,250,8,3,245,254,36,14,1,226,6,10,244,250,250,254,252,253,251,0,9,4,251,251,248,12,4,253,1,248,254,9,33,0,12,253,249,252,252,255,6,231,11,250,247,245,254,252,254,6,255,253,250,15,250,3,10,252,1,0,5,8,234,235,247,237,251,249,244,241,248,9,237,14,249,252,5,248,254,7,1,253,4,252,6,11,2,6,253,251,2,254,0,253,224,243,3,232,3,248,4,1,246,14,241,0,4,6,255,6,7,255,6,4,253,239,1,4,250,255,1,0,3,3,249,252,224,245,7,248,244,13,251,234,252,12,240,2,0,4,0,1,0,6,251,248,2,6,5,0,253,250,5,6,5,5,13,252,212,223,6,252,2,0,247,10,3,4,7,0,255,7,5,1,1,253,1,6,255,0,2,3,252,0,0,1,0,255,254,255,226,238,232,248,5,0,254,14,7,0,1,12,6,4,247,7,5,7,245,251,1,248,255,2,2,247,7,255,7,5,6,6,234,236,243,247,20,253,10,248,6,252,2,249,10,8,0,255,2,253,6,237,2,4,3,3,249,2,255,250,1,1,6,254,229,248,255,3,255,245,24,4,255,1,248,8,5,245,15,253,241,255,255,243,255,1,251,5,2,3,247,0,4,3,249,6,223,240,255,248,10,233,6,13,255,253,247,0,5,249,251,244,254,3,3,6,254,253,2,253,9,250,253,254,0,5,253,252,234,239,11,253,3,1,255,251,17,2,241,254,10,247,6,14,240,244,20,255,249,6,253,244,1,10,246,255,7,253,255,10,228,243,1,253,255,255,0,3,3,5,1,10,246,253,7,2,4,19,255,255,10,5,248,1,11,241,252,253,251,4,243,3,234,243,42,236,5,243,7,245,1,1,255,1,6,3,6,245,3,3,254,0,252,4,253,255,251,2,0,0,247,255,4,4,230,241,254,250,252,254,16,8,21,8,1,253,246,7,248,244,251,12,247,3,254,253,18,1,244,241,252,5,253,0,12,7,230,240,5,6,14,253,15,6,1,249,243,16,241,5,11,254,9,249,252,254,0,0,254,7,248,250,251,2,7,253,2,12,225,239,248,226,4,14,6,250,6,245,0,3,252,0,0,252,0,252,1,4,3,4,0,251,3,2,2,0,2,1,3,5,195,246,4,10,4,7,0,253,0,1,0,253,0,1,0,254,255,1,2,254,4,253,1,1,255,1,254,252,252,4,0,0,228,243,248,252,3,253,2,1,11,14,3,9,1,13,3,5,253,254,254,244,242,247,245,241,244,251,252,244,3,253,0,251,215,0,12,232,13,4,5,16,251,252,0,0,13,252,1,247,9,250,255,6,254,5,2,9,6,247,248,8,254,253,250,252,230,237,254,241,4,242,6,0,26,20,8,9,9,3,252,251,248,1,0,255,5,9,3,4,4,7,1,3,254,254,246,0,227,238,9,252,1,251,242,244,5,246,251,4,251,0,255,255,4,251,7,240,245,2,7,241,2,252,6,252,250,7,253,7,229,240,9,242,3,248,9,0,7,252,253,249,0,246,255,2,1,254,15,246,14,7,6,17,3,252,3,246,8,248,3,11,235,236,248,248,4,5,253,254,0,251,14,246,11,252,13,0,5,245,19,238,18,3,251,253,252,248,11,246,10,3,4,247,221,241,13,244,4,0,254,252,244,253,248,232,249,1,7,8,253,0,254,255,3,254,254,250,8,1,0,1,250,255,2,250,237,242,13,246,9,255,1,3,244,5,240,7,13,9,4,252,6,251,4,9,253,17,252,12,245,250,251,250,13,2,7,247,222,248,252,1,2,255,3,6,236,245,8,255,4,2,247,4,252,251,16,10,252,14,243,1,250,0,2,246,0,253,253,7,220,246,248,253,2,254,14,252,255,249,252,10,255,253,15,245,0,2,3,255,4,0,8,255,0,18,245,251,15,251,13,244,234,243,14,236,15,25,16,10,8,254,246,251,255,248,11,8,255,254,252,1,2,255,249,0,0,0,253,0,2,255,0,2,225,234,7,6,254,5,236,14,250,7,0,14,3,249,3,250,254,1,253,251,1,246,1,232,6,254,3,249,1,249,8,7,231,236,253,247,10,6,12,7,5,4,253,6,255,251,250,248,3,5,6,5,246,10,252,241,241,254,247,2,18,1,8,12,232,237,254,252,249,11,6,9,16,2,249,18,6,249,6,6,254,247,3,12,254,3,255,6,7,8,0,8,245,8,4,2,230,236,244,244,254,253,1,251,255,254,0,3,7,9,254,2,9,22,13,4,252,255,254,242,5,15,248,251,249,245,242,250,235,238,255,252,0,3,7,254,10,8,248,255,15,1,247,3,1,3,251,254,2,4,0,255,10,2,237,248,8,30,249,8,231,250,26,4,248,4,254,21,5,252,240,5,13,4,246,255,250,254,2,246,243,1,3,253,250,248,2,11,1,249,0,5,0,255,254,19,244,208,250,11,8,254,252,254,249,5,253,2,254,255,255,249,0,253,253,252,252,4,1,3,253,255,254,251,245,248,228,18,16,232,248,19,4,8,244,9,252,254,4,249,6,2,3,3,252,0,1,250,252,254,2,6,0,253,1,240,247,251,230,7,253,219,240,254,2,249,4,243,0,252,250,251,250,252,0,3,4,253,252,252,4,253,9,252,254,2,7,252,2,9,238,7,29,232,255,7,14,10,3,253,254,251,6,246,250,253,248,0,5,1,4,3,244,2,6,1,3,4,1,253,236,2,8,20,247,232,252,18,3,11,255,245,6,9,255,253,1,255,241,3,15,9,3,2,243,2,248,8,1,255,1,248,244,5,245,6,19,230,239,250,4,14,6,248,9,5,250,251,2,255,20,1,245,246,238,20,249,0,253,4,2,0,10,4,241,1,254,13,248,235,234,4,4,3,3,249,225,4,246,242,0,8,4,5,8,11,2,248,6,7,0,254,6,8,8,7,243,246,247,12,19,240,253,254,9,2,11,227,255,9,4,253,1,246,246,16,1,7,249,250,252,255,251,3,6,0,3,1,239,255,251,19,12,247,235,251,2,12,249,249,253,8,7,254,6,247,247,1,252,1,1,3,242,2,248,0,10,1,244,250,243,251,8,15,0,236,254,20,8,248,8,237,12,10,2,245,0,12,1,245,0,245,241,5,245,2,4,252,245,5,252,251,3,245,249,8,0,239,230,15,19,249,10,247,251,251,14,231,0,248,2,247,253,9,1,250,4,252,3,247,255,6,2,2,244,5,5,9,14,238,237,4,2,16,14,235,241,247,255,16,12,245,246,251,249,4,15,248,251,255,1,14,13,249,255,252,246,251,255,8,7,233,246,14,6,11,10,240,253,16,6,0,0,9,6,254,249,1,22,5,3,248,0,3,254,246,3,0,254,242,2,16,15,239,239,6,19,4,246,241,255,15,11,242,248,5,8,8,254,248,245,10,10,248,242,2,13,4,254,244,246,3,6,4,19,233,237,1,4,247,226,3,250,18,0,2,0,245,0,3,7,254,8,5,2,253,6,247,1,252,7,250,9,5,254,21,20,223,243,7,246,8,8,241,250,252,1,5,3,7,254,247,255,4,250,1,0,9,255,251,2,1,253,3,247,253,3,15,253,226,249,249,231,6,2,250,1,19,1,244,1,248,243,9,13,1,8,2,5,15,254,3,247,0,252,4,250,244,239,25,22,243,246,9,2,11,249,240,4,6,1,0,0,18,252,251,4,254,255,251,0,252,6,1,6,255,7,0,255,0,246,8,8,229,0,254,29,16,254,252,9,255,2,0,6,10,6,4,2,249,9,238,3,3,3,246,17,10,9,250,253,244,250,11,20,224,5,21,3,252,247,2,246,1,7,252,5,0,0,255,248,247,249,4,246,5,0,2,251,4,9,1,251,255,251,1,2,237,243,1,6,12,2,240,239,11,10,13,16,244,245,3,250,0,6,4,253,1,8,2,5,245,3,242,237,5,10,11,2,233,247,16,254,7,0,245,249,10,6,249,26,241,252,8,6,252,7,247,241,1,8,252,4,2,244,16,245,1,11,252,1,225,243,255,8,5,4,254,0,13,7,239,7,246,250,1,4,255,2,247,252,9,3,3,252,251,3,4,253,1,10,255,0,241,234,4,40,245,252,253,242,9,11,255,9,255,250,6,3,250,0,0,244,7,254,0,9,3,1,3,255,255,255,14,8,232,242,248,5,8,5,244,239,8,2,7,10,248,0,4,250,250,246,8,4,244,3,247,244,5,4,253,251,1,245,8,9,232,0,2,2,14,244,243,1,6,7,0,7,250,9,26,11,242,8,10,1,9,0,11,254,6,2,246,243,1,4,34,19,239,241,0,3,254,249,255,0,253,253,255,1,255,246,8,5,0,248,4,239,9,254,0,0,6,2,253,250,252,1,2,2,242,227,0,9,34,253,251,242,6,246,247,251,255,0,3,3,0,1,255,254,255,255,253,253,252,3,253,252,6,3,14,14,248,227,31,11,14,252,251,250,10,6,247,255,245,249,1,7,4,1,250,4,0,10,249,251,255,2,4,252,252,254,14,6,224,250,242,14,251,245,10,238,252,6,248,9,5,252,1,252,5,254,247,3,5,2,246,250,239,3,17,240,9,21,19,4,236,239,14,9,15,250,239,255,1,6,253,1,1,8,253,250,6,9,4,9,247,251,1,255,0,255,2,249,251,3,19,1,236,247,14,21,249,238,247,26,249,239,249,12,6,0,247,250,14,9,247,248,4,15,249,247,255,9,1,236,30,250,11,24,252,0,250,254,8,252,12,248,239,0,5,252,1,255,3,253,5,3,3,7,254,253,254,4,0,0,255,221,17,6,1,247,255,240,3,236,243,8,7,252,249,252,236,7,12,251,5,251,245,12,255,15,247,250,16,252,247,243,4,235,36,237,9,0,249,248,9,252,253,3,0,7,248,254,254,245,13,255,5,253,7,2,3,255,254,251,1,255,254,251,253,244,33,252,1,244,247,0,243,255,2,248,4,246,6,240,249,255,252,246,15,255,0,251,248,5,5,253,0,2,249,1,249,242,32,5,249,241,3,251,8,14,5,9,13,3,18,253,7,4,246,246,10,255,2,0,254,245,5,253,252,2,2,7,4,242,34,1,20,255,244,0,253,249,252,7,18,9,253,14,249,247,236,249,252,243,12,1,12,5,250,2,252,0,241,1,3,235,23,7,248,3,243,253,0,250,254,249,6,244,9,250,254,254,252,255,6,9,5,247,15,0,8,248,7,6,241,3,251,229,32,255,252,254,4,246,12,253,8,13,7,0,241,4,254,3,5,7,252,9,244,255,254,255,252,0,252,2,251,6,250,239,29,15,0,255,252,246,13,12,255,248,246,246,4,7,254,6,251,243,19,6,1,249,2,247,254,12,252,248,253,2,4,218,27,16,241,250,3,249,252,0,255,6,254,253,250,6,250,253,0,2,0,252,6,1,255,0,4,255,3,4,1,254,5,223,40,252,2,1,0,0,246,242,0,249,4,255,3,254,5,7,6,255,4,1,3,1,249,1,252,5,7,0,4,3,252,236,25,12,252,16,252,2,2,242,254,253,29,255,1,3,1,9,251,2,248,253,1,249,254,249,1,0,4,16,254,255,255,246,30,17,3,251,254,0,251,234,4,5,5,253,238,250,10,251,249,2,8,7,249,245,254,0,253,3,2,11,252,4,252,245,30,11,4,253,248,1,254,4,18,3,1,255,0,248,252,253,10,13,14,5,251,1,1,246,2,15,4,9,255,251,253,239,32,18,238,253,251,6,10,1,241,251,9,8,244,246,250,11,9,251,248,249,10,5,246,242,252,253,1,9,245,2,1,243,28,245,255,2,240,254,7,232,0,3,6,3,255,248,249,244,2,2,236,10,4,0,243,254,254,1,8,242,0,4,1,242,23,12,8,8,230,2,252,242,13,242,15,3,247,255,243,246,254,246,6,240,12,8,0,9,246,249,252,252,7,248,8,236,45,10,242,4,16,8,247,1,248,10,5,249,254,2,251,255,0,251,4,250,254,4,1,3,4,252,2,254,254,5,1,236,26,252,1,7,4,248,1,251,243,2,13,249,253,6,250,22,0,5,11,252,245,8,247,2,254,252,254,2,243,252,248,228,18,17,3,248,233,240,250,5,246,14,10,5,255,248,4,254,13,253,254,3,4,3,254,253,252,0,1,3,4,0,4,244,32,250,240,18,12,240,0,7,13,252,5,248,255,253,4,6,254,255,243,4,255,3,12,253,246,1,6,8,245,254,4,238,26,2,5,0,247,239,14,5,1,7,253,248,253,11,7,251,244,248,7,0,249,2,244,247,13,245,9,6,245,251,11,232,22,241,247,8,1,249,244,247,3,11,15,14,245,12,241,251,7,254,0,248,3,3,255,2,11,245,14,250,13,1,250,236,28,18,252,250,251,12,14,2,10,243,250,248,250,243,255,230,22,253,242,6,0,10,241,243,247,6,249,1,251,252,255,237,26,248,253,242,250,247,252,248,15,248,3,244,252,254,249,251,3,13,253,252,231,4,255,5,244,255,243,5,2,0,6,238,43,14,248,1,233,254,254,1,3,249,0,0,8,255,253,251,1,5,2,0,254,254,254,1,255,255,249,0,3,253,9,245,30,10,242,3,1,10,245,1,249,252,14,2,1,247,1,245,254,249,5,245,1,3,14,1,240,248,3,251,7,252,4,238,24,6,3,8,7,234,249,249,3,248,4,23,9,3,255,3,6,7,255,249,6,4,1,253,1,250,255,2,249,3,3,241,38,249,255,245,2,239,232,24,8,7,252,251,2,2,249,1,4,0,247,5,0,255,1,255,251,250,3,0,7,8,253,242,22,1,251,9,244,247,251,250,5,7,8,255,252,247,253,223,240,247,255,12,245,17,249,253,255,249,3,2,253,16,252,242,20,6,4,246,252,252,252,1,249,2,6,8,244,4,1,255,12,10,3,242,246,253,18,254,33,251,239,17,251,9,7,244,23,13,0,245,248,245,12,251,247,240,11,6,4,12,251,5,243,7,244,253,1,2,12,1,252,255,5,4,11,244,253,15,2,14,7,1,2,1,12,10,23,4,6,236,246,4,26,250,13,4,3,2,245,5,249,246,4,9,1,10,252,11,4,17,15,31,17,18,16,11,24,2,4,2,3,248,253,7,253,251,249,254,250,252,251,252,255,252,254,251,250,2,255,4,254,16,8,15,14,3,7,21,9,8,15,21,6,8,12,5,251,7,253,10,2,253,8,6,0,5,5,6,253,2,4,0,251,5,252,6,12,6,13,24,17,251,17,255,250,249,246,248,238,3,254,2,7,241,245,12,253,254,254,252,249,2,0,5,5,10,250,8,11,12,20,22,245,253,15,253,15,254,254,0,2,5,248,4,251,247,252,255,2,255,253,1,3,13,255,9,7,251,8,5,11,14,251,14,247,2,35,8,15,1,254,2,254,4,247,253,242,244,254,254,252,254,248,253,1,250,3,10,0,16,0,250,15,253,4,4,3,3,20,5,252,10,9,247,253,246,254,249,11,245,246,17,255,3,241,2,9,241,246,16,10,14,4,249,19,3,0,19,8,16,34,247,6,243,255,6,5,255,254,4,3,2,1,1,255,0,249,2,255,1,0,6,255,1,6,9,13,9,10,15,16,10,18,13,17,3,255,249,2,241,245,246,252,243,250,239,243,250,242,1,246,6,4,255,255,13,1,7,10,14,13,249,5,5,28,14,14,254,2,3,253,243,252,10,247,19,252,253,4,251,251,0,5,251,0,3,252,1,0,6,22,9,18,18,253,5,10,12,254,1,253,248,244,9,246,249,1,255,19,0,2,248,245,246,9,6,11,0,3,10,11,19,44,0,14,1,249,6,22,2,255,9,2,0,252,4,0,250,250,3,0,0,254,2,251,1,254,0,1,1,1,5,7,0,32,30,26,5,4,249,253,15,250,3,246,7,6,248,249,2,243,251,255,253,7,3,254,248,0,6,4,5,0,9,8,254,4,2,11,4,29,251,14,8,251,242,8,0,9,8,246,5,241,250,247,9,255,18,240,9,235,253,243,254,8,25,7,247,23,20,18,6,16,247,8,8,251,11,13,248,7,4,10,254,255,249,247,249,247,252,1,1,251,246,8,4,251,9,2,16,14,251,14,1,0,235,17,255,9,12,253,253,4,252,14,10,3,0,246,7,4,4,245,2,4,255,253,9,255,17,8,11,26,15,253,14,255,12,9,10,248,8,238,245,253,242,249,7,253,253,252,1,249,253,2,253,16,10,0,9,6,9,8,3,8,18,14,11,1,10,6,1,252,240,254,14,254,1,8,12,14,3,253,8,8,12,241,3,253,3,254,14,10,22,253,245,13,249,11,4,11,3,14,0,250,254,247,4,2,254,0,251,229,246,3,255,5,8,232,253,245,253,2,11,255,19,2,8,36,5,250,3,15,253,252,251,14,246,1,244,246,253,252,3,254,1,248,4,3,5,253,0,4,8,254,8,4,8,14,15,9,252,10,5,11,9,10,8,9,241,15,6,248,246,243,5,248,236,243,250,245,255,253,250,252,255,0,13,15,254,255,9,12,2,2,13,3,233,33,15,2,252,255,3,8,8,6,6,249,8,6,9,255,3,248,0,252,1,248,11,255,6,5,250,16,2,253,31,21,247,12,0,255,252,1,244,3,243,238,2,245,247,2,248,250,11,253,255,0,255,0,13,5,5,255,2,0,25,5,10,16,251,21,14,12,13,2,251,5,5,253,254,242,0,244,7,11,255,249,19,255,255,255,8,255,10,7,3,11,0,8,22,3,3,19,252,12,15,9,5,15,2,1,2,246,246,0,2,255,0,1,244,255,21,16,9,249,11,252,251,24,249,11,20,11,241,18,5,243,241,0,251,9,1,0,255,247,4,248,6,248,1,254,249,20,9,3,9,3,20,0,244,250,9,31,9,12,8,27,15,7,240,5,253,249,255,247,254,249,253,4,248,253,3,250,254,254,253,250,255,2,6,250,48,8,253,19,12,11,249,2,3,0,255,1,8,252,4,250,0,252,252,253,3,6,3,243,248,5,253,249,8,5,7,254,6,11,12,2,14,4,251,12,2,9,4,2,0,255,2,0,241,247,240,254,8,239,251,234,237,251,255,246,1,254,11,247,3,12,6,6,1,17,250,19,14,7,249,255,255,247,9,245,239,0,250,16,0,1,9,232,3,3,247,253,3,254,9,0,1,8,1,7,2,251,253,8,255,7,2,6,253,250,5,254,6,254,252,253,0,253,13,206,1,254,2,4,4,3,7,0,26,21,252,2,17,8,7,11,249,1,255,241,255,241,245,252,239,252,1,249,3,6,3,247,2,3,6,10,6,12,1,254,2,255,246,252,6,253,251,254,248,2,2,2,8,0,1,1,6,0,11,13,3,4,0,244,11,251,19,20,2,5,5,3,243,254,1,244,11,249,244,7,10,0,7,0,254,4,250,247,245,244,233,12,10,253,0,6,19,255,24,18,9,12,6,253,2,5,2,2,254,251,248,245,252,3,248,252,5,253,240,252,3,244,252,3,32,7,2,8,32,238,255,12,1,7,0,248,255,0,248,7,248,255,255,4,244,255,3,0,1,238,8,8,242,246,245,19,9,5,249,6,8,252,26,12,255,6,3,5,242,7,14,8,20,243,240,246,254,17,249,4,248,247,14,251,3,252,244,7,14,246,237,236,35,8,13,14,254,9,254,252,255,1,253,0,255,1,2,2,6,0,0,4,5,254,3,3,3,254,249,253,253,255,6,254,29,22,13,34,0,14,253,247,3,1,5,252,2,0,7,247,0,2,251,253,0,6,255,255,255,2,2,4,8,7,20,250,7,16,33,20,6,255,245,1,253,253,245,3,247,231,255,240,4,248,15,1,254,7,8,23,2,18,243,16,3,249,6,3,16,248,12,16,3,4,0,5,5,251,1,255,2,253,254,1,243,2,2,10,6,7,18,18,7,9,8,9,21,14,7,12,15,14,15,12,11,5,1,251,11,254,17,8,3,0,255,6,11,249,6,6,7,5,241,14,1,11,4,10,12,1,2,4,30,1,11,1,6,13,2,4,3,249,5,8,245,7,251,9,246,6,8,246,253,10,1,227,252,230,5,248,13,4,3,6,35,1,3,6,3,0,254,1,0,0,255,253,249,253,247,253,255,250,3,4,4,0,5,255,254,254,255,252,246,8], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1122000);
/* memory initializer */ allocate([0,250,10,252,46,12,2,28,4,255,4,1,0,4,254,254,254,255,2,252,1,5,0,253,1,1,254,0,1,254,255,255,3,250,35,245,13,53,253,255,251,254,0,243,240,5,244,245,1,226,3,238,232,248,251,237,1,253,248,7,249,248,15,237,4,10,30,24,6,1,247,10,252,8,249,252,250,12,255,247,252,2,247,3,2,254,4,2,22,9,4,251,0,5,254,247,253,1,18,244,18,16,4,16,251,248,253,251,253,6,249,253,254,251,253,1,2,2,4,250,10,3,12,253,20,0,27,252,16,5,18,253,23,4,12,11,0,1,0,1,254,1,2,1,255,0,254,2,254,252,1,254,254,255,251,254,0,0,254,2,9,7,63,5,12,255,1,0,4,253,249,251,245,251,244,246,246,244,241,244,242,242,1,1,10,246,16,6,2,9,11,9,9,8,12,255,13,12,6,3,7,253,254,4,6,248,2,253,244,251,247,248,246,15,254,252,8,9,7,243,238,34,251,7,12,22,16,245,13,25,241,245,253,254,0,252,1,0,253,243,249,13,12,249,246,13,19,6,16,15,244,241,253,34,1,5,1,247,11,21,8,17,251,250,3,251,0,252,0,4,245,4,249,253,255,248,3,254,2,1,11,5,6,14,253,2,252,249,0,31,15,254,24,11,5,4,255,252,247,5,248,238,252,247,236,238,7,242,240,3,8,253,29,11,243,243,7,1,17,6,6,21,11,1,14,248,2,5,253,8,246,250,12,2,1,3,3,3,3,250,248,242,15,251,16,4,16,0,7,255,0,16,2,1,22,4,19,13,245,1,2,253,10,20,252,255,248,5,248,247,250,254,252,249,8,246,0,8,250,1,248,14,13,5,17,250,26,255,7,255,0,12,252,249,225,254,249,255,5,251,251,244,4,249,250,3,15,254,5,254,7,255,10,7,8,255,14,20,14,9,16,16,8,24,249,0,253,250,1,3,243,250,252,252,251,247,255,246,252,248,2,0,255,1,24,24,21,31,5,2,11,12,7,4,3,6,253,251,6,252,253,255,2,255,254,1,0,248,255,2,0,252,6,22,255,251,8,12,255,254,28,27,20,229,14,1,2,253,1,251,254,254,6,254,9,1,254,251,3,4,11,5,2,8,253,255,1,254,253,251,5,8,49,12,8,253,9,20,12,17,250,0,1,7,0,9,254,252,8,0,254,246,0,7,21,255,0,1,17,249,251,2,4,16,254,17,14,236,15,14,4,15,0,3,252,9,252,0,6,4,250,250,251,249,2,247,246,254,251,0,253,235,9,14,245,13,29,2,25,4,22,255,2,253,2,12,245,2,16,9,252,7,1,246,241,11,252,3,254,4,4,251,246,1,4,19,241,6,252,254,30,249,11,21,244,5,254,253,254,4,255,251,253,249,251,1,0,250,1,250,7,0,8,249,253,254,2,14,2,253,230,255,26,22,32,1,254,6,1,218,255,236,254,253,250,252,2,2,7,0,3,5,3,10,6,1,253,251,7,5,251,252,8,3,1,242,255,247,251,252,251,230,249,237,246,251,245,5,245,231,248,242,247,240,248,250,239,242,255,255,6,2,2,2,3,0,2,8,248,3,0,253,17,207,253,233,255,11,7,3,4,252,0,0,255,4,2,4,254,252,2,254,255,254,2,0,0,255,0,0,1,2,0,0,4,222,250,247,1,21,249,3,254,255,253,18,2,240,7,253,8,7,251,7,2,4,8,250,249,254,251,255,4,1,2,252,5,227,13,254,242,3,1,18,241,4,248,8,246,8,2,1,248,15,3,246,252,252,254,0,253,252,2,253,252,253,12,250,13,236,3,238,239,4,242,13,28,11,248,250,16,6,0,10,3,4,247,13,5,249,12,251,0,249,5,1,3,3,2,1,3,229,251,245,235,245,244,0,251,7,234,1,3,5,0,251,8,7,1,251,249,2,251,4,1,3,248,254,0,4,254,6,31,211,0,255,244,1,2,250,4,3,255,3,3,0,5,3,251,12,4,6,2,1,254,1,3,2,5,2,2,2,3,255,9,211,6,5,255,239,254,18,253,2,0,1,0,255,10,8,249,254,251,248,6,255,0,4,6,253,12,255,254,0,5,249,3,230,254,244,244,2,246,16,253,12,4,5,11,8,240,239,254,253,253,2,5,247,13,1,10,11,3,5,254,2,2,249,8,230,32,249,251,22,2,14,246,248,249,3,3,7,0,251,0,255,253,0,8,4,251,249,6,255,4,8,1,1,7,250,4,225,2,242,2,0,1,8,250,255,17,253,13,250,5,246,254,246,254,246,253,7,1,5,248,8,242,253,241,7,246,250,16,229,13,252,233,7,247,6,249,5,4,2,255,253,23,238,7,0,253,4,253,9,250,254,255,8,250,2,6,253,2,254,255,221,254,248,11,255,249,253,254,11,7,6,250,246,9,6,253,251,250,253,9,16,240,247,236,12,3,5,253,1,247,4,2,232,1,244,240,5,252,3,252,255,245,245,248,242,14,10,248,20,8,253,245,1,1,252,252,249,253,15,2,250,254,7,9,235,2,237,249,251,248,25,3,17,5,253,9,244,8,2,252,3,3,1,11,247,252,253,4,3,234,6,4,6,11,251,16,233,13,239,235,244,5,9,236,7,6,250,0,2,247,6,250,243,249,255,5,253,5,249,246,1,0,8,247,11,0,248,10,230,247,249,237,252,6,16,249,5,252,4,8,0,4,255,6,249,1,248,245,10,242,0,240,6,253,5,255,14,12,1,8,229,12,242,255,255,237,10,245,21,242,9,248,253,8,255,12,243,3,252,254,0,247,0,249,2,253,12,1,253,3,1,18,236,242,242,240,253,232,6,239,2,253,245,2,253,12,10,10,1,10,7,8,5,5,4,255,7,2,2,0,4,7,0,0,226,9,240,238,15,12,253,4,252,251,245,252,244,246,0,2,254,252,255,2,0,255,250,2,253,4,251,7,3,5,7,25,232,255,250,247,6,243,254,3,15,253,11,4,248,245,2,0,247,254,7,4,8,5,248,5,6,255,245,241,251,0,11,0,222,249,245,249,9,253,19,4,248,3,245,11,253,247,12,9,9,2,1,249,1,253,0,250,254,255,3,0,249,254,251,6,222,252,251,253,247,2,9,255,9,251,253,230,244,8,250,249,11,248,4,4,1,255,0,8,9,252,7,255,1,253,255,3,226,5,6,246,3,249,6,3,3,230,237,253,1,7,5,252,251,6,10,13,246,4,249,252,5,253,9,250,3,9,5,4,232,9,237,2,252,251,8,253,2,0,241,255,9,252,22,6,9,3,7,11,247,0,253,4,5,251,10,248,5,249,253,8,229,7,253,255,2,247,13,7,12,252,250,250,5,0,7,5,1,15,253,252,0,251,254,7,251,249,1,254,13,248,13,17,234,241,245,248,16,242,18,2,255,14,249,14,250,250,249,248,17,6,4,4,249,251,247,242,250,255,9,253,1,6,251,25,226,2,244,243,18,238,16,8,253,10,248,253,255,250,3,251,249,4,6,7,1,1,245,251,6,2,252,9,255,251,254,7,233,7,241,255,253,255,0,246,12,2,5,252,0,4,6,255,5,247,255,255,249,1,17,9,239,240,8,4,242,11,14,0,225,7,243,3,245,249,6,1,245,8,249,15,253,16,245,255,241,16,253,5,0,254,254,250,11,5,6,5,251,6,3,13,232,254,236,246,7,253,255,15,2,6,251,249,246,236,1,252,14,8,254,3,243,253,1,252,1,253,2,8,249,16,252,1,254,254,253,252,249,0,3,6,7,3,2,1,254,255,0,250,4,2,252,253,252,5,9,5,0,253,253,252,249,225,206,255,253,7,2,255,2,4,6,0,10,254,0,236,250,253,9,236,234,255,255,15,9,244,10,243,236,12,3,5,6,249,230,0,4,254,242,244,6,243,11,246,3,22,6,16,254,251,1,253,245,0,249,5,251,0,1,255,250,8,8,10,9,251,229,251,10,254,7,9,247,5,247,5,4,241,14,1,3,246,5,0,254,7,3,243,6,9,250,5,242,239,255,11,14,254,230,0,6,253,0,248,6,0,1,4,248,2,251,4,7,15,11,9,19,254,14,248,7,255,3,253,253,246,254,12,254,244,227,244,251,0,253,254,6,3,253,2,254,1,11,2,249,5,1,2,254,242,0,255,251,3,8,228,230,6,250,3,8,246,229,255,253,6,2,4,15,1,0,2,254,254,13,3,6,0,6,255,252,255,251,8,255,5,251,241,11,248,251,14,250,242,227,251,250,0,1,0,6,253,2,251,255,5,253,2,246,3,4,3,0,13,253,255,4,252,250,2,9,8,2,253,28,245,225,1,252,246,247,252,253,241,250,1,5,253,250,5,250,234,27,243,5,3,249,252,20,249,244,255,232,252,243,248,245,241,235,250,252,19,250,2,11,250,1,253,246,9,247,12,246,2,1,247,1,15,7,251,5,227,221,4,226,9,9,19,17,2,239,253,3,253,1,2,5,255,5,254,253,1,253,248,3,252,254,252,255,12,0,2,248,250,252,16,255,242,254,25,250,241,220,0,255,3,252,252,255,7,252,8,0,10,9,252,1,10,255,253,243,251,252,255,252,8,11,14,249,251,16,12,13,255,228,1,254,2,253,248,10,4,9,12,3,5,0,8,253,250,2,16,245,11,0,1,6,1,18,246,240,255,252,5,242,241,236,1,244,5,4,249,8,255,239,254,247,242,245,6,247,5,252,3,254,7,18,251,5,6,255,245,254,246,253,8,253,254,224,244,5,20,251,250,245,250,250,243,4,250,19,248,2,3,247,252,252,255,9,255,21,255,7,15,246,255,253,9,253,2,232,0,253,2,250,4,255,247,254,255,253,6,255,251,250,251,248,0,254,250,9,252,3,2,243,1,249,23,243,4,253,241,223,249,2,241,11,246,14,0,245,3,255,12,252,252,9,11,243,243,253,242,1,3,6,251,8,0,5,5,246,4,5,250,226,250,4,0,251,4,1,255,255,3,6,5,254,251,0,254,5,252,254,252,254,4,7,249,255,1,252,253,237,37,12,10,216,249,2,249,244,17,11,249,2,2,3,1,255,3,4,254,251,9,247,6,4,9,12,11,251,2,255,0,9,5,249,254,232,249,6,1,3,1,0,6,0,4,244,254,254,1,247,10,254,11,255,21,244,15,251,10,251,5,251,14,250,5,249,253,227,254,0,251,254,253,1,253,0,4,2,3,0,2,254,7,254,3,251,2,255,6,252,0,253,8,245,19,248,22,222,13,221,255,253,255,9,11,253,253,255,7,18,11,251,2,244,245,18,9,251,1,250,247,12,1,253,253,247,242,9,9,8,250,230,0,5,251,255,255,254,4,6,8,2,255,254,5,1,251,252,1,1,18,1,7,246,3,254,12,255,241,9,12,242,13,218,3,0,248,255,0,8,247,253,248,16,3,16,251,247,0,255,249,255,252,13,7,0,1,2,255,240,0,254,1,8,248,228,7,9,251,253,254,2,0,3,11,250,252,254,254,251,28,238,250,2,15,246,241,246,254,0,254,254,4,253,7,11,5,226,9,0,249,255,252,249,2,2,9,254,2,3,248,250,250,3,246,4,10,5,21,252,14,238,1,3,246,254,6,14,248,230,242,255,2,3,253,7,1,234,255,255,0,1,12,242,3,251,0,10,253,1,251,12,253,10,248,234,245,243,249,246,243,231,254,251,252,252,247,238,9,253,251,17,13,5,6,11,3,8,20,4,2,9,8,5,6,1,7,249,250,254,249,0,239,233,251,251,2,0,6,2,254,2,253,4,4,0,251,254,252,6,8,10,255,1,251,5,242,254,245,8,6,25,7,255,0,213,252,0,4,254,7,0,3,17,5,2,251,1,21,3,254,246,240,247,7,244,9,248,2,5,251,246,254,245,251,255,247,226,254,3,1,252,255,0,8,1,12,4,255,255,3,239,13,9,0,7,250,251,9,1,5,4,246,238,0,14,11,252,240,228,255,0,2,255,4,1,255,1,255,254,255,254,3,0,0,255,255,1,2,254,3,3,254,4,254,255,250,1,255,255,6,186,7,3,245,255,12,252,242,4,4,252,4,254,2,244,252,15,239,252,253,6,8,251,22,234,5,245,15,252,4,255,235,255,10,254,243,11,4,14,4,9,8,8,19,15,14,15,5,10,8,15,251,4,14,248,1,1,2,1,255,253,21,8,227,13,250,0,250,6,255,2,8,252,251,4,252,251,0,254,252,0,9,254,1,254,26,237,21,246,4,1,248,5,22,246,243,15,11,251,1,0,6,3,7,254,254,253,251,255,254,250,1,1,248,251,243,13,254,253,255,247,228,4,2,245,18,236,232,9,7,4,253,6,6,250,249,251,249,252,252,0,249,251,250,251,2,243,244,2,0,5,18,15,243,249,13,236,16,246,237,6,5,248,255,5,10,2,255,246,245,23,8,251,248,4,251,252,251,251,245,248,5,1,7,247,247,250,12,14,17,244,234,3,251,248,253,3,12,255,0,252,251,1,1,6,1,5,251,7,254,7,1,6,6,2,0,251,17,252,251,232,13,236,229,14,255,2,253,1,253,1,253,0,254,3,254,1,2,255,254,255,254,251,5,254,0,249,1,250,8,8,11,251,24,213,243,2,254,4,7,253,252,4,13,252,0,0,254,9,0,253,250,1,249,1,255,10,0,5,255,232,25,241,7,2,22,246,235,0,251,2,6,254,13,3,5,244,245,16,6,10,251,0,253,6,5,251,251,10,12,10,11,249,8,242,2,241,13,242,248,253,5,6,249,251,5,2,9,5,0,255,252,2,8,0,3,5,244,3,253,250,2,255,251,14,11,236,235,231,24,255,246,6,251,5,254,9,4,252,255,250,11,250,5,0,2,253,6,255,239,238,252,243,9,255,9,249,252,248,2,253,12,225,238,5,249,245,6,248,4,253,244,0,255,250,253,0,5,9,7,2,1,248,250,8,2,251,7,255,16,246,16,244,18,255,231,244,3,244,1,2,254,238,248,241,246,247,2,249,11,245,2,255,255,255,247,250,3,242,254,255,2,243,249,247,19,251,239,2,7,1,248,7,17,243,246,5,7,1,250,4,9,252,0,3,8,1,242,247,4,7,247,0,6,251,244,254,25,254,237,1,7,253,6,253,1,6,249,0,10,0,4,251,239,252,4,255,0,253,249,19,24,255,21,8,10,9,8,255,23,254,238,254,3,253,0,5,8,254,247,2,9,6,19,8,2,6,247,254,252,253,248,7,249,248,5,4,26,250,7,18,24,0,243,4,0,243,245,255,3,247,5,4,249,3,0,2,255,4,251,2,9,254,245,15,1,235,1,255,0,4,242,252,24,240,243,1,1,247,248,0,0,252,11,255,14,16,0,17,254,247,244,0,255,242,247,242,0,254,19,4,6,4,4,245,8,239,237,251,253,1,2,12,252,238,255,252,249,14,253,2,0,249,248,12,251,247,14,12,247,254,4,250,4,18,255,231,22,2,233,251,254,0,0,0,1,3,5,255,5,254,254,2,253,0,1,2,0,255,2,255,247,250,249,252,254,4,249,251,64,253,231,4,12,254,253,0,8,247,13,249,6,253,244,12,15,247,252,2,9,252,244,3,14,1,7,241,15,0,250,244,0,253,236,6,2,255,252,5,9,6,249,2,254,249,254,0,255,238,252,250,241,251,11,5,246,255,2,7,12,237,249,8,21,252,241,4,4,2,5,5,251,1,3,2,248,13,0,251,254,242,245,6,2,17,8,243,26,254,5,241,252,242,12,247,13,235,233,252,2,253,254,253,3,254,6,9,247,13,4,2,12,253,253,1,239,234,253,4,3,254,1,247,1,250,11,243,14,0,241,6,240,252,17,254,236,245,11,10,5,248,16,2,239,242,11,11,250,245,249,12,12,246,250,5,8,252,254,251,28,3,243,4,0,253,3,249,6,8,244,20,237,18,245,10,251,0,247,11,3,0,254,9,249,251,18,3,254,240,1,6,12,249,240,1,4,1,5,251,15,2,248,3,5,245,15,253,8,248,255,7,4,7,254,6,247,5,12,2,33,254,250,238,4,0,238,11,3,255,1,255,0,1,4,255,251,0,1,0,4,2,255,4,253,2,0,254,4,6,255,6,42,19,252,219,19,1,241,252,2,0,251,0,10,0,0,251,3,0,0,253,253,0,2,252,246,2,250,4,4,1,27,249,17,222,5,247,15,240,249,251,254,7,7,254,9,254,241,11,11,7,5,1,15,1,247,31,2,241,2,4,3,4,255,248,2,249,6,239,11,242,245,2,1,1,245,9,9,250,242,245,246,8,253,11,16,247,248,243,248,9,0,6,6,254,13,248,254,3,13,253,10,250,239,4,14,5,4,250,244,10,249,8,21,248,226,15,254,1,11,247,251,1,0,255,255,250,254,3,251,7,9,5,251,2,0,1,255,2,20,239,241,3,3,7,11,239,243,250,253,18,17,241,252,252,251,22,14,242,254,246,249,11,8,249,253,0,249,11,7,245,249,248,242,22,5,2,6,13,244,254,10,3,0,235,252,20,3,10,21,246,244,8,11,2,251,2,1,3,255,15,255,254,255,254,243,8,252,0,7,254,239,8,18,5,3,8,248,254,3,252,14,238,243,14,15,243,255,254,4,11,1,12,13,250,252,240,239,16,21,254,5,245,247,19,21,239,253,239,3,12,8,244,250,1,249,9,9,249,251,255,253,5,250,252,11,5,12,236,250,10,4,12,8,251,246,15,13,14,10,241,243,1,6,14,15,239,243,4,251,10,7,250,248,253,252,12,25,255,7,251,249,11,1,17,13,241,242,252,5,3,8,253,254,2,0,6,16,244,250,252,4,253,7,246,253,249,243,7,248,10,253,243,5,2,4,9,9,239,243,2,11,1,6,252,8,246,4,1,19,241,252,12,31,7,251,239,252,9,254,7,14,250,250,250,242,13,17,251,4,242,247,7,7,247,3,240,241,11,11,6,4,245,237,3,5,8,13,242,242,3,252,12,254,252,10,252,249,255,27,5,2,240,238,4,12,254,253,254,255,1,248,244,3,252,8,15,2,4,9,243,242,9,249,5,4,2,246,251,249,2,1,4,255,250,241,6,1,10,5,246,247,255,13,253,5,235,245,8,8,5,27,235,238,251,255,15,11,1,240,248,245,0,5,248,244,243,239,22,4,250,255,238,246,0,19,2,254,248,249,253,2,254,247,239,251,4,4,10,8,250,237,251,252,12,14,15,10,247,255,247,19,12,0,255,2,4,7,9,16,240,242,9,252,3,1,0,254,10,255,255,12,248,12,247,0,25,7,9,2,225,247,252,15,4,251,1,246,11,8,10,0,250,5,11,255,250,4,246,247,6,4,5,14,6,239,254,17,12,247,2,0,231,242,5,20,14,8,236,5,2,254,253,9,243,253,255,250,3,7,250,0,2,3,1,8,4,241,253,10,18,252,13,8,234,246,9,19,241,7,251,243,12,252,9,2,247,250,0,2,1,247,250,6,1,255,11,4,1,4,251,246,18,7,2,252,247,245,0,32,249,4,240,255,0,6,3,6,253,242,16,9,254,7,255,0,251,5,253,253,2,3,248,250,4,6,2,4,244,241,2,8,8,9,253,238,6,34,11,12,241,255,2,9,2,252,252,2,4,2,253,18,250,244,248,255,15,20,252,255,245,251,6,6,245,241,249,3,7,10,2,8,246,251,8,15,251,5,239,243,13,11,7,8,252,250,255,242,253,6,254,1,251,255,10,10,241,5,0,246,252,253,7,252,237,241,27,11,18,3,237,254,6,0,12,12,0,251,0,4,251,1,5,10,249,245,21,29,1,254,1,252,245,255,13,11,236,255,4,4,4,251,6,243,254,11,9,2,249,249,253,246,255,20,12,1,237,237,255,5,4,249,231,14,1,253,2,12,252,253,253,254,6,1,0,3,2,5,255,12,248,3,244,246,10,13,0,23,242,238,10,0,15,3,244,253,251,5,252,2,242,246,8,2,9,255,245,253,5,13,2,9,250,7,249,226,17,6,13,1,242,0,255,6,247,8,3,252,0,255,249,251,243,237,253,252,4,250,254,243,1,254,3,10,1,3,238,230,17,4,240,4,253,243,252,250,245,252,235,7,8,2,5,13,250,1,5,8,7,9,250,250,1,255,2,253,255,0,254,254,0,255,3,4,242,248,247,13,2,50,233,248,8,7,11,16,3,249,0,254,6,5,255,1,254,4,3,1,3,1,1,250,3,6,6,2,254,253,10,2,248,251,251,5,4,4,254,10,248,216,255,21,8,3,252,255,13,4,7,2,0,252,248,5,2,7,251,5,248,252,255,12,2,12,243,247,0,1,244,9,213,1,251,12,1,3,6,1,255,3,254,6,254,255,1,0,4,8,14,4,249,233,251,23,239,250,241,248,7,10,255,7,240,4,250,2,3,253,253,255,8,255,4,10,4,252,1,7,253,2,11,4,250,253,8,5,4,1,211,250,252,4,2,1,242,246,1,1,6,2,248,255,253,3,3,1,255,2,253,248,9,3,3,254,251,248,8,7,249,252,250,5,247,11,254,46,251,255,9,254,0,3,251,253,251,7,0,252,1,254,255,245,11,8,253,254,246,0,4,9,9,239,239,222,252,251,249,253,244,253,11,18,3,254,251,238,251,253,6,7,251,253,1,252,253,251,255,2,5,254,3,246,12,238,251,246,12,247,4,250,2,0,16,239,15,14,244,246,254,247,255,4,251,253,251,253,255,7,18,249,12,3,5,248,252,236,1,231,1,248,13,246,8,237,255,248,10,6,247,255,0,12,4,252,5,0,255,2,5,248,254,250,4,248,9,3,2,249,4,231,13,233,10,14,15,245,3,238,4,16,252,1,246,246,3,5,253,255,253,4,1,253,252,251,1,244,14,249,11,241,6,250,24,252,13,255,15,243,8,3,7,251,2,2,0,3,249,253,1,0,8,6,255,6,5,251,254,244,4,0,254,253,5,250,0,248,9,246,4,228,12,236,11,243,7,238,1,245,1,1,252,241,5,0,243,251,13,245,4,252,251,5,242,240,0,242,5,236,12,10,249,251,6,6,22,6,252,254,3,8,11,13,245,254,16,16,249,0,20,249,255,0,5,247,12,254,251,234,5,246,12,250,11,9,21,248,15,4,0,248,252,252,10,18,252,243,0,1,241,255,253,2,10,255,6,1,252,236,251,248,6,248,17,251,5,246,8,234,6,251,254,8,239,8,2,1,254,247,6,225,248,248,8,0,5,247,252,2,3,244,11,238,10,251,3,245,13,250,11,253,12,249,3,247,255,2,11,247,250,21,248,241,4,245,12,245,17,255,2,250,0,241,13,244,19,0,2,250,253,247,10,3,17,254,5,246,253,0,1,4,250,5,246,1,251,1,0,0,0,2,7,254,2,254,0,252,3,252,1,244,6,207,16,246,13,0,254,8,6,1,8,5,248,249,9,13,251,7,0,10,11,252,253,255,13,242,6,241,250,242,16,15,1,238,252,236,20,249,255,247,254,246,10,244,4,0,10,0,3,8,4,229,255,254,19,252,2,243,3,1,9,244,1,234,19,251,4,247,12,2,247,248,11,253,7,4,251,11,250,17,239,5,252,254,250,1,251,2,4,242,6,236,19,236,12,235,5,242,13,254,11,4,253,0,246,252,254,254,255,253,8,247,249,234,253,232,13,254,10,241,5,247,4,249,0,251,15,248,11,243,6,252,19,248,12,252,6,9,7,2,253,2,255,0,3,1,2,1,252,254,253,1,5,244,6,240,14,233,10,242,17,241,16,254,9,231,9,246,16,4,9,253,7,248,253,2,2,252,248,247,10,3,245,25,246,228,27,247,7,243,9,254,4,244,248,242,6,7,246,3,3,253,5,248,253,1,246,8,253,247,252,13,7,2,4,246,4,3,7,238,2,234,15,4,20,249,5,250,13,255,4,249,250,6,13,254,3,0,2,252,254,0,0,1,2,254,251,0,1,252,0,254,253,1,2,255,2,248,255,232,68,253,8,3,3,255,255,241,254,247,249,255,8,242,8,3,6,0,255,248,8,233,2,242,17,241,8,252,7,238,0,248,253,255,252,246,4,255,4,8,0,2,249,0,5,1,3,245,4,248,14,3,20,1,26,245,13,243,20,254,0,248,2,250,6,255,9,3,250,253,10,5,0,255,249,10,1,253,5,4,7,251,255,253,255,12,253,241,7,247,22,237,8,247,4,233,13,242,6,250,242,252,7,14,251,248,246,25,3,233,249,228,0,255,247,4,1,243,20,248,10,240,8,12,243,235,5,243,11,254,1,12,249,2,246,251,252,9,5,250,35,249,8,15,2,255,247,250,2,238,7,241,6,253,2,8,12,226,7,252,20,2,6,13,250,252,0,1,8,247,9,251,12,247,16,247,16,239,14,243,15,238,14,241,17,244,14,243,7,240,13,247,5,245,10,247,6,244,13,246,252,5,3,1,6,8,242,251,15,7,4,8,7,234,8,249,248,241,26,1,13,253,17,251,9,254,4,250,3,248,9,8,253,2,3,3,1,254,255,245,8,252,0,250,251,255,13,219,9,1,250,246,254,246,11,8,13,253,254,250,8,252,13,3,2,253,252,252,7,248,9,248,9,236,12,237,15,238,17,241,7,255,20,245,6,250,3,1,9,2,242,254,254,2,1,249,1,255,253,250,4,4,253,3,255,5,252,3,2,255,9,197,5,252,30,3,3,254,253,255,2,2,1,255,255,254,1,0,253,2,0,255,248,0,2,253,4,252,1,10,6,250,8,249,4,10,11,215,27,236,3,253,8,1,11,251,248,0,4,5,1,4,254,1,2,255,6,249,2,11,4,0,0,248,7,246,0,0,8,2,10,255,1,254,44,254,235,244,253,255,2,252,4,254,254,6,248,2,1,246,14,8,6,5,1,254,4,243,4,2,5,10,254,235,32,253,18,9,250,247,247,10,2,9,240,250,254,1,4,22,2,254,1,253,254,247,3,16,19,232,250,250,251,248,249,8,249,255,244,5,253,0,4,2,253,10,3,240,252,255,13,4,4,1,253,1,250,242,18,3,8,248,228,240,4,4,2,12,7,9,252,252,5,255,255,2,2,251,243,234,253,248,21,254,247,21,252,247,5,248,15,5,1,251,247,249,254,251,251,255,251,251,251,3,10,252,0,249,254,5,246,238,2,20,4,13,246,8,241,245,253,255,16,10,9,248,6,7,251,6,11,5,17,252,7,245,5,253,250,2,1,3,251,237,1,1,253,254,231,245,239,0,243,252,10,10,2,251,4,0,3,253,251,246,254,13,234,0,3,245,251,7,255,12,242,227,6,255,10,7,239,244,14,3,9,247,9,7,6,253,243,0,5,3,255,250,255,0,2,4,244,251,255,2,11,12,241,249,254,244,17,20,240,254,244,250,15,250,12,11,9,7,250,7,252,237,6,2,2,3,245,246,252,251,253,3,2,11,234,250,0,8,18,3,245,252,249,241,239,244,6,16,4,247,4,251,3,6,240,10,249,249,253,5,0,1,241,252,5,12,234,240,5,250,8,12,252,247,239,245,3,5,8,239,0,11,252,243,250,2,255,255,3,3,245,244,255,1,1,12,254,8,246,223,251,253,250,1,249,248,252,250,255,5,252,250,244,240,248,11,8,242,7,12,11,4,242,253,6,249,251,253,3,0,248,249,2,252,24,2,247,245,253,249,11,244,17,1,255,3,251,249,12,4,11,0,3,2,238,253,4,7,250,3,15,10,241,240,254,252,247,7,241,250,2,240,13,248,7,19,235,252,244,247,253,253,6,11,253,255,237,3,249,247,252,3,250,251,246,235,0,253,249,18,235,15,251,244,252,243,2,6,247,247,245,252,13,253,6,4,255,7,247,252,9,5,2,6,3,15,255,229,254,10,3,7,248,9,254,7,1,254,251,18,9,245,239,254,7,247,11,10,0,248,6,240,253,2,249,3,11,4,247,217,19,6,243,13,251,251,241,254,9,0,4,14,6,246,252,251,2,252,254,5,245,3,3,254,254,249,9,7,246,5,245,248,10,254,12,16,0,12,254,250,8,14,8,7,1,18,226,4,10,252,250,2,245,9,246,248,5,0,0,249,6,255,240,246,11,0,13,12,252,252,251,235,12,4,13,14,249,6,240,243,8,2,9,15,244,1,247,234,10,247,9,9,249,4,244,229,1,254,11,15,3,14,242,247,0,247,16,22,10,16,246,5,251,247,1,1,6,6,252,2,239,251,250,241,255,7,244,239,1,247,5,20,249,3,23,248,248,248,255,13,17,249,243,4,252,7,14,8,11,253,253,4,0,4,6,255,247,7,241,241,252,10,12,3,243,6,14,9,248,241,14,23,251,246,251,1,15,246,249,1,9,4,243,246,10,7,253,2,3,4,246,242,0,3,4,0,247,253,252,245,2,239,8,2,15,6,244,244,15,251,17,18,3,253,253,252,250,248,13,4,10,254,238,230,10,252,10,13,4,252,240,249,239,253,5,252,2,241,246,255,248,249,253,2,2,8,246,249,2,2,252,4,255,4,237,251,255,255,250,2,248,10,240,228,250,8,255,11,28,2,246,252,6,250,6,11,15,252,254,7,3,7,249,4,1,253,250,246,251,13,18,10,241,251,253,243,5,1,2,18,251,246,246,249,4,2,1,5,4,2,5,4,8,247,239,7,7,20,244,254,252,5,14,7,245,255,240,250,252,245,17,14,0,248,246,248,10,3,5,10,240,3,248,242,10,3,9,0,3,12,246,220,0,7,15,2,240,2,255,0,255,5,4,5,253,1,246,5,255,241,253,244,12,2,5,255,5,6,253,254,2,17,241,225,23,252,15,254,253,6,249,251,1,244,4,6,8,246,8,3,5,252,1,5,3,255,252,253,1,10,252,254,254,6,238,251,12,10,12,14,245,15,2,247,250,251,254,247,4,251,228,252,14,0,240,9,14,255,3,252,252,2,1,0,4,251,242,225,8,16,7,13,243,5,6,240,10,251,2,254,2,14,251,8,251,7,240,6,243,251,0,251,8,253,255,4,3,1,254,255,0,6,5,2,252,253,255,0,1,4,2,43,28,244,221,254,254,249,255,0,2,255,254,254,1,252,0,254,3,2,247,234,12,3,3,249,252,237,234,242,252,255,21,9,253,241,240,243,1,245,4,247,1,249,255,255,0,254,9,243,253,255,253,233,0,2,12,3,247,252,7,3,9,246,1,27,28,0,9,241,254,254,1,6,8,248,7,253,20,0,0,255,250,255,11,8,254,1,5,250,255,4,2,252,0,255,251,4,250,246,244,19,1,249,9,248,247,240,245,254,12,14,4,4,34,17,7,250,1,4,246,251,4,245,3,238,4,14,243,253,1,0,0,245,0,7,239,252,4,245,250,248,18,0,0,0,26,250,249,255,255,11,248,1,3,2,11,250,250,10,253,1,253,7,4,244,248,0,247,8,234,251,0,250,22,254,11,243,24,253,4,0,3,9,10,255,3,247,244,1,251,18,0,253,8,25,15,248,2,2,254,4,8,9,255,251,10,253,1,255,23,251,2,247,255,253,0,3,255,246,252,0,243,16,9,255,242,2,6,254,250,251,254,249,7,5,3,11,254,242,0,247,30,4,6,6,5,253,255,4,5,10,0,5,252,7,245,14,14,7,34,247,0,246,22,249,255,7,247,2,248,0,249,251,29,252,3,255,252,253,5,1,252,0,2,4,2,1,255,246,1,6,250,252,1,4,253,253,251,0,3,7,244,0,254,246,55,5,9,255,0,4,9,235,247,4,2,6,249,11,249,1,251,0,252,2,253,243,248,0,247,252,2,16,254,241,249,245,31,8,2,255,0,3,251,251,5,1,255,247,1,0,250,254,255,5,2,0,0,12,20,237,1,8,244,245,0,6,251,2,31,255,255,254,1,255,3,247,251,8,254,5,255,0,254,4,254,253,244,0,254,3,0,9,4,255,21,248,3,252,9,250,30,252,0,249,17,10,244,254,246,244,253,10,0,11,252,243,253,5,6,10,7,248,0,249,243,1,0,254,7,244,4,253,24,243,9,4,254,2,252,242,255,253,251,246,4,13,254,5,13,8,3,254,1,5,250,7,238,246,1,255,5,4,1,0,25,251,255,18,12,8,8,240,255,1,1,1,252,251,3,3,4,4,245,244,240,250,2,12,243,0,9,7,9,247,0,246,24,252,1,253,0,2,252,4,1,5,0,253,2,253,254,2,255,1,4,255,254,254,1,255,255,252,255,252,254,250,6,12,69,8,5,11,0,241,252,13,6,0,252,9,1,251,253,15,0,1,6,251,0,1,6,5,8,0,7,1,255,252,245,247,41,252,247,32,250,0,7,252,6,250,1,250,254,4,248,251,253,240,255,254,250,1,15,0,21,3,253,252,3,244,16,2,27,250,251,1,247,251,3,7,253,5,5,14,13,20,249,255,12,255,10,245,245,249,252,242,7,242,13,22,18,255,0,14,28,248,3,254,0,5,6,255,252,1,3,249,3,1,241,4,247,22,246,247,252,1,8,252,9,241,2,250,252,240,12,246,23,0,0,2,0,255,3,253,255,3,251,7,1,5,251,248,1,13,241,251,249,12,250,254,3,10,251,248,17,251,245,242,23,249,252,6,252,5,250,251,2,252,11,9,252,2,254,252,6,15,3,253,18,241,254,250,3,3,236,17,11,252,2,3,29,6,1,250,2,3,0,0,253,3,3,255,3,252,250,250,249,253,254,249,254,252,5,3,251,236,243,252,10,242,227,14,37,3,4,3,250,252,5,0,3,2,3,0,254,4,0,253,251,252,4,252,4,4,3,1,252,252,247,242,20,226,3,238,33,0,2,5,254,252,254,255,2,250,253,254,254,2,251,255,4,3,2,253,0,255,255,246,249,2,252,238,2,219,255,12,40,249,2,255,0,254,4,248,1,252,12,7,4,15,249,1,247,18,0,12,239,253,255,0,0,0,2,250,0,252,253,255,26,250,4,8,251,250,254,2,255,1,255,241,8,7,255,239,252,1,5,6,245,250,14,17,251,241,11,8,0,253,241,250,28,255,0,0,0,1,0,255,0,1,3,2,254,3,255,255,2,2,255,255,249,1,2,247,0,255,252,238,7,246,49,243,32,255,253,4,1,2,251,1,249,255,5,247,4,4,25,1,255,2,251,2,249,17,254,10,251,0,2,241,3,247,7,247,30,251,255,0,2,1,255,2,5,223,3,251,14,11,7,5,253,2,248,252,254,249,250,4,248,255,248,2,254,248,255,252,27,255,0,255,254,1,255,254,255,2,0,1,2,2,4,1,3,4,2,1,249,252,1,253,252,221,231,17,10,253,230,249,32,251,1,6,254,6,6,247,3,255,252,5,252,254,254,247,2,251,2,2,4,3,5,251,240,225,244,245,2,237,20,254,21,251,2,7,249,249,5,249,2,0,0,252,3,255,0,255,254,0,253,5,245,248,253,249,249,28,245,249,0,240,245,252,29,2,1,253,254,255,3,4,0,1,0,255,251,4,251,244,2,254,251,234,254,255,11,8,249,244,0,222,6,251,11,248,19,255,253,5,11,18,254,254,251,254,4,255,8,5,250,1,255,2,8,4,251,248,254,5,238,7,12,7,19,238,2,250,243,9,0,0,5,4,3,250,4,1,252,5,255,252,8,8,6,248,250,0,6,253,3,5,253,17,31,16,10,243,0,247,237,12,246,2,254,254,255,253,6,244,251,254,14,240,4,12,12,17,4,7,240,7,250,11,7,7,2,231,23,232,5,249,247,10,4,13,10,10,3,250,3,3,2,255,250,8,4,10,0,1,2,252,2,253,248,0,255,9,9,246,253,227,1,255,229,2,2,0,7,9,254,246,255,255,1,247,251,8,4,1,2,246,1,13,12,253,15,247,2,249,1,246,23,236,238,247,241,253,251,255,8,0,251,255,4,7,255,249,2,248,251,11,7,250,3,253,247,7,9,234,1,6,252,14,27,231,242,3,251,1,3,8,4,7,6,12,239,241,1,248,246,7,242,248,6,254,254,245,245,249,13,254,254,4,5,251,13,233,250,239,248,251,4,242,251,252,251,6,5,248,251,254,245,249,244,3,245,2,250,4,246,251,249,14,5,23,11,7,12,240,250,252,240,5,6,2,5,254,251,251,250,251,237,243,255,253,243,5,0,6,254,254,250,249,249,255,247,4,14,17,244,229,3,0,255,7,255,9,246,8,2,249,254,5,2,253,249,3,0,6,4,12,5,11,14,243,255,8,1,13,9,12,12,238,242,245,240,249,251,250,251,0,255,253,2,2,1,4,9,2,3,5,254,2,1,8,0,3,0,254,2,1,7,29,0,220,251,247,235,14,250,247,0,255,248,248,245,2,2,247,244,12,252,5,3,251,247,11,255,253,12,235,253,12,5,3,11,238,241,1,254,255,3,247,253,7,249,238,2,4,12,246,2,8,253,242,13,17,251,5,247,13,253,249,238,17,254,5,7,236,253,250,245,253,3,3,255,1,250,251,1,5,253,242,250,251,248,14,250,7,255,5,1,15,255,249,252,6,245,9,254,219,16,249,253,255,0,6,1,253,247,0,11,248,2,254,0,5,2,12,246,10,13,2,7,250,2,246,246,21,251,5,5,244,233,3,242,6,0,254,1,0,1,0,252,1,1,8,254,2,251,254,1,8,252,255,255,4,255,2,6,32,1,251,236,216,252,238,242,2,2,249,254,4,4,255,2,0,254,252,249,3,5,0,251,1,2,250,4,255,254,255,241,8,3,9,46,249,238,6,245,5,5,16,21,3,245,252,11,244,2,4,244,255,11,8,1,252,11,245,235,1,1,245,3,13,1,5,12,231,1,253,254,1,6,249,4,2,3,1,251,8,9,241,3,253,242,17,4,248,14,254,248,252,5,8,249,8,9,7,6,227,239,8,4,249,249,4,0,13,1,0,4,4,240,246,249,5,9,241,246,246,8,252,255,245,255,246,241,3,3,14,10,237,2,238,244,252,0,2,0,5,254,247,0,4,252,2,255,254,2,252,9,2,250,252,254,255,253,253,255,2,5,255,11,232,212,247,241,255,246,6,21,11,15,249,10,242,247,248,248,4,6,19,1,250,1,251,239,248,246,9,5,11,18,255,10,240,249,247,248,3,251,0,0,254,254,250,4,252,1,255,0,7,253,4,252,249,7,17,236,6,4,1,250,244,31,13,19,242,246,249,254,254,6,246,3,9,6,242,15,2,251,2,245,9,248,4,6,20,241,253,253,255,32,235,6,1,9,11,17,237,6,255,253,8,10,254,0,248,240,7,7,6,10,4,242,7,250,21,249,10,5,5,0,249,2,250,0,249,11,247,15,236,249,245,2,0,249,5,2,0,253,250,252,254,255,252,251,243,255,27,247,250,245,249,1,11,252,252,242,254,11,6,10,237,250,241,2,0,7,255,2,249,241,254,253,13,251,251,12,3,0,5,251,234,2,7,22,13,0,255,2,3,2,249,7,229,252,252,244,11,1,240,6,241,1,3,2,0,2,253,2,5,254,251,9,5,253,3,254,245,3,9,6,9,3,255,12,215,8,250,9,3,249,3,2,5,5,0,255,1,3,251,254,243,7,255,254,254,250,4,250,0,2,254,2,4,1,252,1,209,235,7,250,3,16,249,13,252,254,10,253,255,18,243,7,243,252,8,4,8,9,251,13,8,251,3,250,7,18,248,10,231,253,244,244,1,255,255,0,2,5,251,253,0,251,255,0,252,248,254,3,2,254,239,250,252,1,33,250,236,250,8,31,230,248,255,252,3,253,253,5,253,254,1,7,0,3,6,3,6,254,9,15,246,253,241,251,253,252,250,226,17,248,254,2,236,0,248,254,254,255,255,255,3,251,254,253,4,254,0,5,8,253,1,252,1,1,253,4,4,242,3,11,251,3,253,7,253,13,23,240,2,250,1,253,5,0,250,245,249,252,255,2,249,255,255,7,1,254,6,12,250,8,243,17,25,233,237,249,244,9,16,239,9,4,4,4,253,255,6,254,253,0,13,252,249,14,1,249,0,251,3,237,253,5,3,9,255,9,243,13,239,4,21,230,0,251,0,0,252,251,2,250,252,5,249,10,0,2,0,254,254,0,4,250,7,254,6,5,251,2,244,1,227,29,27,12,9,246,234,6,255,255,9,242,244,254,1,255,10,245,240,0,3,11,13,242,247,254,255,6,4,242,0,246,254,16,17,245,2,0,255,254,4,3,250,254,1,255,1,3,252,1,3,252,255,255,4,255,1,0,1,6,251,249,2,1,209,253,50,239,8,252,245,249,11,11,14,249,12,249,6,2,13,250,253,254,242,6,6,6,0,2,255,5,236,2,255,4,251,6,21,245,254,247,3,0,250,7,8,248,1,253,4,1,5,254,253,249,4,7,244,247,254,10,250,13,6,5,20,2,241,9,28,249,0,251,250,250,250,1,250,6,254,4,8,253,12,255,252,254,6,16,242,9,242,254,248,229,253,18,255,249,253,8,23,233,1,4,247,255,251,10,254,1,245,1,247,4,7,14,247,254,253,2,251,255,250,246,249,11,20,2,3,237,3,15,30,247,7,2,242,252,0,254,5,2,5,254,8,253,249,6,6,245,242,1,10,255,249,248,1,10,3,250,241,244,239,4,30,250,4,2,1,254,3,0,1,0,2,0,1,6,249,0,3,4,4,252,254,251,254,2,255,254,0,254,245,249,253,42,24,242,4,1,3,2,0,254,253,254,2,255,4,11,254,2,3,252,251,9,2,252,247,5,8,255,249,1,24,243,228,20,15,234,253,7,6,3,254,251,246,254,254,255,250,250,254,242,240,250,251,0,18,0,9,1,7,243,251,250,247,11,241,9,22,245,9,254,6,5,2,9,246,1,1,5,252,12,2,2,246,249,252,250,7,9,6,15,6,6,246,10,5,243,251,6,24,244,1,3,253,253,8,1,250,2,251,253,7,2,14,6,9,250,251,252,27,7,253,8,250,3,248,8,22,251,250,254,22,239,254,254,3,10,9,9,12,241,255,245,243,3,254,1,253,245,7,9,16,253,246,251,251,1,8,253,9,9,251,3,31,244,7,251,10,252,248,2,16,254,10,10,253,254,3,248,253,3,243,250,15,20,247,253,244,1,254,240,8,8,255,16,22,251,5,253,241,254,12,248,8,251,2,248,20,238,14,252,3,3,7,243,240,1,246,7,16,7,4,242,252,251,247,8,23,250,5,252,251,252,1,8,4,249,251,8,10,6,250,246,254,6,9,239,242,11,12,253,243,249,2,18,3,231,240,18,22,251,5,6,249,236,252,2,8,4,232,252,1,4,251,254,1,246,254,9,3,252,253,252,252,252,10,10,3,0,250,25,21,245,0,7,255,14,250,252,246,5,4,4,4,251,3,4,255,249,8,237,0,6,2,3,238,253,250,2,8,14,230,22,27,243,254,250,7,251,12,249,8,255,3,254,4,1,8,254,0,14,6,251,6,252,249,7,235,8,1,8,247,252,253,11,25,243,4,4,255,250,4,9,248,1,253,246,254,0,15,247,240,11,1,1,6,3,247,251,16,26,1,242,1,253,242,7,15,247,244,254,247,243,2,6,14,0,1,0,255,243,0,10,255,6,9,249,8,8,19,6,255,9,10,252,1,249,234,254,29,249,2,4,13,244,248,252,251,13,12,251,253,253,252,1,255,10,15,250,255,245,226,4,15,255,9,249,0,254,249,10,25,240,7,241,249,249,255,251,251,245,236,10,3,246,253,5,20,252,0,254,254,17,2,0,253,3,6,5,255,244,253,15,22,240,4,255,3,4,251,0,255,251,232,227,4,247,1,253,0,0,0,252,7,252,252,252,3,1,250,5,253,251,246,3,25,246,254,255,255,4,4,255,2,0,252,252,2,255,253,255,254,254,1,253,251,255,2,253,252,252,253,5,247,1,245,7,46,210,0,247,3,4,4,3,251,250,5,252,4,254,1,7,252,246,13,1,3,250,4,252,7,2,237,231,253,240,244,16,20,255,18,6,4,244,0,242,9,250,255,252,251,2,1,12,4,2,7,0,2,5,245,251,254,2,252,10,0,247,249,9,25,248,5,0,250,5,6,3,3,246,251,1,255,4,3,245,248,5,4,251,5,251,249,251,11,5,20,248,240,21,252,27,23,251,255,254,254,0,255,2,1,2,2,0,1,254,255,254,254,0,80,119,35,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,155,34,0,112,0,0,0,16,180,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,1,0,6,14,43,52,2,83,1,1,13,1,1,1,1,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,2,4,0,0,0,0,1,103,66,0,30,166,128,176,126,64,0,0,0,1,104,206,56,128,0,0,0,32,74,36,0,112,0,0,0,112,129,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,206,36,0,16,0,0,0,104,88,39,0,16,0,0,0,240,42,37,0,16,0,0,0,40,217,35,0,20,0,0,0,48,232,34,0,32,0,0,0,144,37,34,0,40,0,0,0,232,134,33,0,20,0,0,0,200,11,33,0,28,0,0,0,120,165,32,0,32,0,0,0,0,74,32,0,28,0,0,0,240,48,40,0,32,0,0,0,64,212,39,0,48,0,0,0,104,108,39,0,64,0,0,0,16,28,39,0,4,0,0,0,160,215,38,0,4,0,0,0,16,188,38,0,136,123,38,0,8,0,0,0,5,0,0,0,184,242,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1132240);
/* memory initializer */ allocate([1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,10,71,10,99,10,145,10,210,10,37,11,139,11,2,12,140,12,39,13,213,13,147,14,99,15,68,16,53,17,55,18,73,19,106,20,155,21,219,22,42,24,134,25,241,26,105,28,237,29,126,31,27,33,195,34,118,36,52,38,251,39,203,41,164,43,133,45,109,47,92,49,82,51,77,53,77,55,81,57,89,59,100,61,114,63,129,65,146,67,163,69,180,71,196,73,211,75,223,77,233,79,239,81,241,83,239,85,231,87,218,89,198,91,170,93,135,95,92,97,40,99,234,100,162,102,80,104,242,105,137,107,20,109,146,110,3,112,103,113,189,114,4,116,60,117,102,118,128,119,137,120,131,121,108,122,69,123,12,124,194,124,102,125,249,125,121,126,232,126,68,127,142,127,198,127,235,127,254,127,254,127,235,127,198,127,142,127,68,127,232,126,121,126,249,125,102,125,194,124,12,124,69,123,108,122,131,121,137,120,128,119,102,118,60,117,4,116,189,114,103,113,3,112,146,110,20,109,137,107,242,105,80,104,162,102,234,100,40,99,92,97,135,95,170,93,198,91,218,89,231,87,239,85,241,83,239,81,233,79,223,77,211,75,196,73,180,71,163,69,146,67,129,65,114,63,100,61,89,59,81,57,77,55,77,53,82,51,92,49,109,47,133,45,164,43,203,41,251,39,52,38,118,36,195,34,27,33,126,31,237,29,105,28,241,26,134,25,42,24,219,22,155,21,106,20,73,19,55,18,53,17,68,16,99,15,147,14,213,13,39,13,140,12,2,12,139,11,37,11,210,10,145,10,99,10,71,10,61,10,2,0,0,0,3,0,0,0,28,0,0,0,30,0,0,0,27,0,0,0,29,0,0,0,39,1,0,0,41,1,0,0,40,1,0,0,42,1,0,0,42,0,0,0,68,0,0,0,36,1,0,0,38,1,0,0,255,255,255,255,0,0,0,0,0,218,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,7,0,0,26,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,102,35,0,224,83,35,0,148,0,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,32,64,16,0,1,0,0,0,0,0,240,5,37,0,112,219,36,0,24,0,0,0,84,65,82,86,24,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,224,158,36,0,112,219,36,0,24,0,0,0,84,65,82,86,24,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,128,131,36,0,8,105,36,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,72,77,36,0,8,105,36,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,32,54,36,0,144,15,36,0,48,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,216,36,0,112,0,0,0,64,113,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,28,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,5,0,0,18,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,223,34,0,88,28,34,0,220,1,48,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,32,129,33,0,152,5,33,0,224,1,48,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,64,160,32,0,224,68,32,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,192,44,40,0,176,207,39,0,80,103,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,44,40,0,0,24,39,0,104,211,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,44,40,0,192,142,38,0,176,83,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,192,44,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,240,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,0,0,0,0,136,5,0,0,0,0,0,0,0,0,0,0,72,194,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,0,0,0,0,226,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,23,37,0,112,0,0,0,56,115,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,57,35,0,208,37,35,0,192,133,6,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,200,250,34,0,200,250,34,0,196,133,6,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,4,0,4,0,4,0,4,0,3,0,3,0,3,0,3,0,72,120,35,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,75,35,0,112,0,0,0,112,117,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,120,32,0,0,116,32,0,248,53,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,32,106,32,0,88,81,32,0,4,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,128,68,32,0,208,61,32,0,220,53,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,136,54,32,0,216,47,32,0,0,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,248,33,38,0,152,171,39,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,248,33,38,0,144,96,37,0,208,3,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,200,9,35,0,144,66,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,176,160,33,0,208,35,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,24,184,32,0,160,91,32,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,40,66,40,0,152,232,39,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,128,127,39,0,232,43,39,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,112,228,38,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,176,158,38,0,184,98,38,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,126,32,0,112,0,0,0,128,118,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,68,32,0,208,61,32,0,220,53,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,136,54,32,0,216,47,32,0,0,54,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,17,0,0,0,0,0,0,0,192,36,32,0,216,30,32,0,224,53,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,248,33,38,0,152,171,39,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,248,33,38,0,144,96,37,0,208,3,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,200,9,35,0,144,66,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,176,160,33,0,208,35,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,24,184,32,0,160,91,32,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,40,66,40,0,152,232,39,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,128,127,39,0,232,43,39,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,112,228,38,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,176,158,38,0,184,98,38,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,255,255,255,255,0,241,0,0,0,241,2,0,0,241,3,0,8,48,0,0,8,48,2,0,8,48,3,0,8,192,0,0,8,192,2,0,8,192,3,0,8,240,0,0,8,240,2,0,8,240,3,0,0,0,0,0,1,0,2,0,1,0,3,0,0,0,0,0,152,153,36,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,254,1,2,0,0,0,0,208,41,32,0,112,0,0,0,80,121,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,3,0,2,0,4,0,4,0,5,0,5,0,6,0,7,0,38,0,8,0,33,0,8,0,10,0,10,0,29,0,12,0,24,0,12,0,19,0,12,0,16,0,12,0,26,0,13,0,25,0,13,0,24,0,13,0,23,0,13,0,3,0,3,0,6,0,6,0,37,0,8,0,12,0,10,0,27,0,12,0,22,0,13,0,21,0,13,0,5,0,4,0,4,0,7,0,11,0,10,0,20,0,12,0,20,0,13,0,7,0,5,0,36,0,8,0,28,0,12,0,19,0,13,0,6,0,5,0,15,0,10,0,18,0,12,0,7,0,6,0,9,0,10,0,18,0,13,0,5,0,6,0,30,0,12,0,4,0,6,0,21,0,12,0,7,0,7,0,17,0,12,0,5,0,7,0,17,0,13,0,39,0,8,0,16,0,13,0,35,0,8,0,34,0,8,0,32,0,8,0,14,0,10,0,13,0,10,0,8,0,10,0,31,0,12,0,26,0,12,0,25,0,12,0,23,0,12,0,22,0,12,0,31,0,13,0,30,0,13,0,29,0,13,0,28,0,13,0,27,0,13,0,1,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,7,7,8,8,9,9,10,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,1,2,3,4,5,6,7,1,2,3,4,5,1,2,3,4,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,3,0,0,0,16,0,0,0,5,0,0,0,16,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,96,120,35,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,110,37,0,112,0,0,0,160,122,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,188,0,0,0,0,0,0,225,226,0,0,8,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,12,0,1,0,9,0,0,0,0,0,1,0,10,0,0,0,2,0,0,0,11,0,0,0,2,0,0,0,12,0,0,0,25,0,0,0,13,0,0,0,25,0,0,0,14,0,0,0,25,0,0,0,15,0,0,0,25,0,0,0,16,0,0,0,3,80,1,0,17,0,0,0,2,0,0,0,20,0,0,0,1,0,0,0,22,0,0,0,1,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,224,1,0,0,1,0,0,0,0,2,0,0,1,0,0,0,64,2,0,0,2,0,0,0,96,2,0,0,2,0,0,0,56,4,0,0,4,0,0,0,208,2,0,0,6,0,0,0,117,43,124,141,151,167,73,237,152,94,213,60,140,199,95,132,109,127,94,21,177,208,17,186,145,0,128,95,180,185,126,0,141,212,137,230,118,144,181,70,145,239,115,106,81,0,206,180,255,0,0,0,0,255,0,0,0,128,255,0,0,85,170,255,48,154,36,0,112,0,0,0,96,130,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,204,33,0,0,0,0,0,0,0,8,0,48,204,33,0,120,203,33,0,0,0,4,0,8,0,0,0,66,0,0,0,32,0,0,0,0,0,0,0,0,5,15,10,25,30,20,35,104,128,128,255,0,0,0,0,49,128,128,255,0,0,0,0,221,102,102,102,102,221,150,51,51,51,51,150,221,150,150,150,150,221,221,51,51,51,51,221,48,210,35,0,160,227,34,0,4,0,0,0,4,0,0,0,51,51,51,51,51,51,243,63,82,184,30,133,235,81,224,63,0,0,0,0,0,0,80,64,16,0,1,0,0,0,0,0,8,33,34,0,40,132,33,0,12,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,64,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,107,36,0,112,0,0,0,104,128,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,1,6,5,0,0,0,2,3,1,6,5,0,0,0,2,3,1,6,5,0,0,0,15,0,7,11,13,14,3,5,10,12,1,2,4,8,6,9,47,31,15,0,23,27,29,30,7,11,13,14,39,43,45,46,16,3,5,10,12,19,21,26,28,35,37,42,44,1,2,4,8,17,18,20,24,6,9,22,25,32,33,34,36,40,38,41,47,31,15,0,23,27,29,30,7,11,13,14,39,43,45,46,16,3,5,10,12,19,21,26,28,35,37,42,44,1,2,4,8,17,18,20,24,6,9,22,25,32,33,34,36,40,38,41,0,1,2,4,8,3,5,10,12,15,7,11,13,14,6,9,0,16,1,2,4,8,32,3,5,10,12,15,47,7,11,13,14,6,9,31,35,37,42,44,33,34,36,40,39,43,45,46,17,18,20,24,19,21,26,28,23,27,29,30,22,25,38,41,0,16,1,2,4,8,32,3,5,10,12,15,47,7,11,13,14,6,9,31,35,37,42,44,33,34,36,40,39,43,45,46,17,18,20,24,19,21,26,28,23,27,29,30,22,25,38,41,0,0,0,0,1,3,4,6,7,7,7,7,6,4,3,1,0,2,5,7,7,7,7,7,7,5,2,0,0,0,0,0,0,0,0,0,1,2,3,3,3,3,2,1,1,1,2,2,0,1,2,3,3,3,3,2,1,0,0,0,1,2,2,1,136,98,32,0,224,72,40,0,16,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,224,239,39,0,184,133,39,0,216,48,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,224,239,39,0,128,234,38,0,96,163,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,224,239,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,175,39,0,112,0,0,0,128,131,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,191,32,0,112,0,0,0,96,130,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,73,70,56,57,97,0,0,71,73,70,56,57,97,0,0,71,73,70,56,55,97,0,0,71,73,70,56,55,97,0,0,0,0,0,0,1,1,1,1,1,1,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,10,11,11,11,12,12,12,12,13,13,13,14,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,30,30,31,31,32,32,33,33,34,34,35,35,36,36,37,37,38,39,39,40,40,41,41,42,42,43,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,30,30,31,31,32,32,33,33,34,34,35,35,36,36,37,37,38,38,39,39,40,40,41,41,42,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,144,1,0,0,0,0,0,0,125,0,0,0,120,0,0,0,115,0,0,0,110,0,0,0,105,0,0,0,100,0,0,0,95,0,0,0,85,0,0,0,80,0,0,0,75,0,0,0,70,0,0,0,65,0,0,0,60,0,0,0,55,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,30,30,31,31,32,32,33,33,34,34,35,35,36,36,37,37,38,38,39,39,40,40,41,41,42,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,62,64,66,68,70,72,74,76,78,80,208,7,0,0,0,0,0,0,100,0,0,0,115,0,0,0,130,0,0,0,145,0,0,0,160,0,0,0,175,0,0,0,190,0,0,0,200,0,0,0,210,0,0,0,220,0,0,0,230,0,0,0,240,0,0,0,4,1,0,0,14,1,0,0,24,1,0,0,34,1,0,0,44,1,0,0,54,1,0,0,64,1,0,0,74,1,0,0,84,1,0,0,94,1,0,0,104,1,0,0,114,1,0,0,124,1,0,0,134,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,255,255,255,255,2,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,43,1,0,0,44,1,0,0,35,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,82,0,0,0,61,1,0,0,255,255,255,255,0,0,0,0,144,69,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,227,36,0,96,192,36,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,16,163,32,0,96,192,36,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,112,163,36,0,80,136,36,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,240,71,32,0,80,136,36,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,40,109,36,0,160,81,36,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,16,47,40,0,160,81,36,0,28,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,80,57,36,0,232,27,36,0,32,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,152,224,35,0,232,27,36,0,32,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,184,195,35,0,64,172,35,0,44,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,128,144,38,0,64,172,35,0,44,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,168,150,35,0,160,128,35,0,36,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,120,26,39,0,160,128,35,0,36,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,40,106,35,0,0,87,35,0,40,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,232,213,38,0,0,87,35,0,40,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,69,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,246,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,4,0,0,0,8,0,0,0,2,0,0,0,16,163,32,0,240,71,32,0,16,47,40,0,56,210,39,0,56,106,39,0,0,0,0,0,120,26,39,0,232,213,38,0,128,144,38,0,56,210,39,0,56,106,39,0,0,0,0,0,224,122,36,0,112,0,0,0,176,137,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,78,4,78,5,78,6,78,15,78,18,78,23,78,31,78,32,78,33,78,35,78,38,78,41,78,46,78,47,78,49,78,51,78,53,78,55,78,60,78,64,78,65,78,66,78,68,78,70,78,74,78,81,78,85,78,87,78,90,78,91,78,98,78,99,78,100,78,101,78,103,78,104,78,106,78,107,78,108,78,109,78,110,78,111,78,114,78,116,78,117,78,118,78,119,78,120,78,121,78,122,78,123,78,124,78,125,78,127,78,128,78,129,78,130,78,131,78,132,78,133,78,135,78,138,78,144,78,150,78,151,78,153,78,156,78,157,78,158,78,163,78,170,78,175,78,176,78,177,78,180,78,182,78,183,78,184,78,185,78,188,78,189,78,190,78,200,78,204,78,207,78,208,78,210,78,218,78,219,78,220,78,224,78,226,78,230,78,231,78,233,78,237,78,238,78,239,78,241,78,244,78,248,78,249,78,250,78,252,78,254,78,0,79,2,79,3,79,4,79,5,79,6,79,7,79,8,79,11,79,12,79,18,79,19,79,20,79,21,79,22,79,28,79,29,79,33,79,35,79,40,79,41,79,44,79,45,79,46,79,49,79,51,79,53,79,55,79,57,79,59,79,62,79,63,79,64,79,65,79,66,79,68,79,69,79,71,79,72,79,73,79,74,79,75,79,76,79,82,79,84,79,86,79,97,79,98,79,102,79,104,79,106,79,107,79,109,79,110,79,113,79,114,79,117,79,119,79,120,79,121,79,122,79,125,79,128,79,129,79,130,79,133,79,134,79,135,79,138,79,140,79,142,79,144,79,146,79,147,79,149,79,150,79,152,79,153,79,154,79,156,79,158,79,159,79,161,79,162,79,164,79,171,79,173,79,176,79,177,79,178,79,179,79,180,79,182,79,183,79,184,79,185,79,186,79,187,79,188,79,189,79,190,79,192,79,193,79,194,79,198,79,199,79,200,79,201,79,203,79,204,79,205,79,210,79,211,79,212,79,213,79,214,79,217,79,219,79,224,79,226,79,228,79,229,79,231,79,235,79,236,79,240,79,242,79,244,79,245,79,246,79,247,79,249,79,251,79,252,79,253,79,255,79,0,80,1,80,2,80,3,80,4,80,5,80,6,80,7,80,8,80,9,80,10,80,11,80,14,80,16,80,17,80,19,80,21,80,22,80,23,80,27,80,29,80,30,80,32,80,34,80,35,80,36,80,39,80,43,80,47,80,48,80,49,80,50,80,51,80,52,80,53,80,54,80,55,80,56,80,57,80,59,80,61,80,63,80,64,80,65,80,66,80,68,80,69,80,70,80,73,80,74,80,75,80,77,80,80,80,81,80,82,80,83,80,84,80,86,80,87,80,88,80,89,80,91,80,93,80,94,80,95,80,96,80,97,80,98,80,99,80,100,80,102,80,103,80,104,80,105,80,106,80,107,80,109,80,110,80,111,80,112,80,113,80,114,80,115,80,116,80,117,80,120,80,121,80,122,80,124,80,125,80,129,80,130,80,131,80,132,80,134,80,135,80,137,80,138,80,139,80,140,80,142,80,143,80,144,80,145,80,146,80,147,80,148,80,149,80,150,80,151,80,152,80,153,80,154,80,155,80,156,80,157,80,158,80,159,80,160,80,161,80,162,80,164,80,166,80,170,80,171,80,173,80,174,80,175,80,176,80,177,80,179,80,180,80,181,80,182,80,183,80,184,80,185,80,188,80,189,80,190,80,191,80,192,80,193,80,194,80,195,80,196,80,197,80,198,80,199,80,200,80,201,80,202,80,203,80,204,80,205,80,206,80,208,80,209,80,210,80,211,80,212,80,213,80,215,80,216,80,217,80,219,80,220,80,221,80,222,80,223,80,224,80,225,80,226,80,227,80,228,80,229,80,232,80,233,80,234,80,235,80,239,80,240,80,241,80,242,80,244,80,246,80,247,80,248,80,249,80,250,80,252,80,253,80,254,80,255,80,0,81,1,81,2,81,3,81,4,81,5,81,8,81,9,81,10,81,12,81,13,81,14,81,15,81,16,81,17,81,19,81,20,81,21,81,22,81,23,81,24,81,25,81,26,81,27,81,28,81,29,81,30,81,31,81,32,81,34,81,35,81,36,81,37,81,38,81,39,81,40,81,41,81,42,81,43,81,44,81,45,81,46,81,47,81,48,81,49,81,50,81,51,81,52,81,53,81,54,81,55,81,56,81,57,81,58,81,59,81,60,81,61,81,62,81,66,81,71,81,74,81,76,81,78,81,79,81,80,81,82,81,83,81,87,81,88,81,89,81,91,81,93,81,94,81,95,81,96,81,97,81,99,81,100,81,102,81,103,81,105,81,106,81,111,81,114,81,122,81,126,81,127,81,131,81,132,81,134,81,135,81,138,81,139,81,142,81,143,81,144,81,145,81,147,81,148,81,152,81,154,81,157,81,158,81,159,81,161,81,163,81,166,81,167,81,168,81,169,81,170,81,173,81,174,81,180,81,184,81,185,81,186,81,190,81,191,81,193,81,194,81,195,81,197,81,200,81,202,81,205,81,206,81,208,81,210,81,211,81,212,81,213,81,214,81,215,81,216,81,217,81,218,81,220,81,222,81,223,81,226,81,227,81,229,81,230,81,231,81,232,81,233,81,234,81,236,81,238,81,241,81,242,81,244,81,247,81,254,81,4,82,5,82,9,82,11,82,12,82,15,82,16,82,19,82,20,82,21,82,28,82,30,82,31,82,33,82,34,82,35,82,37,82,38,82,39,82,42,82,44,82,47,82,49,82,50,82,52,82,53,82,60,82,62,82,68,82,69,82,70,82,71,82,72,82,73,82,75,82,78,82,79,82,82,82,83,82,85,82,87,82,88,82,89,82,90,82,91,82,93,82,95,82,96,82,98,82,99,82,100,82,102,82,104,82,107,82,108,82,109,82,110,82,112,82,113,82,115,82,116,82,117,82,118,82,119,82,120,82,121,82,122,82,123,82,124,82,126,82,128,82,131,82,132,82,133,82,134,82,135,82,137,82,138,82,139,82,140,82,141,82,142,82,143,82,145,82,146,82,148,82,149,82,150,82,151,82,152,82,153,82,154,82,156,82,164,82,165,82,166,82,167,82,174,82,175,82,176,82,180,82,181,82,182,82,183,82,184,82,185,82,186,82,187,82,188,82,189,82,192,82,193,82,194,82,196,82,197,82,198,82,200,82,202,82,204,82,205,82,206,82,207,82,209,82,211,82,212,82,213,82,215,82,217,82,218,82,219,82,220,82,221,82,222,82,224,82,225,82,226,82,227,82,229,82,230,82,231,82,232,82,233,82,234,82,235,82,236,82,237,82,238,82,239,82,241,82,242,82,243,82,244,82,245,82,246,82,247,82,248,82,251,82,252,82,253,82,1,83,2,83,3,83,4,83,7,83,9,83,10,83,11,83,12,83,14,83,17,83,18,83,19,83,20,83,24,83,27,83,28,83,30,83,31,83,34,83,36,83,37,83,39,83,40,83,41,83,43,83,44,83,45,83,47,83,48,83,49,83,50,83,51,83,52,83,53,83,54,83,55,83,56,83,60,83,61,83,64,83,66,83,68,83,70,83,75,83,76,83,77,83,80,83,84,83,88,83,89,83,91,83,93,83,101,83,104,83,106,83,108,83,109,83,114,83,118,83,121,83,123,83,124,83,125,83,126,83,128,83,129,83,131,83,135,83,136,83,138,83,142,83,143,83,144,83,145,83,146,83,147,83,148,83,150,83,151,83,153,83,155,83,156,83,158,83,160,83,161,83,164,83,167,83,170,83,171,83,172,83,173,83,175,83,176,83,177,83,178,83,179,83,180,83,181,83,183,83,184,83,185,83,186,83,188,83,189,83,190,83,192,83,195,83,196,83,197,83,198,83,199,83,206,83,207,83,208,83,210,83,211,83,213,83,218,83,220,83,221,83,222,83,225,83,226,83,231,83,244,83,250,83,254,83,255,83,0,84,2,84,5,84,7,84,11,84,20,84,24,84,25,84,26,84,28,84,34,84,36,84,37,84,42,84,48,84,51,84,54,84,55,84,58,84,61,84,63,84,65,84,66,84,68,84,69,84,71,84,73,84,76,84,77,84,78,84,79,84,81,84,90,84,93,84,94,84,95,84,96,84,97,84,99,84,101,84,103,84,105,84,106,84,107,84,108,84,109,84,110,84,111,84,112,84,116,84,121,84,122,84,126,84,127,84,129,84,131,84,133,84,135,84,136,84,137,84,138,84,141,84,145,84,147,84,151,84,152,84,156,84,158,84,159,84,160,84,161,84,162,84,165,84,174,84,176,84,178,84,181,84,182,84,183,84,185,84,186,84,188,84,190,84,195,84,197,84,202,84,203,84,214,84,216,84,219,84,224,84,225,84,226,84,227,84,228,84,235,84,236,84,239,84,240,84,241,84,244,84,245,84,246,84,247,84,248,84,249,84,251,84,254,84,0,85,2,85,3,85,4,85,5,85,8,85,10,85,11,85,12,85,13,85,14,85,18,85,19,85,21,85,22,85,23,85,24,85,25,85,26,85,28,85,29,85,30,85,31,85,33,85,37,85,38,85,40,85,41,85,43,85,45,85,50,85,52,85,53,85,54,85,56,85,57,85,58,85,59,85,61,85,64,85,66,85,69,85,71,85,72,85,75,85,76,85,77,85,78,85,79,85,81,85,82,85,83,85,84,85,87,85,88,85,89,85,90,85,91,85,93,85,94,85,95,85,96,85,98,85,99,85,104,85,105,85,107,85,111,85,112,85,113,85,114,85,115,85,116,85,121,85,122,85,125,85,127,85,133,85,134,85,140,85,141,85,142,85,144,85,146,85,147,85,149,85,150,85,151,85,154,85,155,85,158,85,160,85,161,85,162,85,163,85,164,85,165,85,166,85,168,85,169,85,170,85,171,85,172,85,173,85,174,85,175,85,176,85,178,85,180,85,182,85,184,85,186,85,188,85,191,85,192,85,193,85,194,85,195,85,198,85,199,85,200,85,202,85,203,85,206,85,207,85,208,85,213,85,215,85,216,85,217,85,218,85,219,85,222,85,224,85,226,85,231,85,233,85,237,85,238,85,240,85,241,85,244,85,246,85,248,85,249,85,250,85,251,85,252,85,255,85,2,86,3,86,4,86,5,86,6,86,7,86,10,86,11,86,13,86,16,86,17,86,18,86,19,86,20,86,21,86,22,86,23,86,25,86,26,86,28,86,29,86,32,86,33,86,34,86,37,86,38,86,40,86,41,86,42,86,43,86,46,86,47,86,48,86,51,86,53,86,55,86,56,86,58,86,60,86,61,86,62,86,64,86,65,86,66,86,67,86,68,86,69,86,70,86,71,86,72,86,73,86,74,86,75,86,79,86,80,86,81,86,82,86,83,86,85,86,86,86,90,86,91,86,93,86,94,86,95,86,96,86,97,86,99,86,101,86,102,86,103,86,109,86,110,86,111,86,112,86,114,86,115,86,116,86,117,86,119,86], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1142496);
/* memory initializer */ allocate([120,86,121,86,122,86,125,86,126,86,127,86,128,86,129,86,130,86,131,86,132,86,135,86,136,86,137,86,138,86,139,86,140,86,141,86,144,86,145,86,146,86,148,86,149,86,150,86,151,86,152,86,153,86,154,86,155,86,156,86,157,86,158,86,159,86,160,86,161,86,162,86,164,86,165,86,166,86,167,86,168,86,169,86,170,86,171,86,172,86,173,86,174,86,176,86,177,86,178,86,179,86,180,86,181,86,182,86,184,86,185,86,186,86,187,86,189,86,190,86,191,86,192,86,193,86,194,86,195,86,196,86,197,86,198,86,199,86,200,86,201,86,203,86,204,86,205,86,206,86,207,86,208,86,209,86,210,86,211,86,213,86,214,86,216,86,217,86,220,86,227,86,229,86,230,86,231,86,232,86,233,86,234,86,236,86,238,86,239,86,242,86,243,86,246,86,247,86,248,86,251,86,252,86,0,87,1,87,2,87,5,87,7,87,11,87,12,87,13,87,14,87,15,87,16,87,17,87,18,87,19,87,20,87,21,87,22,87,23,87,24,87,25,87,26,87,27,87,29,87,30,87,32,87,33,87,34,87,36,87,37,87,38,87,39,87,43,87,49,87,50,87,52,87,53,87,54,87,55,87,56,87,60,87,61,87,63,87,65,87,67,87,68,87,69,87,70,87,72,87,73,87,75,87,82,87,83,87,84,87,85,87,86,87,88,87,89,87,98,87,99,87,101,87,103,87,108,87,110,87,112,87,113,87,114,87,116,87,117,87,120,87,121,87,122,87,125,87,126,87,127,87,128,87,129,87,135,87,136,87,137,87,138,87,141,87,142,87,143,87,144,87,145,87,148,87,149,87,150,87,151,87,152,87,153,87,154,87,156,87,157,87,158,87,159,87,165,87,168,87,170,87,172,87,175,87,176,87,177,87,179,87,181,87,182,87,183,87,185,87,186,87,187,87,188,87,189,87,190,87,191,87,192,87,193,87,196,87,197,87,198,87,199,87,200,87,201,87,202,87,204,87,205,87,208,87,209,87,211,87,214,87,215,87,219,87,220,87,222,87,225,87,226,87,227,87,229,87,230,87,231,87,232,87,233,87,234,87,235,87,236,87,238,87,240,87,241,87,242,87,243,87,245,87,246,87,247,87,251,87,252,87,254,87,255,87,1,88,3,88,4,88,5,88,8,88,9,88,10,88,12,88,14,88,15,88,16,88,18,88,19,88,20,88,22,88,23,88,24,88,26,88,27,88,28,88,29,88,31,88,34,88,35,88,37,88,38,88,39,88,40,88,41,88,43,88,44,88,45,88,46,88,47,88,49,88,50,88,51,88,52,88,54,88,55,88,56,88,57,88,58,88,59,88,60,88,61,88,62,88,63,88,64,88,65,88,66,88,67,88,69,88,70,88,71,88,72,88,73,88,74,88,75,88,78,88,79,88,80,88,82,88,83,88,85,88,86,88,87,88,89,88,90,88,91,88,92,88,93,88,95,88,96,88,97,88,98,88,99,88,100,88,102,88,103,88,104,88,105,88,106,88,109,88,110,88,111,88,112,88,113,88,114,88,115,88,116,88,117,88,118,88,119,88,120,88,121,88,122,88,123,88,124,88,125,88,127,88,130,88,132,88,134,88,135,88,136,88,138,88,139,88,140,88,141,88,142,88,143,88,144,88,145,88,148,88,149,88,150,88,151,88,152,88,155,88,156,88,157,88,160,88,161,88,162,88,163,88,164,88,165,88,166,88,167,88,170,88,171,88,172,88,173,88,174,88,175,88,176,88,177,88,178,88,179,88,180,88,181,88,182,88,183,88,184,88,185,88,186,88,187,88,189,88,190,88,191,88,192,88,194,88,195,88,196,88,198,88,199,88,200,88,201,88,202,88,203,88,204,88,205,88,206,88,207,88,208,88,210,88,211,88,212,88,214,88,215,88,216,88,217,88,218,88,219,88,220,88,221,88,222,88,223,88,224,88,225,88,226,88,227,88,229,88,230,88,231,88,232,88,233,88,234,88,237,88,239,88,241,88,242,88,244,88,245,88,247,88,248,88,250,88,251,88,252,88,253,88,254,88,255,88,0,89,1,89,3,89,5,89,6,89,8,89,9,89,10,89,11,89,12,89,14,89,16,89,17,89,18,89,19,89,23,89,24,89,27,89,29,89,30,89,32,89,33,89,34,89,35,89,38,89,40,89,44,89,48,89,50,89,51,89,53,89,54,89,59,89,61,89,62,89,63,89,64,89,67,89,69,89,70,89,74,89,76,89,77,89,80,89,82,89,83,89,89,89,91,89,92,89,93,89,94,89,95,89,97,89,99,89,100,89,102,89,103,89,104,89,105,89,106,89,107,89,108,89,109,89,110,89,111,89,112,89,113,89,114,89,117,89,119,89,122,89,123,89,124,89,126,89,127,89,128,89,133,89,137,89,139,89,140,89,142,89,143,89,144,89,145,89,148,89,149,89,152,89,154,89,155,89,156,89,157,89,159,89,160,89,161,89,162,89,166,89,167,89,172,89,173,89,176,89,177,89,179,89,180,89,181,89,182,89,183,89,184,89,186,89,188,89,189,89,191,89,192,89,193,89,194,89,195,89,196,89,197,89,199,89,200,89,201,89,204,89,205,89,206,89,207,89,213,89,214,89,217,89,219,89,222,89,223,89,224,89,225,89,226,89,228,89,230,89,231,89,233,89,234,89,235,89,237,89,238,89,239,89,240,89,241,89,242,89,243,89,244,89,245,89,246,89,247,89,248,89,250,89,252,89,253,89,254,89,0,90,2,90,10,90,11,90,13,90,14,90,15,90,16,90,18,90,20,90,21,90,22,90,23,90,25,90,26,90,27,90,29,90,30,90,33,90,34,90,36,90,38,90,39,90,40,90,42,90,43,90,44,90,45,90,46,90,47,90,48,90,51,90,53,90,55,90,56,90,57,90,58,90,59,90,61,90,62,90,63,90,65,90,66,90,67,90,68,90,69,90,71,90,72,90,75,90,76,90,77,90,78,90,79,90,80,90,81,90,82,90,83,90,84,90,86,90,87,90,88,90,89,90,91,90,92,90,93,90,94,90,95,90,96,90,97,90,99,90,100,90,101,90,102,90,104,90,105,90,107,90,108,90,109,90,110,90,111,90,112,90,113,90,114,90,115,90,120,90,121,90,123,90,124,90,125,90,126,90,128,90,129,90,130,90,131,90,132,90,133,90,134,90,135,90,136,90,137,90,138,90,139,90,140,90,141,90,142,90,143,90,144,90,145,90,147,90,148,90,149,90,150,90,151,90,152,90,153,90,156,90,157,90,158,90,159,90,160,90,161,90,162,90,163,90,164,90,165,90,166,90,167,90,168,90,169,90,171,90,172,90,173,90,174,90,175,90,176,90,177,90,180,90,182,90,183,90,185,90,186,90,187,90,188,90,189,90,191,90,192,90,195,90,196,90,197,90,198,90,199,90,200,90,202,90,203,90,205,90,206,90,207,90,208,90,209,90,211,90,213,90,215,90,217,90,218,90,219,90,221,90,222,90,223,90,226,90,228,90,229,90,231,90,232,90,234,90,236,90,237,90,238,90,239,90,240,90,242,90,243,90,244,90,245,90,246,90,247,90,248,90,249,90,250,90,251,90,252,90,253,90,254,90,255,90,0,91,1,91,2,91,3,91,4,91,5,91,6,91,7,91,8,91,10,91,11,91,12,91,13,91,14,91,15,91,16,91,17,91,18,91,19,91,20,91,21,91,24,91,25,91,26,91,27,91,28,91,29,91,30,91,31,91,32,91,33,91,34,91,35,91,36,91,37,91,38,91,39,91,40,91,41,91,42,91,43,91,44,91,45,91,46,91,47,91,48,91,49,91,51,91,53,91,54,91,56,91,57,91,58,91,59,91,60,91,61,91,62,91,63,91,65,91,66,91,67,91,68,91,69,91,70,91,71,91,72,91,73,91,74,91,75,91,76,91,77,91,78,91,79,91,82,91,86,91,94,91,96,91,97,91,103,91,104,91,107,91,109,91,110,91,111,91,114,91,116,91,118,91,119,91,120,91,121,91,123,91,124,91,126,91,127,91,130,91,134,91,138,91,141,91,142,91,144,91,145,91,146,91,148,91,150,91,159,91,167,91,168,91,169,91,172,91,173,91,174,91,175,91,177,91,178,91,183,91,186,91,187,91,188,91,192,91,193,91,195,91,200,91,201,91,202,91,203,91,205,91,206,91,207,91,209,91,212,91,213,91,214,91,215,91,216,91,217,91,218,91,219,91,220,91,224,91,226,91,227,91,230,91,231,91,233,91,234,91,235,91,236,91,237,91,239,91,241,91,242,91,243,91,244,91,245,91,246,91,247,91,253,91,254,91,0,92,2,92,3,92,5,92,7,92,8,92,11,92,12,92,13,92,14,92,16,92,18,92,19,92,23,92,25,92,27,92,30,92,31,92,32,92,33,92,35,92,38,92,40,92,41,92,42,92,43,92,45,92,46,92,47,92,48,92,50,92,51,92,53,92,54,92,55,92,67,92,68,92,70,92,71,92,76,92,77,92,82,92,83,92,84,92,86,92,87,92,88,92,90,92,91,92,92,92,93,92,95,92,98,92,100,92,103,92,104,92,105,92,106,92,107,92,108,92,109,92,112,92,114,92,115,92,116,92,117,92,118,92,119,92,120,92,123,92,124,92,125,92,126,92,128,92,131,92,132,92,133,92,134,92,135,92,137,92,138,92,139,92,142,92,143,92,146,92,147,92,149,92,157,92,158,92,159,92,160,92,161,92,164,92,165,92,166,92,167,92,168,92,170,92,174,92,175,92,176,92,178,92,180,92,182,92,185,92,186,92,187,92,188,92,190,92,192,92,194,92,195,92,197,92,198,92,199,92,200,92,201,92,202,92,204,92,205,92,206,92,207,92,208,92,209,92,211,92,212,92,213,92,214,92,215,92,216,92,218,92,219,92,220,92,221,92,222,92,223,92,224,92,226,92,227,92,231,92,233,92,235,92,236,92,238,92,239,92,241,92,242,92,243,92,244,92,245,92,246,92,247,92,248,92,249,92,250,92,252,92,253,92,254,92,255,92,0,93,1,93,4,93,5,93,8,93,9,93,10,93,11,93,12,93,13,93,15,93,16,93,17,93,18,93,19,93,21,93,23,93,24,93,25,93,26,93,28,93,29,93,31,93,32,93,33,93,34,93,35,93,37,93,40,93,42,93,43,93,44,93,47,93,48,93,49,93,50,93,51,93,53,93,54,93,55,93,56,93,57,93,58,93,59,93,60,93,63,93,64,93,65,93,66,93,67,93,68,93,69,93,70,93,72,93,73,93,77,93,78,93,79,93,80,93,81,93,82,93,83,93,84,93,85,93,86,93,87,93,89,93,90,93,92,93,94,93,95,93,96,93,97,93,98,93,99,93,100,93,101,93,102,93,103,93,104,93,106,93,109,93,110,93,112,93,113,93,114,93,115,93,117,93,118,93,119,93,120,93,121,93,122,93,123,93,124,93,125,93,126,93,127,93,128,93,129,93,131,93,132,93,133,93,134,93,135,93,136,93,137,93,138,93,139,93,140,93,141,93,142,93,143,93,144,93,145,93,146,93,147,93,148,93,149,93,150,93,151,93,152,93,154,93,155,93,156,93,158,93,159,93,160,93,161,93,162,93,163,93,164,93,165,93,166,93,167,93,168,93,169,93,170,93,171,93,172,93,173,93,174,93,175,93,176,93,177,93,178,93,179,93,180,93,181,93,182,93,184,93,185,93,186,93,187,93,188,93,189,93,190,93,191,93,192,93,193,93,194,93,195,93,196,93,198,93,199,93,200,93,201,93,202,93,203,93,204,93,206,93,207,93,208,93,209,93,210,93,211,93,212,93,213,93,214,93,215,93,216,93,217,93,218,93,220,93,223,93,224,93,227,93,228,93,234,93,236,93,237,93,240,93,245,93,246,93,248,93,249,93,250,93,251,93,252,93,255,93,0,94,4,94,7,94,9,94,10,94,11,94,13,94,14,94,18,94,19,94,23,94,30,94,31,94,32,94,33,94,34,94,35,94,36,94,37,94,40,94,41,94,42,94,43,94,44,94,47,94,48,94,50,94,51,94,52,94,53,94,54,94,57,94,58,94,62,94,63,94,64,94,65,94,67,94,70,94,71,94,72,94,73,94,74,94,75,94,77,94,78,94,79,94,80,94,81,94,82,94,83,94,86,94,87,94,88,94,89,94,90,94,92,94,93,94,95,94,96,94,99,94,100,94,101,94,102,94,103,94,104,94,105,94,106,94,107,94,108,94,109,94,110,94,111,94,112,94,113,94,117,94,119,94,121,94,126,94,129,94,130,94,131,94,133,94,136,94,137,94,140,94,141,94,142,94,146,94,152,94,155,94,157,94,161,94,162,94,163,94,164,94,168,94,169,94,170,94,171,94,172,94,174,94,175,94,176,94,177,94,178,94,180,94,186,94,187,94,188,94,189,94,191,94,192,94,193,94,194,94,195,94,196,94,197,94,198,94,199,94,200,94,203,94,204,94,205,94,206,94,207,94,208,94,212,94,213,94,215,94,216,94,217,94,218,94,220,94,221,94,222,94,223,94,224,94,225,94,226,94,227,94,228,94,229,94,230,94,231,94,233,94,235,94,236,94,237,94,238,94,239,94,240,94,241,94,242,94,243,94,245,94,248,94,249,94,251,94,252,94,253,94,5,95,6,95,7,95,9,95,12,95,13,95,14,95,16,95,18,95,20,95,22,95,25,95,26,95,28,95,29,95,30,95,33,95,34,95,35,95,36,95,40,95,43,95,44,95,46,95,48,95,50,95,51,95,52,95,53,95,54,95,55,95,56,95,59,95,61,95,62,95,63,95,65,95,66,95,67,95,68,95,69,95,70,95,71,95,72,95,73,95,74,95,75,95,76,95,77,95,78,95,79,95,81,95,84,95,89,95,90,95,91,95,92,95,94,95,95,95,96,95,99,95,101,95,103,95,104,95,107,95,110,95,111,95,114,95,116,95,117,95,118,95,120,95,122,95,125,95,126,95,127,95,131,95,134,95,141,95,142,95,143,95,145,95,147,95,148,95,150,95,154,95,155,95,157,95,158,95,159,95,160,95,162,95,163,95,164,95,165,95,166,95,167,95,169,95,171,95,172,95,175,95,176,95,177,95,178,95,179,95,180,95,182,95,184,95,185,95,186,95,187,95,190,95,191,95,192,95,193,95,194,95,199,95,200,95,202,95,203,95,206,95,211,95,212,95,213,95,218,95,219,95,220,95,222,95,223,95,226,95,227,95,229,95,230,95,232,95,233,95,236,95,239,95,240,95,242,95,243,95,244,95,246,95,247,95,249,95,250,95,252,95,7,96,8,96,9,96,11,96,12,96,16,96,17,96,19,96,23,96,24,96,26,96,30,96,31,96,34,96,35,96,36,96,44,96,45,96,46,96,48,96,49,96,50,96,51,96,52,96,54,96,55,96,56,96,57,96,58,96,61,96,62,96,64,96,68,96,69,96,70,96,71,96,72,96,73,96,74,96,76,96,78,96,79,96,81,96,83,96,84,96,86,96,87,96,88,96,91,96,92,96,94,96,95,96,96,96,97,96,101,96,102,96,110,96,113,96,114,96,116,96,117,96,119,96,126,96,128,96,129,96,130,96,133,96,134,96,135,96,136,96,138,96,139,96,142,96,143,96,144,96,145,96,147,96,149,96,151,96,152,96,153,96,156,96,158,96,161,96,162,96,164,96,165,96,167,96,169,96,170,96,174,96,176,96,179,96,181,96,182,96,183,96,185,96,186,96,189,96,190,96,191,96,192,96,193,96,194,96,195,96,196,96,199,96,200,96,201,96,204,96,205,96,206,96,207,96,208,96,210,96,211,96,212,96,214,96,215,96,217,96,219,96,222,96,225,96,226,96,227,96,228,96,229,96,234,96,241,96,242,96,245,96,247,96,248,96,251,96,252,96,253,96,254,96,255,96,2,97,3,97,4,97,5,97,7,97,10,97,11,97,12,97,16,97,17,97,18,97,19,97,20,97,22,97,23,97,24,97,25,97,27,97,28,97,29,97,30,97,33,97,34,97,37,97,40,97,41,97,42,97,44,97,45,97,46,97,47,97,48,97,49,97,50,97,51,97,52,97,53,97,54,97,55,97,56,97,57,97,58,97,59,97,60,97,61,97,62,97,64,97,65,97,66,97,67,97,68,97,69,97,70,97,71,97,73,97,75,97,77,97,79,97,80,97,82,97,83,97,84,97,86,97,87,97,88,97,89,97,90,97,91,97,92,97,94,97,95,97,96,97,97,97,99,97,100,97,101,97,102,97,105,97,106,97,107,97,108,97,109,97,110,97,111,97,113,97,114,97,115,97,116,97,118,97,120,97,121,97,122,97,123,97,124,97,125,97,126,97,127,97,128,97,129,97,130,97,131,97,132,97,133,97,134,97,135,97,136,97,137,97,138,97,140,97,141,97,143,97,144,97,145,97,146,97,147,97,149,97,150,97,151,97,152,97,153,97,154,97,155,97,156,97,158,97,159,97,160,97,161,97,162,97,163,97,164,97,165,97,166,97,170,97,171,97,173,97,174,97,175,97,176,97,177,97,178,97,179,97,180,97,181,97,182,97,184,97,185,97,186,97,187,97,188,97,189,97,191,97,192,97,193,97,195,97,196,97,197,97,198,97,199,97,201,97,204,97,205,97,206,97,207,97,208,97,211,97,213,97,214,97,215,97,216,97,217,97,218,97,219,97,220,97,221,97,222,97,223,97,224,97,225,97,226,97,227,97,228,97,229,97,231,97,232,97,233,97,234,97,235,97,236,97,237,97,238,97,239,97,240,97,241,97,242,97,243,97,244,97,246,97,247,97,248,97,249,97,250,97,251,97,252,97,253,97,254,97,0,98,1,98,2,98,3,98,4,98,5,98,7,98,9,98,19,98,20,98,25,98,28,98,29,98,30,98,32,98,35,98,38,98,39,98,40,98,41,98,43,98,45,98,47,98,48,98,49,98,50,98,53,98,54,98,56,98,57,98,58,98,59,98,60,98,66,98,68,98,69,98,70,98,74,98,79,98,80,98,85,98,86,98,87,98,89,98,90,98,92,98,93,98,94,98,95,98,96,98,97,98,98,98,100,98,101,98,104,98,113,98,114,98,116,98,117,98,119,98,120,98,122,98,123,98,125,98,129,98,130,98,131,98,133,98,134,98,135,98,136,98,139,98,140,98,141,98,142,98,143,98,144,98,148,98,153,98,156,98,157,98,158,98,163,98,166,98,167,98,169,98,170,98,173,98,174,98,175,98,176,98,178,98,179,98,180,98,182,98,183,98,184,98,186,98,190,98,192,98,193,98,195,98,203,98,207,98,209,98,213,98,221,98,222,98,224,98,225,98,228,98,234,98,235,98,240,98,242,98,245,98,248,98,249,98,250,98,251,98,0,99,3,99,4,99,5,99,6,99,10,99,11,99,12,99,13,99,15,99,16,99,18,99,19,99,20,99,21,99,23,99,24,99,25,99,28,99,38,99,39,99,41,99,44,99,45,99,46,99,48,99,49,99,51,99,52,99,53,99,54,99,55,99,56,99,59,99,60,99,62,99,63,99,64,99,65,99,68,99,71,99,72,99,74,99,81,99,82,99,83,99,84,99,86,99,87,99,88,99,89,99,90,99,91,99,92,99,93,99,96,99,100,99,101,99,102,99,104,99,106,99,107,99,108,99,111,99,112,99,114,99,115,99,116,99,117,99,120,99,121,99,124,99,125,99,126,99,127,99,129,99,131,99,132,99,133,99,134,99,139,99,141,99,145,99,147,99,148,99,149,99,151,99,153,99,154,99,155,99,156,99,157,99,158,99,159,99,161,99,164,99,166,99,171,99,175,99,177,99,178,99,181,99,182,99,185,99,187,99,189,99,191,99,192,99,193,99,194,99,195,99,197,99,199,99,200,99,202,99,203,99,204,99,209,99,211,99,212,99,213,99,215,99,216,99,217,99,218,99,219,99,220,99,221,99,223,99,226,99,228,99,229,99,230,99,231,99,232,99,235,99,236,99,238,99,239,99,240,99,241,99,243,99,245,99,247,99,249,99,250,99,251,99,252,99,254,99,3,100,4,100,6,100,7,100,8,100,9,100,10,100,13,100,14,100,17,100,18,100,21,100,22,100,23,100,24,100,25,100,26,100,29,100,31,100,34,100,35,100,36,100,37,100,39,100,40,100,41,100,43,100,46,100,47,100,48,100,49,100,50,100,51,100,53,100,54,100,55,100,56,100,57,100,59,100,60,100,62,100,64,100,66,100,67,100,73,100,75,100,76,100,77,100,78,100,79,100,80,100,81,100,83,100,85,100,86,100,87,100,89,100,90,100,91,100,92,100,93,100,95,100,96,100,97,100,98,100,99,100,100,100,101,100,102,100,104,100,106,100,107,100,108,100,110,100,111,100,112,100,113,100,114,100,115,100,116,100,117,100,118,100,119,100,123,100,124,100,125,100,126,100,127,100,128,100,129,100,131,100,134,100,136,100,137,100,138,100,139,100,140,100,141,100,142,100,143,100,144,100,147,100,148,100,151,100,152,100,154,100,155,100,156,100,157,100,159,100,160,100,161,100,162,100,163,100,165,100,166,100,167,100,168,100,170,100,171,100,175,100,177,100,178,100,179,100,180,100,182,100,185,100,187,100,189,100,190,100,191,100,193,100,195,100,196,100,198,100,199,100,200,100,201,100,202,100,203,100,204,100,207,100,209,100,211,100,212,100,213,100,214,100,217,100,218,100,219,100,220,100,221,100,223,100,224,100,225,100,227,100,229,100,231,100,232,100,233,100,234,100,235,100,236,100,237,100,238,100,239,100,240,100,241,100,242,100,243,100,244,100,245,100,246,100,247,100,248,100,249,100,250,100,251,100,252,100,253,100,254,100,255,100,1,101,2,101,3,101,4,101,5,101,6,101,7,101,8,101,10,101,11,101,12,101,13,101,14,101,15,101,16,101,17,101,19,101,20,101,21,101,22,101,23,101,25,101,26,101,27,101,28,101,29,101,30,101,31,101,32,101,33,101,34,101,35,101,36,101,38,101,39,101,40,101,41,101,42,101,44,101,45,101,48,101,49,101,50,101,51,101,55,101,58,101,60,101,61,101,64,101,65,101,66,101,67,101,68,101,70,101,71,101,74,101,75,101,77,101,78,101,80,101,82,101,83,101,84,101,87,101,88,101,90,101,92,101,95,101,96,101,97,101,100,101,101,101,103,101,104,101,105,101,106,101,109,101,110,101,111,101,113,101,115,101,117,101,118,101,120,101,121,101,122,101,123,101,124,101,125,101,126,101,127,101,128,101,129,101,130,101,131,101,132,101,133,101,134,101,136,101,137,101,138,101,141,101,142,101,143,101,146,101,148,101,149,101,150,101,152,101,154,101,157,101,158,101,160,101,162,101,163,101,166,101,168,101,170,101,172,101,174,101,177,101,178,101,179,101,180,101,181,101,182,101,183,101,184,101,186,101,187,101,190,101,191,101,192,101,194,101,199,101,200,101,201,101,202,101,205,101,208,101,209,101,211,101,212,101,213,101,216,101,217,101,218,101,219,101,220,101,221,101,222,101,223,101,225,101,227,101,228,101,234,101,235,101,242,101,243,101,244,101,245,101,248,101,249,101,251,101,252,101,253,101,254,101,255,101,1,102,4,102,5,102,7,102,8,102,9,102,11,102,13,102,16,102,17,102,18,102,22,102,23,102,24,102,26,102,27,102,28,102,30,102,33,102,34,102,35,102,36,102,38,102,41,102,42,102,43,102,44,102,46,102,48,102,50,102,51,102,55,102,56,102,57,102,58,102,59,102,61,102,63,102,64,102,66,102,68,102,69,102,70,102,71,102,72,102,73,102,74,102,77,102,78,102,80,102,81,102,88,102,89,102,91,102,92,102,93,102,94,102,96,102,98,102,99,102,101,102,103,102,105,102,106,102,107,102,108,102,109,102,113,102,114,102,115,102,117,102,120,102,121,102,123,102,124,102,125,102,127,102,128,102,129,102,131,102,133,102,134,102,136,102,137,102,138,102,139,102,141,102,142,102,143,102,144,102,146,102,147,102,148,102,149,102,152,102,153,102,154,102,155,102,156,102,158,102,159,102,160,102,161,102,162,102,163,102,164,102,165,102,166,102,169,102,170,102,171,102,172,102,173,102,175,102,176,102,177,102,178,102,179,102,181,102,182,102,183,102,184,102,186,102,187,102,188,102,189,102,191,102,192,102,193,102,194,102,195,102,196,102,197,102,198,102,199,102,200,102,201,102,202,102,203,102,204,102,205,102,206,102,207,102,208,102,209,102,210,102,211,102,212,102,213,102,214,102,215,102,216,102,218,102,222,102,223,102,224,102,225,102,226,102,227,102,228,102,229,102,231,102,232,102,234,102,235,102,236,102,237,102,238,102,239,102,241,102,245,102,246,102,248,102,250,102,251,102,253,102,1,103,2,103,3,103,4,103,5,103,6,103,7,103,12,103,14,103,15,103,17,103,18,103,19,103,22,103,24,103,25,103,26,103,28,103,30,103,32,103,33,103,34,103,35,103,36,103,37,103,39,103,41,103,46,103,48,103,50,103,51,103,54,103,55,103,56,103,57,103,59,103,60,103,62,103,63,103,65,103,68,103,69,103,71,103,74,103,75,103,77,103,82,103,84,103,85,103,87,103,88,103,89,103,90,103,91,103,93,103,98,103,99,103,100,103,102,103,103,103,107,103,108,103,110,103,113,103,116,103,118,103,120,103,121,103,122,103,123,103,125,103,128,103,130,103,131,103,133,103,134,103,136,103,138,103,140,103,141,103,142,103,143,103,145,103,146,103,147,103,148,103,150,103,153,103,155,103,159,103,160,103,161,103,164,103,166,103,169,103,172,103,174,103,177,103,178,103,180,103,185,103,186,103,187,103,188,103,189,103,190,103,191,103,192,103,194,103,197,103,198,103,199,103,200,103,201,103,202,103,203,103,204,103,205,103,206,103,213,103,214,103,215,103,219,103,223,103,225,103,227,103,228,103,230,103,231,103,232,103,234,103,235,103,237,103,238,103,242,103,245,103,246,103,247,103,248,103,249,103,250,103,251,103,252,103,254,103,1,104,2,104,3,104,4,104,6,104,13,104,16,104,18,104,20,104,21,104,24,104,25,104,26,104,27,104,28,104,30,104,31,104,32,104,34,104,35,104,36,104,37,104,38,104,39,104,40,104,43,104,44,104,45,104,46,104,47,104,48,104,49,104,52,104,53,104,54,104,58,104,59,104,63,104,71,104,75,104,77,104,79,104,82,104,86,104,87,104,88,104,89,104,90,104,91,104,92,104,93,104,94,104,95,104,106,104,108,104,109,104,110,104,111,104,112,104,113,104,114,104,115,104,117,104,120,104,121,104,122,104,123,104,124,104,125,104,126,104,127,104,128,104,130,104,132,104,135,104,136,104,137,104,138,104,139,104,140,104,141,104,142,104,144,104,145,104,146,104,148,104,149,104,150,104,152,104,153,104,154,104,155,104,156,104,157,104,158,104,159,104,160,104,161,104,163,104,164,104,165,104,169,104,170,104,171,104,172,104,174,104,177,104,178,104,180,104,182,104,183,104,184,104,185,104,186,104,187,104,188,104,189,104,190,104,191,104,193,104,195,104,196,104,197,104,198,104,199,104,200,104,202,104,204,104,206,104,207,104,208,104,209,104,211,104,212,104,214,104,215,104,217,104,219,104,220,104,221,104,222,104,223,104,225,104,226,104,228,104,229,104,230,104,231,104,232,104,233,104,234,104,235,104,236,104,237,104,239,104,242,104,243,104,244,104,246,104,247,104,248,104,251,104,253,104,254,104,255,104,0,105,2,105,3,105,4,105,6,105,7,105,8,105,9,105,10,105,12,105,15,105,17,105,19,105,20,105,21,105,22,105,23,105,24,105,25,105,26,105,27,105,28,105,29,105,30,105,33,105,34,105,35,105,37,105,38,105,39,105,40,105,41,105,42,105,43,105,44,105,46,105,47,105,49,105,50,105,51,105,53,105,54,105,55,105,56,105,58,105,59,105,60,105,62,105,64,105,65,105,67,105,68,105,69,105,70,105,71,105,72,105,73,105,74,105,75,105,76,105,77,105,78,105,79,105,80,105,81,105,82,105,83,105,85,105,86,105,88,105,89,105,91,105,92,105,95,105,97,105,98,105,100,105,101,105,103,105,104,105,105,105,106,105,108,105,109,105,111,105,112,105,114,105,115,105,116,105,117,105,118,105,122,105,123,105,125,105,126,105,127,105,129,105,131,105,133,105,138,105,139,105,140,105,142,105,143,105,144,105,145,105,146,105,147,105,150,105,151,105,153,105,154,105,157,105,158,105,159,105,160,105,161,105,162,105,163,105,164,105,165,105,166,105,169,105,170,105,172,105,174,105,175,105,176,105,178,105,179,105,181,105,182,105,184,105,185,105,186,105,188,105,189,105,190,105,191,105,192,105,194,105,195,105,196,105,197,105,198,105,199,105,200,105,201,105,203,105,205,105,207,105,209,105,210,105,211,105,213,105,214,105,215,105,216,105,217,105,218,105,220,105,221,105,222,105,225,105,226,105,227,105,228,105,229,105,230,105,231,105,232,105,233,105,234,105,235,105,236,105,238,105,239,105,240,105,241,105,243,105,244,105,245,105,246,105,247,105,248,105,249,105,250,105,251,105,252,105,254,105,0,106,1,106,2,106,3,106,4,106,5,106,6,106,7,106,8,106,9,106,11,106,12,106,13,106,14,106,15,106,16,106,17,106,18,106,19,106,20,106,21,106,22,106,25,106,26,106,27,106,28,106,29,106,30,106,32,106,34,106,35,106,36,106,37,106,38,106,39,106,41,106,43,106,44,106,45,106,46,106,48,106,50,106,51,106,52,106,54,106,55,106,56,106,57,106,58,106,59,106,60,106,63,106,64,106,65,106,66,106,67,106,69,106,70,106,72,106,73,106,74,106,75,106,76,106,77,106,78,106,79,106,81,106,82,106,83,106,84,106,85,106,86,106,87,106,90,106,92,106,93,106,94,106,95,106,96,106,98,106,99,106,100,106,102,106,103,106,104,106,105,106,106,106,107,106,108,106,109,106,110,106,111,106,112,106,114,106,115,106,116,106,117,106,118,106,119,106,120,106,122,106,123,106,125,106,126,106,127,106,129,106,130,106,131,106,133,106,134,106,135,106,136,106,137,106,138,106,139,106,140,106,141,106,143,106,146,106,147,106,148,106,149,106,150,106,152,106,153,106,154,106,155,106,156,106,157,106,158,106,159,106,161,106,162,106,163,106,164,106,165,106,166,106,167,106,168,106,170,106,173,106,174,106,175,106,176,106,177,106,178,106,179,106,180,106,181,106,182,106,183,106,184,106,185,106,186,106,187,106,188,106,189,106,190,106,191,106,192,106,193,106,194,106,195,106,196,106,197,106,198,106,199,106,200,106,201,106,202,106,203,106,204,106,205,106,206,106,207,106,208,106,209,106,210,106,211,106,212,106,213,106,214,106,215,106,216,106,217,106,218,106,219,106,220,106,221,106,222,106,223,106,224,106,225,106,226,106,227,106,228,106,229,106,230,106,231,106,232,106,233,106,234,106,235,106,236,106,237,106,238,106,239,106,240,106,241,106,242,106,243,106,244,106,245,106,246,106,247,106,248,106,249,106,250,106,251,106,252,106,253,106,254,106,255,106,0,107,1,107,2,107,3,107,4,107,5,107,6,107,7,107,8,107,9,107,10,107,11,107,12,107,13,107,14,107,15,107,16,107,17,107,18,107,19,107,20,107,21,107,22,107,23,107,24,107,25,107,26,107,27,107,28,107,29,107,30,107,31,107,37,107,38,107,40,107,41,107,42,107,43,107,44,107,45,107,46,107,47,107,48,107,49,107,51,107,52,107,53,107,54,107,56,107,59,107,60,107,61,107,63,107,64,107,65,107,66,107,68,107,69,107,72,107,74,107,75,107,77,107,78,107,79,107,80,107,81,107,82,107,83,107,84,107,85,107,86,107,87,107,88,107,90,107,91,107,92,107,93,107,94,107,95,107,96,107,97,107,104,107,105,107,107,107,108,107,109,107,110,107,111,107,112,107,113,107,114,107,115,107,116,107,117,107,118,107,119,107,120,107,122,107,125,107,126,107,127,107,128,107,133,107,136,107,140,107,142,107,143,107,144,107,145,107,148,107,149,107,151,107,152,107,153,107,156,107,157,107,158,107,159,107,160,107,162,107,163,107,164,107,165,107,166,107,167,107,168,107,169,107,171,107,172,107,173,107,174,107,175,107,176,107,177,107,178,107,182,107,184,107,185,107,186,107,187,107,188,107,189,107,190,107,192,107,195,107,196,107,198,107,199,107,200,107,201,107,202,107,204,107,206,107,208,107,209,107,216,107,218,107,220,107,221,107,222,107,223,107,224,107,226,107,227,107,228,107,229,107,230,107,231,107,232,107,233,107,236,107,237,107,238,107,240,107,241,107,242,107,244,107,246,107,247,107,248,107,250,107,251,107,252,107,254,107,255,107,0,108,1,108,2,108,3,108,4,108,8,108,9,108,10,108,11,108,12,108,14,108,18,108,23,108,28,108,29,108,30,108,32,108,35,108,37,108,43,108,44,108,45,108,49,108,51,108,54,108,55,108,57,108,58,108,59,108,60,108,62,108,63,108,67,108,68,108,69,108,72,108,75,108,76,108,77,108,78,108,79,108,81,108,82,108,83,108,86,108,88,108,89,108,90,108,98,108,99,108,101,108,102,108,103,108,107,108,108,108,109,108,110,108,111,108,113,108,115,108,117,108,119,108,120,108,122,108,123,108,124,108,127,108,128,108,132,108,135,108,138,108,139,108,141,108,142,108,145,108,146,108,149,108,150,108,151,108,152,108,154,108,156,108,157,108,158,108,160,108,162,108,168,108,172,108,175,108,176,108,180,108,181,108,182,108,183,108,186,108,192,108,193,108,194,108,195,108,198,108,199,108,200,108,203,108,205,108,206,108,207,108,209,108,210,108,216,108,217,108,218,108,220,108,221,108,223,108,228,108,230,108,231,108,233,108,236,108,237,108,242,108,244,108,249,108,255,108,0,109,2,109,3,109,5,109,6,109,8,109,9,109,10,109,13,109,15,109,16,109,17,109,19,109,20,109,21,109,22,109,24,109,28,109,29,109,31,109,32,109,33,109,34,109,35,109,36,109,38,109,40,109,41,109,44,109,45,109,47,109,48,109,52,109,54,109,55,109,56,109,58,109,63,109,64,109,66,109,68,109,73,109,76,109,80,109,85,109,86,109,87,109,88,109,91,109,93,109,95,109,97,109,98,109,100,109,101,109,103,109,104,109,107,109,108,109,109,109,112,109,113,109,114,109,115,109,117,109,118,109,121,109,122,109,123,109,125,109,126,109,127,109,128,109,129,109,131,109,132,109,134,109,135,109,138,109,139,109,141,109,143,109,144,109,146,109,150,109,151,109,152,109,153,109,154,109,156,109,162,109,165,109,172,109,173,109,176,109,177,109,179,109,180,109,182,109,183,109,185,109,186,109,187,109,188,109,189,109,190,109,193,109,194,109,195,109,200,109,201,109,202,109,205,109,206,109,207,109,208,109,210,109,211,109,212,109,213,109,215,109,218,109,219,109,220,109,223,109,226,109,227,109,229,109,231,109,232,109,233,109,234,109,237,109,239,109,240,109,242,109,244,109,245,109,246,109,248,109,250,109,253,109,254,109,255,109,0,110,1,110,2,110,3,110,4,110,6,110,7,110,8,110,9,110,11,110,15,110,18,110,19,110,21,110,24,110,25,110,27,110,28,110,30,110,31,110,34,110,38,110,39,110,40,110,42,110,44,110,46,110,48,110,49,110,51,110,53,110,54,110,55,110,57,110,59,110,60,110,61,110,62,110,63,110,64,110,65,110,66,110,69,110,70,110,71,110,72,110,73,110,74,110,75,110,76,110,79,110,80,110,81,110,82,110,85,110,87,110,89,110,90,110,92,110,93,110,94,110,96,110,97,110,98,110,99,110,100,110,101,110,102,110,103,110,104,110,105,110,106,110,108,110,109,110,111,110,112,110,113,110,114,110,115,110,116,110,117,110,118,110,119,110,120,110,121,110,122,110,123,110,124,110,125,110,128,110,129,110,130,110,132,110,135,110,136,110,138,110,139,110,140,110,141,110,142,110,145,110,146,110,147,110,148,110,149,110,150,110,151,110,153,110,154,110,155,110,157,110,158,110,160,110,161,110,163,110,164,110,166,110,168,110,169,110,171,110,172,110,173,110,174,110,176,110,179,110,181,110,184,110,185,110,188,110,190,110,191,110,192,110,195,110,196,110,197,110,198,110,200,110,201,110,202,110,204,110,205,110,206,110,208,110,210,110,214,110,216,110,217,110,219,110,220,110,221,110,227,110,231,110,234,110,235,110,236,110,237,110,238,110,239,110,240,110,241,110,242,110,243,110,245,110,246,110,247,110,248,110,250,110,251,110,252,110,253,110,254,110,255,110,0,111,1,111,3,111,4,111,5,111,7,111,8,111,10,111,11,111,12,111,13,111,14,111,16,111,17,111,18,111,22,111,23,111,24,111,25,111,26,111,27,111,28,111,29,111,30,111,31,111,33,111,34,111,35,111,37,111,38,111,39,111,40,111,44,111,46,111,48,111,50,111,52,111,53,111,55,111,56,111,57,111,58,111,59,111,60,111,61,111,63,111,64,111,65,111,66,111,67,111,68,111,69,111,72,111,73,111,74,111,76,111,78,111,79,111,80,111,81,111,82,111,83,111,84,111,85,111,86,111,87,111,89,111,90,111,91,111,93,111,95,111,96,111,97,111,99,111,100,111,101,111,103,111,104,111,105,111,106,111,107,111,108,111,111,111,112,111,113,111,115,111,117,111,118,111,119,111,121,111,123,111,125,111,126,111,127,111,128,111,129,111,130,111,131,111,133,111,134,111,135,111,138,111,139,111,143,111,144,111,145,111,146,111,147,111,148,111,149,111,150,111,151,111,152,111,153,111,154,111,155,111,157,111,158,111,159,111,160,111,162,111,163,111,164,111,165,111,166,111,168,111,169,111,170,111,171,111,172,111,173,111,174,111,175,111,176,111,177,111,178,111,180,111,181,111,183,111,184,111,186,111,187,111,188,111,189,111,190,111,191,111,193,111,195,111,196,111,197,111,198,111,199,111,200,111,202,111,203,111,204,111,205,111,206,111,207,111,208,111,211,111,212,111,213,111,214,111,215,111,216,111,217,111,218,111,219,111,220,111,221,111,223,111,226,111,227,111,228,111,229,111,230,111,231,111,232,111,233,111,234,111,235,111,236,111,237,111,240,111,241,111,242,111,243,111,244,111,245,111,246,111,247,111,248,111,249,111,250,111,251,111,252,111,253,111,254,111,255,111,0,112,1,112,2,112,3,112,4,112,5,112,6,112,7,112,8,112,9,112,10,112,11,112,12,112,13,112,14,112,15,112,16,112,18,112,19,112,20,112,21,112,22,112,23,112,24,112,25,112,28,112,29,112,30,112,31,112,32,112,33,112,34,112,36,112,37,112,38,112,39,112,40,112,41,112,42,112,43,112,44,112,45,112,46,112,47,112,48,112,49,112,50,112,51,112,52,112,54,112,55,112,56,112,58,112,59,112,60,112,61,112,62,112,63,112,64,112,65,112,66,112,67,112,68,112,69,112,70,112,71,112,72,112,73,112,74,112,75,112,77,112,78,112,80,112,81,112,82,112,83,112,84,112,85,112,86,112,87,112,88,112,89,112,90,112,91,112,92,112,93,112,95,112,96,112,97,112,98,112,99,112,100,112,101,112,102,112,103,112,104,112,105,112,106,112,110,112,113,112,114,112,115,112,116,112,119,112,121,112,122,112,123,112,125,112,129,112,130,112,131,112,132,112,134,112,135,112,136,112,139,112,140,112,141,112,143,112,144,112,145,112,147,112,151,112,152,112,154,112,155,112,158,112,159,112,160,112,161,112,162,112,163,112,164,112,165,112,166,112,167,112,168,112,169,112,170,112,176,112,178,112,180,112,181,112,182,112,186,112,190,112,191,112,196,112,197,112,198,112,199,112,201,112,203,112,204,112,205,112,206,112,207,112,208,112,209,112,210,112,211,112,212,112,213,112,214,112,215,112,218,112,220,112,221,112,222,112,224,112,225,112,226,112,227,112,229,112,234,112,238,112,240,112,241,112,242,112,243,112,244,112,245,112,246,112,248,112,250,112,251,112,252,112,254,112,255,112,0,113,1,113,2,113,3,113,4,113,5,113,6,113,7,113,8,113,11,113,12,113,13,113,14,113,15,113,17,113,18,113,20,113,23,113,27,113,28,113,29,113,30,113,31,113,32,113,33,113,34,113,35,113,36,113,37,113,39,113,40,113,41,113,42,113,43,113,44,113,45,113,46,113,50,113,51,113,52,113,53,113,55,113,56,113,57,113,58,113,59,113,60,113,61,113,62,113,63,113,64,113,65,113,66,113,67,113,68,113,70,113,71,113,72,113,73,113,75,113,77,113,79,113,80,113,81,113,82,113,83,113,84,113,85,113,86,113,87,113,88,113,89,113,90,113,91,113,93,113,95,113,96,113,97,113,98,113,99,113,101,113,105,113,106,113,107,113,108,113,109,113,111,113,112,113,113,113,116,113,117,113,118,113,119,113,121,113,123,113,124,113,126,113,127,113,128,113,129,113,130,113,131,113,133,113,134,113,135,113,136,113,137,113,139,113,140,113,141,113,142,113,144,113,145,113,146,113,147,113,149,113,150,113,151,113,154,113,155,113,156,113,157,113,158,113,161,113,162,113,163,113,164,113,165,113,166,113,167,113,169,113,170,113,171,113,173,113,174,113,175,113,176,113,177,113,178,113,180,113,182,113,183,113,184,113,186,113,187,113,188,113,189,113,190,113,191,113,192,113,193,113,194,113,196,113,197,113,198,113,199,113,200,113,201,113,202,113,203,113,204,113,205,113,207,113,208,113,209,113,210,113,211,113,214,113,215,113,216,113,217,113,218,113,219,113,220,113,221,113,222,113,223,113,225,113,226,113,227,113,228,113,230,113,232,113,233,113,234,113,235,113,236,113,237,113,239,113,240,113,241,113,242,113,243,113,244,113,245,113,246,113,247,113,248,113,250,113,251,113,252,113,253,113,254,113,255,113,0,114,1,114,2,114,3,114,4,114,5,114,7,114,8,114,9,114,10,114,11,114,12,114,13,114,14,114,15,114,16,114,17,114,18,114,19,114,20,114,21,114,22,114,23,114,24,114,25,114,26,114,27,114,28,114,30,114,31,114,32,114,33,114,34,114,35,114,36,114,37,114,38,114,39,114,41,114,43,114,45,114,46,114,47,114,50,114,51,114,52,114,58,114,60,114,62,114,64,114,65,114,66,114,67,114,68,114,69,114,70,114,73,114,74,114,75,114,78,114,79,114,80,114,81,114,83,114,84,114,85,114,87,114,88,114,90,114,92,114,94,114,96,114,99,114,100,114,101,114,104,114,106,114,107,114,108,114,109,114,112,114,113,114,115,114,116,114,118,114,119,114,120,114,123,114,124,114,125,114,130,114,131,114,133,114,134,114,135,114,136,114,137,114,140,114,142,114,144,114,145,114,147,114,148,114,149,114,150,114,151,114,152,114,153,114,154,114,155,114,156,114,157,114,158,114,160,114,161,114,162,114,163,114,164,114,165,114,166,114,167,114,168,114,169,114,170,114,171,114,174,114,177,114,178,114,179,114,181,114,186,114,187,114,188,114,189,114,190,114,191,114,192,114,197,114,198,114,199,114,201,114,202,114,203,114,204,114,207,114,209,114,211,114,212,114,213,114,214,114,216,114,218,114,219,114,198,228,199,228,200,228,201,228,202,228,203,228,204,228,205,228,206,228,207,228,208,228,209,228,210,228,211,228,212,228,213,228,214,228,215,228,216,228,217,228,218,228,219,228,220,228,221,228,222,228,223,228,224,228,225,228,226,228,227,228,228,228,229,228,230,228,231,228,232,228,233,228,234,228,235,228,236,228,237,228,238,228,239,228,240,228,241,228,242,228,243,228,244,228,245,228,246,228,247,228,248,228,249,228,250,228,251,228,252,228,253,228,254,228,255,228,0,229,1,229,2,229,3,229,4,229,5,229,6,229,7,229,8,229,9,229,10,229,11,229,12,229,13,229,14,229,15,229,16,229,17,229,18,229,19,229,20,229,21,229,22,229,23,229,24,229,25,229,26,229,27,229,28,229,29,229,30,229,31,229,32,229,33,229,34,229,35,229,36,229,37,229,0,48,1,48,2,48,183,0,201,2,199,2,168,0,3,48,5,48,20,32,94,255,22,32,38,32,24,32,25,32,28,32,29,32,20,48,21,48,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,22,48,23,48,16,48,17,48,177,0,215,0,247,0,54,34,39,34,40,34,17,34,15,34,42,34,41,34,8,34,55,34,26,34,165,34,37,34,32,34,18,35,153,34,43,34,46,34,97,34,76,34,72,34,61,34,29,34,96,34,110,34,111,34,100,34,101,34,30,34,53,34,52,34,66,38,64,38,176,0,50,32,51,32,3,33,4,255,164,0,224,255,225,255,48,32,167,0,22,33,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,59,32,146,33,144,33,145,33,147,33,19,48,38,229,39,229,40,229,41,229,42,229,43,229,44,229,45,229,46,229,47,229,48,229,49,229,50,229,51,229,52,229,53,229,54,229,55,229,56,229,57,229,58,229,59,229,60,229,61,229,62,229,63,229,64,229,65,229,66,229,67,229,68,229,69,229,70,229,71,229,72,229,73,229,74,229,75,229,76,229,77,229,78,229,79,229,80,229,81,229,82,229,83,229,84,229,85,229,86,229,87,229,88,229,89,229,90,229,91,229,92,229,93,229,94,229,95,229,96,229,97,229,98,229,99,229,100,229,101,229,102,229,103,229], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1152736);
/* memory initializer */ allocate([104,229,105,229,106,229,107,229,108,229,109,229,110,229,111,229,112,229,113,229,114,229,115,229,116,229,117,229,118,229,119,229,120,229,121,229,122,229,123,229,124,229,125,229,126,229,127,229,128,229,129,229,130,229,131,229,132,229,133,229,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,102,231,103,231,104,231,105,231,106,231,107,231,136,36,137,36,138,36,139,36,140,36,141,36,142,36,143,36,144,36,145,36,146,36,147,36,148,36,149,36,150,36,151,36,152,36,153,36,154,36,155,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,126,36,127,36,128,36,129,36,130,36,131,36,132,36,133,36,134,36,135,36,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,172,32,109,231,32,50,33,50,34,50,35,50,36,50,37,50,38,50,39,50,40,50,41,50,110,231,111,231,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,106,33,107,33,112,231,113,231,134,229,135,229,136,229,137,229,138,229,139,229,140,229,141,229,142,229,143,229,144,229,145,229,146,229,147,229,148,229,149,229,150,229,151,229,152,229,153,229,154,229,155,229,156,229,157,229,158,229,159,229,160,229,161,229,162,229,163,229,164,229,165,229,166,229,167,229,168,229,169,229,170,229,171,229,172,229,173,229,174,229,175,229,176,229,177,229,178,229,179,229,180,229,181,229,182,229,183,229,184,229,185,229,186,229,187,229,188,229,189,229,190,229,191,229,192,229,193,229,194,229,195,229,196,229,197,229,198,229,199,229,200,229,201,229,202,229,203,229,204,229,205,229,206,229,207,229,208,229,209,229,210,229,211,229,212,229,213,229,214,229,215,229,216,229,217,229,218,229,219,229,220,229,221,229,222,229,223,229,224,229,225,229,226,229,227,229,228,229,229,229,1,255,2,255,3,255,229,255,5,255,6,255,7,255,8,255,9,255,10,255,11,255,12,255,13,255,14,255,15,255,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,26,255,27,255,28,255,29,255,30,255,31,255,32,255,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,59,255,60,255,61,255,62,255,63,255,64,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,91,255,92,255,93,255,227,255,230,229,231,229,232,229,233,229,234,229,235,229,236,229,237,229,238,229,239,229,240,229,241,229,242,229,243,229,244,229,245,229,246,229,247,229,248,229,249,229,250,229,251,229,252,229,253,229,254,229,255,229,0,230,1,230,2,230,3,230,4,230,5,230,6,230,7,230,8,230,9,230,10,230,11,230,12,230,13,230,14,230,15,230,16,230,17,230,18,230,19,230,20,230,21,230,22,230,23,230,24,230,25,230,26,230,27,230,28,230,29,230,30,230,31,230,32,230,33,230,34,230,35,230,36,230,37,230,38,230,39,230,40,230,41,230,42,230,43,230,44,230,45,230,46,230,47,230,48,230,49,230,50,230,51,230,52,230,53,230,54,230,55,230,56,230,57,230,58,230,59,230,60,230,61,230,62,230,63,230,64,230,65,230,66,230,67,230,68,230,69,230,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,114,231,115,231,116,231,117,231,118,231,119,231,120,231,121,231,122,231,123,231,124,231,70,230,71,230,72,230,73,230,74,230,75,230,76,230,77,230,78,230,79,230,80,230,81,230,82,230,83,230,84,230,85,230,86,230,87,230,88,230,89,230,90,230,91,230,92,230,93,230,94,230,95,230,96,230,97,230,98,230,99,230,100,230,101,230,102,230,103,230,104,230,105,230,106,230,107,230,108,230,109,230,110,230,111,230,112,230,113,230,114,230,115,230,116,230,117,230,118,230,119,230,120,230,121,230,122,230,123,230,124,230,125,230,126,230,127,230,128,230,129,230,130,230,131,230,132,230,133,230,134,230,135,230,136,230,137,230,138,230,139,230,140,230,141,230,142,230,143,230,144,230,145,230,146,230,147,230,148,230,149,230,150,230,151,230,152,230,153,230,154,230,155,230,156,230,157,230,158,230,159,230,160,230,161,230,162,230,163,230,164,230,165,230,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,125,231,126,231,127,231,128,231,129,231,130,231,131,231,132,231,166,230,167,230,168,230,169,230,170,230,171,230,172,230,173,230,174,230,175,230,176,230,177,230,178,230,179,230,180,230,181,230,182,230,183,230,184,230,185,230,186,230,187,230,188,230,189,230,190,230,191,230,192,230,193,230,194,230,195,230,196,230,197,230,198,230,199,230,200,230,201,230,202,230,203,230,204,230,205,230,206,230,207,230,208,230,209,230,210,230,211,230,212,230,213,230,214,230,215,230,216,230,217,230,218,230,219,230,220,230,221,230,222,230,223,230,224,230,225,230,226,230,227,230,228,230,229,230,230,230,231,230,232,230,233,230,234,230,235,230,236,230,237,230,238,230,239,230,240,230,241,230,242,230,243,230,244,230,245,230,246,230,247,230,248,230,249,230,250,230,251,230,252,230,253,230,254,230,255,230,0,231,1,231,2,231,3,231,4,231,5,231,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,133,231,134,231,135,231,136,231,137,231,138,231,139,231,140,231,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,141,231,142,231,143,231,144,231,145,231,146,231,147,231,53,254,54,254,57,254,58,254,63,254,64,254,61,254,62,254,65,254,66,254,67,254,68,254,148,231,149,231,59,254,60,254,55,254,56,254,49,254,150,231,51,254,52,254,151,231,152,231,153,231,154,231,155,231,156,231,157,231,158,231,159,231,6,231,7,231,8,231,9,231,10,231,11,231,12,231,13,231,14,231,15,231,16,231,17,231,18,231,19,231,20,231,21,231,22,231,23,231,24,231,25,231,26,231,27,231,28,231,29,231,30,231,31,231,32,231,33,231,34,231,35,231,36,231,37,231,38,231,39,231,40,231,41,231,42,231,43,231,44,231,45,231,46,231,47,231,48,231,49,231,50,231,51,231,52,231,53,231,54,231,55,231,56,231,57,231,58,231,59,231,60,231,61,231,62,231,63,231,64,231,65,231,66,231,67,231,68,231,69,231,70,231,71,231,72,231,73,231,74,231,75,231,76,231,77,231,78,231,79,231,80,231,81,231,82,231,83,231,84,231,85,231,86,231,87,231,88,231,89,231,90,231,91,231,92,231,93,231,94,231,95,231,96,231,97,231,98,231,99,231,100,231,101,231,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,160,231,161,231,162,231,163,231,164,231,165,231,166,231,167,231,168,231,169,231,170,231,171,231,172,231,173,231,174,231,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,175,231,176,231,177,231,178,231,179,231,180,231,181,231,182,231,183,231,184,231,185,231,186,231,187,231,202,2,203,2,217,2,19,32,21,32,37,32,53,32,5,33,9,33,150,33,151,33,152,33,153,33,21,34,31,34,35,34,82,34,102,34,103,34,191,34,80,37,81,37,82,37,83,37,84,37,85,37,86,37,87,37,88,37,89,37,90,37,91,37,92,37,93,37,94,37,95,37,96,37,97,37,98,37,99,37,100,37,101,37,102,37,103,37,104,37,105,37,106,37,107,37,108,37,109,37,110,37,111,37,112,37,113,37,114,37,115,37,129,37,130,37,131,37,132,37,133,37,134,37,135,37,136,37,137,37,138,37,139,37,140,37,141,37,142,37,143,37,147,37,148,37,149,37,188,37,189,37,226,37,227,37,228,37,229,37,9,38,149,34,18,48,29,48,30,48,188,231,189,231,190,231,191,231,192,231,193,231,194,231,195,231,196,231,197,231,198,231,1,1,225,0,206,1,224,0,19,1,233,0,27,1,232,0,43,1,237,0,208,1,236,0,77,1,243,0,210,1,242,0,107,1,250,0,212,1,249,0,214,1,216,1,218,1,220,1,252,0,234,0,81,2,199,231,68,1,72,1,249,1,97,2,201,231,202,231,203,231,204,231,5,49,6,49,7,49,8,49,9,49,10,49,11,49,12,49,13,49,14,49,15,49,16,49,17,49,18,49,19,49,20,49,21,49,22,49,23,49,24,49,25,49,26,49,27,49,28,49,29,49,30,49,31,49,32,49,33,49,34,49,35,49,36,49,37,49,38,49,39,49,40,49,41,49,205,231,206,231,207,231,208,231,209,231,210,231,211,231,212,231,213,231,214,231,215,231,216,231,217,231,218,231,219,231,220,231,221,231,222,231,223,231,224,231,225,231,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,163,50,142,51,143,51,156,51,157,51,158,51,161,51,196,51,206,51,209,51,210,51,213,51,48,254,226,255,228,255,226,231,33,33,49,50,227,231,16,32,228,231,229,231,230,231,252,48,155,48,156,48,253,48,254,48,6,48,157,48,158,48,73,254,74,254,75,254,76,254,77,254,78,254,79,254,80,254,81,254,82,254,84,254,85,254,86,254,87,254,89,254,90,254,91,254,92,254,93,254,94,254,95,254,96,254,97,254,98,254,99,254,100,254,101,254,102,254,104,254,105,254,106,254,107,254,62,48,240,47,241,47,242,47,243,47,244,47,245,47,246,47,247,47,248,47,249,47,250,47,251,47,7,48,244,231,245,231,246,231,247,231,248,231,249,231,250,231,251,231,252,231,253,231,254,231,255,231,0,232,0,37,1,37,2,37,3,37,4,37,5,37,6,37,7,37,8,37,9,37,10,37,11,37,12,37,13,37,14,37,15,37,16,37,17,37,18,37,19,37,20,37,21,37,22,37,23,37,24,37,25,37,26,37,27,37,28,37,29,37,30,37,31,37,32,37,33,37,34,37,35,37,36,37,37,37,38,37,39,37,40,37,41,37,42,37,43,37,44,37,45,37,46,37,47,37,48,37,49,37,50,37,51,37,52,37,53,37,54,37,55,37,56,37,57,37,58,37,59,37,60,37,61,37,62,37,63,37,64,37,65,37,66,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,75,37,1,232,2,232,3,232,4,232,5,232,6,232,7,232,8,232,9,232,10,232,11,232,12,232,13,232,14,232,15,232,220,114,221,114,223,114,226,114,227,114,228,114,229,114,230,114,231,114,234,114,235,114,245,114,246,114,249,114,253,114,254,114,255,114,0,115,2,115,4,115,5,115,6,115,7,115,8,115,9,115,11,115,12,115,13,115,15,115,16,115,17,115,18,115,20,115,24,115,25,115,26,115,31,115,32,115,35,115,36,115,38,115,39,115,40,115,45,115,47,115,48,115,50,115,51,115,53,115,54,115,58,115,59,115,60,115,61,115,64,115,65,115,66,115,67,115,68,115,69,115,70,115,71,115,72,115,73,115,74,115,75,115,76,115,78,115,79,115,81,115,83,115,84,115,85,115,86,115,88,115,89,115,90,115,91,115,92,115,93,115,94,115,95,115,97,115,98,115,99,115,100,115,101,115,102,115,103,115,104,115,105,115,106,115,107,115,110,115,112,115,113,115,0,224,1,224,2,224,3,224,4,224,5,224,6,224,7,224,8,224,9,224,10,224,11,224,12,224,13,224,14,224,15,224,16,224,17,224,18,224,19,224,20,224,21,224,22,224,23,224,24,224,25,224,26,224,27,224,28,224,29,224,30,224,31,224,32,224,33,224,34,224,35,224,36,224,37,224,38,224,39,224,40,224,41,224,42,224,43,224,44,224,45,224,46,224,47,224,48,224,49,224,50,224,51,224,52,224,53,224,54,224,55,224,56,224,57,224,58,224,59,224,60,224,61,224,62,224,63,224,64,224,65,224,66,224,67,224,68,224,69,224,70,224,71,224,72,224,73,224,74,224,75,224,76,224,77,224,78,224,79,224,80,224,81,224,82,224,83,224,84,224,85,224,86,224,87,224,88,224,89,224,90,224,91,224,92,224,93,224,114,115,115,115,116,115,117,115,118,115,119,115,120,115,121,115,122,115,123,115,124,115,125,115,127,115,128,115,129,115,130,115,131,115,133,115,134,115,136,115,138,115,140,115,141,115,143,115,144,115,146,115,147,115,148,115,149,115,151,115,152,115,153,115,154,115,156,115,157,115,158,115,160,115,161,115,163,115,164,115,165,115,166,115,167,115,168,115,170,115,172,115,173,115,177,115,180,115,181,115,182,115,184,115,185,115,188,115,189,115,190,115,191,115,193,115,195,115,196,115,197,115,198,115,199,115,203,115,204,115,206,115,210,115,211,115,212,115,213,115,214,115,215,115,216,115,218,115,219,115,220,115,221,115,223,115,225,115,226,115,227,115,228,115,230,115,232,115,234,115,235,115,236,115,238,115,239,115,240,115,241,115,243,115,244,115,245,115,246,115,247,115,94,224,95,224,96,224,97,224,98,224,99,224,100,224,101,224,102,224,103,224,104,224,105,224,106,224,107,224,108,224,109,224,110,224,111,224,112,224,113,224,114,224,115,224,116,224,117,224,118,224,119,224,120,224,121,224,122,224,123,224,124,224,125,224,126,224,127,224,128,224,129,224,130,224,131,224,132,224,133,224,134,224,135,224,136,224,137,224,138,224,139,224,140,224,141,224,142,224,143,224,144,224,145,224,146,224,147,224,148,224,149,224,150,224,151,224,152,224,153,224,154,224,155,224,156,224,157,224,158,224,159,224,160,224,161,224,162,224,163,224,164,224,165,224,166,224,167,224,168,224,169,224,170,224,171,224,172,224,173,224,174,224,175,224,176,224,177,224,178,224,179,224,180,224,181,224,182,224,183,224,184,224,185,224,186,224,187,224,248,115,249,115,250,115,251,115,252,115,253,115,254,115,255,115,0,116,1,116,2,116,4,116,7,116,8,116,11,116,12,116,13,116,14,116,17,116,18,116,19,116,20,116,21,116,22,116,23,116,24,116,25,116,28,116,29,116,30,116,31,116,32,116,33,116,35,116,36,116,39,116,41,116,43,116,45,116,47,116,49,116,50,116,55,116,56,116,57,116,58,116,59,116,61,116,62,116,63,116,64,116,66,116,67,116,68,116,69,116,70,116,71,116,72,116,73,116,74,116,75,116,76,116,77,116,78,116,79,116,80,116,81,116,82,116,83,116,84,116,86,116,88,116,93,116,96,116,97,116,98,116,99,116,100,116,101,116,102,116,103,116,104,116,105,116,106,116,107,116,108,116,110,116,111,116,113,116,114,116,115,116,116,116,117,116,120,116,121,116,122,116,188,224,189,224,190,224,191,224,192,224,193,224,194,224,195,224,196,224,197,224,198,224,199,224,200,224,201,224,202,224,203,224,204,224,205,224,206,224,207,224,208,224,209,224,210,224,211,224,212,224,213,224,214,224,215,224,216,224,217,224,218,224,219,224,220,224,221,224,222,224,223,224,224,224,225,224,226,224,227,224,228,224,229,224,230,224,231,224,232,224,233,224,234,224,235,224,236,224,237,224,238,224,239,224,240,224,241,224,242,224,243,224,244,224,245,224,246,224,247,224,248,224,249,224,250,224,251,224,252,224,253,224,254,224,255,224,0,225,1,225,2,225,3,225,4,225,5,225,6,225,7,225,8,225,9,225,10,225,11,225,12,225,13,225,14,225,15,225,16,225,17,225,18,225,19,225,20,225,21,225,22,225,23,225,24,225,25,225,123,116,124,116,125,116,127,116,130,116,132,116,133,116,134,116,136,116,137,116,138,116,140,116,141,116,143,116,145,116,146,116,147,116,148,116,149,116,150,116,151,116,152,116,153,116,154,116,155,116,157,116,159,116,160,116,161,116,162,116,163,116,164,116,165,116,166,116,170,116,171,116,172,116,173,116,174,116,175,116,176,116,177,116,178,116,179,116,180,116,181,116,182,116,183,116,184,116,185,116,187,116,188,116,189,116,190,116,191,116,192,116,193,116,194,116,195,116,196,116,197,116,198,116,199,116,200,116,201,116,202,116,203,116,204,116,205,116,206,116,207,116,208,116,209,116,211,116,212,116,213,116,214,116,215,116,216,116,217,116,218,116,219,116,221,116,223,116,225,116,229,116,231,116,232,116,233,116,234,116,235,116,236,116,237,116,240,116,241,116,242,116,26,225,27,225,28,225,29,225,30,225,31,225,32,225,33,225,34,225,35,225,36,225,37,225,38,225,39,225,40,225,41,225,42,225,43,225,44,225,45,225,46,225,47,225,48,225,49,225,50,225,51,225,52,225,53,225,54,225,55,225,56,225,57,225,58,225,59,225,60,225,61,225,62,225,63,225,64,225,65,225,66,225,67,225,68,225,69,225,70,225,71,225,72,225,73,225,74,225,75,225,76,225,77,225,78,225,79,225,80,225,81,225,82,225,83,225,84,225,85,225,86,225,87,225,88,225,89,225,90,225,91,225,92,225,93,225,94,225,95,225,96,225,97,225,98,225,99,225,100,225,101,225,102,225,103,225,104,225,105,225,106,225,107,225,108,225,109,225,110,225,111,225,112,225,113,225,114,225,115,225,116,225,117,225,118,225,119,225,243,116,245,116,248,116,249,116,250,116,251,116,252,116,253,116,254,116,0,117,1,117,2,117,3,117,5,117,6,117,7,117,8,117,9,117,10,117,11,117,12,117,14,117,16,117,18,117,20,117,21,117,22,117,23,117,27,117,29,117,30,117,32,117,33,117,34,117,35,117,36,117,38,117,39,117,42,117,46,117,52,117,54,117,57,117,60,117,61,117,63,117,65,117,66,117,67,117,68,117,70,117,71,117,73,117,74,117,77,117,80,117,81,117,82,117,83,117,85,117,86,117,87,117,88,117,93,117,94,117,95,117,96,117,97,117,98,117,99,117,100,117,103,117,104,117,105,117,107,117,108,117,109,117,110,117,111,117,112,117,113,117,115,117,117,117,118,117,119,117,122,117,123,117,124,117,125,117,126,117,128,117,129,117,130,117,132,117,133,117,135,117,120,225,121,225,122,225,123,225,124,225,125,225,126,225,127,225,128,225,129,225,130,225,131,225,132,225,133,225,134,225,135,225,136,225,137,225,138,225,139,225,140,225,141,225,142,225,143,225,144,225,145,225,146,225,147,225,148,225,149,225,150,225,151,225,152,225,153,225,154,225,155,225,156,225,157,225,158,225,159,225,160,225,161,225,162,225,163,225,164,225,165,225,166,225,167,225,168,225,169,225,170,225,171,225,172,225,173,225,174,225,175,225,176,225,177,225,178,225,179,225,180,225,181,225,182,225,183,225,184,225,185,225,186,225,187,225,188,225,189,225,190,225,191,225,192,225,193,225,194,225,195,225,196,225,197,225,198,225,199,225,200,225,201,225,202,225,203,225,204,225,205,225,206,225,207,225,208,225,209,225,210,225,211,225,212,225,213,225,136,117,137,117,138,117,140,117,141,117,142,117,144,117,147,117,149,117,152,117,155,117,156,117,158,117,162,117,166,117,167,117,168,117,169,117,170,117,173,117,182,117,183,117,186,117,187,117,191,117,192,117,193,117,198,117,203,117,204,117,206,117,207,117,208,117,209,117,211,117,215,117,217,117,218,117,220,117,221,117,223,117,224,117,225,117,229,117,233,117,236,117,237,117,238,117,239,117,242,117,243,117,245,117,246,117,247,117,248,117,250,117,251,117,253,117,254,117,2,118,4,118,6,118,7,118,8,118,9,118,11,118,13,118,14,118,15,118,17,118,18,118,19,118,20,118,22,118,26,118,28,118,29,118,30,118,33,118,35,118,39,118,40,118,44,118,46,118,47,118,49,118,50,118,54,118,55,118,57,118,58,118,59,118,61,118,65,118,66,118,68,118,214,225,215,225,216,225,217,225,218,225,219,225,220,225,221,225,222,225,223,225,224,225,225,225,226,225,227,225,228,225,229,225,230,225,231,225,232,225,233,225,234,225,235,225,236,225,237,225,238,225,239,225,240,225,241,225,242,225,243,225,244,225,245,225,246,225,247,225,248,225,249,225,250,225,251,225,252,225,253,225,254,225,255,225,0,226,1,226,2,226,3,226,4,226,5,226,6,226,7,226,8,226,9,226,10,226,11,226,12,226,13,226,14,226,15,226,16,226,17,226,18,226,19,226,20,226,21,226,22,226,23,226,24,226,25,226,26,226,27,226,28,226,29,226,30,226,31,226,32,226,33,226,34,226,35,226,36,226,37,226,38,226,39,226,40,226,41,226,42,226,43,226,44,226,45,226,46,226,47,226,48,226,49,226,50,226,51,226,69,118,70,118,71,118,72,118,73,118,74,118,75,118,78,118,79,118,80,118,81,118,82,118,83,118,85,118,87,118,88,118,89,118,90,118,91,118,93,118,95,118,96,118,97,118,98,118,100,118,101,118,102,118,103,118,104,118,105,118,106,118,108,118,109,118,110,118,112,118,113,118,114,118,115,118,116,118,117,118,118,118,119,118,121,118,122,118,124,118,127,118,128,118,129,118,131,118,133,118,137,118,138,118,140,118,141,118,143,118,144,118,146,118,148,118,149,118,151,118,152,118,154,118,155,118,156,118,157,118,158,118,159,118,160,118,161,118,162,118,163,118,165,118,166,118,167,118,168,118,169,118,170,118,171,118,172,118,173,118,175,118,176,118,179,118,181,118,182,118,183,118,184,118,185,118,186,118,187,118,188,118,189,118,190,118,192,118,193,118,195,118,74,85,63,150,195,87,40,99,206,84,9,85,192,84,145,118,76,118,60,133,238,119,126,130,141,120,49,114,152,150,141,151,40,108,137,91,250,79,9,99,151,102,184,92,250,128,72,104,174,128,2,102,206,118,249,81,86,101,172,113,241,127,132,136,178,80,101,89,202,97,179,111,173,130,76,99,82,98,237,83,39,84,6,123,107,81,164,117,244,93,212,98,203,141,118,151,138,98,25,128,93,87,56,151,98,127,56,114,125,118,207,103,126,118,70,100,112,79,37,141,220,98,23,122,145,101,237,115,44,100,115,98,44,130,129,152,127,103,72,114,110,98,204,98,52,79,227,116,74,83,158,82,202,126,166,144,46,94,134,104,156,105,128,129,209,126,210,104,197,120,140,134,81,149,141,80,36,140,222,130,222,128,5,83,18,137,101,82,196,118,199,118,201,118,203,118,204,118,211,118,213,118,217,118,218,118,220,118,221,118,222,118,224,118,225,118,226,118,227,118,228,118,230,118,231,118,232,118,233,118,234,118,235,118,236,118,237,118,240,118,243,118,245,118,246,118,247,118,250,118,251,118,253,118,255,118,0,119,2,119,3,119,5,119,6,119,10,119,12,119,14,119,15,119,16,119,17,119,18,119,19,119,20,119,21,119,22,119,23,119,24,119,27,119,28,119,29,119,30,119,33,119,35,119,36,119,37,119,39,119,42,119,43,119,44,119,46,119,48,119,49,119,50,119,51,119,52,119,57,119,59,119,61,119,62,119,63,119,66,119,68,119,69,119,70,119,72,119,73,119,74,119,75,119,76,119,77,119,78,119,79,119,82,119,83,119,84,119,85,119,86,119,87,119,88,119,89,119,92,119,132,133,249,150,221,79,33,88,113,153,157,91,177,98,165,98,180,102,121,140,141,156,6,114,111,103,145,120,178,96,81,83,23,83,136,143,204,128,29,141,161,148,13,80,200,114,7,89,235,96,25,113,171,136,84,89,239,130,44,103,40,123,41,93,247,126,45,117,245,108,102,142,248,143,60,144,59,159,212,107,25,145,20,123,124,95,167,120,214,132,61,133,213,107,217,107,214,107,1,94,135,94,249,117,237,149,93,101,10,95,197,95,159,143,193,88,194,129,127,144,91,150,173,151,185,143,22,127,44,141,65,98,191,79,216,83,94,83,168,143,169,143,171,143,77,144,7,104,106,95,152,129,104,136,214,156,139,97,43,82,42,118,108,95,140,101,210,111,232,110,190,91,72,100,117,81,176,81,196,103,25,78,201,121,124,153,179,112,93,119,94,119,95,119,96,119,100,119,103,119,105,119,106,119,109,119,110,119,111,119,112,119,113,119,114,119,115,119,116,119,117,119,118,119,119,119,120,119,122,119,123,119,124,119,129,119,130,119,131,119,134,119,135,119,136,119,137,119,138,119,139,119,143,119,144,119,147,119,148,119,149,119,150,119,151,119,152,119,153,119,154,119,155,119,156,119,157,119,158,119,161,119,163,119,164,119,166,119,168,119,171,119,173,119,174,119,175,119,177,119,178,119,180,119,182,119,183,119,184,119,185,119,186,119,188,119,190,119,192,119,193,119,194,119,195,119,196,119,197,119,198,119,199,119,200,119,201,119,202,119,203,119,204,119,206,119,207,119,208,119,209,119,210,119,211,119,212,119,213,119,214,119,216,119,217,119,218,119,221,119,222,119,223,119,224,119,225,119,228,119,197,117,118,94,187,115,224,131,173,100,232,98,181,148,226,108,90,83,195,82,15,100,194,148,148,123,47,79,27,94,54,130,22,129,138,129,36,110,202,108,115,154,85,99,92,83,250,84,101,136,224,87,13,78,3,94,101,107,63,124,232,144,22,96,230,100,28,115,193,136,80,103,77,98,34,141,108,119,41,142,199,145,105,95,220,131,33,133,16,153,194,83,149,134,139,107,237,96,232,96,127,112,205,130,49,130,211,78,167,108,207,133,205,100,217,124,253,105,249,102,73,131,149,83,86,123,167,79,140,81,75,109,66,92,109,142,210,99,201,83,44,131,54,131,229,103,180,120,61,100,223,91,148,92,238,93,231,139,198,98,244,103,122,140,0,100,186,99,73,135,139,153,23,140,32,127,242,148,167,78,16,150,164,152,12,102,22,115,230,119,232,119,234,119,239,119,240,119,241,119,242,119,244,119,245,119,247,119,249,119,250,119,251,119,252,119,3,120,4,120,5,120,6,120,7,120,8,120,10,120,11,120,14,120,15,120,16,120,19,120,21,120,25,120,27,120,30,120,32,120,33,120,34,120,36,120,40,120,42,120,43,120,46,120,47,120,49,120,50,120,51,120,53,120,54,120,61,120,63,120,65,120,66,120,67,120,68,120,70,120,72,120,73,120,74,120,75,120,77,120,79,120,81,120,83,120,84,120,88,120,89,120,90,120,91,120,92,120,94,120,95,120,96,120,97,120,98,120,99,120,100,120,101,120,102,120,103,120,104,120,105,120,111,120,112,120,113,120,114,120,115,120,116,120,117,120,118,120,120,120,121,120,122,120,123,120,125,120,126,120,127,120,128,120,129,120,130,120,131,120,58,87,29,92,56,94,127,149,127,80,160,128,130,83,94,101,69,117,49,85,33,80,133,141,132,98,158,148,29,103,50,86,110,111,226,93,53,84,146,112,102,143,111,98,164,100,163,99,123,95,136,111,244,144,227,129,176,143,24,92,104,102,241,95,137,108,72,150,129,141,108,136,145,100,240,121,206,87,89,106,16,98,72,84,88,78,11,122,233,96,132,111,218,139,127,98,30,144,139,154,228,121,3,84,244,117,1,99,25,83,96,108,223,143,27,95,112,154,59,128,127,159,136,79,58,92,100,141,197,127,165,101,189,112,69,81,178,81,107,134,7,93,160,91,189,98,108,145,116,117,12,142,32,122,1,97,121,123,199,78,248,126,133,119,17,78,237,129,29,82,250,81,113,106,168,83,135,142,4,149,207,150,193,110,100,150,90,105,132,120,133,120,134,120,136,120,138,120,139,120,143,120,144,120,146,120,148,120,149,120,150,120,153,120,157,120,158,120,160,120,162,120,164,120,166,120,168,120,169,120,170,120,171,120,172,120,173,120,174,120,175,120,181,120,182,120,183,120,184,120,186,120,187,120,188,120,189,120,191,120,192,120,194,120,195,120,196,120,198,120,199,120,200,120,204,120,205,120,206,120,207,120,209,120,210,120,211,120,214,120,215,120,216,120,218,120,219,120,220,120,221,120,222,120,223,120,224,120,225,120,226,120,227,120,228,120,229,120,230,120,231,120,233,120,234,120,235,120,237,120,238,120,239,120,240,120,241,120,243,120,245,120,246,120,248,120,249,120,251,120,252,120,253,120,254,120,255,120,0,121,2,121,3,121,4,121,6,121,7,121,8,121,9,121,10,121,11,121,12,121,64,120,168,80,215,119,16,100,230,137,4,89,227,99,221,93,127,122,61,105,32,79,57,130,152,85,50,78,174,117,151,122,98,94,138,94,239,149,27,82,57,84,138,112,118,99,36,149,130,87,37,102,63,105,135,145,7,85,243,109,175,126,34,136,51,98,240,126,181,117,40,131,193,120,204,150,158,143,72,97,247,116,205,139,100,107,58,82,80,141,33,107,106,128,113,132,241,86,6,83,206,78,27,78,209,81,151,124,139,145,7,124,195,79,127,142,225,123,156,122,103,100,20,93,172,80,6,129,1,118,185,124,236,109,224,127,81,103,88,91,248,91,203,120,174,100,19,100,170,99,43,99,25,149,45,100,190,143,84,123,41,118,83,98,39,89,70,84,121,107,163,80,52,98,38,94,134,107,227,78,55,141,139,136,133,95,46,144,13,121,14,121,15,121,16,121,17,121,18,121,20,121,21,121,22,121,23,121,24,121,25,121,26,121,27,121,28,121,29,121,31,121,32,121,33,121,34,121,35,121,37,121,38,121,39,121,40,121,41,121,42,121,43,121,44,121,45,121,46,121,47,121,48,121,49,121,50,121,51,121,53,121,54,121,55,121,56,121,57,121,61,121,63,121,66,121,67,121,68,121,69,121,71,121,74,121,75,121,76,121,77,121,78,121,79,121,80,121,81,121,82,121,84,121,85,121,88,121,89,121,97,121,99,121,100,121,102,121,105,121,106,121,107,121,108,121,110,121,112,121,113,121,114,121,115,121,116,121,117,121,118,121,121,121,123,121,124,121,125,121,126,121,127,121,130,121,131,121,134,121,135,121,136,121,137,121,139,121,140,121,141,121,142,121,144,121,145,121,146,121,32,96,61,128,197,98,57,78,85,83,248,144,184,99,198,128,230,101,46,108,70,79,238,96,225,109,222,139,57,95,203,134,83,95,33,99,90,81,97,131,99,104,0,82,99,99,72,142,18,80,155,92,119,121,252,91,48,82,59,122,188,96,83,144,215,118,183,95,151,95,132,118,108,142,111,112,123,118,73,123,170,119,243,81,147,144,36,88,78,79,244,110,234,143,76,101,27,123,196,114,164,109,223,127,225,90,181,98,149,94,48,87,130,132,44,123,29,94,31,95,18,144,20,127,160,152,130,99,199,110,152,120,185,112,120,81,91,151,171,87,53,117,67,79,56,117,151,94,230,96,96,89,192,109,191,107,137,120,252,83,213,150,203,81,1,82,137,99,10,84,147,148,3,140,204,141,57,114,159,120,118,135,237,143,13,140,224,83,147,121,148,121,149,121,150,121,151,121,152,121,153,121,155,121,156,121,157,121,158,121,159,121,160,121,161,121,162,121,163,121,164,121,165,121,166,121,168,121,169,121,170,121,171,121,172,121,173,121,174,121,175,121,176,121,177,121,178,121,180,121,181,121,182,121,183,121,184,121,188,121,191,121,194,121,196,121,197,121,199,121,200,121,202,121,204,121,206,121,207,121,208,121,211,121,212,121,214,121,215,121,217,121,218,121,219,121,220,121,221,121,222,121,224,121,225,121,226,121,229,121,232,121,234,121,236,121,238,121,241,121,242,121,243,121,244,121,245,121,246,121,247,121,249,121,250,121,252,121,254,121,255,121,1,122,4,122,5,122,7,122,8,122,9,122,10,122,12,122,15,122,16,122,17,122,18,122,19,122,21,122,22,122,24,122,25,122,27,122,28,122,1,78,239,118,238,83,137,148,118,152,14,159,45,149,154,91,162,139,34,78,28,78,172,81,99,132,194,97,168,82,11,104,151,79,107,96,187,81,30,109,92,81,150,98,151,101,97,150,70,140,23,144,216,117,253,144,99,119,210,107,138,114,236,114,251,139,53,88,121,119,76,141,92,103,64,149,154,128,166,94,33,110,146,89,239,122,237,119,59,149,181,107,173,101,14,127,6,88,81,81,31,150,249,91,169,88,40,84,114,142,102,101,127,152,228,86,157,148,254,118,65,144,135,99,198,84,26,89,58,89,155,87,178,142,53,103,250,141,53,130,65,82,240,96,21,88,254,134,232,92,69,158,196,79,157,152,185,139,37,90,118,96,132,83,124,98,79,144,2,145,127,153,105,96,12,128,63,81,51,128,20,92,117,153,49,109,140,78,29,122,31,122,33,122,34,122,36,122,37,122,38,122,39,122,40,122,41,122,42,122,43,122,44,122,45,122,46,122,47,122,48,122,49,122,50,122,52,122,53,122,54,122,56,122,58,122,62,122,64,122,65,122,66,122,67,122,68,122,69,122,71,122,72,122,73,122,74,122,75,122,76,122,77,122,78,122,79,122,80,122,82,122,83,122,84,122,85,122,86,122,88,122,89,122,90,122,91,122,92,122,93,122,94,122,95,122,96,122,97,122,98,122,99,122,100,122,101,122,102,122,103,122,104,122,105,122,106,122,107,122,108,122,109,122,110,122,111,122,113,122,114,122,115,122,117,122,123,122,124,122,125,122,126,122,130,122,133,122,135,122,137,122,138,122,139,122,140,122,142,122,143,122,144,122,147,122,148,122,153,122,154,122,155,122,158,122,161,122,162,122,48,141,209,83,90,127,79,123,16,79,79,78,0,150,213,108,208,115,233,133,6,94,106,117,251,127,10,106,254,119,146,148,65,126,225,81,230,112,205,83,212,143,3,131,41,141,175,114,109,153,219,108,74,87,179,130,185,101,170,128,63,98,50,150,168,89,255,78,191,139,186,126,62,101,242,131,94,151,97,85,222,152,165,128,42,83,253,139,32,84,186,128,159,94,184,108,57,141,172,130,90,145,41,84,27,108,6,82,183,126,95,87,26,113,126,108,137,124,75,89,253,78,255,95,36,97,170,124,48,78,1,92,171,103,2,135,240,92,11,149,206,152,175,117,253,112,34,144,175,81,29,127,189,139,73,89,228,81,91,79,38,84,43,89,119,101,164,128,117,91,118,98,194,98,144,143,69,94,31,108,38,123,15,79,216,79,13,103,163,122,164,122,167,122,169,122,170,122,171,122,174,122,175,122,176,122,177,122,178,122,180,122,181,122,182,122,183,122,184,122,185,122,186,122,187,122,188,122,189,122,190,122,192,122,193,122,194,122,195,122,196,122,197,122,198,122,199,122,200,122,201,122,202,122,204,122,205,122,206,122,207,122,208,122,209,122,210,122,211,122,212,122,213,122,215,122,216,122,218,122,219,122,220,122,221,122,225,122,226,122,228,122,231,122,232,122,233,122,234,122,235,122,236,122,238,122,240,122,241,122,242,122,243,122,244,122,245,122,246,122,247,122,248,122,251,122,252,122,254,122,0,123,1,123,2,123,5,123,7,123,9,123,12,123,13,123,14,123,16,123,18,123,19,123,22,123,23,123,24,123,26,123,28,123,29,123,31,123,33,123,34,123,35,123,39,123,41,123,45,123,110,109,170,109,143,121,177,136,23,95,43,117,154,98,133,143,239,79,220,145,167,101,47,129,81,129,156,94,80,129,116,141,111,82,134,137,75,141,13,89,133,80,216,78,28,150,54,114,121,129,31,141,204,91,163,139,68,150,135,89,26,127,144,84,118,86,14,86,229,139,57,101,130,105,153,148,214,118,137,110,114,94,24,117,70,103,209,103,255,122,157,128,118,141,31,97,198,121,98,101,99,141,136,81,26,82,162,148,56,127,155,128,178,126,151,92,47,110,96,103,217,123,139,118,216,154,143,129,148,127,213,124,30,100,80,149,63,122,74,84,229,84,76,107,1,100,8,98,61,158,243,128,153,117,114,82,105,151,91,132,60,104,228,134,1,150,148,150,236,148,42,78,4,84,217,126,57,104,223,141,21,128,244,102,154,94,185,127,47,123,48,123,50,123,52,123,53,123,54,123,55,123,57,123,59,123,61,123,63,123,64,123,65,123,66,123,67,123,68,123,70,123,72,123,74,123,77,123,78,123,83,123,85,123,87,123,89,123,92,123,94,123,95,123,97,123,99,123,100,123,101,123,102,123,103,123,104,123,105,123,106,123,107,123,108,123,109,123,111,123,112,123,115,123,116,123,118,123,120,123,122,123,124,123,125,123,127,123,129,123,130,123,131,123,132,123,134,123,135,123,136,123,137,123,138,123,139,123,140,123,142,123,143,123,145,123,146,123,147,123,150,123,152,123,153,123,154,123,155,123,158,123,159,123,160,123,163,123,164,123,165,123,174,123,175,123,176,123,178,123,179,123,181,123,182,123,183,123,185,123,186,123,187,123,188,123,189,123,190,123,191,123,192,123,194,123,195,123,196,123,194,87,63,128,151,104,229,93,59,101,159,82,109,96,154,159,155,79,172,142,108,81,171,91,19,95,233,93,94,108,241,98,33,141,113,81,169,148,254,82,159,108,223,130,215,114,162,87,132,103,45,141,31,89,156,143,199,131,149,84,141,123,48,79,189,108,100,91,209,89,19,159,228,83,202,134,168,154,55,140,161,128,69,101,126,152,250,86,199,150,46,82,220,116,80,82,225,91,2,99,2,137,86,78,208,98,42,96,250,104,115,81,152,91,160,81,194,137,161,123,134,153,80,127,239,96,76,112,47,141,73,81,127,94,27,144,112,116,196,137,45,87,69,120,82,95,159,159,250,149,104,143,60,155,225,139,120,118,66,104,220,103,234,141,53,141,61,82,138,143,218,110,205,104,5,149,237,144,253,86,156,103,249,136,199,143,200,84,197,123,200,123,201,123,202,123,203,123,205,123,206,123,207,123,208,123,210,123,212,123,213,123,214,123,215,123,216,123,219,123,220,123,222,123,223,123,224,123,226,123,227,123,228,123,231,123,232,123,233,123,235,123,236,123,237,123,239,123,240,123,242,123,243,123,244,123,245,123,246,123,248,123,249,123,250,123,251,123,253,123,255,123,0,124,1,124,2,124,3,124,4,124,5,124,6,124,8,124,9,124,10,124,13,124,14,124,16,124,17,124,18,124,19,124,20,124,21,124,23,124,24,124,25,124,26,124,27,124,28,124,29,124,30,124,32,124,33,124,34,124,35,124,36,124,37,124,40,124,41,124,43,124,44,124,45,124,46,124,47,124,48,124,49,124,50,124,51,124,52,124,53,124,54,124,55,124,57,124,58,124,59,124,60,124,61,124,62,124,66,124,184,154,105,91,119,109,38,108,165,78,179,91,135,154,99,145,168,97,175,144,233,151,43,84,181,109,210,91,253,81,138,85,85,127,240,127,188,100,77,99,241,101,190,97,141,96,10,113,87,108,73,108,47,89,109,103,42,130,213,88,142,86,106,140,235,107,221,144,125,89,23,128,247,83,105,109,117,84,157,85,119,131,207,131,56,104,190,121,140,84,85,79,8,84,210,118,137,140,2,150,179,108,184,109,107,141,16,137,100,158,58,141,63,86,209,158,213,117,136,95,224,114,104,96,252,84,168,78,42,106,97,136,82,96,112,143,196,84,216,112,121,134,63,158,42,109,143,91,24,95,162,126,137,85,175,79,52,115,60,84,154,83,25,80,14,84,124,84,78,78,253,95,90,116,246,88,107,132,225,128,116,135,208,114,202,124,86,110,67,124,68,124,69,124,70,124,71,124,72,124,73,124,74,124,75,124,76,124,78,124,79,124,80,124,81,124,82,124,83,124,84,124,85,124,86,124,87,124,88,124,89,124,90,124,91,124,92,124,93,124,94,124,95,124,96,124,97,124,98,124,99,124,100,124,101,124,102,124,103,124,104,124,105,124,106,124,107,124,108,124,109,124,110,124,111,124,112,124,113,124,114,124,117,124,118,124,119,124,120,124,121,124,122,124,126,124,127,124,128,124,129,124,130,124,131,124,132,124,133,124,134,124,135,124,136,124,138,124,139,124,140,124,141,124,142,124,143,124,144,124,147,124,148,124,150,124,153,124,154,124,155,124,160,124,161,124,163,124,166,124,167,124,168,124,169,124,171,124,172,124,173,124,175,124,176,124,180,124,181,124,182,124,183,124,184,124,186,124,187,124,39,95,78,134,44,85,164,98,146,78,170,108,55,98,177,130,215,84,78,83,62,115,209,110,59,117,18,82,22,83,221,139,208,105,138,95,0,96,238,109,79,87,34,107,175,115,83,104,216,143,19,127,98,99,163,96,36,85,234,117,98,140,21,113,163,109,166,91,123,94,82,131,76,97,196,158,250,120,87,135,39,124,135,118,240,81,246,96,76,113,67,102,76,94,77,96,14,140,112,112,37,99,137,143,189,95,98,96,212,134,222,86,193,107,148,96,103,97,73,83,224,96,102,102,63,141,253,121,26,79,233,112,71,108,179,139,242,139,216,126,100,131,15,102,90,90,66,155,81,109,247,109,65,140,59,109,25,79,107,112,183,131,22,98,209,96,13,151,39,141,120,121,251,81,62,87,250,87,58,103,120,117,61,122,239,121,149,123,191,124,192,124,194,124,195,124,196,124,198,124,201,124,203,124,206,124,207,124,208,124,209,124,210,124,211,124,212,124,216,124,218,124,219,124,221,124,222,124,225,124,226,124,227,124,228,124,229,124,230,124,231,124,233,124,234,124,235,124,236,124,237,124,238,124,240,124,241,124,242,124,243,124,244,124,245,124,246,124,247,124,249,124,250,124,252,124,253,124,254,124,255,124,0,125,1,125,2,125,3,125,4,125,5,125,6,125,7,125,8,125,9,125,11,125,12,125,13,125,14,125,15,125,16,125,17,125,18,125,19,125,20,125,21,125,22,125,23,125,24,125,25,125,26,125,27,125,28,125,29,125,30,125,31,125,33,125,35,125,36,125,37,125,38,125,40,125,41,125,42,125,44,125,45,125,46,125,48,125,49,125,50,125,51,125,52,125,53,125,54,125,140,128,101,153,249,143,192,111,165,139,33,158,236,89,233,126,9,127,9,84,129,103,216,104,145,143,77,124,198,150,202,83,37,96,190,117,114,108,115,83,201,90,167,126,36,99,224,81,10,129,241,93,223,132,128,98,128,81,99,91,14,79,109,121,66,82,184,96,78,109,196,91,194,91,161,139,176,139,226,101,204,95,69,150,147,89,231,126,170,126,9,86,183,103,57,89,115,79,182,91,160,82,90,131,138,152,62,141,50,117,190,148,71,80,60,122,247,78,182,103,126,154,193,90,124,107,209,118,90,87,22,92,58,123,244,149,78,113,124,81,169,128,112,130,120,89,4,127,39,131,192,104,236,103,177,120,119,120,227,98,97,99,128,123,237,79,106,82,207,81,80,131,219,105,116,146,245,141,49,141,193,137,46,149,173,123,246,78,55,125,56,125,57,125,58,125,59,125,60,125,61,125,62,125,63,125,64,125,65,125,66,125,67,125,68,125,69,125,70,125,71,125,72,125,73,125,74,125,75,125,76,125,77,125,78,125,79,125,80,125,81,125,82,125,83,125,84,125,85,125,86,125,87,125,88,125,89,125,90,125,91,125,92,125,93,125,94,125,95,125,96,125,97,125,98,125,99,125,100,125,101,125,102,125,103,125,104,125,105,125,106,125,107,125,108,125,109,125,111,125], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1162976);
/* memory initializer */ allocate([112,125,113,125,114,125,115,125,116,125,117,125,118,125,120,125,121,125,122,125,123,125,124,125,125,125,126,125,127,125,128,125,129,125,130,125,131,125,132,125,133,125,134,125,135,125,136,125,137,125,138,125,139,125,140,125,141,125,142,125,143,125,144,125,145,125,146,125,147,125,148,125,149,125,150,125,151,125,152,125,101,80,48,130,81,82,111,153,16,110,133,110,167,109,250,94,245,80,220,89,6,92,70,109,95,108,134,117,139,132,104,104,86,89,178,139,32,83,113,145,77,150,73,133,18,105,1,121,38,113,246,128,164,78,202,144,71,109,132,154,7,90,188,86,5,100,240,148,235,119,165,79,26,129,225,114,210,137,122,153,52,127,222,126,127,82,89,101,117,145,127,143,131,143,235,83,150,122,237,99,165,99,134,118,248,121,87,136,54,150,42,98,171,82,130,130,84,104,112,103,119,99,107,119,237,122,1,109,211,126,227,137,208,89,18,98,201,133,165,130,76,117,31,80,203,78,165,117,235,139,74,92,254,93,75,123,164,101,209,145,202,78,37,109,95,137,39,125,38,149,197,78,40,140,219,143,115,151,75,102,129,121,209,143,236,112,120,109,153,125,154,125,155,125,156,125,157,125,158,125,159,125,160,125,161,125,162,125,163,125,164,125,165,125,167,125,168,125,169,125,170,125,171,125,172,125,173,125,175,125,176,125,177,125,178,125,179,125,180,125,181,125,182,125,183,125,184,125,185,125,186,125,187,125,188,125,189,125,190,125,191,125,192,125,193,125,194,125,195,125,196,125,197,125,198,125,199,125,200,125,201,125,202,125,203,125,204,125,205,125,206,125,207,125,208,125,209,125,210,125,211,125,212,125,213,125,214,125,215,125,216,125,217,125,218,125,219,125,220,125,221,125,222,125,223,125,224,125,225,125,226,125,227,125,228,125,229,125,230,125,231,125,232,125,233,125,234,125,235,125,236,125,237,125,238,125,239,125,240,125,241,125,242,125,243,125,244,125,245,125,246,125,247,125,248,125,249,125,250,125,61,92,178,82,70,131,98,81,14,131,91,119,118,102,184,156,172,78,202,96,190,124,179,124,207,126,149,78,102,139,111,102,136,152,89,151,131,88,108,101,92,149,132,95,201,117,86,151,223,122,222,122,192,81,175,112,152,122,234,99,118,122,160,126,150,115,237,151,69,78,120,112,93,78,82,145,169,83,81,101,231,101,252,129,5,130,142,84,49,92,154,117,160,151,216,98,217,114,189,117,69,92,121,154,202,131,64,92,128,84,233,119,62,78,174,108,90,128,210,98,110,99,232,93,119,81,221,141,30,142,47,149,241,79,229,83,231,96,172,112,103,82,80,99,67,158,31,90,38,80,55,119,119,83,226,126,133,100,43,101,137,98,152,99,20,80,53,114,201,137,179,81,192,139,221,126,71,87,204,131,167,148,155,81,27,84,251,92,251,125,252,125,253,125,254,125,255,125,0,126,1,126,2,126,3,126,4,126,5,126,6,126,7,126,8,126,9,126,10,126,11,126,12,126,13,126,14,126,15,126,16,126,17,126,18,126,19,126,20,126,21,126,22,126,23,126,24,126,25,126,26,126,27,126,28,126,29,126,30,126,31,126,32,126,33,126,34,126,35,126,36,126,37,126,38,126,39,126,40,126,41,126,42,126,43,126,44,126,45,126,46,126,47,126,48,126,49,126,50,126,51,126,52,126,53,126,54,126,55,126,56,126,57,126,58,126,60,126,61,126,62,126,63,126,64,126,66,126,67,126,68,126,69,126,70,126,72,126,73,126,74,126,75,126,76,126,77,126,78,126,79,126,80,126,81,126,82,126,83,126,84,126,85,126,86,126,87,126,88,126,89,126,90,126,91,126,92,126,93,126,202,79,227,122,90,109,225,144,143,154,128,85,150,84,97,83,175,84,0,95,233,99,119,105,239,81,104,97,10,82,42,88,216,82,78,87,13,120,11,119,183,94,119,97,224,124,91,98,151,98,162,78,149,112,3,128,247,98,228,112,96,151,119,87,219,130,239,103,245,104,213,120,151,152,209,121,243,88,179,84,239,83,52,110,75,81,59,82,162,91,254,139,175,128,67,85,166,87,115,96,81,87,45,84,122,122,80,96,84,91,167,99,160,98,227,83,99,98,199,91,175,103,237,84,159,122,230,130,119,145,147,94,228,136,56,89,174,87,14,99,232,141,239,128,87,87,119,123,169,79,235,95,189,91,62,107,33,83,80,123,194,114,70,104,255,119,54,119,247,101,181,81,143,78,212,118,191,92,165,122,117,132,78,89,65,155,128,80,94,126,95,126,96,126,97,126,98,126,99,126,100,126,101,126,102,126,103,126,104,126,105,126,106,126,107,126,108,126,109,126,110,126,111,126,112,126,113,126,114,126,115,126,116,126,117,126,118,126,119,126,120,126,121,126,122,126,123,126,124,126,125,126,126,126,127,126,128,126,129,126,131,126,132,126,133,126,134,126,135,126,136,126,137,126,138,126,139,126,140,126,141,126,142,126,143,126,144,126,145,126,146,126,147,126,148,126,149,126,150,126,151,126,152,126,153,126,154,126,156,126,157,126,158,126,174,126,180,126,187,126,188,126,214,126,228,126,236,126,249,126,10,127,16,127,30,127,55,127,57,127,59,127,60,127,61,127,62,127,63,127,64,127,65,127,67,127,70,127,71,127,72,127,73,127,74,127,75,127,76,127,77,127,78,127,79,127,82,127,83,127,136,153,39,97,131,110,100,87,6,102,70,99,240,86,236,98,105,98,211,94,20,150,131,87,201,98,135,85,33,135,74,129,163,143,102,85,177,131,101,103,86,141,221,132,106,90,15,104,230,98,238,123,17,150,112,81,156,111,48,140,253,99,200,137,210,97,6,127,194,112,229,110,5,116,148,105,252,114,202,94,206,144,23,103,106,109,94,99,179,82,98,114,1,128,108,79,229,89,106,145,217,112,157,109,210,82,80,78,247,150,109,149,126,133,202,120,47,125,33,81,146,87,194,100,139,128,123,124,234,108,241,104,94,105,183,81,152,83,168,104,129,114,206,158,241,123,248,114,187,121,19,111,6,116,78,103,204,145,164,156,60,121,137,131,84,131,15,84,23,104,61,78,137,83,177,82,62,120,134,83,41,82,136,80,139,79,208,79,86,127,89,127,91,127,92,127,93,127,94,127,96,127,99,127,100,127,101,127,102,127,103,127,107,127,108,127,109,127,111,127,112,127,115,127,117,127,118,127,119,127,120,127,122,127,123,127,124,127,125,127,127,127,128,127,130,127,131,127,132,127,133,127,134,127,135,127,136,127,137,127,139,127,141,127,143,127,144,127,145,127,146,127,147,127,149,127,150,127,151,127,152,127,153,127,155,127,156,127,160,127,162,127,163,127,165,127,166,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,177,127,179,127,180,127,181,127,182,127,183,127,186,127,187,127,190,127,192,127,194,127,195,127,196,127,198,127,199,127,200,127,201,127,203,127,205,127,207,127,208,127,209,127,210,127,211,127,214,127,215,127,217,127,218,127,219,127,220,127,221,127,222,127,226,127,227,127,226,117,203,122,146,124,165,108,182,150,155,82,131,116,233,84,233,79,84,128,178,131,222,143,112,149,201,94,28,96,159,109,24,94,91,101,56,129,254,148,75,96,188,112,195,126,174,124,201,81,129,104,177,124,111,130,36,78,134,143,207,145,126,102,174,78,5,140,169,100,74,128,218,80,151,117,206,113,229,91,189,143,102,111,134,78,130,100,99,149,214,94,153,101,23,82,194,136,200,112,163,82,14,115,51,116,151,103,247,120,22,151,52,78,187,144,222,156,203,109,219,81,65,141,29,84,206,98,178,115,241,131,246,150,132,159,195,148,54,79,154,127,204,81,117,112,117,150,173,92,134,152,230,83,228,78,156,110,9,116,180,105,107,120,143,153,89,117,24,82,36,118,65,109,243,103,109,81,153,159,75,128,153,84,60,123,191,122,228,127,231,127,232,127,234,127,235,127,236,127,237,127,239,127,242,127,244,127,245,127,246,127,247,127,248,127,249,127,250,127,253,127,254,127,255,127,2,128,7,128,8,128,9,128,10,128,14,128,15,128,17,128,19,128,26,128,27,128,29,128,30,128,31,128,33,128,35,128,36,128,43,128,44,128,45,128,46,128,47,128,48,128,50,128,52,128,57,128,58,128,60,128,62,128,64,128,65,128,68,128,69,128,71,128,72,128,73,128,78,128,79,128,80,128,81,128,83,128,85,128,86,128,87,128,89,128,91,128,92,128,93,128,94,128,95,128,96,128,97,128,98,128,99,128,100,128,101,128,102,128,103,128,104,128,107,128,108,128,109,128,110,128,111,128,112,128,114,128,115,128,116,128,117,128,118,128,119,128,120,128,121,128,122,128,123,128,124,128,125,128,134,150,132,87,226,98,71,150,124,105,4,90,2,100,211,123,15,111,75,150,166,130,98,83,133,152,144,94,137,112,179,99,100,83,79,134,129,156,147,158,140,120,50,151,239,141,66,141,127,158,94,111,132,121,85,95,70,150,46,98,116,154,21,84,221,148,163,79,197,101,101,92,97,92,21,127,81,134,47,108,139,95,135,115,228,110,255,126,230,92,27,99,106,91,230,110,117,83,113,78,160,99,101,117,161,98,110,143,38,79,209,78,166,108,182,126,186,139,29,132,186,135,87,127,59,144,35,149,169,123,161,154,248,136,61,132,27,109,134,154,220,126,136,89,187,158,155,115,1,120,130,134,108,154,130,154,27,86,23,84,203,87,112,78,166,158,86,83,200,143,9,129,146,119,146,153,238,134,225,110,19,133,252,102,98,97,43,111,126,128,129,128,130,128,133,128,136,128,138,128,141,128,142,128,143,128,144,128,145,128,146,128,148,128,149,128,151,128,153,128,158,128,163,128,166,128,167,128,168,128,172,128,176,128,179,128,181,128,182,128,184,128,185,128,187,128,197,128,199,128,200,128,201,128,202,128,203,128,207,128,208,128,209,128,210,128,211,128,212,128,213,128,216,128,223,128,224,128,226,128,227,128,230,128,238,128,245,128,247,128,249,128,251,128,254,128,255,128,0,129,1,129,3,129,4,129,5,129,7,129,8,129,11,129,12,129,21,129,23,129,25,129,27,129,28,129,29,129,31,129,32,129,33,129,34,129,35,129,36,129,37,129,38,129,39,129,40,129,41,129,42,129,43,129,45,129,46,129,48,129,51,129,52,129,53,129,55,129,57,129,58,129,59,129,60,129,61,129,63,129,41,140,146,130,43,131,242,118,19,108,217,95,189,131,43,115,5,131,26,149,219,107,219,119,198,148,111,83,2,131,146,81,61,94,140,140,56,141,72,78,171,115,154,103,133,104,118,145,9,151,100,113,161,108,9,119,146,90,65,149,207,107,142,127,39,102,208,91,185,89,154,90,232,149,247,149,236,78,12,132,153,132,172,106,223,118,48,149,27,115,166,104,95,91,47,119,154,145,97,151,220,124,247,143,28,140,37,95,115,124,216,121,197,137,204,108,28,135,198,91,66,94,201,104,32,119,245,126,149,81,77,81,201,82,41,90,5,127,98,151,215,130,207,99,132,119,208,133,210,121,58,110,153,94,153,89,17,133,109,112,17,108,191,98,191,118,79,101,175,96,253,149,14,102,159,135,35,158,237,148,13,84,125,84,44,140,120,100,64,129,65,129,66,129,67,129,68,129,69,129,71,129,73,129,77,129,78,129,79,129,82,129,86,129,87,129,88,129,91,129,92,129,93,129,94,129,95,129,97,129,98,129,99,129,100,129,102,129,104,129,106,129,107,129,108,129,111,129,114,129,115,129,117,129,118,129,119,129,120,129,129,129,131,129,132,129,133,129,134,129,135,129,137,129,139,129,140,129,141,129,142,129,144,129,146,129,147,129,148,129,149,129,150,129,151,129,153,129,154,129,158,129,159,129,160,129,161,129,162,129,164,129,165,129,167,129,169,129,171,129,172,129,173,129,174,129,175,129,176,129,177,129,178,129,180,129,181,129,182,129,183,129,184,129,185,129,188,129,189,129,190,129,191,129,196,129,197,129,199,129,200,129,201,129,203,129,205,129,206,129,207,129,208,129,209,129,210,129,211,129,121,100,17,134,33,106,156,129,232,120,105,100,84,155,185,98,43,103,171,131,168,88,216,158,171,108,32,111,222,91,76,150,11,140,95,114,208,103,199,98,97,114,169,78,198,89,205,107,147,88,174,102,85,94,223,82,85,97,40,103,238,118,102,119,103,114,70,122,255,98,234,84,80,84,160,148,163,144,28,90,179,126,22,108,67,78,118,89,16,128,72,89,87,83,55,117,190,150,202,86,32,99,17,129,124,96,249,149,214,109,98,84,129,153,133,81,233,90,253,128,174,89,19,151,42,80,229,108,60,92,223,98,96,79,63,83,123,129,6,144,186,110,43,133,200,98,116,94,190,120,181,100,123,99,245,95,24,90,127,145,31,158,63,92,79,99,66,128,125,91,110,85,74,149,77,149,133,109,168,96,224,103,222,114,221,81,129,91,212,129,213,129,214,129,215,129,216,129,217,129,218,129,219,129,220,129,221,129,222,129,223,129,224,129,225,129,226,129,228,129,229,129,230,129,232,129,233,129,235,129,238,129,239,129,240,129,241,129,242,129,245,129,246,129,247,129,248,129,249,129,250,129,253,129,255,129,3,130,7,130,8,130,9,130,10,130,11,130,14,130,15,130,17,130,19,130,21,130,22,130,23,130,24,130,25,130,26,130,29,130,32,130,36,130,37,130,38,130,39,130,41,130,46,130,50,130,58,130,60,130,61,130,63,130,64,130,65,130,66,130,67,130,69,130,70,130,72,130,74,130,76,130,77,130,78,130,80,130,81,130,82,130,83,130,84,130,85,130,86,130,87,130,89,130,91,130,92,130,93,130,94,130,96,130,97,130,98,130,99,130,100,130,101,130,102,130,103,130,105,130,231,98,222,108,91,114,109,98,174,148,189,126,19,129,83,109,156,81,4,95,116,89,170,82,18,96,115,89,150,102,80,134,159,117,42,99,230,97,239,124,250,139,230,84,39,107,37,158,180,107,213,133,85,84,118,80,164,108,106,85,180,141,44,114,21,94,21,96,54,116,205,98,146,99,76,114,152,95,67,110,62,109,0,101,88,111,216,118,208,120,252,118,84,117,36,82,219,83,83,78,158,94,193,101,42,128,214,128,155,98,134,84,40,82,174,112,141,136,209,141,225,108,120,84,218,128,249,87,244,136,84,141,106,150,77,145,105,79,155,108,183,85,198,118,48,120,168,98,249,112,142,111,109,95,236,132,218,104,124,120,247,123,168,129,11,103,79,158,103,99,176,120,111,87,18,120,57,151,121,98,171,98,136,82,53,116,215,107,106,130,107,130,108,130,109,130,113,130,117,130,118,130,119,130,120,130,123,130,124,130,128,130,129,130,131,130,133,130,134,130,135,130,137,130,140,130,144,130,147,130,148,130,149,130,150,130,154,130,155,130,158,130,160,130,162,130,163,130,167,130,178,130,181,130,182,130,186,130,187,130,188,130,191,130,192,130,194,130,195,130,197,130,198,130,201,130,208,130,214,130,217,130,218,130,221,130,226,130,231,130,232,130,233,130,234,130,236,130,237,130,238,130,240,130,242,130,243,130,245,130,246,130,248,130,250,130,252,130,253,130,254,130,255,130,0,131,10,131,11,131,13,131,16,131,18,131,19,131,22,131,24,131,25,131,29,131,30,131,31,131,32,131,33,131,34,131,35,131,36,131,37,131,38,131,41,131,42,131,46,131,48,131,50,131,55,131,59,131,61,131,100,85,62,129,178,117,174,118,57,83,222,117,251,80,65,92,108,139,199,123,79,80,71,114,151,154,216,152,2,111,226,116,104,121,135,100,165,119,252,98,145,152,43,141,193,84,88,128,82,78,106,87,249,130,13,132,115,94,237,81,246,116,196,139,79,92,97,87,252,108,135,152,70,90,52,120,68,155,235,143,149,124,86,82,81,98,250,148,198,78,134,131,97,132,233,131,178,132,212,87,52,103,3,87,110,102,102,109,49,140,221,102,17,112,31,103,58,107,22,104,26,98,187,89,3,78,196,81,6,111,210,103,143,108,118,81,203,104,71,89,103,107,102,117,14,93,16,129,80,159,215,101,72,121,65,121,145,154,119,141,130,92,94,78,1,79,47,84,81,89,12,120,104,86,20,108,196,143,3,95,125,108,227,108,171,139,144,99,62,131,63,131,65,131,66,131,68,131,69,131,72,131,74,131,75,131,76,131,77,131,78,131,83,131,85,131,86,131,87,131,88,131,89,131,93,131,98,131,112,131,113,131,114,131,115,131,116,131,117,131,118,131,121,131,122,131,126,131,127,131,128,131,129,131,130,131,131,131,132,131,135,131,136,131,138,131,139,131,140,131,141,131,143,131,144,131,145,131,148,131,149,131,150,131,151,131,153,131,154,131,157,131,159,131,161,131,162,131,163,131,164,131,165,131,166,131,167,131,172,131,173,131,174,131,175,131,181,131,187,131,190,131,191,131,194,131,195,131,196,131,198,131,200,131,201,131,203,131,205,131,206,131,208,131,209,131,210,131,211,131,213,131,215,131,217,131,218,131,219,131,222,131,226,131,227,131,228,131,230,131,231,131,232,131,235,131,236,131,237,131,112,96,61,109,117,114,102,98,142,148,197,148,67,83,193,143,126,123,223,78,38,140,126,78,212,158,177,148,179,148,77,82,92,111,99,144,69,109,52,140,17,88,76,93,32,107,73,107,170,103,91,84,84,129,140,127,153,88,55,133,58,95,162,98,71,106,57,149,114,101,132,96,101,104,167,119,84,78,168,79,231,93,152,151,172,100,216,127,237,92,207,79,141,122,7,82,4,131,20,78,47,96,131,122,166,148,181,79,178,78,230,121,52,116,228,82,185,130,210,100,189,121,221,91,129,108,82,151,123,143,34,108,62,80,127,83,5,110,206,100,116,102,48,108,197,96,119,152,247,139,134,94,60,116,119,122,203,121,24,78,177,144,3,116,66,108,218,86,75,145,197,108,139,141,58,83,198,134,242,102,175,142,72,92,113,154,32,110,238,131,239,131,243,131,244,131,245,131,246,131,247,131,250,131,251,131,252,131,254,131,255,131,0,132,2,132,5,132,7,132,8,132,9,132,10,132,16,132,18,132,19,132,20,132,21,132,22,132,23,132,25,132,26,132,27,132,30,132,31,132,32,132,33,132,34,132,35,132,41,132,42,132,43,132,44,132,45,132,46,132,47,132,48,132,50,132,51,132,52,132,53,132,54,132,55,132,57,132,58,132,59,132,62,132,63,132,64,132,65,132,66,132,67,132,68,132,69,132,71,132,72,132,73,132,74,132,75,132,76,132,77,132,78,132,79,132,80,132,82,132,83,132,84,132,85,132,86,132,88,132,93,132,94,132,95,132,96,132,98,132,100,132,101,132,102,132,103,132,104,132,106,132,110,132,111,132,112,132,114,132,116,132,119,132,121,132,123,132,124,132,214,83,54,90,139,159,163,141,187,83,8,87,167,152,67,103,155,145,201,108,104,81,202,117,243,98,172,114,56,82,157,82,58,127,148,112,56,118,116,83,74,158,183,105,110,120,192,150,217,136,164,127,54,113,195,113,137,81,211,103,228,116,228,88,24,101,183,86,169,139,118,153,112,98,213,126,249,96,237,112,236,88,193,78,186,78,205,95,231,151,251,78,164,139,3,82,138,89,171,126,84,98,205,78,229,101,14,98,56,131,201,132,99,131,141,135,148,113,182,110,185,91,210,126,151,81,201,99,212,103,137,128,57,131,21,136,18,81,122,91,130,89,177,143,115,78,93,108,101,81,37,137,111,143,46,150,74,133,94,116,16,149,240,149,166,109,229,130,49,95,146,100,18,109,40,132,110,129,195,156,94,88,91,141,9,78,193,83,125,132,126,132,127,132,128,132,129,132,131,132,132,132,133,132,134,132,138,132,141,132,143,132,144,132,145,132,146,132,147,132,148,132,149,132,150,132,152,132,154,132,155,132,157,132,158,132,159,132,160,132,162,132,163,132,164,132,165,132,166,132,167,132,168,132,169,132,170,132,171,132,172,132,173,132,174,132,176,132,177,132,179,132,181,132,182,132,183,132,187,132,188,132,190,132,192,132,194,132,195,132,197,132,198,132,199,132,200,132,203,132,204,132,206,132,207,132,210,132,212,132,213,132,215,132,216,132,217,132,218,132,219,132,220,132,222,132,225,132,226,132,228,132,231,132,232,132,233,132,234,132,235,132,237,132,238,132,239,132,241,132,242,132,243,132,244,132,245,132,246,132,247,132,248,132,249,132,250,132,251,132,253,132,254,132,0,133,1,133,2,133,30,79,99,101,81,104,211,85,39,78,20,100,154,154,107,98,194,90,95,116,114,130,169,109,238,104,231,80,142,131,2,120,64,103,57,82,153,108,177,126,187,80,101,85,94,113,91,123,82,102,202,115,235,130,73,103,113,92,32,82,125,113,107,136,234,149,85,150,197,100,97,141,179,129,132,85,85,108,71,98,46,127,146,88,36,79,70,85,79,141,76,102,10,78,26,92,243,136,162,104,78,99,13,122,231,112,141,130,250,82,246,151,17,92,232,84,181,144,205,126,98,89,74,141,199,134,12,130,13,130,102,141,68,100,4,92,81,97,137,109,62,121,190,139,55,120,51,117,123,84,56,79,171,142,241,109,32,90,197,126,94,121,136,108,161,91,118,90,26,117,190,128,78,97,23,110,240,88,31,117,37,117,114,114,71,83,243,126,3,133,4,133,5,133,6,133,7,133,8,133,9,133,10,133,11,133,13,133,14,133,15,133,16,133,18,133,20,133,21,133,22,133,24,133,25,133,27,133,28,133,29,133,30,133,32,133,34,133,35,133,36,133,37,133,38,133,39,133,40,133,41,133,42,133,45,133,46,133,47,133,48,133,49,133,50,133,51,133,52,133,53,133,54,133,62,133,63,133,64,133,65,133,66,133,68,133,69,133,70,133,71,133,75,133,76,133,77,133,78,133,79,133,80,133,81,133,82,133,83,133,84,133,85,133,87,133,88,133,90,133,91,133,92,133,93,133,95,133,96,133,97,133,98,133,99,133,101,133,102,133,103,133,105,133,106,133,107,133,108,133,109,133,110,133,111,133,112,133,113,133,115,133,117,133,118,133,119,133,120,133,124,133,125,133,127,133,128,133,129,133,1,119,219,118,105,82,220,128,35,87,8,94,49,89,238,114,189,101,127,110,215,139,56,92,113,134,65,83,243,119,254,98,246,101,192,78,223,152,128,134,158,91,198,139,242,83,226,119,127,79,78,92,118,154,203,89,15,95,58,121,235,88,22,78,255,103,139,78,237,98,147,138,29,144,191,82,47,102,220,85,108,86,2,144,213,78,141,79,202,145,112,153,15,108,2,94,67,96,164,91,198,137,213,139,54,101,75,98,150,153,136,91,255,91,136,99,46,85,215,83,38,118,125,81,44,133,162,103,179,104,138,107,146,98,147,143,212,83,18,130,209,109,143,117,102,78,78,141,112,91,159,113,175,133,145,102,217,102,114,127,0,135,205,158,32,159,94,92,47,103,240,143,17,104,95,103,13,98,214,122,133,88,182,94,112,101,49,111,130,133,131,133,134,133,136,133,137,133,138,133,139,133,140,133,141,133,142,133,144,133,145,133,146,133,147,133,148,133,149,133,150,133,151,133,152,133,153,133,154,133,157,133,158,133,159,133,160,133,161,133,162,133,163,133,165,133,166,133,167,133,169,133,171,133,172,133,173,133,177,133,178,133,179,133,180,133,181,133,182,133,184,133,186,133,187,133,188,133,189,133,190,133,191,133,192,133,194,133,195,133,196,133,197,133,198,133,199,133,200,133,202,133,203,133,204,133,205,133,206,133,209,133,210,133,212,133,214,133,215,133,216,133,217,133,218,133,219,133,221,133,222,133,223,133,224,133,225,133,226,133,227,133,229,133,230,133,231,133,232,133,234,133,235,133,236,133,237,133,238,133,239,133,240,133,241,133,242,133,243,133,244,133,245,133,246,133,247,133,248,133,85,96,55,82,13,128,84,100,112,136,41,117,5,94,19,104,244,98,28,151,204,83,61,114,1,140,52,108,97,119,14,122,46,84,172,119,122,152,28,130,244,139,85,120,20,103,193,112,175,101,149,100,54,86,29,96,193,121,248,83,29,78,123,107,134,128,250,91,227,85,219,86,58,79,60,79,114,153,243,93,126,103,56,128,2,96,130,152,1,144,139,91,188,139,245,139,28,100,88,130,222,100,253,85,207,130,101,145,215,79,32,125,31,144,159,124,243,80,81,88,175,110,191,91,201,139,131,128,120,145,156,132,151,123,125,134,139,150,143,150,229,126,211,154,142,120,129,92,87,122,66,144,167,150,95,121,89,91,95,99,11,123,209,132,173,104,6,85,41,127,16,116,34,125,1,149,64,98,76,88,214,78,131,91,121,89,84,88,249,133,250,133,252,133,253,133,254,133,0,134,1,134,2,134,3,134,4,134,6,134,7,134,8,134,9,134,10,134,11,134,12,134,13,134,14,134,15,134,16,134,18,134,19,134,20,134,21,134,23,134,24,134,25,134,26,134,27,134,28,134,29,134,30,134,31,134,32,134,33,134,34,134,35,134,36,134,37,134,38,134,40,134,42,134,43,134,44,134,45,134,46,134,47,134,48,134,49,134,50,134,51,134,52,134,53,134,54,134,55,134,57,134,58,134,59,134,61,134,62,134,63,134,64,134,65,134,66,134,67,134,68,134,69,134,70,134,71,134,72,134,73,134,74,134,75,134,76,134,82,134,83,134,85,134,86,134,87,134,88,134,89,134,91,134,92,134,93,134,95,134,96,134,97,134,99,134,100,134,101,134,102,134,103,134,104,134,105,134,106,134,109,115,30,99,75,142,15,142,206,128,212,130,172,98,240,83,240,108,94,145,42,89,1,96,112,108,77,87,74,100,42,141,43,118,233,110,91,87,128,106,240,117,109,111,45,140,8,140,102,87,239,107,146,136,179,120,162,99,249,83,173,112,100,108,88,88,42,100,2,88,224,104,155,129,16,85,214,124,24,80,186,142,204,109,159,141,235,112,143,99,155,109,212,110,230,126,4,132,67,104,3,144,216,109,118,150,168,139,87,89,121,114,228,133,126,129,188,117,138,138,175,104,84,82,34,142,17,149,208,99,152,152,68,142,124,85,83,79,255,102,143,86,213,96,149,109,67,82,73,92,41,89,251,109,107,88,48,117,28,117,108,96,20,130,70,129,17,99,97,103,226,143,58,119,243,141,52,141,193,148,22,94,133,83,44,84,195,112,109,134,111,134,112,134,114,134,115,134,116,134,117,134,118,134,119,134,120,134,131,134,132,134,133,134,134,134,135,134,136,134,137,134,142,134,143,134,144,134,145,134,146,134,148,134,150,134,151,134,152,134,153,134,154,134,155,134,158,134,159,134,160,134,161,134,162,134,165,134,166,134,171,134,173,134,174,134,178,134,179,134,183,134,184,134,185,134,187,134,188,134,189,134,190,134,191,134,193,134,194,134,195,134,197,134,200,134,204,134,205,134,210,134,211,134,213,134,214,134,215,134,218,134,220,134,221,134,224,134,225,134,226,134,227,134,229,134,230,134,231,134,232,134,234,134,235,134,236,134,239,134,245,134,246,134,247,134,250,134,251,134,252,134,253,134,255,134,1,135,4,135,5,135,6,135,11,135,12,135,14,135,15,135,16,135,17,135,20,135,22,135,64,108,247,94,92,80,173,78,173,94,58,99,71,130,26,144,80,104,110,145,179,119,12,84,220,148,100,95,229,122,118,104,69,99,82,123,223,126,219,117,119,80,149,98,52,89,15,144,248,81,195,121,129,122,254,86,146,95,20,144,130,109,96,92,31,87,16,84,84,81,77,110,226,86,168,99,147,152,127,129,21,135,42,137,0,144,30,84,111,92,192,129,214,98,88,98,49,129,53,158,64,150,110,154,124,154,45,105,165,89,211,98,62,85,22,99,199,84,217,134,60,109,3,90,230,116,156,136,106,107,22,89,76,140,47,95,126,110,169,115,125,152,56,78,247,112,140,91,151,120,61,99,90,102,150,118,203,96,155,91,73,90,7,78,85,129,106,108,139,115,161,78,137,103,81,127,128,95,250,101,27,103,216,95,132,89,1,90,25,135,27,135,29,135,31,135,32,135,36,135,38,135,39,135,40,135,42,135,43,135,44,135,45,135,47,135,48,135,50,135,51,135,53,135,54,135,56,135,57,135,58,135,60,135,61,135,64,135,65,135,66,135,67,135,68,135,69,135,70,135,74,135,75,135,77,135,79,135,80,135,81,135,82,135,84,135,85,135,86,135,88,135,90,135,91,135,92,135,93,135,94,135,95,135,97,135,98,135,102,135,103,135,104,135,105,135,106,135,107,135,108,135,109,135,111,135,113,135,114,135,115,135,117,135,119,135,120,135,121,135,122,135,127,135,128,135,129,135,132,135,134,135,135,135,137,135,138,135,140,135,142,135,143,135,144,135,145,135,146,135,148,135,149,135,150,135,152,135,153,135,154,135,155,135,156,135,157,135,158,135,160,135,161,135,162,135,163,135,164,135,205,93,174,95,113,83,230,151,221,143,69,104,244,86,47,85,223,96,58,78,77,111,244,126,199,130,14,132,212,89,31,79,42,79,62,92,172,126,42,103,26,133,115,84,79,117,195,128,130,85,79,155,77,79,45,110,19,140,9,92,112,97,107,83,31,118,41,110,138,134,135,101,251,149,185,126,59,84,51,122,10,125,238,149,225,85,193,127,238,116,29,99,23,135,161,109,157,122,17,98,161,101,103,83,225,99,131,108,235,93,92,84,168,148,76,78,97,108,236,139,75,92,224,101,156,130,167,104,62,84,52,84,203,107,102,107,148,78,66,99,72,83,30,130,13,79,174,79,94,87,10,98,254,150,100,102,105,114,255,82,161,82,159,96,239,139,20,102,153,113,144,103,127,137,82,120,253,119,112,102,59,86,56,84,33,149,122,114,165,135,166,135,167,135,169,135,170,135,174,135,176,135,177,135,178,135,180,135,182,135,183,135,184,135,185,135,187,135,188,135,190,135,191,135,193,135,194,135,195,135,196,135,197,135,199,135,200,135,201,135,204,135,205,135,206,135,207,135,208,135,212,135,213,135,214,135,215,135,216,135,217,135,218,135,220,135,221,135,222,135,223,135,225,135,226,135,227,135,228,135,230,135,231,135,232,135,233,135,235,135,236,135,237,135,239,135,240,135,241,135,242,135,243,135,244,135,245,135,246,135,247,135,248,135,250,135,251,135,252,135,253,135,255,135,0,136,1,136,2,136,4,136,5,136,6,136,7,136,8,136,9,136,11,136,12,136,13,136,14,136,15,136,16,136,17,136,18,136,20,136,23,136,24,136,25,136,26,136,28,136,29,136,30,136,31,136,32,136,35,136,0,122,111,96,12,94,137,96,157,129,21,89,220,96,132,113,239,112,170,110,80,108,128,114,132,106,173,136,45,94,96,78,179,90,156,85,227,148,23,109,251,124,153,150,15,98,198,126,142,119,126,134,35,83,30,151,150,143,135,102,225,92,160,79,237,114,11,78,166,83,15,89,19,84,128,99,40,149,72,81,217,78,156,156,164,126,184,84,36,141,84,136,55,130,242,149,142,109,38,95,204,90,62,102,105,150,176,115,46,115,191,83,122,129,133,153,161,127,170,91,119,150,80,150,191,126,248,118,162,83,118,149,153,153,177,123,68,137,88,110,97,78,212,127,101,121,230,139,243,96,205,84,171,78,121,152,247,93,97,106,207,80,17,84,97,140,39,132,93,120,4,151,74,82,238,84,163,86,0,149,136,109,181,91,198,109,83,102,36,136,37,136,38,136,39,136,40,136,41,136,42,136,43,136,44,136,45,136,46,136,47,136,48,136,49,136,51,136,52,136,53,136,54,136,55,136,56,136,58,136,59,136,61,136,62,136,63,136,65,136,66,136,67,136,70,136,71,136,72,136,73,136,74,136,75,136,78,136,79,136,80,136,81,136,82,136,83,136,85,136,86,136,88,136,90,136,91,136,92,136,93,136,94,136,95,136,96,136,102,136,103,136,106,136,109,136,111,136,113,136,115,136,116,136,117,136,118,136,120,136,121,136,122,136,123,136,124,136,128,136,131,136,134,136,135,136,137,136,138,136,140,136,142,136,143,136,144,136,145,136,147,136,148,136,149,136,151,136,152,136,153,136,154,136,155,136,157,136,158,136,159,136,160,136,161,136,163,136,165,136,166,136,167,136,168,136,169,136,170,136,15,92,93,91,33,104,150,128,120,85,17,123,72,101,84,105,155,78,71,107,78,135,139,151,79,83,31,99,58,100,170,144,156,101,193,128,16,140,153,81,176,104,120,83,249,135,200,97,196,108,251,108,34,140,81,92,170,133,175,130,12,149,35,107,155,143,176,101,251,95,195,95,225,79,69,136,31,102,101,129,41,115,250,96,116,81,17,82,139,87,98,95,162,144,76,136,146,145,120,94,79,103,39,96,211,89,68,81,246,81,248,128,8,83,121,108,196,150,138,113,17,79,238,79,158,127,61,103,197,85,8,149,192,121,150,136,227,126,159,88,12,98,0,151,90,134,24,86,123,152,144,95,184,139,196,132,87,145,217,83,237,101,143,94,92,117,100,96,110,125,127,90,234,126,237,126,105,143,167,85,163,91,172,96,203,101,132,115,172,136,174,136,175,136,176,136,178,136,179,136,180,136,181,136,182,136,184,136,185,136,186,136,187,136,189,136,190,136,191,136,192,136,195,136,196,136,199,136,200,136,202,136,203,136,204,136,205,136,207,136,208,136,209,136,211,136,214,136,215,136,218,136,219,136,220,136,221,136,222,136,224,136,225,136,230,136,231,136,233,136,234,136,235,136,236,136,237,136,238,136,239,136,242,136,245,136,246,136,247,136,250,136,251,136,253,136,255,136,0,137,1,137,3,137,4,137,5,137,6,137,7,137,8,137,9,137,11,137,12,137,13,137,14,137,15,137,17,137,20,137,21,137,22,137,23,137,24,137,28,137,29,137,30,137,31,137,32,137,34,137,35,137,36,137,38,137,39,137,40,137,41,137,44,137,45,137,46,137,47,137,49,137,50,137,51,137,53,137,55,137,9,144,99,118,41,119,218,126,116,151,155,133,102,91,116,122,234,150,64,136,203,82,143,113,170,95,236,101,226,139,251,91,111,154,225,93,137,107,91,108,173,139,175,139,10,144,197,143,139,83,188,98,38,158,45,158,64,84,43,78,189,130,89,114,156,134,22,93,89,136,175,109,197,150,209,84,154,78,182,139,9,113,189,84,9,150,223,112,249,109,208,118,37,78,20,120,18,135,169,92,246,94,0,138,156,152,14,150,142,112,191,108,68,89,169,99,60,119,77,136,20,111,115,130,48,88,213,113,140,83,26,120,193,150,1,85,102,95,48,113,180,91,26,140,140,154,131,107,46,89,47,158,231,121,104,103,108,98,111,79,161,117,138,127,11,109,51,150,39,108,240,78,210,117,123,81,55,104,62,111,128,144,112,129,150,89,118,116,56,137,57,137,58,137,59,137,60,137,61,137,62,137,63,137,64,137,66,137,67,137,69,137,70,137,71,137,72,137,73,137,74,137,75,137,76,137,77,137,78,137,79,137,80,137,81,137,82,137,83,137,84,137,85,137,86,137,87,137,88,137,89,137,90,137,91,137,92,137,93,137,96,137,97,137,98,137,99,137,100,137,101,137,103,137,104,137,105,137,106,137,107,137,108,137,109,137,110,137,111,137,112,137,113,137,114,137,115,137,116,137,117,137,118,137,119,137,120,137,121,137,122,137,124,137,125,137,126,137,128,137,130,137,132,137,133,137,135,137,136,137,137,137,138,137,139,137,140,137,141,137,142,137,143,137,144,137,145,137,146,137,147,137,148,137,149,137,150,137,151,137,152,137,153,137,154,137,155,137,156,137,157,137,158,137,159,137,160,137,161,137,71,100,39,92,101,144,145,122,35,140,218,89,172,84,0,130,111,131,129,137,0,128,48,105,78,86,54,128,55,114,206,145,182,81,95,78,117,152,150,99,26,78,246,83,243,102,75,129,28,89,178,109,0,78,249,88,59,83,214,99,241,148,157,79,10,79,99,136,144,152,55,89,87,144,251,121,234,78,240,128,145,117,130,108,156,91,232,89,93,95,5,105,129,134,26,80,242,93,89,78,227,119,229,78,122,130,145,98,19,102,145,144,121,92,191,78,121,95,198,129,56,144,132,128,171,117,166,78,212,136,15,97,197,107,198,95,73,78,202,118,162,110,227,139,174,139,10,140,209,139,2,95,252,127,204,127,206,126,53,131,107,131,224,86,183,107,243,151,52,150,251,89,31,84,246,148,235,109,197,91,110,153,57,92,21,95,144,150,162,137,163,137,164,137,165,137,166,137,167,137,168,137,169,137,170,137,171,137,172,137,173,137,174,137,175,137,176,137,177,137,178,137,179,137,180,137,181,137,182,137,183,137,184,137,185,137,186,137,187,137,188,137,189,137,190,137,191,137,192,137,195,137,205,137,211,137,212,137,213,137,215,137,216,137,217,137,219,137,221,137,223,137,224,137,225,137,226,137,228,137,231,137,232,137,233,137,234,137,236,137,237,137,238,137,240,137,241,137,242,137,244,137,245,137,246,137,247,137,248,137,249,137,250,137,251,137,252,137,253,137,254,137,255,137,1,138,2,138,3,138,4,138,5,138,6,138,8,138,9,138,10,138,11,138,12,138,13,138,14,138,15,138,16,138,17,138,18,138,19,138,20,138,21,138,22,138,23,138,24,138,25,138,26,138,27,138,28,138,29,138,112,83,241,130,49,106,116,90,112,158,148,94,40,127,185,131,36,132,37,132,103,131,71,135,206,143,98,141,200,118,113,95,150,152,108,120,32,102,223,84,229,98,99,79,195,129,200,117,184,94,205,150,10,142,249,134,143,84,243,108,140,109,56,108,127,96,199,82,40,117,125,94,24,79,160,96,231,95,36,92,49,117,174,144,192,148,185,114,185,108,56,110,73,145,9,103,203,83,243,83,81,79,201,145,241,139,200,83,124,94,194,143,228,109,142,78,194,118,134,105,94,134,26,97,6,130,89,79,222,79,62,144,124,156,9,97,29,110,20,110,133,150,136,78,49,90,232,150,14,78,127,92,185,121,135,91,237,139,189,127,137,115,223,87,139,130,193,144,1,84,71,144,187,85,234,92,161,95,8,97,50,107,241,114,178,128,137,138,30,138,31,138,32,138,33,138,34,138,35,138,36,138,37,138,38,138,39,138,40,138,41,138,42,138,43,138,44,138,45,138,46,138,47,138,48,138,49,138,50,138,51,138,52,138,53,138,54,138,55,138,56,138,57,138,58,138,59,138,60,138,61,138,63,138,64,138,65,138,66,138,67,138,68,138,69,138,70,138,71,138,73,138,74,138,75,138,76,138,77,138,78,138,79,138,80,138,81,138,82,138,83,138,84,138,85,138,86,138,87,138,88,138,89,138,90,138,91,138,92,138,93,138,94,138,95,138,96,138,97,138,98,138,99,138,100,138,101,138,102,138,103,138,104,138,105,138,106,138,107,138,108,138,109,138,110,138,111,138,112,138,113,138,114,138,115,138,116,138,117,138,118,138,119,138,120,138,122,138,123,138,124,138,125,138,126,138,127,138,128,138,116,109,211,91,213,136,132,152,107,140,109,154,51,158,10,110,164,81,67,81,163,87,129,136,159,83,244,99,149,143,237,86,88,84,6,87,63,115,144,110,24,127,220,143,209,130,63,97,40,96,98,150,240,102,166,126,138,141,195,141,165,148,179,92,164,124,8,103,166,96,5,150,24,128,145,78,231,144,0,83,104,150,65,81,208,143,116,133,93,145,85,102,245,151,85,91,29,83,56,120,66,103,61,104,201,84,126,112,176,91,125,143,141,81,40,87,177,84,18,101,130,102,94,141,67,141,15,129,108,132,109,144,223,124,255,81,251,133,163,103,233,101,161,111,164,134,129,142,106,86,32,144,130,118,118,112,229,113,35,141,233,98,25,82,253,108,60,141,14,96,158,88,142,97,254,102,96,141,78,98,179,85,35,110,45,103,103,143,129,138,130,138,131,138,132,138,133,138,134,138,135,138,136,138,139,138,140,138,141,138,142,138,143,138,144,138,145,138,146,138,148,138,149,138,150,138,151,138,152,138,153,138,154,138,155,138,156,138,157,138,158,138,159,138,160,138,161,138,162,138,163,138,164,138,165,138,166,138,167,138,168,138,169,138,170,138,171,138,172,138,173,138,174,138,175,138,176,138,177,138,178,138,179,138,180,138,181,138,182,138,183,138,184,138,185,138,186,138,187,138,188,138,189,138,190,138,191,138,192,138,193,138,194,138,195,138,196,138,197,138,198,138,199,138,200,138,201,138,202,138,203,138,204,138,205,138,206,138,207,138,208,138,209,138,210,138,211,138,212,138,213,138,214,138,215,138,216,138,217,138,218,138,219,138,220,138,221,138,222,138,223,138,224,138,225,138,226,138,227,138,225,148,248,149,40,119,5,104,168,105,139,84,77,78,184,112,200,139,88,100,139,101,133,91,132,122,58,80,232,91,187,119,225,107,121,138,152,124,190,108,207,118,169,101,151,143,45,93,85,92,56,134,8,104,96,83,24,98,217,122,91,110,253,126,31,106,224,122,112,95,51,111,32,95,140,99,168,109,86,103,8,78,16,94,38,141,215,78,192,128,52,118,156,150,219,98,45,102,126,98,188,108,117,141,103,113,105,127,70,81,135,128,236,83,110,144,152,98,242,84,240,134,153,143,5,128,23,149,23,133,217,143,89,109,205,115,159,101,31,119,4,117,39,120,251,129,30,141,136,148,166,79,149,103,185,117,202,139,7,151,47,99,71,149,53,150,184,132,35,99,65,119,129,95,240,114,137,78,20,96,116,101,239,98,99,107,63,101,228,138,229,138,230,138,231,138,232,138,233,138,234,138,235,138,236,138,237,138,238,138,239,138,240,138,241,138,242,138,243,138,244,138,245,138,246,138,247,138,248,138,249,138,250,138,251,138,252,138,253,138,254,138,255,138,0,139,1,139,2,139,3,139,4,139,5,139,6,139,8,139,9,139,10,139,11,139,12,139,13,139,14,139,15,139,16,139,17,139,18,139,19,139,20,139,21,139,22,139,23,139,24,139,25,139,26,139,27,139,28,139,29,139,30,139,31,139,32,139,33,139,34,139,35,139,36,139,37,139,39,139,40,139,41,139,42,139,43,139,44,139,45,139,46,139,47,139,48,139,49,139,50,139,51,139,52,139,53,139,54,139,55,139,56,139,57,139,58,139,59,139,60,139,61,139,62,139,63,139,64,139,65,139,66,139,67,139,68,139,69,139,39,94,199,117,209,144,193,139,157,130,157,103,47,101,49,84,24,135,229,119,162,128,2,129,65,108,75,78,199,126,76,128,244,118,13,105,150,107,103,98,60,80,132,79,64,87,7,99,98,107,190,141,234,83,232,101,184,126,215,95,26,99,183,99,243,129,244,129,110,127,28,94,217,92,54,82,122,102,233,121,26,122,40,141,153,112,212,117,222,110,187,108,146,122,45,78,197,118,224,95,159,148,119,136,200,126,205,121,191,128,205,145,242,78,23,79,31,130,104,84,222,93,50,109,204,139,165,124,116,143,152,128,26,94,146,84,177,118,153,91,60,102,164,154,224,115,42,104,219,134,49,103,42,115,248,139,219,139,16,144,249,122,219,112,110,113,196,98,169,119,49,86,59,78,87,132,241,103,169,82,192,134,46,141,248,148,81,123,70,139,71,139,72,139,73,139,74,139,75,139,76,139,77,139,78,139,79,139,80,139,81,139,82,139,83,139,84,139,85,139,86,139,87,139,88,139,89,139,90,139,91,139,92,139,93,139,94,139,95,139,96,139,97,139,98,139,99,139,100,139,101,139,103,139,104,139,105,139,106,139,107,139,109,139,110,139,111,139,112,139,113,139,114,139,115,139,116,139,117,139,118,139,119,139,120,139,121,139,122,139,123,139,124,139,125,139,126,139,127,139,128,139,129,139,130,139,131,139,132,139,133,139,134,139,135,139,136,139,137,139,138,139,139,139,140,139,141,139,142,139,143,139,144,139,145,139,146,139,147,139,148,139,149,139,150,139,151,139,152,139,153,139,154,139,155,139,156,139,157,139,158,139,159,139,172,139,177,139,187,139,199,139,208,139,234,139,9,140,30,140,79,79,232,108,93,121,123,154,147,98,42,114,253,98,19,78,22,120,108,143,176,100,90,141,198,123,105,104,132,94,197,136,134,89,158,100,238,88,182,114,14,105,37,149,253,143,88,141,96,87,0,127,6,140,198,81,73,99,217,98,83,83,76,104,34,116,1,131,76,145,68,85,64,119,124,112,74,109,121,81,168,84,68,141,255,89,203,110,196,109,92,91,43,125,212,78,125,124,211,110,80,91,234,129,13,110,87,91,3,155,213,104,42,142,151,91,252,126,59,96,181,126,185,144,112,141,79,89,205,99,223,121,179,141,82,83,207,101,86,121,197,139,59,150,196,126,187,148,130,126,52,86,137,145,0,103,106,127,10,92,117,144,40,102,230,93,80,79,222,103,90,80,92,79,80,87,167,94,16,232,17,232,18,232,19,232,20,232,56,140,57,140,58,140,59,140,60,140,61,140,62,140,63,140,64,140,66,140,67,140,68,140,69,140,72,140,74,140,75,140,77,140,78,140,79,140,80,140,81,140,82,140,83,140,84,140,86,140,87,140,88,140,89,140,91,140,92,140,93,140,94,140,95,140,96,140,99,140,100,140,101,140,102,140,103,140,104,140,105,140,108,140,109,140,110,140,111,140,112,140], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1173216);
/* memory initializer */ allocate([113,140,114,140,116,140,117,140,118,140,119,140,123,140,124,140,125,140,126,140,127,140,128,140,129,140,131,140,132,140,134,140,135,140,136,140,139,140,141,140,142,140,143,140,144,140,145,140,146,140,147,140,149,140,150,140,151,140,153,140,154,140,155,140,156,140,157,140,158,140,159,140,160,140,161,140,162,140,163,140,164,140,165,140,166,140,167,140,168,140,169,140,170,140,171,140,172,140,173,140,141,78,12,78,64,81,16,78,255,94,69,83,21,78,152,78,30,78,50,155,108,91,105,86,40,78,186,121,63,78,21,83,71,78,45,89,59,114,110,83,16,108,223,86,228,128,151,153,211,107,126,119,23,159,54,78,159,78,16,159,92,78,105,78,147,78,136,130,91,91,108,85,15,86,196,78,141,83,157,83,163,83,165,83,174,83,101,151,93,141,26,83,245,83,38,83,46,83,62,83,92,141,102,83,99,83,2,82,8,82,14,82,45,82,51,82,63,82,64,82,76,82,94,82,97,82,92,82,175,132,125,82,130,82,129,82,144,82,147,82,130,81,84,127,187,78,195,78,201,78,194,78,232,78,225,78,235,78,222,78,27,79,243,78,34,79,100,79,245,78,37,79,39,79,9,79,43,79,94,79,103,79,56,101,90,79,93,79,174,140,175,140,176,140,177,140,178,140,179,140,180,140,181,140,182,140,183,140,184,140,185,140,186,140,187,140,188,140,189,140,190,140,191,140,192,140,193,140,194,140,195,140,196,140,197,140,198,140,199,140,200,140,201,140,202,140,203,140,204,140,205,140,206,140,207,140,208,140,209,140,210,140,211,140,212,140,213,140,214,140,215,140,216,140,217,140,218,140,219,140,220,140,221,140,222,140,223,140,224,140,225,140,226,140,227,140,228,140,229,140,230,140,231,140,232,140,233,140,234,140,235,140,236,140,237,140,238,140,239,140,240,140,241,140,242,140,243,140,244,140,245,140,246,140,247,140,248,140,249,140,250,140,251,140,252,140,253,140,254,140,255,140,0,141,1,141,2,141,3,141,4,141,5,141,6,141,7,141,8,141,9,141,10,141,11,141,12,141,13,141,95,79,87,79,50,79,61,79,118,79,116,79,145,79,137,79,131,79,143,79,126,79,123,79,170,79,124,79,172,79,148,79,230,79,232,79,234,79,197,79,218,79,227,79,220,79,209,79,223,79,248,79,41,80,76,80,243,79,44,80,15,80,46,80,45,80,254,79,28,80,12,80,37,80,40,80,126,80,67,80,85,80,72,80,78,80,108,80,123,80,165,80,167,80,169,80,186,80,214,80,6,81,237,80,236,80,230,80,238,80,7,81,11,81,221,78,61,108,88,79,101,79,206,79,160,159,70,108,116,124,110,81,253,93,201,158,152,153,129,81,20,89,249,82,13,83,7,138,16,83,235,81,25,89,85,81,160,78,86,81,179,78,110,136,164,136,181,78,20,129,210,136,128,121,52,91,3,136,184,127,171,81,177,81,189,81,188,81,14,141,15,141,16,141,17,141,18,141,19,141,20,141,21,141,22,141,23,141,24,141,25,141,26,141,27,141,28,141,32,141,81,141,82,141,87,141,95,141,101,141,104,141,105,141,106,141,108,141,110,141,111,141,113,141,114,141,120,141,121,141,122,141,123,141,124,141,125,141,126,141,127,141,128,141,130,141,131,141,134,141,135,141,136,141,137,141,140,141,141,141,142,141,143,141,144,141,146,141,147,141,149,141,150,141,151,141,152,141,153,141,154,141,155,141,156,141,157,141,158,141,160,141,161,141,162,141,164,141,165,141,166,141,167,141,168,141,169,141,170,141,171,141,172,141,173,141,174,141,175,141,176,141,178,141,182,141,183,141,185,141,187,141,189,141,192,141,193,141,194,141,197,141,199,141,200,141,201,141,202,141,205,141,208,141,210,141,211,141,212,141,199,81,150,81,162,81,165,81,160,139,166,139,167,139,170,139,180,139,181,139,183,139,194,139,195,139,203,139,207,139,206,139,210,139,211,139,212,139,214,139,216,139,217,139,220,139,223,139,224,139,228,139,232,139,233,139,238,139,240,139,243,139,246,139,249,139,252,139,255,139,0,140,2,140,4,140,7,140,12,140,15,140,17,140,18,140,20,140,21,140,22,140,25,140,27,140,24,140,29,140,31,140,32,140,33,140,37,140,39,140,42,140,43,140,46,140,47,140,50,140,51,140,53,140,54,140,105,83,122,83,29,150,34,150,33,150,49,150,42,150,61,150,60,150,66,150,73,150,84,150,95,150,103,150,108,150,114,150,116,150,136,150,141,150,151,150,176,150,151,144,155,144,157,144,153,144,172,144,161,144,180,144,179,144,182,144,186,144,213,141,216,141,217,141,220,141,224,141,225,141,226,141,229,141,230,141,231,141,233,141,237,141,238,141,240,141,241,141,242,141,244,141,246,141,252,141,254,141,255,141,0,142,1,142,2,142,3,142,4,142,6,142,7,142,8,142,11,142,13,142,14,142,16,142,17,142,18,142,19,142,21,142,22,142,23,142,24,142,25,142,26,142,27,142,28,142,32,142,33,142,36,142,37,142,38,142,39,142,40,142,43,142,45,142,48,142,50,142,51,142,52,142,54,142,55,142,56,142,59,142,60,142,62,142,63,142,67,142,69,142,70,142,76,142,77,142,78,142,79,142,80,142,83,142,84,142,85,142,86,142,87,142,88,142,90,142,91,142,92,142,93,142,94,142,95,142,96,142,97,142,98,142,99,142,100,142,101,142,103,142,104,142,106,142,107,142,110,142,113,142,184,144,176,144,207,144,197,144,190,144,208,144,196,144,199,144,211,144,230,144,226,144,220,144,215,144,219,144,235,144,239,144,254,144,4,145,34,145,30,145,35,145,49,145,47,145,57,145,67,145,70,145,13,82,66,89,162,82,172,82,173,82,190,82,255,84,208,82,214,82,240,82,223,83,238,113,205,119,244,94,245,81,252,81,47,155,182,83,1,95,90,117,239,93,76,87,169,87,161,87,126,88,188,88,197,88,209,88,41,87,44,87,42,87,51,87,57,87,46,87,47,87,92,87,59,87,66,87,105,87,133,87,107,87,134,87,124,87,123,87,104,87,109,87,118,87,115,87,173,87,164,87,140,87,178,87,207,87,167,87,180,87,147,87,160,87,213,87,216,87,218,87,217,87,210,87,184,87,244,87,239,87,248,87,228,87,221,87,115,142,117,142,119,142,120,142,121,142,122,142,123,142,125,142,126,142,128,142,130,142,131,142,132,142,134,142,136,142,137,142,138,142,139,142,140,142,141,142,142,142,145,142,146,142,147,142,149,142,150,142,151,142,152,142,153,142,154,142,155,142,157,142,159,142,160,142,161,142,162,142,163,142,164,142,165,142,166,142,167,142,168,142,169,142,170,142,173,142,174,142,176,142,177,142,179,142,180,142,181,142,182,142,183,142,184,142,185,142,187,142,188,142,189,142,190,142,191,142,192,142,193,142,194,142,195,142,196,142,197,142,198,142,199,142,200,142,201,142,202,142,203,142,204,142,205,142,207,142,208,142,209,142,210,142,211,142,212,142,213,142,214,142,215,142,216,142,217,142,218,142,219,142,220,142,221,142,222,142,223,142,224,142,225,142,226,142,227,142,228,142,11,88,13,88,253,87,237,87,0,88,30,88,25,88,68,88,32,88,101,88,108,88,129,88,137,88,154,88,128,88,168,153,25,159,255,97,121,130,125,130,127,130,143,130,138,130,168,130,132,130,142,130,145,130,151,130,153,130,171,130,184,130,190,130,176,130,200,130,202,130,227,130,152,130,183,130,174,130,203,130,204,130,193,130,169,130,180,130,161,130,170,130,159,130,196,130,206,130,164,130,225,130,9,131,247,130,228,130,15,131,7,131,220,130,244,130,210,130,216,130,12,131,251,130,211,130,17,131,26,131,6,131,20,131,21,131,224,130,213,130,28,131,81,131,91,131,92,131,8,131,146,131,60,131,52,131,49,131,155,131,94,131,47,131,79,131,71,131,67,131,95,131,64,131,23,131,96,131,45,131,58,131,51,131,102,131,101,131,229,142,230,142,231,142,232,142,233,142,234,142,235,142,236,142,237,142,238,142,239,142,240,142,241,142,242,142,243,142,244,142,245,142,246,142,247,142,248,142,249,142,250,142,251,142,252,142,253,142,254,142,255,142,0,143,1,143,2,143,3,143,4,143,5,143,6,143,7,143,8,143,9,143,10,143,11,143,12,143,13,143,14,143,15,143,16,143,17,143,18,143,19,143,20,143,21,143,22,143,23,143,24,143,25,143,26,143,27,143,28,143,29,143,30,143,31,143,32,143,33,143,34,143,35,143,36,143,37,143,38,143,39,143,40,143,41,143,42,143,43,143,44,143,45,143,46,143,47,143,48,143,49,143,50,143,51,143,52,143,53,143,54,143,55,143,56,143,57,143,58,143,59,143,60,143,61,143,62,143,63,143,64,143,65,143,66,143,67,143,68,143,104,131,27,131,105,131,108,131,106,131,109,131,110,131,176,131,120,131,179,131,180,131,160,131,170,131,147,131,156,131,133,131,124,131,182,131,169,131,125,131,184,131,123,131,152,131,158,131,168,131,186,131,188,131,193,131,1,132,229,131,216,131,7,88,24,132,11,132,221,131,253,131,214,131,28,132,56,132,17,132,6,132,212,131,223,131,15,132,3,132,248,131,249,131,234,131,197,131,192,131,38,132,240,131,225,131,92,132,81,132,90,132,89,132,115,132,135,132,136,132,122,132,137,132,120,132,60,132,70,132,105,132,118,132,140,132,142,132,49,132,109,132,193,132,205,132,208,132,230,132,189,132,211,132,202,132,191,132,186,132,224,132,161,132,185,132,180,132,151,132,229,132,227,132,12,133,13,117,56,133,240,132,57,133,31,133,58,133,69,143,70,143,71,143,72,143,73,143,74,143,75,143,76,143,77,143,78,143,79,143,80,143,81,143,82,143,83,143,84,143,85,143,86,143,87,143,88,143,89,143,90,143,91,143,92,143,93,143,94,143,95,143,96,143,97,143,98,143,99,143,100,143,101,143,106,143,128,143,140,143,146,143,157,143,160,143,161,143,162,143,164,143,165,143,166,143,167,143,170,143,172,143,173,143,174,143,175,143,178,143,179,143,180,143,181,143,183,143,184,143,186,143,187,143,188,143,191,143,192,143,195,143,198,143,201,143,202,143,203,143,204,143,205,143,207,143,210,143,214,143,215,143,218,143,224,143,225,143,227,143,231,143,236,143,239,143,241,143,242,143,244,143,245,143,246,143,250,143,251,143,252,143,254,143,255,143,7,144,8,144,12,144,14,144,19,144,21,144,24,144,86,133,59,133,255,132,252,132,89,133,72,133,104,133,100,133,94,133,122,133,162,119,67,133,114,133,123,133,164,133,168,133,135,133,143,133,121,133,174,133,156,133,133,133,185,133,183,133,176,133,211,133,193,133,220,133,255,133,39,134,5,134,41,134,22,134,60,134,254,94,8,95,60,89,65,89,55,128,85,89,90,89,88,89,15,83,34,92,37,92,44,92,52,92,76,98,106,98,159,98,187,98,202,98,218,98,215,98,238,98,34,99,246,98,57,99,75,99,67,99,173,99,246,99,113,99,122,99,142,99,180,99,109,99,172,99,138,99,105,99,174,99,188,99,242,99,248,99,224,99,255,99,196,99,222,99,206,99,82,100,198,99,190,99,69,100,65,100,11,100,27,100,32,100,12,100,38,100,33,100,94,100,132,100,109,100,150,100,25,144,28,144,35,144,36,144,37,144,39,144,40,144,41,144,42,144,43,144,44,144,48,144,49,144,50,144,51,144,52,144,55,144,57,144,58,144,61,144,63,144,64,144,67,144,69,144,70,144,72,144,73,144,74,144,75,144,76,144,78,144,84,144,85,144,86,144,89,144,90,144,92,144,93,144,94,144,95,144,96,144,97,144,100,144,102,144,103,144,105,144,106,144,107,144,108,144,111,144,112,144,113,144,114,144,115,144,118,144,119,144,120,144,121,144,122,144,123,144,124,144,126,144,129,144,132,144,133,144,134,144,135,144,137,144,138,144,140,144,141,144,142,144,143,144,144,144,146,144,148,144,150,144,152,144,154,144,156,144,158,144,159,144,160,144,164,144,165,144,167,144,168,144,169,144,171,144,173,144,178,144,183,144,188,144,189,144,191,144,192,144,122,100,183,100,184,100,153,100,186,100,192,100,208,100,215,100,228,100,226,100,9,101,37,101,46,101,11,95,210,95,25,117,17,95,95,83,241,83,253,83,233,83,232,83,251,83,18,84,22,84,6,84,75,84,82,84,83,84,84,84,86,84,67,84,33,84,87,84,89,84,35,84,50,84,130,84,148,84,119,84,113,84,100,84,154,84,155,84,132,84,118,84,102,84,157,84,208,84,173,84,194,84,180,84,210,84,167,84,166,84,211,84,212,84,114,84,163,84,213,84,187,84,191,84,204,84,217,84,218,84,220,84,169,84,170,84,164,84,221,84,207,84,222,84,27,85,231,84,32,85,253,84,20,85,243,84,34,85,35,85,15,85,17,85,39,85,42,85,103,85,143,85,181,85,73,85,109,85,65,85,85,85,63,85,80,85,60,85,194,144,195,144,198,144,200,144,201,144,203,144,204,144,205,144,210,144,212,144,213,144,214,144,216,144,217,144,218,144,222,144,223,144,224,144,227,144,228,144,229,144,233,144,234,144,236,144,238,144,240,144,241,144,242,144,243,144,245,144,246,144,247,144,249,144,250,144,251,144,252,144,255,144,0,145,1,145,3,145,5,145,6,145,7,145,8,145,9,145,10,145,11,145,12,145,13,145,14,145,15,145,16,145,17,145,18,145,19,145,20,145,21,145,22,145,23,145,24,145,26,145,27,145,28,145,29,145,31,145,32,145,33,145,36,145,37,145,38,145,39,145,40,145,41,145,42,145,43,145,44,145,45,145,46,145,48,145,50,145,51,145,52,145,53,145,54,145,55,145,56,145,58,145,59,145,60,145,61,145,62,145,63,145,64,145,65,145,66,145,68,145,55,85,86,85,117,85,118,85,119,85,51,85,48,85,92,85,139,85,210,85,131,85,177,85,185,85,136,85,129,85,159,85,126,85,214,85,145,85,123,85,223,85,189,85,190,85,148,85,153,85,234,85,247,85,201,85,31,86,209,85,235,85,236,85,212,85,230,85,221,85,196,85,239,85,229,85,242,85,243,85,204,85,205,85,232,85,245,85,228,85,148,143,30,86,8,86,12,86,1,86,36,86,35,86,254,85,0,86,39,86,45,86,88,86,57,86,87,86,44,86,77,86,98,86,89,86,92,86,76,86,84,86,134,86,100,86,113,86,107,86,123,86,124,86,133,86,147,86,175,86,212,86,215,86,221,86,225,86,245,86,235,86,249,86,255,86,4,87,10,87,9,87,28,87,15,94,25,94,20,94,17,94,49,94,59,94,60,94,69,145,71,145,72,145,81,145,83,145,84,145,85,145,86,145,88,145,89,145,91,145,92,145,95,145,96,145,102,145,103,145,104,145,107,145,109,145,115,145,122,145,123,145,124,145,128,145,129,145,130,145,131,145,132,145,134,145,136,145,138,145,142,145,143,145,147,145,148,145,149,145,150,145,151,145,152,145,153,145,156,145,157,145,158,145,159,145,160,145,161,145,164,145,165,145,166,145,167,145,168,145,169,145,171,145,172,145,176,145,177,145,178,145,179,145,182,145,183,145,184,145,185,145,187,145,188,145,189,145,190,145,191,145,192,145,193,145,194,145,195,145,196,145,197,145,198,145,200,145,203,145,208,145,210,145,211,145,212,145,213,145,214,145,215,145,216,145,217,145,218,145,219,145,221,145,222,145,223,145,224,145,225,145,226,145,227,145,228,145,229,145,55,94,68,94,84,94,91,94,94,94,97,94,140,92,122,92,141,92,144,92,150,92,136,92,152,92,153,92,145,92,154,92,156,92,181,92,162,92,189,92,172,92,171,92,177,92,163,92,193,92,183,92,196,92,210,92,228,92,203,92,229,92,2,93,3,93,39,93,38,93,46,93,36,93,30,93,6,93,27,93,88,93,62,93,52,93,61,93,108,93,91,93,111,93,93,93,107,93,75,93,74,93,105,93,116,93,130,93,153,93,157,93,115,140,183,93,197,93,115,95,119,95,130,95,135,95,137,95,140,95,149,95,153,95,156,95,168,95,173,95,181,95,188,95,98,136,97,95,173,114,176,114,180,114,183,114,184,114,195,114,193,114,206,114,205,114,210,114,232,114,239,114,233,114,242,114,244,114,247,114,1,115,243,114,3,115,250,114,230,145,231,145,232,145,233,145,234,145,235,145,236,145,237,145,238,145,239,145,240,145,241,145,242,145,243,145,244,145,245,145,246,145,247,145,248,145,249,145,250,145,251,145,252,145,253,145,254,145,255,145,0,146,1,146,2,146,3,146,4,146,5,146,6,146,7,146,8,146,9,146,10,146,11,146,12,146,13,146,14,146,15,146,16,146,17,146,18,146,19,146,20,146,21,146,22,146,23,146,24,146,25,146,26,146,27,146,28,146,29,146,30,146,31,146,32,146,33,146,34,146,35,146,36,146,37,146,38,146,39,146,40,146,41,146,42,146,43,146,44,146,45,146,46,146,47,146,48,146,49,146,50,146,51,146,52,146,53,146,54,146,55,146,56,146,57,146,58,146,59,146,60,146,61,146,62,146,63,146,64,146,65,146,66,146,67,146,68,146,69,146,251,114,23,115,19,115,33,115,10,115,30,115,29,115,21,115,34,115,57,115,37,115,44,115,56,115,49,115,80,115,77,115,87,115,96,115,108,115,111,115,126,115,27,130,37,89,231,152,36,89,2,89,99,153,103,153,104,153,105,153,106,153,107,153,108,153,116,153,119,153,125,153,128,153,132,153,135,153,138,153,141,153,144,153,145,153,147,153,148,153,149,153,128,94,145,94,139,94,150,94,165,94,160,94,185,94,181,94,190,94,179,94,83,141,210,94,209,94,219,94,232,94,234,94,186,129,196,95,201,95,214,95,207,95,3,96,238,95,4,96,225,95,228,95,254,95,5,96,6,96,234,95,237,95,248,95,25,96,53,96,38,96,27,96,15,96,13,96,41,96,43,96,10,96,63,96,33,96,120,96,121,96,123,96,122,96,66,96,70,146,71,146,72,146,73,146,74,146,75,146,76,146,77,146,78,146,79,146,80,146,81,146,82,146,83,146,84,146,85,146,86,146,87,146,88,146,89,146,90,146,91,146,92,146,93,146,94,146,95,146,96,146,97,146,98,146,99,146,100,146,101,146,102,146,103,146,104,146,105,146,106,146,107,146,108,146,109,146,110,146,111,146,112,146,113,146,114,146,115,146,117,146,118,146,119,146,120,146,121,146,122,146,123,146,124,146,125,146,126,146,127,146,128,146,129,146,130,146,131,146,132,146,133,146,134,146,135,146,136,146,137,146,138,146,139,146,140,146,141,146,143,146,144,146,145,146,146,146,147,146,148,146,149,146,150,146,151,146,152,146,153,146,154,146,155,146,156,146,157,146,158,146,159,146,160,146,161,146,162,146,163,146,164,146,165,146,166,146,167,146,106,96,125,96,150,96,154,96,173,96,157,96,131,96,146,96,140,96,155,96,236,96,187,96,177,96,221,96,216,96,198,96,218,96,180,96,32,97,38,97,21,97,35,97,244,96,0,97,14,97,43,97,74,97,117,97,172,97,148,97,167,97,183,97,212,97,245,97,221,95,179,150,233,149,235,149,241,149,243,149,245,149,246,149,252,149,254,149,3,150,4,150,6,150,8,150,10,150,11,150,12,150,13,150,15,150,18,150,21,150,22,150,23,150,25,150,26,150,44,78,63,114,21,98,53,108,84,108,92,108,74,108,163,108,133,108,144,108,148,108,140,108,104,108,105,108,116,108,118,108,134,108,169,108,208,108,212,108,173,108,247,108,248,108,241,108,215,108,178,108,224,108,214,108,250,108,235,108,238,108,177,108,211,108,239,108,254,108,168,146,169,146,170,146,171,146,172,146,173,146,175,146,176,146,177,146,178,146,179,146,180,146,181,146,182,146,183,146,184,146,185,146,186,146,187,146,188,146,189,146,190,146,191,146,192,146,193,146,194,146,195,146,196,146,197,146,198,146,199,146,201,146,202,146,203,146,204,146,205,146,206,146,207,146,208,146,209,146,210,146,211,146,212,146,213,146,214,146,215,146,216,146,217,146,218,146,219,146,220,146,221,146,222,146,223,146,224,146,225,146,226,146,227,146,228,146,229,146,230,146,231,146,232,146,233,146,234,146,235,146,236,146,237,146,238,146,239,146,240,146,241,146,242,146,243,146,244,146,245,146,246,146,247,146,248,146,249,146,250,146,251,146,252,146,253,146,254,146,255,146,0,147,1,147,2,147,3,147,4,147,5,147,6,147,7,147,8,147,9,147,57,109,39,109,12,109,67,109,72,109,7,109,4,109,25,109,14,109,43,109,77,109,46,109,53,109,26,109,79,109,82,109,84,109,51,109,145,109,111,109,158,109,160,109,94,109,147,109,148,109,92,109,96,109,124,109,99,109,26,110,199,109,197,109,222,109,14,110,191,109,224,109,17,110,230,109,221,109,217,109,22,110,171,109,12,110,174,109,43,110,110,110,78,110,107,110,178,110,95,110,134,110,83,110,84,110,50,110,37,110,68,110,223,110,177,110,152,110,224,110,45,111,226,110,165,110,167,110,189,110,187,110,183,110,215,110,180,110,207,110,143,110,194,110,159,110,98,111,70,111,71,111,36,111,21,111,249,110,47,111,54,111,75,111,116,111,42,111,9,111,41,111,137,111,141,111,140,111,120,111,114,111,124,111,122,111,209,111,10,147,11,147,12,147,13,147,14,147,15,147,16,147,17,147,18,147,19,147,20,147,21,147,22,147,23,147,24,147,25,147,26,147,27,147,28,147,29,147,30,147,31,147,32,147,33,147,34,147,35,147,36,147,37,147,38,147,39,147,40,147,41,147,42,147,43,147,44,147,45,147,46,147,47,147,48,147,49,147,50,147,51,147,52,147,53,147,54,147,55,147,56,147,57,147,58,147,59,147,60,147,61,147,63,147,64,147,65,147,66,147,67,147,68,147,69,147,70,147,71,147,72,147,73,147,74,147,75,147,76,147,77,147,78,147,79,147,80,147,81,147,82,147,83,147,84,147,85,147,86,147,87,147,88,147,89,147,90,147,91,147,92,147,93,147,94,147,95,147,96,147,97,147,98,147,99,147,100,147,101,147,102,147,103,147,104,147,105,147,107,147,201,111,167,111,185,111,182,111,194,111,225,111,238,111,222,111,224,111,239,111,26,112,35,112,27,112,57,112,53,112,79,112,94,112,128,91,132,91,149,91,147,91,165,91,184,91,47,117,158,154,52,100,228,91,238,91,48,137,240,91,71,142,7,139,182,143,211,143,213,143,229,143,238,143,228,143,233,143,230,143,243,143,232,143,5,144,4,144,11,144,38,144,17,144,13,144,22,144,33,144,53,144,54,144,45,144,47,144,68,144,81,144,82,144,80,144,104,144,88,144,98,144,91,144,185,102,116,144,125,144,130,144,136,144,131,144,139,144,80,95,87,95,86,95,88,95,59,92,171,84,80,92,89,92,113,91,99,92,102,92,188,127,42,95,41,95,45,95,116,130,60,95,59,155,110,92,129,89,131,89,141,89,169,89,170,89,163,89,108,147,109,147,110,147,111,147,112,147,113,147,114,147,115,147,116,147,117,147,118,147,119,147,120,147,121,147,122,147,123,147,124,147,125,147,126,147,127,147,128,147,129,147,130,147,131,147,132,147,133,147,134,147,135,147,136,147,137,147,138,147,139,147,140,147,141,147,142,147,144,147,145,147,146,147,147,147,148,147,149,147,150,147,151,147,152,147,153,147,154,147,155,147,156,147,157,147,158,147,159,147,160,147,161,147,162,147,163,147,164,147,165,147,166,147,167,147,168,147,169,147,170,147,171,147,172,147,173,147,174,147,175,147,176,147,177,147,178,147,179,147,180,147,181,147,182,147,183,147,184,147,185,147,186,147,187,147,188,147,189,147,190,147,191,147,192,147,193,147,194,147,195,147,196,147,197,147,198,147,199,147,200,147,201,147,203,147,204,147,205,147,151,89,202,89,171,89,158,89,164,89,210,89,178,89,175,89,215,89,190,89,5,90,6,90,221,89,8,90,227,89,216,89,249,89,12,90,9,90,50,90,52,90,17,90,35,90,19,90,64,90,103,90,74,90,85,90,60,90,98,90,117,90,236,128,170,90,155,90,119,90,122,90,190,90,235,90,178,90,210,90,212,90,184,90,224,90,227,90,241,90,214,90,230,90,216,90,220,90,9,91,23,91,22,91,50,91,55,91,64,91,21,92,28,92,90,91,101,91,115,91,81,91,83,91,98,91,117,154,119,154,120,154,122,154,127,154,125,154,128,154,129,154,133,154,136,154,138,154,144,154,146,154,147,154,150,154,152,154,155,154,156,154,157,154,159,154,160,154,162,154,163,154,165,154,167,154,159,126,161,126,163,126,165,126,168,126,169,126,206,147,207,147,208,147,209,147,210,147,211,147,212,147,213,147,215,147,216,147,217,147,218,147,219,147,220,147,221,147,222,147,223,147,224,147,225,147,226,147,227,147,228,147,229,147,230,147,231,147,232,147,233,147,234,147,235,147,236,147,237,147,238,147,239,147,240,147,241,147,242,147,243,147,244,147,245,147,246,147,247,147,248,147,249,147,250,147,251,147,252,147,253,147,254,147,255,147,0,148,1,148,2,148,3,148,4,148,5,148,6,148,7,148,8,148,9,148,10,148,11,148,12,148,13,148,14,148,15,148,16,148,17,148,18,148,19,148,20,148,21,148,22,148,23,148,24,148,25,148,26,148,27,148,28,148,29,148,30,148,31,148,32,148,33,148,34,148,35,148,36,148,37,148,38,148,39,148,40,148,41,148,42,148,43,148,44,148,45,148,46,148,173,126,176,126,190,126,192,126,193,126,194,126,201,126,203,126,204,126,208,126,212,126,215,126,219,126,224,126,225,126,232,126,235,126,238,126,239,126,241,126,242,126,13,127,246,126,250,126,251,126,254,126,1,127,2,127,3,127,7,127,8,127,11,127,12,127,15,127,17,127,18,127,23,127,25,127,28,127,27,127,31,127,33,127,34,127,35,127,36,127,37,127,38,127,39,127,42,127,43,127,44,127,45,127,47,127,48,127,49,127,50,127,51,127,53,127,122,94,127,117,219,93,62,117,149,144,142,115,145,115,174,115,162,115,159,115,207,115,194,115,209,115,183,115,179,115,192,115,201,115,200,115,229,115,217,115,124,152,10,116,233,115,231,115,222,115,186,115,242,115,15,116,42,116,91,116,38,116,37,116,40,116,48,116,46,116,44,116,47,148,48,148,49,148,50,148,51,148,52,148,53,148,54,148,55,148,56,148,57,148,58,148,59,148,60,148,61,148,63,148,64,148,65,148,66,148,67,148,68,148,69,148,70,148,71,148,72,148,73,148,74,148,75,148,76,148,77,148,78,148,79,148,80,148,81,148,82,148,83,148,84,148,85,148,86,148,87,148,88,148,89,148,90,148,91,148,92,148,93,148,94,148,95,148,96,148,97,148,98,148,99,148,100,148,101,148,102,148,103,148,104,148,105,148,106,148,108,148,109,148,110,148,111,148,112,148,113,148,114,148,115,148,116,148,117,148,118,148,119,148,120,148,121,148,122,148,123,148,124,148,125,148,126,148,127,148,128,148,129,148,130,148,131,148,132,148,145,148,150,148,152,148,199,148,207,148,211,148,212,148,218,148,230,148,251,148,28,149,32,149,27,116,26,116,65,116,92,116,87,116,85,116,89,116,119,116,109,116,126,116,156,116,142,116,128,116,129,116,135,116,139,116,158,116,168,116,169,116,144,116,167,116,210,116,186,116,234,151,235,151,236,151,76,103,83,103,94,103,72,103,105,103,165,103,135,103,106,103,115,103,152,103,167,103,117,103,168,103,158,103,173,103,139,103,119,103,124,103,240,103,9,104,216,103,10,104,233,103,176,103,12,104,217,103,181,103,218,103,179,103,221,103,0,104,195,103,184,103,226,103,14,104,193,103,253,103,50,104,51,104,96,104,97,104,78,104,98,104,68,104,100,104,131,104,29,104,85,104,102,104,65,104,103,104,64,104,62,104,74,104,73,104,41,104,181,104,143,104,116,104,119,104,147,104,107,104,194,104,110,105,252,104,31,105,32,105,249,104,39,149,51,149,61,149,67,149,72,149,75,149,85,149,90,149,96,149,110,149,116,149,117,149,119,149,120,149,121,149,122,149,123,149,124,149,125,149,126,149,128,149,129,149,130,149,131,149,132,149,133,149,134,149,135,149,136,149,137,149,138,149,139,149,140,149,141,149,142,149,143,149,144,149,145,149,146,149,147,149,148,149,149,149,150,149,151,149,152,149,153,149,154,149,155,149,156,149,157,149,158,149,159,149,160,149,161,149,162,149,163,149,164,149,165,149,166,149,167,149,168,149,169,149,170,149,171,149,172,149,173,149,174,149,175,149,176,149,177,149,178,149,179,149,180,149,181,149,182,149,183,149,184,149,185,149,186,149,187,149,188,149,189,149,190,149,191,149,192,149,193,149,194,149,195,149,196,149,197,149,198,149,199,149,200,149,201,149,202,149,203,149,36,105,240,104,11,105,1,105,87,105,227,104,16,105,113,105,57,105,96,105,66,105,93,105,132,105,107,105,128,105,152,105,120,105,52,105,204,105,135,105,136,105,206,105,137,105,102,105,99,105,121,105,155,105,167,105,187,105,171,105,173,105,212,105,177,105,193,105,202,105,223,105,149,105,224,105,141,105,255,105,47,106,237,105,23,106,24,106,101,106,242,105,68,106,62,106,160,106,80,106,91,106,53,106,142,106,121,106,61,106,40,106,88,106,124,106,145,106,144,106,169,106,151,106,171,106,55,115,82,115,129,107,130,107,135,107,132,107,146,107,147,107,141,107,154,107,155,107,161,107,170,107,107,143,109,143,113,143,114,143,115,143,117,143,118,143,120,143,119,143,121,143,122,143,124,143,126,143,129,143,130,143,132,143,135,143,139,143,204,149,205,149,206,149,207,149,208,149,209,149,210,149,211,149,212,149,213,149,214,149,215,149,216,149,217,149,218,149,219,149,220,149,221,149,222,149,223,149,224,149,225,149,226,149,227,149,228,149,229,149,230,149,231,149,236,149,255,149,7,150,19,150,24,150,27,150,30,150,32,150,35,150,36,150,37,150,38,150,39,150,40,150,41,150,43,150,44,150,45,150,47,150,48,150,55,150,56,150,57,150,58,150,62,150,65,150,67,150,74,150,78,150,79,150,81,150,82,150,83,150,86,150,87,150,88,150,89,150,90,150,92,150,93,150,94,150,96,150,99,150,101,150,102,150,107,150,109,150,110,150,111,150,112,150,113,150,115,150,120,150,121,150,122,150,123,150,124,150,125,150,126,150,127,150,128,150,129,150,130,150,131,150,132,150,135,150,137,150,138,150,141,143,142,143,143,143,152,143,154,143,206,142,11,98,23,98,27,98,31,98,34,98,33,98,37,98,36,98,44,98,231,129,239,116,244,116,255,116,15,117,17,117,19,117,52,101,238,101,239,101,240,101,10,102,25,102,114,103,3,102,21,102,0,102,133,112,247,102,29,102,52,102,49,102,54,102,53,102,6,128,95,102,84,102,65,102,79,102,86,102,97,102,87,102,119,102,132,102,140,102,167,102,157,102,190,102,219,102,220,102,230,102,233,102,50,141,51,141,54,141,59,141,61,141,64,141,69,141,70,141,72,141,73,141,71,141,77,141,85,141,89,141,199,137,202,137,203,137,204,137,206,137,207,137,208,137,209,137,110,114,159,114,93,114,102,114,111,114,126,114,127,114,132,114,139,114,141,114,143,114,146,114,8,99,50,99,176,99,140,150,142,150,145,150,146,150,147,150,149,150,150,150,154,150,155,150,157,150,158,150,159,150,160,150,161,150,162,150,163,150,164,150,165,150,166,150,168,150,169,150,170,150,171,150,172,150,173,150,174,150,175,150,177,150,178,150,180,150,181,150,183,150,184,150,186,150,187,150,191,150,194,150,195,150,200,150,202,150,203,150,208,150,209,150,211,150,212,150,214,150,215,150,216,150,217,150,218,150,219,150,220,150,221,150,222,150,223,150,225,150,226,150,227,150,228,150,229,150,230,150,231,150,235,150,236,150,237,150,238,150,240,150,241,150,242,150,244,150,245,150,248,150,250,150,251,150,252,150,253,150,255,150,2,151,3,151,5,151,10,151,11,151,12,151,16,151,17,151,18,151,20,151,21,151,23,151,24,151,25,151,26,151,27,151,29,151,31,151,32,151,63,100,216,100,4,128,234,107,243,107,253,107,245,107,249,107,5,108,7,108,6,108,13,108,21,108,24,108,25,108,26,108,33,108,41,108,36,108,42,108,50,108,53,101,85,101,107,101,77,114,82,114,86,114,48,114,98,134,22,82,159,128,156,128,147,128,188,128,10,103,189,128,177,128,171,128,173,128,180,128,183,128,231,128,232,128,233,128,234,128,219,128,194,128,196,128,217,128,205,128,215,128,16,103,221,128,235,128,241,128,244,128,237,128,13,129,14,129,242,128,252,128,21,103,18,129,90,140,54,129,30,129,44,129,24,129,50,129,72,129,76,129,83,129,116,129,89,129,90,129,113,129,96,129,105,129,124,129,125,129,109,129,103,129,77,88,181,90,136,129,130,129,145,129,213,110,163,129,170,129,204,129,38,103,202,129,187,129,33,151,34,151,35,151,36,151,37,151,38,151,39,151,40,151,41,151,43,151,44,151,46,151,47,151,49,151,51,151,52,151,53,151,54,151,55,151,58,151,59,151,60,151,61,151,63,151,64,151,65,151,66,151,67,151,68,151,69,151,70,151,71,151,72,151,73,151,74,151,75,151,76,151,77,151,78,151,79,151,80,151,81,151,84,151,85,151,87,151,88,151,90,151,92,151,93,151,95,151,99,151,100,151,102,151,103,151,104,151,106,151,107,151,108,151,109,151,110,151,111,151,112,151,113,151,114,151,117,151,119,151,120,151,121,151,122,151,123,151,125,151,126,151,127,151,128,151,129,151,130,151,131,151,132,151,134,151,135,151,136,151,137,151,138,151,140,151,142,151,143,151,144,151,147,151,149,151,150,151,151,151,153,151,154,151,155,151,156,151,157,151,193,129,166,129,36,107,55,107,57,107,67,107,70,107,89,107,209,152,210,152,211,152,213,152,217,152,218,152,179,107,64,95,194,107,243,137,144,101,81,159,147,101,188,101,198,101,196,101,195,101,204,101,206,101,210,101,214,101,128,112,156,112,150,112,157,112,187,112,192,112,183,112,171,112,177,112,232,112,202,112,16,113,19,113,22,113,47,113,49,113,115,113,92,113,104,113,69,113,114,113,74,113,120,113,122,113,152,113,179,113,181,113,168,113,160,113,224,113,212,113,231,113,249,113,29,114,40,114,108,112,24,113,102,113,185,113,62,98,61,98,67,98,72,98,73,98,59,121,64,121,70,121,73,121,91,121,92,121,83,121,90,121,98,121,87,121,96,121,111,121,103,121,122,121,133,121,138,121,154,121,167,121,179,121,209,95,208,95,158,151,159,151,161,151,162,151,164,151,165,151,166,151,167,151,168,151,169,151,170,151,172,151,174,151,176,151,177,151,179,151,181,151,182,151,183,151,184,151,185,151,186,151,187,151,188,151,189,151,190,151,191,151,192,151,193,151,194,151,195,151,196,151,197,151,198,151,199,151,200,151,201,151,202,151,203,151,204,151,205,151,206,151,207,151,208,151,209,151,210,151,211,151,212,151,213,151,214,151,215,151,216,151,217,151,218,151,219,151,220,151,221,151,222,151,223,151,224,151,225,151,226,151,227,151,228,151,229,151,232,151,238,151,239,151,240,151,241,151,242,151,244,151,247,151,248,151,249,151,250,151,251,151,252,151,253,151,254,151,255,151,0,152,1,152,2,152,3,152,4,152,5,152,6,152,7,152,8,152,9,152,10,152,11,152,12,152,13,152,14,152,60,96,93,96,90,96,103,96,65,96,89,96,99,96,171,96,6,97,13,97,93,97,169,97,157,97,203,97,209,97,6,98,128,128,127,128,147,108,246,108,252,109,246,119,248,119,0,120,9,120,23,120,24,120,17,120,171,101,45,120,28,120,29,120,57,120,58,120,59,120,31,120,60,120,37,120,44,120,35,120,41,120,78,120,109,120,86,120,87,120,38,120,80,120,71,120,76,120,106,120,155,120,147,120,154,120,135,120,156,120,161,120,163,120,178,120,185,120,165,120,212,120,217,120,201,120,236,120,242,120,5,121,244,120,19,121,36,121,30,121,52,121,155,159,249,158,251,158,252,158,241,118,4,119,13,119,249,118,7,119,8,119,26,119,34,119,25,119,45,119,38,119,53,119,56,119,80,119,81,119,71,119,67,119,90,119,104,119,15,152,16,152,17,152,18,152,19,152,20,152,21,152,22,152,23,152,24,152,25,152,26,152,27,152,28,152,29,152,30,152,31,152,32,152,33,152,34,152,35,152,36,152,37,152,38,152,39,152,40,152,41,152,42,152,43,152,44,152,45,152,46,152,47,152,48,152,49,152,50,152,51,152,52,152,53,152,54,152,55,152,56,152,57,152,58,152,59,152,60,152,61,152,62,152,63,152,64,152,65,152,66,152,67,152,68,152,69,152,70,152,71,152,72,152,73,152,74,152,75,152,76,152,77,152,78,152,79,152,80,152,81,152,82,152,83,152,84,152,85,152,86,152,87,152,88,152,89,152,90,152,91,152,92,152,93,152,94,152,95,152,96,152,97,152,98,152,99,152,100,152,101,152,102,152,103,152,104,152,105,152,106,152,107,152,108,152,109,152,110,152,98,119,101,119,127,119,141,119,125,119,128,119,140,119,145,119,159,119,160,119,176,119,181,119,189,119,58,117,64,117,78,117,75,117,72,117,91,117,114,117,121,117,131,117,88,127,97,127,95,127,72,138,104,127,116,127,113,127,121,127,129,127,126,127,205,118,229,118,50,136,133,148,134,148,135,148,139,148,138,148,140,148,141,148,143,148,144,148,148,148,151,148,149,148,154,148,155,148,156,148,163,148,164,148,171,148,170,148,173,148,172,148,175,148,176,148,178,148,180,148,182,148,183,148,184,148,185,148,186,148,188,148,189,148,191,148,196,148,200,148,201,148,202,148,203,148,204,148,205,148,206,148,208,148,209,148,210,148,213,148,214,148,215,148,217,148,216,148,219,148,222,148,223,148,224,148,226,148,228,148,229,148,231,148,232,148,234,148,111,152,112,152,113,152,114,152,115,152,116,152,139,152,142,152,146,152,149,152,153,152,163,152,168,152,169,152,170,152,171,152,172,152,173,152,174,152,175,152,176,152,177,152,178,152,179,152,180,152,181,152,182,152,183,152,184,152,185,152,186,152,187,152,188,152,189,152,190,152,191,152,192,152,193,152,194,152,195,152,196,152,197,152,198,152,199,152,200,152,201,152,202,152,203,152,204,152,205,152,207,152,208,152,212,152,214,152,215,152,219,152,220,152,221,152,224,152,225,152,226,152,227,152,228,152,229,152,230,152,233,152,234,152,235,152,236,152,237,152,238,152,239,152,240,152,241,152,242,152,243,152,244,152,245,152,246,152,247,152,248,152,249,152,250,152,251,152,252,152,253,152,254,152,255,152,0,153,1,153,2,153,3,153,4,153,5,153,6,153,7,153,233,148,235,148,238,148,239,148,243,148,244,148,245,148,247,148,249,148,252,148,253,148,255,148,3,149,2,149,6,149,7,149,9,149,10,149,13,149,14,149,15,149,18,149,19,149,20,149,21,149,22,149,24,149,27,149,29,149,30,149,31,149,34,149,42,149,43,149,41,149,44,149,49,149,50,149,52,149,54,149,55,149,56,149,60,149,62,149,63,149,66,149,53,149,68,149,69,149,70,149,73,149,76,149,78,149,79,149,82,149,83,149,84,149,86,149,87,149,88,149,89,149,91,149,94,149,95,149,93,149,97,149,98,149,100,149,101,149,102,149,103,149,104,149,105,149,106,149,107,149,108,149,111,149,113,149,114,149,115,149,58,149,231,119,236,119,201,150,213,121,237,121,227,121,235,121,6,122,71,93,3,122,2,122,30,122,20,122,8,153,9,153,10,153,11,153,12,153,14,153,15,153,17,153,18,153,19,153,20,153,21,153,22,153,23,153,24,153,25,153,26,153,27,153,28,153,29,153,30,153,31,153,32,153,33,153,34,153,35,153,36,153,37,153,38,153,39,153,40,153,41,153,42,153,43,153,44,153,45,153,47,153,48,153,49,153,50,153,51,153,52,153,53,153,54,153,55,153,56,153,57,153,58,153,59,153,60,153,61,153,62,153,63,153,64,153,65,153,66,153,67,153,68,153,69,153,70,153,71,153,72,153,73,153,74,153,75,153,76,153,77,153,78,153,79,153,80,153,81,153,82,153,83,153,86,153,87,153,88,153,89,153,90,153,91,153,92,153,93,153,94,153,95,153,96,153,97,153,98,153,100,153,102,153,115,153,120,153,121,153,123,153,126,153,130,153,131,153,137,153,57,122,55,122,81,122,207,158,165,153,112,122,136,118,142,118,147,118,153,118,164,118,222,116,224,116,44,117,32,158,34,158,40,158,41,158,42,158,43,158,44,158,50,158,49,158,54,158,56,158,55,158,57,158,58,158,62,158,65,158,66,158,68,158,70,158,71,158,72,158,73,158,75,158,76,158,78,158,81,158,85,158,87,158,90,158,91,158,92,158,94,158,99,158,102,158,103,158,104,158,105,158,106,158,107,158,108,158,113,158,109,158,115,158,146,117,148,117,150,117,160,117,157,117,172,117,163,117,179,117,180,117,184,117,196,117,177,117,176,117,195,117,194,117,214,117,205,117,227,117,232,117,230,117,228,117,235,117,231,117,3,118,241,117,252,117,255,117,16,118,0,118,5,118,12,118,23,118,10,118,37,118,24,118,21,118,25,118,140,153,142,153,154,153,155,153,156,153,157,153,158,153,159,153,160,153,161,153,162,153,163,153,164,153,166,153,167,153,169,153,170,153,171,153,172,153,173,153,174,153,175,153,176,153,177,153,178,153,179,153,180,153,181,153,182,153,183,153,184,153,185,153,186,153,187,153,188,153,189,153,190,153,191,153,192,153,193,153,194,153,195,153,196,153,197,153,198,153,199,153,200,153,201,153,202,153,203,153,204,153,205,153,206,153,207,153,208,153,209,153,210,153,211,153,212,153,213,153,214,153,215,153,216,153,217,153,218,153,219,153,220,153,221,153,222,153,223,153,224,153,225,153,226,153,227,153,228,153,229,153,230,153,231,153,232,153,233,153,234,153,235,153,236,153,237,153,238,153,239,153,240,153,241,153,242,153,243,153,244,153,245,153,246,153,247,153,248,153,249,153,27,118,60,118,34,118,32,118,64,118,45,118,48,118,63,118,53,118,67,118,62,118,51,118,77,118,94,118,84,118,92,118,86,118,107,118,111,118,202,127,230,122,120,122,121,122,128,122,134,122,136,122,149,122,166,122,160,122,172,122,168,122,173,122,179,122,100,136,105,136,114,136,125,136,127,136,130,136,162,136,198,136,183,136,188,136,201,136,226,136,206,136,227,136,229,136,241,136,26,137,252,136,232,136,254,136,240,136,33,137,25,137,19,137,27,137,10,137,52,137,43,137,54,137,65,137,102,137,123,137,139,117,229,128,178,118,180,118,220,119,18,128,20,128,22,128,28,128,32,128,34,128,37,128,38,128,39,128,41,128,40,128,49,128,11,128,53,128,67,128,70,128,77,128,82,128,105,128,113,128,131,137,120,152,128,152,131,152,250,153,251,153,252,153,253,153,254,153,255,153,0,154,1,154,2,154,3,154,4,154,5,154,6,154,7,154,8,154,9,154,10,154,11,154,12,154,13,154,14,154,15,154,16,154,17,154,18,154,19,154,20,154,21,154,22,154,23,154,24,154,25,154,26,154,27,154,28,154,29,154,30,154,31,154,32,154,33,154,34,154,35,154,36,154,37,154,38,154,39,154,40,154,41,154,42,154,43,154,44,154,45,154,46,154,47,154,48,154,49,154,50,154,51,154,52,154,53,154,54,154,55,154,56,154,57,154,58,154,59,154,60,154,61,154,62,154,63,154,64,154,65,154,66,154,67,154,68,154,69,154,70,154,71,154,72,154,73,154,74,154,75,154,76,154,77,154,78,154,79,154,80,154,81,154,82,154,83,154,84,154,85,154,86,154,87,154,88,154,89,154,137,152,140,152,141,152,143,152,148,152,154,152,155,152,158,152,159,152,161,152,162,152,165,152,166,152,77,134,84,134,108,134,110,134,127,134,122,134,124,134,123,134,168,134,141,134,139,134,172,134,157,134,167,134,163,134,170,134,147,134,169,134,182,134,196,134,181,134,206,134,176,134,186,134,177,134,175,134,201,134,207,134,180,134,233,134,241,134,242,134,237,134,243,134,208,134,19,135,222,134,244,134,223,134,216,134,209,134,3,135,7,135,248,134,8,135,10,135,13,135,9,135,35,135,59,135,30,135,37,135,46,135,26,135,62,135,72,135,52,135,49,135,41,135,55,135,63,135,130,135,34,135,125,135,126,135,123,135,96,135,112,135,76,135,110,135,139,135,83,135,99,135,124,135,100,135,89,135,101,135,147,135,175,135,168,135,210,135,90,154,91,154,92,154,93,154,94,154,95,154,96,154,97,154,98,154,99,154,100,154,101,154,102,154,103,154,104,154,105,154,106,154,107,154,114,154,131,154,137,154,141,154,142,154,148,154,149,154,153,154,166,154,169,154,170,154,171,154,172,154,173,154,174,154,175,154,178,154,179,154], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1183456);
/* memory initializer */ allocate([180,154,181,154,185,154,187,154,189,154,190,154,191,154,195,154,196,154,198,154,199,154,200,154,201,154,202,154,205,154,206,154,207,154,208,154,210,154,212,154,213,154,214,154,215,154,217,154,218,154,219,154,220,154,221,154,222,154,224,154,226,154,227,154,228,154,229,154,231,154,232,154,233,154,234,154,236,154,238,154,240,154,241,154,242,154,243,154,244,154,245,154,246,154,247,154,248,154,250,154,252,154,253,154,254,154,255,154,0,155,1,155,2,155,4,155,5,155,6,155,198,135,136,135,133,135,173,135,151,135,131,135,171,135,229,135,172,135,181,135,179,135,203,135,211,135,189,135,209,135,192,135,202,135,219,135,234,135,224,135,238,135,22,136,19,136,254,135,10,136,27,136,33,136,57,136,60,136,54,127,66,127,68,127,69,127,16,130,250,122,253,122,8,123,3,123,4,123,21,123,10,123,43,123,15,123,71,123,56,123,42,123,25,123,46,123,49,123,32,123,37,123,36,123,51,123,62,123,30,123,88,123,90,123,69,123,117,123,76,123,93,123,96,123,110,123,123,123,98,123,114,123,113,123,144,123,166,123,167,123,184,123,172,123,157,123,168,123,133,123,170,123,156,123,162,123,171,123,180,123,209,123,193,123,204,123,221,123,218,123,229,123,230,123,234,123,12,124,254,123,252,123,15,124,22,124,11,124,7,155,9,155,10,155,11,155,12,155,13,155,14,155,16,155,17,155,18,155,20,155,21,155,22,155,23,155,24,155,25,155,26,155,27,155,28,155,29,155,30,155,32,155,33,155,34,155,36,155,37,155,38,155,39,155,40,155,41,155,42,155,43,155,44,155,45,155,46,155,48,155,49,155,51,155,52,155,53,155,54,155,55,155,56,155,57,155,58,155,61,155,62,155,63,155,64,155,70,155,74,155,75,155,76,155,78,155,80,155,82,155,83,155,85,155,86,155,87,155,88,155,89,155,90,155,91,155,92,155,93,155,94,155,95,155,96,155,97,155,98,155,99,155,100,155,101,155,102,155,103,155,104,155,105,155,106,155,107,155,108,155,109,155,110,155,111,155,112,155,113,155,114,155,115,155,116,155,117,155,118,155,119,155,120,155,121,155,122,155,123,155,31,124,42,124,38,124,56,124,65,124,64,124,254,129,1,130,2,130,4,130,236,129,68,136,33,130,34,130,35,130,45,130,47,130,40,130,43,130,56,130,59,130,51,130,52,130,62,130,68,130,73,130,75,130,79,130,90,130,95,130,104,130,126,136,133,136,136,136,216,136,223,136,94,137,157,127,159,127,167,127,175,127,176,127,178,127,124,124,73,101,145,124,157,124,156,124,158,124,162,124,178,124,188,124,189,124,193,124,199,124,204,124,205,124,200,124,197,124,215,124,232,124,110,130,168,102,191,127,206,127,213,127,229,127,225,127,230,127,233,127,238,127,243,127,248,124,119,125,166,125,174,125,71,126,155,126,184,158,180,158,115,141,132,141,148,141,145,141,177,141,103,141,109,141,71,140,73,140,74,145,80,145,78,145,79,145,100,145,124,155,125,155,126,155,127,155,128,155,129,155,130,155,131,155,132,155,133,155,134,155,135,155,136,155,137,155,138,155,139,155,140,155,141,155,142,155,143,155,144,155,145,155,146,155,147,155,148,155,149,155,150,155,151,155,152,155,153,155,154,155,155,155,156,155,157,155,158,155,159,155,160,155,161,155,162,155,163,155,164,155,165,155,166,155,167,155,168,155,169,155,170,155,171,155,172,155,173,155,174,155,175,155,176,155,177,155,178,155,179,155,180,155,181,155,182,155,183,155,184,155,185,155,186,155,187,155,188,155,189,155,190,155,191,155,192,155,193,155,194,155,195,155,196,155,197,155,198,155,199,155,200,155,201,155,202,155,203,155,204,155,205,155,206,155,207,155,208,155,209,155,210,155,211,155,212,155,213,155,214,155,215,155,216,155,217,155,218,155,219,155,98,145,97,145,112,145,105,145,111,145,125,145,126,145,114,145,116,145,121,145,140,145,133,145,144,145,141,145,145,145,162,145,163,145,170,145,173,145,174,145,175,145,181,145,180,145,186,145,85,140,126,158,184,141,235,141,5,142,89,142,105,142,181,141,191,141,188,141,186,141,196,141,214,141,215,141,218,141,222,141,206,141,207,141,219,141,198,141,236,141,247,141,248,141,227,141,249,141,251,141,228,141,9,142,253,141,20,142,29,142,31,142,44,142,46,142,35,142,47,142,58,142,64,142,57,142,53,142,61,142,49,142,73,142,65,142,66,142,81,142,82,142,74,142,112,142,118,142,124,142,111,142,116,142,133,142,143,142,148,142,144,142,156,142,158,142,120,140,130,140,138,140,133,140,152,140,148,140,155,101,214,137,222,137,218,137,220,137,220,155,221,155,222,155,223,155,224,155,225,155,226,155,227,155,228,155,229,155,230,155,231,155,232,155,233,155,234,155,235,155,236,155,237,155,238,155,239,155,240,155,241,155,242,155,243,155,244,155,245,155,246,155,247,155,248,155,249,155,250,155,251,155,252,155,253,155,254,155,255,155,0,156,1,156,2,156,3,156,4,156,5,156,6,156,7,156,8,156,9,156,10,156,11,156,12,156,13,156,14,156,15,156,16,156,17,156,18,156,19,156,20,156,21,156,22,156,23,156,24,156,25,156,26,156,27,156,28,156,29,156,30,156,31,156,32,156,33,156,34,156,35,156,36,156,37,156,38,156,39,156,40,156,41,156,42,156,43,156,44,156,45,156,46,156,47,156,48,156,49,156,50,156,51,156,52,156,53,156,54,156,55,156,56,156,57,156,58,156,59,156,229,137,235,137,239,137,62,138,38,139,83,151,233,150,243,150,239,150,6,151,1,151,8,151,15,151,14,151,42,151,45,151,48,151,62,151,128,159,131,159,133,159,134,159,135,159,136,159,137,159,138,159,140,159,254,158,11,159,13,159,185,150,188,150,189,150,206,150,210,150,191,119,224,150,142,146,174,146,200,146,62,147,106,147,202,147,143,147,62,148,107,148,127,156,130,156,133,156,134,156,135,156,136,156,35,122,139,156,142,156,144,156,145,156,146,156,148,156,149,156,154,156,155,156,158,156,159,156,160,156,161,156,162,156,163,156,165,156,166,156,167,156,168,156,169,156,171,156,173,156,174,156,176,156,177,156,178,156,179,156,180,156,181,156,182,156,183,156,186,156,187,156,188,156,189,156,196,156,197,156,198,156,199,156,202,156,203,156,60,156,61,156,62,156,63,156,64,156,65,156,66,156,67,156,68,156,69,156,70,156,71,156,72,156,73,156,74,156,75,156,76,156,77,156,78,156,79,156,80,156,81,156,82,156,83,156,84,156,85,156,86,156,87,156,88,156,89,156,90,156,91,156,92,156,93,156,94,156,95,156,96,156,97,156,98,156,99,156,100,156,101,156,102,156,103,156,104,156,105,156,106,156,107,156,108,156,109,156,110,156,111,156,112,156,113,156,114,156,115,156,116,156,117,156,118,156,119,156,120,156,121,156,122,156,123,156,125,156,126,156,128,156,131,156,132,156,137,156,138,156,140,156,143,156,147,156,150,156,151,156,152,156,153,156,157,156,170,156,172,156,175,156,185,156,190,156,191,156,192,156,193,156,194,156,200,156,201,156,209,156,210,156,218,156,219,156,224,156,225,156,204,156,205,156,206,156,207,156,208,156,211,156,212,156,213,156,215,156,216,156,217,156,220,156,221,156,223,156,226,156,124,151,133,151,145,151,146,151,148,151,175,151,171,151,163,151,178,151,180,151,177,154,176,154,183,154,88,158,182,154,186,154,188,154,193,154,192,154,197,154,194,154,203,154,204,154,209,154,69,155,67,155,71,155,73,155,72,155,77,155,81,155,232,152,13,153,46,153,85,153,84,153,223,154,225,154,230,154,239,154,235,154,251,154,237,154,249,154,8,155,15,155,19,155,31,155,35,155,189,158,190,158,59,126,130,158,135,158,136,158,139,158,146,158,214,147,157,158,159,158,219,158,220,158,221,158,224,158,223,158,226,158,233,158,231,158,229,158,234,158,239,158,34,159,44,159,47,159,57,159,55,159,61,159,62,159,68,159,227,156,228,156,229,156,230,156,231,156,232,156,233,156,234,156,235,156,236,156,237,156,238,156,239,156,240,156,241,156,242,156,243,156,244,156,245,156,246,156,247,156,248,156,249,156,250,156,251,156,252,156,253,156,254,156,255,156,0,157,1,157,2,157,3,157,4,157,5,157,6,157,7,157,8,157,9,157,10,157,11,157,12,157,13,157,14,157,15,157,16,157,17,157,18,157,19,157,20,157,21,157,22,157,23,157,24,157,25,157,26,157,27,157,28,157,29,157,30,157,31,157,32,157,33,157,34,157,35,157,36,157,37,157,38,157,39,157,40,157,41,157,42,157,43,157,44,157,45,157,46,157,47,157,48,157,49,157,50,157,51,157,52,157,53,157,54,157,55,157,56,157,57,157,58,157,59,157,60,157,61,157,62,157,63,157,64,157,65,157,66,157,52,226,53,226,54,226,55,226,56,226,57,226,58,226,59,226,60,226,61,226,62,226,63,226,64,226,65,226,66,226,67,226,68,226,69,226,70,226,71,226,72,226,73,226,74,226,75,226,76,226,77,226,78,226,79,226,80,226,81,226,82,226,83,226,84,226,85,226,86,226,87,226,88,226,89,226,90,226,91,226,92,226,93,226,94,226,95,226,96,226,97,226,98,226,99,226,100,226,101,226,102,226,103,226,104,226,105,226,106,226,107,226,108,226,109,226,110,226,111,226,112,226,113,226,114,226,115,226,116,226,117,226,118,226,119,226,120,226,121,226,122,226,123,226,124,226,125,226,126,226,127,226,128,226,129,226,130,226,131,226,132,226,133,226,134,226,135,226,136,226,137,226,138,226,139,226,140,226,141,226,142,226,143,226,144,226,145,226,67,157,68,157,69,157,70,157,71,157,72,157,73,157,74,157,75,157,76,157,77,157,78,157,79,157,80,157,81,157,82,157,83,157,84,157,85,157,86,157,87,157,88,157,89,157,90,157,91,157,92,157,93,157,94,157,95,157,96,157,97,157,98,157,99,157,100,157,101,157,102,157,103,157,104,157,105,157,106,157,107,157,108,157,109,157,110,157,111,157,112,157,113,157,114,157,115,157,116,157,117,157,118,157,119,157,120,157,121,157,122,157,123,157,124,157,125,157,126,157,127,157,128,157,129,157,130,157,131,157,132,157,133,157,134,157,135,157,136,157,137,157,138,157,139,157,140,157,141,157,142,157,143,157,144,157,145,157,146,157,147,157,148,157,149,157,150,157,151,157,152,157,153,157,154,157,155,157,156,157,157,157,158,157,159,157,160,157,161,157,162,157,146,226,147,226,148,226,149,226,150,226,151,226,152,226,153,226,154,226,155,226,156,226,157,226,158,226,159,226,160,226,161,226,162,226,163,226,164,226,165,226,166,226,167,226,168,226,169,226,170,226,171,226,172,226,173,226,174,226,175,226,176,226,177,226,178,226,179,226,180,226,181,226,182,226,183,226,184,226,185,226,186,226,187,226,188,226,189,226,190,226,191,226,192,226,193,226,194,226,195,226,196,226,197,226,198,226,199,226,200,226,201,226,202,226,203,226,204,226,205,226,206,226,207,226,208,226,209,226,210,226,211,226,212,226,213,226,214,226,215,226,216,226,217,226,218,226,219,226,220,226,221,226,222,226,223,226,224,226,225,226,226,226,227,226,228,226,229,226,230,226,231,226,232,226,233,226,234,226,235,226,236,226,237,226,238,226,239,226,163,157,164,157,165,157,166,157,167,157,168,157,169,157,170,157,171,157,172,157,173,157,174,157,175,157,176,157,177,157,178,157,179,157,180,157,181,157,182,157,183,157,184,157,185,157,186,157,187,157,188,157,189,157,190,157,191,157,192,157,193,157,194,157,195,157,196,157,197,157,198,157,199,157,200,157,201,157,202,157,203,157,204,157,205,157,206,157,207,157,208,157,209,157,210,157,211,157,212,157,213,157,214,157,215,157,216,157,217,157,218,157,219,157,220,157,221,157,222,157,223,157,224,157,225,157,226,157,227,157,228,157,229,157,230,157,231,157,232,157,233,157,234,157,235,157,236,157,237,157,238,157,239,157,240,157,241,157,242,157,243,157,244,157,245,157,246,157,247,157,248,157,249,157,250,157,251,157,252,157,253,157,254,157,255,157,0,158,1,158,2,158,240,226,241,226,242,226,243,226,244,226,245,226,246,226,247,226,248,226,249,226,250,226,251,226,252,226,253,226,254,226,255,226,0,227,1,227,2,227,3,227,4,227,5,227,6,227,7,227,8,227,9,227,10,227,11,227,12,227,13,227,14,227,15,227,16,227,17,227,18,227,19,227,20,227,21,227,22,227,23,227,24,227,25,227,26,227,27,227,28,227,29,227,30,227,31,227,32,227,33,227,34,227,35,227,36,227,37,227,38,227,39,227,40,227,41,227,42,227,43,227,44,227,45,227,46,227,47,227,48,227,49,227,50,227,51,227,52,227,53,227,54,227,55,227,56,227,57,227,58,227,59,227,60,227,61,227,62,227,63,227,64,227,65,227,66,227,67,227,68,227,69,227,70,227,71,227,72,227,73,227,74,227,75,227,76,227,77,227,3,158,4,158,5,158,6,158,7,158,8,158,9,158,10,158,11,158,12,158,13,158,14,158,15,158,16,158,17,158,18,158,19,158,20,158,21,158,22,158,23,158,24,158,25,158,26,158,27,158,28,158,29,158,30,158,36,158,39,158,46,158,48,158,52,158,59,158,60,158,64,158,77,158,80,158,82,158,83,158,84,158,86,158,89,158,93,158,95,158,96,158,97,158,98,158,101,158,110,158,111,158,114,158,116,158,117,158,118,158,119,158,120,158,121,158,122,158,123,158,124,158,125,158,128,158,129,158,131,158,132,158,133,158,134,158,137,158,138,158,140,158,141,158,142,158,143,158,144,158,145,158,148,158,149,158,150,158,151,158,152,158,153,158,154,158,155,158,156,158,158,158,160,158,161,158,162,158,163,158,164,158,165,158,167,158,168,158,169,158,170,158,78,227,79,227,80,227,81,227,82,227,83,227,84,227,85,227,86,227,87,227,88,227,89,227,90,227,91,227,92,227,93,227,94,227,95,227,96,227,97,227,98,227,99,227,100,227,101,227,102,227,103,227,104,227,105,227,106,227,107,227,108,227,109,227,110,227,111,227,112,227,113,227,114,227,115,227,116,227,117,227,118,227,119,227,120,227,121,227,122,227,123,227,124,227,125,227,126,227,127,227,128,227,129,227,130,227,131,227,132,227,133,227,134,227,135,227,136,227,137,227,138,227,139,227,140,227,141,227,142,227,143,227,144,227,145,227,146,227,147,227,148,227,149,227,150,227,151,227,152,227,153,227,154,227,155,227,156,227,157,227,158,227,159,227,160,227,161,227,162,227,163,227,164,227,165,227,166,227,167,227,168,227,169,227,170,227,171,227,171,158,172,158,173,158,174,158,175,158,176,158,177,158,178,158,179,158,181,158,182,158,183,158,185,158,186,158,188,158,191,158,192,158,193,158,194,158,195,158,197,158,198,158,199,158,200,158,202,158,203,158,204,158,208,158,210,158,211,158,213,158,214,158,215,158,217,158,218,158,222,158,225,158,227,158,228,158,230,158,232,158,235,158,236,158,237,158,238,158,240,158,241,158,242,158,243,158,244,158,245,158,246,158,247,158,248,158,250,158,253,158,255,158,0,159,1,159,2,159,3,159,4,159,5,159,6,159,7,159,8,159,9,159,10,159,12,159,15,159,17,159,18,159,20,159,21,159,22,159,24,159,26,159,27,159,28,159,29,159,30,159,31,159,33,159,35,159,36,159,37,159,38,159,39,159,40,159,41,159,42,159,43,159,45,159,46,159,48,159,49,159,172,227,173,227,174,227,175,227,176,227,177,227,178,227,179,227,180,227,181,227,182,227,183,227,184,227,185,227,186,227,187,227,188,227,189,227,190,227,191,227,192,227,193,227,194,227,195,227,196,227,197,227,198,227,199,227,200,227,201,227,202,227,203,227,204,227,205,227,206,227,207,227,208,227,209,227,210,227,211,227,212,227,213,227,214,227,215,227,216,227,217,227,218,227,219,227,220,227,221,227,222,227,223,227,224,227,225,227,226,227,227,227,228,227,229,227,230,227,231,227,232,227,233,227,234,227,235,227,236,227,237,227,238,227,239,227,240,227,241,227,242,227,243,227,244,227,245,227,246,227,247,227,248,227,249,227,250,227,251,227,252,227,253,227,254,227,255,227,0,228,1,228,2,228,3,228,4,228,5,228,6,228,7,228,8,228,9,228,50,159,51,159,52,159,53,159,54,159,56,159,58,159,60,159,63,159,64,159,65,159,66,159,67,159,69,159,70,159,71,159,72,159,73,159,74,159,75,159,76,159,77,159,78,159,79,159,82,159,83,159,84,159,85,159,86,159,87,159,88,159,89,159,90,159,91,159,92,159,93,159,94,159,95,159,96,159,97,159,98,159,99,159,100,159,101,159,102,159,103,159,104,159,105,159,106,159,107,159,108,159,109,159,110,159,111,159,112,159,113,159,114,159,115,159,116,159,117,159,118,159,119,159,120,159,121,159,122,159,123,159,124,159,125,159,126,159,129,159,130,159,141,159,142,159,143,159,144,159,145,159,146,159,147,159,148,159,149,159,150,159,151,159,152,159,156,159,157,159,158,159,161,159,162,159,163,159,164,159,165,159,44,249,121,249,149,249,231,249,241,249,10,228,11,228,12,228,13,228,14,228,15,228,16,228,17,228,18,228,19,228,20,228,21,228,22,228,23,228,24,228,25,228,26,228,27,228,28,228,29,228,30,228,31,228,32,228,33,228,34,228,35,228,36,228,37,228,38,228,39,228,40,228,41,228,42,228,43,228,44,228,45,228,46,228,47,228,48,228,49,228,50,228,51,228,52,228,53,228,54,228,55,228,56,228,57,228,58,228,59,228,60,228,61,228,62,228,63,228,64,228,65,228,66,228,67,228,68,228,69,228,70,228,71,228,72,228,73,228,74,228,75,228,76,228,77,228,78,228,79,228,80,228,81,228,82,228,83,228,84,228,85,228,86,228,87,228,88,228,89,228,90,228,91,228,92,228,93,228,94,228,95,228,96,228,97,228,98,228,99,228,100,228,101,228,102,228,103,228,12,250,13,250,14,250,15,250,17,250,19,250,20,250,24,250,31,250,32,250,33,250,35,250,36,250,39,250,40,250,41,250,129,46,22,232,23,232,24,232,132,46,115,52,71,52,136,46,139,46,30,232,158,53,26,54,14,54,140,46,151,46,110,57,24,57,38,232,207,57,223,57,115,58,208,57,43,232,44,232,78,59,110,60,224,60,167,46,49,232,50,232,170,46,86,64,95,65,174,46,55,67,179,46,182,46,183,46,59,232,177,67,172,67,187,46,221,67,214,68,97,70,76,70,67,232,35,71,41,71,124,71,141,71,202,46,71,73,122,73,125,73,130,73,131,73,133,73,134,73,159,73,155,73,183,73,182,73,84,232,85,232,163,76,159,76,160,76,161,76,119,76,162,76,19,77,20,77,21,77,22,77,23,77,24,77,25,77,174,77,100,232,104,228,105,228,106,228,107,228,108,228,109,228,110,228,111,228,112,228,113,228,114,228,115,228,116,228,117,228,118,228,119,228,120,228,121,228,122,228,123,228,124,228,125,228,126,228,127,228,128,228,129,228,130,228,131,228,132,228,133,228,134,228,135,228,136,228,137,228,138,228,139,228,140,228,141,228,142,228,143,228,144,228,145,228,146,228,147,228,148,228,149,228,150,228,151,228,152,228,153,228,154,228,155,228,156,228,157,228,158,228,159,228,160,228,161,228,162,228,163,228,164,228,165,228,166,228,167,228,168,228,169,228,170,228,171,228,172,228,173,228,174,228,175,228,176,228,177,228,178,228,179,228,180,228,181,228,182,228,183,228,184,228,185,228,186,228,187,228,188,228,189,228,190,228,191,228,192,228,193,228,194,228,195,228,196,228,197,228,2,0,0,0,10,0,0,0,10,0,0,0,0,0,0,0,0,9,16,22,28,33,39,44,49,53,58,63,67,72,76,80,84,89,93,97,101,105,109,113,117,121,125,128,132,136,140,143,147,151,154,158,162,165,169,172,176,179,183,186,190,193,197,200,203,207,210,213,217,220,223,227,230,233,237,240,243,246,250,253,3,11,18,24,29,35,40,45,50,54,59,64,68,73,77,81,86,90,94,98,102,106,110,114,118,122,125,129,133,137,141,144,148,152,155,159,162,166,170,173,177,180,184,187,191,194,197,201,204,208,211,214,218,221,224,228,231,234,237,241,244,247,250,253,5,13,19,25,31,36,41,46,51,56,60,65,69,74,78,82,87,91,95,99,103,107,111,115,119,123,126,130,134,138,141,145,149,153,156,160,163,167,170,174,178,181,185,188,191,195,198,202,205,208,212,215,218,222,225,228,232,235,238,241,245,248,251,253,7,14,21,26,32,37,42,47,52,57,61,66,70,75,79,83,88,92,96,100,104,108,112,116,120,124,127,131,135,139,142,146,150,153,157,161,164,168,171,175,178,182,185,189,192,196,199,203,206,209,213,216,219,223,226,229,233,236,239,242,246,249,252,253,61,42,81,112,0,80,225,10,153,73,194,25,81,24,245,28,51,67,204,40,122,84,245,4,143,82,71,17,40,44,20,6,61,74,20,50,215,67,194,9,194,69,225,18,10,39,194,9,122,68,184,30,174,55,92,7,20,62,81,12,61,26,10,7,10,71,225,78,102,70,215,11,71,65,225,22,143,34,174,15,20,62,10,35,102,70,112,5,71,65,0,16,0,32,143,2,133,59,102,54,174,55,40,12,10,55,61,18,30,21,143,10,122,52,153,25,163,48,133,3,163,48,102,10,184,14,143,2,153,57,215,91,225,74,153,9,184,78,215,19,225,26,0,16,0,80,112,33,204,76,225,2,61,74,163,16,184,30,40,8,204,44,0,48,20,62,194,5,112,61,20,18,215,35,153,5,184,62,92,27,235,57,225,2,225,58,204,8,215,19,204,4,215,51,174,67,163,64,30,9,225,58,184,22,92,15,102,14,174,55,153,33,235,65,10,3,225,58,225,14,174,23,102,2,122,36,40,36,215,51,225,6,215,51,194,13,153,9,174,7,204,44,153,21,245,40,225,2,112,45,122,12,194,5,10,3,65,2,150,2,38,3,44,7,37,12,28,4,85,16,107,5,69,9,145,5,176,12,193,7,35,7,16,9,173,3,242,12,47,9,161,11,32,14,116,9,123,13,24,12,139,11,205,16,56,7,148,17,44,15,40,21,163,4,42,28,11,12,40,35,216,28,115,3,74,23,226,5,35,20,86,8,8,31,217,7,107,25,202,8,246,29,192,10,64,23,200,11,34,19,180,14,77,27,4,14,238,31,138,15,176,23,52,17,29,30,223,19,147,21,133,23,89,30,214,27,172,23,2,31,218,21,223,44,85,41,76,5,89,35,61,6,66,38,243,7,242,34,111,9,56,40,24,10,191,36,174,10,252,33,146,12,29,38,67,13,193,39,52,15,210,35,176,17,168,39,140,19,154,35,103,22,4,41,122,24,126,39,207,29,140,34,23,34,252,34,208,48,124,50,208,3,171,44,219,6,106,47,24,9,124,44,64,9,204,41,248,11,44,48,45,11,202,45,255,12,6,44,116,14,109,42,61,17,50,47,181,17,19,44,85,20,184,46,161,24,159,43,110,29,96,47,137,32,217,42,25,42,60,40,224,67,75,54,145,6,36,49,253,7,209,51,135,9,209,54,173,11,140,52,26,12,108,48,74,14,198,52,196,14,80,50,176,16,221,52,253,18,123,49,81,21,30,54,218,23,231,50,83,25,245,52,41,30,157,50,95,36,146,53,31,45,47,49,102,59,9,59,4,6,224,58,29,9,191,56,207,9,100,57,127,12,22,60,232,13,53,55,120,15,254,58,140,16,252,55,216,18,254,57,75,21,202,59,195,23,249,55,232,26,212,58,9,30,70,56,210,36,27,60,13,38,232,57,191,55,32,53,107,97,12,64,177,7,177,65,16,11,97,61,27,11,232,62,8,13,0,64,123,15,44,66,227,17,95,61,247,17,94,63,72,21,192,65,238,24,129,61,229,27,198,63,45,29,227,64,176,33,132,66,178,40,33,62,41,46,238,65,98,57,131,64,134,81,222,70,35,8,201,75,106,12,100,68,98,13,86,78,187,15,149,70,153,16,8,74,202,19,47,69,26,21,123,77,48,24,30,70,102,27,70,83,197,30,246,69,73,36,200,74,74,36,37,80,117,44,155,70,149,56,31,78,218,69,154,73,252,127,44,3,128,0,30,2,140,0,57,11,111,4,218,8,74,13,19,8,51,2,133,49,135,2,36,16,6,7,225,21,165,20,9,30,118,1,151,14,185,1,160,42,78,10,31,46,190,9,10,80,29,3,98,20,163,2,68,26,162,32,162,20,160,6,208,5,172,1,250,22,196,1,212,20,232,15,255,13,244,4,165,9,133,3,22,62,237,3,134,58,199,12,91,40,250,18,51,14,229,7,36,10,67,3,72,48,28,19,174,47,168,6,120,52,68,6,158,35,37,9,128,15,2,6,103,21,208,38,211,14,161,1,79,5,158,1,56,14,33,6,59,31,213,13,141,44,133,2,104,33,123,2,216,15,97,5,224,64,236,23,156,44,188,2,215,7,95,2,127,48,42,6,111,43,46,18,112,53,172,6,214,46,205,4,60,31,129,28,175,51,83,22,124,9,135,4,25,8,149,7,74,24,233,23,218,13,12,7,221,34,10,7,231,33,44,6,111,54,248,13,1,52,93,24,254,23,106,4,106,23,198,6,61,55,54,18,7,44,249,12,194,47,15,6,107,54,199,11,217,19,224,40,228,36,50,26,153,6,171,2,156,5,26,5,44,28,93,15,242,15,153,10,113,30,192,2,222,58,34,3,155,24,92,20,241,16,237,20,20,26,29,2,174,23,114,2,83,53,116,14,234,44,104,9,28,63,204,2,145,47,239,2,129,31,225,44,170,24,208,8,114,17,240,1,125,28,11,2,229,39,249,14,202,32,221,11,211,32,198,3,148,55,88,7,255,33,33,21,11,64,255,18,252,28,187,7,201,23,206,4,155,36,46,17,222,56,35,13,247,52,57,11,107,51,185,5,158,21,142,6,82,51,179,57,170,28,88,2,38,5,36,2,156,16,211,13,60,39,60,9,91,41,110,2,32,51,157,2,46,55,198,13,175,19,56,38,234,59,107,2,43,12,78,2,58,64,197,11,182,60,72,16,177,60,75,6,45,60,204,4,151,62,83,36,110,29,112,19,198,7,189,4,183,44,133,4,224,48,143,21,3,37,84,10,36,30,242,7,224,51,191,8,139,62,229,19,130,31,105,26,99,39,133,5,138,19,43,9,235,48,87,23,22,59,83,11,88,71,241,8,211,61,223,9,137,63,14,40,59,57,55,44,5,7,81,1,43,12,141,1,182,13,112,11,240,17,110,10,95,29,116,2,151,44,144,2,58,23,131,9,144,25,199,28,46,32,61,3,160,15,95,3,48,39,188,9,185,62,223,13,28,71,30,4,215,23,174,5,252,22,220,30,64,73,140,13,72,7,32,2,238,35,171,2,103,45,64,16,242,17,108,6,86,12,133,4,81,62,0,10,61,48,149,14,12,68,140,20,218,23,212,7,101,11,206,6,83,64,137,20,147,65,144,6,53,67,223,6,165,18,159,12,218,28,147,23,6,56,28,39,195,15,186,1,98,16,202,1,254,35,194,8,3,29,121,16,60,50,33,3,178,43,57,3,104,49,36,8,156,50,154,25,33,37,228,3,229,25,217,3,41,41,198,9,185,59,142,19,58,49,7,8,124,60,117,6,66,63,9,27,151,55,158,22,66,10,60,3,239,21,150,6,95,53,146,22,84,14,18,6,49,44,73,10,42,38,179,5,179,54,125,18,25,62,147,24,134,24,78,7,230,30,237,8,82,66,219,17,192,64,9,15,144,59,7,9,151,62,172,12,123,56,144,69,71,46,203,10,189,7,127,5,120,5,108,3,239,16,219,13,39,17,114,16,29,21,168,2,53,68,13,3,101,25,254,19,155,31,253,29,187,28,26,3,141,32,158,4,193,58,88,12,80,58,223,11,197,79,112,3,209,56,84,3,49,48,116,57,248,26,128,7,129,16,165,3,26,32,63,4,163,41,244,15,98,39,181,17,175,10,72,3,177,80,57,4,71,65,78,23,1,62,226,17,119,42,14,10,189,14,142,4,183,56,204,15,219,80,67,10,115,59,174,10,170,59,138,8,113,24,154,12,69,51,24,76,28,28,162,3,158,9,82,6,163,17,20,12,28,54,181,16,220,40,65,3,187,67,42,3,251,65,241,8,186,60,25,32,35,53,148,6,125,12,42,7,76,62,4,11,196,61,207,20,110,66,134,9,148,65,46,5,55,61,220,31,206,45,108,33,178,14,5,8,91,37,37,5,249,52,134,26,195,47,144,7,244,31,222,13,231,51,242,6,171,63,199,25,163,63,78,30,73,33,247,9,57,28,85,10,93,71,65,29,245,65,200,8,218,69,68,11,113,67,0,13,201,36,194,78,34,43,128,32,6,5,108,2,151,5,71,2,105,23,241,8,138,15,42,14,24,20,240,2,97,52,62,3,177,21,44,11,244,45,20,23,241,41,48,2,70,21,52,2,9,52,192,11,170,46,99,14,175,77,30,3,97,38,216,2,95,53,44,34,223,28,237,11,211,9,10,3,162,23,65,3,69,25,210,19,113,32,159,9,253,23,73,7,204,59,238,4,72,56,195,17,95,53,163,17,65,12,167,11,175,9,235,4,240,58,39,18,22,60,47,10,156,56,88,9,174,48,233,9,115,29,133,11,109,50,28,47,92,21,172,2,69,12,210,2,217,19,250,4,188,49,104,16,198,59,169,2,139,30,80,2,134,25,229,7,94,64,33,34,52,52,114,3,21,21,131,3,64,57,130,8,149,57,131,16,190,55,18,5,105,54,237,7,117,60,58,29,199,61,220,17,217,9,221,7,198,19,12,7,39,20,182,25,218,27,13,14,168,42,75,6,209,45,172,6,7,66,127,13,140,63,240,25,90,36,239,3,153,36,58,8,238,74,173,19,153,48,173,16,47,62,52,5,253,59,184,13,122,46,61,55,229,62,198,26,218,7,225,2,195,14,93,3,190,44,64,11,236,13,212,13,97,35,217,4,103,48,128,3,98,33,21,18,41,45,144,22,193,31,77,2,26,32,76,2,40,73,171,14,173,50,77,12,113,61,246,2,250,64,242,2,118,59,130,43,255,61,160,8,65,18,98,2,234,39,166,2,153,59,50,16,97,22,255,12,185,32,134,6,150,77,17,9,90,60,135,21,230,54,105,21,96,22,72,11,156,29,66,5,48,56,205,20,108,63,110,15,14,59,160,14,202,59,155,5,5,57,230,15,13,48,80,61,193,29,163,6,122,8,116,3,107,17,215,17,174,70,234,12,198,49,47,3,78,58,139,3,168,58,185,16,158,60,176,32,74,70,63,4,54,9,97,3,153,63,203,14,63,61,244,17,228,63,254,5,200,64,162,8,193,65,225,37,57,62,161,17,205,12,61,4,171,37,139,8,197,46,180,23,239,35,110,17,251,34,93,6,49,40,246,11,97,64,35,20,106,60,154,27,110,53,239,9,153,20,229,8,106,65,69,24,15,65,80,13,80,79,35,13,0,73,193,7,92,55,67,50,50,59,87,61,121,17,252,3,145,6,118,3,215,16,205,16,248,34,73,14,5,23,123,4,127,45,172,5,14,62,179,8,230,17,244,25,17,27,181,4,76,24,31,3,127,48,81,13,96,62,37,15,147,77,61,8,217,37,93,8,150,57,126,34,144,56,39,10,25,7,214,4,91,30,45,3,135,74,58,17,178,21,16,8,103,14,28,11,27,68,208,8,57,65,134,17,71,63,12,21,92,31,203,10,77,13,71,8,18,68,101,21,130,53,226,10,167,77,160,10,138,35,40,15,252,70,225,18,184,67,175,47,252,19,228,3,71,19,220,3,160,38,9,12,126,23,251,20,9,62,131,6,213,32,159,4,239,58,62,9,65,77,90,27,187,46,26,6,111,28,104,4,219,65,252,5,146,61,5,21,116,57,17,8,137,78,107,8,6,67,53,32,247,69,174,24,91,21,224,5,4,16,14,10,13,68,154,26,41,22,72,11,252,64,54,13,15,35,39,7,191,78,129,18,94,76,126,28,2,26,221,10,208,44,249,12,197,75,190,19,190,73,114,18,55,64,69,9,206,79,34,17,89,44,158,103,73,45,252,11,50,11,30,6,244,19,46,4,142,37,51,19,75,19,208,13,117,29,110,3,237,80,83,3,26,27,43,17,159,65,53,30,153,39,251,3,117,38,196,3,134,60,115,15,99,60,102,13,175,73,214,3,152,78,195,3,236,65,87,50,254,55,104,16,199,25,196,4,6,36,46,3,46,66,14,20,29,22,34,19,112,21,6,7,34,79,122,15,109,66,34,24,9,70,41,23,149,36,92,13,50,29,179,7,81,76,57,20,59,74,190,11,70,64,204,14,198,62,63,9,216,33,183,10,229,36,246,102,104,42,7,5,227,13,241,3,230,21,38,14,253,75,136,21,165,48,29,3,154,80,143,3,67,60,250,11,141,66,35,40,195,73,73,10,73,15,244,4,63,76,43,13,132,70,110,20,91,75,142,6,52,76,100,12,152,70,2,42,241,64,189,26,62,12,250,8,117,42,133,9,220,60,1,27,53,49,53,13,108,43,225,12,122,65,120,9,165,73,59,26,19,67,159,38,199,49,45,10,233,34,68,12,89,74,84,30,171,71,40,15,251,79,98,14,146,76,52,13,244,50,173,75,30,41,84,90,142,117,1,63,249,49,6,63,67,28,11,63,110,52,16,63,0,126,21,63,0,248,26,63,0,164,32,63,0,134,38,63,0,160,44,63,0,242,50,63,0,126,57,63,0,74,64,63,0,84,71,63,0,160,78,63,0,48,86,63,0,8,94,63,0,42,102,63,0,152,110,63,0,36,118,63,0,150,123,63,0,226,126,63,0,0,128,63,0,238,126,63,0,176,123,63,0,74,118,63,0,202,110,63,0,64,101,63,0,192,89,63,0,100,76,63,0,72,61,63,0,144,44,63,0,94,26,63,0,218,6,63,0,92,228,62,0,20,185,62,0,52,140,62,0,72,60,62,0,32,189,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,76,62,205,204,204,62,0,0,0,63,154,153,25,63,51,51,51,63,0,0,64,63,205,204,76,63,154,153,89,63,102,102,102,63,51,51,115,63,0,0,128,63,102,102,134,63,205,204,140,63,51,51,147,63,154,153,153,63,183,98,74,64,95,96,52,64,189,194,32,64,44,71,15,64,182,100,255,63,157,158,227,63,198,221,202,63,251,205,180,63,108,36,161,63,73,158,143,63,0,0,128,63,7,41,100,63,20,89,75,63,243,59,53,63,102,134,33,63,148,245,15,63,203,77,0,63,162,179,228,62,174,212,203,62,13,170,181,62,129,232,161,62,18,77,144,62,183,155,128,62,180,62,101,62,139,80,76,62,139,24,54,62,241,74,34,62,160,164,16,62,213,233,0,62,163,201,229,61,205,204,204,61,43,135,182,61,243,4,181,63,240,55,152,63,0,0,128,63,253,68,87,63,243,4,53,63,240,55,24,63,0,0,0,63,0,0,0,0,243,4,181,62,0,0,0,0,91,148,153,61,212,241,216,61,215,163,16,62,114,225,64,62,212,212,114,62,85,77,144,62,28,153,167,62,26,110,192,62,16,233,215,62,184,64,242,62,192,231,7,63,44,125,24,63,85,24,43,63,203,248,63,63,254,101,87,63,235,173,113,63,129,149,135,63,197,32,152,63,201,176,170,63,203,132,191,63,235,226,214,63,113,27,241,63,108,67,7,64,135,196,23,64,102,73,42,64,207,131,67,64,144,20,99,64,107,241,134,64,4,226,169,64,240,138,226,64,189,12,23,65,5,93,85,65,85,77,16,61,190,106,37,62,14,158,73,61,80,143,229,62,90,73,107,61,113,29,79,63,71,88,148,61,181,81,225,63,101,85,228,61,197,0,17,63,44,14,231,61,111,156,140,63,212,239,18,62,60,19,58,63,240,80,20,62,215,18,178,62,80,171,56,62,186,102,134,63,230,175,64,62,216,159,12,64,84,83,66,62,143,142,131,62,171,4,75,62,183,39,248,62,75,173,87,62,191,125,65,63,156,253,97,62,226,61,23,63,98,192,114,62,79,62,169,63,76,166,130,62,102,107,173,62,232,19,153,62,237,70,107,63,202,22,161,62,179,93,5,63,40,153,172,62,121,36,188,63,221,206,174,62,175,125,51,64,210,252,185,62,12,121,60,63,156,78,186,62,79,59,188,62,251,92,189,62,57,14,248,63,119,130,189,62,48,160,137,63,130,87,203,62,34,166,12,63,174,101,218,62,133,66,96,63,81,192,230,62,26,195,92,62,230,172,239,62,59,254,43,63,184,228,240,62,248,250,158,63,185,199,242,62,62,179,222,63,137,65,248,62,52,43,251,62,13,114,255,62,14,163,120,63,91,239,7,63,229,39,73,63,60,46,10,63,53,93,8,64,8,200,11,63,91,236,22,63,19,240,11,63,16,65,67,64,228,101,13,63,151,144,199,62,207,105,14,63,147,54,179,63,182,71,15,63,111,126,141,63,215,250,18,63,34,226,42,63,197,117,24,63,156,53,84,63,133,7,25,63,122,109,254,62,228,248,29,63,62,121,238,63,215,161,30,63,23,97,156,63,33,5,31,63,57,69,115,63,135,224,32,63,225,121,33,63,195,241,32,63,207,191,135,64,245,17,36,63,254,209,195,63,0,84,37,63,122,137,169,62,174,46,39,63,240,135,63,63,103,180,41,63,125,233,137,63,174,100,43,63,44,100,40,64,95,123,46,63,30,110,235,63,139,22,48,63,57,69,103,63,6,76,48,63,143,170,162,63,28,240,49,63,175,6,20,63,71,171,50,63,125,92,219,62,254,39,55,63,127,246,79,63,9,224,58,63,166,9,197,63,122,200,60,63,122,170,141,63,111,128,61,63,205,34,2,64,185,169,61,63,152,134,17,63,58,176,64,63,87,206,50,63,176,175,65,63,195,160,100,63,88,142,68,63,44,157,255,62,119,189,68,63,133,152,109,64,91,237,69,63,198,138,170,63,125,63,73,63,229,128,133,63,70,238,73,63,252,27,116,62,222,117,74,63,149,124,17,64,69,155,75,63,28,152,202,63,82,67,79,63,193,114,24,63,39,47,82,63,93,167,65,63,85,24,83,63,208,68,108,63,251,117,83,63,213,232,151,63,49,210,83,63,44,74,241,63,31,128,84,63,90,214,194,64,120,71,86,63,196,122,52,64,176,118,88,63,188,204,190,63,178,43,89,63,171,36,210,62,7,69,91,63,66,207,58,63,183,213,92,63,115,133,119,63,59,227,95,63,163,64,215,63,174,239,95,63,148,188,150,63,21,25,97,63,128,72,19,64,223,252,98,63,6,242,28,63,8,144,101,63,249,245,71,63,119,159,103,63,173,251,94,64,10,246,103,63,171,90,170,63,131,79,107,63,48,72,240,63,162,126,107,63,121,203,17,63,64,249,107,63,62,94,132,63,246,36,108,63,18,131,192,62,28,41,111,63,126,27,190,63,243,87,112,63,162,127,94,63,47,109,112,63,248,53,24,64,162,124,117,63,91,181,143,63,199,131,117,63,104,176,49,63,197,3,118,63,183,40,223,63,237,131,120,63,39,162,56,64,23,158,123,63,119,131,80,63,225,121,125,63,41,62,170,63,39,23,127,63,140,100,233,63,109,0,128,63,243,173,119,63,89,24,128,63,207,16,246,62,205,6,129,63,23,12,163,64,235,198,129,63,114,191,6,64,82,98,131,63,211,249,48,63,145,128,131,63,21,114,199,63,18,219,131,63,164,137,101,64,92,87,132,63,206,27,143,63,70,8,133,63,105,198,34,64,193,199,136,63,0,29,86,63,246,94,138,63,100,205,168,63,87,236,139,63,87,36,17,64,218,60,140,63,94,47,219,63,19,41,141,63,92,199,132,63,172,54,141,63,156,82,98,64,169,188,141,63,152,52,2,63,51,51,147,63,207,247,255,64,195,15,148,63,139,78,158,63,12,143,149,63,74,40,17,64,146,145,151,63,98,157,70,63,60,245,154,63,249,131,193,63,175,62,156,63,173,179,139,64,142,172,156,63,158,177,123,63,69,73,160,63,132,211,49,64,239,140,166,63,254,40,246,63,0,0,104,63,0,64,82,63,0,140,62,63,0,172,44,63,0,124,28,63,0,208,13,63,0,132,0,63,0,240,232,62,0,24,211,62,0,80,191,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,31,3,31,63,255,0,15,0,9,0,13,0,13,0,15,0,78,228,13,16,15,0,15,68,79,0,30,15,15,174,175,69,127,239,255,15,255,0,9,1,17,0,1,28,221,0,21,0,255,0,16,0,253,0,15,79,95,61,255,255,255,79,255,28,255,223,255,143,255,0,13,0,0,0,21,1,7,0,1,2,31,1,17,5,127,0,31,65,87,31,255,5,119,13,95,77,255,79,255,15,255,0,0,2,5,0,17,5,125,16,21,47,255,64,80,13,253,4,15,7,31,7,127,15,191,13,127,15,255,77,125,15,255,16,0,0,0,0,0,0,0,85,87,87,127,0,0,0,0,17,17,17,17,81,17,19,17,17,17,19,17,17,17,51,17,19,17,19,19,19,19,49,49,17,1,17,17,113,17,17,117,23,0,0,0,0,0,0,0,4,0,1,1,67,46,255,63,64,0,0,0,0,0,0,0,1,19,3,127,0,0,0,0,0,0,0,0,80,0,243,95,132,4,23,159,4,35,5,255,0,0,0,2,3,3,51,215,5,3,95,63,23,51,255,255,0,128,2,4,18,0,17,87,5,37,5,3,53,191,159,255,7,111,32,64,23,6,250,232,1,7,31,159,31,255,255,255,80,0,0,0,0,0,0,0,55,115,0,25,87,127,245,251,112,51,240,249,127,255,255,255,0,0,1,1,0,0,227,223,5,23,5,15,0,27,15,223,0,4,0,0,13,15,3,127,0,0,0,1,0,29,69,47,0,0,0,13,0,10,255,255,0,4,0,5,1,63,207,255,16,1,128,201,15,15,255,255,0,0,0,0,27,31,255,255,79,84,7,31,87,71,215,61,255,255,95,31,127,255,127,127,5,15,1,15,15,95,155,223,127,255,95,29,95,255,15,31,15,95,3,31,79,95,247,127,127,255,13,15,251,255,247,191,15,79,215,63,79,127,255,255,103,191,86,37,31,127,159,255,0,0,0,5,95,127,1,223,20,0,5,15,7,162,9,15,0,0,0,0,15,95,24,215,148,113,0,5,31,183,12,7,15,15,0,15,15,31,132,143,5,21,5,15,79,255,135,223,5,1,16,0,15,15,0,8,5,4,4,1,79,255,159,143,74,64,95,95,255,254,223,255,127,247,255,127,255,255,123,255,15,253,215,95,79,127,127,223,255,255,255,255,255,119,223,127,79,239,255,255,119,255,255,255,111,255,15,79,255,255,157,255,15,239,255,223,111,255,255,255,79,255,205,15,79,255,255,223,0,0,0,11,5,2,2,15,4,0,0,12,1,6,0,15,32,3,0,0,5,15,64,8,0,0,0,1,0,1,12,15,1,0,128,0,0,0,128,0,0,20,1,5,1,21,175,15,0,1,16,0,8,0,70,12,32,0,136,0,15,21,255,223,2,0,0,15,127,95,219,255,79,62,5,15,127,247,149,79,13,15,1,15,79,95,159,223,37,14,13,13,79,127,143,15,15,250,4,79,79,255,247,119,71,237,5,15,255,255,223,255,79,111,216,95,15,127,223,95,7,15,148,13,31,255,255,255,0,2,0,3,70,87,1,13,1,8,1,15,71,108,13,15,2,0,0,0,11,79,0,8,5,0,149,1,15,127,12,15,1,14,0,0,15,65,0,0,4,36,13,15,15,127,207,223,0,0,0,0,4,64,0,0,6,38,207,5,207,127,223,223,0,0,23,95,255,253,255,255,70,9,79,95,127,253,223,255,10,136,167,127,127,255,255,255,15,4,223,127,79,255,159,255,14,230,223,255,127,255,255,255,15,236,143,79,127,255,223,255,15,207,223,255,111,127,255,255,3,12,157,15,127,255,255,255,136,228,33,0,104,25,156,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,34,0,112,0,0,0,24,94,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,239,38,0,112,0,0,0,0,181,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,43,33,0,112,0,0,0,96,181,11,0,100,66,52], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1193696);
/* memory initializer */ allocate([16,112,37,0,112,0,0,0,192,181,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,0,0,0,0,178,157,239,167,198,75,3,64,246,40,92,143,194,245,10,192,229,208,34,219,249,126,15,64,25,4,86,14,45,178,16,192,109,231,251,169,241,210,10,64,164,112,61,10,215,163,1,192,229,208,34,219,249,126,244,63,104,145,237,124,63,53,226,191,144,160,248,49,230,174,181,63,136,86,35,0,208,68,35,0,0,0,0,0,0,0,0,0,10,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,96,21,36,0,248,220,35,0,0,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,200,191,32,0,240,98,32,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,43,33,0,112,0,0,0,8,96,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,1,0,0,0,40,1,0,0,2,0,0,0,2,0,0,0,3,0,0,0,42,1,0,0,4,0,0,0,30,0,0,0,5,0,0,0,255,255,255,255,0,0,0,0,0,238,2,0,0,0,0,0,94,46,215,245,117,67,136,63,15,254,15,192,16,182,167,191,101,249,173,250,9,219,176,63,92,182,57,219,245,44,150,191,57,210,67,45,198,245,172,191,107,120,208,202,1,9,182,63,5,93,233,186,100,72,161,191,8,51,62,114,193,150,165,191,114,131,0,140,65,109,176,63,98,225,125,74,12,163,161,191,13,118,207,170,119,143,124,63,0,0,0,0,0,0,240,63,35,237,112,46,53,253,20,192,209,212,113,17,104,55,37,64,218,176,55,157,136,123,33,192,242,90,76,237,202,108,245,191,28,50,77,55,210,40,32,64,98,8,1,227,225,216,21,192,236,6,75,129,188,97,225,63,162,248,6,192,251,251,235,63,4,215,134,127,13,46,214,191,114,143,186,175,137,19,159,63,191,226,39,102,157,227,239,63,236,226,39,102,157,227,255,191,191,226,39,102,157,227,239,63,0,0,0,0,0,0,240,63,82,227,70,207,144,227,255,191,13,197,17,250,83,199,239,63,16,177,2,0,0,0,0,0,247,196,119,73,74,0,102,63,212,40,180,76,236,116,129,191,12,38,51,49,160,118,129,63,141,84,113,239,143,240,87,63,9,254,4,23,57,121,131,191,137,123,76,66,80,158,121,63,121,178,140,202,26,9,83,63,110,149,115,234,93,177,109,191,236,63,19,72,95,181,96,63,21,123,190,189,13,154,64,191,135,127,218,92,54,176,6,63,0,0,0,0,0,0,240,63,236,196,42,79,238,76,22,192,99,40,74,44,197,226,40,64,233,242,164,61,207,191,41,192,194,199,57,9,52,175,8,64,244,14,0,219,238,127,26,64,219,125,108,123,119,78,28,192,41,165,192,58,19,24,4,64,162,17,129,27,144,59,177,63,140,208,242,143,92,114,207,191,155,13,121,170,74,72,164,63,69,95,207,252,27,225,239,63,69,95,207,252,27,225,255,191,69,95,207,252,27,225,239,63,0,0,0,0,0,0,240,63,168,145,220,19,13,225,255,191,194,89,132,203,85,194,239,63,128,50,2,0,0,0,0,0,255,192,47,66,142,51,122,63,208,31,46,123,140,45,154,191,0,44,185,41,119,169,165,63,134,254,76,12,27,15,163,191,22,167,60,199,251,152,145,63,122,234,98,18,134,2,121,63,76,161,159,200,62,101,159,191,203,207,86,13,14,64,166,63,210,235,199,9,136,227,160,191,32,180,146,242,131,13,139,63,38,20,165,199,28,12,98,191,0,0,0,0,0,0,240,63,48,109,141,165,179,151,24,192,15,116,20,210,156,153,47,64,194,146,30,160,237,200,52,192,80,152,68,198,26,250,39,64,81,54,51,248,189,234,10,64,228,176,123,43,202,114,36,192,146,219,229,174,189,159,26,64,234,239,9,113,33,190,250,191,233,32,186,138,108,189,171,191,251,157,15,188,32,225,178,63,123,253,88,204,44,218,239,63,168,253,88,204,44,218,255,191,123,253,88,204,44,218,239,63,0,0,0,0,0,0,240,63,204,124,100,113,22,218,255,191,9,253,154,78,134,180,239,63,0,244,1,0,0,0,0,0,125,229,64,195,227,167,118,63,72,241,252,165,27,162,149,191,0,106,231,95,216,43,162,63,7,39,175,53,75,55,161,191,196,95,243,159,166,51,141,63,141,147,153,62,8,138,139,63,164,22,136,247,248,94,161,191,210,30,13,80,131,188,161,63,47,131,42,158,107,225,148,191,149,159,191,13,106,86,123,63,0,155,98,122,121,185,78,191,0,0,0,0,0,0,240,63,152,22,127,20,81,149,24,192,255,177,101,125,64,12,48,64,164,13,207,64,222,48,54,192,156,8,108,205,192,126,46,64,242,115,84,63,245,163,224,191,1,106,242,120,128,2,32,192,111,74,49,227,199,111,26,64,17,93,186,149,74,7,3,192,178,59,45,11,62,48,213,63,54,193,178,37,146,213,114,63,134,189,191,139,117,213,239,63,179,189,191,139,117,213,255,191,134,189,191,139,117,213,239,63,0,0,0,0,0,0,240,63,210,36,207,68,89,213,255,191,39,173,96,165,35,171,239,63,128,181,1,0,0,0,0,0,207,102,71,144,165,168,117,63,232,225,51,119,4,99,147,191,102,73,45,90,238,79,160,63,188,226,38,11,4,247,157,191,224,228,201,19,28,81,125,63,202,109,220,206,129,85,148,63,165,16,217,27,242,127,160,191,184,229,135,7,200,69,154,63,135,230,109,115,91,203,136,191,186,249,176,191,228,168,106,63,33,211,115,95,25,243,60,191,0,0,0,0,0,0,240,63,113,154,193,6,78,255,24,192,73,215,30,198,102,108,49,64,224,99,30,42,66,222,59,192,119,86,165,174,118,202,58,64,36,7,29,253,204,223,42,192,116,95,248,132,167,32,229,191,187,111,220,119,117,37,24,64,51,219,173,134,63,255,16,192,135,22,164,233,93,136,246,63,188,255,173,92,124,239,200,191,24,233,223,99,102,207,239,63,24,233,223,99,102,207,255,191,24,233,223,99,102,207,239,63,0,0,0,0,0,0,240,63,204,192,239,123,65,207,255,191,202,34,160,151,22,159,239,63,0,119,1,0,0,0,0,0,197,238,246,183,19,23,120,63,34,92,228,154,217,133,144,191,145,136,68,194,81,95,150,63,196,93,45,132,213,215,145,191,150,114,34,207,14,8,115,63,27,47,22,223,88,228,134,63,164,37,69,58,150,191,149,191,126,128,16,125,84,16,148,63,19,68,56,132,216,28,134,191,41,22,188,196,211,217,108,63,227,193,240,232,64,175,68,191,0,0,0,0,0,0,240,63,50,27,112,246,143,233,23,192,128,169,26,34,176,54,48,64,97,141,206,75,175,186,57,192,0,81,146,218,154,103,57,64,178,126,9,122,197,82,45,192,105,225,156,209,29,135,6,64,63,14,153,27,163,29,4,64,219,152,103,129,210,226,1,192,136,190,168,185,144,64,232,63,236,132,97,14,188,204,185,191,45,90,234,249,83,199,239,63,45,90,234,249,83,199,255,191,45,90,234,249,83,199,239,63,0,0,0,0,0,0,240,63,5,250,233,202,33,199,255,191,167,116,213,81,12,143,239,63,136,88,1,0,0,0,0,0,119,180,64,230,164,80,155,63,187,50,152,72,88,32,189,191,28,72,153,191,86,133,205,63,176,116,190,228,57,170,211,191,176,206,96,115,155,61,213,63,127,195,143,192,15,172,213,191,0,165,99,12,73,91,212,63,102,248,155,135,27,96,206,191,49,31,49,215,209,107,191,63,8,232,181,55,48,169,163,191,122,88,242,67,190,131,118,63,0,0,0,0,0,0,240,63,72,141,11,89,1,70,25,192,249,205,33,101,66,80,50,64,252,35,184,80,209,225,63,192,206,59,88,156,218,68,66,64,177,210,65,220,226,59,60,192,44,107,245,227,151,126,44,64,177,209,159,177,212,47,16,192,62,161,171,108,238,37,200,63,71,167,70,17,222,68,208,63,87,120,197,93,124,200,174,191,31,22,77,203,85,194,239,63,76,22,77,203,85,194,255,191,31,22,77,203,85,194,239,63,0,0,0,0,0,0,240,63,45,208,220,96,26,194,255,191,213,184,122,107,34,133,239,63,0,250,0,0,0,0,0,0,34,192,29,148,248,193,154,63,194,215,57,17,72,207,180,191,253,72,221,15,166,30,195,63,254,97,138,52,64,197,203,191,165,138,80,116,175,1,208,63,108,53,58,45,209,165,205,191,10,123,47,145,130,77,198,63,240,184,249,1,242,93,186,191,24,35,70,106,245,205,165,63,201,86,87,54,74,7,132,191,150,75,192,147,172,65,81,63,0,0,0,0,0,0,240,63,157,133,74,197,236,241,22,192,138,65,240,26,10,39,48,64,179,114,245,174,193,175,61,192,197,7,8,203,77,199,67,64,12,249,134,165,161,233,67,192,50,86,10,184,140,129,62,64,76,5,235,104,54,110,49,192,210,99,254,103,200,52,28,64,167,47,135,244,231,236,252,191,136,202,46,198,217,82,204,63,198,83,154,164,35,171,239,63,198,83,154,164,35,171,255,191,198,83,154,164,35,171,239,63,0,0,0,0,0,0,240,63,104,221,109,30,179,170,255,191,160,148,141,85,40,87,239,63,192,218,0,0,0,0,0,0,124,207,161,70,26,26,160,63,116,179,39,203,49,127,175,191,247,44,218,144,166,166,180,63,214,232,238,54,219,237,184,191,14,125,62,203,5,229,182,63,146,130,168,211,244,228,177,191,228,73,105,192,225,57,169,63,121,102,119,29,134,47,160,191,242,48,55,47,6,214,141,63,166,40,238,49,81,227,105,191,133,142,68,159,86,194,85,63,0,0,0,0,0,0,240,63,146,92,53,98,190,126,19,192,48,163,142,218,20,20,40,64,191,168,14,163,252,25,52,192,81,170,219,58,152,26,57,64,41,113,235,103,104,74,56,192,202,137,5,147,134,69,50,64,170,32,88,126,173,231,36,192,23,221,144,186,120,54,17,64,188,140,54,22,217,49,242,191,143,171,178,141,224,146,194,63,87,163,78,150,22,159,239,63,87,163,78,150,22,159,255,191,87,163,78,150,22,159,239,63,0,0,0,0,0,0,240,63,151,198,109,213,131,158,255,191,215,255,94,174,82,63,239,63,128,187,0,0,0,0,0,0,50,23,78,148,59,192,163,63,137,21,35,224,69,31,150,191,30,25,58,32,147,55,84,191,100,127,76,30,138,91,24,191,57,67,88,105,42,243,144,191,71,48,13,28,80,34,150,63,183,143,205,46,252,60,149,191,145,39,155,184,170,87,120,63,78,249,55,236,66,26,105,63,191,132,219,151,14,134,31,63,93,40,82,156,133,161,103,63,0,0,0,0,0,0,240,63,105,9,132,109,238,197,14,192,39,38,121,177,147,66,31,64,79,178,147,196,243,174,38,192,77,9,136,125,46,28,42,64,99,181,117,43,64,147,40,192,108,219,102,168,67,247,34,64,70,223,201,63,133,125,23,192,246,69,57,117,138,9,6,64,224,81,234,151,194,213,235,191,22,209,63,188,20,209,193,63,82,90,102,79,12,143,239,63,82,90,102,79,12,143,255,191,82,90,102,79,12,143,239,63,0,0,0,0,0,0,240,63,142,99,111,244,68,142,255,191,136,162,186,84,167,31,239,63,68,172,0,0,0,0,0,0,160,218,19,97,87,190,171,63,11,103,131,69,8,207,157,191,11,230,107,114,174,97,129,191,200,135,220,48,143,110,129,191,157,37,85,210,193,25,129,191,134,135,184,203,230,253,150,63,39,181,23,72,37,150,154,191,246,69,14,107,124,163,144,63,56,93,161,143,153,187,99,191,70,250,109,80,214,161,123,63,51,47,54,53,98,195,94,191,0,0,0,0,0,0,240,63,6,126,21,145,226,211,11,192,124,102,244,223,228,115,25,64,116,244,13,236,83,24,33,192,233,177,50,247,48,244,34,64,239,9,159,243,69,161,33,192,178,24,246,3,131,106,27,64,11,23,20,217,46,148,17,192,203,6,226,181,165,145,1,64,156,177,133,97,139,8,232,191,118,42,253,188,196,212,192,63,212,16,18,104,34,133,239,63,212,16,18,104,34,133,255,191,212,16,18,104,34,133,239,63,0,0,0,0,0,0,240,63,58,43,218,132,54,132,255,191,222,236,147,150,28,12,239,63,168,147,0,0,0,0,0,0,87,243,243,141,89,81,182,63,187,124,168,70,215,124,132,191,121,175,120,139,99,10,176,191,108,237,123,175,129,236,134,191,153,15,118,108,57,185,82,191,19,36,182,146,23,80,149,63,238,162,198,210,218,106,144,191,204,81,181,170,27,213,147,63,251,170,215,141,165,33,127,63,204,193,173,110,231,230,104,191,141,16,227,135,227,154,72,191,0,0,0,0,0,0,240,63,225,65,18,98,122,6,5,192,65,82,32,185,123,76,12,64,105,34,107,92,243,122,14,192,158,86,172,24,167,77,15,64,99,42,228,160,15,72,12,192,248,114,135,124,99,181,5,64,135,27,157,213,47,224,253,191,45,237,184,143,155,238,241,63,220,215,135,222,96,22,223,191,115,95,197,243,149,1,189,63,208,132,81,48,214,112,239,63,253,132,81,48,214,112,255,191,208,132,81,48,214,112,239,63,0,0,0,0,0,0,240,63,20,108,27,235,149,111,255,191,115,59,15,235,44,228,238,63,0,125,0,0,0,0,0,0,241,119,23,71,12,201,195,63,136,170,87,65,50,227,183,191,246,216,149,178,56,253,175,191,212,141,60,98,152,39,150,63,15,64,199,163,209,156,172,191,171,78,232,86,45,123,168,63,214,62,198,171,59,54,98,63,47,107,20,185,88,64,160,63,238,33,35,135,177,122,140,191,80,155,72,10,164,174,122,63,207,141,107,9,225,12,130,191,0,0,0,0,0,0,240,63,145,69,61,11,43,8,3,192,158,18,71,136,25,202,6,64,5,109,176,90,138,42,5,192,226,192,107,249,83,229,1,64,85,26,176,107,99,190,250,191,59,4,2,10,105,24,240,63,30,237,181,186,3,105,221,191,248,74,46,12,204,246,196,63,47,41,133,24,165,195,169,191,144,190,25,71,223,10,152,63,149,236,96,73,40,87,239,63,149,236,96,73,40,87,255,191,149,236,96,73,40,87,239,63,0,0,0,0,0,0,240,63,224,62,238,205,106,85,255,191,238,52,167,137,203,177,238,63,192,93,0,0,0,0,0,0,45,33,68,101,216,99,211,63,13,242,27,221,38,242,204,191,31,155,214,217,201,251,181,191,48,106,136,146,0,207,160,63,42,241,39,172,235,192,130,191,74,23,235,77,116,53,152,191,58,82,97,60,119,240,119,191,44,162,59,19,27,17,176,63,5,119,162,194,193,93,225,190,93,236,29,149,60,221,96,63,254,79,225,18,154,53,158,191,0,0,0,0,0,0,240,63,189,230,61,180,191,205,249,191,207,180,185,17,194,70,241,63,154,139,250,113,133,107,208,191,177,214,138,41,142,213,196,191,8,250,225,13,80,250,204,191,33,145,242,79,141,9,217,63,231,77,7,178,57,86,204,191,124,115,66,108,140,10,167,63,218,187,97,92,56,138,148,63,191,156,19,136,155,198,104,63,20,206,26,0,207,53,239,63,65,206,26,0,207,53,255,191,20,206,26,0,207,53,239,63,0,0,0,0,0,0,240,63,251,142,188,33,80,51,255,191,178,26,242,188,155,112,238,63,34,86,0,0,0,0,0,0,92,65,204,137,244,135,213,63,249,69,133,139,193,93,208,191,138,220,181,196,248,71,190,191,82,82,232,220,164,132,190,63,200,31,137,62,105,14,180,191,79,101,137,91,19,64,115,191,20,188,151,157,91,37,120,191,151,43,39,61,220,78,173,63,188,121,230,134,78,10,129,63,121,1,134,222,13,191,144,191,140,202,208,127,50,6,146,191,0,0,0,0,0,0,240,63,48,118,159,74,57,250,247,191,239,27,204,246,187,243,235,63,207,9,154,244,174,62,191,63,236,2,32,94,21,217,233,191,216,69,1,144,135,160,222,63,198,185,85,146,127,225,191,191,110,73,114,241,93,211,164,191,62,39,251,31,156,85,181,63,254,211,216,15,250,177,165,191,92,75,230,2,146,124,158,63,152,52,59,107,43,36,239,63,197,52,59,107,43,36,255,191,152,52,59,107,43,36,239,63,0,0,0,0,0,0,240,63,125,31,207,50,56,33,255,191,192,147,78,71,61,78,238,63,212,73,0,0,0,0,0,0,25,106,2,242,219,167,216,63,96,2,184,32,116,183,209,191,19,143,6,155,156,140,185,191,152,234,158,109,206,121,185,63,22,233,241,219,255,222,182,191,219,125,189,41,147,104,106,191,62,124,60,151,137,19,82,191,73,54,73,200,110,96,163,63,162,111,160,84,66,62,145,63,210,163,193,215,202,125,135,191,160,110,14,112,58,226,147,191,0,0,0,0,0,0,240,63,94,133,151,150,224,192,244,191,183,210,89,143,131,237,236,63,113,241,186,193,236,243,210,191,95,17,230,51,204,22,219,191,2,187,236,127,64,71,216,63,161,225,162,132,199,68,216,191,150,193,125,229,20,247,205,63,41,210,197,143,152,238,163,191,36,91,146,135,220,129,112,63,37,178,60,60,61,163,162,63,75,115,122,137,44,228,238,63,75,115,122,137,44,228,254,191,75,115,122,137,44,228,238,63,0,0,0,0,0,0,240,63,133,93,221,115,65,223,254,191,123,18,47,62,47,210,237,63,128,62,0,0,0,0,0,0,129,213,143,103,234,190,220,63,192,115,192,172,200,94,194,191,0,184,172,136,253,41,205,191,15,236,159,153,97,16,141,191,178,156,195,234,117,225,164,63,67,252,140,166,66,189,191,191,86,74,4,181,194,250,164,63,193,175,189,46,49,211,186,63,30,94,167,239,17,22,147,191,236,38,37,198,176,89,160,191,76,164,77,137,80,50,118,63,0,0,0,0,0,0,240,63,43,99,103,223,67,26,228,191,183,80,102,97,201,251,210,63,227,81,99,138,21,216,215,191,183,212,176,113,9,131,97,63,130,37,186,109,42,230,218,191,175,240,202,169,97,106,204,63,112,186,245,115,56,32,121,63,222,3,62,232,30,70,177,63,76,198,139,158,71,158,173,63,87,85,220,210,32,128,160,63,162,74,80,205,141,221,238,63,162,74,80,205,141,221,254,191,162,74,80,205,141,221,238,63,0,0,0,0,0,0,240,63,147,20,125,71,103,216,254,191,96,1,71,166,104,197,237,63,224,46,0,0,0,0,0,0,214,175,6,93,68,30,226,63,107,180,52,94,12,38,232,191,72,155,25,68,57,202,196,63,102,6,2,243,192,110,197,63,232,114,101,123,173,49,200,191,236,21,72,1,221,203,211,63,190,128,199,106,234,163,209,191,74,124,66,94,139,131,122,63,19,84,73,99,58,35,182,63,124,52,246,62,76,102,163,191,222,155,204,206,226,23,120,191,0,0,0,0,0,0,240,63,197,102,124,41,159,196,240,191,213,161,248,91,248,168,210,63,81,61,138,44,229,39,209,191,35,114,239,228,40,203,128,63,202,138,18,136,196,213,220,63,22,215,218,105,7,36,213,191,179,50,221,97,182,64,177,63,108,42,253,84,209,126,168,191,216,212,254,132,235,202,144,63,58,215,119,170,229,129,146,63,247,168,92,169,17,185,238,63,247,168,92,169,17,185,254,191,247,168,92,169,17,185,238,63,0,0,0,0,0,0,240,63,255,251,115,239,138,178,254,191,54,172,138,198,48,127,237,63,17,43,0,0,0,0,0,0,13,214,43,177,151,151,226,63,30,204,55,171,22,4,225,191,151,183,151,57,123,74,194,191,42,112,91,63,47,109,198,63,235,71,167,5,164,89,152,63,174,158,17,79,49,234,195,63,33,128,18,139,125,56,208,191,102,94,30,159,234,172,144,63,13,56,49,211,101,183,177,63,248,239,170,144,253,13,163,191,99,105,238,162,82,180,126,191,0,0,0,0,0,0,240,63,9,162,4,98,208,84,224,191,159,53,10,182,134,100,212,191,233,26,64,31,159,237,201,191,113,221,175,29,31,218,194,63,71,180,1,35,0,238,216,63,143,150,116,253,74,215,205,191,160,159,226,226,15,220,170,191,139,80,254,113,58,169,153,191,167,98,233,63,126,2,153,63,227,96,172,195,224,159,146,63,252,4,93,62,153,172,238,63,41,5,93,62,153,172,254,191,252,4,93,62,153,172,238,63,0,0,0,0,0,0,240,63,169,23,62,147,144,165,254,191,247,228,247,210,67,103,237,63,64,31,0,0,0,0,0,0,119,157,38,168,232,42,225,63,221,69,23,214,253,251,218,191,189,171,77,172,42,155,102,191,213,51,35,55,242,217,165,63,42,16,217,211,105,38,186,191,220,17,8,177,26,173,194,63,205,75,240,92,99,48,153,191,167,104,9,158,140,173,188,191,223,19,236,99,145,201,164,191,186,21,107,134,153,132,168,63,251,195,4,49,48,182,150,191,0,0,0,0,0,0,240,63,28,220,12,200,43,8,208,191,148,99,7,64,229,164,219,191,237,37,103,67,204,136,161,191,44,170,144,166,250,243,167,191,141,223,67,100,188,230,208,63,99,214,230,70,69,88,195,63,24,234,52,104,233,120,198,191,105,39,247,117,236,23,200,191,250,169,244,249,193,11,172,63,59,51,38,243,41,22,168,63,157,193,105,65,113,69,238,63,157,193,105,65,113,69,254,191,157,193,105,65,113,69,238,63,0,0,0,0,0,0,240,63,117,252,16,192,122,57,254,191,137,13,133,133,207,162,236,63,208,84,39,0,196,10,0,0,0,0,0,0,100,66,52,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,228,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,33,37,0,184,211,35,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,228,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,125,36,0,112,0,0,0,144,115,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,214,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,170,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,241,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,160,195,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,129,36,0,112,0,0,0,0,139,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,255,38,0,112,0,0,0,192,110,17,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,13,15,17,19,20,26,31,5,0,0,0,0,0,0,0,24,20,4,1,0,0,0,0,24,20,4,1,0,0,0,0,60,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,50,0,0,0,1,0,0,0,30,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,25,0,0,0,1,0,0,0,24,0,0,0,1,0,0,0,192,93,0,0,233,3,0,0,0,0,0,0,0,0,0,0,112,227,38,0,128,25,156,0,160,1,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,0,0,0,0,0,0,0,0,248,157,38,0,128,25,156,0,168,1,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,0,0,0,0,0,0,0,0,40,98,38,0,128,25,156,0,196,1,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,0,0,0,0,0,0,0,0,0,44,38,0,128,25,156,0,124,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,168,249,37,0,128,25,156,0,68,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,176,206,37,0,128,25,156,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,176,169,37,0,128,25,156,0,80,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,184,132,37,0,128,25,156,0,96,1,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,0,0,0,0,0,0,0,0,176,66,37,0,128,25,156,0,88,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,4,0,6,0,8,0,0,16,0,32,0,64,0,2,0,4,0,8,0,0,0,0,1,0,0,0,0,0,0,0,2,1,0,1,0,0,28,0,2,1,1,2,0,0,46,0,2,1,1,3,2,0,80,0,2,1,1,3,5,0,104,0,4,2,1,3,0,0,108,0,4,2,1,3,2,0,132,0,4,2,1,3,5,0,168,0,2,1,2,3,0,0,64,0,2,1,2,3,2,0,80,0,2,1,2,3,5,0,104,0,4,2,2,3,0,0,108,0,4,2,2,3,2,0,132,0,4,2,2,3,5,0,168,0,8,3,2,3,0,0,176,0,8,3,2,3,2,0,208,0,8,3,2,3,5,0,0,1,0,0,2,0,1,0,2,0,4,0,3,0,5,0,3,0,12,0,4,0,13,0,4,0,56,0,6,0,57,0,6,0,58,0,6,0,59,0,6,0,120,0,7,0,121,0,7,0,122,0,7,0,123,0,7,0,240,1,9,0,241,1,9,0,242,1,9,0,243,1,9,0,244,1,9,0,245,1,9,0,246,1,9,0,247,1,9,0,248,1,9,0,249,1,9,0,250,1,9,0,251,1,9,0,252,1,9,0,253,1,9,0,254,1,9,0,255,1,9,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,24,0,0,0,1,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,48,138,36,0,208,228,34,0,24,0,0,0,84,65,82,86,120,34,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,40,133,33,0,160,9,33,0,16,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,16,0,0,0,0,0,0,0,0,164,32,0,144,72,32,0,32,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,0,164,32,0,96,47,40,0,200,210,39,0,32,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,0,164,32,0,16,107,39,0,224,26,39,0,32,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,0,164,32,0,168,214,38,0,88,145,38,0,32,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,0,164,32,0,104,86,38,0,96,33,38,0,32,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,0,164,32,0,144,241,37,0,168,195,37,0,32,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,0,164,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,138,36,0,112,0,0,0,176,121,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,35,0,0,0,8,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,35,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,34,0,0,0,255,255,255,255,8,4,0,3,3,2,9,0,8,5,1,3,4,4,13,0,3,3,3,3,3,3,3,3,3,3,3,1,3,3,3,0,0,3,0,3,2,3,3,2,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,3,3,3,3,3,3,3,3,3,3,0,0,0,3,3,3,3,3,3,0,0,3,3,3,3,1,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,3,3,3,3,3,1,1,0,0,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,0,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,1,1,3,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,192,148,36,0,112,0,0,0,80,140,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,70,184,38,75,21,182,11,113,6,139,3,243,1,18,1,151,0,83,0,0,0,0,0,240,212,33,0,208,121,38,0,208,181,36,0,184,142,35,0,232,179,34,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,4,4,0,221,221,0,0,150,150,0,0,108,1,0,0,188,0,0,0,208,0,0,0,26,1,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,2,0,0,16,0,0,0,178,2,0,0,36,2,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,1,0,0,150,2,0,0,166,2,0,0,116,1,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,1,0,0,234,0,0,0,214,0,0,0,82,1,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,1,0,0,48,2,0,0,20,2,0,0,44,2,0,0,142,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,0,0,0,5,0,0,0,8,0,0,0,13,0,0,0,9,0,0,0,87,0,0,0,3,0,0,0,132,0,0,0,6,0,0,0,93,0,0,0,4,0,0,0,92,0,0,0,4,0,0,0,107,0,0,0,5,0,0,0,28,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,144,112,37,0,112,0,0,0,160,122,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,145,35,0,112,0,0,0,16,132,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,80,1,0,2,0,0,0,5,0,1,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,3,0,0,0,13,16,1,0,1,0,0,0,2,80,1,0,10,0,0,0,34,80,1,0,6,0,0,0,6,0,1,0,8,0,0,0,7,0,1,0,7,0,0,0,36,80,1,0,11,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,5,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,255,255,255,255,9,0,0,0,10,0,0,0,11,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,12,0,0,0,13,0,0,0,14,0,0,0,0,0,0,0,248,45,32,0,32,21,40,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,136,32,0,112,0,0,0,248,128,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,136,35,0,112,0,0,0,32,182,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,7,6,0,0,0,0,0,0,15,6,0,0,0,0,0,0,15,7,0,0,0,0,0,0,63,6,0,0,0,0,0,0,96,7,0,0,0,8,80,0,0,8,16,0,20,8,115,0,18,7,31,0,0,8,112,0,0,8,48,0,0,9,192,0,16,7,10,0,0,8,96,0,0,8,32,0,0,9,160,0,0,8,0,0,0,8,128,0,0,8,64,0,0,9,224,0,16,7,6,0,0,8,88,0,0,8,24,0,0,9,144,0,19,7,59,0,0,8,120,0,0,8,56,0,0,9,208,0,17,7,17,0,0,8,104,0,0,8,40,0,0,9,176,0,0,8,8,0,0,8,136,0,0,8,72,0,0,9,240,0,16,7,4,0,0,8,84,0,0,8,20,0,21,8,227,0,19,7,43,0,0,8,116,0,0,8,52,0,0,9,200,0,17,7,13,0,0,8,100,0,0,8,36,0,0,9,168,0,0,8,4,0,0,8,132,0,0,8,68,0,0,9,232,0,16,7,8,0,0,8,92,0,0,8,28,0,0,9,152,0,20,7,83,0,0,8,124,0,0,8,60,0,0,9,216,0,18,7,23,0,0,8,108,0,0,8,44,0,0,9,184,0,0,8,12,0,0,8,140,0,0,8,76,0,0,9,248,0,16,7,3,0,0,8,82,0,0,8,18,0,21,8,163,0,19,7,35,0,0,8,114,0,0,8,50,0,0,9,196,0,17,7,11,0,0,8,98,0,0,8,34,0,0,9,164,0,0,8,2,0,0,8,130,0,0,8,66,0,0,9,228,0,16,7,7,0,0,8,90,0,0,8,26,0,0,9,148,0,20,7,67,0,0,8,122,0,0,8,58,0,0,9,212,0,18,7,19,0,0,8,106,0,0,8,42,0,0,9,180,0,0,8,10,0,0,8,138,0,0,8,74,0,0,9,244,0,16,7,5,0,0,8,86,0,0,8,22,0,64,8,0,0,19,7,51,0,0,8,118,0,0,8,54,0,0,9,204,0,17,7,15,0,0,8,102,0,0,8,38,0,0,9,172,0,0,8,6,0,0,8,134,0,0,8,70,0,0,9,236,0,16,7,9,0,0,8,94,0,0,8,30,0,0,9,156,0,20,7,99,0,0,8,126,0,0,8,62,0,0,9,220,0,18,7,27,0,0,8,110,0,0,8,46,0,0,9,188,0,0,8,14,0,0,8,142,0,0,8,78,0,0,9,252,0,96,7,0,0,0,8,81,0,0,8,17,0,21,8,131,0,18,7,31,0,0,8,113,0,0,8,49,0,0,9,194,0,16,7,10,0,0,8,97,0,0,8,33,0,0,9,162,0,0,8,1,0,0,8,129,0,0,8,65,0,0,9,226,0,16,7,6,0,0,8,89,0,0,8,25,0,0,9,146,0,19,7,59,0,0,8,121,0,0,8,57,0,0,9,210,0,17,7,17,0,0,8,105,0,0,8,41,0,0,9,178,0,0,8,9,0,0,8,137,0,0,8,73,0,0,9,242,0,16,7,4,0,0,8,85,0,0,8,21,0,16,8,2,1,19,7,43,0,0,8,117,0,0,8,53,0,0,9,202,0,17,7,13,0,0,8,101,0,0,8,37,0,0,9,170,0,0,8,5,0,0,8,133,0,0,8,69,0,0,9,234,0,16,7,8,0,0,8,93,0,0,8,29,0,0,9,154,0,20,7,83,0,0,8,125,0,0,8,61,0,0,9,218,0,18,7,23,0,0,8,109,0,0,8,45,0,0,9,186,0,0,8,13,0,0,8,141,0,0,8,77,0,0,9,250,0,16,7,3,0,0,8,83,0,0,8,19,0,21,8,195,0,19,7,35,0,0,8,115,0,0,8,51,0,0,9,198,0,17,7,11,0,0,8,99,0,0,8,35,0,0,9,166,0,0,8,3,0,0,8,131,0,0,8,67,0,0,9,230,0,16,7,7,0,0,8,91,0,0,8,27,0,0,9,150,0,20,7,67,0,0,8,123,0,0,8,59,0,0,9,214,0,18,7,19,0,0,8,107,0,0,8,43,0,0,9,182,0,0,8,11,0,0,8,139,0,0,8,75,0,0,9,246,0,16,7,5,0,0,8,87,0,0,8,23,0,64,8,0,0,19,7,51,0,0,8,119,0,0,8,55,0,0,9,206,0,17,7,15,0,0,8,103,0,0,8,39,0,0,9,174,0,0,8,7,0,0,8,135,0,0,8,71,0,0,9,238,0,16,7,9,0,0,8,95,0,0,8,31,0,0,9,158,0,20,7,99,0,0,8,127,0,0,8,63,0,0,9,222,0,18,7,27,0,0,8,111,0,0,8,47,0,0,9,190,0,0,8,15,0,0,8,143,0,0,8,79,0,0,9,254,0,96,7,0,0,0,8,80,0,0,8,16,0,20,8,115,0,18,7,31,0,0,8,112,0,0,8,48,0,0,9,193,0,16,7,10,0,0,8,96,0,0,8,32,0,0,9,161,0,0,8,0,0,0,8,128,0,0,8,64,0,0,9,225,0,16,7,6,0,0,8,88,0,0,8,24,0,0,9,145,0,19,7,59,0,0,8,120,0,0,8,56,0,0,9,209,0,17,7,17,0,0,8,104,0,0,8,40,0,0,9,177,0,0,8,8,0,0,8,136,0,0,8,72,0,0,9,241,0,16,7,4,0,0,8,84,0,0,8,20,0,21,8,227,0,19,7,43,0,0,8,116,0,0,8,52,0,0,9,201,0,17,7,13,0,0,8,100,0,0,8,36,0,0,9,169,0,0,8,4,0,0,8,132,0,0,8,68,0,0,9,233,0,16,7,8,0,0,8,92,0,0,8,28,0,0,9,153,0,20,7,83,0,0,8,124,0,0,8,60,0,0,9,217,0,18,7,23,0,0,8,108,0,0,8,44,0,0,9,185,0,0,8,12,0,0,8,140,0,0,8,76,0,0,9,249,0,16,7,3,0,0,8,82,0,0,8,18,0,21,8,163], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1203968);
/* memory initializer */ allocate([19,7,35,0,0,8,114,0,0,8,50,0,0,9,197,0,17,7,11,0,0,8,98,0,0,8,34,0,0,9,165,0,0,8,2,0,0,8,130,0,0,8,66,0,0,9,229,0,16,7,7,0,0,8,90,0,0,8,26,0,0,9,149,0,20,7,67,0,0,8,122,0,0,8,58,0,0,9,213,0,18,7,19,0,0,8,106,0,0,8,42,0,0,9,181,0,0,8,10,0,0,8,138,0,0,8,74,0,0,9,245,0,16,7,5,0,0,8,86,0,0,8,22,0,64,8,0,0,19,7,51,0,0,8,118,0,0,8,54,0,0,9,205,0,17,7,15,0,0,8,102,0,0,8,38,0,0,9,173,0,0,8,6,0,0,8,134,0,0,8,70,0,0,9,237,0,16,7,9,0,0,8,94,0,0,8,30,0,0,9,157,0,20,7,99,0,0,8,126,0,0,8,62,0,0,9,221,0,18,7,27,0,0,8,110,0,0,8,46,0,0,9,189,0,0,8,14,0,0,8,142,0,0,8,78,0,0,9,253,0,96,7,0,0,0,8,81,0,0,8,17,0,21,8,131,0,18,7,31,0,0,8,113,0,0,8,49,0,0,9,195,0,16,7,10,0,0,8,97,0,0,8,33,0,0,9,163,0,0,8,1,0,0,8,129,0,0,8,65,0,0,9,227,0,16,7,6,0,0,8,89,0,0,8,25,0,0,9,147,0,19,7,59,0,0,8,121,0,0,8,57,0,0,9,211,0,17,7,17,0,0,8,105,0,0,8,41,0,0,9,179,0,0,8,9,0,0,8,137,0,0,8,73,0,0,9,243,0,16,7,4,0,0,8,85,0,0,8,21,0,16,8,2,1,19,7,43,0,0,8,117,0,0,8,53,0,0,9,203,0,17,7,13,0,0,8,101,0,0,8,37,0,0,9,171,0,0,8,5,0,0,8,133,0,0,8,69,0,0,9,235,0,16,7,8,0,0,8,93,0,0,8,29,0,0,9,155,0,20,7,83,0,0,8,125,0,0,8,61,0,0,9,219,0,18,7,23,0,0,8,109,0,0,8,45,0,0,9,187,0,0,8,13,0,0,8,141,0,0,8,77,0,0,9,251,0,16,7,3,0,0,8,83,0,0,8,19,0,21,8,195,0,19,7,35,0,0,8,115,0,0,8,51,0,0,9,199,0,17,7,11,0,0,8,99,0,0,8,35,0,0,9,167,0,0,8,3,0,0,8,131,0,0,8,67,0,0,9,231,0,16,7,7,0,0,8,91,0,0,8,27,0,0,9,151,0,20,7,67,0,0,8,123,0,0,8,59,0,0,9,215,0,18,7,19,0,0,8,107,0,0,8,43,0,0,9,183,0,0,8,11,0,0,8,139,0,0,8,75,0,0,9,247,0,16,7,5,0,0,8,87,0,0,8,23,0,64,8,0,0,19,7,51,0,0,8,119,0,0,8,55,0,0,9,207,0,17,7,15,0,0,8,103,0,0,8,39,0,0,9,175,0,0,8,7,0,0,8,135,0,0,8,71,0,0,9,239,0,16,7,9,0,0,8,95,0,0,8,31,0,0,9,159,0,20,7,99,0,0,8,127,0,0,8,63,0,0,9,223,0,18,7,27,0,0,8,111,0,0,8,47,0,0,9,191,0,0,8,15,0,0,8,143,0,0,8,79,0,0,9,255,0,16,5,1,0,23,5,1,1,19,5,17,0,27,5,1,16,17,5,5,0,25,5,1,4,21,5,65,0,29,5,1,64,16,5,3,0,24,5,1,2,20,5,33,0,28,5,1,32,18,5,9,0,26,5,1,8,22,5,129,0,64,5,0,0,16,5,2,0,23,5,129,1,19,5,25,0,27,5,1,24,17,5,7,0,25,5,1,6,21,5,97,0,29,5,1,96,16,5,4,0,24,5,1,3,20,5,49,0,28,5,1,48,18,5,13,0,26,5,1,12,22,5,193,0,64,5,0,0,0,0,240,65,0,0,136,65,0,0,128,65,0,0,32,65,0,0,64,64,0,0,64,65,0,0,0,65,0,0,32,64,0,0,160,64,0,0,160,64,0,0,192,64,0,0,192,64,0,0,160,64,0,0,192,64,0,0,32,65,0,0,192,64,0,0,128,192,0,0,32,193,0,0,168,193,0,0,240,193,0,0,40,194,0,0,92,194,0,0,136,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,182,194,0,0,214,194,0,0,220,194,0,0,216,194,0,0,240,65,0,0,136,65,0,0,128,65,0,0,32,65,0,0,64,64,0,0,64,65,0,0,0,65,0,0,32,64,0,0,160,64,0,0,160,64,0,0,192,64,0,0,192,64,0,0,160,64,0,0,192,64,0,0,32,65,0,0,192,64,0,0,128,192,0,0,32,193,0,0,168,193,0,0,240,193,0,0,40,194,0,0,92,194,0,0,136,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,150,194,0,0,182,194,0,0,214,194,0,0,220,194,0,0,216,194,0,0,1,255,2,254,3,253,4,252,5,251,6,250,7,249,8,248,9,247,10,246,11,245,12,244,13,243,14,242,15,241,16,240,17,239,18,238,19,237,20,236,21,235,22,234,23,233,24,232,25,231,26,230,27,229,28,228,29,227,30,226,31,225,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,3,0,0,0,253,255,255,255,1,0,0,0,1,0,2,0,3,0,4,0,6,0,9,0,13,0,18,0,26,0,38,0,55,0,80,0,115,0,166,0,240,0,92,1,246,1,214,2,26,4,237,5,145,8,98,12,230,17,223,25,72,206,249,46,43,88,154,46,40,41,138,178,53,83,90,179,46,182,37,180,15,181,212,180,144,23,69,181,176,35,213,180,177,137,254,180,243,169,33,181,151,236,49,181,29,114,59,181,136,117,60,181,61,172,53,181,130,26,40,181,123,92,21,181,118,255,59,53,164,5,98,53,137,196,130,53,38,168,145,53,242,21,156,53,63,87,160,53,99,68,158,53,69,180,138,53,216,183,125,53,208,143,4,54,80,199,159,53,18,131,12,53,8,83,88,52,23,64,168,51,255,59,56,176,112,186,221,176,186,90,56,177,132,156,105,177,48,208,97,50,211,246,0,50,204,140,239,50,161,37,27,52,49,43,168,52,179,224,187,53,134,95,8,54,149,51,54,54,135,200,103,54,26,195,140,54,145,76,164,54,91,25,185,54,131,214,201,54,45,116,213,54,190,85,6,55,140,176,7,55,226,59,5,55,202,247,253,54,184,108,234,54,151,224,208,54,141,95,178,54,92,160,148,54,162,165,95,54,114,55,98,53,27,21,233,52,47,31,203,51,145,144,255,50,5,127,137,51,14,109,11,179,41,162,35,179,237,30,181,51,192,63,138,51,160,160,159,53,208,149,39,54,47,190,114,54,4,225,83,54,158,170,27,54,136,6,4,55,72,220,36,55,110,124,69,55,219,110,103,55,44,210,131,55,146,58,146,55,16,15,158,55,129,176,166,55,115,96,171,55,121,227,3,184,185,224,11,184,47,36,17,184,216,119,19,184,105,155,18,184,45,132,14,184,247,72,7,184,103,229,249,183,103,150,224,183,51,147,151,183,39,8,149,183,73,103,139,183,102,128,74,183,31,168,234,182,152,59,23,181,250,3,134,181,179,94,197,181,234,200,248,181,85,56,65,53,208,39,79,54,147,43,204,54,130,104,32,55,129,184,91,55,45,221,189,55,43,216,238,55,253,66,15,56,2,134,37,56,252,160,57,56,83,249,74,56,246,33,89,56,230,188,99,56,112,177,106,56,114,247,164,54,22,5,28,55,17,136,99,55,10,245,146,55,243,166,175,55,92,47,198,55,133,211,212,55,13,160,219,55,172,72,214,55,43,59,253,55,57,168,215,55,92,135,166,55,199,223,71,55,211,125,41,54,210,56,127,183,242,180,135,183,138,39,167,55,114,223,148,55,115,247,65,56,100,82,107,56,176,189,137,56,9,147,157,56,168,114,176,56,183,168,183,56,227,150,199,56,197,13,214,56,89,108,227,56,142,50,239,56,115,31,249,56,199,114,0,57,107,25,3,57,73,85,4,57,150,155,0,57,90,129,254,56,99,171,247,56,112,50,236,56,128,157,219,56,172,125,197,56,133,106,169,56,161,53,135,56,114,99,60,56,248,65,207,55,234,20,230,181,225,239,5,184,182,48,137,184,251,200,214,184,51,152,9,185,129,7,58,185,50,57,106,185,90,158,140,185,44,131,175,185,233,207,204,185,136,107,235,185,13,177,5,186,211,50,22,186,89,177,38,186,45,19,56,186,185,206,73,186,40,209,91,186,219,255,109,186,232,31,128,186,169,57,137,186,67,61,146,186,86,27,155,186,254,53,164,186,5,132,172,186,22,110,180,186,12,223,187,186,193,193,194,186,102,0,201,186,178,132,206,186,141,55,211,186,92,2,215,186,149,191,217,186,85,123,219,186,74,254,219,186,205,65,219,186,244,30,217,186,189,43,214,186,74,219,208,186,164,31,202,58,38,230,193,58,239,233,182,58,88,205,170,58,253,200,156,58,81,189,140,58,238,86,117,58,207,236,76,58,135,71,32,58,238,135,222,57,226,82,103,57,83,255,145,180,153,223,121,185,240,94,1,186,169,197,72,186,48,84,138,186,243,117,178,186,48,202,220,186,249,162,4,187,239,237,27,187,170,62,52,187,158,140,77,187,10,206,103,187,235,123,129,187,4,127,143,187,58,233,157,187,109,180,172,187,204,214,187,187,119,74,203,187,162,4,219,187,94,242,234,187,212,34,251,187,25,189,5,188,167,247,13,188,1,64,22,188,35,138,30,188,61,211,38,188,156,21,47,188,8,76,55,188,206,112,63,188,65,124,71,188,85,105,79,188,5,50,87,188,100,208,94,188,148,62,102,188,201,118,109,188,86,115,116,188,177,46,123,188,87,209,128,188,223,229,131,188,2,210,134,188,100,147,137,188,193,39,140,188,248,140,142,188,11,193,144,188,38,194,146,188,149,142,148,188,12,37,150,188,202,131,151,188,215,169,152,188,46,150,153,188,57,72,154,188,194,191,154,188,51,251,154,188,51,251,154,60,194,191,154,60,57,72,154,60,46,150,153,60,215,169,152,60,202,131,151,60,12,37,150,60,149,142,148,60,38,194,146,60,11,193,144,60,248,140,142,60,193,39,140,60,100,147,137,60,2,210,134,60,223,229,131,60,87,209,128,60,177,46,123,60,86,115,116,60,201,118,109,60,148,62,102,60,100,208,94,60,5,50,87,60,85,105,79,60,65,124,71,60,206,112,63,60,8,76,55,60,156,21,47,60,61,211,38,60,35,138,30,60,1,64,22,60,167,247,13,60,25,189,5,60,212,34,251,59,94,242,234,59,162,4,219,59,119,74,203,59,204,214,187,59,109,180,172,59,58,233,157,59,4,127,143,59,235,123,129,59,10,206,103,59,158,140,77,59,170,62,52,59,239,237,27,59,249,162,4,59,48,202,220,58,243,117,178,58,48,84,138,58,169,197,72,58,240,94,1,58,153,223,121,57,83,255,145,52,226,82,103,185,238,135,222,185,135,71,32,186,207,236,76,186,238,86,117,186,81,189,140,186,253,200,156,186,88,205,170,186,239,233,182,186,38,230,193,186,164,31,202,186,74,219,208,58,189,43,214,58,244,30,217,58,205,65,219,58,74,254,219,58,85,123,219,58,149,191,217,58,92,2,215,58,141,55,211,58,178,132,206,58,102,0,201,58,193,193,194,58,12,223,187,58,22,110,180,58,5,132,172,58,254,53,164,58,86,27,155,58,67,61,146,58,169,57,137,58,232,31,128,58,219,255,109,58,40,209,91,58,185,206,73,58,45,19,56,58,89,177,38,58,211,50,22,58,13,177,5,58,136,107,235,57,233,207,204,57,44,131,175,57,90,158,140,57,50,57,106,57,129,7,58,57,51,152,9,57,251,200,214,56,182,48,137,56,225,239,5,56,234,20,230,53,248,65,207,183,114,99,60,184,161,53,135,184,133,106,169,184,172,125,197,184,128,157,219,184,112,50,236,184,99,171,247,184,90,129,254,184,150,155,0,185,73,85,4,185,107,25,3,185,199,114,0,185,115,31,249,184,142,50,239,184,89,108,227,184,197,13,214,184,227,150,199,184,183,168,183,184,168,114,176,184,9,147,157,184,176,189,137,184,100,82,107,184,115,247,65,184,114,223,148,183,138,39,167,183,242,180,135,55,210,56,127,55,211,125,41,182,199,223,71,183,92,135,166,183,57,168,215,183,43,59,253,183,172,72,214,183,13,160,219,183,133,211,212,183,92,47,198,183,243,166,175,183,10,245,146,183,17,136,99,183,22,5,28,183,114,247,164,182,112,177,106,184,230,188,99,184,246,33,89,184,83,249,74,184,252,160,57,184,2,134,37,184,253,66,15,184,43,216,238,183,45,221,189,183,129,184,91,183,130,104,32,183,147,43,204,182,208,39,79,182,85,56,65,181,234,200,248,53,179,94,197,53,250,3,134,53,152,59,23,53,31,168,234,54,102,128,74,55,73,103,139,55,39,8,149,55,51,147,151,55,103,150,224,55,103,229,249,55,247,72,7,56,45,132,14,56,105,155,18,56,216,119,19,56,47,36,17,56,185,224,11,56,121,227,3,56,115,96,171,183,129,176,166,183,16,15,158,183,146,58,146,183,44,210,131,183,219,110,103,183,110,124,69,183,72,220,36,183,136,6,4,183,158,170,27,182,4,225,83,182,47,190,114,182,208,149,39,182,160,160,159,181,192,63,138,179,237,30,181,179,41,162,35,51,14,109,11,51,5,127,137,179,145,144,255,178,47,31,203,179,27,21,233,180,114,55,98,181,162,165,95,182,92,160,148,182,141,95,178,182,151,224,208,182,184,108,234,182,202,247,253,182,226,59,5,183,140,176,7,183,190,85,6,183,45,116,213,182,131,214,201,182,91,25,185,182,145,76,164,182,26,195,140,182,135,200,103,182,149,51,54,182,134,95,8,182,179,224,187,181,49,43,168,180,161,37,27,180,204,140,239,178,211,246,0,178,48,208,97,178,132,156,105,49,186,90,56,49,112,186,221,48,255,59,56,48,23,64,168,179,8,83,88,180,18,131,12,181,80,199,159,181,208,143,4,182,216,183,125,181,69,180,138,181,99,68,158,181,63,87,160,181,242,21,156,181,38,168,145,181,137,196,130,181,164,5,98,181,118,255,59,181,123,92,21,53,130,26,40,53,61,172,53,53,136,117,60,53,29,114,59,53,151,236,49,53,243,169,33,53,177,137,254,52,176,35,213,52,144,23,69,53,15,181,212,52,46,182,37,52,53,83,90,51,40,41,138,50,43,88,154,174,72,206,249,174,72,206,249,46,43,88,154,46,40,41,138,178,53,83,90,179,46,182,37,180,15,181,212,180,144,23,69,181,176,35,213,180,177,137,254,180,243,169,33,181,151,236,49,181,29,114,59,181,136,117,60,181,61,172,53,181,130,26,40,181,123,92,21,181,118,255,59,53,164,5,98,53,137,196,130,53,38,168,145,53,242,21,156,53,63,87,160,53,99,68,158,53,69,180,138,53,216,183,125,53,208,143,4,54,80,199,159,53,18,131,12,53,8,83,88,52,23,64,168,51,255,59,56,176,112,186,221,176,186,90,56,177,132,156,105,177,48,208,97,50,211,246,0,50,204,140,239,50,161,37,27,52,49,43,168,52,179,224,187,53,134,95,8,54,149,51,54,54,135,200,103,54,26,195,140,54,145,76,164,54,91,25,185,54,131,214,201,54,45,116,213,54,190,85,6,55,140,176,7,55,226,59,5,55,202,247,253,54,184,108,234,54,151,224,208,54,141,95,178,54,92,160,148,54,162,165,95,54,114,55,98,53,27,21,233,52,47,31,203,51,145,144,255,50,5,127,137,51,14,109,11,179,41,162,35,179,237,30,181,51,192,63,138,51,160,160,159,53,208,149,39,54,47,190,114,54,4,225,83,54,158,170,27,54,136,6,4,55,72,220,36,55,110,124,69,55,219,110,103,55,44,210,131,55,146,58,146,55,16,15,158,55,129,176,166,55,115,96,171,55,121,227,3,184,185,224,11,184,47,36,17,184,216,119,19,184,105,155,18,184,45,132,14,184,247,72,7,184,103,229,249,183,103,150,224,183,51,147,151,183,39,8,149,183,73,103,139,183,102,128,74,183,31,168,234,182,152,59,23,181,250,3,134,181,179,94,197,181,234,200,248,181,85,56,65,53,208,39,79,54,147,43,204,54,130,104,32,55,129,184,91,55,45,221,189,55,43,216,238,55,253,66,15,56,2,134,37,56,252,160,57,56,83,249,74,56,246,33,89,56,230,188,99,56,112,177,106,56,114,247,164,54,22,5,28,55,17,136,99,55,10,245,146,55,243,166,175,55,92,47,198,55,133,211,212,55,13,160,219,55,172,72,214,55,43,59,253,55,57,168,215,55,92,135,166,55,199,223,71,55,211,125,41,54,210,56,127,183,242,180,135,183,138,39,167,55,114,223,148,55,115,247,65,56,100,82,107,56,176,189,137,56,9,147,157,56,168,114,176,56,183,168,183,56,227,150,199,56,197,13,214,56,89,108,227,56,142,50,239,56,115,31,249,56,199,114,0,57,107,25,3,57,73,85,4,57,150,155,0,57,90,129,254,56,99,171,247,56,112,50,236,56,128,157,219,56,172,125,197,56,133,106,169,56,161,53,135,56,114,99,60,56,248,65,207,55,234,20,230,181,225,239,5,184,182,48,137,184,251,200,214,184,51,152,9,185,129,7,58,185,50,57,106,185,90,158,140,185,44,131,175,185,233,207,204,185,136,107,235,185,13,177,5,186,211,50,22,186,89,177,38,186,45,19,56,186,185,206,73,186,40,209,91,186,219,255,109,186,232,31,128,186,169,57,137,186,67,61,146,186,86,27,155,186,254,53,164,186,5,132,172,186,22,110,180,186,12,223,187,186,193,193,194,186,102,0,201,186,178,132,206,186,141,55,211,186,92,2,215,186,149,191,217,186,85,123,219,186,74,254,219,186,205,65,219,186,244,30,217,186,189,43,214,186,74,219,208,186,164,31,202,58,38,230,193,58,239,233,182,58,88,205,170,58,253,200,156,58,81,189,140,58,238,86,117,58,207,236,76,58,135,71,32,58,238,135,222,57,226,82,103,57,83,255,145,180,153,223,121,185,240,94,1,186,169,197,72,186,48,84,138,186,243,117,178,186,48,202,220,186,249,162,4,187,239,237,27,187,170,62,52,187,158,140,77,187,10,206,103,187,235,123,129,187,4,127,143,187,58,233,157,187,109,180,172,187,204,214,187,187,119,74,203,187,162,4,219,187,94,242,234,187,212,34,251,187,25,189,5,188,167,247,13,188,1,64,22,188,35,138,30,188,61,211,38,188,156,21,47,188,8,76,55,188,206,112,63,188,65,124,71,188,85,105,79,188,5,50,87,188,100,208,94,188,148,62,102,188,201,118,109,188,86,115,116,188,177,46,123,188,87,209,128,188,223,229,131,188,2,210,134,188,100,147,137,188,193,39,140,188,248,140,142,188,11,193,144,188,38,194,146,188,149,142,148,188,12,37,150,188,202,131,151,188,215,169,152,188,46,150,153,188,57,72,154,188,194,191,154,188,51,251,154,188,51,251,154,60,194,191,154,60,57,72,154,60,46,150,153,60,215,169,152,60,202,131,151,60,12,37,150,60,149,142,148,60,38,194,146,60,11,193,144,60,248,140,142,60,193,39,140,60,100,147,137,60,2,210,134,60,223,229,131,60,87,209,128,60,177,46,123,60,86,115,116,60,201,118,109,60,148,62,102,60,100,208,94,60,5,50,87,60,85,105,79,60,65,124,71,60,206,112,63,60,8,76,55,60,156,21,47,60,61,211,38,60,35,138,30,60,1,64,22,60,167,247,13,60,25,189,5,60,212,34,251,59,94,242,234,59,162,4,219,59,119,74,203,59,204,214,187,59,109,180,172,59,58,233,157,59,4,127,143,59,235,123,129,59,10,206,103,59,158,140,77,59,170,62,52,59,239,237,27,59,249,162,4,59,48,202,220,58,243,117,178,58,48,84,138,58,169,197,72,58,240,94,1,58,153,223,121,57,83,255,145,52,226,82,103,185,238,135,222,185,135,71,32,186,207,236,76,186,238,86,117,186,81,189,140,186,253,200,156,186,88,205,170,186,239,233,182,186,38,230,193,186,164,31,202,186,74,219,208,58,189,43,214,58,244,30,217,58,205,65,219,58,74,254,219,58,85,123,219,58,149,191,217,58,92,2,215,58,141,55,211,58,178,132,206,58,102,0,201,58,193,193,194,58,12,223,187,58,22,110,180,58,5,132,172,58,254,53,164,58,86,27,155,58,67,61,146,58,169,57,137,58,232,31,128,58,219,255,109,58,40,209,91,58,185,206,73,58,45,19,56,58,89,177,38,58,211,50,22,58,13,177,5,58,136,107,235,57,233,207,204,57,44,131,175,57,90,158,140,57,50,57,106,57,129,7,58,57,51,152,9,57,251,200,214,56,182,48,137,56,225,239,5,56,234,20,230,53,248,65,207,183,114,99,60,184,161,53,135,184,133,106,169,184,172,125,197,184,128,157,219,184,112,50,236,184,99,171,247,184,90,129,254,184,150,155,0,185,73,85,4,185,107,25,3,185,199,114,0,185,115,31,249,184,142,50,239,184,89,108,227,184,197,13,214,184,227,150,199,184,183,168,183,184,168,114,176,184,9,147,157,184,176,189,137,184,100,82,107,184,115,247,65,184,114,223,148,183,138,39,167,183,242,180,135,55,210,56,127,55,211,125,41,182,199,223,71,183,92,135,166,183,57,168,215,183,43,59,253,183,172,72,214,183,13,160,219,183,133,211,212,183,92,47,198,183,243,166,175,183,10,245,146,183,17,136,99,183,22,5,28,183,114,247,164,182,112,177,106,184,230,188,99,184,246,33,89,184,83,249,74,184,252,160,57,184,2,134,37,184,253,66,15,184,43,216,238,183,45,221,189,183,129,184,91,183,130,104,32,183,147,43,204,182,208,39,79,182,85,56,65,181,234,200,248,53,179,94,197,53,250,3,134,53,152,59,23,53,31,168,234,54,102,128,74,55,73,103,139,55,39,8,149,55,51,147,151,55,103,150,224,55,103,229,249,55,247,72,7,56,45,132,14,56,105,155,18,56,216,119,19,56,47,36,17,56,185,224,11,56,121,227,3,56,115,96,171,183,129,176,166,183,16,15,158,183,146,58,146,183,44,210,131,183,219,110,103,183,110,124,69,183,72,220,36,183,136,6,4,183,158,170,27,182,4,225,83,182,47,190,114,182,208,149,39,182,160,160,159,181,192,63,138,179,237,30,181,179,41,162,35,51,14,109,11,51,5,127,137,179,145,144,255,178,47,31,203,179,27,21,233,180,114,55,98,181,162,165,95,182,92,160,148,182,141,95,178,182,151,224,208,182,184,108,234,182,202,247,253,182,226,59,5,183,140,176,7,183,190,85,6,183,45,116,213,182,131,214,201,182,91,25,185,182,145,76,164,182,26,195,140,182,135,200,103,182,149,51,54,182,134,95,8,182,179,224,187,181,49,43,168,180,161,37,27,180,204,140,239,178,211,246,0,178,48,208,97,178,132,156,105,49,186,90,56,49,112,186,221,48,255,59,56,48,23,64,168,179,8,83,88,180,18,131,12,181,80,199,159,181,208,143,4,182,216,183,125,181,69,180,138,181,99,68,158,181,63,87,160,181,242,21,156,181,38,168,145,181,137,196,130,181,164,5,98,181,118,255,59,181,123,92,21,53,130,26,40,53,61,172,53,53,136,117,60,53,29,114,59,53,151,236,49,53,243,169,33,53,177,137,254,52,176,35,213,52,144,23,69,53,15,181,212,52,46,182,37,52,53,83,90,51,40,41,138,50,43,88,154,174,72,206,249,174,77,69,21,180,34,221,53,180,215,10,90,180,154,19,129,180,69,76,151,180,121,234,175,180,61,49,203,180,120,108,233,180,57,121,5,181,106,18,24,181,89,184,44,181,214,167,67,181,60,36,93,181,224,119,121,181,45,122,140,181,102,249,157,181,25,106,177,181,137,0,199,181,4,245,222,181,236,131,249,181,184,118,11,182,195,186,27,182,237,177,45,182,166,129,65,182,232,80,87,182,11,72,111,182,69,200,132,182,106,42,147,182,250,223,162,182,148,254,179,182,198,155,198,182,222,204,218,182,181,166,240,182,179,30,4,183,1,210,16,183,47,118,30,183,91,19,45,183,173,176,60,183,47,84,77,183,152,2,95,183,31,191,113,183,165,197,130,183,93,51,141,183,127,39,152,183,168,159,163,183,54,152,175,183,45,12,188,183,24,245,200,183,244,74,214,183,20,4,228,183,9,21,242,183,70,56,0,184,179,131,7,184,44,228,14,184,12,80,22,184,149,188,29,184,246,29,37,184,56,103,44,184,70,138,51,184,228,119,58,184,178,31,65,184,45,112,71,184,178,86,77,184,135,191,82,184,224,149,87,56,232,195,91,56,217,50,95,56,0,203,97,56,218,115,99,56,37,20,100,56,252,145,99,56,242,210,97,56,47,188,94,56,150,50,90,56,231,26,84,56,233,89,76,56,147,212,66,56,57,112,55,56,192,18,42,56,207,162,26,56,1,8,9,56,74,86,234,55,223,236,189,55,115,171,140,55,243,218,44,55,181,148,88,54,115,2,150,182,49,197,86,183,227,163,182,183,102,167,3,184,115,179,46,184,67,116,92,184,17,114,134,184,161,252,159,184,193,210,186,184,26,235,214,184,244,57,244,184,144,88,9,185,239,31,25,185,102,105,41,185,232,41,58,185,8,85,75,185,238,220,92,185,87,178,110,185,72,98,128,185,186,128,137,185,186,170,146,185,198,213,155,185,172,246,164,185,136,1,174,185,204,233,182,185,69,162,191,185,33,29,200,185,250,75,208,185,221,31,216,185,87,137,223,185,128,120,230,185,7,221,236,185,70,166,242,185,79,195,247,185,246,34,252,185,243,179,255,185,116,50,1,186,61,18,2,186,0,113,2,186,161,69,2,186,6,136,1,186,248,47,0,186,6,107,252,57,237,33,247,57,248,117,240,57,73,89,232,57,227,190,222,57,200,154,211,57,28,226,198,57,57,139,184,57,207,141,168,57,252,226,150,57,110,133,131,57,240,226,92,57,89,74,47,57,229,129,252,56,247,148,147,56,57,118,143,55,113,24,37,184,111,135,207,184,11,117,41,185,93,64,110,185,157,3,155,185,27,83,192,185,122,250,230,185,129,113,7,186,181,249,27,186,241,7,49,186,253,140,70,186,96,120,92,186,85,184,114,186,235,156,132,186,81,244,143,186,158,87,155,186,128,187,166,186,15,20,178,186,217,84,189,186,227,112,200,186,181,90,211,186,93,4,222,186,125,95,232,186,81,93,242,186,185,238,251,186,36,130,2,187,35,199,6,187,101,190,10,187,222,95,14,187,114,163,17,187,254,128,20,187,94,240,22,187,117,233,24,187,50,100,26,187,157,88,27,187,216,190,27,187,49,143,27,187,29,194,26,187,76,80,25,187,171,50,23,187,111,98,20,187,26,217,16,187,135,144,12,187,239,130,7,187,241,170,1,187,56,7,246,186,235,16,231,186,253,106,214,186,121,14,196,58,126,245,175,58,80,27,154,58,91,124,130,58,144,44,82,58,253,207,27,58,197,198,195,57,51,167,17,57,58,184,228,184,58,45,194,185,177,9,41,186,51,98,116,186,157,135,161,186,139,126,202,186,154,10,245,186,143,143,16,187,2,87,39,187,237,211,62,187,231,253,86,187,226,203,111,187,18,154,132,187,43,150,145,187,196,212,158,187,23,80,172,187,23,2,186,187,120,228,199,187,169,240,213,187,224,31,228,187,28,107,242,187,149,101,0,188,83,156,7,188,6,214,14,188,215,14,22,188,226,66,29,188,56,110,36,188,223,140,43,188,218,154,50,188,42,148,57,188,205,116,64,188,200,56,71,188,37,220,77,188,248,90,84,188,101,177,90,188,157,219,96,188,230,213,102,188,154,156,108,188,50,44,114,188,62,129,119,188,112,152,124,188,78,183,128,188,92,0,131,188,243,37,133,188,184,38,135,188,99,1,137,188,201,180,138,188,210,63,140,188,130,161,141,188,245,216,142,188,99,229,143,188,35,198,144,188,155,122,145,188,92,2,146,188,14,93,146,188,118,138,146,188,118,138,146,60,14,93,146,60,92,2,146,60,155,122,145,60,35,198,144,60,99,229,143,60,245,216,142,60,130,161,141,60,210,63,140,60,201,180,138,60,99,1,137,60,184,38,135,60,243,37,133,60,92,0,131,60,78,183,128,60,112,152,124,60,62,129,119,60,50,44,114,60,154,156,108,60,230,213,102,60,157,219,96,60,101,177,90,60,248,90,84,60,37,220,77,60,200,56,71,60,205,116,64,60,42,148,57,60,218,154,50,60,223,140,43,60,56,110,36,60,226,66,29,60,215,14,22,60,6,214,14,60,83,156,7,60,149,101,0,60,28,107,242,59,224,31,228,59,169,240,213,59,120,228,199,59,23,2,186,59,23,80,172,59,196,212,158,59,43,150,145,59,18,154,132,59,226,203,111,59,231,253,86,59,237,211,62,59,2,87,39,59,143,143,16,59,154,10,245,58,139,126,202,58,157,135,161,58,51,98,116,58,177,9,41,58,58,45,194,57,58,184,228,56,51,167,17,185,197,198,195,185,253,207,27,186,144,44,82,186,91,124,130,186,80,27,154,186,126,245,175,186,121,14,196,186,253,106,214,58,235,16,231,58,56,7,246,58,241,170,1,59,239,130,7,59,135,144,12,59,26,217,16,59,111,98,20,59,171,50,23,59,76,80,25,59,29,194,26,59,49,143,27,59,216,190,27,59,157,88,27,59,50,100,26,59,117,233,24,59,94,240,22,59,254,128,20,59,114,163,17,59,222,95,14,59,101,190,10,59,35,199,6,59,36,130,2,59,185,238,251,58,81,93,242,58,125,95,232,58,93,4,222,58,181,90,211,58,227,112,200,58,217,84,189,58,15,20,178,58,128,187,166,58,158,87,155,58,81,244,143,58,235,156,132,58,85,184,114,58,96,120,92,58,253,140,70,58,241,7,49,58,181,249,27,58,129,113,7,58,122,250,230,57,27,83,192,57,157,3,155,57,93,64,110,57,11,117,41,57,111,135,207,56,113,24,37,56,57,118,143,183,247,148,147,184,229,129,252,184,89,74,47,185,240,226,92,185,110,133,131,185,252,226,150,185,207,141,168,185,57,139,184,185,28,226,198,185,200,154,211,185,227,190,222,185,73,89,232,185,248,117,240,185,237,33,247,185,6,107,252,185,248,47,0,58,6,136,1,58,161,69,2,58,0,113,2,58,61,18,2,58,116,50,1,58,243,179,255,57,246,34,252,57,79,195,247,57,70,166,242,57,7,221,236,57,128,120,230,57,87,137,223,57,221,31,216,57,250,75,208,57,33,29,200,57,69,162,191,57,204,233,182,57,136,1,174,57,172,246,164,57,198,213,155,57,186,170,146,57,186,128,137,57,72,98,128,57,87,178,110,57,238,220,92,57,8,85,75,57,232,41,58,57,102,105,41,57,239,31,25,57,144,88,9,57,244,57,244,56,26,235,214,56,193,210,186,56,161,252,159,56,17,114,134,56,67,116,92,56,115,179,46,56,102,167,3,56,227,163,182,55,49,197,86,55,115,2,150,54,181,148,88,182,243,218,44,183,115,171,140,183,223,236,189,183,74,86,234,183,1,8,9,184,207,162,26,184,192,18,42,184,57,112,55,184,147,212,66,184,233,89,76,184,231,26,84,184,150,50,90,184,47,188,94,184,242,210,97,184,252,145,99,184,37,20,100,184,218,115,99,184,0,203,97,184,217,50,95,184,232,195,91,184,224,149,87,184,135,191,82,56,178,86,77,56,45,112,71,56,178,31,65,56,228,119,58,56,70,138,51,56,56,103,44,56,246,29,37,56,149,188,29,56,12,80,22,56,44,228,14,56,179,131,7,56,70,56,0,56,9,21,242,55,20,4,228,55,244,74,214,55,24,245,200,55,45,12,188,55,54,152,175,55,168,159,163,55,127,39,152,55,93,51,141,55,165,197,130,55,31,191,113,55,152,2,95,55,47,84,77,55,173,176,60,55,91,19,45,55,47,118,30,55,1,210,16,55,179,30,4,55,181,166,240,54,222,204,218,54,198,155,198,54,148,254,179,54,250,223,162,54,106,42,147,54,69,200,132,54,11,72,111,54,232,80,87,54,166,129,65,54,237,177,45,54,195,186,27,54,184,118,11,54,236,131,249,53,4,245,222,53,137,0,199,53,25,106,177,53,102,249,157,53,45,122,140,53,224,119,121,53,60,36,93,53,214,167,67,53,89,184,44,53,106,18,24,53,57,121,5,53,120,108,233,52,61,49,203,52,121,234,175,52,69,76,151,52,154,19,129,52,215,10,90,52,34,221,53,52,77,69,21,52,77,69,21,180,34,221,53,180,215,10,90,180,154,19,129,180,69,76,151,180,121,234,175,180,61,49,203,180,120,108,233,180,57,121,5,181,106,18,24,181,89,184,44,181,214,167,67,181,60,36,93,181,224,119,121,181,45,122,140,181,102,249,157,181,25,106,177,181,137,0,199,181,4,245,222,181,236,131,249,181,184,118,11,182,195,186,27,182,237,177,45,182,166,129,65,182,232,80,87,182,11,72,111,182,69,200,132,182,106,42,147,182,250,223,162,182,148,254,179,182,198,155,198,182,222,204,218,182,181,166,240,182,179,30,4,183,1,210,16,183,47,118,30,183,91,19,45,183,173,176,60,183,47,84,77,183,152,2,95,183,31,191,113,183,165,197,130,183,93,51,141,183,127,39,152,183,168,159,163,183,54,152,175,183,45,12,188,183,24,245,200,183,244,74,214,183,20,4,228,183,9,21,242,183,70,56,0,184,179,131,7,184,44,228,14,184,12,80,22,184,149,188,29,184,246,29,37,184,56,103,44,184,70,138,51,184,228,119,58,184,178,31,65,184,45,112,71,184,178,86,77,184,135,191,82,184,224,149,87,56,232,195,91,56,217,50,95,56,0,203,97,56,218,115,99,56,37,20,100,56,252,145,99,56,242,210,97,56,47,188,94,56,150,50,90,56,231,26,84,56,233,89,76,56,147,212,66,56,57,112,55,56,192,18,42,56,207,162,26,56,1,8,9,56,74,86,234,55,223,236,189,55,115,171,140,55,243,218,44,55,181,148,88,54,115,2,150,182,49,197,86,183,227,163,182,183,102,167,3,184,115,179,46,184,67,116,92,184,17,114,134,184,161,252,159,184,193,210,186,184,26,235,214,184,244,57,244,184,144,88,9,185,239,31,25,185,102,105,41,185,232,41,58,185,8,85,75,185,238,220,92,185,87,178,110,185,72,98,128,185,186,128,137,185,186,170,146,185,198,213,155,185,172,246,164,185,136,1,174,185,204,233,182,185,69,162,191,185,33,29,200,185,250,75,208,185,221,31,216,185,87,137,223,185,128,120,230,185,7,221,236,185,70,166,242,185,79,195,247,185,246,34,252,185,243,179,255,185,116,50,1,186,61,18,2,186,0,113,2,186,161,69,2,186,6,136,1,186,248,47,0,186,6,107,252,57,237,33,247,57,248,117,240,57,73,89,232,57,227,190,222,57,200,154,211,57,28,226,198,57,57,139,184,57,207,141,168,57,252,226,150,57,110,133,131,57,240,226,92,57,89,74,47,57,229,129,252,56,247,148,147,56,57,118,143,55,113,24,37,184,111,135,207,184,11,117,41,185,93,64,110,185,157,3,155,185,27,83,192,185,122,250,230,185,129,113,7,186,181,249,27,186,241,7,49,186,253,140,70,186,96,120,92,186,85,184,114,186,235,156,132,186,81,244,143,186,158,87,155,186,128,187,166,186,15,20,178,186,217,84,189,186,227,112,200,186,181,90,211,186,93,4,222,186,125,95,232,186,81,93,242,186,185,238,251,186,36,130,2,187,35,199,6,187,101,190,10,187,222,95,14,187,114,163,17,187,254,128,20,187,94,240,22,187,117,233,24,187,50,100,26,187,157,88,27,187,216,190,27,187,49,143,27,187,29,194,26,187,76,80,25,187,171,50,23,187,111,98,20,187,26,217,16,187,135,144,12,187,239,130,7,187,241,170,1,187,56,7,246,186,235,16,231,186,253,106,214,186,121,14,196,58,126,245,175,58,80,27,154,58,91,124,130,58,144,44,82,58,253,207,27,58,197,198,195,57,51,167,17,57,58,184,228,184,58,45,194,185,177,9,41,186,51,98,116,186,157,135,161,186,139,126,202,186,154,10,245,186,143,143,16,187,2,87,39,187,237,211,62,187,231,253,86,187,226,203,111,187,18,154,132,187,43,150,145,187,196,212,158,187,23,80,172,187,23,2,186,187,120,228,199,187,169,240,213,187,224,31,228,187,28,107,242,187,149,101,0,188,83,156,7,188,6,214,14,188,215,14,22,188,226,66,29,188,56,110,36,188,223,140,43,188,218,154,50,188,42,148,57,188,205,116,64,188,200,56,71,188,37,220,77,188,248,90,84,188,101,177,90,188,157,219,96,188,230,213,102,188,154,156,108,188,50,44,114,188,62,129,119,188,112,152,124,188,78,183,128,188,92,0,131,188,243,37,133,188,184,38,135,188,99,1,137,188,201,180,138,188,210,63,140,188,130,161,141,188,245,216,142,188,99,229,143,188,35,198,144,188,155,122,145,188,92,2,146,188,14,93,146,188,118,138,146,188,118,138,146,60,14,93,146,60,92,2,146,60,155,122,145,60,35,198,144,60,99,229,143,60,245,216,142,60,130,161,141,60,210,63,140,60,201,180,138,60,99,1,137,60,184,38,135,60,243,37,133,60,92,0,131,60,78,183,128,60,112,152,124,60,62,129,119,60,50,44,114,60,154,156,108,60,230,213,102,60,157,219,96,60,101,177,90,60,248,90,84,60,37,220,77,60,200,56,71,60,205,116,64,60,42,148,57,60,218,154,50,60,223,140,43,60,56,110,36,60,226,66,29,60,215,14,22,60,6,214,14,60,83,156,7,60,149,101,0,60,28,107,242,59,224,31,228,59,169,240,213,59,120,228,199,59,23,2,186,59,23,80,172,59,196,212,158,59,43,150,145,59,18,154,132,59,226,203,111,59,231,253,86,59,237,211,62,59,2,87,39,59,143,143,16,59,154,10,245,58,139,126,202,58,157,135,161,58,51,98,116,58,177,9,41,58,58,45,194,57,58,184,228,56,51,167,17,185,197,198,195,185,253,207,27,186,144,44,82,186,91,124,130,186,80,27,154,186,126,245,175,186,121,14,196,186,253,106,214,58,235,16,231,58,56,7,246,58,241,170,1,59,239,130,7,59,135,144,12,59,26,217,16,59,111,98,20,59,171,50,23,59,76,80,25,59,29,194,26,59,49,143,27,59,216,190,27,59,157,88,27,59,50,100,26,59,117,233,24,59,94,240,22,59,254,128,20,59,114,163,17,59,222,95,14,59,101,190,10,59,35,199,6,59,36,130,2,59,185,238,251,58,81,93,242,58,125,95,232,58,93,4,222,58,181,90,211,58,227,112,200,58,217,84,189,58,15,20,178,58,128,187,166,58,158,87,155,58,81,244,143,58,235,156,132,58,85,184,114,58,96,120,92,58,253,140,70,58,241,7,49,58,181,249,27,58,129,113,7,58,122,250,230,57,27,83,192,57,157,3,155,57,93,64,110,57,11,117,41,57,111,135,207,56,113,24,37,56,57,118,143,183,247,148,147,184,229,129,252,184,89,74,47,185,240,226,92,185,110,133,131,185,252,226,150,185,207,141,168,185,57,139,184,185,28,226,198,185,200,154,211,185,227,190,222,185,73,89,232,185,248,117,240,185,237,33,247,185,6,107,252,185,248,47,0,58,6,136,1,58,161,69,2,58,0,113,2,58,61,18,2,58,116,50,1,58,243,179,255,57,246,34,252,57,79,195,247,57,70,166,242,57,7,221,236,57,128,120,230,57,87,137,223,57,221,31,216,57,250,75,208,57,33,29,200,57,69,162,191,57,204,233,182,57,136,1,174,57,172,246,164,57,198,213,155,57,186,170,146,57,186,128,137,57,72,98,128,57,87,178,110,57,238,220,92,57,8,85,75,57,232,41,58,57,102,105,41,57,239,31,25,57,144,88,9,57,244,57,244,56,26,235,214,56,193,210,186,56,161,252,159,56,17,114,134,56,67,116,92,56,115,179,46,56,102,167,3,56,227,163,182,55,49,197,86,55,115,2,150,54,181,148,88,182,243,218,44,183,115,171,140,183,223,236,189,183,74,86,234,183,1,8,9,184,207,162,26,184,192,18,42,184,57,112,55,184,147,212,66,184,233,89,76,184,231,26,84,184,150,50,90,184,47,188,94,184,242,210,97,184,252,145,99,184,37,20,100,184,218,115,99,184,0,203,97,184,217,50,95,184,232,195,91,184,224,149,87,184,135,191,82,56,178,86,77,56,45,112,71,56,178,31,65,56,228,119,58,56,70,138,51,56,56,103,44,56,246,29,37,56,149,188,29,56,12,80,22,56,44,228,14,56,179,131,7,56,70,56,0,56,9,21,242,55,20,4,228,55,244,74,214,55,24,245,200,55,45,12,188,55,54,152,175,55,168,159,163,55,127,39,152,55,93,51,141,55,165,197,130,55,31,191,113,55,152,2,95,55,47,84,77,55,173,176,60,55,91,19,45,55,47,118,30,55,1,210,16,55,179,30,4,55,181,166,240,54,222,204,218,54,198,155,198,54,148,254,179,54,250,223,162,54,106,42,147,54,69,200,132,54,11,72,111,54,232,80,87,54,166,129,65,54,237,177,45,54,195,186,27,54,184,118,11,54,236,131,249,53,4,245,222,53,137,0,199,53,25,106,177,53,102,249,157,53,45,122,140,53,224,119,121,53,60,36,93,53,214,167,67,53,89,184,44,53,106,18,24,53,57,121,5,53,120,108,233,52,61,49,203,52,121,234,175,52,69,76,151,52,154,19,129,52,215,10,90,52,34,221,53,52,77,69,21,52,3,255,255,3,4,255,255,4,255,255,0,255,255,0,6,255,0,255,255,0,4,255,255,2,255,255,0,253,253,0,2,255,255,0,0,255,255,4,2,255,255,255,253,0,0,253,255,2,1,255,255,1,2,255,255,2,255,255,0,253,253,0,253,253,0,255,255,0,2,255,255,255,255,1,0,253,253,0,253,253,255,0,0,255,255,2,255,255,1,255,253,0,0,253,253,253,0,255,255,0,1,255,255,1,255,255,0,253,253,0,253,253,0,255,255,0,1,255,255,255,0,254,254,0,254,255,255,254,255,0,0,255,255,1,255,255,254,0,0,254,255,254,254,255,0,255,255,0,255,255,0,254,254,0,255,254,254,255,254,254,0,255,255,0,255,255,0,254,254,0,255,254,254,255,254,254,0,255,255,0,255,255,0,254,254,0,255,254,254,255,254,254,0,255,255,0,255,255,0,254,254,0,255,254,254,255,254,254,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,68,172,0,0,0,0,0,0,5,0,0,0,210,0,0,0,248,87,15,0,65,0,0,0,176,179,0,0,0,0,0,0,9,0,0,0,20,1,0,0,104,95,18,0,66,0,0,0,176,179,0,0,0,0,0,0,9,0,0,0,160,0,0,0,0,174,12,0,67,0,0,0,176,179,0,0,0,0,0,0,9,0,0,0,65,1,0,0,176,108,16,0,68,0,0,0,128,187,0,0,0,0,0,0,16,0,0,0,45,1,0,0,32,190,8,0,69,0,0,0,68,172,0,0,0,0,0,0,20,0,0,0,77,1,0,0,160,190,8,0,69,0,0,0,168,147,0,0,0,0,0,0,16,0,0,0,240,0,0,0,64,191,8,0,69,0,0,0,0,125,0,0,0,0,0,0,20,0,0,0,240,0,0,0,192,191,8,0,69,0,0,0,34,86,0,0,0,0,0,0,20,0,0,0,240,0,0,0,96,192,8,0,69,0,0,0,128,62,0,0,0,0,0,0,20,0,0,0,240,0,0,0,0,193,8,0,69,0,0,0,17,43,0,0,0,0,0,0,20,0,0,0,240,0,0,0,160,193,8,0,69,0,0,0,64,31,0,0,0,0,0,0,20,0,0,0,240,0,0,0,64,194,8,0,69,0,0,0,128,187,0,0,0,0,0,0,16,0,0,0,250,0,0,0,240,188,8,0,70,0,0,0,68,172,0,0,0,0,0,0,15,0,0,0,250,0,0,0,112,189,8,0,70,0,0,0,68,172,0,0,0,0,0,0,20,0,0,0,127,1,0,0,224,194,8,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,14,37,0,136,229,36,0,1,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,80,194,36,0,168,164,36], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1214208);
/* memory initializer */ allocate([1,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,208,137,36,0,48,110,36,0,1,0,0,0,1,0,0,0,3,0,0,0,0,32,0,0,112,83,36,0,136,58,36,0,1,0,0,0,2,0,0,0,4,0,0,0,0,2,0,0,96,29,36,0,104,227,35,0,1,0,0,0,1,0,0,0,3,0,0,0,0,64,0,0,16,197,35,0,176,173,35,0,1,0,0,0,2,0,0,0,4,0,0,0,0,4,0,0,192,151,35,0,72,130,35,0,1,0,0,0,5,0,0,0,6,0,0,0,4,0,0,0,168,107,35,0,0,88,35,0,0,0,0,0,1,0,0,0,2,0,0,0,8,0,0,0,240,70,35,0,152,52,35,0,1,0,0,0,1,0,0,0,4,0,0,0,0,0,2,0,224,28,35,0,184,241,34,0,1,0,0,0,1,0,0,0,4,0,0,0,0,0,1,0,56,218,34,0,200,203,34,0,1,0,0,0,1,0,0,0,4,0,0,0,0,0,4,0,64,187,34,0,48,169,34,0,1,0,0,0,1,0,0,0,4,0,0,0,0,0,8,0,32,151,34,0,56,137,34,0,1,0,0,0,1,0,0,0,4,0,0,0,0,0,64,0,48,122,34,0,56,105,34,0,1,0,0,0,1,0,0,0,4,0,0,0,0,0,128,0,192,84,34,0,200,44,34,0,1,0,0,0,7,0,0,0,8,0,0,0,0,0,16,0,0,25,34,0,0,11,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,252,33,0,168,233,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,54,19,0,8,55,19,0,216,54,19,0,192,54,19,0,168,54,19,0,144,54,19,0,120,54,19,0,0,0,0,0,16,158,35,0,32,138,35,0,24,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,16,158,35,0,0,115,35,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,16,158,35,0,104,95,35,0,144,76,35,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,96,58,35,0,16,39,35,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,136,252,34,0,88,224,34,0,44,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,181,35,0,112,0,0,0,184,176,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,134,102,138,187,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,180,84,69,102,136,170,171,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,248,101,69,85,102,119,120,153,153,170,171,187,188,203,191,255,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,134,85,85,85,102,103,119,136,136,153,153,153,153,153,154,170,155,187,203,187,204,204,207,255,204,207,252,188,204,251,185,252,168,118,102,86,102,103,103,119,120,136,136,137,136,137,153,153,154,154,154,154,170,170,170,170,154,169,171,169,169,152,134,255,202,136,119,119,119,119,119,136,136,136,136,153,153,153,152,153,153,154,153,153,153,153,153,153,153,153,153,152,136,135,101,255,251,170,169,136,136,137,153,152,153,154,169,154,169,170,169,154,170,169,170,169,153,153,169,154,153,153,153,152,136,119,100,255,255,252,187,186,185,170,171,170,170,186,171,171,171,203,186,171,187,187,170,186,170,170,170,169,170,153,153,153,136,135,100,255,255,255,255,203,187,187,187,187,187,203,187,188,187,204,251,204,207,207,204,252,252,207,203,204,187,187,203,187,170,153,134,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,252,184,160,0,0,251,149,103,139,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,247,85,86,119,137,186,187,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,184,101,85,85,86,119,120,137,154,170,170,188,188,203,188,207,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,134,85,85,85,85,86,103,119,119,136,137,154,153,153,170,187,187,171,191,203,250,204,252,236,239,251,188,255,188,187,169,255,152,118,102,102,101,102,102,118,119,119,119,136,136,136,137,153,153,153,153,169,153,153,154,153,153,170,170,169,153,152,118,255,249,135,119,119,119,119,119,119,119,120,136,136,136,136,153,153,137,153,153,153,153,137,153,153,153,152,153,152,119,119,101,255,202,169,153,137,136,136,152,137,153,152,153,153,153,153,154,153,153,169,154,169,153,153,153,153,169,153,153,152,136,119,100,255,203,169,169,170,170,170,154,171,170,154,187,171,171,187,171,186,187,186,170,186,186,170,170,169,169,153,153,153,136,119,100,255,255,255,188,251,203,187,187,187,186,186,171,191,203,187,187,188,191,204,203,203,204,187,187,251,203,188,202,188,170,169,134,255,255,255,255,255,207,255,252,255,255,207,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,250,240,0,0,155,101,103,171,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,181,84,86,103,136,169,171,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,168,101,68,69,86,103,120,137,153,169,170,187,187,171,188,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,249,118,85,84,85,85,86,103,119,119,136,137,153,152,153,138,153,187,171,188,171,186,170,187,203,204,187,204,187,172,186,151,251,151,118,102,102,102,102,103,119,119,119,136,136,136,136,153,137,153,153,153,153,153,153,154,152,153,153,169,153,136,135,101,255,202,152,135,119,119,135,136,136,136,136,136,153,153,153,153,153,153,153,153,153,153,153,153,153,153,153,153,136,135,119,100,255,252,202,170,153,153,153,153,153,170,154,170,170,170,170,170,170,170,170,170,170,170,170,170,170,153,153,153,137,136,135,100,255,255,251,255,188,252,187,203,187,202,203,188,204,191,188,187,187,190,188,203,204,187,252,188,204,171,203,171,187,170,169,151,255,255,255,255,187,207,251,204,252,207,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,3,3,3,1,1,1,1,0,3,1,1,3,3,3,3,71,136,118,82,18,53,68,67,52,69,119,103,102,135,135,125,138,137,157,221,156,192,0,0,124,204,199,101,204,34,35,70,50,34,70,123,182,187,187,188,204,204,204,204,204,192,0,0,187,187,180,67,37,91,90,171,91,34,34,43,186,170,70,91,187,187,187,187,187,176,0,0,153,137,136,137,49,136,136,137,136,56,136,19,40,136,136,40,136,136,136,136,153,144,0,0,153,137,136,137,136,136,136,57,152,136,136,136,8,136,136,129,153,136,153,153,153,32,0,0,170,217,134,205,221,221,152,118,67,101,53,99,35,68,51,36,69,68,69,89,168,144,0,0,153,137,136,137,152,136,136,137,152,8,136,136,40,136,136,131,25,152,136,153,153,144,0,0,186,170,170,170,170,170,170,165,164,1,74,170,83,74,164,170,90,170,170,170,170,176,0,0,170,170,170,170,170,170,170,154,170,163,49,49,52,52,169,165,68,74,170,170,170,160,0,0,238,222,237,222,238,237,221,222,232,238,231,100,71,67,48,67,67,54,126,238,238,144,0,0,103,135,135,102,101,85,68,69,101,84,84,50,52,102,99,85,68,84,52,69,86,96,0,0,86,102,101,84,51,52,51,51,51,52,68,69,86,102,103,119,119,119,120,137,137,96,0,0,120,137,152,101,101,50,34,50,51,51,69,119,119,139,154,239,255,255,255,255,238,240,0,0,157,216,141,87,86,85,68,69,34,34,35,52,87,120,136,221,221,221,221,221,221,208,0,0,220,204,140,204,135,101,85,84,35,68,33,35,70,86,135,124,140,140,204,204,204,208,0,0,221,205,204,205,220,199,100,88,49,37,51,34,68,86,102,109,221,221,220,220,220,208,0,0,185,153,166,103,120,118,120,136,102,85,68,67,35,51,51,51,52,69,86,102,136,176,0,0,221,205,220,205,220,204,119,197,83,18,35,51,51,70,101,117,141,221,221,220,220,208,0,0,221,205,204,205,220,204,140,133,85,51,33,35,51,68,86,86,86,141,221,204,220,208,0,0,238,222,221,222,221,221,221,135,117,85,67,34,33,37,101,85,102,119,216,141,221,144,0,0,255,255,255,255,255,255,252,170,152,119,85,67,51,51,33,51,52,102,137,175,255,192,0,0,87,119,118,102,101,85,68,68,68,68,68,68,51,68,67,68,68,69,86,102,119,80,0,0,87,118,102,101,68,68,67,51,51,51,51,52,69,86,103,119,119,137,136,137,153,96,0,0,138,153,136,119,102,68,67,50,50,34,51,69,103,137,235,239,255,255,255,255,255,240,0,0,255,251,186,167,120,102,101,84,34,33,35,68,86,138,158,175,251,255,255,255,255,240,0,0,255,175,253,223,172,152,119,102,68,49,17,53,103,136,138,170,255,255,255,255,255,240,0,0,255,239,238,239,168,142,151,102,67,34,33,35,69,103,151,127,255,238,233,238,238,240,0,0,170,169,151,101,69,69,103,102,85,84,68,68,51,51,51,51,68,69,86,104,139,176,0,0,238,222,237,222,237,221,216,119,101,67,17,34,52,102,120,135,238,238,238,157,237,224,0,0,255,255,255,220,255,174,234,152,118,84,49,17,52,86,136,153,155,255,255,191,255,240,0,0,255,255,255,207,223,255,253,154,118,101,67,33,18,53,86,103,137,153,175,175,255,240,0,0,255,255,254,239,219,186,170,153,118,85,67,34,34,51,51,68,85,103,138,250,251,160,0,0,87,119,119,102,101,85,84,68,68,68,67,51,51,52,68,68,85,85,102,119,136,96,0,0,88,119,118,102,85,84,68,51,51,35,51,51,69,86,102,119,136,136,136,136,153,96,0,0,154,169,169,136,118,85,68,51,34,34,35,69,86,153,157,191,255,255,255,255,255,240,0,0,253,187,170,186,169,135,119,84,51,33,18,69,104,138,170,203,255,207,255,255,254,240,0,0,255,255,255,239,254,169,152,135,101,65,2,69,119,136,172,175,255,255,255,255,255,240,0,0,191,252,171,251,186,171,184,136,118,82,1,53,120,153,171,170,207,187,207,252,252,240,0,0,186,202,152,117,33,53,119,119,118,101,84,68,68,52,68,68,69,86,120,136,154,192,0,0,223,207,204,255,171,201,185,152,151,117,32,19,86,137,137,170,252,188,175,204,255,208,0,0,255,255,187,251,255,251,186,168,119,84,33,17,69,103,136,138,239,187,255,187,255,240,0,0,255,255,255,255,252,251,203,185,136,101,49,18,35,53,103,136,170,172,252,255,255,240,0,0,255,255,252,239,255,187,170,169,118,85,50,34,34,51,52,86,103,104,154,170,205,224,0,0,88,119,119,102,102,85,84,68,68,67,51,51,51,52,68,85,85,102,103,120,136,96,0,0,87,119,118,102,85,85,84,67,51,34,51,52,69,85,102,103,119,119,120,136,153,80,0,0,172,153,152,135,118,102,84,67,50,33,35,69,102,137,153,153,170,191,255,255,255,240,0,0,255,255,255,185,170,152,119,101,66,33,18,69,120,138,186,170,251,255,255,255,255,240,0,0,255,255,255,253,188,187,185,152,118,50,1,70,121,171,187,190,255,255,255,255,255,240,0,0,255,255,255,255,207,170,170,153,118,66,1,54,121,154,171,191,253,255,255,255,255,240,0,0,204,220,185,117,16,71,137,153,152,135,118,102,85,85,85,86,102,103,120,153,190,224,0,0,255,255,255,252,204,255,251,171,135,100,16,35,103,153,154,173,206,255,252,255,255,240,0,0,255,255,255,251,255,253,250,185,151,101,32,19,86,120,170,155,251,252,255,255,255,240,0,0,255,255,255,207,252,201,172,152,135,84,49,18,35,69,103,120,154,170,235,255,255,224,0,0,255,255,254,202,250,153,152,136,101,68,50,34,34,51,69,86,103,120,153,187,171,160,0,0,72,119,118,102,101,85,85,68,68,67,51,51,51,52,69,85,85,102,103,119,120,96,0,0,104,135,119,119,102,85,84,67,51,34,35,52,69,85,102,120,136,152,136,136,137,96,0,0,171,186,170,186,153,135,118,84,51,33,18,70,103,137,154,223,255,255,255,255,255,240,0,0,255,255,255,253,202,152,135,118,84,33,17,69,120,138,154,255,255,255,255,255,255,240,0,0,255,255,255,255,255,188,170,153,118,50,1,70,120,154,171,239,255,255,255,255,255,240,0,0,255,255,255,255,255,202,233,137,118,82,1,53,104,152,154,175,255,255,255,255,255,240,0,0,173,203,169,116,16,70,137,154,169,152,119,118,102,85,85,86,102,102,120,136,138,208,0,0,255,255,255,255,255,253,170,170,135,99,16,36,103,137,175,223,255,255,255,255,255,240,0,0,255,255,255,255,255,255,187,154,151,100,32,19,103,137,154,207,255,255,255,255,255,240,0,0,255,255,255,255,255,255,153,135,118,67,33,18,52,86,103,136,137,174,207,253,239,240,0,0,255,255,255,255,255,253,170,135,102,84,49,18,51,68,85,103,119,137,171,171,207,192,0,0,88,135,135,119,118,102,85,85,68,67,50,34,51,68,85,86,103,119,120,136,136,112,0,0,103,118,102,118,102,85,68,68,51,34,34,52,86,103,119,137,136,153,171,154,171,112,0,0,155,169,136,136,135,119,101,84,67,33,18,69,103,154,154,239,255,255,255,255,238,240,0,0,255,255,252,203,186,170,152,135,101,49,2,86,137,171,203,188,255,255,255,255,255,240,0,0,255,255,255,255,250,170,154,152,118,66,1,54,121,175,207,255,255,255,255,255,255,240,0,0,255,255,255,255,250,120,169,152,118,82,1,53,120,142,203,191,239,255,255,255,255,240,0,0,140,186,153,116,16,54,137,154,169,153,136,135,118,102,102,102,102,86,102,120,137,192,0,0,255,255,255,255,255,249,138,169,136,99,16,36,103,139,188,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,201,153,118,84,16,36,86,120,154,170,255,255,255,255,239,240,0,0,255,255,255,255,255,255,255,217,135,84,32,34,69,103,119,137,172,171,251,255,255,240,0,0,255,255,255,255,255,255,173,171,134,84,33,18,52,69,102,119,103,119,136,153,154,144,0,0,87,119,118,102,101,85,85,85,84,67,50,35,51,68,85,85,102,103,136,119,119,80,0,0,53,68,69,85,84,68,68,67,51,51,35,68,104,153,170,170,203,171,175,254,235,224,0,0,119,102,103,102,102,102,84,68,51,34,18,69,104,170,190,175,255,255,255,255,238,240,0,0,255,234,152,136,135,119,101,85,68,50,2,70,120,137,170,191,255,255,255,255,255,240,0,0,255,255,255,255,171,171,153,118,101,66,1,69,120,170,173,172,254,255,255,255,255,240,0,0,255,255,255,255,252,235,186,169,134,66,1,54,119,138,187,255,255,255,255,255,255,240,0,0,172,187,152,116,16,54,119,137,153,153,136,119,118,102,102,85,86,103,137,170,171,192,0,0,255,255,255,255,223,201,153,153,136,100,16,36,85,104,137,187,173,191,191,255,255,240,0,0,255,255,255,255,255,255,151,101,101,84,32,35,69,86,119,119,142,203,190,223,255,240,0,0,255,255,255,255,255,255,255,186,118,83,33,19,52,85,69,85,103,121,171,250,251,160,0,0,255,255,255,255,255,255,191,254,135,84,33,35,51,68,85,85,68,69,87,138,170,128,0,0,121,153,153,151,119,118,84,68,68,68,50,51,51,51,68,69,86,103,136,119,120,96,0,0,52,84,69,85,84,68,68,51,50,67,52,68,86,119,187,182,204,204,204,200,203,112,0,0,126,103,85,101,68,85,68,51,34,35,35,87,152,221,221,222,237,221,221,221,221,224,0,0,255,239,238,151,117,84,67,51,51,50,18,88,136,238,174,239,255,255,255,254,238,240,0,0,255,255,255,255,250,136,135,102,83,34,2,87,157,255,255,239,239,255,255,255,255,240,0,0,255,255,255,255,255,250,169,120,118,66,1,54,153,154,255,223,255,253,255,255,255,240,0,0,171,170,168,117,16,38,121,136,119,119,102,102,87,120,136,137,152,154,187,187,221,192,0,0,255,255,254,239,255,254,168,120,118,84,32,34,69,110,142,239,255,249,255,255,255,240,0,0,255,255,255,239,255,255,250,231,102,100,32,35,52,86,120,136,175,252,255,255,175,240,0,0,238,222,237,222,237,141,221,217,230,99,33,35,67,52,53,85,101,71,238,237,237,224,0,0,221,205,220,205,221,204,204,205,221,118,67,68,68,67,52,51,34,51,53,216,204,208,0,0,107,119,187,182,150,85,85,84,68,68,51,67,51,51,69,52,68,104,87,120,134,80,0,0,74,170,170,154,68,68,69,35,36,34,163,58,68,153,153,154,170,170,170,170,170,160,0,0,170,69,52,148,74,74,50,35,50,36,74,170,170,169,153,154,170,170,170,170,170,160,0,0,170,170,170,170,74,164,68,33,67,50,35,90,170,170,153,170,170,170,170,170,170,160,0,0,221,221,221,221,221,125,141,116,33,17,53,125,221,221,221,221,221,221,221,221,221,208,0,0,254,238,238,238,238,238,238,233,100,50,1,87,232,238,238,238,238,238,238,238,238,240,0,0,238,222,233,85,16,39,152,101,72,174,153,136,119,135,121,137,234,238,174,238,238,224,0,0,203,187,187,187,187,187,187,187,182,69,17,19,68,59,187,187,187,187,187,187,187,192,0,0,187,171,170,170,170,170,170,170,170,90,49,18,35,52,170,170,170,170,170,170,170,176,0,0,187,187,187,171,187,187,170,171,187,187,181,85,100,34,36,85,50,20,187,187,187,176,0,0,170,170,169,154,170,169,153,154,74,170,163,51,50,52,53,68,66,36,164,170,170,160,0,0,170,154,153,154,169,84,148,149,68,83,52,83,35,52,52,69,51,74,153,153,169,160,0,0,87,171,102,82,18,68,69,67,51,69,119,166,119,167,167,101,119,187,183,187,123,176,0,0,187,91,187,91,187,33,34,69,98,38,86,187,187,186,170,187,187,187,187,187,187,176,0,0,170,58,153,147,25,153,153,153,153,36,25,51,153,147,153,153,153,153,153,153,153,160,0,0,119,103,102,103,118,102,102,103,119,102,102,102,102,102,102,16,119,118,119,119,119,112,0,0,119,103,102,103,118,102,102,103,119,102,102,102,97,102,102,103,7,118,119,119,119,112,0,0,221,221,214,205,221,217,136,201,100,118,52,66,18,84,83,52,84,86,102,121,221,208,0,0,136,120,119,120,119,119,119,120,135,7,119,119,33,119,119,120,136,135,135,136,136,128,0,0,170,154,153,154,153,153,153,154,153,1,153,153,67,153,52,153,148,153,153,153,170,160,0,0,153,137,136,137,136,136,136,137,136,130,136,33,130,130,131,136,130,136,136,136,153,144,0,0,221,221,221,205,221,221,204,205,221,221,214,116,86,100,32,84,66,56,221,221,221,208,0,0,121,135,150,118,118,85,102,68,85,68,85,50,36,136,98,85,69,67,71,102,118,96,0,0,87,102,101,84,67,52,51,51,51,51,68,69,85,102,119,119,119,119,152,136,121,96,0,0,136,152,141,101,102,50,51,34,35,51,69,103,120,104,141,205,221,221,221,221,221,208,0,0,141,205,220,197,86,70,69,84,34,34,34,69,87,108,204,205,221,221,221,220,204,208,0,0,204,204,203,188,204,199,181,84,18,51,34,37,86,182,123,183,204,204,204,204,204,192,0,0,187,171,186,171,187,165,165,85,33,43,51,35,68,85,166,91,187,187,187,187,187,176,0,0,172,171,198,102,135,135,119,152,102,84,67,67,51,50,51,51,68,69,102,104,121,160,0,0,187,187,187,171,187,187,186,75,67,34,34,50,68,52,165,166,187,187,187,187,187,176,0,0,187,171,170,171,186,170,166,101,84,67,33,35,52,52,85,86,107,187,182,186,186,176,0,0,221,205,220,205,221,204,204,198,102,68,67,50,33,37,101,70,84,141,221,220,215,192,0,0,255,239,238,239,238,238,238,154,247,102,85,67,51,34,34,51,52,120,152,238,254,144,0,0,87,103,102,118,101,85,68,84,68,67,67,52,67,68,68,68,69,69,85,103,119,96,0,0,120,136,118,102,85,84,68,51,34,35,51,68,85,103,103,120,152,152,153,154,169,144,0,0,153,170,171,151,101,85,68,50,34,34,51,69,103,137,255,239,255,255,255,255,255,240,0,0,255,252,187,168,136,119,118,84,50,17,35,70,119,138,248,207,255,255,255,255,255,240,0,0,238,222,237,222,233,221,119,101,67,33,18,52,87,125,120,222,238,238,238,238,238,224,0,0,238,238,238,222,238,231,125,150,84,34,17,36,86,135,221,222,238,238,238,238,238,224,0,0,203,170,151,101,68,69,119,118,102,85,68,51,51,51,51,51,68,85,104,153,154,192,0,0,221,221,221,125,221,220,204,102,102,67,17,34,52,86,140,205,221,221,221,221,221,208,0,0,255,239,254,239,255,238,233,136,118,84,49,17,52,87,119,143,175,255,255,254,254,240,0,0,254,238,238,234,174,238,169,233,135,101,67,17,34,53,86,102,136,154,238,234,238,240,0,0,255,255,255,234,255,251,234,152,118,85,67,34,34,51,51,68,70,120,170,255,251,176,0,0,121,153,119,119,102,85,84,68,67,67,51,51,51,52,68,85,85,102,102,121,153,128,0,0,104,135,119,102,85,85,84,67,50,34,51,52,69,102,119,120,136,137,152,136,136,96,0,0,170,171,171,169,136,102,101,67,34,33,35,70,120,169,191,239,255,255,255,239,255,240,0,0,253,255,255,188,153,152,118,101,66,33,18,70,103,153,255,239,255,255,191,255,255,240,0,0,255,255,255,255,190,250,185,135,101,49,2,86,121,154,175,234,255,255,255,207,255,240,0,0,155,174,190,155,187,171,170,152,118,82,1,53,136,153,154,172,186,187,234,186,234,176,0,0,204,188,167,101,33,70,136,135,119,101,68,68,67,51,68,69,85,86,120,154,155,192,0,0,158,158,169,171,170,169,157,153,135,101,16,35,104,136,152,154,169,170,218,173,170,144,0,0,255,255,254,239,255,252,187,169,167,101,48,18,86,120,154,154,255,255,255,255,255,240,0,0,255,255,255,255,255,255,204,186,152,118,65,17,36,71,119,137,187,237,207,255,255,240,0,0,255,207,255,239,207,206,155,169,135,101,66,17,35,68,85,102,103,154,171,207,204,208,0,0,104,120,119,118,102,85,85,84,68,51,51,50,51,52,85,85,102,102,119,119,136,96,0,0,104,119,118,102,85,85,84,68,50,34,51,52,85,86,102,102,103,120,136,153,153,80,0,0,203,202,170,169,151,119,102,84,50,33,19,70,121,170,171,191,205,253,207,255,255,240,0,0,255,255,252,255,187,169,168,135,101,49,2,86,137,171,187,187,188,255,255,255,255,240,0,0,255,255,251,255,205,207,153,135,101,66,1,69,103,154,187,175,189,191,252,255,255,240,0,0,255,255,255,255,255,207,249,168,134,66,1,54,120,138,191,159,255,255,255,255,255,176,0,0,207,219,186,133,16,71,137,153,153,135,102,101,85,85,85,86,102,119,137,172,206,240,0,0,255,255,255,207,255,191,187,255,152,99,16,36,89,153,191,251,191,255,255,255,255,240,0,0,255,255,255,255,255,203,187,175,151,101,32,19,86,120,153,171,253,175,255,255,255,240,0,0,255,255,255,255,255,204,187,170,151,101,48,19,68,86,136,137,169,191,255,207,252,240,0,0,255,255,253,255,250,186,186,185,135,101,50,17,35,69,86,103,119,154,186,191,255,240,0,0,87,120,119,102,102,85,85,68,68,67,51,35,51,68,69,85,86,102,102,119,120,96,0,0,104,135,135,119,102,85,84,68,50,34,35,68,69,86,102,120,136,136,136,136,136,80,0,0,154,185,169,168,135,118,101,84,67,33,18,69,104,136,170,223,255,255,255,255,255,240,0,0,255,255,255,252,207,186,152,119,101,49,2,86,137,172,239,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,185,135,118,66,1,54,137,170,189,255,223,255,255,255,255,240,0,0,255,255,191,255,239,191,172,153,135,66,1,53,121,170,187,255,255,255,255,255,255,240,0,0,205,204,185,116,16,70,138,169,153,152,119,102,102,85,85,85,102,103,137,154,171,208,0,0,255,255,255,255,255,255,187,218,168,83,16,36,104,154,174,255,254,255,255,255,255,240,0,0,255,255,255,255,255,255,252,251,152,116,16,35,87,137,171,188,255,255,207,255,255,240,0,0,255,255,255,255,255,255,187,186,152,101,32,19,86,120,137,154,172,239,251,255,223,240,0,0,255,255,255,255,255,255,187,153,134,84,33,18,52,69,86,103,103,153,171,235,255,176,0,0,87,135,119,119,102,102,101,85,68,67,50,34,51,68,85,86,103,119,119,136,153,112,0,0,120,136,136,119,118,101,84,68,51,50,18,52,70,120,153,154,186,172,171,203,170,144,0,0,154,152,136,152,135,119,101,84,67,33,18,69,103,139,255,239,255,255,255,255,255,240,0,0,255,255,255,189,169,153,135,119,85,65,2,70,121,171,252,255,255,255,255,255,255,240,0,0,255,254,255,255,219,154,186,152,118,66,1,54,121,187,203,252,255,252,255,255,255,240,0,0,255,255,255,254,255,250,154,170,135,66,1,53,120,218,255,254,255,255,255,255,255,240,0,0,188,204,169,116,16,54,138,170,169,153,136,119,118,102,101,102,85,102,120,136,171,192,0,0,255,255,255,255,255,255,191,170,151,99,16,36,103,136,155,253,253,255,255,255,255,240,0,0,255,255,255,255,251,255,252,187,151,100,16,35,103,136,170,171,255,255,239,255,255,240,0,0,255,255,255,255,255,207,255,189,167,100,32,20,85,119,120,138,170,171,253,204,191,240,0,0,255,255,255,255,255,255,255,234,118,84,33,18,52,69,86,103,119,138,170,153,186,144,0,0,104,136,119,102,102,85,85,85,84,67,34,35,52,68,68,86,119,119,120,153,153,96,0,0,69,86,102,101,85,84,68,68,68,66,18,53,104,142,154,188,235,187,235,187,190,176,0,0,135,119,118,118,102,102,85,84,67,49,18,69,86,169,238,222,238,238,238,238,238,224,0,0,255,255,175,152,151,120,117,85,68,50,2,69,104,142,156,239,223,255,255,255,255,240,0,0,255,255,255,255,251,186,152,119,101,66,1,69,105,156,155,223,191,255,255,255,255,240,0,0,255,255,251,255,255,202,170,168,118,82,1,53,103,138,234,191,255,255,254,255,255,240,0,0,169,171,152,116,16,54,137,153,153,136,135,135,118,102,102,85,86,103,121,155,155,176,0,0,255,255,255,255,255,255,184,136,135,84,16,36,86,119,137,191,255,236,255,255,255,240,0,0,255,255,255,220,255,251,219,185,134,83,32,35,68,86,136,120,170,255,171,255,255,240,0,0,255,255,255,255,255,175,191,250,151,100,32,35,68,85,86,103,119,137,155,185,255,240,0,0,238,238,238,238,238,238,238,217,117,67,33,35,52,68,68,85,85,102,102,120,138,128,0,0,121,137,152,136,119,119,84,68,68,67,34,51,51,68,69,69,102,104,119,152,136,96,0,0,37,69,87,69,69,85,67,51,51,51,52,68,85,187,187,107,187,187,187,187,187,176,0,0,134,118,117,85,85,101,116,68,51,50,18,53,108,204,204,205,221,204,204,204,204,208,0,0,238,222,221,142,118,85,67,68,50,50,18,70,135,153,157,222,238,238,221,221,221,224,0,0,255,255,254,239,255,169,150,85,67,50,2,69,136,238,233,239,255,255,255,255,255,240,0,0,255,255,255,255,255,250,175,137,102,66,1,54,217,138,255,239,255,255,255,255,255,240,0,0,170,234,249,116,16,53,121,152,135,102,102,85,86,103,119,119,136,153,170,252,238,176,0,0,255,255,255,239,255,255,233,151,247,101,32,19,86,121,234,239,255,255,255,255,255,240,0,0,238,238,237,222,238,237,221,222,117,99,17,34,52,69,103,120,158,238,238,238,238,224,0,0,238,222,221,222,237,216,221,222,135,84,32,35,70,70,86,103,118,121,142,237,237,224,0,0,238,222,221,222,221,221,221,217,152,84,50,35,69,68,52,67,35,102,54,216,221,144,0,0,123,123,167,119,106,87,86,85,69,67,51,51,51,51,68,67,53,187,186,170,183,80,0,0,36,163,68,68,170,73,52,67,36,66,53,169,153,73,153,154,170,170,170,170,170,160,0,0,153,57,148,148,57,67,146,51,41,34,57,153,153,153,136,153,153,153,153,153,153,144,0,0,153,153,153,153,73,73,51,52,51,33,35,153,153,153,152,153,153,153,153,153,153,144,0,0,220,204,204,204,204,204,204,198,50,33,18,69,199,204,204,204,204,204,204,204,204,208,0,0,237,221,221,221,221,221,215,221,117,66,1,56,221,125,221,221,221,221,221,221,221,224,0,0,204,140,135,100,16,55,134,102,103,105,120,119,118,102,102,103,104,119,136,204,204,192,0,0,187,171,170,171,170,170,170,170,170,164,32,34,68,165,170,170,170,170,170,170,186,176,0,0,187,187,187,187,187,187,187,187,187,75,51,3,35,70,75,91,187,187,187,187,187,176,0,0,187,187,187,171,187,187,170,171,187,187,178,67,68,50,19,70,52,53,187,187,187,176,0,0,170,170,170,170,170,170,169,154,170,170,164,35,50,165,50,162,36,163,170,74,170,160,0,0,169,89,153,153,153,84,73,69,85,69,67,57,82,51,67,68,37,89,89,153,89,160,0,0,88,118,91,83,33,37,84,67,51,72,136,86,103,107,135,188,124,140,204,204,140,176,0,0,204,204,108,76,204,18,18,69,83,53,124,204,204,204,187,204,204,204,204,204,204,192,0,0,170,170,164,161,68,85,169,154,170,162,34,36,165,164,73,170,170,170,170,170,170,160,0,0,153,136,51,136,136,136,136,40,136,136,136,33,51,136,131,130,136,136,136,136,137,144,0,0,102,86,85,86,101,85,85,86,6,101,85,85,85,85,85,86,102,102,102,102,102,96,0,0,238,157,166,157,218,217,151,85,66,100,67,50,36,68,51,68,102,85,88,125,221,160,0,0,136,120,119,120,119,119,119,120,130,7,119,119,114,39,119,120,135,119,135,136,136,128,0,0,187,171,170,170,170,170,170,170,68,1,58,170,74,74,69,170,170,170,170,170,170,176,0,0,153,153,153,153,153,153,153,137,153,146,57,33,73,67,51,153,52,57,153,153,153,144,0,0,238,238,237,222,238,237,221,222,238,238,151,117,85,117,32,52,99,38,142,238,238,224,0,0,105,184,119,139,133,86,85,68,101,68,51,50,35,103,164,116,69,68,69,104,134,112,0,0,103,118,102,84,67,67,51,51,51,51,68,68,85,102,103,103,119,119,137,137,153,96,0,0,169,153,153,102,102,67,51,34,34,51,52,87,120,255,191,255,255,255,255,255,255,240,0,0,254,233,233,135,101,85,68,68,50,34,34,52,86,121,142,234,238,238,238,238,238,240,0,0,238,222,221,216,221,117,84,84,51,68,49,19,69,102,136,137,142,221,221,221,237,224,0,0,204,188,187,188,203,117,101,69,50,36,67,18,70,84,119,188,204,204,203,203,203,192,0,0,169,139,151,86,136,118,119,102,85,68,51,51,51,51,51,51,69,86,103,138,202,192,0,0,221,205,204,205,220,204,104,85,83,33,35,51,51,69,119,103,221,221,221,220,220,208,0,0,238,222,221,222,233,141,216,103,68,50,34,34,51,68,70,135,238,238,238,221,221,224,0,0,255,239,238,239,254,238,233,120,103,84,67,34,18,53,83,85,86,122,254,238,254,240,0,0,255,255,255,255,255,255,186,251,135,102,84,51,51,34,34,51,70,103,122,207,207,240,0,0,103,119,119,102,102,85,85,68,67,68,51,52,67,68,67,68,68,85,102,118,136,112,0,0,120,119,118,102,85,68,68,51,51,34,51,52,69,103,120,136,136,153,137,169,169,112,0,0,169,155,153,135,119,84,68,51,34,34,35,69,103,159,255,255,255,255,255,255,255,240,0,0,255,255,253,170,152,135,119,101,50,17,35,68,87,154,206,255,255,255,255,255,255,240,0,0,255,255,255,255,250,136,119,101,84,49,17,53,87,136,143,223,252,159,255,255,255,240,0,0,255,239,238,239,254,153,135,119,84,34,17,36,102,119,120,234,249,255,238,238,254,240,0,0,171,170,151,101,68,69,102,101,84,68,67,51,51,51,51,68,85,102,120,139,171,176,0,0,238,222,237,222,152,141,221,103,102,67,17,34,52,87,119,142,238,238,238,237,221,224,0,0,255,255,255,239,251,255,187,152,102,84,49,17,52,86,152,191,220,191,191,255,255,240,0,0,255,255,255,255,255,255,203,170,136,102,50,17,35,53,102,119,153,206,254,205,255,240,0,0,255,255,255,255,255,254,202,169,118,84,66,34,34,51,52,85,86,119,155,191,255,192,0,0,105,136,119,119,118,101,85,68,67,67,51,51,51,52,68,68,85,103,119,136,137,112,0,0,121,152,135,119,102,85,68,67,51,34,35,51,69,102,119,136,137,153,154,169,153,112,0,0,187,251,186,169,152,118,101,68,50,33,34,53,121,174,204,255,255,255,255,255,255,240,0,0,255,207,250,170,153,136,119,101,51,33,18,68,87,137,171,190,207,255,255,255,255,240,0,0,255,255,255,191,219,169,153,134,101,65,2,69,120,137,202,255,255,255,255,255,255,240,0,0,255,255,255,255,255,171,169,152,118,82,1,53,104,137,158,239,191,255,255,255,255,192,0,0,219,202,152,117,33,70,119,118,102,84,68,68,51,52,68,69,102,119,137,172,203,208,0,0,255,255,255,255,255,255,187,152,119,101,16,35,86,137,170,255,252,255,255,255,255,240,0,0,255,255,255,255,255,252,187,202,135,101,48,18,86,120,169,186,253,207,255,255,255,240,0,0,255,255,255,255,254,237,170,169,151,100,49,18,35,69,86,120,169,172,255,255,255,240,0,0,255,255,255,255,254,252,203,168,101,84,50,18,35,52,69,86,119,136,172,223,223,224,0,0,104,152,136,119,119,102,85,84,68,67,50,34,51,68,85,86,102,119,120,137,153,112,0,0,138,169,136,135,102,101,84,67,51,34,35,51,69,85,103,120,136,136,136,153,153,96,0,0,207,191,202,170,152,135,118,84,51,33,18,69,120,138,191,255,255,255,255,255,255,240,0,0,255,255,255,239,190,186,153,119,101,49,2,86,137,155,188,255,255,255,255,255,255,240,0,0,255,255,255,255,255,252,187,151,118,50,1,70,136,155,171,255,255,255,255,255,255,240,0,0,255,255,255,255,255,253,252,168,151,66,1,53,120,154,188,223,255,255,255,255,255,240,0,0,220,203,185,117,16,71,137,137,136,118,102,85,85,85,85,102,119,120,154,172,254,240,0,0,255,255,255,255,255,251,202,169,135,99,16,36,103,138,202,255,254,207,255,255,255,240,0,0,255,255,255,255,255,255,253,170,152,116,32,19,87,138,158,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,188,169,135,101,48,19,68,86,120,154,190,239,255,255,255,240,0,0,255,255,255,255,255,255,187,152,101,84,49,18,51,68,85,103,120,154,172,252,255,240,0,0,104,136,135,119,119,118,85,84,68,67,50,34,51,68,69,86,103,120,137,154,187,144,0,0,138,153,136,119,118,102,85,67,51,34,34,51,69,103,119,136,136,153,170,154,170,128,0,0,188,170,171,169,152,135,102,84,51,33,18,69,137,207,255,255,255,255,255,255,255,240,0,0,255,255,239,252,204,186,152,135,101,49,2,86,121,187,239,255,255,255,255,255,255,240,0,0,255,255,255,223,255,253,186,152,118,66,1,54,120,154,251,255,255,255,255,255,255,240,0,0,255,255,255,255,255,250,187,169,135,66,1,53,120,171,251,207,255,255,255,255,255,240,0,0,221,236,201,116,16,71,137,153,153,135,118,102,85,85,85,86,103,120,137,188,205,224,0,0,255,255,255,255,255,255,255,218,152,99,16,36,88,154,191,239,255,191,255,255,255,240,0,0,255,255,255,255,255,255,254,219,151,116,16,35,87,154,171,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,255,202,168,101,32,19,86,119,137,155,206,207,255,255,255,240,0,0,255,255,255,255,255,203,154,170,118,84,33,18,52,69,86,102,120,153,175,236,239,176,0,0,120,136,135,119,102,102,101,85,84,67,34,34,51,68,85,103,119,136,152,153,170,128,0,0,103,119,134,102,102,101,84,68,51,50,18,52,87,153,172,154,172,251,207,238,235,160,0,0,170,153,136,135,119,119,102,85,67,33,18,53,138,251,255,255,255,255,255,255,255,240,0,0,255,250,218,153,152,119,118,101,83,50,2,69,103,154,207,223,255,255,255,255,255,240,0,0,255,255,255,207,251,187,233,135,118,66,1,54,137,187,191,255,255,255,255,255,255,240,0,0,255,255,255,255,255,255,170,169,118,82,1,53,103,138,154,201,255,254,255,255,255,240,0,0,236,204,169,116,16,55,136,137,153,136,135,118,102,85,85,86,119,120,170,254,255,240,0,0,255,255,255,255,255,255,237,186,135,100,16,36,70,119,171,255,255,255,239,255,255,240,0,0,255,255,255,255,255,254,207,255,136,100,16,36,70,120,136,170,191,204,255,255,255,240,0,0,255,255,255,255,255,255,254,220,167,101,32,20,85,87,119,136,154,170,187,255,255,240,0,0,255,255,255,255,255,252,249,151,118,83,33,19,52,69,85,102,102,119,136,170,220,160,0,0,157,172,186,152,136,119,101,84,84,67,33,35,52,69,85,102,103,121,153,157,187,128,0,0,71,124,101,69,69,69,69,51,67,34,35,68,87,119,204,184,204,204,204,204,204,192,0,0,137,136,103,104,103,118,85,85,67,33,18,70,142,234,238,239,238,238,238,238,238,240,0,0,238,222,217,216,135,102,100,85,68,66,2,69,103,141,221,222,238,238,238,237,221,224,0,0,255,255,250,255,207,183,152,102,84,66,1,87,137,250,255,239,251,255,255,255,255,240,0,0,255,255,255,255,255,253,170,136,118,66,1,54,120,255,255,234,255,255,255,255,255,240,0,0,188,170,184,117,16,53,120,136,135,102,102,85,85,102,119,119,136,153,154,219,187,208,0,0,255,255,255,239,255,255,253,153,135,101,16,35,86,120,158,175,255,255,255,255,255,240,0,0,255,239,254,239,255,238,233,232,101,84,32,35,52,103,122,153,159,249,255,254,254,240,0,0,255,239,238,239,254,238,233,239,135,83,32,35,85,85,86,104,152,138,159,254,254,240,0,0,255,255,255,255,255,255,250,138,119,84,49,35,68,52,68,68,67,69,87,250,251,240,0,0,124,183,139,118,118,102,85,84,68,67,51,50,51,68,84,68,68,87,152,135,203,80,0,0,70,171,106,107,101,84,84,50,34,50,67,68,164,106,170,171,187,187,187,170,170,176,0,0,103,102,107,108,86,181,85,52,50,33,35,100,187,187,187,188,204,204,204,204,203,192,0,0,204,204,204,188,118,87,85,84,67,33,18,70,124,187,187,188,204,204,204,204,204,192,0,0,221,221,221,221,221,221,221,119,67,34,2,87,141,221,221,221,221,221,221,221,221,208,0,0,221,205,204,205,204,204,204,204,101,66,1,60,124,204,204,204,204,204,204,204,220,208,0,0,238,142,217,117,16,53,119,102,104,119,102,101,102,101,102,104,136,238,174,237,221,224,0,0,221,221,221,221,221,221,221,216,221,85,32,20,86,77,125,221,221,221,221,221,221,208,0,0,204,204,204,188,204,204,203,188,199,99,32,35,68,85,118,124,204,204,204,204,204,192,0,0,187,187,186,171,187,186,170,171,181,182,49,34,52,67,52,84,69,75,187,187,187,176,0,0,204,188,203,188,203,187,187,183,102,85,66,34,35,52,67,53,84,85,108,203,203,192,0,0,203,187,107,183,187,107,101,85,52,51,67,50,35,52,85,68,70,187,187,182,187,192,0,0,136,120,113,120,119,119,119,120,39,113,119,23,119,119,119,120,136,119,136,135,136,128,0,0,153,137,136,137,136,130,136,131,131,18,34,56,136,136,136,136,136,136,136,136,152,144,0,0,153,137,136,137,136,136,56,137,34,17,40,136,136,136,136,137,152,136,136,152,152,144,0,0,170,154,153,154,57,153,153,51,153,66,2,153,153,153,153,154,169,153,153,153,169,160,0,0,170,154,153,154,153,153,153,154,169,146,1,52,153,153,153,154,169,153,154,169,169,160,0,0,170,170,170,170,48,74,170,154,170,164,67,67,53,74,58,170,170,170,170,170,170,160,0,0,170,154,153,154,153,153,153,154,153,147,17,19,52,153,153,154,153,153,153,153,169,160,0,0,153,137,136,137,136,136,136,137,136,136,49,18,136,24,136,137,152,136,137,153,152,144,0,0,136,120,119,120,119,119,119,120,119,119,113,17,114,119,119,120,135,119,136,136,136,128,0,0,170,154,153,153,153,153,153,153,153,57,146,33,25,57,153,148,147,153,153,153,170,160,0,0,136,120,119,120,119,119,119,120,119,114,119,114,23,39,119,120,135,113,120,135,136,128,0,0,4,250,4,245,255,251,3,3,254,5,251,0,9,1,6,3,252,255,251,253,254,251,249,1,6,249,30,227,12,253,245,4,253,7,236,23,2,0,1,250,242,251,15,238,6,7,15,246,242,22,249,254,252,9,6,244,6,250,0,245,0,251,4,0,214,51,105,231,7,248,0,0,127,240,2,30,170,0,0,0,228,0,189,252,233,16,0,0,153,6,184,5,227,2,0,0,103,3,113,11,40,1,0,0,79,0,232,1,51,15,0,0,2,1,255,2,2,1,255,2,0,255,1,0,0,255,1,0,0,1,255,0,0,1,255,0,2,255,1,2,2,255,1,2,5,4,255,5,5,4,255,5,3,255,4,3,3,255,4,3,3,4,255,3,3,4,255,3,5,255,4,5,5,255,4,5,8,7,255,8,8,7,255,8,6,255,7,6,6,255,7,6,6,7,255,6,6,7,255,6,8,255,7,8,8,255,7,8,0,2,0,2,0,2,0,2,2,0,2,0,2,0,2,0,1,255,1,255,1,255,1,255,255,1,255,1,255,1,255,1,3,5,3,5,3,5,3,5,5,3,5,3,5,3,5,3,4,255,4,255,4,255,4,255,255,4,255,4,255,4,255,4,6,8,6,8,6,8,6,8,8,6,8,6,8,6,8,6,7,255,7,255,7,255,7,255,255,7,255,7,255,7,255,7,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,1,0,255,255,255,255,255,5,4,3,255,255,255,255,255,8,7,6,255,255,255,255,255,0,1,2,3,7,10,8,11,3,7,11,15,17,33,21,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,3,3,8,11,8,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1224448);
/* memory initializer */ allocate([11,11,15,15,21,37,21,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,7,10,7,10,3,3,7,7,17,33,17,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,7,10,7,10,3,11,3,11,17,33,17,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,7,10,8,11,3,7,11,15,17,33,21,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,3,3,8,11,8,11,11,11,15,15,21,37,21,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,7,10,7,10,3,3,7,7,17,33,17,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,7,10,7,10,3,11,3,11,17,33,17,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,158,36,0,176,124,35,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,200,164,34,0,32,230,33,0,12,0,0,0,1,0,0,0,255,255,255,127,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,11,33,0,112,0,0,0,0,0,0,0,100,66,52,0,4,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,112,33,0,112,0,0,0,224,215,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,35,37,0,128,213,35,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,112,35,37,0,72,229,34,0,0,35,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,35,37,0,96,133,33,0,8,10,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,112,35,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,150,36,0,112,0,0,0,208,216,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,158,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,3,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,195,37,0,176,161,37,0,64,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,224,195,37,0,248,121,37,0,96,54,37,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,224,195,37,0,56,13,37,0,24,228,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,224,195,37,0,224,192,36,0,176,163,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,224,195,37,0,216,136,36,0,64,109,36,0,72,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,16,0,1,0,216,136,36,0,136,82,36,0,128,57,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,136,36,0,56,28,36,0,96,225,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,136,36,0,8,196,35,0,88,172,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,136,36,0,216,150,35,0,216,128,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,136,36,0,128,106,35,0,24,87,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,136,36,0,216,69,35,0,136,51,35,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,136,36,0,56,28,35,0,72,240,34,0,68,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,217,34,0,192,202,34,0,76,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,152,217,34,0,248,121,37,0,120,186,34,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,152,217,34,0,88,168,34,0,56,150,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,152,217,34,0,88,136,34,0,64,121,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,152,217,34,0,0,104,34,0,120,83,34,0,80,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,72,43,34,0,208,23,34,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,104,10,34,0,208,23,34,0,88,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,80,251,33,0,232,232,33,0,104,0,0,0,3,0,0,0,0,0,0,0,0,0,40,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,160,218,33,0,8,207,33,0,112,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,216,196,33,0,120,188,33,0,32,174,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,196,33,0,144,139,33,0,240,124,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,196,33,0,232,115,33,0,248,105,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,216,196,33,0,24,96,33,0,16,86,33,0,116,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,16,0,1,0,144,77,33,0,120,188,33,0,112,69,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,77,33,0,128,106,35,0,248,60,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,77,33,0,8,48,33,0,136,16,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,144,77,33,0,96,3,33,0,88,251,32,0,120,0,0,0,1,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,128,243,32,0,136,235,32,0,124,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,229,32,0,96,222,32,0,128,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,232,215,32,0,104,206,32,0,132,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,184,195,32,0,232,168,32,0,136,0,0,0,1,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,178,36,0,112,0,0,0,56,218,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,2,56,18,26,34,27,35,28,36,29,45,7,54,39,8,24,25,33,41,11,42,12,43,13,44,14,53,15,62,47,16,32,40,10,49,4,50,5,51,6,52,22,61,38,23,55,1,17,48,3,57,19,58,20,59,21,60,37,30,46,31,63,0,0,0,0,0,0,0,0,0,8,16,1,9,24,32,17,2,25,40,48,56,33,10,3,18,41,49,57,26,11,4,19,34,42,50,58,27,12,5,20,35,43,51,59,28,13,6,21,36,44,52,60,29,14,22,37,45,53,61,30,7,15,38,46,54,62,23,31,39,47,55,63,0,0,0,0,0,0,0,0,0,4,1,8,12,5,9,13,2,6,10,14,3,7,11,15,0,0,0,0,0,0,0,0,144,73,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,40,37,0,248,214,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,96,230,34,0,72,36,34,0,240,133,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,230,34,0,200,10,33,0,184,164,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,230,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,73,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,180,36,0,112,0,0,0,232,225,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,6,2,9,2,14,2,0,0,0,0,1,5,6,7,8,9,9,11,5,5,7,8,9,9,11,12,6,7,8,9,9,11,11,12,7,7,8,9,9,11,12,13,7,8,9,9,10,11,13,16,8,9,9,10,11,13,16,19,8,9,9,11,12,15,18,23,9,9,11,12,15,18,23,27,1,2,2,2,3,3,3,4,2,2,2,3,3,3,4,4,2,2,3,3,3,4,4,4,2,2,3,3,3,4,4,5,2,3,3,3,4,4,5,6,3,3,3,4,4,5,6,7,3,3,3,4,4,5,7,7,3,3,4,4,5,7,7,7,0,0,1,70,73,67,86,0,222,235,243,248,251,253,254,255,0,1,2,3,5,8,13,21,96,146,36,0,32,119,36,0,0,0,0,0,0,0,0,0,16,92,36,0,112,0,0,0,240,187,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,192,33,0,102,10,0,0,104,109,83,0,100,66,52,0,0,0,0,0,0,0,0,0,64,2,0,0,188,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,215,35,60,214,185,114,187,111,18,3,187,57,142,227,187,137,98,241,186,171,170,42,61,0,0,0,0,0,0,0,0,171,170,170,188,136,69,74,188,0,0,0,62,73,146,100,61,34,115,7,61,162,188,134,188,40,176,31,188,0,0,32,62,0,0,128,61,38,180,23,61,205,204,204,187,214,185,114,187,38,100,76,62,0,0,160,61,47,161,61,61,9,242,20,59,39,135,176,58,205,204,76,62,0,0,128,61,38,180,23,61,171,170,170,60,214,185,242,59,82,223,89,62,57,142,99,61,5,217,6,61,171,170,170,60,136,69,74,60,212,155,94,62,124,240,65,61,166,218,229,60,228,56,14,61,71,143,168,60,212,155,94,62,228,56,14,61,71,143,168,60,124,240,65,61,166,218,229,60,82,223,89,62,171,170,170,60,136,69,74,60,57,142,99,61,5,217,6,61,205,204,76,62,171,170,170,60,214,185,242,59,0,0,128,61,38,180,23,61,38,100,76,62,9,242,20,59,39,135,176,58,0,0,160,61,47,161,61,61,0,0,32,62,205,204,204,187,214,185,114,187,0,0,128,61,38,180,23,61,0,0,0,62,162,188,134,188,40,176,31,188,73,146,100,61,34,115,7,61,171,170,42,61,171,170,170,188,136,69,74,188,0,0,0,0,0,0,0,0,10,215,35,60,57,142,227,187,137,98,241,186,214,185,114,187,111,18,3,187,10,215,163,59,10,215,163,188,205,204,76,60,202,38,155,190,111,18,3,59,85,85,213,61,10,215,35,61,205,204,204,188,137,136,8,61,10,215,163,188,0,0,0,62,10,215,35,60,161,14,106,60,205,204,76,189,10,215,163,188,0,0,32,62,10,215,35,186,46,116,1,186,10,215,35,186,46,116,1,186,0,0,32,62,10,215,35,186,46,116,1,186,10,215,35,186,46,116,1,186,0,0,0,62,205,204,76,189,10,215,163,188,10,215,35,60,161,14,106,60,85,85,213,61,137,136,8,61,10,215,163,188,10,215,35,61,205,204,204,188,10,215,163,59,202,38,155,190,111,18,3,59,10,215,163,188,205,204,76,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,73,18,62,0,0,0,62,161,14,234,188,37,73,18,189,171,170,170,60,140,46,58,62,241,240,112,61,137,136,8,61,65,76,174,60,10,215,35,60,140,46,58,62,65,76,174,60,10,215,35,60,241,240,112,61,137,136,8,61,37,73,18,62,37,73,18,189,171,170,170,60,0,0,0,62,161,14,234,188,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,4,53,62,115,130,218,62,123,130,26,63,123,130,90,63,122,130,154,63,0,128,215,63,0,0,24,64,0,128,87,64,0,0,152,64,0,128,215,64,0,0,24,65,0,128,87,65,0,0,152,65,0,128,215,65,0,0,24,66,0,128,87,66,0,0,152,66,0,128,215,66,0,0,24,67,0,128,87,67,0,0,152,67,0,128,215,67,0,0,24,68,0,128,87,68,0,0,152,68,0,128,215,68,0,0,24,69,0,128,87,69,0,0,152,69,0,128,215,69,0,0,24,70,0,128,87,70,0,0,152,70,0,128,215,70,0,0,24,71,0,128,87,71,0,0,152,71,0,128,215,71,0,0,24,72,0,128,87,72,0,0,152,72,0,128,215,72,0,0,24,73,0,128,87,73,0,0,152,73,0,128,215,73,0,0,24,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,63,0,128,87,63,0,0,152,63,0,128,215,63,0,0,24,64,0,128,87,64,0,0,152,64,0,128,215,64,0,0,24,65,0,128,87,65,0,0,152,65,0,128,215,65,0,0,24,66,0,128,87,66,0,0,152,66,0,128,215,66,0,0,24,67,0,128,87,67,0,0,152,67,0,128,215,67,0,0,24,68,0,128,87,68,0,0,152,68,0,128,215,68,0,0,24,69,0,128,87,69,0,0,152,69,0,128,215,69,0,0,24,70,0,128,87,70,0,0,152,70,0,128,215,70,0,0,24,71,0,128,87,71,0,0,152,71,0,128,215,71,0,0,24,72,0,128,87,72,0,0,152,72,0,128,215,72,0,0,24,73,0,128,87,73,0,0,152,73,0,128,215,73,0,0,24,74,0,128,87,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,104,29,60,16,229,27,61,60,147,172,61,28,246,21,62,78,140,99,62,118,8,158,62,145,14,206,62,1,0,0,63,185,248,24,63,198,251,48,63,238,28,71,63,122,130,90,63,153,109,106,63,176,65,118,63,96,138,125,63,0,0,128,63,95,138,125,63,175,65,118,63,152,109,106,63,120,130,90,63,236,28,71,63,196,251,48,63,183,248,24,63,0,0,0,63,144,14,206,62,117,8,158,62,76,140,99,62,26,246,21,62,56,147,172,61,8,229,27,61,32,104,29,60,16,229,27,61,28,246,21,62,118,8,158,62,1,0,0,63,198,251,48,63,122,130,90,63,176,65,118,63,0,0,128,63,175,65,118,63,120,130,90,63,196,251,48,63,0,0,0,63,117,8,158,62,26,246,21,62,8,229,27,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,246,21,62,1,0,0,63,122,130,90,63,0,0,128,63,120,130,90,63,0,0,0,63,26,246,21,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,0,0,128,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,2,0,1,13,21,5,9,3,0,0,0,0,0,0,0,6,2,2,4,4,6,5,4,2,0,0,0,0,0,0,0,62,1,0,2,6,14,30,0,6,1,2,3,4,5,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,3,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,4,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,36,15,1,0,2,0,0,0,6,0,5,0,7,0,12,0,11,0,20,0,19,0,4,0,3,0,35,0,100,0,164,0,36,0,36,1,36,3,36,7,12,3,3,3,3,3,3,4,4,5,5,6,6,6,7,8,9,10,11,12,0,0,0,0,198,30,6,0,194,0,66,1,66,2,70,2,198,0,70,0,66,0,70,1,162,0,98,0,38,0,22,0,14,0,5,0,4,0,3,0,0,0,1,0,10,0,18,0,2,0,34,0,198,1,198,2,198,6,198,14,13,7,8,9,10,10,10,10,10,9,8,7,6,5,4,3,3,2,3,3,4,5,7,8,9,11,12,13,0,0,0,0,168,0,0,0,4,1,0,0,212,0,0,0,34,0,0,0,178,1,0,0,106,0,0,0,26,1,0,0,122,1,0,0,136,1,0,0,54,1,0,0,254,1,0,0,28,0,0,0,252,0,0,0,4,2,0,0,64,2,0,0,0,0,0,0,36,1,0,0,38,1,0,0,170,0,0,0,156,0,0,0,6,2,0,0,242,0,0,0,212,1,0,0,182,0,0,0,24,1,0,0,208,1,0,0,52,2,0,0,22,0,0,0,118,1,0,0,114,1,0,0,92,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,254,255,255,255,0,0,0,0,0,0,0,0,88,190,33,0,112,0,0,0,112,177,92,0,100,66,52,0,0,0,0,0,0,0,0,0,118,3,0,0,154,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,175,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,133,37,0,112,0,0,0,104,249,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,175,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,36,36,0,112,0,0,0,240,19,32,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,47,37,0,136,110,39,0,0,0,0,0,82,0,0,0,0,0,0,0,0,0,0,0,56,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,2,0,0,0,0,0,0,192,1,0,0,0,0,0,0,132,3,0,0,0,0,0,0,0,0,0,0,136,48,37,0,168,110,39,0,0,0,0,0,82,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,7,0,0,0,0,0,0,0,0,0,0,132,2,0,0,254,8,0,0,0,0,0,0,0,0,0,0,112,127,38,0,64,183,39,0,0,0,0,0,55,0,0,0,0,0,0,0,0,0,0,0,88,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,4,0,0,0,0,0,0,62,0,0,0,0,0,0,0,154,4,0,0,0,0,0,0,0,0,0,0,224,102,37,0,32,10,36,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,6,0,0,0,0,0,0,0,0,0,0,224,2,0,0,232,1,0,0,0,0,0,0,0,0,0,0,0,1,8,16,9,2,3,10,17,24,32,25,18,11,4,5,12,19,26,33,40,48,41,34,27,20,13,6,7,14,21,28,35,42,49,56,57,50,43,36,29,22,15,23,30,37,44,51,58,59,52,45,38,31,39,46,53,60,61,54,47,55,62,63,0,8,1,9,16,24,2,10,17,25,32,40,48,56,33,41,18,26,3,11,4,12,19,27,34,42,49,57,50,58,35,43,20,28,5,13,6,14,21,29,36,44,51,59,52,60,37,45,22,30,7,15,23,31,38,46,53,61,54,62,39,47,55,63,240,48,37,0,200,110,39,0,0,0,0,0,162,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,10,0,0,0,0,0,0,0,0,0,0,116,1,0,0,8,7,0,0,0,0,0,0,0,0,0,0,48,47,37,0,72,110,39,0,0,0,0,0,86,50,49,48,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,8,0,0,0,0,0,0,0,0,0,0,202,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,252,39,0,128,249,39,0,0,0,0,0,40,141,37,0,0,0,0,0,14,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,136,4,0,0,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,252,39,0,128,249,39,0,0,0,0,0,40,141,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,9,0,0,6,4,0,0,38,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,49,37,0,8,111,39,0,0,0,0,0,52,86,85,89,0,0,0,0,0,0,0,0,64,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,1,0,0,0,0,0,0,60,0,0,0,0,0,0,0,166,5,0,0,0,0,0,0,0,0,0,0,248,49,37,0,40,111,39,0,0,0,0,0,52,86,85,89,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,6,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,1,0,213,28,2,0,130,54,0,0,87,136,0,0,0,203,1,0,213,28,2,0,130,54,0,0,87,136,0,0,149,152,1,0,105,4,2,0,75,100,0,0,31,208,0,0,149,152,1,0,105,4,2,0,75,100,0,0,31,208,0,0,0,152,1,0,190,6,2,0,183,96,0,0,117,207,0,0,149,152,1,0,105,4,2,0,75,100,0,0,31,208,0,0,149,152,1,0,105,4,2,0,75,100,0,0,31,208,0,0,75,203,1,0,38,20,2,0,11,66,0,0,231,138,0,0,136,252,39,0,184,249,39,0,0,1,0,0,136,252,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,144,4,0,0,204,8,0,0,132,0,0,0,138,11,0,0,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,50,37,0,88,111,39,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,10,0,0,0,0,0,0,0,0,0,0,200,2,0,0,206,0,0,0,0,0,0,0,0,0,0,0,0,51,37,0,128,111,39,0,0,0,0,0,80,49,52,89,0,0,0,0,0,0,0,0,72,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,1,0,0,0,0,0,0,128,1,0,0,0,0,0,0,66,7,0,0,0,0,0,0,0,0,0,0,96,51,37,0,184,111,39,0,0,0,0,0,80,49,52,89,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,7,0,0,0,0,0,0,0,0,0,0,44,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,253,39,0,232,249,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,82,11,0,0,168,11,0,0,190,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,52,37,0,72,112,39,0,0,0,0,0,159,0,0,0,0,0,0,0,0,0,0,0,80,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,37,0,232,112,39,0,0,0,0,0,159,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,54,37,0,24,113,39,0,3,0,0,0,3,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,4,0,0,218,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,54,37,0,128,113,39,0,3,0,0,0,3,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,2,0,0,0,0,0,0,0,0,0,0,166,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,254,39,0,0,250,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,122,1,0,0,174,1,0,0,214,1,0,0,186,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,55,37,0,208,113,39,0,0,0,0,0,60,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,8,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,255,0,0,0,251,0,0,0,0,0,0,0,4,0,0,0,251,0,0,0,1,0,0,0,255,0,0,0,200,0,0,0,0,0,0,0,55,0,0,0,200,0,0,0,33,0,0,0,223,0,0,0,159,0,0,0,0,0,0,0,64,0,0,0,159,0,0,0,131,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,125,0,0,0,131,0,0,0,0,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,38,0,0,0,38,0,0,0,13,0,0,0,152,0,0,0,38,0,0,0,76,0,0,0,13,0,0,0,165,0,0,0,13,0,0,0,178,0,0,0,6,0,0,0,230,0,0,0,38,0,0,0,114,0,0,0,13,0,0,0,191,0,0,0,13,0,0,0,204,0,0,0,6,0,0,0,236,0,0,0,13,0,0,0,217,0,0,0,6,0,0,0,242,0,0,0,5,0,0,0,248,0,0,0,3,0,0,0,253,0,0,0,16,56,37,0,248,113,39,0,0,0,0,0,67,65,70,88,0,0,0,0,0,0,0,0,168,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,8,0,0,0,0,0,0,104,2,0,0,0,0,0,0,142,2,0,0,0,0,0,0,0,0,0,0,128,57,37,0,64,114,39,0,0,0,0,0,67,65,70,88,0,0,0,0,0,0,0,0,176,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,2,0,0,0,0,0,0,0,0,0,0,160,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,60,37,0,24,115,39,0,0,0,0,0,161,0,0,0,0,0,0,0,0,0,0,0,184,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,63,37,0,112,115,39,0,0,0,0,0,161,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,11,0,0,0,0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,136,35,0,48,174,34,0,0,0,0,0,0,0,0,0,0,0,0,0,176,95,40,0,0,0,0,0,0,0,0,0,32,0,0,0,214,9,0,0,190,3,0,0,148,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,127,37,0,24,32,36,0,0,0,0,0,78,73,66,88,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,8,0,0,0,0,0,0,0,0,0,0,112,1,0,0,186,11,0,0,0,0,0,0,0,0,0,0,112,52,37,0,248,111,39,0,0,0,0,0,42,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,78,7,0,0,0,0,0,0,0,0,0,0,16,65,37,0,40,116,39,0,0,0,0,0,41], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1234688);
/* memory initializer */ allocate([2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,8,0,0,0,0,0,0,0,0,0,0,230,2,0,0,226,4,0,0,0,0,0,0,0,0,0,0,200,172,33,0,72,46,33,0,1,0,0,0,2,64,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,6,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,254,39,0,16,250,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,2,0,0,0,192,11,0,0,152,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,254,39,0,32,250,39,0,216,141,37,0,96,254,39,0,25,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,18,0,0,0,104,0,0,0,188,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,254,39,0,176,250,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,0,0,0,182,7,0,0,138,0,0,0,188,1,0,0,0,0,0,0,142,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,2,40,0,96,251,39,0,0,0,0,0,168,2,40,0,3,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,64,107,40,0,0,0,0,0,0,0,0,0,80,2,0,0,166,4,0,0,222,1,0,0,74,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,183,216,0,32,55,73,218,17,166,78,0,7,233,94,173,141,112,4,40,0,176,251,39,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,20,3,0,0,222,5,0,0,96,3,0,0,154,6,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,4,40,0,208,251,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,106,3,0,0,22,5,0,0,92,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,4,40,0,232,251,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,3,0,0,102,6,0,0,202,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,65,37,0,152,116,39,0,1,0,0,0,17,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,10,0,0,0,0,0,0,0,0,0,0,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,66,37,0,48,117,39,0,0,0,0,0,74,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,9,0,0,0,0,0,0,0,0,0,0,150,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,250,34,0,248,51,34,0,0,0,0,0,152,0,0,0,2,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,9,0,0,0,0,0,0,0,0,0,0,22,2,0,0,66,11,0,0,56,0,0,0,0,0,0,0,48,72,37,0,40,238,35,0,0,0,0,0,72,0,0,0,34,0,0,0,0,0,0,0,8,23,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,171,10,0,168,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,9,0,0,0,0,0,0,0,0,0,0,22,2,0,0,66,11,0,0,14,1,0,0,0,0,0,0,0,2,4,8,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,0,8,1,16,9,24,17,2,32,10,25,40,18,48,33,26,56,41,34,3,49,57,11,42,19,50,27,58,35,43,51,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,8,3,9,10,16,4,11,17,24,18,12,5,19,25,13,20,26,27,6,21,28,14,22,29,7,30,15,23,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,224,4,0,208,220,4,0,208,216,4,0,184,185,19,0,216,142,33,0,64,19,33,0,0,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,192,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,8,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,144,171,32,0,144,79,32,0,0,0,0,0,19,0,0,0,3,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,8,0,0,0,0,0,0,0,0,0,0,114,1,0,0,234,6,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,8,8,8,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,0,8,1,2,9,16,24,17,10,3,4,11,18,25,32,40,48,56,41,33,26,19,12,5,6,13,20,27,34,49,57,58,50,42,35,28,21,14,7,15,22,29,36,43,51,59,60,52,44,37,30,23,31,38,45,53,61,62,54,46,39,47,55,63,0,8,1,2,9,16,24,17,10,3,4,11,18,25,32,40,33,48,26,19,12,5,6,13,20,27,34,41,56,49,57,42,35,28,21,14,7,15,22,29,36,43,50,58,51,59,44,37,30,23,31,38,45,52,60,53,61,46,39,47,54,62,55,63,0,1,8,2,3,9,16,24,17,10,4,5,11,18,25,32,40,48,33,26,19,12,6,7,13,20,27,34,41,56,49,57,42,35,28,21,14,15,22,29,36,43,50,58,51,44,37,30,23,31,38,45,52,59,60,53,46,39,47,54,61,62,55,63,0,8,16,1,24,32,40,9,2,3,10,17,25,48,56,41,33,26,18,11,4,5,12,19,27,34,49,57,50,42,35,28,20,13,6,7,14,21,29,36,43,51,58,59,52,44,37,30,22,15,23,31,38,45,60,53,46,39,47,54,61,62,55,63,104,173,32,0,208,159,32,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,80,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,178,1,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,168,139,34,0,56,124,34,0,0,0,0,0,18,0,0,0,3,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,7,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,19,20,20,21,21,22,144,74,37,0,56,119,39,0,1,0,0,0,37,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,2,0,0,76,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,20,9,0,0,62,0,0,0,0,0,0,0,192,63,37,0,112,232,35,0,1,0,0,0,8,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,1,0,0,0,0,0,0,58,3,0,0,0,0,0,0,14,1,0,0,0,0,0,0,0,0,0,0,248,63,37,0,152,232,35,0,1,0,0,0,8,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,5,0,0,0,0,0,0,0,0,0,0,86,0,0,0,14,1,0,0,34,1,0,0,0,0,0,0,32,81,37,0,64,121,39,0,1,0,0,0,7,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,1,0,0,0,0,0,0,58,3,0,0,0,0,0,0,14,1,0,0,0,0,0,0,0,0,0,0,152,81,37,0,152,121,39,0,1,0,0,0,7,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,5,0,0,0,0,0,0,0,0,0,0,86,0,0,0,14,1,0,0,34,1,0,0,0,0,0,0,112,80,37,0,232,120,39,0,1,0,0,0,38,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,35,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,5,0,0,0,0,0,0,0,0,0,0,64,1,0,0,202,3,0,0,204,1,0,0,0,0,0,0,184,80,37,0,32,121,39,0,1,0,0,0,39,80,1,0,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,123,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,9,0,0,0,0,0,0,0,0,0,0,118,1,0,0,198,10,0,0,208,0,0,0,0,0,0,0,202,96,254,63,119,94,253,63,165,99,252,63,168,54,251,63,45,166,249,63,97,120,247,63,225,30,244,63,52,83,238,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,126,252,63,136,252,250,63,229,147,249,63,103,18,248,63,216,107,246,63,57,126,244,63,166,55,242,63,64,141,239,63,51,62,236,63,105,35,232,63,139,90,227,63,144,199,221,63,12,236,214,63,18,7,206,63,220,15,193,63,223,100,170,63,244,86,243,63,144,178,238,63,245,198,234,63,153,157,230,63,182,28,226,63,116,52,221,63,247,174,215,63,192,149,209,63,204,225,202,63,63,76,194,63,8,233,183,63,237,116,171,63,15,242,158,63,152,177,143,63,221,173,119,63,69,144,61,63,247,124,226,63,17,208,214,63,58,187,204,63,187,142,196,63,59,195,188,63,191,191,180,63,22,44,172,63,156,254,162,63,121,181,152,63,218,127,140,63,214,249,124,63,62,85,95,63,149,98,62,63,173,1,25,63,253,5,221,62,175,21,56,62,154,150,183,63,84,2,169,63,142,249,154,63,50,138,141,63,19,184,128,63,141,66,103,63,131,235,77,63,74,4,53,63,179,177,26,63,69,12,255,62,57,43,197,62,109,201,138,62,45,136,19,62,199,30,16,59,244,67,43,190,222,28,189,190,163,187,127,63,142,133,87,63,44,33,53,63,171,61,20,63,171,236,240,62,87,69,189,62,57,90,137,62,197,192,47,62,188,160,147,61,108,234,250,188,116,63,179,191,10,169,128,190,13,137,190,190,239,192,2,191,174,28,38,191,172,150,77,191,28,194,135,62,49,77,129,61,64,179,181,189,175,25,88,190,166,19,159,190,203,41,203,190,192,200,241,190,249,170,10,191,109,76,29,191,182,126,48,191,155,11,68,191,17,9,90,191,164,240,115,191,189,86,136,191,243,64,154,191,149,38,176,191,81,22,10,191,132,218,60,191,32,94,98,191,83,110,129,191,86,35,145,191,174,87,162,191,81,208,181,191,70,103,207,191,215,0,141,191,214,34,149,191,28,223,157,191,49,238,166,191,132,53,176,191,17,249,187,191,210,194,201,191,181,159,213,191,105,164,197,190,74,98,15,191,5,119,43,191,5,162,66,191,91,165,86,191,79,159,104,191,226,93,121,191,196,186,132,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,151,221,199,191,138,104,212,191,245,10,221,191,109,168,227,191,72,56,233,191,152,92,238,191,65,144,243,191,198,94,249,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,231,2,1,0,205,5,93,0,201,5,94,0,3,0,22,0,11,0,1,0,6,0,1,0,6,0,4,0,5,0,4,0,7,0,3,0,7,0,4,0,10,0,10,0,2,0,3,0,0,0,5,0,2,0,95,0,4,0,3,0,2,0,200,5,184,0,202,5,203,5,204,5,0,0,0,0,0,0,10,12,10,13,9,13,9,8,7,5,5,4,4,3,3,3,4,3,4,4,5,5,6,8,7,10,8,10,9,8,9,9,13,10,13,13,13,0,0,0,100,0,200,0,44,1,144,1,254,1,118,2,2,3,152,3,56,4,246,4,200,5,184,6,208,7,16,9,140,10,78,12,116,14,48,17,180,20,0,25,20,30,28,37,224,46,140,60,180,95,0,0,0,0,0,0,40,5,40,0,0,252,39,0,192,143,37,0,24,44,36,0,0,0,0,0,0,0,0,0,84,84,86,87,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,0,0,222,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,8,40,0,16,252,39,0,0,0,0,0,208,143,37,0,0,0,0,0,160,98,2,0,0,0,0,0,0,0,0,0,28,0,0,0,44,0,0,0,90,6,0,0,134,0,0,0,66,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,216,83,37,0,40,122,39,0,3,0,0,0,84,84,86,87,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,85,37,0,176,123,39,0,0,0,0,0,80,66,69,87,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,192,3,0,0,0,0,0,0,0,0,0,0,80,147,34,0,168,216,33,0,224,84,33,0,80,147,34,0,5,80,1,0,141,0,0,0,84,84,86,87,64,4,3,0,0,0,0,0,208,98,2,0,0,0,0,0,224,0,0,0,206,9,0,0,208,2,0,0,210,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,8,40,0,72,252,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,198,6,0,0,200,1,0,0,208,3,0,0,130,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,88,37,0,80,124,39,0,1,0,0,0,25,80,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,100,40,0,0,0,0,0,0,0,0,0,0,99,2,0,0,0,0,0,232,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,4,0,0,0,0,0,0,148,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,168,90,37,0,72,125,39,0,1,0,0,0,25,80,1,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,0,0,0,0,0,0,0,0,0,0,0,40,3,0,0,78,2,0,0,48,1,0,0,0,0,0,0,24,10,40,0,104,252,39,0,240,143,37,0,24,10,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,80,107,40,0,120,99,2,0,0,0,0,0,64,0,0,0,162,8,0,0,236,1,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,13,40,0,144,252,39,0,0,1,0,0,0,0,0,0,88,107,40,0,208,99,2,0,0,0,0,0,0,0,0,0,80,0,0,0,212,7,0,0,130,6,0,0,212,1,0,0,0,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,44,36,0,72,41,35,0,0,0,0,0,64,44,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,48,96,40,0,0,0,0,0,0,0,0,0,64,0,0,0,72,11,0,0,236,1,0,0,104,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,97,118,101,243,172,211,17,140,209,0,192,79,142,219,138,188,148,95,146,90,82,210,17,134,220,0,192,79,142,219,138,114,105,102,102,46,145,207,17,165,214,40,219,4,193,0,0,102,109,116,32,243,172,211,17,140,209,0,192,79,142,219,138,102,97,99,116,243,172,211,17,140,209,0,192,79,142,219,138,100,97,116,97,243,172,211,17,140,209,0,192,79,142,219,138,0,144,37,0,72,44,36,0,0,1,0,0,0,0,0,0,208,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,0,0,194,5,0,0,50,1,0,0,212,1,0,0,0,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,113,33,0,88,249,32,0,0,0,0,0,232,16,30,0,72,190,4,0,0,0,0,0,250,7,0,0,0,0,0,0,230,1,0,0,130,8,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,92,39,0,216,14,39,0,0,0,0,0,48,152,8,0,224,151,8,0,0,0,0,0,108,9,0,0,0,0,0,0,230,1,0,0,200,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,33,40,0,48,192,39,0,0,0,0,0,48,152,8,0,168,152,8,0,0,0,0,0,126,5,0,0,0,0,0,0,230,1,0,0,200,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,150,32,0,192,58,32,0,0,0,0,0,96,17,30,0,240,93,10,0,0,0,0,0,148,9,0,0,0,0,0,0,230,1,0,0,216,8,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,198,34,0,120,6,34,0,0,0,0,0,176,222,11,0,40,223,11,0,0,0,0,0,26,10,0,0,0,0,0,0,230,1,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,184,34,0,88,198,38,0,0,0,0,0,112,26,12,0,72,30,12,0,0,0,0,0,10,5,0,0,0,0,0,0,0,0,0,0,104,1,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,196,34,0,24,202,38,0,0,0,0,0,64,204,12,0,104,209,12,0,0,0,0,0,160,10,0,0,0,0,0,0,36,0,0,0,32,8,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,202,34,0,72,205,38,0,0,0,0,0,32,88,15,0,200,91,15,0,0,0,0,0,236,0,0,0,0,0,0,0,4,0,0,0,164,5,0,0,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,216,36,0,216,167,35,0,0,0,0,0,200,112,17,0,144,114,17,0,0,0,0,0,168,9,0,0,0,0,0,0,230,1,0,0,36,9,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,181,34,0,160,197,38,0,0,0,0,0,184,20,25,0,32,23,25,0,0,0,0,0,140,4,0,0,0,0,0,0,230,1,0,0,0,8,0,0,152,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,184,211,34,0,216,207,38,0,0,0,0,0,96,61,26,0,56,65,26,0,0,0,0,0,58,6,0,0,0,0,0,0,244,0,0,0,118,0,0,0,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,220,39,0,120,126,37,0,0,0,0,0,216,17,30,0,152,252,28,0,0,0,0,0,60,4,0,0,0,0,0,0,50,2,0,0,172,1,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,212,34,0,80,208,38,0,80,18,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,133,37,0,24,199,32,0,240,240,18,0,0,0,0,0,104,241,18,0,0,0,0,0,0,0,0,0,0,0,0,0,234,0,0,0,128,9,0,0,72,0,0,0,0,0,0,0,0,0,0,0,212,2,0,0,152,173,39,0,24,199,32,0,200,18,30,0,0,0,0,0,200,249,28,0,0,0,0,0,0,0,0,0,0,0,0,0,234,0,0,0,128,9,0,0,72,0,0,0,0,0,0,0,0,0,0,0,212,2,0,0,192,14,40,0,208,252,39,0,0,0,0,0,32,144,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,84,1,0,0,242,9,0,0,84,2,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,92,37,0,184,125,39,0,0,0,0,0,45,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,7,0,0,0,0,0,0,0,0,0,0,84,1,0,0,138,2,0,0,0,0,0,0,0,0,0,0,0,15,40,0,8,253,39,0,0,0,0,0,48,144,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,82,0,0,0,192,2,0,0,116,1,0,0,236,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,16,82,37,0,88,245,35,0,3,0,0,0,114,108,80,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,23,3,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,3,0,0,0,0,0,0,0,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,93,37,0,24,126,39,0,0,0,0,0,169,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,164,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,3,0,0,0,0,0,0,0,0,0,0,124,0,0,0,16,5,0,0,210,1,0,0,0,0,0,0,152,66,37,0,16,234,35,0,0,0,0,0,141,0,0,0,2,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,8,0,0,0,0,0,0,0,0,0,0,120,2,0,0,244,4,0,0,184,0,0,0,0,0,0,0,208,189,3,0,200,189,3,0,192,189,3,0,176,189,3,0,184,123,32,0,5,0,0,0,0,0,0,0,128,2,0,0,226,1,0,0,252,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,160,66,37,0,24,234,35,0,0,0,0,0,93,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,4,0,0,0,0,0,0,0,0,0,0,156,0,0,0,150,4,0,0,0,0,0,0,0,0,0,0,168,247,34,0,64,49,34,0,0,0,0,0,107,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,4,0,0,0,0,0,0,0,0,0,0,156,0,0,0,150,4,0,0,0,0,0,0,0,0,0,0,240,93,37,0,208,126,39,0,0,0,0,0,92,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,4,0,0,0,0,0,0,0,0,0,0,156,0,0,0,150,4,0,0,0,0,0,0,0,0,0,0,184,96,37,0,184,127,39,0,0,0,0,0,91,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,6,0,0,0,0,0,0,0,0,0,0,156,0,0,0,60,8,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,8,0,4,1,2,2,0,0,255,0,2,3,254,0,253,0,4,4,2,5,252,0,251,0,2,6,250,0,249,0,0,0,9,15,32,25,7,19,9,21,1,12,14,12,3,18,14,23,3,10,0,4,41,22,1,0,1,31,0,0,0,0,0,1,1,7,0,1,98,25,4,10,2,3,2,3,0,2,0,2,0,0,11,4,1,4,0,2,3,2,0,4,48,39,1,2,11,27,29,44,7,27,1,4,0,3,1,6,1,2,0,0,123,37,6,4,1,27,0,0,0,0,5,8,1,7,0,1,12,10,0,2,49,46,3,4,7,31,42,41,0,0,2,6,1,7,1,4,2,4,0,1,21,32,1,2,4,10,32,43,6,23,2,3,1,19,1,6,12,21,0,7,26,14,14,12,0,24,0,0,0,0,55,17,1,9,0,36,5,7,1,3,26,25,1,1,2,10,67,39,0,0,1,1,0,14,0,2,31,26,1,6,69,83,0,0,0,2,10,29,3,12,0,1,0,3,0,3,2,2,0,0,209,5,0,0,0,27,0,0,0,0,0,1,0,1,0,1,0,0,0,0,103,46,1,2,2,10,33,42,0,0,1,4,0,3,0,1,1,3,0,0,11,20,1,4,18,36,43,48,13,35,0,2,0,5,3,12,1,2,0,0,2,5,4,5,0,121,0,0,0,0,0,3,2,4,1,4,2,2,0,1,14,31,9,13,14,54,22,29,0,0,2,6,4,18,6,13,1,5,0,1,70,44,0,1,2,10,37,46,8,26,0,2,0,2,0,2,0,1,0,0,175,5,0,1,0,48,0,0,0,0,0,2,0,1,0,2,0,1,0,0,85,39,0,0,1,9,69,40,0,0,0,1,0,3,0,1,2,3,0,0,8,15,0,1,8,21,74,53,22,42,0,1,0,2,0,3,1,2,0,0,83,5,2,3,0,102,0,0,0,0,1,3,0,2,0,1,0,0,0,0,31,28,0,0,3,14,130,34,0,0,0,1,0,3,0,1,3,3,0,1,141,42,0,0,1,4,11,24,1,11,0,1,0,1,0,2,0,0,0,0,233,6,0,0,0,8,0,0,0,0,0,1,0,1,0,0,0,1,0,0,171,25,0,0,1,5,25,21,0,0,0,1,0,1,0,0,0,0,0,0,8,19,4,10,24,45,21,37,9,29,0,3,1,7,11,25,0,2,0,1,34,16,112,21,1,28,0,0,0,0,6,8,1,7,0,3,2,5,0,2,17,21,68,29,6,15,13,22,0,0,6,12,3,14,4,10,1,7,0,3,46,42,0,1,2,10,54,51,10,30,0,2,0,2,0,1,0,1,0,0,159,35,2,2,0,25,0,0,0,0,3,6,0,5,0,1,4,4,0,1,51,39,0,1,2,12,91,44,0,0,0,2,0,3,0,1,2,3,0,1,28,32,0,0,3,10,75,51,14,33,0,1,0,2,0,1,1,2,0,0,75,39,5,7,2,48,0,0,0,0,3,11,2,16,1,4,7,10,0,2,81,25,0,0,2,9,106,26,0,0,0,1,0,1,0,1,1,1,0,0,100,46,0,1,3,9,21,37,5,20,0,1,0,2,1,2,0,1,0,0,212,21,0,1,0,9,0,0,0,0,1,2,0,2,0,0,2,2,0,0,140,37,0,1,1,8,24,33,0,0,1,2,0,2,0,1,1,2,0,0,27,29,0,1,9,25,53,51,12,34,0,1,0,3,1,5,0,2,0,0,4,2,0,0,0,172,0,0,0,0,0,1,0,2,0,0,2,0,0,0,14,23,1,3,11,53,90,31,0,0,0,3,1,5,2,6,1,2,0,0,80,38,0,0,1,4,69,33,5,16,0,1,0,1,0,0,0,1,0,0,187,22,1,1,0,17,0,0,0,0,3,6,0,4,0,1,4,4,0,1,123,29,0,0,1,7,57,30,0,0,0,1,0,1,0,1,0,1,0,0,16,20,0,0,2,8,104,49,15,33,0,1,0,1,0,1,1,1,0,0,133,6,1,2,1,70,0,0,0,0,0,2,0,4,0,3,1,1,0,0,13,14,0,0,4,20,175,20,0,0,0,1,0,1,0,1,1,1,0,0,194,16,0,0,1,1,1,9,1,3,0,0,0,1,0,1,0,0,0,0,251,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,23,0,0,1,3,2,9,0,0,0,1,0,1,0,1,0,0,0,0,4,0,2,1,248,0,252,0,8,2,6,3,4,4,2,5,232,0,236,0,240,0,244,0,0,0,0,0,0,0,0,0,8,1,4,2,2,4,0,0,254,0,2,5,253,0,252,0,4,3,2,6,255,0,249,0,4,7,2,8,251,0,250,0,2,9,248,0,247,0,0,0,4,6,2,7,0,0,255,0,4,8,2,9,254,0,253,0,2,10,252,0,251,0,0,0,8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,83,199,140,125,104,0,0,14,14,13,13,12,12,10,10,10,10,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,6,6,6,6,6,6,5,5,5,5,4,4,4,4,4,4,4,3,3,3,3,2,69,42,1,2,1,7,44,42,6,22,1,3,0,2,1,5,0,1,0,0,229,8,1,1,0,8,0,0,0,0,1,2,0,1,0,0,1,1,0,0,122,35,1,1,1,6,46,34,0,0,1,2,0,1,0,1,1,1,0,0,0,0,0,0,47,47,47,47,45,43,43,43,43,43,42,41,41,40,40,40,40,35,35,35,35,33,33,33,33,32,32,32,27,27,26,26,25,25,24,24,23,23,19,19,19,19,18,18,17,16,16,16,16,16,15,11,11,11,10,10,9,8,7,5,3,3,2,2,159,0,0,0,0,0,0,0,0,0,0,145,165,0,0,0,0,0,0,0,0,0,140,148,173,0,0,0,0,0,0,0,0,135,140,155,176,0,0,0,0,0,0,0,130,134,141,157,180,0,0,0,0,0,0,129,130,133,140,153,177,196,230,243,254,254,0,0,0,0,0,0,0,1,2,3,4,10,0,0,0,1,2,3,4,5,7,11,19,35,67,0,0,0,0,0,0,255,255,0,255,255,1,255,0,254,254,0,254,255,255,254,1,254,2,255,254,254,2,254,0,0,1,1,2,3,0,0,0,0,0,0,1,2,3,3,3,3,0,0,0,0,0,0,94,92,90,88,86,82,78,74,70,66,62,58,54,53,52,51,50,49,48,47,46,45,44,43,42,40,39,37,36,35,34,33,32,31,30,29,28,27,26,25,24,23,22,21,20,19,18,17,16,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,40,68,37,0,32,235,35,0,0,0,0,0,30,0,0,0,3,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,9,0,0,0,0,0,0,0,0,0,0,20,3,0,0,78,4,0,0,216,0,0,0,0,0,0,0,104,15,40,0,32,253,39,0,56,144,37,0,144,44,36,0,136,41,35,0,120,95,34,0,240,183,33,0,64,56,33,0,0,0,0,0,0,0,0,0,120,167,2,0,248,221,2,0,248,203,2,0,248,167,2,0,248,222,2,0,248,205,2,0,248,171,2,0,120,103,2,0,62,180,228,51,9,145,243,51,139,178,1,52,60,32,10,52,35,26,19,52,96,169,28,52,167,215,38,52,75,175,49,52,80,59,61,52,112,135,73,52,35,160,86,52,184,146,100,52,85,109,115,52,136,159,129,52,252,11,138,52,147,4,147,52,105,146,156,52,50,191,166,52,63,149,177,52,147,31,189,52,228,105,201,52,173,128,214,52,54,113,228,52,166,73,243,52,136,140,1,53,192,247,9,53,6,239,18,53,118,123,28,53,192,166,38,53,55,123,49,53,218,3,61,53,94,76,73,53,59,97,86,53,185,79,100,53,252,37,115,53,138,121,129,53,134,227,137,53,124,217,146,53,133,100,156,53,82,142,166,53,51,97,177,53,37,232,188,53,220,46,201,53,206,65,214,53,65,46,228,53,87,2,243,53,143,102,1,54,79,207,9,54,245,195,18,54,152,77,28,54,232,117,38,54,50,71,49,54,116,204,60,54,94,17,73,54,101,34,86,54,206,12,100,54,184,222,114,54,151,83,129,54,28,187,137,54,114,174,146,54,175,54,156,54,129,93,166,54,53,45,177,54,199,176,188,54,228,243,200,54,1,3,214,54,96,235,227,54,30,187,242,54,162,64,1,55,235,166,9,55,241,152,18,55,201,31,28,55,30,69,38,55,61,19,49,55,30,149,60,55,111,214,72,55,162,227,85,55,247,201,99,55,137,151,114,55,175,45,129,55,190,146,137,55,116,131,146,55,230,8,156,55,190,44,166,55,71,249,176,55,121,121,188,55,254,184,200,55,71,196,213,55,146,168,227,55,248,115,242,55,192,26,1,56,147,126,9,56,249,109,18,56,6,242,27,56,98,20,38,56,86,223,48,56,216,93,60,56,146,155,72,56,242,164,85,56,51,135,99,56,110,80,114,56,211,7,129,56,107,106,137,56,130,88,146,56,42,219,155,56,9,252,165,56,104,197,176,56,59,66,188,56,41,126,200,56,160,133,213,56,217,101,227,56,232,44,242,56,233,244,0,57,70,86,9,57,14,67,18,57,81,196,27,57,181,227,37,57,127,171,48,57,162,38,60,57,197,96,72,57,83,102,85,57,131,68,99,57,104,9,114,57,1,226,128,57,36,66,137,57,157,45,146,57,123,173,155,57,99,203,165,57,153,145,176,57,13,11,188,57,102,67,200,57,11,71,213,57,50,35,227,57,237,229,241,57,29,207,0,58,5,46,9,58,48,24,18,58,169,150,27,58,21,179,37,58,183,119,48,58,124,239,59,58,10,38,72,58,199,39,85,58,230,1,99,58,120,194,113,58,59,188,128,58,233,25,137,58,198,2,146,58,219,127,155,58,203,154,165,58,216,93,176,58,239,211,187,58,179,8,200,58,136,8,213,58,159,224,226,58,7,159,241,58,92,169,0,59,208,5,9,59,94,237,17,59,15,105,27,59,132,130,37,59,253,67,48,59,103,184,59,59,97,235,71,59,77,233,84,59,93,191,98,59,156,123,113,59,127,150,128,59,186,241,136,59,249,215,145,59,71,82,155,59,65,106,165,59,39,42,176,59,226,156,187,59,18,206,199,59,23,202,212,59,32,158,226,59,53,88,241,59,166,131,0,60,167,221,8,60,152,194,17,60,130,59,27,60,1,82,37,60,84,16,48,60,97,129,59,60,200,176,71,60,229,170,84,60,232,124,98,60,212,52,113,60,207,112,128,60,150,201,136,60,58,173,145,60,192,36,155,60,197,57,165,60,133,246,175,60,229,101,187,60,130,147,199,60,185,139,212,60,180,91,226,60,121,17,241,60,251,93,0,61,137,181,8,61,223,151,17,61,2,14,27,61,141,33,37,61,185,220,47,61,109,74,59,61,64,118,71,61,145,108,84,61,133,58,98,61,34,238,112,61,42,75,128,61,127,161,136,61,136,130,145,61,72,247,154,61,88,9,165,61,242,194,175,61,248,46,187,61,3,89,199,61,109,77,212,61,92,25,226,61,209,202,240,61,91,56,0,62,119,141,8,62,51,109,17,62,144,224,26,62,39,241,36,62,46,169,47,62,135,19,59,62,202,59,71,62,77,46,84,62,55,248,97,62,132,167,112,62,143,37,128,62,115,121,136,62,226,87,145,62,220,201,154,62,249,216,164,62,109,143,175,62,27,248,186,62,149,30,199,62,51,15,212,62,23,215,225,62,61,132,240,62,198,18,0,63,114,101,8,63,147,66,17,63,43,179,26,63,206,192,36,63,177,117,47,63,178,220,58,63,101,1,71,63,29,240,83,63,251,181,97,63,251,96,112,63,0,0,128,63,32,99,37,0,160,128,39,0,1,0,0,0,5,80,1,0,32,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,6,0,0,0,0,0,0,16,2,0,0,0,0,0,0,122,4,0,0,0,0,0,0,0,0,0,0,16,102,37,0,120,129,39,0,1,0,0,0,5,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,100,40,0,40,38,19,0,0,0,0,0,0,0,0,0,0,0,0,0,52,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,9,0,0,0,0,0,0,0,0,0,0,48,3,0,0,214,5,0,0,236,1,0,0,0,0,0,0,240,73,33,0,7,0,0,0,0,0,0,0,12,1,0,0,182,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,142,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,55,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,15,7,0,0,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,1,2,3,0,0,0,0,0,2,1,3,4,0,0,0,0,2,1,5,3,4,0,0,0,2,1,6,5,3,4,0,0,2,1,7,5,6,3,4,192,15,40,0,48,253,39,0,72,144,37,0,192,15,40,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,120,107,40,0,0,0,0,0,0,0,0,0,4,0,0,0,214,3,0,0,204,2,0,0,108,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1244928);
/* memory initializer */ allocate([67,114,101,97,116,105,118,101,32,86,111,105,99,101,32,70,105,108,101,26,0,0,0,0,88,144,37,0,176,44,36,0,0,0,0,0,0,0,0,0,128,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,20,0,0,0,224,10,0,0,220,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,1,0,0,0,0,0,15,16,1,0,1,0,0,0,16,16,1,0,2,0,0,0,17,16,1,0,3,0,0,0,0,0,1,0,4,0,0,0,7,0,1,0,6,0,0,0,6,0,1,0,7,0,0,0,12,16,1,0,0,2,0,0,0,0,0,0,0,0,0,0,184,119,36,0,24,95,35,0,8,0,0,0,104,141,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,3,0,0,106,4,0,0,214,0,0,0,104,3,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,24,104,37,0,24,130,39,0,0,0,0,0,90,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,4,0,0,0,0,0,0,0,0,0,0,66,1,0,0,16,8,0,0,0,0,0,0,0,0,0,0,152,105,37,0,224,130,39,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,7,0,0,0,0,0,0,0,0,0,0,10,3,0,0,166,0,0,0,0,0,0,0,0,0,0,0,136,70,37,0,80,237,35,0,1,0,0,0,11,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,3,0,0,0,0,0,0,0,0,0,0,28,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,27,32,0,128,178,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,3,0,0,86,7,0,0,186,8,0,0,170,3,0,0,220,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,19,40,0,232,253,39,0,0,0,0,0,96,144,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,10,7,0,0,210,2,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,106,37,0,88,131,39,0,1,0,0,0,65,77,73,86,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,10,0,0,0,0,0,0,0,0,0,0,180,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,38,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,218,34,0,120,210,38,0,184,19,30,0,64,19,30,0,152,7,0,0,4,0,2,0,0,0,0,0,0,0,0,0,226,0,0,0,134,10,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,225,34,0,136,212,38,0,208,102,2,0,8,101,2,0,72,103,2,0,0,0,2,0,0,0,0,0,0,0,0,0,26,2,0,0,254,2,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,34,0,96,215,38,0,208,236,3,0,232,233,3,0,72,237,3,0,0,0,1,0,176,8,0,0,0,0,0,0,98,0,0,0,72,2,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,232,34,0,248,215,38,0,168,20,30,0,48,20,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,254,34,0,240,223,38,0,152,21,30,0,32,21,30,0,16,87,4,0,0,0,1,0,168,3,0,0,0,0,0,0,146,0,0,0,118,5,0,0,84,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,22,38,0,184,170,39,0,224,164,4,0,88,162,4,0,88,165,4,0,0,0,0,0,16,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,9,35,0,8,228,38,0,136,22,30,0,16,22,30,0,216,169,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,6,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,23,35,0,48,236,38,0,168,180,4,0,240,177,4,0,32,181,4,0,0,0,0,0,0,0,0,0,0,0,0,0,250,0,0,0,210,9,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,41,35,0,40,240,38,0,40,183,4,0,144,181,4,0,160,183,4,0,0,0,0,0,220,2,0,0,0,0,0,0,0,0,0,0,246,8,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,45,35,0,104,242,38,0,216,184,4,0,0,184,4,0,80,185,4,0,0,0,0,0,70,8,0,0,0,0,0,0,62,1,0,0,156,3,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,48,35,0,112,243,38,0,72,192,4,0,128,190,4,0,192,192,4,0,0,0,0,0,186,0,0,0,0,0,0,0,86,0,0,0,148,2,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,48,35,0,168,243,38,0,120,12,8,0,0,12,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,49,35,0,24,244,38,0,40,109,8,0,176,108,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,7,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,35,0,184,246,38,0,72,126,8,0,32,118,8,0,192,126,8,0,0,0,0,0,0,0,0,0,0,0,0,0,130,0,0,0,186,1,0,0,176,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,68,35,0,168,247,38,0,56,136,8,0,112,134,8,0,176,136,8,0,0,0,2,0,16,2,0,0,0,0,0,0,202,0,0,0,88,6,0,0,28,5,0,0,0,0,0,0,30,0,0,0,0,0,0,0,192,63,38,0,136,174,39,0,0,23,30,0,0,0,0,0,224,136,8,0,2,0,0,0,78,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,77,35,0,112,249,38,0,16,156,8,0,40,153,8,0,136,156,8,0,0,0,1,0,16,7,0,0,0,0,0,0,232,1,0,0,118,1,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,78,35,0,232,249,38,0,240,23,30,0,120,23,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,159,38,0,240,186,39,0,224,24,30,0,104,24,30,0,192,37,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,93,37,0,56,1,36,0,208,25,30,0,88,25,30,0,16,39,9,0,0,0,0,0,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,80,38,0,184,177,39,0,192,26,30,0,72,26,30,0,64,39,9,0,0,0,0,0,162,7,0,0,0,0,0,0,248,0,0,0,0,0,0,0,184,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,81,35,0,128,250,38,0,8,41,9,0,112,39,9,0,128,41,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,4,38,0,216,166,39,0,176,27,30,0,56,27,30,0,208,42,9,0,0,0,0,0,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,82,35,0,24,251,38,0,0,44,9,0,136,43,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,191,38,0,160,191,39,0,240,44,9,0,120,44,9,0,104,45,9,0,0,0,0,0,102,7,0,0,0,0,0,0,20,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,112,37,0,40,19,36,0,40,28,30,0,0,0,0,0,176,46,9,0,2,0,0,0,62,3,0,0,0,0,0,0,154,1,0,0,180,10,0,0,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,99,35,0,40,255,38,0,24,29,30,0,160,28,30,0,208,73,9,0,0,0,0,0,0,0,0,0,30,1,0,0,52,1,0,0,104,8,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,102,35,0,112,0,39,0,248,94,9,0,16,92,9,0,112,95,9,0,0,0,1,0,78,8,0,0,0,0,0,0,186,0,0,0,120,6,0,0,96,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,116,35,0,0,3,39,0,120,92,10,0,32,90,10,0,240,92,10,0,4,0,1,0,24,9,0,0,0,0,0,0,154,0,0,0,204,0,0,0,240,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,96,119,35,0,152,3,39,0,40,99,10,0,32,98,10,0,160,99,10,0,0,0,1,0,132,4,0,0,0,0,0,0,22,2,0,0,136,8,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,124,35,0,224,4,39,0,64,163,10,0,232,160,10,0,184,163,10,0,0,0,0,0,0,0,0,0,0,0,0,0,252,1,0,0,96,11,0,0,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,133,35,0,152,6,39,0,120,166,10,0,112,165,10,0,48,167,10,0,0,0,0,0,252,0,0,0,0,0,0,0,44,2,0,0,12,5,0,0,48,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,139,35,0,240,7,39,0,24,176,10,0,64,175,10,0,96,186,10,0,0,0,1,0,124,3,0,0,0,0,0,0,10,1,0,0,48,5,0,0,44,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,176,140,35,0,64,8,39,0,8,30,30,0,144,29,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,145,35,0,128,9,39,0,48,38,11,0,168,35,11,0,152,39,11,0,0,0,0,0,0,0,0,0,0,0,0,0,150,0,0,0,236,3,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,150,35,0,104,10,39,0,176,42,11,0,248,39,11,0,40,43,11,0,0,0,1,0,58,2,0,0,0,0,0,0,2,2,0,0,90,9,0,0,160,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,114,37,0,104,21,36,0,208,43,11,0,88,43,11,0,72,44,11,0,0,0,0,0,72,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,162,35,0,128,13,39,0,248,30,30,0,128,30,30,0,32,61,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,8,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,166,35,0,104,14,39,0,128,63,11,0,232,61,11,0,248,63,11,0,0,0,1,0,0,0,0,0,0,0,0,0,60,2,0,0,150,0,0,0,56,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,182,35,0,32,19,39,0,232,31,30,0,112,31,30,0,136,67,11,0,0,0,2,0,8,0,0,0,0,0,0,0,66,1,0,0,70,11,0,0,152,2,0,0,0,0,0,0,58,0,0,0,0,0,0,0,152,183,35,0,152,19,39,0,24,33,30,0,160,32,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,193,35,0,144,21,39,0,96,250,11,0,72,241,11,0,216,250,11,0,4,0,1,0,114,5,0,0,0,0,0,0,52,0,0,0,206,4,0,0,152,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,35,37,0,0,213,35,0,8,34,30,0,144,33,30,0,8,251,11,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,92,11,0,0,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,129,33,0,160,6,33,0,88,86,16,0,168,68,11,0,136,252,11,0,0,0,1,0,144,3,0,0,0,0,0,0,56,1,0,0,198,1,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,204,35,0,32,24,39,0,96,48,12,0,248,46,12,0,216,48,12,0,0,0,0,0,0,10,0,0,0,0,0,0,30,2,0,0,218,2,0,0,4,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,36,0,96,24,36,0,224,136,12,0,8,136,12,0,88,137,12,0,0,0,0,0,204,3,0,0,0,0,0,0,0,1,0,0,4,9,0,0,116,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,223,35,0,144,30,39,0,0,0,0,0,72,174,12,0,80,175,12,0,1,0,0,0,52,1,0,0,0,0,0,0,120,0,0,0,160,4,0,0,120,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,35,0,40,39,39,0,248,178,12,0,160,176,12,0,112,179,12,0,0,0,0,0,0,0,0,0,0,0,0,0,150,1,0,0,66,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,26,37,0,200,205,35,0,88,86,16,0,168,68,11,0,32,213,12,0,0,0,1,0,202,10,0,0,0,0,0,0,56,1,0,0,198,1,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,225,34,0,0,30,34,0,88,86,16,0,168,68,11,0,80,213,12,0,0,0,1,0,90,10,0,0,0,0,0,0,56,1,0,0,198,1,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,17,36,0,72,48,39,0,80,215,12,0,184,213,12,0,200,215,12,0,4,0,1,0,8,2,0,0,0,0,0,0,0,0,0,0,160,11,0,0,232,1,48,0,0,0,0,0,0,0,0,0,0,0,0,0,152,50,36,0,216,56,39,0,88,86,16,0,168,68,11,0,136,213,12,0,0,0,1,0,38,8,0,0,0,0,0,0,56,1,0,0,198,1,0,0,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,52,36,0,136,57,39,0,200,208,15,0,48,207,15,0,64,209,15,0,0,0,0,0,0,0,0,0,0,0,0,0,162,1,0,0,100,2,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,20,39,0,232,203,39,0,0,0,0,0,216,70,16,0,224,71,16,0,1,0,0,0,200,5,0,0,0,0,0,0,222,1,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,56,36,0,24,58,39,0,208,86,16,0,32,69,11,0,32,74,16,0,0,0,0,0,0,0,0,0,0,0,0,0,190,1,0,0,224,2,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,245,33,0,240,130,38,0,216,185,36,0,32,26,156,0,208,1,0,0,0,0,0,0,248,246,33,0,24,131,38,0,240,185,36,0,40,26,156,0,56,0,0,0,0,0,0,0,112,249,33,0,168,131,38,0,88,186,36,0,48,26,156,0,14,0,0,0,0,0,0,0,136,250,33,0,248,131,38,0,144,186,36,0,56,26,156,0,24,2,0,0,0,0,0,0,168,254,33,0,232,132,38,0,40,187,36,0,64,26,156,0,112,2,0,0,0,0,0,0,128,1,34,0,176,133,38,0,112,187,36,0,72,26,156,0,96,0,0,0,0,0,0,0,168,2,34,0,88,134,38,0,176,187,36,0,80,26,156,0,94,2,0,0,0,0,0,0,104,68,36,0,240,59,39,0,72,87,16,0,152,69,11,0,120,108,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,84,3,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,72,36,0,224,60,39,0,104,110,16,0,96,109,16,0,224,110,16,0,0,0,0,0,32,5,0,0,0,0,0,0,40,1,0,0,152,6,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,77,36,0,32,63,39,0,64,166,16,0,216,164,16,0,184,166,16,0,0,0,1,0,68,2,0,0,0,0,0,0,180,0,0,0,54,6,0,0,112,1,2,0,0,0,0,0,22,0,0,0,0,0,0,0,160,83,36,0,32,64,39,0,248,34,30,0,128,34,30,0,248,167,16,0,0,0,2,0,106,7,0,0,0,0,0,0,224,1,0,0,26,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,98,36,0,40,66,39,0,192,87,16,0,16,70,11,0,24,213,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,146,11,0,0,52,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,103,36,0,80,67,39,0,16,215,16,0,72,213,16,0,136,215,16,0,0,0,1,0,48,7,0,0,0,0,0,0,0,0,0,0,120,1,0,0,24,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,104,36,0,216,67,39,0,232,35,30,0,112,35,30,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,8,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,23,37,0,40,203,35,0,136,116,17,0,192,114,17,0,64,117,17,0,4,0,2,0,24,0,0,0,0,0,0,0,82,0,0,0,160,11,0,0,232,1,48,0,0,0,0,0,0,0,0,0,0,0,0,0,168,107,36,0,144,68,39,0,216,36,30,0,96,36,30,0,248,128,17,0,0,0,1,0,250,0,0,0,0,0,0,0,158,1,0,0,80,2,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,122,36,0,16,72,39,0,128,140,17,0,56,137,17,0,56,141,17,0,0,0,1,0,170,10,0,0,0,0,0,0,216,1,0,0,28,7,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,125,36,0,112,72,39,0,240,115,18,0,24,115,18,0,104,116,18,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,129,36,0,96,73,39,0,16,117,18,0,152,116,18,0,200,117,18,0,0,0,0,0,0,0,0,0,0,0,0,0,120,1,0,0,146,9,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,138,36,0,232,74,39,0,200,37,30,0,80,37,30,0,96,123,18,0,0,0,0,0,188,4,0,0,0,0,0,0,14,2,0,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,148,36,0,56,76,39,0,184,38,30,0,64,38,30,0,72,125,18,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,206,1,0,0,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,139,38,0,224,184,39,0,168,39,30,0,48,39,30,0,0,0,0,0,0,0,0,0,72,8,0,0,0,0,0,0,64,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,150,36,0,24,77,39,0,152,40,30,0,32,40,30,0,144,217,18,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,228,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,178,36,0,216,81,39,0,0,0,0,0,192,217,18,0,152,224,18,0,1,0,0,0,70,10,0,0,0,0,0,0,166,1,0,0,158,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,180,36,0,16,83,39,0,168,226,18,0,112,225,18,0,32,227,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,188,36,0,176,84,39,0,136,41,30,0,16,41,30,0,248,175,22,0,4,0,0,0,100,3,0,0,0,0,0,0,0,0,0,0,230,3,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,205,36,0,48,87,39,0,56,184,22,0,0,0,0,0,176,184,22,0,2,0,0,0,206,5,0,0,0,0,0,0,162,0,0,0,254,5,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,209,36,0,144,89,39,0,104,23,23,0,160,21,23,0,224,23,23,0,0,0,0,0,236,4,0,0,0,0,0,0,126,0,0,0,222,6,0,0,44,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,212,36,0,184,90,39,0,24,25,23,0,16,24,23,0,144,25,23,0,0,0,1,0,0,6,0,0,0,0,0,0,74,1,0,0,178,5,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,46,37,0,120,219,35,0,96,46,23,0,216,43,23,0,216,46,23,0,0,0,1,0,40,1,0,0,0,0,0,0,0,0,0,0,206,10,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,229,36,0,136,94,39,0,144,49,23,0,8,47,23,0,8,50,23,0,0,0,1,0,40,1,0,0,0,0,0,0,0,0,0,0,206,10,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,0,8,98,39,0,16,159,23,0,8,155,23,0,136,159,23,0,0,0,0,0,150,1,0,0,0,0,0,0,58,1,0,0,182,3,0,0,104,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,5,37,0,24,100,39,0,120,42,30,0,0,42,30,0,64,234,23,0,0,0,1,0,180,2,0,0,0,0,0,0,0,0,0,0,50,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,8,37,0,232,100,39,0,72,235,23,0,112,234,23,0,192,235,23,0,0,0,0,0,242,3,0,0,0,0,0,0,60,1,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,27,37,0,88,104,39,0,0,0,0,0,120,50,24,0,112,52,24,0,1,0,0,0,86,8,0,0,0,0,0,0,68,2,0,0,80,11,0,0,136,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,33,37,0,160,106,39,0,96,54,24,0,200,52,24,0,216,54,24,0,0,0,1,0,246,1,0,0,0,0,0,0,68,0,0,0,14,11,0,0,136,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,80,37,0,144,120,39,0,200,202,24,0,0,198,24,0,64,203,24,0,4,0,1,0,32,4,0,0,0,0,0,0,0,0,0,0,86,4,0,0,40,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,93,37,0,184,126,39,0,104,43,30,0,240,42,30,0,0,205,24,0,0,0,1,0,250,9,0,0,0,0,0,0,0,0,0,0,50,3,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,117,37,0,32,135,39,0,88,44,30,0,224,43,30,0,176,206,24,0,0,0,0,0,0,0,0,0,0,0,0,0,102,1,0,0,114,6,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,120,37,0,240,136,39,0,72,45,30,0,208,44,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,148,37,0,40,144,39,0,80,8,25,0,136,6,25,0,200,8,25,0,0,0,1,0,100,0,0,0,0,0,0,0,0,0,0,0,184,11,0,0,92,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,156,37,0,80,147,39,0,160,12,25,0,248,8,25,0,24,13,25,0,0,0,1,0,0,0,0,0,0,0,0,0,160,0,0,0,130,4,0,0,208,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,160,37,0,216,147,39,0,160,15,25,0,72,13,25,0,24,16,25,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,88,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,180,37,0,136,150,39,0,56,46,30,0,192,45,30,0,80,0,29,0,0,0,1,0,28,9,0,0,0,0,0,0,16,2,0,0,88,8,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,218,37,0,248,158,39,0,160,12,29,0,72,4,29,0,88,13,29,0,4,0,2,0,178,2,0,0,0,0,0,0,14,0,0,0,234,0,0,0,96,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,226,37,0,248,159,39,0,40,47,30,0,176,46,30,0,72,14,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,9,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,232,37,0,128,162,39,0,64,16,29,0,120,14,29,0,184,16,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,7,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,239,37,0,96,164,39,0,64,213,29,0,104,212,29,0,184,213,29,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,220,6,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,7,38,0,88,167,39,0,136,213,30,0,16,213,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,1,0,0,60,9,0,0,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,42,37,0,0,216,35,0,56,184,22,0,0,0,0,0,0,0,0,0,2,0,0,0,240,8,0,0,0,0,0,0,162,0,0,0,254,5,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,106,37,0,32,132,39,0,0,0,0,0,36,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,10,0,0,0,0,0,0,0,0,0,0,138,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,19,40,0,240,253,39,0,0,0,0,0,104,144,37,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,20,7,0,0,24,0,0,0,94,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,19,40,0,8,254,39,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,1,0,0,16,11,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,147,33,0,96,23,33,0,0,0,0,0,153,0,0,0,2,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,9,0,0,0,0,0,0,0,0,0,0,22,2,0,0,66,11,0,0,56,0,0,0,0,0,0,0,3,0,46,0,95,0,0,0,22,0,21,0,1,0,4,0,20,0,241,2,121,1,123,1,192,11,193,11,225,5,122,1,6,0,6,0,3,0,7,0,15,0,14,0,0,0,2,0,2,0,20,0,17,0,11,0,9,0,33,0,21,0,32,0,6,0,0,0,14,0,5,0,2,0,3,0,3,0,15,0,2,0,129,0,33,0,9,0,1,1,65,0,17,0,0,1,2,6,7,2,5,5,2,3,5,10,9,9,12,12,11,9,3,4,4,4,4,4,3,3,2,7,7,6,6,8,7,8,3,3,4,5,3,3,4,4,2,10,8,6,11,9,7,11,0,0,0,0,3,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,6,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,3,0,0,0,6,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,7,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,3,0,0,0,2,0,0,0,0,1,3,5,16,17,18,19,3,0,1,2,3,5,8,9,1,0,1,4,6,7,10,11,2,2,2,3,5,5,5,5,2,3,3,3,3,3,4,4,2,3,3,3,3,3,4,4,14,12,7,11,9,26,2,10,27,8,0,6,1,15,1,14,0,8,15,10,4,23,13,5,9,25,3,24,22,1,5,6,2,2,8,0,28,3,1,3,29,1,19,18,15,0,0,0,5,5,5,5,5,6,4,5,6,5,4,5,4,5,1,4,3,4,4,4,5,5,4,5,4,5,4,5,5,2,3,3,4,3,4,5,5,3,5,4,5,4,5,5,4,0,0,0,0,8,16,1,9,24,17,2,10,18,25,3,11,26,19,27,0,1,2,3,4,5,6,7,8,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,27,29,31,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,0,1,1,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,29,31,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,24,0,0,0,11,0,0,0,20,0,0,0,11,0,0,0,32,0,0,0,11,0,0,0,80,0,0,0,33,0,0,0,18,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,64,0,0,0,33,0,0,0,160,0,0,0,99,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,2,0,3,0,0,0,4,0,1,0,2,0,71,0,5,0,3,0,4,0,75,0,5,0,77,0,78,0,14,3,6,0,6,0,7,0,83,0,8,0,85,0,86,0,13,3,9,0,89,0,90,0,12,3,92,0,11,3,10,3,55,0,7,0,10,0,11,0,67,0,12,0,69,0,70,0,9,3,13,0,73,0,74,0,8,3,76,0,7,3,6,3,54,0,14,0,81,0,82,0,5,3,84,0,4,3,3,3,53,0,88,0,2,3,1,3,52,0,0,3,51,0,50,0,7,0,1,4,4,8,4,8,8,10,4,8,8,10,8,10,10,13,4,8,8,10,8,10,10,13,8,10,10,13,10,13,13,9,4,8,8,10,8,10,10,13,8,10,10,13,10,13,13,9,8,10,10,13,10,13,13,9,10,13,13,9,13,9,9,6,0,4,5,3,0,0,0,0,1,3,3,2,0,0,0,0,0,1,2,3,1,3,2,0,0,1,2,4,3,1,3,2,4,0,0,0,0,0,0,0,0,0,2,0,3,0,8,0,64,2,3,0,2,0,6,0,5,0,65,2,66,2,7,0,8,0,9,0,40,0,19,0,37,0,82,0,21,0,22,0,23,0,67,2,68,2,166,0,96,0,167,0,49,0,194,0,195,0,69,2,70,2,71,2,36,1,37,1,38,1,13,0,2,0,7,0,24,0,50,0,102,0,39,1,13,0,7,0,8,0,18,0,50,0,103,0,38,0,20,0,21,0,22,0,39,0,204,0,103,0,23,0,24,0,25,0,104,0,154,1,105,0,106,0,107,0,108,0,109,0,220,0,155,1,186,1,222,0,187,1,190,1,191,1,7,0,0,0,4,0,5,0,3,0,4,0,3,0,4,0,5,0,20,0,6,0,21,0,44,0,45,0,46,0,192,11,95,0,112,0,113,0,57,0,193,11,194,11,116,0,117,0,195,11,118,0,196,11,197,11,198,11,199,11,200,11,201,11,202,11,203,11,204,11,205,11,206,11,1,0,4,0,15,0,160,0,161,0,41,0,6,0,11,0,42,0,162,0,43,0,119,0,56,0,57,0,58,0,163,0,236,0,237,0,207,11,119,0,120,0,242,0,122,0,230,1,232,5,231,1,246,0,238,1,233,5,239,1,234,5,235,5,236,5,237,5,238,5,239,5,31,0,0,0,0,2,1,2,2,2,3,2,2,0,3,0,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,1,0,5,0,31,1,32,1,33,1,34,1,6,0,7,0,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,44,1,45,1,46,1,47,1,48,1,49,1,50,1,51,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,63,1,0,0,1,0,1,0,2,0,3,0,4,0,1,0,5,0,4,0,3,0,5,0,8,0,6,0,9,0,10,0,11,0,12,0,7,0,104,0,14,0,105,0,4,0,10,0,15,0,11,0,6,0,14,0,8,0,106,0,107,0,108,0,15,0,109,0,9,0,55,0,10,0,1,0,2,0,1,0,2,0,3,0,12,0,6,0,2,0,6,0,7,0,28,0,7,0,15,0,8,0,5,0,18,0,29,0,152,0,77,0,24,0,25,0,26,0,39,0,108,0,13,0,109,0,55,0,56,0,57,0,116,0,11,0,153,0,234,0,235,0,118,0,119,0,15,0,6,7,7,8,14,6,5,6,7,14,14,6,6,6,8,9,10,9,7,7,7,14,14,10,9,10,8,10,10,14,14,14,13,13,13,6,3,5,6,8,9,13,5,4,4,5,7,9,6,5,5,5,6,9,8,5,5,5,7,10,7,7,7,7,7,8,10,9,8,9,9,9,3,5,7,7,6,6,5,5,6,7,5,7,8,8,8,14,9,9,9,8,14,14,9,9,14,9,14,14,14,14,14,14,14,14,14,14,14,2,3,6,8,8,6,3,4,6,8,6,9,6,6,6,8,8,8,14,7,7,8,7,9,13,9,8,9,13,9,13,13,13,13,13,13,5,3,12,12,12,12,3,4,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,1,5,11,11,11,11,4,4,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,15,11,15,15,15,15,12,15,12,11,12,12,15,12,12,12,12,15,15,12,15,10,11,12,11,10,11,10,15,15,15,11,15,10,14,10,4,4,5,7,8,9,5,3,4,5,6,8,5,4,3,5,6,8,7,5,5,5,6,7,9,7,6,6,6,7,10,8,8,8,7,7,4,0,0,0,0,184,192,33,0,56,186,33,0,0,0,0,0,184,192,33,0,0,0,0,0,71,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,1,0,0,1,0,0,0,0,1,0,1,0,1,1,0,0,1,1,1,0,1,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,1,0,0,1,0,0,0,0,1,0,1,0,1,1,0,0,1,1,1,0,1,1,0,0,0,4,0,0,1,4,1,0,1,4,0,0,0,3,0,0,1,3,1,0,1,3,0,0,0,5,0,0,0,9,22,0,17,16,10,1,3,23,7,0,5,2,1,1,6,3,4,1,0,10,23,44,8,3,9,45,7,97,1,2,49,13,25,0,96,0,0,0,0,4,5,2,5,5,4,2,2,5,3,4,6,2,3,2,3,5,6,2,2,4,5,6,4,2,4,6,4,8,1,3,7,5,6,2,8,0,0,0,0,22,0,17,0,0,0,47,0,32,0,10,0,1,0,3,0,67,0,133,0,132,0,92,0,19,0,93,0,18,0,3,0,45,0,0,0,7,0,23,0,6,0,1,0,2,0,10,0,39,0,44,0,8,0,18,0,77,0,76,0,15,0,6,0,28,0,9,0,41,0,6,0,2,0,15,0,14,0,8,0,40,0,29,0,0,0,21,0,11,0,7,0,198,0,1,0,2,0,193,0,13,0,25,0,0,0,97,0,63,6,98,0,142,1,30,3,192,0,62,6,5,5,2,6,6,4,2,2,7,8,8,7,5,7,5,3,6,3,3,5,3,3,3,4,6,6,4,5,7,7,4,3,5,5,7,4,2,5,5,5,7,5,2,6,5,4,9,1,3,9,5,6,2,8,12,8,10,11,9,12,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,3,1,2,3,0,4,2,3,2,4,3,3,0,16,17,3,3,0,5,9,2,8,9,3,6,7,0,5,2,16,17,5,3,0,3,9,2,56,57,15,4,5,6,29,0,52,53,27,14,15,2,12,0,56,57,29,5,6,0,15,4,16,17,6,7,0,1,9,5,56,57,0,5,6,29,4,15,6,6,2,3,2,4,5,2,5,5,3,3,3,2,4,2,6,6,4,3,2,2,5,2,6,6,4,3,3,3,5,1,6,6,5,4,4,2,4,1,6,6,5,3,3,1,4,3,5,5,3,3,2,2,4,3,6,6,1,3,3,5,3,4,0,1,1,1,1,1,0,1,1,1,1,1,16,17,3,0,9,5,20,21,3,11,0,4,4,5,2,3,3,0,4,5,3,2,0,3,0,1,1,1,1,1,16,17,9,5,3,0,5,5,1,3,2,4,5,5,1,2,3,4,5,5,2,1,4,3,5,5,2,4,1,3,4,4,2,3,2,2,4,4,3,2,2,2,5,5,3,4,1,2,5,5,4,3,2,1,26,47,27,47,140,23,144,0,168,2,169,2,199,11,145,0,170,2,171,2,224,5,74,0,150,0,151,0,189,0,146,0,172,2,173,2,225,5,152,0,50,1,51,1,121,1,52,1,106,2,107,2,252,2,78,0,64,0,65,0,43,0,147,0,174,2,175,2,226,5,54,1,110,2,111,2,253,2,158,0,62,1,63,1,127,1,80,0,66,0,67,0,44,0,81,0,164,0,165,0,190,0,83,0,68,0,69,0,45,0,84,0,70,0,71,0,46,0,3,0,0,0,1,0,1,0,65,0,66,0,0,1,67,0,136,0,137,0,1,1,69,0,140,0,141,0,2,1,16,0,34,0,35,0,36,0,71,0,16,0,17,0,3,1,37,0,88,0,89,0,90,0,91,0,90,0,91,0,92,0,12,0,48,0,49,0,25,0,9,0,20,0,21,0,44,0,92,0,93,0,94,0,95,0,38,0,93,0,94,0,95,0,13,0,52,0,53,0,27,0,20,0,39,0,42,0,43,0,14,0,56,0,57,0,29,0,15,0,60,0,61,0,31,0,5,0,9,0,0,0,3,0,50,0,51,0,26,0,38,0,228,0,229,0,230,1,39,0,230,0,231,0,231,1,14,0,99,0,108,0,119,0,40,0,232,0,233,0,232,1,123,0,218,0,219,0,236,0,245,0,184,1,185,1,218,1,33,0,75,0,84,0,43,0,41,0,234,0,235,0,233,1,74,0,186,1,187,1,219,1,32,0,222,0,223,0,242,0,34,0,85,0,88,0,45,0,15,0,112,0,113,0,120,0,35,0,89,0,92,0,47,0,36,0,93,0,98,0,48,0,2,0,31,0,6,0,0,0,40,0,41,0,157,0,0,0,234,1,235,1,236,1,1,0,237,1,238,1,239,1,5,0,240,0,241,0,59,0,2,0,240,1,241,1,242,1,63,0,92,1,93,1,153,0,16,0,208,3,209,3,48,1,15,0,158,0,159,0,251,0,3,0,243,1,244,1,245,1,17,0,210,3,211,3,49,1,9,0,94,1,95,1,156,0,16,0,168,0,169,0,56,0,6,0,242,0,243,0,77,0,17,0,170,0,171,0,57,0,18,0,172,0,173,0,58,0,6,0,22,0,23,0,14,0,60,0,61,0,31,0,10,0,97,0,98,0,2,0,11,0,99,0,100,0,3,0,7,0,3,0,4,0,11,0,12,0,101,0,102,0,4,0,18,0,10,0,11,0,20,0,27,0,24,0,25,0,52,0,44,0,103,0,104,0,53,0,13,0,105,0,108,0,5,0,96,0,26,0,27,0,53,0,19,0,14,0,15,0,21,0,45,0,109,0,110,0,56,0,8,0,8,0,9,0,12,0,46,0,111,0,114,0,58,0,47,0,115,0,0,0,59,0,7,0,20,0,21,0,4,0,56,0,57,0,157,0,10,0,145,0,146,0,147,0,11,0,148,0,149,0,150,0,3,0,238,0,239,0,54,0,12,0,151,0,152,0,153,0,8,0,228,1,229,1,106,0,24,0,204,3,205,3,214,0,14,0,158,0,159,0,245,0,13,0,154,0,155,0,156,0,25,0,206,3,207,3,215,0,9,0,232,1,233,1,144,0,15,0,232,0,233,0,246,0,5,0,240,0,241,0,55,0,16,0,234,0,235,0,247,0,17,0,236,0,237,0,52,0,0,0,62,0,63,0,2,0,60,0,61,0,207,1,0,0,191,0,224,0,252,1,1,0,225,0,226,0,253,1,9,0,241,1,242,1,243,1,2,0,227,0,228,0,254,1,17,0,238,3,239,3,240,3,33,0,226,7,227,7,228,7,24,0,247,3,254,3,255,3,3,0,229,0,230,0,128,0,46,0,229,7,230,7,231,7,22,0,244,3,245,3,246,3,25,0,2,1,3,1,4,1,10,0,244,1,245,1,246,1,26,0,5,1,6,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1255168);
/* memory initializer */ allocate([7,1,27,0,120,1,121,1,206,1,29,0,189,0,190,0,240,1,3,0,4,0,182,1,4,0,46,0,47,0,14,0,5,0,48,0,49,0,15,0,3,0,10,0,11,0,20,0,6,0,50,0,51,0,16,0,5,0,48,0,49,0,50,0,9,0,102,0,103,0,104,0,29,0,183,1,184,1,185,1,7,0,52,0,53,0,17,0,22,0,105,0,106,0,107,0,10,0,54,0,55,0,216,0,30,0,186,1,187,1,188,1,4,0,21,0,22,0,23,0,31,0,189,1,190,1,191,1,0,0,16,0,17,0,18,0,28,0,217,0,218,0,19,0,15,15,14,9,11,11,13,9,11,11,12,8,9,9,9,9,11,11,12,9,10,10,10,10,11,11,11,8,8,8,7,9,11,11,12,10,11,11,11,9,10,10,10,8,8,8,7,8,9,9,9,8,8,8,7,8,8,8,7,3,3,3,1,7,7,9,7,8,8,9,7,8,8,9,6,7,7,7,7,7,7,9,7,8,8,8,8,9,9,9,6,7,7,6,6,7,7,8,8,9,9,9,7,8,8,8,6,7,7,6,6,7,7,7,6,7,7,6,6,7,7,6,3,4,3,2,6,6,5,6,8,8,9,6,8,8,9,5,7,7,7,6,8,8,9,7,8,8,8,8,9,9,9,6,7,7,6,6,8,8,9,7,9,9,9,6,8,8,8,6,7,7,6,5,7,7,7,6,7,7,6,6,7,7,6,3,5,4,2,6,6,8,4,9,9,9,4,9,9,9,4,8,8,7,4,9,9,9,6,9,9,8,6,10,10,9,5,8,8,8,4,9,9,9,6,10,10,9,5,9,9,8,5,8,8,7,4,8,8,7,5,8,8,7,5,8,8,7,3,5,5,4,6,6,5,5,7,7,7,5,7,7,7,5,6,6,6,5,7,7,7,6,7,7,7,7,8,8,8,6,7,7,6,5,7,7,7,7,8,8,8,6,7,7,7,6,7,7,6,5,6,6,6,6,7,7,6,6,7,6,6,4,5,5,3,6,6,8,4,8,8,8,4,8,8,8,4,8,8,7,4,8,8,8,5,9,9,8,6,10,10,9,5,8,8,8,4,8,8,8,6,10,10,9,5,9,9,8,5,8,8,8,4,8,8,7,5,8,8,8,5,8,8,7,3,6,6,4,6,6,9,3,8,8,9,3,8,8,9,4,9,9,9,3,8,8,9,5,10,10,10,6,11,11,11,5,10,10,10,3,8,8,8,6,11,11,11,5,10,10,10,5,9,9,9,4,9,9,9,5,9,9,9,5,9,9,9,5,8,8,9,6,6,10,3,7,7,7,3,7,7,7,4,8,8,8,3,7,7,7,5,9,9,9,6,10,10,10,6,10,10,10,3,7,7,7,6,10,10,10,5,9,9,9,6,10,10,10,4,8,8,8,6,10,10,10,5,9,9,9,6,9,9,9,24,0,0,0,25,0,0,0,30,0,0,0,50,0,0,0,60,0,0,0,48,0,0,0,72,0,0,0,0,0,0,0,232,3,0,0,233,3,0,0,128,0,192,0,213,0,224,0,0,2,85,1,51,1,37,1,219,0,236,0,242,0,245,0,32,0,48,0,53,0,56,0,8,0,12,0,13,0,14,0,37,0,20,0,14,0,11,0,10,0,5,0,4,0,3,0,128,0,64,0,43,0,32,0,0,2,0,4,0,6,0,8,219,0,204,0,200,0,198,0,32,0,16,0,11,0,8,0,8,0,4,0,3,0,2,0,37,0,52,0,56,0,58,0,10,0,13,0,14,0,15,0,0,0,4,0,0,0,2,0,85,85,1,0,0,0,1,0,205,204,0,0,171,170,0,0,73,146,0,0,0,128,0,0,199,113,0,0,102,102,0,0,23,93,0,0,85,85,0,0,197,78,0,0,37,73,0,0,68,68,0,0,0,64,0,0,60,60,0,0,228,56,0,0,229,53,0,0,51,51,0,0,195,48,0,0,140,46,0,0,134,44,0,0,171,42,0,0,246,40,0,0,98,39,0,0,237,37,0,0,146,36,0,0,79,35,0,0,34,34,0,0,8,33,0,0,0,32,0,0,8,31,0,0,30,30,0,0,66,29,0,0,114,28,0,0,173,27,0,0,243,26,0,0,66,26,0,0,154,25,0,0,250,24,0,0,98,24,0,0,208,23,0,0,70,23,0,0,193,22,0,0,67,22,0,0,202,21,0,0,85,21,0,0,230,20,0,0,123,20,0,0,20,20,0,0,177,19,0,0,82,19,0,0,247,18,0,0,158,18,0,0,73,18,0,0,247,17,0,0,168,17,0,0,91,17,0,0,17,17,0,0,201,16,0,0,132,16,0,0,0,16,0,0,0,0,0,0,80,5,38,0,0,219,37,0,0,1,0,0,80,5,38,0,0,0,0,0,32,23,4,0,0,0,0,0,71,0,0,0,20,0,0,0,0,0,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,110,37,0,128,133,39,0,0,0,0,0,71,0,0,0,34,0,0,0,0,0,0,0,8,23,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,171,10,0,168,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,9,0,0,0,0,0,0,0,0,0,0,22,2,0,0,66,11,0,0,14,1,0,0,0,0,0,0,0,0,6,0,15,0,13,0,13,0,11,0,3,0,13,0,5,0,8,0,49,0,10,0,12,0,114,0,102,0,119,0,1,0,54,0,96,0,8,0,10,0,111,0,5,0,15,0,12,0,10,0,2,0,12,0,13,0,115,0,53,0,63,0,1,0,7,0,1,0,7,0,14,0,12,0,4,0,14,0,1,0,9,0,97,0,11,0,7,0,58,0,52,0,62,0,4,0,103,0,1,0,9,0,11,0,56,0,101,0,118,0,4,0,110,0,100,0,30,0,2,0,5,0,4,0,3,0,0,0,9,0,1,0,18,0,5,0,14,0,237,0,26,0,3,0,121,0,3,0,22,0,13,0,16,0,6,0,30,0,2,0,10,0,1,0,20,0,12,0,241,0,5,0,28,0,16,0,12,0,3,0,24,0,28,0,124,0,239,0,247,0,1,0,240,0,1,0,19,0,18,0,15,0,4,0,27,0,1,0,122,0,2,0,23,0,1,0,17,0,7,0,31,0,1,0,11,0,2,0,21,0,19,0,246,0,238,0,29,0,17,0,13,0,236,0,25,0,58,0,63,0,8,0,125,0,0,0,201,0,25,0,231,0,5,0,221,0,1,0,3,0,2,0,158,1,2,0,241,0,16,0,225,0,195,0,236,1,2,0,156,1,1,0,240,0,7,0,224,0,98,0,245,0,1,0,220,0,96,0,5,0,9,0,230,0,101,0,247,0,1,0,102,0,1,0,159,1,24,0,3,0,2,0,244,0,3,0,54,0,3,0,228,1,17,0,114,0,200,0,237,1,3,0,157,1,1,0,4,0,13,0,113,0,99,0,229,1,4,0,111,0,194,0,243,0,5,0,29,0,26,0,31,0,0,0,28,0,12,0,44,0,3,0,36,0,20,0,52,0,2,0,32,0,16,0,48,0,8,0,40,0,24,0,28,0,1,0,30,0,14,0,46,0,6,0,38,0,22,0,54,0,3,0,34,0,18,0,50,0,10,0,42,0,26,0,30,0,1,0,29,0,13,0,45,0,5,0,37,0,21,0,53,0,2,0,33,0,17,0,49,0,9,0,41,0,25,0,29,0,1,0,31,0,15,0,47,0,7,0,39,0,23,0,55,0,4,0,35,0,19,0,51,0,11,0,43,0,27,0,31,0,13,13,7,13,7,13,13,12,6,13,7,12,6,8,8,8,5,7,8,12,6,8,13,12,7,13,13,12,6,8,7,7,6,13,8,12,7,13,13,12,7,13,8,12,5,7,7,7,6,8,13,12,6,7,8,8,5,8,8,6,3,3,3,2,14,13,8,13,3,13,8,13,3,7,8,13,4,13,13,13,3,13,13,13,4,8,13,13,5,13,13,13,5,7,8,8,3,8,14,13,5,13,13,13,4,7,13,13,6,13,13,13,5,13,8,13,5,8,8,13,5,13,8,13,6,6,13,7,13,8,6,8,4,8,13,12,4,9,8,8,5,8,8,9,5,9,10,8,4,8,7,8,6,8,7,13,4,8,7,8,5,7,8,9,6,13,13,8,4,6,8,9,5,7,8,9,5,9,9,13,5,7,7,9,4,7,8,8,3,5,5,5,9,9,9,9,2,9,9,9,2,9,9,9,9,9,9,8,3,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,2,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,128,0,85,0,170,0,64,0,192,0,51,0,102,0,153,0,204,0,43,0,215,0,37,0,74,0,111,0,148,0,185,0,222,0,32,0,96,0,160,0,224,0,255,255,0,0,0,0,0,1,2,3,4,5,6,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,0,3,3,3,3,3,3,3,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,0,171,0,205,0,219,0,228,0,128,1,64,1,43,1,32,1,230,0,239,0,244,0,246,0,43,0,51,0,55,0,57,0,11,0,13,0,14,0,14,0,26,0,17,0,12,0,10,0,7,0,4,0,3,0,3,0,0,8,1,16,2,9,10,3,24,17,4,11,18,12,5,19,25,13,20,26,27,6,21,28,14,22,29,7,30,15,23,31,0,1,8,2,9,16,17,24,10,32,25,18,40,3,33,26,48,11,56,41,34,49,57,42,19,50,27,58,35,43,51,59,0,8,1,16,24,9,2,32,40,48,56,17,10,3,25,18,11,4,33,41,49,57,26,34,42,50,58,19,12,5,27,20,13,6,35,28,21,14,7,15,22,29,36,43,51,59,60,52,44,37,30,23,31,38,45,53,61,62,54,46,39,47,55,63,0,8,16,24,1,9,2,17,25,10,3,18,26,4,11,19,12,5,13,20,27,6,21,28,14,22,29,7,30,15,23,31,0,1,2,8,16,9,24,17,10,3,32,40,48,56,25,18,33,26,41,34,49,57,11,42,19,50,27,58,35,43,51,59,0,8,16,24,1,9,17,2,25,10,18,3,26,11,19,27,186,0,0,0,169,0,0,0,133,0,0,0,149,0,0,0,103,0,0,0,103,0,0,0,163,0,0,0,175,0,0,0,14,58,59,25,12,26,15,15,13,24,27,0,28,1,2,2,8,18,19,4,20,5,30,11,21,31,6,12,7,13,14,0,15,6,7,2,8,3,28,9,10,29,4,11,5,12,13,0,0,11,12,4,13,5,30,16,14,31,6,17,7,18,19,10,5,6,6,5,5,5,5,4,5,5,5,3,5,3,3,2,4,5,5,4,5,4,5,4,5,5,4,4,4,4,4,2,4,4,4,4,4,4,5,4,4,5,4,4,4,4,4,3,2,4,4,4,4,4,5,5,4,5,4,5,4,5,5,4,12,0,0,0,28,0,0,0,11,0,0,0,0,0,0,0,14,0,0,0,42,0,0,0,80,0,0,0,104,3,0,0,2,0,0,0,26,0,0,0,4,0,0,0,58,0,0,0,29,0,0,0,108,0,0,0,239,0,0,0,188,1,0,0,95,1,0,0,15,0,0,0,3,0,0,0,28,0,0,0,13,0,0,0,11,0,0,0,62,0,0,0,167,0,0,0,70,1,0,0,153,1,0,0,6,0,0,0,31,0,0,0,4,0,0,0,60,0,0,0,7,0,0,0,190,1,0,0,139,0,0,0,44,0,0,0,179,7,0,0,5,0,0,0,219,0,0,0,86,0,0,0,236,0,0,0,82,0,0,0,189,1,0,0,120,0,0,0,207,0,0,0,115,5,0,0,9,0,0,0,35,0,0,0,237,0,0,0,24,0,0,0,6,0,0,0,68,0,0,0,245,0,0,0,121,0,0,0,210,6,0,0,110,0,0,0,43,0,0,0,93,1,0,0,23,0,0,0,127,3,0,0,68,1,0,0,206,0,0,0,40,0,0,0,171,0,0,0,16,0,0,0,181,1,0,0,247,0,0,0,166,0,0,0,123,0,0,0,40,0,0,0,237,1,0,0,233,1,0,0,253,6,0,0,4,0,0,0,245,0,0,0,41,0,0,0,138,2,0,0,139,2,0,0,143,2,0,0,249,13,0,0,53,3,0,0,133,30,0,0,238,0,0,0,189,2,0,0,43,0,0,0,216,3,0,0,209,3,0,0,152,1,0,0,233,1,0,0,29,5,0,0,180,0,0,0,63,0,0,0,85,4,0,0,43,2,0,0,41,2,0,0,81,4,0,0,120,5,0,0,178,7,0,0,112,5,0,0,85,1,0,0,50,0,0,0,208,3,0,0,84,0,0,0,211,6,0,0,113,5,0,0,84,4,0,0,52,3,0,0,241,27,0,0,183,0,0,0,41,0,0,0,132,30,0,0,108,1,0,0,155,1,0,0,240,27,0,0,121,5,0,0,67,15,0,0,181,0,0,0,161,8,0,0,42,0,0,0,109,1,0,0,160,8,0,0,160,7,0,0,209,3,0,0,229,10,0,0,84,1,0,0,228,10,0,0,57,10,0,0,56,10,0,0,3,0,0,0,9,0,0,0,22,0,0,0,16,0,0,0,215,0,0,0,53,3,0,0,116,5,0,0,85,5,0,0,0,0,0,0,29,0,0,0,9,0,0,0,23,0,0,0,44,0,0,0,173,0,0,0,116,3,0,0,179,6,0,0,119,5,0,0,15,0,0,0,24,0,0,0,10,0,0,0,46,0,0,0,34,0,0,0,124,1,0,0,123,14,0,0,137,27,0,0,216,21,0,0,8,0,0,0,52,0,0,0,109,0,0,0,35,0,0,0,194,1,0,0,118,3,0,0,211,2,0,0,74,28,0,0,10,51,0,0,20,0,0,0,106,0,0,0,114,0,0,0,108,0,0,0,227,0,0,0,155,1,0,0,63,7,0,0,240,28,0,0,65,11,0,0,50,0,0,0,230,0,0,0,224,0,0,0,207,0,0,0,171,0,0,0,156,1,0,0,171,2,0,0,43,14,0,0,217,21,0,0,111,0,0,0,195,1,0,0,175,0,0,0,191,0,0,0,172,0,0,0,125,1,0,0,227,6,0,0,41,14,0,0,132,25,0,0,84,0,0,0,181,0,0,0,122,1,0,0,173,1,0,0,153,1,0,0,120,1,0,0,88,3,0,0,210,2,0,0,75,28,0,0,91,0,0,0,168,2,0,0,49,3,0,0,136,3,0,0,139,3,0,0,112,3,0,0,19,7,0,0,195,12,0,0,241,28,0,0,185,1,0,0,239,5,0,0,56,7,0,0,242,2,0,0,59,3,0,0,185,2,0,0,235,6,0,0,112,5,0,0,36,14,0,0,157,3,0,0,162,5,0,0,163,5,0,0,125,14,0,0,238,5,0,0,57,7,0,0,84,5,0,0,165,10,0,0,164,10,0,0,119,3,0,0,245,28,0,0,206,11,0,0,121,14,0,0,96,6,0,0,116,6,0,0,234,6,0,0,124,14,0,0,101,13,0,0,246,2,0,0,218,21,0,0,136,27,0,0,161,5,0,0,244,28,0,0,230,5,0,0,40,14,0,0,117,5,0,0,100,13,0,0,52,3,0,0,11,51,0,0,219,21,0,0,64,11,0,0,207,11,0,0,197,13,0,0,42,14,0,0,117,6,0,0,113,5,0,0,83,5,0,0,4,0,0,0,2,0,0,0,16,0,0,0,3,0,0,0,23,0,0,0,69,0,0,0,62,0,0,0,126,0,0,0,3,0,0,0,2,0,0,0,40,0,0,0,30,0,0,0,21,0,0,0,71,0,0,0,2,0,0,0,77,1,0,0,96,0,0,0,11,0,0,0,38,0,0,0,36,0,0,0,20,0,0,0,50,0,0,0,111,0,0,0,195,0,0,0,49,5,0,0,229,6,0,0,21,0,0,0,63,0,0,0,45,0,0,0,1,0,0,0,62,1,0,0,221,0,0,0,246,0,0,0,5,3,0,0,49,3,0,0,14,0,0,0,3,0,0,0,52,0,0,0,51,0,0,0,26,0,0,0,74,1,0,0,197,0,0,0,244,0,0,0,228,6,0,0,1,0,0,0,60,0,0,0,125,0,0,0,141,0,0,0,157,0,0,0,49,0,0,0,110,0,0,0,150,2,0,0,205,0,0,0,37,0,0,0,73,1,0,0,50,0,0,0,137,0,0,0,54,0,0,0,136,0,0,0,111,0,0,0,3,0,0,0,29,3,0,0,14,0,0,0,170,1,0,0,126,2,0,0,97,0,0,0,78,1,0,0,79,1,0,0,103,0,0,0,255,0,0,0,131,1,0,0,54,0,0,0,87,3,0,0,245,0,0,0,198,0,0,0,194,0,0,0,153,2,0,0,25,1,0,0,49,2,0,0,80,3,0,0,44,0,0,0,143,1,0,0,48,5,0,0,151,2,0,0,4,0,0,0,184,1,0,0,192,0,0,0,122,2,0,0,17,3,0,0,156,0,0,0,33,6,0,0,153,1,0,0,28,3,0,0,247,0,0,0,227,3,0,0,86,3,0,0,137,1,0,0,5,0,0,0,107,0,0,0,194,8,0,0,48,3,0,0,255,4,0,0,240,4,0,0,81,3,0,0,242,4,0,0,242,1,0,0,115,3,0,0,0,0,0,0,65,12,0,0,195,8,0,0,236,9,0,0,226,3,0,0,4,3,0,0,247,4,0,0,241,4,0,0,240,1,0,0,72,1,0,0,64,12,0,0,237,9,0,0,192,8,0,0,193,8,0,0,243,4,0,0,254,4,0,0,254,0,0,0,243,1,0,0,169,1,0,0,0,0,0,0,4,0,0,0,47,0,0,0,82,0,0,0,16,0,0,0,173,0,0,0,11,5,0,0,144,1,0,0,3,0,0,0,22,0,0,0,7,0,0,0,13,0,0,0,187,0,0,0,115,1,0,0,201,0,0,0,15,5,0,0,44,23,0,0,3,0,0,0,17,0,0,0,5,0,0,0,67,0,0,0,35,0,0,0,75,0,0,0,46,3,0,0,91,46,0,0,130,4,0,0,9,0,0,0,42,0,0,0,20,0,0,0,42,0,0,0,8,1,0,0,202,5,0,0,90,6,0,0,54,33,0,0,50,33,0,0,11,0,0,0,19,0,0,0,65,0,0,0,184,0,0,0,116,1,0,0,0,1,0,0,218,20,0,0,78,64,0,0,55,20,0,0,43,0,0,0,133,0,0,0,167,0,0,0,160,0,0,0,76,1,0,0,154,2,0,0,44,3,0,0,51,33,0,0,42,20,0,0,81,0,0,0,132,2,0,0,172,0,0,0,2,1,0,0,69,0,0,0,68,0,0,0,27,8,0,0,94,6,0,0,183,12,0,0,24,0,0,0,12,5,0,0,18,2,0,0,228,2,0,0,3,2,0,0,148,0,0,0,34,1,0,0,26,8,0,0,85,6,0,0,51,0,0,0,186,2,0,0,70,2,0,0,66,2,0,0,110,10,0,0,12,4,0,0,8,8,0,0,52,33,0,0,79,64,0,0,117,1,0,0,5,4,0,0,71,2,0,0,42,1,0,0,20,10,0,0,187,2,0,0,145,1,0,0,79,8,0,0,56,20,0,0,175,0,0,0,151,11,0,0,131,4,0,0,59,20,0,0,43,3,0,0,67,2,0,0,43,20,0,0,88,9,0,0,191,41,0,0,73,0,0,0,108,10,0,0,219,20,0,0,173,4,0,0,222,20,0,0,78,8,0,0,52,20,0,0,87,2,0,0,90,46,0,0,7,2,0,0,53,20,0,0,57,20,0,0,182,12,0,0,58,20,0,0,148,1,0,0,84,6,0,0,53,33,0,0,124,83,0,0,92,1,0,0,64,2,0,0,18,16,0,0,125,83,0,0,89,9,0,0,152,16,0,0,54,20,0,0,95,6,0,0,38,32,0,0,55,33,0,0,5,0,0,0,25,0,0,0,22,0,0,0,17,0,0,0,62,0,0,0,94,0,0,0,239,0,0,0,226,0,0,0,0,0,0,0,57,0,0,0,43,0,0,0,38,0,0,0,40,0,0,0,18,0,0,0,194,0,0,0,237,0,0,0,29,1,0,0,13,0,0,0,49,0,0,0,42,0,0,0,37,0,0,0,32,0,0,0,92,0,0,0,237,1,0,0,77,2,0,0,112,7,0,0,6,0,0,0,122,0,0,0,96,0,0,0,79,0,0,0,72,0,0,0,57,0,0,0,134,1,0,0,19,2,0,0,198,14,0,0,15,0,0,0,38,0,0,0,95,0,0,0,117,0,0,0,112,0,0,0,39,0,0,0,219,1,0,0,198,3,0,0,143,7,0,0,63,0,0,0,166,0,0,0,240,0,0,0,58,0,0,0,82,0,0,0,78,0,0,0,227,0,0,0,217,1,0,0,15,3,0,0,16,0,0,0,221,1,0,0,167,0,0,0,247,0,0,0,34,0,0,0,146,0,0,0,196,3,0,0,239,2,0,0,98,7,0,0,121,0,0,0,143,0,0,0,218,1,0,0,135,0,0,0,232,0,0,0,186,0,0,0,118,1,0,0,238,0,0,0,176,3,0,0,133,0,0,0,25,1,0,0,14,3,0,0,8,1,0,0,210,1,0,0,12,1,0,0,115,7,0,0,36,4,0,0,52,4,0,0,113,0,0,0,221,5,0,0,193,1,0,0,167,3,0,0,39,1,0,0,141,0,0,0,27,2,0,0,178,7,0,0,223,1,0,0,216,3,0,0,100,7,0,0,228,14,0,0,179,3,0,0,77,7,0,0,216,1,0,0,220,5,0,0,74,8,0,0,153,4,0,0,197,3,0,0,142,29,0,0,101,7,0,0,53,4,0,0,113,7,0,0,194,1,0,0,24,1,0,0,188,3,0,0,129,3,0,0,135,3,0,0,51,123,0,0,151,16,0,0,150,16,0,0,205,30,0,0,153,14,0,0,28,15,0,0,29,15,0,0,229,14,0,0,28,1,0,0,50,123,0,0,152,61,0,0,143,29,0,0,152,14,0,0,103,15,0,0,189,3,0,0,128,3,0,0,152,4,0,0,134,3,0,0,13,0,0,0,16,0,0,0,46,0,0,0,57,0,0,0,13,0,0,0,116,0,0,0,237,0,0,0,182,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,48,0,0,0,41,0,0,0,112,0,0,0,243,0,0,0,140,0,0,0,102,1,0,0,9,0,0,0,51,0,0,0,120,0,0,0,6,0,0,0,196,0,0,0,11,0,0,0,99,1,0,0,204,0,0,0,190,5,0,0,31,0,0,0,47,0,0,0,100,0,0,0,24,0,0,0,198,0,0,0,10,0,0,0,98,1,0,0,192,2,0,0,243,14,0,0,7,0,0,0,15,0,0,0,227,0,0,0,202,0,0,0,178,0,0,0,143,1,0,0,174,3,0,0,95,7,0,0,81,12,0,0,21,0,0,0,71,0,0,0,238,0,0,0,226,0,0,0,234,0,0,0,9,0,0,0,106,1,0,0,195,2,0,0,157,5,0,0,61,0,0,0,8,0,0,0,217,1,0,0,50,0,0,0,14,0,0,0,110,1,0,0,44,3,0,0,91,6,0,0,107,25,0,0,2,0,0,0,15,0,0,0,216,1,0,0,141,0,0,0,180,0,0,0,228,1,0,0,103,0,0,0,23,3,0,0,148,7,0,0,34,0,0,0,190,3,0,0,21,3,0,0,52,0,0,0,55,0,0,0,222,2,0,0,108,0,0,0,254,14,0,0,108,6,0,0,40,0,0,0,203,3,0,0,172,3,0,0,53,0,0,0,107,1,0,0,189,3,0,0,193,2,0,0,44,6,0,0,254,29,0,0,14,0,0,0,158,5,0,0,191,5,0,0,218,0,0,0,41,6,0,0,132,5,0,0,183,14,0,0,10,11,0,0,109,6,0,0,12,0,0,0,126,7,0,0,156,5,0,0,120,7,0,0,94,7,0,0,90,7,0,0,45,6,0,0,55,3,0,0,52,3,0,0,151,1,0,0,87,30,0,0,228,29,0,0,106,25,0,0,86,30,0,0,80,12,0,0,63,11,0,0,84,30,0,0,11,11,0,0,142,1,0,0,182,1,0,0,85,30,0,0,180,12,0,0,62,11,0,0,182,14,0,0,229,29,0,0,255,29,0,0,53,3,0,0,183,1,0,0,1,0,0,0,11,0,0,0,25,0,0,0,111,0,0,0,42,0,0,0,117,0,0,0,235,7,0,0,99,1,0,0,1,0,0,0,14,0,0,0,26,0,0,0,62,0,0,0,28,0,0,0,45,0,0,0,100,1,0,0,236,7,0,0,101,1,0,0,4,0,0,0,6,0,0,0,54,0,0,0,127,0,0,0,174,0,0,0,88,1,0,0,92,1,0,0,109,5,0,0,16,213,15,0,0,0,0,0,4,0,0,0,123,0,0,0,243,0,0,0,59,0,0,0,237,7,0,0,179,2,0,0,204,2,0,0,110,5,0,0,24,0,0,0,62,0,0,0,23,0,0,0,30,0,0,0,175,0,0,0,247,3,0,0,111,5,0,0,205,2,0,0,17,213,15,0,20,0,0,0,173,0,0,0,170,0,0,0,20,0,0,0,168,0,0,0,83,1,0,0,232,0,0,0,254,1,0,0,207,13,0,0,120,0,0,0,184,1,0,0,82,1,0,0,254,0,0,0,177,2,0,0,93,1,0,0,96,1,0,0,18,213,15,0,19,213,15,0,122,0,0,0,176,2,0,0,229,1,0,0,233,0,0,0,252,0,0,0,230,6,0,0,200,13,0,0,132,5,0,0,20,213,15,0,171,0,0,0,222,13,0,0,89,1,0,0,244,3,0,0,201,13,0,0,202,13,0,0,250,1,0,0,21,213,15,0,22,213,15,0,252,0,0,0,255,1,0,0,228,1,0,0,175,0,0,0,90,1,0,0,103,1,0,0,203,13,0,0,133,5,0,0,23,213,15,0,247,3,0,0,85,63,0,0,24,213,15,0,220,13,0,0,134,5,0,0,86,63,0,0,25,213,15,0,87,63,0,0,26,213,15,0,186,1,0,0,135,5,0,0,136,5,0,0,223,13,0,0,178,2,0,0,27,213,15,0,206,13,0,0,246,3,0,0,28,213,15,0,212,15,0,0,29,213,15,0,30,213,15,0,31,213,15,0,128,234,7,0,129,234,7,0,108,5,0,0,130,234,7,0,131,234,7,0,118,3,0,0,137,5,0,0,138,5,0,0,132,234,7,0,133,234,7,0,221,13,0,0,134,234,7,0,135,234,7,0,139,5,0,0,169,126,0,0,3,0,0,0,14,0,0,0,15,0,0,0,126,0,0,0,98,0,0,0,198,0,0,0,217,12,0,0,62,6,0,0,2,0,0,0,2,0,0,0,0,0,0,0,24,0,0,0,12,0,0,0,105,0,0,0,57,0,0,0,7,7,0,0,126,12,0,0,2,0,0,0,13,0,0,0,27,0,0,0,15,0,0,0,154,1,0,0,71,6,0,0,55,26,0,0,196,70,3,0,109,52,0,0,1,0,0,0,30,0,0,0,127,0,0,0,10,0,0,0,225,0,0,0,97,6,0,0,228,12,0,0,197,70,3,0,198,70,3,0,29,0,0,0,48,0,0,0,13,0,0,0,203,0,0,0,153,1,0,0,32,3,0,0,142,0,0,0,46,101,0,0,199,70,3,0,62,0,0,0,57,0,0,0,53,0,0,0,51,0,0,0,159,1,0,0,192,1,0,0,218,12,0,0,200,70,3,0,201,70,3,0,11,0,0,0,208,0,0,0,158,1,0,0,34,0,0,0,56,0,0,0,142,1,0,0,30,3,0,0,148,50,0,0,60,2,0,0,50,0,0,0,18,0,0,0,19,0,0,0,113,0,0,0,157,1,0,0,32,0,0,0,135,12,0,0,192,12,0,0,202,70,3,0,56,3,0,0,83,6,0,0,162,1,0,0,42,3,0,0,34,3,0,0,231,12,0,0,132,0,0,0,31,1,0,0,203,70,3,0,37,3,0,0,73,6,0,0,43,3,0,0,119,0,0,0,72,6,0,0,66,6,0,0,134,12,0,0,140,12,0,0,204,70,3,0,58,0,0,0,183,25,0,0,67,0,0,0,39,3,0,0,140,0,0,0,141,0,0,0,141,12,0,0,205,70,3,0,206,70,3,0,55,3,0,0,229,12,0,0,133,0,0,0,38,3,0,0,71,3,0,0,164,12,0,0,127,12,0,0,26,13,0,0,207,70,3,0,40,3,0,0,96,163,1,0,97,163,1,0,216,12,0,0,140,6,0,0,149,50,0,0,150,50,0,0,47,101,0,0,216,102,0,0,49,3,0,0,6,7,0,0,61,2,0,0,118,0,0,0,193,12,0,0,130,3,0,0,230,12,0,0,217,102,0,0,218,102,0,0,219,102,0,0,4,5,5,5,6,7,8,10,2,5,5,6,6,7,8,9,10,4,5,6,6,7,8,9,10,11,4,6,6,7,7,9,9,10,12,5,8,8,8,8,9,9,10,12,5,7,8,7,7,8,9,9,11,7,9,10,9,10,10,10,10,12,6,9,9,9,9,9,10,10,11,7,10,10,11,11,11,12,12,14,8,11,10,11,11,11,11,12,12,8,12,11,11,12,12,12,12,13,8,12,11,11,12,12,12,13,12,9,14,13,11,13,12,13,12,13,9,13,13,12,12,13,13,13,13,13,3,4,5,6,8,10,11,11,2,5,5,6,7,8,10,11,11,4,5,5,6,7,9,12,13,13,4,6,7,7,9,10,11,13,14,5,7,7,7,8,9,11,13,13,6,8,8,8,8,9,10,12,13,7,9,8,8,8,9,11,12,13,7,9,9,9,9,9,10,11,13,8,10,10,10,10,10,11,12,13,9,11,11,10,10,10,11,11,12,10,12,12,12,11,11,11,12,12,10,13,12,12,11,11,11,12,12,10,13,13,12,13,11,12,11,12,10,14,13,13,12,12,12,11,11,11,4,4,5,5,6,7,8,9,2,5,6,6,6,7,7,9,9,4,6,6,6,7,8,9,11,12,5,7,7,7,9,9,10,11,12,5,7,7,7,7,9,9,10,12,5,8,8,8,8,8,9,10,10,6,9,8,8,8,8,9,9,11,6,10,10,9,9,9,9,10,10,7,11,10,9,9,10,9,10,11,7,10,11,10,10,10,9,10,11,8,12,11,11,10,11,11,10,10,8,12,12,11,11,11,11,10,11,8,13,12,12,11,11,11,11,10,9,13,12,12,12,11,11,10,10,10,3,4,6,7,7,9,11,11,2,5,5,6,8,9,10,11,13,3,5,5,7,8,9,12,14,13,4,6,6,7,9,11,13,14,14,5,7,7,8,9,9,13,15,13,6,8,8,8,9,10,12,14,13,7,10,9,9,9,9,12,13,14,7,11,10,10,10,10,11,12,13,8,11,12,12,12,11,12,14,15,9,11,12,11,12,11,11,12,13,9,12,13,13,12,12,13,14,14,9,12,13,13,13,12,13,12,14,10,13,13,14,13,11,13,14,15,10,12,13,15,14,13,13,13,14,14,4,5,5,5,6,7,8,8,2,6,6,6,6,6,8,9,10,4,6,6,6,6,7,9,10,11,4,7,7,7,7,7,9,10,12,5,7,7,7,7,7,9,10,11,6,8,8,7,7,7,8,9,10,6,9,8,8,7,8,10,10,11,7,9,9,8,8,8,9,9,10,8,10,10,9,9,9,11,11,11,8,11,10,10,9,9,10,11,10,10,12,12,11,11,10,11,12,11,10,13,12,11,11,10,10,11,11,11,15,13,13,13,12,12,12,12,10,15,14,13,12,12,11,11,11,11,4,5,6,6,6,7,8,8,2,4,5,6,6,7,8,8,9,4,6,7,7,8,8,9,10,11,5,6,7,7,8,8,9,10,12,5,7,8,8,8,9,10,11,12,5,7,8,8,8,8,9,10,11,6,8,9,8,8,9,10,11,13,5,8,9,8,8,9,9,10,11,6,10,10,9,9,10,10,12,13,6,10,10,9,9,10,10,11,13,7,11,11,11,11,11,12,12,13,7,11,11,11,11,11,11,12,12,9,13,13,13,13,12,12,13,12,9,12,13,12,12,12,13,13,12,12,3,5,6,8,9,10,12,12,1,5,6,7,8,9,12,12,12,4,6,7,8,9,12,12,14,21,4,6,8,9,9,12,13,13,14,6,9,8,8,9,13,14,13,21,6,9,9,8,9,10,11,12,13,8,10,10,11,11,12,12,21,21,8,11,10,11,11,12,13,14,21,9,13,10,11,13,13,12,21,21,9,12,10,11,12,12,13,14,21,11,15,21,13,14,15,21,15,21,10,14,14,13,13,21,13,13,21,13,21,21,21,20,20,14,20,20,11,14,14,20,20,13,20,20,14,16,2,5,6,8,9,10,13,13,2,4,5,6,8,9,10,13,14,3,5,7,8,10,12,15,20,16,4,6,8,8,10,12,13,20,20,7,8,8,9,10,11,12,16,20,7,8,8,8,10,11,13,20,20,8,10,10,10,10,11,12,15,14,8,9,9,9,10,10,13,13,20,11,12,11,11,11,13,12,13,20,11,12,11,11,12,12,13,13,20,10,14,11,11,12,12,13,20,20,11,13,12,11,12,13,14,14,20,11,19,19,13,13,15,15,16,16,11,13,14,11,13,12,13,16,16,16,2,1,0,3,1,0,2,3,2,0,3,1,1,3,2,0,2,2,2,2,1,2,3,3,3,2,3,1,1,3,3,2,5,0,0,0,12,0,0,0,30,0,0,0,18,0,0,0,12,0,0,0,52,0,0,0,117,0,0,0,112,0,0,0,0,0,0,0,8,0,0,0,27,0,0,0,8,0,0,0,29,0,0,0,124,0,0,0,214,0,0,0,222,1,0,0,175,1,0,0,5,0,0,0,27,0,0,0,38,0,0,0,30,0,0,0,18,0,0,0,118,0,0,0,77,0,0,0,246,1,0,0,244,1,0,0,57,0,0,0,127,0,0,0,39,0,0,0,106,0,0,0,113,0,0,0,53,0,0,0,113,0,0,0,104,0,0,0,220,1,0,0,39,0,0,0,115,0,0,0,255,0,0,0,232,0,0,0,233,0,0,0,126,0,0,0,249,1,0,0,245,1,0,0,253,1,0,0,62,0,0,0,202,1,0,0,249,3,0,0,76,0,0,0,105,0,0,0,250,1,0,0,223,1,0,0,247,1,0,0,112,0,0,0,221,1,0,0,77,14,0,0,39,7,0,0,146,3,0,0,200,1,0,0,203,1,0,0,248,3,0,0,174,1,0,0,248,1,0,0,251,1,0,0,206,228,0,0,207,228,0,0,96,114,0,0,97,114,0,0,98,114,0,0,99,114,0,0,100,114,0,0,101,114,0,0,102,114,0,0,7,0,0,0,1,0,0,0,7,0,0,0,22,0,0,0,1,0,0,0,69,0,0,0,24,0,0,0,182,2,0,0,6,0,0,0,4,0,0,0,23,0,0,0,16,0,0,0,41,0,0,0,44,0,0,0,90,1,0,0,102,0,0,0,158,1,0,0,9,0,0,0,40,0,0,0,23,0,0,0,0,0,0,0,42,0,0,0,4,0,0,0,91,0,0,0,181,0,0,0,206,0,0,0,6,0,0,0,68,0,0,0,15,0,0,0,70,0,0,0,14,0,0,0,172,0,0,0,50,0,0,0,55,0,0,0,235,17,0,0,10,0,0,0,26,0,0,0,31,1,0,0,22,0,0,0,20,0,0,0,43,0,0,0,104,1,0,0,85,0,0,0,213,35,0,0,87,0,0,0,47,0,0,0,54,0,0,0,46,0,0,0,105,1,0,0,84,0,0,0,123,4,0,0,159,1,0,0,125,43,0,0,142,0,0,0,222,10,0,0,121,4,0,0,110,5,0,0,244,8,0,0,191,21,0,0,120,4,0,0,212,35,0,0,241,173,0,0,249,86,0,0,14,223,10,0,15,223,10,0,128,111,5,0,129,111,5,0,130,111,5,0,131,111,5,0,132,111,5,0,133,111,5,0,134,111,5,0,2,0,0,0,6,0,0,0,7,0,0,0,13,0,0,0,7,0,0,0,48,0,0,0,255,0,0,0,240,1,0,0,2,0,0,0,0,0,0,0,5,0,0,0,25,0,0,0,30,0,0,0,7,0,0,0,99,0,0,0,253,0,0,0,35,0,0,0,14,0,0,0,27,0,0,0,26,0,0,0,6,0,0,0,9,0,0,0,24,0,0,0,197,0,0,0,51,0,0,0,241,1,0,0,2,0,0,0,251,3,0,0,243,1,0,0,34,0,0,0,252,1,0,0,66,0,0,0,35,6,0,0,131,0,0,0,32,6,0,0,125,0,0,0,64,0,0,0,67,0,0,0,228,3,0,0,229,3,0,0,145,1,0,0,233,15,0,0,5,1,0,0,8,2,0,0,252,0,0,0,36,6,0,0,34,6,0,0,144,1,0,0,38,6,0,0,245,7,0,0,75,12,0,0,208,31,0,0,77,16,0,0,101,0,0,0,66,12,0,0,201,0,0,0,39,6,0,0,67,12,0,0,74,12,0,0,78,16,0,0,209,31,0,0,79,16,0,0,18,4,0,0,206,4,1,0,207,4,1,0,96,130,0,0,97,130,0,0,98,130,0,0,99,130,0,0,100,130,0,0,101,130,0,0,102,130,0,0,13,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,23,0,0,0,5,0,0,0,127,0,0,0,77,0,0,0,3,0,0,0,17,0,0,0,62,0,0,0,59,0,0,0,23,0,0,0,103,0,0,0,74,0,0,0,195,0,0,0,242,0,0,0,10,0,0,0,44,0,0,0,50,0,0,0,61,0,0,0,21,0,0,0,40,0,0,0,147,0,0,0,204,0,0,0,150,0,0,0,3,0,0,0,117,0,0,0,32,0,0,0,45,0,0,0,33,0,0,0,41,0,0,0,144,0,0,0,208,1,0,0,251,1,0,0,28,0,0,0,76,0,0,0,96,0,0,0,9,0,0,0,8,0,0,0,45,0,0,0,159,0,0,0,250,1,0,0,61,1,0,0,49,0,0,0,252,0,0,0,88,0,0,0,146,0,0,0,240,0,0,0,241,0,0,0,205,0,0,0,133,1,0,0,101,1,0,0,78,0,0,0,145,0,0,0,233,0,0,0,132,1,0,0,209,1,0,0,230,1,0,0,151,0,0,0,231,1,0,0,179,0,0,0,60,1,0,0,78,22,0,0,79,22,0,0,32,11,0,0,33,11,0,0,34,11,0,0,35,11,0,0,36,11,0,0,37,11,0,0,38,11,0,0,3,4,5,5,5,6,7,7,2,4,5,5,6,7,8,9,9,4,6,6,6,6,7,8,9,9,6,8,7,7,7,7,8,8,9,6,8,8,8,8,8,9,9,9,7,10,10,8,8,9,9,9,8,9,13,12,11,10,10,10,9,9,9,17,17,16,16,16,16,16,16,16,3,3,4,5,5,7,8,10,3,4,5,5,6,7,9,10,12,4,6,6,5,6,6,8,9,11,4,7,7,7,7,8,9,9,13,5,8,9,8,8,9,10,10,14,7,9,9,9,10,10,11,12,14,8,12,11,11,12,13,11,14,16,15,20,20,19,19,19,19,19,19,19,3,4,4,4,5,6,8,9,2,4,5,5,5,6,7,8,8,4,7,7,6,6,7,8,8,9,5,10,9,8,9,9,11,10,11,7,9,9,10,10,11,12,11,12,8,11,11,11,11,11,12,13,15,9,12,10,11,12,12,15,13,15,13,19,19,18,18,18,18,18,18,18,4,4,4,4,5,5,7,7,3,5,6,6,6,7,7,8,8,4,6,6,6,6,7,8,8,8,4,7,6,6,6,7,8,9,9,5,7,7,6,6,7,8,9,9,6,8,8,8,8,8,8,9,10,7,8,8,9,9,9,8,9,9,9,14,14,13,13,13,13,13,13,13,192,123,37,0,192,137,39,0,0,0,0,0,156,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,3,0,0,0,0,0,0,0,0,0,0,14,1,0,0,34,11,0,0,0,0,0,0,0,0,0,0,24,126,37,0,152,138,39,0,0,0,0,0,109,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,2,0,0,0,0,0,0,0,0,0,0,88,1,0,0,172,11,0,0,0,0,0,0,0,0,0,0,96,128,37,0,224,138,39,0,0,0,0,0,158,0,0,0,0,0,0,0,0,0,0,0,104,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,4,0,0,0,0,0,0,102,2,0,0,0,0,0,0,142,5,0,0,0,0,0,0,0,0,0,0,168,129,37,0,0,139,39,0,0,0,0,0,158,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,8,0,0,0,0,0,0,0,0,0,0,76,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,74,37,0,0,240,35,0,0,0,0,0,56,48,52,86,0,0,0,0,0,0,0,0,152,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,2,0,0,0,0,0,0,238,1,0,0,0,0,0,0,146,4,0,0,0,0,0,0,0,0,0,0,104,75,37,0,56,240,35,0,0,0,0,0,56,48,52,86,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,11,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,132,37,0,8,140,39,0,0,0,0,0,56,48,51,86,0,0,0,0,0,0,0,0,120,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,8,0,0,0,0,0,0,176,2,0,0,0,0,0,0,216,6,0,0,0,0,0,0,0,0,0,0,200,132,37,0,64,140,39,0,0,0,0,0,56,48,51,86,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,2,3,3,9,5,5,4,33,7,32,7,17,6,1,1,0,3,1,3,1,2,136,134,37,0,168,140,39,0,0,0,0,0,126,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,4,0,0,0,0,0,0,0,0,0,0,90,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,135,37,0,248,140,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,128,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,246,1,0,0,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,16,138,37,0,40,141,39,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,78,4,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,10,0,0,0,0,0,0,0,0,0,0,26,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,140,37,0,136,141,39,0,0,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,136,100,40], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1265408);
/* memory initializer */ allocate([28,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,10,0,0,0,0,0,0,144,1,0,0,0,0,0,0,84,11,0,0,0,0,0,0,0,0,0,0,232,143,37,0,80,143,39,0,0,0,0,0,154,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,170,0,0,0,184,3,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,80,41,40,0,128,254,39,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,7,0,0,142,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,1,0,0,0,0,0,0,0,0,0,0,200,150,37,0,80,145,39,0,0,0,0,0,58,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,10,0,0,0,0,0,0,0,0,0,0,100,0,0,0,50,11,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,31,32,32,32,32,32,32,32,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,41,40,0,160,254,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,1,0,0,68,11,0,0,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,151,37,0,96,145,39,0,0,0,0,0,106,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,152,151,37,0,192,145,39,0,1,0,0,0,44,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,3,0,0,0,0,0,0,0,0,0,0,248,0,0,0,112,6,0,0,0,0,0,0,0,0,0,0,8,42,40,0,192,254,39,0,0,0,0,0,240,144,37,0,0,0,0,0,40,154,4,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,238,3,0,0,234,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,124,19,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,0,0,0,128,10,9,10,12,0,0,0,0,216,151,37,0,248,145,39,0,1,0,0,0,22,80,1,0,64,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,176,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,0,0,0,0,0,0,0,140,2,0,0,0,0,0,0,140,7,0,0,0,0,0,0,0,0,0,0,96,42,40,0,216,254,39,0,0,0,0,0,96,42,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,110,11,0,0,180,6,0,0,142,3,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,152,37,0,16,146,39,0,1,0,0,0,22,80,1,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,154,4,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,1,0,0,0,0,0,0,0,0,0,0,46,1,0,0,162,11,0,0,0,0,0,0,0,0,0,0,16,153,37,0,136,146,39,0,0,0,0,0,57,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,7,0,0,0,0,0,0,0,0,0,0,50,0,0,0,50,7,0,0,0,0,0,0,0,0,0,0,208,152,37,0,104,146,39,0,0,0,0,0,165,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,9,0,0,0,0,0,0,0,0,0,0,158,1,0,0,36,7,0,0,0,0,0,0,0,0,0,0,144,153,37,0,200,146,39,0,1,0,0,0,21,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,7,0,0,0,0,0,0,0,0,0,0,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,154,37,0,224,146,39,0,0,0,0,0,78,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,3,0,0,0,0,0,0,0,0,0,0,106,0,0,0,58,11,0,0,0,0,0,0,0,0,0,0,168,154,37,0,248,146,39,0,0,0,0,0,52,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,10,0,0,0,0,0,0,0,0,0,0,94,1,0,0,2,5,0,0,0,0,0,0,0,0,0,0,0,226,33,0,80,213,33,0,0,0,0,0,0,202,33,0,45,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,63,39,0,216,247,38,0,0,1,0,0,24,178,38,0,0,0,0,0,0,0,0,0,0,0,0,0,45,80,1,0,0,0,0,0,0,0,0,0,148,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,99,37,0,0,7,36,0,1,0,0,0,45,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,9,0,0,0,0,0,0,0,0,0,0,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,32,37,31,31,0,0,0,0,0,0,0,0,9,9,10,14,14,14,14,14,14,14,14,14,14,0,0,0,31,31,34,40,42,51,46,46,42,42,42,39,39,0,0,0,176,42,40,0,240,254,39,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,74,5,0,0,100,4,0,0,118,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,154,37,0,16,147,39,0,0,0,0,0,127,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,10,0,0,0,0,0,0,0,0,0,0,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,91,5,230,27,151,169,73,67,136,23,26,101,90,41,138,151,116,0,105,0,109,0,101,0,108,0,105,0,110,0,101,0,46,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,101,0,110,0,116,0,114,0,105,0,101,0,115,0,46,0,69,0,118,0,101,0,110,0,116,0,115,0,0,0,116,0,105,0,109,0,101,0,108,0,105,0,110,0,101,0,200,33,35,0,0,0,0,0,48,246,34,0,177,135,0,0,24,220,34,0,0,0,0,0,96,205,34,0,0,0,0,0,224,21,38,0,152,21,38,0,232,20,38,0,152,20,38,0,64,20,38,0,216,19,38,0,128,19,38,0,232,18,38,0,80,18,38,0,16,18,38,0,216,17,38,0,168,17,38,0,128,17,38,0,224,16,38,0,112,16,38,0,192,15,38,0,88,15,38,0,152,14,38,0,80,14,38,0,40,14,38,0,160,13,38,0,96,13,38,0,24,13,38,0,120,12,38,0,40,12,38,0,232,11,38,0,200,11,38,0,240,10,38,0,200,10,38,0,160,10,38,0,32,10,38,0,168,9,38,0,117,39,0,0,224,224,38,0,118,39,0,0,208,223,38,0,147,39,0,0,200,219,38,0,148,39,0,0,104,217,38,0,217,39,0,0,160,216,38,0,218,39,0,0,192,215,38,0,219,39,0,0,32,215,38,0,247,39,0,0,176,214,38,0,248,39,0,0,240,213,38,0,249,39,0,0,128,213,38,0,61,40,0,0,8,213,38,0,62,40,0,0,48,212,38,0,91,40,0,0,0,211,38,0,92,40,0,0,16,210,38,0,161,40,0,0,168,209,38,0,162,40,0,0,104,209,38,0,163,40,0,0,208,208,38,0,164,40,0,0,168,208,38,0,165,40,0,0,24,208,38,0,166,40,0,0,192,207,38,0,167,40,0,0,48,207,38,0,191,40,0,0,240,206,38,0,192,40,0,0,144,205,38,0,193,40,0,0,48,205,38,0,194,40,0,0,168,204,38,0,195,40,0,0,112,204,38,0,196,40,0,0,176,203,38,0,5,41,0,0,32,203,38,0,6,41,0,0,248,201,38,0,7,41,0,0,40,201,38,0,35,41,0,0,152,200,38,0,36,41,0,0,16,200,38,0,37,41,0,0,8,199,38,0,104,41,0,0,144,198,38,0,134,41,0,0,64,198,38,0,204,41,0,0,40,198,38,0,234,41,0,0,0,198,38,0,149,42,0,0,200,197,38,0,150,42,0,0,168,196,38,0,151,42,0,0,32,196,38,0,179,42,0,0,144,195,38,0,180,42,0,0,88,195,38,0,181,42,0,0,112,194,38,0,249,42,0,0,248,193,38,0,250,42,0,0,168,193,38,0,23,43,0,0,72,193,38,0,24,43,0,0,0,193,38,0,93,43,0,0,184,192,38,0,94,43,0,0,248,191,38,0,95,43,0,0,248,190,38,0,123,43,0,0,184,190,38,0,124,43,0,0,64,190,38,0,125,43,0,0,88,189,38,0,193,43,0,0,0,189,38,0,194,43,0,0,152,188,38,0,223,43,0,0,56,188,38,0,224,43,0,0,248,187,38,0,37,44,0,0,152,187,38,0,38,44,0,0,208,186,38,0,67,44,0,0,184,186,38,0,68,44,0,0,64,185,38,0,137,44,0,0,32,185,38,0,138,44,0,0,232,183,38,0,167,44,0,0,64,183,38,0,168,44,0,0,200,182,38,0,237,44,0,0,112,182,38,0,238,44,0,0,176,181,38,0,11,45,0,0,88,181,38,0,12,45,0,0,120,180,38,0,81,45,0,0,48,180,38,0,82,45,0,0,200,179,38,0,111,45,0,0,160,179,38,0,112,45,0,0,160,178,38,0,181,45,0,0,56,178,38,0,182,45,0,0,224,177,38,0,211,45,0,0,168,177,38,0,212,45,0,0,24,177,38,0,25,46,0,0,224,176,38,0,26,46,0,0,144,175,38,0,55,46,0,0,56,175,38,0,56,46,0,0,232,174,38,0,124,46,0,0,152,174,38,0,154,46,0,0,216,173,38,0,225,46,0,0,80,173,38,0,226,46,0,0,0,173,38,0,255,46,0,0,216,172,38,0,0,47,0,0,160,172,38,0,69,47,0,0,120,172,38,0,70,47,0,0,64,172,38,0,71,47,0,0,200,171,38,0,79,47,0,0,152,171,38,0,80,47,0,0,216,168,38,0,81,47,0,0,240,166,38,0,109,47,0,0,168,165,38,0,110,47,0,0,200,163,38,0,111,47,0,0,0,162,38,0,169,47,0,0,64,160,38,0,170,47,0,0,192,158,38,0,171,47,0,0,200,157,38,0,199,47,0,0,96,156,38,0,200,47,0,0,240,154,38,0,201,47,0,0,240,153,38,0,13,48,0,0,208,150,38,0,14,48,0,0,104,148,38,0,43,48,0,0,80,147,38,0,44,48,0,0,56,146,38,0,113,48,0,0,224,145,38,0,114,48,0,0,160,145,38,0,115,48,0,0,136,144,38,0,143,48,0,0,64,144,38,0,144,48,0,0,176,143,38,0,145,48,0,0,64,143,38,0,213,48,0,0,56,142,38,0,214,48,0,0,104,141,38,0,215,48,0,0,16,141,38,0,242,48,0,0,216,140,38,0,57,49,0,0,112,140,38,0,58,49,0,0,56,140,38,0,86,49,0,0,184,139,38,0,157,49,0,0,160,139,38,0,158,49,0,0,16,139,38,0,159,49,0,0,176,138,38,0,187,49,0,0,184,137,38,0,188,49,0,0,64,137,38,0,189,49,0,0,160,136,38,0,0,50,0,0,56,136,38,0,30,50,0,0,136,135,38,0,100,50,0,0,32,135,38,0,130,50,0,0,152,134,38,0,201,50,0,0,96,134,38,0,202,50,0,0,184,133,38,0,203,50,0,0,80,133,38,0,231,50,0,0,112,132,38,0,232,50,0,0,0,132,38,0,233,50,0,0,176,131,38,0,45,51,0,0,136,131,38,0,46,51,0,0,40,131,38,0,47,51,0,0,0,131,38,0,48,51,0,0,96,130,38,0,75,51,0,0,8,130,38,0,76,51,0,0,192,129,38,0,77,51,0,0,168,129,38,0,78,51,0,0,136,128,38,0,144,51,0,0,32,128,38,0,174,51,0,0,0,128,38,0,245,51,0,0,176,127,38,0,246,51,0,0,120,127,38,0,19,52,0,0,24,127,38,0,20,52,0,0,176,126,38,0,89,52,0,0,32,126,38,0,90,52,0,0,240,125,38,0,119,52,0,0,216,125,38,0,120,52,0,0,24,125,38,0,189,52,0,0,152,124,38,0,190,52,0,0,64,124,38,0,219,52,0,0,152,123,38,0,220,52,0,0,80,123,38,0,33,53,0,0,232,122,38,0,34,53,0,0,112,122,38,0,63,53,0,0,88,122,38,0,64,53,0,0,48,122,38,0,133,53,0,0,168,121,38,0,134,53,0,0,248,120,38,0,163,53,0,0,64,120,38,0,164,53,0,0,192,119,38,0,232,53,0,0,104,119,38,0,6,54,0,0,0,119,38,0,77,54,0,0,168,118,38,0,78,54,0,0,48,118,38,0,106,54,0,0,240,117,38,0,177,54,0,0,136,117,38,0,178,54,0,0,64,117,38,0,207,54,0,0,32,116,38,0,208,54,0,0,208,115,38,0,20,55,0,0,168,115,38,0,50,55,0,0,120,115,38,0,121,55,0,0,248,114,38,0,122,55,0,0,176,114,38,0,123,55,0,0,96,114,38,0,124,55,0,0,40,114,38,0,125,55,0,0,200,113,38,0,151,55,0,0,168,113,38,0,152,55,0,0,160,112,38,0,153,55,0,0,120,112,38,0,154,55,0,0,56,112,38,0,155,55,0,0,32,112,38,0,221,55,0,0,8,112,38,0,222,55,0,0,208,111,38,0,223,55,0,0,8,111,38,0,251,55,0,0,232,110,38,0,252,55,0,0,192,110,38,0,253,55,0,0,200,108,38,0,64,56,0,0,160,106,38,0,94,56,0,0,216,105,38,0,165,56,0,0,248,103,38,0,166,56,0,0,112,102,38,0,195,56,0,0,184,100,38,0,196,56,0,0,48,99,38,0,9,57,0,0,232,97,38,0,10,57,0,0,184,96,38,0,39,57,0,0,72,95,38,0,40,57,0,0,80,94,38,0,109,57,0,0,144,91,38,0,110,57,0,0,200,89,38,0,139,57,0,0,232,88,38,0,140,57,0,0,240,87,38,0,209,57,0,0,200,86,38,0,210,57,0,0,144,86,38,0,211,57,0,0,144,85,38,0,239,57,0,0,64,85,38,0,240,57,0,0,184,84,38,0,241,57,0,0,64,84,38,0,53,58,0,0,56,83,38,0,54,58,0,0,80,82,38,0,55,58,0,0,200,81,38,0,56,58,0,0,160,81,38,0,83,58,0,0,8,81,38,0,84,58,0,0,136,80,38,0,85,58,0,0,16,80,38,0,86,58,0,0,176,79,38,0,153,58,0,0,64,79,38,0,154,58,0,0,32,79,38,0,155,58,0,0,112,78,38,0,156,58,0,0,8,78,38,0,157,58,0,0,72,77,38,0,158,58,0,0,232,76,38,0,159,58,0,0,104,76,38,0,160,58,0,0,184,75,38,0,161,58,0,0,48,75,38,0,162,58,0,0,216,74,38,0,183,58,0,0,120,74,38,0,184,58,0,0,56,74,38,0,185,58,0,0,152,73,38,0,186,58,0,0,8,73,38,0,187,58,0,0,208,72,38,0,188,58,0,0,168,72,38,0,189,58,0,0,144,72,38,0,190,58,0,0,120,72,38,0,191,58,0,0,16,72,38,0,192,58,0,0,200,71,38,0,253,58,0,0,112,71,38,0,254,58,0,0,88,71,38,0,255,58,0,0,8,71,38,0,0,59,0,0,184,70,38,0,1,59,0,0,104,70,38,0,27,59,0,0,24,70,38,0,28,59,0,0,200,69,38,0,29,59,0,0,168,69,38,0,30,59,0,0,224,68,38,0,31,59,0,0,144,68,38,0,97,59,0,0,48,68,38,0,98,59,0,0,0,68,38,0,126,59,0,0,88,67,38,0,42,62,0,0,248,66,38,0,43,62,0,0,216,66,38,0,44,62,0,0,104,66,38,0,45,62,0,0,72,66,38,0,196,67,0,0,176,65,38,0,197,67,0,0,72,65,38,0,198,67,0,0,8,65,38,0,199,67,0,0,224,64,38,0,200,67,0,0,184,64,38,0,201,67,0,0,8,64,38,0,202,67,0,0,160,63,38,0,203,67,0,0,56,63,38,0,204,67,0,0,240,62,38,0,205,67,0,0,192,62,38,0,206,67,0,0,120,62,38,0,40,68,0,0,168,61,38,0,41,68,0,0,128,61,38,0,42,68,0,0,248,60,38,0,43,68,0,0,160,60,38,0,44,68,0,0,232,59,38,0,45,68,0,0,192,59,38,0,46,68,0,0,128,59,38,0,47,68,0,0,88,59,38,0,48,68,0,0,240,58,38,0,49,68,0,0,112,58,38,0,50,68,0,0,24,58,38,0,111,70,0,0,248,57,38,0,112,70,0,0,48,57,38,0,113,70,0,0,24,57,38,0,114,70,0,0,160,56,38,0,115,70,0,0,128,56,38,0,116,70,0,0,104,56,38,0,117,70,0,0,80,56,38,0,131,70,0,0,40,56,38,0,132,70,0,0,248,55,38,0,133,70,0,0,160,55,38,0,134,70,0,0,136,55,38,0,152,70,0,0,56,55,38,0,153,70,0,0,224,53,38,0,154,70,0,0,72,52,38,0,221,70,0,0,88,51,38,0,222,70,0,0,40,49,38,0,188,77,0,0,240,47,38,0,193,77,0,0,96,46,38,0,200,77,0,0,232,44,38,0,144,41,38,0,0,0,0,0,184,247,37,0,177,135,0,0,8,205,37,0,0,0,0,0,208,167,37,0,0,0,0,0,64,130,37,0,0,0,0,0,0,64,37,0,176,135,0,0,64,18,37,0,176,135,0,0,104,233,36,0,176,135,0,0,72,198,36,0,176,135,0,0,104,168,36,0,176,135,0,0,208,141,36,0,176,135,0,0,152,113,36,0,176,135,0,0,200,86,36,0,176,135,0,0,32,61,36,0,176,135,0,0,88,34,36,0,176,135,0,0,176,232,35,0,176,135,0,0,240,199,35,0,176,135,0,0,16,176,35,0,176,135,0,0,104,154,35,0,176,135,0,0,32,133,35,0,176,135,0,0,152,110,35,0,176,135,0,0,152,90,35,0,176,135,0,0,8,73,35,0,176,135,0,0,232,54,35,0,176,135,0,0,169,78,0,0,168,204,34,0,170,78,0,0,200,201,34,0,24,79,0,0,144,200,34,0,25,79,0,0,64,199,34,0,26,79,0,0,104,198,34,0,27,79,0,0,64,197,34,0,28,79,0,0,16,196,34,0,29,79,0,0,32,195,34,0,30,79,0,0,128,193,34,0,31,79,0,0,136,192,34,0,32,79,0,0,8,188,34,0,33,79,0,0,88,185,34,0,34,79,0,0,48,184,34,0,124,79,0,0,32,183,34,0,125,79,0,0,0,182,34,0,126,79,0,0,80,181,34,0,127,79,0,0,8,180,34,0,128,79,0,0,136,178,34,0,129,79,0,0,16,177,34,0,130,79,0,0,128,175,34,0,131,79,0,0,216,170,34,0,132,79,0,0,24,167,34,0,133,79,0,0,176,165,34,0,134,79,0,0,24,164,34,0,213,79,0,0,168,162,34,0,214,79,0,0,216,160,34,0,215,79,0,0,192,159,34,0,19,80,0,0,200,158,34,0,58,80,0,0,192,157,34,0,59,80,0,0,88,156,34,0,220,80,0,0,200,151,34,0,86,81,0,0,104,149,34,0,87,81,0,0,208,147,34,0,88,81,0,0,216,146,34,0,237,81,0,0,168,145,34,0,239,81,0,0,56,145,34,0,241,81,0,0,88,144,34,0,243,81,0,0,128,143,34,0,245,81,0,0,168,142,34,0,247,81,0,0,112,141,34,0,249,81,0,0,8,138,34,0,251,81,0,0,144,135,34,0,253,81,0,0,80,134,34,0,255,81,0,0,64,133,34,0,1,82,0,0,48,132,34,0,3,82,0,0,16,131,34,0,108,82,0,0,56,130,34,0,156,82,0,0,192,128,34,0,157,82,0,0,136,127,34,0,158,82,0,0,208,126,34,0,165,83,0,0,192,122,34,0,166,83,0,0,0,120,34,0,167,83,0,0,16,119,34,0,168,83,0,0,112,117,34,0,169,83,0,0,144,115,34,0,170,83,0,0,64,114,34,0,171,83,0,0,0,113,34,0,172,83,0,0,120,111,34,0,173,83,0,0,40,110,34,0,174,83,0,0,104,109,34,0,175,83,0,0,224,105,34,0,225,83,0,0,40,103,34,0,226,83,0,0,120,102,34,0,227,83,0,0,176,101,34,0,228,83,0,0,232,100,34,0,229,83,0,0,96,100,34,0,230,83,0,0,168,99,34,0,231,83,0,0,160,98,34,0,232,83,0,0,168,96,34,0,233,83,0,0,168,93,34,0,234,83,0,0,168,86,34,0,235,83,0,0,248,81,34,0,252,83,0,0,128,76,34,0,30,85,0,0,216,72,34,0,57,85,0,0,56,69,34,0,58,85,0,0,176,66,34,0,131,85,0,0,240,63,34,0,132,85,0,0,8,59,34,0,133,85,0,0,152,55,34,0,134,85,0,0,248,52,34,0,16,86,0,0,128,46,34,0,17,86,0,0,200,41,34,0,175,86,0,0,0,39,34,0,176,86,0,0,8,37,34,0,177,86,0,0,176,35,34,0,178,86,0,0,128,34,34,0,179,86,0,0,32,33,34,0,180,86,0,0,16,32,34,0,181,86,0,0,144,30,34,0,60,87,0,0,8,29,34,0,119,87,0,0,224,25,34,0,120,87,0,0,104,23,34,0,251,87,0,0,80,22,34,0,252,87,0,0,192,21,34,0,48,89,0,0,184,20,34,0,208,89,0,0,184,19,34,0,209,89,0,0,192,18,34,0,210,89,0,0,136,17,34,0,244,89,0,0,168,16,34,0,245,89,0,0,232,14,34,0,246,89,0,0,144,11,34,0,247,89,0,0,224,9,34,0,248,89,0,0,40,8,34,0,249,89,0,0,232,6,34,0,250,89,0,0,0,6,34,0,251,89,0,0,136,4,34,0,252,89,0,0,64,3,34,0,253,89,0,0,216,1,34,0,254,89,0,0,240,0,34,0,199,90,0,0,248,255,33,0,200,90,0,0,152,252,33,0,137,91,0,0,112,250,33,0,38,93,0,0,128,249,33,0,39,93,0,0,120,248,33,0,40,93,0,0,224,246,33,0,41,93,0,0,24,246,33,0,42,93,0,0,0,245,33,0,43,93,0,0,168,242,33,0,44,93,0,0,232,238,33,0,45,93,0,0,224,237,33,0,78,93,0,0,152,234,33,0,79,93,0,0,24,232,33,0,80,93,0,0,152,230,33,0,81,93,0,0,208,229,33,0,82,93,0,0,48,229,33,0,83,93,0,0,24,228,33,0,84,93,0,0,8,227,33,0,85,93,0,0,40,226,33,0,86,93,0,0,40,225,33,0,139,93,0,0,120,223,33,0,140,93,0,0,0,220,33,0,239,93,0,0,184,217,33,0,240,93,0,0,192,216,33,0,36,94,0,0,0,216,33,0,136,94,0,0,136,215,33,0,50,95,0,0,0,215,33,0,51,95,0,0,24,214,33,0,52,95,0,0,96,213,33,0,53,95,0,0,168,212,33,0,54,95,0,0,216,211,33,0,62,95,0,0,136,208,33,0,63,95,0,0,136,206,33,0,64,95,0,0,208,205,33,0,180,95,0,0,24,205,33,0,227,95,0,0,136,204,33,0,228,95,0,0,240,203,33,0,144,96,0,0,56,203,33,0,145,96,0,0,32,202,33,0,242,96,0,0,160,201,33,0,243,96,0,0,32,201,33,0,244,96,0,0,96,198,33,0,245,96,0,0,88,196,33,0,45,97,0,0,248,195,33,0,46,97,0,0,144,195,33,0,47,97,0,0,8,195,33,0,48,97,0,0,64,194,33,0,59,97,0,0,88,193,33,0,60,97,0,0,192,192,33,0,61,97,0,0,184,191,33,0,168,97,0,0,96,191,33,0,143,98,0,0,152,189,33,0,47,99,0,0,88,188,33,0,48,99,0,0,8,188,33,0,49,99,0,0,200,187,33,0,50,99,0,0,128,187,33,0,51,99,0,0,56,187,33,0,100,100,0,0,200,186,33,0,76,101,0,0,72,186,33,0,79,102,0,0,216,184,33,0,80,102,0,0,160,181,33,0,81,102,0,0,200,176,33,0,125,102,0,0,56,173,33,0,219,102,0,0,104,168,33,0,220,102,0,0,168,165,33,0,23,103,0,0,192,162,33,0,24,103,0,0,184,160,33,0,25,103,0,0,168,157,33,0,64,103,0,0,96,153,33,0,223,103,0,0,96,150,33,0,224,103,0,0,64,148,33,0,8,104,0,0,112,142,33,0,68,104,0,0,64,138,33,0,79,104,0,0,88,136,33,0,80,104,0,0,120,134,33,0,81,104,0,0,128,133,33,0,82,104,0,0,72,133,33,0,83,104,0,0,88,132,33,0,84,104,0,0,112,131,33,0,85,104,0,0,16,130,33,0,86,104,0,0,128,129,33,0,87,104,0,0,136,126,33,0,88,104,0,0,192,124,33,0,89,104,0,0,232,123,33,0,90,104,0,0,136,123,33,0,91,104,0,0,248,122,33,0,92,104,0,0,104,122,33,0,93,104,0,0,176,121,33,0,94,104,0,0,216,120,33,0,95,104,0,0,16,120,33,0,96,104,0,0,96,119,33,0,97,104,0,0,0,117,33,0,98,104,0,0,184,115,33,0,105,104,0,0,232,114,33,0,106,104,0,0,232,113,33,0,107,104,0,0,152,113,33,0,108,104,0,0,216,112,33,0,109,104,0,0,232,111,33,0,110,104,0,0,16,111,33,0,111,104,0,0,40,110,33,0,112,104,0,0,136,109,33,0,113,104,0,0,64,107,33,0,114,104,0,0,88,105,33,0,115,104,0,0,120,104,33,0,116,104,0,0,8,104,33,0,117,104,0,0,208,103,33,0,118,104,0,0,144,103,33,0,119,104,0,0,104,102,33,0,120,104,0,0,144,101,33,0,121,104,0,0,88,100,33,0,122,104,0,0,120,99,33,0,123,104,0,0,104,97,33,0,124,104,0,0,208,95,33,0,125,104,0,0,120,94,33,0,126,104,0,0,192,93,33,0,127,104,0,0,96,93,33,0,128,104,0,0,192,92,33,0,129,104,0,0,112,91,33,0,130,104,0,0,184,90,33,0,131,104,0,0,8,90,33,0,132,104,0,0,96,89,33,0,133,104,0,0,0,87,33,0,134,104,0,0,184,85,33,0,135,104,0,0,248,84,33,0,136,104,0,0,184,84,33,0,137,104,0,0,48,84,33,0,138,104,0,0,144,83,33,0,139,104,0,0,232,82,33,0,140,104,0,0,24,82,33,0,141,104,0,0,144,81,33,0,142,104,0,0,128,80,33,0,143,104,0,0,120,78,33,0,144,104,0,0,64,77,33,0,145,104,0,0,128,76,33,0,146,104,0,0,232,75,33,0,147,104,0,0,176,75,33,0,148,104,0,0,24,75,33,0,149,104,0,0,40,74,33,0,150,104,0,0,104,73,33,0,150,104,0,0,224,72,33,0,151,104,0,0,64,72,33,0,151,104,0,0,152,70,33,0,152,104,0,0,152,68,33,0,152,104,0,0,40,68,33,0,153,104,0,0,208,67,33,0,153,104,0,0,48,67,33,0,154,104,0,0,112,66,33,0,155,104,0,0,104,65,33,0,156,104,0,0,160,64,33,0,157,104,0,0,208,63,33,0,158,104,0,0,64,63,33,0,159,104,0,0,192,61,33,0,160,104,0,0,208,60,33,0,161,104,0,0,128,60,33,0,162,104,0,0,64,60,33,0,163,104,0,0,16,60,33,0,164,104,0,0,160,59,33,0,165,104,0,0,224,58,33,0,166,104,0,0,24,58,33,0,167,104,0,0,0,57,33,0,168,104,0,0,64,54,33,0,169,104,0,0,8,50,33,0,170,104,0,0,144,46,33,0,171,104,0,0,104,42,33,0,172,104,0,0,8,40,33,0,173,104,0,0,8,38,33,0,174,104,0,0,8,36,33,0,177,104,0,0,200,33,33,0,178,104,0,0,72,29,33,0,179,104,0,0,88,26,33,0,23,105,0,0,8,24,33,0,24,105,0,0,232,18,33,0,25,105,0,0,8,15,33,0,26,105,0,0,64,13,33,0,27,105,0,0,112,11,33,0,28,105,0,0,96,10,33,0,29,105,0,0,232,9,33,0,30,105,0,0,152,8,33,0,31,105,0,0,208,7,33,0,32,105,0,0,224,6,33,0,33,105,0,0,8,6,33,0,34,105,0,0,80,4,33,0,35,105,0,0,24,3,33,0,36,105,0,0,168,2,33,0,37,105,0,0,24,2,33,0,38,105,0,0,128,1,33,0,39,105,0,0,232,0,33,0,40,105,0,0,72,0,33,0,41,105,0,0,192,255,32,0,42,105,0,0,248,254,32,0,43,105,0,0,136,254,32,0,49,105,0,0,56,252,32,0,50,105,0,0,64,251,32,0,51,105,0,0,88,250,32,0,52,105,0,0,224,249,32,0,53,105,0,0,64,249,32,0,54,105,0,0,152,248,32,0,55,105,0,0,216,247,32,0,56,105,0,0,96,247,32,0,57,105,0,0,208,246,32,0,58,105,0,0,56,246,32,0,59,105,0,0,120,244,32,0,60,105,0,0,48,243,32,0,61,105,0,0,216,242,32,0,62,105,0,0,128,242,32,0,63,105,0,0,88,242,32,0,64,105,0,0,40,242,32,0,65,105,0,0,248,240,32,0,66,105,0,0,8,240,32,0,68,105,0,0,128,239,32,0,69,105,0,0,8,239,32,0,70,105,0,0,0,237,32,0,71,105,0,0,72,235,32,0,72,105,0,0,240,234,32,0,73,105,0,0,152,234,32,0,74,105,0,0,72,234,32,0,75,105,0,0,248,233,32,0,76,105,0,0,8,233,32,0,77,105,0,0,152,232,32,0,78,105,0,0,248,231,32,0,79,105,0,0,192,231,32,0,80,105,0,0,72,230,32,0,81,105,0,0,112,229,32,0,82,105,0,0,160,228,32,0,83,105,0,0,120,228,32,0,84,105,0,0,216,227,32,0,85,105,0,0,8,227,32,0,86,105,0,0,192,226,32,0,87,105,0,0,88,226,32,0,88,105,0,0,248,225,32,0,89,105,0,0,216,225,32,0,90,105,0,0,216,223,32,0,91,105,0,0,56,222,32,0,92,105,0,0,136,221,32,0,93,105,0,0,0,221,32,0,94,105,0,0,200,220,32,0,95,105,0,0,144,220,32,0,96,105,0,0,248,219,32,0,97,105,0,0,48,219,32,0,98,105,0,0,88,218,32,0,99,105,0,0,0,218,32,0,100,105,0,0,136,216,32,0,101,105,0,0,144,215,32,0,102,105,0,0,88,215,32,0,103,105,0,0,16,215,32,0,104,105,0,0,216,214,32,0,105,105,0,0,40,214,32,0,106,105,0,0,96,213,32,0,107,105,0,0,216,212,32,0,108,105,0,0,8,209,32,0,109,105,0,0,232,208,32,0,110,105,0,0,152,207,32,0,111,105,0,0,72,206,32,0,112,105,0,0,240,205,32,0,113,105,0,0,200,205,32,0,114,105,0,0,160,205,32,0,115,105,0,0,112,205,32,0,116,105,0,0,248,204,32,0,117,105,0,0,136,204,32,0,118,105,0,0,24,204,32,0,158,105,0,0,0,202,32,0,159,105,0,0,136,198,32,0,160,105,0,0,248,194,32,0,240,105,0,0,0,192,32,0,64,106,0,0,216,189,32,0,155,106,0,0,224,186,32,0,156,106,0,0,208,184,32,0,37,107,0,0,128,182,32,0,108,107,0,0,56,179,32,0,189,107,0,0,8,177,32,0,190,107,0,0,240,175,32,0,191,107,0,0,8,172,32,0,199,107,0,0,248,167,32,0,200,107,0,0,168,166,32,0,201,107,0,0,136,165,32,0,52,108,0,0,152,164,32,0,72,110,0,0,48,164,32,0,188,110,0,0,24,163,32,0,189,110,0,0,168,162,32,0,190,110,0,0,232,161,32,0,191,110,0,0,96,161,32,0,192,110,0,0,32,159,32,0,193,110,0,0,40,158,32,0,194,110,0,0,160,157,32,0,195,110,0,0,72,157,32,0,196,110,0,0,152,156,32,0,197,110,0,0,80,156,32,0,198,110,0,0,176,155,32,0,244,110,0,0,80,155,32,0,245,110,0,0,224,154,32,0,246,110,0,0,152,154,32,0,247,110,0,0,240,152,32,0,248,110,0,0,144,151,32,0,249,110,0,0,16,151,32,0,250,110,0,0,200,150,32,0,251,110,0,0,40,150,32,0,252,110,0,0,144,149,32,0,253,110,0,0,8,149,32,0,254,110,0,0,40,148,32,0,255,110,0,0,88,147,32,0,0,111,0,0,176,146,32,0,1,111,0,0,56,145,32,0,2,111,0,0,40,144,32,0,3,111,0,0,224,143,32,0,4,111,0,0,128,143,32,0,5,111,0,0,80,143,32,0,6,111,0,0,24,143,32,0,7,111,0,0,72,142,32,0,8,111,0,0,88,141,32,0,9,111,0,0,16,141,32,0,10,111,0,0,128,140,32,0,11,111,0,0,8,138,32,0,12,111,0,0,200,136,32,0,13,111,0,0,144,136,32,0,14,111,0,0,40,136,32,0,15,111,0,0,184,135,32,0,16,111,0,0,40,135,32,0,48,111,0,0,128,134,32,0,49,111,0,0,216,133,32,0,50,111,0,0,80,133,32,0,51,111,0,0,40,133,32,0,52,111,0,0,0,132,32,0,53,111,0,0,64,131,32,0,54,111,0,0,176,130,32,0,55,111,0,0,72,130,32,0,56,111,0,0,32,130,32,0,57,111,0,0,40,129,32,0,58,111,0,0,208,128,32,0,59,111,0,0,144,128,32,0,60,111,0,0,16,128,32,0,61,111,0,0,208,127,32,0,62,111,0,0,96,126,32,0,63,111,0,0,72,125,32,0,64,111,0,0,24,125,32,0,65,111,0,0,168,124,32,0,66,111,0,0,128,124,32,0,67,111,0,0,0,124,32,0,68,111,0,0,112,123,32,0,69,111,0,0,216,122,32,0,70,111,0,0,104,122,32,0,71,111,0,0,200,121,32,0,72,111,0,0,104,120,32,0,73,111,0,0,64,119,32,0,74,111,0,0,16,119,32,0,75,111,0,0,208,118,32,0,76,111,0,0,168,118,32,0,184,111,0,0,24,118,32,0,63,113,0,0,168,117,32,0,64,113,0,0,48,117,32,0,190,113,0,0,144,116,32,0,191,113,0,0,120,116,32,0,192,113,0,0,184,115,32,0,193,113,0,0,56,112,32,0,194,113,0,0,24,112,32,0,249,113,0,0,0,112,32,0,250,113,0,0,232,111,32,0,251,113,0,0,184,111,32,0,252,113,0,0,128,111,32,0,253,113,0,0,104,111,32,0,254,113,0,0,176,110,32,0,255,113,0,0,40,108,32,0,0,114,0,0,208,104,32,0,1,114,0,0,176,102,32,0,36,114,0,0,8,99,32,0,37,114,0,0,216,96,32,0,149,114,0,0,40,94,32,0,195,115,0,0,72,92,32,0,196,115,0,0,88,90,32,0,4,116,0,0,16,87,32,0,42,116,0,0,40,85,32,0,43,116,0,0,48,84,32,0,104,116,0,0,40,80,32,0,153,116,0,0,184,76,32,0,154,116,0,0,96,75,32,0,204,116,0,0,40,74,32,0,248,117,0,0,112,73,32,0,131,118,0,0,216,72,32,0,132,118,0,0,208,71,32,0,27,119,0,0,144,71,32,0,28,119,0,0,96,70,32,0,127,119,0,0,168,69,32,0,128,119,0,0,240,67,32,0,136,119,0,0,184,66,32,0,9,120,0,0,120,66,32,0,10,120,0,0,64,66,32,0,11,120,0,0,200,65,32,0,12,120,0,0,240,64,32,0,52,121,0,0,56,64,32,0,145,121,0,0,0,64,32,0,59,122,0,0,56,63,32,0,60,122,0,0,216,62,32,0,61,122,0,0,104,61,32,0,68,122,0,0,120,60,32,0,3,123,0,0,184,59,32,0,4,123,0,0,64,59,32,0,5,123,0,0,168,58,32,0,6,123,0,0,216,57,32,0,7,123,0,0,72,57,32,0,1,125,0,0,240,56,32,0,2,125,0,0,240,55,32,0,3,125,0,0,104,55,32,0,5,125,0,0,248,53,32,0,6,125,0,0,88,52,32,0,7,125,0,0,0,52,32,0,8,125,0,0,192,51,32,0,9,125,0,0,144,51,32,0,10,125,0,0,88,51,32,0,11,125,0,0,136,50,32,0,12,125,0,0,48,50,32,0,13,125,0,0,88,49,32,0,14,125,0,0,232,48,32,0,15,125,0,0,152,47,32,0,16,125,0,0,176,46,32,0,17,125,0,0,112,46,32,0,18,125,0,0,16,46,32,0,19,125,0,0,64,45,32,0,20,125,0,0,24,45,32,0,21,125,0,0,248,43,32,0,22,125,0,0,200,43,32,0,23,125,0,0,24,43,32,0,24,125,0,0,168,42,32,0,25,125,0,0,120,41,32,0,26,125,0,0,104,40,32,0,27,125,0,0,240,39,32,0,28,125,0,0,184,39,32,0,29,125,0,0,104,39,32,0,30,125,0,0,80,39,32,0,31,125,0,0,200,38,32,0,33,125,0,0,160,38,32,0,34,125,0,0,192,37,32,0,35,125,0,0,128,37,32,0,36,125,0,0,88,36,32,0,37,125,0,0,88,35,32,0,38,125,0,0,0,35,32,0,39,125,0,0,144,34,32,0,40,125,0,0,88,34,32,0,41,125,0,0,8,34,32,0,42,125,0,0,88,33,32,0,43,125,0,0,16,33,32,0,44,125,0,0,168,32,32,0,45,125,0,0,112,32,32,0,46,125,0,0,72,30,32,0,47,125,0,0,64,29,32,0,48,125,0,0,0,29,32,0,49,125,0,0,168,28,32,0,50,125,0,0,112,28,32,0,51,125,0,0,0,28,32,0,52,125,0,0,64,27,32,0,53,125,0,0,16,27,32,0,54,125,0,0,32,90,40,0,55,125,0,0,248,89,40,0,56,125,0,0,240,88,40,0,57,125,0,0,248,87,40,0,58,125,0,0,208,87,40,0,59,125,0,0,184,87,40,0,60,125,0,0,160,87,40,0,100,125,0,0,136,87,40,0,104,125,0,0,248,86,40,0,107,125,0,0,216,86,40,0,108,125,0,0,104,86,40,0,109,125,0,0,96,84,40,0,110,125,0,0,216,77,40,0,111,125,0,0,120,76,40,0,112,125,0,0,64,73,40,0,113,125,0,0,208,70,40,0,114,125,0,0,184,67,40,0,115,125,0,0,104,66,40,0,116,125], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1275668);
/* memory initializer */ allocate([72,65,40,0,117,125,0,0,232,63,40,0,118,125,0,0,24,61,40,0,119,125,0,0,0,60,40,0,120,125,0,0,224,55,40,0,121,125,0,0,224,51,40,0,122,125,0,0,32,50,40,0,123,125,0,0,8,49,40,0,124,125,0,0,80,48,40,0,125,125,0,0,208,47,40,0,126,125,0,0,24,47,40,0,127,125,0,0,184,46,40,0,128,125,0,0,216,45,40,0,129,125,0,0,120,45,40,0,130,125,0,0,200,43,40,0,133,125,0,0,144,42,40,0,134,125,0,0,32,42,40,0,135,125,0,0,216,41,40,0,136,125,0,0,128,41,40,0,137,125,0,0,56,41,40,0,138,125,0,0,152,40,40,0,139,125,0,0,120,40,40,0,140,125,0,0,240,36,40,0,141,125,0,0,208,36,40,0,142,125,0,0,160,35,40,0,143,125,0,0,184,34,40,0,144,125,0,0,32,34,40,0,145,125,0,0,240,33,40,0,146,125,0,0,96,33,40,0,147,125,0,0,216,32,40,0,148,125,0,0,248,31,40,0,149,125,0,0,56,31,40,0,150,125,0,0,96,30,40,0,151,125,0,0,176,29,40,0,152,125,0,0,16,28,40,0,153,125,0,0,144,26,40,0,154,125,0,0,32,26,40,0,155,125,0,0,240,25,40,0,156,125,0,0,216,25,40,0,157,125,0,0,192,25,40,0,158,125,0,0,40,25,40,0,161,125,0,0,224,24,40,0,201,125,0,0,24,24,40,0,202,125,0,0,248,23,40,0,203,125,0,0,104,22,40,0,204,125,0,0,144,21,40,0,205,125,0,0,112,21,40,0,206,125,0,0,56,21,40,0,207,125,0,0,224,20,40,0,208,125,0,0,184,20,40,0,209,125,0,0,216,19,40,0,210,125,0,0,128,19,40,0,211,125,0,0,168,18,40,0,212,125,0,0,136,18,40,0,213,125,0,0,216,16,40,0,214,125,0,0,208,15,40,0,215,125,0,0,80,15,40,0,216,125,0,0,8,15,40,0,217,125,0,0,200,14,40,0,218,125,0,0,144,14,40,0,219,125,0,0,248,13,40,0,220,125,0,0,224,13,40,0,221,125,0,0,160,13,40,0,222,125,0,0,128,13,40,0,223,125,0,0,64,12,40,0,224,125,0,0,0,11,40,0,225,125,0,0,120,10,40,0,226,125,0,0,40,10,40,0,227,125,0,0,240,9,40,0,228,125,0,0,192,9,40,0,229,125,0,0,208,8,40,0,230,125,0,0,160,8,40,0,231,125,0,0,48,8,40,0,232,125,0,0,8,8,40,0,233,125,0,0,56,6,40,0,234,125,0,0,56,5,40,0,235,125,0,0,8,5,40,0,236,125,0,0,184,4,40,0,237,125,0,0,144,4,40,0,238,125,0,0,48,4,40,0,239,125,0,0,88,3,40,0,240,125,0,0,32,3,40,0,241,125,0,0,240,2,40,0,242,125,0,0,96,2,40,0,243,125,0,0,40,0,40,0,244,125,0,0,32,255,39,0,245,125,0,0,104,254,39,0,246,125,0,0,72,254,39,0,247,125,0,0,40,254,39,0,248,125,0,0,208,253,39,0,249,125,0,0,176,252,39,0,250,125,0,0,48,252,39,0,251,125,0,0,144,251,39,0,252,125,0,0,0,249,39,0,253,125,0,0,216,245,39,0,254,125,0,0,152,243,39,0,255,125,0,0,128,240,39,0,0,126,0,0,16,238,39,0,1,126,0,0,152,235,39,0,2,126,0,0,16,234,39,0,3,126,0,0,224,231,39,0,4,126,0,0,64,229,39,0,45,126,0,0,112,226,39,0,46,126,0,0,168,223,39,0,47,126,0,0,176,219,39,0,48,126,0,0,184,215,39,0,49,126,0,0,216,213,39,0,50,126,0,0,72,212,39,0,51,126,0,0,160,211,39,0,52,126,0,0,48,211,39,0,53,126,0,0,64,210,39,0,54,126,0,0,16,210,39,0,55,126,0,0,144,209,39,0,56,126,0,0,112,208,39,0,57,126,0,0,216,206,39,0,58,126,0,0,40,205,39,0,59,126,0,0,16,204,39,0,60,126,0,0,16,203,39,0,61,126,0,0,208,201,39,0,62,126,0,0,16,201,39,0,63,126,0,0,216,199,39,0,64,126,0,0,48,199,39,0,65,126,0,0,104,198,39,0,66,126,0,0,120,197,39,0,67,126,0,0,96,195,39,0,68,126,0,0,104,194,39,0,69,126,0,0,160,193,39,0,70,126,0,0,32,193,39,0,71,126,0,0,24,192,39,0,72,126,0,0,192,191,39,0,73,126,0,0,208,190,39,0,74,126,0,0,56,190,39,0,75,126,0,0,0,189,39,0,76,126,0,0,72,188,39,0,77,126,0,0,192,186,39,0,78,126,0,0,80,185,39,0,79,126,0,0,176,184,39,0,80,126,0,0,88,184,39,0,81,126,0,0,144,183,39,0,82,126,0,0,8,183,39,0,83,126,0,0,152,182,39,0,84,126,0,0,48,182,39,0,85,126,0,0,136,181,39,0,86,126,0,0,104,180,39,0,87,126,0,0,32,179,39,0,88,126,0,0,64,178,39,0,89,126,0,0,128,177,39,0,90,126,0,0,88,176,39,0,91,126,0,0,224,175,39,0,92,126,0,0,144,175,39,0,93,126,0,0,176,174,39,0,94,126,0,0,24,174,39,0,95,126,0,0,128,173,39,0,96,126,0,0,56,173,39,0,97,126,0,0,16,172,39,0,98,126,0,0,128,171,39,0,99,126,0,0,40,171,39,0,100,126,0,0,24,170,39,0,101,126,0,0,48,169,39,0,102,126,0,0,96,168,39,0,103,126,0,0,176,167,39,0,104,126,0,0,40,167,39,0,145,126,0,0,0,167,39,0,146,126,0,0,184,166,39,0,147,126,0,0,16,166,39,0,148,126,0,0,208,164,39,0,149,126,0,0,24,164,39,0,150,126,0,0,104,163,39,0,151,126,0,0,24,162,39,0,152,126,0,0,120,161,39,0,153,126,0,0,104,160,39,0,154,126,0,0,48,159,39,0,155,126,0,0,136,158,39,0,156,126,0,0,216,157,39,0,157,126,0,0,232,155,39,0,158,126,0,0,48,155,39,0,159,126,0,0,72,154,39,0,160,126,0,0,128,153,39,0,161,126,0,0,88,152,39,0,162,126,0,0,112,151,39,0,163,126,0,0,176,150,39,0,164,126,0,0,80,150,39,0,165,126,0,0,232,149,39,0,166,126,0,0,200,149,39,0,167,126,0,0,136,148,39,0,168,126,0,0,248,147,39,0,169,126,0,0,184,147,39,0,170,126,0,0,120,147,39,0,171,126,0,0,48,147,39,0,172,126,0,0,168,146,39,0,173,126,0,0,144,145,39,0,174,126,0,0,8,145,39,0,175,126,0,0,184,144,39,0,176,126,0,0,48,142,39,0,177,126,0,0,32,139,39,0,178,126,0,0,208,136,39,0,179,126,0,0,216,133,39,0,180,126,0,0,216,131,39,0,181,126,0,0,40,129,39,0,182,126,0,0,216,127,39,0,183,126,0,0,240,125,39,0,184,126,0,0,40,124,39,0,185,126,0,0,96,121,39,0,186,126,0,0,24,120,39,0,187,126,0,0,248,114,39,0,188,126,0,0,40,112,39,0,189,126,0,0,104,110,39,0,190,126,0,0,112,108,39,0,191,126,0,0,200,107,39,0,192,126,0,0,104,107,39,0,193,126,0,0,64,106,39,0,194,126,0,0,160,105,39,0,195,126,0,0,192,104,39,0,196,126,0,0,248,103,39,0,197,126,0,0,184,102,39,0,198,126,0,0,88,101,39,0,199,126,0,0,168,100,39,0,200,126,0,0,56,100,39,0,201,126,0,0,8,99,39,0,202,126,0,0,88,98,39,0,203,126,0,0,168,97,39,0,204,126,0,0,56,97,39,0,245,126,0,0,176,96,39,0,246,126,0,0,56,96,39,0,247,126,0,0,16,95,39,0,248,126,0,0,72,94,39,0,249,126,0,0,128,93,39,0,250,126,0,0,32,93,39,0,251,126,0,0,64,92,39,0,252,126,0,0,64,91,39,0,253,126,0,0,136,90,39,0,254,126,0,0,208,89,39,0,255,126,0,0,224,88,39,0,0,127,0,0,8,88,39,0,1,127,0,0,0,86,39,0,2,127,0,0,48,85,39,0,3,127,0,0,224,84,39,0,4,127,0,0,144,84,39,0,5,127,0,0,80,84,39,0,6,127,0,0,48,84,39,0,7,127,0,0,104,83,39,0,8,127,0,0,240,82,39,0,9,127,0,0,16,82,39,0,10,127,0,0,184,81,39,0,11,127,0,0,120,80,39,0,12,127,0,0,144,79,39,0,13,127,0,0,64,79,39,0,14,127,0,0,0,79,39,0,15,127,0,0,88,78,39,0,16,127,0,0,48,78,39,0,17,127,0,0,112,77,39,0,18,127,0,0,48,77,39,0,19,127,0,0,208,76,39,0,20,127,0,0,144,76,39,0,21,127,0,0,80,75,39,0,22,127,0,0,176,74,39,0,23,127,0,0,96,74,39,0,24,127,0,0,200,73,39,0,25,127,0,0,64,73,39,0,26,127,0,0,240,72,39,0,27,127,0,0,152,72,39,0,28,127,0,0,56,72,39,0,29,127,0,0,104,71,39,0,30,127,0,0,64,71,39,0,31,127,0,0,80,70,39,0,32,127,0,0,192,68,39,0,33,127,0,0,104,68,39,0,34,127,0,0,24,68,39,0,35,127,0,0,128,67,39,0,36,127,0,0,8,67,39,0,37,127,0,0,80,66,39,0,38,127,0,0,248,65,39,0,39,127,0,0,184,65,39,0,40,127,0,0,144,65,39,0,41,127,0,0,88,64,39,0,42,127,0,0,224,63,39,0,43,127,0,0,160,63,39,0,44,127,0,0,240,62,39,0,45,127,0,0,144,62,39,0,46,127,0,0,96,62,39,0,47,127,0,0,184,60,39,0,48,127,0,0,104,60,39,0,89,127,0,0,24,60,39,0,90,127,0,0,152,59,39,0,91,127,0,0,240,58,39,0,92,127,0,0,72,58,39,0,93,127,0,0,0,58,39,0,94,127,0,0,224,57,39,0,95,127,0,0,184,57,39,0,96,127,0,0,104,57,39,0,97,127,0,0,24,57,39,0,98,127,0,0,152,56,39,0,99,127,0,0,80,56,39,0,100,127,0,0,56,54,39,0,101,127,0,0,184,52,39,0,102,127,0,0,112,51,39,0,103,127,0,0,48,49,39,0,104,127,0,0,32,47,39,0,105,127,0,0,152,45,39,0,106,127,0,0,168,44,39,0,107,127,0,0,216,42,39,0,108,127,0,0,64,41,39,0,109,127,0,0,128,39,39,0,110,127,0,0,24,38,39,0,111,127,0,0,120,34,39,0,112,127,0,0,72,30,39,0,113,127,0,0,144,29,39,0,114,127,0,0,48,28,39,0,115,127,0,0,104,27,39,0,116,127,0,0,0,27,39,0,117,127,0,0,128,26,39,0,118,127,0,0,80,26,39,0,119,127,0,0,160,25,39,0,120,127,0,0,64,25,39,0,121,127,0,0,120,23,39,0,122,127,0,0,32,22,39,0,123,127,0,0,160,21,39,0,124,127,0,0,112,21,39,0,125,127,0,0,0,21,39,0,126,127,0,0,168,20,39,0,127,127,0,0,80,20,39,0,128,127,0,0,248,19,39,0,129,127,0,0,80,19,39,0,130,127,0,0,248,18,39,0,131,127,0,0,96,17,39,0,132,127,0,0,80,16,39,0,133,127,0,0,176,15,39,0,134,127,0,0,96,15,39,0,135,127,0,0,192,14,39,0,136,127,0,0,48,14,39,0,137,127,0,0,192,13,39,0,138,127,0,0,64,13,39,0,139,127,0,0,112,12,39,0,140,127,0,0,32,12,39,0,141,127,0,0,248,10,39,0,142,127,0,0,80,10,39,0,143,127,0,0,224,9,39,0,144,127,0,0,192,9,39,0,145,127,0,0,160,9,39,0,146,127,0,0,104,9,39,0,147,127,0,0,40,9,39,0,148,127,0,0,216,8,39,0,189,127,0,0,24,8,39,0,190,127,0,0,216,7,39,0,191,127,0,0,104,6,39,0,192,127,0,0,120,5,39,0,193,127,0,0,72,5,39,0,194,127,0,0,8,5,39,0,195,127,0,0,168,4,39,0,196,127,0,0,72,4,39,0,197,127,0,0,192,3,39,0,198,127,0,0,72,3,39,0,199,127,0,0,24,3,39,0,200,127,0,0,192,2,39,0,201,127,0,0,96,1,39,0,202,127,0,0,16,1,39,0,203,127,0,0,176,0,39,0,204,127,0,0,248,255,38,0,205,127,0,0,192,255,38,0,206,127,0,0,112,255,38,0,207,127,0,0,248,254,38,0,208,127,0,0,224,254,38,0,209,127,0,0,128,254,38,0,210,127,0,0,96,254,38,0,211,127,0,0,72,253,38,0,212,127,0,0,144,252,38,0,213,127,0,0,104,252,38,0,214,127,0,0,16,252,38,0,215,127,0,0,144,251,38,0,216,127,0,0,64,251,38,0,217,127,0,0,104,250,38,0,218,127,0,0,32,250,38,0,219,127,0,0,200,249,38,0,220,127,0,0,88,249,38,0,221,127,0,0,48,248,38,0,222,127,0,0,232,247,38,0,223,127,0,0,144,247,38,0,224,127,0,0,96,247,38,0,225,127,0,0,248,246,38,0,226,127,0,0,152,246,38,0,227,127,0,0,80,246,38,0,228,127,0,0,40,246,38,0,229,127,0,0,176,245,38,0,230,127,0,0,144,245,38,0,231,127,0,0,208,244,38,0,232,127,0,0,120,244,38,0,233,127,0,0,88,244,38,0,234,127,0,0,248,243,38,0,235,127,0,0,144,243,38,0,236,127,0,0,88,243,38,0,237,127,0,0,240,242,38,0,238,127,0,0,184,242,38,0,239,127,0,0,64,242,38,0,240,127,0,0,88,240,38,0,241,127,0,0,216,237,38,0,242,127,0,0,16,237,38,0,243,127,0,0,192,234,38,0,244,127,0,0,176,232,38,0,245,127,0,0,88,230,38,0,246,127,0,0,136,228,38,0,247,127,0,0,48,227,38,0,248,127,0,0,80,226,38,0,56,224,34,0,72,219,34,0,96,216,34,0,80,215,34,0,104,214,34,0,176,213,34,0,128,212,34,0,168,211,34,0,144,210,34,0,216,209,34,0,56,208,34,0,0,0,0,0,104,9,38,0,248,8,38,0,200,8,38,0,160,8,38,0,120,8,38,0,192,7,38,0,240,106,34,0,184,88,34,0,32,48,34,0,120,26,34,0,168,12,34,0,152,253,33,0,72,235,33,0,16,221,33,0,96,209,33,0,24,199,33,0,0,190,33,0,216,177,33,0,208,143,33,0,104,127,33,0,192,117,33,0,0,0,0,0,72,139,34,0,216,123,34,0,208,188,34,0,176,171,34,0,16,153,34,0,0,0,0,0,224,244,35,0,0,0,0,0,128,255,34,0,177,135,0,0,88,56,34,0,0,0,0,0,0,151,33,0,0,0,0,0,200,26,33,0,0,0,0,0,112,177,32,0,176,135,0,0,112,85,32,0,0,0,0,0,184,61,40,0,176,135,0,0,240,226,39,0,0,0,0,0,176,121,39,0,176,135,0,0,168,39,39,0,176,135,0,0,24,225,38,0,176,135,0,0,24,155,38,0,0,0,0,0,160,95,38,0,176,135,0,0,192,137,35,0,192,131,35,0,48,127,35,0,216,125,35,0,184,123,35,0,136,122,35,0,200,120,35,0,152,119,35,0,216,117,35,0,96,116,35,0,176,114,35,0,32,109,35,0,24,105,35,0,184,102,35,0,184,101,35,0,232,100,35,0,248,99,35,0,0,99,35,0,32,98,35,0,40,97,35,0,48,95,35,0,96,89,35,0,72,86,35,0,208,84,35,0,120,83,35,0,176,82,35,0,168,81,35,0,72,80,35,0,120,78,35,0,104,77,35,0,104,76,35,0,184,71,35,0,160,68,35,0,120,67,35,0,216,65,35,0,0,0,0,0,72,244,36,0,16,231,36,0,64,226,36,0,144,223,36,0,32,218,36,0,208,215,36,0,112,213,36,0,144,211,36,0,112,209,36,0,72,207,36,0,248,204,36,0,88,196,36,0,96,191,36,0,48,189,36,0,0,187,36,0,80,185,36,0,8,184,36,0,192,181,36,0,88,179,36,0,184,177,36,0,232,175,36,0,32,166,36,0,40,162,36,0,8,160,36,0,0,158,36,0,72,156,36,0,8,154,36,0,136,152,36,0,176,150,36,0,184,149,36,0,96,147,36,0,240,139,36,0,8,135,36,0,200,132,36,0,104,130,36,0,104,128,36,0,216,126,36,0,40,125,36,0,200,122,36,0,112,121,36,0,8,120,36,0,232,111,36,0,40,108,36,0,120,106,36,0,128,104,36,0,168,102,36,0,32,101,36,0,40,99,36,0,56,96,36,0,168,94,36,0,56,93,36,0,192,84,36,0,192,80,36,0,96,78,36,0,152,76,36,0,16,75,36,0,96,73,36,0,136,71,36,0,176,69,36,0,248,67,36,0,232,66,36,0,240,59,36,0,72,56,36,0,240,54,36,0,152,53,36,0,40,52,36,0,24,51,36,0,248,49,36,0,72,48,36,0,248,45,36,0,104,41,36,0,176,31,36,0,24,25,36,0,232,17,36,0,88,12,36,0,128,7,36,0,248,3,36,0,200,0,36,0,160,248,35,0,24,244,35,0,32,240,35,0,136,230,35,0,248,222,35,0,160,219,35,0,200,215,35,0,88,214,35,0,128,212,35,0,128,210,35,0,0,209,35,0,120,206,35,0,112,204,35,0,72,198,35,0,184,194,35,0,192,192,35,0,24,191,35,0,232,189,35,0,32,188,35,0,224,185,35,0,216,183,35,0,128,182,35,0,216,180,35,0,224,174,35,0,104,171,35,0,192,169,35,0,72,168,35,0,8,167,35,0,240,164,35,0,136,163,35,0,224,161,35,0,168,159,35,0,240,157,35,0,184,152,35,0,128,149,35,0,192,147,35,0,128,146,35,0,200,145,35,0,160,144,35,0,32,143,35,0,64,141,35,0,8,140,35,0,0,155,37,0,168,152,37,0,216,150,37,0,8,149,37,0,248,145,37,0,168,139,37,0,104,126,37,0,176,118,37,0,128,110,37,0,8,105,37,0,56,100,37,0,192,96,37,0,192,92,37,0,160,85,37,0,200,80,37,0,192,74,37,0,232,59,37,0,192,51,37,0,80,46,37,0,64,42,37,0,64,36,37,0,232,34,37,0,152,32,37,0,144,29,37,0,48,27,37,0,80,25,37,0,72,16,37,0,0,10,37,0,24,7,37,0,48,4,37,0,48,2,37,0,56,0,37,0,48,254,36,0,128,251,36,0,248,249,36,0,0,0,0,0,152,4,33,0,80,252,32,0,144,244,32,0,24,237,32,0,96,230,32,0,240,223,32,0,168,216,32,0,184,207,32,0,168,198,32,0,48,172,32,0,56,159,32,0,16,153,32,0,88,145,32,0,40,138,32,0,24,132,32,0,120,126,32,0,128,120,32,0,208,115,32,0,232,104,32,0,112,80,32,0,16,68,32,0,128,61,32,0,24,54,32,0,176,47,32,0,152,41,32,0,112,36,32,0,104,30,32,0,8,89,40,0,64,81,40,0,32,56,40,0,224,43,40,0,184,35,40,0,48,28,40,0,128,22,40,0,240,16,40,0,88,12,40,0,80,6,40,0,64,0,40,0,240,245,39,0,240,219,39,0,240,206,39,0,120,195,39,0,216,186,39,0,56,179,39,0,40,172,39,0,40,166,39,0,8,156,39,0,168,148,39,0,64,139,39,0,240,115,39,0,216,102,39,0,40,95,39,0,32,86,39,0,152,80,39,0,112,75,39,0,112,70,39,0,120,64,39,0,8,59,39,0,208,52,39,0,144,34,39,0,144,23,39,0,120,17,39,0,16,11,39,0,128,6,39,0,120,1,39,0,96,253,38,0,72,248,38,0,232,244,38,0,240,237,38,0,224,219,38,0,32,211,38,0,168,205,38,0,40,199,38,0,136,194,38,0,112,189,38,0,0,184,38,0,192,178,38,0,240,173,38,0,16,167,38,0,240,150,38,0,80,142,38,0,208,137,38,0,144,132,38,0,168,128,38,0,48,125,38,0,24,121,38,0,64,116,38,0,192,112,38,0,184,106,38,0,176,91,38,0,80,83,38,0,136,78,38,0,176,73,38,0,32,71,38,0,120,67,38,0,40,64,38,0,8,60,38,0,184,56,38,0,104,52,38,0,64,38,38,0,64,28,38,0,80,23,38,0,8,19,38,0,184,14,38,0,16,11,38,0,232,7,38,0,96,5,38,0,120,3,38,0,192,255,37,0,200,244,37,0,208,239,37,0,88,236,37,0,168,233,37,0,152,230,37,0,248,227,37,0,192,225,37,0,40,219,37,0,0,217,37,0,96,213,37,0,240,200,37,0,232,193,37,0,120,191,37,0,48,189,37,0,224,186,37,0,40,184,37,0,160,181,37,0,24,179,37,0,96,177,37,0,16,175,37,0,160,164,37,0,24,160,37,0,16,158,37,0,144,156,37,0,0,0,0,0,176,155,37,0,32,147,39,0,0,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,192,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,183,4,0,0,0,0,0,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,9,0,0,0,0,0,0,236,0,0,0,0,0,0,0,176,9,0,0,0,0,0,0,0,0,0,0,200,64,35,0,96,63,35,0,48,62,35,0,32,61,35,0,216,59,35,0,40,58,35,0,216,53,35,0,176,50,35,0,192,49,35,0,216,48,35,0,104,48,35,0,144,47,35,0,240,46,35,0,216,45,35,0,208,42,35,0,184,38,35,0,112,31,35,0,0,26,35,0,24,19,35,0,48,15,35,0,136,12,35,0,216,9,35,0,96,7,35,0,72,2,35,0,8,255,34,0,240,251,34,0,248,243,34,0,128,238,34,0,72,234,34,0,224,230,34,0,168,229,34,0,0,229,34,0,0,228,34,0,160,226,34,0,88,225,34,0,0,0,0,0,176,184,37,0,56,151,39,0,0,0,0,0,97,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,11,0,0,0,0,0,0,0,0,0,0,70,1,0,0,104,9,0,0,0,0,0,0,0,0,0,0,176,43,38,0,144,42,38,0,112,41,38,0,104,40,38,0,32,38,38,0,168,36,38,0,216,35,38,0,128,34,38,0,8,34,38,0,120,33,38,0,24,33,38,0,200,32,38,0,64,29,38,0,200,28,38,0,40,28,38,0,24,27,38,0,176,26,38,0,144,26,38,0,24,26,38,0,200,25,38,0,128,25,38,0,88,25,38,0,128,24,38,0,104,24,38,0,56,23,38,0,208,22,38,0,120,22,38,0,0,0,0,0,160,182,37,0,0,0,0,0,152,150,39,0,0,0,0,0,168,81,37,0,177,135,0,0,208,107,33,0,0,98,33,0,232,87,33,0,0,79,33,0,8,71,33,0,248,61,33,0,240,50,33,0,120,20,33,0,224,184,37,0,80,151,39,0,0,0,0,0,96,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,10,0,0,0,0,0,0,0,0,0,0,106,1,0,0,98,11,0,0,0,0,0,0,0,0,0,0,24,43,40,0,0,255,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,1,0,0,18,7,0,0,28,1,0,0,46,3,0,0,130,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,43,40,0,24,255,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,220,8,0,0,194,1,0,0,166,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,128,33,0,152,118,33,0,0,0,0,0,101,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,0,0,0,0,0,0,0,0,0,0,6,2,0,0,138,5,0,0,186,1,0,0,0,0,0,0,72,98,37,0,72,128,39,0,0,0,0,0,31,0,0,0,3,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,7,0,0,0,0,0,0,0,0,0,0,20,3,0,0,78,4,0,0,216,0,0,0,0,0,0,0,160,124,32,0,7,0,0,0,0,0,0,0,16,3,0,0,238,0,0,0,64,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,248,226,32,0,8,129,32,0,0,0,0,0,248,226,32,0,0,32,1,0,5,0,0,0,0,0,0,0,64,0,5,0,24,94,40,0,216,187,4,0,0,0,0,0,128,0,0,0,20,5,0,0,70,3,0,0,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,227,37,0,224,182,37,0,0,0,0,0,16,227,37,0,0,32,1,0,5,0,0,0,0,0,0,0,64,0,5,0,24,101,40,0,8,188,4,0,0,0,0,0,128,0,0,0,20,5,0,0,70,3,0,0,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,185,37,0,144,151,39,0,3,0,0,0,2,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,188,4,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,47,40,0,56,255,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,240,192,4,0,0,0,0,0,200,0,0,0,132,2,0,0,86,2,0,0,62,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,47,40,0,80,255,39,0,0,0,0,0,0,0,0,0,0,0,0,0,128,193,4,0,0,0,0,0,0,0,0,0,40,0,0,0,146,3,0,0,44,2,0,0,250,0,0,0,22,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,240,185,37,0,192,151,39,0,0,0,0,0,54,49,50,84,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,7,0,0,0,0,0,0,0,0,0,0,42,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,185,37,0,168,151,39,0,0,0,0,0,94,0,0,0,0,0,0,0,0,0,0,0,80,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,9,0,0,0,0,0,0,196,1,0,0,0,0,0,0,224,8,0,0,0,0,0,0,0,0,0,0,72,186,37,0,248,151,39,0,0,0,0,0,94,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,97,66,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,52,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,48,40,0,120,255,39,0,0,1,0,0,216,48,40,0,0,0,0,0,0,0,0,0,0,0,0,0,75,97,66,116,16,0,0,0,96,1,0,0,230,1,0,0,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,186,37,0,16,152,39,0,1,0,0,0,75,97,66,116,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,7,0,0,0,0,0,0,0,0,0,0,40,2,0,0,108,4,0,0,0,0,0,0,0,0,0,0,64,0,0,0,7,0,0,0,201,19,0,0,13,0,0,0,253,9,0,0,12,0,0,0,252,1,0,0,15,0,0,0,252,9,0,0,12,0,0,0,131,10,0,0,18,0,0,0,52,45,1,0,17,0,0,0,188,131,0,0,16,0,0,0,58,8,0,0,12,0,0,0,248,7,0,0,17,0,0,0,253,3,0,0,16,0,0,0,255,3,0,0,16,0,0,0,121,0,0,0,13,0,0,0,130,10,0,0,18,0,0,0,157,150,0,0,16,0,0,0,164,2,0,0,16,0,0,0,120,9,0,0,12,0,0,0,67,5,0,0,17,0,0,0,223,65,0,0,15,0,0,0,249,7,0,0,17,0,0,0,243,18,0,0,13,0,0,0,107,90,2,0,18,0,0,0,249,94,2,0,18,0,0,0,250,3,0,0,16,0,0,0,238,32,0,0,14,0,0,0,171,105,9,0,20,0,0,0,156,150,0,0,16,0,0,0,248,94,2,0,18,0,0,0,210,18,0,0,13,0,0,0,133,10,0,0,18,0,0,0,158,150,0,0,16,0,0,0,200,75,0,0,15,0,0,0,61,0,0,0,12,0,0,0,127,47,1,0,17,0,0,0,162,2,0,0,16,0,0,0,159,150,0,0,16,0,0,0,238,37,0,0,14,0,0,0,85,211,18,0,21,0,0,0,125,47,1,0,17,0,0,0,126,47,1,0,17,0,0,0,229,9,0,0,12,0,0,0,129,10,0,0,18,0,0,0,212,180,4,0,19,0,0,0,189,131,0,0,16,0,0,0,120,0,0,0,13,0,0,0,155,150,0,0,16,0,0,0,254,3,0,0,16,0,0,0,165,2,0,0,16,0,0,0,126,0,0,0,13,0,0,0,128,10,0,0,18,0,0,0,163,2,0,0,16,0,0,0,251,3,0,0,16,0,0,0,118,16,0,0,13,0,0,0,132,10,0,0,18,0,0,0,83,1,0,0,15,0,0,0,201,75,0,0,15,0,0,0,85,0,0,0,13,0,0,0,84,211,18,0,21,0,0,0,222,75,0,0,15,0,0,0,229,37,0,0,14,0,0,0,91,2,0,0,10,0,0,0,76,75,0,0,15,0,0,0,107,9,0,0,12,0,0,0,106,9,0,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,7,0,0,0,38,0,0,0,6,0,0,0,43,1,0,0,9,0,0,0,7,0,0,0,3,0,0,0,15,2,0,0,10,0,0,0,4,0,0,0,9,0,0,0,40,0,0,0,12,0,0,0,6,0,0,0,3,0,0,0,10,2,0,0,10,0,0,0,40,1,0,0,9,0,0,0,43,0,0,0,12,0,0,0,17,0,0,0,5,0,0,0,27,0,0,0,11,0,0,0,58,1,0,0,9,0,0,0,255,4,0,0,11,0,0,0,3,0,0,0,4,0,0,0,119,2,0,0,10,0,0,0,6,1,0,0,9,0,0,0,57,8,0,0,12,0,0,0,11,0,0,0,4,0,0,0,123,2,0,0,10,0,0,0,44,1,0,0,9,0,0,0,191,4,0,0,11,0,0,0,9,0,0,0,6,0,0,0,53,0,0,0,12,0,0,0,126,2,0,0,10,0,0,0,200,19,0,0,13,0,0,0,1,0,0,0,6,0,0,0,170,4,0,0,11,0,0,0,8,2,0,0,10,0,0,0,41,0,0,0,12,0,0,0,1,0,0,0,4,0,0,0,84,2,0,0,10,0,0,0,46,1,0,0,9,0,0,0,56,8,0,0,12,0,0,0,36,0,0,0,6,0,0,0,243,4,0,0,11,0,0,0,118,2,0,0,10,0,0,0,246,18,0,0,13,0,0,0,1,0,0,0,5,0,0,0,122,2,0,0,10,0,0,0,62,1,0,0,9,0,0,0,62,0,0,0,12,0,0,0,8,0,0,0,6,0,0,0,19,4,0,0,11,0,0,0,12,0,0,0,10,0,0,0,190,4,0,0,11,0,0,0,20,0,0,0,5,0,0,0,18,4,0,0,11,0,0,0,83,2,0,0,10,0,0,0,122,9,0,0,12,0,0,0,33,0,0,0,6,0,0,0,171,4,0,0,11,0,0,0,11,2,0,0,10,0,0,0,52,0,0,0,12,0,0,0,21,0,0,0,5,0,0,0,120,2,0,0,10,0,0,0,82,2,0,0,10,0,0,0,104,9,0,0,12,0,0,0,5,0,0,0,5,0,0,0,11,0,0,0,10,0,0,0,156,0,0,0,8,0,0,0,14,0,0,0,10,0,0,0,0,1,2,2,6,3,7,3,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,101,0,110,0,116,0,114,0,105,0,101,0,115,0,46,0,116,0,105,0,109,0,101,0,116,0,97,0,98,0,108,0,101,0,46,0,48,0,46,0,101,0,110,0,116,0,114,0,105,0,101,0,115,0,46,0,108,0,101,0,103,0,97,0,99,0,121,0,95,0,97,0,116,0,116,0,114,0,105,0,98,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,5,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,3,0,0,0,5,0,0,0,8,0,0,0,5,0,0,0,0,0,0,0,6,0,0,0,5,0,0,0,6,0,0,0,13,0,0,0,6,0,0,0,15,0,0,0,6,0,0,0,19,0,0,0,6,0,0,0,8,0,0,0,7,0,0,0,24,0,0,0,7,0,0,0,28,0,0,0,7,0,0,0,36,0,0,0,7,0,0,0,4,0,0,0,8,0,0,0,6,0,0,0,8,0,0,0,18,0,0,0,8,0,0,0,50,0,0,0,8,0,0,0,59,0,0,0,8,0,0,0,74,0,0,0,8,0,0,0,75,0,0,0,8,0,0,0,11,0,0,0,9,0,0,0,38,0,0,0,9,0,0,0,39,0,0,0,9,0,0,0,102,0,0,0,9,0,0,0,116,0,0,0,9,0,0,0,117,0,0,0,9,0,0,0,20,0,0,0,10,0,0,0,28,0,0,0,10,0,0,0,31,0,0,0,10,0,0,0,29,0,0,0,10,0,0,0,43,0,0,0,11,0,0,0,61,0,0,0,11,0,0,0,157,1,0,0,11,0,0,0,159,1,0,0,11,0,0,0,84,0,0,0,12,0,0,0,57,3,0,0,12,0,0,0,56,3,0,0,12,0,0,0,61,3,0,0,12,0,0,0,171,0,0,0,13,0,0,0,241,0,0,0,13,0,0,0,120,6,0,0,13,0,0,0,242,0,0,0,13,0,0,0,224,1,0,0,14,0,0,0,225,1,0,0,14,0,0,0,84,1,0,0,14,0,0,0,242,12,0,0,14,0,0,0,204,3,0,0,15,0,0,0,171,2,0,0,15,0,0,0,231,25,0,0,15,0,0,0,206,3,0,0,15,0,0,0,230,25,0,0,15,0,0,0,84,5,0,0,16,0,0,0,159,7,0,0,16,0,0,0,85,5,0,0,16,0,0,0,61,15,0,0,17,0,0,0,55,15,0,0,17,0,0,0,60,15,0,0,17,0,0,0,53,15,0,0,17,0,0,0,109,30,0,0,18,0,0,0,104,30,0,0,18,0,0,0,216,60,0,0,19,0,0,0,211,60,0,0,19,0,0,0,217,60,0,0,19,0,0,0,164,121,0,0,20,0,0,0,186,52,15,0,25,0,0,0,180,52,15,0,25,0,0,0,181,52,15,0,25,0,0,0,182,52,15,0,25,0,0,0,183,52,15,0,25,0,0,0,184,52,15,0,25,0,0,0,185,52,15,0,25,0,0,0,187,52,15,0,25,0,0,0,188,52,15,0,25,0,0,0,189,52,15,0,25,0,0,0,190,52,15,0,25,0,0,0,191,52,15,0,25,0,0,0,64,105,30,0,26,0,0,0,65,105,30,0,26,0,0,0,66,105,30,0,26,0,0,0,67,105,30,0,26,0,0,0,68,105,30,0,26,0,0,0,69,105,30,0,26,0,0,0,70,105,30,0,26,0,0,0,71,105,30,0,26,0,0,0,72,105,30,0,26,0,0,0,73,105,30,0,26,0,0,0,74,105,30,0,26,0,0,0,75,105,30,0,26,0,0,0,76,105,30,0,26,0,0,0,77,105,30,0,26,0,0,0,78,105,30,0,26,0,0,0,79,105,30,0,26,0,0,0,80,105,30,0,26,0,0,0,81,105,30,0,26,0,0,0,82,105,30,0,26,0,0,0,83,105,30,0,26,0,0,0,84,105,30,0,26,0,0,0,85,105,30,0,26,0,0,0,86,105,30,0,26,0,0,0,87,105,30,0,26,0,0,0,88,105,30,0,26,0,0,0,89,105,30,0,26,0,0,0,90,105,30,0,26,0,0,0,91,105,30,0,26,0,0,0,92,105,30,0,26,0,0,0,93,105,30,0,26,0,0,0,94,105,30,0,26,0,0,0,95,105,30,0,26,0,0,0,96,105,30,0,26,0,0,0,97,105,30,0,26,0,0,0,98,105,30,0,26,0,0,0,99,105,30,0,26,0,0,0,100,105,30,0,26,0,0,0,101,105,30,0,26,0,0,0,102,105,30,0,26,0,0,0,103,105,30,0,26,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,11,0,0,0,4,0,0,0,13,0,0,0,4,0,0,0,21,0,0,0,5,0,0,0,40,0,0,0,6,0,0,0,48,0,0,0,6,0,0,0,50,0,0,0,6,0,0,0,82,0,0,0,7,0,0,0,98,0,0,0,7,0,0,0,102,0,0,0,7,0,0,0,166,0,0,0,8,0,0,0,198,0,0,0,8,0,0,0,207,0,0,0,8,0,0,0,79,1,0,0,9,0,0,0,142,1,0,0,9,0,0,0,156,1,0,0,9,0,0,0,157,2,0,0,10,0,0,0,58,3,0,0,10,0,0,0,56,5,0,0,11,0,0,0,60,6,0,0,11,0,0,0,62,6,0,0,11,0,0,0,63,6,0,0,11,0,0,0,118,6,0,0,11,0,0,0,115,10,0,0,12,0,0,0,122,12,0,0,12,0,0,0,239,12,0,0,12,0,0,0,229,20,0,0,13,0,0,0,221,25,0,0,13,0,0,0,200,41,0,0,14,0,0,0,201,41,0,0,14,0,0,0,221,99,0,0,15,0,0,0,184,51,0,0,14,0,0,0,185,51,0,0,14,0,0,0,182,199,0,0,16,0,0,0,216,99,0,0,15,0,0,0,223,99,0,0,15,0,0,0,179,199,0,0,16,0,0,0,180,199,0,0,16,0,0,0,181,199,0,0,16,0,0,0,222,99,0,0,15,0,0,0,183,199,0,0,16,0,0,0,184,199,0,0,16,0,0,0,185,199,0,0,16,0,0,0,101,143,1,0,17,0,0,0,200,30,3,0,18,0,0,0,72,178,199,0,24,0,0,0,73,178,199,0,24,0,0,0,74,178,199,0,24,0,0,0,75,178,199,0,24,0,0,0,76,178,199,0,24,0,0,0,77,178,199,0,24,0,0,0,78,178,199,0,24,0,0,0,79,178,199,0,24,0,0,0,80,178,199,0,24,0,0,0,81,178,199,0,24,0,0,0,82,178,199,0,24,0,0,0,83,178,199,0,24,0,0,0,84,178,199,0,24,0,0,0,85,178,199,0,24,0,0,0,86,178,199,0,24,0,0,0,87,178,199,0,24,0,0,0,88,178,199,0,24,0,0,0,89,178,199,0,24,0,0,0,90,178,199,0,24,0,0,0,91,178,199,0,24,0,0,0,92,178,199,0,24,0,0,0,93,178,199,0,24,0,0,0,94,178,199,0,24,0,0,0,95,178,199,0,24,0,0,0,96,178,199,0,24,0,0,0,97,178,199,0,24,0,0,0,98,178,199,0,24,0,0,0,99,178,199,0,24,0,0,0,100,178,199,0,24,0,0,0,101,178,199,0,24,0,0,0,102,178,199,0,24,0,0,0,103,178,199,0,24,0,0,0,104,178,199,0,24,0,0,0,105,178,199,0,24,0,0,0,106,178,199,0,24,0,0,0,107,178,199,0,24,0,0,0,108,178,199,0,24,0,0,0,109,178,199,0,24,0,0,0,110,178,199,0,24,0,0,0,111,178,199,0,24,0,0,0,112,178,199,0,24,0,0,0,113,178,199,0,24,0,0,0,114,178,199,0,24,0,0,0,115,178,199,0,24,0,0,0,116,178,199,0,24,0,0,0,117,178,199,0,24,0,0,0,118,178,199,0,24,0,0,0,119,178,199,0,24,0,0,0,120,178,199,0,24,0,0,0,121,178,199,0,24,0,0,0,122,178,199,0,24,0,0,0,123,178,199,0,24,0,0,0,124,178,199,0,24,0,0,0,125,178,199,0,24,0,0,0,126,178,199,0,24,0,0,0,127,178,199,0,24,0,0,0,128,100,143,1,25,0,0,0,129,100,143,1,25,0,0,0,130,100,143,1,25,0,0,0,131,100,143,1,25,0,0,0,132,100,143,1,25,0,0,0,133,100,143,1,25,0,0,0,134,100,143,1,25,0,0,0,135,100,143,1,25,0,0,0,136,100,143,1,25,0,0,0,137,100,143,1,25,0,0,0,138,100,143,1,25,0,0,0,139,100,143,1,25,0,0,0,140,100,143,1,25,0,0,0,141,100,143,1,25,0,0,0,142,100,143,1,25,0,0,0,143,100,143,1,25,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,7,0,0,0,5,0,0,0,8,0,0,0,6,0,0,0,12,0,0,0,6,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,7,0,0,0,18,0,0,0,7,0,0,0,26,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,7,0,0,0,8,0,0,0,39,0,0,0,8,0,0,0,55,0,0,0,8,0,0,0,5,0,0,0,9,0,0,0,76,0,0,0,9,0,0,0,108,0,0,0,9,0,0,0,109,0,0,0,9,0,0,0,8,0,0,0,10,0,0,0,25,0,0,0,10,0,0,0,155,0,0,0,10,0,0,0,27,0,0,0,10,0,0,0,154,0,0,0,10,0,0,0,19,0,0,0,11,0,0,0,52,0,0,0,11,0,0,0,53,0,0,0,11,0,0,0,97,0,0,0,12,0,0,0,72,0,0,0,13,0,0,0,196,0,0,0,13,0,0,0,74,0,0,0,13,0,0,0,198,0,0,0,13,0,0,0,199,0,0,0,13,0,0,0,146,0,0,0,14,0,0,0,139,1,0,0,14,0,0,0,147,0,0,0,14,0,0,0,131,1,0,0,14,0,0,0,130,1,0,0,14,0,0,0,150,0,0,0,14,0,0,0,151,0,0,0,14,0,0,0,128,1,0,0,14,0,0,0,20,3,0,0,15,0,0,0,21,3,0,0,15,0,0,0,5,6,0,0,16,0,0,0,4,6,0,0,16,0,0,0,6,6], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1285908);
/* memory initializer */ allocate([16,0,0,0,14,12,0,0,17,0,0,0,205,3,3,0,23,0,0,0,201,3,3,0,23,0,0,0,200,3,3,0,23,0,0,0,202,3,3,0,23,0,0,0,203,3,3,0,23,0,0,0,204,3,3,0,23,0,0,0,206,3,3,0,23,0,0,0,207,3,3,0,23,0,0,0,208,3,3,0,23,0,0,0,209,3,3,0,23,0,0,0,210,3,3,0,23,0,0,0,211,3,3,0,23,0,0,0,212,3,3,0,23,0,0,0,213,3,3,0,23,0,0,0,214,3,3,0,23,0,0,0,215,3,3,0,23,0,0,0,216,3,3,0,23,0,0,0,217,3,3,0,23,0,0,0,218,3,3,0,23,0,0,0,219,3,3,0,23,0,0,0,220,3,3,0,23,0,0,0,221,3,3,0,23,0,0,0,222,3,3,0,23,0,0,0,223,3,3,0,23,0,0,0,224,3,3,0,23,0,0,0,225,3,3,0,23,0,0,0,226,3,3,0,23,0,0,0,227,3,3,0,23,0,0,0,228,3,3,0,23,0,0,0,229,3,3,0,23,0,0,0,230,3,3,0,23,0,0,0,231,3,3,0,23,0,0,0,232,3,3,0,23,0,0,0,233,3,3,0,23,0,0,0,234,3,3,0,23,0,0,0,235,3,3,0,23,0,0,0,236,3,3,0,23,0,0,0,237,3,3,0,23,0,0,0,238,3,3,0,23,0,0,0,239,3,3,0,23,0,0,0,240,3,3,0,23,0,0,0,241,3,3,0,23,0,0,0,242,3,3,0,23,0,0,0,243,3,3,0,23,0,0,0,244,3,3,0,23,0,0,0,245,3,3,0,23,0,0,0,246,3,3,0,23,0,0,0,247,3,3,0,23,0,0,0,248,3,3,0,23,0,0,0,249,3,3,0,23,0,0,0,250,3,3,0,23,0,0,0,251,3,3,0,23,0,0,0,252,3,3,0,23,0,0,0,253,3,3,0,23,0,0,0,254,3,3,0,23,0,0,0,255,3,3,0,23,0,0,0,128,7,6,0,24,0,0,0,129,7,6,0,24,0,0,0,130,7,6,0,24,0,0,0,131,7,6,0,24,0,0,0,132,7,6,0,24,0,0,0,133,7,6,0,24,0,0,0,134,7,6,0,24,0,0,0,135,7,6,0,24,0,0,0,136,7,6,0,24,0,0,0,137,7,6,0,24,0,0,0,138,7,6,0,24,0,0,0,139,7,6,0,24,0,0,0,140,7,6,0,24,0,0,0,141,7,6,0,24,0,0,0,142,7,6,0,24,0,0,0,143,7,6,0,24,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,5,0,0,0,3,0,0,0,9,0,0,0,4,0,0,0,13,0,0,0,4,0,0,0,17,0,0,0,5,0,0,0,29,0,0,0,5,0,0,0,31,0,0,0,5,0,0,0,33,0,0,0,6,0,0,0,49,0,0,0,6,0,0,0,56,0,0,0,6,0,0,0,51,0,0,0,6,0,0,0,57,0,0,0,6,0,0,0,61,0,0,0,6,0,0,0,97,0,0,0,7,0,0,0,121,0,0,0,7,0,0,0,128,0,0,0,8,0,0,0,200,0,0,0,8,0,0,0,202,0,0,0,8,0,0,0,240,0,0,0,8,0,0,0,129,0,0,0,8,0,0,0,192,0,0,0,8,0,0,0,201,0,0,0,8,0,0,0,7,1,0,0,9,0,0,0,6,1,0,0,9,0,0,0,150,1,0,0,9,0,0,0,131,1,0,0,9,0,0,0,227,1,0,0,9,0,0,0,226,1,0,0,9,0,0,0,10,2,0,0,10,0,0,0,11,2,0,0,10,0,0,0,9,6,0,0,11,0,0,0,18,4,0,0,11,0,0,0,19,4,0,0,11,0,0,0,11,6,0,0,11,0,0,0,17,4,0,0,11,0,0,0,10,6,0,0,11,0,0,0,95,6,0,0,11,0,0,0,16,4,0,0,11,0,0,0,93,6,0,0,11,0,0,0,94,6,0,0,11,0,0,0,184,12,0,0,12,0,0,0,16,12,0,0,12,0,0,0,185,12,0,0,12,0,0,0,35,24,0,0,13,0,0,0,69,48,0,0,14,0,0,0,137,96,0,0,15,0,0,0,16,193,0,0,16,0,0,0,72,68,48,0,22,0,0,0,73,68,48,0,22,0,0,0,74,68,48,0,22,0,0,0,75,68,48,0,22,0,0,0,76,68,48,0,22,0,0,0,77,68,48,0,22,0,0,0,78,68,48,0,22,0,0,0,79,68,48,0,22,0,0,0,80,68,48,0,22,0,0,0,81,68,48,0,22,0,0,0,82,68,48,0,22,0,0,0,83,68,48,0,22,0,0,0,84,68,48,0,22,0,0,0,85,68,48,0,22,0,0,0,86,68,48,0,22,0,0,0,87,68,48,0,22,0,0,0,88,68,48,0,22,0,0,0,89,68,48,0,22,0,0,0,90,68,48,0,22,0,0,0,91,68,48,0,22,0,0,0,92,68,48,0,22,0,0,0,93,68,48,0,22,0,0,0,94,68,48,0,22,0,0,0,95,68,48,0,22,0,0,0,96,68,48,0,22,0,0,0,97,68,48,0,22,0,0,0,98,68,48,0,22,0,0,0,99,68,48,0,22,0,0,0,100,68,48,0,22,0,0,0,101,68,48,0,22,0,0,0,102,68,48,0,22,0,0,0,103,68,48,0,22,0,0,0,104,68,48,0,22,0,0,0,105,68,48,0,22,0,0,0,106,68,48,0,22,0,0,0,107,68,48,0,22,0,0,0,108,68,48,0,22,0,0,0,109,68,48,0,22,0,0,0,110,68,48,0,22,0,0,0,111,68,48,0,22,0,0,0,112,68,48,0,22,0,0,0,113,68,48,0,22,0,0,0,114,68,48,0,22,0,0,0,115,68,48,0,22,0,0,0,116,68,48,0,22,0,0,0,117,68,48,0,22,0,0,0,118,68,48,0,22,0,0,0,119,68,48,0,22,0,0,0,120,68,48,0,22,0,0,0,121,68,48,0,22,0,0,0,122,68,48,0,22,0,0,0,123,68,48,0,22,0,0,0,124,68,48,0,22,0,0,0,125,68,48,0,22,0,0,0,126,68,48,0,22,0,0,0,127,68,48,0,22,0,0,0,128,136,96,0,23,0,0,0,129,136,96,0,23,0,0,0,130,136,96,0,23,0,0,0,131,136,96,0,23,0,0,0,132,136,96,0,23,0,0,0,133,136,96,0,23,0,0,0,134,136,96,0,23,0,0,0,135,136,96,0,23,0,0,0,136,136,96,0,23,0,0,0,137,136,96,0,23,0,0,0,138,136,96,0,23,0,0,0,139,136,96,0,23,0,0,0,140,136,96,0,23,0,0,0,141,136,96,0,23,0,0,0,142,136,96,0,23,0,0,0,143,136,96,0,23,0,0,0,151,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,216,51,40,0,160,255,39,0,192,145,37,0,216,51,40,0,1,80,1,0,22,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,116,7,0,0,170,1,0,0,14,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,58,40,0,232,255,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,64,3,0,0,222,7,0,0,140,3,0,0,122,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,0,0,0,93,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,7,8,0,232,7,8,0,56,8,8,0,136,8,8,0,136,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,8,8,0,200,8,8,0,200,8,8,0,8,9,8,0,8,9,8,0,8,9,8,0,40,9,8,0,40,9,8,0,72,9,8,0,72,9,8,0,72,9,8,0,232,8,8,0,232,8,8,0,0,0,0,0,104,9,8,0,104,9,8,0,24,10,8,0,120,10,8,0,120,10,8,0,224,10,8,0,72,11,8,0,72,11,8,0,168,11,8,0,168,11,8,0,168,11,8,0,192,9,8,0,192,9,8,0,0,0,0,0,0,16,64,80,0,0,0,0,40,188,37,0,120,152,39,0,0,0,0,0,24,0,0,0,35,0,0,0,0,0,0,0,120,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,190,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,92,1,0,0,202,4,0,0,0,0,0,0,0,0,0,0,1,5,1,1,3,3,2,3,3,4,2,4,0,5,1,4,1,4,3,2,5,3,4,3,3,3,2,3,0,4,1,3,1,5,1,1,3,3,0,5,3,4,2,3,2,4,1,4,1,6,1,1,1,2,0,6,3,4,2,4,1,5,1,4,1,6,1,1,1,2,3,5,2,5,0,6,1,5,1,3,1,7,1,1,1,2,1,3,1,4,1,6,0,7,1,5,55,0,6,0,86,0,7,0,1,0,17,0,1,0,20,0,2,0,20,0,3,0,20,0,0,0,20,0,4,0,20,0,5,0,20,0,3,0,19,0,21,0,11,0,66,0,9,0,20,0,11,0,3,0,14,0,2,0,14,0,1,0,15,0,1,0,16,0,1,0,12,0,43,0,10,0,24,0,11,0,12,0,11,0,65,0,9,0,120,0,8,0,108,0,8,0,85,0,7,0,15,0,4,0,14,0,4,0,52,0,6,0,81,0,7,0,114,0,8,0,110,0,8,0,64,0,9,0,63,0,9,0,62,0,9,0,61,0,9,0,60,0,9,0,59,0,9,0,58,0,9,0,57,0,9,0,56,0,9,0,55,0,9,0,67,0,9,0,70,0,9,0,71,0,9,0,69,0,9,0,68,0,9,0,73,0,9,0,72,0,9,0,74,0,8,0,121,0,8,0,118,0,8,0,119,0,8,0,113,0,8,0,117,0,8,0,116,0,8,0,115,0,8,0,106,0,8,0,85,0,8,0,112,0,8,0,111,0,8,0,82,0,8,0,109,0,8,0,76,0,8,0,107,0,8,0,64,0,7,0,105,0,8,0,104,0,8,0,103,0,8,0,102,0,8,0,101,0,8,0,100,0,8,0,99,0,8,0,98,0,8,0,97,0,8,0,96,0,8,0,95,0,8,0,94,0,8,0,93,0,8,0,92,0,8,0,91,0,8,0,90,0,8,0,89,0,8,0,88,0,8,0,87,0,8,0,86,0,8,0,61,0,7,0,84,0,8,0,83,0,8,0,63,0,7,0,81,0,8,0,80,0,8,0,79,0,8,0,78,0,8,0,77,0,8,0,65,0,7,0,75,0,8,0,83,0,7,0,62,0,7,0,72,0,8,0,79,0,7,0,82,0,7,0,69,0,8,0,80,0,7,0,67,0,8,0,66,0,8,0,65,0,8,0,66,0,7,0,67,0,7,0,62,0,8,0,68,0,7,0,60,0,8,0,69,0,7,0,70,0,7,0,71,0,7,0,72,0,7,0,73,0,7,0,74,0,7,0,75,0,7,0,76,0,7,0,77,0,7,0,78,0,7,0,88,0,7,0,89,0,7,0,90,0,7,0,91,0,7,0,92,0,7,0,93,0,7,0,68,0,8,0,73,0,8,0,41,0,8,0,63,0,8,0,61,0,8,0,59,0,8,0,44,0,8,0,40,0,8,0,37,0,8,0,38,0,8,0,94,0,7,0,87,0,7,0,84,0,7,0,95,0,7,0,98,0,7,0,99,0,7,0,100,0,7,0,97,0,7,0,101,0,7,0,103,0,7,0,102,0,7,0,53,0,6,0,54,0,6,0,96,0,7,0,57,0,8,0,58,0,8,0,56,0,8,0,55,0,8,0,54,0,8,0,53,0,8,0,52,0,8,0,51,0,8,0,50,0,8,0,49,0,8,0,48,0,8,0,45,0,8,0,43,0,8,0,42,0,8,0,39,0,8,0,64,0,8,0,70,0,8,0,71,0,8,0,38,0,9,0,37,0,9,0,36,0,9,0,35,0,9,0,34,0,9,0,46,0,8,0,47,0,8,0,31,0,9,0,54,0,9,0,29,0,9,0,33,0,9,0,27,0,9,0,28,0,9,0,25,0,9,0,26,0,9,0,24,0,9,0,23,0,9,0,22,0,9,0,30,0,9,0,32,0,9,0,39,0,9,0,40,0,9,0,41,0,9,0,42,0,9,0,43,0,9,0,44,0,9,0,45,0,9,0,46,0,9,0,47,0,9,0,48,0,9,0,53,0,9,0,49,0,9,0,50,0,9,0,51,0,9,0,52,0,9,0,25,0,10,0,42,0,10,0,23,0,10,0,22,0,10,0,21,0,10,0,40,0,10,0,38,0,10,0,37,0,10,0,34,0,10,0,33,0,10,0,24,0,10,0,20,0,10,0,41,0,10,0,18,0,10,0,13,0,10,0,14,0,10,0,15,0,10,0,16,0,10,0,17,0,10,0,26,0,10,0,27,0,10,0,28,0,10,0,29,0,10,0,30,0,10,0,31,0,10,0,32,0,10,0,19,0,10,0,35,0,10,0,36,0,10,0,9,0,11,0,8,0,11,0,7,0,11,0,39,0,10,0,5,0,11,0,11,0,11,0,6,0,11,0,4,0,11,0,3,0,11,0,2,0,11,0,1,0,11,0,10,0,11,0,22,0,11,0,25,0,11,0,23,0,11,0,13,0,11,0,14,0,11,0,15,0,11,0,16,0,11,0,17,0,11,0,18,0,11,0,19,0,11,0,1,0,14,0,64,58,8,0,64,52,8,0,64,40,8,0,64,16,8,0,0,0,0,0,0,0,0,0,3,2,5,3,4,3,3,3,2,3,1,3,1,4,0,4,3,2,5,3,4,3,3,3,2,3,1,3,1,4,0,4,1,1,3,3,2,3,3,4,2,4,1,4,1,5,0,5,1,1,3,3,2,3,3,4,2,4,1,4,1,5,0,5,1,1,3,3,2,3,3,4,2,4,1,4,1,5,0,5,1,1,1,2,1,3,3,5,2,5,1,5,1,6,0,6,90,0,22,0,212,0,22,0,213,0,22,0,214,0,22,0,215,0,22,0,216,0,22,0,217,0,22,0,218,0,22,0,219,0,22,0,220,0,22,0,221,0,22,0,222,0,22,0,223,0,22,0,224,0,22,0,225,0,22,0,226,0,22,0,227,0,22,0,228,0,22,0,229,0,22,0,230,0,22,0,232,0,22,0,203,0,22,0,233,0,22,0,234,0,22,0,231,0,22,0,236,0,22,0,237,0,22,0,238,0,22,0,239,0,22,0,240,0,22,0,241,0,22,0,242,0,22,0,243,0,22,0,244,0,22,0,245,0,22,0,246,0,22,0,247,0,22,0,248,0,22,0,2,1,22,0,235,0,22,0,249,0,22,0,252,0,22,0,253,0,22,0,254,0,22,0,0,1,22,0,92,0,22,0,96,0,22,0,1,1,22,0,113,0,22,0,4,1,22,0,5,1,22,0,251,0,22,0,255,0,22,0,134,0,21,0,250,0,22,0,124,0,22,0,117,0,22,0,3,1,22,0,120,0,22,0,211,0,22,0,123,0,22,0,130,0,22,0,210,0,22,0,209,0,22,0,208,0,22,0,207,0,22,0,206,0,22,0,205,0,22,0,204,0,22,0,195,0,22,0,202,0,22,0,201,0,22,0,200,0,22,0,199,0,22,0,198,0,22,0,197,0,22,0,139,0,22,0,196,0,22,0,194,0,22,0,193,0,22,0,192,0,22,0,191,0,22,0,190,0,22,0,189,0,22,0,188,0,22,0,187,0,22,0,186,0,22,0,185,0,22,0,97,0,22,0,132,0,22,0,133,0,22,0,134,0,22,0,135,0,22,0,136,0,22,0,137,0,22,0,138,0,22,0,140,0,22,0,141,0,22,0,142,0,22,0,143,0,22,0,144,0,22,0,145,0,22,0,146,0,22,0,147,0,22,0,148,0,22,0,149,0,22,0,150,0,22,0,151,0,22,0,152,0,22,0,153,0,22,0,154,0,22,0,155,0,22,0,156,0,22,0,157,0,22,0,158,0,22,0,159,0,22,0,160,0,22,0,161,0,22,0,162,0,22,0,163,0,22,0,164,0,22,0,165,0,22,0,166,0,22,0,167,0,22,0,168,0,22,0,169,0,22,0,170,0,22,0,171,0,22,0,127,0,22,0,143,0,21,0,172,0,22,0,173,0,22,0,174,0,22,0,175,0,22,0,176,0,22,0,177,0,22,0,83,0,20,0,144,0,21,0,178,0,22,0,145,0,21,0,179,0,22,0,180,0,22,0,84,0,20,0,181,0,22,0,182,0,22,0,140,0,21,0,52,0,19,0,61,0,18,0,85,0,20,0,183,0,22,0,184,0,22,0,139,0,21,0,86,0,20,0,61,0,19,0,87,0,20,0,88,0,20,0,64,0,19,0,67,0,19,0,71,0,19,0,42,0,18,0,46,0,19,0,44,0,18,0,70,0,19,0,89,0,20,0,73,0,19,0,45,0,19,0,56,0,18,0,54,0,18,0,57,0,18,0,69,0,19,0,40,0,18,0,48,0,18,0,53,0,18,0,32,0,17,0,68,0,19,0,50,0,18,0,49,0,18,0,31,0,17,0,47,0,18,0,46,0,18,0,45,0,18,0,33,0,17,0,34,0,17,0,35,0,17,0,36,0,17,0,39,0,16,0,35,0,16,0,32,0,16,0,29,0,16,0,37,0,16,0,30,0,16,0,36,0,16,0,42,0,16,0,38,0,16,0,33,0,15,0,41,0,16,0,34,0,15,0,35,0,15,0,36,0,15,0,27,0,15,0,26,0,15,0,29,0,15,0,31,0,15,0,39,0,15,0,23,0,14,0,24,0,14,0,25,0,14,0,27,0,14,0,28,0,14,0,30,0,14,0,37,0,14,0,32,0,14,0,33,0,14,0,19,0,13,0,20,0,13,0,21,0,13,0,22,0,13,0,23,0,13,0,24,0,13,0,25,0,13,0,26,0,13,0,24,0,12,0,23,0,12,0,21,0,12,0,20,0,12,0,19,0,12,0,18,0,12,0,15,0,11,0,16,0,11,0,18,0,11,0,19,0,11,0,27,0,11,0,26,0,11,0,14,0,10,0,19,0,10,0,15,0,10,0,16,0,10,0,17,0,10,0,18,0,10,0,13,0,9,0,20,0,9,0,21,0,9,0,12,0,9,0,19,0,9,0,15,0,8,0,14,0,8,0,16,0,8,0,17,0,8,0,12,0,7,0,9,0,7,0,10,0,7,0,8,0,6,0,9,0,6,0,9,0,5,0,8,0,5,0,5,0,4,0,1,0,1,0,3,0,3,0,7,0,5,0,6,0,5,0,11,0,6,0,10,0,6,0,14,0,7,0,15,0,7,0,11,0,7,0,13,0,7,0,11,0,8,0,13,0,8,0,12,0,8,0,15,0,9,0,16,0,9,0,17,0,9,0,14,0,9,0,18,0,9,0,23,0,10,0,20,0,10,0,22,0,10,0,21,0,10,0,25,0,11,0,24,0,11,0,23,0,11,0,22,0,11,0,21,0,11,0,20,0,11,0,17,0,11,0,25,0,12,0,26,0,12,0,22,0,12,0,29,0,12,0,27,0,12,0,28,0,12,0,32,0,13,0,28,0,13,0,35,0,13,0,34,0,13,0,33,0,13,0,31,0,13,0,30,0,13,0,27,0,13,0,29,0,13,0,36,0,14,0,22,0,14,0,26,0,14,0,34,0,14,0,29,0,14,0,31,0,14,0,21,0,14,0,35,0,14,0,24,0,15,0,32,0,15,0,41,0,15,0,40,0,15,0,38,0,15,0,37,0,15,0,25,0,15,0,28,0,15,0,30,0,15,0,23,0,15,0,44,0,16,0,43,0,16,0,28,0,16,0,33,0,16,0,45,0,16,0,40,0,16,0,31,0,16,0,27,0,16,0,26,0,16,0,34,0,16,0,45,0,17,0,50,0,17,0,44,0,17,0,39,0,17,0,49,0,17,0,51,0,17,0,47,0,17,0,43,0,17,0,55,0,18,0,42,0,17,0,46,0,17,0,48,0,17,0,41,0,17,0,40,0,17,0,38,0,17,0,37,0,17,0,47,0,19,0,51,0,18,0,52,0,18,0,48,0,19,0,58,0,18,0,59,0,18,0,49,0,19,0,60,0,18,0,43,0,18,0,41,0,18,0,72,0,19,0,39,0,18,0,66,0,19,0,65,0,19,0,38,0,18,0,82,0,20,0,81,0,20,0,63,0,19,0,62,0,19,0,57,0,19,0,60,0,19,0,59,0,19,0,58,0,19,0,37,0,18,0,56,0,19,0,80,0,20,0,55,0,19,0,54,0,19,0,135,0,21,0,79,0,20,0,53,0,19,0,78,0,20,0,51,0,19,0,50,0,19,0,77,0,20,0,76,0,20,0,131,0,22,0,75,0,20,0,129,0,22,0,128,0,22,0,142,0,21,0,126,0,22,0,125,0,22,0,132,0,21,0,141,0,21,0,122,0,22,0,121,0,22,0,74,0,20,0,119,0,22,0,118,0,22,0,137,0,21,0,116,0,22,0,115,0,22,0,114,0,22,0,73,0,20,0,112,0,22,0,111,0,22,0,110,0,22,0,109,0,22,0,108,0,22,0,107,0,22,0,106,0,22,0,105,0,22,0,104,0,22,0,103,0,22,0,102,0,22,0,101,0,22,0,100,0,22,0,99,0,22,0,98,0,22,0,138,0,21,0,136,0,21,0,95,0,22,0,94,0,22,0,93,0,22,0,133,0,21,0,91,0,22,0,131,0,21,0,89,0,22,0,88,0,22,0,87,0,22,0,86,0,22,0,85,0,22,0,84,0,22,0,83,0,22,0,82,0,22,0,81,0,22,0,80,0,22,0,79,0,22,0,78,0,22,0,77,0,22,0,76,0,22,0,75,0,22,0,74,0,22,0,73,0,22,0,72,0,22,0,71,0,22,0,70,0,22,0,69,0,22,0,68,0,22,0,67,0,22,0,66,0,22,0,65,0,22,0,64,0,22,0,63,0,22,0,62,0,22,0,61,0,22,0,60,0,22,0,59,0,22,0,58,0,22,0,57,0,22,0,56,0,22,0,55,0,22,0,54,0,22,0,53,0,22,0,52,0,22,0,51,0,22,0,50,0,22,0,49,0,22,0,48,0,22,0,47,0,22,0,46,0,22,0,45,0,22,0,44,0,22,0,43,0,22,0,42,0,22,0,41,0,22,0,40,0,22,0,39,0,22,0,38,0,22,0,37,0,22,0,36,0,22,0,35,0,22,0,34,0,22,0,33,0,22,0,32,0,22,0,31,0,22,0,30,0,22,0,29,0,22,0,28,0,22,0,27,0,22,0,26,0,22,0,25,0,22,0,24,0,22,0,23,0,22,0,22,0,22,0,21,0,22,0,20,0,22,0,19,0,22,0,18,0,22,0,17,0,22,0,16,0,22,0,15,0,22,0,14,0,22,0,13,0,22,0,12,0,22,0,11,0,22,0,10,0,22,0,9,0,22,0,8,0,22,0,7,0,22,0,6,0,22,0,5,0,22,0,4,0,22,0,3,0,22,0,2,0,22,0,1,0,22,0,0,0,22,0,192,104,8,0,192,98,8,0,192,86,8,0,192,62,8,0,0,0,0,0,0,0,0,0,160,0,120,0,128,0,96,0,176,0,144,0,96,1,32,1,192,2,64,2,240,0,180,0,64,1,240,0,0,0,0,0,128,188,37,0,176,152,39,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,128,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,12,3,0,0,0,0,0,0,146,10,0,0,0,0,0,0,0,0,0,0,160,188,37,0,232,152,39,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,136,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,10,0,0,0,0,0,0,0,0,0,0,174,2,0,0,92,4,0,0,50,1,0,0,0,0,0,0,1,1,1,2,1,3,0,3,176,188,37,0,32,153,39,0,0,0,0,0,111,0,0,0,0,0,0,0,0,0,0,0,144,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,109,8,0,0,0,0,0,110,6,0,0,0,0,0,0,12,0,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,200,188,37,0,56,153,39,0,0,0,0,0,111,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,62,40,0,80,0,40,0,0,0,0,0,24,146,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,104,4,0,0,182,4,0,0,138,1,0,0,148,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,216,188,37,0,80,153,39,0,3,0,0,0,86,98,117,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,30,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,64,40,0,120,0,40,0,0,0,0,0,32,146,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,96,6,0,0,64,11,0,0,76,3,0,0,82,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,72,151,33,0,248,26,33,0,3,0,0,0,49,86,98,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,109,8,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,3,0,0,0,0,0,0,0,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,83,37,0,56,247,35,0,3,0,0,0,112,105,82,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,5,0,0,44,2,0,0,0,0,0,0,0,0,0,0,106,5,0,0,0,0,0,0,0,0,0,0,240,83,37,0,72,247,35,0,3,0,0,0,112,105,82,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,226,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,180,37,0,168,70,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,40,133,8,0,0,0,0,0,200,0,0,0,138,3,0,0,68,3,0,0,84,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,161,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,200,73,32,0,72,196,37,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,234,4,0,0,170,9,0,0,180,0,0,0,132,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,155,39,0,144,228,39,0,3,0,0,0,4,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,6,0,0,246,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,157,39,0,248,228,39,0,3,0,0,0,4,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,10,0,0,0,0,0,0,0,0,0,0,16,1,0,0,178,4,0,0,0,0,0,0,0,0,0,0,40,68,40,0,144,1,40,0,104,146,37,0,40,68,40,0,0,0,0,0,0,0,0,0,112,105,82,83,0,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,38,0,0,0,96,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,189,37,0,160,153,39,0,3,0,0,0,8,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,5,0,0,44,2,0,0,0,0,0,0,0,0,0,0,106,5,0,0,0,0,0,0,0,0,0,0,200,70,40,0,160,1,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,80,0,0,0,70,0,0,0,146,1,0,0,80,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,72,190,37,0,232,153,39,0,3,0,0,0,8,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,226,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,23,28,32,36,40,43,46,48,51,54,56,58,60,62,64,66,68,70,72,74,76,77,79,80,82,84,85,87,88,90,91,92,94,95,96,98,99,100,102,103,104,105,107,108,109,110,111,112,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,144,145,146,147,148,149,150,151,151,152,153,154,155,156,156,157,158,159,160,160,161,162,163,164,164,165,166,167,168,168,169,170,171,171,172,173,174,174,175,176,176,177,178,179,179,180,181,182,182,183,184,184,185,186,186,187,188,188,189,190,190,191,192,192,193,194,194,195,196,196,197,198,198,199,200,200,201,202,202,203,204,204,205,205,206,207,207,208,208,209,210,210,211,212,212,213,213,214,215,215,216,216,217,218,218,219,219,220,220,221,222,222,223,223,224,224,225,226,226,227,227,228,228,229,230,230,231,231,232,232,233,233,234,235,235,236,236,237,237,238,238,239,239,240,240,241,242,242,243,243,244,244,245,245,246,246,247,247,248,248,249,249,250,250,251,251,252,252,253,253,254,254,255,255,255,0,0,2,0,2,0,3,0,3,0,3,0,4,0,3,0,5,0,3,0,6,0,3,0,14,0,4,0,30,0,5,0,62,0,6,0,126,0,7,0,254,0,8,0,254,1,9,0,254,3,10,0,254,7,11,0,254,15,12,0,0,0,0,0,168,130,34,0,136,203,33,0,96,74,33,0,32,220,32,0,36,80,1,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,16,137,8,0,0,0,0,0,24,0,0,0,24,10,0,0,128,1,0,0,102,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,124,32,0,8,0,0,0,0,0,0,0,118,2,0,0,242,3,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,24,78,40,0,224,1,40,0,0,0,0,0,24,78,40,0,3,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,216,137,8,0,0,0,0,0,76,0,0,0,230,6,0,0,144,2,0,0,76,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,147,37,0,160,46,36,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,8,0,0,56,3,0,0,54,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,190,37,0,16,154,39,0,0,0,0,0,11,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,0,0,0,0,0,0,0,0,0,0,204,2,0,0,138,5,0,0,0,0,0,0,0,0,0,0,16,85,40,0,64,2,40,0,0,0,0,0,16,85,40,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,222,4,0,0,136,1,0,0,92,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,86,40,0,120,2,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,6,0,0,96,5,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,37,0,104,247,35,0,1,0,0,0,76,78,79,83,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,11,0,0,0,0,0,0,4,3,0,0,0,0,0,0,2,8,0,0,0,0,0,0,0,0,0,0,64,191,37,0,56,154,39,0,1,0,0,0,67,78,79,83,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,11,0,0,0,0,0,0,4,3,0,0,0,0,0,0,2,8,0,0,0,0,0,0,0,0,0,0,64,191,37,0,56,154,39,0,1,0,0,0,67,78,79,83,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,5,0,0,0,0,0,0,0,0,0,0,58,2,0,0,132,1,0,0,0,0,0,0,0,0,0,0,112,25,35,0,176,81,34,0,1,0,0,0,3,64,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,6,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,86,40,0,136,2,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,3,0,0,80,7,0,0,100,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,192,37,0,64,154,39,0,0,0,0,0,87,79,78,83,0,0,0,0,0,0,0,0,176,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,151,8,0,0,0,0,0,144,239,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,3,0,0,0,0,0,0,28,2,0,0,0,0,0,0,250,10,0,0,0,0,0,0,0,0,0,0,152,192,37,0,104,154,39,0,0,0,0,0,87,79,78,83,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,239,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,10,0,0,0,0,0,0,0,0,0,0,52,0,0,0,194,8,0,0,0,0,0,0,0,0,0,0,248,192,37,0,152,154,39,0,0,0,0,0,74,86,77,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,151,8,0,0,0,0,0,224,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,114,8,0,0,0,0,0,0,0,0,0,0,240,86,40,0,152,2,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,142,6,0,0,84,4,0,0,198,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,87,40,0,176,2,40,0,0,0,0,0,0,0,0,0,2,80,1,0,28,0,0,0,0,0,0,0,65,0,0,0,208,107,40,0,136,36,16,0,0,0,0,0,40,0,0,0,84,6,0,0,82,1,0,0,52,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,88,40,0,200,2,40,0,0,0,0,0,0,0,0,0,0,0,1,0,8,0,0,0,0,0,0,0,64,0,2,0,216,107,40,0,0,0,0,0,0,0,0,0,4,0,0,0,74,3,0,0,252,3,0,0,74,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,90,40,0,216,2,40,0,0,1,0,0,216,147,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,32,3,0,0,70,5,0,0,228,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,193,37,0,184,154,39,0,0,0,0,0,50,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,4,0,0,0,0,0,0,0,0,0,0,16,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,24,90,40,0,232,2,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,4,0,0,124,9,0,0,182,11,0,0,120,3,0,0,154,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,37,0,216,154,39,0,0,0,0,0,84,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,9,0,0,0,0,0,0,0,0,0,0,188,2,0,0,192,4,0,0,0,0,0,0,0,0,0,0,192,84,37,0,40,248,35,0,1,0,0,0,23,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,1,0,0,0,0,0,0,0,0,0,0,126,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,124,32,0,8,0,0,0,0,0,0,0,222,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,19,37,20,0,0,0,0,144,194,37,0,240,154,39,0,1,0,0,0,42,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,10,0,0,0,0,0,0,0,0,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,183,95,0,24,110,95,0,152,219,95,0,152,183,95,0,24,111,95,0,152,221,95,0,152,187,95,0,24,119,95,0,24,238,94,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,228,99,0,24,82,99,0,152,45,98,0,120,228,99,0,88,82,99,0,24,46,98,0,120,229,99,0,88,84,99,0,24,50,98,0,152,237,95,0,88,100,99,0,24,82,98,0,152,45,96,0,0,0,0,0,40,27,32,0,48,178,37,0,0,0,0,0,192,68,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,46,1,0,0,204,10,0,0,126,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,115,38,0,168,59,38,0,0,224,0,0,200,115,38,0,0,0,0,0,0,0,0,0,0,0,0,0,15,80,1,0,0,0,0,0,0,0,0,0,148,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,196,37,0,104,155,39,0,1,0,0,0,15,80,1,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,6,0,0,0,0,0,0,0,0,0,0,8,3,0,0,78,6,0,0,0,0,0,0,0,0,0,0,208,197,37,0,120,155,39,0,0,0,0,0,82,73,71,83,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,5,0,0,0,0,0,0,0,0,0,0,220,1,0,0,46,3,0,0,0,0,0,0,0,0,0,0,184,198,37], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1296148);
/* memory initializer */ allocate([136,155,39,0,0,0,0,0,102,0,0,0,0,0,0,0,0,0,0,0,216,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,2,0,0,0,0,0,0,160,1,0,0,0,0,0,0,70,2,0,0,0,0,0,0,0,0,0,0,8,203,37,0,216,155,39,0,0,0,0,0,102,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,6,0,0,0,0,0,0,0,0,0,0,228,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,34,32,0,32,34,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,0,0,0,0,0,0,64,47,9,0,0,0,0,0,200,0,0,0,138,3,0,0,68,3,0,0,84,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,34,32,0,152,180,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,242,10,0,0,222,8,0,0,38,3,0,0,172,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,17,17,17,17,17,17,17,16,17,17,17,17,17,17,17,8,248,9,247,10,246,11,245,12,244,13,243,14,242,15,241,4,4,4,4,252,252,252,252,5,5,5,5,251,251,251,251,6,6,6,6,250,250,250,250,7,7,7,7,249,249,249,249,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,254,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,253,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,34,32,0,184,180,37,0,0,1,0,0,136,34,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,6,0,0,64,1,0,0,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,222,127,191,13,71,24,191,70,156,120,63,125,223,44,191,21,177,16,62,212,110,115,191,11,171,240,190,1,47,191,190,223,154,78,63,168,211,151,62,206,149,199,190,78,78,101,63,29,136,44,188,74,106,43,191,84,164,105,191,98,253,235,189,56,100,12,63,19,145,64,63,238,216,204,62,95,66,125,191,122,169,127,191,16,168,97,191,63,143,116,191,247,185,104,63,229,29,234,190,156,49,17,191,49,179,58,191,180,230,122,191,41,152,65,63,8,136,86,62,61,200,144,61,139,80,72,191,221,181,62,63,133,100,105,191,10,227,118,191,193,136,114,191,44,198,155,62,186,31,253,190,15,104,42,63,243,130,37,63,141,190,106,63,40,88,51,62,13,47,53,191,73,134,6,63,229,84,51,191,21,36,232,190,9,182,126,191,135,149,102,191,21,77,123,63,65,78,70,191,145,245,11,191,71,156,210,188,23,106,138,188,148,107,60,59,71,113,92,191,72,217,217,62,129,42,125,191,199,249,96,191,57,127,4,63,35,85,43,63,208,16,127,191,123,193,20,191,237,235,127,191,194,211,123,63,76,123,13,63,137,48,24,63,62,14,177,62,45,228,114,63,158,107,32,63,187,120,62,191,212,128,69,191,253,123,173,190,229,121,106,191,115,14,23,61,118,74,67,191,120,233,105,191,22,66,76,63,21,139,110,191,122,115,11,63,248,26,244,189,143,60,91,191,169,61,217,62,105,199,109,191,35,180,142,62,150,201,239,189,123,125,127,191,112,177,90,62,213,59,104,191,253,12,67,191,9,104,127,63,14,42,123,63,46,99,117,191,31,240,91,191,148,41,117,63,214,221,110,191,50,23,253,62,74,22,156,62,30,149,52,191,109,87,90,63,78,113,239,62,198,204,105,63,225,150,127,191,57,67,113,189,93,25,53,63,186,102,145,62,229,82,177,62,100,220,115,63,243,134,12,191,58,33,73,191,153,116,65,191,155,56,117,191,46,34,81,190,250,248,82,63,146,111,119,63,239,223,38,191,93,41,99,191,70,186,111,191,82,171,127,63,180,13,106,63,170,159,123,191,132,54,52,191,18,133,22,63,159,188,184,59,104,32,30,63,172,1,100,63,25,32,7,63,142,212,47,191,164,221,78,63,71,190,56,63,36,78,49,191,168,24,33,191,118,138,11,62,232,72,153,62,102,200,235,190,57,246,106,191,249,120,61,191,104,52,126,63,38,251,208,62,227,220,82,63,68,136,61,191,95,49,124,191,222,237,127,191,25,139,117,191,124,12,126,191,252,63,91,190,228,42,111,191,216,46,48,191,73,176,137,190,32,36,107,63,18,168,191,61,178,235,117,191,206,211,184,62,216,54,4,63,58,183,54,191,161,126,28,63,125,98,240,62,105,92,242,62,37,242,139,190,167,244,104,63,148,151,119,63,250,154,229,62,76,251,125,63,188,136,42,63,86,69,119,63,10,205,63,63,170,23,102,191,60,231,126,191,133,33,7,63,198,88,121,63,167,154,44,190,5,18,58,63,56,18,246,190,113,78,116,63,71,65,48,63,131,200,58,191,28,30,68,191,48,133,90,191,107,43,99,63,115,106,80,191,255,140,121,191,80,26,97,191,13,91,63,63,76,58,55,191,60,87,124,191,124,210,85,63,75,71,86,63,94,51,246,190,91,13,125,191,25,173,120,63,40,10,77,63,5,26,5,63,22,111,77,63,127,8,11,188,137,70,68,191,31,244,51,191,172,184,13,63,95,125,117,191,246,132,221,190,220,133,120,63,90,254,190,61,20,142,108,191,84,230,90,63,195,239,49,191,101,128,124,63,174,251,135,62,68,175,59,63,140,142,143,62,69,222,20,62,41,203,61,191,6,60,126,63,204,150,143,188,163,127,83,191,226,31,13,191,38,46,125,191,168,199,122,63,229,177,112,191,75,241,125,191,149,145,43,63,255,69,45,191,179,88,1,62,33,48,187,61,110,78,82,190,107,114,55,191,122,86,122,191,193,101,79,63,173,135,9,63,129,245,207,62,117,133,135,190,227,66,45,191,221,236,113,63,222,85,94,63,110,188,59,190,146,184,126,191,139,201,215,188,250,225,87,63,110,34,213,61,56,190,188,189,190,5,50,63,71,227,127,63,90,26,253,189,173,29,76,191,134,115,106,191,235,167,118,63,74,102,119,63,77,167,76,191,80,171,36,63,92,223,236,189,169,94,146,62,209,103,204,190,199,248,112,63,25,171,125,63,42,174,107,191,153,151,146,62,186,12,105,191,70,65,85,191,168,93,44,191,66,60,116,63,159,182,251,62,220,23,132,189,154,36,5,61,130,233,126,191,35,9,217,62,212,174,39,191,108,81,83,63,233,2,80,191,109,42,4,191,63,24,127,191,183,75,88,63,164,163,60,59,135,206,37,63,49,167,51,63,99,112,81,190,185,175,118,63,112,107,208,62,169,87,48,191,230,211,105,63,33,144,178,190,21,248,54,63,17,120,107,63,83,66,42,63,146,118,125,191,119,210,91,63,227,75,48,63,140,125,14,63,25,174,126,191,149,86,77,190,108,48,113,63,13,57,127,191,218,148,44,191,216,175,253,62,163,96,242,190,67,234,91,191,152,172,18,62,66,3,113,191,138,218,149,190,218,229,107,61,125,57,224,62,41,255,73,191,73,22,186,190,28,20,38,63,95,54,179,189,30,20,122,63,36,7,119,191,109,35,10,191,35,38,14,63,89,246,73,63,1,66,60,63,213,234,118,63,216,39,158,190,55,128,78,191,140,110,18,61,81,39,121,191,151,185,124,63,210,218,247,62,230,31,81,191,216,132,104,191,58,189,45,63,157,22,80,63,56,225,33,190,207,80,90,63,226,166,78,63,59,27,125,190,174,173,244,62,201,57,237,190,113,179,118,63,90,13,197,62,238,206,125,191,140,112,127,190,138,176,84,63,148,163,114,191,126,104,22,191,235,122,83,60,219,147,116,63,171,6,91,191,74,4,119,191,201,228,35,191,74,40,121,191,10,129,253,61,37,252,105,63,215,104,20,63,102,207,127,191,42,250,53,63,254,102,94,191,121,201,79,190,87,89,134,190,220,193,46,191,71,144,124,190,61,93,96,191,250,240,197,60,76,58,139,62,126,24,82,63,34,211,89,191,104,174,98,63,96,120,101,191,162,23,58,190,36,230,133,190,164,153,191,61,77,103,12,63,126,243,11,191,246,181,117,63,121,179,189,62,182,94,25,191,10,40,52,191,247,138,105,63,241,39,177,190,239,145,126,191,11,16,48,191,166,210,154,190,10,112,137,190,175,198,84,63,23,64,251,62,225,61,232,190,157,142,199,62,242,132,116,63,28,66,122,191,86,84,89,61,230,105,49,190,48,126,109,191,242,221,127,63,4,54,21,63,44,67,38,191,133,187,47,63,70,27,246,189,18,76,18,191,206,231,22,191,213,106,178,190,241,23,214,190,170,171,38,62,15,181,127,63,54,17,228,61,228,5,17,191,183,170,103,191,75,254,112,63,183,164,180,62,48,219,65,191,109,88,9,63,141,89,82,62,4,193,113,191,35,243,127,63,68,97,76,63,123,225,148,62,85,55,181,62,32,235,32,191,248,122,198,62,221,106,222,62,83,71,124,191,246,164,123,191,170,66,87,62,60,208,71,62,4,65,113,191,150,107,116,191,50,208,123,63,71,13,111,63,57,117,53,191,225,51,90,191,238,217,170,189,141,63,93,191,117,120,234,190,129,16,199,62,197,5,121,63,177,162,107,63,133,212,31,191,143,65,100,63,169,172,12,63,129,151,188,190,233,238,118,63,232,92,112,63,169,81,102,191,13,32,126,63,92,227,25,189,112,205,112,191,31,159,211,62,193,85,127,63,34,88,44,190,20,206,183,190,26,195,238,190,106,132,86,61,86,71,131,190,31,236,187,62,156,231,197,190,212,161,106,63,209,155,156,190,94,164,48,63,106,214,104,63,204,238,197,190,90,185,126,63,161,195,149,190,231,183,191,62,2,17,26,191,233,39,94,63,63,100,121,191,157,245,118,63,45,118,98,63,181,56,19,63,196,242,84,61,36,205,89,62,131,245,8,191,58,240,120,63,80,20,253,190,199,89,123,63,35,70,125,191,97,19,206,190,157,22,123,191,127,131,58,191,169,248,139,190,214,223,127,63,200,62,129,61,16,159,11,191,15,135,81,190,155,130,17,190,117,136,41,63,85,172,57,63,41,255,88,191,23,87,194,60,42,241,99,191,154,127,99,63,49,131,117,63,142,119,68,63,170,43,60,63,70,124,25,189,17,136,162,190,53,151,188,190,190,165,174,190,167,225,205,62,130,193,244,62,205,216,201,190,92,165,123,63,243,0,163,60,235,135,158,190,10,27,57,190,37,251,127,63,45,144,134,190,156,118,110,191,132,174,123,191,217,205,127,63,131,42,77,191,102,62,133,190,52,143,66,191,27,217,182,190,19,159,69,62,221,189,127,191,115,23,63,63,28,150,93,63,255,81,14,63,151,12,171,62,212,162,92,63,173,119,125,63,163,131,60,61,194,188,42,191,143,155,106,191,11,226,35,63,78,64,32,62,140,230,126,63,106,185,234,62,114,98,34,191,164,217,87,62,19,214,157,189,23,84,101,191,0,100,124,63,24,230,97,63,230,13,77,63,133,174,188,190,87,159,72,63,239,254,232,62,252,85,178,61,46,52,79,63,9,61,94,191,78,117,201,62,146,17,202,190,59,8,43,191,147,143,122,63,134,132,57,191,121,76,115,191,39,72,101,63,55,34,46,62,22,253,11,63,66,228,68,191,19,87,118,191,194,87,127,63,5,156,218,62,216,81,116,63,113,83,120,63,8,236,126,63,115,131,10,191,134,168,143,62,118,134,90,191,183,65,90,63,7,75,37,191,208,142,1,191,216,144,40,191,7,220,120,191,183,126,108,190,27,73,116,63,6,14,126,191,204,33,120,191,157,221,60,63,195,16,158,62,125,142,212,62,198,31,123,190,25,207,33,63,185,31,173,190,196,242,197,190,185,170,110,189,165,37,142,189,241,122,106,190,222,117,120,63,162,138,61,190,102,137,243,62,147,204,214,189,234,176,96,191,152,7,56,191,98,194,71,63,234,120,127,63,121,129,102,63,176,92,19,63,67,12,105,191,116,4,148,62,69,140,118,63,247,1,216,62,102,133,246,62,15,240,110,63,217,232,222,190,47,139,120,191,16,202,93,63,103,5,188,62,138,37,39,63,32,153,79,191,241,199,179,61,21,90,134,190,110,128,109,191,242,7,87,63,52,243,14,63,196,196,127,191,176,210,117,191,70,26,63,63,56,186,248,61,71,108,63,191,212,183,137,190,121,51,117,63,217,92,74,191,187,104,116,63,236,229,175,189,252,98,249,62,95,255,127,63,84,56,237,62,153,139,224,61,20,213,67,191,70,97,100,63,244,239,18,63,236,174,180,62,80,245,64,63,187,144,119,63,137,124,23,191,180,224,100,191,156,57,64,63,236,157,151,190,165,111,124,191,194,45,128,62,85,178,208,190,68,132,102,191,196,86,43,63,211,125,124,63,207,129,121,191,89,84,249,186,195,197,102,63,187,112,127,63,63,98,95,191,185,9,126,63,191,80,106,191,56,193,32,190,47,103,7,189,175,125,190,190,151,237,147,61,63,87,99,191,4,183,126,63,194,143,120,63,179,193,63,191,125,246,127,63,155,207,59,61,3,133,127,63,14,251,99,191,76,198,162,190,119,123,86,191,205,243,121,63,226,73,171,62,176,192,92,191,92,64,127,191,115,176,110,63,255,192,105,190,13,71,65,62,174,39,44,63,76,89,21,189,93,205,82,189,36,14,109,191,118,221,127,63,59,174,111,63,23,101,43,63,236,50,125,63,203,251,126,191,212,161,228,190,69,48,82,63,5,211,126,63,223,234,125,63,254,96,56,63,233,32,39,191,23,153,5,63,196,88,112,63,100,187,63,191,106,164,119,63,220,174,104,63,11,152,99,190,206,60,18,63,185,245,225,190,143,72,109,191,15,97,91,191,39,113,99,63,239,246,106,63,232,88,237,190,240,190,57,63,44,190,127,191,251,66,127,191,135,5,21,63,123,193,70,63,194,118,113,63,1,13,158,61,67,29,22,63,209,124,15,191,209,65,83,63,179,230,123,63,195,18,202,62,188,112,243,62,63,166,47,63,212,32,40,63,73,183,59,62,212,19,6,61,42,212,63,191,21,16,198,190,114,108,3,63,218,52,121,191,151,42,119,191,254,102,8,191,39,11,106,191,70,136,127,63,128,128,28,63,202,166,0,191,50,103,99,191,127,128,163,60,21,44,90,63,96,210,127,63,58,31,114,63,111,62,84,63,13,129,129,189,226,43,22,191,146,233,119,63,127,244,51,190,89,157,246,190,127,151,85,63,50,92,5,190,123,145,115,61,123,8,82,62,111,167,80,63,98,101,114,191,113,71,230,190,86,97,209,62,64,192,101,191,116,155,127,63,198,37,203,62,193,160,63,191,242,107,155,189,178,175,61,63,71,112,67,63,36,190,213,62,214,177,62,191,147,127,114,63,214,23,38,63,202,164,211,62,187,137,31,63,233,84,110,191,30,37,216,62,56,245,157,189,156,142,221,60,203,230,93,189,246,205,76,63,24,89,106,63,4,36,75,191,186,99,185,190,100,131,35,63,116,119,166,61,85,102,7,63,161,185,25,63,250,12,62,63,37,253,55,61,164,175,125,63,28,46,71,190,6,219,77,191,106,152,98,191,134,104,37,191,32,212,56,63,75,192,238,61,70,45,86,191,14,86,115,191,137,42,120,191,80,78,31,191,90,226,83,63,109,32,246,60,226,84,127,191,231,216,122,191,135,3,187,62,120,247,127,191,63,110,184,190,142,31,100,63,250,155,122,191,176,39,213,61,52,9,70,63,115,171,117,63,112,110,181,190,159,40,2,63,35,9,118,63,22,37,46,62,14,191,68,191,213,119,132,62,19,186,127,63,97,216,54,188,90,38,124,63,206,197,75,191,161,172,120,63,31,30,126,191,98,212,126,191,94,144,127,191,116,198,153,60,39,64,53,191,243,113,172,62,74,101,52,191,63,199,110,63,23,155,127,63,232,188,124,191,222,54,34,191,138,176,40,190,241,123,38,190,170,154,117,191,39,119,223,190,109,179,114,191,178,156,127,191,60,99,118,63,233,254,43,190,117,104,125,191,17,58,97,191,44,158,55,191,172,55,226,62,93,137,111,191,194,223,110,63,48,199,127,191,201,125,112,191,115,104,16,191,88,202,98,191,132,214,243,62,76,237,127,63,31,194,86,191,171,246,64,191,159,120,5,60,60,90,112,63,109,27,231,189,118,236,89,63,155,3,6,63,114,69,203,62,26,91,81,63,181,144,189,190,72,231,94,191,118,114,184,190,247,111,177,62,75,19,111,191,140,66,88,191,57,42,39,191,62,210,60,190,132,242,244,61,9,190,127,63,147,99,113,63,76,230,84,63,46,53,64,63,27,238,181,190,81,53,17,63,251,139,118,190,105,233,239,62,104,81,154,190,153,30,121,63,231,215,126,191,140,24,196,190,11,52,124,63,86,13,210,62,49,103,173,60,52,99,197,61,2,183,52,61,59,83,90,191,109,45,106,63,192,127,99,63,129,82,127,191,227,203,246,190,134,210,119,191,239,43,141,62,223,26,22,63,26,173,40,191,133,158,22,63,135,6,125,63,76,252,127,63,70,120,83,190,25,194,11,63,43,11,31,191,236,83,25,191,240,19,80,62,36,105,94,191,4,88,122,191,37,129,118,63,176,149,227,61,5,1,92,62,79,206,211,190,96,120,144,62,80,31,119,62,70,80,3,63,150,247,41,191,21,244,168,189,105,119,9,191,215,251,121,191,52,229,120,191,228,28,98,62,137,185,95,63,103,8,3,190,97,19,67,62,72,73,131,60,98,84,237,190,105,214,115,191,54,172,144,189,73,222,113,191,40,168,108,191,228,43,214,189,250,149,86,191,162,219,138,188,178,140,64,63,245,226,127,191,62,145,215,190,30,73,127,63,10,144,56,191,242,62,179,190,193,214,73,63,177,76,7,63,38,84,121,63,232,174,136,190,243,247,125,63,39,242,17,191,215,148,68,63,186,227,67,191,27,237,81,191,189,60,60,191,93,186,81,63,92,58,127,63,62,206,136,190,131,100,48,63,239,192,221,190,129,108,90,63,108,240,125,63,5,52,107,63,79,146,78,191,146,13,167,190,211,145,220,62,152,115,96,190,24,86,45,63,131,108,116,191,160,191,15,63,229,249,52,191,40,214,221,61,245,183,176,189,28,140,105,63,120,237,40,191,192,189,250,190,184,25,16,63,25,237,99,191,217,112,55,191,252,22,39,63,183,190,40,63,35,165,44,63,173,28,81,191,47,150,244,190,208,236,43,190,221,69,127,191,70,135,111,191,103,173,104,191,221,206,30,63,165,140,135,189,76,214,115,190,159,138,126,63,252,163,64,62,195,19,122,63,46,195,146,190,19,185,114,63,244,157,121,191,244,79,116,191,227,203,75,191,159,106,251,190,106,108,168,62,32,178,127,63,25,211,99,63,94,38,1,63,187,37,92,191,88,121,241,62,9,73,63,190,201,237,30,191,113,0,64,63,96,153,224,190,188,254,127,63,135,126,124,63,120,41,9,191,110,119,29,191,144,40,101,191,59,89,29,189,86,234,50,191,128,31,154,190,103,9,157,189,163,110,214,62,195,63,179,60,187,129,92,191,57,78,125,63,204,25,44,63,187,46,10,190,118,22,53,191,18,246,67,191,76,193,112,63,74,219,184,61,184,232,82,191,126,199,182,61,170,51,164,190,254,93,0,63,65,112,19,63,163,90,125,191,61,253,185,190,77,96,152,61,68,242,127,63,179,177,16,190,255,116,108,191,182,211,122,191,133,99,228,190,78,214,10,191,244,112,226,62,180,152,54,63,189,102,22,61,21,213,34,63,176,145,5,63,170,157,90,191,87,111,114,191,76,157,149,188,25,211,124,191,187,168,82,63,68,213,95,63,218,220,100,63,132,34,111,191,204,213,211,62,119,236,117,63,247,96,110,63,12,176,121,63,224,139,92,63,176,21,127,63,191,175,51,63,237,113,114,191,39,115,151,190,217,126,106,63,42,66,123,191,6,222,127,191,13,71,24,191,70,156,120,63,125,223,44,191,21,177,16,62,212,110,115,191,11,171,240,190,1,47,191,190,223,154,78,63,168,211,151,62,206,149,199,190,78,78,101,63,29,136,44,188,74,106,43,191,84,164,105,191,98,253,235,189,232,39,32,0,168,183,37,0,0,0,0,0,232,39,32,0,0,0,0,0,240,85,9,0,0,0,0,0,0,0,0,0,16,0,0,0,204,11,0,0,180,9,0,0,166,1,0,0,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,152,206,37,0,40,156,39,0,0,0,0,0,77,78,65,83,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,8,0,0,0,0,0,0,0,0,0,0,114,0,0,0,20,8,0,0,0,0,0,0,0,0,0,0,88,41,32,0,16,184,37,0,0,0,0,0,72,73,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,178,3,0,0,118,9,0,0,78,0,0,0,86,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,208,207,37,0,96,156,39,0,3,0,0,0,73,77,65,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,8,0,0,0,0,0,0,0,0,0,0,32,0,0,0,202,9,0,0,0,0,0,0,0,0,0,0,136,208,37,0,184,156,39,0,1,0,0,0,26,0,1,0,0,2,1,0,0,0,0,0,0,0,0,0,0,102,40,0,248,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,5,0,0,0,0,0,0,64,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,208,37,0,224,156,39,0,1,0,0,0,26,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,0,0,0,103,0,0,0,8,59,16,0,168,57,16,0,88,58,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,0,0,0,103,0,0,0,176,75,16,0,80,74,16,0,0,75,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,210,37,0,240,156,39,0,0,0,0,0,70,0,0,0,34,16,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,218,2,0,0,8,4,0,0,14,1,0,0,0,0,0,0,48,214,37,0,96,157,39,0,0,0,0,0,69,0,0,0,34,16,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,9,0,0,0,0,0,0,0,0,0,0,218,2,0,0,8,4,0,0,14,1,0,0,0,0,0,0,152,179,32,0,128,87,32,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,8,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,81,10,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,72,250,35,0,72,3,35,0,0,0,0,0,7,0,0,0,34,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,88,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,6,0,0,0,0,0,0,0,0,0,0,28,1,0,0,210,8,0,0,14,1,0,0,0,0,0,0,72,216,37,0,248,157,39,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,16,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,81,10,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,40,158,39,0,240,86,37,0,0,0,0,0,6,0,0,0,2,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,88,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,6,0,0,0,0,0,0,0,0,0,0,28,1,0,0,210,8,0,0,0,0,0,0,0,0,0,0,8,46,32,0,56,186,37,0,0,0,0,0,0,0,0,0,6,0,1,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,87,10,0,0,0,0,0,104,0,0,0,206,3,0,0,180,2,0,0,202,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,46,32,0,80,186,37,0,0,0,0,0,80,46,32,0,5,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,200,93,40,0,0,0,0,0,0,0,0,0,0,0,0,0,128,8,0,0,170,2,0,0,176,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,46,32,0,128,186,37,0,0,0,0,0,168,46,32,0,208,93,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,7,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,46,32,0,184,186,37,0,0,0,0,0,224,46,32,0,216,93,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,0,0,0,68,4,0,0,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,216,37,0,48,158,39,0,0,0,0,0,43,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,11,0,0,0,0,0,0,0,0,0,0,156,1,0,0,178,6,0,0,0,0,0,0,0,0,0,0,144,48,32,0,112,187,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,194,11,0,0,162,6,0,0,144,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,59,33,0,16,56,38,0,0,0,0,0,232,59,33,0,0,64,1,0,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,9,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,216,37,0,72,158,39,0,0,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,24,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,93,10,0,0,0,0,0,96,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,6,0,0,0,0,0,0,94,0,0,0,0,0,0,0,220,3,0,0,0,0,0,0,0,0,0,0,144,217,37,0,104,158,39,0,1,0,0,0,0,64,1,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,5,0,0,0,0,0,0,86,1,0,0,0,0,0,0,158,7,0,0,0,0,0,0,0,0,0,0,216,117,37,0,144,24,36,0,1,0,0,0,0,64,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,6,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,60,33,0,32,56,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,158,4,0,0,250,5,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,217,37,0,88,158,39,0,0,0,0,0,39,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,5,0,0,0,0,0,0,0,0,0,0,72,1,0,0,180,8,0,0,0,0,0,0,0,0,0,0,200,49,32,0,184,187,37,0,112,75,36,0,32,65,35,0,3,80,1,0,6,0,0,0,0,0,0,0,0,0,0,0,224,93,40,0,0,0,0,0,0,0,0,0,84,0,0,0,110,1,0,0,58,0,0,0,212,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,173,39,0,232,233,39,0,160,133,37,0,96,37,36,0,192,118,32,0,144,28,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,138,7,0,0,72,3,0,0,24,1,0,0,48,3,0,0,54,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,82,86,49,48,7,0,0,0,82,86,50,48,7,0,0,0,82,86,84,82,69,0,0,0,82,86,51,48,70,0,0,0,82,86,52,48,3,80,1,0,100,110,101,116,0,48,1,0,108,112,99,74,1,48,1,0,50,56,95,56,20,80,1,0,99,111,111,107,31,80,1,0,97,116,114,99,42,80,1,0,115,105,112,114,2,80,1,0,114,97,97,99,2,80,1,0,114,97,99,112,58,80,1,0,76,83,68,58,0,0,0,0,0,0,0,0,132,0,0,0,85,0,0,0,248,6,5,0,16,9,5,0,32,31,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,185,0,0,0,119,0,0,0,128,233,4,0,104,236,4,0,40,237,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,67,0,0,0,64,129,20,0,224,130,20,0,72,131,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,0,0,0,81,0,0,0,232,237,4,0,64,240,4,0,96,6,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,99,0,0,0,136,229,4,0,48,232,4,0,216,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,58,0,0,0,128,232,20,0,32,234,20,0,136,234,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,111,0,0,0,111,0,0,0,176,34,12,0,64,43,12,0,80,46,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,111,0,0,0,111,0,0,0,120,41,12,0,64,43,12,0,80,46,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,58,0,0,0,8,56,16,0,176,61,16,0,88,62,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,51,32,0,168,188,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,250,1,0,0,238,5,0,0,154,3,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,217,37,0,120,158,39,0,0,0,0,0,115,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,52,3,0,0,92,2,0,0,0,0,0,0,0,0,0,0,160,56,32,0,168,189,37,0,232,76,36,0,96,66,35,0,64,118,34,0,168,195,33,0,232,67,33,0,8,215,32,0,200,118,32,0,160,28,32,0,176,4,40,0,112,153,39,0,232,62,39,0,88,247,38,0,160,177,38,0,112,115,38,0,80,59,38,0,24,5,38,0,216,218,37,0,24,5,38,0,232,178,37,0,200,148,37,0,224,83,37,0,8,29,37,0,40,251,36,0,40,209,36,0,0,0,0,0,0,0,0,0,0,128,64,192,32,160,96,224,16,144,80,208,48,176,112,240,8,136,72,200,40,168,104,232,24,152,88,216,56,184,120,248,4,132,68,196,36,164,100,228,20,148,84,212,52,180,116,244,12,140,76,204,44,172,108,236,28,156,92,220,60,188,124,252,2,130,66,194,34,162,98,226,18,146,82,210,50,178,114,242,10,138,74,202,42,170,106,234,26,154,90,218,58,186,122,250,6,134,70,198], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1306388);
/* memory initializer */ allocate([38,166,102,230,22,150,86,214,54,182,118,246,14,142,78,206,46,174,110,238,30,158,94,222,62,190,126,254,1,129,65,193,33,161,97,225,17,145,81,209,49,177,113,241,9,137,73,201,41,169,105,233,25,153,89,217,57,185,121,249,5,133,69,197,37,165,101,229,21,149,85,213,53,181,117,245,13,141,77,205,45,173,109,237,29,157,93,221,61,189,125,253,3,131,67,195,35,163,99,227,19,147,83,211,51,179,115,243,11,139,75,203,43,171,107,235,27,155,91,219,59,187,123,251,7,135,71,199,39,167,103,231,23,151,87,215,55,183,119,247,15,143,79,207,47,175,111,239,31,159,95,223,63,191,127,255,32,57,32,0,192,189,37,0,0,0,0,0,240,76,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,240,2,0,0,166,7,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,58,32,0,248,189,37,0,0,0,0,0,56,77,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,208,5,0,0,100,10,0,0,84,1,0,0,232,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,224,217,37,0,192,158,39,0,3,0,0,0,84,88,84,82,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,70,32,0,0,27,156,0,12,0,0,0,84,65,82,86,16,81,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,17,34,0,200,1,34,0,0,0,0,0,104,242,33,0,0,0,0,0,14,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,217,37,0,216,158,39,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,4,0,0,0,0,0,0,100,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,58,32,0,104,190,37,0,0,1,0,0,80,77,36,0,0,0,0,0,104,106,10,0,0,0,0,0,14,0,0,0,24,0,0,0,0,0,0,0,216,7,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,218,37,0,232,158,39,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,106,10,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,1,0,0,0,0,0,0,0,0,0,0,80,2,0,0,238,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,52,50,48,0,0,0,0,73,89,85,86,0,0,0,0,89,86,49,50,6,0,0,0,89,85,86,57,6,0,0,0,89,86,85,57,7,0,0,0,89,52,49,66,4,0,0,0,89,52,50,66,4,0,0,0,80,52,50,50,4,0,0,0,89,86,49,54,12,0,0,0,73,52,50,48,12,0,0,0,73,89,85,86,12,0,0,0,89,86,49,50,13,0,0,0,89,52,50,66,13,0,0,0,80,52,50,50,8,0,0,0,89,56,48,48,8,0,0,0,89,56,32,32,1,0,0,0,89,85,89,50,1,0,0,0,89,52,50,50,1,0,0,0,86,52,50,50,1,0,0,0,86,89,85,89,1,0,0,0,89,85,78,86,17,0,0,0,85,89,86,89,17,0,0,0,72,68,89,67,17,0,0,0,85,89,78,86,17,0,0,0,85,89,78,89,17,0,0,0,117,121,118,49,17,0,0,0,50,86,117,49,17,0,0,0,65,86,82,110,17,0,0,0,65,86,49,120,17,0,0,0,65,86,117,112,17,0,0,0,86,68,84,90,17,0,0,0,97,117,118,50,17,0,0,0,99,121,117,118,18,0,0,0,89,52,49,49,8,0,0,0,71,82,69,89,25,0,0,0,78,86,49,50,26,0,0,0,78,86,50,49,46,0,0,0,82,71,66,15,50,0,0,0,66,71,82,15,44,0,0,0,82,71,66,16,48,0,0,0,66,71,82,16,45,0,0,0,15,66,71,82,49,0,0,0,15,82,71,66,43,0,0,0,16,66,71,82,47,0,0,0,16,82,71,66,62,0,0,0,82,71,66,12,64,0,0,0,66,71,82,12,63,0,0,0,12,66,71,82,65,0,0,0,12,82,71,66,36,1,0,0,82,66,65,64,38,1,0,0,66,82,65,64,35,1,0,0,64,82,66,65,37,1,0,0,64,66,82,65,28,0,0,0,82,71,66,65,40,1,0,0,82,71,66,0,30,0,0,0,66,71,82,65,42,1,0,0,66,71,82,0,29,0,0,0,65,66,71,82,41,1,0,0,0,66,71,82,27,0,0,0,65,82,71,66,39,1,0,0,0,82,71,66,2,0,0,0,82,71,66,24,3,0,0,0,66,71,82,24,7,0,0,0,52,49,49,80,4,0,0,0,52,50,50,80,13,0,0,0,52,50,50,80,33,0,0,0,52,52,48,80,34,0,0,0,52,52,48,80,5,0,0,0,52,52,52,80,14,0,0,0,52,52,52,80,9,0,0,0,66,49,87,48,10,0,0,0,66,48,87,49,19,0,0,0,66,71,82,8,22,0,0,0,82,71,66,8,20,0,0,0,66,71,82,4,23,0,0,0,82,71,66,4,24,0,0,0,66,52,66,89,21,0,0,0,82,52,66,89,42,0,0,0,82,71,66,48,41,0,0,0,48,82,71,66,68,0,0,0,66,71,82,48,67,0,0,0,48,66,71,82,32,0,0,0,89,49,0,16,31,0,0,0,16,0,49,89,72,0,0,0,89,51,11,10,71,0,0,0,10,11,51,89,74,0,0,0,89,51,10,10,73,0,0,0,10,10,51,89,78,0,0,0,89,51,0,10,77,0,0,0,10,0,51,89,46,1,0,0,89,51,11,12,45,1,0,0,12,11,51,89,50,1,0,0,89,51,10,12,49,1,0,0,12,10,51,89,54,1,0,0,89,51,0,12,53,1,0,0,12,0,51,89,48,1,0,0,89,51,11,14,47,1,0,0,14,11,51,89,52,1,0,0,89,51,10,14,51,1,0,0,14,10,51,89,56,1,0,0,89,51,0,14,55,1,0,0,14,0,51,89,54,0,0,0,89,51,11,16,55,0,0,0,16,11,51,89,56,0,0,0,89,51,10,16,57,0,0,0,16,10,51,89,58,0,0,0,89,51,0,16,59,0,0,0,16,0,51,89,35,0,0,0,89,52,11,8,44,1,0,0,89,52,10,8,43,1,0,0,89,52,0,8,66,0,0,0,89,50,0,8,92,0,0,0,89,52,11,9,91,0,0,0,9,11,52,89,94,0,0,0,89,52,10,9,93,0,0,0,9,10,52,89,96,0,0,0,89,52,0,9,95,0,0,0,9,0,52,89,98,0,0,0,89,52,11,10,97,0,0,0,10,11,52,89,100,0,0,0,89,52,10,10,99,0,0,0,10,10,52,89,102,0,0,0,89,52,0,10,101,0,0,0,10,0,52,89,104,0,0,0,89,52,11,16,103,0,0,0,16,11,52,89,106,0,0,0,89,52,10,16,105,0,0,0,16,10,52,89,108,0,0,0,89,52,0,16,107,0,0,0,16,0,52,89,82,0,0,0,71,51,0,8,84,0,0,0,71,51,0,9,83,0,0,0,9,0,51,71,86,0,0,0,71,51,0,10,85,0,0,0,10,0,51,71,58,1,0,0,71,51,0,12,57,1,0,0,12,0,51,71,60,1,0,0,71,51,0,14,59,1,0,0,14,0,51,71,88,0,0,0,71,51,0,16,87,0,0,0,16,0,51,71,110,0,0,0,88,89,90,36,111,0,0,0,36,90,89,88,65,1,0,0,186,66,71,8,69,1,0,0,186,66,71,16,70,1,0,0,16,71,66,186,66,1,0,0,186,82,71,8,71,1,0,0,186,82,71,16,72,1,0,0,16,71,82,186,67,1,0,0,186,71,66,8,73,1,0,0,186,71,66,16,74,1,0,0,16,66,71,186,68,1,0,0,186,71,82,8,75,1,0,0,186,71,82,16,76,1,0,0,16,82,71,186,0,0,0,0,82,52,50,48,7,0,0,0,82,52,49,49,17,0,0,0,50,118,117,121,17,0,0,0,50,86,117,121,17,0,0,0,65,86,85,73,17,0,0,0,98,120,121,118,1,0,0,0,121,117,118,50,1,0,0,0,121,117,118,115,1,0,0,0,68,86,79,79,46,0,0,0,76,53,53,53,44,0,0,0,76,53,54,53,43,0,0,0,66,53,54,53,3,0,0,0,50,52,66,71,3,0,0,0,98,120,98,103,30,0,0,0,66,71,82,65,28,0,0,0,82,71,66,65,2,0,0,0,98,120,114,103,29,0,0,0,65,66,71,82,31,0,0,0,98,49,54,103,41,0,0,0,98,52,56,114,44,0,0,0,3,0,0,0,5,0,0,0,89,86,50,52,1,0,0,0,89,86,89,85,255,255,255,255,0,0,0,0,120,131,37,0,88,65,37,0,0,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,40,159,39,0,112,88,37,0,80,251,35,0,32,4,35,0,24,61,34,0,200,154,33,0,216,30,33,0,56,180,32,0,40,88,32,0,16,64,40,0,96,229,39,0,88,124,39,0,104,41,39,0,104,226,38,0,128,156,38,0,216,96,38,0,184,42,38,0,224,248,37,0,8,206,37,0,32,169,37,0,0,0,0,0,0,0,0,0,224,223,37,0,88,159,39,0,1,0,0,0,58,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,124,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,3,0,0,0,0,0,0,0,0,0,0,232,0,0,0,120,9,0,0,30,0,0,0,0,0,0,0,8,224,37,0,120,159,39,0,1,0,0,0,1,48,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,7,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,224,37,0,144,159,39,0,1,0,0,0,0,48,1,0,96,0,0,0,0,0,0,0,0,0,0,0,64,102,40,0,32,100,40,0,0,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,176,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,7,0,0,0,0,0,0,242,2,0,0,0,0,0,0,240,9,0,0,0,0,0,0,0,0,0,0,112,224,37,0,168,159,39,0,1,0,0,0,0,48,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,7,0,0,0,0,0,0,0,0,0,0,200,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,71,32,0,112,195,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,172,2,0,0,18,6,0,0,60,1,0,0,112,3,0,0,208,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,225,37,0,192,159,39,0,0,0,0,0,134,0,0,0,0,0,0,0,0,0,0,0,72,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,11,0,0,0,0,0,0,194,2,0,0,0,0,0,0,12,7,0,0,0,0,0,0,0,0,0,0,128,225,37,0,224,159,39,0,0,0,0,0,134,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,5,0,0,0,0,0,0,0,0,0,0,198,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,89,37,0,40,252,35,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0,168,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,11,0,0,0,0,0,0,194,2,0,0,0,0,0,0,12,7,0,0,0,0,0,0,0,0,0,0,32,89,37,0,72,252,35,0,0,0,0,0,146,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,5,0,0,0,0,0,0,0,0,0,0,198,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,1,255,16,226,37,0,32,160,39,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,80,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,7,0,0,0,0,0,0,50,3,0,0,0,0,0,0,100,8,0,0,0,0,0,0,0,0,0,0,72,226,37,0,72,160,39,0,0,0,0,0,56,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,236,5,0,0,0,0,0,0,0,0,0,0,147,101,94,255,255,255,223,208,171,0,0,0,0,0,0,0,255,255,255,255,255,204,255,255,153,255,255,102,255,255,51,255,255,0,255,204,255,255,204,204,255,204,153,255,204,102,255,204,51,255,204,0,255,153,255,255,153,204,255,153,153,255,153,102,255,153,51,255,153,0,255,102,255,255,102,204,255,102,153,255,102,102,255,102,51,255,102,0,255,51,255,255,51,204,255,51,153,255,51,102,255,51,51,255,51,0,255,0,255,255,0,204,255,0,153,255,0,102,255,0,51,255,0,0,204,255,255,204,255,204,204,255,153,204,255,102,204,255,51,204,255,0,204,204,255,204,204,204,204,204,153,204,204,102,204,204,51,204,204,0,204,153,255,204,153,204,204,153,153,204,153,102,204,153,51,204,153,0,204,102,255,204,102,204,204,102,153,204,102,102,204,102,51,204,102,0,204,51,255,204,51,204,204,51,153,204,51,102,204,51,51,204,51,0,204,0,255,204,0,204,204,0,153,204,0,102,204,0,51,204,0,0,153,255,255,153,255,204,153,255,153,153,255,102,153,255,51,153,255,0,153,204,255,153,204,204,153,204,153,153,204,102,153,204,51,153,204,0,153,153,255,153,153,204,153,153,153,153,153,102,153,153,51,153,153,0,153,102,255,153,102,204,153,102,153,153,102,102,153,102,51,153,102,0,153,51,255,153,51,204,153,51,153,153,51,102,153,51,51,153,51,0,153,0,255,153,0,204,153,0,153,153,0,102,153,0,51,153,0,0,102,255,255,102,255,204,102,255,153,102,255,102,102,255,51,102,255,0,102,204,255,102,204,204,102,204,153,102,204,102,102,204,51,102,204,0,102,153,255,102,153,204,102,153,153,102,153,102,102,153,51,102,153,0,102,102,255,102,102,204,102,102,153,102,102,102,102,102,51,102,102,0,102,51,255,102,51,204,102,51,153,102,51,102,102,51,51,102,51,0,102,0,255,102,0,204,102,0,153,102,0,102,102,0,51,102,0,0,51,255,255,51,255,204,51,255,153,51,255,102,51,255,51,51,255,0,51,204,255,51,204,204,51,204,153,51,204,102,51,204,51,51,204,0,51,153,255,51,153,204,51,153,153,51,153,102,51,153,51,51,153,0,51,102,255,51,102,204,51,102,153,51,102,102,51,102,51,51,102,0,51,51,255,51,51,204,51,51,153,51,51,102,51,51,51,51,51,0,51,0,255,51,0,204,51,0,153,51,0,102,51,0,51,51,0,0,0,255,255,0,255,204,0,255,153,0,255,102,0,255,51,0,255,0,0,204,255,0,204,204,0,204,153,0,204,102,0,204,51,0,204,0,0,153,255,0,153,204,0,153,153,0,153,102,0,153,51,0,153,0,0,102,255,0,102,204,0,102,153,0,102,102,0,102,51,0,102,0,0,51,255,0,51,204,0,51,153,0,51,102,0,51,51,0,51,0,0,0,255,0,0,204,0,0,153,0,0,102,0,0,51,238,0,0,221,0,0,187,0,0,170,0,0,136,0,0,119,0,0,85,0,0,68,0,0,34,0,0,17,0,0,0,238,0,0,221,0,0,187,0,0,170,0,0,136,0,0,119,0,0,85,0,0,68,0,0,34,0,0,17,0,0,0,238,0,0,221,0,0,187,0,0,170,0,0,136,0,0,119,0,0,85,0,0,68,0,0,34,0,0,17,238,238,238,221,221,221,187,187,187,170,170,170,136,136,136,119,119,119,85,85,85,68,68,68,34,34,34,17,17,17,0,0,0,255,251,255,239,217,187,232,201,177,147,101,94,252,222,232,157,136,145,255,255,255,255,255,255,255,255,255,71,72,55,122,94,85,223,208,171,255,251,249,232,202,197,138,124,119,0,0,0,232,226,37,0,128,160,39,0,0,0,0,0,61,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,11,0,0,0,0,0,0,0,0,0,0,2,0,0,0,60,6,0,0,70,1,0,0,0,0,0,0,240,226,37,0,144,160,39,0,0,0,0,0,59,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,6,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,227,37,0,216,160,39,0,1,0,0,0,19,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,251,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,4,0,0,0,0,0,0,0,0,0,0,2,3,0,0,76,9,0,0,0,0,0,0,0,0,0,0,72,72,32,0,152,195,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,38,3,0,0,18,4,0,0,44,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,227,37,0,240,160,39,0,1,0,0,0,24,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,3,0,0,0,0,0,0,0,0,0,0,146,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,72,32,0,192,195,37,0,0,1,0,0,184,72,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,1,0,0,10,9,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,73,32,0,232,195,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,232,6,0,0,128,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,227,37,0,8,161,39,0,0,0,0,0,105,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,187,38,0,144,122,38,0,0,0,0,0,120,65,38,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,5,0,176,103,40,0,64,165,10,0,0,0,0,0,128,0,0,0,20,5,0,0,70,3,0,0,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,3,3,0,4,4,4,4,1,1,1,1,1,1,2,0,1,8,9,2,3,10,11,16,17,24,25,18,19,26,27,4,5,12,20,13,6,7,14,21,28,29,22,15,23,30,31,32,33,40,48,41,34,35,42,49,56,57,50,43,36,37,44,51,58,59,52,45,38,39,46,53,60,61,54,47,55,62,63,64,230,37,0,192,161,39,0,0,0,0,0,149,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,0,0,0,0,0,0,0,0,0,0,0,98,2,0,0,174,9,0,0,0,0,0,0,0,0,0,0,0,6,3,5,0,1,1,1,1,2,0,0,0,0,0,0,240,228,37,0,144,161,39,0,0,0,0,0,149,0,0,0,0,32,0,0,0,0,0,0,104,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,168,10,0,0,0,0,0,208,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,7,0,0,0,0,0,0,94,2,0,0,0,0,0,0,206,11,0,0,0,0,0,0,0,0,0,0,0,8,1,9,16,24,17,25,2,10,3,11,18,26,19,27,32,40,33,34,41,48,56,49,42,35,43,50,57,58,51,59,4,12,5,6,13,20,28,21,14,7,15,22,29,36,44,37,30,23,31,38,45,52,60,53,46,39,47,54,61,62,55,63,88,90,37,0,176,161,39,0,0,0,0,0,149,0,0,0,0,16,0,64,0,0,0,0,16,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,171,10,0,12,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,0,0,0,0,16,3,0,0,0,0,0,0,84,8,0,0,0,0,0,0,0,0,0,0,168,230,37,0,8,162,39,0,0,0,0,0,149,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,124,2,0,0,70,9,0,0,0,0,0,0,0,0,0,0,4,40,77,112,0,0,0,0,184,229,37,0,176,161,39,0,0,0,0,0,149,0,0,0,0,16,0,64,0,0,0,0,120,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,171,10,0,12,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,0,0,0,0,16,3,0,0,0,0,0,0,84,8,0,0,0,0,0,0,0,0,0,0,4,40,76,5,41,6,10,0,160,62,34,0,64,156,33,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,232,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,5,0,0,0,0,0,0,164,1,0,0,0,0,0,0,58,3,0,0,0,0,0,0,0,0,0,0,176,5,35,0,168,62,34,0,0,0,0,0,63,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,63,0,0,16,63,0,0,216,62,248,255,161,62,21,0,115,62,33,64,54,62,8,176,8,62,11,8,205,61,42,198,153,61,130,169,102,61,51,51,51,63,72,225,250,62,178,157,175,62,198,220,117,62,139,26,44,62,245,241,240,61,55,169,168,61,79,32,108,61,60,74,37,61,90,104,231,60,205,204,12,63,72,225,154,62,53,94,42,62,127,103,187,61,188,36,78,61,68,195,226,60,22,110,121,60,232,46,9,60,138,229,150,59,176,0,38,59,0,0,0,63,0,0,128,62,0,0,0,62,0,0,128,61,0,0,0,61,0,0,128,60,0,0,0,60,0,0,128,59,0,0,0,59,0,0,128,58,0,0,0,58,0,0,128,57,0,0,0,57,0,0,128,56,0,0,0,56,0,0,128,55,128,128,8,136,34,170,85,0,3,3,2,2,1,1,0,0,0,4,0,2,0,1,0,0,240,232,37,0,176,162,39,0,0,0,0,0,62,0,0,0,0,16,0,64,0,0,0,0,144,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,190,10,0,0,0,0,0,48,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,5,0,0,0,0,0,0,224,0,0,0,0,0,0,0,114,4,0,0,0,0,0,0,0,0,0,0,40,233,37,0,232,162,39,0,0,0,0,0,62,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,8,0,0,0,0,0,0,0,0,0,0,140,0,0,0,68,8,0,0,0,0,0,0,0,0,0,0,48,75,32,0,16,197,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,6,5,0,0,146,6,0,0,118,1,0,0,96,3,0,0,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,75,32,0,216,197,37,0,0,0,0,0,240,75,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,122,5,0,0,54,10,0,0,82,3,0,0,246,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,248,255,34,0,152,56,34,0,3,0,0,0,83,74,104,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,11,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,3,0,0,0,0,0,0,0,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,96,233,37,0,16,163,39,0,0,0,0,0,142,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,234,37,0,32,163,39,0,3,0,0,0,6,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,39,11,0,0,0,0,0,16,4,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,2,0,0,0,0,0,0,0,0,0,0,102,1,0,0,50,2,0,0,0,0,0,0,0,0,0,0,136,90,37,0,120,254,35,0,0,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,176,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,5,0,0,0,0,0,0,164,1,0,0,0,0,0,0,58,3,0,0,0,0,0,0,0,0,0,0,160,90,37,0,160,254,35,0,0,0,0,0,66,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,232,37,0,48,162,39,0,0,0,0,0,65,0,0,0,0,0,0,0,0,0,0,0,128,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,5,0,0,0,0,0,0,164,1,0,0,0,0,0,0,58,3,0,0,0,0,0,0,0,0,0,0,152,232,37,0,96,162,39,0,0,0,0,0,65,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,234,37,0,80,163,39,0,0,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,184,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,5,0,0,0,0,0,0,48,0,0,0,0,0,0,0,152,7,0,0,0,0,0,0,0,0,0,0,112,234,37,0,144,163,39,0,0,0,0,0,110,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,22,40,0,24,17,40,0,1,0,0,0,17,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,98,35,0,96,78,35,0,0,0,0,0,24,61,35,0,5,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,224,32,0,192,216,32,0,1,0,0,0,5,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,98,35,0,8,79,35,0,0,1,0,0,120,61,35,0,0,0,0,0,56,152,4,0,0,0,0,0,5,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,224,32,0,192,216,32,0,1,0,0,0,5,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,150,36,0,232,122,36,0,0,0,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,56,40,0,48,44,40,0,1,0,0,0,10,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,151,36,0,32,123,36,0,0,1,0,0,0,0,0,0,0,0,0,0,104,152,4,0,0,0,0,0,10,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,56,40,0,48,44,40,0,1,0,0,0,10,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,209,36,0,112,179,36,0,0,0,0,0,0,0,0,0,11,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,36,32,0,136,30,32,0,1,0,0,0,11,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,232,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,209,36,0,160,179,36,0,0,1,0,0,0,0,0,0,0,0,0,0,152,152,4,0,0,0,0,0,11,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,36,32,0,136,30,32,0,1,0,0,0,11,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,48,36,0,120,248,35,0,0,0,0,0,0,0,0,0,14,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,61,32,0,48,54,32,0,1,0,0,0,14,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,232,93,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,48,36,0,32,250,35,0,0,1,0,0,0,0,0,0,0,0,0,0,200,152,4,0,0,0,0,0,14,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,61,32,0,48,54,32,0,1,0,0,0,14,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,93,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,96,36,0,144,69,36,0,0,0,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,115,32,0,64,105,32,0,1,0,0,0,15,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,248,93,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,96,36,0,216,69,36,0,0,1,0,0,0,0,0,0,0,0,0,0,248,152,4,0,0,0,0,0,15,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,115,32,0,64,105,32,0,1,0,0,0,15,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,93,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,161,35,0,24,141,35,0,0,0,0,0,208,117,35,0,2,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,138,32,0,48,132,32,0,1,0,0,0,2,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,56,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,162,35,0,176,141,35,0,0,1,0,0,72,118,35,0,0,0,0,0,40,153,4,0,0,0,0,0,2,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,138,32,0,48,132,32,0,1,0,0,0,2,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1316628);
/* memory initializer */ allocate([10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,208,35,0,184,183,35,0,0,0,0,0,0,0,0,0,3,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,172,32,0,128,159,32,0,1,0,0,0,3,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,72,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,209,35,0,8,184,35,0,0,1,0,0,0,0,0,0,0,0,0,0,88,153,4,0,0,0,0,0,3,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,172,32,0,128,159,32,0,1,0,0,0,3,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,62,36,0,80,36,36,0,1,0,0,0,27,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,62,36,0,80,36,36,0,1,0,0,0,27,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,85,37,0,168,29,37,0,0,0,0,0,144,251,36,0,4,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,169,36,0,176,142,36,0,1,0,0,0,4,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,112,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,86,37,0,32,30,37,0,0,1,0,0,40,252,36,0,0,0,0,0,160,95,9,0,0,0,0,0,4,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,169,36,0,176,142,36,0,1,0,0,0,4,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,252,32,0,208,244,32,0,1,0,0,0,80,83,80,32,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,252,32,0,208,244,32,0,1,0,0,0,80,83,80,32,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,6,40,0,112,156,39,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,62,33,0,208,51,33,0,1,0,0,0,8,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,216,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,8,40,0,8,158,39,0,0,1,0,0,0,0,0,0,0,0,0,0,208,95,9,0,0,0,0,0,8,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,62,33,0,208,51,33,0,1,0,0,0,8,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,120,32,0,144,31,32,0,0,0,0,0,0,0,0,0,9,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,98,33,0,40,88,33,0,1,0,0,0,9,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,48,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,122,32,0,136,32,32,0,0,1,0,0,0,0,0,0,0,0,0,0,0,96,9,0,0,0,0,0,9,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,98,33,0,40,88,33,0,1,0,0,0,9,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,144,33,0,200,127,33,0,1,0,0,0,80,83,80,24,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,80,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,144,33,0,200,127,33,0,1,0,0,0,80,83,80,24,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,178,38,0,152,116,38,0,0,0,0,0,0,0,0,0,12,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,209,33,0,120,199,33,0,1,0,0,0,12,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,179,38,0,96,117,38,0,0,1,0,0,0,0,0,0,0,0,0,0,48,96,9,0,0,0,0,0,12,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,209,33,0,120,199,33,0,1,0,0,0,12,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,12,34,0,8,254,33,0,1,0,0,0,16,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,16,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,12,34,0,8,254,33,0,1,0,0,0,16,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,64,39,0,120,248,38,0,0,0,0,0,0,0,0,0,13,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,107,34,0,40,90,34,0,1,0,0,0,13,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,65,39,0,168,249,38,0,0,1,0,0,0,0,0,0,0,0,0,0,96,96,9,0,0,0,0,0,13,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,107,34,0,40,90,34,0,1,0,0,0,13,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,172,34,0,128,153,34,0,1,0,0,0,18,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,80,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,172,34,0,128,153,34,0,1,0,0,0,18,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,219,37,0,88,179,37,0,0,0,0,0,32,149,37,0,0,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,247,34,0,168,220,34,0,1,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,219,37,0,168,179,37,0,0,1,0,0,72,149,37,0,0,0,0,0,144,96,9,0,0,0,0,0,0,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,247,34,0,168,220,34,0,1,0,0,0,0,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,90,35,0,144,73,35,0,1,0,0,0,16,80,83,80,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,200,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,90,35,0,144,73,35,0,1,0,0,0,16,80,83,80,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,60,38,0,136,5,38,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,176,35,0,208,154,35,0,1,0,0,0,1,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,60,38,0,232,5,38,0,0,1,0,0,0,0,0,0,0,0,0,0,192,96,9,0,0,0,0,0,1,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,176,35,0,208,154,35,0,1,0,0,0,1,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,210,34,0,16,195,34,0,0,0,0,0,128,178,34,0,6,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,65,37,0,224,19,37,0,1,0,0,0,6,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,192,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,210,34,0,120,195,34,0,0,1,0,0,232,178,34,0,0,0,0,0,32,24,12,0,0,0,0,0,6,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,65,37,0,224,19,37,0,1,0,0,0,6,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,206,37,0,96,169,37,0,1,0,0,0,25,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,90,36,0,40,75,35,0,0,0,0,0,0,0,0,0,23,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,157,38,0,184,97,38,0,1,0,0,0,23,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,94,36,0,64,77,35,0,0,1,0,0,0,0,0,0,0,0,0,0,104,181,22,0,0,0,0,0,23,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,157,38,0,184,97,38,0,1,0,0,0,23,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,97,32,0,56,210,37,0,0,0,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,231,39,0,144,125,39,0,1,0,0,0,22,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,88,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,112,32,0,152,216,37,0,0,1,0,0,0,0,0,0,0,0,0,0,152,181,22,0,0,0,0,0,22,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,231,39,0,144,125,39,0,1,0,0,0,22,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,71,33,0,72,217,32,0,0,0,0,0,0,0,0,0,21,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,33,33,0,24,182,32,0,1,0,0,0,21,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,72,33,0,48,218,32,0,0,1,0,0,0,0,0,0,0,0,0,0,248,181,22,0,0,0,0,0,21,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,33,33,0,24,182,32,0,1,0,0,0,21,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,125,34,0,88,200,33,0,0,0,0,0,0,0,0,0,20,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,0,192,6,35,0,1,0,0,0,20,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,40,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,127,34,0,120,201,33,0,0,1,0,0,0,0,0,0,0,0,0,0,40,182,22,0,0,0,0,0,20,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,0,192,6,35,0,1,0,0,0,20,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,240,37,0,232,164,39,0,1,0,0,0,19,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,5,0,0,0,0,0,0,0,0,0,0,172,0,0,0,166,8,0,0,0,0,0,0,0,0,0,0,8,241,37,0,32,165,39,0,1,0,0,0,24,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,45,35,0,32,2,35,0,0,0,0,0,112,226,34,0,7,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,240,37,0,184,164,39,0,1,0,0,0,7,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,102,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,46,35,0,32,3,35,0,0,1,0,0,232,226,34,0,0,0,0,0,192,220,30,0,0,0,0,0,7,0,1,0,12,0,0,0,0,0,0,0,120,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,240,37,0,184,164,39,0,1,0,0,0,7,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,181,32,0,48,89,32,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,152,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,5,0,0,0,0,0,0,164,1,0,0,0,0,0,0,58,3,0,0,0,0,0,0,0,0,0,0,104,156,33,0,64,32,33,0,0,0,0,0,64,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,241,37,0,144,165,39,0,0,0,0,0,67,0,0,0,0,0,0,0,0,0,0,0,8,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,142,0,0,0,0,0,0,0,190,11,0,0,0,0,0,0,0,0,0,0,88,181,32,0,80,89,32,0,0,0,0,0,67,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,242,37,0,200,165,39,0,0,0,0,0,86,70,65,80,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,52,2,0,0,40,2,0,0,0,0,0,0,0,0,0,0,160,112,32,0,216,216,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,220,4,0,0,42,3,0,0,54,3,0,0,200,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,92,37,0,128,0,36,0,1,0,0,0,65,70,65,80,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,3,0,0,0,0,0,0,0,0,0,0,56,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,255,255,255,255,160,123,32,0,128,33,32,0,96,74,33,0,160,123,32,0,83,85,80,79,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,240,106,11,0,0,0,0,0,24,0,0,0,24,10,0,0,128,1,0,0,102,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,125,32,0,8,0,0,0,104,225,37,0,214,2,0,0,238,3,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,64,1,185,1,224,1,114,3,192,3,0,0,0,0,0,0,96,121,32,0,152,219,37,0,80,96,36,0,96,121,32,0,31,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,94,3,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,123,32,0,168,223,37,0,0,1,0,0,192,96,36,0,48,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,248,1,0,0,4,3,0,0,126,0,0,0,106,0,0,0,0,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,80,1,0,0,0,0,0,40,80,1,0,1,0,0,0,1,80,1,0,3,0,0,0,1,0,1,0,4,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,1,0,0,0,0,0,0,63,6,0,0,0,0,0,0,24,226,37,0,4,0,0,0,0,0,0,0,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,10,12,14,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,226,37,0,8,0,0,0,0,0,0,0,230,2,0,0,0,0,0,0,192,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,144,126,32,0,6,0,0,0,0,0,0,0,50,2,0,0,28,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,216,98,36,0,5,0,0,0,0,0,0,0,50,2,0,0,28,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,32,80,35,0,35,0,0,0,0,0,0,0,156,1,0,0,28,1,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,184,225,37,0,6,0,0,0,0,0,0,0,50,2,0,0,28,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,160,129,32,0,24,227,37,0,24,100,36,0,72,81,35,0,12,80,1,0,31,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,208,209,11,0,0,0,0,0,24,0,0,0,24,10,0,0,128,1,0,0,102,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,130,32,0,80,227,37,0,0,35,0,0,120,130,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,142,10,0,0,54,3,0,0,4,0,0,0,152,3,0,0,114,0,0,0,52,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,11,0,0,220,11,0,176,215,11,0,240,215,11,0,200,130,32,0,160,227,37,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,82,4,0,0,30,7,0,0,138,2,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,13,38,0,168,168,39,0,0,0,0,0,85,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,6,0,0,0,0,0,0,0,0,0,0,166,0,0,0,186,2,0,0,0,0,0,0,0,0,0,0,169,0,0,0,86,80,57,48,14,0,0,0,82,71,66,15,14,0,0,0,66,71,82,15,14,0,0,0,82,71,66,16,14,0,0,0,66,71,82,16,14,0,0,0,15,66,71,82,14,0,0,0,15,82,71,66,14,0,0,0,16,66,71,82,14,0,0,0,16,82,71,66,14,0,0,0,82,71,66,12,14,0,0,0,66,71,82,12,14,0,0,0,12,66,71,82,14,0,0,0,12,82,71,66,14,0,0,0,82,71,66,65,14,0,0,0,82,71,66,0,14,0,0,0,66,71,82,65,14,0,0,0,66,71,82,0,14,0,0,0,65,66,71,82,14,0,0,0,0,66,71,82,14,0,0,0,65,82,71,66,14,0,0,0,0,82,71,66,14,0,0,0,82,71,66,24,14,0,0,0,66,71,82,24,14,0,0,0,52,49,49,80,14,0,0,0,52,50,50,80,14,0,0,0,52,50,50,80,14,0,0,0,52,52,48,80,14,0,0,0,52,52,48,80,14,0,0,0,52,52,52,80,14,0,0,0,52,52,52,80,14,0,0,0,66,49,87,48,14,0,0,0,66,48,87,49,14,0,0,0,66,71,82,8,14,0,0,0,82,71,66,8,14,0,0,0,66,71,82,4,14,0,0,0,82,71,66,4,14,0,0,0,66,52,66,89,14,0,0,0,82,52,66,89,14,0,0,0,66,71,82,48,14,0,0,0,82,71,66,48,14,0,0,0,48,66,71,82,14,0,0,0,48,82,71,66,14,0,0,0,66,82,65,64,14,0,0,0,82,66,65,64,14,0,0,0,64,66,82,65,14,0,0,0,64,82,66,65,14,0,0,0,89,51,11,10,14,0,0,0,10,11,51,89,14,0,0,0,89,51,10,10,14,0,0,0,10,10,51,89,14,0,0,0,89,51,0,10,14,0,0,0,10,0,51,89,14,0,0,0,89,51,11,12,14,0,0,0,12,11,51,89,14,0,0,0,89,51,10,12,14,0,0,0,12,10,51,89,14,0,0,0,89,51,0,12,14,0,0,0,12,0,51,89,14,0,0,0,89,51,11,14,14,0,0,0,14,11,51,89,14,0,0,0,89,51,10,14,14,0,0,0,14,10,51,89,14,0,0,0,89,51,0,14,14,0,0,0,14,0,51,89,14,0,0,0,89,49,0,16,14,0,0,0,16,0,49,89,14,0,0,0,89,51,11,16,14,0,0,0,16,11,51,89,14,0,0,0,89,51,10,16,14,0,0,0,16,10,51,89,14,0,0,0,89,51,0,16,14,0,0,0,16,0,51,89,14,0,0,0,89,52,11,8,14,0,0,0,89,52,10,8,14,0,0,0,89,52,0,8,14,0,0,0,89,50,0,8,14,0,0,0,89,49,0,9,14,0,0,0,9,0,49,89,14,0,0,0,89,52,11,9,14,0,0,0,9,11,52,89,14,0,0,0,89,52,10,9,14,0,0,0,9,10,52,89,14,0,0,0,89,52,0,9,14,0,0,0,9,0,52,89,14,0,0,0,89,49,0,10,14,0,0,0,10,0,49,89,14,0,0,0,89,52,11,10,14,0,0,0,10,11,52,89,14,0,0,0,89,52,10,10,14,0,0,0,10,10,52,89,14,0,0,0,89,52,0,10,14,0,0,0,10,0,52,89,14,0,0,0,89,49,0,16,14,0,0,0,16,0,49,89,14,0,0,0,89,52,11,16,14,0,0,0,16,11,52,89,14,0,0,0,89,52,10,16,14,0,0,0,16,10,52,89,14,0,0,0,89,52,0,16,14,0,0,0,16,0,52,89,14,0,0,0,71,51,0,8,14,0,0,0,71,51,0,9,14,0,0,0,9,0,51,71,14,0,0,0,71,51,0,10,14,0,0,0,10,0,51,71,14,0,0,0,71,51,0,12,14,0,0,0,12,0,51,71,14,0,0,0,71,51,0,14,14,0,0,0,14,0,51,71,14,0,0,0,71,51,0,16,14,0,0,0,16,0,51,71,14,0,0,0,88,89,90,36,14,0,0,0,36,90,89,88,14,0,0,0,186,66,71,8,14,0,0,0,186,66,71,16,14,0,0,0,16,71,66,186,14,0,0,0,186,82,71,8,14,0,0,0,186,82,71,16,14,0,0,0,16,71,82,186,14,0,0,0,186,71,66,8,14,0,0,0,186,71,66,16,14,0,0,0,16,66,71,186,14,0,0,0,186,71,82,8,14,0,0,0,186,71,82,16,14,0,0,0,16,82,71,186,0,0,0,0,0,0,0,0,2,112,1,0,85,84,70,56,4,112,1,0,83,83,65,0,0,112,1,0,68,86,68,83,1,112,1,0,68,86,66,83,7,112,1,0,68,86,66,84,0,0,0,0,0,0,0,0,72,133,32,0,208,228,37,0,96,101,36,0,72,133,32,0,0,80,1,0,13,0,0,0,0,0,0,0,64,4,0,0,160,102,20,0,0,0,0,0,0,0,0,0,208,14,0,0,214,7,0,0,158,1,0,0,242,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,175,39,0,80,234,39,0,32,134,37,0,184,37,36,0,80,36,35,0,184,37,36,0,56,91,34,0,248,179,33,0,160,52,33,0,208,199,32,0,64,106,32,0,40,82,40,0,56,247,39,0,152,140,39,0,120,53,39,0,248,238,38,0,248,167,38,0,184,107,38,0,48,53,38,0,128,0,38,0,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,0,0,0,0,1,0,0,0,100,117,98,0,0,0,0,0,0,0,0,0,2,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,4,0,0,0,99,111,109,109,101,110,116,0,0,0,0,0,8,0,0,0,108,121,114,105,99,115,0,0,0,0,0,0,16,0,0,0,107,97,114,97,111,107,101,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,139,32,0,48,231,37,0,0,0,0,4,16,139,32,0,160,102,20,0,0,0,0,0,0,0,0,0,0,0,0,0,208,14,0,0,236,10,0,0,22,9,0,0,174,3,0,0,52,9,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,112,1,0,85,84,70,56,0,0,0,0,0,0,0,0,0,97,20,0,192,102,20,0,240,100,20,0,128,128,21,0,200,117,21,0,48,221,11,0,144,102,20,0,0,0,0,0,20,0,1,0,32,68,70,80,21,0,1,0,80,70,68,32,22,0,1,0,64,68,70,80,23,0,1,0,80,70,68,64,1,0,1,0,16,68,83,80,0,0,1,0,80,83,68,16,13,0,1,0,24,68,83,80,12,0,1,0,80,83,68,24,9,0,1,0,32,68,83,80,8,0,1,0,80,83,68,32,4,0,1,0,80,83,68,8,3,0,1,0,16,68,85,80,2,0,1,0,80,85,68,16,15,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1326884);
/* memory initializer */ allocate([24,68,85,80,14,0,1,0,80,85,68,24,11,0,1,0,32,68,85,80,10,0,1,0,80,85,68,32,5,0,1,0,80,85,68,8,27,0,1,0,80,83,80,8,16,80,83,80,16,80,83,80,18,0,1,0,80,83,80,16,80,83,80,24,80,83,80,24,80,83,80,32,80,83,80,32,0,0,0,0,0,0,0,0,160,140,32,0,64,231,37,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,161,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,140,32,0,80,231,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,194,6,0,0,106,2,0,0,88,2,0,0,190,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,142,32,0,160,232,37,0,0,1,0,0,208,103,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,4,0,0,42,2,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,14,38,0,192,168,39,0,1,0,0,0,34,80,1,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,10,0,0,0,0,0,0,250,1,0,0,0,0,0,0,198,4,0,0,0,0,0,0,0,0,0,0,64,14,38,0,216,168,39,0,1,0,0,0,34,80,1,0,2,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,6,0,0,0,0,0,0,0,0,0,0,136,1,0,0,64,2,0,0,0,0,0,0,0,0,0,0,62,12,222,20,214,26,112,30,121,33,225,35,16,38,207,39,135,41,53,43,170,44,250,45,84,47,225,48,125,50,244,51,106,53,203,54,16,56,124,57,13,59,117,60,208,61,29,63,129,64,164,65,194,66,249,67,15,69,28,70,62,71,88,72,76,73,134,74,181,75,184,76,209,77,237,78,20,80,77,81,170,82,217,83,34,85,121,86,181,87,228,88,27,90,54,91,84,92,118,93,163,94,201,95,243,96,19,98,70,99,130,100,8,102,129,103,15,105,208,106,229,108,47,111,242,114,123,122,0,0,0,0,197,229,88,191,220,243,56,63,241,42,195,191,4,3,232,190,81,47,192,62,157,99,188,63,161,186,253,191,49,178,152,191,92,59,21,191,14,22,142,189,132,43,200,62,233,43,104,63,58,62,190,63,186,45,14,64,227,225,24,192,183,67,231,191,164,140,180,191,247,230,137,191,25,172,76,191,161,73,14,191,171,179,170,190,182,160,7,190,55,169,104,61,61,127,130,62,224,103,244,62,118,26,61,63,210,171,133,63,249,157,178,63,252,169,231,63,127,20,25,64,167,235,24,192,31,134,254,191,2,46,224,191,96,59,200,191,9,52,178,191,32,181,155,191,117,2,134,191,119,248,99,191,19,186,67,191,188,60,37,191,56,163,6,191,85,217,207,190,37,31,155,190,250,184,86,190,229,236,253,189,232,74,68,189,230,33,211,60,14,19,205,61,34,227,49,62,49,97,132,62,91,95,180,62,85,250,233,62,135,167,19,63,233,71,51,63,125,177,87,63,160,51,129,63,51,80,151,63,12,62,173,63,67,27,196,63,135,219,221,63,50,114,252,63,201,117,25,64,35,215,36,192,84,171,3,192,201,1,243,191,125,234,226,191,2,72,213,191,250,127,201,191,28,234,191,191,196,64,183,191,203,191,174,191,165,105,166,191,39,50,157,191,117,85,148,191,193,202,139,191,203,188,129,191,204,151,107,191,3,38,84,191,20,204,60,191,10,16,37,191,201,32,15,191,129,175,248,190,201,114,210,190,251,34,177,190,185,250,145,190,42,200,111,190,34,140,63,190,70,182,19,190,152,191,226,189,137,124,151,189,253,192,21,189,28,40,240,187,29,204,166,60,252,54,68,61,226,0,154,61,167,232,200,61,149,239,249,61,207,102,21,62,94,128,45,62,109,198,73,62,26,166,102,62,104,233,130,62,250,242,146,62,7,177,163,62,194,133,180,62,209,30,199,62,170,242,221,62,68,50,244,62,79,62,5,63,254,127,16,63,103,185,28,63,233,40,43,63,61,242,59,63,144,159,77,63,22,223,96,63,29,229,116,63,30,21,133,63,109,143,144,63,135,77,156,63,118,109,167,63,119,132,179,63,48,186,192,63,7,183,207,63,38,225,226,63,28,183,248,63,205,149,18,64,0,0,0,0,51,210,52,219,26,225,111,229,196,232,143,235,9,238,57,240,77,242,42,244,220,245,134,247,18,249,153,250,8,252,108,253,183,254,255,255,81,1,184,2,61,4,232,5,170,7,129,9,152,11,241,13,218,16,159,20,222,25,218,31,92,39,175,50,2,2,2,2,2,2,2,2,2,3,3,4,4,5,6,6,7,8,9,10,12,14,15,0,56,143,32,0,192,232,37,0,0,0,0,0,224,103,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,0,0,0,194,7,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,15,38,0,232,168,39,0,0,0,0,0,147,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,240,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,8,0,0,0,0,0,0,0,0,0,0,222,0,0,0,230,4,0,0,0,0,0,0,0,0,0,0,72,143,32,0,208,232,37,0,0,0,0,0,72,143,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,168,5,0,0,70,0,0,0,100,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,0,0,0,65,8,66,8,71,8,82,8,0,0,0,0,0,0,0,0,27,0,0,0,65,8,82,8,71,8,66,8,0,0,0,0,0,0,0,0,3,0,0,0,66,8,71,8,82,8,0,0,0,0,0,0,0,0,0,0,30,0,0,0,66,8,71,8,82,8,65,8,0,0,0,0,0,0,0,0,2,0,0,0,82,8,71,8,66,8,0,0,0,0,0,0,0,0,0,0,63,0,0,0,70,4,82,4,71,4,66,4,0,0,0,0,0,0,0,0,41,0,0,0,82,8,114,8,71,8,103,8,66,8,98,8,0,0,0,0,41,0,0,0,82,16,71,16,66,16,0,0,0,0,0,0,0,0,0,0,42,0,0,0,114,8,82,8,103,8,71,8,98,8,66,8,0,0,0,0,45,0,0,0,70,1,82,5,71,5,66,5,0,0,0,0,0,0,0,0,43,0,0,0,82,5,71,6,66,5,0,0,0,0,0,0,0,0,0,0,28,0,0,0,82,8,71,8,66,8,65,8,0,0,0,0,0,0,0,0,11,0,0,0,80,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,10,4,1,2,1,1,2,1,1,16,0,0,0,17,0,0,0,6,14,43,52,4,1,1,10,4,1,2,1,1,2,1,2,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,24,144,32,0,8,233,37,0,40,104,36,0,24,144,32,0,0,0,1,0,2,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,78,5,0,0,200,2,0,0,40,6,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,150,32,0,200,235,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,254,0,0,0,42,1,0,0,6,0,0,0,6,8,0,0,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,1,3,2,2,1,0,0,0,13,0,0,0,0,0,0,0,6,14,43,52,4,1,1,1,1,3,2,2,2,0,0,0,13,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,112,83,35,0,16,133,34,0,40,104,36,0,0,0,0,0,0,0,1,0,2,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,0,0,0,78,5,0,0,200,2,0,0,40,6,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,4,1,1,3,4,1,2,2,1,1,17,0,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,1,4,1,2,2,1,2,1,1,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,3,4,1,2,2,1,3,3,0,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,3,4,1,2,2,1,4,2,0,14,0,0,0,2,0,0,0,6,14,43,52,4,1,1,3,4,1,2,2,1,32,2,3,14,0,0,0,13,0,0,0,6,14,43,52,4,1,1,1,4,1,2,2,2,1,2,0,13,0,0,0,25,0,0,0,6,14,43,52,4,1,1,7,4,1,2,2,3,1,1,0,14,0,0,0,89,0,0,0,6,14,43,52,4,1,1,1,4,1,2,1,127,0,0,0,13,0,0,0,14,0,0,0,6,14,43,52,4,1,1,10,4,1,2,1,1,2,1,0,15,0,0,0,14,0,0,0,6,14,43,52,4,1,1,1,4,1,2,2,113,0,0,0,13,0,0,0,100,0,0,0,6,14,43,52,4,1,1,1,4,1,2,2,3,2,0,0,14,0,0,0,100,0,0,0,6,14,43,52,4,1,1,10,4,1,2,2,1,50,0,0,14,0,0,0,28,0,0,0,6,14,43,52,4,1,1,10,4,1,2,1,1,2,2,1,16,0,0,0,128,0,0,0,6,14,43,52,4,1,1,1,4,2,2,1,0,0,0,0,13,0,0,0,0,0,1,0,6,14,43,52,4,1,1,1,4,2,2,1,127,0,0,0,13,0,0,0,0,0,1,0,6,14,43,52,4,1,1,7,4,2,2,1,126,0,0,0,13,0,0,0,1,0,1,0,6,14,43,52,4,1,1,4,4,2,2,2,3,1,1,0,15,0,0,0,7,0,1,0,6,14,43,52,4,1,1,1,4,2,2,2,3,2,1,0,15,0,0,0,3,80,1,0,6,14,43,52,4,1,1,1,4,2,2,2,3,2,5,0,15,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,3,1,4,3,6,5,7,4,7,3,7,11,9,10,9,9,9,17,10,16,10,15,10,14,10,13,10,12,10,11,10,10,10,9,10,8,10,7,10,6,10,5,10,4,10,7,11,6,11,5,11,4,11,3,11,2,11,3,12,2,12,0,0,0,0,0,0,8,151,32,0,0,236,37,0,0,0,0,0,8,151,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,122,6,0,0,182,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,94,37,0,176,2,36,0,0,0,0,0,50,67,86,77,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,4,0,0,0,0,0,0,0,0,0,0,140,1,0,0,86,0,0,0,0,0,0,0,0,0,0,0,248,15,38,0,0,169,39,0,0,0,0,0,49,67,86,77,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,4,0,0,0,0,0,0,0,0,0,0,140,1,0,0,86,0,0,0,0,0,0,0,0,0,0,0,75,4,0,0,56,18,5,0,208,26,5,0,232,13,5,0,152,9,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,4,0,0,120,249,4,0,16,2,5,0,40,245,4,0,216,240,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,155,32,0,176,237,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,236,8,0,0,152,4,0,0,46,0,0,0,0,0,0,0,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,157,32,0,248,238,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,148,8,0,0,146,5,0,0,56,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,17,38,0,120,169,39,0,0,0,0,0,166,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,6,0,0,0,0,0,0,0,0,0,0,208,2,0,0,10,6,0,0,0,0,0,0,0,0,0,0,88,129,38,0,104,183,39,0,0,0,0,0,54,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,6,0,0,0,0,0,0,0,0,0,0,224,2,0,0,232,1,0,0,0,0,0,0,0,0,0,0,96,16,38,0,72,169,39,0,0,0,0,0,47,0,0,0,0,0,0,0,0,0,0,0,80,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,11,0,0,0,0,0,0,32,2,0,0,0,0,0,0,184,5,0,0,0,0,0,0,0,0,0,0,176,16,38,0,96,169,39,0,0,0,0,0,47,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,0,0,0,0,0,0,0,0,0,0,0,170,2,0,0,26,3,0,0,0,0,0,0,0,0,0,0,72,18,38,0,184,169,39,0,0,0,0,0,168,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,111,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,9,0,0,0,0,0,0,0,0,0,0,80,0,0,0,20,1,0,0,0,0,0,0,0,0,0,0,48,20,38,0,48,170,39,0,0,0,0,0,163,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,147,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,7,0,0,0,0,0,0,0,0,0,0,126,1,0,0,66,1,0,0,0,0,0,0,0,0,0,0,208,20,38,0,120,170,39,0,0,0,0,0,46,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,7,0,0,0,0,0,0,0,0,0,0,18,1,0,0,72,6,0,0,0,0,0,0,0,0,0,0,144,157,32,0,8,239,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,5,0,0,162,10,0,0,212,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,217,32,0,224,207,32,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,96,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,26,12,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,96,172,34,0,240,153,34,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,7,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,0,0,0,0,0,0,0,0,200,237,32,0,152,230,32,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,112,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,26,12,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,232,205,34,0,192,189,34,0,0,0,0,0,16,0,0,0,3,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,7,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,0,0,0,0,0,0,0,0,208,247,34,0,232,220,34,0,0,0,0,0,15,0,0,0,3,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,7,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,23,0,6,0,9,0,5,0,5,0,5,0,6,0,5,0,71,0,9,0,32,0,7,0,16,0,7,0,2,0,5,0,124,0,9,0,58,0,7,0,29,0,7,0,2,0,6,0,236,0,9,0,119,0,8,0,0,0,8,0,3,0,5,0,183,0,9,0,44,0,7,0,19,0,7,0,1,0,6,0,104,1,10,0,70,0,8,0,63,0,8,0,30,0,6,0,18,7,13,0,181,0,9,0,66,0,8,0,34,0,7,0,197,1,11,0,30,1,10,0,135,0,9,0,6,0,4,0,3,0,9,0,30,0,7,0,28,0,6,0,18,0,7,0,136,3,12,0,68,0,9,0,112,0,9,0,31,0,6,0,62,2,11,0,57,0,8,0,142,0,9,0,1,0,7,0,198,1,11,0,182,0,9,0,69,0,9,0,20,0,6,0,63,2,11,0,125,0,9,0,24,0,9,0,7,0,7,0,199,1,11,0,134,0,9,0,25,0,9,0,21,0,6,0,219,1,10,0,2,0,9,0,70,0,9,0,13,0,8,0,19,7,13,0,218,1,10,0,105,1,10,0,208,17,38,0,168,169,39,0,0,0,0,0,164,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,93,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,11,0,0,0,0,0,0,0,0,0,0,22,1,0,0,236,2,0,0,0,0,0,0,0,0,0,0,248,33,38,0,152,171,39,0,68,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,248,33,38,0,144,96,37,0,208,3,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,200,9,35,0,144,66,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,176,160,33,0,208,35,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,24,184,32,0,160,91,32,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,248,33,38,0,40,66,40,0,152,232,39,0,72,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,128,127,39,0,232,43,39,0,76,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,112,228,38,0,0,0,0,0,72,56,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,176,158,38,0,184,98,38,0,0,57,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,158,32,0,96,239,37,0,0,0,0,0,240,107,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,196,8,0,0,132,7,0,0,44,2,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,8,159,32,0,168,239,37,0,0,0,0,0,16,108,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,198,0,0,0,142,0,0,0,4,2,0,0,134,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,232,24,38,0,64,171,39,0,3,0,0,0,50,76,80,77,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,161,32,0,24,240,37,0,96,108,36,0,144,86,35,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,10,0,0,136,0,0,0,94,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,161,32,0,56,240,37,0,0,1,0,0,0,0,0,0,0,0,0,0,184,30,12,0,0,0,0,0,1,0,0,0,20,0,0,0,8,3,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,11,35,0,56,176,39,0,0,0,0,0,2,0,0,0,43,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,176,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,7,0,0,0,0,0,0,0,0,0,0,210,0,0,0,232,4,0,0,200,0,0,0,0,0,0,0,216,138,34,0,208,208,33,0,8,2,0,0,0,0,0,0,0,0,0,0,120,31,12,0,0,0,0,0,0,0,0,0,104,160,0,0,0,0,0,0,188,10,0,0,138,0,0,0,226,2,0,0,0,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,165,32,0,24,242,37,0,160,109,36,0,112,87,35,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,64,32,12,0,0,0,0,0,128,0,0,0,160,5,0,0,218,3,0,0,40,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,112,36,0,64,90,35,0,8,2,0,0,0,0,0,0,0,0,0,0,112,32,12,0,0,0,0,0,0,0,0,0,104,160,0,0,250,8,0,0,188,10,0,0,202,0,0,0,226,2,0,0,0,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,199,32,0,80,0,38,0,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,3,0,0,32,9,0,0,222,2,0,0,8,0,0,0,0,0,0,0,0,0,0,0,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,80,1,0,0,80,1,0,1,80,1,0,0,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,44,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,57,0,0,206,6,0,0,66,0,0,0,18,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,8,0,8,8,8,8,10,12,14,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,34,36,38,40,42,44,46,102,0,0,0,67,0,0,0,64,129,20,0,224,130,20,0,72,131,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,126,0,124,0,120,0,112,0,96,0,64,0,0,2,0,2,0,6,0,3,0,15,0,4,0,13,0,5,0,12,0,5,0,21,0,6,0,19,0,6,0,18,0,6,0,23,0,7,0,31,0,8,0,30,0,8,0,29,0,8,0,37,0,9,0,36,0,9,0,35,0,9,0,33,0,9,0,33,0,10,0,32,0,10,0,15,0,10,0,14,0,10,0,7,0,11,0,6,0,11,0,32,0,11,0,33,0,11,0,80,0,12,0,81,0,12,0,82,0,12,0,14,0,4,0,20,0,6,0,22,0,7,0,28,0,8,0,32,0,9,0,31,0,9,0,13,0,10,0,34,0,11,0,83,0,12,0,85,0,12,0,11,0,5,0,21,0,7,0,30,0,9,0,12,0,10,0,86,0,12,0,17,0,6,0,27,0,8,0,29,0,9,0,11,0,10,0,16,0,6,0,34,0,9,0,10,0,10,0,13,0,6,0,28,0,9,0,8,0,10,0,18,0,7,0,27,0,9,0,84,0,12,0,20,0,7,0,26,0,9,0,87,0,12,0,25,0,8,0,9,0,10,0,24,0,8,0,35,0,11,0,23,0,8,0,25,0,9,0,24,0,9,0,7,0,10,0,88,0,12,0,7,0,4,0,12,0,6,0,22,0,8,0,23,0,9,0,6,0,10,0,5,0,11,0,4,0,11,0,89,0,12,0,15,0,6,0,22,0,9,0,5,0,10,0,14,0,6,0,4,0,10,0,17,0,7,0,36,0,11,0,16,0,7,0,37,0,11,0,19,0,7,0,90,0,12,0,21,0,8,0,91,0,12,0,20,0,8,0,19,0,8,0,26,0,8,0,21,0,9,0,20,0,9,0,19,0,9,0,18,0,9,0,17,0,9,0,38,0,11,0,39,0,11,0,92,0,12,0,93,0,12,0,94,0,12,0,95,0,12,0,3,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,9,9,10,11,12,13,14,0,0,0,0,0,0,0,0,1,1,1,2,2,3,3,4,4,5,5,6,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,1,2,3,4,5,6,7,8,9,10,1,2,3,4,5,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,1,1,1,1,1,2,3,4,5,6,7,8,1,2,3,1,2,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,72,5,36,0,216,10,35,0,0,0,0,0,13,0,0,0,32,32,0,0,0,0,0,0,216,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,32,12,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,2,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,255,255,255,255,3,0,0,0,2,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,19,0,20,0,21,0,22,0,23,0,24,0,26,0,27,0,20,0,21,0,22,0,23,0,25,0,26,0,27,0,28,0,21,0,22,0,23,0,24,0,26,0,27,0,28,0,30,0,22,0,23,0,24,0,26,0,27,0,28,0,30,0,31,0,23,0,24,0,25,0,27,0,28,0,30,0,31,0,33,0,8,0,17,0,18,0,19,0,21,0,23,0,25,0,27,0,17,0,18,0,19,0,21,0,23,0,25,0,27,0,28,0,20,0,21,0,22,0,23,0,24,0,26,0,28,0,30,0,21,0,22,0,23,0,24,0,26,0,28,0,30,0,32,0,22,0,23,0,24,0,26,0,28,0,30,0,32,0,35,0,23,0,24,0,26,0,28,0,30,0,32,0,35,0,38,0,25,0,26,0,28,0,30,0,32,0,35,0,38,0,41,0,27,0,28,0,30,0,32,0,35,0,38,0,41,0,45,0,232,199,33,0,168,190,33,0,0,0,0,0,13,0,0,0,43,16,0,0,0,0,0,0,88,11,21,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,128,34,12,0,96,33,12,0,192,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,2,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,14,1,0,0,0,0,0,0,99,13,15,17,19,21,23,0,0,8,8,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,19,20,21,22,23,24,25,3,3,3,2,2,2,2,3,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,0,0,0,0,0,0,3,2,2,2,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,0,0,0,0,0,0,128,79,33,0,40,224,32,0,64,117,36,0,128,79,33,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,224,3,0,0,0,0,0,88,0,0,0,86,10,0,0,20,1,0,0,186,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,98,34,0,0,58,34,0,0,0,0,0,216,31,34,0,0,0,0,0,2,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,67,34,0,0,162,33,0,0,0,0,0,2,0,0,0,32,32,0,0,56,136,20,0,24,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,41,12,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,208,98,37,0,248,5,36,0,0,0,0,0,2,0,0,0,43,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,120,36,12,0,176,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,7,0,0,0,0,0,0,0,0,0,0,210,0,0,0,232,4,0,0,200,0,0,0,0,0,0,0,184,126,32,0,168,36,32,0,64,117,36,0,128,79,33,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,107,8,0,0,0,0,0,88,0,0,0,86,10,0,0,20,1,0,0,186,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,12,40,0,56,166,39,0,64,117,36,0,120,12,40,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,33,23,0,0,0,0,0,88,0,0,0,86,10,0,0,20,1,0,0,186,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,1,0,0,0,8,0,0,0,1,0,0,0,9,0,0,0,1,0,0,0,10,0,0,0,1,0,0,0,12,0,0,0,1,0,0,0,15,0,0,0,1,0,0,0,16,0,0,0,1,0,0,0,18,0,0,0,1,0,0,0,20,0,0,0,1,0,0,0,24,0,0,0,1,0,0,0,25,0,0,0,1,0,0,0,30,0,0,0,1,0,0,0,32,0,0,0,1,0,0,0,36,0,0,0,1,0,0,0,40,0,0,0,1,0,0,0,45,0,0,0,1,0,0,0,48,0,0,0,1,0,0,0,50,0,0,0,1,0,0,0,60,0,0,0,1,0,0,0,72,0,0,0,1,0,0,0,75,0,0,0,1,0,0,0,80,0,0,0,1,0,0,0,90,0,0,0,1,0,0,0,96,0,0,0,1,0,0,0,100,0,0,0,1,0,0,0,120,0,0,0,1,0,0,0,150,0,0,0,1,0,0,0,180,0,0,0,1,0,0,0,200,0,0,0,1,0,0,0,240,0,0,0,1,0,0,0,238,2,0,0,233,3,0,0,32,3,0,0,233,3,0,0,192,3,0,0,233,3,0,0,232,3,0,0,233,3,0,0,176,4,0,0,233,3,0,0,226,4,0,0,233,3,0,0,220,5,0,0,233,3,0,0,64,6,0,0,233,3,0,0,83,7,0,0,233,3,0,0,208,7,0,0,233,3,0,0,96,9,0,0,233,3,0,0,196,9,0,0,233,3,0,0,184,11,0,0,233,3,0,0,166,14,0,0,233,3,0,0,160,15,0,0,233,3,0,0,192,18,0,0,233,3,0,0,136,19,0,0,233,3,0,0,112,23,0,0,233,3,0,0,76,29,0,0,233,3,0,0,64,31,0,0,233,3,0,0,16,39,0,0,233,3,0,0,224,46,0,0,233,3,0,0,152,58,0,0,233,3,0,0,32,78,0,0,233,3,0,0,192,93,0,0,233,3,0,0,48,117,0,0,233,3,0,0,96,234,0,0,233,3,0,0,0,0,0,0,0,0,0,0,32,143,20,0,200,40,12,0,72,40,12,0,200,39,12,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,16,0,0,0,9,0,0,0,221,0,0,0,100,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,160,158,34,0,80,143,34,0,160,128,34,0,104,111,34,0,0,0,0,0,1,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,5,36,0,248,10,35,0,0,0,0,0,1,0,0,0,32,32,0,0,48,145,20,0,224,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,46,12,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,192,72,38,0,56,176,39,0,0,0,0,0,1,0,0,0,43,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,176,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,7,0,0,0,0,0,0,0,0,0,0,210,0,0,0,232,4,0,0,200,0,0,0,0,0,0,0,16,140,34,0,24,210,33,0,64,117,36,0,0,0,0,0,0,80,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,8,4,0,0,0,0,0,88,0,0,0,86,10,0,0,20,1,0,0,186,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,32,0,80,251,37,0,64,117,36,0,224,92,35,0,0,80,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,32,12,0,0,0,0,0,88,0,0,0,86,10,0,0,20,1,0,0,186,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,8,0,16,0,19,0,22,0,26,0,27,0,29,0,34,0,16,0,16,0,22,0,24,0,27,0,29,0,34,0,37,0,19,0,22,0,26,0,27,0,29,0,34,0,34,0,38,0,22,0,22,0,26,0,27,0,29,0,34,0,37,0,40,0,22,0,26,0,27,0,29,0,32,0,35,0,40,0,48,0,26,0,27,0,29,0,32,0,35,0,40,0,48,0,58,0,26,0,27,0,29,0,34,0,38,0,46,0,56,0,69,0,27,0,29,0,35,0,38,0,46,0,56,0,69,0,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,8,8,8,8,8,8,8,8], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1337124);
/* memory initializer */ allocate([8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,0,0,0,0,0,0,128,63,127,106,44,63,93,254,51,63,170,241,66,63,63,53,78,63,185,252,87,63,106,188,100,63,81,107,106,63,150,67,123,63,150,67,131,63,96,229,136,63,246,40,140,63,246,40,148,63,193,202,153,63,0,0,0,0,4,0,0,0,1,0,5,0,6,0,14,0,30,0,62,0,126,0,254,0,254,1,255,1,3,2,2,3,3,4,5,6,7,8,9,9,0,0,0,0,0,0,1,0,2,0,6,0,14,0,30,0,62,0,126,0,254,0,254,1,254,3,255,3,2,2,2,3,4,5,6,7,8,9,10,10,0,0,0,0,1,9,11,5,9,5,13,6,13,4,23,7,19,7,31,8,12,4,22,7,18,7,30,8,19,5,27,8,23,8,19,8,11,4,21,7,17,7,29,8,17,5,25,8,21,8,17,8,15,6,15,8,13,8,3,9,15,5,11,8,7,8,7,9,10,4,20,7,16,7,28,8,14,6,14,8,12,8,2,9,16,5,24,8,20,8,16,8,14,5,10,8,6,8,6,9,18,5,26,8,22,8,18,8,13,5,9,8,5,8,5,9,12,5,8,8,4,8,4,9,7,3,10,5,8,5,12,6,1,1,1,2,1,3,1,4,3,6,5,7,4,7,3,7,11,9,10,9,9,9,17,10,16,10,15,10,14,10,13,10,12,10,0,0,0,0,0,0,1,1,3,3,2,3,3,4,2,4,3,5,2,5,7,7,6,7,11,8,10,8,9,8,8,8,7,8,6,8,23,10,22,10,21,10,20,10,19,10,18,10,35,11,34,11,33,11,32,11,31,11,30,11,29,11,28,11,27,11,26,11,25,11,24,11,8,11,15,11,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,93,0,0,233,3,0,0,24,0,0,0,1,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,30,0,0,0,1,0,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,60,0,0,0,1,0,0,0,15,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,10,0,0,0,1,0,0,0,12,0,0,0,1,0,0,0,15,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,204,32,0,200,2,38,0,0,0,0,0,112,204,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,140,0,0,0,150,7,0,0,206,1,0,0,250,3,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,202,32,0,120,1,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,10,0,0,244,6,0,0,216,3,0,0,0,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,74,38,0,112,176,39,0,1,0,0,0,35,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,1,0,0,0,0,0,0,0,0,0,0,130,2,0,0,0,0,0,0,42,1,0,0,0,0,0,0,240,74,38,0,224,176,39,0,1,0,0,0,28,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,6,0,0,0,0,0,0,0,0,0,0,26,1,0,0,16,6,0,0,220,1,0,0,0,0,0,0,27,0,0,0,30,0,0,0,8,0,0,0,12,0,0,0,30,0,0,0,0,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,15,0,0,0,31,0,0,0,63,0,0,0,127,0,0,0,255,0,0,0,255,1,0,0,255,3,0,0,255,7,0,0,255,15,0,0,255,31,0,0,255,63,0,0,255,127,0,0,255,255,0,0,0,0,0,0,251,255,255,255,249,255,255,255,3,0,0,0,246,255,255,255,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,253,255,255,255,253,255,255,255,252,255,255,255,252,255,255,255,251,255,255,255,251,255,255,255,250,255,255,255,249,255,255,255,249,255,255,255,248,255,255,255,247,255,255,255,246,255,255,255,245,255,255,255,243,255,255,255,242,255,255,255,240,255,255,255,239,255,255,255,237,255,255,255,235,255,255,255,232,255,255,255,230,255,255,255,227,255,255,255,225,255,255,255,221,255,255,255,218,255,255,255,215,255,255,255,211,255,255,255,207,255,255,255,203,255,255,255,198,255,255,255,193,255,255,255,188,255,255,255,183,255,255,255,177,255,255,255,171,255,255,255,165,255,255,255,159,255,255,255,152,255,255,255,145,255,255,255,139,255,255,255,131,255,255,255,124,255,255,255,117,255,255,255,109,255,255,255,102,255,255,255,95,255,255,255,87,255,255,255,80,255,255,255,73,255,255,255,66,255,255,255,60,255,255,255,54,255,255,255,48,255,255,255,213,0,0,0,218,0,0,0,222,0,0,0,225,0,0,0,227,0,0,0,228,0,0,0,228,0,0,0,227,0,0,0,224,0,0,0,221,0,0,0,215,0,0,0,208,0,0,0,200,0,0,0,189,0,0,0,177,0,0,0,163,0,0,0,146,0,0,0,127,0,0,0,106,0,0,0,83,0,0,0,57,0,0,0,29,0,0,0,254,255,255,255,220,255,255,255,184,255,255,255,145,255,255,255,103,255,255,255,59,255,255,255,12,255,255,255,218,254,255,255,165,254,255,255,111,254,255,255,53,254,255,255,249,253,255,255,187,253,255,255,123,253,255,255,57,253,255,255,245,252,255,255,176,252,255,255,105,252,255,255,33,252,255,255,216,251,255,255,143,251,255,255,70,251,255,255,253,250,255,255,180,250,255,255,108,250,255,255,38,250,255,255,225,249,255,255,158,249,255,255,94,249,255,255,33,249,255,255,231,248,255,255,178,248,255,255,129,248,255,255,86,248,255,255,47,248,255,255,16,248,255,255,247,247,255,255,229,247,255,255,219,247,255,255,217,247,255,255,224,247,255,255,241,247,255,255,245,7,0,0,208,7,0,0,160,7,0,0,101,7,0,0,30,7,0,0,203,6,0,0,108,6,0,0,255,5,0,0,134,5,0,0,0,5,0,0,107,4,0,0,202,3,0,0,26,3,0,0,93,2,0,0,146,1,0,0,185,0,0,0,211,255,255,255,224,254,255,255,223,253,255,255,210,252,255,255,185,251,255,255,148,250,255,255,100,249,255,255,42,248,255,255,230,246,255,255,153,245,255,255,68,244,255,255,233,242,255,255,135,241,255,255,33,240,255,255,183,238,255,255,76,237,255,255,223,235,255,255,115,234,255,255,9,233,255,255,163,231,255,255,67,230,255,255,233,228,255,255,153,227,255,255,83,226,255,255,26,225,255,255,239,223,255,255,213,222,255,255,205,221,255,255,218,220,255,255,253,219,255,255,56,219,255,255,143,218,255,255,1,218,255,255,146,217,255,255,68,217,255,255,25,217,255,255,18,217,255,255,49,217,255,255,121,217,255,255,234,217,255,255,136,218,255,255,83,219,255,255,77,220,255,255,120,221,255,255,212,222,255,255,100,224,255,255,40,226,255,255,34,228,255,255,174,25,0,0,71,23,0,0,168,20,0,0,209,17,0,0,192,14,0,0,119,11,0,0,245,7,0,0,58,4,0,0,70,0,0,0,26,252,255,255,182,247,255,255,28,243,255,255,75,238,255,255,70,233,255,255,14,228,255,255,164,222,255,255,9,217,255,255,65,211,255,255,76,205,255,255,44,199,255,255,229,192,255,255,121,186,255,255,234,179,255,255,59,173,255,255,111,166,255,255,138,159,255,255,142,152,255,255,127,145,255,255,96,138,255,255,53,131,255,255,1,124,255,255,200,116,255,255,143,109,255,255,88,102,255,255,40,95,255,255,2,88,255,255,235,80,255,255,231,73,255,255,250,66,255,255,39,60,255,255,115,53,255,255,226,46,255,255,118,40,255,255,54,34,255,255,35,28,255,255,66,22,255,255,151,16,255,255,36,11,255,255,237,5,255,255,246,0,255,255,66,252,254,255,211,247,254,255,172,243,254,255,209,239,254,255,66,236,254,255,4,233,254,255,23,230,254,255,125,227,254,255,57,225,254,255,76,223,254,255,183,221,254,255,122,220,254,255,152,219,254,255,16,219,254,255,30,37,1,0,0,0,0,0,152,218,30,0,152,218,30,0,40,218,30,0,40,218,30,0,96,217,30,0,0,0,0,0,5,112,1,0,8,0,0,0,13,0,0,0,32,0,0,0,28,0,0,0,33,0,0,0,53,54,50,72,35,0,0,0,2,80,1,0,64,0,0,0,46,80,1,0,64,0,0,0,2,0,0,0,97,0,0,0,2,0,0,0,96,0,0,0,2,0,0,0,98,0,0,0,2,0,0,0,99,0,0,0,2,0,0,0,100,0,0,0,2,0,0,0,101,0,0,0,2,80,1,0,102,0,0,0,2,80,1,0,103,0,0,0,2,80,1,0,104,0,0,0,1,80,1,0,105,0,0,0,0,80,1,0,105,0,0,0,1,0,0,0,106,0,0,0,1,80,1,0,107,0,0,0,8,0,0,0,108,0,0,0,62,0,0,0,109,0,0,0,89,0,0,0,110,0,0,0,71,0,0,0,163,0,0,0,117,0,0,0,164,0,0,0,3,80,1,0,165,0,0,0,4,80,1,0,169,0,0,0,5,80,1,0,221,0,0,0,0,112,1,0,224,0,0,0,24,80,1,0,225,0,0,0,1,0,2,0,1,0,0,0,1,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,32,14,40,0,208,167,39,0,192,72,39,0,32,14,40,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,5,0,136,106,40,0,136,137,12,0,0,0,0,0,128,0,0,0,20,5,0,0,70,3,0,0,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,234,39,0,248,127,39,0,1,0,0,0,14,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,4,0,0,0,0,0,0,0,0,0,0,206,1,0,0,80,3,0,0,240,1,0,0,0,0,0,0,56,234,39,0,8,128,39,0,1,0,0,0,14,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,4,0,0,0,0,0,0,0,0,0,0,68,2,0,0,28,0,0,0,86,1,0,0,0,0,0,0,104,67,34,0,104,161,33,0,1,0,0,0,1,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,10,0,0,0,0,0,0,0,0,0,0,96,1,0,0,0,0,0,0,48,2,0,0,0,0,0,0,240,184,32,0,96,92,32,0,1,0,0,0,13,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,10,0,0,0,0,0,0,0,0,0,0,62,1,0,0,0,0,0,0,48,2,0,0,0,0,0,0,0,185,32,0,168,92,32,0,1,0,0,0,13,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,6,0,0,0,0,0,0,0,0,0,0,44,3,0,0,0,0,0,0,38,2,0,0,0,0,0,0,160,142,34,0,120,212,33,0,72,121,36,0,160,142,34,0,1,80,1,0,62,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,8,138,12,0,0,0,0,0,232,12,0,0,102,0,0,0,80,3,0,0,248,1,0,0,0,0,0,0,126,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,205,32,0,72,3,38,0,0,1,0,0,88,121,36,0,0,0,0,0,192,175,23,0,0,0,0,0,0,0,0,0,48,0,0,0,10,2,0,0,34,1,0,0,148,3,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,67,34,0,144,161,33,0,1,0,0,0,1,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,6,0,0,0,0,0,0,0,0,0,0,56,3,0,0,0,0,0,0,38,2,0,0,0,0,0,0,176,97,37,0,208,4,36,0,1,0,0,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,10,0,0,0,0,0,0,0,0,0,0,96,1,0,0,0,0,0,0,48,2,0,0,0,0,0,0,56,52,38,0,240,172,39,0,1,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,103,40,0,56,100,40,0,48,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,172,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,138,12,0,0,0,0,0,98,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,205,32,0,40,3,38,0,72,121,36,0,16,97,35,0,0,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,50,38,0,192,172,39,0,1,0,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,112,103,40,0,48,100,40,0,24,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,236,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,138,12,0,0,0,0,0,124,1,0,0,0,0,0,0,14,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,97,37,0,248,4,36,0,1,0,0,0,0,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,6,0,0,0,0,0,0,0,0,0,0,56,3,0,0,0,0,0,0,38,2,0,0,0,0,0,0,16,59,38,0,208,173,39,0,1,0,0,0,43,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,10,0,0,0,0,0,0,0,0,0,0,96,1,0,0,0,0,0,0,48,2,0,0,0,0,0,0,224,60,38,0,248,173,39,0,1,0,0,0,43,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,6,0,0,0,0,0,0,0,0,0,0,56,3,0,0,0,0,0,0,38,2,0,0,0,0,0,0,88,75,38,0,240,176,39,0,3,0,0,0,5,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,4,0,0,228,0,0,0,0,0,0,0,0,0,0,0,124,11,0,0,0,0,0,0,0,0,0,0,168,75,38,0,16,177,39,0,3,0,0,0,5,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,7,0,0,0,0,0,0,0,0,0,0,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,14,0,16,0,18,0,20,0,21,0,27,0,32,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,214,33,0,64,83,33,0,0,0,0,0,184,214,33,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,5,0,120,94,40,0,16,142,12,0,0,0,0,0,128,0,0,0,20,5,0,0,70,3,0,0,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,127,36,0,200,100,35,0,0,128,0,0,0,0,0,0,0,0,0,0,0,147,12,0,0,0,0,0,0,0,0,0,128,0,0,0,144,6,0,0,116,6,0,0,50,3,0,0,44,7,0,0,40,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,76,38,0,48,177,39,0,0,0,0,0,120,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,3,0,0,0,0,0,0,0,0,0,0,158,0,0,0,114,3,0,0,0,0,0,0,0,0,0,0,0,3,1,2,3,4,5,6,7,8,9,9,10,11,12,13,14,15,16,17,18,18,19,20,21,22,23,24,25,26,27,28,0,2,3,4,5,6,7,8,9,10,11,13,14,15,16,17,18,19,20,21,22,24,25,26,27,28,29,30,31,31,31,26,128,76,38,0,72,177,39,0,0,0,0,0,81,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,9,0,0,0,0,0,0,0,0,0,0,222,2,0,0,106,6,0,0,0,0,0,0,0,0,0,0,224,236,32,0,128,14,38,0,64,128,36,0,224,236,32,0,14,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,112,4,0,0,136,1,0,0,44,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,236,32,0,128,14,38,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,134,5,0,0,208,3,0,0,160,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,238,32,0,56,15,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,40,9,0,0,0,5,0,0,124,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,80,1,0,45,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,0,8,1,0,0,26,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,195,34,0,96,178,34,0,0,0,0,0,0,195,34,0,29,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,51,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,11,1,0,0,0,0,0,0,59,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,55,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,15,1,0,0,0,0,0,0,63,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,55,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,15,1,0,0,0,0,0,0,63,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,55,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,9,1,8,1,7,1,6,1,5,1,4,1,3,4,3,5,3,6,3,7,3,3,3,5,4,9,5,17,6,33,7,65,8,129,9,1,9,1,8,1,7,1,6,1,5,1,4,1,3,2,2,3,2,3,3,5,4,9,5,17,6,33,7,65,8,129,9,0,0,0,0,1,9,1,8,1,7,1,6,1,5,1,4,1,3,1,1,3,3,5,4,9,5,17,6,33,7,65,8,129,9,0,0,0,0,0,0,0,0,0,0,48,5,40,0,232,154,39,0,0,1,0,0,48,5,40,0,0,0,0,0,0,0,0,0,0,0,0,0,29,80,1,0,0,0,0,0,0,0,0,0,148,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,79,38,0,152,177,39,0,1,0,0,0,29,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,9,0,0,0,0,0,0,0,0,0,0,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,239,32,0,128,15,38,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,6,0,0,38,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,101,120,116,47,112,108,97,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,112,1,0,105,109,97,103,101,47,103,105,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,0,0,0,105,109,97,103,101,47,106,112,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,105,109,97,103,101,47,112,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,105,109,97,103,101,47,116,105,102,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,116,114,117,101,116,121,112,101,45,102,111,110,116,0,0,0,0,0,0,128,1,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,102,111,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,97,112,112,108,105,99,97,116,105,111,110,47,118,110,100,46,109,115,45,111,112,101,110,116,121,112,101,0,0,0,0,0,70,84,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,179,39,0,136,235,39,0,176,134,37,0,48,38,36,0,0,0,0,0,0,0,0,0,65,95,65,65,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,80,1,0,65,95,65,67,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,80,1,0,65,95,65,76,65,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,80,1,0,65,95,68,84,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,80,1,0,65,95,69,65,67,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41,80,1,0,65,95,70,76,65,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,80,1,0,65,95,77,76,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,80,1,0,65,95,77,80,69,71,47,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,1,0,65,95,77,80,69,71,47,76,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,1,0,65,95,77,80,69,71,47,76,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,80,1,0,65,95,79,80,85,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,85,80,79,65,95,79,80,85,83,47,69,88,80,69,82,73,77,69,78,84,65,76,0,0,0,0,0,83,85,80,79,65,95,80,67,77,47,70,76,79,65,84,47,73,69,69,69,0,0,0,0,0,0,0,0,21,0,1,0,65,95,80,67,77,47,70,76,79,65,84,47,73,69,69,69,0,0,0,0,0,0,0,0,23,0,1,0,65,95,80,67,77,47,73,78,84,47,66,73,71,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,65,95,80,67,77,47,73,78,84,47,66,73,71,0,0,0,0,0,0,0,0,0,0,0,13,0,1,0,65,95,80,67,77,47,73,78,84,47,66,73,71,0,0,0,0,0,0,0,0,0,0,0,9,0,1,0,65,95,80,67,77,47,73,78,84,47,76,73,84,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,95,80,67,77,47,73,78,84,47,76,73,84,0,0,0,0,0,0,0,0,0,0,0,12,0,1,0,65,95,80,67,77,47,73,78,84,47,76,73,84,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,65,95,80,67,77,47,73,78,84,47,76,73,84,0,0,0,0,0,0,0,0,0,0,0,5,0,1,0,65,95,81,85,73,67,75,84,73,77,69,47,81,68,77,50,0,0,0,0,0,0,0,0,19,80,1,0,65,95,82,69,65,76,47,49,52,95,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,1,0,65,95,82,69,65,76,47,50,56,95,56,0,0,0,0,0,0,0,0,0,0,0,0,0,1,48,1,0,65,95,82,69,65,76,47,65,84,82,67,0,0,0,0,0,0,0,0,0,0,0,0,0,31,80,1,0,65,95,82,69,65,76,47,67,79,79,75,0,0,0,0,0,0,0,0,0,0,0,0,0,20,80,1,0,65,95,82,69,65,76,47,83,73,80,82,0,0,0,0,0,0,0,0,0,0,0,0,0,42,80,1,0,65,95,84,82,85,69,72,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,80,1,0,65,95,84,84,65,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,80,1,0,65,95,86,79,82,66,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,80,1,0,65,95,87,65,86,80,65,67,75,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,80,1,0,68,95,87,69,66,86,84,84,47,83,85,66,84,73,84,76,69,83,0,0,0,0,0,0,84,84,86,87,68,95,87,69,66,86,84,84,47,67,65,80,84,73,79,78,83,0,0,0,0,0,0,0,84,84,86,87,68,95,87,69,66,86,84,84,47,68,69,83,67,82,73,80,84,73,79,78,83,0,0,0,84,84,86,87,68,95,87,69,66,86,84,84,47,77,69,84,65,68,65,84,65,0,0,0,0,0,0,0,84,84,86,87,83,95,84,69,88,84,47,85,84,70,56,0,0,0,0,0,0,0,0,0,0,0,0,0,112,105,82,83,83,95,84,69,88,84,47,85,84,70,56,0,0,0,0,0,0,0,0,0,0,0,0,0,2,112,1,0,83,95,84,69,88,84,47,85,84,70,56,0,0,0,0,0,0,0,0,0,0,0,0,0,8,112,1,0,83,95,84,69,88,84,47,65,83,67,73,73,0,0,0,0,0,0,0,0,0,0,0,0,2,112,1,0,83,95,84,69,88,84,47,65,83,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,112,1,0,83,95,84,69,88,84,47,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,112,1,0,83,95,65,83,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,112,1,0,83,95,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,112,1,0,83,95,84,69,88,84,47,65,83,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,83,83,65,83,95,84,69,88,84,47,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,83,83,65,83,95,65,83,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,83,83,65,83,95,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,83,83,65,83,95,86,79,66,83,85,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,1,0,83,95,68,86,66,83,85,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,112,1,0,83,95,72,68,77,86,47,80,71,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,112,1,0,86,95,68,73,82,65,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,0,0,0,86,95,77,74,80,69,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,86,95,77,80,69,71,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,86,95,77,80,69,71,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,86,95,77,80,69,71,52,47,73,83,79,47,65,83,80,0,0,0,0,0,0,0,0,0,13,0,0,0,86,95,77,80,69,71,52,47,73,83,79,47,65,80,0,0,0,0,0,0,0,0,0,0,13,0,0,0,86,95,77,80,69,71,52,47,73,83,79,47,83,80,0,0,0,0,0,0,0,0,0,0,13,0,0,0,86,95,77,80,69,71,52,47,73,83,79,47,65,86,67,0,0,0,0,0,0,0,0,0,28,0,0,0,86,95,77,80,69,71,72,47,73,83,79,47,72,69,86,67,0,0,0,0,0,0,0,0,53,54,50,72,86,95,77,80,69,71,52,47,77,83,47,86,51,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,86,95,80,82,79,82,69,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,86,95,82,69,65,76,47,82,86,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,86,95,82,69,65,76,47,82,86,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,86,95,82,69,65,76,47,82,86,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,69,0,0,0,86,95,82,69,65,76,47,82,86,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,70,0,0,0,86,95,83,78,79,87,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,79,78,83,86,95,84,72,69,79,82,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,86,95,85,78,67,79,77,80,82,69,83,83,69,68,0,0,0,0,0,0,0,0,0,0,14,0,0,0,86,95,86,80,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,141,0,0,0,86,95,86,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,91,38,0,16,179,39,0,0,0,0,0,9,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,0,0,0,0,0,0,0,0,0,0,108,1,0,0,138,5,0,0,0,0,0,0,0,0,0,0,200,45,35,0,40,1,35,0,72,226,34,0,120,210,34,0,0,0,0,0,8,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,68,34,0,120,162,33,0,0,0,0,0,8,0,0,0,0,48,0,64,0,0,0,0,248,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,136,215,32,0,48,119,32,0,0,1,0,0,48,29,32,0,0,0,0,0,96,173,12,0,0,0,0,0,8,0,0,0,20,0,0,0,0,0,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,180,33,0,120,146,33,0,0,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,48,173,12,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,0,0,0,0,0,0,0,0,0,0,6,2,0,0,138,5,0,0,186,1,0,0,0,0,0,0,72,96,38,0,72,179,39,0,0,0,0,0,114,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,1,0,0,0,0,0,0,0,0,0,0,62,3,0,0,208,1,0,0,0,0,0,0,0,0,0,0,192,239,32,0,8,16,38,0,104,129,36,0,64,101,35,0,0,0,0,0,0,0,0,0,68,86,68,109,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,0,0,0,102,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,240,32,0,192,16,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,118,2,0,0,160,9,0,0,22,3,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,192,99,38,0,104,179,39,0,3,0,0,0,68,86,68,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,4,0,0,0,0,0,0,0,0,0,0,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,242,32,0,80,17,38,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,0,0,130,7,0,0,174,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,16,219,29,0,10,0,0,0,96,71,22,0,1,6,0,0,80,94,26,0,208,86,26,0,15,0,0,0,4,0,0,0,136,220,29,0,20,0,0,0,96,76,22,0,2,6,0,0,208,108,26,0,208,101,26,0,14,0,0,0,1,0,0,0,56,223,29,0,40,0,0,0,96,81,22,0,4,6,0,0,208,122,26,0,208,115,26,0,14,0,0,0,0,8,20,0,192,252,12,0,1,6,4,4,128,215,8,0,9,84,54,7,200,0,0,0,16,0,0,0,16,219,29,0,10,0,0,0,96,71,22,0,1,6,0,0,80,94,26,0,208,86,26,0,15,0,0,0,4,0,0,0,136,220,29,0,20,0,0,0,96,76,22,0,2,6,0,0,208,108,26,0,208,101,26,0,14,0,0,0,1,0,0,0,56,223,29,0,40,0,0,0,96,81,22,0,4,6,0,0,208,122,26,0,208,115,26,0,14,0,0,0,0,8,20,0,192,252,12,0,1,6,4,4,128,215,8,0,9,84,54,7,200,0,0,0,16,0,0,0,16,219,29,0,10,0,0,0,96,71,22,0,1,6,0,0,208,138,26,0,208,129,26,0,18,0,0,0,4,0,0,0,136,220,29,0,20,0,0,0,96,76,22,0,2,6,0,0,80,156,26,0,208,147,26,0,17,0,0,0,1,0,0,0,56,223,29,0,40,0,0,0,96,81,22,0,4,6,0,0,80,173,26,0,208,164,26,0,17,0,0,0,0,8,20,0,192,252,12,0,1,6,4,4,128,215,8,0,9,84,54,7,200,0,0,0,16,0,0,0,16,219,29,0,10,0,0,0,96,71,22,0,1,6,0,0,208,138,26,0,208,129,26,0,18,0,0,0,4,0,0,0,136,220,29,0,20,0,0,0,96,76,22,0,2,6,0,0,80,156,26,0,208,147,26,0,17,0,0,0,1,0,0,0,56,223,29,0,40,0,0,0,96,81,22,0,4,6,0,0,80,173,26,0,208,164,26,0,17,0,0,0,0,8,20,0,192,252,12,0,1,6,4,4,128,215,8,0,9,84,54,7,200,0,0,0,16,0,0,0,16,219,29,0,10,0,0,0,96,71,22,0,1,6,0,0,80,193,26,0,208,181,26,0,23,0,0,0,4,0,0,0,136,220,29,0,20,0,0,0,96,76,22,0,2,6,0,0,80,215,26,0,208,204,26,0,21,0,0,0,1,0,0,0,56,223,29,0,40,0,0,0,96,81,22,0,4,6,0,0,208,236,26,0,208,225,26,0,22,0,0,0,0,8,20,0,192,252,12,0,1,6,4,4,128,215,8,0,9,84,54,7,200,0,0,0,16,0,0,0,16,219,29,0,10,0,0,0,96,71,22,0,1,6,0,0,80,193,26,0,208,181,26,0,23,0,0,0,4,0,0,0,136,220,29,0,20,0,0,0,96,76,22,0,2,6,0,0,80,215,26,0,208,204,26,0,21,0,0,0,1,0,0,0,56,223,29,0,40,0,0,0,96,81,22,0,4,6,0,0,208,236,26,0,208,225,26,0,22,0,0,0,0,8,20,0,192,252,12,0,1,6,4,4,128,215,8,0,9,84,54,7,200,0,0,0,8,0,0,0,40,219,29,0,10,0,0,0,96,86,22,0,1,6,0,0,80,255,26,0,208,247,26,0,15,0,0,0,2,0,0,0,176,220,29,0,20,0,0,0,96,91,22,0,2,6,0,0,208,13,27,0,208,6,27,0,14,0,0,0,1,0,0,0,136,223,29,0,32,0,0,0,96,96,22,0,4,6,0,0,80,28,27,0,208,20,27,0,15,0,0,0,0,4,16,0,96,22,13,0,1,6,4,3,128,224,8,0,9,56,36,7,200,0,0,0,8,0,0,0,88,219,29,0,10,0,0,0,96,100,22,0,1,6,0,0,80,43,27,0,208,35,27,0,15,0,0,0,2,0,0,0,0,221,29,0,20,0,0,0,96,105,22,0,2,6,0,0,208,57,27,0,208,50,27,0,14,0,0,0,1,0,0,0,72,224,29,0,32,0,0,0,96,110,22,0,4,6,0,0,80,72,27,0,208,64,27,0,15,0,0,0,0,4,16,0,224,42,13,0,1,6,4,3,128,233,8,0,9,56,36,7,200,0,0,0,8,0,0,0,112,219,29,0,10,0,0,0,96,114,22,0,1,5,0,0,208,87,27,0,208,79,27,0,16,0,0,0,2,0,0,0,80,221,29,0,20,0,0,0,224,116,22,0,2,5,0,0,80,103,27,0,208,95,27,0,15,0,0,0,1,0,0,0,136,224,29,0,30,0,0,0,96,119,22,0,3,6,0,0,208,118,27,0,208,110,27,0,16,0,0,0,0,4,16,0,96,63,13,0,1,6,4,3,128,242,8,0,9,56,60,7,200,0,0,0,8,0,0,0,160,219,29,0,10,0,0,0,96,124,22,0,1,5,0,0,208,134,27,0,208,126,27,0,16,0,0,0,2,0,0,0,160,221,29,0,24,0,0,0,224,126,22,0,2,5,0,0,80,150,27,0,208,142,27,0,15,0,0,0,1,0,0,0,8,225,29,0,30,0,0,0,224,129,22,0,3,6,0,0,208,165,27,0,208,157,27,0,16,0,0,0,0,4,16], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1347364);
/* memory initializer */ allocate([96,63,13,0,1,6,4,3,128,1,9,0,9,28,30,7,200,0,0,0,8,0,0,0,184,219,29,0,10,0,0,0,224,134,22,0,1,5,0,0,80,184,27,0,208,173,27,0,21,0,0,0,2,0,0,0,208,221,29,0,20,0,0,0,96,137,22,0,2,5,0,0,208,203,27,0,208,194,27,0,18,0,0,0,1,0,0,0,72,225,29,0,30,0,0,0,224,139,22,0,3,6,0,0,208,222,27,0,208,212,27,0,20,0,0,0,0,2,16,0,96,85,13,0,1,6,4,3,128,16,9,0,9,36,30,7,200,0,0,0,8,0,0,0,232,219,29,0,8,0,0,0,224,144,22,0,1,5,0,0,80,243,27,0,208,232,27,0,21,0,0,0,2,0,0,0,32,222,29,0,16,0,0,0,224,146,22,0,2,5,0,0,208,6,28,0,208,253,27,0,18,0,0,0,1,0,0,0,200,225,29,0,24,0,0,0,224,148,22,0,3,6,0,0,80,25,28,0,208,15,28,0,19,0,0,0,0,2,16,0,224,105,13,0,1,6,4,3,128,26,9,0,9,28,20,7,200,0,0,0,8,0,0,0,200,218,29,0,10,0,0,0,96,51,22,0,1,5,0,0,208,43,28,0,208,34,28,0,18,0,0,0,2,0,0,0,16,220,29,0,20,0,0,0,224,53,22,0,2,5,0,0,208,60,28,0,208,52,28,0,16,0,0,0,1,0,0,0,104,222,29,0,30,0,0,0,96,56,22,0,3,6,0,0,80,77,28,0,208,68,28,0,17,0,0,0,0,2,12,0,0,237,12,0,1,5,3,3,128,195,8,0,8,28,20,6,200,0,0,0,8,0,0,0,224,218,29,0,10,0,0,0,96,61,22,0,1,5,0,0,208,94,28,0,208,85,28,0,18,0,0,0,2,0,0,0,56,220,29,0,20,0,0,0,224,63,22,0,2,5,0,0,208,111,28,0,208,103,28,0,16,0,0,0,1,0,0,0,168,222,29,0,30,0,0,0,96,66,22,0,3,6,0,0,80,128,28,0,208,119,28,0,17,0,0,0,0,2,12,0,224,244,12,0,1,5,3,3,128,205,8,0,8,28,20,6,200,0,0,0,8,0,0,0,200,218,29,0,10,0,0,0,96,51,22,0,1,5,0,0,80,150,28,0,208,136,28,0,27,0,0,0,2,0,0,0,16,220,29,0,20,0,0,0,224,53,22,0,2,5,0,0,208,174,28,0,208,163,28,0,22,0,0,0,1,0,0,0,104,222,29,0,30,0,0,0,96,56,22,0,3,6,0,0,208,197,28,0,208,185,28,0,24,0,0,0,0,2,12,0,0,237,12,0,1,5,3,3,128,195,8,0,8,28,20,6,200,0,0,0,8,0,0,0,224,218,29,0,10,0,0,0,96,61,22,0,1,5,0,0,80,150,28,0,208,136,28,0,27,0,0,0,2,0,0,0,56,220,29,0,20,0,0,0,224,63,22,0,2,5,0,0,208,174,28,0,208,163,28,0,22,0,0,0,1,0,0,0,168,222,29,0,30,0,0,0,96,66,22,0,3,6,0,0,208,197,28,0,208,185,28,0,24,0,0,0,0,2,12,0,224,244,12,0,1,5,3,3,128,205,8,0,8,28,20,6,200,0,0,0,240,105,38,0,216,179,39,0,1,0,0,0,64,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,10,0,0,0,0,0,0,0,0,0,0,248,0,0,0,112,6,0,0,0,0,0,0,0,0,0,0,90,254,215,109,200,29,143,74,153,34,250,177,28,56,20,83,118,105,100,115,0,0,16,0,128,0,0,170,0,56,155,113,97,117,100,115,0,0,16,0,128,0,0,170,0,56,155,113,40,189,173,70,208,111,150,71,147,178,21,92,81,220,4,141,144,107,38,0,248,179,39,0,0,0,0,0,38,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,10,0,0,0,0,0,0,0,0,0,0,238,2,0,0,82,7,0,0,0,0,0,0,0,0,0,0,184,242,32,0,0,18,38,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,112,176,12,0,0,0,0,0,12,0,0,0,42,7,0,0,6,1,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,0,98,0,139,1,47,6,191,24,255,35,0,0,0,0,6,7,9,11,13,14,14,0,1,1,1,2,1,3,1,4,40,214,37,0,136,175,37,0,96,140,37,0,0,0,0,0,16,37,35,0,200,91,34,0,48,180,33,0,0,53,33,0,224,199,32,0,128,106,32,0,72,82,40,0,72,247,39,0,200,140,39,0,136,53,39,0,0,239,38,0,0,168,38,0,192,107,38,0,80,53,38,0,144,0,38,0,0,0,0,0,112,249,32,0,192,21,38,0,144,131,36,0,64,102,35,0,3,80,1,0,28,0,0,0,4,112,1,0,64,4,3,0,160,94,40,0,8,198,12,0,0,0,0,0,224,0,0,0,206,9,0,0,208,2,0,0,210,4,0,0,0,0,0,0,94,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,255,32,0,72,25,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,1,0,0,176,0,0,0,38,1,0,0,242,1,0,0,248,2,0,0,54,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,249,32,0,144,228,32,0,96,130,32,0,216,39,32,0,3,80,1,0,0,0,0,0,0,0,0,0,64,0,3,0,104,107,40,0,0,173,12,0,0,0,0,0,224,0,0,0,206,9,0,0,208,2,0,0,210,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,101,37,0,144,8,36,0,1,0,0,0,10,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,0,0,0,0,248,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,111,38,0,184,180,39,0,1,0,0,0,9,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,0,0,0,0,248,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,78,35,0,0,61,35,0,0,0,0,0,48,78,35,0,0,0,0,0,13,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,0,104,25,38,0,0,1,0,0,64,0,33,0,0,0,0,0,168,211,12,0,0,0,0,0,13,0,0,0,20,0,0,0,56,8,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,3,0,0,0,0,0,96,1,33,0,240,25,38,0,0,0,0,0,0,0,0,0,184,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,4,0,0,234,2,0,0,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,1,33,0,16,26,38,0,0,1,0,0,184,1,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,11,0,0,220,0,0,0,58,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,7,14,0,216,6,14,0,152,6,14,0,120,6,14,0,88,6,14,0,72,6,14,0,56,6,14,0,40,6,14,0,24,6,14,0,24,7,14,0,0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,5,5,6,6,7,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,0,0,0,0,0,0,152,112,38,0,112,181,39,0,0,0,0,0,73,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,1,33,0,56,26,38,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,80,1,0,0,0,0,0,160,6,0,0,56,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,2,33,0,120,26,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,9,0,0,62,0,0,0,178,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,113,38,0,120,181,39,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,24,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,10,0,0,0,0,0,0,38,3,0,0,0,0,0,0,66,5,0,0,0,0,0,0,0,0,0,0,0,102,37,0,136,9,36,0,0,0,0,0,28,0,0,0,32,128,0,0,0,0,0,0,248,31,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,94,10,0,0,0,0,0,192,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,126,1,0,0,0,0,0,162,4,0,0,0,0,0,0,232,1,0,0,0,0,0,0,140,2,0,0,0,0,0,0,0,0,0,0,128,119,38,0,96,182,39,0,0,0,0,0,28,0,0,0,32,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,135,1,0,0,0,0,0,192,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,126,1,0,24,0,0,0,162,4,0,0,0,0,0,0,232,1,0,0,0,0,0,0,140,2,0,0,0,0,0,0,0,0,0,0,144,102,37,0,224,9,36,0,0,0,0,0,169,0,0,0,32,128,0,0,0,0,0,0,232,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,26,0,0,0,0,0,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,235,23,0,82,1,0,0,56,6,0,0,0,0,0,0,10,1,0,0,0,0,0,0,254,9,0,0,0,0,0,0,0,0,0,0,160,102,37,0,240,9,36,0,0,0,0,0,169,0,0,0,2,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,1,0,0,200,4,0,0,0,0,0,0,0,0,0,0,18,2,0,0,126,2,0,0,0,0,0,0,0,0,0,0,16,126,38,0,32,183,39,0,0,0,0,0,141,0,0,0,32,128,0,0,0,0,0,0,72,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,26,0,0,0,0,0,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,235,23,0,0,0,0,0,74,0,0,0,0,0,0,0,10,1,0,0,0,0,0,0,254,9,0,0,0,0,0,0,0,0,0,0,96,126,38,0,48,183,39,0,0,0,0,0,141,0,0,0,2,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,3,0,0,0,0,0,0,0,0,0,0,18,2,0,0,126,2,0,0,0,0,0,0,0,0,0,0,248,2,33,0,240,26,38,0,128,134,36,0,24,104,35,0,2,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,116,15,0,0,0,0,0,24,40,0,0,38,11,0,0,94,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,196,33,0,176,68,33,0,0,1,0,0,112,196,33,0,0,0,0,0,0,0,0,0,0,0,0,0,50,80,1,0,0,0,0,0,0,0,0,0,148,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,129,38,0,168,183,39,0,0,0,0,0,148,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,1,0,0,0,0,0,0,0,0,0,0,168,1,0,0,44,3,0,0,0,0,0,0,0,0,0,0,144,130,38,0,192,183,39,0,0,0,0,0,86,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,248,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,9,0,0,0,0,0,0,0,0,0,0,248,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,130,38,0,224,183,39,0,0,0,0,0,139,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,11,0,0,0,0,0,0,0,0,0,0,136,2,0,0,182,5,0,0,248,1,0,0,0,0,0,0,192,3,33,0,64,27,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,218,7,0,0,164,3,0,0,130,3,0,0,116,10,0,0,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,131,38,0,16,184,39,0,0,0,0,0,150,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,5,0,0,0,0,0,0,0,0,0,0,238,0,0,0,244,5,0,0,0,0,0,0,0,0,0,0,160,131,38,0,48,184,39,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,96,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,10,0,0,0,0,0,0,66,2,0,0,0,0,0,0,218,5,0,0,0,0,0,0,0,0,0,0,64,39,33,0,48,188,32,0,0,0,0,0,12,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,0,0,0,0,0,0,0,0,0,0,6,2,0,0,138,5,0,0,0,0,0,0,0,0,0,0,32,140,38,0,32,185,39,0,0,0,0,0,89,0,0,0,0,2,0,0,0,0,0,0,120,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,2,0,0,0,0,0,0,60,2,0,0,0,0,0,0,162,1,0,0,0,0,0,0,0,0,0,0,240,134,38,0,112,184,39,0,0,0,0,0,89,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,120,210,15,0,160,171,10,0,116,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,4,33,0,16,28,38,0,232,134,36,0,16,105,35,0,0,0,0,0,0,0,0,0,66,85,83,74,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,2,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,7,33,0,64,32,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,98,8,0,0,60,5,0,0,56,2,0,0,232,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,152,139,38,0,200,184,39,0,3,0,0,0,66,85,83,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,24,32,40,48,56,1,9,17,25,33,41,49,57,2,10,18,26,34,42,50,58,3,11,19,27,35,43,51,59,4,12,20,28,36,44,52,60,5,13,21,29,37,45,53,61,6,14,22,30,38,46,54,62,7,15,23,31,39,47,55,63,5,2,1,1,0,1,1,0,1,1,2,2,1,1,1,1,3,3,1,1,2,2,1,1,4,4,1,1,1,1,2,2,5,5,1,1,3,3,1,1,6,6,1,2,1,2,7,7,1,1,8,8,1,1,4,2,1,4,2,1,3,3,1,1,1,9,9,1,2,1,2,1,5,5,1,1,10,10,1,1,3,3,2,2,1,1,11,11,6,4,4,1,6,1,2,1,2,12,8,1,12,7,8,7,1,16,1,16,1,3,3,13,1,13,2,2,1,15,1,5,14,15,1,5,14,1,17,8,17,8,1,4,4,2,2,1,25,25,24,24,1,3,1,3,1,8,6,7,6,1,18,8,18,1,7,23,2,2,23,1,1,21,22,9,9,22,19,1,21,5,19,5,1,33,20,33,20,8,4,4,1,32,2,2,8,3,32,26,3,1,7,7,26,6,1,6,1,1,16,1,10,1,10,2,16,29,28,2,29,28,1,27,5,8,5,27,1,8,3,7,3,31,41,31,1,41,6,1,6,7,4,4,1,1,2,1,2,11,34,30,11,1,30,15,15,34,36,40,36,40,35,35,37,37,39,39,38,38,1,255,0,2,254,0,3,253,1,255,4,252,5,251,1,255,6,250,2,254,7,249,1,255,8,248,9,247,3,253,1,255,10,246,2,254,11,245,1,255,12,4,244,252,1,255,13,243,1,255,14,242,2,5,15,254,251,241,253,3,16,240,17,1,255,239,6,18,250,238,2,254,19,237,1,255,20,236,4,252,7,249,21,235,1,255,2,3,253,22,254,234,8,23,248,1,2,233,255,2,254,254,24,1,232,255,25,5,251,1,231,255,9,247,26,1,230,3,1,255,27,253,255,229,1,3,255,253,28,252,4,10,246,228,1,255,1,255,29,6,227,250,30,252,3,3,253,226,1,4,255,31,253,1,11,245,255,225,32,255,255,2,254,1,1,224,1,4,255,252,33,255,1,1,255,5,5,251,223,255,244,12,251,249,1,1,7,34,4,252,255,4,222,252,35,36,254,221,254,220,2,13,2,255,1,243,1,255,37,1,251,6,5,255,38,250,248,5,8,255,1,1,219,255,5,39,251,251,6,250,218,217,242,40,14,2,1,1,254,216,255,254,2,255,255,255,1,1,1,255,1,255,1,255,1,255,0,38,0,1,1,2,2,3,3,4,4,5,5,6,8,6,8,7,7,9,9,10,10,11,11,1,12,1,12,13,13,16,14,16,14,15,15,17,17,18,0,18,19,20,21,19,22,21,20,22,25,24,2,25,24,23,23,2,26,28,26,28,29,27,29,27,33,33,1,32,1,3,32,30,36,3,36,30,31,31,35,34,37,41,34,35,37,4,41,4,49,8,8,49,40,38,5,38,40,39,5,39,42,43,42,7,57,6,43,44,6,50,7,44,57,48,50,48,45,45,46,47,51,46,47,58,1,51,58,1,52,59,53,9,52,55,55,59,53,56,54,56,54,9,64,64,60,63,60,63,61,62,61,62,2,10,2,10,11,1,11,13,12,1,12,13,16,16,8,8,14,3,3,15,14,15,4,4,1,17,17,5,1,7,7,5,6,1,2,2,6,22,1,25,21,22,8,24,1,21,25,24,8,18,18,23,9,20,23,33,29,33,20,1,19,1,29,36,9,36,19,41,28,57,32,3,28,3,1,27,49,49,1,32,26,26,2,4,4,7,57,41,2,7,10,5,37,16,10,27,8,8,13,16,37,13,1,5,0,1,255,1,255,1,255,1,255,1,255,1,1,255,255,1,255,1,255,1,255,1,255,2,1,254,255,1,255,1,1,255,255,1,255,1,255,1,0,255,1,1,1,255,1,255,255,255,1,1,2,255,255,1,255,254,1,1,255,255,1,1,255,255,1,255,3,1,253,2,255,1,1,254,255,255,255,1,1,1,1,1,255,255,255,2,255,254,1,2,254,255,1,1,2,255,255,1,254,255,1,1,255,2,1,2,255,1,254,255,254,255,255,1,1,255,1,255,1,1,1,255,255,1,4,255,255,252,1,1,1,2,255,255,1,255,255,1,255,255,1,254,1,255,1,1,255,255,1,1,255,255,3,2,253,254,2,5,254,2,2,251,254,254,254,2,253,3,2,3,253,2,254,254,3,253,6,2,254,3,250,3,253,253,3,7,252,4,253,2,249,2,2,254,252,2,8,254,254,254,4,2,254,2,3,2,254,254,2,2,254,248,254,9,254,2,253,254,2,254,2,2,2,4,254,252,10,2,2,254,247,254,2,254,5,4,252,4,254,2,251,252,253,4,2,253,3,254,251,5,3,3,254,253,246,252,2,11,1,1,0,2,2,1,1,3,3,4,4,0,1,1,5,5,2,2,6,6,7,7,1,8,1,8,3,3,9,9,1,2,2,1,4,10,4,10,11,11,1,5,12,12,1,5,13,13,3,3,6,6,2,2,14,14,16,16,15,7,15,8,8,7,1,1,17,17,4,4,1,1,18,18,2,2,5,5,25,3,9,3,25,9,19,24,19,24,1,21,20,1,21,22,20,22,23,23,8,6,33,6,8,33,7,7,26,26,1,32,1,32,28,4,28,10,29,27,27,10,41,4,29,2,2,41,36,31,49,31,34,30,34,36,30,35,1,49,11,5,35,11,1,3,3,5,37,37,8,40,8,40,12,12,42,42,1,38,16,57,1,6,16,39,38,6,7,7,13,13,39,43,2,43,57,2,50,9,44,9,50,4,15,48,44,4,1,15,48,14,14,1,45,45,8,3,5,8,51,47,3,46,46,47,5,51,1,17,17,58,1,58,2,52,52,2,53,7,59,6,6,56,53,55,7,55,1,54,59,56,54,10,1,10,4,60,1,60,8,4,8,64,64,61,1,63,3,63,62,61,5,11,5,3,11,62,1,255,0,1,255,2,254,1,255,1,255,0,3,253,1,255,2,254,1,255,1,255,4,1,252,255,2,254,1,255,5,3,253,251,2,1,254,255,1,255,6,2,1,255,250,254,1,255,3,253,2,254,4,252,1,255,1,255,1,2,255,2,254,254,7,249,1,255,3,253,8,248,1,255,5,251,3,253,1,4,2,252,255,254,1,1,255,255,9,1,1,247,255,1,255,255,1,255,3,253,1,3,253,255,3,253,1,255,10,1,246,255,1,4,255,2,1,255,1,254,1,252,255,6,250,255,1,1,1,255,1,1,255,255,255,1,11,255,254,4,255,2,245,5,251,252,255,1,4,1,252,255,254,2,1,255,12,1,254,1,244,4,2,1,255,252,4,252,2,254,255,1,7,255,255,249,255,253,1,3,1,5,2,1,255,251,13,254,255,2,254,243,1,255,5,6,5,251,1,1,250,1,255,255,251,255,14,2,254,1,242,255,8,1,255,248,1,5,1,5,251,1,255,1,251,255,15,1,255,255,255,3,241,253,6,1,16,255,6,250,250,1,255,1,240,1,7,255,1,255,250,253,6,249,3,255,0,35,0,1,1,2,2,3,3,4,4,1,1,5,5,6,6,7,7,8,8,9,9,2,2,10,10,1,1,11,11,12,12,3,3,13,13,0,14,14,16,15,16,15,4,4,17,1,17,1,5,5,18,18,2,2,6,6,8,19,7,8,7,19,20,20,21,21,22,24,22,24,23,23,1,1,25,25,3,3,26,26,9,9,27,27,28,28,33,29,4,33,29,1,4,1,32,32,2,2,31,10,30,10,30,31,34,34,5,5,36,36,35,41,35,11,41,11,37,1,8,8,37,6,1,6,40,7,7,40,12,38,12,39,39,38,49,13,49,13,3,42,3,42,16,16,43,43,14,14,1,1,44,15,44,15,2,2,57,48,50,48,57,50,4,45,45,4,46,47,47,46,1,51,1,17,17,51,8,9,9,5,58,8,58,5,52,52,55,56,53,56,55,59,59,53,54,1,6,54,7,7,6,1,2,3,2,3,64,60,60,10,10,64,61,62,61,63,1,63,62,1,18,24,18,4,25,4,8,21,21,1,24,22,25,22,8,11,19,11,23,1,20,23,19,20,5,12,5,1,16,2,12,13,2,13,1,16,0,1,255,1,255,1,255,1,255,2,254,1,255,1,255,1,255,1,255,1,255,2,254,1,255,3,253,1,255,1,255,2,254,1,255,0,1,255,1,1,255,255,2,254,1,4,255,252,2,254,1,255,253,3,2,254,2,1,2,254,254,255,1,255,1,255,1,1,255,255,1,255,5,251,1,255,3,253,1,255,2,254,1,255,1,255,1,1,3,255,255,6,253,250,255,1,4,252,1,2,1,254,255,255,1,255,3,253,1,255,1,1,255,2,255,254,1,7,253,3,255,3,249,253,1,253,3,255,2,1,254,1,255,255,1,2,255,254,252,255,4,1,2,254,1,255,254,2,8,248,255,2,1,254,251,5,1,255,255,1,255,1,4,255,1,252,255,255,1,1,9,1,247,2,254,255,252,3,253,252,255,4,1,4,1,255,1,255,1,1,255,1,255,255,255,10,4,1,4,252,252,246,6,5,250,251,1,255,1,3,253,255,1,255,255,255,11,1,1,245,254,254,2,5,254,251,251,2,254,12,2,254,2,2,5,253,254,3,254,244,254,2,2,2,251,3,5,13,253,7,253,253,249,3,243,3,0,34,0,1,1,1,2,2,1,3,3,1,1,1,4,4,1,5,2,1,5,2,1,1,6,6,1,1,1,1,1,7,3,1,2,3,0,1,2,7,1,1,1,8,1,1,8,1,1,1,9,1,9,1,2,1,1,2,1,1,10,4,1,10,1,4,1,1,1,1,1,3,1,1,1,3,2,1,5,1,1,1,2,5,1,11,1,11,1,1,1,1,1,1,1,1,1,1,2,1,6,1,6,1,1,2,1,1,1,1,1,1,1,12,3,1,12,1,1,1,2,1,1,3,1,1,1,1,1,1,4,1,1,1,2,1,1,4,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,3,1,2,1,1,5,1,1,1,1,1,7,1,7,1,1,2,3,1,1,1,1,5,1,1,1,1,1,1,2,13,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,13,2,1,1,4,1,1,1,3,1,6,1,1,1,14,1,1,1,1,1,14,6,1,1,1,1,15,2,4,1,2,3,15,1,1,1,8,1,1,8,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,0,1,255,2,1,255,254,1,255,3,253,4,1,255,252,1,2,5,255,254,251,6,1,255,250,7,249,8,248,1,2,9,3,254,0,247,253,255,10,246,11,1,245,12,255,244,13,243,1,14,255,242,4,15,241,252,16,240,1,2,17,255,239,254,18,238,19,237,20,3,236,21,235,253,5,22,2,234,233,23,251,254,24,1,232,255,25,231,26,230,229,27,28,29,228,227,6,30,2,225,254,226,31,250,224,32,33,223,34,221,222,1,4,220,255,35,37,36,7,219,38,252,218,39,41,40,216,217,3,42,213,215,249,214,43,253,44,212,45,211,46,47,8,209,208,210,50,206,48,49,51,207,52,204,5,205,248,203,53,3,200,56,55,54,202,2,60,254,201,58,9,251,59,57,199,193,253,198,196,195,61,197,194,247,1,64,62,69,192,63,65,189,188,66,191,68,190,187,67,186,255,10,71,185,4,73,72,70,6,180,253,74,178,182,1,78,80,184,181,76,255,3,183,79,75,77,1,11,252,177,246,250,255,179,173,176,2,81,172,254,83,175,82,174,84,169,170,85,245,171,86,167,87,168,88,89,2,33,1,1,0,2,1,2,1,3,3,1,1,4,4,2,2,1,1,5,5,6,1,6,1,7,7,3,3,2,8,2,8,1,1,0,9,9,1,1,10,4,10,4,11,11,2,1,2,1,12,12,3,3,1,1,13,5,5,13,14,1,1,14,2,2,6,6,15,1,1,15,16,4,7,16,4,7,1,1,3,3,8,8,2,2,1,1,17,17,1,1,18,18,5,5,2,2,1,1,9,19,9,19,20,3,3,20,1,10,21,1,10,4,4,21,22,6,6,22,1,1,23,24,2,2,23,24,11,1,1,11,7,25,7,1,1,25,8,8,3,26,3,1,12,2,2,26,1,12,5,5,27,4,1,4,1,27,28,1,28,13,1,13,2,29,2,1,32,6,1,30,14,29,14,6,3,31,3,1,30,1,32,31,33,9,33,1,1,7,9,7,2,2,1,1,4,36,34,4,5,10,10,5,34,1,1,35,8,8,36,3,35,1,15,3,2,1,16,15,16,2,37,1,37,1,1,1,6,6,38,1,38,11,1,39,39,40,11,2,41,4,40,1,2,4,1,1,1,41,3,1,3,1,5,7,5,7,1,255,0,1,2,255,254,1,255,3,253,1,255,2,254,4,252,1,255,1,5,255,251,1,255,2,254,3,1,253,255,6,250,0,1,255,7,249,1,2,255,254,1,255,4,8,252,248,1,255,3,253,9,247,1,2,254,255,1,10,246,255,5,251,2,254,1,11,245,255,1,3,2,255,253,254,12,244,4,252,2,254,250,6,13,243,1,255,14,242,1,255,3,253,7,249,15,241,2,1,254,255,1,5,251,255,240,2,1,16,254,4,252,255,1,3,253,255,17,239,1,1,248,8,255,255,2,18,238,254,3,1,253,19,237,255,3,253,6,1,250,20,2,9,247,255,236,254,4,252,1,251,21,5,235,255,1,234,255,2,22,254,10,1,246,23,1,4,233,1,2,255,254,252,249,1,7,232,255,24,255,255,1,3,255,231,25,4,253,252,11,245,26,230,6,1,1,250,251,253,3,5,255,229,27,1,4,252,255,248,255,28,2,8,244,228,254,254,2,12,255,29,1,227,30,226,5,251,1,225,255,3,31,255,1,1,253,243,1,249,255,224,13,7,32,33,223,255,247,222,9,34,250,5,6,251,2,13,1,1,0,1,1,2,2,1,1,3,3,1,1,0,2,2,4,1,4,1,1,1,5,5,1,1,6,6,2,2,1,1,3,3,7,7,1,1,8,8,1,1,2,2,1,9,1,9,4,4,10,1,1,10,1,1,11,11,3,3,1,2,1,2,1,1,12,12,5,5,1,1,13,1,1,13,2,2,1,1,6,6,1,1,4,14,4,14,3,1,3,1,1,1,15,7,15,2,2,7,1,1,1,8,1,8,16,16,1,1,1,1,2,1,1,2,1,1,3,5,5,3,4,1,1,4,1,1,17,17,9,1,1,9,2,2,1,1,10,10,1,6,1,1,6,18,1,1,18,1,1,1,2,2,3,1,3,1,1,1,4,1,19,1,19,7,1,1,20,1,4,20,1,7,11,2,1,11,21,2,8,5,1,8,1,5,21,1,1,1,22,1,1,22,1,1,3,3,1,23,2,12,24,1,1,2,1,1,12,23,1,1,24,1,1,1,4,1,1,1,2,1,6,6,4,2,1,1,1,1,1,1,1,14,13,3,1,25,9,25,14,1,9,3,13,1,1,1,1,1,10,1,1,2,10,2,236,255,0,2,254,1,255,3,253,1,255,4,252,0,2,254,1,5,255,251,6,250,1,255,7,249,1,255,3,253,8,248,2,254,1,255,9,247,1,255,10,246,4,252,11,1,245,255,2,254,1,12,244,255,13,243,1,255,3,253,14,5,242,251,241,15,255,1,2,254,16,240,1,17,239,255,6,250,18,238,2,254,237,19,253,1,3,255,4,20,252,1,235,21,1,2,255,249,7,254,22,234,23,2,233,254,1,255,232,24,231,25,248,230,26,8,229,27,5,3,253,251,252,28,228,4,29,227,1,255,254,226,30,2,9,247,225,31,2,254,224,3,32,223,253,1,33,222,255,34,221,35,246,10,250,36,6,220,37,219,251,38,1,218,255,3,39,217,255,40,5,1,216,253,2,245,215,254,1,11,253,252,41,3,42,4,255,213,214,43,1,212,45,255,44,211,249,7,210,1,244,2,1,209,46,12,47,48,254,255,208,49,255,206,207,50,250,205,51,52,243,53,252,4,6,13,203,204,202,55,54,201,200,254,2,248,56,1,253,255,2,58,3,8,254,57,198,196,197,199,253,60,59,242,3,14,2,38,1,1,0,2,2,1,1,3,3,4,4,5,5,1,1,6,6,2,2,7,7,8,8,1,1,3,3,9,9,10,10,1,1,2,2,4,4,11,0,11,12,12,13,13,1,1,5,5,14,14,15,16,15,16,3,3,1,6,1,6,2,2,7,7,8,8,17,17,1,1,4,4,18,18,2,2,1,19,1,20,19,20,21,21,3,3,22,22,5,5,24,1,1,23,9,23,24,9,2,2,10,1,1,10,6,6,25,4,4,25,7,7,26,8,1,8,3,1,26,3,11,11,27,27,2,28,1,2,28,1,12,12,5,5,29,13,13,29,32,1,1,33,31,30,32,4,30,33,4,31,3,14,1,1,3,34,34,2,2,14,6,6,35,36,35,36,1,15,1,16,16,15,7,9,7,9,37,8,8,37,1,1,39,2,38,39,2,40,5,38,40,5,3,3,4,4,10,10,1,1,1,1,41,2,41,2,6,6,1,1,11,42,11,43,3,42,3,17,4,43,1,17,7,1,8,44,4,7,44,5,8,2,5,1,2,48,45,1,12,45,12,48,13,13,1,9,9,46,1,46,47,47,49,18,18,49,1,255,0,1,255,2,254,1,255,1,255,1,255,3,253,1,255,254,2,1,255,1,255,4,252,254,2,1,255,1,255,5,251,253,3,2,254,1,0,255,1,255,1,255,6,250,2,254,1,255,1,1,255,255,253,3,7,2,249,254,252,4,2,254,2,254,1,255,8,248,3,253,1,255,251,5,9,1,247,1,255,255,1,255,252,4,1,255,3,253,1,246,10,1,2,255,255,254,6,250,2,11,245,254,3,253,1,252,4,255,3,253,1,3,12,253,251,244,255,5,2,254,1,255,249,1,13,7,255,243,2,254,4,252,1,2,254,255,1,14,242,1,1,1,255,251,255,255,5,255,250,2,241,15,6,1,255,248,8,254,252,4,1,1,255,255,16,2,240,254,2,254,4,3,252,253,255,252,4,1,239,17,255,247,1,1,9,1,251,255,255,5,249,7,6,250,3,253,18,238,19,237,1,246,255,10,251,5,20,236,253,1,3,1,8,255,248,2,7,255,235,254,5,21,5,255,249,251,1,250,251,245,6,22,11,1,1,234,253,255,3,255,3,253,233,4,252,1,23,255,1,255,1,254,2,255,4,11,1,1,1,1,0,2,2,1,1,3,3,0,1,1,2,2,4,4,1,1,5,5,1,1,2,2,3,3,6,6,1,1,7,7,8,1,8,2,2,1,4,4,1,3,1,3,9,9,2,2,1,5,1,5,10,10,1,1,11,11,3,6,3,4,4,6,2,2,1,12,1,12,7,13,7,13,1,1,8,8,2,2,14,14,16,15,16,5,5,1,3,15,1,3,4,4,1,1,17,17,2,2,6,6,1,18,1,18,22,21,22,21,25,24,25,19,9,20,9,23,19,24,20,3,23,7,3,1,1,7,28,26,29,5,28,26,5,8,29,4,8,27,2,2,4,27,1,1,10,36,10,33,33,36,30,1,32,32,1,30,6,31,31,35,3,6,11,11,3,2,35,2,34,1,34,1,37,37,12,7,12,5,41,5,4,7,1,8,13,4,1,41,13,38,8,38,9,1,40,40,9,1,39,2,2,49,39,42,3,3,14,16,49,14,16,42,43,43,6,6,15,1,1,15,44,44,1,1,50,48,4,5,4,7,5,2,10,10,48,7,50,45,2,1,45,8,8,1,46,46,3,47,47,3,1,1,1,255,2,254,0,1,255,3,253,1,255,0,4,252,2,254,1,255,5,251,1,255,6,250,3,253,2,254,1,255,7,249,1,255,1,8,255,4,252,248,2,254,9,3,247,253,1,255,5,251,10,2,246,254,1,255,11,245,1,255,252,2,4,3,253,254,6,250,12,1,244,255,2,1,254,255,13,243,2,254,7,249,1,255,1,1,255,3,253,14,5,255,242,251,4,252,15,241,1,255,8,248,253,3,16,1,240,255,1,1,255,255,1,1,255,1,2,1,254,1,255,255,255,6,255,3,250,17,239,253,1,1,1,4,255,255,252,3,255,5,253,255,247,9,251,1,18,238,2,1,254,1,255,255,1,19,255,1,237,255,4,1,255,1,7,252,254,2,249,10,255,246,1,20,255,236,1,255,2,4,254,5,1,251,6,252,21,4,2,250,235,255,254,1,252,255,253,22,255,1,3,234,255,11,245,1,1,1,8,248,2,2,255,254,254,255,1,255,251,5,2,23,233,254,1,255,24,232,255,255,7,6,249,5,250,12,253,3,1,251,1,1,244,25,255,251,5,231,255,1,9,1,255,247,26,230,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,1,4,8,5,2,3,6,9,12,13,10,7,11,14,15,40,8,33,0,192,32,38,0,0,0,0,0,40,8,33,0,0,0,0,0,141,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,8,33,0,232,32,38,0,0,1,0,0,0,0,0,0,200,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,8,0,0,108,8,0,0,162,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,33,0,144,33,38,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,6,0,0,140,11,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,10,33,0,216,33,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,186,7,0,0,58,9,0,0,72,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,183,36,0,120,153,36,0,192,72,39,0,16,126,36,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,5,0,120,98,40,0,88,36,16,0,0,0,0,0,128,0,0,0,20,5,0,0,70,3,0,0,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,12,33,0,192,34,38,0,0,0,0,0,32,137,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,208,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,74,9,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,13,33,0,56,35,38,0,0,1,0,0,176,137,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,7,0,0,24,11,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,93,37,0,184,33,37,0,192,72,39,0,40,255,36,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,5,0,200,98,40,0,24,51,16,0,0,0,0,0,128,0,0,0,20,5,0,0,70,3,0,0,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,13,33,0,8,36,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,4,0,0,174,11,0,0,30,2,0,0,186], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1357604);
/* memory initializer */ allocate([255,255,255,255,0,0,0,128,86,85,85,85,0,0,0,64,52,51,51,51,171,170,170,42,37,73,146,36,0,0,0,32,29,199,113,28,154,153,153,25,117,209,69,23,86,85,85,21,20,59,177,19,147,36,73,18,18,17,17,17,0,0,0,16,16,15,15,15,143,227,56,14,95,67,121,13,205,204,204,12,13,195,48,12,187,232,162,11,45,100,33,11,171,170,170,10,164,112,61,10,138,157,216,9,95,66,123,9,74,146,36,9,177,220,211,8,137,136,136,8,133,16,66,8,0,0,0,8,125,240,193,7,136,135,135,7,8,117,80,7,200,113,28,7,70,62,235,6,176,161,188,6,7,105,144,6,103,102,102,6,100,112,62,6,135,97,24,6,209,23,244,5,94,116,209,5,6,91,176,5,23,178,144,5,11,98,114,5,86,85,85,5,42,120,57,5,82,184,30,5,6,5,5,5,197,78,236,4,63,135,212,4,48,161,189,4,75,144,167,4,37,73,146,4,32,193,125,4,89,238,105,4,152,199,86,4,69,68,68,4,84,92,50,4,67,8,33,4,5,65,16,4,0,0,0,4,4,63,240,3,63,248,224,3,54,38,210,3,196,195,195,3,15,204,181,3,132,58,168,3,210,10,155,3,228,56,142,3,225,192,129,3,35,159,117,3,55,208,105,3,216,80,94,3,237,29,83,3,132,52,72,3,211,145,61,3,52,51,51,3,32,22,41,3,50,56,31,3,34,151,21,3,196,48,12,3,4,3,3,3,233,11,250,2,145,73,241,2,47,186,232,2,12,92,224,2,131,45,216,2,3,45,208,2,12,89,200,2,45,176,192,2,6,49,185,2,71,218,177,2,171,170,170,2,254,160,163,2,21,188,156,2,213,250,149,2,41,92,143,2,13,223,136,2,131,130,130,2,152,69,124,2,99,39,118,2,3,39,112,2,160,67,106,2,106,124,100,2,152,208,94,2,106,63,89,2,38,200,83,2,24,106,78,2,147,36,73,2,241,246,67,2,144,224,62,2,214,224,57,2,45,247,52,2,3,35,48,2,204,99,43,2,3,185,38,2,35,34,34,2,174,158,29,2,42,46,25,2,34,208,20,2,34,132,16,2,187,73,12,2,131,32,8,2,17,8,4,2,0,0,0,2,241,7,252,1,130,31,248,1,90,70,244,1,32,124,240,1,124,192,236,1,27,19,233,1,173,115,229,1,226,225,225,1,111,93,222,1,8,230,218,1,102,123,215,1,66,29,212,1,89,203,208,1,105,133,205,1,49,75,202,1,114,28,199,1,241,248,195,1,113,224,192,1,185,210,189,1,146,207,186,1,196,214,183,1,28,232,180,1,101,3,178,1,108,40,175,1,2,87,172,1,247,142,169,1,27,208,166,1,66,26,164,1,64,109,161,1,234,200,158,1,21,45,156,1,154,153,153,1,80,14,151,1,16,139,148,1,181,15,146,1,25,156,143,1,25,48,141,1,145,203,138,1,96,110,136,1,98,24,134,1,120,201,131,1,130,129,129,1,96,64,127,1,245,5,125,1,33,210,122,1,201,164,120,1,207,125,118,1,24,93,116,1,136,66,114,1,6,46,112,1,119,31,110,1,194,22,108,1,206,19,106,1,130,22,104,1,199,30,102,1,134,44,100,1,168,63,98,1,23,88,96,1,188,117,94,1,131,152,92,1,87,192,90,1,36,237,88,1,212,30,87,1,86,85,85,1,149,144,83,1,127,208,81,1,2,21,80,1,11,94,78,1,137,171,76,1,107,253,74,1,159,83,73,1,21,174,71,1,189,12,70,1,135,111,68,1,99,214,66,1,66,65,65,1,20,176,63,1,204,34,62,1,91,153,60,1,178,19,59,1,195,145,57,1,130,19,56,1,224,152,54,1,208,33,53,1,70,174,51,1,53,62,50,1,145,209,48,1,76,104,47,1,93,2,46,1,181,159,44,1,75,64,43,1,19,228,41,1,2,139,40,1,12,53,39,1,40,226,37,1,74,146,36,1,104,69,35,1,121,251,33,1,113,180,32,1,72,112,31,1,244,46,30,1,107,240,28,1,165,180,27,1,151,123,26,1,57,69,25,1,130,17,24,1,105,224,22,1,230,177,21,1,241,133,20,1,130,92,19,1,143,53,18,1,18,17,17,1,2,239,15,1,87,207,14,1,11,178,13,1,21,151,12,1,111,126,11,1,17,104,10,1,244,83,9,1,17,66,8,1,97,50,7,1,222,36,6,1,128,25,5,1,66,16,4,1,28,9,3,1,9,4,2,1,2,1,1,1,0,0,0,1,0,0,0,0,0,16,137,11,63,12,155,13,0,16,93,20,144,29,254,57,137,11,81,8,212,8,207,9,137,11,175,14,81,21,207,41,63,12,212,8,95,9,106,10,63,12,150,15,161,22,99,44,155,13,207,9,106,10,146,11,155,13,81,17,36,25,81,49,0,16,137,11,63,12,155,13,0,16,93,20,144,29,254,57,93,20,175,14,150,15,81,17,93,20,235,25,161,37,207,73,144,29,81,21,161,22,36,25,144,29,161,37,161,54,40,107,254,57,207,41,99,44,81,49,254,57,207,73,40,107,49,210,168,152,38,0,136,186,39,0,0,0,0,0,40,0,0,0,2,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,228,7,0,0,0,0,0,0,0,0,0,0,24,27,39,0,104,205,39,0,1,0,0,0,1,64,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,6,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,16,7,7,17,18,8,8,3,3,3,3,3,3,3,3,19,20,9,9,21,22,10,10,4,4,4,4,4,4,4,4,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,23,24,11,11,25,26,12,12,5,5,5,5,5,5,5,5,27,28,13,13,29,30,14,14,6,6,6,6,6,6,6,6,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,248,4,4,9,247,252,252,2,2,2,2,2,2,2,2,10,246,5,5,11,245,251,251,254,254,254,254,254,254,254,254,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,12,244,6,6,13,243,250,250,3,3,3,3,3,3,3,3,14,242,7,7,15,241,249,249,253,253,253,253,253,253,253,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,7,7,9,9,7,7,5,5,5,5,5,5,5,5,9,9,7,7,9,9,7,7,5,5,5,5,5,5,5,5,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,9,9,7,7,9,9,7,7,5,5,5,5,5,5,5,5,9,9,7,7,9,9,7,7,5,5,5,5,5,5,5,5,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,0,2,3,1,1,0,0,0,0,0,0,0,0,4,5,2,2,6,7,3,3,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,9,4,4,10,11,5,5,2,2,2,2,2,2,2,2,12,13,6,6,14,15,7,7,3,3,3,3,3,3,3,3,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,15,0,4,0,21,0,6,0,23,0,7,0,31,0,8,0,37,0,9,0,36,0,9,0,33,0,10,0,32,0,10,0,7,0,11,0,6,0,11,0,32,0,11,0,6,0,3,0,20,0,6,0,30,0,8,0,15,0,10,0,33,0,11,0,80,0,12,0,14,0,4,0,29,0,8,0,14,0,10,0,81,0,12,0,13,0,5,0,35,0,9,0,13,0,10,0,12,0,5,0,34,0,9,0,82,0,12,0,11,0,5,0,12,0,10,0,83,0,12,0,19,0,6,0,11,0,10,0,84,0,12,0,18,0,6,0,10,0,10,0,17,0,6,0,9,0,10,0,16,0,6,0,8,0,10,0,22,0,7,0,85,0,12,0,21,0,7,0,20,0,7,0,28,0,8,0,27,0,8,0,33,0,9,0,32,0,9,0,31,0,9,0,30,0,9,0,29,0,9,0,28,0,9,0,27,0,9,0,26,0,9,0,34,0,11,0,35,0,11,0,86,0,12,0,87,0,12,0,7,0,4,0,25,0,9,0,5,0,11,0,15,0,6,0,4,0,11,0,14,0,6,0,13,0,6,0,12,0,6,0,19,0,7,0,18,0,7,0,17,0,7,0,16,0,7,0,26,0,8,0,25,0,8,0,24,0,8,0,23,0,8,0,22,0,8,0,21,0,8,0,20,0,8,0,19,0,8,0,24,0,9,0,23,0,9,0,22,0,9,0,21,0,9,0,20,0,9,0,19,0,9,0,18,0,9,0,17,0,9,0,7,0,10,0,6,0,10,0,5,0,10,0,4,0,10,0,36,0,11,0,37,0,11,0,38,0,11,0,39,0,11,0,88,0,12,0,89,0,12,0,90,0,12,0,91,0,12,0,92,0,12,0,93,0,12,0,94,0,12,0,95,0,12,0,3,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,8,8,9,9,10,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,0,0,0,1,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,0,0,1,2,3,4,5,6,7,8,9,10,11,12,1,2,3,4,5,6,1,2,3,4,1,2,3,1,2,3,1,2,3,1,2,3,1,2,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,120,15,33,0,144,36,38,0,0,1,0,0,144,138,36,0,0,0,0,0,152,90,16,0,0,0,0,0,8,0,0,0,20,0,0,0,0,0,0,0,14,2,0,0,34,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,16,159,38,0,80,187,39,0,0,0,0,0,113,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,5,0,0,0,0,0,0,0,0,0,0,154,2,0,0,92,3,0,0,0,0,0,0,0,0,0,0,120,164,38,0,168,187,39,0,0,0,0,0,112,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,1,0,0,0,0,0,0,0,0,0,0,154,2,0,0,92,3,0,0,0,0,0,0,0,0,0,0,8,171,38,0,0,188,39,0,0,0,0,0,29,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,3,0,0,0,0,0,0,0,0,0,0,50,1,0,0,76,6,0,0,0,0,0,0,0,0,0,0,192,171,38,0,96,188,39,0,0,0,0,0,76,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,10,0,0,0,0,0,0,0,0,0,0,178,0,0,0,152,1,0,0,0,0,0,0,0,0,0,0,152,172,38,0,144,188,39,0,1,0,0,0,27,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,9,0,0,0,0,0,0,0,0,0,0,176,0,0,0,118,3,0,0,138,1,0,0,0,0,0,0,120,110,35,0,192,152,34,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,128,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,4,0,0,128,2,0,0,180,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,144,36,0,160,112,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,16,0,0,0,0,0,0,0,0,0,120,4,0,0,0,0,0,0,48,11,0,0,172,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,26,33,0,56,41,38,0,0,0,0,0,0,141,36,0,0,0,0,0,8,0,0,0,0,0,0,0,129,8,0,0,0,0,0,0,48,95,16,0,0,0,0,0,28,4,0,0,128,2,0,0,180,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,39,33,0,208,46,38,0,1,0,0,0,0,0,0,0,0,0,0,0,96,95,16,0,0,0,0,0,0,0,0,0,120,4,0,0,128,6,0,0,48,11,0,0,172,2,0,0,62,9,0,0,38,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,58,33,0,120,55,38,0,24,149,36,0,16,116,35,0,60,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,10,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,58,33,0,120,55,38,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,8,0,0,34,2,0,0,90,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,173,38,0,176,188,39,0,0,0,0,0,137,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,244,10,0,0,0,0,0,0,0,0,0,0,152,59,33,0,216,55,38,0,0,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,240,3,0,0,118,10,0,0,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,173,38,0,176,188,39,0,0,0,0,0,138,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,244,10,0,0,0,0,0,0,0,0,0,0,208,179,39,0,88,81,39,0,0,0,0,0,208,179,39,0,0,0,0,0,240,104,40,0,0,0,0,0,0,0,0,0,32,0,0,0,116,0,0,0,94,9,0,0,148,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,31,35,0,224,86,34,0,0,0,0,0,70,68,73,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,8,0,0,0,0,0,0,0,0,0,0,112,1,0,0,186,11,0,0,0,0,0,0,0,0,0,0,56,60,33,0,64,56,38,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,238,9,0,0,80,5,0,0,200,0,0,0,0,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,173,38,0,184,188,39,0,0,0,0,0,48,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,8,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,4,0,0,0,0,0,0,0,0,0,0,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,65,76,66,84,66,80,77,84,67,79,77,84,67,79,78,84,67,79,80,84,68,76,89,84,69,78,67,84,69,88,84,84,70,76,84,84,73,84,49,84,73,84,50,84,73,84,51,84,75,69,89,84,76,65,78,84,76,69,78,84,77,69,68,84,79,65,76,84,79,70,78,84,79,76,89,84,79,80,69,84,79,87,78,84,80,69,49,84,80,69,50,84,80,69,51,84,80,69,52,84,80,79,83,84,80,85,66,84,82,67,75,84,82,83,78,84,82,83,79,84,83,82,67,84,83,83,69,0,0,0,0,0,0,0,0,248,63,35,0,248,47,35,0,192,10,35,0,80,229,34,0,16,213,34,0,0,198,34,0,192,181,34,0,160,161,34,0,120,145,34,0,136,131,34,0,184,114,34,0,184,100,34,0,80,67,34,0,104,35,34,0,48,20,34,0,104,5,34,0,88,246,33,0,80,228,33,0,40,215,33,0,64,204,33,0,96,194,33,0,0,0,0,0,105,109,97,103,101,47,103,105,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,0,0,0,105,109,97,103,101,47,106,112,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,105,109,97,103,101,47,106,112,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,105,109,97,103,101,47,112,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,105,109,97,103,101,47,116,105,102,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,0,0,0,105,109,97,103,101,47,98,109,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,0,0,0,74,80,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,80,78,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,68,69,78,84,68,79,82,84,68,82,67,84,68,82,76,84,68,84,71,84,73,80,76,84,77,67,76,84,77,79,79,84,80,82,79,84,83,79,65,84,83,79,80,84,83,79,84,84,83,83,84,0,0,0,0,160,101,36,0,0,74,36,0,128,51,36,0,0,74,36,0,240,4,36,0,152,213,35,0,128,188,35,0,144,165,35,0,96,145,35,0,136,121,35,0,80,100,35,0,64,82,35,0,0,0,0,0,0,0,0,0,84,68,65,84,84,73,77,69,84,79,82,89,84,82,68,65,84,83,73,90,84,89,69,82,0,0,0,0,0,0,0,0,248,68,33,0,184,59,38,0,144,150,36,0,160,117,35,0,176,158,34,0,8,226,33,0,176,90,33,0,72,232,32,0,120,133,32,0,152,43,32,0,40,19,40,0,240,173,39,0,16,77,39,0,56,3,39,0,240,190,38,0,24,126,38,0,136,68,38,0,24,12,38,0,232,228,37,0,96,185,37,0,160,153,37,0,192,97,37,0,120,35,37,0,176,0,37,0,8,214,36,0,96,184,36,0,168,154,36,0,80,127,36,0,0,0,0,0,0,0,0,0,128,194,39,0,104,239,39,0,32,137,37,0,168,39,36,0,200,37,35,0,88,92,34,0,120,180,33,0,56,53,33,0,16,200,32,0,200,106,32,0,192,82,40,0,112,247,39,0,32,141,39,0,184,53,39,0,56,239,38,0,72,168,38,0,232,107,38,0,96,53,38,0,160,0,38,0,56,214,37,0,144,175,37,0,120,140,37,0,0,76,37,0,120,25,37,0,184,244,36,0,40,205,36,0,40,176,36,0,136,147,36,0,56,120,36,0,88,93,36,0,8,67,36,0,224,41,36,0,216,240,35,0,168,204,35,0,240,180,35,0,8,158,35,0,24,138,35,0,240,114,35,0,96,95,35,0,136,76,35,0,80,58,35,0,8,39,35,0,104,252,34,0,80,224,34,0,96,208,34,0,184,192,34,0,16,176,34,0,128,156,34,0,160,141,34,0,248,126,34,0,160,109,34,0,232,93,34,0,48,53,34,0,48,29,34,0,24,15,34,0,32,0,34,0,56,238,33,0,144,223,33,0,240,211,33,0,56,201,33,0,120,191,33,0,216,181,33,0,136,148,33,0,152,129,33,0,128,119,33,0,160,109,33,0,240,99,33,0,120,89,33,0,152,80,33,0,88,72,33,0,96,63,33,0,96,54,33,0,32,24,33,0,32,6,33,0,24,254,32,0,248,245,32,0,216,238,32,0,104,231,32,0,128,225,32,0,208,217,32,0,192,208,32,0,48,201,32,0,80,175,32,0,200,160,32,0,24,154,32,0,88,146,32,0,32,139,32,0,16,133,32,0,152,127,32,0,160,121,32,0,96,116,32,0,48,107,32,0,136,83,32,0,72,69,32,0,176,62,32,0,80,55,32,0,208,48,32,0,144,42,32,0,104,37,32,0,48,32,32,0,200,89,40,0,112,83,40,0,128,59,40,0,24,45,40,0,160,36,40,0,136,29,40,0,120,23,40,0,72,18,40,0,80,13,40,0,144,7,40,0,8,2,40,0,240,247,39,0,216,223,39,0,24,208,39,0,56,197,39,0,232,187,39,0,32,180,39,0,24,173,39,0,152,166,39,0,112,157,39,0,112,149,39,0,152,141,39,0,128,119,39,0,168,103,39,0,0,96,39,0,160,87,39,0,152,81,39,0,40,76,39,0,16,71,39,0,96,65,39,0,128,59,39,0,240,53,39,0,176,37,39,0,120,24,39,0,176,18,39,0,144,11,39,0,160,7,39,0,96,2,39,0,48,254,38,0,32,249,38,0,96,245,38,0,136,239,38,0,16,223,38,0,232,211,38,0,216,206,38,0,216,199,38,0,64,195,38,0,16,190,38,0,200,71,33,0,48,60,38,0,208,150,36,0,200,71,33,0,0,0,0,0,79,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,136,2,0,0,152,3,0,0,224,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,72,33,0,192,60,38,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,102,5,0,0,30,9,0,0,110,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,106,37,0,72,13,36,0,1,0,0,0,59,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,9,0,0,0,0,0,0,0,0,0,0,176,0,0,0,118,3,0,0,138,1,0,0,0,0,0,0,176,174,38,0,232,188,39,0,0,0,0,0,26,0,0,0,0,16,0,64,0,0,0,0,144,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,5,0,0,0,0,0,0,114,2,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,136,175,38,0,40,189,39,0,0,0,0,0,26,0,0,0,3,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,6,0,0,0,0,0,0,0,0,0,0,184,1,0,0,128,10,0,0,0,0,0,0,0,0,0,0,248,72,33,0,232,60,38,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,162,5,0,0,122,8,0,0,178,2,0,0,254,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,177,38,0,184,189,39,0,0,0,0,0,174,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,5,0,0,0,0,0,0,0,0,0,0,38,2,0,0,104,7,0,0,0,0,0,0,0,0,0,0,16,75,33,0,72,62,38,0,0,0,0,0,160,151,36,0,0,80,1,0,2,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,224,168,16,0,0,0,0,0,104,0,0,0,166,11,0,0,22,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,77,33,0,128,63,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,86,3,0,0,32,10,0,0,244,1,0,0,106,8,0,0,216,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,2,0,0,0,0,0,3,4,4,0,0,0,0,0,6,7,6,0,0,0,0,152,117,35,0,8,98,35,0,0,0,0,0,152,117,35,0,0,0,0,0,53,54,50,72,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,4,5,0,1,2,3,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,34,0,0,0,35,0,0,0,35,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,37,0,0,0,40,45,51,57,64,72,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,2,2,3,3,3,3,3,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,254,58,10,254,254,58,10,254,254,58,10,254,254,58,10,254,252,54,16,254,252,54,16,254,252,54,16,254,252,54,16,254,250,46,28,252,250,46,28,252,250,46,28,252,250,46,28,252,252,36,36,252,252,36,36,252,252,36,36,252,252,36,36,252,252,28,46,250,252,28,46,250,252,28,46,250,252,28,46,250,254,16,54,252,254,16,54,252,254,16,54,252,254,16,54,252,254,10,58,254,254,10,58,254,254,10,58,254,254,10,58,254,0,1,0,2,1,0,3,2,1,0,4,3,2,1,0,5,4,3,2,1,0,6,5,4,3,2,1,0,7,6,5,4,3,2,1,0,7,6,5,4,3,2,1,7,6,5,4,3,2,7,6,5,4,3,7,6,5,4,7,6,5,7,6,7,0,0,1,0,1,2,0,1,2,3,0,1,2,3,4,0,1,2,3,4,5,0,1,2,3,4,5,6,0,1,2,3,4,5,6,7,1,2,3,4,5,6,7,2,3,4,5,6,7,3,4,5,6,7,4,5,6,7,5,6,7,6,7,7,0,1,0,2,1,0,3,2,1,0,3,2,1,3,2,3,0,0,1,0,1,2,0,1,2,3,1,2,3,2,3,3,120,77,33,0,200,63,38,0,0,1,0,0,88,152,36,0,0,0,0,0,112,109,17,0,0,0,0,0,53,54,50,72,20,0,0,0,226,0,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,189,38,0,248,190,39,0,0,0,0,0,53,54,50,72,34,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,109,17,0,208,171,10,0,92,29,0,0,0,0,0,0,224,0,0,0,46,1,0,0,0,0,0,0,0,0,0,0,126,6,0,0,0,0,0,0,0,0,0,0,30,0,0,0,34,6,0,0,104,1,0,0,0,0,0,0,216,82,33,0,40,65,38,0,0,0,0,0,0,0,0,0,2,80,1,0,28,0,0,0,0,0,0,0,65,0,0,0,0,0,0,0,24,110,17,0,0,0,0,0,28,0,0,0,38,5,0,0,124,1,0,0,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,189,8,0,174,2,0,0,24,0,0,0,250,1,0,0,84,1,0,0,0,0,0,0,0,0,0,0,128,161,35,0,240,140,35,0,0,0,0,0,128,161,35,0,0,0,0,0,28,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,128,1,0,2,0,3,0,32,128,160,0,0,0,0,3,3,3,3,7,7,7,7,11,11,11,11,15,15,15,15,3,7,11,15,3,7,11,15,3,7,11,15,3,7,11,15,0,83,33,0,56,65,38,0,0,1,0,0,88,153,36,0,0,0,0,0,32,118,17,0,0,0,0,0,28,0,0,0,20,0,0,0,124,6,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,48,39,0,208,233,38,0,0,0,0,0,28,0,0,0,34,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,118,17,0,240,171,10,0,48,189,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,10,0,0,0,0,0,0,0,0,0,0,18,3,0,0,22,11,0,0,142,0,0,0,0,0,0,0,71,114,97,121,0,52,50,48,0,0,52,50,50,0,0,52,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,29,30,31,32,32,33,34,34,35,35,36,36,37,37,37,38,38,38,39,39,39,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,35,36,37,38,38,39,40,40,41,41,42,42,43,43,43,44,44,44,45,45,45,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,41,42,43,44,44,45,46,46,47,47,48,48,49,49,49,50,50,50,51,51,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,47,48,49,50,50,51,52,52,53,53,54,54,55,55,55,56,56,56,57,57,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,53,54,55,56,56,57,58,58,59,59,60,60,61,61,61,62,62,62,63,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,59,60,61,62,62,63,64,64,65,65,66,66,67,67,67,68,68,68,69,69,69,69,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,65,66,67,68,68,69,70,70,71,71,72,72,73,73,73,74,74,74,75,75,75,75,4,1,255,255,0,0,0,0,5,255,2,255,6,0,0,0,255,0,9,255,255,255,255,255,0,0,0,0,0,0,0,0,0,255,10,0,255,255,255,0,255,11,0,0,0,0,0,0,9,8,7,7,6,6,6,6,5,5,5,5,5,5,5,5,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1367844);
/* memory initializer */ allocate([5,33,0,200,252,32,0,0,0,0,0,20,0,0,0,0,32,0,0,0,0,0,0,152,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,121,17,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,128,72,40,0,16,98,32,0,0,0,0,0,20,0,0,0,43,0,0,0,0,0,0,0,88,11,21,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,4,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,14,1,0,0,0,0,0,0,32,96,32,0,176,69,40,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,4,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,1,1,0,0,0,1,1,1,1,1,0,0,0,0,0,0,1,1,0,0,0,1,1,1,1,1,0,0,0,0,0,0,1,1,102,0,0,0,58,0,0,0,128,232,20,0,32,234,20,0,136,234,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,4,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,247,35,0,216,208,35,0,168,183,35,0,152,247,35,0,0,0,0,0,5,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,3,1,5,4,4,5,4,6,6,2,4,3,4,7,6,4,6,5,6,1,6,1,10,1,7,1,8,0,0,0,1,1,2,2,3,3,4,4,4,5,5,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,12,1,1,2,3,1,1,2,3,1,0,0,0,0,0,0,0,1,3,3,3,4,6,6,6,9,0,0,0,0,0,0,0,1,3,2,5,3,4,3,3,3,7,6,5,4,4,3,2,2,5,4,5,1,0,0,0,2,12,14,15,0,0,0,0,1,4,4,6,5,8,8,7,3,7,7,9,6,9,9,9,3,7,7,8,9,0,0,0,11,13,13,13,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,128,0,96,0,176,0,144,0,96,1,32,1,192,2,64,2,128,5,128,4,0,0,0,0,0,0,0,0,120,52,33,0,192,21,33,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,88,103,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,124,17,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,83,33,0,144,65,38,0,0,1,0,0,0,0,0,0,0,0,0,0,16,124,17,0,0,0,0,0,5,0,0,0,20,0,0,0,76,2,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,191,32,0,16,98,32,0,0,0,0,0,5,0,0,0,43,0,0,0,0,0,0,0,88,11,21,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,4,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,14,1,0,0,0,0,0,0,0,1,2,3,4,5,6,6,7,8,9,9,10,10,11,11,12,12,12,13,13,13,14,14,14,14,14,15,15,15,15,15,3,4,5,5,4,5,9,4,3,5,7,4,2,6,11,4,2,5,3,6,5,4,10,4,4,4,8,4,6,4,3,2,64,0,0,0,64,0,0,0,120,124,17,0,128,125,17,0,192,125,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,3,1,4,3,6,5,7,4,7,3,7,11,9,10,9,9,9,17,10,16,10,15,10,14,10,13,10,12,10,0,0,0,0,0,0,24,96,36,0,120,69,36,0,40,48,36,0,24,96,36,0,0,0,0,0,4,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,0,0,2,0,0,0,3,0,8,0,0,0,8,0,2,0,8,0,3,0,8,0,128,0,8,0,130,0,8,0,131,0,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,4,7,1,5,9,8,10,3,2,6,0,0,0,0,0,0,1,3,2,3,2,3,2,7,6,11,10,9,8,7,6,23,22,21,20,19,18,35,34,33,32,31,30,29,28,27,26,25,24,15,1,0,0,0,0,0,1,3,3,4,4,5,5,7,7,8,8,8,8,8,8,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,16,0,0,0,0,0,8,217,38,0,8,195,39,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,160,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,126,17,0,0,0,0,0,112,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,216,83,33,0,160,65,38,0,0,1,0,0,216,83,33,0,0,0,0,0,128,126,17,0,0,0,0,0,4,0,0,0,20,0,0,0,202,1,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,218,38,0,72,195,39,0,0,0,0,0,4,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,112,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,4,0,0,0,0,0,0,0,0,0,0,136,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,5,9,5,13,6,13,4,23,7,19,7,31,8,12,4,22,7,18,7,30,8,19,5,27,8,23,8,19,8,11,4,21,7,17,7,29,8,17,5,25,8,21,8,17,8,15,6,15,8,13,8,3,9,15,5,11,8,7,8,7,9,10,4,20,7,16,7,28,8,14,6,14,8,12,8,2,9,16,5,24,8,20,8,16,8,14,5,10,8,6,8,6,9,18,5,26,8,22,8,18,8,13,5,9,8,5,8,5,9,12,5,8,8,4,8,4,9,7,3,10,5,8,5,12,6,0,0,240,84,33,0,152,66,38,0,0,0,0,0,240,84,33,0,0,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,0,0,0,112,5,0,0,130,2,0,0,56,5,0,0,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,33,0,24,67,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,116,2,0,0,14,4,0,0,54,2,0,0,0,0,0,0,48,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,110,37,0,192,17,36,0,1,0,0,0,30,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,5,0,0,0,0,0,0,0,0,0,0,60,3,0,0,0,0,0,0,90,0,0,0,0,0,0,0,205,12,205,44,51,83,255,127,228,255,236,255,244,255,252,255,4,0,12,0,20,0,28,0,200,255,216,255,232,255,248,255,8,0,24,0,40,0,56,0,172,255,196,255,220,255,244,255,12,0,36,0,60,0,84,0,144,255,176,255,208,255,240,255,16,0,48,0,80,0,112,0,116,255,156,255,196,255,236,255,20,0,60,0,100,0,140,0,88,255,136,255,184,255,232,255,24,0,72,0,120,0,168,0,60,255,116,255,172,255,228,255,28,0,84,0,140,0,196,0,32,255,96,255,160,255,224,255,32,0,96,0,160,0,224,0,4,255,76,255,148,255,220,255,36,0,108,0,180,0,252,0,232,254,56,255,136,255,216,255,40,0,120,0,200,0,24,1,204,254,36,255,124,255,212,255,44,0,132,0,220,0,52,1,176,254,16,255,112,255,208,255,48,0,144,0,240,0,80,1,148,254,252,254,100,255,204,255,52,0,156,0,4,1,108,1,120,254,232,254,88,255,200,255,56,0,168,0,24,1,136,1,92,254,212,254,76,255,196,255,60,0,180,0,44,1,164,1,64,254,192,254,64,255,192,255,64,0,192,0,64,1,192,1,8,254,152,254,40,255,184,255,72,0,216,0,104,1,248,1,208,253,112,254,16,255,176,255,80,0,240,0,144,1,48,2,152,253,72,254,248,254,168,255,88,0,8,1,184,1,104,2,96,253,32,254,224,254,160,255,96,0,32,1,224,1,160,2,40,253,248,253,200,254,152,255,104,0,56,1,8,2,216,2,240,252,208,253,176,254,144,255,112,0,80,1,48,2,16,3,184,252,168,253,152,254,136,255,120,0,104,1,88,2,72,3,128,252,128,253,128,254,128,255,128,0,128,1,128,2,128,3,16,252,48,253,80,254,112,255,144,0,176,1,208,2,240,3,160,251,224,252,32,254,96,255,160,0,224,1,32,3,96,4,48,251,144,252,240,253,80,255,176,0,16,2,112,3,208,4,192,250,64,252,192,253,64,255,192,0,64,2,192,3,64,5,80,250,240,251,144,253,48,255,208,0,112,2,16,4,176,5,224,249,160,251,96,253,32,255,224,0,160,2,96,4,32,6,112,249,80,251,48,253,16,255,240,0,208,2,176,4,144,6,0,249,0,251,0,253,0,255,0,1,0,3,0,5,0,7,32,248,96,250,160,252,224,254,32,1,96,3,160,5,224,7,64,247,192,249,64,252,192,254,64,1,192,3,64,6,192,8,96,246,32,249,224,251,160,254,96,1,32,4,224,6,160,9,128,245,128,248,128,251,128,254,128,1,128,4,128,7,128,10,160,244,224,247,32,251,96,254,160,1,224,4,32,8,96,11,192,243,64,247,192,250,64,254,192,1,64,5,192,8,64,12,224,242,160,246,96,250,32,254,224,1,160,5,96,9,32,13,0,242,0,246,0,250,0,254,0,2,0,6,0,10,0,14,64,240,192,244,64,249,192,253,64,2,192,6,64,11,192,15,128,238,128,243,128,248,128,253,128,2,128,7,128,12,128,17,192,236,64,242,192,247,64,253,192,2,64,8,192,13,64,19,0,235,0,241,0,247,0,253,0,3,0,9,0,15,0,21,64,233,192,239,64,246,192,252,64,3,192,9,64,16,192,22,128,231,128,238,128,245,128,252,128,3,128,10,128,17,128,24,192,229,64,237,192,244,64,252,192,3,64,11,192,18,64,26,0,228,0,236,0,244,0,252,0,4,0,12,0,20,0,28,129,224,129,233,128,242,128,251,128,4,128,13,128,22,128,31,1,221,1,231,0,241,0,251,0,5,0,15,0,25,0,35,129,217,129,228,128,239,128,250,128,5,128,16,128,27,128,38,1,214,1,226,0,238,0,250,0,6,0,18,0,30,0,42,129,210,129,223,128,236,128,249,128,6,128,19,128,32,128,45,1,207,1,221,0,235,0,249,0,7,0,21,0,35,0,49,129,203,129,218,128,233,128,248,128,7,128,22,128,37,128,52,1,200,1,216,0,232,0,248,0,8,0,24,0,40,0,56,1,193,1,211,0,229,0,247,0,9,0,27,255,44,255,62,1,186,1,206,0,226,0,246,0,10,0,30,255,49,255,69,1,179,1,201,0,223,0,245,0,11,0,33,255,54,255,76,1,172,1,196,0,220,0,244,0,12,0,36,255,59,255,83,1,165,1,191,0,217,0,243,0,13,0,39,255,64,255,90,1,158,1,186,0,214,0,242,0,14,0,42,255,69,255,97,1,151,1,181,0,211,0,241,0,15,0,45,255,74,255,104,1,144,1,176,0,208,0,240,0,16,0,48,255,79,255,111,64,89,33,0,192,67,38,0,0,1,0,0,64,89,33,0,0,0,0,0,224,127,17,0,0,0,0,0,18,80,1,0,8,0,0,0,0,0,0,0,234,3,0,0,226,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,224,38,0,88,195,39,0,1,0,0,0,18,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,5,0,0,0,0,0,0,0,0,0,0,60,3,0,0,0,0,0,0,90,0,0,0,0,0,0,0,16,202,30,0,16,202,30,0,16,202,30,0,16,202,30,0,16,202,30,0,16,202,30,0,16,202,30,0,64,201,30,0,16,202,30,0,16,202,30,0,116,201,30,0,12,201,30,0,16,202,30,0,168,201,30,0,12,201,30,0,12,201,30,0,220,201,30,0,12,201,30,0,12,201,30,0,12,201,30,0,12,201,30,0,12,201,30,0,12,201,30,0,60,200,30,0,12,201,30,0,12,201,30,0,112,200,30,0,8,200,30,0,12,201,30,0,164,200,30,0,8,200,30,0,8,200,30,0,216,200,30,0,8,200,30,0,8,200,30,0,8,200,30,0,19,17,15,15,13,13,13,13,11,11,11,11,11,11,11,11,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,216,91,33,0,0,69,38,0,208,154,36,0,216,91,33,0,0,0,0,0,98,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,32,131,17,0,0,0,0,0,20,0,0,0,184,8,0,0,120,1,0,0,68,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,231,38,0,216,196,39,0,0,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,176,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,131,17,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,11,0,0,0,0,0,0,96,2,0,0,0,0,0,0,234,1,0,0,0,0,0,0,0,0,0,0,168,90,33,0,88,68,38,0,0,1,0,0,0,0,0,0,0,0,0,0,240,175,23,0,0,0,0,0,0,0,0,0,28,0,0,0,244,2,0,0,172,5,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,228,38,0,192,195,39,0,0,0,0,0,98,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,46,24,0,0,0,0,0,116,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,11,0,0,0,0,0,0,0,0,0,0,178,2,0,0,244,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,103,110,16,40,166,212,32,50,51,12,113,24,136,98,16,25,25,134,56,140,68,48,33,2,86,78,110,97,135,62,115,77,152,12,3,6,156,11,115,230,192,181,24,99,13,57,224,91,2,212,198,25,26,121,140,50,52,36,240,22,129,19,247,255,128,2,0,1,241,128,128,128,160,0,0,3,0,32,0,0,6,80,128,0,0,0,0,1,104,238,49,18,17,0,0,0,0,0,0,0,0,0,0,1,103,122,16,41,182,212,32,42,51,29,199,98,161,8,64,84,102,59,142,197,66,2,16,37,100,44,137,232,133,228,33,75,144,131,6,149,209,6,70,151,32,200,215,67,8,17,194,30,76,145,15,1,64,22,236,7,140,4,4,5,0,0,3,0,1,0,0,3,0,100,132,0,0,0,0,0,0,0,0,1,104,206,49,18,17,0,0,0,0,0,0,0,0,0,0,1,103,122,16,41,182,212,32,34,51,25,198,99,35,33,1,17,152,206,51,25,24,33,2,86,185,61,125,126,79,227,63,17,241,158,8,184,140,84,67,192,120,2,39,226,112,30,48,16,16,20,0,0,3,0,4,0,0,3,0,202,16,0,0,0,0,0,0,0,0,0,0,1,104,206,51,72,208,0,0,0,0,0,0,0,0,0,0,1,103,122,16,41,182,212,32,34,51,25,198,99,35,33,1,17,152,206,51,25,24,33,3,58,70,101,106,101,36,173,233,18,50,20,26,38,52,173,164,65,130,35,1,80,43,26,36,105,72,48,64,46,17,18,8,198,140,4,65,40,76,52,240,30,1,19,242,224,60,96,32,32,40,0,0,3,0,8,0,0,3,1,148,0,0,0,0,1,104,206,51,72,208,0,0,0,0,0,0,0,29,2,188,3,0,3,109,3,69,2,56,2,163,2,38,6,123,2,224,4,184,5,156,2,222,4,71,3,114,5,0,10,106,5,223,3,157,3,175,2,96,2,160,8,29,3,120,4,23,2,64,3,31,3,250,2,93,2,130,4,64,3,98,4,235,3,156,4,175,2,152,4,12,5,133,3,220,2,120,6,177,2,128,3,214,6,224,4,80,3,236,8,174,3,254,3,56,3,192,5,131,2,5,2,253,2,0,2,50,2,24,7,242,5,182,2,34,7,140,10,192,2,12,2,160,2,162,5,245,2,184,8,116,3,39,2,242,4,184,8,239,3,156,6,164,3,234,2,9,3,108,4,54,3,158,3,202,4,3,3,99,2,132,11,62,5,240,3,22,5,82,2,134,4,66,6,124,2,104,4,80,13,142,3,158,5,204,7,102,2,63,2,153,2,167,3,116,2,119,2,168,4,61,3,132,2,158,3,28,4,111,3,220,3,202,4,173,3,208,10,212,10,53,2,64,5,0,9,35,2,116,2,228,2,127,2,20,2,50,4,187,3,184,4,86,2,100,4,136,4,132,3,182,4,131,3,218,4,234,2,21,2,112,2,178,5,4,4,223,2,170,6,78,4,180,2,106,7,250,3,236,3,128,8,220,3,223,2,42,6,14,3,106,6,129,3,4,2,242,2,20,8,190,2,120,6,40,9,50,3,246,5,139,3,140,2,80,2,32,4,140,2,130,2,76,8,136,5,12,3,104,10,226,4,215,2,102,7,215,2,84,4,148,8,145,2,213,3,232,18,152,3,168,6,128,19,214,4,215,3,116,9,141,3,70,4,200,10,167,3,8,4,240,10,100,2,85,3,252,11,64,3,62,2,11,2,4,7,155,3,210,2,124,7,102,5,202,4,6,6,160,3,246,2,245,2,72,2,0,2,110,4,65,2,103,2,252,4,186,2,62,2,8,10,52,9,225,3,168,10,184,13,27,2,122,3,145,3,182,2,160,3,64,4,37,3,88,2,80,5,112,8,183,3,56,12,48,3,182,3,78,2,187,3,79,3,43,3,70,4,115,3,44,2,24,5,120,3,92,2,95,3,146,4,87,3,255,3,229,3,8,4,164,3,204,4,0,5,115,2,52,2,61,2,108,3,132,3,168,5,6,4,89,3,0,7,14,5,185,3,222,6,76,6,86,3,178,6,66,4,142,4,119,2,34,5,178,4,239,2,200,5,137,3,27,3,146,6,248,3,56,2,214,5,154,4,215,3,110,3,101,2,14,2,192,6,166,5,11,3,88,8,68,5,6,3,182,3,137,2,171,3,156,4,191,2,131,3,212,4,15,2,134,4,170,5,135,2,204,3,2,5,135,2,195,2,180,5,151,2,132,2,78,6,60,2,66,2,188,13,198,4,53,3,108,10,217,2,146,6,56,12,73,2,222,5,136,12,221,2,208,3,144,26,103,3,136,5,152,13,231,2,128,5,180,14,131,3,146,4,188,14,120,2,107,3,252,15,220,2,126,2,40,12,241,2,60,10,44,13,177,3,98,7,184,14,201,3,240,8,224,7,47,2,86,3,200,6,217,2,19,3,148,7,174,2,35,2,92,8,123,2,162,2,128,17,248,4,60,3,136,15,80,2,130,6,32,17,109,2,108,5,48,17,33,3,187,3,48,18,10,2,134,2,240,18,113,2,100,6,120,19,79,2,106,3,232,20,23,2,233,3,208,43,170,3,160,4,157,3,208,12,196,5,223,2,44,6,64,4,126,4,40,6,162,2,143,2,15,3,16,2,15,2,4,8,74,5,14,3,168,6,88,7,66,2,142,3,2,4,180,2,114,3,188,5,74,2,171,2,203,2,227,2,97,2,205,2,10,3,5,3,185,2,154,3,17,3,45,3,254,2,139,2,216,3,210,3,84,2,6,4,46,4,245,2,56,4,44,5,175,2,154,4,84,4,96,8,211,3,211,2,214,3,178,2,168,3,188,3,15,2,156,4,234,3,35,2,5,2,26,5,57,3,64,3,160,4,206,3,0,4,189,3,135,3,238,4,66,4,138,3,4,4,208,2,137,2,168,4,167,2,182,2,164,9,200,5,211,3,28,11,90,5,109,3,30,5,67,3,80,3,228,5,71,3,186,2,206,6,6,4,1,3,118,7,84,3,61,2,0,5,91,3,150,4,48,6,95,3,84,4,150,6,196,2,84,5,150,7,0,3,80,4,123,3,24,2,178,2,248,3,48,2,151,2,124,8,102,3,68,5,100,9,231,3,146,4,98,7,198,3,121,3,68,8,144,3,9,3,248,8,252,3,202,2,8,19,52,7,164,3,88,9,10,3,161,3,44,10,4,3,232,2,204,10,189,3,210,2,200,22,252,5,216,3,140,8,7,2,240,4,28,9,20,2,154,3,200,19,227,3,108,9,148,10,59,2,106,3,104,9,33,2,154,2,152,19,60,4,107,3,0,21,215,3,172,4,160,21,211,3,218,2,224,20,122,2,208,6,56,22,194,2,68,5,24,23,209,3,166,4,184,23,137,3,251,2,160,23,70,2,246,5,192,46,245,3,24,7,64,50,169,3,108,7,16,49,62,4,230,3,206,7,172,2,92,7,200,9,121,2,200,7,228,4,55,2,67,3,198,5,59,2,205,3,60,10,1,3,134,5,248,10,184,3,118,4,92,11,200,2,4,4,160,11,174,2,229,2,182,5,40,2,202,2,224,12,223,3,172,5,54,6,103,2,32,2,152,13,126,4,56,3,140,12,64,3,155,3,204,12,71,3,19,2,220,13,18,3,84,3,148,14,252,2,58,2,96,22,138,3,56,10,128,24,36,3,204,8,24,12,23,2,108,3,156,12,86,2,137,2,136,25,247,2,156,5,248,25,225,3,78,3,208,26,55,2,186,4,192,54,244,3,22,5,80,13,36,2,74,4,248,27,240,3,206,6,224,27,232,3,158,4,56,29,8,4,68,3,24,29,100,2,16,6,64,30,102,2,48,3,192,32,9,3,158,5,80,34,182,2,18,3,114,3,228,5,44,4,85,2,69,3,254,2,246,4,186,3,128,5,35,3,38,2,30,3,118,5,28,5,30,3,56,7,254,5,226,2,202,3,163,2,96,2,240,4,194,2,172,2,180,6,255,2,102,4,60,8,253,2,124,5,188,8,156,3,235,3,168,9,24,4,99,2,231,3,174,3,195,3,70,4,89,3,167,3,120,11,158,3,114,4,142,7,234,2,39,2,8,13,121,2,226,6,180,14,189,2,174,5,98,7,52,2,124,2,0,16,102,4,25,3,96,15,44,2,116,4,96,15,28,2,228,2,120,16,252,2,106,3,32,33,48,5,246,3,136,8,3,2,18,4,80,17,166,3,64,5,176,18,177,3,88,4,152,19,38,4,221,2,0,36,252,3,236,7,240,38,156,3,164,4,48,21,141,3,182,4,112,25,232,2,62,4,15,15,15,15,15,16,14,15,14,14,14,14,14,14,14,14,14,13,14,14,13,14,13,14,13,13,13,14,13,13,14,13,13,13,13,13,14,13,12,12,13,13,13,12,13,13,13,13,13,12,13,13,12,12,13,13,13,13,14,14,13,13,13,13,13,13,13,12,12,12,13,13,12,12,12,13,12,12,12,12,12,12,12,11,12,12,12,12,12,12,12,12,12,11,12,12,12,12,12,12,12,12,12,13,13,13,13,14,13,13,13,13,13,13,13,12,12,12,12,13,13,13,13,13,13,13,13,14,13,12,12,11,12,12,11,11,11,11,11,11,11,11,11,11,12,11,11,11,11,11,11,11,11,11,12,12,11,11,11,11,12,12,12,12,11,11,12,12,12,12,12,13,12,12,12,13,12,12,13,12,12,13,13,13,13,13,13,13,13,14,14,14,12,12,11,11,12,12,12,12,11,12,11,12,12,12,12,12,13,13,12,12,13,13,13,14,12,13,13,13,13,13,13,13,11,10,11,10,11,11,10,10,11,11,11,11,10,9,11,10,12,12,11,12,12,12,12,13,11,12,12,12,13,13,12,12,0,0,162,123,53,111,153,92,130,70,234,47,129,27,57,11,0,0,195,249,157,247,56,248,44,250,91,252,28,254,68,255,0,0,171,124,252,114,225,99,196,80,102,59,167,37,87,17,0,0,194,242,53,234,107,230,242,230,240,234,67,241,174,248,0,0,59,6,167,10,231,12,247,12,34,11,238,7,255,3,0,0,137,252,9,250,188,248,172,248,178,249,130,251,189,253,0,0,245,1,91,3,17,4,20,4,124,3,119,2,59,1,0,0,246,254,59,254,225,253,230,253,57,254,195,254,100,255,0,0,130,0,218,0,2,1,253,0,212,0,147,0,72,0,0,0,197,255,155,255,134,255,133,255,150,255,179,255,216,255,0,93,33,0,136,69,38,0,0,1,0,0,0,93,33,0,0,0,0,0,120,94,18,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,34,4,0,0,28,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,236,38,0,32,197,39,0,1,0,0,0,54,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,11,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,209,36,0,32,179,36,0,128,150,36,0,184,122,36,0,53,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,242,38,0,144,197,39,0,1,0,0,0,53,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,2,0,0,0,0,0,0,150,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,93,33,0,192,69,38,0,0,1,0,0,40,155,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,7,0,0,100,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,242,38,0,144,197,39,0,1,0,0,0,53,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,94,18,0,0,0,0,0,220,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,98,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,84,37,0,64,29,37,0,56,251,36,0,64,84,37,0,28,16,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,239,255,239,255,239,255,239,255,227,243,78,245,184,246,216,247,175,248,103,249,1,250,137,250,1,251,110,251,208,251,42,252,125,252,202,252,18,253,86,253,150,253,210,253,11,254,65,254,116,254,165,254,212,254,2,255,45,255,86,255,126,255,165,255,29,12,178,10,72,9,40,8,81,7,153,6,255,5,119,5,255,4,146,4,48,4,214,3,131,3,54,3,238,2,170,2,106,2,46,2,245,1,191,1,140,1,91,1,44,1,254,0,211,0,170,0,130,0,91,0,54,0,17,0,202,255,239,255,0,0,3,246,180,249,159,251,238,252,238,253,189,254,106,255,253,9,76,6,97,4,18,3,18,2,67,1,150,0,0,0,98,252,54,255,158,3,202,0,168,93,33,0,232,69,38,0,0,1,0,0,120,155,36,0,0,0,0,0,0,0,0,0,0,0,0,0,28,16,1,0,0,0,0,0,0,0,0,0,234,5,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,244,38,0,192,197,39,0,0,0,0,0,77,50,71,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,1,0,0,0,0,0,0,0,0,0,0,8,0,0,0,212,3,0,0,0,0,0,0,0,0,0,0,112,244,38,0,208,197,39,0,0,0,0,0,131,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,96,18,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,7,0,0,0,0,0,0,0,0,0,0,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,93,33,0,8,70,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,158,6,0,0,98,3,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,245,38,0,232,197,39,0,0,0,0,0,77,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,8,0,0,0,0,0,0,0,0,0,0,40,0,0,0,30,3,0,0,0,0,0,0,0,0,0,0,208,129,36,0,160,101,35,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,248,117,18,0,0,0,0,0,12,0,0,0,102,1,0,0,196,2,0,0,188,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,95,33,0,128,70,38,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,7,0,0,210,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,231,39,0,8,247,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,238,0,0,0,160,2,0,0,90,3,0,0,200,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,47,37,0,40,110,39,0,0,0,0,0,35,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,230,1,0,0,120,11,0,0,0,0,0,0,0,0,0,0,129,159,88,5,86,195,206,17,191,1,0,170,0,85,89,90,160,118,42,247,10,235,208,17,172,228,0,0,192,204,22,186,214,23,100,15,24,195,208,17,164,63,0,160,201,34,49,150,227,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,111,179,57,103,95,29,194,74,129,146,40,187,14,115,209,106,136,103,33,0,96,72,38,0,232,156,36,0,136,103,33,0,13,16,1,0,22,0,0,0,0,0,0,0,64,4,2,0,56,95,40,0,0,0,0,0,0,0,0,0,40,0,0,0,226,9,0,0,26,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,245,38,0,24,198,39,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,232,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,127,18,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,254,2,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,168,105,33,0,240,72,38,0,0,0,0,0,168,105,33,0,0,0,0,0,224,127,18,0,0,0,0,0,0,0,0,0,96,0,0,0,48,1,0,0,190,2,0,0,188,2,0,0,60,10,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,19,36,0,24,21,35,0,0,0,0,0,22,0,0,0,3,0,0,0,0,0,0,0,200,50,20,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,4,0,0,0,0,0,0,0,0,0,0,114,1,0,0,96,10,0,0,0,0,0,0,0,0,0,0,176,106,33,0,104,73,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,156,1,0,0,232,5,0,0,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,246,38,0,160,198,39,0,0,0,0,0,51,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,4,0,0,0,0,0,0,0,0,0,0,240,2,0,0,200,7,0,0,0,0,0,0,0,0,0,0,176,246,38,0,192,198,39,0,0,0,0,0,87,0,0,0,0,0,0,0,0,0,0,0,32,105,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,0,0,0,0,0,0,154,0,0,0,0,0,0,0,204,4,0,0,0,0,0,0,0,0,0,0,40,248,38,0,16,199,39,0,0,0,0,0,87,0,0,0,2,0,0,0,0,0,0,0,48,105,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,124,4,0,0,0,0,0,0,0,0,0,0,70,2,0,0,72,5,0,0,0,0,0,0,0,0,0,0,72,247,38,0,216,198,39,0,0,0,0,0,132,0,0,0,0,0,0,0,0,0,0,0,40,105,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,130,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,2,0,0,0,0,0,0,184,0,0,0,0,0,0,0,104,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,51,51,0,102,102,102,0,153,153,153,0,204,204,204,0,255,255,255,0,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,0,0,51,51,0,0,102,102,0,0,153,153,0,0,204,204,0,0,255,255,0,51,51,0,0,102,102,0,0,153,153,0,0,204,204,0,0,255,255,0,0,51,0,51,0,102,0,102,0,153,0,153,0,204,0,204,0,255,0,255,0,51,255,255,0,102,255,255,0,153,255,255,0,204,255,255,0,255,51,255,0,255,102,255,0,255,153,255,0,255,204,255,0,255,255,51,0,255,255,102,0,255,255,153,0,255,255,204,0,51,204,204,0,102,204,204,0,153,204,204,0,255,204,204,0,204,51,204,0,204,102,204,0,204,153,204,0,204,255,204,0,204,204,51,0,204,204,102,0,204,204,153,0,204,204,255,0,51,153,153,0,102,153,153,0,204,153,153,0,255,153,153,0,153,51,153,0,153,102,153,0,153,204,153,0,153,255,153,0,153,153,51,0,153,153,102,0,153,153,204,0,153,153,255,0,51,102,102,0,153,102,102,0,204,102,102,0,255,102,102,0,102,51,102,0,102,153,102,0,102,204,102,0,102,255,102,0,102,102,51,0,102,102,153,0,102,102,204,0,102,102,255,0,102,51,51,0,153,51,51,0,204,51,51,0,255,51,51,0,51,102,51,0,51,153,51,0,51,204,51,0,51,255,51,0,51,51,102,0,51,51,153,0,51,51,204,0,51,51,255,0,102,51,0,0,0,102,51,0,51,0,102,0,51,102,0,0,102,0,51,0,0,51,102,0,153,102,51,0,51,153,102,0,102,51,153,0,102,153,51,0,153,51,102,0,51,102,153,0,204,153,102,0,102,204,153,0,153,102,204,0,153,204,102,0,204,102,153,0,102,153,204,0,255,204,153,0,153,255,204,0,204,153,255,0,204,255,153,0,255,153,204,0,153,204,255,0,17,17,17,0,34,34,34,0,68], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1378161);
/* memory initializer */ allocate([68,68,0,85,85,85,0,170,170,170,0,187,187,187,0,221,221,221,0,238,238,238,0,112,113,37,0,120,20,36,0,0,0,0,0,132,0,0,0,2,0,0,0,0,0,0,0,176,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,70,2,0,0,146,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,88,1,0,16,177,2,0,0,238,2,0,64,31,0,0,128,62,0,0,34,86,0,0,192,93,0,0,0,125,0,0,68,172,0,0,128,187,0,0,0,119,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,0,0,98,6,0,0,12,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,109,33,0,40,74,38,0,80,158,36,0,248,109,33,0,12,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,88,129,18,0,0,0,0,0,8,0,0,0,4,4,0,0,202,1,0,0,180,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,38,0,136,199,39,0,1,0,0,0,12,80,1,0,96,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,56,105,40,0,0,0,0,0,0,0,0,0,136,129,18,0,0,0,0,0,168,42,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,10,0,0,0,0,0,0,32,3,0,0,0,0,0,0,122,7,0,0,0,0,0,0,0,0,0,0,64,110,33,0,96,74,38,0,0,1,0,0,64,110,33,0,0,0,0,0,0,0,0,0,0,0,0,0,12,80,1,0,0,0,0,0,204,9,0,0,122,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,253,38,0,176,199,39,0,1,0,0,0,12,80,1,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,105,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,2,0,0,0,0,0,0,0,0,0,0,148,1,0,0,216,0,0,0,0,0,0,0,0,0,0,0,56,127,32,0,5,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,64,2,0,0,128,4,0,0,0,9,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,111,33,0,184,74,38,0,0,0,0,0,152,158,36,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,162,2,0,0,70,2,0,0,242,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,111,33,0,24,75,38,0,0,0,0,0,160,158,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,2,0,0,190,3,0,0,0,0,0,0,138,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,112,33,0,26,0,0,0,0,0,0,0,84,0,0,0,178,0,0,0,242,1,0,0,130,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,4,0,0,0,0,0,0,0,0,0,0,16,0,0,0,160,216,18,0,0,0,0,0,210,1,0,0,0,0,0,0,136,255,38,0,80,200,39,0,0,0,0,0,176,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,7,0,0,0,0,0,0,0,0,0,0,122,1,0,0,126,3,0,0,0,0,0,0,0,0,0,0,176,255,38,0,96,200,39,0,1,0,0,0,83,87,70,70,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,5,0,0,0,0,0,0,0,0,0,0,24,3,0,0,28,10,0,0,0,0,0,0,0,0,0,0,184,106,37,0,176,13,36,0,0,0,0,0,68,0,0,0,0,16,0,64,0,0,0,0,248,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,5,0,0,0,0,0,0,114,2,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,200,106,37,0,224,13,36,0,0,0,0,0,68,0,0,0,3,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,38,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,6,0,0,0,0,0,0,0,0,0,0,184,1,0,0,128,10,0,0,0,0,0,0,0,0,0,0,88,1,39,0,136,200,39,0,0,0,0,0,34,0,0,0,32,32,0,0,0,0,0,0,96,105,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,228,18,0,0,0,0,0,136,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,227,18,0,0,0,0,0,68,5,0,0,0,0,0,0,110,2,0,0,0,0,0,0,248,3,0,0,0,0,0,0,0,0,0,0,96,3,39,0,40,201,39,0,0,0,0,0,34,0,0,0,2,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,10,0,0,0,0,0,0,0,0,0,0,224,1,0,0,134,2,0,0,0,0,0,0,0,0,0,0,192,113,33,0,56,76,38,0,0,0,0,0,216,158,36,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,11,0,0,168,3,0,0,184,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,114,33,0,16,77,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,6,0,0,128,11,0,0,190,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,115,33,0,96,77,38,0,0,0,0,0,104,115,33,0,0,80,1,0,1,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,80,16,0,0,40,8,0,0,230,3,0,0,86,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,115,33,0,232,77,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,16,0,0,134,1,0,0,12,3,0,0,14,4,0,0,90,2,0,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,3,4,8,9,13,14,18,19,23,24,28,29,33,34,38,39,43,44,48,49,53,54,58,59,63,64,68,69,73,74,78,79,0,2,5,4,12,10,7,9,25,24,20,22,14,15,19,17,36,31,21,26,1,6,16,11,27,29,32,30,39,37,34,35,1,3,8,6,18,16,11,13,38,36,31,33,21,23,28,26,184,72,36,0,216,50,36,0,184,1,36,0,184,72,36,0,2,80,1,0,28,0,0,0,0,0,0,0,64,0,1,0,248,97,40,0,200,181,22,0,0,0,0,0,128,0,0,0,20,5,0,0,70,3,0,0,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,7,39,0,152,201,39,0,0,0,0,0,82,88,69,48,2,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,186,22,0,0,0,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,2,0,0,188,7,0,0,0,0,0,0,0,0,0,0,16,8,39,0,168,201,39,0,1,0,0,0,99,118,101,115,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,0,0,0,0,0,0,0,0,0,0,0,134,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,8,39,0,232,201,39,0,0,0,0,0,48,51,49,69,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,7,0,0,0,0,0,0,0,0,0,0,154,1,0,0,172,6,0,0,0,0,0,0,0,0,0,0,200,8,39,0,248,201,39,0,0,0,0,0,116,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,0,0,0,0,0,0,0,0,0,0,0,54,1,0,0,88,3,0,0,0,0,0,0,0,0,0,0,160,116,33,0,48,78,38,0,0,1,0,0,232,159,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,9,0,0,232,10,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,0,25,0,32,0,41,0,51,0,65,0,81,0,103,0,129,0,163,0,205,0,3,1,70,1,154,1,4,2,138,2,51,3,7,4,18,5,98,6,9,8,30,10,189,12,9,16,48,20,107,25,0,32,73,40,183,50,217,63,112,44,37,0,24,109,39,0,1,0,0,0,56,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,8,0,0,0,0,0,0,0,0,0,0,68,1,0,0,54,2,0,0,0,0,0,0,0,0,0,0,24,55,37,0,136,226,35,0,1,0,0,0,55,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,8,0,0,0,0,0,0,0,0,0,0,68,1,0,0,54,2,0,0,0,0,0,0,0,0,0,0,184,44,37,0,40,109,39,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,3,0,0,0,0,0,0,0,0,0,0,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,170,0,0,255,0,170,0,255,170,170,0,255,0,0,170,255,170,0,170,255,0,170,170,255,170,170,170,255,85,0,0,255,255,0,0,255,85,170,0,255,255,170,0,255,85,0,170,255,255,0,170,255,85,170,170,255,255,170,170,255,0,85,0,255,170,85,0,255,0,255,0,255,170,255,0,255,0,85,170,255,170,85,170,255,0,255,170,255,170,255,170,255,85,85,0,255,255,85,0,255,85,255,0,255,255,255,0,255,85,85,170,255,255,85,170,255,85,255,170,255,255,255,170,255,0,0,85,255,170,0,85,255,0,170,85,255,170,170,85,255,0,0,255,255,170,0,255,255,0,170,255,255,170,170,255,255,85,0,85,255,255,0,85,255,85,170,85,255,255,170,85,255,85,0,255,255,255,0,255,255,85,170,255,255,255,170,255,255,0,85,85,255,170,85,85,255,0,255,85,255,170,255,85,255,0,85,255,255,170,85,255,255,0,255,255,255,170,255,255,255,85,85,85,255,255,85,85,255,85,255,85,255,255,255,85,255,85,85,255,255,255,85,255,255,85,255,255,255,255,255,255,255,32,9,39,0,8,202,39,0,0,0,0,0,123,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,9,0,0,0,0,0,0,0,0,0,0,196,0,0,0,48,9,0,0,0,0,0,0,0,0,0,0,96,9,39,0,64,202,39,0,0,0,0,0,121,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,10,0,0,0,0,0,0,0,0,0,0,190,1,0,0,32,2,0,0,0,0,0,0,0,0,0,0,152,9,39,0,96,202,39,0,0,0,0,0,122,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,0,0,0,0,0,0,0,0,0,0,0,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,9,39,0,128,202,39,0,0,0,0,0,130,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,11,0,0,0,0,0,0,0,0,0,0,92,2,0,0,88,11,0,0,0,0,0,0,0,0,0,0,216,9,39,0,192,202,39,0,0,0,0,0,119,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,8,0,0,0,0,0,0,0,0,0,0,82,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,128,112,116,63,165,102,105,63,103,220,94,63,165,102,105,63,2,204,84,63,0,3,66,63,103,220,94,63,0,3,66,63,163,229,40,63,2,204,84,63,133,226,48,63,140,8,19,63,245,47,75,63,24,69,33,63,0,0,0,63,0,3,66,63,140,8,19,63,103,220,222,62,30,64,57,63,188,13,6,63,0,3,194,62,133,226,48,63,128,112,244,62,163,229,168,62,163,229,40,63,103,220,222,62,140,8,147,62,24,69,33,63,245,47,203,62,0,0,128,62,185,252,25,63,30,64,185,62,103,220,94,62,140,8,19,63,163,229,168,62,0,3,66,62,195,100,12,63,185,252,153,62,163,229,40,62,188,13,6,63,195,100,140,62,140,8,19,62,0,0,0,63,0,0,128,62,0,0,0,62,128,112,244,62,165,102,105,62,103,220,222,61,165,102,233,62,2,204,84,62,0,3,194,61,103,220,222,62,0,3,66,62,163,229,168,61,2,204,212,62,133,226,48,62,140,8,147,61,245,47,203,62,24,69,33,62,0,0,128,61,0,3,194,62,140,8,19,62,103,220,94,61,30,64,185,62,188,13,6,62,0,3,66,61,133,226,176,62,128,112,244,61,163,229,40,61,163,229,168,62,103,220,222,61,140,8,19,61,24,69,161,62,245,47,203,61,0,0,0,61,185,252,153,62,30,64,185,61,103,220,222,60,140,8,147,62,163,229,168,61,0,3,194,60,195,100,140,62,185,252,153,61,163,229,168,60,188,13,134,62,195,100,140,61,140,8,147,60,0,0,128,62,0,0,128,61,0,0,128,60,128,112,116,62,165,102,105,61,103,220,94,60,165,102,105,62,2,204,84,61,0,3,66,60,248,218,37,0,240,178,37,0,208,148,37,0,248,218,37,0,41,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,21,3,0,152,21,3,0,216,20,3,0,88,19,3,0,88,13,3,0,88,1,3,0,88,233,2,0,0,1,2,3,4,5,6,7,8,8,8,8,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,17,17,17,17,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,19,171,234,110,251,73,210,205,236,137,200,50,230,33,196,12,227,8,194,131,225,2,193,193,224,129,192,96,224,64,192,48,224,32,192,24,224,0,0,0,0,85,213,183,237,37,201,102,230,68,196,25,227,17,194,134,225,4,193,194,224,129,192,96,224,64,192,48,224,32,192,24,224,16,192,12,224,0,0,0,0,73,18,137,8,33,4,8,2,2,1,129,0,64,0,32,0,16,0,8,0,2,0,0,0,1,0,0,0,0,0,1,0,0,0,0,3,1,0,0,0,2,0,1,0,0,0,3,3,2,0,0,2,0,0,2,0,0,2,0,3,2,0,0,3,2,0,2,0,0,3,3,3,2,0,1,0,0,0,2,0,2,0,0,3,2,0,2,0,2,0,2,0,2,0,3,3,2,0,3,2,0,0,2,0,3,2,0,3,2,0,3,3,2,0,2,0,3,3,3,3,3,1,0,0,0,0,3,1,0,0,0,3,3,2,0,0,2,0,3,2,0,0,3,3,3,2,0,2,0,0,3,2,0,2,0,3,3,2,0,3,2,0,3,2,0,3,3,3,3,3,1,0,0,0,3,3,2,0,0,3,3,3,2,0,2,0,3,3,2,0,3,3,3,3,3,2,0,0,3,3,3,2,0,3,3,3,3,3,2,0,3,3,3,3,3,3,216,13,39,0,104,203,39,0,1,0,0,0,41,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,105,40,0,8,12,22,0,0,0,0,0,216,30,23,0,0,0,0,0,160,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,16,32,0,0,0,0,0,60,11,0,0,0,0,0,0,26,3,0,0,0,0,0,0,2,6,0,0,0,0,0,0,0,0,0,0,160,139,37,0,88,41,36,0,0,1,0,0,160,139,37,0,0,0,0,0,0,0,0,0,0,0,0,0,41,80,1,0,0,0,0,0,184,4,0,0,148,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,1,1,1,1,0,0,0,0,0,0,56,54,37,0,32,225,35,0,1,0,0,0,41,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,96,40,0,0,0,0,0,0,0,0,0,8,31,23,0,0,0,0,0,32,211,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,1,0,0,0,0,0,0,0,0,0,0,174,0,0,0,92,9,0,0,0,0,0,0,0,0,0,0,0,2,3,4,5,7,8,9,3,4,5,6,7,8,9,10,11,12,14,16,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,120,33,0,112,79,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,0,106,9,0,0,152,11,0,0,184,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,121,33,0,200,79,38,0,0,0,0,0,136,160,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,18,9,0,0,236,9,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,14,39,0,128,203,39,0,0,0,0,0,157,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,122,33,0,80,80,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,2,3,0,0,100,11,0,0,62,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,15,39,0,136,203,39,0,0,0,0,0,99,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,5,0,0,0,0,0,0,0,0,0,0,54,3,0,0,60,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,16,39,0,168,203,39,0,0,0,0,0,25,0,0,0,0,32,0,0,0,0,0,0,248,105,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,128,0,0,0,0,0,0,0,230,7,0,0,0,0,0,0,0,0,0,0,144,19,39,0,40,204,39,0,0,0,0,0,25,0,0,0,2,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,10,0,0,0,0,0,0,0,0,0,0,162,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,17,39,0,192,203,39,0,3,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,10,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,19,39,0,216,203,39,0,3,0,0,0,0,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,33,23,0,0,0,0,0,88,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,166,3,0,0,0,0,0,0,0,0,0,0,206,2,0,0,134,7,0,0,0,0,0,0,0,0,0,0,120,20,39,0,120,204,39,0,3,0,0,0,1,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,20,39,0,104,204,39,0,3,0,0,0,1,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,6,0,0,0,0,0,0,0,0,0,0,172,2,0,0,240,7,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,1,0,0,3,4,0,0,5,6,2,1,1,0,0,0,7,8,9,10,3,4,2,1,1,1,0,0,0,0,0,0,11,12,13,14,5,6,3,4,2,2,1,0,0,0,0,0,5,3,3,2,1,1,1,0,1,6,4,3,1,1,1,2,3,4,5,7,8,9,10,7,8,4,3,2,2,2,2,2,1,1,1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,1,2,1,3,4,1,2,5,6,1,1,7,8,1,1,2,3,4,9,10,11,1,1,1,1,2,2,3,5,6,7,12,13,14,15,16,17,1,1,1,1,2,2,3,3,4,5,8,18,19,20,21,22,3,4,5,6,9,10,11,0,0,3,4,6,12,13,14,0,0,0,0,2,2,2,2,3,3,5,7,7,8,9,10,11,15,16,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,0,0,0,0,0,0,0,0,2,3,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,4,0,0,0,0,0,0,0,0,0,2,0,7,0,8,0,9,0,20,0,21,0,22,0,23,0,48,0,49,0,50,0,51,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,224,0,225,0,226,0,227,0,228,0,229,0,230,0,231,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,239,0,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,224,3,225,3,226,3,227,3,228,3,229,3,230,3,206,7,207,7,208,7,209,7,210,7,211,7,212,7,213,7,172,15,173,15,174,15,175,15,176,15,177,15,178,15,179,15,180,15,181,15,182,15,183,15,184,15,185,15,186,15,187,15,188,15,189,15,190,15,191,15,128,31,129,31,130,31,131,31,132,31,133,31,134,31,135,31,136,31,137,31,138,31,139,31,140,31,141,31,142,31,143,31,144,31,145,31,146,31,147,31,148,31,149,31,150,31,151,31,152,31,153,31,154,31,155,31,156,31,157,31,158,31,159,31,160,31,161,31,162,31,163,31,164,31,165,31,166,31,167,31,168,31,169,31,170,31,171,31,172,31,173,31,174,31,175,31,176,31,177,31,178,31,179,31,180,31,181,31,182,31,183,31,184,31,185,31,186,31,187,31,188,31,189,31,190,31,191,31,0,127,1,127,2,127,3,127,4,127,5,127,6,127,7,127,8,127,9,127,10,127,11,127,12,127,13,127,14,127,15,127,16,127,17,127,18,127,19,127,20,127,21,127,22,127,23,127,24,127,25,127,26,127,27,127,28,127,29,127,30,127,31,127,32,127,33,127,34,127,35,127,36,127,37,127,38,127,39,127,40,127,41,127,42,127,43,127,44,127,45,127,46,127,47,127,48,127,49,127,50,127,51,127,52,127,53,127,54,127,55,127,56,127,57,127,58,127,59,127,60,127,61,127,62,127,63,127,64,127,65,127,66,127,67,127,68,127,69,127,70,127,71,127,72,127,73,127,74,127,75,127,76,127,77,127,78,127,79,127,80,127,81,127,82,127,83,127,84,127,85,127,86,127,87,127,88,127,89,127,90,127,91,127,92,127,93,127,94,127,95,127,96,127,97,127,98,127,99,127,100,127,101,127,102,127,103,127,104,127,105,127,106,127,107,127,108,127,109,127,110,127,111,127,112,127,113,127,114,127,115,127,116,127,117,127,118,127,119,127,120,127,121,127,122,127,123,127,124,127,125,127,126,127,127,127,128,127,129,127,130,127,131,127,132,127,133,127,134,127,135,127,136,127,137,127,138,127,139,127,140,127,141,127,142,127,143,127,144,127,145,127,146,127,147,127,148,127,149,127,150,127,151,127,152,127,153,127,154,127,155,127,156,127,157,127,158,127,159,127,160,127,161,127,162,127,163,127,164,127,165,127,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,197,127,198,127,199,127,200,127,201,127,202,127,203,127,204,127,205,127,206,127,207,127,208,127,209,127,210,127,211,127,212,127,213,127,214,127,215,127,216,127,217,127,218,127,219,127,220,127,221,127,222,127,223,127,224,127,225,127,226,127,227,127,228,127,229,127,230,127,231,127,232,127,233,127,234,127,235,127,236,127,237,127,238,127,239,127,240,127,241,127,242,127,243,127,244,127,245,127,246,127,247,127,248,127,249,127,250,127,251,127,252,127,253,127,254,127,255,127,6,0,0,0,0,0,0,0,3,3,4,4,3,3,4,4,2,3,3,4,2,3,3,4,2,2,3,3,2,2,3,3,1,2,2,3,1,2,2,3,1,1,2,2,1,1,2,2,0,1,1,2,0,1,1,2,0,0,1,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,0,1,0,0,0,0,200,122,33,0,168,80,38,0,0,0,0,0,200,122,33,0,0,0,1,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,202,8,0,30,5,0,0,24,3,0,0,108,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,65,0,0,70,65,0,0,71,69,0,0,119,66,0,0,71,69,0,0,21,71,0,0,159,70,0,0,159,70,0,0,21,71,0,0,37,73,0,0,127,72,0,0,252,74,0,0,127,72,0,0,37,73,0,0,84,75,0,0,164,74,0,0,236,76,0,0,236,76,0,0,164,74,0,0,84,75,0,0,152,83,0,0,189,76,0,0,38,79,0,0,246,78,0,0,38,79,0,0,189,76,0,0,152,83,0,0,205,88,0,0,85,85,0,0,131,81,0,0,79,81,0,0,79,81,0,0,131,81,0,0,85,85,0,0,205,88,0,0,133,90,0,0,133,90,0,0,152,83,0,0,152,83,0,0,152,83,0,0,133,90,0,0,133,90,0,0,24,96,0,0,212,92,0,0,1,86,0,0,1,86,0,0,212,92,0,0,24,96,0,0,179,98,0,0,137,95,0,0,144,88,0,0,137,95,0,0,179,98,0,0,115,101,0,0,103,98,0,0,103,98,0,0,115,101,0,0,91,104,0,0,58,109,0,0,91,104,0,0,202,115,0,0,202,115,0,0,48,123,0,0,128,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,42,0,0,0,38,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,38,0,0,0,42,0,0,0,44,0,0,0,43,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,43,0,0,0,44,0,0,0,68,0,0,0,68,0,0,0,63,0,0,0,63,0,0,0,63,0,0,0,68,0,0,0,68,0,0,0,96,0,0,0,92,0,0,0,86,0,0,0,86,0,0,0,92,0,0,0,96,0,0,0,98,0,0,0,96,0,0,0,88,0,0,0,96,0,0,0,98,0,0,0,202,0,0,0,196,0,0,0,196,0,0,0,202,0,0,0,208,0,0,0,218,0,0,0,208,0,0,0,232,0,0,0,232,0,0,0,246,0,0,0,128,0,0,0,24,0,0,0,24,0,0,0,26,0,0,0,26,0,0,0,26,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,38,0,0,0,36,0,0,0,36,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,84,0,0,0,76,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,76,0,0,0,84,0,0,0,88,0,0,0,86,0,0,0,82,0,0,0,82,0,0,0,82,0,0,0,82,0,0,0,86,0,0,0,88,0,0,0,182,0,0,0,182,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,182,0,0,0,182,0,0,0,192,0,0,0,186,0,0,0,192,0,0,0,172,0,0,0,186,0,0,0,192,0,0,0,138,1,0,0,126,1,0,0,98,1,0,0,126,1,0,0,138,1,0,0,150,1,0,0,138,1,0,0,138,1,0,0,150,1,0,0,162,1,0,0,182,1,0,0,162,1,0,0,208,1,0,0,208,1,0,0,236,1,0,0,0,128,0,0,71,69,0,0,70,65,0,0,159,70,0,0,37,73,0,0,152,83,0,0,71,69,0,0,252,74,0,0,164,74,0,0,85,85,0,0,0,64,0,0,71,69,0,0,37,73,0,0,152,83,0,0,70,65,0,0,159,70,0,0,38,79,0,0,133,90,0,0,21,71,0,0,236,76,0,0,37,73,0,0,38,79,0,0,79,81,0,0,212,92,0,0,71,69,0,0,252,74,0,0,164,74,0,0,85,85,0,0,38,79,0,0,133,90,0,0,21,71,0,0,236,76,0,0,152,83,0,0,137,95,0,0,84,75,0,0,131,81,0,0,152,83,0,0,133,90,0,0,1,86,0,0,103,98,0,0,37,73,0,0,38,79,0,0,79,81,0,0,212,92,0,0,152,83,0,0,137,95,0,0,84,75,0,0,131,81,0,0,137,95,0,0,58,109,0,0,205,88,0,0,24,96,0,0,115,101,0,0,202,115,0,0,152,83,0,0,133,90,0,0,1,86,0,0,103,98,0,0,137,95,0,0,58,109,0,0,205,88,0,0,24,96,0,0,115,101,0,0,202,115,0,0,128,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,42,0,0,0,38,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,38,0,0,0,42,0,0,0,44,0,0,0,43,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,45,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,45,0,0,0,45,0,0,0,48,0,0,0,46,0,0,0,43,0,0,0,43,0,0,0,46,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,44,0,0,0,48,0,0,0,49,0,0,0,101,0,0,0,98,0,0,0,98,0,0,0,101,0,0,0,104,0,0,0,109,0,0,0,104,0,0,0,116,0,0,0,116,0,0,0,123,0,0,0,128,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,25,0,0,0,25,0,0,0,25,0,0,0,25,0,0,0,26,0,0,0,25,0,0,0,26,0,0,0,25,0,0,0,26,0,0,0,26,0,0,0,26,0,0,0,27,0,0,0,27,0,0,0,26,0,0,0,26,0,0,0,42,0,0,0,38,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,38,0,0,0,42,0,0,0,44,0,0,0,43,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,41,0,0,0,43,0,0,0,44,0,0,0,91,0,0,0,91,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,91,0,0,0,91,0,0,0,96,0,0,0,93,0,0,0,86,0,0,0,86,0,0,0,93,0,0,0,96,0,0,0,197,0,0,0,191,0,0,0,177,0,0,0,191,0,0,0,197,0,0,0,203,0,0,0,197,0,0,0,197,0,0,0,203,0,0,0,209,0,0,0,219,0,0,0,209,0,0,0,232,0,0,0,232,0,0,0,246,0,0,0,184,81,38,0,96,161,36,0,0,0,0,0,184,126,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,202,8,0,252,2,0,0,136,7,0,0,170,0,0,0,242,0,0,0,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,124,33,0,40,82,38,0,0,1,0,0,144,124,33,0,0,0,0,0,0,0,0,0,0,0,0,0,4,80,1,0,8,0,0,0,220,7,0,0,154,7,0,0,68,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,115,38,0,160,59,38,0,64,5,38,0,192,115,38,0,4,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,124,33,0,72,82,38,0,0,1,0,0,216,124,33,0,0,0,0,0,0,0,0,0,0,0,0,0,4,80,1,0,0,0,0,0,24,8,0,0,148,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,23,39,0,208,204,39,0,0,0,0,0,95,0,0,0,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1388401);
/* memory initializer */ allocate([24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,6,0,0,0,0,0,0,0,0,0,0,234,1,0,0,64,9,0,0,0,0,0,0,0,0,0,0,152,117,37,0,32,24,36,0,1,0,0,0,26,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,6,0,0,0,0,0,0,0,0,0,0,116,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,124,33,0,112,82,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,0,0,140,8,0,0,98,9,0,0,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,25,39,0,0,205,39,0,0,0,0,0,129,0,0,0,0,0,0,0,0,0,0,0,8,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,8,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,26,39,0,64,205,39,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,247,38,0,0,178,38,0,0,0,0,0,208,247,38,0,0,0,0,0,100,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,28,39,0,224,205,39,0,0,0,0,0,100,0,0,0,0,32,0,0,0,0,0,0,72,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,51,23,0,0,0,0,0,96,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,51,23,0,0,0,0,0,66,2,0,0,0,0,0,0,104,0,0,0,0,0,0,0,104,11,0,0,0,0,0,0,0,0,0,0,48,126,33,0,0,83,38,0,0,1,0,0,0,0,0,0,0,0,0,0,16,51,23,0,0,0,0,0,100,0,0,0,20,0,0,0,34,3,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,29,39,0,64,206,39,0,0,0,0,0,100,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,7,0,0,0,0,0,0,0,0,0,0,24,2,0,0,88,10,0,0,0,0,0,0,0,0,0,0,211,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,0,14,0,0,0,14,0,6,0,0,0,10,0,0,0,4,0,0,0,80,85,23,0,144,85,23,0,16,86,23,0,32,86,23,0,64,88,23,0,72,90,23,0,48,86,23,0,56,87,23,0,80,91,23,0,208,91,23,0,208,85,23,0,175,0,0,0,185,0,0,0,109,1,0,0,184,1,0,0,0,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,0,0,0,0,0,0,0,0,213,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,64,9,0,0,64,9,0,4,0,0,0,8,0,0,0,3,0,0,0,144,79,23,0,240,79,23,0,208,79,23,0,224,79,23,0,64,82,23,0,72,84,23,0,48,80,23,0,56,81,23,0,144,78,23,0,16,79,23,0,80,79,23,0,115,0,0,0,120,0,0,0,145,0,0,0,240,0,0,0,34,1,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,214,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,0,14,0,0,0,14,0,4,0,0,0,8,0,0,0,4,0,0,0,208,72,23,0,48,73,23,0,16,73,23,0,32,73,23,0,128,75,23,0,136,77,23,0,112,73,23,0,120,74,23,0,80,91,23,0,208,91,23,0,144,72,23,0,175,0,0,0,185,0,0,0,220,0,0,0,109,1,0,0,184,1,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,217,4,0,0,128,7,0,0,56,4,0,0,1,0,0,0,0,0,14,0,0,0,7,0,6,0,0,0,10,0,0,0,4,0,0,0,16,72,23,0,80,72,23,0,16,86,23,0,32,86,23,0,64,88,23,0,72,90,23,0,48,86,23,0,56,87,23,0,80,91,23,0,208,91,23,0,208,85,23,0,185,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,4,0,0,128,7,0,0,56,4,0,0,1,0,0,0,0,64,9,0,0,160,4,0,4,0,0,0,8,0,0,0,3,0,0,0,144,71,23,0,208,71,23,0,208,79,23,0,224,79,23,0,64,82,23,0,72,84,23,0,48,80,23,0,56,81,23,0,144,78,23,0,16,79,23,0,80,79,23,0,120,0,0,0,145,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,219,4,0,0,128,7,0,0,56,4,0,0,1,0,0,0,0,0,14,0,0,0,7,0,4,0,0,0,8,0,0,0,4,0,0,0,16,71,23,0,80,71,23,0,16,73,23,0,32,73,23,0,128,75,23,0,136,77,23,0,112,73,23,0,120,74,23,0,80,91,23,0,208,91,23,0,144,72,23,0,185,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,4,0,0,0,5,0,0,208,2,0,0,0,0,0,0,0,0,7,0,0,0,7,0,6,0,0,0,10,0,0,0,4,0,0,0,80,65,23,0,176,65,23,0,144,65,23,0,160,65,23,0,0,68,23,0,8,70,23,0,240,65,23,0,248,66,23,0,80,64,23,0,208,64,23,0,16,65,23,0,90,0,0,0,90,0,0,0,180,0,0,0,220,0,0,0,0,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,0,0,0,0,0,0,0,0,227,4,0,0,0,5,0,0,208,2,0,0,0,0,0,0,0,0,7,0,0,0,7,0,4,0,0,0,8,0,0,0,4,0,0,0,144,58,23,0,240,58,23,0,208,58,23,0,224,58,23,0,64,61,23,0,72,63,23,0,48,59,23,0,56,60,23,0,144,57,23,0,16,58,23,0,80,58,23,0,90,0,0,0,90,0,0,0,110,0,0,0,180,0,0,0,220,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,228,4,0,0,0,5,0,0,208,2,0,0,0,0,0,0,0,160,4,0,0,160,4,0,4,0,0,0,8,0,0,0,5,0,0,0,208,51,23,0,48,52,23,0,16,52,23,0,32,52,23,0,128,54,23,0,136,56,23,0,112,52,23,0,120,53,23,0,144,57,23,0,16,58,23,0,80,58,23,0,60,0,0,0,60,0,0,0,75,0,0,0,120,0,0,0,145,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,229,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,224,2,0,0,224,2,0,4,0,0,0,8,0,0,0,3,0,0,0,144,79,23,0,240,79,23,0,208,79,23,0,224,79,23,0,64,82,23,0,72,84,23,0,48,80,23,0,56,81,23,0,144,78,23,0,16,79,23,0,80,79,23,0,36,0,0,0,36,0,0,0,45,0,0,0,75,0,0,0,90,0,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,232,4,0,0,128,7,0,0,56,4,0,0,0,0,0,0,0,0,28,0,0,0,28,0,6,0,0,0,10,0,0,0,4,0,0,0,80,85,23,0,144,51,23,0,16,86,23,0,32,86,23,0,64,88,23,0,72,90,23,0,48,86,23,0,56,87,23,0,80,91,23,0,208,91,23,0,208,85,23,0,94,1,0,0,134,1,0,0,184,1,0,0,218,2,0,0,112,3,0,0,192,93,0,0,233,3,0,0,25,0,0,0,1,0,0,0,48,117,0,0,233,3,0,0,50,0,0,0,1,0,0,0,96,234,0,0,233,3,0,0,0,0,0,0,0,55,14,68,3,58,17,72,37,18,50,32,40,22,54,35,9,64,5,59,13,67,8,63,46,27,41,23,49,31,44,26,2,57,16,71,1,56,15,70,39,21,52,34,38,19,51,33,11,66,7,62,10,65,6,60,48,30,43,25,47,29,42,24,0,55,14,68,3,58,17,72,17,9,23,15,16,8,22,14,5,29,3,27,4,28,2,26,21,13,19,11,20,12,18,10,0,24,6,30,1,25,7,31,16,8,22,14,17,9,23,15,4,28,2,26,5,29,3,27,20,12,18,10,21,13,19,11,1,25,7,31,0,24,6,30,17,9,23,15,16,8,22,14,117,62,158,103,113,58,155,100,34,199,21,186,31,196,17,182,144,89,131,76,141,86,127,72,0,165,41,206,10,175,52,217,110,55,151,96,120,65,162,107,28,193,14,179,38,203,24,189,138,83,124,69,148,93,134,79,7,172,48,213,3,168,45,210,117,62,158,103,113,58,155,100,36,68,60,92,34,66,58,90,100,4,124,28,98,2,122,26,52,84,44,76,50,82,42,74,116,20,108,12,114,18,106,10,32,64,56,88,38,70,62,94,96,0,120,24,102,6,126,30,48,80,40,72,54,86,46,78,112,16,104,8,118,22,110,14,36,68,60,92,34,66,58,90,8,4,11,7,8,4,11,7,2,14,1,13,2,14,1,13,10,6,9,5,10,6,9,5,0,12,3,15,0,12,3,15,8,4,11,7,8,4,11,7,6,2,6,2,6,2,6,2,0,4,0,4,0,4,0,4,6,2,6,2,6,2,6,2,1,3,1,3,1,3,1,3,2,0,2,0,2,0,2,0,1,3,1,3,1,3,1,3,0,0,2,0,5,0,8,0,11,0,15,0,20,0,24,0,29,0,35,0,41,0,47,0,53,0,60,0,67,0,74,0,82,0,89,0,97,0,106,0,114,0,123,0,132,0,141,0,150,0,160,0,170,0,180,0,190,0,201,0,211,0,222,0,233,0,244,0,0,1,11,1,23,1,35,1,47,1,59,1,71,1,84,1,97,1,110,1,123,1,136,1,149,1,163,1,177,1,191,1,205,1,219,1,233,1,248,1,6,2,21,2,36,2,51,2,66,2,81,2,97,2,112,2,128,2,144,2,160,2,176,2,193,2,209,2,226,2,242,2,3,3,20,3,37,3,54,3,72,3,89,3,107,3,124,3,142,3,160,3,178,3,196,3,215,3,233,3,252,3,14,4,33,4,52,4,71,4,90,4,109,4,129,4,148,4,168,4,187,4,207,4,227,4,247,4,11,5,31,5,52,5,72,5,93,5,113,5,134,5,155,5,176,5,197,5,218,5,240,5,5,6,26,6,48,6,70,6,92,6,113,6,135,6,158,6,180,6,202,6,224,6,247,6,14,7,36,7,59,7,82,7,105,7,128,7,143,7,150,7,157,7,163,7,169,7,176,7,182,7,188,7,193,7,199,7,204,7,209,7,214,7,219,7,224,7,229,7,233,7,237,7,241,7,245,7,248,7,252,7,255,7,2,8,5,8,8,8,10,8,13,8,15,8,17,8,18,8,20,8,21,8,22,8,23,8,24,8,24,8,24,8,24,8,24,8,24,8,23,8,22,8,21,8,20,8,18,8,17,8,15,8,12,8,10,8,7,8,4,8,1,8,253,7,250,7,246,7,241,7,237,7,232,7,227,7,221,7,216,7,210,7,204,7,197,7,190,7,183,7,176,7,168,7,160,7,151,7,142,7,133,7,124,7,114,7,104,7,93,7,82,7,71,7,59,7,47,7,35,7,22,7,8,7,250,6,236,6,221,6,206,6,191,6,174,6,158,6,140,6,123,6,104,6,86,6,66,6,46,6,25,6,4,6,238,5,215,5,191,5,167,5,142,5,116,5,89,5,61,5,32,5,2,5,227,4,195,4,162,4,127,4,90,4,53,4,13,4,227,3,184,3,138,3,89,3,37,3,238,2,178,2,113,2,41,2,215,1,120,1,255,0,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,42,0,0,0,166,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,9,9,5,6,7,8,8,10,11,12,13,13,0,0,0,0,0,19,0,0,0,0,32,5,40,0,168,154,39,0,0,0,0,0,192,63,39,0,0,0,0,0,117,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,127,33,0,104,83,38,0,0,1,0,0,0,0,0,0,0,0,0,0,128,100,23,0,0,0,0,0,117,0,0,0,20,0,0,0,170,11,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,39,39,0,8,207,39,0,0,0,0,0,117,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,5,0,0,0,0,0,0,0,0,0,0,6,3,0,0,48,2,0,0,8,1,0,0,0,0,0,0,232,127,32,0,5,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,44,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,146,183,116,145,89,112,112,68,136,223,6,59,130,204,33,61,224,129,33,0,32,84,38,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,10,0,0,66,4,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,44,39,0,120,207,39,0,0,0,0,0,151,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,0,0,0,0,0,0,0,0,0,0,188,1,0,0,122,9,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,4,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,0,42,10,0,0,28,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,49,39,0,240,207,39,0,1,0,0,0,4,80,1,0,0,2,0,0,0,0,0,0,0,0,0,0,240,86,9,0,112,106,40,0,32,101,40,0,0,0,0,0,0,0,0,0,0,0,0,0,252,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,236,23,0,0,0,0,0,48,8,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,56,39,0,136,208,39,0,1,0,0,0,4,80,1,0,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,106,40,0,0,0,0,0,0,0,0,0,24,158,24,0,96,172,10,0,160,116,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,5,0,0,0,0,0,0,0,0,0,0,250,0,0,0,170,7,0,0,0,0,0,0,0,0,0,0,56,130,33,0,128,84,38,0,0,0,0,0,56,128,35,0,16,0,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,3,0,0,68,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,130,33,0,128,84,38,0,0,0,0,0,176,162,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,3,0,0,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,48,49,50,51,52,53,54,55,56,57,97,98,99,100,101,102,40,119,32,0,32,29,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,195,210,194,126,154,218,17,139,247,0,7,233,94,173,141,0,69,35,0,96,120,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,119,37,0,48,26,36,0,0,0,0,0,27,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,57,39,0,200,208,39,0,0,0,0,0,80,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,11,0,0,0,0,0,0,0,0,0,0,92,0,0,0,80,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1398652);
/* memory initializer */ allocate([1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,130,33,0,224,84,38,0,0,0,0,0,0,0,0,0,0,0,1,0,14,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,30,10,0,0,244,3,0,0,118,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,57,39,0,8,209,39,0,0,0,0,0,65,73,80,67,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,46,3,0,0,130,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,15,133,0,0,116,131,0,64,61,131,0,144,207,133,0,96,244,132,0,0,62,131,0,16,209,133,0,96,247,132,0,0,68,131,0,64,221,127,0,112,15,133,0,32,116,131,0,64,61,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,207,133,0,32,244,132,0,128,61,131,0,16,208,133,0,96,245,132,0,0,64,131,0,16,213,133,0,96,255,132,0,0,84,131,0,64,253,127,0,112,79,133,0,32,244,131,0,64,61,129,0,0,0,0,0,176,59,39,0,104,209,39,0,1,0,0,0,20,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,3,0,0,0,0,0,0,0,0,0,0,242,0,0,0,204,7,0,0,0,0,0,0,0,0,0,0,56,133,33,0,112,86,38,0,0,0,0,0,0,0,0,0,0,0,0,0,160,255,24,0,0,0,0,0,0,0,0,0,28,0,0,0,154,8,0,0,174,8,0,0,198,0,0,0,140,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,112,96,39,0,128,213,39,0,1,0,0,0,62,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,4,0,0,0,0,0,0,36,2,0,0,0,0,0,0,244,9,0,0,0,0,0,0,0,0,0,0,232,96,39,0,176,213,39,0,1,0,0,0,62,80,1,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,10,0,0,0,0,0,0,0,0,0,0,212,1,0,0,120,7,0,0,170,1,0,0,0,0,0,0,0,0,1,0,1,0,0,0,5,0,1,0,1,0,0,0,12,0,1,0,1,0,0,0,8,0,1,0,1,0,0,0,6,16,1,0,2,0,0,0,21,0,1,0,3,0,0,0,23,0,1,0,3,0,0,0,7,0,1,0,6,0,0,0,6,0,1,0,7,0,0,0,37,80,1,0,10,0,0,0,32,73,75,79,16,0,0,0,1,16,1,0,17,0,0,0,17,0,1,0,17,0,0,0,32,73,75,79,23,0,0,0,14,16,1,0,32,0,0,0,21,80,1,0,34,0,0,0,30,80,1,0,49,0,0,0,30,80,1,0,50,0,0,0,0,32,1,0,56,0,0,0,53,80,1,0,66,0,0,0,11,16,1,0,69,0,0,0,0,80,1,0,80,0,0,0,1,80,1,0,85,0,0,0,0,32,1,0,87,0,0,0,1,32,1,0,88,0,0,0,3,16,1,0,97,0,0,0,2,16,1,0,98,0,0,0,11,16,1,0,100,0,0,0,1,16,1,0,105,0,0,0,64,80,1,0,117,0,0,0,2,80,1,0,255,0,0,0,53,80,1,0,17,1,0,0,42,80,1,0,48,1,0,0,7,80,1,0,96,1,0,0,8,80,1,0,97,1,0,0,38,80,1,0,98,1,0,0,39,80,1,0,99,1,0,0,12,16,1,0,0,2,0,0,31,80,1,0,112,2,0,0,28,16,1,0,143,2,0,0,27,80,1,0,1,4,0,0,59,80,1,0,2,4,0,0,30,80,1,0,0,21,0,0,21,80,1,0,1,21,0,0,2,80,1,0,0,22,0,0,50,80,1,0,2,22,0,0,3,80,1,0,0,32,0,0,41,80,1,0,0,32,0,0,4,80,1,0,1,32,0,0,67,78,79,83,72,32,0,0,76,78,79,83,72,32,0,0,6,0,1,0,117,108,0,0,2,80,1,0,109,112,0,0,2,80,1,0,67,65,0,0,2,64,1,0,74,89,0,0,53,80,1,0,0,161,0,0,2,80,1,0,6,161,0,0,36,80,1,0,9,161,0,0,12,80,1,0,172,241,0,0,13,16,1,0,70,83,0,0,5,80,1,0,111,86,0,0,0,0,0,0,0,0,0,0,3,80,1,0,44,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,40,80,1,0,191,170,35,233,88,203,113,68,161,25,255,250,1,228,206,98,41,80,1,0,175,135,251,167,2,45,251,66,164,212,5,205,147,132,59,221,0,80,1,0,43,128,109,224,70,219,207,17,180,209,0,128,95,108,187,234,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,74,70,73,70,0,0,0,0,0,0,0,0,5,16,1,0,65,80,67,77,0,0,1,0,78,79,78,69,0,0,0,0,0,0,0,0,5,0,1,0,0,1,0,0,1,16,1,0,1,1,0,0,0,0,0,0,0,0,0,0,14,0,0,0,114,97,119,32,14,0,0,0,121,117,118,50,14,0,0,0,50,118,117,121,14,0,0,0,121,117,118,115,14,0,0,0,76,53,53,53,14,0,0,0,76,53,54,53,14,0,0,0,66,53,54,53,14,0,0,0,50,52,66,71,14,0,0,0,66,71,82,65,14,0,0,0,82,71,66,65,14,0,0,0,65,66,71,82,14,0,0,0,98,49,54,103,14,0,0,0,98,52,56,114,14,0,0,0,98,120,98,103,14,0,0,0,98,120,114,103,14,0,0,0,98,120,121,118,14,0,0,0,78,79,49,54,14,0,0,0,68,86,79,79,14,0,0,0,82,52,50,48,14,0,0,0,82,52,49,49,146,0,0,0,82,49,48,107,146,0,0,0,82,49,48,103,134,0,0,0,114,50,49,48,73,85,86,65,65,86,85,73,80,82,86,65,65,86,114,112,80,82,86,65,83,85,68,83,128,0,0,0,118,50,49,48,128,0,0,0,98,120,121,50,56,48,51,86,118,51,48,56,56,48,52,86,118,52,48,56,158,0,0,0,118,52,49,48,80,49,52,89,89,52,49,80,52,86,85,89,121,117,118,52,54,49,50,84,89,50,49,54,8,0,0,0,106,112,101,103,8,0,0,0,109,106,112,97,8,0,0,0,65,86,68,74,8,0,0,0,100,109,98,49,9,0,0,0,109,106,112,98,23,0,0,0,83,86,81,49,23,0,0,0,115,118,113,49,23,0,0,0,115,118,113,105,24,0,0,0,83,86,81,51,13,0,0,0,109,112,52,118,13,0,0,0,68,73,86,88,13,0,0,0,88,86,73,68,13,0,0,0,51,73,86,50,5,0,0,0,104,50,54,51,5,0,0,0,115,50,54,51,25,0,0,0,100,118,99,112,25,0,0,0,100,118,99,32,25,0,0,0,100,118,112,112,25,0,0,0,100,118,53,112,25,0,0,0,100,118,53,110,25,0,0,0,65,86,100,118,25,0,0,0,65,86,100,49,25,0,0,0,100,118,104,113,25,0,0,0,100,118,104,112,25,0,0,0,100,118,104,49,25,0,0,0,100,118,104,50,25,0,0,0,100,118,104,52,25,0,0,0,100,118,104,53,25,0,0,0,100,118,104,54,25,0,0,0,100,118,104,51,30,0,0,0,86,80,51,49,43,0,0,0,114,112,122,97,44,0,0,0,99,118,105,100,49,0,0,0,56,66,80,83,50,0,0,0,115,109,99,32,56,0,0,0,114,108,101,32,82,73,71,83,114,108,101,49,46,0,0,0,87,82,76,69,59,0,0,0,113,100,114,119,14,0,0,0,87,82,65,87,53,54,50,72,104,101,118,49,53,54,50,72,104,118,99,49,28,0,0,0,97,118,99,49,28,0,0,0,97,105,53,112,28,0,0,0,97,105,53,113,28,0,0,0,97,105,53,50,28,0,0,0,97,105,53,51,28,0,0,0,97,105,53,53,28,0,0,0,97,105,53,54,28,0,0,0,97,105,49,112,28,0,0,0,97,105,49,113,28,0,0,0,97,105,49,50,28,0,0,0,97,105,49,51,28,0,0,0,97,105,49,53,28,0,0,0,97,105,49,54,28,0,0,0,97,105,118,120,28,0,0,0,65,86,105,110,1,0,0,0,109,49,118,49,1,0,0,0,109,112,101,103,1,0,0,0,109,49,118,32,2,0,0,0,109,50,118,49,2,0,0,0,104,100,118,49,2,0,0,0,104,100,118,50,2,0,0,0,104,100,118,51,2,0,0,0,104,100,118,52,2,0,0,0,104,100,118,53,2,0,0,0,104,100,118,54,2,0,0,0,104,100,118,55,2,0,0,0,104,100,118,56,2,0,0,0,104,100,118,57,2,0,0,0,104,100,118,97,2,0,0,0,109,120,53,110,2,0,0,0,109,120,53,112,2,0,0,0,109,120,52,110,2,0,0,0,109,120,52,112,2,0,0,0,109,120,51,110,2,0,0,0,109,120,51,112,2,0,0,0,120,100,53,49,2,0,0,0,120,100,53,52,2,0,0,0,120,100,53,53,2,0,0,0,120,100,53,57,2,0,0,0,120,100,53,97,2,0,0,0,120,100,53,98,2,0,0,0,120,100,53,99,2,0,0,0,120,100,53,100,2,0,0,0,120,100,53,101,2,0,0,0,120,100,53,102,2,0,0,0,120,100,118,49,2,0,0,0,120,100,118,50,2,0,0,0,120,100,118,51,2,0,0,0,120,100,118,52,2,0,0,0,120,100,118,53,2,0,0,0,120,100,118,54,2,0,0,0,120,100,118,55,2,0,0,0,120,100,118,56,2,0,0,0,120,100,118,57,2,0,0,0,120,100,118,97,2,0,0,0,120,100,118,98,2,0,0,0,120,100,118,99,2,0,0,0,120,100,118,100,2,0,0,0,120,100,118,101,2,0,0,0,120,100,118,102,2,0,0,0,120,100,104,100,2,0,0,0,120,100,104,50,2,0,0,0,65,86,109,112,2,0,0,0,109,112,50,118,89,0,0,0,109,106,112,50,94,0,0,0,116,103,97,32,97,0,0,0,116,105,102,102,98,0,0,0,103,105,102,32,62,0,0,0,112,110,103,32,62,0,0,0,77,78,71,32,71,0,0,0,118,99,45,49,88,0,0,0,97,118,115,50,117,0,0,0,100,114,97,99,100,0,0,0,65,86,100,110,5,0,0,0,72,50,54,51,17,0,0,0,51,73,86,68,14,0,0,0,65,86,49,120,14,0,0,0,65,86,117,112,102,0,0,0,115,103,105,32,129,0,0,0,100,112,120,32,82,88,69,48,101,120,114,32,149,0,0,0,97,112,99,104,149,0,0,0,97,112,99,110,149,0,0,0,97,112,99,115,149,0,0,0,97,112,99,111,149,0,0,0,97,112,52,104,51,0,0,0,102,108,105,99,170,0,0,0,105,99,111,100,0,0,0,0,0,0,0,0,5,112,1,0,116,101,120,116,5,112,1,0,116,120,51,103,56,48,54,99,99,54,48,56,0,0,0,0,0,0,0,0,2,80,1,0,109,112,52,97,3,80,1,0,97,99,45,51,3,80,1,0,115,97,99,51,0,16,1,0,105,109,97,52,16,80,1,0,97,108,97,99,0,32,1,0,115,97,109,114,1,32,1,0,115,97,119,98,4,80,1,0,100,116,115,99,4,80,1,0,100,116,115,104,4,80,1,0,100,116,115,108,4,80,1,0,68,84,83,32,41,80,1,0,101,99,45,51,6,80,1,0,118,100,118,97,6,80,1,0,100,118,99,97,18,80,1,0,97,103,115,109,60,80,1,0,105,108,98,99,9,80,1,0,77,65,67,51,10,80,1,0,77,65,67,54,43,80,1,0,46,109,112,49,0,80,1,0,46,109,112,50,1,80,1,0,46,109,112,51,1,80,1,0,85,0,115,109,34,80,1,0,110,109,111,115,7,0,1,0,97,108,97,119,20,0,1,0,102,108,51,50,21,0,1,0,102,108,51,50,22,0,1,0,102,108,54,52,23,0,1,0,102,108,54,52,6,0,1,0,117,108,97,119,1,0,1,0,116,119,111,115,0,0,1,0,115,111,119,116,1,0,1,0,108,112,99,109,0,0,1,0,108,112,99,109,13,0,1,0,105,110,50,52,12,0,1,0,105,110,50,52,9,0,1,0,105,110,51,50,8,0,1,0,105,110,51,50,4,0,1,0,115,111,119,116,5,0,1,0,114,97,119,32,5,0,1,0,78,79,78,69,24,80,1,0,81,99,108,112,24,80,1,0,81,99,108,113,24,80,1,0,115,113,99,112,19,80,1,0,81,68,77,50,51,80,1,0,81,68,77,67,36,80,1,0,115,112,101,120,36,80,1,0,83,80,88,78,8,80,1,0,87,77,65,50,99,118,101,115,115,101,118,99,118,109,115,115,115,115,109,118,0,0,0,0,0,0,0,0,7,0,1,0,1,0,1,0,21,0,1,0,4,0,0,0,23,0,1,0,8,0,0,0,6,0,1,0,1,0,2,0,0,0,1,0,2,0,0,0,12,0,1,0,3,0,0,0,8,0,1,0,4,0,4,0,4,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,7,0,1,0,1,0,1,0,20,0,1,0,4,0,0,0,22,0,1,0,8,0,0,0,6,0,1,0,1,0,2,0,1,0,1,0,2,0,0,0,13,0,1,0,3,0,0,0,9,0,1,0,4,0,4,0,4,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,2,80,1,0,97,97,99,32,3,80,1,0,97,99,45,51,0,16,1,0,105,109,97,52,1,16,1,0,109,115,0,17,6,16,1,0,109,115,0,2,16,80,1,0,97,108,97,99,0,32,1,0,115,97,109,114,18,80,1,0,97,103,115,109,30,80,1,0,109,115,0,49,60,80,1,0,105,108,98,99,9,80,1,0,77,65,67,51,10,80,1,0,77,65,67,54,43,80,1,0,46,109,112,49,0,80,1,0,46,109,112,50,1,80,1,0,46,109,112,51,1,80,1,0,109,115,0,85,7,0,1,0,97,108,97,119,6,0,1,0,117,108,97,119,24,80,1,0,81,99,108,112,19,80,1,0,81,68,77,50,19,80,1,0,81,68,77,67,0,0,0,0,0,0,0,0,28,0,0,0,72,50,54,52,28,0,0,0,104,50,54,52,28,0,0,0,88,50,54,52,28,0,0,0,120,50,54,52,28,0,0,0,97,118,99,49,28,0,0,0,68,65,86,67,28,0,0,0,83,77,86,50,28,0,0,0,86,83,83,72,28,0,0,0,81,50,54,52,28,0,0,0,86,50,54,52,28,0,0,0,71,65,86,67,28,0,0,0,85,77,83,86,28,0,0,0,73,78,77,67,5,0,0,0,72,50,54,51,5,0,0,0,88,50,54,51,5,0,0,0,84,50,54,51,5,0,0,0,76,50,54,51,5,0,0,0,86,88,49,75,5,0,0,0,90,121,71,111,5,0,0,0,77,50,54,51,5,0,0,0,108,115,118,109,20,0,0,0,72,50,54,51,21,0,0,0,73,50,54,51,4,0,0,0,72,50,54,49,5,0,0,0,85,50,54,51,13,0,0,0,70,77,80,52,13,0,0,0,68,73,86,88,13,0,0,0,68,88,53,48,13,0,0,0,88,86,73,68,13,0,0,0,77,80,52,83,13,0,0,0,77,52,83,50,13,0,0,0,4,0,0,0,13,0,0,0,90,77,80,52,13,0,0,0,68,73,86,49,13,0,0,0,66,76,90,48,13,0,0,0,109,112,52,118,13,0,0,0,85,77,80,52,13,0,0,0,87,86,49,70,13,0,0,0,83,69,68,71,13,0,0,0,82,77,80,52,13,0,0,0,51,73,86,50,13,0,0,0,87,65,87,86,13,0,0,0,70,70,68,83,13,0,0,0,70,86,70,87,13,0,0,0,68,67,79,68,13,0,0,0,77,86,88,77,13,0,0,0,80,77,52,86,13,0,0,0,83,77,80,52,13,0,0,0,68,88,71,77,13,0,0,0,86,73,68,77,13,0,0,0,77,52,84,51,13,0,0,0,71,69,79,88,13,0,0,0,71,50,54,52,13,0,0,0,72,68,88,52,13,0,0,0,68,77,52,86,13,0,0,0,68,77,75,50,13,0,0,0,68,89,77,52,13,0,0,0,68,73,71,73,13,0,0,0,69,80,72,86,13,0,0,0,69,77,52,65,13,0,0,0,77,52,67,67,13,0,0,0,83,78,52,48,13,0,0,0,86,83,80,88,13,0,0,0,85,76,68,88,13,0,0,0,71,69,79,86,13,0,0,0,83,73,80,80,13,0,0,0,83,77,52,86,13,0,0,0,88,86,73,88,13,0,0,0,68,114,101,88,13,0,0,0,81,77,80,52,13,0,0,0,80,76,86,49,17,0,0,0,77,80,52,51,17,0,0,0,68,73,86,51,17,0,0,0,77,80,71,51,17,0,0,0,68,73,86,53,17,0,0,0,68,73,86,54,17,0,0,0,68,73,86,52,17,0,0,0,68,86,88,51,17,0,0,0,65,80,52,49,17,0,0,0,67,79,76,49,17,0,0,0,67,79,76,48,16,0,0,0,77,80,52,50,16,0,0,0,68,73,86,50,15,0,0,0,77,80,71,52,15,0,0,0,77,80,52,49,18,0,0,0,87,77,86,49,19,0,0,0,87,77,86,50,19,0,0,0,71,88,86,69,25,0,0,0,100,118,115,100,25,0,0,0,100,118,104,100,25,0,0,0,100,118,104,49,25,0,0,0,100,118,115,108,25,0,0,0,100,118,50,53,25,0,0,0,100,118,53,48,25,0,0,0,99,100,118,99,25,0,0,0,67,68,86,72,25,0,0,0,67,68,86,53,25,0,0,0,100,118,99,32,25,0,0,0,100,118,99,115,25,0,0,0,100,118,104,49,25,0,0,0,100,118,105,115,25,0,0,0,112,100,118,99,25,0,0,0,83,76,50,53,25,0,0,0,83,76,68,86,1,0,0,0,109,112,103,49,1,0,0,0,109,112,103,50,2,0,0,0,109,112,103,50,2,0,0,0,77,80,69,71,1,0,0,0,80,73,77,49,2,0,0,0,80,73,77,50,1,0,0,0,86,67,82,50,1,0,0,0,1,0,0,16,2,0,0,0,2,0,0,16,13,0,0,0,4,0,0,16,2,0,0,0,68,86,82,32,2,0,0,0,77,77,69,83,2,0,0,0,76,77,80,50,2,0,0,0,115,108,105,102,2,0,0,0,69,77,50,86,2,0,0,0,77,55,48,49,2,0,0,0,109,112,103,118,1,0,0,0,66,87,49,48,1,0,0,0,88,77,80,71,8,0,0,0,77,74,80,71,8,0,0,0,76,74,80,71,8,0,0,0,100,109,98,49,8,0,0,0,109,106,112,97,10,0,0,0,76,74,80,71,8,0,0,0,74,80,71,76,12,0,0,0,77,74,76,83,12,0,0,0,77,74,80,71,8,0,0,0,77,74,76,83,8,0,0,0,106,112,101,103,8,0,0,0,73,74,80,71,110,82,86,65,65,86,82,110,8,0,0,0,65,67,68,86,8,0,0,0,81,73,86,71,8,0,0,0,83,76,77,74,8,0,0,0,67,74,80,71,8,0,0,0,73,74,76,86,8,0,0,0,77,86,74,80,8,0,0,0,65,86,73,49,8,0,0,0,65,86,73,50,8,0,0,0,77,84,83,74,8,0,0,0,90,74,80,71,8,0,0,0,77,77,74,80,26,0,0,0,72,70,89,85,68,0,0,0,70,70,86,72,27,0,0,0,67,89,85,86,14,0,0,0,0,0,0,0,14,0,0,0,3,0,0,0,14,0,0,0,73,52,50,48,14,0,0,0,89,85,89,50,14,0,0,0,89,52,50,50,14,0,0,0,86,52,50,50,14,0,0,0,89,85,78,86,14,0,0,0,85,89,78,86,14,0,0,0,85,89,78,89,14,0,0,0,117,121,118,49,14,0,0,0,50,86,117,49,14,0,0,0,50,118,117,121,14,0,0,0,121,117,118,115,14,0,0,0,121,117,118,50,14,0,0,0,80,52,50,50,14,0,0,0,89,86,49,50,14,0,0,0,89,86,49,54,14,0,0,0,89,86,50,52,14,0,0,0,85,89,86,89,14,0,0,0,86,89,85,89,14,0,0,0,73,89,85,86,14,0,0,0,89,56,48,48,14,0,0,0,89,56,32,32,14,0,0,0,72,68,89,67,14,0,0,0,89,86,85,57,14,0,0,0,86,68,84,90,14,0,0,0,89,52,49,49,14,0,0,0,78,86,49,50,14,0,0,0,78,86,50,49,14,0,0,0,89,52,49,66,14,0,0,0,89,52,50,66,14,0,0,0,89,85,86,57,14,0,0,0,89,86,85,57,14,0,0,0,97,117,118,50,14,0,0,0,89,86,89,85,131,0,0,0,70,82,87,85,146,0,0,0,82,49,48,107,134,0,0,0,114,50,49,48,128,0,0,0,118,50,49,48,56,48,51,86,118,51,48,56,56,48,52,86,118,52,48,56,86,85,89,65,65,89,85,86,158,0,0,0,118,52,49,48,52,86,85,89,121,117,118,52,29,0,0,0,73,86,51,49,29,0,0,0,73,86,51,50,112,0,0,0,73,86,52,49,113,0,0,0,73,86,53,48,30,0,0,0,86,80,51,49,30,0,0,0,86,80,51,48,91,0,0,0,86,80,53,48,92,0,0,0,86,80,54,48,92,0,0,0,86,80,54,49,92,0,0,0,86,80,54,50,107,0,0,0,86,80,54,65,93,0,0,0,86,80,54,70,93,0,0,0,70,76,86,52,141,0,0,0,86,80,56,48,169,0,0,0,86,80,57,48,32,0,0,0,65,83,86,49,33,0,0,0,65,83,86,50,36,0,0,0,86,67,82,49,34,0,0,0,70,70,86,49,42,0,0,0,88,120,97,110,114,0,0,0,76,77,50,48,46,0,0,0,109,114,108,101,46,0,0,0,1,0,0,0,46,0,0,0,2,0,0,0,47,0,0,0,77,83,86,67,47,0,0,0,109,115,118,99,47,0,0,0,67,82,65,77,47,0,0,0,99,114,97,109,47,0,0,0,87,72,65,77,47,0,0,0,119,104,97,109,44,0,0,0,99,118,105,100,52,0,0,0,68,85,67,75,52,0,0,0,80,86,69,90,54,0,0,0,77,83,90,72,55,0,0,0,90,76,73,66,87,79,78,83,83,78,79,87,35,0,0,0,52,88,77,86,22,0,0,0,70,76,86,49,22,0,0,0,83,50,54,51,87,0,0,0,70,83,86,49,23,0,0,0,115,118,113,49,57,0,0,0,116,115,99,99,58,0,0,0,85,76,84,73,60,0,0,0,86,73,88,76,61,0,0,0,81,80,69,71,61,0,0,0,81,49,46,48,61,0,0,0,81,49,46,49,72,0,0,0,87,77,86,51,152,0,0,0,87,77,86,80,71,0,0,0,87,86,67,49,71,0,0,0,87,77,86,65,153,0,0,0,87,86,80,50,73,0,0,0,76,79,67,79,74,0,0,0,87,78,86,49,74,0,0,0,89,85,86,56,75,0,0,0,65,65,83,52,75,0,0,0,65,65,83,67,76,0,0,0,82,84,50,49,77,0,0,0,70,80,83,49,31,0,0,0,116,104,101,111,78,0,0,0,84,77,50,48,80,0,0,0,67,83,67,68,82,0,0,0,90,77,66,86,86,0,0,0,75,77,86,67,88,0,0,0,67,65,86,83,89,0,0,0,109,106,112,50,89,0,0,0,77,74,50,67,89,0,0,0,76,74,50,67,89,0,0,0,76,74,50,75,89,0,0,0,73,80,74,50,90,0,0,0,86,77,110,99,94,0,0,0,116,103,97,32,62,0,0,0,77,80,78,71,62,0,0,0,80,78,71,49,37,0,0,0,67,76,74,82,117,0,0,0,100,114,97,99,43,0,0,0,97,122,112,114,43,0,0,0,82,80,90,65,43,0,0,0,114,112,122,97,11,0,0,0,83,80,53,52,124,0,0,0,65,85,82,65,125,0,0,0,65,85,82,50,129,0,0,0,100,112,120,32,139,0,0,0,75,71,86,49,148,0,0,0,76,65,71,83,108,0,0,0,65,77,86,70,154,0,0,0,85,76,82,65,154,0,0,0,85,76,82,71,154,0,0,0,85,76,89,48,154,0,0,0,85,76,89,50,154,0,0,0,85,76,72,48,154,0,0,0,85,76,72,50,156,0,0,0,86,66,76,69,48,51,49,69,69,49,51,48,157,0,0,0,120,116,111,114,162,0,0,0,90,69,67,79,80,49,52,89,89,52,49,80,51,0,0,0,65,70,76,67,163,0,0,0,77,83,83,49,164,0,0,0,77,83,65,49,165,0,0,0,84,83,67,50,166,0,0,0,77,84,83,50,167,0,0,0,67,76,76,67,168,0,0,0,77,83,83,50,24,0,0,0,83,86,81,51,86,50,49,48,48,49,50,118,86,50,49,48,97,49,50,118,77,50,71,0,71,50,77,50,77,50,71,0,71,50,77,51,77,50,71,0,71,50,77,52,176,0,0,0,70,73,67,86,0,0,0,0,0,0,0,0,32,67,70,65,0,0,0,0,16,80,83,80,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,78,79,78,69,4,0,1,0,78,79,78,69,5,0,1,0,114,97,119,32,13,0,1,0,78,79,78,69,9,0,1,0,78,79,78,69,20,0,1,0,102,108,51,50,22,0,1,0,102,108,54,52,7,0,1,0,97,108,97,119,6,0,1,0,117,108,97,119,13,0,1,0,105,110,50,52,9,0,1,0,105,110,51,50,9,80,1,0,77,65,67,51,10,80,1,0,77,65,67,54,18,80,1,0,71,83,77,32,28,16,1,0,71,55,50,50,71,55,50,54,71,55,50,54,1,0,1,0,116,119,111,115,0,0,1,0,115,111,119,116,0,16,1,0,105,109,97,52,19,80,1,0,81,68,77,50,24,80,1,0,81,99,108,112,0,0,0,0,0,0,0,0,1,0,1,0,78,79,78,69,4,0,1,0,78,79,78,69,5,0,1,0,114,97,119,32,13,0,1,0,78,79,78,69,9,0,1,0,78,79,78,69,20,0,1,0,102,108,51,50,22,0,1,0,102,108,54,52,7,0,1,0,97,108,97,119,6,0,1,0,117,108,97,119,13,0,1,0,105,110,50,52,9,0,1,0,105,110,51,50,9,80,1,0,77,65,67,51,10,80,1,0,77,65,67,54,18,80,1,0,71,83,77,32,28,16,1,0,71,55,50,50,71,55,50,54,71,55,50,54,1,0,1,0,116,119,111,115,0,0,1,0,115,111,119,116,0,16,1,0,105,109,97,52,19,80,1,0,81,68,77,50,24,80,1,0,81,99,108,112,0,0,0,0,0,0,0,0,120,97,39,0,240,213,39,0,0,0,0,0,167,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,2,0,0,0,0,0,0,0,0,0,0,4,2,0,0,146,7,0,0,0,0,0,0,0,0,0,0,120,98,39,0,56,214,39,0,0,0,0,0,37,0,0,0,0,0,0,0,0,0,0,0,160,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,254,25,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,8,0,0,0,0,0,0,72,2,0,0,0,0,0,0,2,4,0,0,0,0,0,0,0,0,0,0,120,98,39,0,56,214,39,0,0,0,0,0,37,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,1,0,0,0,0,0,0,0,0,0,0,50,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,100,39,0,120,214,39,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,168,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,1,26,0,0,0,0,0,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,8,0,0,0,0,0,0,250,2,0,0,0,0,0,0,94,11,0,0,0,0,0,0,0,0,0,0,120,100,39,0,136,214,39,0,0,0,0,0,44,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,7,0,0,0,0,0,0,0,0,0,0,78,0,0,0,196,3,0,0,0,0,0,0,0,0,0,0,0,0,0,255,170,0,0,255,0,170,0,255,170,170,0,255,0,0,170,255,170,0,170,255,0,85,170,255,170,170,170,255,85,85,85,255,255,85,85,255,85,255,85,255,255,255,85,255,85,85,255,255,255,85,255,255,85,255,255,255,255,255,255,255,0,128,32,0,8,0,0,0,0,0,0,0,66,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,152,133,33,0,176,86,38,0,0,1,0,0,168,163,36,0,0,0,0,0,0,66,26,0,0,0,0,0,0,0,0,0,64,0,0,0,102,9,0,0,46,11,0,0,162,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,101,39,0,232,214,39,0,0,0,0,0,160,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,8,0,0,0,0,0,0,0,0,0,0,186,1,0,0,166,10,0,0,0,0,0,0,0,0,0,0,128,103,39,0,112,215,39,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,1,0,0,0,0,0,0,0,0,0,0,56,2,0,0,188,9,0,0,0,0,0,0,0,0,0,0,56,134,33,0,88,87,38,0,0,1,0,0,56,134,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,9,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,7,3,6,3,73,224,196,241,230,59,2,223,30,246,253,239,8,30,255,230,252,234,10,16,220,251,245,56,37,6,246,251,243,253,6,251,11,4,237,251,240,41,24,13,4,245,219,23,251,46,254,227,251,217,235,247,0,49,12,247,240,230,22,15,211,236,251,40,22,17,230,31,242,2,242,10,30,20,229,247,217,39,18,5,34,231,208,228,245,34,254,215,9,249,239,21,20,24,239,223,0,232,10,42,3,251,10,42,11,8,253,3,16,9,22,254,0,223,246,18,7,58,10,28,222,252,231,10,9,21,249,220,230,220,221,28,12,42,253,240,244,228,21,42,251,235,16,26,252,19,237,39,15,15,1,13,19,239,239,14,241,55,4,19,28,236,205,242,250,7,0,230,27,252,18,216,250,16,255,241,0,201,251,240,237,14,253,49,14,1,234,226,244,0,24,15,9,239,211,227,4,28,51,35,216,0,228,24,14,251,252,235,249,223,0,224,241,35,12,1,245,198,5,240,228,0,1,33,0,11,217,5,242,6,3,31,28,255,203,223,237,25,46,26,245,242,217,229,9,239,252,223,6,0,4,255,5,10,239,234,5,199,251,9,20,13,18,35,245,3,240,234,17,13,40,19,255,201,221,251,27,44,37,49,176,6,240,11,30,226,247,228,228,227,243,6,254,28,253,251,249,196,5,9,11,255,24,19,229,13,224,13,15,19,19,35,17,217,213,247,4,42,32,41,78,235,213,4,218,17,17,251,55,24,241,220,14,4,24,232,12,5,17,31,202,251,254,27,43,244,2,9,247,241,22,253,28,21,236,3,20,28,9,251,9,255,236,43,239,3,12,0,20,252,223,227,6,22,38,249,0,1,29,30,193,235,3,11,27,255,242,45,246,247,1,12,47,37,228,0,254,26,4,243,39,242,226,248,234,248,12,244,34,27,227,2,26,254,8,225,16,3,17,57,242,250,19,13,16,246,8,17,20,254,38,0,17,240,245,27,44,45,252,8,227,5,249,30,255,235,7,249,0,0,209,9,18,15,22,242,4,0,28,57,233,235,25,254,1,0,249,53,19,3,17,15,36,0,237,24,21,43,247,0,33,246,222,5,239,221,15,1,53,30,6,197,0,246,24,243,17,229,1,255,219,13,4,20,20,238,246,240,248,245,39,18,26,0,210,236,41,15,37,15,221,10,245,44,3,208,10,6,17,2,245,205,248,8,38,3,4,225,12,254,210,255,10,4,5,249,230,19,246,251,18,34,45,15,202,232,18,13,31,7,251,253,235,249,254,196,10,251,32,34,249,236,11,240,8,236,21,227,1,24,2,13,27,6,251,241,253,248,21,1,55,21,15,218,219,3,65,32,23,30,182,17,0,31,18,183,5,0,253,5,231,244,3,1,22,253,9,223,12,24,250,254,33,247,235,251,236,27,19,7,34,37,34,234,212,0,41,29,17,21,76,221,225,228,207,43,216,0,29,242,8,5,10,18,230,210,0,7,6,3,231,249,254,40,28,14,18,253,229,228,248,211,243,34,243,229,241,31,12,3,7,241,247,9,228,29,211,5,250,213,247,12,2,36,244,226,245,3,17,3,222,234,3,24,12,24,2,32,228,234,227,227,5,50,235,225,218,29,7,251,36,227,237,215,222,18,211,250,8,246,251,43,23,11,214,203,5,5,6,30,14,248,20,26,1,16,25,4,3,241,7,215,233,253,252,253,8,48,255,17,224,248,3,254,243,4,206,255,229,217,233,51,15,30,229,219,249,1,17,29,5,233,25,10,242,26,8,41,1,247,243,230,251,12,244,249,242,45,250,9,31,232,233,229,227,247,213,8,26,249,30,239,252,3,230,221,5,232,246,228,247,12,5,33,5,8,5,227,230,232,9,233,242,12,217,204,5,18,39,24,219,253,0,10,249,234,208,12,248,220,12,247,244,22,244,237,250,228,0,227,238,253,11,17,246,18,246,7,229,238,245,249,3,28,209,201,238,15,34,16,248,239,246,216,243,222,209,0,5,252,16,21,8,254,214,213,10,230,246,254,31,11,27,19,235,10,12,236,3,245,25,236,231,231,227,228,28,34,25,38,179,2,11,255,7,209,204,5,227,223,255,28,0,15,228,230,254,226,0,254,22,252,33,3,220,21,253,15,2,251,4,252,250,247,219,225,5,32,20,30,81,231,242,248,195,0,231,28,54,20,253,242,17,248,0,212,16,35,13,18,213,249,6,11,33,252,30,11,234,216,6,213,3,50,242,238,22,18,255,240,12,252,8,29,217,244,226,33,19,248,235,250,8,9,13,228,4,31,24,18,204,233,12,252,18,5,14,47,232,222,242,229,22,66,234,234,255,16,250,232,41,238,254,235,211,232,226,21,33,24,239,24,29,241,240,205,21,33,13,45,253,248,28,254,7,254,37,19,7,229,22,217,249,12,251,5,45,35,241,255,229,1,20,17,232,218,221,26,255,252,221,32,21,3,254,221,8,29,24,44,244,232,34,238,248,7,21,55,5,235,2,233,11,28,243,1,22,33,235,246,36,243,251,249,216,205,228,36,52,27,18,220,2,234,0,223,21,2,253,243,230,11,14,4,10,246,18,242,234,220,24,235,1,28,216,214,42,5,25,5,224,6,17,31,237,191,223,41,16,255,0,227,250,252,13,239,9,255,8,242,221,253,19,245,252,0,1,21,233,226,3,251,20,44,208,210,19,3,20,253,253,249,6,236,231,179,224,29,31,30,4,2,14,227,240,216,26,0,253,12,13,10,36,247,241,248,24,250,7,234,40,239,248,247,225,238,66,22,11,19,184,13,29,18,252,166,219,34,252,1,243,9,6,245,254,232,13,253,7,11,4,252,42,231,225,1,8,29,6,239,19,254,10,6,218,234,42,19,6,11,116,236,188,226,228,83,28,238,32,234,243,235,5,28,5,249,232,248,234,17,233,30,231,45,15,247,245,238,22,246,4,254,19,244,23,3,213,2,12,252,47,0,211,7,249,69,23,243,254,205,224,242,253,47,19,8,219,245,246,16,224,15,237,29,0,1,228,18,20,252,240,13,38,3,15,0,190,0,7,243,77,243,200,213,243,57,23,230,11,237,229,16,17,22,246,241,237,246,234,43,16,30,254,31,245,250,251,247,52,2,20,0,8,206,33,27,237,19,255,9,8,6,223,252,7,44,18,235,233,208,210,24,9,40,3,1,224,243,245,43,7,14,3,15,230,3,235,26,50,8,0,16,27,222,25,23,213,17,250,1,71,247,197,227,248,30,26,245,30,240,8,212,247,14,5,2,237,216,218,241,249,50,239,38,249,242,232,213,22,250,22,19,17,222,254,236,233,246,39,16,2,11,220,9,13,17,21,250,251,211,246,220,238,33,19,19,225,212,229,241,240,34,245,22,234,252,216,249,21,0,1,35,36,238,246,232,210,244,34,8,32,254,209,214,7,5,21,238,9,244,251,251,2,8,246,252,242,214,218,10,33,49,5,24,223,244,239,221,52,6,38,22,7,184,7,3,0,6,25,30,220,18,232,253,28,249,16,243,230,215,232,1,251,26,3,12,229,210,229,10,24,34,10,8,207,254,222,0,51,12,17,38,25,200,0,0,234,3,20,22,121,247,206,246,216,40,43,9,58,12,231,215,11,2,31,251,248,19,241,32,215,30,240,16,20,228,0,253,26,234,19,0,36,4,22,12,250,247,255,232,52,10,229,27,238,26,38,14,23,240,212,223,3,20,45,10,236,15,253,31,206,14,246,0,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1404393);
/* memory initializer */ allocate([239,241,32,24,240,255,15,55,20,14,8,227,244,249,224,82,253,218,233,232,15,38,2,37,15,217,254,23,252,15,244,253,17,241,58,255,29,6,2,251,230,7,4,56,247,35,3,25,223,32,36,17,7,241,247,13,17,241,15,253,1,33,7,1,244,198,5,15,13,29,3,240,13,252,57,246,13,11,243,235,241,247,40,55,253,14,19,44,239,24,32,251,4,235,238,76,1,215,247,237,244,41,17,55,18,253,193,253,244,30,5,253,244,225,0,232,49,248,9,255,223,244,227,27,238,37,21,34,239,253,245,14,233,25,254,7,22,238,29,1,231,36,21,20,247,234,200,245,6,45,21,241,240,236,255,223,34,254,250,239,233,228,6,25,244,16,37,53,255,245,241,248,231,20,245,37,8,227,234,252,219,36,9,34,22,239,232,8,238,15,254,1,242,225,25,15,48,13,252,228,225,251,235,57,252,53,24,23,201,6,12,37,250,11,11,225,28,250,16,16,206,31,14,0,250,220,239,0,0,29,14,245,238,236,25,6,33,19,236,213,235,235,14,55,0,32,40,42,217,255,8,14,248,6,3,119,232,217,212,205,66,242,15,31,230,255,0,7,16,237,228,237,22,230,4,243,28,240,29,5,255,16,240,8,221,246,214,252,17,29,237,214,249,0,241,50,253,240,251,226,53,237,20,253,201,237,8,0,34,251,245,224,18,241,4,234,13,246,13,247,8,0,19,7,227,225,230,13,33,21,234,191,247,252,233,79,239,229,200,220,41,237,8,10,234,241,39,20,9,221,221,241,20,230,31,26,27,6,15,236,0,23,248,38,234,5,218,241,236,39,4,238,9,243,255,10,3,252,238,241,27,232,13,232,205,222,47,12,28,235,237,229,16,241,30,17,12,12,0,220,10,7,27,37,240,241,234,3,252,31,1,214,7,238,247,74,244,226,214,226,14,240,23,29,237,20,235,249,1,237,239,242,246,213,229,3,48,248,22,240,249,4,214,9,225,6,236,250,252,3,213,234,236,28,5,5,7,249,252,247,0,235,28,250,208,2,242,241,20,251,0,229,242,224,228,251,32,254,6,224,3,244,251,8,231,242,252,12,11,252,209,211,234,22,254,34,250,238,201,241,245,235,16,8,240,6,16,5,252,221,232,246,244,213,255,43,47,14,8,213,251,10,222,39,238,22,240,239,214,13,237,1,253,14,20,222,14,4,239,5,232,230,20,229,211,244,24,254,13,235,248,234,240,224,254,34,31,20,249,198,5,251,2,38,244,2,255,1,230,5,233,235,250,8,11,124,243,235,233,194,23,0,43,57,8,243,238,14,246,6,230,253,49,237,19,225,27,249,0,11,236,29,255,12,209,4,217,11,34,28,247,251,237,243,222,55,6,1,14,215,10,252,48,22,236,225,246,5,7,20,247,240,45,248,19,216,12,255,241,252,246,12,34,11,215,240,232,30,49,20,243,228,234,238,213,84,250,247,220,209,255,252,36,36,12,229,20,26,239,247,223,1,47,237,46,9,27,15,243,241,238,35,6,42,223,20,220,1,252,38,14,18,254,229,236,15,13,13,1,230,242,247,41,1,240,210,27,18,1,4,240,245,43,248,45,0,11,21,227,226,248,19,42,41,228,0,236,20,11,30,10,252,251,224,228,79,254,244,234,214,228,255,51,54,15,8,215,0,232,6,241,1,17,220,244,242,47,0,250,245,230,16,229,13,213,22,238,10,12,2,222,15,223,13,243,10,18,10,15,235,215,250,56,19,243,247,223,247,250,20,1,245,13,232,243,233,32,6,234,230,241,0,8,12,219,1,254,28,27,251,219,249,221,8,235,39,4,0,221,229,203,250,44,33,18,251,254,11,225,247,234,6,15,220,13,25,46,23,236,219,232,23,237,43,227,38,242,0,230,12,246,38,240,0,0,227,25,22,2,250,189,245,49,255,246,232,5,3,243,4,251,250,11,231,12,16,31,28,220,203,243,6,16,42,232,17,1,18,246,4,243,15,238,251,249,29,231,234,254,6,67,11,207,1,10,24,251,253,13,252,5,6,245,25,244,240,225,228,36,53,13,250,240,214,24,239,255,238,10,252,13,241,18,5,7,217,252,0,35,27,53,6,212,223,238,5,2,245,31,9,22,250,241,36,243,231,210,233,20,37,24,233,19,213,29,218,14,0,26,244,10,218,16,0,0,246,238,246,241,21,41,6,200,237,13,9,33,9,6,236,255,11,243,24,13,23,224,250,22,26,15,0,248,244,37,255,2,228,229,5,37,7,35,248,21,177,2,12,22,42,28,1,205,202,241,248,41,0,24,250,15,255,239,36,12,14,209,0,6,11,26,240,27,243,43,234,18,246,244,254,34,241,33,243,13,241,243,243,255,26,14,9,215,255,16,46,229,238,255,252,16,11,213,8,211,0,245,235,29,30,8,237,214,215,28,0,20,236,245,226,246,4,5,32,28,172,6,9,36,47,1,4,220,220,244,27,236,230,17,9,33,255,209,19,210,247,229,241,13,15,18,221,250,214,33,236,36,255,4,218,242,238,2,27,20,201,250,255,242,41,246,4,208,234,20,31,10,251,249,236,9,16,211,8,237,40,244,1,15,4,10,244,222,245,41,16,24,226,207,236,13,28,22,18,43,132,13,21,23,62,233,0,213,199,248,13,18,242,10,250,26,3,207,19,237,31,229,7,0,245,20,227,1,244,47,252,39,245,222,228,9,5,19,13,34,34,242,252,17,251,24,26,236,27,45,12,232,2,243,21,8,22,16,32,2,222,225,236,7,58,251,5,254,218,12,254,1,255,26,251,23,21,6,248,245,222,6,18,55,15,11,21,240,248,16,250,240,251,4,35,24,10,12,43,1,213,209,242,248,43,5,246,34,217,18,234,16,17,42,243,19,255,3,242,236,251,249,7,4,9,0,21,228,6,48,254,14,15,236,5,0,27,14,32,28,5,224,2,250,32,253,12,5,248,25,14,4,244,245,4,47,45,22,234,2,182,12,30,42,30,242,16,233,227,19,236,21,7,255,19,17,14,10,43,27,253,208,8,234,16,7,252,42,247,31,250,20,6,4,253,43,22,20,228,251,246,253,4,18,15,229,24,243,24,51,34,209,244,228,21,19,27,240,15,226,239,244,244,0,36,246,249,229,219,16,15,22,253,4,225,255,42,249,18,9,177,17,27,56,36,215,19,248,246,22,15,217,236,247,35,35,15,236,26,225,230,229,250,241,20,0,233,8,218,22,251,38,15,20,217,252,18,247,13,1,206,3,16,5,30,203,19,236,3,55,19,248,0,222,5,11,32,238,15,252,22,243,10,243,9,248,0,237,249,29,31,26,243,223,235,22,65,9,4,23,137,24,39,44,51,190,14,241,225,26,1,0,249,240,19,28,19,234,26,252,13,228,16,227,251,1,240,16,248,35,10,42,4,239,227,19,42,7,0,15,31,228,6,240,240,50,225,242,0,6,36,17,0,0,227,242,11,18,20,231,250,223,237,20,43,21,21,242,201,0,224,216,214,39,1,248,242,8,250,253,219,248,29,22,4,37,220,247,222,234,17,24,248,18,241,2,255,14,31,231,241,208,243,4,28,31,5,21,199,4,203,232,233,55,250,244,219,6,245,245,249,234,18,227,255,25,220,235,236,9,22,56,11,250,211,235,15,16,20,1,33,222,2,6,17,23,28,250,231,12,240,219,203,1,11,15,8,25,236,11,180,255,41,9,19,12,215,239,201,238,3,63,3,12,226,251,3,12,31,0,24,207,8,247,1,33,12,29,229,18,219,235,222,17,3,11,242,23,231,2,243,239,15,241,3,255,223,249,255,12,58,251,241,243,227,253,16,243,4,199,10,243,245,13,21,15,9,216,201,3,242,237,212,17,232,224,5,252,21,18,174,3,38,23,24,241,218,254,219,241,39,2,233,4,241,12,3,239,15,198,1,227,250,254,5,26,249,252,200,9,221,253,231,33,224,220,239,249,15,9,204,246,27,229,18,230,218,242,233,16,44,33,253,236,211,246,20,241,3,225,50,242,10,0,251,17,15,224,232,16,1,241,201,236,242,248,29,12,7,32,135,9,50,10,40,216,213,247,198,244,25,41,245,254,225,5,8,237,15,224,41,226,16,240,236,28,0,3,230,22,237,0,220,252,234,244,6,9,1,24,36,238,24,3,228,7,240,13,26,41,24,255,5,230,253,244,27,46,27,246,232,222,246,248,49,2,34,0,205,244,239,218,231,56,0,0,22,253,236,234,224,2,47,42,249,251,235,18,247,12,5,5,254,248,10,4,14,42,38,246,223,207,251,232,33,12,17,35,204,250,218,234,249,72,249,253,0,250,231,226,254,245,36,247,243,239,235,6,5,45,10,36,18,223,237,237,31,44,27,15,16,222,11,234,22,4,40,7,235,0,255,221,220,18,10,24,46,12,222,248,185,9,59,29,8,226,230,11,226,16,248,44,9,242,251,254,19,40,38,15,7,206,17,218,7,14,24,43,234,6,234,237,239,34,2,20,23,10,217,240,248,250,33,4,249,212,238,21,23,48,46,232,247,216,253,255,32,13,11,213,249,242,253,241,26,253,21,230,206,248,0,240,229,34,231,233,43,239,6,255,179,13,56,43,13,199,233,26,245,19,27,240,239,234,10,15,19,10,22,213,240,226,2,225,11,6,5,9,204,254,236,0,248,50,223,229,19,237,1,247,209,0,45,249,7,187,233,13,2,51,32,14,3,209,237,248,37,11,10,240,32,241,19,227,0,255,28,238,236,4,16,243,218,253,241,0,66,0,249,13,140,20,68,30,28,173,228,18,224,22,13,21,251,228,251,7,24,8,22,239,23,226,25,211,241,9,11,18,234,10,252,2,237,12,233,253,43,254,244,4,72,243,227,238,4,90,37,222,4,255,13,247,250,11,2,24,243,3,249,245,252,4,214,25,31,255,248,227,250,17,237,2,246,250,38,22,214,237,250,245,3,7,250,20,25,77,32,227,225,226,252,254,242,29,16,40,230,0,3,244,243,246,220,9,15,8,232,6,249,22,216,17,8,9,31,18,190,234,245,237,32,250,239,225,19,65,33,215,240,1,0,29,6,4,243,17,247,1,248,14,35,3,237,11,4,0,255,235,23,30,253,5,236,212,48,46,237,253,236,3,220,13,5,7,40,51,28,220,204,229,238,36,254,22,0,33,235,254,3,13,26,245,242,252,246,10,238,14,22,36,232,21,255,228,40,42,214,251,231,251,27,255,236,239,24,38,35,230,1,4,35,224,235,253,2,35,248,227,232,212,12,24,222,18,8,249,235,201,251,21,254,23,245,228,13,255,234,223,21,10,215,18,2,21,45,24,30,235,223,232,17,232,227,15,16,51,235,223,243,211,3,8,228,2,249,2,219,237,249,27,234,39,7,244,5,251,211,221,15,1,244,4,248,227,39,12,30,223,237,8,21,6,248,247,243,28,252,225,232,238,52,23,244,4,238,251,242,209,24,34,14,27,234,190,22,22,1,240,6,24,175,25,14,8,61,0,25,228,202,236,3,14,239,8,0,44,240,221,243,238,43,7,250,245,223,4,226,245,22,40,250,43,253,206,14,18,234,238,1,16,77,254,245,1,249,47,52,251,29,33,1,228,0,241,28,26,2,30,0,2,234,4,223,253,36,235,3,241,254,5,252,4,6,9,37,31,251,224,236,226,8,17,10,40,13,34,47,0,251,4,240,235,248,2,42,43,246,26,10,2,225,245,229,237,21,246,244,20,253,11,231,20,25,25,29,28,228,222,231,218,37,3,0,246,7,22,48,244,8,36,244,9,12,234,12,19,6,28,0,29,18,3,245,239,10,238,10,249,27,18,11,7,253,228,47,55,18,241,222,240,225,24,23,27,29,9,43,248,230,7,226,17,4,253,26,35,251,24,10,28,9,244,251,223,251,248,251,29,26,24,247,23,14,244,39,52,251,238,217,232,32,8,253,2,13,252,50,1,27,39,23,205,241,226,27,37,7,255,239,227,251,23,231,246,14,230,248,215,255,9,13,26,5,244,12,7,14,211,6,247,220,29,19,41,34,238,45,6,248,10,5,213,233,245,42,53,251,251,250,226,242,8,236,230,255,240,231,252,253,15,249,41,23,3,4,3,248,208,1,239,249,15,9,247,28,227,45,251,6,43,9,244,254,220,12,30,11,253,239,253,34,22,253,232,244,232,254,224,28,22,29,29,251,206,21,31,38,227,249,5,180,35,31,28,49,213,40,0,227,14,248,251,246,238,26,46,0,249,250,253,25,7,2,216,228,242,238,3,27,28,8,45,13,222,13,27,15,225,244,253,74,239,0,225,238,73,251,0,3,251,25,12,253,255,234,3,247,33,244,232,6,2,223,9,21,5,20,229,237,249,222,219,222,22,44,0,215,227,239,235,5,3,21,7,2,60,246,5,224,222,7,20,245,16,248,20,235,29,255,232,254,243,229,250,5,15,3,8,235,255,201,235,241,38,37,253,191,224,233,226,35,246,11,212,253,48,246,250,239,254,11,51,8,248,218,253,252,31,244,2,46,1,246,252,251,7,26,237,10,5,238,222,211,241,54,24,238,243,225,249,223,10,34,251,17,35,241,255,203,226,250,59,0,10,232,13,239,27,255,1,37,243,252,236,236,18,10,16,8,11,217,238,230,0,46,20,215,241,219,241,29,251,7,226,1,21,249,7,0,0,47,247,238,241,234,14,252,0,228,199,23,21,231,2,255,0,7,203,237,253,239,241,220,0,19,232,235,213,9,0,217,14,30,8,22,8,244,12,222,229,29,254,230,2,248,31,240,253,239,199,14,6,237,243,240,10,248,239,236,2,218,0,239,16,11,229,212,211,4,248,247,1,20,213,17,253,244,0,236,4,33,29,250,234,218,7,0,255,227,226,63,21,253,245,229,1,14,211,10,9,255,244,209,219,28,0,2,230,252,13,178,21,43,252,38,239,239,5,201,232,15,36,242,252,232,24,244,251,239,225,54,5,2,229,213,12,254,247,9,15,234,3,228,235,20,253,236,228,247,5,80,250,16,245,226,30,9,28,28,29,13,250,2,228,3,5,7,60,251,247,245,1,232,237,27,243,32,243,241,237,237,221,239,39,43,9,252,214,224,215,11,14,39,27,247,17,4,33,250,0,252,1,251,246,17,22,251,57,5,247,236,243,238,221,11,253,16,22,239,243,216,237,1,55,35,5,229,212,219,207,40,0,28,232,242,5,4,21,7,33,0,32,15,221,244,255,11,58,251,16,28,0,255,223,0,245,39,251,14,250,253,225,228,1,53,33,19,231,210,230,228,20,51,14,6,249,0,26,229,4,238,40,6,240,1,15,0,55,5,16,19,242,3,207,242,255,22,30,12,0,232,241,247,17,45,29,252,228,205,221,34,4,25,246,247,235,7,36,26,36,35,228,244,214,3,16,12,28,235,214,5,21,240,230,4,237,19,217,241,241,255,243,237,17,17,242,15,201,252,237,222,25,48,28,11,222,2,41,247,7,17,235,236,232,17,33,0,24,246,214,253,5,246,214,245,248,3,253,240,247,234,2,0,33,10,238,249,198,246,228,252,11,37,233,5,210,2,29,5,39,21,9,0,207,244,9,16,26,234,241,45,20,5,216,234,239,26,225,14,254,14,246,226,236,27,9,39,217,238,251,183,32,60,15,26,197,254,33,226,10,3,17,248,226,1,26,4,22,246,240,36,5,11,200,219,250,10,5,13,3,250,5,245,252,19,5,16,215,232,243,142,47,68,52,55,54,8,54,114,51,171,51,148,51,21,47,122,48,164,54,12,56,39,57,44,51,103,52,168,51,236,47,206,46,1,54,187,52,130,55,53,54,196,57,243,53,53,51,185,44,219,51,33,50,149,53,184,49,128,53,215,49,117,48,246,39,153,47,108,45,105,51,242,45,146,52,24,48,18,50,203,40,229,49,235,46,196,54,42,46,1,54,165,48,170,51,206,40,106,51,105,46,220,55,59,50,160,63,178,52,205,58,171,39,20,50,255,44,149,54,9,47,233,58,91,49,118,55,118,55,91,49,233,58,9,47,149,54,255,44,20,50,171,39,205,58,178,52,160,63,59,50,220,55,105,46,106,51,206,40,170,51,165,48,1,54,42,46,196,54,235,46,229,49,203,40,18,50,24,48,146,52,242,45,105,51,108,45,153,47,246,39,117,48,215,49,128,53,184,49,149,53,33,50,219,51,185,44,53,51,243,53,196,57,53,54,130,55,187,52,1,54,206,46,236,47,168,51,103,52,44,51,39,57,12,56,164,54,122,48,21,47,148,51,171,51,114,51,8,54,55,54,68,52,142,47,38,252,15,252,14,243,12,245,254,250,250,245,211,240,245,243,249,6,244,4,236,3,240,12,255,12,46,24,0,33,253,9,244,244,248,249,17,250,0,254,60,240,3,234,10,224,0,228,239,238,253,231,219,233,246,3,2,3,0,3,242,0,242,255,0,2,32,9,255,25,7,13,251,13,8,1,2,8,246,6,27,244,28,254,6,249,15,9,245,1,243,245,216,4,227,242,237,251,233,248,226,243,239,0,242,12,34,20,254,25,2,240,252,244,15,16,29,7,24,10,49,232,16,236,2,230,2,249,231,246,245,231,224,253,229,2,248,248,245,247,232,239,240,242,243,2,20,5,252,17,14,244,3,13,33,25,14,23,15,19,46,250,21,8,254,240,251,248,245,4,8,15,232,4,254,230,253,240,240,242,247,254,255,4,19,7,36,17,9,13,0,31,251,244,7,248,11,241,243,252,68,238,9,247,250,221,238,231,230,249,10,1,240,253,255,247,6,237,252,241,252,250,0,248,20,254,23,2,7,5,12,35,1,13,24,0,253,0,234,4,35,242,34,10,246,246,255,12,236,12,0,15,238,24,236,229,242,228,229,229,236,237,254,248,5,7,25,13,5,5,6,5,2,244,31,15,23,255,12,8,57,230,22,249,242,228,242,253,221,0,3,1,245,16,238,246,252,225,241,228,242,233,255,235,7,254,11,255,3,255,18,9,10,13,49,24,8,14,2,16,25,15,22,11,18,4,15,234,8,254,239,247,208,236,226,239,240,11,255,16,2,10,251,26,254,252,22,0,2,10,250,13,242,10,233,0,10,254,1,0,47,3,11,250,15,243,2,218,250,243,241,234,216,228,228,0,251,8,10,15,7,7,252,13,255,242,9,242,0,2,4,18,249,36,250,8,253,13,249,8,14,7,36,13,10,10,18,0,0,5,231,248,213,0,208,238,229,0,244,3,249,250,249,13,241,251,11,253,0,2,0,244,250,10,0,23,22,11,26,12,36,251,24,252,7,249,6,239,242,251,234,234,221,248,210,255,239,253,0,2,254,246,251,0,242,241,254,238,254,252,11,249,1,36,18,32,7,27,17,20,33,13,29,24,1,1,254,238,0,9,253,17,229,0,235,226,244,245,251,254,12,4,9,19,18,247,13,250,11,248,254,35,248,10,249,255,4,245,246,254,55,1,17,6,255,240,241,221,241,254,0,4,237,248,236,243,255,242,7,253,18,0,10,5,19,237,0,235,8,240,9,39,0,36,10,7,247,4,236,5,22,5,42,26,250,8,1,2,247,17,246,18,235,19,217,225,233,233,240,241,2,244,7,6,5,247,1,246,7,240,4,9,0,10,17,22,16,2,14,9,44,250,30,8,247,246,245,242,233,5,248,4,242,12,219,242,244,230,252,240,8,240,9,249,6,237,244,231,5,232,15,13,8,36,34,31,1,18,4,18,253,251,247,249,15,255,5,13,2,12,5,2,235,233,254,240,0,5,250,13,233,3,224,10,241,8,44,28,9,37,254,13,247,241,244,229,249,244,0,245,18,239,235,231,11,237,250,253,245,0,7,245,243,225,255,0,9,1,5,12,238,0,225,254,243,255,30,14,7,29,9,18,255,10,4,238,234,3,246,254,243,243,3,251,7,4,9,34,251,20,254,3,240,253,236,239,245,249,239,0,222,243,223,254,228,8,32,24,5,29,3,244,0,241,11,253,3,2,24,1,8,231,248,233,3,243,253,17,236,8,0,246,248,245,238,0,255,246,251,0,228,239,224,241,230,255,19,9,3,21,15,249,6,9,29,5,246,17,15,9,4,250,253,5,255,252,245,16,250,23,19,29,0,253,6,226,3,239,246,251,243,254,239,3,5,3,35,21,17,17,2,35,254,241,3,228,243,235,243,243,26,237,241,244,251,234,232,0,235,12,21,15,8,245,7,244,14,236,2,250,249,250,240,247,6,251,21,7,15,10,13,39,5,10,20,237,228,251,234,251,251,241,9,7,247,2,248,37,242,31,11,29,5,16,245,226,249,227,235,238,233,237,238,247,249,3,23,17,14,9,8,9,6,241,27,252,254,250,12,255,16,229,254,246,243,240,236,20,227,20,14,16,13,8,247,243,2,223,247,237,239,233,239,234,250,250,9,2,12,2,20,13,13,10,45,4,240,8,2,7,240,14,254,8,20,17,9,2,14,16,250,5,232,228,235,236,248,9,4,25,255,11,234,24,241,248,21,5,11,14,251,18,245,7,229,236,242,249,1,247,6,2,242,247,16,255,253,242,0,5,253,248,240,220,237,253,1,6,17,24,4,7,235,11,242,238,7,247,9,7,6,22,253,33,246,245,228,7,249,0,230,6,11,10,12,23,12,23,5,24,243,5,237,248,218,235,236,254,250,12,245,251,233,11,227,247,9,0,7,6,1,249,254,7,253,3,254,6,27,3,252,250,0,249,8,4,0,6,247,13,245,249,245,241,219,252,247,251,5,11,251,247,234,255,229,238,252,242,5,0,12,253,4,32,14,12,239,22,17,11,248,12,3,21,3,14,248,5,4,28,7,32,254,248,244,222,252,244,1,6,9,4,249,17,4,243,11,255,19,252,0,39,252,7,245,235,236,240,246,245,13,0,248,3,0,252,235,245,247,16,10,18,5,240,246,240,5,241,13,5,15,1,250,4,6,233,254,240,17,244,10,44,3,33,6,244,222,255,236,253,238,4,17,23,252,20,252,26,253,36,0,32,2,12,227,222,240,232,246,250,0,244,248,4,248,243,0,250,16,244,5,13,3,7,13,3,248,254,14,0,3,249,5,5,248,2,239,9,238,24,2,19,10,4,228,239,251,228,2,249,4,241,249,248,250,233,243,235,14,236,17,18,11,33,30,11,233,13,5,9,60,10,7,255,9,248,6,243,2,241,255,246,243,245,15,0,6,9,255,0,243,1,245,253,243,21,13,26,249,31,246,249,240,223,225,246,22,248,1,254,82,255,252,237,6,229,250,227,244,230,1,232,251,238,17,17,17,6,10,0,249,254,247,240,244,11,0,11,247,23,0,253,248,248,243,255,8,7,249,6,49,2,21,0,1,254,9,8,250,250,248,246,248,9,254,0,252,254,243,244,233,241,244,240,230,21,2,21,245,23,252,223,249,223,250,13,34,5,27,10,71,246,9,239,255,236,253,248,235,238,250,232,0,1,0,16,6,251,0,243,239,237,245,227,231,11,245,6,243,15,7,227,0,248,11,22,20,21,17,18,67,8,14,11,249,245,245,247,249,253,13,16,8,9,24,244,10,243,251,239,254,252,3,246,6,17,4,19,0,11,250,13,247,223,242,246,16,239,246,252,90,253,2,250,246,227,232,230,235,241,15,2,16,1,25,4,21,240,6,238,3,248,5,232,8,7,247,4,255,3,5,18,255,249,2,255,2,255,237,3,57,0,27,13,242,251,249,11,241,4,5,16,13,29,6,243,0,231,240,225,244,234,2,233,250,16,249,14,254,3,0,244,0,223,9,13,28,253,14,7,79,245,15,252,238,233,236,251,226,249,7,2,21,21,8,3,10,228,252,225,250,231,3,219,252,7,236,0,252,252,11,249,6,248,27,22,14,12,5,16,47,30,15,14,14,9,9,233,13,246,244,249,240,241,253,253,255,14,9,12,9,8,0,10,242,4,247,2,251,8,243,253,238,246,211,253,16,252,4,0,69,17,3,253,10,248,253,216,255,235,246,235,248,233,255,13,8,11,21,11,15,4,0,254,243,251,233,244,249,0,255,0,246,14,228,5,1,11,251,7,36,21,28,16,6,16,12,254,4,254,236,249,245,4,236,252,244,2,255,0,0,248,254,254,229,4,235,254,247,0,250,227,247,246,235,21,28,10,29,11,58,9,16,255,2,254,0,237,246,243,239,235,253,253,237,12,254,0,10,255,5,244,0,241,230,251,222,240,245,249,4,231,254,14,253,29,13,25,20,20,55,28,21,27,254,7,248,236,4,1,1,18,5,4,5,240,2,248,5,251,19,2,14,3,6,0,238,252,2,245,248,18,245,246,227,253,10,243,248,253,77,16,9,9,250,245,235,219,246,246,4,5,13,253,7,0,13,245,17,250,25,255,15,247,7,247,224,237,0,238,2,22,253,15,244,5,252,2,239,5,44,20,34,29,246,13,252,0,252,9,251,19,10,24,245,239,248,236,251,237,9,242,12,247,250,0,226,247,0,237,254,249,254,246,251,20,21,1,17,9,66,8,23,11,242,251,239,240,237,254,253,5,18,17,246,0,1,233,6,236,15,238,14,234,251,246,212,233,254,230,9,253,4,14,12,29,7,16,7,18,18,9,239,252,11,3,0,11,7,4,10,3,10,238,24,253,14,7,4,10,240,1,229,252,229,17,12,30,0,35,247,253,244,220,221,226,254,243,2,245,40,254,227,234,7,242,244,251,249,249,12,247,18,230,26,14,24,4,16,9,246,254,230,238,230,7,255,15,255,27,2,0,252,245,239,235,240,1,249,253,8,1,253,254,3,10,3,32,255,12,2,4,15,1,7,253,2,252,250,253,230,241,227,239,216,17,0,26,254,27,254,227,252,220,246,250,9,0,27,0,30,245,241,236,0,248,247,15,241,0,5,247,23,250,8,13,13,249,5,253,236,237,229,225,217,7,243,11,252,19,8,231,3,245,7,2,252,16,18,9,26,7,245,8,251,1,239,14,255,15,24,30,32,1,33,240,18,242,0,248,250,252,244,244,250,13,2,23,8,15,252,17,251,220,238,226,248,234,246,242,48,252,233,247,247,239,226,254,240,3,26,16,40,250,35,1,28,239,12,247,0,248,245,231,251,3,246,8,6,7,6,22,1,245,255,235,234,249,237,251,15,0,2,10,243,7,242,35,246,23,16,31,37,21,16,239,6,230,246,235,240,235,243,231,237,13,248,19,5,7,1,248,2,220,5,250,3,248,15,255,37,244,247,249,239,245,230,18,231,12,19,17,45,14,17,0,17,226,1,234,246,231,244,218,238,3,234,4,3,0,13,253,10,245,23,2,246,7,5,7,5,29,247,11,15,22,3,0,18,8,255,6,7,233,6,250,5,12,15,21,5,8,239,9,228,0,245,6,2,12,245,0,242,243,207,234,248,247,4,247,27,16,235,250,12,3,247,240,3,254,1,249,15,225,7,10,16,9,27,21,11,5,240,253,230,247,232,249,0,4,0,4,250,11,224,242,233,6,251,255,252,20,3,13,8,28,6,21,10,16,248,7,12,253,245,249,251,0,4,8,252,248,238,253,215,0,234,2,0,4,251,231,250,242,231,1,2,4,29,2,17,8,248,252,4,10,250,5,252,5,250,250,20,246,247,9,4,254,16,7,1,244,239,240,217,247,220,244,254,253,6,235,1,11,249,10,245,20,20,11,13,27,253,24,255,19,242,3,9,20,12,33,29,253,15,236,9,247,11,3,16,2,254,2,249,253,236,0,10,249,249,22,249,243,223,233,242,238,249,244,35,15,241,6,252,1,229,244,251,8,15,19,37,245,16,254,20,244,23,2,22,255,255,245,251,243,222,242,8,242,4,26,0,11,240,242,227,254,239,253,3,19,9,26,248,26,246,24,0,28,5,33,34,17,254,236,255,234,0,246,6,242,253,246,236,252,224,252,7,241,0,253,0,243,247,0,253,252,17,0,25,7,254,8,244,7,233,8,243,16,7,20,42,9,0,253,9,231,12,246,12,238,254,232,237,243,210,237,5,234,10,0,8,11,8,9,239,11,7,8,231,249,2,248,12,249,23,248,13,240,249,236,214,247,0,3,247,25,244,10,244,18,2,24,19,13,46,19,251,22,246,0,248,245,248,247,17,245,249,248,253,237,247,230,8,230,10,232,0,228,251,223,222,239,2,20,1,22,0,10,250,14,3,10,20,4,32,4,249,15,0,3,0,13,9,0,3,4,239,0,221,241,15,250,4,255,27,12,5,248,241,237,219,11,240,2,236,12,233,254,234,1,1,11,5,13,34,14,248,14,252,230,0,245,16,14,29,2,17,3,243,229,3,232,1,237,14,253,247,236,244,223,227,3,241,20,247,9,245,253,240,254,2,254,7,3,20,0,246,7,7,234,7,13,33,23,14,18,7,12,239,248,8,4,252,246,6,251,4,251,6,6,236,10,9,247,252,2,240,249,255,12,17,16,39,9,36,12,2,3,250,21,255,245,7,246,11,236,236,245,4,236,253,243,248,228,250,235,246,240,8,249,244,3,11,7,5,0,252,248,4,8,18,3,41,0,22,254,0,252,5,25,6,14,25,255,254,252,227,254,229,240,21,6,244,253,9,16,253,2,255,7,241,31,249,246,240,247,229,235,245,251,16,3,26,9,24,7,0,252,0,252,6,245,32,14,23,250,5,1,251,227,9,245,241,234,253,0,238,248,1,250,249,23,250,6,251,244,241,235,251,248,17,247,28,0,11,250,254,244,11,0,14,13,49,22,8,9,252,9,219,12,9,7,17,11,26,238,25,244,237,239,211,242,239,0,239,30,255,22,10,25,12,38,18,253,22,252,253,0,243,3,246,11,233,254,10,249,251,249,241,0,254,246,13,249,14,221,10,233,240,225,219,235,240,17,250,26,10,21,16,21,13,25,19,243,8,237,251,249,255,8,254,36,251,6,253,8,241,1,208,4,23,9,9,17,30,2,16,253,230,240,216,6,221,255,228,17,244,9,0,8,11,25,5,253,10,248,250,249,250,234,255,11,1,21,22,7,19,5,230,249,11,248,5,255,17,242,1,241,232,226,224,255,223,16,238,14,0,8,6,4,12,12,6,243,254,233,248,241,4,239,5,36,18,30,8,22,10,14,226,11,15,20,0,8,9,241,15,0,251,9,233,6,248,243,243,7,251,3,20,19,27,31,39,249,13,245,4,237,248,25,253,11,249,254,4,240,238,247,248,255,3,2,253,246,253,224,1,244,254,252,241,255,249,3,254,4,6,3,26,15,29,17,40,239,0,230,2,229,2,29,4,36,10,6,247,0,229,0,216,2,29,22,249,14,12,5,7,7,244,9,238,26,230,242,232,252,240,247,10,2,26,18,26,249,1,241,1,229,254,0,4,11,17,21,16,255,7,3,238,247,17,4,245,253,0,245,249,252,246,253,246,18,232,3,242,249,252,246,16,255,27,4,27,239,244,226,0,221,9,3,12,36,35,30,2,13,254,11,190,248,233,245,14,5,17,16,19,2,3,251,238,239,10,0,255,23,250,20,241,18,242,22,5,10,44,23,2,26,247,3,252,242,244,227,249,240,249,238,212,236,222,227,10,243,4,0,4,247,5,237,246,232,11,17,8,20,5,19,247,14,244,9,6,0,30,9,0,19,2,7,2,10,5,236,235,255,239,247,179,240,247,247,6,11,21,37,10,10,252,251,243,3,249,0,243,11,239,6,231,1,241,9,249,9,32,19,0,18,254,234,3,241,12,251,4,254,17,251,201,228,235,229,2,249,8,20,252,255,255,238,251,252,251,16,254,8,251,5,237,254,242,253,250,0,18,4,254,11,8,238,11,10,29,3,246,13,8,3,198,247,240,1,254,2,0,19,10,13,17,21,3,3,19,244,2,0,246,1,251,12,0,15,26,5,34,16,11,7,252,25,2,242,3,227,243,231,236,236,220,235,228,240,250,240,244,2,252,2,20,7,11,252,20,4,12,254,1,0,0,8,2,2,27,252,21,2,9,0,6,29,9,10,21,235,228,246,227,245,187,239,253,3,246,8,3,40,1,21,10,21,8,23,1,243,248,245,235,245,241,252,0,2,13,5,23,12,7,0,1,0,10,242,28,251,255,245,5,249,209,226,241,242,242,247,247,23,243,10,12,7,16,15,3,3,1,242,247,244,247,248,0,246,14,252,9,254,5,248,13,3,18,10,45,3,240,4,252,0,177,11,241,4,18,23,20,5,30,7,249,254,235,235,248,253,246,28,4,31,6,25,253,37,4,249,20,0,4,4,245,7,250,8,229,234,242,244,251,240,199,0,229,243,14,5,7,245,15,252,251,240,243,227,250,13,0,25,16,31,12,22,254,23,6,240,7,242,2,253,0,12,0,33,247,243,228,3,242,249,166,3,254,6,10,29,24,26,21,15,241,254,240,255,231,252,235,16,250,18,253,8,251,24,248,249,9,252,1,253,251,238,1,7,254,1,254,1,19,253,189,248,242,245,7,11,11,9,7,3,243,240,248,247,232,12,246,13,5,17,2,4,253,10,250,239,252,237,0,245,6,243,9,33,14,10,240,17,10,4,185,10,247,17,1,20,3,8,21,18,6,24,0,255,0,240,250,5,0,13,17,19,11,29,25,245,11,250,13,241,249,29,0,8,245,234,236,235,239,238,207,254,235,0,255,2,247,248,6,6,8,10,8,247,2,0,4,2,13,12,23,15,12,16,26,235,254,235,11,233,4,33,7,33,6,243,222,251,229,246,174,1,4,19,250,27,6,29,12,26,255,24,5,18,239,239,239,250,246,0,7,2,9,16,12,245,0,245,9,233,0,3,8,8,13,1,248,249,7,250,196,246,249,1,247,8,250,13,254,15,1,10,13,11,241,0,250,247,1,0,13,255,11,3,13,235,243,230,7,225,10,7,16,33,31,10,234,8,255,2,253,7,251,251,8,254,17,247,18,232,254,237,246,252,28,17,5,28,254,7,252,15,7,8,6,23,13,21,242,20,239,238,245,223,226,245,23,243,251,247,18,252,239,233,4,236,4,230,3,220,0,224,254,244,29,34,16,24,10,6,0,12,8,252,8,13,0,6,240,12,251,243,253,249,243,253,8,2,242,0,243,0,8,253,0,4,21,11,9,240,246,238,251,16,10,16,251,15,243,251,241,255,6,252,250,23,2,16,239,12,246,212,253,223,250,12,34,1,20,3,8,244,253,235,253,242,8,251,252,228,249,224,2,8,12,34,4,12,255,250,247,252,7,239,252,13,245,1,237,4,0,217,4,249,11,21,20,16,10,11,4,6,0,7,248,252,0,250,9,243,11,7,11,15,37,4,9,5,251,245,5,9,22,1,27,18,4,14,251,0,244,3,252,224,242,244,17,234,239,245,26,250,245,246,244,233,244,233,251,232,13,251,19,8,38,21,20,2,6,244,11,5,23,245,29,9,247,0,249,250,255,7,2,249,3,253,2,250,229,253,250,254,14,9,240,1,3,14,0,251,3,8,16,36,19,3,255,250,239,232,252,249,21,245,14,18,249,9,247,249,250,234,3,223,10,11,28,249,7,0,16,242,2,248,236,239,247,254,242,240,6,251,24,28,21,20,8,247,252,231,1,245,22,232,15,8,235,251,245,242,5,238,11,249,27,20,14,7,255,9,240,27,2,10,13,16,20,236,29,236,242,240,243,248,9,13,254,33,9,19,17,23,17,22,6,6,247,254,244,254,236,243,243,246,211,252,16,248,254,249,5,15,247,249,9,254,8,219,14,225,245,227,251,240,11,30,7,29,21,18,23,19,18,9,7,253,233,239,242,247,248,247,250,15,229,4,2,6,244,1,230,19,15,12,5,22,24,0,21,244,235,241,248,11,249,12,242,20,254,6,7,6,16,9,250,5,235,249,241,246,243,217,251,246,236,19,28,5,22,5,252,6,3,251,1,4,11,240,6,233,237,227,0,3,250,30,253,17,10,5,13,2,17,253,251,253,221,235,239,239,254,221,2,15,253,28,13,21,13,13,248,25,8,23,253,13,3,239,20,248,0,10,8,11,18,0,1,10,5,0,28,17,32,15,26,1,237,247,253,235,241,7,250,247,227,251,10,239,241,247,13,13,253,5,249,252,247,222,5,236,2,253,16,3,20,17,11,7,17,0,34,13,33,2,28,248,224,232,251,227,253,12,0,15,245,3,253,254,232,255,238,17,21,25,245,19,6,3,11,0,249,11,13,31,1,0,247,255,251,244,18,0,31,2,13,1,226,242,249,227,247,238,1,246,252,18,22,253,10,2,3,5,9,7,241,1,251,243,254,244,251,254,21,23,2,16,0,251,6,243,23,253,32,246,15,248,212,228,247,219,2,243,9,15,12,27,7,12,0,11,212,6,226,248,9,10,11,14,23,251,8,252,14,244,37,14,12,26,4,16,248,16,247,7,250,19,12,25,251,24,241,243,248,220,222,225,255,238,252,238,234,251,214,230,6,248,255,254,9,239,10,238,21,237,39,31,23,23,16,15,254,12,249,250,251,9,255,10,249,16,252,247,0,246,239,234,240,254,242,247,201,255,239,250,1,16,15,35,15,2,0,252,19,8,20,13,1,14,249,3,238,0,246,251,237,19,0,21,248,16,247,217,0,220,246,249,9,252,20,251,223,243,227,232,255,255,2,18,0,247,3,239,27,0,21,30,12,11,5,2,244,252,247,237,238,9,243,6,245,8,2,221,8,246,7,1,252,11,10,2,220,5,232,4,249,7,250,17,14,5,22,22,35,8,46,1,17,3,0,254,2,10,5,0,14,15,2,18,2,4,245,7,255,220,238,224,249,229,239,236,242,249,220,243,246,246,238,0,0,251,25,8,43,0,48,18,27,0,12,253,7,6,7,243,15,5,245,3,0,254,0,12,6,246,0,233,234,245,230,244,209,253,245,6,241,13,254,38,6,13,15,22,40,28,28,0,5,248,246,241,249,249,4,243,1,14,247,14,0,254,252,238,7,220,6,248,3,243,7,248,231,241,234,245,238,252,241,22,248,2,17,9,48,20,30,17,16,245,1,240,254,246,5,230,2,4,234,0,254,246,6,243,14,246,23,0,246,2,255,0,199,26,234,7,14,28,14,3,35,0,253,255,11,240,18,10,4,31,15,28,14,23,1,21,249,2,245,1,253,1,238,247,246,243,207,232,248,242,254,240,221,14,222,246,10,10,1,244,20,244,0,241,18,232,20,27,14,28,27,27,20,19,2,8,251,249,231,243,251,251,250,251,254,12,225,241,233,1,244,248,188,18,247,9,6,35,18,25,26,7,246,255,16,3,1,9,250,19,4,15,4,6,0,8,236,2,233,254,249,251,244,221,255,243,232,0,3,0,22,252,210,6,235,248,2,16,5,8,11,252,248,241,24,252,2,26,3,16,16,14,9,2,1,252,237,249,220,239,247,243,0,225,5,12,249,8,245,15,13,4,207,24,240,20,254,26,254,7,25,10,11,25,32,3,27,254,8,8,11,9,24,17,16,14,13,254,236,251,4,239,242,12,253,243,223,231,242,233,241,237,229,12,228,2,250,7,241,247,11,255,13,11,40,252,29,14,19,5,23,8,30,13,17,0,14,244,222,236,2,231,254,16,4,12,241,240,227,249,232,246,196,16,253,22,246,32,0,28,17,18,3,25,37,23,10,253,254,253,0,253,14,0,14,1,0,254,224,247,1,231,249,243,5,243,248,255,254,248,10,250,218,4,241,4,242,13,244,11,2,6,6,11,45,16,11,13,7,250,12,252,20,253,16,244,1,244,210,232,0,223,3,247,12,12,8,7,239,6,0,2,201,76,42,72,189,71,112,68,56,82,55,71,152,72,31,65,139,79,125,74,209,75,254,71,84,85,65,73,157,76,3,68,165,79,12,85,161,78,198,84,242,81,248,79,171,76,187,75,229,83,94,90,81,85,111,93,73,86,15,84,142,82,116,81,219,76,157,69,100,74,69,68,18,78,59,66,14,72,214,62,146,82,211,73,216,81,241,73,204,83,169,69,136,78,7,67,58,77,88,78,112,79,130,81,129,75,41,71,220,73,84,70,52,84,188,85,39,90,81,93,186,81,88,76,248,81,69,77,69,77,248,81,88,76,186,81,81,93,39,90,188,85,52,84,84,70,220,73,41,71,129,75,130,81,112,79,88,78,58,77,7,67,136,78,169,69,204,83,241,73,216,81,211,73,146,82,214,62,14,72,59,66,18,78,69,68,100,74,157,69,219,76,116,81,142,82,15,84,73,86,111,93,81,85,94,90,229,83,187,75,171,76,248,79,242,81,198,84,161,78,12,85,165,79,3,68,157,76,65,73,84,85,254,71,209,75,125,74,139,79,31,65,152,72,55,71,56,82,112,68,189,71,42,72,201,76,72,196,33,0,104,68,33,0,0,0,0,0,128,215,32,0,0,0,0,0,88,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,134,33,0,200,87,38,0,0,1,0,0,0,0,0,0,0,0,0,0,208,209,28,0,0,0,0,0,88,0,0,0,20,0,0,0,202,8,0,0,14,2,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,128,192,192,192,0,0,0,67,131,76,140,73,137,70,134,99,163,102,166,83,147,89,153,115,179,192,0,0,0,0,0,0,1,0,254,255,0,0,0,0,1,0,253,255,152,105,39,0,208,215,39,0,0,0,0,0,88,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,1,0,0,0,0,0,0,0,0,0,0,58,0,0,0,74,11,0,0,136,0,0,0,0,0,0,0,88,137,33,0,64,89,38,0,200,164,36,0,88,137,33,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,88,95,40,0,0,0,0,0,0,0,0,0,24,0,0,0,72,1,0,0,108,3,0,0,188,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,143,33,0,24,91,38,0,0,0,0,0,0,0,0,0,96,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,106,10,0,0,22,2,0,0,94,3,0,0,0,0,0,0,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,148,33,0,144,93,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,8,0,0,230,9,0,0,210,3,0,0,106,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,106,39,0,88,216,39,0,0,0,0,0,103,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,5,0,0,0,0,0,0,0,0,0,0,204,1,0,0,250,6,0,0,0,0,0,0,0,0,0,0,24,151,33,0,120,95,38,0,0,0,0,0,24,151,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,12,4,0,0,146,2,0,0,146,3,0,0,196,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,28,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,152,107,39,0,240,216,39,0,0,0,0,0,88,73,80,66,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,154,33,0,104,96,38,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,3,0,0,78,9,0,0,240,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,108,39,0,152,217,39,0,0,0,0,0,155,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,55,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,156,33,0,88,97,38,0,0,0,0,0,96,156,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,46,5,0,0,164,3,0,0,12,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1414633);
/* memory initializer */ allocate([152,125,37,0,56,31,36,0,1,0,0,0,57,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,9,0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,110,39,0,224,217,39,0,0,0,0,0,79,0,0,0,0,0,0,0,0,0,0,0,184,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,126,0,0,0,0,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,24,117,39,0,208,218,39,0,0,0,0,0,79,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,160,33,0,160,98,38,0,0,170,36,0,168,160,33,0,54,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,138,6,0,0,14,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,160,33,0,160,98,38,0,0,0,0,0,168,160,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,9,0,0,58,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,169,33,0,184,103,38,0,0,0,0,0,192,169,33,0,0,0,0,0,112,95,40,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,80,8,0,0,148,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,127,39,0,120,221,39,0,0,0,0,0,84,88,84,66,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,8,0,0,0,0,0,0,0,0,0,0,112,1,0,0,186,11,0,0,0,0,0,0,0,0,0,0,160,129,39,0,80,222,39,0,1,0,0,0,48,80,1,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,11,0,0,0,0,0,0,0,0,0,0,82,1,0,0,164,8,0,0,0,0,0,0,0,0,0,0,136,127,37,0,80,32,36,0,1,0,0,0,49,80,1,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,11,0,0,0,0,0,0,0,0,0,0,82,1,0,0,164,8,0,0,0,0,0,0,0,0,0,0,112,174,33,0,0,106,38,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,8,0,0,112,2,0,0,50,5,0,0,92,2,0,0,0,0,0,0,94,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,134,39,0,64,223,39,0,0,0,0,0,136,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,4,0,0,0,0,0,0,0,0,0,0,210,2,0,0,46,8,0,0,228,0,0,0,0,0,0,0,200,177,33,0,136,106,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,44,1,0,0,222,9,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,141,39,0,192,223,39,0,0,0,0,0,118,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,5,0,0,0,0,0,0,0,0,0,0,36,0,0,0,134,0,0,0,0,0,0,0,0,0,0,0,24,182,33,0,32,108,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,202,6,0,0,92,8,0,0,54,0,0,0,252,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,143,39,0,48,224,39,0,0,0,0,0,104,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,7,0,0,0,0,0,0,0,0,0,0,244,0,0,0,216,9,0,0,0,0,0,0,0,0,0,0,255,5,102,63,251,115,93,63,7,238,68,63,1,194,31,63,3,180,229,62,246,211,135,62,250,111,196,61,9,0,41,189,231,143,9,190,27,72,55,190,11,208,54,190,24,8,18,190,253,239,173,189,249,255,167,188,3,96,23,61,3,128,158,61,253,159,195,61,3,240,186,61,255,47,141,61,9,64,18,61,0,0,0,0,2,64,250,188,246,127,78,189,246,127,105,189,4,64,80,189,10,96,15,189,47,0,104,188,252,255,217,59,6,0,189,60,247,127,4,61,251,95,9,61,5,0,226,60,17,128,137,60,249,255,134,59,7,0,245,187,237,127,128,188,232,127,158,188,10,128,150,188,226,127,97,188,255,255,230,187,0,0,0,0,6,0,191,59,252,255,25,60,25,0,42,60,253,255,19,60,255,255,197,59,251,255,27,59,232,255,143,186,3,0,112,187,10,0,163,187,255,255,164,187,255,255,131,187,6,0,30,187,0,0,24,186,20,0,136,58,242,255,17,59,2,0,54,59,237,255,49,59,254,255,11,59,17,0,152,58,0,0,0,0,0,0,0,0,208,130,37,0,112,139,39,0,0,0,0,0,86,85,89,65,0,0,0,0,0,0,0,0,112,100,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,2,0,0,0,0,0,0,238,1,0,0,0,0,0,0,146,4,0,0,0,0,0,0,0,0,0,0,224,131,37,0,200,139,39,0,0,0,0,0,86,85,89,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,11,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,144,39,0,88,224,39,0,0,0,0,0,73,85,86,65,0,2,0,0,0,0,0,0,240,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,6,0,0,0,0,0,0,34,0,0,0,0,0,0,0,166,1,0,0,0,0,0,0,0,0,0,0,0,145,39,0,136,224,39,0,0,0,0,0,73,85,86,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,2,0,0,0,0,0,0,0,0,0,0,222,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,58,38,0,176,173,39,0,0,0,0,0,0,0,0,0,136,140,12,0,2,0,0,0,76,10,0,0,0,0,0,0,238,0,0,0,218,4,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,97,37,0,104,4,36,0,0,0,0,0,0,0,0,0,88,210,30,0,2,0,0,0,76,10,0,0,0,0,0,0,238,0,0,0,218,4,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,184,33,0,112,109,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,16,10,0,0,140,3,0,0,28,0,0,0,70,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,145,39,0,168,224,39,0,0,0,0,0,83,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,0,0,0,0,0,0,0,0,122,2,0,0,116,8,0,0,0,0,0,0,0,0,0,0,120,61,34,0,240,154,33,0,0,0,0,0,80,82,86,65,0,0,0,0,0,0,0,0,224,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,11,0,0,0,0,0,0,194,2,0,0,0,0,0,0,12,7,0,0,0,0,0,0,0,0,0,0,128,4,35,0,128,61,34,0,0,0,0,0,80,82,86,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,5,0,0,0,0,0,0,0,0,0,0,198,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,145,39,0,32,225,39,0,0,0,0,0,110,82,86,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,208,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,11,0,0,0,0,0,0,0,0,0,0,162,1,0,0,248,6,0,0,0,0,0,0,0,0,0,0,240,185,33,0,248,109,38,0,0,1,0,0,240,185,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,4,0,0,218,3,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,45,36,0,144,42,35,0,192,145,37,0,0,0,0,0,1,80,1,0,22,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,116,7,0,0,170,1,0,0,14,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,194,33,0,208,114,38,0,208,178,36,0,184,194,33,0,3,80,1,0,13,0,0,0,0,0,0,0,0,0,0,0,224,95,40,0,0,0,0,0,0,0,0,0,40,0,0,0,212,10,0,0,90,2,0,0,180,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,198,33,0,0,116,38,0,0,0,0,0,0,0,0,0,0,0,0,0,32,176,23,0,0,0,0,0,0,0,0,0,96,0,0,0,106,1,0,0,202,7,0,0,28,3,0,0,222,3,0,0,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,35,32,0,16,181,37,0,240,167,8,0,200,165,8,0,104,168,8,0,0,0,0,0,0,0,0,0,0,0,0,0,242,1,0,0,126,8,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,71,32,0,224,194,37,0,208,172,8,0,152,168,8,0,72,173,8,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,0,252,5,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,112,32,0,112,216,37,0,0,0,0,0,0,0,0,0,208,255,24,0,3,0,0,0,162,9,0,0,0,0,0,0,54,0,0,0,32,1,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,135,32,0,200,229,37,0,136,150,30,0,16,150,30,0,96,62,30,0,0,0,0,0,0,0,0,0,0,0,0,0,70,0,0,0,138,1,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,57,39,0,184,208,39,0,0,0,0,0,124,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,148,39,0,80,226,39,0,0,0,0,0,125,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,7,0,0,0,0,0,0,0,0,0,0,218,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,201,33,0,128,117,38,0,192,179,36,0,184,201,33,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,72,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,156,2,0,0,136,1,0,0,46,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,201,33,0,128,117,38,0,0,0,0,0,0,0,0,0,240,95,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,10,0,0,46,7,0,0,26,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,228,60,0,188,15,61,0,24,53,61,0,42,100,61,0,188,143,61,0,24,181,61,0,42,228,61,0,188,15,62,0,24,53,62,0,42,100,62,0,188,143,62,0,24,181,62,0,42,228,62,0,188,15,63,0,24,53,63,0,42,100,63,0,188,143,63,0,24,181,63,0,42,228,63,0,188,15,64,0,24,53,64,0,42,100,64,0,188,143,64,0,24,181,64,0,42,228,64,0,188,15,65,0,24,53,65,0,42,100,65,0,188,143,65,0,24,181,65,0,42,228,65,0,188,15,66,0,24,53,66,0,42,100,66,0,188,143,66,0,24,181,66,0,42,228,66,0,188,15,67,0,24,53,67,0,42,100,67,0,188,143,67,0,24,181,67,0,42,228,67,0,188,15,68,0,24,53,68,0,42,100,68,0,188,143,68,0,24,181,68,0,42,228,68,0,188,15,69,0,24,53,69,0,42,100,69,0,188,143,69,0,24,181,69,0,42,228,69,0,188,15,70,0,24,53,70,0,42,100,70,0,188,143,70,0,24,181,70,0,42,228,70,0,188,15,71,0,24,53,71,0,42,100,71,0,0,16,0,32,0,48,0,64,0,80,0,96,0,112,0,128,0,160,0,192,0,224,0,0,1,32,1,64,1,96,1,128,1,192,1,0,2,64,2,128,2,192,2,0,3,128,3,0,4,128,4,0,5,128,5,0,6,128,6,0,7,128,7,0,8,0,0,0,0,0,0,0,0,0,0,0,126,63,63,0,204,229,62,0,36,164,62,0,230,80,62,0,50,25,62,0,66,148,61,0,230,17,61,144,159,30,0,136,159,30,0,0,0,0,0,0,0,0,0,3,0,0,0,5,0,0,0,8,0,0,0,8,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,5,0,0,0,176,159,30,0,168,159,30,0,160,159,30,0,152,159,30,0,208,159,30,0,200,159,30,0,192,159,30,0,184,159,30,0,248,169,30,0,184,169,30,0,0,0,0,0,0,0,0,0,168,169,30,0,152,169,30,0,0,0,0,0,0,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,152,171,30,0,152,171,30,0,24,171,30,0,152,170,30,0,120,170,30,0,120,170,30,0,88,170,30,0,56,170,30,0,200,172,30,0,200,172,30,0,136,172,30,0,72,172,30,0,56,172,30,0,56,172,30,0,40,172,30,0,24,172,30,0,0,0,0,0,0,0,0,0,168,176,30,0,0,0,0,0,4,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,192,176,30,0,184,176,30,0,184,176,30,0,176,176,30,0,216,176,30,0,208,176,30,0,208,176,30,0,200,176,30,0,64,150,39,0,192,226,39,0,1,0,0,0,40,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,9,0,0,0,0,0,0,0,0,0,0,194,1,0,0,238,8,0,0,0,0,0,0,0,0,0,0,72,151,39,0,40,227,39,0,1,0,0,0,31,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,106,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,184,2,0,0,112,11,0,0,0,0,0,0,0,0,0,0,56,152,39,0,136,227,39,0,1,0,0,0,47,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,0,0,0,244,2,0,0,156,10,0,0,0,0,0,0,0,0,0,0,0,8,1,9,16,24,17,25,2,10,3,11,18,26,19,27,4,12,5,13,32,40,33,41,6,14,7,15,20,28,21,29,34,42,35,43,48,56,49,57,22,30,23,31,36,44,37,45,50,58,51,59,38,46,39,47,52,60,53,61,54,62,55,63,3,4,3,3,3,2,0,3,2,2,2,3,2,4,0,0,1,2,13,4,15,4,12,4,5,3,14,4,4,3,0,2,2,2,7,5,11,5,3,5,13,5,5,5,9,5,1,5,14,5,6,5,10,5,2,5,12,5,4,5,8,5,3,2,15,5,0,0,0,0,0,0,0,2,59,6,10,4,58,6,2,3,57,6,60,6,56,6,3,3,61,6,8,4,31,5,9,4,11,4,13,4,12,4,63,10,47,10,55,10,39,10,59,10,43,10,51,10,35,10,61,10,45,10,53,10,37,10,57,10,41,10,49,10,33,10,31,8,23,8,27,8,19,8,29,8,21,8,25,8,17,8,15,6,11,6,13,6,9,6,7,4,5,4,3,2,0,5,2,2,4,4,6,4,8,6,12,6,10,6,14,6,16,8,24,8,20,8,28,8,18,8,26,8,22,8,30,8,32,10,48,10,40,10,56,10,36,10,52,10,44,10,60,10,34,10,50,10,42,10,58,10,38,10,54,10,46,10,62,10,0,0,184,130,37,0,216,34,36,0,0,0,0,0,33,0,0,0,0,0,0,0,0,0,0,0,184,97,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,8,0,0,0,0,0,0,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,130,37,0,232,34,36,0,0,0,0,0,33,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,10,0,0,0,0,0,0,0,0,0,0,18,0,0,0,214,1,0,0,0,0,0,0,0,0,0,0,104,153,39,0,200,227,39,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,8,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,8,0,0,0,0,0,0,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,154,39,0,88,228,39,0,0,0,0,0,32,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,10,0,0,0,0,0,0,0,0,0,0,18,0,0,0,214,1,0,0,0,0,0,0,0,0,0,0,88,203,33,0,24,118,38,0,0,0,0,0,88,203,33,0,16,80,83,80,0,0,0,0,0,0,0,0,0,0,0,0,248,95,40,0,48,182,30,0,0,0,0,0,48,0,0,0,136,3,0,0,12,2,0,0,238,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,203,33,0,136,118,38,0,0,1,0,0,208,203,33,0,0,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,1,0,0,134,11,0,0,218,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,204,33,0,200,118,38,0,160,180,36,0,72,142,35,0,0,0,0,0,0,0,0,0,4,112,1,0,192,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,46,6,0,0,236,0,0,0,118,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,131,37,0,0,35,36,0,3,0,0,0,32,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,6,0,0,246,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,204,33,0,32,119,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,58,10,0,0,4,6,0,0,164,0,0,0,152,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,64,131,37,0,48,35,36,0,3,0,0,0,32,83,83,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,10,0,0,0,0,0,0,0,0,0,0,236,2,0,0,178,4,0,0,0,0,0,0,0,0,0,0,184,156,32,0,56,238,37,0,0,0,0,0,232,158,8,0,64,161,8,0,0,0,0,0,118,7,0,0,0,0,0,0,210,0,0,0,16,4,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,179,32,0,120,247,37,0,0,0,0,0,152,48,30,0,120,205,30,0,0,0,0,0,204,6,0,0,0,0,0,0,0,0,0,0,112,8,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,167,34,0,192,193,38,0,0,0,0,0,232,255,30,0,64,2,31,0,0,0,0,0,166,6,0,0,0,0,0,0,174,1,0,0,54,5,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,31,36,0,216,30,35,0,0,0,0,0,16,49,30,0,96,22,32,0,0,0,0,0,46,4,0,0,0,0,0,0,50,2,0,0,172,1,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,36,36,0,168,105,32,0,152,241,18,0,0,0,0,0,16,242,18,0,0,0,0,0,0,0,0,0,0,0,0,0,234,0,0,0,88,7,0,0,72,0,0,0,0,0,0,0,0,0,0,0,184,2,0,0,152,195,32,0,232,253,37,0,136,49,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,233,39,0,168,105,32,0,0,50,30,0,0,0,0,0,16,21,32,0,0,0,0,0,0,0,0,0,0,0,0,0,234,0,0,0,88,7,0,0,72,0,0,0,0,0,0,0,0,0,0,0,184,2,0,0,192,239,25,188,77,91,207,17,168,253,0,128,95,92,68,43,0,87,251,32,85,91,207,17,168,253,0,128,95,92,68,43,216,179,34,0,16,120,38,0,104,181,36,0,168,142,35,0,8,80,1,0,17,0,0,0,0,0,0,0,64,0,0,0,56,96,40,0,0,0,0,0,0,0,0,0,104,109,2,0,56,4,0,0,154,2,0,0,96,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,7,220,183,183,169,207,17,142,230,0,192,12,32,83,101,144,8,0,51,177,229,207,17,137,244,0,160,201,3,73,203,32,219,254,76,246,117,207,17,156,15,0,160,201,3,73,203,96,206,33,0,16,120,38,0,104,181,36,0,168,142,35,0,8,80,1,0,17,0,0,0,0,0,0,0,64,0,0,0,32,108,40,0,0,0,0,0,0,0,0,0,104,109,2,0,158,5,0,0,154,2,0,0,96,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,28,35,68,152,148,209,73,161,65,29,19,78,69,112,84,234,203,248,197,175,91,119,72,132,103,170,140,68,250,76,202,0,203,39,0,80,242,39,0,96,138,37,0,48,40,36,0,24,38,35,0,192,92,34,0,224,180,33,0,168,53,33,0,144,200,32,0,224,106,32,0,0,83,40,0,152,247,39,0,72,141,39,0,192,53,39,0,64,239,38,0,80,168,38,0,240,107,38,0,104,53,38,0,168,0,38,0,72,214,37,0,160,175,37,0,128,140,37,0,72,76,37,0,128,25,37,0,200,244,36,0,192,53,39,0,56,205,36,0,48,176,36,0,152,147,36,0,64,120,36,0,104,93,36,0,16,67,36,0,0,0,0,0,0,0,0,0,1,205,135,244,81,169,207,17,142,230,0,192,12,32,83,101,169,70,67,124,224,239,252,75,178,41,57,62,222,65,92,133,0,225,27,182,78,91,207,17,168,253,0,128,95,92,68,43,48,38,178,117,142,102,207,17,166,217,0,170,0,98,206,108,17,210,211,171,186,169,207,17,142,230,0,192,12,32,83,101,181,3,191,95,46,169,207,17,142,227,0,192,12,32,83,101,161,220,171,140,71,169,207,17,142,228,0,192,12,32,83,101,64,164,208,210,7,227,210,17,151,240,0,160,201,94,168,80,203,165,230,20,114,198,50,67,131,153,169,105,82,6,91,90,226,101,251,58,239,71,242,64,172,44,112,169,13,113,211,67,157,140,23,49,225,3,40,69,181,130,61,249,219,34,245,3,20,230,138,41,34,38,23,76,185,53,218,224,126,233,40,156,252,179,17,34,35,189,210,17,180,183,0,160,201,85,252,110,56,215,33,0,0,123,38,0,0,96,0,0,0,0,0,0,0,0,0,0,136,185,30,0,0,0,0,0,0,0,0,0,216,107,2,0,164,10,0,0,144,8,0,0,30,3,0,0,90,11,0,0,20,0,0,0,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,38,178,117,142,102,207,17,166,217,0,170,0,98,206,108,251,179,17,34,35,189,210,17,180,183,0,160,201,85,252,110,51,38,178,117,142,102,207,17,166,217,0,170,0,98,206,108,192,207,218,89,230,89,208,17,163,172,0,160,201,3,72,246,64,82,209,134,29,49,208,17,163,164,0,160,201,3,72,246,65,82,209,134,29,49,208,17,163,164,0,160,201,3,72,246,64,158,105,248,77,91,207,17,168,253,0,128,95,92,68,43,80,205,195,191,143,97,207,17,139,178,0,170,0,180,226,32,216,215,33,0,112,123,38,0,0,0,0,0,72,183,36,0,0,0,0,0,24,195,30,0,0,0,0,0,0,0,0,0,32,0,0,0,146,1,0,0,18,11,0,0,48,3,0,0,126,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,224,217,33,0,128,124,38,0,0,0,0,0,200,183,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,44,5,0,0,136,10,0,0,228,3,0,0,164,2,0,0,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,159,39,0,128,229,39,0,1,0,0,0,33,80,1,0,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,107,40,0,0,0,0,0,0,0,0,0,216,199,30,0,0,0,0,0,40,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,1,0,0,0,0,0,0,0,0,0,0,22,0,0,0,50,8,0,0,214,1,0,0,0,0,0,0,232,218,33,0,184,124,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,2,0,0,100,1,0,0,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,161,39,0,224,229,39,0,0,0,0,0,143,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,5,0,0,0,0,0,0,0,0,0,0,78,2,0,0,132,9,0,0,0,0,0,0,0,0,0,0,224,220,33,0,0,125,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,12,0,0,142,7,0,0,114,7,0,0,204,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,162,39,0,104,230,39,0,0,0,0,0,135,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,2,0,0,0,0,0,0,0,0,0,0,254,0,0,0,220,5,0,0,0,0,0,0,0,0,0,0,208,37,33,0,32,186,32,0,0,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,8,94,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,172,1,0,0,0,0,0,0,178,9,0,0,0,0,0,0,0,0,0,0,248,83,37,0,88,247,35,0,0,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,192,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,3,0,0,0,0,0,0,0,0,0,0,204,2,0,0,138,5,0,0,0,0,0,0,0,0,0,0,168,163,39,0,232,230,39,0,1,0,0,0,1,32,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,4,0,0,0,0,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,164,39,0,32,231,39,0,1,0,0,0,0,32,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,9,0,0,0,0,0,0,0,0,0,0,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,223,33,0,152,125,38,0,56,184,36,0,96,223,33,0,0,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,1,0,0,32,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,223,33,0,152,125,38,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,6,0,0,110,0,0,0,200,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,24,1,9,2,10,17,25,32,40,48,56,57,49,41,33,26,18,3,11,4,12,19,27,34,42,50,58,35,43,51,59,20,28,5,13,6,14,21,29,36,44,52,60,37,45,53,61,22,30,7,15,23,31,38,46,54,62,39,47,55,63,0,1,2,3,8,9,16,17,10,11,4,5,6,7,15,14,13,12,19,18,24,25,32,33,26,27,20,21,22,23,28,29,30,31,34,35,40,41,48,49,42,43,36,37,38,39,44,45,46,47,50,51,56,57,58,59,52,53,54,55,60,61,62,63,96,166,39,0,88,231,39,0,1,0,0,0,46,80,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,202,2,0,0,138,4,0,0,8,2,0,0,0,0,0,0,88,13,37,0,160,101,39,0,1,0,0,0,16,80,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,98,40,0,64,224,21,0,0,0,0,0,0,0,0,0,0,0,0,0,120,193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,9,0,0,0,0,0,0,166,1,0,0,0,0,0,0,96,8,0,0,0,0,0,0,0,0,0,0,224,14,37,0,0,102,39,0,1,0,0,0,16,80,1,0,2,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,5,0,0,0,0,0,0,0,0,0,0,198,2,0,0,114,10,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,55,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,1,0,0,0,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,2,0,1,0,0,0,0,0,2,0,1,3,0,0,0,0,2,0,1,3,4,0,0,0,2,0,1,4,5,3,0,0,2,0,1,4,5,6,3,0,2,6,7,0,1,4,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,96,211,39,0,192,243,39,0,8,139,37,0,160,40,36,0,1,0,1,0,62,0,0,0,0,0,0,0,0,0,0,0,48,107,40,0,40,222,30,0,0,0,0,0,48,0,0,0,244,0,0,0,130,0,0,0,176,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,211,39,0,216,243,39,0,0,0,0,0,0,0,0,0,56,107,40,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,38,2,0,0,202,2,0,0,240,3,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,16,37,0,64,102,39,0,0,0,0,0,170,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,6,0,0,0,0,0,0,0,0,0,0,108,0,0,0,230,10,0,0,0,0,0,0,0,0,0,0,0,2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,48,212,39,0,240,243,39,0,0,224,0,0,48,212,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,34,5,0,0,196,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,17,34,0,112,139,38,0,96,222,3,0,232,221,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,1,0,0,68,6,0,0,8,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,56,22,34,0,240,140,38,0,240,50,30,0,120,50,30,0,136,224,3,0,0,0,1,0,32,0,0,0,0,0,0,0,84,1,0,0,178,1,0,0,184,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,64,193,34,0,160,0,34,0,104,85,16,0,184,67,11,0,200,167,4,0,0,0,0,0,50,4,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,24,34,0,152,141,38,0,184,163,8,0,80,162,8,0,48,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,6,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,29,34,0,248,142,38,0,120,97,10,0,0,97,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,1,0,0,36,6,0,0,156,203,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,34,34,0,112,145,38,0,184,58,11,0,224,57,11,0,48,59,11,0,0,0,0,0,204,1,0,0,0,0,0,0,156,1,0,0,254,10,0,0,176,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,29,40,0,16,188,39,0,104,85,16,0,184,67,11,0,224,9,14,0,0,0,0,0,198,8,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,40,34,0,120,147,38,0,0,0,0,0,104,51,30,0,112,211,15,0,1,0,0,0,130,1,0,0,0,0,0,0,168,1,0,0,8,5,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,87,39,0,152,11,39,0,104,85,16,0,184,67,11,0,40,218,16,0,0,0,0,0,82,3,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,99,34,0,8,172,38,0,104,85,16,0,184,67,11,0,208,12,23,0,0,0,0,0,56,9,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,77,39,0,72,211,39,0,0,28,23,0,0,0,0,0,120,28,23,0,2,0,0,0,146,0,0,0,0,0,0,0,138,0,0,0,182,6,0,0,144,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,42,34,0,24,148,38,0,96,30,23,0,232,29,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,58,34,0,168,155,38,0,16,3,25,0,24,1,25,0,136,3,25,0,0,0,0,0,108,11,0,0,0,0,0,0,18,2,0,0,36,8,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,64,34,0,120,157,38,0,224,51,30,0,0,0,0,0,24,30,26,0,2,0,0,0,14,8,0,0,0,0,0,0,0,0,0,0,58,7,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,68,34,0,216,159,38], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1424888);
/* memory initializer */ allocate([208,52,30,0,88,52,30,0,248,30,26,0,0,0,0,0,52,7,0,0,0,0,0,0,0,0,0,0,218,9,0,0,32,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,74,38,0,72,19,38,0,104,85,16,0,184,67,11,0,88,54,29,0,0,0,0,0,84,10,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,206,36,0,96,159,35,0,104,85,16,0,184,67,11,0,40,216,29,0,0,0,0,0,200,10,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,146,32,0,128,55,32,0,104,85,16,0,184,67,11,0,24,228,29,0,0,0,0,0,244,3,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,109,33,0,80,246,32,0,104,85,16,0,184,67,11,0,88,230,29,0,0,0,0,0,214,2,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,95,37,0,184,170,39,0,160,153,30,0,24,151,30,0,24,154,30,0,0,0,0,0,16,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,101,34,0,192,172,38,0,216,177,30,0,0,177,30,0,80,178,30,0,0,0,0,0,134,9,0,0,0,0,0,0,158,0,0,0,34,9,0,0,208,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,240,103,34,0,120,173,38,0,200,179,30,0,128,178,30,0,128,180,30,0,0,0,0,0,180,3,0,0,0,0,0,0,200,1,0,0,242,2,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,110,34,0,184,174,38,0,136,181,30,0,176,180,30,0,0,182,30,0,0,0,0,0,0,0,0,0,0,0,0,0,140,0,0,0,124,2,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,97,37,0,24,5,36,0,72,53,30,0,0,0,0,0,80,185,30,0,2,0,0,0,78,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,112,34,0,88,175,38,0,224,85,16,0,48,68,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,104,37,0,0,12,36,0,56,54,30,0,192,53,30,0,72,186,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,114,34,0,144,176,38,0,128,187,30,0,120,186,30,0,248,187,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,5,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,99,37,0,216,6,36,0,160,188,30,0,40,188,30,0,24,189,30,0,0,0,0,0,162,7,0,0,0,0,0,0,248,0,0,0,0,0,0,0,184,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,117,34,0,104,177,38,0,176,190,30,0,72,189,30,0,40,191,30,0,0,0,0,0,42,11,0,0,0,0,0,0,78,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,107,37,0,160,191,39,0,208,191,30,0,88,191,30,0,72,192,30,0,0,0,0,0,102,7,0,0,0,0,0,0,20,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,245,38,0,240,197,39,0,176,54,30,0,0,0,0,0,104,193,30,0,2,0,0,0,218,10,0,0,0,0,0,0,154,1,0,0,0,0,0,0,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,120,34,0,32,178,38,0,16,194,30,0,152,193,30,0,136,194,30,0,0,0,0,0,0,0,0,0,148,0,0,0,92,0,0,0,160,1,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,128,34,0,248,179,38,0,224,197,30,0,88,195,30,0,88,198,30,0,0,0,0,0,30,0,0,0,0,0,0,0,116,0,0,0,132,6,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,3,39,0,64,201,39,0,0,199,30,0,136,198,30,0,120,199,30,0,0,0,0,0,72,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,130,34,0,200,180,38,0,128,203,30,0,72,202,30,0,248,203,30,0,0,0,2,0,100,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,131,34,0,16,181,38,0,160,55,30,0,40,55,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,134,34,0,184,182,38,0,0,0,0,0,24,56,30,0,216,211,30,0,1,0,0,0,22,1,0,0,0,0,0,0,28,2,0,0,104,5,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,141,34,0,112,184,38,0,0,0,0,0,8,212,30,0,224,212,30,0,1,0,0,0,208,7,0,0,0,0,0,0,88,1,0,0,222,10,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,38,0,32,133,38,0,104,85,16,0,184,67,11,0,48,217,30,0,0,0,0,0,164,9,0,0,0,0,0,0,104,0,0,0,160,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,116,37,0,232,22,36,0,0,0,0,0,240,220,30,0,248,221,30,0,1,0,0,0,200,5,0,0,0,0,0,0,222,1,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,143,34,0,120,186,38,0,8,57,30,0,144,56,30,0,216,250,30,0,0,0,0,0,170,1,0,0,0,0,0,0,0,0,0,0,132,10,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,104,37,0,72,11,36,0,248,57,30,0,128,57,30,0,0,0,0,0,0,0,0,0,72,8,0,0,0,0,0,0,64,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,148,34,0,120,188,38,0,232,58,30,0,112,58,30,0,184,255,30,0,0,0,1,0,206,7,0,0,0,0,0,0,0,0,0,0,40,3,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,215,36,0,200,166,35,0,176,3,31,0,120,2,31,0,56,4,31,0,0,0,0,0,166,6,0,0,0,0,0,0,174,1,0,0,198,2,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,157,34,0,152,190,38,0,208,5,31,0,104,4,31,0,72,6,31,0,0,0,0,0,76,3,0,0,0,0,0,0,98,1,0,0,174,0,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,159,34,0,16,191,38,0,176,135,31,0,216,134,31,0,40,136,31,0,0,0,2,0,0,0,0,0,0,0,0,0,44,0,0,0,112,1,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,160,34,0,72,192,38,0,208,177,31,0,200,176,31,0,72,178,31,0,0,0,0,0,32,7,0,0,0,0,0,0,58,2,0,0,122,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,212,39,0,248,243,39,0,0,1,0,0,136,212,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,6,0,0,210,6,0,0,210,2,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,68,35,0,240,119,34,0,0,0,0,0,32,68,35,0,9,16,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,213,39,0,8,244,39,0,0,1,0,0,96,213,39,0,0,0,0,0,0,0,0,0,0,0,0,0,9,16,1,0,4,0,0,0,0,0,0,0,12,8,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,217,39,0,224,244,39,0,96,139,37,0,0,41,36,0,2,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,6,31,0,0,0,0,0,76,1,0,0,150,6,0,0,186,3,0,0,148,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,230,0,230,0,230,0,51,1,153,1,0,2,102,2,230,0,230,0,230,0,230,0,51,1,153,1,0,2,102,2,216,167,32,0,136,76,32,0,1,0,0,0,14,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,7,0,0,0,0,0,0,56,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,1,3,5,7,9,11,13,15,255,253,251,249,247,245,243,241,24,189,33,0,168,175,33,0,1,0,0,0,14,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,208,33,0,16,198,33,0,1,0,0,0,8,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,33,0,136,219,33,0,1,0,0,0,18,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,138,33,0,32,15,33,0,1,0,0,0,13,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,7,0,0,0,0,0,0,56,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,32,11,34,0,56,252,33,0,1,0,0,0,13,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,16,0,17,0,19,0,21,0,23,0,25,0,28,0,31,0,34,0,37,0,41,0,45,0,50,0,55,0,60,0,66,0,73,0,80,0,88,0,97,0,107,0,118,0,130,0,143,0,157,0,173,0,190,0,209,0,230,0,253,0,23,1,51,1,81,1,115,1,152,1,193,1,238,1,32,2,86,2,146,2,212,2,28,3,108,3,195,3,36,4,142,4,2,5,131,5,16,6,171,6,86,7,18,8,224,8,195,9,189,10,208,11,255,12,76,14,186,15,76,17,7,19,238,20,6,23,84,25,220,27,165,30,182,33,21,37,202,40,223,44,91,49,75,54,185,59,178,65,68,72,126,79,113,87,47,96,206,105,98,116,255,127,0,0,0,0,0,0,96,45,34,0,120,25,34,0,1,0,0,0,15,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,105,34,0,80,85,34,0,1,0,0,0,16,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,137,34,0,96,122,34,0,1,0,0,0,17,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,0,19,0,21,0,23,0,25,0,28,0,31,0,34,0,37,0,41,0,45,0,50,0,55,0,60,0,66,0,73,0,80,0,88,0,97,0,107,0,118,0,130,0,143,0,157,0,173,0,190,0,209,0,230,0,253,0,23,1,51,1,81,1,115,1,152,1,193,1,238,1,32,2,86,2,146,2,212,2,28,3,108,3,195,3,36,4,142,4,2,5,131,5,16,6,0,0,0,0,0,0,152,238,34,0,248,41,34,0,1,0,0,0,6,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,7,0,0,0,0,0,0,56,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,88,169,34,0,88,151,34,0,1,0,0,0,6,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,134,31,0,200,134,31,0,88,244,21,0,168,134,31,0,255,255,255,255,2,4,6,8,255,255,255,255,2,4,6,8,248,203,34,0,96,187,34,0,1,0,0,0,4,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,37,0,40,223,35,0,1,0,0,0,1,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,7,0,0,0,0,0,0,56,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,128,242,34,0,176,218,34,0,1,0,0,0,1,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,52,35,0,120,29,35,0,1,0,0,0,5,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,88,35,0,32,71,35,0,1,0,0,0,32,68,65,82,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,20,37,0,248,102,39,0,1,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,7,0,0,0,0,0,0,56,0,0,0,0,0,0,0,152,0,0,0,0,0,0,0,0,0,0,0,112,130,35,0,64,108,35,0,1,0,0,0,0,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,173,35,0,208,151,35,0,1,0,0,0,32,73,75,79,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,228,35,0,104,197,35,0,1,0,0,0,27,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,58,36,0,16,30,36,0,1,0,0,0,23,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,110,36,0,192,83,36,0,1,0,0,0,24,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,164,36,0,152,138,36,0,1,0,0,0,3,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,229,36,0,24,195,36,0,1,0,0,0,2,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,12,4,20,0,0,0,0,16,32,8,32,0,0,0,0,80,57,37,0,56,15,37,0,1,0,0,0,29,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,163,37,0,160,124,37,0,1,0,0,0,19,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,111,37,0,120,18,36,0,1,0,0,0,71,55,50,54,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,4,0,0,0,0,0,0,0,0,0,0,228,2,0,0,0,0,0,0,218,1,0,0,0,0,0,0,224,239,38,0,64,197,39,0,1,0,0,0,11,16,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,104,40,0,0,0,0,0,0,0,0,0,168,94,18,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,236,23,0,0,0,0,0,168,2,0,0,0,0,0,0,216,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,239,38,0,64,197,39,0,1,0,0,0,11,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,4,0,0,0,0,0,0,0,0,0,0,228,2,0,0,0,0,0,0,218,1,0,0,0,0,0,0,208,242,38,0,152,197,39,0,1,0,0,0,28,16,1,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,104,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,2,0,0,0,0,0,0,130,1,0,0,0,0,0,0,234,9,0,0,0,0,0,0,0,0,0,0,8,243,38,0,168,197,39,0,1,0,0,0,28,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,95,18,0,0,0,0,0,148,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,3,0,0,0,0,0,0,0,0,0,0,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,243,37,0,136,198,37,0,1,0,0,0,25,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,89,38,0,112,36,38,0,1,0,0,0,21,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,217,38,0,72,148,38,0,1,0,0,0,22,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,112,39,0,216,30,39,0,1,0,0,0,20,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,51,40,0,144,215,39,0,1,0,0,0,26,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,32,0,160,76,32,0,1,0,0,0,10,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,138,33,0,64,15,33,0,1,0,0,0,32,75,84,68,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,239,34,0,136,42,34,0,1,0,0,0,12,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,52,37,0,224,223,35,0,1,0,0,0,32,67,70,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,4,0,16,0,14,0,12,0,18,104,16,192,18,0,20,0,8,0,4,0,252,0,252,0,248,0,0,0,0,0,8,0,4,0,248,0,250,0,252,0,246,56,247,4,247,0,244,0,248,0,252,0,4,0,0,0,0,112,17,37,0,104,102,39,0,1,0,0,0,9,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,3,0,0,0,0,0,0,146,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,17,37,0,128,102,39,0,1,0,0,0,9,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,98,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,10,0,0,0,0,0,0,0,0,0,0,152,1,0,0,0,0,0,0,176,0,0,0,0,0,0,0,230,0,230,0,230,0,230,0,51,1,153,1,0,2,102,2,0,3,102,2,0,2,153,1,51,1,230,0,230,0,230,0,0,192,0,16,0,204,198,0,64,128,0,48,60,115,98,0,0,27,37,0,72,104,39,0,1,0,0,0,7,16,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,0,0,0,0,0,0,0,0,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,219,39,0,112,245,39,0,0,0,0,0,112,139,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,0,0,0,136,0,0,0,100,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,238,32,0,184,138,32,0,0,0,0,0,120,238,32,0,0,0,0,0,240,107,40,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,164,6,0,0,148,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,223,39,0,176,245,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,116,4,0,0,246,6,0,0,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,115,186,110,119,98,225,79,109,57,245,33,71,12,184,250,206,238,23,233,38,233,191,237,33,245,96,253,187,4,232,9,58,12,175,11,211,8,146,4,0,0,23,252,140,249,180,248,126,249,133,251,48,254,218,0,244,2,36,4,75,4,136,3,38,2,135,0,11,255,254,253,134,253,166,253,61,254,25,255,0,0,191,0,52,1,84,1,40,1,198,0,78,0,220,255,136,255,93,255,91,255,124,255,177,255,237,255,34,0,73,0,91,0,89,0,70,0,38,0,0,0,0,0,0,0,0,0,4,0,7,0,12,0,16,0,21,0,28,0,34,0,42,0,51,0,61,0,72,0,84,0,97,0,111,0,127,0,145,0,164,0,184,0,207,0,231,0,1,1,29,1,59,1,91,1,126,1,163,1,202,1,244,1,32,2,79,2,129,2,182,2,238,2,42,3,104,3,169,3,239,3,55,4,131,4,211,4,38,5,126,5,217,5,57,6,156,6,4,7,111,7,224,7,84,8,205,8,75,9,205,9,84,10,223,10,111,11,4,12,158,12,61,13,224,13,137,14,54,15,232,15,159,16,92,17,29,18,227,18,174,19,126,20,83,21,45,22,11,23,239,23,215,24,196,25,181,26,171,27,166,28,165,29,168,30,176,31,188,32,204,33,223,34,247,35,19,37,50,38,85,39,123,40,164,41,208,42,0,44,50,45,103,46,158,47,216,48,20,50,82,51,146,52,212,53,23,55,91,56,161,57,231,58,47,60,119,61,191,62,8,64,80,65,153,66,225,67,41,69,112,70,182,71,251,72,63,74,130,75,195,76,2,78,63,79,122,80,178,81,233,82,28,84,77,85,123,86,166,87,205,88,241,89,18,91,47,92,72,93,93,94,110,95,123,96,132,97,137,98,137,99,132,100,123,101,109,102,91,103,67,104,39,105,6,106,223,106,180,107,132,108,79,109,20,110,213,110,144,111,70,112,247,112,163,113,74,114,236,114,137,115,33,116,180,116,66,117,203,117,80,118,207,118,74,119,193,119,51,120,160,120,9,121,110,121,206,121,42,122,131,122,215,122,40,123,117,123,190,123,3,124,70,124,133,124,192,124,249,124,46,125,97,125,145,125,190,125,232,125,16,126,54,126,89,126,122,126,153,126,182,126,209,126,234,126,1,127,23,127,44,127,62,127,80,127,96,127,111,127,124,127,137,127,149,127,159,127,169,127,178,127,186,127,193,127,200,127,206,127,212,127,217,127,221,127,225,127,229,127,232,127,235,127,238,127,240,127,242,127,244,127,245,127,247,127,248,127,249,127,250,127,251,127,252,127,252,127,253,127,253,127,254,127,254,127,254,127,254,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,0,1,0,0,1,1,0,1,2,0,2,0,0,2,1,0,2,2,1,0,0,1,0,1,1,0,2,1,1,0,1,1,1,1,1,2,1,2,0,1,2,1,1,2,2,2,0,0,2,0,1,2,0,2,2,1,0,2,1,1,2,1,2,2,2,0,2,2,1,2,2,2,3,0,0,3,0,1,3,0,2,3,1,0,3,1,1,64,5,216,4,120,4,16,4,15,17,19,21,0,0,0,0,128,187,68,172,0,125,0,0,13,25,37,61,253,0,0,0,3,80,1,0,41,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,188,11,0,0,2,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,66,32,0,80,193,37,0,48,80,36,0,104,66,32,0,3,80,1,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,5,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,63,62,61,60,59,58,57,56,55,54,53,52,52,51,50,49,48,47,47,46,45,44,44,43,42,41,41,40,39,38,38,37,36,36,35,35,34,33,33,32,32,31,30,30,29,29,28,28,27,27,26,26,25,25,24,24,23,23,22,22,21,21,21,20,20,19,19,19,18,18,18,17,17,17,16,16,16,15,15,15,14,14,14,13,13,13,13,12,12,12,12,11,11,11,11,10,10,10,10,10,9,9,9,9,9,8,8,8,8,8,8,7,7,7,7,7,7,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,4,4,4,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,4,240,4,128,5,208,4,240,4,128,5,64,4,96,4,176,4,0,4,16,4,80,4,224,3,224,3,32,4,192,3,208,3,240,3,176,3,192,3,224,3,176,3,176,3,208,3,160,3,176,3,192,3,160,3,160,3,176,3,160,3,160,3,176,3,160,3,160,3,176,3,160,3,160,3,160,3,144,3,160,3,160,3,144,3,144,3,160,3,144,3,144,3,160,3,128,3,144,3,160,3,128,3,128,3,160,3,112,3,128,3,160,3,112,3,128,3,160,3,96,3,112,3,144,3,96,3,112,3,144,3,80,3,96,3,144,3,80,3,96,3,144,3,64,3,80,3,128,3,64,3,80,3,128,3,48,3,64,3,128,3,32,3,64,3,112,3,16,3,32,3,96,3,0,3,16,3,80,3,240,2,0,3,64,3,240,2,240,2,48,3,240,2,240,2,32,3,240,2,240,2,16,3,0,3,240,2,0,3,16,3,0,3,240,2,64,3,32,3,240,2,144,3,80,3,240,2,224,3,144,3,0,3,32,4,224,3,16,3,96,4,32,4,48,3,144,4,80,4,80,3,160,4,160,4,192,3,96,4,144,4,16,4,64,4,96,4,112,4,64,4,64,4,160,4,32,5,128,4,96,4,0,8,48,6,64,4,64,8,64,8,80,4,64,8,64,8,224,4,0,0,0,0,64,0,69,0,96,0,64,0,70,0,96,0,80,0,87,0,120,0,80,0,88,0,120,0,96,0,104,0,144,0,96,0,105,0,144,0,112,0,121,0,168,0,112,0,122,0,168,0,128,0,139,0,192,0,128,0,140,0,192,0,160,0,174,0,240,0,160,0,175,0,240,0,192,0,208,0,32,1,192,0,209,0,32,1,224,0,243,0,80,1,224,0,244,0,80,1,0,1,22,1,128,1,0,1,23,1,128,1,64,1,92,1,224,1,64,1,93,1,224,1,128,1,161,1,64,2,128,1,162,1,64,2,192,1,231,1,160,2,192,1,232,1,160,2,0,2,45,2,0,3,0,2,46,2,0,3,128,2,184,2,192,3,128,2,185,2,192,3,0,3,67,3,128,4,0,3,68,3,128,4,128,3,207,3,64,5,128,3,208,3,64,5,0,4,90,4,0,6,0,4,91,4,0,6,128,4,229,4,192,6,128,4,230,4,192,6,0,5,113,5,128,7,0,5,114,5,128,7,0,0,0,0,240,2,176,2,112,2,48,2,240,1,112,1,240,0,0,248,144,53,37,0,176,224,35,0,1,0,0,0,3,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,99,40,0,8,12,22,0,0,0,0,0,120,250,31,0,0,0,0,0,160,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,16,32,0,0,0,0,0,132,8,0,0,0,0,0,0,124,1,0,0,0,0,0,0,2,6,0,0,0,0,0,0,0,0,0,0,128,0,0,1,128,1,0,2,128,2,0,3,128,3,0,4,63,83,103,123,0,0,0,0,104,53,37,0,120,224,35,0,1,0,0,0,3,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,40,0,8,12,22,0,0,0,0,0,72,250,31,0,0,0,0,0,160,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,16,32,0,0,0,0,0,60,11,0,0,0,0,0,0,26,3,0,0,0,0,0,0,2,6,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,2,0,0,0,0,2,1,0,0,0,0,2,1,3,0,0,0,1,2,0,0,0,0,1,3,2,0,0,0,2,1,3,0,0,0,2,1,4,3,0,0,1,2,3,0,0,0,1,3,4,2,0,0,2,1,3,4,0,0,2,1,4,5,3,104,226,39,0,200,245,39,0,0,1,0,0,104,226,39,0,0,0,0,0,0,0,0,0,0,0,0,0,3,80,1,0,0,0,0,0,104,10,0,0,148,1,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,35,37,0,80,107,39,0,1,0,0,0,3,80,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,99,40,0,0,0,0,0,0,0,0,0,72,17,32,0,0,0,0,0,32,211,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,1,0,0,0,0,0,0,0,0,0,0,174,0,0,0,92,9,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,2,0,0,0,0,2,1,0,0,0,0,2,1,3,0,0,0,1,2,0,0,0,0,1,3,2,0,0,0,2,1,3,0,0,0,2,1,4,3,0,0,1,2,3,0,0,0,1,4,2,3,0,0,2,1,3,4,0,0,2,1,5,3,4,0,0,0,7,0,9,0,11,2,1,2,3,3,4,4,5,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,7,0,0,0,0,0,0,0,3,6,0,0,0,0,0,0,51,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,7,6,0,0,0,0,0,0,55,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,11,1,0,0,0,0,0,0,15,0,0,0,0,0,0,0,11,6,0,0,0,0,0,0,59,0,0,0,0,0,0,0,15,1,0,0,0,0,0,0,15,6,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,160,0,192,0,224,0,0,1,64,1,128,1,192,1,0,2,64,2,128,2,0,0,0,1,1,1,1,1,2,2,3,3,3,4,4,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,31,34,37,40,43,46,49,55,61,67,73,79,85,97,109,121,133,157,181,205,229,253,0,0,0,0,0,104,35,37,0,136,107,39,0,0,0,0,0,75,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,4,0,0,0,0,0,0,0,0,0,0,244,1,0,0,196,2,0,0,0,0,0,0,0,0,0,0,0,64,197,88,159,83,66,75,0,64,73,50,163,34,168,17,197,88,33,123,252,115,98,104,197,88,191,69,11,48,126,24,159,83,252,115,65,109,84,98,159,83,179,65,65,45,18,23,66,75,98,104,84,98,126,88,66,75,33,59,186,40,195,20,0,64,197,88,159,83,66,75,0,64,73,50,163,34,168,17,73,50,191,69,179,65,33,59], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1435128);
/* memory initializer */ allocate([73,50,130,39,55,27,224,13,163,34,11,48,65,45,186,40,163,34,55,27,191,18,142,9,168,17,126,24,18,23,195,20,168,17,224,13,142,9,223,4,81,0,81,0,81,0,81,0,81,0,81,0,64,0,64,0,169,0,169,0,33,1,0,0,216,167,25,0,144,163,25,0,232,162,25,0,64,162,25,0,152,161,25,0,240,160,25,0,112,160,25,0,240,159,25,0,152,158,25,0,128,166,25,0,56,164,25,0,0,0,0,0,0,22,29,0,208,19,29,0,120,19,29,0,32,19,29,0,200,18,29,0,112,18,29,0,48,18,29,0,240,17,29,0,64,17,29,0,80,21,29,0,40,20,29,0,0,0,0,0,232,255,3,0,230,255,3,0,231,255,3,0,229,255,3,0,245,255,7,0,241,255,7,0,237,255,7,0,246,255,7,0,238,255,7,0,239,255,7,0,240,255,7,0,252,255,7,0,253,255,7,0,255,255,7,0,254,255,7,0,247,255,7,0,248,255,7,0,251,255,7,0,249,255,7,0,228,255,3,0,250,255,7,0,227,255,3,0,239,255,1,0,240,255,1,0,245,255,0,0,238,255,1,0,242,255,0,0,243,255,0,0,244,255,0,0,241,255,0,0,246,127,0,0,247,127,0,0,249,63,0,0,245,63,0,0,247,63,0,0,243,63,0,0,246,63,0,0,242,63,0,0,247,31,0,0,245,31,0,0,249,15,0,0,247,15,0,0,246,15,0,0,249,7,0,0,244,15,0,0,248,7,0,0,249,3,0,0,247,3,0,0,245,3,0,0,248,1,0,0,247,1,0,0,250,0,0,0,248,0,0,0,246,0,0,0,121,0,0,0,58,0,0,0,56,0,0,0,26,0,0,0,11,0,0,0,4,0,0,0,0,0,0,0,10,0,0,0,12,0,0,0,27,0,0,0,57,0,0,0,59,0,0,0,120,0,0,0,122,0,0,0,247,0,0,0,249,0,0,0,246,1,0,0,249,1,0,0,244,3,0,0,246,3,0,0,248,3,0,0,245,7,0,0,244,7,0,0,246,7,0,0,247,7,0,0,245,15,0,0,248,15,0,0,244,31,0,0,246,31,0,0,248,31,0,0,248,63,0,0,244,63,0,0,240,255,0,0,244,127,0,0,246,255,0,0,245,127,0,0,226,255,3,0,217,255,7,0,218,255,7,0,219,255,7,0,220,255,7,0,221,255,7,0,222,255,7,0,216,255,7,0,210,255,7,0,211,255,7,0,212,255,7,0,213,255,7,0,214,255,7,0,242,255,7,0,223,255,7,0,231,255,7,0,232,255,7,0,233,255,7,0,234,255,7,0,235,255,7,0,230,255,7,0,224,255,7,0,225,255,7,0,226,255,7,0,227,255,7,0,228,255,7,0,229,255,7,0,215,255,7,0,236,255,7,0,244,255,7,0,243,255,7,0,0,0,0,0,18,18,18,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,18,19,18,17,17,16,17,16,16,16,16,15,15,14,14,14,14,14,14,13,13,12,12,12,11,12,11,10,10,10,9,9,8,8,8,7,6,6,5,4,3,1,4,4,5,6,6,7,7,8,8,9,9,10,10,10,11,11,11,11,12,12,13,13,13,14,14,16,15,16,15,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,0,0,0,0,0,0,0,136,250,36,0,168,1,0,0,76,1,0,0,0,3,0,0,164,0,0,0,0,0,0,0,33,33,38,40,40,40,41,41,37,37,37,34,34,0,0,0,2,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,38,7,0,0,2,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,37,31,31,0,0,0,0,0,0,0,0,12,12,12,14,14,14,15,15,15,15,15,15,15,0,0,0,41,41,47,49,49,51,47,47,43,43,43,40,40,0,0,0,50,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,10,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,54,37,0,240,225,35,0,1,0,0,0,50,80,1,0,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,96,40,0,0,26,32,0,0,0,0,0,0,0,0,0,0,0,0,0,192,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,11,0,0,0,0,0,0,0,0,0,0,214,1,0,0,10,8,0,0,42,2,0,0,0,0,0,0,48,41,37,0,0,108,39,0,1,0,0,0,2,80,1,0,96,2,0,0,0,0,0,0,0,0,0,0,32,33,12,0,24,99,40,0,0,0,0,0,0,0,0,0,48,25,32,0,0,0,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,7,0,0,0,0,0,0,112,0,0,0,0,0,0,0,196,4,0,0,0,0,0,0,0,0,0,0,233,14,94,59,231,9,186,59,38,226,10,60,33,32,64,60,4,24,123,60,84,24,157,60,243,244,189,60,182,148,223,60,129,204,0,61,11,212,17,61,172,182,34,61,90,101,51,61,96,234,67,61,112,79,84,61,157,156,100,61,248,216,116,61,200,133,130,61,184,157,138,61,169,183,146,61,12,212,154,61,219,240,162,61,169,12,171,61,189,38,179,61,214,63,187,61,212,89,195,61,208,118,203,61,0,153,211,61,126,194,219,61,233,244,227,61,112,49,236,61,245,120,244,61,180,205,252,61,157,153,2,62,89,214,6,62,100,30,11,62,133,114,15,62,18,211,19,62,85,64,24,62,136,186,28,62,95,65,33,62,27,212,37,62,13,114,42,62,154,26,47,62,231,204,51,62,236,135,56,62,193,74,61,62,167,20,66,62,19,229,70,62,165,187,75,62,19,152,80,62,36,122,85,62,166,97,90,62,98,78,95,62,29,64,100,62,159,54,105,62,222,49,110,62,0,50,115,62,24,55,120,62,42,65,125,62,19,40,129,62,249,177,131,62,51,62,134,62,171,204,136,62,80,93,139,62,32,240,141,62,14,133,144,62,12,28,147,62,247,180,149,62,159,79,152,62,214,235,154,62,110,137,157,62,253,39,160,62,234,198,162,62,185,101,165,62,9,4,168,62,147,161,170,62,35,62,173,62,139,217,175,62,169,115,178,62,158,12,181,62,186,164,183,62,57,60,186,62,57,211,188,62,185,105,191,62,163,255,193,62,225,148,196,62,88,41,199,62,224,188,201,62,72,79,204,62,101,224,206,62,20,112,209,62,32,254,211,62,80,138,214,62,118,20,217,62,117,156,219,62,42,34,222,62,109,165,224,62,28,38,227,62,34,164,229,62,161,31,232,62,224,152,234,62,11,16,237,62,51,133,239,62,67,248,241,62,26,105,244,62,154,215,246,62,175,67,249,62,56,173,251,62,15,20,254,62,14,60,0,63,171,108,1,63,230,155,2,63,200,201,3,63,88,246,4,63,150,33,6,63,129,75,7,63,25,116,8,63,91,155,9,63,70,193,10,63,214,229,11,63,10,9,13,63,226,42,14,63,94,75,15,63,129,106,16,63,79,136,17,63,204,164,18,63,254,191,19,63,237,217,20,63,163,189,21,63,214,212,22,63,150,234,23,63,229,254,24,63,194,17,26,63,47,35,27,63,44,51,28,63,185,65,29,63,216,78,30,63,136,90,31,63,203,100,32,63,162,109,33,63,16,117,34,63,23,123,35,63,187,127,36,63,254,130,37,63,223,132,38,63,96,133,39,63,128,132,40,63,66,130,41,63,166,126,42,63,173,121,43,63,88,115,44,63,168,107,45,63,157,98,46,63,54,88,47,63,115,76,48,63,84,63,49,63,216,48,50,63,252,32,51,63,193,15,52,63,35,253,52,63,35,233,53,63,189,211,54,63,241,188,55,63,187,164,56,63,28,139,57,63,16,112,58,63,150,83,59,63,171,53,60,63,75,22,61,63,114,245,61,63,27,211,62,63,69,175,63,63,237,137,64,63,16,99,65,63,173,58,66,63,193,16,67,63,68,229,67,63,52,184,68,63,137,137,69,63,65,89,70,63,87,39,71,63,201,243,71,63,146,190,72,63,176,135,73,63,31,79,74,63,218,20,75,63,222,216,75,63,39,155,76,63,176,91,77,63,116,26,78,63,110,215,78,63,156,146,79,63,247,75,80,63,125,3,81,63,42,185,81,63,249,108,82,63,232,30,83,63,246,206,83,63,31,125,84,63,97,41,85,63,185,211,85,63,36,124,86,63,161,34,87,63,46,199,87,63,199,105,88,63,106,10,89,63,22,169,89,63,202,69,90,63,132,224,90,63,70,121,91,63,13,16,92,63,219,164,92,63,177,55,93,63,141,200,93,63,113,87,94,63,94,228,94,63,88,111,95,63,99,248,95,63,130,127,96,63,184,4,97,63,10,136,97,63,125,9,98,63,21,137,98,63,218,6,99,63,215,130,99,63,21,253,99,63,160,117,100,63,131,236,100,63,202,97,101,63,127,213,101,63,174,71,102,63,106,184,102,63,202,39,103,63,230,149,103,63,216,2,104,63,184,110,104,63,160,217,104,63,167,67,105,63,233,172,105,63,131,21,106,63,153,125,106,63,80,229,106,63,203,76,107,63,26,180,107,63,62,27,108,63,53,130,108,63,250,232,108,63,46,79,109,63,30,180,109,63,14,23,110,63,67,119,110,63,173,211,110,63,235,42,111,63,154,123,111,63,90,196,111,63,81,4,112,63,107,94,112,63,60,113,112,63,169,134,112,63,34,158,112,63,234,182,112,63,69,208,112,63,122,233,112,63,68,2,113,63,210,26,113,63,87,51,113,63,6,76,113,63,243,100,113,63,19,126,113,63,89,151,113,63,185,176,113,63,45,202,113,63,186,227,113,63,97,253,113,63,37,23,114,63,9,49,114,63,14,75,114,63,51,101,114,63,121,127,114,63,226,153,114,63,107,180,114,63,21,207,114,63,224,233,114,63,203,4,115,63,217,31,115,63,10,59,115,63,96,86,115,63,219,113,115,63,122,141,115,63,60,169,115,63,31,197,115,63,36,225,115,63,77,253,115,63,155,25,116,63,16,54,116,63,173,82,116,63,112,111,116,63,87,140,116,63,98,169,116,63,145,198,116,63,228,227,116,63,94,1,117,63,1,31,117,63,204,60,117,63,189,90,117,63,212,120,117,63,14,151,117,63,107,181,117,63,237,211,117,63,149,242,117,63,100,17,118,63,90,48,118,63,116,79,118,63,178,110,118,63,16,142,118,63,144,173,118,63,50,205,118,63,247,236,118,63,225,12,119,63,239,44,119,63,31,77,119,63,111,109,119,63,222,141,119,63,108,174,119,63,24,207,119,63,229,239,119,63,211,16,120,63,225,49,120,63,15,83,120,63,89,116,120,63,190,149,120,63,61,183,120,63,214,216,120,63,140,250,120,63,95,28,121,63,78,62,121,63,88,96,121,63,121,130,121,63,177,164,121,63,254,198,121,63,97,233,121,63,221,11,122,63,113,46,122,63,28,81,122,63,222,115,122,63,180,150,122,63,155,185,122,63,148,220,122,63,158,255,122,63,188,34,123,63,238,69,123,63,52,105,123,63,141,140,123,63,245,175,123,63,107,211,123,63,239,246,123,63,129,26,124,63,35,62,124,63,213,97,124,63,152,133,124,63,106,169,124,63,72,205,124,63,49,241,124,63,37,21,125,63,37,57,125,63,50,93,125,63,77,129,125,63,119,165,125,63,173,201,125,63,237,237,125,63,55,18,126,63,137,54,126,63,229,90,126,63,76,127,126,63,193,163,126,63,66,200,126,63,207,236,126,63,103,17,127,63,7,54,127,63,175,90,127,63,94,127,127,63,18,164,127,63,202,200,127,63,132,237,127,63,63,9,128,63,161,27,128,63,8,46,128,63,113,64,128,63,222,82,128,63,76,101,128,63,188,119,128,63,45,138,128,63,158,156,128,63,14,175,128,63,125,193,128,63,234,211,128,63,87,230,128,63,197,248,128,63,51,11,129,63,162,29,129,63,16,48,129,63,126,66,129,63,234,84,129,63,83,103,129,63,187,121,129,63,35,140,129,63,138,158,129,63,240,176,129,63,86,195,129,63,185,213,129,63,25,232,129,63,117,250,129,63,206,12,130,63,38,31,130,63,123,49,130,63,206,67,130,63,31,86,130,63,107,104,130,63,177,122,130,63,243,140,130,63,47,159,130,63,103,177,130,63,155,195,130,63,203,213,130,63,246,231,130,63,26,250,130,63,55,12,131,63,76,30,131,63,89,48,131,63,95,66,131,63,96,84,131,63,89,102,131,63,75,120,131,63,52,138,131,63,18,156,131,63,230,173,131,63,176,191,131,63,113,209,131,63,40,227,131,63,215,244,131,63,122,6,132,63,18,24,132,63,158,41,132,63,28,59,132,63,141,76,132,63,243,93,132,63,77,111,132,63,155,128,132,63,220,145,132,63,15,163,132,63,52,180,132,63,73,197,132,63,80,214,132,63,72,231,132,63,51,248,132,63,17,9,133,63,223,25,133,63,158,42,133,63,77,59,133,63,234,75,133,63,119,92,133,63,244,108,133,63,98,125,133,63,193,141,133,63,15,158,133,63,77,174,133,63,120,190,133,63,145,206,133,63,153,222,133,63,145,238,133,63,121,254,133,63,81,14,134,63,25,30,134,63,208,45,134,63,116,61,134,63,7,77,134,63,137,92,134,63,250,107,134,63,93,123,134,63,176,138,134,63,244,153,134,63,40,169,134,63,74,184,134,63,91,199,134,63,92,214,134,63,78,229,134,63,48,244,134,63,4,3,135,63,200,17,135,63,126,32,135,63,36,47,135,63,186,61,135,63,65,76,135,63,185,90,135,63,35,105,135,63,127,119,135,63,208,133,135,63,22,148,135,63,83,162,135,63,133,176,135,63,164,190,135,63,170,204,135,63,144,218,135,63,97,232,135,63,57,246,135,63,55,4,136,63,116,18,136,63,201,32,136,63,206,46,136,63,24,60,136,63,60,72,136,63,231,82,136,63,184,75,136,63,3,72,136,63,230,63,136,63,198,51,136,63,127,36,136,63,234,18,136,63,210,255,135,63,206,235,135,63,62,215,135,63,126,194,135,63,228,173,135,63,123,153,135,63,8,133,135,63,79,112,135,63,22,91,135,63,57,69,135,63,163,46,135,63,65,23,135,63,3,255,134,63,250,229,134,63,86,204,134,63,73,178,134,63,0,152,134,63,154,125,134,63,35,99,134,63,166,72,134,63,46,46,134,63,181,19,134,63,38,249,133,63,106,222,133,63,108,195,133,63,5,168,133,63,0,140,133,63,38,111,133,63,67,81,133,63,52,50,133,63,228,17,133,63,66,240,132,63,60,205,132,63,209,168,132,63,16,131,132,63,9,92,132,63,202,51,132,63,109,10,132,63,19,224,131,63,225,180,131,63,246,136,131,63,108,92,131,63,87,47,131,63,200,1,131,63,207,211,130,63,118,165,130,63,189,118,130,63,163,71,130,63,41,24,130,63,66,232,129,63,218,183,129,63,217,134,129,63,44,85,129,63,191,34,129,63,130,239,128,63,101,187,128,63,89,134,128,63,75,80,128,63,37,25,128,63,163,193,127,63,119,78,127,63,175,216,126,63,72,96,126,63,66,229,125,63,158,103,125,63,175,231,124,63,26,102,124,63,132,227,123,63,145,96,123,63,178,221,122,63,37,91,122,63,36,217,121,63,230,87,121,63,44,215,120,63,67,86,120,63,115,212,119,63,8,81,119,63,153,203,118,63,8,68,118,63,57,186,117,63,18,46,117,63,152,159,116,63,240,14,116,63,63,124,115,63,174,231,114,63,137,81,114,63,70,186,113,63,92,34,113,63,64,138,112,63,87,242,111,63,244,90,111,63,106,196,110,63,6,47,110,63,111,154,109,63,168,5,109,63,174,111,108,63,133,215,107,63,204,60,107,63,190,159,106,63,158,0,106,63,174,95,105,63,98,189,104,63,89,26,104,63,53,119,103,63,147,212,102,63,149,50,102,63,224,144,101,63,21,239,100,63,214,76,100,63,235,169,99,63,65,6,99,63,199,97,98,63,109,188,97,63,56,22,97,63,64,111,96,63,158,199,95,63,108,31,95,63,194,118,94,63,186,205,93,63,108,36,93,63,243,122,92,63,102,209,91,63,152,37,91,63,76,123,90,63,14,208,89,63,255,35,89,63,61,119,88,63,232,201,87,63,30,28,87,63,254,109,86,63,167,191,85,63,55,17,85,63,202,98,84,63,101,180,83,63,240,5,83,63,83,87,82,63,117,168,81,63,12,249,80,63,161,72,80,63,184,150,79,63,222,226,78,63,55,45,78,63,124,118,77,63,112,191,76,63,209,8,76,63,49,83,75,63,242,158,74,63,117,236,73,63,19,60,73,63,74,141,72,63,196,222,71,63,31,47,71,63,5,125,70,63,237,199,69,63,33,16,69,63,244,85,68,63,186,153,67,63,241,219,66,63,66,29,66,63,88,94,65,63,220,159,64,63,69,226,63,63,219,37,63,63,226,106,62,63,158,177,61,63,30,250,60,63,64,68,60,63,224,143,59,63,210,220,58,63,97,42,58,63,77,119,57,63,79,194,56,63,43,10,56,63,90,78,55,63,18,143,54,63,142,204,53,63,16,7,53,63,76,63,52,63,107,118,51,63,153,173,50,63,252,229,49,63,53,32,49,63,92,92,48,63,131,154,47,63,186,218,46,63,231,28,46,63,200,96,45,63,24,166,44,63,144,236,43,63,233,51,43,63,212,123,42,63,4,196,41,63,43,12,41,63,231,83,40,63,195,154,39,63,73,224,38,63,5,36,38,63,164,101,37,63,248,164,36,63,212,225,35,63,13,28,35,63,191,83,34,63,69,137,33,63,1,189,32,63,87,239,31,63,213,32,31,63,59,82,30,63,73,132,29,63,190,183,28,63,51,237,27,63,30,37,27,63,243,95,26,63,34,158,25,63,221,223,24,63,21,37,24,63,183,109,23,63,173,185,22,63,90,8,22,63,159,88,21,63,87,169,20,63,90,249,19,63,109,71,19,63,63,146,18,63,125,216,17,63,223,24,17,63,36,83,16,63,9,136,15,63,93,184,14,63,239,228,13,63,48,15,13,63,43,57,12,63,242,100,11,63,144,148,10,63,70,201,9,63,146,3,9,63,231,67,8,63,173,138,7,63,31,215,6,63,75,39,6,63,53,121,5,63,228,202,4,63,234,26,4,63,101,104,3,63,118,178,2,63,71,248,1,63,223,57,1,63,34,120,0,63,245,103,255,62,167,220,253,62,40,80,252,62,154,206,250,62,97,61,249,62,227,179,247,62,114,50,246,62,238,183,244,62,32,67,243,62,208,210,241,62,116,101,240,62,47,249,238,62,35,140,237,62,129,28,236,62,183,169,234,62,116,52,233,62,115,189,231,62,117,69,230,62,120,205,228,62,193,86,227,62,148,226,225,62,40,114,224,62,91,5,223,62,177,154,221,62,160,48,220,62,164,197,218,62,208,88,217,62,206,233,215,62,77,120,214,62,6,4,213,62,129,141,211,62,21,22,210,62,33,159,208,62,254,41,207,62,88,183,205,62,49,71,204,62,131,217,202,62,69,110,201,62,69,5,200,62,39,158,198,62,143,56,197,62,31,212,195,62,135,112,194,62,131,13,193,62,208,170,191,62,44,72,190,62,136,229,188,62,5,131,187,62,196,32,186,62,233,190,184,62,132,93,183,62,147,252,181,62,23,156,180,62,14,60,179,62,124,220,177,62,111,125,176,62,242,30,175,62,17,193,173,62,215,99,172,62,84,7,171,62,146,171,169,62,160,80,168,62,129,246,166,62,50,157,165,62,173,68,164,62,238,236,162,62,239,149,161,62,170,63,160,62,28,234,158,62,67,149,157,62,35,65,156,62,196,237,154,62,45,155,153,62,102,73,152,62,115,248,150,62,85,168,149,62,9,89,148,62,144,10,147,62,237,188,145,62,38,112,144,62,65,36,143,62,67,217,141,62,48,143,140,62,4,70,139,62,189,253,137,62,90,182,136,62,221,111,135,62,80,42,134,62,189,229,132,62,43,162,131,62,161,95,130,62,31,30,129,62,80,187,127,62,121,60,125,62,190,191,122,62,41,69,120,62,196,204,117,62,151,86,115,62,166,226,112,62,235,112,110,62,97,1,108,62,4,148,105,62,213,40,103,62,223,191,100,62,44,89,98,62,199,244,95,62,175,146,93,62,218,50,91,62,62,213,88,62,207,121,86,62,136,32,84,62,104,201,81,62,112,116,79,62,159,33,77,62,235,208,74,62,69,130,72,62,154,53,70,62,217,234,67,62,248,161,65,62,244,90,63,62,207,21,61,62,135,210,58,62,68,145,56,62,83,82,54,62,2,22,52,62,163,220,49,62,129,166,47,62,238,115,45,62,55,69,43,62,172,26,41,62,155,244,38,62,127,218,36,62,226,199,34,62,49,186,32,62,34,177,30,62,110,172,28,62,199,171,26,62,228,174,24,62,122,181,22,62,64,191,20,62,234,203,18,62,46,219,16,62,239,236,14,62,54,1,13,62,17,24,11,62,139,49,9,62,176,77,7,62,136,108,5,62,27,142,3,62,115,178,1,62,53,179,255,61,69,7,252,61,53,97,248,61,34,193,244,61,35,39,241,61,58,147,237,61,114,5,234,61,206,125,230,61,95,252,226,61,55,129,223,61,111,12,220,61,23,158,216,61,57,54,213,61,212,212,209,61,227,121,206,61,99,37,203,61,90,215,199,61,218,143,196,61,240,78,193,61,174,20,190,61,23,225,186,61,37,180,183,61,208,141,180,61,15,110,177,61,232,84,174,61,102,66,171,61,155,54,168,61,147,49,165,61,81,51,162,61,202,59,159,61,244,74,156,61,198,96,153,61,64,125,150,61,111,160,147,61,97,202,144,61,35,251,141,61,181,50,139,61,12,113,136,61,26,182,133,61,212,1,131,61,58,84,128,61,175,90,123,61,110,26,118,61,202,231,112,61,188,194,107,61,40,171,102,61,237,160,97,61,240,163,92,61,44,180,87,61,177,209,82,61,149,252,77,61,232,52,73,61,172,122,68,61,195,205,63,61,23,46,59,61,141,155,54,61,42,22,50,61,8,158,45,61,74,51,41,61,8,214,36,61,72,134,32,61,235,67,28,61,213,14,24,61,237,230,19,61,35,204,15,61,122,190,11,61,242,189,7,61,144,202,3,61,71,200,255,60,186,20,248,60,197,121,240,60,202,246,232,60,107,139,225,60,175,55,218,60,144,251,210,60,20,215,203,60,117,202,196,60,42,214,189,60,163,250,182,60,87,56,176,60,60,144,169,60,176,3,163,60,26,148,156,60,210,66,150,60,189,15,144,60,62,249,137,60,182,253,131,60,253,54,124,60,213,162,112,60,81,61,101,60,15,5,90,60,140,248,78,60,105,24,68,60,31,103,57,60,84,231,46,60,128,155,36,60,132,131,26,60,166,156,16,60,0,228,6,60,198,173,250,59,29,233,231,59,223,124,213,59,187,107,195,59,202,184,177,59,105,103,160,59,95,124,143,59,191,248,125,59,99,216,93,59,78,147,62,59,184,23,32,59,44,83,2,59,191,101,202,58,179,66,145,58,188,21,50,58,249,40,134,57,253,131,43,185,5,198,23,186,151,149,129,186,134,78,182,186,26,212,233,186,143,234,13,187,242,244,37,187,178,212,60,187,80,87,82,187,14,113,102,187,69,62,121,187,62,110,133,187,31,181,141,187,88,139,149,187,199,16,157,187,144,101,164,187,124,169,171,187,86,239,178,187,126,61,186,187,168,153,193,187,200,8,201,187,163,129,208,187,59,236,215,187,60,48,223,187,84,53,230,187,32,232,236,187,244,57,243,187,97,28,249,187,58,129,254,187,70,177,1,188,86,225,3,188,252,209,5,188,185,132,7,188,128,253,8,188,250,66,10,188,9,92,11,188,78,79,12,188,254,34,13,188,130,220,13,188,66,129,14,188,180,22,15,188,167,160,15,188,150,33,16,188,218,155,16,188,192,17,17,188,245,130,17,188,167,236,17,188,253,75,18,188,8,158,18,188,172,223,18,188,153,13,19,188,138,36,19,188,69,33,19,188,185,0,19,188,55,192,18,188,250,92,18,188,126,212,17,188,237,37,17,188,147,82,16,188,157,91,15,188,99,66,14,188,158,9,13,188,128,181,11,188,60,74,10,188,247,203,8,188,90,63,7,188,109,169,5,188,36,15,4,188,69,117,2,188,255,220,0,188,240,135,254,187,87,79,251,187,84,11,248,187,73,181,244,187,189,69,241,187,207,180,237,187,70,251,233,187,137,21,230,187,23,4,226,187,113,199,221,187,110,96,217,187,22,211,212,187,244,38,208,187,150,99,203,187,93,144,198,187,103,178,193,187,100,204,188,187,24,225,183,187,7,243,178,187,157,2,174,187,65,14,169,187,114,20,164,187,129,19,159,187,192,8,154,187,189,240,148,187,10,200,143,187,116,139,138,187,148,59,133,187,94,185,127,187,27,230,116,187,238,5,106,187,178,29,95,187,152,47,84,187,32,61,73,187,164,71,62,187,36,80,51,187,34,87,40,187,243,92,29,187,110,98,18,187,20,104,7,187,117,220,248,186,112,234,226,186,199,251,204,186,209,18,183,186,67,52,161,186,121,101,139,186,248,84,107,186,167,16,64,186,184,6,21,186,114,126,212,185,62,14,127,185,136,211,172,184,148,66,172,56,80,186,124,57,103,78,209,57,203,232,17,58,243,231,58,58,241,155,99,58,175,252,133,58,191,251,153,58,33,198,173,58,35,87,193,58,189,170,212,58,148,189,231,58,253,142,250,58,208,142,6,59,147,180,15,59,199,183,24,59,20,151,33,59,163,81,42,59,155,229,50,59,167,82,59,59,27,152,67,59,33,182,75,59,187,172,83,59,140,120,91,59,12,20,99,59,48,121,106,59,154,162,113,59,115,143,120,59,109,67,127,59,6,225,130,59,22,7,134,59,190,21,137,59,129,14,140,59,56,243,142,59,101,197,145,59,94,133,148,59,246,49,151,59,22,202,153,59,167,76,156,59,186,182,158,59,134,3,161,59,45,46,163,59,63,50,165,59,160,13,167,59,126,192,168,59,2,75,170,59,152,173,171,59,175,234,172,59,121,6,174,59,103,5,175,59,107,235,175,59,139,188,176,59,208,124,177,59,254,47,178,59,199,217,178,59,127,121,179,59,116,10,180,59,221,135,180,59,93,237,180,59,110,54,181,59,113,94,181,59,245,96,181,59,222,57,181,59,146,230,180,59,79,102,180,59,19,184,179,59,95,219,178,59,202,209,177,59,47,159,176,59,129,71,175,59,111,206,173,59,215,55,172,59,190,135,170,59,22,194,168,59,123,234,166,59,156,4,165,59,236,19,163,59,217,27,161,59,128,31,159,59,161,31,157,59,77,26,155,59,174,13,153,59,20,248,150,59,102,214,148,59,114,164,146,59,28,94,144,59,136,255,141,59,2,132,139,59,110,230,136,59,152,33,134,59,226,48,131,59,201,17,128,59,195,136,121,59,130,145,114,59,39,62,107,59,231,149,99,59,4,166,91,59,233,123,83,59,45,37,75,59,24,179,66,59,207,58,58,59,73,209,49,59,168,138,41,59,251,110,33,59,103,123,25,59,144,172,17,59,113,254,9,59,157,99,2,59,218,137,245,58,119,23,230,58,198,68,214,58,231,241,197,58,189,12,181,58,39,131,163,58,182,68,145,58,84,188,124,58,55,240,85,58,162,119,46,58,32,165,6,58,60,114,189,57,98,146,91,57,28,126,117,56,196,245,189,184,1,98,121,185,168,40,201,185,107,146,10,186,250,114,48,186,50,82,86,186,143,71,124,186,157,53,145,186,90,107,164,186,171,198,183,186,46,63,203,186,42,205,222,186,145,103,242,186,85,3,3,187,138,209,12,187,181,153,22,187,207,87,32,187,128,10,42,187,247,179,51,187,100,87,61,187,245,246,70,187,0,147,80,187,173,41,90,187,120,185,99,187,140,65,109,187,104,193,118,187,69,28,128,187,206,210,132,187,119,131,137,187,86,46,142,187,24,212,146,187,189,117,151,187,178,19,156,187,32,174,160,187,222,68,165,187,235,215,169,187,199,103,174,187,223,244,178,187,51,127,183,187,193,6,188,187,161,139,192,187,252,13,197,187,211,141,201,187,38,11,206,187,244,133,210,187,148,254,214,187,157,117,219,187,184,235,223,187,126,97,228,187,154,215,232,187,248,78,237,187,90,200,241,187,235,68,246,187,153,197,250,187,122,75,255,187,211,235,1,188,143,53,4,188,125,131,6,188,29,214,8,188,252,45,11,188,175,139,13,188,226,239,15,188,109,91,18,188,47,207,20,188,12,76,23,188,207,210,25,188,47,100,28,188,247,0,31,188,212,169,33,188,32,92,36,188,199,17,39,188,222,195,41,188,13,107,44,188,226,2,47,188,103,138,49,188,206,0,52,188,44,101,54,188,246,182,56,188,202,245,58,188,73,33,61,188,49,57,63,188,66,61,65,188,103,45,67,188,127,9,69,188,150,209,70,188,182,133,72,188,9,38,74,188,188,178,75,188,24,44,77,188,106,146,78,188,39,230,79,188,198,39,81,188,209,87,82,188,65,119,83,188,76,135,84,188,52,137,85,188,124,126,86,188,112,103,87,188,131,67,88,188,223,17,89,188,216,209,89,188,36,131,90,188,12,38,91,188,220,186,91,188,235,65,92,188,120,187,92,188,174,39,93,188,185,134,93,188,195,216,93,188,46,30,94,188,143,87,94,188,135,133,94,188,184,168,94,188,54,193,94,188,98,206,94,188,164,207,94,188,81,196,94,188,62,172,94,188,213,135,94,188,110,87,94,188,137,27,94,188,38,212,93,188,218,128,93,188,67,33,93,188,247,180,92,188,108,60,92,188,227,184,91,188,213,43,91,188,164,150,90,188,200,250,89,188,174,89,89,188,216,180,88,188,211,13,88,188,46,102,87,188,139,166,86,188,83,13,86,188,41,105,85,188,12,186,84,188,29,0,84,188,70,59,83,188,168,107,82,188,34,145,81,188,180,171,80,188,73,187,79,188,204,191,78,188,6,185,77,188,226,166,76,188,32,137,75,188,160,95,74,188,204,42,73,188,113,235,71,188,81,162,70,188,44,80,69,188,56,245,67,188,42,145,66,188,172,35,65,188,126,172,63,188,11,44,62,188,52,163,60,188,241,18,59,188,45,124,57,188,128,223,55,188,105,61,54,188,85,150,52,188,185,234,50,188,11,59,49,188,227,135,47,188,224,209,45,188,110,25,44,188,163,94,42,188,233,160,40,188,222,223,38,188,34,27,37,188,76,83,35,188,30,138,33,188,27,193,31,188,209,249,29,188,85,53,28,188,171,116,26,188,147,184,24,188,239,1,23,188,96,81,21,188,103,167,19,188,122,4,18,188,25,105,16,188,155,213,14,188,97,74,13,188,213,199,11,188,45,78,10,188,138,221,8,188,224,117,7,188,27,23,6,188,16,193,4,188,104,115,3,188,183,45,2,188,116,239,0,188,248,111,255,187,229,5,253,187,108,145,250,187,51,4,248,187,59,81,245,187,187,115,242,187,247,109,239,187,94,66,236,187,116,243,232,187,103,131,229,187,103,244,225,187,117,72,222,187,172,129,218,187,248,161,214,187,180,171,210,187,205,160,206,187,113,131,202,187,122,85,198,187,126,24,194,187,44,206,189,187,6,120,185,187,186,23,181,187,223,174,176,187,248,62,172,187,158,201,167,187,252,79,163,187,255,210,158,187,190,83,154,187,17,211,149,187,247,81,145,187,181,209,140,187,118,83,136,187,82,216,131,187,106,195,126,187,153,225,117,187,54,14,109,187,111,75,100,187,115,156,91,187,32,5,83,187,208,136,74,187,221,42,66,187,160,236,57,187,195,205,49,187,110,205,41,187,204,234,33,187,177,37,26,187,71,126,18,187,187,244,10,187,98,137,3,187,38,123,248,186,252,39,234,186,249,29,220,186,205,97,206,186,126,245,192,186,92,214,179,186,99,2,167,186,144,119,154,186,227,53,142,186,184,64,130,186,32,52,109,186,229,137,86,186,111,135,64,186,33,52,43,186,176,150,22,186,123,180,2,186,252,22,223,185,82,35,186,185,125,120,150,185,88,255,103,185,29,68,37,185,47,19,201,184,43,72,22,184,212,150,190,55,117,63,167,56,121,145,13,57,7,109,69,57,168,244,122,57,59,233,150,57,224,206,174,57,73,252,196,57,36,65,217,57,27,156,235,57,193,50,252,57,86,149,5,58,99,85,12,58,13,117,18,58,53,21,24,58,21,88,29,58,224,91,34,58,180,50,39,58,241,225,43,58,71,110,48,58,20,219,52,58,156,31,57,58,103,38,61,58,250,217,64,58,225,38,68,58,174,255,70,58,253,90,73,58,105,47,75,58,231,118,76,58,119,49,77,58,119,100,77,58,246,23,77,58,169,82,76,58,162,30,75,58,251,139,73,58,28,166,71,58,118,124,69,58,110,24,67,58,24,134,64,58,128,205,61,58,14,248,58,58,118,12,56,58,192,14,53,58,242,2,50,58,103,236,46,58,31,203,43,58,24,157,40,58,76,96,37,58,98,17,34,58,174,175,30,58,212,55,27,58,213,169,23,58,2,3,20,58,5,68,16,58,137,107,12,58,227,122,8,58,190,112,4,58,30,81,0,58,193,62,248,57,21,191,239,57,72,43,231,57,102,139,222,57,220,236,213,57,183,87,205,57,180,214,196,57,225,113,188,57,250,51,180,57,181,35,172,57,113,70,164,57,52,160,156,57,161,43,149,57,182,232,141,57,23,210,134,57,212,204,127,57,84,67,114,57,172,7,101,57,207,17,88,57,28,103,75,57,146,7,63,57,63,251,50,57,130,71,39,57,9,239,27,57,146,252,16,57,123,117,6,57,66,190,248,56,106,120,229,56,203,30,211,56,102,177,193,56,219,42,177,56,43,139,161,56,152,199,146,56,130,229,132,56,156,169,111,56,56,32,87,56,150,57,64,56,196,202,42,56,126,222,22,56,8,106,4,56,192,218,230,55,28,166,199,55,158,75,171,55,81,160,145,55,121,29,117,55,218,215,75,55,198,111,39,55,99,100,7,55,123,21,215,54,198,111,167,54,232,171,125,54,9,144,58,54,139,136,3,54,219,42,177,53,249,29,92,53,235,245,246,52,149,191,86,52,149,191,86,51,89,217,0,179,89,217,128,179,119,204,43,179,119,204,43,178,119,204,43,50,119,204,43,50,119,204,43,50,119,204,43,50,119,204,43,178,119,204,43,179,149,191,86,179,89,217,0,179,149,191,86,51,149,191,86,52,192,218,230,52,255,177,78,53,122,22,165,53,82,158,245,53,68,120,44,54,242,137,105,54,52,172,152,54,133,243,194,54,211,240,243,54,15,210,21,55,166,49,53,55,20,109,88,55,103,89,127,55,66,38,149,55,189,141,172,55,144,35,198,55,201,188,225,55,103,89,255,55,114,135,15,56,227,99,32,56,7,66,50,56,154,44,69,56,224,24,89,56,150,17,110,56,255,5,130,56,107,137,141,56,176,141,153,56,45,24,166,56,37,30,179,56,246,164,192,56,66,167,206,56,77,26,221,56,89,243,235,56,75,34,251,56,226,80,5,57,214,48,13,57,80,46,21,57,68,65,29,57,177,105,37,57,139,159,45,57,47,232,53,57,238,64,62,57,119,172,70,57,28,40,79,57,58,185,87,57,129,98,96,57,65,33,105,57,42,248,113,57,128,220,122,57,194,225,129,57,237,83,134,57,178,188,138,57,11,24,143,57,235,93,147,57,75,138,151,57,28,149,155,57,177,123,159,57,170,56,163,57,169,198,166,57,174,37,170,57,185,85,173,57,27,84,176,57,219,36,179,57,248,199,181,57,203,62,184,57,171,138,186,57,71,174,188,57,165,173,190,57,199,136,192,57,178,67,194,57,22,225,195,57,243,96,197,57,153,192,198,57,90,253,199,57,47,19,201,57,16,254,201,57,154,180,202,57,196,50,203,57,210,109,203,57,15,95,203,57,20,253,202,57,118,58,202,57,128,16,201,57,203,117,199,57,81,102,197,57,187,224,194,57,169,223,191,57,124,104,188,57,144,128,184,57,162,50,180,57,24,136,175,57,94,142,170,57,63,88,165,57,131,248,159,57,247,129,154,57,167,252,148,57,235,105,143,57,20,199,137,57,202,18,132,57,241,129,124,57,78,120,112,57,181,221,99,57,135,132,86,57,219,73,72,57,152,29,57,57,55,226,40,57,75,138,23,57,50,27,5,57,194,127,227,56,52,65,187,56,162,208,145,56,41,253,78,56,110,237,241,55,22,102,8,55,47,188,84,183,131,205,12,184,23,226,100,184,154,214,158,184,164,183,203,184,0,47,249,184,21,169,19,185,76,27,43,185,147,251,66,185,57,71,91,185,130,243,115,185,217,122,134,185,127,29,147,185,171,221,159,185,169,180,172,185,19,153,185,185,139,133,198,185,9,118,211,185,142,106,224,185,114,100,237,185,11,101,250,185,130,181,3,186,41,57,10,186,34,186,16,186,192,55,23,186,255,175,29,186,136,33,36,186,88,138,42,186,107,232,48,186,190,57,55,186,252,126,61,186,122,183,67,186,141,226,73,186,135,255,79,186,103,12,86,186,127,8,92,186,121,242,97,186,84,202,103,186,98,141,109,186,161,59,115,186,16,211,120,186,2,83,126,186,185,220,129,186,220,130,132,186,231,26,135,186,46,164,137,186,8,31,140,186,114,138,142,186,23,230,144,186,246,49,147,186,187,109,149,186,14,153,151,186,155,179,153,186,182,189,155,186,95,182,157,186,64,158,159,186,89,116,161,186,170,56,163,186,220,234,164,186,153,138,166,186,54,23,168,186,179,144,169,186,185,246,170,186,160,73,172,186,100,136,173,186,6,179,174,186,219,200,175,186,140,201,176,186,24,180,177,186,43,138,178,186,117,77,179,186,79,1,180,186,106,169,180,186,117,71,181,186,26,220,181,186,91,103,182,186,140,233,182,186,3,99,183,186,193,211,183,186,198,59,184,186,103,155,184,186,250,241,184,186,210,63,185,186,70,132,185,186,84,191,185,186,167,240,185,186,233,23,186,186,197,52,186,186,141,70,186,186,153,77,186,186,61,73,186,186,33,57,186,186,156,28,186,186,172,243,185,186,252,189,185,186,224,122,185,186,173,41,185,186,13,203,184,186,172,94,184,186,52,229,183,186,166,94,183,186,3,203,182,186,73,42,182,186,207,124,181,186,63,194,180,186,153,250,179,186,51,38,179,186,98,69,178,186,123,87,177,186,42,93,176,186,111,86,175,186,74,67,174,186,186,35,173,186,192,247,171,186,8,192,170,186,59,124,169,186,91,45,168,186,19,211,166,186,98,109,165,186,245,252,163,186,31,129,162,186,140,250,160,186,146,105,159,186,136,206,157,186,22,41,156,186,235,122,154,186,93,196,152,186,108,6,151,186,200,66,149,186,113,122,147,186,189,173,145,186,176,222,143,186,73,13,142,186,141,59,140,186,208,227,39,0,64,246,39,0,0,1,0,0,208,227,39,0,0,0,0,0,0,0,0,0,0,0,0,0,2,80,1,0,0,0,0,0,242,5,0,0,108,5,0,0,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,43,37,0,144,108,39,0,1,0,0,0,2,80,1,0,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,99,40,0,0,26,32,0,0,0,0,0,96,25,32,0,0,0,0,0,160,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,11,0,0,0,0,0,0,0,0,0,0,234,0,0,0,10,8,0,0,42,2,0,0,0,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,8,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,160,229,25,0,160,229,25,0,72,212,25,0,72,212,25,0,192,209,25,0,192,209,25,0,240,206,25,0,240,206,25,0,40,201,25,0,40,201,25,0,224,219,25,0,0,0,0,0,232,228,25,0,232,228,25,0,88,217,25,0,88,217,25,0,240,208,25,0,240,208,25,0,88,217,25,0,88,217,25,0,88,217,25,0,88,217,25,0,88,217,25,0,0,0,0,0,248,228,25,0,248,228,25,0,248,228,25,0,248,228,25,0,24,209,25,0,24,209,25,0,112,206,25,0,112,206,25,0,208,199,25,0,208,199,25,0,152,217,25,0,0,0,0,0,216,43,37,0,208,108,39,0,0,0,0,0,144,0,0,0,32,0,0,0,0,0,0,0,40,99,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,7,0,0,0,0,0,0,128,2,0,0,0,0,0,0,18,1,0,0,0,0,0,0,0,0,0,0,248,54,37,0,40,226,35,0,0,0,0,0,145,0,0,0,32,0,0,0,0,0,0,0,120,96,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,7,0,0,0,0,0,0,128,2,0,0,0,0,0,0,18,1,0,0,0,0,0,0,0,0,0,0,56,229,39,0,104,246,39,0,0,0,0,0,16,140,37,0,0,0,0,0,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,237,164,19,35,45,191,79,69,173,138,217,91,167,249,31,238,18,246,34,182,173,71,113,70,173,108,5,169,142,101,222,58,55,250,211,251,198,251,42,253,206,252,218,253,95,254,87,1,233,1,19,1,210,252,2,254,56,253,91,252,210,253,20,255,32,0,235,11,195,1,45,1,98,254,19,255,85,253,169,253,43,14,67,254,24,255,56,0,58,0,112,0,54,251,129,253,0,16,124,253,30,255,233,255,90,0,162,0,57,1,104,0,151,250,231,21,84,254,164,252,65,254,247,254,111,255,124,255,115,0,56,255,187,250,0,251,64,251,234,251,111,253,43,0,53,5,63,3,163,2,150,4,142,250,240,8,48,7,86,253,15,254,0,255,22,0,22,0,5,1,70,0,167,250,198,252,49,252,238,8,183,254,245,254,142,0,36,0,181,1,57,1,34,6,52,0,42,254,110,2,12,255,9,255,142,255,22,0,139,255,227,253,113,251,172,253,215,252,95,252,99,253,185,254,102,0,4,2,230,10,85,2,219,250,154,252,47,5,219,3,231,255,135,1,208,255,174,255,209,0,14,255,72,17,201,254,116,254,3,253,130,254,176,254,147,254,98,254,182,255,243,255,103,4,180,253,83,5,54,253,112,1,62,254,122,254,148,254,84,0,139,0,72,7,89,7,241,255,234,252,231,254,226,254,38,0,70,255,225,255,18,255,31,251,6,1,183,252,219,2,98,254,195,255,238,254,24,1,100,0,45,2,183,252,249,252,17,252,217,251,81,253,138,254,152,254,31,0,24,4,143,13,151,250,160,9,184,252,175,251,54,253,112,254,56,0,189,1,76,2,171,1,249,6,187,251,241,252,177,252,41,0,233,255,209,1,136,1,126,1,172,1,250,253,7,255,198,255,233,252,79,253,187,253,74,12,73,255,40,1,66,0,37,251,35,4,204,251,150,252,160,1,32,2,253,0,66,0,168,0,211,0,148,250,229,4,138,0,41,253,3,254,137,3,63,1,215,254,67,0,243,253,66,250,189,8,169,255,35,2,44,2,17,255,90,0,109,255,142,255,210,254,7,252,200,252,183,253,25,0,0,0,62,0,142,5,101,255,215,255,192,254,155,251,211,251,146,251,241,252,105,4,45,0,183,0,47,0,204,2,160,2,153,1,111,251,114,252,65,254,222,255,79,0,95,0,199,1,248,1,125,1,86,1,147,252,6,254,212,252,219,252,215,11,7,255,250,253,187,255,52,2,243,0,5,1,180,254,78,254,83,255,219,255,61,0,45,0,251,255,6,0,103,250,15,252,148,5,73,252,186,253,154,0,143,0,113,2,127,1,131,1,144,250,58,251,190,253,229,0,14,5,218,0,114,255,99,1,107,255,201,0,195,250,145,251,167,252,1,253,239,254,11,8,255,0,66,2,94,1,59,1,239,251,151,253,254,0,8,254,1,255,160,255,231,253,116,254,107,1,50,4,175,250,228,1,26,2,235,252,64,253,65,254,200,0,9,2,213,0,90,0,97,251,110,251,157,252,76,252,22,253,236,1,251,5,132,5,12,2,82,0,78,2,30,252,108,252,165,252,88,253,12], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1445368);
/* memory initializer */ allocate([230,2,193,3,230,0,255,0,34,0,38,0,80,255,255,255,88,7,16,255,255,252,237,253,13,1,224,255,252,252,18,254,245,2,185,253,91,253,231,254,205,2,184,1,49,2,91,0,159,251,226,251,91,251,180,251,23,253,95,254,195,255,46,1,7,12,25,7,152,250,57,250,59,250,27,250,203,251,189,254,134,3,44,9,184,5,14,4,25,254,77,255,65,254,201,254,216,254,73,254,84,255,118,8,245,0,228,255,230,251,122,254,18,255,121,2,46,1,177,254,75,3,204,255,185,0,230,0,146,255,79,254,78,253,148,0,63,0,223,254,108,254,43,254,156,7,245,0,224,7,57,5,171,254,214,253,151,253,55,254,76,254,53,254,112,254,248,253,107,253,249,255,54,4,203,3,186,254,180,254,233,255,19,253,83,0,152,255,58,8,77,252,157,252,141,252,63,253,79,254,221,255,164,0,171,1,134,2,100,252,148,8,112,253,226,252,230,254,217,0,29,255,134,0,190,1,241,255,184,253,33,0,185,0,197,253,97,255,60,7,107,254,162,255,195,255,173,255,183,254,252,253,118,254,62,254,83,255,116,255,202,255,100,255,226,0,58,7,16,253,232,250,158,250,5,251,7,252,88,253,175,254,100,1,107,4,47,16,160,251,27,251,11,251,164,252,90,0,205,3,152,0,118,3,97,2,174,5,227,255,36,0,139,255,209,252,117,253,166,254,37,8,98,254,24,0,163,255,21,255,177,251,148,251,10,253,158,255,217,5,5,5,223,254,222,255,146,1,122,253,125,2,99,8,91,253,162,254,246,254,24,255,195,255,57,255,153,254,167,0,10,6,48,3,59,254,221,255,5,255,44,254,21,254,141,254,175,253,146,252,165,5,229,252,139,2,108,0,101,255,55,255,242,255,250,0,241,254,36,253,25,3,154,0,224,254,170,255,16,0,45,2,130,2,176,253,181,253,169,255,147,254,203,254,217,6,216,255,95,0,239,253,169,255,42,255,22,255,135,19,46,254,13,253,224,252,239,252,46,253,236,253,65,253,242,253,47,254,79,2,97,15,27,255,220,252,216,252,70,253,192,253,155,253,6,254,43,253,10,0,13,0,139,255,201,255,101,0,52,0,125,0,180,255,231,255,228,255,189,5,11,255,8,0,231,255,65,0,203,255,250,254,230,254,101,254,180,253,101,253,94,5,48,1,237,252,107,253,93,253,55,0,64,1,208,2,252,255,110,1,153,255,120,255,180,254,198,254,219,254,218,255,127,0,151,0,124,1,206,250,198,250,150,253,216,255,4,5,220,5,210,1,253,253,105,0,95,255,19,0,185,2,95,254,209,253,195,254,56,253,12,253,201,253,242,2,201,5,11,251,155,249,187,250,120,249,115,250,190,10,212,0,235,13,182,255,19,6,41,250,132,251,108,251,71,5,28,254,39,254,138,5,45,2,131,3,123,2,236,23,140,251,126,251,15,3,92,250,27,250,239,251,1,7,107,17,45,5,7,8,103,252,230,252,55,253,89,6,206,255,78,0,97,255,105,1,87,3,42,40,3,250,175,251,210,249,88,249,95,249,96,250,23,252,96,3,246,7,189,250,177,252,117,250,194,5,167,250,91,251,155,251,113,253,122,255,182,3,138,250,34,255,38,250,18,251,37,10,217,2,217,9,224,253,201,1,10,8,237,14,224,249,215,249,221,7,75,249,172,249,244,250,211,10,255,9,78,19,39,250,216,249,68,249,242,249,17,249,58,249,183,251,133,253,142,7,146,10,137,250,30,252,149,6,138,251,1,254,59,6,237,254,93,3,228,1,190,3,162,250,4,253,175,251,43,250,114,249,162,249,247,253,18,20,53,0,51,5,45,19,160,250,86,8,154,249,26,6,227,249,49,250,167,249,160,12,134,18,7,252,183,250,68,251,207,249,227,250,141,251,185,255,204,252,40,23,171,11,127,253,222,250,82,251,98,251,19,252,226,253,249,250,70,251,177,251,209,26,150,251,95,5,140,252,217,4,236,253,83,255,188,255,15,0,53,1,192,0,152,251,173,251,175,252,193,250,185,8,255,250,233,253,89,253,38,15,73,7,109,250,156,17,2,252,21,253,163,251,176,251,223,255,157,2,192,4,202,5,176,250,205,251,53,250,146,250,170,250,14,253,238,251,2,253,139,13,144,253,56,252,179,251,119,254,134,252,65,254,29,252,42,9,115,252,240,252,209,3,139,251,79,251,136,20,240,249,232,253,117,250,0,0,84,2,44,2,118,6,156,251,55,251,194,252,243,4,49,253,255,6,222,253,215,254,210,3,122,1,114,10,19,251,121,251,73,252,253,251,233,9,42,254,152,254,244,254,74,4,126,251,23,250,39,253,81,250,39,22,44,251,224,252,150,252,94,6,249,4,117,7,145,253,44,253,137,5,209,253,186,254,255,254,67,255,9,1,220,0,228,254,234,250,8,251,57,251,182,252,242,16,90,252,23,252,17,254,128,11,199,16,100,252,20,252,183,251,0,252,184,254,200,6,106,0,196,1,158,0,0,252,227,253,240,250,24,17,163,251,56,251,181,252,73,4,97,4,227,4,195,252,162,250,244,8,31,250,58,7,127,251,81,252,45,252,234,253,164,5,26,250,42,250,133,251,139,250,255,5,230,252,235,255,33,5,126,2,247,3,208,251,5,251,114,251,190,249,174,249,157,250,189,17,30,255,121,8,120,3,167,250,88,9,193,251,76,252,50,4,162,2,128,1,124,0,244,1,237,2,142,1,189,251,47,253,142,255,241,255,157,1,200,0,135,0,34,1,189,0,95,251,92,251,197,250,243,249,153,252,194,253,29,9,166,254,42,2,189,14,33,251,5,250,128,250,226,250,17,252,45,11,161,9,96,2,56,4,200,4,177,251,59,250,92,7,124,250,120,252,63,250,178,252,68,255,14,3,1,8,63,250,251,5,6,250,77,250,246,249,20,251,168,252,167,4,140,2,165,3,208,19,80,250,139,249,175,14,41,249,237,253,145,250,201,16,138,254,17,253,222,249,38,251,181,5,250,250,111,252,147,253,232,6,222,4,11,5,11,3,176,250,105,6,98,4,139,253,184,254,59,255,241,0,103,1,48,2,24,2,62,250,6,254,13,250,42,1,241,249,26,251,39,252,19,14,221,16,190,3,139,252,15,255,121,251,94,252,31,251,210,5,199,252,18,1,91,1,51,1,220,251,253,251,215,252,217,251,18,6,172,6,14,255,233,255,168,1,36,3,219,250,171,252,35,6,106,7,239,0,212,253,42,1,95,255,9,3,253,2,72,250,29,4,82,251,124,251,107,252,0,0,180,5,191,1,154,4,117,2,81,250,201,249,40,1,7,249,98,249,161,249,85,14,235,14,109,13,202,12,68,252,102,253,150,252,228,254,166,252,54,255,81,253,192,6,0,254,73,252,84,18,176,250,38,251,92,251,23,250,63,254,226,249,21,250,54,251,17,15,222,4,55,251,164,252,212,251,20,253,229,255,124,1,166,4,79,2,40,2,145,250,194,0,5,253,49,254,75,1,247,254,190,2,181,0,34,1,111,255,186,252,177,250,155,250,223,249,137,250,192,251,179,250,241,250,26,254,156,253,102,6,182,253,178,5,250,252,33,255,148,253,152,255,189,0,88,1,13,1,19,6,148,5,157,252,147,253,218,254,50,255,32,0,235,0,5,1,161,0,3,252,151,255,142,2,21,255,230,254,249,255,189,0,97,255,38,255,113,0,184,251,218,250,24,251,201,250,93,252,36,254,239,251,81,251,146,251,221,10,57,250,58,251,139,250,157,252,209,252,107,253,228,2,16,255,134,4,223,2,101,250,21,252,95,1,34,252,11,255,184,255,165,254,184,255,128,5,122,2,95,249,65,249,2,250,76,249,100,250,154,255,146,1,238,5,111,7,31,5,59,250,94,252,157,254,252,1,94,255,21,0,210,255,198,1,131,1,173,0,224,250,252,250,50,250,108,251,180,250,59,252,174,251,224,6,98,253,115,8,186,255,161,1,209,253,101,253,223,253,79,252,83,254,149,254,157,0,0,5,11,8,217,250,245,250,49,252,182,250,31,251,244,252,36,254,130,5,228,4,87,251,97,252,74,250,103,3,255,250,209,250,124,252,4,6,251,5,203,4,141,249,202,250,207,251,16,253,102,255,198,2,62,3,5,3,23,1,51,1,242,250,228,252,7,253,244,3,47,6,92,254,79,255,189,254,154,0,70,2,2,252,166,252,251,252,48,1,143,252,253,252,171,254,169,3,14,1,164,1,84,253,24,252,229,252,121,252,97,253,193,253,14,0,255,12,16,2,125,3,197,3,227,253,77,252,253,251,168,15,199,251,25,253,33,252,216,252,165,3,130,250,107,251,89,29,200,252,43,255,227,252,120,253,216,255,176,0,217,0,238,250,87,26,13,253,24,255,72,254,88,253,243,254,196,255,176,255,171,255,131,252,236,251,42,253,35,253,190,252,127,253,231,0,245,252,11,254,40,7,240,250,244,9,194,10,19,0,46,255,60,253,51,255,182,255,18,0,55,0,55,251,157,251,41,251,79,27,79,253,16,1,222,254,56,0,100,1,163,2,87,6,146,251,161,253,146,5,152,252,255,1,220,251,152,1,253,0,167,1,168,7,199,250,128,251,39,252,100,252,228,7,114,254,92,1,92,16,20,4,118,253,193,252,93,11,35,8,55,254,251,255,243,251,60,252,128,255,216,255,131,23,166,252,87,252,209,253,144,253,167,253,101,254,120,0,223,254,156,1,9,251,185,250,18,15,66,251,176,8,187,254,91,255,23,2,47,2,130,1,76,7,137,2,13,1,245,0,60,253,246,252,77,255,244,255,101,0,244,255,45,251,132,252,195,252,10,10,194,253,81,254,170,0,167,0,236,1,19,2,94,252,187,251,243,251,103,251,129,251,112,252,46,254,47,1,65,6,249,15,46,251,88,12,137,253,190,251,27,253,238,254,103,0,13,0,100,1,33,1,149,10,165,251,13,252,59,252,76,252,205,253,147,7,102,3,163,4,38,2,252,251,63,251,42,253,70,252,74,253,15,253,145,14,141,0,6,2,86,3,178,251,114,4,77,252,148,253,133,254,76,254,72,0,193,1,176,1,172,1,168,251,252,4,32,2,178,254,67,254,179,0,224,255,219,255,9,0,28,0,28,251,167,11,61,252,232,4,163,1,246,255,17,0,211,0,218,0,191,0,126,0,82,252,77,253,239,253,235,253,63,255,192,4,150,0,133,1,152,0,89,251,37,252,82,252,164,252,49,254,63,253,97,255,184,0,101,7,56,4,217,6,74,253,159,253,69,253,61,0,13,1,130,255,93,0,236,0,124,1,241,253,58,252,178,254,163,0,106,253,223,12,35,254,79,2,3,1,126,2,141,1,181,0,170,253,127,255,35,0,205,255,134,255,64,0,224,255,158,255,185,250,140,251,44,13,15,253,248,252,206,2,1,2,134,0,164,1,98,1,152,251,222,253,25,253,41,1,27,7,179,255,179,0,17,0,181,0,206,0,252,251,253,251,11,253,13,253,123,254,11,4,227,0,249,0,59,1,139,1,93,252,143,252,183,4,247,252,91,255,237,253,137,254,73,0,90,1,76,1,121,251,236,252,172,4,191,3,80,254,175,254,243,0,176,0,65,1,249,255,157,250,205,250,3,251,14,251,97,252,0,0,248,9,15,10,169,1,48,0,8,10,230,255,183,252,6,253,89,253,206,253,92,254,186,0,68,0,69,0,25,253,63,255,10,1,92,0,178,6,15,255,155,254,163,255,4,255,34,255,140,252,127,254,132,9,66,254,106,255,235,253,64,255,223,255,226,0,8,0,12,253,100,251,42,251,22,251,30,251,133,251,4,253,141,0,3,12,40,16,25,251,248,250,78,251,92,251,58,251,23,251,12,254,197,7,222,15,48,5,212,254,70,255,113,254,183,254,182,254,235,253,199,254,238,7,193,0,128,255,91,252,8,252,66,0,112,6,28,255,191,254,236,0,114,0,100,1,212,0,91,253,198,252,240,252,98,253,28,254,89,254,68,255,215,0,172,9,140,2,96,13,199,7,172,3,192,253,82,252,242,251,183,251,119,251,160,251,68,252,5,253,96,254,8,11,149,5,75,253,13,253,57,254,98,253,233,253,31,255,206,18,116,0,84,252,71,252,16,252,168,252,227,252,186,253,237,253,43,255,100,254,175,9,100,255,38,255,193,254,88,255,20,255,8,255,207,254,253,253,32,255,130,254,11,254,9,253,139,0,253,6,254,254,169,254,89,255,209,2,10,252,188,251,49,252,210,251,154,251,246,252,78,255,36,0,10,2,251,20,110,254,185,250,215,249,130,249,150,249,232,249,31,251,154,252,90,2,8,35,154,251,178,251,162,251,208,251,78,252,1,254,226,1,99,6,84,4,167,9,89,252,20,253,210,254,67,254,214,252,153,254,153,5,173,255,80,1,42,7,56,253,251,252,16,253,159,253,121,254,113,2,246,9,147,1,65,254,238,255,251,254,91,0,232,19,57,255,137,252,6,252,40,253,94,252,103,252,84,253,234,255,118,9,70,8,95,254,11,253,235,252,36,253,230,252,239,252,104,253,141,253,117,3,215,1,30,3,83,254,84,253,58,254,71,255,185,0,230,255,34,252,143,254,24,4,231,255,158,255,208,2,41,0,196,255,253,255,164,255,234,252,109,255,78,3,167,15,166,254,117,252,175,252,38,253,129,253,182,252,136,35,105,2,116,251,5,251,156,250,140,250,145,250,172,250,194,250,200,251,143,2,55,22,249,1,206,252,146,251,155,251,144,251,157,251,192,251,28,252,3,0,36,0,208,255,228,255,121,0,201,255,172,0,213,255,21,0,182,255,1,6,187,255,122,1,218,255,143,255,159,0,107,255,159,253,75,253,228,252,53,253,76,2,120,1,24,253,109,253,196,254,145,0,192,1,147,2,64,1,19,3,197,254,68,252,86,253,173,253,185,254,146,0,92,1,69,3,65,2,13,252,10,252,121,253,97,255,167,2,158,0,38,1,158,2,251,1,28,2,162,1,46,2,12,0,94,253,123,252,127,252,197,252,86,253,67,1,20,10,41,251,226,250,40,251,134,251,199,250,23,5,30,254,167,8,234,7,174,8,136,251,92,251,71,251,231,9,169,251,180,252,205,5,113,2,230,4,180,4,44,23,164,251,45,251,72,251,223,252,4,252,210,253,107,5,233,5,201,251,148,12,128,252,197,251,114,251,198,8,70,251,186,252,74,252,64,252,252,2,117,54,229,250,207,252,27,251,58,7,216,250,175,250,62,251,97,253,12,3,185,252,212,251,248,252,161,11,54,253,80,252,201,252,188,253,101,1,79,2,46,1,202,251,129,252,4,252,44,12,136,251,158,5,133,252,185,255,248,5,18,255,239,250,4,252,8,18,95,251,254,253,126,251,123,251,109,7,68,9,149,251,247,250,7,251,247,250,225,250,205,250,196,250,183,1,199,1,91,9,231,253,100,251,105,9,196,251,188,253,145,7,78,3,205,255,103,2,75,4,14,15,103,251,112,252,185,251,144,2,29,252,121,253,226,12,48,252,76,254,35,48,245,250,93,251,195,250,171,18,168,250,179,250,219,250,39,252,127,5,255,253,149,250,56,251,211,251,62,251,163,251,75,255,71,251,0,21,160,16,234,255,48,251,107,251,190,252,226,251,77,252,157,253,202,252,50,255,196,21,36,252,43,4,187,252,226,2,180,254,218,255,197,255,143,0,248,0,130,1,65,254,47,251,22,251,111,251,69,14,235,251,111,253,98,252,212,7,153,8,116,251,130,27,234,250,223,250,212,252,150,0,127,255,49,1,186,1,230,2,95,251,243,250,60,251,152,252,232,250,20,251,171,252,243,250,146,11,195,11,78,255,93,251,193,251,128,252,129,252,227,251,204,14,59,0,87,255,96,6,79,251,247,250,143,20,128,252,75,1,172,252,218,0,57,3,105,4,0,4,217,255,94,251,226,251,70,7,82,251,218,7,205,251,19,252,190,2,14,6,139,17,225,251,134,252,123,253,37,252,161,9,17,2,194,0,184,255,114,1,11,6,56,252,175,252,127,251,59,25,116,251,219,251,4,252,186,252,125,0,114,14,112,251,214,251,90,7,121,251,73,254,7,252,9,253,232,2,22,5,212,252,39,252,22,252,251,251,153,252,106,14,86,255,92,2,111,2,248,4,247,23,12,252,49,251,214,251,97,252,198,251,89,9,181,252,1,6,216,4,158,252,119,251,158,252,239,25,30,252,164,252,248,254,214,254,213,1,160,4,156,252,18,251,119,8,103,251,84,8,37,252,205,253,201,3,121,4,228,5,33,253,48,251,190,251,76,251,227,5,179,251,119,254,243,2,207,3,222,4,152,7,212,251,111,251,240,251,37,252,235,250,112,21,223,251,78,12,98,7,147,251,165,10,157,251,61,252,109,7,4,1,28,254,193,1,52,2,120,4,167,2,162,251,35,252,66,253,212,253,162,0,177,2,200,2,161,2,187,1,73,253,33,251,5,252,215,251,106,254,137,251,214,6,25,253,84,10,98,9,109,251,123,251,221,251,201,252,80,253,34,5,178,5,117,2,89,3,88,3,149,252,220,250,142,13,219,251,178,252,7,253,56,253,69,252,210,3,175,7,44,252,189,13,30,252,71,252,121,252,56,0,228,0,226,255,103,1,48,2,198,38,102,251,224,251,141,253,72,252,31,254,112,251,244,254,67,253,213,253,137,252,68,251,232,6,124,251,116,254,13,253,137,255,58,6,181,3,177,4,180,252,198,6,32,5,181,254,12,254,232,254,131,255,37,255,117,255,240,1,159,251,53,251,135,251,41,255,157,251,3,253,83,255,215,15,62,4,185,5,54,253,120,252,123,252,55,253,207,251,209,4,227,252,133,2,58,0,129,3,250,253,144,253,71,254,214,253,115,4,37,2,147,0,72,0,127,0,172,1,176,251,45,252,129,9,75,7,19,255,23,253,232,254,110,0,26,3,119,2,231,251,117,4,50,252,104,252,175,252,120,254,122,2,158,1,102,2,29,3,118,251,192,250,88,251,21,251,201,251,112,252,157,10,244,9,55,7,128,7,20,252,189,251,18,252,76,253,171,255,232,255,246,3,147,5,239,2,184,253,169,23,74,251,208,251,229,252,103,252,177,251,123,251,145,253,206,252,81,10,49,12,196,251,185,251,85,252,104,253,74,253,116,3,43,2,144,0,81,2,150,252,206,251,161,1,253,251,250,255,234,252,151,6,80,0,250,3,226,2,241,253,66,252,67,253,135,254,252,255,155,0,48,1,164,254,77,252,170,254,221,8,240,251,100,4,18,254,180,255,76,0,2,0,114,0,62,255,92,1,136,3,210,1,191,253,51,253,107,0,217,255,227,255,158,0,101,0,149,0,56,252,103,252,46,2,248,254,67,254,138,0,135,255,223,255,105,0,243,0,34,254,233,251,87,252,17,253,159,253,202,252,59,253,48,252,18,252,240,10,172,251,244,250,225,251,8,251,241,250,128,251,49,1,136,251,123,2,19,8,184,253,145,251,105,253,150,251,14,253,15,252,87,252,253,253,193,5,73,3,45,251,198,250,231,250,139,251,171,251,63,251,18,255,123,7,222,13,2,9,61,252,39,252,150,252,251,2,198,252,74,253,19,0,135,1,123,1,8,3,186,253,64,251,251,250,116,251,4,251,231,250,7,251,71,10,189,253,183,9,34,4,113,253,216,252,146,252,114,252,18,252,158,251,178,253,105,253,172,1,137,8,155,251,248,251,204,251,151,252,141,251,251,251,35,254,184,6,214,4,169,251,225,250,193,250,50,4,208,250,99,251,54,252,126,254,55,9,241,6,235,251,91,251,163,251,227,251,82,252,183,254,245,1,213,4,40,3,254,3,158,252,232,251,90,253,61,6,248,5,250,254,0,255,231,0,162,1,216,2,175,25,143,252,245,250,22,251,190,251,251,253,244,254,200,255,106,0,39,1,209,254,146,251,167,251,118,253,4,254,51,7,21,255,115,255,198,1,64,3,68,251,88,3,108,254,148,253,86,253,25,254,187,255,97,3,85,1,95,0,42,14,243,251,170,250,187,250,154,251,210,253,187,0,87,1,145,2,253,2,102,254,33,253,234,251,1,252,127,252,95,253,146,254,102,12,240,4,208,2,38,253,102,252,245,253,203,252,202,15,49,254,45,0,73,1,213,0,163,255,45,1,13,252,21,1,184,252,204,252,61,254,161,1,214,1,227,2,185,3,61,251,250,250,247,249,110,250,71,251,221,252,132,4,31,5,49,5,49,5,125,253,144,251,80,251,112,252,197,4,73,253,86,1,142,3,137,3,44,3,28,252,147,254,4,19,30,253,177,253,147,253,17,0,214,255,0,0,100,0,37,8,66,251,102,250,104,250,37,251,191,253,142,253,140,0,77,5,29,7,216,251,19,251,163,249,11,250,48,250,179,251,137,253,39,2,228,13,134,15,133,253,178,252,19,252,122,253,221,252,123,0,105,255,101,1,89,8,185,3,112,251,225,251,165,251,219,251,201,252,117,253,2,15,94,2,235,1,235,1,239,250,217,251,34,252,229,251,78,251,41,252,44,254,209,255,163,0,80,1,149,251,66,254,85,253,132,2,108,253,93,253,227,4,117,1,195,0,133,255,171,251,82,254,28,7,91,7,162,252,25,253,247,254,119,0,66,0,215,255,255,250,0,253,149,7,69,252,226,251,168,252,16,2,107,1,232,1,33,2,88,252,86,253,210,252,158,21,198,252,165,254,58,0,218,255,168,0,14,0,200,4,49,253,212,254,2,253,105,254,118,2,13,1,39,0,26,255,67,253,65,6,66,252,79,252,69,252,34,253,25,254,236,255,112,5,32,2,26,1,138,255,147,251,119,251,215,251,85,252,43,255,127,255,241,254,195,1,10,10,129,252,219,252,232,253,175,5,216,5,121,253,57,255,114,0,95,0,214,255,182,8,169,252,53,253,205,252,226,6,69,253,206,255,147,255,163,0,207,0,178,254,9,253,225,12,123,253,1,10,77,0,17,255,253,254,237,254,67,254,232,250,208,13,74,6,242,253,98,252,186,253,244,255,44,0,76,255,187,255,220,252,83,4,171,5,156,252,173,252,179,253,158,254,171,255,88,0,80,1,231,253,68,254,40,0,231,0,53,253,245,253,161,254,133,254,133,255,171,0,199,4,184,254,201,253,134,8,221,254,160,254,20,0,99,255,174,254,133,253,146,8,36,254,88,6,222,252,6,253,183,253,11,255,48,0,63,0,211,255,224,255,122,253,79,3,212,253,41,253,253,254,29,5,239,0,128,255,13,253,6,252,128,253,108,3,126,253,118,252,114,5,230,255,82,1,204,0,148,0,36,252,247,253,135,0,217,252,41,4,243,253,176,255,8,255,127,1,68,3,9,2,13,0,215,253,159,252,96,252,137,253,119,255,173,255,190,1,221,0,132,7,48,0,147,253,179,252,242,252,224,253,237,253,94,254,177,255,147,3,57,253,223,4,86,252,2,253,29,252,179,5,31,0,199,0,5,1,190,0,98,253,73,251,11,252,108,0,98,253,204,0,151,1,10,1,217,1,230,3,162,253,101,252,53,7,219,251,142,3,250,252,12,1,237,1,178,0,61,0,146,7,43,251,14,252,183,251,244,252,144,254,101,4,98,1,142,1,38,2,8,4,152,251,84,251,116,252,1,253,17,2,22,9,216,2,227,0,243,255,167,251,145,254,126,1,85,252,186,251,128,252,49,254,190,1,128,3,104,4,177,253,201,252,130,252,236,11,56,252,109,8,103,255,185,255,111,0,118,0,174,251,94,252,113,252,127,6,119,252,77,253,30,255,247,1,153,2,190,2,19,8,131,251,196,252,222,3,174,252,86,254,97,255,148,0,123,1,0,2,12,251,146,250,44,250,193,250,117,250,198,8,32,255,76,8,243,5,58,5,10,2,77,6,168,254,74,253,25,254,187,254,37,1,96,0,138,254,89,253,148,254,124,0,79,251,6,251,202,251,255,253,15,0,21,4,17,2,168,2,131,0,213,251,250,251,136,252,218,252,134,255,234,3,22,5,245,2,39,254,238,253,230,253,203,252,139,254,72,0,29,3,96,3,9,1,226,253,190,251,15,255,185,251,75,251,33,252,108,251,161,19,92,254,216,2,205,1,103,0,21,9,109,252,12,252,170,252,163,251,226,7,135,254,221,255,10,1,187,1,75,252,117,251,216,251,223,251,222,252,209,2,254,4,214,1,52,1,7,1,218,1,251,252,247,251,132,252,227,0,226,255,39,0,101,0,200,1,220,1,17,251,107,28,78,252,123,251,232,250,102,252,248,0,143,0,158,255,56,1,91,13,110,254,119,253,139,253,214,253,208,255,231,1,72,0,85,255,81,253,113,251,77,7,244,253,210,5,155,252,20,255,111,0,68,0,77,0,171,255,201,5,138,3,91,251,215,250,156,251,214,253,173,1,65,1,46,3,187,2,232,251,230,1,166,252,184,251,208,251,24,253,140,6,183,255,81,2,120,2,11,3,15,251,66,250,157,250,230,251,220,253,13,3,12,2,254,3,55,4,131,251,135,14,216,251,100,251,121,251,249,252,45,255,241,0,236,1,43,2,209,11,12,11,175,252,147,251,217,251,201,253,186,255,114,255,80,255,194,255,154,253,209,6,84,253,158,253,198,5,149,253,21,255,151,254,172,255,212,255,125,251,214,5,97,251,70,251,242,250,7,252,182,254,210,0,163,3,88,5,230,250,154,10,228,251,152,251,60,251,116,252,105,9,185,1,54,1,62,1,243,21,93,255,19,252,168,252,193,252,124,253,156,253,9,253,254,252,56,254,199,0,217,253,188,250,176,255,131,0,31,254,78,1,202,0,110,1,222,4,35,251,243,1,82,250,116,254,93,253,255,254,13,2,233,3,110,3,51,4,20,252,14,252,153,251,77,252,48,252,76,1,205,13,35,5,9,1,85,253,166,251,32,4,15,252,130,4,40,253,44,255,108,2,169,0,102,0,146,255,110,253,122,252,42,251,67,251,42,251,98,252,33,253,57,254,106,4,19,20,96,251,190,0,54,6,164,253,224,252,139,254,146,254,251,0,208,2,59,2,250,255,48,1,52,251,143,254,109,253,6,254,231,255,22,255,57,1,62,9,111,2,193,5,197,254,12,3,24,4,96,254,182,253,31,253,251,251,186,251,227,1,43,253,253,252,133,254,244,254,241,255,185,2,238,6,255,255,25,252,37,252,157,252,197,250,25,251,6,252,116,253,131,255,131,2,190,11,113,9,225,253,93,6,21,6,84,253,200,253,38,254,124,255,221,254,174,254,191,254,30,251,129,2,98,255,89,252,193,253,193,253,154,0,159,1,30,3,141,5,75,12,111,7,177,254,1,253,39,253,141,253,157,253,16,253,188,252,33,253,166,2,246,1,78,252,44,2,203,252,205,255,0,255,94,0,151,0,70,0,216,252,188,254,153,254,53,14,30,1,166,255,147,254,155,253,242,252,153,252,75,0,27,4,244,252,25,254,47,0,17,1,232,6,154,255,196,252,13,251,187,251,140,5,144,253,225,0,27,5,85,0,239,0,104,255,119,253,171,252,208,251,228,252,124,253,103,5,119,4,57,255,94,0,231,255,70,0,52,0,216,251,183,9,180,252,161,253,181,253,148,0,214,2,224,0,18,255,28,254,67,252,39,253,237,5,54,5,37,254,195,254,3,255,70,255,1,0,17,0,192,252,170,5,167,1,128,5,192,253,199,252,138,253,189,253,200,254,58,1,20,3,126,1,24,252,220,251,5,253,200,3,121,255,56,0,143,0,221,1,32,253,30,0,183,15,68,0,246,254,92,254,230,253,17,253,131,252,145,252,89,252,59,0,209,1,119,3,161,254,116,5,176,0,6,255,84,253,5,252,253,253,209,252,67,252,73,254,188,0,210,14,86,0,158,255,11,255,195,252,102,7,126,254,159,252,233,5,24,0,6,254,231,254,153,253,36,254,148,254,253,250,61,252,173,254,123,255,95,255,32,254,25,0,230,0,84,5,23,7,230,6,180,252,113,250,95,251,52,252,54,254,237,254,138,0,37,5,242,6,241,250,150,252,69,251,232,252,167,253,12,254,253,8,133,3,56,5,74,3,75,5,86,254,120,251,65,252,223,252,79,254,60,7,144,0,28,1,169,0,158,251,173,252,67,252,16,1,119,254,49,3,94,3,6,1,77,1,34,3,64,1,192,253,79,6,153,253,138,252,201,254,108,0,13,0,1,0,64,1,75,251,194,3,29,254,233,252,19,253,134,4,165,2,199,255,166,0,23,1,164,252,213,4,53,252,223,251,170,253,227,254,116,3,150,4,145,2,209,254,206,8,62,253,167,251,113,253,207,2,234,0,132,255,57,255,121,255,152,254,10,253,145,253,127,254,238,255,171,12,214,1,117,255,226,254,248,253,71,252,87,251,140,251,239,250,143,251,4,253,25,0,235,0,169,8,221,5,89,5,232,7,13,3,183,250,189,252,200,252,167,253,253,254,116,255,131,1,159,2,3,0,50,252,8,253,140,252,27,254,197,2,225,5,161,255,65,1,227,2,74,6,100,255,235,5,180,255,92,254,143,254,67,255,6,254,63,253,117,252,228,251,252,253,232,251,28,252,41,254,171,4,212,0,184,0,32,3,129,6,235,2,251,251,11,252,21,3,65,253,47,2,117,255,158,255,124,1,11,2,157,254,255,7,2,253,33,252,215,252,202,253,255,254,14,255,229,1,42,5,197,7,182,254,79,252,209,253,64,254,217,4,43,3,10,0,1,253,62,251,64,6,13,253,172,1,39,253,157,254,103,253,96,254,136,255,125,1,36,2,51,253,242,255,51,6,138,252,247,255,97,1,71,3,201,0,58,254,168,251,202,250,203,254,148,2,137,254,107,253,1,254,157,5,28,2,236,1,0,0,95,0,71,15,19,255,211,254,206,253,29,254,199,253,225,252,141,252,188,253,98,253,44,252,224,251,128,252,227,252,15,6,11,1,232,3,81,6,75,0,148,251,109,254,36,252,194,252,141,253,140,4,35,5,58,6,54,1,204,253,189,251,205,253,171,4,70,254,62,4,168,254,80,255,254,254,175,0,220,1,155,3,219,255,139,253,105,252,254,4,158,253,113,0,198,254,175,255,192,0,219,2,80,252,239,250,172,251,90,252,253,254,128,2,140,4,46,5,46,2,1,253,249,253,149,252,94,252,207,252,235,253,240,1,45,10,79,5,125,255,14,252,144,3,225,251,203,254,0,3,58,255,90,255,180,255,173,1,128,2,211,12,129,252,51,251,171,252,171,252,113,254,147,0,44,0,237,0,239,1,191,252,115,252,20,252,213,252,15,4,91,6,62,255,39,1,226,2,34,1,253,252,237,0,112,252,33,254,120,253,250,253,30,255,61,2,42,9,163,1,245,3,230,5,159,252,151,252,42,252,211,253,86,2,50,0,81,0,175,255,130,251,128,253,13,252,199,7,207,253,116,255,42,0,175,0,9,2,31,3,159,12,210,255,20,252,30,252,140,251,186,251,67,252,164,252,8,0,42,9,212,0,13,254,201,255,27,252,145,253,180,253,38,0,198,255,207,3,249,5,38,252,133,252,159,251,149,253,175,7,49,254,249,255,120,2,0,3,185,3,129,9,99,252,9,252,15,252,149,252,236,254,122,1,208,1,182,2,27,3,236,251,167,253,110,253,1,1,126,252,3,254,166,254,112,8,182,2,184,3,234,250,149,253,246,1,134,254,144,253,78,255,93,1,156,255,204,0,34,2,86,250,153,251,234,250,239,250,229,251,184,252,98,13,66,5,41,6,187,6,13,251,58,253,152,252,192,1,1,252,40,253,247,253,122,255,106,3,168,3,146,251,219,253,203,0,92,252,229,251,243,2,160,253,57,255,90,3,240,3,27,7,182,252,251,252,29,253,50,3,141,254,33,1,37,1,144,2,192,2,52,1,15,252,65,252,191,251,210,1,44,254,23,1,129,3,252,2,29,3,103,250,4,251,27,251,210,250,98,251,32,252,171,255,243,16,87,8,88,8,107,4,107,252,58,252,165,252,135,252,154,4,62,0,147,2,3,3,114,3,52,7,161,253,160,4,2,253,219,252,127,254,195,255,246,1,136,2,220,2,35,251,35,5,206,252,197,252,109,2,180,253,193,0,224,1,137,2,8,3,102,251,78,251,128,251,192,251,167,252,65,255,207,255,129,0,158,7,213,4,75,250,246,250,194,250,135,250,198,250,67,251,145,253,224,0,246,15,213,9,130,251,210,252,21,253,148,3,39,3,224,254,63,1,180,1,48,2,206,2,136,1,51,252,36,252,155,1,70,252,10,254,214,0,109,2,88,3,63,3,12,251,172,15,172,252,22,252,10,252,191,253,32,0,40,2,219,3,114,4,75,251,217,250,135,251,96,252,80,0,115,1,21,1,11,3,91,3,134,3,139,251,33,252,67,252,195,2,132,252,74,4,126,0,125,1,156,2,102,3,26,251,29,252,117,251,98,252,131,251,12,10,239,255,235,2,176,5,229,5,20,252,157,252,181,4,227,252,170,3,111,253,90,1,8,2,14,3,104,3,208,250,200,251,169,251,213,251,179,8,132,252,153,2,68,6,145,5,197,5,77,7,100,253,56,253,20,4,224,252,117,255,0,0,99,1,97,2,205,2,88,251,136,253,218,13,244,252,154,252,11,254,141,0,248,1,153,3,3,4,155,251,193,251,130,4,108,253,37,252,169,3,82,0,110,5,80,5,219,4,235,4,218,253,255,252,237,252,25,253,150,254,244,255,177,0,65,1,249,1,133,251,125,252,77,252,175,252,91,5,50,254,129,255,16,0,240,2,186,3,131,250,192,1,99,251,21,251,76,251,156,252,44,254,110,0,13,5,239,4,13,251,100,251,42,251,94,252,84,252,148,3,1,7,141,2,46,4,113,4,40,255,27,252,179,252,109,253,69,253,82,255,246,2,193,3,161,1,118,2,157,251,155,6,205,4,36,253,87,252,21,254,178,255,9,1,232,2,96,3,163,18,168,252,19,252,17,252,90,252,28,254,239,255,67,2,93,3,191,3,16,251,70,0,63,252,160,252,164,252,210,254,58,1,20,3,231,1,174,2,147,251,234,252,46,254,49,2,212,252,0,255,30,8,198,255,245,2,185,3,147,251,226,254,113,253,36,254,233,255,139,253,7,0,182,0,170,1,248,1,170,251,58,1,241,1,202,252,106,253,14,253,155,4,190,6,184,2,187,3,1,7,137,251,12,251,1,251,73,251,151,252,73,255,10,6,160,5,25,5,2,251,116,5,245,252,46,2,184,252,224,255,238,255,1,1,104,2,245,2,9,1,118,252,243,1,127,252,178,252,77,254,106,1,178,1,240,2,220,2,197,1,150,0,251,251,98,251,85,251,84,252,215,254,108,3,60,4,27,4,159,250,74,5,132,251,223,250,69,251,87,252,146,254,150,7,43,5,130,5,55,1,242,254,175,255,97,255,42,0,42,0,7,0,101,1,255,0,29,1,181,7,106,5,16,253,151,252,108,252,46,254,217,255,237,1,126,2,247,2,198,250,83,4,199,251,115,251,242,251,28,254,186,6,22,2,14,4,78,4,90,250,68,251,199,250,84,250,114,250,245,250,78,253,98,6,68,5,104,6,236,251,72,255,11,253,85,253,156,255,20,4,113,1,93,1,176,1,72,2,143,251,240,253,145,5,14,5,182,252,255,254,224,255,33,1,127,2,28,3,118,250,51,251,254,250,145,250,115,250,46,251,172,252,3,253,225,2,28,8,176,251,96,252,88,252,192,251,122,1,3,253,67,6,69,2,241,2,157,3,89,251,183,252,105,252,70,11,117,252,24,255,180,0,31,2,188,3,46,4,222,250,181,252,36,3,186,251,71,251,249,251,142,253,186,2,25,4,128,4,0,1,63,3,183,252,210,252,183,252,202,255,134,0,91,1,23,2,146,2,104,0,223,252,65,252,249,253,106,254,156,0,12,0,13,0,124,1,238,1,136,251,168,251,51,252,59,252,108,252,38,254,31,255,204,1,146,1,222,2,88,250,220,250,2,251,231,0,194,251,190,253,72,2,91,4,251,4,236,4,215,250,61,252,153,251,248,250,41,0,178,251,225,255,51,5,235,3,121,4,112,0,10,251,193,250,160,250,166,251,246,252,136,1,126,7,141,4,222,4,33,251,154,252,48,251,133,251,205,251,58,2,181,0,191,7,203,3,192,4,227,250,81,251,4,1,144,251,74,252,26,253,43,4,191,2,126,4,120,4,131,250,3,250,228,249,243,249,16,251,31,253,61,4,170,6,14,7,249,6,26,1,107,251,152,251,92,251,53,252,139,252,221,254,254,0,73,3,219,3,114,255,212,251,16,251,48,251,222,251,138,0,34,2,9,2,72,4,219,3,122,3,88,252,4,252,229,251,153,252,247,253,150,6,113,2,162,3,168,3,193,250,100,252,49,251,33,251,228,251,73,252,86,4,125,0,58,3,92,4,109,26,130,253,172,251,47,252,89,253,66,254,187,254,80,254,129,255,96,0,199,253,147,253,230,251,183,252,224,252,194,5,146,4,60,0,74,1,223,0,219,250,87,3,51,1,93,252,120,253,219,253,108,255,23,2,130,2,189,1,82,14,134,251,113,251,80,252,184,253,174,3,228,254,25,0,61,2,216,1,239,251,184,251,71,251,198,251,254,252,31,253,117,255,25,8,241,2,64,3,251,1,196,252,168,251,150,251,188,16,46,253,251,254,199,255,243,1,44,1,156,250,150,251,135,0,126,252,208,252,117,254,195,0,197,1,138,2,25,2,71,252,171,251,59,251,43,252,21,253,121,253,56,9,211,1,77,3,172,2,103,251,232,252,26,251,132,251,64,5,23,253,189,254,180,0,217,2,227,2,4,252,183,0,106,20,130,253,154,254,170,255,244,254,113,255,84,0,141,255,224,1,225,253,51,251,183,251,174,253,41,252,232,252,121,254,77,10,125,5,7,253,158,252,94,251,51,252,232,252,128,253,36,255,154,255,141,4,87,12,39,251,223,251,214,250,17,252,37,253,44,0,8,1,156,2,85,10,56,6,69,11,125,251,189,250,71,251,203,254,119,251,120,16,192,255,62,3,104,2,80,253,130,253,172,253,202,0,103,253,145,253,13,254,8,255,0,2,237,2,141,250,60,253,194,251,185,4,23,253,145,254,117,5,23,1,118,1,3,1,179,250,2,255,6,9,47,7,109,255,36,0,110,254,44,1,207,255,47,0,208,250,32,252,125,13,135,252,147,253,135,0,181,1,70,0,151,2,90,1,197,250,144,251,5,251,19,26,227,250,237,8,155,252,130,4,128,2,105,2,7,254,238,251,40,252,66,253,3,5,37,6,88,255,135,0,249,0,253,0,241,252,161,251,194,250,49,252,153,251,111,5,63,253,87,17,136,4,77,3,253,250,56,251,250,250,138,251,5,252,123,252,110,253,99,255,231,0,99,2,30,252,49,254,7,252,58,4,39,7,53,254,92,255,114,0,0,0,108,0,150,250,201,251,218,250,189,251,236,9,51,253,250,2,134,5,81,3,64,2,131,250,202,253,144,10,28,252,85,8,90,253,148,1,25,1,4,0,224,255,62,250,202,13,253,8,57,253,105,252,207,254,131,255,184,0,194,1,73,0,148,251,31,6,84,6,217,253,58,255,123,253,19,0,8,0,190,0,191,0,27,253,40,253,154,1,43,4,190,254,17,255,86,0,11,0,119,255,36,255,23,254,161,253,61,252,46,14,144,253,34,254,244,255,124,0,219,0,63,0,248,7,75,0,58,5,219,254,179,254,176,254,182,254,10,255,152,254,168,254,71,252,119,254,14,6,67,253,152,253,2,255,116,7,211,0,72,1,213,255,191,251,213,254,46,4,45,253,101,252,122,8,112,254,243,255,228,255,108,0,212,252,112,254,108,3,118,253,28,5,252,252,0,255,56,255,117,0,73,1,137,2,129,253,181,1,64,253,201,253,236,255,45,255,197,0,74,1,86,1,134,6,44,254,104,252,180,253,204,3,202,254,9,0,210,255,70,0,227,255,223,250,148,6,230,252,45,252,16,253,72,7,83,255,108,0,248,0,36,1,33,251,54,251,221,251,32,1,144,255,189,0,20,0,28,2,198,1,124,1,245,251,221,252,243,4,1,253,234,2,51,5,107,0,61,1,158,0,140,255,45,8,45,253,216,251,118,252,55,253,235,252,250,253,48,0,238,1,250,3,43,7,183,250,233,250,182,251,209,253,32,3,8,2,150,2,103,2,62,2,254,250,242,253,37,7,194,251,139,252,156,254,229,253,206,255,237,1,146,1,247,252,138,254,14,253,185,6,67,253,38,8,164,254,218,0,138,0,109,0,169,250,54,251,239,251,157,7,79,254,221,254,149,254,55,2,101,2,48,2,142,4,31,254,31,253,169,4,33,254,93,255,187,255,2,0,133,0,239,0,92,250,88,250,186,250,37,252,216,254,94,2,243,2,31,2,229,2,38,3,173,252,133,9,23,0,87,253,98,253,241,254,73,254,29,255,13,255,58,255,229,250,168,1,68,251,37,252,23,253,143,254,162,0,129,2,147,3,99,2,232,255,40,253,219,251,109,253,40,3,236,253,217,4,23,255,10,1,97,1,175,0,210,0,250,254,184,254,101,0,18,255,66,0,173,254,40,254,97,254,184,3,46,250,234,250,69,252,10,251,144,22,232,252,9,3,73,4,39,3,202,250,108,251,69,251,100,252,147,252,154,9,157,254,81,2,168,3,187,2,176,254,68,253,6,253,199,253,175,254,130,2,97,0,185,1,68,255,235,253,218,251,188,0,151,252,223,252,162,1,89,255,199,255,227,255,79,0,241,0,170,251,30,25,208,252,217,252,50,254,167,253,200,255,211,255,188,0,74,0,53,11,43,0,158,251,225,252,252,252,177,252,114,5,220,255,38,1,13,0,232,250,107,8,234,253,9,6,197,254,187,254,183,0,31,0,116,1,187,0,105,3,96,5,243,251,214,252,252,253,21,255,229,1,99,0,31,1,71,1,206,251,179,4,191,251,142,252,253,253,224,253,249,7,216,255,208,0,191,0,85,2,139,251,6,251,139,252,126,254,106,0,81,2,138,1,159,2,166,2,244,250,21,15,195,251,130,251,20,253,38,255,244,1,55,0,79,1,213,1,145,12,72,11,142,252,125,253,178,253,6,254,43,0,53,254,46,255,34,255,59,252,149,9,194,252,245,252,16,7,180,253,130,0,4,0,130,0,233,255,11,251,94,5,42,251,132,251,245,253,109,253,86,255,210,254,31,4,109,5,69,250,201,9,94,252,99,251,182,252,252,253,143,1,118,3,81,3,226,2,129,22,114,254,25,253,76,252,80,252,179,252,141,252,128,252,213,252,164,253,138,251,148,250,90,251,83,253,138,255,218,5,54,6,37,1,52,2,96,1,124,0,83,3,125,255,116,253,195,253,233,254,12,253,34,254,65,3,158,2,49,10,142,251,173,251,0,252,29,253,122,253,125,254,33,0,123,2,13,4,51,253,34,252,119,251,76,252,108,253,26,255,69,0,206,9,250,4,73,3,207,255,152,252,4,253,45,255,230,11,226,255,113,255,201,254,188,254,99,254,8,253,67,0,107,2,69,253,43,253,49,1,28,254,12,5,216,1,100,255,200,253,37,251,24,251,30,252,221,252,126,254,156,6,84,2,45,5,10,5,20,254,17,252,36,253,236,252,112,4,158,253,45,0,27,5,164,1,137,2,234,253,205,251,75,252,145,254,219,0,188,1,136,255,251,0,220,1,14,7,134,3,97,252,129,251,145,252,109,253,27,253,251,255,42,1,69,7,227,3,12,255,249,251,138,251,195,251,72,252,251,252,44,254,247,255,101,6,8,14,53,252,130,251,81,251,39,252,79,253,195,254,150,0,28,2,167,10,142,6,33,255,109,254,102,0,122,252,251,252,33,255,110,12,55,254,75,0,68,255,221,254,84,254,155,255,147,254,70,254,176,254,128,255,223,255,13,3,218,4,245,1,15,253,178,252,245,2,68,254,201,254,158,4,4,0,248,255,134,255,74,7,240,253,114,255,62,6,241,255,37,255,211,253,220,252,108,252,59,252,114,0,130,0,88,14,237,255,151,252,232,254,247,252,105,252,200,252,114,253,54,4,39,0,206,255,119,0,101,254,201,254,153,254,199,255,119,255,7,0,244,252,132,252,1,253,89,255,22,5,157,6,51,255,205,255,82,255,185,255,70,3,36,255,147,251,31,252,58,253,172,254,138,2,61,5,191,0,251,255,231,2,225,253,131,255,201,253,70,0,214,255,11,254,64,254,47,0,127,4,144,1,250,252,243,252,44,5,65,4,32,0,0,255,97,254,160,254,42,255,144,3,139,251,36,252,130,253,69,5,251,0,124,0,252,255,89,0,240,255,90,253,199,253,222,5,146,0,114,0,48,3,158,255,243,254,146,253,216,252,134,253,247,12,194,4,189,254,18,253,220,253,243,253,193,253,177,253,38,253,35,0,252,2,143,5,62,2,160,254,96,253,222,252,198,254,204,254,227,255,240,251,51,253,213,1,165,1,241,253,92,254,77,2,195,0,44,2,216,1,142,253,160,252,123,255,203,13,101,253,52,254,245,253,103,0,23,0,203,254,77,9,136,0,173,4,113,254,113,254,11,254,130,253,125,252,211,252,61,253,7,255,207,2,53,3,35,252,139,253,200,253,130,2,252,255,41,1,70,0,175,251,198,1,144,1,21,255,206,253,71,6,140,255,51,255,1,0,22,254,7,0,245,253,252,2,73,1,224,3,16,255,7,255,237,254,146,254,247,254,150,2,221,252,137,1,201,253,11,254,224,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1455608);
/* memory initializer */ allocate([178,0,115,1,126,0,110,255,212,6,252,253,134,253,117,254,12,1,125,3,154,0,220,255,148,253,25,252,48,1,210,5,0,254,203,252,33,254,130,7,158,253,31,254,30,254,219,252,28,252,240,255,201,253,30,2,234,255,77,2,142,255,69,0,66,1,102,1,176,252,181,4,253,1,241,253,25,0,111,0,13,255,59,255,236,255,62,0,220,5,47,252,50,252,121,254,213,253,192,1,0,255,79,0,136,1,35,2,192,5,4,251,77,251,37,252,197,254,3,2,87,3,183,0,231,0,62,0,104,251,115,254,15,11,241,253,193,253,77,254,174,0,175,254,211,2,107,0,10,254,3,253,57,254,100,4,38,255,164,5,53,0,55,255,121,255,245,254,2,254,222,251,155,252,106,4,128,255,118,254,16,0,105,3,85,2,199,1,16,0,0,0,245,255,14,0,244,255,9,0,6,0,242,255,245,255,233,255,59,254,224,251,36,252,55,253,245,254,26,3,186,3,81,5,54,3,64,254,123,1,139,4,80,1,44,253,55,0,109,0,237,0,176,255,36,253,7,252,248,254,142,2,237,251,9,252,114,253,91,0,17,0,36,2,248,1,164,3,223,251,129,251,60,252,126,255,147,4,110,255,228,2,134,0,22,3,27,2,177,253,191,253,124,254,154,0,97,2,85,1,145,2,70,3,133,254,152,252,199,2,103,253,206,252,219,253,105,255,197,9,228,255,67,255,1,255,134,254,149,254,123,251,95,252,137,252,174,254,134,7,223,255,230,255,241,3,253,2,177,255,158,255,219,255,57,252,202,253,244,3,137,3,11,255,41,0,66,1,194,0,108,255,36,255,85,255,17,255,14,255,109,255,242,255,221,0,63,2,218,6,243,11,10,255,55,253,72,253,132,253,128,253,181,252,183,252,13,253,250,9,8,254,200,253,194,254,188,254,85,255,218,254,18,255,224,254,82,255,223,254,249,4,25,255,29,4,228,254,174,254,118,254,29,255,209,254,30,255,198,3,230,2,151,252,9,254,182,253,226,254,119,0,197,255,83,1,218,255,181,252,209,3,64,254,18,255,227,0,179,255,217,2,6,0,45,0,19,254,21,1,151,250,247,250,178,252,139,255,120,1,251,2,41,2,1,3,158,2,116,253,208,12,6,253,142,252,116,254,213,254,124,0,242,254,225,255,46,255,109,9,132,2,234,252,112,252,187,253,5,254,146,255,104,254,202,255,226,255,120,2,201,3,136,253,50,255,187,3,161,255,190,253,175,254,135,254,45,254,240,4,67,0,170,252,161,252,115,252,17,253,152,253,33,254,51,2,22,8,52,252,198,5,62,254,53,253,165,252,79,253,190,0,224,2,105,2,18,2,74,4,173,251,155,251,41,252,254,252,23,255,201,0,55,3,103,250,242,250,239,255,124,251,211,254,161,4,27,5,84,4,33,251,37,7,73,5,231,253,55,254,116,0,62,2,200,2,159,0,23,254,255,1,172,254,54,0,119,0,213,0,95,1,47,250,24,251,212,250,148,251,126,14,6,1,63,4,185,5,102,250,253,251,164,251,57,3,106,253,84,254,147,255,21,4,229,0,241,2,164,253,90,254,122,0,36,255,23,1,119,1,163,254,84,253,59,255,234,1,96,255,140,255,136,255,146,0,75,20,129,252,50,252,10,253,244,253,21,0,249,2,248,3,64,251,151,0,96,3,166,253,53,253,177,253,165,254,80,2,15,251,208,250,161,250,146,252,108,253,219,253,143,0,206,16,103,250,3,251,104,1,248,251,189,252,127,254,81,1,87,4,191,250,30,251,124,251,146,3,58,6,22,0,144,3,244,3,216,249,125,250,172,250,127,251,74,3,72,255,240,0,22,5,50,250,118,251,222,4,144,252,194,252,14,0,183,9,71,6,152,250,98,255,196,253,47,252,43,0,226,255,72,255,60,2,199,10,132,252,0,253,246,253,223,254,212,255,95,1,63,2,244,250,222,253,152,14,159,253,230,253,231,255,2,2,156,3,236,6,103,6,121,252,173,253,249,254,84,1,67,2,158,2,111,250,2,3,101,251,104,252,122,251,93,253,240,1,184,4,199,250,216,4,250,251,236,251,48,7,56,1,41,3,140,3,79,250,130,5,40,251,197,251,227,253,56,2,208,10,152,5,31,251,134,252,54,4,254,4,210,253,63,0,61,2,10,3,251,250,140,7,20,252,122,252,173,254,59,0,17,0,147,2,184,250,89,252,147,252,93,13,57,254,160,0,52,3,206,4,210,250,46,252,218,3,234,252,5,6,41,0,30,2,231,2,45,250,118,251,147,250,15,251,96,252,117,255,181,19,211,8,98,251,78,5,71,252,58,5,10,254,122,0,237,2,71,3,252,250,37,17,23,252,211,252,91,254,44,0,87,3,48,4,122,6,143,252,203,252,129,5,213,254,4,0,197,1,188,2,136,251,168,251,206,4,234,252,91,254,226,4,244,255,143,2,9,6,152,252,175,4,136,253,147,254,56,0,159,1,151,2,135,250,91,251,133,250,91,251,135,251,81,253,140,255,96,4,232,6,212,251,0,252,139,253,160,5,88,0,66,2,199,2,141,249,231,249,228,249,106,250,243,251,240,4,235,255,152,7,240,249,200,250,3,251,148,3,100,254,27,0,150,9,125,6,204,7,193,251,57,251,100,252,119,254,137,6,26,3,249,3,174,250,124,255,151,0,25,2,32,252,38,7,9,3,223,3,201,249,181,250,42,250,116,250,102,253,103,9,138,12,44,8,166,251,144,253,193,251,121,252,216,252,74,254,89,7,142,2,140,251,254,0,151,255,212,0,130,1,49,0,0,1,58,1,83,0,98,0,152,251,123,252,190,253,106,1,190,2,179,2,167,4,52,255,177,254,30,255,154,255,212,255,251,255,120,0,57,0,170,251,109,254,117,253,218,252,54,255,55,2,178,2,93,1,116,252,205,251,83,252,207,5,208,1,251,2,14,3,131,1,210,251,34,252,3,253,217,254,133,6,85,1,113,3,232,0,11,252,237,251,211,2,201,254,38,1,134,2,62,2,72,0,89,251,222,253,73,255,237,1,161,0,201,0,209,1,71,255,102,250,168,250,229,251,64,0,129,1,236,2,218,3,28,253,238,253,81,251,206,253,142,0,108,5,207,5,203,2,177,250,105,3,93,251,101,252,57,254,122,7,147,1,248,3,35,251,57,251,144,253,17,254,212,2,140,2,177,1,73,2,37,250,3,251,155,250,132,251,143,6,90,8,227,3,144,5,191,250,217,250,240,250,138,3,28,255,254,5,250,1,0,4,164,249,126,250,114,250,83,251,113,5,234,255,168,10,248,6,35,251,224,251,82,252,2,0,91,255,141,255,72,3,57,2,248,3,89,251,189,251,162,252,55,254,95,0,39,8,5,4,76,250,50,250,77,250,176,251,197,253,157,3,210,4,167,3,224,249,207,255,211,250,25,251,192,255,59,1,70,3,194,3,141,249,230,249,186,249,221,249,228,250,132,254,196,7,69,8,176,252,100,254,37,252,142,254,200,4,208,254,10,0,242,1,13,250,188,250,163,250,65,252,252,252,183,14,109,2,237,6,93,252,140,253,169,0,255,253,61,0,206,254,226,3,220,1,164,251,145,252,149,252,28,254,229,252,190,3,94,255,188,1,126,38,33,254,117,251,133,251,220,250,143,251,33,252,82,252,10,2,227,2,238,251,230,250,240,251,130,255,123,4,198,13,88,7,35,254,29,254,184,254,125,252,39,4,219,4,158,253,47,253,241,253,140,254,171,0,90,0,196,0,215,25,113,251,91,251,201,251,70,252,207,252,191,252,198,8,183,1,14,4,227,251,144,251,86,252,219,252,2,252,239,251,51,253,229,7,85,1,167,3,116,251,50,251,195,253,232,6,103,43,167,251,150,252,137,253,145,254,7,0,203,251,99,252,22,6,174,252,106,252,13,253,0,254,196,1,4,1,144,1,237,252,58,252,78,253,184,253,181,252,222,252,44,8,120,0,103,0,68,2,22,253,0,254,15,255,147,253,211,10,26,254,244,254,2,1,171,0,232,0,15,251,27,251,24,59,157,251,243,251,139,252,171,251,104,253,109,253,16,255,22,6,115,252,120,251,33,251,57,251,249,251,35,252,97,254,176,13,33,6,117,253,39,251,135,251,10,252,214,250,24,252,158,254,59,0,197,2,110,16,156,251,38,252,135,253,48,252,117,252,132,253,141,254,255,0,171,4,108,3,111,255,134,251,6,252,32,252,32,254,6,253,248,26,65,253,81,254,19,4,232,251,130,253,114,255,138,1,172,252,38,253,235,253,151,254,234,0,221,0,210,251,94,252,4,253,138,12,244,252,0,255,241,6,2,1,51,1,126,1,56,251,219,3,30,19,197,13,100,254,210,253,205,252,161,252,196,253,15,254,105,251,83,251,213,29,171,251,20,253,140,255,206,254,27,0,130,1,118,2,202,250,158,250,234,250,48,49,209,250,53,252,89,0,37,253,3,1,201,0,145,251,73,252,183,253,192,255,161,13,205,10,43,0,75,0,241,253,94,255,49,11,192,250,142,250,145,250,49,251,20,253,62,252,27,21,207,2,138,5,44,253,179,251,69,252,25,253,87,252,216,251,185,251,167,253,196,255,155,1,167,251,151,252,165,253,97,11,208,9,173,254,220,255,26,0,217,255,78,0,11,253,26,252,246,253,186,252,131,21,51,252,28,3,24,2,250,0,56,1,173,250,80,252,133,23,198,255,193,20,78,253,219,253,27,254,190,255,123,255,23,251,116,23,230,24,207,5,48,252,37,252,55,252,221,252,253,251,144,253,57,252,208,6,176,13,6,0,109,253,77,253,186,254,127,255,207,255,148,0,248,251,85,253,27,7,12,7,21,254,60,254,217,254,33,0,236,255,42,0,54,251,194,251,232,252,12,25,111,253,234,254,153,255,231,255,174,255,207,0,146,9,250,255,113,9,251,0,146,253,175,253,103,254,63,255,173,254,208,254,162,252,101,253,153,9,12,254,74,254,8,254,128,5,143,0,203,0,9,1,152,251,132,251,231,10,139,254,73,252,81,8,182,252,234,254,81,0,51,1,237,252,202,252,95,10,164,253,236,7,237,252,4,0,79,1,170,0,219,0,137,2,55,254,204,3,161,253,153,254,42,254,18,255,68,0,199,255,107,0,237,8,242,253,22,254,164,253,179,0,215,255,230,0,64,0,20,0,50,0,222,252,144,4,21,255,248,254,196,254,189,5,13,254,108,0,183,0,150,0,212,251,218,252,113,254,220,4,157,254,231,1,199,255,194,1,195,0,248,0,158,251,184,251,255,12,68,252,60,4,26,5,247,0,186,1,169,0,27,1,88,13,159,253,133,252,145,252,171,252,195,253,227,254,109,255,124,1,96,2,247,4,150,252,93,252,40,0,35,252,152,5,189,7,222,255,29,1,190,0,122,252,50,252,21,16,156,252,240,252,184,253,154,254,200,0,5,1,9,2,79,252,43,252,251,252,189,13,63,252,116,9,9,0,62,1,187,0,66,1,18,252,245,252,242,253,156,11,56,253,190,253,192,253,167,0,156,0,14,1,204,1,182,255,19,255,171,3,72,254,253,253,126,0,63,0,82,0,67,0,211,251,176,251,101,252,134,253,66,255,127,4,14,2,104,11,125,0,54,2,136,251,103,16,34,5,54,254,200,253,176,254,253,253,180,254,160,254,113,255,254,252,27,1,254,252,239,252,217,252,164,254,93,0,171,1,181,0,78,1,226,252,194,252,212,254,3,254,233,4,214,253,61,5,6,0,242,0,16,1,250,251,62,0,13,5,84,1,240,2,19,254,250,255,222,255,33,0,85,0,131,252,78,251,244,0,125,255,206,254,166,29,192,252,164,1,80,0,167,1,225,252,154,252,94,252,48,253,128,253,86,9,103,254,79,255,91,0,114,1,160,252,75,252,70,3,194,253,22,255,43,2,46,0,247,255,173,255,146,0,199,252,34,254,104,253,199,255,99,3,216,254,132,254,183,255,70,0,171,0,156,251,26,41,28,255,159,253,66,252,255,251,220,253,128,254,255,254,55,0,38,21,180,1,117,253,20,253,97,253,243,253,231,255,239,254,248,254,57,0,151,251,182,7,111,255,114,6,195,254,254,253,207,254,178,255,102,255,59,0,245,4,240,3,2,254,57,253,234,253,154,254,194,0,117,0,102,0,57,0,187,252,236,4,130,255,18,254,47,0,94,255,156,3,184,255,130,0,97,0,230,2,221,252,57,253,13,253,110,254,68,255,24,0,53,1,187,0,123,1,188,251,230,22,121,253,217,252,53,253,72,253,104,254,227,255,104,0,97,1,226,12,145,8,249,254,252,252,116,252,14,253,63,254,92,255,99,255,212,255,38,252,9,9,172,253,56,0,9,8,34,254,74,0,205,255,51,0,121,0,125,252,1,7,173,253,99,253,25,253,79,253,222,253,71,0,201,0,126,1,219,251,47,13,248,252,148,252,120,253,105,254,212,255,4,1,2,1,137,1,2,45,100,3,92,250,220,249,118,249,47,249,204,248,176,249,69,249,28,250,27,0,191,254,75,253,171,253,138,254,132,254,71,1,209,0,99,2,158,4,220,253,176,0,224,253,27,254,171,254,136,254,129,254,0,4,36,5,252,255,192,0,119,253,45,252,79,252,222,252,73,255,165,14,44,3,96,254,241,253,34,253,35,4,247,253,156,3,50,254,137,253,180,255,182,0,126,0,100,0,115,253,125,253,91,251,16,251,224,250,225,250,68,251,8,252,38,255,223,32,19,252,222,2,23,5,240,254,115,254,247,253,11,255,133,1,242,0,22,255,202,1,112,252,65,251,52,251,248,250,149,251,179,252,108,254,144,3,121,21,157,1,89,12,80,254,108,255,168,6,105,253,28,252,15,252,117,250,95,252,220,255,41,254,128,253,197,253,59,255,195,253,50,254,26,10,77,255,130,254,11,253,129,252,184,251,140,251,64,251,229,251,80,253,212,255,239,12,190,13,38,254,226,9,195,5,92,253,66,253,247,252,132,254,196,254,230,253,44,254,60,253,30,2,43,255,55,253,113,252,30,254,72,253,121,255,2,5,214,7,75,22,220,1,61,253,253,252,118,253,236,252,246,252,171,252,62,252,98,252,10,0,245,255,3,0,1,0,244,255,242,255,21,0,7,0,243,255,246,255,126,250,80,249,99,5,125,22,218,0,48,251,205,253,95,252,84,253,197,252,251,254,16,4,102,255,203,254,157,255,62,0,88,3,199,0,154,253,98,252,142,253,32,6,254,254,118,1,47,4,116,255,6,255,180,254,192,252,62,253,161,252,54,253,19,253,9,12,242,1,73,253,117,254,168,253,233,254,76,2,245,0,50,12,183,254,91,253,250,254,67,0,19,0,238,253,142,252,162,252,247,251,96,255,6,6,124,7,96,254,168,253,215,253,37,255,126,255,15,254,69,253,183,6,160,0,221,12,44,255,101,252,235,251,7,253,42,251,242,251,7,6,226,2,220,253,227,253,109,254,231,254,141,255,161,255,199,254,237,255,220,254,112,4,8,14,184,2,114,253,168,252,42,253,75,253,223,251,13,251,46,253,131,254,85,253,84,5,226,255,77,2,198,1,6,1,199,255,6,252,200,254,78,3,117,255,181,253,129,255,178,9,78,255,23,255,47,252,228,252,250,255,250,0,220,0,41,6,117,4,5,255,119,253,215,252,229,251,151,252,6,253,34,252,14,252,134,252,127,252,129,253,97,253,172,7,20,3,6,9,113,23,20,0,16,252,121,251,72,251,72,251,218,250,53,251,195,252,144,6,1,252,26,252,56,251,79,252,255,252,215,255,241,7,196,0,149,3,79,6,234,7,114,253,10,252,106,252,18,253,93,253,185,252,5,6,26,1,174,1,221,251,60,253,5,254,246,253,87,255,182,1,196,0,67,3,10,3,129,3,164,1,14,2,215,4,198,0,32,253,71,252,189,252,27,255,164,254,214,2,1,253,31,5,248,0,159,254,218,253,249,3,6,255,36,253,0,1,81,255,130,253,251,2,7,253,67,252,214,253,27,2,252,0,43,1,175,1,101,2,46,17,134,254,2,252,4,252,34,252,11,253,147,253,173,255,222,255,122,0,36,254,77,0,225,252,140,255,194,17,237,252,33,253,50,254,149,252,117,252,163,250,182,250,181,250,60,251,0,252,168,255,18,5,28,11,172,3,111,4,213,8,94,8,181,0,33,253,100,252,83,252,225,252,53,253,106,253,86,0,49,253,247,253,115,0,192,253,69,253,28,4,15,5,199,255,42,0,230,0,60,11,245,1,218,254,98,255,104,0,99,255,253,253,106,253,37,252,211,251,65,253,39,252,219,251,78,252,146,252,245,254,141,1,132,0,22,2,58,14,18,5,208,253,67,253,242,253,218,254,197,0,54,1,75,0,253,255,11,1,170,254,10,8,184,254,85,254,59,253,80,253,14,0,213,255,237,0,250,1,6,11,175,254,124,252,206,252,130,253,64,255,115,3,242,255,241,254,209,253,6,11,91,255,36,252,91,252,107,252,165,253,185,253,115,254,211,1,68,4,236,251,33,254,174,9,126,254,233,253,3,255,63,0,207,255,79,0,27,0,74,255,156,255,106,1,140,253,107,253,61,253,21,6,136,0,79,1,89,0,59,255,65,22,220,0,39,254,40,254,227,251,1,252,193,251,77,251,12,253,135,254,107,252,99,252,200,253,19,255,142,5,197,0,158,255,102,2,99,3,193,252,195,252,55,252,48,253,158,1,56,4,171,6,60,3,135,255,11,253,236,251,223,254,48,3,28,1,41,3,172,255,234,255,216,253,247,255,193,0,153,254,66,0,186,253,94,253,200,7,225,255,58,0,171,1,253,253,213,254,164,3,160,253,177,251,212,251,8,252,254,252,200,0,7,4,88,4,2,4,170,253,206,252,133,252,133,253,196,252,158,252,118,253,187,18,105,254,215,0,171,252,117,1,72,253,159,0,227,3,209,1,3,254,109,0,60,0,10,0,7,33,198,0,25,252,149,251,169,251,85,251,34,251,88,251,99,251,90,252,147,254,4,253,79,253,179,253,34,253,175,9,64,252,255,4,104,0,47,255,12,252,200,252,221,251,103,252,212,252,52,255,199,0,89,2,64,12,125,2,205,11,11,15,22,254,238,255,94,252,199,251,147,251,98,251,12,251,44,252,160,252,79,252,234,254,193,3,254,253,133,255,50,2,106,3,126,255,80,1,242,12,181,254,168,251,118,251,53,251,50,251,108,251,36,252,193,254,254,13,122,3,50,0,87,253,236,252,118,252,148,252,195,252,197,252,215,255,88,13,28,253,111,252,131,252,148,1,11,8,117,253,38,254,46,1,4,2,66,2,175,10,56,251,82,251,207,251,165,251,226,251,55,253,157,6,174,251,21,251,210,2,24,251,57,251,150,6,53,6,211,7,118,252,225,9,93,8,116,254,174,254,220,255,52,0,220,1,63,1,92,254,49,2,20,254,242,253,153,254,35,255,2,255,16,253,144,251,78,253,128,252,211,16,149,254,214,255,83,5,51,253,244,251,150,252,11,9,72,252,152,252,6,1,138,5,225,2,94,5,6,254,42,254,237,254,130,255,242,0,172,1,90,253,87,253,187,253,248,3,215,253,3,254,27,254,104,254,123,37,9,252,112,251,92,252,212,252,78,253,89,255,241,2,89,252,73,254,57,8,242,253,58,253,198,253,9,0,36,2,18,2,228,250,220,251,161,254,50,252,242,251,93,0,203,21,31,253,254,250,106,5,252,250,37,251,175,251,22,3,121,8,67,253,108,253,213,253,37,5,245,10,24,3,161,8,22,254,10,253,18,251,197,251,207,251,162,3,214,252,86,255,22,9,67,251,250,250,107,13,145,251,229,251,220,0,224,11,207,7,91,252,105,253,54,253,169,252,140,254,169,253,75,254,117,1,241,22,37,252,199,251,21,252,21,253,241,254,70,2,45,4,107,252,14,253,44,22,203,253,152,253,116,254,177,0,140,3,34,12,179,5,90,253,225,253,172,254,47,0,80,1,237,1,220,251,147,5,208,253,5,253,58,253,107,253,193,0,83,2,28,252,184,9,180,253,16,253,26,5,114,0,36,1,177,2,78,251,30,9,107,251,113,251,13,253,97,1,175,6,36,6,92,252,17,253,51,8,233,7,95,254,62,0,202,1,99,2,43,252,35,17,129,253,208,253,248,253,104,255,6,1,236,2,196,252,206,252,86,253,130,20,128,253,242,254,129,1,25,4,208,251,250,252,78,7,100,253,234,5,98,255,27,1,25,3,193,251,130,251,125,252,149,252,68,255,72,255,0,26,7,9,118,252,118,6,66,254,141,6,114,253,155,255,108,1,209,2,8,251,248,30,212,252,192,253,60,253,165,254,141,1,104,4,246,14,246,251,225,251,196,8,9,253,62,253,79,0,125,3,102,252,213,251,180,10,156,252,166,252,105,4,34,0,72,4,151,9,74,253,178,7,118,253,94,253,125,255,114,1,185,2,211,251,143,251,76,252,235,251,193,251,60,252,111,1,67,4,0,16,64,252,103,252,154,252,117,5,1,254,66,255,33,2,111,253,86,251,232,253,73,252,186,251,117,0,48,253,228,9,182,251,133,251,103,251,228,6,11,253,135,255,68,9,218,7,78,14,72,252,29,252,130,252,143,253,208,1,219,2,95,3,161,253,7,254,145,1,89,254,228,253,96,8,243,2,82,254,37,250,38,251,78,251,90,251,142,253,225,4,60,13,75,9,41,252,190,251,117,252,3,252,12,252,154,252,163,10,53,6,111,252,76,1,154,255,99,0,226,0,6,0,176,0,98,1,156,0,220,255,195,252,250,252,83,253,241,255,242,1,247,1,238,7,103,254,169,253,196,253,171,254,254,255,111,0,46,1,20,3,22,252,46,252,95,252,23,252,138,252,66,2,227,3,213,4,21,253,72,253,115,253,119,4,62,0,250,1,59,2,226,3,31,252,122,252,153,252,106,253,247,5,114,1,211,3,212,3,46,254,28,254,19,3,251,254,61,0,250,0,121,1,144,255,92,253,233,253,168,254,18,1,107,1,185,0,78,1,208,255,136,251,185,251,13,252,216,253,189,1,75,5,183,4,172,251,152,251,195,251,198,252,173,255,209,7,241,4,149,5,0,252,175,4,97,253,67,253,68,254,168,4,187,0,161,2,241,251,224,251,71,252,36,253,103,1,202,2,19,3,167,3,93,251,147,251,168,251,53,252,110,8,184,6,33,3,224,7,224,251,212,251,135,252,16,7,247,1,124,3,102,1,17,4,100,251,96,251,212,251,236,252,143,5,195,253,93,8,157,7,238,251,100,252,175,252,0,2,139,253,240,254,11,3,47,3,147,7,211,251,188,251,253,251,254,252,48,0,18,6,5,5,171,251,132,251,123,251,247,251,90,252,11,3,78,5,24,6,227,251,222,0,185,251,23,252,87,253,230,255,88,4,11,4,112,251,251,250,111,251,100,251,195,251,183,251,33,5,40,12,96,252,113,253,213,252,150,253,19,6,32,254,71,0,211,1,60,251,157,251,16,252,191,253,179,252,14,15,235,1,86,7,229,251,7,253,105,2,118,253,59,254,51,0,16,3,245,2,31,252,141,252,119,252,60,253,155,252,201,3,192,255,143,2,52,1,236,253,213,252,50,252,127,253,81,254,81,13,2,1,55,2,129,2,35,5,45,253,30,253,10,254,142,0,166,2,189,255,86,255,73,0,191,255,157,10,220,252,66,252,146,252,236,253,206,253,238,0,241,1,36,2,206,2,156,252,99,253,92,252,20,252,250,253,10,254,226,254,149,1,171,11,140,5,174,0,245,252,20,253,193,253,103,255,216,255,84,1,157,1,19,1,131,1,197,3,82,0,218,253,24,253,176,253,177,253,164,253,93,255,172,1,75,3,0,251,220,6,144,254,9,3,227,255,59,254,195,255,43,0,50,0,137,0,182,3,27,255,224,5,21,254,159,254,89,255,227,254,98,255,162,255,71,255,105,250,47,1,161,2,10,253,158,253,204,254,223,4,92,1,95,0,31,0,95,6,171,7,144,253,254,252,46,254,106,255,134,255,133,255,34,0,115,255,141,252,138,254,76,252,139,253,92,13,252,252,120,254,225,255,91,2,134,2,8,253,153,252,88,252,76,252,41,253,235,13,136,254,90,3,187,2,49,2,166,250,62,9,249,252,39,251,175,251,9,255,177,0,176,1,158,1,123,1,176,250,223,251,79,252,176,252,200,253,245,252,136,253,184,254,217,254,169,1,163,254,118,2,237,254,241,253,182,1,47,0,62,255,160,255,17,255,223,253,155,250,79,253,108,6,141,4,75,254,103,255,63,255,51,1,183,0,66,0,201,250,30,10,121,8,65,254,77,254,195,254,174,255,204,0,45,0,111,255,212,250,51,255,179,15,51,252,190,253,28,0,175,0,250,1,235,0,158,255,116,252,218,254,163,5,174,252,212,253,171,6,235,254,58,0,241,0,68,255,171,252,196,253,191,253,234,4,239,3,66,255,1,0,253,255,103,0,207,255,9,21,137,0,61,253,190,252,2,254,251,253,120,254,122,254,25,255,237,254,31,251,109,20,212,252,131,252,159,254,105,253,227,255,187,0,45,0,10,0,148,250,109,251,229,251,156,1,133,254,101,254,240,0,62,2,120,2,28,1,186,252,112,252,100,252,246,11,73,253,103,254,32,255,166,1,37,1,11,1,100,250,43,251,233,250,231,250,110,252,13,255,53,3,71,3,19,4,4,5,102,251,16,254,58,6,32,253,216,6,167,253,116,254,74,1,231,0,48,0,27,251,40,3,128,252,57,252,115,253,172,255,4,0,186,1,107,1,77,2,19,252,96,253,81,253,163,255,238,254,96,5,24,255,204,255,143,1,255,0,195,251,66,251,192,251,20,253,12,4,158,1,220,0,253,1,180,1,243,1,120,253,3,253,93,252,41,252,10,253,225,253,133,254,141,255,12,3,255,12,194,251,131,252,251,252,143,252,85,253,245,255,190,254,90,13,227,2,193,3,173,250,95,252,131,3,19,252,232,252,174,254,71,255,190,2,115,2,126,2,155,251,151,250,97,250,149,250,160,251,87,253,121,255,104,2,14,12,233,9,96,250,71,251,253,251,71,251,142,253,173,0,150,2,131,3,93,3,132,8,131,1,8,4,168,3,140,0,159,254,210,254,222,254,182,254,217,253,5,252,227,13,188,255,71,254,229,253,12,254,229,255,89,254,6,254,246,253,97,254,43,9,98,7,200,254,26,253,89,253,89,253,115,253,159,253,79,254,40,254,149,10,13,253,127,251,214,251,252,251,162,252,198,252,197,254,78,0,163,6,149,254,83,254,78,253,66,255,154,254,101,253,117,7,39,0,255,255,138,0,200,249,233,249,179,250,238,249,18,253,45,3,140,6,1,6,209,3,243,254,128,32,166,253,140,251,127,251,144,251,106,251,20,252,189,251,148,250,93,251,5,254,31,12,56,255,103,253,178,253,131,254,147,254,216,255,217,254,177,253,61,252,15,1,183,8,221,253,191,255,242,254,192,255,243,0,73,255,220,253,228,252,235,254,249,255,88,255,39,6,151,254,35,0,237,255,192,0,102,255,128,254,144,0,86,254,240,253,170,253,246,252,215,254,55,7,52,2,218,0,96,3,114,253,27,254,77,254,45,0,197,2,118,2,245,255,77,253,145,255,249,252,156,254,246,253,199,8,177,255,79,254,148,253,82,2,79,0,60,0,196,252,37,254,0,3,177,255,113,253,38,2,55,255,77,0,90,3,245,255,221,252,149,4,3,4,53,252,112,253,120,253,216,255,17,0,208,2,176,0,225,251,88,252,254,254,38,2,62,4,41,4,0,0,39,254,148,254,30,0,53,0,250,255,202,255,232,255,21,0,175,255,168,255,211,255,242,255,81,0,162,2,91,251,231,251,178,252,23,254,232,255,209,255,165,0,146,2,117,7,15,255,122,254,125,254,58,254,193,254,219,253,205,254,144,255,10,3,206,5,198,254,34,0,163,255,225,252,230,253,171,8,67,254,39,0,218,255,254,254,85,254,81,252,8,253,166,253,193,253,62,254,120,1,156,2,111,3,191,4,64,251,240,252,122,253,221,254,19,1,251,3,179,255,124,0,0,1,142,4,102,254,31,252,135,251,162,251,84,252,199,252,208,253,125,255,238,3,14,19,135,250,250,250,220,250,142,250,177,0,105,252,162,0,244,8,0,7,218,4,6,253,169,3,88,255,124,252,195,252,203,0,201,4,114,2,134,255,253,253,224,3,58,255,242,252,231,255,74,0,251,3,162,253,148,254,162,254,251,255,195,1,68,1,9,1,137,251,204,252,126,1,150,254,85,0,227,252,181,2,58,6,177,254,27,255,116,254,45,255,156,254,159,255,141,255,92,0,49,0,36,254,156,251,196,251,174,253,28,255,216,2,16,0,77,2,189,4,73,3,195,252,82,7,117,252,24,252,131,5,147,253,61,253,100,1,181,1,37,0,199,250,158,251,233,249,84,250,183,250,51,252,18,15,121,4,201,4,55,8,161,253,75,255,45,2,83,254,15,0,16,254,68,254,245,253,182,248,146,251,10,251,213,11,170,251,226,252,200,252,109,253,44,0,102,2,35,4,149,4,202,2,92,252,185,251,219,251,103,252,246,251,151,252,7,0,152,252,148,2,201,250,40,250,169,249,131,250,210,251,88,253,175,3,134,0,66,255,21,11,246,251,35,255,175,254,228,253,197,253,83,255,101,254,10,9,145,255,202,3,60,251,244,251,184,251,109,255,63,4,92,2,145,254,83,0,205,1,167,2,203,250,194,0,244,250,141,251,183,251,198,253,4,254,147,255,54,0,194,3,32,10,168,251,80,252,132,253,247,253,12,0,230,0,186,1,50,2,112,2,173,251,90,251,18,6,43,252,227,5,11,252,118,254,83,2,55,3,70,4,83,250,238,250,242,0,95,251,82,253,227,253,90,3,75,1,183,2,173,4,21,251,200,3,100,251,26,251,16,253,193,5,222,0,86,1,205,3,5,4,161,249,36,250,173,249,19,250,237,250,147,6,155,8,139,4,201,4,217,5,91,251,87,252,93,252,121,12,47,252,60,253,250,254,37,2,149,3,185,5,192,2,203,253,60,253,78,3,126,255,190,254,255,254,221,0,111,1,53,1,120,250,157,251,213,250,20,251,107,254,231,12,46,255,17,3,239,3,80,6,237,251,51,253,44,0,56,3,163,1,20,254,189,253,164,253,241,255,164,2,213,251,201,251,57,15,69,251,38,254,4,252,179,253,114,0,81,2,224,5,55,250,31,251,244,251,12,252,49,253,78,3,67,255,215,254,225,255,185,4,31,249,226,249,87,250,147,249,72,250,142,5,24,0,105,8,97,5,156,7,56,250,140,2,95,252,97,254,79,253,126,254,92,6,233,1,231,1,244,2,112,250,219,252,217,4,228,0,71,253,196,254,167,1,148,2,45,2,75,2,224,4,247,252,64,4,176,252,14,254,113,254,196,255,169,0,241,1,177,2,47,22,246,252,171,251,162,251,129,252,238,251,8,254,134,1,134,6,213,1,209,3,95,252,107,251,222,251,25,252,72,253,120,7,52,0,17,5,57,4,67,250,37,251,225,251,129,1,239,253,142,3,79,0,252,1,201,4,241,2,144,2,229,250,41,251,66,250,170,251,25,251,150,254,47,9,121,3,151,6,226,249,205,250,126,250,151,250,11,3,13,254,39,255,168,3,16,8,213,5,37,250,191,250,118,251,22,3,165,251,95,253,35,8,242,3,76,2,241,4,97,250,112,251,242,250,240,2,115,250,46,251,87,255,239,253,70,6,83,8,236,249,94,250,92,250,231,1,20,251,141,251,104,1,224,9,202,7,150,6,244,249,63,250,205,253,155,251,199,3,210,5,223,5,231,1,223,3,0,4,106,250,129,251,65,251,39,253,22,253,6,253,40,254,10,3,121,3,6,3,207,250,151,251,103,5,50,251,45,253,198,5,123,1,161,0,242,4,214,4,69,250,181,252,3,251,213,250,53,253,58,0,74,255,20,20,250,2,187,6,251,250,110,4,105,251,223,251,14,5,252,255,95,254,45,2,171,3,158,4,39,0,53,2,215,252,65,253,241,252,141,252,144,255,156,1,32,4,179,2,239,254,202,250,126,252,191,250,211,251,33,251,151,255,126,2,155,26,133,4,214,3,168,252,219,252,187,251,243,4,21,253,118,253,55,1,25,1,52,4,91,5,78,6,133,252,138,252,116,254,10,255,191,255,77,0,216,1,93,2,81,252,178,0,3,254,112,0,114,255,0,2,190,255,109,0,144,0,76,0,118,11,77,251,108,250,11,250,11,251,174,249,151,251,72,255,31,255,85,12,7,255,4,251,225,251,73,254,95,255,244,254,28,1,102,2,10,3,158,2,37,251,146,6,151,3,44,254,33,254,171,254,31,0,212,1,69,1,94,2,199,251,45,253,83,0,113,254,237,254,110,253,240,0,149,0,186,10,167,2,219,249,249,250,18,254,7,3,207,3,17,253,209,255,222,6,140,2,131,4,71,250,207,251,193,251,254,251,33,1,84,1,192,1,68,5,95,1,170,2,17,8,97,251,223,250,230,249,46,254,246,249,203,251,35,254,196,11,208,9,232,249,4,250,95,250,51,251,93,3,91,254,235,5,147,8,139,4,138,5,12,251,177,251,220,252,186,251,182,12,57,253,210,253,201,2,134,5,148,6,30,2,243,252,197,252,210,252,11,255,105,4,96,255,210,0,130,1,106,2,159,249,232,1,208,249,221,249,187,250,106,253,199,2,236,5,125,6,137,6,26,250,6,250,245,3,108,251,169,1,121,250,168,252,147,11,210,8,127,7,24,253,72,251,161,252,134,253,39,253,212,251,167,252,223,254,189,2,47,26,34,250,183,250,5,250,164,250,148,250,213,251,112,5,100,0,10,10,167,6,241,249,36,250,205,249,99,249,39,249,105,250,232,251,138,4,28,5,1,12,26,252,217,249,251,253,190,250,243,250,43,250,161,250,171,251,221,252,156,11,90,250,220,250,166,251,131,250,40,251,223,251,171,251,179,253,63,10,90,6,237,249,254,251,190,250,69,250,122,252,11,5,176,0,118,2,197,16,157,7,47,251,174,250,94,252,105,251,162,251,161,250,108,251,57,252,32,19,99,16,48,249,230,249,251,248,233,248,215,249,86,251,115,1,254,12,111,12,255,11,111,250,19,249,230,249,178,250,221,253,10,255,24,0,242,253,34,250,192,114,164,252,154,253,167,252,229,252,25,3,152,253,155,6,131,255,156,0,47,2,149,249,74,250,13,250,123,250,29,251,176,253,246,3,96,7,243,0,17,4,236,4,109,250,136,250,28,252,66,252,85,251,117,24,31,0,199,3,240,2,192,14,49,252,184,252,61,253,72,253,213,253,45,0,135,4,4,0,102,1,110,18,65,250,72,250,245,250,172,250,90,252,146,252,78,20,239,254,19,6,98,250,63,249,213,249,66,250,228,248,100,250,25,251,137,253,191,16,185,15,209,4,84,253,20,253,26,253,221,253,27,255,65,1,126,0,26,3,158,2,33,26,239,251,120,251,163,252,22,252,48,252,147,0,100,253,9,2,172,3,94,251,49,8,198,253,223,6,5,255,70,254,164,255,46,0,99,0,12,0,200,250,219,251,75,17,79,252,163,252,52,254,206,254,238,1,225,1,24,2,179,251,175,251,135,10,60,1,223,252,97,255,18,4,191,253,178,255,84,1,43,9,168,5,135,0,131,254,80,253,19,254,2,255,22,255,182,255,176,255,233,251,34,251,39,253,39,252,23,21,6,252,131,2,54,3,121,3,176,1,184,254,150,250,116,250,66,253,86,250,15,27,173,251,209,1,89,6,92,4,22,251,31,11,131,252,129,252,247,253,249,254,112,0,157,0,44,2,244,1,182,0,116,253,30,255,2,1,130,253,202,253,93,254,99,253,32,255,35,255,83,251,29,255,186,253,92,0,122,7,72,255,245,255,238,255,14,1,166,0,242,250,194,255,0,6,166,9,99,254,149,253,113,254,24,0,106,0,54,0,57,251,112,10,96,9,202,255,191,253,76,253,211,254,253,255,206,0,89,0,112,250,45,250,233,32,208,251,14,255,92,254,62,255,255,255,233,1,75,1,86,252,217,250,189,9,181,250,39,2,249,8,197,0,247,255,205,2,178,1,43,251,251,252,3,252,105,15,202,253,116,0,246,0,150,0,254,1,114,1,28,46,55,254,18,252,49,251,105,251,194,251,59,251,77,2,89,253,11,253,97,251,102,25,184,253,58,254,139,253,198,253,99,254,160,254,233,254,224,255,44,251,78,252,8,253,255,5,159,252,56,253,32,255,87,1,135,2,101,2,188,250,86,252,63,252,81,32,150,251,177,253,31,255,210,0,164,1,140,0,33,251,114,251,58,252,38,252,160,251,117,252,75,255,214,1,96,7,137,4,204,251,238,250,151,13,129,251,106,9,116,254,1,0,212,255,101,1,82,2,128,252,233,2,223,255,90,254,180,254,253,254,0,0,48,0,143,0,190,0,15,252,187,252,148,252,141,254,142,254,240,5,106,255,251,0,240,0,192,1,0,252,16,252,200,253,62,254,157,253,232,253,227,6,222,255,99,1,198,1,255,252,169,253,129,253,31,253,112,252,43,253,8,254,26,255,20,2,222,12,203,251,223,254,149,252,226,253,194,253,164,253,173,254,207,9,223,1,230,2,62,251,78,252,41,5,246,253,224,253,74,252,3,253,120,2,127,2,241,1,84,252,83,251,90,251,80,251,88,251,64,252,50,253,98,2,228,12,181,12,21,250,103,249,250,248,250,248,255,248,28,249,176,249,33,0,73,9,98,30,100,253,209,6,221,5,17,3,176,254,201,252,60,253,66,254,57,254,212,252,158,34,159,0,139,251,19,251,213,250,237,250,19,251,53,251,66,251,190,251,0,14,44,8,176,2,237,253,176,252,24,252,233,251,88,251,176,251,137,252,43,20,165,254,151,251,251,250,200,250,245,250,31,251,171,251,14,254,207,9,157,253,65,253,252,253,16,255,188,255,143,1,34,6,252,0,251,255,43,0,117,251,112,251,16,252,103,252,29,252,199,253,157,3,231,5,233,3,231,7,126,50,135,0,194,249,14,249,201,248,198,248,212,248,58,249,97,249,102,249,109,2,39,18,76,2,16,253,51,252,28,252,71,252,199,251,220,251,96,253,156,252,3,1,76,19,139,255,50,253,117,252,196,252,248,252,162,253,43,252,22,252,242,253,127,254,15,2,221,5,17,255,38,0,25,0,112,0,179,255,98,4,6,255,160,254,167,251,179,251,82,252,87,253,36,20,224,252,132,253,182,22,96,255,247,252,199,252,180,252,21,253,71,253,123,253,100,253,20,254,88,252,235,1,232,254,13,10,243,254,32,253,137,254,247,254,158,255,13,255,104,252,20,255,190,1,71,4,102,253,168,253,10,255,15,3,26,1,0,0,216,251,140,255,223,8,138,255,30,254,16,255,69,255,241,254,36,0,91,0,73,253,2,255,129,254,76,252,233,2,162,10,127,255,225,252,238,0,133,254,56,11,252,253,156,252,145,253,217,253,237,254,22,0,123,1,71,255,26,255,244,5,96,253,218,251,116,251,103,251,143,251,222,251,234,252,6,0,64,19,217,253,123,254,52,254,118,254,94,253,182,253,185,254,78,255,103,2,52,11,69,250,77,251,220,250,160,251,28,252,235,2,37,255,231,7,83,7,254,0,153,252,32,252,218,251,170,251,131,251,32,252,20,254,40,0,16,2,254,20,83,0,209,253,162,252,8,253,227,253,28,0,207,0,117,2,246,1,236,4,39,254,170,251,200,250,146,250,124,250,157,250,207,250,199,251,18,255,116,38,204,250,230,250,5,251,143,252,13,251,31,251,19,255,66,11,207,13,72,2,243,255,52,0,206,255,252,255,7,0,5,0,20,0,201,255,5,0,45,0,51,6,94,1,191,0,105,2,153,0,20,255,176,254,119,253,226,252,217,251,171,5,195,2,253,0,35,253,101,252,165,252,147,253,30,253,213,253,87,6,191,6,101,254,44,253,252,252,22,253,93,253,80,253,47,255,147,3,110,2,242,251,38,254,169,254,165,255,83,255,152,255,255,0,96,0,11,6,5,3,143,253,224,8,166,255,3,254,241,253,9,255,109,255,22,255,211,255,166,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,255,226,252,252,252,235,0,3,2,75,255,136,255,3,254,120,254,121,251,180,252,239,251,143,252,87,251,79,4,200,251,214,0,79,6,27,7,230,5,110,252,90,251,239,254,181,251,246,253,28,252,50,255,106,15,228,3,142,6,60,251,79,251,34,11,2,252,77,4,210,252,68,255,111,3,13,6,255,4,151,251,136,7,14,6,38,0,156,254,194,253,99,255,30,1,225,1,219,1,201,251,104,251,163,252,220,253,111,253,131,254,26,2,180,3,186,252,11,3,131,251,62,252,252,6,245,252,26,253,201,254,205,0,43,1,216,1,203,2,190,2,181,252,93,252,234,252,144,253,180,254,68,1,10,3,17,3,158,2,143,251,75,251,153,255,98,251,209,251,74,252,101,0,15,2,60,6,236,3,170,2,204,253,227,251,180,252,96,251,196,6,162,252,202,7,36,252,107,4,211,251,4,251,227,251,14,25,21,251,70,255,94,252,118,0,119,1,68,4,71,24,124,252,104,252,89,252,43,252,54,252,2,253,122,252,178,254,93,6,186,251,138,251,125,251,245,252,188,251,243,3,22,254,39,4,33,6,60,5,194,8,223,250,139,23,217,250,199,250,235,252,240,250,55,254,51,3,228,8,209,251,215,251,53,253,34,3,28,252,141,1,92,9,229,255,201,4,167,3,120,5,162,252,222,252,54,7,255,253,7,255,64,253,3,2,104,3,150,2,139,251,244,22,77,253,108,254,165,253,108,255,199,255,187,0,137,2,20,3,164,251,109,252,217,253,3,15,31,253,123,255,242,1,155,0,227,0,206,2,6,7,117,5,156,252,52,253,182,253,188,253,185,255,189,255,55,1,24,2,161,9,244,253,45,7,25,255,46,255,7,1,231,0,246,255,92,255,188,254,73,252,150,251,86,20,243,253,165,253,111,254,223,0,182,1,243,3,53,4,42,253,178,251,11,252,126,254,238,252,185,16,183,254,6,1,38,2,12,5,139,253,81,252,48,252,5,3,157,252,140,3,88,253,102,255,106,1,32,4,229,251,65,253,203,250,112,250,254,251,231,252,165,252,142,252,108,255,230,38,87,251,124,251,203,251,217,4,11,252,42,253,117,255,39,2,126,4,251,3,35,253,27,252,117,253,143,253,202,255,210,2,73,0,242,255,105,1,179,1,173,15,20,251,85,251,172,5,175,251,249,4,98,253,10,6,14,4,144,6,212,252,220,251,171,252,222,251,46,8,223,252,55,254,192,254,171,2,192,3,5,252,122,251,162,251,246,251,151,253,148,1,96,5,79,3,246,3,183,3,244,255,20,252,59,251,149,251,137,2,228,251,186,1,89,255,165,252,28,15,64,251,238,250,225,250,50,11,226,250,129,253,201,251,40,6,224,6,45,7,118,0,200,251,162,252,179,252,215,251,211,251,151,8,2,253,239,1,29,5,28,252,240,251,27,253,77,5,190,6,126,1,8,1,92,0,147,2,153,2,243,252,180,250,7,8,82,251,15,0,95,8,119,2,57,2,150,3,96,4,76,252,27,251,46,251,138,9,218,251,158,8,48,0,148,2,30,7,200,5,129,253,115,2,80,254,35,254,77,3,216,0,228,0,152,0,157,0,39,1,140,9,116,252,47,254,0,253,109,0,251,0,72,0,197,255,169,0,149,1,43,17,187,252,93,252,185,252,41,255,204,253,143,2,103,1,247,1,40,1,186,13,198,251,95,251,197,252,63,11,56,251,213,252,54,252,36,3,143,3,212,11,252,250,80,253,54,251,29,251,217,253,33,251,237,254,113,13,18,9,138,253,67,251,148,255,89,251,105,4,170,252,32,11,73,6,24,4,255,5,224,10,35,251,4,3,50,251,238,250,82,253,243,250,129,253,22,1,151,9,247,38,203,251,47,251,225,251,117,255,171,252,208,255,24,0,48,253,21,2,89,251,249,10,9,252,125,252,228,255,3,253,109,255,146,0,80,2,46,3,205,48,6,251,208,251,239,250,109,3,212,251,101,251,248,251,255,3,102,251,184,252,162,3,108,253,192,4,146,254,106,254,159,255,77,0,179,0,84,1,51,252,31,252,232,8,239,6,137,253,239,255,70,255,251,1,203,1,133,2,47,8,5,252,213,251,75,252,167,252,78,251,120,252,208,255,132,4,249,4,50,251,35,251,77,251,244,251,130,251,69,252,169,4,151,7,157,5,49,5,150,253,225,251,38,253,10,252,89,19,155,251,65,4,61,4,23,4,21,4,45,3,244,251,246,4,53,253,84,253,160,255,125,255,33,1,14,3,116,2,45,252,36,4,49,252,60,252,213,252,242,255,223,0,166,1,51,2,184,2,123,252,135,253,240,1,120,255,22,0,173,255,204,255,8,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1465848);
/* memory initializer */ allocate([24,0,147,0,66,254,83,251,22,251,81,253,41,251,229,252,214,251,84,251,147,0,93,10,49,251,5,251,40,251,239,251,20,251,121,251,169,7,222,255,121,11,80,8,218,250,181,250,210,250,236,250,191,250,210,250,154,252,214,254,222,7,50,15,91,252,10,252,165,252,206,251,6,254,117,251,70,252,205,252,184,1,220,2,186,253,12,251,74,251,243,251,199,251,25,251,130,251,189,252,56,9,189,5,48,251,152,250,148,250,30,2,177,250,162,253,201,250,60,7,94,8,138,14,62,251,215,250,12,251,73,251,77,251,220,250,70,252,72,253,122,18,104,11,55,251,230,250,149,251,7,251,4,251,42,251,240,251,31,8,92,10,139,7,113,251,234,250,147,2,236,253,118,253,208,253,252,251,186,0,200,4,251,10,128,252,63,254,25,252,201,252,175,255,148,252,246,1,219,254,168,2,221,2,188,252,169,251,148,251,159,252,139,251,86,252,44,252,7,5,69,2,158,5,185,250,51,251,106,251,1,253,123,5,182,0,20,2,189,1,159,1,98,2,185,251,253,252,138,251,149,12,221,252,88,253,210,254,62,1,185,1,182,1,92,251,121,4,16,6,240,253,119,3,221,253,83,254,124,0,99,0,128,0,0,253,25,4,206,253,97,4,175,253,160,255,151,255,105,0,251,0,154,0,148,6,62,6,133,253,83,253,79,255,45,255,244,254,234,0,138,255,207,255,49,253,151,252,188,251,39,252,90,253,106,254,22,255,151,1,141,2,123,12,223,3,184,253,150,252,242,255,85,253,148,11,255,252,62,254,31,1,94,1,85,3,221,252,194,253,225,6,102,254,196,255,26,255,178,255,235,255,19,0,9,251,83,17,95,253,234,252,110,0,13,255,175,255,147,0,191,0,145,0,195,21,157,253,134,253,69,253,61,255,231,254,7,255,210,254,240,254,189,255,131,252,112,253,23,253,71,253,218,253,129,253,103,254,13,12,127,1,30,3,201,254,172,254,204,253,237,252,44,14,180,254,2,254,37,255,209,1,95,1,21,253,196,251,52,252,41,253,108,254,138,253,80,255,181,1,24,13,210,3,138,252,17,253,1,253,188,253,75,253,82,252,221,252,98,255,220,255,253,255,58,252,94,253,3,12,98,252,84,255,247,255,216,255,111,0,169,0,212,0,181,0,213,252,53,253,38,252,247,253,82,253,75,15,18,0,198,255,243,1,210,0,93,251,121,252,109,252,246,253,14,4,221,1,20,3,34,1,156,1,14,252,233,252,68,253,58,253,34,0,238,6,0,255,96,0,131,0,241,0,29,251,38,8,251,255,3,253,66,254,141,0,93,0,160,0,88,0,129,0,127,251,147,4,88,251,207,251,121,254,69,255,206,0,160,1,188,1,136,2,195,2,226,253,8,254,18,253,145,253,120,253,8,3,180,2,165,0,74,1,88,4,81,251,148,252,84,254,181,3,65,0,250,0,104,0,108,0,173,0,99,8,119,252,178,252,228,253,136,254,125,255,143,255,124,0,58,1,229,1,229,4,253,253,155,5,241,253,21,0,156,255,144,254,172,255,137,255,112,255,161,250,91,251,91,251,25,252,45,253,66,255,28,3,127,2,187,2,48,3,92,251,105,252,171,2,74,3,177,0,194,255,231,255,71,0,15,0,16,0,157,0,80,0,181,254,169,254,12,0,193,0,123,255,162,255,162,255,192,255,230,250,19,2,107,252,114,255,250,4,102,0,241,255,184,0,159,0,148,0,213,255,177,251,187,253,93,254,191,1,124,255,52,255,187,0,119,2,205,1,234,250,118,251,97,252,128,3,203,0,164,0,201,255,31,1,32,2,229,1,22,251,233,252,165,2,79,252,12,255,155,255,167,1,106,1,42,1,133,1,199,252,128,253,122,253,18,1,183,255,238,254,193,5,243,255,132,0,169,0,1,253,101,251,92,251,211,251,78,253,84,255,19,3,109,5,87,6,76,3,87,255,130,252,105,252,51,0,15,0,170,1,186,254,43,6,182,0,77,0,202,0,95,254,155,254,239,255,106,8,179,255,161,253,179,253,137,254,251,254,136,254,175,0,195,252,223,252,189,253,222,254,12,255,21,2,27,5,105,3,147,252,105,251,123,251,42,253,205,1,193,6,177,1,219,0,246,0,94,2,233,252,197,252,137,2,123,3,52,3,208,2,151,1,127,253,41,253,60,253,194,9,193,3,157,255,226,253,238,253,5,254,232,253,160,253,126,253,146,253,60,1,195,0,47,253,219,253,3,255,240,5,171,0,175,255,140,254,179,254,142,4,208,251,50,251,157,251,249,251,156,252,142,254,209,0,25,6,215,6,113,0,145,254,143,1,105,253,246,255,241,254,182,3,118,0,177,254,240,254,161,252,60,0,149,252,58,7,14,255,236,254,218,255,150,255,215,1,30,0,55,3,168,254,16,253,54,253,203,254,93,254,86,0,68,6,6,255,71,255,185,252,65,253,207,253,231,254,21,7,199,255,255,0,10,1,224,255,99,0,144,1,216,9,59,1,140,254,206,254,1,254,219,253,109,253,8,253,39,253,209,253,119,255,158,253,174,0,156,3,202,254,63,253,205,254,117,3,0,2,157,253,183,251,108,251,208,251,10,253,241,253,64,255,22,1,228,2,70,13,144,251,153,1,26,255,159,254,119,255,66,1,70,1,109,1,133,0,173,0,243,8,124,253,43,253,172,253,233,253,172,254,168,255,191,255,203,255,17,1,8,253,122,254,119,253,119,0,13,255,34,255,190,6,143,255,44,0,70,1,150,253,55,1,41,9,15,255,114,254,113,254,130,254,190,254,68,254,55,254,81,7,58,254,7,254,42,0,225,1,187,0,207,255,7,254,134,253,14,253,28,4,171,253,35,5,41,1,100,254,146,255,51,255,216,253,86,253,244,253,225,251,81,254,203,3,149,254,229,253,146,254,39,0,227,3,181,0,220,1,150,2,229,0,67,254,146,6,51,255,75,255,239,254,15,254,83,253,140,253,247,23,235,255,190,252,90,252,22,252,214,251,93,252,50,252,122,252,125,253,204,252,99,7,62,253,224,254,4,255,25,255,177,255,126,0,35,0,37,0,10,0,246,255,220,255,250,255,247,255,209,255,249,255,1,0,11,0,254,255,132,2,59,1,145,0,159,254,116,254,84,254,155,254,196,255,19,1,109,0,101,251,72,252,70,253,138,0,30,1,171,0,138,1,7,1,46,3,239,1,22,254,110,0,113,1,87,2,9,0,87,2,81,254,23,255,184,254,187,255,154,1,22,252,50,254,77,0,97,0,196,0,133,0,165,255,0,2,49,0,109,2,76,254,160,254,122,254,45,255,68,255,58,254,194,254,44,0,144,5,34,250,73,250,200,250,103,251,145,254,89,0,219,1,99,3,38,2,52,3,219,252,188,253,221,252,167,255,207,252,155,6,208,254,120,0,36,0,52,2,153,1,243,253,204,252,106,1,55,252,154,252,163,253,191,7,225,3,210,2,225,5,77,4,182,252,176,252,106,252,133,254,185,255,1,1,243,1,95,2,83,6,68,252,0,252,155,252,24,253,182,255,27,3,172,2,20,2,122,2,176,250,206,252,49,0,43,252,111,0,39,254,50,253,35,254,121,1,198,2,137,250,175,251,128,251,0,252,122,9,156,254,65,255,55,4,143,3,140,4,215,252,233,252,105,252,171,10,173,252,112,254,143,255,242,0,252,1,79,3,51,251,175,4,114,252,103,4,82,253,129,254,26,0,96,1,24,2,134,2,234,252,37,251,177,251,110,251,148,251,215,251,236,252,247,253,161,0,2,15,182,251,141,252,228,251,8,0,177,251,21,253,216,253,32,254,15,255,52,3,64,13,254,252,254,252,44,253,180,253,86,254,103,255,170,1,127,2,212,2,90,6,55,253,133,4,32,253,20,254,0,254,96,255,205,1,57,2,71,2,185,250,52,5,58,251,178,250,240,0,5,6,44,253,100,2,47,6,170,4,219,251,34,252,97,253,55,252,72,252,64,9,70,254,99,254,141,7,255,3,112,255,229,254,32,252,84,252,215,3,24,255,50,3,85,1,246,1,37,2,116,250,12,251,1,251,67,251,147,253,227,7,173,2,156,7,240,4,176,4,243,250,104,253,136,1,176,252,98,3,167,4,36,255,95,0,194,1,128,2,202,250,74,4,17,253,67,253,16,5,165,254,164,255,233,0,20,2,87,2,72,252,74,253,13,12,116,252,0,255,18,254,79,255,123,0,41,3,173,3,18,0,191,251,223,252,47,1,7,253,11,0,120,2,32,1,220,1,6,2,15,255,142,251,212,251,155,252,36,1,121,0,230,255,160,255,201,1,36,2,150,255,240,252,162,3,68,253,50,7,212,252,151,253,205,254,174,1,143,2,70,253,133,4,179,3,221,252,106,253,25,253,207,255,96,4,92,1,66,2,87,3,231,251,15,253,189,255,198,2,165,254,228,255,182,2,155,1,212,1,195,255,239,0,23,0,208,251,11,253,221,1,110,253,150,254,239,0,64,2,57,250,1,251,250,250,91,253,85,252,46,253,145,12,82,1,26,6,30,6,157,3,149,3,71,253,60,253,133,2,65,254,232,254,202,2,247,1,40,2,230,251,3,252,121,3,68,252,90,252,193,2,201,1,104,2,44,2,155,2,205,250,205,255,0,255,208,255,22,255,240,0,245,2,182,255,148,0,100,1,2,251,2,6,234,0,140,254,40,254,35,255,88,254,18,254,170,0,39,2,216,0,38,1,139,252,231,0,249,254,78,1,192,255,202,255,35,1,94,1,140,251,206,251,81,251,162,250,2,251,179,252,221,253,155,2,192,17,130,7,125,252,94,252,70,252,160,251,188,251,132,4,97,7,108,254,3,1,90,4,68,252,188,252,113,3,196,254,47,252,164,252,202,0,7,255,121,0,48,3,92,251,60,14,195,252,148,252,98,253,39,254,95,255,164,1,83,3,118,3,10,252,167,4,86,252,66,252,160,252,229,2,241,0,189,3,32,1,117,2,125,251,126,252,80,4,235,252,28,0,157,252,188,253,28,10,68,3,210,4,71,252,19,253,166,3,113,4,202,254,79,255,143,255,244,0,20,2,168,1,171,254,166,253,144,252,175,251,209,254,131,254,241,253,151,7,126,0,247,2,3,251,243,251,59,0,241,252,229,1,179,253,61,5,225,2,232,1,197,2,63,250,72,251,198,251,77,2,23,3,223,2,191,1,66,1,67,3,219,2,164,251,87,253,176,253,192,2,8,2,223,253,152,255,232,255,7,1,202,1,120,2,47,253,194,251,57,251,130,251,158,252,1,6,255,10,123,0,73,4,42,251,163,252,63,251,42,251,19,251,110,252,141,4,166,1,199,2,115,3,84,251,52,252,84,254,26,255,171,0,8,0,64,254,171,4,189,1,184,1,99,254,117,255,137,254,200,253,243,252,248,253,99,2,182,253,113,3,77,2,44,253,204,3,117,252,230,252,205,252,127,253,114,6,66,0,254,0,191,2,156,250,112,251,57,252,164,2,3,253,231,253,66,2,6,6,175,2,65,3,127,4,213,252,76,252,29,252,10,255,21,5,135,254,6,1,120,2,140,2,250,5,89,253,86,253,225,3,102,253,55,254,184,255,236,255,61,1,4,2,93,3,240,253,24,0,189,253,126,254,53,0,14,2,180,255,66,0,89,1,197,255,156,253,165,0,75,255,158,255,222,255,190,255,30,1,95,0,108,0,162,251,109,255,131,2,225,251,0,253,10,254,181,253,27,0,65,8,43,3,61,251,77,252,213,252,92,251,119,4,159,253,15,253,88,0,28,11,144,5,108,250,198,251,7,251,62,4,74,251,109,251,23,1,2,254,21,9,221,6,99,250,142,2,2,251,13,251,163,251,74,252,11,3,157,8,126,4,77,4,52,250,15,252,81,251,120,250,65,251,145,2,31,253,122,2,242,4,206,6,91,250,87,251,178,250,122,251,9,252,29,252,113,253,195,15,174,7,111,7,211,251,186,3,181,251,109,251,251,251,206,252,192,253,152,255,110,5,45,4,47,2,110,252,246,251,128,251,37,252,186,253,34,255,138,1,180,4,7,3,72,250,205,255,65,252,19,252,60,254,91,1,162,255,1,0,13,2,83,2,212,250,54,251,178,251,199,252,97,252,248,252,186,253,175,0,139,6,120,2,165,252,28,0,110,252,47,255,44,254,143,253,26,255,134,2,67,2,190,1,132,251,146,251,24,252,183,253,203,2,6,3,114,2,138,2,61,8,126,252,39,253,17,255,43,255,79,3,77,0,115,1,122,252,234,252,61,7,153,252,208,252,163,0,39,1,121,1,182,6,210,251,184,252,233,252,76,6,127,255,144,0,194,1,194,252,117,7,229,253,35,3,101,254,68,255,122,0,148,0,178,4,193,2,72,253,190,253,43,255,231,255,126,0,142,0,237,12,197,251,159,252,253,252,42,254,19,255,212,3,9,2,172,1,29,252,21,252,16,12,24,252,57,254,64,1,247,1,153,253,210,6,17,253,34,253,68,4,31,0,97,0,225,0,105,251,239,8,254,4,91,254,197,254,91,0,130,0,120,0,77,251,115,16,54,252,146,252,28,255,71,0,71,1,32,1,12,252,174,252,191,5,36,253,204,4,201,0,146,0,15,1,156,252,240,253,172,4,232,2,70,255,85,0,38,0,153,0,199,251,129,252,26,253,246,3,86,4,66,0,237,0,79,1,12,252,143,251,5,17,218,251,199,253,121,1,12,1,189,1,179,4,51,253,46,4,227,253,184,255,227,255,91,0,104,0,48,25,132,251,211,251,214,252,109,253,118,0,228,254,44,1,195,251,84,252,42,255,147,253,243,252,146,253,253,6,199,2,115,251,107,6,134,252,215,252,235,253,148,0,128,1,117,1,114,252,38,252,169,252,248,251,63,14,34,254,124,255,201,2,253,255,94,253,244,251,68,252,125,252,138,10,117,2,153,2,4,253,214,251,107,251,222,251,76,253,112,255,90,4,123,12,12,252,125,253,98,253,11,6,192,253,95,1,251,0,17,1,74,252,51,2,26,253,248,0,107,255,2,2,100,0,185,0,63,255,152,253,113,253,255,0,148,254,189,254,172,0,0,1,52,1,228,0,16,0,69,255,13,255,219,0,88,0,53,0,0,252,152,2,194,1,96,254,67,255,17,255,43,0,102,0,192,255,13,254,97,255,112,254,137,3,192,255,188,255,46,0,225,251,179,255,211,252,107,253,59,0,179,255,226,0,65,1,200,4,215,253,76,254,25,3,101,255,173,255,251,255,72,0,116,253,127,252,99,255,189,253,229,253,78,3,181,0,62,1,14,3,57,252,222,252,199,253,250,255,108,1,28,2,1,2,59,254,193,251,147,251,155,251,172,252,98,255,128,4,241,12,247,3,68,254,61,4,47,254,195,254,214,254,41,254,18,255,121,253,146,5,15,255,149,0,212,254,87,255,237,255,28,255,210,12,243,254,255,251,211,251,183,251,209,251,229,253,23,5,87,4,91,252,27,253,223,252,215,253,98,0,137,1,7,4,238,252,39,253,189,252,214,252,178,255,33,6,119,2,176,3,7,4,139,2,103,254,115,254,166,254,35,255,157,255,40,255,168,255,45,255,93,254,193,0,18,5,196,0,35,255,145,252,244,251,233,250,254,250,228,251,193,253,27,1,38,12,57,5,233,1,49,254,128,253,112,0,85,1,190,254,5,1,10,1,110,6,207,252,24,251,7,251,63,251,249,251,114,255,107,14,196,11,28,6,223,254,194,252,54,252,248,251,205,251,35,252,44,2,52,0,180,253,179,253,155,253,20,253,160,254,6,8,187,255,239,252,50,253,13,254,115,255,192,0,116,5,190,1,253,255,254,253,156,253,3,0,171,0,43,4,142,255,147,255,212,252,131,252,248,252,170,254,148,5,165,1,182,1,40,2,91,252,137,251,49,255,32,5,23,3,166,0,58,255,177,255,136,253,98,4,231,253,148,253,194,1,97,0,171,255,174,0,224,6,123,0,88,255,229,1,179,255,201,253,248,252,72,252,10,253,104,251,214,250,181,250,73,251,96,252,79,255,85,24,99,254,5,1,185,254,176,252,43,253,117,254,81,3,253,5,55,255,132,255,160,11,177,254,65,253,94,253,41,253,75,252,247,253,209,0,236,3,70,3,56,0,35,254,17,253,165,253,102,252,153,253,40,7,64,254,183,254,108,255,73,0,211,1,127,19,170,255,215,252,96,252,73,252,68,252,205,252,17,253,49,7,234,252,56,253,140,255,143,255,165,255,0,0,124,254,39,253,60,255,246,2,135,254,68,0,85,0,172,1,221,255,251,255,2,0,247,255,18,0,225,255,53,0,233,255,26,0,128,252,67,254,68,255,50,3,165,254,212,255,246,1,66,2,101,0,152,11,13,1,44,253,66,253,21,253,49,253,95,253,163,29,68,0,109,251,159,250,95,250,81,250,63,250,102,251,187,2,73,2,15,0,209,8,9,254,84,252,195,251,248,250,245,250,43,251,105,251,94,251,141,251,12,2,201,4,184,5,238,251,47,253,123,252,41,0,40,253,54,3,111,253,54,4,29,254,250,5,23,254,229,4,158,3,186,254,148,1,89,0,89,251,110,251,43,251,97,6,213,5,47,254,218,3,160,4,167,252,192,252,212,254,213,252,88,252,101,253,2,255,236,1,204,15,144,251,41,252,169,252,176,253,57,255,127,1,108,3,28,8,238,251,5,252,39,253,155,5,231,255,64,0,77,3,33,252,103,252,163,252,148,3,110,254,217,253,236,0,173,1,133,20,47,251,12,251,98,254,1,7,49,254,199,253,157,6,83,251,178,24,137,252,45,255,79,252,228,253,114,2,135,3,31,252,220,5,22,254,165,5,4,253,120,255,65,1,36,2,206,1,28,255,127,0,190,254,225,1,73,255,88,0,155,0,215,252,180,252,65,252,171,15,187,253,24,255,74,1,218,3,124,252,108,252,211,251,158,252,45,252,73,254,176,15,22,6,1,252,73,8,181,6,156,253,180,253,66,254,223,0,174,1,7,10,52,252,70,8,250,251,124,252,104,253,180,0,90,3,160,12,33,252,148,251,71,8,66,254,220,253,254,254,127,3,62,252,72,255,79,10,57,4,107,253,34,255,36,1,18,2,72,252,231,6,43,255,67,253,55,4,37,0,131,0,233,1,149,252,19,253,95,12,248,252,223,4,147,255,173,255,124,2,134,251,210,251,23,252,216,251,82,252,75,11,113,4,49,6,222,250,136,253,101,251,175,251,77,4,51,0,246,7,244,7,98,252,41,253,180,0,235,5,202,253,167,4,101,0,83,2,199,8,148,254,197,254,151,255,126,255,177,255,121,0,210,0,58,31,234,250,126,252,239,252,10,253,247,252,31,0,159,1,232,2,116,253,176,2,202,4,119,253,163,253,244,254,58,1,99,2,150,2,16,255,101,254,70,253,78,254,121,1,83,1,185,3,214,252,93,252,30,4,28,254,214,254,209,2,10,2,154,3,234,251,72,252,153,252,150,253,242,254,163,1,123,2,238,3,129,0,186,252,44,253,220,0,225,1,253,0,73,1,205,0,56,254,44,253,163,2,86,2,76,1,242,255,35,1,8,252,73,253,30,2,246,4,242,1,56,254,143,255,106,1,221,253,212,251,102,251,19,251,119,251,119,252,134,1,156,8,224,251,178,251,235,21,180,251,204,251,122,252,104,1,210,3,230,253,226,254,229,4,82,254,55,254,108,255,255,255,196,255,164,251,69,252,53,11,98,252,88,253,87,4,194,2,74,3,225,250,5,251,130,251,20,255,163,2,129,3,246,2,144,3,94,7,165,251,25,252,172,255,180,253,142,8,85,255,227,2,31,253,150,0,122,252,170,252,107,252,78,1,45,2,22,2,173,252,217,255,231,255,214,0,120,255,183,255,7,1,234,0,3,252,52,5,225,253,113,253,56,253,117,253,80,0,223,1,19,6,141,7,61,253,27,254,50,255,139,0,56,1,149,1,168,9,108,251,79,252,85,252,55,253,56,2,141,5,172,2,70,0,17,251,45,251,74,2,61,255,215,251,63,254,110,12,137,251,17,2,98,252,210,253,163,1,134,1,119,1,51,2,190,251,42,13,80,253,240,253,166,254,136,0,61,1,103,2,221,252,47,252,198,251,218,252,23,14,69,254,100,255,106,4,248,250,49,6,62,251,54,251,45,252,103,1,19,6,122,5,171,254,96,254,32,254,152,254,97,254,30,2,108,255,190,254,185,251,206,251,250,2,160,252,134,253,234,6,84,1,210,1,240,251,190,252,228,5,61,253,143,0,74,0,138,5,137,3,186,251,58,253,219,253,164,252,117,1,212,5,232,7,229,2,86,252,114,252,101,10,193,251,175,251,123,252,127,1,138,3,243,2,205,252,69,2,156,253,92,254,49,1,88,1,107,1,156,254,33,252,179,252,229,251,64,8,202,6,42,2,186,3,252,251,81,252,132,252,128,252,20,255,94,253,52,4,167,2,157,253,181,251,165,252,110,252,68,254,142,3,235,1,197,2,217,251,7,3,240,1,99,253,208,254,160,2,5,1,240,1,194,251,61,252,13,4,129,253,122,255,191,253,33,0,95,2,210,251,119,253,218,2,20,253,92,7,238,255,90,1,115,2,191,251,162,251,69,252,239,2,78,253,94,2,180,4,13,4,8,252,185,251,217,1,105,252,244,251,83,253,208,6,192,4,190,252,108,252,104,252,134,253,62,4,38,254,161,0,108,2,27,252,125,252,231,255,13,254,143,1,149,1,163,0,145,1,50,0,150,0,250,0,94,1,194,1,58,2,188,2,72,3,232,3,146,4,90,5,64,6,58,7,102,8,196,9,84,11,72,13,160,15,192,18,168,22,88,27,52,33,4,41,188,52,104,66,0,0,0,0,0,0,64,153,22,0,64,153,22,0,64,153,22,0,48,153,22,0,0,0,0,0,0,0,0,0,0,0,40,0,80,0,180,255,160,0,102,255,236,0,20,255,0,0,241,255,50,0,206,255,115,0,141,255,235,0,21,255,104,153,22,0,104,153,22,0,104,153,22,0,48,153,22,0,0,0,0,0,0,0,0,0,0,0,236,255,15,0,176,255,100,0,96,255,180,0,96,255,1,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,255,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,254,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,11,10,16,24,40,51,61,12,12,14,19,26,58,60,55,14,13,16,24,40,57,69,56,14,17,22,29,51,87,80,62,18,22,37,56,68,109,103,77,24,35,55,64,81,104,113,92,49,64,78,87,103,121,120,101,72,92,95,98,112,100,103,99,17,18,24,47,99,99,99,99,18,21,26,66,99,99,99,99,24,26,56,99,99,99,99,99,47,66,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,40,11,33,0,24,165,32,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,40,11,33,0,192,73,32,0,24,165,32,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,40,11,33,0,120,215,35,0,176,48,40,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,11,33,0,176,230,34,0,216,211,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,11,33,0,32,108,39,0,160,27,39,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,72,215,38,0,160,27,39,0,16,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1476088);
/* memory initializer */ allocate([192,255,255,255,223,65,16,0,1,0,0,0,0,0,248,145,38,0,104,87,38,0,20,0,0,0,1,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,40,34,38,0,104,87,38,0,20,0,0,0,1,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,192,241,37,0,16,196,37,0,52,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,232,161,37,0,24,122,37,0,56,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,184,54,37,0,24,122,37,0,56,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,112,13,37,0,120,228,36,0,64,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,248,192,36,0,120,228,36,0,64,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,224,163,36,0,248,136,36,0,76,0,0,0,82,76,79,67,128,109,36,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,224,82,36,0,248,136,36,0,76,0,0,0,82,76,79,67,128,109,36,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,188,36,0,112,0,0,0,248,172,22,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,12,0,0,0,16,0,0,102,6,0,0,204,12,0,0,61,10,0,0,204,12,0,0,30,5,0,0,0,16,0,0,204,12,0,0,0,16,0,0,102,6,0,0,102,6,0,0,30,5,0,0,102,6,0,0,143,2,0,0,247,31,248,31,249,31,250,31,251,31,248,63,249,63,252,7,254,0,126,0,14,0,2,0,0,0,6,0,30,0,62,0,254,1,250,15,246,31,250,63,251,63,252,63,253,63,254,63,255,63,0,0,0,0,0,0,13,13,13,13,13,14,14,11,8,7,4,2,1,3,5,6,9,12,13,14,14,14,14,14,14,0,0,0,0,0,0,0,226,255,3,0,227,255,3,0,228,255,3,0,229,255,3,0,230,255,3,0,231,255,3,0,232,255,3,0,233,255,3,0,234,255,3,0,235,255,3,0,236,255,3,0,237,255,3,0,238,255,3,0,239,255,3,0,240,255,3,0,247,255,0,0,240,255,1,0,252,63,0,0,254,7,0,0,252,7,0,0,254,0,0,0,126,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,30,0,0,0,62,0,0,0,254,1,0,0,253,7,0,0,254,15,0,0,250,127,0,0,246,255,0,0,241,255,3,0,242,255,3,0,243,255,3,0,244,255,3,0,245,255,3,0,246,255,3,0,247,255,3,0,248,255,3,0,249,255,3,0,250,255,3,0,251,255,3,0,252,255,3,0,253,255,3,0,254,255,3,0,254,255,7,0,255,255,7,0,0,0,0,0,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,16,17,14,11,11,8,7,4,2,1,3,5,6,9,11,12,15,16,18,18,18,18,18,18,18,18,18,18,18,18,18,18,19,19,0,0,0,0,0,0,0,240,255,15,0,241,255,15,0,242,255,15,0,243,255,15,0,244,255,15,0,245,255,15,0,246,255,15,0,243,255,3,0,245,255,7,0,238,255,7,0,239,255,7,0,246,255,7,0,244,255,3,0,242,255,3,0,247,255,15,0,240,255,7,0,245,255,1,0,240,255,3,0,244,255,1,0,247,255,0,0,246,255,0,0,248,127,0,0,251,63,0,0,253,15,0,0,253,7,0,0,253,3,0,0,253,1,0,0,253,0,0,0,62,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,30,0,0,0,252,0,0,0,252,1,0,0,252,3,0,0,252,7,0,0,252,15,0,0,252,31,0,0,250,63,0,0,249,127,0,0,250,127,0,0,248,255,0,0,249,255,0,0,246,255,1,0,247,255,1,0,245,255,3,0,246,255,3,0,241,255,3,0,248,255,15,0,241,255,7,0,242,255,7,0,243,255,7,0,249,255,15,0,247,255,7,0,244,255,7,0,250,255,15,0,251,255,15,0,252,255,15,0,253,255,15,0,254,255,15,0,255,255,15,0,0,0,0,0,20,20,20,20,20,20,20,18,19,19,19,19,18,18,20,19,17,18,17,16,16,15,14,12,11,10,9,8,6,4,2,1,3,5,8,9,10,11,12,13,14,15,15,16,16,17,17,18,18,18,20,19,19,19,20,19,19,20,20,20,20,20,20,0,231,255,7,0,232,255,7,0,210,255,15,0,211,255,15,0,212,255,15,0,213,255,15,0,214,255,15,0,215,255,15,0,216,255,15,0,218,255,7,0,217,255,15,0,218,255,15,0,219,255,15,0,220,255,15,0,219,255,7,0,221,255,15,0,220,255,7,0,221,255,7,0,222,255,15,0,228,255,3,0,223,255,15,0,224,255,15,0,225,255,15,0,222,255,7,0,226,255,15,0,227,255,15,0,228,255,15,0,223,255,7,0,229,255,15,0,224,255,7,0,232,255,3,0,225,255,7,0,224,255,3,0,233,255,3,0,239,255,1,0,229,255,3,0,236,255,1,0,237,255,1,0,238,255,1,0,244,255,0,0,243,255,0,0,240,255,0,0,247,127,0,0,246,127,0,0,250,63,0,0,250,31,0,0,249,31,0,0,250,15,0,0,248,15,0,0,249,7,0,0,251,3,0,0,252,1,0,0,250,1,0,0,251,0,0,0,124,0,0,0,60,0,0,0,28,0,0,0,12,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,13,0,0,0,29,0,0,0,61,0,0,0,250,0,0,0,252,0,0,0,251,1,0,0,250,3,0,0,248,7,0,0,250,7,0,0,251,7,0,0,249,15,0,0,251,15,0,0,248,31,0,0,251,31,0,0,248,63,0,0,249,63,0,0,241,255,0,0,242,255,0,0,234,255,1,0,235,255,1,0,225,255,3,0,226,255,3,0,234,255,3,0,227,255,3,0,230,255,3,0,231,255,3,0,235,255,3,0,230,255,15,0,226,255,7,0,231,255,15,0,232,255,15,0,233,255,15,0,234,255,15,0,235,255,15,0,236,255,15,0,227,255,7,0,237,255,15,0,238,255,15,0,239,255,15,0,240,255,15,0,228,255,7,0,241,255,15,0,236,255,3,0,242,255,15,0,243,255,15,0,229,255,7,0,230,255,7,0,244,255,15,0,245,255,15,0,246,255,15,0,247,255,15,0,248,255,15,0,249,255,15,0,250,255,15,0,251,255,15,0,252,255,15,0,253,255,15,0,254,255,15,0,255,255,15,0,0,0,0,0,19,19,20,20,20,20,20,20,20,19,20,20,20,20,19,20,19,19,20,18,20,20,20,19,20,20,20,19,20,19,18,19,18,18,17,18,17,17,17,16,16,16,15,15,14,13,13,12,12,11,10,9,9,8,7,6,5,4,3,2,2,3,4,5,6,8,8,9,10,11,11,11,12,12,13,13,14,14,16,16,17,17,18,18,18,18,18,18,18,20,19,20,20,20,20,20,20,19,20,20,20,20,19,20,18,20,20,19,19,20,20,20,20,20,20,20,20,20,20,20,20,0,0,0,0,0,0,0,48,82,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,29,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,187,35,0,112,0,0,0,80,119,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,101,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,90,33,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,32,115,112,114,111,112,45,112,97,114,97,109,101,116,101,114,45,115,101,116,115,61,0,59,32,112,114,111,102,105,108,101,45,108,101,118,101,108,45,105,100,61,0,0,0,0,0,0,37,34,0,104,134,33,0,4,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,224,111,64,16,0,1,0,104,11,33,0,88,165,32,0,216,73,32,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,104,11,33,0,200,48,40,0,248,211,39,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,104,11,33,0,72,108,39,0,248,27,39,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,104,11,33,0,144,215,38,0,32,146,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,104,11,33,0,192,87,38,0,104,34,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,104,11,33,0,232,241,37,0,104,196,37,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,104,11,33,0,8,162,37,0,104,122,37,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,104,11,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,54,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,0,0,0,0,0,0,0,0,196,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,205,36,0,112,0,0,0,136,182,22,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,5,0,0,0,3,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,243,4,181,63,240,55,152,63,0,0,128,63,240,55,24,63,243,4,53,63,240,55,24,63,0,0,0,63,0,0,0,0,40,141,34,0,112,0,0,0,80,188,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,192,224,240,248,252,254,255,0,1,2,4,8,16,32,64,12,4,4,4,4,4,8,8,8,12,16,20,36,0,0,0,0,0,0,0,0,0,0,0,0,15,4,8,4,8,8,4,8,8,12,12,12,24,28,40,76,0,0,0,0,0,0,0,0,0,17,4,8,8,4,12,12,8,8,24,16,20,24,32,40,60,80,152,0,0,0,0,0,0,0,0,0,0,0,0,11,4,4,8,4,4,12,16,24,20,28,4,0,0,0,0,0,0,0,0,0,0,0,0,0,15,4,8,4,4,8,8,16,20,12,20,20,28,40,56,8,0,0,0,0,0,0,0,0,0,16,8,4,8,8,12,16,20,24,40,32,32,44,56,80,112,16,0,0,0,0,0,0,0,0,0,0,0,0,0,10,4,8,4,8,8,12,20,24,24,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,4,8,8,4,12,12,16,24,16,20,24,32,40,36,0,0,0,0,0,0,0,0,0,0,23,4,4,4,8,4,4,8,8,8,8,8,12,12,16,16,24,24,32,44,48,60,84,72,0,0,0,0,0,0,52,0,0,0,47,0,0,0,43,0,0,0,37,0,0,0,29,0,0,0,22,0,0,0,16,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,3,2,2,1,1,1,5,5,0,0,0,0,0,0,128,189,22,0,64,188,22,0,101,85,137,62,194,152,156,62,245,72,159,62,21,137,188,62,235,195,208,62,92,10,122,62,199,83,148,62,19,199,166,62,61,202,199,62,209,176,211,62,53,5,111,62,56,0,154,62,177,106,168,62,221,105,197,62,65,69,210,62,87,163,132,62,233,90,152,62,49,22,175,62,148,71,197,62,123,110,211,62,245,187,120,62,251,159,149,62,221,132,167,62,170,121,193,62,45,129,206,62,233,169,124,62,24,81,152,62,31,49,172,62,134,220,201,62,168,93,216,62,21,232,90,62,207,173,169,62,51,109,174,62,113,178,195,62,152,155,209,62,119,145,136,62,59,167,157,62,158,58,176,62,152,207,202,62,45,6,217,62,224,189,133,62,48,31,156,62,35,242,168,62,108,13,197,62,90,41,215,62,178,137,127,62,151,99,150,62,107,235,170,62,161,203,193,62,115,147,213,62,21,99,119,62,230,124,154,62,147,188,174,62,26,193,196,62,181,23,213,62,92,49,132,62,141,125,162,62,208,181,178,62,132,128,198,62,50,190,212,62,191,95,122,62,79,12,157,62,23,237,171,62,115,195,193,62,239,166,207,62,254,214,128,62,86,223,159,62,251,76,173,62,121,132,202,62,86,18,217,62,89,89,105,62,161,181,162,62,41,56,173,62,158,6,205,62,189,222,210,62,249,212,142,62,106,46,165,62,205,145,182,62,207,219,205,62,203,239,216,62,174,103,44,61,229,72,142,61,116,189,228,61,136,55,21,62,69,243,85,62,168,13,97,61,61,51,201,61,1,113,225,61,185,184,34,62,251,105,82,62,167,23,57,61,41,2,154,61,120,243,233,61,247,104,30,62,206,52,74,62,75,166,74,61,183,40,163,61,11,187,0,62,185,131,45,62,62,189,84,62,87,43,43,61,22,247,129,61,57,39,247,61,212,79,34,62,62,247,80,62,11,42,65,61,172,14,162,61,149,130,249,61,169,65,32,62,76,114,100,62,64,101,95,61,229,138,164,61,201,149,4,62,151,129,27,62,243,142,78,62,39,197,100,61,73,191,192,61,43,134,15,62,52,88,54,62,112,16,107,62,255,34,58,61,225,156,150,61,180,123,244,61,91,32,30,62,109,38,87,62,121,99,129,61,186,8,195,61,31,60,253,61,131,247,52,62,227,167,94,62,128,32,88,61,115,192,172,61,47,88,237,61,246,178,33,62,158,76,84,62,45,113,84,61,148,143,166,61,35,221,12,62,83,160,59,62,37,152,93,62,65,241,53,61,14,14,141,61,216,76,6,62,1,138,38,62,8,202,93,62,11,65,74,61,10,178,167,61,204,206,5,62,151,65,44,62,217,233,108,62,167,1,101,61,152,236,185,61,52,177,8,62,121,229,38,62,96,165,86,62,184,103,123,61,64,240,201,61,213,123,23,62,186,117,69,62,102,31,109,62,0,2,0,3,4,0,0,0,3,3,4,0,0,0,0,0,224,212,22,0,224,206,22,0,224,190,22,0,0,0,0,0,39,151,114,62,28,32,131,62,6,72,162,62,136,166,208,62,160,94,152,62,126,159,165,62,122,1,178,62,46,197,191,62,46,37,140,62,116,186,152,62,202,235,168,62,26,103,196,62,118,158,157,62,132,105,170,62,158,87,199,62,168,167,207,62,55,106,111,62,150,69,133,62,142,21,188,62,250,11,207,62,182,83,152,62,106,118,161,62,114,48,197,62,200,236,205,62,160,60,146,62,184,42,159,62,54,228,186,62,180,6,197,62,184,168,171,62,176,223,181,62,42,139,195,62,138,32,204,62,109,18,77,62,214,65,128,62,214,164,189,62,196,48,221,62,212,175,157,62,154,227,170,62,222,101,183,62,234,187,193,62,2,42,133,62,152,170,166,62,26,184,182,62,90,252,196,62,98,75,154,62,248,199,174,62,178,243,204,62,56,173,213,62,214,190,136,62,198,104,152,62,150,73,189,62,66,61,199,62,98,155,139,62,106,12,179,62,110,170,200,62,120,17,208,62,102,114,129,62,144,3,179,62,222,227,196,62,48,214,207,62,36,148,175,62,216,160,191,62,134,153,207,62,94,56,215,62,184,59,129,62,108,141,143,62,86,147,164,62,52,225,198,62,122,12,152,62,148,100,162,62,46,14,187,62,134,51,206,62,224,85,144,62,122,91,154,62,10,46,171,62,86,181,208,62,228,91,167,62,70,193,177,62,82,2,192,62,248,140,207,62,71,11,114,62,144,4,162,62,186,137,178,62,126,153,195,62,212,92,147,62,184,147,160,62,42,109,207,62,56,197,216,62,206,20,142,62,70,139,154,62,170,151,190,62,16,163,214,62,58,113,168,62,26,75,185,62,250,212,205,62,74,165,214,62,9,92,102,62,36,157,140,62,66,8,193,62,152,25,202,62,162,34,154,62,52,84,174,62,86,241,191,62,178,24,206,62,88,17,133,62,170,33,169,62,110,9,183,62,158,59,209,62,172,23,154,62,126,128,182,62,66,63,207,62,24,83,216,62,121,72,98,62,92,9,162,62,102,177,205,62,174,106,215,62,12,60,143,62,124,91,169,62,162,130,210,62,40,137,221,62,94,75,135,62,202,26,162,62,126,139,196,62,4,149,223,62,186,82,176,62,166,78,197,62,250,146,217,62,46,20,226,62,139,193,96,62,138,34,114,62,180,87,175,62,74,152,217,62,234,58,149,62,38,2,165,62,144,230,190,62,128,132,200,62,152,177,140,62,12,17,162,62,76,215,176,62,180,197,191,62,204,4,159,62,216,167,171,62,248,105,198,62,114,157,216,62,143,145,100,62,174,212,152,62,92,162,188,62,24,202,199,62,36,2,148,62,174,44,167,62,136,171,192,62,6,177,209,62,190,20,135,62,68,50,158,62,208,77,195,62,178,47,207,62,162,179,177,62,200,198,186,62,220,5,198,62,40,28,207,62,17,178,95,62,74,29,141,62,68,181,185,62,170,40,214,62,74,77,161,62,18,127,174,62,108,219,193,62,8,234,202,62,120,56,143,62,224,154,169,62,244,89,184,62,112,41,195,62,220,31,163,62,36,20,173,62,220,105,209,62,86,80,220,62,210,68,135,62,6,211,148,62,124,184,188,62,84,28,221,62,52,152,139,62,158,30,186,62,132,4,203,62,50,22,215,62,91,250,103,62,108,58,179,62,232,166,201,62,234,63,211,62,122,195,180,62,104,103,189,62,112,190,209,62,112,79,218,62,14,134,133,62,32,2,146,62,124,31,177,62,54,133,203,62,128,43,154,62,20,10,168,62,140,78,182,62,224,84,210,62,14,130,147,62,154,126,158,62,228,0,176,62,240,136,217,62,118,248,158,62,146,237,179,62,84,149,201,62,10,195,212,62,199,164,99,62,24,82,167,62,208,134,193,62,228,25,204,62,190,23,155,62,172,67,165,62,232,15,204,62,198,217,217,62,224,228,141,62,18,214,163,62,124,70,193,62,38,189,219,62,64,110,173,62,82,97,183,62,4,24,209,62,136,218,217,62,197,249,95,62,232,154,145,62,104,193,201,62,110,43,213,62,116,29,154,62,12,45,176,62,92,239,188,62,216,134,212,62,226,194,143,62,2,134,170,62,64,226,192,62,164,136,203,62,66,248,160,62,10,177,185,62,36,235,216,62,158,64,226,62,156,108,136,62,132,245,157,62,244,120,203,62,8,188,213,62,90,164,150,62,24,14,175,62,240,80,211,62,194,169,222,62,20,25,147,62,222,52,170,62,128,249,193,62,54,96,224,62,236,219,182,62,238,217,203,62,172,24,220,62,240,115,227,62,247,46,107,62,131,133,128,62,168,157,174,62,106,10,207,62,28,197,150,62,220,125,171,62,160,135,184,62,20,114,196,62,162,149,147,62,30,154,159,62,248,209,169,62,0,239,186,62,226,86,166,62,234,249,176,62,24,208,198,62,82,217,207,62,176,108,128,62,172,36,142,62,112,217,189,62,228,236,199,62,178,72,150,62,116,25,168,62,240,194,200,62,70,165,209,62,44,53,145,62,230,150,155,62,84,203,193,62,74,108,203,62,68,7,171,62,26,167,180,62,92,103,203,62,4,34,212,62,161,55,99,62,21,246,128,62,140,82,190,62,182,19,221,62,240,91,160,62,140,174,174,62,72,35,187,62,72,242,198,62,214,235,138,62,222,166,173,62,220,168,185,62,232,157,202,62,54,119,157,62,234,15,178,62,96,86,205,62,178,147,221,62,110,206,132,62,160,17,147,62,236,12,198,62,212,228,207,62,30,43,146,62,56,45,176,62,144,217,205,62,102,189,214,62,128,20,136,62,138,31,174,62,0,35,189,62,230,163,218,62,136,29,181,62,94,216,196,62,156,208,210,62,128,52,218,62,35,184,121,62,50,101,137,62,24,53,175,62,150,2,204,62,34,23,150,62,230,100,171,62,28,49,185,62,68,253,203,62,232,42,149,62,224,85,160,62,32,77,172,62,252,134,198,62,12,127,156,62,160,206,185,62,12,188,198,62,90,163,207,62,79,182,94,62,58,154,159,62,20,129,192,62,152,165,219,62,132,17,149,62,158,164,168,62,8,204,206,62,14,60,216,62,86,170,148,62,216,122,158,62,136,11,194,62,246,206,211,62,186,188,168,62,48,59,193,62,228,43,208,62,124,119,217,62,109,96,124,62,70,14,139,62,176,144,187,62,194,139,220,62,186,210,160,62,210,140,172,62,16,197,194,62,160,123,210,62,96,154,141,62,148,150,167,62,112,186,183,62,68,159,219,62,76,101,162,62,60,203,183,62,120,61,207,62,2,121,225,62,187,154,120,62,50,127,171,62,44,60,203,62,120,158,211,62,28,234,147,62,254,192,166,62,12,129,216,62,86,52,227,62,102,31,142,62,48,165,166,62,248,61,199,62,178,212,225,62,82,223,183,62,16,9,200,62,144,142,215,62,48,21,223,62,223,116,97,62,31,170,125,62,138,113,181,62,200,205,217,62,42,178,156,62,192,229,167,62,122,230,187,62,138,80,201,62,8,167,138,62,26,55,162,62,222,248,176,62,166,204,210,62,4,121,165,62,138,224,176,62,22,145,199,62,32,216,215,62,27,11,124,62,216,241,159,62,130,143,190,62,230,171,202,62,28,147,155,62,212,17,166,62,170,128,197,62,32,12,212,62,30,233,143,62,166,32,163,62,130,115,197,62,44,47,206,62,50,0,181,62,222,210,190,62,50,227,202,62,142,126,211,62,17,62,86,62,156,44,151,62,142,184,194,62,128,208,220,62,130,143,166,62,80,135,177,62,138,207,189,62,34,55,200,62,144,162,146,62,26,231,175,62,26,75,189,62,194,156,199,62,180,212,167,62,50,218,177,62,30,153,207,62,188,96,217,62,108,144,129,62,196,245,154,62,38,171,195,62,162,27,220,62,4,190,150,62,88,210,189,62,138,119,202,62,164,202,214,62,78,151,134,62,234,172,176,62,142,235,206,62,140,3,216,62,154,233,186,62,138,206,195,62,106,172,211,62,182,203,220,62,106,194,126,62,42,147,144,62,130,70,187,62,28,108,210,62,244,84,157,62,50,217,167,62,78,93,193,62,90,88,223,62,138,218,152,62,68,41,164,62,222,125,179,62,10,241,218,62,146,236,161,62,136,206,185,62,114,197,198,62,104,233,217,62,212,208,116,62,134,161,169,62,78,154,189,62,106,253,212,62,66,131,155,62,142,101,170,62,10,10,210,62,48,2,219,62,164,141,151,62,232,85,163,62,158,26,195,62,216,153,218,62,156,62,170,62,212,155,185,62,194,188,216,62,30,202,225,62,148,197,112,62,142,169,140,62,234,250,210,62,20,247,222,62,32,157,152,62,246,238,181,62,202,23,194,62,170,164,212,62,182,29,145,62,144,198,176,62,246,161,189,62,134,222,209,62,254,173,165,62,100,23,187,62,62,92,211,62,28,175,220,62,248,161,141,62,62,220,153,62,254,241,205,62,102,112,218,62,102,202,150,62,22,15,185,62,110,218,214,62,92,190,223,62,176,228,148,62,232,241,174,62,94,26,201,62,40,17,227,62,40,2,184,62,36,215,206,62,70,182,225,62,94,243,231,62,145,167,100,62,224,238,116,62,236,196,165,62,174,231,215,62,38,237,150,62,150,57,163,62,248,216,180,62,244,167,200,62,220,159,132,62,216,215,158,62,72,232,175,62,220,69,202,62,248,8,162,62,176,85,173,62,108,98,201,62,138,16,211,62,237,222,117,62,46,187,145,62,192,118,184,62,236,139,194,62,120,4,152,62,82,176,161,62,196,56,202,62,154,139,212,62,106,36,146,62,172,30,156,62,192,84,185,62,186,192,207,62,158,192,172,62,188,157,182,62,12,51,197,62,16,135,210,62,43,100,101,62,242,45,133,62,160,31,202,62,246,211,214,62,134,238,153,62,134,235,174,62,240,141,189,62,44,111,199,62,20,42,136,62,136,107,166,62,124,169,191,62,152,225,200,62,152,206,161,62,224,84,174,62,132,1,206,62,182,73,215,62,170,40,138,62,226,208,150,62,220,132,185,62,176,21,208,62,160,203,142,62,198,59,184,62,228,152,195,62,54,55,210,62,114,130,133,62,112,132,169,62,60,20,199,62,242,155,207,62,126,206,175,62,80,234,195,62,188,85,212,62,192,249,220,62,55,243,125,62,48,250,139,62,220,141,169,62,186,127,214,62,200,110,155,62,240,128,166,62,172,241,189,62,236,46,212,62,110,197,141,62,18,219,153,62,216,86,181,62,152,140,219,62,46,182,165,62,238,57,184,62,224,111,199,62,74,142,209,62,125,169,116,62,188,173,158,62,108,52,181,62,24,81,213,62,190,245,143,62,76,115,157,62,172,32,213,62,50,134,224,62,72,229,147,62,134,159,158,62,52,86,188,62,14,64,223,62,216,69,173,62,202,195,189,62,220,181,212,62,24,242,220,62,247,12,119,62,164,23,140,62,180,115,199,62,98,56,211,62,148,153,152,62,124,36,174,62,224,185,197,62,12,225,211,62,130,155,144,62,38,199,169,62,24,68,183,62,196,0,211,62,82,142,155,62,202,189,189,62,188,193,207,62,206,239,220,62,203,208,116,62,20,143,159,62,100,239,211,62,44,224,222,62,138,195,136,62,124,18,175,62,176,182,213,62,214,220,224,62,84,48,137,62,14,172,170,62,228,224,197,62,22,251,223,62,116,87,174,62,42,33,200,62,232,247,222,62,176,240,229,62,141,28,87,62,230,26,110,62,106,59,185,62,240,218,220,62,0,202,150,62,2,220,170,62,6,186,195,62,102,26,204,62,254,160,143,62,12,221,166,62,2,136,179,62,198,38,201,62,254,214,163,62,32,246,175,62,102,58,200,62,36,0,224,62,253,223,97,62,186,54,155,62,198,118,195,62,18,25,207,62,174,126,146,62,138,212,168,62,106,181,198,62,0,55,217,62,40,36,138,62,244,145,166,62,138,32,194,62,0,141,212,62,160,114,171,62,112,15,189,62,198,27,202,62,118,231,210,62,151,20,84,62,194,169,139,62,118,211,193,62,68,129,222,62,36,233,156,62,26,130,177,62,254,54,198,62,50,159,206,62,234,80,138,62,180,124,177,62,118,97,193,62,118,249,202,62,170,50,163,62,16,50,174,62,198,121,212,62,156,22,226,62,72,102,132,62,30,245,160,62,66,236,186,62,242,221,215,62,194,191,144,62,118,81,181,62,2,65,208,62,0,201,219,62,255,8,129,62,160,220,183,62,238,74,202,62,140,23,214,62,68,182,181,62,212,249,191,62,182,130,214,62,82,78,223,62,66,153,135,62,120,252,149,62,10,207,167,62,252,76,209,62,150,148,157,62,244,209,171,62,138,115,185,62,70,205,217,62,220,177,147,62,174,212,161,62,162,211,184,62,114,207,214,62,168,94,162,62,198,39,182,62,42,198,207,62,252,18,217,62,20,5,125,62,136,38,173,62,98,100,190,62,198,188,202,62,200,175,157,62,148,86,170,62,210,18,205,62,104,101,224,62,162,24,143,62,206,226,161,62,190,98,203,62,28,151,222,62,14,97,176,62,110,120,187,62,70,105,210,62,14,42,226,62,75,102,113,62,36,212,150,62,42,208,203,62,48,107,213,62,166,201,160,62,0,93,180,62,126,30,194,62,138,106,210,62,180,229,144,62,50,32,173,62,18,252,198,62,146,248,207,62,56,178,165,62,26,83,179,62,142,46,219,62,188,172,228,62,214,194,133,62,152,98,166,62,234,232,204,62,198,195,217,62,64,78,156,62,36,48,175,62,206,84,217,62,208,61,227,62,202,34,147,62,134,61,170,62,198,226,201,62,104,148,226,62,206,134,191,62,102,214,205,62,82,163,220,62,242,104,227,62,209,33,112,62,22,47,131,62,218,182,174,62,100,153,216,62,134,105,156,62,68,135,168,62,98,150,180,62,198,237,200,62,164,9,144,62,34,73,155,62,90,166,178,62,198,76,201,62,56,207,164,62,62,106,179,62,50,109,203,62,64,65,212,62,224,111,117,62,52,188,149,62,22,4,194,62,178,6,203,62,96,87,157,62,116,131,168,62,94,2,204,62,188,16,213,62,130,15,146,62,178,23,158,62,90,44,201,62,44,49,212,62,70,91,176,62,134,114,185,62,210,148,203,62,126,226,213,62,47,167,109,62,32,30,137,62,34,147,193,62,196,126,222,62,182,6,156,62,176,39,180,62,142,127,192,62,238,99,202,62,172,35,134,62,22,66,177,62,162,26,190,62,50,43,211,62,0,70,159,62,162,187,179,62,206,8,213,62,212,97,222,62,60,202,140,62,20,224,151,62,22,105,198,62,102,136,209,62,248,245,148,62,52,123,181,62,66,111,201,62,64,2,209,62,202,50,139,62,202,230,176,62,74,53,198,62,204,93,216,62,94,251,185,62,158,140,195,62,38,232,206,62,174,52,214,62,83,171,123,62,198,186,139,62,186,86,178,62,208,174,217,62,212,214,160,62,154,253,172,62,222,250,186,62,150,16,207,62,26,145,150,62,96,69,162,62,226,163,175,62,82,240,207,62,218,22,161,62,248,172,190,62,102,35,205,62,8,251,213,62,110,161,111,62,142,197,160,62,10,25,196,62,238,161,222,62,106,87,150,62,130,28,164,62,70,89,210,62,236,110,223,62,28,58,148,62,8,168,159,62,158,202,197,62,160,166,224,62,20,19,167,62,216,255,194,62,186,229,214,62,206,169,224,62,27,106,128,62,190,231,144,62,238,181,195,62,72,85,222,62,48,83,163,62,218,144,176,62,62,209,190,62,62,156,216,62,142,166,147,62,192,89,172,62,222,78,189,62,38,161,217,62,38,186,156,62,192,130,195,62,30,31,214,62,236,160,221,62,10,131,111,62,186,145,176,62,206,8,211,62,58,194,219,62,22,108,146,62,22,145,175,62,102,168,217,62,64,123,227,62,168,73,143,62,204,117,173,62,106,191,200,62,152,142,225,62,248,160,186,62,20,176,195,62,194,18,220,62,78,66,228,62,137,4,112,62,248,198,131,62,44,25,184,62,146,52,220,62,36,45,156,62,204,185,167,62,68,177,193,62,76,83,205,62,114,23,142,62,250,225,162,62,136,79,188,62,12,151,205,62,170,131,170,62,42,46,182,62,208,108,198,62,238,104,217,62,201,230,122,62,244,7,160,62,128,68,200,62,92,73,209,62,34,24,152,62,216,52,174,62,184,44,201,62,190,152,219,62,244,64,142,62,254,104,166,62,200,124,203,62,150,243,212,62,28,237,178,62,38,160,189,62,176,124,202,62,16,37,221,62,143,10,109,62,4,1,149,62,92,125,193,62,38,81,221,62,32,121,163,62,96,20,181,62,48,16,195,62,32,178,203,62,38,82,148,62,6,86,179,62,0,239,194,62,164,194,203,62,6,113,168,62,14,58,180,62,180,58,211,62,214,12,224,62,176,115,141,62,196,194,154,62,64,113,195,62,228,182,222,62,78,43,143,62,48,89,191,62,196,34,211,62,14,123,220,62,64,195,129,62,126,92,187,62,160,114,212,62,146,144,221,62,32,145,192,62,14,80,202,62,52,101,213,62,68,181,221,62,204,143,134,62,50,152,147,62,12,222,177,62,118,46,217,62,190,150,154,62,58,243,175,62,64,10,193,62,12,80,222,62,188,125,152,62,48,161,165,62,192,158,186,62,96,250,221,62,88,222,169,62,204,136,186,62,148,230,203,62,150,194,222,62,228,6,127,62,174,222,167,62,132,101,196,62,120,1,223,62,136,251,155,62,134,196,167,62,160,67,214,62,102,252,225,62,66,11,152,62,20,214,165,62,220,234,199,62,170,60,225,62,198,22,176,62,152,244,187,62,120,234,219,62,56,243,227,62,8,208,132,62,242,76,149,62,232,9,207,62,50,226,220,62,214,86,152,62,234,19,183,62,240,41,199,62,224,41,220,62,124,113,145,62,112,251,178,62,12,24,195,62,80,3,220,62,72,196,166,62,188,239,191,62,196,41,221,62,78,3,229,62,202,213,135,62,98,38,161,62,40,90,213,62,24,229,223,62,216,205,153,62,202,82,181,62,88,105,219,62,54,177,235,62,146,157,152,62,24,216,178,62,16,5,205,62,62,124,229,62,134,75,192,62,28,84,213,62,192,95,226,62,12,204,231,62,17,222,199,61,53,87,253,61,38,129,45,62,13,119,194,61,97,232,77,62,190,76,104,62,245,107,184,61,173,190,24,62,54,248,103,62,213,99,46,62,203,244,73,62,103,249,127,62,183,196,222,61,169,158,27,62,138,83,51,62,215,103,5,62,191,88,90,62,106,40,107,62,1,213,255,61,23,216,63,62,6,160,81,62,125,124,77,62,109,117,106,62,134,241,137,62,193,252,183,61,59,87,0,62,166,151,87,62,65,24,197,61,135,40,84,62,40,35,130,62,109,118,216,61,35,38,55,62,134,236,76,62,77,203,31,62,239,215,96,62,92,8,149,62,143,176,12,62,75,213,35,62,14,95,71,62,113,172,219,61,121,127,115,62,138,158,138,62,107,104,18,62,65,99,78,62,82,182,95,62,185,105,91,62,10,52,139,62,234,54,154,62,255,197,226,61,145,229,8,62,30,152,30,62,147,116,218,61,75,235,52,62,148,141,134,62,73,171,187,61,119,200,50,62,222,151,96,62,159,116,60,62,105,111,105,62,96,181,125,62,195,115,226,61,15,1,34,62,166,183,72,62,153,191,8,62,25,216,109,62,159,239,128,62,25,170,31,62,65,54,54,62,186,84,95,62,211,223,68,62,51,128,127,62,72,111,148,62,55,224,232,61,111,46,13,62,218,204,79,62,175,9,210,61,121,65,61,62,154,150,149,62,185,223,11,62,245,126,34,62,114,49,119,62,27,246,48,62,101,73,127,62,182,213,153,62,245,39,12,62,25,6,33,62,158,249,87,62,249,17,4,62,73,13,123,62,228,9,137,62,213,208,42,62,179,136,65,62,242,229,108,62,139,210,109,62,162,193,134,62,180,45,162,62,159,89,189,61,189,182,245,61,66,218,67,62,63,153,231,61,241,118,85,62,122,223,106,62,103,68,206,61,209,11,16,62,212,32,132,62,197,4,43,62,15,87,95,62,134,114,134,62,186,127,0,62,105,151,38,62,198,213,60,62,119,16,28,62,87,26,84,62,64,134,125,62,99,189,12,62,179,150,56,62,114,236,94,62,141,215,84,62,199,48,127,62,44,39,138,62,107,138,191,61,49,199,24,62,78,144,81,62,199,94,229,61,127,163,102,62,94,238,124,62,141,224,223,61,159,118,70,62,246,238,90,62,73,82,51,62,86,74,129,62,166,215,140,62,109,52,12,62,251,178,53,62,118,174,74,62,63,24,12,62,217,31,115,62,40,201,145,62,55,158,36,62,53,167,77,62,138,81,95,62,189,81,111,62,252,97,136,62,20,103,149,62,249,15,244,61,89,14,15,62,134,58,64,62,245,49,6,62,107,88,70,62,176,86,133,62,29,187,221,61,211,40,41,62,134,69,117,62,91,18,80,62,101,93,103,62,144,99,127,62,93,161,253,61,47,75,21,62,150,207,92,62,245,85,47,62,145,196,115,62,98,21,132,62,21,238,42,62,149,33,65,62,242,48,88,62,247,172,87,62,228,94,134,62,38,246,144,62,213,146,216,61,175,142,11,62,214,84,97,62,97,66,199,61,41,19,111,62,64,156,151,62,131,133,9,62,65,156,70,62,110,227,116,62,187,43,40,62,82,70,138,62,216,153,150,62,191,47,18,62,129,254,40,62,146,122,101,62,177,237,21,62,152,228,125,62,106,246,153,62,53,249,50,62,23,157,96,62,254,224,115,62,139,251,113,62,168,210,148,62,14,241,167,62,231,160,233,61,223,67,8,62,126,86,49,62,115,154,232,61,233,223,66,62,70,123,119,62,1,245,175,61,181,218,39,62,26,165,115,62,5,140,69,62,143,62,92,62,1,222,116,62,59,150,12,62,221,63,35,62,26,9,56,62,75,206,15,62,39,108,99,62,106,190,118,62,167,193,15,62,207,38,66,62,42,146,82,62,181,198,88,62,153,65,114,62,220,255,143,62,195,239,184,61,141,53,2,62,110,44,111,62,147,133,225,61,47,90,86,62,50,177,139,62,223,5,239,61,91,31,54,62,250,39,100,62,89,13,58,62,235,214,109,62,166,203,140,62,29,18,22,62,199,138,45,62,214,207,66,62,123,171,223,61,52,206,134,62,16,181,147,62,35,105,25,62,57,106,88,62,158,100,106,62,149,99,74,62,132,3,145,62,64,56,161,62,141,247,254,61,181,154,21,62,186,28,42,62,157,29,10,62,59,108,59,62,152,29,148,62,193,21,191,61,151,96,60,62,158,68,116,62,247,120,69,62,165,86,117,62,212,79,132,62,45,137,253,61,171,135,41,62,2,105,85,62,149,197,26,62,217,117,113,62,110,192,132,62,5,70,26,62,33,157,66,62,226,215,105,62,243,239,74,62,136,122,131,62,14,50,158,62,228,146,3,62,123,169,24,62,54,35,75,62,187,137,188,61,41,83,89,62,100,253,149,62,81,25,17,62,69,126,48,62,26,84,132,62,127,116,73,62,7,57,107,62,128,112,151,62,123,151,22,62,221,248,44,62,34,87,84,62,209,148,11,62,158,79,133,62,234,177,144,62,213,98,57,62,131,171,78,62,178,153,116,62,207,54,123,62,40,116,143,62,122,184,159,62,9,67,213,61,207,59,8,62,6,100,66,62,189,131,252,61,233,166,86,62,191,194,125,62,23,9,254,61,201,169,35,62,200,136,132,62,189,137,63,62,123,150,89,62,28,238,132,62,145,121,254,61,125,240,49,62,122,122,69,62,91,187,34,62,151,204,102,62,164,31,121,62,111,26,29,62,35,105,68,62,130,69,86,62,45,155,104,62,209,154,128,62,70,146,139,62,209,30,225,61,229,222,32,62,58,78,97,62,25,248,7,62,207,192,96,62,4,184,136,62,239,230,1,62,191,155,75,62,166,40,95,62,77,2,68,62,192,61,129,62,36,153,139,62,25,1,31,62,31,226,55,62,154,151,77,62,223,188,240,61,153,209,125,62,202,214,157,62,23,175,41,62,61,99,87,62,58,179,106,62,145,28,103,62,226,161,145,62,94,204,159,62,123,156,4,62,109,251,23,62,54,129,56,62,113,119,30,62,147,126,74,62,70,216,136,62,41,173,3,62,27,104,52,62,226,169,117,62,195,21,92,62,113,86,115,62,166,128,132,62,237,102,3,62,163,41,35,62,206,16,104,62,73,124,31,62,177,175,125,62,236,37,140,62,161,245,51,62,5,180,74,62,238,95,96,62,151,223,95,62,103,181,123,62,120,216,153,62,109,17,241,61,83,1,21,62,238,193,115,62,153,173,241,61,105,37,101,62,30,158,150,62,73,251,26,62,113,172,64,62,143,182,126,62,15,219,65,62,118,6,138,62,30,107,150,62,59,126,25,62,229,185,50,62,218,32,115,62,81,33,15,62,126,29,139,62,36,157,157,62,69,92,60,62,207,179,84,62,218,41,104,62,169,84,130,62,82,225,151,62,96,76,166,62,10,142,93,60,55,41,149,60,173,91,33,61,45,235,187,60,81,145,18,61,65,195,215,61,207,76,171,60,199,42,249,60,66,20,183,61,23,193,154,60,85,195,28,61,203,32,13,62,199,13,168,60,189,221,233,60,216,128,151,61,186,79,64,61,249,22,140,61,78,124,223,61,146,64,1,61,167,30,105,61,128,134,175,61,210,33,28,61,81,74,159,61,85,39,69,62,205,48,177,60,117,243,239,60,52,2,128,61,65,28,255,60,5,98,117,61,159,168,210,61,158,13,248,60,29,36,91,61,0,239,159,61,22,75,133,61,63,173,185,61,133,71,18,62,32,20,6,61,37,115,78,61,61,78,128,61,20,10,88,61,165,1,127,61,31,67,250,61,144,226,14,61,243,134,131,61,18,154,187,61,188,73,72,61,169,40,215,61,111,221,44,62,249,40,193,60,237,126,3,61,149,190,101,61,33,32,227,60,51,151,71,61,161,78,207,61,243,190,224,60,193,223,37,61,14,121,191,61,98,141,51,61,136,24,119,61,249,14,28,62,83,92,220,60,173,130,57,61,65,20,133,61,180,96,83,61,39,42,121,61,88,210,222,61,0,15,44,61,156,156,122,61,12,255,174,61,23,32,146,61,193,214,208,61,23,213,50,62,31,172,236,60,79,143,41,61,141,107], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1486338);
/* memory initializer */ allocate([87,61,56,149,1,61,49,228,135,61,234,229,255,61,32,63,48,61,63,139,82,61,88,51,163,61,160,222,105,61,39,24,222,61,143,136,19,62,250,201,10,61,139,190,78,61,186,116,149,61,93,254,133,61,137,254,161,61,70,176,236,61,150,222,29,61,227,36,150,61,154,134,209,61,243,184,134,61,97,194,210,61,157,245,88,62,146,129,125,60,71,147,167,60,247,176,95,61,159,188,186,60,133,34,32,61,247,158,244,61,83,103,251,60,255,45,58,61,148,5,168,61,171,26,185,60,117,61,68,61,251,247,47,62,71,19,222,60,115,141,36,61,249,192,143,61,72,19,75,61,29,102,162,61,40,194,214,61,244,192,250,60,235,9,103,61,142,121,194,61,162,227,129,61,1,181,186,61,101,40,61,62,153,88,199,60,1,144,32,61,223,79,129,61,32,115,10,61,99,87,135,61,129,100,227,61,60,23,16,61,53,82,109,61,150,153,147,61,32,237,132,61,135,82,177,61,61,92,30,62,35,39,239,60,249,111,83,61,132,56,142,61,60,132,115,61,201,107,147,61,49,126,2,62,142,220,89,61,31,179,130,61,28,99,202,61,116,211,177,61,201,133,16,62,119,84,68,62,241,202,204,60,193,128,20,61,75,83,78,61,91,55,231,60,139,14,95,61,31,188,230,61,68,135,20,61,81,9,60,61,96,50,193,61,148,168,105,61,163,215,152,61,25,250,34,62,159,161,223,60,177,8,59,61,58,30,154,61,74,17,82,61,145,79,174,61,177,27,253,61,122,76,73,61,55,23,115,61,82,247,188,61,42,201,144,61,53,247,215,61,127,57,69,62,35,250,229,60,223,107,43,61,43,128,112,61,2,61,62,61,95,187,144,61,56,16,1,62,14,102,43,61,126,29,129,61,94,233,156,61,226,134,172,61,219,0,232,61,183,34,19,62,44,14,43,61,253,40,101,61,200,97,145,61,228,100,99,61,1,150,194,61,235,202,2,62,20,12,114,61,223,225,150,61,220,210,197,61,88,151,160,61,165,211,16,62,157,165,94,62,17,111,172,60,253,29,239,60,63,110,60,61,176,114,21,61,203,100,61,61,249,57,219,61,111,20,220,60,125,242,32,61,14,70,172,61,27,144,223,60,171,214,98,61,247,251,16,62,87,141,203,60,109,204,20,61,86,37,156,61,106,55,87,61,37,225,158,61,156,162,234,61,202,2,39,61,29,39,93,61,128,226,185,61,242,183,106,61,35,214,156,61,141,227,55,62,189,140,201,60,67,215,11,61,172,14,139,61,250,52,39,61,207,250,128,61,175,208,203,61,22,227,28,61,79,115,98,61,196,203,161,61,73,76,148,61,249,178,208,61,213,129,22,62,124,38,25,61,183,179,64,61,83,20,134,61,164,5,88,61,139,200,137,61,99,8,15,62,164,9,38,61,145,102,144,61,178,147,189,61,130,160,53,61,47,8,226,61,115,109,76,62,193,212,208,60,235,96,14,61,111,45,120,61,222,93,50,61,253,14,90,61,1,218,221,61,85,12,229,60,35,63,73,61,250,25,181,61,134,0,76,61,253,147,180,61,121,66,28,62,226,205,2,61,247,77,61,61,141,84,140,61,60,171,109,61,99,35,140,61,213,177,235,61,52,186,49,61,13,110,141,61,132,13,173,61,36,125,151,61,95,52,244,61,171,152,53,62,50,145,2,61,197,74,60,61,159,113,106,61,140,173,56,61,208,10,104,61,137,44,7,62,208,11,60,61,65,120,95,61,100,107,176,61,251,130,152,61,13,24,233,61,195,114,37,62,230,209,34,61,53,230,74,61,6,250,147,61,98,127,138,61,219,49,170,61,215,15,3,62,10,9,108,61,33,103,142,61,10,17,215,61,42,90,140,61,177,92,249,61,237,235,97,62,173,250,178,60,77,12,245,60,85,112,83,61,38,60,21,61,115,112,73,61,195,120,252,61,180,149,31,61,205,58,67,61,196,122,176,61,166,213,41,61,97,231,140,61,179,107,45,62,66,109,9,61,25,35,43,61,98,248,150,61,248,168,109,61,135,61,178,61,74,65,231,61,36,181,68,61,253,66,105,61,2,89,206,61,102,76,117,61,227,180,175,61,225,56,78,62,219,49,245,60,195,184,33,61,185,96,132,61,116,46,31,61,77,93,165,61,163,149,236,61,220,33,15,61,13,205,128,61,62,220,164,61,229,17,141,61,249,63,203,61,33,62,36,62,22,49,21,61,175,187,90,61,68,63,137,61,166,255,110,61,151,211,160,61,13,38,17,62,10,66,71,61,241,213,148,61,16,55,194,61,166,213,111,61,138,143,11,62,55,104,75,62,73,184,213,60,139,242,24,61,37,127,100,61,172,205,59,61,255,149,101,61,43,132,241,61,20,163,47,61,79,214,82,61,72,190,199,61,54,149,130,61,85,231,178,61,253,95,44,62,230,76,26,61,111,175,59,61,186,20,161,61,164,71,138,61,167,13,184,61,124,145,244,61,126,203,95,61,213,143,136,61,150,13,183,61,0,84,158,61,97,90,249,61,127,94,76,62,75,71,1,61,105,4,57,61,75,40,128,61,62,38,27,61,213,141,164,61,249,75,14,62,118,51,80,61,167,111,125,61,102,56,170,61,136,144,183,61,7,216,3,62,87,217,40,62,112,242,65,61,19,209,107,61,232,185,156,61,34,210,146,61,11,187,202,61,67,51,5,62,11,214,128,61,149,243,161,61,120,68,215,61,106,91,180,61,206,43,41,62,209,84,90,62,2,2,3,3,0,0,0,0,248,250,22,0,248,248,22,0,248,224,22,0,248,218,22,0,112,15,142,62,42,74,162,62,194,126,202,62,166,81,172,62,126,102,184,62,110,80,195,62,20,251,158,62,212,216,169,62,166,213,187,62,254,200,172,62,192,40,203,62,94,32,211,62,166,47,143,62,134,168,187,62,206,71,197,62,220,207,161,62,150,110,197,62,210,119,205,62,34,179,158,62,136,211,175,62,62,120,217,62,108,95,181,62,8,65,209,62,102,38,216,62,54,87,151,62,30,224,170,62,34,92,198,62,124,185,170,62,142,33,198,62,38,126,205,62,94,150,165,62,160,4,187,62,14,56,197,62,144,122,175,62,64,111,206,62,206,255,214,62,80,44,142,62,98,214,195,62,6,253,206,62,102,241,162,62,150,190,202,62,82,218,220,62,16,128,155,62,68,185,194,62,54,213,223,62,18,175,193,62,112,108,208,62,102,105,216,62,208,212,115,62,44,86,175,62,106,104,217,62,138,244,176,62,196,195,188,62,238,55,205,62,4,168,162,62,222,13,175,62,10,171,207,62,182,148,187,62,62,48,199,62,122,243,207,62,178,74,153,62,48,60,180,62,254,198,204,62,88,101,166,62,220,177,199,62,234,197,214,62,162,99,165,62,122,121,188,62,114,222,205,62,212,130,185,62,150,119,213,62,130,148,221,62,222,158,139,62,184,233,183,62,26,144,218,62,172,109,177,62,100,62,189,62,78,204,212,62,90,16,171,62,18,35,182,62,194,34,203,62,188,200,172,62,254,30,210,62,242,26,218,62,0,84,153,62,84,228,194,62,86,41,214,62,174,139,164,62,140,136,210,62,178,138,219,62,204,218,167,62,206,26,189,62,26,105,222,62,14,231,194,62,254,39,218,62,186,176,226,62,252,178,137,62,56,150,175,62,250,31,204,62,210,27,173,62,124,175,192,62,226,185,200,62,12,174,165,62,82,142,178,62,34,191,190,62,46,242,177,62,70,40,201,62,150,163,215,62,218,189,155,62,228,57,184,62,114,101,195,62,160,225,160,62,44,225,205,62,106,21,215,62,218,68,154,62,238,174,185,62,86,200,219,62,172,88,190,62,238,33,204,62,146,229,220,62,58,151,140,62,44,211,171,62,174,20,215,62,168,103,176,62,76,233,199,62,62,21,208,62,214,133,166,62,94,182,193,62,158,18,202,62,56,159,182,62,86,249,199,62,186,33,222,62,164,233,134,62,136,95,202,62,182,162,216,62,130,207,172,62,20,254,200,62,102,7,227,62,16,9,161,62,82,14,195,62,10,105,216,62,226,161,192,62,46,168,213,62,46,231,220,62,220,17,134,62,46,191,188,62,62,251,206,62,154,14,182,62,126,136,193,62,62,175,202,62,232,205,167,62,208,46,181,62,234,115,210,62,250,213,185,62,240,134,204,62,70,82,212,62,26,107,158,62,50,98,191,62,94,12,201,62,248,122,169,62,222,53,205,62,142,15,221,62,94,171,165,62,180,187,188,62,174,188,213,62,80,191,178,62,200,138,218,62,178,72,227,62,158,88,148,62,170,62,186,62,154,46,210,62,28,232,181,62,110,86,199,62,106,173,211,62,94,82,172,62,20,111,184,62,254,45,217,62,168,11,174,62,112,134,209,62,234,95,225,62,56,14,154,62,110,215,204,62,74,254,213,62,166,84,162,62,38,54,216,62,234,107,226,62,176,152,167,62,128,196,196,62,202,78,220,62,138,72,204,62,56,231,219,62,46,15,227,62,185,22,127,62,190,193,166,62,12,206,210,62,162,29,177,62,50,182,188,62,248,229,198,62,84,94,160,62,124,175,173,62,60,115,198,62,198,241,179,62,96,38,204,62,172,71,211,62,242,67,150,62,6,100,192,62,88,250,201,62,8,33,166,62,246,212,201,62,20,89,209,62,162,27,160,62,28,39,183,62,212,255,211,62,212,166,187,62,212,251,208,62,76,8,217,62,26,149,153,62,10,251,169,62,12,211,208,62,80,123,171,62,138,180,197,62,32,181,210,62,86,105,171,62,16,126,187,62,204,100,201,62,32,25,178,62,152,213,207,62,116,107,220,62,108,104,146,62,146,98,202,62,152,13,213,62,242,209,165,62,182,29,208,62,28,141,226,62,176,40,162,62,216,214,196,62,124,250,224,62,26,7,198,62,172,218,210,62,188,12,219,62,64,201,115,62,240,132,185,62,20,163,220,62,230,97,177,62,40,23,194,62,168,41,208,62,84,22,162,62,14,131,182,62,32,221,202,62,6,171,187,62,118,120,199,62,152,148,215,62,94,216,157,62,56,30,190,62,0,212,208,62,60,65,172,62,148,116,200,62,116,144,216,62,234,100,165,62,254,201,194,62,144,176,209,62,44,255,186,62,18,23,219,62,128,43,227,62,146,72,139,62,76,209,192,62,20,12,222,62,248,31,183,62,248,105,193,62,232,127,209,62,138,73,172,62,130,122,186,62,240,137,209,62,220,55,178,62,214,211,213,62,120,215,221,62,164,2,155,62,52,189,202,62,48,16,222,62,122,209,169,62,252,205,213,62,212,90,223,62,172,164,170,62,26,248,194,62,248,21,225,62,158,182,198,62,194,181,223,62,24,211,230,62,236,21,131,62,12,47,178,62,80,137,216,62,74,9,177,62,144,113,195,62,152,40,203,62,40,184,166,62,146,102,179,62,52,80,198,62,106,183,182,62,254,17,204,62,176,170,216,62,82,58,154,62,172,24,198,62,0,130,206,62,0,7,168,62,196,222,205,62,48,186,214,62,30,247,160,62,82,243,188,62,112,102,222,62,224,160,190,62,186,198,210,62,172,139,225,62,194,185,148,62,8,61,178,62,12,57,218,62,72,90,176,62,216,236,195,62,28,171,213,62,170,115,171,62,246,161,192,62,96,23,207,62,44,210,183,62,182,55,207,62,36,163,222,62,220,233,142,62,144,124,210,62,148,231,222,62,130,61,178,62,156,38,204,62,172,211,228,62,4,111,167,62,38,188,199,62,124,39,226,62,150,30,200,62,218,241,214,62,112,204,222,62,54,185,130,62,218,165,189,62,212,71,221,62,242,148,181,62,138,211,198,62,68,80,206,62,212,169,164,62,176,127,181,62,28,74,219,62,110,21,192,62,248,51,204,62,16,15,212,62,98,184,159,62,154,105,200,62,20,58,211,62,240,95,175,62,102,240,202,62,76,112,221,62,138,224,170,62,112,186,192,62,160,80,215,62,196,1,181,62,44,196,219,62,180,93,235,62,22,119,147,62,54,137,193,62,200,54,222,62,36,28,182,62,154,245,194,62,136,166,216,62,186,79,176,62,4,143,190,62,208,206,220,62,12,59,181,62,168,13,212,62,52,201,226,62,216,10,156,62,126,53,211,62,64,77,222,62,214,252,171,62,246,99,217,62,184,139,228,62,116,254,175,62,20,0,197,62,228,219,222,62,230,102,210,62,148,158,225,62,104,123,231,62,51,179,11,62,18,179,44,62,202,153,81,62,195,44,62,62,14,63,106,62,165,0,129,62,178,105,251,61,220,105,62,62,163,19,143,62,7,47,73,62,129,106,135,62,155,33,148,62,96,171,0,62,88,36,26,62,201,98,141,62,71,3,73,62,52,128,119,62,249,146,147,62,55,118,15,62,206,179,99,62,25,161,140,62,120,24,133,62,145,0,141,62,61,56,159,62,75,65,34,62,0,30,65,62,186,80,84,62,159,79,72,62,80,177,98,62,171,244,146,62,163,125,45,62,18,116,78,62,131,36,141,62,191,125,89,62,221,75,135,62,163,204,162,62,51,91,59,62,50,86,76,62,59,12,107,62,147,93,92,62,135,90,134,62,5,155,144,62,19,235,21,62,104,167,114,62,173,131,148,62,13,58,123,62,193,81,155,62,185,60,175,62,73,199,12,62,64,19,34,62,92,245,116,62,213,216,78,62,148,98,97,62,13,2,138,62,128,97,242,61,58,187,107,62,25,46,145,62,133,238,102,62,65,103,139,62,153,181,156,62,213,234,10,62,178,59,68,62,159,37,136,62,65,110,72,62,14,126,109,62,231,245,160,62,237,7,44,62,216,43,105,62,27,204,141,62,91,22,128,62,221,110,154,62,39,101,164,62,53,178,8,62,110,13,78,62,232,129,111,62,145,101,83,62,222,110,116,62,93,28,142,62,145,88,55,62,168,121,72,62,57,178,143,62,109,36,83,62,69,50,135,62,225,139,170,62,197,99,51,62,28,193,67,62,83,220,131,62,85,225,105,62,12,47,123,62,187,50,158,62,81,51,57,62,202,108,121,62,7,224,151,62,236,99,141,62,189,211,157,62,187,146,177,62,17,104,12,62,16,97,56,62,160,65,98,62,21,185,57,62,108,54,104,62,233,112,138,62,159,64,0,62,226,234,55,62,169,233,158,62,13,73,67,62,231,81,147,62,245,127,160,62,37,158,5,62,38,73,36,62,139,185,153,62,229,13,74,62,11,68,131,62,47,148,142,62,69,103,34,62,28,20,115,62,47,156,134,62,12,14,134,62,243,48,142,62,239,170,169,62,193,25,40,62,62,77,62,62,72,69,113,62,137,131,86,62,134,196,98,62,49,149,149,62,173,207,42,62,232,196,90,62,9,150,138,62,173,89,107,62,215,165,147,62,69,203,156,62,165,134,58,62,104,164,77,62,246,238,117,62,233,87,102,62,13,37,138,62,139,50,149,62,9,224,39,62,183,44,128,62,91,126,142,62,218,113,131,62,215,23,151,62,91,227,180,62,135,149,15,62,158,237,52,62,34,178,124,62,83,117,92,62,154,183,106,62,47,80,135,62,62,208,247,61,232,146,95,62,235,9,165,62,42,44,130,62,235,71,140,62,183,175,151,62,19,60,36,62,88,44,60,62,181,45,144,62,19,87,64,62,82,30,115,62,153,216,168,62,39,14,54,62,246,36,104,62,5,202,154,62,252,218,140,62,219,99,150,62,117,239,159,62,255,50,46,62,124,173,61,62,51,8,124,62,175,19,99,62,142,171,117,62,127,227,146,62,7,196,71,62,134,86,85,62,147,162,147,62,199,60,115,62,99,205,140,62,111,248,173,62,227,227,64,62,218,70,81,62,169,198,131,62,37,47,125,62,13,103,133,62,197,177,154,62,107,243,42,62,152,214,124,62,33,70,163,62,144,101,142,62,255,66,160,62,113,12,187,62,219,178,20,62,246,246,38,62,126,79,102,62,15,161,82,62,166,33,98,62,86,113,129,62,187,16,248,61,76,22,73,62,175,169,153,62,139,189,92,62,61,4,136,62,31,49,153,62,194,129,223,61,100,193,54,62,25,159,147,62,139,100,80,62,196,29,118,62,233,181,151,62,183,198,28,62,70,211,102,62,9,215,145,62,153,30,128,62,137,51,142,62,133,81,166,62,227,76,42,62,100,213,70,62,242,182,88,62,211,30,78,62,216,124,103,62,103,36,150,62,115,27,25,62,178,87,91,62,167,90,145,62,3,41,99,62,221,9,146,62,223,225,163,62,123,31,66,62,22,137,83,62,62,220,107,62,47,204,108,62,252,201,124,62,197,102,148,62,171,116,14,62,139,180,132,62,5,150,152,62,129,97,122,62,77,186,144,62,217,246,184,62,132,241,250,61,36,143,44,62,177,176,138,62,29,71,81,62,140,237,107,62,113,40,139,62,65,17,18,62,74,190,99,62,133,136,149,62,149,119,120,62,57,11,142,62,37,34,152,62,161,178,27,62,174,165,73,62,135,163,133,62,161,26,95,62,148,189,123,62,87,196,157,62,1,172,66,62,64,165,108,62,131,115,143,62,120,53,130,62,161,145,150,62,127,230,173,62,153,117,32,62,146,154,85,62,168,123,105,62,169,125,102,62,230,1,128,62,169,112,141,62,13,127,54,62,88,252,74,62,245,191,155,62,165,146,85,62,217,180,149,62,13,142,177,62,73,40,47,62,64,82,80,62,81,121,134,62,85,205,107,62,187,131,132,62,179,188,159,62,21,200,61,62,144,168,123,62,239,0,159,62,14,46,148,62,237,71,159,62,83,101,177,62,189,240,25,62,36,143,43,62,126,242,117,62,125,74,56,62,84,220,114,62,165,148,133,62,133,118,25,62,178,163,74,62,61,167,157,62,221,219,87,62,87,140,147,62,161,212,168,62,73,223,6,62,98,227,41,62,227,82,165,62,237,252,91,62,231,113,129,62,23,88,152,62,177,43,60,62,100,57,115,62,175,153,140,62,192,218,130,62,95,6,141,62,199,41,177,62,205,11,59,62,26,66,76,62,165,60,93,62,25,67,86,62,150,190,99,62,237,209,154,62,161,129,60,62,80,102,88,62,213,168,144,62,141,245,118,62,27,21,152,62,9,200,161,62,41,135,73,62,68,230,88,62,125,114,119,62,153,150,120,62,117,101,132,62,227,30,150,62,29,184,34,62,45,184,135,62,83,107,148,62,132,32,132,62,71,71,163,62,251,24,178,62,55,86,24,62,194,219,42,62,155,157,136,62,247,31,93,62,242,116,107,62,83,85,141,62,123,187,13,62,184,6,117,62,255,235,167,62,155,157,121,62,71,170,147,62,107,178,156,62,171,61,46,62,196,139,66,62,245,251,143,62,55,96,96,62,69,25,132,62,113,52,167,62,135,198,68,62,30,251,100,62,253,236,152,62,38,14,140,62,179,200,159,62,61,90,169,62,215,89,38,62,104,217,81,62,123,181,129,62,83,58,101,62,12,96,115,62,75,61,155,62,55,156,70,62,126,110,89,62,103,121,157,62,59,110,107,62,139,92,152,62,179,204,172,62,35,225,65,62,54,12,81,62,241,165,142,62,109,30,120,62,9,220,139,62,21,119,161,62,219,186,30,62,53,129,147,62,185,7,172,62,134,36,140,62,19,149,169,62,185,158,185,62,245,11,28,62,18,195,48,62,228,40,67,62,75,183,73,62,190,189,103,62,50,27,124,62,158,229,246,61,152,82,83,62,107,249,143,62,195,91,70,62,139,54,139,62,79,72,154,62,99,251,11,62,152,202,29,62,43,132,144,62,203,8,74,62,61,223,129,62,45,164,148,62,43,232,18,62,210,185,121,62,193,18,141,62,34,87,132,62,87,235,139,62,185,105,164,62,167,28,30,62,208,113,70,62,188,16,93,62,71,236,82,62,224,168,101,62,131,75,146,62,99,185,50,62,102,124,85,62,183,48,143,62,203,24,96,62,83,131,139,62,19,121,167,62,83,223,53,62,26,26,90,62,200,219,116,62,231,169,106,62,101,177,132,62,213,40,145,62,47,33,33,62,106,184,117,62,97,200,155,62,49,130,123,62,211,54,162,62,209,145,175,62,85,98,18,62,132,202,37,62,79,230,129,62,201,60,87,62,48,50,100,62,29,206,138,62,97,227,1,62,250,232,93,62,173,112,152,62,77,139,108,62,119,106,143,62,65,115,153,62,233,166,28,62,30,167,70,62,251,184,139,62,41,248,89,62,170,87,119,62,191,14,162,62,45,67,47,62,24,207,99,62,47,107,150,62,154,4,129,62,79,199,155,62,55,156,169,62,173,98,8,62,74,234,84,62,210,190,130,62,77,34,89,62,144,0,120,62,49,235,147,62,13,11,61,62,152,248,77,62,225,157,146,62,141,134,95,62,127,178,141,62,253,108,176,62,185,247,59,62,24,68,76,62,99,57,134,62,197,185,110,62,85,150,127,62,39,182,161,62,225,116,66,62,196,204,124,62,191,33,152,62,190,207,140,62,115,29,165,62,15,167,177,62,125,184,17,62,80,80,69,62,246,87,93,62,85,95,72,62,100,154,99,62,221,156,141,62,117,112,8,62,238,137,74,62,225,82,165,62,73,77,61,62,77,30,152,62,65,247,166,62,253,206,25,62,38,6,53,62,59,68,149,62,25,5,80,62,105,236,132,62,251,42,153,62,241,117,41,62,240,15,116,62,103,50,147,62,218,201,138,62,45,63,148,62,67,152,163,62,13,165,44,62,238,152,75,62,62,224,107,62,113,241,90,62,94,25,112,62,169,248,148,62,197,203,50,62,92,120,94,62,181,69,146,62,209,252,105,62,65,166,151,62,213,16,162,62,45,170,63,62,48,215,97,62,246,112,117,62,197,96,106,62,95,244,134,62,219,71,154,62,165,42,54,62,207,41,132,62,39,31,144,62,248,222,132,62,229,73,157,62,19,149,178,62,183,181,20,62,82,1,55,62,40,180,132,62,223,81,96,62,222,240,115,62,55,91,133,62,55,25,19,62,136,203,86,62,127,180,161,62,181,16,128,62,253,240,142,62,23,61,156,62,231,143,24,62,100,14,78,62,145,169,144,62,155,99,85,62,38,66,113,62,137,211,176,62,79,74,62,62,6,237,98,62,185,29,159,62,190,210,143,62,209,71,151,62,221,167,166,62,87,30,49,62,216,206,73,62,73,179,123,62,123,195,96,62,58,164,122,62,35,81,150,62,203,82,60,62,22,42,92,62,115,197,153,62,13,58,123,62,81,133,137,62,91,88,178,62,159,150,69,62,134,149,83,62,81,224,136,62,30,123,130,62,123,139,137,62,161,106,155,62,251,24,53,62,7,199,132,62,17,229,161,62,170,244,148,62,225,154,161,62,85,201,188,62,71,227,32,62,218,183,49,62,232,57,106,62,7,156,89,62,130,8,108,62,183,34,129,62,63,241,17,62,212,211,78,62,179,5,150,62,231,19,92,62,139,94,142,62,175,219,160,62,195,53,11,62,184,102,57,62,29,11,141,62,191,45,75,62,86,121,119,62,177,63,156,62,131,88,35,62,86,35,109,62,77,64,151,62,68,51,132,62,75,31,147,62,45,5,164,62,111,9,51,62,48,131,69,62,236,81,88,62,67,5,79,62,108,121,104,62,195,25,156,62,211,153,45,62,250,232,88,62,247,62,152,62,247,141,107,62,15,64,149,62,187,54,167,62,43,186,71,62,74,202,88,62,178,43,105,62,27,163,115,62,25,60,129,62,249,114,152,62,7,116,29,62,100,117,124,62,101,41,161,62,213,189,113,62,99,109,155,62,125,194,189,62,249,252,13,62,20,251,43,62,49,10,140,62,1,240,90,62,188,184,104,62,205,146,146,62,35,21,0,62,238,244,121,62,173,231,154,62,61,95,113,62,155,250,143,62,161,40,158,62,253,84,27,62,86,240,87,62,127,18,135,62,41,7,98,62,27,108,129,62,251,0,162,62,233,92,61,62,196,43,117,62,91,251,145,62,140,227,132,62,103,159,158,62,3,33,167,62,81,215,38,62,178,45,97,62,242,208,113,62,157,208,111,62,104,241,127,62,233,26,142,62,153,248,46,62,244,12,75,62,49,144,164,62,221,31,109,62,199,206,140,62,173,74,189,62,141,82,56,62,112,169,83,62,95,219,138,62,1,202,115,62,27,13,130,62,187,204,165,62,133,237,75,62,49,48,130,62,251,109,157,62,216,41,147,62,79,108,166,62,59,128,178,62,153,197,20,62,168,243,67,62,26,175,127,62,197,84,71,62,216,153,118,62,157,250,141,62,157,211,28,62,106,10,71,62,177,180,167,62,225,251,80,62,137,225,152,62,9,153,164,62,1,193,31,62,102,91,57,62,183,19,154,62,137,6,88,62,83,244,130,62,119,189,157,62,13,229,61,62,114,255,126,62,163,77,140,62,104,138,140,62,189,49,148,62,135,118,173,62,65,48,53,62,246,36,71,62,57,104,99,62,17,146,93,62,0,70,108,62,41,125,155,62,97,60,66,62,8,208,91,62,29,175,147,62,113,155,118,62,9,166,152,62,37,158,167,62,121,161,78,62,88,181,96,62,65,18,117,62,181,200,126,62,147,31,136,62,55,54,150,62,129,101,58,62,223,91,137,62,11,134,150,62,202,83,131,62,1,213,163,62,255,174,185,62,71,156,34,62,226,164,51,62,83,231,136,62,59,164,101,62,42,89,114,62,183,38,142,62,199,200,24,62,252,5,104,62,87,197,176,62,244,85,128,62,189,163,149,62,207,140,160,62,255,227,33,62,188,11,79,62,189,240,152,62,7,80,106,62,209,133,126,62,253,127,176,62,191,123,64,62,98,186,111,62,197,196,155,62,166,65,146,62,181,55,161,62,73,130,172,62,151,149,38,62,56,12,95,62,193,206,131,62,79,109,101,62,93,169,124,62,235,1,154,62,227,47,78,62,138,134,95,62,75,70,160,62,191,189,115,62,5,161,152,62,115,254,180,62,23,154,75,62,118,252,89,62,37,196,139,62,206,80,128,62,187,10,137,62,61,39,164,62,227,0,47,62,171,229,137,62,45,58,171,62,128,39,156,62,249,33,172,62,33,0,187,62,193,42,23,62,148,159,57,62,244,158,81,62,193,102,70,62,0,71,98,62,101,7,134,62,141,66,7,62,46,135,71,62,39,45,145,62,165,185,84,62,171,139,138,62,187,163,149,62,141,204,2,62,202,230,42,62,53,90,145,62,161,60,82,62,66,193,125,62,81,56,145,62,185,233,29,62,24,106,102,62,49,72,138,62,122,255,136,62,103,160,145,62,33,97,158,62,53,230,44,62,30,126,63,62,164,74,79,62,185,76,79,62,70,239,93,62,123,14,150,62,85,140,39,62,144,202,92,62,59,202,144,62,233,235,102,62,63,86,136,62,7,194,162,62,33,166,65,62,72,139,82,62,190,113,99,62,201,140,98,62,149,68,133,62,241,199,149,62,1,76,31,62,118,198,124,62,217,76,148,62,47,94,126,62,55,79,156,62,17,236,181,62,79,44,2,62,214,216,33,62,213,33,130,62,55,235,81,62,138,190,96,62,217,130,142,62,103,128,8,62,240,31,107,62,189,234,146,62,175,117,114,62,147,44,137,62,113,208,157,62,235,59,16,62,240,75,80,62,91,232,139,62,47,171,84,62,4,38,112,62,199,47,166,62,27,111,53,62,14,27,107,62,11,44,145,62,98,211,133,62,171,49,154,62,203,182,164,62,123,41,24,62,48,194,84,62,114,223,124,62,151,122,91,62,200,3,126,62,141,101,139,62,7,157,52,62,154,159,73,62,161,166,149,62,59,243,74,62,39,12,141,62,13,181,178,62,127,97,52,62,14,227,69,62,67,2,138,62,231,167,114,62,160,8,128,62,159,23,157,62,67,73,52,62,56,17,130,62,27,109,155,62,52,223,144,62,243,128,154,62,195,57,181,62,155,215,20,62,78,22,60,62,82,98,112,62,175,126,70,62,186,43,108,62,105,31,137,62,67,75,14,62,56,62,63,62,97,80,160,62,63,190,76,62,213,36,142,62,121,108,166,62,179,101,18,62,28,108,47,62,147,36,155,62,59,186,84,62,63,115,132,62,67,217,147,62,75,230,47,62,18,3,118,62,243,235,139,62,160,198,138,62,237,1,146,62,31,161,167,62,95,238,45,62,0,12,64,62,82,223,101,62,39,99,92,62,192,203,104,62,101,11,151,62,155,207,51,62,194,42,95,62,5,189,140,62,35,76,112,62,101,61,148,62,141,11,162,62,119,129,66,62,106,223,81,62,209,225,124,62,51,254,114,62,207,96,137,62,147,212,148,62,211,10,46,62,98,185,129,62,227,198,149,62,238,147,138,62,137,35,152,62,191,93,182,62,93,51,28,62,232,56,46,62,105,98,129,62,201,96,96,62,244,143,113,62,63,27,138,62,217,168,17,62,202,107,95,62,51,12,168,62,196,223,133,62,97,89,142,62,3,209,154,62,237,53,29,62,34,78,67,62,157,236,149,62,69,67,86,62,217,205,127,62,69,64,166,62,113,97,51,62,208,95,116,62,129,223,156,62,88,227,139,62,253,159,155,62,101,26,164,62,113,216,39,62,138,41,66,62,39,54,131,62,145,102,104,62,20,226,117,62,131,224,149,62,97,66,72,62,12,11,89,62,127,65,152,62,165,212,118,62,225,181,147,62,95,54,172,62,137,160,71,62,176,128,86,62,5,59,131,62,120,213,125,62,167,214,134,62,229,94,159,62,17,64,45,62,124,134,113,62,225,40,172,62,204,110,146,62,241,157,166,62,117,30,184,62,65,2,32,62,36,242,52,62,244,137,91,62,69,3,86,62,12,88,101,62,243,146,133,62,21,6,11,62,74,119,80,62,235,106,156,62,105,55,96,62,215,21,143,62,159,81,153,62,69,72,9,62,178,156,54,62,29,145,148,62,229,106,90,62,210,202,117,62,241,198,153,62,129,81,40,62,140,223,103,62,25,8,147,62,241,96,128,62,167,198,143,62,233,178,171,62,189,147,39,62,174,214,73,62,32,121,98,62,141,34,85,62,34,105,108,62,71,159,151,62,141,238,34,62,252,108,95,62,247,79,151,62,5,164,117,62,47,76,144,62,115,239,166,62,177,240,65,62,72,31,85,62,76,43,116,62,109,150,110,62,191,234,132,62,49,60,150,62,137,105,36,62,247,164,130,62,41,18,155,62,248,203,129,62,11,145,151,62,1,70,188,62,83,63,5,62,254,8,51,62,109,94,133,62,183,63,87,62,46,45,111,62,125,237,144,62,179,5,28,62,52,191,102,62,81,129,155,62,255,84,118,62,35,236,141,62,221,157,156,62,135,168,39,62,64,116,71,62,155,219,137,62,95,32,103,62,50,175,118,62,215,216,162,62,23,170,68,62,218,95,107,62,43,100,148,62,112,136,134,62,47,204,155,62,83,222,171,62,143,14,42,62,104,200,83,62,47,119,117,62,31,74,101,62,2,14,128,62,89,18,146,62,139,236,64,62,78,175,80,62,53,40,155,62,91,60,108,62,115,247,146,62,89,25,179,62,219,100,58,62,22,54,91,62,139,229,134,62,47,254,114,62,105,177,135,62,183,184,162,62,71,210,65,62,185,129,132,62,107,23,156,62,62,48,152,62,227,97,162,62,43,146,182,62,255,105,34,62,150,242,54,62,182,185,119,62,143,144,71,62,30,127,119,62,5,60,134,62,95,235,33,62,204,213,88,62,141,105,159,62,191,27,94,62,229,251,152,62,85,89,164,62,247,218,24,62,204,41,51,62,131,115,161,62,243,240,98,62,231,41,131,62,43,153,155,62,255,51,52,62,126,89,121,62,155,84,146,62,100,120,135,62,129,50,146,62,247,177,176,62,219,117,56,62,192,52,82,62,19,151,99,62,247,218,87,62,60,191,103,62,145,252,160,62,103,115,55,62,94,119,86,62,233,40,150,62,88,182,127,62,185,31,149,62,209,129,167,62,19,120,75,62,10,20,93,62,146,245,127,62,251,128,118,62,111,155,135,62,91,106,153,62,23,92,47,62,19,77,137,62,227,109,155,62,48,3,138,62,241,215,161,62,111,144,182,62,165,45,26,62,136,156,60,62,191,143,137,62,213,37,94,62,240,151,118,62,131,209,142,62,41,166,10,62,153,107,133,62,47,75,170,62,56,38,131,62,133,93,147,62,135,192,156,62,117,100,42,62,74,64,65,62,53,7,150,62,25,183,106,62,231,235,133,62,77,173,167,62,105,6,75,62,210,143,110,62,33,40,153,62,186,247,146,62,181,60,157,62,157,147,167,62,201,30,52,62,242,251,88,62,181,174,128,62,21,163,109,62,62,126,122,62,175,80,153,62,217,91,67,62,32,46,89,62,43,110,166,62,133,22,109,62,97,218,160,62,19,123,175,62,65,200,71,62,104,149,86,62,117,24,143,62,161,47,118,62,163,9,138,62,165,241,167,62,145,236,47,62,219,128,144,62,209,38,161,62,82,218,137,62,245,74,173,62,237,134,194,62,231,197,35,62,236,60,54,62,102,163,77,62,197,211,78,62,96,52,108,62,203,119,131,62,169,61,9,62,82,6,88,62,151,194,145,62,29,154,80,62,85,236,144,62,95,75,155,62,97,255,19,62,122,174,40,62,237,245,145,62,137,60,83,62,218,157,126,62,133,191,151,62,249,238,33,62,252,240,111,62,73,46,143,62,130,173,135,62,37,79,143,62,21,34,163,62,205,136,42,62,190,179,60,62,86,178,91,62,213,236,79,62,206,192,112,62,211,215,147,62,1,119,44,62,68,215,80,62,111,48,147,62,217,73,109,62,13,85,140,62,79,70,166,62,5,206,61,62,120,64,91,62,242,134,106,62,89,77,120,62,163,116,133,62,89,233,144,62,113,149,43,62,14,214,119,62,21,83,153,62,149,138,116,62,121,84,163,62,73,130,183,62,211,55,13,62,178,128,30,62,49,254,135,62,111,21,88,62,118,255,101,62,57,86,143,62,31,223,12,62,24,136,102,62,65,94,158,62,219,189,106,62,169,99,141,62,97,103,161,62,211,86,36,62,252,38,72,62,151,251,144,62,243,191,95,62,248,233,115,62,87,34,169,62,239,91,58,62,158,158,110,62,71,40,150,62,174,84,130,62,69,248,160,62,155,59,172,62,215,141,19,62,92,20,104,62,255,77,128,62,63,90,92,62,195,185,128,62,73,241,145,62,183,45,64,62,170,93,81,62,81,157,150,62,215,6,108,62,153,114,137,62,217,105,180,62,111,118,61,62,98,218,75,62,123,58,139,62,27,100,120,62,94,194,130,62,187,111,159,62,159,217,71,62,156,20,127,62,83,22,153,62,30,59,145,62,73,19,161,62,191,19,182,62,51,32,27,62,174,121,74,62,244,11,110,62,163,212,76,62,170,159,107,62,165,89,144,62,87,10,14,62,148,107,68,62,33,10,177,62,95,76,73,62,147,3,156,62,5,93,174,62,79,120,13,62,116,17,65,62,251,82,153,62,59,154,82,62,231,173,137,62,95,111,156,62,43,150,48,62,238,41,111,62,11,86,150,62,128,80,138,62,71,233,152,62,139,56,168,62,127,179,51,62,72,244,67,62,72,61,113,62,139,215,97,62,152,104,112,62,93,62,151,62,167,27,62,62,126,175,99,62,241,76,143,62,195,246,106,62,127,237,155,62,5,61,166,62,235,98,63,62,2,164,92,62,96,243,128,62,99,140,112,62,1,221,138,62,203,139,153,62,251,149,61,62,189,27,131,62,71,42,150,62,196,27,135,62,207,63,157,62,183,159,185,62,145,220,36,62,124,59,55,62,79,249,130,62,81,22,103,62,176,149,121,62,55,137,137,62,73,204,30,62,250,236,107,62,215,90,164,62,192,230,128,62,187,46,143,62,27,223,160,62,173,193,32,62,54,114,84,62,57,114,148,62,241,178,94,62,193,237,132,62,221,106,174,62,21,14,53,62,24,162,108,62,141,151,162,62,42,223,144,62,51,133,153,62,13,116,172,62,5,110,58,62,30,129,75,62,144,3,129,62,145,75,103,62,163,67,129,62,207,50,150,62,129,158,77,62,132,3,95,62,71,187,154,62,167,92,125,62,79,226,146,62,139,21,178,62,137,244,77,62,156,230,91,62,53,72,134,62,124,7,130,62,5,249,137,62,1,208,159,62,165,158,67,62,29,240,130,62,65,69,170,62,254,4,149,62,235,180,169,62,161,183,188,62,225,0,33,62,184,210,61,62,30,197,102,62,105,11,85,62,64,18,116,62,235,70,135,62,105,95,22,62,178,28,90,62,215,178,153,62,177,224,95,62,117,157,148,62,63,59,158,62,225,37,19,62,158,82,64,62,73,74,145,62,205,77,84,62,136,248,122,62,137,47,158,62,105,43,40,62,100,75,105,62,45,41,158,62,88,26,134,62,177,41,149,62,9,190,169,62,149,190,46,62,98,2,79,62,66,14,95,62,129,200,84,62,118,86,112,62,195,18,157,62,233,63,48,62,220,49,91,62,55,204,158,62,109,157,106,62,169,216,143,62,119,228,170,62,85,87,73,62,76,218,93,62,225,224,110,62,5,127,115,62,227,151,132,62,189,245,155,62,9,232,30,62,53,172,134,62,129,76,163,62,201,95,127,62,1,74,162,62,21,106,193,62,15,255,26,62,254,53,51,62,61,118,142,62,239,21,97,62,214,239,109,62,25,240,145,62,195,13,18,62,152,96,118,62,73,182,155,62,91,151,120,62,69,73,145,62,193,134,161,62,39,63,33,62,48,129,84,62,67,37,141,62,179,63,106,62,7,18,127,62,227,1,168,62,35,116,67,62,24,215,115,62,107,252,150,62,44,100,136,62,189,238,160,62,23,102,173,62,91,189,46,62,80,103,103,62,48,79,125,62,15,30,114,62,171,137,129,62,161,145,147,62,187,223,61,62,98,206,81,62,105,20,161,62,155,152,94,62,185,207,150,62,89,84,188,62,235,22,65,62,166,86,92,62,159,198,139,62,13,252,122,62,159,0,133,62,47,206,164,62,243,52,75,62,219,182,133,62,167,90,162,62,88,24,153,62,37,110,168,62,235,158,182,62,247,11,34,62,146,209,68,62,234,246,123,62,27,62,79,62,194,234,125,62,197,34,139,62,131,151,37,62,76,214,90,62,249,158,167,62,215,144,91,62,95,113,156,62,141,221,170,62,35,180,37,62,112,116,66,62,15,250,158,62,235,179,96,62,245,177,135,62,27,91,158,62,191,210,64,62,214,159,127,62,255,44,146,62,4,229,137,62,79,128,153,62,63,246,174,62,51,139,48,62,108,10,88,62,98,61,105,62,123,145,97,62,212,161,111,62,93,45,160,62,203,167,59,62,54,100,99,62,209,4,149,62,27,90,120,62,103,122,158,62,213,40,169,62,31,135,84,62,246,13,102,62,70,73,122,62,65,194,123,62,237,98,138,62,71,58,156,62,215,70,61,62,69,80,139,62,19,4,160,62,214,106,140,62,51,123,164,62,51,211,191,62,137,107,42,62,96,235,60,62,191,91,137,62,229,231,105,62,168,219,120,62,119,247,143,62,249,238,35,62,25,131,129,62,231,240,171,62,72,51,134,62,131,86,151,62,243,111,160,62,69,186,43,62,178,95,78,62,189,133,154,62,221,135,115,62,237,16,133,62,161,44,173,62,109,240,73,62,248,97,123,62,49,195,162,62,34,207,152,62,119,111,163,62,217,147,174,62,213,77,47,62,50,182,101,62,89,133,134,62,117,41,108,62,225,177,129,62,199,55,154,62,209,186,81,62,236,52,99,62,23,229,166,62,215,86,100,62,123,216,156,62,51,145,179,62,9,173,77,62,80,135,92,62,65,123,145,62,188,124,128,62,245,73,136,62,61,174,170,62,45,211,51,62,209,107,150,62,85,63,174,62,156,95,149,62,115,99,174,62,125,70,195,62,109,203,85,61,179,182,171,61,130,212,216,61,103,200,3,62,237,151,96,61,26,14,9,62,153,48,241,61,181,177,70,62,191,148,91,61,5,37,228,61,40,189,245,61,155,3,23,62,160,234,163,61,133,110,18,62,81,6,40,62,137,219,86,62,5,109,85,61,175,210,203,61,140,173,177,61,1,110,62,62,16,51,159,61,187,169,6,62,11,102,36,62,239,75,58,62,242,2,152,61,217,44,226,61,244,246,242,61,157,131,51,62,174,124,135,61,119,99,40,62,201,136,73,62,227,225,93,62,45,240,119,61,163,158,193,61,208,164,217,61,247,144,23,62,110,162,112,61,29,69,23,62,84,13,10,62,185,90,78,62,49,27,135,61,249,123,238,61,233,120,7,62,23,242,28,62,182,199,189,61,53,63,22,62,161,150,55,62,153,250,96,62,197,174,144,61,215,200,204,61,238,28,218,61,5,192,55,62,2,18,180,61,107,75,0,62,219,83,29,62,231,153,74,62,83,243,181,61,101,84,230,61,121,216,23,62,149,137,43,62,176,59,167,61,43,86,45,62,73,204,84,62,15,148,108,62,223,223,123,61,71,68,171,61,244,112,234,61,13,16,12,62,101,185,140,61,215,105,13,62,207,83,226,61,119,133,92,62,93,152,99,61,109,90,250,61,230,230,246,61,45,240,36,62,218,113,170,61,247,52,31,62,143,132,37,62,79,191,105,62,179,217,128,61,227,142,217,61,70,209,169,61,179,188,83,62,190,50,181,61,37,15,11,62,197,216,45,62,173,108,70,62,203,48,159,61,39,89,246,61,152,200,5,62,123,193,60,62,144,181,141,61,165,163,60,62,59,204,80,62,85,181,127,62,97,238,144,61,247,248,184,61,86,38,222,61,141,218,37,62,126,209,146,61,43,184,26,62,57,28,14,62,147,13,96,62,255,108,138,61,54,200,1,62,63,157,8,62,25,228,44,62,52,251,196,61,199,137,34,62,23,246,62,62,7,61,114,62,88,164,168,61,115,39,209,61,76,125,205,61,183,152,71,62,36,250,203,61,5,179,11,62,197,211,58,62,253,138,80,62,17,122,200,61,30,27,248,61,171,241,20,62,211,2,60,62,134,71,196,61,217,83,48,62,171,167,100,62,41,85,124,62,245,173,104,60,236,211,158,60,30,239,238,60,109,122,133,61,178,82,169,60,119,205,75,61,95,173,33,61,30,194,195,61,246,247,185,60,59,117,34,61,45,176,92,61,133,175,128,61,158,255,237,60,26,225,106,61,161,157,55,61,74,68,236,61,244,3,159,60,5,22,14,61,131,51,51,61,107,73,138,61,153,156,17,61,193,96,74,61,66,51,143,61,112,158,177,61,177,163,227,60,69,197,62,61,49,52,109,61,116,37,138,61,43,108,66,61,38,100,97,61,6,145,161,61,107,195,250,61,49,161,181,60,220,233,247,60,212,232,10,61,92,252,146,61,148,63,2,61,137,99,76,61,75,126,122,61,72,221,178,61,46,36,219,60,197,128,34,61,93,231,53,61,136,80,169,61,179,103,31,61,69,191,103,61,241,185,119,61,120,23,214,61,60,126,220,60,223,75,18,61,195,100,40,61,62,47,150,61,157,6,41,61,67,185,70,61,122,14,147,61,158,128,217,61,215,117,10,61,31,203,45,61,164,104,114,61,74,82,163,61,99,142,64,61,216,186,128,61,142,236,192,61,168,44,5,62,250,31,159,60,30,108,223,60,133,228,23,61,208,43,136,61,218,124,229,60,241,88,83,61,77,234,90,61,12,160,189,61,210,220,208,60,17,75,49,61,203,10,98,61,40,197,150,61,249,51,11,61,92,241,119,61,24,53,125,61,172,207,9,62,104,15,193,60,211,129,17,61,181,57,81,61,166,44,139,61,55,17,29,61,191,105,86,61,124,109,152,61,230,219,197,61,180,126,2,61,31,73,61,61,102,129,125,61,118,42,150,61,137,237,52,61,208,65,109,61,76,135,162,61,205,144,16,62,30,174,202,60,0,143,4,61,73,219,9,61,222,202,164,61,247,107,10,61,255,56,95,61,8,222,133,61,230,32,195,61,236,82,240,60,39,122,47,61,59,55,88,61,66,38,167,61,13,35,36,61,43,49,125,61,238,105,138,61,127,4,240,61,84,69,248,60,225,122,30,61,93,225,69,61,64,10,152,61,67,56,51,61,253,39,86,61,4,117,170,61,204,9,225,61,149,216,25,61,69,163,57,61,241,48,135,61,44,88,163,61,249,30,78,61,121,188,113,61,12,163,179,61,156,26,39,62,0,0,0,0,48,188,22,0,0,0,0,0,200,190,22,0,224,218,22,0,0,0,0,0,0,0,0,0,56,188,22,0,0,0,0,0,208,190,22,0,232,218,22,0,0,0,0,0,211,217,201,188,96,60,131,187,174,182,226,189,36,151,95,63,18,131,128,63,63,53,126,63,153,42,216,62,112,95,199,62,18,131,0,63,154,153,185,63,231,251,169,63,129,149,163,63,149,101,72,62,9,27,94,62,49,8,140,62,14,45,146,63,82,184,158,63,147,24,148,63,236,192,73,63,77,132,45,63,162,69,214,62,18,131,192,63,109,231,187,63,29,90,196,63,37,117,162,62,177,225,137,62,173,23,195,189,74,12,146,63,70,182,147,63,203,161,133,63,97,195,3,63,6,18,20,63,202,84,97,63,137,65,192,63,147,24,180,63,29,90,180,63,19,242,161,62,16,233,183,62,96,229,144,62,168,198,155,63,150,67,155,63,227,165,155,63,170,241,130,63,193,202,145,63,173,23,195,189,100,59,207,63,10,215,211,63,14,45,210,63,24,38,19,62,172,28,26,62,208,10,140,61,245,185,122,63,33,176,130,63,219,249,142,63,242,176,240,62,111,129,36,63,82,73], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1496578);
/* memory initializer */ allocate([13,63,23,217,174,63,229,208,178,63,207,247,179,63,207,102,149,62,245,185,154,62,217,206,119,62,80,141,167,63,23,217,158,63,246,40,156,63,182,132,76,63,65,241,67,63,168,53,61,63,4,86,206,63,137,65,192,63,76,55,185,63,20,208,132,62,167,121,71,62,229,208,130,62,227,165,139,63,51,51,147,63,229,208,162,63,242,65,175,62,225,122,212,62,203,161,165,63,223,79,221,63,137,65,176,63,236,81,136,63,215,18,210,62,94,75,168,62,11,70,165,62,152,110,146,63,207,247,163,63,125,63,181,63,25,4,134,63,219,249,142,63,173,105,30,63,244,253,244,63,188,116,227,63,74,12,194,63,181,108,173,188,228,20,93,62,14,190,112,62,109,231,139,63,150,67,139,63,248,83,131,63,228,131,14,63,238,90,2,63,233,72,238,62,174,71,193,63,213,120,185,63,94,186,153,63,106,222,113,62,68,105,175,62,65,130,130,62,31,133,171,63,205,204,156,63,219,249,142,63,231,251,153,63,102,136,195,62,121,88,104,62,119,190,175,63,70,182,179,63,113,61,234,63,129,149,131,62,2,154,136,62,194,134,39,62,49,8,156,63,68,139,140,63,178,157,143,63,229,208,50,63,62,121,88,63,254,212,136,63,102,102,198,63,197,32,192,63,252,169,177,63,170,241,146,62,8,172,156,62,208,68,184,62,180,200,150,63,246,40,172,63,240,167,166,63,92,143,162,63,31,133,155,63,126,140,57,62,205,204,220,63,188,116,227,63,57,180,216,63,170,96,84,62,25,115,87,62,246,151,29,62,164,112,141,63,29,90,132,63,223,79,141,63,181,21,43,63,58,35,42,63,90,245,41,63,129,149,179,63,209,34,187,63,20,174,183,63,77,132,173,62,110,52,192,62,246,40,92,62,47,221,164,63,154,153,169,63,96,229,160,63,79,175,100,63,220,70,83,63,110,52,80,63,61,10,199,63,172,28,202,63,236,81,200,63,231,29,167,62,217,61,121,62,188,5,146,62,219,249,158,63,61,10,151,63,35,219,153,63,185,141,6,62,13,224,45,62,33,176,210,63,25,4,230,63,127,106,204,63,23,217,158,63,23,183,241,62,140,219,8,63,173,250,156,62,111,18,163,63,248,83,179,63,145,237,172,63,113,61,186,63,115,104,177,63,166,155,36,63,231,251,233,63,219,249,238,63,154,153,233,63,2,43,167,190,226,88,151,190,218,27,124,190,225,122,132,63,92,143,130,63,78,98,128,63,219,138,189,62,182,132,220,62,15,11,53,63,162,69,182,63,246,40,172,63,86,14,173,63,11,36,104,62,76,55,137,62,145,126,155,62,123,20,158,63,59,223,159,63,33,176,146,63,0,145,126,63,25,4,38,63,75,89,6,63,244,253,196,63,219,249,190,63,4,86,206,63,248,83,195,62,49,8,172,62,173,23,195,189,47,221,148,63,152,110,146,63,219,249,142,63,241,99,44,63,93,254,67,63,193,202,129,63,57,180,200,63,98,16,184,63,113,61,186,63,114,138,174,62,149,212,169,62,93,109,197,62,61,10,151,63,29,90,164,63,29,90,164,63,100,59,159,63,90,100,155,63,173,23,195,189,78,98,224,63,68,139,204,63,100,59,223,63,228,131,30,62,150,33,14,62,23,217,78,62,188,116,131,63,37,6,145,63,109,231,139,63,185,252,199,62,197,32,64,63,74,12,18,63,143,194,181,63,45,178,173,63,6,129,197,63,157,128,166,62,46,144,160,62,151,144,143,62,145,237,172,63,80,141,167,63,8,172,156,63,41,203,96,63,100,59,79,63,139,253,53,63,141,151,206,63,113,61,202,63,139,108,183,63,102,247,164,62,177,80,107,62,118,224,92,62,227,165,155,63,35,219,137,63,178,157,159,63,201,118,174,63,10,215,163,63,117,147,168,63,197,32,224,63,250,126,186,63,199,75,151,63,174,182,226,62,151,255,208,62,1,222,162,62,147,24,148,63,86,14,157,63,223,79,205,63,166,155,164,63,211,77,162,63,64,19,81,63,100,59,255,63,233,38,1,64,199,75,167,63,238,206,218,60,20,208,132,62,41,237,173,62,244,253,148,63,113,61,138,63,27,158,110,63,126,140,25,63,172,139,27,63,215,18,2,63,117,147,184,63,117,147,184,63,0,0,176,63,106,188,116,62,253,246,181,62,68,105,175,62,106,188,164,63,199,75,167,63,152,110,146,63,154,153,153,63,59,223,63,63,67,28,203,62,217,206,199,63,14,45,194,63,170,241,242,63,181,55,184,62,60,78,177,62,143,194,245,61,221,36,166,63,0,0,144,63,158,239,135,63,161,248,65,63,252,169,129,63,254,212,152,63,106,188,196,63,252,169,193,63,90,100,187,63,50,230,206,62,224,190,206,62,194,134,199,62,6,129,165,63,49,8,156,63,78,98,176,63,0,0,160,63,74,12,178,63,127,251,122,62,139,108,199,63,193,202,225,63,27,47,221,63,113,61,138,62,19,242,65,62,129,4,69,62,63,53,142,63,4,86,142,63,221,36,150,63,188,5,66,63,34,142,85,63,134,201,244,62,90,100,187,63,86,14,189,63,49,8,188,63,232,217,204,62,192,236,158,62,83,5,99,62,186,73,172,63,84,227,181,63,158,239,167,63,135,22,137,63,34,142,101,63,23,72,64,63,23,217,206,63,43,135,198,63,213,120,201,63,222,113,170,62,141,151,142,62,156,196,160,62,207,247,163,63,131,192,154,63,141,151,158,63,178,157,143,62,12,147,137,62,33,176,210,63,39,49,232,63,193,202,193,63,174,71,193,63,123,131,31,63,61,10,215,62,191,125,189,62,215,163,160,63,121,233,182,63,172,28,186,63,14,45,210,63,53,94,202,63,52,17,54,63,49,8,236,63,150,67,251,63,92,143,242,63,20,92,44,189,172,173,24,190,92,114,156,189,84,227,133,63,116,181,117,63,213,231,106,63,11,70,229,62,168,198,235,62,115,215,2,63,33,176,194,63,66,96,165,63,168,198,171,63,248,83,99,62,65,130,130,62,18,131,128,62,217,206,151,63,18,131,160,63,84,227,149,63,217,95,102,63,182,243,253,62,228,20,253,62,221,36,182,63,182,243,189,63,41,92,207,63,187,39,143,62,205,59,142,62,78,98,144,190,143,194,149,63,2,43,151,63,94,186,137,63,23,72,208,62,76,166,90,63,68,105,111,63,131,192,202,63,125,63,181,63,55,137,177,63,113,61,170,62,209,34,187,62,12,2,171,62,8,172,156,63,96,229,160,63,41,92,159,63,217,206,135,63,252,169,145,63,173,23,195,189,2,43,215,63,172,28,218,63,221,36,214,63,57,214,69,62,62,121,24,62,183,209,0,62,170,241,130,63,150,67,139,63,92,143,146,63,47,221,4,63,229,242,47,63,56,103,4,63,215,163,176,63,10,215,179,63,8,172,188,63,187,184,173,62,82,184,158,62,84,116,100,62,223,79,173,63,59,223,159,63,92,143,162,63,40,126,60,63,7,206,89,63,138,31,83,63,4,86,206,63,106,188,196,63,233,38,193,63,116,36,151,62,42,58,82,62,166,155,132,62,252,169,145,63,49,8,156,63,55,137,161,63,246,40,172,63,244,253,164,63,150,67,171,63,158,239,183,63,123,20,174,63,117,147,184,63,89,23,247,62,140,219,168,62,221,181,196,62,49,8,156,63,217,206,167,63,47,221,180,63,209,34,155,63,217,206,151,63,60,189,34,63,119,190,239,63,39,49,248,63,162,69,214,63,174,71,161,63,2,43,167,63,160,26,175,63,33,176,146,63,35,219,137,63,51,51,131,63,168,87,26,63,151,255,0,63,93,254,19,63,193,202,193,63,143,194,181,63,213,120,169,63,75,200,135,62,47,110,163,62,26,192,155,62,160,26,175,63,16,88,153,63,154,153,153,63,182,243,157,63,90,100,251,62,172,226,13,61,127,106,172,63,20,174,199,63,63,53,238,63,132,158,141,62,125,208,147,62,5,197,79,62,96,229,160,63,164,112,141,63,92,143,146,63,145,237,172,63,27,47,173,63,207,247,179,63,156,196,192,63,113,61,202,63,4,86,174,63,132,13,143,62,166,10,198,62,127,251,218,62,182,243,157,63,131,192,170,63,12,2,171,63,10,215,163,63,137,65,160,63,254,212,56,62,55,137,177,63,33,176,178,63,80,141,183,63,24,149,148,62,178,157,239,61,13,224,45,62,233,38,145,63,35,219,137,63,219,249,142,63,115,215,50,63,48,187,55,63,209,145,60,63,41,92,175,63,23,217,190,63,41,92,191,63,32,99,206,62,184,175,3,63,106,77,51,62,190,159,170,63,137,65,176,63,96,229,160,63,195,211,107,63,221,181,100,63,97,195,99,63,90,100,203,63,141,151,206,63,170,241,194,63,229,97,161,62,246,151,93,62,66,96,165,62,102,102,166,63,92,143,146,63,209,34,155,63,152,110,162,63,41,92,159,63,178,157,191,63,252,169,225,63,227,165,219,63,217,206,167,63,14,190,240,62,159,205,10,63,154,119,220,62,168,198,171,63,139,108,183,63,221,36,182,63,127,106,188,63,70,182,179,63,48,76,86,63,217,206,247,63,37,6,241,63,150,67,235,63,74,12,162,63,143,194,165,63,240,167,166,63,213,120,137,63,137,65,128,63,170,241,130,63,11,70,5,63,160,26,207,62,135,167,39,63,250,126,186,63,78,98,176,63,201,118,174,63,12,2,139,62,212,154,134,62,142,117,145,62,193,202,161,63,33,176,162,63,102,102,150,63,209,34,171,63,61,10,167,63,2,43,167,63,61,10,199,63,135,22,201,63,147,24,212,63,40,15,171,62,143,83,212,62,17,199,186,190,98,16,152,63,20,174,151,63,166,155,148,63,54,171,30,63,89,134,56,63,147,24,148,63,250,126,202,63,31,133,187,63,252,169,193,63,138,142,196,62,99,238,186,62,220,70,195,62,90,100,155,63,156,196,160,63,66,96,165,63,63,53,174,63,201,118,174,63,158,239,167,63,6,129,229,63,57,180,216,63,203,161,213,63,0,111,65,62,92,143,2,62,165,189,129,62,176,114,136,63,162,69,150,63,37,6,145,63,229,242,255,62,101,25,82,63,20,208,20,63,27,47,189,63,125,63,181,63,178,157,191,63,220,70,195,62,101,170,160,62,179,234,147,62,33,176,178,63,133,235,161,63,242,210,157,63,243,31,114,63,136,133,106,63,102,102,22,63,25,4,214,63,96,229,208,63,180,200,198,63,188,116,179,62,174,71,129,62,215,18,114,62,12,2,155,63,252,169,145,63,123,20,158,63,74,12,178,63,104,145,157,63,164,112,173,63,88,57,228,63,174,71,193,63,213,120,153,63,34,108,216,62,140,219,232,62,136,244,187,62,207,247,163,63,18,131,160,63,166,155,212,63,150,67,171,63,18,131,176,63,93,254,115,63,213,120,9,64,31,133,251,63,131,192,202,63,157,244,190,61,61,10,183,62,143,83,180,62,209,34,155,63,12,2,139,63,203,161,133,63,118,224,28,63,228,20,29,63,209,34,27,63,182,243,189,63,96,229,192,63,33,176,178,63,78,98,144,62,129,4,197,62,83,150,161,62,160,26,175,63,106,188,164,63,78,98,144,63,100,59,175,63,86,14,173,63,242,210,173,63,156,196,176,63,133,235,225,63,100,59,7,64,39,49,168,63,246,40,172,63,131,192,170,63,184,30,165,63,25,4,150,63,100,59,143,63,121,233,166,63,137,65,176,63,240,167,182,63,82,184,190,63,184,30,197,63,166,155,196,63,40,126,204,62,229,97,225,62,88,168,213,62,16,88,169,63,199,75,167,63,14,45,178,63,51,51,179,63,252,169,177,63,100,59,175,63,203,161,213,63,57,180,232,63,131,192,234,63,241,99,140,62,47,221,100,62,204,93,75,62,55,137,145,63,193,202,145,63,94,186,153,63,213,120,169,63,174,71,177,63,8,172,172,63,113,61,186,63,213,120,201,63,172,28,186,63,133,124,0,63,240,167,166,62,229,208,130,62,252,169,177,63,98,16,184,63,102,102,166,63,152,110,178,63,8,172,172,63,166,155,180,63,193,202,209,63,113,61,202,63,2,43,215,63,57,180,200,62,146,203,127,62,170,96,180,62,43,135,166,63,186,73,156,63,225,122,164,63,57,180,168,63,168,198,171,63,100,59,191,63,225,122,244,63,61,10,215,63,246,40,188,63,255,178,27,63,121,233,6,63,88,168,213,62,215,163,160,63,86,14,189,63,78,98,192,63,199,75,231,63,219,249,222,63,190,193,39,63,0,0,0,64,166,155,4,64,150,67,3,64,192,10,34,0,112,0,0,0,0,0,0,0,100,66,52,0,40,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,66,0,0,160,66,0,0,28,66,0,0,142,66,0,0,4,66,0,0,0,0,8,189,172,185,80,90,39,0,176,43,37,0,190,170,184,222,208,217,35,0,160,232,34,0,190,170,184,223,248,37,34,0,160,232,34,0,190,170,185,172,72,135,33,0,0,12,33,0,8,187,186,188,168,165,32,0,72,74,32,0,8,187,186,178,40,49,40,0,104,212,39,0,8,186,177,188,184,108,39,0,80,28,39,0,187,176,185,223,240,215,38,0,136,146,38,0,187,167,182,171,24,88,38,0,160,34,38,0,187,167,171,223,8,242,37,0,152,196,37,0,8,185,182,179,48,162,37,0,136,122,37,0,183,177,187,190,8,55,37,0,200,13,37,0,8,178,170,167,216,228,36,0,88,193,36,0,8,176,175,171,24,164,36,0,56,137,36,0,176,190,168,186,184,109,36,0,8,83,36,0,8,175,173,176,32,58,36,0,192,28,36,0,8,172,171,173,112,226,35,0,144,196,35,0,171,177,180,177,248,172,35,0,72,151,35,0,88,80,77,212,176,129,35,0,240,106,35,0,0,0,0,0,80,0,100,0,100,0,100,0,110,0,120,0,140,0,150,0,160,0,190,0,210,0,240,0,24,1,64,1,124,1,194,1,38,2,188,2,132,3,76,4,20,5,8,7,196,9,172,13,148,17,0,0,0,0,0,0,96,187,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,130,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,104,36,0,184,76,36,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,152,104,36,0,184,53,36,0,0,13,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,80,216,35,0,56,191,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,112,168,35,0,160,146,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,16,124,35,0,232,101,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,160,83,35,0,96,164,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,0,49,35,0,96,164,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,224,101,34,0,88,73,34,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,48,37,34,0,88,73,34,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,99,34,0,112,0,0,0,144,10,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,12,4,0,0,8,8,0,0,4,12,0,0,12,0,4,0,9,3,3,1,6,6,2,2,3,9,1,3,8,0,8,0,6,2,6,2,4,4,4,4,2,6,2,6,4,0,12,0,3,1,9,3,2,2,6,6,1,3,3,9,208,107,36,0,248,55,36,0,144,221,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,12,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,6,0,62,0,28,0,29,0,7,0,8,0,9,0,10,0,11,0,12,0,0,0,1,0,2,0,13,0,30,0,126,0,254,0,254,1,252,7,253,7,252,15,253,15,254,15,255,15,254,3,254,0,62,0,28,0,29,0,12,0,0,0,1,0,2,0,3,0,4,0,5,0,13,0,30,0,126,0,254,1,254,7,254,15,254,31,252,127,253,127,254,127,254,255,255,255,254,15,254,3,254,0,62,0,28,0,6,0,7,0,8,0,9,0,10,0,11,0,0,0,1,0,2,0,12,0,13,0,29,0,30,0,126,0,254,1,254,7,254,31,254,63,255,63,252,31,254,3,252,1,253,1,124,0,125,0,28,0,29,0,10,0,0,0,1,0,2,0,3,0,4,0,11,0,12,0,13,0,30,0,126,0,254,1,254,7,253,31,254,31,255,31,254,15,254,31,254,3,254,0,60,0,61,0,26,0,27,0,10,0,11,0,0,0,1,0,2,0,3,0,4,0,12,0,28,0,29,0,62,0,126,0,254,1,254,7,254,63,255,63,254,15,254,7,254,1,252,0,253,0,124,0,28,0,10,0,11,0,0,0,1,0,2,0,3,0,4,0,12,0,13,0,29,0,30,0,125,0,254,0,254,3,254,31,254,63,255,63,252,127,252,255,253,127,254,15,254,3,254,0,62,0,28,0,12,0,2,0,3,0,4,0,0,0,5,0,13,0,29,0,30,0,126,0,254,1,254,7,254,31,253,255,254,255,255,255,252,63,253,63,254,7,254,3,252,1,124,0,125,0,28,0,29,0,12,0,2,0,3,0,0,0,4,0,5,0,13,0,30,0,126,0,253,1,254,1,254,15,254,63,254,127,255,127,252,1,253,1,254,1,252,0,124,0,60,0,28,0,12,0,0,0,1,0,2,0,3,0,4,0,5,0,13,0,29,0,61,0,125,0,253,0,254,3,254,7,254,15,254,31,255,31,252,63,254,15,254,3,252,0,60,0,61,0,28,0,12,0,0,0,1,0,2,0,3,0,4,0,5,0,13,0,29,0,62,0,253,0,254,0,254,1,254,7,253,63,254,63,255,63,254,31,254,3,252,1,252,0,60,0,61,0,28,0,10,0,11,0,12,0,2,0,3,0,0,0,4,0,13,0,29,0,62,0,253,0,253,1,254,1,254,7,254,15,254,63,255,63,252,255,254,31,254,15,254,7,254,1,62,0,28,0,29,0,10,0,11,0,12,0,2,0,0,0,3,0,4,0,13,0,30,0,126,0,254,0,254,3,254,63,253,255,254,255,255,255,252,31,250,63,251,63,252,63,254,3,254,0,124,0,125,0,28,0,12,0,2,0,3,0,0,0,4,0,5,0,13,0,29,0,30,0,126,0,254,1,254,7,253,63,254,63,255,63,4,6,5,5,4,4,4,4,4,4,3,3,3,4,5,7,8,9,11,11,12,12,12,12,10,8,6,5,5,4,3,3,3,3,3,3,4,5,7,9,11,12,13,15,15,15,16,16,12,10,8,6,5,4,4,4,4,4,4,3,3,3,4,4,5,5,7,9,11,13,14,14,13,10,9,9,7,7,5,5,4,3,3,3,3,3,4,4,4,5,7,9,11,13,13,13,12,13,10,8,6,6,5,5,4,4,3,3,3,3,3,4,5,5,6,7,9,11,14,14,12,11,9,8,8,7,5,4,4,3,3,3,3,3,4,4,5,5,7,8,10,13,14,14,15,16,15,12,10,8,6,5,4,3,3,3,2,3,4,5,5,7,9,11,13,16,16,16,14,14,11,10,9,7,7,5,5,4,3,3,2,3,3,4,5,7,9,9,12,14,15,15,9,9,9,8,7,6,5,4,3,3,3,3,3,3,4,5,6,7,8,10,11,12,13,13,14,12,10,8,6,6,5,4,3,3,3,3,3,3,4,5,6,8,8,9,11,14,14,14,13,10,9,8,6,6,5,4,4,4,3,3,2,3,4,5,6,8,9,9,11,12,14,14,16,13,12,11,9,6,5,5,4,4,4,3,2,3,3,4,5,7,8,10,14,16,16,16,13,14,14,14,10,8,7,7,5,4,3,3,2,3,3,4,5,5,7,9,11,14,14,14,205,204,76,62,154,153,153,62,205,204,204,62,0,0,0,63,92,143,66,62,123,20,174,62,225,122,20,63,123,20,46,63,0,0,4,66,0,0,4,66,0,0,4,66,0,0,230,65,0,0,240,65,0,0,16,66,0,0,4,66,0,0,16,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,1,0,0,240,0,0,0,1,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,60,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,63,0,0,0,100,0,0,0,100,0,0,0,112,23,0,0,160,15,0,0,136,19,0,0,50,0,0,0,0,0,0,0,208,7,0,0,1,0,0,0,0,0,0,0,15,39,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,164,1,0,0,5,0,0,0,14,1,0,0,6,0,0,0,28,1,0,0,7,0,0,0,4,1,0,0,1,0,0,0,16,1,0,0,3,0,0,0,160,1,0,0,8,0,0,0,144,0,0,0,9,0,0,0,102,0,0,0,11,0,0,0,56,1,0,0,13,0,0,0,134,0,0,0,15,0,0,0,134,0,0,0,14,0,0,0,134,0,0,0,16,0,0,0,134,0,0,0,17,0,0,0,134,0,0,0,28,0,0,0,134,0,0,0,29,0,0,0,134,0,0,0,21,0,0,0,134,0,0,0,22,0,0,0,134,0,0,0,23,0,0,0,134,0,0,0,24,0,0,0,134,0,0,0,25,0,0,0,134,0,0,0,26,0,0,0,134,0,0,0,27,0,0,0,134,0,0,0,30,0,0,0,134,0,0,0,31,0,0,0,134,0,0,0,32,0,0,0,134,0,0,0,33,0,0,0,112,1,0,0,34,0,0,0,10,1,0,0,35,0,0,0,34,1,0,0,19,0,0,0,238,0,0,0,20,0,0,0,238,0,0,0,128,0,0,0,100,1,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,2,0,0,0,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,0,0,0,0,0,0,0,0,15,0,0,0,1,0,0,0,235,0,0,0,1,0,0,0,128,0,0,0,1,0,0,0,240,0,0,0,1,0,0,0,128,0,0,0,1,0,0,0,240,0,0,0,1,0,0,0,0,0,64,16,0,0,79,16,0,0,42,203,0,0,37,203,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,0,0,0,0,56,212,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,43,37,0,96,217,35,0,32,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,88,232,34,0,96,217,35,0,32,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,168,37,34,0,240,134,33,0,12,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,208,11,33,0,240,134,33,0,12,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,128,165,32,0,16,74,32,0,8,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,0,49,40,0,16,74,32,0,8,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,212,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,166,0,0,0,0,0,0,0,0,0,0,0,104,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,209,36,0,112,0,0,0,24,22,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,135,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,43,37,0,184,217,35,0,24,0,0,0,3,0,0,0,25,25,25,25,25,25,201,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,232,34,0,224,37,34,0,16,0,0,0,3,0,0,0,20,20,20,20,20,20,180,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,135,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,0,0,0,0,0,0,0,0,68,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,212,36,0,112,0,0,0,136,24,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,25,37,0,232,243,36,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,168,204,36,0,32,175,36,0,36,0,0,0,69,90,73,83,248,146,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,152,119,36,0,128,92,36,0,96,0,0,0,1,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,34,64,0,0,0,0,0,0,50,64,16,0,1,0,0,0,0,0,112,66,36,0,128,40,36,0,136,24,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,16,239,35,0,240,203,35,0,120,180,35,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,16,239,35,0,208,157,35,0,88,137,35,0,0,0,0,0,128,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,24,0,1,0,16,239,35,0,136,114,35,0,232,94,35,0,140,24,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,24,0,1,0,0,0,0,0,56,76,35,0,16,58,35,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,88,38,35,0,72,251,34,0,232,223,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,88,38,35,0,40,208,34,0,56,192,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,88,38,35,0,48,175,34,0,248,155,34,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,88,38,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,141,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,2,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,77,39,0,112,0,0,0,192,25,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,223,69,26,6,0,0,0,0,0,0,0,0,0,0,0,40,29,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,66,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,243,66,0,0,1,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,242,66,0,0,1,0,0,0,0,0,0,0,16,0,0,0,4,0,0,0,0,0,0,0,130,66,0,0,3,0,0,0,0,0,0,0,24,0,0,0,104,83,33,0,0,0,0,0,133,66,0,0,1,0,0,0,0,0,0,0,32,0,0,0,1,0,0,0,0,0,0,0,134,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,194,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,194,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,23,35,0,112,0,0,0,168,9,32,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,43,34,0,112,0,0,0,208,153,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,6,0,0,0,0,0,0,0,0,240,0,0,0,204,1,0,0,136,1,0,0,0,0,0,0,0,0,0,0,48,255,255,255,36,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,11,0,0,0,0,0,0,0,255,255,255,255,253,255,255,255,252,255,255,255,16,39,0,0,194,76,0,0,42,163,0,0,62,72,1,0,40,148,2,0,224,41,5,0,36,84,10,0,40,165,20,0,80,74,41,0,232,136,82,0,252,78,0,0,210,155,0,0,94,70,1,0,160,153,2,0,172,58,5,0,220,120,10,0,72,243,20,0,144,230,41,0,80,197,83,0,0,0,0,0,252,78,0,0,210,155,0,0,94,70,1,0,160,153,2,0,172,58,5,0,220,120,10,0,72,243,20,0,144,230,41,0,80,197,83,0,0,0,0,0,64,81,0,0,250,150,0,0,126,68,1,0,24,159,2,0,220,75,5,0,92,158,10,0,104,65,21,0,208,130,42,0,160,5,85,0,0,0,0,0,16,39,0,0,152,58,0,0,108,107,0,0,246,209,0,0,48,161,1,0,152,65,3,0,204,130,6,0,52,5,13,0,248,11,26,0,8,20,52,0,140,40,0,0,48,62,0,0,6,114,0,0,198,222,0,0,148,186,1,0,96,116,3,0,148,231,6,0,96,206,13,0,104,154,27,0,0,0,0,0,140,40,0,0,48,62,0,0,6,114,0,0,198,222,0,0,148,186,1,0,96,116,3,0,148,231,6,0,96,206,13,0,104,154,27,0,0,0,0,0,18,28,0,0,2,36,0,0,244,61,0,0,222,118,0,0,30,235,0,0,36,213,1,0,128,169,3,0,212,81,7,0,68,163,14,0,0,0,0,0,0,0,0,0,255,0,0,0,0,255,0,0,0,0,255,0,0,255,255,0,255,0,255,0,255,255,0,0,255,255,255,0,0,128,128,0,255,128,128,0,128,0,128,0,128,255,128,0,128,128,0,0,128,128,255,0,85,85,85,0,170,170,170,0,104,75,40,0,112,0,0,0,176,188,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,70,39,0,112,0,0,0,160,117,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,34,51,68,85,102,119,136,153,170,187,204,221,238,255,0,0,2,0,83,236,3,0,83,236,3,0,13,178,3,0,7,217,3,0,13,178,3,0,147,153,3,0,224,159,3,0,224,159,3,0,147,153,3,0,0,128,3,0,222,135,3,0,10,106,3,0,222,135,3,0,0,128,3,0,215,102,3,0,201,110,3,0,109,83,3,0,109,83,3,0,201,110,3,0,215,102,3,0,188,15,3,0,28,86,3,0,204,59,3,0,101,61,3,0,204,59,3,0,28,86,3,0,188,15,3,0,67,226,2,0,173,0,3,0,141,36,3,0,97,38,3,0,97,38,3,0,141,36,3,0,173,0,3,0,67,226,2,0,20,212,2,0,20,212,2,0,188,15,3,0,0,16,3,0,188,15,3,0,20,212,2,0,20,212,2,0,17,170,2,0,88,193,2,0,252,249,2,0,252,249,2,0,88,193,2,0,17,170,2,0,107,152,2,0,197,173,2,0,151,228,2,0,197,173,2,0,107,152,2,0,251,133,2,0,131,154,2,0,131,154,2,0,251,133,2,0,215,115,2,0,216,87,2,0,215,115,2,0,11,53,2,0,11,53,2,0,66,20,2,0,0,0,2,0,13,178,3,0,83,236,3,0,224,159,3,0,0,128,3,0,188,15,3,0,13,178,3,0,10,106,3,0,201,110,3,0,173,0,3,0,0,0,4,0,13,178,3,0,0,128,3,0,188,15,3,0,83,236,3,0,224,159,3,0,204,59,3,0,20,212,2,0,147,153,3,0,109,83,3,0,0,128,3,0,204,59,3,0,97,38,3,0,88,193,2,0,13,178,3,0,10,106,3,0,201,110,3,0,173,0,3,0,204,59,3,0,20,212,2,0,147,153,3,0,109,83,3,0,0,16,3,0,197,173,2,0,215,102,3,0,141,36,3,0,188,15,3,0,20,212,2,0,252,249,2,0,131,154,2,0,0,128,3,0,204,59,3,0,97,38,3,0,88,193,2,0,0,16,3,0,197,173,2,0,215,102,3,0,141,36,3,0,197,173,2,0,216,87,2,0,67,226,2,0,17,170,2,0,251,133,2,0,11,53,2,0,188,15,3,0,20,212,2,0,252,249,2,0,131,154,2,0,197,173,2,0,216,87,2,0,67,226,2,0,17,170,2,0,251,133,2,0,11,53,2,0,0,0,0,0,0,0,0,0,192,212,1,0,10,0,0,0,1,0,0,0,233,3,0,0,48,117,0,0,30,0,0,0,224,1,0,0,208,2,0,0,8,0,0,0,9,0,0,0,32,0,0,0,27,0,0,0,192,82,50,0,136,24,141,0,7,0,0,0,6,0,0,0,88,1,29,0,90,0,0,0,44,6,0,0,172,5,0,0,29,4,0,0,64,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,152,41,23,0,1,0,0,0,0,0,0,0,128,50,2,0,12,0,0,0,1,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,64,2,0,0,208,2,0,0,16,0,0,0,15,0,0,0,64,0,0,0,45,0,0,0,144,67,50,0,136,24,141,0,0,0,0,0,6,0,0,0,88,1,29,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,40,41,23,0,1,0,0,0,0,0,0,0,128,50,2,0,12,0,0,0,1,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,64,2,0,0,208,2,0,0,16,0,0,0,15,0,0,0,64,0,0,0,45,0,0,0,96,52,50,0,136,24,141,0,7,0,0,0,6,0,0,0,88,1,29,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,40,41,23,0,0,0,0,0,4,0,0,0,128,169,3,0,10,0,0,0,2,0,0,0,233,3,0,0,48,117,0,0,30,0,0,0,224,1,0,0,208,2,0,0,8,0,0,0,9,0,0,0,32,0,0,0,27,0,0,0,16,27,50,0,136,24,141,0,4,0,0,0,6,0,0,0,88,1,29,0,90,0,0,0,44,6,0,0,172,5,0,0,29,4,0,0,64,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,152,41,23,0,1,0,0,0,4,0,0,0,0,101,4,0,12,0,0,0,2,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,64,2,0,0,208,2,0,0,16,0,0,0,15,0,0,0,64,0,0,0,45,0,0,0,176,252,49,0,136,24,141,0,4,0,0,0,6,0,0,0,88,1,29,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,40,41,23,0,0,0,0,0,20,0,0,0,0,83,7,0,10,0,0,0,4,0,0,0,233,3,0,0,48,117,0,0,30,0,0,0,56,4,0,0,0,5,0,0,1,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,216,211,50,0,136,240,141,0,4,0,0,0,8], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1506818);
/* memory initializer */ allocate([96,1,29,0,90,0,0,0,44,6,0,0,172,5,0,0,29,4,0,0,64,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,152,41,23,0,1,0,0,0,20,0,0,0,0,202,8,0,12,0,0,0,4,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,56,4,0,0,160,5,0,0,1,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,200,125,50,0,136,240,141,0,4,0,0,0,8,0,0,0,96,1,29,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,40,41,23,0,0,0,0,0,24,0,0,0,128,169,3,0,10,0,0,0,2,0,0,0,233,3,0,0,96,234,0,0,60,0,0,0,208,2,0,0,192,3,0,0,1,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,136,186,50,0,136,112,141,0,4,0,0,0,8,0,0,0,96,1,29,0,90,0,0,0,44,6,0,0,172,5,0,0,29,4,0,0,64,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,66,6,0,0,152,41,23,0,1,0,0,0,24,0,0,0,0,101,4,0,12,0,0,0,2,0,0,0,1,0,0,0,50,0,0,0,50,0,0,0,208,2,0,0,192,3,0,0,1,0,0,0,1,0,0,0,4,0,0,0,3,0,0,0,104,95,50,0,136,112,141,0,4,0,0,0,8,0,0,0,96,1,29,0,90,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,40,41,23,0,1,0,0,0,1,0,0,0,128,50,2,0,12,0,0,0,1,0,0,0,1,0,0,0,25,0,0,0,25,0,0,0,64,2,0,0,208,2,0,0,16,0,0,0,15,0,0,0,64,0,0,0,45,0,0,0,144,67,50,0,136,24,141,0,0,0,0,0,6,0,0,0,88,1,29,0,108,0,0,0,104,7,0,0,206,6,0,0,240,4,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,128,7,0,0,40,41,23,0,255,255,255,255,255,255,255,255,255,0,0,0,255,255,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,0,0,0,0,18,9,27,0,36,0,0,0,24,12,36,0,48,0,0,0,36,18,54,0,72,0,0,0,0,1,2,3,4,5,5,4,3,2,1,0,0,1,2,3,4,5,5,4,3,2,1,0,0,1,2,3,4,5,0,0,0,1,2,2,1,0,0,1,2,2,1,0,0,1,2,2,1,0,0,1,2,2,1,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,10,0,10,1,10,2,10,3,20,0,20,1,20,2,20,3,30,0,30,1,30,2,30,3,40,0,40,1,40,2,40,3,50,0,50,1,50,2,50,3,60,0,60,1,60,2,60,3,70,0,70,1,70,2,70,3,0,64,0,65,0,66,10,64,10,65,10,66,20,64,20,65,20,66,30,64,30,65,30,66,40,64,40,65,40,66,50,64,50,65,50,66,60,64,60,65,60,66,70,64,70,65,70,66,0,67,20,67,40,67,60,67,2,6,8,0,4,0,0,0,9,4,13,0,18,0,0,0,0,4,9,13,18,22,27,31,36,40,0,0,0,0,0,0,0,36,72,26,62,98,16,52,88,6,42,78,32,68,104,22,58,94,12,48,84,2,38,74,28,64,100,18,54,90,8,44,80,34,70,106,24,60,96,14,50,86,4,40,76,30,66,102,20,56,92,10,46,82,1,37,73,27,63,99,17,53,89,7,43,79,33,69,105,23,59,95,13,49,85,3,39,75,29,65,101,19,55,91,9,45,81,35,71,107,25,61,97,15,51,87,5,41,77,31,67,103,21,57,93,11,47,83,0,0,0,0,0,30,60,20,50,80,10,40,70,6,36,66,26,56,86,16,46,76,12,42,72,2,32,62,22,52,82,18,48,78,8,38,68,28,58,88,24,54,84,14,44,74,4,34,64,1,31,61,21,51,81,11,41,71,7,37,67,27,57,87,17,47,77,13,43,73,3,33,63,23,53,83,19,49,79,9,39,69,29,59,89,25,55,85,15,45,75,5,35,65,0,0,0,0,0,0,128,187,0,0,68,172,0,0,0,125,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,1,1,2,3,4,5,6,7,8,16,18,20,22,24,28,52,0,240,210,71,0,0,0,0,0,0,32,65,0,0,0,0,0,14,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,234,34,0,168,38,34,0,44,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,56,13,33,0,104,166,32,0,48,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,16,75,32,0,240,49,40,0,52,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,72,213,39,0,240,49,40,0,52,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,224,109,39,0,32,29,39,0,56,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,120,216,38,0,32,29,39,0,56,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,240,146,38,0,80,88,38,0,24,0,0,0,5,0,0,0,0,35,38,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,88,242,37,0,80,88,38,0,24,0,0,0,5,0,0,0,0,35,38,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,200,196,37,0,96,162,37,0,60,0,0,0,5,0,0,0,168,122,37,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,104,55,37,0,96,162,37,0,60,0,0,0,5,0,0,0,168,122,37,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,0,0,0,0,0,0,0,0,0,0,0,126,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,46,37,0,112,0,0,0,80,44,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,234,34,0,208,129,35,0,44,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,56,13,33,0,16,107,35,0,48,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,16,75,32,0,152,87,35,0,52,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,72,213,39,0,152,87,35,0,52,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,224,109,39,0,112,70,35,0,56,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,120,216,38,0,112,70,35,0,56,0,0,0,5,0,0,0,80,136,33,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,240,146,38,0,24,52,35,0,24,0,0,0,5,0,0,0,0,35,38,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,88,242,37,0,24,52,35,0,24,0,0,0,5,0,0,0,0,35,38,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,200,196,37,0,128,28,35,0,60,0,0,0,5,0,0,0,8,241,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,104,55,37,0,128,28,35,0,60,0,0,0,5,0,0,0,8,241,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,1,0,0,0,0,0,0,0,0,0,0,126,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,229,36,0,112,0,0,0,128,47,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,1,0,0,0,6,0,0,0,5,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,1,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,1,0,0,0,5,0,0,0,125,96,55,103,106,79,95,97,127,111,0,0,0,0,0,0,1,0,0,0,0,0,0,0,9,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,9,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,96,86,3,0,0,0,0,0,104,86,3,0,0,0,0,0,0,0,2,128,1,0,0,0,0,0,1,2,0,0,1,2,0,0,2,128,1,0,0,0,248,161,36,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,236,38,0,248,164,38,0,0,0,0,0,0,0,0,0,0,0,2,128,2,0,0,0,0,0,2,128,1,0,0,0,104,28,39,0,112,0,0,0,16,189,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,32,32,32,33,32,32,32,32,32,32,32,34,32,32,32,32,32,32,33,37,32,32,32,32,32,32,36,39,32,32,32,32,32,34,39,44,32,37,32,32,35,40,43,49,32,33,36,36,40,43,50,60,34,37,39,44,51,56,61,70,0,32,34,35,36,36,36,37,36,37,39,40,41,40,40,40,41,41,42,41,41,43,44,44,45,46,48,55,60,57,52,50,49,49,52,52,53,55,58,62,65,73,82,82,80,78,73,68,71,82,90,90,88,87,90,95,100,107,103,97,95,93,99,99,0,12,13,1,2,3,4,5,14,30,62,63,0,0,0,0,3,4,4,3,3,3,3,3,4,5,6,6,0,0,0,0,0,32,35,36,37,37,38,40,42,46,49,50,50,49,49,53,56,56,57,58,60,62,64,65,63,64,64,65,66,65,67,71,72,74,74,74,74,77,81,78,72,73,82,85,89,88,84,80,90,100,90,90,88,87,90,95,114,128,125,129,134,125,116,116,3,3,5,7,5,0,9,11,13,15,7,17,19,21,23,25,27,29,9,11,31,33,35,37,13,39,41,43,45,47,49,15,17,51,53,55,57,59,61,63,65,19,21,67,69,71,73,75,77,79,81,83,23,25,27,85,87,89,91,93,95,97,99,101,103,105,107,29,31,33,109,111,113,115,117,119,121,123,125,127,129,3,5,7,35,37,39,41,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,43,45,47,49,51,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,0,2,2,0,0,0,0,2,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,12,0,26,0,27,0,56,0,57,0,58,0,118,0,119,0,120,0,242,0,243,0,244,0,245,0,246,0,247,0,240,1,241,1,242,1,243,1,244,1,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,228,7,229,7,230,7,231,7,232,7,233,7,234,7,235,7,236,7,237,7,220,15,221,15,222,15,223,15,224,15,225,15,226,15,227,15,228,15,229,15,230,15,231,15,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,222,31,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,160,127,161,127,162,127,163,127,164,127,165,127,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,110,255,111,255,112,255,113,255,114,255,115,255,116,255,117,255,118,255,119,255,120,255,121,255,122,255,123,255,124,255,125,255,126,255,127,255,128,255,129,255,130,255,131,255,132,255,133,255,134,255,135,255,136,255,137,255,138,255,139,255,140,255,141,255,142,255,143,255,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,4,5,5,6,6,6,7,7,7,8,8,8,8,8,8,9,9,9,9,9,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,4,0,5,0,12,0,26,0,27,0,28,0,58,0,118,0,119,0,120,0,242,0,230,1,231,1,208,3,209,3,210,3,211,3,212,3,213,3,214,3,215,3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,224,3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,3,252,3,253,3,254,3,255,3,0,0,0,0,1,3,3,4,5,5,5,6,7,7,7,8,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,0,0,0,32,32,34,34,34,34,35,35,35,36,37,36,36,35,36,38,38,38,38,38,38,38,38,38,38,39,41,44,43,41,40,40,40,40,39,40,41,40,39,40,43,46,46,44,44,44,42,41,43,46,48,50,55,58,53,48,50,55,58,61,62,62,62,0,12,13,1,2,3,4,5,14,30,62,63,0,0,0,0,3,4,4,3,3,3,3,3,4,5,6,6,0,0,0,0,0,32,35,36,36,35,36,39,41,43,45,44,41,39,40,42,43,43,45,48,48,48,50,50,50,51,51,51,51,52,53,54,51,49,51,52,52,56,57,55,54,54,55,56,55,58,58,58,60,61,62,62,59,57,58,58,61,59,59,59,61,62,62,62,3,3,5,7,0,9,11,5,13,15,17,7,19,21,23,9,25,27,29,31,33,11,35,37,39,41,43,13,45,47,49,51,53,55,57,59,15,17,61,63,65,67,69,71,73,75,77,79,81,19,21,23,83,85,87,89,91,93,95,97,99,101,103,105,25,27,29,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,31,33,35,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,37,39,41,43,45,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,47,49,51,53,55,57,119,121,123,125,127,129,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,116,0,117,0,118,0,119,0,240,0,241,0,242,0,243,0,244,0,245,0,236,1,237,1,238,1,239,1,240,1,241,1,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,220,7,221,7,222,7,223,7,224,7,225,7,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,212,15,213,15,214,15,215,15,216,15,217,15,218,15,219,15,220,15,221,15,222,15,223,15,224,15,225,15,226,15,198,31,199,31,200,31,201,31,202,31,203,31,204,31,205,31,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,186,63,187,63,188,63,189,63,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,208,63,209,63,210,63,211,63,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,197,127,198,127,199,127,200,127,201,127,202,127,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,4,0,5,0,12,0,26,0,27,0,28,0,58,0,118,0,119,0,120,0,242,0,230,1,231,1,208,3,209,3,210,3,211,3,212,3,213,3,214,3,215,3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,224,3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,3,252,3,253,3,254,3,255,3,0,0,0,0,1,3,3,4,5,5,5,6,7,7,7,8,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,0,0,0,32,32,33,34,35,35,35,34,34,35,36,36,36,36,36,37,38,38,38,38,38,39,39,38,38,39,41,43,43,42,41,40,40,39,40,41,41,39,39,40,42,47,50,47,45,46,46,44,45,46,47,49,54,58,54,48,49,54,57,60,62,63,63,10,62,11,12,13,0,1,2,3,4,14,30,126,127,0,0,4,6,4,4,4,3,3,3,3,3,4,5,7,7,0,0,0,32,35,36,36,35,36,39,41,43,45,44,41,39,40,42,43,43,45,48,49,51,52,50,50,51,51,51,51,52,53,54,51,49,51,52,52,56,57,55,54,54,55,56,55,58,58,58,60,61,62,62,59,57,58,58,61,59,59,59,60,62,63,63,3,3,5,7,0,9,11,5,13,15,17,7,19,21,23,9,25,27,29,31,33,11,35,37,39,41,43,45,13,47,49,51,53,55,57,59,15,17,61,63,65,67,69,71,73,75,77,79,19,21,81,83,85,87,89,91,93,95,97,99,101,103,105,23,25,27,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,29,31,33,35,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,37,39,41,43,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,111,113,45,47,49,51,53,55,109,115,117,119,121,123,125,127,129,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,116,0,117,0,118,0,119,0,240,0,241,0,242,0,243,0,244,0,245,0,236,1,237,1,238,1,239,1,240,1,241,1,242,1,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,222,7,223,7,224,7,225,7,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,212,15,213,15,214,15,215,15,216,15,217,15,218,15,219,15,220,15,221,15,222,15,223,15,224,15,225,15,226,15,227,15,200,31,201,31,202,31,203,31,204,31,205,31,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,186,63,187,63,188,63,189,63,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,208,63,209,63,210,63,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,197,127,198,127,199,127,200,127,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,33,33,35,35,35,35,35,35,35,34,35,38,40,39,37,37,37,36,35,36,38,40,41,42,44,45,44,42,41,40,38,36,36,37,38,40,43,44,45,45,45,45,45,45,41,39,41,45,47,47,48,48,48,46,44,45,47,47,48,47,47,0,32,36,37,36,37,39,39,41,43,43,42,41,41,41,42,43,43,43,44,44,44,46,47,46,45,45,45,45,46,44,44,45,44,42,41,43,46,45,44,45,45,45,46,46,46,45,44,45,44,45,47,47,48,49,48,46,45,46,47,47,48,47,47,0,32,33,33,34,35,36,35,33,33,35,36,37,37,38,37,37,37,36,37,37,37,38,39,37,36,37,40,42,45,46,44,41,42,44,45,47,49,50,48,46,48,49,50,52,52,50,49,47,48,50,50,51,51,50,49,49,51,52,51,49,47,47,47,0,32,37,42,45,45,45,44,38,37,40,42,44,49,51,47,41,40,43,44,46,48,51,54,51,47,47,45,47,50,51,49,46,47,49,47,50,55,55,51,48,49,51,51,52,52,54,54,49,49,52,53,54,54,53,53,55,59,63,62,60,60,60,60,0,32,33,34,34,35,36,37,36,37,38,38,38,39,39,40,40,38,38,39,38,37,39,41,41,42,43,45,45,46,47,46,45,43,39,37,37,40,44,45,45,46,46,46,47,47,46,44,42,43,45,47,48,49,50,49,48,46,47,48,48,49,49,49,0,32,36,38,37,37,40,41,40,40,42,42,41,41,41,41,42,43,44,44,45,46,46,45,44,45,45,45,45,46,47,46,45,44,42,41,43,45,45,47,48,48,48,46,47,47,46,47,46,45,45,47,48,49,50,49,48,46,48,49,48,49,49,49,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,20,21,17,18,19,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,0,0,0,32,32,33,34,33,33,33,33,33,33,33,33,35,37,37,36,36,35,36,38,38,36,35,36,37,38,41,42,41,39,38,38,38,39,41,42,41,39,39,40,41,43,44,44,44,44,44,45,47,47,47,49,50,51,51,51,53,55,57,58,59,57,57,0,12,13,1,2,3,4,5,14,30,62,63,0,0,0,0,3,4,4,3,3,3,3,3,4,5,6,6,0,0,0,0,0,32,35,35,35,34,34,35,39,43,45,45,41,39,40,41,42,44,48,55,59,63,65,59,53,52,52,55,61,62,58,58,63,66,66,65,70,74,70,66,65,68,75,77,74,74,77,76,73,73,73,73,76,80,89,90,82,77,80,86,84,82,82,82,3,3,5,7,0,9,11,5,13,15,17,7,19,21,23,9,25,27,29,31,33,11,35,37,39,41,43,45,13,15,47,49,51,53,55,57,59,17,19,61,63,65,67,69,71,73,75,21,23,77,79,81,83,85,87,89,91,93,95,97,25,27,29,99,101,103,105,107,109,111,113,115,117,119,121,123,31,33,35,37,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,39,41,43,45,47,49,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,81,51,53,55,57,59,61,77,79,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,116,0,117,0,118,0,119,0,240,0,241,0,242,0,243,0,244,0,245,0,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,234,7,235,7,216,15,217,15,218,15,219,15,220,15,221,15,222,15,223,15,224,15,225,15,226,15,227,15,228,15,229,15,204,31,205,31,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,186,63,187,63,188,63,189,63,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,208,63,209,63,210,63,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,132,255,133,255,134,255,135,255,136,255,137,255,138,255,139,255,140,255,141,255,142,255,143,255,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1517060);
/* memory initializer */ allocate([15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,58,0,118,0,119,0,240,0,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,222,3,223,3,224,3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,3,252,3,253,3,254,3,255,3,0,0,0,0,1,3,4,4,5,5,5,6,6,6,6,6,7,7,8,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,53,57,58,59,60,61,62,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,54,55,56,0,0,0,32,33,34,34,36,37,36,36,37,38,38,38,39,41,44,43,41,40,41,46,49,47,46,47,49,51,54,60,62,59,55,54,56,58,61,65,66,64,63,66,73,78,79,80,79,78,78,82,87,89,90,93,95,96,97,97,100,104,102,98,98,99,99,0,12,13,1,2,3,4,5,14,30,62,63,0,0,0,0,3,4,4,3,3,3,3,3,4,5,6,6,0,0,0,0,0,32,36,39,39,38,39,41,45,51,57,58,53,48,47,51,55,58,66,75,81,83,82,78,73,72,74,77,83,85,83,82,89,99,96,90,94,97,99,105,109,105,95,89,92,95,94,93,92,88,89,90,93,95,96,97,97,100,104,102,98,98,99,99,3,3,5,0,7,9,5,11,13,15,7,17,19,21,23,25,9,11,27,29,31,33,13,35,37,39,41,43,15,45,47,49,51,53,55,17,19,57,59,61,63,65,67,69,21,23,25,71,73,75,77,79,81,83,27,29,31,33,85,87,89,91,93,95,97,99,101,103,105,35,37,39,41,43,107,109,111,113,115,117,119,121,123,129,3,45,47,49,51,53,55,125,127,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,2,0,0,0,2,0,0,0,0,0,2,2,0,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,0,0,0,0,0,0,0,0,0,0,1,2,2,2,2,2,2,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,5,0,12,0,26,0,27,0,56,0,57,0,58,0,59,0,120,0,121,0,244,0,245,0,246,0,247,0,248,0,242,1,243,1,244,1,245,1,246,1,238,3,239,3,240,3,241,3,242,3,243,3,232,7,233,7,234,7,235,7,236,7,237,7,238,7,239,7,224,15,225,15,226,15,227,15,228,15,229,15,230,15,231,15,232,15,233,15,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,222,31,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,156,127,157,127,158,127,159,127,160,127,161,127,162,127,163,127,164,127,165,127,166,127,167,127,168,127,169,127,170,127,171,127,172,127,90,255,91,255,92,255,93,255,94,255,95,255,96,255,97,255,98,255,99,255,100,255,101,255,102,255,103,255,104,255,105,255,106,255,107,255,108,255,109,255,110,255,111,255,112,255,113,255,114,255,115,255,116,255,117,255,118,255,119,255,120,255,121,255,122,255,123,255,124,255,125,255,126,255,127,255,128,255,129,255,130,255,131,255,132,255,133,255,134,255,135,255,136,255,137,255,138,255,139,255,140,255,141,255,142,255,143,255,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,3,4,5,5,6,6,6,6,7,7,8,8,8,8,8,9,9,9,9,9,10,10,10,10,10,10,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,32,32,32,33,32,32,32,32,31,32,33,33,33,33,35,36,36,34,34,36,37,37,36,36,35,36,38,39,39,37,36,37,37,39,41,42,41,39,39,40,41,42,43,42,42,41,41,41,44,47,46,46,48,51,51,50,50,53,55,55,56,60,60,0,32,33,34,34,33,34,35,37,40,43,42,39,38,39,41,43,44,47,50,55,61,63,56,48,46,49,54,59,58,55,58,63,65,67,74,84,82,75,72,70,74,84,87,87,94,93,81,75,78,83,89,91,86,82,85,90,90,85,79,73,73,73,73,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,18,20,17,19,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,0,0,10,62,11,12,13,0,1,2,3,4,14,30,126,127,0,0,4,6,4,4,4,3,3,3,3,3,4,5,7,7,0,0,3,3,5,7,0,9,11,5,13,15,17,7,19,21,23,9,25,27,29,31,33,11,35,37,39,41,43,13,15,45,47,49,51,53,55,57,59,17,19,61,63,65,67,69,71,73,75,77,21,23,79,81,83,85,87,89,91,93,95,97,99,101,25,27,29,31,103,105,107,109,111,113,115,117,119,121,123,125,127,3,33,35,37,39,129,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,41,43,45,47,49,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,51,53,55,57,59,61,63,65,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55,57,59,61,63,65,67,69,71,73,75,77,79,81,83,85,87,89,91,93,95,97,99,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,2,2,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,0,4,0,10,0,11,0,24,0,25,0,26,0,54,0,55,0,56,0,57,0,116,0,117,0,118,0,119,0,240,0,241,0,242,0,243,0,244,0,245,0,236,1,237,1,238,1,239,1,240,1,241,1,242,1,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,224,7,225,7,226,7,227,7,228,7,229,7,230,7,231,7,232,7,233,7,234,7,214,15,215,15,216,15,217,15,218,15,219,15,220,15,221,15,222,15,223,15,224,15,225,15,226,15,227,15,228,15,229,15,204,31,205,31,206,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,188,63,189,63,190,63,191,63,192,63,193,63,194,63,195,63,196,63,197,63,198,63,199,63,200,63,201,63,202,63,203,63,204,63,205,63,206,63,207,63,208,63,209,63,164,127,165,127,166,127,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,138,255,139,255,140,255,141,255,142,255,143,255,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,157,255,158,255,159,255,160,255,161,255,162,255,163,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,171,255,172,255,173,255,174,255,175,255,176,255,177,255,178,255,179,255,180,255,181,255,182,255,183,255,184,255,185,255,186,255,187,255,188,255,189,255,190,255,191,255,192,255,193,255,194,255,195,255,196,255,197,255,198,255,199,255,200,255,201,255,202,255,203,255,204,255,205,255,206,255,207,255,208,255,209,255,210,255,211,255,212,255,213,255,214,255,215,255,216,255,217,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,225,255,226,255,227,255,228,255,229,255,230,255,231,255,232,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,0,0,2,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,4,0,10,0,11,0,24,0,25,0,26,0,27,0,56,0,57,0,58,0,59,0,120,0,242,0,230,1,231,1,232,1,233,1,212,3,213,3,214,3,215,3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,224,3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,3,252,3,253,3,254,3,255,3,0,0,0,0,1,3,4,4,5,5,5,5,6,6,6,6,7,8,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,0,0,248,148,142,0,248,144,142,0,0,0,0,0,248,112,142,0,120,149,142,0,248,146,142,0,0,0,0,0,248,128,142,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,2,2,3,3,3,3,3,3,4,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,10,10,11,11,11,11,11,11,12,12,12,12,12,12,13,13,13,13,13,13,14,14,14,14,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,1,1,0,1,0,1,0,1,0,1,2,1,2,1,2,1,2,3,0,3,0,3,0,3,0,1,2,1,2,1,2,1,2,3,0,3,0,3,0,3,0,1,2,1,2,1,2,1,2,3,0,3,0,3,0,3,0,1,2,1,2,1,2,1,2,3,0,3,0,3,0,3,0,2,4,3,5,2,4,3,5,6,0,7,1,6,0,7,1,3,5,2,4,3,5,2,4,7,1,6,0,7,1,6,0,2,4,3,5,2,4,3,5,6,0,7,1,6,0,7,1,3,5,2,4,3,5,2,4,7,1,6,0,7,1,6,0,4,8,7,11,4,8,7,11,12,0,15,3,12,0,15,3,6,10,5,9,6,10,5,9,14,2,13,1,14,2,13,1,4,8,7,11,4,8,7,11,12,0,15,3,12,0,15,3,6,10,5,9,6,10,5,9,14,2,13,1,14,2,13,1,9,17,15,23,8,16,14,22,25,1,31,7,24,0,30,6,13,21,11,19,12,20,10,18,29,5,27,3,28,4,26,2,8,16,14,22,9,17,15,23,24,0,30,6,25,1,31,7,12,20,10,18,13,21,11,19,28,4,26,2,29,5,27,3,18,34,30,46,17,33,29,45,50,2,62,14,49,1,61,13,26,42,22,38,25,41,21,37,58,10,54,6,57,9,53,5,16,32,28,44,19,35,31,47,48,0,60,12,51,3,63,15,24,40,20,36,27,43,23,39,56,8,52,4,59,11,55,7,18,34,30,46,17,33,29,45,50,2,62,14,49,1,61,13,26,42,22,38,25,41,21,37,58,10,54,6,57,9,53,5,16,32,28,44,19,35,31,47,48,0,60,12,51,3,63,15,24,40,20,36,27,43,23,39,56,8,52,4,59,11,55,7,36,68,60,92,34,66,58,90,100,4,124,28,98,2,122,26,52,84,44,76,50,82,42,74,116,20,108,12,114,18,106,10,32,64,56,88,38,70,62,94,96,0,120,24,102,6,126,30,48,80,40,72,54,86,46,78,112,16,104,8,118,22,110,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,5,53,62,0,0,128,62,247,4,53,63,0,0,128,63,0,0,0,0,2,0,3,0,3,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,2,0,3,0,7,0,7,0,13,0,13,0,25,0,25,0,25,0,25,0,25,0,25,0,25,0,25,0,25,0,25,0,3,0,3,0,4,0,15,0,15,0,29,0,57,0,57,0,57,0,113,0,113,0,113,0,113,0,113,0,113,0,113,0,3,0,4,0,4,0,5,0,31,0,31,0,61,0,121,0,241,0,241,0,241,0,241,0,225,1,225,1,225,1,225,1,3,0,4,0,5,0,5,0,6,0,63,0,63,0,125,0,249,0,241,1,225,3,225,3,225,3,225,3,225,3,193,7,3,0,5,0,6,0,6,0,6,0,7,0,127,0,127,0,253,0,249,1,241,3,225,7,193,15,193,15,193,15,193,15,3,0,5,0,6,0,7,0,7,0,7,0,8,0,255,0,255,0,253,1,249,3,241,7,225,15,193,31,129,63,129,63,3,0,5,0,6,0,8,0,8,0,8,0,8,0,9,0,255,1,255,1,253,3,249,7,241,15,225,31,193,63,129,127,3,0,5,0,7,0,8,0,9,0,9,0,9,0,9,0,10,0,255,3,255,3,253,7,249,15,241,31,225,63,193,127,3,0,5,0,7,0,8,0,10,0,10,0,10,0,10,0,10,0,11,0,255,7,255,7,253,15,249,31,241,63,225,127,3,0,5,0,7,0,8,0,10,0,11,0,11,0,11,0,11,0,11,0,12,0,255,15,255,15,253,31,249,63,241,127,3,0,5,0,7,0,9,0,10,0,12,0,12,0,12,0,12,0,12,0,12,0,13,0,255,31,255,31,253,63,249,127,3,0,5,0,7,0,9,0,10,0,12,0,13,0,13,0,13,0,13,0,13,0,13,0,14,0,255,63,255,63,253,127,3,0,5,0,7,0,9,0,10,0,12,0,14,0,14,0,14,0,14,0,14,0,14,0,14,0,15,0,255,127,255,127,3,0,5,0,7,0,9,0,11,0,12,0,14,0,15,0,15,0,15,0,15,0,15,0,15,0,15,0,16,0,255,255,0,192,48,240,12,204,60,252,128,64,176,112,140,76,188,124,32,224,16,208,44,236,28,220,160,96,144,80,172,108,156,92,8,200,56,248,4,196,52,244,136,72,184,120,132,68,180,116,40,232,24,216,36,228,20,212,168,104,152,88,164,100,148,84,0,48,12,60,3,51,15,63,32,16,44,28,35,19,47,31,8,56,4,52,11,59,7,55,40,24,36,20,43,27,39,23,2,50,14,62,1,49,13,61,34,18,46,30,33,17,45,29,10,58,6,54,9,57,5,53,42,26,38,22,41,25,37,21,0,48,12,60,3,51,15,63,32,16,44,28,35,19,47,31,8,56,4,52,11,59,7,55,40,24,36,20,43,27,39,23,2,50,14,62,1,49,13,61,34,18,46,30,33,17,45,29,10,58,6,54,9,57,5,53,42,26,38,22,41,25,37,21,0,48,12,60,3,51,15,63,32,16,44,28,35,19,47,31,8,56,4,52,11,59,7,55,40,24,36,20,43,27,39,23,2,50,14,62,1,49,13,61,34,18,46,30,33,17,45,29,10,58,6,54,9,57,5,53,42,26,38,22,41,25,37,21,0,0,96,0,24,0,120,0,6,0,102,0,30,0,126,0,64,0,32,0,88,0,56,0,70,0,38,0,94,0,62,0,16,0,112,0,8,0,104,0,22,0,118,0,14,0,110,0,80,0,48,0,72,0,40,0,86,0,54,0,78,0,46,0,4,0,100,0,28,0,124,0,2,0,98,0,26,0,122,0,68,0,36,0,92,0,60,0,66,0,34,0,90,0,58,0,20,0,116,0,12,0,108,0,18,0,114,0,10,0,106,0,84,0,52,0,76,0,44,0,82,0,50,0,74,0,42,0,4,8,12,16,0,0,0,0,4,12,16,24,0,0,0,0,128,2,0,0,224,1,0,0,2,0,0,1,1,0,128,2,224,1,0,0,0,0,1,0,176,0,0,0,120,0,0,0,2,0,0,9,2,0,176,0,120,0,0,0,0,0,1,1,176,0,0,0,144,0,0,0,2,0,1,10,3,0,176,0,144,0,0,0,0,0,1,2,96,1,0,0,240,0,0,0,2,0,0,9,2,0,96,1,240,0,0,0,0,0,1,1,96,1,0,0,32,1,0,0,2,0,1,10,3,0,96,1,32,1,0,0,0,0,1,2,192,2,0,0,224,1,0,0,2,0,0,9,2,0,192,2,224,1,0,0,0,0,1,1,192,2,0,0,64,2,0,0,2,0,1,10,3,0,192,2,64,2,0,0,0,0,1,2,208,2,0,0,224,1,0,0,1,1,0,4,2,0,192,2,224,1,8,0,0,0,3,1,208,2,0,0,64,2,0,0,1,1,1,3,3,0,192,2,64,2,8,0,0,0,3,2,0,5,0,0,208,2,0,0,1,0,1,7,1,0,0,5,208,2,0,0,0,0,3,3,0,5,0,0,208,2,0,0,1,0,1,6,1,0,0,5,208,2,0,0,0,0,3,3,128,7,0,0,56,4,0,0,1,1,1,4,1,0,128,7,56,4,0,0,0,0,3,3,128,7,0,0,56,4,0,0,1,1,1,3,1,0,128,7,56,4,0,0,0,0,3,3,128,7,0,0,56,4,0,0,1,0,1,7,1,0,128,7,56,4,0,0,0,0,3,3,128,7,0,0,56,4,0,0,1,0,1,6,1,0,128,7,56,4,0,0,0,0,3,3,0,8,0,0,56,4,0,0,0,0,1,2,1,0,0,8,56,4,0,0,0,0,4,4,0,16,0,0,112,8,0,0,0,0,1,2,1,0,0,16,112,8,0,0,0,0,4,4,0,15,0,0,112,8,0,0,1,0,1,7,1,0,0,15,112,8,0,0,0,0,3,3,0,15,0,0,112,8,0,0,1,0,1,6,1,0,0,15,112,8,0,0,0,0,3,3,0,30,0,0,224,16,0,0,1,0,1,7,1,0,0,15,112,8,0,0,0,0,3,3,0,30,0,0,224,16,0,0,1,0,1,6,1,0,0,15,112,8,0,0,0,0,3,3,1,0,0,0,6,0,0,0,5,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,11,0,0,0,40,0,0,0,33,0,0,0,16,0,0,0,11,0,0,0,4,0,0,0,3,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,152,58,0,0,233,3,0,0,25,0,0,0,2,0,0,0,8,162,36,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,6,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,5,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,77,5,33,5,112,4,16,3,182,1,181,0,145,0,124,2,136,2,155,2,56,2,186,1,217,0,106,1,171,1,184,1,162,2,12,2,76,1,117,0,95,254,121,0,39,1,212,1,209,1,230,0,44,0,35,255,109,255,16,255,149,0,80,0,134,1,22,1,106,0,94,254,212,253,40,2,255,1,235,0,144,0,161,255,43,0,193,0,18,1,150,0,67,0,34,0,239,254,213,255,130,255,171,0,160,1,26,1,63,0,158,254,140,254,170,255,168,254,148,255,162,255,74,255,167,255,168,253,184,252,56,255,209,1,2,1,245,255,3,255,208,255,73,1,97,0,222,254,225,253,229,252,158,254,198,253,139,255,187,0,10,0,123,255,96,254,180,255,150,253,127,255,9,255,141,254,45,0,180,255,21,1,2,252,201,251,126,0,218,1,254,0,127,0,52,0,231,254,76,0,89,255,151,254,229,254,217,253,229,254,137,255,204,255,255,255,134,0,224,255,52,255,97,254,40,4,59,3,125,2,172,2,208,1,209,0,12,0,226,1,160,1,193,1,115,1,79,1,38,1,194,0,207,2,64,2,109,1,135,0,113,0,91,0,57,255,42,1,176,0,237,1,110,1,194,0,163,0,36,0,221,255,20,255,253,254,220,255,252,255,99,0,152,0,158,255,206,254,229,255,228,0,90,0,111,0,170,255,91,0,13,0,45,255,254,254,150,255,86,0,192,255,73,0,221,255,199,255,225,255,162,0,35,0,64,255,147,255,177,254,139,253,190,255,195,255,128,255,66,1,17,254,99,253,40,253,193,0,31,0,36,255,122,0,68,1,95,0,167,255,165,255,103,254,58,253,102,255,0,0,22,255,92,0,33,0,169,254,159,253,36,255,169,254,104,254,36,254,113,253,103,255,82,0,222,0,22,254,23,253,1,255,49,0,208,255,135,0,129,255,119,0,189,255,184,254,122,254,240,254,223,253,200,255,199,255,126,255,246,255,249,255,92,255,209,255,234,255,216,3,40,4,193,3,56,2,210,0,229,255,16,0,43,3,179,2,242,2,2,2,224,0,221,255,166,0,150,2,192,2,106,2,130,1,57,0,45,255,255,254,254,1,103,1,162,1,137,1,91,0,112,255,238,255,63,255,225,255,229,255,223,0,89,0,113,255,24,0,144,255,158,255,215,1,63,1,185,0,3,0,175,0,252,0,146,0,209,255,16,1,48,0,45,255,22,255,146,0,69,0,203,0,108,1,68,0,204,255,51,0,253,254,34,254,71,253,163,254,10,253,11,254,63,0,11,254,255,252,223,254,79,0,201,254,15,254,150,255,251,0,53,0,21,255,43,254,129,252,140,252,145,0,96,254,217,253,140,0,123,255,245,253,249,252,44,0,186,254,89,254,55,253,15,254,170,255,81,254,99,0,11,253,252,252,96,255,180,255,210,255,224,255,123,1,85,0,221,255,56,255,111,254,105,253,240,251,9,255,76,255,182,254,164,255,136,254,27,0,73,255,146,255,255,4,62,4,13,3,246,1,68,1,164,0,157,0,170,2,210,1,193,1,21,1,146,0,28,0,153,1,123,2,216,1,134,1,107,0,24,255,230,253,117,255,196,0,140,1,76,1,213,0,209,0,227,255,175,255,150,0,161,255,200,254,76,0,179,255,192,254,206,255,46,0,9,0,47,0,175,0,139,0,30,0,128,1,218,0,206,0,232,255,6,255,160,255,236,254,73,255,26,0,119,0,38,0,14,0,252,255,123,255,204,255,35,254,154,253,37,252,53,253,137,253,211,252,200,0,24,253,15,252,215,251,23,253,137,253,85,255,18,0,119,255,5,255,29,254,155,253,44,252,77,251,12,0,163,253,1,253,206,253,82,253,192,251,253,253,58,0,54,255,84,254,242,252,208,251,160,255,22,255,77,255,32,254,59,253,210,251,127,252,125,255,164,255,65,1,111,255,63,255,0,254,39,253,196,253,3,253,46,255,181,254,183,253,243,253,137,253,231,254,48,255,209,254,141,4,80,4,171,3,60,3,204,2,170,1,155,0,6,0,147,255,52,3,10,3,159,1,113,0,229,255,125,1,83,1,58,1,9,1,121,0,247,255,38,254,139,254,47,0,72,2,186,1,99,0,25,255,143,255,16,254,218,255,227,254,6,1,49,1,170,0,4,0,181,253,212,253,69,0,66,0,215,1,98,1,13,0,118,255,70,0,238,255,106,0,67,0,167,0,210,254,67,254,115,255,185,0,191,0,151,0,83,0,123,255,255,254,247,253,48,253,58,255,134,0,210,255,74,255,205,252,112,251,247,252,0,2,103,1,95,0,143,255,137,0,254,255,182,255,118,255,111,254,142,255,141,254,14,255,46,254,204,0,223,0,225,255,44,255,64,255,236,253,131,253,46,254,82,253,0,1,21,1,117,255,139,251,36,251,131,254,181,255,202,255,14,0,88,0,201,254,115,0,113,255,13,254,169,254,124,0,96,254,152,253,109,255,121,255,43,0,252,255,121,0,143,254,67,3,15,3,129,2,134,1,99,1,94,1,64,0,72,0,194,0,187,1,211,1,180,1,219,0,116,1,208,1,113,1,192,0,4,0,100,255,184,255,30,255,57,0,206,0,47,1,205,0,188,0,101,0,9,1,216,255,51,255,24,254,72,255,20,1,64,0,230,255,39,255,79,254,215,254,137,0,72,1,52,1,223,254,122,1,81,0,204,254,47,254,57,0,219,255,227,0,156,255,24,0,220,255,105,255,199,0,8,0,143,0,86,254,71,253,221,251,123,255,132,1,161,0,65,1,124,253,1,252,9,251,39,0,66,0,133,255,70,0,116,1,177,0,83,255,212,253,215,253,208,254,67,255,139,255,143,254,87,254,134,255,50,254,104,255,183,255,119,253,174,252,91,251,1,253,241,1,104,1,222,0,226,252,141,251,81,250,66,255,174,1,234,0,179,0,42,0,162,255,107,254,76,253,38,0,54,255,10,255,87,255,146,254,222,254,168,255,192,255,32,0,220,254,242,3,155,3,170,3,198,2,209,1,230,0,86,1,217,0,44,1,30,4,163,2,68,0,54,254,77,255,78,0,197,1,60,1,18,0,19,255,16,254,13,255,167,0,21,0,168,1,215,0,165,255,209,254,86,255,222,254,175,255,186,255,189,255,40,0,54,0,197,255,159,254,85,254,166,255,53,0,94,0,9,0,54,0,228,255,62,1,27,1,15,0,16,255,198,255,79,0,181,255,135,255,229,0,35,0,58,0,6,0,123,255,161,254,254,253,24,253,190,252,63,253,119,255,164,0,156,251,148,250,225,251,26,255,183,255,40,0,36,0,93,255,23,255,236,253,239,252,110,251,71,253,96,0,236,252,65,252,10,255,82,254,144,253,91,255,248,255,168,252,228,253,138,253,117,252,175,254,186,255,76,0,87,252,238,251,109,253,35,253,48,255,199,0,230,255,245,253,78,0,158,255,11,254,155,252,134,252,175,255,144,253,65,253,211,255,164,254,231,255,87,0,70,255,237,3,55,3,34,2,249,0,90,0,234,255,207,0,42,1,141,1,125,1,63,1,200,0,62,0,47,1,217,1,123,1,133,0,9,255,136,253,71,254,75,0,28,1,208,0,135,1,115,0,231,255,44,0,95,0,184,255,79,0,161,255,193,255,127,255,219,254,203,0,92,255,163,254,115,0,122,0,69,0,255,255,122,1,92,1,170,0,99,0,58,0,77,255,210,254,188,0,66,255,254,255,150,0,23,0,205,255,245,255,216,0,153,253,161,252,190,251,109,250,222,252,208,255,250,255,63,252,4,251,244,249,41,253,198,255,56,0,223,0,132,255,1,255,207,253,36,252,3,251,108,255,174,255,32,254,108,253,133,252,89,251,197,250,187,254,20,0,147,253,107,252,240,250,186,250,8,1,33,1,50,0,180,252,2,252,191,250,207,250,219,254,46,0,22,1,252,254,44,254,195,252,104,251,235,253,208,253,178,255,41,255,28,254,202,252,47,251,233,252,15,0,118,255,21,5,37,5,238,4,24,4,204,2,101,1,192,255,66,2,56,3,157,3,34,3,118,2,106,1,102,0,214,1,157,3,255,2,2,2,71,1,190,0,144,255,225,0,236,1,239,1,181,1,86,2,128,1,211,255,43,0,82,0,214,255,175,0,7,2,86,1,192,255,208,254,102,255,159,0,64,2,147,1,221,0,71,1,214,0,244,0,122,0,194,255,56,1,92,0,96,255,218,0,208,0,54,1,12,1,50,1,67,1,57,255,227,254,243,254,177,255,132,255,113,255,103,255,236,0,51,255,128,254,86,254,88,1,59,0,71,255,72,255,240,254,247,0,126,0,46,255,250,253,44,254,78,0,157,255,136,255,246,1,160,0,232,254,211,253,48,1,89,254,239,255,229,254,69,254,215,0,212,0,116,255,204,253,84,253,28,255,254,1,105,1,130,0,67,1,84,254,79,1,98,0,191,255,36,0,41,255,10,255,150,254,51,0,108,1,240,255,22,255,150,0,91,255,146,3,115,3,239,2,141,2,164,2,208,1,103,255,119,2,33,2,23,2,208,2,84,2,104,1,175,255,15,3,200,2,0,2,183,1,85,1,251,0,121,254,241,1,161,1,249,0,116,1,39,1,173,0,63,255,128,0,146,255,127,254,93,0,39,0,173,0,25,255,216,0,197,255,3,255,206,1,133,1,154,0,69,0,199,1,14,1,252,255,175,254,207,255,233,0,190,254,51,1,143,0,53,0,218,0,128,0,236,0,100,255,219,255,70,255,16,255,101,254,146,255,9,0,143,1,116,255,147,254,140,253,2,1,124,1,214,0,21,1,131,0,198,1,177,0,227,254,248,253,108,0,42,255,77,0,115,255,201,0,133,255,22,254,125,255,60,0,242,255,62,255,247,253,27,253,17,1,106,1,223,255,150,254,202,253,225,254,28,255,161,0,237,0,61,1,243,254,195,0,181,255,137,254,52,255,11,0,77,0,128,255,248,254,100,255,33,255,37,254,9,1,27,0,214,4,123,4,148,3,177,2,176,1,210,0,232,254,32,3,152,2,111,3,214,2,155,1,160,0,92,255,198,1,174,2,24,2,19,1,147,0,46,0,111,0,47,1,230,1,0,2,99,1,241,0,181,0,187,255,79,0,92,0,29,0,147,0,233,0,52,0,17,0,85,255,33,1,131,0,183,1,15,1,3,0,246,255,157,1,241,0,144,0,174,0,155,0,254,255,14,0,58,0,217,0,247,0,219,0,149,0,175,0,238,255,228,0,248,255,16,255,50,255,255,253,65,255,202,0,160,255,240,254,58,254,33,0,212,254,193,253,46,0,246,255,148,255,10,255,165,254,254,252,233,253,9,0,186,254,82,254,195,255,191,254,64,253,213,254,201,0,255,255,232,254,165,253,93,254,71,255,18,0,220,255,252,253,246,253,133,254,221,254,75,255,159,255,27,0,97,255,199,254,243,253,32,255,2,254,193,252,59,255,220,254,53,254,197,255,202,254,206,253,113,255,161,254,42,4,144,3,119,2,133,1,207,0,86,0,32,255,84,2,0,2,84,2,249,1,58,1,122,0,208,255,19,3,93,3,185,1,163,255,209,254,33,0,66,255,1,1,213,1,81,1,51,0,15,0,42,1,163,255,39,1,73,0,137,255,25,0,36,0,23,0,108,0,228,255,253,255,224,255,114,0,21,0,185,0,107,0,226,1,49,1,15,0,233,254,193,254,52,0,96,0,226,0,46,0,115,0,72,0,120,255,133,0,131,255,18,0,49,255,209,253,178,253,9,254,30,254,65,1,197,253,235,252,73,252,84,255,71,254,230,253,113,0,181,0,14,0,202,254,127,253,23,252,54,255,159,0,120,255,119,254,79,254,255,253,113,252,112,255,234,255,72,0,247,254,62,253,70,252,97,255,53,0,76,1,174,254,177,253,172,252,129,254,117,254,56,0,44,0,43,0,98,255,48,254,127,252,137,253,99,255,218,254,95,255,128,255,184,254,195,253,29,254,131,255,11,0,249,3,138,3,27,4,237,3,167,2,85,1,154,255,103,1,78,1,31,6,34,5,211,2,105,0,10,0,191,255,214,2,17,2,45,1,220,0,43,0,239,254,2,254,180,1,207,2,54,2,102,1,179,0,114,0,208,253,42,1,133,0,136,255,86,1,225,0,14,0,125,252,155,255,217,0,105,2,144,1,146,0,198,255,215,255,96,1,82,0,60,255,39,0,121,0,89,255,44,255,59,0,191,1,28,1,167,1,250,0,87,255,141,254,28,254,172,253,30,0,215,255,249,0,22,0,140,254,118,253,230,252,221,1,189,1,216,0,177,255,160,254,19,1,17,0,69,254,95,252,92,0,19,0,69,253,72,253,175,1,8,1,207,255,202,254,182,0,46,252,39,255,82,254,112,254,101,0,5,1,72,0,95,252,135,252,155,254,243,255,207,1,122,1,236,0,198,252,56,0,30,0,213,254,152,254,128,255,205,255,146,252,213,254,145,255,75,0,65,0,36,0,3,0,49,3,112,1,231,255,98,1,185,2,79,2,83,255,53,1,212,0,222,0,239,2,228,1,140,0,200,255,81,2,123,1,70,0,248,255,2,1,180,0,110,0,165,0,210,255,255,0,41,1,219,0,17,1,105,0,160,0,186,255,154,254,75,255,123,1,74,1,63,1,18,255,143,254,58,255,228,2,68,2,63,1,113,255,201,0,109,0,54,255,56,254,72,1,20,1,115,255,203,0,170,0,111,0,42,0,207,0,104,1,188,0,167,254,113,254,255,253,23,255,138,2,166,1,81,0,133,253,63,252,60,251,207,1,27,2,204,0,209,0,202,0,231,255,62,255,14,254,237,252,193,0,113,255,63,254,230,253,195,0,150,255,181,254,68,0,62,0,28,255,35,254,184,252,192,253,61,1,128,0,27,1,97,253,87,252,217,252,142,255,135,1,79,1,194,255,246,0,2,0,198,254,89,253,209,254,180,0,168,255,149,255,240,254,90,0,58,255,228,255,34,1,144,255,117,3,125,4,253,3,200,2,240,1,25,1,173,255,13,1,236,1,19,3,131,2,91,1,70,0,124,0,80,1,124,2,243,1,92,0,27,255,77,255,191,0,26,0,146,1,52,2,84,1,149,0,245,255,135,0,72,254,49,2,214,1,204,0,184,255,70,255,140,0,48,253,14,0,99,1,229,0,68,0,123,255,209,1,110,0,54,1,103,0,12,0,106,0,29,0,158,0,78,255,113,0,161,0,142,0,121,0,115,0,27,0,117,253,98,254,123,253,104,255,92,255,243,255,83,254,129,253,80,252,87,253,152,255,175,255,52,0,67,255,105,253,92,255,196,254,85,253,70,252,51,255,173,255,159,253,99,253,84,255,251,253,74,253,27,1,176,255,122,253,104,255,129,254,90,253,10,255,216,255,113,255,21,253,228,252,23,253,122,254,158,255,43,0,19,1,169,253,57,255,114,254,79,254,76,254,230,253,31,0,173,251,200,253,136,254,247,254,130,255,235,255,1,0,79,3,61,2,52,1,136,1,49,1,101,0,55,0,17,1,37,1,201,0,11,1,90,1,201,0,123,0,215,2,224,1,226,0,2,0,191,255,118,255,164,0,17,1,208,0,173,0,36,1,12,0,253,0,174,0,84,1,207,0,180,0,88,0,116,0,46,0,219,1,52,254,90,255,226,255,13,0,110,0,173,0,140,1,137,0,88,0,43,0,119,255,162,255,34,0,28,1,96,0,242,255,226,0,40,0,63,0,70,0,130,0,45,254,33,253,12,252,106,251,205,254,49,1,189,255,156,253,104,252,134,251,201,253,248,255,92,0,231,255,74,255,241,254,20,254,14,253,167,252,31,1,181,255,18,254,237,252,79,253,85,253,59,253,137,0,186,254,224,254,218,253,121,252,175,251,78,1,65,1,194,255,158,254,115,253,190,252,67,254,1,0,121,1,104,255,94,255,206,254,160,253,87,252,215,254,247,0,64,255,22,255,35,254,12,255,24,254,246,254,86,1,180,254,169,0,142,0,137,255,115,0,206,0,236,255,94,0,226,0,150,255,57,1,235,255,16,0,194,255,161,0,71,0,255,0,167,255,101,0,71,255,125,0,72,0,226,255,55,255,88,1,254,254,33,0,248,255,81,0,152,255,102,255,72,0,40,1,144,0,188,255,244,254,231,255,81,0,178,255,169,255,106,0,22,0,155,0,70,255,137,255,210,255,228,255,27,0,91,0,142,255,219,255,81,255,223,255,162,255,34,255,67,255,122,0,124,255,137,255,65,255,242,254,84,255,83,255,18,0,213,255,23,1,135,0,214,255,128,255,187,0,170,255,229,0,118,255,159,0,240,0,140,0,46,0,69,0,25,0,227,0,77,0,21,0,115,0,13,0,8,0,68,0,8,255,126,0,81,0,106,255,137,0,207,0,247,255,102,255,123,255,33,1,67,0,143,0,219,255,170,255,186,254,180,0,224,255,19,0,233,255,26,0,168,0,116,0,23,255,224,255,230,255,118,0,178,255,3,0,248,255,211,255,141,255,57,0,41,255,202,255,173,255,47,255,112,0,234,255,89,255,165,255,105,255,168,0,250,254,177,255,167,255,252,255,85,255,77,0,45,255,160,0,63,255,98,0,120,0,153,255,67,1,32,0,234,255,127,255,72,0,78,0,244,254,182,0,180,255,190,255,53,1,99,0,111,255,27,255,99,255,172,255,129,254,98,0,185,255,166,255,160,254,12,0,228,254,78,255,178,0,191,255,131,255,90,255,169,255,81,255,161,254,42,0,58,255,208,255,154,0,116,255,13,255,179,255,18,0,108,0,217,255,99,1,91,0,87,0,8,0,155,0,252,255,158,0,239,0,128,0,95,0,202,255,7,0,246,0,132,255,2,1,15,0,89,0,206,0,216,0,98,0,55,255,9,0,18,0,200,254,233,0,204,0,217,255,82,255,155,0,112,255,247,255,28,1,199,255,70,0,187,255,99,255,187,0,18,0,54,0,226,255,23,0,24,0,135,0,55,0,81,0,238,255,68,0,229,255,134,255,232,254,252,255,45,0,79,255,209,0,226,255,120,255,182,255,131,0,212,255,101,0,181,255,168,255,208,255,119,255,202,255,11,255,228,255,63,0,238,255,144,255,153,255,58,0,177,255,250,255,220,0,191,255,114,0,221,255,206,255,109,0,191,255,143,0,142,255,129,0,76,0,125,0,166,0,90,0,195,255,14,255,186,0,182,255,213,255,210,255,164,255,49,0,29,255,24,0,101,255,39,0,67,0,85,0,99,0,214,255,53,0,72,255,231,254,142,0,134,255,0,0,21,0,114,255,241,255,239,255,223,0,92,0,235,255,208,255,174,255,242,255,89,255,51,0,219,255,13,255,226,255,166,255,18,0,200,255,54,0,105,0,74,0,86,0,69,0,13,0,155,255,196,0,72,0,167,255,43,0,65,0,19,0,39,0,121,0,34,0,131,0,174,255,25,0,213,0,100,255,101,0,154,255,120,255,235,255,57,0,214,0,22,0,36,0,132,255,205,0,204,0,58,0,100,255,173,255,83,0,139,255,137,0,137,0,85,0,116,0,44,0,164,255,108,255,188,255,11,0,154,255,59,255,36,255,180,255,71,255,198,255,132,0,230,255,73,255,85,0,249,255,225,255,254,255,23,0,205,0,105,255,10,0,229,255,219,255,251,255,238,255,36,1,131,0,1,0,117,0,88,255,9,0,163,255,80,0,197,255,131,255,74,255,12,255,98,0,232,255,135,0,234,255,94,0,221,0,97,0,106,0,42,0,43,0,96,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1527300);
/* memory initializer */ allocate([83,0,25,0,192,255,235,255,6,0,14,0,241,255,154,0,126,0,15,0,116,255,150,0,246,255,49,255,142,255,79,0,193,255,45,255,186,255,228,255,39,255,165,0,46,0,38,0,234,255,25,1,132,0,194,255,109,0,112,0,54,0,144,255,163,255,208,0,27,0,40,1,115,0,10,0,109,255,41,0,216,0,42,0,236,254,50,0,141,255,2,255,167,0,117,0,254,255,61,0,17,0,144,0,34,0,184,255,70,255,106,255,16,1,227,255,190,255,167,255,161,255,107,255,129,0,251,0,122,0,0,0,206,255,22,255,165,255,36,0,26,0,151,255,154,255,168,255,135,255,20,255,249,255,245,255,52,255,109,0,5,0,65,255,105,0,241,255,163,0,176,255,32,0,232,255,47,255,41,0,38,1,70,0,150,255,162,255,52,255,138,255,120,0,206,255,219,255,174,255,15,255,46,0,125,255,227,255,150,0,201,255,33,0,155,0,120,0,167,255,248,255,7,0,62,0,213,0,82,0,61,0,18,0,95,255,144,0,152,0,30,0,131,0,65,0,169,255,1,255,239,255,149,255,248,255,85,0,192,255,51,0,94,255,223,0,203,255,122,255,5,1,69,0,200,255,218,0,72,0,145,255,2,0,155,0,143,255,169,255,49,0,85,0,228,255,93,255,42,0,255,255,60,255,7,0,39,0,11,255,14,0,119,255,177,255,11,0,96,255,202,0,219,254,162,255,33,0,208,0,100,0,56,0,212,255,70,1,178,255,215,255,232,0,13,0,114,255,227,0,80,0,240,255,169,255,201,0,33,0,123,255,15,0,73,255,198,255,64,255,209,255,184,0,128,255,133,0,99,0,51,255,11,0,101,255,78,0,52,0,72,0,141,0,10,255,26,0,99,0,151,0,59,0,115,0,192,255,177,255,209,255,240,255,242,255,6,0,47,0,213,255,184,255,78,255,229,255,162,0,112,0,43,0,82,255,81,255,238,0,186,0,71,0,202,255,68,255,180,255,31,255,233,0,39,0,217,255,98,255,122,0,44,0,230,255,43,0,84,0,130,0,163,255,205,255,22,0,3,0,92,0,106,255,136,0,74,255,199,255,97,0,125,255,179,0,178,255,80,0,91,0,91,255,90,0,254,255,148,0,15,0,130,0,65,0,175,0,117,0,118,255,114,0,119,255,132,0,3,0,246,255,70,255,140,0,252,255,219,255,254,0,194,255,92,0,147,255,246,255,151,0,103,1,136,0,42,1,223,0,255,0,152,255,34,1,167,1,6,0,183,0,242,254,243,254,158,255,204,255,174,255,13,0,174,255,238,254,159,255,90,0,10,255,184,255,213,254,186,255,165,1,168,255,109,1,174,1,187,0,194,254,125,1,124,1,37,0,232,1,139,254,196,254,79,0,204,254,155,255,5,0,121,255,61,254,8,0,72,0,91,254,102,255,180,0,170,0,135,255,62,0,177,0,216,255,70,1,80,0,151,255,248,0,7,1,251,255,88,255,75,255,35,255,254,255,233,255,98,255,242,255,107,255,135,255,119,0,165,255,109,255,119,0,76,1,103,255,49,0,47,1,34,0,186,1,201,255,187,255,217,0,198,1,58,0,153,254,69,255,137,254,214,255,50,0,238,254,248,255,245,254,7,255,85,0,170,255,166,254,179,255,216,255,89,1,89,0,134,0,219,0,156,0,176,255,160,0,108,0,40,0,116,0,98,255,50,255,29,0,5,0,224,255,175,0,191,255,98,255,146,0,55,0,178,255,73,0,142,255,34,255,97,1,209,255,81,0,211,0,49,0,105,255,12,1,105,0,4,0,46,1,249,254,124,255,183,0,105,255,228,255,201,0,79,255,205,254,166,0,101,0,35,255,130,0,74,0,58,0,158,255,32,0,44,0,13,0,194,0,30,0,114,255,170,0,96,0,8,0,120,255,137,255,165,255,191,255,8,0,201,255,3,0,68,255,12,0,45,0,193,255,207,255,149,0,235,255,237,255,24,0,144,0,95,0,254,0,234,255,60,0,161,0,196,0,96,0,98,255,195,255,48,0,186,255,33,0,82,0,233,255,191,254,58,0,155,0,109,255,5,0,148,254,72,1,77,0,235,255,197,1,173,0,148,255,82,0,118,2,111,1,7,1,208,0,212,254,194,255,80,255,51,255,143,0,98,255,87,255,102,254,248,254,1,1,243,254,156,255,132,253,33,1,254,255,220,254,115,2,173,0,130,254,149,254,131,1,248,0,12,2,191,1,247,253,145,255,149,255,117,254,118,0,238,254,169,254,88,253,131,255,84,255,65,254,105,253,75,0,148,0,145,254,177,255,7,1,162,255,249,0,148,0,226,254,124,1,15,1,94,255,114,255,252,255,70,255,199,255,111,0,131,255,221,255,148,255,2,255,100,0,29,0,14,255,176,255,47,1,248,254,178,255,208,1,199,255,248,0,234,255,18,254,149,2,150,2,44,0,63,255,216,255,182,254,78,255,145,0,175,254,166,255,57,255,112,254,216,255,233,255,14,254,64,255,114,0,59,1,215,255,244,0,190,0,88,0,159,255,229,1,241,0,80,0,212,0,10,255,40,0,87,0,100,255,147,0,134,0,254,255,178,254,239,0,52,1,53,255,110,0,53,254,251,0,166,1,38,255,54,1,228,0,170,255,166,254,142,2,184,0,175,0,169,1,31,254,193,255,169,0,163,254,117,0,188,0,131,255,208,253,54,1,158,0,96,254,94,0,46,0,171,0,64,255,193,255,157,0,14,0,0,1,221,255,241,254,66,1,123,0,53,0,42,255,4,0,180,255,100,255,86,0,238,255,128,0,59,255,24,255,9,1,166,255,158,255,204,254,76,1,111,255,125,255,52,1,58,0,253,1,59,0,173,254,50,2,196,0,242,255,134,254,100,0,209,255,22,255,202,0,1,0,104,0,242,254,19,254,63,1,46,255,187,254,214,254,250,255,95,0,31,0,43,255,169,255,134,255,5,1,4,0,207,255,208,0,14,0,127,255,146,255,30,0,118,0,42,255,2,1,110,0,21,255,215,255,238,255,130,255,120,0,103,0,65,0,127,0,219,255,126,0,220,255,232,255,25,0,118,255,189,255,234,254,70,255,92,255,62,255,55,255,78,0,45,255,169,255,205,255,35,255,82,255,177,255,162,255,217,255,23,0,250,255,99,255,16,255,22,0,146,255,103,255,188,255,148,0,251,255,254,255,107,255,255,255,121,255,217,255,77,255,68,0,104,1,139,255,241,255,137,0,47,0,234,254,146,0,136,0,4,1,135,0,65,0,61,0,116,0,211,255,97,0,231,0,123,1,87,0,136,255,82,1,177,0,240,254,3,0,10,1,156,0,28,0,187,255,4,1,84,0,171,255,86,0,246,254,154,0,0,255,74,255,239,255,191,255,208,254,250,255,216,255,175,0,105,255,76,255,229,255,27,0,169,255,193,255,121,0,114,0,90,255,43,254,159,0,190,255,189,254,25,255,214,0,152,0,115,255,44,255,137,0,36,0,72,255,205,255,230,254,19,255,40,0,10,0,208,255,21,255,219,255,251,0,202,255,189,254,136,0,29,0,168,255,82,255,213,0,198,0,122,254,99,0,193,255,137,254,107,0,87,255,92,255,168,1,69,0,145,255,141,0,89,255,74,0,127,255,65,0,144,0,159,254,49,255,51,255,147,255,96,255,126,254,157,254,98,0,80,255,19,254,236,255,113,255,4,255,80,254,254,255,216,0,166,255,82,255,88,255,101,254,13,0,228,254,27,255,96,255,169,255,233,254,34,0,5,255,181,255,249,254,198,255,214,255,164,1,53,0,45,255,154,254,128,1,221,255,138,254,140,1,68,0,28,255,67,1,254,255,167,0,205,254,192,0,194,0,203,1,73,1,251,255,180,254,119,1,79,0,249,255,57,1,26,1,132,255,200,0,164,255,15,1,94,255,186,255,180,0,99,255,214,254,254,253,203,254,58,0,93,255,222,253,18,0,124,0,148,254,167,0,18,255,83,0,101,254,139,255,96,0,140,0,144,255,124,254,144,253,3,1,123,255,195,254,41,0,163,0,126,255,192,255,178,254,226,0,91,255,132,255,146,255,46,254,195,255,6,0,229,0,103,255,205,0,111,255,242,0,97,255,48,0,195,0,148,0,198,255,28,0,31,0,23,1,209,254,185,0,23,1,252,255,195,255,197,0,59,0,86,0,142,255,123,0,168,0,204,255,35,0,36,0,100,0,126,0,105,254,102,0,179,255,216,255,174,254,255,255,170,254,156,0,77,255,105,0,222,255,159,255,71,255,84,0,221,255,108,0,123,255,107,0,165,255,155,254,76,255,54,0,27,255,24,0,212,255,47,0,47,0,74,255,190,255,13,0,45,0,4,0,173,254,251,0,64,0,226,0,214,255,101,0,162,254,19,1,157,255,142,1,142,0,121,0,111,0,12,0,154,255,4,1,0,0,249,1,4,1,162,255,161,0,29,1,160,255,224,0,252,255,206,0,58,1,33,0,167,0,139,0,88,0,204,0,21,255,60,1,196,255,231,255,248,255,106,255,200,254,201,0,220,255,36,1,61,0,152,255,216,255,174,0,94,255,42,0,235,255,146,1,227,255,161,254,21,0,152,0,152,254,163,255,57,0,191,0,212,0,60,255,76,0,158,0,235,255,187,255,184,254,71,255,75,1,119,0,203,255,29,1,56,0,81,1,149,255,232,255,149,1,29,0,238,255,137,0,16,1,21,1,1,255,22,0,173,0,65,255,39,1,66,1,69,1,46,1,21,0,229,255,76,1,78,255,119,0,13,0,15,1,129,0,57,254,76,255,116,0,65,255,29,255,62,0,108,255,12,2,80,255,225,254,26,1,99,255,13,255,13,0,199,0,174,1,197,255,207,255,115,0,147,254,72,0,84,255,119,255,93,0,118,255,130,255,141,0,172,255,5,0,132,255,38,0,236,255,254,254,55,1,89,2,213,0,94,0,130,0,195,255,246,1,255,255,99,255,229,1,57,1,146,0,182,255,158,0,89,1,20,1,135,0,24,1,199,255,234,1,252,0,99,0,43,0,11,1,182,255,173,1,105,0,22,1,233,255,119,0,94,0,226,253,232,1,1,1,141,255,172,255,12,255,74,254,222,1,143,255,223,253,131,1,101,0,161,255,206,254,111,0,242,1,95,0,166,0,22,0,211,254,164,1,241,255,198,255,178,255,14,1,29,0,122,0,230,254,160,0,16,255,50,0,218,255,129,255,54,1,42,0,14,255,197,0,5,0,105,255,84,0,239,255,42,255,127,0,107,255,9,255,125,255,159,0,244,254,245,254,161,255,39,255,1,0,177,255,241,254,176,255,71,255,211,255,180,1,159,0,165,0,199,0,135,1,223,255,81,0,187,0,190,255,214,255,99,1,214,254,199,255,87,1,148,255,231,253,226,0,112,255,233,255,193,0,176,0,110,254,87,0,53,0,40,1,25,0,172,255,253,0,152,255,198,255,105,0,130,255,87,255,174,0,198,254,208,255,44,0,218,254,92,255,95,254,14,255,117,255,3,0,62,255,101,255,49,255,45,255,119,0,66,1,213,0,77,1,50,0,124,1,237,0,247,0,254,255,210,1,240,255,201,0,238,0,1,255,149,255,67,0,72,254,107,255,122,0,168,255,117,255,88,0,9,255,183,255,215,255,231,0,167,0,194,255,155,0,16,0,191,255,16,0,77,0,188,255,254,255,193,255,105,255,212,254,160,0,238,255,179,254,54,0,200,255,162,255,5,0,2,0,66,255,14,0,92,0,148,0,209,0,108,0,9,0,16,1,108,0,35,0,110,0,142,0,171,255,145,0,47,0,99,255,23,1,3,0,192,254,246,0,43,0,184,255,68,0,86,0,39,255,135,0,36,0,140,0,79,0,56,0,175,0,207,255,26,0,45,0,3,0,73,0,55,0,155,255,109,0,73,255,14,255,252,255,229,254,14,255,48,0,188,255,208,255,250,255,103,255,134,255,161,0,196,0,96,0,232,0,80,0,190,0,165,0,97,0,11,0,2,1,225,255,71,0,11,1,179,255,165,255,55,1,47,255,87,0,152,0,242,255,234,255,150,0,107,255,9,0,188,254,45,2,187,0,128,254,51,1,46,0,5,255,27,0,77,0,147,254,77,0,204,255,30,254,172,255,160,0,88,254,253,253,192,255,218,254,136,255,252,255,36,254,140,255,147,255,159,255,62,1,109,1,106,0,115,2,189,1,66,255,120,0,31,1,110,255,65,0,107,2,85,254,242,0,107,1,151,254,141,254,176,1,165,254,102,0,168,0,139,253,195,0,242,255,191,255,220,1,209,255,215,254,64,1,88,255,201,255,100,1,248,254,121,254,82,0,226,254,205,255,225,255,212,253,78,255,113,254,182,253,51,255,207,255,152,254,169,254,18,255,175,254,220,0,201,1,58,0,49,2,211,1,3,1,84,1,14,1,88,255,194,1,77,0,232,254,60,0,167,0,99,254,133,0,4,255,20,254,216,0,157,0,222,254,26,1,0,0,17,254,30,255,37,1,183,0,99,255,135,0,122,0,98,255,197,255,39,0,123,255,138,255,159,255,180,254,203,254,113,0,96,255,87,254,250,255,107,255,45,255,24,0,176,255,235,254,166,255,245,255,125,0,82,1,130,0,185,255,209,1,5,0,211,255,184,0,237,0,161,255,253,0,117,255,59,255,41,1,237,255,212,254,255,1,193,255,104,255,139,0,250,0,223,254,80,1,124,0,83,1,106,255,34,0,176,0,48,255,171,0,166,0,140,255,94,0,38,0,27,255,75,0,191,255,173,254,178,255,51,255,127,254,0,0,226,255,93,255,200,255,146,255,14,255,65,1,244,0,194,0,249,1,238,0,255,255,61,1,116,0,65,0,53,1,88,0,182,255,196,1,205,255,206,255,78,1,39,255,222,254,211,0,41,0,104,255,238,0,201,255,252,254,204,255,160,255,212,0,59,1,183,255,82,0,52,255,107,1,136,0,59,255,130,255,181,254,183,0,218,0,143,0,207,255,215,255,45,2,230,0,72,0,2,0,183,255,163,0,121,1,221,0,133,0,111,0,22,1,215,0,146,255,154,255,236,255,28,1,113,0,17,1,84,0,63,1,34,1,18,0,85,0,231,255,251,255,125,0,132,0,52,255,218,255,251,255,30,1,247,255,156,254,116,255,0,255,92,0,117,0,67,255,112,255,191,0,57,1,51,0,158,255,167,0,246,255,44,0,247,0,36,0,125,1,197,0,238,0,74,0,6,0,38,0,104,254,29,0,253,255,171,255,92,0,10,1,157,0,231,255,56,255,161,0,135,255,70,0,84,0,116,255,240,255,170,255,112,0,162,255,67,255,243,254,242,254,95,1,107,0,232,255,188,255,189,255,236,1,153,255,101,255,203,255,125,255,62,0,122,0,10,0,135,0,84,0,27,1,201,255,136,255,244,255,37,255,75,1,175,255,167,0,220,0,120,255,147,0,84,255,214,255,140,0,161,255,147,255,168,255,62,255,0,0,254,255,252,255,223,255,131,254,190,255,39,255,152,0,70,255,110,254,244,0,108,0,156,0,116,255,117,254,113,0,120,255,60,255,110,0,232,255,214,0,118,0,11,0,192,255,125,255,146,255,226,254,250,255,180,254,16,0,94,0,97,0,79,0,221,254,51,255,251,255,217,255,236,255,252,0,160,255,76,0,174,0,101,0,163,0,61,0,187,255,17,255,201,255,143,1,6,0,141,255,63,1,164,0,19,1,196,0,241,255,36,0,209,255,75,1,121,0,226,0,209,0,15,1,69,1,184,0,13,0,176,255,38,255,215,1,97,1,32,1,122,1,16,0,205,255,251,0,174,0,116,0,52,0,149,0,233,254,235,0,20,1,39,0,120,0,208,255,0,0,148,255,148,255,241,0,173,254,163,255,22,2,45,0,33,0,169,255,194,0,149,0,185,255,149,1,212,255,153,1,114,1,81,0,70,255,102,255,25,0,154,255,64,254,124,0,83,255,22,0,152,1,146,255,202,254,42,255,230,255,23,0,173,255,114,0,14,0,146,255,164,0,52,0,223,0,174,255,37,0,231,255,249,254,50,1,241,255,46,254,159,1,36,1,165,0,238,255,29,0,237,255,85,255,155,0,182,0,179,0,144,0,229,255,231,0,2,1,153,255,9,255,116,254,238,0,113,0,119,1,102,255,147,255,252,255,156,0,98,0,85,0,220,254,251,255,132,255,116,0,139,0,140,255,158,255,218,254,242,255,173,255,234,254,139,255,134,254,106,0,33,0,150,255,168,254,28,254,119,0,17,0,100,254,138,0,166,0,128,1,101,0,52,255,88,0,100,255,135,255,228,254,212,254,255,255,90,255,24,1,33,0,104,255,199,254,175,255,219,255,22,0,229,0,153,0,37,0,196,255,173,255,236,0,248,255,215,255,87,255,28,255,126,0,236,255,107,1,21,255,17,0,108,1,100,255,156,0,231,255,226,255,72,0,144,0,156,0,153,0,230,255,0,1,97,0,144,0,235,255,219,255,48,0,191,255,250,0,63,0,77,0,17,1,128,255,124,0,127,255,230,255,40,0,9,0,141,255,250,255,82,0,38,0,166,255,74,255,176,254,243,255,28,0,158,0,91,0,226,255,241,0,137,0,86,255,239,255,146,0,14,0,245,255,33,0,61,0,192,0,197,0,54,0,172,255,85,0,23,0,56,255,178,255,227,255,140,0,122,0,237,0,106,0,171,254,136,0,199,255,114,255,171,255,240,255,182,255,197,255,166,255,248,255,69,255,236,255,45,255,245,254,216,0,77,255,146,255,206,255,249,255,220,0,245,254,186,255,199,255,214,255,239,255,241,255,71,0,32,0,21,0,63,0,119,255,33,0,119,255,81,255,104,0,188,255,97,0,189,255,213,255,133,0,211,254,221,0,140,255,56,255,175,255,164,255,240,254,192,255,215,255,202,255,12,255,36,255,225,254,14,255,206,255,169,255,167,255,11,255,236,0,102,0,90,255,217,254,66,0,24,0,94,255,185,255,95,0,66,0,136,0,166,255,36,255,220,255,158,255,95,255,34,255,68,255,29,0,238,255,18,0,237,255,97,254,9,0,49,0,61,0,100,0,39,0,200,255,145,255,82,0,135,0,225,255,52,0,166,255,103,255,163,255,189,0,182,0,42,255,39,1,119,0,182,255,28,1,2,0,137,0,37,0,47,0,182,0,92,0,117,0,184,0,203,255,117,1,235,255,242,255,221,255,136,0,135,1,146,0,129,0,92,255,228,255,77,1,92,0,80,0,172,255,100,0,122,255,248,255,217,0,224,255,3,0,209,255,105,255,251,0,41,255,142,0,92,0,32,255,54,1,84,255,237,254,98,0,159,0,155,0,79,255,112,0,53,0,205,0,27,0,8,0,16,255,192,0,169,0,120,0,193,254,55,255,106,0,11,0,36,0,170,255,19,255,199,1,147,255,102,255,93,255,174,0,201,255,218,255,32,0,155,255,178,255,197,255,51,255,191,254,159,255,69,0,79,0,202,254,44,0,18,0,71,255,34,0,141,255,236,255,108,255,217,255,203,0,227,255,154,0,226,255,98,255,166,0,211,255,125,255,195,254,232,255,107,1,91,255,51,255,144,255,34,255,9,1,224,255,212,255,106,255,54,0,63,255,250,255,218,255,1,255,87,255,141,255,246,254,87,0,67,255,220,255,87,255,196,255,169,255,246,254,76,254,86,255,188,255,175,255,234,254,24,0,38,0,233,255,237,255,101,255,0,255,141,0,195,255,30,255,203,253,81,255,71,0,9,0,227,255,19,255,253,253,7,1,73,1,153,1,249,0,223,255,249,1,160,0,227,255,242,255,70,2,250,254,127,0,98,1,145,0,237,0,175,0,104,255,245,0,122,0,27,0,42,0,84,1,172,255,163,255,55,1,29,1,222,0,100,255,47,0,213,255,8,254,234,0,121,0,129,1,104,0,195,254,45,0,176,0,195,0,8,0,104,0,197,255,162,255,177,0,53,0,192,0,222,255,129,255,152,0,58,2,21,1,222,255,189,255,183,254,129,253,99,255,240,254,206,1,79,255,50,254,198,0,66,1,179,0,115,0,126,254,171,0,19,0,19,0,244,255,195,0,136,255,4,255,201,0,48,1,36,0,176,254,128,255,35,255,132,254,171,0,71,255,40,1,14,255,200,254,23,0,198,0,39,0,16,0,253,255,79,255,145,255,111,0,163,255,76,0,164,255,33,255,4,0,177,0,150,1,212,255,88,255,124,1,107,255,252,255,17,1,75,1,92,254,1,2,21,1,21,0,247,0,47,0,198,255,131,0,254,255,253,255,134,0,180,0,111,255,40,0,175,0,189,0,74,0,111,255,229,255,211,255,187,254,114,1,142,255,235,255,173,255,97,254,83,255,77,0,95,0,205,255,216,255,226,255,189,255,71,0,88,0,86,0,221,255,158,255,14,0,69,0,197,0,178,254,60,255,79,0,25,255,164,254,119,255,218,0,160,254,167,255,171,255,47,0,201,0,126,255,91,255,37,0,241,255,213,255,3,0,86,0,95,255,148,255,79,0,83,0,21,0,19,255,175,255,107,255,18,255,150,0,70,255,5,255,70,255,7,255,94,255,237,255,66,0,117,255,230,255,206,255,75,255,24,0,11,0,0,0,126,255,151,255,158,255,67,2,57,4,11,4,134,1,3,0,249,254,58,255,174,255,38,0,18,0,188,255,244,255,57,1,249,2,149,1,249,0,111,0,180,255,228,2,239,4,12,5,238,3,229,3,251,3,249,3,208,3,155,3,165,255,59,3,180,3,136,2,101,2,23,2,10,2,234,1,165,1,41,0,212,255,231,254,40,254,140,2,22,2,193,0,135,0,166,255,41,0,135,255,156,254,196,255,151,2,51,1,61,0,208,255,168,254,45,2,178,3,25,4,99,3,78,3,222,3,88,4,238,4,217,4,138,255,52,255,72,1,0,2,102,3,25,3,98,2,146,1,186,0,156,0,37,1,74,0,174,254,37,254,127,252,174,253,95,255,15,254,226,0,131,0,118,255,51,1,169,0,241,254,92,255,125,254,144,253,62,0,224,255,195,255,4,255,227,253,196,252,253,251,245,253,106,253,102,0,195,255,141,0,112,0,242,254,5,255,227,253,25,0,106,255,6,0,124,255,156,254,82,253,160,255,190,254,246,253,225,255,186,254,220,255,47,255,247,253,27,255,51,1,124,255,251,255,157,255,128,254,60,0,205,255,19,255,100,253,51,252,105,254,60,253,181,255,84,255,26,0,118,255,246,254,111,0,210,254,43,0,234,254,156,254,153,254,58,2,54,3,240,1,102,255,200,254,164,255,137,0,23,1,115,1,110,255,112,1,153,1,68,0,6,0,77,0,167,0,202,0,162,0,121,2,130,3,228,3,244,2,150,2,171,2,15,3,141,3,228,3,153,255,38,1,95,2,159,1,227,1,206,1,224,1,175,1,152,1,136,255,174,254,156,253,244,253,72,2,75,1,92,0,177,1,20,1,78,255,219,254,102,255,215,255,13,1,100,0,247,255,213,0,160,0,62,3,224,2,22,1,52,3,230,4,174,2,200,2,15,4,217,1,38,255,208,254,207,1,198,1,141,1,17,1,202,0,30,1,17,1,24,255,7,0,6,0,124,254,40,254,85,254,134,254,89,255,156,255,218,254,73,255,134,0,209,255,101,0,168,255,172,255,139,255,253,255,57,0,17,0,54,255,134,253,35,252,161,251,235,253,176,0,220,255,120,0,228,255,23,0,111,0,193,254,62,1,234,255,179,255,10,1,241,254,48,254,78,254,110,253,128,253,127,254,127,254,157,255,187,255,58,255,253,254,246,254,212,255,217,255,117,255,119,255,171,0,66,0,9,0,111,255,135,254,178,252,24,252,145,255,187,254,86,1,135,0,175,255,226,254,132,254,192,0,199,255,51,1,76,0,232,255,116,255,165,2,190,2,247,0,56,0,249,0,141,0,151,255,20,255,157,255,36,0,217,255,187,255,92,1,198,0,163,255,66,1,91,0,184,255,247,1,117,3,228,5,27,5,2,5,148,4,95,4,185,4,37,4,160,1,207,2,221,3,203,4,233,3,28,4,186,3,229,2,20,4,129,255,136,254,111,253,139,0,111,2,223,0,245,1,50,1,220,0,143,255,128,254,228,252,248,1,182,1,85,0,213,0,173,255,62,255,73,2,108,4,209,4,67,4,223,4,153,5,232,5,168,5,34,5,82,255,90,254,7,0,131,4,65,4,158,4,235,3,177,3,38,3,8,0,130,255,195,254,153,255,161,254,73,253,158,255,244,254,231,253,33,0,153,255,222,254,167,0,217,255,105,254,44,0,48,255,137,254,104,0,233,255,192,255,221,254,131,253,173,252,196,251,195,255,144,255,181,255,206,254,78,254,218,0,108,255,158,254,88,253,123,255,40,255,135,255,135,254,50,253,159,255,126,255,151,254,100,255,133,254,169,253,200,255,2,255,182,253,235,0,157,0,42,255,11,0,252,254,107,255,132,255,245,254,115,254,188,253,175,253,241,253,219,252,127,254,90,1,63,255,72,254,60,253,161,254,115,255,1,255,13,254,109,255,71,255,192,1,148,2,238,1,208,0,253,1,205,1,82,1,35,1,149,0,33,255,88,0,79,1,159,0,212,0,191,0,30,1,52,1,205,0,225,255,213,1,35,3,147,2,107,2,146,2,75,3,219,3,89,4,85,255,14,255,2,2,106,1,39,1,12,2,40,2,182,2,73,2,192,255,204,254,64,254,235,255,28,1,18,3,190,1,33,1,92,0,38,255,122,254,249,255,169,0,206,0,74,1,96,1,152,1,102,1,220,255,190,2,191,3,91,3,93,3,91,4,245,4,77,5,25,5,123,255,171,254,191,255,166,2,161,1,184,1,230,1,6,2,12,3,33,0,212,255,65,255,168,254,51,254,13,253,55,255,217,0,225,255,159,254,221,253,212,255,123,0,195,255,188,255,177,255,29,0,60,0,73,0,199,255,106,254,2,253,37,251,77,251,240,0,144,1,165,0,183,255,230,254,167,253,43,255,85,255,137,254,76,1,35,0,153,255,227,255,49,255,215,253,36,254,130,253,116,252,172,0,234,255,121,255,64,255,17,255,92,255,153,255,145,255,209,255,153,0,125,0,110,0,255,255,53,255,198,253,250,251,112,250,233,253,155,0,1,0,147,0,179,254,115,253,159,252,59,255,98,255,235,255,212,255,95,0,108,0,133,1,76,2,234,1,33,0,19,255,244,253,140,253,120,255,252,254,40,0,79,255,50,254,197,1,94,3,124,1,131,0,126,255,107,254,74,3,142,6,49,7,13,6,194,5,232,4,58,4,137,3,230,2,114,1,192,4,232,6,97,6,188,4,124,2,22,0,182,254,71,0,180,255,231,254,27,253,26,253,130,3,107,2,21,1,71,0,34,255,224,255,247,254,212,253,231,255,226,3,170,2,49,1,126,0,91,255,73,0,226,2,125,3,200,3,225,3,232,6,225,8,48,7,111,5,187,255,163,254,183,253,234,0,134,4,135,3,114,2,254,1,251,0,255,255,157,255,240,254,46,255,165,253,161,254,228,253,213,252,129,254,240,255,26,255,8,254,154,1,149,0,51,255,169,254,117,253,129,253,103,0,247,255,29,255,51,255,206,253,243,252,201,251,72,251,100,255,143,0,63,0,121,255,189,255,195,254,166,253,240,252,126,251,128,253,112,255,121,254,94,253,146,253,56,255,2,255,108,253,77,252,117,254,216,255,6,255,143,253,27,0,31,2,94,0,125,255,126,254,95,253,133,255,141,254,11,253,61,254,204,253,154,253,97,254,57,253,221,255,140,255,203,254,175,253,244,254,239,0,223,255,174,254,118,253,121,255,94,0,251,0,42,2,57,0,200,254,89,254,102,255,199,255,235,0,244,254,185,255,125,1,114,0,212,255,169,255,125,0,173,0,133,0,233,5,178,6,214,4,22,2,20,1,59,1,205,1,203,1,252,1,125,255,237,255,125,4,158,2,230,1,100,1,53,1,113,1,40,1,33,255,11,254,125,252,46,253,186,255,6,0,131,0,54,1,138,1,157,255,209,254,251,253,249,0,64,0,203,255,135,0,245,255,197,1,109,255,113,254,38,253,111,254,49,3,226,2,34,3,237,2,63,2,102,255,77,254,29,253,32,3,81,2,110,1,17,2,62,1,70,1,32,255,45,0,217,255,125,254,253,253,250,253,160,253,128,254,191,254,197,254,135,254,143,0,155,255,143,255,135,254,79,255,112,255,244,255,117,0,40,0,17,255,117,253,229,251,187,253,31,253,34,252,184,254,26,0,206,255,99,255,233,255,59,254,229,254,237,253,222,253,192,0,4,255,11,254,25,253,179,253,141,253,13,254,184,254,138,255,184,255,188,254,18,254,12,255,206,254,112,255,79,255,250,254,121,255,178,255,220,255,22,255,249,253,63,252,246,250,198,254,33,254,141,254,211,255,161,255,220,254,233,253,248,255,212,254,112,0,92,255,235,254,198,0,157,255,128,255,112,3,68,3,67,2,95,1,23,0,161,255,39,255,229,255,254,254,124,0,243,3,85,2,169,1,144,0,7,0,183,255,165,1,13,5,104,6,87,6,206,6,81,6,219,5,4,5,238,3,161,255,240,2,144,6,33,6,82,6,156,5,176,4,212,3,200,2,187,255,212,254,85,253,77,254,108,4,131,3,248,1,76,1,109,0,182,255,189,254,131,253,51,2,50,4,96,2,115,1,105,0,207,255,178,255,63,3,170,4,86,4,98,5,201,5,212,5,85,5,193,4,253,254,135,255,160,5,54,5,92,6,210,5,158,5,199,4,165,3,174,255,206,254,155,253,34,255,134,254,93,253,223,253,97,253,179,252,53,0,132,255,165,254,166,1,52,0,131,255,242,254,239,253,9,0,79,0,167,255,192,254,106,253,25,252,81,251,37,251,92,253,215,254,188,255,239,254,157,253,137,0,110,255,115,254,141,253,179,252,36,255,144,255,166,254,227,252,198,252,234,0,124,255,68,255,234,254,246,253,97,255,107,254,34,253,93,254,37,1,74,0,89,255,89,255,184,0,103,255,75,254,191,252,200,251,176,254,40,254,207,253,172,254,3,255,87,255,89,254,204,252,120,252,125,255,237,255,166,254,164,253,31,0,33,0,225,255,56,1,62,0,108,255,49,0,197,255,52,2,230,1,206,254,179,254,194,0,212,255,67,0,72,0,147,0,205,0,243,0,49,255,207,255,80,5,215,3,201,3,223,3,246,3,86,4,205,3,45,255,84,255,115,3,115,2,199,2,162,2,193,2,30,3,234,2,168,255,187,254,5,253,50,252,175,2,140,3,2,2,126,1,172,0,220,254,156,253,219,252,63,0,131,0,14,1,3,1,96,1,92,1,21,255,172,255,187,3,50,3,96,4,9,5,23,6,200,5,5,5,76,255,51,254,154,253,145,2,179,2,233,2,86,3,15,3,201,2,159,255,203,254,35,254,154,253,247,252,34,253,0,253,242,253,40,254,168,254,36,254,221,255,87,255,49,0,179,255,106,255,16,255,115,255,204,255,244,254,129,253,105,252,2,251,167,251,170,254,179,254,105,255,188,255,14,255,183,253,183,255,47,255,34,254,97,255,83,254,133,0,59,255,13,254,19,252,12,251,240,254,32,255,151,255,189,255,17,0,149,254,150,253,98,254,140,255,194,255,20,0,10,0,116,0,108,0,61,255,37,254,118,252,20,251,133,252,71,254,235,254,114,255,228,255,30,255,249,253,74,252,68,253,237,254,246,254,140,255,151,255,82,0,148,1,255,1,8,2,71,1,17,0,62,255,179,254,232,253,182,253,142,255,126,255,20,1,237,0,204,0,86,1,135,0,240,255,145,255,158,2,184,4,144,4,92,3,230,2,89,2,16,2,147,1,53,1,141,1,109,2,198,3,240,2,67,2,142,1,144,1,73,1,252,0,191,0,180,0,119,255,45,254,16,1,106,0,161,255,17,0,64,255,176,255,222,254,142,253,194,0,86,2,196,0,21,0,231,254,77,0,254,1,96,3,84,4,39,3,171,3,134,3,157,3,205,2,225,1,137,0,111,1,22,2,252,2,158,2,126,1,40,1,153,0,84,0,47,1,241,1,144,0,171,255,131,255,229,253,30,254,48,254,4,253,233,0,91,1,68,0,109,255,169,0,46,255,14,255,30,255,30,254,51,1,166,1,154,0,81,255,126,254,46,253,44,253,120,252,9,252,53,1,52,1,160,0,196,255,42,254,92,254,170,253,233,252,37,255,68,0,121,0,119,255,208,253,110,255,66,254,253,253,18,254,39,253,130,0,53,0,29,255,46,0,218,1,32,0,95,255,64,255,22,254,213,0,164,0,185,255,47,254,148,252,95,255,56,254,181,253,208,255,218,0,117,0,39,0,177,0,62,255,168,255,30,255,94,254,50,0,210,0,35,2,57,2,23,1,121,0,212,255,206,255,10,0,172,255,58,0,140,0,182,0,251,255,11,1,117,0,106,0,211,0,198,0,27,2,67,3,145,3,207,2,105,2,32,2,79,2,53,2,130,2,153,0,47,2,104,3,204,1,222,0,108,0,188,0,180,0,183,0,158,0,119,0,28,1,103,255,241,254,229,0,87,0,110,0,199,255,73,255,82,0,118,0,21,0,13,0,40,0,118,0,191,0,185,0,162,0,121,3,142,2,108,0,222,255,244,0,232,1,49,2,20,2,163,0,56,0,97,2,85,1,50,0,73,1,68,0,10,1,218,0,100,0,206,0,18,0,208,254,149,255,76,254,25,254,191,255,206,254,170,255,154,0,134,0,226,255,211,255,183,255,152,255,176,255,160,255,245,0,74,1,10,0,72,254,175,252,198,251,79,0,40,0,247,254,196,0,116,1,16,1,75,255,19,254,123,254,19,1,80,0,197,255,2,0,244,255,10,255,7,254,156,255,76,254,21,0,69,255,81,254,35,255,208,255,36,0,241,254,70,255,109,255,147,255,26,0,71,0,213,0,140,0,72,0,161,254,148,253,172,255,149,254,69,0,46,0,91,0,167,0,253,255,161,255,157,255,151,255,208,255,114,0,147,0,3,1,249,0,172,0,95,2,150,1,52,0,59,0,67,255,192,254,115,0,171,255,202,255,62,2,128,0,226,0,197,255,3,255,130,0,194,255,9,4,28,5,11,4,103,4,74,4,5,4,193,3,55,3,39,0,108,1,245,2,172,3,216,2,148,2,147,2,71,2,2,3,141,255,174,254,8,253,41,254,138,1,37,0,185,1,178,0,6,0,199,255,207,254,243,253,28,3,197,1,188,0,252,255,142,255,248,0,71,0,188,1,29,3,219,2,72,4,133,4,198,4,5,4,43,3,135,0,103,1,39,2,169,1,237,2,47,3,106,3,192,2,246,1,132,0,247,0,0,0,50,255,63,254,18,253,254,254,254,253,135,253,248,0,249,0,91,0,121,0,61,255,13,254,166,255,230,254,77,254,78,0,20,0,235,254,145,253,41,252,56,251,97,254,54,254,129,253,91,1,253,1,208,0,77,255,48,254,40,253,180,255,19,255,26,254,153,255,169,254,12,253,55,253,247,254,159,253,65,255,114,254,132,253,135,255,129,254,19,253,55,2,252,0,220,255,158,254,95,254,206,255,204,0,100,0,107,255,118,253,199,251,209,255,249,255,249,254,111,0,210,255,76,255,245,254,188,254,206,253,118,254,76,253,142,1,36,1,226,1,158,2,171,2,112,2,186,1,165,0,116,0,36,0,107,255,108,0,247,0,35,1,247,0,99,1,122,0,109,0,224,0,40,1,242,255,177,3,222,3,33,3,243,2,47,3,79,3,145,3,124,3,36,1,93,1,213,2,226,1,132,1,73,1,173,1,108,2,155,2,222,255,197,0,213,0,129,255,84,0,238,1,108,2,63,2,119,1,126,0,207,0,172,0,167,0,106,1,202,0,40,1,139,1,199,1,250,255,250,0,27,2,211,1,124,2,33,3,125,4,7,5,94,4,27,0,240,0,113,1,24,1,184,1,155,1,122,2,124,3,185,3,159,0,170,0,198,255,117,254,227,252,78,253,77,0,45,255,178,254,251,255,228,255,243,255,182,255,177,254,165,253,44,1,88,0,51,255,82,0,223,255,148,254,70,253,77,251,127,251,110,0,110,255,223,254,113,0,1,0,13,255,180,253,30,252,16,254,158,1,160,0,42,0,200,255,9,255,72,254,75,253,28,252,33,254,11,0,78,255,155,254,105,255,159,254,185,254,45,255,172,254,141,0,65,0,169,1,197,1,34,0,87,255,57,254,92,252,65,251,138,0,243,1,0,1,68,1,68,0,139,0,241,255,221,253,34,254,17,0,50,1,246,1,225,1,224,255,122,255,189,1,129,0,113,255,12,255,9,254,5,254,169,253,61,0,116,255,167,254,240,1,202,1,254,255,20,0,29,255,254,253,138,1,229,6,130,6,59,5,93,4,38,3,130,2,223,1,124,1,215,0,7,2,152,3,29,4,66,4,23,3,16,2,34,1,155,0,202,255,23,255,121,253,166,253,127,2,38,1,254,255,89,255,70,254,178,255,197,254,233,252,143,255,52,3,147,1,158,0,140,255,156,254,17,2,59,7,211,7,204,4,110,2,215,255,96,254,88,1,51,3,151,255,133,254,20,255,200,4,125,3,237,2,56,2,100,1,214,0,239,255,57,255,112,255,50,0,229,254,9,255,190,253,178,252,193,251,69,0,245,255,131,254,50,255,209,0,228,254,125,254,96,254,52,253,39,0,251,255,111,255,138,254,86,253,115,252,206,251,111,251,214,251,31,1,226,0,67,0,35,255,106,253,85,255,91,254,126,253,61,253,124,255,164,254,230,253,64,254,236,255,252,255,158,254,20,253,91,252,4,0,181,255,223,254,170,253,61,1,52,0,48,255,215,254,209,253,168,255,248,254,154,254,179,253,137,253,8,255,245,253,202,252,209,251,70,0,248,255,54,0,198,254,253,253,92,0,110,255,238,254,19,254,199,0,62,0,135,1,158,0,115,255,71,0,37,255,53,255,49,255,152,0,40,0,73,1,162,0,227,255,48,0,107,255,108,0,127,0,123,2,34,4,115,3,236,1,116,1,56,1,61,1,18,1,241,0,11,1,210,2,232,4,114,3,113,2,248,0,8,0,175,255,196,255,198,255,118,255,221,254,168,253,244,255,254,255,217,255,147,0,117,0,149,255,167,254,255,253,203,1,76,0,92,0,240,254,132,1,6,1,106,1,4,2,203,0,103,254,52,253,193,252,181,254,185,0,209,0,139,255,121,254,214,254,159,2,36,1,26,2,1,1,166,0,218,255,154,255,193,254,62,255,229,254,195,253,250,254,189,253,37,255,68,254,21,255,78,0,11,0,88,255,155,255,27,255,249,254,191,254,133,255,70,0,50,0,86,255,169,253,28,252,180,253,249,254,252,253,57,254,138,1,107,1,229,0,120,255,230,253,21,0,73,255,164,254,55,255,132,255,144,254,128,253,145,252,177,252,47,255,103,254,18,254,253,253,129,255,171,254,227,253,87,254,2,254,246,255,4,255,39,254,221,254,84,0,187,255,55,255,92,253,156,252,103,0,201,254,124,255,192,254,5,0,83,255,68,255,215,254,140,253,197,0,199,255,7,0,245,255,49,0,96,255,56,0,46,2,111,0,33,0,201,254,72,254,49,254,255,255,10,255,205,254,94,3,197,1,139,0,86,255,157,254,24,255,23,1,198,3,106,6,198,5,183,5,99,4,27,3,13,2,83,1,59,255,218,255,166,6,51,5,228,4,182,3,180,2,248,1,170,1,148,255,168,254,163,252,108,251,188,1,98,1,88,0,210,255,36,255,203,255,191,254,18,254,89,4,232,2,108,1,198,0,222,255,181,255,201,1,187,3,153,4,190,4,147,5,177,5,65,5,149,3,27,2,187,255,199,0,129,3,116,4,63,5,159,4,209,3,230,2,10,2,122,0,44,0,243,254,27,0,101,255,206,253,205,254,178,253,251,252,154,0,42,0,96,255,252,0,127,255,207,254,41,254,35,253,141,254,135,0,185,0,174,255,96,254,46,253,111,252,8,254,25,253,144,252,149,0,214,0,172,255,183,254,88,253,189,252,86,254,107,253,175,255,128,255,132,254,33,253,26,252,175,254,17,0,74,255,45,254,71,253,172,255,222,254,2,254,176,253,13,0,184,1,154,0,218,255,233,254,70,0,195,255,10,255,41,253,233,251,176,255,131,254,233,253,64,253,178,0,254,255,110,255,98,253,86,252,226,1,138,0,63,0,65,0,245,255,15,0,4,3,187,1,142,0,236,255,47,255,130,255,95,255,224,255,7,255,95,0,40,2,124,0,30,0,169,254,82,0,170,255,148,0,239,2,235,5,81,4,99,3,94,2,218,1,192,1,143,1,93,255,255,254,131,3,73,4,138,3,239,2,246,1,134,1,38,1,205,255,254,254,65,254,218,252,144,254,251,2,208,1,108,1,183,0,90,255,138,254,145,254,87,0,35,0,143,1,162,1,88,3,65,3,51,255,202,254,76,2,10,3,17,3,41,4,94,4,221,4,133,4,83,255,200,254,107,0,89,1,144,1,22,3,102,3,89,4,233,3,249,255,136,255,125,254,102,254,154,253,81,252,30,255,128,254,21,254,53,255,224,254,205,255,181,254,166,255,78,255,104,254,195,253,174,254,56,0,227,255,239,254,141,253,239,251,226,252,9,255,45,254,148,0,66,0,254,255,51,255,51,255,193,253,163,254,199,255,160,254,198,255,211,255,31,255,41,254,100,252,15,254,77,0,224,255,44,0,121,255,235,254,21,254,15,254,10,254,88,254,54,255,119,255,77,0,96,0,26,0,77,255,43,254,16,252,20,251,6,1,221,255,124,255,253,254,190,255,24,255,65,254,235,253,235,252,65,255,156,255,245,254,108,1,0,2,5,9,14,20,27,35,1,4,8,13,19,26,34,42,3,7,12,18,25,33,41,48,6,11,17,24,32,40,47,53,10,16,23,31,39,46,52,57,15,22,30,38,45,51,56,60,21,29,37,44,50,55,59,62,28,36,43,49,54,58,61,63,0,2,5,9,1,4,8,12,3,7,11,14,6,10,13,15,0,2,1,3,0,0,0,0,200,28,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,13,33,0,200,166,32,0,80,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,128,75,32,0,56,50,40,0,84,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,232,220,35,0,8,214,39,0,72,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,160,110,39,0,168,29,39,0,76,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,24,217,38,0,200,166,32,0,8,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,64,16,0,1,0,0,0,0,0,112,147,38,0,56,50,40,0,12,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,64,16,0,1,0,0,0,0,0,24,89,38,0,248,35,38,0,16,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,16,0,1,0,24,89,38,0,192,242,37,0,176,197,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,24,89,38,0,0,163,37,0,80,123,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,24,89,38,0,240,55,37,0,72,14,37,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,24,89,38,0,152,229,36,0,88,194,36,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,24,89,38,0,184,164,36,0,216,137,36,0,20,0,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,96,64,16,0,1,0,0,0,0,0,64,110,36,0,120,83,36,0,24,0,0,0,1,0,0,0,125,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,152,58,36,0,72,29,36,0,28,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1537540);
/* memory initializer */ allocate([240,63,16,0,1,0,96,227,35,0,0,197,35,0,152,173,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,227,35,0,184,151,35,0,48,130,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,96,227,35,0,152,107,35,0,208,87,35,0,88,5,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,232,70,35,0,112,52,35,0,92,5,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,28,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,3,0,0,0,0,0,0,0,0,0,0,4,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,0,112,0,0,0,128,155,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,0,0,0,0,16,15,13,19,24,31,28,17,17,23,25,31,36,63,45,21,18,24,27,37,52,59,49,20,16,28,34,40,60,80,51,20,18,31,48,66,68,86,56,21,19,38,56,59,64,64,48,20,27,48,55,55,56,51,35,15,20,35,34,32,31,22,15,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,205,0,0,0,154,0,0,0,102,0,0,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,0,0,0,102,0,0,0,154,0,0,0,205,0,0,0,0,1,0,0,238,0,0,0,219,0,0,0,201,0,0,0,183,0,0,0,165,0,0,0,146,0,0,0,128,0,0,0,110,0,0,0,91,0,0,0,73,0,0,0,55,0,0,0,37,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,37,0,0,0,55,0,0,0,73,0,0,0,91,0,0,0,110,0,0,0,128,0,0,0,146,0,0,0,165,0,0,0,183,0,0,0,201,0,0,0,219,0,0,0,238,0,0,0,0,1,0,0,228,0,0,0,199,0,0,0,171,0,0,0,142,0,0,0,114,0,0,0,85,0,0,0,57,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,0,0,0,85,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,0,0,0,171,0,0,0,0,1,0,0,171,0,0,0,85,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,0,0,0,171,0,0,0,0,1,0,0,219,0,0,0,183,0,0,0,146,0,0,0,110,0,0,0,73,0,0,0,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,0,0,0,73,0,0,0,110,0,0,0,146,0,0,0,183,0,0,0,219,0,0,0,0,1,0,0,228,0,0,0,199,0,0,0,171,0,0,0,142,0,0,0,114,0,0,0,85,0,0,0,57,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,57,0,0,0,85,0,0,0,114,0,0,0,142,0,0,0,171,0,0,0,199,0,0,0,228,0,0,0,0,1,0,0,213,0,0,0,171,0,0,0,128,0,0,0,85,0,0,0,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,0,0,0,85,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,0,0,0,171,0,0,0,0,1,0,0,192,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,205,0,0,0,154,0,0,0,102,0,0,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,0,0,0,102,0,0,0,154,0,0,0,205,0,0,0,0,1,0,0,213,0,0,0,171,0,0,0,128,0,0,0,85,0,0,0,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,0,0,0,85,0,0,0,128,0,0,0,171,0,0,0,213,0,0,0,0,1,0,0,213,0,0,0,171,0,0,0,128,0,0,0,85,0,0,0,43,0,0,0,14,14,14,14,14,14,14,14,13,13,13,13,13,13,13,13,13,12,12,12,12,12,12,12,11,11,11,11,11,11,11,11,11,10,10,10,10,10,10,10,10,9,9,9,9,9,9,9,9,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,0,128,221,140,56,152,255,165,5,181,103,197,141,216,8,236,164,128,150,139,56,152,255,165,97,180,103,197,69,215,29,234,255,255,150,139,56,152,81,166,5,181,185,197,243,214,193,234,41,128,150,139,56,152,214,165,46,181,144,197,69,215,152,234,255,255,150,139,56,152,255,165,240,180,83,197,69,215,172,234,255,255,160,139,56,152,255,165,5,181,103,197,59,215,183,234,255,255,150,139,61,152,4,166,5,181,103,197,69,215,193,234,3,128,150,139,53,152,1,166,5,181,103,197,69,215,195,234,0,1,64,0,32,0,32,0,3,217,76,0,56,96,117,63,0,253,65,181,0,247,87,63,203,180,79,23,32,132,79,63,156,18,208,170,91,142,82,63,134,237,4,145,168,170,229,191,147,158,42,93,17,202,200,191,11,217,146,148,88,238,186,191,11,70,69,218,202,21,199,191,31,133,107,191,0,0,0,0,31,133,107,63,10,215,99,191,0,0,0,0,10,215,99,63,20,18,32,19,25,24,22,19,35,21,28,26,26,23,42,24,33,31,28,25,45,26,35,33,32,28,51,30,40,38,36,32,58,34,46,43,0,0,0,0,0,3,4,3,3,1,5,1,4,5,2,5,3,1,5,1,20,18,32,19,25,24,22,19,35,21,28,26,26,23,42,24,33,31,28,25,45,26,35,33,32,28,51,30,40,38,36,32,58,34,46,43,0,0,0,0,10,13,16,11,14,18,13,16,20,14,18,23,16,20,25,18,23,29,0,0,0,0,0,0,10,13,16,11,14,18,13,16,20,14,18,23,16,20,25,18,23,29,0,0,0,0,0,0,232,205,32,0,112,0,0,0,240,118,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,228,33,0,112,0,0,0,192,130,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,198,33,0,112,0,0,0,144,133,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,58,35,0,104,39,35,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,2,2,3,3,4,6,0,0,0,0,0,0,0,0,0,0,2,2,2,2,254,253,253,253,6,6,6,6,250,249,249,249,12,12,12,12,244,243,243,243,20,20,20,20,236,235,235,235,32,32,32,32,224,223,223,223,46,46,46,46,210,209,209,209,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,254,253,6,6,250,249,12,12,244,243,20,20,236,235,32,32,224,223,46,46,210,209,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,252,251,4,4,0,0,252,251,255,255,4,4,4,4,252,251,251,251,12,12,12,12,244,243,243,243,0,0,12,12,0,0,244,243,12,12,0,0,244,243,255,255,248,247,7,8,8,8,248,247,8,8,240,239,248,247,15,16,0,0,232,231,0,0,24,24,232,231,247,247,24,24,248,247,232,231,7,8,24,24,8,8,20,20,240,239,236,235,15,16,228,227,255,255,28,28,0,0,240,239,231,231,16,16,232,231,240,239,23,24,16,16,24,24,0,0,224,223,0,0,32,32,228,227,239,239,28,28,240,239,228,227,15,16,28,28,16,16,248,247,223,223,8,8,224,223,224,223,247,247,32,32,248,247,224,223,7,8,32,32,8,8,248,247,31,32,8,8,32,32,24,24,24,24,232,231,231,231,24,24,232,231,232,231,23,24,236,235,223,223,20,20,32,32,216,215,255,255,40,40,0,0,216,215,239,239,40,40,16,16,0,0,212,211,0,0,212,211,212,211,255,255,44,44,0,0,0,0,44,44,0,0,44,44,224,223,223,223,32,32,32,32,240,239,211,211,16,16,44,44,232,231,211,211,212,211,231,231,44,44,24,24,24,24,44,44,208,207,239,239,48,48,16,16,220,219,219,219,220,219,219,219,36,36,36,36,36,36,36,36,236,235,203,203,40,40,40,40,216,215,215,215,224,223,203,203,0,0,0,0,0,0,0,4,0,252,4,0,252,255,4,4,252,251,12,12,244,243,0,12,0,244,12,0,244,255,248,7,8,248,8,240,248,15,0,232,0,24,232,247,24,248,232,7,24,8,20,240,236,15,228,255,28,0,240,231,16,232,240,23,16,24,0,224,0,32,228,239,28,240,228,15,28,16,248,223,8,224,224,247,32,248,224,7,32,8,248,31,8,32,24,24,232,231,24,232,232,23,236,223,20,32,216,255,40,0,216,239,40,16,0,212,0,212,212,255,44,0,0,44,0,44,224,223,32,32,240,211,16,44,232,211,212,231,44,24,24,44,208,239,48,16,220,219,220,219,36,36,36,36,236,203,40,40,216,215,224,203,0,0,0,0,0,0,0,0,2,2,0,0,254,253,2,2,0,0,254,253,255,255,4,4,4,4,252,251,251,251,10,10,10,10,246,245,245,245,0,0,10,10,0,0,246,245,10,10,0,0,246,245,255,255,250,249,5,6,6,6,250,249,14,14,248,247,242,241,7,8,238,237,255,255,18,18,0,0,10,10,240,239,246,245,15,16,0,0,232,231,0,0,24,24,232,231,247,247,24,24,248,247,232,231,7,8,24,24,8,8,18,18,18,18,238,237,237,237,20,20,240,239,236,235,15,16,242,241,229,229,14,14,230,229,242,241,25,26,14,14,26,26,226,225,255,255,30,30,0,0,0,0,222,221,0,0,34,34,222,221,247,247,34,34,248,247,222,221,7,8,34,34,8,8,226,225,237,237,30,30,238,237,226,225,17,18,30,30,18,18,246,245,221,221,10,10,222,221,246,245,33,34,10,10,34,34,236,235,221,221,20,20,34,34,216,215,255,255,40,40,0,0,30,30,30,30,226,225,225,225,216,215,237,237,40,40,18,18,0,0,212,211,0,0,44,44,240,239,211,211,16,16,44,44,220,219,219,219,220,219,219,219,36,36,36,36,230,229,211,211,26,26,44,44,210,209,229,229,46,46,26,26,204,203,237,237,52,52,18,18,236,235,201,201,212,211,211,211,44,44,44,44,224,223,201,201,210,209,209,209,210,209,209,209,46,46,46,46,0,0,0,0,0,0,0,2,0,254,2,0,254,255,4,4,252,251,10,10,246,245,0,10,0,246,10,0,246,255,250,5,6,250,14,248,242,7,238,255,18,0,10,240,246,15,0,232,0,24,232,247,24,248,232,7,24,8,18,18,238,237,20,240,236,15,242,229,14,230,242,25,14,26,226,255,30,0,0,222,0,34,222,247,34,248,222,7,34,8,226,237,30,238,226,17,30,18,246,221,10,222,246,33,10,34,236,221,20,34,216,255,40,0,30,30,226,225,216,237,40,18,0,212,0,44,240,211,16,44,220,219,220,219,36,36,230,211,26,44,210,229,46,26,204,237,52,18,236,201,212,211,44,44,224,201,210,209,210,209,46,46,0,0,0,0,0,0,0,0,2,2,0,0,254,253,2,2,0,0,254,253,255,255,2,2,2,2,254,253,253,253,6,6,6,6,250,249,249,249,0,0,6,6,0,0,250,249,6,6,0,0,250,249,255,255,252,251,3,4,4,4,252,251,10,10,250,249,246,245,5,6,0,0,244,243,0,0,12,12,250,249,243,243,6,6,244,243,250,249,11,12,6,6,12,12,242,241,255,255,14,14,0,0,12,12,12,12,244,243,243,243,0,0,238,237,0,0,18,18,14,14,244,243,242,241,11,12,238,237,249,249,18,18,250,249,238,237,5,6,18,18,6,6,246,245,237,237,10,10,238,237,246,245,17,18,10,10,18,18,234,233,255,255,22,22,0,0,0,0,232,231,0,0,24,24,234,233,243,243,22,22,244,243,234,233,11,12,22,22,12,12,248,247,231,231,8,8,232,231,248,247,23,24,8,8,24,24,230,229,249,249,26,26,250,249,230,229,5,6,26,26,6,6,228,227,255,255,28,28,0,0,20,20,20,20,236,235,235,235,242,241,229,229,14,14,26,26,226,225,243,243,30,30,12,12,246,245,223,223,10,10,32,32,238,237,223,223,18,18,32,32,230,229,229,229,26,26,26,26,222,221,235,235,34,34,20,20,218,217,243,243,38,38,12,12,224,223,223,223,32,32,32,32,32,32,32,32,234,233,215,215,222,221,221,221,34,34,34,34,0,0,0,0,0,0,0,2,0,254,2,0,254,255,2,2,254,253,6,6,250,249,0,6,0,250,6,0,250,255,252,3,4,252,10,250,246,5,0,244,0,12,250,243,6,244,250,11,6,12,242,255,14,0,12,12,244,243,0,238,0,18,14,244,242,11,238,249,18,250,238,5,18,6,246,237,10,238,246,17,10,18,234,255,22,0,0,232,0,24,234,243,22,244,234,11,22,12,248,231,8,232,248,23,8,24,230,249,26,250,230,5,26,6,228,255,28,0,20,20,236,235,242,229,14,26,226,243,30,12,246,223,10,32,238,223,18,32,230,229,26,26,222,235,34,20,218,243,38,12,224,223,32,32,32,32,234,215,222,221,34,34,0,0,0,0,0,0,2,2,2,2,254,253,253,253,0,0,3,3,0,0,253,252,3,3,0,0,253,252,255,255,6,6,6,6,250,249,249,249,0,0,7,7,0,0,249,248,7,7,0,0,249,248,255,255,251,250,4,5,5,5,251,250,5,5,251,250,251,250,4,5,6,6,11,11,250,249,244,244,11,11,6,6,245,244,249,249,0,0,8,8,0,0,248,247,8,8,0,0,248,247,255,255,11,11,11,11,245,244,244,244,0,0,12,12,0,0,244,243,12,12,0,0,244,243,255,255,12,12,17,17,244,243,238,238,17,17,12,12,239,238,243,243,17,17,17,17,239,238,238,238,6,6,18,18,250,249,237,237,18,18,6,6,238,237,249,249,248,247,10,11,8,8,245,244,11,11,248,247,245,244,7,8,0,0,15,15,0,0,241,240,15,15,0,0,241,240,255,255,0,0,20,20,0,0,236,235,20,20,0,0,236,235,255,255,18,18,25,25,238,237,230,230,25,25,18,18,231,230,237,237,11,11,25,25,245,244,230,230,25,25,11,11,231,230,244,244,25,25,25,25,231,230,230,230,242,241,13,14,14,14,242,241,14,14,242,241,242,241,13,14,0,0,26,26,0,0,230,229,26,26,0,0,230,229,255,255,245,244,17,18,11,11,238,237,18,18,245,244,238,237,10,11,249,248,21,22,7,7,234,233,22,22,249,248,234,233,6,7,26,26,34,34,230,229,221,221,34,34,26,26,222,221,229,229,18,18,34,34,238,237,221,221,34,34,18,18,222,221,237,237,34,34,34,34,222,221,221,221,11,11,35,35,245,244,220,220,35,35,11,11,221,220,244,244,0,0,29,29,0,0,227,226,29,29,0,0,227,226,255,255,237,236,21,22,19,19,234,233,22,22,237,236,234,233,18,19,241,240,25,26,15,15,230,229,26,26,241,240,230,229,14,15,0,0,37,37,0,0,219,218,37,37,0,0,219,218,255,255,27,27,44,44,229,228,211,211,44,44,27,27,212,211,228,228,36,36,44,44,220,219,211,211,44,44,36,36,212,211,219,219,18,18,44,44,238,237,211,211,44,44,18,18,212,211,237,237,246,245,32,33,10,10,223,222,33,33,246,245,223,222,9,10,45,45,45,45,211,210,210,210,0,0,0,0,0,0,2,2,254,253,0,3,0,253,3,0,253,255,6,6,250,249,0,7,0,249,7,0,249,255,251,4,5,251,5,251,251,4,6,11,250,244,11,6,245,249,0,8,0,248,8,0,248,255,11,11,245,244,0,12,0,244,12,0,244,255,12,17,244,238,17,12,239,243,17,17,239,238,6,18,250,237,18,6,238,249,248,10,8,245,11,248,245,7,0,15,0,241,15,0,241,255,0,20,0,236,20,0,236,255,18,25,238,230,25,18,231,237,11,25,245,230,25,11,231,244,25,25,231,230,242,13,14,242,14,242,242,13,0,26,0,230,26,0,230,255,245,17,11,238,18,245,238,10,249,21,7,234,22,249,234,6,26,34,230,221,34,26,222,229,18,34,238,221,34,18,222,237,34,34,222,221,11,35,245,220,35,11,221,244,0,29,0,227,29,0,227,255,237,21,19,234,22,237,234,18,241,25,15,230,26,241,230,14,0,37,0,219,37,0,219,255,27,44,229,211,44,27,212,228,36,44,220,211,44,36,212,219,18,44,238,211,44,18,212,237,246,32,10,223,33,246,223,9,45,45,211,210,0,0,0,0,0,0,9,9,9,9,247,246,246,246,0,0,9,9,0,0,247,246,9,9,0,0,247,246,255,255,18,18,18,18,238,237,237,237,9,9,27,27,247,246,228,228,27,27,9,9,229,228,246,246,238,237,17,18,18,18,238,237,247,246,26,27,9,9,229,228,27,27,247,246,229,228,8,9,18,18,36,36,238,237,219,219,36,36,18,18,220,219,237,237,36,36,36,36,220,219,219,219,0,0,45,45,0,0,211,210,45,45,0,0,211,210,255,255,229,228,35,36,27,27,220,219,36,36,229,228,220,219,26,27,45,45,72,72,211,210,183,183,72,72,45,45,184,183,210,210,238,237,53,54,18,18,202,201,54,54,238,237,202,201,17,18,18,18,72,72,238,237,183,183,72,72,18,18,184,183,237,237,72,72,72,72,184,183,183,183,0,0,81,81,0,0,175,174,81,81,0,0,175,174,255,255,202,201,53,54,54,54,202,201,220,219,71,72,36,36,184,183,72,72,220,219,184,183,35,36,45,45,117,117,211,210,138,138,117,117,45,45,139,138,210,210,81,81,126,126,175,174,129,129,126,126,81,81,130,129,174,174,229,228,98,99,27,27,157,156,99,99,229,228,157,156,26,27,175,174,98,99,81,81,157,156,99,99,175,174,157,156,80,81,54,54,54,54,202,201,201,201,108,108,108,108,148,147,147,147,0,0,0,0,0,0,9,9,247,246,0,9,0,247,9,0,247,255,18,18,238,237,9,27,247,228,27,9,229,246,238,17,18,238,247,26,9,229,27,247,229,8,18,36,238,219,36,18,220,237,36,36,220,219,0,45,0,211,45,0,211,255,229,35,27,220,36,229,220,26,45,72,211,183,72,45,184,210,238,53,18,202,54,238,202,17,18,72,238,183,72,18,184,237,72,72,184,183,0,81,0,175,81,0,175,255,202,53,54,202,220,71,36,184,72,220,184,35,45,117,211,138,117,45,139,210,81,126,175,129,126,81,130,174,229,98,27,157,99,229,157,26,175,98,81,157,99,175,157,80,54,54,202,201,108,108,148,147,0,0,0,0,0,0,0,0,0,0,8,8,8,8,248,247,247,247,0,0,8,8,0,0,248,247,8,8,0,0,248,247,255,255,16,16,16,16,240,239,239,239,8,8,16,16,248,247,239,239,16,16,8,8,240,239,247,247,240,239,15,16,16,16,240,239,248,247,23,24,8,8,232,231,24,24,248,247,232,231,7,8,16,16,32,32,240,239,223,223,32,32,16,16,224,223,239,239,32,32,32,32,224,223,223,223,0,0,40,40,0,0,216,215,40,40,0,0,216,215,255,255,232,231,31,32,24,24,224,223,32,32,232,231,224,223,23,24,40,40,64,64,216,215,191,191,64,64,40,40,192,191,215,215,240,239,47,48,16,16,208,207,48,48,240,239,208,207,15,16,16,16,64,64,240,239,191,191,64,64,16,16,192,191,239,239,64,64,64,64,192,191,191,191,0,0,72,72,0,0,184,183,72,72,0,0,184,183,255,255,208,207,47,48,48,48,208,207,224,223,63,64,32,32,192,191,64,64,224,223,192,191,31,32,40,40,104,104,216,215,151,151,104,104,40,40,152,151,215,215,72,72,112,112,184,183,143,143,112,112,72,72,144,143,183,183,232,231,87,88,24,24,168,167,88,88,232,231,168,167,23,24,16,16,112,112,240,239,143,143,112,112,16,16,144,143,239,239,120,120,120,120,136,135,135,135,184,183,87,88,72,72,168,167,88,88,184,183,168,167,71,72,200,199,119,120,56,56,136,135,120,120,200,199,136,135,55,56,48,48,48,48,208,207,207,207,88,88,88,88,168,167,167,167,0,0,0,0,0,0,8,8,248,247,0,8,0,248,8,0,248,255,16,16,240,239,8,16,248,239,16,8,240,247,240,15,16,240,248,23,8,232,24,248,232,7,16,32,240,223,32,16,224,239,32,32,224,223,0,40,0,216,40,0,216,255,232,31,24,224,32,232,224,23,40,64,216,191,64,40,192,215,240,47,16,208,48,240,208,15,16,64,240,191,64,16,192,239,64,64,192,191,0,72,0,184,72,0,184,255,208,47,48,208,224,63,32,192,64,224,192,31,40,104,216,151,104,40,152,215,72,112,184,143,112,72,144,183,232,87,24,168,88,232,168,23,16,112,240,143,112,16,144,239,120,120,136,135,184,87,72,168,88,184,168,71,200,119,56,136,120,200,136,55,48,48,208,207,88,88,168,167,0,0,0,0,0,0,7,7,7,7,249,248,248,248,0,0,7,7,0,0,249,248,7,7,0,0,249,248,255,255,14,14,14,14,242,241,241,241,7,7,21,21,249,248,234,234,21,21,7,7,235,234,248,248,242,241,13,14,14,14,242,241,249,248,20,21,7,7,235,234,21,21,249,248,235,234,6,7,14,14,28,28,242,241,227,227,28,28,14,14,228,227,241,241,28,28,28,28,228,227,227,227,0,0,35,35,0,0,221,220,35,35,0,0,221,220,255,255,235,234,27,28,21,21,228,227,28,28,235,234,228,227,20,21,35,35,56,56,221,220,199,199,56,56,35,35,200,199,220,220,242,241,41,42,14,14,214,213,42,42,242,241,214,213,13,14,14,14,56,56,242,241,199,199,56,56,14,14,200,199,241,241,56,56,56,56,200,199,199,199,0,0,63,63,0,0,193,192,63,63,0,0,193,192,255,255,214,213,41,42,42,42,214,213,228,227,55,56,28,28,200,199,56,56,228,227,200,199,27,28,35,35,91,91,221,220,164,164,91,91,35,35,165,164,220,220,63,63,98,98,193,192,157,157,98,98,63,63,158,157,192,192,235,234,76,77,21,21,179,178,77,77,235,234,179,178,20,21,14,14,98,98,242,241,157,157,98,98,14,14,158,157,241,241,105,105,105,105,151,150,150,150,249,248,118,119,7,7,137,136,119,119,249,248,137,136,6,7,193,192,76,77,63,63,179,178,77,77,193,192,179,178,62,63,207,206,104,105,49,49,151,150,105,105,207,206,151,150,48,49,137,136,118,119,119,119,137,136,42,42,42,42,214,213,213,213,77,77,77,77,179,178,178,178,0,0,0,0,0,0,7,7,249,248,0,7,0,249,7,0,249,255,14,14,242,241,7,21,249,234,21,7,235,248,242,13,14,242,249,20,7,235,21,249,235,6,14,28,242,227,28,14,228,241,28,28,228,227,0,35,0,221,35,0,221,255,235,27,21,228,28,235,228,20,35,56,221,199,56,35,200,220,242,41,14,214,42,242,214,13,14,56,242,199,56,14,200,241,56,56,200,199,0,63,0,193,63,0,193,255,214,41,42,214,228,55,28,200,56,228,200,27,35,91,221,164,91,35,165,220,63,98,193,157,98,63,158,192,235,76,21,179,77,235,179,20,14,98,242,157,98,14,158,241,105,105,151,150,249,118,7,137,119,249,137,6,193,76,63,179,77,193,179,62,207,104,49,151,105,207,151,48,137,118,119,137,42,42,214,213,77,77,179,178,0,0,0,0,0,0,0,0,0,0,6,6,6,6,250,249,249,249,0,0,6,6,0,0,250,249,6,6,0,0,250,249,255,255,12,12,12,12,244,243,243,243,6,6,12,12,250,249,243,243,12,12,6,6,244,243,249,249,244,243,11,12,12,12,244,243,250,249,17,18,6,6,238,237,18,18,250,249,238,237,5,6,12,12,24,24,244,243,231,231,24,24,12,12,232,231,243,243,24,24,24,24,232,231,231,231,0,0,30,30,0,0,226,225,30,30,0,0,226,225,255,255,238,237,23,24,18,18,232,231,24,24,238,237,232,231,17,18,30,30,48,48,226,225,207,207,48,48,30,30,208,207,225,225,250,249,35,36,6,6,220,219,36,36,250,249,220,219,5,6,12,12,48,48,244,243,207,207,48,48,12,12,208,207,243,243,48,48,48,48,208,207,207,207,0,0,54,54,0,0,202,201,54,54,0,0,202,201,255,255,220,219,35,36,36,36,220,219,232,231,47,48,24,24,208,207,48,48,232,231,208,207,23,24,30,30,78,78,226,225,177,177,78,78,30,30,178,177,225,225,54,54,84,84,202,201,171,171,84,84,54,54,172,171,201,201,238,237,65,66,18,18,190,189,66,66,238,237,190,189,17,18,12,12,84,84,244,243,171,171,84,84,12,12,172,171,243,243,90,90,90,90,166,165,165,165,250,249,95,96,6,6,160,159,96,96,250,249,160,159,5,6,202,201,65,66,54,54,190,189,66,66,202,201,190,189,53,54,214,213,89,90,42,42,166,165,90,90,214,213,166,165,41,42,226,225,125,126,30,30,130,129,126,126,226,225,130,129,29,30,154,153,101,102,102,102,154,153,172,171,125,126,84,84,130,129,126,126,172,171,130,129,83,84,36,36,36,36,220,219,219,219,66,66,66,66,190,189,189,189,0,0,0,0,0,0,6,6,250,249,0,6,0,250,6,0,250,255,12,12,244,243,6,12,250,243,12,6,244,249,244,11,12,244,250,17,6,238,18,250,238,5,12,24,244,231,24,12,232,243,24,24,232,231,0,30,0,226,30,0,226,255,238,23,18,232,24,238,232,17,30,48,226,207,48,30,208,225,250,35,6,220,36,250,220,5,12,48,244,207,48,12,208,243,48,48,208,207,0,54,0,202,54,0,202,255,220,35,36,220,232,47,24,208,48,232,208,23,30,78,226,177,78,30,178,225,54,84,202,171,84,54,172,201,238,65,18,190,66,238,190,17,12,84,244,171,84,12,172,243,90,90,166,165,250,95,6,160,96,250,160,5,202,65,54,190,66,202,190,53,214,89,42,166,90,214,166,41,226,125,30,130,126,226,130,29,154,101,102,154,172,125,84,130,126,172,130,83,36,36,220,219,66,66,190,189,0,0,0,0,0,0,0,0,0,0,5,5,5,5,251,250,250,250,0,0,5,5,0,0,251,250,5,5,0,0,251,250,255,255,10,10,10,10,246,245,245,245,5,5,15,15,251,250,240,240,15,15,5,5,241,240,250,250,246,245,9,10,10,10,246,245,251,250,14,15,5,5,241,240,15,15,251,250,241,240,4,5,10,10,20,20,246,245,235,235,20,20,10,10,236,235,245,245,20,20,20,20,236,235,235,235,0,0,25,25,0,0,231,230,25,25,0,0,231,230,255,255,241,240,19,20,15,15,236,235,20,20,241,240,236,235,14,15,25,25,40,40,231,230,215,215,40,40,25,25,216,215,230,230,246,245,29,30,10,10,226,225,30,30,246,245,226,225,9,10,10,10,40,40,246,245,215,215,40,40,10,10,216,215,245,245,40,40,40,40,216,215,215,215,0,0,45,45,0,0,211,210,45,45,0,0,211,210,255,255,226,225,29,30,30,30,226,225,236,235,39,40,20,20,216,215,40,40,236,235,216,215,19,20,25,25,65,65,231,230,190,190,65,65,25,25,191,190,230,230,45,45,70,70,211,210,185,185,70,70,45,45,186,185,210,210,241,240,54,55,15,15,201,200,55,55,241,240,201,200,14,15,10,10,70,70,246,245,185,185,70,70,10,10,186,185,245,245,75,75,75,75,181,180,180,180,251,250,84,85,5,5,171,170,85,85,251,250,171,170,4,5,211,210,54,55,45,45,201,200,55,55,211,210,201,200,44,45,221,220,74,75,35,35,181,180,75,75,221,220,181,180,34,35,55,55,115,115,201,200,140,140,115,115,55,55,141,140,200,200,30,30,115,115,226,225,140,140,115,115,30,30,141,140,225,225,90,90,120,120,166,165,135,135,120,120,90,90,136,135,165,165,226,225,104,105,30,30,151,150,105,105,226,225,151,150,29,30,171,170,84,85,85,85,171,170,186,185,104,105,70,70,151,150,105,105,186,185,151,150,69,70,30,30,30,30,226,225,225,225,60,60,60,60,196,195,195,195,105,105,105,105,151,150,150,150,0,0,0,0,0,0,5,5,251,250,0,5,0,251,5,0,251,255,10,10,246,245,5,15,251,240,15,5,241,250,246,9,10,246,251,14,5,241,15,251,241,4,10,20,246,235,20,10,236,245,20,20,236,235,0,25,0,231,25,0,231,255,241,19,15,236,20,241,236,14,25,40,231,215,40,25,216,230,246,29,10,226,30,246,226,9,10,40,246,215,40,10,216,245,40,40,216,215,0,45,0,211,45,0,211,255,226,29,30,226,236,39,20,216,40,236,216,19,25,65,231,190,65,25,191,230,45,70,211,185], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1547790);
/* memory initializer */ allocate([70,45,186,210,241,54,15,201,55,241,201,14,10,70,246,185,70,10,186,245,75,75,181,180,251,84,5,171,85,251,171,4,211,54,45,201,55,211,201,44,221,74,35,181,75,221,181,34,55,115,201,140,115,55,141,200,30,115,226,140,115,30,141,225,90,120,166,135,120,90,136,165,226,104,30,151,105,226,151,29,171,84,85,171,186,104,70,151,105,186,151,69,30,30,226,225,60,60,196,195,105,105,151,150,0,0,0,0,0,0,4,4,4,4,252,251,251,251,0,0,4,4,0,0,252,251,4,4,0,0,252,251,255,255,4,4,8,8,252,251,247,247,8,8,4,4,248,247,251,251,8,8,8,8,248,247,247,247,248,247,7,8,8,8,248,247,252,251,11,12,4,4,244,243,12,12,252,251,244,243,3,4,8,8,16,16,248,247,239,239,16,16,8,8,240,239,247,247,16,16,16,16,240,239,239,239,0,0,20,20,0,0,236,235,20,20,0,0,236,235,255,255,244,243,15,16,12,12,240,239,16,16,244,243,240,239,11,12,252,251,23,24,4,4,232,231,24,24,252,251,232,231,3,4,16,16,32,32,240,239,223,223,32,32,16,16,224,223,239,239,8,8,32,32,248,247,223,223,32,32,8,8,224,223,247,247,32,32,32,32,224,223,223,223,0,0,36,36,0,0,220,219,36,36,0,0,220,219,255,255,232,231,23,24,24,24,232,231,240,239,31,32,16,16,224,223,32,32,240,239,224,223,15,16,20,20,52,52,236,235,203,203,52,52,20,20,204,203,235,235,36,36,56,56,220,219,199,199,56,56,36,36,200,199,219,219,244,243,43,44,12,12,212,211,44,44,244,243,212,211,11,12,8,8,56,56,248,247,199,199,56,56,8,8,200,199,247,247,60,60,60,60,196,195,195,195,252,251,63,64,4,4,192,191,64,64,252,251,192,191,3,4,220,219,43,44,36,36,212,211,44,44,220,219,212,211,35,36,228,227,59,60,28,28,196,195,60,60,228,227,196,195,27,28,44,44,92,92,212,211,163,163,92,92,44,44,164,163,211,211,24,24,92,92,232,231,163,163,92,92,24,24,164,163,231,231,72,72,96,96,184,183,159,159,96,96,72,72,160,159,183,183,236,235,83,84,20,20,172,171,84,84,236,235,172,171,19,20,8,8,100,100,248,247,155,155,100,100,8,8,156,155,247,247,108,108,108,108,148,147,147,147,188,187,67,68,68,68,188,187,200,199,83,84,56,56,172,171,84,84,200,199,172,171,55,56,244,243,119,120,12,12,136,135,120,120,244,243,136,135,11,12,208,207,107,108,48,48,148,147,108,108,208,207,148,147,47,48,152,151,123,124,104,104,132,131,124,124,152,151,132,131,103,104,24,24,24,24,232,231,231,231,44,44,44,44,212,211,211,211,84,84,84,84,172,171,171,171,0,0,0,0,0,0,4,4,252,251,0,4,0,252,4,0,252,255,4,8,252,247,8,4,248,251,8,8,248,247,248,7,8,248,252,11,4,244,12,252,244,3,8,16,248,239,16,8,240,247,16,16,240,239,0,20,0,236,20,0,236,255,244,15,12,240,16,244,240,11,252,23,4,232,24,252,232,3,16,32,240,223,32,16,224,239,8,32,248,223,32,8,224,247,32,32,224,223,0,36,0,220,36,0,220,255,232,23,24,232,240,31,16,224,32,240,224,15,20,52,236,203,52,20,204,235,36,56,220,199,56,36,200,219,244,43,12,212,44,244,212,11,8,56,248,199,56,8,200,247,60,60,196,195,252,63,4,192,64,252,192,3,220,43,36,212,44,220,212,35,228,59,28,196,60,228,196,27,44,92,212,163,92,44,164,211,24,92,232,163,92,24,164,231,72,96,184,159,96,72,160,183,236,83,20,172,84,236,172,19,8,100,248,155,100,8,156,247,108,108,148,147,188,67,68,188,200,83,56,172,84,200,172,55,244,119,12,136,120,244,136,11,208,107,48,148,108,208,148,47,152,123,104,132,124,152,132,103,24,24,232,231,44,44,212,211,84,84,172,171,0,0,0,0,0,0,0,0,0,0,3,3,3,3,253,252,252,252,0,0,3,3,0,0,253,252,3,3,0,0,253,252,255,255,6,6,6,6,250,249,249,249,3,3,9,9,253,252,246,246,9,9,3,3,247,246,252,252,253,252,8,9,3,3,247,246,9,9,253,252,247,246,2,3,250,249,5,6,6,6,250,249,6,6,12,12,250,249,243,243,12,12,6,6,244,243,249,249,12,12,12,12,244,243,243,243,0,0,15,15,0,0,241,240,15,15,0,0,241,240,255,255,247,246,11,12,9,9,244,243,12,12,247,246,244,243,8,9,15,15,24,24,241,240,231,231,24,24,15,15,232,231,240,240,250,249,17,18,6,6,238,237,18,18,250,249,238,237,5,6,6,6,24,24,250,249,231,231,24,24,6,6,232,231,249,249,24,24,24,24,232,231,231,231,0,0,27,27,0,0,229,228,27,27,0,0,229,228,255,255,238,237,17,18,18,18,238,237,244,243,23,24,12,12,232,231,24,24,244,243,232,231,11,12,15,15,39,39,241,240,216,216,39,39,15,15,217,216,240,240,27,27,42,42,229,228,213,213,42,42,27,27,214,213,228,228,247,246,32,33,9,9,223,222,33,33,247,246,223,222,8,9,6,6,42,42,250,249,213,213,42,42,6,6,214,213,249,249,45,45,45,45,211,210,210,210,253,252,50,51,3,3,205,204,51,51,253,252,205,204,2,3,229,228,32,33,27,27,223,222,33,33,229,228,223,222,26,27,235,234,44,45,21,21,211,210,45,45,235,234,211,210,20,21,33,33,69,69,223,222,186,186,69,69,33,33,187,186,222,222,18,18,69,69,238,237,186,186,69,69,18,18,187,186,237,237,54,54,72,72,202,201,183,183,72,72,54,54,184,183,201,201,238,237,62,63,18,18,193,192,63,63,238,237,193,192,17,18,6,6,78,78,250,249,177,177,78,78,6,6,178,177,249,249,81,81,81,81,175,174,174,174,205,204,50,51,51,51,205,204,214,213,62,63,42,42,193,192,63,63,214,213,193,192,41,42,247,246,89,90,9,9,166,165,90,90,247,246,166,165,8,9,42,42,114,114,214,213,141,141,114,114,42,42,142,141,213,213,63,63,117,117,193,192,138,138,117,117,63,63,139,138,192,192,220,219,80,81,36,36,175,174,81,81,220,219,175,174,35,36,21,21,120,120,235,234,135,135,120,120,21,21,136,135,234,234,96,96,123,123,160,159,132,132,123,123,96,96,133,132,159,159,226,225,110,111,30,30,145,144,111,111,226,225,145,144,29,30,178,177,92,93,78,78,163,162,93,93,178,177,163,162,77,78,187,186,113,114,69,69,142,141,114,114,187,186,142,141,68,69,18,18,18,18,238,237,237,237,33,33,33,33,223,222,222,222,63,63,63,63,193,192,192,192,108,108,108,108,148,147,147,147,0,0,0,0,0,0,3,3,253,252,0,3,0,253,3,0,253,255,6,6,250,249,3,9,253,246,9,3,247,252,253,8,3,247,9,253,247,2,250,5,6,250,6,12,250,243,12,6,244,249,12,12,244,243,0,15,0,241,15,0,241,255,247,11,9,244,12,247,244,8,15,24,241,231,24,15,232,240,250,17,6,238,18,250,238,5,6,24,250,231,24,6,232,249,24,24,232,231,0,27,0,229,27,0,229,255,238,17,18,238,244,23,12,232,24,244,232,11,15,39,241,216,39,15,217,240,27,42,229,213,42,27,214,228,247,32,9,223,33,247,223,8,6,42,250,213,42,6,214,249,45,45,211,210,253,50,3,205,51,253,205,2,229,32,27,223,33,229,223,26,235,44,21,211,45,235,211,20,33,69,223,186,69,33,187,222,18,69,238,186,69,18,187,237,54,72,202,183,72,54,184,201,238,62,18,193,63,238,193,17,6,78,250,177,78,6,178,249,81,81,175,174,205,50,51,205,214,62,42,193,63,214,193,41,247,89,9,166,90,247,166,8,42,114,214,141,114,42,142,213,63,117,193,138,117,63,139,192,220,80,36,175,81,220,175,35,21,120,235,135,120,21,136,234,96,123,160,132,123,96,133,159,226,110,30,145,111,226,145,29,178,92,78,163,93,178,163,77,187,113,69,142,114,187,142,68,18,18,238,237,33,33,223,222,63,63,193,192,108,108,148,147,0,0,0,0,0,0,2,2,2,2,254,253,253,253,0,0,2,2,0,0,254,253,2,2,0,0,254,253,255,255,4,4,4,4,252,251,251,251,0,0,4,4,0,0,252,251,4,4,0,0,252,251,255,255,252,251,3,4,4,4,252,251,254,253,5,6,2,2,250,249,6,6,254,253,250,249,1,2,4,4,8,8,252,251,247,247,8,8,4,4,248,247,251,251,8,8,8,8,248,247,247,247,0,0,10,10,0,0,246,245,10,10,0,0,246,245,255,255,252,251,7,8,4,4,248,247,8,8,252,251,248,247,3,4,8,8,14,14,248,247,241,241,14,14,8,8,242,241,247,247,254,253,11,12,2,2,244,243,12,12,254,253,244,243,1,2,4,4,16,16,252,251,239,239,16,16,4,4,240,239,251,251,16,16,16,16,240,239,239,239,0,0,18,18,0,0,238,237,18,18,0,0,238,237,255,255,244,243,11,12,12,12,244,243,248,247,15,16,8,8,240,239,16,16,248,247,240,239,7,8,10,10,26,26,246,245,229,229,26,26,10,10,230,229,245,245,18,18,28,28,238,237,227,227,28,28,18,18,228,227,237,237,250,249,21,22,6,6,234,233,22,22,250,249,234,233,5,6,4,4,28,28,252,251,227,227,28,28,4,4,228,227,251,251,30,30,30,30,226,225,225,225,254,253,31,32,2,2,224,223,32,32,254,253,224,223,1,2,238,237,21,22,18,18,234,233,22,22,238,237,234,233,17,18,242,241,29,30,14,14,226,225,30,30,242,241,226,225,13,14,22,22,46,46,234,233,209,209,46,46,22,22,210,209,233,233,12,12,46,46,244,243,209,209,46,46,12,12,210,209,243,243,34,34,48,48,222,221,207,207,48,48,34,34,208,207,221,221,246,245,39,40,10,10,216,215,40,40,246,245,216,215,9,10,4,4,50,50,252,251,205,205,50,50,4,4,206,205,251,251,54,54,54,54,202,201,201,201,222,221,33,34,34,34,222,221,228,227,41,42,28,28,214,213,42,42,228,227,214,213,27,28,250,249,59,60,6,6,196,195,60,60,250,249,196,195,5,6,26,26,76,76,230,229,179,179,76,76,26,26,180,179,229,229,42,42,76,76,214,213,179,179,76,76,42,42,180,179,213,213,232,231,53,54,24,24,202,201,54,54,232,231,202,201,23,24,14,14,78,78,242,241,177,177,78,78,14,14,178,177,241,241,62,62,82,82,194,193,173,173,82,82,62,62,174,173,193,193,236,235,73,74,20,20,182,181,74,74,236,235,182,181,19,20,2,2,88,88,254,253,167,167,88,88,2,2,168,167,253,253,92,92,92,92,164,163,163,163,204,203,59,60,52,52,196,195,60,60,204,203,196,195,51,52,52,52,118,118,204,203,137,137,118,118,52,52,138,137,203,203,212,211,73,74,44,44,182,181,74,74,212,211,182,181,43,44,74,74,118,118,182,181,137,137,118,118,74,74,138,137,181,181,32,32,118,118,224,223,137,137,118,118,32,32,138,137,223,223,244,243,101,102,12,12,154,153,102,102,244,243,154,153,11,12,216,215,95,96,40,40,160,159,96,96,216,215,160,159,39,40,222,221,117,118,34,34,138,137,118,118,222,221,138,137,33,34,168,167,87,88,88,88,168,167,178,177,103,104,78,78,152,151,104,104,178,177,152,151,77,78,12,12,12,12,244,243,243,243,22,22,22,22,234,233,233,233,42,42,42,42,214,213,213,213,72,72,72,72,184,183,183,183,0,0,0,0,0,0,2,2,254,253,0,2,0,254,2,0,254,255,4,4,252,251,0,4,0,252,4,0,252,255,252,3,4,252,254,5,2,250,6,254,250,1,4,8,252,247,8,4,248,251,8,8,248,247,0,10,0,246,10,0,246,255,252,7,4,248,8,252,248,3,8,14,248,241,14,8,242,247,254,11,2,244,12,254,244,1,4,16,252,239,16,4,240,251,16,16,240,239,0,18,0,238,18,0,238,255,244,11,12,244,248,15,8,240,16,248,240,7,10,26,246,229,26,10,230,245,18,28,238,227,28,18,228,237,250,21,6,234,22,250,234,5,4,28,252,227,28,4,228,251,30,30,226,225,254,31,2,224,32,254,224,1,238,21,18,234,22,238,234,17,242,29,14,226,30,242,226,13,22,46,234,209,46,22,210,233,12,46,244,209,46,12,210,243,34,48,222,207,48,34,208,221,246,39,10,216,40,246,216,9,4,50,252,205,50,4,206,251,54,54,202,201,222,33,34,222,228,41,28,214,42,228,214,27,250,59,6,196,60,250,196,5,26,76,230,179,76,26,180,229,42,76,214,179,76,42,180,213,232,53,24,202,54,232,202,23,14,78,242,177,78,14,178,241,62,82,194,173,82,62,174,193,236,73,20,182,74,236,182,19,2,88,254,167,88,2,168,253,92,92,164,163,204,59,52,196,60,204,196,51,52,118,204,137,118,52,138,203,212,73,44,182,74,212,182,43,74,118,182,137,118,74,138,181,32,118,224,137,118,32,138,223,244,101,12,154,102,244,154,11,216,95,40,160,96,216,160,39,222,117,34,138,118,222,138,33,168,87,88,168,178,103,78,152,104,178,152,77,12,12,244,243,22,22,234,233,42,42,214,213,72,72,184,183,0,0,0,0,0,0,9,9,9,9,247,246,246,246,253,252,11,12,3,3,244,243,12,12,253,252,244,243,2,3,20,20,20,20,236,235,235,235,6,6,23,23,250,249,232,232,23,23,6,6,233,232,249,249,239,238,16,17,17,17,239,238,249,248,26,27,7,7,229,228,27,27,249,248,229,228,6,7,19,19,39,39,237,236,216,216,39,39,19,19,217,216,236,236,39,39,39,39,217,216,216,216,3,3,43,43,253,252,212,212,43,43,3,3,213,212,252,252,232,231,35,36,24,24,220,219,36,36,232,231,220,219,23,24,42,42,69,69,214,213,186,186,69,69,42,42,187,186,213,213,242,241,52,53,14,14,203,202,53,53,242,241,203,202,13,14,19,19,71,71,237,236,184,184,71,71,19,19,185,184,236,236,73,73,73,73,183,182,182,182,254,253,79,80,2,2,176,175,80,80,254,253,176,175,1,2,204,203,51,52,52,52,204,203,217,216,69,70,39,39,186,185,70,70,217,216,186,185,38,39,48,48,121,121,208,207,134,134,121,121,48,48,135,134,207,207,84,84,124,124,172,171,131,131,124,124,84,84,132,131,171,171,229,228,99,100,27,27,156,155,100,100,229,228,156,155,26,27,175,174,101,102,81,81,154,153,102,102,175,174,154,153,80,81,55,55,55,55,201,200,200,200,104,104,104,104,152,151,151,151,0,0,0,0,0,0,9,9,247,246,253,11,3,244,12,253,244,2,20,20,236,235,6,23,250,232,23,6,233,249,239,16,17,239,249,26,7,229,27,249,229,6,19,39,237,216,39,19,217,236,39,39,217,216,3,43,253,212,43,3,213,252,232,35,24,220,36,232,220,23,42,69,214,186,69,42,187,213,242,52,14,203,53,242,203,13,19,71,237,184,71,19,185,236,73,73,183,182,254,79,2,176,80,254,176,1,204,51,52,204,217,69,39,186,70,217,186,38,48,121,208,134,121,48,135,207,84,124,172,131,124,84,132,171,229,99,27,156,100,229,156,26,175,101,81,154,102,175,154,80,55,55,201,200,104,104,152,151,0,0,0,0,0,0,0,0,0,0,8,8,8,8,248,247,247,247,253,252,10,11,3,3,245,244,11,11,253,252,245,244,2,3,18,18,18,18,238,237,237,237,5,5,20,20,251,250,235,235,20,20,5,5,236,235,250,250,241,240,14,15,15,15,241,240,249,248,23,24,7,7,232,231,24,24,249,248,232,231,6,7,17,17,35,35,239,238,220,220,35,35,17,17,221,220,238,238,34,34,34,34,222,221,221,221,3,3,38,38,253,252,217,217,38,38,3,3,218,217,252,252,234,233,31,32,22,22,224,223,32,32,234,233,224,223,21,22,37,37,61,61,219,218,194,194,61,61,37,37,195,194,218,218,243,242,46,47,13,13,209,208,47,47,243,242,209,208,12,13,17,17,63,63,239,238,192,192,63,63,17,17,193,192,238,238,65,65,65,65,191,190,190,190,255,254,71,72,1,1,184,183,72,72,255,254,184,183,0,1,210,209,45,46,46,46,210,209,221,220,62,63,35,35,193,192,63,63,221,220,193,192,34,35,43,43,107,107,213,212,148,148,107,107,43,43,149,148,212,212,75,75,110,110,181,180,145,145,110,110,75,75,146,145,180,180,232,231,88,89,24,24,167,166,89,89,232,231,167,166,23,24,17,17,114,114,239,238,141,141,114,114,17,17,142,141,238,238,121,121,121,121,135,134,134,134,184,183,90,91,72,72,165,164,91,91,184,183,165,164,71,72,198,197,119,120,58,58,136,135,120,120,198,197,136,135,57,58,49,49,49,49,207,206,206,206,92,92,92,92,164,163,163,163,0,0,0,0,0,0,8,8,248,247,253,10,3,245,11,253,245,2,18,18,238,237,5,20,251,235,20,5,236,250,241,14,15,241,249,23,7,232,24,249,232,6,17,35,239,220,35,17,221,238,34,34,222,221,3,38,253,217,38,3,218,252,234,31,22,224,32,234,224,21,37,61,219,194,61,37,195,218,243,46,13,209,47,243,209,12,17,63,239,192,63,17,193,238,65,65,191,190,255,71,1,184,72,255,184,0,210,45,46,210,221,62,35,193,63,221,193,34,43,107,213,148,107,43,149,212,75,110,181,145,110,75,146,180,232,88,24,167,89,232,167,23,17,114,239,141,114,17,142,238,121,121,135,134,184,90,72,165,91,184,165,71,198,119,58,136,120,198,136,57,49,49,207,206,92,92,164,163,0,0,0,0,0,0,7,7,7,7,249,248,248,248,253,252,9,10,3,3,246,245,10,10,253,252,246,245,2,3,16,16,16,16,240,239,239,239,5,5,18,18,251,250,237,237,18,18,5,5,238,237,250,250,243,242,12,13,13,13,243,242,250,249,20,21,6,6,235,234,21,21,250,249,235,234,5,6,15,15,30,30,241,240,225,225,30,30,15,15,226,225,240,240,30,30,30,30,226,225,225,225,2,2,34,34,254,253,221,221,34,34,2,2,222,221,253,253,237,236,27,28,19,19,228,227,28,28,237,236,228,227,18,19,32,32,54,54,224,223,201,201,54,54,32,32,202,201,223,223,245,244,40,41,11,11,215,214,41,41,245,244,215,214,10,11,15,15,55,55,241,240,200,200,55,55,15,15,201,200,240,240,57,57,57,57,199,198,198,198,255,254,62,63,1,1,193,192,63,63,255,254,193,192,0,1,216,215,39,40,40,40,216,215,226,225,54,55,30,30,201,200,55,55,226,225,201,200,29,30,37,37,94,94,219,218,161,161,94,94,37,37,162,161,218,218,65,65,96,96,191,190,159,159,96,96,65,65,160,159,190,190,235,234,77,78,21,21,178,177,78,78,235,234,178,177,20,21,15,15,100,100,241,240,155,155,100,100,15,15,156,155,240,240,106,106,106,106,150,149,149,149,248,247,115,116,8,8,140,139,116,116,248,247,140,139,7,8,193,192,78,79,63,63,177,176,79,79,193,192,177,176,62,63,205,204,104,105,51,51,151,150,105,105,205,204,151,150,50,51,136,135,119,120,120,120,136,135,43,43,43,43,213,212,212,212,80,80,80,80,176,175,175,175,0,0,0,0,0,0,7,7,249,248,253,9,3,246,10,253,246,2,16,16,240,239,5,18,251,237,18,5,238,250,243,12,13,243,250,20,6,235,21,250,235,5,15,30,241,225,30,15,226,240,30,30,226,225,2,34,254,221,34,2,222,253,237,27,19,228,28,237,228,18,32,54,224,201,54,32,202,223,245,40,11,215,41,245,215,10,15,55,241,200,55,15,201,240,57,57,199,198,255,62,1,193,63,255,193,0,216,39,40,216,226,54,30,201,55,226,201,29,37,94,219,161,94,37,162,218,65,96,191,159,96,65,160,190,235,77,21,178,78,235,178,20,15,100,241,155,100,15,156,240,106,106,150,149,248,115,8,140,116,248,140,7,193,78,63,177,79,193,177,62,205,104,51,151,105,205,151,50,136,119,120,136,43,43,213,212,80,80,176,175,0,0,0,0,0,0,0,0,0,0,6,6,6,6,250,249,249,249,254,253,7,8,2,2,248,247,8,8,254,253,248,247,1,2,13,13,13,13,243,242,242,242,4,4,15,15,252,251,240,240,15,15,4,4,241,240,251,251,245,244,10,11,11,11,245,244,251,250,17,18,5,5,238,237,18,18,251,250,238,237,4,5,13,13,26,26,243,242,229,229,26,26,13,13,230,229,242,242,26,26,26,26,230,229,229,229,2,2,29,29,254,253,226,226,29,29,2,2,227,226,253,253,240,239,23,24,16,16,232,231,24,24,240,239,232,231,15,16,28,28,46,46,228,227,209,209,46,46,28,28,210,209,227,227,247,246,34,35,9,9,221,220,35,35,247,246,221,220,8,9,13,13,47,47,243,242,208,208,47,47,13,13,209,208,242,242,49,49,49,49,207,206,206,206,255,254,53,54,1,1,202,201,54,54,255,254,202,201,0,1,221,220,34,35,35,35,221,220,230,229,46,47,26,26,209,208,47,47,230,229,209,208,25,26,32,32,81,81,224,223,174,174,81,81,32,32,175,174,223,223,56,56,83,83,200,199,172,172,83,83,56,56,173,172,199,199,238,237,66,67,18,18,189,188,67,67,238,237,189,188,17,18,13,13,86,86,243,242,169,169,86,86,13,13,170,169,242,242,91,91,91,91,165,164,164,164,249,248,98,99,7,7,157,156,99,99,249,248,157,156,6,7,202,201,67,68,54,54,188,187,68,68,202,201,188,187,53,54,212,211,89,90,44,44,166,165,90,90,212,211,166,165,43,44,223,222,123,124,33,33,132,131,124,124,223,222,132,131,32,33,153,152,102,103,103,103,153,152,170,169,126,127,86,86,129,128,127,127,170,169,129,128,85,86,37,37,37,37,219,218,218,218,69,69,69,69,187,186,186,186,0,0,0,0,0,0,6,6,250,249,254,7,2,248,8,254,248,1,13,13,243,242,4,15,252,240,15,4,241,251,245,10,11,245,251,17,5,238,18,251,238,4,13,26,243,229,26,13,230,242,26,26,230,229,2,29,254,226,29,2,227,253,240,23,16,232,24,240,232,15,28,46,228,209,46,28,210,227,247,34,9,221,35,247,221,8,13,47,243,208,47,13,209,242,49,49,207,206,255,53,1,202,54,255,202,0,221,34,35,221,230,46,26,209,47,230,209,25,32,81,224,174,81,32,175,223,56,83,200,172,83,56,173,199,238,66,18,189,67,238,189,17,13,86,243,169,86,13,170,242,91,91,165,164,249,98,7,157,99,249,157,6,202,67,54,188,68,202,188,53,212,89,44,166,90,212,166,43,223,123,33,132,124,223,132,32,153,102,103,153,170,126,86,129,127,170,129,85,37,37,219,218,69,69,187,186,0,0,0,0,0,0,0,0,0,0,5,5,5,5,251,250,250,250,254,253,6,7,2,2,249,248,7,7,254,253,249,248,1,2,11,11,11,11,245,244,244,244,3,3,13,13,253,252,242,242,13,13,3,3,243,242,252,252,247,246,8,9,9,9,247,246,252,251,14,15,4,4,241,240,15,15,252,251,241,240,3,4,11,11,22,22,245,244,233,233,22,22,11,11,234,233,244,244,21,21,21,21,235,234,234,234,2,2,24,24,254,253,231,231,24,24,2,2,232,231,253,253,242,241,19,20,14,14,236,235,20,20,242,241,236,235,13,14,23,23,38,38,233,232,217,217,38,38,23,23,218,217,232,232,248,247,28,29,8,8,227,226,29,29,248,247,227,226,7,8,11,11,39,39,245,244,216,216,39,39,11,11,217,216,244,244,41,41,41,41,215,214,214,214,255,254,44,45,1,1,211,210,45,45,255,254,211,210,0,1,227,226,28,29,29,29,227,226,234,233,38,39,22,22,217,216,39,39,234,233,217,216,21,22,27,27,67,67,229,228,188,188,67,67,27,27,189,188,228,228,47,47,69,69,209,208,186,186,69,69,47,47,187,186,208,208,241,240,55,56,15,15,200,199,56,56,241,240,200,199,14,15,11,11,71,71,245,244,184,184,71,71,11,11,185,184,244,244,76,76,76,76,180,179,179,179,250,249,82,83,6,6,173,172,83,83,250,249,173,172,5,6,211,210,56,57,45,45,199,198,57,57,211,210,199,198,44,45,220,219,74,75,36,36,181,180,75,75,220,219,181,180,35,36,56,56,115,115,200,199,140,140,115,115,56,56,141,140,199,199,31,31,117,117,225,224,138,138,117,117,31,31,139,138,224,224,88,88,122,122,168,167,133,133,122,122,88,88,134,133,167,167,228,227,103,104,28,28,152,151,104,104,228,227,152,151,27,28,171,170,84,85,85,85,171,170,184,183,105,106,72,72,150,149,106,106,184,183,150,149,71,72,30,30,30,30,226,225,225,225,58,58,58,58,198,197,197,197,105,105,105,105,151,150,150,150,0,0,0,0,0,0,5,5,251,250,254,6,2,249,7,254,249,1,11,11,245,244,3,13,253,242,13,3,243,252,247,8,9,247,252,14,4,241,15,252,241,3,11,22,245,233,22,11,234,244,21,21,235,234,2,24,254,231,24,2,232,253,242,19,14,236,20,242,236,13,23,38,233,217,38,23,218,232,248,28,8,227,29,248,227,7,11,39,245,216,39,11,217,244,41,41,215,214,255,44,1,211,45,255,211,0,227,28,29,227,234,38,22,217,39,234,217,21,27,67,229,188,67,27,189,228,47,69,209,186,69,47,187,208,241,55,15,200,56,241,200,14,11,71,245,184,71,11,185,244,76,76,180,179,250,82,6,173,83,250,173,5,211,56,45,199,57,211,199,44,220,74,36,181,75,220,181,35,56,115,200,140,115,56,141,199,31,117,225,138,117,31,139,224,88,122,168,133,122,88,134,167,228,103,28,152,104,228,152,27,171,84,85,171,184,105,72,150,106,184,150,71,30,30,226,225,58,58,198,197,105,105,151,150,0,0,0,0,0,0,4,4,4,4,252,251,251,251,255,254,4,5,1,1,251,250,5,5,255,254,251,250,0,1,3,3,10,10,253,252,245,245,10,10,3,3,246,245,252,252,9,9,9,9,247,246,246,246,249,248,6,7,7,7,249,248,253,252,11,12,3,3,244,243,12,12,253,252,244,243,2,3,8,8,17,17,248,247,238,238,17,17,8,8,239,238,247,247,17,17,17,17,239,238,238,238,1,1,19,19,255,254,236,236,19,19,1,1,237,236,254,254,245,244,15,16,11,11,240,239,16,16,245,244,240,239,10,11,250,249,22,23,6,6,233,232,23,23,250,249,233,232,5,6,18,18,31,31,238,237,224,224,31,31,18,18,225,224,237,237,8,8,32,32,248,247,223,223,32,32,8,8,224,223,247,247,33,33,33,33,223,222,222,222,255,254,35,36,1,1,220,219,36,36,255,254,220,219,0,1,233,232,22,23,23,23,233,232,239,238,30,31,17,17,225,224,31,31,239,238,225,224,16,17,21,21,54,54,235,234,201,201,54,54,21,21,202,201,234,234,37,37,55,55,219,218,200,200,55,55,37,37,201,200,218,218,244,243,43,44,12,12,212,211,44,44,244,243,212,211,11,12,8,8,57,57,248,247,198,198,57,57,8,8,199,198,247,247,61,61,61,61,195,194,194,194,251,250,65,66,5,5,190,189,66,66,251,250,190,189,4,5,220,219,44,45,36,36,211,210,45,45,220,219,211,210,35,36,227,226,59,60,29,29,196,195,60,60,227,226,196,195,28,29,45,45,92,92,211,210,163,163,92,92,45,45,164,163,210,210,25,25,93,93,231,230,162,162,93,93,25,25,163,162,230,230,71,71,97,97,185,184,158,158,97,97,71,71,159,158,184,184,234,233,82,83,22,22,173,172,83,83,234,233,173,172,21,22,7,7,102,102,249,248,153,153,102,102,7,7,154,153,248,248,109,109,109,109,147,146,146,146,188,187,67,68,68,68,188,187,199,198,84,85,57,57,171,170,85,85,199,198,171,170,56,57,243,242,119,120,13,13,136,135,120,120,243,242,136,135,12,13,207,206,109,110,49,49,146,145,110,110,207,206,146,145,48,49,152,151,122,123,104,104,133,132,123,123,152,151,133,132,103,104,24,24,24,24,232,231,231,231,46,46,46,46,210,209,209,209,84,84,84,84,172,171,171,171,0,0,0,0,0,0,4,4,252,251,255,4,1,251,5,255,251,0,3,10,253,245,10,3,246,252,9,9,247,246,249,6,7,249,253,11,3,244,12,253,244,2,8,17,248,238,17,8,239,247,17,17,239,238,1,19,255,236,19,1,237,254,245,15,11,240,16,245,240,10,250,22,6,233,23,250,233,5,18,31,238,224,31,18,225,237,8,32,248,223,32,8,224,247,33,33,223,222,255,35,1,220,36,255,220,0,233,22,23,233,239,30,17,225,31,239,225,16,21,54,235,201,54,21,202,234,37,55,219,200,55,37,201,218,244,43,12,212,44,244,212,11,8,57,248,198,57,8,199,247,61,61,195,194,251,65,5,190,66,251,190,4,220,44,36,211,45,220,211,35,227,59,29,196,60,227,196,28,45,92,211,163,92,45,164,210,25,93,231,162,93,25,163,230,71,97,185,158,97,71,159,184,234,82,22,173,83,234,173,21,7,102,249,153,102,7,154,248,109,109,147,146,188,67,68,188,199,84,57,171,85,199,171,56,243,119,13,136,120,243,136,12,207,109,49,146,110,207,146,48,152,122,104,133,123,152,133,103,24,24,232,231,46,46,210,209,84,84,172,171,0,0,0,0,0,0,0,0,0,0,3,3,3,3,253,252,252,252,255,254,3,4,1,1,252,251,4,4,255,254,252,251,0,1,7,7,7,7,249,248,248,248,2,2,8,8,254,253,247,247,8,8,2,2,248,247,253,253,254,253,8,9,2,2,247,246,9,9,254,253,247,246,1,2,250,249,5,6,6,6,250,249,6,6,13,13,250,249,242,242,13,13,6,6,243,242,249,249,13,13,13,13,243,242,242,242,1,1,14,14,255,254,241,241,14,14,1,1,242,241,254,254,248,247,11,12,8,8,244,243,12,12,248,247,244,243,7,8,14,14,23,23,242,241,232,232,23,23,14,14,233,232,241,241,251,250,17,18,5,5,238,237,18,18,251,250,238,237,4,5,6,6,24,24,250,249,231,231,24,24,6,6,232,231,249,249,24,24,24,24,232,231,231,231,255,254,26,27,1,1,229,228,27,27,255,254,229,228,0,1,239,238,16,17,17,17,239,238,243,242,22,23,13,13,233,232,23,23,243,242,233,232,12,13,16,16,40,40,240,239,215,215,40,40,16,16,216,215,239,239,28,28,41,41,228,227,214,214,41,41,28,28,215,214,227,227,247,246,32,33,9,9,223,222,33,33,247,246,223,222,8,9,6,6,43,43,250,249,212,212,43,43,6,6,213,212,249,249,46,46,46,46,210,209,209,209,252,251,49,50,4,4,206,205,50,50,252,251,206,205,3,4,229,228,33,34,27,27,222,221,34,34,229,228,222,221,26,27,234,233,44,45,22,22,211,210,45,45,234,233,211,210,21,22,34,34,69,69,222,221,186,186,69,69,34,34,187,186,221,221,19,19,70,70,237,236,185,185,70,70,19,19,186,185,236,236,53,53,73,73,203,202,182,182,73,73,53,53,183,182,202,202,239,238,61,62,17,17,194,193,62,62,239,238,194,193,16,17,5,5,77,77,251,250,178,178,77,77,5,5,179,178,250,250,82,82,82,82,174,173,173,173,205,204,50,51,51,51,205,204,213,212,63,64,43,43,192,191,64,64,213,212,192,191,42,43,246,245,89,90,10,10,166,165,90,90,246,245,166,165,9,10,41,41,114,114,215,214,141,141,114,114,41,41,142,141,214,214,64,64,116,116,192,191,139,139,116,116,64,64,140,139,191,191,219,218,81,82,37,37,174,173,82,82,219,218,174,173,36,37,22,22,119,119,234,233,136,136,119,119,22,22,137,136,233,233,95,95,124,124,161,160,131,131,124,124,95,95,132,131,160,160,226,225,110,111,30,30,145,144,111,111,226,225,145,144,29,30,178,177,91,92,78,78,164,163,92,92,178,177,164,163,77,78,188,187,112,113,68,68,143,142,113,113,188,187,143,142,67,68,18,18,18,18,238,237,237,237,34,34,34,34,222,221,221,221,63,63,63,63,193,192,192,192,109,109,109,109,147,146,146,146,0,0,0,0,0,0,3,3,253,252,255,3,1,252,4,255,252,0,7,7,249,248,2,8,254,247,8,2,248,253,254,8,2,247,9,254,247,1,250,5,6,250,6,13,250,242,13,6,243,249,13,13,243,242,1,14,255,241,14,1,242,254,248,11,8,244,12,248,244,7,14,23,242,232,23,14,233,241,251,17,5,238,18,251,238,4,6,24,250,231,24,6,232,249,24,24,232,231,255,26,1,229,27,255,229,0,239,16,17,239,243,22,13,233,23,243,233,12,16,40,240,215,40,16,216,239,28,41,228,214,41,28,215,227,247,32,9,223,33,247,223,8,6,43,250,212,43,6,213,249,46,46,210,209,252,49,4,206,50,252,206,3,229,33,27,222,34,229,222,26,234,44,22,211,45,234,211,21,34,69,222,186,69,34,187,221,19,70,237,185,70,19,186,236,53,73,203,182,73,53,183,202,239,61,17,194,62,239,194,16,5,77,251,178,77,5,179,250,82,82,174,173,205,50,51,205,213,63,43,192,64,213,192,42,246,89,10,166,90,246,166,9,41,114,215,141,114,41,142,214,64,116,192,139,116,64,140,191,219,81,37,174,82,219,174,36,22,119,234,136,119,22,137,233,95,124,161,131,124,95,132,160,226,110,30,145,111,226,145,29,178,91,78,164,92,178,164,77,188,112,68,143,113,188,143,67,18,18,238,237,34,34,222,221,63,63,193,192,109,109,147,146,0,0,0,0,0,0,2,2,2,2,254,253,253,253,255,254,2,3,1,1,253,252,3,3,255,254,253,252,0,1,4,4,4,4,252,251,251,251,1,1,5,5,255,254,250,250,5,5,1,1,251,250,254,254,252,251,3,4,4,4,252,251,254,253,5,6,2,2,250,249,6,6,254,253,250,249,1,2,4,4,9,9,252,251,246,246,9,9,4,4,247,246,251,251,9,9,9,9,247,246,246,246,1,1,10,10,255,254,245,245,10,10,1,1,246,245,254,254,251,250,7,8,5,5,248,247,8,8,251,250,248,247,4,5,9,9,15,15,247,246,240,240,15,15,9,9,241,240,246,246,253,252,11,12,3,3,244,243,12,12,253,252,244,243,2,3,4,4,16,16,252,251,239,239,16,16,4,4,240,239,251,251,16,16,16,16,240,239,239,239,0,0,18,18,0,0,238,237,18,18,0,0,238,237,255,255,244,243,11,12,12,12,244,243,247,246,15,16,9,9,240,239,16,16,247,246,240,239,8,9,11,11,27,27,245,244,228,228,27,27,11,11,229,228,244,244,19,19,28,28,237,236,227,227,28,28,19,19,228,227,236,236,250,249,21,22,6,6,234,233,22,22,250,249,234,233,5,6,4,4,29,29,252,251,226,226,29,29,4,4,227,226,251,251,30,30,30,30,226,225,225,225,254,253,32,33,2,2,223,222,33,33,254,253,223,222,1,2,238,237,22,23,18,18,233,232,23,23,238,237,233,232,17,18,241,240,29,30,15,15,226,225,30,30,241,240,226,225,14,15,22,22,46,46,234,233,209,209,46,46,22,22,210,209,233,233,13,13,47,47,243,242,208,208,47,47,13,13,209,208,242,242,35,35,49,49,221,220,206,206,49,49,35,35,207,206,220,220,245,244,40,41,11,11,215,214,41,41,245,244,215,214,10,11,4,4,51,51,252,251,204,204,51,51,4,4,205,204,251,251,54,54,54,54,202,201,201,201,222,221,33,34,34,34,222,221,227,226,41,42,29,29,214,213,42,42,227,226,214,213,28,29,250,249,59,60,6,6,196,195,60,60,250,249,196,195,5,6,27,27,76,76,229,228,179,179,76,76,27,27,180,179,228,228,43,43,77,77,213,212,178,178,77,77,43,43,179,178,212,212,232,231,54,55,24,24,201,200,55,55,232,231,201,200,23,24,14,14,79,79,242,241,176,176,79,79,14,14,177,176,241,241,63,63,83,83,193,192,172,172,83,83,63,63,173,172,192,192,236,235,73,74,20,20,182,181,74,74,236,235,182,181,19,20,2,2,88,88,254,253,167,167,88,88,2,2,168,167,253,253,93,93,93,93,163,162,162,162,204,203,60,61,52,52,195,194,61,61,204,203,195,194,51,52,52,52,120,120,204,203,135,135,120,120,52,52,136,135,203,203,211,210,74,75,45,45,181,180,75,75,211,210,181,180,44,45,75,75,125,125,181,180,130,130,125,125,75,75,131,130,180,180,33,33,122,122,223,222,133,133,122,122,33,33,134,133,222,222,243,242,102,103,13,13,153,152,103,103,243,242,153,152,12,13,216,215,95,96,40,40,160,159,96,96,216,215,160,159,39,40,222,221,126,127,34,34,129,128,127,127,222,221,129,128,33,34,167,166,88,89,89,89,167,166,178,177,104,105,78,78,151,150,105,105,178,177,151,150,77,78,12,12,12,12,244,243,243,243,23,23,23,23,233,232,232,232,42,42,42,42,214,213,213,213,73,73,73,73,183,182,182,182,0,0,0,0,0,0,2,2,254,253,255,2,1,253,3,255,253,0,4,4,252,251,1,5,255,250,5,1,251,254,252,3,4,252,254,5,2,250,6,254,250,1,4,9,252,246,9,4,247,251,9,9,247,246,1,10,255,245,10,1,246,254,251,7,5,248,8,251,248,4,9,15,247,240,15,9,241,246,253,11,3,244,12,253,244,2,4,16,252,239,16,4,240,251,16,16,240,239,0,18,0,238,18,0,238,255,244,11,12,244,247,15,9,240,16,247,240,8,11,27,245,228,27,11,229,244,19,28,237,227,28,19,228,236,250,21,6,234,22,250,234,5,4,29,252,226,29,4,227,251,30,30,226,225,254,32,2,223,33,254,223,1,238,22,18,233,23,238,233,17,241,29,15,226,30,241,226,14,22,46,234,209,46,22,210,233,13,47,243,208,47,13,209,242,35,49,221,206,49,35,207,220,245,40,11,215,41,245,215,10,4,51,252,204,51,4,205,251,54,54,202,201,222,33,34,222,227,41,29,214,42,227,214,28,250,59,6,196,60,250,196,5,27,76,229,179,76,27,180,228,43,77,213,178,77,43,179,212,232,54,24,201,55,232,201,23,14,79,242,176,79,14,177,241,63,83,193,172,83,63,173,192,236,73,20,182,74,236,182,19,2,88,254,167,88,2,168,253,93,93,163,162,204,60,52,195,61,204,195,51,52,120,204,135,120,52,136,203,211,74,45,181,75,211,181,44,75,125,181,130,125,75,131,180,33,122,223,133,122,33,134,222,243,102,13,153,103,243,153,12,216,95,40,160,96,216,160,39,222,126,34,129,127,222,129,33,167,88,89,167,178,104,78,151,105,178,151,77,12,12,244,243,23,23,233,232,42,42,214,213,73,73,183,182,0,0,32,221,35,0,48,167,32,0,4,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,160,236,34,0,176,75,32,0,8,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,200,40,34,0,192,50,40,0,12,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,128,137,33,0,80,214,39,0,16,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,192,110,39,0,216,29,39,0,20,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,32,217,38,0,216,29,39,0,20,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,176,147,38,0,96,89,38,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,5,37,0,112,0,0,0,192,232,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,237,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,50,37,0,152,221,35,0,36,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,110,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,237,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,8,37,0,112,0,0,0,232,234,23,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,46,50,46,53,0,0,0,8,195,38,0,192,189,38,0,88,184,38,0,192,189,38,0,40,179,38,0,192,189,38,0,72,174,38,0,192,189,38,0,0,0,0,0,0,0,0,0,200,133,39,0,248,48,39,0,0,0,0,0,0,0,0,0,112,136,39,0,32,51,39,0,0,0,0,0,0,0,0,0,3,136,37,5,52,13,20,152,15,101,100,66,0,0,0,0,235,162,36,255,34,3,149,144,1,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,255,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,18,18,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,254,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,255,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,17,2,253,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,17,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,255,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,255,2,18,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,2,1,7,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,18,2,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1558030);
/* memory initializer */ allocate([1,3,18,253,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,2,3,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,1,4,6,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,17,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,2,1,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,255,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,255,17,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,2,3,255,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,5,254,18,18,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,255,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,4,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,18,2,2,18,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,2,1,7,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,253,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,17,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,2,3,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,17,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,3,5,4,7,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,254,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,4,3,1,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,18,17,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,2,254,18,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,255,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,3,2,1,7,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,18,254,2,18,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,18,18,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,3,4,5,7,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,255,2,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,2,3,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,4,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,18,254,2,18,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,2,1,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,1,4,6,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,2,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,3,6,255,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,17,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,253,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,18,253,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,17,2,253,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,255,2,254,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,17,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,254,2,255,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,18,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,255,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,18,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,254,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,17,2,254,18,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,2,18,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,254,4,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,254,18,2,2,18,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,18,254,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,2,18,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,18,2,254,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,254,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,18,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,18,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,17,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,255,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,254,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,255,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,18,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,255,17,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,17,17,2,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,254,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,17,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,2,3,18,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,254,17,2,253,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,18,2,4,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,18,3,254,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,18,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,254,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,255,255,2,17,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,18,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,254,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,2,3,17,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,18,2,254,18,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,3,5,4,7,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,1,5,4,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,254,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,18,2,254,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,2,17,3,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,2,18,3,254,0,0,0,0,0,0,0,0,0,0,0,0,1,4,18,18,2,3,254,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,17,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,17,254,255,17,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,255,2,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,254,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,3,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,17,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,17,253,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,254,253,2,6,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,17,1,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,17,2,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,4,3,1,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,253,18,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,3,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,17,17,2,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,1,2,18,254,18,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17,254,17,1,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,18,3,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,18,255,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,17,18,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,18,18,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,18,254,18,2,0,0,0,0,0,0,0,0,0,0,0,0,192,128,64,0,0,0,0,0,33,16,77,74,142,142,172,170,238,247,0,0,0,0,0,0,0,0,0,0,51,51,51,0,102,102,102,0,153,153,153,0,204,204,204,0,255,255,255,0,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,51,0,0,0,102,0,0,0,153,0,0,0,204,0,0,0,255,0,0,0,0,51,51,0,0,102,102,0,0,153,153,0,0,204,204,0,0,255,255,0,51,51,0,0,102,102,0,0,153,153,0,0,204,204,0,0,255,255,0,0,51,0,51,0,102,0,102,0,153,0,153,0,204,0,204,0,255,0,255,0,51,255,255,0,102,255,255,0,153,255,255,0,204,255,255,0,255,51,255,0,255,102,255,0,255,153,255,0,255,204,255,0,255,255,51,0,255,255,102,0,255,255,153,0,255,255,204,0,51,204,204,0,102,204,204,0,153,204,204,0,255,204,204,0,204,51,204,0,204,102,204,0,204,153,204,0,204,255,204,0,204,204,51,0,204,204,102,0,204,204,153,0,204,204,255,0,51,153,153,0,102,153,153,0,204,153,153,0,255,153,153,0,153,51,153,0,153,102,153,0,153,204,153,0,153,255,153,0,153,153,51,0,153,153,102,0,153,153,204,0,153,153,255,0,51,102,102,0,153,102,102,0,204,102,102,0,255,102,102,0,102,51,102,0,102,153,102,0,102,204,102,0,102,255,102,0,102,102,51,0,102,102,153,0,102,102,204,0,102,102,255,0,102,51,51,0,153,51,51,0,204,51,51,0,255,51,51,0,51,102,51,0,51,153,51,0,51,204,51,0,51,255,51,0,51,51,102,0,51,51,153,0,51,51,204,0,51,51,255,0,102,51,0,0,0,102,51,0,51,0,102,0,51,102,0,0,102,0,51,0,0,51,102,0,153,102,51,0,51,153,102,0,102,51,153,0,102,153,51,0,153,51,102,0,51,102,153,0,204,153,102,0,102,204,153,0,153,102,204,0,153,204,102,0,204,102,153,0,102,153,204,0,255,204,153,0,153,255,204,0,204,153,255,0,204,255,153,0,255,153,204,0,153,204,255,0,17,17,17,0,34,34,34,0,68,68,68,0,85,85,85,0,170,170,170,0,187,187,187,0,221,221,221,0,238,238,238,0,0,0,8,0,1,0,16,0,9,0,2,0,17,0,24,0,10,0,3,0,18,0,25,0,32,0,11,0,4,0,26,0,33,0,19,0,40,0,12,0,34,0,27,0,5,0,41,0,20,0,48,0,13,0,35,0,42,0,28,0,21,0,6,0,49,0,56,0,36,0,43,0,29,0,7,0,14,0,50,0,57,0,44,0,22,0,37,0,15,0,51,0,58,0,30,0,45,0,23,0,52,0,59,0,38,0,31,0,60,0,53,0,46,0,39,0,61,0,54,0,47,0,62,0,55,0,63,0,0,0,4,0,1,0,5,0,8,0,2,0,12,0,9,0,3,0,6,0,13,0,10,0,7,0,14,0,11,0,15,0,0,0,32,0,1,0,64,0,33,0,2,0,96,0,65,0,34,0,128,0,3,0,97,0,66,0,160,0,129,0,35,0,98,0,4,0,67,0,130,0,161,0,192,0,36,0,99,0,224,0,5,0,162,0,193,0,68,0,131,0,37,0,100,0,225,0,194,0,0,1,163,0,69,0,132,0,6,0,226,0,1,1,32,1,195,0,101,0,164,0,38,0,2,1,7,0,227,0,33,1,133,0,64,1,70,0,196,0,165,0,34,1,3,1,228,0,39,0,65,1,102,0,96,1,8,0,197,0,71,0,134,0,66,1,35,1,4,1,97,1,128,1,229,0,166,0,103,0,40,0,98,1,67,1,36,1,135,0,129,1,198,0,5,1,72,0,9,0,160,1,167,0,130,1,99,1,230,0,68,1,104,0,37,1,41,0,161,1,199,0,136,0,6,1,131,1,192,1,69,1,100,1,10,0,73,0,162,1,231,0,168,0,193,1,38,1,132,1,105,0,163,1,7,1,42,0,200,0,101,1,194,1,137,0,224,1,74,0,70,1,232,0,11,0,133,1,169,0,39,1,164,1,106,0,195,1,225,1,102,1,8,1,71,1,201,0,43,0,138,0,0,2,226,1,134,1,40,1,233,0,170,0,165,1,75,0,196,1,103,1,12,0,1,2,9,1,227,1,72,1,107,0,202,0,2,2,32,2,166,1,135,1,197,1,139,0,44,0,234,0,228,1,41,1,104,1,171,0,76,0,3,2,33,2,10,1,73,1,198,1,13,0,167,1,203,0,108,0,34,2,229,1,64,2,42,1,235,0,140,0,105,1,74,1,172,0,35,2,45,0,199,1,11,1,65,2,230,1,77,0,204,0,106,1,96,2,14,0,43,1,66,2,109,0,236,0,231,1,97,2,75,1,141,0,67,2,46,0,15,0,173,0,98,2,107,1,78,0,205,0,16,0,110,0,237,0,99,2,142,0,47,0,174,0,79,0,206,0,17,0,111,0,238,0,48,0,143,0,80,0,175,0,112,0,207,0,49,0,18,0,239,0,81,0,113,0,19,0,50,0,82,0,114,0,51,0,83,0,115,0,128,2,4,2,136,1,12,1,144,0,20,0,160,2,129,2,36,2,5,2,168,1,137,1,44,1,13,1,176,0,145,0,52,0,21,0,192,2,161,2,130,2,68,2,37,2,6,2,200,1,169,1,138,1,76,1,45,1,14,1,208,0,177,0,146,0,84,0,53,0,22,0,224,2,193,2,162,2,131,2,100,2,69,2,38,2,7,2,232,1,201,1,170,1,139,1,108,1,77,1,46,1,15,1,240,0,209,0,178,0,147,0,116,0,85,0,54,0,23,0,225,2,194,2,163,2,101,2,70,2,39,2,233,1,202,1,171,1,109,1,78,1,47,1,241,0,210,0,179,0,117,0,86,0,55,0,226,2,195,2,102,2,71,2,234,1,203,1,110,1,79,1,242,0,211,0,118,0,87,0,227,2,103,2,235,1,111,1,243,0,119,0,0,3,132,2,8,2,140,1,16,1,148,0,24,0,32,3,1,3,164,2,133,2,40,2,9,2,172,1,141,1,48,1,17,1,180,0,149,0,56,0,25,0,64,3,33,3,2,3,196,2,165,2,134,2,72,2,41,2,10,2,204,1,173,1,142,1,80,1,49,1,18,1,212,0,181,0,150,0,88,0,57,0,26,0,96,3,65,3,34,3,3,3,228,2,197,2,166,2,135,2,104,2,73,2,42,2,11,2,236,1,205,1,174,1,143,1,112,1,81,1,50,1,19,1,244,0,213,0,182,0,151,0,120,0,89,0,58,0,27,0,97,3,66,3,35,3,229,2,198,2,167,2,105,2,74,2,43,2,237,1,206,1,175,1,113,1,82,1,51,1,245,0,214,0,183,0,121,0,90,0,59,0,98,3,67,3,230,2,199,2,106,2,75,2,238,1,207,1,114,1,83,1,246,0,215,0,122,0,91,0,99,3,231,2,107,2,239,1,115,1,247,0,123,0,128,3,4,3,136,2,12,2,144,1,20,1,152,0,28,0,160,3,129,3,36,3,5,3,168,2,137,2,44,2,13,2,176,1,145,1,52,1,21,1,184,0,153,0,60,0,29,0,192,3,161,3,130,3,68,3,37,3,6,3,200,2,169,2,138,2,76,2,45,2,14,2,208,1,177,1,146,1,84,1,53,1,22,1,216,0,185,0,154,0,92,0,61,0,30,0,224,3,193,3,162,3,131,3,100,3,69,3,38,3,7,3,232,2,201,2,170,2,139,2,108,2,77,2,46,2,15,2,240,1,209,1,178,1,147,1,116,1,85,1,54,1,23,1,248,0,217,0,186,0,155,0,124,0,93,0,62,0,31,0,225,3,194,3,163,3,101,3,70,3,39,3,233,2,202,2,171,2,109,2,78,2,47,2,241,1,210,1,179,1,117,1,86,1,55,1,249,0,218,0,187,0,125,0,94,0,63,0,226,3,195,3,102,3,71,3,234,2,203,2,110,2,79,2,242,1,211,1,118,1,87,1,250,0,219,0,126,0,95,0,227,3,103,3,235,2,111,2,243,1,119,1,251,0,127,0,132,3,8,3,140,2,16,2,148,1,24,1,156,0,164,3,133,3,40,3,9,3,172,2,141,2,48,2,17,2,180,1,149,1,56,1,25,1,188,0,157,0,196,3,165,3,134,3,72,3,41,3,10,3,204,2,173,2,142,2,80,2,49,2,18,2,212,1,181,1,150,1,88,1,57,1,26,1,220,0,189,0,158,0,228,3,197,3,166,3,135,3,104,3,73,3,42,3,11,3,236,2,205,2,174,2,143,2,112,2,81,2,50,2,19,2,244,1,213,1,182,1,151,1,120,1,89,1,58,1,27,1,252,0,221,0,190,0,159,0,229,3,198,3,167,3,105,3,74,3,43,3,237,2,206,2,175,2,113,2,82,2,51,2,245,1,214,1,183,1,121,1,90,1,59,1,253,0,222,0,191,0,230,3,199,3,106,3,75,3,238,2,207,2,114,2,83,2,246,1,215,1,122,1,91,1,254,0,223,0,231,3,107,3,239,2,115,2,247,1,123,1,255,0,136,3,12,3,144,2,20,2,152,1,28,1,168,3,137,3,44,3,13,3,176,2,145,2,52,2,21,2,184,1,153,1,60,1,29,1,200,3,169,3,138,3,76,3,45,3,14,3,208,2,177,2,146,2,84,2,53,2,22,2,216,1,185,1,154,1,92,1,61,1,30,1,232,3,201,3,170,3,139,3,108,3,77,3,46,3,15,3,240,2,209,2,178,2,147,2,116,2,85,2,54,2,23,2,248,1,217,1,186,1,155,1,124,1,93,1,62,1,31,1,233,3,202,3,171,3,109,3,78,3,47,3,241,2,210,2,179,2,117,2,86,2,55,2,249,1,218,1,187,1,125,1,94,1,63,1,234,3,203,3,110,3,79,3,242,2,211,2,118,2,87,2,250,1,219,1,126,1,95,1,235,3,111,3,243,2,119,2,251,1,127,1,140,3,16,3,148,2,24,2,156,1,172,3,141,3,48,3,17,3,180,2,149,2,56,2,25,2,188,1,157,1,204,3,173,3,142,3,80,3,49,3,18,3,212,2,181,2,150,2,88,2,57,2,26,2,220,1,189,1,158,1,236,3,205,3,174,3,143,3,112,3,81,3,50,3,19,3,244,2,213,2,182,2,151,2,120,2,89,2,58,2,27,2,252,1,221,1,190,1,159,1,237,3,206,3,175,3,113,3,82,3,51,3,245,2,214,2,183,2,121,2,90,2,59,2,253,1,222,1,191,1,238,3,207,3,114,3,83,3,246,2,215,2,122,2,91,2,254,1,223,1,239,3,115,3,247,2,123,2,255,1,144,3,20,3,152,2,28,2,176,3,145,3,52,3,21,3,184,2,153,2,60,2,29,2,208,3,177,3,146,3,84,3,53,3,22,3,216,2,185,2,154,2,92,2,61,2,30,2,240,3,209,3,178,3,147,3,116,3,85,3,54,3,23,3,248,2,217,2,186,2,155,2,124,2,93,2,62,2,31,2,241,3,210,3,179,3,117,3,86,3,55,3,249,2,218,2,187,2,125,2,94,2,63,2,242,3,211,3,118,3,87,3,250,2,219,2,126,2,95,2,243,3,119,3,251,2,127,2,148,3,24,3,156,2,180,3,149,3,56,3,25,3,188,2,157,2,212,3,181,3,150,3,88,3,57,3,26,3,220,2,189,2,158,2,244,3,213,3,182,3,151,3,120,3,89,3,58,3,27,3,252,2,221,2,190,2,159,2,245,3,214,3,183,3,121,3,90,3,59,3,253,2,222,2,191,2,246,3,215,3,122,3,91,3,254,2,223,2,247,3,123,3,255,2,152,3,28,3,184,3,153,3,60,3,29,3,216,3,185,3,154,3,92,3,61,3,30,3,248,3,217,3,186,3,155,3,124,3,93,3,62,3,31,3,249,3,218,3,187,3,125,3,94,3,63,3,250,3,219,3,126,3,95,3,251,3,127,3,156,3,188,3,157,3,220,3,189,3,158,3,252,3,221,3,190,3,159,3,253,3,222,3,191,3,254,3,223,3,255,3,0,0,16,0,1,0,32,0,17,0,2,0,48,0,33,0,18,0,3,0,64,0,34,0,49,0,19,0,65,0,80,0,50,0,4,0,35,0,66,0,20,0,81,0,96,0,51,0,5,0,36,0,82,0,97,0,67,0,112,0,21,0,52,0,98,0,37,0,83,0,113,0,6,0,68,0,128,0,53,0,22,0,99,0,114,0,84,0,7,0,129,0,38,0,69,0,100,0,115,0,144,0,130,0,85,0,54,0,23,0,8,0,145,0,39,0,70,0,116,0,101,0,131,0,160,0,146,0,55,0,86,0,24,0,71,0,132,0,117,0,161,0,40,0,9,0,102,0,147,0,176,0,162,0,87,0,56,0,25,0,133,0,118,0,177,0,148,0,72,0,103,0,41,0,163,0,10,0,192,0,178,0,88,0,57,0,134,0,149,0,119,0,26,0,164,0,73,0,104,0,193,0,42,0,179,0,208,0,11,0,135,0,89,0,165,0,120,0,150,0,58,0,194,0,180,0,27,0,74,0,209,0,105,0,151,0,136,0,43,0,90,0,224,0,166,0,195,0,181,0,121,0,210,0,59,0,12,0,152,0,106,0,167,0,196,0,75,0,137,0,225,0,211,0,240,0,182,0,122,0,91,0,28,0,197,0,13,0,226,0,168,0,183,0,153,0,44,0,212,0,138,0,107,0,241,0,60,0,29,0,123,0,198,0,184,0,227,0,169,0,242,0,76,0,213,0,154,0,45,0,92,0,14,0,199,0,139,0,61,0,228,0,214,0,170,0,185,0,243,0,108,0,77,0,155,0,30,0,15,0,200,0,229,0,124,0,215,0,244,0,93,0,46,0,186,0,171,0,201,0,109,0,140,0,230,0,62,0,216,0,245,0,31,0,125,0,78,0,156,0,231,0,47,0,187,0,202,0,217,0,94,0,246,0,141,0,63,0,232,0,172,0,110,0,247,0,157,0,79,0,218,0,203,0,126,0,233,0,188,0,248,0,95,0,173,0,142,0,219,0,111,0,249,0,234,0,158,0,127,0,189,0,204,0,250,0,235,0,143,0,174,0,220,0,205,0,159,0,251,0,190,0,221,0,175,0,236,0,237,0,191,0,206,0,252,0,222,0,253,0,207,0,238,0,223,0,254,0,239,0,255,0,16,16,16,16,17,18,21,24,16,16,16,16,17,19,22,25,16,16,17,18,20,22,25,29,16,16,18,21,24,27,31,36,17,17,20,24,30,35,41,47,18,19,22,27,35,44,54,65,21,22,25,31,41,54,70,88,24,25,29,36,47,65,88,115,16,16,16,16,17,18,20,24,16,16,16,17,18,20,24,25,16,16,17,18,20,24,25,28,16,17,18,20,24,25,28,33,17,18,20,24,25,28,33,41,18,20,24,25,28,33,41,54,20,24,25,28,33,41,54,71,24,25,28,33,41,54,71,91,6,10,13,16,18,23,25,27,10,11,16,18,23,25,27,29,13,16,18,23,25,27,29,31,16,18,23,25,27,29,31,33,18,23,25,27,29,31,33,36,23,25,27,29,31,33,36,38,25,27,29,31,33,36,38,40,27,29,31,33,36,38,40,42,9,13,15,17,19,21,22,24,13,13,17,19,21,22,24,25,15,17,19,21,22,24,25,27,17,19,21,22,24,25,27,28,19,21,22,24,25,27,28,30,21,22,24,25,27,28,30,32,22,24,25,27,28,30,32,33,24,25,27,28,30,32,33,35,6,13,20,28,13,20,28,32,20,28,32,37,28,32,37,42,10,14,20,24,14,20,24,27,20,24,27,30,24,27,30,34,5,3,3,0,0,4,4,1,0,5,5,2,0,6,6,3,4,2,2,0,0,4,4,2,0,5,5,3,0,7,7,5,5,3,3,0,0,4,4,1,0,5,5,2,0,6,6,3,8,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,8,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,8,0,8,8,12,0,13,13,17,0,17,17,21,3,1,1,0,0,4,4,2,0,6,6,5,0,9,9,7,199,122,141,147,63,159,148,133,118,121,104,114,174,73,87,92,41,83,82,99,50,53,39,39,177,58,59,68,26,63,52,79,25,17,14,12,222,34,30,72,16,44,58,32,12,10,7,6,32,64,96,128,224,144,192,168,192,176,192,198,198,245,216,136,140,148,160,176,192,224,234,234,240,128,128,64,96,112,64,64,96,64,160,128,128,216,128,176,160,176,176,192,198,198,208,208,136,140,148,160,176,192,224,234,234,240,128,128,64,96,112,64,64,96,64,160,128,0,0,0,9,102,187,225,0,0,0,0,2,173,34,7,145,85,7,166,63,7,94,66,8,64,46,17,81,31,25,29,30,0,0,0,65,32,18,144,162,194,41,51,98,132,68,18,165,217,196,45,40,78,173,80,19,176,240,193,64,35,46,221,135,38,194,248,121,96,85,29,0,0,0,0,120,7,76,176,208,126,28,54,103,48,12,154,155,139,90,34,117,119,67,6,25,204,243,158,13,21,96,97,5,44,131,176,139,48,68,97,83,5,42,156,111,152,26,49,152,80,5,58,178,74,83,33,62,145,86,5,32,154,192,168,14,22,163,85,5,32,156,216,148,19,29,73,77,7,64,116,132,122,37,126,120,101,21,107,181,192,103,19,67,125,0,0,0,0,0,0,0,0,128,63,252,255,52,63,252,255,52,191,252,255,52,63,252,255,52,63,0,0,20,63,252,255,52,63,248,255,209,62,0,0,20,63,252,255,52,191,248,255,209,62,0,0,20,63,0,0,0,0,252,255,80,191,0,0,0,63,4,0,39,63,0,0,0,63,248,255,137,62,0,0,0,63,248,255,137,62,0,0,0,191,4,0,39,191,0,0,0,63,248,255,137,190,0,0,0,191,4,0,39,63,0,0,0,63,4,0,39,191,0,0,0,63,248,255,137,190,239,255,227,62,248,255,25,63,4,0,3,63,8,0,190,62,222,255,71,62,239,255,227,62,8,0,190,62,222,255,71,190,248,255,25,191,4,0,3,191,239,255,227,62,0,0,0,0,248,255,33,191,0,0,0,0,248,255,33,63,239,255,227,62,8,0,190,190,222,255,71,190,248,255,25,63,4,0,3,191,239,255,227,62,248,255,25,191,4,0,3,63,8,0,190,190,222,255,71,62,248,255,209,62,4,0,15,63,0,0,0,63,248,255,209,62,239,255,147,62,34,0,24,62,248,255,209,62,248,255,209,62,0,0,0,0,248,255,209,190,0,0,20,191,248,255,209,190,248,255,209,62,34,0,24,62,0,0,0,191,248,255,209,190,239,255,147,62,4,0,15,63,248,255,209,62,34,0,24,190,0,0,0,191,248,255,209,62,239,255,147,62,4,0,15,191,248,255,209,62,248,255,209,190,0,0,0,0,248,255,209,62,0,0,20,191,248,255,209,62,248,255,209,62,4,0,15,191,0,0,0,63,248,255,209,190,239,255,147,62,34,0,24,190,0,0,0,0,0,0,0,0,192,14,24,0,196,14,24,0,212,14,24,0,248,14,24,0,56,15,24,0,156,15,24,0,0,0,0,0,50,126,123,221,226,0,0,0,239,183,119,96,41,0,0,0,125,34,187,52,41,133,6,31,56,0,0,0,0,0,0,0,0,0,37,109,153,51,102,147,23,87,128,8,67,101,1,41,63,1,19,29,31,154,185,17,127,175,6,96,145,2,73,114,1,51,82,1,28,45,23,163,200,10,131,185,2,93,148,1,67,111,1,41,69,1,14,24,29,176,217,12,145,201,3,101,156,1,69,111,1,39,63,1,14,23,57,192,233,25,154,215,6,109,167,3,78,118,1,48,69,1,21,29,202,105,245,108,106,216,18,90,144,0,0,0,0,0,0,0,0,0,33,172,219,64,149,206,14,117,177,5,90,141,2,61,95,1,37,57,33,179,220,11,140,198,1,89,148,1,60,104,1,33,57,1,12,21,30,181,221,8,141,198,1,87,145,1,58,100,1,31,55,1,12,20,32,186,224,7,142,198,1,86,143,1,58,100,1,31,55,1,12,22,57,192,227,20,143,204,3,96,154,1,68,112,1,42,69,1,19,32,212,35,215,113,47,169,29,48,105,0,0,0,0,0,0,0,0,0,74,129,203,106,120,203,49,107,178,19,84,144,4,50,84,1,15,25,71,172,217,44,141,209,15,102,173,6,76,133,2,51,89,1,24,42,64,185,231,31,148,216,8,103,175,3,74,131,1,46,81,1,18,30,65,196,235,25,157,221,5,105,174,1,67,120,1,38,69,1,15,30,65,204,238,30,156,224,7,107,177,2,70,124,1,42,73,1,18,34,225,86,251,144,104,235,42,99,181,0,0,0,0,0,0,0,0,0,85,175,239,112,165,229,29,136,200,12,103,162,6,77,123,2,53,84,75,183,239,30,155,221,3,106,171,1,74,128,1,44,76,1,17,28,73,185,240,27,159,222,2,107,172,1,75,127,1,42,73,1,17,29,62,190,238,21,159,222,2,107,172,1,72,122,1,40,71,1,18,32,61,199,240,27,161,226,4,113,180,1,76,129,1,46,80,1,23,41,195,29,183,84,49,136,8,42,71,0,0,0,0,0,0,0,0,0,31,107,169,35,99,159,17,82,140,8,66,114,2,44,76,1,19,32,40,132,201,29,114,187,13,91,157,7,75,127,3,58,95,1,28,47,69,142,221,42,122,201,15,91,159,6,67,121,1,42,77,1,17,31,102,148,228,67,117,204,17,82,154,6,59,114,2,39,75,1,15,29,156,57,233,119,57,212,58,48,163,29,40,124,12,30,81,3,12,31,191,107,226,124,117,204,25,99,155,0,0,0,0,0,0,0,0,0,29,148,210,37,126,194,8,93,157,2,68,118,1,39,69,1,17,33,41,151,213,27,123,193,3,82,144,1,58,105,1,32,60,1,13,26,59,159,220,23,126,198,4,88,151,1,66,114,1,38,71,1,18,34,114,136,232,51,114,207,11,83,155,3,56,105,1,33,65,1,17,34,149,65,234,121,57,215,61,49,166,28,36,114,12,25,76,3,16,42,214,49,220,132,63,188,42,65,137,0,0,0,0,0,0,0,0,0,85,137,221,104,131,216,49,111,192,21,87,155,2,49,87,1,16,28,89,163,230,90,137,220,29,100,183,10,70,135,2,42,81,1,17,33,108,167,237,55,133,222,15,97,179,4,72,135,1,45,85,1,19,38,124,146,240,66,124,224,17,88,175,4,58,122,1,36,75,1,18,37,141,79,241,126,70,227,66,58,182,30,44,136,12,34,96,2,20,47,229,99,249,143,111,235,46,109,192,0,0,0,0,0,0,0,0,0,82,158,236,94,146,224,25,117,191,9,87,149,3,56,99,1,33,57,83,167,237,68,145,222,10,103,177,2,72,131,1,41,79,1,20,39,99,167,239,47,141,224,10,104,178,2,73,133,1,44,85,1,22,47,127,145,243,71,129,228,17,93,177,3,61,124,1,41,84,1,21,52,157,78,244,140,72,231,69,58,184,31,44,137,14,38,105,8,23,61,17,38,140,7,34,80,1,17,29,0,0,0,0,0,0,0,0,0,37,75,128,41,76,128,26,66,116,12,52,94,2,32,55,1,10,16,50,127,154,37,109,152,16,82,121,5,59,85,1,35,54,1,13,20,40,142,167,17,110,157,2,71,112,1,44,72,1,27,45,1,11,17,30,175,188,9,124,169,1,74,116,1,48,78,1,30,49,1,11,18,10,222,223,2,150,194,1,83,128,1,48,79,1,27,45,1,11,17,36,41,235,29,36,193,10,27,111,0,0,0,0,0,0,0,0,0,85,165,222,177,162,215,110,135,195,57,113,168,23,83,120,10,49,61,85,190,223,36,139,200,5,90,146,1,60,103,1,38,65,1,18,30,72,202,223,23,141,199,2,86,140,1,56,97,1,36,61,1,16,27,55,218,225,13,145,200,1,86,141,1,57,99,1,35,61,1,13,22,15,235,212,1,132,184,1,84,139,1,57,97,1,34,56,1,14,23,181,21,201,61,37,123,10,38,71,0,0,0,0,0,0,0,0,0,47,106,172,95,104,173,42,93,159,18,77,131,4,50,81,1,17,23,62,147,199,44,130,189,28,102,154,18,75,115,2,44,65,1,12,19,55,153,210,24,130,194,3,93,146,1,61,97,1,31,50,1,10,16,49,186,223,17,148,204,1,96,142,1,53,83,1,26,44,1,11,17,13,217,212,2,136,180,1,78,124,1,50,83,1,29,49,1,14,23,197,13,247,82,17,222,25,17,162,0,0,0,0,0,0,0,0,0,126,186,247,234,191,243,176,177,234,104,158,220,66,128,186,55,90,137,111,197,242,46,158,219,9,104,171,2,65,125,1,44,80,1,17,91,104,208,245,39,168,224,3,109,162,1,79,124,1,50,102,1,43,102,84,220,246,31,177,231,2,115,180,1,79,134,1,55,77,1,60,79,43,243,240,8,180,217,1,115,166,1,84,121,1,51,67,1,16,6,7,27,153,5,30,95,1,16,30,0,0,0,0,0,0,0,0,0,50,75,127,57,75,124,27,67,108,10,54,86,1,33,52,1,12,18,43,125,151,26,108,148,7,83,122,2,59,89,1,38,60,1,17,27,23,144,163,13,112,154,2,75,117,1,50,81,1,31,51,1,14,23,18,162,185,6,123,171,1,78,125,1,51,86,1,31,54,1,14,23,15,199,227,3,150,204,1,91,146,1,55,95,1,30,53,1,11,20,19,55,240,19,59,196,3,52,105,0,0,0,0,0,0,0,0,0,41,166,207,104,153,199,31,123,181,14,101,152,5,72,106,1,36,52,35,176,211,12,131,190,2,88,144,1,60,101,1,36,60,1,16,28,28,183,213,8,134,191,1,86,142,1,56,96,1,30], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1568280);
/* memory initializer */ allocate([53,1,12,20,20,190,215,4,135,192,1,84,139,1,53,91,1,28,49,1,11,20,13,196,216,2,137,192,1,86,143,1,57,99,1,32,56,1,13,24,211,29,217,96,47,156,22,43,87,0,0,0,0,0,0,0,0,0,78,120,193,111,116,186,46,102,164,15,80,128,2,49,76,1,18,28,71,161,203,42,132,192,10,98,150,3,69,109,1,44,70,1,18,29,57,186,211,30,140,196,4,93,146,1,62,102,1,38,65,1,16,27,47,199,217,14,145,196,1,88,142,1,57,98,1,36,62,1,15,26,26,219,229,5,155,207,1,94,151,1,60,104,1,36,62,1,16,28,233,29,248,146,47,220,43,52,140,0,0,0,0,0,0,0,0,0,100,163,232,179,161,222,63,142,204,37,113,174,26,89,137,18,68,97,85,181,230,32,146,209,7,100,164,3,71,121,1,45,77,1,18,30,65,187,230,20,148,207,2,97,159,1,68,116,1,40,70,1,14,29,40,194,227,8,147,204,1,94,155,1,65,112,1,39,66,1,14,26,16,208,228,3,151,207,1,98,160,1,67,117,1,41,74,1,17,31,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,253,136,254,255,228,219,128,128,128,128,128,189,129,242,255,227,213,255,219,128,128,128,106,126,227,252,214,209,255,255,128,128,128,1,98,248,255,236,226,255,255,128,128,128,181,133,238,254,221,234,255,154,128,128,128,78,134,202,247,198,180,255,219,128,128,128,1,185,249,255,243,255,128,128,128,128,128,184,150,247,255,236,224,128,128,128,128,128,77,110,216,255,236,230,128,128,128,128,128,1,101,251,255,241,255,128,128,128,128,128,170,139,241,252,236,209,255,255,128,128,128,37,116,196,243,228,255,255,255,128,128,128,1,204,254,255,245,255,128,128,128,128,128,207,160,250,255,238,128,128,128,128,128,128,102,103,231,255,211,171,128,128,128,128,128,1,152,252,255,240,255,128,128,128,128,128,177,135,243,255,234,225,128,128,128,128,128,80,129,211,255,194,224,128,128,128,128,128,1,1,255,128,128,128,128,128,128,128,128,246,1,255,128,128,128,128,128,128,128,128,255,128,128,128,128,128,128,128,128,128,128,198,35,237,223,193,187,162,160,145,155,62,131,45,198,221,172,176,220,157,252,221,1,68,47,146,208,149,167,221,162,255,223,128,1,149,241,255,221,224,255,255,128,128,128,184,141,234,253,222,220,255,199,128,128,128,81,99,181,242,176,190,249,202,255,255,128,1,129,232,253,214,197,242,196,255,255,128,99,121,210,250,201,198,255,202,128,128,128,23,91,163,242,170,187,247,210,255,255,128,1,200,246,255,234,255,128,128,128,128,128,109,178,241,255,231,245,255,255,128,128,128,44,130,201,253,205,192,255,255,128,128,128,1,132,239,251,219,209,255,165,128,128,128,94,136,225,251,218,190,255,255,128,128,128,22,100,174,245,186,161,255,199,128,128,128,1,182,249,255,232,235,128,128,128,128,128,124,143,241,255,227,234,128,128,128,128,128,35,77,181,251,193,211,255,205,128,128,128,1,157,247,255,236,231,255,255,128,128,128,121,141,235,255,225,227,255,255,128,128,128,45,99,188,251,195,217,255,224,128,128,128,1,1,251,255,213,255,128,128,128,128,128,203,1,248,255,255,128,128,128,128,128,128,137,1,177,255,224,255,128,128,128,128,128,253,9,248,251,207,208,255,192,128,128,128,175,13,224,243,193,185,249,198,255,255,128,73,17,171,221,161,179,236,167,255,234,128,1,95,247,253,212,183,255,255,128,128,128,239,90,244,250,211,209,255,255,128,128,128,155,77,195,248,188,195,255,255,128,128,128,1,24,239,251,218,219,255,205,128,128,128,201,51,219,255,196,186,128,128,128,128,128,69,46,190,239,201,218,255,228,128,128,128,1,191,251,255,255,128,128,128,128,128,128,223,165,249,255,213,255,128,128,128,128,128,141,124,248,255,255,128,128,128,128,128,128,1,16,248,255,255,128,128,128,128,128,128,190,36,230,255,236,255,128,128,128,128,128,149,1,255,128,128,128,128,128,128,128,128,1,226,255,128,128,128,128,128,128,128,128,247,192,255,128,128,128,128,128,128,128,128,240,128,255,128,128,128,128,128,128,128,128,1,134,252,255,255,128,128,128,128,128,128,213,62,250,255,255,128,128,128,128,128,128,55,93,255,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,202,24,213,235,186,191,220,160,240,175,255,126,38,182,232,169,184,228,174,255,187,128,61,46,138,219,151,178,240,170,255,216,128,1,112,230,250,199,191,247,159,255,255,128,166,109,228,252,211,215,255,174,128,128,128,39,77,162,232,172,180,245,178,255,255,128,1,52,220,246,198,199,249,220,255,255,128,124,74,191,243,183,193,250,221,255,255,128,24,71,130,219,154,170,243,182,255,255,128,1,182,225,249,219,240,255,224,128,128,128,149,150,226,252,216,205,255,171,128,128,128,28,108,170,242,183,194,254,223,255,255,128,1,81,230,252,204,203,255,192,128,128,128,123,102,209,247,188,196,255,233,128,128,128,20,95,153,243,164,173,255,203,128,128,128,1,222,248,255,216,213,128,128,128,128,128,168,175,246,252,235,205,255,255,128,128,128,47,116,215,255,211,212,255,255,128,128,128,1,121,236,253,212,214,255,255,128,128,128,141,84,213,252,201,202,255,219,128,128,128,42,80,160,240,162,185,255,205,128,128,128,1,1,255,128,128,128,128,128,128,128,128,244,1,255,128,128,128,128,128,128,128,128,238,1,255,128,128,128,128,128,128,128,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,117,0,0,176,103,0,0,225,0,0,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,167,63,0,222,104,0,0,69,98,0,0,217,4,0,0,130,0,0,0,26,0,0,0,6,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,73,2,0,244,40,0,0,66,37,0,0,238,3,0,0,160,0,0,0,36,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,0,0,242,100,0,0,8,158,0,0,102,4,0,0,83,0,0,0,11,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,36,0,0,74,31,0,0,0,2,0,0,73,0,0,0,7,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,169,0,0,23,4,0,0,239,2,0,0,149,0,0,0,31,0,0,0,13,0,0,0,6,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,111,3,0,0,24,102,0,0,98,38,0,0,252,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,31,0,0,198,21,0,0,191,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,137,0,0,93,2,0,0,165,2,0,0,116,0,0,0,9,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,2,0,0,23,40,0,0,103,60,0,0,27,1,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,213,10,0,0,143,8,0,0,128,0,0,0,9,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,39,0,0,134,0,0,0,125,0,0,0,32,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,243,40,0,0,103,10,0,0,23,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,8,0,0,227,4,0,0,27,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,56,0,0,116,0,0,0,156,0,0,0,14,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,0,0,0,17,160,0,0,222,107,0,0,156,1,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,225,23,0,0,93,20,0,0,5,1,0,0,22,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,102,0,0,126,1,0,0,56,1,0,0,50,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,1,0,0,0,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,196,12,0,0,182,75,0,0,19,4,0,0,250,0,0,0,93,0,0,0,82,0,0,0,49,0,0,0,26,0,0,0,17,0,0,0,8,0,0,0,25,0,0,0,113,65,1,0,54,34,0,0,110,125,0,0,60,21,0,0,40,7,0,0,59,3,0,0,156,2,0,0,164,1,0,0,153,0,0,0,24,0,0,0,0,0,0,0,3,0,0,0,178,206,0,0,121,36,0,0,173,92,0,0,39,33,0,0,114,15,0,0,59,8,0,0,44,7,0,0,45,4,0,0,143,1,0,0,59,0,0,0,0,0,0,0,0,0,0,0,188,72,0,0,131,48,0,0,228,32,0,0,196,1,0,0,62,0,0,0,9,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,195,45,0,0,1,34,0,0,181,2,0,0,92,0,0,0,15,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,210,0,0,179,29,0,0,137,33,0,0,2,9,0,0,10,3,0,0,14,1,0,0,145,0,0,0,39,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,35,0,0,66,62,0,0,255,55,0,0,183,4,0,0,184,0,0,0,55,0,0,0,13,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,28,0,0,173,26,0,0,114,4,0,0,244,0,0,0,71,0,0,0,26,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,38,0,0,44,6,0,0,32,7,0,0,143,2,0,0,241,0,0,0,89,0,0,0,46,0,0,0,10,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,173,1,0,0,253,75,0,0,140,20,0,0,201,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,213,35,0,0,174,14,0,0,213,0,0,0,22,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,38,0,0,153,6,0,0,253,4,0,0,20,1,0,0,51,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,167,2,0,0,44,47,0,0,171,41,0,0,108,2,0,0,85,0,0,0,19,0,0,0,9,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,18,0,0,41,14,0,0,167,1,0,0,55,0,0,0,19,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,20,0,0,159,1,0,0,184,1,0,0,143,0,0,0,34,0,0,0,20,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,0,0,0,151,47,0,0,238,18,0,0,115,0,0,0,11,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,16,0,0,77,12,0,0,177,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,245,27,0,0,119,1,0,0,109,2,0,0,189,0,0,0,51,0,0,0,11,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,0,0,0,218,240,0,0,111,147,0,0,179,4,0,0,94,0,0,0,10,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,60,0,0,43,45,0,0,135,3,0,0,111,0,0,0,14,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,98,0,0,161,3,0,0,53,4,0,0,35,1,0,0,78,0,0,0,14,0,0,0,7,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,251,1,0,0,0,0,0,0,222,3,0,0,15,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,1,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,6,0,0,0,0,0,0,18,0,0,0,7,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,185,3,0,0,199,95,0,0,116,2,0,0,120,0,0,0,28,0,0,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,80,34,0,245,5,0,0,54,100,0,0,87,10,0,0,105,2,0,0,239,0,0,0,143,0,0,0,42,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,5,1,0,156,4,0,0,3,43,0,0,185,11,0,0,213,4,0,0,20,2,0,0,192,1,0,0,239,0,0,0,54,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,210,27,0,0,76,5,0,0,172,8,0,0,67,0,0,0,10,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,5,0,0,240,9,0,0,102,0,0,0,18,0,0,0,4,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,222,0,0,158,4,0,0,62,8,0,0,214,1,0,0,130,0,0,0,41,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,159,23,0,0,114,1,0,0,50,13,0,0,200,0,0,0,30,0,0,0,5,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,1,0,0,238,3,0,0,131,0,0,0,29,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,21,0,0,114,0,0,0,131,1,0,0,98,0,0,0,23,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,0,0,0,67,2,0,0,194,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,1,0,0,213,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,16,0,0,119,0,0,0,122,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,1,0,0,38,0,0,0,45,2,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,114,0,0,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,1,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,52,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,2,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,128,2,0,0,57,2,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,77,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,2,0,0,4,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,9,0,0,193,78,0,0,147,10,0,0,255,2,0,0,5,1,0,0,178,0,0,0,107,0,0,0,30,0,0,0,14,0,0,0,3,0,0,0,0,0,0,0,86,137,1,0,102,34,0,0,126,142,0,0,113,34,0,0,196,12,0,0,0,5,0,0,82,3,0,0,145,1,0,0,114,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,204,228,0,0,251,42,0,0,78,106,0,0,22,46,0,0,84,22,0,0,178,9,0,0,24,8,0,0,24,4,0,0,175,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,84,75,0,0,10,38,0,0,49,44,0,0,191,3,0,0,205,0,0,0,70,0,0,0,18,0,0,0,11,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,49,0,0,237,58,0,0,227,5,0,0,17,1,0,0,52,0,0,0,19,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,212,0,0,205,41,0,0,230,61,0,0,185,21,0,0,134,7,0,0,45,3,0,0,58,2,0,0,249,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,25,0,0,125,26,0,0,11,88,0,0,224,10,0,0,122,2,0,0,182,0,0,0,123,0,0,0,20,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,24,0,0,24,45,0,0,89,10,0,0,22,3,0,0,3,1,0,0,168,0,0,0,27,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,80,0,0,37,12,0,0,235,15,0,0,239,7,0,0,128,3,0,0,201,1,0,0,130,1,0,0,158,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,4,0,0,251,44,0,0,239,15,0,0,209,1,0,0,73,0,0,0,5,0,0,0,14,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,36,0,0,202,22,0,0,138,2,0,0,96,0,0,0,24,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,165,86,0,0,247,16,0,0,134,15,0,0,80,5,0,0,159,1,0,0,132,0,0,0,96,0,0,0,14,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,4,0,0,179,18,0,0,81,36,0,0,55,3,0,0,168,0,0,0,44,0,0,0,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,14,0,0,120,17,0,0,207,2,0,0,198,0,0,0,60,0,0,0,31,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,209,32,0,0,133,4,0,0,151,4,0,0,227,1,0,0,182,0,0,0,88,0,0,0,31,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,1,0,0,107,32,0,0,202,4,0,0,32,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,13,0,0,32,6,0,0,57,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,38,0,0,31,4,0,0,46,4,0,0,166,0,0,0,29,0,0,0,6,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,2,0,0,22,107,0,0,23,109,0,0,197,7,0,0,91,1,0,0,69,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,22,0,0,90,39,0,0,38,6,0,0,85,1,0,0,91,0,0,0,24,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,85,0,0,35,6,0,0,123,8,0,0,10,3,0,0,68,1,0,0,124,0,0,0,65,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,211,3,0,0,0,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,0,0,0,4,0,1,0,8,0,2,0,8,0,3,0,8,0,0,0,3,0,1,0,8,0,2,0,8,0,3,0,8,0,0,0,4,0,3,0,8,0,2,0,8,0,1,0,8,0,0,0,4,0,17,0,8,0,1,0,8,0,2,0,8,0,0,0,4,0,17,0,8,0,3,0,8,0,2,0,8,120,153,22,0,88,236,23,0,88,218,16,0,112,240,3,0,0,1,0,1,0,1,0,1,2,5,10,16,0,0,0,0,2,0,0,0,26,1,0,0,1,0,0,0,166,0,0,0,3,0,0,0,54,1,0,0,4,0,0,0,188,1,0,0,5,0,0,0,188,1,0,0,6,0,0,0,188,1,0,0,7,0,0,0,188,1,0,0,5,1,0,0,98,0,0,0,0,1,0,0,0,1,0,0,1,1,0,0,62,0,0,0,128,0,0,0,42,1,0,0,4,1,0,0,170,1,0,0,255,255,255,255,0,0,0,0,144,133,39,0,112,0,0,0,160,180,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,2,0,0,176,1,0,0,230,0,0,0,134,2,0,0,42,1,0,0,68,0,0,0,198,0,0,0,48,2,0,0,0,0,0,0,3,0,0,0,6,0,0,0,12,0,0,0,24,0,0,0,48,0,0,0,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,3,3,3,3,2,2,2,1,1,1,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,3,3,3,3,2,2,2,1,1,1,0,0,0,0,0,0,0,8,0,8,12,8,12,14,12,14,15,14,15,0,0,0,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,2,2,1,3,5,5,5,5,5,5,5,5,5,5,2,2,1,3,5,5,5,5,5,5,5,5,5,5,1,1,0,3,5,5,5,5,5,5,5,5,5,5,3,3,3,4,0,0,0,0,0,0,8,8,8,12,12,12,14,14,14,15,15,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,2,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,64,0,0,64,64,0,0,128,64,0,0,160,64,0,0,192,64,0,0,224,64,0,0,0,65,0,0,16,65,0,0,32,65,0,0,48,65,0,0,64,65,0,0,80,65,0,0,96,65,0,0,112,65,1,0,2,0,3,0,4,0,3,0,3,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,43,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,235,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,235,3,0,0,0,0,0,1,2,3,4,5,5,4,4,3,3,4,4,4,5,5,4,4,4,4,3,3,6,7,7,7,8,9,10,9,8,7,7,6,11,12,13,11,6,7,8,9,14,10,9,8,6,11,12,13,11,6,9,14,10,9,11,12,13,11,14,10,12,0,1,1,2,2,3,3,4,5,6,7,7,7,8,4,5,6,9,10,10,8,11,12,11,9,9,10,10,8,11,12,11,9,9,10,10,8,11,12,11,9,9,10,10,8,13,13,9,9,10,10,8,13,13,9,9,10,10,14,14,14,14,14,0,0,105,0,0,0,120,0,0,0,134,0,0,0,149,0,0,0,152,0,0,0,146,1,0,0,228,1,0,0,243,1,0,0,1,2,0,0,148,2,0,0,16,2,0,0,31,2,0,0,45,2,0,0,206,2,0,0,21,1,0,0,36,1,0,0,50,1,0,0,65,1,0,0,68,1,0,0,180,1,0,0,8,3,0,0,23,3,0,0,37,3,0,0,163,2,0,0,52,3,0,0,67,3,0,0,81,3,0,0,221,2,0,0,0,0,1,1,2,2,2,0,166,0,0,0,181,0,0,0,195,0,0,0,210,0,0,0,213,0,0,0,161,1,0,0,60,2,0,0,75,2,0,0,89,2,0,0,178,2,0,0,104,2,0,0,119,2,0,0,133,2,0,0,236,2,0,0,82,1,0,0,97,1,0,0,111,1,0,0,126,1,0,0,129,1,0,0,195,1,0,0,96,3,0,0,111,3,0,0,125,3,0,0,187,2,0,0,140,3,0,0,155,3,0,0,169,3,0,0,245,2,0,0,5,5,5,5,6,7,8,9,5,5,5,5,6,7,8,8,1,2,3,3,4,5,6,7,4,4,4,4,5,6,7,7,227,0,0,0,237,0,0,0,247,0,0,0,1,1,0,0,10,1,0,0,170,1,0,0,184,3,0,0,194,3,0,0,204,3,0,0,196,2,0,0,214,3,0,0,224,3,0,0,234,3,0,0,254,2,0,0,1,2,3,4,0,0,0,0,55,197,17,242,242,55,197,17,17,242,55,197,197,17,242,55,224,164,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,8,0,0,184,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,111,39,0,160,30,39,0,80,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,57,64,16,0,1,0,0,0,0,0,72,217,38,0,48,148,38,0,88,0,0,0,3,0,0,0,154,153,153,153,153,153,241,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,168,89,38,0,80,36,38,0,96,0,0,0,3,0,0,0,0,0,0,0,0,0,46,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,8,243,37,0,64,198,37,0,120,0,0,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,32,163,37,0,56,124,37,0,124,0,0,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,0,0,0,0,0,0,128,64,16,0,1,0,0,0,0,0,48,57,37,0,232,14,37,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,192,229,36,0,208,194,36,0,132,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,27,37,0,112,0,0,0,240,50,24,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,112,137,0,255,9,47,15,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,16,216,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,224,35,0,200,239,34,0,32,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,16,0,1,0,0,0,0,0,184,42,34,0,200,239,34,0,32,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,16,0,1,0,0,0,0,0,192,138,33,0,136,15,33,0,108,0,0,0,1,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,64,16,0,1,0,0,0,0,0,16,168,32,0,216,76,32,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,52,40,0,216,76,32,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,216,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,1,0,0,0,0,0,0,0,0,0,0,178,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,33,37,0,112,0,0,0,64,53,24,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,123,15,10,0,121,15,10,0,119,15,10,0,117,15,10,0,115,15,10,0,113,15,10,0,111,15,10,0,109,15,10,0,107,15,10,0,105,15,10,0,103,15,10,0,101,15,10,0,99,15,10,0,97,15,10,0,95,15,10,0,93,15,10,0,91,15,10,0,89,15,10,0,87,15,10,0,85,15,10,0,83,15,10,0,81,15,10,0,79,15,10,0,77,15,10,0,75,15,10,0,73,15,10,0,71,15,10,0,69,15,10,0,67,15,10,0,65,15,10,0,63,15,10,0,61,15,10,0,59,15,10,0,57,15,10,0,55,15,10,0,53,15,10,0,51,15,10,0,49,15,10,0,47,15,10,0,45,15,10,0,43,15,10,0,41,15,10,0,39,15,10,0,37,15,10,0,35,15,10,0,33,15,10,0,31,15,10,0,29,15,10,0,27,15,10,0,25,15,10,0,23,15,10,0,21,15,10,0,19,15,10,0,17,15,10,0,15,15,10,0,13,15,10,0,11,15,10,0,9,15,10,0,7,15,10,0,5,15,10,0,3,15,10,0,1,15,10,0,255,14,10,0,253,14,10,0,251,14,10,0,249,14,10,0,247,14,10,0,245,14,10,0,243,14,10,0,241,14,10,0,239,14,10,0,237,14,10,0,235,14,10,0,233,14,10,0,231,14,10,0,229,14,10,0,227,14,10,0,225,14,10,0,223,14,10,0,221,14,10,0,219,14,10,0,217,14,10,0,215,14,10,0,213,14,10,0,211,14,10,0,209,14,10,0,207,14,10,0,205,14,10,0,203,14,10,0,201,14,10,0,199,14,10,0,197,14,10,0,195,14,10,0,193,14,10,0,191,14,10,0,189,14,10,0,187,14,10,0,185,14,10,0,183,14,10,0,181,14,10,0,179,14,10,0,177,14,10,0,175,14,10,0,173,14,10,0,171,14,10,0,169,14,10,0,167,14,10,0,165,14,10,0,163,14,10,0,161,14,10,0,159,14,10,0,157,14,10,0,155,14,10,0,153,14,10,0,151,14,10,0,149,14,10,0,147,14,10,0,145,14,10,0,143,14,10,0,141,14,10,0,139,14,10,0,137,14,10,0,135,14,10,0,133,14,10,0,131,14,10,0,129,14,10,0,127,14,10,0,125,14,10,0,123,14,10,0,121,14,10,0,119,14,10,0,117,14,10,0,115,14,10,0,113,14,10,0,111,14,10,0,109,14,10,0,107,14,10,0,105,14,10,0,103,14,10,0,101,14,10,0,99,14,10,0,97,14,10,0,95,14,10,0,93,14,10,0,91,14,10,0,89,14,10,0,87,14,10,0,85,14,10,0,83,14,10,0,81,14,10,0,79,14,10,0,77,14,10,0,75,14,10,0,73,14,10,0,71,14,10,0,69,14,10,0,67,14,10,0,65,14,10,0,63,14,10,0,61,14,10,0,59,14,10,0,57,14,10,0,55,14,10,0,53,14,10,0,51,14,10,0,49,14,10,0,47,14,10,0,45,14,10,0,43,14,10,0,41,14,10,0,39,14,10,0,37,14,10,0,35,14,10,0,33,14,10,0,31,14,10,0,29,14,10,0,27,14,10,0,25,14,10,0,23,14,10,0,21,14,10,0,19,14,10,0,17,14,10,0,15,14,10,0,13,14,10,0,11,14,10,0,9,14,10,0,7,14,10,0,5,14,10,0,3,14,10,0,1,14,10,0,255,13,10,0,253,13,10,0,251,13,10,0,249,13,10,0,247,13,10,0,245,13,10,0,243,13,10,0,241,13,10,0,239,13,10,0,237,13,10,0,235,13,10,0,233,13,10,0,231,13,10,0,229,13,10,0,227,13,10,0,225,13,10,0,223,13,10,0,221,13,10,0,219,13,10,0,217,13,10,0,215,13,10,0,213,13,10,0,211,13,10,0,209,13,10,0,207,13,10,0,205,13,10,0,203,13,10,0,201,13,10,0,199,13,10,0,197,13,10,0,195,13,10,0,193,13,10,0,191,13,10,0,189,13,10,0,187,13,10,0,185,13,10,0,183,13,10,0,181,13,10,0,179,13,10,0,177,13,10,0,175,13,10,0,173,13,10,0,171,13,10,0,169,13,10,0,167,13,10,0,165,13,10,0,163,13,10,0,161,13,10,0,159,13,10,0,157,13,10,0,155,13,10,0,153,13,10,0,151,13,10,0,149,13,10,0,147,13,10,0,145,13,10,0,143,13,10,0,141,13,10,0,139,13,10,0,137,13,10,0,135,13,10,0,133,13,10,0,131,13,10,0,129,13,10,0,127,13,10,0,125,13,10,0,123,13,10,0,121,13,10,0,119,13,10,0,117,13,10,0,115,13,10,0,113,13,10,0,111,13,10,0,109,13,10,0,107,13,10,0,105,13,10,0,103,13,10,0,101,13,10,0,99,13,10,0,97,13,10,0,95,13,10,0,93,13,10,0,91,13,10,0,89,13,10,0,87,13,10,0,85,13,10,0,83,13,10,0,81,13,10,0,79,13,10,0,77,13,10,0,75,13,10,0,73,13,10,0,71,13,10,0,69,13,10,0,67,13,10,0,65,13,10,0,63,13,10,0,61,13,10,0,59,13,10,0,57,13,10,0,55,13,10,0,53,13,10,0,51,13,10,0,49,13,10,0,47,13,10,0,45,13,10,0,43,13,10,0,41,13,10,0,39,13,10,0,37,13,10,0,35,13,10,0,33,13,10,0,31,13,10,0,29,13,10,0,27,13,10,0,25,13,10,0,23,13,10,0,21,13,10,0,19,13,10,0,17,13,10,0,15,13,10,0,13,13,10,0,11,13,10,0,9,13,10,0,7,13,10,0,5,13,10,0,3,13,10,0,1,13,10,0,255,12,10,0,253,12,10,0,251,12,10,0,249,12,10,0,247,12,10,0,245,12,10,0,243,12,10,0,241,12,10,0,239,12,10,0,237,12,10,0,235,12,10,0,233,12,10,0,231,12,10,0,229,12,10,0,227,12,10,0,225,12,10,0,223,12,10,0,221,12,10,0,219,12,10,0,217,12,10,0,215,12,10,0,213,12,10,0,211,12,10,0,209,12,10,0,207,12,10,0,205,12,10,0,203,12,10,0,201,12,10,0,199,12,10,0,197,12,10,0,195,12,10,0,193,12,10,0,191,12,10,0,189,12,10,0,187,12,10,0,185,12,10,0,183,12,10,0,181,12,10,0,179,12,10,0,177,12,10,0,175,12,10,0,173,12,10,0,171,12,10,0,169,12,10,0,167,12,10,0,165,12,10,0,163,12,10,0,161,12,10,0,159,12,10,0,157,12,10,0,155,12,10,0,153,12,10,0,151,12,10,0,149,12,10,0,147,12,10,0,145,12,10,0,143,12,10,0,141,12,10,0,139,12,10,0,137,12,10,0,135,12,10,0,133,12,10,0,131,12,10,0,129,12,10,0,127,12,10,0,125,12,10,0,123,12,10,0,121,12,10,0,119,12,10,0,117,12,10,0,115,12,10,0,113,12,10,0,111,12,10,0,109,12,10,0,107,12,10,0,105,12,10,0,103,12,10,0,101,12,10,0,99,12,10,0,97,12,10,0,95,12,10,0,93,12,10,0,91,12,10,0,89,12,10,0,87,12,10,0,85,12,10,0,83,12,10,0,81,12,10,0,79,12,10,0,77,12,10,0,75,12,10,0,73,12,10,0,71,12,10,0,69,12,10,0,67,12,10,0,65,12,10,0,63,12,10,0,61,12,10,0,59,12,10,0,57,12,10,0,55,12,10,0,53,12,10,0,51,12,10,0,49,12,10,0,47,12,10,0,45,12,10,0,43,12,10,0,41,12,10,0,39,12,10,0,37,12,10,0,35,12,10,0,33,12,10,0,31,12,10,0,29,12,10,0,27,12,10,0,25,12,10,0,23,12,10,0,21,12,10,0,19,12,10,0,17,12,10,0,15,12,10,0,13,12,10,0,11,12,10,0,9,12,10,0,7,12,10,0,5,12,10,0,3,12,10,0,1,12,10,0,255,11,10,0,253,11,10,0,251,11,10,0,249,11,10,0,247,11,10,0,245,11,10,0,243,11,10,0,241,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1578520);
/* memory initializer */ allocate([10,0,239,11,10,0,237,11,10,0,235,11,10,0,233,11,10,0,231,11,10,0,229,11,10,0,227,11,10,0,225,11,10,0,223,11,10,0,221,11,10,0,219,11,10,0,217,11,10,0,215,11,10,0,213,11,10,0,211,11,10,0,209,11,10,0,207,11,10,0,205,11,10,0,203,11,10,0,201,11,10,0,199,11,10,0,197,11,10,0,195,11,10,0,193,11,10,0,191,11,10,0,189,11,10,0,187,11,10,0,185,11,10,0,183,11,10,0,181,11,10,0,179,11,10,0,177,11,10,0,175,11,10,0,173,11,10,0,171,11,10,0,169,11,10,0,167,11,10,0,165,11,10,0,163,11,10,0,161,11,10,0,159,11,10,0,157,11,10,0,155,11,10,0,153,11,10,0,151,11,10,0,149,11,10,0,147,11,10,0,145,11,10,0,143,11,10,0,141,11,10,0,139,11,10,0,137,11,10,0,135,11,10,0,133,11,10,0,131,11,10,0,129,11,10,0,127,11,10,0,125,11,10,0,123,11,10,0,121,11,10,0,119,11,10,0,117,11,10,0,115,11,10,0,113,11,10,0,111,11,10,0,109,11,10,0,107,11,10,0,105,11,10,0,103,11,10,0,101,11,10,0,99,11,10,0,97,11,10,0,95,11,10,0,93,11,10,0,91,11,10,0,89,11,10,0,87,11,10,0,85,11,10,0,83,11,10,0,81,11,10,0,79,11,10,0,77,11,10,0,75,11,10,0,73,11,10,0,71,11,10,0,69,11,10,0,67,11,10,0,65,11,10,0,63,11,10,0,61,11,10,0,59,11,10,0,57,11,10,0,55,11,10,0,53,11,10,0,51,11,10,0,49,11,10,0,47,11,10,0,45,11,10,0,43,11,10,0,41,11,10,0,39,11,10,0,37,11,10,0,35,11,10,0,33,11,10,0,31,11,10,0,29,11,10,0,27,11,10,0,25,11,10,0,23,11,10,0,21,11,10,0,19,11,10,0,17,11,10,0,15,11,10,0,13,11,10,0,11,11,10,0,9,11,10,0,7,11,10,0,5,11,10,0,3,11,10,0,1,11,10,0,255,10,10,0,253,10,10,0,251,10,10,0,249,10,10,0,247,10,10,0,245,10,10,0,243,10,10,0,241,10,10,0,239,10,10,0,237,10,10,0,235,10,10,0,233,10,10,0,231,10,10,0,229,10,10,0,227,10,10,0,225,10,10,0,223,10,10,0,221,10,10,0,219,10,10,0,217,10,10,0,215,10,10,0,213,10,10,0,211,10,10,0,209,10,10,0,207,10,10,0,205,10,10,0,203,10,10,0,201,10,10,0,199,10,10,0,197,10,10,0,195,10,10,0,193,10,10,0,191,10,10,0,189,10,10,0,187,10,10,0,185,10,10,0,183,10,10,0,181,10,10,0,179,10,10,0,177,10,10,0,175,10,10,0,173,10,10,0,171,10,10,0,169,10,10,0,167,10,10,0,165,10,10,0,163,10,10,0,161,10,10,0,159,10,10,0,157,10,10,0,155,10,10,0,153,10,10,0,151,10,10,0,149,10,10,0,147,10,10,0,145,10,10,0,143,10,10,0,141,10,10,0,139,10,10,0,137,10,10,0,135,10,10,0,133,10,10,0,131,10,10,0,129,10,10,0,127,10,10,0,125,10,10,0,123,10,10,0,121,10,10,0,119,10,10,0,117,10,10,0,115,10,10,0,113,10,10,0,111,10,10,0,109,10,10,0,107,10,10,0,105,10,10,0,103,10,10,0,101,10,10,0,99,10,10,0,97,10,10,0,95,10,10,0,93,10,10,0,91,10,10,0,89,10,10,0,87,10,10,0,85,10,10,0,83,10,10,0,81,10,10,0,79,10,10,0,77,10,10,0,75,10,10,0,73,10,10,0,71,10,10,0,69,10,10,0,67,10,10,0,65,10,10,0,63,10,10,0,61,10,10,0,59,10,10,0,57,10,10,0,55,10,10,0,53,10,10,0,51,10,10,0,49,10,10,0,47,10,10,0,45,10,10,0,43,10,10,0,41,10,10,0,39,10,10,0,37,10,10,0,35,10,10,0,33,10,10,0,31,10,10,0,29,10,10,0,27,10,10,0,25,10,10,0,23,10,10,0,21,10,10,0,19,10,10,0,17,10,10,0,15,10,10,0,13,10,10,0,11,10,10,0,9,10,10,0,7,10,10,0,5,10,10,0,3,10,10,0,1,10,10,0,255,9,10,0,253,9,10,0,251,9,10,0,249,9,10,0,247,9,10,0,245,9,10,0,243,9,10,0,241,9,10,0,239,9,10,0,237,9,10,0,235,9,10,0,233,9,10,0,231,9,10,0,229,9,10,0,227,9,10,0,225,9,10,0,223,9,10,0,221,9,10,0,219,9,10,0,217,9,10,0,215,9,10,0,213,9,10,0,211,9,10,0,209,9,10,0,207,9,10,0,205,9,10,0,203,9,10,0,201,9,10,0,199,9,10,0,197,9,10,0,195,9,10,0,193,9,10,0,191,9,10,0,189,9,10,0,187,9,10,0,185,9,10,0,183,9,10,0,181,9,10,0,179,9,10,0,177,9,10,0,175,9,10,0,173,9,10,0,171,9,10,0,169,9,10,0,167,9,10,0,165,9,10,0,163,9,10,0,161,9,10,0,159,9,10,0,157,9,10,0,155,9,10,0,153,9,10,0,151,9,10,0,149,9,10,0,147,9,10,0,145,9,10,0,143,9,10,0,141,9,10,0,139,9,10,0,137,9,10,0,135,9,10,0,133,9,10,0,131,9,10,0,129,9,10,0,127,9,10,0,125,9,10,0,123,9,10,0,121,9,10,0,119,9,10,0,117,9,10,0,115,9,10,0,113,9,10,0,111,9,10,0,109,9,10,0,107,9,10,0,105,9,10,0,103,9,10,0,101,9,10,0,99,9,10,0,97,9,10,0,95,9,10,0,93,9,10,0,91,9,10,0,89,9,10,0,87,9,10,0,85,9,10,0,83,9,10,0,81,9,10,0,79,9,10,0,77,9,10,0,75,9,10,0,73,9,10,0,71,9,10,0,69,9,10,0,67,9,10,0,65,9,10,0,63,9,10,0,61,9,10,0,59,9,10,0,57,9,10,0,55,9,10,0,53,9,10,0,51,9,10,0,49,9,10,0,47,9,10,0,45,9,10,0,43,9,10,0,41,9,10,0,39,9,10,0,37,9,10,0,35,9,10,0,33,9,10,0,31,9,10,0,29,9,10,0,27,9,10,0,25,9,10,0,23,9,10,0,21,9,10,0,19,9,10,0,17,9,10,0,15,9,10,0,13,9,10,0,11,9,10,0,9,9,10,0,7,9,10,0,5,9,10,0,3,9,10,0,1,9,10,0,255,8,10,0,253,8,10,0,251,8,10,0,249,8,10,0,247,8,10,0,245,8,10,0,243,8,10,0,241,8,10,0,239,8,10,0,237,8,10,0,235,8,10,0,233,8,10,0,231,8,10,0,229,8,10,0,227,8,10,0,225,8,10,0,223,8,10,0,221,8,10,0,219,8,10,0,217,8,10,0,215,8,10,0,213,8,10,0,211,8,10,0,209,8,10,0,207,8,10,0,205,8,10,0,203,8,10,0,201,8,10,0,199,8,10,0,197,8,10,0,195,8,10,0,193,8,10,0,191,8,10,0,189,8,10,0,187,8,10,0,185,8,10,0,183,8,10,0,181,8,10,0,179,8,10,0,177,8,10,0,175,8,10,0,173,8,10,0,171,8,10,0,169,8,10,0,167,8,10,0,165,8,10,0,163,8,10,0,161,8,10,0,159,8,10,0,157,8,10,0,155,8,10,0,153,8,10,0,151,8,10,0,149,8,10,0,147,8,10,0,145,8,10,0,143,8,10,0,141,8,10,0,139,8,10,0,137,8,10,0,135,8,10,0,133,8,10,0,131,8,10,0,129,8,10,0,127,8,10,0,125,8,10,0,123,8,10,0,121,8,10,0,119,8,10,0,117,8,10,0,115,8,10,0,113,8,10,0,111,8,10,0,109,8,10,0,107,8,10,0,105,8,10,0,103,8,10,0,101,8,10,0,99,8,10,0,97,8,10,0,95,8,10,0,93,8,10,0,91,8,10,0,89,8,10,0,87,8,10,0,85,8,10,0,83,8,10,0,81,8,10,0,79,8,10,0,77,8,10,0,75,8,10,0,73,8,10,0,71,8,10,0,69,8,10,0,67,8,10,0,65,8,10,0,63,8,10,0,61,8,10,0,59,8,10,0,57,8,10,0,55,8,10,0,53,8,10,0,51,8,10,0,49,8,10,0,47,8,10,0,45,8,10,0,43,8,10,0,41,8,10,0,39,8,10,0,37,8,10,0,35,8,10,0,33,8,10,0,31,8,10,0,29,8,10,0,27,8,10,0,25,8,10,0,23,8,10,0,21,8,10,0,19,8,10,0,17,8,10,0,15,8,10,0,13,8,10,0,11,8,10,0,9,8,10,0,7,8,10,0,5,8,10,0,3,8,10,0,1,8,10,0,255,7,10,0,253,7,10,0,251,7,10,0,249,7,10,0,247,7,10,0,245,7,10,0,243,7,10,0,241,7,10,0,239,7,10,0,237,7,10,0,235,7,10,0,233,7,10,0,231,7,10,0,229,7,10,0,227,7,10,0,225,7,10,0,223,7,10,0,221,7,10,0,219,7,10,0,217,7,10,0,215,7,10,0,213,7,10,0,211,7,10,0,209,7,10,0,207,7,10,0,205,7,10,0,203,7,10,0,201,7,10,0,199,7,10,0,197,7,10,0,195,7,10,0,193,7,10,0,191,7,10,0,189,7,10,0,187,7,10,0,185,7,10,0,183,7,10,0,181,7,10,0,179,7,10,0,177,7,10,0,175,7,10,0,173,7,10,0,171,7,10,0,169,7,10,0,167,7,10,0,165,7,10,0,163,7,10,0,161,7,10,0,159,7,10,0,157,7,10,0,155,7,10,0,153,7,10,0,151,7,10,0,149,7,10,0,147,7,10,0,145,7,10,0,143,7,10,0,141,7,10,0,139,7,10,0,137,7,10,0,135,7,10,0,133,7,10,0,131,7,10,0,129,7,10,0,127,7,10,0,125,7,10,0,123,7,10,0,121,7,10,0,119,7,10,0,117,7,10,0,115,7,10,0,113,7,10,0,111,7,10,0,109,7,10,0,107,7,10,0,105,7,10,0,103,7,10,0,101,7,10,0,99,7,10,0,97,7,10,0,95,7,10,0,93,7,10,0,91,7,10,0,89,7,10,0,87,7,10,0,85,7,10,0,83,7,10,0,81,7,10,0,79,7,10,0,77,7,10,0,75,7,10,0,73,7,10,0,71,7,10,0,69,7,10,0,67,7,10,0,65,7,10,0,63,7,10,0,61,7,10,0,59,7,10,0,57,7,10,0,55,7,10,0,53,7,10,0,51,7,10,0,49,7,10,0,47,7,10,0,45,7,10,0,43,7,10,0,41,7,10,0,39,7,10,0,37,7,10,0,35,7,10,0,33,7,10,0,31,7,10,0,29,7,10,0,27,7,10,0,25,7,10,0,23,7,10,0,21,7,10,0,19,7,10,0,17,7,10,0,15,7,10,0,13,7,10,0,11,7,10,0,9,7,10,0,7,7,10,0,5,7,10,0,3,7,10,0,1,7,10,0,255,6,10,0,253,6,10,0,251,6,10,0,249,6,10,0,247,6,10,0,245,6,10,0,243,6,10,0,241,6,10,0,239,6,10,0,237,6,10,0,235,6,10,0,233,6,10,0,231,6,10,0,229,6,10,0,227,6,10,0,225,6,10,0,223,6,10,0,221,6,10,0,219,6,10,0,217,6,10,0,215,6,10,0,213,6,10,0,211,6,10,0,209,6,10,0,207,6,10,0,205,6,10,0,203,6,10,0,201,6,10,0,199,6,10,0,197,6,10,0,195,6,10,0,193,6,10,0,191,6,10,0,189,6,10,0,187,6,10,0,185,6,10,0,183,6,10,0,181,6,10,0,179,6,10,0,177,6,10,0,175,6,10,0,173,6,10,0,171,6,10,0,169,6,10,0,167,6,10,0,165,6,10,0,163,6,10,0,161,6,10,0,159,6,10,0,157,6,10,0,155,6,10,0,153,6,10,0,151,6,10,0,149,6,10,0,147,6,10,0,145,6,10,0,143,6,10,0,141,6,10,0,139,6,10,0,137,6,10,0,135,6,10,0,133,6,10,0,131,6,10,0,129,6,10,0,127,6,10,0,125,6,10,0,123,6,10,0,121,6,10,0,119,6,10,0,117,6,10,0,115,6,10,0,113,6,10,0,111,6,10,0,109,6,10,0,107,6,10,0,105,6,10,0,103,6,10,0,101,6,10,0,99,6,10,0,97,6,10,0,95,6,10,0,93,6,10,0,91,6,10,0,89,6,10,0,87,6,10,0,85,6,10,0,83,6,10,0,81,6,10,0,79,6,10,0,77,6,10,0,75,6,10,0,73,6,10,0,71,6,10,0,69,6,10,0,67,6,10,0,65,6,10,0,63,6,10,0,61,6,10,0,59,6,10,0,57,6,10,0,55,6,10,0,53,6,10,0,51,6,10,0,49,6,10,0,47,6,10,0,45,6,10,0,43,6,10,0,41,6,10,0,39,6,10,0,37,6,10,0,35,6,10,0,33,6,10,0,31,6,10,0,29,6,10,0,27,6,10,0,25,6,10,0,23,6,10,0,21,6,10,0,19,6,10,0,17,6,10,0,15,6,10,0,13,6,10,0,11,6,10,0,9,6,10,0,7,6,10,0,5,6,10,0,3,6,10,0,1,6,10,0,255,5,10,0,253,5,10,0,251,5,10,0,249,5,10,0,247,5,10,0,245,5,10,0,243,5,10,0,241,5,10,0,239,5,10,0,237,5,10,0,235,5,10,0,233,5,10,0,231,5,10,0,229,5,10,0,227,5,10,0,225,5,10,0,223,5,10,0,221,5,10,0,219,5,10,0,217,5,10,0,215,5,10,0,213,5,10,0,211,5,10,0,209,5,10,0,207,5,10,0,205,5,10,0,203,5,10,0,201,5,10,0,199,5,10,0,197,5,10,0,195,5,10,0,193,5,10,0,191,5,10,0,189,5,10,0,187,5,10,0,185,5,10,0,183,5,10,0,181,5,10,0,179,5,10,0,177,5,10,0,175,5,10,0,173,5,10,0,171,5,10,0,169,5,10,0,167,5,10,0,165,5,10,0,163,5,10,0,161,5,10,0,159,5,10,0,157,5,10,0,155,5,10,0,153,5,10,0,151,5,10,0,149,5,10,0,147,5,10,0,145,5,10,0,143,5,10,0,141,5,10,0,139,5,10,0,137,5,10,0,135,5,10,0,133,5,10,0,131,5,10,0,129,5,10,0,127,5,10,0,125,5,10,0,123,5,10,0,121,5,10,0,119,5,10,0,117,5,10,0,115,5,10,0,113,5,10,0,111,5,10,0,109,5,10,0,107,5,10,0,105,5,10,0,103,5,10,0,101,5,10,0,99,5,10,0,97,5,10,0,95,5,10,0,93,5,10,0,91,5,10,0,89,5,10,0,87,5,10,0,85,5,10,0,83,5,10,0,81,5,10,0,79,5,10,0,77,5,10,0,75,5,10,0,73,5,10,0,71,5,10,0,69,5,10,0,67,5,10,0,65,5,10,0,63,5,10,0,61,5,10,0,59,5,10,0,57,5,10,0,55,5,10,0,53,5,10,0,51,5,10,0,49,5,10,0,47,5,10,0,45,5,10,0,43,5,10,0,41,5,10,0,39,5,10,0,37,5,10,0,35,5,10,0,33,5,10,0,31,5,10,0,29,5,10,0,27,5,10,0,25,5,10,0,23,5,10,0,21,5,10,0,19,5,10,0,17,5,10,0,15,5,10,0,13,5,10,0,11,5,10,0,9,5,10,0,7,5,10,0,5,5,10,0,3,5,10,0,1,5,10,0,255,4,10,0,253,4,10,0,251,4,10,0,249,4,10,0,247,4,10,0,245,4,10,0,243,4,10,0,241,4,10,0,239,4,10,0,237,4,10,0,235,4,10,0,233,4,10,0,231,4,10,0,229,4,10,0,227,4,10,0,225,4,10,0,223,4,10,0,221,4,10,0,219,4,10,0,217,4,10,0,215,4,10,0,213,4,10,0,211,4,10,0,209,4,10,0,207,4,10,0,205,4,10,0,203,4,10,0,201,4,10,0,199,4,10,0,197,4,10,0,195,4,10,0,193,4,10,0,191,4,10,0,189,4,10,0,187,4,10,0,185,4,10,0,183,4,10,0,181,4,10,0,179,4,10,0,177,4,10,0,175,4,10,0,173,4,10,0,171,4,10,0,169,4,10,0,167,4,10,0,165,4,10,0,163,4,10,0,161,4,10,0,159,4,10,0,157,4,10,0,155,4,10,0,153,4,10,0,151,4,10,0,149,4,10,0,147,4,10,0,145,4,10,0,143,4,10,0,141,4,10,0,139,4,10,0,137,4,10,0,135,4,10,0,133,4,10,0,131,4,10,0,129,4,10,0,127,4,10,0,125,4,10,0,123,4,10,0,121,4,10,0,119,4,10,0,117,4,10,0,115,4,10,0,113,4,10,0,111,4,10,0,109,4,10,0,107,4,10,0,105,4,10,0,103,4,10,0,101,4,10,0,99,4,10,0,97,4,10,0,95,4,10,0,93,4,10,0,91,4,10,0,89,4,10,0,87,4,10,0,85,4,10,0,83,4,10,0,81,4,10,0,79,4,10,0,77,4,10,0,75,4,10,0,73,4,10,0,71,4,10,0,69,4,10,0,67,4,10,0,65,4,10,0,63,4,10,0,61,4,10,0,59,4,10,0,57,4,10,0,55,4,10,0,53,4,10,0,51,4,10,0,49,4,10,0,47,4,10,0,45,4,10,0,43,4,10,0,41,4,10,0,39,4,10,0,37,4,10,0,35,4,10,0,33,4,10,0,31,4,10,0,29,4,10,0,27,4,10,0,25,4,10,0,23,4,10,0,21,4,10,0,19,4,10,0,17,4,10,0,15,4,10,0,13,4,10,0,11,4,10,0,9,4,10,0,7,4,10,0,5,4,10,0,3,4,10,0,1,4,10,0,255,3,10,0,253,3,10,0,251,3,10,0,249,3,10,0,247,3,10,0,245,3,10,0,243,3,10,0,241,3,10,0,239,3,10,0,237,3,10,0,235,3,10,0,233,3,10,0,231,3,10,0,229,3,10,0,227,3,10,0,225,3,10,0,223,3,10,0,221,3,10,0,219,3,10,0,217,3,10,0,215,3,10,0,213,3,10,0,211,3,10,0,209,3,10,0,207,3,10,0,205,3,10,0,203,3,10,0,201,3,10,0,199,3,10,0,197,3,10,0,195,3,10,0,193,3,10,0,191,3,10,0,189,3,10,0,187,3,10,0,185,3,10,0,183,3,10,0,181,3,10,0,179,3,10,0,177,3,10,0,175,3,10,0,173,3,10,0,171,3,10,0,169,3,10,0,167,3,10,0,165,3,10,0,163,3,10,0,161,3,10,0,159,3,10,0,157,3,10,0,155,3,10,0,153,3,10,0,151,3,10,0,149,3,10,0,147,3,10,0,145,3,10,0,143,3,10,0,141,3,10,0,139,3,10,0,137,3,10,0,135,3,10,0,133,3,10,0,131,3,10,0,129,3,10,0,127,3,10,0,125,3,10,0,123,3,10,0,121,3,10,0,119,3,10,0,117,3,10,0,115,3,10,0,113,3,10,0,111,3,10,0,109,3,10,0,107,3,10,0,105,3,10,0,103,3,10,0,101,3,10,0,99,3,10,0,97,3,10,0,95,3,10,0,93,3,10,0,91,3,10,0,89,3,10,0,87,3,10,0,85,3,10,0,83,3,10,0,81,3,10,0,79,3,10,0,77,3,10,0,75,3,10,0,73,3,10,0,71,3,10,0,69,3,10,0,67,3,10,0,65,3,10,0,63,3,10,0,61,3,10,0,59,3,10,0,57,3,10,0,55,3,10,0,53,3,10,0,51,3,10,0,49,3,10,0,47,3,10,0,45,3,10,0,43,3,10,0,41,3,10,0,39,3,10,0,37,3,10,0,35,3,10,0,33,3,10,0,31,3,10,0,29,3,10,0,27,3,10,0,25,3,10,0,23,3,10,0,21,3,10,0,19,3,10,0,17,3,10,0,15,3,10,0,13,3,10,0,11,3,10,0,9,3,10,0,7,3,10,0,5,3,10,0,3,3,10,0,1,3,10,0,255,2,10,0,253,2,10,0,251,2,10,0,249,2,10,0,247,2,10,0,245,2,10,0,243,2,10,0,241,2,10,0,239,2,10,0,237,2,10,0,235,2,10,0,233,2,10,0,231,2,10,0,229,2,10,0,227,2,10,0,225,2,10,0,223,2,10,0,221,2,10,0,219,2,10,0,217,2,10,0,215,2,10,0,213,2,10,0,211,2,10,0,209,2,10,0,207,2,10,0,205,2,10,0,203,2,10,0,201,2,10,0,199,2,10,0,197,2,10,0,195,2,10,0,193,2,10,0,191,2,10,0,189,2,10,0,187,2,10,0,185,2,10,0,183,2,10,0,181,2,10,0,179,2,10,0,177,2,10,0,175,2,10,0,173,2,10,0,171,2,10,0,169,2,10,0,167,2,10,0,165,2,10,0,163,2,10,0,161,2,10,0,159,2,10,0,157,2,10,0,155,2,10,0,153,2,10,0,151,2,10,0,149,2,10,0,147,2,10,0,145,2,10,0,143,2,10,0,141,2,10,0,139,2,10,0,137,2,10,0,135,2,10,0,133,2,10,0,131,2,10,0,129,2,10,0,127,2,10,0,125,2,10,0,123,2,10,0,121,2,10,0,119,2,10,0,117,2,10,0,115,2,10,0,113,2,10,0,111,2,10,0,109,2,10,0,107,2,10,0,105,2,10,0,103,2,10,0,101,2,10,0,99,2,10,0,97,2,10,0,95,2,10,0,93,2,10,0,91,2,10,0,89,2,10,0,87,2,10,0,85,2,10,0,83,2,10,0,81,2,10,0,79,2,10,0,77,2,10,0,75,2,10,0,73,2,10,0,71,2,10,0,69,2,10,0,67,2,10,0,65,2,10,0,63,2,10,0,61,2,10,0,59,2,10,0,57,2,10,0,55,2,10,0,53,2,10,0,51,2,10,0,49,2,10,0,47,2,10,0,45,2,10,0,43,2,10,0,41,2,10,0,39,2,10,0,37,2,10,0,35,2,10,0,33,2,10,0,31,2,10,0,29,2,10,0,27,2,10,0,25,2,10,0,23,2,10,0,21,2,10,0,19,2,10,0,17,2,10,0,15,2,10,0,13,2,10,0,11,2,10,0,9,2,10,0,7,2,10,0,5,2,10,0,3,2,10,0,1,2,10,0,255,1,10,0,253,1,10,0,251,1,10,0,249,1,10,0,247,1,10,0,245,1,10,0,243,1,10,0,241,1,10,0,239,1,10,0,237,1,10,0,235,1,10,0,233,1,10,0,231,1,10,0,229,1,10,0,227,1,10,0,225,1,10,0,223,1,10,0,221,1,10,0,219,1,10,0,217,1,10,0,215,1,10,0,213,1,10,0,211,1,10,0,209,1,10,0,207,1,10,0,205,1,10,0,203,1,10,0,201,1,10,0,199,1,10,0,197,1,10,0,195,1,10,0,193,1,10,0,191,1,10,0,189,1,10,0,187,1,10,0,185,1,10,0,183,1,10,0,181,1,10,0,179,1,10,0,177,1,10,0,175,1,10,0,173,1,10,0,171,1,10,0,169,1,10,0,167,1,10,0,165,1,10,0,163,1,10,0,161,1,10,0,159,1,10,0,157,1,10,0,155,1,10,0,153,1,10,0,151,1,10,0,149,1,10,0,147,1,10,0,145,1,10,0,143,1,10,0,141,1,10,0,139,1,10,0,137,1,10,0,135,1,10,0,133,1,10,0,131,1,10,0,129,1,10,0,127,1,10,0,125,1,10,0,123,1,10,0,121,1,10,0,119,1,10,0,117,1,10,0,115,1,10,0,113,1,10,0,111,1,10,0,109,1,10,0,107,1,10,0,105,1,10,0,103,1,10,0,101,1,10,0,99,1,10,0,97,1,10,0,95,1,10,0,93,1,10,0,91,1,10,0,89,1,10,0,87,1,10,0,85,1,10,0,83,1,10,0,81,1,10,0,79,1,10,0,77,1,10,0,75,1,10,0,73,1,10,0,71,1,10,0,69,1,10,0,67,1,10,0,65,1,10,0,63,1,10,0,61,1,10,0,59,1,10,0,57,1,10,0,55,1,10,0,53,1,10,0,51,1,10,0,49,1,10,0,47,1,10,0,45,1,10,0,43,1,10,0,41,1,10,0,39,1,10,0,37,1,10,0,35,1,10,0,33,1,10,0,31,1,10,0,29,1,10,0,27,1,10,0,25,1,10,0,23,1,10,0,21,1,10,0,19,1,10,0,17,1,10,0,15,1,10,0,13,1,10,0,11,1,10,0,9,1,10,0,7,1,10,0,5,1,10,0,3,1,10,0,1,1,10,0,255,0,10,0,253,0,10,0,251,0,10,0,249,0,10,0,247,0,10,0,245,0,10,0,243,0,10,0,241,0,10,0,239,0,10,0,237,0,10,0,235,0,10,0,233,0,10,0,231,0,10,0,229,0,10,0,227,0,10,0,225,0,10,0,223,0,10,0,221,0,10,0,219,0,10,0,217,0,10,0,215,0,10,0,213,0,10,0,211,0,10,0,209,0,10,0,207,0,10,0,205,0,10,0,203,0,10,0,201,0,10,0,199,0,10,0,197,0,10,0,195,0,10,0,193,0,10,0,191,0,10,0,189,0,10,0,187,0,10,0,185,0,10,0,183,0,10,0,181,0,10,0,179,0,10,0,177,0,10,0,175,0,10,0,173,0,10,0,171,0,10,0,169,0,10,0,167,0,10,0,165,0,10,0,163,0,10,0,161,0,10,0,159,0,10,0,157,0,10,0,155,0,10,0,153,0,10,0,151,0,10,0,149,0,10,0,147,0,10,0,145,0,10,0,143,0,10,0,141,0,10,0,139,0,10,0,137,0,10,0,135,0,10,0,133,0,10,0,131,0,10,0,129,0,10,0,127,0,10,0,125,0,10,0,123,0,10,0,121,0,10,0,119,0,10,0,117,0,10,0,115,0,10,0,113,0,10,0,111,0,10,0,109,0,10,0,107,0,10,0,105,0,10,0,103,0,10,0,101,0,10,0,99,0,10,0,97,0,10,0,95,0,10,0,93,0,10,0,91,0,10,0,89,0,10,0,87,0,10,0,85,0,10,0,83,0,10,0,81,0,10,0,79,0,10,0,77,0,10,0,75,0,10,0,73,0,10,0,71,0,10,0,69,0,10,0,67,0,10,0,65,0,10,0,63,0,10,0,61,0,10,0,59,0,10,0,57,0,10,0,55,0,10,0,53,0,10,0,51,0,10,0,49,0,10,0,47,0,10,0,45,0,10,0,43,0,10,0,41,0,10,0,39,0,10,0,37,0,10,0,35,0,10,0,33,0,10,0,31,0,10,0,29,0,10,0,27,0,10,0,25,0,10,0,23,0,10,0,21,0,10,0,19,0,10,0,17,0,10,0,15,0,10,0,13,0,10,0,11,0,10,0,9,0,10,0,7,0,10,0,5,0,10,0,3,0,10,0,1,0,9,0,63,0,9,0,61,0,9,0,59,0,9,0,57,0,9,0,55,0,9,0,53,0,9,0,51,0,9,0,49,0,9,0,47,0,9,0,45,0,9,0,43,0,9,0,41,0,9,0,39,0,9,0,37,0,9,0,35,0,9,0,33,0,9,0,31,0,9,0,29,0,9,0,27,0,9,0,25,0,9,0,23,0,9,0,21,0,9,0,19,0,9,0,17,0,9,0,15,0,9,0,13,0,9,0,11,0,9,0,9,0,9,0,7,0,9,0,5,0,9,0,3,0,9,0,1,0,8,0,31,0,8,0,29,0,8,0,27,0,8,0,25,0,8,0,23,0,8,0,21,0,8,0,19,0,8,0,17,0,8,0,15,0,8,0,13,0,8,0,11,0,8,0,9,0,8,0,7,0,8,0,5,0,8,0,3,0,8,0,1,0,7,0,15,0,7,0,13,0,7,0,11,0,7,0,9,0,7,0,7,0,7,0,5,0,7,0,3,0,7,0,1,0,6,0,7,0,6,0,5,0,6,0,3,0,6,0,1,0,5,0,3,0,5,0,1,0,4,0,1,0,3,0,1,0,2,0,1,0,1,0,1,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,5,0,2,0,6,0,0,0,6,0,2,0,6,0,4,0,6,0,6,0,7,0,0,0,7,0,2,0,7,0,4,0,7,0,6,0,7,0,8,0,7,0,10,0,7,0,12,0,7,0,14,0,8,0,0,0,8,0,2,0,8,0,4,0,8,0,6,0,8,0,8,0,8,0,10,0,8,0,12,0,8,0,14,0,8,0,16,0,8,0,18,0,8,0,20,0,8,0,22,0,8,0,24,0,8,0,26,0,8,0,28,0,8,0,30,0,9,0,0,0,9,0,2,0,9,0,4,0,9,0,6,0,9,0,8,0,9,0,10,0,9,0,12,0,9,0,14,0,9,0,16,0,9,0,18,0,9,0,20,0,9,0,22,0,9,0,24,0,9,0,26,0,9,0,28,0,9,0,30,0,9,0,32,0,9,0,34,0,9,0,36,0,9,0,38,0,9,0,40,0,9,0,42,0,9,0,44,0,9,0,46,0,9,0,48,0,9,0,50,0,9,0,52,0,9,0,54,0,9,0,56,0,9,0,58,0,9,0,60,0,9,0,62,0,10,0,0,0,10,0,2,0,10,0,4,0,10,0,6,0,10,0,8,0,10,0,10,0,10,0,12,0,10,0,14,0,10,0,16,0,10,0,18,0,10,0,20,0,10,0,22,0,10,0,24,0,10,0,26,0,10,0,28,0,10,0,30,0,10,0,32,0,10,0,34,0,10,0,36,0,10,0,38,0,10,0,40,0,10,0,42,0,10,0,44,0,10,0,46,0,10,0,48,0,10,0,50,0,10,0,52,0,10,0,54,0,10,0,56,0,10,0,58,0,10,0,60,0,10,0,62,0,10,0,64,0,10,0,66,0,10,0,68,0,10,0,70,0,10,0,72,0,10,0,74,0,10,0,76,0,10,0,78,0,10,0,80,0,10,0,82,0,10,0,84,0,10,0,86,0,10,0,88,0,10,0,90,0,10,0,92,0,10,0,94,0,10,0,96,0,10,0,98,0,10,0,100,0,10,0,102,0,10,0,104,0,10,0,106,0,10,0,108,0,10,0,110,0,10,0,112,0,10,0,114,0,10,0,116,0,10,0,118,0,10,0,120,0,10,0,122,0,10,0,124,0,10,0,126,0,10,0,128,0,10,0,130,0,10,0,132,0,10,0,134,0,10,0,136,0,10,0,138,0,10,0,140,0,10,0,142,0,10,0,144,0,10,0,146,0,10,0,148,0,10,0,150,0,10,0,152,0,10,0,154,0,10,0,156,0,10,0,158,0,10,0,160,0,10,0,162,0,10,0,164,0,10,0,166,0,10,0,168,0,10,0,170,0,10,0,172,0,10,0,174,0,10,0,176,0,10,0,178,0,10,0,180,0,10,0,182,0,10,0,184,0,10,0,186,0,10,0,188,0,10,0,190,0,10,0,192,0,10,0,194,0,10,0,196,0,10,0,198,0,10,0,200,0,10,0,202,0,10,0,204,0,10,0,206,0,10,0,208,0,10,0,210,0,10,0,212,0,10,0,214,0,10,0,216,0,10,0,218,0,10,0,220,0,10,0,222,0,10,0,224,0,10,0,226,0,10,0,228,0,10,0,230,0,10,0,232,0,10,0,234,0,10,0,236,0,10,0,238,0,10,0,240,0,10,0,242,0,10,0,244,0,10,0,246,0,10,0,248,0,10,0,250,0,10,0,252,0,10,0,254,0,10,0,0,1,10,0,2,1,10,0,4,1,10,0,6,1,10,0,8,1,10,0,10,1,10,0,12,1,10,0,14,1,10,0,16,1,10,0,18,1,10,0,20,1,10,0,22,1,10,0,24,1,10,0,26,1,10,0,28,1,10,0,30,1,10,0,32,1,10,0,34,1,10,0,36,1,10,0,38,1,10,0,40,1,10,0,42,1,10,0,44,1,10,0,46,1,10,0,48,1,10,0,50,1,10,0,52,1,10,0,54,1,10,0,56,1,10,0,58,1,10,0,60,1,10,0,62,1,10,0,64,1,10,0,66,1,10,0,68,1,10,0,70,1,10,0,72,1,10,0,74,1,10,0,76,1,10,0,78,1,10,0,80,1,10,0,82,1,10,0,84,1,10,0,86,1,10,0,88,1,10,0,90,1,10,0,92,1,10,0,94,1,10,0,96,1,10,0,98,1,10,0,100,1,10,0,102,1,10,0,104,1,10,0,106,1,10,0,108,1,10,0,110,1,10,0,112,1,10,0,114,1,10,0,116,1,10,0,118,1,10,0,120,1,10,0,122,1,10,0,124,1,10,0,126,1,10,0,128,1,10,0,130,1,10,0,132,1,10,0,134,1,10,0,136,1,10,0,138,1,10,0,140,1,10,0,142,1,10,0,144,1,10,0,146,1,10,0,148,1,10,0,150,1,10,0,152,1,10,0,154,1,10,0,156,1,10,0,158,1,10,0,160,1,10,0,162,1,10,0,164,1,10,0,166,1,10,0,168,1,10,0,170,1,10,0,172,1,10,0,174,1,10,0,176,1,10,0,178,1,10,0,180,1,10,0,182,1,10,0,184,1,10,0,186,1,10,0,188,1,10,0,190,1,10,0,192,1,10,0,194,1,10,0,196,1,10,0,198,1,10,0,200,1,10,0,202,1,10,0,204,1,10,0,206,1,10,0,208,1,10,0,210,1,10,0,212,1,10,0,214,1,10,0,216,1,10,0,218,1,10,0,220,1,10,0,222,1,10,0,224,1,10,0,226,1,10,0,228,1,10,0,230,1,10,0,232,1,10,0,234,1,10,0,236,1,10,0,238,1,10,0,240,1,10,0,242,1,10,0,244,1,10,0,246,1,10,0,248,1,10,0,250,1,10,0,252,1,10,0,254,1,10,0,0,2,10,0,2,2,10,0,4,2,10,0,6,2,10,0,8,2,10,0,10,2,10,0,12,2,10,0,14,2,10,0,16,2,10,0,18,2,10,0,20,2,10,0,22,2,10,0,24,2,10,0,26,2,10,0,28,2,10,0,30,2,10,0,32,2,10,0,34,2,10,0,36,2,10,0,38,2,10,0,40,2,10,0,42,2,10,0,44,2,10,0,46,2,10,0,48,2,10,0,50,2,10,0,52,2,10,0,54,2,10,0,56,2,10,0,58,2,10,0,60,2,10,0,62,2,10,0,64,2,10,0,66,2,10,0,68,2,10,0,70,2,10,0,72,2,10,0,74,2,10,0,76,2,10,0,78,2,10,0,80,2,10,0,82,2,10,0,84,2,10,0,86,2,10,0,88,2,10,0,90,2,10,0,92,2,10,0,94,2,10,0,96,2,10,0,98,2,10,0,100,2,10,0,102,2,10,0,104,2,10,0,106,2,10,0,108,2,10,0,110,2,10,0,112,2,10,0,114,2,10,0,116,2,10,0,118,2,10,0,120,2,10,0,122,2,10,0,124,2,10,0,126,2,10,0,128,2,10,0,130,2,10,0,132,2,10,0,134,2,10,0,136,2,10,0,138,2,10,0,140,2,10,0,142,2,10,0,144,2,10,0,146,2,10,0,148,2,10,0,150,2,10,0,152,2,10,0,154,2,10,0,156,2,10,0,158,2,10,0,160,2,10,0,162,2,10,0,164,2,10,0,166,2,10,0,168,2,10,0,170,2,10,0,172,2,10,0,174,2,10,0,176,2,10,0,178,2,10,0,180,2,10,0,182,2,10,0,184,2,10,0,186,2,10,0,188,2,10,0,190,2,10,0,192,2,10,0,194,2,10,0,196,2,10,0,198,2,10,0,200,2,10,0,202,2,10,0,204,2,10,0,206,2,10,0,208,2,10,0,210,2,10,0,212,2,10,0,214,2,10,0,216,2,10,0,218,2,10,0,220,2,10,0,222,2,10,0,224,2,10,0,226,2,10,0,228,2,10,0,230,2,10,0,232,2,10,0,234,2,10,0,236,2,10,0,238,2,10,0,240,2,10,0,242,2,10,0,244,2,10,0,246,2,10,0,248,2,10,0,250,2,10,0,252,2,10,0,254,2,10,0,0,3,10,0,2,3,10,0,4,3,10,0,6,3,10,0,8,3,10,0,10,3,10,0,12,3,10,0,14,3,10,0,16,3,10,0,18,3,10,0,20,3,10,0,22,3,10,0,24,3,10,0,26,3,10,0,28,3,10,0,30,3,10,0,32,3,10,0,34,3,10,0,36,3,10,0,38,3,10,0,40,3,10,0,42,3,10,0,44,3,10,0,46,3,10,0,48,3,10,0,50,3,10,0,52,3,10,0,54,3,10,0,56,3,10,0,58,3,10,0,60,3,10,0,62,3,10,0,64,3,10,0,66,3,10,0,68,3,10,0,70,3,10,0,72,3,10,0,74,3,10,0,76,3,10,0,78,3,10,0,80,3,10,0,82,3,10,0,84,3,10,0,86,3,10,0,88,3,10,0,90,3,10,0,92,3,10,0,94,3,10,0,96,3,10,0,98,3,10,0,100,3,10,0,102,3,10,0,104,3,10,0,106,3,10,0,108,3,10,0,110,3,10,0,112,3,10,0,114,3,10,0,116,3,10,0,118,3,10,0,120,3,10,0,122,3,10,0,124,3,10,0,126,3,10,0,128,3,10,0,130,3,10,0,132,3,10,0,134,3,10,0,136,3,10,0,138,3,10,0,140,3,10,0,142,3,10,0,144,3,10,0,146,3,10,0,148,3,10,0,150,3,10,0,152,3,10,0,154,3,10,0,156,3,10,0,158,3,10,0,160,3,10,0,162,3,10,0,164,3,10,0,166,3,10,0,168,3,10,0,170,3,10,0,172,3,10,0,174,3,10,0,176,3,10,0,178,3,10,0,180,3,10,0,182,3,10,0,184,3,10,0,186,3,10,0,188,3,10,0,190,3,10,0,192,3,10,0,194,3,10,0,196,3,10,0,198,3,10,0,200,3,10,0,202,3,10,0,204,3,10,0,206,3,10,0,208,3,10,0,210,3,10,0,212,3,10,0,214,3,10,0,216,3,10,0,218,3,10,0,220,3,10,0,222,3,10,0,224,3,10,0,226,3,10,0,228,3,10,0,230,3,10,0,232,3,10,0,234,3,10,0,236,3,10,0,238,3,10,0,240,3,10,0,242,3,10,0,244,3,10,0,246,3,10,0,248,3,10,0,250,3,10,0,252,3,10,0,254,3,10,0,0,4,10,0,2,4,10,0,4,4,10,0,6,4,10,0,8,4,10,0,10,4,10,0,12,4,10,0,14,4,10,0,16,4,10,0,18,4,10,0,20,4,10,0,22,4,10,0,24,4,10,0,26,4,10,0,28,4,10,0,30,4,10,0,32,4,10,0,34,4,10,0,36,4,10,0,38,4,10,0,40,4,10,0,42,4,10,0,44,4,10,0,46,4,10,0,48,4,10,0,50,4,10,0,52,4,10,0,54,4,10,0,56,4,10,0,58,4,10,0,60,4,10,0,62,4,10,0,64,4,10,0,66,4,10,0,68,4,10,0,70,4,10,0,72,4,10,0,74,4,10,0,76,4,10,0,78,4,10,0,80,4,10,0,82,4,10,0,84,4,10,0,86,4,10,0,88,4,10,0,90,4,10,0,92,4,10,0,94,4,10,0,96,4,10,0,98,4,10,0,100,4,10,0,102,4,10,0,104,4,10,0,106,4,10,0,108,4,10,0,110,4,10,0,112,4,10,0,114,4,10,0,116,4,10,0,118,4,10,0,120,4,10,0,122,4,10,0,124,4,10,0,126,4,10,0,128,4,10,0,130,4,10,0,132,4,10,0,134,4,10,0,136,4,10,0,138,4,10,0,140,4,10,0,142,4,10,0,144,4,10,0,146,4,10,0,148,4,10,0,150,4,10,0,152,4,10,0,154,4,10,0,156,4,10,0,158,4,10,0,160,4,10,0,162,4,10,0,164,4,10,0,166,4,10,0,168,4,10,0,170,4,10,0,172,4,10,0,174,4,10,0,176,4,10,0,178,4,10,0,180,4,10,0,182,4,10,0,184,4,10,0,186,4,10,0,188,4,10,0,190,4,10,0,192,4,10,0,194,4,10,0,196,4,10,0,198,4,10,0,200,4,10,0,202,4,10,0,204,4,10,0,206,4,10,0,208,4,10,0,210,4,10,0,212,4,10,0,214,4,10,0,216,4,10,0,218,4,10,0,220,4,10,0,222,4,10,0,224,4,10,0,226,4,10,0,228,4,10,0,230,4,10,0,232,4,10,0,234,4,10,0,236,4,10,0,238,4,10,0,240,4,10,0,242,4,10,0,244,4,10,0,246,4,10,0,248,4,10,0,250,4,10,0,252,4,10,0,254,4,10,0,0,5,10,0,2,5,10,0,4,5,10,0,6,5,10,0,8,5,10,0,10,5,10,0,12,5,10,0,14,5,10,0,16,5,10,0,18,5,10,0,20,5,10,0,22,5,10,0,24,5,10,0,26,5,10,0,28,5,10,0,30,5,10,0,32,5,10,0,34,5,10,0,36,5,10,0,38,5,10,0,40,5,10,0,42,5,10,0,44,5,10,0,46,5,10,0,48,5,10,0,50,5,10,0,52,5,10,0,54,5,10,0,56,5,10,0,58,5,10,0,60,5,10,0,62,5,10,0,64,5,10,0,66,5,10,0,68,5,10,0,70,5,10,0,72,5,10,0,74,5,10,0,76,5,10,0,78,5,10,0,80,5,10,0,82,5,10,0,84,5,10,0,86,5,10,0,88,5,10,0,90,5,10,0,92,5,10,0,94,5,10,0,96,5,10,0,98,5,10,0,100,5,10,0,102,5,10,0,104,5,10,0,106,5,10,0,108,5,10,0,110,5,10,0,112,5,10,0,114,5,10,0,116,5,10,0,118,5,10,0,120,5,10,0,122,5,10,0,124,5,10,0,126,5,10,0,128,5,10,0,130,5,10,0,132,5,10,0,134,5,10,0,136,5,10,0,138,5,10,0,140,5,10,0,142,5,10,0,144,5,10,0,146,5,10,0,148,5,10,0,150,5,10,0,152,5,10,0,154,5,10,0,156,5,10,0,158,5,10,0,160,5,10,0,162,5,10,0,164,5,10,0,166,5,10,0,168,5,10,0,170,5,10,0,172,5,10,0,174,5,10,0,176,5,10,0,178,5,10,0,180,5,10,0,182,5,10,0,184,5,10,0,186,5,10,0,188,5,10,0,190,5,10,0,192,5,10,0,194,5,10,0,196,5,10,0,198,5,10,0,200,5,10,0,202,5,10,0,204,5,10,0,206,5,10,0,208,5,10,0,210,5,10,0,212,5,10,0,214,5,10,0,216,5,10,0,218,5,10,0,220,5,10,0,222,5,10,0,224,5,10,0,226,5,10,0,228,5,10,0,230,5,10,0,232,5,10,0,234,5,10,0,236,5,10,0,238,5,10,0,240,5,10,0,242,5,10,0,244,5,10,0,246,5,10,0,248,5,10,0,250,5,10,0,252,5,10,0,254,5,10,0,0,6,10,0,2,6,10,0,4,6,10,0,6,6,10,0,8,6,10,0,10,6,10,0,12,6,10,0,14,6,10,0,16,6,10,0,18,6,10,0,20,6,10,0,22,6,10,0,24,6,10,0,26,6,10,0,28,6,10,0,30,6,10,0,32,6,10,0,34,6,10,0,36,6,10,0,38,6,10,0,40,6,10,0,42,6,10,0,44,6,10,0,46,6,10,0,48,6,10,0,50,6,10,0,52,6,10,0,54,6,10,0,56,6,10,0,58,6,10,0,60,6,10,0,62,6,10,0,64,6,10,0,66,6,10,0,68,6,10,0,70,6,10,0,72,6,10,0,74,6,10,0,76,6,10,0,78,6,10,0,80,6,10,0,82,6,10,0,84,6,10,0,86,6,10,0,88,6,10,0,90,6,10,0,92,6,10,0,94,6,10,0,96,6,10,0,98,6,10,0,100,6,10,0,102,6,10,0,104,6,10,0,106,6,10,0,108,6,10,0,110,6,10,0,112,6,10,0,114,6,10,0,116,6,10,0,118,6,10,0,120,6,10,0,122,6,10,0,124,6,10,0,126,6,10,0,128,6,10,0,130,6,10,0,132,6,10,0,134,6,10,0,136,6,10,0,138,6,10,0,140,6,10,0,142,6,10,0,144,6,10,0,146,6,10,0,148,6,10,0,150,6,10,0,152,6,10,0,154,6,10,0,156,6,10,0,158,6,10,0,160,6,10,0,162,6,10,0,164,6,10,0,166,6,10,0,168,6,10,0,170,6,10,0,172,6,10,0,174,6,10,0,176,6,10,0,178,6,10,0,180,6,10,0,182,6,10,0,184,6,10,0,186,6,10,0,188,6,10,0,190,6,10,0,192,6,10,0,194,6,10,0,196,6,10,0,198,6,10,0,200,6,10,0,202,6,10,0,204,6,10,0,206,6,10,0,208,6,10,0,210,6,10,0,212,6,10,0,214,6,10,0,216,6,10,0,218,6,10,0,220,6,10,0,222,6,10,0,224,6,10,0,226,6,10,0,228,6,10,0,230,6,10,0,232,6,10,0,234,6,10,0,236,6,10,0,238,6,10,0,240,6,10,0,242,6,10,0,244,6,10,0,246,6,10,0,248,6,10,0,250,6,10,0,252,6,10,0,254,6,10,0,0,7,10,0,2,7,10,0,4,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1588760);
/* memory initializer */ allocate([10,0,6,7,10,0,8,7,10,0,10,7,10,0,12,7,10,0,14,7,10,0,16,7,10,0,18,7,10,0,20,7,10,0,22,7,10,0,24,7,10,0,26,7,10,0,28,7,10,0,30,7,10,0,32,7,10,0,34,7,10,0,36,7,10,0,38,7,10,0,40,7,10,0,42,7,10,0,44,7,10,0,46,7,10,0,48,7,10,0,50,7,10,0,52,7,10,0,54,7,10,0,56,7,10,0,58,7,10,0,60,7,10,0,62,7,10,0,64,7,10,0,66,7,10,0,68,7,10,0,70,7,10,0,72,7,10,0,74,7,10,0,76,7,10,0,78,7,10,0,80,7,10,0,82,7,10,0,84,7,10,0,86,7,10,0,88,7,10,0,90,7,10,0,92,7,10,0,94,7,10,0,96,7,10,0,98,7,10,0,100,7,10,0,102,7,10,0,104,7,10,0,106,7,10,0,108,7,10,0,110,7,10,0,112,7,10,0,114,7,10,0,116,7,10,0,118,7,10,0,120,7,10,0,122,7,10,0,124,7,10,0,126,7,10,0,128,7,10,0,130,7,10,0,132,7,10,0,134,7,10,0,136,7,10,0,138,7,10,0,140,7,10,0,142,7,10,0,144,7,10,0,146,7,10,0,148,7,10,0,150,7,10,0,152,7,10,0,154,7,10,0,156,7,10,0,158,7,10,0,160,7,10,0,162,7,10,0,164,7,10,0,166,7,10,0,168,7,10,0,170,7,10,0,172,7,10,0,174,7,10,0,176,7,10,0,178,7,10,0,180,7,10,0,182,7,10,0,184,7,10,0,186,7,10,0,188,7,10,0,190,7,10,0,192,7,10,0,194,7,10,0,196,7,10,0,198,7,10,0,200,7,10,0,202,7,10,0,204,7,10,0,206,7,10,0,208,7,10,0,210,7,10,0,212,7,10,0,214,7,10,0,216,7,10,0,218,7,10,0,220,7,10,0,222,7,10,0,224,7,10,0,226,7,10,0,228,7,10,0,230,7,10,0,232,7,10,0,234,7,10,0,236,7,10,0,238,7,10,0,240,7,10,0,242,7,10,0,244,7,10,0,246,7,10,0,248,7,10,0,250,7,10,0,252,7,10,0,254,7,10,0,0,8,10,0,2,8,10,0,4,8,10,0,6,8,10,0,8,8,10,0,10,8,10,0,12,8,10,0,14,8,10,0,16,8,10,0,18,8,10,0,20,8,10,0,22,8,10,0,24,8,10,0,26,8,10,0,28,8,10,0,30,8,10,0,32,8,10,0,34,8,10,0,36,8,10,0,38,8,10,0,40,8,10,0,42,8,10,0,44,8,10,0,46,8,10,0,48,8,10,0,50,8,10,0,52,8,10,0,54,8,10,0,56,8,10,0,58,8,10,0,60,8,10,0,62,8,10,0,64,8,10,0,66,8,10,0,68,8,10,0,70,8,10,0,72,8,10,0,74,8,10,0,76,8,10,0,78,8,10,0,80,8,10,0,82,8,10,0,84,8,10,0,86,8,10,0,88,8,10,0,90,8,10,0,92,8,10,0,94,8,10,0,96,8,10,0,98,8,10,0,100,8,10,0,102,8,10,0,104,8,10,0,106,8,10,0,108,8,10,0,110,8,10,0,112,8,10,0,114,8,10,0,116,8,10,0,118,8,10,0,120,8,10,0,122,8,10,0,124,8,10,0,126,8,10,0,128,8,10,0,130,8,10,0,132,8,10,0,134,8,10,0,136,8,10,0,138,8,10,0,140,8,10,0,142,8,10,0,144,8,10,0,146,8,10,0,148,8,10,0,150,8,10,0,152,8,10,0,154,8,10,0,156,8,10,0,158,8,10,0,160,8,10,0,162,8,10,0,164,8,10,0,166,8,10,0,168,8,10,0,170,8,10,0,172,8,10,0,174,8,10,0,176,8,10,0,178,8,10,0,180,8,10,0,182,8,10,0,184,8,10,0,186,8,10,0,188,8,10,0,190,8,10,0,192,8,10,0,194,8,10,0,196,8,10,0,198,8,10,0,200,8,10,0,202,8,10,0,204,8,10,0,206,8,10,0,208,8,10,0,210,8,10,0,212,8,10,0,214,8,10,0,216,8,10,0,218,8,10,0,220,8,10,0,222,8,10,0,224,8,10,0,226,8,10,0,228,8,10,0,230,8,10,0,232,8,10,0,234,8,10,0,236,8,10,0,238,8,10,0,240,8,10,0,242,8,10,0,244,8,10,0,246,8,10,0,248,8,10,0,250,8,10,0,252,8,10,0,254,8,10,0,0,9,10,0,2,9,10,0,4,9,10,0,6,9,10,0,8,9,10,0,10,9,10,0,12,9,10,0,14,9,10,0,16,9,10,0,18,9,10,0,20,9,10,0,22,9,10,0,24,9,10,0,26,9,10,0,28,9,10,0,30,9,10,0,32,9,10,0,34,9,10,0,36,9,10,0,38,9,10,0,40,9,10,0,42,9,10,0,44,9,10,0,46,9,10,0,48,9,10,0,50,9,10,0,52,9,10,0,54,9,10,0,56,9,10,0,58,9,10,0,60,9,10,0,62,9,10,0,64,9,10,0,66,9,10,0,68,9,10,0,70,9,10,0,72,9,10,0,74,9,10,0,76,9,10,0,78,9,10,0,80,9,10,0,82,9,10,0,84,9,10,0,86,9,10,0,88,9,10,0,90,9,10,0,92,9,10,0,94,9,10,0,96,9,10,0,98,9,10,0,100,9,10,0,102,9,10,0,104,9,10,0,106,9,10,0,108,9,10,0,110,9,10,0,112,9,10,0,114,9,10,0,116,9,10,0,118,9,10,0,120,9,10,0,122,9,10,0,124,9,10,0,126,9,10,0,128,9,10,0,130,9,10,0,132,9,10,0,134,9,10,0,136,9,10,0,138,9,10,0,140,9,10,0,142,9,10,0,144,9,10,0,146,9,10,0,148,9,10,0,150,9,10,0,152,9,10,0,154,9,10,0,156,9,10,0,158,9,10,0,160,9,10,0,162,9,10,0,164,9,10,0,166,9,10,0,168,9,10,0,170,9,10,0,172,9,10,0,174,9,10,0,176,9,10,0,178,9,10,0,180,9,10,0,182,9,10,0,184,9,10,0,186,9,10,0,188,9,10,0,190,9,10,0,192,9,10,0,194,9,10,0,196,9,10,0,198,9,10,0,200,9,10,0,202,9,10,0,204,9,10,0,206,9,10,0,208,9,10,0,210,9,10,0,212,9,10,0,214,9,10,0,216,9,10,0,218,9,10,0,220,9,10,0,222,9,10,0,224,9,10,0,226,9,10,0,228,9,10,0,230,9,10,0,232,9,10,0,234,9,10,0,236,9,10,0,238,9,10,0,240,9,10,0,242,9,10,0,244,9,10,0,246,9,10,0,248,9,10,0,250,9,10,0,252,9,10,0,254,9,10,0,0,10,10,0,2,10,10,0,4,10,10,0,6,10,10,0,8,10,10,0,10,10,10,0,12,10,10,0,14,10,10,0,16,10,10,0,18,10,10,0,20,10,10,0,22,10,10,0,24,10,10,0,26,10,10,0,28,10,10,0,30,10,10,0,32,10,10,0,34,10,10,0,36,10,10,0,38,10,10,0,40,10,10,0,42,10,10,0,44,10,10,0,46,10,10,0,48,10,10,0,50,10,10,0,52,10,10,0,54,10,10,0,56,10,10,0,58,10,10,0,60,10,10,0,62,10,10,0,64,10,10,0,66,10,10,0,68,10,10,0,70,10,10,0,72,10,10,0,74,10,10,0,76,10,10,0,78,10,10,0,80,10,10,0,82,10,10,0,84,10,10,0,86,10,10,0,88,10,10,0,90,10,10,0,92,10,10,0,94,10,10,0,96,10,10,0,98,10,10,0,100,10,10,0,102,10,10,0,104,10,10,0,106,10,10,0,108,10,10,0,110,10,10,0,112,10,10,0,114,10,10,0,116,10,10,0,118,10,10,0,120,10,10,0,122,10,10,0,124,10,10,0,126,10,10,0,128,10,10,0,130,10,10,0,132,10,10,0,134,10,10,0,136,10,10,0,138,10,10,0,140,10,10,0,142,10,10,0,144,10,10,0,146,10,10,0,148,10,10,0,150,10,10,0,152,10,10,0,154,10,10,0,156,10,10,0,158,10,10,0,160,10,10,0,162,10,10,0,164,10,10,0,166,10,10,0,168,10,10,0,170,10,10,0,172,10,10,0,174,10,10,0,176,10,10,0,178,10,10,0,180,10,10,0,182,10,10,0,184,10,10,0,186,10,10,0,188,10,10,0,190,10,10,0,192,10,10,0,194,10,10,0,196,10,10,0,198,10,10,0,200,10,10,0,202,10,10,0,204,10,10,0,206,10,10,0,208,10,10,0,210,10,10,0,212,10,10,0,214,10,10,0,216,10,10,0,218,10,10,0,220,10,10,0,222,10,10,0,224,10,10,0,226,10,10,0,228,10,10,0,230,10,10,0,232,10,10,0,234,10,10,0,236,10,10,0,238,10,10,0,240,10,10,0,242,10,10,0,244,10,10,0,246,10,10,0,248,10,10,0,250,10,10,0,252,10,10,0,254,10,10,0,0,11,10,0,2,11,10,0,4,11,10,0,6,11,10,0,8,11,10,0,10,11,10,0,12,11,10,0,14,11,10,0,16,11,10,0,18,11,10,0,20,11,10,0,22,11,10,0,24,11,10,0,26,11,10,0,28,11,10,0,30,11,10,0,32,11,10,0,34,11,10,0,36,11,10,0,38,11,10,0,40,11,10,0,42,11,10,0,44,11,10,0,46,11,10,0,48,11,10,0,50,11,10,0,52,11,10,0,54,11,10,0,56,11,10,0,58,11,10,0,60,11,10,0,62,11,10,0,64,11,10,0,66,11,10,0,68,11,10,0,70,11,10,0,72,11,10,0,74,11,10,0,76,11,10,0,78,11,10,0,80,11,10,0,82,11,10,0,84,11,10,0,86,11,10,0,88,11,10,0,90,11,10,0,92,11,10,0,94,11,10,0,96,11,10,0,98,11,10,0,100,11,10,0,102,11,10,0,104,11,10,0,106,11,10,0,108,11,10,0,110,11,10,0,112,11,10,0,114,11,10,0,116,11,10,0,118,11,10,0,120,11,10,0,122,11,10,0,124,11,10,0,126,11,10,0,128,11,10,0,130,11,10,0,132,11,10,0,134,11,10,0,136,11,10,0,138,11,10,0,140,11,10,0,142,11,10,0,144,11,10,0,146,11,10,0,148,11,10,0,150,11,10,0,152,11,10,0,154,11,10,0,156,11,10,0,158,11,10,0,160,11,10,0,162,11,10,0,164,11,10,0,166,11,10,0,168,11,10,0,170,11,10,0,172,11,10,0,174,11,10,0,176,11,10,0,178,11,10,0,180,11,10,0,182,11,10,0,184,11,10,0,186,11,10,0,188,11,10,0,190,11,10,0,192,11,10,0,194,11,10,0,196,11,10,0,198,11,10,0,200,11,10,0,202,11,10,0,204,11,10,0,206,11,10,0,208,11,10,0,210,11,10,0,212,11,10,0,214,11,10,0,216,11,10,0,218,11,10,0,220,11,10,0,222,11,10,0,224,11,10,0,226,11,10,0,228,11,10,0,230,11,10,0,232,11,10,0,234,11,10,0,236,11,10,0,238,11,10,0,240,11,10,0,242,11,10,0,244,11,10,0,246,11,10,0,248,11,10,0,250,11,10,0,252,11,10,0,254,11,10,0,0,12,10,0,2,12,10,0,4,12,10,0,6,12,10,0,8,12,10,0,10,12,10,0,12,12,10,0,14,12,10,0,16,12,10,0,18,12,10,0,20,12,10,0,22,12,10,0,24,12,10,0,26,12,10,0,28,12,10,0,30,12,10,0,32,12,10,0,34,12,10,0,36,12,10,0,38,12,10,0,40,12,10,0,42,12,10,0,44,12,10,0,46,12,10,0,48,12,10,0,50,12,10,0,52,12,10,0,54,12,10,0,56,12,10,0,58,12,10,0,60,12,10,0,62,12,10,0,64,12,10,0,66,12,10,0,68,12,10,0,70,12,10,0,72,12,10,0,74,12,10,0,76,12,10,0,78,12,10,0,80,12,10,0,82,12,10,0,84,12,10,0,86,12,10,0,88,12,10,0,90,12,10,0,92,12,10,0,94,12,10,0,96,12,10,0,98,12,10,0,100,12,10,0,102,12,10,0,104,12,10,0,106,12,10,0,108,12,10,0,110,12,10,0,112,12,10,0,114,12,10,0,116,12,10,0,118,12,10,0,120,12,10,0,122,12,10,0,124,12,10,0,126,12,10,0,128,12,10,0,130,12,10,0,132,12,10,0,134,12,10,0,136,12,10,0,138,12,10,0,140,12,10,0,142,12,10,0,144,12,10,0,146,12,10,0,148,12,10,0,150,12,10,0,152,12,10,0,154,12,10,0,156,12,10,0,158,12,10,0,160,12,10,0,162,12,10,0,164,12,10,0,166,12,10,0,168,12,10,0,170,12,10,0,172,12,10,0,174,12,10,0,176,12,10,0,178,12,10,0,180,12,10,0,182,12,10,0,184,12,10,0,186,12,10,0,188,12,10,0,190,12,10,0,192,12,10,0,194,12,10,0,196,12,10,0,198,12,10,0,200,12,10,0,202,12,10,0,204,12,10,0,206,12,10,0,208,12,10,0,210,12,10,0,212,12,10,0,214,12,10,0,216,12,10,0,218,12,10,0,220,12,10,0,222,12,10,0,224,12,10,0,226,12,10,0,228,12,10,0,230,12,10,0,232,12,10,0,234,12,10,0,236,12,10,0,238,12,10,0,240,12,10,0,242,12,10,0,244,12,10,0,246,12,10,0,248,12,10,0,250,12,10,0,252,12,10,0,254,12,10,0,0,13,10,0,2,13,10,0,4,13,10,0,6,13,10,0,8,13,10,0,10,13,10,0,12,13,10,0,14,13,10,0,16,13,10,0,18,13,10,0,20,13,10,0,22,13,10,0,24,13,10,0,26,13,10,0,28,13,10,0,30,13,10,0,32,13,10,0,34,13,10,0,36,13,10,0,38,13,10,0,40,13,10,0,42,13,10,0,44,13,10,0,46,13,10,0,48,13,10,0,50,13,10,0,52,13,10,0,54,13,10,0,56,13,10,0,58,13,10,0,60,13,10,0,62,13,10,0,64,13,10,0,66,13,10,0,68,13,10,0,70,13,10,0,72,13,10,0,74,13,10,0,76,13,10,0,78,13,10,0,80,13,10,0,82,13,10,0,84,13,10,0,86,13,10,0,88,13,10,0,90,13,10,0,92,13,10,0,94,13,10,0,96,13,10,0,98,13,10,0,100,13,10,0,102,13,10,0,104,13,10,0,106,13,10,0,108,13,10,0,110,13,10,0,112,13,10,0,114,13,10,0,116,13,10,0,118,13,10,0,120,13,10,0,122,13,10,0,124,13,10,0,126,13,10,0,128,13,10,0,130,13,10,0,132,13,10,0,134,13,10,0,136,13,10,0,138,13,10,0,140,13,10,0,142,13,10,0,144,13,10,0,146,13,10,0,148,13,10,0,150,13,10,0,152,13,10,0,154,13,10,0,156,13,10,0,158,13,10,0,160,13,10,0,162,13,10,0,164,13,10,0,166,13,10,0,168,13,10,0,170,13,10,0,172,13,10,0,174,13,10,0,176,13,10,0,178,13,10,0,180,13,10,0,182,13,10,0,184,13,10,0,186,13,10,0,188,13,10,0,190,13,10,0,192,13,10,0,194,13,10,0,196,13,10,0,198,13,10,0,200,13,10,0,202,13,10,0,204,13,10,0,206,13,10,0,208,13,10,0,210,13,10,0,212,13,10,0,214,13,10,0,216,13,10,0,218,13,10,0,220,13,10,0,222,13,10,0,224,13,10,0,226,13,10,0,228,13,10,0,230,13,10,0,232,13,10,0,234,13,10,0,236,13,10,0,238,13,10,0,240,13,10,0,242,13,10,0,244,13,10,0,246,13,10,0,248,13,10,0,250,13,10,0,252,13,10,0,254,13,10,0,0,14,10,0,2,14,10,0,4,14,10,0,6,14,10,0,8,14,10,0,10,14,10,0,12,14,10,0,14,14,10,0,16,14,10,0,18,14,10,0,20,14,10,0,22,14,10,0,24,14,10,0,26,14,10,0,28,14,10,0,30,14,10,0,32,14,10,0,34,14,10,0,36,14,10,0,38,14,10,0,40,14,10,0,42,14,10,0,44,14,10,0,46,14,10,0,48,14,10,0,50,14,10,0,52,14,10,0,54,14,10,0,56,14,10,0,58,14,10,0,60,14,10,0,62,14,10,0,64,14,10,0,66,14,10,0,68,14,10,0,70,14,10,0,72,14,10,0,74,14,10,0,76,14,10,0,78,14,10,0,80,14,10,0,82,14,10,0,84,14,10,0,86,14,10,0,88,14,10,0,90,14,10,0,92,14,10,0,94,14,10,0,96,14,10,0,98,14,10,0,100,14,10,0,102,14,10,0,104,14,10,0,106,14,10,0,108,14,10,0,110,14,10,0,112,14,10,0,114,14,10,0,116,14,10,0,118,14,10,0,120,14,10,0,122,14,10,0,124,14,10,0,126,14,10,0,128,14,10,0,130,14,10,0,132,14,10,0,134,14,10,0,136,14,10,0,138,14,10,0,140,14,10,0,142,14,10,0,144,14,10,0,146,14,10,0,148,14,10,0,150,14,10,0,152,14,10,0,154,14,10,0,156,14,10,0,158,14,10,0,160,14,10,0,162,14,10,0,164,14,10,0,166,14,10,0,168,14,10,0,170,14,10,0,172,14,10,0,174,14,10,0,176,14,10,0,178,14,10,0,180,14,10,0,182,14,10,0,184,14,10,0,186,14,10,0,188,14,10,0,190,14,10,0,192,14,10,0,194,14,10,0,196,14,10,0,198,14,10,0,200,14,10,0,202,14,10,0,204,14,10,0,206,14,10,0,208,14,10,0,210,14,10,0,212,14,10,0,214,14,10,0,216,14,10,0,218,14,10,0,220,14,10,0,222,14,10,0,224,14,10,0,226,14,10,0,228,14,10,0,230,14,10,0,232,14,10,0,234,14,10,0,236,14,10,0,238,14,10,0,240,14,10,0,242,14,10,0,244,14,10,0,246,14,10,0,248,14,10,0,250,14,10,0,252,14,10,0,254,14,10,0,0,15,10,0,2,15,10,0,4,15,10,0,6,15,10,0,8,15,10,0,10,15,10,0,12,15,10,0,14,15,10,0,16,15,10,0,18,15,10,0,20,15,10,0,22,15,10,0,24,15,10,0,26,15,10,0,28,15,10,0,30,15,10,0,32,15,10,0,34,15,10,0,36,15,10,0,38,15,10,0,40,15,10,0,42,15,10,0,44,15,10,0,46,15,10,0,48,15,10,0,50,15,10,0,52,15,10,0,54,15,10,0,56,15,10,0,58,15,10,0,60,15,10,0,62,15,10,0,64,15,10,0,66,15,10,0,68,15,10,0,70,15,10,0,72,15,10,0,74,15,10,0,76,15,10,0,78,15,10,0,80,15,10,0,82,15,10,0,84,15,10,0,86,15,10,0,88,15,10,0,90,15,10,0,92,15,10,0,94,15,10,0,96,15,10,0,98,15,10,0,100,15,10,0,102,15,10,0,104,15,10,0,106,15,10,0,108,15,10,0,110,15,10,0,112,15,10,0,114,15,10,0,116,15,10,0,118,15,10,0,120,15,93,32,85,32,75,32,67,32,61,32,53,32,34,32,26,32,20,32,12,32,2,32,250,31,244,31,236,31,214,31,206,31,200,31,192,31,182,31,174,31,168,31,160,31,141,31,133,31,127,31,119,31,109,31,101,31,95,31,87,31,61,31,53,31,47,31,39,31,29,31,21,31,15,31,7,31,244,30,236,30,230,30,222,30,212,30,204,30,198,30,190,30,168,30,160,30,154,30,146,30,136,30,128,30,122,30,114,30,95,30,87,30,81,30,73,30,63,30,55,30,49,30,41,30,243,30,235,30,229,30,221,30,211,30,203,30,197,30,189,30,170,30,162,30,156,30,148,30,138,30,130,30,124,30,116,30,94,30,86,30,80,30,72,30,62,30,54,30,48,30,40,30,21,30,13,30,7,30,255,29,245,29,237,29,231,29,223,29,197,29,189,29,183,29,175,29,165,29,157,29,151,29,143,29,124,29,116,29,110,29,102,29,92,29,84,29,78,29,70,29,48,29,40,29,34,29,26,29,16,29,8,29,2,29,250,28,231,28,223,28,217,28,209,28,199,28,191,28,185,28,177,28,55,29,47,29,41,29,33,29,23,29,15,29,9,29,1,29,238,28,230,28,224,28,216,28,206,28,198,28,192,28,184,28,162,28,154,28,148,28,140,28,130,28,122,28,116,28,108,28,89,28,81,28,75,28,67,28,57,28,49,28,43,28,35,28,9,28,1,28,251,27,243,27,233,27,225,27,219,27,211,27,192,27,184,27,178,27,170,27,160,27,152,27,146,27,138,27,116,27,108,27,102,27,94,27,84,27,76,27,70,27,62,27,43,27,35,27,29,27,21,27,11,27,3,27,253,26,245,26,208,29,200,29,194,29,186,29,176,29,168,29,162,29,154,29,135,29,127,29,121,29,113,29,103,29,95,29,89,29,81,29,59,29,51,29,45,29,37,29,27,29,19,29,13,29,5,29,242,28,234,28,228,28,220,28,210,28,202,28,196,28,188,28,162,28,154,28,148,28,140,28,130,28,122,28,116,28,108,28,89,28,81,28,75,28,67,28,57,28,49,28,43,28,35,28,13,28,5,28,255,27,247,27,237,27,229,27,223,27,215,27,196,27,188,27,182,27,174,27,164,27,156,27,150,27,142,27,20,28,12,28,6,28,254,27,244,27,236,27,230,27,222,27,203,27,195,27,189,27,181,27,171,27,163,27,157,27,149,27,127,27,119,27,113,27,105,27,95,27,87,27,81,27,73,27,54,27,46,27,40,27,32,27,22,27,14,27,8,27,0,27,230,26,222,26,216,26,208,26,198,26,190,26,184,26,176,26,157,26,149,26,143,26,135,26,125,26,117,26,111,26,103,26,81,26,73,26,67,26,59,26,49,26,41,26,35,26,27,26,8,26,0,26,250,25,242,25,232,25,224,25,218,25,210,25,156,26,148,26,142,26,134,26,124,26,116,26,110,26,102,26,83,26,75,26,69,26,61,26,51,26,43,26,37,26,29,26,7,26,255,25,249,25,241,25,231,25,223,25,217,25,209,25,190,25,182,25,176,25,168,25,158,25,150,25,144,25,136,25,110,25,102,25,96,25,88,25,78,25,70,25,64,25,56,25,37,25,29,25,23,25,15,25,5,25,253,24,247,24,239,24,217,24,209,24,203,24,195,24,185,24,177,24,171,24,163,24,144,24,136,24,130,24,122,24,112,24,104,24,98,24,90,24,224,24,216,24,210,24,202,24,192,24,184,24,178,24,170,24,151,24,143,24,137,24,129,24,119,24,111,24,105,24,97,24,75,24,67,24,61,24,53,24,43,24,35,24,29,24,21,24,2,24,250,23,244,23,236,23,226,23,218,23,212,23,204,23,178,23,170,23,164,23,156,23,146,23,138,23,132,23,124,23,105,23,97,23,91,23,83,23,73,23,65,23,59,23,51,23,29,23,21,23,15,23,7,23,253,22,245,22,239,22,231,22,212,22,204,22,198,22,190,22,180,22,172,22,166,22,158,22,41,26,33,26,27,26,19,26,9,26,1,26,251,25,243,25,224,25,216,25,210,25,202,25,192,25,184,25,178,25,170,25,148,25,140,25,134,25,126,25,116,25,108,25,102,25,94,25,75,25,67,25,61,25,53,25,43,25,35,25,29,25,21,25,251,24,243,24,237,24,229,24,219,24,211,24,205,24,197,24,178,24,170,24,164,24,156,24,146,24,138,24,132,24,124,24,102,24,94,24,88,24,80,24,70,24,62,24,56,24,48,24,29,24,21,24,15,24,7,24,253,23,245,23,239,23,231,23,109,24,101,24,95,24,87,24,77,24,69,24,63,24,55,24,36,24,28,24,22,24,14,24,4,24,252,23,246,23,238,23,216,23,208,23,202,23,194,23,184,23,176,23,170,23,162,23,143,23,135,23,129,23,121,23,111,23,103,23,97,23,89,23,63,23,55,23,49,23,41,23,31,23,23,23,17,23,9,23,246,22,238,22,232,22,224,22,214,22,206,22,200,22,192,22,170,22,162,22,156,22,148,22,138,22,130,22,124,22,116,22,97,22,89,22,83,22,75,22,65,22,57,22,51,22,43,22,245,22,237,22,231,22,223,22,213,22,205,22,199,22,191,22,172,22,164,22,158,22,150,22,140,22,132,22,126,22,118,22,96,22,88,22,82,22,74,22,64,22,56,22,50,22,42,22,23,22,15,22,9,22,1,22,247,21,239,21,233,21,225,21,199,21,191,21,185,21,177,21,167,21,159,21,153,21,145,21,126,21,118,21,112,21,104,21,94,21,86,21,80,21,72,21,50,21,42,21,36,21,28,21,18,21,10,21,4,21,252,20,233,20,225,20,219,20,211,20,201,20,193,20,187,20,179,20,57,21,49,21,43,21,35,21,25,21,17,21,11,21,3,21,240,20,232,20,226,20,218,20,208,20,200,20,194,20,186,20,164,20,156,20,150,20,142,20,132,20,124,20,118,20,110,20,91,20,83,20,77,20,69,20,59,20,51,20,45,20,37,20,11,20,3,20,253,19,245,19,235,19,227,19,221,19,213,19,194,19,186,19,180,19,172,19,162,19,154,19,148,19,140,19,118,19,110,19,104,19,96,19,86,19,78,19,72,19,64,19,45,19,37,19,31,19,23,19,13,19,5,19,255,18,247,18,210,21,202,21,196,21,188,21,178,21,170,21,164,21,156,21,137,21,129,21,123,21,115,21,105,21,97,21,91,21,83,21,61,21,53,21,47,21,39,21,29,21,21,21,15,21,7,21,244,20,236,20,230,20,222,20,212,20,204,20,198,20,190,20,164,20,156,20,150,20,142,20,132,20,124,20,118,20,110,20,91,20,83,20,77,20,69,20,59,20,51,20,45,20,37,20,15,20,7,20,1,20,249,19,239,19,231,19,225,19,217,19,198,19,190,19,184,19,176,19,166,19,158,19,152,19,144,19,22,20,14,20,8,20,0,20,246,19,238,19,232,19,224,19,205,19,197,19,191,19,183,19,173,19,165,19,159,19,151,19,129,19,121,19,115,19,107,19,97,19,89,19,83,19,75,19,56,19,48,19,42,19,34,19,24,19,16,19,10,19,2,19,232,18,224,18,218,18,210,18,200,18,192,18,186,18,178,18,159,18,151,18,145,18,137,18,127,18,119,18,113,18,105,18,83,18,75,18,69,18,61,18,51,18,43,18,37,18,29,18,10,18,2,18,252,17,244,17,234,17,226,17,220,17,212,17,158,18,150,18,144,18,136,18,126,18,118,18,112,18,104,18,85,18,77,18,71,18,63,18,53,18,45,18,39,18,31,18,9,18,1,18,251,17,243,17,233,17,225,17,219,17,211,17,192,17,184,17,178,17,170,17,160,17,152,17,146,17,138,17,112,17,104,17,98,17,90,17,80,17,72,17,66,17,58,17,39,17,31,17,25,17,17,17,7,17,255,16,249,16,241,16,219,16,211,16,205,16,197,16,187,16,179,16,173,16,165,16,146,16,138,16,132,16,124,16,114,16,106,16,100,16,92,16,226,16,218,16,212,16,204,16,194,16,186,16,180,16,172,16,153,16,145,16,139,16,131,16,121,16,113,16,107,16,99,16,77,16,69,16,63,16,55,16,45,16,37,16,31,16,23,16,4,16,252,15,246,15,238,15,228,15,220,15,214,15,206,15,180,15,172,15,166,15,158,15,148,15,140,15,134,15,126,15,107,15,99,15,93,15,85,15,75,15,67,15,61,15,53,15,31,15,23,15,17,15,9,15,255,14,247,14,241,14,233,14,214,14,206,14,200,14,192,14,182,14,174,14,168,14,160,14,41,26,33,26,27,26,19,26,9,26,1,26,251,25,243,25,224,25,216,25,210,25,202,25,192,25,184,25,178,25,170,25,148,25,140,25,134,25,126,25,116,25,108,25,102,25,94,25,75,25,67,25,61,25,53,25,43,25,35,25,29,25,21,25,251,24,243,24,237,24,229,24,219,24,211,24,205,24,197,24,178,24,170,24,164,24,156,24,146,24,138,24,132,24,124,24,102,24,94,24,88,24,80,24,70,24,62,24,56,24,48,24,29,24,21,24,15,24,7,24,253,23,245,23,239,23,231,23,109,24,101,24,95,24,87,24,77,24,69,24,63,24,55,24,36,24,28,24,22,24,14,24,4,24,252,23,246,23,238,23,216,23,208,23,202,23,194,23,184,23,176,23,170,23,162,23,143,23,135,23,129,23,121,23,111,23,103,23,97,23,89,23,63,23,55,23,49,23,41,23,31,23,23,23,17,23,9,23,246,22,238,22,232,22,224,22,214,22,206,22,200,22,192,22,170,22,162,22,156,22,148,22,138,22,130,22,124,22,116,22,97,22,89,22,83,22,75,22,65,22,57,22,51,22,43,22,245,22,237,22,231,22,223,22,213,22,205,22,199,22,191,22,172,22,164,22,158,22,150,22,140,22,132,22,126,22,118,22,96,22,88,22,82,22,74,22,64,22,56,22,50,22,42,22,23,22,15,22,9,22,1,22,247,21,239,21,233,21,225,21,199,21,191,21,185,21,177,21,167,21,159,21,153,21,145,21,126,21,118,21,112,21,104,21,94,21,86,21,80,21,72,21,50,21,42,21,36,21,28,21,18,21,10,21,4,21,252,20,233,20,225,20,219,20,211,20,201,20,193,20,187,20,179,20,57,21,49,21,43,21,35,21,25,21,17,21,11,21,3,21,240,20,232,20,226,20,218,20,208,20,200,20,194,20,186,20,164,20,156,20,150,20,142,20,132,20,124,20,118,20,110,20,91,20,83,20,77,20,69,20,59,20,51,20,45,20,37,20,11,20,3,20,253,19,245,19,235,19,227,19,221,19,213,19,194,19,186,19,180,19,172,19,162,19,154,19,148,19,140,19,118,19,110,19,104,19,96,19,86,19,78,19,72,19,64,19,45,19,37,19,31,19,23,19,13,19,5,19,255,18,247,18,210,21,202,21,196,21,188,21,178,21,170,21,164,21,156,21,137,21,129,21,123,21,115,21,105,21,97,21,91,21,83,21,61,21,53,21,47,21,39,21,29,21,21,21,15,21,7,21,244,20,236,20,230,20,222,20,212,20,204,20,198,20,190,20,164,20,156,20,150,20,142,20,132,20,124,20,118,20,110,20,91,20,83,20,77,20,69,20,59,20,51,20,45,20,37,20,15,20,7,20,1,20,249,19,239,19,231,19,225,19,217,19,198,19,190,19,184,19,176,19,166,19,158,19,152,19,144,19,22,20,14,20,8,20,0,20,246,19,238,19,232,19,224,19,205,19,197,19,191,19,183,19,173,19,165,19,159,19,151,19,129,19,121,19,115,19,107,19,97,19,89,19,83,19,75,19,56,19,48,19,42,19,34,19,24,19,16,19,10,19,2,19,232,18,224,18,218,18,210,18,200,18,192,18,186,18,178,18,159,18,151,18,145,18,137,18,127,18,119,18,113,18,105,18,83,18,75,18,69,18,61,18,51,18,43,18,37,18,29,18,10,18,2,18,252,17,244,17,234,17,226,17,220,17,212,17,158,18,150,18,144,18,136,18,126,18,118,18,112,18,104,18,85,18,77,18,71,18,63,18,53,18,45,18,39,18,31,18,9,18,1,18,251,17,243,17,233,17,225,17,219,17,211,17,192,17,184,17,178,17,170,17,160,17,152,17,146,17,138,17,112,17,104,17,98,17,90,17,80,17,72,17,66,17,58,17,39,17,31,17,25,17,17,17,7,17,255,16,249,16,241,16,219,16,211,16,205,16,197,16,187,16,179,16,173,16,165,16,146,16,138,16,132,16,124,16,114,16,106,16,100,16,92,16,226,16,218,16,212,16,204,16,194,16,186,16,180,16,172,16,153,16,145,16,139,16,131,16,121,16,113,16,107,16,99,16,77,16,69,16,63,16,55,16,45,16,37,16,31,16,23,16,4,16,252,15,246,15,238,15,228,15,220,15,214,15,206,15,180,15,172,15,166,15,158,15,148,15,140,15,134,15,126,15,107,15,99,15,93,15,85,15,75,15,67,15,61,15,53,15,31,15,23,15,17,15,9,15,255,14,247,14,241,14,233,14,214,14,206,14,200,14,192,14,182,14,174,14,168,14,160,14,43,18,35,18,29,18,21,18,11,18,3,18,253,17,245,17,226,17,218,17,212,17,204,17,194,17,186,17,180,17,172,17,150,17,142,17,136,17,128,17,118,17,110,17,104,17,96,17,77,17,69,17,63,17,55,17,45,17,37,17,31,17,23,17,253,16,245,16,239,16,231,16,221,16,213,16,207,16,199,16,180,16,172,16,166,16,158,16,148,16,140,16,134,16,126,16,104,16,96,16,90,16,82,16,72,16,64,16,58,16,50,16,31,16,23,16,17,16,9,16,255,15,247,15,241,15,233,15,111,16,103,16,97,16,89,16,79,16,71,16,65,16,57,16,38,16,30,16,24,16,16,16,6,16,254,15,248,15,240,15,218,15,210,15,204,15,196,15,186,15,178,15,172,15,164,15,145,15,137,15,131,15,123,15,113,15,105,15,99,15,91,15,65,15,57,15,51,15,43,15,33,15,25,15,19,15,11,15,248,14,240,14,234,14,226,14,216,14,208,14,202,14,194,14,172,14,164,14,158,14,150,14,140,14,132,14,126,14,118,14,99,14,91,14,85,14,77,14,67,14,59,14,53,14,45,14,247,14,239,14,233,14,225,14,215,14,207,14,201,14,193,14,174,14,166,14,160,14,152,14,142,14,134,14,128,14,120,14,98,14,90,14,84,14,76,14,66,14,58,14,52,14,44,14,25,14,17,14,11,14,3,14,249,13,241,13,235,13,227,13,201,13,193,13,187,13,179,13,169,13,161,13,155,13,147,13,128,13,120,13,114,13,106,13,96,13,88,13,82,13,74,13,52,13,44,13,38,13,30,13,20,13,12,13,6,13,254,12,235,12,227,12,221,12,213,12,203,12,195,12,189,12,181,12,59,13,51,13,45,13,37,13,27,13,19,13,13,13,5,13,242,12,234,12,228,12,220,12,210,12,202,12,196,12,188,12,166,12,158,12,152,12,144,12,134,12,126,12,120,12,112,12,93,12,85,12,79,12,71,12,61,12,53,12,47,12,39,12,13,12,5,12,255,11,247,11,237,11,229,11,223,11,215,11,196,11,188,11,182,11,174,11,164,11,156,11,150,11,142,11,120,11,112,11,106,11,98,11,88,11,80,11,74,11,66,11,47,11,39,11,33,11,25,11,15,11,7,11,1,11,249,10,212,13,204,13,198,13,190,13,180,13,172,13,166,13,158,13,139,13,131,13,125,13,117,13,107,13,99,13,93,13,85,13,63,13,55,13,49,13,41,13,31,13,23,13,17,13,9,13,246,12,238,12,232,12,224,12,214,12,206,12,200,12,192,12,166,12,158,12,152,12,144,12,134,12,126,12,120,12,112,12,93,12,85,12,79,12,71,12,61,12,53,12,47,12,39,12,17,12,9,12,3,12,251,11,241,11,233,11,227,11,219,11,200,11,192,11,186,11,178,11,168,11,160,11,154,11,146,11,24,12,16,12,10,12,2,12,248,11,240,11,234,11,226,11,207,11,199,11,193,11,185,11,175,11,167,11,161,11,153,11,131,11,123,11,117,11,109,11,99,11,91,11,85,11,77,11,58,11,50,11,44,11,36,11,26,11,18,11,12,11,4,11,234,10,226,10,220,10,212,10,202,10,194,10,188,10,180,10,161,10,153,10,147,10,139,10,129,10,121,10,115,10,107,10,85,10,77,10,71,10,63,10,53,10,45,10,39,10,31,10,12,10,4,10,254,9,246,9,236,9,228,9,222,9,214,9,160,10,152,10,146,10,138,10,128,10,120,10,114,10,106,10,87,10,79,10,73,10,65,10,55,10,47,10,41,10,33,10,11,10,3,10,253,9,245,9,235,9,227,9,221,9,213,9,194,9,186,9,180,9,172,9,162,9,154,9,148,9,140,9,114,9,106,9,100,9,92,9,82,9,74,9,68,9,60,9,41,9,33,9,27,9,19,9,9,9,1,9,251,8,243,8,221,8,213,8,207,8,199,8,189,8,181,8,175,8,167,8,148,8,140,8,134,8,126,8,116,8,108,8,102,8,94,8,228,8,220,8,214,8,206,8,196,8,188,8,182,8,174,8,155,8,147,8,141,8,133,8,123,8,115,8,109,8,101,8,79,8,71,8,65,8,57,8,47,8,39,8,33,8,25,8,6,8,254,7,248,7,240,7,230,7,222,7,216,7,208,7,182,7,174,7,168,7,160,7,150,7,142,7,136,7,128,7,109,7,101,7,95,7,87,7,77,7,69,7,63,7,55,7,33,7,25,7,19,7,11,7,1,7,249,6,243,6,235,6,216,6,208,6,202,6,194,6,184,6,176,6,170,6,162,6,105,7,91,7,68,7,54,7,27,7,13,7,246,6,232,6,187,6,173,6,150,6,136,6,109,6,95,6,72,6,58,6,38,6,24,6,1,6,243,5,216,5,202,5,179,5,165,5,120,5,106,5,83,5,69,5,42,5,28,5,5,5,247,4,72,6,29,6,255,5,212,5,166,5,123,5,93,5,50,5,32,5,245,4,215,4,172,4,126,4,83,4,53,4,10,4,11,5,194,4,147,4,74,4,247,3,174,3,127,3,54,3,185,3,82,3,217,2,114,2,106,2,175,1,1,1,1,1,1,1,1,1,0,0,255,0,255,0,255,0,255,0,173,1,104,2,112,2,215,2,80,3,183,3,52,3,125,3,172,3,245,3,72,4,145,4,192,4,9,5,8,4,51,4,81,4,124,4,170,4,213,4,243,4,30,5,48,5,91,5,121,5,164,5,210,5,253,5,27,6,70,6,245,4,3,5,26,5,40,5,67,5,81,5,104,5,118,5,163,5,177,5,200,5,214,5,241,5,255,5,22,6,36,6,56,6,70,6,93,6,107,6,134,6,148,6,171,6,185,6,230,6,244,6,11,7,25,7,52,7,66,7,89,7,103,7,160,6,168,6,174,6,182,6,192,6,200,6,206,6,214,6,233,6,241,6,247,6,255,6,9,7,17,7,23,7,31,7,53,7,61,7,67,7,75,7,85,7,93,7,99,7,107,7,126,7,134,7,140,7,148,7,158,7,166,7,172,7,180,7,206,7,214,7,220,7,228,7,238,7,246,7,252,7,4,8,23,8,31,8,37,8,45,8,55,8,63,8,69,8,77,8,99,8,107,8,113,8,121,8,131,8,139,8,145,8,153,8,172,8,180,8,186,8,194,8,204,8,212,8,218,8,226,8,92,8,100,8,106,8,114,8,124,8,132,8,138,8,146,8,165,8,173,8,179,8,187,8,197,8,205,8,211,8,219,8,241,8,249,8,255,8,7,9,17,9,25,9,31,9,39,9,58,9,66,9,72,9,80,9,90,9,98,9,104,9,112,9,138,9,146,9,152,9,160,9,170,9,178,9,184,9,192,9,211,9,219,9,225,9,233,9,243,9,251,9,1,10,9,10,31,10,39,10,45,10,53,10,63,10,71,10,77,10,85,10,104,10,112,10,118,10,126,10,136,10,144,10,150,10,158,10,212,9,220,9,226,9,234,9,244,9,252,9,2,10,10,10,29,10,37,10,43,10,51,10,61,10,69,10,75,10,83,10,105,10,113,10,119,10,127,10,137,10,145,10,151,10,159,10,178,10,186,10,192,10,200,10,210,10,218,10,224,10,232,10,2,11,10,11,16,11,24,11,34,11,42,11,48,11,56,11,75,11,83,11,89,11,97,11,107,11,115,11,121,11,129,11,151,11,159,11,165,11,173,11,183,11,191,11,197,11,205,11,224,11,232,11,238,11,246,11,0,12,8,12,14,12,22,12,144,11,152,11,158,11,166,11,176,11,184,11,190,11,198,11,217,11,225,11,231,11,239,11,249,11,1,12,7,12,15,12,37,12,45,12,51,12,59,12,69,12,77,12,83,12,91,12,110,12,118,12,124,12,132,12,142,12,150,12,156,12,164,12,190,12,198,12,204,12,212,12,222,12,230,12,236,12,244,12,7,13,15,13,21,13,29,13,39,13,47,13,53,13,61,13,83,13,91,13,97,13,105,13,115,13,123,13,129,13,137,13,156,13,164,13,170,13,178,13,188,13,196,13,202,13,210,13,247,10,255,10,5,11,13,11,23,11,31,11,37,11,45,11,64,11,72,11,78,11,86,11,96,11,104,11,110,11,118,11,140,11,148,11,154,11,162,11,172,11,180,11,186,11,194,11,213,11,221,11,227,11,235,11,245,11,253,11,3,12,11,12,37,12,45,12,51,12,59,12,69,12,77,12,83,12,91,12,110,12,118,12,124,12,132,12,142,12,150,12,156,12,164,12,186,12,194,12,200,12,208,12,218,12,226,12,232,12,240,12,3,13,11,13,17,13,25,13,35,13,43,13,49,13,57,13,179,12,187,12,193,12,201,12,211,12,219,12,225,12,233,12,252,12,4,13,10,13,18,13,28,13,36,13,42,13,50,13,72,13,80,13,86,13,94,13,104,13,112,13,118,13,126,13,145,13,153,13,159,13,167,13,177,13,185,13,191,13,199,13,225,13,233,13,239,13,247,13,1,14,9,14,15,14,23,14,42,14,50,14,56,14,64,14,74,14,82,14,88,14,96,14,118,14,126,14,132,14,140,14,150,14,158,14,164,14,172,14,191,14,199,14,205,14,213,14,223,14,231,14,237,14,245,14,43,14,51,14,57,14,65,14,75,14,83,14,89,14,97,14,116,14,124,14,130,14,138,14,148,14,156,14,162,14,170,14,192,14,200,14,206,14,214,14,224,14,232,14,238,14,246,14,9,15,17,15,23,15,31,15,41,15,49,15,55,15,63,15,89,15,97,15,103,15,111,15,121,15,129,15,135,15,143,15,162,15,170,15,176,15,184,15,194,15,202,15,208,15,216,15,238,15,246,15,252,15,4,16,14,16,22,16,28,16,36,16,55,16,63,16,69,16,77,16,87,16,95,16,101,16,109,16,231,15,239,15,245,15,253,15,7,16,15,16,21,16,29,16,48,16,56,16,62,16,70,16,80,16,88,16,94,16,102,16,124,16,132,16,138,16,146,16,156,16,164,16,170,16,178,16,197,16,205,16,211,16,219,16,229,16,237,16,243,16,251,16,21,17,29,17,35,17,43,17,53,17,61,17,67,17,75,17,94,17,102,17,108,17,116,17,126,17,134,17,140,17,148,17,170,17,178,17,184,17,192,17,202,17,210,17,216,17,224,17,243,17,251,17,1,18,9,18,19,18,27,18,33,18,41,18,158,14,166,14,172,14,180,14,190,14,198,14,204,14,212,14,231,14,239,14,245,14,253,14,7,15,15,15,21,15,29,15,51,15,59,15,65,15,73,15,83,15,91,15,97,15,105,15,124,15,132,15,138,15,146,15,156,15,164,15,170,15,178,15,204,15,212,15,218,15,226,15,236,15,244,15,250,15,2,16,21,16,29,16,35,16,43,16,53,16,61,16,67,16,75,16,97,16,105,16,111,16,119,16,129,16,137,16,143,16,151,16,170,16,178,16,184,16,192,16,202,16,210,16,216,16,224,16,90,16,98,16,104,16,112,16,122,16,130,16,136,16,144,16,163,16,171,16,177,16,185,16,195,16,203,16,209,16,217,16,239,16,247,16,253,16,5,17,15,17,23,17,29,17,37,17,56,17,64,17,70,17,78,17,88,17,96,17,102,17,110,17,136,17,144,17,150,17,158,17,168,17,176,17,182,17,190,17,209,17,217,17,223,17,231,17,241,17,249,17,255,17,7,18,29,18,37,18,43,18,51,18,61,18,69,18,75,18,83,18,102,18,110,18,116,18,124,18,134,18,142,18,148,18,156,18,210,17,218,17,224,17,232,17,242,17,250,17,0,18,8,18,27,18,35,18,41,18,49,18,59,18,67,18,73,18,81,18,103,18,111,18,117,18,125,18,135,18,143,18,149,18,157,18,176,18,184,18,190,18,198,18,208,18,216,18,222,18,230,18,0,19,8,19,14,19,22,19,32,19,40,19,46,19,54,19,73,19,81,19,87,19,95,19,105,19,113,19,119,19,127,19,149,19,157,19,163,19,171,19,181,19,189,19,195,19,203,19,222,19,230,19,236,19,244,19,254,19,6,20,12,20,20,20,142,19,150,19,156,19,164,19,174,19,182,19,188,19,196,19,215,19,223,19,229,19,237,19,247,19,255,19,5,20,13,20,35,20,43,20,49,20,57,20,67,20,75,20,81,20,89,20,108,20,116,20,122,20,130,20,140,20,148,20,154,20,162,20,188,20,196,20,202,20,210,20,220,20,228,20,234,20,242,20,5,21,13,21,19,21,27,21,37,21,45,21,51,21,59,21,81,21,89,21,95,21,103,21,113,21,121,21,127,21,135,21,154,21,162,21,168,21,176,21,186,21,194,21,200,21,208,21,245,18,253,18,3,19,11,19,21,19,29,19,35,19,43,19,62,19,70,19,76,19,84,19,94,19,102,19,108,19,116,19,138,19,146,19,152,19,160,19,170,19,178,19,184,19,192,19,211,19,219,19,225,19,233,19,243,19,251,19,1,20,9,20,35,20,43,20,49,20,57,20,67,20,75,20,81,20,89,20,108,20,116,20,122,20,130,20,140,20,148,20,154,20,162,20,184,20,192,20,198,20,206,20,216,20,224,20,230,20,238,20,1,21,9,21,15,21,23,21,33,21,41,21,47,21,55,21,177,20,185,20,191,20,199,20,209,20,217,20,223,20,231,20,250,20], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1599000);
/* memory initializer */ allocate([2,21,8,21,16,21,26,21,34,21,40,21,48,21,70,21,78,21,84,21,92,21,102,21,110,21,116,21,124,21,143,21,151,21,157,21,165,21,175,21,183,21,189,21,197,21,223,21,231,21,237,21,245,21,255,21,7,22,13,22,21,22,40,22,48,22,54,22,62,22,72,22,80,22,86,22,94,22,116,22,124,22,130,22,138,22,148,22,156,22,162,22,170,22,189,22,197,22,203,22,211,22,221,22,229,22,235,22,243,22,41,22,49,22,55,22,63,22,73,22,81,22,87,22,95,22,114,22,122,22,128,22,136,22,146,22,154,22,160,22,168,22,190,22,198,22,204,22,212,22,222,22,230,22,236,22,244,22,7,23,15,23,21,23,29,23,39,23,47,23,53,23,61,23,87,23,95,23,101,23,109,23,119,23,127,23,133,23,141,23,160,23,168,23,174,23,182,23,192,23,200,23,206,23,214,23,236,23,244,23,250,23,2,24,12,24,20,24,26,24,34,24,53,24,61,24,67,24,75,24,85,24,93,24,99,24,107,24,229,23,237,23,243,23,251,23,5,24,13,24,19,24,27,24,46,24,54,24,60,24,68,24,78,24,86,24,92,24,100,24,122,24,130,24,136,24,144,24,154,24,162,24,168,24,176,24,195,24,203,24,209,24,217,24,227,24,235,24,241,24,249,24,19,25,27,25,33,25,41,25,51,25,59,25,65,25,73,25,92,25,100,25,106,25,114,25,124,25,132,25,138,25,146,25,168,25,176,25,182,25,190,25,200,25,208,25,214,25,222,25,241,25,249,25,255,25,7,26,17,26,25,26,31,26,39,26,158,14,166,14,172,14,180,14,190,14,198,14,204,14,212,14,231,14,239,14,245,14,253,14,7,15,15,15,21,15,29,15,51,15,59,15,65,15,73,15,83,15,91,15,97,15,105,15,124,15,132,15,138,15,146,15,156,15,164,15,170,15,178,15,204,15,212,15,218,15,226,15,236,15,244,15,250,15,2,16,21,16,29,16,35,16,43,16,53,16,61,16,67,16,75,16,97,16,105,16,111,16,119,16,129,16,137,16,143,16,151,16,170,16,178,16,184,16,192,16,202,16,210,16,216,16,224,16,90,16,98,16,104,16,112,16,122,16,130,16,136,16,144,16,163,16,171,16,177,16,185,16,195,16,203,16,209,16,217,16,239,16,247,16,253,16,5,17,15,17,23,17,29,17,37,17,56,17,64,17,70,17,78,17,88,17,96,17,102,17,110,17,136,17,144,17,150,17,158,17,168,17,176,17,182,17,190,17,209,17,217,17,223,17,231,17,241,17,249,17,255,17,7,18,29,18,37,18,43,18,51,18,61,18,69,18,75,18,83,18,102,18,110,18,116,18,124,18,134,18,142,18,148,18,156,18,210,17,218,17,224,17,232,17,242,17,250,17,0,18,8,18,27,18,35,18,41,18,49,18,59,18,67,18,73,18,81,18,103,18,111,18,117,18,125,18,135,18,143,18,149,18,157,18,176,18,184,18,190,18,198,18,208,18,216,18,222,18,230,18,0,19,8,19,14,19,22,19,32,19,40,19,46,19,54,19,73,19,81,19,87,19,95,19,105,19,113,19,119,19,127,19,149,19,157,19,163,19,171,19,181,19,189,19,195,19,203,19,222,19,230,19,236,19,244,19,254,19,6,20,12,20,20,20,142,19,150,19,156,19,164,19,174,19,182,19,188,19,196,19,215,19,223,19,229,19,237,19,247,19,255,19,5,20,13,20,35,20,43,20,49,20,57,20,67,20,75,20,81,20,89,20,108,20,116,20,122,20,130,20,140,20,148,20,154,20,162,20,188,20,196,20,202,20,210,20,220,20,228,20,234,20,242,20,5,21,13,21,19,21,27,21,37,21,45,21,51,21,59,21,81,21,89,21,95,21,103,21,113,21,121,21,127,21,135,21,154,21,162,21,168,21,176,21,186,21,194,21,200,21,208,21,245,18,253,18,3,19,11,19,21,19,29,19,35,19,43,19,62,19,70,19,76,19,84,19,94,19,102,19,108,19,116,19,138,19,146,19,152,19,160,19,170,19,178,19,184,19,192,19,211,19,219,19,225,19,233,19,243,19,251,19,1,20,9,20,35,20,43,20,49,20,57,20,67,20,75,20,81,20,89,20,108,20,116,20,122,20,130,20,140,20,148,20,154,20,162,20,184,20,192,20,198,20,206,20,216,20,224,20,230,20,238,20,1,21,9,21,15,21,23,21,33,21,41,21,47,21,55,21,177,20,185,20,191,20,199,20,209,20,217,20,223,20,231,20,250,20,2,21,8,21,16,21,26,21,34,21,40,21,48,21,70,21,78,21,84,21,92,21,102,21,110,21,116,21,124,21,143,21,151,21,157,21,165,21,175,21,183,21,189,21,197,21,223,21,231,21,237,21,245,21,255,21,7,22,13,22,21,22,40,22,48,22,54,22,62,22,72,22,80,22,86,22,94,22,116,22,124,22,130,22,138,22,148,22,156,22,162,22,170,22,189,22,197,22,203,22,211,22,221,22,229,22,235,22,243,22,41,22,49,22,55,22,63,22,73,22,81,22,87,22,95,22,114,22,122,22,128,22,136,22,146,22,154,22,160,22,168,22,190,22,198,22,204,22,212,22,222,22,230,22,236,22,244,22,7,23,15,23,21,23,29,23,39,23,47,23,53,23,61,23,87,23,95,23,101,23,109,23,119,23,127,23,133,23,141,23,160,23,168,23,174,23,182,23,192,23,200,23,206,23,214,23,236,23,244,23,250,23,2,24,12,24,20,24,26,24,34,24,53,24,61,24,67,24,75,24,85,24,93,24,99,24,107,24,229,23,237,23,243,23,251,23,5,24,13,24,19,24,27,24,46,24,54,24,60,24,68,24,78,24,86,24,92,24,100,24,122,24,130,24,136,24,144,24,154,24,162,24,168,24,176,24,195,24,203,24,209,24,217,24,227,24,235,24,241,24,249,24,19,25,27,25,33,25,41,25,51,25,59,25,65,25,73,25,92,25,100,25,106,25,114,25,124,25,132,25,138,25,146,25,168,25,176,25,182,25,190,25,200,25,208,25,214,25,222,25,241,25,249,25,255,25,7,26,17,26,25,26,31,26,39,26,156,22,164,22,170,22,178,22,188,22,196,22,202,22,210,22,229,22,237,22,243,22,251,22,5,23,13,23,19,23,27,23,49,23,57,23,63,23,71,23,81,23,89,23,95,23,103,23,122,23,130,23,136,23,144,23,154,23,162,23,168,23,176,23,202,23,210,23,216,23,224,23,234,23,242,23,248,23,0,24,19,24,27,24,33,24,41,24,51,24,59,24,65,24,73,24,95,24,103,24,109,24,117,24,127,24,135,24,141,24,149,24,168,24,176,24,182,24,190,24,200,24,208,24,214,24,222,24,88,24,96,24,102,24,110,24,120,24,128,24,134,24,142,24,161,24,169,24,175,24,183,24,193,24,201,24,207,24,215,24,237,24,245,24,251,24,3,25,13,25,21,25,27,25,35,25,54,25,62,25,68,25,76,25,86,25,94,25,100,25,108,25,134,25,142,25,148,25,156,25,166,25,174,25,180,25,188,25,207,25,215,25,221,25,229,25,239,25,247,25,253,25,5,26,27,26,35,26,41,26,49,26,59,26,67,26,73,26,81,26,100,26,108,26,114,26,122,26,132,26,140,26,146,26,154,26,208,25,216,25,222,25,230,25,240,25,248,25,254,25,6,26,25,26,33,26,39,26,47,26,57,26,65,26,71,26,79,26,101,26,109,26,115,26,123,26,133,26,141,26,147,26,155,26,174,26,182,26,188,26,196,26,206,26,214,26,220,26,228,26,254,26,6,27,12,27,20,27,30,27,38,27,44,27,52,27,71,27,79,27,85,27,93,27,103,27,111,27,117,27,125,27,147,27,155,27,161,27,169,27,179,27,187,27,193,27,201,27,220,27,228,27,234,27,242,27,252,27,4,28,10,28,18,28,140,27,148,27,154,27,162,27,172,27,180,27,186,27,194,27,213,27,221,27,227,27,235,27,245,27,253,27,3,28,11,28,33,28,41,28,47,28,55,28,65,28,73,28,79,28,87,28,106,28,114,28,120,28,128,28,138,28,146,28,152,28,160,28,186,28,194,28,200,28,208,28,218,28,226,28,232,28,240,28,3,29,11,29,17,29,25,29,35,29,43,29,49,29,57,29,79,29,87,29,93,29,101,29,111,29,119,29,125,29,133,29,152,29,160,29,166,29,174,29,184,29,192,29,198,29,206,29,243,26,251,26,1,27,9,27,19,27,27,27,33,27,41,27,60,27,68,27,74,27,82,27,92,27,100,27,106,27,114,27,136,27,144,27,150,27,158,27,168,27,176,27,182,27,190,27,209,27,217,27,223,27,231,27,241,27,249,27,255,27,7,28,33,28,41,28,47,28,55,28,65,28,73,28,79,28,87,28,106,28,114,28,120,28,128,28,138,28,146,28,152,28,160,28,182,28,190,28,196,28,204,28,214,28,222,28,228,28,236,28,255,28,7,29,13,29,21,29,31,29,39,29,45,29,53,29,175,28,183,28,189,28,197,28,207,28,215,28,221,28,229,28,248,28,0,29,6,29,14,29,24,29,32,29,38,29,46,29,68,29,76,29,82,29,90,29,100,29,108,29,114,29,122,29,141,29,149,29,155,29,163,29,173,29,181,29,187,29,195,29,221,29,229,29,235,29,243,29,253,29,5,30,11,30,19,30,38,30,46,30,52,30,60,30,70,30,78,30,84,30,92,30,114,30,122,30,128,30,136,30,146,30,154,30,160,30,168,30,187,30,195,30,201,30,209,30,219,30,227,30,233,30,241,30,39,30,47,30,53,30,61,30,71,30,79,30,85,30,93,30,112,30,120,30,126,30,134,30,144,30,152,30,158,30,166,30,188,30,196,30,202,30,210,30,220,30,228,30,234,30,242,30,5,31,13,31,19,31,27,31,37,31,45,31,51,31,59,31,85,31,93,31,99,31,107,31,117,31,125,31,131,31,139,31,158,31,166,31,172,31,180,31,190,31,198,31,204,31,212,31,234,31,242,31,248,31,0,32,10,32,18,32,24,32,32,32,51,32,59,32,65,32,73,32,83,32,3,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,128,2,0,3,2,5,2,7,132,9,8,12,186,14,102,17,244,20,252,20,4,21,12,21,16,21,20,21,36,21,44,21,52,21,84,21,116,21,132,21,196,21,228,21,36,22,164,22,228,22,4,23,12,25,12,26,140,26,140,28,140,29,140,30,140,31,172,33,172,35,172,36,182,38,182,39,184,41,188,43,206,45,208,47,208,49,242,51,242,53,246,55,248,57,140,60,150,62,156,64,6,67,14,69,88,71,108,73,152,75,214,77,244,79,224,83,126,87,230,89,70,92,0,0,0,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,0,0,128,63,0,0,144,63,0,0,160,63,0,0,184,63,1,2,2,2,2,3,2,3,2,3,2,3,1,3,2,3,0,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,4,0,0,0,12,0,0,0,255,255,255,255,255,255,255,255,2,0,0,0,255,255,255,255,111,18,131,58,37,206,138,58,19,16,147,58,56,216,155,58,8,5,165,58,157,217,174,58,106,52,185,58,110,21,196,58,198,191,207,58,228,17,220,58,200,11,233,58,141,240,246,58,140,190,2,59,66,122,10,59,48,188,18,59,199,98,27,59,94,160,36,59,44,100,46,59,50,174,56,59,253,159,67,59,143,57,79,59,172,139,91,59,144,133,104,59,199,72,118,59,12,115,130,59,195,46,138,59,233,95,146,59,229,14,155,59,180,59,164,59,31,247,173,59,37,65,184,59,240,50,195,59,30,196,206,59,17,253,218,59,245,246,231,59,44,186,245,59,91,35,2,60,224,218,9,60,213,7,18,60,109,174,26,60,10,215,35,60,67,142,45,60,23,212,55,60,78,185,66,60,24,66,78,60,11,123,90,60,139,108,103,60,45,35,117,60,195,213,129,60,253,134,137,60,167,173,145,60,244,77,154,60,121,116,163,60,79,35,173,60,241,100,183,60,221,67,194,60,92,198,205,60,236,246,217,60,34,226,230,60,96,144,244,60,30,135,1,61,244,78,5,61,38,52,9,61,168,53,13,61,134,84,17,61,218,146,21,61,174,241,25,61,248,111,30,61,220,16,35,61,78,211,39,61,115,186,44,61,63,197,49,61,203,245,54,61,47,78,60,61,96,205,65,61,129,118,71,61,149,73,77,61,166,71,83,61,205,114,89,61,37,205,95,61,159,85,102,61,98,15,109,61,122,251,115,61,0,28,123,61,122,56,129,61,55,254,132,61,68,224,136,61,173,223,140,61,248,252,144,61,172,56,149,61,213,147,153,61,6,16,158,61,197,173,162,61,152,109,167,61,152,81,172,61,62,89,177,61,43,135,182,61,228,219,187,61,239,87,193,61,101,253,198,61,205,204,204,61,185,199,210,61,53,239,216,61,212,68,223,61,42,202,229,61,187,127,236,61,161,103,243,61,111,131,250,61,24,234,0,62,188,173,4,62,109,141,8,62,55,138,12,62,227,164,16,62,248,221,20,62,9,55,25,62,87,176,29,62,241,74,34,62,37,8,39,62,188,232,43,62,7,238,48,62,139,24,54,62,90,188,56,62,219,105,59,62,83,33,62,62,193,226,64,62,104,174,67,62,140,132,70,62,44,101,73,62,139,80,76,62,170,70,79,62,15,72,82,62,51,84,85,62,223,107,88,62,210,142,91,62,144,189,94,62,26,248,97,62,180,62,101,62,92,145,104,62,86,240,107,62,230,91,111,62,11,212,114,62,75,89,118,62,100,235,121,62,219,138,125,62,216,155,128,62,20,121,130,62,32,93,132,62,98,72,134,62,184,58,136,62,34,52,138,62,5,53,140,62,62,61,142,62,18,77,144,62,161,100,146,62,203,131,148,62,243,170,150,62,249,217,152,62,65,17,155,62,169,80,157,62,82,152,159,62,163,232,161,62,120,65,164,62,245,162,166,62,57,13,169,62,136,128,171,62,5,253,173,62,174,130,176,62,165,17,179,62,13,170,181,62,39,76,184,62,22,248,186,62,218,173,189,62,181,109,192,62,202,55,195,62,57,12,198,62,37,235,200,62,174,212,203,62,25,201,206,62,101,200,209,62,212,210,212,62,171,232,215,62,200,9,219,62,143,54,222,62,34,111,225,62,196,179,228,62,83,4,232,62,86,97,235,62,205,202,238,62,217,64,242,62,223,195,245,62,223,83,249,62,250,240,252,62,203,77,0,63,233,41,2,63,233,12,4,63,236,246,5,63,4,232,7,63,97,224,9,63,5,224,11,63,16,231,13,63,148,245,15,63,212,11,18,63,191,41,20,63,135,79,22,63,78,125,24,63,37,179,26,63,61,241,28,63,151,55,31,63,102,134,33,63,202,221,35,63,230,61,38,63,202,166,40,63,152,24,43,63,129,147,45,63,152,23,48,63,13,165,50,63,247,4,53,63,123,220,55,63,182,134,58,63,231,58,61,63,14,249,63,63,110,193,66,63,41,148,69,63,80,113,72,63,20,89,75,63,169,75,78,63,48,73,81,63,202,81,84,63,170,101,87,63,241,132,90,63,209,175,93,63,125,230,96,63,7,41,100,63,175,119,103,63,154,210,106,63,247,57,110,63,251,173,113,63,199,46,117,63,157,188,120,63,159,87,124,63,0,0,128,63,0,0,0,0,247,4,53,63,247,4,53,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,77,0,63,203,77,0,63,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,203,77,0,63,203,77,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,77,0,63,203,77,0,63,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,203,77,0,63,203,77,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,203,77,0,63,0,0,0,0,0,0,0,0,203,77,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,77,0,63,203,77,0,63,247,4,53,63,0,0,0,0,0,0,0,0,247,4,53,63,203,77,0,63,0,0,0,0,0,0,0,0,203,77,0,63,0,0,0,0,0,0,0,0,168,126,34,0,112,0,0,0,112,189,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,7,1,0,0,0,0,0,0,3,6,0,0,0,0,0,0,7,6,0,0,0,0,0,0,195,6,0,0,0,0,0,0,55,1,0,0,0,0,0,0,244,1,0,0,0,0,0,0,199,6,0,0,0,0,0,0,243,6,0,0,0,0,0,0,199,7,0,0,0,0,0,0,1,2,2,2,2,3,3,4,4,5,6,6,6,7,8,8,0,1,255,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,2,0,1,3,255,255,255,255,255,0,1,2,3,255,255,255,255,255,2,0,1,3,4,255,255,255,255,0,1,3,4,2,255,255,255,255,2,0,1,4,5,3,255,255,255,2,3,0,1,5,6,4,255,255,2,0,1,3,4,5,6,255,255,0,5,3,4,1,2,6,255,255,3,2,4,0,1,6,7,5,255,4,5,0,1,7,2,8,3,6,3,2,4,0,1,5,8,7,6,0,255,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,2,0,1,255,255,255,255,255,255,0,1,2,255,255,255,255,255,255,2,0,1,3,255,255,255,255,255,0,1,2,3,255,255,255,255,255,2,0,1,3,4,255,255,255,255,2,3,0,1,4,5,255,255,255,2,0,1,3,4,5,255,255,255,0,5,3,4,1,2,255,255,255,3,2,4,0,1,5,6,255,255,4,5,0,1,6,2,7,3,255,3,2,4,0,1,5,7,6,255,0,2,255,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,2,0,1,4,255,255,255,255,255,0,1,3,4,255,255,255,255,255,2,0,1,4,5,255,255,255,255,0,1,4,5,3,255,255,255,255,2,0,1,5,6,4,255,255,255,3,4,0,1,6,7,5,255,255,2,0,1,4,5,6,7,255,255,0,6,4,5,2,3,7,255,255,4,2,5,0,1,7,8,6,255,5,6,0,1,8,3,9,4,7,4,2,5,0,1,6,9,8,7,0,255,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,0,1,255,255,255,255,255,255,255,2,0,1,255,255,255,255,255,255,0,1,3,255,255,255,255,255,255,2,0,1,4,255,255,255,255,255,0,1,3,4,255,255,255,255,255,2,0,1,4,5,255,255,255,255,3,4,0,1,5,6,255,255,255,2,0,1,4,5,6,255,255,255,0,6,4,5,2,3,255,255,255,4,2,5,0,1,6,7,255,255,5,6,0,1,7,3,8,4,255,4,2,5,0,1,6,8,7,255,0,125,0,0,192,218,0,0,0,250,0,0,0,119,1,0,128,181,1,0,0,244,1,0,0,238,2,0,0,107,3,0,0,232,3,0,0,226,4,0,0,220,5,0,0,214,6,0,0,208,7,0,0,202,8,0,0,196,9,0,0,184,11,0,0,172,13,0,0,160,15,0,0,148,17,0,0,136,19,0,0,130,20,0,0,124,21,0,128,136,21,0,0,118,22,0,0,112,23,0,0,76,29,0,0,64,31,0,0,224,46,0,0,152,58,0,1,0,0,0,2,0,0,0,3,0,0,0,0,125,0,0,192,218,0,0,0,250,0,0,0,119,1,0,128,181,1,0,0,244,1,0,0,238,2,0,0,107,3,0,0,232,3,0,0,226,4,0,0,220,5,0,0,214,6,0,0,208,7,0,0,202,8,0,0,196,9,0,0,184,11,0,0,172,13,0,0,160,15,0,0,148,17,0,0,136,19,0,0,130,20,0,0,124,21,0,128,136,21,0,0,118,22,0,0,112,23,0,0,76,29,0,0,64,31,0,0,224,46,0,0,152,58,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,8,0,8,0,9,0,10,0,11,0,12,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,38,0,39,0,40,0,41,0,42,0,43,0,43,0,44,0,45,0,46,0,47,0,48,0,48,0,49,0,50,0,51,0,52,0,53,0,53,0,54,0,55,0,56,0,57,0,57,0,58,0,59,0,60,0,61,0,62,0,62,0,63,0,64,0,65,0,66,0,66,0,67,0,68,0,69,0,70,0,70,0,71,0,72,0,73,0,74,0,74,0,75,0,76,0,77,0,78,0,78,0,79,0,80,0,81,0,81,0,82,0,83,0,84,0,85,0,85,0,87,0,88,0,90,0,92,0,93,0,95,0,96,0,98,0,99,0,101,0,102,0,104,0,105,0,107,0,108,0,110,0,111,0,113,0,114,0,116,0,117,0,118,0,120,0,121,0,123,0,125,0,127,0,129,0,131,0,134,0,136,0,138,0,140,0,142,0,144,0,146,0,148,0,150,0,152,0,154,0,156,0,158,0,161,0,164,0,166,0,169,0,172,0,174,0,177,0,180,0,182,0,185,0,187,0,190,0,192,0,195,0,199,0,202,0,205,0,208,0,211,0,214,0,217,0,220,0,223,0,226,0,230,0,233,0,237,0,240,0,243,0,247,0,250,0,253,0,1,1,5,1,9,1,13,1,16,1,20,1,24,1,28,1,32,1,36,1,40,1,44,1,48,1,53,1,57,1,61,1,66,1,70,1,74,1,79,1,84,1,88,1,93,1,98,1,103,1,108,1,113,1,118,1,123,1,128,1,133,1,139,1,144,1,150,1,155,1,161,1,167,1,173,1,179,1,185,1,191,1,198,1,205,1,211,1,219,1,226,1,233,1,241,1,249,1,1,2,10,2,18,2,27,2,37,2,47,2,57,2,67,2,78,2,90,2,102,2,114,2,128,2,142,2,156,2,172,2,188,2,205,2,224,2,243,2,7,3,28,3,51,3,75,3,101,3,128,3,157,3,187,3,220,3,254,3,34,4,74,4,115,4,160,4,208,4,2,5,56,5,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,21,0,0,0,21,0,0,0,22,0,0,0,22,0,0,0,23,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,91,0,0,0,93,0,0,0,95,0,0,0,96,0,0,0,98,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,110,0,0,0,112,0,0,0,114,0,0,0,116,0,0,0,118,0,0,0,122,0,0,0,124,0,0,0,126,0,0,0,128,0,0,0,130,0,0,0,132,0,0,0,134,0,0,0,136,0,0,0,138,0,0,0,140,0,0,0,143,0,0,0,145,0,0,0,148,0,0,0,151,0,0,0,154,0,0,0,157,0,0,0,59,12,113,18,10,30,54,42,48,54,111,64,40,77,244,86,140,99,70,108,0,0,0,0,0,1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,0,0,0,0,0,0,0,4,40,40,77,77,112,112,0,4,40,40,77,77,112,112,0,45,0,6,0,38,0,7,0,102,1,9,0,78,0,8,0,206,2,10,0,158,5,11,0,125,2,11,0,8,0,5,0,249,4,12,0,15,0,4,0,14,0,4,0,27,0,5,0,6,0,4,0,8,0,4,0,5,0,4,0,26,0,5,0,21,0,5,0,7,0,4,0,12,0,4,0,1,0,3,0,0,0,3,0,9,0,4,0,23,0,5,0,41,0,6,0,40,0,6,0,178,0,8,0,248,4,12,0,159,5,11,0,158,0,9,0,63,1,10,0,18,0,6,0,88,0,7,0,16,0,5,0,71,0,7,0,255,1,9,0,140,0,8,0,252,3,10,0,106,4,11,0,105,4,11,0,34,0,6,0,161,17,13,0,14,0,4,0,13,0,4,0,4,0,4,0,5,0,4,0,9,0,4,0,6,0,4,0,30,0,5,0,22,0,5,0,7,0,4,0,12,0,4,0,1,0,3,0,0,0,3,0,10,0,4,0,23,0,5,0,125,0,7,0,126,0,7,0,27,1,9,0,209,8,12,0,253,3,10,0,107,4,11,0,160,17,13,0,124,0,7,0,254,0,8,0,22,0,5,0,32,0,6,0,134,0,8,0,135,0,8,0,103,3,10,0,204,6,11,0,203,6,11,0,110,0,7,0,109,54,14,0,15,0,4,0,14,0,4,0,4,0,4,0,5,0,4,0,10,0,4,0,6,0,4,0,26,0,5,0,17,0,5,0,7,0,4,0,12,0,4,0,1,0,3,0,0,0,3,0,9,0,4,0,23,0,5,0,111,0,7,0,109,0,7,0,100,3,10,0,154,13,12,0,202,6,11,0,55,27,13,0,108,54,14,0,66,0,7,0,216,0,8,0,0,0,4,0,45,0,6,0,247,0,8,0,88,0,7,0,103,1,9,0,203,2,10,0,202,2,10,0,14,0,6,0,97,22,13,0,3,0,3,0,2,0,3,0,8,0,4,0,9,0,4,0,13,0,4,0,2,0,4,0,31,0,5,0,23,0,5,0,1,0,4,0,12,0,4,0,14,0,4,0,10,0,4,0,6,0,5,0,120,0,7,0,15,0,6,0,122,0,7,0,100,1,9,0,153,5,11,0,205,2,10,0,49,11,12,0,96,22,13,0,121,0,7,0,246,0,8,0,3,0,4,0,60,0,6,0,15,0,7,0,122,0,7,0,29,0,8,0,32,0,9,0,114,0,10,0,6,0,6,0,153,3,13,0,4,0,3,0,5,0,3,0,5,0,4,0,6,0,4,0,14,0,4,0,4,0,4,0,0,0,4,0,25,0,5,0,2,0,4,0,13,0,4,0,7,0,4,0,31,0,5,0,48,0,6,0,17,0,8,0,49,0,6,0,5,0,6,0,33,0,9,0,231,0,11,0,56,0,9,0,205,1,12,0,152,3,13,0,123,0,7,0,9,0,7,0,9,0,4,0,2,0,5,0,116,0,7,0,7,0,6,0,236,0,8,0,209,0,9,0,166,1,10,0,6,0,6,0,33,13,13,0,5,0,3,0,6,0,3,0,8,0,4,0,7,0,4,0,15,0,4,0,4,0,4,0,0,0,4,0,28,0,5,0,2,0,4,0,5,0,4,0,3,0,4,0,12,0,5,0,53,0,7,0,167,1,10,0,27,0,6,0,119,0,7,0,165,1,10,0,73,3,11,0,208,0,9,0,145,6,12,0,32,13,13,0,117,0,7,0,237,0,8,0,10,0,4,0,12,0,5,0,18,0,6,0,27,0,6,0,183,0,8,0,108,1,9,0,153,0,9,0,90,0,7,0,216,22,13,0,7,0,3,0,6,0,3,0,9,0,4,0,8,0,4,0,0,0,3,0,5,0,4,0,23,0,5,0,14,0,5,0,2,0,4,0,3,0,4,0,15,0,5,0,26,0,6,0,77,0,8,0,179,45,14,0,44,0,6,0,17,0,6,0,218,2,10,0,183,5,11,0,152,0,9,0,109,11,12,0,178,45,14,0,16,0,6,0,39,0,7,0,13,0,4,0,15,0,5,0,29,0,6,0,8,0,5,0,81,0,7,0,86,0,8,0,175,0,9,0,42,0,7,0,138,20,13,0,7,0,3,0,0,0,2,0,8,0,4,0,9,0,4,0,12,0,4,0,6,0,4,0,23,0,5,0,11,0,5,0,22,0,5,0,21,0,5,0,9,0,5,0,80,0,7,0,174,0,9,0,23,41,14,0,28,0,6,0,20,0,6,0,144,2,10,0,35,5,11,0,73,1,9,0,68,10,12,0,22,41,14,0,83,0,7,0,165,0,8,0,1,0,4,0,29,0,6,0,245,0,8,0,244,0,8,0,77,2,10,0,153,4,11,0,152,4,11,0,1,0,5,0,33,0,6,0,6,0,3,0,5,0,3,0,6,0,4,0,5,0,4,0,2,0,4,0,7,0,5,0,37,0,6,0,123,0,7,0,28,0,6,0,32,0,6,0,13,0,6,0,72,0,7,0,146,0,8,0,39,1,9,0,14,0,4,0,4,0,4,0,17,0,5,0,12,0,6,0,60,0,6,0,15,0,5,0,0,0,5,0,31,0,5,0,19,0,5,0,5,0,4,0,60,0,6,0,64,0,7,0,13,0,7,0,49,0,9,0,97,0,10,0,96,0,10,0,2,0,5,0,245,0,8,0,6,0,3,0,5,0,3,0,7,0,4,0,6,0,4,0,2,0,4,0,9,0,5,0,37,0,6,0,7,0,6,0,33,0,6,0,36,0,6,0,16,0,6,0,65,0,7,0,244,0,8,0,25,0,8,0,14,0,4,0,3,0,4,0,17,0,5,0,17,0,6,0,63,0,6,0,62,0,6,0,123,0,7,0,0,0,4,0,19,0,5,0,10,0,4,0,7,0,5,0,1,0,6,0,9,0,6,0,49,1,9,0,97,2,10,0,96,2,10,0,21,0,6,0,1,0,7,0,7,0,3,0,6,0,3,0,8,0,4,0,7,0,4,0,6,0,4,0,18,0,5,0,47,0,6,0,20,0,6,0,39,0,6,0,45,0,6,0,22,0,6,0,77,0,7,0,153,0,8,0,0,0,7,0,4,0,4,0,1,0,4,0,5,0,5,0,23,0,6,0,46,0,6,0,44,0,6,0,8,0,6,0,6,0,5,0,1,0,5,0,0,0,3,0,14,0,5,0,23,0,6,0,42,0,6,0,16,0,7,0,249,0,10,0,248,0,10,0,30,0,7,0,63,0,8,0,7,0,3,0,6,0,3,0,9,0,4,0,8,0,4,0,6,0,4,0,15,0,5,0,5,0,5,0,22,0,6,0,41,0,6,0,43,0,6,0,21,0,6,0,80,0,7,0,17,0,7,0,125,0,9,0,4,0,4,0,23,0,5,0,6,0,5,0,20,0,6,0,44,0,6,0,45,0,6,0,14,0,6,0,9,0,6,0,81,0,7,0,2,0,3,0,24,0,5,0,47,0,6,0,13,0,5,0,83,0,7,0,149,2,10,0,148,2,10,0,164,0,8,0,124,0,8,0,0,0,2,0,7,0,3,0,9,0,4,0,8,0,4,0,27,0,5,0,12,0,5,0,40,0,6,0,106,0,7,0,30,0,6,0,29,0,6,0,105,0,7,0,215,0,8,0,125,0,8,0,75,1,9,0,25,0,5,0,22,0,5,0,46,0,6,0,28,0,6,0,43,0,6,0,42,0,6,0,104,0,7,0,63,0,7,0,214,0,8,0,2,0,3,0,27,0,5,0,12,0,5,0,24,0,5,0,41,0,6,0,127,0,8,0,240,2,10,0,152,1,9,0,121,1,9,0,0,0,2,0,7,0,3,0,9,0,4,0,8,0,4,0,26,0,5,0,13,0,5,0,42,0,6,0,100,0,7,0,30,0,6,0,103,0,7,0,95,0,7,0,205,0,8,0,126,0,8,0,241,2,10,0,22,0,5,0,14,0,5,0,46,0,6,0,101,0,7,0,43,0,6,0,40,0,6,0,62,0,7,0,189,0,8,0,153,1,9,0,2,0,3,0,7,0,4,0,22,0,5,0,6,0,4,0,54,0,6,0,92,0,7,0,93,1,9,0,92,1,9,0,191,2,10,0,0,0,2,0,7,0,3,0,9,0,4,0,8,0,4,0,24,0,5,0,52,0,6,0,42,0,6,0,94,0,7,0,106,0,7,0,100,0,7,0,93,0,7,0,203,0,8,0,173,0,8,0,190,2,10,0,20,0,5,0,51,0,6,0,110,0,7,0,95,0,7,0,111,0,7,0,107,0,7,0,202,0,8,0,172,0,8,0,94,1,9,0,15,0,4,0,29,0,5,0,24,0,5,0,11,0,4,0,25,0,5,0,41,0,6,0,214,0,8,0,81,5,11,0,161,10,12,0,1,0,2,0,0,0,2,0,9,0,4,0,8,0,4,0,27,0,5,0,56,0,6,0,40,0,6,0,87,0,7,0,106,0,7,0,104,0,7,0,86,0,7,0,229,0,8,0,85,1,9,0,160,10,12,0,115,0,7,0,105,0,7,0,215,0,8,0,171,0,8,0,228,0,8,0,169,0,8,0,81,1,9,0,80,1,9,0,169,2,10,0,255,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,17,18,19,20,21,22,23,24,25,26,27,28,29,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,22,23,24,25,26,27,28,29,30,31,32,32,188,154,16,255,0,0,0,0,1,86,1,1,1,0,1,52,2,6,0,0,1,24,3,9,0,0,193,10,4,12,0,0,33,5,5,29,0,0,33,2,38,33,0,0,1,86,7,6,1,0,1,84,8,14,0,0,1,72,9,14,0,0,1,56,10,14,0,0,1,48,11,17,0,0,1,36,12,18,0,0,1,28,13,20,0,0,1,22,29,21,0,0,1,86,15,14,1,0,1,84,16,14,0,0,1,81,17,15,0,0,1,72,18,16,0,0,1,56,19,17,0,0,1,52,20,18,0,0,1,48,21,19,0,0,1,40,22,19,0,0,1,36,23,20,0,0,1,34,24,21,0,0,1,28,25,22,0,0,1,24,26,23,0,0,1,22,27,24,0,0,1,20,28,25,0,0,1,18,29,26,0,0,1,17,30,27,0,0,193,10,31,28,0,0,193,9,32,29,0,0,161,8,33,30,0,0,33,5,34,31,0,0,65,4,35,32,0,0,161,2,36,33,0,0,33,2,37,34,0,0,65,1,38,35,0,0,17,1,39,36,0,0,133,0,40,37,0,0,73,0,41,38,0,0,37,0,42,39,0,0,21,0,43,40,0,0,9,0,44,41,0,0,5,0,45,42,0,0,1,0,45,43,0,0,1,86,46,46,0,0,0,0,0,0,0,0,0,0,8,0,9,0,52,0,10,0,53,0,54,0,246,0,11,0,55,0,56,0,247,0,57,0,250,1,248,0,252,3,12,0,58,0,122,0,249,0,59,0,251,1,250,0,254,7,60,0,252,1,251,0,253,3,252,0,254,3,253,1,255,7,0,0,4,0,240,0,5,0,18,0,240,1,241,1,232,3,206,63,6,0,48,0,222,7,19,0,49,0,210,15,233,3,223,7,176,127,242,1,224,7,177,127,234,3,210,31,178,127,207,63,179,127,49,0,7,0,50,0,211,15,51,0,112,0,212,15,213,15,214,15,180,127,20,0,113,0,211,31,52,0,114,0,212,31,215,15,213,31,181,127,235,3,216,15,182,127,225,7,214,31,183,127,184,127,185,127,114,0,241,0,215,31,186,127,226,7,217,15,187,127,188,127,189,127,112,0,236,3,216,31,190,127,218,15,191,127,192,127,193,127,194,127,114,0,195,127,196,127,113,0,197,127,198,127,114,0,52,0,114,0,114,0,8,0,21,0,227,7,22,0,115,0,219,15,228,7,220,15,199,127,53,0,116,0,217,31,117,0,242,0,208,63,221,15,209,63,200,127,229,7,218,31,201,127,222,15,219,31,202,127,203,127,204,127,242,0,23,0,54,0,220,31,118,0,243,0,205,127,223,15,210,63,206,127,55,0,244,0,211,63,119,0,245,0,207,127,212,63,208,127,209,127,224,15,225,15,210,127,226,15,221,31,211,127,212,127,213,127,245,0,243,1,222,31,214,127,227,15,223,31,215,127,216,127,217,127,243,0,230,7,224,31,218,127,225,31,226,31,219,127,220,127,221,127,245,0,213,63,222,127,244,0,223,127,224,127,245,0,119,0,245,0,245,0,246,0,237,3,225,127,231,7,228,15,226,127,227,127,228,127,115,0,238,3,229,15,229,127,230,15,227,31,230,127,231,127,232,127,242,0,214,63,233,127,116,0,234,127,235,127,242,0,117,0,242,0,242,0,247,0,231,15,236,127,232,15,228,31,237,127,238,127,239,127,243,0,232,7,229,31,240,127,230,31,241,127,242,127,243,127,244,127,245,0,245,127,246,127,244,0,247,127,248,127,245,0,119,0,245,0,245,0,215,63,249,127,54,0,250,127,251,127,243,0,118,0,243,0,243,0,252,127,253,127,0,0,254,127,255,127,0,0,0,0,0,0,4,0,108,0,230,3,5,0,18,0,109,0,231,3,110,0,232,0,232,3,196,63,224,7,225,7,164,127,165,127,6,0,19,0,226,1,218,15,20,0,21,0,233,0,219,15,234,0,111,0,233,3,166,127,226,7,227,7,167,127,168,127,112,0,227,1,220,15,169,127,235,0,236,0,221,15,170,127,234,3,235,3,214,31,171,127,197,63,198,63,172,127,214,31,228,7,215,31,173,127,174,127,229,7,216,31,175,127,176,127,199,63,177,127,178,127,214,31,179,127,180,127,214,31,214,31,7,0,22,0,228,1,217,31,23,0,50,0,229,1,218,31,230,1,231,1,230,7,181,127,200,63,219,31,182,127,183,127,8,0,51,0,232,1,222,15,24,0,52,0,233,1,220,31,234,1,237,0,231,7,184,127,221,31,223,15,185,127,186,127,113,0,235,1,224,15,187,127,114,0,238,0,232,7,188,127,236,3,237,3,201,63,189,127,202,63,190,127,191,127,201,63,238,3,225,15,192,127,193,127,233,7,222,31,194,127,195,127,196,127,197,127,198,127,201,63,199,127,200,127,201,63,201,63,53,0,236,1,223,31,203,63,239,0,237,1,226,15,201,127,227,15,228,15,202,127,203,127,204,127,205,127,206,127,202,127,115,0,238,1,224,31,207,127,240,0,239,1,229,15,208,127,234,7,230,15,209,127,210,127,211,127,212,127,213,127,209,127,240,1,235,7,214,127,215,127,241,1,236,7,216,127,217,127,204,63,205,63,218,127,218,127,219,127,220,127,218,127,218,127,206,63,221,127,222,127,214,127,207,63,223,127,224,127,216,127,225,127,226,127,218,127,218,127,204,63,205,63,218,127,218,127,242,1,231,15,227,127,228,127,232,15,225,31,229,127,230,127,231,127,232,127,233,127,202,127,234,127,235,127,202,127,202,127,239,3,233,15,236,127,237,127,234,15,208,63,238,127,239,127,240,127,241,127,242,127,209,127,243,127,244,127,209,127,209,127,209,63,245,127,246,127,214,127,247,127,248,127,249,127,216,127,250,127,251,127,218,127,218,127,204,63,205,63,218,127,218,127,252,127,253,127,214,127,214,127,254,127,255,127,0,0,0,0,0,0,4,0,34,0,198,0,176,3,12,0,13,0,35,0,199,0,177,3,92,0,200,0,201,0,178,3,164,15,194,1,195,1,179,3,165,15,114,127,180,3,178,7,154,31,36,255,37,255,14,0,36,0,202,0,181,3,179,7,15,0,37,0,203,0,182,3,166,15,93,0,94,0,204,0,183,3,155,31,196,1,197,1,184,3,167,15,115,127,168,15,180,7,156,31,38,255,39,255,95,0,198,1,185,3,169,15,116,127,96,0,205,0,186,3,170,15,157,31,199,1,200,1,181,7,158,31,40,255,182,7,183,7,171,15,162,63,41,255,172,15,173,15,163,63,42,255,162,63,201,1,184,7,174,15,43,255,44,255,202,1,187,3,159,31,117,127,45,255,188,3,185,7,175,15,46,255,47,255,160,31,161,31,48,255,49,255,50,255,51,255,52,255,118,127,53,255,49,255,186,7,162,31,54,255,55,255,119,127,187,7,163,31,120,127,56,255,57,255,164,31,165,31,58,255,59,255,46,255,164,63,60,255,61,255,62,255,49,255,63,255,64,255,48,255,49,255,49,255,5,0,38,0,206,0,189,3,166,31,39,0,40,0,207,0,190,3,167,31,203,1,208,0,191,3,176,15,65,255,192,3,193,3,188,7,121,127,66,255,168,31,177,15,165,63,67,255,68,255,16,0,41,0,209,0,189,7,169,31,42,0,43,0,210,0,194,3,170,31,211,0,212,0,204,1,190,7,166,63,195,3,196,3,178,15,179,15,69,255,171,31,180,15,172,31,122,127,70,255,97,0,213,0,205,1,181,15,71,255,98,0,214,0,197,3,182,15,167,63,206,1,207,1,198,3,173,31,72,255,191,7,199,3,183,15,123,127,73,255,174,31,175,31,74,255,75,255,123,127,208,1,192,7,176,31,76,255,77,255,209,1,200,3,184,15,124,127,78,255,201,3,193,7,177,31,79,255,80,255,178,31,185,15,81,255,82,255,83,255,84,255,85,255,86,255,87,255,82,255,194,7,179,31,88,255,89,255,90,255,195,7,180,31,91,255,92,255,93,255,186,15,181,31,125,127,94,255,79,255,95,255,96,255,97,255,98,255,82,255,99,255,100,255,81,255,82,255,82,255,44,0,215,0,196,7,182,31,101,255,216,0,217,0,202,3,187,15,102,255,197,7,203,3,198,7,183,31,103,255,188,15,184,31,185,31,126,127,104,255,105,255,106,255,168,63,107,255,126,127,45,0,218,0,204,3,186,31,108,255,219,0,220,0,205,3,189,15,109,255,206,3,207,3,199,7,187,31,110,255,188,31,190,15,189,31,111,255,112,255,169,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1609240);
/* memory initializer */ allocate([170,63,171,63,113,255,111,255,221,0,210,1,200,7,190,31,114,255,222,0,211,1,201,7,115,255,172,63,208,3,209,3,191,15,127,127,116,255,192,15,193,15,191,31,117,255,118,255,128,127,119,255,120,255,121,255,117,255,210,3,194,15,129,127,122,255,123,255,211,3,195,15,196,15,173,63,124,255,197,15,198,15,192,31,125,255,126,255,174,63,130,127,127,255,128,255,128,255,129,255,130,255,131,255,128,255,128,255,199,15,131,127,132,127,132,255,122,255,193,31,194,31,133,255,134,255,173,63,175,63,135,255,136,255,137,255,125,255,138,255,139,255,140,255,128,255,128,255,174,63,130,127,127,255,128,255,128,255,223,0,212,3,195,31,133,127,141,255,213,3,202,7,196,31,142,255,143,255,197,31,198,31,176,63,144,255,145,255,146,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,149,255,224,0,214,3,203,7,134,127,155,255,212,1,215,3,200,15,156,255,157,255,201,15,202,15,135,127,158,255,159,255,160,255,177,63,161,255,162,255,163,255,164,255,165,255,166,255,167,255,162,255,213,1,204,7,178,63,168,255,169,255,216,3,205,7,199,31,170,255,171,255,179,63,200,31,180,63,172,255,173,255,174,255,136,127,137,127,175,255,175,255,176,255,177,255,178,255,175,255,175,255,206,7,201,31,179,255,180,255,181,255,207,7,202,31,138,127,182,255,183,255,203,31,184,255,185,255,186,255,186,255,187,255,188,255,189,255,190,255,190,255,191,255,192,255,189,255,190,255,190,255,139,127,193,255,194,255,195,255,180,255,181,63,196,255,197,255,198,255,182,255,199,255,200,255,201,255,186,255,186,255,202,255,203,255,189,255,190,255,190,255,187,255,188,255,189,255,190,255,190,255,214,1,204,31,204,255,205,255,206,255,208,7,205,31,207,255,208,255,209,255,182,63,140,127,210,255,211,255,144,255,141,127,212,255,213,255,214,255,149,255,215,255,216,255,148,255,149,255,149,255,215,1,206,31,142,127,143,127,217,255,203,15,207,31,183,63,218,255,219,255,220,255,144,127,221,255,222,255,158,255,223,255,224,255,225,255,226,255,162,255,227,255,228,255,161,255,162,255,162,255,209,7,208,31,145,127,229,255,168,255,204,15,184,63,230,255,231,255,170,255,232,255,233,255,234,255,235,255,172,255,236,255,237,255,238,255,175,255,175,255,174,255,136,127,137,127,175,255,175,255,239,255,240,255,241,255,242,255,180,255,243,255,244,255,245,255,246,255,182,255,247,255,248,255,249,255,186,255,186,255,250,255,251,255,189,255,190,255,190,255,187,255,188,255,189,255,190,255,190,255,252,255,253,255,179,255,180,255,180,255,254,255,255,255,0,0,0,0,10,0,24,0,116,0,242,0,244,1,246,3,4,0,11,0,25,0,117,0,243,0,245,1,247,3,26,0,27,0,56,0,118,0,244,0,248,3,249,3,119,0,57,0,120,0,245,0,246,1,250,3,252,15,246,0,247,0,248,0,247,1,251,3,253,15,254,63,249,0,248,1,249,1,252,3,252,7,254,127,254,255,250,1,253,3,253,7,254,15,254,31,255,255,0,0,8,0,20,0,48,0,106,0,226,0,227,0,228,1,236,3,237,3,9,0,21,0,49,0,107,0,108,0,228,0,229,0,229,1,230,1,240,7,22,0,23,0,50,0,109,0,230,0,231,0,231,1,232,1,238,3,241,7,51,0,52,0,110,0,232,0,233,0,233,1,234,1,239,3,242,7,246,15,111,0,112,0,234,0,235,0,235,1,236,1,240,3,243,7,244,7,250,31,236,0,237,0,238,0,237,1,238,1,241,3,242,3,245,7,247,15,250,63,239,0,240,0,241,0,239,1,243,3,246,7,247,7,248,15,251,31,254,127,240,1,241,1,242,1,244,3,248,7,249,15,250,15,251,63,252,63,0,0,243,1,244,1,245,1,245,3,249,7,251,15,253,63,254,255,0,0,0,0,246,3,247,3,250,7,252,15,252,31,254,63,255,255,0,0,0,0,0,0,0,0,8,0,44,0,45,0,98,0,99,0,212,0,213,0,214,0,198,1,199,1,202,3,214,7,215,7,9,0,20,0,46,0,100,0,101,0,215,0,216,0,200,1,201,1,202,1,203,1,203,3,216,7,217,7,21,0,47,0,102,0,217,0,218,0,204,1,205,1,206,1,207,1,204,3,205,3,206,3,218,7,228,15,48,0,103,0,219,0,208,1,209,1,210,1,211,1,207,3,208,3,209,3,210,3,219,7,229,15,234,31,104,0,105,0,220,0,212,1,213,1,214,1,211,3,212,3,213,3,214,3,220,7,221,7,230,15,235,31,221,0,222,0,215,1,216,1,217,1,215,3,216,3,217,3,218,3,222,7,223,7,231,15,236,31,242,63,223,0,224,0,218,1,219,1,219,3,220,3,224,7,225,7,226,7,232,15,233,15,237,31,238,31,244,127,225,0,226,0,220,1,221,1,221,3,222,3,227,7,228,7,229,7,234,15,235,15,239,31,243,63,245,127,222,1,223,1,224,1,223,3,224,3,225,3,230,7,231,7,236,15,240,31,237,15,244,63,246,127,248,255,225,1,226,1,226,3,227,3,228,3,229,3,232,7,238,15,239,15,245,63,246,63,249,255,250,255,250,255,227,1,228,1,230,3,231,3,233,7,234,7,240,15,241,31,242,31,247,63,248,63,247,127,247,127,250,255,232,3,233,3,234,3,235,7,236,7,241,15,242,15,243,31,248,127,249,127,251,255,248,63,247,127,247,127,237,7,238,7,239,7,243,15,244,31,245,31,246,31,250,127,252,255,253,255,251,255,251,255,248,63,247,127,240,7,241,7,244,15,247,31,248,31,249,63,251,127,254,255,255,255,0,0,184,185,24,0,240,184,24,0,144,184,24,0,208,179,24,0,224,177,24,0,16,176,24,0,208,175,24,0,0,0,0,0,1,4,4,6,4,6,6,8,4,6,6,8,6,9,8,10,4,6,7,8,6,9,8,11,6,9,8,10,8,10,9,11,2,4,8,4,5,9,9,10,14,4,6,11,5,6,12,10,11,15,9,11,15,10,13,15,14,15,0,4,6,12,6,7,12,12,12,15,5,7,13,6,7,13,12,13,15,10,12,15,11,13,15,15,15,0,8,13,15,11,12,15,15,15,0,10,13,15,12,15,15,15,15,0,15,15,0,15,15,0,0,0,0,4,5,11,5,7,12,11,12,15,6,7,13,7,8,14,12,14,15,11,13,15,12,13,15,15,15,0,5,6,13,7,8,15,12,14,15,6,8,14,7,8,15,14,15,15,12,12,15,12,13,15,15,15,0,9,13,15,12,13,15,15,15,0,11,13,15,13,13,15,15,15,0,14,15,0,15,15,0,0,0,0,8,10,15,11,12,15,15,15,0,10,12,15,12,13,15,15,15,0,14,15,0,15,15,0,0,0,0,8,12,15,12,13,15,15,15,0,11,13,15,13,15,15,15,15,0,15,15,0,15,15,0,0,0,0,14,15,0,15,15,0,0,0,0,15,15,0,15,15,0,0,2,4,7,10,4,5,7,10,7,8,10,14,11,11,15,15,4,5,9,12,5,5,8,12,8,7,10,15,11,11,15,15,7,9,12,15,8,8,12,15,10,10,13,15,14,14,15,0,11,13,15,15,11,13,15,15,14,15,15,0,15,15,0,0,4,5,9,13,5,6,9,13,9,9,11,15,14,13,15,15,4,6,9,12,5,6,9,13,9,8,11,15,13,12,15,15,7,9,12,15,7,8,11,15,10,10,14,15,14,15,15,0,10,12,15,15,11,13,15,15,15,15,15,0,15,15,0,0,6,9,13,14,8,9,12,15,12,12,15,15,15,15,15,0,7,9,13,15,8,9,12,15,11,12,15,15,15,15,15,0,9,11,15,15,9,11,15,15,14,14,15,0,15,15,0,0,14,15,15,0,14,15,15,0,15,15,0,0,0,0,0,0,9,12,15,15,12,13,15,15,15,15,15,0,15,15,0,0,10,12,15,15,12,14,15,15,15,15,15,0,15,15,0,0,14,15,15,0,15,15,15,0,15,15,0,0,0,0,0,0,15,15,0,0,15,15,0,0,2,4,6,8,10,5,5,6,8,10,7,8,8,10,12,9,9,10,12,15,10,11,13,16,16,5,6,8,10,11,5,6,8,10,12,7,7,8,10,13,9,9,10,12,15,12,11,13,16,16,7,9,10,12,15,7,8,10,12,13,9,9,11,13,16,11,11,12,14,16,12,12,14,16,0,9,11,12,16,16,9,10,13,15,16,10,11,12,16,16,13,13,16,16,16,16,16,15,16,0,11,13,16,16,15,11,13,15,16,16,13,13,16,16,0,14,16,16,16,0,16,16,0,0,0,4,6,8,10,13,6,6,8,10,13,9,8,10,12,16,10,10,11,15,16,13,12,14,16,16,5,6,8,11,13,6,6,8,10,13,8,8,9,11,14,10,10,12,12,16,13,12,13,15,16,7,8,9,12,16,7,8,10,12,14,9,9,10,13,16,11,10,12,15,16,13,13,16,16,0,9,11,13,16,16,9,10,12,15,16,10,11,13,16,16,13,12,16,16,16,16,16,16,16,0,11,13,16,16,16,11,13,16,16,16,12,13,15,16,0,16,16,16,16,0,16,16,0,0,0,6,8,11,13,16,8,8,10,12,16,11,10,11,13,16,12,13,13,15,16,16,16,14,16,0,6,8,10,13,16,8,8,10,12,16,10,10,11,13,16,13,12,13,16,16,14,14,14,16,0,8,9,11,13,16,8,9,11,16,14,10,10,12,15,16,12,12,13,16,16,15,16,16,16,0,10,12,15,16,16,10,12,12,14,16,12,12,13,16,16,14,15,16,16,0,16,16,16,0,0,12,15,15,16,0,13,13,16,16,0,14,16,16,16,0,16,16,16,0,0,0,0,0,0,0,8,10,13,15,16,10,11,13,16,16,13,13,14,16,16,16,16,16,16,16,16,16,16,16,0,8,10,11,15,16,9,10,12,16,16,12,12,15,16,16,16,14,16,16,16,16,16,16,16,0,9,11,14,16,16,10,11,13,16,16,14,13,14,16,16,16,15,15,16,0,16,16,16,0,0,11,13,16,16,16,11,13,15,16,16,13,16,16,16,0,16,16,16,16,0,16,16,0,0,0,15,16,16,16,0,14,16,16,16,0,16,16,16,0,0,16,16,0,0,0,0,0,0,0,0,9,13,16,16,16,11,13,16,16,16,14,15,16,16,0,15,16,16,16,0,16,16,0,0,0,9,13,15,15,16,12,13,14,16,16,16,15,16,16,0,16,16,16,16,0,16,16,0,0,0,11,13,15,16,0,12,14,16,16,0,16,16,16,16,0,16,16,16,0,0,0,0,0,0,0,16,16,16,16,0,16,16,16,16,0,16,16,16,0,0,16,16,0,0,0,0,0,0,0,0,16,16,0,0,0,16,16,0,1,4,5,7,8,9,10,3,4,5,7,8,9,10,5,5,6,7,8,10,10,7,6,7,8,9,10,12,8,8,8,9,10,12,14,8,9,9,10,11,15,16,9,10,11,12,13,16,1,4,5,6,7,8,8,9,10,10,4,5,6,7,7,8,8,9,9,11,5,5,6,7,8,8,9,9,10,11,6,6,7,8,8,9,9,10,11,12,7,7,8,8,9,9,10,11,11,13,8,8,8,9,9,10,10,11,12,14,8,8,8,9,10,11,11,12,13,15,9,9,9,10,11,12,12,14,14,0,9,9,9,10,11,12,14,16,0,0,10,10,11,12,13,14,16,0,0,0,0,0,0,0,1,4,6,6,7,7,8,8,8,9,9,10,11,11,4,5,6,7,7,8,8,9,9,9,9,10,11,11,5,6,7,8,8,9,9,9,9,10,10,10,11,12,6,7,8,9,9,9,9,10,10,10,10,11,12,13,7,7,8,9,9,9,10,10,10,10,11,11,12,13,8,8,9,9,9,10,10,10,10,11,11,12,13,14,8,8,9,9,10,10,11,11,11,12,12,13,13,15,8,8,9,9,10,10,11,11,11,12,12,13,14,15,9,9,9,10,10,10,11,11,12,13,12,14,15,16,9,9,10,10,10,10,11,12,12,14,14,16,16,0,9,9,10,10,11,11,12,13,13,14,14,15,0,0,10,10,10,11,11,12,12,13,15,15,16,0,0,0,11,11,11,12,13,13,13,15,16,16,0,0,0,0,11,11,12,13,13,14,15,16,16,0,80,192,24,0,232,191,24,0,184,191,24,0,88,189,24,0,96,188,24,0,120,187,24,0,88,187,24,0,0,0,0,0,2,0,0,0,16,0,0,0,16,0,0,0,192,253,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,8,0,0,0,8,0,0,0,184,253,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,1,0,0,0,1,0,0,112,242,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,64,0,0,0,64,0,0,0,72,236,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,128,0,0,0,128,0,0,0,200,235,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,32,0,0,0,32,0,0,0,168,235,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,96,0,0,0,96,0,0,0,72,235,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,32,0,0,0,32,0,0,0,40,235,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,96,0,0,0,96,0,0,0,200,234,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,17,0,0,0,17,0,0,0,176,234,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,32,0,0,0,32,0,0,0,152,253,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,78,0,0,0,78,0,0,0,72,253,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,17,0,0,0,17,0,0,0,48,253,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,32,0,0,0,32,0,0,0,16,253,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,78,0,0,0,78,0,0,0,192,252,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,100,0,0,0,100,0,0,0,88,252,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,105,6,0,0,161,25,0,0,232,245,25,0,1,0,0,0,0,0,128,191,0,0,128,63,64,104,40,0,4,0,0,0,187,1,0,0,113,2,0,0,40,244,25,0,1,0,0,0,0,0,0,192,0,0,128,63,96,103,40,0,4,0,0,0,105,0,0,0,113,2,0,0,184,243,25,0,1,0,0,0,0,0,0,192,0,0,128,63,48,103,40,0,2,0,0,0,68,0,0,0,81,0,0,0,112,243,25,0,1,0,0,0,0,0,128,192,0,0,128,63,40,102,40,0,2,0,0,0,81,0,0,0,81,0,0,0,24,242,25,0,1,0,0,0,0,0,128,192,0,0,128,63,8,101,40,0,2,0,0,0,33,1,0,0,33,1,0,0,240,240,25,0,1,0,0,0,0,0,0,193,0,0,128,63,80,100,40,0,4,0,0,0,81,0,0,0,81,0,0,0,152,240,25,0,1,0,0,0,0,0,48,193,0,0,48,65,232,99,40,0,2,0,0,0,121,0,0,0,121,0,0,0,24,240,25,0,1,0,0,0,0,0,160,192,0,0,128,63,240,98,40,0,2,0,0,0,169,0,0,0,169,0,0,0,104,239,25,0,1,0,0,0,0,0,240,193,0,0,160,64,176,98,40,0,2,0,0,0,25,0,0,0,25,0,0,0,72,239,25,0,1,0,0,0,0,0,0,192,0,0,128,63,160,98,40,0,2,0,0,0,169,0,0,0,169,0,0,0,152,238,25,0,1,0,0,0,0,64,191,196,0,0,127,67,144,98,40,0,2,0,0,0,225,0,0,0,225,0,0,0,176,237,25,0,1,0,0,0,0,0,238,194,0,0,136,65,128,98,40,0,2,0,0,0,33,1,0,0,33,1,0,0,136,236,25,0,1,0,0,0,0,0,0,193,0,0,128,63,88,98,40,0,71,0,40,1,39,1,237,0,71,0,40,0,38,0,19,0,245,0,193,0,185,0,121,0,102,0,73,0,53,0,27,0,158,0,129,0,141,0,107,0,97,0,73,0,50,0,26,0,102,0,116,0,109,0,98,0,82,0,66,0,45,0,23,0,71,0,94,0,95,0,81,0,70,0,56,0,38,0,20,0,56,0,77,0,74,0,66,0,56,0,44,0,30,0,15,0,38,0,53,0,50,0,45,0,38,0,30,0,21,0,11,0,20,0,27,0,26,0,23,0,20,0,15,0,11,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,150,38,0,240,90,38,0,168,37,38,0,0,0,0,0,64,244,37,0,16,200,37,0,72,164,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,125,37,0,0,0,0,0,0,0,0,0,0,0,0,0,80,59,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,37,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,36,0,0,0,0,0,0,0,0,0,0,0,0,0,224,165,36,0,0,0,0,0,0,0,0,0,0,0,0,0,160,139,36,0,144,111,36,0,144,84,36,0,168,59,36,0,0,0,0,0,104,126,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,198,35,0,192,174,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,64,16,0,1,0,168,152,35,0,144,131,35,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,248,108,35,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,40,89,35,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,152,71,35,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,136,53,35,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,168,30,35,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,112,243,34,0,0,0,0,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,24,219,34,0,0,0,0,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,112,204,34,0,0,0,0,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,200,187,34,0,0,0,0,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,240,169,34,0,0,0,0,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,16,0,1,0,168,152,35,0,136,151,34,0,168,137,34,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,122,34,0,168,137,34,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,208,105,34,0,72,86,34,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,72,46,34,0,72,86,34,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,184,25,34,0,96,11,34,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,128,252,33,0,96,11,34,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,234,33,0,200,219,33,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,96,208,33,0,200,219,33,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,198,33,0,88,189,33,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,56,176,33,0,40,142,33,0,28,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,126,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,1,0,0,0,0,0,0,0,0,0,0,98,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,80,37,0,112,0,0,0,120,198,24,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,0,0,0,0,0,6,10,1,7,11,2,8,12,0,0,0,0,0,0,5,9,13,0,0,0,0,0,0,0,6,10,1,7,11,2,8,12,0,0,0,0,0,0,5,9,13,0,0,0,0,0,0,0,6,10,1,7,11,2,8,12,0,0,0,0,0,0,5,9,13,0,0,0,0,0,0,0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,192,233,35,0,240,246,34,0,20,0,0,0,1,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,200,48,34,0,120,144,33,0,24,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,216,20,33,0,136,172,32,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,184,80,32,0,136,172,32,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,93,37,0,112,0,0,0,16,204,24,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,72,37,0,64,238,35,0,64,0,0,0,5,0,0,0,232,250,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,24,52,34,0,64,238,35,0,64,0,0,0,5,0,0,0,232,250,34,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,168,147,33,0,128,23,33,0,68,0,0,0,5,0,0,0,192,174,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,240,82,32,0,128,23,33,0,68,0,0,0,5,0,0,0,192,174,32,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,16,58,40,0,192,222,39,0,56,0,0,0,5,0,0,0,64,118,39,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,248,36,39,0,8,222,38,0,60,0,0,0,5,0,0,0,216,152,38,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,48,93,38,0,200,39,38,0,28,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,117,37,0,112,0,0,0,48,205,24,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,0,200,0,44,1,144,1,254,1,118,2,2,3,152,3,56,4,246,4,200,5,184,6,208,7,16,9,140,10,78,12,116,14,48,17,180,20,0,25,20,30,28,37,224,46,140,60,195,80,159,111,159,161,131,249,255,255,255,255,255,255,255,255,255,255,16,255,255,255,255,255,255,255,17,255,255,255,255,255,255,255,18,255,255,255,255,255,255,255,19,255,255,255,255,255,255,255,20,255,255,255,255,255,255,255,21,255,255,255,255,255,22,23,255,255,255,255,255,255,24,25,255,255,255,255,255,255,26,27,28,255,255,255,255,255,93,0,0,0,23,0,0,0,116,1,0,0,6,0,0,0,46,0,0,0,186,0,0,0,238,2,0,0,14,0,0,0,33,0,0,0,65,0,0,0,130,0,0,0,4,1,0,0,44,2,0,0,3,0,0,0,10,0,0,0,18,0,0,0,28,0,0,0,39,0,0,0,55,0,0,0,79,0,0,0,111,0,0,0,158,0,0,0,220,0,0,0,56,1,0,0,208,1,0,0,138,2,0,0,82,3,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,150,48,7,119,44,97,14,238,186,81,9,153,25,196,109,7,143,244,106,112,53,165,99,233,163,149,100,158,50,136,219,14,164,184,220,121,30,233,213,224,136,217,210,151,43,76,182,9,189,124,177,126,7,45,184,231,145,29,191,144,100,16,183,29,242,32,176,106,72,113,185,243,222,65,190,132,125,212,218,26,235,228,221,109,81,181,212,244,199,133,211,131,86,152,108,19,192,168,107,100,122,249,98,253,236,201,101,138,79,92,1,20,217,108,6,99,99,61,15,250,245,13,8,141,200,32,110,59,94,16,105,76,228,65,96,213,114,113,103,162,209,228,3,60,71,212,4,75,253,133,13,210,107,181,10,165,250,168,181,53,108,152,178,66,214,201,187,219,64,249,188,172,227,108,216,50,117,92,223,69,207,13,214,220,89,61,209,171,172,48,217,38,58,0,222,81,128,81,215,200,22,97,208,191,181,244,180,33,35,196,179,86,153,149,186,207,15,165,189,184,158,184,2,40,8,136,5,95,178,217,12,198,36,233,11,177,135,124,111,47,17,76,104,88,171,29,97,193,61,45,102,182,144,65,220,118,6,113,219,1,188,32,210,152,42,16,213,239,137,133,177,113,31,181,182,6,165,228,191,159,51,212,184,232,162,201,7,120,52,249,0,15,142,168,9,150,24,152,14,225,187,13,106,127,45,61,109,8,151,108,100,145,1,92,99,230,244,81,107,107,98,97,108,28,216,48,101,133,78,0,98,242,237,149,6,108,123,165,1,27,193,244,8,130,87,196,15,245,198,217,176,101,80,233,183,18,234,184,190,139,124,136,185,252,223,29,221,98,73,45,218,21,243,124,211,140,101,76,212,251,88,97,178,77,206,81,181,58,116,0,188,163,226,48,187,212,65,165,223,74,215,149,216,61,109,196,209,164,251,244,214,211,106,233,105,67,252,217,110,52,70,136,103,173,208,184,96,218,115,45,4,68,229,29,3,51,95,76,10,170,201,124,13,221,60,113,5,80,170,65,2,39,16,16,11,190,134,32,12,201,37,181,104,87,179,133,111,32,9,212,102,185,159,228,97,206,14,249,222,94,152,201,217,41,34,152,208,176,180,168,215,199,23,61,179,89,129,13,180,46,59,92,189,183,173,108,186,192,32,131,184,237,182,179,191,154,12,226,182,3,154,210,177,116,57,71,213,234,175,119,210,157,21,38,219,4,131,22,220,115,18,11,99,227,132,59,100,148,62,106,109,13,168,90,106,122,11,207,14,228,157,255,9,147,39,174,0,10,177,158,7,125,68,147,15,240,210,163,8,135,104,242,1,30,254,194,6,105,93,87,98,247,203,103,101,128,113,54,108,25,231,6,107,110,118,27,212,254,224,43,211,137,90,122,218,16,204,74,221,103,111,223,185,249,249,239,190,142,67,190,183,23,213,142,176,96,232,163,214,214,126,147,209,161,196,194,216,56,82,242,223,79,241,103,187,209,103,87,188,166,221,6,181,63,75,54,178,72,218,43,13,216,76,27,10,175,246,74,3,54,96,122,4,65,195,239,96,223,85,223,103,168,239,142,110,49,121,190,105,70,140,179,97,203,26,131,102,188,160,210,111,37,54,226,104,82,149,119,12,204,3,71,11,187,185,22,2,34,47,38,5,85,190,59,186,197,40,11,189,178,146,90,180,43,4,106,179,92,167,255,215,194,49,207,208,181,139,158,217,44,29,174,222,91,176,194,100,155,38,242,99,236,156,163,106,117,10,147,109,2,169,6,9,156,63,54,14,235,133,103,7,114,19,87,0,5,130,74,191,149,20,122,184,226,174,43,177,123,56,27,182,12,155,142,210,146,13,190,213,229,183,239,220,124,33,223,219,11,212,210,211,134,66,226,212,241,248,179,221,104,110,131,218,31,205,22,190,129,91,38,185,246,225,119,176,111,119,71,183,24,230,90,8,136,112,106,15,255,202,59,6,102,92,11,1,17,255,158,101,143,105,174,98,248,211,255,107,97,69,207,108,22,120,226,10,160,238,210,13,215,84,131,4,78,194,179,3,57,97,38,103,167,247,22,96,208,77,71,105,73,219,119,110,62,74,106,209,174,220,90,214,217,102,11,223,64,240,59,216,55,83,174,188,169,197,158,187,222,127,207,178,71,233,255,181,48,28,242,189,189,138,194,186,202,48,147,179,83,166,163,180,36,5,54,208,186,147,6,215,205,41,87,222,84,191,103,217,35,46,122,102,179,184,74,97,196,2,27,104,93,148,43,111,42,55,190,11,180,161,142,12,195,27,223,5,90,141,239,2,45,0,0,0,0,65,49,27,25,130,98,54,50,195,83,45,43,4,197,108,100,69,244,119,125,134,167,90,86,199,150,65,79,8,138,217,200,73,187,194,209,138,232,239,250,203,217,244,227,12,79,181,172,77,126,174,181,142,45,131,158,207,28,152,135,81,18,194,74,16,35,217,83,211,112,244,120,146,65,239,97,85,215,174,46,20,230,181,55,215,181,152,28,150,132,131,5,89,152,27,130,24,169,0,155,219,250,45,176,154,203,54,169,93,93,119,230,28,108,108,255,223,63,65,212,158,14,90,205,162,36,132,149,227,21,159,140,32,70,178,167,97,119,169,190,166,225,232,241,231,208,243,232,36,131,222,195,101,178,197,218,170,174,93,93,235,159,70,68,40,204,107,111,105,253,112,118,174,107,49,57,239,90,42,32,44,9,7,11,109,56,28,18,243,54,70,223,178,7,93,198,113,84,112,237,48,101,107,244,247,243,42,187,182,194,49,162,117,145,28,137,52,160,7,144,251,188,159,23,186,141,132,14,121,222,169,37,56,239,178,60,255,121,243,115,190,72,232,106,125,27,197,65,60,42,222,88,5,79,121,240,68,126,98,233,135,45,79,194,198,28,84,219,1,138,21,148,64,187,14,141,131,232,35,166,194,217,56,191,13,197,160,56,76,244,187,33,143,167,150,10,206,150,141,19,9,0,204,92,72,49,215,69,139,98,250,110,202,83,225,119,84,93,187,186,21,108,160,163,214,63,141,136,151,14,150,145,80,152,215,222,17,169,204,199,210,250,225,236,147,203,250,245,92,215,98,114,29,230,121,107,222,181,84,64,159,132,79,89,88,18,14,22,25,35,21,15,218,112,56,36,155,65,35,61,167,107,253,101,230,90,230,124,37,9,203,87,100,56,208,78,163,174,145,1,226,159,138,24,33,204,167,51,96,253,188,42,175,225,36,173,238,208,63,180,45,131,18,159,108,178,9,134,171,36,72,201,234,21,83,208,41,70,126,251,104,119,101,226,246,121,63,47,183,72,36,54,116,27,9,29,53,42,18,4,242,188,83,75,179,141,72,82,112,222,101,121,49,239,126,96,254,243,230,231,191,194,253,254,124,145,208,213,61,160,203,204,250,54,138,131,187,7,145,154,120,84,188,177,57,101,167,168,75,152,131,59,10,169,152,34,201,250,181,9,136,203,174,16,79,93,239,95,14,108,244,70,205,63,217,109,140,14,194,116,67,18,90,243,2,35,65,234,193,112,108,193,128,65,119,216,71,215,54,151,6,230,45,142,197,181,0,165,132,132,27,188,26,138,65,113,91,187,90,104,152,232,119,67,217,217,108,90,30,79,45,21,95,126,54,12,156,45,27,39,221,28,0,62,18,0,152,185,83,49,131,160,144,98,174,139,209,83,181,146,22,197,244,221,87,244,239,196,148,167,194,239,213,150,217,246,233,188,7,174,168,141,28,183,107,222,49,156,42,239,42,133,237,121,107,202,172,72,112,211,111,27,93,248,46,42,70,225,225,54,222,102,160,7,197,127,99,84,232,84,34,101,243,77,229,243,178,2,164,194,169,27,103,145,132,48,38,160,159,41,184,174,197,228,249,159,222,253,58,204,243,214,123,253,232,207,188,107,169,128,253,90,178,153,62,9,159,178,127,56,132,171,176,36,28,44,241,21,7,53,50,70,42,30,115,119,49,7,180,225,112,72,245,208,107,81,54,131,70,122,119,178,93,99,78,215,250,203,15,230,225,210,204,181,204,249,141,132,215,224,74,18,150,175,11,35,141,182,200,112,160,157,137,65,187,132,70,93,35,3,7,108,56,26,196,63,21,49,133,14,14,40,66,152,79,103,3,169,84,126,192,250,121,85,129,203,98,76,31,197,56,129,94,244,35,152,157,167,14,179,220,150,21,170,27,0,84,229,90,49,79,252,153,98,98,215,216,83,121,206,23,79,225,73,86,126,250,80,149,45,215,123,212,28,204,98,19,138,141,45,82,187,150,52,145,232,187,31,208,217,160,6,236,243,126,94,173,194,101,71,110,145,72,108,47,160,83,117,232,54,18,58,169,7,9,35,106,84,36,8,43,101,63,17,228,121,167,150,165,72,188,143,102,27,145,164,39,42,138,189,224,188,203,242,161,141,208,235,98,222,253,192,35,239,230,217,189,225,188,20,252,208,167,13,63,131,138,38,126,178,145,63,185,36,208,112,248,21,203,105,59,70,230,66,122,119,253,91,181,107,101,220,244,90,126,197,55,9,83,238,118,56,72,247,177,174,9,184,240,159,18,161,51,204,63,138,114,253,36,147,0,0,0,0,55,106,194,1,110,212,132,3,89,190,70,2,220,168,9,7,235,194,203,6,178,124,141,4,133,22,79,5,184,81,19,14,143,59,209,15,214,133,151,13,225,239,85,12,100,249,26,9,83,147,216,8,10,45,158,10,61,71,92,11,112,163,38,28,71,201,228,29,30,119,162,31,41,29,96,30,172,11,47,27,155,97,237,26,194,223,171,24,245,181,105,25,200,242,53,18,255,152,247,19,166,38,177,17,145,76,115,16,20,90,60,21,35,48,254,20,122,142,184,22,77,228,122,23,224,70,77,56,215,44,143,57,142,146,201,59,185,248,11,58,60,238,68,63,11,132,134,62,82,58,192,60,101,80,2,61,88,23,94,54,111,125,156,55,54,195,218,53,1,169,24,52,132,191,87,49,179,213,149,48,234,107,211,50,221,1,17,51,144,229,107,36,167,143,169,37,254,49,239,39,201,91,45,38,76,77,98,35,123,39,160,34,34,153,230,32,21,243,36,33,40,180,120,42,31,222,186,43,70,96,252,41,113,10,62,40,244,28,113,45,195,118,179,44,154,200,245,46,173,162,55,47,192,141,154,112,247,231,88,113,174,89,30,115,153,51,220,114,28,37,147,119,43,79,81,118,114,241,23,116,69,155,213,117,120,220,137,126,79,182,75,127,22,8,13,125,33,98,207,124,164,116,128,121,147,30,66,120,202,160,4,122,253,202,198,123,176,46,188,108,135,68,126,109,222,250,56,111,233,144,250,110,108,134,181,107,91,236,119,106,2,82,49,104,53,56,243,105,8,127,175,98,63,21,109,99,102,171,43,97,81,193,233,96,212,215,166,101,227,189,100,100,186,3,34,102,141,105,224,103,32,203,215,72,23,161,21,73,78,31,83,75,121,117,145,74,252,99,222,79,203,9,28,78,146,183,90,76,165,221,152,77,152,154,196,70,175,240,6,71,246,78,64,69,193,36,130,68,68,50,205,65,115,88,15,64,42,230,73,66,29,140,139,67,80,104,241,84,103,2,51,85,62,188,117,87,9,214,183,86,140,192,248,83,187,170,58,82,226,20,124,80,213,126,190,81,232,57,226,90,223,83,32,91,134,237,102,89,177,135,164,88,52,145,235,93,3,251,41,92,90,69,111,94,109,47,173,95,128,27,53,225,183,113,247,224,238,207,177,226,217,165,115,227,92,179,60,230,107,217,254,231,50,103,184,229,5,13,122,228,56,74,38,239,15,32,228,238,86,158,162,236,97,244,96,237,228,226,47,232,211,136,237,233,138,54,171,235,189,92,105,234,240,184,19,253,199,210,209,252,158,108,151,254,169,6,85,255,44,16,26,250,27,122,216,251,66,196,158,249,117,174,92,248,72,233,0,243,127,131,194,242,38,61,132,240,17,87,70,241,148,65,9,244,163,43,203,245,250,149,141,247,205,255,79,246,96,93,120,217,87,55,186,216,14,137,252,218,57,227,62,219,188,245,113,222,139,159,179,223,210,33,245,221,229,75,55,220,216,12,107,215,239,102,169,214,182,216,239,212,129,178,45,213,4,164,98,208,51,206,160,209,106,112,230,211,93,26,36,210,16,254,94,197,39,148,156,196,126,42,218,198,73,64,24,199,204,86,87,194,251,60,149,195,162,130,211,193,149,232,17,192,168,175,77,203,159,197,143,202,198,123,201,200,241,17,11,201,116,7,68,204,67,109,134,205,26,211,192,207,45,185,2,206,64,150,175,145,119,252,109,144,46,66,43,146,25,40,233,147,156,62,166,150,171,84,100,151,242,234,34,149,197,128,224,148,248,199,188,159,207,173,126,158,150,19,56,156,161,121,250,157,36,111,181,152,19,5,119,153,74,187,49,155,125,209,243,154,48,53,137,141,7,95,75,140,94,225,13,142,105,139,207,143,236,157,128,138,219,247,66,139,130,73,4,137,181,35,198,136,136,100,154,131,191,14,88,130,230,176,30,128,209,218,220,129,84,204,147,132,99,166,81,133,58,24,23,135,13,114,213,134,160,208,226,169,151,186,32,168,206,4,102,170,249,110,164,171,124,120,235,174,75,18,41,175,18,172,111,173,37,198,173,172,24,129,241,167,47,235,51,166,118,85,117,164,65,63,183,165,196,41,248,160,243,67,58,161,170,253,124,163,157,151,190,162,208,115,196,181,231,25,6,180,190,167,64,182,137,205,130,183,12,219,205,178,59,177,15,179,98,15,73,177,85,101,139,176,104,34,215,187,95,72,21,186,6,246,83,184,49,156,145,185,180,138,222,188,131,224,28,189,218,94,90,191,237,52,152,190,0,0,0,0,101,103,188,184,139,200,9,170,238,175,181,18,87,151,98,143,50,240,222,55,220,95,107,37,185,56,215,157,239,40,180,197,138,79,8,125,100,224,189,111,1,135,1,215,184,191,214,74,221,216,106,242,51,119,223,224,86,16,99,88,159,87,25,80,250,48,165,232,20,159,16,250,113,248,172,66,200,192,123,223,173,167,199,103,67,8,114,117,38,111,206,205,112,127,173,149,21,24,17,45,251,183,164,63,158,208,24,135,39,232,207,26,66,143,115,162,172,32,198,176,201,71,122,8,62,175,50,160,91,200,142,24,181,103,59,10,208,0,135,178,105,56,80,47,12,95,236,151,226,240,89,133,135,151,229,61,209,135,134,101,180,224,58,221,90,79,143,207,63,40,51,119,134,16,228,234,227,119,88,82,13,216,237,64,104,191,81,248,161,248,43,240,196,159,151,72,42,48,34,90,79,87,158,226,246,111,73,127,147,8,245,199,125,167,64,213,24,192,252,109,78,208,159,53,43,183,35,141,197,24,150,159,160,127,42,39,25,71,253,186,124,32,65,2,146,143,244,16,247,232,72,168,61,88,20,155,88,63,168,35,182,144,29,49,211,247,161,137,106,207,118,20,15,168,202,172,225,7,127,190,132,96,195,6,210,112,160,94,183,23,28,230,89,184,169,244,60,223,21,76,133,231,194,209,224,128,126,105,14,47,203,123,107,72,119,195,162,15,13,203,199,104,177,115,41,199,4,97,76,160,184,217,245,152,111,68,144,255,211,252,126,80,102,238,27,55,218,86,77,39,185,14,40,64,5,182,198,239,176,164,163,136,12,28,26,176,219,129,127,215,103,57,145,120,210,43,244,31,110,147,3,247,38,59,102,144,154,131,136,63,47,145,237,88,147,41,84,96,68,180,49,7,248,12,223,168,77,30,186,207,241,166,236,223,146,254,137,184,46,70,103,23,155,84,2,112,39,236,187,72,240,113,222,47,76,201,48,128,249,219,85,231,69,99,156,160,63,107,249,199,131,211,23,104,54,193,114,15,138,121,203,55,93,228,174,80,225,92,64,255,84,78,37,152,232,246,115,136,139,174,22,239,55,22,248,64,130,4,157,39,62,188,36,31,233,33,65,120,85,153,175,215,224,139,202,176,92,51,59,182,89,237,94,209,229,85,176,126,80,71,213,25,236,255,108,33,59,98,9,70,135,218,231,233,50,200,130,142,142,112,212,158,237,40,177,249,81,144], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1619480);
/* memory initializer */ allocate([95,86,228,130,58,49,88,58,131,9,143,167,230,110,51,31,8,193,134,13,109,166,58,181,164,225,64,189,193,134,252,5,47,41,73,23,74,78,245,175,243,118,34,50,150,17,158,138,120,190,43,152,29,217,151,32,75,201,244,120,46,174,72,192,192,1,253,210,165,102,65,106,28,94,150,247,121,57,42,79,151,150,159,93,242,241,35,229,5,25,107,77,96,126,215,245,142,209,98,231,235,182,222,95,82,142,9,194,55,233,181,122,217,70,0,104,188,33,188,208,234,49,223,136,143,86,99,48,97,249,214,34,4,158,106,154,189,166,189,7,216,193,1,191,54,110,180,173,83,9,8,21,154,78,114,29,255,41,206,165,17,134,123,183,116,225,199,15,205,217,16,146,168,190,172,42,70,17,25,56,35,118,165,128,117,102,198,216,16,1,122,96,254,174,207,114,155,201,115,202,34,241,164,87,71,150,24,239,169,57,173,253,204,94,17,69,6,238,77,118,99,137,241,206,141,38,68,220,232,65,248,100,81,121,47,249,52,30,147,65,218,177,38,83,191,214,154,235,233,198,249,179,140,161,69,11,98,14,240,25,7,105,76,161,190,81,155,60,219,54,39,132,53,153,146,150,80,254,46,46,153,185,84,38,252,222,232,158,18,113,93,140,119,22,225,52,206,46,54,169,171,73,138,17,69,230,63,3,32,129,131,187,118,145,224,227,19,246,92,91,253,89,233,73,152,62,85,241,33,6,130,108,68,97,62,212,170,206,139,198,207,169,55,126,56,65,127,214,93,38,195,110,179,137,118,124,214,238,202,196,111,214,29,89,10,177,161,225,228,30,20,243,129,121,168,75,215,105,203,19,178,14,119,171,92,161,194,185,57,198,126,1,128,254,169,156,229,153,21,36,11,54,160,54,110,81,28,142,167,22,102,134,194,113,218,62,44,222,111,44,73,185,211,148,240,129,4,9,149,230,184,177,123,73,13,163,30,46,177,27,72,62,210,67,45,89,110,251,195,246,219,233,166,145,103,81,31,169,176,204,122,206,12,116,148,97,185,102,241,6,5,222,0,0,0,0,119,7,48,150,238,14,97,44,153,9,81,186,7,109,196,25,112,106,244,143,233,99,165,53,158,100,149,163,14,219,136,50,121,220,184,164,224,213,233,30,151,210,217,136,9,182,76,43,126,177,124,189,231,184,45,7,144,191,29,145,29,183,16,100,106,176,32,242,243,185,113,72,132,190,65,222,26,218,212,125,109,221,228,235,244,212,181,81,131,211,133,199,19,108,152,86,100,107,168,192,253,98,249,122,138,101,201,236,20,1,92,79,99,6,108,217,250,15,61,99,141,8,13,245,59,110,32,200,76,105,16,94,213,96,65,228,162,103,113,114,60,3,228,209,75,4,212,71,210,13,133,253,165,10,181,107,53,181,168,250,66,178,152,108,219,187,201,214,172,188,249,64,50,216,108,227,69,223,92,117,220,214,13,207,171,209,61,89,38,217,48,172,81,222,0,58,200,215,81,128,191,208,97,22,33,180,244,181,86,179,196,35,207,186,149,153,184,189,165,15,40,2,184,158,95,5,136,8,198,12,217,178,177,11,233,36,47,111,124,135,88,104,76,17,193,97,29,171,182,102,45,61,118,220,65,144,1,219,113,6,152,210,32,188,239,213,16,42,113,177,133,137,6,182,181,31,159,191,228,165,232,184,212,51,120,7,201,162,15,0,249,52,150,9,168,142,225,14,152,24,127,106,13,187,8,109,61,45,145,100,108,151,230,99,92,1,107,107,81,244,28,108,97,98,133,101,48,216,242,98,0,78,108,6,149,237,27,1,165,123,130,8,244,193,245,15,196,87,101,176,217,198,18,183,233,80,139,190,184,234,252,185,136,124,98,221,29,223,21,218,45,73,140,211,124,243,251,212,76,101,77,178,97,88,58,181,81,206,163,188,0,116,212,187,48,226,74,223,165,65,61,216,149,215,164,209,196,109,211,214,244,251,67,105,233,106,52,110,217,252,173,103,136,70,218,96,184,208,68,4,45,115,51,3,29,229,170,10,76,95,221,13,124,201,80,5,113,60,39,2,65,170,190,11,16,16,201,12,32,134,87,104,181,37,32,111,133,179,185,102,212,9,206,97,228,159,94,222,249,14,41,217,201,152,176,208,152,34,199,215,168,180,89,179,61,23,46,180,13,129,183,189,92,59,192,186,108,173,237,184,131,32,154,191,179,182,3,182,226,12,116,177,210,154,234,213,71,57,157,210,119,175,4,219,38,21,115,220,22,131,227,99,11,18,148,100,59,132,13,109,106,62,122,106,90,168,228,14,207,11,147,9,255,157,10,0,174,39,125,7,158,177,240,15,147,68,135,8,163,210,30,1,242,104,105,6,194,254,247,98,87,93,128,101,103,203,25,108,54,113,110,107,6,231,254,212,27,118,137,211,43,224,16,218,122,90,103,221,74,204,249,185,223,111,142,190,239,249,23,183,190,67,96,176,142,213,214,214,163,232,161,209,147,126,56,216,194,196,79,223,242,82,209,187,103,241,166,188,87,103,63,181,6,221,72,178,54,75,216,13,43,218,175,10,27,76,54,3,74,246,65,4,122,96,223,96,239,195,168,103,223,85,49,110,142,239,70,105,190,121,203,97,179,140,188,102,131,26,37,111,210,160,82,104,226,54,204,12,119,149,187,11,71,3,34,2,22,185,85,5,38,47,197,186,59,190,178,189,11,40,43,180,90,146,92,179,106,4,194,215,255,167,181,208,207,49,44,217,158,139,91,222,174,29,155,100,194,176,236,99,242,38,117,106,163,156,2,109,147,10,156,9,6,169,235,14,54,63,114,7,103,133,5,0,87,19,149,191,74,130,226,184,122,20,123,177,43,174,12,182,27,56,146,210,142,155,229,213,190,13,124,220,239,183,11,219,223,33,134,211,210,212,241,212,226,66,104,221,179,248,31,218,131,110,129,190,22,205,246,185,38,91,111,176,119,225,24,183,71,119,136,8,90,230,255,15,106,112,102,6,59,202,17,1,11,92,143,101,158,255,248,98,174,105,97,107,255,211,22,108,207,69,160,10,226,120,215,13,210,238,78,4,131,84,57,3,179,194,167,103,38,97,208,96,22,247,73,105,71,77,62,110,119,219,174,209,106,74,217,214,90,220,64,223,11,102,55,216,59,240,169,188,174,83,222,187,158,197,71,178,207,127,48,181,255,233,189,189,242,28,202,186,194,138,83,179,147,48,36,180,163,166,186,208,54,5,205,215,6,147,84,222,87,41,35,217,103,191,179,102,122,46,196,97,74,184,93,104,27,2,42,111,43,148,180,11,190,55,195,12,142,161,90,5,223,27,45,2,239,141,0,0,0,0,25,27,49,65,50,54,98,130,43,45,83,195,100,108,197,4,125,119,244,69,86,90,167,134,79,65,150,199,200,217,138,8,209,194,187,73,250,239,232,138,227,244,217,203,172,181,79,12,181,174,126,77,158,131,45,142,135,152,28,207,74,194,18,81,83,217,35,16,120,244,112,211,97,239,65,146,46,174,215,85,55,181,230,20,28,152,181,215,5,131,132,150,130,27,152,89,155,0,169,24,176,45,250,219,169,54,203,154,230,119,93,93,255,108,108,28,212,65,63,223,205,90,14,158,149,132,36,162,140,159,21,227,167,178,70,32,190,169,119,97,241,232,225,166,232,243,208,231,195,222,131,36,218,197,178,101,93,93,174,170,68,70,159,235,111,107,204,40,118,112,253,105,57,49,107,174,32,42,90,239,11,7,9,44,18,28,56,109,223,70,54,243,198,93,7,178,237,112,84,113,244,107,101,48,187,42,243,247,162,49,194,182,137,28,145,117,144,7,160,52,23,159,188,251,14,132,141,186,37,169,222,121,60,178,239,56,115,243,121,255,106,232,72,190,65,197,27,125,88,222,42,60,240,121,79,5,233,98,126,68,194,79,45,135,219,84,28,198,148,21,138,1,141,14,187,64,166,35,232,131,191,56,217,194,56,160,197,13,33,187,244,76,10,150,167,143,19,141,150,206,92,204,0,9,69,215,49,72,110,250,98,139,119,225,83,202,186,187,93,84,163,160,108,21,136,141,63,214,145,150,14,151,222,215,152,80,199,204,169,17,236,225,250,210,245,250,203,147,114,98,215,92,107,121,230,29,64,84,181,222,89,79,132,159,22,14,18,88,15,21,35,25,36,56,112,218,61,35,65,155,101,253,107,167,124,230,90,230,87,203,9,37,78,208,56,100,1,145,174,163,24,138,159,226,51,167,204,33,42,188,253,96,173,36,225,175,180,63,208,238,159,18,131,45,134,9,178,108,201,72,36,171,208,83,21,234,251,126,70,41,226,101,119,104,47,63,121,246,54,36,72,183,29,9,27,116,4,18,42,53,75,83,188,242,82,72,141,179,121,101,222,112,96,126,239,49,231,230,243,254,254,253,194,191,213,208,145,124,204,203,160,61,131,138,54,250,154,145,7,187,177,188,84,120,168,167,101,57,59,131,152,75,34,152,169,10,9,181,250,201,16,174,203,136,95,239,93,79,70,244,108,14,109,217,63,205,116,194,14,140,243,90,18,67,234,65,35,2,193,108,112,193,216,119,65,128,151,54,215,71,142,45,230,6,165,0,181,197,188,27,132,132,113,65,138,26,104,90,187,91,67,119,232,152,90,108,217,217,21,45,79,30,12,54,126,95,39,27,45,156,62,0,28,221,185,152,0,18,160,131,49,83,139,174,98,144,146,181,83,209,221,244,197,22,196,239,244,87,239,194,167,148,246,217,150,213,174,7,188,233,183,28,141,168,156,49,222,107,133,42,239,42,202,107,121,237,211,112,72,172,248,93,27,111,225,70,42,46,102,222,54,225,127,197,7,160,84,232,84,99,77,243,101,34,2,178,243,229,27,169,194,164,48,132,145,103,41,159,160,38,228,197,174,184,253,222,159,249,214,243,204,58,207,232,253,123,128,169,107,188,153,178,90,253,178,159,9,62,171,132,56,127,44,28,36,176,53,7,21,241,30,42,70,50,7,49,119,115,72,112,225,180,81,107,208,245,122,70,131,54,99,93,178,119,203,250,215,78,210,225,230,15,249,204,181,204,224,215,132,141,175,150,18,74,182,141,35,11,157,160,112,200,132,187,65,137,3,35,93,70,26,56,108,7,49,21,63,196,40,14,14,133,103,79,152,66,126,84,169,3,85,121,250,192,76,98,203,129,129,56,197,31,152,35,244,94,179,14,167,157,170,21,150,220,229,84,0,27,252,79,49,90,215,98,98,153,206,121,83,216,73,225,79,23,80,250,126,86,123,215,45,149,98,204,28,212,45,141,138,19,52,150,187,82,31,187,232,145,6,160,217,208,94,126,243,236,71,101,194,173,108,72,145,110,117,83,160,47,58,18,54,232,35,9,7,169,8,36,84,106,17,63,101,43,150,167,121,228,143,188,72,165,164,145,27,102,189,138,42,39,242,203,188,224,235,208,141,161,192,253,222,98,217,230,239,35,20,188,225,189,13,167,208,252,38,138,131,63,63,145,178,126,112,208,36,185,105,203,21,248,66,230,70,59,91,253,119,122,220,101,107,181,197,126,90,244,238,83,9,55,247,72,56,118,184,9,174,177,161,18,159,240,138,63,204,51,147,36,253,114,0,0,0,0,1,194,106,55,3,132,212,110,2,70,190,89,7,9,168,220,6,203,194,235,4,141,124,178,5,79,22,133,14,19,81,184,15,209,59,143,13,151,133,214,12,85,239,225,9,26,249,100,8,216,147,83,10,158,45,10,11,92,71,61,28,38,163,112,29,228,201,71,31,162,119,30,30,96,29,41,27,47,11,172,26,237,97,155,24,171,223,194,25,105,181,245,18,53,242,200,19,247,152,255,17,177,38,166,16,115,76,145,21,60,90,20,20,254,48,35,22,184,142,122,23,122,228,77,56,77,70,224,57,143,44,215,59,201,146,142,58,11,248,185,63,68,238,60,62,134,132,11,60,192,58,82,61,2,80,101,54,94,23,88,55,156,125,111,53,218,195,54,52,24,169,1,49,87,191,132,48,149,213,179,50,211,107,234,51,17,1,221,36,107,229,144,37,169,143,167,39,239,49,254,38,45,91,201,35,98,77,76,34,160,39,123,32,230,153,34,33,36,243,21,42,120,180,40,43,186,222,31,41,252,96,70,40,62,10,113,45,113,28,244,44,179,118,195,46,245,200,154,47,55,162,173,112,154,141,192,113,88,231,247,115,30,89,174,114,220,51,153,119,147,37,28,118,81,79,43,116,23,241,114,117,213,155,69,126,137,220,120,127,75,182,79,125,13,8,22,124,207,98,33,121,128,116,164,120,66,30,147,122,4,160,202,123,198,202,253,108,188,46,176,109,126,68,135,111,56,250,222,110,250,144,233,107,181,134,108,106,119,236,91,104,49,82,2,105,243,56,53,98,175,127,8,99,109,21,63,97,43,171,102,96,233,193,81,101,166,215,212,100,100,189,227,102,34,3,186,103,224,105,141,72,215,203,32,73,21,161,23,75,83,31,78,74,145,117,121,79,222,99,252,78,28,9,203,76,90,183,146,77,152,221,165,70,196,154,152,71,6,240,175,69,64,78,246,68,130,36,193,65,205,50,68,64,15,88,115,66,73,230,42,67,139,140,29,84,241,104,80,85,51,2,103,87,117,188,62,86,183,214,9,83,248,192,140,82,58,170,187,80,124,20,226,81,190,126,213,90,226,57,232,91,32,83,223,89,102,237,134,88,164,135,177,93,235,145,52,92,41,251,3,94,111,69,90,95,173,47,109,225,53,27,128,224,247,113,183,226,177,207,238,227,115,165,217,230,60,179,92,231,254,217,107,229,184,103,50,228,122,13,5,239,38,74,56,238,228,32,15,236,162,158,86,237,96,244,97,232,47,226,228,233,237,136,211,235,171,54,138,234,105,92,189,253,19,184,240,252,209,210,199,254,151,108,158,255,85,6,169,250,26,16,44,251,216,122,27,249,158,196,66,248,92,174,117,243,0,233,72,242,194,131,127,240,132,61,38,241,70,87,17,244,9,65,148,245,203,43,163,247,141,149,250,246,79,255,205,217,120,93,96,216,186,55,87,218,252,137,14,219,62,227,57,222,113,245,188,223,179,159,139,221,245,33,210,220,55,75,229,215,107,12,216,214,169,102,239,212,239,216,182,213,45,178,129,208,98,164,4,209,160,206,51,211,230,112,106,210,36,26,93,197,94,254,16,196,156,148,39,198,218,42,126,199,24,64,73,194,87,86,204,195,149,60,251,193,211,130,162,192,17,232,149,203,77,175,168,202,143,197,159,200,201,123,198,201,11,17,241,204,68,7,116,205,134,109,67,207,192,211,26,206,2,185,45,145,175,150,64,144,109,252,119,146,43,66,46,147,233,40,25,150,166,62,156,151,100,84,171,149,34,234,242,148,224,128,197,159,188,199,248,158,126,173,207,156,56,19,150,157,250,121,161,152,181,111,36,153,119,5,19,155,49,187,74,154,243,209,125,141,137,53,48,140,75,95,7,142,13,225,94,143,207,139,105,138,128,157,236,139,66,247,219,137,4,73,130,136,198,35,181,131,154,100,136,130,88,14,191,128,30,176,230,129,220,218,209,132,147,204,84,133,81,166,99,135,23,24,58,134,213,114,13,169,226,208,160,168,32,186,151,170,102,4,206,171,164,110,249,174,235,120,124,175,41,18,75,173,111,172,18,172,173,198,37,167,241,129,24,166,51,235,47,164,117,85,118,165,183,63,65,160,248,41,196,161,58,67,243,163,124,253,170,162,190,151,157,181,196,115,208,180,6,25,231,182,64,167,190,183,130,205,137,178,205,219,12,179,15,177,59,177,73,15,98,176,139,101,85,187,215,34,104,186,21,72,95,184,83,246,6,185,145,156,49,188,222,138,180,189,28,224,131,191,90,94,218,190,152,52,237,0,0,0,0,184,188,103,101,170,9,200,139,18,181,175,238,143,98,151,87,55,222,240,50,37,107,95,220,157,215,56,185,197,180,40,239,125,8,79,138,111,189,224,100,215,1,135,1,74,214,191,184,242,106,216,221,224,223,119,51,88,99,16,86,80,25,87,159,232,165,48,250,250,16,159,20,66,172,248,113,223,123,192,200,103,199,167,173,117,114,8,67,205,206,111,38,149,173,127,112,45,17,24,21,63,164,183,251,135,24,208,158,26,207,232,39,162,115,143,66,176,198,32,172,8,122,71,201,160,50,175,62,24,142,200,91,10,59,103,181,178,135,0,208,47,80,56,105,151,236,95,12,133,89,240,226,61,229,151,135,101,134,135,209,221,58,224,180,207,143,79,90,119,51,40,63,234,228,16,134,82,88,119,227,64,237,216,13,248,81,191,104,240,43,248,161,72,151,159,196,90,34,48,42,226,158,87,79,127,73,111,246,199,245,8,147,213,64,167,125,109,252,192,24,53,159,208,78,141,35,183,43,159,150,24,197,39,42,127,160,186,253,71,25,2,65,32,124,16,244,143,146,168,72,232,247,155,20,88,61,35,168,63,88,49,29,144,182,137,161,247,211,20,118,207,106,172,202,168,15,190,127,7,225,6,195,96,132,94,160,112,210,230,28,23,183,244,169,184,89,76,21,223,60,209,194,231,133,105,126,128,224,123,203,47,14,195,119,72,107,203,13,15,162,115,177,104,199,97,4,199,41,217,184,160,76,68,111,152,245,252,211,255,144,238,102,80,126,86,218,55,27,14,185,39,77,182,5,64,40,164,176,239,198,28,12,136,163,129,219,176,26,57,103,215,127,43,210,120,145,147,110,31,244,59,38,247,3,131,154,144,102,145,47,63,136,41,147,88,237,180,68,96,84,12,248,7,49,30,77,168,223,166,241,207,186,254,146,223,236,70,46,184,137,84,155,23,103,236,39,112,2,113,240,72,187,201,76,47,222,219,249,128,48,99,69,231,85,107,63,160,156,211,131,199,249,193,54,104,23,121,138,15,114,228,93,55,203,92,225,80,174,78,84,255,64,246,232,152,37,174,139,136,115,22,55,239,22,4,130,64,248,188,62,39,157,33,233,31,36,153,85,120,65,139,224,215,175,51,92,176,202,237,89,182,59,85,229,209,94,71,80,126,176,255,236,25,213,98,59,33,108,218,135,70,9,200,50,233,231,112,142,142,130,40,237,158,212,144,81,249,177,130,228,86,95,58,88,49,58,167,143,9,131,31,51,110,230,13,134,193,8,181,58,166,109,189,64,225,164,5,252,134,193,23,73,41,47,175,245,78,74,50,34,118,243,138,158,17,150,152,43,190,120,32,151,217,29,120,244,201,75,192,72,174,46,210,253,1,192,106,65,102,165,247,150,94,28,79,42,57,121,93,159,150,151,229,35,241,242,77,107,25,5,245,215,126,96,231,98,209,142,95,222,182,235,194,9,142,82,122,181,233,55,104,0,70,217,208,188,33,188,136,223,49,234,48,99,86,143,34,214,249,97,154,106,158,4,7,189,166,189,191,1,193,216,173,180,110,54,21,8,9,83,29,114,78,154,165,206,41,255,183,123,134,17,15,199,225,116,146,16,217,205,42,172,190,168,56,25,17,70,128,165,118,35,216,198,102,117,96,122,1,16,114,207,174,254,202,115,201,155,87,164,241,34,239,24,150,71,253,173,57,169,69,17,94,204,118,77,238,6,206,241,137,99,220,68,38,141,100,248,65,232,249,47,121,81,65,147,30,52,83,38,177,218,235,154,214,191,179,249,198,233,11,69,161,140,25,240,14,98,161,76,105,7,60,155,81,190,132,39,54,219,150,146,153,53,46,46,254,80,38,84,185,153,158,232,222,252,140,93,113,18,52,225,22,119,169,54,46,206,17,138,73,171,3,63,230,69,187,131,129,32,227,224,145,118,91,92,246,19,73,233,89,253,241,85,62,152,108,130,6,33,212,62,97,68,198,139,206,170,126,55,169,207,214,127,65,56,110,195,38,93,124,118,137,179,196,202,238,214,89,29,214,111,225,161,177,10,243,20,30,228,75,168,121,129,19,203,105,215,171,119,14,178,185,194,161,92,1,126,198,57,156,169,254,128,36,21,153,229,54,160,54,11,142,28,81,110,134,102,22,167,62,218,113,194,44,111,222,44,148,211,185,73,9,4,129,240,177,184,230,149,163,13,73,123,27,177,46,30,67,210,62,72,251,110,89,45,233,219,246,195,81,103,145,166,204,176,169,31,116,12,206,122,102,185,97,148,222,5,6,241,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,80,0,0,0,81,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,0,0,128,63,81,125,127,63,243,115,126,63,2,101,125,63,48,80,124,63,39,53,123,63,139,19,122,63,243,234,120,63,239,186,119,63,1,131,118,63,158,66,117,63,41,249,115,63,243,165,114,63,55,72,113,63,19,223,111,63,135,105,110,63,107,230,108,63,103,84,107,63,233,177,105,63,18,253,103,63,166,51,102,63,237,82,100,63,138,87,98,63,62,61,96,63,146,254,93,63,64,148,91,63,71,244,88,63,51,16,86,63,197,209,82,63,110,19,79,63,179,139,74,63,50,124,68,63,243,4,53,63,53,26,36,63,135,143,28,63,135,132,22,63,96,58,17,63,23,103,12,63,147,228,7,63,253,155,3,63,114,252,254,62,18,1,247,62,176,53,239,62,136,141,231,62,15,254,223,62,56,126,216,62,235,5,209,62,164,141,201,62,34,14,194,62,36,128,186,62,37,220,178,62,15,26,171,62,234,48,163,62,108,22,155,62,96,190,146,62,212,25,138,62,204,21,129,62,98,50,111,62,123,2,91,62,167,53,69,62,15,41,45,62,3,185,17,62,72,208,224,61,248,68,129,61,0,0,0,0,0,0,0,0,0,0,128,63,8,245,126,63,244,205,124,63,209,141,122,63,135,49,120,63,79,181,117,63,123,20,115,63,39,73,112,63,176,75,109,63,240,17,106,63,233,141,102,63,87,171,98,63,255,74,94,63,2,56,89,63,175,10,83,63,152,181,74,63,243,4,53,63,69,89,28,63,158,231,16,63,53,120,7,63,145,241,253,62,116,247,237,62,133,137,222,62,96,86,207,62,185,28,192,62,5,159,176,62,169,153,160,62,235,182,143,62,73,243,122,62,246,23,82,62,1,74,33,62,14,171,184,61,0,0,0,0,0,0,0,0,0,0,128,63,19,210,125,63,217,38,121,63,41,249,115,63,59,29,110,63,182,72,103,63,57,233,94,63,144,128,83,63,243,4,53,63,89,59,16,63,101,196,251,62,208,124,219,62,116,4,188,62,108,22,155,62,88,68,107,62,56,85,5,62,0,0,0,0,0,0,0,0,0,0,128,63,39,53,123,63,19,223,111,63,62,61,96,63,243,4,53,63,18,1,247,62,37,220,178,62,167,53,69,62,0,0,0,0,0,0,0,0,0,0,128,63,41,249,115,63,243,4,53,63,108,22,155,62,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,0,0,0,0,122,76,198,64,225,47,226,30,224,17,62,9,146,4,24,2,5,1,119,0,65,0,31,0,19,0,10,0,6,0,3,0,3,0,2,0,1,0,1,0,1,0,0,0,0,0,0,0,232,57,88,52,116,43,59,33,251,23,81,16,195,10,220,6,80,4,165,2,159,1,248,0,150,0,89,0,54,0,31,0,19,0,11,0,7,0,4,0,2,0,0,0,0,0,0,0,0,0,122,76,64,141,33,189,3,220,227,237,33,247,179,251,203,253,208,254,71,255,136,255,167,255,186,255,196,255,202,255,205,255,208,255,210,255,211,255,212,255,213,255,0,0,0,0,0,0,232,57,64,110,180,153,239,186,234,210,59,227,254,237,218,244,42,249,207,251,110,253,102,254,252,254,85,255,139,255,170,255,189,255,200,255,207,255,211,255,213,255,0,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,9,0,0,0,0,0,0,0,9,0,0,0,9,0,0,0,5,0,0,0,5,0,0,0,9,0,0,0,5,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,69,69,0,0,61,167,0,0,64,65,0,0,13,72,1,0,50,115,0,0,248,76,0,0,79,64,0,0,242,140,2,0,226,100,0,0,203,82,0,0,145,72,0,0,196,135,0,0,121,220,0,0,225,66,0,0,82,24,5,0,96,86,0,0,176,149,0,0,249,67,0,0,101,7,1,0,157,74,0,0,111,107,0,0,179,64,0,0,44,180,1,0,174,79,0,0,125,124,0,0,250,65,0,0,249,189,0,0,204,70,0,0,76,95,0,0,19,64,0,0,69,69,0,0,61,167,0,0,64,65,0,0,13,72,1,0,50,115,0,0,248,76,0,0,79,64,0,0,242,140,2,0,226,100,0,0,203,82,0,0,145,72,0,0,196,135,0,0,121,220,0,0,225,66,0,0,82,24,5,0,96,86,0,0,176,149,0,0,249,67,0,0,101,7,1,0,157,74,0,0,111,107,0,0,179,64,0,0,44,180,1,0,174,79,0,0,125,124,0,0,250,65,0,0,249,189,0,0,204,70,0,0,76,95,0,0,19,64,0,0,0,64,255,63,251,63,245,63,236,63,225,63,212,63,196,63,177,63,156,63,133,63,107,63,79,63,48,63,15,63,235,62,197,62,157,62,114,62,69,62,21,62,227,61,175,61,120,61,63,61,3,61,197,60,133,60,66,60,253,59,182,59,109,59,33,59,211,58,130,58,48,58,219,57,132,57,43,57,207,56,113,56,18,56,176,55,75,55,229,54,125,54,18,54,165,53,55,53,198,52,83,52,223,51,104,51,239,50,116,50,248,49,121,49,249,48,118,48,242,47,108,47,228,46,90,46,207,45,65,45,178,44,33,44,143,43,251,42,101,42,206,41,53,41,154,40,254,39,96,39,193,38,32,38,126,37,218,36,53,36,142,35,231,34,61,34,147,33,231,32,58,32,140,31,220,30,43,30,121,29,198,28,18,28,93,27,167,26,239,25,55,25,126,24,196,23,9,23,76,22,144,21,210,20,19,20,84,19,148,18,211,17,18,17,80,16,141,15,202,14,6,14,65,13,124,12,183,11,241,10,43,10,100,9,157,8,214,7,14,7,70,6,126,5,181,4,237,3,36,3,91,2,146,1,201,0,0,0,55,255,110,254,165,253,220,252,19,252,75,251,130,250,186,249,242,248,42,248,99,247,156,246,213,245,15,245,73,244,132,243,191,242,250,241,54,241,115,240,176,239,238,238,45,238,108,237,172,236,237,235,46,235,112,234,180,233,247,232,60,232,130,231,201,230,17,230,89,229,163,228,238,227,58,227,135,226,213,225,36,225,116,224,198,223,25,223,109,222,195,221,25,221,114,220,203,219,38,219,130,218,224,217,63,217,160,216,2,216,102,215,203,214,50,214,155,213,5,213,113,212,223,211,78,211,191,210,49,210,166,209,28,209,148,208,14,208,138,207,7,207,135,206,8,206,140,205,17,205,152,204,33,204,173,203,58,203,201,202,91,202,238,201,131,201,27,201,181,200,80,200,238,199,143,199,49,199,213,198,124,198,37,198,208,197,126,197,45,197,223,196,147,196,74,196,3,196,190,195,123,195,59,195,253,194,193,194,136,194,81,194,29,194,235,193,187,193,142,193,99,193,59,193,21,193,241,192,208,192,177,192,149,192,123,192,100,192,79,192,60,192,44,192,31,192,20,192,11,192,5,192,1,192,0,192,1,192,5,192,11,192,20,192,31,192,44,192,60,192,79,192,100,192,123,192,149,192,177,192,208,192,241,192,21,193,59,193,99,193,142,193,187,193,235,193,29,194,81,194,136,194,193,194,253,194,59,195,123,195,190,195,3,196,74,196,147,196,223,196,45,197,126,197,208,197,37,198,124,198,213,198,49,199,143,199,238,199,80,200,181,200,27,201,131,201,238,201,91,202,201,202,58,203,173,203,33,204,152,204,17,205,140,205,8,206,135,206,7,207,138,207,14,208,148,208,28,209,166,209,49,210,191,210,78,211,223,211,113,212,5,213,155,213,50,214,203,214,102,215,2,216,160,216,63,217,224,217,130,218,38,219,203,219,114,220,25,221,195,221,109,222,25,223,198,223,116,224,36,225,213,225,135,226,58,227,238,227,163,228,89,229,17,230,201,230,130,231,60,232,247,232,180,233,112,234,46,235,237,235,172,236,108,237,45,238,238,238,176,239,115,240,54,241,250,241,191,242,132,243,73,244,15,245,213,245,156,246,99,247,42,248,242,248,186,249,130,250,75,251,19,252,220,252,165,253,110,254,55,255,0,0,201,0,146,1,91,2,36,3,237,3,181,4,126,5,70,6,14,7,214,7,157,8,100,9,43,10,241,10,183,11,124,12,65,13,6,14,202,14,141,15,80,16,18,17,211,17,148,18,84,19,19,20,210,20,144,21,76,22,9,23,196,23,126,24,55,25,239,25,167,26,93,27,18,28,198,28,121,29,43,30,220,30,140,31,58,32,231,32,147,33,61,34,231,34,142,35,53,36,218,36,126,37,32,38,193,38,96,39,254,39,154,40,53,41,206,41,101,42,251,42,143,43,33,44,178,44,65,45,207,45,90,46,228,46,108,47,242,47,118,48,249,48,121,49,248,49,116,50,239,50,104,51,223,51,83,52,198,52,55,53,165,53,18,54,125,54,229,54,75,55,176,55,18,56,113,56,207,56,43,57,132,57,219,57,48,58,130,58,211,58,33,59,109,59,182,59,253,59,66,60,133,60,197,60,3,61,63,61,120,61,175,61,227,61,21,62,69,62,114,62,157,62,197,62,235,62,15,63,48,63,79,63,107,63,133,63,156,63,177,63,196,63,212,63,225,63,236,63,245,63,251,63,255,63,0,64,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,6,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,6,0,0,0,6,0,0,0,4,0,0,0,6,0,0,0,6,0,0,0,240,0,0,0,124,1,0,0,180,1,0,0,234,0,0,0,110,1,0,0,142,1,0,0,160,66,71,82,27,0,0,0,32,82,71,66,30,0,0,0,24,82,71,66,3,0,0,0,144,82,71,66,43,0,0,0,16,82,71,66,44,0,0,0,143,82,71,66,45,0,0,0,15,82,71,66,46,0,0,0,140,82,71,66,63,0,0,0,12,82,71,66,62,0,0,0,8,82,71,66,22,0,0,0,4,82,71,66,23,0,0,0,1,82,71,66,10,0,0,0,1,66,71,82,10,0,0,0,132,66,71,82,21,0,0,0,132,82,71,66,24,0,0,0,48,66,71,82,42,0,0,0,176,66,71,82,41,0,0,0,160,82,71,66,29,0,0,0,32,66,71,82,28,0,0,0,24,66,71,82,2,0,0,0,144,66,71,82,47,0,0,0,16,66,71,82,48,0,0,0,143,66,71,82,49,0,0,0,15,66,71,82,50,0,0,0,140,66,71,82,65,0,0,0,12,66,71,82,64,0,0,0,8,66,71,82,19,0,0,0,4,66,71,82,20,0,0,0,8,82,71,66,11,0,0,0,89,85,89,50,1,0,0,0,85,89,86,89,17,0,0,0,78,86,49,50,25,0,0,0,78,86,50,49,26,0,0,0,89,56,48,48,8,0,0,0,89,56,32,32,8,0,0,0,89,86,85,57,6,0,0,0,73,70,48,57,6,0,0,0,89,86,49,50,0,0,0,0,73,52,50,48,0,0,0,0,73,89,85,86,0,0,0,0,52,49,49,80,7,0,0,0,52,50,50,80,4,0,0,0,52,52,52,80,5,0,0,0,52,52,48,80,33,0,0,0,52,50,48,65,35,0,0,0,52,50,48,81,54,0,0,0,81,48,50,52,55,0,0,0,52,50,50,81,56,0,0,0,81,50,50,52,57,0,0,0,52,52,52,81,58,0,0,0,81,52,52,52,59,0,0,0,89,86,49,50,12,0,0,0,52,50,50,80,13,0,0,0,52,52,52,80,14,0,0,0,52,52,48,80,34,0,0,0,2,0,199,29,15,0,0,0,130,0,199,29,16,0,0,0,1,0,200,29,37,0,0,0,2,0,200,29,38,0,0,0,3,0,200,29,36,0,0,0,4,0,200,29,39,0,0,0,5,0,200,29,40,0,0,0,6,0,200,29,60,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,84,34,0,0,0,0,0,105,87,20,139,10,191,5,64,232,43,34,0,0,0,0,0,24,45,68,84,251,33,9,64,144,24,34,0,0,0,0,0,168,244,151,155,119,227,249,63,24,45,68,84,251,33,9,64,105,87,20,139,10,191,5,64,0,0,0,0,0,128,93,64,0,0,0,0,0,0,0,0,176,60,32,0,184,52,32,0,16,47,32,0,0,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,4,0,4,0,8,0,4,0,140,1,0,0,4,0,5,0,16,0,8,0,140,1,0,0,4,0,6,0,32,0,32,0,140,1,0,0,4,0,4,0,16,0,16,0,64,1,0,0,8,0,16,0,32,0,32,0,64,1,0,0,8,0,16,0,128,0,128,0,64,1,0,0,8,0,32,0,128,0,0,1,64,1,0,0,32,0,128,0,2,1,0,4,64,1,0,0,32,0,2,1,2,1,0,16,64,1,0,0,216,248,38,0,48,179,38,0,12,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,224,116,38,0,88,60,38,0,4,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,168,5,38,0,72,219,37,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,48,179,37,0,240,148,37,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,24,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,70,38,0,112,0,0,0,112,132,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,112,32,0,112,0,0,0,176,254,24,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,40,189,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,1,0,0,220,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,198,36,0,48,154,35,0,8,0,0,0,5,0,0,0,192,188,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,136,253,33,0,136,107,33,0,12,0,0,0,5,0,0,0,112,244,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,48,145,32,0,216,53,32,0,16,0,0,0,5,0,0,0,0,28,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,160,186,39,0,240,85,39,0,48,0,0,0,3,0,0,0,123,20,174,71,225,122,132,63,123,20,174,71,225,122,132,63,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,240,10,39,0,248,198,38,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,104,132,38,0,128,73,38,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,224,18,38,0,104,233,37,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,189,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,58,34,0,112,0,0,0,144,1,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,227,207,1,0,232,127,1,0,90,59,1,0,244,0,1,0,138,207,0,0,8,166,0,0,113,131,0,0,222,102,0,0,125,79,0,0,144,60,0,0,108,45,0,0,120,33,0,0,44,24,0,0,16,17,0,0,187,11,0,0,210,7,0,0,7,5,0,0,24,3,0,0,206,1,0,0,252,0,0,0,126,0,0,0,56,0,0,0,21,0,0,0,6,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,199,92,0,0,251,79,0,0,142,68,0,0,102,58,0,0,106,49,0,0,130,41,0,0,151,34,0,0,147,28,0,0,97,23,0,0,237,18,0,0,36,15,0,0,244,11,0,0,76,9,0,0,28,7,0,0,85,5,0,0,233,3,0,0,203,2,0,0,239,1,0,0,74,1,0,0,210,0,0,0,126,0,0,0,70,0,0,0,35,0,0,0,15,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,14,0,0,204,12,0,0,109,11,0,0,40,10,0,0,252,8,0,0,232,7,0,0,235,6,0,0,4,6,0,0,50,5,0,0,116,4,0,0,201,3,0,0,48,3,0,0,168,2,0,0,48,2,0,0,199,1,0,0,108,1,0,0,30,1,0,0,220,0,0,0,165,0,0,0,120,0,0,0,84,0,0,0,56,0,0,0,35,0,0,0,20,0,0,0,10,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,1,0,0,122,1,0,0,95,1,0,0,69,1,0,0,44,1,0,0,20,1,0,0,253,0,0,0,231,0,0,0,210,0,0,0,190,0,0,0,171,0,0,0,153,0,0,0,136,0,0,0,120,0,0,0,105,0,0,0,91,0,0,0,78,0,0,0,66,0,0,0,55,0,0,0,45,0,0,0,36,0,0,0,28,0,0,0,21,0,0,0,15,0,0,0,10,0,0,0,6,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,29,0,0,0,28,0,0,0,27,0,0,0,26,0,0,0,25,0,0,0,24,0,0,0,23,0,0,0,22,0,0,0,21,0,0,0,20,0,0,0,19,0,0,0,18,0,0,0,17,0,0,0,16,0,0,0,15,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1629720);
/* memory initializer */ allocate([1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,32,40,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,253,34,0,200,53,34,0,72,2,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,8,64,16,0,1,0,8,149,33,0,104,24,33,0,160,175,32,0,76,2,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,8,64,16,0,1,0,8,149,33,0,208,83,32,0,136,59,40,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,149,33,0,224,223,39,0,144,119,39,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,149,33,0,168,37,39,0,248,222,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,149,33,0,112,153,38,0,216,93,38,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,8,149,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,40,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,1,0,0,0,0,0,0,0,0,0,0,150,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,148,37,0,112,0,0,0,0,7,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,175,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,80,37,0,192,243,35,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,224,254,34,0,40,55,34,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,16,150,33,0,176,25,33,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,176,176,32,0,144,84,32,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,184,60,40,0,136,225,39,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,136,120,39,0,112,38,39,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,40,224,38,0,24,154,38,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,224,94,38,0,192,40,38,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,64,247,37,0,80,204,37,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,128,167,37,0,128,129,37,0,80,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,112,63,37,0,184,17,37,0,88,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,248,232,36,0,136,197,36,0,96,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,72,167,36,0,192,140,36,0,104,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,0,113,36,0,200,85,36,0,112,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,200,60,36,0,128,33,36,0,120,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,24,232,35,0,96,199,35,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,175,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,156,37,0,112,0,0,0,112,9,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,167,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,80,37,0,8,244,35,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,255,34,0,128,55,34,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,88,150,33,0,64,26,33,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,177,32,0,16,85,32,0,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,16,61,40,0,16,226,39,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,24,121,39,0,88,39,39,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,160,224,38,0,184,154,38,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,48,95,38,0,32,41,38,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,104,247,37,0,168,204,37,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,167,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,160,37,0,112,0,0,0,192,13,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,146,38,0,240,248,255,0,176,87,38,0,250,235,215,0,96,34,38,0,0,255,255,0,216,241,37,0,127,255,212,0,96,196,37,0,240,255,255,0,0,162,37,0,245,245,220,0,96,122,37,0,255,228,196,0,208,54,37,0,0,0,0,0,136,13,37,0,255,235,205,0,176,228,36,0,0,0,255,0,8,193,36,0,138,43,226,0,8,164,36,0,165,42,42,0,16,137,36,0,222,184,135,0,144,109,36,0,95,158,160,0,240,82,36,0,127,255,0,0,224,57,36,0,210,105,30,0,168,28,36,0,255,127,80,0,224,225,35,0,100,149,237,0,120,196,35,0,255,248,220,0,232,172,35,0,220,20,60,0,0,151,35,0,0,255,255,0,80,129,35,0,0,0,139,0,168,106,35,0,0,139,139,0,80,87,35,0,184,134,11,0,32,70,35,0,169,169,169,0,232,51,35,0,0,100,0,0,88,28,35,0,189,183,107,0,216,240,34,0,139,0,139,0,216,217,34,0,85,107,47,0,40,203,34,0,255,140,0,0,192,186,34,0,153,50,204,0,160,168,34,0,139,0,0,0,152,150,34,0,233,150,122,0,168,136,34,0,143,188,143,0,160,121,34,0,72,61,139,0,88,104,34,0,47,79,79,0,0,84,34,0,0,206,209,0,128,43,34,0,148,0,211,0,96,24,34,0,255,20,147,0,168,10,34,0,0,191,255,0,152,251,33,0,105,105,105,0,48,233,33,0,30,144,255,0,0,219,33,0,178,34,34,0,112,207,33,0,255,250,240,0,48,197,33,0,34,139,34,0,176,188,33,0,255,0,255,0,80,174,33,0,220,220,220,0,24,140,33,0,248,248,255,0,136,125,33,0,255,215,0,0,16,116,33,0,218,165,32,0,96,106,33,0,128,128,128,0,112,96,33,0,0,128,0,0,120,86,33,0,173,255,47,0,184,77,33,0,240,255,240,0,168,69,33,0,255,105,180,0,48,61,33,0,205,92,92,0,64,48,33,0,75,0,130,0,0,17,33,0,255,255,240,0,168,3,33,0,240,230,140,0,192,251,32,0,230,230,250,0,192,243,32,0,255,240,245,0,224,235,32,0,124,252,0,0,176,229,32,0,255,250,205,0,208,222,32,0,173,216,230,0,0,216,32,0,240,128,128,0,192,206,32,0,224,255,255,0,200,195,32,0,250,250,210,0,144,169,32,0,144,238,144,0,112,158,32,0,211,211,211,0,192,151,32,0,255,182,193,0,104,144,32,0,255,160,122,0,40,137,32,0,32,178,170,0,104,131,32,0,135,206,250,0,120,125,32,0,119,136,153,0,160,119,32,0,176,196,222,0,104,112,32,0,255,255,224,0,240,102,32,0,0,255,0,0,24,78,32,0,50,205,50,0,16,67,32,0,250,240,230,0,168,60,32,0,255,0,255,0,176,52,32,0,128,0,0,0,248,46,32,0,102,205,170,0,144,40,32,0,0,0,205,0,168,35,32,0,186,85,211,0,136,29,32,0,147,112,216,0,32,88,40,0,60,179,113,0,176,76,40,0,123,104,238,0,0,53,40,0,0,250,154,0,216,42,40,0,72,209,204,0,240,34,40,0,199,21,133,0,232,26,40,0,25,25,112,0,192,21,40,0,245,255,250,0,240,15,40,0,255,228,225,0,104,11,40,0,255,228,181,0,120,5,40,0,255,222,173,0,112,255,39,0,0,0,128,0,232,243,39,0,253,245,230,0,88,217,39,0,128,128,0,0,208,205,39,0,107,142,35,0,248,194,39,0,255,165,0,0,200,185,39,0,255,69,0,0,112,178,39,0,218,112,214,0,208,171,39,0,238,232,170,0,128,165,39,0,152,251,152,0,88,155,39,0,175,238,238,0,32,148,39,0,216,112,147,0,72,137,39,0,255,239,213,0,136,113,39,0,255,218,185,0,216,101,39,0,205,133,63,0,128,94,39,0,255,192,203,0,104,85,39,0,221,160,221,0,224,79,39,0,176,224,230,0,224,74,39,0,128,0,128,0,104,69,39,0,255,0,0,0,16,64,39,0,188,143,143,0,112,58,39,0,65,105,225,0,168,51,39,0,139,69,19,0,88,32,39,0,250,128,114,0,176,22,39,0,244,164,96,0,208,16,39,0,46,139,87,0,176,10,39,0,255,245,238,0,192,5,39,0,160,82,45,0,56,1,39,0,192,192,192,0,232,252,38,0,135,206,235,0,8,248,38,0,106,90,205,0,160,244,38,0,112,128,144,0,72,237,38,0,255,250,250,0,88,218,38,0,0,255,127,0,104,210,38,0,70,130,180,0,112,205,38,0,210,180,140,0,192,198,38,0,0,128,128,0,56,194,38,0,216,191,216,0,40,189,38,0,255,99,71,0,128,183,38,0,64,224,208,0,104,178,38,0,238,130,238,0,192,173,38,0,245,222,179,0,16,166,38,0,255,255,255,0,104,149,38,0,245,245,245,0,184,141,38,0,255,255,0,0,120,137,38,0,154,205,50,0,5,0,0,0,43,1,0,0,14,0,0,0,255,255,255,255,0,218,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,7,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,181,34,0,96,49,35,0,140,0,0,0,82,76,79,67,16,17,35,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,176,66,35,0,96,49,35,0,140,0,0,0,82,76,79,67,16,17,35,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,80,190,37,0,136,157,37,0,4,0,0,0,69,90,73,83,136,108,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,176,44,37,0,136,157,37,0,4,0,0,0,69,90,73,83,136,108,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,240,5,37,0,112,219,36,0,24,0,0,0,84,65,82,86,24,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,224,158,36,0,112,219,36,0,24,0,0,0,84,65,82,86,24,188,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,128,131,36,0,8,105,36,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,72,77,36,0,8,105,36,0,40,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,16,0,1,0,0,0,0,0,32,54,36,0,144,15,36,0,48,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,83,32,0,224,223,39,0,168,37,39,0,112,153,38,0,176,181,34,0,112,0,0,0,48,21,25,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,196,52,0,65,208,0,0,17,196,0,0,3,226,0,0,9,253,0,0,2,40,0,0,2,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,250,0,0,21,219,0,0,5,201,0,0,21,213,0,0,5,207,0,0,22,51,0,0,6,39,0,0,18,155,0,0,20,192,0,0,20,153,0,0,20,147,0,0,0,0,0,0,0,8,1,2,9,16,24,17,10,3,4,11,18,25,32,40,33,26,19,12,5,6,13,20,27,34,41,48,56,49,42,35,28,21,14,7,15,22,29,36,43,50,57,58,51,44,37,30,23,31,38,45,52,59,39,46,53,60,61,54,47,55,62,63,0,0,8,0,16,0,1,0,24,0,9,0,32,0,17,0,2,0,40,0,25,0,10,0,33,0,18,0,48,0,3,0,26,0,41,0,11,0,56,0,19,0,34,0,4,0,49,0,27,0,42,0,12,0,35,0,20,0,57,0,50,0,28,0,5,0,43,0,13,0,36,0,58,0,51,0,21,0,44,0,6,0,29,0,59,0,37,0,14,0,52,0,22,0,7,0,45,0,60,0,30,0,15,0,38,0,53,0,23,0,46,0,31,0,61,0,39,0,54,0,47,0,62,0,55,0,63,0,0,0,4,0,8,0,1,0,12,0,5,0,9,0,2,0,13,0,6,0,10,0,3,0,7,0,14,0,11,0,15,0,0,0,16,0,32,0,48,0,1,0,64,0,17,0,80,0,33,0,96,0,49,0,2,0,65,0,112,0,18,0,81,0,34,0,128,0,50,0,97,0,3,0,66,0,144,0,19,0,113,0,35,0,82,0,160,0,98,0,51,0,129,0,4,0,67,0,176,0,20,0,114,0,145,0,83,0,36,0,99,0,130,0,52,0,192,0,5,0,161,0,68,0,115,0,21,0,146,0,84,0,208,0,177,0,37,0,131,0,100,0,53,0,162,0,224,0,69,0,6,0,116,0,193,0,147,0,85,0,22,0,240,0,132,0,38,0,178,0,101,0,163,0,54,0,209,0,117,0,70,0,7,0,148,0,194,0,86,0,179,0,225,0,23,0,133,0,39,0,164,0,8,0,102,0,210,0,241,0,55,0,195,0,118,0,149,0,71,0,180,0,24,0,87,0,226,0,134,0,165,0,211,0,40,0,103,0,56,0,72,0,150,0,196,0,242,0,119,0,9,0,181,0,227,0,88,0,166,0,25,0,135,0,41,0,104,0,212,0,57,0,151,0,197,0,120,0,73,0,243,0,182,0,136,0,167,0,213,0,89,0,10,0,228,0,105,0,152,0,198,0,26,0,42,0,121,0,183,0,244,0,168,0,58,0,137,0,229,0,74,0,214,0,90,0,153,0,199,0,184,0,11,0,106,0,245,0,27,0,122,0,230,0,169,0,43,0,215,0,59,0,200,0,138,0,185,0,246,0,75,0,12,0,91,0,154,0,216,0,231,0,107,0,28,0,44,0,201,0,123,0,170,0,60,0,247,0,232,0,76,0,139,0,13,0,92,0,217,0,186,0,248,0,155,0,108,0,29,0,124,0,45,0,202,0,233,0,171,0,61,0,14,0,77,0,140,0,15,0,249,0,93,0,30,0,187,0,156,0,218,0,46,0,109,0,125,0,62,0,172,0,78,0,203,0,31,0,141,0,234,0,94,0,47,0,188,0,63,0,157,0,110,0,250,0,219,0,79,0,126,0,204,0,173,0,142,0,95,0,189,0,111,0,235,0,158,0,220,0,251,0,127,0,174,0,143,0,205,0,236,0,159,0,190,0,221,0,252,0,175,0,206,0,237,0,191,0,253,0,222,0,238,0,207,0,254,0,223,0,239,0,255,0,1,0,0,0,6,2,0,0,8,6,3,0,9,8,7,5,10,9,8,6,11,10,9,7,13,11,10,8,13,13,11,9,13,13,13,10,14,14,13,11,14,14,14,13,15,15,14,14,15,15,15,14,16,15,15,15,16,16,16,15,16,16,16,16,16,16,16,16,2,0,0,0,6,2,0,0,6,5,3,0,7,6,6,4,8,6,6,4,8,7,7,5,9,8,8,6,11,9,9,6,11,11,11,7,12,11,11,9,12,12,12,11,12,12,12,11,13,13,13,12,13,13,13,13,13,14,13,13,14,14,14,13,14,14,14,14,4,0,0,0,6,4,0,0,6,5,4,0,6,5,5,4,7,5,5,4,7,5,5,4,7,6,6,4,7,6,6,4,8,7,7,5,8,8,7,6,9,8,8,7,9,9,8,8,9,9,9,8,10,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,6,0,0,0,6,6,0,0,6,6,6,0,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,1,0,0,0,5,1,0,0,7,4,1,0,7,6,5,3,7,6,5,3,7,6,5,4,15,6,5,4,11,14,5,4,8,10,13,4,15,14,9,4,11,10,13,12,15,14,9,12,11,10,13,8,15,1,9,12,11,14,13,8,7,10,9,12,4,6,5,8,3,0,0,0,11,2,0,0,7,7,3,0,7,10,9,5,7,6,5,4,4,6,5,6,7,6,5,8,15,6,5,4,11,14,13,4,15,10,9,4,11,14,13,12,8,10,9,8,15,14,13,12,11,10,9,12,7,11,6,8,9,8,10,1,7,6,5,4,15,0,0,0,15,14,0,0,11,15,13,0,8,12,14,12,15,10,11,11,11,8,9,10,9,14,13,9,8,10,9,8,15,14,13,13,11,14,10,12,15,10,13,12,11,14,9,12,8,10,13,8,13,7,9,12,9,12,11,10,5,8,7,6,1,4,3,2,3,0,0,0,0,1,0,0,4,5,6,0,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,137,149,0,224,137,149,0,64,29,25,0,136,38,25,0,128,38,25,0,120,38,25,0,112,38,25,0,104,38,25,0,96,38,25,0,88,38,25,0,80,38,25,0,64,38,25,0,32,38,25,0,224,37,25,0,96,37,25,0,96,29,25,0,88,29,25,0,88,29,25,0,88,29,25,0,88,29,25,0,88,29,25,0,88,29,25,0,88,29,25,0,80,29,25,0,72,29,25,0,1,0,0,0,0,0,0,0,2,0,3,0,254,255,253,255,2,0,3,0,254,255,253,255,1,0,255,255,0,0,0,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,112,0,113,0,114,0,115,0,116,0,117,0,118,0,119,0,120,0,121,0,122,0,123,0,124,0,125,0,126,0,127,0,128,0,129,0,130,0,131,0,132,0,133,0,134,0,135,0,136,0,137,0,138,0,139,0,140,0,141,0,142,0,143,0,144,0,145,0,146,0,147,0,148,0,149,0,150,0,151,0,152,0,153,0,154,0,155,0,156,0,157,0,158,0,159,0,160,0,161,0,162,0,163,0,164,0,165,0,166,0,167,0,168,0,169,0,170,0,171,0,172,0,173,0,174,0,175,0,176,0,177,0,178,0,179,0,180,0,181,0,182,0,183,0,184,0,185,0,186,0,187,0,188,0,189,0,190,0,191,0,192,0,193,0,194,0,195,0,196,0,197,0,198,0,199,0,200,0,201,0,202,0,203,0,204,0,205,0,206,0,207,0,208,0,209,0,210,0,211,0,212,0,213,0,214,0,215,0,216,0,217,0,218,0,219,0,220,0,221,0,222,0,223,0,224,0,225,0,226,0,227,0,228,0,229,0,230,0,231,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,239,0,240,0,241,0,242,0,243,0,244,0,245,0,246,0,247,0,248,0,249,0,250,0,251,0,252,0,253,0,254,0,255,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,44,1,45,1,46,1,47,1,48,1,49,1,50,1,51,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,63,1,64,1,65,1,66,1,67,1,68,1,69,1,70,1,71,1,72,1,73,1,74,1,75,1,76,1,77,1,78,1,79,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,123,1,124,1,125,1,126,1,127,1,128,1,129,1,130,1,131,1,132,1,133,1,134,1,135,1,136,1,137,1,138,1,139,1,140,1,141,1,142,1,143,1,144,1,145,1,146,1,147,1,148,1,149,1,150,1,151,1,152,1,153,1,154,1,155,1,156,1,157,1,158,1,159,1,160,1,161,1,162,1,163,1,164,1,165,1,166,1,167,1,168,1,169,1,170,1,171,1,172,1,173,1,174,1,175,1,176,1,177,1,178,1,179,1,180,1,181,1,182,1,183,1,184,1,185,1,186,1,187,1,188,1,189,1,190,1,191,1,192,1,193,1,194,1,195,1,196,1,197,1,198,1,199,1,200,1,201,1,202,1,203,1,204,1,205,1,206,1,207,1,208,1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,1,0,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,2,9,2,10,2,11,2,12,2,13,2,14,2,15,2,16,2,17,2,18,2,19,2,20,2,21,2,22,2,23,2,24,2,25,2,26,2,27,2,28,2,29,2,30,2,31,2,32,2,33,2,34,2,35,2,36,2,37,2,38,2,39,2,40,2,41,2,42,2,43,2,44,2,45,2,46,2,47,2,48,2,49,2,50,2,51,2,52,2,53,2,54,2,55,2,56,2,57,2,58,2,59,2,60,2,61,2,62,2,63,2,64,2,65,2,66,2,67,2,68,2,187,255,186,255,185,255,184,255,183,255,182,255,181,255,180,255,179,255,178,255,177,255,176,255,175,255,174,255,173,255,172,255,171,255,170,255,169,255,168,255,167,255,166,255,165,255,164,255,163,255,162,255,161,255,160,255,159,255,158,255,157,255,156,255,155,255,154,255,153,255,152,255,151,255,150,255,149,255,148,255,147,255,146,255,145,255,144,255,143,255,142,255,141,255,140,255,139,255,138,255,137,255,136,255,135,255,134,255,133,255,132,255,131,255,130,255,129,255,128,255,127,255,126,255,125,255,124,255,123,255,122,255,121,255,120,255,119,255,118,255,117,255,116,255,115,255,114,255,113,255,112,255,111,255,110,255,109,255,108,255,107,255,106,255,105,255,104,255,103,255,102,255,101,255,100,255,99,255,98,255,97,255,96,255,95,255,94,255,93,255,92,255,91,255,90,255,89,255,88,255,87,255,86,255,85,255,84,255,83,255,82,255,81,255,80,255,79,255,78,255,77,255,76,255,75,255,74,255,73,255,72,255,71,255,70,255,69,255,68,255,67,255,66,255,65,255,64,255,63,255,62,255,61,255,60,255,59,255,58,255,57,255,56,255,55,255,54,255,53,255,52,255,51,255,50,255,49,255,48,255,47,255,46,255,45,255,44,255,43,255,42,255,41,255,40,255,39,255,38,255,37,255,36,255,35,255,34,255,33,255,32,255,31,255,30,255,29,255,28,255,27,255,26,255,25,255,24,255,23,255,22,255,21,255,20,255,19,255,18,255,17,255,16,255,15,255,14,255,13,255,12,255,11,255,10,255,9,255,8,255,7,255,6,255,5,255,4,255,3,255,2,255,1,255,0,255,255,254,254,254,253,254,252,254,251,254,250,254,249,254,248,254,247,254,246,254,245,254,244,254,243,254,242,254,241,254,240,254,239,254,238,254,237,254,236,254,235,254,234,254,233,254,232,254,231,254,230,254,229,254,228,254,227,254,226,254,225,254,224,254,223,254,222,254,221,254,220,254,219,254,218,254,217,254,216,254,215,254,214,254,213,254,212,254,211,254,210,254,209,254,208,254,207,254,206,254,205,254,204,254,203,254,202,254,201,254,200,254,199,254,198,254,197,254,196,254,195,254,194,254,193,254,192,254,191,254,190,254,189,254,188,254,187,254,186,254,185,254,184,254,183,254,182,254,181,254,180,254,179,254,178,254,177,254,176,254,175,254,174,254,173,254,172,254,171,254,170,254,169,254,168,254,167,254,166,254,165,254,164,254,163,254,162,254,161,254,160,254,159,254,158,254,157,254,156,254,155,254,154,254,153,254,152,254,151,254,150,254,149,254,148,254,147,254,146,254,145,254,144,254,143,254,142,254,141,254,140,254,139,254,138,254,137,254,136,254,135,254,134,254,133,254,132,254,131,254,130,254,129,254,128,254,127,254,126,254,125,254,124,254,123,254,122,254,121,254,120,254,119,254,118,254,117,254,116,254,115,254,114,254,113,254,112,254,111,254,110,254,109,254,108,254,107,254,106,254,105,254,104,254,103,254,102,254,101,254,100,254,99,254,98,254,97,254,96,254,95,254,94,254,93,254,92,254,91,254,90,254,89,254,88,254,87,254,86,254,85,254,84,254,83,254,82,254,81,254,80,254,79,254,78,254,77,254,76,254,75,254,74,254,73,254,72,254,71,254,70,254,69,254,68,254,67,254,66,254,65,254,64,254,63,254,62,254,61,254,60,254,59,254,58,254,57,254,56,254,55,254,54,254,53,254,52,254,51,254,50,254,49,254,48,254,47,254,46,254,45,254,44,254,43,254,42,254,41,254,40,254,39,254,38,254,37,254,36,254,35,254,34,254,33,254,32,254,31,254,30,254,29,254,28,254,27,254,26,254,25,254,24,254,23,254,22,254,21,254,20,254,19,254,18,254,17,254,16,254,15,254,14,254,13,254,12,254,11,254,10,254,9,254,8,254,7,254,6,254,5,254,4,254,3,254,2,254,1,254,0,254,255,253,254,253,253,253,252,253,251,253,250,253,249,253,248,253,247,253,246,253,245,253,244,253,243,253,242,253,241,253,240,253,239,253,238,253,237,253,236,253,235,253,234,253,233,253,232,253,231,253,230,253,229,253,228,253,227,253,226,253,225,253,224,253,223,253,222,253,221,253,220,253,219,253,218,253,217,253,216,253,215,253,214,253,213,253,212,253,211,253,210,253,209,253,208,253,207,253,206,253,205,253,204,253,203,253,202,253,201,253,200,253,199,253,198,253,197,253,196,253,195,253,194,253,193,253,192,253,191,253,190,253,189,253,188,253,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,219,255,218,255,217,255,216,255,215,255,214,255,213,255,212,255,211,255,210,255,209,255,208,255,207,255,206,255,205,255,204,255,203,255,202,255,201,255,200,255,199,255,198,255,197,255,196,255,195,255,194,255,193,255,192,255,191,255,190,255,189,255,188,255,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,235,255,234,255,233,255,232,255,231,255,230,255,229,255,228,255,227,255,226,255,225,255,224,255,223,255,222,255,221,255,220,255,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,243,255,242,255,241,255,240,255,239,255,238,255,237,255,236,255,9,0,10,0,11,0,12,0,247,255,246,255,245,255,244,255,7,0,8,0,249,255,248,255,6,0,250,255,0,0,0,0,5,0,251,255,0,0,0,0,4,0,252,255,0,0,0,0,3,0,253,255,0,0,0,0,254,255,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,0,1,2,2,2,3,3,3,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,0,1,2,3,4,4,5,5,5,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,0,1,2,2,3,3,4,4,4,4,4,4,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,0,1,2,3,4,4,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,10,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,5,5,5,5,6,7,8,8,5,5,5,5,6,7,8,8,5,5,5,5,6,7,8,9,5,5,5,5,6,7,8,9,1,2,3,3,4,5,6,7,4,4,4,4,5,6,7,7,1,2,3,3,4,5,6,7,4,4,4,4,5,6,7,7,1,2,3,4,0,0,0,0,1,2,3,4,0,0,0,0,65,2,118,189,78,73,235,63,111,126,145,78,94,39,216,63,246,216,29,135,225,81,188,191,92,46,36,129,254,107,152,191,2,127,133,86,64,94,163,63,203,132,250,47,70,59,233,63,178,199,12,24,6,194,218,191,253,72,218,75,62,213,164,191,22,48,54,198,158,133,176,63,0,0,0,0,0,0,0,0,154,2,0,0,60,0,0,0,16,138,25,0,136,149,25,0,88,109,15,0,43,2,0,0,40,0,0,0,152,115,25,0,64,125,25,0,8,109,15,0,56,5,0,0,84,1,0,0,248,79,25,0,216,100,25,0,96,106,15,0,48,4,0,0,180,0,0,0,8,59,25,0,200,75,25,0,248,104,15,0,220,1,0,0,70,0,0,0,184,49,25,0,40,57,25,0,104,104,15,0,179,1,0,0,40,0,0,0,48,41,25,0,0,48,25,0,24,104,15,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,88,249,255,255,168,134,0,0,168,134,0,0,88,249,255,255,0,240,255,255,0,32,0,0,0,240,255,255,0,0,0,0,0,0,0,0,240,7,0,0,78,226,255,255,132,43,0,0,78,226,255,255,240,7,0,0,71,3,0,0,11,0,0,0,1,0,0,0,1,0,0,0,12,0,0,0,4,0,0,0,16,0,0,0,21,0,0,0,31,0,0,0,11,0,0,0,35,0,0,0,38,0,0,0,41,0,0,0,53,0,0,0,55,0,0,0,1,0,0,0,21,0,0,0,26,0,0,0,29,0,0,0,28,0,0,0,30,0,0,0,78,0,0,0,73,0,0,0,81,0,0,0,120,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,13,0,0,0,123,0,0,0,5,0,0,0,50,0,0,0,149,0,0,0,145,0,0,0,150,0,0,0,161,0,0,0,217,0,0,0,3,0,0,0,25,0,0,0,97,0,0,0,102,0,0,0,96,0,0,0,23,0,0,0,14,0,0,0,99,0,0,0,160,1,0,0,183,1,0,0,230,1,0,0,231,1,0,0,182,1,0,0,24,0,0,0,232,1,0,0,56,0,0,0,49,0,0,0,5,0,0,0,61,0,0,0,39,0,0,0,234,1,0,0,26,0,0,0,197,0,0,0,249,0,0,0,255,0,0,0,219,0,0,0,80,2,0,0,252,0,0,0,92,2,0,0,8,0,0,0,117,0,0,0,215,3,0,0,211,3,0,0,176,1,0,0,124,0,0,0,202,3,0,0,54,0,0,0,137,1,0,0,166,4,0,0,162,4,0,0,251,4,0,0,192,0,0,0,127,0,0,0,154,0,0,0,17,3,0,0,110,0,0,0,155,0,0,0,140,6,0,0,192,6,0,0,132,4,0,0,18,0,0,0,195,0,0,0,79,9,0,0,121,9,0,0,249,9,0,0,9,13,0,0,166,13,0,0,168,13,0,0,1,9,0,0,193,0,0,0,115,3,0,0,8,13,0,0,250,9,0,0,139,13,0,0,133,13,0,0,134,13,0,0,223,0,0,0,226,6,0,0,206,0,0,0,36,15,0,0,254,9,0,0,247,1,0,0,193,7,0,0,207,0,0,0,252,9,0,0,255,9,0,0,137,13,0,0,169,13,0,0,253,9,0,0,248,1,0,0,54,26,0,0,140,18,0,0,157,18,0,0,55,26,0,0,150,1,0,0,234,3,0,0,139,15,0,0,147,13,0,0,69,30,0,0,88,30,0,0,75,30,0,0,89,30,0,0,241,19,0,0,9,3,0,0,101,2,0,0,8,3,0,0,58,36,0,0,225,39,0,0,137,15,0,0,36,3,0,0,188,60,0,0,134,60,0,0,149,54,0,0,60,36,0,0,59,36,0,0,62,36,0,0,74,30,0,0,165,3,0,0,104,52,0,0,40,52,0,0,132,60,0,0,224,39,0,0,226,37,0,0,128,24,0,0,151,1,0,0,37,3,0,0,183,60,0,0,30,121,0,0,236,7,0,0,117,108,0,0,200,4,0,0,199,75,0,0,198,4,0,0,131,9,0,0,30,72,0,0,83,27,0,0,27,37,0,0,88,27,0,0,132,9,0,0,168,79,0,0,187,60,0,0,138,15,0,0,34,3,0,0,106,52,0,0,61,36,0,0,38,3,0,0,105,52,0,0,31,72,0,0,29,72,0,0,70,7,0,0,50,144,0,0,80,27,0,0,19,29,0,0,228,216,0,0,27,72,0,0,116,108,0,0,107,121,0,0,105,121,0,0,133,9,0,0,227,216,0,0,134,9,0,0,162,15,0,0,1,19,0,0,124,108,0,0,135,9,0,0,184,60,0,0,175,244,0,0,136,14,0,0,192,177,1,0,206,15,0,0,235,51,0,0,106,63,0,0,105,63,0,0,207,15,0,0,31,121,0,0,201,4,0,0,113,72,0,0,205,15,0,0,130,9,0,0,204,15,0,0,163,15,0,0,18,29,0,0,108,121,0,0,71,27,0,0,33,3,0,0,106,121,0,0,226,216,0,0,114,72,0,0,115,72,0,0,14,0,0,0,20,0,0,0,10,0,0,0,160,0,0,0,18,0,0,0,125,0,0,0,162,1,0,0,59,0,0,0,95,2,0,0,221,0,0,0,124,2,0,0,67,3,0,0,104,3,0,0,107,3,0,0,62,0,0,0,250,1,0,0,133,4,0,0,179,1,0,0,127,0,0,0,177,1,0,0,158,1,0,0,186,4,0,0,173,7,0,0,57,3,0,0,102,0,0,0,164,7,0,0,147,7,0,0,198,6,0,0,126,0,0,0,241,0,0,0,114,3,0,0,251,9,0,0,131,13,0,0,138,13,0,0,71,9,0,0,244,9,0,0,208,1,0,0,9,27,0,0,75,27,0,0,236,7,0,0,225,3,0,0,202,0,0,0,236,3,0,0,57,37,0,0,169,79,0,0,87,27,0,0,41,52,0,0,42,61,0,0,151,13,0,0,167,3,0,0,192,13,0,0,150,13,0,0,193,13,0,0,235,7,0,0,186,60,0,0,67,12,0,0,65,12,0,0,82,27,0,0,239,7,0,0,35,3,0,0,185,60,0,0,131,60,0,0,208,7,0,0,237,7,0,0,127,108,0,0,51,144,0,0,108,63,0,0,131,99,3,0,93,233,1,0,120,108,0,0,71,7,0,0,81,27,0,0,34,0,0,0,22,0,0,0,57,0,0,0,82,2,0,0,121,0,0,0,134,4,0,0,56,3,0,0,105,3,0,0,136,13,0,0,38,0,0,0,135,13,0,0,75,15,0,0,130,13,0,0,39,0,0,0,225,1,0,0,21,26,0,0,199,7,0,0,240,18,0,0,224,1,0,0,208,6,0,0,22,26,0,0,68,30,0,0,95,30,0,0,144,54,0,0,144,13,0,0,66,12,0,0,175,13,0,0,146,13], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1639960);
/* memory initializer */ allocate([128,15,0,0,251,12,0,0,47,52,0,0,127,72,0,0,70,27,0,0,104,121,0,0,149,13,0,0,145,13,0,0,85,27,0,0,104,63,0,0,198,75,0,0,189,60,0,0,129,15,0,0,32,3,0,0,105,0,0,0,254,0,0,0,213,6,0,0,63,3,0,0,222,0,0,0,198,7,0,0,64,30,0,0,148,13,0,0,136,15,0,0,142,60,0,0,148,54,0,0,174,13,0,0,173,13,0,0,103,2,0,0,166,3,0,0,39,3,0,0,126,72,0,0,238,7,0,0,73,7,0,0,199,4,0,0,146,54,0,0,86,27,0,0,209,15,0,0,86,122,0,0,119,108,0,0,49,144,0,0,72,7,0,0,122,108,0,0,109,121,0,0,234,51,0,0,118,108,0,0,208,15,0,0,130,99,3,0,23,228,1,0,69,7,0,0,175,79,0,0,225,216,0,0,107,63,0,0,92,233,1,0,173,79,0,0,158,0,0,0,189,4,0,0,124,6,0,0,8,27,0,0,235,3,0,0,69,27,0,0,145,54,0,0,229,216,0,0,4,121,0,0,129,9,0,0,234,7,0,0,244,25,0,0,125,108,0,0,171,79,0,0,172,79,0,0,126,108,0,0,0,19,0,0,123,108,0,0,111,0,0,0,247,3,0,0,133,60,0,0,196,4,0,0,30,0,0,0,225,6,0,0,147,54,0,0,68,27,0,0,65,2,0,0,70,30,0,0,157,1,0,0,102,2,0,0,187,4,0,0,56,37,0,0,172,7,0,0,84,27,0,0,2,9,0,0,112,72,0,0,167,13,0,0,0,9,0,0,133,1,0,0,121,108,0,0,227,6,0,0,233,3,0,0,148,30,0,0,237,3,0,0,242,3,0,0,46,52,0,0,107,52,0,0,26,37,0,0,197,4,0,0,129,24,0,0,28,72,0,0,89,27,0,0,135,60,0,0,174,79,0,0,233,7,0,0,109,63,0,0,10,242,0,0,48,144,0,0,170,79,0,0,230,216,0,0,111,63,0,0,26,72,0,0,110,63,0,0,22,228,1,0,231,216,0,0,0,0,0,0,10,4,2,4,4,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,8,8,8,8,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,10,9,10,10,10,10,10,9,10,10,10,10,10,10,10,10,11,11,10,10,11,11,10,11,11,11,11,11,12,12,12,12,12,12,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,12,12,13,13,13,12,12,12,12,12,13,13,13,13,13,14,14,14,14,13,13,13,13,13,14,14,14,14,14,14,15,14,14,14,14,14,14,13,14,14,14,14,14,14,15,14,15,14,15,15,15,15,15,15,16,15,15,14,15,16,15,14,14,15,14,14,15,14,15,15,15,16,15,17,16,15,15,15,15,16,16,16,16,17,15,16,14,16,16,17,16,16,16,16,16,15,15,15,16,16,16,16,17,15,15,15,15,16,15,15,4,7,8,8,9,9,9,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,12,12,11,11,11,12,12,12,12,12,12,12,12,13,13,13,13,12,13,14,14,15,15,14,14,14,14,14,14,14,15,14,14,14,15,15,15,14,14,15,15,15,16,16,18,17,15,15,15,6,9,10,10,11,11,12,12,12,13,12,12,12,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,15,15,15,14,14,15,16,15,14,14,15,7,10,11,12,13,13,13,14,14,14,14,14,14,14,14,15,15,15,15,15,14,15,16,15,15,16,15,15,15,16,15,16,18,17,15,15,16,16,17,15,8,11,13,13,14,15,14,16,15,16,15,15,15,15,15,15,17,15,9,12,14,15,10,13,14,15,10,13,11,14,11,14,11,15,12,15,12,12,13,15,13,14,13,14,14,14,14,14,15,15,15,15,14,15,15,16,16,16,15,16,16,15,16,17,16,0,0,0,0,0,1,15,0,0,30,0,0,0,0,0,0,0,4,0,0,0,6,0,0,0,13,0,0,0,10,0,0,0,23,0,0,0,29,0,0,0,23,0,0,0,44,0,0,0,49,0,0,0,57,0,0,0,62,0,0,0,57,0,0,0,90,0,0,0,102,0,0,0,112,0,0,0,123,0,0,0,112,0,0,0,119,0,0,0,175,0,0,0,201,0,0,0,242,0,0,0,244,0,0,0,178,0,0,0,227,0,0,0,91,1,0,0,93,1,0,0,129,1,0,0,157,1,0,0,227,1,0,0,197,1,0,0,181,2,0,0,219,2,0,0,56,3,0,0,195,3,0,0,204,3,0,0,240,3,0,0,205,2,0,0,250,3,0,0,161,3,0,0,180,5,0,0,87,6,0,0,171,7,0,0,77,7,0,0,76,7,0,0,193,10,0,0,197,10,0,0,107,7,0,0,168,12,0,0,4,15,0,0,0,15,0,0,227,15,0,0,60,15,0,0,16,15,0,0,57,15,0,0,230,15,0,0,38,14,0,0,144,14,0,0,197,22,0,0,39,24,0,0,84,25,0,0,197,21,0,0,88,25,0,0,138,31,0,0,74,28,0,0,15,43,0,0,65,43,0,0,14,43,0,0,198,51,0,0,80,48,0,0,79,28,0,0,136,45,0,0,92,48,0,0,24,60,0,0,79,43,0,0,194,44,0,0,71,58,0,0,128,86,0,0,157,86,0,0,66,100,0,0,67,100,0,0,70,100,0,0,110,101,0,0,68,100,0,0,32,113,0,0,138,116,0,0,186,193,0,0,34,126,0,0,166,122,0,0,37,127,0,0,167,122,0,0,32,126,0,0,27,193,0,0,24,193,0,0,165,122,0,0,10,173,0,0,137,243,0,0,187,158,1,0,173,202,0,0,66,254,0,0,64,254,0,0,52,108,1,0,229,180,2,0,101,61,3,0,48,108,1,0,174,231,1,0,92,226,1,0,112,131,1,0,3,231,1,0,186,158,1,0,55,108,1,0,52,226,0,0,110,108,1,0,4,0,0,0,42,0,0,0,97,0,0,0,117,0,0,0,203,0,0,0,255,0,0,0,144,1,0,0,235,1,0,0,209,1,0,0,185,2,0,0,7,3,0,0,57,3,0,0,63,3,0,0,251,3,0,0,180,3,0,0,12,6,0,0,121,6,0,0,69,6,0,0,125,6,0,0,138,7,0,0,227,7,0,0,73,7,0,0,196,10,0,0,210,10,0,0,227,10,0,0,16,12,0,0,22,12,0,0,209,10,0,0,244,12,0,0,226,15,0,0,134,21,0,0,157,14,0,0,241,25,0,0,100,22,0,0,38,30,0,0,56,29,0,0,77,43,0,0,197,51,0,0,194,31,0,0,195,31,0,0,40,29,0,0,29,60,0,0,142,89,0,0,148,240,0,0,164,122,0,0,56,173,0,0,12,172,0,0,26,193,0,0,234,121,0,0,129,200,0,0,68,254,0,0,53,182,0,0,13,172,0,0,30,182,0,0,135,89,0,0,33,113,0,0,130,243,0,0,135,243,0,0,55,226,0,0,71,254,0,0,131,243,0,0,145,240,0,0,133,243,0,0,51,226,0,0,238,130,1,0,184,158,1,0,62,102,1,0,147,240,0,0,20,0,0,0,88,0,0,0,89,1,0,0,103,1,0,0,0,3,0,0,212,3,0,0,181,5,0,0,157,7,0,0,106,7,0,0,103,11,0,0,96,11,0,0,5,15,0,0,240,12,0,0,23,15,0,0,149,14,0,0,34,24,0,0,19,25,0,0,194,22,0,0,47,24,0,0,89,25,0,0,203,31,0,0,39,30,0,0,64,28,0,0,199,51,0,0,123,30,0,0,73,28,0,0,137,45,0,0,35,30,0,0,96,22,0,0,18,63,0,0,198,44,0,0,225,51,0,0,52,91,0,0,154,96,0,0,105,101,0,0,136,116,0,0,33,126,0,0,95,207,0,0,44,113,0,0,157,56,0,0,207,103,0,0,40,127,0,0,63,102,1,0,103,61,3,0,61,102,1,0,93,226,1,0,171,193,3,0,68,92,1,0,54,108,1,0,31,0,0,0,236,0,0,0,35,3,0,0,178,5,0,0,159,7,0,0,194,10,0,0,22,15,0,0,158,14,0,0,86,25,0,0,15,30,0,0,234,25,0,0,102,22,0,0,137,43,0,0,2,43,0,0,140,45,0,0,27,60,0,0,25,60,0,0,181,50,0,0,156,63,0,0,207,44,0,0,151,56,0,0,53,91,0,0,2,173,0,0,41,127,0,0,65,100,0,0,132,56,0,0,136,120,0,0,78,120,0,0,104,101,0,0,187,193,0,0,134,89,0,0,204,103,0,0,73,254,0,0,72,254,0,0,188,193,0,0,65,254,0,0,113,131,1,0,60,102,1,0,49,226,0,0,30,113,0,0,9,173,0,0,146,240,0,0,45,0,0,0,219,1,0,0,129,7,0,0,26,12,0,0,85,15,0,0,128,21,0,0,168,30,0,0,155,45,0,0,175,50,0,0,22,63,0,0,28,60,0,0,52,120,0,0,69,60,0,0,156,56,0,0,206,103,0,0,69,100,0,0,185,193,0,0,137,120,0,0,58,127,0,0,79,120,0,0,43,127,0,0,11,173,0,0,144,240,0,0,29,193,0,0,78,233,0,0,31,113,0,0,241,233,0,0,142,243,0,0,233,121,0,0,3,173,0,0,155,240,0,0,174,202,0,0,70,254,0,0,230,180,2,0,240,233,0,0,182,158,1,0,193,122,6,0,192,122,6,0,102,61,3,0,136,243,0,0,113,0,0,0,160,3,0,0,169,12,0,0,41,24,0,0,57,29,0,0,67,43,0,0,196,44,0,0,84,101,0,0,154,240,0,0,31,182,0,0,205,103,0,0,28,113,0,0,54,182,0,0,42,127,0,0,52,182,0,0,31,193,0,0,94,207,0,0,29,182,0,0,107,240,0,0,171,202,0,0,190,193,0,0,76,233,0,0,153,240,0,0,237,130,1,0,79,233,0,0,25,193,0,0,50,226,0,0,228,180,2,0,138,243,0,0,180,158,1,0,95,226,1,0,77,233,0,0,183,0,0,0,133,7,0,0,204,22,0,0,81,48,0,0,196,51,0,0,111,101,0,0,145,56,0,0,29,113,0,0,175,202,0,0,151,240,0,0,137,116,0,0,152,240,0,0,128,200,0,0,170,202,0,0,134,243,0,0,183,158,1,0,111,108,1,0,132,243,0,0,232,130,1,0,233,130,1,0,48,226,0,0,0,231,1,0,98,61,3,0,99,61,3,0,100,61,3,0,51,108,1,0,22,226,0,0,253,0,0,0,21,12,0,0,101,22,0,0,74,60,0,0,59,127,0,0,150,120,0,0,28,193,0,0,21,226,0,0,50,108,1,0,139,243,0,0,141,243,0,0,234,130,1,0,1,231,1,0,223,18,7,0,70,92,1,0,148,1,0,0,224,15,0,0,19,63,0,0,139,116,0,0,150,240,0,0,128,207,0,0,94,226,1,0,189,37,14,0,97,61,3,0,49,108,1,0,249,1,0,0,18,25,0,0,16,87,0,0,208,243,0,0,191,193,0,0,1,3,0,0,36,30,0,0,8,173,0,0,205,3,0,0,65,28,0,0,189,193,0,0,99,5,0,0,82,58,0,0,209,243,0,0,112,5,0,0,206,44,0,0,23,226,0,0,123,6,0,0,93,101,0,0,75,7,0,0,71,100,0,0,18,12,0,0,251,116,0,0,8,15,0,0,28,182,0,0,34,14,0,0,67,254,0,0,199,22,0,0,54,24,0,0,242,25,0,0,67,28,0,0,63,29,0,0,207,31,0,0,76,43,0,0,76,48,0,0,182,50,0,0,70,58,0,0,7,86,0,0,23,63,0,0,197,44,0,0,155,96,0,0,92,101,0,0,35,126,0,0,193,103,0,0,38,127,0,0,39,127,0,0,149,240,0,0,243,233,0,0,129,207,0,0,30,193,0,0,172,202,0,0,143,243,0,0,242,233,0,0,250,116,0,0,54,226,0,0,69,254,0,0,40,196,1,0,53,226,0,0,239,130,1,0,181,158,1,0,214,243,0,0,236,130,1,0,53,108,1,0,140,243,0,0,231,180,2,0,71,92,1,0,188,37,14,0,2,231,1,0,182,196,1,0,90,226,0,0,170,193,3,0,69,92,1,0,41,196,1,0,185,158,1,0,175,231,1,0,235,130,1,0,212,224,1,0,110,137,3,0,12,6,2,3,4,4,5,5,5,6,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,10,10,10,11,10,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,16,16,16,15,15,15,15,15,16,16,15,16,16,17,16,16,16,17,18,18,17,17,17,17,17,17,17,17,17,4,6,7,8,8,8,9,9,10,10,10,10,10,10,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,13,13,13,14,13,14,14,14,13,13,14,14,16,16,15,16,16,16,15,16,16,16,16,16,16,16,16,16,17,16,16,16,16,17,17,17,18,16,5,8,9,10,10,10,11,11,12,12,12,12,12,12,13,13,13,13,13,13,13,13,14,14,13,14,14,13,14,14,15,14,15,15,15,16,15,16,16,15,15,15,18,18,18,17,18,17,17,6,9,10,11,11,12,12,13,13,13,13,14,14,14,14,14,14,14,14,15,15,15,16,15,15,15,15,15,15,16,16,15,16,16,16,16,17,18,17,16,16,16,7,10,11,12,12,13,13,14,14,14,14,15,14,15,15,15,16,15,15,15,15,16,16,16,17,16,17,16,15,16,16,16,16,18,17,17,19,19,18,16,7,11,12,13,14,14,15,15,16,16,15,16,16,15,16,16,16,16,16,16,16,17,16,17,17,16,17,18,16,17,17,17,8,11,13,14,14,15,15,16,16,16,16,16,16,16,16,17,17,16,17,17,17,17,18,18,18,17,17,8,12,14,14,15,15,16,17,17,16,16,17,17,20,17,9,12,14,16,16,16,17,21,18,17,9,13,15,16,16,10,13,16,10,14,16,11,15,16,11,15,17,11,15,12,15,12,16,12,16,13,16,13,13,13,14,14,13,14,14,14,15,15,14,15,15,15,15,15,15,15,16,17,16,16,16,16,17,16,17,16,18,17,17,17,16,17,17,16,18,17,21,17,18,17,18,17,18,17,17,17,17,19,0,0,0,0,178,1,0,0,105,0,0,0,0,0,0,0,4,0,0,0,6,0,0,0,14,0,0,0,20,0,0,0,25,0,0,0,22,0,0,0,43,0,0,0,48,0,0,0,61,0,0,0,60,0,0,0,90,0,0,0,95,0,0,0,109,0,0,0,126,0,0,0,95,0,0,0,127,0,0,0,182,0,0,0,188,0,0,0,216,0,0,0,242,0,0,0,254,0,0,0,188,0,0,0,252,0,0,0,97,1,0,0,110,1,0,0,116,1,0,0,118,1,0,0,162,1,0,0,227,1,0,0,243,1,0,0,116,1,0,0,122,1,0,0,234,1,0,0,168,2,0,0,196,2,0,0,230,2,0,0,20,3,0,0,70,3,0,0,103,3,0,0,233,3,0,0,229,2,0,0,238,2,0,0,214,3,0,0,85,5,0,0,84,5,0,0,87,5,0,0,195,5,0,0,214,5,0,0,224,6,0,0,47,6,0,0,226,6,0,0,153,7,0,0,137,7,0,0,250,7,0,0,206,5,0,0,254,7,0,0,236,5,0,0,204,7,0,0,175,7,0,0,167,10,0,0,25,11,0,0,148,11,0,0,133,11,0,0,159,11,0,0,72,12,0,0,69,12,0,0,216,13,0,0,76,12,0,0,75,12,0,0,153,13,0,0,31,13,0,0,194,13,0,0,149,15,0,0,162,15,0,0,181,11,0,0,159,11,0,0,93,15,0,0,191,11,0,0,71,15,0,0,74,21,0,0,213,15,0,0,69,15,0,0,127,15,0,0,13,22,0,0,137,24,0,0,87,23,0,0,34,23,0,0,179,24,0,0,45,23,0,0,57,26,0,0,24,26,0,0,179,27,0,0,48,27,0,0,99,30,0,0,60,23,0,0,53,27,0,0,35,23,0,0,128,30,0,0,238,31,0,0,97,23,0,0,252,31,0,0,127,31,0,0,124,44,0,0,161,31,0,0,123,23,0,0,85,23,0,0,90,23,0,0,166,31,0,0,171,46,0,0,10,49,0,0,105,44,0,0,105,54,0,0,39,49,0,0,3,49,0,0,67,46,0,0,98,54,0,0,101,49,0,0,36,49,0,0,59,49,0,0,17,49,0,0,104,54,0,0,59,52,0,0,82,60,0,0,252,62,0,0,108,46,0,0,218,63,0,0,248,62,0,0,123,46,0,0,226,62,0,0,197,60,0,0,114,61,0,0,192,88,0,0,248,61,0,0,169,46,0,0,126,62,0,0,109,85,0,0,130,92,0,0,113,61,0,0,123,62,0,0,66,60,0,0,215,88,0,0,78,63,0,0,0,98,0,0,112,61,0,0,178,92,0,0,150,92,0,0,176,92,0,0,69,63,0,0,177,92,0,0,109,46,0,0,16,49,0,0,104,47,0,0,144,92,0,0,166,124,0,0,136,124,0,0,4,98,0,0,200,98,0,0,166,120,0,0,134,121,0,0,213,121,0,0,173,177,0,0,137,121,0,0,121,176,0,0,221,92,0,0,212,170,0,0,232,93,0,0,205,125,0,0,135,121,0,0,103,93,0,0,153,93,0,0,29,185,0,0,241,124,0,0,155,93,0,0,215,121,0,0,123,176,0,0,133,92,0,0,154,93,0,0,204,125,0,0,191,126,0,0,206,125,0,0,251,125,0,0,192,126,0,0,26,125,0,0,7,122,0,0,132,92,0,0,113,196,0,0,242,124,0,0,239,186,0,0,210,185,0,0,235,93,0,0,214,123,0,0,69,184,0,0,152,93,0,0,26,185,0,0,232,186,0,0,224,196,0,0,49,220,0,0,61,249,0,0,206,187,0,0,210,209,0,0,169,247,0,0,185,217,0,0,203,187,0,0,0,185,0,0,215,170,0,0,189,186,0,0,225,196,0,0,111,244,0,0,136,197,0,0,139,197,0,0,230,96,1,0,207,187,0,0,195,186,0,0,69,249,0,0,163,247,0,0,193,209,0,0,142,251,0,0,164,247,0,0,140,251,0,0,12,244,0,0,115,196,0,0,114,253,0,0,205,187,0,0,250,255,0,0,64,249,0,0,201,187,0,0,168,247,0,0,237,161,1,0,197,187,0,0,111,242,1,0,253,99,1,0,199,96,1,0,245,161,1,0,71,249,0,0,252,99,1,0,179,84,1,0,246,255,0,0,246,99,1,0,233,96,1,0,240,161,1,0,185,186,0,0,186,186,0,0,134,112,1,0,3,185,0,0,117,253,0,0,8,243,0,0,243,118,1,0,255,99,1,0,125,253,0,0,120,187,1,0,251,99,1,0,219,136,1,0,247,161,1,0,178,84,1,0,253,114,1,0,244,99,1,0,115,187,1,0,255,114,1,0,188,186,0,0,125,249,0,0,243,161,1,0,109,187,1,0,213,255,1,0,244,161,1,0,114,242,1,0,128,115,1,0,130,115,1,0,231,255,1,0,200,186,0,0,196,187,0,0,211,136,1,0,224,96,1,0,123,253,0,0,95,114,1,0,245,114,1,0,121,187,1,0,217,250,1,0,105,242,1,0,208,136,1,0,196,186,0,0,197,186,0,0,133,17,3,0,210,136,1,0,204,136,1,0,135,17,3,0,254,231,3,0,209,136,1,0,108,187,1,0,104,242,1,0,210,250,1,0,217,255,1,0,234,161,1,0,104,187,1,0,203,250,1,0,178,253,3,0,26,232,1,0,206,136,1,0,251,114,1,0,239,161,1,0,206,250,1,0,112,187,1,0,193,186,0,0,107,187,1,0,248,114,1,0,102,187,1,0,223,255,1,0,106,187,1,0,215,255,1,0,102,242,1,0,248,118,1,0,83,118,3,0,126,250,1,0,130,17,3,0,200,250,1,0,227,199,2,0,238,112,3,0,236,118,1,0,233,118,1,0,188,228,2,0,197,96,1,0,90,118,3,0,156,206,3,0,115,115,1,0,232,118,1,0,212,136,1,0,241,118,1,0,239,118,1,0,89,118,3,0,124,187,1,0,222,255,1,0,242,118,1,0,139,17,3,0,212,199,2,0,81,118,3,0,159,206,5,0,80,118,3,0,145,17,3,0,246,244,3,0,245,244,3,0,108,160,7,0,193,250,1,0,123,201,5,0,224,199,2,0,58,157,7,0,253,231,3,0,223,199,2,0,240,244,3,0,109,160,7,0,193,118,3,0,59,157,7,0,4,0,0,0,20,0,0,0,89,0,0,0,171,0,0,0,184,0,0,0,119,1,0,0,245,1,0,0,242,1,0,0,21,3,0,0,252,3,0,0,189,5,0,0,45,6,0,0,232,6,0,0,221,7,0,0,4,11,0,0,205,7,0,0,30,11,0,0,30,13,0,0,21,15,0,0,59,15,0,0,65,15,0,0,72,21,0,0,176,24,0,0,59,23,0,0,132,24,0,0,28,26,0,0,180,27,0,0,37,31,0,0,181,23,0,0,109,23,0,0,248,30,0,0,115,46,0,0,7,49,0,0,37,49,0,0,5,49,0,0,73,46,0,0,232,60,0,0,249,62,0,0,94,62,0,0,114,46,0,0,113,52,0,0,217,63,0,0,63,98,0,0,160,120,0,0,103,104,0,0,179,92,0,0,114,98,0,0,236,104,0,0,154,110,0,0,212,121,0,0,152,110,0,0,170,177,0,0,26,110,0,0,133,121,0,0,238,104,0,0,155,110,0,0,136,92,0,0,172,177,0,0,250,125,0,0,101,93,0,0,240,124,0,0,191,124,0,0,117,196,0,0,235,96,1,0,126,187,1,0,166,247,0,0,221,254,1,0,227,96,1,0,251,255,0,0,141,251,0,0,249,255,0,0,192,209,0,0,140,197,0,0,233,161,1,0,184,186,0,0,207,245,0,0,245,255,0,0,197,118,3,0,236,161,1,0,237,96,1,0,222,254,1,0,201,250,1,0,235,161,1,0,36,242,1,0,238,118,1,0,121,253,0,0,128,112,1,0,135,115,1,0,122,187,1,0,233,255,1,0,247,118,1,0,133,115,1,0,129,119,1,0,213,199,2,0,133,119,1,0,227,255,1,0,245,99,1,0,194,250,1,0,249,231,3,0,141,17,3,0,177,253,3,0,226,255,1,0,38,242,1,0,138,17,3,0,217,199,2,0,144,17,3,0,140,17,3,0,243,244,3,0,127,187,1,0,114,187,1,0,132,17,3,0,244,146,11,0,251,231,3,0,217,225,6,0,202,250,1,0,0,35,6,0,184,253,3,0,55,208,3,0,252,231,3,0,1,35,6,0,242,244,3,0,106,242,1,0,14,0,0,0,99,0,0,0,248,0,0,0,238,1,0,0,119,3,0,0,247,3,0,0,227,6,0,0,204,5,0,0,5,11,0,0,210,13,0,0,212,15,0,0,46,23,0,0,42,23,0,0,35,30,0,0,45,31,0,0,99,23,0,0,105,23,0,0,108,23,0,0,117,46,0,0,4,49,0,0,193,46,0,0,88,62,0,0,63,88,0,0,98,63,0,0,68,63,0,0,197,88,0,0,60,98,0,0,244,92,0,0,215,123,0,0,157,93,0,0,210,170,0,0,102,93,0,0,169,177,0,0,120,176,0,0,254,124,0,0,24,185,0,0,111,196,0,0,25,185,0,0,71,184,0,0,27,110,0,0,75,184,0,0,216,170,0,0,116,253,0,0,244,114,1,0,129,112,1,0,124,249,0,0,115,242,1,0,160,247,0,0,124,253,0,0,247,114,1,0,122,253,0,0,119,187,1,0,254,114,1,0,112,242,1,0,115,253,0,0,123,187,1,0,188,161,1,0,125,187,1,0,195,187,0,0,246,114,1,0,235,186,0,0,143,251,0,0,244,244,3,0,180,253,3,0,200,118,3,0,250,231,3,0,208,255,1,0,3,35,6,0,245,146,11,0,97,242,1,0,137,17,3,0,181,253,3,0,219,199,2,0,201,118,3,0,214,250,1,0,209,250,1,0,21,0,0,0,240,0,0,0,224,2,0,0,142,5,0,0,215,5,0,0,77,12,0,0,161,15,0,0,219,11,0,0,86,23,0,0,112,31,0,0,25,44,0,0,60,49,0,0,15,55,0,0,192,60,0,0,168,46,0,0,198,88,0,0,199,88,0,0,183,46,0,0,208,88,0,0,24,125,0,0,88,170,0,0,72,184,0,0,158,93,0,0,108,93,0,0,76,184,0,0,137,197,0,0,1,185,0,0,248,99,1,0,201,186,0,0,197,185,0,0,60,249,0,0,216,136,1,0,199,187,0,0,236,96,1,0,111,253,0,0,217,136,1,0,234,96,1,0,167,247,0,0,68,249,0,0,171,186,0,0,58,220,0,0,207,136,1,0,251,118,1,0,216,199,2,0,215,199,2,0,117,187,1,0,158,206,5,0,2,35,6,0,237,112,3,0,244,118,1,0,209,255,1,0,239,112,3,0,248,244,3,0,199,118,3,0,225,255,1,0,198,118,3,0,255,118,1,0,216,225,6,0,246,118,1,0,135,112,1,0,205,245,0,0,53,0,0,0,160,1,0,0,139,5,0,0,172,10,0,0,154,11,0,0,95,23,0,0,34,30,0,0,140,30,0,0,178,31,0,0,11,49,0,0,209,88,0,0,46,85,0,0,39,92,0,0,110,104,0,0,167,124,0,0,116,196,0,0,51,220,0,0,242,123,0,0,233,93,0,0,53,122,0,0,170,186,0,0,235,185,0,0,149,251,0,0,184,185,0,0,129,115,1,0,98,242,1,0,205,136,1,0,136,112,1,0,250,114,1,0,162,247,0,0,211,250,1,0,192,186,0,0,92,118,3,0,223,254,1,0,37,242,1,0,212,250,1,0,218,199,2,0,157,206,5,0,248,231,3,0,3,226,1,0,215,136,1,0,84,0,0,0,192,2,0,0,161,7,0,0,120,15,0,0,54,27,0,0,163,31,0,0,58,49,0,0,54,52,0,0,58,52,0,0,29,125,0,0,216,123,0,0,223,92,0,0,70,184,0,0,137,177,0,0,184,217,0,0,248,255,0,0,190,217,0,0,138,197,0,0,234,93,0,0,211,209,0,0,228,96,1,0,107,242,1,0,218,136,1,0,2,226,1,0,210,199,2,0,254,99,1,0,147,17,3,0,130,119,1,0,194,118,3,0,209,199,2,0,176,253,3,0,93,118,3,0,208,199,2,0,208,250,1,0,1,226,1,0,221,136,1,0,226,199,2,0,87,118,3,0,85,118,3,0,196,118,3,0,192,118,3,0,234,118,1,0,111,0,0,0,207,3,0,0,213,13,0,0,35,31,0,0,97,44,0,0,208,46,0,0,84,93,0,0,45,85,0,0,131,120,0,0,168,177,0,0,28,185,0,0,191,186,0,0,2,185,0,0,170,247,0,0,165,247,0,0,232,161,1,0,214,255,1,0,190,186,0,0,191,161,1,0,243,99,1,0,216,255,1,0,215,250,1,0,117,242,1,0,220,255,1,0,125,0,0,0,188,5,0,0,73,21,0,0,153,42,0,0,239,61,0,0,115,98,0,0,214,121,0,0,27,125,0,0,211,170,0,0,252,208,0,0,221,199,2,0,214,136,1,0,194,186,0,0,225,199,2,0,118,187,1,0,189,161,1,0,134,17,3,0,120,253,0,0,190,161,1,0,131,17,3,0,182,253,3,0,241,244,3,0,82,118,3,0,213,250,1,0,249,244,3,0,255,231,3,0,156,206,5,0,91,118,3,0,136,17,3,0,114,115,1,0,189,0,0,0,139,7,0,0,33,31,0,0,67,60,0,0,237,61,0,0,214,170,0,0,193,126,0,0,66,249,0,0,134,92,0,0,137,112,1,0,187,186,0,0,232,255,1,0,222,199,2,0,110,242,1,0,196,250,1,0,247,244,3,0,86,118,3,0,125,250,1,0,195,118,3,0,179,253,3,0,143,17,3,0,198,250,1,0,248,0,0,0,237,7,0,0,253,30,0,0,122,62,0,0,145,92,0,0,217,170,0,0,236,186,0,0,50,220,0,0,110,244,0,0,0,226,1,0,250,118,1,0,94,118,3,0,183,253,3,0,214,199,2,0,185,253,3,0,84,118,3,0,88,118,3,0,142,17,3,0,219,255,1,0,246,0,0,0,67,12,0,0,6,49,0,0,239,104,0,0,77,184,0,0,136,177,0,0,204,187,0,0,100,242,1,0,105,187,1,0,134,115,1,0,192,250,1,0,113,1,0,0,57,15,0,0,65,62,0,0,237,104,0,0,188,217,0,0,161,247,0,0,103,187,1,0,221,255,1,0,249,118,1,0,185,1,0,0,125,15,0,0,99,63,0,0,253,208,0,0,234,185,0,0,220,136,1,0,195,250,1,0,242,161,1,0,146,17,3,0,228,255,1,0,246,1,0,0,84,23,0,0,101,104,0,0,9,243,0,0,229,96,1,0,245,118,1,0,95,118,3,0,204,250,1,0,233,1,0,0,26,26,0,0,1,98,0,0,5,241,0,0,240,118,1,0,223,2,0,0,86,23,0,0,109,93,0,0,250,99,1,0,237,118,1,0,66,3,0,0,64,46,0,0,255,208,0,0,130,112,1,0,205,3,0,0,152,42,0,0,252,255,0,0,220,199,2,0,127,250,1,0,254,3,0,0,100,55,0,0,253,255,0,0,252,118,1,0,197,250,1,0,247,2,0,0,209,46,0,0,151,251,0,0,138,5,0,0,220,46,0,0,200,187,0,0,212,5,0,0,61,98,0,0,232,96,1,0,46,6,0,0,48,88,0,0,249,99,1,0,235,6,0,0,5,98,0,0,116,242,1,0,222,7,0,0,201,98,0,0,101,242,1,0,201,5,0,0,222,92,0,0,211,255,1,0,212,5,0,0,136,121,0,0,206,7,0,0,73,184,0,0,27,11,0,0,137,92,0,0,199,250,1,0,147,11,0,0,131,92,0,0,158,11,0,0,79,241,0,0,74,12,0,0,199,185,0,0,212,13,0,0,112,196,0,0,113,242,1,0,56,15,0,0,150,251,0,0,235,118,1,0,160,15,0,0,247,99,1,0,178,11,0,0,27,185,0,0,190,11,0,0,2,241,0,0,68,15,0,0,70,249,0,0,205,250,1,0,121,15,0,0,189,217,0,0,77,21,0,0,198,187,0,0,210,15,0,0,231,96,1,0,43,23,0,0,203,136,1,0,94,23,0,0,118,253,0,0,92,23,0,0,113,187,1,0,159,24,0,0,238,161,1,0,36,31,0,0,246,161,1,0,167,27,0,0,202,187,0,0,125,31,0,0,255,255,0,0,46,31,0,0,101,187,1,0,181,27,0,0,249,114,1,0,239,31,0,0,108,242,1,0,62,31,0,0,119,253,0,0,98,23,0,0,110,187,1,0,249,30,0,0,252,114,1,0,160,31,0,0,183,42,0,0,74,46,0,0,103,242,1,0,179,31,0,0,218,255,1,0,66,46,0,0,1,49,0,0,128,119,1,0,61,49,0,0,117,52,0,0,132,119,1,0,38,49,0,0,207,250,1,0,81,60,0,0,131,119,1,0,64,62,0,0,229,255,1,0,99,54,0,0,224,255,1,0,143,62,0,0,109,242,1,0,60,52,0,0,193,60,0,0,253,118,1,0,69,62,0,0,192,46,0,0,97,63,0,0,238,61,0,0,216,63,0,0,62,88,0,0,69,46,0,0,89,62,0,0,2,61,0,0,232,92,0,0,104,85,0,0,254,118,1,0,105,47,0,0,216,250,1,0,193,88,0,0,131,92,0,0,230,255,1,0,113,98,0,0,28,110,0,0,199,98,0,0,225,104,0,0,47,85,0,0,100,104,0,0,102,104,0,0,153,110,0,0,188,92,0,0,165,124,0,0,161,120,0,0,130,92,0,0,207,125,0,0,59,98,0,0,62,98,0,0,232,104,0,0,54,122,0,0,156,93,0,0,119,176,0,0,243,124,0,0,52,122,0,0,164,124,0,0,25,125,0,0,210,121,0,0,28,125,0,0,217,123,0,0,74,184,0,0,148,251,0,0,213,170,0,0,48,220,0,0,243,123,0,0,238,186,0,0,122,176,0,0,114,196,0,0,30,185,0,0,186,217,0,0,159,93,0,0,254,208,0,0,198,185,0,0,135,92,0,0,78,241,0,0,237,186,0,0,46,185,0,0,3,241,0,0,196,185,0,0,145,251,0,0,187,217,0,0,171,177,0,0,141,197,0,0,254,255,0,0,59,249,0,0,65,249,0,0,234,186,0,0,31,185,0,0,204,245,0,0,191,217,0,0,67,249,0,0,4,241,0,0,96,242,1,0,146,251,0,0,63,249,0,0,166,243,0,0,199,186,0,0,171,247,0,0,198,186,0,0,131,115,1,0,109,253,0,0,233,186,0,0,110,253,0,0,79,231,1,0,202,136,1,0,39,242,1,0,147,251,0,0,144,251,0,0,247,255,0,0,133,112,1,0,131,112,1,0,225,96,1,0,132,112,1,0,62,249,0,0,226,96,1,0,198,96,1,0,241,161,1,0,111,187,1,0,132,115,1,0,112,253,0,0,99,242,1,0,213,136,1,0,166,115,1,0,206,245,0,0,242,99,1,0,113,253,0,0,210,255,1,0,196,96,1,0,212,255,1,0,211,199,2,0,116,187,1,0,9,7,2,3,4,4,5,5,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,13,14,14,13,14,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,14,14,15,14,14,15,15,15,15,15,15,15,15,15,14,15,15,15,15,15,15,15,15,15,15,14,15,15,15,15,15,15,15,15,15,16,15,16,16,16,16,15,15,16,16,16,16,16,15,16,16,16,15,16,15,15,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,16,17,16,17,17,16,17,16,17,16,16,17,17,17,16,17,16,16,17,16,17,16,17,17,16,16,17,17,17,17,17,17,17,17,16,17,17,16,17,17,17,17,17,17,17,17,16,18,17,17,17,17,17,17,17,17,17,17,17,17,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,18,17,17,17,17,18,17,17,18,19,17,17,17,18,17,17,17,18,18,18,17,17,17,18,17,17,17,17,17,17,17,17,17,18,18,18,18,18,18,18,18,18,18,17,18,18,18,18,17,18,18,18,17,17,18,18,18,18,19,18,18,19,19,20,18,19,18,19,19,18,19,20,18,19,4,6,7,8,9,9,9,10,10,10,11,11,11,11,12,12,12,12,12,12,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,16,15,15,15,15,16,16,15,16,16,15,16,17,17,17,17,17,16,16,16,16,16,17,17,17,16,18,17,17,17,18,17,17,18,17,17,17,17,17,18,17,18,18,18,17,17,18,19,18,18,17,17,18,18,18,18,19,17,17,18,20,19,19,18,19,18,19,19,19,19,17,5,7,9,10,10,11,11,12,12,12,13,13,13,13,13,14,14,14,14,14,15,14,15,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,15,16,16,17,17,17,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,16,16,19,18,18,19,17,19,20,17,18,18,18,18,18,18,6,8,10,11,12,12,12,13,13,13,14,14,14,14,15,15,15,15,15,15,16,16,16,16,16,16,17,17,17,16,16,17,17,17,17,17,17,17,16,16,16,17,18,18,18,17,19,19,18,18,17,18,19,18,17,18,18,19,18,17,17,6,9,11,12,13,13,13,14,14,14,15,15,15,15,15,16,16,16,16,16,16,17,16,17,17,17,17,17,17,17,18,17,18,17,17,18,18,19,19,17,17,7,10,12,13,13,14,14,14,14,15,16,16,16,16,16,16,16,16,16,16,17,17,17,17,18,17,18,18,18,18,18,18,18,18,17,17,18,18,18,18,18,18,7,10,12,13,14,15,15,15,15,16,16,17,17,17,17,17,17,17,17,17,17,18,17,17,8,11,13,14,15,15,15,15,16,16,18,17,17,18,17,17,18,17,17,18,18,19,18,18,19,19,19,18,18,18,8,11,13,14,15,16,16,16,16,17,17,17,18,17,18,19,18,18,18,18,18,18,8,12,14,15,15,16,16,16,17,17,18,18,18,18,18,18,18,18,17,9,12,14,15,16,16,17,17,17,17,18,9,12,14,15,16,17,17,17,18,9,13,15,16,17,17,18,17,18,17,9,13,15,16,17,18,18,18,10,13,15,16,18,10,14,16,17,18,10,14,16,17,10,14,16,18,18,10,14,16,18,18,11,15,16,11,15,17,11,15,17,11,15,17,11,15,17,11,15,17,12,16,17,12,15,12,16,12,16,18,12,16,12,16,12,16,12,16,17,12,16,18,12,17,13,16,13,16,13,16,18,13,16,13,17,13,17,13,17,13,17,13,17,13,17,13,17,13,17,13,16,13,17,13,17,13,17,14,17,14,17,14,17,14,14,14,17,14,17,14,14,18,14,14,18,14,18,14,18,14,17,14,17,14,17,14,14,18,14,15,15,15,14,15,15,14,15,15,15,18,15,18,15,15,17,15,15,15,15,15,15,15,15,15,15,15,16,15,15,15,15,16,16,16,16,16,15,15,15,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,16,16,16,17,16,16,16,17,17,17,17,17,16,17,17,17,17,16,16,16,17,17,17,17,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,18,17,230,3,0,0,246,0,0,0,0,0,0,0,2,0,0,0,6,0,0,0,15,0,0,0,27,0,0,0,40,0,0,0,57,0,0,0,63,0,0,0,107,0,0,0,118,0,0,0,183,0,0,0,232,0,0,0,239,0,0,0,105,1,0,0,167,1,0,0,212,1,0,0,220,1,0,0,196,2,0,0,73,3,0,0,85,3,0,0,145,3,0,0,220,3,0,0,129,5,0,0,178,5,0,0,152,6,0,0,12,7,0,0,85,7,0,0,58,7,0,0,116,7,0,0,207,7,0,0,10,11,0,0,102,11,0,0,46,13,0,0,94,13,0,0,27,14,0,0,172,14,0,0,90,14,0,0,126,15,0,0,161,15,0,0,62,22,0,0,55,26,0,0,82,26,0,0,57,28,0,0,179,26,0,0,95,29,0,0,182,28,0,0,82,31,0,0,217,29,0,0,4,44,0,0,46,44,0,0,45,44,0,0,35,44,0,0,103,52,0,0,163,52,0,0,27,53,0,0,1,53,0,0,93,58,0,0,28,53,0,0,117,56,0,0,234,61,0,0,123,57,0,0,219,57,0,0,241,61,0,0,216,57,0,0,180,59,0,0,10,88,0,0,77,88,0,0,66,88,0,0,19,91,0,0,234,88,0,0,125,105,0,0,6,106,0,0,204,104,0,0,199,106,0,0,150,106,0,0,244,114,0,0,67,117,0,0,180,114,0,0,32,125,0,0,3,176,0,0,181,115,0,0,230,123,0,0,128,209,0,0,209,123,0,0,184,124,0,0,6,125,0,0,37,125,0,0,242,210,0,0,154,209,0,0,52,211,0,0,220,225,0,0,41,213,0,0,132,213,0,0,210,225,0,0,227,229,0,0,196,238,0,0,100,229,0,0,73,250,0,0,1,96,1,0,220,238,0,0,250,247,0,0,44,163,1,0,49,97,1,0,3,96,1,0,200,249,0,0,128,239,1,0,160,210,1,0,75,170,1,0,206,247,0,0,254,171,1,0,80,170,1,0,88,164,1,0,22,168,1,0,228,202,1,0,254,210,1,0,46,213,1,0,76,170,1,0,69,194,2,0,161,210,1,0,93,163,1,0,27,202,1,0,216,213,1,0,49,245,1,0,28,202,1,0,137,243,1,0,175,244,1,0,231,165,3,0,251,81,3,0,75,194,2,0,206,75,3,0,77,194,2,0,73,194,2,0,74,194,2,0,252,45,7,0,239,87,3,0,2,80,3,0,230,165,3,0,49,148,3,0,59,132,5,0,119,74,3,0,49,132,5,0,243,165,3,0,221,165,3,0,229,229,3,0,189,86,3,0,110,151,3,0,210,163,6,0,13,80,3,0,196,148,6,0,189,128,5,0,232,229,3,0,149,75,7,0,110,74,3,0,124,151,3,0,50,148,3,0,210,176,5,0,216,163,6,0,184,128,5,0,203,176,5,0,215,176,5,0,238,45,7,0,237,45,7,0,236,45,7,0,156,75,7,0,127,151,3,0,234,45,7,0,158,75,7,0,125,190,7,0,191,128,5,0,213,176,5,0,168,203,7,0,145,75,7,0,221,229,3,0,113,97,11,0,179,70,13,0,185,70,13,0,161,203,7,0,159,75,7,0,225,45,7,0,245,89,14,0,235,229,3,0,4,0,0,0,21,0,0,0,56,0,0,0,117,0,0,0,232,0,0,0,211,1,0,0,71,3,0,0,156,3,0,0,144,6,0,0,74,7,0,0,96,11,0,0,147,14,0,0,116,15,0,0,61,22,0,0,90,26,0,0,36,29,0,0,190,28,0,0,75,31,0,0,104,52,0,0,98,53,0,0,71,57,0,0,130,62,0,0,4,88,0,0,18,91,0,0,3,88,0,0,109,105,0,0,158,106,0,0,124,105,0,0,120,105,0,0,251,106,0,0,178,116,0,0,245,114,0,0,192,115,0,0,65,117,0,0,68,105,0,0,183,116,0,0,211,112,0,0,169,123,0,0,177,176,0,0,175,209,0,0,221,225,0,0,226,229,0,0,163,225,0,0,195,238,0,0,47,97,1,0,97,233,0,0,218,238,0,0,142,231,0,0,72,250,0,0,44,97,1,0,17,229,0,0,101,229,0,0,83,233,0,0,74,170,1,0,157,229,0,0,44,213,1,0,17,168,1,0,231,202,1,0,252,171,1,0,45,213,1,0,207,202,1,0,5,207,1,0,84,194,2,0,114,74,3,0,172,244,1,0,107,151,3,0,113,74,3,0,217,198,2,0,115,216,2,0,106,74,3,0,231,87,3,0,76,70,3,0,245,229,3,0,51,132,5,0,58,245,1,0,10,80,3,0,234,87,3,0,115,74,3,0,47,148,3,0,229,87,3,0,117,151,3,0,205,148,6,0,114,151,3,0,165,203,7,0,239,163,6,0,131,84,3,0,152,75,7,0,193,176,5,0,112,151,3,0,215,165,3,0,51,148,3,0,52,148,3,0,206,148,6,0,190,128,5,0,255,229,3,0,236,163,6,0,111,97,11,0,177,70,13,0,209,163,6,0,229,45,7,0,110,75,7,0,233,45,7,0,0,231,3,0,182,70,13,0,233,163,6,0,105,75,7,0,117,86,14,0,184,70,13,0,170,203,7,0,209,165,3,0,12,0,0,0,60,0,0,0,235,0,0,0,241,1,0,0,164,3,0,0,168,6,0,0,213,7,0,0,67,13,0,0,119,14,0,0,197,22,0,0,177,28,0,0,93,44,0,0,85,58,0,0,86,58,0,0,81,62,0,0,181,59,0,0,10,91,0,0,159,106,0,0,184,116,0,0,40,125,0,0,135,209,0,0,14,212,0,0,46,213,0,0,37,212,0,0,227,234,0,0,211,225,0,0,46,97,1,0,158,229,0,0,194,238,0,0,120,229,0,0,26,229,0,0,121,229,0,0,21,229,0,0,96,233,0,0,131,209,0,0,32,210,0,0,203,210,0,0,18,229,0,0,62,108,1,0,2,96,1,0,66,108,1,0,233,202,1,0,26,70,3,0,250,210,1,0,8,163,1,0,73,168,1,0,7,207,1,0,143,243,1,0,101,75,3,0,83,194,2,0,158,239,1,0,195,203,1,0,193,203,1,0,85,194,2,0,132,243,1,0,53,132,5,0,205,197,2,0,247,165,3,0,82,194,2,0,156,149,3,0,216,198,2,0,211,165,3,0,120,173,6,0,242,163,6,0,169,203,7,0,118,97,11,0,235,45,7,0,100,151,3,0,246,229,3,0,216,165,3,0,140,74,7,0,230,163,6,0,209,148,6,0,121,173,6,0,146,69,26,0,251,89,14,0,179,203,7,0,205,176,5,0,23,0,0,0,181,0,0,0,195,2,0,0,183,5,0,0,28,11,0,0,92,14,0,0,63,22,0,0,178,26,0,0,250,30,0,0,138,52,0,0,110,57,0,0,218,88,0,0,99,105,0,0,48,106,0,0,205,114,0,0,207,115,0,0,231,124,0,0,202,210,0,0,216,210,0,0,100,231,0,0,148,231,0,0,8,96,1,0,103,97,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1650200);
/* memory initializer */ allocate([126,97,1,0,73,170,1,0,11,163,1,0,19,168,1,0,218,198,2,0,128,165,1,0,194,203,1,0,202,249,0,0,127,97,1,0,254,210,1,0,252,247,0,0,64,108,1,0,19,229,0,0,197,238,0,0,195,247,0,0,8,213,1,0,30,168,1,0,253,210,1,0,48,148,3,0,134,84,3,0,253,229,3,0,76,194,2,0,90,199,2,0,116,74,3,0,244,165,3,0,77,70,3,0,202,148,6,0,241,165,3,0,9,213,1,0,192,213,1,0,72,70,3,0,78,70,3,0,213,163,6,0,232,163,6,0,231,163,6,0,195,176,5,0,72,194,2,0,138,243,1,0,242,165,3,0,229,163,6,0,41,0,0,0,104,1,0,0,140,5,0,0,103,11,0,0,157,15,0,0,61,28,0,0,191,28,0,0,32,44,0,0,29,53,0,0,246,61,0,0,249,106,0,0,181,114,0,0,215,177,0,0,178,176,0,0,10,212,0,0,43,213,0,0,82,233,0,0,151,231,0,0,195,99,1,0,160,195,1,0,134,243,1,0,33,202,1,0,85,70,3,0,71,194,2,0,59,245,1,0,80,194,2,0,79,194,2,0,133,243,1,0,93,239,1,0,21,207,1,0,234,202,1,0,10,171,1,0,25,207,1,0,61,245,1,0,194,213,1,0,251,210,1,0,88,239,1,0,120,74,3,0,236,87,3,0,51,245,1,0,225,165,3,0,210,148,6,0,130,132,5,0,238,165,3,0,220,198,2,0,235,87,3,0,196,176,5,0,120,151,3,0,225,163,6,0,180,203,7,0,225,165,3,0,104,75,7,0,239,165,3,0,210,165,3,0,36,148,3,0,226,45,7,0,246,89,14,0,247,89,14,0,2,231,3,0,236,229,3,0,139,243,1,0,59,0,0,0,240,1,0,0,119,7,0,0,168,15,0,0,178,28,0,0,132,45,0,0,87,58,0,0,214,61,0,0,23,105,0,0,17,106,0,0,7,125,0,0,226,234,0,0,150,231,0,0,201,249,0,0,251,247,0,0,102,97,1,0,96,97,1,0,27,171,1,0,250,171,1,0,123,216,2,0,247,210,1,0,104,151,3,0,140,243,1,0,83,70,3,0,81,70,3,0,217,163,6,0,1,80,3,0,189,171,3,0,66,135,3,0,38,148,3,0,118,74,3,0,236,165,3,0,117,74,3,0,0,80,3,0,136,84,3,0,16,207,1,0,219,198,2,0,237,87,3,0,232,87,3,0,233,87,3,0,240,165,3,0,194,148,6,0,120,97,11,0,245,45,7,0,37,148,3,0,43,148,3,0,109,75,7,0,111,75,7,0,119,97,11,0,121,97,11,0,106,75,7,0,114,97,11,0,135,132,5,0,238,229,3,0,237,229,3,0,242,45,7,0,244,45,7,0,174,203,7,0,202,163,6,0,134,14,7,0,207,75,3,0,200,163,6,0,89,0,0,0,132,3,0,0,91,13,0,0,56,28,0,0,96,53,0,0,91,57,0,0,78,88,0,0,100,105,0,0,205,115,0,0,231,177,0,0,152,231,0,0,141,231,0,0,67,250,0,0,72,168,1,0,47,163,1,0,78,170,1,0,74,70,3,0,171,244,1,0,141,243,1,0,235,165,3,0,212,165,3,0,138,84,3,0,199,163,6,0,208,176,5,0,197,163,6,0,176,203,7,0,203,148,6,0,229,165,3,0,226,229,3,0,44,148,3,0,114,216,2,0,174,244,1,0,213,165,3,0,211,148,6,0,129,132,5,0,9,80,3,0,116,151,3,0,50,132,5,0,108,97,11,0,219,176,5,0,139,84,3,0,116,97,11,0,149,93,29,0,76,0,11,0,178,203,7,0,229,165,3,0,143,74,7,0,249,89,14,0,246,45,7,0,253,89,14,0,173,203,7,0,125,66,13,0,255,44,7,0,122,151,3,0,217,176,5,0,109,97,11,0,107,97,11,0,147,69,26,0,175,203,7,0,218,176,5,0,113,0,0,0,235,3,0,0,3,22,0,0,108,44,0,0,97,57,0,0,200,104,0,0,49,106,0,0,189,114,0,0,194,210,0,0,27,229,0,0,230,229,0,0,251,171,1,0,255,210,1,0,229,202,1,0,92,239,1,0,94,239,1,0,19,207,1,0,109,74,3,0,109,151,3,0,106,97,11,0,242,229,3,0,196,163,6,0,105,97,11,0,220,229,3,0,185,128,5,0,153,75,7,0,100,87,7,0,52,132,5,0,217,165,3,0,90,148,6,0,89,148,6,0,140,84,3,0,233,165,3,0,87,148,6,0,241,45,7,0,94,148,6,0,94,163,6,0,1,231,3,0,104,97,11,0,221,176,5,0,222,165,3,0,194,163,6,0,120,66,13,0,204,163,6,0,253,45,7,0,101,97,11,0,154,0,22,0,177,203,7,0,124,66,13,0,98,97,11,0,94,118,14,0,190,236,28,0,182,203,7,0,84,148,6,0,96,97,11,0,122,66,13,0,150,93,29,0,109,29,11,0,244,89,14,0,232,45,7,0,219,165,3,0,122,0,0,0,174,6,0,0,60,28,0,0,186,58,0,0,233,88,0,0,204,114,0,0,221,210,0,0,45,210,0,0,193,238,0,0,219,238,0,0,162,210,1,0,91,239,1,0,226,87,3,0,191,171,3,0,249,210,1,0,4,80,3,0,220,165,3,0,252,81,3,0,108,151,3,0,198,163,6,0,203,163,6,0,234,229,3,0,243,89,14,0,206,163,6,0,82,148,6,0,240,89,14,0,144,75,7,0,121,66,13,0,123,66,13,0,181,203,7,0,197,176,5,0,227,165,3,0,226,165,3,0,208,0,0,0,117,7,0,0,254,30,0,0,213,61,0,0,140,114,0,0,185,124,0,0,162,225,0,0,133,234,0,0,216,238,0,0,10,163,1,0,79,170,1,0,223,165,3,0,8,80,3,0,224,165,3,0,244,229,3,0,247,229,3,0,108,29,11,0,62,132,5,0,112,74,3,0,248,45,7,0,107,75,7,0,127,66,13,0,240,45,7,0,191,176,5,0,192,176,5,0,176,70,13,0,239,45,7,0,248,89,14,0,100,46,22,0,111,29,11,0,224,165,3,0,39,148,3,0,102,145,6,0,226,163,6,0,227,163,6,0,141,74,7,0,126,66,13,0,151,93,29,0,180,70,13,0,216,176,5,0,211,163,6,0,224,0,0,0,99,11,0,0,204,52,0,0,51,106,0,0,201,115,0,0,160,225,0,0,253,247,0,0,204,249,0,0,125,97,1,0,235,202,1,0,169,244,1,0,179,171,3,0,80,148,6,0,32,148,3,0,119,151,3,0,224,229,3,0,212,163,6,0,237,163,6,0,102,97,11,0,241,89,14,0,110,29,11,0,118,86,14,0,234,163,6,0,116,86,14,0,99,97,11,0,183,70,13,0,166,203,7,0,186,70,13,0,148,93,29,0,100,97,11,0,241,163,6,0,162,203,7,0,81,148,6,0,250,45,7,0,187,70,13,0,247,45,7,0,148,75,7,0,191,236,28,0,250,89,14,0,155,0,22,0,228,163,6,0,230,0,0,0,148,14,0,0,118,56,0,0,239,112,0,0,42,213,0,0,21,96,1,0,20,96,1,0,249,171,1,0,23,207,1,0,121,74,3,0,80,70,3,0,5,231,3,0,208,163,6,0,48,132,5,0,157,75,7,0,126,190,7,0,190,176,5,0,115,151,3,0,222,163,6,0,251,0,0,0,123,15,0,0,215,61,0,0,208,123,0,0,156,229,0,0,205,249,0,0,24,207,1,0,255,210,1,0,122,74,3,0,41,148,3,0,12,80,3,0,224,45,7,0,86,148,6,0,124,190,7,0,181,70,13,0,178,70,13,0,221,163,6,0,162,1,0,0,59,22,0,0,19,105,0,0,22,176,0,0,66,250,0,0,45,163,1,0,6,207,1,0,124,74,3,0,125,74,3,0,97,97,11,0,129,84,3,0,250,229,3,0,160,203,7,0,127,190,7,0,163,203,7,0,167,203,7,0,211,176,5,0,230,45,7,0,220,163,6,0,169,1,0,0,180,26,0,0,52,106,0,0,106,212,0,0,48,97,1,0,95,239,1,0,50,245,1,0,54,245,1,0,46,148,3,0,54,132,5,0,219,163,6,0,91,148,6,0,201,1,0,0,160,28,0,0,139,114,0,0,217,238,0,0,57,245,1,0,29,202,1,0,101,151,3,0,102,151,3,0,57,132,5,0,93,148,6,0,103,151,3,0,211,1,0,0,44,31,0,0,252,123,0,0,97,97,1,0,82,70,3,0,237,165,3,0,141,84,3,0,56,132,5,0,218,163,6,0,193,2,0,0,94,44,0,0,53,211,0,0,26,171,1,0,116,216,2,0,6,80,3,0,132,84,3,0,204,176,5,0,154,75,7,0,243,45,7,0,214,163,6,0,218,2,0,0,179,52,0,0,174,213,0,0,238,202,1,0,113,216,2,0,227,87,3,0,151,75,7,0,249,45,7,0,186,128,5,0,212,176,5,0,77,3,0,0,78,53,0,0,80,247,0,0,192,203,1,0,231,165,3,0,228,165,3,0,133,3,0,0,88,58,0,0,65,108,1,0,207,197,2,0,225,229,3,0,108,75,7,0,119,86,14,0,223,163,6,0,144,3,0,0,80,62,0,0,194,99,1,0,118,216,2,0,130,84,3,0,214,176,5,0,58,132,5,0,159,3,0,0,94,88,0,0,131,165,1,0,15,80,3,0,147,75,7,0,113,151,3,0,228,3,0,0,18,105,0,0,67,108,1,0,225,87,3,0,138,5,0,0,111,105,0,0,56,245,1,0,201,176,5,0,207,163,6,0,182,5,0,0,248,106,0,0,52,245,1,0,131,132,5,0,224,163,6,0,149,6,0,0,2,125,0,0,232,202,1,0,133,132,5,0,162,6,0,0,74,117,0,0,238,87,3,0,123,151,3,0,72,7,0,0,178,116,0,0,123,74,3,0,41,7,0,0,224,177,0,0,73,70,3,0,227,229,3,0,61,7,0,0,196,210,0,0,230,229,3,0,187,7,0,0,153,176,0,0,98,151,3,0,206,176,5,0,95,148,6,0,209,7,0,0,171,213,0,0,121,151,3,0,211,7,0,0,47,213,0,0,99,151,3,0,92,148,6,0,26,11,0,0,197,210,0,0,137,84,3,0,35,13,0,0,237,234,0,0,248,229,3,0,50,13,0,0,22,96,1,0,251,229,3,0,65,13,0,0,104,231,0,0,237,165,3,0,31,14,0,0,23,96,1,0,39,128,5,0,173,14,0,0,7,250,0,0,85,148,6,0,84,14,0,0,43,97,1,0,85,14,0,0,129,165,1,0,120,15,0,0,43,163,1,0,188,128,5,0,238,163,6,0,121,15,0,0,253,171,1,0,149,15,0,0,24,171,1,0,240,163,6,0,55,22,0,0,77,170,1,0,45,22,0,0,60,245,1,0,243,163,6,0,49,26,0,0,16,168,1,0,105,151,3,0,80,26,0,0,239,202,1,0,54,26,0,0,46,163,1,0,103,26,0,0,142,243,1,0,133,26,0,0,89,239,1,0,166,26,0,0,131,239,1,0,81,29,0,0,18,192,2,0,83,29,0,0,121,216,2,0,94,29,0,0,5,80,3,0,186,28,0,0,4,207,1,0,83,148,6,0,45,29,0,0,255,81,3,0,45,31,0,0,111,216,2,0,41,31,0,0,7,80,3,0,34,44,0,0,250,81,3,0,3,44,0,0,236,165,3,0,95,44,0,0,235,165,3,0,88,44,0,0,107,74,3,0,105,52,0,0,190,86,3,0,89,44,0,0,108,74,3,0,106,52,0,0,234,165,3,0,189,52,0,0,191,52,0,0,191,86,3,0,106,56,0,0,185,58,0,0,63,132,5,0,107,56,0,0,245,165,3,0,75,58,0,0,33,148,3,0,164,58,0,0,233,165,3,0,90,58,0,0,96,57,0,0,126,151,3,0,233,61,0,0,88,57,0,0,247,61,0,0,225,57,0,0,228,229,3,0,95,57,0,0,88,148,6,0,145,62,0,0,242,61,0,0,40,148,3,0,242,88,0,0,128,62,0,0,195,163,6,0,147,62,0,0,192,148,6,0,184,88,0,0,202,176,5,0,79,88,0,0,193,148,6,0,241,88,0,0,214,104,0,0,16,106,0,0,195,106,0,0,50,106,0,0,210,112,0,0,17,105,0,0,177,116,0,0,148,116,0,0,212,106,0,0,214,106,0,0,184,114,0,0,250,106,0,0,179,116,0,0,64,117,0,0,206,115,0,0,5,176,0,0,179,116,0,0,149,116,0,0,185,116,0,0,54,211,0,0,255,123,0,0,99,119,0,0,200,115,0,0,41,125,0,0,34,182,0,0,33,210,0,0,129,209,0,0,209,177,0,0,184,116,0,0,208,177,0,0,155,209,0,0,195,210,0,0,114,177,0,0,220,210,0,0,35,182,0,0,170,213,0,0,38,212,0,0,130,209,0,0,149,231,0,0,209,225,0,0,55,211,0,0,108,233,0,0,228,229,0,0,20,229,0,0,238,234,0,0,0,96,1,0,103,231,0,0,161,225,0,0,143,231,0,0,4,96,1,0,194,247,0,0,153,231,0,0,231,229,0,0,102,229,0,0,105,231,0,0,81,247,0,0,222,238,0,0,6,250,0,0,5,96,1,0,159,250,0,0,230,165,1,0,102,231,0,0,111,99,1,0,221,238,0,0,192,238,0,0,9,163,1,0,202,206,1,0,205,99,1,0,203,249,0,0,223,238,0,0,130,165,1,0,45,97,1,0,229,229,0,0,248,171,1,0,12,163,1,0,31,202,1,0,204,99,1,0,92,163,1,0,30,202,1,0,81,170,1,0,172,99,1,0,78,168,1,0,63,165,1,0,22,207,1,0,252,210,1,0,179,165,1,0,25,171,1,0,31,168,1,0,195,213,1,0,63,108,1,0,193,213,1,0,252,210,1,0,170,244,1,0,18,168,1,0,53,245,1,0,18,207,1,0,23,168,1,0,124,97,1,0,11,171,1,0,248,210,1,0,130,239,1,0,122,216,2,0,47,213,1,0,48,245,1,0,72,170,1,0,135,84,3,0,253,210,1,0,173,244,1,0,17,207,1,0,27,70,3,0,133,84,3,0,32,202,1,0,237,202,1,0,230,202,1,0,255,171,1,0,79,70,3,0,111,74,3,0,129,239,1,0,75,70,3,0,150,157,3,0,131,243,1,0,55,245,1,0,20,207,1,0,206,197,2,0,14,80,3,0,81,194,2,0,236,202,1,0,135,243,1,0,84,70,3,0,228,87,3,0,120,216,2,0,11,80,3,0,128,84,3,0,232,165,3,0,142,84,3,0,100,75,3,0,168,244,1,0,3,80,3,0,223,229,3,0,112,216,2,0,230,87,3,0,240,229,3,0,90,239,1,0,234,165,3,0,136,243,1,0,3,231,3,0,78,194,2,0,226,165,3,0,253,81,3,0,221,198,2,0,4,231,3,0,254,81,3,0,117,216,2,0,199,176,5,0,106,151,3,0,230,165,3,0,35,148,3,0,128,132,5,0,70,194,2,0,227,165,3,0,119,216,2,0,241,229,3,0,190,171,3,0,137,132,5,0,249,229,3,0,224,87,3,0,188,171,3,0,198,176,5,0,103,145,6,0,101,145,6,0,233,229,3,0,34,148,3,0,111,151,3,0,125,151,3,0,222,229,3,0,201,163,6,0,152,139,5,0,246,165,3,0,208,165,3,0,134,132,5,0,193,163,6,0,252,229,3,0,220,176,5,0,143,84,3,0,45,148,3,0,201,148,6,0,132,132,5,0,232,165,3,0,155,75,7,0,150,75,7,0,208,148,6,0,136,132,5,0,228,165,3,0,42,148,3,0,194,46,7,0,118,151,3,0,209,176,5,0,207,176,5,0,214,165,3,0,252,89,14,0,200,176,5,0,231,229,3,0,183,203,7,0,135,14,7,0,171,203,7,0,194,176,5,0,195,148,6,0,142,74,7,0,243,229,3,0,205,163,6,0,254,45,7,0,46,59,7,0,192,46,7,0,197,148,6,0,55,132,5,0,200,148,6,0,255,45,7,0,53,148,3,0,61,132,5,0,215,163,6,0,193,46,7,0,200,34,13,0,207,148,6,0,115,97,11,0,254,229,3,0,187,128,5,0,242,89,14,0,110,97,11,0,117,97,11,0,218,165,3,0,189,176,5,0,204,148,6,0,60,132,5,0,199,148,6,0,146,75,7,0,195,46,7,0,198,148,6,0,112,97,11,0,172,203,7,0,51,23,11,0,164,203,7,0,103,97,11,0,231,45,7,0,228,45,7,0,192,163,6,0,239,229,3,0,101,46,22,0,227,45,7,0,251,45,7,0,95,163,6,0,235,163,6,0,11,9,2,3,4,4,5,6,6,7,7,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,17,17,17,18,17,17,17,17,17,17,17,18,18,17,17,18,17,17,18,17,18,18,18,18,19,18,18,18,18,18,18,20,18,18,18,19,19,18,19,18,19,19,18,19,19,18,19,19,19,19,18,19,19,19,19,19,19,19,20,20,20,19,19,20,19,20,19,19,20,19,19,20,20,20,20,19,20,21,19,3,5,7,8,9,9,10,11,11,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,16,16,15,15,15,15,16,16,16,16,17,16,17,17,16,17,17,17,17,17,17,16,17,17,17,17,18,17,17,18,18,18,18,18,19,18,18,18,18,18,18,19,19,18,18,18,18,19,18,19,19,19,20,19,18,19,19,19,19,19,19,19,19,19,19,20,20,19,20,19,20,19,20,19,19,21,20,20,19,4,7,8,10,11,11,12,12,13,13,14,14,14,14,15,15,15,15,15,16,16,16,16,16,16,16,17,17,17,17,17,17,17,16,16,16,16,17,17,17,17,18,18,18,17,17,18,18,18,18,18,18,18,18,18,19,18,18,18,19,18,19,19,19,20,20,20,19,19,19,19,19,19,19,21,21,20,19,5,8,10,11,12,13,13,13,14,14,15,15,15,15,16,16,16,16,16,17,17,17,17,17,17,17,17,18,17,18,17,17,17,17,17,17,17,17,17,17,17,19,18,19,18,18,18,18,18,19,18,17,17,18,18,19,19,19,19,18,18,18,19,6,9,11,12,13,13,14,14,14,15,15,16,16,16,16,16,16,17,17,17,18,18,18,18,18,18,18,18,18,18,18,17,18,18,17,18,18,18,18,18,18,19,19,18,18,18,19,19,19,20,19,19,18,19,19,20,21,21,19,19,18,6,10,12,13,14,14,14,15,15,15,16,16,17,17,17,17,17,17,17,18,18,19,18,18,18,19,18,18,18,19,18,18,18,18,18,18,18,18,18,18,18,19,20,20,19,19,19,19,20,20,19,20,19,19,19,20,20,20,19,19,18,19,7,10,12,13,14,15,15,15,16,16,17,17,17,17,17,17,18,18,18,18,19,18,19,19,19,20,19,18,19,19,18,18,19,19,19,18,19,19,20,19,18,20,21,20,20,19,19,21,20,21,20,20,20,19,19,20,20,21,20,19,7,11,13,14,15,15,15,16,16,17,17,17,17,18,18,18,18,18,19,20,19,19,20,19,19,19,19,19,19,19,19,18,18,19,20,19,19,19,20,19,19,19,20,19,20,20,21,20,20,20,21,22,20,19,20,20,21,20,21,20,19,8,11,13,14,15,16,16,16,17,17,17,18,18,18,18,18,19,18,19,19,19,19,21,19,19,21,19,20,20,20,19,18,18,8,12,14,15,16,16,16,16,17,17,17,19,18,18,19,19,20,19,18,20,19,20,20,19,19,20,20,21,21,20,19,19,19,19,19,19,20,21,20,19,19,8,12,14,15,16,16,17,17,17,18,18,18,19,19,19,19,19,19,20,21,20,21,19,21,20,20,20,20,21,20,19,20,19,20,20,20,19,22,21,21,19,9,12,14,15,16,17,17,17,18,18,18,19,19,19,19,20,19,19,19,9,13,15,16,17,17,18,18,18,19,18,20,19,20,20,20,19,9,13,15,16,17,17,18,18,18,20,18,19,20,20,20,20,19,20,19,9,13,15,16,17,18,18,18,19,19,19,19,10,14,16,17,18,18,19,19,19,19,19,10,14,16,17,18,18,18,19,19,10,14,16,17,18,18,18,19,19,20,19,10,14,16,18,18,18,19,20,19,19,10,14,17,18,18,18,10,15,17,18,19,19,21,19,11,15,17,18,18,19,19,11,15,17,18,19,19,11,15,17,18,11,15,18,19,19,11,15,18,19,19,11,16,18,19,11,15,18,19,11,16,18,12,16,18,19,12,16,19,12,16,19,19,19,12,16,19,12,16,19,19,12,16,18,12,16,19,12,17,19,12,17,19,12,17,19,12,17,19,13,17,13,17,13,17,19,19,13,17,13,17,19,13,17,13,18,19,13,17,19,13,18,13,17,13,18,13,18,13,18,13,18,13,18,13,18,14,18,19,14,18,14,18,14,18,14,18,14,19,14,19,14,18,14,18,14,18,14,19,14,14,18,14,14,19,14,18,14,19,14,19,14,15,19,15,15,15,15,19,15,19,15,15,19,15,15,19,15,19,15,19,15,19,15,15,15,15,15,15,15,15,15,15,15,16,15,15,15,16,16,16,15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,16,16,16,17,17,16,17,17,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,18,17,17,17,17,17,17,17,17,18,17,17,18,17,17,17,17,18,18,17,17,17,17,17,17,17,18,17,18,18,17,17,17,18,18,18,17,18,17,18,18,18,18,18,18,18,18,18,17,18,18,18,18,19,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,19,18,18,19,18,18,18,19,18,19,18,18,19,18,18,19,19,19,19,19,18,19,18,19,18,19,19,18,18,19,19,19,19,19,19,19,19,19,19,18,19,19,19,19,19,18,19,19,19,19,19,19,19,19,19,19,20,19,19,19,19,21,19,19,20,19,20,19,19,19,19,19,20,20,20,19,19,19,20,19,19,19,20,20,19,20,19,19,21,20,20,19,19,19,19,19,19,20,19,20,20,20,20,20,20,20,19,19,21,20,20,19,19,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,0,0,1,0,2,0,3,0,4,0,5,0,0,0,1,0,2,0,0,0,1,0,2,0,0,0,1,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,160,64,0,0,160,64,0,0,160,64,0,0,192,64,0,0,192,64,0,0,192,64,0,0,224,64,0,0,224,64,0,0,224,64,0,0,0,65,0,0,0,65,0,0,16,65,0,0,16,65,0,0,32,65,0,0,32,65,0,0,48,65,0,0,48,65,0,0,64,65,0,0,64,65,0,0,80,65,0,0,80,65,0,0,96,65,0,0,96,65,0,0,112,65,0,0,112,65,0,0,128,65,0,0,128,65,0,0,136,65,0,0,136,65,0,0,144,65,0,0,144,65,0,0,152,65,0,0,152,65,0,0,160,65,0,0,160,65,0,0,168,65,0,0,168,65,0,0,176,65,0,0,176,65,0,0,184,65,0,0,184,65,0,0,192,65,0,0,192,65,0,0,200,65,0,0,200,65,0,0,208,65,0,0,208,65,0,0,216,65,0,0,216,65,0,0,224,65,0,0,224,65,0,0,232,65,0,0,232,65,0,0,240,65,0,0,240,65,0,0,248,65,0,0,248,65,0,0,0,66,0,0,0,66,0,0,4,66,0,0,4,66,0,0,8,66,0,0,8,66,0,0,12,66,0,0,12,66,0,0,16,66,0,0,16,66,0,0,20,66,0,0,20,66,0,0,24,66,0,0,24,66,0,0,28,66,0,0,28,66,0,0,32,66,0,0,32,66,0,0,36,66,0,0,36,66,0,0,40,66,0,0,40,66,0,0,44,66,0,0,44,66,0,0,48,66,0,0,48,66,0,0,52,66,0,0,52,66,0,0,56,66,0,0,56,66,0,0,60,66,0,0,60,66,0,0,64,66,0,0,64,66,0,0,68,66,0,0,68,66,0,0,72,66,0,0,76,66,0,0,80,66,226,1,0,0,127,0,0,0,0,0,0,0,2,0,0,0,8,0,0,0,14,0,0,0,25,0,0,0,47,0,0,0,55,0,0,0,96,0,0,0,108,0,0,0,149,0,0,0,198,0,0,0,240,0,0,0,46,1,0,0,137,1,0,0,165,1,0,0,248,1,0,0,83,2,0,0,10,3,0,0,68,3,0,0,77,3,0,0,242,3,0,0,189,4,0,0,215,5,0,0,42,6,0,0,139,6,0,0,147,6,0,0,151,7,0,0,125,9,0,0,171,11,0,0,82,12,0,0,94,12,0,0,33,13,0,0,32,13,0,0,26,15,0,0,206,15,0,0,209,15,0,0,241,18,0,0,89,23,0,0,172,24,0,0,167,24,0,0,191,24,0,0,43,26,0,0,82,30,0,0,80,30,0,0,49,30,0,0,184,31,0,0,230,37,0,0,231,37,0,0,180,46,0,0,183,46,0,0,105,49,0,0,91,49,0,0,124,49,0,0,108,49,0,0,202,52,0,0,141,52,0,0,64,63,0,0,162,60,0,0,118,63,0,0,195,75,0,0,229,75,0,0,115,63,0,0,248,75,0,0,249,75,0,0,49,97,0,0,139,98,0,0,137,98,0,0,218,98,0,0,138,98,0,0,212,98,0,0,151,105,0,0,180,98,0,0,24,105,0,0,77,121,0,0,123,126,0,0,135,126,0,0,234,126,0,0,78,121,0,0,157,105,0,0,103,121,0,0,159,105,0,0,219,98,0,0,122,126,0,0,235,126,0,0,192,186,0,0,201,151,0,0,55,197,0,0,171,197,0,0,51,210,0,0,56,211,0,0,193,186,0,0,61,210,0,0,145,47,1,0,57,211,0,0,200,253,0,0,60,210,0,0,220,253,0,0,201,253,0,0,221,253,0,0,60,211,0,0,3,0,0,0,22,0,0,0,62,0,0,0,195,0,0,0,161,1,0,0,71,3,0,0,46,6,0,0,170,11,0,0,45,15,0,0,42,26,0,0,88,30,0,0,155,48,0,0,163,60,0,0,106,93,0,0,154,98,0,0,150,105,0,0,79,121,0,0,229,126,0,0,215,186,0,0,170,197,0,0,244,197,0,0,223,253,0,0,222,253,0,0,32,138,1,0,109,138,1,0,123,166,1,0,100,164,1,0,33,95,2,0,226,249,1,0,227,249,1,0,10,0,0,0,61,0,0,0,40,1,0,0,199,3,0,0,36,12,0,0,163,24,0,0,177,46,0,0,178,60,0,0,31,105,0,0,121,126,0,0,19,0,0,0,187,0,0,0,78,3,0,0,20,13,0,0,253,37,0,0,231,75,0,0,36,0,0,0,136,1,0,0,239,7,0,0,53,0,0,0,8,3,0,0,242,18,0,0,92,0,0,0,246,3,0,0,224,37,0,0,109,0,0,0,152,6,0,0,150,0,0,0,37,12,0,0,199,0,0,0,27,15,0,0,243,0,0,0,255,18,0,0,116,1,0,0,102,26,0,0,160,1,0,0,153,48,0,0,228,1,0,0,107,49,0,0,82,2,0,0,49,63,0,0,11,3,0,0,230,75,0,0,70,3,0,0,251,98,0,0,79,3,0,0,102,121,0,0,245,3,0,0,134,126,0,0,212,5,0,0,17,197,0,0,44,6,0,0,245,197,0,0,146,6,0,0,153,242,0,0,149,7,0,0,152,242,0,0,233,7,0,0,33,138,1,0,126,9,0,0,173,117,1,0,39,12,0,0,122,166,1,0,87,12,0,0,89,235,2,0,34,13,0,0,217,20,3,0,25,15,0,0,194,243,3,0,205,15,0,0,203,72,3,0,248,18,0,0,65,190,4,0,160,24,0,0,193,243,3,0,161,24,0,0,64,190,4,0,183,24,0,0,176,41,6,0,100,26,0,0,41,35,13,0,48,30,0,0,195,243,3,0,159,31,0,0,98,173,11,0,153,31,0,0,0,207,15,0,154,48,0,0,177,41,6,0,182,46,0,0,195,90,23,0,76,49,0,0,149,145,6,0,104,49,0,0,99,173,11,0,142,52,0,0,193,90,23,0,48,63,0,0,129,231,7,0,65,63,0,0,40,35,13,0,66,63,0,0,3,158,31,0,194,75,0,0,194,90,23,0,116,63,0,0,192,90,23,0,97,93,0,0,5,60,63,0,48,97,0,0,4,60,63,0,181,98,0,0,21,1,0,0,2,0,0,0,1,0,0,0,0,0,0,0,13,0,0,0,7,0,0,0,19,0,0,0,29,0,0,0,8,0,0,0,12,0,0,0,35,0,0,0,43,0,0,0,63,0,0,0,23,0,0,0,27,0,0,0,67,0,0,0,73,0,0,0,80,0,0,0,85,0,0,0,84,0,0,0,103,0,0,0,100,0,0,0,123,0,0,0,45,0,0,0,40,0,0,0,42,0,0,0,133,0,0,0,137,0,0,0,43,0,0,0,53,0,0,0,144,0,0,0,145,0,0,0,148,0,0,0,136,0,0,0,193,0,0,0,198,0,0,0,242,0,0,0,227,0,0,0,197,0,0,0,226,0,0,0,54,0,0,0,240,0,0,0,167,0,0,0,205,0,0,0,251,0,0,0,89,0,0,0,22,1,0,0,3,1,0,0,8,1,0,0,43,1,0,0,45,1,0,0,136,1,0,0,46,1,0,0,76,1,0,0,195,1,0,0,135,1,0,0,231,1,0,0,111,0,0,0,148,0,0,0,105,0,0,0,230,1,0,0,202,1,0,0,71,1,0,0,149,1,0,0,167,0,0,0,19,2,0,0,9,2,0,0,3,3,0,0,149,2,0,0,137,2,0,0,140,2,0,0,141,2,0,0,18,3,0,0,48,3,0,0,155,2,0,0,8,3,0,0,40,3,0,0,154,2,0,0,94,2,0,0,197,3,0,0,132,3,0,0,159,3,0,0,151,3,0,0,150,2,0,0,46,3,0,0,50,3,0,0,198,3,0,0,230,3,0,0,45,1,0,0,209,0,0,0,2,4,0,0,221,0,0,0,97,1,0,0,43,1,0,0,39,1,0,0,93,4,0,0,1,6,0,0,171,4,0,0,95,4,0,0,16,4,0,0,191,4,0,0,40,5,0,0,92,4,0,0,36,4,0,0,0,4,0,0,17,5,0,0,24,6,0,0,61,7,0,0,58,6,0,0,20,6,0,0,60,7,0,0,192,7,0,0,207,7,0,0,2,8,0,0,102,9,0,0,100,9,0,0,81,9,0,0,160,8,0,0,70,3,0,0,3,8,0,0,82,10,0,0,74,2,0,0,193,7,0,0,63,6,0,0,38,1,0,0,6,4,0,0,137,7,0,0,162,8,0,0,96,9,0,0,103,9,0,0,5,12,0,0,112,12,0,0,121,12,0,0,93,10,0,0,38,12,0,0,77,12,0,0,114,3,0,0,165,8,0,0,8,12,0,0,197,2,0,0,17,15,0,0,196,12,0,0,142,15,0,0,22,14,0,0,150,4,0,0,119,14,0,0,156,15,0,0,37,12,0,0,30,15,0,0,39,12,0,0,31,15,0,0,23,14,0,0,205,12,0,0,85,3,0,0,9,12,0,0,120,12,0,0,144,15,0,0,33,5,0,0,87,3,0,0,86,3,0,0,142,6,0,0,157,15,0,0,4,12,0,0,88,14,0,0,32,10,0,0,44,10,0,0,76,12,0,0,47,5,0,0,141,15,0,0,120,17,0,0,83,16,0,0,151,16,0,0,15,24,0,0,13,24,0,0,251,18,0,0,170,18,0,0,42,32,0,0,64,10,0,0,237,24,0,0,235,28,0,0,85,20,0,0,227,24,0,0,161,18,0,0,84,3,0,0,83,3,0,0,28,15,0,0,123,12,0,0,55,12,0,0,29,16,0,0,203,18,0,0,66,17,0,0,125,25,0,0,149,16,0,0,59,30,0,0,107,24,0,0,136,5,0,0,42,28,0,0,184,20,0,0,58,30,0,0,236,24,0,0,70,31,0,0,250,18,0,0,83,10,0,0,232,28,0,0,85,10,0,0,41,28,0,0,123,17,0,0,82,16,0,0,160,18,0,0,137,5,0,0,80,9,0,0,43,28,0,0,80,10,0,0,139,32,0,0,14,24,0,0,39,32,0,0,86,37,0,0,32,30,0,0,231,6,0,0,40,28,0,0,122,25,0,0,132,6,0,0,162,32,0,0,34,31,0,0,24,48,0,0,207,57,0,0,37,62,0,0,87,37,0,0,76,41,0,0,166,40,0,0,17,13,0,0,169,40,0,0,121,41,0,0,70,13,0,0,86,10,0,0,206,57,0,0,204,48,0,0,154,50,0,0,157,20,0,0,15,81,0,0,28,69,0,0,40,32,0,0,153,50,0,0,237,28,0,0,185,20,0,0,133,15,0,0,122,12,0,0,0,24,0,0,65,3,0,0,202,18,0,0,200,57,0,0,157,50,0,0,13,13,0,0,32,62,0,0,68,81,0,0,69,13,0,0,208,48,0,0,109,24,0,0,213,48,0,0,15,13,0,0,64,13,0,0,20,65,0,0,161,32,0,0,127,41,0,0,36,62,0,0,241,50,0,0,71,64,0,0,212,48,0,0,168,40,0,0,14,13,0,0,29,69,0,0,68,64,0,0,126,41,0,0,66,64,0,0,210,48,0,0,207,48,0,0,33,62,0,0,38,62,0,0,165,40,0,0,26,69,0,0,72,13,0,0,22,26,0,0,68,13,0,0,24,69,0,0,155,20,0,0,202,57,0,0,152,20,0,0,61,64,0,0,27,69,0,0,156,20,0,0,243,50,0,0,203,48,0,0,115,128,0,0,34,62,0,0,154,82,0,0,170,32,0,0,204,57,0,0,138,115,0,0,48,101,0,0,137,115,0,0,147,97,0,0,113,128,0,0,67,64,0,0,206,48,0,0,71,81,0,0,136,115,0,0,69,81,0,0,114,128,0,0,33,69,0,0,71,13,0,0,124,41,0,0,205,48,0,0,202,48,0,0,11,0,0,0,12,0,0,0,131,0,0,0,228,0,0,0,72,0,0,0,2,1,0,0,204,1,0,0,245,1,0,0,151,0,0,0,11,2,0,0,36,1,0,0,83,4,0,0,39,6,0,0,57,6,0,0,5,6,0,0,23,5,0,0,184,1,0,0,99,6,0,0,103,6,0,0,195,7,0,0,35,8,0,0,97,9,0,0,99,9,0,0,90,14,0,0,89,14,0,0,43,10,0,0,191,12,0,0,146,2,0,0,45,10,0,0,208,7,0,0,83,9,0,0,197,12,0,0,132,15,0,0,171,4,0,0,167,20,0,0,138,6,0,0,122,17,0,0,46,5,0,0,66,20,0,0,44,5,0,0,119,12,0,0,143,15,0,0,170,4,0,0,148,16,0,0,1,24,0,0,196,18,0,0,123,41,0,0,82,9,0,0,25,31,0,0,165,6,0,0,73,17,0,0,197,18,0,0,3,24,0,0,242,34,0,0,155,50,0,0,32,69,0,0,158,20,0,0,19,13,0,0,22,31,0,0,233,28,0,0,28,16,0,0,230,6,0,0,201,57,0,0,145,97,0,0,142,124,0,0,146,97,0,0,99,202,0,0,205,57,0,0,144,97,0,0,132,104,0,0,133,104,0,0,130,115,0,0,73,13,0,0,65,13,0,0,12,69,0,0,154,20,0,0,209,48,0,0,119,128,0,0,35,62,0,0,21,26,0,0,1,231,0,0,2,231,0,0,121,128,0,0,42,130,0,0,24,162,0,0,135,120,0,0,63,64,0,0,11,82,0,0,155,82,0,0,0,231,0,0,25,69,0,0,7,0,0,0,224,0,0,0,208,0,0,0,155,3,0,0,229,3,0,0,99,1,0,0,62,6,0,0,201,7,0,0,6,8,0,0,84,9,0,0,68,16,0,0,68,31,0,0,124,25,0,0,69,31,0,0,81,10,0,0,71,31,0,0,81,9,0,0,45,5,0,0,145,34,0,0,47,9,0,0,84,10,0,0,18,13,0,0,125,41,0,0,12,13,0,0,153,20,0,0,158,50,0,0,240,50,0,0,37,32,0,0,198,57,0,0,87,10,0,0,70,62,0,0,66,13,0,0,139,115,0,0,70,81,0,0,70,64,0,0,120,128,0,0,14,81,0,0,134,120,0,0,4,41,0,0,86,65,0,0,87,65,0,0,50,96,0,0,211,48,0,0,206,139,0,0,64,64,0,0,62,64,0,0,20,164,0,0,87,4,1,0,117,128,0,0,135,104,0,0,143,124,0,0,199,57,0,0,135,115,0,0,112,128,0,0,207,139,0,0,42,72,1,0,86,4,1,0,43,72,1,0,23,26,0,0,134,104,0,0,13,69,0,0,19,0,0,0,107,0,0,0,21,6,0,0,11,8,0,0,43,8,0,0,82,9,0,0,91,14,0,0,226,24,0,0,108,24,0,0,24,31,0,0,159,50,0,0,67,13,0,0,41,62,0,0,64,81,0,0,65,81,0,0,98,202,0,0,51,96,0,0,66,60,0,0,40,62,0,0,15,69,0,0,26,162,0,0,132,115,0,0,25,162,0,0,3,231,0,0,27,162,0,0,20,26,0,0,131,115,0,0,230,69,0,0,122,0,0,0,44,1,0,0,204,12,0,0,143,6,0,0,2,24,0,0,82,10,0,0,83,9,0,0,69,64,0,0,32,26,0,0,31,69,0,0,164,0,0,0,53,7,0,0,236,28,0,0,41,32,0,0,163,32,0,0,30,69,0,0,105,0,0,0,36,12,0,0,36,32,0,0,242,50,0,0,66,81,0,0,150,1,0,0,35,5,0,0,166,0,0,0,123,25,0,0,11,3,0,0,46,9,0,0,233,3,0,0,39,62,0,0,96,1,0,0,67,81,0,0,82,6,0,0,65,64,0,0,52,7,0,0,167,40,0,0,15,8,0,0,131,20,0,0,124,9,0,0,64,3,0,0,139,6,0,0,34,5,0,0,84,16,0,0,150,16,0,0,23,31,0,0,43,32,0,0,234,28,0,0,160,32,0,0,120,41,0,0,38,32,0,0,122,41,0,0,203,57,0,0,43,62,0,0,159,20,0,0,156,50,0,0,133,115,0,0,116,128,0,0,14,69,0,0,42,62,0,0,73,81,0,0,118,128,0,0,134,115,0,0,72,81,0,0,0,0,0,0,9,7,2,3,4,4,5,6,6,7,7,8,8,8,9,9,9,9,10,10,10,10,10,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,16,16,16,16,16,16,16,16,17,16,16,16,16,16,16,16,3,5,6,8,9,10,11,12,12,13,13,14,14,15,15,15,15,15,16,16,16,16,16,17,17,17,17,18,17,17,4,6,9,10,12,13,14,14,15,15,5,8,10,12,14,15,6,9,11,6,10,13,7,10,14,7,11,8,12,8,12,8,13,9,13,9,14,9,14,10,14,10,15,10,15,10,15,10,15,11,16,11,16,11,16,11,16,11,17,12,17,12,17,12,18,12,18,12,18,12,18,13,19,13,18,13,19,13,19,13,20,13,18,13,20,13,20,14,19,14,21,14,19,14,20,14,21,14,19,14,20,14,21,15,21,14,21,15,22,15,22,15,0,0,0,0,9,5,2,4,4,5,5,5,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,11,11,11,11,11,12,12,12,12,12,12,12,12,12,13,12,12,12,12,12,12,12,13,12,12,12,12,12,12,12,12,13,12,12,12,13,13,13,13,12,12,12,12,12,12,13,12,13,13,13,13,13,13,13,14,14,13,13,13,13,13,13,13,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,13,14,13,13,13,13,13,14,13,14,14,13,14,14,13,14,13,13,14,14,13], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1660440);
/* memory initializer */ allocate([14,14,14,14,14,14,14,14,14,15,14,14,14,14,15,15,15,14,14,13,13,12,12,13,13,13,14,14,15,14,15,15,14,13,14,15,15,15,14,14,14,14,15,14,14,15,15,15,14,15,14,14,14,14,14,15,15,16,15,15,15,14,15,15,15,15,14,14,16,14,15,14,14,15,15,15,15,16,15,14,15,15,15,16,15,15,14,14,14,4,7,8,8,9,9,9,9,10,10,11,11,11,11,11,11,12,11,11,11,12,12,12,12,12,12,12,12,12,11,12,12,12,13,13,13,13,13,13,13,12,12,13,13,13,13,14,14,13,14,13,13,13,14,14,15,15,14,13,13,13,14,14,15,15,15,16,14,15,17,17,15,15,15,15,15,14,16,14,16,16,16,16,16,16,15,15,17,15,16,15,6,8,10,10,10,11,11,11,12,12,13,13,13,13,14,13,14,13,14,14,14,14,14,15,15,14,14,14,14,14,14,15,15,15,15,16,15,15,16,15,15,15,14,16,15,15,18,17,16,17,15,14,15,16,16,19,17,19,16,17,15,7,10,11,12,12,12,12,13,13,13,14,15,14,15,15,16,15,14,14,15,16,15,16,16,16,16,15,15,7,11,12,13,13,14,14,15,15,15,8,11,13,14,14,15,9,12,14,14,15,9,13,10,13,10,14,10,14,11,15,11,15,11,14,12,15,12,13,13,13,13,13,13,14,13,14,14,14,14,14,14,15,14,15,16,15,14,15,16,15,15,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,112,0,113,0,114,0,115,0,116,0,117,0,118,0,119,0,120,0,121,0,122,0,123,0,124,0,125,0,126,0,127,0,128,0,129,0,130,0,131,0,132,0,133,0,134,0,135,0,136,0,137,0,138,0,139,0,140,0,141,0,142,0,143,0,144,0,145,0,146,0,147,0,148,0,149,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,0,0,1,0,2,0,3,0,4,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,0,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,64,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,128,64,0,0,160,64,0,0,160,64,0,0,160,64,0,0,160,64,0,0,160,64,0,0,192,64,0,0,192,64,0,0,224,64,0,0,224,64,0,0,0,65,0,0,0,65,0,0,16,65,0,0,16,65,0,0,32,65,0,0,32,65,0,0,48,65,0,0,48,65,0,0,64,65,0,0,64,65,0,0,80,65,0,0,80,65,0,0,96,65,0,0,96,65,0,0,112,65,0,0,112,65,0,0,128,65,0,0,128,65,0,0,136,65,0,0,136,65,0,0,144,65,0,0,144,65,0,0,152,65,0,0,152,65,0,0,160,65,0,0,160,65,0,0,168,65,0,0,168,65,0,0,176,65,0,0,176,65,0,0,184,65,0,0,184,65,0,0,192,65,0,0,192,65,0,0,200,65,0,0,200,65,0,0,208,65,0,0,208,65,0,0,216,65,0,0,216,65,0,0,224,65,74,0,0,0,43,0,0,0,0,0,0,0,3,0,0,0,6,0,0,0,9,0,0,0,15,0,0,0,16,0,0,0,22,0,0,0,17,0,0,0,22,0,0,0,40,0,0,0,47,0,0,0,38,0,0,0,41,0,0,0,69,0,0,0,85,0,0,0,93,0,0,0,66,0,0,0,78,0,0,0,81,0,0,0,94,0,0,0,141,0,0,0,168,0,0,0,173,0,0,0,128,0,0,0,150,0,0,0,159,0,0,0,170,0,0,0,190,0,0,0,28,1,0,0,83,1,0,0,88,1,0,0,112,1,0,0,4,1,0,0,13,1,0,0,5,1,0,0,3,1,0,0,47,1,0,0,119,1,0,0,117,1,0,0,87,1,0,0,116,1,0,0,37,2,0,0,59,2,0,0,13,2,0,0,31,2,0,0,129,2,0,0,123,2,0,0,130,2,0,0,172,2,0,0,253,2,0,0,79,4,0,0,120,4,0,0,77,4,0,0,236,2,0,0,78,4,0,0,100,5,0,0,9,4,0,0,11,4,0,0,1,5,0,0,69,5,0,0,243,4,0,0,65,5,0,0,59,4,0,0,241,4,0,0,244,4,0,0,253,8,0,0,148,10,0,0,17,8,0,0,136,11,0,0,145,11,0,0,147,11,0,0,234,8,0,0,153,8,0,0,138,11,0,0,114,9,0,0,229,9,0,0,143,10,0,0,132,10,0,0,142,10,0,0,0,10,0,0,48,8,0,0,232,8,0,0,149,11,0,0,113,8,0,0,58,8,0,0,20,8,0,0,115,8,0,0,254,11,0,0,40,23,0,0,149,21,0,0,18,23,0,0,42,16,0,0,33,16,0,0,41,23,0,0,46,21,0,0,195,19,0,0,33,23,0,0,151,21,0,0,27,21,0,0,242,16,0,0,3,20,0,0,3,23,0,0,3,21,0,0,8,23,0,0,193,19,0,0,14,23,0,0,12,23,0,0,225,16,0,0,234,17,0,0,32,16,0,0,0,21,0,0,250,23,0,0,4,23,0,0,5,23,0,0,240,23,0,0,251,23,0,0,230,33,0,0,45,43,0,0,198,32,0,0,41,43,0,0,74,46,0,0,172,35,0,0,25,21,0,0,243,35,0,0,44,43,0,0,192,33,0,0,254,23,0,0,215,35,0,0,249,23,0,0,231,18,0,0,192,19,0,0,97,34,0,0,211,35,0,0,87,32,0,0,86,32,0,0,210,33,0,0,199,32,0,0,210,35,0,0,236,32,0,0,192,68,0,0,226,47,0,0,91,71,0,0,3,42,0,0,227,47,0,0,226,33,0,0,208,33,0,0,49,42,0,0,19,46,0,0,5,46,0,0,229,71,0,0,14,0,0,0,36,0,0,0,136,0,0,0,185,0,0,0,12,1,0,0,36,2,0,0,179,2,0,0,131,2,0,0,237,2,0,0,123,4,0,0,30,4,0,0,61,4,0,0,245,4,0,0,253,5,0,0,146,10,0,0,150,11,0,0,56,8,0,0,113,9,0,0,131,11,0,0,128,11,0,0,249,11,0,0,211,17,0,0,232,17,0,0,215,17,0,0,39,21,0,0,248,17,0,0,115,16,0,0,240,16,0,0,228,16,0,0,248,23,0,0,98,16,0,0,2,20,0,0,227,23,0,0,26,21,0,0,119,16,0,0,43,21,0,0,13,23,0,0,211,33,0,0,65,46,0,0,194,19,0,0,41,0,0,0,169,0,0,0,93,2,0,0,25,4,0,0,68,5,0,0,139,11,0,0,228,9,0,0,210,17,0,0,38,21,0,0,36,23,0,0,230,18,0,0,11,21,0,0,255,23,0,0,38,46,0,0,75,46,0,0,40,43,0,0,227,33,0,0,20,42,0,0,90,71,0,0,18,46,0,0,87,0,0,0,62,2,0,0,144,10,0,0,240,11,0,0,114,16,0,0,2,21,0,0,214,35,0,0,237,32,0,0,48,42,0,0,199,68,0,0,140,0,0,0,127,4,0,0,42,21,0,0,98,34,0,0,4,46,0,0,161,0,0,0,249,5,0,0,115,1,0,0,117,8,0,0,113,1,0,0,45,21,0,0,227,2,0,0,226,23,0,0,173,2,0,0,193,33,0,0,121,4,0,0,231,33,0,0,31,4,0,0,78,92,0,0,67,5,0,0,79,92,0,0,145,10,0,0,141,137,0,0,151,11,0,0,70,135,0,0,112,9,0,0,69,135,0,0,133,11,0,0,86,168,0,0,47,21,0,0,142,14,1,0,229,16,0,0,87,168,0,0,15,23,0,0,17,29,2,0,88,42,0,0,143,14,1,0,64,46,0,0,19,29,2,0,89,42,0,0,37,58,4,0,2,42,0,0,33,58,4,0,193,68,0,0,72,116,8,0,228,71,0,0,32,58,4,0,42,84,0,0,73,116,8,0,140,137,0,0,88,2,0,0,61,0,0,0,0,0,0,0,5,0,0,0,8,0,0,0,8,0,0,0,12,0,0,0,27,0,0,0,31,0,0,0,21,0,0,0,36,0,0,0,50,0,0,0,58,0,0,0,38,0,0,0,44,0,0,0,47,0,0,0,74,0,0,0,77,0,0,0,97,0,0,0,112,0,0,0,115,0,0,0,72,0,0,0,82,0,0,0,90,0,0,0,93,0,0,0,110,0,0,0,153,0,0,0,158,0,0,0,193,0,0,0,206,0,0,0,228,0,0,0,240,0,0,0,147,0,0,0,158,0,0,0,162,0,0,0,161,0,0,0,184,0,0,0,210,0,0,0,211,0,0,0,46,1,0,0,48,1,0,0,222,0,0,0,45,1,0,0,155,1,0,0,228,1,0,0,57,1,0,0,58,1,0,0,63,1,0,0,79,1,0,0,109,1,0,0,162,1,0,0,124,2,0,0,126,2,0,0,50,3,0,0,60,3,0,0,63,3,0,0,139,3,0,0,150,3,0,0,197,3,0,0,112,2,0,0,124,2,0,0,90,2,0,0,149,3,0,0,72,2,0,0,189,4,0,0,251,4,0,0,98,6,0,0,97,6,0,0,27,7,0,0,230,4,0,0,255,4,0,0,102,6,0,0,28,7,0,0,26,7,0,0,31,7,0,0,148,7,0,0,54,5,0,0,226,4,0,0,142,7,0,0,238,4,0,0,24,5,0,0,53,5,0,0,251,4,0,0,141,7,0,0,48,5,0,0,128,6,0,0,143,6,0,0,203,5,0,0,101,9,0,0,166,6,0,0,103,9,0,0,127,9,0,0,130,6,0,0,174,6,0,0,208,12,0,0,40,14,0,0,19,15,0,0,31,15,0,0,245,9,0,0,211,12,0,0,17,15,0,0,38,9,0,0,100,9,0,0,50,15,0,0,18,15,0,0,48,15,0,0,102,9,0,0,11,13,0,0,104,10,0,0,145,11,0,0,199,9,0,0,115,11,0,0,250,18,0,0,29,19,0,0,249,19,0,0,160,28,0,0,156,25,0,0,122,28,0,0,140,25,0,0,72,18,0,0,116,28,0,0,100,28,0,0,158,19,0,0,253,18,0,0,119,10,0,0,252,18,0,0,123,28,0,0,202,18,0,0,204,20,0,0,210,20,0,0,227,20,0,0,220,20,0,0,220,18,0,0,68,51,0,0,152,37,0,0,60,38,0,0,59,51,0,0,230,37,0,0,28,26,0,0,60,30,0,0,226,20,0,0,212,51,0,0,17,26,0,0,73,51,0,0,206,60,0,0,225,20,0,0,52,26,0,0,62,39,0,0,39,38,0,0,63,39,0,0,238,56,0,0,113,57,0,0,103,60,0,0,97,60,0,0,61,51,0,0,194,56,0,0,63,38,0,0,205,56,0,0,56,38,0,0,65,46,0,0,31,53,0,0,72,51,0,0,102,60,0,0,98,53,0,0,137,41,0,0,213,39,0,0,60,51,0,0,79,46,0,0,59,52,0,0,223,45,0,0,200,75,0,0,192,41,0,0,87,46,0,0,114,76,0,0,183,37,0,0,71,53,0,0,64,53,0,0,211,41,0,0,69,76,0,0,187,37,0,0,0,102,0,0,115,76,0,0,206,75,0,0,123,53,0,0,166,41,0,0,210,41,0,0,62,38,0,0,138,41,0,0,131,113,0,0,2,102,0,0,88,121,0,0,102,75,0,0,125,83,0,0,117,83,0,0,233,79,0,0,103,75,0,0,159,121,0,0,201,75,0,0,254,81,0,0,59,106,0,0,182,91,0,0,168,79,0,0,143,114,0,0,118,83,0,0,44,73,0,0,126,83,0,0,90,121,0,0,60,106,0,0,21,229,0,0,135,120,0,0,58,104,0,0,249,81,0,0,253,81,0,0,106,204,0,0,138,106,0,0,109,204,0,0,179,91,0,0,59,104,0,0,252,81,0,0,120,83,0,0,142,114,0,0,134,120,0,0,183,91,0,0,164,242,0,0,91,121,0,0,60,104,0,0,193,159,0,0,61,104,0,0,82,183,0,0,120,150,0,0,232,163,0,0,199,106,0,0,240,81,0,0,89,183,0,0,243,106,0,0,107,75,0,0,160,242,0,0,173,242,0,0,195,150,0,0,24,229,0,0,92,183,0,0,88,212,0,0,107,204,0,0,124,83,0,0,170,103,0,0,234,79,0,0,58,52,0,0,113,204,0,0,127,150,0,0,196,159,0,0,194,150,0,0,22,229,0,0,161,242,0,0,92,212,0,0,93,212,0,0,94,212,0,0,185,47,1,0,126,150,0,0,47,152,1,0,131,152,0,0,196,150,0,0,83,183,0,0,184,47,1,0,168,242,0,0,33,202,1,0,197,150,0,0,26,229,0,0,39,202,1,0,60,47,1,0,113,212,0,0,170,242,0,0,91,183,0,0,187,47,1,0,169,242,0,0,172,242,0,0,90,212,0,0,79,183,0,0,200,150,0,0,145,110,1,0,202,150,0,0,191,47,1,0,167,208,0,0,3,49,1,0,22,213,0,0,153,110,1,0,189,44,1,0,234,163,0,0,41,152,1,0,85,183,0,0,167,155,2,0,40,202,1,0,165,155,2,0,147,110,1,0,44,152,1,0,40,152,1,0,148,89,2,0,235,163,0,0,41,202,1,0,144,110,1,0,37,202,1,0,45,152,1,0,38,202,1,0,155,110,1,0,86,183,0,0,124,150,0,0,151,89,2,0,95,183,0,0,211,152,1,0,87,183,0,0,42,154,1,0,91,212,0,0,23,229,0,0,36,202,1,0,35,202,1,0,34,202,1,0,88,183,0,0,151,110,1,0,20,205,0,0,0,49,1,0,7,0,0,0,59,0,0,0,107,0,0,0,151,0,0,0,56,1,0,0,37,1,0,0,115,1,0,0,88,2,0,0,53,3,0,0,142,2,0,0,198,4,0,0,21,7,0,0,41,7,0,0,239,4,0,0,25,5,0,0,237,4,0,0,50,5,0,0,140,6,0,0,134,6,0,0,120,9,0,0,93,14,0,0,49,14,0,0,244,9,0,0,146,11,0,0,248,18,0,0,6,13,0,0,103,10,0,0,68,13,0,0,118,10,0,0,89,13,0,0,205,18,0,0,120,28,0,0,117,28,0,0,159,25,0,0,143,25,0,0,103,28,0,0,198,20,0,0,121,28,0,0,118,28,0,0,148,11,0,0,27,13,0,0,50,30,0,0,49,30,0,0,176,26,0,0,5,26,0,0,161,26,0,0,58,51,0,0,229,37,0,0,38,38,0,0,65,53,0,0,68,53,0,0,33,52,0,0,70,53,0,0,85,46,0,0,86,46,0,0,45,73,0,0,222,45,0,0,155,41,0,0,220,45,0,0,122,53,0,0,156,36,0,0,139,102,0,0,127,199,1,0,32,202,1,0,95,212,0,0,134,152,0,0,154,110,1,0,167,242,0,0,81,183,0,0,238,163,0,0,89,207,0,0,87,207,0,0,84,183,0,0,166,208,0,0,152,110,1,0,96,183,0,0,198,106,0,0,240,163,0,0,190,47,1,0,4,49,1,0,165,242,0,0,239,163,0,0,114,212,0,0,186,44,1,0,46,152,1,0,156,110,1,0,126,199,1,0,208,152,1,0,5,49,1,0,146,110,1,0,93,183,0,0,89,212,0,0,26,0,0,0,192,0,0,0,108,1,0,0,205,3,0,0,80,3,0,0,123,6,0,0,30,5,0,0,169,6,0,0,244,9,0,0,114,11,0,0,9,13,0,0,73,18,0,0,61,30,0,0,161,28,0,0,31,26,0,0,33,23,0,0,138,26,0,0,232,22,0,0,71,51,0,0,53,26,0,0,157,36,0,0,154,41,0,0,150,37,0,0,78,46,0,0,139,41,0,0,130,113,0,0,70,76,0,0,186,37,0,0,64,46,0,0,214,39,0,0,232,79,0,0,7,102,0,0,16,83,0,0,132,152,0,0,225,114,0,0,61,106,0,0,106,75,0,0,122,76,0,0,3,102,0,0,123,76,0,0,40,52,0,0,5,102,0,0,100,150,0,0,192,159,0,0,222,113,0,0,1,102,0,0,178,91,0,0,133,152,0,0,226,163,0,0,31,198,1,0,187,44,1,0,80,183,0,0,88,207,0,0,125,150,0,0,149,89,2,0,173,104,6,0,90,183,0,0,194,159,0,0,127,83,0,0,94,183,0,0,174,63,1,0,188,47,1,0,49,0,0,0,196,1,0,0,197,4,0,0,184,5,0,0,244,12,0,0,111,9,0,0,70,13,0,0,87,30,0,0,4,26,0,0,37,38,0,0,70,51,0,0,249,40,0,0,71,76,0,0,224,114,0,0,105,75,0,0,32,52,0,0,87,121,0,0,57,102,0,0,158,121,0,0,89,121,0,0,129,120,0,0,104,75,0,0,195,159,0,0,214,159,0,0,112,204,0,0,241,163,0,0,190,44,1,0,14,227,0,0,27,229,0,0,242,106,0,0,188,44,1,0,125,199,1,0,171,242,0,0,189,47,1,0,47,170,1,0,236,163,0,0,115,212,0,0,119,83,0,0,233,163,0,0,43,152,1,0,0,227,0,0,63,47,1,0,95,207,0,0,192,150,0,0,60,140,3,0,148,110,1,0,149,110,1,0,61,47,1,0,164,155,2,0,166,155,2,0,124,199,1,0,186,168,6,0,92,84,3,0,87,52,3,0,172,104,6,0,187,168,6,0,157,110,1,0,25,229,0,0,150,89,2,0,62,47,1,0,54,0,0,0,62,3,0,0,173,6,0,0,3,13,0,0,200,18,0,0,74,18,0,0,66,60,0,0,205,60,0,0,6,102,0,0,128,120,0,0,82,104,0,0,58,106,0,0,180,91,0,0,162,242,0,0,199,159,0,0,185,44,1,0,108,204,0,0,232,166,0,0,193,150,0,0,74,0,0,0,85,3,0,0,249,18,0,0,232,20,0,0,190,26,0,0,182,37,0,0,46,73,0,0,198,159,0,0,255,81,0,0,111,204,0,0,203,150,0,0,113,208,0,0,209,152,1,0,184,44,1,0,61,140,3,0,175,63,1,0,201,150,0,0,157,0,0,0,57,5,0,0,206,18,0,0,31,52,0,0,193,41,0,0,51,75,0,0,227,163,0,0,112,208,0,0,150,110,1,0,99,183,0,0,160,0,0,0,206,9,0,0,204,56,0,0,61,52,0,0,250,81,0,0,136,152,0,0,186,47,1,0,223,0,0,0,117,10,0,0,167,41,0,0,197,159,0,0,1,227,0,0,123,150,0,0,231,1,0,0,201,18,0,0,251,81,0,0,137,152,0,0,166,242,0,0,111,1,0,0,185,28,0,0,90,207,0,0,191,44,1,0,121,150,0,0,114,2,0,0,21,26,0,0,122,150,0,0,203,3,0,0,246,37,0,0,98,183,0,0,141,2,0,0,96,60,0,0,94,207,0,0,82,3,0,0,204,60,0,0,47,7,0,0,134,113,0,0,236,4,0,0,121,83,0,0,142,6,0,0,135,152,0,0,167,6,0,0,241,106,0,0,41,14,0,0,91,207,0,0,49,15,0,0,112,212,0,0,198,9,0,0,251,19,0,0,2,49,1,0,165,25,0,0,1,49,1,0,131,25,0,0,101,28,0,0,79,18,0,0,199,20,0,0,38,23,0,0,191,26,0,0,4,51,0,0,36,38,0,0,65,60,0,0,215,39,0,0,221,45,0,0,84,46,0,0,60,52,0,0,4,102,0,0,129,113,0,0,58,102,0,0,169,79,0,0,59,102,0,0,17,83,0,0,122,83,0,0,57,104,0,0,181,91,0,0,47,73,0,0,240,106,0,0,199,150,0,0,110,204,0,0,123,83,0,0,92,207,0,0,86,207,0,0,210,152,1,0,93,207,0,0,237,163,0,0,163,242,0,0,42,152,1,0,97,183,0,0,198,150,0,0,8,7,2,3,3,4,4,5,5,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,13,12,12,12,12,12,12,13,13,13,13,13,13,13,12,12,13,13,13,13,13,13,13,13,14,14,13,13,14,13,13,14,14,14,14,14,14,14,14,14,14,13,14,14,14,14,14,14,14,15,14,15,14,14,14,14,14,14,15,14,14,14,14,14,14,14,15,15,15,15,14,15,15,15,15,15,15,15,15,15,15,15,15,4,7,8,9,10,10,10,11,11,11,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,13,14,15,14,14,6,9,11,12,12,12,13,13,13,13,14,14,14,14,14,14,15,15,15,15,7,10,12,13,14,14,14,15,15,15,8,11,13,14,15,9,12,9,13,10,13,10,14,11,15,11,15,12,15,12,15,12,16,12,17,13,17,13,17,13,18,14,17,14,19,14,18,14,19,14,20,15,20,15,21,15,20,16,21,16,11,6,2,3,4,5,5,5,5,6,6,6,6,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,10,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,11,12,12,12,12,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,14,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,14,14,15,15,15,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,15,15,15,15,16,16,16,15,16,15,15,16,16,16,16,15,16,16,16,15,16,16,15,16,16,16,16,16,16,16,16,16,16,15,15,16,16,15,16,16,16,17,17,17,16,16,17,16,16,16,16,17,16,17,17,16,16,15,15,15,16,17,16,17,16,16,17,17,17,17,17,17,16,17,17,17,16,17,17,16,17,17,17,16,17,17,16,16,17,17,17,18,17,17,17,17,17,18,18,17,17,17,19,17,19,18,17,17,18,17,17,18,17,17,17,18,17,17,18,17,17,17,17,17,16,17,17,17,17,18,16,17,4,6,8,9,9,10,10,10,10,11,11,11,11,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,13,13,13,13,13,13,14,14,14,14,14,14,15,15,15,15,15,15,16,15,15,15,15,15,15,17,17,17,16,18,16,17,17,16,16,17,17,18,17,16,17,17,17,16,17,17,18,17,18,17,17,17,18,17,17,5,8,10,10,11,11,12,12,12,13,13,14,13,13,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,16,16,15,16,16,15,15,15,15,15,16,16,15,15,16,16,17,17,18,17,16,17,18,19,17,16,16,17,17,17,6,9,11,12,12,13,13,13,14,14,14,15,15,15,16,15,15,15,15,15,15,16,16,16,16,17,18,16,16,16,18,17,16,17,18,17,17,16,17,17,16,17,16,17,18,18,18,17,19,19,17,20,19,18,19,20,18,16,18,17,7,10,12,13,13,14,14,14,15,15,16,16,16,16,16,18,16,17,17,8,11,13,14,14,15,16,16,16,16,17,17,17,18,18,17,17,8,12,14,15,15,15,17,17,18,17,9,12,14,15,16,16,17,9,13,15,16,16,17,9,13,16,16,16,10,13,16,18,17,10,14,17,10,14,17,11,14,16,11,14,11,15,12,16,12,16,12,16,12,16,12,17,13,13,17,13,17,13,13,14,14,14,14,14,14,14,15,15,15,15,15,15,15,16,15,16,16,16,16,16,16,17,16,16,16,16,17,16,17,16,17,17,17,0,0,0,0,0,0,170,153,172,185,189,170,122,168,168,168,121,121,119,168,151,121,137,119,135,135,104,120,102,134,135,103,104,102,118,118,87,103,85,117,101,86,86,85,101,101,86,69,85,84,85,85,69,85,84,85,85,69,86,100,102,118,87,103,119,119,152,136,157,191,186,236,252,186,239,252,0,0,207,155,175,255,255,171,138,152,184,249,120,137,119,249,247,121,137,119,151,151,104,104,102,166,135,119,104,102,117,118,103,86,101,117,117,86,86,85,101,101,86,86,85,84,85,85,69,85,83,85,101,53,103,100,102,102,86,120,134,136,168,251,175,255,175,255,255,255,255,255,0,0,220,173,204,202,207,254,223,255,233,255,153,121,151,151,151,121,121,119,151,151,121,121,119,134,135,104,104,118,118,118,103,87,102,101,118,102,86,85,100,101,85,69,85,84,85,85,53,85,83,85,101,53,103,100,103,135,87,138,134,139,186,154,205,170,175,252,255,255,223,255,0,0,34,30,24,24,16,16,16,16,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,34,30,24,24,16,16,16,16,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,34,30,30,30,24,24,16,16,16,16,16,16,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,34,34,30,30,24,24,24,24,16,16,16,16,16,16,16,16,16,16,16,16,16,16,10,10,10,10,10,10,10,10,34,34,30,30,30,30,30,30,24,24,24,24,24,24,24,24,24,24,24,24,16,16,16,16,16,16,16,16,16,16,0,0,156,2,122,244,26,251,2,249,7,246,88,236,31,238,235,251,92,11,246,12,253,244,139,245,76,252,247,244,158,238,233,229,172,254,202,5,4,251,238,4,206,253,155,229,1,5,179,0,6,251,48,246,38,228,195,236,1,27,107,9,82,246,100,255,75,18,223,240,0,0,240,223,92,8,34,254,31,245,21,2,97,7,199,10,101,5,213,228,231,232,218,19,100,246,110,233,5,7,56,2,96,247,19,243,85,238,164,231,175,226,97,245,6,17,84,244,131,251,104,10,235,4,227,3,151,10,96,246,106,215,186,6,111,226,74,245,123,8,231,246,8,4,235,2,166,252,246,224,213,205,34,12,248,18,159,239,19,246,11,4,70,7,64,252,28,230,154,1,250,22,67,246,188,245,96,240,196,255,34,28,144,245,166,5,0,6,9,241,209,4,74,235,0,27,53,6,165,239,81,14,128,242,22,224,227,225,104,5,90,18,165,237,191,231,88,212,168,31,190,65,162,3,92,27,245,4,239,220,7,10,41,18,28,46,113,13,231,233,175,4,238,9,73,255,101,221,216,224,158,12,200,244,37,248,15,218,63,223,183,50,14,12,92,8,160,241,85,218,176,244,71,226,115,25,21,247,38,246,188,24,251,242,12,234,86,220,133,212,167,21,105,254,191,229,198,187,183,244,48,45,108,14,140,26,250,254,162,213,192,248,107,28,92,52,83,244,157,214,72,19,244,0,85,247,96,10,192,14,220,234,53,240,210,232,83,8,95,3,206,244,26,243,207,6,42,248,128,255,252,247,39,231,14,13,209,249,235,255,118,4,3,241,217,248,253,24,241,9,224,244,140,219,128,230,189,20,194,7,59,247,118,238,236,2,143,7,45,244,19,254,217,219,246,20,121,12,115,238,248,6,176,18,142,254,74,7,33,4,159,248,174,28,126,245,239,245,164,2,157,253,10,254,187,8,198,248,15,249,255,247,243,3,40,15,95,246,161,8,104,255,32,10,13,11,212,21,23,11,118,227,23,244,202,236,67,23,241,35,161,238,185,2,68,15,166,22,157,238,220,237,183,247,68,21,246,245,65,1,78,251,30,11,218,247,204,13,54,2,60,253,73,239,182,3,116,19,165,14,196,1,76,246,174,13,183,6,86,255,238,0,149,242,7,1,66,8,43,248,57,9,86,227,72,251,131,36,64,251,83,240,70,203,73,254,92,31,120,239,105,1,111,241,57,21,212,7,137,237,21,251,110,240,63,30,237,32,149,241,37,252,78,20,89,254,126,4,255,250,48,3,241,28,13,16,147,240,130,10,30,0,222,4,239,11,221,255,166,250,10,255,47,250,3,22,90,253,189,245,98,12,222,18,23,238,216,7,218,251,31,3,127,255,205,2,242,17,89,58,210,41,161,1,199,10,58,7,63,236,127,251,209,240,193,28,120,233,189,16,154,2,163,5,86,252,20,0,185,247,95,249,128,241,182,242,92,247,110,0,88,8,120,244,12,0,224,249,84,242,193,248,221,250,61,249,136,4,210,253,173,6,88,0,39,238,194,0,58,254,115,244,233,244,126,249,239,254,36,8,101,255,67,255,184,246,127,6,240,251,111,246,230,244,167,250,124,2,8,255,139,245,237,5,79,0,59,244,171,241,51,252,121,7,67,246,64,235,19,253,247,4,169,244,4,243,84,241,150,241,219,248,159,244,245,249,56,245,130,250,100,4,52,7,214,248,200,1,194,2,80,239,211,1,96,239,139,248,241,5,110,4,129,255,30,252,131,253,45,250,162,230,105,3,3,248,12,241,24,245,190,253,7,9,231,248,72,10,20,244,176,7,129,2,170,4,101,7,11,16,198,24,211,255,174,4,112,8,87,250,155,8,44,248,177,6,190,13,92,10,155,16,120,11,128,240,0,5,131,0,60,250,11,11,8,0,120,248,98,10,185,13,127,12,208,252,127,10,51,249,129,250,132,11,189,15,138,1,3,255,18,5,190,16,51,0,101,238,224,255,109,253,63,15,14,22,44,234,224,245,75,22,162,253,210,4,185,249,189,235,152,2,243,253,36,14,112,247,33,246,171,6,201,16,77,243,21,247,44,3,40,247,133,22,16,2,41,243,72,5,136,6,175,10,217,4,177,251,55,243,177,242,193,15,112,6,107,244,106,251,164,5,74,0,150,3,207,7,147,3,254,251,64,246,187,249,242,7,134,11,229,0,136,247,245,7,15,0,16,251,48,255,32,242,250,5,69,2,211,5,194,3,203,245,222,246,37,14,48,250,119,247,45,249,81,0,162,21,152,5,47,247,5,252,99,3,214,0,20,247,26,250,108,249,0,11,27,255,247,9,147,250,147,10,248,1,223,1,223,10,15,252,213,9,49,250,196,249,109,2,137,7,108,255,158,8,64,239,12,5,135,250,241,253,219,4,85,245,117,7,0,5,101,8,35,250,104,14,98,2,17,238,234,12,215,242,83,7,52,14,63,251,14,10,209,9,169,5,254,243,141,236,46,3,34,7,63,246,138,16,19,240,128,6,36,255,90,13,234,3,91,4,13,3,122,6,79,15,242,23,68,12,124,4,225,15,236,5,47,3,199,0,167,4,185,9,1,10,117,9,139,9,2,3,229,232,139,21,144,254,129,243,166,4,23,4,158,14,15,27,215,247,36,1,27,12,212,16,10,253,105,246,11,2,81,15,204,15,106,5,85,0,15,17,238,3,28,251,70,250,153,250,12,15,43,6,179,255,16,8,100,3,245,19,103,11,54,255,103,1,3,254,66,14,134,12,255,8,157,6,16,5,89,11,189,240,229,0,84,251,228,246,89,23,255,241,37,3,241,14,190,243,162,14,162,253,53,0,243,254,27,243,94,2,226,7,220,250,224,15,142,1,0,0,5,0,55,0,231,0,222,1,206,3,217,3,200,7,205,7,200,15,221,15,228,31,236,31,4,0,12,0,53,0,114,0,234,0,237,0,226,1,209,3,211,3,224,3,216,7,207,15,213,15,54,0,52,0,113,0,232,0,236,0,225,1,207,3,221,3,219,3,208,7,199,15,212,15,228,15,230,0,112,0,233,0,221,1,227,1,210,3,220,3,204,7,202,7,222,7,216,15,234,15,219,31,223,1,235,0,220,1,230,1,213,3,222,3,203,7,221,7,220,7,205,15,226,15,231,15,225,31,208,3,224,1,228,1,214,3,197,7,209,7,219,7,210,15,224,7,217,15,235,15,227,31,233,31,196,7,229,1,215,3,198,7,207,7,218,7,203,15,218,15,227,15,233,15,230,31,243,31,247,31,211,7,216,3,225,3,212,7,217,7,211,15,222,15,221,31,217,31,226,31,234,31,241,31,246,31,210,7,212,3,218,3,199,7,215,7,226,7,206,15,219,15,216,31,238,31,240,63,244,31,242,63,225,7,223,3,201,7,214,7,202,15,208,15,229,15,230,15,235,31,239,31,243,63,244,63,245,63,224,15,206,7,213,7,198,15,209,15,225,15,224,31,232,31,240,31,241,63,248,63,246,63,252,127,232,15,223,7,201,15,215,15,220,15,220,31,223,31,237,31,245,31,249,63,251,63,253,127,254,127,231,31,204,15,214,15,223,15,222,31,218,31,229,31,242,31,250,63,247,63,252,63,253,63,255,127,0,0,0,0,0,0,14,0,5,0,16,0,48,0,111,0,241,0,250,1,254,3,3,0,0,0,4,0,18,0,44,0,106,0,117,0,248,0,15,0,2,0,6,0,20,0,46,0,105,0,114,0,245,0,47,0,17,0,19,0,42,0,50,0,108,0,236,0,250,0,113,0,43,0,45,0,49,0,109,0,112,0,242,0,249,1,239,0,104,0,51,0,107,0,110,0,238,0,249,0,252,3,248,1,116,0,115,0,237,0,240,0,246,0,246,1,253,1,253,3,243,0,244,0,247,0,247,1,251,1,252,1,255,3,0,0,5,0,55,0,116,0,242,0,235,1,237,3,247,7,4,0,12,0,53,0,113,0,236,0,238,0,238,1,245,1,54,0,52,0,114,0,234,0,241,0,233,1,243,1,245,3,115,0,112,0,235,0,240,0,241,1,240,1,236,3,250,3,243,0,237,0,232,1,239,1,239,3,241,3,249,3,251,7,237,1,239,0,234,1,242,1,243,3,248,3,249,7,252,7,238,3,236,1,244,1,244,3,247,3,248,7,253,15,254,15,246,7,240,3,242,3,246,3,250,7,253,7,252,15,255,15,254,7,253,3,241,1,235,1,244,1,234,1,240,1,252,3,253,7,246,3,229,1,234,0,108,0,113,0,104,0,240,0,230,1,247,3,243,1,239,0,50,0,39,0,40,0,38,0,49,0,235,0,247,1,232,1,111,0,46,0,8,0,4,0,6,0,41,0,107,0,238,1,239,1,114,0,45,0,2,0,0,0,3,0,47,0,115,0,250,1,231,1,110,0,43,0,7,0,1,0,5,0,44,0,109,0,236,1,249,1,238,0,48,0,36,0,42,0,37,0,51,0,236,0,242,1,248,3,228,1,237,0,106,0,112,0,105,0,116,0,241,0,250,3,255,7,249,3,246,1,237,1,248,1,233,1,245,1,251,3,252,7,0,0,0,0,0,0,255,31,247,15,244,7,232,7,241,3,238,7,249,7,248,15,253,31,253,15,241,7,232,3,232,1,240,0,236,1,238,3,242,7,250,15,244,15,239,3,242,1,232,0,112,0,236,0,240,1,234,3,243,7,235,7,235,1,234,0,26,0,8,0,25,0,238,0,239,1,237,7,240,3,242,0,115,0,11,0,0,0,10,0,113,0,243,0,233,7,239,7,238,1,239,0,24,0,9,0,27,0,235,0,233,1,236,7,246,7,235,3,243,1,237,0,114,0,233,0,241,1,237,3,247,7,246,15,240,7,233,3,237,1,241,0,234,1,236,3,248,7,249,15,252,31,252,15,245,15,234,7,243,3,242,3,245,7,251,15,254,31,0,0,0,0,0,0,7,0,22,0,246,0,24,0,8,0,239,0,239,1,243,0,248,7,25,0,23,0,237,0,21,0,1,0,226,0,240,0,112,0,240,3,238,1,241,0,250,7,238,0,228,0,242,3,246,7,239,3,253,7,5,0,20,0,242,0,9,0,4,0,229,0,244,0,232,0,244,3,6,0,2,0,231,0,3,0,0,0,107,0,227,0,105,0,243,1,235,0,230,0,246,3,110,0,106,0,244,1,236,3,240,1,249,3,245,0,236,0,251,7,234,0,111,0,247,3,249,7,243,3,255,15,233,0,109,0,248,3,108,0,104,0,245,1,238,3,242,1,244,7,247,7,241,3,254,15,237,3,241,1,245,7,254,7,245,3,252,7,0,0,0,0,0,0,0,0,9,0,239,0,11,0,25,0,240,0,235,1,230,1,242,3,10,0,53,0,239,1,52,0,55,0,233,1,237,1,231,1,243,3,238,1,237,3,250,31,236,1,242,1,249,7,248,7,248,3,248,15,8,0,56,0,246,3,54,0,117,0,241,3,235,3,236,3,244,15,24,0,118,0,244,7,57,0,116,0,239,3,243,1,244,1,246,7,232,1,234,3,252,31,242,0,241,1,251,15,245,3,243,7,252,15,238,0,247,3,254,127,240,1,245,7,253,127,251,31,250,63,255,255,241,0,240,3,252,63,234,1,238,3,251,63,246,15,250,15,252,127,242,7,245,15,254,255,244,3,247,7,251,127,247,15,249,15,250,127,0,0,0,0,0,0,243,1,111,0,253,1,235,0,35,0,234,0,247,1,232,0,250,1,242,0,45,0,112,0,32,0,6,0,43,0,110,0,40,0,233,0,249,1,102,0,248,0,231,0,27,0,241,0,244,1,107,0,245,1,236,0,42,0,108,0,44,0,10,0,39,0,103,0,26,0,245,0,36,0,8,0,31,0,9,0,0,0,7,0,29,0,11,0,48,0,239,0,28,0,100,0,30,0,12,0,41,0,243,0,47,0,240,0,252,1,113,0,242,1,244,0,33,0,230,0,247,0,104,0,248,1,238,0,34,0,101,0,49,0,2,0,38,0,237,0,37,0,106,0,251,1,114,0,254,1,105,0,46,0,246,0,255,1,109,0,246,1,0,0,0,0,0,0,0,0,6,0,25,0,61,0,156,0,198,0,167,1,144,3,194,3,223,3,230,7,243,7,251,15,236,7,250,15,254,15,142,3,5,0,1,0,8,0,20,0,55,0,66,0,146,0,175,0,145,1,165,1,181,1,158,3,192,3,162,3,205,3,214,7,174,0,23,0,7,0,9,0,24,0,57,0,64,0,142,0,163,0,184,0,153,1,172,1,193,1,177,3,150,3,190,3,202,3,157,0,60,0,21,0,22,0,26,0,59,0,68,0,145,0,165,0,190,0,150,1,174,1,185,1,161,3,145,3,165,3,213,3,148,0,154,0,54,0,56,0,58,0,65,0,140,0,155,0,176,0,195,0,158,1,171,1,188,1,159,3,143,3,169,3,207,3,147,0,191,0,62,0,63,0,67,0,69,0,158,0,167,0,185,0,148,1,162,1,186,1,195,1,166,3,167,3,187,3,212,3,159,0,160,1,143,0,141,0,144,0,152,0,166,0,182,0,196,0,159,1,175,1,191,1,153,3,191,3,180,3,201,3,231,3,168,0,182,1,171,0,164,0,170,0,178,0,194,0,197,0,152,1,164,1,184,1,140,3,164,3,196,3,198,3,221,3,232,3,173,0,175,3,146,1,189,0,188,0,142,1,151,1,154,1,163,1,177,1,141,3,152,3,183,3,211,3,209,3,219,3,221,7,180,0,222,3,169,1,155,1,156,1,161,1,170,1,173,1,179,1,139,3,178,3,184,3,206,3,225,3,224,3,210,7,229,7,183,0,227,7,187,1,168,1,166,1,176,1,178,1,183,1,155,3,154,3,186,3,181,3,214,3,215,7,228,3,216,7,234,7,186,0,232,7,160,3,189,1,180,1,138,3,196,1,146,3,170,3,176,3,188,3,215,3,212,7,220,7,219,7,213,7,240,7,193,0,251,7,200,3,163,3,149,3,157,3,172,3,174,3,197,3,216,3,226,3,230,3,228,7,231,7,224,7,233,7,247,7,144,1,242,7,147,3,190,1,192,1,148,3,151,3,173,3,195,3,193,3,210,3,218,7,217,7,223,7,235,7,244,7,250,7,149,1,248,7,189,3,156,3,171,3,168,3,179,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1670680);
/* memory initializer */ allocate([185,3,208,3,227,3,229,3,226,7,222,7,237,7,241,7,249,7,252,7,147,1,253,15,220,3,182,3,199,3,204,3,203,3,217,3,218,3,211,7,225,7,238,7,239,7,245,7,246,7,252,15,255,15,157,1,194,1,181,0,161,0,150,0,151,0,149,0,153,0,160,0,162,0,172,0,169,0,177,0,179,0,187,0,192,0,143,1,4,0,0,0,0,0,0,0,34,0,8,0,29,0,38,0,95,0,211,0,207,1,208,3,215,3,237,3,240,7,246,7,253,15,7,0,0,0,1,0,9,0,32,0,84,0,96,0,213,0,220,0,212,1,205,3,222,3,231,7,28,0,2,0,6,0,12,0,30,0,40,0,91,0,205,0,217,0,206,1,220,1,217,3,241,3,37,0,11,0,10,0,13,0,36,0,87,0,97,0,204,0,221,0,204,1,222,1,211,3,231,3,93,0,33,0,31,0,35,0,39,0,89,0,100,0,216,0,223,0,210,1,226,1,221,3,238,3,209,0,85,0,41,0,86,0,88,0,98,0,206,0,224,0,226,0,218,1,212,3,227,3,235,7,201,1,94,0,90,0,92,0,99,0,202,0,218,0,199,1,202,1,224,1,219,3,232,3,236,7,227,1,210,0,203,0,208,0,215,0,219,0,198,1,213,1,216,1,202,3,218,3,234,7,241,7,225,1,212,0,207,0,214,0,222,0,225,0,208,1,214,1,209,3,213,3,242,3,238,7,251,7,233,3,205,1,200,1,203,1,209,1,215,1,223,1,207,3,224,3,239,3,230,7,248,7,250,15,235,3,221,1,211,1,217,1,219,1,210,3,204,3,220,3,234,3,237,7,243,7,249,7,249,15,242,7,206,3,228,1,203,3,216,3,214,3,226,3,229,3,232,7,244,7,245,7,247,7,251,15,250,7,236,3,223,3,225,3,228,3,230,3,240,3,233,7,239,7,248,15,254,15,252,15,255,15,0,0,0,0,0,0,248,7,241,1,253,7,245,3,104,0,240,3,247,7,236,1,245,7,241,3,114,0,244,3,116,0,17,0,118,0,235,1,108,0,246,3,252,7,225,1,241,7,240,1,97,0,246,1,242,7,234,1,251,7,242,1,105,0,237,1,119,0,23,0,111,0,230,1,100,0,229,1,103,0,21,0,98,0,18,0,0,0,20,0,101,0,22,0,109,0,233,1,99,0,228,1,107,0,19,0,113,0,227,1,112,0,243,1,254,7,231,1,243,7,239,1,96,0,238,1,240,7,226,1,250,7,243,3,106,0,232,1,117,0,16,0,115,0,244,1,110,0,247,3,246,7,224,1,249,7,242,3,102,0,245,1,255,7,247,1,244,7,0,0,0,0,0,0,86,88,48,51,6,0,0,0,1,0,0,0,64,31,0,0,86,88,48,52,12,0,0,0,2,0,0,0,64,31,0,0,86,79,88,105,8,0,0,0,1,0,0,0,64,31,0,0,86,79,88,106,10,0,0,0,1,0,0,0,17,43,0,0,86,79,88,107,16,0,0,0,1,0,0,0,128,62,0,0,86,79,88,76,24,0,0,0,1,0,0,0,34,86,0,0,86,79,88,113,32,0,0,0,1,0,0,0,68,172,0,0,86,79,88,114,40,0,0,0,1,0,0,0,68,172,0,0,86,79,88,115,48,0,0,0,1,0,0,0,68,172,0,0,86,79,88,116,16,0,0,0,2,0,0,0,64,31,0,0,86,79,88,117,20,0,0,0,2,0,0,0,17,43,0,0,86,79,88,118,32,0,0,0,2,0,0,0,128,62,0,0,86,79,88,119,48,0,0,0,2,0,0,0,34,86,0,0,86,79,88,120,64,0,0,0,2,0,0,0,68,172,0,0,86,79,88,121,80,0,0,0,2,0,0,0,68,172,0,0,86,79,88,122,96,0,0,0,2,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,97,118,99,49,13,0,0,0,109,112,52,118,2,80,1,0,109,112,52,97,16,80,1,0,97,108,97,99,3,80,1,0,97,99,45,51,5,112,1,0,116,120,51,103,5,112,1,0,116,101,120,116,0,0,0,0,0,0,0,0,1,80,1,0,46,109,112,51,2,80,1,0,109,112,52,97,28,0,0,0,97,118,99,49,107,0,0,0,86,80,54,65,93,0,0,0,86,80,54,70,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,96,39,0,112,213,39,0,2,0,0,0,2,0,0,0,0,0,0,0,16,123,37,0,32,29,36,0,2,0,0,0,3,0,0,0,0,0,0,0,208,28,35,0,136,84,34,0,2,0,0,0,4,0,0,0,0,0,0,0,168,174,33,0,120,48,33,0,2,0,0,0,5,0,0,0,0,0,0,0,232,196,32,0,32,103,32,0,2,0,0,0,6,0,0,0,0,0,0,0,240,76,40,0,48,244,39,0,2,0,0,0,7,0,0,0,0,0,0,0,184,137,39,0,200,51,39,0,2,0,0,0,8,0,0,0,0,0,0,0,88,237,38,0,48,166,38,0,3,0,0,0,9,0,0,0,0,0,0,0,16,106,38,0,136,51,38,0,3,0,0,0,10,0,0,0,0,0,0,0,152,255,37,0,56,213,37,0,5,0,0,0,11,0,0,0,0,0,0,0,224,174,37,0,64,139,37,0,3,0,0,0,12,0,0,0,0,0,0,0,16,74,37,0,40,25,37,0,7,0,0,0,13,0,0,0,0,0,0,0,24,244,36,0,192,204,36,0,2,0,0,0,14,0,0,0,0,0,0,0,104,175,36,0,8,147,36,0,5,0,0,0,15,0,0,0,0,0,0,0,168,119,36,0,184,92,36,0,2,0,0,0,16,0,0,0,0,0,0,0,144,66,36,0,208,40,36,0,2,0,0,0,17,0,0,0,0,0,0,0,96,239,35,0,64,204,35,0,2,0,0,0,18,0,0,0,0,0,0,0,208,180,35,0,216,157,35,0,2,0,0,0,19,0,0,0,0,0,0,0,184,137,35,0,152,114,35,0,2,0,0,0,20,0,0,0,0,0,0,0,16,95,35,0,64,76,35,0,2,0,0,0,21,0,0,0,0,0,0,0,32,58,35,0,112,38,35,0,2,0,0,0,22,0,0,0,0,0,0,0,120,251,34,0,0,224,34,0,2,0,0,0,23,0,0,0,0,0,0,0,48,208,34,0,80,192,34,0,2,0,0,0,24,0,0,0,0,0,0,0,120,175,34,0,32,156,34,0,2,0,0,0,25,0,0,0,0,0,0,0,96,141,34,0,184,126,34,0,3,0,0,0,26,0,0,0,0,0,0,0,96,109,34,0,88,93,34,0,5,0,0,0,27,0,0,0,0,0,0,0,136,52,34,0,240,28,34,0,3,0,0,0,28,0,0,0,0,0,0,0,224,14,34,0,200,255,33,0,6,0,0,0,29,0,0,0,0,0,0,0,216,237,33,0,104,223,33,0,2,0,0,0,30,0,0,0,0,0,0,0,208,211,33,0,24,201,33,0,2,0,0,0,31,0,0,0,0,0,0,0,88,191,33,0,64,181,33,0,2,0,0,0,32,0,0,0,0,0,0,0,16,148,33,0,120,129,33,0,3,0,0,0,33,0,0,0,0,0,0,0,88,119,33,0,128,109,33,0,3,0,0,0,34,0,0,0,0,0,0,0,112,99,33,0,72,89,33,0,4,0,0,0,35,0,0,0,0,0,0,0,120,80,33,0,48,72,33,0,2,0,0,0,36,0,0,0,0,0,0,0,56,63,33,0,232,53,33,0,3,0,0,0,37,0,0,0,0,0,0,0,216,23,33,0,240,5,33,0,3,0,0,0,38,0,0,0,0,0,0,0,0,254,32,0,208,245,32,0,3,0,0,0,39,0,0,0,0,0,0,0,208,238,32,0,88,231,32,0,2,0,0,0,40,0,0,0,0,0,0,0,112,225,32,0,184,217,32,0,2,0,0,0,41,0,0,0,0,0,0,0,184,208,32,0,216,200,32,0,2,0,0,0,42,0,0,0,0,0,0,0,48,175,32,0,168,160,32,0,2,0,0,0,43,0,0,0,0,0,0,0,232,153,32,0,64,146,32,0,2,0,0,0,44,0,0,0,0,0,0,0,24,139,32,0,8,133,32,0,2,0,0,0,45,0,0,0,0,0,0,0,144,127,32,0,104,121,32,0,2,0,0,0,46,0,0,0,0,0,0,0,88,116,32,0,248,106,32,0,4,0,0,0,47,0,0,0,0,0,0,0,88,83,32,0,48,69,32,0,2,0,0,0,48,0,0,0,0,0,0,0,160,62,32,0,56,55,32,0,2,0,0,0,49,0,0,0,0,0,0,0,200,48,32,0,120,42,32,0,5,0,0,0,50,0,0,0,0,0,0,0,64,37,32,0,16,32,32,0,2,0,0,0,51,0,0,0,0,0,0,0,192,89,40,0,64,83,40,0,4,0,0,0,52,0,0,0,0,0,0,0,112,59,40,0,0,45,40,0,2,0,0,0,53,0,0,0,0,0,0,0,104,36,40,0,112,29,40,0,2,0,0,0,54,0,0,0,0,0,0,0,112,23,40,0,32,18,40,0,5,0,0,0,55,0,0,0,0,0,0,0,72,13,40,0,104,7,40,0,5,0,0,0,56,0,0,0,0,0,0,0,216,1,40,0,192,247,39,0,4,0,0,0,87,79,78,83,0,0,0,0,160,223,39,0,16,208,39,0,6,0,0,0,57,0,0,0,0,0,0,0,40,197,39,0,200,187,39,0,4,0,0,0,58,0,0,0,0,0,0,0,240,179,39,0,224,172,39,0,2,0,0,0,59,0,0,0,0,0,0,0,144,166,39,0,48,157,39,0,5,0,0,0,60,0,0,0,0,0,0,0,104,149,39,0,96,141,39,0,3,0,0,0,61,0,0,0,0,0,0,0,48,119,39,0,144,103,39,0,2,0,0,0,62,0,0,0,0,0,0,0,184,95,39,0,88,87,39,0,4,0,0,0,63,0,0,0,0,0,0,0,104,81,39,0,224,75,39,0,5,0,0,0,64,0,0,0,0,0,0,0,248,70,39,0,16,65,39,0,5,0,0,0,65,0,0,0,0,0,0,0,112,59,39,0,200,53,39,0,5,0,0,0,66,0,0,0,0,0,0,0,160,37,39,0,80,24,39,0,5,0,0,0,67,0,0,0,0,0,0,0,160,18,39,0,112,11,39,0,5,0,0,0,68,0,0,0,0,0,0,0,152,7,39,0,64,2,39,0,5,0,0,0,69,0,0,0,0,0,0,0,40,254,38,0,16,249,38,0,2,0,0,0,70,0,0,0,0,0,0,0,88,245,38,0,120,239,38,0,2,0,0,0,71,0,0,0,0,0,0,0,240,222,38,0,216,211,38,0,2,0,0,0,72,0,0,0,0,0,0,0,168,206,38,0,192,199,38,0,2,0,0,0,73,0,0,0,0,0,0,0,56,195,38,0,0,190,38,0,5,0,0,0,74,0,0,0,0,0,0,0,184,184,38,0,104,179,38,0,3,0,0,0,75,0,0,0,0,0,0,0,112,174,38,0,96,168,38,0,4,0,0,0,76,0,0,0,0,0,0,0,104,153,38,0,232,142,38,0,2,0,0,0,77,0,0,0,0,0,0,0,120,138,38,0,16,133,38,0,4,0,0,0,78,0,0,0,0,0,0,0,144,129,38,0,168,125,38,0,2,0,0,0,79,0,0,0,0,0,0,0,160,121,38,0,16,117,38,0,5,0,0,0,80,0,0,0,0,0,0,0,96,113,38,0,16,108,38,0,4,0,0,0,81,0,0,0,0,0,0,0,208,93,38,0,0,84,38,0,2,0,0,0,82,0,0,0,0,0,0,0,24,79,38,0,8,74,38,0,4,0,0,0,83,0,0,0,0,0,0,0,80,71,38,0,200,67,38,0,2,0,0,0,84,0,0,0,0,0,0,0,168,64,38,0,144,60,38,0,2,0,0,0,85,0,0,0,0,0,0,0,16,57,38,0,128,53,38,0,2,0,0,0,86,0,0,0,0,0,0,0,24,40,38,0,136,28,38,0,2,0,0,0,87,0,0,0,0,0,0,0,96,24,38,0,48,19,38,0,4,0,0,0,88,0,0,0,0,0,0,0,80,15,38,0,120,11,38,0,2,0,0,0,89,0,0,0,0,0,0,0,104,8,38,0,216,5,38,0,7,0,0,0,90,0,0,0,0,0,0,0,224,3,38,0,192,0,38,0,4,0,0,0,91,0,0,0,0,0,0,0,120,246,37,0,16,240,37,0,2,0,0,0,92,0,0,0,0,0,0,0,248,236,37,0,216,233,37,0,2,0,0,0,93,0,0,0,0,0,0,0,56,231,37,0,168,228,37,0,2,0,0,0,94,0,0,0,0,0,0,0,32,226,37,0,176,219,37,0,5,0,0,0,95,0,0,0,0,0,0,0,128,217,37,0,128,214,37,0,2,0,0,0,96,0,0,0,0,0,0,0,128,203,37,0,80,194,37,0,2,0,0,0,97,0,0,0,0,0,0,0,248,191,37,0,120,189,37,0,5,0,0,0,98,0,0,0,0,0,0,0,128,187,37,0,128,184,37,0,4,0,0,0,99,0,0,0,0,0,0,0,88,182,37,0,136,179,37,0,4,0,0,0,100,0,0,0,0,0,0,0,232,177,37,0,176,175,37,0,3,0,0,0,101,0,0,0,0,0,0,0,32,167,37,0,160,160,37,0,3,0,0,0,102,0,0,0,0,0,0,0,152,158,37,0,208,156,37,0,5,0,0,0,82,73,71,83,0,0,0,0,184,155,37,0,248,152,37,0,5,0,0,0,103,0,0,0,0,0,0,0,104,151,37,0,56,149,37,0,2,0,0,0,104,0,0,0,0,0,0,0,56,147,37,0,136,140,37,0,2,0,0,0,105,0,0,0,0,0,0,0,136,128,37,0,112,119,37,0,3,0,0,0,106,0,0,0,0,0,0,0,184,111,37,0,200,105,37,0,3,0,0,0,107,0,0,0,0,0,0,0,32,101,37,0,64,97,37,0,2,0,0,0,108,0,0,0,0,0,0,0,72,93,37,0,144,86,37,0,3,0,0,0,109,0,0,0,0,0,0,0,24,81,37,0,104,76,37,0,2,0,0,0,110,0,0,0,0,0,0,0,8,63,37,0,72,52,37,0,5,0,0,0,111,0,0,0,0,0,0,0,232,46,37,0,136,42,37,0,5,0,0,0,112,0,0,0,0,0,0,0,8,37,37,0,48,35,37,0,2,0,0,0,113,0,0,0,0,0,0,0,248,32,37,0,0,30,37,0,2,0,0,0,114,0,0,0,0,0,0,0,88,27,37,0,160,25,37,0,2,0,0,0,115,0,0,0,0,0,0,0,104,17,37,0,104,10,37,0,3,0,0,0,116,0,0,0,0,0,0,0,144,7,37,0,120,4,37,0,2,0,0,0,117,0,0,0,0,0,0,0,120,2,37,0,144,0,37,0,6,0,0,0,118,0,0,0,0,0,0,0,176,254,36,0,160,251,36,0,2,0,0,0,119,0,0,0,0,0,0,0,72,250,36,0,16,245,36,0,2,0,0,0,120,0,0,0,0,0,0,0,128,232,36,0,144,226,36,0,2,0,0,0,121,0,0,0,0,0,0,0,0,224,36,0,56,218,36,0,2,0,0,0,122,0,0,0,0,0,0,0,24,216,36,0,160,213,36,0,2,0,0,0,123,0,0,0,0,0,0,0,32,212,36,0,160,209,36,0,2,0,0,0,124,0,0,0,0,0,0,0,144,207,36,0,96,205,36,0,3,0,0,0,125,0,0,0,0,0,0,0,128,197,36,0,176,191,36,0,3,0,0,0,126,0,0,0,0,0,0,0,136,189,36,0,0,0,0,0,5,0,0,0,127,0,0,0,0,0,0,0,88,187,36,0,128,185,36,0,3,0,0,0,128,0,0,0,0,0,0,0,80,184,36,0,120,182,36,0,5,0,0,0,129,0,0,0,0,0,0,0,152,179,36,0,8,178,36,0,5,0,0,0,130,0,0,0,0,0,0,0,120,176,36,0,40,167,36,0,2,0,0,0,131,0,0,0,0,0,0,0,160,162,36,0,40,160,36,0,5,0,0,0,132,0,0,0,0,0,0,0,40,158,36,0,112,156,36,0,2,0,0,0,133,0,0,0,0,0,0,0,88,154,36,0,224,152,36,0,2,0,0,0,134,0,0,0,0,0,0,0,0,151,36,0,224,149,36,0,5,0,0,0,135,0,0,0,0,0,0,0,176,147,36,0,168,140,36,0,2,0,0,0,136,0,0,0,0,0,0,0,64,135,36,0,240,132,36,0,2,0,0,0,137,0,0,0,0,0,0,0,136,130,36,0,192,128,36,0,2,0,0,0,138,0,0,0,0,0,0,0,48,127,36,0,192,125,36,0,2,0,0,0,139,0,0,0,0,0,0,0,24,123,36,0,184,121,36,0,2,0,0,0,140,0,0,0,0,0,0,0,120,120,36,0,224,112,36,0,2,0,0,0,141,0,0,0,0,0,0,0,88,108,36,0,176,106,36,0,2,0,0,0,169,0,0,0,0,0,0,0,168,104,36,0,240,102,36,0,2,0,0,0,142,0,0,0,0,0,0,0,80,101,36,0,176,99,36,0,3,0,0,0,143,0,0,0,0,0,0,0,96,96,36,0,216,94,36,0,2,0,0,0,144,0,0,0,0,0,0,0,136,93,36,0,160,85,36,0,3,0,0,0,145,0,0,0,0,0,0,0,232,80,36,0,176,78,36,0,3,0,0,0,146,0,0,0,0,0,0,0,208,76,36,0,64,75,36,0,5,0,0,0,49,67,86,77,0,0,0,0,168,73,36,0,24,72,36,0,3,0,0,0,50,67,86,77,0,0,0,0,208,69,36,0,56,68,36,0,3,0,0,0,147,0,0,0,0,0,0,0,40,67,36,0,176,60,36,0,2,0,0,0,148,0,0,0,0,0,0,0,152,56,36,0,40,55,36,0,5,0,0,0,149,0,0,0,0,0,0,0,192,53,36,0,88,52,36,0,3,0,0,0,150,0,0,0,0,0,0,0,104,51,36,0,112,50,36,0,3,0,0,0,151,0,0,0,0,0,0,0,112,48,36,0,104,46,36,0,2,0,0,0,152,0,0,0,0,0,0,0,0,42,36,0,208,32,36,0,2,0,0,0,153,0,0,0,0,0,0,0,240,25,36,0,88,18,36,0,2,0,0,0,154,0,0,0,0,0,0,0,8,13,36,0,104,8,36,0,5,0,0,0,155,0,0,0,0,0,0,0,88,4,36,0,16,1,36,0,4,0,0,0,156,0,0,0,0,0,0,0,192,249,35,0,64,244,35,0,5,0,0,0,157,0,0,0,0,0,0,0,96,241,35,0,200,231,35,0,5,0,0,0,158,0,0,0,0,0,0,0,104,223,35,0,208,219,35,0,5,0,0,0,159,0,0,0,0,0,0,0,88,216,35,0,120,214,35,0,5,0,0,0,160,0,0,0,0,0,0,0,112,213,35,0,56,211,35,0,3,0,0,0,161,0,0,0,0,0,0,0,64,209,35,0,168,206,35,0,5,0,0,0,162,0,0,0,0,0,0,0,32,205,35,0,24,199,35,0,4,0,0,0,163,0,0,0,0,0,0,0,16,195,35,0,240,192,35,0,2,0,0,0,164,0,0,0,0,0,0,0,72,191,35,0,40,190,35,0,2,0,0,0,165,0,0,0,0,0,0,0,88,188,35,0,56,186,35,0,2,0,0,0,166,0,0,0,0,0,0,0,240,183,35,0,168,182,35,0,2,0,0,0,167,0,0,0,0,0,0,0,64,181,35,0,160,175,35,0,5,0,0,0,168,0,0,0,0,0,0,0,152,171,35,0,8,170,35,0,3,0,0,0,170,0,0,0,0,0,0,0,120,168,35,0,64,167,35,0,3,0,0,0,80,49,52,89,0,0,0,0,88,165,35,0,24,164,35,0,1,0,0,0,48,51,49,69,0,0,0,0,32,162,35,0,0,160,35,0,2,0,0,0,82,88,69,48,0,0,0,0,32,158,35,0,136,153,35,0,7,0,0,0,80,82,86,65,0,0,0,0,232,149,35,0,32,148,35,0,1,0,0,0,86,50,49,48,0,0,0,0,168,146,35,0,120,182,36,0,1,0,0,0,73,85,86,65,0,0,0,0,224,145,35,0,56,145,35,0,1,0,0,0,86,85,89,65,0,0,0,0,64,143,35,0,144,141,35,0,1,0,0,0,54,49,50,84,0,0,0,0,40,140,35,0,56,138,35,0,1,0,0,0,56,48,51,86,0,0,0,0,112,132,35,0,24,128,35,0,1,0,0,0,56,48,52,86,0,0,0,0,248,125,35,0,24,124,35,0,1,0,0,0,52,86,85,89,0,0,0,0,168,122,35,0,48,121,35,0,1,0,0,0,77,78,65,83,0,0,0,0,216,119,35,0,48,118,35,0,2,0,0,0,86,70,65,80,0,0,0,0,136,116,35,0,8,115,35,0,2,0,0,0,110,82,86,65,0,0,0,0,168,109,35,0,96,105,35,0,0,0,0,0,65,73,80,67,0,0,0,0,16,103,35,0,240,101,35,0,0,0,0,0,67,65,70,88,0,0,0,0,40,101,35,0,56,100,35,0,3,0,0,0,88,73,80,66,0,0,0,0,64,99,35,0,64,98,35,0,5,0,0,0,74,86,77,83,0,0,0,0,72,97,35,0,112,95,35,0,0,0,0,0,77,50,71,0,0,0,0,0,0,90,35,0,152,86,35,0,2,0,0,0,80,66,69,87,0,0,0,0,240,84,35,0,168,83,35,0,7,0,0,0,174,0,0,0,0,0,0,0,232,82,35,0,248,81,35,0,2,0,0,0,53,54,50,72,0,0,0,0,112,80,35,0,216,78,35,0,2,0,0,0,176,0,0,0,0,0,0,0,128,77,35,0,176,76,35,0,2,0,0,0,0,0,1,0,1,0,0,0,64,72,35,0,224,68,35,0,4,0,0,0,1,0,1,0,1,0,0,0,152,67,35,0,56,66,35,0,4,0,0,0,2,0,1,0,1,0,0,0,8,65,35,0,152,63,35,0,4,0,0,0,3,0,1,0,1,0,0,0,104,62,35,0,88,61,35,0,4,0,0,0,4,0,1,0,1,0,0,0,8,60,35,0,112,58,35,0,4,0,0,0,5,0,1,0,1,0,0,0,144,54,35,0,248,50,35,0,4,0,0,0,6,0,1,0,1,0,0,0,0,50,35,0,8,49,35,0,2,0,0,0,7,0,1,0,1,0,0,0,160,48,35,0,192,47,35,0,2,0,0,0,8,0,1,0,1,0,0,0,40,47,35,0,32,46,35,0,4,0,0,0,9,0,1,0,1,0,0,0,48,44,35,0,48,39,35,0,4,0,0,0,10,0,1,0,1,0,0,0,144,32,35,0,176,26,35,0,4,0,0,0,11,0,1,0,1,0,0,0,200,19,35,0,184,15,35,0,4,0,0,0,12,0,1,0,1,0,0,0,8,13,35,0,104,10,35,0,4,0,0,0,13,0,1,0,1,0,0,0,136,7,35,0,232,2,35,0,4,0,0,0,14,0,1,0,1,0,0,0,32,255,34,0,160,252,34,0,4,0,0,0,15,0,1,0,1,0,0,0,96,245,34,0,248,238,34,0,4,0,0,0,16,0,1,0,1,0,0,0,144,234,34,0,88,231,34,0,4,0,0,0,17,0,1,0,1,0,0,0,192,229,34,0,48,229,34,0,2,0,0,0,16,80,83,80,1,0,0,0,32,228,34,0,192,226,34,0,4,0,0,0,18,0,1,0,1,0,0,0,112,225,34,0,128,224,34,0,4,0,0,0,80,83,80,24,1,0,0,0,184,219,34,0,24,217,34,0,4,0,0,0,80,83,80,32,1,0,0,0,104,215,34,0,136,214,34,0,4,0,0,0,19,0,1,0,1,0,0,0,200,213,34,0,160,212,34,0,4,0,0,0,20,0,1,0,1,0,0,0,208,211,34,0,184,210,34,0,4,0,0,0,21,0,1,0,1,0,0,0,248,209,34,0,104,208,34,0,4,0,0,0,22,0,1,0,1,0,0,0,64,205,34,0,8,202,34,0,4,0,0,0,23,0,1,0,1,0,0,0,176,200,34,0,160,199,34,0,4,0,0,0,24,0,1,0,1,0,0,0,192,198,34,0,192,197,34,0,4,0,0,0,25,0,1,0,1,0,0,0,136,196,34,0,80,195,34,0,4,0,0,0,26,0,1,0,1,0,0,0,232,193,34,0,200,192,34,0,4,0,0,0,27,0,1,0,1,0,0,0,136,188,34,0,192,185,34,0,4,0,0,0,0,16,1,0,1,0,0,0,104,184,34,0,120,183,34,0,2,0,0,0,1,16,1,0,1,0,0,0,32,182,34,0,160,181,34,0,2,0,0,0,2,16,1,0,1,0,0,0,40,180,34,0,208,178,34,0,2,0,0,0,3,16,1,0,1,0,0,0,48,177,34,0,40,176,34,0,2,0,0,0,4,16,1,0,1,0,0,0,112,171,34,0,136,167,34,0,2,0,0,0,5,16,1,0,1,0,0,0,216,165,34,0,112,164,34,0,2,0,0,0,6,16,1,0,1,0,0,0,0,163,34,0,16,161,34,0,2,0,0,0,7,16,1,0,1,0,0,0,8,160,34,0,240,158,34,0,2,0,0,0,8,16,1,0,1,0,0,0,248,157,34,0,152,156,34,0,2,0,0,0,9,16,1,0,1,0,0,0,160,152,34,0,144,149,34,0,2,0,0,0,10,16,1,0,1,0,0,0,16,148,34,0,0,147,34,0,2,0,0,0,11,16,1,0,1,0,0,0,232,145,34,0,96,145,34,0,2,0,0,0,12,16,1,0,1,0,0,0,152,144,34,0,168,143,34,0,2,0,0,0,13,16,1,0,1,0,0,0,216,142,34,0,168,141,34,0,2,0,0,0,14,16,1,0,1,0,0,0,232,138,34,0,224,135,34,0,2,0,0,0,15,16,1,0,1,0,0,0,160,134,34,0,128,133,34,0,2,0,0,0,16,16,1,0,1,0,0,0,120,132,34,0,64,131,34,0,2,0,0,0,17,16,1,0,1,0,0,0,136,130,34,0,248,128,34,0,2,0,0,0,18,16,1,0,1,0,0,0,200,127,34,0,0,127,34,0,2,0,0,0,19,16,1,0,1,0,0,0,128,123,34,0,80,120,34,0,2,0,0,0,20,16,1,0,1,0,0,0,120,119,34,0,192,117,34,0,2,0,0,0,21,16,1,0,1,0,0,0,192,115,34,0,144,114,34,0,2,0,0,0,22,16,1,0,1,0,0,0,56,113,34,0,176,111,34,0,2,0,0,0,23,16,1,0,1,0,0,0,96,110,34,0,176,109,34,0,2,0,0,0,24,16,1,0,1,0,0,0,128,106,34,0,104,103,34,0,2,0,0,0,25,16,1,0,1,0,0,0,184,102,34,0,232,101,34,0,2,0,0,0,26,16,1,0,1,0,0,0,24,101,34,0,136,100,34,0,2,0,0,0,27,16,1,0,1,0,0,0,208,99,34,0,200,98,34,0,2,0,0,0,28,16,1,0,1,0,0,0,48,97,34,0,0,94,34,0,2,0,0,0,29,16,1,0,1,0,0,0,184,87,34,0,144,82,34,0,2,0,0,0,32,67,70,65,1,0,0,0,32,77,34,0,144,73,34,0,2,0,0,0,32,73,75,79,1,0,0,0,24,70,34,0,240,66,34,0,2,0,0,0,32,75,84,68,1,0,0,0,56,64,34,0,128,59,34,0,2,0,0,0,32,68,65,82,1,0,0,0,208,55,34,0,80,53,34,0,2,0,0,0,71,55,50,54,1,0,0,0,40,47,34,0,32,42,34,0,2,0,0,0,0,32,1,0,1,0,0,0,64,39,34,0,56,37,34,0,2,0,0,0,1,32,1,0,1,0,0,0,240,35,34,0,216,34,34,0,2,0,0,0,0,48,1,0,1,0,0,0,72,33,34,0,56,32,34,0,2,0,0,0,1,48,1,0,1,0,0,0,200,30,34,0,64,29,34,0,2,0,0,0,0,64,1,0,1,0,0,0,88,26,34,0,152,23,34,0,2,0,0,0,1,64,1,0,1,0,0,0,128,22,34,0,240,21,34,0,2,0,0,0,2,64,1,0,1,0,0,0,232,20,34,0,216,19,34,0,2,0,0,0,3,64,1,0,1,0,0,0,240,18,34,0,184,17,34,0,2,0,0,0,0,80,1,0,1,0,0,0,208,16,34,0,40,15,34,0,2,0,0,0,1,80,1,0,1,0,0,0,64,12,34,0,16,10,34,0,2,0,0,0,2,80,1,0,1,0,0,0,112,8,34,0,96,7,34,0,2,0,0,0,3,80,1,0,1,0,0,0,64,6,34,0,32,5,34,0,2,0,0,0,4,80,1,0,1,0,0,0,224,3,34,0,56,2,34,0,6,0,0,0,5,80,1,0,1,0,0,0,24,1,34,0,40,0,34,0,2,0,0,0,6,80,1,0,1,0,0,0,88,253,33,0,0,0,0,0,2,0,0,0,7,80,1,0,1,0,0,0,232,250,33,0,192,249,33,0,2,0,0,0,8,80,1,0,1,0,0,0,192,248,33,0,32,247,33,0,2,0,0,0,9,80,1,0,1,0,0,0,64,246,33,0,32,245,33,0,2,0,0,0,10,80,1,0,1,0,0,0,48,243,33,0,8,239,33,0,2,0,0,0,11,80,1,0,1,0,0,0,72,238,33,0,232,234,33,0,2,0,0,0,12,80,1,0,1,0,0,0,88,232,33,0,176,230,33,0,4,0,0,0,13,80,1,0,1,0,0,0,8,230,33,0,72,229,33,0,2,0,0,0,14,80,1,0,1,0,0,0,48,228,33,0,32,227,33,0,2,0,0,0,15,80,1,0,1,0,0,0,80,226,33,0,64,225,33,0,4,0,0,0,16,80,1,0,1,0,0,0,152,223,33,0,96,220,33,0,4,0,0,0,17,80,1,0,1,0,0,0,208,217,33,0,216,216,33,0,2,0,0,0,18,80,1,0,1,0,0,0,64,216,33,0,160,215,33,0,2,0,0,0,19,80,1,0,1,0,0,0,24,215,33,0,48,214,33,0,2,0,0,0,20,80,1,0,1,0,0,0,136,213,33,0,200,212,33,0,2,0,0,0,21,80,1,0,1,0,0,0,248,211,33,0,248,208,33,0,2,0,0,0,22,80,1,0,1,0,0,0,192,206,33,0,232,205,33,0,4,0,0,0,23,80,1,0,1,0,0,0,72,205,33,0,184,204,33,0,2,0,0,0,24,80,1,0,1,0,0,0,8,204,33,0,96,203,33,0,2,0,0,0,25,80,1,0,1,0,0,0,80,202,33,0,192,201,33,0,6,0,0,0,26,80,1,0,1,0,0,0,88,201,33,0,232,198,33,0,2,0,0,0,27,80,1,0,1,0,0,0,120,196,33,0,32,196,33,0,2,0,0,0,28,80,1,0,1,0,0,0,184,195,33,0,32,195,33,0,2,0,0,0,29,80,1,0,1,0,0,0,88,194,33,0,120,193,33,0,4,0,0,0,30,80,1,0,1,0,0,0,240,192,33,0,216,191,33,0,2,0,0,0,31,80,1,0,1,0,0,0,176,191,33,0,208,189,33,0,2,0,0,0,32,80,1,0,1,0,0,0,112,188,33,0,48,188,33,0,2,0,0,0,33,80,1,0,1,0,0,0,232,187,33,0,160,187,33,0,4,0,0,0,34,80,1,0,1,0,0,0,80,187,33,0,224,186,33,0,2,0,0,0,35,80,1,0,1,0,0,0,120,186,33,0,248,185,33,0,2,0,0,0,36,80,1,0,1,0,0,0,224,182,33,0,208,177,33,0,2,0,0,0,37,80,1,0,1,0,0,0,8,174,33,0,200,169,33,0,2,0,0,0,38,80,1,0,1,0,0,0,120,166,33,0,72,163,33,0,2,0,0,0,39,80,1,0,1,0,0,0,80,161,33,0,200,157,33,0,4,0,0,0,40,80,1,0,1,0,0,0,144,154,33,0,120,150,33,0,2,0,0,0,41,80,1,0,1,0,0,0,32,149,33,0,152,143,33,0,2,0,0,0,42,80,1,0,1,0,0,0,168,138,33,0,192,136,33,0,2,0,0,0,43,80,1,0,1,0,0,0,40,135,33,0,208,133,33,0,2,0,0,0,44,80,1,0,1,0,0,0,104,133,33,0,120,132,33,0,2,0,0,0,45,80,1,0,1,0,0,0,152,131,33,0,120,130,33,0,4,0,0,0,46,80,1,0,1,0,0,0,232,129,33,0,64,127,33,0,4,0,0,0,47,80,1,0,1,0,0,0,224,124,33,0,32,124,33,0,2,0,0,0,48,80,1,0,1,0,0,0,160,123,33,0,24,123,33,0,2,0,0,0,49,80,1,0,1,0,0,0,152,122,33,0,200,121,33,0,2,0,0,0,50,80,1,0,1,0,0,0,32,121,33,0,40,120,33,0,2,0,0,0,51,80,1,0,1,0,0,0,184,119,33,0,176,117,33,0,2,0,0,0,52,80,1,0,1,0,0,0,216,115,33,0,32,115,33,0,2,0,0,0,53,80,1,0,1,0,0,0,80,114,33,0,208,113,33,0,2,0,0,0,54,80,1,0,1,0,0,0,64,113,33,0,64,112,33,0,2,0,0,0,55,80,1,0,1,0,0,0,72,111,33,0,96,110,33,0,2,0,0,0,56,80,1,0,1,0,0,0,216,109,33,0,192,107,33,0,2,0,0,0,57,80,1,0,1,0,0,0,176,105,33,0,192,104,33,0,2,0,0,0,58,80,1,0,1,0,0,0,48,104,33,0,232,103,33,0,4,0,0,0,59,80,1,0,1,0,0,0,176,103,33,0,136,102,33,0,2,0,0,0,60,80,1,0,1,0,0,0,184,101,33,0,168,100,33,0,2,0,0,0,65,77,73,86,1,0,0,0,40,100,33,0,232,97,33,0,2,0,0,0,83,87,70,70,1,0,0,0,232,95,33,0,232,94,33,0,0,0,0,0,67,78,79,83,1,0,0,0,232,93,33,0,128,93,33,0,0,0,0,0,76,78,79,83,1,0,0,0,240,92,33,0,144,91,33,0,0,0,0,0,65,70,65,80,1,0,0,0,232,90,33,0,40,90,33,0,2,0,0,0,83,85,80,79,1,0,0,0,200,89,33,0,192,87,33,0,2,0,0,0,62,80,1,0,1,0,0,0,224,85,33,0,56,85,33,0,2,0,0,0,75,97,66,116,1,0,0,0,208,84,33,0,80,84,33,0,4,0,0,0,64,80,1,0,1,0,0,0,200,83,33,0,8,83,33,0,2,0,0,0,99,118,101,115,1,0,0,0,64,82,33,0,168,81,33,0,2,0,0,0,118,109,115,115,1,0,0,0,72,97,35,0,248,80,33,0,2,0,0,0,0,112,1,0,3,0,0,0,240,78,33,0,104,77,33,0,0,0,1,0,1,112,1,0,3,0,0,0,216,76,33,0,0,76,33,0,0,0,1,0,2,112,1,0,3,0,0,0,200,75,33,0,112,75,33,0,0,0,2,0,3,112,1,0,3,0,0,0,64,74,33,0,160,73,33,0,0,0,1,0,32,83,83,65,3,0,0,0,0,73,33,0,176,72,33,0,0,0,2,0,4,112,1,0,3,0,0,0,0,71,33,0,192,68,33,0,0,0,2,0,5,112,1,0,3,0,0,0,72,68,33,0,240,67,33,0,0,0,2,0,6,112,1,0,3,0,0,0,72,67,33,0,160,66,33,0,0,0,1,0,7,112,1,0,3,0,0,0,136,65,33,0,232,64,33,0,0,0,0,0,8,112,1,0,3,0,0,0,240,63,33,0,168,63,33,0,0,0,2,0,112,105,82,83,3,0,0,0,240,61,33,0,232,60,33,0,0,0,2,0,68,86,68,109,3,0,0,0,184,60,33,0,88,60,33,0,0,0,2,0,50,76,80,77,3,0,0,0,48,60,33,0,216,59,33,0,0,0,2,0,56,48,54,99,3,0,0,0,0,59,33,0,88,58,33,0,0,0,0,0,66,85,83,74,3,0,0,0,248,57,33,0,136,55,33,0,0,0,2,0,83,74,104,80,3,0,0,0,232,50,33,0,208,47,33,0,0,0,2,0,73,77,65,83,3,0,0,0,240,43,33,0,192,40,33,0,0,0,2,0,84,88,84,82,3,0,0,0,120,38,33,0,128,36,33,0,0,0,2,0,49,86,98,83,3,0,0,0,240,33,33,0,128,30,33,0,0,0,2,0,86,98,117,83,3,0,0,0,128,26,33,0,176,24,33,0,0,0,2,0,114,108,80,86,3,0,0,0,56,20,33,0,96,15,33,0,0,0,2,0,84,84,86,87,3,0,0,0,128,13,33,0,216,11,33,0,0,0,2,0,84,88,84,66,0,0,0,0,192,10,33,0,64,10,33,0,1,0,0,0,78,73,66,88,0,0,0,0,192,8,33,0,232,7,33,0,1,0,0,0,70,68,73,0,0,0,0,0,32,7,33,0,144,6,33,0,1,0,0,0,65,86,76,75,2,0,0,0,144,4,33,0,48,3,33,0,0,0,0,0,86,65,78,68,2,0,0,0,200,2,33,0,56,2,33,0,0,0,0,0,51,68,73,84,2,0,0,0,192,1,33,0,16,1,33,0,0,0,0,0,0,0,0,0,6,0,1,0,1,0,0,0,4,0,1,0,2,0,0,0,1,0,1,0,3,0,0,0,13,0,1,0,4,0,0,0,9,0,1,0,5,0,0,0,20,0,1,0,6,0,0,0,22,0,1,0,7,0,0,0,71,55,50,54,23,0,0,0,28,16,1,0,24,0,0,0,71,55,50,54,25,0,0,0,71,55,50,54,26,0,0,0,7,0,1,0,27,0,0,0,71,55,50,54,50,54,50,55,0,0,0,0,0,0,0,0,13,0,0,0,77,52,83,50,13,0,0,0,77,80,52,83,17,0,0,0,77,80,52,51,0,0,0,0,0,0,0,0,5,0,0,0,115,50,54,51,28,0,0,0,97,118,99,49,13,0,0,0,109,112,52,118,2,80,1,0,109,112,52,97,0,32,1,0,115,97,109,114,1,32,1,0,115,97,119,98,5,112,1,0,116,120,51,103,0,0,0,0,0,0,0,0,0,0,16,1,32,1,48,1,64,1,80,1,96,1,112,1,128,1,144,1,160,1,176,1,192,1,1,17,17,2,33,2,49,2,65,2,81,2,97,2,113,2,129,2,145,2,161,2,177,2,193,2,2,17,18,2,34,2,50,2,66,2,82,2,98,2,114,2,130,2,146,2,162,2,178,2,194,2,3,17,19,2,35,2,51,2,67,2,83,2,99,2,115,2,131,2,147,2,163,2,179,2,195,2,4,17,20,2,36,2,52,2,68,2,84,2,100,2,116,2,132,2,148,2,164,2,180,2,196,2,5,17,21,2,37,2,53,2,69,2,85,2,101,2,117,2,133,2,149,2,165,2,181,2,197,2,6,17,22,2,38,2,54,2,70,2,86,2,102,2,118,2,134,2,150,2,166,2,182,2,198,2,7,17,23,2,39,2,55,2,71,2,87,2,103,2,119,2,135,2,151,2,167,2,183,2,199,2,8,17,24,2,40,2,56,2,72,2,88,2,104,2,120,2,136,2,152,2,168,2,184,2,200,2,9,17,25,2,41,2,57,2,73,2,89,2,105,2,121,2,137,2,153,2,169,2,185,2,201,2,10,17,26,2,42,2,58,2,74,2,90,2,106,2,122,2,138,2,154,2,170,2,186,2,202,2,11,17,27,2,43,2,59,2,75,2,91,2,107,2,123,2,139,2,155,2,171,2,187,2,203,2,12,17,28,2,44,2,60,2,76,2,92,2,108,2,124,2,140,2,156,2,172,2,188,2,204,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,186,116,138,64,0,0,0,0,245,47,203,64,0,0,0,0,79,204,8,65,0,0,0,0,142,113,46,65,0,0,0,0,144,63,86,65,0,0,0,0,0,0,128,65,0,0,0,0,27,196,149,65,0,0,0,0,211,90,172,65,0,0,0,0,211,181,195,65,0,0,0,0,255,200,219,65,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,186,116,138,64,0,0,128,63,245,47,203,64,0,0,128,63,79,204,8,65,0,0,128,63,142,113,46,65,0,0,128,63,144,63,86,65,0,0,128,63,0,0,128,65,0,0,128,63,27,196,149,65,0,0,128,63,211,90,172,65,0,0,128,63,211,181,195,65,0,0,128,63,255,200,219,65,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,186,116,138,64,24,69,33,64,245,47,203,64,24,69,33,64,79,204,8,65,24,69,33,64,142,113,46,65,24,69,33,64,144,63,86,65,24,69,33,64,0,0,128,65,24,69,33,64,27,196,149,65,24,69,33,64,211,90,172,65,24,69,33,64,211,181,195,65,24,69,33,64,255,200,219,65,186,116,138,64,0,0,0,0,186,116,138,64,0,0,128,63,186,116,138,64,24,69,33,64,186,116,138,64,186,116,138,64,186,116,138,64,245,47,203,64,186,116,138,64,79,204,8,65,186,116,138,64,142,113,46,65,186,116,138,64,144,63,86,65,186,116,138,64,0,0,128,65,186,116,138,64,27,196,149,65,186,116,138,64,211,90,172,65,186,116,138,64,211,181,195,65,186,116,138,64,255,200,219,65,245,47,203,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,64,245,47,203,64,245,47,203,64,79,204,8,65,245,47,203,64,142,113,46,65,245,47,203,64,144,63,86,65,245,47,203,64,0,0,128,65,245,47,203,64,27,196,149,65,245,47,203,64,211,90,172,65,245,47,203,64,211,181,195,65,245,47,203,64,255,200,219,65,79,204,8,65,0,0,0,0,79,204,8,65,0,0,128,63,79,204,8,65,24,69,33,64,79,204,8,65,186,116,138,64,79,204,8,65,245,47,203,64,79,204,8,65,79,204,8,65,79,204,8,65,142,113,46,65,79,204,8,65,144,63,86,65,79,204,8,65,0,0,128,65,79,204,8,65,27,196,149,65,79,204,8,65,211,90,172,65,79,204,8,65,211,181,195,65,79,204,8,65,255,200,219,65,142,113,46,65,0,0,0,0,142,113,46,65,0,0,128,63,142,113,46,65,24,69,33,64,142,113,46,65,186,116,138,64,142,113,46,65,245,47,203,64,142,113,46,65,79,204,8,65,142,113,46,65,142,113,46,65,142,113,46,65,144,63,86,65,142,113,46,65,0,0,128,65,142,113,46,65,27,196,149,65,142,113,46,65,211,90,172,65,142,113,46,65,211,181,195,65,142,113,46,65,255,200,219,65,144,63,86,65,0,0,0,0,144,63,86,65,0,0,128,63,144,63,86,65,24,69,33,64,144,63,86,65,186,116,138,64,144,63,86,65,245,47,203,64,144,63,86,65,79,204,8,65,144,63,86,65,142,113,46,65,144,63,86,65,144,63,86,65,144,63,86,65,0,0,128,65,144,63,86,65,27,196,149,65,144,63,86,65,211,90,172,65,144,63,86,65,211,181,195,65,144,63,86,65,255,200,219,65,0,0,128,65,0,0,0,0,0,0,128,65,0,0,128,63,0,0,128,65,24,69,33,64,0,0,128,65,186,116,138,64,0,0,128,65,245,47,203,64,0,0,128,65,79,204,8,65,0,0,128,65,142,113,46,65,0,0,128,65,144,63,86,65,0,0,128,65,0,0,128,65,0,0,128,65,27,196,149,65,0,0,128,65,211,90,172,65,0,0,128,65,211,181,195,65,0,0,128,65,255,200,219,65,27,196,149,65,0,0,0,0,27,196,149,65,0,0,128,63,27,196,149,65,24,69,33,64,27,196,149,65,186,116,138,64,27,196,149,65,245,47,203,64,27,196,149,65,79,204,8,65,27,196,149,65,142,113,46,65,27,196,149,65,144,63,86,65,27,196,149,65,0,0,128,65,27,196,149,65,27,196,149,65,27,196,149,65,211,90,172,65,27,196,149,65,211,181,195,65,27,196,149,65,255,200,219,65,211,90,172,65,0,0,0,0,211,90,172,65,0,0,128,63,211,90,172,65,24,69,33,64,211,90,172,65,186,116,138,64,211,90,172,65,245,47,203,64,211,90,172,65,79,204,8,65,211,90,172,65,142,113,46,65,211,90,172,65,144,63,86,65,211,90,172,65,0,0,128,65,211,90,172,65,27,196,149,65,211,90,172,65,211,90,172,65,211,90,172,65,211,181,195,65,211,90,172,65,255,200,219,65,211,181,195,65,0,0,0,0,211,181,195,65,0,0,128,63,211,181,195,65,24,69,33,64,211,181,195,65,186,116,138,64,211,181,195,65,245,47,203,64,211,181,195,65,79,204,8,65,211,181,195,65,142,113,46,65,211,181,195,65,144,63,86,65,211,181,195,65,0,0,128,65,211,181,195,65,27,196,149,65,211,181,195,65,211,90,172,65,211,181,195,65,211,181,195,65,211,181,195,65,255,200,219,65,255,200,219,65,0,0,0,0,255,200,219,65,0,0,128,63,255,200,219,65,24,69,33,64], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1680920);
/* memory initializer */ allocate([255,200,219,65,186,116,138,64,255,200,219,65,245,47,203,64,255,200,219,65,79,204,8,65,255,200,219,65,142,113,46,65,255,200,219,65,144,63,86,65,255,200,219,65,0,0,128,65,255,200,219,65,27,196,149,65,255,200,219,65,211,90,172,65,255,200,219,65,211,181,195,65,255,200,219,65,255,200,219,65,0,0,16,1,32,1,48,1,64,1,80,1,96,1,112,1,1,17,17,2,33,2,49,2,65,2,81,2,97,2,113,2,2,17,18,2,34,2,50,2,66,2,82,2,98,2,114,2,3,17,19,2,35,2,51,2,67,2,83,2,99,2,115,2,4,17,20,2,36,2,52,2,68,2,84,2,100,2,116,2,5,17,21,2,37,2,53,2,69,2,85,2,101,2,117,2,6,17,22,2,38,2,54,2,70,2,86,2,102,2,118,2,7,17,23,2,39,2,55,2,71,2,87,2,103,2,119,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,186,116,138,64,0,0,0,0,245,47,203,64,0,0,0,0,79,204,8,65,0,0,0,0,142,113,46,65,0,0,0,0,144,63,86,65,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,186,116,138,64,0,0,128,63,245,47,203,64,0,0,128,63,79,204,8,65,0,0,128,63,142,113,46,65,0,0,128,63,144,63,86,65,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,186,116,138,64,24,69,33,64,245,47,203,64,24,69,33,64,79,204,8,65,24,69,33,64,142,113,46,65,24,69,33,64,144,63,86,65,186,116,138,64,0,0,0,0,186,116,138,64,0,0,128,63,186,116,138,64,24,69,33,64,186,116,138,64,186,116,138,64,186,116,138,64,245,47,203,64,186,116,138,64,79,204,8,65,186,116,138,64,142,113,46,65,186,116,138,64,144,63,86,65,245,47,203,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,64,245,47,203,64,245,47,203,64,79,204,8,65,245,47,203,64,142,113,46,65,245,47,203,64,144,63,86,65,79,204,8,65,0,0,0,0,79,204,8,65,0,0,128,63,79,204,8,65,24,69,33,64,79,204,8,65,186,116,138,64,79,204,8,65,245,47,203,64,79,204,8,65,79,204,8,65,79,204,8,65,142,113,46,65,79,204,8,65,144,63,86,65,142,113,46,65,0,0,0,0,142,113,46,65,0,0,128,63,142,113,46,65,24,69,33,64,142,113,46,65,186,116,138,64,142,113,46,65,245,47,203,64,142,113,46,65,79,204,8,65,142,113,46,65,142,113,46,65,142,113,46,65,144,63,86,65,144,63,86,65,0,0,0,0,144,63,86,65,0,0,128,63,144,63,86,65,24,69,33,64,144,63,86,65,186,116,138,64,144,63,86,65,245,47,203,64,144,63,86,65,79,204,8,65,144,63,86,65,142,113,46,65,144,63,86,65,144,63,86,65,245,47,203,192,186,116,138,192,24,69,33,192,0,0,128,191,0,0,0,0,0,0,128,63,24,69,33,64,186,116,138,64,245,47,203,64,0,0,0,0,0,0,16,0,32,0,48,0,64,0,80,0,96,0,112,0,128,0,1,0,17,0,33,0,49,0,65,0,81,0,97,0,113,0,129,0,2,0,18,0,34,0,50,0,66,0,82,0,98,0,114,0,130,0,3,0,19,0,35,0,51,0,67,0,83,0,99,0,115,0,131,0,4,0,20,0,36,0,52,0,68,0,84,0,100,0,116,0,132,0,5,0,21,0,37,0,53,0,69,0,85,0,101,0,117,0,133,0,6,0,22,0,38,0,54,0,70,0,86,0,102,0,118,0,134,0,7,0,23,0,39,0,55,0,71,0,87,0,103,0,119,0,135,0,8,0,24,0,40,0,56,0,72,0,88,0,104,0,120,0,136,0,0,0,0,0,0,0,245,47,203,192,245,47,203,192,245,47,203,192,186,116,138,192,245,47,203,192,24,69,33,192,245,47,203,192,0,0,128,191,245,47,203,192,0,0,0,0,245,47,203,192,0,0,128,63,245,47,203,192,24,69,33,64,245,47,203,192,186,116,138,64,245,47,203,192,245,47,203,64,186,116,138,192,245,47,203,192,186,116,138,192,186,116,138,192,186,116,138,192,24,69,33,192,186,116,138,192,0,0,128,191,186,116,138,192,0,0,0,0,186,116,138,192,0,0,128,63,186,116,138,192,24,69,33,64,186,116,138,192,186,116,138,64,186,116,138,192,245,47,203,64,24,69,33,192,245,47,203,192,24,69,33,192,186,116,138,192,24,69,33,192,24,69,33,192,24,69,33,192,0,0,128,191,24,69,33,192,0,0,0,0,24,69,33,192,0,0,128,63,24,69,33,192,24,69,33,64,24,69,33,192,186,116,138,64,24,69,33,192,245,47,203,64,0,0,128,191,245,47,203,192,0,0,128,191,186,116,138,192,0,0,128,191,24,69,33,192,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,24,69,33,64,0,0,128,191,186,116,138,64,0,0,128,191,245,47,203,64,0,0,0,0,245,47,203,192,0,0,0,0,186,116,138,192,0,0,0,0,24,69,33,192,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,186,116,138,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,192,0,0,128,63,186,116,138,192,0,0,128,63,24,69,33,192,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,186,116,138,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,192,24,69,33,64,186,116,138,192,24,69,33,64,24,69,33,192,24,69,33,64,0,0,128,191,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,186,116,138,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,192,186,116,138,64,186,116,138,192,186,116,138,64,24,69,33,192,186,116,138,64,0,0,128,191,186,116,138,64,0,0,0,0,186,116,138,64,0,0,128,63,186,116,138,64,24,69,33,64,186,116,138,64,186,116,138,64,186,116,138,64,245,47,203,64,245,47,203,64,245,47,203,192,245,47,203,64,186,116,138,192,245,47,203,64,24,69,33,192,245,47,203,64,0,0,128,191,245,47,203,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,64,245,47,203,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,24,69,33,64,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,24,69,33,64,0,0,0,0,0,0,0,0,24,69,33,64,0,0,0,0,0,0,0,0,0,0,0,0,24,69,33,64,0,0,128,63,0,0,0,0,0,0,0,0,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,0,0,0,0,0,0,0,0,0,0,128,63,24,69,33,64,0,0,128,63,0,0,0,0,0,0,128,63,24,69,33,64,24,69,33,64,0,0,0,0,24,69,33,64,0,0,0,0,0,0,0,0,0,0,0,0,24,69,33,64,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,0,0,0,0,0,0,0,0,24,69,33,64,0,0,128,63,0,0,128,63,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,0,0,0,0,24,69,33,64,24,69,33,64,0,0,0,0,0,0,0,0,24,69,33,64,24,69,33,64,0,0,128,63,0,0,0,0,24,69,33,64,24,69,33,64,24,69,33,64,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,24,69,33,64,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,24,69,33,64,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,128,63,0,0,128,63,0,0,0,0,24,69,33,64,24,69,33,64,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,24,69,33,64,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,0,0,128,63,24,69,33,64,0,0,0,0,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,24,69,33,64,0,0,128,63,24,69,33,64,0,0,0,0,0,0,0,0,0,0,128,63,24,69,33,64,0,0,0,0,0,0,128,63,0,0,128,63,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,0,0,128,63,0,0,0,0,0,0,128,63,24,69,33,64,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,24,69,33,64,0,0,128,63,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,24,69,33,64,0,0,0,0,0,0,0,0,0,0,0,0,24,69,33,64,0,0,0,0,0,0,0,0,0,0,128,63,24,69,33,64,0,0,0,0,0,0,0,0,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,0,0,128,63,0,0,128,63,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,24,69,33,64,0,0,0,0,24,69,33,64,0,0,0,0,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,0,0,0,0,24,69,33,64,24,69,33,64,24,69,33,64,0,0,128,63,0,0,0,0,0,0,0,0,24,69,33,64,0,0,128,63,0,0,0,0,0,0,128,63,24,69,33,64,0,0,128,63,0,0,0,0,24,69,33,64,24,69,33,64,0,0,128,63,0,0,128,63,0,0,0,0,24,69,33,64,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,0,0,128,63,24,69,33,64,24,69,33,64,0,0,128,63,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,0,0,128,63,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,24,69,33,64,0,0,0,0,0,0,0,0,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,24,69,33,64,0,0,0,0,24,69,33,64,24,69,33,64,24,69,33,64,0,0,128,63,0,0,0,0,24,69,33,64,24,69,33,64,0,0,128,63,0,0,128,63,24,69,33,64,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,24,69,33,64,0,0,0,0,24,69,33,64,24,69,33,64,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,24,69,33,64,0,0,0,0,0,0,128,63,24,69,33,64,186,116,138,64,245,47,203,64,79,204,8,65,142,113,46,65,144,63,86,65,0,0,128,65,27,196,149,65,211,90,172,65,211,181,195,65,255,200,219,65,239,137,244,65,205,247,6,66,4,249,19,66,0,0,16,16,32,16,48,16,64,16,80,16,96,16,112,16,128,16,144,16,160,16,176,16,192,16,208,16,224,16,240,16,0,18,1,16,17,32,33,32,49,32,65,32,81,32,97,32,113,32,129,32,145,32,161,32,177,32,193,32,209,32,225,32,241,32,1,34,2,16,18,32,34,32,50,32,66,32,82,32,98,32,114,32,130,32,146,32,162,32,178,32,194,32,210,32,226,32,242,32,2,34,3,16,19,32,35,32,51,32,67,32,83,32,99,32,115,32,131,32,147,32,163,32,179,32,195,32,211,32,227,32,243,32,3,34,4,16,20,32,36,32,52,32,68,32,84,32,100,32,116,32,132,32,148,32,164,32,180,32,196,32,212,32,228,32,244,32,4,34,5,16,21,32,37,32,53,32,69,32,85,32,101,32,117,32,133,32,149,32,165,32,181,32,197,32,213,32,229,32,245,32,5,34,6,16,22,32,38,32,54,32,70,32,86,32,102,32,118,32,134,32,150,32,166,32,182,32,198,32,214,32,230,32,246,32,6,34,7,16,23,32,39,32,55,32,71,32,87,32,103,32,119,32,135,32,151,32,167,32,183,32,199,32,215,32,231,32,247,32,7,34,8,16,24,32,40,32,56,32,72,32,88,32,104,32,120,32,136,32,152,32,168,32,184,32,200,32,216,32,232,32,248,32,8,34,9,16,25,32,41,32,57,32,73,32,89,32,105,32,121,32,137,32,153,32,169,32,185,32,201,32,217,32,233,32,249,32,9,34,10,16,26,32,42,32,58,32,74,32,90,32,106,32,122,32,138,32,154,32,170,32,186,32,202,32,218,32,234,32,250,32,10,34,11,16,27,32,43,32,59,32,75,32,91,32,107,32,123,32,139,32,155,32,171,32,187,32,203,32,219,32,235,32,251,32,11,34,12,16,28,32,44,32,60,32,76,32,92,32,108,32,124,32,140,32,156,32,172,32,188,32,204,32,220,32,236,32,252,32,12,34,13,16,29,32,45,32,61,32,77,32,93,32,109,32,125,32,141,32,157,32,173,32,189,32,205,32,221,32,237,32,253,32,13,34,14,16,30,32,46,32,62,32,78,32,94,32,110,32,126,32,142,32,158,32,174,32,190,32,206,32,222,32,238,32,254,32,14,34,15,16,31,32,47,32,63,32,79,32,95,32,111,32,127,32,143,32,159,32,175,32,191,32,207,32,223,32,239,32,255,32,15,34,0,17,16,33,32,33,48,33,64,33,80,33,96,33,112,33,128,33,144,33,160,33,176,33,192,33,208,33,224,33,240,33,0,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,24,69,33,64,0,0,0,0,186,116,138,64,0,0,0,0,245,47,203,64,0,0,0,0,79,204,8,65,0,0,0,0,142,113,46,65,0,0,0,0,144,63,86,65,0,0,0,0,0,0,128,65,0,0,0,0,27,196,149,65,0,0,0,0,211,90,172,65,0,0,0,0,211,181,195,65,0,0,0,0,255,200,219,65,0,0,0,0,239,137,244,65,0,0,0,0,205,247,6,66,0,0,0,0,4,249,19,66,0,0,0,0,0,0,128,66,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,24,69,33,64,0,0,128,63,186,116,138,64,0,0,128,63,245,47,203,64,0,0,128,63,79,204,8,65,0,0,128,63,142,113,46,65,0,0,128,63,144,63,86,65,0,0,128,63,0,0,128,65,0,0,128,63,27,196,149,65,0,0,128,63,211,90,172,65,0,0,128,63,211,181,195,65,0,0,128,63,255,200,219,65,0,0,128,63,239,137,244,65,0,0,128,63,205,247,6,66,0,0,128,63,4,249,19,66,0,0,128,63,0,0,128,66,24,69,33,64,0,0,0,0,24,69,33,64,0,0,128,63,24,69,33,64,24,69,33,64,24,69,33,64,186,116,138,64,24,69,33,64,245,47,203,64,24,69,33,64,79,204,8,65,24,69,33,64,142,113,46,65,24,69,33,64,144,63,86,65,24,69,33,64,0,0,128,65,24,69,33,64,27,196,149,65,24,69,33,64,211,90,172,65,24,69,33,64,211,181,195,65,24,69,33,64,255,200,219,65,24,69,33,64,239,137,244,65,24,69,33,64,205,247,6,66,24,69,33,64,4,249,19,66,24,69,33,64,0,0,128,66,186,116,138,64,0,0,0,0,186,116,138,64,0,0,128,63,186,116,138,64,24,69,33,64,186,116,138,64,186,116,138,64,186,116,138,64,245,47,203,64,186,116,138,64,79,204,8,65,186,116,138,64,142,113,46,65,186,116,138,64,144,63,86,65,186,116,138,64,0,0,128,65,186,116,138,64,27,196,149,65,186,116,138,64,211,90,172,65,186,116,138,64,211,181,195,65,186,116,138,64,255,200,219,65,186,116,138,64,239,137,244,65,186,116,138,64,205,247,6,66,186,116,138,64,4,249,19,66,186,116,138,64,0,0,128,66,245,47,203,64,0,0,0,0,245,47,203,64,0,0,128,63,245,47,203,64,24,69,33,64,245,47,203,64,186,116,138,64,245,47,203,64,245,47,203,64,245,47,203,64,79,204,8,65,245,47,203,64,142,113,46,65,245,47,203,64,144,63,86,65,245,47,203,64,0,0,128,65,245,47,203,64,27,196,149,65,245,47,203,64,211,90,172,65,245,47,203,64,211,181,195,65,245,47,203,64,255,200,219,65,245,47,203,64,239,137,244,65,245,47,203,64,205,247,6,66,245,47,203,64,4,249,19,66,245,47,203,64,0,0,128,66,79,204,8,65,0,0,0,0,79,204,8,65,0,0,128,63,79,204,8,65,24,69,33,64,79,204,8,65,186,116,138,64,79,204,8,65,245,47,203,64,79,204,8,65,79,204,8,65,79,204,8,65,142,113,46,65,79,204,8,65,144,63,86,65,79,204,8,65,0,0,128,65,79,204,8,65,27,196,149,65,79,204,8,65,211,90,172,65,79,204,8,65,211,181,195,65,79,204,8,65,255,200,219,65,79,204,8,65,239,137,244,65,79,204,8,65,205,247,6,66,79,204,8,65,4,249,19,66,79,204,8,65,0,0,128,66,142,113,46,65,0,0,0,0,142,113,46,65,0,0,128,63,142,113,46,65,24,69,33,64,142,113,46,65,186,116,138,64,142,113,46,65,245,47,203,64,142,113,46,65,79,204,8,65,142,113,46,65,142,113,46,65,142,113,46,65,144,63,86,65,142,113,46,65,0,0,128,65,142,113,46,65,27,196,149,65,142,113,46,65,211,90,172,65,142,113,46,65,211,181,195,65,142,113,46,65,255,200,219,65,142,113,46,65,239,137,244,65,142,113,46,65,205,247,6,66,142,113,46,65,4,249,19,66,142,113,46,65,0,0,128,66,144,63,86,65,0,0,0,0,144,63,86,65,0,0,128,63,144,63,86,65,24,69,33,64,144,63,86,65,186,116,138,64,144,63,86,65,245,47,203,64,144,63,86,65,79,204,8,65,144,63,86,65,142,113,46,65,144,63,86,65,144,63,86,65,144,63,86,65,0,0,128,65,144,63,86,65,27,196,149,65,144,63,86,65,211,90,172,65,144,63,86,65,211,181,195,65,144,63,86,65,255,200,219,65,144,63,86,65,239,137,244,65,144,63,86,65,205,247,6,66,144,63,86,65,4,249,19,66,144,63,86,65,0,0,128,66,0,0,128,65,0,0,0,0,0,0,128,65,0,0,128,63,0,0,128,65,24,69,33,64,0,0,128,65,186,116,138,64,0,0,128,65,245,47,203,64,0,0,128,65,79,204,8,65,0,0,128,65,142,113,46,65,0,0,128,65,144,63,86,65,0,0,128,65,0,0,128,65,0,0,128,65,27,196,149,65,0,0,128,65,211,90,172,65,0,0,128,65,211,181,195,65,0,0,128,65,255,200,219,65,0,0,128,65,239,137,244,65,0,0,128,65,205,247,6,66,0,0,128,65,4,249,19,66,0,0,128,65,0,0,128,66,27,196,149,65,0,0,0,0,27,196,149,65,0,0,128,63,27,196,149,65,24,69,33,64,27,196,149,65,186,116,138,64,27,196,149,65,245,47,203,64,27,196,149,65,79,204,8,65,27,196,149,65,142,113,46,65,27,196,149,65,144,63,86,65,27,196,149,65,0,0,128,65,27,196,149,65,27,196,149,65,27,196,149,65,211,90,172,65,27,196,149,65,211,181,195,65,27,196,149,65,255,200,219,65,27,196,149,65,239,137,244,65,27,196,149,65,205,247,6,66,27,196,149,65,4,249,19,66,27,196,149,65,0,0,128,66,211,90,172,65,0,0,0,0,211,90,172,65,0,0,128,63,211,90,172,65,24,69,33,64,211,90,172,65,186,116,138,64,211,90,172,65,245,47,203,64,211,90,172,65,79,204,8,65,211,90,172,65,142,113,46,65,211,90,172,65,144,63,86,65,211,90,172,65,0,0,128,65,211,90,172,65,27,196,149,65,211,90,172,65,211,90,172,65,211,90,172,65,211,181,195,65,211,90,172,65,255,200,219,65,211,90,172,65,239,137,244,65,211,90,172,65,205,247,6,66,211,90,172,65,4,249,19,66,211,90,172,65,0,0,128,66,211,181,195,65,0,0,0,0,211,181,195,65,0,0,128,63,211,181,195,65,24,69,33,64,211,181,195,65,186,116,138,64,211,181,195,65,245,47,203,64,211,181,195,65,79,204,8,65,211,181,195,65,142,113,46,65,211,181,195,65,144,63,86,65,211,181,195,65,0,0,128,65,211,181,195,65,27,196,149,65,211,181,195,65,211,90,172,65,211,181,195,65,211,181,195,65,211,181,195,65,255,200,219,65,211,181,195,65,239,137,244,65,211,181,195,65,205,247,6,66,211,181,195,65,4,249,19,66,211,181,195,65,0,0,128,66,255,200,219,65,0,0,0,0,255,200,219,65,0,0,128,63,255,200,219,65,24,69,33,64,255,200,219,65,186,116,138,64,255,200,219,65,245,47,203,64,255,200,219,65,79,204,8,65,255,200,219,65,142,113,46,65,255,200,219,65,144,63,86,65,255,200,219,65,0,0,128,65,255,200,219,65,27,196,149,65,255,200,219,65,211,90,172,65,255,200,219,65,211,181,195,65,255,200,219,65,255,200,219,65,255,200,219,65,239,137,244,65,255,200,219,65,205,247,6,66,255,200,219,65,4,249,19,66,255,200,219,65,0,0,128,66,239,137,244,65,0,0,0,0,239,137,244,65,0,0,128,63,239,137,244,65,24,69,33,64,239,137,244,65,186,116,138,64,239,137,244,65,245,47,203,64,239,137,244,65,79,204,8,65,239,137,244,65,142,113,46,65,239,137,244,65,144,63,86,65,239,137,244,65,0,0,128,65,239,137,244,65,27,196,149,65,239,137,244,65,211,90,172,65,239,137,244,65,211,181,195,65,239,137,244,65,255,200,219,65,239,137,244,65,239,137,244,65,239,137,244,65,205,247,6,66,239,137,244,65,4,249,19,66,239,137,244,65,0,0,128,66,205,247,6,66,0,0,0,0,205,247,6,66,0,0,128,63,205,247,6,66,24,69,33,64,205,247,6,66,186,116,138,64,205,247,6,66,245,47,203,64,205,247,6,66,79,204,8,65,205,247,6,66,142,113,46,65,205,247,6,66,144,63,86,65,205,247,6,66,0,0,128,65,205,247,6,66,27,196,149,65,205,247,6,66,211,90,172,65,205,247,6,66,211,181,195,65,205,247,6,66,255,200,219,65,205,247,6,66,239,137,244,65,205,247,6,66,205,247,6,66,205,247,6,66,4,249,19,66,205,247,6,66,0,0,128,66,4,249,19,66,0,0,0,0,4,249,19,66,0,0,128,63,4,249,19,66,24,69,33,64,4,249,19,66,186,116,138,64,4,249,19,66,245,47,203,64,4,249,19,66,79,204,8,65,4,249,19,66,142,113,46,65,4,249,19,66,144,63,86,65,4,249,19,66,0,0,128,65,4,249,19,66,27,196,149,65,4,249,19,66,211,90,172,65,4,249,19,66,211,181,195,65,4,249,19,66,255,200,219,65,4,249,19,66,239,137,244,65,4,249,19,66,205,247,6,66,4,249,19,66,4,249,19,66,4,249,19,66,0,0,128,66,0,0,128,66,0,0,0,0,0,0,128,66,0,0,128,63,0,0,128,66,24,69,33,64,0,0,128,66,186,116,138,64,0,0,128,66,245,47,203,64,0,0,128,66,79,204,8,65,0,0,128,66,142,113,46,65,0,0,128,66,144,63,86,65,0,0,128,66,0,0,128,65,0,0,128,66,27,196,149,65,0,0,128,66,211,90,172,65,0,0,128,66,211,181,195,65,0,0,128,66,255,200,219,65,0,0,128,66,239,137,244,65,0,0,128,66,205,247,6,66,0,0,128,66,4,249,19,66,0,0,128,66,0,0,128,66,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,64,129,128,129,16,65,80,194,144,194,32,65,96,194,160,194,4,33,68,162,132,162,20,98,84,227,148,227,36,98,100,227,164,227,8,33,72,162,136,162,24,98,88,227,152,227,40,98,104,227,168,227,1,17,65,146,129,146,17,82,81,211,145,211,33,82,97,211,161,211,5,50,69,179,133,179,21,115,85,244,149,244,37,115,101,244,165,244,9,50,73,179,137,179,25,115,89,244,153,244,41,115,105,244,169,244,2,17,66,146,130,146,18,82,82,211,146,211,34,82,98,211,162,211,6,50,70,179,134,179,22,115,86,244,150,244,38,115,102,244,166,244,10,50,74,179,138,179,26,115,90,244,154,244,42,115,106,244,170,244,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,191,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,191,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,191,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,191,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,191,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,191,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,4,5,4,5,3,5,3,5,3,5,4,4,4,4,5,5,5,0,0,0,0,0,0,0,4,3,4,3,4,4,5,4,5,4,5,5,6,5,6,5,7,5,7,6,7,6,8,7,8,7,8,7,9,8,9,9,9,9,10,10,10,11,9,12,9,12,9,15,10,14,9,13,10,13,10,12,10,12,10,13,10,12,11,13,11,14,12,13,13,14,14,13,14,15,14,16,13,13,14,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,15,15,1,5,5,5,5,5,5,5,6,5,6,5,6,5,6,5,6,6,7,7,7,7,8,7,8,8,9,8,10,9,10,9,8,5,8,4,9,4,9,4,9,4,9,4,9,4,9,4,9,4,9,4,9,4,8,4,8,4,9,5,9,5,9,5,9,5,9,6,10,6,10,7,10,8,11,9,11,11,12,13,12,14,13,15,13,15,14,16,14,17,15,17,15,15,16,16,15,16,16,16,15,18,16,15,17,17,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,2,5,5,4,5,4,5,4,5,4,6,5,6,5,6,5,6,5,7,5,7,6,8,6,8,6,8,6,9,6,9,6,5,5,5,5,6,5,6,5,6,5,6,5,6,5,6,5,6,5,6,5,6,5,6,5,7,5,7,5,7,5,7,5,8,6,8,6,8,6,9,6,9,6,10,6,10,6,11,6,11,7,11,7,12,7,12,7,12,7,12,7,12,7,12,7,12,7,12,8,13,8,12,8,12,8,13,8,13,9,13,9,13,9,13,9,12,10,12,10,13,10,14,11,14,12,14,13,14,13,14,14,15,16,15,15,15,14,15,17,21,22,22,21,22,22,22,22,22,22,21,21,21,21,21,21,21,21,21,21,2,3,7,13,4,4,7,15,8,6,9,17,21,16,15,21,2,5,7,11,5,5,7,14,9,7,10,16,17,15,16,21,4,7,10,17,7,7,9,15,11,9,11,16,21,18,15,21,18,21,21,21,15,17,17,19,21,19,18,20,21,21,21,20,2,5,5,6,6,7,7,7,7,7,7,8,8,8,8,8,8,10,6,6,7,7,8,7,8,8,8,8,8,9,9,9,9,9,10,6,6,7,7,7,7,8,8,8,8,9,9,9,9,9,9,10,7,7,7,7,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,7,7,8,8,8,9,9,9,9,9,9,9,9,9,11,11,11,8,8,8,8,9,9,9,9,9,9,9,9,9,9,10,10,10,8,8,8,8,9,9,9,9,9,9,9,9,9,9,10,10,10,8,9,9,9,9,9,9,9,9,9,9,9,10,9,10,10,10,11,11,9,9,9,9,9,9,9,9,9,9,9,9,11,10,11,11,11,9,9,9,9,9,9,10,10,9,9,10,9,11,10,11,11,11,9,9,9,9,9,9,9,9,10,10,10,9,11,11,11,11,11,9,9,9,9,10,10,9,9,9,9,10,9,11,11,11,11,11,11,11,9,9,9,9,9,9,10,10,10,10,11,11,11,11,11,11,11,10,9,10,10,9,10,9,9,10,9,11,10,10,11,11,11,11,9,10,9,9,9,9,10,10,10,10,11,11,11,11,11,11,10,10,10,9,9,10,9,10,9,10,10,10,10,11,11,11,11,11,11,11,9,9,9,9,9,10,10,10,0,0,0,0,0,0,0,1,4,4,6,6,7,7,8,7,9,9,10,10,10,10,6,5,5,7,7,8,8,10,8,11,10,12,12,13,13,6,5,5,7,7,8,8,10,9,11,11,12,12,13,12,18,8,8,8,8,9,9,10,9,11,10,12,12,13,13,18,8,8,8,8,9,9,10,10,11,11,13,12,14,13,18,11,11,9,9,10,10,11,11,11,12,13,12,13,14,18,11,11,9,8,11,10,11,11,11,11,12,12,14,13,18,18,18,10,11,10,11,12,12,12,12,13,12,14,13,18,18,18,10,11,11,9,12,11,12,12,12,13,13,13,18,18,17,14,14,11,11,12,12,13,12,14,12,14,13,18,18,18,14,14,11,10,12,9,12,13,13,13,13,13,18,18,17,16,18,13,13,12,12,13,11,14,12,14,14,17,18,18,17,18,13,12,13,10,12,11,14,14,14,14,17,18,18,18,18,15,16,12,12,13,10,14,12,14,15,18,18,18,16,17,16,14,12,11,13,10,13,13,14,15,0,0,0,0,0,0,0,1,4,4,12,12,12,12,12,12,12,12,12,12,4,9,8,12,12,12,12,12,12,12,12,12,12,2,9,7,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,0,0,0,0,0,0,0,2,4,4,5,5,6,5,5,5,5,6,4,5,5,5,6,5,5,5,5,6,6,6,5,5,0,0,0,0,0,0,0,1,4,4,6,6,7,7,8,8,9,9,10,10,6,5,5,7,7,8,8,8,8,9,9,10,10,7,5,5,7,7,8,8,8,8,9,9,11,10,0,8,8,8,8,9,9,9,9,10,10,11,11,0,8,8,8,8,9,9,9,9,10,10,11,11,0,12,12,9,9,10,10,10,10,11,11,11,12,0,13,13,9,9,10,10,10,10,11,11,12,12,0,0,0,10,10,10,10,11,11,12,12,12,12,0,0,0,10,10,10,10,11,11,12,12,12,12,0,0,0,14,14,11,11,11,11,12,12,13,13,0,0,0,14,14,11,11,11,11,12,12,13,13,0,0,0,0,0,12,12,12,12,13,13,14,13,0,0,0,0,0,13,13,12,12,13,12,14,13,0,0,0,0,0,0,0,2,4,4,6,6,7,7,7,7,8,8,10,5,5,6,6,7,7,8,8,8,8,10,5,5,6,6,7,7,8,8,8,8,10,6,6,7,7,8,8,8,8,8,8,10,10,10,7,7,8,7,8,8,8,8,10,10,10,8,8,8,8,8,8,8,8,10,10,10,7,8,8,8,8,8,8,8,10,10,10,8,8,8,8,8,8,8,8,10,10,10,10,10,8,8,8,8,8,8,10,10,10,10,10,9,9,8,8,9,8,10,10,10,10,10,8,8,8,8,8,8,0,0,0,0,0,0,0,1,4,4,7,6,6,7,6,6,4,7,7,10,9,9,11,9,9,4,7,7,10,9,9,11,9,9,7,10,10,11,11,10,12,11,11,6,9,9,11,10,10,11,10,10,6,9,9,11,10,10,11,10,10,7,11,11,11,11,11,12,11,11,6,9,9,11,10,10,11,10,10,6,9,9,11,10,10,11,10,10,0,0,0,0,0,0,0,2,3,3,6,6,7,7,8,8,8,8,9,9,10,10,11,10,0,5,5,7,7,8,8,9,9,9,9,10,10,10,10,11,11,0,5,5,7,7,8,8,9,9,9,9,10,10,10,10,11,11,0,6,6,7,7,8,8,9,9,9,9,10,10,11,11,11,11,0,0,0,7,7,8,8,9,9,9,9,10,10,11,11,11,12,0,0,0,8,8,8,8,9,9,9,9,10,10,11,11,12,12,0,0,0,8,8,8,8,9,9,9,9,10,10,11,11,12,12,0,0,0,9,9,9,9,10,10,10,10,11,10,11,11,12,12,0,0,0,0,0,9,9,10,10,10,10,11,11,11,11,12,12,0,0,0,0,0,9,8,9,9,10,10,11,11,12,12,12,12,0,0,0,0,0,8,8,9,9,10,10,11,11,12,11,12,12,0,0,0,0,0,9,10,10,10,11,11,11,11,12,12,13,13,0,0,0,0,0,0,0,10,10,10,10,11,11,12,12,13,13,0,0,0,0,0,0,0,11,11,11,11,12,12,12,12,13,13,0,0,0,0,0,0,0,11,11,11,11,12,12,12,12,13,13,0,0,0,0,0,0,0,11,11,12,12,12,12,13,13,13,13,0,0,0,0,0,0,0,0,0,12,12,12,12,13,13,13,13,0,0,0,0,0,0,0,1,3,4,6,6,7,7,9,9,0,5,5,7,7,7,8,9,9,0,5,5,7,7,8,8,9,9,0,7,7,8,8,8,8,10,10,0,0,0,8,8,8,8,10,10,0,0,0,9,9,9,9,10,10,0,0,0,9,9,9,9,10,10,0,0,0,10,10,10,10,11,11,0,0,0,0,0,10,10,11,11,0,0,0,0,0,0,0,1,5,7,21,5,8,9,21,10,9,12,20,20,16,20,20,4,8,9,20,6,8,9,20,11,11,13,20,20,15,17,20,9,11,14,20,8,10,15,20,11,13,15,20,20,20,20,20,20,20,20,20,13,20,20,20,18,18,20,20,20,20,20,20,3,6,8,20,6,7,9,20,10,9,12,20,20,20,20,20,5,7,9,20,6,6,9,20,10,9,12,20,20,20,20,20,8,10,13,20,8,9,12,20,11,10,12,20,20,20,20,20,18,20,20,20,15,17,18,20,18,17,18,20,20,20,20,20,7,10,12,20,8,9,11,20,14,13,14,20,20,20,20,20,6,9,12,20,7,8,11,20,12,11,13,20,20,20,20,20,9,11,15,20,8,10,14,20,12,11,14,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,11,16,18,20,15,15,17,20,20,17,20,20,20,20,20,20,9,14,16,20,12,12,15,20,17,15,18,20,20,20,20,20,16,19,18,20,15,16,20,20,17,17,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,2,3,3,6,6,0,0,0,0,0,4,4,6,6,0,0,0,0,0,4,4,6,6,0,0,0,0,0,5,5,6,6,0,0,0,0,0,0,0,6,6,0,0,0,0,0,0,0,7,8,0,0,0,0,0,0,0,7,7,0,0,0,0,0,0,0,9,9,0,0,0,0,2,4,3,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,6,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,7,9,9,0,0,0,0,0,0,0,2,5,5,0,0,0,5,5,0,0,0,5,5,0,0,0,7,8,0,0,0,0,0,0,0,5,6,6,0,0,0,7,7,0,0,0,7,7,0,0,0,10,10,0,0,0,0,0,0,0,5,6,6,0,0,0,7,7,0,0,0,7,7,0,0,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,7,7,0,0,0,7,7,0,0,0,9,9,0,0,0,0,0,0,0,5,7,7,0,0,0,7,7,0,0,0,7,7,0,0,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,7,7,0,0,0,7,7,0,0,0,9,9,0,0,0,0,0,0,0,5,7,7,0,0,0,7,7,0,0,0,7,7,0,0,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,10,10,0,0,0,9,9,0,0,0,9,9,0,0,0,10,10,0,0,0,0,0,0,0,8,10,10,0,0,0,9,9,0,0,0,9,9,0,0,0,10,10,0,0,0,0,0,2,4,4,0,0,0,0,0,0,5,6,6,0,0,0,0,0,0,5,6,6], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1691160);
/* memory initializer */ allocate([5,7,7,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,6,7,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,0,0,0,6,8,7,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,8,8,9,0,0,0,0,0,0,8,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,8,0,0,0,0,0,0,7,9,8,0,0,0,0,0,0,8,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,7,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,8,0,0,0,0,0,0,8,9,9,0,0,0,0,0,0,7,8,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,8,0,0,0,0,0,0,8,9,9,0,0,0,0,0,0,8,9,8,0,0,0,0,0,0,0,5,6,11,11,11,11,10,10,12,11,5,2,11,5,6,6,7,9,11,13,13,10,7,11,6,7,8,9,10,12,11,5,11,6,8,7,9,11,14,15,11,6,6,8,4,5,7,8,10,13,10,5,7,7,5,5,6,8,10,11,10,7,7,8,6,5,5,7,9,9,11,8,8,11,8,7,6,6,7,9,12,11,10,13,9,9,7,7,7,9,11,13,12,15,12,11,9,8,8,8,0,0,0,0,2,5,2,6,3,6,4,7,4,7,5,9,5,11,6,11,6,11,7,11,6,11,6,11,9,11,8,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,10,10,10,10,10,10,0,0,4,2,4,2,5,3,5,4,6,6,6,7,7,8,7,8,7,8,7,9,8,9,8,9,8,10,8,11,9,12,9,12,4,5,4,5,4,5,4,5,3,5,3,5,3,5,4,5,4,0,0,0,0,0,0,0,3,7,3,8,3,10,3,8,3,9,3,8,4,9,4,9,5,9,6,10,6,9,7,11,7,12,9,13,10,13,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,0,0,3,3,4,3,4,4,4,4,5,5,5,5,5,6,5,7,5,8,6,8,6,9,7,10,7,10,8,10,8,11,9,11,1,4,2,6,3,7,5,7,2,10,8,14,7,12,11,14,1,5,3,7,4,9,7,13,253,1,9,0,253,0,8,0,125,0,7,0,61,0,6,0,29,0,5,0,13,0,4,0,5,0,3,0,0,0,1,0,4,0,3,0,12,0,4,0,28,0,5,0,60,0,6,0,124,0,7,0,252,0,8,0,252,1,9,0,255,0,8,0,17,18,0,1,2,3,4,5,16,6,7,8,9,10,11,12,13,14,15,0,0,0,0,0,243,4,53,63,240,55,24,63,0,0,0,63,0,0,0,0,48,131,32,0,80,40,32,0,200,15,40,0,120,171,39,0,168,74,39,0,8,1,39,0,240,188,38,0,144,124,38,0,240,66,38,0,192,10,38,0,176,123,37,0,112,0,0,0,208,189,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,3,4,4,5,6,34,36,35,69,135,232,9,16,10,24,11,23,12,16,13,10,14,8,15,8,16,8,17,20,16,10,207,206,205,236,11,8,10,21,9,23,8,8,199,70,69,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,36,37,38,39,40,41,75,76,77,110,239,144,81,82,83,84,85,118,183,56,57,88,89,56,89,154,57,58,57,26,141,57,56,58,57,58,57,184,119,214,245,116,83,82,49,80,79,78,77,44,75,41,40,39,38,37,36,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,9,5,12,10,35,32,29,27,50,48,45,44,41,39,37,73,70,68,65,64,61,58,56,53,50,49,46,44,41,38,36,68,65,63,61,58,55,53,51,48,46,45,43,41,39,38,36,35,33,32,30,29,27,26,25,48,47,46,44,43,41,40,39,37,36,35,34,32,31,30,28,27,26,24,23,22,20,19,37,35,34,33,31,30,29,27,26,24,23,21,20,18,17,15,29,27,26,24,22,21,19,17,16,14,26,25,23,21,19,18,16,15,27,25,23,21,19,17,16,14,26,25,23,21,18,17,14,12,17,19,13,4,9,2,11,1,7,8,0,16,3,14,6,12,10,5,15,18,11,10,13,15,16,19,20,22,24,27,15,18,20,22,24,26,14,17,20,22,24,27,15,18,20,23,25,28,16,19,22,25,28,32,36,21,25,29,33,38,42,45,49,28,31,34,37,40,42,44,47,49,50,52,54,56,57,59,60,62,64,66,67,69,35,37,39,40,42,43,45,47,48,51,52,54,55,57,59,60,62,63,66,67,69,71,72,38,40,42,43,46,47,49,51,26,28,30,31,33,34,18,19,11,13,7,8,3,1,2,2,2,2,3,3,7,5,7,5,8,6,11,9,7,13,11,10,9,8,7,5,9,7,6,4,7,5,8,7,11,8,13,11,19,15,22,23,20,33,32,28,27,29,51,77,43,45,76,81,46,82,75,55,56,144,58,80,60,74,147,63,143,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,27,30,21,22,17,14,5,6,100,54,47,50,51,53,106,107,108,109,110,111,112,113,114,115,4,117,118,92,94,121,122,3,124,103,2,1,0,129,130,131,120,119,126,125,136,137,138,139,140,141,142,134,135,132,133,104,64,101,62,57,102,95,93,59,61,28,97,96,52,49,48,29,32,25,24,46,23,98,45,44,43,20,42,41,19,18,99,40,15,39,38,16,13,12,11,37,10,9,8,36,7,128,127,105,123,116,35,34,33,145,31,79,42,146,78,26,83,48,49,50,44,47,26,31,30,18,17,19,21,24,25,13,14,16,17,18,20,21,12,14,15,9,10,6,9,6,5,8,6,12,8,10,7,9,6,4,6,2,2,3,3,3,3,2,40,160,32,0,112,0,0,0,120,52,3,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,168,38,0,112,0,0,0,184,172,3,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,100,39,0,112,0,0,0,48,190,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,137,51,147,176,155,131,163,187,170,98,177,132,183,44,189,98,194,49,199,160,203,182,207,122,211,244,214,39,218,27,221,212,223,87,226,167,228,201,230,193,232,145,234,61,236,200,237,52,239,132,240,185,241,214,242,221,243,207,244,175,245,125,246,59,247,234,247,140,248,33,249,170,249,41,250,157,250,9,251,108,251,200,251,28,252,106,252,177,252,243,252,48,253,105,253,156,253,204,253,248,253,33,254,70,254,105,254,136,254,166,254,193,254,218,254,241,254,6,255,26,255,44,255,60,255,75,255,90,255,103,255,115,255,126,255,136,255,145,255,154,255,162,255,169,255,176,255,182,255,188,255,194,255,198,255,203,255,207,255,211,255,215,255,218,255,221,255,224,255,226,255,229,255,231,255,233,255,235,255,236,255,238,255,239,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,17,0,18,0,20,0,21,0,23,0,25,0,27,0,30,0,32,0,35,0,38,0,41,0,45,0,49,0,53,0,58,0,62,0,68,0,74,0,80,0,87,0,94,0,102,0,111,0,120,0,130,0,141,0,153,0,166,0,181,0,196,0,212,0,230,0,250,0,15,1,38,1,63,1,90,1,120,1,151,1,186,1,223,1,8,2,52,2,100,2,151,2,208,2,13,3,79,3,150,3,228,3,56,4,148,4,247,4,99,5,215,5,86,6,223,6,116,7,22,8,197,8,131,9,81,10,49,11,35,12,42,13,71,14,124,15,204,16,56,18,195,19,111,21,63,23,55,25,89,27,169,29,44,32,229,34,217,37,12,41,134,44,74,48,96,52,207,56,158,61,212,66,124,72,158,78,69,85,125,92,80,100,205,108,2,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,153,25,191,195,245,8,191,195,245,168,190,164,112,61,190,92,143,194,189,158,239,39,189,30,167,104,188,179,123,114,187,154,153,25,191,195,245,8,191,195,245,168,190,164,112,61,190,92,143,194,189,158,239,39,189,30,167,104,188,179,123,114,187,144,26,35,0,112,82,34,0,88,173,33,0,176,46,33,0,24,195,32,0,8,102,32,0,32,76,40,0,64,243,39,0,20,28,36,44,52,60,68,76,84,92,100,106,112,116,120,124,128,132,136,140,144,150,156,164,172,180,188,196,204,212,220,228,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,34,0,0,0,35,0,0,0,35,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,37,0,0,0,17,18,24,47,99,99,99,99,18,21,26,66,99,99,99,99,24,26,56,99,99,99,99,99,47,66,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,99,9,9,12,24,50,50,50,50,9,11,13,33,50,50,50,50,12,13,28,50,50,50,50,50,24,33,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,50,6,255,255,255,255,4,1,255,255,255,5,2,255,255,255,2,1,0,255,255,2,1,0,3,255,0,0,0,0,0,0,0,1,1,1,255,1,1,1,2,1,255,2,1,1,3,1,255,3,1,1,4,1,255,4,1,1,5,1,255,5,1,1,6,1,255,6,1,1,7,1,255,7,1,2,1,2,254,1,2,1,8,1,255,8,1,1,9,1,255,9,1,1,10,1,255,10,1,1,11,1,255,11,1,1,12,1,255,12,1,1,13,1,255,13,1,1,14,1,255,14,1,1,15,1,255,15,1,3,1,3,253,1,3,1,16,1,255,16,1,1,17,1,255,17,1,1,18,1,255,18,1,1,19,1,255,19,1,1,20,1,255,20,1,1,21,1,255,21,1,1,22,1,255,22,1,2,2,2,254,2,2,1,23,1,255,23,1,1,24,1,255,24,1,1,25,1,255,25,1,4,1,3,252,1,3,0,0,0,0,5,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,255,2,0,0,0,0,0,0,0,25,0,0,0,0,0,0,1,1,0,255,1,0,1,2,0,255,2,0,2,1,1,254,1,1,1,3,0,255,3,0,1,4,0,255,4,0,1,5,0,255,5,0,1,6,0,255,6,0,3,1,2,253,1,2,1,7,0,255,7,0,1,8,0,255,8,0,2,2,1,254,2,1,1,9,0,255,9,0,1,10,0,255,10,0,1,11,0,255,11,0,4,1,2,252,1,2,1,12,0,255,12,0,1,13,0,255,13,0,1,14,0,255,14,0,2,3,1,254,3,1,1,15,0,255,15,0,2,4,1,254,4,1,5,1,3,251,1,3,3,2,2,253,2,2,1,16,0,255,16,0,1,17,0,255,17,0,1,18,0,255,18,0,2,5,1,254,5,1,1,19,0,255,19,0,1,20,0,255,20,0,0,6,4,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,255,255,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,1,1,0,255,1,0,0,0,0,2,1,0,254,1,0,1,2,0,255,2,0,3,1,1,253,1,1,1,3,0,255,3,0,4,1,1,252,1,1,2,2,0,254,2,0,1,4,0,255,4,0,5,1,2,251,1,2,1,5,0,255,5,0,3,2,1,253,2,1,2,3,0,254,3,0,1,6,0,255,6,0,6,1,2,250,1,2,1,7,0,255,7,0,2,4,0,254,4,0,7,1,2,249,1,2,1,8,0,255,8,0,4,2,1,252,2,1,1,9,0,255,9,0,3,3,1,253,3,1,2,5,0,254,5,0,2,6,0,254,6,0,8,1,2,248,1,2,1,10,0,255,10,0,1,11,0,255,11,0,9,1,2,247,1,2,5,2,2,251,2,2,3,4,1,253,4,1,0,10,6,4,4,3,3,2,2,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,2,0,0,0,11,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,1,2,0,255,2,0,5,1,1,251,1,1,2,2,0,254,2,0,6,1,1,250,1,1,1,3,0,255,3,0,7,1,1,249,1,1,3,2,0,253,2,0,8,1,1,248,1,1,1,4,0,255,4,0,2,3,0,254,3,0,9,1,1,247,1,1,4,2,0,252,2,0,1,5,0,255,5,0,10,1,1,246,1,1,3,3,0,253,3,0,5,2,1,251,2,1,2,4,0,254,4,0,11,1,1,245,1,1,1,6,0,255,6,0,12,1,1,244,1,1,1,7,0,255,7,0,6,2,1,250,2,1,13,1,1,243,1,1,2,5,0,254,5,0,1,8,0,255,8,0,0,14,7,4,3,3,2,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,4,0,0,0,8,0,0,0,0,0,0,1,1,0,255,1,0,2,1,0,254,1,0,3,1,0,253,1,0,4,1,0,252,1,0,5,1,0,251,1,0,6,1,0,250,1,0,7,1,0,249,1,0,8,1,0,248,1,0,1,2,0,255,2,0,9,1,0,247,1,0,10,1,0,246,1,0,11,1,0,245,1,0,2,2,0,254,2,0,12,1,0,244,1,0,13,1,0,243,1,0,3,2,0,253,2,0,14,1,0,242,1,0,1,3,0,255,3,0,15,1,0,241,1,0,4,2,0,252,2,0,16,1,0,240,1,0,17,1,0,239,1,0,5,2,0,251,2,0,1,4,0,255,4,0,2,3,0,254,3,0,18,1,0,238,1,0,6,2,0,250,2,0,19,1,0,237,1,0,1,5,0,255,5,0,0,20,7,3,2,2,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,255,255,255,127,5,0,0,0,1,2,3,3,1,2,2,0,1,1,0,0,0,0,0,0,1,1,1,0,1,1,0,0,1,0,0,0,0,0,0,0,0,16,32,48,0,0,0,0,0,16,32,48,0,0,0,0,0,16,32,48,0,0,0,0,2,0,0,0,6,1,0,0,6,6,3,0,6,7,7,6,6,8,8,7,0,0,0,0,1,0,0,0,7,1,0,0,4,6,1,0,3,3,2,5,2,3,2,0,0,0,0,0,0,0,0,0,3,0,0,0,5,0,0,0,0,0,0,0,1,1,0,255,255,255,0,1,0,1,1,1,0,255,255,255,1,3,3,4,4,4,5,5,3,2,3,3,3,3,3,0,3,3,2,2,3,3,0,0,3,2,2,2,3,0,0,0,2,2,2,2,0,0,0,0,2,2,1,0,0,0,0,0,1,1,0,0,0,0,0,0,1,2,3,2,3,1,1,0,0,1,1,4,5,6,7,0,0,1,1,2,6,7,0,0,6,0,1,2,7,0,0,0,0,1,2,3,0,0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,16,64,96,48,80,112,0,32,16,64,96,48,80,112,1,0,0,0,7,2,0,0,7,7,3,0,9,7,7,5,9,9,7,6,10,10,9,7,11,11,10,7,12,12,11,10,13,12,12,11,0,0,0,0,1,0,0,0,15,1,0,0,14,13,1,0,7,12,11,1,6,5,10,1,7,6,4,9,7,6,5,8,7,6,5,4,7,5,4,4,0,0,0,0,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,174,71,225,122,20,174,251,63,10,215,163,112,61,10,247,63,51,51,51,51,51,51,243,63,0,0,0,0,0,0,240,63,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,33,16,66,32,99,48,132,64,165,80,198,96,231,112,8,129,41,145,74,161,107,177,140,193,173,209,206,225,239,241,49,18,16,2,115,50,82,34,181,82,148,66,247,114,214,98,57,147,24,131,123,179,90,163,189,211,156,195,255,243,222,227,98,36,67,52,32,4,1,20,230,100,199,116,164,68,133,84,106,165,75,181,40,133,9,149,238,229,207,245,172,197,141,213,83,54,114,38,17,22,48,6,215,118,246,102,149,86,180,70,91,183,122,167,25,151,56,135,223,247,254,231,157,215,188,199,196,72,229,88,134,104,167,120,64,8,97,24,2,40,35,56,204,201,237,217,142,233,175,249,72,137,105,153,10,169,43,185,245,90,212,74,183,122,150,106,113,26,80,10,51,58,18,42,253,219,220,203,191,251,158,235,121,155,88,139,59,187,26,171,166,108,135,124,228,76,197,92,34,44,3,60,96,12,65,28,174,237,143,253,236,205,205,221,42,173,11,189,104,141,73,157,151,126,182,110,213,94,244,78,19,62,50,46,81,30,112,14,159,255,190,239,221,223,252,207,27,191,58,175,89,159,120,143,136,145,169,129,202,177,235,161,12,209,45,193,78,241,111,225,128,16,161,0,194,48,227,32,4,80,37,64,70,112,103,96,185,131,152,147,251,163,218,179,61,195,28,211,127,227,94,243,177,2,144,18,243,34,210,50,53,66,20,82,119,98,86,114,234,181,203,165,168,149,137,133,110,245,79,229,44,213,13,197,226,52,195,36,160,20,129,4,102,116,71,100,36,84,5,68,219,167,250,183,153,135,184,151,95,231,126,247,29,199,60,215,211,38,242,54,145,6,176,22,87,102,118,118,21,70,52,86,76,217,109,201,14,249,47,233,200,153,233,137,138,185,171,169,68,88,101,72,6,120,39,104,192,24,225,8,130,56,163,40,125,203,92,219,63,235,30,251,249,139,216,155,187,171,154,187,117,74,84,90,55,106,22,122,241,10,208,26,179,42,146,58,46,253,15,237,108,221,77,205,170,189,139,173,232,157,201,141,38,124,7,108,100,92,69,76,162,60,131,44,224,28,193,12,31,239,62,255,93,207,124,223,155,175,186,191,217,143,248,159,23,110,54,126,85,78,116,94,147,46,178,62,209,14,240,30,13,0,13,0,14,14,1,1,12,11,10,2,13,3,13,3,4,4,4,4,5,5,5,5,6,6,6,6,13,7,13,7,14,14,8,8,14,0,1,9,24,0,0,0,25,0,0,0,30,0,0,0,50,0,0,0,60,0,0,0,0,0,0,0,117,116,102,56,0,0,200,119,99,104,97,114,116,0,0,198,117,99,115,50,0,117,99,115,50,98,101,0,0,196,117,99,115,50,108,101,0,0,197,117,116,102,49,54,0,117,116,102,49,54,98,101,0,0,194,117,116,102,49,54,108,101,0,0,193,117,99,115,52,0,117,99,115,52,98,101,0,117,116,102,51,50,0,117,116,102,51,50,98,101,0,0,192,117,99,115,52,108,101,0,117,116,102,51,50,108,101,0,0,195,97,115,99,105,105,0,117,115,97,115,99,105,105,0,105,115,111,54,52,54,0,105,115,111,54,52,54,117,115,0,0,199,101,117,99,106,112,0,0,208,115,104,105,102,116,106,105,115,0,115,106,105,115,0,0,209,103,98,49,56,48,51,48,0,0,216,103,98,107,0,0,217,103,98,50,51,49,50,0,0,218,98,105,103,53,0,98,105,103,102,105,118,101,0,99,112,57,53,48,0,98,105,103,53,104,107,115,99,115,0,0,224,101,117,99,107,114,0,107,115,99,53,54,48,49,0,107,115,120,49,48,48,49,0,99,112,57,52,57,0,0,232,105,115,111,56,56,53,57,49,0,108,97,116,105,110,49,0,0,128,105,115,111,56,56,53,57,50,0,0,32,0,84,0,137,18,0,32,1,6,0,0,152,65,134,26,127,0,48,72,32,0,88,32,201,18,0,36,17,198,35,0,156,81,198,26,128,80,66,136,32,90,0,0,192,4,0,16,113,1,0,29,0,112,2,0,41,0,0,192,7,33,48,1,5,0,0,88,1,0,0,94,208,1,128,29,0,0,128,6,0,91,0,0,0,5,0,20,129,1,0,30,0,128,2,0,42,0,0,0,8,34,52,17,5,0,0,92,1,0,0,95,212,1,192,29,0,0,144,70,36,105,115,111,56,56,53,57,51,0,0,32,0,212,0,9,0,0,4,48,3,0,0,244,64,70,11,63,0,16,64,32,0,216,0,0,0,0,0,64,3,0,0,248,80,134,11,64,0,16,128,32,0,0,0,64,0,0,108,144,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,188,0,0,0,43,0,0,0,0,0,200,33,6,0,0,0,0,64,0,0,112,160,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,192,0,0,0,44,0,0,0,0,0,204,49,70,36,105,115,111,56,56,53,57,52,0,0,32,0,84,48,4,23,0,220,96,4,0,0,152,49,66,12,108,0,48,8,0,0,88,32,73,23,0,224,112,196,35,0,156,65,130,12,109,72,65,200,20,17,0,0,0,0,0,0,0,192,14,29,0,112,2,0,37,0,0,64,14,33,56,65,69,16,0,0,0,0,0,0,224,1,0,0,0,184,1,7,0,18,0,0,0,0,0,0,0,0,15,30,0,128,2,0,38,0,0,128,14,34,60,81,133,16,0,0,0,0,0,0,228,1,0,0,0,188,17,71,36,105,115,111,56,56,53,57,53,0,0,32,0,136,51,14,57,229,152,115,14,58,233,168,179,14,59,237,0,224,206,59,240,196,35,207,60,244,212,99,207,61,248,228,163,207,62,252,244,227,207,63,0,5,36,208,64,4,21,100,208,65,8,37,164,208,66,12,53,228,208,67,16,69,36,209,68,20,85,100,209,69,24,101,164,209,70,28,117,228,209,71,32,133,36,210,72,36,149,100,210,73,40,165,164,210,74,44,181,228,210,75,53,194,20,147,76,51,209,84,147,77,55,225,148,147,78,59,13,192,83,79,105,115,111,56,56,53,57,54,0,0,32,0,4,16,64,0,0,4,16,64,0,1,4,16,64,0,115,1,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,0,93,1,4,16,64,93,1,216,117,23,94,121,233,181,23,95,125,249,245,23,96,129,9,54,24,97,133,25,118,24,98,137,41,182,24,99,141,57,246,88,0,1,4,16,64,0,144,69,38,217,100,148,85,102,217,101,152,101,166,217,102,156,117,230,217,103,160,133,38,90,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,105,115,111,56,56,53,57,55,0,0,32,0,144,88,34,0,51,210,8,0,0,0,0,160,9,0,0,0,16,128,136,0,0,0,0,0,155,112,210,9,0,158,124,2,10,0,161,0,32,202,40,164,148,98,202,41,168,164,162,202,42,172,180,226,202,43,176,196,34,203,44,180,212,18,128,45,183,224,146,139,46,187,240,210,139,47,191,0,19,140,48,195,16,83,140,49,199,32,147,140,50,203,48,211,140,51,207,64,19,141,52,211,80,83,141,53,215,96,147,141,54,219,112,211,141,55,223,128,19,78,0,105,115,111,56,56,53,57,56,0,0,32,0,4,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,192,136,83,81,85,149,85,87,97,149,149,86,91,113,213,149,87,95,129,21,150,88,99,145,85,150,89,103,161,149,150,90,107,177,213,86,0,1,120,248,97,0,105,115,111,56,56,53,57,57,0,0,80,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,80,6,0,105,115,111,56,56,53,57,49,48,0,0,32,0,84,48,66,12,57,220,16,4,0,70,132,96,6,27,131,0,0,135,20,0,88,64,130,12,58,224,32,4,0,71,136,112,70,27,132,136,24,199,20,17,0,0,0,0,0,0,0,192,14,29,0,112,2,0,37,0,0,0,0,0,56,65,5,0,0,0,0,128,27,0,224,1,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,15,30,0,128,2,0,38,0,0,0,0,0,60,81,5,0,0,0,0,192,27,0,228,1,0,0,0,0,0,192,16,105,115,111,56,56,53,57,49,49,0,116,105,115,54,50,48,0,0,32,0,188,6,91,108,178,205,70,91,109,182,221,134,91,110,186,237,198,91,111,190,253,6,92,112,194,13,71,92,113,198,29,135,92,114,202,45,199,92,115,206,61,7,93,116,210,77,71,93,117,214,93,135,93,118,218,109,199,93,119,222,125,7,94,120,226,141,71,94,121,230,157,135,94,0,1,4,16,64,122,234,173,199,94,123,238,189,7,95,124,242,205,71,95,125,246,221,135,95,126,250,237,199,95,127,254,253,7,96,128,2,14,72,96,129,1,4,16,64,0,105,115,111,56,56,53,57,49,51,0,0,32,0,160,8,0,0,0,164,8,0,0,13,0,192,5,0,0,0,0,192,2,0,0,0,0,0,39,2,0,0,0,16,0,208,5,0,0,0,0,128,3,21,236,16,193,5,0,0,112,194,8,29,0,240,71,9,49,4,145,131,17,102,48,225,4,0,84,0,0,0,0,120,40,1,6,28,0,4,50,8,0,22,240,32,1,6,0,0,128,2,9,30,0,0,136,9,50,8,161,195,17,103,52,241,4,0,85,0,0,0,0,121,44,17,70,28,0,8,66,72,137,105,115,111,56,56,53,57,49,52,0,0,32,0,24,120,32,0,27,112,128,32,0,20,2,96,97,130,26,2,0,128,31,10,46,248,2,12,12,54,8,128,131,21,62,120,33,132,27,98,152,97,132,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,0,0,0,0,0,0,0,128,132,0,0,0,0,0,0,0,192,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,0,0,0,0,0,0,0,192,132,0,0,0,0,0,0,0,208,7,0,105,115,111,56,56,53,57,49,53,0,108,97,116,105,110,57,0,0,36,51,2,96,6,0,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,0,132,0,0,0,0,88,100,225,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,115,111,56,56,53,57,49,54,0,0,32,0,84,96,129,18,51,166,104,6,0,103,0,160,8,0,127,0,0,72,32,0,0,208,193,18,131,160,8,0,0,132,120,176,8,0,88,100,225,135,32,0,0,0,192,4,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,33,48,1,0,0,0,88,1,0,24,118,0,0,0,0,0,156,192,8,0,0,0,0,0,5,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,34,52,1,0,0,0,92,1,64,24,119,0,0,0,0,0,160,208,8,0,99,112,49,50,53,48,0,119,105,110,100,111,119,115,49,50,53,48,0,0,0,51,6,96,98,0,41,182,168,226,138,1,184,104,198,139,96,168,49,200,31,1,144,88,226,137,40,178,8,98,136,1,216,120,6,140,97,172,65,8,32,0,60,2,137,18,0,84,0,0,0,0,0,64,6,0,0,0,0,64,32,0,0,32,201,18,0,0,0,0,0,0,88,80,6,0,72,80,146,132,32,90,0,0,192,4,0,16,113,1,0,29,0,112,2,0,41,0,0,192,7,33,48,1,5,0,0,88,1,0,0,94,208,1,128,29,0,0,128,6,0,91,0,0,0,5,0,20,129,1,0,30,0,128,2,0,42,0,0,0,8,34,52,17,5,0,0,92,1,0,0,95,212,1,192,29,0,0,144,70,36,99,112,49,50,53,49,0,119,105,110,100,111,119,115,49,50,53,49,0,0,0,227,144,99,162,76,41,182,168,226,138,51,186,168,206,139,235,180,195,206,59,49,145,88,226,137,40,178,8,98,136,1,216,136,19,140,57,237,164,83,79,0,184,195,83,58,0,248,4,0,0,226,0,80,14,0,0,0,0,0,58,0,0,112,78,77,63,1,0,0,0,48,213,56,19,0,55,153,67,147,77,240,196,35,207,60,244,212,99,207,61,248,228,163,207,62,252,244,227,207,63,0,5,36,208,64,4,21,100,208,65,8,37,164,208,66,12,53,228,208,67,16,69,36,209,68,20,85,100,209,69,24,101,164,209,70,28,117,228,209,71,32,133,36,210,72,36,149,100,210,73,40,165,164,210,74,44,181,228,210,75,99,112,49,50,53,50,0,119,105,110,100,111,119,115,49,50,53,50,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,104,198,139,88,4,48,72,0,1,144,88,226,137,40,178,8,98,136,147,216,120,6,140,89,4,64,136,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,112,49,50,53,51,0,119,105,110,100,111,119,115,49,50,53,51,0,0,0,51,6,96,98,33,41,182,168,226,138,1,184,24,192,139,1,4,16,64,0,1,144,88,226,137,40,178,8,98,136,1,216,24,0,140,1,4,16,64,0,0,112,210,9,0,0,0,0,0,0,0,0,16,0,0,0,0,0,128,136,0,0,0,0,0,155,0,0,0,0,158,124,2,10,0,161,0,32,202,40,164,148,98,202,41,168,164,162,202,42,172,180,226,202,43,176,196,34,203,44,180,212,18,128,45,183,224,146,139,46,187,240,210,139,47,191,0,19,140,48,195,16,83,140,49,199,32,147,140,50,203,48,211,140,51,207,64,19,141,52,211,80,83,141,53,215,96,147,141,54,219,112,211,141,55,223,128,19,78,0,99,112,49,50,53,52,0,119,105,110,100,111,119,115,49,50,53,52,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,104,198,139,88,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,120,6,140,89,4,16,128,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,80,6,0,99,112,49,50,53,53,0,119,105,110,100,111,119,115,49,50,53,53,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,24,192,139,1,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,24,0,140,1,4,16,64,0,0,0,0,0,0,49,2,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,64,5,37,212,80,68,21,101,212,81,72,37,21,128,82,75,49,213,148,83,79,65,21,149,84,110,189,5,87,92,114,5,16,64,0,1,4,16,64,0,83,81,85,149,85,87,97,149,149,86,91,113,213,149,87,95,129,21,150,88,99,145,85,150,89,103,161,149,150,90,107,177,213,86,0,1,120,248,97,0,99,112,49,50,53,54,0,119,105,110,100,111,119,115,49,50,53,54,0,0,0,51,146,102,98,33,41,182,168,226,138,142,184,56,218,139,88,148,134,154,105,170,145,88,226,137,40,178,8,98,136,169,217,120,26,140,89,112,216,225,106,0,204,5,0,0,0,0,0,0,0,0,0,192,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,23,0,0,0,0,64,93,173,217,117,23,94,121,233,181,23,95,125,249,245,23,96,129,9,54,24,97,133,25,118,24,98,137,41,182,24,0,140,53,230,216,99,144,69,38,217,100,0,80,6,64,101,150,93,134,25,0,0,0,0,0,0,153,105,6,0,0,155,113,214,153,103,0,124,6,26,0,161,1,32,26,0,0,120,248,161,107,99,112,49,50,53,55,0,119,105,110,100,111,119,115,49,50,53,55,0,0,0,51,6,96,98,0,41,182,168,226,138,1,184,24,192,139,1,16,240,136,2,1,144,88,226,137,40,178,8,98,136,1,216,24,0,140,1,24,32,73,0,0,4,0,0,0,0,4,0,0,0,13,0,192,5,0,0,0,0,192,2,0,0,0,0,0,0,0,0,0,0,16,0,208,5,0,0,0,0,128,3,21,236,16,193,5,0,0,112,194,8,29,0,240,71,9,49,4,145,131,17,102,48,225,4,0,84,0,0,0,0,120,40,1,6,28,0,4,50,8,0,22,240,32,1,6,0,0,128,2,9,30,0,0,136,9,50,8,161,195,17,103,52,241,4,0,85,0,0,0,0,121,44,17,70,28,0,8,66,72,36,99,112,49,50,53,56,0,119,105,110,100,111,119,115,49,50,53,56,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,24,192,139,88,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,24,0,140,89,4,16,128,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,4,0,0,0,0,0,0,0,0,0,0,149,0,0,0,0,33,0,128,9,0,0,24,2,0,0,0,0,0,0,0,0,32,114,9,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,150,0,0,0,0,34,0,144,9,0,0,28,2,0,0,0,0,0,0,0,0,36,34,35,0,107,111,105,56,114,0,0,0,62,254,8,100,144,66,14,73,100,145,70,30,137,164,153,103,162,153,166,154,107,178,217,38,143,110,222,136,99,142,58,238,40,64,143,7,32,144,192,3,73,42,185,36,76,76,54,233,228,147,80,70,41,229,148,84,86,105,229,149,88,102,169,165,56,91,114,217,165,151,95,130,25,166,152,99,146,89,102,1,46,65,20,145,73,20,85,68,210,68,37,97,148,145,70,27,113,212,145,71,31,189,4,82,72,34,141,100,145,68,44,173,116,17,74,45,165,116,146,74,14,193,19,143,65,244,212,67,208,60,5,225,147,143,62,251,240,211,143,63,255,60,4,80,64,2,13,100,143,60,12,45,116,15,66,13,37,116,144,66,107,111,105,56,117,0,0,0,62,254,8,100,144,66,14,73,100,145,70,30,137,164,153,103,162,153,166,154,107,178,217,38,143,110,222,136,99,142,58,238,40,64,143,7,32,144,192,3,73,42,185,36,76,51,53,89,147,77,80,70,41,229,148,84,254,100,229,149,88,102,169,165,56,229,112,121,14,58,95,130,25,166,152,99,250,84,102,1,46,65,20,145,73,20,85,68,210,68,37,97,148,145,70,27,113,212,145,71,31,189,4,82,72,34,141,100,145,68,44,173,116,17,74,45,165,116,146,74,14,193,19,143,65,244,212,67,208,60,5,225,147,143,62,251,240,211,143,63,255,60,4,80,64,2,13,100,143,60,12,45,116,15,66,13,37,116,144,66,0,0,0,0,0,0,0,0,192,154,35,0,96,189,34,0,16,0,0,0,5,0,0,0,0,254,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,64,34,0,112,0,0,0,184,29,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1701425);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,54,32,0,112,28,40,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,64,187,39,0,64,86,39,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,99,104,97,110,110,101,108,32,109,97,112,10,0,0,0,0,248,68,34,0,112,0,0,0,72,30,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,34,0,136,135,33,0,32,12,33,0,200,165,32,0,96,74,32,0,64,49,40,0,128,212,39,0,8,109,39,0,112,28,39,0,32,216,38,0,152,146,38,0,32,88,38,0,232,34,38,0,64,242,37,0,192,196,37,0,72,162,37,0,160,122,37,0,40,55,37,0,248,13,37,0,232,228,36,0,104,193,36,0,48,164,36,0,80,137,36,0,200,109,36,0,56,83,36,0,56,58,36,0,216,28,36,0,160,226,35,0,168,196,35,0,0,173,35,0,96,151,35,0,192,129,35,0,8,107,35,0,136,87,35,0,64,70,35,0,8,52,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,28,35,0,248,240,34,0,0,218,34,0,80,203,34,0,224,186,34,0,192,168,34,0,216,150,34,0,248,136,34,0,232,121,34,0,152,104,34,0,40,84,34,0,72,44,34,0,152,24,34,0,200,10,34,0,184,251,33,0,1,0,0,0,4,0,0,0,0,0,0,0,72,233,33,0,2,0,0,0,3,0,0,0,0,0,0,0,24,219,33,0,3,0,0,0,11,0,0,0,0,0,0,0,168,207,33,0,3,0,0,0,7,0,0,0,0,0,0,0,112,197,33,0,3,0,0,0,3,1,0,0,0,0,0,0,192,188,33,0,4,0,0,0,7,1,0,0,0,0,0,0,120,174,33,0,4,0,0,0,51,0,0,0,0,0,0,0,160,140,33,0,4,0,0,0,3,6,0,0,0,0,0,0,152,125,33,0,4,0,0,0,15,0,0,0,0,0,0,0,40,116,33,0,5,0,0,0,55,0,0,0,0,0,0,0,112,106,33,0,5,0,0,0,7,6,0,0,0,0,0,0,128,96,33,0,5,0,0,0,15,1,0,0,0,0,0,0,152,86,33,0,6,0,0,0,63,0,0,0,0,0,0,0,208,77,33,0,6,0,0,0,15,6,0,0,0,0,0,0,216,69,33,0,6,0,0,0,7,7,0,0,0,0,0,0,72,61,33,0,6,0,0,0,195,6,0,0,0,0,0,0,80,48,33,0,6,0,0,0,55,1,0,0,0,0,0,0,136,17,33,0,7,0,0,0,15,7,0,0,0,0,0,0,136,17,33,0,7,0,0,0,63,1,0,0,0,0,0,0,200,3,33,0,7,0,0,0,203,6,0,0,0,0,0,0,216,251,32,0,7,0,0,0,55,6,0,0,0,0,0,0,216,243,32,0,7,0,0,0,199,6,0,0,0,0,0,0,0,236,32,0,8,0,0,0,63,6,0,0,0,0,0,0,208,229,32,0,8,0,0,0,255,0,0,0,0,0,0,0,232,222,32,0,8,0,0,0,207,6,0,0,0,0,0,0,56,216,32,0,8,0,0,0,55,7,0,0,0,0,0,0,0,207,32,0,2,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,2,0,3,0,0,2,0,3,0,0,2,0,4,3,0,2,0,6,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,2,0,3,0,0,2,0,3,0,0,2,0,4,3,0,2,0,6,4,3,0,0,4,0,3,0,7,0,7,1,7,6,15,6,63,6,0,0,4,0,3,0,7,0,7,1,7,6,15,6,63,6,3,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,192,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,192,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,6,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,1,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,48,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,48,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,1,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,3,5,7,0,2,4,6,0,3,4,7,0,11,13,15,0,10,12,14,0,11,12,15,192,14,36,0,0,0,0,0,0,64,59,63,118,62,177,61,237,60,41,60,101,59,161,58,221,57,26,57,87,56,150,55,213,54,21,54,85,53,151,52,217,51,27,51,94,50,162,49,230,48,44,48,114,47,186,46,2,46,77,45,152,44,229,43,51,43,130,42,210,41,36,41,118,40,200,39,26,39,110,38,194,37,25,37,112,36,203,35,39,35,133,34,227,33,69,33,167,32,13,32,115,31,221,30,71,30,178,29,29,29,140,28,251,27,110,27,226,26,89,26,209,25,76,25,199,24,70,24,197,23,72,23,203,22,80,22,213,21,90,21,223,20,103,20,239,19,123,19,8,19,153,18,42,18,190,17,83,17,236,16,133,16,34,16,191,15,96,15,1,15,163,14,69,14,235,13,145,13,59,13,230,12,148,12,66,12,243,11,164,11,89,11,14,11,199,10,128,10,59,10,246,9,177,9,108,9,41,9,230,8,167,8,104,8,44,8,240,7,182,7,125,7,71,7,17,7,222,6,171,6,123,6,75,6,28,6,237,5,193,5,149,5,107,5,66,5,27,5,244,4,206,4,169,4,134,4,99,4,66,4,34,4,2,4,226,3,194,3,162,3,131,3,101,3,73,3,45,3,18,3,248,2,223,2,198,2,175,2,152,2,131,2,110,2,90,2,70,2,50,2,31,2,13,2,251,1,234,1,217,1,201,1,186,1,171,1,156,1,142,1,129,1,117,1,105,1,93,1,81,1,69,1,57,1,45,1,34,1,23,1,13,1,3,1,249,0,240,0,231,0,222,0,214,0,206,0,199,0,192,0,185,0,178,0,171,0,165,0,159,0,153,0,148,0,143,0,138,0,133,0,128,0,123,0,119,0,115,0,111,0,107,0,103,0,99,0,95,0,91,0,87,0,83,0,80,0,77,0,74,0,71,0,68,0,65,0,63,0,61,0,59,0,57,0,55,0,53,0,51,0,49,0,47,0,45,0,43,0,41,0,40,0,39,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,31,0,30,0,29,0,28,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,67,63,134,62,201,61,13,61,81,60,149,59,217,58,30,58,100,57,170,56,241,55,56,55,128,54,200,53,17,53,90,52,163,51,237,50,57,50,133,49,211,48,33,48,112,47,191,46,16,46,97,45,180,44,7,44,92,43,178,42,10,42,98,41,186,40,18,40,107,39,197,38,33,38,126,37,222,36,62,36,160,35,3,35,105,34,207,33,56,33,162,32,15,32,124,31,234,30,89,30,203,29,61,29,179,28,41,28,162,27,27,27,151,26,20,26,148,25,20,25,152,24,28,24,162,23,40,23,174,22,52,22,188,21,68,21,208,20,92,20,236,19,124,19,15,19,163,18,59,18,211,17,110,17,10,17,169,16,73,16,233,15,138,15,46,15,211,14,123,14,35,14,207,13,123,13,41,13,216,12,138,12,61,12,243,11,169,11,97,11,25,11,209,10,137,10,67,10,253,9,186,9,120,9,56,9,249,8,189,8,129,8,71,8,14,8,215,7,161,7,109,7,57,7,6,7,212,6,164,6,116,6,71,6,26,6,239,5,196,5,155,5,114,5,75,5,37,5,1,5,221,4,186,4,151,4,116,4,81,4,47,4,13,4,237,3,205,3,175,3,145,3,117,3,89,3,62,3,36,3,11,3,242,2,219,2,196,2,173,2,151,2,130,2,109,2,89,2,69,2,51,2,33,2,16,2,255,1,239,1,223,1,207,1,192,1,177,1,163,1,149,1,135,1,121,1,108,1,95,1,82,1,70,1,58,1,46,1,35,1,24,1,14,1,4,1,251,0,242,0,234,0,226,0,218,0,210,0,202,0,195,0,188,0,181,0,174,0,168,0,162,0,156,0,150,0,144,0,139,0,134,0,129,0,124,0,119,0,114,0,109,0,104,0,100,0,96,0,92,0,88,0,84,0,80,0,77,0,74,0,71,0,68,0,65,0,62,0,59,0,56,0,54,0,52,0,50,0,48,0,46,0,44,0,42,0,40,0,38,0,36,0,34,0,33,0,32,0,31,0,30,0,29,0,28,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,75,63,150,62,226,61,46,61,122,60,198,59,18,59,94,58,171,57,248,56,70,56,148,55,227,54,50,54,130,53,210,52,35,52,116,51,198,50,24,50,108,49,192,48,22,48,108,47,195,46,27,46,117,45,207,44,43,44,135,43,228,42,65,42,158,41,251,40,90,40,185,39,27,39,125,38,225,37,70,37,173,36,20,36,126,35,232,34,85,34,194,33,50,33,163,32,20,32,134,31,251,30,112,30,232,29,96,29,220,28,88,28,214,27,84,27,214,26,88,26,221,25,98,25,233,24,112,24,247,23,126,23,7,23,144,22,28,22,169,21,57,21,201,20,92,20,240,19,135,19,31,19,185,18,84,18,242,17,144,17,48,17,208,16,115,16,22,16,188,15,99,15,13,15,183,14,100,14,17,14,193,13,113,13,36,13,215,12,140,12,65,12,246,11,171,11,99,11,27,11,213,10,144,10,78,10,12,10,204,9,141,9,80,9,20,9,218,8,160,8,105,8,50,8,252,7,198,7,147,7,96,7,47,7,255,6,209,6,163,6,119,6,75,6,33,6,247,5,207,5,168,5,129,5,90,5,51,5,12,5,231,4,194,4,159,4,124,4,91,4,58,4,27,4,252,3,222,3,192,3,164,3,136,3,110,3,84,3,58,3,33,3,9,3,241,2,219,2,197,2,175,2,154,2,133,2,113,2,93,2,74,2,55,2,38,2,21,2,4,2,243,1,226,1,209,1,193,1,177,1,162,1,147,1,133,1,119,1,106,1,93,1,81,1,69,1,58,1,47,1,37,1,27,1,17,1,7,1,254,0,245,0,236,0,227,0,219,0,211,0,204,0,197,0,190,0,183,0,177,0,171,0,165,0,159,0,153,0,147,0,141,0,135,0,130,0,125,0,120,0,115,0,110,0,105,0,101,0,97,0,93,0,89,0,85,0,81,0,77,0,74,0,71,0,68,0,65,0,62,0,59,0,56,0,53,0,51,0,49,0,47,0,45,0,43,0,41,0,39,0,37,0,35,0,33,0,31,0,29,0,27,0,25,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,82,63,164,62,247,61,74,61,157,60,240,59,68,59,152,58,236,57,64,57,149,56,234,55,65,55,152,54,240,53,72,53,160,52,248,51,81,51,170,50,4,50,95,49,187,48,24,48,117,47,211,46,51,46,147,45,244,44,85,44,184,43,27,43,126,42,225,41,69,41,170,40,17,40,120,39,225,38,74,38,182,37,34,37,143,36,253,35,110,35,223,34,83,34,199,33,60,33,177,32,41,32,161,31,28,31,151,30,20,30,146,29,18,29,147,28,22,28,153,27,31,27,165,26,45,26,181,25,61,25,197,24,79,24,217,23,102,23,244,22,132,22,21,22,169,21,61,21,211,20,106,20,4,20,158,19,60,19,218,18,121,18,24,18,186,17,92,17,1,17,166,16,78,16,247,15,162,15,77,15,251,14,169,14,90,14,11,14,190,13,113,13,36,13,215,12,140,12,66,12,250,11,179,11,110,11,42,11,232,10,166,10,102,10,39,10,234,9,174,9,116,9,58,9,1,9,201,8,147,8,93,8,41,8,245,7,196,7,147,7,99,7,52,7,7,7,218,6,175,6,132,6,90,6,48,6,6,6,220,5,179,5,138,5,100,5,62,5,25,5,245,4,210,4,175,4,142,4,109,4,78,4,47,4,17,4,244,3,215,3,186,3,158,3,131,3,104,3,79,3,54,3,30,3,6,3,239,2,216,2,195,2,174,2,154,2,134,2,115,2,96,2,77,2,58,2,40,2,22,2,5,2,244,1,228,1,212,1,197,1,182,1,168,1,154,1,141,1,128,1,116,1,104,1,92,1,80,1,69,1,58,1,47,1,37,1,27,1,17,1,8,1,255,0,246,0,237,0,229,0,221,0,213,0,205,0,197,0,189,0,181,0,174,0,167,0,160,0,154,0,148,0,142,0,136,0,131,0,126,0,121,0,116,0,111,0,106,0,101,0,97,0,93,0,89,0,85,0,81,0,77,0,73,0,70,0,67,0,64,0,61,0,58,0,55,0,52,0,49,0,46,0,43,0,40,0,37,0,35,0,33,0,31,0,29,0,27,0,25,0,23,0,21,0,19,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,90,63,180,62,14,62,104,61,194,60,29,60,120,59,211,58,47,58,139,57,231,56,67,56,160,55,253,54,91,54,185,53,23,53,117,52,213,51,53,51,150,50,247,49,89,49,188,48,32,48,132,47,233,46,78,46,181,45,28,45,132,44,236,43,84,43,188,42,38,42,144,41,252,40,104,40,214,39,68,39,180,38,36,38,150,37,9,37,126,36,243,35,106,35,225,34,89,34,209,33,76,33,199,32,69,32,195,31,67,31,195,30,69,30,200,29,78,29,212,28,92,28,228,27,110,27,248,26,130,26,12,26,151,25,35,25,178,24,65,24,211,23,101,23,249,22,141,22,36,22,187,21,85,21,239,20,140,20,41,20,199,19,101,19,7,19,169,18,78,18,243,17,154,17,65,17,235,16,149,16,66,16,239,15,159,15,79,15,1,15,179,14,101,14,23,14,202,13,126,13,52,13,235,12,164,12,94,12,25,12,213,11,147,11,81,11,18,11,211,10,150,10,90,10,31,10,228,9,171,9,114,9,59,9,5,9,209,8,157,8,107,8,57,8,9,8,217,7,171,7,126,7,81,7,36,7,247,6,202,6,158,6,114,6,71,6,29,6,244,5,204,5,165,5,127,5,89,5,53,5,17,5,239,4,205,4,173,4,141,4,110,4,79,4,49,4,19,4,247,3,219,3,192,3,165,3,139,3,114,3,90,3,66,3,43,3,20,3,254,2,232,2,210,2,188,2,167,2,146,2,126,2,106,2,87,2,69,2,51,2,33,2,16,2,255,1,239,1,224,1,209,1,195,1,181,1,167,1,154,1,141,1,128,1,116,1,104,1,92,1,81,1,70,1,59,1,49,1,39,1,29,1,19,1,9,1,255,0,245,0,236,0,227,0,219,0,211,0,203,0,195,0,188,0,181,0,174,0,167,0,161,0,155,0,149,0,143,0,137,0,131,0,126,0,121,0,116,0,111,0,106,0,101,0,97,0,93,0,89,0,85,0,81,0,77,0,73,0,69,0,65,0,61,0,58,0,55,0,52,0,49,0,46,0,43,0,40,0,37,0,34,0,32,0,30,0,28,0,26,0,24,0,22,0,20,0,18,0,16,0,14,0,12,0,10,0,8,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,0,0,0,0,0,0,64,232,62,209,61,186,60,164,59,143,58,122,57,103,56,84,55,67,54,52,53,38,52,25,51,15,50,5,49,255,47,249,46,245,45,241,44,242,43,244,42,250,41,1,41,14,40,27,39,44,38,62,37,87,36,112,35,144,34,176,33,214,32,252,31,34,31,72,30,115,29,159,28,211,27,7,27,68,26,129,25,195,24,6,24,82,23,158,22,242,21,70,21,162,20,255,19,93,19,187,18,34,18,138,17,249,16,105,16,225,15,89,15,214,14,85,14,219,13,97,13,238,12,124,12,14,12,160,11,50,11,196,10,90,10,241,9,143,9,46,9,212,8,122,8,37,8,208,7,129,7,51,7,234,6,162,6,96,6,30,6,221,5,156,5,96,5,36,5,237,4,183,4,133,4,84,4,37,4,247,3,205,3,163,3,125,3,87,3,51,3,15,3,235,2,199,2,165,2,132,2,102,2,72,2,45,2,18,2,249,1,224,1,202,1,180,1,160,1,140,1,122,1,104,1,87,1,70,1,54,1,39,1,25,1,11,1,255,0,243,0,232,0,221,0,211,0,201,0,192,0,183,0,174,0,166,0,158,0,150,0,142,0,134,0,126,0,119,0,112,0,106,0,100,0,95,0,90,0,85,0,80,0,76,0,72,0,69,0,66,0,63,0,60,0,57,0,54,0,51,0,48,0,46,0,44,0,42,0,40,0,38,0,36,0,34,0,33,0,32,0,31,0,30,0,29,0,28,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,244,62,233,61,222,60,212,59,202,58,193,57,185,56,177,55,171,54,166,53,164,52,162,51,163,50,164,49,169,48,174,47,180,46,186,45,196,44,207,43,223,42,239,41,4,41,25,40,50,39,75,38,107,37,139,36,176,35,213,34,255,33,41,33,83,32,125,31,173,30,221,29,20,29,76,28,139,27,202,26,15,26,84,25,161,24,239,23,68,23,153,22,246,21,83,21,178,20,17,20,119,19,222,18,76,18,187,17,49,17,167,16,35,16,159,15,34,15,166,14,48,14,187,13,73,13,215,12,101,12,243,11,133,11,24,11,177,10,75,10,235,9,140,9,50,9,216,8,133,8,50,8,228,7,151,7,80,7,9,7,195,6,125,6,60,6,252,5,192,5,132,5,77,5,23,5,227,4,176,4,129,4,82,4,39,4,252,3,211,3,170,3,129,3,88,3,50,3,12,3,234,2,200,2,169,2,138,2,109,2,80,2,54,2,28,2,5,2,238,1,217,1,196,1,175,1,154,1,135,1,117,1,100,1,84,1,69,1,54,1,40,1,26,1,14,1,2,1,247,0,236,0,225,0,214,0,203,0,192,0,182,0,172,0,162,0,153,0,144,0,136,0,128,0,121,0,114,0,108,0,102,0,97,0,92,0,87,0,82,0,77,0,73,0,69,0,65,0,62,0,59,0,56,0,53,0,50,0,47,0,45,0,43,0,41,0,39,0,37,0,35,0,33,0,31,0,29,0,27,0,26,0,25,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,0,63,0,62,1,61,2,60,3,59,5,58,8,57,11,56,16,55,22,54,29,53,38,52,49,51,60,50,74,49,88,48,103,47,118,46,137,45,157,44,181,43,205,42,234,41,7,41,39,40,72,39,110,38,148,37,191,36,235,35,27,35,75,34,123,33,171,32,223,31,19,31,78,30,137,29,203,28,14,28,85,27,156,26,235,25,59,25,145,24,232,23,69,23,163,22,2,22,97,21,199,20,45,20,154,19,7,19,124,18,241,17,106,17,228,16,101,16,231,15,111,15,247,14,130,14,13,14,152,13,35,13,178,12,66,12,216,11,111,11,12,11,169,10,75,10,237,9,149,9,62,9,236,8,154,8,78,8,2,8,183,7,108,7,38,7,225,6,161,6,97,6,38,6,235,5,179,5,123,5,71,5,20,5,228,4,181,4,136,4,91,4,46,4,1,4,214,3,171,3,131,3,92,3,56,3,21,3,244,2,211,2,181,2,151,2,124,2,97,2,72,2,47,2,23,2,255,1,233,1,211,1,191,1,171,1,153,1,135,1,118,1,102,1,87,1,72,1,57,1,44,1,31,1,18,1,5,1,248,0,235,0,223,0,211,0,200,0,189,0,179,0,169,0,160,0,151,0,143,0,135,0,128,0,121,0,115,0,109,0,103,0,97,0,92,0,87,0,82,0,77,0,73,0,69,0,65,0,61,0,58,0,55,0,52,0,49,0,46,0,43,0,40,0,37,0,35,0,33,0,31,0,29,0,27,0,25,0,23,0,21,0,20,0,19,0,18,0,17,0,16,0,15,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,11,63,22,62,33,61,45,60,58,59,71,58,85,57,99,56,115,55,131,54,149,53,167,52,187,51,208,50,231,49,254,48,22,48,47,47,75,46,103,45,135,44,168,43,204,42,241,41,25,41,65,40,110,39,155,38,205,37,255,36,52,36,105,35,158,34,211,33,11,33,68,32,131,31,194,30,8,30,78,29,153,28,228,27,53,27,134,26,221,25,52,25,146,24,240,23,80,23,176,22,23,22,127,21,236,20,89,20,205,19,65,19,186,18,52,18,180,17,52,17,186,16,64,16,201,15,82,15,219,14,100,14,240,13,124,13,15,13,162,12,59,12,213,11,115,11,17,11,181,10,89,10,3,10,173,9,92,9,12,9,188,8,109,8,35,8,217,7,148,7,79,7,15,7,207,6,147,6,87,6,31,6,231,5,179,5,127,5,77,5,27,5,233,4,183,4,135,4,87,4,43,4,255,3,215,3,175,3,137,3,100,3,66,3,32,3,1,3,226,2,197,2,169,2,141,2,113,2,88,2,63,2,40,2,17,2,252,1,231,1,210,1,191,1,172,1,154,1,136,1,120,1,104,1,88,1,72,1,57,1,42,1,27,1,12,1,255,0,242,0,230,0,218,0,207,0,196,0,186,0,176,0,167,0,158,0,150,0,142,0,135,0,128,0,121,0,114,0,108,0,102,0,97,0,92,0,87,0,82,0,78,0,74,0,70,0,66,0,62,0,58,0,54,0,50,0,47,0,44,0,41,0,38,0,35,0,32,0,30,0,28,0,26,0,24,0,22,0,20,0,18,0,16,0,14,0,13,0,12,0,11,0,10,0,9,0,8,0,7,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,21,63,43,62,65,61,87,60,110,59,133,58,157,57,181,56,206,55,231,54,3,54,31,53,61,52,91,51,123,50,155,49,188,48,221,47,2,47,39,46,79,45,119,44,163,43,207,42,254,41,45,41,97,40,149,39,205,38,5,38,64,37,123,36,182,35,241,34,47,34,109,33,177,32,245,31,62,31,136,30,214,29,36,29,120,28,204,27,38,27,129,26,225,25,65,25,162,24,3,24,107,23,211,22,65,22,175,21,35,21,151,20,15,20,136,19,7,19,134,18,10,18,143,17,22,17,157,16,36,16,171,15,53,15,191,14,79,14,224,13,118,13,12,13,167,12,66,12,227,11,132,11,42,11,208,10,124,10,40,10,212,9,129,9,51,9,230,8,157,8,85,8,17,8,205,7,140,7,75,7,15,7,211,6,154,6,98,6,44,6,246,5,192,5,138,5,86,5,34,5,242,4,194,4,150,4,106,4,64,4,23,4,241,3,203,3,168,3,133,3,100,3,68,3,36,3,4,3,231,2,202,2,173,2,146,2,119,2,94,2,70,2,47,2,24,2,3,2,238,1,219,1,200,1,181,1,162,1,143,1,124,1,106,1,88,1,72,1,56,1,41,1,27,1,14,1,1,1,245,0,233,0,222,0,211,0,201,0,191,0,181,0,172,0,163,0,155,0,147,0,139,0,132,0,125,0,119,0,113,0,107,0,101,0,96,0,91,0,86,0,81,0,76,0,71,0,66,0,62,0,58,0,54,0,50,0,46,0,43,0,40,0,37,0,34,0,31,0,28,0,26,0,24,0,22,0,20,0,18,0,16,0,14,0,12,0,10,0,8,0,6,0,5,0,4,0,3,0,2,0,1,0,0,0,0,64,31,63,62,62,93,61,125,60,157,59,190,58,224,57,2,57,37,56,72,55,109,54,146,53,185,52,224,51,9,51,50,50,92,49,134,48,179,47,224,46,15,46,63,45,114,44,165,43,219,42,17,42,75,41,133,40,195,39,1,39,65,38,129,37,193,36,1,36,69,35,138,34,210,33,27,33,105,32,184,31,10,31,93,30,180,29,11,29,103,28,196,27,38,27,136,26,234,25,77,25,182,24,31,24,141,23,251,22,110,22,226,21,90,21,210,20,79,20,204,19,79,19,210,18,88,18,222,17,100,17,234,16,115,16,253,15,139,15,26,15,175,14,68,14,221,13,118,13,20,13,178,12,85,12,249,11,161,11,73,11,242,10,156,10,74,10,249,9,172,9,95,9,22,9,206,8,137,8,69,8,4,8,195,7,134,7,74,7,16,7,214,6,156,6,98,6,42,6,242,5,190,5,138,5,89,5,41,5,251,4,205,4,163,4,121,4,81,4,42,4,3,4,223,3,187,3,151,3,115,3,82,3,49,3,18,3,244,2,216,2,188,2,162,2,136,2,112,2,88,2,66,2,44,2,22,2,0,2,234,1,212,1,191,1,170,1,151,1,132,1,115,1,98,1,82,1,66,1,51,1,37,1,24,1,11,1,255,0,243,0,231,0,219,0,209,0,199,0,189,0,179,0,170,0,161,0,153,0,145,0,138,0,131,0,124,0,117,0,111,0,105,0,99,0,93,0,87,0,81,0,76,0,71,0,66,0,61,0,57,0,53,0,49,0,45,0,42,0,39,0,36,0,33,0,30,0,27,0,24,0,21,0,19,0,17,0,15,0,13,0,11,0,9,0,7,0,5,0,3,0,1,0,0,0,0,64,41,63,82,62,123,61,164,60,206,59,248,58,35,58,78,57,122,56,166,55,211,54,0,54,46,53,93,52,142,51,191,50,241,49,35,49,88,48,141,47,196,46,252,45,54,45,113,44,174,43,235,42,43,42,107,41,174,40,242,39,56,39,126,38,196,37,10,37,83,36,156,35,233,34,55,34,137,33,219,32,49,32,135,31,226,30,61,30,156,29,251,28,95,28,195,27,40,27,141,26,247,25,97,25,209,24,65,24,182,23,43,23,164,22,29,22,155,21,25,21,155,20,30,20,163,19,40,19,173,18,50,18,186,17,67,17,208,16,94,16,241,15,132,15,27,15,178,14,78,14,234,13,139,13,44,13,209,12,119,12,29,12,196,11,112,11,28,11,204,10,124,10,48,10,229,9,156,9,83,9,14,9,202,8,137,8,73,8,11,8,205,7,143,7,81,7,21,7,218,6,162,6,106,6,52,6,255,5,203,5,153,5,104,5,58,5,12,5,225,4,182,4,141,4,101,4,61,4,21,4,240,3,203,3,169,3,135,3,103,3,72,3,42,3,12,3,240,2,212,2,186,2,160,2,135,2,110,2,85,2,60,2,36,2,12,2,246,1,224,1,204,1,184,1,165,1,147,1,130,1,113,1,97,1,81,1,67,1,53,1,39,1,25,1,12,1,255,0,243,0,231,0,220,0,209,0,199,0,189,0,180,0,171,0,163,0,155,0,147,0,139,0,131,0,123,0,116,0,109,0,102,0,95,0,89,0,83,0,77,0,72,0,67,0,62,0,57,0,52,0,48,0,44,0,40,0,36,0,32,0,28,0,25,0,22,0,19,0,16,0,13,0,10,0,8,0,6,0,4,0,2,0,0,0,0,64,49,63,98,62,148,61,198,60,249,59,44,59,96,58,148,57,201,56,254,55,52,55,106,54,161,53,217,52,18,52,75,51,133,50,191,49,251,48,55,48,118,47,181,46,246,45,56,45,124,44,192,43,7,43,78,42,151,41,225,40,45,40,121,39,197,38,17,38,96,37,175,36,2,36,85,35,172,34,3,34,93,33,183,32,21,32,115,31,214,30,57,30,159,29,5,29,109,28,213,27,65,27,174,26,31,26,144,25,6,25,124,24,245,23,110,23,236,22,106,22,236,21,111,21,244,20,121,20,254,19,131,19,11,19,147,18,32,18,173,17,62,17,208,16,102,16,252,15,150,15,48,15,206,14,109,14,16,14,179,13,87,13,251,12,163,12,75,12,248,11,165,11,86,11,7,11,186,10,110,10,34,10,218,9,146,9,78,9,10,9,200,8,134,8,68,8,2,8,195,7,132,7,72,7,12,7,212,6,156,6,102,6,49,6,254,5,204,5,157,5,110,5,66,5,22,5,234,4,191,4,150,4,109,4,71,4,33,4,253,3,218,3,184,3,150,3,119,3,88,3,59,3,30,3,2,3,230,2,202,2,174,2,147,2,120,2,95,2,70,2,47,2,24,2,2,2,236,1,216,1,196,1,177,1,159,1,142,1,125,1,108,1,92,1,77,1,62,1,48,1,34,1,21,1,8,1,252,0,240,0,229,0,218,0,208,0,198,0,188,0,178,0,168,0,158,0,149,0,140,0,132,0,124,0,116,0,108,0,101,0,94,0,87,0,81,0,75,0,69,0,64,0,59,0,54,0,49,0,44,0,39,0,35,0,31,0,27,0,23,0,19,0,15,0,12,0,9,0,6,0,3,0,0,0,0,64,194,62,132,61,71,60,10,59,207,57,149,56,93,55,37,54,240,52,187,51,139,50,91,49,48,48,6,47,225,45,188,44,153,43,118,42,90,41,63,40,43,39,23,38,11,37,255,35,249,34,244,33,248,32,253,31,10,31,24,30,48,29,72,28,96,27,120,26,154,25,189,24,234,23,24,23,79,22,136,21,200,20,8,20,83,19,158,18,243,17,73,17,168,16,8,16,106,15,204,14,56,14,165,13,27,13,146,12,18,12,147,11,26,11,161,10,49,10,194,9,91,9,244,8,148,8,52,8,212,7,116,7,28,7,196,6,115,6,34,6,217,5,144,5,75,5,7,5,199,4,137,4,76,4,20,4,220,3,170,3,120,3,71,3,22,3,234,2,190,2,150,2,111,2,76,2,41,2,8,2,232,1,203,1,175,1,149,1,124,1,101,1,78,1,55,1,32,1,12,1,248,0,230,0,213,0,197,0,182,0,168,0,154,0,142,0,130,0,119,0,108,0,99,0,90,0,81,0,72,0,64,0,56,0,49,0,42,0,36,0,30,0,25,0,20,0,15,0,11,0,7,0,3,0,0,0,0,64,208,62,160,61,113,60,66,59,20,58,231,56,188,55,146,54,106,53,66,52,30,51,250,49,217,48,186,47,160,46,134,45,109,44,84,43,66,42,48,41,36,40,24,39,21,38,18,37,20,36,22,35,33,34,44,33,64,32,84,31,112,30,140,29,168,28,196,27,232,26,13,26,59,25,105,24,162,23,220,22,28,22,92,21,166,20,240,19,67,19,152,18,246,17,84,17,179,16,19,16,125,15,232,14,90,14,206,13,75,13,200,12,75,12,207,11,91,11,232,10,124,10,17,10,172,9,71,9,226,8,125,8,31,8,194,7,105,7,18,7,188,6,109,6,31,6,213,5,139,5,71,5,4,5,198,4,137,4,81,4,26,4,227,3,173,3,123,3,74,3,29,3,241,2,201,2,161,2,124,2,87,2,54,2,21,2,247,1,217,1,190,1,163,1,136,1,109,1,84,1,60,1,38,1,16,1,253,0,234,0,216,0,199,0,184,0,169,0,155,0,142,0,130,0,118,0,106,0,95,0,85,0,75,0,66,0,57,0,49,0,41,0,34,0,27,0,21,0,15,0,10,0,5,0,0,0,0,64,220,62,185,61,150,60,115,59,82,58,49,57,19,56,245,54,217,53,189,52,163,51,138,50,117,49,96,48,80,47,65,46,51,45,37,44,29,43,21,42,18,41,16,40,21,39,26,38,36,37,47,36,65,35,83,34,109,33,135,32,167,31,199,30,231,29,7,29,47,28,88,27,136,26,185,25,243,24,46,24,110,23,175,22,249,21,69,21,152,20,236,19,73,19,166,18,5,18,100,17,205,16,54,16,167,15,25,15,147,14,13,14,141,13,13,13,146,12,27,12,165,11,53,11,198,10,92,10,242,9,136,9,30,9,186,8,86,8,249,7,157,7,72,7,243,6,163,6,84,6,11,6,194,5,127,5,60,5,254,4,193,4,133,4,73,4,19,4,221,3,172,3,123,3,78,3,33,3,247,2,206,2,168,2,131,2,97,2,63,2,31,2,255,1,223,1,191,1,162,1,133,1,107,1,81,1,58,1,35,1,14,1,249,0,230,0,212,0,195,0,179,0,164,0,149,0,135,0,121,0,108,0,96,0,85,0,74,0,64,0,54,0,45,0,36,0,28,0,20,0,13,0,6,0,0,0,0,0,248,57,26,0,250,58,26,0,252,59,26,0,232,45,26,0,106,47,26,0,236,48,26,0,110,50,26,0,240,51,26,0,114,53,26,0,244,54,26,0,118,56,26,0,216,35,26,0,218,37,26,0,220,39,26,0,222,41,26,0,224,43,26,0,132,0,177,0,253,0,29,1,61,1,109,1,141,1,205,1,221,1,40,0,0,0,0,0,4,5,6,5,0,0,0,0,144,125,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,6,0,0,190,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,59,32,0,56,34,40,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,184,193,39,0,56,34,40,0,12,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,152,93,39,0,200,15,39,0,100,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,192,204,38,0,200,15,39,0,100,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,152,136,38,0,56,77,38,0,56,0,0,0,84,65,82,86,112,22,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,24,236,37,0,56,77,38,0,56,0,0,0,84,65,82,86,112,22,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,224,36,0,240,190,37,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,192,157,37,0,240,190,37,0,4,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,104,109,37,0,112,45,37,0,40,0,0,0,1,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,72,6,37,0,152,222,36,0,64,0,0,0,3,0,0,0,79,233,47,55,239,198,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,188,36,0,152,222,36,0,64,0,0,0,3,0,0,0,79,233,47,55,239,198,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,159,36,0,232,131,36,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,56,106,36,0,232,131,36,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,224,255,255,255,239,65,16,0,1,0,0,0,0,0,224,77,36,0,104,54,36,0,80,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,120,16,36,0,248,218,35,0,84,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,192,35,0,248,218,35,0,84,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,136,169,35,0,144,147,35,0,76,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,211,34,0,112,0,0,0,216,61,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,3,3,0,0,8,96,33,0,48,25,156,0,4,0,0,0,1,0,0,0,17,43,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,8,137,32,0,48,25,156,0,8,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,232,33,0,112,0,0,0,112,65,26,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,66,26,0,104,66,26,0,88,66,26,0,72,66,26,0,0,0,0,0,0,0,0,0,0,0,254,255,2,0,248,255,8,0,238,255,18,0,216,255,0,0,252,255,3,0,240,255,20,0,224,255,36,0,224,255,0,0,255,255,1,0,254,255,3,0,252,255,5,0,252,255,4,0,5,0,5,0,6,0,6,0,7,0,7,0,7,0,7,0,8,0,8,0,8,0,8,0,9,0,9,0,9,0,9,0,10,0,10,0,10,0,10,0,10,0,11,0,11,0,11,0,11,0,12,0,13,0,14,0,14,0,16,0,0,0,10,0,24,0,25,0,54,0,55,0,116,0,117,0,118,0,119,0,244,0,245,0,246,0,247,0,245,1,246,1,247,1,248,1,246,3,247,3,248,3,249,3,250,3,250,7,251,7,252,7,253,7,253,15,253,31,253,63,254,63,255,255,0,0,248,3,249,3,250,3,251,3,248,1,249,1,248,0,249,0,120,0,121,0,56,0,57,0,24,0,25,0,4,0,0,0,5,0,26,0,27,0,58,0,59,0,122,0,123,0,250,0,251,0,250,1,251,1,252,3,253,3,254,3,255,3,0,0,252,0,253,0,124,0,60,0,28,0,12,0,4,0,0,0,5,0,13,0,29,0,61,0,125,0,254,0,255,0,0,0,62,0,30,0,2,0,0,0,6,0,14,0,63,0,0,0,2,0,0,0,3,0,0,0,104,67,26,0,88,67,26,0,56,67,26,0,248,66,26,0,120,66,26,0,0,0,0,0,16,15,14,13,12,11,11,11,11,10,10,10,10,9,9,9,9,9,8,8,8,8,7,7,7,7,6,6,5,5,3,1,4,5,5,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,10,11,11,11,11,12,13,14,14,16,0,10,10,10,10,9,9,8,8,7,7,6,6,5,5,3,1,3,5,5,6,6,7,7,8,8,9,9,10,10,10,10,0,8,8,7,6,5,4,3,1,3,4,5,6,7,8,8,0,6,5,2,1,3,4,6,0,2,1,2,0,0,0,0,0,0,68,26,0,248,67,26,0,232,67,26,0,200,67,26,0,136,67,26,0,0,0,0,0,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,128,0,192,0,0,1,64,1,128,1,192,1,0,2,64,2,128,2,192,2,0,3,64,3,128,3,192,3,0,4,64,4,128,4,192,4,0,5,64,5,128,5,192,5,0,6,64,6,128,6,192,6,0,7,64,7,128,7,192,7,0,8,64,8,128,8,192,8,0,9,64,9,128,9,192,9,0,10,4,3,7,6,3,1,3,6,7,7,9,0,0,0,0,0,1,1,2,2,2,1,3,3,3,1,1,0,0,0,0,0,8,6,4,4,4,4,4,4,5,5,5,5,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,5,5,6,7,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,6,9,11,11,11,12,12,12,12,12,12,12,12,12,12,10,3,2,2,3,4,4,5,6,6,7,7,7,8,8,9,10,10,10,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,10,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,11,11,11,12,12,12,12,12,12,12,12,12,12,53,7,7,8,11,12,14,15,19,20,7,8,8,3,52,53,42,43,39,12,8,23,3,4,40,43,19,36,24,2,3,26,27,18,19,20,21,22,23,40,41,42,43,44,45,4,5,10,11,82,83,84,85,36,37,88,89,90,91,74,75,50,51,52,27,18,23,55,54,55,100,101,104,103,204,205,210,211,212,213,214,215,216,217,218,219,152,153,154], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1711665);
/* memory initializer */ allocate([24,155,8,12,13,18,19,20,21,22,23,28,29,30,31,55,2,3,2,3,3,2,3,5,4,4,5,7,4,7,24,23,24,8,103,104,108,55,40,23,24,202,203,204,205,104,105,106,107,210,211,212,213,214,215,108,109,218,219,84,85,86,87,100,101,82,83,36,55,56,39,40,88,89,43,44,90,102,103,15,200,201,91,51,52,53,108,109,74,75,76,77,114,115,116,117,118,119,82,83,84,85,90,91,100,101,8,12,13,18,19,20,21,22,23,28,29,30,31,194,149,139,63,240,55,152,63,243,4,181,63,0,0,0,64,0,1,2,5,3,6,14,10,4,15,7,11,8,12,13,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,10,11,6,12,7,14,2,13,15,8,3,9,4,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7,4,8,17,13,5,18,9,14,10,15,16,11,1,32,33,36,34,37,44,40,35,45,38,41,39,42,43,19,6,24,25,20,26,21,46,28,27,47,22,29,23,30,31,12,3,29,30,17,31,18,37,8,32,38,19,9,20,10,11,2,16,33,34,21,35,22,39,4,36,40,23,5,24,6,7,1,41,42,43,25,44,26,46,12,45,47,27,13,28,14,15,0,0,1,2,5,3,6,14,10,4,15,7,11,8,12,13,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,10,11,6,12,7,14,2,13,15,8,3,9,4,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7,4,8,17,13,5,18,9,14,10,15,16,11,1,32,33,36,34,37,44,40,35,45,38,41,39,42,43,19,6,24,25,20,26,21,46,28,27,47,22,29,23,30,31,12,3,29,30,17,31,18,37,8,32,38,19,9,20,10,11,2,16,33,34,21,35,22,39,4,36,40,23,5,24,6,7,1,41,42,43,25,44,26,46,12,45,47,27,13,28,14,15,0,63,0,15,15,31,63,47,31,0,16,14,32,13,47,11,13,7,14,5,11,10,12,8,5,12,10,61,7,4,48,55,3,1,2,2,8,59,4,3,1,62,61,9,55,6,59,29,62,45,29,51,27,23,23,39,19,27,30,46,28,53,9,30,6,43,60,37,21,60,44,16,26,21,51,28,35,19,18,35,20,42,24,26,53,44,17,32,37,58,39,24,45,20,58,17,43,18,42,48,46,22,36,33,33,25,34,49,40,40,52,36,49,34,50,50,56,52,25,54,22,41,54,56,57,38,41,57,38,58,67,16,62,229,63,55,63,132,64,217,61,16,62,61,60,248,57,237,60,242,35,152,28,132,26,58,30,234,31,218,31,152,34,114,34,174,32,96,33,118,30,255,32,13,32,101,32,190,31,29,33,255,32,255,33,83,35,156,33,249,56,157,71,60,77,192,67,42,64,75,64,51,59,116,59,171,62,92,61,229,32,149,35,215,35,5,35,74,35,97,35,61,34,71,34,146,35,225,33,106,27,21,28,214,29,139,28,20,29,211,28,126,27,44,27,18,27,212,26,96,21,126,19,14,20,57,20,126,20,21,20,86,20,231,19,222,18,27,20,216,15,215,11,54,10,208,11,100,11,153,10,237,12,165,12,41,11,145,13,53,30,200,30,252,31,239,31,55,32,42,33,189,33,153,33,167,32,145,29,114,16,215,11,248,9,145,13,36,15,13,15,88,16,58,16,69,15,128,15,142,12,138,7,33,5,95,8,189,9,81,9,195,10,146,10,238,9,103,11,208,11,56,6,172,3,95,6,187,6,43,6,242,7,36,8,121,7,41,10,77,254,209,252,26,253,9,4,250,253,70,2,79,251,61,3,86,0,129,1,191,252,133,252,207,1,248,255,29,251,170,5,72,0,25,255,96,3,149,2,3,252,231,0,206,254,65,1,36,255,93,255,242,253,14,253,159,249,11,1,57,0,58,255,173,254,223,255,68,250,61,2,28,3,87,255,137,253,48,3,171,0,162,254,38,1,124,6,197,1,7,2,35,1,159,0,128,253,240,250,67,253,182,252,198,255,182,3,124,3,13,6,203,2,15,2,54,253,63,255,72,2,31,0,223,254,100,1,179,254,55,254,100,2,229,254,155,250,27,253,147,255,216,252,231,0,77,0,169,255,168,254,61,5,63,4,114,253,199,253,165,252,212,4,38,2,86,3,202,2,225,253,40,249,61,255,158,255,236,254,147,252,70,252,32,251,213,254,212,0,21,255,40,253,181,3,237,5,127,3,179,255,88,1,148,253,251,2,157,1,246,1,150,254,64,252,29,254,106,5,198,254,205,254,0,255,20,251,83,254,194,1,46,254,148,255,242,3,175,8,199,2,181,2,9,2,138,2,25,5,228,255,134,254,232,2,19,252,240,0,144,255,241,254,12,254,178,3,197,6,15,1,241,255,141,3,253,254,152,6,63,2,246,255,44,254,57,255,77,4,13,252,69,2,203,255,21,253,110,3,145,0,227,254,0,251,114,254,36,0,14,254,159,250,18,0,68,254,203,5,147,251,189,252,70,5,4,5,161,255,247,3,34,255,187,1,116,1,158,254,77,250,43,251,160,1,43,255,210,1,157,2,147,2,104,6,164,3,22,2,241,255,66,0,212,1,251,3,20,253,105,5,74,255,117,252,47,253,250,254,174,254,148,0,165,5,75,0,8,253,57,2,223,4,81,1,160,1,135,255,133,1,239,0,32,6,213,3,113,0,113,1,21,252,5,254,181,253,120,252,200,254,158,255,181,3,31,0,80,4,72,0,115,255,185,5,63,0,239,252,103,4,72,2,67,3,21,1,121,251,208,0,45,1,142,252,117,0,108,254,27,2,142,255,88,3,19,254,223,0,112,252,111,2,180,255,20,1,72,254,149,8,33,9,244,4,158,2,48,1,245,254,243,253,140,0,114,3,117,255,196,249,38,2,33,3,56,254,200,255,71,253,97,3,36,4,157,1,190,1,130,4,81,2,179,255,213,4,225,255,69,2,243,251,129,252,157,2,41,1,141,1,46,2,203,0,227,252,105,252,3,0,180,2,220,254,26,4,14,3,78,1,195,5,120,2,176,255,48,0,219,251,28,254,106,1,171,253,172,252,223,253,182,254,83,254,88,253,109,4,98,251,24,253,60,5,6,1,63,0,40,5,59,3,114,254,192,253,85,1,250,252,29,254,33,251,186,255,98,0,93,255,162,2,245,255,138,252,19,2,155,251,247,254,14,255,212,2,166,3,206,5,120,8,167,14,114,35,102,47,120,54,63,70,229,74,198,82,60,85,194,6,80,10,122,13,6,19,238,23,196,30,28,61,153,69,70,79,142,85,32,6,208,8,16,12,10,19,55,43,81,52,131,71,93,75,117,82,237,84,197,6,208,9,29,13,100,18,65,27,56,40,128,66,36,70,201,74,126,79,208,6,132,9,236,12,27,34,192,40,231,46,254,60,255,64,111,83,153,85,250,6,65,9,44,13,169,17,139,26,163,50,10,69,44,74,119,81,136,84,95,6,129,9,33,13,184,24,213,41,237,46,221,51,80,54,241,75,96,82,209,5,60,9,219,12,106,24,11,36,163,40,19,54,174,59,57,69,203,83,77,7,229,9,147,13,13,17,192,35,177,56,36,62,126,66,131,80,163,83,22,8,209,11,237,16,222,22,125,30,15,36,101,41,175,62,141,78,74,85,118,7,113,10,91,13,165,16,160,43,7,59,193,64,183,68,110,75,41,79,117,4,23,7,64,10,15,18,95,25,116,37,144,54,44,64,151,75,38,83,144,8,99,12,99,18,176,22,152,42,212,48,82,55,48,61,132,82,29,85,6,5,115,7,244,9,125,13,102,37,188,46,106,62,192,67,235,76,223,87,129,7,160,10,252,17,28,26,239,44,192,50,14,56,158,59,101,66,55,81,4,8,199,10,57,15,126,20,238,25,27,40,218,61,174,65,229,70,171,84,6,7,193,9,241,21,185,44,133,51,119,57,154,66,19,71,83,79,190,82,241,3,111,6,73,11,77,22,69,37,66,48,127,59,62,72,230,81,17,86,200,11,210,14,30,21,45,29,200,48,160,54,224,59,206,63,240,77,55,81,155,8,224,11,212,14,66,21,211,46,200,52,83,58,242,63,192,69,115,73,96,11,196,16,52,31,100,37,42,45,188,51,220,56,145,64,36,78,81,82,45,11,23,14,35,23,122,27,18,36,22,47,161,53,136,70,38,79,238,81,253,11,215,16,79,23,199,28,218,44,155,49,229,55,105,63,157,71,228,74,130,9,77,14,2,19,166,22,143,40,202,45,249,50,52,61,174,73,119,77,228,7,45,10,20,15,25,36,219,51,52,57,138,62,203,66,68,75,27,79,85,7,249,10,6,14,99,18,48,43,153,48,6,61,16,67,73,73,195,77,59,8,57,11,89,14,167,22,11,53,95,57,66,62,181,66,202,73,119,77,76,6,236,8,128,11,244,13,27,32,135,54,52,62,87,67,160,72,149,78,116,9,84,12,142,25,231,39,29,47,222,52,201,59,68,64,29,73,168,77,131,6,52,10,206,13,117,20,17,41,176,45,140,50,158,65,138,70,178,75,84,9,201,11,231,18,117,36,149,44,186,49,176,58,120,63,41,68,245,72,83,7,226,10,135,16,176,24,246,33,165,39,9,46,117,66,176,72,248,77,167,2,131,5,46,18,70,31,182,44,193,51,147,61,207,70,137,79,63,84,46,7,36,10,250,13,0,18,18,22,10,44,19,56,14,62,99,80,250,84,23,5,163,7,91,9,250,12,247,46,196,53,11,62,157,70,212,78,240,82,158,5,54,8,103,10,134,13,136,32,122,40,195,53,96,67,20,77,72,87,92,3,112,7,210,23,95,30,87,38,231,46,229,57,69,65,75,77,140,82,137,6,163,10,120,14,237,23,244,29,231,36,115,53,107,56,58,80,227,84,222,4,57,7,86,11,156,17,53,28,166,49,243,57,186,63,135,75,192,88,245,5,212,8,22,15,27,22,174,28,228,45,58,52,106,56,124,70,86,83,172,4,54,7,32,12,151,27,220,42,105,50,222,57,141,66,210,77,108,88,99,8,34,12,123,17,111,25,35,32,37,38,232,42,129,47,27,74,52,83,49,6,101,9,178,11,196,15,217,44,121,51,183,56,71,60,255,77,27,83,242,6,128,10,30,14,72,18,249,36,56,43,185,48,192,63,30,77,64,81,70,7,26,10,164,13,63,26,188,45,212,50,28,56,0,63,154,76,201,79,115,5,108,8,109,10,58,13,111,41,93,47,46,53,65,65,32,74,119,83,164,5,69,8,214,12,89,24,207,36,181,50,150,58,237,61,36,67,97,85,212,7,79,11,199,14,33,19,24,24,129,28,65,49,61,64,97,75,217,83,215,5,47,11,216,24,164,31,135,44,191,55,30,62,47,69,255,79,45,86,180,9,42,12,86,22,185,27,208,32,72,49,249,54,255,57,55,80,148,83,120,9,205,12,176,20,140,24,26,44,103,50,150,62,100,68,133,75,59,79,5,10,194,14,240,20,77,27,78,34,188,40,54,56,126,61,106,69,230,84,167,10,56,13,213,25,38,36,46,41,204,47,59,57,71,61,106,78,110,82,124,7,137,11,130,24,152,31,238,37,173,42,104,48,50,64,42,78,191,82,56,13,14,17,229,20,243,29,172,43,61,49,97,54,220,59,189,77,18,81,3,12,187,16,63,23,195,29,132,37,2,43,96,48,182,54,178,80,249,83,215,6,151,9,27,20,238,38,101,45,120,51,147,57,86,64,52,81,252,84,162,5,140,8,2,13,157,26,225,34,103,47,140,56,202,59,179,76,64,80,246,8,79,11,230,15,99,31,201,47,104,52,170,57,215,67,8,74,232,76,145,7,99,10,250,17,41,26,111,35,63,50,117,55,126,59,175,62,189,73,23,8,103,10,120,16,229,36,135,42,4,48,125,54,61,58,36,75,117,79,204,6,187,9,160,13,202,31,184,37,145,43,150,51,96,57,160,81,147,85,151,8,65,11,67,18,79,33,67,39,144,44,99,56,103,60,38,67,117,80,151,7,172,11,81,16,151,23,54,29,88,33,101,55,191,60,214,68,75,84,33,7,103,12,150,27,90,38,24,50,90,60,154,71,144,77,70,85,140,87,160,9,230,11,214,18,89,23,16,30,38,60,90,65,238,68,108,80,72,83,246,9,65,13,185,20,8,27,251,39,3,55,223,70,251,74,201,80,88,83,187,11,215,14,201,20,37,25,239,30,123,45,194,61,206,65,199,70,36,74,127,13,61,16,182,26,7,32,149,38,26,48,33,62,186,65,237,77,156,81,236,11,185,14,27,19,178,22,65,27,142,39,196,57,118,62,61,77,168,81,87,14,4,17,195,22,85,27,12,33,52,47,74,55,91,58,47,75,199,79,156,10,100,14,126,20,30,26,15,33,17,39,106,48,51,55,22,63,64,77,153,7,78,10,34,16,59,31,2,56,216,60,161,66,30,71,1,79,5,82,0,9,112,11,26,16,216,18,8,22,83,51,209,61,42,66,140,78,62,82,8,7,212,9,22,13,99,20,94,52,76,62,210,68,108,72,51,80,4,83,156,5,176,8,193,10,194,17,185,37,237,43,73,59,189,63,81,68,191,74,15,9,83,11,116,19,24,27,212,32,177,52,194,60,153,63,46,79,175,81,139,8,103,11,2,18,243,22,222,28,12,49,209,54,154,65,6,82,9,85,187,8,107,11,1,20,115,24,163,31,21,53,236,59,212,63,7,70,191,78,229,6,78,10,167,14,98,22,203,30,124,39,65,53,59,60,168,65,142,72,132,13,109,22,124,37,222,45,77,56,208,62,253,70,146,74,109,81,97,84,151,14,74,17,55,24,195,28,34,36,153,56,163,62,130,66,161,77,140,81,193,13,170,18,231,26,232,33,173,49,242,55,78,62,130,70,198,78,153,82,93,8,152,11,209,26,115,31,26,39,103,51,221,57,245,61,120,68,223,72,52,16,240,23,68,35,119,42,142,49,181,54,104,62,56,67,131,76,115,80,51,17,247,20,234,25,179,32,179,39,79,45,115,58,203,63,62,70,80,73,251,15,10,21,196,26,66,34,43,45,234,51,112,61,34,66,112,74,134,78,186,10,41,14,179,20,80,29,22,40,168,44,116,51,130,60,235,65,106,68,200,8,228,13,91,33,94,41,121,49,104,57,131,64,160,69,44,79,255,82,255,4,168,7,80,15,113,30,169,39,161,57,6,65,219,70,199,80,218,83,136,9,147,13,81,26,206,33,158,47,252,56,223,66,5,70,166,74,11,78,87,7,210,9,145,17,148,29,33,39,100,58,13,63,1,66,221,71,176,75,244,10,104,14,66,29,102,39,210,43,167,49,179,63,62,68,109,78,134,82,231,7,122,10,33,15,76,32,15,40,125,45,83,59,206,66,21,74,76,77,7,11,21,14,183,22,147,33,101,39,205,44,184,64,54,68,66,73,164,77,35,11,97,14,160,20,224,29,213,35,98,40,113,58,20,63,151,68,42,72,68,5,85,10,194,22,81,34,124,41,31,50,127,63,143,71,141,82,58,88,93,8,220,11,197,16,194,23,169,29,133,41,6,67,113,70,218,83,68,86,72,6,71,9,56,13,222,26,242,38,219,43,32,66,242,68,217,78,128,82,214,10,32,14,150,19,157,25,108,30,255,34,172,66,126,71,81,76,62,80,142,7,205,18,60,24,44,28,19,35,145,45,117,62,147,69,202,79,199,84,240,8,179,13,173,19,185,26,86,32,166,37,218,58,97,64,149,84,198,86,135,11,187,14,14,19,154,29,56,35,58,40,154,56,138,59,255,78,254,81,184,12,183,18,201,25,97,29,196,33,235,37,86,52,206,62,158,74,25,79,35,7,54,10,158,13,151,23,117,47,255,53,63,63,130,67,175,83,25,86,232,3,168,6,186,11,191,24,23,33,4,41,30,58,83,66,58,78,155,87,110,6,238,8,37,12,77,28,229,44,247,49,184,65,3,69,37,74,254,78,172,6,197,9,243,12,81,26,25,34,196,38,217,62,201,66,198,71,205,77,63,10,182,13,126,17,13,22,134,38,107,43,115,59,147,70,127,76,158,79,214,9,106,13,120,18,244,24,146,31,69,36,106,51,207,71,107,77,72,80,190,6,79,9,250,15,159,24,125,30,45,50,20,57,200,68,69,75,213,78,44,11,151,14,230,18,156,23,86,28,210,32,207,54,253,63,117,70,210,75,151,16,105,23,16,31,64,38,54,48,61,57,119,68,86,73,95,81,195,84,174,13,211,15,48,22,149,26,210,31,169,46,9,65,36,68,166,79,60,84,79,12,29,19,11,23,30,28,154,44,17,51,20,59,9,69,40,80,101,85,120,15,240,18,38,23,91,28,107,34,33,41,45,61,176,64,20,71,215,78,147,17,204,25,100,31,35,36,52,42,83,49,8,62,104,68,52,78,54,82,155,16,165,21,254,25,126,32,172,38,166,45,252,58,197,66,92,80,183,84,185,14,207,20,185,30,144,36,188,41,42,46,92,53,6,60,45,73,170,77,11,12,129,15,104,24,185,31,70,38,242,42,105,48,118,53,224,69,161,74,171,10,62,18,151,27,241,35,82,44,167,53,235,65,109,73,51,81,88,87,163,4,179,8,129,18,46,28,150,37,89,49,44,60,48,70,38,79,237,91,119,7,173,9,75,15,114,39,96,45,155,50,95,63,242,66,70,75,249,80,228,6,215,9,47,15,32,27,190,35,46,49,130,63,88,66,4,70,3,72,120,5,90,14,219,27,14,34,192,41,220,48,92,61,47,69,8,77,76,82,18,9,1,12,191,16,172,31,191,36,132,41,246,61,53,65,2,77,226,83,70,10,11,13,150,18,168,32,34,40,69,44,80,50,222,67,21,75,224,77,185,6,17,10,177,21,27,28,203,33,190,41,221,58,57,66,15,73,217,77,22,20,80,2,147,67,69,7,16,24,91,9,240,62,64,13,58,3,213,7,29,74,47,23,202,7,0,0,74,60,237,0,77,41,150,11,28,59,50,19,49,45,172,4,114,55,94,6,155,31,253,18,57,59,196,55,160,35,13,2,204,51,184,12,0,0,79,16,76,42,210,107,39,64,108,61,126,17,156,28,148,15,0,0,51,40,121,44,180,46,239,41,196,30,141,30,170,12,221,38,15,6,121,9,118,10,26,106,129,7,75,36,39,7,158,19,1,0,236,5,100,1,164,57,57,0,28,21,217,22,0,0,99,12,64,36,33,14,91,26,123,19,22,87,113,11,54,4,180,23,205,23,209,36,171,10,75,15,72,50,75,25,196,255,162,0,42,0,185,255,50,0,171,255,234,254,242,255,196,255,203,255,132,0,28,0,191,255,185,255,194,255,6,0,119,0,195,0,116,255,28,0,37,0,165,253,164,236,222,254,188,2,15,255,11,0,211,254,41,1,15,252,212,1,117,3,192,0,40,0,239,1,78,3,228,255,201,0,1,255,159,3,124,253,120,9,66,11,174,255,28,249,53,4,59,1,178,3,75,3,143,1,176,0,55,2,34,2,121,1,27,1,165,9,233,248,191,255,12,0,166,1,144,254,129,253,19,254,26,234,84,0,122,0,241,0,11,1,248,255,255,254,233,255,36,255,138,255,139,0,210,249,38,255,124,246,235,9,242,254,146,0,250,254,23,254,15,6,92,2,31,255,107,1,234,0,146,255,90,255,34,4,38,9,158,7,43,0,58,9,91,251,236,1,172,0,216,254,159,0,82,254,201,254,121,255,74,255,77,0,68,254,53,248,169,252,32,8,55,254,133,1,104,3,245,9,167,3,128,255,7,2,138,254,54,1,96,0,119,0,249,254,189,7,5,252,140,253,212,0,83,255,12,247,42,4,63,248,86,254,115,0,22,253,147,0,3,0,94,0,195,0,30,249,177,6,175,254,92,7,133,255,32,254,95,0,9,3,49,4,69,8,55,252,16,0,11,0,123,0,118,1,118,254,117,250,61,3,121,6,14,5,46,245,30,1,45,3,222,254,141,255,111,0,56,1,53,0,44,0,128,3,34,0,16,247,141,242,251,247,98,0,37,1,173,1,88,255,74,0,198,255,221,0,129,254,100,0,63,0,133,7,73,251,199,0,94,0,162,255,244,11,33,7,99,2,36,1,115,255,126,1,141,0,105,0,105,255,0,0,168,5,245,254,206,0,164,3,86,253,251,0,73,255,56,4,161,0,238,16,115,254,13,2,165,255,127,0,152,255,153,3,22,247,238,254,210,251,131,1,200,254,100,5,209,10,214,253,221,5,103,252,102,0,73,255,152,255,190,255,136,249,1,8,122,0,33,247,84,0,236,254,52,255,97,1,124,1,98,254,35,249,245,251,194,254,126,255,246,255,163,0,41,254,121,9,48,11,156,248,38,1,49,3,242,2,21,1,227,255,42,255,217,255,200,254,199,255,202,255,218,3,238,8,194,253,34,0,127,253,199,14,214,0,113,254,101,255,38,0,108,255,214,255,167,255,97,0,239,255,112,247,217,2,16,1,144,4,247,241,150,0,96,0,39,254,211,0,196,255,136,0,230,255,142,0,227,254,93,0,154,2,47,254,75,255,224,7,174,254,118,247,208,245,63,254,107,0,238,255,45,0,24,0,245,0,137,255,244,0,186,1,229,5,158,0,242,0,169,0,240,255,35,255,104,0,115,0,16,0,39,255,23,0,231,255,130,0,236,15,150,2,197,254,252,11,221,255,36,0,225,10,33,255,240,253,99,255,43,0,186,0,254,253,16,255,15,0,11,255,8,2,146,255,243,252,127,253,38,1,236,255,64,0,212,255,144,1,147,255,148,18,54,5,91,254,61,255,130,0,122,247,64,0,127,252,113,250,9,12,245,253,122,1,92,255,200,3,81,2,64,255,71,0,114,0,113,255,246,255,169,7,187,243,101,12,217,255,146,255,199,255,144,0,188,255,83,254,30,0,246,255,211,1,159,0,40,0,67,0,4,1,46,3,88,255,188,252,49,4,22,242,250,6,75,251,108,255,151,255,94,0,5,0,143,0,138,0,18,0,152,250,20,0,123,2,130,255,185,255,169,255,192,254,105,254,47,2,105,255,32,5,213,238,13,253,249,254,179,255,121,6,187,2,170,1,213,1,43,254,253,0,176,255,61,1,185,255,12,1,8,14,253,247,48,1,157,0,43,0,80,7,210,14,255,249,202,4,97,255,177,254,84,1,127,254,3,255,61,255,21,0,106,0,225,255,69,255,193,255,45,245,190,1,60,253,202,0,70,255,36,2,64,3,221,6,6,251,210,4,12,253,96,255,76,0,174,255,64,0,121,8,13,0,175,252,244,0,74,246,166,247,76,3,78,255,14,1,41,1,150,0,202,0,215,255,68,255,121,0,8,251,115,1,193,254,32,11,43,254,245,247,10,5,55,254,132,254,178,2,148,0,205,255,172,254,113,0,57,0,21,251,116,254,132,250,80,1,1,254,64,2,89,17,124,0,143,0,29,254,85,0,138,0,196,0,38,0,68,255,153,4,4,253,237,247,52,3,248,254,218,0,212,254,11,254,26,255,31,246,69,5,186,249,57,255,92,0,201,255,212,250,66,253,30,8,11,251,158,1,206,255,29,0,12,0,87,0,175,253,217,0,174,255,94,0,168,246,52,1,11,9,140,8,0,3,177,251,179,255,67,2,170,6,198,252,32,255,215,254,145,0,128,253,58,2,146,0,57,255,163,4,152,252,71,1,202,254,134,255,233,255,243,255,40,3,117,255,183,238,98,253,156,1,252,255,186,255,94,255,224,251,173,2,200,254,67,252,83,1,125,3,4,255,200,15,151,255,76,0,225,3,25,1,177,255,117,255,168,0,214,254,27,3,173,251,139,1,130,1,244,253,28,4,219,246,233,9,218,1,214,2,252,251,155,254,204,255,115,0,247,255,69,5,64,247,17,3,191,10,77,0,154,3,129,1,229,253,108,255,154,1,251,0,186,255,199,0,51,0,192,6,50,255,157,4,158,4,108,5,233,252,121,0,253,255,8,0,109,255,161,255,101,0,118,3,148,246,19,0,97,9,140,255,206,2,176,253,35,255,212,2,223,255,178,2,76,255,100,3,254,242,121,1,176,254,128,0,11,1,229,247,32,11,178,11,212,254,3,0,103,255,41,0,56,254,38,0,225,255,53,1,150,255,164,255,242,255,96,0,160,2,122,2,207,0,20,6,182,1,157,247,26,1,139,9,130,249,255,1,201,1,253,254,7,254,173,0,52,255,166,252,139,255,191,10,84,3,220,0,0,254,240,245,6,6,101,1,179,255,252,255,165,0,193,255,189,0,46,1,69,253,4,253,233,249,25,0,23,255,149,1,173,0,186,2,183,255,212,254,94,250,149,244,210,250,231,255,98,0,60,255,157,244,111,251,192,242,179,2,97,1,60,255,96,0,41,0,180,0,198,0,24,1,207,0,98,255,237,255,20,6,223,3,245,253,232,254,193,249,88,5,81,243,28,252,159,0,120,255,43,254,208,255,0,0,30,0,95,0,3,253,33,0,180,25,76,255,60,1,80,255,105,0,235,255,247,255,166,0,148,0,204,255,207,255,42,0,2,0,62,1,201,255,165,255,75,250,62,250,242,243,12,253,199,5,227,255,100,253,1,255,205,255,241,0,249,0,44,255,132,0,127,255,102,254,113,0,17,0,45,1,185,0,96,0,10,0,188,0,38,0,252,252,32,20,243,255,246,255,247,5,38,3,233,255,177,255,78,4,179,255,73,1,157,255,108,254,228,8,151,252,135,245,3,253,71,0,20,0,112,246,221,252,35,7,91,4,96,255,241,255,32,1,210,255,61,2,100,0,42,253,74,253,106,254,32,1,61,0,88,247,120,252,77,0,89,244,62,252,98,250,41,3,218,255,177,255,95,0,52,0,25,255,6,2,115,0,41,0,140,3,12,3,37,3,49,255,143,247,42,2,200,3,39,12,133,0,98,255,243,255,222,255,74,255,196,255,105,0,206,2,35,251,227,0,206,252,160,4,135,3,91,2,36,252,169,245,55,7,141,0,49,3,175,254,131,0,137,1,117,6,71,3,251,254,210,1,209,1,215,254,160,5,81,254,10,8,191,248,120,250,54,1,46,253,202,255,203,0,246,254,186,14,172,0,175,253,183,255,4,254,195,255,86,4,237,4,19,1,145,6,191,1,109,255,161,255,33,0,1,5,209,243,24,0,204,254,110,1,44,254,232,0,102,1,155,2,82,252,184,2,100,252,245,247,194,255,151,0,202,247,76,1,2,1,70,255,132,253,173,2,214,0,154,243,37,251,61,2,236,254,9,0,250,254,236,255,158,0,82,255,235,255,81,2,202,231,246,254,242,254,193,255,53,255,63,0,116,254,156,255,191,0,212,0,85,0,120,0,233,252,37,0,209,255,60,8,140,2,7,2,90,1,106,0,208,248,250,245,205,253,14,0,10,1,10,0,214,0,248,1,11,251,50,0,164,0,120,0,151,255,222,253,44,255,177,255,41,0,85,255,163,2,4,255,21,17,240,255,95,249,45,250,252,241,181,253,111,2,67,0,13,1,228,1,231,255,43,4,68,2,170,253,195,0,47,0,239,255,136,245,195,9,184,254,164,8,8,5,199,255,41,253,76,0,46,255,38,255,41,0,169,254,230,255,218,255,43,0,94,2,149,253,237,253,222,247,87,0,153,251,2,5,233,255,224,8,232,248,104,0,225,255,85,0,234,255,60,0,13,5,138,0,126,1,176,1,233,1,140,254,143,249,7,245,4,246,158,255,24,255,23,255,169,0,186,0,79,0,133,4,65,8,82,252,124,2,109,3,167,253,229,8,131,5,141,4,5,4,155,253,164,254,218,255,237,255,45,0,38,5,68,248,12,0,202,10,239,5,184,0,188,7,207,255,242,254,105,1,84,255,167,253,60,255,186,0,189,255,132,255,223,5,13,252,7,1,223,0,128,254,153,0,235,255,217,251,17,255,147,4,83,242,0,2,94,255,76,255,139,0,88,253,97,2,129,248,153,11,239,246,73,255,194,0,210,253,26,0,91,0,84,1,231,255,225,255,127,0,150,2,182,0,191,0,103,247,213,245,204,8,245,253,21,1,50,0,99,1,39,1,191,255,99,1,207,0,82,0,23,254,113,255,38,255,89,0,154,2,153,254,156,10,250,246,136,248,161,1,144,1,43,0,110,0,163,255,114,255,61,0,72,244,198,1,103,255,0,0,99,254,213,1,83,1,62,1,59,255,75,0,176,255,78,11,127,255,82,0,151,5,159,4,173,1,236,249,197,250,219,249,164,255,113,252,26,255,244,255,252,255,111,255,124,254,93,254,251,255,15,255,208,27,165,0,131,255,134,255,126,0,106,255,109,0,110,255,195,255,207,255,47,0,70,0,213,255,40,0,75,7,193,5,2,251,205,4,48,247,166,255,10,0,24,253,172,4,147,255,146,1,2,1,178,2,182,255,26,0,14,5,201,251,142,0,176,246,188,254,96,249,75,245,65,1,66,0,83,0,129,255,125,255,156,0,166,0,135,0,20,7,139,242,10,0,23,2,221,253,225,1,61,247,31,1,177,254,218,0,195,0,255,255,231,255,162,255,195,0,153,5,108,250,92,250,8,2,219,0,35,13,124,254,217,252,58,254,227,255,60,1,125,0,159,0,112,255,100,255,195,254,240,2,0,1,216,0,84,1,232,1,147,0,226,233,55,0,146,255,131,1,154,255,45,255,190,255,230,255,104,14,84,255,194,246,12,255,251,255,97,1,11,0,247,1,88,0,227,0,69,0,16,255,69,255,198,255,123,254,9,249,109,250,20,0,150,253,32,2,199,250,116,2,148,243,196,2,230,253,89,254,115,0,49,0,95,255,184,0,86,253,33,255,177,2,19,5,133,252,207,251,52,251,207,254,47,0,83,247,233,249,86,2,132,254,166,0,143,0,146,254,31,1,74,8,253,1,117,2,235,0,243,5,84,11,128,253,87,254,50,254,25,255,203,255,229,255,249,254,42,8,156,248,133,251,214,255,98,3,3,247,205,1,198,251,143,253,171,255,148,0,229,0,231,255,85,0,53,0,3,1,175,255,24,240,17,10,244,255,249,255,79,1,105,255,77,253,119,255,98,0,116,1,219,255,64,255,239,255,246,12,210,253,16,8,140,1,2,1,213,251,229,0,98,4,42,1,231,255,40,0,27,0,122,255,90,255,9,255,38,248,72,254,42,4,136,250,130,242,223,254,172,1,117,2,98,255,126,0,129,0,183,0,244,255,85,255,136,255,165,1,67,254,66,0,124,252,96,14,47,6,193,7,25,0,229,0,233,253,255,255,45,0,207,0,202,255,226,255,45,6,86,252,65,253,149,1,110,3,114,254,211,251,212,6,229,245,117,250,137,254,71,254,25,254,109,0,21,0,137,250,136,2,241,254,67,253,123,2,115,0,118,255,54,254,168,253,157,248,73,2,164,1,132,248,111,4,7,0,48,6,142,3,171,16,48,5,23,1,139,1,221,255,157,255,88,255,247,1,216,0,130,255,211,0,212,0,193,0,99,247,235,1,184,2,41,0,27,1,137,2,159,242,25,252,200,0,113,2,251,254,134,254,209,255,241,255,226,255,18,251,164,6,113,247,196,0,19,249,5,255,84,0,242,1,251,254,150,0,195,1,41,0,80,1,27,0,200,255,50,2,170,255,255,255,207,251,181,5,100,8,111,244,186,254,255,254,184,1,214,255,208,255,192,254,122,0,94,0,13,251,194,252,250,10,162,255,55,255,222,3,111,9,28,253,90,255,245,254,99,255,68,0,45,1,34,1,65,0,163,3,177,7,86,255,6,0,149,0,240,254,151,255,30,2,245,255,208,240,105,0,49,1,77,1,242,255,217,255,152,7,116,251,88,0,245,14,90,251,233,253,124,253,182,254,253,1,163,255,198,254,28,255,218,254,170,254,230,255,119,4,189,246,112,254,74,0,101,0,188,255,185,253,189,251,39,13,122,4,130,253,76,254,136,0,41,0,164,255,238,5,2,11,90,247,4,248,124,2,254,255,79,0,4,254,164,2,73,254,154,254,58,255,187,255,15,1,59,0,102,6,212,1,97,0,8,1,248,255,224,235,104,255,152,0,252,0,145,1,137,254,239,255,124,255,51,0,63,0,121,2,76,255,111,1,111,0,238,255,15,0,204,255,128,0,202,255,11,0,96,0,134,255,230,255,167,227,214,255,59,251,80,253,197,0,149,255,39,255,141,0,223,254,141,0,13,1,183,1,21,253,97,241,50,8,226,0,137,0,26,0,147,249,57,249,176,255,43,0,40,255,245,0,32,2,157,0,40,0,238,0,237,0,35,252,123,1,88,0,127,2,201,250,6,6,123,4,2,254,240,3,122,255,142,253,184,2,38,244,78,1,79,253,115,0,88,255,39,0,214,6,119,253,23,255,157,255,25,255,3,2,112,0,245,255,94,255,123,255,118,255,26,254,215,239,204,0,154,255,99,3,250,251,219,0,2,255,29,245,128,255,193,3,235,244,30,254,61,255,179,2,86,255,78,255,164,0,202,255,40,248,140,255,74,0,142,1,160,255,40,254,151,1,27,0,31,1,116,2,97,0,111,250,173,240,6,0,117,0,199,251,162,3,140,1,196,1,87,0,71,254,101,255,30,253,65,4,80,8,195,243,235,255,146,253,208,255,129,255,250,1,217,3,56,255,33,13,184,0,246,253,41,0,247,1,209,0,14,0,160,255,23,3,239,4,33,1,155,255,64,249,207,251,251,253,60,16,83,253,214,0,47,253,160,253,154,255,217,254,142,255,126,0,172,254,109,0,88,0,204,249,82,0,219,253,136,254,76,0,84,0,46,255,59,0,126,255,65,1,166,2,96,18,52,2,255,255,100,0,69,1,216,254,0,1,88,252,138,252,192,251,65,255,220,1,156,241,79,5,12,0,115,254,186,255,239,255,58,0,57,2,97,1,53,3,179,255,253,0,153,0,65,22,85,255,181,0,3,0,166,255,99,254,247,254,142,0,62,0,191,3,151,0,153,255,77,3,172,254,232,254,35,253,176,253,12,255,230,9,17,12,167,3,119,254,151,255,145,0,102,253,207,244,4,250,205,2,51,11,206,0,224,252,131,255,222,255,67,255,118,255,42,0,189,0,115,255,107,0,42,244,45,241,18,254,108,0,107,255,126,1,248,2,114,255,81,1,180,252,228,0,124,0,232,0,233,255,255,255,250,8,238,2,124,2,159,254,157,0,164,2,65,255,44,3,106,13,247,2,31,2,239,255,43,255,161,255,60,1,75,253,164,253,221,251,32,0,16,254,250,242,240,254,152,255,17,254,126,255,115,2,136,254,74,0,169,253,55,0,119,247,56,252,5,2,169,254,21,0,7,255,61,252,12,1,11,13,239,0,3,3,122,255,42,0,231,0,75,0,97,6,75,1,131,255,98,254,201,1,196,254,111,0,37,254,107,1,81,253,247,239,213,1,187,1,113,0,72,0,218,5,150,1,147,3,27,255,52,2,135,254,89,0,137,0,39,0,2,0,227,255,96,254,107,255,14,14,3,255,12,0,9,252,200,11,148,3,42,253,18,247,157,255,195,251,18,255,178,2,212,255,205,255,141,255,25,0,56,0,119,252,22,244,159,251,232,255,144,247,112,250,241,3,76,255,88,254,188,0,95,254,190,255,170,255,74,0,228,255,31,255,87,252,166,255,251,0,198,248,147,7,51,7,65,3,169,248,64,255,194,254,103,0,149,254,234,255,199,255,239,244,138,255,235,254,158,255,171,255,17,254,150,252,211,11,115,255,46,250,84,255,246,254,224,255,190,0,244,255,148,254,132,254,197,247,249,0,39,255,150,2,184,253,89,0,205,253,129,4,237,243,112,253,207,1,144,0,230,255,214,30,181,254,127,1,212,253,63,0,141,254,233,255,73,0,46,0,111,255,105,0,43,0,57,255,204,255,171,255,171,255,13,0,235,255,26,255,211,28,12,1,13,255,52,254,251,0,73,0,12,0,115,0,238,255,9,255,177,1,166,255,250,253,194,3,0,0,64,252,184,0,207,254,45,248,20,1,160,6,114,9,14,1,164,247,41,255,234,253,123,254,109,254,84,242,160,1,55,2,119,254,73,255,253,0,156,255,227,254,149,255,100,0,25,1,241,253,128,244,170,255,92,10,55,1,239,252,213,252,229,254,169,1,179,255,137,1,136,0,170,0,10,5,3,253,108,0,164,2,43,255,54,251,42,254,171,1,171,13,104,2,69,251,30,255,219,255,88,0,24,245,95,1,78,0,97,244,99,0,192,0,110,5,174,254,47,0,248,255,58,0,1,255,50,0,221,0,207,255,236,252,49,255,182,247,89,255,76,253,123,1,89,243,59,252,70,253,49,254,211,255,34,0,249,6,2,4,173,251,113,0,124,0,254,254,235,254,54,253,204,10,78,255,56,255,139,3,211,255,43,255,241,245,238,253,144,255,32,14,128,255,76,0,146,254,121,255,234,255,205,255,125,0,156,255,177,255,142,0,54,0,107,0,87,0,237,1,222,255,35,255,64,254,13,255,226,3,77,3,208,237,151,255,25,254,41,0,144,255,93,1,24,239,184,255,1,2,144,255,83,253,42,254,118,255,227,253,84,1,31,250,232,255,37,0,169,0,107,254,78,254,78,244,214,255,96,254,121,248,15,6,48,250,164,1,179,0,190,255,14,0,92,0,147,0,141,0,241,1,148,1,100,254,253,8,80,1,195,244,203,248,76,252,240,252,6,1,45,255,6,0,114,249,78,254,103,250,41,253,230,4,30,2,106,250,210,254,22,6,107,0,105,2,191,252,143,254,78,255,146,6,247,245,48,251,236,249,169,255,78,255,144,1,78,255,85,254,132,255,193,255,142,0,35,255,33,0,64,11,29,255,156,254,46,254,222,242,114,254,89,255,164,0,126,0,59,0,255,255,5,0,212,0,25,0,14,8,50,254,223,255,210,255,45,0,55,255,55,3,244,254,210,254,39,14,133,1,126,1,136,0,226,255,192,255,2,0,168,253,42,12,160,10,17,1,180,253,21,255,199,254,115,255,37,0,228,255,99,1,184,0,79,254,146,255,192,253,200,255,134,0,145,253,241,254,31,246,63,245,179,3,39,5,254,255,108,2,36,0,100,254,62,248,221,0,108,254,2,2,151,12,150,255,217,5,144,254,89,255,114,255,146,254,131,255,16,0,142,0,77,254,96,255,29,11,103,255,214,1,131,1,45,12,181,255,137,254,146,2,3,1,243,2,253,255,160,14,251,253,90,250,101,253,92,5,100,249,117,0,160,255,195,0,55,255,122,255,180,255,179,0,97,0,71,0,95,7,161,0,109,1,228,0,153,4,235,0,190,252,208,255,131,6,157,251,169,8,47,255,100,0,37,255,38,245,81,0,189,253,93,13,186,254,20,254,23,255,78,0,32,0,117,0,182,255,176,255,85,0,230,254,197,1,244,1,209,2,32,3,83,0,144,253,232,3,165,0,236,255,252,253,159,239,178,254,107,0,197,4,29,250,246,255,11,2,85,0,212,255,21,0,34,0,199,0,150,255,71,247,13,2,90,8,40,0,201,255,193,255,13,224,70,1,77,1,104,255,229,255,137,0,212,0,130,0,246,255,76,0,195,255,143,255,224,253,77,255,69,255,0,0,68,235,66,1,186,254,1,2,159,1,119,1,164,255,158,254,69,0,77,0,65,0,93,0,160,254,91,255,211,248,254,6,146,3,236,254,167,8,118,250,87,1,25,1,4,0,27,1,46,17,159,6,8,255,153,0,90,255,239,2,54,3,106,254,56,254,5,255,185,0,5,255,34,255,87,255,246,254,77,231,249,0,216,255,211,255,53,255,47,0,173,255,147,253,82,255,71,1,30,0,114,0,227,255,7,254,32,255,12,7,46,6,12,247,54,8,22,253,91,254,170,0,182,1,85,255,153,0,84,0,99,255,135,244,133,255,175,255,29,255,158,255,7,1,203,13,36,0,105,0,33,254,162,255,155,254,234,255,132,255,23,1,140,255,31,2,201,0,119,254,30,255,49,247,123,255,77,6,133,255,127,10,70,0,191,0,240,0,28,252,92,253,94,2,35,251,206,254,157,1,240,254,229,253,229,1,255,13,32,255,176,1,133,1,31,0,136,252,62,1,107,255,28,255,252,2,86,254,72,6,160,245,254,0,111,247,252,0,228,1,166,255,139,255,255,254,94,247,100,255,41,2,47,2,168,2,42,1,240,255,249,253,148,4,124,8,8,5,143,255,186,0,57,255,121,250,173,255,64,248,155,2,11,252,88,1,113,254,73,11,105,251,116,252,186,0,185,0,234,255,184,254,60,12,114,251,209,0,43,255,130,1,92,8,40,2,255,3,207,2,17,2,87,255,165,1,196,0,76,0,203,7,20,2,181,255,12,8,242,253,140,1,158,11,248,254,164,254,149,0,74,2,22,0,97,0,175,254,4,255,101,1,103,0,252,246,238,245,212,248,235,254,90,1,198,254,35,252,185,0,198,254,102,0,56,0,195,14,247,254,251,251,244,255,130,255,81,254,100,1,67,246,170,255,172,0,116,0,61,0,110,255,84,247,211,0,91,255,233,0,185,254,73,0,249,255,152,255,222,253,253,0,154,246,105,1,204,8,230,1,163,2,79,255,83,10,91,2,44,1,99,4,126,253,105,1,172,2,153,247,57,2,10,252,120,0,206,255,65,1,102,12,8,12,35,253,85,254,43,1,169,0,133,255,116,255,243,255,197,254,21,0,136,255,232,255,174,0,65,255,162,254,94,225,111,255,87,255,93,254,241,255,150,0,126,255,183,255,162,0,247,255,38,0,225,254,109,0,134,1,147,0,151,0,115,7,109,239,7,0,49,255,109,255,26,255,169,254,139,255,145,255,107,0,132,0,177,5,168,255,248,255,67,254,80,255,84,255,249,248,211,252,230,1,126,4,46,244,88,255,196,245,184,253,178,0,225,253,180,248,153,254,143,255,9,249,214,0,105,253,217,1,98,3,120,255,169,0,4,243,127,255,180,242,7,255,234,0,166,1,251,0,84,1,169,254,231,0,134,0,214,255,32,0,64,0,47,255,12,0,236,0,245,254,93,254,1,0,4,1,147,255,108,25,105,0,7,0,239,254,133,255,149,255,104,255,238,254,99,255,75,0,74,0,55,255,46,0,37,0,82,1,235,255,76,255,208,0,239,230,26,3,250,0,175,255,183,253,4,0,137,255,198,254,17,2,219,0,159,0,124,255,235,254,76,0,155,253,69,19,15,0,213,0,157,9,30,1,30,2,177,0,207,10,133,1,136,0,238,2,47,2,30,252,172,2,244,255,223,247,222,253,167,255,107,241,36,2,148,253,163,2,118,0,135,255,190,0,204,255,19,0,237,255,25,0,56,251,88,1,22,12,237,247,7,0,17,1,12,251,137,254,215,254,55,255,15,1,65,255,123,0,6,0,252,254,236,8,204,254,10,244,242,0,156,2,35,255,122,4,194,4,217,1,123,255,82,0,57,0,112,0,115,249,78,0,27,255,98,1,49,254,251,2,92,6,195,8,106,5,94,6,111,255,255,0,196,255,228,0,195,0,160,252,235,9,46,254,217,3,253,243,2,0,118,0,221,0,117,254,62,254,0,255,98,255,224,255,11,241,220,7,206,255,47,254,146,0,189,251,194,254,15,1,244,255,84,2,160,0,120,0,92,0,47,255,177,254,104,0,228,255,177,2,49,1,220,253,175,252,81,6,93,2,185,0,98,254,59,15,239,254,51,0,182,0,64,255,121,0,104,2,195,4,158,1,65,252,133,239,39,5,60,0,246,0,44,254,224,255,225,0,82,1,217,255,211,4,225,247,202,8,114,2,121,0,40,1,119,255,173,254,178,248,209,255,115,254,124,0,6,236,166,0,239,252,123,2,240,253,154,255,13,1,236,1,71,255,154,253,122,0,132,255,85,0,145,0,14,1,102,255,39,0,220,9,58,0,199,255,119,0,5,0,87,1,57,11,234,254,237,252,137,0,62,0,87,255,1,8,196,5,187,254,130,0,66,253,66,11,237,255,54,1,254,254,121,255,88,0,244,254,69,0,69,0,183,2,113,248,47,3,166,2,44,0,13,12,22,1,181,253,210,250,104,1,145,0,239,255,66,0,85,246,174,253,132,0,102,1,150,1,143,254,19,255,35,13,73,1,88,254,52,0,49,0,35,1,20,255,228,246,251,254,49,0,229,255,170,0,72,14,42,255,165,253,8,1,60,0,169,255,145,0,116,0,179,0,190,0,167,2,83,1,172,254,200,12,129,2,185,245,228,1,159,0,49,1,34,1,208,0,226,0,68,0,102,0,111,255,156,254,153,0,135,2,2,248,169,3,126,249,69,4,227,255,119,251,237,2,200,246,171,0,119,247,73,3,130,250,223,251,28,249,212,254,51,255,196,1,120,8,42,255,103,255,35,1,150,255,79,0,181,6,236,255,21,249,30,1,46,254,174,2,167,0,137,0,5,0,43,0,51,4,215,245,5,1,170,255,179,254,44,253,162,0,186,0,4,0,178,254,100,254,203,254,120,3,142,255,19,2,41,1,188,16,41,1,97,249,44,255,75,0,249,254,247,246,102,0,78,254,96,1,235,248,40,254,114,0,71,255,6,0,66,0,125,31,158,1,191,253,160,2,104,255,152,0,1,0,38,0,190,255,48,0,221,255,62,0,158], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1721905);
/* memory initializer */ allocate([255,237,255,78,241,98,0,242,0,114,0,103,1,94,255,115,0,34,244,84,1,253,0,242,253,112,255,14,0,109,255,28,0,160,254,30,233,46,0,171,253,120,254,226,0,202,255,186,255,209,255,211,255,16,0,53,0,137,0,172,0,55,244,234,255,93,255,245,254,39,243,225,255,82,255,110,0,26,3,169,1,67,0,58,0,184,255,100,255,97,15,183,253,68,8,99,0,165,251,255,254,33,3,14,1,183,254,255,254,238,255,122,0,143,254,108,247,210,6,207,254,87,2,32,3,237,2,186,5,213,254,17,250,1,255,23,255,217,0,139,255,0,255,45,1,7,255,185,254,154,21,86,0,135,0,240,252,119,255,98,2,249,255,55,0,93,0,150,255,206,255,11,1,27,255,230,255,210,251,13,0,181,255,197,6,113,11,126,255,55,253,15,0,160,247,104,0,194,254,26,1,248,255,227,254,44,254,132,255,59,0,8,2,178,255,180,254,114,253,72,236,212,0,124,254,97,0,13,250,227,0,15,246,111,8,129,255,252,3,79,0,104,253,147,1,225,255,156,254,255,255,76,254,170,255,75,0,98,2,232,11,235,0,195,243,91,251,212,255,233,255,188,254,4,1,213,1,143,255,22,0,53,0,13,2,171,1,213,1,248,3,164,1,237,1,51,251,18,255,145,245,105,1,71,245,193,0,3,255,197,255,15,0,53,0,199,255,36,0,112,255,127,0,25,0,11,0,222,255,160,25,244,255,176,255,184,255,70,0,142,2,145,251,158,0,23,1,42,1,234,2,66,255,154,250,138,0,15,2,32,250,63,245,150,255,201,255,225,0,54,0,136,0,53,0,250,1,174,0,12,1,235,253,213,255,96,254,60,255,122,24,175,255,22,0,98,255,94,1,153,4,40,253,82,2,34,0,144,254,30,255,184,253,247,0,36,3,139,251,78,0,83,15,203,255,53,1,58,0,211,255,46,226,183,255,39,0,104,255,55,0,179,255,211,255,194,255,231,255,9,255,95,255,28,0,187,245,111,254,217,254,81,253,42,1,88,243,0,0,5,255,7,0,207,255,238,1,58,255,202,0,153,8,211,254,83,0,45,0,60,252,0,1,37,250,166,246,24,0,245,254,169,253,46,0,161,0,142,254,81,0,124,2,74,12,227,247,60,252,66,1,144,1,133,253,80,253,138,253,164,255,21,255,104,0,179,255,227,253,255,1,162,10,185,1,197,10,184,3,227,2,255,254,2,255,74,254,134,255,105,255,12,0,66,2,164,255,72,254,193,255,93,0,107,19,13,254,163,1,94,5,91,255,95,254,64,0,243,255,21,255,56,4,179,255,24,2,68,0,182,252,252,252,91,6,41,254,186,250,112,255,33,11,219,0,114,0,68,0,201,255,94,1,245,255,202,250,30,244,142,4,109,255,133,252,29,254,181,5,83,1,40,3,106,1,155,255,9,245,232,255,135,254,6,2,74,254,194,0,146,255,194,0,198,252,52,13,175,255,226,255,213,255,103,0,157,255,3,6,154,253,243,255,126,251,196,0,206,243,247,253,174,5,193,254,159,0,84,254,210,2,48,255,162,0,79,7,230,9,239,8,178,3,5,1,29,254,123,253,26,0,86,255,225,255,17,0,164,0,104,0,212,255,0,224,236,255,94,0,21,255,56,0,68,0,198,255,124,1,231,255,86,255,17,0,16,0,102,255,63,0,221,1,0,5,102,2,239,253,213,246,152,254,159,0,175,7,219,247,229,1,79,1,122,1,178,0,97,6,75,254,210,255,23,0,128,2,185,5,165,255,255,4,255,251,17,252,20,255,72,10,255,254,6,1,177,0,213,11,179,243,23,252,231,0,250,254,87,0,13,255,188,255,171,253,109,0,62,0,248,254,37,0,49,254,223,243,135,253,113,3,2,4,170,255,161,1,193,2,136,251,188,255,220,247,46,0,124,0,220,255,99,246,183,255,130,255,209,254,55,4,154,254,52,245,7,253,82,250,11,255,203,0,0,0,77,255,139,255,11,10,113,237,236,255,194,0,42,1,2,1,134,1,14,1,220,255,182,0,152,0,200,255,159,255,209,255,138,0,23,255,145,255,46,250,22,254,183,254,150,2,192,254,167,237,187,1,66,0,96,1,203,0,142,255,137,255,186,0,137,2,150,255,251,255,232,8,108,4,136,254,144,4,151,3,66,7,15,1,51,249,126,255,196,242,8,1,106,2,185,246,4,1,255,4,110,0,220,2,128,0,139,254,54,0,74,255,99,0,125,255,9,0,30,0,173,255,27,0,204,0,109,0,206,254,247,26,130,0,249,255,141,255,92,0,15,255,119,0,128,253,153,252,216,255,116,1,188,255,109,255,33,250,198,255,152,3,46,254,55,1,144,0,192,241,135,255,155,254,5,0,176,7,31,253,45,250,84,2,50,3,122,0,176,2,119,255,145,246,144,254,236,0,71,0,171,253,63,255,117,254,27,3,87,3,145,2,207,255,76,3,8,243,127,248,78,3,17,0,219,254,239,255,116,249,222,248,118,255,129,3,49,255,253,255,46,7,123,252,86,0,19,1,196,3,230,0,254,1,246,255,63,11,109,15,76,1,33,1,109,0,27,255,18,0,238,0,244,0,31,1,44,0,103,0,111,1,21,0,146,251,134,254,58,5,196,252,172,13,5,0,3,4,219,1,208,0,142,2,77,2,164,255,236,0,171,255,141,255,71,4,56,246,59,3,139,252,218,252,101,255,64,8,166,254,96,4,162,254,113,252,22,255,231,0,55,0,87,0,165,7,89,2,243,2,32,251,241,2,90,245,31,254,246,7,96,0,149,254,53,1,150,0,43,1,207,253,70,253,250,251,118,0,200,4,168,12,13,250,196,5,86,1,80,253,180,255,192,0,248,255,193,254,94,1,149,0,181,254,155,0,76,254,30,1,30,252,160,0,120,245,89,254,18,245,121,255,148,255,226,244,2,255,6,14,94,1,130,0,214,252,207,1,133,255,59,0,0,255,251,0,18,253,180,255,248,255,159,249,150,0,93,252,166,7,243,5,33,246,239,0,225,254,172,0,76,1,243,255,230,1,247,0,230,255,149,0,59,0,130,0,9,1,19,0,209,0,52,28,233,255,157,255,187,255,190,255,186,255,202,255,181,255,60,0,248,254,154,255,55,4,233,253,51,6,211,253,37,250,241,0,220,245,133,4,116,255,14,1,33,0,194,244,54,253,26,12,180,255,205,255,232,0,118,0,244,252,77,253,245,254,203,254,105,0,77,255,251,255,172,255,245,255,136,255,133,254,202,1,167,243,65,0,178,11,64,0,118,1,72,254,62,0,73,255,28,0,207,253,73,0,59,0,251,245,189,1,61,254,254,251,181,1,10,0,83,255,219,4,26,247,31,254,117,254,102,255,158,246,177,3,27,245,117,0,96,251,75,0,64,253,15,2,222,1,179,253,17,0,131,0,146,255,62,2,225,251,140,253,235,254,238,10,203,5,111,253,52,248,8,255,194,0,228,254,54,3,225,0,86,255,246,255,210,254,85,254,92,249,166,255,196,10,76,8,207,255,60,252,116,1,131,253,187,1,13,0,187,255,185,255,196,0,77,248,110,0,123,4,186,2,53,5,89,5,15,2,165,0,135,3,65,2,170,247,56,0,223,255,34,0,183,0,247,0,170,254,206,3,55,4,174,9,230,255,80,0,183,246,174,1,114,250,172,1,117,247,43,254,0,251,186,254,216,255,188,0,143,3,149,1,212,10,23,1,19,254,9,1,0,3,45,0,146,22,44,0,121,0,255,254,121,255,124,0,7,1,15,0,197,0,142,255,5,0,242,255,248,255,174,255,149,15,1,254,197,0,142,9,220,254,51,255,105,252,162,0,135,255,145,0,216,255,71,0,151,255,72,0,243,7,192,3,111,255,45,254,250,253,167,0,84,244,165,1,92,3,64,1,40,0,66,254,63,1,160,0,140,0,255,1,201,255,213,0,108,255,241,253,102,253,175,2,9,0,23,0,88,1,100,255,218,237,131,255,36,255,9,0,134,0,231,255,16,0,217,250,251,2,58,0,206,249,74,254,45,1,101,254,175,254,186,242,102,1,188,255,145,255,107,21,220,255,56,254,162,255,140,255,204,0,95,0,84,0,183,255,93,255,69,0,66,255,64,0,124,241,186,254,23,7,181,252,56,1,14,254,172,2,127,253,2,253,152,255,94,2,70,0,70,10,51,0,86,255,0,242,167,0,205,1,94,255,132,0,240,1,91,0,171,0,255,0,48,0,2,0,136,255,84,251,22,2,81,254,109,10,109,254,8,0,31,1,121,254,253,9,81,3,167,0,237,254,72,255,93,2,14,242,113,0,22,0,230,245,156,2,38,1,114,252,67,0,115,255,0,0,162,1,15,1,75,0,90,0,132,255,190,1,114,255,133,253,119,2,68,252,30,6,25,0,66,248,22,3,210,10,33,0,248,253,23,0,192,226,67,0,183,255,60,0,64,0,210,255,220,255,76,0,3,0,22,0,149,0,61,0,34,0,255,0,132,254,228,254,29,246,113,250,227,5,98,252,206,251,95,252,106,250,115,255,165,0,176,255,244,254,21,0,1,253,6,6,125,12,65,255,222,7,208,254,83,2,24,2,118,252,130,255,158,254,180,255,94,255,131,255,189,243,125,12,166,3,110,1,101,252,182,254,21,1,228,254,93,255,244,255,146,1,15,0,110,255,20,0,83,0,111,0,196,0,23,0,71,0,77,0,119,28,81,255,243,255,29,255,197,255,200,255,228,255,1,0,163,0,206,255,59,0,123,2,150,0,95,0,190,10,7,3,247,247,167,1,202,251,213,6,253,255,113,253,147,254,155,254,145,0,180,255,5,0,163,255,224,0,150,0,108,0,222,255,173,0,148,0,141,254,34,0,48,0,155,224,65,0,50,0,103,0,214,255,246,255,160,255,166,255,253,255,60,0,92,0,177,255,180,255,130,1,114,0,101,248,65,3,1,251,28,254,217,0,84,12,226,0,229,1,167,4,169,1,88,0,197,255,13,255,244,8,145,6,159,2,62,0,131,3,107,246,156,255,15,4,201,2,152,255,42,2,219,0,100,1,195,3,229,2,154,255,199,1,19,8,188,254,172,0,28,0,4,3,240,2,209,246,98,250,159,252,124,249,105,0,10,4,171,4,14,0,162,254,87,254,120,253,38,8,236,253,122,2,1,6,223,255,170,253,72,11,171,255,184,0,158,0,92,255,11,13,237,0,228,254,202,255,10,255,46,0,2,255,109,1,55,0,136,7,166,254,155,254,75,1,139,0,16,0,162,2,128,254,189,255,185,242,165,0,76,0,215,0,137,0,141,243,110,255,248,254,91,255,33,244,235,0,227,253,138,253,224,255,223,255,45,255,160,0,135,255,145,255,240,250,209,255,128,255,36,1,13,250,4,6,3,3,90,255,3,254,212,0,198,10,185,254,94,254,207,254,247,255,209,1,209,9,195,0,186,255,47,255,190,255,127,0,109,255,167,243,64,255,227,253,213,253,131,0,166,252,183,249,205,3,100,255,171,248,60,0,243,3,66,0,164,254,144,3,61,249,240,250,49,1,143,254,208,253,214,1,46,0,161,252,132,255,219,255,40,0,117,254,234,236,236,255,221,0,228,0,177,0,182,0,98,0,105,255,61,255,86,3,62,255,138,254,45,1,74,2,58,0,116,252,237,255,154,239,85,255,74,1,48,0,16,243,92,255,121,7,159,4,214,255,7,5,159,254,245,2,108,2,221,253,251,0,248,253,59,0,43,0,77,255,65,255,125,255,121,244,80,252,81,246,88,1,211,252,104,0,71,253,212,255,242,254,198,0,245,0,50,11,208,0,178,0,8,255,38,0,19,0,65,2,252,10,3,253,169,252,73,254,196,255,226,255,160,254,241,5,211,251,201,1,159,1,60,2,19,253,112,255,100,0,3,2,230,252,238,249,203,9,242,254,10,0,62,0,203,9,242,249,181,255,70,0,226,9,50,2,132,0,115,255,251,0,156,0,67,3,102,0,205,2,154,12,255,12,172,0,84,0,51,255,245,255,208,0,202,254,164,0,229,255,11,0,25,1,37,0,250,253,20,0,180,255,82,0,60,21,225,253,211,254,112,0,103,1,116,255,162,255,78,0,238,255,38,0,60,255,164,255,13,0,145,255,233,255,30,0,241,255,162,255,101,0,142,0,201,230,65,1,66,1,50,0,40,255,191,254,246,255,47,254,101,0,45,0,183,253,55,252,224,4,56,254,37,246,172,252,175,247,135,252,33,0,112,250,182,5,71,2,237,2,15,2,55,249,238,4,174,253,158,1,41,255,96,251,156,1,222,6,212,248,224,4,184,1,78,255,16,3,7,14,29,255,43,0,19,254,2,253,242,254,150,0,151,0,200,255,146,255,240,244,183,255,90,255,214,1,77,255,87,253,71,0,142,255,73,245,218,252,208,253,63,0,12,255,166,255,182,0,113,255,227,3,148,1,243,255,193,250,244,5,88,246,182,6,67,252,205,4,202,1,117,254,255,244,189,253,157,255,84,1,2,6,172,2,20,254,132,4,211,255,191,255,207,254,128,250,187,254,242,254,154,254,129,255,92,0,159,255,159,1,85,0,115,237,173,0,216,254,53,255,75,1,59,1,184,0,210,255,35,5,110,255,201,255,171,1,37,0,255,0,47,255,16,1,223,2,250,1,105,0,103,0,134,3,135,242,116,0,0,9,104,2,228,249,228,5,222,1,64,1,142,246,244,0,80,255,224,255,238,0,92,0,34,1,88,255,178,255,120,242,14,1,146,248,2,0,184,2,92,0,182,249,50,255,207,255,178,0,121,0,27,0,119,0,72,0,3,255,114,254,96,245,175,255,94,255,218,253,35,10,165,5,249,0,152,255,218,0,202,254,161,255,18,0,39,254,116,7,176,1,29,255,88,255,91,245,16,255,218,248,199,0,181,1,144,250,48,1,181,5,166,246,165,253,228,253,1,3,84,1,152,255,33,6,235,255,82,1,150,252,253,5,25,1,197,255,231,1,72,8,179,0,116,255,184,254,199,255,63,0,146,255,206,250,27,254,133,246,135,4,99,1,230,255,249,247,154,0,205,253,124,255,49,0,183,254,69,255,232,255,185,255,126,240,20,1,158,0,92,0,54,255,7,0,90,254,190,253,186,0,105,254,96,19,173,253,3,4,161,1,179,2,69,0,133,0,123,0,109,255,246,240,247,250,63,254,220,255,102,251,105,251,193,2,159,255,37,0,118,253,170,1,35,254,111,255,124,0,6,0,207,0,160,255,183,243,101,11,252,254,93,1,156,2,184,255,6,0,157,0,194,255,128,255,20,0,174,255,179,250,61,253,149,253,199,254,27,255,194,11,87,255,229,255,226,2,203,3,86,250,246,0,154,0,93,255,241,255,163,255,5,0,221,255,214,255,24,0,31,0,231,255,147,26,33,0,224,255,188,255,188,255,212,255,61,1,43,0,150,255,96,2,25,252,69,253,70,2,46,0,95,6,62,3,222,249,171,245,224,3,78,8,132,0,73,9,15,6,247,0,9,255,228,5,222,255,162,0,237,254,175,255,114,253,143,253,125,0,223,255,46,255,53,1,132,3,59,2,214,2,131,10,5,11,70,253,60,0,46,0,29,254,14,0,46,255,217,254,102,0,214,0,226,0,62,10,174,255,122,254,156,5,107,0,42,2,125,1,27,5,235,8,66,255,27,0,221,255,181,21,27,1,103,0,180,0,104,0,167,255,70,255,193,254,31,255,115,255,92,0,1,0,106,248,1,4,138,3,32,0,253,255,191,251,182,0,225,252,227,1,144,254,58,249,153,255,144,6,218,1,123,255,213,251,223,253,37,255,138,255,133,253,1,246,234,3,250,9,128,253,7,254,179,0,168,254,175,255,107,0,195,255,79,0,244,255,227,255,219,255,106,226,164,255,64,0,92,0,92,255,236,255,195,255,221,255,200,254,97,255,77,1,183,242,220,245,168,254,88,0,92,2,23,2,169,255,109,1,243,255,179,255,131,0,127,0,76,2,46,1,162,255,6,254,123,9,99,0,48,1,93,10,176,251,100,5,208,3,238,253,136,255,151,255,37,1,9,0,198,252,132,1,190,255,165,1,54,255,93,2,163,2,220,15,210,3,143,0,162,255,21,0,116,246,226,255,42,2,183,2,62,11,145,2,152,255,77,254,186,254,51,1,20,0,20,0,159,0,106,0,111,242,70,1,251,251,208,254,158,2,195,247,81,254,61,2,192,2,37,1,211,255,87,255,137,255,65,255,87,2,114,252,184,7,91,255,69,2,185,4,103,249,61,9,142,254,167,253,72,253,118,1,202,0,142,255,195,255,3,0,193,255,30,0,113,1,98,255,128,255,198,0,52,0,158,255,212,255,189,254,2,236,180,251,99,253,208,8,32,0,190,255,206,0,65,0,241,10,15,3,42,254,51,252,215,1,45,255,229,255,87,7,46,1,124,254,7,255,45,1,25,2,201,10,65,1,59,2,20,0,81,1,56,5,10,2,231,0,112,1,149,254,239,247,199,255,251,245,184,253,157,253,56,0,46,3,130,254,135,6,152,1,236,1,12,0,177,4,233,5,247,0,117,8,176,253,34,251,19,254,12,252,206,250,227,4,75,0,156,255,182,0,52,0,209,255,198,2,143,251,116,9,209,253,10,1,223,252,219,9,205,4,224,2,103,254,207,255,13,1,82,255,77,255,232,255,92,1,107,253,251,0,241,251,87,10,27,1,216,2,198,248,216,247,196,0,39,0,184,255,221,255,162,255,228,253,10,1,84,1,62,254,251,2,251,255,113,0,58,10,79,245,23,4,10,255,246,253,74,255,120,1,44,4,203,0,214,4,86,252,211,0,204,254,117,254,139,253,84,2,182,245,172,5,125,251,83,0,167,255,207,243,163,1,40,0,131,10,206,254,169,254,4,0,165,254,43,253,139,255,197,254,115,0,41,255,26,0,173,1,50,4,217,248,198,248,49,10,72,0,211,1,191,0,176,1,89,3,70,255,0,0,69,254,232,255,244,1,29,2,30,0,20,9,120,251,127,251,247,6,2,5,56,248,101,0,148,255,148,255,44,2,36,248,250,1,179,2,191,255,158,253,146,1,98,2,149,7,135,255,174,3,77,2,87,7,58,0,56,1,86,247,248,247,20,247,162,254,59,254,50,1,38,0,189,253,71,255,155,255,60,255,106,255,156,0,126,0,212,255,113,255,13,225,126,0,136,255,118,255,23,255,97,0,236,255,135,255,81,255,248,255,243,255,133,255,147,254,251,0,218,2,67,11,155,2,94,254,48,255,122,8,94,250,196,0,123,254,252,253,252,0,158,255,13,2,229,248,121,253,39,6,0,3,100,4,84,254,14,252,21,248,155,1,39,254,95,3,210,0,140,3,40,0,145,0,37,0,192,0,189,0,52,0,39,255,88,255,63,0,249,255,203,255,135,255,13,0,111,255,0,0,219,255,61,0,213,224,114,255,32,0,118,0,190,0,249,255,243,255,113,0,36,0,31,0,181,5,216,247,87,9,85,252,190,255,54,3,24,1,246,0,99,255,73,255,79,254,156,254,88,0,155,255,129,15,196,242,172,255,84,0,130,0,35,0,74,0,37,0,181,0,61,255,219,0,227,255,233,255,224,255,69,0,113,2,24,9,64,255,199,245,31,1,31,2,188,249,55,3,221,253,235,254,252,2,20,1,156,0,198,0,17,0,84,0,90,1,229,255,127,255,143,0,217,0,212,0,7,255,20,0,49,25,7,0,51,0,135,252,168,255,9,1,26,1,92,248,47,5,255,251,58,5,83,249,16,252,116,1,57,0,124,5,234,0,61,10,238,255,151,2,45,1,0,0,167,0,140,254,26,246,153,7,65,255,198,0,103,1,213,255,92,0,24,0,134,234,193,255,189,0,36,0,143,254,96,1,125,1,51,255,112,255,137,255,245,254,196,255,246,255,131,1,84,9,101,255,62,254,209,1,249,5,40,255,113,10,110,255,118,0,50,0,34,1,147,0,11,0,160,244,95,3,136,8,79,253,212,255,59,0,105,253,151,2,163,2,39,1,51,5,141,255,246,255,202,255,255,255,31,0,163,6,127,0,215,0,150,11,163,0,160,1,227,251,192,4,100,1,148,5,90,255,84,255,254,255,157,254,87,255,181,254,162,255,178,255,133,255,11,19,55,1,67,0,121,4,141,1,224,254,212,0,168,254,222,254,126,0,16,0,176,0,229,1,39,2,242,253,11,0,120,0,238,254,83,0,233,234,102,255,181,249,119,3,65,1,66,254,142,4,179,254,140,2,54,1,129,252,62,0,37,255,24,11,15,253,222,255,125,243,240,241,208,1,7,255,80,1,41,1,171,255,60,1,144,0,50,1,7,255,149,0,112,0,73,0,192,0,167,255,18,0,197,0,116,0,51,0,37,0,212,0,176,227,163,0,31,0,204,255,225,255,155,255,170,250,159,254,187,254,201,250,72,254,169,4,158,2,181,245,104,3,120,5,221,2,139,1,122,0,130,0,206,239,0,0,130,254,206,5,52,1,155,4,100,254,32,1,189,2,161,0,147,0,191,3,60,0,77,0,133,255,17,0,193,0,204,0,30,255,132,1,16,1,180,253,99,255,7,11,223,2,23,253,64,9,103,1,192,251,44,248,243,250,226,7,227,1,64,1,10,252,218,252,33,254,188,255,205,255,168,0,105,3,27,0,30,225,57,0,19,0,233,255,27,0,43,0,243,255,206,255,93,0,16,0,29,0,31,0,230,255,32,0,234,255,197,1,106,11,0,246,138,0,155,3,35,251,107,254,10,0,228,0,242,254,145,0,64,255,83,0,48,0,101,0,77,0,30,255,36,0,112,30,126,0,237,254,219,255,220,255,9,0,45,0,167,255,13,0,148,0,125,0,24,0,70,254,111,0,244,255,28,2,2,7,192,11,84,6,71,255,142,250,95,255,231,255,199,254,195,254,79,2,203,9,134,0,143,254,77,0,15,2,149,253,20,255,121,10,87,0,220,251,222,255,102,7,157,251,117,1,140,253,142,7,1,251,103,249,159,253,40,254,170,253,149,1,229,0,158,1,12,0,149,244,223,255,77,254,207,255,76,9,222,255,168,254,133,247,228,254,18,1,226,0,225,254,172,255,199,255,255,255,87,255,206,255,223,1,195,2,42,245,236,253,128,253,12,255,44,0,202,1,215,9,178,253,40,254,219,26,152,255,190,255,161,0,57,0,24,0,252,255,76,0,134,255,156,255,31,0,188,0,137,255,206,255,12,255,49,0,1,0,156,255,43,2,253,0,177,1,121,2,93,255,31,235,86,255,39,255,207,255,227,255,75,1,121,2,169,255,210,255,227,255,44,0,82,255,182,255,140,8,178,1,148,2,175,253,12,6,123,1,163,5,140,6,193,255,179,247,246,0,22,2,49,254,104,3,87,255,244,255,33,0,211,0,103,254,152,1,234,5,67,255,235,254,135,1,151,254,221,255,145,0,150,254,195,237,212,0,159,255,191,255,131,1,175,255,70,0,36,0,192,1,47,1,76,1,203,251,254,254,183,250,161,4,206,255,244,255,182,255,203,247,125,9,25,7,85,252,137,1,169,0,234,255,220,255,195,4,165,12,48,3,196,1,15,7,122,253,151,1,65,254,14,249,142,254,240,253,129,255,104,0,160,1,135,255,122,255,194,255,20,0,215,6,128,253,34,255,182,3,67,6,43,2,9,0,219,0,8,251,164,10,236,3,213,4,117,254,100,1,59,254,158,255,232,255,80,0,171,249,218,1,101,248,19,255,221,251,213,247,12,3,187,4,171,3,12,1,100,254,131,7,93,254,83,3,230,0,55,2,143,0,48,0,226,5,180,8,54,251,59,254,246,0,213,1,28,2,230,253,160,255,209,3,252,1,105,0,178,243,114,255,219,255,139,1,9,0,218,255,1,0,121,255,121,254,166,6,77,255,226,249,147,243,113,249,203,0,105,255,131,1,250,0,51,2,203,0,187,1,88,255,82,0,61,0,68,6,170,248,229,0,174,255,208,0,149,11,69,4,251,0,56,6,80,254,236,253,153,0,151,1,157,0,191,0,40,255,52,0,198,255,167,3,143,247,103,254,255,253,209,3,143,255,175,12,73,251,25,253,102,251,136,0,206,0,184,0,139,252,192,255,16,0,233,255,232,255,219,2,233,6,83,252,7,6,174,246,99,253,66,252,233,0,105,0,156,251,180,3,97,0,99,248,59,0,104,255,191,255,114,0,82,0,131,1,140,248,20,254,129,0,144,253,93,0,146,2,15,253,8,4,176,9,16,249,104,1,218,255,132,7,168,0,244,255,246,255,128,255,80,249,66,254,171,3,209,1,93,2,182,253,213,254,119,254,38,15,111,0,133,254,146,0,186,0,206,255,233,254,226,255,253,255,35,0,107,248,104,1,177,255,145,255,65,239,250,255,159,2,42,255,232,252,21,1,77,0,58,0,8,0,16,0,133,0,161,0,21,0,33,0,255,5,216,254,148,245,130,243,228,255,126,254,132,4,144,0,55,255,0,1,101,254,42,1,67,0,158,2,11,0,29,255,252,255,152,255,12,0,24,252,168,4,92,3,45,3,104,1,25,0,93,0,24,3,162,254,81,0,206,15,78,255,122,0,76,1,28,0,144,255,248,255,32,1,27,2,239,255,193,255,8,0,231,0,55,0,254,253,105,0,168,254,252,0,103,255,59,0,246,255,235,255,51,0,137,26,45,0,3,1,128,1,209,0,38,248,55,1,255,252,91,248,231,10,49,254,219,254,38,255,2,4,129,3,226,252,47,0,243,253,31,0,214,255,226,7,49,245,122,6,173,2,101,248,46,0,68,250,84,1,240,254,62,1,21,0,91,254,116,254,244,0,205,255,34,1,45,0,3,0,6,250,79,5,159,241,207,5,103,249,209,0,182,1,239,252,36,255,2,0,201,255,29,254,221,255,40,0,6,0,189,0,56,255,2,0,22,248,45,249,70,3,144,252,104,4,220,243,184,0,97,253,251,254,8,0,40,1,126,255,178,255,244,254,156,255,18,0,151,255,247,255,192,1,112,12,198,253,144,2,136,254,55,252,146,6,75,10,235,254,65,2,217,0,25,1,219,0,161,254,31,0,64,0,101,0,82,0,189,3,163,248,6,3,48,242,88,255,81,254,150,255,33,254,17,4,153,255,6,3,114,255,126,3,44,253,162,255,2,253,198,255,112,0,236,7,54,2,166,254,117,255,145,245,141,248,15,4,189,0,223,255,154,6,7,1,254,253,31,255,19,255,145,0,193,254,38,0,116,0,75,11,179,255,239,247,255,9,185,254,5,253,86,0,84,255,229,254,109,255,137,0,245,0,179,254,220,0,92,0,194,0,80,255,105,0,36,12,73,1,140,254,92,251,158,2,5,3,21,255,34,0,110,255,108,3,253,254,212,249,108,3,105,0,70,2,3,1,193,255,157,255,234,249,98,4,251,249,74,254,227,0,197,4,239,250,22,253,138,10,227,255,145,4,227,3,254,255,201,0,136,1,107,254,234,255,220,255,245,2,57,240,213,2,168,7,198,5,149,255,67,0,145,254,159,255,168,255,154,0,176,255,0,0,247,254,93,255,14,0,147,255,33,0,85,2,115,0,31,2,212,1,11,253,58,3,253,1,80,255,207,254,161,236,138,255,48,254,91,254,184,255,1,0,69,255,123,0,168,255,194,251,26,0,112,1,98,2,66,13,175,254,108,1,34,10,235,1,247,2,203,254,139,1,152,0,82,1,249,0,47,1,134,255,63,0,251,3,160,252,10,6,196,0,75,0,135,253,163,255,137,253,9,3,182,255,211,4,23,253,121,1,41,12,82,255,230,254,232,255,89,0,104,252,76,8,108,2,54,2,10,5,161,11,156,4,22,1,188,0,238,2,213,3,155,254,80,0,69,0,77,0,105,255,150,0,241,255,66,3,131,252,50,3,119,6,12,254,237,0,133,0,243,0,149,1,239,0,16,0,104,255,186,255,148,241,146,255,145,0,58,0,199,255,33,246,0,12,178,8,218,0,200,252,128,1,160,255,119,0,28,255,62,255,136,0,111,0,5,255,147,255,77,255,222,255,143,0,109,0,133,4,40,255,107,250,66,253,67,1,81,251,196,255,120,2,183,253,172,254,16,4,215,1,224,255,132,254,104,13,199,1,118,255,217,255,144,246,140,2,3,255,145,0,25,1,137,1,97,253,25,11,176,249,210,255,127,254,119,250,239,254,88,255,62,1,249,254,254,255,187,255,130,253,119,255,148,245,153,254,170,255,79,0,247,252,108,254,208,253,51,242,122,0,143,255,105,2,241,1,117,0,244,254,110,0,73,0,240,2,175,251,247,253,250,2,183,2,181,253,109,255,45,251,74,7,54,247,97,253,1,254,126,247,204,252,149,253,162,0,219,255,102,0,170,254,234,254,181,26,234,254,185,0,10,0,105,1,204,255,85,255,246,0,184,0,81,255,19,0,166,0,208,255,215,255,92,0,104,255,53,251,41,252,111,240,65,253,119,4,204,0,245,253,29,4,145,253,234,3,231,0,53,0,235,254,103,254,189,255,200,255,166,255,209,255,192,1,242,2,42,2,204,3,249,1,181,254,82,19,63,255,89,0,18,2,232,255,84,255,254,0,244,0,140,0,246,255,40,0,179,255,119,6,74,254,40,245,51,0,215,253,80,2,170,244,24,1,36,3,8,3,131,0,69,0,49,255,131,0,7,0,209,0,93,0,237,255,132,251,35,253,114,10,164,249,37,251,6,254,214,246,167,252,252,251,154,2,109,1,159,254,105,0,120,0,210,0,171,255,37,0,216,255,3,4,11,0,210,4,251,255,72,248,3,2,33,1,231,14,114,255,68,255,8,255,239,254,247,254,81,2,205,0,164,0,191,255,70,0,32,252,50,6,82,8,11,3,92,0,5,244,165,1,1,0,148,4,240,1,107,252,8,253,169,0,192,255,14,0,216,255,9,255,161,255,233,6,111,255,200,2,230,252,197,253,240,0,18,249,218,255,127,255,188,252,44,13,119,3,61,254,73,0,149,255,182,0,100,0,14,0,65,253,255,9,234,1,185,252,179,254,134,0,36,3,35,242,50,0,57,255,41,255,142,254,197,1,170,255,151,0,158,255,198,255,128,0,192,245,29,250,169,249,118,247,167,255,201,255,40,254,101,253,2,0,73,254,83,250,250,254,53,2,56,0,138,255,32,1,200,255,87,0,114,254,217,2,40,0,129,232,219,0,44,255,31,1,6,255,45,255,227,255,195,255,201,255,136,255,164,255,30,0,129,0,134,255,111,0,245,7,236,4,175,3,4,255,243,255,230,252,246,245,163,251,41,1,118,1,163,249,255,255,105,254,171,253,188,254,77,255,152,1,58,0,122,252,120,249,99,2,58,255,195,255,103,0,110,1,147,3,43,3,232,254,111,254,247,240,145,255,221,0,97,1,232,0,4,0,238,255,161,2,0,7,210,246,132,0,187,7,242,246,95,254,79,253,70,1,0,3,135,254,246,253,117,1,123,254,151,255,153,255,33,0,208,255,217,5,101,4,101,7,72,245,61,251,153,3,216,1,91,255,74,254,127,255,86,253,241,252,83,253,167,0,53,253,156,0,64,0,61,0,123,4,132,252,184,255,67,2,167,4,57,245,39,7,103,7,151,2,48,3,158,255,195,255,33,255,146,254,83,254,31,0,127,255,135,255,1,255,12,7,138,0,180,0,217,251,86,2,251,2,208,2,129,1,242,253,143,0,80,0,168,0,208,3,54,253,236,0,124,243,93,0,106,3,238,0,153,254,59,6,191,0,56,2,74,255,20,0,160,253,224,254,90,2,32,255,34,15,204,254,186,255,198,252,147,255,214,255,142,252,115,250,189,249,113,2,74,251,31,0,14,3,150,255,68,253,10,255,197,253,132,255,176,252,122,254,245,253,169,244,247,255,39,0,147,255,57,255,241,1,245,255,121,1,5,0,25,0,141,255,195,255,27,1,27,0,125,255,63,255,24,1,178,0,193,234,44,0,204,255,70,251,151,253,94,255,183,251,253,255,236,2,211,255,83,251,222,251,141,3,71,6,181,2,42,0,19,253,71,244,151,1,194,255,45,0,214,0,200,254,226,251,242,1,11,5,165,4,12,251,59,4,11,253,193,254,20,245,52,253,54,1,47,6,160,253,63,1,172,255,137,255,121,250,166,253,116,2,207,1,67,251,230,252,38,254,122,10,163,3,240,0,187,9,76,0,22,255,95,255,78,253,103,1,28,0,237,255,250,252,1,252,226,2,163,2,248,0,52,0,164,254,223,253,101,245,169,253,4,255,148,2,125,254,152,255,12,9,200,1,166,255,100,0,51,244,0,8,62,254,123,4,207,5,228,252,111,253,203,1,97,2,63,0,103,255,106,251,112,255,37,0,80,255,96,255,43,0,225,255,239,245,88,0,227,252,155,4,61,253,82,12,225,253,107,3,116,0,216,255,106,255,70,1,37,1,144,255,183,255,222,255,61,0,8,0,53,247,241,249,53,246,6,0,204,255,251,255,189,254,199,254,52,4,152,3,92,4,180,251,79,4,54,1,112,255,136,3,149,0,197,255,124,2,28,250,134,254,125,1,107,252,156,252,108,5,55,251,188,255,211,5,173,2,36,255,181,12,48,0,8,254,192,0,114,0,245,255,74,249,108,252,148,2,16,255,255,2,219,251,76,1,79,2,35,254,234,254,25,0,51,250,55,0,216,0,90,243,237,255,192,254,108,255,17,1,148,252,22,0,239,253,191,12,25,246,12,253,123,255,31,254,0,252,34,0,162,1,97,254,156,1,164,255,166,255,161,0,207,255,93,249,79,245,107,11,13,255,122,0,87,0,216,3,135,254,219,255,128,0,94,1,68,254,158,255,204,255,14,0,242,255,170,255,255,0,205,7,41,251,42,0,247,0,241,255,16,0,149,1,46,1,239,255,84,0,63,240,244,255,254,0,147,254,51,255,94,255,73,1,31,0,122,251,46,255,136,254,118,15,191,249,152,251,225,2,219,2,44,1,239,252,247,252,109,254,207,1,30,255,147,255,235,254,186,255,203,255,168,252,239,252,27,252,71,0,189,21,61,1,191,1,233,254,155,254,254,0,93,0,209,255,50,255,133,0,88,0,16,1,7,0,44,0,181,8,130,6,234,0,7,2,52,248,85,251,37,2,193,1,174,0,14,252,110,2,169,1,240,8,247,255,122,254,100,2,216,255,32,0,181,248,95,253,186,255,106,251,106,0,134,0,98,1,61,0,112,255,222,254,82,0,164,253,202,0,142,240,248,0,180,255,7,0,224,0,204,248,99,0,110,255,206,0,177,254,243,0,25,0,60,0,186,0,117,0,67,0,119,255,119,0,46,0,211,17,45,0,210,255,254,255,106,3,21,2,216,0,218,255,185,0,228,253,65,255,93,255,130,255,148,255,72,255,193,0,217,255,96,237,111,0,167,255,195,255,17,0,40,4,142,6,126,3,238,16,139,0,132,252,61,1,161,254,161,1,169,255,234,255,195,0,20,0,140,0,234,0,59,255,244,254,251,255,174,249,12,253,137,255,43,249,64,253,81,252,165,1,96,242,103,3,44,254,144,2,10,1,177,255,69,1,209,254,45,0,253,255,225,255,116,4,61,253,214,249,102,250,34,1,71,1,171,250,159,244,24,4,38,0,120,255,153,252,196,253,226,255,186,0,87,1,226,255,99,255,21,5,121,7,253,253,182,252,45,253,172,255,172,254,14,1,106,252,141,12,6,250,118,254,72,255,196,255,121,254,229,255,146,255,84,0,104,0,163,1,177,4,214,252,10,6,39,0,110,252,178,254,95,239,171,1,161,255,86,254,162,255,0,1,108,255,246,0,176,255,9,0,50,254,155,251,132,2,213,13,116,255,42,9,21,4,177,254,157,252,41,3,176,1,130,1,250,255,159,0,70,0,246,255,218,0,43,0,75,247,161,253,25,2,100,252,34,244,81,252,56,252,237,4,28,0,197,0,227,254,61,0,137,0,69,0,254,255,5,255,111,0,237,255,198,254,16,8,192,3,249,5,32,4,158,3,193,254,175,249,25,5,193,5,157,252,172,2,77,5,190,252,190,255,221,1,74,0,241,255,23,249,133,7,112,246,15,249,5,254,8,1,52,249,176,0,250,253,198,255,32,0,148,255,165,0,188,255,189,0,35,0,40,0,171,255,128,251,255,0,36,0,126,248,220,5,135,5,73,3,164,255,233,12,146,255,3,0,37,255,167,0,61,2,219,0,54,1,27,0,195,0,103,1,12,255,26,2,6,248,99,1,144,2,51,0,57,255,52,255,229,241,116,254,71,3,231,2,15,255,176,255,46,255,155,255,28,0,137,250,38,4,69,252,54,0,138,253,78,255,136,254,212,0,237,0,37,255,47,0,37,3,216,0,26,0,18,239,199,1,4,0,4,0,205,249,95,0,162,4,227,243,116,255,162,252,148,3,15,8,211,0,96,0,81,1,71,255,61,255,168,1,183,4,225,255,94,255,206,0,181,9,210,255,61,254,14,249,216,255,144,0,101,255,68,11,35,3,140,1,172,4,133,253,41,1,180,255,135,255,94,255,50,255,107,255,100,247,11,4,232,0,209,252,207,255,238,3,41,2,105,254,161,0,66,14,248,254,114,1,94,254,228,255,141,0,79,255,143,255,166,255,197,254,114,2,62,0,112,5,233,248,80,1,4,251,110,254,230,1,220,251,200,248,50,10,58,3,229,1,6,255,39,0,208,0,14,0,251,9,53,11,211,252,230,247,81,1,89,2,87,3,113,253,54,2,61,253,189,0,179,255,137,0,2,254,230,254,79,0,42,0,73,0,62,0,138,2,132,237,26,254,98,1,164,1,60,3,123,253,20,254,132,1,241,2,18,0,2,0,254,2,44,255,126,0,213,255,45,0,191,1,229,254,95,2,251,0,90,255,246,255,48,0,38,233,5,255,128,0,51,255,161,255,90,0,90,0,67,0,24,0,206,255,208,255,89,255,97,243,146,244,39,7,199,0,228,1,169,0,154,253,121,255,138,254,94,254,17,255,167,255,135,255,45,0,75,0,245,255,16,0,222,251,98,1,97,6,77,2,57,251,194,4,74,3,134,251,138,8,118,1,149,254,216,0,151,247,83,254,173,1,171,253,93,0,148,0,57,7,227,252,94,255,31,0,187,254,87,1,189,254,161,0,139,254,172,2,145,254,60,254,46,239,168,255,28,0,200,255,197,255,43,0,207,255,50,248,68,252,51,5,138,239,127,255,30,0,79,0,166,255,127,255,109,0,130,0,96,255,153,1,105,0,42,1,208,0,178,0,188,6,219,2,5,3,128,0,49,3,87,254,50,240,180,0,242,252,140,255,191,0,253,254,181,0,225,255,162,0,43,0,215,255,187,255,183,5,23,249,254,255,70,254,132,253,215,5,38,255,133,255,198,255,32,14,198,1,37,254,247,0,129,254,48,1,185,0,155,0,40,0,80,4,22,4,248,255,32,253,125,251,141,255,85,15,255,254,221,255,169,253,75,254,121,255,0,255,55,0,214,0,168,255,215,0,199,255,183,251,183,0,11,254,160,253,121,255,148,0,149,1,39,1,96,0,255,253,245,3,254,16,94,255,195,255,171,1,59,1,24,0,179,255,2,251,89,255,18,249,123,255,189,254,13,239,220,2,85,2,226,255,153,255,79,0,15,255,177,0,124,254,7,0,44,0,175,0,113,255,166,19,21,1,58,0,42,0,34,255,123,255,193,254,6,0,240,0,217,0,18,255,58,255,218,0,213,255,183,1,49,0,37,0,106,0,99,4,148,8,158,0,171,0,202,1,92,252,77,254,33,245,212,254,188,1,13,9,110,255,173,254,94,255,157,0,40,255,1,0,66,0,219,3,66,255,40,253,140,243,161,243,122,1,255,255,158,0,203,1,78,0,214,255,130,1,123,255,155,0,38,1,103,1,227,255,78,0,227,6,12,3,251,3,182,254,179,0,205,255,119,254,82,1,70,17,216,254,120,254,170,0,2,0,52,0,253,0,150,0,65,255,139,0,141,254,161,0,102,247,156,0,37,0,20,252,128,254,46,254,23,0,183,0,139,241,97,0,243,250,157,254,173,255,193,255,230,255,69,0,231,248,129,2,180,11,240,255,219,7,106,254,121,253,116,253,76,1,20,3,228,1,150,3,72,254,222,4,165,0,52,0,252,254,31,0,1,255,187,227,14,0,90,0,121,255,122,0,14,0,154,0,5,0,178,255,111,0,2,255,154,0,233,255,232,255,173,255,247,255,49,0,86,254,121,6,99,0,220,255,65,255,65,10,143,2,236,255,93,245,47,252,34,255,208,255,155,0,41,0,20,0,194,0,183,255,230,255,74,251,67,242,41,254,209,252,136,251,141,254,73,5,211,251,42,251,61,3,29,255,231,1,215,254,155,255,146,3,100,0,239,255,115,0,218,252,226,252,73,2,73,4,255,255,232,252,50,3,29,0,0,255,95,254,174,3,68,0,187,239,34,0,104,254,4,255,55,0,179,255,246,0,7,8,252,255,199,254,107,253,188,252,47,2,119,254,251,7,153,0,30,1,116,245,98,0,79,255,177,4,99,0,52,1,183,255,161,5,194,240,218,2,182,249,118,3,169,253,130,255,217,1,43,0,4,255,45,0,95,0,221,254,101,0,205,254,3,1,107,255,26,0,2,254,242,1,123,5,178,255,241,251,9,246,5,3,104,251,11,250,107,254,253,254,229,254,142,1,32,8,57,255,62,0,239,0,230,255,192,3,70,2,212,9,31,3,177,247,69,1,3,255,140,249,59,252,133,5,8,0,137,255,140,1,170,254,21,1,29,2,186,0,114,255,186,4,36,253,30,3,209,255,211,253,244,255,63,0,25,2,148,0,128,255,72,1,34,1,203,0,105,1,184,254,192,255,164,15,197,0,128,253,228,3,163,255,246,246,76,0,110,252,157,5,60,252,57,249,216,3,190,253,109,5,255,251,190,255,136,255,69,251,224,255,5,0,65,251,3,3,85,6,90,252,40,252,148,0,200,249,66,254,19,0,48,252,83,249,167,251,38,255,191,0,233,254,135,8,10,0,219,255,182,252,210,249,164,255,46,2,227,0,66,253,147,254,192,253,156,255,158,2,207,254,29,1,48,0,183,254,253,0,38,15,156,0,70,0,16,252,129,2,5,6,22,255,160,5,165,1,64,4,223,2,50,255,173,255,204,1,117,255,107,0,120,251,250,255,39,8,102,7,139,255,194,3,113,0,34,252,93,0,227,255,67,2,193,4,204,255,170,254,61,254,158,2,202,0,210,251,69,3,124,255,179,13,197,255,142,255,77,253,208,0,110,251,65,4,49,1,56,255,91,2,235,250,82,252,161,249,11,5,89,245,158,1,80,0,47,3,69,254,54,0,222,255,139,251,21,5,81,251,116,1,102,0,255,254,70,0,194,1,201,255,80,0,29,255,218,0,8,1,227,2,204,255,56,255,33,15,83,0,0,32,96,0,214,0,117,254,150,255,35,1,111,254,49,1,154,255,194,0,183,255,31,0,71,0,237,255,163,254,65,0,73,255,26,0,235,255,218,31,107,0,120,255,219,255,221,255,85,0,127,0,54,255,43,0,61,255,225,0,205,255,187,255,199,255,149,255,141,0,136,255,228,254,29,255,28,0,168,2,218,0,29,0,248,248,232,1,49,255,59,254,157,255,160,241,46,255,39,0,23,1,126,5,22,1,219,255,196,249,232,0,120,1,90,0,234,0,236,242,242,0,229,6,43,2,141,252,118,0,115,0,48,0,140,255,118,8,220,254,136,0,15,2,20,255,238,255,155,1,236,255,66,255,32,254,153,2,4,13,122,1,225,254,81,1,199,0,251,255,192,240,55,1,215,254,96,245,63,255,239,255,143,3,32,255,201,1,208,255,254,0,15,1,232,255,179,255,165,0,23,0,182,0,158,251,122,0,248,253,53,1,236,241,11,252,107,254,121,253,111,255,118,251,251,3,66,255,234,254,69,0,106,1,71,255,178,255,11,255,216,1,158,2,19,254,108,2,76,0,205,2,8,247,145,255,58,254,152,12,27,0,47,0,161,254,102,255,219,254,187,0,163,255,96,0,87,0,59,254,124,255,9,0,125,0,47,255,230,255,28,1,216,253,255,0,87,0,227,0,187,234,112,0,172,0,241,255,64,254,219,1,141,233,111,1,149,0,28,255,227,252,115,1,67,0,154,255,138,255,94,254,76,1,38,0,156,255,90,0,73,255,26,243,15,0,231,251,232,249,19,5,58,253,233,4,186,2,60,1,229,254,187,3,240,0,182,0,13,1,12,0,219,255,25,7,137,2,7,251,233,247,73,249,3,253,209,3,121,251,95,1,209,249,171,255,253,252,41,255,123,0,58,1,98,255,32,0,48,2,208,0,9,1,61,254,99,254,32,0,162,7,242,241,112,249,192,252,122,253,249,2,16,1,138,1,213,0,221,255,212,255,87,1,53,1,244,0,225,11,113,254,206,255,130,255,61,245,110,255,243,0,145,254,168,253,90,255,192,252,231,253,13,1,208,255,115,9,242,253,203,254,239,255,21,255,73,0,85,1,95,1,184,252,169,12,162,255,80,254,148,1,180,253,158,0,129,255,207,255,187,12,215,13,134,0,0,255,150,255,110,2,211,255,86,255,147,255,68,0,121,1,172,255,210,0,6,255,245,254,1,1,179,255,6,0,171,251,38,250,185,254,39,4,224,3,120,2,11,255,112,253,180,251,196,255,56,254,86,255,136,12,250,255,13,0,161,255,94,2,174,253,9,248,143,254,49,249,19,1,163,255,117,0,12,11,118,255,148,255,206,0,27,7,98,0,211,255,45,0,93,255,146,11,114,254,208], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1732145);
/* memory initializer */ allocate([13,73,255,253,254,187,253,65,0,14,254,224,254,155,254,173,254,243,255,185,255,103,254,36,0,241,255,223,253,153,5,135,0,36,255,99,0,240,2,177,0,57,254,5,255,148,4,6,251,38,4,250,252,25,252,193,255,60,245,99,0,170,255,87,18,85,255,127,255,168,252,26,0,225,253,98,2,186,250,254,255,15,1,199,1,106,255,102,1,101,0,24,2,125,0,101,0,88,0,240,255,244,255,232,1,201,226,110,0,8,1,140,0,210,254,110,0,232,0,0,0,15,0,70,0,228,255,229,255,146,255,157,255,201,0,78,0,215,0,148,255,245,254,132,226,34,0,56,1,170,255,197,0,125,0,80,0,181,255,139,255,254,255,128,0,49,255,125,255,255,253,102,2,33,0,20,237,210,254,189,254,160,0,40,3,133,2,243,0,165,253,68,0,186,255,158,0,125,255,44,255,222,255,9,255,113,2,134,0,214,255,13,2,167,255,31,0,116,0,255,255,252,1,157,19,139,1,111,0,170,255,84,255,153,5,142,255,130,255,108,255,175,254,252,254,233,0,33,254,19,1,9,255,216,233,130,1,146,255,157,255,114,255,85,255,102,255,154,254,30,0,4,4,178,255,63,2,11,2,182,253,29,253,50,6,52,4,41,246,36,6,88,250,55,255,166,0,202,255,137,0,244,4,133,4,101,254,167,244,195,0,233,1,28,253,154,0,10,2,228,8,164,253,194,0,168,251,192,0,144,1,241,254,250,0,157,1,17,1,158,0,213,254,150,252,28,255,106,246,162,0,51,3,201,1,73,13,177,2,48,255,214,254,51,254,152,254,186,255,171,247,142,255,132,255,81,0,28,255,113,2,197,13,141,3,254,0,22,255,36,5,251,252,19,2,226,255,240,255,92,255,172,255,56,9,148,248,95,1,93,244,33,2,141,2,160,1,17,1,177,255,199,252,149,255,71,0,239,1,223,0,80,255,129,0,40,0,168,1,91,6,207,0,47,0,248,255,239,254,53,253,60,0,27,251,221,5,81,251,8,255,39,0,43,11,80,254,89,0,43,1,180,3,208,245,128,252,140,13,84,0,255,1,55,0,151,0,221,2,14,1,158,254,214,1,37,255,141,255,151,255,91,0,253,254,149,7,7,3,12,0,204,10,228,1,45,2,240,8,138,255,38,1,224,255,207,2,194,255,192,255,217,254,174,255,111,255,227,254,20,254,87,0,121,255,158,255,194,0,224,254,248,255,7,1,37,254,203,255,124,254,245,21,41,0,228,255,34,0,189,254,138,0,143,7,242,248,71,255,84,1,100,5,48,0,226,253,107,244,173,254,88,0,42,2,41,0,4,0,105,255,182,0,217,255,63,255,229,242,200,254,34,12,53,255,186,1,146,255,61,1,243,254,225,0,31,0,194,255,235,254,163,0,2,253,104,254,210,0,198,255,128,0,161,0,236,12,249,12,118,255,234,254,107,255,216,0,134,0,3,255,121,255,102,255,133,255,254,0,200,0,254,255,133,0,205,254,147,231,54,1,250,255,191,3,26,0,191,0,59,1,16,2,181,255,26,255,53,255,153,0,247,254,162,255,195,255,254,255,201,10,241,237,159,254,237,255,102,0,117,255,54,0,182,1,11,1,183,255,191,1,226,0,71,0,237,255,75,0,216,255,224,255,174,252,12,254,166,1,213,4,80,253,101,1,170,243,44,254,62,254,233,254,74,253,171,251,222,2,190,249,139,255,122,0,5,1,211,3,236,255,129,1,143,244,86,1,164,243,110,255,252,0,152,255,62,0,213,1,33,1,249,0,42,255,218,255,73,0,83,0,249,255,18,0,118,254,251,255,116,255,245,254,75,1,109,255,140,25,139,1,153,255,109,255,241,254,236,255,191,0,73,0,101,255,197,0,71,0,247,1,19,0,138,0,127,255,79,1,209,0,75,0,193,231,140,0,80,255,251,255,35,0,216,255,195,255,110,255,56,4,58,0,71,1,207,255,182,252,151,5,83,2,133,13,1,0,142,0,209,7,41,1,240,255,87,254,132,4,155,255,202,255,36,4,34,255,217,254,170,3,68,251,186,246,73,0,240,254,10,243,248,255,50,253,114,0,102,255,85,0,247,255,72,0,86,0,206,250,226,0,122,250,247,253,89,12,192,248,133,0,240,0,13,254,141,254,23,253,11,3,49,254,6,254,207,1,27,255,30,255,133,1,135,0,215,239,104,1,223,2,194,254,9,3,81,2,209,3,82,255,30,1,187,0,161,255,166,249,245,0,97,0,9,0,21,1,43,1,32,6,42,4,119,1,62,5,122,254,116,3,15,1,185,0,254,254,180,251,65,8,149,255,65,254,131,248,198,255,227,255,57,4,57,254,244,253,60,255,77,7,91,253,20,242,163,5,29,0,87,254,228,255,142,254,170,254,228,255,30,0,138,255,58,0,95,2,198,1,45,0,136,255,232,0,20,0,21,0,81,255,144,255,20,255,236,1,155,1,42,0,214,255,201,15,39,0,237,245,235,0,110,255,122,0,24,0,21,5,123,0,51,254,64,243,60,1,168,255,47,255,140,0,131,1,82,254,78,0,252,1,149,0,252,241,83,4,52,3,116,255,142,2,44,3,202,253,238,245,109,254,184,255,120,0,99,1,120,255,135,255,209,0,240,0,116,0,231,0,94,6,208,0,78,255,168,243,155,8,204,255,195,1,84,0,202,254,81,251,84,2,69,0,29,1,242,0,15,0,49,0,85,1,102,255,18,247,182,4,147,255,24,4,121,253,103,4,98,0,16,251,216,252,208,6,195,249,13,0,26,0,40,255,7,1,204,12,120,12,151,255,122,254,225,255,164,2,73,0,9,1,31,0,101,0,223,1,187,255,123,0,232,255,207,255,32,0,115,253,205,8,49,0,166,254,196,5,28,7,140,1,127,2,37,255,24,3,192,6,147,0,3,253,116,255,157,4,98,0,153,0,158,255,13,253,169,9,196,1,231,0,239,7,164,9,96,254,75,2,212,2,148,0,244,1,91,252,27,255,55,0,102,0,74,0,92,255,140,2,87,254,100,0,132,245,78,5,90,6,162,254,32,2,211,254,203,249,207,254,14,251,11,0,243,0,131,255,182,254,38,1,191,5,150,244,45,6,222,253,70,2,231,0,129,250,147,252,90,2,219,0,94,1,106,4,170,255,214,0,200,255,201,0,75,255,164,247,84,4,237,1,200,1,226,253,143,255,172,252,111,6,105,7,72,3,102,251,143,254,20,3,232,1,0,1,110,1,250,8,143,4,51,255,0,1,73,2,213,253,36,1,55,10,236,2,9,255,178,251,110,249,226,0,159,1,20,0,27,0,100,0,9,0,180,1,46,249,61,10,47,6,45,255,191,252,185,1,54,0,97,251,198,252,108,252,61,253,52,2,24,255,242,255,147,0,197,1,70,0,70,4,121,252,175,254,194,1,246,249,106,253,233,251,215,246,213,252,243,251,96,0,48,2,101,5,137,255,129,254,208,230,197,255,42,1,109,253,197,255,73,1,199,253,141,1,32,255,128,0,40,255,153,0,156,255,63,1,203,255,166,255,50,0,241,12,4,0,41,255,149,1,0,255,78,0,74,11,69,255,55,252,195,0,2,252,137,255,214,0,254,0,152,254,34,255,39,0,91,8,91,0,222,254,17,2,183,255,240,255,194,254,128,0,164,254,53,2,90,251,202,0,71,255,22,255,170,13,48,0,68,0,131,248,158,6,212,0,35,254,239,0,27,243,23,254,168,1,162,1,174,255,195,255,87,2,250,5,56,255,4,255,162,0,13,255,43,0,234,253,121,245,255,0,61,1,233,1,23,1,9,13,246,0,163,254,107,255,128,255,110,255,0,1,57,254,137,0,181,255,68,3,209,0,163,254,166,13,255,0,100,248,36,253,111,1,93,5,45,255,96,2,89,1,239,255,43,0,102,0,19,0,37,255,173,0,199,246,130,0,162,252,125,2,153,255,179,253,219,0,19,251,18,255,32,246,107,6,205,249,78,253,90,255,7,0,199,255,197,4,70,1,103,0,194,252,96,2,196,0,135,241,79,4,56,2,190,249,31,2,103,255,96,254,74,0,185,0,156,0,34,0,49,5,226,252,42,255,253,253,121,0,227,252,237,2,90,1,117,2,159,253,147,252,196,255,184,0,99,255,250,0,193,0,33,17,113,1,75,255,65,255,204,254,198,254,117,254,83,255,168,255,124,254,213,255,46,0,9,0,89,255,189,0,64,255,198,23,30,255,253,248,126,0,83,252,89,254,141,1,124,1,205,1,63,1,108,1,62,255,177,1,190,4,125,241,238,254,9,0,185,254,212,0,137,254,130,0,107,252,193,255,96,4,117,253,45,255,149,0,152,251,9,1,183,255,234,237,237,1,173,255,236,255,198,254,165,255,142,3,147,255,253,255,95,254,147,255,118,1,101,1,43,245,253,0,22,255,206,254,12,244,6,253,53,0,220,1,213,254,167,255,120,246,110,253,173,255,170,252,186,14,118,1,40,2,194,1,51,0,90,1,119,3,49,254,189,0,254,0,182,0,15,0,219,255,65,243,34,10,121,253,173,255,148,1,2,3,179,2,114,253,211,254,81,0,243,255,230,2,115,1,54,0,31,0,173,255,197,255,100,16,141,2,0,1,205,251,229,253,60,4,203,251,214,4,3,1,20,0,65,255,86,3,179,0,209,255,255,251,67,255,25,1,252,9,229,6,106,0,177,255,64,1,6,244,228,0,12,254,1,0,73,255,210,255,220,0,23,255,206,255,158,255,251,254,172,255,231,255,230,238,84,254,141,250,186,253,149,253,187,1,80,250,119,1,144,0,224,255,100,1,58,254,28,0,136,0,5,0,247,0,223,251,197,2,150,254,37,1,12,12,33,2,12,245,143,253,16,0,28,255,18,255,164,0,55,255,142,255,107,255,58,0,182,255,203,0,15,1,206,1,13,4,159,0,140,249,177,253,178,252,90,255,56,243,198,2,5,3,56,3,142,251,118,2,242,255,209,0,92,1,196,5,66,1,141,254,241,0,37,16,147,252,36,254,121,254,90,2,235,4,76,251,96,1,90,0,39,254,43,0,104,255,73,254,125,255,39,255,233,249,91,236,70,255,17,255,212,255,238,2,33,0,89,255,45,255,189,255,165,255,113,255,124,0,32,0,240,255,0,32,68,0,154,255,163,0,225,255,202,1,38,0,249,0,21,0,157,0,193,255,36,0,49,0,234,255,89,0,9,0,153,0,46,0,60,0,110,255,243,255,174,226,152,255,101,0,115,255,25,0,165,0,172,255,219,0,53,0,74,255,162,255,46,0,222,250,141,254,214,254,241,253,6,0,93,248,52,0,54,253,51,254,174,0,170,5,214,254,107,0,149,11,250,0,191,255,46,0,85,255,40,1,239,252,240,252,35,0,36,0,29,0,147,3,133,252,121,254,168,0,253,1,179,14,13,251,118,255,132,0,168,1,203,255,99,253,45,250,97,252,200,2,130,253,72,254,213,254,10,2,57,6,189,1,162,12,35,2,242,1,184,1,145,0,121,255,68,255,216,254,56,4,212,1,77,0,176,0,197,254,221,0,176,18,102,253,18,1,250,2,214,255,218,0,170,255,239,254,116,0,46,3,235,255,146,1,246,254,120,254,87,254,102,4,188,255,142,0,101,1,23,20,107,1,32,255,58,255,115,0,35,255,250,254,32,253,42,245,60,255,48,255,155,253,163,0,184,2,21,3,132,0,114,0,121,0,190,243,164,0,172,0,67,255,232,0,53,0,54,1,206,255,105,254,183,4,38,254,249,0,218,252,21,0,20,0,72,0,234,253,101,0,209,255,33,255,40,238,128,255,227,255,114,252,2,255,105,0,91,12,137,255,121,255,209,6,208,6,81,4,35,1,179,254,234,254,71,254,148,2,141,0,221,254,58,1,149,0,142,0,135,255,58,225,16,255,52,255,189,0,120,1,3,0,127,255,59,0,46,0,170,0,82,0,106,255,222,255,67,0,146,255,123,2,148,0,0,1,133,244,157,0,3,254,159,5,90,246,26,3,214,254,151,1,212,3,37,3,93,1,208,0,221,255,241,3,156,4,142,255,8,3,173,254,248,252,250,0,159,7,211,253,172,0,117,254,27,3,253,243,164,254,150,255,122,0,209,255,247,255,55,0,40,0,186,11,165,1,26,2,255,255,235,254,10,244,241,255,168,0,205,1,9,2,243,253,157,1,60,255,159,0,14,243,171,255,215,3,53,2,215,243,38,0,79,0,84,255,20,0,28,255,248,253,90,1,47,0,229,1,79,255,51,0,175,0,188,1,147,13,168,242,175,255,118,0,8,1,94,255,20,0,64,255,37,255,145,255,199,255,31,255,159,0,38,255,117,0,228,255,106,255,180,251,87,253,188,1,202,255,245,255,195,237,40,255,129,251,90,3,168,0,217,255,52,0,131,1,74,0,217,255,102,255,207,10,51,1,124,255,19,2,175,0,138,3,14,0,127,255,49,0,195,242,220,1,129,255,183,254,223,1,118,0,171,255,209,0,4,0,227,0,154,0,254,255,18,255,7,1,232,255,41,2,25,255,78,0,2,0,73,255,31,0,45,23,117,0,86,0,130,1,103,1,153,0,101,0,240,252,215,253,243,255,0,1,165,254,225,250,88,252,192,255,182,6,68,254,168,0,178,253,76,243,62,255,13,255,243,254,48,8,30,252,199,251,53,1,235,3,34,1,190,255,50,1,89,243,231,255,188,2,109,1,254,252,144,0,4,0,3,1,71,255,213,5,98,255,214,2,148,243,109,249,137,255,45,0,19,254,51,255,64,249,54,251,21,255,169,255,168,255,169,255,174,7,8,0,142,0,240,1,239,0,60,3,30,0,251,253,78,12,218,8,146,1,197,254,74,0,200,254,98,254,240,255,202,1,125,1,120,1,7,5,69,4,102,254,57,252,80,0,126,1,150,255,67,17,189,1,37,1,229,254,26,1,68,1,176,255,231,255,115,0,125,249,12,253,101,7,44,245,139,1,3,0,163,254,138,0,70,4,150,1,176,1,214,0,208,250,120,2,124,255,156,255,135,0,91,6,38,4,2,4,195,250,24,0,232,242,83,255,241,4,93,3,203,252,169,255,145,254,22,1,151,0,155,255,224,255,161,0,131,1,146,22,204,253,236,1,83,0,68,1,29,0,89,254,91,0,124,255,190,0,202,254,55,254,194,255,157,255,171,0,42,255,97,255,60,246,75,253,254,249,201,254,240,252,138,246,14,254,245,6,86,1,45,254,178,255,210,1,4,255,241,0,197,0,186,0,241,251,66,255,90,1,167,248,16,255,191,255,158,5,233,3,63,244,204,255,221,0,22,254,200,4,193,255,217,255,53,0,169,0,130,0,86,0,200,255,166,255,116,0,4,0,186,27,251,255,61,0,84,255,191,255,160,0,162,255,226,255,145,255,14,1,115,253,9,2,86,254,60,4,111,251,122,251,72,2,61,246,190,9,191,254,183,2,55,3,83,254,35,0,17,2,232,254,211,255,226,254,181,11,207,0,135,253,97,247,172,6,214,254,99,254,161,2,7,252,36,1,237,1,76,0,120,255,147,254,191,255,10,1,84,3,0,2,23,3,127,255,84,5,215,251,91,5,127,1,244,253,249,1,175,3,147,0,229,0,39,0,103,244,70,0,217,254,66,0,199,10,240,255,77,254,38,254,222,251,250,2,54,0,255,254,48,2,161,243,196,253,94,254,34,254,114,1,72,0,236,255,40,1,54,0,133,245,38,2,241,255,101,255,98,8,113,255,136,251,207,1,139,255,102,249,131,248,42,0,249,0,234,254,193,254,255,253,32,2,15,248,195,254,93,248,170,245,65,5,247,2,12,1,207,0,219,4,0,1,224,255,211,255,18,253,45,255,72,255,93,9,217,1,12,10,23,254,4,1,133,1,19,255,90,2,49,254,57,2,137,6,80,255,29,255,196,3,203,0,130,0,243,254,66,255,59,5,46,252,205,3,194,7,121,4,234,4,16,1,243,6,76,254,230,250,140,2,39,3,62,2,121,5,53,0,73,255,76,6,196,252,234,243,174,255,37,4,18,4,56,255,133,252,130,255,181,0,212,250,37,2,43,2,252,255,156,252,79,0,157,0,3,250,18,0,230,0,184,251,177,254,99,253,90,255,61,7,202,254,172,254,249,0,70,252,174,253,143,244,159,1,5,0,135,0,221,250,19,255,76,7,19,3,120,7,180,251,115,4,177,251,39,255,130,254,114,253,30,8,16,2,133,0,141,255,200,255,215,255,49,255,69,0,205,1,209,1,116,254,189,6,26,5,69,254,48,253,192,249,152,4,140,2,27,252,206,254,240,251,210,8,181,255,15,244,171,252,140,12,178,254,5,0,224,0,63,0,6,255,167,254,154,255,223,254,141,255,75,0,157,255,206,0,248,255,19,0,96,0,2,255,250,245,78,1,213,10,136,0,199,0,204,251,91,1,69,255,225,1,192,255,142,2,247,255,186,251,196,0,40,0,161,255,5,0,163,0,121,255,253,0,227,251,60,1,25,255,24,0,253,246,200,5,252,247,238,255,53,254,218,253,188,248,241,255,98,0,130,250,190,255,6,255,21,0,241,1,108,254,202,255,28,255,173,9,219,7,111,255,91,248,86,254,118,252,96,2,15,0,173,5,218,0,177,255,132,253,19,252,180,254,48,1,34,9,76,5,81,0,79,251,86,255,130,255,103,251,148,249,234,251,16,0,182,0,184,254,165,254,90,1,79,2,162,1,111,2,146,255,170,254,29,255,10,0,65,236,101,254,128,0,153,255,87,0,228,255,123,255,196,0,77,1,249,6,33,254,70,254,180,244,197,1,12,247,237,255,129,254,212,255,77,254,63,255,247,1,130,0,4,0,144,0,136,8,11,255,249,255,202,1,82,0,180,255,236,11,137,254,19,5,180,255,108,1,111,255,116,1,36,0,59,0,217,255,48,0,129,1,26,255,204,10,140,11,27,253,140,254,172,1,8,254,36,255,203,252,209,255,207,255,97,2,194,255,56,0,6,0,216,0,120,1,7,2,0,254,54,0,194,254,73,255,45,238,41,1,27,3,74,255,108,0,234,0,148,1,218,0,133,255,239,255,64,255,170,0,93,1,134,0,165,255,43,0,121,255,232,255,250,255,224,255,231,229,50,0,118,255,167,255,238,255,15,0,24,0,96,254,100,1,55,1,83,0,245,254,81,0,209,0,101,255,144,254,140,1,102,1,232,0,88,18,165,254,212,2,112,0,10,0,75,1,102,1,197,0,54,0,56,3,134,2,42,255,113,0,183,238,184,0,245,255,101,0,199,254,186,0,253,0,169,0,78,0,52,0,186,255,148,255,133,6,234,255,238,255,216,245,229,255,246,10,32,1,150,255,250,1,176,0,104,2,213,254,58,0,226,255,1,0,36,255,144,1,79,255,106,3,70,0,220,255,238,254,117,255,124,4,116,1,40,0,236,0,249,1,107,2,94,240,161,255,208,255,218,244,114,0,187,255,11,245,111,254,247,255,203,0,13,252,216,1,214,251,156,1,36,255,245,0,73,255,229,255,35,0,6,253,56,1,119,255,220,254,14,255,128,3,172,0,167,254,106,0,118,238,250,1,57,2,245,255,160,254,148,255,78,1,91,255,85,9,129,252,201,10,211,1,201,0,150,0,252,253,39,0,175,251,4,0,75,2,104,255,4,253,72,255,241,255,119,255,226,255,244,255,7,0,126,1,51,254,41,6,191,13,83,255,90,5,80,0,243,1,88,1,253,252,123,0,243,255,32,1,233,0,111,0,88,246,112,15,3,3,216,0,7,254,66,254,19,2,26,255,103,0,184,255,34,0,61,0,249,0,81,255,97,1,83,0,51,0,169,0,159,255,196,255,147,30,95,0,75,0,243,255,201,0,229,255,103,0,245,255,1,0,3,0,121,0,183,255,228,255,7,0,92,11,47,255,37,252,127,255,171,254,24,11,121,3,109,255,247,253,123,0,95,0,17,255,40,2,30,253,23,1,190,255,0,0,16,0,116,0,211,255,228,255,213,255,218,255,53,226,30,0,204,255,47,255,25,1,210,255,23,0,232,255,56,0,231,255,233,255,26,246,149,255,210,255,163,255,207,255,238,0,231,255,96,0,156,254,155,13,53,254,98,254,205,0,102,0,202,0,106,255,140,255,249,6,119,5,25,3,31,2,173,2,235,244,255,0,106,1,160,255,154,1,158,3,44,4,160,1,46,2,87,255,246,0,138,0,88,8,39,0,160,255,163,253,23,1,126,255,75,245,179,251,89,252,236,255,29,255,197,1,237,4,103,0,19,1,102,1,43,0,197,0,233,255,5,255,66,1,234,255,233,0,0,10,42,255,2,0,155,255,133,2,48,11,31,1,33,254,136,3,191,255,73,0,224,0,114,9,161,255,172,1,90,253,234,254,71,0,223,253,197,253,202,253,75,255,44,255,125,244,222,0,12,3,147,254,124,0,113,245,58,255,187,255,10,255,16,244,72,255,170,253,181,255,111,255,78,253,124,1,194,0,229,1,214,0,28,254,54,0,163,0,107,1,100,252,148,6,201,0,34,0,236,0,229,253,70,9,106,255,22,254,223,250,195,255,61,1,75,8,59,1,217,253,230,255,184,254,207,0,253,0,57,244,166,0,109,0,106,253,162,9,99,255,28,253,239,2,254,0,236,252,143,254,250,255,100,0,45,255,107,0,203,254,217,255,209,255,23,1,130,255,165,255,97,0,63,253,235,0,25,255,182,0,27,1,23,236,188,255,29,1,49,0,50,0,125,2,111,0,39,0,126,254,155,3,223,0,115,0,102,6,190,4,128,253,136,247,226,1,76,247,89,3,172,0,15,0,97,247,167,255,79,1,238,255,39,1,206,2,68,252,26,0,92,2,76,254,40,11,149,251,98,0,14,253,243,0,9,0,29,0,68,240,67,249,51,249,176,1,45,255,196,255,233,253,201,0,239,254,111,0,188,1,95,2,6,255,122,0,98,0,159,0,97,0,25,1,255,11,100,254,223,244,47,253,242,255,192,3,213,255,26,3,85,254,41,1,222,1,123,1,209,255,234,255,69,0,196,255,226,255,36,253,152,9,170,0,142,0,6,0,216,9,124,253,55,255,240,255,66,6,236,255,219,254,30,2,61,254,89,255,247,255,14,0,28,4,147,10,164,11,139,255,223,1,54,255,164,255,36,0,136,3,190,255,192,251,225,255,75,0,194,255,146,255,227,255,112,0,154,255,97,20,171,255,14,0,65,255,54,255,81,255,185,255,182,0,25,255,19,1,144,0,255,255,54,255,243,255,227,255,237,255,70,0,39,0,46,0,56,0,72,226,203,255,152,255,195,255,44,0,23,0,1,0,99,255,42,0,12,0,38,0,37,0,75,1,159,253,44,246,82,255,69,246,2,1,0,255,98,252,215,3,100,0,83,0,173,0,59,252,138,2,208,254,159,255,98,0,90,255,22,2,10,10,157,253,237,1,103,0,158,255,148,0,9,12,125,255,29,1,13,0,145,254,205,0,203,255,41,0,29,0,102,255,159,245,205,255,200,254,134,0,50,0,22,250,122,2,155,1,187,244,121,254,109,1,139,254,202,255,182,255,105,255,80,0,152,0,165,255,192,255,47,255,110,4,151,244,60,1,73,252,100,4,201,2,2,0,92,247,31,0,164,0,252,254,103,0,36,0,229,0,111,0,233,255,191,255,219,255,36,255,148,255,226,255,86,0,17,0,87,0,205,0,163,0,63,0,125,233,254,0,178,0,238,255,224,6,132,254,173,5,177,243,198,2,106,0,66,0,131,1,235,0,207,1,217,254,176,2,132,255,66,1,63,255,82,0,244,3,15,248,112,253,82,5,37,3,21,253,223,9,214,1,43,0,23,252,100,0,173,255,161,0,74,0,152,251,205,254,174,255,59,255,162,234,226,0,185,254,137,0,125,255,215,1,80,254,240,255,243,0,224,0,168,0,92,255,198,255,125,0,23,0,254,255,64,245,12,1,164,255,46,254,60,11,106,3,182,0,28,2,105,254,174,254,116,254,50,2,136,254,24,2,31,255,160,0,44,0,35,250,10,255,218,251,134,254,190,1,112,246,132,255,243,1,7,247,159,254,131,253,139,1,86,2,21,253,162,1,17,254,5,0,10,252,90,8,33,1,181,255,45,1,176,3,66,0,55,254,53,254,3,255,254,255,166,2,111,1,116,0,171,244,180,1,17,255,209,254,51,252,128,1,242,245,6,0,31,255,92,255,72,254,115,2,132,1,254,243,249,254,156,0,219,252,125,1,247,255,144,255,55,250,24,2,57,253,186,14,16,254,140,3,227,1,218,1,42,1,88,254,231,252,53,255,178,254,134,0,165,255,208,0,183,255,64,21,196,254,208,254,249,0,255,255,158,255,42,255,190,0,242,0,199,255,218,255,244,0,37,255,30,0,32,255,66,0,226,255,22,0,24,0,24,0,147,255,86,226,141,255,90,0,109,255,173,255,21,0,255,254,204,255,134,0,207,255,92,0,139,255,30,0,248,255,132,253,15,6,159,8,190,255,86,248,212,0,55,2,201,3,197,249,206,253,99,1,45,254,163,252,169,3,108,255,15,0,188,255,20,250,186,247,197,5,9,3,178,5,208,3,10,2,69,1,189,3,126,255,124,255,106,252,192,1,64,4,102,0,142,0,124,253,228,254,175,2,103,253,124,255,178,248,107,5,221,2,172,255,152,3,4,254,53,0,121,247,254,0,53,2,8,8,97,0,57,0,219,0,176,2,168,254,147,2,241,7,195,3,75,249,222,254,90,252,185,247,57,0,84,250,24,0,129,253,29,253,24,255,170,0,28,0,103,1,200,254,54,1,153,255,213,251,71,252,57,4,167,252,134,7,84,5,73,249,161,252,40,7,18,3,55,0,166,0,127,1,163,250,165,254,174,6,116,252,91,0,233,4,221,7,176,253,199,250,151,5,166,255,105,2,37,2,156,254,188,255,134,0,208,255,123,255,80,255,238,255,191,255,23,0,84,0,233,255,220,255,252,255,230,0,41,1,52,255,106,255,86,0,155,236,230,2,40,0,32,0,210,251,149,0,38,0,46,1,183,254,126,254,199,255,45,0,170,249,145,5,25,7,32,6,154,8,7,0,88,251,55,255,214,255,194,255,86,255,224,255,139,255,218,255,229,0,44,0,30,255,155,0,70,0,235,2,3,1,251,254,136,255,216,241,17,254,158,0,10,255,239,253,211,252,177,2,248,1,241,253,88,247,58,255,189,254,78,253,177,253,175,0,6,1,243,0,164,241,88,10,38,252,166,0,243,0,45,1,68,253,68,1,188,254,13,0,106,1,222,0,42,254,30,0,20,0,210,255,109,255,210,15,159,255,208,253,28,1,61,1,181,249,143,2,96,254,210,249,93,253,133,1,132,255,150,0,229,255,69,1,172,255,48,0,50,29,97,0,105,0,19,0,38,0,133,0,19,0,28,0,25,0,40,0,34,0,197,255,22,0,11,0,27,0,21,0,5,0,196,249,84,254,183,1,97,1,240,8,238,255,101,1,238,254,22,10,130,255,166,255,71,0,247,255,64,253,205,0,22,0,44,0,136,255,213,255,5,2,49,3,90,5,103,8,2,11,42,254,90,0,139,1,37,251,167,254,191,3,19,0,255,255,123,0,148,255,91,1,25,0,118,255,15,0,119,0,139,255,110,255,142,0,183,0,2,255,236,254,82,255,92,23,27,1,195,254,70,0,51,0,241,255,113,246,177,255,234,0,224,2,216,245,127,253,118,251,120,1,191,3,6,255,189,2,216,255,154,255,204,0,218,255,232,255,131,252,125,254,83,1,58,5,165,255,113,253,160,252,78,0,43,1,228,0,84,245,234,0,203,7,215,250,117,255,244,1,196,254,116,255,2,0,176,255,186,0,11,0,16,0,187,255,146,226,85,0,249,254,189,0,249,255,255,255,189,255,188,255,3,0,24,0,135,1,29,243,120,244,135,255,119,254,103,0,196,255,143,255,141,0,185,0,137,255,240,0,14,1,120,254,151,255,9,0,217,255,225,9,239,255,97,1,150,11,169,252,18,4,14,5,132,0,255,254,255,254,16,254,112,0,77,255,168,1,230,1,193,255,77,0,19,1,58,255,234,7,121,6,145,3,1,255,109,255,44,249,251,255,162,1,100,1,230,7,159,3,217,254,194,0,165,0,28,0,109,0,13,0,209,0,123,255,14,245,164,1,175,248,120,253,53,1,108,251,223,248,220,255,72,3,24,1,44,0,138,255,128,0,34,0,241,0,19,252,136,4,209,254,62,1,214,2,76,249,65,10,74,252,185,252,23,251,123,252,18,255,99,4,131,0,252,0,1,0,184,1,175,5,242,255,238,254,51,254,87,0,253,253,5,247,160,3,205,244,220,252,41,255,168,2,147,0,80,0,215,0,15,0,59,5,141,0,161,255,134,0,221,255,122,0,53,0,173,1,168,0,220,1,211,255,233,2,236,0,133,16,62,1,247,0,55,255,140,254,241,8,161,0,175,1,81,1,61,253,0,252,121,0,19,249,229,252,93,251,111,254,138,1,105,250,246,5,221,255,176,1,113,11,90,0,88,7,116,2,18,5,216,253,14,254,207,0,159,255,105,250,81,4,29,0,29,253,200,255,62,0,94,0,25,2,36,253,231,4,2,253,200,0,147,254,30,11,91,8,179,1,92,0,58,253,0,254,104,1,173,254,253,3,218,1,124,255,149,1,72,254,107,13,75,0,2,255,117,246,144,252,69,1,87,1,29,1,230,0,81,254,65,255,215,0,201,0,69,254,93,0,175,255,125,255,165,11,86,244,235,3,181,1,178,1,126,254,17,0,222,0,70,0,173,0,218,253,11,1,135,255,213,255,114,0,245,255,229,252,49,2,109,255,187,0,58,255,151,236,50,0,59,0,162,2,171,252,163,0,71,0,51,255,228,254,206,255,228,255,124,250,151,255,6,1,16,1,53,2,200,252,227,253,53,13,174,1,175,255,228,0,86,254,210,3,218,254,166,1,230,253,13,0,9,0,174,1,180,0,25,9,204,253,198,251,204,6,84,4,37,248,11,0,87,1,100,3,211,2,218,252,86,1,83,1,115,255,83,255,186,0,50,0,41,1,193,2,15,3,175,253,73,6,212,0,16,2,13,246,161,252,103,246,148,252,164,0,162,0,109,1,68,0,30,0,11,0,48,0,47,0,227,254,192,255,166,0,235,255,32,229,65,255,30,255,89,0,255,255,22,0,163,255,250,255,44,0,26,1,52,0,38,1,78,253,109,255,116,1,199,8,36,3,131,253,54,0,81,9,249,248,59,1,95,252,180,2,191,255,202,255,218,0,16,253,249,253,123,8,177,0,139,3,22,0,246,252,160,245,62,0,94,254,78,254,51,1,114,7,232,254,196,0,76,0,58,0,210,255,70,0,145,254,189,255,50,0,125,0,77,0,221,253,225,254,159,255,246,255,172,255,241,254,8,237,10,0,234,1,208,253,235,255,66,0,91,246,190,254,253,3,168,3,113,2,40,246,120,4,139,254,14,1,36,3,91,2,165,255,6,1,147,2,9,0,188,254,50,0,56,253,145,10,56,244,82,2,87,0,168,255,185,2,51,255,225,252,128,255,37,0,248,1,59,0,238,254,143,2,160,2,236,255,14,5,35,255,118,244,198,0,162,2,116,249,95,3,68,1,200,3,219,2,101,4,215,255,107,255,209,254,223,0,90,5,189,255,62,255,255,255,62,255,251,0,53,254,217,255,125,17,113,0,182,255,126,254,214,0,184,255,179,255,199,249,255,1,51,254,240,2,209,253,36,254,204,0,46,253,26,4,32,8,164,9,102,255,48,255,196,3,103,0,198,255,134,1,185,248,142,3,205,254,209,0,224,255,151,2,103,0,123,255,191,243,89,254,3,1,163,253,14,255,139,0,121,254,24,254,77,0,246,254,98,249,141,1,109,253,237,0,20,8,253,255,157,252,102,3,111,6,133,2,56,7,68,0,126,1,199,1,217,253,169,255,157,255,146,244,116,1,134,9,114,251,250,255,9,2,61,255,235,4,94,255,149,3,140,0,19,1,239,254,133,0,62,1,231,255,252,0,137,255,124,255,48,12,141,1,142,1,92,254,220,6,154,2,128,8,115,255,15,1,205,255,22,0,18,254,220,255,57,0,52,1,222,0,1,14,16,0,247,254,68,10,232,255,162,0,13,0,16,255,160,255,108,2,75,1,63,254,198,2,133,255,151,255,23,0,86,255,20,0,0,1,148,235,142,1,70,255,16,1,129,0,175,0,86,2,240,255,10,254,11,0,41,255,28,0,146,255,242,13,68,0,199,0,25,246,91,252,13,3,6,253,69,1,18,0,74,254,193,254,217,1,91,253,176,0,34,1,0,0,67,0,250,255,100,255,31,0,35,0,125,255,129,255,24,0,156,255,86,229,139,255,203,255,216,255,99,0,206,255,163,255,31,0,34,0,5,255,186,0,231,1,53,255,106,253,74,255,160,255,239,0,52,1,82,1,170,255,249,236,8,1,208,255,58,1,190,255,100,0,68,255,151,0,24,0,198,0,4,0,182,19,209,255,114,253,213,255,41,0,109,0,103,0,250,254,93,0,138,255,193,255,58,0,40,8,80,1,192,254,22,9,36,2,214,252,221,250,160,252,205,1,171,0,76,0,171,251,26,250,150,252,148,253,97,0,88,0,40,0,252,255,129,227,128,255,217,255,23,0,156,255,247,255,182,255,112,0,105,255,67,0,21,0,53,0,2,0,227,255,223,255,52,0,215,12,126,247,114,2,83,1,207,252,93,1,93,251,218,253,122,254,57,0,215,255,39,1,244,2,185,0,41,255,17,0,3,0,78,29,122,255,134,255,225,255,203,255,91,0,86,255,185,255,133,0,222,255,57,0,144,255,251,255,190,255,17,0,1,0,24,9,130,14,214,0,133,255,185,252,9,0,194,255,54,0,70,0,238,255,49,3,186,0,195,255,4,255,37,0,98,0,9,0,218,7,226,2,141,249,124,248,82,4,144,253,143,0,220,253,79,3,58,255,116,255,77,253,222,1,10,253,56,0,54,0,249,255,209,0,151,245,109,0,129,255,122,255,51,8,77,1,166,253,87,247,25,253,90,1,74,0,216,0,67,2,223,0,61,0,226,255,57,0,94,0,224,0,221,245,202,253,173,252,246,0,58,1,65,0,41,11,114,0,8,253,77,0,157,253,119,0,181,0,4,0,4,246,127,0,138,0,92,255,37,255,140,255,157,0,185,243,197,0,158,255,240,251,235,0,180,254,88,254,104,255,174,254,223,255,36,255,207,0,254,0,93,21,154,255,122,254,131,255,92,254,113,0,23,255,73,1,222,255,109,0,85,255,103,0,50,0,58,0,96,0,12,254,243,246,253,254,130,8,109,0,18,248,247,2,244,252,192,1,166,2,128,254,241,254,213,0,78,1,241,254,23,0,159,251,124,2,177,251,30,254,13,244,80,251,136,4,109,0,24,255,29,2,236,252,130,0,90,255,212,254,152,2,233,0,159,255,227,255,226,254,33,0,248,4,214,254,130,254,14,255,57,255,47,0,223,1,224,0,31,249,144,248,244,6,159,5,87,253,75,248,138,255,166,255,108,255,247,0,10,253,144,7,182,0,93,5,42,9,120,0,10,253,36,254,253,6,153,4,99,2,118,254,242,255,217,255,30,252,94,253,25,4,215,255,68,3,121,254,174,3,240,251,99,250,96,5,132,248,105,4,6,252,115,253,4,5,184,255,90,255,65,1,194,0,114,255,105,255,179,255,251,0,94,255,220,2,234,252,107,0,220,254,93,253,104,239,205,255,170,255,213,254,17,254,157,1,128,255,57,254,151,255,182,252,113,3,20,254,217,4,104,250,240,250,204,255,82,254,229,9,27,249,70,3,84,0,232,255,226,252,84,254,102,255,110,253,37,0,124,254,177,253,93,252,79,254,211,248,83,5,85,253,51,253,43,12,104,0,0,0,80,4,208,0,148,0,148,1,101,0,18,0,217,0,58,0,49,0,4,0,207,255,61,255,187,0,17,255,235,255,38,1,118,255,40,21,33,255,133,255,156,0,223,255,185,0,112,255,148,255,57,255,188,255,220,255,11,0,37,0,124,0,211,254,58,0,235,255,155,0,99,0,246,255,178,255,230,255,186,255,168,243,243,251,98,0,155,0,139,254,66,3,140,2,235,254,83,254,239,253,153,255,154,254,187,0,137,4,99,255,147,0,112,254,205,1,156,0,237,0,225,1,189,255,99,0,171,3,155,4,109,253,57,5,66,2,23,254,31,254,85,254,146,253,131,0,34,7,34,253,29,252,251,255,51,254,2,2,173,255,241,254,144,244,170,255,130,254,51,255,123,255,126,254,61,255,189,255,252,1,74,2,95,2,114,252,75,255,2,248,188,4,77,255,23,0,152,1,119,248,252,7,112,8,145,252,74,0,179,0,72,0,92,255,47,0,162,0,217,5,58,3,162,11,112,252,198,1,150,253,141,248,11,254,18,254,213,254,96,0,118,255,142,255,205,255,85,255,189,1,120,4,69,255,217,0,224,0,146,1,13,0,42,0,198,255,100,249,66,16,248,4,202,3,234,254,71,1,88,0,225,255,74,255,23,1,158,253,78,0,80,254,109,255,114,255,43,253,239,255,161,255,132,1,133,0,195,255,28,0,171,250,161,5,94,2,155,1,155,3,180,254,51,7,142,7,85,250,254,253,229,254,0,3,172,3,84,254,31,0,81,4,248,0,178,255,59,250,145,254,148,1,68,0,78,255,17,0,179,2,247,254,151,255,145,6,36,254,229,250,150,242,92,249,244,253,153,252,216,1,85,255,237,0,104,0,114,255,25,255,220,254,227,254,10,1,253,254,90,255,159,255,80,254,163,15,196,4,156,254,62,8,36,255,47,254,208,255,117,0,78,255,34,1,235,255,205,0,237,255,65,1,169,254,184,254,199,255,215,0,167,254,48,1,2,0,10,0,233,247,185,0,177,1,212,0,115,251,112,0,242,0,218,254,94,255,83,4,152,4,116,254,120,5,216,245,78,254,128,253,201,1,100,0,244,254,41,3,128,0,20,255,190,255,162,255,182,252,82,0,163,0,227,0,175,245,27,254,35,1,186,254,42,0,234,0,120,253,75,5,200,11,133,250,185,255,188,0,24,3,15,0,240,255,246,253,181,255,106,0,200,252,109,4,179,3,221,1,126,253,237,253,216,252,4,16,222,255,105,254,133,0,33,0,15,0,63,0,72,0,33,255,241,255,21,254,38,0,47,0,2,1,20,255,192,0,92,6,173,0,188,247,175,2,39,1,182,255,73,255,95,0,17,2,149,0,140,254,182,0,37,5,21,0,112,250,172,243,145,255,160,255,68,2,28,1,238,254,41,0,145,0,34,5,79,0,38,7,6,1,187,254,240,255,169,0,11,255,10,248,167,7,124,3,178,3,47,1,85,255,80,254,115,3,34,0,18,255,159,9,218,254,25,0,24,0,150,255,211,255,253,1,102,255,240,1,109,0,115,0,169,0,190,2,140,1,159,255,145,2,5,255,144,255,142,255,112,255,26,255,5,2,66,255,21,19,211,255,104,255,247,255,86,255,27,248,29,2,119,252,33,248,28,10,88,252,236,255,212,254,128,1,177,1,133,255,119,0,7,254,130,255,39,1,14,2,184,250,194,1,142,0,130,255,141,255,1,0,116,255,34,253,160,2,109,255,108,253,21,253,140,2,161,0,93,255,51,0,152,253,74,248,133,5,183,243,154,3,247,250,215,0,182,0,186,252,85,255,107,0,179,254,34,0,216,0,205,254,153,254,240,1,169,254,187,254,8,246,219,249,76,2,71,254,16,5,253,243,119,0,125,255,54,0,206,0,22,1,106,0,156,255,112,0,220,0,207,255,176,255,27,255,27,4,199,12,236,250,68,1,225,255,255,251,123,6,246,5,95,255,157,2,200,255,174,1,201,0,233,253,130,255,247,255,132,254,222,0,212,0,167,254,230,254,195,0,215,255,45,251,175,253,175,253,21,6,71,0,255,3,193,252,33,2,149,252,161,0,252,252,99,0,66,255,80,6,82,1,5,255,55,255,224,243,250,252,4,0,135,255,178,0,176,255,140,2,6,252,71,254,169,254,20,255,16,255,12,255,230,255,144,8,75,0,188,250,187,14,234,255,174,252,5,255,60,1,132,0,235,255,63,0,104,0,152,0,185,0,216,255,19,1,180,250,226,1,9,12,59,2,31,254,149,250,47,3,5,5,160,254,158,255,215,255,61,2,205,254,169,248,171,1,196,0,169,0,230,255,24,255,158,255,101,254,25,255,14,248,55,252,15,1,141,5,51,250,105,254,124,5,169,254,93,3,120,3,245,255,202,0,11,255,115,254,104,0,229,0,53,1,59,245,59,1,160,1,137,1,194,0,80,255,105,253,90,255,27,255,244,0,104,255,183,0,24,0,51,255,97,0,1,255,213,254,123,0,244,255,53,0,102,0,150,254,115,1,223,0,46,0,132,0,199,235,157,0,164,255,166,251,228,255,135,0,193,252,115,2,84,254,164,251,165,1,249,2,202,1,184,12,89,255,99,1,253,7,113,0,234,0,102,255,20,0,217,255,61,0,175,255,63,0,98,0,85,255,191,6,87,251,55,8,160,1,91,254,193,253,132,253,142,255,188,2,252,254,74,6,176,254,9,2,31,10,30,253,43,0,103,0,193,255,177,254,168,0,110,0,41,0,203,7,226,13,163,5,203,255,50,255,224,3,255,2,140,254,141,0,232,255,173,0,60,0,19,255,69,0,83,255,183,255,137,0,167,0,92,255,97,255,56,1,105,255,178,255,107,2,64,255,177,2,187,255,11,245,253,254,224,254,25,255,28,0,110,249,12,9,250,8,176,254,125,255,59,0,30,2,38,255,231,254,42,255,215,255,116,0,138,0,8,0,215,254,211,255,41,255,89,255,51,6,219,251,72,248,67,254,145,1,168,246,214,255,69,2,249,253,26,255,181,5,30,2,113,0,134,253,240,6,76,1,191,0,5,0,174,0,147,7,230,255,14,255,120,0,230,0,38,252,173,13,155,251,167,255,3,0,188,253,37,255,1,255,37,0,137,255,94,0,239,255,215,254,80,255,78,254,22,255,55,0,193,255,113,251,20,254,39,249,187,242,185,0,230,252,177,2,51,3,224,255,188,252,79,1,123,255,212,2,213,254,194,254,168,1,46,2,114,253,119,0,65,254,140,0,156,255,72,0,152,252,104,250,53,255,216,255,242,255,197,255,38,2,85,0,203,255,143,19,2,1,145,1,72,255,199,254,86,255,66,0,71,255,174,255,195,255,210,0,48,0,52,255,160,255,130,0,206,253,92,249,243,251,170,240,140,252,91,4,250,255,156,255,74,3,62,254,109,3,76,0,56,2,145,253,27,0,73,0,61,255,72,1,41,0,232,255,124,0,179,255,219,5,28,2,216,251,165,17,234,255,221,255,71,3,208,255,253,0,253,254,96,0,153,1,90,0,26,0,79,255,109,1,208,255,188,254,230,255,233,255,173,255,179,255,176,255,63,6,206,5,10,1,147,2,236,0,231,0,240,255,103,1,93,255,199,1,25,252,111,251,149,9,169,253,79,252,4,0,194,247,82,255,32,253,88,1,232,0,142,0,32,0,157,255,251,2,133,0,187,254,200,255,99,6,73,254,75,3,2,0,88,249,243,255,3,3,96,14,167,255,182,0,4,0,42,0,138,1,148,1,82,0,56,1,91,0,141,0,215,249,229,6,69,12,113,2,241,254,182,247,167,1,97,1,233,1,94,2,222,254,66,255,230,1,125,255,118,0,236,0,248,0,47,255,254,255,94,255,161,255,95,0,170,0,22,1,71,247,37,2,34,0,178,252,11,14,189,1,112,254,191,255,131,0,242,255,240,255,99,2,140,255,13,5,98,0,88,253,189,0,217,0,241,255,219,253,131,0,8,0,0,253,198,251,73,3,166,254,129,0,223,255,246,252,66,1,52,246,176,247,153,248,27,248,229,255,214,255,205,255,232,253,239,0,255,255,78,0,105,0,48,0,79,0,207,0,166,1,75,255,18,0,162,255,104,255,75,255,108,236,69,255,253,255,138,255,115,254,172,255,207,255,129,0,236,254,188,0,45,0,110,255,21,255,147,255,83,0,32,0,177,255,247,7,152,253,1,1,217,249,36,249,196,246,222,0,195,0,142,251,222,254,58,0,127,253,4,255,245,255,146,1,225,255,240,251,176,253,164,2,138,255,25,255,94,0,133,255,106,6,124,5,178,254,40,253,159,242,126,1,111,0,62,255,165,2,177,0,74,255,178,1,92,3,2,252,84,0,190,4,35,253,44,1,254,255,253,254,140,0,35,0,96,0,140,4,60,250,11,253,182,255,239,0,53,255,4,7,183,4,196,6,43,244,158,253,146,2,234,1,47,254,136,0,56,0,154,253,156,253,133,255,93,0,105,255,162,0,56,0,246,1,98,6,223,248,45,0,9,4,18,6,180,246,79,6,37,5,18,3,131,1,1,255,89,254,212,255,10,255,43,255,107,255,107,0,182,255,162,255,45,0,52,255,13,0,89,248,168,3,231,7,232,3,7,4,112,0,62,2,67,1,163,0,179,3,111,253,236,1,192,245,212,255,227,2,207,254,225,255,247,0,14,1,213,0,210,255,166,255,43,0,32,250,163,3,195,255,205,15,161,252,133,1,126,254,126,255,138,254,185,253,224,252,124,252,158,0,57,254,169,0,134,0,92,255,54,0,139,255,71,255,166,255,53,255,215,255,213,252,222,247,169,0,31,1,134,254,241,255,231,0,83,0,89,0,69,255,198,0,18,0,178,0,238,255,15,2,216,255,94,0,54,0,79], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1742385);
/* memory initializer */ allocate([0,252,238,248,0,162,0,162,255,105,250,225,255,0,248,139,2,207,4,4,254,191,251,25,251,254,2,137,6,101,1,13,0,211,252,157,246,179,0,42,254,65,0,173,254,154,0,9,0,56,0,246,0,66,0,252,246,163,5,77,252,24,253,87,246,32,251,143,255,249,3,160,253,149,0,74,255,41,0,244,253,16,0,29,1,244,254,243,252,199,255,166,254,194,0,0,1,205,255,107,0,28,254,66,255,131,255,123,253,231,1,58,1,74,0,213,253,12,252,69,1,76,0,233,0,51,255,67,255,208,255,15,238,134,255,10,0,121,0,165,255,108,0,207,255,254,0,130,249,196,9,87,0,252,249,56,255,31,1,183,254,206,255,111,254,182,0,236,250,177,2,147,3,32,255,0,253,215,1,173,254,133,0,151,1,168,254,99,0,96,0,111,0,200,4,105,250,21,8,230,254,127,0,141,1,137,255,52,5,237,250,232,2,233,253,32,3,71,1,106,3,188,2,88,254,196,249,85,5,117,253,105,255,113,0,102,0,232,255,208,1,125,0,143,3,209,249,140,254,235,2,2,0,173,1,209,255,192,255,34,0,164,6,27,253,87,1,216,2,30,255,97,7,78,0,253,253,11,11,77,0,190,255,108,0,3,2,90,0,179,8,90,253,21,5,50,252,122,0,41,252,53,9,64,0,57,250,186,0,156,5,11,255,204,0,204,1,191,0,91,253,177,254,56,255,121,255,150,255,155,255,88,4,83,245,127,253,73,0,241,4,255,250,204,250,25,253,163,2,129,0,136,251,111,251,75,1,113,255,169,255,41,3,133,252,176,252,246,0,243,0,97,0,86,255,36,0,171,251,102,0,31,4,141,250,104,5,131,4,183,1,243,249,212,254,235,247,246,3,187,0,242,252,212,3,53,252,167,254,185,253,190,255,118,255,195,254,132,255,48,0,104,255,158,255,92,0,142,9,128,0,48,251,100,8,175,254,153,253,211,1,37,6,155,253,89,3,47,1,166,1,196,250,92,254,49,1,142,253,94,0,16,254,126,254,127,255,243,0,27,0,56,255,163,250,188,5,8,248,151,0,93,253,65,0,184,5,80,254,33,2,13,1,2,254,72,2,113,248,202,3,193,254,185,5,234,1,7,1,43,2,0,255,207,255,59,1,14,255,118,254,200,254,168,255,201,0,135,255,210,254,172,0,49,0,234,0,59,0,71,1,155,0,199,0,69,255,215,255,182,255,52,0,225,255,197,255,58,234,135,255,26,1,87,1,131,255,56,255,193,253,48,5,155,0,120,248,250,0,190,2,21,0,98,245,103,255,154,255,83,8,100,2,176,1,208,251,55,254,222,0,171,1,144,0,149,0,79,254,219,249,57,5,118,253,176,0,13,0,7,251,24,1,17,253,20,255,197,1,204,0,197,249,176,244,240,254,233,0,229,1,82,0,117,255,240,253,116,255,113,254,200,255,238,254,177,254,176,0,12,253,243,0,202,8,207,254,209,2,175,6,7,0,50,251,202,249,176,248,119,255,54,253,7,1,149,249,106,1,246,254,80,255,64,0,220,255,193,255,175,2,29,254,48,250,197,2,161,3,69,5,35,251,133,2,173,249,223,2,117,253,58,7,7,4,159,0,143,253,70,3,242,0,116,254,115,254,215,255,213,4,48,1,81,0,162,255,32,253,66,2,255,4,40,4,81,0,108,7,77,255,224,0,10,1,83,254,222,2,244,1,227,3,142,252,27,6,21,7,249,253,246,2,20,2,229,255,27,0,197,1,2,246,191,10,72,254,176,4,43,4,43,253,20,254,76,2,234,0,47,255,148,255,26,255,223,0,25,255,21,255,124,255,205,255,88,0,222,254,42,255,157,255,196,255,175,0,242,9,33,252,139,3,190,1,123,2,28,1,195,2,238,0,220,0,204,254,3,1,8,0,77,254,97,247,49,250,213,249,46,0,29,1,7,255,154,0,142,254,37,0,42,0,244,5,195,248,113,5,180,4,126,0,215,6,82,0,136,0,107,1,149,246,242,252,128,255,206,252,24,255,253,2,83,255,129,255,220,2,4,1,155,255,100,3,7,255,34,1,32,0,133,2,55,0,50,249,203,251,136,1,200,253,117,2,104,252,13,255,23,3,164,253,149,254,117,0,176,250,241,255,11,255,185,241,54,0,215,254,10,0,124,0,11,0,166,251,201,253,42,15,6,248,160,251,214,255,142,255,110,252,163,1,51,1,44,0,21,1,155,255,173,1,170,0,187,0,240,253,63,253,92,1,237,255,180,0,180,255,91,0,187,248,75,255,85,255,36,3,38,253,222,0,72,255,93,1,191,0,131,255,14,0,174,16,45,254,240,254,29,0,40,255,212,0,170,1,34,255,11,0,240,255,172,252,101,0,64,2,178,0,95,1,135,2,90,0,179,0,87,253,69,255,77,0,19,16,48,252,42,253,199,2,251,2,60,2,114,251,210,255,67,254,153,255,135,0,38,1,44,1,10,0,225,2,130,1,113,254,163,254,204,255,17,21,149,255,224,255,27,255,102,255,75,255,82,0,188,255,243,255,179,255,48,0,75,0,117,0,206,255,254,0,233,0,98,0,75,0,86,247,90,247,211,5,64,3,225,0,223,251,11,1,27,2,171,7,11,255,159,254,198,1,82,254,202,255,21,253,198,255,74,254,166,255,192,255,21,1,214,0,151,255,209,255,235,250,108,254,101,251,170,2,3,240,252,2,242,254,170,254,145,254,158,250,6,0,173,255,173,1,142,1,61,0,107,255,180,0,31,0,169,0,38,255,152,0,185,255,218,255,45,10,167,2,81,255,235,253,251,6,99,2,228,1,190,254,158,0,207,253,125,0,221,255,214,255,66,255,17,2,193,1,157,0,223,243,106,0,168,0,248,255,190,255,176,255,183,5,112,4,185,18,158,255,80,254,26,2,111,255,241,0,98,255,105,0,140,254,39,0,96,255,92,0,33,255,81,0,245,0,114,255,94,255,89,255,215,254,207,255,158,255,70,2,198,235,106,4,241,254,55,2,5,255,55,0,231,1,209,254,31,0,231,255,87,0,186,255,154,0,233,255,35,255,70,0,208,0,48,0,119,255,46,0,59,0,247,255,139,250,54,252,224,0,202,2,161,0,24,0,205,254,15,5,187,5,101,255,7,254,247,253,12,255,247,1,231,255,35,252,80,14,108,255,12,0,121,255,218,0,97,255,100,255,255,252,91,254,41,2,203,2,185,2,75,255,146,5,169,1,217,255,153,255,50,238,171,0,91,1,161,0,170,0,128,0,46,255,221,255,31,0,125,0,248,254,121,255,156,255,125,10,26,255,14,8,82,6,157,255,150,252,158,3,245,2,124,1,148,1,183,255,30,0,29,0,206,1,213,2,123,254,10,255,20,0,150,0,22,255,198,255,73,255,10,0,156,0,226,1,24,255,124,0,115,0,180,0,153,253,117,254,74,1,171,255,77,254,207,12,213,5,174,2,133,4,245,0,213,251,95,248,23,0,28,3,228,253,175,0,56,0,117,248,89,0,193,2,170,254,39,2,49,248,159,7,255,246,15,254,246,254,19,1,33,250,95,1,157,254,159,254,236,0,154,254,241,254,216,255,136,0,217,0,243,255,211,255,213,247,117,4,218,2,160,248,107,4,148,2,247,4,183,1,37,10,92,0,63,1,165,255,62,0,60,1,31,1,252,254,121,0,223,255,139,255,234,255,177,255,86,255,92,255,206,5,134,0,194,255,220,255,217,242,21,255,197,4,215,4,78,0,202,255,23,254,12,1,208,253,250,252,83,3,51,252,194,255,82,255,118,255,53,254,134,1,234,255,214,255,83,0,59,5,27,5,206,1,72,241,255,1,44,1,243,253,237,252,167,255,163,2,230,247,37,0,208,255,252,0,86,2,180,254,67,0,69,255,2,0,150,255,221,255,108,255,70,255,226,253,31,3,59,9,101,255,103,253,205,244,47,255,56,255,176,255,146,6,58,4,2,0,4,2,31,254,20,1,255,255,36,255,54,0,244,255,3,1,161,0,108,255,54,2,47,250,37,253,238,4,243,1,208,252,115,0,217,15,185,255,189,2,39,0,124,255,33,255,240,255,229,0,254,255,216,255,195,255,234,0,149,1,108,0,48,1,194,255,116,254,89,5,98,250,3,248,162,7,247,2,201,3,90,255,21,255,141,255,188,255,131,7,23,7,248,252,169,252,34,0,193,255,17,0,87,0,223,0,111,255,126,255,240,255,199,254,88,249,54,254,180,254,164,1,52,5,164,2,110,3,249,240,152,254,171,1,25,2,139,2,89,255,61,254,59,255,21,1,136,0,55,255,5,2,10,0,100,255,35,0,97,252,226,4,83,255,236,3,87,255,66,1,116,255,209,253,208,237,169,254,248,254,195,255,244,255,195,0,246,255,133,255,233,255,236,255,250,255,145,254,154,255,41,255,41,0,70,3,233,5,40,2,183,249,15,253,5,253,112,253,135,253,14,0,35,0,141,0,117,0,135,255,89,3,42,250,66,2,242,9,10,4,92,253,59,2,49,3,38,255,145,255,144,5,205,255,110,3,212,244,255,254,104,0,242,253,14,3,196,2,46,9,12,254,170,254,219,0,106,254,68,3,139,255,32,1,97,254,30,3,14,0,201,254,57,254,3,0,102,254,112,255,226,255,47,252,111,255,94,246,67,252,90,5,127,243,185,254,171,255,149,0,188,253,198,0,94,1,140,0,152,255,71,1,128,255,78,255,58,0,38,1,50,0,22,7,69,2,115,252,31,1,245,254,104,240,61,0,164,252,2,1,241,254,33,255,237,0,221,254,253,255,66,0,110,0,148,253,63,1,194,255,177,0,108,1,110,0,93,255,103,252,161,252,251,0,58,19,24,1,121,0,128,0,209,0,130,255,66,2,200,255,41,0,124,0,94,1,245,0,47,254,189,255,5,0,139,2,147,0,200,0,0,0,21,0,159,253,180,254,253,255,247,0,100,254,128,0,42,0,131,250,211,254,171,254,28,254,21,254,201,255,105,1,156,255,226,255,107,254,131,2,153,16,225,255,165,255,246,255,6,0,169,1,162,254,35,250,49,3,188,250,55,255,167,254,197,241,235,0,179,2,76,1,219,0,199,0,114,254,130,0,206,255,66,255,89,0,233,255,100,0,47,5,56,255,146,0,226,1,144,253,33,254,121,254,188,0,129,0,102,2,177,254,204,253,253,3,149,255,57,255,145,0,201,0,59,2,252,4,157,16,58,0,121,0,39,1,38,0,26,0,47,0,203,250,114,4,53,12,101,1,184,255,91,1,20,1,240,254,120,0,179,255,23,2,247,0,185,255,250,247,188,248,183,255,194,255,10,1,226,255,183,0,17,0,210,255,249,255,116,255,229,3,14,2,209,255,197,255,4,6,117,1,162,0,106,255,149,255,182,255,234,254,219,255,172,16,235,255,243,254,103,1,111,0,141,255,251,255,50,255,169,255,212,255,251,253,54,0,213,244,189,0,215,254,161,252,106,252,95,252,225,253,25,0,206,244,177,255,179,251,237,254,102,254,54,254,181,255,45,255,92,254,96,0,211,1,190,255,241,255,188,253,92,254,182,253,249,255,109,0,236,0,227,0,24,254,106,0,2,1,76,0,78,0,248,255,57,255,232,236,122,255,51,255,223,255,13,255,237,255,246,255,157,0,129,0,120,0,96,252,92,2,167,254,209,255,82,254,255,254,17,1,81,0,157,7,234,1,16,1,51,255,156,9,202,255,103,0,148,244,239,253,45,255,196,255,23,1,220,0,199,255,86,1,209,0,216,3,126,250,221,242,252,251,235,250,243,250,227,0,118,4,212,251,0,254,246,2,108,1,46,0,154,254,16,0,1,1,98,255,3,255,74,255,254,255,181,0,195,5,38,6,215,0,56,252,246,0,113,1,239,254,51,253,34,2,74,0,224,240,37,1,98,0,130,0,12,255,41,0,143,0,187,2,200,255,130,255,67,0,54,0,254,255,146,252,30,9,115,3,215,0,69,248,246,0,9,253,243,1,248,0,239,2,54,255,68,2,54,244,103,1,117,255,210,0,209,255,88,255,89,0,109,253,3,1,202,255,216,255,22,254,87,255,255,252,57,2,85,255,64,0,179,252,7,2,227,4,185,255,53,254,172,238,1,1,178,254,198,252,73,255,115,0,104,254,179,255,32,2,173,0,254,254,48,0,75,1,199,6,11,4,233,10,130,4,147,248,19,1,147,255,95,251,109,254,52,5,230,254,36,0,145,254,21,0,27,0,106,1,87,254,217,0,150,0,208,254,192,0,53,0,180,251,27,0,116,2,186,2,134,253,231,255,84,0,8,0,153,255,21,2,211,254,218,0,254,16,119,0,147,255,53,1,24,0,160,254,109,255,238,254,156,0,85,0,9,0,170,6,170,252,220,7,219,249,112,0,95,253,254,249,165,255,159,1,11,250,98,3,213,5,147,253,116,254,21,1,164,253,149,254,114,0,152,254,4,255,238,255,225,255,179,255,177,253,179,9,23,2,16,250,223,251,115,247,205,255,30,3,20,1,110,250,72,0,209,254,146,1,111,0,71,1,16,1,248,255,40,255,189,0,2,5,152,0,211,255,223,255,244,5,253,8,171,254,200,7,171,3,142,6,243,3,114,0,167,0,74,2,12,254,40,0,39,254,238,254,84,2,213,4,130,255,205,0,254,0,228,254,145,254,137,255,64,0,123,7,181,1,183,253,1,0,146,1,241,254,40,252,18,2,11,1,50,14,239,1,37,255,40,253,189,255,196,250,215,3,122,0,6,0,110,0,90,255,111,0,102,0,117,255,61,246,241,2,243,3,219,6,28,251,104,3,2,254,204,248,108,5,242,252,31,1,205,1,36,0,77,0,181,1,151,254,40,255,97,254,158,0,179,255,133,255,57,0,163,255,80,13,248,1,82,252,178,1,120,253,5,255,92,254,125,254,93,5,27,255,236,0,65,255,3,0,204,0,100,2,137,1,227,254,48,2,92,255,57,255,47,1,146,0,93,0,224,4,121,9,233,3,237,4,17,255,61,4,170,248,137,254,224,253,29,252,64,255,193,254,30,2,24,1,52,253,213,250,189,255,222,255,252,0,220,255,206,0,130,255,228,255,26,0,145,251,239,10,15,2,209,255,40,248,253,1,24,255,71,252,76,1,126,254,148,255,34,1,251,1,66,2,215,252,119,1,82,3,123,250,63,3,119,255,3,1,25,0,205,251,151,1,248,6,253,249,122,6,170,5,55,252,211,1,4,0,17,3,173,253,144,3,34,0,91,0,30,1,11,4,244,253,20,1,190,254,11,0,139,2,221,2,243,0,45,0,111,255,101,1,12,2,71,253,253,254,11,253,223,251,181,0,44,5,148,0,10,254,192,255,133,254,22,253,105,5,139,1,184,0,19,253,59,255,209,242,222,253,252,255,20,2,242,254,175,2,245,1,29,1,145,1,175,1,160,248,129,253,143,2,187,254,104,7,165,248,53,0,6,252,61,250,34,3,26,254,188,255,232,0,57,5,172,1,232,0,218,6,105,249,250,253,140,254,252,1,11,251,71,1,124,252,44,254,103,4,117,5,61,6,69,3,147,2,151,253,99,0,8,1,52,254,40,1,44,0,217,254,47,255,82,255,81,4,128,3,41,4,82,255,5,0,77,3,31,5,90,5,12,246,95,1,108,253,232,255,191,251,237,252,224,250,234,255,183,253,59,255,237,2,37,1,144,255,87,255,233,255,3,0,127,4,17,2,149,4,224,0,19,250,162,3,204,255,12,1,254,250,209,253,210,1,240,253,226,5,25,255,175,254,225,3,222,250,6,255,30,244,57,0,19,0,15,0,20,7,185,2,123,254,55,255,135,2,45,253,182,251,79,255,31,255,122,245,17,254,81,254,18,255,132,1,61,249,229,3,227,0,3,253,34,255,94,0,157,253,35,0,187,0,89,252,66,250,245,3,27,4,134,254,55,1,58,253,202,253,236,253,143,254,193,249,41,2,167,0,194,1,212,251,18,11,131,255,89,2,143,255,9,254,40,0,14,0,220,255,36,255,249,249,99,3,156,253,214,248,120,3,1,249,16,5,27,255,175,253,8,253,59,255,172,1,246,250,124,3,194,255,89,4,52,251,59,252,166,255,212,254,32,1,123,255,11,3,69,251,141,253,12,1,180,0,145,3,182,8,99,254,110,255,39,255,170,0,123,251,241,249,109,3,75,0,248,6,82,255,26,255,11,253,219,4,113,2,207,255,114,0,38,255,103,254,195,0,115,251,212,5,213,0,76,4,155,255,67,252,248,3,151,2,64,253,49,3,94,0,233,254,0,255,213,1,181,255,133,255,118,244,180,3,105,254,19,1,143,29,17,1,12,1,182,255,201,0,18,1,107,255,110,255,250,254,243,0,239,254,63,0,129,255,135,0,96,255,231,0,120,0,209,0,165,255,38,255,218,255,74,251,44,254,97,255,22,1,24,2,29,252,196,255,22,0,17,4,218,253,135,255,15,255,104,253,171,1,96,254,141,250,36,253,152,0,175,12,189,255,102,255,130,246,165,1,107,254,210,253,183,255,185,244,240,254,196,255,109,1,233,2,31,1,146,253,177,251,156,1,10,1,82,0,61,0,132,247,133,254,17,2,131,255,54,250,63,1,131,2,222,0,4,254,147,9,54,252,71,0,237,0,232,254,202,0,215,3,33,255,205,254,126,255,217,0,137,12,49,0,226,255,19,1,244,255,252,254,137,240,195,4,152,255,116,245,55,255,54,0,83,3,178,253,179,2,2,255,152,1,40,1,208,255,148,254,216,0,16,0,220,0,97,254,218,0,83,0,43,0,64,240,177,250,25,0,15,0,233,254,212,247,26,3,79,254,61,255,94,255,94,2,166,0,87,0,196,254,252,1,242,0,153,254,175,2,78,255,14,0,103,244,12,254,239,251,162,12,167,2,170,0,233,252,129,255,138,253,240,255,237,255,181,0,254,255,71,255,84,255,168,255,138,255,89,255,128,0,121,0,239,0,65,1,131,255,217,0,164,227,99,255,95,255,165,254,255,254,102,0,99,251,71,0,133,254,51,255,244,254,144,0,82,255,150,255,49,1,23,0,209,255,202,0,146,255,148,2,54,0,109,244,137,255,165,250,249,244,147,4,42,253,178,2,22,2,161,0,77,254,241,2,58,0,227,0,241,0,138,0,180,255,217,1,193,0,122,248,121,247,34,246,108,250,28,1,10,251,80,1,78,250,208,0,41,0,156,254,89,1,153,0,239,254,90,255,244,1,42,0,120,0,221,255,175,255,56,0,211,6,22,244,19,248,4,253,77,252,120,3,166,1,118,1,143,0,194,254,31,255,92,2,87,1,165,255,90,6,75,0,45,255,160,0,101,253,61,255,38,0,66,254,11,251,148,255,65,252,152,253,238,253,42,2,49,11,100,255,154,254,83,254,251,254,23,0,255,1,84,1,220,253,43,9,105,0,12,0,224,255,164,0,170,0,88,255,12,1,27,10,183,13,100,2,73,1,159,0,200,1,17,1,60,254,168,0,118,254,31,3,198,255,160,0,32,254,255,254,242,0,167,0,46,0,103,250,161,249,50,0,84,3,253,1,96,3,131,254,206,254,70,253,5,1,66,253,237,255,17,16,218,255,103,255,245,255,149,1,71,254,136,255,139,0,247,254,225,0,86,1,199,0,37,8,237,0,22,1,252,0,1,6,119,0,182,0,82,255,63,255,182,9,87,0,87,11,201,254,208,254,17,1,39,255,0,255,248,254,93,253,205,252,68,255,153,253,97,251,239,1,102,255,81,253,119,9,197,0,193,255,110,255,127,4,128,3,151,251,198,255,90,4,148,249,195,4,120,253,185,255,126,255,173,245,21,2,38,255,102,15,173,255,208,0,44,253,198,0,125,253,78,2,80,252,200,255,92,254,115,0,23,0,98,254,112,255,39,1,219,0,220,255,137,1,82,255,91,0,34,1,102,228,158,0,237,254,186,255,137,255,255,255,46,1,250,254,183,255,195,255,110,0,60,255,231,255,87,0,66,254,97,255,250,255,149,255,115,0,118,226,5,0,223,255,28,1,150,255,34,0,116,255,160,0,208,254,240,254,87,255,25,0,93,0,51,255,28,0,169,0,91,255,222,255,206,255,87,1,156,8,160,5,49,3,127,248,178,253,241,253,81,0,148,254,158,254,163,0,222,251,185,7,244,0,181,255,177,4,49,255,37,1,223,254,151,255,135,255,4,14,157,3,254,255,55,255,164,252,149,3,100,0,9,1,56,255,212,255,239,253,95,1,189,253,153,255,186,0,218,241,52,0,181,0,253,254,101,254,252,255,184,254,124,1,5,2,50,1,57,0,84,1,191,255,249,254,201,254,238,1,70,1,8,232,235,2,115,255,40,1,217,0,254,255,131,255,8,0,168,255,254,0,138,244,253,254,178,3,119,252,141,2,180,1,65,13,109,255,99,255,27,0,166,0,43,1,8,0,240,255,131,2,114,0,217,0,57,0,235,255,214,254,19,0,129,0,185,6,122,255,33,9,13,3,29,254,20,253,118,0,182,254,30,255,78,241,222,0,95,254,102,255,232,255,243,255,114,4,210,0,101,1,134,255,1,1,143,254,95,3,13,0,192,254,73,254,79,254,141,13,155,252,116,0,44,245,202,0,41,4,126,255,225,254,142,0,224,254,54,0,62,1,131,0,240,255,84,0,238,0,151,254,166,3,61,5,37,0,130,0,100,254,146,0,44,253,253,255,201,252,251,9,17,251,11,0,109,255,92,12,173,255,217,255,129,255,2,1,26,0,99,251,11,13,92,253,226,255,200,255,179,2,99,3,203,2,121,252,37,1,51,255,120,254,234,255,17,2,180,255,153,8,177,1,134,0,58,5,238,255,85,0,56,12,33,0,156,3,1,1,126,6,255,252,65,1,63,254,138,254,198,255,171,253,122,249,97,0,222,0,26,252,148,1,101,255,133,0,102,1,6,255,131,255,163,0,139,23,28,255,140,255,195,255,146,252,75,253,198,2,252,253,65,255,229,255,187,1,83,0,82,255,73,253,139,255,149,255,203,255,114,255,92,0,111,255,142,255,194,255,58,253,136,243,152,252,212,12,247,253,220,255,76,252,252,0,3,255,113,255,4,1,109,0,232,255,6,1,87,255,60,255,195,0,105,0,27,0,121,255,186,6,70,7,255,253,242,254,112,255,98,254,197,255,91,0,224,254,160,255,200,255,52,255,17,1,170,0,85,255,194,255,127,236,131,255,189,255,206,255,226,0,237,254,88,2,105,0,39,255,62,254,169,255,236,255,159,254,24,0,182,255,167,0,89,7,92,239,112,255,48,0,92,0,187,0,63,1,85,1,22,0,252,255,149,1,147,0,237,0,136,255,122,0,19,255,56,0,253,253,103,255,77,1,66,3,145,1,210,0,116,234,7,0,127,0,147,0,116,255,33,254,230,255,123,249,235,255,109,255,60,0,131,1,53,2,116,255,61,233,243,254,161,251,188,254,118,0,57,255,245,255,105,0,207,255,150,0,108,255,178,0,182,0,162,0,150,0,68,0,29,255,3,0,221,0,182,254,233,255,65,0,118,24,71,0,48,0,215,255,246,255,255,255,212,255,1,255,206,255,118,255,147,255,202,255,225,255,236,1,42,255,239,0,62,255,35,0,52,231,108,255,9,0,25,0,133,255,84,0,64,254,241,0,148,0,221,255,52,0,35,0,7,0,99,0,240,255,57,0,213,255,0,255,8,13,117,1,211,0,255,253,24,9,86,0,238,254,130,1,74,0,82,255,112,2,243,251,126,251,36,0,47,255,252,251,155,255,100,254,153,255,245,254,149,255,130,255,163,0,118,254,183,251,156,255,217,249,226,253,254,12,155,247,35,2,114,2,234,254,98,254,243,252,230,1,70,255,97,255,138,0,69,255,203,252,163,1,137,1,86,239,60,3,175,1,86,0,233,2,33,5,204,5,4,1,52,0,163,0,57,254,209,251,186,0,10,2,32,1,165,1,18,0,97,0,243,4,200,0,77,10,67,255,217,2,234,2,203,0,129,253,181,252,116,8,159,2,84,0,176,246,174,1,95,255,148,1,166,0,223,255,239,255,79,2,29,255,247,240,43,6,175,0,50,253,99,0,102,254,180,252,17,255,32,0,212,0,163,0,224,1,75,3,133,254,147,253,195,254,88,254,113,0,250,254,44,0,163,255,17,2,144,0,38,255,140,0,185,12,193,253,119,245,144,0,173,255,70,255,212,255,209,3,153,0,26,255,6,250,234,0,212,0,212,0,75,1,156,1,131,255,253,255,166,1,183,254,123,247,126,5,107,1,166,255,170,255,73,1,245,254,146,238,67,255,169,255,154,0,66,0,56,255,37,0,80,0,147,255,57,255,125,0,191,7,4,1,74,254,143,246,187,12,50,252,197,1,41,0,179,255,230,253,99,4,119,0,120,0,254,0,17,255,122,255,33,0,128,254,105,254,27,0,209,1,18,7,114,252,212,3,241,255,229,250,105,252,88,7,185,254,209,254,58,255,149,0,157,1,128,8,221,8,61,253,87,1,104,1,169,0,148,0,182,0,104,0,163,0,89,3,35,1,103,255,47,1,89,253,126,254,156,252,235,8,192,254,167,0,185,12,205,6,82,1,211,1,209,0,207,0,66,3,30,255,33,254,136,255,138,6,195,255,184,2,163,255,209,250,128,8,204,2,146,1,152,6,171,8,173,254,11,3,110,1,102,1,241,0,73,253,240,254,120,255,208,255,36,0,243,254,94,3,152,253,138,255,20,248,142,6,179,7,115,0,34,1,71,0,3,253,31,0,198,244,122,0,13,0,88,254,231,254,192,254,233,0,248,251,40,0,70,255,184,4,18,1,250,246,198,249,33,1,230,0,240,4,194,3,202,254,23,0,220,253,12,0,218,255,82,245,152,2,37,0,90,1,148,253,10,1,158,255,82,0,65,9,195,3,145,250,61,254,65,3,82,0,175,0,192,1,82,7,89,1,72,254,155,0,130,0,94,0,70,1,151,12,234,0,93,255,128,254,158,254,229,253,59,3,247,255,18,2,30,255,235,255,76,1,6,247,149,12,190,5,230,254,224,252,231,0,58,1,26,252,229,251,120,253,78,254,231,2,184,255,119,0,91,0,158,1,123,1,90,5,131,253,26,252,83,3,168,244,246,254,140,249,180,250,197,250,113,249,75,255,245,0,219,2,25,255,254,255,221,0,74,255,187,254,101,254,90,1,246,0,187,245,200,6,151,254,24,0,229,0,144,4,235,2,53,1,169,1,128,255,192,254,16,254,109,0,216,5,186,255,227,252,37,0,241,254,217,255,138,3,194,255,62,255,217,6,55,1,177,2,74,5,245,251,51,252,74,254,142,4,149,8,157,255,132,254,238,254,227,249,191,1,100,0,93,1,229,1,141,2,232,2,50,0,186,253,133,255,140,250,156,0,229,255,93,1,213,251,154,250,108,5,219,251,214,253,126,3,176,255,241,252,36,250,32,253,129,3,134,4,150,250,216,255,232,254,205,252,96,253,129,252,226,3,204,254,46,254,190,253,199,1,0,250,111,3,64,254,30,2,228,5,82,3,95,246,48,3,129,2,85,254,54,1,88,255,215,255,116,252,210,254,233,5,227,255,136,251,76,2,89,249,120,4,63,10,90,0,28,1,98,3,79,1,161,254,163,1,23,253,111,3,73,255,200,252,79,249,222,255,241,255,111,252,37,0,52,254,10,3,82,8,111,255,103,255,225,6,140,5,13,255,224,255,147,252,140,0,68,253,100,2,251,247,65,1,178,255,91,255,200,0,14,2,22,252,128,8,2,252,156,5,42,1,235,255,158,250,3,2,48,1,206,3,186,6,6,8,149,2,169,1,26,1,215,1,182,1,70,0,169,0,51,6,228,247,216,255,66,253,8,1,110,255,37,250,161,252,17,249,221,251,22,254,92,0,119,2,86,251,249,251,79,1,1,1,237,250,241,0,242,254,187,254,190,254,219,255,0,0,83,253,129,3,216,3,115,252,20,6,1,5,87,5,11,251,201,249,159,1,124,251,138,254,146,255,16,6,73,253,74,0,89,255,39,254,141,5,157,253,175,0,241,5,42,5,180,1,177,7,237,252,17,4,38,253,170,253,188,0,230,252,237,253,106,247,195,254,245,255,248,255,105,254,198,0,100,251,117,249,174,0,213,3,211,1,107,255,134,252,7,1,6,4,135,255,99,8,121,255,183,7,134,253,175,1,18,255,73,253,58,5,84,255,110,0,147,0,178,254,42,253,65,0,151,252,155,2,229,3,162,251,173,254,144,0,68,253,23,5,49,255,159,253,175,249,3,253,71,3,249,1,220,255,198,255,178,244,226,0,12,232,250,254,239,254,30,251,191,253,216,3,82,254,102,254,48,254,65,2,190,253,78,255,224,255,113,1,144,253,11,1,188,255,218,1,32,254,31,255,166,0,103,254,181,1,25,18,98,0,232,249,48,254,155,252,103,0,193,0,205,1,72,0,36,1,11,255,78,4,161,1,187,254,205,1,74,0,43,0,136,255,43,255,77,1,160,0,44,254,44,255,31,0,175,255,116,25,182,0,201,0,44,255,190,255,207,255,246,254,148,0,148,255,98,0,210,255,245,255,197,255,236,255,236,255,28,9,218,254,208,253,198,0,121,253,209,255,130,253,219,240,11,0,66,3,35,2,47,0,237,9,130,255,251,255,146,254,83,1,3,0,2,0,190,255,60,0,242,253,146,3,65,1,110,253,21,14,59,0,168,246,113,253,128,1,7,3,110,1,71,1,100,1,130,1,239,2,137,254,38,0,51,255,241,255,70,254,44,255,39,251,121,7,91,254,13,253,45,0,155,249,220,255,125,246,224,5,32,251,5,253,104,253,133,0,133,255,46,3,241,0,13,255,66,254,66,0,125,255,43,255,244,7,14,5,166,247,165,2,238,251,253,252,38,1,115,1,218,1,85,0,123,5,198,245,34,254,231,253,19,1,198,252,93,1,84,0,8,1,240,254,195,255,63,253,175,0,52,252,100,3,25,0,87,16,113,3,129,253,191,252,11,253,217,251,33,252,255,254,119,255,149,253,227,254,58,254,77,0,87,255,60,1,211,255,10,17,53,255,172,247,88,254,204,252,9,254,84,1,84,1,156,253,136,2,2,0,170,254,81,0,118,2,18,250,235,0,216,0,210,0,153,2,231,0,130,0,145,252,38,0,163,2,120,255,208,255,28,2,22,255,104,255,87,255,143,233,218,254,232,255,8,0,127,255,248,255,52,1,242,255,240,255,147,0,62,0,70,0,248,0,34,248,76,0,66,255,184,254,149,248,159,254,116,255,68,3,147,254,144,255,151,240,32,253,211,1,254,254,89,2,105,2,74,0,62,0,138,1,180,0,127,4,214,252,36,0,201,1,150,1,75,0,248,255,116,236,31,9,148,255,133,255,43,1,177,254,112,0,13,254,244,254,71,255,205,1,208,0,218,255,92,255,252,2,8,254,16,1,245,18,140,1,9,1,147,251,79,254,1,3,54,254,237,3,133,2,81,0,84,255,129,1,200,255,126,255,119,254,128,0,183,255,31,0,246,7,127,0,76,254,123,0,35,246,26,1,64,254,23,254,217,254,242,255,85,0,50,254,207,255,6,1,163,255,238,0,108,255,143,240,98,254,253,254,33,0,132,252,203,1,118,247,60,0,188,1,158,253,76,3,26,254,213,254,219,0,79,254,19,0,97,251,20,1,227,255,132,1,255,12,102,0,110,252,35,255,230,1,132,252,218,253,190,0,151,0,115,255,176,254,194,0,14,255,32,255,149,1,111,3,64,6,93,1,222,247,218,255,254,253,18,0,10,242,161,0,114,255,218,255,233,248,28,2,228,0,33,0,164,0,50,4,4,0,234,254,198,255,245,15,217,254,229,252,31,0,238,1,43,2,6,255,22,0,54,255,200,254,92,0,109,0,18,255,64,254,146,253,25,250,6,239,95,254,62,253,37,0,133,4,160,255,57,255,197,255,29,1,213,255,39,255,234,255,161,255,103,0,194,8,244,0,45,0,182,255,249,255,110,1,177,255,153,254,226,254,188,0,242,255,34,0,49,0,245,0,148,255,172,255,88,0,179,254,40,255,177,255,15,0,178,233,220,255,154,255,216,253,43,255,248,255,156,254,3,2,212,0,247,254,80,0,60,1,117,251,207,253,251,253,54,253,137,254,176,239,73,0,102,253,149,254,228,255,224,4,188,255,222,1,88,10,130,2,58,253,213,253,24,253,90,255,24,253,172,253,138,0,243,1,59,0,197,1,185,253,222,254,245,255,208,255,78,16,4,255,182,255,178,255,194,255,193,1,247,254,206,252,155,254,171,0,255,253,72,0,106,0,211,255,137,2,145,0,182,21,196,255,120,255,69,0,84,255,122,255,190,255,188,255,100,0,171,2,85,254,27,3,105,254,89,1,66,19,186,252,105,1,23,1,66,255,173,0,171,254,247,255,210,2,127,1,116,255,123,0,243,254,154,0,31,0,79,1,47,254,55,1,46,0,183,17,125,255,90,0,151,0,31,1,245,255,242,253,154,253,51,247,191,254,163,255,218,253,128,255,25,0,47,1,117,255,19,0,0,0,73,243,95,255,20,1,103,0,11,255,253,253,48,3,238,251,87,250,157,6,141,253,7,5,187,252,41,253,176,255,34,254,175,254,116,0,1,0,242,254,201,253,201,254,105,254,136,249,40,255,196,0,188,11,227,254,247,253,230,5,26,7,112,5,42,0,212,255,12,255,163,254,191,3,73,255,25,0,58,0,43,0,167,254,202,254,0,224,172,255,55,1,196,255,164,254,125,0,33,0,177,255,118,255,88,0,138,0,135,255,219,255,45,255,138,255,114,255,219,255,124,255,181,0,162,0,113,250,245,6,131,242,237,4,134,0,158,2,194,4,249,2,36,1,110,255,199,252,160,2,225,2,37,1,177,1,245,0,120,254,46,0,86,2,1,1,22,255,79,251,206,2,59,238,195,253,72,253,32,255,171,255,75,0,244,254,244,0,25,7,85,1,90,255,180,1,126,254,33,251,22,0,144,255,201,255,61,254,106,0,132,1,224,255,2,255,160,246,139,254,124,3,78,1,238,239,205,254,149,255,196,254,41,0,42,255,109,254,200,255,43,254,10,255,120,0,19,255,10,1,43,0,185,12,171,240,35,1,239,0,240,2,101,254,162,0,181,1,159,0,0,1,37,0,71,0,177,255,120,255,37,254,124,0,48,255,40,255,11,255,16,0,40,0,53,254,32,239,84,1,74,250,146,3,10,0,234,1,180,1,162,0,15,1,18,255,218,255,171,8,25,0,115,255,149,1,107,0,235,0,26,1,201,255,249,255,155,242,53,2,185,251,90,253,187,7,233,0,150,252,80,2,38,254,168,2,146,1,30,253,21,0,18,1,191,254,143,2,164,254,222,253,254,1,62,0,23,0,114,18,60,2,167,1,0,255,217,1,216,4,27,252,125,252,203,255,183,255,76,1,122,252,253,252,177,254,0,0,1,3,181,253,80,2,65,253,168,253,179,255,162,255,49,255,24,3,123,255,10,253,244,1,242,255,74,1,22,0,231,254,172,234,152,0,95,2,81,1,217,255,138,255,176,255,205,255,228,0,65,0,250,255,28,2,69,242,80,249,63,254,99,255,92,255,61,255,137,249,251,250,90,0,251,253,140,255,11,0,122,5,94,255,192,255,153,255,46,0,46,1,37,0,71,0,87,11,136,11,12,3,25,254,215,254,86,254,143,254,150,0,127,255,23,255,45,3,103,6,190,0,54,1,201,254,64,1,94,0,9,255,204,5,224,255,70,0,36,255,48,2,116,1,54,0,205,0,96,0,17,242,88,253,147,6,183,246,17,0,36,2,246,254,1,1,144,2,75,1,205,0,135,255,210,252,139,0,70,1,142,254,113,2,243,7,50,3,7,3,115,251,215,255,94,239,41,0,85,4,216,3,139,252,213,255,198,254,204,0,204,0,95,0,151,1,161,254,101,0,133,0,95,252,131,3,250,255,128,1,79,255,182,254,240,0,90,0,78,0,194,254,57,254,251,255,147,254,195,255,176,255,184,255,14,237,174,254,128,254,30,0,181,0,95,245,1,253,145,12,197,1,30,255,186,253,27,1,135,0,153,255,9,1,238,1,92,250,136,255,70,0,48,252,189,255,166,255,148,2,110,1,159,253,32,0,205,0,73,0,51,0,90,1,250,255,136,255,246,255,44,1,32,0,14,1,139,0,201,255,197,1,80,22,97,1,111,255,176,0,88,255,216,0,205,0,226,255,208,254,61,4,221,0,208,1,86,254,126,6,139,250,166,251,45,1,222,251,225,13,124,254,231,2,184,2,131,252,216,254,199,255,2,255,5,255,78,255,161,1,82,0,36,252,18,242,123,8,224,250,70,252,233,255,187,250,224,1,54,2,24,0,125,253,220,254,188,255,47,1,73,0,175,255,40,1,7,0,115,1,94,0,182,6,242,1,250,252,89,3,246,3,102,1,180,1,210,0,103,242,54,255,96,254,59,0,195,7,137,0,36,254,32,0,141,253,193,0,112,1,253,255,222,254,37,244,160,254,57,254,159,253,81,255,251,255,168,253,75,255,7,255,9,246,226,0,105,0,7,255,59,7,170,255,77,251,214,0,199,255,7,254,246,253,9,255,102,255,216,255,239,255,245,253,77,1,15,249,158,254,224,249,92,242,8,4,41,6,90,0,153,0,22,2,150,255,230,253,102,0,3,0,58,255,157,255,233,255,67,3,167,13,181,251,44,0,220,2,162,254,158,3,40,254,21,2,249,5,54,0,180,252,15,5,61,2,158,1,233,255,185,255,23,1,133,252,31,1,126,0,176,5,205,3,200,1,72,6,122,253,36,251,196,1,139,2,182,2,87,3,21,255,9,254,233,2,224,253,72,242,118,255,166,2,217,1,220,0,239,254,247,255,9,1,174,248,141,1,172,4,28,1,61,252,42,1,62,1,251,246,94,255,66,1,30,251,240,255,20,252,251,255,240,10,192,255,72,0,30,254,94,255,100,254,150,244,6,3,177,254,238,0,136,251,122,255,148,5,46,2,177,7,109,253,134,3,94,249,25,3,166,252,155,253,230,3,253,0,176,254,164,254,176,255,139,255,248,254,99,1,40,3,16,3,209,253,238,7,160,7,12,255,150,251,38,252,91,7,147,4,19,254,186,254,144,252,28,10,13,255,52,255,194,0,84,255,191,255,234,7,168,1,75,2,195,254,246,9,167,253,203,0,99,253,219,1,92,253,44,250,27,0,41,0,202,251,213,254,138,253,177,0,92,255,83,254,10,255,155,254,167,4,157,252,173,250,85,6,146,255,148,3,217,0,11,251,110,2,78,254,167,251,120,3,215,255,252,3,18,249,46,0,80,0,29,254,132,252,195,255,40,254,193,0,64,255,208,7,153,255,228,2,33,255,189,9,166,1,204,9,181,254,214,1,47,251,47,0,83,2,27,3,47,254,192,254,93,255,128,0,6,0,47,255,91,2,24,2,96,254,81,250,169,255,89,251,158,255,231,254,235,3,141,5,132,1,139,4,134,251,175,255,213,254,214,9,208,251,207,0,69,254,250,1,36,255,166,254,98,0,71,8,96,254,36,247,14,254,109,0,194,250,177,254,101,4,56,253,156,0,192,251,212,247,140,4,12,254,113,0,239,255,39,2,57,255,6,1,229,255,76,253,139,253,204,0,88,250,186,249,238,249,33,1,126,1,77,253,205,4,158,1,46,249,82,251,89,4,126,254,54,1,74,5,244,255,228,254,199,253,46,0,210,253,215,5,172,0,125,252,105,2,59,3,147,254,100,0,240,3,136,0,63,8,10,0,16,9,221,254,108,1,111,254,104,254,240,253,156,253,127,0,194,4,128,254,129,0,189,249,182,1,5,4,232,9,106,255,104,250,168,252,44,4,5,3,6,253,216,252,164,2,75,253,148,1,145,0,4,0,27,0,108,255,194,254,5,252,235,254,124,5,112,3,145,251,93,3,135,3,227,2,47,1,139,0,126,7,72,252,33,3,206,254,121,246,253,255,186,1,178,253,246,251,178,0,174,1,153,0,61,7,205,7,230,2,209,6,160,253,19,255,160,0,11,2,182,3,82,0,68,250,200,249,39,3,207,2,106,2,63,1,57,0,235,0,31,1,64,5,206,255,68,1,74,255,147,254,131,254,135,254,197,7,147,0,195,253,222,4,233,6,39,254,78,255,193,3,239,250,18,253,108,250,34,251,21,3,158,0,100,2,17,0,220,254,29,255,114,255,64,0,51,0,240,255,211,254,225,254,196,255,108,254,245,254,109,0,148,255,189,0,74,254,48,0,95,0,61,236,214,255,229,240,64,254,154,8,129,0,156,255,137,1,37,0,245,254,100,255,23,0,238,254,222,0,33,0,65,255,104,0,116,255,206,255,228,255,108,255,75,255,234,255,6,0,233,1,225,3,52,245,167,4,251,252,13,3,52,254,75,3,179,255,119,250,134,1,124,0,53,255,205,0,150,2,240,255,57,2,61,252,97,2,101,255,64,0,219,254,89,10,27,246,70,0,40,254,30,254,60,249,235,0,251,255,27,254,116,0,79,255,152,255,58,1,157,254,118,0,25,0,153,3,29,1,130,0,162,255,77,0,121,0,44,4,77,254,127,5,191,1,85,254,184,251,11,253,2,1,19,0,164,12,190,2,106,1,96,252,164,254,106,255,240,252,81,253,124,254,80,255,218,255,16,0,242,255,249,3,111,3,167,3,0,5,246,3,171,255,0,255,153,255,200,242,96,252,56,255,106,254,81,255,48,1,202,255,195,0,178,255,164,2,156,254,89,255,91,255,200,255,195,243,156,0,85,255,84,253,70,253,121,255,230,0,226,255,32,0,30,2,167,7,132,255,180,255,162,0,182,0,82,255,243,3,159,255,166,2,10,0,188,0,30,0,62,4,250,254,99,255,250,0,241,0,233,0,184,253,204,12,78,8,206,255,49,255,125,2,72,254,75,1,78,254,251,0,245,254,13,1,120,254,68,0,12,255,8,0,160,3,59,3,184,251,203,254,156,254,137,254,124,243,166,1,183,2,2,0,240,0,83,2,129,2,70,2,86,1,42,0,7,0,27,2,192,255,140,255,82,0,16,0,26,0,120,255,134,255,142,255,74,233,22,0,240,254,10,0,113,0,186,0,90,254,161,255,53,1,52,1,138,255,48,255,52,0,81,255,12,0,150,255,250,255,20,0,58,0,165,23,155,255,236,255,10,0,70,0,189,0,57,0,245,255,210,0,83,0,239,0,250,255,177,255,23,255,197,255,31,0,226,255,194,255,64,0,218,255,25,0,178,255,54,255,41,255,141,255,197,5,255,0,101,0,241,245,186,0,68,12,210,255,211,255,53,0,73,255,167,255,100,254,183,0,34,255,50,0,19,255,96,0,35,0,148,6,247,253,87,255,76,254,217,254,110,5,5,1,27,0,163,0,96,1,68,0,163,241,12,0,54,1,169,253,75,1,138,0,179,254,243,254,126,255,212,255,242,255,9,1,142,253,2,1,197,255,31,0,239,255,222,0,246,255,148,254,24,1,73,255,21,255,39,255,73,0,189,255,114,0,196,0,244,235,13,1,159,0,250,255,220,255,8,255,18,1,184,254,152,10,119,254,203,10,251,1,146,255,90,255,172,255,184,255,169,251,237,255,114,1,25,0,5,0,156,0,224,255,237,0,199,255,150,255,234,255,114,1,27,255,75,4,201,16,152,0,72,0,200,255,91,1,64,0,11,254,199,255,178,0,175,0,242,255,172,255,142,253,43,2,155,0,20,0,181,255,20,0,223,255,2,255,131,255,247,255,150,0,91,0,249,255,211,255,239,0,147,255,72,0,190,255,84,255,45,255,175,23,51,255,171,0,181,255,50,0,181,255,22,0,109,0,21,0,198,255,58,0,151,255,80,254,54,1,198,14,238,255,209,251,19,0,20,0,175,5,81,1,255,254,224,254,204,255,7,2,43,0,80,0,81,255,38,255,9,0,176,0,228,255,94,254,200,0,254,253,95,1,119,0,224,232,160,255,223,255,223,254,74,0,26,0,120,0,219,255,113,0,47,0,111,255,239,255,78,1,46,0,47,0,19,0,18,1,172,0,159,0,108,254,79,12,104,254,209,253,219,3,78,255,253,0,166,255,14,254,174,5,159,4,136,1,250,2,220,0,73,251,36,255,187,255,171,255,22,0,108,6,66,7,213,2,60,4,0,0,255,254,34,1,176,6,105,255,68,255,122,254,126,2,185,254,119,247,190,254,164,251,106,255,120,0,116,255,198,0,162,0,173,255,41,5,232,0,242,0,204,255,56,254,10,3,224,254,65,0,127,9,37,0,85,0,23,254,94,3,216,10,4,1,184,255,24,3,100,0,17,0,46,255,76,2,49,0,88,2,246,0,254,254,128,0,205,255,20,254,117,254,23,254,50,0,68,235,189,255,58,1,124,0,46,0,68,255,192,255,155,255,51,0,233,253,108,0,56,0,252,255,65,255,101,252,229,1,66,2,40,5,228,0,233,253,54,1,227,0,139,1,95,250,100,10,226,0,120,254,221,0,82,253,213,6,81,255,120,252,197,253,127,255,154,0,62,10,97,2,9,255,16,255,131,252,98,0,35,1,27,247,155,1,4,1,96,255,13,8,53,255,75,254,103,1,21,0,155,255,19,0,49,0,15,0,158,255,82,0,3,0,213,253,164,0,104,255,198,255,38,0,175,0,73,254,219,255,68,0,235,255,75,255,76,234,229,255,8,0,48,0,21,0,105,255,125,1,3,0,104,255,182,255,202,0,227,255,71,7,177,6,102,252,72,248,39,2,14,250,13,2,140,255,146,0,62,249,18,255,184,255,73], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1752625);
/* memory initializer */ allocate([255,126,0,234,0,16,255,82,0,138,0,196,255,125,255,78,247,226,0,66,253,183,0,175,255,206,1,221,244,117,250,19,252,124,0,175,255,4,255,191,255,147,0,198,255,77,255,50,1,154,0,122,0,187,255,69,0,11,0,115,0,40,1,12,13,11,254,236,245,220,252,9,0,79,2,170,255,88,0,127,0,76,2,183,0,48,0,79,0,218,255,57,255,63,0,116,255,29,0,88,0,228,255,3,1,69,0,207,6,237,253,110,0,238,255,8,3,238,255,79,255,112,0,36,0,13,255,48,255,16,2,209,255,101,18,107,0,131,255,140,0,255,255,22,0,15,0,160,1,62,255,245,254,207,255,43,0,253,255,204,254,214,0,128,255,140,0,252,20,133,255,70,0,19,1,210,0,182,0,109,255,125,255,172,255,69,0,116,0,29,0,111,254,94,255,20,255,83,255,122,1,45,0,244,255,179,255,191,231,153,255,126,0,54,0,237,255,236,255,43,0,64,0,92,0,248,255,244,255,118,0,133,255,58,0,212,241,98,254,157,247,76,0,95,0,157,255,101,1,246,255,22,1,4,0,160,253,248,1,105,0,184,255,147,255,164,255,201,255,111,1,89,255,40,0,222,255,76,0,220,0,106,13,146,254,191,0,248,0,29,0,187,0,79,255,155,0,164,254,171,254,94,246,16,1,120,255,254,1,139,0,81,0,184,0,33,0,213,254,92,0,212,255,110,254,185,253,43,253,112,254,97,255,239,2,31,255,121,1,96,255,20,6,164,245,173,2,203,251,252,4,76,1,255,254,87,250,230,254,25,255,111,255,58,0,173,0,165,1,15,1,145,1,70,255,79,0,254,254,127,0,252,0,214,0,96,0,157,0,195,0,205,0,118,0,93,237,161,255,92,255,217,0,221,1,205,255,252,255,8,0,170,5,205,255,204,255,184,3,163,2,161,3,239,254,219,1,9,0,26,1,7,255,236,0,234,2,129,250,240,254,53,7,180,2,151,255,130,10,168,0,1,0,255,255,157,0,169,253,49,1,255,0,52,247,45,0,57,255,119,0,95,242,95,255,6,0,249,254,253,254,82,1,5,255,61,0,153,0,132,255,176,1,249,255,131,0,5,0,49,1,190,254,45,243,224,255,176,254,239,254,195,8,95,3,255,255,169,2,147,254,10,255,104,255,119,1,123,255,241,255,48,255,152,255,89,0,128,0,121,255,44,0,1,255,37,2,65,245,208,255,14,1,232,245,219,253,137,253,189,1,182,0,58,255,231,2,41,255,196,255,112,254,103,5,167,0,191,255,250,0,146,0,185,0,22,0,28,254,95,255,86,0,222,6,196,3,148,1,242,245,2,4,6,0,252,253,44,253,59,1,157,248,55,1,2,0,83,1,217,255,68,1,43,1,15,254,244,255,179,0,38,251,108,1,71,255,59,255,62,250,232,0,22,254,202,15,151,255,119,3,31,0,27,2,235,0,75,0,144,255,56,255,225,255,74,0,180,255,240,255,236,255,38,0,97,255,113,255,114,0,179,255,146,255,28,0,238,255,172,255,229,255,203,255,174,255,32,255,75,0,0,0,210,255,192,255,44,0,144,255,84,0,171,255,114,232,232,255,149,2,38,254,78,255,8,0,1,252,116,254,199,0,237,255,206,255,163,255,129,1,209,0,53,251,188,9,115,8,218,3,177,250,143,1,80,3,169,2,195,252,211,0,184,2,169,253,138,250,159,7,143,255,118,1,239,255,167,251,84,249,14,5,154,2,238,6,111,2,3,1,105,0,193,3,169,255,43,0,49,254,65,0,155,0,230,255,225,255,59,250,4,254,67,4,73,250,244,253,195,248,74,5,178,1,86,0,125,3,153,252,151,0,161,248,205,0,167,1,89,3,201,255,245,255,217,255,85,1,61,0,134,4,90,10,131,3,69,246,175,253,181,252,137,250,241,255,55,253,85,255,61,255,245,253,210,255,243,0,117,0,241,0,248,255,140,0,107,255,65,255,70,0,134,0,122,251,141,7,111,4,20,247,231,251,181,6,122,1,101,255,219,255,171,0,76,253,232,254,150,3,238,252,133,255,46,2,59,2,39,0,197,254,62,0,27,0,59,0,196,2,122,255,56,255,88,255,122,255,148,0,114,255,25,0,164,0,230,254,28,1,161,255,221,255,120,1,165,0,111,1,177,254,15,1,249,0,88,238,176,0,220,255,40,255,233,250,119,1,92,0,90,2,135,252,122,254,28,1,78,0,218,250,235,4,73,7,218,5,15,8,22,255,184,252,121,254,88,0,168,0,21,255,182,255,31,0,17,255,197,4,71,0,155,249,233,5,68,0,153,8,233,5,181,251,146,253,170,1,87,1,182,254,120,253,125,1,100,255,27,0,225,255,164,255,133,0,210,0,103,0,101,255,13,8,146,254,107,251,225,255,238,254,55,253,41,254,253,1,20,4,208,0,147,1,230,1,190,255,247,253,165,248,76,255,231,253,3,5,158,255,72,250,56,254,252,1,149,253,222,253,173,2,176,3,171,255,55,1,148,4,62,255,126,5,157,255,197,252,226,5,140,1,196,0,2,250,99,251,52,6,226,4,47,0,10,4,85,255,33,251,158,255,136,255,157,4,109,247,128,254,177,3,115,2,26,0,8,255,92,5,97,253,214,0,119,253,239,255,212,255,12,254,209,253,65,2,167,253,32,0,165,1,19,2,88,1,47,251,145,0,92,1,102,2,208,253,12,255,155,254,54,255,46,3,18,254,240,246,52,1,27,247,31,254,250,253,81,254,173,252,43,0,52,255,230,255,26,253,59,4,126,255,210,7,106,6,124,251,210,6,239,253,169,3,224,253,160,1,27,253,251,2,24,255,253,1,243,0,54,254,78,0,126,255,143,0,133,255,71,0,102,253,151,255,31,0,219,251,185,1,208,255,155,1,245,249,155,0,38,253,183,1,88,6,105,3,157,253,42,254,44,9,99,255,160,4,166,2,82,255,30,2,161,255,244,255,107,254,237,0,66,1,86,251,111,7,216,5,101,1,222,255,107,253,0,252,188,8,92,3,0,255,105,2,244,2,27,254,239,254,179,253,24,2,214,0,226,254,14,3,162,1,90,1,50,254,187,1,32,4,110,252,208,254,204,253,180,254,31,7,31,8,93,0,49,252,133,252,191,251,48,253,153,251,190,2,44,1,19,3,118,1,178,255,46,4,179,2,59,5,227,252,57,0,226,1,176,1,236,2,2,6,161,2,93,7,8,254,121,7,66,255,121,255,113,3,117,255,84,0,123,1,80,255,127,255,181,254,222,255,78,253,26,1,205,253,51,0,71,0,54,253,153,255,50,4,117,253,186,253,108,5,192,254,165,251,11,6,192,251,191,255,182,245,55,255,115,253,116,0,18,255,38,255,220,1,137,5,135,6,111,4,255,251,102,2,106,253,127,0,95,3,139,255,214,2,53,252,102,5,226,254,209,1,171,4,53,253,94,3,24,251,105,0,37,0,90,251,70,254,15,249,50,0,162,0,41,6,68,2,250,2,253,0,92,0,204,254,42,251,95,255,39,1,106,255,197,6,39,7,241,253,241,253,228,255,70,0,153,254,202,249,92,3,35,255,47,0,79,251,2,255,39,0,12,3,186,254,73,4,5,252,66,3,106,1,101,1,41,0,181,2,181,251,129,245,102,2,14,1,128,255,190,254,131,251,119,2,210,255,169,254,215,5,128,252,160,252,9,6,200,0,102,252,147,251,131,253,49,251,228,1,228,252,25,253,141,254,231,3,20,5,173,0,237,255,76,241,29,255,184,0,254,254,79,249,122,0,154,1,224,255,12,255,199,250,184,254,236,255,20,255,153,254,243,255,204,255,181,255,252,254,170,1,160,255,219,255,218,255,117,0,86,252,231,1,60,0,30,1,59,2,112,1,217,253,198,0,154,255,15,0,245,255,183,17,129,255,15,255,114,0,179,255,196,254,46,1,195,0,107,255,183,255,101,1,128,255,233,255,34,0,63,1,159,255,189,0,30,23,236,255,122,255,209,255,7,255,7,0,3,0,116,0,7,0,48,0,47,0,92,0,19,0,14,0,31,0,124,254,183,254,170,248,80,252,190,3,120,2,181,7,182,0,126,255,63,255,5,9,156,252,63,0,4,1,244,255,167,255,168,255,48,255,127,0,88,255,237,0,74,0,129,4,157,3,244,8,176,11,221,255,204,0,254,2,94,252,169,255,85,1,155,255,245,1,35,0,74,255,112,0,91,0,228,255,79,0,193,0,183,255,185,255,52,0,82,0,85,254,109,255,187,255,114,18,212,1,69,255,98,0,217,254,36,1,33,252,43,0,98,0,225,0,213,253,173,253,190,255,75,255,91,0,104,255,253,255,89,0,37,255,100,1,137,254,142,255,246,249,148,253,136,2,154,7,39,0,160,253,82,252,103,0,179,0,170,0,210,246,157,0,108,4,80,252,229,254,64,0,119,254,15,0,166,255,249,2,71,255,132,2,152,254,5,0,164,235,106,0,120,255,216,255,97,255,216,255,136,255,213,255,248,255,61,255,208,0,77,255,217,254,193,255,19,0,32,0,152,255,233,255,132,0,148,2,52,254,237,0,11,2,92,253,134,254,175,255,72,255,158,10,64,0,19,2,71,8,228,249,102,2,165,3,6,0,65,0,206,255,55,0,243,0,229,253,144,4,185,3,229,254,45,0,220,1,166,254,237,8,100,7,103,2,247,253,23,0,225,247,57,0,245,255,208,0,5,4,115,1,28,0,170,0,193,255,89,255,184,0,39,255,76,0,192,254,69,245,30,2,206,247,105,254,246,255,148,252,59,250,206,254,53,2,57,0,207,255,145,255,185,0,6,255,120,0,70,255,214,0,248,253,207,1,24,3,140,246,200,10,129,254,241,252,183,251,71,254,233,253,46,4,78,0,96,0,122,0,63,255,4,2,114,0,100,0,99,254,100,0,233,255,103,255,243,4,142,239,26,253,228,0,147,2,143,1,87,255,156,1,175,255,32,4,4,0,2,255,173,0,109,0,38,255,196,0,64,0,26,0,143,255,196,255,248,255,15,0,121,21,180,255,169,0,218,254,118,254,84,2,123,1,12,0,192,255,53,255,118,255,41,0,7,255,203,255,212,255,237,255,55,0,222,255,99,0,36,0,186,255,8,0,46,0,227,10,74,3,125,7,75,253,88,254,151,0,208,1,118,251,3,4,148,0,253,251,83,255,72,1,23,0,24,3,72,255,139,1,84,253,229,0,117,255,249,255,228,10,148,1,43,0,28,250,178,253,6,0,72,255,136,3,219,1,219,255,20,1,151,254,132,7,68,255,143,255,202,250,80,255,11,0,222,255,186,255,188,255,95,0,79,254,225,0,181,1,61,254,215,1,240,254,127,254,233,10,131,245,32,2,113,3,153,1,235,252,188,2,251,255,112,255,66,0,239,255,248,1,115,254,8,1,74,0,175,255,245,248,188,1,195,253,121,2,121,254,245,242,192,0,228,1,102,4,206,254,153,0,47,1,61,0,3,255,1,255,199,255,235,254,168,255,156,255,32,0,79,0,216,250,167,252,8,12,154,4,67,1,97,1,107,255,36,5,113,254,236,0,127,255,231,0,67,1,184,2,59,0,193,4,201,253,244,254,130,2,128,1,185,254,209,255,210,1,250,5,68,4,104,251,100,2,1,1,113,255,242,254,231,1,194,255,76,1,65,4,193,3,62,253,170,3,78,0,97,0,11,245,192,251,153,252,239,254,87,0,167,254,148,0,113,0,167,0,97,0,31,0,68,0,209,255,203,255,53,0,29,0,165,233,203,255,244,255,241,0,92,0,131,0,139,0,48,0,102,0,230,255,209,255,152,2,188,253,249,255,7,5,227,9,37,4,58,253,24,0,109,5,50,249,254,0,133,251,27,2,106,255,232,255,239,1,52,255,85,255,187,3,202,0,145,255,147,0,78,250,123,240,165,1,96,254,224,253,136,1,139,5,78,255,88,255,203,255,50,0,231,253,249,255,166,254,223,254,204,255,218,255,253,254,141,255,120,255,118,255,167,255,51,255,107,253,179,238,146,255,124,1,47,253,76,255,127,0,165,250,178,255,20,1,63,1,229,0,90,252,11,1,159,254,44,0,65,0,193,1,224,255,159,0,245,255,234,255,197,253,100,0,92,253,76,11,76,245,139,3,255,1,248,0,185,1,194,255,251,253,165,254,21,255,63,1,248,255,116,255,53,1,2,1,150,255,215,0,1,0,76,243,170,1,199,1,91,247,7,4,174,1,234,2,111,1,90,2,187,0,109,255,56,255,97,0,43,2,149,255,7,255,185,255,101,0,59,0,162,255,192,255,223,255,221,0,184,0,233,252,159,2,65,255,28,1,225,250,146,1,227,255,250,0,66,255,9,254,38,0,106,0,74,2,159,18,14,2,147,0,74,255,249,0,146,0,17,0,37,1,185,251,55,4,95,255,141,0,254,255,169,2,237,254,85,255,104,238,61,0,151,255,206,254,190,255,229,0,20,0,154,255,163,255,78,1,67,255,5,0,250,255,161,1,247,9,193,255,172,252,72,6,28,7,158,2,56,6,102,0,203,0,147,0,1,253,109,255,54,1,50,253,175,0,39,2,158,255,54,255,53,1,70,0,81,0,201,255,238,5,222,0,82,1,156,254,93,1,97,0,86,0,239,1,23,255,135,255,120,11,200,0,167,3,131,254,170,9,53,0,238,1,248,0,117,255,211,255,100,0,249,250,75,255,142,254,55,1,31,1,200,11,160,255,128,255,98,8,55,2,129,254,217,253,160,255,144,0,239,1,172,1,224,255,137,0,27,0,240,254,107,255,9,0,195,255,177,0,140,235,91,0,187,252,99,2,233,254,182,255,140,2,14,0,78,255,174,255,167,255,91,1,11,255,135,2,194,255,49,0,41,255,29,0,201,255,229,255,178,0,79,0,237,255,197,255,177,0,104,255,0,0,189,0,246,255,128,0,141,255,33,0,61,0,150,255,56,0,243,255,135,0,116,0,116,233,157,0,43,0,26,0,245,255,102,0,252,255,204,255,208,0,70,255,198,0,99,0,81,0,227,255,153,255,193,0,221,255,172,255,252,255,145,255,125,235,84,0,71,0,171,255,179,255,55,0,234,0,38,0,0,0,221,255,60,0,243,22,98,0,36,0,37,255,239,255,93,254,120,255,47,0,34,0,55,0,235,255,239,255,255,255,72,0,94,0,52,0,253,255,65,253,99,250,250,253,45,2,121,0,100,1,167,254,51,253,74,254,233,254,13,0,70,0,161,255,254,255,182,239,40,0,136,0,17,0,103,255,8,0,107,255,229,255,209,253,12,1,19,255,174,255,36,255,103,252,180,253,106,255,153,13,142,248,135,2,163,2,57,254,86,2,126,254,204,255,249,255,222,0,55,255,90,0,54,0,75,0,229,254,118,0,137,254,136,22,20,0,130,255,115,255,157,255,64,0,116,0,16,0,198,255,0,0,225,255,241,255,250,0,152,255,226,255,112,255,115,0,12,0,117,0,30,254,83,249,76,254,122,0,10,255,249,255,15,1,169,7,154,0,149,0,170,255,147,0,2,1,19,2,224,6,146,3,84,251,248,248,44,3,147,253,125,0,95,255,81,5,50,0,117,253,229,250,104,1,239,252,205,0,100,255,38,1,21,0,100,242,238,255,177,255,246,254,2,3,51,1,29,0,3,253,6,255,183,0,55,0,131,0,172,5,4,1,224,0,221,0,165,254,104,1,160,254,116,247,104,253,9,254,57,1,150,1,5,255,196,12,210,0,210,255,129,0,236,254,87,1,113,255,104,0,201,255,205,1,17,0,192,253,225,254,223,254,33,0,60,246,171,255,84,254,143,251,150,3,11,255,22,254,252,254,242,254,123,255,177,253,199,0,218,254,224,10,102,0,19,0,147,255,23,253,91,0,244,253,212,255,28,0,252,0,1,254,176,255,110,255,15,1,7,2,40,255,24,247,101,254,115,14,144,254,230,253,171,1,98,255,114,0,206,255,179,253,172,254,76,255,191,2,70,255,231,1,119,253,156,2,108,252,76,254,156,241,8,252,109,3,191,255,103,255,194,255,108,255,239,255,150,255,142,0,183,255,255,255,188,255,55,2,110,253,47,3,222,8,205,253,249,253,30,255,33,255,230,254,72,2,240,0,14,250,113,248,145,4,112,3,127,0,4,251,129,255,143,1,63,0,25,0,239,250,83,8,80,2,116,6,49,10,69,0,187,253,77,255,179,3,85,2,150,0,35,0,0,0,1,255,24,255,40,253,239,0,91,0,130,0,22,255,231,0,56,0,123,247,238,6,108,247,97,6,215,251,106,253,9,3,81,255,128,255,11,1,249,255,51,0,27,0,123,255,95,0,12,254,188,0,89,255,94,0,80,255,227,255,191,255,95,255,115,255,74,253,56,252,82,2,243,254,90,254,40,254,37,253,186,4,208,252,94,8,215,250,46,249,107,255,41,252,30,5,185,252,250,2,28,1,99,0,225,255,111,251,172,255,161,251,201,255,48,253,80,252,165,251,241,254,248,251,40,4,187,0,11,252,171,11,26,0,47,255,4,2,248,255,107,0,232,255,188,0,22,1,203,255,112,2,204,1,237,254,167,248,47,248,83,3,52,249,105,254,107,6,160,254,239,255,240,253,230,253,81,255,179,0,160,1,215,254,54,0,132,0,21,254,180,255,34,0,72,254,175,0,17,8,42,248,92,255,38,0,109,254,134,3,127,255,215,0,9,6,98,254,97,251,236,253,66,2,248,0,204,254,189,0,205,253,167,254,75,252,233,254,157,6,65,252,101,0,15,3,9,0,105,6,214,5,167,0,218,254,230,253,183,3,115,0,78,2,105,0,177,252,21,252,208,1,144,254,12,251,129,2,254,0,243,0,232,1,76,10,71,251,240,254,181,1,189,1,13,3,49,254,97,254,26,2,213,252,76,2,59,4,206,0,221,253,171,0,183,253,24,253,87,1,164,253,139,1,180,255,142,3,245,253,148,255,63,254,113,2,187,254,201,251,17,1,63,250,184,251,119,255,203,253,29,8,145,253,214,0,170,254,239,254,1,3,113,4,145,252,37,253,56,0,182,251,211,0,54,3,67,2,185,252,164,0,168,253,176,255,61,0,60,1,132,2,165,5,123,3,252,248,250,248,94,255,161,249,20,254,142,253,81,2,32,2,66,0,63,0,167,252,7,251,150,1,129,6,131,3,45,254,87,0,139,255,43,254,126,0,30,0,93,252,166,5,66,255,132,1,184,249,196,254,105,247,129,255,228,1,205,255,56,0,244,253,244,5,153,255,207,4,28,253,205,2,163,252,55,3,103,253,2,249,155,1,78,253,47,1,177,249,63,0,24,255,19,0,66,4,160,255,137,0,80,0,253,251,69,2,195,255,160,2,133,0,188,1,1,253,254,2,214,255,154,243,242,254,233,255,130,255,169,251,67,0,169,250,4,0,59,1,203,255,166,255,91,255,48,0,135,249,139,255,136,1,100,1,24,3,158,253,150,253,37,255,190,1,102,0,118,1,207,0,2,4,176,9,51,254,242,252,137,4,185,250,8,4,230,1,204,254,34,1,240,254,131,3,120,7,36,0,144,253,30,1,84,254,145,253,103,253,12,0,147,253,63,248,222,255,212,1,62,1,45,254,127,0,52,252,217,255,105,253,3,9,230,255,150,1,44,254,111,253,132,250,170,254,52,9,117,254,114,250,37,251,209,1,90,0,103,253,232,254,222,254,235,255,40,249,24,1,15,1,139,1,240,0,110,254,55,0,53,4,148,0,203,254,26,7,227,1,243,250,43,0,5,1,54,2,125,255,179,3,209,252,152,252,3,252,23,252,117,254,7,1,213,253,78,0,111,247,152,254,180,255,251,251,19,254,48,254,59,5,203,255,238,2,97,253,187,250,133,0,186,255,114,0,245,1,254,2,208,252,191,2,32,252,134,255,248,253,213,250,21,246,147,254,221,255,213,253,136,252,235,5,65,255,42,5,97,6,94,253,195,1,34,251,14,1,156,252,191,2,118,254,106,0,245,252,242,2,138,2,42,4,95,254,231,250,149,0,91,255,0,32,69,255,41,254,55,255,185,0,47,254,208,3,1,1,83,0,238,253,54,1,164,2,85,1,48,0,9,1,161,254,50,1,24,1,46,1,48,0,240,1,173,254,168,1,126,235,3,255,92,2,195,254,223,254,22,1,61,2,189,253,79,0,146,12,194,253,135,254,20,1,15,11,225,254,2,255,76,1,31,255,42,0,162,0,55,254,65,252,115,250,171,2,197,255,223,255,34,13,137,1,94,2,249,0,151,252,94,252,200,4,189,5,37,0,200,249,129,6,186,253,193,6,28,1,106,0,111,237,136,255,37,254,99,3,68,254,53,255,175,1,245,255,242,253,188,254,220,2,210,251,96,255,157,253,16,7,215,254,232,253,62,255,202,252,200,4,172,8,230,246,72,0,236,3,237,252,107,255,45,2,109,11,29,0,41,3,93,9,137,251,136,2,136,3,200,253,61,253,185,252,238,254,214,250,153,4,45,254,30,254,195,235,234,0,223,0,98,1,130,1,225,2,249,4,234,0,159,254,31,0,248,255,120,254,85,0,22,255,86,5,169,5,120,0,73,253,70,3,146,253,160,255,126,1,115,250,100,2,83,255,129,243,106,255,218,1,118,254,207,253,109,251,237,9,241,254,209,9,158,2,29,1,124,2,60,254,54,255,39,5,122,247,89,252,182,253,243,0,211,252,215,255,203,255,239,251,212,0,58,0,160,242,111,0,12,1,196,3,97,243,12,254,99,3,65,255,207,0,31,2,127,1,27,250,104,245,64,245,201,0,172,1,209,2,242,1,19,0,21,253,67,0,87,0,244,1,176,4,196,8,122,251,210,1,248,251,103,255,173,4,177,10,188,254,210,7,174,254,89,0,84,254,78,0,63,2,74,1,221,7,175,0,49,1,55,2,229,253,17,0,128,1,229,1,92,3,2,13,173,0,74,2,137,2,132,1,195,3,28,7,206,245,251,0,106,244,103,5,103,255,110,255,52,2,50,253,230,3,253,250,202,253,149,253,138,1,203,1,47,251,6,10,155,254,215,245,98,0,95,252,145,254,11,254,96,0,193,4,97,249,188,254,137,1,5,1,209,6,185,251,17,253,156,3,20,4,175,254,37,251,137,1,150,9,37,250,11,255,134,3,157,3,178,247,167,0,70,3,126,2,248,8,218,254,50,1,53,253,234,10,242,5,173,254,21,0,62,1,161,255,54,5,75,0,83,255,165,255,36,248,104,252,223,252,78,1,221,242,164,254,38,2,113,252,251,254,207,251,185,0,87,254,175,1,3,2,173,254,25,7,203,249,241,0,36,2,175,254,41,254,52,242,114,251,120,3,141,0,235,254,73,5,54,1,114,253,198,0,252,253,135,11,203,8,234,253,189,2,237,0,20,0,171,253,211,254,3,0,154,1,56,254,187,253,26,251,28,4,41,5,165,0,36,12,221,1,196,0,156,10,85,0,5,0,222,255,209,2,206,253,4,0,84,0,231,252,232,2,243,0,134,0,127,254,127,255,134,255,128,255,179,254,29,254,164,253,13,1,65,24,3,0,3,2,193,255,134,253,217,253,229,252,96,249,94,247,136,8,92,1,30,0,157,1,227,9,214,0,214,0,70,255,184,255,216,253,190,3,191,6,153,249,106,2,195,255,80,254,109,1,15,253,15,0,242,255,33,0,208,3,84,252,157,254,246,12,165,2,110,248,21,0,113,3,186,254,173,255,229,242,203,5,69,251,94,253,166,0,139,0,236,254,158,0,32,253,14,4,19,252,105,4,195,4,91,4,120,254,46,2,96,0,68,255,58,1,24,2,89,254,66,243,139,1,126,255,75,4,48,1,75,255,85,3,96,255,8,251,172,1,77,255,122,2,96,2,83,255,130,10,113,247,105,5,250,253,96,254,167,12,178,12,57,1,233,255,200,0,131,2,129,253,239,255,48,255,27,0,74,255,6,1,53,255,97,253,157,0,221,239,127,1,108,254,81,1,51,0,175,1,92,0,138,0,74,254,29,0,81,1,232,1,4,255,144,2,253,1,245,7,133,253,206,251,165,251,169,247,252,252,126,254,42,255,114,253,71,254,125,6,30,2,129,254,72,249,22,0,153,255,62,250,248,250,9,17,26,1,28,251,222,2,166,252,212,253,38,1,243,0,37,1,133,0,80,3,65,0,41,253,137,252,222,250,187,1,160,255,90,254,172,16,160,2,142,0,96,2,70,254,75,3,109,1,158,252,99,255,12,3,107,0,136,252,41,8,233,6,73,0,227,2,241,255,62,249,45,251,152,3,79,249,163,0,40,2,199,5,76,253,13,253,150,5,63,255,236,254,248,254,78,253,4,3,123,5,216,255,167,2,252,254,130,2,22,242,194,3,5,8,68,5,36,0,98,244,155,0,47,1,53,3,80,252,77,255,57,252,120,2,43,253,155,1,65,254,49,254,182,2,175,254,110,255,59,0,255,255,96,254,12,0,12,2,15,254,182,237,23,253,113,2,243,3,20,0,50,254,9,254,220,7,37,254,229,255,85,0,90,251,22,2,202,8,87,0,31,10,171,4,129,6,167,1,211,252,197,253,140,254,41,10,35,248,171,252,34,253,109,254,25,3,219,253,219,4,56,1,210,2,11,252,102,250,19,253,197,253,238,1,168,255,127,255,51,5,38,3,53,251,70,1,116,251,183,9,197,255,42,9,71,2,7,2,112,1,25,3,154,4,149,2,140,0,202,4,122,1,83,254,66,251,158,5,193,254,179,255,41,250,14,14,105,1,21,0,39,0,138,7,198,0,26,4,19,2,18,1,32,0,13,254,163,254,251,255,123,255,4,243,133,254,26,253,6,255,174,249,0,250,36,8,89,5,253,2,124,255,188,254,150,1,106,247,58,1,246,1,105,250,247,2,39,253,64,1,184,247,204,5,164,9,45,243,4,0,16,1,254,255,236,1,91,0,221,252,48,0,179,2,119,1,87,0,4,254,43,253,136,253,12,1,113,11,22,5,245,255,140,253,79,247,211,2,21,2,141,3,166,3,170,2,94,1,229,5,61,253,138,251,106,0,130,247,86,1,59,252,200,1,113,253,113,4,215,253,159,1,94,254,185,245,135,255,237,0,3,0,157,251,237,249,123,250,251,242,205,2,115,0,250,251,17,252,205,252,130,0,173,252,25,1,213,255,39,254,189,251,70,1,101,3,135,254,22,1,108,255,162,1,200,247,90,254,111,2,15,249,121,2,9,4,17,248,59,251,30,16,196,255,240,255,89,31,243,0,172,254,169,253,11,254,223,254,37,255,152,255,26,255,208,1,191,0,18,0,89,1,191,255,188,255,31,254,113,2,202,252,85,240,252,253,229,2,222,2,196,254,18,2,122,0,177,3,115,1,214,254,170,4,6,255,89,255,136,1,161,255,105,255,255,255,26,254,189,0,90,0,116,255,30,0,133,17,69,2,54,0,113,7,129,252,16,248,82,255,169,9,80,253,152,255,197,254,136,254,62,3,40,1,220,253,242,2,195,0,123,252,244,249,117,248,24,3,254,1,38,1,153,0,107,2,246,251,34,244,110,4,142,0,227,255,218,252,138,255,227,255,246,246,97,255,2,3,173,244,23,0,235,251,13,4,216,5,80,4,241,253,135,0,231,254,202,254,197,255,202,0,166,254,156,253,206,0,27,0,56,254,246,2,67,0,219,13,99,3,227,0,253,255,61,2,160,5,165,1,170,0,211,5,77,253,213,255,248,255,16,3,51,1,45,2,106,2,173,246,54,2,116,254,182,0,109,3,150,245,93,255,41,2,101,255,179,2,68,255,208,249,195,251,9,4,204,254,76,5,198,253,47,253,24,255,183,243,104,0,255,1,60,252,223,10,83,253,88,255,205,255,18,6,232,248,127,9,71,1,72,254,150,4,247,254,220,255,120,0,115,254,70,4,26,251,51,252,62,2,61,4,117,255,17,253,239,253,16,255,25,0,113,4,45,254,113,242,82,1,218,252,20,248,94,0,158,255,176,254,231,253,165,4,144,252,233,241,88,255,197,255,100,0,53,1,73,4,39,1,6,1,106,0,248,255,210,0,219,226,139,1,8,255,205,1,234,1,186,254,8,1,105,0,13,0,96,255,96,2,69,254,205,250,67,3,194,250,179,13,251,2,198,3,101,0,23,4,43,254,81,250,200,251,28,0,99,0,212,255,14,1,16,253,130,0,2,0,57,0,102,1,103,254,2,0,110,253,212,252,125,252,155,0,141,0,53,8,32,14,40,0,91,248,252,251,215,239,212,0,44,6,66,2,251,3,0,254,167,0,110,1,188,253,192,1,216,0,79,0,107,255,32,229,145,2,147,253,69,0,219,0,180,253,169,2,229,0,248,0,210,254,146,255,222,2,12,0,253,0,58,254,134,252,244,241,10,3,216,245,0,255,17,2,76,1,187,255,39,1,57,254,214,3,247,254,186,255,180,254,145,254,214,5,74,2,98,255,226,251,225,9,199,254,107,253,234,250,74,246,220,1,5,0,126,0,69,2,105,1,82,6,138,2,241,7,202,0,76,0,247,254,95,255,75,14,224,252,45,4,89,255,0,249,133,1,188,253,85,2,244,254,109,2,245,251,198,2,86,3,212,7,239,252,154,10,123,6,17,3,32,3,176,255,9,0,171,254,248,251,21,3,139,2,44,4,159,253,149,2,235,2,96,252,25,252,167,250,107,251,96,254,60,6,16,245,74,1,34,2,5,251,22,253,120,254,239,253,134,254,243,13,21,245,37,253,73,255,182,254,201,249,115,1,98,3,67,1,252,253,167,255,229,8,57,6,192,3,66,249,75,247,215,2,97,254,189,0,244,1,111,255,79,255,38,2,211,1,240,0,107,4,218,1,93,254,44,251,162,2,152,253,249,253,135,9,67,251,118,253,99,3,206,3,116,252,205,4,0,254,164,3,17,254,39,246,159,252,46,254,8,0,86,254,144,3,179,255,20,255,105,254,177,1,128,0,69,14,86,3,243,0,2,3,191,0,224,0,188,255,59,254,129,254,23,1,67,253,77,253,26,1,63,254,124,4,241,252,241,0,99,236,131,2,177,31,167,254,13,0,90,0,199,255,219,1,64,0,244,254,93,255,156,255,161,255,6,2,65,2,29,2,7,8,102,1,99,255,104,1,24,1,184,252,119,251,244,1,95,0,46,1,106,253,110,4,59,3,228,12,183,2,7,3,226,252,165,245,181,244,157,251,43,2,155,251,156,0,72,1,159,2,239,2,165,254,52,252,120,254,64,251,165,10,224,235,110,254,241,255,150,0,31,0,74,255,234,254,245,0,81,0,253,255,210,255,54,1,184,255,118,255,231,5,30,249,208,248,148,254,123,0,241,10,240,255,225,253,224,250,50,2,250,254,148,0,9,2,57,253,61,0,161,252,145,0,73,1,249,2,76,0,101,255,101,0,134,236,192,0,13,1,148,254,82,255,128,2,251,254,117,2,54,14,141,1,35,249,103,251,86,1,132,1,65,4,56,3,115,0,150,0,125,0,38,3,247,4,58,255,32,3,81,255,127,252,119,253,187,252,178,2,13,253,136,5,213,246,155,4,243,252,58,3,31,6,108,255,100,255,244,251,220,249,224,4,69,255,208,1,252,254,19,253,210,251,85,0,46,254,144,247,14,245,233,0,75,255,191,1,30,254,113,0,36,2,141,11,192,249,61,5,209,253,35,3,37,8,217,252,57,253,111,251,56,254,145,2,180,255,109,255,140,7,226,251,57,252,180,251,207,255,243,244,132,5,161,3,183,4,58,0,110,255,77,0,54,254,26,2,141,253,244,255,214,0,163,246,180,2,4,5,110,1,6,5,205,7,168,252,11,1,74,7,212,4,25,0,254,0,93,251,128,13,27,1,72,2,44,9,92,2,150,251,7,0,244,1,232,0,205,255,120,0,73,253,94,252,61,1,67,0,190,250,12,254,56,1,220,251,222,246,188,248,45,250,3,6,85,249,10,3,115,253,215,255,145,1,55,1,243,255,107,8,13,252,139,4,200,2,42,8,56,5,42,253,62,2,176,4,26,251,225,249,211,2,171,2,147,252,115,253,113,4,198,249,103,4,81,10,209,1,3,1,209,247,184,2,107,254,40,0,253,254,216,252,82,252,139,1,76,255,161,251,58,252,26,255,234,253,142,255,88,0,107,253,245,2,75,0,226,254,137,255,156,3,147,244,179,9,126,6,31,7,78,2,211,16,42,3,191,1,165,0,243,0,72,255,94,255,180,1,130,255,62,255,109,1,89,2,158,254,65,248,45,255,105,253,20,1,155,0,72,253,18,246,194,252,70,9,21,255,183,253,43,254,34,254,21,0,99,3,159,249,157,7,75,252,182,254,222,253,72,1,32,255,212,4,10,1,163,251,36,0,195,255,221,0,153,0,93,242,73,250,19,255,68,18,15,255,17,1,12,1,91,1,119,254,235,254,168,0,170,1,155,0,191,255,163,253,199,253,120,250,233,250,224,4,83,2,108,255,0,2,38,14,35,1,68,254,245,253,104,2,105,0,101,0,77,5,4,3,175,254,238,1,58,2,15,0,150,0,112,254,60,2,78,2,138,6,246,239,172,3,167,0,185,254,176,254,184,2,79,2,106,1,23,1,137,17,211,250,96,2,38,1,215,255,37,2,214,3,225,255,72,255,111,1,77,0,46,254,142,1,120,248,161,253,239,0,55,0,15,0,7,4,26,254,228,10,103,8,249,253,83,251,136,251,18,1,159,2,84,6,31,8,237,249,63,252,31,2,245,255,26,0,141,253,9,3,187,253,220,251,103,251,216,252,39,3,47,11,95,2,144,0,195,0,238,254,18,0,232,233,157,254,254,251,56,0,116,0,81,254,19,254,5,2,30,1,97,1,97,1,199,0,117,253,161,252,236,254,212,253,206,253,157,252,113,255,157,254,189,254,242,255,202,255,22,235,213,255,200,249,8,0,225,253,24,0,94,0,37,253,223,253,193,2,85,255,248,1,202,251,217,242,69,5,196,1,108,255,159,4,142,249,136,250,10,255,248,251,137,255,203,254,202,253,230,3,88,243,68,254,110,253,163,253,70,255,235,1,183,1,66,255,176,2,227,255,59,252,2,10,144,255,183,254,231,255,223,245,99,1,203,255,180,2,12,0,175,253,138,7,220,252,174,255,130,1,136,253,159,3,238,3,27,255,133,251,75,255,205,251,11,255,162,241,136,3,214,254,215,8,50,0,51,2,81,1,229,251,173,0,54,1,44,242,153,253,8,254,237,2,192,0,166,255,143,255,38,253,54,248,34,3,211,255,186,8,167,0,33,1,186,6,206,253,170,2,197,1,35,6,171,0,131,246,71,254,26,255,136,251,217,3,190,249,102,1,83,253,233,255,245,253,239,253,122,246,188,2,144,253,37,0,61,250,218,250,220,12,190,2,138,1,226,252,3,10,33,4,177,254,102,2,14,1,63,12,255,250,215,247,6,255,116,255,45,0,251,253,42,254,107,250,84,255,77,10,11,1,55,0,243,251,82,255,144,3,159,252,238,252,106,254,25,2,11,245,126,253,193,249,120,3,236,251,81,255,56,1,28,0,123,251,16,255,75,255,42,1,9,2,218,14,169,255,93,0,48,0,56,5,209,251,178,248,83,1,174,251,80,252,244,251,105,1,121,241,109,255,113,2,70,1,134,255,151,1,39,255,140,1,17,1,254,255,197,254,250,254,120,2,212,26,228,0,245,254,207,0,227,255,238,254,192,0,63,0,159,254,76,2,38,2,253,255,156,0,67,8,44,6,194,246,50,1,121,2,74,5,9,9,152,254,167,254,14,1,13,254,48,252,155,241,231,250,139,3,151,5,9,6,202,250,18,0,135,4,229,0,132,255,157,0,214,1,151,255,188,2,6,249,153,248,27,3,228,251,234,254,233,2,145,255,211,255,182,2,87,2,115,242,40,2,186,255,34,255,45,0,128,3,5,255,1,0,250,0,255,252,45,1,129,251,33,5,218,16,198,2,168,2,87,255,105,253,40,0,143,1,147,4,69,2,7,3,168,3,24,254,154,244,155,0,87,255,232,249,162,252,39,254,15,3,184,255,1,249,55,2,195,247,100,255,226,4,50,250,181,12,61,0,206,255,138,254,235,254,174,3,111,0,95,2,196,254,197,0,20,253,103,3,100,2,14,255,216,254,53,0,63,255,209,4,11,0,62,252,249,1,116,238,21,0,242,2,106,255,195,1,183,0,113,3,116,253,97,255,240,24,170,0,15,1,11,4,145,1,48,0,49,254,16,255,161,255,143,253,101,2,165,255,142,251,148,4,30,2,53,250,178,245,140,250,107,251,100,2,0,2,75,5,209,3,150,254,234,255,239,255,124,0,150,243,236,253,96,1,125,245,98,2,57,2,228,2,189,249,251,255,20,254,192,2,76,254,160,255,173,253,41,250,170,10,239,243,92,255,53,2,20,5,35,254,199,253,45,4,38,1,23,255,123,255,196,2,150,0,132,1,196,247,238,251,189,249,227,8,70,249,49,2,140,0,251,1,125,252,231,254,162,0,239,250,224,5,98,255,193,0,38,253,80,252,76,246,103,2,226,255,32,0,158,254,129,254,86,0,73,1,150,242,130,254,188,249,213,254,208,0,0,32,243,255,90,1,204,255,5,0,131,0,218,254,89,255,191,255,165,254,74,254,209,253,57,0,170,255,33,255,32,255,5,255,117,2,198,255,129,20,127,0,48,254,132,2,210,0,102,255,32,254,165,0,211,0,13,0,62,1,152,0,83,255,75,21,235,0,170,0,156,255,250,255,52,254,7,255,134,1,54,0,225,3,155,249,224,254,46,252,59,255,234,0,195,244,198,253,105,255,174,255,4,3,199,0,127,254,149,248,89,1,231,255,15,2,35,254,154,244,129,1,224,10,78,0,244,253,9,253,27,3,177,1,255,1,88,3,237,254,255,1,136,0,68,254,151,0,233,0,208,0,179,253,137,254,26,1,70,11,30,0,67,245,94,252,55,4,86,0,19,247,212,3,27,255,167,250,93,0,176,255,10,9,86,255,200,4,141,1,149,1,207,1,246,3,135,254,166,255,243,254,174,255,136,254,251,252,172,2,162,255,179,244,189,254,124,253,175,252,156,248,60,247,161,1,117,8,92,255,221,0,198,1,223,246,142,0,99,0,162,1,230,1,207,255,97,0,138,0,173,8,3,247,100,255,190,253,123,15,196,0,140,0,138,254,180,0,195,1,98,1,72,252,178,3,33,254,150,252,97,255,145,0,34,1,240,0,16,255,23,255,94,254,226,0,62,11,197,253,69,246,229,2,98,250,45,2,197,0,142,254,144,237,123,1,32,0,53,3,39,0,223,253,115,255,29,250,192,0,130,251,137,3,185,251,92,236,87,255,21,2,233,255,115,1,162,0,82,251,209,1,143,254,242,255,163,252,112,253,67,253,216,254,31,0,194,1,125,254,244,11,72,253,85,2,14,0,5,252,75,245,48,255,94,251,174,254,200,2,192,255,168,254,41,0,71,1,9,0,64,2,163,254,8,245,124,9,177,1,202,253,140,3,148,255,111,255,13,252,201,0,30,244,185,254,210,0,144,254,230,0,202,254,112,254,12,0,246,251,198,6,224,3,50,7,254,3,114,8,76,2,110,1,154,0,250,243,181,253,72,4,215,0,208,251,240,252,216,1,191,251,94,0,231,1,18,0,72,0,34,0,241,255,138,254,161,253,60,1,62,3,110,255,25,17,211,254,134,1,70,3,121,0,146,255,113,255,163,255,172,11,98,11,160,254,159,254,24,253,141,255,99,0,239,1,169,254,53,1,237,4,249,253,101,0,154,245,212,255,189,243,21,254,118,4,189,254,206,255,8,3,86,0,187,0,224,1,15,1,89,255,1,0,245,254,157,255,223,3,188,9,104,255,119,9,31,255,34,0,64,2,50,250,20,255,137,254,160,0,80,255,111,255,221,9,125,255,194,0,61,1,191,4,17,6,39,1,128,250,130,0,231,8,95,251,111,10,119,255,188,254,233,255,26,0,245,252,81,254,252,255,232,1,70,255,174,0,137,255,246,11,107,255,88,255,191,0,169,0,100,4,45,1,191,5,103,254,25,252,90,255,126,8,131,250,224,3,77,255,210,245,185,255,177,243,92,0,48,252,19,12,190,254,54,1,138,254,245,252,87,2,201,255,169,1,71,253,63,0,27,0,218,255,86,0,170,0,245,255,152,253,159,255,13,2,78,0,14,0,172,2,76,234,204,254,68,254,10,1,116,254,127,249,86,0,46,253,193,251,103,252,243,253,3,0,73,254,192,249,219,255,246,7,144,245,69,255,105,1,0,224,169,1,109,1,54,0,87,1,65,253,253,0,28,1,199,255,185,254,102,255,136,1,99,0,75,255,213,0,139,1,148,246,209,254,182,0,82,0,7,9,45,0,9,7,47,255,36,252,42,0,106,250,38,0,47,253,118,0,93,255,255,4,136,8,238,255,35,11,18,1,149,254,41,1,150,0,36,255,69,14,63,12,131,254,79,1,254,0,122,1,204,255,52,0,72,1,129,254,195,255,222,252,103,254,207,255,49,0,0,224,106,1,208,255,82,254,202,255,255,0,243,0,243,253,14,0,152,0,10,0,120,254,211,254,174,253,229,253,176,4,114,2,93,244,233,0,32,250,152,2,40,253,243,250,21,254,138,1,37,5,42,1,169,0,214,0,83,254,197,251,42,0,133,1,143,18,254,1,43,1,226,253,200,1,172,252,30,0,208,0,193,255,125,255,72,0,87,254,73,0,213,0,225,254,235,254,43,0,128,0,152,21,165,0,196,254,121,255,192,253,185,253,217,0,238,250,47,0,134,0,103,0,154,248,148,0,78,13,112,3,196,3,71,253,162,255,166,249,223,0,232,4,254,253,31,8,239,253,125,7,84,250,152,253,163,253,129,1,61,252,139,1,105,0,102,255,165,249,42,255,40,0,201,3,60,253,44,250,200,252,153,9,19,1,148,1,108,3,243,252,251,251,34,0,72,0,229,0,119,255,8,1,125,254,49,1,199,255,92,11,113,255,7,255,87,246,202,0,69,250,148,254,46,8,247,253,186,255,4,1,132,0,209,1,71,0,214,3,220,255,0,7,50,1,91,11,201,255,254,0,165,1,231,0,140,0,191,6,218,1,249,2,81,12,238,255,156,254,158,1,170,8,52,2,9,255,2,254,67,0,86,9,227,9,240,0,117,0,25,254,202,254,5,1,222,0,226,254,163,252,124,247,224,1,181,255,161,18,105,254,248,0,227,0,32,255,46,1,133,3,80,251,40,253,1,4,222,2,176,254,115,0,66,249,77,255,131,0,43,0,155,254,108,1,87,253,27,1,67,255,203,2,23,245,76,253,87,5,148,3,28,0,12,254,22,12,225,253,141,253,59,253,6,254,186,251,34,0,96,246,178,1,1,1,101,1,10,0,122,254,134,12,155,13,137,0,147,0,180,0,231,0,252,254,61,253,206,252,220,1,240,253,144,2,56,3,248,255,1,12,106,1,38,244,57,255,47,0,182,2,4,255,51,3,109,255,33,254,224,255,18,2,115,255,165,255,251,0,102,255,120,1,165,253,1,9,219,244,146,253,60,1,88,253,146,1,205,252,67,1,215,1,209,255,236,6,227,5,228,251,83,253,18,0,51,246,94,254,121,1,225,255,100,254,105,0,118,252,245,254,10,245,67,255,159,255,198,0,222,252,174,255,110,253,92,244,27,3,65,254,134,2,13,4,230,1,79,253,162,245,55,0,50,242,28,2,188,255,246,1,166,255,21,1,169,255,15,254,24,0,10,255,144,1,136,1,92,1,76,0,167,254,25,255,185,255,155,0,249,255,30,255,153,25,115,1,5,1,222,254,88,0,212,255,55,1,214,1,251,255,182,0,151,255,56,0,188,254,11,1,241,0,71,1,198,3,218,0,169,237,56,252,27,0,160,254,197,254,202,0,52,255,179,1,104,1,229,253,137,254,241,253,123,251,242,3,15,255,75,16,220,254,66,0,39,9,54,1,86,253,83,2,224,11,27,2,138,255,195,253,128,255,184,3,84,255,221,253,227,254,255,255,89,1,187,233,89,1,103,255,77,0,93,1,31,255,148,254,113,253,242,254,52,253,199,252,27,0,55,0,131,8,102,255,237,254,103,1,11,254,32,252,103,253,2,6,38,255,121,251,128,8,179,252,54,244,105,0,53,254,182,243,67,0,59,255,219,254,27,2,115,0,182,255,119,0,98,255,167,255,169,5,66,244,104,0,139,2,118,3,202,254,14,255,195,4,13,7,176,0,187,8,67,2,38,1,122,2,65,5,255,255,58,254,243,2,250,251,224,6,156,246,106,254,126,3,102,2,182,255,113,0,211,250,51,7,120,254,89,243,136,9,202,255,222,0,69,5,73,253,15,252,178,1,44,254,3,254,232,254,206,1,228,0,61,2,213,0,55,0,69,1,45,2,100,0,47,253,94,253,88,2,27,3,31,6,151,1,201,12,198,255,206,250,93,1,75,255,161,1,9,254,143,3,94,1,87,253,106,238,129,255,230,255,74,1,106,2,241,0,109,255,28,1,30,255,129,255,124,245,228,1,110,255,238,255,96,254,243,2,85,0,209,243,108,254,0,0,34,254,18,239,154,5,28,255,197,5,207,250,230,0,174,2,210,253,230,1,68,255,168,1,58,254,200,253,115,255,186,254,124,255,217,255,184,9,9,0,119,2,1,2,204,1,95,254,96,10,121,2,132,250,175,255,229,254,225,254,224,1,254,9,237,255,98,255,117,245,149,1,20,1,129,253,105,255,17,2,241,0,83,252,228,252,43,255,101,4,121,254,211,9,78,0,79,255,117,10,217,0,187,3,81,253,99], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1762865);
/* memory initializer */ allocate([3,27,254,135,255,255,3,220,249,177,253,139,0,30,3,238,4,45,254,210,2,83,10,19,255,232,251,130,1,80,254,180,0,236,252,78,255,234,0,147,1,11,1,56,1,101,10,73,2,41,245,82,253,168,255,240,255,37,251,67,254,253,254,47,1,42,1,29,1,21,1,51,9,163,0,161,246,96,254,115,0,229,8,61,253,194,0,27,1,159,4,23,0,119,0,97,0,0,32,216,255,67,0,155,255,151,0,169,0,21,0,109,255,96,255,55,0,49,255,38,2,220,255,12,254,224,255,225,0,206,0,72,0,179,0,208,1,106,254,52,0,184,2,238,255,37,237,11,6,252,253,29,247,87,3,174,1,245,253,83,0,159,249,150,248,29,1,202,0,123,253,89,255,102,0,132,255,126,1,24,0,236,0,62,3,68,1,172,255,235,1,161,255,102,255,255,2,25,0,133,18,194,253,240,245,215,254,6,255,166,254,205,244,192,255,161,251,239,3,141,252,201,1,184,254,170,252,43,252,201,255,10,27,57,2,205,254,5,1,156,255,192,252,129,0,160,1,102,255,169,2,120,255,128,4,112,255,230,255,38,247,192,254,115,255,127,252,32,2,50,255,77,3,178,253,88,0,211,0,31,249,194,253,115,253,28,245,252,0,246,254,100,239,39,1,97,0,192,247,209,0,112,255,143,2,167,255,143,254,79,2,205,0,113,4,30,0,165,244,88,0,92,0,16,255,222,243,240,255,114,254,192,253,48,253,165,1,171,1,89,254,61,255,238,255,199,9,123,255,106,252,104,0,0,254,23,254,63,10,198,254,215,0,153,255,10,252,249,2,126,1,80,250,183,6,44,252,248,0,55,0,132,2,103,248,42,0,94,255,221,255,172,252,201,7,67,255,152,2,107,255,60,12,206,255,110,13,38,2,22,255,202,253,178,1,64,0,123,1,87,255,221,254,50,253,160,253,31,0,49,255,139,2,249,245,234,252,138,3,6,2,204,6,117,1,134,4,114,0,4,248,29,1,144,251,139,254,164,3,119,247,24,254,148,0,3,0,212,2,111,2,200,253,153,254,68,245,239,2,182,251,166,252,140,251,3,255,183,246,110,254,200,254,114,254,209,255,198,245,48,3,200,253,250,4,98,255,118,0,107,0,181,0,138,1,198,10,80,0,15,244,20,0,233,254,110,0,226,1,242,3,94,255,199,251,200,255,173,2,159,8,246,255,82,0,184,1,81,2,43,0,242,3,171,252,144,253,32,1,27,244,86,254,9,0,132,0,104,0,157,0,210,1,138,255,116,0,226,0,42,255,37,255,43,1,205,23,122,0,7,0,174,0,188,1,200,0,214,255,252,255,199,254,99,0,218,0,36,1,97,255,103,254,11,2,179,250,254,239,160,255,200,3,8,0,84,255,68,254,240,251,243,2,36,254,199,3,175,0,156,255,153,6,211,252,103,12,113,1,36,7,248,0,95,255,37,26,119,2,24,2,131,255,18,1,45,254,3,1,85,254,130,0,245,253,105,1,72,2,27,0,60,0,199,255,226,255,0,224,148,0,192,255,217,0,204,254,163,0,140,255,89,0,108,0,191,0,127,255,107,255,128,0,60,0,63,2,253,0,127,254,135,244,120,3,134,250,225,253,161,253,79,10,156,0,251,0,54,27,109,255,130,254,124,254,39,0,220,1,4,1,232,251,63,2,145,1,11,255,71,254,121,0,133,1,102,253,95,0,103,11,92,247,3,253,169,0,95,255,184,0,192,254,197,254,15,254,136,0,42,254,223,1,227,253,200,2,150,11,7,2,35,10,179,255,65,4,18,0,71,253,152,253,241,0,202,255,132,1,205,1,112,1,144,0,107,255,181,0,19,30,11,0,3,0,144,254,65,0,48,1,102,1,227,255,255,0,94,255,87,255,42,254,240,255,198,0,92,0,89,8,233,0,17,1,255,0,238,15,233,254,62,255,238,254,101,0,45,0,31,255,52,253,38,246,68,255,10,0,178,253,23,253,126,3,184,7,208,255,254,8,252,255,173,237,189,255,211,250,6,254,93,2,215,254,61,1,241,254,80,255,170,6,29,2,1,0,31,0,188,253,103,0,148,0,134,255,115,255,175,252,76,0,234,243,189,255,215,10,218,255,170,253,198,254,25,3,40,0,68,1,194,5,194,7,225,5,64,3,8,254,227,2,47,251,177,4,183,2,173,250,158,2,37,3,184,2,119,255,143,236,206,254,137,0,139,252,199,1,253,3,88,2,81,249,24,2,235,0,107,255,31,0,251,255,93,241,107,254,138,1,140,0,102,0,216,249,190,0,152,1,151,2,229,247,21,253,210,1,119,2,39,3,75,7,113,253,102,0,85,1,179,1,39,2,244,1,170,1,118,253,168,255,230,255,112,10,1,249,34,0,170,255,147,11,254,242,231,252,205,254,21,1,184,253,16,255,115,255,2,1,196,2,14,255,13,254,40,3,152,255,243,247,250,253,172,2,121,3,150,1,3,1,211,0,206,1,172,1,219,245,133,251,193,6,171,2,131,247,89,255,136,1,184,1,87,2,209,252,144,253,144,254,110,244,84,255,77,3,167,1,106,1,199,2,83,8,197,240,84,0,147,0,58,3,113,254,131,253,108,4,108,0,32,254,230,0,9,1,89,254,48,0,11,0,239,0,169,253,231,254,10,0,29,2,115,254,142,0,30,239,148,4,255,254,155,255,36,1,191,254,111,254,60,0,203,254,212,1,11,1,99,2,182,1,130,253,146,8,90,1,141,5,88,251,219,243,86,255,248,242,207,255,187,255,181,255,184,0,22,12,79,2,82,0,139,254,140,0,234,255,80,3,124,0,77,2,157,0,252,255,4,1,79,255,147,0,73,0,228,254,109,24,111,0,46,1,182,255,100,1,125,1,221,253,240,255,237,254,12,254,93,0,88,1,166,254,235,244,108,1,213,255,176,253,205,6,66,253,57,247,80,3,53,255,168,0,246,2,175,252,106,246,50,2,80,4,87,255,207,1,114,254,57,245,213,254,121,252,135,2,194,255,132,255,45,1,81,1,55,255,207,1,170,255,117,255,115,247,136,246,82,252,136,254,5,248,176,255,1,249,212,249,1,2,29,0,165,251,186,253,190,4,126,253,99,1,240,0,29,1,223,6,185,4,94,3,171,6,25,13,33,255,245,0,253,253,96,252,26,3,66,255,230,254,73,4,224,255,139,6,89,3,38,253,241,255,102,0,100,1,203,254,27,15,24,0,93,0,131,3,160,253,15,254,41,255,60,247,223,2,62,255,102,0,205,255,109,248,78,3,74,0,140,255,7,0,189,7,0,2,233,0,62,2,52,246,83,0,174,7,5,255,160,255,20,2,97,0,129,3,160,251,134,1,136,243,116,253,253,7,193,0,144,252,114,254,108,255,36,2,231,254,237,255,37,252,211,1,186,254,217,10,195,0,24,6,10,4,196,252,102,0,5,250,12,5,130,255,27,2,9,255,36,0,55,0,73,246,215,254,150,254,226,1,63,247,3,252,1,250,12,255,38,0,168,242,141,0,80,13,35,0,189,255,95,0,77,1,85,254,21,255,128,255,48,1,220,253,81,1,163,254,182,254,23,0,62,254,121,6,71,1,241,243,183,2,239,254,190,251,238,4,145,255,156,252,236,5,13,1,119,0,192,0,14,0,200,0,141,0,117,254,233,27,48,0,78,1,143,0,117,255,154,0,154,255,200,254,254,255,27,1,238,0,226,255,114,2,48,5,242,0,96,254,186,1,22,244,108,5,156,255,191,4,49,3,130,241,172,254,111,12,200,0,132,255,167,1,95,254,80,254,232,0,216,252,85,0,111,255,39,0,196,0,59,255,196,255,102,255,43,255,192,254,131,244,225,3,228,11,4,254,61,0,171,252,75,0,40,0,105,3,3,253,147,254,147,253,146,245,188,0,57,0,109,254,26,255,119,255,40,0,53,2,138,248,160,251,5,252,165,253,121,248,150,0,239,243,23,0,96,254,57,255,63,243,15,0,128,0,243,253,237,253,91,0,217,255,66,2,124,254,59,1,40,0,72,9,226,6,2,0,61,250,18,249,111,0,166,3,53,254,9,3,186,253,114,0,38,255,174,255,61,255,165,0,123,8,120,2,189,255,239,0,89,1,255,254,104,0,222,255,145,252,232,1,90,254,148,247,201,252,148,7,187,2,95,11,23,255,131,255,38,255,145,255,177,254,109,242,195,255,185,255,67,254,249,0,182,254,102,0,120,1,140,255,107,10,59,254,19,0,223,239,90,0,5,254,236,0,162,1,43,0,79,0,61,0,40,1,181,0,190,0,152,1,216,0,198,0,32,0,175,255,245,0,99,255,179,21,94,255,62,1,179,0,83,1,49,254,64,254,2,255,242,253,64,255,85,254,63,2,76,2,232,10,123,10,171,252,202,253,19,0,230,255,106,0,36,255,6,2,222,2,23,255,68,0,164,253,25,255,0,1,69,255,197,255,107,254,206,0,75,1,231,255,27,237,189,254,146,0,29,2,211,2,147,3,112,255,194,1,102,0,141,254,27,0,88,0,176,255,20,1,239,0,101,0,157,0,187,255,242,255,234,0,0,224,238,255,146,255,204,255,248,255,48,0,79,0,213,255,153,0,187,0,211,0,138,255,145,255,238,0,11,0,42,248,168,2,222,1,73,253,6,12,226,255,124,3,233,255,232,5,62,255,167,1,240,255,194,254,127,3,150,1,122,2,47,0,51,243,51,255,4,253,41,1,155,254,195,255,68,255,245,249,156,252,82,255,86,1,5,1,134,7,88,0,221,255,78,243,236,255,96,12,144,254,10,3,120,1,167,0,86,2,186,1,134,0,231,1,164,0,224,255,245,0,180,1,19,8,83,2,190,253,49,0,93,255,121,2,138,0,233,254,157,255,118,0,117,4,160,243,68,2,166,255,136,243,39,2,105,253,143,245,201,255,147,0,27,5,9,0,15,0,176,1,51,1,15,2,234,3,43,254,180,246,170,254,219,254,183,255,253,254,154,1,53,1,76,0,192,254,95,255,26,1,28,243,249,255,160,0,220,2,228,1,191,255,147,0,107,11,17,9,184,252,141,7,12,1,172,2,148,4,135,254,147,254,200,253,229,254,236,1,230,253,153,1,62,255,17,0,215,254,204,255,133,255,242,254,161,0,162,255,92,0,143,17,116,254,28,2,229,0,226,255,148,255,29,0,1,0,198,0,236,1,196,253,118,254,174,246,227,10,117,3,105,251,127,255,143,251,220,0,148,0,5,1,191,255,12,255,1,0,58,0,195,0,207,255,222,254,162,255,235,255,105,0,71,0,241,25,56,255,105,254,16,254,181,255,233,0,222,0,37,2,107,1,188,0,227,2,155,252,122,0,157,254,254,12,67,1,194,246,115,0,121,243,223,10,223,7,148,0,156,3,103,255,123,255,81,255,225,254,144,1,73,0,75,255,82,255,72,0,45,0,219,0,164,255,245,255,59,0,225,234,150,254,68,255,136,255,239,0,249,0,133,0,27,255,158,0,180,0,193,253,174,246,158,254,248,0,20,2,178,253,103,2,171,255,187,255,138,1,236,11,147,252,192,254,228,1,218,0,49,254,54,255,183,252,193,6,28,1,229,4,145,8,14,2,116,246,161,254,7,5,139,254,131,1,184,1,53,255,163,0,103,255,206,0,199,255,160,255,56,10,172,255,40,2,33,0,193,2,37,253,181,252,107,247,166,247,198,253,22,0,248,254,95,8,213,2,124,255,120,254,215,1,11,255,51,0,227,2,223,251,25,4,8,253,141,10,200,1,20,0,228,1,83,2,176,12,121,250,162,252,76,1,95,254,67,1,81,254,34,8,78,0,172,2,87,255,84,2,28,255,37,255,172,0,160,0,76,255,28,255,135,243,248,253,156,255,65,254,139,253,126,247,253,254,10,255,4,249,40,247,223,0,115,0,182,255,230,0,45,246,212,0,77,255,200,1,209,0,181,246,10,255,167,254,154,255,209,253,3,1,242,254,86,254,77,1,154,254,50,11,179,253,42,250,94,254,96,255,118,255,40,8,171,2,223,250,37,4,168,255,148,3,108,255,231,246,211,254,241,254,7,255,6,11,243,253,107,254,80,2,190,254,208,250,240,255,135,0,186,253,92,253,9,254,142,247,185,254,19,255,105,1,166,0,88,2,152,4,247,3,97,0,251,255,209,1,17,9,64,238,202,0,162,254,57,1,149,0,32,2,92,254,40,2,183,0,95,1,129,249,176,2,238,0,75,2,139,3,73,249,243,4,235,246,112,1,236,0,40,1,208,245,240,0,229,3,240,1,105,0,75,0,77,255,235,0,125,0,216,255,57,0,234,255,100,254,48,254,18,254,175,255,64,2,123,242,243,251,24,253,78,5,168,252,228,254,232,253,131,1,154,254,184,0,171,255,102,8,138,251,132,255,119,0,218,4,136,2,199,2,113,8,177,253,184,248,96,253,62,0,87,7,243,255,55,0,29,1,89,255,142,0,126,255,66,1,8,0,221,255,26,255,120,2,69,253,18,16,12,254,67,255,208,255,186,10,47,0,165,1,80,251,114,9,204,1,206,254,75,1,164,0,178,250,34,3,197,1,202,1,10,14,249,11,232,255,122,255,75,254,132,252,146,255,241,0,144,254,80,1,161,2,109,255,130,0,154,0,89,0,81,0,171,254,239,27,175,0,118,0,29,255,230,254,6,1,20,1,138,255,138,255,11,255,7,0,144,0,169,255,120,255,110,255,28,254,70,0,221,0,36,255,243,255,42,226,93,0,218,255,193,254,34,254,26,0,228,255,25,1,76,255,182,0,70,255,90,0,192,0,50,0,153,244,153,0,165,245,33,1,47,0,241,252,0,3,128,1,39,0,194,0,202,246,218,4,113,249,80,0,12,5,28,0,170,2,247,10,86,1,210,1,43,1,132,254,120,1,114,17,12,0,41,2,153,0,65,254,221,2,99,0,8,0,114,255,94,2,196,246,168,0,167,0,194,255,148,1,184,243,96,1,115,0,106,241,104,1,54,255,50,254,60,255,208,1,100,254,192,0,149,254,99,254,107,254,254,0,101,1,15,245,30,4,190,249,130,2,2,255,82,254,45,247,159,255,16,0,201,254,245,2,192,255,156,1,83,1,29,255,40,255,227,255,219,0,67,0,63,0,26,0,24,255,118,255,211,254,241,0,204,255,26,232,223,0,133,254,99,255,35,255,55,255,163,255,2,234,226,254,62,255,133,0,46,0,151,0,188,1,40,254,103,0,141,255,253,254,203,255,161,2,208,6,186,246,103,1,237,9,101,2,119,254,211,4,221,0,139,255,182,252,142,4,105,0,114,255,146,5,3,0,89,254,36,0,142,1,74,245,211,2,28,253,217,3,242,1,175,1,224,250,64,3,148,249,146,0,187,255,146,255,164,1,126,255,79,1,13,1,207,244,189,255,168,255,50,0,175,10,14,4,205,3,115,1,142,2,87,255,144,255,67,2,193,254,130,9,8,253,198,2,241,0,159,248,39,0,241,248,226,255,103,5,200,251,193,1,127,2,82,246,8,253,47,2,42,1,56,0,91,254,50,3,70,254,22,6,182,249,88,8,244,255,245,255,80,2,73,0,77,0,84,255,77,0,92,0,143,255,25,1,69,2,184,253,160,238,251,1,61,255,183,0,4,254,56,1,44,253,19,4,238,255,246,255,248,252,234,253,249,0,150,243,136,3,210,4,30,254,126,1,240,251,64,254,189,253,227,0,174,255,252,21,91,255,255,0,109,0,115,255,7,0,228,255,63,0,93,0,45,255,0,0,162,0,69,2,103,255,212,22,190,255,122,0,154,255,166,255,51,255,75,255,243,0,56,1,111,0,77,254,151,255,169,254,16,1,115,255,6,0,158,255,240,255,183,255,230,255,131,255,53,226,183,255,190,255,108,0,81,255,186,0,67,255,154,255,16,255,219,255,158,254,252,254,136,255,30,0,87,0,0,10,85,12,113,1,106,253,82,1,9,254,190,255,131,250,178,0,76,4,85,253,198,245,155,9,245,250,8,255,117,255,85,253,159,252,165,5,165,0,112,1,251,1,183,253,215,243,97,0,229,0,53,1,100,255,30,255,43,254,70,2,126,243,176,254,102,0,20,0,96,0,64,252,41,1,29,255,80,2,232,242,238,10,131,253,123,255,191,0,105,254,170,0,192,253,53,255,232,254,40,3,85,3,10,254,143,255,88,249,255,251,155,1,242,10,233,0,200,253,104,1,152,253,77,249,47,0,135,1,187,247,54,254,221,254,107,255,174,255,26,0,227,255,168,255,100,255,225,30,32,0,181,255,102,255,178,255,212,255,155,0,255,255,174,254,133,252,170,0,181,255,155,0,226,0,64,255,184,254,17,255,194,253,165,255,95,0,168,253,175,16,25,0,222,3,49,255,68,18,59,0,188,254,116,3,107,1,65,0,167,1,248,252,118,252,177,255,252,255,195,5,37,2,4,255,0,14,215,13,103,254,26,1,22,1,125,0,133,254,125,0,76,255,133,255,4,255,196,254,63,255,91,1,53,0,217,7,195,0,152,0,152,255,233,0,181,255,222,253,52,2,79,255,171,12,159,252,100,252,6,2,76,253,131,254,163,248,146,255,68,255,116,4,5,248,74,254,71,249,251,3,142,6,13,0,17,1,17,253,154,3,221,254,241,255,75,0,232,0,144,255,60,0,142,10,88,0,175,0,137,255,43,0,219,253,186,251,169,248,145,1,51,6,7,5,215,255,41,0,140,255,233,255,57,1,168,0,147,0,155,255,199,255,141,255,178,228,54,0,242,255,16,255,92,255,127,0,25,0,65,253,151,254,1,3,19,6,120,246,200,245,64,255,86,0,1,3,227,255,47,253,42,2,105,253,71,1,147,2,225,255,177,255,91,0,109,1,182,255,244,4,115,0,224,1,238,11,34,249,168,6,247,2,111,253,240,254,183,254,31,0,111,255,234,253,241,4,73,0,179,1,202,255,224,1,157,252,164,10,69,9,122,3,198,254,144,255,240,245,170,253,217,1,121,0,204,10,123,6,105,0,67,2,96,254,169,255,158,0,44,1,191,1,231,254,35,232,35,0,217,0,185,0,56,0,155,254,151,0,108,0,207,255,230,254,28,254,36,255,178,255,115,255,0,1,185,251,20,7,39,252,91,4,43,2,188,247,13,9,139,251,232,252,158,252,137,255,187,0,103,2,62,255,73,0,213,255,12,1,181,1,250,0,204,255,221,1,7,255,37,254,195,245,78,2,85,244,165,253,116,253,203,3,84,253,81,1,116,255,176,254,38,9,134,1,52,255,39,1,85,0,212,255,65,1,242,2,100,10,61,0,14,3,118,6,180,255,167,10,54,6,181,251,98,1,49,0,224,10,187,1,6,253,60,3,204,254,19,254,13,253,142,254,176,254,49,255,132,1,118,2,129,255,163,7,137,7,246,4,6,8,13,2,132,1,50,2,174,3,235,252,59,254,158,0,227,3,157,255,210,8,195,254,19,254,129,1,166,255,177,255,199,0,93,251,7,2,2,255,179,0,61,2,243,10,37,9,151,1,95,0,3,2,76,1,1,0,250,255,175,254,142,0,196,254,162,1,30,2,209,12,10,0,92,2,226,253,197,249,43,0,79,0,10,0,75,0,134,255,100,0,201,255,212,0,33,255,159,254,211,253,234,1,6,19,151,241,10,14,111,255,64,255,209,255,4,255,132,254,76,255,35,255,144,2,78,0,68,255,120,0,135,0,3,255,75,254,48,255,105,255,8,254,217,0,125,241,106,255,16,2,121,0,68,250,127,1,55,3,201,255,113,251,248,255,58,255,253,253,216,254,232,255,84,0,129,0,40,254,7,0,207,19,142,255,56,255,240,255,241,254,59,0,82,254,114,255,197,254,90,0,17,1,200,255,114,1,14,13,97,255,235,0,166,3,69,6,37,250,207,0,142,249,113,4,140,1,54,247,20,1,192,254,195,254,233,255,20,1,249,253,163,0,54,2,110,1,250,255,214,8,13,248,106,253,28,243,123,255,29,241,150,254,164,254,113,0,146,0,177,255,214,254,238,0,221,0,99,0,194,0,70,1,69,1,144,255,32,224,197,255,241,255,8,0,215,255,251,254,236,255,250,255,188,255,116,255,215,255,167,0,131,255,129,0,81,1,100,9,25,1,176,254,37,254,37,8,170,245,60,2,228,250,120,1,114,0,6,254,38,4,193,253,239,253,19,13,44,255,8,2,18,1,93,255,14,244,163,255,53,255,92,252,49,255,220,255,47,1,139,255,22,1,31,1,204,0,205,0,28,255,14,255,227,0,3,0,99,2,66,255,54,254,212,255,47,255,122,0,122,254,47,238,117,255,98,5,183,254,184,1,221,3,10,249,164,254,217,4,199,3,35,254,248,246,42,2,54,252,177,251,217,1,253,252,206,255,150,0,71,1,138,1,245,254,120,253,88,253,72,9,17,246,20,1,196,4,40,2,10,0,119,5,38,250,223,252,9,0,47,9,201,255,155,0,71,1,88,0,96,3,172,1,179,0,94,243,6,0,32,2,121,253,206,254,132,0,73,1,123,4,128,7,156,5,197,247,158,251,85,1,228,7,80,254,159,255,117,0,25,3,100,0,75,253,174,0,55,14,198,253,142,3,45,245,231,0,108,255,64,252,195,251,57,0,188,0,232,2,59,253,71,254,21,2,217,254,7,5,123,11,171,11,117,3,99,2,188,2,108,1,51,255,169,252,151,253,48,0,94,255,12,255,194,254,208,0,4,3,132,255,55,246,198,1,74,1,36,255,79,1,150,254,125,252,197,252,140,8,216,255,154,249,100,1,96,255,129,255,70,11,187,255,215,255,209,0,55,7,20,255,192,10,232,255,131,1,98,1,145,255,14,2,19,255,135,247,39,5,163,8,144,0,164,254,78,254,193,254,93,5,78,0,138,3,189,2,27,2,122,255,158,1,240,1,187,254,220,255,116,0,124,0,102,16,221,255,73,254,48,255,237,253,156,255,173,5,81,255,211,2,116,252,51,254,87,0,127,0,165,255,131,255,116,255,76,31,70,255,23,0,163,255,107,0,176,0,218,0,35,0,193,0,174,0,229,255,252,255,77,0,153,255,57,255,116,0,215,255,176,255,186,0,203,228,68,255,125,0,202,255,43,0,9,0,207,255,64,255,69,0,120,255,232,255,139,255,60,247,241,8,145,0,226,0,119,251,98,248,113,3,104,255,75,6,247,3,82,255,235,254,98,255,113,1,49,0,23,255,221,0,19,1,69,0,108,0,136,0,132,255,1,0,42,254,120,1,149,0,84,226,55,0,53,0,213,0,9,255,80,0,39,255,245,255,189,0,125,0,239,255,115,255,165,0,182,244,14,0,201,0,106,0,242,0,2,255,206,254,171,243,203,1,246,255,24,0,241,254,109,3,181,1,74,254,18,0,130,255,247,255,177,21,63,0,22,0,55,0,172,0,21,0,177,254,127,0,160,0,208,0,121,0,13,0,197,7,164,2,218,254,160,8,178,255,122,2,18,250,243,251,29,5,124,0,217,255,190,254,116,250,108,254,121,1,221,255,242,255,178,0,110,0,46,224,26,0,158,255,103,255,13,255,145,0,24,1,248,255,29,0,199,255,85,0,203,254,25,1,26,1,209,255,229,255,11,11,77,252,141,0,88,3,79,246,150,1,130,253,150,254,249,251,230,0,171,254,137,255,239,255,1,0,190,0,41,0,241,255,247,19,59,0,74,0,123,0,230,254,231,255,212,254,4,0,52,254,40,255,39,1,39,255,26,0,227,0,62,0,129,1,236,2,107,11,154,7,135,1,116,249,87,2,148,0,56,254,160,255,42,4,222,1,117,0,255,0,87,255,99,253,109,248,112,253,116,10,165,2,28,248,222,250,169,1,243,253,167,255,246,253,147,10,153,0,5,0,49,255,244,0,235,251,75,1,221,250,174,255,193,1,116,246,70,1,28,254,72,247,76,9,177,253,25,252,8,246,211,249,93,1,72,254,217,0,42,1,39,253,250,255,116,254,182,255,110,0,186,255,41,242,124,254,205,255,84,2,126,0,39,1,27,8,133,255,75,253,208,251,13,249,92,254,127,0,176,1,87,243,25,255,10,255,105,0,75,254,189,255,137,255,131,244,255,254,47,0,55,252,123,1,106,2,163,255,7,0,202,0,87,254,218,255,140,0,202,1,15,14,242,0,232,255,213,252,144,253,237,255,12,2,94,9,212,254,111,0,120,1,223,7,175,1,125,0,231,0,219,254,181,246,134,253,50,7,255,255,210,250,158,253,168,255,128,0,80,0,75,0,30,0,172,0,21,255,34,0,206,0,177,255,72,1,128,0,229,254,50,229,155,255,4,1,68,0,40,33,21,1,63,0,173,0,224,0,226,255,98,255,64,0,133,0,123,255,234,0,205,0,191,255,152,1,249,0,222,253,226,255,255,255,82,254,80,0,102,0,62,254,96,255,254,233,145,0,106,254,161,254,37,0,26,1,232,0,126,252,174,1,229,12,105,251,209,253,239,1,125,10,235,255,41,255,169,255,216,2,201,255,235,0,174,1,6,255,7,254,250,1,128,255,184,255,216,12,52,6,35,1,7,0,217,255,80,252,222,1,183,6,168,0,195,251,225,0,74,1,200,5,73,255,171,253,13,232,156,2,125,254,160,2,83,255,201,255,113,0,40,0,143,255,212,255,85,1,172,254,174,253,23,252,221,6,127,0,197,255,25,2,214,248,121,5,88,3,127,251,22,255,208,4,206,253,220,1,110,0,140,8,146,0,119,0,71,8,152,252,194,1,85,2,141,254,186,250,28,252,136,255,17,254,61,3,111,0,127,252,187,234,98,253,134,1,138,255,4,0,109,0,4,3,239,1,196,0,154,1,131,255,44,3,170,1,132,3,180,1,131,4,215,253,57,251,19,1,10,1,133,252,63,0,13,251,11,2,220,253,115,246,239,0,139,4,72,0,188,255,216,249,164,8,172,254,219,5,238,1,97,253,183,255,231,254,86,2,109,7,140,249,179,252,10,1,27,3,223,253,194,253,19,0,51,254,115,1,32,1,137,240,165,1,43,1,135,255,255,245,191,255,118,0,181,0,29,255,207,2,164,255,226,246,150,243,63,246,58,255,58,0,255,4,203,254,152,0,53,253,210,1,196,254,10,0,98,0,32,6,9,252,238,255,77,254,214,255,46,10,179,7,137,255,193,2,254,0,187,1,36,0,20,3,111,4,210,4,233,8,174,3,115,0,69,2,143,255,62,255,74,253,178,1,226,255,19,11,89,254,180,1,10,2,150,1,49,5,167,4,188,245,165,1,215,245,134,2,54,255,125,2,98,2,184,253,101,1,206,249,13,254,50,251,134,0,173,255,16,251,130,9,198,255,148,244,129,2,227,254,172,0,34,254,110,254,72,2,100,251,119,255,18,255,105,255,89,253,149,253,17,254,20,4,1,5,100,251,68,254,120,1,177,7,75,253,229,254,106,2,128,0,194,245,166,255,141,255,160,2,202,6,53,254,7,2,100,252,22,10,169,3,213,253,160,2,131,0,31,0,7,3,51,1,230,254,241,253,237,250,252,253,10,0,239,0,27,240,118,0,10,0,103,253,241,255,28,254,216,1,6,1,23,1,165,2,13,253,8,5,2,251,147,1,154,2,118,254,50,251,253,244,35,255,109,0,91,2,242,2,183,3,232,1,109,255,149,255,86,254,83,7,8,8,127,255,239,0,207,253,81,0,188,254,243,0,93,1,197,0,213,252,110,255,95,252,169,4,153,5,248,252,137,12,178,1,250,255,161,9,25,255,199,255,56,1,131,3,116,254,86,255,219,253,90,1,135,0,17,0,172,253,145,1,13,1,243,1,192,255,191,254,170,254,124,255,200,254,213,22,20,1,152,255,247,255,206,255,90,253,34,254,155,251,59,250,10,8,156,0,26,2,195,1,12,10,239,1,101,0,74,0,15,253,98,0,173,2,120,9,49,248,26,4,232,254,250,251,29,0,78,255,12,255,122,255,130,0,119,255,153,255,11,255,113,8,66,254,8,252,208,1,61,2,39,254,190,1,18,241,174,3,19,251,178,254,56,2,240,253,211,254,159,1,28,253,149,2,211,252,81,3,211,5,6,3,250,252,101,6,47,252,10,255,135,2,196,253,116,255,126,244,114,253,118,253,201,254,83,1,91,255,245,2,35,3,66,252,192,2,171,0,124,1,251,2,159,0,161,10,193,249,238,3,138,255,171,253,169,11,139,10,69,0,139,1,11,2,145,2,182,1,190,0,72,0,164,0,244,254,111,255,250,1,218,253,222,0,199,241,5,0,83,255,60,0,62,255,165,2,174,2,212,2,149,255,114,3,173,254,14,0,202,255,43,2,227,1,243,5,119,0,114,255,118,254,109,249,40,252,18,0,148,255,66,255,141,0,28,2,25,1,42,251,109,247,171,254,185,254,10,252,34,252,86,18,46,0,6,252,104,1,97,253,173,255,218,0,89,3,144,0,68,255,207,1,133,254,197,253,159,252,191,250,65,254,238,255,192,255,81,20,132,0,90,0,98,255,124,255,125,1,171,255,149,255,153,255,202,3,213,253,76,251,10,7,206,4,253,0,28,2,140,254,213,246,126,254,67,3,63,253,75,254,173,3,27,3,74,255,144,254,64,4,168,0,0,1,210,0,101,253,34,1,247,6,132,253,165,0,149,254,126,2,57,242,80,7,205,7,223,5,67,255,229,245,153,254,128,1,237,1,128,254,110,253,34,249,225,3,206,254,148,0,198,0,163,0,174,1,199,254,107,255,175,254,96,1,158,254,228,1,102,1,248,254,83,238,208,253,201,255,154,0,118,1,195,254,86,254,166,5,95,255,227,254,146,255,209,0,43,1,25,9,99,0,126,5,94,5,225,3,154,4,99,254,126,253,153,255,94,14,219,248,14,253,178,250,163,254,136,2,20,254,243,2,188,0,114,0,68,254,94,252,32,255,63,1,212,0,199,4,120,253,81,2,13,5,247,250,24,0,56,253,31,10,18,254,223,5,247,255,22,2,155,3,210,5,217,3,235,1,16,1,220,3,92,1,9,254,58,254,125,3,153,1,90,254,93,251,25,12,90,2,110,254,206,1,62,6,37,255,214,3,63,1,125,0,46,2,156,255,251,254,108,0,197,255,149,242,76,0,215,251,106,255,34,249,51,248,129,7,215,4,170,1,251,1,173,0,168,252,195,252,230,253,247,0,77,251,232,1,186,251,197,1,176,251,253,3,137,8,217,244,171,1,177,0,246,252,74,255,129,2,98,253,91,0,57,2,50,0,166,255,59,2,108,0,138,254,174,0,205,7,196,3,132,2,84,254,180,248,156,2,171,0,64,1,164,2,121,0,38,255,109,7,167,252,47,253,62,255,127,246,222,255,121,249,96,1,124,253,39,1,59,2,253,0,224,254,6,249,32,0,74,0,183,255,122,252,94,248,154,251,157,242,168,0,194,254,23,0,13,253,71,254,201,0,172,255,243,1,111,1,103,255,86,254,204,2,138,2,55,254,80,0,59,253,91,3,206,247,45,253,59,255,250,251,3,255,27,1,93,251,125,252,123,5,139,255,231,255,193,29,193,255,157,254,229,254,208,253,171,255,154,254,211,255,63,0,179,0,63,255,130,0,218,254,92,253,243,253,117,252,82,254,141,253,109,235,229,253,1,1,82,2,83,255,122,3,203,0,223,255,120,255,221,252,223,1,200,255,134,253,208,1,105,252,110,255,50,1,5,0,198,0,166,255,118,255,175,254,218,18,202,254,3,1,115,6,81,253,116,249,168,1,169,10,58,252,195,255,130,1,60,0,1,3,184,255,140,249,49,0,106,0,247,1,74,250,224,251,124,3,103,1,209,0,127,255,4,1,126,255,223,247,30,3,232,1,78,3,188,252,146,254,250,6,67,247,28,254,72,0,136,245,196,252,167,252,152,3,48,2,162,3,59,255,56,0,152,252,222,255,157,254,161,3,35,0,63,254,2,2,70,0,3,251,208,0,97,1,70,14,0,255,134,0,129,252,72,255,119,1,146,1,40,6,235,5,156,255,74,254,89,253,128,1,119,4,232,255,100,0,254,244,42,2,37,255,105,0,140,2,38,245,148,255,44,0,50,1,189,1,42,254,129,251,110,251,25,5,27,253,199,4,69,254,186,252,118,1,72,244,72,0,178,253,181,253,102,14,76,0,19,254,246,0,68,5,65,251,217,1,12,255,208,254,145,7,188,255,142,253,22,1,136,1,143,4,149,248,203,254,218,1,226,0,91,254,161,255,29,254,105,0,108,255,237,2,82,254,15,244,235,252,255,248,191,248,98,255,23,254,92,253,52,255,38,3,94,252,136,243,52,255,150,255,212,252,135,4,136,2,119,0,163,255,51,255,117,255,24,1,150,225,124,254,124,255,244,255,180,254,32,0,82,255,100,0,153,0,249,255,33,1,227,255,40,252,183,254,176,253,8,10,192,2,32,2,66,0,9,2,107,253,160,249,156,252,202,254,57,1,46,254,165,254,110,255,197,0,10,1,253,2,16,255,55,255,247,254,151,251,221,255,205,253,156,254,172,0,94,3,247,14,11,6,174,249,91,250,114,241,132,1,36,2,55,254,143,0,218,255,146,1,255,0,72,3,65,253,102,255,8,3,242,251,99,233,205,4,118,255,242,3,55,3,166,253,37,252,19,255,47,0,227,255,172,1,210,0,87,0,245,255,236,255,251,254,180,243,195,4,230,247,124,255,254,254,195,2,134,253,110,3,26,254,221,3,236,254,119,255,249,254,80,2,224,4,218,1,219,254,43,252,77,8,115,253,85,250,191,252,14,250,131,1,243,254,93,1,186,2,39,1,102,3,149,2,252,5,202,0,142,2,106,1,15,251,132,15,117,253,224,0,213,0,40,253,173,255,63,2,9,254,2,253,47,2,111,253,86,0,173,3,218,5,184,255,249,8,133,5,136,254,185,2,30,253,128,1,217,252,158,254,117,4,118,1,162,4,171,253,222,0,118,2,51,253,139,249,106,0,159,250,95,252,214,3,115,242,191,254,55,255,95,251,109,255,243,255,12,1,103,0,151,11,221,247,96,254,190,2,121,1,154,251,92,0,195,3,18,254,162,255,76,254,101,7,121,5,216,255,72,250,184,249,188,7,44,0,254,0,164,2,17,2,133,252,161,255,9,0,84,255,127,255,158,0,109,254,133,251,2,4,102,254,86,0,33,10,220,251,147,253,224,1,254,0,244,252,179,2,4,252,79,0,64,255,40,247,61,251,20,253,90,2,243,0,82,1,38,2,68,254,126,255,79,0,24,0,68,13,124,0,196,253,237,2,208,3,33,0,141,252,144,254,159,253,182,2,199,253,208,253,192,0,100,3,132,2,173,0,86,0,50,239,121,2,219,30,152,254,222,1,237,1,206,254,14,0,244,0,96,0,71,0,87,255,80,1,90,1,74,0,204,255,243,6,60,3,4,255,227,2,19,252,13,253,31,0,210,255,200,0,69,2,245,255,34,3,80,4,180,12,227,251,211,2,21,254,68,246,230,246,11,255,52,1,3,252,200,254,51,2,171,255,223,3,240,255,224,0,171,255,67,252,214,8,23,238,61,250,102,0,54,1,42,1,149,252,250,255,244,254,8,0,228,254,68,1,41,254,32,255,133,0,222,5,78,249,185,251,152,255,41,3,24,10,239,254,10,252,216,254,130,0,220,2,253,254,177,254,23,253,149,253,52,253,247,0,247,1,94,3,235,254,119,255,32,255,223,236,124,0,21,1,42,1,216,255,169,0,166,2,45,2,27,17,165,2,32,248,6,254,148,255,209,255,49,0,141,255,252,254,212,254,206,0,172,4,239,255,202,0,109,1,216,252,39,254,96,255,159,253,14,2,156,251,93,6,148,244,201,2,25,254,147,255,28,2,1,254,221,0,118,254,116,250,255,3,52,254,168,1,170,255,149,252,235,249,168,255,12,255,195,249,57,244,99,1,166,0,74,1,178,254,187,254,249,1,48,14,32,249,90,6,85,254,61,2,173,4,195,254,202,253,105,253,204,1,82,1,70,254,171,253,29,6,170,252,234,253,37,255,128,255,129,247,227,2,40,4,2,8,195,255,163,254,105,1,137,254,87,4,134,255,135,255,92,255,243,245,170,3,222,6,241,255,116,3,97,3,138,253,195,253,226,3,88,4,230,255,9,0,226,255,53,15,218,255,106,5,93,2,56,2,88,253,117,0,37,0,60,2,245,0,203,255,250,251,15,255,141,1,107,1,160,249,201,253,230,255,70,253,195,247,247,251,147,250,101,5,94,254,146,1,234,253,9,0,119,4,223,3,181,2,253,9,12,251,249,4,64,255,201,4,108,3,216,1,67,3,253,1,60,254,17,250,226,1,79,4,142,253,213,254,44,6,4,250,87,2,197,8,247,1,146,255,169,248,210,3,122,251,126,255,103,253,192,1,33,251,92,2,240,253,91,253,57,253,78,0,205,253,163,254,203,255,5,1,184,3,174,254,234,253,43,0,254,255,5,246,184,7,89,9,179,6,228,3,252,21,12,4,171,0,228,255,57,255,173,255,130,255,221,255,8,255,119,254,36,0,209,0,77,0,255,248,244,0,148,255,126,255,215,255,190,253,213,246,81,253,114,6,131,0,118,255,151,1,28,255,188,250,47,255,183,252,52,5,226,253,220,0,63,255,75,3,153,255,85,3,5,1,115,253,217,0,149,255,143,255,202,255,201,239,233,250,225,254,225,15,136,254,185,255,43,0,55,250,153,254,31,254,78,0,17,2,177,2,62,255,178,0,60,0,27,252,237,249,151,6,89,1,169,0,10,1,78,11,83,0,12,254,87,254,116,254,11,255,6,0,5,2,112,0,129,0,213,2,135,255,108,254,234,0,47,0,195,255,134,255,198,2,69,239,217,3,56,0,151,255,211,255,19,4,208,2,73,0,65,1,100,17,178,249,91,0,148,253,213,254,250,1,254,2,142,252,138,2,118,255,123,0,160,253,210,0,210,249,230,253,194,255,246,0,208,1,180,254,232,249,223,8,23,6,57,255,192,252,147,251,227,252,85,1,68,7,92,6,147,251,161,253,125,2,108,254,181,1,132,251,30,2,38,254,142,252,158,253,196,250,97,255,244,5,144,5,169,0,250,255,52,0,191,1,119,234,176,253,244,0,218,254,44,0,164,0,205,255,147,0,202,0,208,255,139,0,113,0,113,254,239,255,83,255,57,255,1,0,17,0,90,255,15,0,254,254,249,255,238,0,140,233,118,254,172,252,8,255,210,255,192,0,224,255,247,251,163,254,151,0,227,1,130,0,164,249,193,242,247,5,182,2,207,254,228,2,155,254,21,254,70,255,143,249,142,250,151,252,213,0,140,2,73,248,63,1,149,251,153,255,208,255,161,2,155,0,141,253,91,4,213,1,158,251,109,7,72,255,19,255,216,254,185,244,136,255,211,0,67,3,57,0,198,252,248,4,1,255,87,252,242,0,243,253,68,3,178,254,137,1,144,253,111,0,165,254,78,255,143,242,219,0,160,254,39,7,216,254,75,2,155,254,181,251,5,0,57,1,34,241,118,254,46,3,138,255,23,255,233,255,131,255,235,255,122,250,45,3,109,254,178,9,186,1,72,255,166,3,84,1,216,1,118,1,49,4,229,254,212,246,221,1,125,254,55,253,47,4,125,252,252,0,237,250,10,254,137,254,102,254,7,249,174,2,163,253,115,255,153,252,15,249,220,10,53,0,19,255,19,255,141,10,176,3,44,0,83,2,3,0,239,4,234,249,37,247,26,252,221,0,99,1,193,254,29,253,120,251,174,253,161,11,191,0,215,255,228,254,83,0,228,1,225,1,183,255,243,255,138,0,55,245,115,252,190,253,117,255,224,251,189,0,123,253,109,255,195,255,88,255,112,1,130,0,134,1,91,16,101,0,79,0,211,255,195,1,162,250,107,248,234,253,211,254,45,252,100,253,235,253,94,244,130,1,62,2,58,254,252,255,42,2,136,255,110,1,83,0,55,4,161,254,156,0,133,1,44,30,83,0,102,0,65,255,221,251,1,255,170,255,195,1,45,255,175,0,6,3,50,1,3,255,82,9,142,4,23,248,223,0,182,1,255,4,185,6,233,255,165,255,94,2,251,250,249,252,100,243,232,253,31,2,109,3,116,4,176,249,165,253,38,2,90,253,50,254,248,0,209,0,253,253,202,254,22,246,46,248,231,0,17,254,63,1,26,2,253,1,143,255,239,255,143,0,10,244,227,255,204,255,43,1,169,2,83,2,134,1,18,2,114,254,55,252,216,1,135,251,92,3,17,16,73,1,97,251,77,253,163,253,91,3,49,1,218,3,175,255,237,7,152,1,2,0,118,246,59,0,171,255,113,252,227,254,236,253,28,0,178,1,9,247,180,255,95,244,51,0,56,3,6,249,253,8,110,2,175,253,247,255,131,2,246,0,171,1,193,0,51,0,118,0,4,0,234,0,203,1,31,0,104,254,198,2,248,254,144,0,108,254,36,254,22,1,28,237,143,255,126,1,227,255,177,0,89,1,223,255,239,255,171,255,139,23,72,0,91,255,32,2,58,255,75,0,234,254,250,254,155,0,245,1,207,254,233,254,73,254,226,5,59,3,149,252,224,245,84,251,79,251,149,0,16,0,35,2,252,3,152,253,118,1,63,255,101,255,213,241,231,0,8,1,161,247,90,0,163,1,62,2,229,252,177,0,72,1,240,2,217,254,210,0,152,254,30,251,79,10,156,243,243,255,222,255,233,1,228,1,122,254,97,255,227,254,27,0,188,1,4,255,9,1,18,2,102,245,172,254,249,249,26,9,128,251,142,255,196,1,48,1,32,255,61,254,195,254,189,253,45,1,201,253,190,4,174,253,147,253,98,245,59,0,1,1,154,1,253,255,145,0,70,0,109,3,225,243,244,0,146,251,236,0,132,251,109,37,58,255,156,255,234,255,237,0,241,255,155,255,233,255,46,0,129,0,63,0,113,255,5,0,205,254,113,255,247,255,27,0,50,0,40,0,160,23,25,0,58,0,240,255,95,255,147,255,99,255,137,0,115,0,121,0,164,0,4,0,202,255,77,25,188,255,136,255,227,255,45,0,248,255,243,255,78,1,169,255,105,0,76,250,28,0,178,254,93,255,192,255,211,241,185,255,176,0,61,255,53,0,255,255,160,255,208,253,235,255,135,0,178,0,179,255,150,239,20,0,240,9,51,255,85,0,180,254,158,0,61,0,151,255,142,1,168,255,14,0,241,0,107,255,62,0,132,255,120,255,103,255,27,0,190,0,35,10,25,0,61,246,238,253,17,7,152,255,63,245,42,1,145,0,253,252,139,0,165,0,158,9,10,254,92,3,82,255,199,0,74,0,163,0,82,253,231,255,57,0,153,255,203,254,152,254,39,0,216,254,51,245,193,254,74,252,90,253,121,251,49,249,219,5,240,6,80,255,9,0,44,0,187,253,69,0,39,0,162,0,70,1,160,255,73,1,247,255,250,4,117,246,151,255,206,255,116,16,233,255,146,0,25,255,234,255,206,255,128,255,11,0,28,0,116,0,41,255,46,0,217,0,204,0,153,0,183,255,100,255,156,255,225,255,72,10,66,255,46,247,199,0,35,249,194,0,53,0,38,0,165,233,66,0,169,0,96,1,217,255,106,255,255,255,50,254,41,0,158,255,146,255,216,255,125,233,66,255,98,255,156,250,205,0,29,255,110,254,81,0,85,255,151,1,131,255,192,254,56,254,195,254,233,1,186,2,204,254,149,15,84,255,146,1,196,0,55,254,42,251,64,255,187,253,193,255,21,255,153,0,186,251,203,255,211,255,170,255,240,0,64,255,156,245,52,9,153,0,196,255,21,1,33,0,198,0,199,255,197,4,88,244,185,254,186,254,208,255,61,0,93,0,222,255,89,255,201,254,136,3,92,1,159,1,57,0,208,7,179,255,238,0,40,0,0,244,220,255,27,1,202,255,113,253,6,255,234,255,199,253,184,253,238,255,221,2,5,255,184,255,228,255,80,0,206,254,211,0,188,0,107,255,244,17,49,1,116,1,95,1,174,255,72,255,177,255,191,255,128,10,110,10,202,255,175,255,86,255,19,0,168,255,122,0,139,255,33,0,51,0,227,255,143,255,99,244,46,0,34,243,90,0,8,0,76,255,29,255,194,255,43,0,231,255,187,0,132,254,227,255,167,255,138,0,160,254,231,0,72,10,158,0,201,7,241,255,94,1,107,0,42,252,240,255,160,251,136,0,85,255,214,255,45,10,70,255,110,0,167,0,137,6,116,4,227,255,79,253,81,0,141,3,57,254,163,11,44,0,1,0,252,254,26,0,28,0,166,255,200,253,133,255,81,255,232,0,218,255,68,9,111,0,56,1,17,2,191,255,75,1,100,0,232,1,12,0,172,253,15,254,7,9,183,251,218,4,162,255,14,247,98,255,165,245,16,0,24,255,24,13,24,0,203,255,173,255,251,255,204,255,205,0,152,255,218,254,217,0,60,255,219,255,249,255,0,0,228,255,211,255,60,0,13,0,41,0,111,0,142,0,93,227,216,255,56,255,18,0,90,255,14,251,209,255,6,255,176,253,164,253,33,0,83,0,52,255,149,251,90,255,68,5,199,250,184,0,50,0,174,216,30,0,24,0,72,255,137,0,53,0,32,0,87,0,229,255,151,0,100,0,10,0,209,255,28,0,118,255,12,0,95,244,136,254,58,0,168,0,106,6,144,0,15,4,113,254,217,252,5,0,77,249,12,0,114,255,179,255,206,254,246,2,162,2,174,255,144,12,143,254,60,0,224,1,20,1,89,254,238,19,253,12,169,0,47,0,235,0,37,0,81,0,170,255,228,255,200,255,197,255,51,255,130,255,28,0,23,1,15,223,137], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1773105);
/* memory initializer */ allocate([0,230,255,103,254,237,255,106,0,93,255,180,255,199,255,235,0,7,0,131,0,175,255,59,255,194,254,1,5,54,1,138,244,204,3,201,250,35,0,204,254,163,255,128,255,177,1,15,2,63,255,233,250,162,0,222,255,169,255,99,255,6,1,135,19,25,0,201,254,163,254,94,0,250,254,0,0,37,255,57,0,12,0,252,255,10,0,239,255,38,0,192,254,48,0,156,0,80,0,248,22,48,0,45,0,31,0,2,252,31,0,227,0,41,253,121,255,5,1,235,255,80,253,51,1,124,12,53,2,115,2,222,253,237,0,193,246,223,255,86,6,169,255,186,6,55,255,208,2,229,253,224,254,12,252,141,0,124,254,184,255,236,255,197,255,6,248,203,255,155,255,208,0,23,255,189,252,240,255,20,12,2,0,54,1,94,0,150,254,93,255,128,255,30,0,234,255,111,255,164,1,255,255,66,1,244,253,182,10,236,254,206,0,85,246,63,2,115,253,170,254,132,5,1,0,75,0,242,255,54,0,170,0,66,0,86,1,251,254,197,2,181,255,192,8,122,255,32,0,153,2,171,0,122,255,30,7,109,0,57,2,57,12,168,0,156,254,53,0,235,4,189,255,43,0,120,0,132,255,137,8,157,9,239,255,1,255,163,254,89,255,98,255,237,255,84,0,36,253,52,252,30,1,87,0,251,17,96,255,7,0,141,0,1,0,30,1,54,1,197,254,157,255,26,1,128,1,68,0,93,0,233,248,63,0,170,255,121,0,219,254,210,0,115,0,63,0,82,255,104,2,200,248,132,255,251,4,42,1,185,0,245,254,188,13,151,255,94,255,3,255,78,254,94,253,166,255,72,247,38,0,168,0,251,254,33,1,70,0,130,14,0,16,175,255,17,0,56,0,57,0,68,0,236,255,110,255,28,0,104,255,239,255,159,255,125,255,88,10,71,0,225,242,40,0,235,254,57,1,85,0,230,255,41,0,54,255,76,0,8,0,176,255,96,255,154,255,239,255,155,0,189,0,16,6,86,242,66,254,153,255,24,255,51,255,194,253,124,255,169,0,206,0,153,6,19,4,32,253,78,255,163,255,103,244,26,0,5,255,108,255,139,0,70,0,187,254,117,0,255,243,9,0,43,0,245,255,132,254,66,255,198,254,60,244,50,0,182,254,230,255,198,2,153,0,19,0,129,244,58,0,20,244,200,255,7,0,40,0,9,0,65,1,219,255,51,254,234,255,138,254,57,0,53,255,16,0,241,255,231,255,240,255,219,255,248,255,215,255,140,255,28,31,70,0,197,255,77,0,200,0,0,0,213,255,118,0,184,255,189,255,104,0,250,255,78,0,171,0,13,0,153,255,25,3,98,0,126,237,52,255,11,0,30,0,184,255,33,0,194,255,47,0,157,0,236,0,109,255,96,254,42,253,66,2,5,0,198,15,162,0,254,255,63,9,118,255,71,255,214,1,49,12,70,0,185,0,234,255,51,255,37,0,193,255,177,254,115,254,43,0,10,0,99,230,144,255,2,255,106,0,127,255,20,255,0,0,6,255,42,0,128,255,84,0,237,253,229,255,211,8,230,254,235,255,186,255,104,254,19,0,104,253,177,3,60,255,206,251,89,5,216,255,95,243,28,0,20,0,171,247,125,0,87,1,113,0,72,2,242,255,50,0,126,255,48,254,1,2,39,3,134,238,193,255,57,0,96,4,64,0,226,255,90,1,206,1,129,0,219,0,226,255,31,1,192,1,128,1,198,0,153,254,73,4,0,255,60,3,181,245,198,254,80,1,250,1,112,255,194,0,167,0,43,5,239,254,184,239,245,10,138,255,248,255,136,0,174,255,44,255,53,0,253,254,195,255,94,0,214,0,11,0,29,0,250,254,187,255,24,0,102,0,45,0,225,255,70,255,58,0,129,2,147,2,84,255,44,14,64,255,89,254,34,0,3,0,45,0,19,0,93,1,117,0,251,255,197,236,99,0,108,255,180,0,119,2,50,0,52,255,129,2,164,255,156,0,63,248,53,4,201,0,56,0,107,254,198,2,36,255,131,248,239,254,22,255,100,0,90,228,30,11,79,0,145,255,236,255,74,1,227,0,220,255,49,1,45,0,81,0,148,0,243,255,68,0,108,1,195,254,184,255,229,7,28,0,93,0,72,1,0,255,75,255,243,9,235,0,178,251,130,0,191,253,92,255,10,5,93,7,85,255,109,255,81,243,68,1,184,255,199,254,194,255,32,0,28,1,118,255,247,255,110,255,173,6,122,254,41,7,33,1,125,0,65,9,60,0,223,0,119,255,130,2,143,255,204,0,32,1,20,250,118,255,228,0,112,1,219,0,146,253,17,1,139,12,41,255,89,254,139,0,65,0,85,0,53,255,71,252,11,0,193,0,38,1,23,1,195,12,246,0,183,246,197,255,188,254,136,0,20,254,23,0,200,255,79,0,51,1,115,0,110,255,181,8,69,1,112,249,171,253,89,254,152,8,212,255,48,0,130,1,140,1,134,255,220,255,35,0,35,38,33,0,189,255,19,0,222,255,15,0,41,0,231,255,226,255,195,255,20,0,135,255,117,0,101,255,228,255,191,255,229,255,40,0,137,0,188,0,45,255,16,255,71,0,223,255,247,236,200,7,56,0,115,245,255,255,151,0,160,255,30,1,114,254,94,254,35,255,39,1,118,254,137,255,74,255,132,255,77,0,7,0,212,255,168,0,222,255,102,255,1,1,4,0,142,255,122,2,131,0,66,19,138,255,196,246,46,0,52,255,127,255,160,243,118,255,23,254,198,1,160,255,120,0,65,254,9,0,26,255,174,0,95,44,200,1,251,254,182,255,7,255,228,255,149,0,177,255,220,255,211,0,246,255,213,0,146,255,81,1,40,241,4,0,33,255,238,255,136,0,222,254,101,255,21,255,57,0,191,1,17,254,25,255,241,255,244,251,171,255,102,255,187,238,237,255,19,255,89,251,12,0,237,255,2,0,168,255,172,255,13,1,249,255,175,1,230,255,140,245,156,255,31,1,225,255,156,244,96,255,173,255,58,255,9,0,183,0,233,254,188,255,233,255,201,255,139,11,135,255,185,255,183,0,66,253,189,254,153,6,124,255,53,1,136,0,63,251,184,1,131,255,121,249,33,6,95,255,148,255,232,0,13,1,252,253,37,0,21,0,252,254,26,255,52,2,137,254,224,0,129,0,236,16,136,255,234,12,153,0,231,255,252,254,172,255,123,0,21,0,5,0,239,255,111,255,212,255,7,0,255,255,34,1,166,246,74,255,51,0,165,3,13,4,26,0,211,0,187,0,9,249,68,0,19,253,204,255,148,5,221,249,251,254,34,0,57,255,210,2,129,255,138,255,142,255,175,246,146,0,238,251,185,255,61,250,106,255,109,247,151,0,227,255,6,0,96,0,67,251,26,1,219,0,210,1,144,0,212,254,109,0,182,255,125,0,47,11,2,0,109,244,38,255,235,0,3,0,103,1,63,1,116,1,12,254,241,254,238,1,135,10,191,255,227,255,47,0,74,0,222,255,161,255,208,255,180,255,185,255,87,244,226,255,245,255,26,0,80,255,107,0,96,0,22,0,196,255,114,0,186,255,109,255,213,255,69,27,110,0,170,255,33,0,66,0,8,0,195,255,52,0,87,255,82,0,233,0,56,0,141,255,217,254,241,0,227,251,182,240,177,255,105,1,155,252,112,255,112,255,219,252,158,0,234,254,3,2,4,0,195,254,149,3,99,253,242,12,253,0,36,5,3,1,12,0,234,31,15,0,129,0,56,255,120,0,245,255,34,0,179,255,243,255,1,1,79,0,9,0,23,0,54,0,73,0,0,0,12,217,5,0,7,0,43,0,29,0,4,0,152,255,43,0,220,255,76,0,28,255,1,0,179,255,100,255,187,255,47,255,84,0,246,244,242,0,75,250,50,253,242,255,248,6,15,2,226,0,124,38,83,0,241,255,123,254,34,0,51,0,240,255,210,255,255,255,232,0,115,0,26,0,214,255,132,255,178,255,58,0,20,12,59,245,145,255,223,0,226,254,23,0,86,255,90,255,248,254,75,1,84,255,207,255,230,255,166,0,56,10,128,0,46,12,59,0,76,3,135,255,8,254,63,255,203,255,161,255,26,1,235,255,248,255,245,255,58,0,208,255,102,38,25,0,230,255,53,0,113,0,96,0,125,0,12,0,192,255,185,0,225,255,19,0,5,255,205,254,120,255,103,5,219,255,128,255,56,0,207,16,24,255,240,254,44,0,64,255,19,2,113,255,71,253,13,247,70,0,229,0,80,254,176,253,238,4,138,3,49,255,242,5,5,1,88,225,217,255,48,252,150,0,115,0,117,255,61,0,230,255,45,255,39,3,231,255,55,1,158,255,215,254,133,0,205,1,147,255,250,255,249,251,236,0,221,244,86,0,136,8,2,255,173,255,137,255,110,3,149,255,231,255,100,6,160,6,237,5,249,0,215,255,229,254,190,255,229,2,192,2,126,252,46,1,214,1,104,1,249,255,142,232,26,0,12,1,147,255,150,0,202,0,196,0,250,254,199,255,160,0,155,0,7,0,9,0,118,233,28,0,127,0,112,0,180,255,234,252,45,0,138,255,201,0,193,252,67,0,175,255,199,0,40,1,156,6,226,255,130,255,135,255,29,0,131,1,215,0,13,1,250,253,24,255,155,0,175,10,21,255,174,255,223,255,17,12,144,241,217,255,205,255,124,0,36,255,37,0,51,0,127,255,194,0,176,255,81,0,0,0,17,255,124,248,12,255,107,0,116,1,111,0,206,0,162,1,39,0,138,255,245,247,66,254,98,5,149,2,169,247,122,0,151,255,60,0,16,1,165,255,29,255,48,0,102,243,168,255,147,255,199,0,54,2,158,0,108,9,228,238,79,255,153,0,252,0,24,0,189,254,8,1,140,255,244,255,179,254,99,0,75,255,132,255,0,1,125,255,217,255,211,255,168,255,69,0,230,255,83,255,44,237,30,1,85,255,174,255,175,1,18,0,197,252,149,255,142,0,60,0,44,1,166,1,7,1,61,0,94,1,85,0,64,4,123,255,252,250,70,0,31,238,5,0,114,0,233,255,23,0,91,11,174,0,43,0,18,0,33,0,225,255,64,1,247,255,34,1,2,0,249,255,39,0,245,255,52,0,32,0,252,255,6,33,18,0,10,0,67,0,20,0,22,0,253,255,47,255,153,255,44,255,155,255,155,255,92,254,235,244,228,255,142,1,140,0,3,4,69,255,222,246,150,1,104,255,224,254,211,2,100,254,197,248,185,0,129,2,66,255,107,0,249,255,134,243,128,255,130,254,165,0,0,255,85,0,96,0,155,0,112,255,175,1,156,254,86,1,52,246,114,247,247,254,192,254,191,250,27,0,67,248,99,248,95,0,178,255,56,254,153,254,126,1,38,255,154,255,164,0,126,1,139,3,87,2,153,2,27,11,179,16,17,0,100,255,248,254,73,0,104,0,231,255,136,255,91,0,84,0,69,1,170,0,191,255,11,255,233,255,89,0,52,0,43,18,124,0,185,0,30,0,65,1,145,0,111,0,15,251,128,0,100,255,64,0,24,0,114,248,133,0,172,255,246,255,34,0,33,3,108,255,168,255,169,0,105,249,163,1,203,6,52,255,186,255,185,0,117,0,123,1,92,254,145,0,190,241,248,254,94,4,75,1,206,252,103,253,92,254,74,0,32,0,104,255,30,255,6,0,216,0,77,16,23,0,206,4,239,0,2,0,199,255,78,253,4,2,90,0,58,0,232,255,195,255,175,0,20,245,143,255,242,254,94,0,241,246,98,255,205,251,237,254,121,253,1,241,37,0,171,16,20,0,207,255,168,255,72,0,85,255,61,255,45,0,233,255,97,255,192,255,110,0,45,255,42,0,45,255,55,6,20,1,178,241,213,0,54,0,76,255,18,3,164,255,183,254,126,1,88,1,165,0,193,255,14,0,249,255,66,0,29,0,171,34,43,0,206,255,65,0,13,0,15,0,48,0,216,255,114,0,125,0,229,255,158,0,3,0,75,3,8,0,122,253,100,0,207,243,184,6,88,0,130,3,90,1,184,244,73,255,22,14,0,0,33,0,99,0,180,255,248,254,161,254,4,254,222,253,153,255,252,0,207,255,46,0,224,255,48,0,11,255,67,0,152,246,84,1,81,12,102,255,232,254,72,254,118,1,32,255,217,255,48,253,223,254,120,255,233,243,158,255,219,255,170,255,145,0,51,0,132,0,5,3,122,251,182,254,63,254,115,255,217,248,154,2,136,245,146,255,118,252,205,254,29,243,31,1,55,0,247,253,83,255,81,254,129,254,67,0,228,255,34,0,247,0,254,10,199,5,32,0,108,247,167,249,135,0,72,0,3,0,122,2,76,0,246,1,206,254,146,254,136,255,37,255,142,7,116,1,126,255,143,255,255,0,242,255,30,0,81,253,192,253,29,3,50,1,200,246,14,255,14,8,69,0,225,8,26,0,236,255,235,255,188,255,187,255,246,237,60,0,85,255,21,255,241,254,175,0,146,255,147,0,100,0,92,6,59,255,254,255,94,240,8,2,44,251,235,255,62,0,116,254,1,2,143,254,88,255,29,1,49,2,131,0,67,5,83,0,155,255,89,0,206,0,5,0,204,17,233,255,167,4,39,0,96,1,98,255,99,0,61,255,223,255,225,1,66,254,131,255,181,0,118,10,44,11,244,253,17,255,55,0,152,254,154,254,208,253,93,0,51,1,29,1,77,0,217,254,166,255,114,0,211,255,54,0,184,254,94,0,34,255,226,255,116,236,92,255,100,0,123,1,208,0,168,1,245,255,26,0,10,0,230,255,224,255,114,0,30,0,18,0,212,255,35,255,72,255,224,255,0,0,157,255,215,220,249,255,223,255,1,0,41,0,253,255,13,0,9,0,210,255,170,255,47,0,56,0,72,0,249,255,5,0,118,251,101,0,200,1,39,255,112,13,36,255,144,1,100,0,223,5,109,1,143,2,26,255,42,0,105,4,255,2,192,0,240,255,144,242,177,255,20,255,3,0,176,255,51,0,245,255,40,252,114,255,29,0,42,2,83,1,59,7,105,0,233,254,157,244,116,0,18,12,81,254,233,0,81,1,61,0,159,3,32,0,82,255,237,0,255,0,6,255,92,2,115,0,244,7,78,0,177,255,206,255,163,254,82,1,29,1,169,0,138,1,207,255,170,4,106,244,191,1,57,0,225,245,159,1,182,253,200,245,59,255,195,255,84,2,121,251,130,0,71,254,100,1,47,0,168,4,240,1,247,248,241,255,114,255,233,255,132,0,21,0,84,0,234,0,119,255,23,0,109,255,74,243,151,1,107,0,108,4,130,0,74,0,153,0,76,12,136,8,48,254,14,5,222,0,77,2,201,1,115,254,169,255,163,253,137,253,55,1,65,253,110,0,20,0,233,255,181,255,18,0,213,255,74,255,8,0,162,255,151,0,125,19,149,253,150,2,82,0,8,0,69,0,252,255,126,0,221,255,157,255,235,254,29,255,92,247,116,12,91,4,45,254,150,253,35,252,169,2,218,0,231,255,219,255,247,255,32,0,210,255,97,0,15,0,233,255,161,255,250,255,55,0,19,0,224,30,242,255,4,254,3,0,14,0,244,255,198,255,28,0,154,0,11,0,15,1,175,253,88,1,176,254,161,13,215,255,74,244,110,2,77,245,236,10,0,6,54,1,176,0,194,254,143,1,186,255,214,254,3,254,0,1,131,254,98,255,66,1,59,255,3,0,203,255,37,0,98,0,8,232,231,255,202,255,57,0,138,0,182,255,239,0,210,255,238,255,29,0,247,254,26,247,22,0,110,0,235,255,109,255,10,1,85,0,226,254,137,0,106,13,27,254,68,0,219,1,253,255,159,0,75,255,19,255,59,6,247,2,18,3,210,5,158,3,231,244,96,255,68,4,249,255,130,0,127,3,167,254,161,255,225,255,221,255,139,0,158,255,58,8,49,1,160,2,190,255,93,1,229,0,231,249,98,249,6,249,25,253,180,255,189,255,130,6,76,0,10,0,234,255,60,0,211,255,5,0,153,1,54,254,71,2,107,254,26,10,248,254,175,0,121,2,74,3,136,12,48,250,222,252,40,0,137,255,59,255,172,255,109,6,72,1,55,3,81,255,86,1,12,0,39,255,67,0,124,0,76,255,150,255,195,244,176,254,171,0,185,0,132,0,41,247,181,255,146,253,137,253,156,246,176,0,124,255,35,0,179,0,38,250,182,0,68,0,187,2,85,2,88,245,69,1,52,0,165,1,161,252,97,2,53,0,97,255,2,1,205,254,103,11,44,0,198,252,45,254,91,0,30,2,91,7,47,3,86,253,36,2,93,254,81,2,82,0,196,247,98,255,181,255,244,253,136,9,240,253,43,254,211,2,242,255,231,248,25,254,192,1,4,0,101,255,186,255,77,249,34,0,201,255,134,0,0,0,19,0,107,0,163,1,78,1,74,0,190,1,217,4,64,239,61,0,191,255,21,0,71,0,133,0,2,0,168,255,18,255,66,1,229,254,250,255,148,1,98,0,78,0,97,248,156,1,106,248,162,1,1,1,214,255,116,246,159,255,211,5,208,1,90,1,229,0,102,255,96,0,5,1,29,0,46,1,39,0,55,255,216,255,158,255,99,255,79,1,216,241,163,254,195,253,121,2,140,255,200,254,174,255,7,1,254,255,155,255,199,255,25,7,88,254,3,0,11,255,130,1,74,0,97,2,123,8,179,255,212,245,244,251,139,255,49,6,254,255,9,0,233,255,31,0,244,255,48,0,215,0,84,0,13,0,219,0,163,1,237,254,21,17,165,255,250,255,18,0,180,8,210,255,157,0,104,254,240,8,142,2,43,253,11,255,246,255,98,251,190,6,68,1,111,1,197,11,101,13,116,255,104,1,134,255,194,253,91,255,109,0,182,254,174,255,84,1,123,255,210,0,99,1,248,255,47,0,204,255,128,31,5,0,60,0,214,255,161,255,253,255,91,0,187,255,209,255,214,255,101,0,118,0,212,255,240,255,242,255,247,255,27,0,8,0,223,255,253,255,170,219,27,0,49,0,250,255,61,0,74,0,204,0,174,1,252,0,253,254,73,0,125,0,110,1,54,254,226,244,89,0,122,245,150,255,168,254,66,253,41,3,195,1,69,0,73,2,151,248,96,2,142,251,52,0,106,2,106,0,3,3,176,11,10,1,239,3,184,0,26,254,36,0,245,12,201,254,38,0,105,0,167,255,16,0,97,0,168,255,28,0,183,0,238,244,212,255,131,1,207,255,211,1,36,246,77,0,200,255,113,241,81,0,204,254,63,0,119,255,203,0,179,255,139,0,254,0,191,255,248,254,198,255,119,2,1,246,227,2,193,250,83,2,139,255,63,255,244,245,66,1,11,1,185,0,157,2,146,255,129,2,212,0,45,0,240,255,12,0,14,0,253,255,244,255,78,0,208,255,60,255,128,255,179,0,146,0,76,227,177,0,118,255,208,255,142,0,223,255,34,0,107,232,15,0,151,255,103,0,136,0,208,255,217,0,87,255,88,0,225,255,9,0,24,0,41,0,197,6,59,245,177,254,247,6,220,3,95,255,246,3,121,2,190,255,166,251,13,2,246,254,205,1,113,4,230,255,83,255,89,0,82,0,219,242,67,0,58,255,149,255,44,0,96,1,231,252,99,3,217,252,90,255,107,0,4,0,71,0,61,0,124,0,27,0,83,246,178,0,224,255,84,255,79,11,21,5,30,3,195,2,11,1,48,253,109,254,167,0,99,255,12,10,46,255,15,2,200,254,128,249,42,255,236,249,180,254,83,2,158,249,198,255,203,0,15,249,43,254,24,0,188,0,197,255,164,252,111,3,15,0,87,3,2,250,94,11,22,2,185,255,20,1,215,1,41,0,231,255,105,0,219,255,106,255,110,0,226,0,235,254,177,237,62,2,139,0,104,255,182,253,67,0,198,251,5,1,188,255,25,0,40,255,110,0,46,0,137,241,25,1,99,1,6,254,80,0,38,255,164,0,114,254,75,0,159,255,150,22,39,0,188,255,26,0,76,0,74,0,38,0,153,255,105,0,44,0,116,0,187,0,32,1,90,0,215,22,215,255,28,0,237,255,20,0,129,0,157,255,2,1,22,0,228,255,136,255,155,255,135,255,79,0,76,255,233,255,22,0,251,255,196,255,63,0,35,0,229,220,245,255,2,0,241,255,253,255,228,255,47,0,29,0,241,0,132,0,90,255,253,254,208,255,102,0,70,0,14,11,91,12,29,1,211,252,0,0,105,0,176,0,57,254,141,0,102,5,31,254,22,247,155,11,56,255,39,254,37,0,94,252,118,251,162,3,122,3,156,1,190,0,96,255,38,242,79,254,180,255,46,0,24,0,127,253,214,0,114,0,245,252,94,252,199,255,50,254,199,253,176,252,99,254,53,0,45,0,156,243,99,11,34,253,152,0,231,1,143,255,246,0,60,255,69,255,120,255,213,1,219,1,126,1,213,0,138,252,237,254,57,1,76,12,194,255,251,252,17,3,232,255,37,250,191,255,81,255,106,248,187,254,78,0,241,255,218,255,2,0,6,0,227,255,240,255,218,37,241,255,207,255,243,255,12,0,235,255,11,0,211,255,193,255,240,253,192,0,119,255,201,0,138,0,102,255,57,0,168,255,97,249,155,0,105,0,121,0,153,16,197,255,211,1,73,254,131,17,126,255,217,255,6,1,235,255,135,254,185,1,159,254,0,253,110,1,23,0,73,3,17,2,195,0,162,10,76,11,1,255,189,255,116,2,14,254,33,0,241,0,212,0,4,252,159,255,45,253,82,2,35,0,225,255,179,5,19,0,181,255,229,255,255,255,48,0,28,0,11,1,237,254,196,14,253,253,45,254,36,0,107,254,240,254,80,248,60,0,44,0,193,1,195,244,132,255,12,250,171,4,18,4,117,0,115,0,207,254,225,0,215,0,155,254,144,0,35,0,233,255,89,0,85,8,2,0,65,0,229,255,208,255,13,255,40,255,217,252,188,2,234,4,6,0,116,255,4,0,225,255,235,255,42,0,67,0,97,0,254,255,104,0,246,255,202,225,134,0,206,255,161,255,168,255,243,254,105,0,238,255,27,255,197,1,14,4,207,245,128,244,199,255,27,0,116,1,59,0,212,253,169,255,14,255,114,0,59,4,137,255,117,255,175,0,146,0,201,255,153,6,86,1,245,1,162,10,7,251,90,6,100,3,222,254,111,255,62,0,194,0,233,255,77,255,4,6,171,255,104,1,254,0,83,1,87,253,33,8,170,10,70,3,128,255,31,0,171,247,83,255,227,1,118,255,146,10,215,7,91,0,37,1,126,253,35,0,24,1,124,255,198,1,190,255,137,231,232,255,82,0,225,255,217,255,5,0,41,0,66,0,239,0,18,0,199,255,61,0,139,255,103,0,16,0,49,251,104,5,92,255,104,0,114,1,157,248,189,8,72,254,137,250,142,250,3,0,18,1,223,0,226,255,186,255,67,2,105,1,167,1,99,1,80,255,92,255,69,254,206,254,178,246,201,2,85,244,172,254,77,253,127,5,251,255,183,1,248,254,170,255,172,7,239,255,88,0,175,0,56,0,137,255,31,0,210,1,188,7,176,0,1,2,17,7,17,0,184,11,69,7,185,255,58,1,1,255,249,7,64,2,203,0,187,1,120,254,229,253,132,254,83,253,52,255,95,255,31,1,122,1,10,254,106,7,4,6,49,4,234,8,61,2,99,3,122,0,40,4,140,253,204,253,97,0,24,1,220,255,65,6,166,255,82,255,246,255,45,0,199,255,159,0,16,254,129,2,65,252,165,255,166,255,241,11,144,6,173,255,80,0,19,0,63,0,137,255,1,0,184,255,210,1,177,254,197,1,79,255,90,15,235,255,71,1,57,255,117,253,218,255,250,255,243,255,7,0,179,255,1,0,8,0,40,0,131,255,36,0,120,255,16,1,122,24,29,243,3,13,24,0,18,0,185,255,9,0,177,255,138,254,235,254,128,0,23,255,81,255,162,254,40,255,81,0,75,253,207,255,33,0,212,255,219,255,92,239,186,255,96,0,177,0,193,254,133,0,178,0,135,254,211,255,182,0,156,0,101,255,222,255,10,0,22,0,53,0,45,255,4,0,108,22,48,0,214,255,114,0,149,0,226,255,122,0,150,255,203,254,108,255,174,255,20,0,130,0,174,10,216,255,172,253,29,5,139,4,66,250,140,1,248,254,116,3,142,0,230,248,67,0,255,255,38,0,204,255,183,255,1,0,23,1,143,0,22,1,211,255,5,6,138,252,91,253,207,245,168,255,74,241,55,255,237,0,216,255,195,0,206,255,146,254,88,0,166,0,147,1,236,0,126,255,205,0,211,255,68,222,243,255,229,255,206,255,8,0,40,0,21,0,41,0,220,255,231,255,216,255,242,255,242,255,42,0,40,1,191,9,116,1,151,254,11,254,159,7,163,247,220,0,177,252,98,0,228,0,6,255,51,2,159,251,227,255,72,11,60,255,151,0,237,255,225,254,6,247,65,0,30,254,132,255,70,255,191,4,212,1,243,252,29,255,109,2,42,1,214,255,212,255,141,255,0,0,50,0,179,0,23,0,9,0,191,255,248,255,10,0,155,255,122,236,77,0,157,4,208,254,139,0,250,0,47,247,159,255,79,3,177,1,129,1,149,246,32,3,172,252,240,253,179,1,71,252,233,255,4,0,160,3,148,255,134,253,239,254,145,252,6,10,207,245,109,2,39,3,39,1,179,255,115,2,166,251,215,254,147,255,55,8,203,255,247,255,44,0,32,0,83,1,167,2,77,0,142,243,96,254,210,4,223,252,216,1,152,1,153,0,209,1,167,6,111,3,149,246,215,253,184,1,51,8,125,252,224,254,54,1,153,2,209,255,108,255,177,5,92,15,43,255,243,0,29,249,254,255,32,1,87,254,52,252,222,1,210,254,40,2,135,254,160,254,179,0,32,254,186,5,227,7,1,11,5,0,56,3,13,0,128,254,186,253,215,254,115,251,177,2,136,255,191,2,138,255,151,2,206,0,207,255,219,244,180,255,32,0,170,0,11,0,42,0,9,254,141,251,12,6,225,254,168,251,253,2,57,254,221,255,148,9,22,0,122,255,144,0,75,7,107,255,211,10,19,0,8,1,188,2,208,255,30,1,175,253,179,245,152,1,0,9,242,255,187,0,121,255,46,255,233,2,26,1,212,2,93,3,21,0,98,254,94,2,68,3,204,253,212,0,203,0,64,0,98,18,226,255,213,255,171,255,195,255,166,255,132,2,231,254,31,1,134,255,172,254,119,255,36,0,252,255,234,255,8,0,14,37,253,255,4,0,10,0,4,0,86,0,58,0,248,255,6,0,151,255,241,255,15,0,193,255,198,255,226,255,15,0,0,0,237,255,78,0,181,223,122,255,248,255,211,255,163,0,237,255,149,0,214,254,89,255,34,0,190,0,217,255,75,247,5,11,126,0,185,0,233,252,51,251,235,3,181,254,212,3,147,2,196,255,196,255,208,255,20,0,12,0,89,255,196,255,217,255,66,0,180,0,234,255,236,255,84,0,148,255,131,0,246,255,211,222,255,255,238,255,252,255,203,255,25,0,193,255,242,255,20,0,25,0,215,255,40,0,251,255,230,246,182,255,59,0,249,255,102,255,219,254,192,255,114,245,51,3,75,0,209,3,166,253,114,4,160,0,6,1,26,0,175,255,18,0,182,21,118,0,89,255,98,0,110,0,251,255,212,255,229,255,72,0,51,0,67,255,0,0,76,7,231,2,237,254,226,9,6,0,180,0,5,252,229,250,198,2,47,1,104,255,141,255,38,250,11,254,17,254,153,255,180,255,78,0,249,255,135,219,250,255,31,0,235,255,16,0,242,255,57,0,36,0,175,255,189,255,226,255,233,253,216,0,57,1,54,1,99,255,14,11,110,252,122,0,73,5,206,248,42,1,115,251,243,255,3,255,156,255,208,253,195,255,40,0,24,0,3,0,56,0,238,255,77,22,41,0,13,0,233,255,201,255,158,255,214,0,109,0,51,255,211,255,27,0,230,255,177,0,222,254,89,0,8,0,35,5,30,12,121,6,210,0,248,251,6,3,45,255,187,253,205,255,128,3,84,3,75,1,93,1,38,254,137,255,159,252,111,255,222,8,191,2,81,248,216,247,98,2,68,253,113,0,25,255,14,8,104,255,169,253,38,254,218,255,167,253,176,1,41,252,37,253,232,2,192,244,156,0,16,255,145,248,193,9,167,255,61,252,125,247,72,251,189,0,62,1,150,0,204,0,29,0,89,255,118,255,163,255,73,0,36,1,103,243,202,254,2,254,173,0,166,255,154,0,39,7,124,1,89,251,48,252,76,250,254,253,235,0,13,0,122,244,22,0,161,255,228,0,85,0,10,0,8,1,163,243,46,0,72,255,242,252,143,0,247,255,37,0,12,0,108,0,191,255,192,255,115,0,86,0,175,19,201,255,53,255,93,255,50,254,77,0,164,255,167,1,139,0,239,0,251,255,95,7,170,1,217,2,118,0,97,255,251,244,132,255,99,8,89,255,1,252,92,0,233,255,162,0,97,255,209,255,253,255,14,0,222,255,37,0,227,255,159,255,41,0,164,255,181,255,185,228,32,255,250,0,176,255,110,243,161,253,129,6,76,4,205,253,165,1,121,1,189,1,242,254,253,255,33,250,224,0,175,253,196,254,31,0,106,1,162,4,133,1,231,248,77,2,230,244,33,1,123,248,156,254,28,255,108,255,106,2,135,0,102,1,238,0,1,0,1,253,246,254,1,0,101,0,245,0,231,0,89,255,152,1,1,0,162,0,221,255,241,0,215,0,162,237,230,1,34,2,173,254,93,1,220,254,62,5,143,252,184,0,93,253,79,10,228,254,29,252,90,1,13,254,219,5,80,6,66,2,189,1,178,255,76,3,8,7,82,253,98,254,111,250,27,3,242,2,118,250,78,255,78,247,3,2,113,255,43,0,57,2,199,3,227,246,57,248,26,1,16,2,130,5,135,254,224,2,138,1,26,255,147,254,14,255,213,10,136,0,30,253,220,255,109,251,180,255,124,255,212,254,33,255,88,253,96,254,78,245,93,0,158,1,234,1,166,254,75,0,191,251,148,251,189,8,52,7,139,1,69,1,22,250,121,7,198,248,138,4,70,254,177,2,190,255,185,255,173,255,86,1,59,255,84,252,206,0,203,242,5,251,89,254,169,255,57,254,242,1,97,3,99,1,201,4,141,255,251,242,108,254,180,253,253,3,124,247,66,250,201,4,216,2,59,0,32,10,177,254,194,0,119,253,2,14,73,252,114,255,77,252,130,3,157,255,243,254,209,3,240,5,232,1,148,254,3,255,127,0,220,9,81,3,114,251,65,255,115,2,116,1,4,3,145,0,235,255,23,1,146,1,161,252,121,245,193,4,7,6,237,3,117,250,176,6,110,0,113,247,201,3,27,6,183,0,43,3,38,255,202,251,36,255,188,251,190,254,35,3,235,253,153,254,149,1,186,255,253,252,245,254,134,237,235,0,161,253,125,254,227,254,188,255,48,0,196,255,34,255,229,0,193,251,19,251,55,247,241,4,168,249,96,3,191,255,223,0,190,254,81,1,250,254,158,243,244,255,219,17,19,0,198,0,202,1,251,251,0,10,253,255,141,255,107,2,123,253,188,252,113,254,246,0,175,255,244,255,223,251,185,247,220,10,25,0,233,249,35,1,80,2,255,253,62,0,157,0,41,2,58,2,111,253,72,0,138,255,228,254,58,254,13,15,145,0,3,1,83,249,143,247,161,243,189,0,23,255,181,251,141,0,114,0,6,254,12,252,249,252,218,1,75,1,30,3,213,1,123,7,96,0,246,254,127,254,183,254,110,253,192,0,16,0,97,0,209,255,28,1,93,255,200,0,189,0,18,0,227,226,160,0,84,244,165,10,8,2,124,255,33,10,115,2,74,253,230,255,210,253,44,0,47,255,40,0,121,1,235,1,188,255,128,1,15,1,69,8,130,2,94,12,199,253,190,2,1,2,190,248,108,0,176,3,248,0,166,0,169,2,152,1,116,252,13,2,111,255,11,4,189,0,252,10,135,0,156,254,9,246,145,1,150,0,4,254,247,254,244,0,205,1,190,3,23,255,52,255,232,2,189,249,141,1,27,255,82,255,27,2,117,255,135,238,69,3,202,254,253,0,133,253,141,1,176,255,89,2,141,254,33,248,251,254,148,254,50,0,75,1,89,0,86,252,197,2,164,5,162,244,28,255,94,255,163,1,62,0,193,254,246,254,72,2,144,14,57,0,220,0,225,253,0,3,138,253,105,1,105,1,130,2,199,254,182,0,24,254,208,255,185,11,115,254,128,2,179,0,8,0,57,4,119,251,198,255,186,255,192,255,104,17,67,1,115,3,65,255,240,255,61,0,163,1,173,1,115,2,126,252,141,252,238,2,243,1,201,250,45,254,126,250,251,255,27,1,211,254,20,1,156,249,54,1,114,0,84,254,0,224,12,0,142,255,74,0,215,0,255,1,61,1,198,254,170,255,198,0,138,0,59,1,241,254,246,0,149,254,170,1,96,2,54,253,111,1,180,250,87,247,154,4,127,254,162,5,28,0,126,253,141,254,169,255,177,244,58,253,47,1,106,255,114,254,156,252,65,249,12,6,214,3,153,4,76,1,135,254,44,6,194,3,252,251,130,7,214,5,200,252,93,0,174,250,216,253,105,6,63,249,228,0,30,4,165,1,71,255,232,253,51,0,87,0,52,255,88,0,177,252,14,253,79,241,110,245,118,255,38,251,35,0,64,0,162,1,52,254,201,2,120,15,221,2,212,1,106,255,201,252,45,255,94,253,110,1,243,254,180,0,218,254,128,254,92,2,37,7,135,255,15,1,241,0,192,0,45,255,144,245,53,250,178,251,192,3,90,0,49,0,136,251,248,9,137,252,224,255,211,254,62,0,73,255,193,0,78,0,243,252,193,0,162,253,227,254,246,243,240,0,136,1,192,2,20,0,177,251,61,255,166,0,65,2,151,255,211,255,202,254,150,255,219,11,28,0,143,254,213,2,53,0,87,0,24,255,65,255,7,0,230,254,196,253,0,224,69,1,99,0,162,0,143,255,19,255,47,255,156,1,195,253,39,1,123,254,189,249,190,255,27,254,157,252,210,1,142,252,94,3,40,255,221,0,50,0,205,255,87,15,45,2,185,1,223,0,234,0,208,15,83,255,164,1,134,6,180,1,85,1,175,0,71,254,55,255,75,0,219,253,59,1,172,0,162,1,97,255,7,0,157,11,253,255,36,255,176,250,26,0,221,10,132,0,39,1,241,255,217,0,90,255,187,0,230,254,101,1,135,255,224,1,40,255,38,1,7,1,95,0,57,227,77,2,193,255,100,254,153,255,55,255,79,1,160,255,53,255,240,0,223,0,77,254,110,1,45,254,118,0,16,2,40,254,209,253,95,254,67,255,127,253,83,1,10,6,75,245,133,5,247,254,125,2,236,249,207,255,166,1,61,255,136,1,235,255,3,0,254,255,26,1,126,255,240,254,29,254,164,252,93,253,250,2,81,250,92,20,178,0,197,0,44,254,14,1,202,254,14,4,150,1,139,10,231,253,223,255,16,1,225,0,62,248,15,5,167,252,166,244,120,252,187,248,50,255,98,3,111,255,49,255,252,0,199,252,235,11,175,250,71,254,85,0,70,255,129,255,139,0,29,1,251,11,180,254,139,4,248,0,29,254,79,255,12,1,179,2,221,2,152,255,202,255,237,9,238,251,30,255,165,0,250,0,7,0,253,254,129,254,71,1,116,8,224,8,18,253,178,9,94,252,117,255,179,4,254,2,150,0,64,1,202,3,28,0,185,250,211,1,32,2,9,2,164,244,181,255,122,252,99,2,63,2,192,4,47,255,249,255,29,2,74,1,16,2,91,1,71,255,206,254,80,254,200,242,204,248,132,254,155,0,50,251,117,2,195,251,99,254,119,0,114,0,69,4,198,0,38,3,235,1,119,255,250,253,24,2,192,255,131,1,80,249,96,2,232,255,97,19,149,0,43,1,170,254,249,1,247,1,125,254,80,252,215,254,137,246,158,255,253,251,80,254,253,254,224,2,127,0,233,13,39,254,145,253,17,253,114,0,74,254,145,2,144,9,95,3,99,254,175,255,18,8,220,3,229,253,240,253,145,255,58,1,134,1,52,251,161,252,19,0,251,2,179,8,180,252,232,255,68,16,139,0,130,0,145,255,138,253,84,254,26,2,162,253,172,3,147,252,122,0,14,2,194,0,152,255,127,0,117,0,139,3,235,252,49,11,14,2,220,253,3,255,33,1,25,9,176,0,186,255,7,3,169,2,21,0,38,0,55,250,254,2,45,8,98,244,223,254,197,253,67,254,41,7,77,1,172,255,13,255,99,254,188,0,20,254,234,255,157,252,93,2,179,254,136,3,120,12,227,255,235,1,101,254,114,1,212,253,145,245,218,254,132,0,13,255,23,255,180,0,181,0,127,1,177,255,26,0,45,242,130,2,103,4,179,247,86,255,126,254,121,255,65,253,222,254,99,255,68,254,139,252,171,254,104,252,204,1,105,254,80,255,81,12,244,243,7,254,31,2,7,0,79,0,167,4,124,4,111,254,239,255,33,1,33,253,44,1,179,7,114,2,110,255,110,0,255,250,155,253,119,253,50,255,58,7,189,2,114,4,221,252,230,2,144,250,147,0,42,2,69,7,110,253,55,250,108,0,88,3,253,3,62,2,242,12,6,2,124,251,205,254,42,0,164,255,124,255,22,1,160,254,219,255,35,0,146,0,163,255,106,253,216,0,125,0,55,3,148,252,86,255,93,236,188,1,74,255,76,3,189,0,22,254,95,250,177,254,117,252,83,255,114,4,40,254,31,250,151,249,136,2,66,0,115,2,64,0,184,251,148,253,52,6,6,254,53,1,156,255,70,22,213,253,99,255,77,255,171,255,213,254,142,255,236,255,178,0,159,1,118,0,187,253,124,255,1,4,185,245,126,251,63,10,226,254,201,0,84,1,181,3,235,0,171,0,137,2,72,1,141,1,114,255,89,5,249,255,1,9,139,254,146,2,111,249,24,253,10,242,34,0,73,255,8,254,165,0,81,0,21,0,123,2,205,254,172,1,248,253,164,0,163,237,232,2,249,0,180,252,249,255,178,254,38,0,27,2,11,1,43,255,73,0,134,0,5,255,8,255,101,252,121,5,117,1,252,253,74,1,57,253,16,253,37,254,32,255,139,0,236,1,212,253,21,18,15,4,77,1,104,3,226,253,218,1,152,254,134,254,125,242,254,0,175,4,113,0,243,253,87,249,231,0,46,0,188,0,206,255,242,251,32,0,58,255,147,255,107,2,47,4,191,249,234,3,101,254,67,255,52,243,103,2,44,254,45,254,237,254,250,250,224,2,29,2,173,251,167,1,191,0,183,1,51,255,17,0,169,255,244,1,176,0,6,1,171,254,114,255,12,1,228,31,254,255,112,0,66,255,227,0,206,255,113,255,186,254,135,2,89,2,226,1,187,1,201,10,15,254,211,3,214,254,198,1,145,244,234,2,33,253,81,15,224,1,89,255,195,254,23,5,111,0,216,0,63,252,110,0,173,253,244,0,246,0,34,255,51,255,46,0,61,0,226,252,2,1,104,1,130,228,114,253,161,255,75,0,242,1,232,255,6,255,71,0,138,0,15,2,240,0,41,255,250,0,104,254,40,2,187,254,77,1,35,252,88,10,29,254,159,251,40,9,145,249,140,255,123,252,103,2,71,1,1,0,241,1,155,1,118,255,76,1,25,1,111,255,81,1,163,0,45,227,70,0,9,1,109,1,238,0,92,2,99,0,107,255,233,0,109,0,59,3,64,253,87,5,184,4,51,253,239,255,33,255,15,0,69,243,53,0,27,254,137,253,29,1,255,1,248,255,242,0,35,2,129,0,145,0,254,7,8,2,44,0,79,255,126,1,27,1,87,255,166,254,79,245,38,1,225,250,145,0,81,7,47,3,54,4,165,2,165,242,78,254,228,1,144,0,229,255,157,2,153,0,14,255,14,255,46,3,94,1,105,1,50,254,193,255,13,9,235,4,139,254,23,254,234,253,44,1,99,3,61,10,139,255,88,255,98,254,17,255,44,3,72,3,112,0,49,254,114,231,75,253,194,252,140,0,88,255,192,1,37,2,107,255,162,1,151,255,137,0,31,0,216,255,213,255,166,1,157,255,41,1,3,0,36,255,241,255,81,0,45,0,121,253,233,253,64,254,37,253,250,0,170,229,192,254,162,254,64,255,4,6,168,251,237,251,37,5,77,251,11,4,6,254,161,2,209,2,86,3,49,250,12,3,218,254,149,4,94,8,0,224,86,255,118,255,202,255,202,255,23,255,129,255,145,0,23,255,71,255,87,0,20,0,18,2,207,254,141,0,118,254,54,1,40,0,133,2,41,3,193,18,70,255,80,254,61,254,56,1,112,255,191,255,65,0,135,0,192,255,241,255,155,254,38,242,237,250,216,0,249,0,5,1,49,255,117,0,190,243,15,2,14,0,114,255,30,1,100,0,84,1,69,2,157,0,234,0,227,2,39,246,253,255,127,2,96,250,131,0,44,241,159,0,39,0,41,0,109,253,28,1,165,0,76,4,166,254,31,254,39,1,38,3,29,255,224,254,168,17,253,0,231,1,4,255,88,0,213,255,180,249,251,255,199,255,190,255,18,0,19,0,45,2,175,254,246,5,175,244,144,0,76,3,108,254,184,7,19,3,246,0,8,1,106,254,10,3,106,252,51,0,143,255,21,255,6,2,90,2,205,254,2,248,76,253,215,10,144,1,139,247,72,255,139,0,147,1,193,248,219,250,33,1,198,2,100,4,96,7,251,253,20,1,190,0,125,2,71,254,205,2,204,3,142,254,222,1,114,2,158,254,241,0,189,241,145,0,7,0,30,253,141,1,223,3,169,254,198,252,142,0,160,2,121,9,152,253,50,243,239,2,63,255,80,252,221,255,219,251,234,4,119,2,47,253,145,0,144,255,187,255,60,3,217,255,60,255,19,255,183,255,3,3,61,255,239,0,235,253,119,249,149,13,209,253,104,0,121,253,226,252,167,0,15,254,209,253,79,2,3,1,44,1,231,255,166,1,93,0,39,0,193,255,233,0,144,0,110,251,142,0,56,254,73,0,155,1,8,27,174,254,205,254,180,1,143,0,164,1,152,0,247,255,4,249,184,251,74,244,41,253,244,253,128,0,204,1,14,3,154,255,192,253,118,255,48,252,11,4,132,243,76,254,229,255,233,251,147,250,172,12,113,255,141,252,12,252,4,0,71,1,16,0,155,1,15,254,164,5,4,2,159,4,252,0,254,1,70,253,92,253,57,2,186,255,115,254,29,255,149,30,56,1,102,254,20,0,41,0,191,255,37,255,175,0,41,1,40,0,2,250,14,254,194,0,103,3,153,1,24,1,74,4,65,250,247,244,163,3,151,255,223,253,223,252,229,252,140,254,73,0,75,1,100,0,232,1,203,247,48,2,44,0,117,3,41,4,124,1,61,255,20,1,124,0,169,255,193,0,139,15,30,0,95,0,3,254,93,252,177,10,55,254,37,3,10,0,53,0,183,255,53,255,181,253,79,255,242,0,238,0,144,2,181,242,132,254,60,9,86,11,30,255,204,0,23,6,85,247,216,255,70,254,111,0,65,253,88,254,4,255,15,255,205,1,237,2,146,2,31,254,125,0,146,254,89,2,10,255,226,254,132,0,41,1,24,255,111,20,115,255,196,0,135,255,21,255,150,1,57,255,82,255,87,0,149,255,107,1,16,1,205,253,148,253,235,0,223,0,141,253,173,254,45,254,93,1,196,249,136,234,132,2,160,255,175,255,146,7,237,2,96,255,72,248,100,250,224,251,235,251,182,251,23,9,208,3,199,255,132,255,115,4,19,1,47,255,132,253,42,1,180,9,204,10,194,3,217,255,108,0,50,253,70,254,9,0,29,3,99,4,68,4,155,4,110,251,67,253,131,254,19,255,14,251,235,251,175,254,161,254,238,254,43,252,240,254,145,255,175,242,125,254,165,1,106,254,181,247,111,2,238,255,169,9,105,2,176,0,26,0,122,5,185,250,212,0,23,0,84,255,40,1,36,6,193,255,110,254,69,3,247,253,161,8,155,253,183,254,203,254,76,255,128,251,233,253,156,250,199,245,219,1,129,1,96,253,182,0,92,0,93,247,64,1,109,0,135,253,186,253,184,4,0,250,241,3,128,3,199,7,138,254,214,6,21,251,171,254,238,6,39,4,166,2,220,247,219,3,175,254,48,0,51,255,174,255,224,254,132,1,217,0,239,4,123,9,64,250,207,251,60,252,188,252,38,8,95,255,182,1,63,254,219,255,98,252,134,241,164,0,140,254,152,253,160,0,196,253,43,253,215,2,11,0,53,0,172,255,70,29,182,255,11,2,84,255,208,1,196,1,86,254,35,3,106,0,250,254,32,0,42,1,21,254,75,255,8,253,116,252,47,1,235,2,36,5,16,1,138,3,255,2,105,0,247,0,232,23,180,3,211,253,96,252,173,253,170,254,62,254,174,2,209,252,37,251,99,255,60,2,134,5,166,0,27,255,245,12,148,7,229,254,111,2,243,252,205,2,44,255,61,253,30,0,51,14,123,4,72,253,96,252,131,253,157,3,29,3,75,3,177,250,214,0,72,4,7,4,84,3,172,255,28,255,222,255,43,4,171,251,136,1,36,1,13,253,167,13,216,255,242,248,131,253,20,255,166,253,248,254,109,255,188,255,23,255,201,255,43,248,241,254,121,253,195,3,53,1,251,255,56,0,237,254,114,254,34,0,16,254,252,9,225,4,169,255,144,255,127,6,214,253,122,248,115,2,211], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1783345);
/* memory initializer */ allocate([9,152,251,202,253,3,6,228,2,38,0,154,253,16,1,24,255,104,255,242,252,92,254,208,254,247,246,223,255,80,252,179,255,116,242,187,255,62,249,235,255,153,2,198,254,152,249,148,2,149,2,106,0,235,255,31,250,184,244,85,254,158,252,102,253,56,12,18,3,201,255,227,2,112,0,8,0,55,2,166,253,162,254,165,0,108,0,255,2,64,0,53,253,212,3,161,2,70,255,0,3,223,253,214,254,23,255,244,253,186,255,255,1,253,247,232,14,176,251,17,2,244,3,17,10,9,3,86,1,125,254,170,10,247,0,236,255,29,255,80,254,249,254,139,252,88,251,124,253,253,254,10,9,38,0,108,0,102,2,126,254,214,1,178,255,169,2,250,242,231,251,212,254,177,0,82,255,90,254,110,0,127,253,106,254,40,254,212,1,117,3,38,253,147,252,76,248,164,250,102,254,33,2,31,2,224,252,124,251,23,1,218,12,231,250,43,255,250,254,192,252,30,252,170,251,206,2,148,254,136,5,249,255,195,3,196,1,168,2,165,0,25,241,135,3,38,3,149,0,11,0,204,250,146,253,61,254,152,0,150,253,203,254,246,0,179,1,206,247,231,1,213,1,61,254,218,249,52,255,69,255,40,2,179,254,3,2,181,254,172,5,22,1,125,245,110,255,241,3,97,1,185,252,6,0,122,243,200,251,196,253,118,245,240,2,66,249,194,254,141,1,104,255,128,255,179,255,220,255,6,254,200,1,70,4,25,1,98,255,237,255,107,255,48,0,241,244,250,7,241,9,95,255,107,2,105,4,18,1,24,0,1,0,57,1,92,255,143,2,157,0,2,3,182,0,150,7,241,0,126,252,44,249,179,253,0,1,66,1,171,2,191,255,183,255,109,2,74,0,195,254,25,10,185,0,47,254,227,255,243,255,183,231,120,255,60,255,24,0,28,255,211,254,101,255,219,255,202,255,165,255,252,255,126,255,88,254,167,255,75,255,145,2,110,0,82,238,121,254,250,2,9,4,202,254,216,252,230,254,47,253,78,253,2,1,253,254,16,0,213,253,115,10,133,254,236,245,100,1,198,0,57,254,95,0,62,255,14,253,127,1,249,254,151,252,15,1,149,255,65,255,228,255,11,0,190,255,91,0,25,0,41,255,9,0,152,0,11,0,132,255,66,0,166,1,9,2,25,21,103,0,77,255,221,254,203,252,15,251,116,254,150,0,187,255,241,255,154,0,224,5,67,254,116,0,120,255,56,242,3,11,251,255,174,0,166,0,33,1,196,255,158,0,67,253,83,0,132,253,105,254,194,0,16,255,118,255,124,0,162,255,132,0,151,255,150,255,72,0,139,0,101,0,97,0,8,225,6,0,112,0,164,0,173,255,183,254,41,0,124,0,133,1,234,255,62,255,157,0,134,254,49,247,81,254,104,12,57,255,202,254,49,0,227,1,48,255,21,255,11,0,45,0,125,2,196,4,5,9,93,0,2,2,109,248,136,0,20,1,91,255,137,0,192,9,56,0,31,0,238,0,230,253,79,254,178,2,194,254,212,255,66,3,108,249,124,255,59,10,99,255,167,7,202,253,119,0,183,0,227,0,18,8,145,1,208,255,233,4,92,2,26,5,149,0,17,1,74,2,57,255,118,8,1,1,255,7,210,255,135,254,7,253,231,255,58,254,200,249,214,255,176,1,248,246,222,0,240,253,169,255,225,254,20,2,90,11,37,248,208,2,42,2,167,1,192,253,169,1,24,1,130,252,24,255,77,255,229,1,116,2,154,244,149,1,229,0,254,255,110,255,127,0,183,254,13,255,194,0,139,9,237,253,80,2,242,255,143,6,36,1,110,252,180,254,78,9,32,244,41,1,216,244,168,255,236,0,27,254,182,1,241,0,229,254,192,1,67,2,108,253,21,1,233,0,201,0,126,0,15,0,101,254,208,253,186,253,123,254,120,254,249,255,238,0,1,0,88,1,40,255,7,238,55,254,3,4,142,255,13,0,211,254,32,1,172,0,24,254,132,255,95,245,100,0,151,255,178,1,243,255,231,10,197,252,64,6,37,255,128,236,156,255,155,1,70,1,160,253,245,252,94,0,206,3,197,1,210,250,20,255,173,1,67,255,62,3,32,0,187,0,203,1,185,9,220,1,165,0,189,12,67,254,169,0,179,0,143,255,168,0,119,254,52,0,129,254,223,255,73,0,137,0,123,232,253,254,135,255,227,255,210,255,100,255,68,0,31,255,217,0,152,0,232,254,7,0,62,0,3,0,17,0,39,1,221,0,98,255,226,234,177,254,232,0,58,254,192,254,211,1,211,255,96,0,86,255,245,254,249,4,31,1,2,1,24,2,73,253,71,252,110,4,172,1,251,0,3,13,205,2,220,252,115,2,75,4,120,0,4,0,42,0,191,0,247,255,3,1,177,254,175,254,231,255,200,255,116,0,28,255,161,254,49,254,54,23,193,0,142,255,192,255,244,254,44,1,146,0,241,255,145,2,111,1,254,255,161,244,70,3,5,255,255,255,81,11,178,255,159,253,223,253,180,253,232,1,103,5,230,1,28,7,126,0,155,11,105,255,11,0,10,0,163,254,233,254,252,254,247,254,142,0,85,253,65,255,172,0,30,0,219,254,17,236,195,255,9,255,218,255,210,2,19,1,186,254,222,255,132,0,41,1,233,12,210,255,227,0,228,251,166,251,50,2,62,0,174,249,187,2,106,1,168,249,57,254,150,0,146,255,61,0,246,254,88,255,88,255,121,254,136,0,199,253,252,252,53,255,211,1,20,0,117,237,86,255,142,0,118,255,129,0,183,6,104,7,210,0,16,252,206,0,73,2,187,254,39,1,175,0,18,246,23,254,121,0,162,255,218,255,50,245,141,255,122,243,207,254,64,1,77,255,247,1,83,0,184,255,134,255,204,255,75,255,98,0,39,0,6,254,65,245,163,255,255,255,197,255,85,10,248,0,203,254,53,255,138,0,68,1,201,253,184,2,19,254,170,0,136,9,151,3,92,254,43,244,177,254,175,253,184,255,24,2,174,255,202,0,78,0,254,1,184,0,254,255,227,0,242,244,19,0,54,6,231,254,131,1,210,255,152,1,49,254,232,253,6,1,166,8,141,255,178,249,127,254,203,0,32,0,139,252,210,245,34,9,97,0,36,1,63,254,193,1,242,251,186,253,0,0,188,255,211,0,96,255,62,0,226,254,94,246,91,254,208,255,111,7,243,251,83,255,59,5,177,253,152,0,49,251,24,3,12,2,214,0,164,255,29,0,181,0,31,255,106,255,255,255,139,0,57,224,238,0,137,255,189,0,34,0,116,255,68,255,141,0,144,255,56,0,80,255,154,0,91,0,21,22,42,1,196,254,233,255,232,0,182,255,195,254,252,255,138,253,6,254,105,0,137,249,130,255,113,9,113,0,161,255,40,254,134,0,34,1,13,253,152,0,58,251,198,255,213,3,20,255,0,32,102,255,75,0,218,0,71,255,107,0,246,255,39,0,9,1,31,255,169,255,9,0,123,0,118,252,130,254,240,9,44,0,63,248,154,255,151,1,165,255,213,248,148,255,122,0,142,0,169,0,134,0,47,253,6,250,252,255,123,255,45,0,118,1,231,251,180,255,16,0,155,254,21,1,158,0,220,245,252,255,52,250,243,255,100,10,58,255,9,0,38,255,152,1,193,255,177,0,185,255,61,255,197,16,248,255,228,0,34,0,91,254,183,2,127,250,85,0,180,10,94,1,44,0,217,1,141,0,163,255,144,0,197,255,36,255,102,255,108,255,88,255,51,255,233,11,229,0,194,0,149,255,90,0,159,254,252,1,169,254,217,1,66,254,201,1,60,254,140,255,165,13,248,1,104,8,28,255,216,248,49,254,111,253,43,2,145,2,28,2,34,2,92,2,166,8,188,255,254,0,51,2,11,1,227,0,92,0,149,255,143,0,4,1,23,0,42,0,64,0,189,255,138,0,89,255,72,0,201,1,94,19,61,0,91,252,1,0,221,20,224,255,89,0,161,0,248,1,55,3,55,1,11,0,72,255,194,253,177,255,138,249,182,255,146,254,164,0,149,254,117,0,53,0,194,2,67,253,106,244,233,0,11,0,165,0,138,1,206,1,184,245,191,2,221,254,191,255,207,255,240,15,162,252,191,255,237,255,146,255,152,252,67,1,65,3,102,255,113,1,219,1,163,8,20,0,44,255,175,6,232,255,228,255,198,255,32,0,210,6,41,0,245,252,102,2,252,1,234,11,175,2,167,1,74,255,28,254,196,255,242,0,55,15,203,253,59,254,110,0,35,2,63,252,64,1,222,255,165,254,85,248,140,255,218,2,77,254,222,255,41,0,26,0,205,255,0,32,141,255,56,1,184,0,108,255,57,255,157,0,153,0,82,0,99,0,138,0,224,255,237,255,192,255,117,255,107,0,43,0,133,0,169,255,42,0,108,255,168,27,98,255,177,254,7,255,192,255,81,0,157,0,45,3,233,254,178,8,240,255,167,4,63,253,95,2,205,0,245,255,195,250,220,253,53,247,186,254,107,255,24,246,139,0,18,253,73,0,118,254,38,255,221,255,181,0,157,3,211,253,226,0,193,255,22,10,31,253,164,0,181,0,89,255,26,255,157,1,72,1,150,1,225,254,80,244,27,2,109,4,171,255,142,247,102,255,155,254,11,255,248,255,162,0,138,255,111,0,251,4,47,0,198,254,5,248,84,245,228,251,228,255,113,2,214,252,25,254,40,0,125,255,17,1,105,0,45,10,98,244,12,1,237,255,255,254,74,3,106,253,87,3,249,1,78,2,13,255,68,0,66,27,118,0,155,255,93,1,24,255,254,254,194,254,212,0,55,0,82,253,79,255,83,255,154,255,224,1,35,0,149,0,7,1,234,244,58,255,174,3,136,1,135,0,164,11,34,0,92,0,19,255,96,253,224,0,214,254,42,1,80,8,103,1,254,0,150,0,185,252,233,3,162,12,87,255,5,1,210,254,74,0,235,254,242,1,65,1,194,0,53,243,104,255,30,245,33,0,70,0,236,0,34,255,88,0,119,254,47,0,132,253,101,3,14,253,74,3,234,246,52,254,133,0,0,0,8,1,172,0,117,244,226,254,13,255,143,1,114,3,46,253,130,254,104,3,137,255,191,255,157,246,137,255,10,255,134,252,71,255,102,0,224,255,195,253,225,0,228,11,28,254,216,255,215,252,147,1,233,239,211,244,180,255,207,255,64,255,226,253,0,0,94,0,218,253,6,0,89,2,236,0,66,254,54,255,167,0,238,0,49,10,80,253,106,254,9,1,250,243,65,1,59,0,167,253,157,0,200,0,247,254,78,0,69,253,89,253,18,0,202,255,203,0,81,253,123,10,145,255,35,244,141,253,19,254,157,1,32,254,54,0,75,0,20,1,206,0,187,248,17,0,92,254,87,255,56,1,105,1,235,254,244,255,149,254,176,253,246,2,133,255,195,12,78,0,162,252,81,0,156,254,84,2,232,253,217,2,191,8,207,255,41,2,112,0,188,1,140,2,82,244,186,255,60,4,76,254,34,0,53,0,246,255,233,255,41,0,253,255,130,255,207,0,126,255,48,255,63,0,224,1,191,0,85,24,211,255,223,255,174,255,35,0,56,0,3,1,1,0,98,31,159,255,52,0,97,255,178,254,215,255,50,0,199,255,56,0,62,255,201,253,2,8,146,0,219,3,129,254,160,1,254,254,30,11,51,0,8,0,178,2,130,255,64,253,60,1,16,0,252,255,166,255,159,0,34,0,126,0,65,0,218,0,131,228,251,254,169,255,235,255,71,255,14,0,112,0,42,0,92,255,18,1,243,254,114,4,48,255,62,2,77,2,113,255,33,254,185,10,14,3,243,255,68,246,124,255,242,1,106,254,4,1,60,3,188,253,46,2,211,244,168,253,65,254,199,254,36,5,32,3,236,6,107,4,67,1,208,255,124,240,185,2,5,0,109,254,46,0,95,0,130,0,84,0,217,255,219,0,117,0,93,6,67,255,165,250,25,0,140,255,7,9,87,253,101,254,83,253,196,250,103,254,223,0,50,254,226,9,208,252,162,251,58,1,131,252,147,255,250,254,120,1,21,245,208,255,194,244,250,255,180,0,53,0,12,254,75,255,125,0,221,254,247,254,102,255,233,255,72,255,185,0,205,253,121,251,163,2,24,0,43,255,17,1,167,244,14,255,69,9,250,255,90,255,92,0,20,1,95,5,228,255,87,7,12,10,205,0,135,255,51,0,100,1,151,252,204,254,220,251,184,3,207,2,200,1,106,0,116,0,149,255,45,255,235,255,247,12,61,8,84,255,84,255,143,0,50,253,118,255,111,4,232,0,175,250,157,0,157,255,10,2,241,238,84,0,93,2,63,1,87,252,115,254,117,0,78,254,82,0,121,2,18,1,237,249,35,255,197,255,141,246,74,246,144,255,136,0,74,255,32,254,27,0,220,253,19,255,49,3,18,2,144,2,252,0,131,245,230,255,191,2,60,243,125,1,129,254,189,254,105,0,12,254,66,0,213,254,224,251,149,254,187,255,21,0,36,1,142,1,133,254,150,255,156,254,38,0,169,0,50,11,206,0,245,253,235,254,197,244,186,253,187,255,137,2,253,255,198,0,226,255,98,0,145,0,131,255,70,255,237,255,149,255,154,255,83,255,125,227,194,255,9,254,25,255,24,0,145,0,87,5,157,254,81,255,117,1,71,252,64,253,130,242,170,0,131,3,130,1,80,2,14,253,108,2,81,0,86,0,191,255,84,0,171,2,238,11,232,254,247,244,11,253,53,0,246,255,185,1,111,255,138,0,84,5,254,255,164,255,212,254,225,0,57,255,217,247,71,4,149,254,181,255,32,1,253,2,155,252,249,255,189,12,9,0,212,244,182,254,130,254,237,12,28,0,117,2,244,0,113,255,214,254,0,254,103,254,15,255,104,0,250,255,241,254,254,255,0,32,119,255,139,0,208,254,242,255,81,0,6,1,220,255,51,0,124,1,11,0,101,0,100,0,103,255,119,8,241,254,11,1,50,1,64,244,67,2,235,254,60,1,71,1,144,4,71,0,135,250,133,1,231,255,247,254,101,0,203,255,86,255,30,255,45,11,145,0,224,11,97,255,77,0,240,255,233,0,198,253,234,1,149,2,196,1,194,7,246,253,212,0,149,255,196,0,9,255,52,1,159,254,186,0,127,245,230,1,210,255,45,3,232,255,233,0,90,255,233,12,16,11,169,254,174,255,219,1,11,1,127,254,26,0,221,255,30,255,27,0,160,1,231,0,12,0,88,0,47,255,117,255,148,1,17,255,147,255,74,255,173,252,4,1,242,0,109,0,11,0,184,251,85,0,126,239,132,255,12,0,117,255,156,255,164,253,169,255,89,0,188,22,59,0,213,255,172,255,8,1,225,253,0,0,172,1,240,255,110,255,212,253,61,255,97,255,107,3,27,0,5,1,207,0,74,255,63,9,146,253,135,243,225,1,223,254,52,0,12,0,34,0,198,11,10,0,167,254,162,255,189,244,194,255,144,1,249,0,51,0,78,255,166,4,128,255,156,240,41,0,216,254,208,255,13,0,230,255,223,0,168,246,4,2,128,254,33,0,210,255,95,255,213,255,32,255,167,255,252,255,163,254,135,0,28,2,136,255,236,254,58,255,129,0,7,236,175,0,211,255,222,255,147,255,163,1,211,255,152,255,71,255,119,254,160,1,70,242,149,0,240,243,141,255,178,255,175,1,84,255,21,0,222,254,94,255,216,0,41,0,200,255,25,254,193,2,62,255,21,252,100,0,172,0,233,10,173,255,24,10,67,255,174,4,39,2,137,255,183,255,165,255,55,8,149,253,124,0,128,0,68,10,192,0,160,0,146,255,14,1,203,6,38,4,200,253,183,255,200,255,72,1,100,0,128,1,83,255,83,0,39,0,20,255,231,255,55,254,53,0,243,230,89,1,53,254,146,255,28,0,129,255,147,255,175,253,32,0,141,0,145,252,254,0,84,8,102,254,145,253,79,4,2,247,16,2,156,0,28,0,81,0,101,2,90,2,171,0,244,1,204,246,108,2,17,0,245,253,111,244,103,252,149,255,107,254,26,255,127,255,18,0,107,1,143,252,2,5,147,5,149,254,146,2,205,0,205,255,19,11,45,248,188,0,230,255,73,0,25,255,96,1,74,0,22,254,34,255,119,9,171,254,54,245,242,255,200,255,252,254,215,255,33,0,169,0,66,255,224,4,179,255,238,246,161,253,26,14,152,255,56,255,166,255,175,255,207,2,204,255,153,254,138,1,211,254,66,0,217,255,200,255,0,224,87,0,56,0,221,254,50,0,231,0,28,1,45,255,240,255,170,255,172,255,228,255,52,0,3,0,205,255,48,1,32,255,228,0,138,254,202,1,90,248,46,255,203,245,145,1,176,247,137,255,244,255,196,255,242,255,0,224,53,0,27,0,113,0,33,1,249,255,22,0,60,0,64,255,77,1,72,0,168,254,238,0,147,0,69,247,68,1,124,0,176,0,97,254,194,1,36,254,210,253,83,254,10,255,217,253,225,254,160,2,97,8,0,32,161,0,91,255,222,255,193,0,148,255,119,255,160,255,188,255,156,0,52,1,74,255,5,0,182,1,185,255,229,255,92,255,187,0,146,255,154,22,174,255,126,255,130,255,197,0,250,254,74,255,138,255,146,255,121,0,163,255,235,0,200,255,157,255,44,255,59,244,63,255,246,255,128,244,58,0,121,255,144,253,86,255,84,0,83,1,115,0,171,255,162,248,250,0,123,0,152,255,138,254,63,247,150,9,74,254,88,255,120,2,120,255,43,253,183,254,118,254,196,255,19,0,235,10,182,1,228,252,141,0,113,255,132,0,251,0,37,0,30,1,66,7,39,0,77,9,247,255,171,255,146,255,149,0,97,254,99,1,84,255,247,255,107,255,42,2,188,254,189,236,231,253,251,254,183,253,221,254,252,2,164,255,117,255,248,255,176,255,65,0,250,255,230,255,175,255,37,0,242,255,45,0,115,0,171,0,191,254,57,1,52,1,227,237,128,255,136,255,82,255,148,0,0,3,234,1,81,0,81,255,251,254,120,255,221,5,89,1,25,0,200,255,44,255,188,254,188,252,207,0,116,253,16,253,102,9,180,254,233,1,237,254,92,252,28,1,31,12,197,254,102,2,105,245,170,6,208,251,93,255,181,255,176,251,163,0,91,254,252,5,164,255,93,255,213,252,138,255,218,255,14,253,210,1,198,254,232,0,173,253,29,14,226,255,58,2,194,255,17,3,90,6,56,4,41,2,105,254,32,0,151,255,82,0,100,255,181,255,127,31,189,255,114,0,191,255,191,255,14,255,98,0,132,255,38,0,185,1,171,245,164,255,69,0,17,0,44,243,234,254,234,254,116,0,55,2,26,253,182,0,208,254,176,1,5,1,86,0,243,239,133,1,27,3,118,255,151,0,111,0,33,255,88,9,143,1,121,255,223,253,182,0,30,255,61,0,234,0,73,0,78,0,192,255,76,0,17,0,106,24,252,255,89,255,52,0,4,0,253,255,11,0,67,255,237,255,120,255,36,255,15,0,6,0,92,254,99,247,38,0,128,244,16,0,118,0,140,255,61,0,119,0,122,254,217,0,36,2,24,0,161,0,232,255,218,246,108,255,97,255,33,245,225,0,145,1,30,255,210,0,131,2,146,254,240,0,8,1,167,0,115,0,59,3,217,255,95,255,30,0,83,255,42,0,29,0,98,0,121,1,198,255,93,255,215,255,27,0,25,0,16,17,87,0,236,244,81,255,185,255,194,255,172,255,36,254,4,0,162,9,113,0,242,244,108,252,81,2,20,1,156,254,85,254,82,253,41,255,192,10,139,1,247,255,167,254,117,0,134,255,185,254,92,0,107,0,150,255,32,0,14,1,15,1,171,0,66,12,198,0,210,255,186,255,46,0,246,1,91,0,77,0,237,255,216,0,94,0,122,0,192,255,120,254,225,255,120,245,148,254,125,255,197,254,129,0,51,254,229,0,192,0,236,0,185,0,249,254,83,255,44,0,24,0,245,254,216,255,79,255,107,255,89,246,26,0,113,0,73,255,99,249,68,255,48,0,22,0,183,255,50,0,123,255,58,0,186,255,83,255,204,254,70,254,68,255,92,0,133,1,221,255,167,0,235,0,66,0,33,10,131,9,244,0,118,2,234,255,235,0,112,0,224,255,21,2,98,255,81,0,71,0,44,0,197,255,98,255,233,255,28,0,0,32,198,255,75,255,39,0,220,0,202,255,132,255,197,255,235,254,71,0,41,0,174,255,99,255,52,229,252,255,44,0,172,255,208,255,134,0,63,255,159,0,211,255,218,0,209,255,123,255,147,0,213,6,253,2,172,255,184,0,195,254,226,254,239,255,172,254,250,254,12,255,235,255,50,12,34,1,129,255,137,255,179,0,128,255,131,255,73,254,206,10,125,7,85,0,57,0,224,255,117,1,240,255,170,0,182,255,31,0,169,1,114,2,1,0,1,254,64,0,131,1,142,0,147,253,183,0,32,255,220,0,171,4,130,1,224,242,76,1,228,1,168,251,160,255,187,0,43,0,46,7,39,0,220,255,13,0,124,255,248,255,255,255,213,255,29,0,124,255,237,255,10,0,10,0,38,255,181,241,119,0,153,255,229,255,227,255,148,255,13,0,181,0,39,0,139,255,92,0,37,0,239,255,58,255,74,1,26,2,17,0,113,0,150,18,1,0,28,0,246,255,87,0,22,0,96,0,242,255,157,255,200,255,126,255,0,0,201,255,45,0,193,255,227,244,191,10,208,1,225,255,194,255,76,0,102,255,88,0,81,0,125,0,117,1,164,254,75,2,198,254,234,254,203,255,247,7,252,253,133,9,191,0,44,255,87,0,254,255,181,0,14,255,117,0,23,0,193,255,78,1,145,0,198,1,87,1,21,255,91,0,69,0,248,255,2,0,150,255,148,255,251,255,137,0,88,255,118,225,25,255,25,0,37,0,75,0,118,255,56,0,142,0,172,253,130,0,142,255,221,12,146,254,34,1,160,0,254,255,37,255,83,0,75,3,238,255,9,5,79,255,226,0,155,2,252,0,85,253,48,3,26,0,157,0,168,0,25,254,207,255,46,243,176,1,184,0,183,4,23,0,164,0,32,2,197,3,255,255,61,0,138,255,92,0,79,5,89,0,94,243,15,0,240,1,244,0,177,0,155,253,96,255,233,255,61,255,145,255,140,254,141,255,22,1,96,0,77,0,249,245,49,0,89,254,44,254,13,0,28,254,65,5,214,254,194,0,133,255,8,255,117,255,226,2,102,0,130,4,177,254,134,10,46,5,213,0,246,2,17,0,154,0,97,2,250,253,145,254,201,0,112,255,61,0,66,0,240,8,50,0,128,10,169,255,45,0,243,255,155,255,127,0,66,255,216,255,226,254,6,0,121,0,32,0,31,0,119,0,171,255,28,0,93,0,0,32,17,1,169,0,44,0,37,0,255,0,32,255,219,0,222,255,129,255,122,255,165,0,169,0,126,0,68,255,204,255,98,0,15,0,68,233,63,255,181,254,117,254,255,255,49,0,69,255,55,0,135,255,60,255,114,0,10,0,2,1,111,255,242,255,127,254,105,0,69,255,59,0,127,1,202,20,147,0,146,255,187,255,122,1,138,0,160,254,187,255,15,0,245,254,75,0,162,0,250,255,76,12,3,2,231,0,182,255,76,254,8,5,210,4,151,255,68,0,160,255,90,255,207,255,192,255,144,0,189,255,135,0,2,1,185,255,94,255,156,0,146,254,249,255,189,255,123,255,236,255,137,255,71,0,172,255,31,0,26,0,116,0,67,247,212,0,43,0,124,1,182,255,13,0,249,255,6,3,4,251,153,255,132,255,208,255,78,255,193,254,26,0,179,1,145,255,90,3,39,1,65,6,89,245,14,255,8,0,36,0,195,255,236,255,237,255,237,255,31,0,2,1,21,0,242,255,125,1,103,255,0,224,157,255,71,1,72,0,175,0,99,251,241,254,104,0,226,255,121,255,87,255,21,0,29,0,74,255,231,255,125,0,165,0,174,255,73,0,230,255,7,9,171,255,89,244,131,255,85,0,50,255,156,255,156,255,36,0,253,255,179,255,76,255,35,0,0,0,86,255,123,0,168,0,210,254,110,1,178,254,120,11,186,255,148,1,202,244,13,0,79,0,226,0,93,255,14,255,132,255,216,255,85,255,147,255,189,0,20,0,204,255,144,0,179,248,168,255,230,0,248,255,229,255,45,0,131,0,245,255,68,255,93,0,29,255,60,254,27,255,158,0,121,1,247,255,56,249,16,0,196,12,92,255,41,0,49,1,98,254,126,253,145,255,156,255,118,0,101,255,20,255,168,3,142,255,51,0,31,0,60,0,19,5,5,0,232,11,18,1,17,1,59,255,223,254,11,255,224,254,135,7,249,255,27,0,51,1,174,0,13,255,161,255,122,255,14,0,24,0,137,255,124,255,5,245,2,255,35,0,95,0,22,0,135,0,21,0,101,255,176,255,113,255,196,255,250,255,182,0,77,0,11,0,59,255,248,255,64,232,28,0,155,0,11,0,229,255,22,0,208,255,248,255,206,255,134,255,11,0,222,255,86,1,255,255,40,0,48,255,117,0,221,255,187,255,150,0,152,240,87,254,46,0,200,1,182,0,61,254,37,255,38,0,15,0,53,255,254,2,24,255,243,0,186,255,179,0,59,8,34,255,90,1,90,255,143,0,239,0,245,0,59,0,119,255,17,0,219,1,188,255,119,10,89,254,20,0,199,254,74,0,152,0,171,0,243,254,68,0,39,0,121,237,94,0,253,255,110,0,134,0,88,255,73,0,180,0,140,255,20,1,182,255,53,255,2,0,173,255,17,0,170,0,96,0,169,0,75,0,91,234,46,0,20,0,88,255,234,255,35,0,182,255,104,0,103,255,8,1,4,0,199,255,94,0,64,255,161,0,15,0,7,0,45,0,70,255,15,0,131,255,121,0,139,236,2,255,179,0,26,1,72,0,31,2,159,255,107,1,251,255,189,255,123,254,190,255,178,0,171,1,236,254,141,245,191,1,254,255,131,255,33,255,53,11,10,254,117,0,225,7,185,255,41,0,9,0,124,0,19,0,101,1,206,253,25,0,127,254,80,0,203,255,81,255,228,9,183,255,82,244,92,255,57,0,128,255,2,255,53,0,106,255,76,255,16,0,211,255,66,1,10,1,142,246,248,254,61,1,115,1,5,0,197,0,7,0,84,246,163,255,152,0,90,0,91,255,11,0,253,254,232,255,201,255,240,255,98,0,216,236,140,255,53,0,205,0,211,255,199,255,116,0,75,0,161,0,201,255,97,0,220,254,27,0,140,250,105,0,129,255,133,0,247,254,223,255,5,0,218,241,25,0,253,255,152,255,8,0,229,254,27,255,236,0,48,255,145,0,115,2,16,255,118,0,40,1,108,0,203,254,48,0,239,242,70,2,242,1,3,1,20,0,17,3,118,255,165,1,97,0,114,1,161,0,141,0,23,245,106,0,10,255,116,255,84,255,42,0,62,255,54,255,193,254,149,255,232,255,167,1,125,28,147,255,243,255,14,255,55,0,171,0,13,0,163,255,131,0,115,255,88,0,132,0,76,0,176,0,78,0,153,0,193,255,201,255,102,254,217,255,6,0,27,0,33,255,82,255,61,0,133,2,167,0,221,255,7,12,83,255,182,3,1,0,147,255,138,255,150,255,15,0,191,250,242,255,50,0,186,255,187,255,24,0,109,0,182,0,84,0,31,0,77,255,163,255,176,243,59,244,196,255,56,0,196,255,58,0,166,0,95,255,24,0,129,0,1,0,181,0,128,0,244,255,17,1,213,255,24,251,134,0,159,0,220,255,175,0,43,0,207,255,41,0,48,0,218,255,211,255,59,0,220,255,174,255,48,0,182,255,152,255,128,11,132,255,232,255,98,0,248,0,110,255,25,255,15,255,72,0,142,255,8,3,14,254,242,0,155,254,250,0,154,255,209,27,109,0,11,0,94,0,203,255,37,0,219,255,123,255,24,0,99,255,47,0,210,255,187,255,62,0,177,255,210,255,47,236,119,0,188,255,8,0,96,255,201,0,241,255,55,0,44,0,44,0,59,255,146,255,173,255,166,255,190,255,227,255,128,255,145,9,74,255,178,8,42,1,187,255,189,0,89,255,199,0,178,255,60,0,102,255,87,255,14,255,189,0,214,0,132,0,215,255,169,0,222,0,126,255,209,0,20,0,102,255,185,254,126,242,186,0,76,5,160,2,133,0,100,0,119,1,21,254,204,255,169,255,153,0,25,2,209,9,163,254,47,0,229,255,118,0,211,254,250,0,45,0,191,0,106,255,23,1,63,9,186,255,191,0,211,254,50,255,251,255,216,255,55,255,96,14,189,255,36,0,171,254,123,255,59,255,129,254,155,255,21,0,188,255,40,251,69,0,248,255,249,255,240,255,28,0,209,255,111,255,87,255,32,0,170,0,246,0,149,0,223,11,199,245,214,255,161,255,184,0,182,255,71,0,200,255,234,255,171,255,53,255,129,0,97,0,151,255,165,255,208,254,4,0,93,0,89,0,164,10,249,10,78,255,52,0,101,255,104,255,149,0,47,0,182,0,124,0,181,255,24,0,0,1,218,255,53,0,121,255,63,0,70,0,59,0,197,255,7,0,6,0,46,0,0,32,99,255,142,0,81,0,121,0,136,0,169,255,109,255,185,255,59,0,57,0,119,0,21,0,110,248,46,0,186,0,100,0,98,255,204,255,34,0,95,0,22,0,20,0,179,0,112,0,116,0,234,0,247,9,60,244,89,255,163,255,133,254,166,255,24,0,208,0,1,1,253,0,23,0,175,250,209,0,75,0,191,0,233,255,141,255,232,7,8,1,77,0,97,255,77,0,37,255,19,255,102,255,13,0,17,1,246,242,122,0,51,255,212,14,160,255,103,0,120,255,196,255,115,0,175,255,19,0,69,0,140,1,225,0,232,254,86,0,73,1,28,1,249,1,147,1,219,255,203,0,54,1,229,245,186,246,15,255,239,255,236,1,214,255,224,255,5,1,112,0,123,0,223,255,9,251,144,255,215,255,12,0,82,0,67,0,185,255,56,0,246,255,173,255,228,255,15,0,244,255,42,0,244,8,41,1,21,255,253,255,16,2,199,255,159,0,71,255,202,255,172,255,104,255,7,3,15,0,54,0,195,1,218,254,53,0,254,255,141,0,39,0,191,255,75,0,149,0,172,234,17,0,198,255,130,255,231,254,8,1,151,0,106,1,158,255,62,0,199,246,0,246,173,0,42,0,222,254,95,255,160,255,204,255,82,0,130,0,170,255,106,255,48,0,20,0,199,255,52,0,41,247,160,255,102,10,190,255,21,0,74,0,219,255,22,0,67,1,64,0,14,1,115,255,169,253,212,254,135,255,244,255,128,255,160,255,253,255,127,255,13,239,219,254,201,255,31,0,174,255,8,0,82,0,236,255,58,0,15,0,18,255,140,0,131,255,158,255,208,29,242,255,96,0,127,255,244,255,217,255,85,0,0,0,152,255,31,255,24,0,3,0,95,0,169,255,115,0,168,0,19,0,22,0,95,0,120,31,36,0,244,255,106,0,157,255,241,255,169,255,112,0,134,255,55,0,14,0,26,1,225,255,80,0,42,0,252,255,81,0,183,255,74,0,246,255,82,0,35,0,173,0,236,255,216,255,0,224,221,255,126,254,14,1,7,1,25,255,114,255,42,0,67,254,204,0,177,0,182,254,165,252,203,2,171,10,59,0,18,10,220,0,34,254,3,0,154,1,209,255,61,0,42,255,205,10,50,255,174,0,56,0,171,1,186,1,118,0,148,10,190,255,216,255,41,0,119,0,191,255,185,255,235,255,124,0,106,0,238,255,230,245,221,255,106,0,148,254,30,1,240,255,78,255,110,255,174,255,157,0,92,0,252,255,75,254,125,255,171,255,229,255,166,255,23,0,198,255,44,235,115,0,187,255,231,255,242,255,13,0,52,0,14,0,226,254,243,255,196,255,16,0,19,0,53,0,35,0,7,0,235,255,7,0,231,0,48,0,191,9,174,255,20,11,44,0,122,255,180,255,33,0,118,254,47,0,132,255,81,255,95,0,103,0,161,0,57,0,219,255,174,0,13,254,131,0,118,254,215,7,220,245,31,254,38,1,152,0,89,2,144,0,74,254,109,0,52,255,61,1,37,0,106,1,103,255,216,0,13,1,217,255,226,4,249,1,249,1,11,10,141,255,173,253,218,252,26,252,202,4,185,255,26,0,189,255,6,1,51,0,95,255,183,0,86,6,224,255,233,0,3,0,39,255,19,0,240,255,209,0,51,0,40,0,216,255,213,255,229,255,197,227,13,0,128,255,238,255,82,0,154,0,133,0,135,255,33,0,190,255,8,0,154,255,71,0,8,0,220,10,213,255,79,0,140,12,230,254,91,255,125,0,78,0,155,255,197,255,59,0,120,255,52,1,195,255,217,254,15,255,227,255,27,0,186,254,116,11,205,253,52,1,243,254,222,255,98,255,230,255,192,255,101,254,181,255,164,1,218,254,17,255,245,255,173,1,44,0,36,0,69,0,56,255,200,255,23,1,80,0,38,255,218,254,218,254,252,0,64,0,113,30,7,0,101,255,200,255,210,243,67,245,78,255,62,0,185,1,105,0,211,255,23,0,23,0,155,255,147,255,230,255,107,255,54,2,227,255,118,254,174,252,163,6,194,7,243,0,103,253,53,2,155,0,46,249,96,0,168,254,117,253,131,1,149,254,27,1,241,0,101,0,71,0,238,255,247,255,43,0,114,0,234,255,9,0,147,255,137,255,164,255,117,0,0,32,189,255,87,0,174,0,214,255,61,255,15,2,101,255,61,255,89,255,173,249,78,10,200,252,121,0,44,0,138,0,216,252,151,1,72,2,39,255,166,255,234,254,37,2,138,255,2,251,69,3,220,0,142,0,68,252,218,254,89,0,67,10,13,1,127,255,253,0,10,0,15,0,167,0,163,0,87,0,250,254,89,0,48,0,14,0,24,0,151,11,81,255,246,9,51,0,11,0,104,255,145,255,230,0,245,254,177,255,65,1,127,253,251,1,224,255,236,255,18,255,23,0,190,254,54,246,173,0,157,8,165,255,235,255,198,249,164,1,99,255,97,0,64,0,126,0,218,255,172,255,10,0,171,255,93,0,235,255,16,1,85,254,30,0,196,255,61,0,175,255,216,255,27,0,18,0,227,255,48,255,186,255,0,224,16,0,15,0,53,0,34,0,49,0,230,255,48,246,104,255,23,0,179,255,199,11,87,0,92,255,247,0,119,0,91,0,188,1,213,255,90,255,230,255,253,0,163,255,50,0,152,1,54,243,145,3,104,0,119,0,17,0,202,255,42,0,19,0,218,254,214,254,96,254,174,255,38,0,249,254,137,0,132,0,207,245,212,255,223,10,222,255,247,255,10,1,8,0,18,0,73,255,8,2,3,2,163,255,97,255,235,255,186,0,27,0,167,255,137,0,77,0,196,255,223,255,34,0,5,236,212,255,84,255,134,255,247,255,152,255,69,0,16,0,94,0,253,10,56,255,114,255,206,255,119,1,204,12,240,254,212,255,47,0,215,255,68,255,7,1,19,255,232,255,56,1,120,0,186,254,55,3,193,0,154,1,161,255,100,1,53,2,40,1,178,4,79,245,56,252,87,0,52,255,207,250,198,252,197,252,72,2,194,0,225,255,244,255,147,255,217,255,249,255,73,0,29,0,24,0,244,255,0,1,158,255,210,255,63,0,207,0,248,255,73,0,170,254,226,17,219,255,60,0,190,255,8,0,217,255,80,255,131,255,222,255,57,0,115,255,204,255,217,255,128,255,206,255,113,255,171,255,149,255,19,0,218,255,74,0,216,255,95,255,202,255,193,255,132,242,176,0,116,0,154,20,19,0,214,255,198,0,3,0,33,0,80,0,157,255,145,255,11,0,166,255,97,0,250,255,253,255,204,255,45,1,31,9,148,0,85,255,168,255,44,0,108,254,124,0,4,0,176,255,189,0,22,11,62,0,9,255,138,1,26,255,165,255,92,0,229,245,84,0,117,255,225,255,198,11,25,0,201,0,119,255,192,255,127,1,2,0,186,255,141,255,46,255,43,0,169,251,109,254,133,254,247,255,243,0,77,0,36,255,196,255,218,255,241,255,7,0,109,0,41,0,143,0,56,0,45,255,68,246,208,255,38,255,141,255,191,254,154,254,132,1,246,255,84,255,204,255,177,0,180,11,160,255,224,1,233,255,241,255,177,0,31,255,217,0,10,0,111,1,129,0,211,255,142,255,23,0,1,1,208,255,193,9,236,0,12,0,197,0,245,0,19,0,83,255,191,254,54,1,150,1,232,254,184,255,233,254,73,0,235,12,245,0,78,0,70,255,112,11,8,1,7,1,29,255,50,0,172,0,91,0,37,1,24,0,108,255,11,255,195,255,219,0,168,255,169,0,220,0,157,255,150,12,3,0,0,0,103,0,19,0,116,0,69,0,76,255,249,255,207,255,26,0,197,255,163,255,188,255,123,0,101,1,241,0,20,243,215,254,198,0,40,0,176,255,29,1,161,0,90,0,210,255,91,255,224,255,87,0,212,233,254,0,219,255,7,0,236,255,39,246,250,253,38,7,217,3,12,254,109,0,217,252,59,255,31,2,244,251,104,0,197,7,172,1,228,2,86,4,146,254,202,5,131,3,220,248,159,0,57,244,201,254,232,252,214,255,3,0,100,254,99,255,243,255,95,3,8,255,5,1,69,255,103,254,156,0,4,3,15,1,62,1,250,254,78,0,197,253,28,0,114,1,119,0,46,1,70,237,106,0,133,255,103,255,65,7,66,253,66,4,193,254,159,1,185,254,76,8,86,255,101,254,174,0,62,0,249,255,153,3,128,255,223,2,129,255,204,3,142,6,166,0,65,250,48,255,32,255,103,3,124,252,33,255,207,252,32,1,40,254,10,0,31,0,111,254,127,243,246,250,253,255,211,254,183,0,218,2,217,1,182,1,175,255,114,3,192,255,82,11,14,255,152,1,45,255,179,254,2,255,204,252,100,2,152,251,196,255,183,255,44,246,45,0,125,2,126,255,203,1,200,254,33,255,139,253,210,5,0,7,57,255,235,255,223,253,236,6,196,251,83,255,125,1,124,1,9,5,139,255,227,1,138,0,80,251,249,253,86,2,131,242,93,1,226,243,236,4,86,255,238,0,84,253,48,0,29,254,141,252,145,252,139,0,42,1,146,255,53,255,69,252,195,0,57,0,218,253,153,7,57,253,80,253,66,250,247,5,58,0,61,1,144,2,54,1,57,0,162,0,214,7,107,5,77,3,129,255,114,254,62,1,216,9,210,7,118,252,189,254,62,255,139,3,76,2,28,255,155,254,196,254,45,2,172,253,233,249,253,255,78,6,37,5,91,249,168,3,167,255,34,247,47,5,22,4,144,1,23,255,18,0,38,253,233,255,75,255,175,253,74,0,198,253,55,252,176,1,251,254,191,252,166,255,189,237,18,3,202,253,73,255,165,252,214,253,90,1,19,254,55,255,36,255,241,0,105,252,152,248,9,1,222,252,100,5,50,253,177,251,194,253,51,1,138,0,20,251,175,0,236,9,174,255,58,0,22,4,155,250,182,9,70,2,199,1,229,1,200,252,106,255,57,0,211,255,101,255,22,254,172,251,113,247,65,3,167,1,37,248,11,1,11,3,140,0,228,255,57,0,94,0,6,0,211,254,5,0,191,252,54,251,63,255,86,4,193,255,79,0,20,254,71,250,83,245,188,1,56,0,164,251,167,253,20,0,150,253,221,250,73,253,122,4,190,255,80,1,90,255,158,0,18,2,203,255,141,254,174,253,83,253,114,0,110,255,117,1,174,0,255,255,47,0,119,0,132,255,135,255,215,229,162,255,40,242,226,5,197,4,155,255,112,8,46,2,2,255,40,253,255,1,122,1,129,254,12,0,114,2,172,0,183,0,98,1,49,0,133,6,164,4,226,14,153,1,152,0,182,2,40,246,86,1,61,0,171,255,218,255,86,255,5,0,49,1,154,0,164,254,187,2,76,1,238,9,161,2,150,251,215,245,42,2,203,5,210,1,15,1,234,1,124,253,54,3,160,255,221,1,131,0,253,247,145,255,43,0,225,255,194,255,1,253,71,243,151,2,232,1,31,7,10,2,243,253,7,255,225,1,249,255,238,250,83,252,177,254,202,253,49,1,22,2,33,253,207,0,197,2,158,243,19,0,236,255,160,248,15,1,95,249,117,0,45,7,130,10,49,1,29,254,49,254,151,1,62,253,211,1,6,2,14,7,244,0,176,255,59,254,7,254,114,3,75,3,48,5,232,254,175,0,63,1,182,252,192,0,88,253,43,254,64,21,51,255,69,255,53,0,76,1,204,0,72,255,96,0,2,4,243,253,20,0,207,3,125,0,230,249,175,248,11,253,119,255,133,0,246,255,172,254,241,252,52,250,98,247,214,4,164,235,46,254,129,0,32,255,17,0,241,1,215,255,78,3,88,0,215,255,29,1,28,1,101,255,21,0,31,255,150,0,223,0,217,252,68,254,139,251,116,252,36,1,186,254,47,2,66,254,229,254,215,255,235,254,105,242,101,253,20,2,83,0,1,1,127,1,86,244,149,6,185,2,9,3,15,6,114,255,250,6,67,2,237,253,19,3,200,2,40,252,91,2,82,255,53,254,23,5,81,252,229,2,79,4,183,255,88,2,109,254,214,255,87,255,166,255,220,0,208,0,105,0,13,240,211,251,213,3,98,252,124,0,17,1,111,255,123,255,51,1,112,18,209,0,68,1,177,255,12,0,215,255,36,255,211,0,72,255,179,1,51,1,248,249,83,0,29,6,67,254,39,255,120,253,133,254,10,251,202,249,223,246,164,252,92,1,136,2,99,255,239,252,246,12,133,255,118,255,100,254,148,252,102,1,83,255,232,254,175,255,107,255,89,255,96,255,191,247,20,0,216,255,254,3,176,1,47,253,55,0,117,253,17,0,145,251,132,254,226,253,152,251,103,11,37,254,113,255,203,255,176,0,104,255,7,0,227,255,84,255,174,0,195,0,187,224,21,1,105,0,35,0,115,0,198,254,137,0,3,255,75,0,234,254,90,0,28,250,79,0,103,255,208,253,3,4,163,254,220,254,46,254,179,251,188,254,172,255,155,16,54,3,92,254,55,0,43,0,94,7,25,1,196,3,104,9,169,1,163,4,229,255,172,255,3,251,63,0,46,252,113,255,250,1,215,2,101,255,128,254,106,13,80,2,250,254,74,254,226,255,33,11,187,255,198,255,75,255,169,255,20,0,43,1,156,1,249,254,190,2,131,0,241,254,246,255,224,2,121,0,101,231,124,255,140,255,26,0,3,255,182,253,32,0,111,255,5,255,244,255,215,1,135,0,73,2,92,2,29,0,105,3,107,1,254,255,197,249,41,0,133,251,114,255,153,2,64,245,22,5,154,254,122,255,29,0,77,253,244,255,66,253,53,254,100,0,22,1,9,0,54,0,66,0,54,254,53,0,213,0,193,0,14,0,112,254,6,19,74,252,47,255,50,0,214,1,193,1,3,0,138,255,239,8,43,254,198,255,126,0,243,3,198,252,130,1,5,252,170,246,182,253,135,250,137,0,248,2,141,0,167,255,117,0,4,255,34,12,88,252,58,255,134,1,207,1,11,255,3,254,133,255,241,11,176,4,123,13,26,1,180,254,183,253,106,253,69,252,165,0,236,254,73,0,117,1,202,0,250,1,100,1,125,0,141,0,155,253,98,253,190,1,239,7,241,5,66,254,59,5,198,0,144,255,214,0,70,0,9,1,226,250,188,9,123,255,168,248,165,254,63,252,56,1,126,241,37,254,102,0,135,1,64,0,67,4,82,253,155,255,144,0,191,1,173,0,66,0,138,254,86,1,69,0,205,242,205,250,136,4,135,252,166,252,214,3,179,249,33,255,57,0,186,0,172,1,226,0,35,254,193,1,228,251,107,253,130,254,203,1,21,1,235,254,6,255,12,0,237,15,252,254,95,255,93,255,38,0,159,0,243,0,131,0,201,1,51,247,211,254,166,249,37,0,38,3,104,0,191,0,107,7,90,1,142,1,172,251,145,253,121,254,68,4,228,4,102,4,81,0,140,255,168,4,162,2,215,250,224,255,203,6,60,253,26,255,180,252,5,254,159,1,5,1,211,0,149,253,65,255,84,21,8,0,139,0,197,0,136,1,212,253,41,255,66,0,64,0,216,252,0,0,120,255,151,0,156,0,4,1,94,0,162,1,90,250,23,7,228,253,231,252,195,1,35,254,252,6,132,255,74,1,102,6,86,1,9,254,128,254,79,251,6,253,161,3,186,244,120,3,193,255,62,1,86,2,42,0,54,251,112,254,50,254,120,255,65,1,80,7,120,1,236,4,142,0,177,255,25,17,9,0,38,1,185,255,66,255,235,255,204,245,16,255,26,0,238,255,29,255,96,3,79,0,28,10,142,252,87,0,96,244,9,0,224,1,219,249,86,255,83,254,201,0,132,255,171,0,120,2,196,255,65,254,64,0,219,255,98,251,170,255,151,255,85,11,27,242,122,255,230,1,141,0,253,254,239,0,209,1,211,1,241,3,103,254,34,0,254,0,165,9,234,3,66,3,45,2,179,252,149,0,21,253,8,254,238,1,102,5,43,4,97,1,191,0,175,251,169,6,182,253,192,5,68,254,233,250,198,0,90,2,215,1,212,1,247,18,127,0,115,255,231,1,58,254,118,255,120,254,138,255,21,254,76,252,58,0,222,254,249,255,106,253,229,0,244,254,254,255,231,253,148,253,94,237,128,4,83,255,166,0,187,255,32,0,5,246,177,1,185,253,85], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1793585);
/* memory initializer */ allocate([247,83,4,58,4,82,252,83,255,143,1,167,253,250,0,167,1,125,0,64,254,96,1,197,253,106,254,0,0,127,18,248,254,82,255,4,252,81,4,131,251,85,255,4,255,126,255,54,255,182,255,89,2,89,2,58,2,74,245,133,250,57,12,163,254,194,0,53,1,130,0,5,1,93,0,154,0,139,255,94,254,111,253,14,1,96,255,124,6,206,252,101,2,78,250,115,253,77,241,24,255,90,0,247,254,157,255,228,255,243,255,231,254,215,253,11,0,114,255,28,249,60,238,168,3,235,255,85,253,168,255,218,252,69,255,28,0,78,0,186,255,157,255,254,255,19,254,240,255,48,0,189,4,234,250,150,251,90,0,187,255,22,0,152,254,104,1,201,255,197,1,63,253,64,17,227,0,173,0,248,255,149,0,210,0,138,255,51,0,81,241,181,3,114,9,18,255,201,0,171,253,94,0,3,255,24,0,225,0,15,254,197,255,17,1,64,2,139,2,96,2,29,254,79,1,131,255,0,1,199,244,62,1,110,255,118,253,206,254,27,248,20,4,41,0,57,254,160,251,64,3,210,3,212,0,49,254,47,255,12,0,237,254,236,255,118,0,31,0,127,2,45,23,76,255,135,255,227,254,65,0,212,0,183,1,121,255,26,2,116,0,210,254,11,255,230,9,145,253,13,6,222,255,215,2,42,249,197,5,79,0,133,6,196,252,106,2,168,252,5,3,226,254,87,1,162,255,107,0,192,254,184,243,132,254,182,2,176,255,75,3,103,0,68,253,243,254,196,1,65,229,244,255,241,253,97,0,235,255,180,255,10,255,2,0,152,255,188,255,98,0,56,1,117,0,170,254,1,4,207,0,70,3,185,255,159,9,60,0,242,250,13,6,226,250,54,255,207,249,170,2,71,1,96,2,137,2,152,2,223,252,76,2,137,0,44,254,30,1,234,0,186,229,149,255,177,0,109,255,22,1,118,0,175,255,14,255,97,0,21,255,63,6,147,252,193,7,192,1,193,254,23,253,8,254,79,254,189,248,221,255,30,1,103,253,87,250,132,255,159,255,162,3,62,10,170,2,186,2,106,7,96,4,189,254,114,255,89,253,38,1,94,255,229,253,143,249,152,0,23,0,98,254,213,5,90,2,145,3,148,5,116,243,153,255,182,254,45,2,207,1,92,0,251,0,83,1,16,0,168,3,140,255,229,0,197,252,8,254,223,7,17,6,9,254,162,254,214,0,130,1,39,1,137,10,173,1,72,0,63,253,136,255,171,1,117,255,178,254,194,254,43,230,44,254,10,0,134,255,59,0,190,254,91,255,112,255,45,0,85,254,244,255,177,255,54,255,246,254,213,3,239,254,240,0,58,254,226,255,137,255,84,1,92,0,5,255,247,0,189,0,71,0,243,0,240,233,167,253,78,254,94,253,99,3,55,253,84,254,155,255,25,255,120,4,167,255,246,255,57,0,46,1,154,0,106,1,87,254,222,7,17,10,45,222,133,1,166,255,76,0,15,0,147,0,30,0,54,255,157,255,1,255,14,255,91,255,1,1,97,0,41,0,184,255,7,1,101,2,16,1,144,1,156,19,57,255,60,255,79,255,236,254,231,255,28,0,97,0,101,255,119,0,251,2,33,0,44,242,89,250,16,0,87,255,148,0,113,255,195,2,77,246,178,0,83,0,173,255,154,0,181,255,241,255,153,0,27,1,189,254,117,255,146,250,69,0,213,2,48,249,75,1,175,241,159,1,254,253,146,254,124,0,148,2,217,254,180,0,77,0,28,255,192,0,172,2,63,255,4,0,57,17,42,1,171,1,79,2,34,1,97,255,90,255,140,254,254,253,208,248,206,253,27,3,27,249,163,254,154,4,173,249,121,254,103,2,240,252,73,5,234,2,153,252,30,252,182,0,48,254,14,254,160,255,206,254,39,253,231,2,14,1,223,0,37,253,73,0,132,10,86,4,206,246,184,254,235,255,84,255,173,254,240,253,93,0,174,254,36,2,218,5,53,1,122,255,160,0,9,255,149,253,103,4,15,3,235,249,144,1,11,4,67,254,101,255,117,246,78,2,234,252,137,0,132,1,164,4,76,3,117,254,237,3,55,0,117,4,134,255,154,243,138,0,155,0,6,254,50,1,73,243,128,9,140,255,247,250,24,253,162,254,3,0,192,0,100,255,95,0,216,253,199,255,73,1,107,254,225,2,138,0,189,252,0,16,243,251,29,3,95,254,94,254,5,254,74,253,0,255,78,0,162,255,193,255,163,255,242,2,213,253,166,255,18,250,146,252,167,0,120,254,156,255,178,255,176,255,211,255,166,18,114,0,228,254,208,253,235,255,19,1,15,0,61,255,100,249,57,253,223,251,167,0,237,249,78,253,249,254,245,254,54,1,27,255,242,255,144,252,170,1,246,244,64,1,207,255,57,251,43,253,210,13,242,254,162,253,236,248,225,1,65,253,176,0,228,254,83,255,15,1,79,3,199,2,239,0,58,1,209,4,195,255,221,1,173,1,77,253,100,255,56,26,82,3,109,1,229,0,59,255,157,254,42,1,250,0,207,0,75,254,145,249,251,254,165,0,114,0,165,0,141,4,198,255,171,253,38,243,251,253,34,254,182,252,69,255,64,254,210,254,52,255,154,1,32,2,157,2,36,248,220,1,178,1,214,0,186,2,46,1,100,0,61,0,63,0,126,254,150,3,82,17,26,255,157,0,5,252,49,250,191,8,250,252,22,255,134,254,4,3,66,255,14,1,195,255,237,255,66,1,232,1,169,3,2,242,97,254,43,8,70,7,81,0,122,255,5,5,84,245,221,0,21,255,132,1,40,255,193,255,152,2,151,255,219,255,165,0,131,3,139,254,28,1,137,254,30,1,249,254,217,254,20,1,10,255,188,0,165,20,209,254,34,1,196,255,255,255,95,0,65,253,224,254,74,0,51,253,129,255,203,255,90,254,60,254,166,0,202,255,241,255,12,1,238,0,225,255,233,254,16,233,95,3,117,252,155,255,117,3,40,2,186,1,224,246,162,247,220,252,109,255,233,252,232,3,96,0,250,0,206,254,134,0,231,2,144,249,157,252,161,2,58,6,141,14,15,2,92,253,107,253,238,0,6,1,48,2,21,1,198,255,188,1,166,0,241,251,66,253,46,2,54,252,29,249,82,251,68,2,122,1,91,254,52,252,118,2,233,254,104,246,58,251,24,255,19,253,3,243,174,0,21,3,217,2,25,254,71,2,99,255,223,5,223,252,218,255,245,255,44,2,81,0,228,5,116,255,74,0,93,5,144,3,191,5,4,0,200,251,151,255,198,255,152,255,202,255,224,253,168,246,14,6,62,1,6,254,245,255,76,255,157,248,26,255,253,254,98,251,102,255,12,2,200,253,180,7,34,2,213,1,48,253,65,4,6,250,88,253,69,5,173,1,82,0,12,250,102,7,166,255,188,0,111,255,15,0,167,251,15,0,53,0,26,1,164,8,32,253,83,252,132,251,168,254,193,5,88,1,136,1,179,254,212,253,32,254,7,241,35,0,96,255,243,253,151,0,234,253,242,252,38,0,8,2,96,254,128,254,158,29,98,255,227,255,74,0,199,255,233,255,73,0,119,254,11,255,244,255,252,254,102,255,193,254,101,1,247,0,206,254,95,1,17,1,243,2,227,0,89,0,27,1,104,255,17,0,9,20,191,0,43,255,237,253,255,0,44,254,47,255,104,4,72,0,217,252,225,0,193,254,102,6,42,0,20,0,167,3,204,255,186,254,29,2,106,251,130,0,28,1,144,255,188,1,119,15,6,1,137,253,250,254,19,1,1,4,190,0,101,4,247,254,161,255,9,1,35,0,14,1,164,255,226,255,115,255,69,1,77,254,45,0,109,253,149,0,64,14,83,1,91,249,198,250,112,255,35,252,164,253,84,0,118,254,168,0,210,254,242,250,79,254,103,252,247,4,77,0,118,1,164,253,26,255,97,0,206,0,118,255,93,11,222,1,195,2,0,0,218,4,172,254,133,249,93,1,191,10,105,251,110,255,14,4,65,0,249,252,89,254,14,0,22,0,41,0,119,252,31,1,24,1,91,252,195,0,231,248,28,2,186,246,107,253,178,251,111,3,208,4,29,0,109,249,30,1,120,255,146,2,117,254,10,249,249,244,144,253,33,255,213,254,43,11,153,255,211,255,32,2,82,0,235,255,249,254,102,253,150,254,36,253,249,0,63,4,14,255,30,0,151,2,126,254,162,254,216,4,20,254,156,252,69,0,215,255,35,0,30,0,1,249,30,15,57,254,75,5,74,4,117,11,91,1,105,1,79,0,39,11,230,255,190,255,170,253,213,255,21,0,126,254,222,252,175,255,76,254,78,3,95,253,121,1,186,254,63,251,185,5,32,254,51,255,136,247,103,249,178,2,99,1,168,4,222,2,143,255,39,0,26,254,124,253,182,1,72,4,45,253,244,253,158,249,147,253,118,254,226,0,167,0,143,253,59,253,86,3,189,11,114,252,13,0,231,252,19,250,26,251,18,0,72,254,188,252,139,2,225,255,229,0,199,251,130,255,65,255,228,241,231,1,195,1,220,254,175,3,30,248,150,253,253,254,119,253,45,253,65,254,18,255,72,4,76,247,163,2,51,2,196,254,32,251,32,0,228,255,37,1,231,248,226,0,11,1,11,5,112,2,25,247,143,0,138,2,5,0,205,253,8,254,180,247,162,255,179,249,22,244,196,2,126,242,186,1,30,0,65,0,176,255,89,0,204,0,11,255,94,0,28,0,254,255,25,255,111,2,67,255,107,254,157,247,123,4,52,12,38,3,24,4,121,4,141,2,47,0,86,0,252,255,46,0,181,1,229,0,66,255,54,1,203,7,208,255,9,252,242,248,246,254,83,252,105,1,179,0,172,0,141,1,182,0,67,1,252,253,107,13,7,0,251,255,191,254,249,255,187,229,220,255,77,0,236,255,155,255,239,253,90,255,97,0,180,255,24,255,186,255,16,0,13,0,93,0,206,255,222,0,254,254,184,238,131,255,125,0,83,0,57,1,10,255,187,254,108,0,181,254,228,1,68,255,192,0,60,252,43,10,218,255,68,247,58,0,81,1,2,255,239,255,166,255,168,255,40,0,115,255,243,250,200,255,213,252,247,0,178,255,222,255,144,0,112,0,43,0,142,0,119,255,109,255,56,0,106,254,12,0,210,0,132,0,123,14,109,0,128,252,244,254,9,247,3,254,32,0,37,255,113,0,152,255,141,0,17,1,18,0,154,254,16,0,230,242,146,13,89,255,220,0,10,0,104,0,81,255,248,255,185,255,179,255,208,255,21,1,82,0,86,0,35,0,56,253,224,255,36,0,191,255,213,0,121,0,180,255,26,253,35,1,21,238,87,255,134,255,179,255,227,254,54,0,136,255,89,0,71,0,12,0,123,255,54,0,41,255,142,248,141,255,148,12,62,255,121,254,87,0,159,1,44,255,46,255,118,255,182,0,78,2,201,2,176,3,64,1,142,0,78,248,197,0,177,255,220,253,202,1,20,11,33,0,194,255,73,255,107,255,128,253,147,0,85,254,143,255,78,255,161,249,148,255,106,10,198,255,162,8,5,255,32,1,16,0,126,1,75,8,124,2,252,255,94,4,232,0,79,1,223,255,142,255,24,0,188,255,29,5,218,255,32,8,22,2,32,1,94,255,138,253,152,254,125,253,10,0,62,0,75,247,7,1,19,0,54,1,212,255,163,1,30,11,237,245,97,255,10,255,173,2,189,255,138,1,58,1,156,254,98,255,19,0,90,0,116,0,43,247,163,0,152,2,163,0,65,255,207,255,238,255,204,254,241,255,204,9,142,254,181,2,194,255,50,3,205,254,110,253,133,0,66,7,220,236,53,0,75,246,208,255,247,255,126,0,159,0,6,0,185,255,35,1,102,0,145,254,194,255,27,0,88,0,250,255,204,0,191,255,43,253,31,0,97,255,255,255,251,255,45,0,123,255,110,255,5,1,127,238,237,255,182,2,251,254,34,254,79,255,88,0,214,0,188,252,242,255,6,253,145,255,245,1,0,0,254,0,179,7,0,252,118,10,115,255,80,232,76,0,174,1,160,0,61,255,186,253,24,1,68,2,183,0,197,254,243,255,153,2,203,255,59,1,57,255,182,1,220,0,195,12,194,0,2,0,248,10,168,255,42,0,150,0,77,255,237,0,101,255,143,0,46,0,99,0,27,0,30,0,7,232,205,255,167,255,201,0,145,0,77,255,13,0,154,254,55,0,71,0,253,255,28,0,247,255,240,255,125,0,160,0,159,0,235,255,225,234,27,254,252,255,168,255,167,255,44,0,3,0,166,0,22,0,99,254,225,3,80,0,229,1,149,255,190,1,81,252,1,4,5,1,253,255,175,11,35,2,244,254,147,255,24,2,246,255,187,0,17,0,132,1,136,255,185,255,169,254,96,254,162,0,69,0,247,255,46,0,35,254,83,0,246,23,146,0,20,255,131,255,162,255,201,255,238,254,25,255,96,4,171,0,117,255,102,245,80,0,145,255,20,0,171,9,121,255,82,249,61,1,6,253,155,0,198,4,68,0,168,4,241,255,33,7,220,255,211,255,136,255,28,254,125,255,94,255,128,255,163,0,105,254,72,0,34,255,210,255,34,255,57,235,22,1,139,254,76,254,28,1,138,0,13,255,152,255,28,0,179,255,206,11,93,0,241,255,187,253,14,254,36,1,91,255,52,249,121,0,195,0,168,250,122,255,188,255,236,255,181,255,246,255,113,0,128,0,131,254,5,254,19,255,59,253,13,0,234,255,155,0,55,236,161,255,246,0,30,255,193,0,175,2,47,7,246,0,24,255,153,254,219,1,106,0,41,1,205,0,114,245,134,254,37,255,236,255,140,0,130,243,192,0,251,243,121,255,218,255,233,255,213,0,184,255,255,0,166,255,126,255,106,255,62,0,28,254,162,255,191,245,167,255,88,1,127,255,95,10,113,1,221,255,17,0,71,253,251,0,169,254,68,0,53,0,176,0,32,12,237,0,181,255,52,244,178,0,45,0,170,255,45,0,141,255,183,0,49,0,26,0,140,0,77,0,40,0,245,246,249,0,255,6,48,0,13,253,244,255,201,0,57,254,6,255,194,255,193,6,143,255,65,252,238,0,142,255,33,1,121,255,96,247,188,10,65,0,50,1,173,255,3,0,255,253,31,254,207,255,93,255,200,253,168,255,156,2,205,255,230,245,106,0,234,255,72,2,59,254,162,254,77,1,79,255,20,255,111,253,24,2,163,254,138,1,200,255,14,0,133,0,201,255,172,255,210,0,237,255,57,222,154,0,80,0,27,0,249,255,180,255,139,255,100,0,55,255,1,0,40,1,155,255,250,255,10,22,137,0,197,255,163,255,95,0,146,255,232,254,195,255,212,254,25,0,119,3,43,0,226,255,189,9,76,0,234,255,169,254,233,1,10,1,52,1,163,0,132,0,163,254,229,7,18,0,176,60,61,0,11,0,215,255,214,255,41,0,252,255,73,255,216,255,232,255,26,0,241,0,154,255,141,255,92,255,252,7,221,255,39,255,30,255,222,2,28,255,14,246,218,0,0,0,122,0,106,255,240,253,68,255,7,251,155,0,107,0,223,255,219,255,219,254,6,0,112,0,101,255,28,255,192,0,182,246,153,0,235,251,213,0,159,11,39,0,97,255,246,255,215,255,34,0,131,255,4,0,226,255,67,15,215,255,80,3,166,254,191,0,61,255,220,254,130,255,93,13,232,255,12,255,92,0,181,2,64,0,63,255,192,0,121,0,223,255,115,255,11,2,94,255,194,10,71,0,59,0,40,0,193,255,114,255,156,255,174,254,123,1,120,255,192,255,60,255,11,0,126,12,162,0,49,8,124,255,201,246,63,255,114,254,194,254,74,3,133,253,88,255,169,1,209,7,120,255,34,1,206,0,50,2,160,255,248,255,42,255,211,255,245,255,4,0,52,0,177,0,108,255,229,0,33,0,208,255,210,255,138,25,150,255,229,255,234,255,127,25,20,0,107,254,157,0,87,0,208,0,139,255,252,255,30,0,87,0,28,0,156,254,180,255,148,255,223,255,200,253,242,254,177,0,49,0,55,254,118,243,119,0,103,0,0,1,76,255,211,0,71,251,143,254,0,255,37,0,209,255,112,19,84,0,207,0,225,0,224,0,87,254,140,1,153,3,58,0,106,255,104,0,229,5,15,0,198,255,188,6,47,0,232,255,21,0,120,1,97,1,226,1,20,255,122,2,50,1,107,12,73,0,223,255,202,255,87,255,42,255,146,0,226,16,40,255,124,253,49,1,49,1,59,254,53,0,143,0,247,255,64,250,115,255,34,5,57,0,40,0,201,255,176,255,67,0,48,36,57,0,86,0,22,0,109,255,1,0,250,255,0,0,39,0,7,0,114,0,205,255,119,255,155,0,241,255,134,255,5,0,137,0,125,0,213,0,250,255,246,27,36,0,204,255,202,255,149,0,133,3,91,3,191,2,110,1,161,2,243,255,162,4,76,2,54,255,61,254,18,0,183,253,6,255,184,245,122,255,61,0,34,244,254,3,78,0,96,253,236,254,96,0,70,3,21,2,2,255,243,253,150,255,134,254,91,6,12,0,31,0,61,1,138,255,81,0,57,1,70,255,197,0,196,1,101,244,83,0,46,5,163,1,194,246,184,254,169,255,153,255,13,255,232,254,25,0,16,255,78,2,24,255,105,0,106,244,169,246,186,254,82,1,80,0,120,254,13,255,15,1,249,255,103,4,1,0,109,7,25,247,49,255,32,0,157,255,48,2,63,255,115,1,238,1,250,1,255,0,76,1,241,41,48,0,8,0,223,255,223,255,32,0,223,255,45,0,152,255,253,254,157,255,219,255,122,255,72,0,206,255,138,0,172,1,46,247,77,0,232,2,5,0,96,0,204,11,243,254,49,0,112,0,33,255,186,0,48,0,224,0,11,10,84,1,127,255,217,255,148,248,211,255,186,7,251,254,223,0,38,1,22,0,148,255,198,255,109,0,225,255,76,243,118,255,103,244,237,255,123,255,190,0,220,255,132,0,120,255,63,0,81,255,95,1,180,255,232,0,108,245,239,255,232,255,126,255,38,254,74,0,94,244,45,0,117,255,233,255,227,0,214,255,115,255,22,1,81,0,8,0,69,246,66,254,59,1,192,255,89,255,125,253,237,254,100,0,0,0,180,9,30,254,128,255,112,255,50,255,19,241,187,242,203,0,231,255,234,255,68,0,189,0,243,255,226,254,94,0,18,0,32,1,29,0,251,255,3,0,98,254,203,5,84,255,5,251,76,255,48,241,104,1,145,0,113,255,188,1,117,255,58,255,70,0,239,255,159,254,135,255,250,255,76,0,206,255,171,11,173,0,2,244,27,255,240,255,192,0,134,0,201,255,170,255,56,255,128,0,252,247,197,255,245,255,252,255,53,1,179,0,238,1,118,255,149,254,176,254,119,0,129,255,193,9,87,255,196,254,169,255,230,253,42,0,234,253,59,1,60,9,61,0,13,1,169,255,162,255,82,0,235,247,18,0,214,4,249,255,79,0,247,255,41,0,70,0,50,0,209,0,98,255,120,255,28,0,237,254,62,0,40,1,77,0,125,24,72,255,73,0,237,255,231,255,199,255,134,0,204,255,121,33,80,255,248,255,17,0,15,0,79,0,36,0,119,255,12,0,44,0,242,254,31,9,111,0,5,2,173,255,207,0,236,254,17,10,58,255,83,0,120,1,181,255,239,254,62,0,109,0,4,0,208,255,122,0,215,255,99,0,169,255,14,0,240,225,138,255,190,255,171,0,96,0,225,255,123,0,39,255,92,253,73,254,151,1,97,0,231,254,81,7,114,2,108,255,220,253,98,6,192,2,97,0,228,247,176,254,120,2,141,254,113,0,32,2,168,255,184,0,104,247,92,254,176,253,88,255,247,2,35,1,167,8,192,2,116,255,111,255,8,240,39,1,186,0,242,254,27,1,38,1,214,255,76,0,69,0,41,0,116,255,99,6,56,255,86,253,46,1,64,255,134,3,228,253,181,252,18,254,239,253,102,0,9,253,91,255,88,12,76,255,86,250,88,254,240,255,6,0,220,253,40,1,16,244,219,0,165,248,147,255,202,253,81,254,95,0,90,254,236,253,230,255,120,0,210,255,23,0,174,0,175,0,143,254,110,0,254,255,25,0,132,0,255,255,246,242,189,255,92,8,231,255,54,2,127,255,35,0,163,4,81,1,207,7,152,10,185,255,45,0,79,255,94,0,191,254,59,255,195,253,98,0,225,0,46,0,53,0,78,0,216,255,82,0,23,0,158,10,230,9,89,0,191,255,77,0,206,0,87,1,15,2,102,0,65,255,94,0,207,1,111,0,79,238,97,0,108,3,51,255,80,252,181,0,124,255,211,1,110,1,85,0,210,254,156,255,223,255,180,255,241,243,14,246,215,0,21,1,204,255,96,1,137,0,211,255,162,0,78,2,150,1,126,1,85,0,248,244,141,0,219,0,50,241,40,0,126,0,32,0,30,0,100,0,121,0,46,255,196,0,244,254,178,0,102,0,205,4,176,255,18,253,245,255,199,255,84,0,238,0,243,13,18,1,2,255,55,0,176,249,80,255,13,253,46,0,230,250,55,255,28,255,101,0,197,0,163,255,100,255,63,1,82,0,127,254,239,255,204,237,180,0,254,4,143,255,41,255,103,0,64,3,23,255,156,1,249,0,124,252,124,255,157,242,52,0,160,1,11,1,61,1,128,254,130,0,78,0,91,0,152,254,75,0,130,1,171,8,152,254,97,244,17,0,30,1,218,254,43,255,231,0,131,0,53,3,154,254,222,0,26,255,212,255,163,255,129,251,38,1,196,254,248,255,129,0,231,0,31,252,198,255,247,12,48,0,14,246,43,255,242,255,136,12,162,0,16,255,80,255,51,1,91,255,236,255,92,1,143,255,178,255,165,255,248,255,251,254,97,31,77,255,64,0,249,255,143,255,197,255,224,255,86,255,52,0,55,0,176,255,140,0,64,0,217,255,147,3,28,0,160,1,38,0,232,246,206,0,115,0,110,1,164,255,140,2,110,0,234,244,197,255,101,2,23,0,109,0,105,255,58,255,185,0,217,11,134,255,47,11,239,254,86,0,41,0,114,0,157,255,59,1,116,1,14,0,143,8,85,255,19,2,238,255,222,255,160,254,130,0,152,254,117,0,176,244,2,0,204,253,51,0,223,0,57,0,255,254,89,12,58,12,128,254,126,0,216,255,96,255,24,255,118,255,81,0,222,255,160,255,82,0,9,0,62,0,95,255,88,1,100,0,22,3,13,255,168,254,119,254,237,253,145,1,90,0,171,0,144,0,183,254,7,0,225,237,121,255,250,255,95,1,235,255,61,255,224,0,231,255,139,23,224,0,242,255,88,1,170,0,87,255,159,255,252,0,24,254,133,254,183,255,117,2,247,255,10,1,152,0,192,255,74,1,248,255,32,8,165,255,13,243,229,0,25,0,45,0,240,253,133,255,135,11,40,0,171,255,252,255,121,245,218,255,144,255,84,0,226,255,79,0,250,2,151,0,7,240,161,255,105,255,9,0,138,0,50,255,253,255,190,247,99,0,156,255,116,0,109,254,200,255,248,255,220,255,115,0,238,255,61,255,218,255,16,255,8,0,224,255,122,0,125,0,18,227,45,0,46,255,111,0,104,255,104,255,221,255,184,255,28,0,102,255,47,1,181,243,203,1,191,244,242,255,243,255,200,255,130,255,187,255,43,255,159,255,202,0,168,255,235,254,211,253,195,1,136,254,165,255,63,1,141,0,168,10,23,0,202,9,155,255,120,2,62,0,198,254,159,0,44,0,207,4,191,255,219,255,192,0,46,12,70,255,116,254,148,255,71,0,63,8,74,2,95,0,15,0,228,255,176,0,20,0,189,255,3,0,247,254,101,0,74,255,235,255,57,254,241,255,175,231,211,255,159,254,128,254,234,255,113,0,216,255,209,255,57,0,183,255,9,254,134,0,224,2,186,255,131,255,251,255,6,255,62,0,165,0,182,0,185,0,124,255,170,1,236,254,100,0,15,254,233,255,81,0,144,255,56,242,51,248,22,255,102,255,165,255,131,255,230,255,179,0,157,253,143,2,255,2,216,251,130,0,248,254,107,0,251,10,145,250,42,1,236,255,37,0,182,255,244,255,99,255,242,254,150,255,255,9,167,255,221,243,55,0,187,0,247,254,195,0,140,0,1,0,28,254,201,2,171,0,157,251,30,255,82,14,145,254,252,253,7,255,38,0,195,0,236,0,134,254,129,254,51,255,184,255,249,255,15,0,143,219,250,255,230,255,56,0,141,0,48,0,6,0,115,255,161,255,187,255,216,255,157,255,176,255,73,0,3,255,200,1,82,255,51,0,6,255,208,255,189,247,193,255,5,246,231,255,246,247,198,255,66,0,176,0,14,0,187,216,233,255,217,255,219,255,241,255,38,0,82,0,11,0,97,0,169,0,5,0,189,255,57,0,61,0,56,247,108,0,237,255,0,1,87,255,134,255,176,254,81,254,179,255,6,255,100,255,23,253,184,0,172,2,63,41,57,255,222,255,219,255,96,0,174,255,239,255,60,0,65,0,21,0,189,255,175,254,62,0,35,0,74,0,42,255,38,0,47,0,127,255,251,23,117,255,199,255,102,255,5,1,7,0,129,255,109,0,40,0,179,0,157,255,198,0,205,255,48,0,220,255,183,246,62,255,178,254,246,244,103,0,36,255,199,255,41,0,211,3,129,252,68,0,39,255,80,249,82,254,158,255,91,0,149,255,37,249,55,10,84,0,12,254,231,0,224,1,225,255,146,0,99,255,136,255,152,0,38,9,220,255,79,248,57,0,147,255,220,1,13,255,5,1,198,255,206,7,4,0,108,5,158,255,45,0,116,255,144,1,180,255,191,254,234,255,247,255,210,0,5,2,5,0,156,237,66,0,182,254,107,254,237,255,110,8,191,255,141,247,244,0,240,255,64,255,238,1,131,254,62,255,157,1,89,0,220,0,199,1,202,255,4,0,206,0,221,0,122,236,63,0,147,254,98,1,108,1,165,2,207,0,190,255,229,255,35,254,74,255,73,3,85,0,216,255,166,0,71,255,65,1,219,254,75,255,83,254,25,255,121,5,134,255,170,3,67,0,71,255,51,0,116,12,222,252,165,1,98,243,152,5,80,254,110,253,181,253,181,252,165,1,177,0,190,1,254,1,116,255,166,255,129,255,178,255,2,0,65,4,71,255,45,1,119,254,4,16,104,255,9,1,224,0,25,0,95,0,22,2,24,1,2,255,211,255,251,255,49,255,49,0,130,255,218,34,43,0,9,0,21,0,28,0,21,0,214,255,172,255,38,0,90,0,34,248,61,0,107,255,188,0,234,242,136,255,213,255,10,0,14,0,155,0,31,255,161,254,142,255,28,0,233,255,208,238,111,1,205,255,76,0,167,255,143,255,122,0,215,7,25,0,164,254,29,255,142,254,195,255,135,0,177,255,175,255,5,0,240,255,34,0,19,0,186,42,141,0,235,255,27,0,151,255,146,255,32,0,189,255,181,255,19,0,118,255,3,0,242,255,104,254,210,254,36,0,252,237,23,0,189,253,221,255,19,0,200,254,35,0,120,0,97,0,82,0,147,255,41,0,47,249,98,255,43,1,3,244,84,0,18,0,65,254,223,255,65,0,224,255,45,0,249,255,144,0,86,0,100,0,54,249,250,0,30,255,119,255,159,0,211,255,134,0,182,1,102,0,37,0,241,255,95,255,233,255,125,16,174,0,47,0,248,254,74,255,74,255,174,2,8,255,89,0,215,255,80,0,129,245,62,255,248,9,151,1,174,251,54,252,75,255,28,255,43,17,118,0,3,4,1,255,136,0,100,0,213,255,246,0,80,0,15,0,34,0,82,0,202,255,145,254,186,2,232,0,79,255,45,0,189,255,49,0,138,0,98,255,168,0,202,0,43,0,186,255,155,255,20,0,159,255,119,242,170,254,1,255,127,0,25,0,204,255,251,255,7,0,76,0,253,255,19,0,237,255,42,0,10,0,193,255,16,0,121,0,220,2,201,243,213,255,116,0,36,0,41,246,23,0,18,0,181,0,41,0,224,255,245,255,22,0,51,0,35,0,16,0,222,255,194,255,208,6,94,0,173,0,37,251,250,254,11,0,146,12,239,0,149,0,37,255,29,0,118,0,130,254,223,254,214,255,161,0,17,0,255,255,247,9,173,255,90,0,128,255,138,0,166,12,43,0,227,255,144,255,110,0,244,254,37,1,23,0,139,255,192,255,119,255,79,0,186,255,5,214,190,255,73,0,90,0,35,0,90,0,227,255,178,255,145,255,75,0,48,0,8,0,87,255,128,11,16,0,89,0,186,0,222,255,82,0,241,0,210,255,1,1,13,255,93,0,150,11,178,0,0,255,238,255,223,255,103,0,192,254,241,254,16,12,77,11,6,255,102,0,184,2,124,0,45,255,18,0,113,255,97,0,216,0,157,255,195,0,40,0,221,255,144,0,26,0,135,0,104,255,41,255,120,0,25,0,2,255,173,248,145,2,197,0,57,242,180,254,54,1,245,255,166,7,102,0,244,255,211,255,2,0,129,255,4,0,1,0,237,255,47,0,236,255,204,255,97,0,226,255,198,225,51,0,26,0,5,0,235,255,18,0,15,0,15,0,66,0,30,0,248,255,249,255,225,255,255,255,223,255,38,0,164,0,90,0,142,26,223,255,166,255,239,255,251,255,14,0,214,255,21,0,236,255,215,255,48,0,250,255,220,255,6,0,49,255,245,238,211,19,31,0,6,0,100,0,65,0,86,0,19,0,98,255,28,0,122,255,165,255,188,255,9,0,230,255,219,255,28,10,51,1,139,13,61,254,101,0,71,254,67,1,62,0,188,0,124,255,218,254,98,0,234,255,152,0,210,255,65,0,217,255,219,255,174,255,247,255,18,0,43,0,17,0,8,0,56,0,97,0,212,210,21,0,15,0,75,0,85,0,155,0,15,0,32,0,0,0,20,0,211,255,244,28,48,0,3,0,38,0,72,0,30,0,23,0,42,0,236,255,146,255,58,254,23,255,141,2,187,254,236,254,248,1,31,254,71,2,14,1,119,253,225,1,162,243,83,6,164,0,166,255,150,0,32,0,160,255,209,255,49,0,243,255,115,0,73,255,75,0,62,0,190,220,12,0,163,255,53,253,6,0,137,0,174,254,42,3,217,255,235,254,148,255,236,255,59,1,60,2,253,255,38,238,29,4,124,255,13,0,132,1,33,255,157,254,31,0,209,255,61,0,143,255,5,0,218,255,43,0,209,255,176,255,246,9,27,0,247,0,21,1,170,255,80,1,139,0,146,0,145,255,183,255,187,0,200,254,68,0,236,254,72,0,126,2,73,0,24,3,86,255,103,5,165,1,65,253,27,241,112,0,135,1,61,255,94,255,228,255,231,255,61,1,228,0,173,255,3,18,142,2,97,1,132,254,229,254,141,253,211,254,161,0,100,255,175,255,5,0,241,255,243,255,239,255,53,0,206,255,36,0,190,255,15,225,254,255,202,255,215,255,230,255,47,0,253,255,22,0,250,255,11,0,63,0,2,0,42,0,71,0,206,255,169,255,217,255,2,0,200,255,254,255,157,43,44,0,137,255,182,255,131,0,134,0,5,0,115,0,217,255,144,0,233,255,0,0,186,0,40,18,95,1,36,0,186,255,185,255,170,6,83,8,28,255,42,0,6,0,8,0,4,0,213,255,244,255,216,255,212,255,249,255,242,255,11,0,83,0,163,255,112,255,186,0,210,255,247,255,13,0,169,255,136,255,70,0,47,255,115,0,71,242,139,0,210,255,133,0,96,0,25,0,215,0,221,255,75,254,126,0,147,1,141,255,145,0,203,0,187,255,178,254,37,0,166,3,31,254,91,12,32,246,207,255,57,0,100,0,76,0,82,0,251,0,32,1,142,255,46,0,55,255,95,255,95,255,52,253,16,240,122,1,194,252,2,255,12,0,194,247,212,254,78,0,32,1,48,0,166,255,157,255,225,255,146,255,201,0,66,0,71,1,119,0,76,255,148,0,121,2,71,0,252,239,33,0,57,0,247,255,208,255,151,0,236,255,72,0,71,0,245,255,39,0,189,255,176,0,27,0,143,0,198,0,127,1,155,0,110,12,128,255,104,255,119,243,84,255,250,254,243,255,129,0,89,255,128,255,55,0,46,0,219,255,70,0,107,0,7,0,233,255,222,247,241,0,236,0,209,255,171,255,105,0,209,255,54,255,208,0,201,0,30,0,150,255,242,255,218,255,14,0,211,255,24,0,232,255,51,47,22,0,151,0,198,255,247,255,59,0,170,0,113,0,174,255,113,1,101,255,53,0,97,0,71,255,199,255,203,0,55,1,236,0,181,18,232,255,177,253,73,250,118,0,94,0,238,254,116,12,111,255,106,254,183,0,0,0,202,255,17,0,234,255,37,0,201,255,222,255,63,0,172,254,175,0,212,254,106,0,66,255,218,255,67,0,254,255,19,0,210,255,214,255,11,0,223,255,223,255,228,255,246,255,229,255,237,219,29,0,62,0,97,252,5,5,49,0,72,0,65,0,89,0,57,0,212,255,247,255,241,255,85,0,255,255,74,0,81,0,133,255,160,0,69,0,13,245,234,255,47,0,45,254,182,255,236,2,168,0,247,255,235,0,173,243,102,255,48,0,227,1,171,254,74,0,99,9,97,0,93,0,150,255,219,0,136,0,65,255,206,255,7,0,71,0,153,255,5,1,211,12,132,255,144,253,246,245,73,0,225,255,10,0,183,255,30,0,241,255,48,247,254,255,183,255,55,0,73,0,14,0,182,255,175,255,38,0,96,1,108,0,238,255,25,0,61,0,54,0,1,0,251,255,109,0,25,0,140,245,231,255,204,255,196,254,2,0,36,0,220,255,157,254,40,0,237,255,120,0,27,0,252,255,205,255,248,255,42,0,246,255,228,255,166,255,113,255,29,0,246,255,6,223,234,255,202,253,59,0,217,255,255,255,27,0,29,0,236,255,6,0,19,0,0,0,220,255,38,0,68,0,213,255,35,0,22,0,209,255,110,255,239,13,13,0,12,0,158,12,238,255,224,255,75,0,144,255,248,255,99,255,233,255,101,0,165,0,198,0,93,0,127,1,212,4,53,4,248,241,135,250,111,4,76,3,246,254,182,255,186,255,232,254,158,255,67,0,147,255,38,0,11,236,190,255,199,255,89,0,235,255,6,0,19,0,235,255,70,0,60,0,76,0,35,0,18,0,44,0,51,0,45,0,40,0,54,0,227,229,189,255,9,0,113,0,227,255,246,255,160,255,80,0,98,0,103,0,216,255,248,255,236,255,125,255,15,0,6,1,47,0,3,255,140,255,244,255,57,237,2,0,175,255,76,0,210,255,37,0,97,1,126,255,65,255,129,255,246,255,221,255,91,0,134,255,173,0,91,255,248,255,181,196,86,0,70,255,123,0,217,254,231,255,21,0,63,0,163,255,218,2,20,0,136,255,240,237,84,1,3,255,39,254,44,0,238,255,157,255,219,255,202,255,195,254,65,0,204,255,119,8,68,0,11,255,224,0,117,0,76,255,169,237,236,254,118,0,142,0,155,255,202,0,211,254,223,255,127,255,209,254,166,255,181,255,50,0,98,0,200,255,188,255,103,255,218,255,168,0,234,254,234,255,192,255,29,38,165,255,233,255,4,5,53,0,56,0,245,255,210,255,147,249,11,0,15,0,12,0,8,0,216,255,254,255,84,0,200,255,17,0,249,255,226,255,86,240,27,242,4,255,56,0,177,255,169,255,249,255,8,0,79,0,16,0,21,0,51,0,193,255,234,255,118,0,228,0,11,250,178,255,234,255,254,255,16,0,207,255,17,0,219,255,253,255,242,255,10,0,31,0,17,0,145,255,32,0,112,255,228,241,145,13,79,0,23,0,167,255,74,0,33,0,227,255,11,0,214,255,214,255,127,255,215,255,155,0,52,0,31,0,94,255,65,49,147,0,17,0,68,0,2,0,15,0,244,255,217,255,50,0,148,255,190,255,121,0,69,0,229,255,94,0,241,255,229,225,115,0,30,0,220,255,229,255,234,255,213,255,2,0,5,0,31,0,255,255,87,0,2,0,41,0,21,0,14,1,16,0,163,14,251,252,211,11,224,0,92,0,88,255,249,255,194,255,177,255,212,255,247,255,252,255,198,255,178,255,39,4,203,0,254,255,76,0,33,1,220,255,92,0,227,255,178,255,108,255,200,235,137,0,219,0,43,1,89,0,23,255,62,0,127,255,33,0,123,0,226,255,197,0,178,15,219,255,218,255,139,0,41,0,153,0,71,0,230,255,27,0,53,0,72,0,30,13,188,255,134,255,37,1,237,255,157,254,104,0,34,0,49,12,16,0,29,0,168,254,37,0,174,0,228,255,213,255,154,255,197,255,131,249,14,0,5,0,194,255,255,255,14,0,15,0,214,255,4,0,225,255,254,255,13,0,23,0,189,3,93,254,20,0,31,0,242,255,51,0,24,0,210,255,8,0,240,255,27,0,181,255,229,255,223,255,228,255,18,0,189,255,104,255,208,255,47,0,90,0,48,0,182,255,153,255,238,255,255,18,3,0,132,0,158,1,170,255,196,255,29,1,16,0,32,0,212,255,0,0,22,0,93,255,23,0,253,255,23,0,195,255,168,51,52,0,117,255,243,255,171,0,215,0,205,255,235,255,208,255,33,0,246,255,239,255,235,255,18,226,199,255,212,255,205,255,35,0,35,0,34,0,105,0,178,0,179,255,77,0,147,0,67,0,208,252,97,11,241,243,4,2,144,255,216,254,21,0,133,0,211,0,162,0,87,0,231,255,233,253,194,252,244,255,46,0,197,255,246,255,252,255,42,0,0,0,165,255,247,255,47,0,166,255,227,255,74,0,66,1,150,255,83,0,44,0,85,18,236,252,183,255,171,255,151,255,180,255,249,251,34,0,6,0,78,0,222,255,160,0,208,255,61,253,244,255,247,255,39,0,14,0,23,0,88,0,18,247,21,0,231,255,42,0,130,0,39,0,251,0,16,0,206,255,141,1,30,255,246,245,88,0,127,255,165,254,159,0,92,0,0,0,212,255,207,255,235,0,60,255,232,255,220,255,113,0,75,52,45,0,22,0,54,0,236,255,29,0,27,0,229,255,54,0,38,0,193,255,244,255,182,255,45,0,248,255,141,255,79,2,46,0,5,0,22,255,57,0,124,0,86,0,46,241,205,255,36,1,96,255,104,255,96,0,178,254,92,1,96,0,70,255,226,240,125,241,54,0,0,0,227,255,191,255,188,255,6,0,132,0,47,0,101,255,62,0,26,0,66,0,246,255,210,255,235,243,66,0,49,14,183,0,85,255,124,255,232,255,154,0,157,0,129,0,71,255,12,0,230,255,96,0,244,255,88,0,222,255,42,0,241,255,37,0,31,230,229,255,13,0,41,0,226,255,62,0,142,0,163,255,88,255,84,0,234,255,139,0,237,255,18,0,94,41,145,255,36,0,13,0,212,255,4,0,211,255,253,255,253,255,28,0,231,255,252,255,115,0,119,0,207,255,41,0,33,0,87,0,171,255,156,48,73,0,71,0,145,255,61,0,241,255,117,0,23,0,232,255,251,255,131,0,225,255,255,255,234,255,199,255,244,255,50,0,35,0,237,249,236,255,38,0,82,0,204,255,27,0,128,255,230,200,40,3,190,0,89,0,83,2,63,0,221,254,26,1,208,255,32,0,62,253,79,254,95,253,213,12,31,5,62,3,161,14,52,255,95,251,184,253,205,255,184,3,237,3,202,253,228,6,186,0,187,4,17,254,144,255,189,4,192,0,16,9,213,255,226,255,24,0,128,251,2,0,2,0,32,0,201,255,231,255,254,255,239,255,242,255,250,255,22,0,202,255,32,0,45,0,10,0,171,255,230,255,240,255,190,255,196,255,46,255,152,255,208,0,8,255,62,0,228,255,40,199,245,255,212,255,65,6,47,0,118,255,46,0,221,255,87,10,175,255,253,255,218,255,190,255,197,255,223,255,237,255,43,0,239,255,177,255,53,0,29,7,220,249,22,10,85,0,48,0,116,255,78,0,101,255,83,255,96,0,224,255,121,0,198,255,201,0,82,255,202,255,74,0,118,246,230,254,253,252,37,0,142,244,15,0,226,6,154,0,7,1,241,255,237,255,139,0,246,0,13,255,225,255,84,0,145,0,8,0,152,0,43,0,128,0,167,2,36,7,148,13,17,0,92,0,102,0,2,1,227,255,237,254,217,255,69,255,88,0,70,0,28,0,2,0,95,8,18,1,202,0,189,255,243,255,234,255,68,0,221,255,135,0,114,0,108,0,27,0,1,0,16,212,156,255,14,0,26,0,59,0,10,0,232,255,30,0,1,0,218,255,247,255,21,0,18,0,255,255,237,7,173,255,170,254,115,13,231,255,7,0,0,0,54,0,78,0,198,0,45,0,233,0,250,255,0,0,147,255,84,255,54,247,41,0,177,255,4,11,44,0,216,0,39,0,59,0,215,255,52,0,79,0,204,255,12,0,23,0,184,255,131,255,83,0,17,0,228,255,224,255,13,0,2,0,28,0,0,0,230,255,75,0,175,255,66,0,25,0,175,255,116,25,9,0,163,255,49,0,60,240,76,246,214,255,185,255,178,0,99,0,123,255,79,0,215,255,144,255,57,0,66,0,228,255,13,0,39,0,64,0,133,255,102,12,245,11,3,1,55,0,123,0,133,255,246,0,118,255,139,0,75,0,31,0,41,255,102,255,38,255,26,0,16,0,21,0,126,0,26,0,223,255,246,255,241,255,16,0,236,255,203,255,21,0,166,60,221,255,197,255,206,255,245,255,198,255,67,0,245,255,107,0,232,255,219,255,219,31,31,0,145,255,194,255,138,0,196,255,246,255,84,0,128,255,37,0,24,0,211,255,246,255,129,0,188,255,219,255,42,0,176,255,51,255,177,255,106,23,163,255,242,254,112,254,20,0,167,255,217,255,56,255,230,0,197,0,69,1,207,254,218,254,94,0,135,12,128,0,47,12,226,0,28,0,207,255,8,1,186,0,8,0,227,255,243,255,27,0,22,0,193,255,43,0,84,0,237,255,57,0,211,245,60,1,3,1,213,255,50,0,63,247,105,0,244,255,233,255,220,255,89,0,41,0,241,255,145,0,10,0,175,255,7,0,206,255,70,0,60,0,233,255,55,0,194,255,0,0,52,0,179,255,180,0,74,0,79,0,39,200,6,0,24,0,43,1,149,255,4,0,227,255,76,243,205,255,40,0,113,255,222,13,228,255,102,0,24,0,215,0,147,0,87,255,196,255,213,255,26,254,5,0,255,255,62,0,140,255,155,244,174,1,50,0,111,11,139,0,127,0,63,0,203,255,141,0,1,255,171,255,95,0,155,255,80,255,195,0,104,0,6,244,200,255,167,12,95,255,42,255,57,0,24,0,137,254,75,255,0,0,253,254,130,0,136,255,254,255,250,255,175,0,109,255,71,255,68,0,219,0,169,1,125,10,208,243,10,1,246,0,242,254,186,255,17,1,168,0,121,0,113,255,81,10,215,253,221,253,126,2,113,0,149,11,95,255,29,0,138,254,105,0,155,252,108,0,70,0,15,0,230,0,202,255,150,255,235,255,252,255,86,0,85,0,155,0,136,255,239,255,235,255,26,246,57,0,149,0,127,255,21,0,87,255,15,247,129,255,237,255,230,255,3,0,60,0,35,0,1,0,228,255,249,255,36,0,76,255,243,255,87,0,188,255,56,0,80,0,64,0,248,255,183,255,35,26,224,255,47,0,48,0,250,255,61,0,36,0,248,255,215,255,255,255,13,0,68,0,140,0,205,255,25,0,12,0,3,0,57,0,202,255,223,255,237,255,12,0,28,0,196,255,200,255,161,246,242,255,127,0,143,7,84,0,127,0,63,255,253,255,235,12,200,255,15,0,31,0,140,255,69,255,236,0,223,254,5,1,69,0,144,0,187,6,79,0,188,255,102,0,215,2,69,0,142,2,196,255,21,0,124,0,169,13,248,0,84,253,189,5,112,1,2,255,45,255,216,245,3,3,118,255,112,1,17,12,52,0,50,255,147,0,200,0,241,255,120,255,194,0,92,255,160,254,104,255,250,236,5,0,191,0,253,255,159,255,28,0,215,255,107,0,2,0,11,0,60,0,180,255,221,255,214,255,129,0,179,255,206,245,217,254,38,255,143,254,10,0,253,0,15,0,131,255,74,0,169,255,186,255,38,13,115,0,240,0,150,255,163,255,121,0,10,0,36,0,9,0,238,255,190,255,179,255,7,0,37,0,180,255,234,255,97,11,242,0,22,0,172,0,102,0,186,0,25,255,90,0,245,255,199,255,45,0,246,255,212,255,172,255,44,0,139,255,213,255,49,0,209,21,18,0,90,255,213,255,64,0,28,0,247,255,26,0,96,255,31,0,228,255,29,0,56,0,29,0,199,255,109,0,231,255,68,12,125,255,57,0,236,255,27,0,229,255,251,255,214,255,204,255,18,0,23,0,200,255,218,255,242,255,213,0,223,255,170,255,123,237,105,255,210,255,1,0,239,255,46,0,7,0,243,255,0,0,50,0,28,0,199,255,133,227,236,255,12,0,66,0,214,0,119,2,225,11,191,4,72,9,205,248,153,255,238,2,144,0,169,255,7,255,203,2,55,255,246,2,202,0,59,255,121,255,245,253,219,4,201,1,51,253,68,253,126,6,150,3,208,255,16,252,180,0,155,1,180,3,144,8,47,10,198,252,62,252,150,251,197,255,233,251,207,254,187,254,248,251,48,8,225,254,139,1,249,249,244,254,62,251,3,248,118,249,183,3,202,248,132,253,7,1,118,255,225,254,185], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1803825);
/* memory initializer */ allocate([254,96,247,104,253,240,1,131,8,109,6,84,1,167,253,217,1,158,2,182,3,214,10,108,1,101,2,152,248,172,248,151,243,151,255,250,1,92,255,25,1,206,2,115,9,203,251,206,255,109,1,161,249,122,255,128,254,231,0,255,2,227,254,244,4,65,1,128,250,217,0,103,254,43,253,201,4,9,246,194,245,238,254,217,1,192,10,245,255,86,1,17,254,91,6,79,0,240,0,2,0,3,252,128,2,4,254,243,254,136,2,140,255,253,250,39,255,13,0,118,249,98,9,145,252,255,6,193,10,82,9,171,4,68,253,230,254,84,254,97,253,164,255,163,4,96,253,13,4,135,248,246,0,208,252,187,255,20,247,56,253,28,252,194,9,134,3,41,3,107,255,66,0,7,3,212,255,202,253,187,3,207,251,98,250,130,252,46,252,18,1,122,254,152,21,129,4,17,0,18,253,63,0,33,2,43,253,211,254,189,254,149,2,211,252,165,254,227,2,79,1,136,0,203,0,86,1,34,3,57,255,206,252,89,253,230,254,147,8,78,249,11,253,102,255,182,0,132,0,55,249,149,1,90,9,113,241,69,5,213,0,63,255,65,246,182,250,139,253,109,251,149,5,240,255,66,3,20,251,160,0,156,248,106,3,218,6,201,253,88,1,85,242,76,6,37,252,88,254,27,252,152,249,82,2,34,4,241,252,255,1,164,253,56,250,38,249,88,254,214,8,57,248,17,5,130,253,94,1,180,253,201,255,203,5,56,254,201,253,146,0,78,252,219,2,5,6,9,253,80,2,207,4,242,254,171,0,73,248,109,245,56,254,29,255,136,1,133,252,240,3,214,251,25,254,231,0,92,5,205,255,169,253,29,255,184,2,204,252,98,1,136,7,208,255,234,250,198,253,60,1,229,254,176,252,3,10,246,254,5,11,28,2,41,2,8,251,96,4,116,251,61,254,128,1,222,251,6,252,199,6,224,3,60,251,173,255,210,5,0,9,122,0,94,6,84,4,205,7,42,9,121,253,45,1,46,249,38,255,57,1,206,1,206,5,232,253,4,254,49,254,104,0,162,3,93,2,68,8,25,3,65,11,44,253,157,250,203,255,106,17,25,3,19,1,76,255,252,253,23,254,250,252,247,254,192,2,112,0,175,0,112,0,135,255,140,2,54,1,52,2,72,254,5,3,93,7,159,3,96,253,251,252,190,6,154,253,50,3,53,6,140,254,49,255,243,1,130,252,219,3,28,3,140,2,52,251,86,240,96,247,202,1,133,2,242,1,233,254,172,252,151,248,228,248,221,255,162,2,201,0,218,1,77,0,94,0,23,9,211,2,199,251,5,1,209,0,155,4,105,251,111,2,243,250,106,8,139,255,133,241,172,3,45,3,221,251,177,254,26,5,13,2,65,255,238,247,87,254,19,0,146,254,17,2,111,255,54,3,111,252,254,0,168,1,158,254,89,255,123,246,103,250,91,2,194,254,19,250,154,16,29,2,176,250,194,1,237,253,200,0,22,2,176,4,34,255,233,253,94,255,69,251,140,255,112,255,50,254,117,255,30,254,255,1,20,8,204,247,203,3,49,250,230,251,178,243,67,253,119,0,16,0,255,5,16,1,96,251,194,8,232,1,20,254,109,252,124,6,212,0,198,252,68,254,235,3,145,10,7,14,82,255,179,254,81,254,197,255,121,252,61,0,239,2,63,4,211,255,249,251,105,2,174,2,241,255,80,3,164,254,179,3,140,1,163,3,249,6,216,253,104,252,99,253,193,255,179,248,53,9,243,249,39,3,121,3,211,249,209,251,51,6,172,251,20,5,110,253,143,253,44,1,227,254,47,252,120,6,87,16,207,5,65,255,146,2,212,254,241,1,98,5,212,254,7,4,66,1,114,0,63,254,154,2,226,4,8,1,125,0,147,255,236,2,9,254,216,255,199,0,68,251,149,249,38,246,151,0,121,0,152,251,128,243,108,3,66,254,110,3,35,252,230,5,213,8,29,250,1,7,110,254,30,0,228,0,206,255,217,3,224,249,243,2,23,6,80,253,62,5,89,254,29,250,96,0,11,254,218,1,146,244,67,246,125,255,112,253,194,1,11,4,44,3,242,255,91,252,173,3,116,5,67,252,147,253,252,253,123,1,31,255,241,247,0,248,157,2,31,1,152,6,191,6,43,1,110,253,84,3,233,2,252,254,225,3,158,0,44,251,114,250,33,0,99,2,144,255,189,254,62,255,71,3,129,250,31,250,38,248,243,4,157,254,93,253,61,241,0,3,28,255,125,253,149,2,33,5,239,253,194,3,76,252,44,255,19,4,24,6,82,255,208,6,86,252,33,1,150,7,76,247,116,248,32,4,178,253,84,252,154,3,89,2,171,252,233,252,131,253,254,255,204,255,173,255,47,255,142,5,88,3,139,251,196,9,85,251,5,3,63,4,147,250,153,1,183,1,166,241,197,1,101,6,241,255,245,3,75,10,250,5,176,251,184,1,127,3,46,255,94,4,250,255,45,0,65,0,170,251,21,243,181,254,222,1,101,255,102,254,47,253,46,251,129,0,53,252,163,251,229,255,148,251,247,250,96,7,168,251,203,0,189,251,186,1,97,247,245,1,169,254,212,1,204,255,129,1,13,1,226,243,146,254,43,254,135,1,249,1,176,0,100,1,187,255,95,252,131,4,232,254,16,251,127,252,238,3,18,254,155,0,36,0,141,253,156,3,208,252,154,0,18,253,187,252,143,20,181,251,91,0,31,254,71,0,87,253,194,253,205,4,163,2,193,4,49,4,73,253,18,1,131,254,116,255,92,5,244,253,140,4,85,1,107,255,168,252,25,3,242,250,213,3,63,252,115,1,154,4,183,5,117,1,95,5,224,238,239,0,136,0,67,0,84,251,130,255,23,252,28,255,150,0,181,1,218,248,221,1,242,1,150,16,25,3,107,253,4,1,238,248,125,5,76,0,134,3,180,252,140,3,38,7,27,0,132,255,1,1,253,2,158,255,80,2,231,1,124,255,202,0,163,2,99,253,89,253,29,5,94,240,50,255,190,255,122,254,3,255,66,255,103,252,173,255,131,5,95,254,0,246,122,253,61,7,108,255,36,2,142,254,45,253,191,3,118,252,14,244,236,254,211,1,0,251,202,3,175,2,228,1,250,1,119,4,27,250,60,3,135,247,115,11,42,5,189,253,9,4,209,0,45,252,217,0,78,254,98,250,58,1,80,9,118,252,227,255,58,250,225,255,62,2,139,254,198,5,132,255,88,253,74,1,26,3,15,253,47,252,127,4,90,251,57,250,126,253,122,6,103,247,67,250,53,6,75,2,52,0,18,5,44,8,53,250,166,2,196,7,150,3,120,253,72,1,48,8,190,251,105,8,120,250,39,1,25,2,5,1,142,1,147,250,113,254,81,4,10,0,117,254,145,4,81,254,89,254,175,249,254,2,148,248,123,243,131,0,22,253,172,252,167,8,195,254,24,255,55,4,37,1,41,253,50,0,66,254,55,253,127,252,0,3,128,252,101,253,231,254,121,1,115,0,159,6,250,236,201,2,119,254,251,0,244,4,221,1,15,254,38,1,18,0,153,254,44,2,52,1,16,253,161,252,40,255,151,0,93,255,183,2,75,2,42,3,59,8,149,255,153,3,179,4,40,254,0,5,116,1,110,0,187,253,31,255,54,253,198,255,229,245,68,248,70,255,140,254,126,250,32,250,4,252,23,253,168,255,69,9,200,253,231,244,7,248,207,248,17,8,133,1,82,254,139,4,48,255,57,2,119,1,138,2,61,1,90,4,244,251,65,252,128,252,36,4,246,3,169,253,49,249,97,4,40,3,20,6,70,1,196,244,236,249,253,250,128,1,178,251,122,1,153,5,190,2,174,5,37,251,43,253,224,0,158,253,57,254,133,5,45,249,44,246,196,253,81,250,199,254,231,0,12,3,251,5,85,246,222,255,153,3,142,249,13,1,50,3,5,0,67,3,47,255,113,252,80,254,176,251,165,0,154,249,210,255,17,248,67,254,28,5,239,5,56,248,70,6,188,3,245,2,115,4,116,0,61,3,160,250,209,0,131,252,195,3,199,253,46,254,71,255,191,250,244,5,178,6,13,1,219,0,95,255,226,1,102,251,219,241,193,252,100,253,79,7,239,253,41,252,46,2,206,252,81,0,43,2,33,0,39,254,69,255,113,0,131,3,191,253,187,251,128,5,134,3,254,254,145,255,120,253,244,16,244,252,117,253,21,3,164,255,6,9,111,254,157,2,43,255,113,1,152,255,204,252,222,254,48,0,107,252,71,0,46,4,17,255,24,253,123,3,23,0,246,235,7,253,56,1,63,1,74,3,24,1,78,0,107,255,96,1,174,253,151,254,98,1,118,252,42,0,182,249,67,3,157,0,137,253,76,4,215,254,57,4,160,255,228,1,199,252,172,247,37,2,25,5,128,0,198,254,59,249,247,254,5,5,35,240,164,254,120,255,84,252,5,254,24,255,25,250,148,252,78,0,72,8,175,0,168,8,155,4,241,1,79,1,94,1,238,255,229,250,125,254,97,247,75,2,137,12,142,254,131,4,221,5,105,249,228,252,119,250,35,253,243,254,33,3,83,0,149,4,206,2,114,245,19,0,197,254,149,17,1,4,147,254,92,1,95,254,2,254,84,255,79,251,198,5,159,2,141,7,223,6,164,2,160,1,30,0,144,1,19,2,95,1,104,251,9,245,177,7,138,250,135,4,200,253,242,2,107,255,168,248,238,254,77,251,213,255,111,5,127,1,190,2,68,8,19,5,160,7,134,2,49,253,199,6,38,252,100,0,68,252,16,4,239,8,186,249,100,2,224,6,221,2,107,246,19,2,242,255,255,255,114,243,55,248,115,1,227,0,45,0,219,7,237,253,65,4,251,251,26,1,134,246,243,253,221,3,43,254,29,1,251,6,159,3,177,254,103,4,207,254,119,4,100,254,166,249,223,6,249,245,174,255,146,4,21,244,242,4,242,5,132,255,113,248,40,2,98,4,205,255,91,1,94,253,152,254,159,4,223,0,199,11,187,3,198,252,84,4,21,9,100,3,128,4,55,4,223,0,217,0,84,254,126,1,130,2,223,244,1,253,186,255,151,1,147,0,120,254,105,254,201,255,4,254,249,6,85,253,139,252,83,3,39,15,215,1,94,253,25,255,213,5,85,6,94,249,16,2,111,2,44,1,87,5,180,253,48,3,232,255,88,2,74,255,183,252,86,3,114,1,203,2,116,0,202,2,228,250,155,5,10,7,189,245,210,252,107,1,194,254,183,255,82,3,48,249,205,9,209,254,53,4,148,2,97,8,82,8,38,253,168,255,141,255,251,253,102,255,160,0,175,254,27,0,222,5,253,1,186,255,246,1,52,3,203,254,100,241,242,250,158,253,241,0,106,253,244,253,39,5,200,1,158,3,190,3,145,255,20,252,3,7,164,253,62,4,206,1,129,255,131,255,8,1,187,251,147,5,78,1,70,3,187,7,192,253,236,11,250,241,71,6,100,1,216,2,83,6,112,254,23,1,58,2,78,254,9,3,88,250,136,252,156,0,235,254,7,250,98,4,187,8,230,252,89,13,194,252,174,255,104,253,211,248,178,3,142,254,154,5,206,255,230,2,192,246,158,5,240,4,148,4,198,250,148,255,30,255,66,252,174,247,254,255,149,3,128,3,27,6,133,8,124,10,39,9,237,0,105,254,131,245,167,5,4,4,40,253,109,0,148,253,222,1,46,0,226,253,235,252,145,252,74,254,220,4,51,4,62,249,119,0,74,253,137,0,5,224,90,0,74,253,88,255,60,254,252,255,253,254,180,254,96,1,214,253,43,0,133,1,236,0,252,1,81,255,205,1,235,254,118,0,139,2,11,255,184,2,113,250,112,1,119,250,246,6,114,6,228,253,27,0,51,254,4,2,169,253,71,255,166,1,245,255,75,255,19,0,17,7,102,243,185,252,65,255,212,1,180,0,218,253,198,0,183,9,101,252,201,250,16,252,5,4,180,6,76,2,115,1,134,3,66,251,179,0,2,4,24,6,23,7,78,249,206,4,56,253,139,6,75,7,102,255,212,244,28,254,241,8,6,252,33,0,42,250,102,2,220,246,44,253,192,251,118,248,249,252,148,252,130,2,178,250,112,255,42,246,62,0,31,2,231,251,199,251,160,2,25,5,30,250,170,255,104,11,6,2,212,248,222,253,124,255,211,255,126,253,125,1,108,254,98,247,69,251,186,2,65,253,101,253,162,253,91,253,58,247,14,2,123,251,177,0,254,1,116,250,151,253,229,248,174,6,95,6,25,4,95,249,17,254,193,3,30,251,39,0,226,1,189,1,68,252,185,255,209,3,170,1,34,7,30,1,36,0,39,1,250,6,26,3,128,242,109,6,2,253,212,249,125,246,84,4,226,254,219,2,109,253,192,3,33,249,46,252,60,1,162,254,91,0,221,255,34,255,119,250,203,255,239,253,89,253,169,2,164,237,244,253,217,255,162,254,196,0,199,0,191,0,141,2,64,5,82,252,84,254,156,0,173,0,124,2,254,249,3,7,173,6,66,255,241,4,164,0,138,2,254,8,35,249,226,6,157,1,173,252,44,0,165,250,87,1,251,240,134,255,72,7,23,254,89,2,20,253,110,254,78,2,132,255,60,248,0,250,25,252,143,1,15,253,39,1,128,254,220,250,55,0,99,253,6,1,123,251,74,241,224,3,145,255,144,244,112,250,158,255,194,255,178,254,200,248,121,1,24,6,179,3,32,6,18,6,206,0,152,2,222,7,50,8,92,255,128,253,175,244,121,253,117,249,253,246,2,255,213,253,134,246,217,5,209,1,11,250,132,251,55,0,120,2,42,2,20,8,195,1,4,250,53,253,239,247,103,251,145,253,222,1,168,255,140,251,184,255,62,254,8,255,169,251,6,255,76,5,157,10,207,248,164,1,237,250,77,249,234,2,155,255,88,2,106,4,121,252,39,254,201,4,148,252,193,0,182,2,63,255,30,254,210,248,94,0,157,0,107,4,11,1,14,255,229,7,217,255,27,3,227,254,182,1,30,239,73,4,147,253,250,253,174,254,223,254,142,255,97,253,164,6,35,254,193,1,128,249,75,253,123,5,211,241,200,5,33,252,22,255,43,255,98,1,243,254,140,251,216,255,175,5,10,253,249,4,241,1,82,253,79,252,59,0,190,255,255,252,142,244,39,9,148,9,216,249,227,3,34,253,241,3,98,0,162,254,164,251,33,2,189,0,99,0,54,2,108,252,20,0,117,0,217,252,218,3,84,254,177,0,223,4,229,1,88,253,115,4,17,251,0,255,220,18,89,0,27,0,197,250,189,251,149,0,127,253,65,253,198,253,144,255,90,1,163,255,127,253,159,255,33,252,57,247,236,8,79,3,62,8,143,250,197,254,68,250,2,2,43,250,210,255,111,4,49,251,39,0,111,252,234,254,6,253,239,6,84,253,223,2,116,249,130,1,18,248,230,9,189,246,131,249,180,4,145,255,248,255,161,253,209,4,4,250,17,251,250,5,231,253,64,249,177,254,13,1,154,253,12,0,93,251,254,252,215,1,117,1,135,18,12,0,197,0,98,2,155,255,161,1,162,254,39,2,32,2,126,252,131,1,86,253,64,251,126,0,96,0,94,0,244,254,23,2,126,0,246,252,59,6,157,250,38,13,49,0,204,1,236,6,198,0,128,252,75,0,253,0,160,250,68,0,70,3,159,251,190,253,138,253,50,253,49,252,203,253,23,5,98,1,255,252,218,255,10,255,63,255,104,254,41,0,165,0,118,1,169,255,101,255,248,255,22,253,82,254,155,252,206,248,127,254,25,1,255,19,176,1,95,4,217,252,220,6,48,3,131,0,220,253,240,253,67,5,222,1,202,5,126,11,222,254,138,2,244,3,163,0,72,3,220,252,94,0,203,9,234,5,71,252,223,254,23,0,104,4,129,252,15,252,79,7,142,254,187,2,147,2,3,244,73,253,233,249,155,5,160,2,94,0,216,5,131,253,96,247,59,4,176,2,229,1,251,0,196,252,33,5,235,255,100,248,230,0,165,253,15,3,195,252,12,2,138,251,251,240,153,250,67,1,15,5,220,2,247,2,79,2,68,0,179,248,12,253,191,6,83,1,227,249,2,254,63,10,102,1,255,11,25,1,234,252,105,4,243,0,180,253,81,254,236,1,116,1,96,0,122,3,89,252,41,253,20,255,96,254,171,0,226,0,190,251,233,4,217,251,209,254,207,252,30,250,77,252,234,8,109,253,106,254,79,0,4,3,208,252,206,245,246,248,5,252,208,252,162,248,230,250,85,5,112,2,246,246,199,255,244,3,215,0,126,255,76,13,160,252,191,3,202,0,230,255,9,252,68,251,222,255,104,254,166,13,228,254,77,3,19,1,19,252,202,1,72,3,46,247,243,255,127,255,232,9,245,4,192,4,23,8,13,255,112,2,72,2,144,8,208,2,92,2,139,250,254,2,216,3,230,251,157,0,10,255,182,1,240,0,181,253,227,4,119,253,234,255,33,0,186,22,96,2,28,252,218,1,245,253,58,254,228,4,233,252,119,2,47,254,151,2,196,1,1,7,85,3,39,0,148,14,246,2,207,250,11,0,169,8,120,255,228,253,55,5,65,0,1,248,175,3,189,2,94,7,37,8,134,252,240,255,72,255,69,1,203,251,241,254,34,251,135,1,106,249,117,253,179,255,63,1,36,1,96,255,180,4,69,4,8,3,202,254,232,5,84,251,149,0,46,0,81,2,202,6,202,253,97,0,173,241,27,254,85,253,135,255,40,255,107,255,168,254,150,1,35,252,201,254,127,1,211,3,196,252,138,1,234,255,233,235,168,250,238,255,79,254,103,1,95,2,228,3,136,251,27,255,85,5,37,251,157,1,177,253,147,253,35,3,76,5,143,253,125,4,22,255,182,0,251,250,73,246,103,1,80,10,110,250,190,255,80,253,237,0,27,5,151,254,108,0,207,0,2,4,12,254,124,251,237,251,112,247,72,247,254,6,111,4,206,6,214,5,124,251,70,253,216,9,220,245,148,253,175,1,236,2,88,0,144,3,64,3,98,4,29,254,45,7,29,7,198,252,88,4,88,254,206,254,18,253,61,4,4,1,152,0,142,255,215,251,90,238,212,254,48,252,143,0,172,5,115,5,141,6,59,0,205,255,208,251,100,3,85,255,230,255,110,252,147,255,140,246,208,255,69,0,26,255,118,2,246,253,226,8,241,4,180,249,10,10,68,3,6,248,126,248,154,11,7,3,192,254,74,246,137,244,41,2,178,0,226,3,226,251,215,250,187,2,237,2,234,3,1,2,74,2,14,6,35,0,142,2,29,252,207,6,231,251,107,254,153,242,151,7,188,2,43,2,111,0,189,255,239,3,111,0,199,255,149,2,148,1,140,253,169,1,137,8,92,3,252,253,245,253,196,1,238,0,14,249,134,254,47,253,107,247,218,0,96,3,249,251,192,252,135,0,17,246,65,254,21,3,93,4,45,250,120,0,14,5,66,253,115,2,100,254,122,252,148,1,205,248,238,252,171,253,132,3,171,7,22,0,181,252,144,4,235,251,227,252,252,2,89,254,73,1,4,9,98,248,75,1,190,251,94,246,29,254,231,7,221,242,78,8,239,1,252,10,130,7,48,250,239,251,226,252,135,0,152,1,33,0,51,2,53,5,220,255,123,247,237,252,197,2,31,1,53,252,93,0,53,254,49,252,108,9,24,1,251,9,32,0,169,8,223,248,138,2,57,1,73,2,77,252,146,4,45,0,84,4,77,254,68,4,220,0,101,255,0,2,204,1,211,0,25,255,141,253,188,252,99,247,75,255,143,255,130,0,226,0,191,254,3,253,209,250,90,251,92,253,155,254,179,2,232,0,147,254,230,248,65,244,162,8,229,3,89,2,108,8,242,252,90,6,199,251,207,255,152,253,173,2,244,255,40,0,152,13,51,2,3,2,245,0,51,0,34,1,203,4,171,0,202,251,8,2,29,254,24,1,19,250,205,250,84,8,104,251,155,250,246,249,156,5,172,252,7,254,160,2,217,252,111,2,12,255,131,255,90,248,4,2,30,3,161,4,154,3,185,1,139,2,158,253,106,250,161,248,114,0,155,252,24,248,165,249,28,247,216,7,56,251,125,0,159,253,115,1,176,251,6,254,82,252,144,253,34,254,197,0,141,0,14,255,229,251,252,5,11,251,154,2,225,251,153,6,188,1,184,6,16,0,45,1,249,246,172,4,84,4,18,5,204,253,83,251,190,248,183,1,58,255,68,1,164,248,121,12,233,8,201,0,75,2,20,248,177,7,193,251,160,254,169,255,136,253,144,0,165,0,68,0,126,4,173,0,222,1,187,252,42,254,48,254,61,255,51,255,63,8,15,0,131,2,59,254,173,254,152,251,168,250,158,4,54,3,142,2,229,246,124,249,41,255,90,253,100,246,145,4,104,253,9,3,164,254,10,10,1,253,205,253,254,0,50,2,211,253,4,0,159,255,198,7,117,1,244,252,91,253,204,7,9,250,147,254,96,254,187,254,75,2,142,3,60,241,215,253,104,0,169,6,240,0,49,253,75,249,205,10,186,253,180,255,143,1,128,251,75,9,97,12,127,251,43,253,221,255,66,251,106,1,64,6,44,253,168,1,46,253,216,1,104,3,182,2,130,255,143,249,222,250,234,248,161,255,200,254,222,255,12,3,140,252,56,3,160,252,14,2,156,255,236,14,200,255,60,254,43,0,52,2,231,1,177,0,122,3,113,250,126,3,216,253,158,5,204,0,247,3,252,255,71,1,1,243,79,254,177,254,155,252,32,5,24,254,249,250,87,255,226,7,179,1,73,0,252,1,136,4,220,251,122,255,232,250,171,254,111,2,125,0,241,255,160,251,108,0,185,255,49,250,67,255,200,241,144,5,204,6,92,4,67,2,67,6,34,243,217,4,31,255,201,5,215,10,46,5,14,255,136,253,232,249,51,2,47,2,138,0,115,0,211,253,212,7,21,249,205,2,228,251,165,251,158,249,121,3,71,254,162,7,92,255,29,250,224,250,105,254,150,2,157,252,128,252,225,0,16,10,32,255,149,255,237,0,74,253,91,3,192,0,247,251,207,8,55,251,133,252,54,248,166,255,83,1,130,254,250,252,180,5,239,249,136,2,247,253,66,9,160,0,202,2,54,0,118,252,155,5,40,249,238,254,245,253,220,255,184,4,17,6,173,254,232,3,78,255,209,0,23,252,148,3,239,1,54,1,214,2,127,0,121,254,107,0,255,253,228,251,136,254,41,1,205,254,165,3,23,255,3,255,172,4,11,18,2,251,250,2,243,255,125,254,51,252,105,8,68,0,106,1,137,252,126,248,150,255,42,1,153,251,215,245,120,247,145,255,111,0,204,249,234,3,147,254,78,247,222,254,169,253,98,2,39,2,168,250,8,239,106,2,84,255,93,1,110,252,238,253,64,255,206,2,92,1,93,253,140,252,145,3,162,255,215,0,190,252,97,1,241,2,213,252,172,255,119,252,128,255,29,254,10,249,25,251,227,246,170,251,221,1,202,253,90,1,226,7,148,249,187,254,85,5,57,251,158,0,6,249,54,2,203,0,230,2,25,1,213,253,61,2,46,252,53,254,121,249,122,1,79,253,93,1,94,2,183,232,50,2,243,255,33,255,93,254,70,254,65,254,125,0,228,251,53,0,34,10,159,250,209,0,243,249,21,2,138,255,22,246,16,7,148,254,219,255,197,4,95,2,81,2,53,1,16,255,38,6,254,0,178,1,115,255,36,255,30,248,104,1,34,12,250,253,185,0,118,252,173,12,252,1,165,255,170,3,10,251,20,254,36,0,168,0,27,252,48,255,223,3,99,0,17,6,218,254,204,0,234,255,148,255,155,246,77,11,49,0,72,0,22,254,239,253,38,255,63,5,238,252,135,3,155,1,207,0,131,0,132,253,127,255,122,255,109,2,3,255,63,1,135,0,22,255,181,255,219,254,46,0,207,0,97,23,24,1,170,255,178,255,178,2,216,3,254,252,203,253,30,255,14,255,118,1,26,0,72,253,81,0,235,254,247,255,127,2,38,253,250,0,24,255,24,254,228,254,204,1,114,254,240,16,209,254,246,254,34,2,220,254,120,11,70,0,29,8,117,1,115,255,36,1,54,8,84,1,200,254,245,253,171,254,249,3,201,1,224,0,59,1,15,1,56,4,152,0,192,0,56,2,246,3,155,0,85,0,73,1,141,235,137,0,9,254,141,0,19,1,249,255,240,2,26,1,245,254,65,1,33,253,234,2,233,1,194,1,222,1,176,1,104,255,195,1,88,251,243,4,171,254,112,4,100,0,46,242,241,249,11,6,217,253,38,1,39,254,203,252,205,255,206,2,113,253,245,255,1,11,230,255,73,0,53,254,223,249,181,0,4,2,105,255,30,11,144,255,186,0,202,2,28,255,46,255,61,254,152,3,157,255,124,255,154,245,77,2,224,11,120,1,150,2,190,252,14,3,30,2,205,5,26,2,203,13,107,0,47,0,62,0,142,1,245,255,241,255,35,253,215,1,25,255,156,2,44,255,38,0,232,253,143,248,209,10,107,255,87,6,166,242,237,0,55,0,184,254,254,252,79,1,195,10,84,1,62,0,46,254,11,1,78,252,171,1,10,1,80,0,110,4,34,0,181,3,110,1,173,254,144,255,3,0,151,255,186,1,253,19,33,2,163,255,99,2,70,255,54,2,217,255,84,255,197,255,160,251,132,1,191,2,107,2,153,254,139,255,188,255,57,2,148,0,42,255,11,255,25,1,105,2,223,246,168,255,1,255,124,0,220,12,187,1,178,1,239,255,123,251,18,12,51,255,11,255,41,252,250,0,194,251,131,2,112,5,63,3,221,2,197,255,81,251,211,6,97,254,49,4,23,1,172,1,0,254,192,242,0,0,250,255,14,2,19,1,177,255,221,1,155,1,85,0,205,5,27,3,47,255,239,1,188,245,111,1,58,249,132,3,45,1,239,0,203,255,236,247,147,1,53,5,232,250,202,253,116,250,253,252,4,247,241,255,74,3,86,1,187,246,61,0,157,250,47,1,221,2,148,255,196,254,94,0,35,254,2,255,45,255,39,3,17,1,232,252,159,0,190,255,167,252,68,4,23,252,187,255,70,241,231,3,114,9,86,3,173,0,233,8,87,253,229,1,66,2,145,0,35,251,77,3,137,254,219,0,253,254,118,1,239,2,226,0,189,250,199,252,66,0,63,1,83,255,191,0,189,1,28,1,62,0,42,224,185,255,53,0,125,2,160,255,227,0,75,0,73,0,168,255,142,2,232,255,46,254,221,1,159,2,131,255,82,252,104,0,248,0,105,255,129,254,11,0,66,1,76,1,64,16,108,0,211,254,207,1,110,254,96,1,249,248,68,2,163,5,140,1,31,1,98,255,91,254,84,1,163,254,109,0,61,0,47,0,0,245,214,254,77,252,207,252,161,2,189,0,36,0,229,15,184,253,177,254,48,10,10,0,134,254,138,253,223,252,228,0,178,3,107,254,94,251,217,1,113,2,254,255,27,253,11,2,163,14,62,1,221,2,171,0,12,1,6,246,146,1,4,255,51,255,36,1,161,254,64,0,33,1,33,3,221,3,179,1,156,255,93,255,65,251,45,254,149,2,54,253,165,0,28,255,131,253,77,5,14,254,204,255,232,1,214,240,130,0,227,251,28,3,16,4,125,1,39,253,147,0,35,3,169,0,46,0,99,255,167,0,47,255,126,0,8,252,88,0,6,252,54,254,241,253,235,4,109,2,7,15,243,253,223,4,18,0,253,0,130,2,84,1,63,253,70,3,47,245,96,253,153,0,115,0,197,1,5,3,9,0,19,247,221,254,6,0,37,255,116,2,28,1,182,254,56,2,16,255,50,255,129,255,17,1,117,1,111,1,18,254,0,32,173,253,1,255,98,255,186,254,196,255,1,2,78,1,101,253,219,253,146,255,2,0,61,2,62,4,158,253,144,254,3,1,229,241,57,254,41,6,244,253,11,0,136,3,134,1,57,1,195,2,110,10,33,255,150,10,81,2,231,255,228,0,28,2,151,2,228,2,172,251,42,1,199,4,237,253,70,248,248,0,107,253,171,254,114,252,126,246,111,0,217,0,236,2,231,0,207,254,93,254,81,7,70,4,88,252,51,249,109,4,89,7,97,253,41,0,12,1,222,248,210,1,135,0,37,0,56,255,15,18,68,251,55,252,29,2,254,4,140,2,37,4,9,253,21,253,85,254,149,255,207,250,185,253,1,255,189,255,201,254,246,255,91,254,0,224,66,1,75,255,70,254,76,0,176,0,26,253,81,255,147,0,129,1,237,254,169,255,64,253,223,253,197,254,98,254,57,2,81,0,125,254,116,2,138,11,164,253,77,250,227,255,157,6,72,3,0,252,190,255,195,254,10,1,95,246,107,252,242,255,151,0,143,254,110,1,172,246,1,0,251,252,53,5,157,255,223,0,74,253,111,251,149,3,64,246,246,250,226,254,17,252,4,254,222,2,195,1,0,255,10,1,151,255,113,255,183,1,136,255,110,255,10,30,73,255,188,0,68,0,127,254,7,0,234,254,232,255,190,255,36,1,137,0,143,0,21,0,17,254,241,253,228,254,89,0,208,249,192,255,176,241,30,1,46,247,80,0,92,252,253,252,174,254,194,252,251,251,157,255,224,255,224,252,95,1,169,255,88,2,163,255,133,0,133,1,78,253,13,1,201,0,184,254,113,21,46,2,66,253,25,254,210,0,35,12,212,241,160,255,124,254,87,255,35,255,83,1,147,1,208,252,232,255,213,1,144,255,48,2,76,3,71,254,186,2,169,0,134,254,229,254,100,252,26,11,33,254,74,253,139,255,162,255,11,2,206,3,76,5,130,253,78,2,52,3,116,8,247,0,236,253,136,2,13,255,169,253,189,255,54,22,174,0,78,0,160,253,230,0,84,255,113,1,86,1,143,255,111,0,167,254,201,254,82,2,94,1,252,254,113,250,87,254,105,254,7,252,214,254,76,255,30,253,133,252,66,0,16,243,123,251,1,0,43,3,105,250,100,2,29,3,192,250,134,252,65,252,62,1,136,1,66,255,223,2,196,0,165,254,61,0,140,255,88,1,243,0,101,254,66,254,62,0,128,255,198,242,220,1,135,10,63,255,217,255,168,7,249,255,141,3,138,255,29,247,228,255,27,252,46,255,118,1,182,253,174,255,146,3,67,1,183,255,73,245,90,3,191,255,43,0,116,246,10,255,145,0,78,0,130,253,76,3,225,247,96,1,180,254,103,2,245,252,14,1,7,7,168,2,244,1,174,2,144,4,115,254,71,247,225,255,93,255,238,255,90,2,24,255,109,252,83,252,124,14,175,254,209,253,59,1,111,254,42,0,26,0,60,1,156,255,65,255,36,0,206,0,214,0,248,242,105,254,238,1,237,2,21,254,94,255,201,255,170,244,21,250,58,255,201,254,153,254,183,1,103,1,89,252,203,0,42,255,159,246,161,253,229,244,50,3,189,253,238,247,132,1,254,253,112,252,19,3,52,2,149,0,153,255,11,253,133,1,173,0,209,254,154,0,46,3,95,6,119,254,40,247,128,6,222,252,136,3,29,2,16,3,39,4,128,4,50,246,41,1,84,0,102,255,160,0,15,254,178,255,223,5,170,253,225,253,86,0,147,6,182,254,46,0,232,255,132,252,235,2,248,242,119,254,36,247,107,0,198,2,146,6,235,254,234,254,236,254,229,4,71,1,38,252,34,3,191,0,36,253,30,1,7,253,240,3,205,1,79,6,239,251,79,8,152,9,87,15,96,255,187,0,31,0,155,255,186,12,202,0,181,255,74,1,119,1,211,254,237,254,242,252,181,3,12,0,147,253,151,253,60,2,239,3,158,1,165,255,84,254,120,254,39,252,76,253,162,242,199,0,77,3,91,0,162,1,34,1,41,252,209,2,15,251,208,0,176,4,91,0,10,253,167,245,61,254,210,252,145,253,54,254,16,1,217,10,41,3,2,5,251,2,98,4,21,0,8,2,50,0,6,252,172,1,129,1,5,24,1,255,8,0,244,255,21,0,20,0,37,1,197,254,66,254,89,254,37,2,172,1,200,255,15,254,101,0,141,2,79,255,121,240,56,0,129,255,142,12,35,1,128,254,47,253,222,1,198,254,25,255,43,254,150,254,86,253,253,2,204,254,164,1,200,1,66,1,202,255,254,255,10,0,17,255,4,27,51,254,30,254,45,255,226,254,146,255,147,252,57,253,42,254,159,0,4,1,59,0,252,0,159,255,94,244,122,253,221,255,156,0,133,255,104,1,44,2,74,243,37,254,199,254,244,254,21,249,230,253,203,0,199,3,27,1,115,253,203,253,131,1,231,243,1,255,25,0,39,1,8,1,124,241,249,1,0,4,197,254,41,255,34,255,244,252,148,2,175,1,171,254,247,253,46,0,127,0,12,255,252,252,99,241,190,0,177,254,239,255,87,8,232,2,221,255,115,2,165,251,169,2,169,254,123,0,2,250,170,255,226,253,215,254,174,255,44,245,74,15,181,255,14,2,124,0,245,253,144,255,244,1,95,3,115,1,190,0,12,4,141,0,13,252,117,1,28,3,165,1,86,253,147,1,108,11,146,14,6,0,211,0,77,253,89,255,121,254,113,253,162,0,92,1,216,0,29,255,233,253,109,255,111,1,67,255,75,1,65,255,159,0,49,0,215,236,4,255,222,254,97,2,60,254,18,4,3,4,123,253,97,255,135,253,226,253,99,252,250,254,165,255,192,0,242,4,254,255,92,255,75,2,188,0,106,13,10,252,2,0,93,5,40,7,56,251,59,252,63,3,37,252,156,4,109,5,99,252,48,0,89,243,7,1,183,254,108,253,35,253,6,1,36,252,86,2,139,246,118,2,208,2,99,252,57,254,208,0,68,4,218,254,148,3,243,254,212,255,87,1,111,2,48,246,85,255,144,248,233,3,216,10,226,0,207,5,193,2,251,2,152,253,32,1,44,255,233,253,8,12,160,254,145,254,0,2,95,253,108,2,150,252,1,3,68,252,204,1,167,253,23,245,154,255,3,253,81,254,167,250,149,0,225,1,207,255,109,0,100,254,158,2,153,253,31,1,150,0,65,1,35,243,19,255,165,249,188,0,75,7,201,5,97,1,122,255,146,10,147,0,74,0,179,255,108,255,32,255,196,0,196,255,179,0,125,0,243,255,243,3,67,255,84,255,146,2,89,17,228,253,19,2,239,0,183,254,222,10,136,1,97,0,108,253,160,13,178,255,28,5,194,253,121,252,86,255,233,254,173,0,186,255,89,2,127,254,123,0,89,254,0,254,63,255,23,255,106,0,175,0,210,0,185,0,233,1,20,255,153,0,98,253,25,0,61,0,60,255,213,0,67,0,83,1,67,21,116,0,121,253,149,0,126,255,197,0,245,255,49,1,109,10,188,4,42,1,84,0,219,0,230,255,101,10,138,2,68,5,191,255,62,2,54,250,244,254,226,255,114,2,72,1,23,1,11,255,87,0,94,0,54,255,2,0,110,1,7,254,176,253,2,0,34,22,128,1,22,0,227,0,208,0,59,251,78,0,155,0,4,1,169,251,165,0,140,1,90,253,29,253,199,9,165,246,233,7,144,5,169,254,9,253,187,252,101,0,55,0,18,1,31,254,22,0,200,253,20,4,241,254,132,255,159,253,191,252,50,255,53,0,177,253,126,4,98,248,197,244,157,7,59,0,178,254,98,243,176,0,109,4,140,254,121,11,221,252,105,253,119,2,109,253,224,255,174,255,83,3,113,0,196,255,143,253,44,2,177,0,112,0,15,253,223,255,57,1,223,255,48,255,79,255,136,234,55,0,235,253,209,252,123,0,13,253,41,255,126,2,223,0,100,255,107,252,90,255,223,255,248,1,192,2,71,244,124,0,103,255,239,248,47,252,51,253,182,6,220,1,212,0,125,6,185,3,114,250,10,252,162,255,244,253,254,245,245,254,115,1,104,0,193,255,222,253,6,1,193,0,78,249,5,1,75,7,226,2,170,248,144,1,218,6,67,254,107,254,183,252,73,254,197,2,44,0,163,2,248,0,128,2,118,255,193,4,137,1,134,250,141,2,38,12,86,252,69,246,80,253,190,4,119,253,180,250,202,9,203,0,172,0,167,2,235,3,4,3,62,244,82,0,26,252,243,3,44,252,228,255,118,255,82,254,102,2,171,1,171,254,201,0,110,224,138,255,224,0,113,251,195,0,104,252,160,254,111,253,5,0,46,0,217,255,184,255,186,2,120,255,216,255,135,1,31,1,157,0,83,251,196,255,248,10,133,255,233,1,152,0,14,9,219,252,190,3,98,0,40,250,189,252,178,252,77,2,199,1,156,252,245,0,246,255,73,236,12,0,206,255,253,4,161,255,200,1,207,255,58,2,96,2,110,253,160,254,235,254,244,254,214,0,132,1,73,7,2,0,217,11,243,254,3,1,181,255,147,242,32,3,66,255,156,2,249,254,145,255,229,0,213,255,117,255,147,2,222,254,14,3,238,255,170,252,15,1,81,247,30,0,94,255,71,0,47,0,244,2,11,251,80,1,95,3,50,248,240,255,148,4,236,0,161,3,35,254,114,246,164,255,87,254,63,255,0,224,65,1,154,255,85,0,171,255,108,0,62,1,149,0,229,255,74,255,69,0,19,255,35,0,195,1,249,254,134,252,164,254,217,254,64,0,154,1,27,25,57,2,92,2,31,2,38,0,31,0,241,255,148,0,249,0,173,255,189,255,201,1,180,255,208,253,182,2,227,252,190,0,143,255,214,7,136,0,169,6,84,254,221,13,218,253,70,0,253,255,109,255,224,254,118,4,105,252,237,1,231,250,52,254,105,255,63,3,111,2,0,253,45,255,31,0,216,254,167,0,95,245,240,255,114,253,243,0,251,9,201,254,53,7,237,253,192,253,143,0,194,253,234,1,191,251,2,247,56,4,189,2,216,1,222,10,64,1,81,250,136,253,38,255,25,1,44,250,107,253,157,250,230,253,20,255,120,248,10,254,203,253,32,254,13,2,175,255,38,0,7,1,3,0,110,1,163,0,188,243,114,3,189,0,99,4,126,1,44,249,70,251,115,1,166,253,184,2,99,254,49,255,102,1,152,253,117,18,39,254,240,252,249,0,109,2,252,2,247,254,20,252,198,253,83,1,125,253,133,255,46,1,28,1,1,0,97,255,191,254,250,0,215,254,213,255,72,242,216,251,19,254,44,2,96,251,249,254,34,5,236,7,50,4,9,0,125,11,26,252,241,254,198,3,14,253,227,245,88,0,229,2,205,254,134,0,152,0,170,255,55,1,136,3,107,252,175,4,30,236,118,0,181,0,201,254,100,254,219,1,121,253,51,253,131,253,35,255,221,254,43,254,77,0,178,3,84,251,137,255,81,255,18,2,47,254,127,1,27,251,77,2,58,3,67,3,6,242,193,254,176,255,232,1,18,255,15,254,104,1,71,3,78,7,250,2,123,249,255,252,173,1,10,3,207,243,187,254,201,255,128,255,46,10,150,252,19,4,122,252,210,6,43,253,115,0,167,0,142,0,92,2,155,255,43,253,245,255,54,254,229,255,194,1,37,1,2,0,129,254,23,0,172,0,187,229,144,1,51,255,165,0,45,0,218,255,86,0,116,1,98,1,188,255,134,1,140,9,9,2,4,0,254,241,101,1,129,0,153,2,184,254,12,2,113,0,66,254,254,253,108,4,33,1,208,253,239,0,167,0,163,254,44,253,101,0,163,243,189,243,93,255,109,255,97,3,151,253,0,0,235,252,29,3,254,251,176,1,103,1,52,254,151,255,95,4,230,1,23,255,152,254,81,255,163,254,69,3,213,1,6,255,247,253,138,238,148,255,241,3,193,253,27,1,22,0,213,253,86,253,22,255,7,255,223,255,150,255,9,2,3,2,229,254,178,255,101,0,121,255,120,253,250,1,181,0,136,1,251,253,29,21,186,1,150,255,24,224,51,0,202,254,211,252,49,0,198,254,74,2,33,254,120,1,113,0,81,1,105,255,245,0,14,1,255,255,107,2,200,254,219,255,41,255,30,254,17,244,67,243,166,254,19,254,155,254,50,1,96,255,235,255,2,1,104,3,191,253,115,255,18,0,172,255,181,2,151,0,218,0,235,253,219,255,28,2,61,0,40,0,78,12,157,0,11,246,188,254,11,1,56,254,44,251,30,3,5,2,32,255,60,255,75,2,17,254,18,0,2,1,75,12,241,255,200,253,189,3,68,254,125,2,158,254,60,3,158,4,255,252,119,255,174,247,152,1,125,249,252,0,26,1,201,0,239,0,154,0,125,0,54,225,180,254,198,0,209,255,9,1,223,254,102,1,252,255,103,0,229,252,207,0,82,0,229,0,173,1,105,1,7,1,103,254,61,254,244,251,165,242,131,3,200,253,56,250,130,3,28,1,203,255,179,0,207,3,253,250,247,2,106,255,172,12,152,1,19,10,94,254,139,255,226,0,71,2,210,0,194,255,23,250,108,255,204,252,49,4,10,5,249,254,58,254,141,2,43,2,30,1,218,0,151,255,121,255,231,0,132,252,228,254,209,9,155,10,6,250,91,255,117,250,33,255,190,255,13,2,20,6,238,255,104,253,237,255,88,3,179,0,23,2,173,254,11,255,242,1,193,0,235,0,72,1,21,254,231,0,3,234,65,0,171,255,57,1,117,254,6,0,88,1,11,1,160,2,33,252,178,0,201,250,192,255,9,0,28,250,187,255,57,0,202,254,255,248,174,252,171,241,171,1,177,255,48,253,219,0,110,1,131,0,11,2,141,0,225,251,190,255,13,0,181,252,201,255,230,252,149,2,112,0,105,254,16,254,38,2,163,3,158,240,244,6,3,254,225,253,99,255,242,254,9,252,52,2,25,255,170,252,212,242,185,254,101,3,60,255,43,252,51,255,41,255,93,2,234,2,116,247,202,8,74,0,93,244,14,255,64,3,66,255,109,1,209,250,197,1,95,0,76,0,158,0,85,253,116,2,41,1,157,252,226,253,113,255,200,253,98,254,130,23,216,255,221,255,56,254,136,253,245,252,30,255,70,254,217,254,54,1,2,253,66,2,59,255,84,0,63,252,238,242,150,255,194,12,253,255,35,254,248,255,140,2,122,0,162,253,49,0,34,0,174,2,129,1,254,254,214,0,196,253,184,255,63,255,124,0,184,1,48,0,45,0,75,0,9,0,212,225,200,0,148,254,66,2,62,1,51,254,84,0,23,255,46,0,108,254,185,0,214,1,197,242,187,242,118,1,249,253,192,254,134,254,27,0,153,3,232,254,188,0,11,255,187,255,190,254,248,1,184,255,204,1,176,255,221,255,36,255,230,243,162,241,221,1,248,0,223,252,68,2,187,0,212,1,132,253,148,254,80,254,183,0,174,255,177,255,10,1,237,252,28,253,40,2,228,0,238,0,226,1,75,247,19,1,149,0,152,254,162,254,214,10,103,3,138,255,55,0,63,252,91,255,125,9,214,3,57,1,10,254,22,12,81,254,157,13,217,1,165,254,171,0,32,2,253,0,188,254,206,255,208,1,116,0,138,2,78,4,239,1,164,1,108,254,255,255,81,244,215,15,207,0,118,1,69,255,135,255,130,0,61,254,71,252,54,3,14,2,31,1,120,0,45,252,120,1,82,2,177,255,126,255,150,254,45,252,166,0,181,2,244,239,84,0,121,255,61,255,65,253,30,250,182,251,157,253,102,3,167,3,100,255,206,3,30,1,170,255,83,0,159,11,87,253,146,12,226,254,60,254,186,255,143,255,117,254,137,0,241,250,9,254,85,3,41,1,160,254,20,252,139,255,220,1,81,254,224,244,249,255,17,14,146,1,234,253,56,1,86,0,244,5,154,254,92,255,213,255,145,3,235,3,239,0,148,254,168,255,44,254,96,253,220,0,45,255,186,254,81,254,182,1,215,254,124,1,125,0,110,255,198,17,241,254,193,252,0,3,176,250,211,255,10,1,234,254,10,255,113,2,124,255,153,0,2,2,115,0,225,250,195,2,151,254,167,253,104,243,120,1,197,247,253,254,125,251,170,1,122,253,25,253,212,254,165,254,71,254,85,0,162,20,6,255,32,0,28,0,206,254,78,254,78,0,78,255,144,255,228,255,94,255,68,255,213,255,17,0,94,0,14,255,254,254,125,245,41,254,212,253,209,252,120,0,199,255,220,255,187,254,210,12,3,253,99,1,2,0,94,255,58,254,184,255,192,0,86,0,219,0,133,255,237,0,135,0,214,255,236,1,41,254,142,255,26,20,92,255,28,0,77,0,70,0,20,1,108,255,77,1,64,0,167,255,210,255,121,255,218,1,38,255,137,255,95,1,195,29,93,0,176,255,172,255,205,255,146,255,33,255,243,255,140,255,96,255,154,255,192,255,116,255,136,254,156,0,113,255,91,254,105,0,102,0,7,2,232,4,18,3,228,254,43,244,51,244,147,254,253,253,178,250,239,254,138,1,233,1,14,255,31,0,239,0,208,250,169,0,24,254,3,244,114,254,47,1,238,254,242,1,58,245,20,253,48,255,188,254,227,254,78,0,126,254,217,251,42,1,5,0,181,2,160,0,139,253,120,6,186,0,201,1,230,2,166,1,117,241,205,7,1,4,232,255,35,1,180,253,16,0,185,254,203,1,247,253,165,1,255,4,104,254,254,255,216,250,101,0,140,254,190,255,100,0,163,253,142,12,138,254,108,253,141,254,207,0,175,0,215,253,194,253,146,11,119,0,217,253,116,255,194,255,50,0,160,253,19,255,156,255,108,0,101,0,186,12,225,255,211,255,119,1,95,255,132,0,26,11,178,5,235,0,32,3,143,255,207,2,221,254,227,255,0,254,245,254,53,0,12,3,197], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1814065);
/* memory initializer */ allocate([255,59,13,81,255,88,0,178,255,37,254,232,253,72,2,47,244,237,255,151,255,91,0,107,3,201,255,253,252,143,0,128,1,42,3,140,254,3,255,160,0,128,255,232,0,98,0,75,30,181,0,237,255,79,255,46,0,217,255,226,255,44,255,223,254,75,0,127,0,142,255,80,0,79,0,69,1,128,255,76,254,243,9,183,255,227,255,22,4,88,1,12,13,177,254,202,1,125,2,81,255,73,253,146,254,38,1,190,254,52,2,30,2,209,0,12,2,194,255,188,1,11,11,203,255,66,0,65,252,84,0,228,1,109,255,158,0,3,1,33,254,144,12,232,0,188,255,71,2,214,252,107,0,93,0,117,2,88,255,143,0,216,253,96,0,185,255,193,240,74,254,79,1,123,255,70,255,234,254,73,0,193,253,3,255,35,253,165,255,248,255,131,251,94,1,140,0,12,0,95,15,20,255,103,0,213,1,98,2,232,253,207,254,40,12,13,0,74,255,82,253,125,2,13,2,71,1,102,0,207,255,62,254,240,255,32,254,233,0,174,255,124,255,117,240,170,1,245,2,54,0,152,0,67,253,1,2,26,9,148,0,242,0,173,6,162,0,88,255,146,0,0,0,123,3,124,253,109,0,219,253,104,0,206,255,19,1,63,255,201,255,112,255,139,255,31,0,22,255,68,0,7,235,72,0,54,0,54,0,119,0,116,255,192,0,30,1,214,255,234,254,60,242,231,241,180,2,146,254,241,255,87,1,139,252,245,254,38,1,125,254,41,255,173,255,43,254,22,3,85,0,172,1,155,253,114,0,122,2,23,1,198,253,104,2,211,252,139,255,1,12,49,12,51,253,56,255,29,1,219,251,212,255,177,3,130,1,90,255,238,1,8,3,36,0,231,255,68,254,252,254,151,1,45,15,25,4,68,5,185,0,198,1,120,255,29,247,40,4,241,254,196,254,133,2,230,251,227,1,174,1,32,0,57,2,92,253,177,254,184,254,90,244,142,254,50,0,189,0,155,0,34,4,137,255,105,254,202,254,205,1,221,12,164,253,195,0,48,0,68,0,196,0,194,0,35,2,46,255,17,3,129,254,102,254,244,254,107,255,192,0,168,255,243,255,20,0,176,255,230,235,170,255,145,255,40,0,220,255,118,255,12,0,239,0,220,255,172,255,0,254,149,0,19,255,96,253,149,13,138,242,174,4,220,0,146,0,21,253,242,0,48,0,110,255,60,255,177,254,247,252,107,254,108,2,172,254,145,254,123,254,148,255,229,255,72,255,24,248,6,2,241,0,152,255,161,1,180,250,87,248,134,0,149,12,89,254,30,1,196,255,146,255,200,253,14,0,76,0,112,255,159,0,192,2,102,254,30,2,213,255,223,0,105,0,102,255,115,255,172,255,124,255,241,254,21,255,227,254,8,255,224,1,174,1,153,237,25,254,170,255,226,1,80,0,46,0,17,255,163,255,141,255,202,255,255,255,7,0,97,0,244,255,151,0,76,255,159,0,193,255,65,0,41,255,54,0,80,22,70,11,141,255,20,255,113,0,231,255,211,254,62,254,236,254,178,255,197,0,201,255,234,254,1,254,163,0,114,13,114,252,182,255,31,255,153,255,63,0,52,255,213,255,130,255,178,254,223,0,192,0,125,255,202,0,173,255,136,19,190,255,185,1,33,0,0,0,140,255,237,0,18,255,219,255,189,1,208,255,7,0,193,248,126,251,5,255,139,255,71,255,125,0,85,7,119,1,132,1,120,252,202,0,137,2,120,1,97,243,129,3,101,0,131,253,120,1,16,0,1,0,77,3,218,253,158,253,132,254,173,250,69,252,71,0,23,5,40,1,248,254,184,253,247,0,175,12,98,0,11,4,98,253,160,1,40,248,64,254,200,255,87,255,5,249,242,12,152,1,237,9,191,252,254,255,87,255,72,255,193,0,193,253,175,255,154,1,219,254,34,254,21,0,194,0,223,0,145,255,40,18,60,0,98,1,175,253,131,246,97,253,150,0,162,254,151,0,64,254,251,255,130,1,71,254,131,0,173,254,87,0,47,3,23,1,51,0,131,0,56,0,134,243,86,255,197,240,215,254,14,1,21,0,41,255,7,0,205,0,207,254,141,0,65,2,83,0,223,254,10,254,190,255,160,255,177,1,150,255,83,253,62,255,174,255,33,0,98,0,59,1,2,1,107,246,115,244,96,2,160,2,152,0,87,253,12,7,182,255,53,254,89,254,114,0,97,251,156,255,226,252,101,1,177,255,166,242,92,253,68,2,155,249,6,254,50,1,181,1,233,3,219,2,139,252,4,251,185,253,153,254,138,2,15,0,67,255,190,0,86,0,39,0,205,224,123,255,68,1,174,0,22,0,86,0,112,255,131,255,213,255,175,255,207,255,68,0,39,0,52,255,97,255,221,254,39,255,188,255,8,1,193,0,150,1,247,0,27,0,240,254,88,255,24,2,148,233,115,255,38,0,18,0,249,255,2,1,145,255,125,0,220,1,148,254,5,0,72,0,148,245,59,255,163,253,97,253,174,255,201,0,16,253,227,0,240,0,89,1,245,255,118,255,39,2,161,254,28,255,42,245,124,255,91,4,242,251,238,255,23,3,192,243,81,0,219,0,101,1,243,2,67,2,26,0,199,243,114,254,49,253,193,0,239,1,34,1,157,251,86,3,131,254,233,253,33,0,232,0,36,9,31,238,162,255,255,3,139,255,39,0,202,255,15,0,95,255,164,252,64,0,47,255,171,253,159,1,121,255,105,254,44,4,126,3,240,252,108,0,11,1,82,29,140,0,67,0,198,0,74,0,52,0,124,254,72,255,232,255,202,255,232,255,172,0,172,0,206,255,72,255,143,255,164,0,128,0,217,255,252,0,90,0,100,1,199,254,166,255,199,254,157,254,183,255,19,0,139,0,141,0,134,255,25,255,60,238,99,255,29,255,47,0,231,0,91,254,60,0,176,255,221,241,156,16,158,254,69,0,148,0,80,1,190,1,73,255,86,0,248,0,35,0,73,0,120,0,157,0,156,0,221,254,245,253,35,0,248,254,106,13,189,0,239,1,197,255,21,2,169,254,214,253,58,244,97,254,17,0,180,1,40,2,16,255,118,254,7,253,43,0,2,253,46,0,161,251,2,255,4,6,195,0,214,254,191,252,45,0,163,255,61,0,40,0,85,255,167,0,82,0,107,0,16,0,40,0,90,255,210,255,120,0,71,255,13,0,151,0,215,31,21,255,92,0,233,255,214,0,206,0,4,1,93,0,163,0,78,0,184,0,196,255,244,255,85,255,13,254,105,255,37,255,11,0,35,255,221,0,181,12,136,254,201,251,31,254,251,2,255,254,136,255,246,255,34,0,128,253,85,1,119,244,16,2,55,2,96,253,177,254,81,255,195,255,69,2,252,254,135,4,222,252,46,4,12,0,168,0,1,9,35,1,203,0,241,255,199,253,175,12,77,255,108,2,83,1,224,0,198,2,96,254,0,2,170,255,59,2,183,1,89,255,59,2,184,255,112,255,236,0,130,254,11,0,12,1,80,255,120,255,175,254,220,0,64,0,85,1,105,1,134,238,25,0,129,1,197,1,103,255,89,0,196,253,245,0,59,255,33,0,75,0,76,2,51,0,57,255,182,255,107,255,224,0,210,0,81,18,26,1,20,0,209,255,129,0,221,0,184,255,27,0,76,0,93,0,75,1,215,0,251,255,236,255,74,0,176,255,169,0,126,0,216,255,119,255,232,255,91,224,233,255,165,0,15,1,147,1,222,255,237,255,34,1,57,255,242,255,205,0,145,2,45,1,139,252,153,9,83,248,38,247,20,252,32,255,214,253,182,0,36,255,45,254,157,253,244,3,134,255,231,12,183,255,51,255,93,0,221,13,217,0,33,255,55,0,53,254,29,2,30,1,210,255,128,0,98,1,137,0,56,3,199,254,32,0,45,1,139,0,20,254,170,0,136,0,221,255,16,253,5,18,194,252,222,255,41,0,88,1,23,1,131,2,118,254,51,254,163,0,182,254,199,0,41,255,83,0,72,4,101,2,39,254,48,3,206,13,210,0,252,252,167,3,237,254,168,253,171,254,90,2,104,0,170,253,39,255,235,252,132,246,102,3,161,254,218,1,50,0,65,1,108,255,143,244,25,0,121,255,210,255,11,0,202,253,15,244,104,253,188,2,212,254,0,1,64,252,94,1,32,254,158,1,175,1,24,0,205,255,28,255,151,1,142,0,191,254,60,1,222,254,149,0,56,0,172,255,153,254,138,255,172,236,138,0,117,1,207,255,142,0,71,0,93,255,243,255,233,254,38,0,135,255,35,0,209,255,186,255,213,255,116,0,3,0,97,255,245,255,97,0,140,255,194,255,156,0,51,1,83,255,126,28,113,255,32,1,222,255,159,2,101,2,16,0,16,255,27,255,98,254,18,254,213,255,87,255,170,252,80,1,33,252,207,2,159,254,93,255,18,253,125,10,21,11,210,253,129,0,28,8,209,255,129,2,219,255,163,255,226,0,187,255,86,2,228,254,127,0,106,0,86,254,213,253,77,252,229,1,54,0,153,243,110,2,171,254,224,253,22,1,51,255,79,253,135,1,238,0,9,0,152,0,23,255,120,254,28,0,36,0,118,254,221,251,132,0,177,14,32,254,87,0,112,253,24,5,222,1,240,254,65,0,109,255,91,0,8,2,128,252,166,0,62,0,226,255,228,255,194,0,30,2,3,0,113,2,3,7,29,14,73,4,6,4,138,3,144,1,133,0,129,255,219,0,190,3,93,0,222,253,66,253,121,11,244,253,242,254,1,253,64,255,213,2,127,252,125,253,198,9,141,0,133,251,1,1,23,1,214,1,71,244,152,255,79,0,252,1,194,1,9,1,235,255,182,255,75,254,135,2,61,245,105,254,208,252,108,2,24,0,25,2,100,253,92,2,104,241,103,241,238,255,227,254,127,1,112,255,101,255,52,255,40,1,113,254,105,253,100,1,148,254,73,1,182,254,251,255,204,255,168,255,215,255,228,0,235,255,211,255,120,255,232,254,147,255,170,255,57,0,91,0,44,255,158,0,150,255,166,255,0,224,70,0,1,255,78,0,248,255,167,255,146,255,198,255,104,0,205,255,218,245,155,1,162,255,201,253,209,0,48,254,139,0,22,255,176,254,242,2,95,3,143,1,89,1,117,0,149,242,37,255,113,1,59,0,187,254,135,9,108,255,6,0,208,255,84,0,242,255,71,0,94,0,10,0,6,0,73,0,106,0,22,254,56,255,186,0,89,1,248,255,99,0,153,241,221,249,44,7,199,249,87,4,140,241,214,1,250,255,145,1,74,255,137,255,182,1,249,254,228,0,17,3,151,254,200,255,20,254,209,1,77,1,61,0,53,0,234,0,233,255,169,255,39,0,105,0,114,28,59,0,209,255,199,255,179,255,211,255,84,255,12,0,179,0,122,255,37,0,99,255,237,255,50,255,9,0,162,4,248,254,88,2,94,1,118,1,115,0,201,255,215,2,92,255,193,240,33,253,74,2,232,255,145,0,238,252,138,255,175,3,2,2,140,1,107,13,221,255,83,0,38,1,107,0,16,0,204,241,163,255,104,1,205,254,151,255,84,255,204,0,64,1,108,255,154,1,175,0,79,1,0,0,78,255,12,0,94,0,209,255,165,255,207,255,97,255,101,255,191,255,239,255,97,255,196,254,64,0,155,0,252,254,81,0,98,237,106,255,140,255,180,254,128,0,163,2,151,255,33,254,51,2,155,255,101,0,133,254,33,0,37,0,1,0,106,0,151,0,69,0,140,0,250,255,182,255,157,0,131,255,136,255,223,255,78,255,226,254,60,0,98,255,43,0,133,227,217,254,188,255,222,255,188,255,198,255,8,0,176,0,214,255,44,255,176,0,235,253,194,255,229,255,167,0,35,1,59,0,55,1,22,244,40,2,19,254,49,255,16,10,33,252,137,254,154,255,44,252,106,4,203,253,57,255,47,2,146,250,84,254,150,253,70,0,75,254,11,255,148,251,234,250,59,254,83,0,222,0,237,249,78,255,140,250,104,251,28,255,218,2,207,243,195,251,84,0,186,254,71,0,71,255,197,254,121,3,35,3,162,244,231,241,129,253,57,255,187,0,137,0,146,253,217,1,121,0,181,0,85,0,139,1,11,2,77,2,71,0,191,2,123,0,105,1,47,0,93,253,43,1,66,254,51,1,79,2,13,13,64,0,14,2,251,249,206,255,167,250,189,2,112,255,184,6,55,253,50,2,41,1,146,0,222,255,35,5,188,3,249,2,97,254,225,250,125,2,17,251,184,251,127,254,156,12,117,254,61,1,158,254,9,254,255,0,242,253,245,0,86,2,85,3,243,254,146,255,74,5,77,1,110,0,87,3,238,242,123,2,124,2,107,252,191,253,4,1,147,0,17,4,249,4,129,1,162,252,215,6,181,251,80,0,108,255,120,0,138,255,189,21,28,254,182,255,70,1,35,1,234,0,215,255,212,0,192,0,207,0,148,255,198,0,118,0,123,254,178,0,105,255,4,255,187,255,13,255,224,252,80,10,237,253,84,0,211,254,157,0,156,242,3,0,94,254,83,255,90,255,46,253,207,0,192,1,125,254,8,254,202,0,197,1,210,0,53,255,48,1,190,0,248,254,101,0,233,255,36,0,74,0,110,255,26,0,29,0,223,255,59,0,129,255,22,0,213,0,89,255,103,0,0,32,183,0,149,10,131,255,68,1,60,252,253,254,112,254,215,255,82,254,111,1,127,0,10,1,113,1,57,4,66,255,36,255,197,251,129,2,83,245,238,2,13,2,145,253,238,255,87,12,174,2,234,254,221,247,144,6,75,2,123,0,250,255,246,254,120,1,10,2,79,254,13,254,169,0,106,0,249,7,174,0,59,2,148,255,129,0,140,255,169,255,4,255,89,0,242,255,14,0,120,0,62,225,52,255,15,0,19,0,146,255,174,255,202,255,66,0,31,0,210,0,55,0,83,1,61,0,37,255,123,243,12,5,80,0,88,1,35,253,100,12,235,255,201,255,200,2,64,255,38,0,152,1,233,1,132,1,169,254,5,253,182,1,236,248,250,255,127,255,144,250,130,254,228,255,105,0,228,254,88,255,50,254,228,254,22,0,113,0,179,4,181,12,179,253,149,253,92,1,113,0,79,3,3,0,211,253,204,1,132,253,167,253,26,253,46,0,145,255,51,0,190,255,205,244,39,2,199,1,130,3,17,0,157,8,236,3,210,255,61,250,145,254,33,11,254,2,224,255,137,255,112,2,46,253,43,13,172,0,182,254,93,0,35,255,201,1,59,254,84,0,231,254,152,254,108,0,231,1,211,254,166,0,205,245,65,2,192,0,34,0,81,4,193,2,34,0,29,0,31,244,126,252,172,0,66,2,51,1,227,1,73,254,185,254,104,1,89,252,180,255,131,1,75,246,32,3,77,1,89,2,56,253,51,252,191,255,70,254,220,0,249,13,84,254,46,255,53,2,245,2,130,254,33,1,214,2,237,255,74,255,128,1,224,255,38,0,214,252,75,255,94,244,3,1,43,255,39,254,69,255,201,252,233,254,238,5,26,0,127,254,119,4,103,254,30,5,164,2,88,246,64,0,121,254,154,255,199,1,137,233,22,1,30,0,64,0,79,255,143,255,86,255,94,0,22,255,89,255,101,0,254,255,107,255,125,255,95,1,2,255,118,255,149,0,214,255,119,2,235,255,237,0,77,11,221,254,101,11,40,251,211,0,41,255,22,0,197,252,96,255,140,0,43,255,156,0,6,255,47,251,179,2,242,1,226,255,94,1,228,255,244,255,217,0,34,0,164,254,186,255,116,255,103,0,196,255,97,1,56,255,198,254,182,255,112,0,83,17,176,255,225,254,157,1,157,255,127,5,239,5,74,247,114,0,107,12,245,253,39,0,84,1,133,254,117,1,240,249,118,255,66,254,150,255,6,253,7,252,215,254,73,255,242,1,31,254,118,1,15,1,23,234,41,1,98,0,134,254,187,0,178,255,131,255,77,1,114,0,175,255,62,0,111,255,14,0,106,1,6,2,134,0,195,0,130,0,222,255,184,255,240,243,107,244,142,255,73,2,178,255,6,0,40,2,135,253,158,255,32,255,212,3,82,1,173,255,216,251,42,0,106,0,137,255,132,2,219,254,240,1,67,0,128,0,127,255,108,2,20,0,14,2,79,255,68,0,95,1,137,241,185,5,137,3,11,255,86,0,255,1,39,0,0,254,106,255,239,0,86,0,60,0,39,0,177,255,247,255,191,255,77,0,199,224,57,0,237,255,56,0,218,255,161,0,35,255,127,255,8,0,93,0,52,0,10,234,142,255,133,0,26,0,64,0,62,255,196,254,113,255,225,0,190,255,175,255,182,255,240,0,130,0,137,0,219,253,11,0,96,1,203,255,67,240,1,2,92,12,51,255,127,0,80,0,63,255,59,255,220,255,139,252,223,0,166,252,5,0,54,254,34,1,203,1,247,0,228,254,80,255,20,253,173,0,191,0,114,0,150,1,126,0,3,0,91,0,84,0,91,31,123,1,200,255,47,0,35,0,246,0,113,255,65,0,220,255,8,0,59,0,67,0,187,255,91,254,92,242,56,1,4,255,5,1,39,13,63,1,189,255,77,0,166,254,130,1,34,0,237,0,18,0,111,0,92,1,221,253,186,0,163,255,26,242,78,255,39,241,123,255,229,255,207,253,204,254,112,0,32,255,16,1,61,255,242,254,77,255,91,255,199,0,244,253,169,2,139,255,83,254,37,0,253,232,94,0,201,255,79,254,158,254,122,0,196,255,67,0,56,255,176,255,11,1,120,255,214,255,130,0,188,254,231,255,156,0,167,0,209,255,178,0,8,0,33,1,157,0,88,0,228,255,217,255,250,254,245,255,9,0,143,255,76,0,0,32,89,0,115,0,214,254,137,0,34,0,0,0,5,1,226,255,49,0,18,1,130,0,56,3,80,252,200,255,50,4,198,254,180,255,15,2,75,0,7,243,221,2,226,252,160,254,242,251,25,4,72,0,23,255,56,1,35,13,69,0,104,0,107,255,22,0,27,1,236,255,155,255,234,242,164,0,184,254,150,254,31,252,174,1,78,0,125,0,13,1,227,255,106,1,183,255,226,255,91,251,116,5,59,0,251,250,40,255,135,255,53,15,84,0,48,254,218,255,143,255,143,254,75,255,94,252,12,252,138,1,120,0,18,1,216,253,224,252,105,0,115,255,244,255,241,0,101,253,31,2,96,254,28,0,74,255,51,0,137,3,132,240,67,251,12,0,241,254,122,1,22,255,70,3,143,255,56,0,55,2,35,0,48,0,234,1,76,255,73,4,170,0,36,10,228,255,26,12,36,255,168,1,117,3,214,255,15,3,226,255,139,3,63,0,46,0,125,255,28,0,201,255,54,0,210,255,231,255,30,0,58,0,241,255,56,255,250,255,11,0,186,255,66,0,103,224,86,0,120,255,96,0,200,255,155,255,44,1,107,253,215,255,55,255,248,2,4,255,187,3,189,0,179,5,234,13,55,254,35,0,202,255,92,255,183,254,35,251,194,252,147,254,113,254,233,255,104,2,18,255,235,250,58,255,79,1,184,242,149,0,175,0,159,255,233,254,174,253,164,255,109,252,194,252,212,1,116,2,216,2,0,4,219,253,49,4,222,0,114,255,40,1,181,255,88,255,251,255,189,255,113,227,206,255,0,255,191,254,121,0,102,1,240,254,30,0,2,1,105,0,95,255,221,254,206,1,249,255,45,255,29,255,152,255,105,255,104,255,184,255,158,255,197,255,233,255,158,255,53,255,103,0,89,0,239,0,28,254,69,30,110,0,35,0,89,1,26,1,190,253,140,0,205,255,194,255,18,255,102,0,198,1,64,0,149,255,33,255,82,255,29,1,110,0,66,255,240,255,88,6,142,0,229,14,175,252,43,0,234,0,84,0,0,0,124,255,131,0,121,255,186,255,255,255,125,0,173,255,171,0,109,0,108,31,97,0,218,255,143,0,64,0,13,0,4,0,31,255,181,0,200,2,114,2,20,0,167,0,45,254,186,0,217,14,125,247,121,253,137,255,144,255,73,255,33,255,39,1,74,254,105,254,227,255,36,0,222,255,232,9,209,255,110,254,223,255,194,255,120,255,140,9,104,255,51,253,156,252,86,0,237,246,163,3,147,2,255,250,158,255,126,2,94,255,195,0,251,255,216,255,168,255,203,11,138,13,189,254,60,1,240,252,53,253,5,0,188,0,42,0,155,0,160,253,244,1,185,0,219,1,100,0,205,255,111,3,133,252,98,255,18,0,59,254,124,1,49,255,113,255,145,1,103,255,158,3,72,255,215,10,104,12,227,252,58,255,136,252,149,1,204,1,53,1,48,1,142,255,82,9,15,9,146,2,104,247,216,0,179,1,70,251,113,253,154,0,81,0,26,2,140,3,220,0,138,255,226,1,160,252,242,253,15,255,89,3,39,254,6,3,224,254,138,252,46,0,250,0,160,255,45,1,120,0,24,254,128,255,23,255,166,1,38,0,168,242,50,252,13,255,30,255,125,1,90,9,140,2,52,12,51,255,233,250,204,5,97,255,104,255,243,251,151,255,135,255,46,254,180,255,93,2,181,0,201,255,186,254,241,253,130,255,155,6,36,5,180,254,26,5,90,6,19,6,74,242,31,255,162,1,240,5,55,252,182,255,226,254,233,0,199,254,159,255,119,1,181,0,203,254,68,5,201,3,8,254,115,255,21,3,56,251,119,255,64,253,98,0,235,3,210,1,211,8,205,5,31,255,61,0,16,1,33,255,165,254,233,255,144,254,96,0,41,9,112,0,107,1,216,253,250,255,218,252,155,249,89,249,61,6,190,247,60,255,37,1,107,251,138,253,161,252,56,251,16,3,46,253,232,2,117,3,30,3,128,254,92,0,42,1,151,252,16,7,109,5,232,1,223,249,251,249,8,244,34,253,3,0,211,1,37,252,90,1,123,7,85,253,205,0,25,254,85,1,182,254,18,1,231,255,49,0,173,255,222,4,107,254,247,252,10,1,121,0,6,255,210,1,48,251,131,243,153,252,130,253,180,254,27,6,108,7,42,254,44,2,47,254,100,254,133,3,170,255,85,253,191,253,247,251,40,3,161,252,188,4,44,253,174,8,173,1,173,10,157,1,123,3,133,6,3,2,73,254,187,0,153,254,158,1,176,0,62,253,167,2,193,255,223,4,71,249,11,3,46,245,28,254,135,253,31,252,13,255,162,5,200,254,188,254,142,254,136,1,105,254,229,0,97,0,243,4,238,255,46,0,209,254,84,253,3,2,90,255,116,16,249,252,233,255,203,255,23,0,174,7,47,254,231,0,171,4,252,0,244,251,16,0,200,252,140,255,186,253,226,254,214,1,97,255,217,0,56,254,37,2,136,2,60,0,161,251,221,0,21,253,98,1,140,253,26,254,126,3,0,5,185,245,247,0,174,1,89,249,69,0,20,255,147,0,165,5,28,2,88,252,181,0,93,255,163,3,236,251,157,2,153,9,7,2,85,2,17,248,11,0,217,250,252,255,90,251,85,0,254,0,42,250,230,0,47,6,221,253,21,1,42,248,153,255,171,4,38,246,21,5,135,253,152,255,1,254,61,2,92,6,61,254,2,252,52,2,76,253,255,0,5,4,104,254,245,2,172,0,117,254,40,254,89,249,192,248,133,254,33,1,253,1,140,253,187,250,49,255,148,1,113,254,135,6,136,1,89,252,66,255,184,3,13,251,126,4,26,6,159,253,235,1,166,254,242,254,29,254,54,1,140,5,7,252,178,6,123,253,129,3,209,250,82,12,234,251,167,252,13,254,16,254,188,250,143,1,63,0,115,253,197,254,52,3,109,6,102,2,154,8,11,3,185,11,102,5,131,1,181,252,208,248,166,1,7,252,246,0,37,255,218,253,105,0,160,253,170,1,166,254,32,255,119,1,22,0,64,254,242,254,130,251,127,252,202,16,142,252,49,0,121,2,87,252,74,253,163,2,190,254,231,252,252,253,152,254,8,255,166,4,63,2,181,252,243,255,50,0,223,252,157,4,196,1,177,254,17,254,154,255,223,251,250,1,50,255,66,0,121,253,223,3,3,1,3,1,44,254,197,0,117,1,136,239,18,253,224,0,74,255,8,2,238,253,96,7,30,248,44,250,144,2,89,250,225,3,234,252,239,252,24,3,122,6,117,1,131,0,52,254,65,253,56,4,149,252,44,255,74,253,235,2,129,253,37,247,239,4,97,254,19,253,2,251,79,2,23,253,31,255,115,249,69,0,113,2,110,255,212,0,89,1,216,2,215,253,93,4,215,1,38,2,14,254,39,253,234,247,238,3,182,254,171,3,52,14,34,0,93,1,249,2,125,255,116,1,98,2,113,254,10,0,86,0,110,0,163,3,121,251,81,255,121,2,56,2,140,0,200,2,240,10,234,249,39,9,3,0,50,252,95,253,233,0,156,5,241,252,87,2,70,254,84,3,127,2,191,1,48,252,204,253,231,5,36,0,17,2,177,1,165,2,179,7,217,10,204,252,113,253,73,250,144,250,138,251,160,254,176,1,218,2,183,1,239,254,76,3,108,0,115,0,152,1,151,254,248,1,81,1,58,0,50,4,147,249,169,249,19,254,186,255,207,249,62,11,27,253,124,2,32,255,50,252,210,2,109,255,149,0,135,0,149,255,102,255,253,251,238,255,35,252,26,1,101,12,99,4,246,252,109,5,177,253,81,1,124,6,224,254,138,4,191,255,148,2,70,1,141,0,102,1,167,2,34,255,204,1,105,0,0,2,36,0,170,252,35,254,82,252,198,246,9,1,204,8,92,255,245,247,106,0,154,2,92,254,9,2,78,255,140,1,212,248,219,1,82,0,100,1,207,0,177,1,19,252,97,0,129,1,208,254,171,252,2,5,17,255,170,247,83,0,84,0,201,0,154,248,189,249,171,2,91,248,143,255,71,3,163,4,199,254,6,3,14,253,173,3,29,253,236,2,116,0,204,2,110,4,238,253,126,247,71,0,157,253,8,6,199,13,253,255,27,1,15,2,201,1,143,1,250,2,17,0,233,254,196,0,250,253,96,255,76,251,223,254,182,250,132,0,197,254,222,254,125,247,164,2,62,250,14,252,139,250,107,1,211,255,15,3,46,5,223,255,147,255,151,253,241,254,57,252,153,255,75,7,1,3,228,2,206,252,243,3,131,5,75,253,102,246,40,3,38,3,43,255,212,1,31,0,186,255,166,0,230,0,107,254,163,0,70,0,140,2,53,4,66,255,146,253,39,9,208,250,89,2,160,3,131,249,174,0,173,1,81,246,245,1,247,1,215,255,85,5,159,2,238,3,80,248,7,0,103,0,113,254,130,254,61,2,229,255,42,2,41,247,154,243,21,1,177,0,39,3,184,254,208,252,197,1,244,249,60,3,185,254,187,0,119,254,23,253,180,255,216,252,63,2,248,255,186,254,242,247,89,2,54,2,243,2,7,3,83,2,163,1,171,240,30,255,16,1,112,1,139,1,59,0,93,4,36,2,119,253,83,254,65,1,37,2,24,253,63,1,82,0,135,0,73,0,14,0,118,1,93,0,242,254,59,254,177,0,127,19,57,2,169,0,111,0,10,255,150,254,168,255,207,255,71,2,221,255,60,0,9,253,47,5,232,6,254,2,162,254,144,252,150,255,63,254,143,255,85,253,94,254,25,252,224,3,47,2,222,254,109,255,188,254,93,0,77,252,164,240,219,255,51,1,63,4,198,254,219,254,176,1,62,3,126,255,48,255,59,0,207,2,164,254,159,17,224,0,232,1,82,255,76,2,27,3,211,254,10,255,65,254,170,2,149,3,73,251,9,254,62,254,63,2,140,255,130,255,82,2,234,255,155,255,5,0,92,251,81,254,122,4,227,240,184,255,146,1,95,254,122,254,94,1,117,4,118,255,185,2,77,0,73,243,244,254,238,252,150,255,150,250,144,1,168,252,77,253,74,254,242,249,28,255,114,8,236,0,64,0,130,254,1,0,8,4,153,0,109,253,27,6,102,254,0,5,37,6,165,241,239,251,240,0,145,1,215,0,159,254,140,251,9,1,153,255,200,252,163,255,193,254,175,252,253,0,35,254,49,254,153,0,7,252,26,2,209,4,239,251,11,0,230,3,75,254,199,253,54,252,70,8,215,249,1,0,65,1,248,6,214,254,11,9,72,0,236,255,83,0,137,3,247,250,10,255,219,2,236,15,59,250,90,2,113,252,210,3,186,2,17,255,135,1,39,253,236,254,225,0,143,0,95,254,12,254,229,255,60,251,89,0,109,254,83,250,14,246,247,3,70,0,78,0,60,9,97,255,249,252,29,0,37,0,25,255,73,0,177,1,170,1,239,253,164,1,155,253,156,255,163,253,183,5,233,3,135,4,14,240,215,253,92,1,218,252,112,2,94,255,159,251,231,255,151,3,194,255,90,0,237,254,233,0,203,0,32,0,233,2,35,255,202,1,17,2,133,3,64,4,38,0,185,4,194,1,195,1,202,8,101,254,51,255,249,2,249,0,54,251,246,254,133,243,223,252,225,255,247,3,188,254,172,253,214,255,150,0,207,0,37,10,17,4,235,251,50,247,108,250,250,0,217,0,69,0,91,252,144,5,24,1,190,1,12,2,28,2,127,2,253,251,23,0,156,1,36,0,189,255,219,1,154,251,29,253,136,4,2,2,99,255,240,244,104,250,47,2,77,0,228,2,136,252,134,0,24,5,245,254,245,254,73,1,8,0,185,6,208,5,227,255,32,249,144,248,182,245,194,250,240,253,185,8,37,255,62,255,153,244,128,0,179,4,145,253,129,255,232,1,126,254,123,255,183,254,62,0,85,0,247,4,71,255,33,254,180,253,108,244,34,2,115,6,246,5,194,252,22,4,91,1,63,0,232,251,239,0,122,5,234,255,51,1,186,249,0,3,231,3,48,1,0,254,81,255,10,255,139,254,17,2,93,0,247,253,30,5,4,254,242,238,27,0,0,253,154,254,193,253,254,255,175,253,235,255,186,252,123,2,197,0,122,2,65,1,249,254,135,254,219,253,20,0,227,2,139,1,247,255,120,254,70,0,47,22,123,255,126,255,16,255,90,253,165,1,155,255,156,1,143,0,209,0,194,0,216,0,200,0,234,255,20,253,113,254,47,11,28,1,231,0,179,2,59,2,124,242,56,255,56,1,224,1,198,250,165,253,179,1,204,254,153,253,8,2,178,0,68,0,52,253,45,0,175,253,224,255,143,250,214,253,24,252,157,252,101,2,32,1,251,1,202,0,143,255,17,0,93,0,115,255,209,255,153,2,47,2,216,252,5,240,193,253,63,255,151,252,234,252,161,2,160,253,83,252,233,2,26,6,220,251,220,3,168,4,29,0,73,251,207,0,141,2,146,253,124,255,114,1,155,5,185,7,170,248,137,255,101,0,156,255,102,255,155,252,185,246,230,4,122,0,188,0,109,3,188,0,186,252,157,254,155,2,229,14,52,4,113,1,253,252,56,253,99,253,242,255,107,0,3,4,112,0,2,9,138,5,133,0,31,4,121,1,249,0,255,3,97,252,12,0,65,248,150,4,223,0,129,1,59,3,145,5,98,249,102,251,162,255,175,253,226,254,239,4,97,253,87,254,210,7,189,2,10,6,35,2,182,0,245,3,128,0,95,1,13,255,151,1,45,9,136,254,189,1,163,255,200,3,175,254,167,253,62,5,219,3,37,250,124,253,9,2,71,1,211,253,8,7,12,0,29,1,127,0,243,254,59,248,63,254,87,0,238,251,184,0,13,254,207,4,128,249,160,254,4,0,229,4,147,1,216,251,69,3,90,249,133,0,151,6,236,250,200,8,179,0,177,252,151,253,204,1,194,1,252,254,94,0,244,252,93,253,185,4,38,0,197,1,89,3,137,253,61,1,23,2,62,4,60,255,126,2,224,254,123,254,176,2,163,255,247,4,62,239,160,255,189,1,64,0,45,255,148,0,182,255,230,1,175,248,190,4,44,7,60,253,8,7,108,6,64,2,192,251,68,251,123,4,56,254,173,0,113,252,233,1,69,254,132,2,22,2,78,3,14,250,238,252,241,1,111,254,193,251,130,5,111,5,69,3,3,255,124,0,170,253,2,255,151,240,111,251,103,0,63,255,50,0,78,3,10,252,97,1,199,1,16,3,63,5,239,11,178,0,140,253,108,255,246,254,188,254,160,255,66,255,94,252,115,0,219,1,117,253,198,254,174,255,20,255,168,255,87,241,232,251,229,254,78,255,95,1,97,253,69,1,30,4,28,0,28,2,113,0,183,255,251,2,76,3,31,2,250,255,31,3,245,0,176,0,124,0,6,1,144,255,242,3,105,1,181,252,218,12,99,241,146,3,213,248,253,254,163,9,41,1,75,251,168,0,131,248,156,0,87,0,125,2,91,253,69,252,56,1,222,4,37,255,92,0,66,4,220,254,251,252,87,1,245,253,43,1,255,253,41,5,232,253,74,2,212,250,41,9,80,9,49,253,88,252,109,5,229,255,112,3,82,1,129,255,102,253,71,254,67,6,143,0,38,255,119,8,201,250,213,1,56,251,185,9,85,5,56,2,19,0,214,250,32,253,208,0,18,254,58,254,222,3,6,255,49,1,193,253,206,0,88,255,103,251,26,1,223,230,239,1,235,254,138,253,155,1,217,4,186,254,87,254,11,2,114,0,31,255,203,255,230,253,66,253,252,254,95,254,111,254,34,255,249,254,96,254,163,0,24,251,78,2,104,251,73,7,203,5,97,252,191,255,94,253,23,5,109,255,18,253,124,255,151,1,229,254,84,3,252,6,47,247,210,0,62,254,47,1,240,254,24,246,94,0,218,7,172,1,103,252,253,255,185,255,149,252,156,0,87,253,9,2,49,0,51,0,245,253,252,5,83,6,78,253,146,1,101,252,62,1,97,3,193,0,117,247,106,253,41,2,176,251,186,255,223,250,206,1,235,251,64,1,169,3,83,250,254,253,148,1,25,255,44,249,200,249,9,248,39,255,148,254,223,250,84,254,115,9,233,4,244,250,19,0,51,11,234,254,216,248,17,255,77,253,129,254,62,0,185,0,57,254,203,249,116,0,163,1,193,254,94,254,25,2,232,254,214,248,121,10,167,252,46,255,100,255,137,251,152,255,18,249,166,6,184,0,249,3,121,255,158,253,13,2,79,1,157,254,18,254,25,255,102,255,218,3,178,1,110,4,189,4,146,3,177,5,254,254,194,251,221,1,57,247,242,1,51,249,49,252,250,254,44,3,108,0,66,3,100,254,120,0,248,251,235,253,56,254,139,0,211,254,125,254,78,253,30,3,3,0,236,249,237,4,233,2,122,238,8,0,213,0,209,3,105,255,243,254,168,254,13,0,32,2,242,254,90,255,62,253,160,2,184,0,81,252,78,249,230,5,29,253,99,7,35,254,16,2,55,7,220,249,164,1,103,0,171,255,252,1,231,0,232,7,193,250,20,0,238,0,113,253,156,2,231,249,25,253,117,253,197,2,144,251,48,255,211,3,2,1,75,253,233,253,154,251,229,254,80,252,47,255,91,2,251,248,74,244,253,0,216,254,74,3,63,0,53,255,44,254,163,2,81,1,178,5,114,0,3,1,130,12,145,0,163,1,119,2,96,1,5,9,57,5,47,3,157,255,200,252,245,252,209,248,81,250,166,0,212,247,19,5,162,0,254,251,110,252,128,0,41,5,128,3,47,255,255,0,136,251,39,3,202,244,136,253,180,253,98,3,81,0,197,1,154,0,22,251,13,254,60,254,158,255,39,10,254,11,28,2,190,252,28,255,12,251,199,254,245,4,191,255,200,255,11,4,13,254,5,254,111,253,191,1,26,0,96,0,81,255,133,0,221,254,230,253,253,254,7,0,50,255,155,1,145,0,25,0,215,0,11,1,254,238,70,254,250,0,210,252,113,255,53,254,74,255,128,253,22,251,169,0,123,1,84,251,173,1,128,255,77,248,121,10,211,255,105,6,152,0,212,253,141,3,109,1,150,253,95,254,149,254,78,254,14,1,148,250,39,254,62,0,58,0,253,1,187,240,47,5,35,6,226,1,57,4,128,252,203,1,224,1,211,253,245,254,134,1,241,255,228,1,248,0,52,0,49,0,190,2,246,255,162,0,245,0,96,254,117,5,23,0,183,0,69,1,79,2,208,252,77,17,162,2,180,254,37,251,68,0,29,1,235,0,247,2,197,254,31,3,57,1,181,254,74,255,139,253,138,1,201,251,39,15,175,255,139,2,250,252,235,255,215,254,231,0,222,248,47,0,104,0,28,1,85,255,58,255,146,255,63,255,113,3,53,253,38,1,22,254,139,1,19,251,43,11,153,243,59,250,156,2,41,255,54,1,10,0,250,2,187,252,101,0,142,0,201,0,84,252,197,1,174,255,237,1,41,252,23,0,45,255,222,3,47,5,56,18,229,255,53,3,41,3,244,1,243,0,41,0,56,2,44,0,192,254,105,0,205,1,50,1,104,254,231,252,221,255,238,255,229,0,244,255,96,254,65,2,211,254,6,19,248,253,243,1,57,0,224,253,235,255,99,2,226,0,236,255,100,254,184,1,88,253,192,1,174,1,226,0,158,253,202,254,38,255,137,4,11,2,112,254,108,255,15,3,139,1,130,255,114,1,174,2,15,254,211,254,161,0,251,255,238,0,119,1,101,1,130,255,186,3,64,23,203,255,121,0,107,254,35,6,179,1,205,1,114,251,117,251,67,5,114,5,170,0,243,7,212,249,66,252,20,1,88,253,56,252,19,1,189,254,12,2,48,0,152,248,46,0,17,254,36,2,95,252,165,252,224,0,55,4,95,3,8,12,198,249,133,254,46,1,109,254,198,2,143,2,219,254,49,253,85,253,80,252,228,0,171,254,51,2,17,254,152,3,226,2,154,253,40,2,7,255,110,254,92,255,250,254,87,254,71,240,164,0,40,252,250,253,157,0,124,251,39,253,0,4,0,253,235,3,225,1,140,255,63,1,106,252,27,6,106,253,244,18,105,2,6,255,37,2,247,254,163,255,168,2,214,1,157,3,219,254,117,2,142,0,231,0,44,0,133,0,12,0,40,0,157,252,13,1,179,255,189,1,148,251,39,252,232,250,216,2,168,1,18,2,254,254,143,253,121,1,136,250,22,246,42,254,81,249,157,1,189,249,175,255,119,254,11,252,106,4,138,3,31,1,128,2,201,14,49,254,97,255,43,0,91,255,71,254,255,253,225,254,214,253,11,6,80,3,237,254,168,3,141,2,1,3,198,255,17,252,70,253,232,252,127,8,142,1,102,5,134,255,203,1,249,255,25,1,225,10,131,253,120,2,233,254,37,1,202,251,28,252,96,0,219,254,201,250,182,255,181,253,226,254,203,253,47,252,28,255,216,19,3,0,171,0,111,0,222,255,79,255,149,253,65,2,192,1,232,254,189,0,9,4,189,253,134,0,55,253,77,252,7,255,151,248,108,1,212,6,206,247,21,0,91,3,183,255,167,248,116,0,36,0,55,6,106,5,152,251,166,254,9,252,231,255,166,255,77,253,40,252,136,255,29,0,133,253,20,255,26,0,77,253,26,253,53,255,38,1,40,254,123,252,22,10,85,255,155,254,150,1,162,0,25,6,111,252,52,1,9,243,205,1,11,3,207,254,97,252,34,1,83,252,103,2,80,253,4,254,222,0,80,254,131,1,170,0,141,255,38,235,252,1,44,255,150,0,26,0,218,255,50,1,241,255,50,0,216,7,168,251,69,255,44,0,79,2,232,254,163,4,166,3,28,255,42,2,65,0,149,250,49,248,219,252,251,9,55,251,229,254,77,254,82,254,206,255,113,253,153,255,248,0,22,255,32,0,198,252,60,253,64,253,18,252,176,0,16,3,18,1,114,2,207,246,195,2,60,7,124,255,60,255,87,255,49,254,187,247,56,0,157,1,115,255,206,252,147,254,153,3,208,252,130,255,121,255,182,1,76,252,111,255,163,254,188,2,205,0,233,3,214,241,58,1,19,254,98,251,131,0,221,2,100,9,36,251,52,2,64,252,72,1,143,251,148,255,13,253,88,255,29,252,198,3,86,249,203,253,38,3,75,253,89,5,243,254,84,254,163,2,0,3,85,1,230,252,217,8,48,255,165,248,223,252,159,248,193,3,182,0,8,254,173,253,103,3,0,251,184,3,71,5,153,2,218,1,8,4,58,0,195,1,58,255,89,1,176,0,171,252,181,244,202,8,112,2,152,253,183,0,144,0,224,2,0,0,58,255,118,255,62,251,11,254,110,253,232,255,208,4,226,254,23,255,87,252,102,8,245,251,193,1,145,253,68,245,128,247,150,3,86,255,165,1,96,5,93,0,153,0,115,2,237,1,28,0,37,2,220,254,81,255,42,4,13,4,37,254,157,1,42,248,26,248,178,254,109,1,133,3,177,3,105,253,3,2,161,254,171,253,155,0,38,5,103,255,161,1,87,254,44,0,82,1,90,248,157,254,172,253,170,247,104,1,85,1,197,9,56,3,198,247,230,254,69,249,33,253,218,253,25,253,113,0,3,4,33,254,190,247,240,255,137,253,230,254,226,251,40,5,98,255,22,255,151,13,28,0,26,7,115,2,184,5,229,252,234,255,129,3,250,255,136,1,22,255,86,255,202,2,130,254,238,4,67,0,150,253,145,0,25,0,58,253,9,255,223,253,150,250,251,248,29,252,97,3,209,1,148,254,62,3,203,255,172,251,129,254,230,253,85,0,219,2,68,255,211,252,2,0,125,249,51,13,33,1,169,1,39,5,253,254,176,253,44,255,15,1,244,254,130,255,2,5,50,1,19,15,113,250,95,2,20,0,243,2,174,0,242,252,72,0,22,255,163,2,103,251,77,4,133,253,151,249,14,10,46,252,146,250,49,249,135,8,53,0,75,0,138,2,159,255,56,254,130,255,49,253,93,253,45,2,137,254,131,2,85,3,175,255,64,255,106,251,248,250,70,252,141,252,218,252,122,247,193,247,110,250,180,0,246,254,211,254,114,2,69,254,61,0,107,255,69,254,89,252,208,255,130,2,250,0,17,0,84,2,62,5,177,247,67,1,80,250,203,7,69,3,80,250,109,249,177,3,46,253,91,250,196,1,178,0,71,254,6,255,119,255,128,255,206,255,201,254,168,253,189,8,154,3,139,0,149,255,131,253,234,6,57,246,157,1,221,252,240,1,209,0,121,254,145,1,156,1,216,253,93,2,219,255,101,253,183,249,237,255,207,251,242,5,63,253,158,2,32,252,114,3,67,251,170,252,102,8,141,254,73,0,113,251,176,253,103,255,3,254,184,253,17,254,173,255,27,8,47,250,207,2,221,4,142,251,72,0,182,3,74,252,30,2,178,253,220,3,110,6,192,255,50,2,33,255,73,0,71,2,105,255,215,0,146,3,111,5,75,244,161,0,180,1,49,0,177,8,15,1,229,254,4,15,190,253,79,1,166,255,70,253,94,255,212,4,139,255,214,1,127,1,50,253,8,2,39,1,29,0,36,1,77,255,6,3,204,0,116,1,5,255,200,252,25,254,226,248,200,254,37,253,56,2,16,252,1,255,189,0,85,251,145,2,29,255,94,13,139,2,36,255,76,251,178,253,201,2,109,1,47,252,204,0,46,12,65,1,154,3,165,254,225,5,119,1,179,255,16,250,125,250,88,253,5,254,31,2,20,254,204,248,135,0,177,2,128,1,104,254,140,0,121,2,88,251,219,1,220,0,81,249,218,250,94,2,153,255,56,253,58,249,38,255,169,252,189,252,1,244,147,255,111,5,62,0,21,0,181,255,179,255,113,1,216,0,52,250,9,8,149,2,58,1,19,1,24,4,175,0,50,7,231,2,40,3,174,253,82,1,63,251,70,6,237,253,176,250,207,251,196,1,237,253,226,252,253,252,244,250,106,252,94,2,16,249,3,254,178,0,142,5,96,13,122,2,210,2,255,254,13,2,181,1,59,255,126,255,35,1,101,254,253,254,134,252,172,255,112,1,93,4,215,250,188,254,182,247,3,2,134,4,213,6,61,252,169,2,39,0,12,1,37,2,68,1,167,253,151,0,56,255,61,3,41,15,29,3,148,2,196,253,75,253,121,2,255,3,109,255,187,253,102,0,49,255,93,255,1,254,226,255,154,255,123,1,8,3,238,1,2,254,55,0,237,248,49,4,32,17,194,254,205,12,166,7,47,255,229,253,31,7,176,4,74,255,70,255,213,0,123,0,250,1,41,254,81,254,70,253,181,254,112,251,88,0,20,1,72,255,221,2,217,254,227,251,51,253,94,3,83,250,117,239,39,4,25,4,147,253,83,254,116,1,19,4,87,2,15,1,75,253,79,253,122,0,210,1,189,254,76,1,235,253,133,2,4,2,141,254,49,255,2,248,72,0,155,251,27,255,47,245,182,254,107,5,167,255,86,1,226,10,38,253,152,0,117,2,41,3,53,254,8,255,246,254,111,0,124,1,212,2,101,254,128,2,184,255,67,1,34,0,235,254,187,1,33,1,151,0,48,237,146,1,85,255,37,253,123,2,172,255,123,255,202,254,141,1,136,3,169,4,24,250,231,255,230,250,75,2,66,1,78,241,25,2,206,254,43,252,149,3,190,0,19,3,155,253,149,0,45,1,136,254,110,1,94,1,18,0,125,3,146,255,183,10,225,255,86,0,245,255,121,14,192,0,167,255,57,0,4,255,245,255,44,255,163,0,0,0,119,255,149,1,157,255,132,255,119,255,105,254,125,0,106,0,102,252,31,6,85,0,165,0,241,0,110,0,102,11,86,2,69,254,44,3,159,0,6,2,43,2,162,248,191,255,204,255,253,255,229,255,56,0,226,255,130,255,126,0,23,0,74,0,157,0,78,27,222,255,56,0,255,254,84,255,115], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1824305);
/* memory initializer */ allocate([0,233,255,152,253,13,255,71,254,34,0,159,0,6,0,78,0,137,255,49,0,34,0,123,255,220,3,17,252,218,1,77,0,238,254,98,1,43,19,222,0,240,255,69,0,252,255,156,3,238,255,207,13,213,254,218,255,173,255,145,255,209,3,118,255,205,251,68,254,28,2,199,0,202,0,10,254,62,255,58,255,249,0,101,0,20,1,167,255,96,0,211,254,6,0,73,240,186,255,174,0,93,0,192,0,136,255,243,2,208,253,234,255,78,0,56,0,29,0,28,0,212,255,65,0,252,255,0,0,49,0,6,255,87,0,46,0,44,0,215,255,133,228,14,0,32,1,120,2,253,254,192,255,20,0,78,255,169,254,238,254,106,0,26,11,80,1,229,254,245,0,156,253,251,255,244,1,77,0,188,9,6,255,64,0,171,0,36,252,4,0,205,255,222,255,213,253,85,255,187,245,16,1,36,11,94,255,158,255,19,255,234,254,23,254,129,2,160,255,135,30,117,255,140,255,119,255,135,255,198,254,95,255,211,0,76,0,136,0,221,255,132,255,229,255,76,0,158,255,133,0,85,0,76,1,0,239,251,1,242,255,237,254,44,255,52,1,2,1,129,0,91,255,59,255,152,255,106,255,152,255,60,0,125,0,56,2,253,255,158,6,62,0,186,255,109,0,122,0,199,255,238,255,194,33,100,0,50,0,92,0,17,0,170,255,163,255,188,255,135,255,195,255,224,255,27,0,68,255,246,1,123,0,175,255,37,0,48,0,187,0,75,0,226,255,234,255,32,255,220,254,99,0,207,255,177,16,10,0,66,3,231,255,225,0,213,10,78,0,47,243,75,255,234,0,126,255,182,255,101,0,214,0,230,255,143,255,244,254,88,255,166,255,77,254,230,255,38,0,199,253,87,240,255,255,11,0,69,0,3,0,249,0,98,0,178,0,131,0,44,1,198,252,48,0,81,1,196,252,141,254,96,0,56,1,200,2,101,253,186,255,234,247,14,255,7,2,92,253,143,0,155,253,125,3,111,247,215,1,47,4,213,0,49,251,60,255,188,253,155,0,145,1,78,0,192,255,27,0,18,255,22,0,183,255,237,255,194,0,60,0,169,255,46,255,101,255,244,0,133,255,87,255,166,238,169,0,60,12,75,255,65,0,110,15,116,254,209,0,39,0,204,255,230,255,166,0,1,0,92,255,143,0,190,255,169,0,46,0,240,255,217,254,39,0,42,0,40,0,67,0,25,0,17,0,255,255,40,221,174,255,214,255,49,0,81,0,195,255,1,0,39,0,216,255,18,0,74,0,206,0,125,255,185,255,106,0,7,0,88,0,243,255,69,0,143,255,167,255,212,0,252,255,21,17,222,255,27,1,105,0,252,0,59,0,238,245,214,254,54,7,146,255,151,255,202,254,113,255,129,255,18,1,225,0,93,3,6,1,209,252,201,254,230,255,83,253,243,0,148,253,138,254,176,11,144,255,221,255,87,11,162,255,200,255,43,255,65,0,127,1,41,0,252,1,254,254,153,255,72,254,19,255,172,1,132,0,233,10,179,255,143,255,198,255,237,255,239,240,231,255,40,0,89,255,13,255,23,255,215,255,233,254,213,0,234,255,8,0,120,0,126,0,159,0,44,255,12,255,183,0,69,6,62,0,244,255,12,255,7,2,12,3,116,0,131,243,32,252,85,1,222,0,169,2,155,254,99,253,55,0,189,4,100,0,185,1,1,0,199,255,232,0,10,0,142,255,62,1,109,255,89,0,188,0,192,1,185,254,151,14,220,254,107,3,40,255,211,0,111,0,160,0,172,0,30,1,71,242,175,252,71,255,247,255,31,0,186,1,235,2,235,251,187,0,192,2,37,255,253,1,48,0,69,0,231,255,246,255,75,0,23,0,10,0,23,0,224,255,89,0,180,33,179,255,237,255,27,0,0,0,24,255,22,0,206,255,144,248,119,255,87,255,128,0,138,0,78,0,69,254,243,0,157,0,31,241,231,0,21,1,171,254,73,0,186,255,84,2,3,1,157,0,149,8,63,2,141,9,11,0,203,255,118,0,141,255,50,2,108,0,30,0,15,255,30,0,118,254,101,255,70,255,168,254,19,255,193,254,46,247,87,1,201,254,14,0,169,0,59,0,241,255,233,0,220,2,109,1,76,253,148,255,136,5,49,254,233,254,8,255,61,249,106,254,234,254,42,1,209,0,213,20,58,255,89,255,50,0,183,1,142,0,91,0,245,253,226,0,6,1,126,255,241,255,61,2,252,255,15,1,254,255,209,255,7,0,110,220,187,255,212,255,112,255,158,255,199,0,75,255,6,0,45,0,47,0,37,0,205,255,188,255,206,255,140,255,151,255,49,0,120,1,92,254,187,0,78,11,29,0,41,254,35,255,199,1,255,255,166,252,55,0,59,255,103,1,76,248,68,255,153,3,122,255,186,0,181,252,18,246,66,1,255,255,98,255,160,254,205,254,190,253,196,255,143,0,234,250,77,1,169,2,93,5,3,252,18,0,28,1,228,255,8,0,199,255,240,255,15,0,58,0,31,0,197,32,221,255,18,0,77,0,178,255,15,0,36,0,17,0,122,255,239,255,60,1,88,253,235,1,38,0,39,255,234,254,20,1,213,254,181,255,66,240,219,254,5,254,194,255,168,254,64,0,74,254,168,254,0,255,85,1,199,0,190,255,28,0,239,255,239,255,2,0,142,0,6,0,208,255,87,255,229,255,139,255,83,26,42,0,195,255,140,0,246,0,29,13,85,243,48,0,201,255,49,0,27,0,4,0,172,0,87,255,6,0,69,0,247,254,70,0,25,0,223,0,28,0,129,0,231,0,57,0,184,249,80,10,228,255,59,255,29,0,245,255,138,0,109,2,171,1,20,0,2,2,151,2,50,2,191,1,98,255,115,252,87,1,191,254,255,254,241,25,255,255,236,255,186,255,62,0,241,0,51,0,173,255,208,255,100,255,246,254,177,254,213,255,165,1,94,1,50,1,165,0,227,253,47,0,5,0,216,255,108,1,21,0,190,0,24,238,131,255,71,254,233,1,197,253,209,255,246,255,205,0,60,0,183,255,184,253,161,1,233,0,222,255,147,255,85,0,41,0,134,0,229,1,85,255,73,255,14,250,202,0,134,1,216,243,144,0,139,6,139,2,146,1,161,7,120,0,93,0,236,254,118,248,59,255,195,255,100,0,81,0,6,255,101,255,237,255,80,1,78,255,220,246,88,0,225,253,226,0,53,246,196,255,194,255,218,0,247,255,158,0,223,241,190,255,32,0,58,1,64,255,135,255,116,1,78,1,4,2,156,1,247,0,159,253,43,251,56,1,136,255,217,255,47,0,61,0,193,255,166,255,148,17,65,255,159,254,10,0,54,0,93,255,167,254,121,0,194,254,21,255,190,0,157,255,181,0,215,242,4,0,68,255,169,255,128,0,167,0,5,254,148,251,102,253,158,254,121,0,43,0,222,253,89,2,103,254,181,0,209,255,197,254,127,0,227,244,231,1,186,0,92,245,87,1,177,0,187,252,131,1,172,255,3,1,122,0,97,255,88,0,117,0,137,0,79,0,126,0,48,6,247,253,112,246,88,10,10,255,181,255,55,2,114,0,244,0,141,2,217,253,60,255,145,253,205,0,48,3,48,0,186,254,66,0,162,255,223,255,133,0,156,1,15,255,235,1,224,255,56,253,7,255,84,241,71,255,27,255,248,0,12,1,45,2,73,0,164,0,24,0,186,255,229,255,54,0,100,255,205,255,209,255,230,255,43,0,187,0,179,0,218,255,119,255,218,0,124,7,6,18,179,1,241,255,21,0,145,0,76,7,241,0,240,0,43,1,52,255,73,0,232,255,138,255,140,254,167,255,23,0,214,254,223,1,21,11,191,3,180,255,171,255,254,255,28,0,94,0,83,243,28,0,126,255,159,0,39,1,8,1,93,254,158,255,240,255,97,255,93,1,202,0,98,255,136,245,46,255,122,254,238,255,248,255,108,1,87,5,146,255,164,3,24,255,68,5,176,255,97,3,221,254,104,254,150,1,138,255,62,25,201,255,10,0,104,255,95,255,124,255,231,0,2,1,135,0,243,255,152,255,247,0,207,0,18,255,212,0,237,255,225,255,25,243,96,255,232,255,74,13,50,0,116,0,65,255,97,0,117,255,156,255,71,0,207,255,219,254,133,0,136,255,246,255,197,0,196,0,252,253,82,253,79,0,204,255,114,23,209,255,88,0,55,255,146,0,136,0,54,0,162,0,76,255,31,1,67,0,70,0,201,255,210,0,110,248,123,2,94,255,82,0,136,255,56,254,181,255,87,241,173,255,176,0,137,0,18,0,250,255,231,254,232,0,137,0,89,255,117,1,78,0,194,245,218,255,219,254,89,0,69,0,108,242,8,0,152,0,136,0,32,0,241,255,116,255,11,0,6,0,13,0,225,1,81,255,28,255,2,255,158,0,161,242,206,0,22,0,132,3,233,7,10,1,110,254,132,0,156,254,46,2,176,253,250,254,93,254,234,3,73,0,10,255,232,255,183,243,148,12,223,255,27,1,142,1,225,255,231,255,249,255,103,0,163,255,113,255,1,0,32,0,15,254,206,0,221,255,144,5,114,0,140,0,89,9,173,12,38,255,93,255,113,0,191,0,92,255,41,255,248,1,0,255,140,0,148,254,30,255,172,254,91,0,48,254,32,0,188,0,4,0,15,0,76,232,69,0,109,0,219,0,75,0,196,0,232,255,172,255,38,255,27,0,57,0,159,255,8,0,174,254,252,255,102,1,23,0,204,255,188,255,40,2,183,15,1,255,172,2,144,0,188,0,100,0,219,254,206,1,41,2,9,0,153,2,12,0,128,253,21,236,98,255,11,255,182,255,88,255,7,1,157,254,142,254,115,253,93,255,39,254,118,254,23,255,238,2,17,0,225,255,173,1,152,255,46,255,216,0,105,1,230,245,253,0,186,250,145,0,235,10,251,255,151,2,250,254,37,0,134,255,205,0,14,1,65,1,63,10,0,1,4,0,214,255,219,255,112,0,166,254,20,0,205,255,9,0,166,255,242,242,78,0,52,0,17,255,58,254,49,255,99,1,120,255,237,255,138,1,44,255,90,255,183,255,188,255,25,4,127,244,129,1,223,253,45,255,116,0,241,255,175,2,24,255,32,7,190,255,133,0,109,254,193,255,3,0,46,0,152,255,155,255,136,0,195,255,164,1,149,0,232,255,247,255,181,16,107,255,90,255,96,0,221,255,250,6,236,251,115,0,210,250,53,13,248,253,70,0,122,255,79,254,58,255,146,0,153,253,113,255,201,0,86,1,156,1,94,255,22,0,111,0,16,0,171,255,14,0,136,255,79,0,226,255,172,255,56,0,222,255,204,255,109,255,19,0,155,0,17,0,136,255,221,22,96,0,255,2,6,1,62,255,124,0,76,255,13,0,9,12,39,0,146,1,90,0,36,1,84,0,207,7,240,255,98,3,36,1,160,1,198,254,177,0,255,255,68,0,3,0,228,255,200,255,202,255,10,0,251,255,193,255,89,0,187,255,5,255,70,0,99,29,173,255,67,0,62,0,178,0,69,249,180,255,101,0,113,1,117,255,58,0,135,0,224,255,138,0,65,13,193,253,74,2,36,1,216,254,7,254,134,253,52,0,24,1,78,0,14,0,117,0,217,255,77,0,231,0,136,0,14,0,51,0,173,0,160,255,5,0,122,1,204,255,12,239,249,254,61,0,22,0,176,244,236,255,180,0,21,0,52,14,118,255,104,0,233,254,56,0,105,254,248,255,133,255,134,0,161,255,12,254,10,1,192,255,213,255,1,0,86,255,31,0,110,0,53,0,56,0,206,232,151,0,49,0,180,255,90,255,34,0,248,255,193,0,198,0,138,255,252,255,212,255,249,0,228,255,154,255,226,241,49,0,208,1,124,254,24,253,12,254,91,2,168,255,237,255,70,6,69,1,29,255,235,254,114,255,232,0,213,248,150,0,167,255,29,0,9,0,76,0,169,1,192,254,179,0,231,0,184,6,168,1,86,245,214,254,154,2,72,0,84,254,37,251,213,254,93,0,244,255,236,255,160,255,133,255,18,0,188,0,255,255,21,255,254,255,0,13,107,0,47,250,199,0,125,3,193,255,46,0,215,14,22,0,138,255,129,255,27,1,254,0,213,247,37,1,75,1,89,3,164,255,46,0,13,0,55,254,169,0,83,3,237,255,25,255,225,221,194,255,69,0,66,255,153,255,225,255,108,0,66,0,95,0,53,0,250,255,12,0,19,0,183,255,105,0,216,255,227,255,60,0,249,254,149,255,185,8,10,255,229,1,86,1,196,6,76,0,185,9,40,0,44,0,212,254,24,1,147,255,149,255,34,252,211,255,246,3,47,236,1,0,87,255,25,0,201,255,172,254,85,254,91,2,206,0,151,0,104,1,56,1,212,255,150,255,2,2,171,2,98,0,3,13,19,0,150,255,106,0,201,242,85,0,95,255,168,255,8,0,12,0,93,255,183,0,119,254,117,0,13,255,14,254,196,255,36,1,190,254,199,247,152,3,45,1,41,0,237,255,114,255,75,246,119,2,223,254,175,252,132,0,32,3,1,255,122,254,137,0,174,252,101,254,41,0,163,255,51,222,9,0,231,255,134,0,190,255,222,0,152,0,59,0,29,0,63,255,127,255,151,255,39,0,235,255,188,0,111,0,25,0,253,255,0,0,177,255,203,34,232,255,238,255,37,0,223,255,214,255,87,0,212,255,56,0,177,255,189,255,204,255,18,0,124,255,133,7,53,1,145,0,69,254,255,4,200,0,191,4,25,1,15,13,55,1,134,1,102,255,137,255,245,253,19,0,239,253,190,0,16,1,29,2,119,254,22,1,161,0,13,0,161,0,123,3,191,255,57,255,160,250,162,254,127,250,84,1,67,8,47,255,155,9,30,0,3,254,141,0,11,0,211,253,232,249,136,248,22,255,76,0,19,3,221,10,45,0,98,255,74,1,145,253,143,2,179,252,49,254,137,255,4,255,213,254,108,248,145,0,17,0,73,255,185,255,98,0,67,0,145,0,122,255,168,255,251,255,204,241,3,0,34,0,231,0,213,3,33,0,71,252,109,254,129,0,215,0,245,255,109,0,68,255,51,0,56,20,167,255,143,255,60,0,118,255,162,255,142,0,216,0,66,1,223,255,94,1,227,254,182,0,92,0,240,255,12,0,15,0,126,0,229,255,5,0,156,235,102,255,13,0,109,0,18,0,186,254,255,254,118,0,57,1,86,1,241,8,221,255,234,255,115,0,0,255,164,244,68,0,187,4,203,0,33,253,132,254,122,255,249,0,10,2,109,0,208,255,6,236,32,0,214,255,85,0,157,255,9,1,69,255,163,255,117,1,85,1,2,255,16,0,135,255,164,255,252,254,176,255,254,255,190,254,234,0,160,255,238,244,230,0,146,0,248,254,41,243,103,255,41,0,163,254,107,255,158,255,140,0,141,255,116,2,245,255,36,1,4,0,90,255,82,0,60,238,116,0,233,255,201,254,100,2,178,254,195,1,3,1,47,2,64,1,245,254,5,2,117,255,90,255,126,0,27,0,167,255,100,255,14,0,63,0,253,255,31,0,109,0,213,255,10,0,254,225,36,0,233,255,73,0,129,0,0,0,140,255,66,0,5,0,137,0,239,255,219,9,203,0,175,1,87,245,175,0,28,2,198,1,81,255,215,254,196,255,92,1,53,0,176,2,207,255,133,0,184,255,200,0,164,254,136,0,114,255,45,247,25,244,196,255,31,253,48,0,181,254,85,0,122,255,218,0,62,252,234,254,108,255,203,251,125,255,53,0,129,255,39,247,82,0,225,255,250,254,226,0,127,254,83,0,244,2,101,245,20,254,141,255,151,2,200,254,240,0,194,254,205,252,224,11,75,255,148,0,165,0,120,1,92,0,23,255,188,0,156,255,134,3,111,254,237,3,204,255,162,0,219,0,39,7,188,255,190,255,217,216,166,255,233,255,39,0,165,255,25,255,23,0,174,0,42,0,79,0,199,255,198,255,18,0,175,0,32,0,122,0,71,255,10,1,162,0,44,1,170,243,203,242,253,255,200,254,178,0,232,255,22,255,248,0,68,0,37,1,104,1,110,255,226,255,254,255,177,0,113,0,65,251,230,253,238,254,79,0,254,255,239,255,231,10,71,0,236,250,93,0,206,252,210,253,181,254,115,0,215,0,165,253,54,255,113,0,169,255,39,0,235,254,236,13,75,0,68,254,201,0,111,0,143,254,208,251,212,0,236,254,190,254,28,254,68,253,37,0,210,254,177,0,86,0,10,0,169,255,56,0,76,0,19,221,229,255,183,255,123,255,205,255,150,255,228,255,204,255,49,0,68,0,26,0,16,0,175,255,89,254,18,11,7,0,202,255,149,255,144,0,28,241,17,0,157,254,3,0,224,255,232,255,14,0,76,0,169,0,252,254,93,1,97,255,107,14,72,255,249,16,210,255,146,0,242,255,143,0,128,254,181,255,12,0,144,0,105,0,47,0,141,0,224,255,225,255,48,0,187,0,74,0,139,0,132,0,86,0,241,255,195,254,245,254,40,12,29,7,149,254,131,255,128,251,218,254,63,254,21,1,127,4,171,254,12,0,215,255,210,0,205,255,6,0,18,0,53,0,11,0,37,0,220,255,186,255,65,0,44,0,122,227,15,0,123,255,56,0,150,0,63,0,3,2,15,1,224,255,47,0,41,0,126,255,168,0,98,255,17,255,196,255,226,0,247,0,175,253,19,255,25,242,65,0,111,2,16,0,44,255,26,0,75,255,81,0,83,0,26,0,231,255,164,255,251,255,36,0,225,255,21,1,249,254,135,0,78,0,83,255,220,0,116,235,191,8,160,255,237,255,161,255,75,0,231,255,192,255,244,0,102,255,170,245,66,254,212,3,0,2,136,1,110,254,230,251,20,1,56,254,202,250,71,7,124,2,24,250,234,0,199,0,237,0,107,1,66,0,28,1,198,0,235,254,245,254,228,253,183,254,88,3,30,254,123,253,178,0,16,255,78,255,233,25,251,255,127,0,176,255,89,255,51,1,7,0,248,0,13,0,53,0,124,0,215,0,202,254,255,0,62,255,6,244,234,255,196,13,51,0,193,0,165,0,82,0,176,255,54,0,65,255,234,254,237,255,123,1,29,1,198,255,99,255,88,255,73,255,132,1,58,255,191,0,107,0,10,0,254,255,252,231,45,0,198,255,48,0,106,255,184,255,112,0,132,255,215,255,127,255,36,0,190,255,17,243,4,240,15,0,245,255,93,0,202,255,72,0,151,255,131,0,66,0,29,0,202,255,201,0,46,255,221,0,47,0,55,0,157,255,31,0,214,241,217,241,81,255,91,0,203,255,40,0,158,255,180,255,224,0,15,0,172,0,85,0,103,0,109,255,121,255,42,255,199,254,24,5,143,0,190,0,19,0,34,246,165,255,88,255,107,3,229,255,21,3,23,3,50,254,144,3,188,253,70,0,243,5,19,3,106,255,55,2,157,10,251,255,127,11,149,255,155,0,32,0,65,0,158,0,133,0,65,255,212,255,141,0,107,255,199,0,177,0,14,1,242,255,199,255,171,241,51,15,98,255,239,0,239,255,52,0,244,0,169,254,138,255,186,0,202,255,122,255,106,0,123,255,140,255,186,0,107,255,130,252,234,255,113,254,1,0,32,1,108,240,252,254,113,0,66,0,236,254,179,0,30,255,119,0,164,1,51,0,29,254,39,2,129,0,245,0,221,7,127,2,169,255,194,19,41,0,203,255,140,255,126,255,33,255,152,255,8,253,20,1,117,0,82,1,119,255,23,255,191,255,119,0,100,0,83,243,2,0,37,15,126,0,172,0,254,255,184,255,103,255,200,0,147,255,194,255,135,0,194,0,174,255,106,255,98,0,38,2,5,255,238,254,71,0,160,0,121,0,243,255,147,254,100,1,44,255,241,254,203,19,53,255,5,255,222,0,75,0,125,255,17,0,103,0,113,252,164,254,230,255,6,0,110,0,120,0,123,253,99,1,119,253,124,255,168,242,65,0,58,250,205,1,147,255,2,1,241,255,192,255,11,0,182,255,160,255,39,0,184,23,16,0,46,0,41,255,137,0,77,0,128,0,61,255,64,255,169,255,96,0,123,1,183,255,111,1,181,1,146,254,84,0,101,255,227,255,187,255,195,255,222,255,127,255,4,1,79,255,154,14,227,2,35,255,242,255,216,255,2,0,29,254,243,254,104,10,166,0,29,0,0,255,30,0,92,0,51,0,111,0,211,255,53,15,90,0,226,255,157,255,12,0,74,0,201,0,204,255,160,255,60,255,171,255,220,255,123,0,212,255,188,255,2,0,218,33,33,0,215,255,24,0,244,255,204,255,69,0,59,0,229,255,38,0,108,255,201,255,236,255,196,255,50,0,35,13,30,0,165,14,164,255,228,0,173,0,17,255,89,255,181,255,177,255,170,255,39,255,32,0,34,0,119,255,243,255,17,0,128,255,74,250,86,255,32,255,119,254,201,242,37,251,209,255,24,0,33,255,26,0,55,1,169,254,209,255,16,3,203,1,220,253,46,2,215,3,103,0,13,1,32,0,13,0,19,0,172,255,219,255,227,255,209,255,114,231,7,0,48,0,156,255,13,0,11,0,241,254,170,255,115,0,239,255,183,0,175,12,248,242,57,0,189,255,139,255,169,255,19,0,74,0,241,254,237,0,232,255,242,0,49,0,77,255,42,1,85,0,187,255,72,1,18,255,222,255,103,0,206,255,79,0,2,0,229,255,240,255,153,255,195,255,236,22,151,255,250,254,74,0,182,255,98,255,7,1,146,255,154,0,212,0,253,255,172,255,130,255,25,0,189,255,59,246,244,255,221,255,139,0,3,1,161,255,115,255,137,0,90,0,12,0,12,255,114,255,58,1,15,0,132,255,1,0,231,255,229,255,254,255,250,255,28,0,208,255,239,255,254,255,43,0,67,0,42,0,63,35,231,255,19,0,243,255,233,255,213,255,73,0,226,255,143,0,255,255,68,11,114,255,252,255,221,13,207,255,146,254,110,0,58,1,19,0,201,255,107,1,204,0,213,1,189,0,217,0,75,255,119,0,41,0,123,255,29,0,201,255,162,255,71,0,207,255,41,0,85,0,242,255,252,23,71,0,114,255,10,0,18,0,169,0,136,0,26,1,207,255,36,0,190,1,157,255,7,1,92,0,153,8,129,255,43,0,113,255,162,254,36,0,133,1,48,255,15,0,230,241,237,254,127,1,63,6,77,255,79,255,180,251,252,255,67,0,218,255,2,0,22,1,39,0,107,0,136,255,209,1,204,0,115,254,49,1,160,1,7,0,250,254,68,0,37,9,189,0,181,255,233,255,25,0,236,255,182,255,56,0,213,255,131,255,170,0,253,1,63,0,26,0,7,1,27,253,225,255,8,0,216,254,101,0,20,0,107,255,30,11,38,255,123,1,202,254,151,0,133,3,84,0,171,255,173,255,125,254,161,0,226,243,98,255,74,254,38,0,191,0,198,255,54,255,127,0,126,0,168,255,82,254,251,243,219,248,180,254,61,0,104,255,242,255,224,255,100,255,251,255,137,254,197,251,246,235,110,0,77,0,55,255,241,255,4,0,13,0,86,0,119,0,67,0,149,0,80,0,8,1,3,255,135,255,63,0,193,0,153,255,127,255,63,0,120,0,30,255,156,255,124,12,72,0,245,255,8,0,200,255,23,1,183,255,64,255,47,0,169,255,125,0,213,255,148,255,21,1,188,0,149,255,33,1,78,23,236,255,209,254,178,255,235,255,40,0,117,255,44,0,28,0,6,0,2,255,12,255,47,0,255,255,105,255,29,0,168,254,242,246,30,0,73,241,114,0,84,0,101,255,85,0,166,255,155,0,111,0,6,254,6,0,197,1,15,255,215,0,131,0,222,252,15,0,169,254,176,0,82,254,251,0,182,255,6,0,215,255,212,255,125,255,151,255,8,255,90,1,39,0,84,238,93,0,136,255,177,255,247,252,96,254,198,253,35,255,21,0,28,0,204,255,56,0,71,0,69,255,133,11,29,246,154,2,31,3,119,255,202,3,243,0,73,253,108,255,231,254,70,1,194,1,34,253,157,255,226,247,112,0,173,255,166,255,178,255,6,1,118,255,225,255,251,255,182,255,85,255,157,255,88,1,143,0,195,15,56,0,135,255,103,252,248,255,46,0,224,17,97,0,37,255,222,255,123,0,212,255,255,255,85,0,220,255,143,1,252,254,25,255,132,0,194,254,55,0,75,255,156,0,235,243,142,0,247,255,166,242,225,255,43,0,126,0,136,0,53,1,206,255,236,255,170,0,166,255,188,0,83,255,175,0,50,0,144,0,12,255,22,0,64,0,36,254,234,255,190,255,16,1,255,14,203,2,68,255,174,255,6,255,181,253,10,0,112,1,5,254,242,0,216,255,237,253,195,1,35,0,48,2,149,255,138,0,15,0,113,0,56,0,242,0,33,0,233,255,229,255,81,0,99,255,45,1,185,254,103,1,64,14,62,0,47,250,89,255,136,0,217,255,183,0,53,0,105,255,240,255,196,255,191,255,194,235,239,255,255,254,246,255,56,0,152,255,201,2,254,255,72,1,72,0,97,1,43,0,205,255,195,232,40,0,32,0,174,255,220,255,234,255,57,0,56,0,55,0,112,0,152,255,76,0,5,0,80,0,227,255,173,0,152,254,143,255,42,0,137,255,180,0,230,255,120,0,250,0,48,244,198,0,115,0,116,255,22,0,136,0,19,1,186,2,107,255,187,2,170,1,36,255,23,1,63,0,55,0,193,255,148,255,205,255,186,255,186,255,163,1,100,255,238,22,33,0,199,255,142,255,124,254,43,255,92,255,7,6,117,0,165,0,152,7,223,0,173,255,46,0,201,0,12,0,153,255,228,0,139,0,49,255,136,0,62,251,224,253,45,253,90,0,116,253,25,3,255,255,156,255,224,255,20,255,49,0,164,0,138,0,16,0,82,0,107,243,194,255,88,255,62,0,199,254,98,0,116,253,28,254,172,2,165,255,33,0,146,244,131,242,54,2,34,0,35,0,104,0,13,0,189,0,235,0,207,255,188,254,126,0,226,0,154,255,123,0,3,255,109,254,38,0,160,0,251,255,100,0,226,255,16,0,237,255,212,255,2,0,186,255,226,255,82,0,118,0,6,0,132,0,241,255,220,255,59,0,125,221,64,254,123,14,68,1,87,0,67,0,146,255,114,0,180,255,38,1,98,1,7,0,140,0,11,0,84,1,139,255,209,253,67,0,129,0,201,0,198,254,72,1,47,255,102,0,135,255,122,1,110,236,140,0,53,0,15,0,3,255,242,255,158,1,73,255,186,255,231,255,205,255,34,0,165,254,85,255,146,0,158,255,155,255,253,255,157,255,96,0,66,0,50,0,251,255,141,255,233,255,211,255,161,254,150,239,143,0,224,1,210,255,140,0,17,0,88,231,146,255,233,255,150,0,60,0,217,255,247,255,208,255,196,255,248,255,236,255,37,0,57,0,94,255,60,0,119,255,55,0,155,255,65,0,100,0,8,221,3,0,207,255,253,255,247,255,28,0,15,0,167,255,120,255,59,0,125,0,183,255,221,255,145,255,187,255,228,255,111,0,240,255,48,0,27,0,56,36,55,0,34,0,164,255,66,0,3,0,3,0,218,255,12,0,59,0,95,0,156,255,3,0,51,0,121,0,146,0,56,255,142,0,2,255,65,0,3,0,87,255,248,255,191,255,44,0,10,0,15,0,157,255,56,0,250,255,148,255,236,255,171,234,167,255,139,1,37,8,230,1,208,255,68,1,166,1,137,241,212,1,198,0,239,0,0,0,235,254,141,255,29,255,227,0,227,255,159,0,128,255,65,254,221,254,95,248,146,255,25,0,226,8,141,0,177,0,204,0,38,0,254,254,90,0,248,255,125,255,180,245,55,0,49,2,157,255,36,255,223,255,142,0,178,254,96,255,139,255,244,255,223,255,6,0,72,0,253,255,245,255,50,0,1,0,211,255,8,0,23,0,241,255,223,255,241,255,30,0,224,255,107,0,145,0,14,0,60,0,114,0,45,0,24,0,107,34,247,255,61,0,192,0,16,0,124,0,46,0,202,255,225,255,89,0,109,255,144,255,13,13,117,254,91,0,189,254,45,0,100,255,25,0,238,255,34,0,234,253,118,0,83,0,69,255,164,255,180,0,34,0,147,2,135,0,103,0,218,246,54,0,6,0,179,0,40,0,143,0,232,0,238,240,55,255,179,0,32,0,200,255,150,1,20,255,29,2,186,255,168,255,135,255,191,1,212,11,33,255,138,0,211,253,230,0,129,13,96,0,252,255,234,255,243,255,120,255,211,255,133,255,248,255,107,0,14,1,132,0,192,255,224,255,208,1,223,255,212,255,16,246,5,255,10,255,185,255,33,240,40,0,107,0,128,1,234,255,59,255,64,0,166,0,119,255,212,255,98,0,221,255,193,0,4,0,201,247,57,0,147,255,245,0,159,13,201,255,196,255,21,0,187,0,245,254,23,1,3,0,166,0,178,255,108,0,121,255,126,0,134,255,171,0,123,255,235,255,122,255,183,0,25,0,200,255,190,231,107,0,109,0,22,0,163,255,39,0,95,0,43,0,245,255,212,255,251,255,174,255,6,0,202,255,229,255,140,255,240,255,84,0,44,0,22,0,188,255,255,255,199,255,78,0,35,0,83,0,56,18,46,0,1,0,92,255,229,12,154,254,83,241,236,0,104,0,175,255,135,255,234,254,144,255,236,255,89,0,133,255,35,0,113,0,17,0,181,254,17,1,84,255,125,0,183,255,77,0,211,9,152,240,86,255,169,255,174,0,84,0,142,0,138,0,13,0,227,0,127,0,146,0,141,0,196,0,38,0,216,255,144,255,136,0,7,9,72,1,87,0,234,255,179,255,222,255,61,255,58,0,179,254,81,1,97,255,114,2,64,244,152,1,11,2,196,254,27,2,181,253,175,255,248,244,98,0,200,0,101,2,149,255,86,255,90,251,97,4,9,2,229,0,39,255,143,0,144,0,32,251,128,254,255,5,214,1,113,253,236,1,83,254,230,255,124,255,76,255,52,0,97,0,10,0,221,255,196,255,7,0,210,234,230,255,154,0,124,255,35,255,124,0,136,0,239,255,188,255,25,0,29,0,4,0,5,0,241,255,9,0,69,0,240,255,209,255,180,255,5,0,41,0,6,0,234,255,63,0,248,255,237,37,223,255,138,2,223,253,97,255,81,0,181,255,54,0,164,255,207,255,176,255,14,0,178,255,111,255,113,254,161,240,186,0,136,251,207,0,60,0,30,1,82,10,44,0,117,0,174,14,102,255,170,1,75,1,153,253,40,255,15,1,135,255,147,255,239,1,42,0,45,3,237,255,33,2,107,255,121,2,136,246,215,247,9,1,120,255,198,255,4,0,228,255,147,0,2,0,133,255,163,255,14,0,206,255,61,1,131,0,126,255,104,255,66,1,255,3,92,241,20,241,151,255,16,0,234,255,249,255,112,0,242,255,52,0,28,0,214,255,143,255,132,0,175,255,248,255,144,255,19,0,33,0,5,255,117,0,223,255,247,255,243,255,228,255,60,0,226,255,29,0,27,0,198,255,249,255,4,0,43,0,132,216,218,255,253,255,48,0,3,0,233,255,202,0,81,255,54,255,71,0,161,247,3,0,174,255,218,255,143,255,141,0,38,0,190,255,138,255,218,255,242,255,148,0,248,254,143,0,243,255,200,255,247,255,235,255,228,255,226,34,233,255,53,0,216,255,30,0,72,0,210,255,26,0,66,0,22,0,32,0,44,0,22,0,206,255,190,255,141,255,115,255,24,0,59,244,124,242,236,1,207,0,194,255,201,253,134,0,230,255,192,255,31,1,87,1,43,255,42,0,238,254,112,255,112,255,179,255,230,255,217,255,4,0,252,255,42,0,43,0,30,0,240,255,34,0,113,0,75,36,85,255,239,255,24,0,203,255,229,255,45,0,42,0,21,2,146,0,191,255,32,0,156,0,112,255,5,11,121,3,249,255,102,2,11,0,1,0,39,254,178,1,147,2,189,254,112,246,23,0,118,255,186,253,180,1,104,255,226,255,29,0,222,254,210,254,55,12,240,1,14,0,166,254,186,255,201,1,72,248,27,255,53,0,227,247,199,254,58,0,33,0,165,255,81,255,141,0,168,10,160,12,154,247,245,0,114,255,13,0,194,254,70,0,104,255,192,255,132,0,190,254,44,0,30,0,186,255,72,255,177,1,231,255,159,255,13,248,145,0,47,0,128,2,179,0,71,254,48,0,148,255,206,6,232,254,33,0,69,243,79,0,109,255,68,1,176,255,65,0,48,0,90,0,249,255,235,255,22,0,3,0,56,0,226,255,14,0,254,255,145,255,22,0,248,255,196,223,153,255,220,255,57,0,53,255,31,1,55,245,36,255,143,0,11,0,243,241,21,0,175,255,62,0,157,255,41,0,84,255,108,0,29,0,95,1,142,254,15,0,134,255,49,255,19,1,163,255,56,245,144,1,44,255,225,0,230,0,17,255,54,242,183,255,211,0,32,1,85,0,250,255,134,253,57,0,178,255,105,1,107,255,205,248,233,255,17,0,219,255,185,255,82,255,19,255,42,0,234,255,13,255,63,0,155,255,131,0,35,0,136,0,71,240,41,0,250,254,199,255,197,0,222,254,51,1,35,0,240,255,3,0,251,255,45,0,249,255,1,0,209,255,41,0,237,255,79,0,78,0,42,0,171,255,74,0,98,254,160,6,191,2,41,1,32,243,108,0,222,253,105,4,44,0,191,1,79,254,59,1,12,252,133,0,141,0,27,4,89,2,238,255,236,253,226,255,200,2,129,255,46,255,10,0,138,9,161,255,210,255,242,255,77,0,32,0,245,255,10,0,153,255,241,255,125,2,196,255,96,1,182,2,54,255,28,1,108,234,92,0,174,255,5,0,140,0,202,255,141,255,45,0,31,1,242,255,205,254,170,254,10,0,75,255,50,0,226,255,250,255,160,39,77,0,42,0,13,0,26,0,236,255,34,0,10,0,37,0,219,255,209,255,90,0,251,255,212,255,171,255,192,255,205,255,255,255,16,0,104,255,165,255,212,0,4,0,231,255,19,255,20,232,22,0,136,255,255,255,171,0,239,255,213,255,141,0,243,255,199,255,71,255,80,0,17,1,19,254,178,0,45,0,11,0,199,255,16,0,233,255,226,255,219,255,82,0,4,0,243,255,126,255,98,0,16,1,62,254,95,255,133,0,240,19,14,0,224,17,63,255,11,0,55,0,226,255,1,0,123,0,247,254,172,255,172,254,238,255,152,0,232,255,246,254,33,0,166,255,148,255,129,253,126,6,43,1,242,255,123,254,71,18,30,255,21,0,55,1,218,254,159,0,47,255,172,0,184,0,36,1,139,254,169,0,84,0,55,0,243,254,173,5,206,255,41,0,68,0,247,255,194,255,35,0,23,0,124,255,96,0,58,0,134,255,140,240,194,254,210,0,139,255,166,2,152,255,122,1,182,252,61,0,245,9,37,0,149,0,0,254,70,0,101,244,225,0,101,254,230,0,42,255,185,2,198,255,153,252,231,254,128,255,52,255,219,255,128,255,51,0,82,255,107,254,241,1,153,238,37,255,124,0,136,255,63,0,135,0,201,0,134,255,77,254,91,253,221,0,138,0,230,1,23,2,81,12,165,0,11,0,237,254,94,0,156,255,69,0,52,0,189,255,26,253,212,0,16,0,163,255,84,254,95,3,239,255,95,246,255,2,221,255,126,255,97,0,107,5,34,0,72,0,233,255,239,255,29,11,166,255,185,255,213,0,35,1,87,0,58,3,193,255,189,0,129,2,0,255,64,3,39,8,57,255,86,255,63,255,194,255,249,255,37,0,196,255,75,239,213,255,24,0,187,255,62,2,93,255,143,255,7,1,170,255,45,0,171,0,51,4,102,255,217,255,121,0,74,0,124,255,182,0,34,0,13,0,234,254,215,255,96,0,204,2,35,255,142,253,181,4,244,0,161,254,74,15,178,255,224,255,17,11,106,255,219,255,95,0,29,255,172,255,152,242,57,0,238,0,113,255,147,254,39,0,27,0,18,255,205,254,86,255,124,0,66,0,123,255,40,0,62,0,237,255,42,0,190,255,2,0,176,255,254,255,60,0,7,0,10,0,7,1,133,236,187,255,123,254,62,0,203,255,190,255,24,0,169,255,13,0,34,0,241,255,231,255,236,255,197,0,9,0,101,0,173,255,177,255,100,255,156,255,2,0,148,255,55,22,99,255,110,3,64,249,32,0,72,0,190,255,70,0,254,255,210,255,93,255,206,0,17,0,247,0,158,11,190,255,74,5,79,1,238,0,7,255,102,254,215,253,98,1,215,255,132,0,160,255,68,0,126,8,183,254,198,255,180,255,6,0,17,12,28,1,238,254,114,254,215,1,27,1,171,1,36,255,81,0,116,10,40,0,233,255,210,255,251,0,109,0,13,244,50,0,231,255,217,253,124,0,123,254,228,0,95,0,56,0,216,250,177,255,3,4,182,236,151,255,174,255,13,0,97,255,52,0,155,255,23,0,36,255,179,255,103,255,113,0,230,254,42,0,185,0,112,255,110,254,46,0,112,255,157,255,210,244,152,242,254,255,16,0,224,255,23,0,231,255,111,255,181,0,49,0,6,0,20,255,30,255,228,255,234,0,230,255,167,255,242,255,157,254,146,0,117,0,206,255,76,0,246,255,185,1,161,255,254,255,90,1,14,255,95,241,116,3,207,254,72,255,94,1,18,0,219,254,184,254,1,1,109,0,49,0,157,0,212,255,186,255,35,0,6,0,89,0,11,240,89,255,249,254,197,255,35,0,243,255,174,1,44,255,17,0,150,253,251,255,248,220,114,0,41,0,73,0,171,255,122,0,5,0,38,0,19,0,196,255,14,0,220,255,214,255,167,255,20,0,85,0,239,255,20,0,26,1,188,242,231,255,138,14,151,0,73,255,100,0,106,255,19,0,35,255,126,0,34,0,235,255,72,0,28,0,138,0,166,255,30,0,162,0,46,0,40,0,27,0,15,0,201,255,235,255,38,0,55,0,32,0,83,0,203,37,31,0,26,0,254,255,4,0,96,0,205,255,120,0,124,255,213,0,58,8,39,0,5,255,98,0,244,245,83,254,181,254,156,5,30,8,79,1,131,254,115,1,43,1,83,1,44,1,115,255,157,255,209,254,136,11,49,0,93,0,40,0,147,240,211,255,50,0,41,255,73,0,217,255,91,255,229,254,46,0,133,255,165,254,23,0,98,255,41,0,20,0,41,0,210,255,19,0,34,0,86,0,190,221,40,0,20,0,224,255,226,255,240,255,77,0,72,0,252,255,92,0,222,255,103,0,179,255,128,0,236,253,198,254,24,0,216,2,49,0,220,255,78,255,76,0,22,0,242,255,92,255,62,255,69,0,61,12,239,3,126,255,232,254,198,9,226,1,254,255,45,0,194,255,249,255,162,255,17,0,23,0,252,255,44,37,229,255,11,0,22,0,54,0,243,255,2,0,254,255,6,0,234,255,193,255,67,0,82,253,130,0,124,247,132,255,57,0,195,255,98,255,36,13,6,2,4,0,59,1,145,254,153,255,217,254,3,1,171,253,56,0,250,255,72,0,170,255,211,255,243,255,209,255,243,255,229,255,253,255,48,0,244,255,204,255,250,255,242,255,230,255,240,255,222,255,82,37,80,0,91,0,242,254,1,0,135,255,117,0,33,0,8,0,40,0,157,255,177,255,43,0,133,242,164,255,186,255,199,255,43,0,68,0,64,0,28,1,129,253,202,1,118,0,202,255,61,245,114,1,190,255,54,0,27,0,58,255,75,1,115,0,216,255,47,255,200,254,82,0,240,255,8,0,230,0,212,0,61,7,162,255,165,7,138,255,153,0,243,255,183,255,71,0,116,0,184,255,43,243,106,0,19,0,135,255,177,0,212,254,199,1,227,255,94,0,190,0,235,255,248,255,201,0,16,0,2,0,83,0,120,231,32,0,238,255,59,0,238,255,215,255,124,255,22,0,1,0,217,255,44,255,58,255,186,0,82,12,154,255,135,13,232,254,138,255,124,255,124,255,63,0,237,255,97,1,232,255,179,255,224,0,82,0,143,0,191,255,165,0,240,255,66,241,215,13,228,255,212,255,93,0,211,255,243,255,232,255,251,255,216,255,58,0,3,0,89,0,71,0,113,0,46,0,62,0,44,0,160,0,179,255,248,255,197,255,151,230,134,0,214,255,183,255,0,0,85,0,2,0,16,0,34,0,157,0,222,255,196,255,78,0,24,0,64,0,96,0,222,1,231,0,131,255,39,255,13,0,21,0,44,0,83,0,198,0,187,255,21,0,89,255,204,255,245,15,22,255,119,254,17,0,66,254,158,254,228,255,42,0,53,0,219,255,28,0,15,0,240,255,246,255,171,255,255,36,240,255,167,255,169,255,200,255,52,0,159,255,86,0,249,255,153,255,244,255,71,0,217,255,17,0,216,255,23,0,63,0,65,0,237,255,242,255,150,255,29,0,235,37,255,255,244,255,1,0,170,255,100,0,7,0,73,4,10,1,252,0,197,0,192,255,42,255,59,255,228,255,3,15,215,249,54,1,139,255,82,2,13,0,90,0,203,254,128,254,134,0,166,255,62,255,196,254,68,11,156,0,71,255,196,0,153,255,75,0,241,3,69,0,0,3,181,255,163,253,48,250,133,1,242,0,112,1,22,1,134,255,60,246,121,0,7,0,209,254,91,0,246,255,58,14,23,0,147,255,243,255,138,0,107,254,18,0,213,255,3,0,42,0,194,0,144,255,237,0,63,247,23,0,40,1,173,255,242,255,198,255,93,255,248,255,82,255,17,255,85,0,148,255,174,255,177,255,88,1,236,0,85,254,127,0,52,0,24,9,183,0,116,6,117,252,67,244,49,5,195,255,47,254,0,0,59,254,171,249,223,0,232,0,197,255,254,0,200,254,139,255,197,255,35,254,168,245,104,251,29,255,111,248,194,3,141,0,47,250,81,3,93,0,252,250,232,3,39,1,192,0,117,255,44,254,32,253,76,254,107,8,115,1,171,9,164,254,88,3,63,248,38,0,94,0,240,1,246,2,186,3,13,255,134,0,33,249,235,1,130,250,90,4,6,246,65,254,76,253,176,247,44,0,101,252,74,6,19,3,150,0,12,254,114,13,70,253,20,1,251,253,237,249,123,1,184,255,42,3,163,250,81,11,168,3,182,253,74,254,157,3,89,7,93,254,211,0,188,6,209,2,117,3,102,2,253,0,101,2,96,250,253,1,74,3,153,246,40,255,27,249,195,1,139,5,87,2,177,2,193,5,81,255,98,244,9,252,191,7,188,255,128,2,21,0,140,0,241,250,212,253,167,255,188,252,206,2,169,254,145,248,187,1,246,1,216,251,48,5,86,0,1,8,211,4,130,0,124,3,81,4,180,2,104,244,13,253,217,1,167,1,165,250,16,248,93,7,227,255,252,253,162,251,29,1,226,1,164,0,116,248,83,253,205,252,183,2,203,2,16,250,20,5,92,251,135,255,59,255,119,239,115,255,255,4,43,1,208,0,47,4,20,0,4,3,180,2,19,2,1,1,172,1,78,0,202,0,113,254,229,255,25,3,126,4,32,253,132,1,126,248,155,0,102,254,85,0,111,4,67,3,133,0,168,255,65,0,62,0,234,253,120,255,18,238,94,255,56,252,98,5,67,254,247,244,163,255,249,253,146,1,12,0,170,251,131,253,3,253,210,0,255,246,142,2,191,1,26,0,247,254,165,255,71,0,138,252,126,0,147,255,7,0,90,1,19,0,55,253,255,254,6,3,56,4,189,253,185,0,200,0,197,233,29,2,228,0,168,1,37,0,0,2,178,255,55,255,80,3,143,254,75,4,23,252,214,0,176,254,10,1,198,9,47,6,173,247,114,253,84,246,159,255,237,252,30,253,32,4,105,5,124,0,176,3,163,242,148,4,221,253,30,255,225,4,16,6,170,4,204,254,233,1,128,251,239,2,164,255,88,255,216,243,85,250,246,7,35,0,115,1,207,249,23,2,52,1,5,0,203,255,11,2,87,255,79,2,81,255,252,251,91,0,231,2,112,255,230,0,39,7,79,255,253,1,11,5,16,7,6,243,209,252,29,255,37,254,216,251,121,253,79,0,199,4,174,0,246,255,100,254,137,1,207,254,200,4,30,5,12,0,247,253,13,251,119,7,197,8,151,1,212,2,48,251,31,248,54,2,250,1,45,254,45,3,148,2,60,255,197,241,191,9,102,3,207,253,33,1,150,2,142,2,4,254,34,253,187,254,110,2,220,0,203,254,205,254,75,255,67,254,131,0,137,249,189,252,137,253,115,3,211,0,225,2,40,2,143,252,225,243,2,253,83,2,112,0,151,0,103,251,89,2,223,1,242,255,37,0,98,252,7,254,38,4,37,249,225,252,78,255,213,253,205,9,74,253,232,252,150,2,225,2,79,3,75,6,141,1,189,255,122,255,218,1,53,247,138,10,11,255,6,8,67,6,11,5,164,4,40,0,251,2,40,255,18,6,215,254,23,249,154,1,246,4,65,4,184,1,57,252,38,1,219,255,14,1,215,1,7,5,189,14,148,255,158,253,237,254,214,254,14,1,128,254,24,8,93,253,234,3,174,0,18,0,171,0,192,2,239,12,151,255,18,249,108,0,255,1,71,244,187,255,31,2,29,255,84,251,151,5,193,255,6,0,255,4,255,255,159,2,239,0,177,247,124,248,90,252,168,0,212,254,51,4,47,4,16,12,178,253,159,5,73,1,49,4,127,0,250,2,125,255,18,1,69,3,122,255,158,253,113,254,121,250,23,4,100,255,159], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1834545);
/* memory initializer */ allocate([1,253,2,186,2,172,1,20,253,241,0,126,239,152,0,195,252,16,4,87,252,145,0,172,252,171,255,115,244,126,255,106,254,214,2,168,0,219,255,215,250,211,251,25,251,135,4,39,6,40,2,137,2,95,248,239,255,3,4,54,4,127,254,55,245,215,253,55,255,58,0,148,248,232,255,27,1,224,4,166,255,163,1,98,4,134,3,244,249,224,255,34,0,152,254,195,2,45,0,126,242,10,255,31,1,52,1,141,1,137,1,54,3,43,5,203,253,249,1,239,249,146,248,91,253,113,2,55,4,121,255,172,247,69,255,93,255,23,252,57,250,92,252,107,4,228,245,196,254,53,0,246,4,21,253,58,252,212,3,242,0,246,254,217,249,134,251,163,253,245,253,35,255,73,2,237,252,85,5,226,254,73,255,155,1,34,2,171,18,226,254,190,253,155,255,53,1,128,3,34,0,195,1,2,252,69,253,170,0,167,3,202,1,47,16,229,0,196,253,112,252,115,254,216,255,124,255,58,255,98,0,190,248,100,2,101,0,158,255,238,255,163,254,66,1,166,249,24,5,17,1,21,255,162,1,3,254,121,15,19,254,16,4,96,254,16,7,161,0,163,5,28,4,52,254,55,0,189,255,41,0,2,2,25,5,188,252,156,249,73,5,123,1,147,0,142,1,26,241,89,253,235,0,71,1,11,247,52,253,210,4,40,253,189,254,186,2,200,7,4,0,237,254,176,3,127,3,212,0,78,1,29,1,58,253,133,252,211,250,35,12,3,0,111,1,13,249,44,1,156,252,197,255,124,253,186,254,111,0,11,1,213,255,165,1,208,3,57,0,181,5,84,255,245,0,68,255,40,1,41,255,149,20,210,255,177,0,199,0,229,253,92,0,226,253,251,0,183,3,25,255,117,0,188,253,126,252,146,1,79,3,4,0,128,1,41,255,161,0,57,248,70,17,157,9,61,251,17,253,51,7,203,5,48,4,61,10,240,255,123,251,243,0,211,253,139,2,185,3,220,1,95,254,235,253,249,1,178,253,201,2,153,0,244,4,200,254,39,255,132,255,102,3,28,254,17,253,95,255,129,3,243,2,201,252,21,16,225,250,39,253,191,1,126,253,161,3,152,246,174,254,57,252,152,255,232,251,88,247,70,249,132,255,52,255,60,255,124,251,180,5,135,1,225,253,120,0,70,0,204,0,161,4,70,246,134,11,5,254,153,253,219,4,106,255,149,254,37,254,237,253,15,3,159,2,51,255,177,253,217,0,245,253,7,1,242,255,71,0,190,3,95,251,251,251,182,254,71,1,63,253,205,4,147,244,131,0,17,254,220,6,53,8,185,1,245,255,133,0,250,4,229,4,102,255,4,3,10,2,189,6,235,254,12,252,42,253,59,5,80,251,15,255,140,6,206,3,208,8,91,1,183,10,202,5,30,253,15,255,156,252,242,250,104,253,87,3,207,250,178,239,145,249,152,255,101,0,51,1,121,253,201,252,91,1,4,0,136,255,168,251,78,1,27,0,9,1,222,3,63,1,122,250,57,1,165,253,52,0,190,243,16,6,156,253,170,252,114,2,212,0,5,3,30,9,150,2,102,2,48,2,77,2,235,253,57,5,229,0,45,2,230,255,178,5,142,253,98,7,88,9,11,250,255,3,155,2,81,254,72,0,155,6,247,3,159,255,253,253,100,5,28,3,168,4,217,255,162,0,251,244,144,11,22,6,222,251,47,5,25,3,207,4,25,253,90,251,11,255,29,0,230,1,18,254,165,250,97,6,190,255,242,248,231,0,104,253,109,255,98,9,184,253,217,1,241,253,248,4,208,1,199,7,17,252,21,255,101,1,201,0,104,251,171,254,223,0,209,255,215,247,47,3,49,0,192,0,49,253,239,251,8,255,230,11,216,255,11,254,166,254,189,250,111,254,57,0,204,249,241,251,187,1,78,2,191,251,74,255,171,250,11,252,179,240,130,254,158,255,1,4,205,255,186,2,59,255,80,3,181,255,60,6,104,254,252,248,137,243,131,4,234,0,156,255,186,2,59,2,47,251,197,254,34,250,121,253,197,253,190,254,74,3,232,251,165,251,0,32,240,252,40,254,17,0,50,253,37,0,166,4,119,254,146,0,221,253,90,0,79,254,191,254,137,251,11,254,212,1,235,0,26,254,192,255,90,247,182,254,187,252,190,4,129,255,197,2,253,255,111,2,128,254,221,0,41,1,241,252,38,241,104,254,245,255,61,253,92,0,237,254,244,254,139,255,44,6,186,5,198,2,236,250,142,0,22,253,111,6,95,9,49,251,114,0,196,4,168,251,114,3,211,1,51,252,48,252,15,15,121,253,106,255,36,251,205,3,148,254,102,255,217,1,93,253,207,252,166,254,246,254,255,252,155,253,36,254,157,4,248,255,226,251,149,1,0,253,105,5,194,249,132,252,160,2,119,247,83,0,229,255,70,2,78,254,80,252,99,0,136,252,134,249,20,250,88,9,214,2,34,255,28,1,68,1,240,18,189,255,242,252,211,255,168,1,53,255,62,255,51,251,142,255,67,255,40,255,19,1,89,252,163,255,117,0,67,249,104,1,255,245,237,249,81,251,255,252,227,254,74,0,243,4,125,254,88,5,179,0,143,255,184,3,1,4,213,2,226,253,70,255,234,4,140,250,21,253,60,2,91,2,173,7,100,253,244,255,48,246,57,5,1,255,254,0,237,8,112,4,117,5,45,2,97,253,131,251,154,253,50,254,111,252,60,254,182,4,150,244,229,1,142,252,14,1,227,250,163,253,235,255,188,253,252,250,62,255,169,0,246,246,40,255,27,255,100,4,103,0,75,251,220,5,94,4,176,5,131,251,12,3,45,254,127,254,73,2,218,251,33,1,228,242,198,0,203,254,202,254,91,0,44,0,135,254,136,253,31,253,252,253,30,0,245,252,73,0,30,254,53,18,237,254,38,0,136,253,223,1,167,254,106,254,76,0,48,255,26,255,80,0,36,255,199,254,203,0,253,255,204,6,125,255,5,3,226,255,116,1,255,2,137,6,254,252,254,12,50,6,234,0,152,1,255,254,218,1,184,253,34,252,98,5,184,2,47,0,156,253,199,254,189,0,132,240,27,3,223,254,202,0,75,254,144,249,117,1,244,252,232,255,72,252,123,0,182,1,29,3,27,2,31,254,191,0,35,1,37,0,234,252,191,254,168,17,207,255,231,254,211,0,176,248,180,254,225,250,0,254,90,252,245,255,112,0,133,1,67,255,23,250,228,5,199,251,185,0,169,255,20,12,17,2,90,255,85,255,144,249,240,9,96,8,253,254,80,253,167,251,185,255,131,1,170,4,35,253,175,0,88,3,48,252,12,1,77,2,19,249,86,254,147,255,186,4,26,254,41,1,195,0,33,252,249,249,80,254,166,4,191,251,237,253,91,254,80,0,31,255,98,1,25,255,98,253,213,254,146,241,2,254,142,252,31,0,244,10,220,1,34,254,105,7,174,2,214,251,58,251,142,252,138,254,85,254,72,250,189,3,37,2,69,251,52,255,38,255,124,250,223,253,56,252,175,3,170,254,80,0,231,254,7,255,56,252,96,13,218,246,44,255,181,3,89,255,241,254,95,2,186,252,94,254,133,252,114,254,147,252,138,0,117,6,246,251,45,246,173,250,1,250,148,254,176,1,188,254,160,251,251,5,151,1,70,253,140,1,69,1,152,5,134,2,217,10,174,0,188,252,163,253,209,8,62,4,136,252,92,1,36,0,1,2,181,8,7,6,13,5,94,0,140,9,194,253,250,251,165,3,247,255,100,253,43,2,90,1,255,1,203,2,63,240,153,1,213,254,90,255,188,2,208,253,182,3,15,251,11,255,138,5,174,250,236,255,102,3,152,0,174,3,181,254,190,255,227,0,70,255,251,0,208,241,223,251,35,252,250,248,155,3,30,2,138,253,73,11,128,255,195,5,159,255,60,252,164,252,22,2,39,255,22,253,181,0,65,1,17,252,35,10,101,254,18,5,123,2,54,1,163,7,239,255,78,3,200,252,245,255,72,252,208,0,72,1,221,253,194,251,201,5,248,254,218,249,251,13,244,1,242,0,14,4,250,251,97,1,181,255,204,247,165,254,102,10,182,246,5,1,210,0,129,251,13,2,35,1,112,1,56,255,66,253,105,0,116,255,175,255,151,2,52,253,78,1,196,4,239,0,21,0,114,0,45,1,150,248,63,14,210,254,38,2,23,254,28,254,171,252,238,254,229,5,93,254,182,254,159,251,150,245,203,9,147,253,206,252,164,4,187,255,139,252,231,0,60,1,45,7,28,253,69,255,154,255,124,4,195,4,133,255,84,3,130,4,27,0,139,0,168,254,108,254,147,251,169,1,97,1,145,0,133,255,179,0,49,0,52,233,197,253,39,0,18,1,218,255,55,254,172,0,176,255,81,2,71,248,181,254,91,254,173,7,232,6,143,255,64,0,224,8,219,1,117,8,210,0,105,3,205,252,245,2,137,255,238,253,105,250,137,247,19,250,160,252,36,4,16,253,170,250,45,9,97,253,156,4,77,255,10,0,62,254,13,3,225,252,233,250,119,254,195,255,143,255,5,8,218,253,181,252,4,4,4,248,185,245,148,250,54,4,171,0,5,2,240,1,96,252,97,249,42,1,196,2,211,253,122,0,107,252,59,255,89,254,118,4,116,0,240,253,183,253,42,254,224,1,144,1,253,17,128,1,114,255,57,0,220,246,29,250,189,255,139,3,0,32,100,1,238,255,64,253,16,2,224,255,133,254,157,253,162,1,191,2,116,254,19,2,155,0,130,2,166,2,85,254,85,0,46,3,212,0,77,3,189,253,178,253,56,254,103,0,144,253,67,238,206,254,126,2,8,253,36,0,107,255,137,7,205,4,51,253,225,253,18,2,74,253,169,0,76,244,167,1,166,254,127,252,53,4,255,0,226,251,193,255,19,249,33,254,223,1,67,253,11,6,109,249,170,254,98,252,112,0,105,253,102,6,247,255,27,10,55,1,207,253,92,252,229,253,177,254,77,2,11,3,41,9,80,254,20,3,57,252,63,1,252,255,192,0,180,253,153,255,101,1,76,242,255,254,195,2,39,254,241,5,247,255,130,0,218,12,18,1,216,254,222,252,117,255,210,252,237,255,203,3,81,3,253,0,230,1,40,0,64,251,155,4,20,249,28,252,120,5,70,3,163,7,104,250,123,248,20,9,255,2,128,3,34,5,79,13,21,252,216,253,57,252,90,255,230,255,75,4,83,248,9,0,239,0,246,255,13,255,96,3,227,4,91,0,25,247,77,253,226,253,39,254,140,248,72,251,89,250,133,252,201,254,144,251,102,6,126,4,74,2,120,6,4,1,26,2,46,249,180,5,34,254,164,252,41,1,163,253,117,255,54,3,122,241,62,255,51,1,97,2,30,0,90,13,226,0,174,254,161,0,125,254,168,254,40,254,98,1,86,255,91,254,177,1,89,2,90,250,53,3,208,255,225,255,237,1,148,3,165,254,100,241,125,252,109,5,157,254,71,0,126,1,124,253,229,1,218,0,207,3,226,253,137,243,230,2,154,255,241,252,185,249,217,1,196,0,156,6,185,255,2,1,142,9,227,5,56,252,255,251,193,251,125,2,103,252,131,250,168,4,168,255,252,7,235,248,154,3,156,0,184,251,239,3,73,253,27,254,9,252,44,254,196,254,33,7,190,0,84,8,51,255,38,255,28,242,226,254,186,250,44,255,134,253,120,0,161,1,201,254,166,255,219,0,102,3,178,254,232,250,11,2,231,3,112,255,98,0,109,8,205,0,45,0,9,255,121,5,119,9,22,1,2,253,190,255,53,1,135,255,60,1,225,253,166,242,164,3,221,252,125,2,180,1,219,246,224,7,160,3,188,252,68,251,190,2,101,251,224,253,6,0,107,250,246,3,208,1,142,4,69,2,221,254,136,0,0,0,215,3,225,252,181,2,26,255,41,253,70,255,202,254,180,255,186,2,250,255,108,253,250,2,46,3,195,1,184,254,117,17,58,254,14,0,89,254,140,255,122,255,200,253,255,5,206,253,139,253,243,254,58,3,124,1,68,0,26,1,103,254,128,2,128,254,218,0,186,233,232,254,130,253,230,245,211,253,147,252,49,0,136,2,178,1,154,4,114,13,115,3,178,255,232,7,3,255,46,255,190,251,198,0,189,255,204,255,154,12,97,253,186,249,49,0,239,6,90,254,83,255,53,1,48,253,101,253,7,254,25,8,90,253,128,251,25,255,249,253,49,253,166,1,202,245,118,254,31,2,31,252,169,5,181,1,49,254,250,250,167,4,6,251,58,253,49,254,147,2,213,5,45,0,192,252,98,254,50,1,94,0,4,5,99,253,224,250,58,4,107,252,185,9,18,254,35,2,226,2,96,249,82,255,26,1,94,250,81,250,97,6,144,3,84,254,196,3,12,0,156,246,27,254,119,2,201,254,18,7,96,11,240,255,64,2,50,0,97,252,81,255,37,0,161,2,55,255,227,3,172,2,12,255,5,255,92,250,123,12,71,7,168,255,97,251,58,252,233,6,36,0,199,252,254,2,233,1,170,255,147,254,150,255,59,250,182,254,125,0,3,255,6,255,245,253,37,253,246,235,141,2,139,1,99,0,179,252,47,253,127,0,225,254,82,3,223,1,25,0,226,255,36,0,242,252,99,2,192,1,99,0,165,3,236,255,171,252,75,252,226,254,133,254,114,253,127,254,18,5,35,2,235,0,218,4,185,253,205,239,81,0,221,253,138,251,0,5,33,255,80,249,35,250,202,1,114,255,17,8,208,0,87,3,165,251,69,255,93,3,66,4,8,253,9,246,22,9,134,254,75,251,232,1,15,255,125,3,113,0,176,0,220,15,31,255,215,255,51,253,230,255,70,254,67,254,200,254,45,3,238,1,58,1,46,255,158,255,236,252,255,0,120,2,6,254,166,0,64,253,178,254,42,255,164,252,95,235,60,0,222,255,18,255,109,255,131,2,8,2,246,7,28,0,129,9,98,249,220,250,153,253,60,2,106,255,149,255,93,1,29,249,205,254,78,0,156,251,137,253,138,4,186,254,235,254,177,253,46,2,248,3,196,237,188,254,209,252,5,255,252,250,52,0,38,1,253,250,86,2,118,2,167,254,129,2,222,255,61,4,151,16,125,2,159,6,166,252,212,0,13,255,192,255,71,1,45,2,170,1,191,254,107,1,116,253,116,1,9,3,201,253,19,253,88,249,158,1,179,20,133,1,242,0,39,0,31,0,197,254,179,0,154,255,11,0,62,0,248,0,45,2,194,2,103,1,171,255,47,1,109,254,251,5,153,1,212,247,144,0,182,250,54,0,208,255,51,0,5,249,254,4,174,3,240,4,41,250,135,6,92,0,125,252,131,251,116,7,121,252,172,253,86,1,213,6,199,252,243,255,253,1,117,251,41,4,101,9,3,255,27,253,75,4,240,253,155,11,100,254,21,255,155,252,120,255,160,254,23,254,128,254,233,2,114,254,155,239,84,0,128,4,15,254,187,3,95,255,205,1,240,255,153,252,33,3,163,255,241,255,160,254,34,7,22,254,232,253,219,244,135,253,128,0,255,249,122,249,26,2,20,3,252,4,42,2,172,254,53,2,192,4,34,249,128,1,223,250,140,253,24,0,67,3,162,252,97,252,0,7,238,251,209,0,240,252,39,3,129,254,137,250,203,13,52,0,231,253,205,0,241,254,255,11,142,6,74,253,247,246,1,251,136,249,84,254,217,251,216,249,189,254,170,254,255,254,29,255,52,253,54,254,137,4,76,255,185,255,216,255,4,251,242,6,205,243,134,254,173,250,197,252,112,3,19,1,238,254,187,253,70,255,248,255,149,2,166,251,57,255,85,255,123,1,173,1,241,249,109,6,167,252,93,255,193,245,193,4,178,5,172,253,188,255,127,1,205,3,27,254,158,254,171,253,197,244,252,253,234,0,173,255,84,1,116,254,85,5,194,253,208,252,218,247,221,251,203,249,175,253,245,252,78,1,222,253,49,0,215,251,89,248,200,6,110,4,187,0,41,7,17,0,174,255,68,0,35,3,56,254,167,255,224,6,68,3,34,6,122,0,39,252,245,9,80,6,82,0,78,4,227,0,222,0,44,251,101,255,12,252,121,2,211,1,163,0,189,1,166,0,254,2,3,255,165,254,17,4,1,20,235,255,24,3,81,0,34,254,128,0,98,255,60,1,100,251,140,254,156,6,196,252,225,255,98,4,233,245,66,5,179,9,195,0,72,0,37,2,168,1,179,3,42,254,148,7,181,255,249,1,97,5,38,2,58,0,249,6,87,1,207,252,106,3,155,13,205,254,192,253,240,0,35,0,69,3,51,253,9,255,27,16,182,255,127,2,70,1,146,255,104,7,58,3,169,252,213,254,60,254,24,2,189,254,6,1,79,0,230,1,144,0,14,1,192,255,21,1,154,0,143,1,50,0,154,227,195,255,14,0,248,255,19,0,152,255,77,1,119,0,118,1,133,1,60,255,77,0,190,254,5,1,75,0,130,1,162,0,56,9,132,2,31,245,99,1,21,1,135,255,108,255,156,0,88,8,112,0,59,254,173,1,171,0,101,9,35,251,249,252,75,255,62,8,185,253,127,0,121,3,222,254,218,253,91,255,3,4,107,8,161,254,88,252,176,1,129,10,217,0,236,255,134,2,239,252,140,3,142,2,202,3,218,254,215,255,210,1,11,255,138,0,50,0,148,255,146,254,177,0,225,1,186,247,200,3,174,253,52,15,16,2,188,0,155,253,18,0,27,1,221,2,221,255,62,6,131,1,1,0,156,0,50,255,75,254,203,0,12,255,165,254,69,1,40,1,100,0,147,4,49,0,152,3,94,254,202,255,60,245,24,0,123,0,250,3,47,1,11,254,133,3,65,254,66,1,199,246,15,4,213,251,109,3,49,5,113,255,43,245,13,1,24,6,142,1,135,243,102,0,222,3,23,1,123,1,52,255,112,255,82,255,139,0,155,1,22,255,21,0,56,236,68,255,109,1,22,1,97,1,67,255,94,0,81,2,110,254,159,254,255,254,236,252,127,1,244,251,57,2,184,255,28,249,59,2,235,3,117,2,158,2,136,250,0,0,77,254,64,0,189,0,58,11,239,0,104,4,224,3,189,4,69,0,128,255,207,0,201,2,124,246,93,252,125,254,145,255,40,4,86,255,219,244,208,251,145,254,232,251,18,255,196,255,207,255,84,1,78,9,114,1,11,255,95,1,248,0,192,255,27,9,202,1,28,254,222,255,25,1,177,2,227,1,124,2,199,0,81,12,95,2,132,255,32,243,185,3,105,254,49,0,199,1,59,4,178,2,87,255,43,253,55,1,19,254,31,249,18,244,120,1,224,253,223,1,91,0,159,0,235,244,23,251,194,252,76,252,2,255,33,1,241,251,88,3,86,0,99,4,203,0,0,253,65,4,73,0,158,252,52,1,181,1,162,2,237,247,16,255,201,251,33,0,211,251,82,242,244,2,92,253,45,0,16,246,122,1,147,254,237,254,219,254,118,254,119,253,5,254,222,244,160,2,114,1,186,0,95,254,170,2,185,0,241,255,47,11,21,0,91,255,100,1,64,241,153,255,23,2,96,254,167,254,225,255,24,0,166,255,51,255,96,0,58,252,94,0,168,1,251,255,68,255,149,0,111,247,73,255,38,9,169,1,121,253,95,249,141,253,68,254,224,4,57,252,66,253,208,255,32,14,100,242,6,3,213,254,94,0,165,1,216,1,71,0,112,255,245,253,114,0,84,255,93,1,227,254,150,255,101,0,59,0,173,1,0,2,34,13,218,255,194,255,50,0,31,255,128,250,12,3,69,245,108,254,233,1,49,252,72,3,101,1,214,3,232,1,237,254,147,255,137,1,119,1,186,18,183,0,146,255,154,3,8,253,61,0,213,251,248,255,66,1,74,0,155,255,42,2,162,254,26,254,66,0,128,1,236,2,14,0,223,0,211,255,126,254,69,0,87,24,247,0,69,1,192,254,209,255,206,255,91,255,153,0,132,254,77,2,85,243,83,255,116,255,85,1,21,253,233,249,127,2,134,249,100,1,110,0,106,255,239,254,76,0,136,253,87,254,29,255,128,2,211,0,192,0,21,253,91,255,0,18,34,1,96,255,244,4,194,10,253,255,66,2,189,0,27,254,69,245,133,255,227,250,150,2,89,2,43,0,120,255,84,0,89,6,167,251,120,5,75,0,130,255,253,13,13,255,35,9,254,253,155,8,112,254,29,254,9,2,30,0,10,255,180,255,103,1,101,0,151,2,216,255,57,0,52,0,104,1,65,254,222,254,254,0,104,0,102,0,113,0,215,0,93,255,124,254,43,1,218,17,31,0,108,0,215,255,41,0,183,245,75,11,164,4,7,254,37,4,163,254,164,253,63,254,138,254,192,254,201,3,208,254,64,255,246,0,104,255,185,1,210,255,120,250,137,0,195,7,239,1,193,255,63,4,107,3,187,2,201,0,211,0,171,243,239,254,196,255,195,0,3,245,17,255,182,9,201,255,38,1,59,1,123,255,192,1,199,248,107,1,39,4,76,0,96,252,194,253,184,255,199,255,168,0,41,22,100,255,140,255,144,1,132,255,82,0,218,0,25,254,37,0,112,0,53,0,224,253,178,0,99,0,224,1,245,227,60,255,15,1,96,255,52,1,194,255,137,1,138,1,36,255,28,253,242,255,92,0,152,1,148,254,43,1,207,254,76,0,17,255,26,0,200,254,22,255,34,0,67,255,103,3,215,254,108,1,26,1,191,254,97,252,159,17,2,0,6,0,52,1,174,255,87,0,128,255,6,2,82,0,99,238,121,4,192,3,147,255,70,255,83,0,112,255,240,2,84,0,196,244,94,255,109,3,7,255,61,1,254,1,82,1,42,1,232,2,76,11,233,252,107,1,64,4,118,2,54,246,255,255,78,12,219,0,130,0,119,0,57,1,202,252,100,253,177,4,124,244,19,255,150,255,57,253,149,1,20,1,1,255,0,0,184,1,161,0,27,10,34,253,48,13,20,1,154,0,31,1,56,255,82,2,227,255,198,0,19,255,160,253,67,254,226,254,202,0,241,252,112,0,217,240,78,0,249,10,175,254,162,253,84,253,78,254,47,2,17,1,201,0,75,1,135,3,203,255,90,1,188,2,39,10,46,1,178,253,9,246,14,254,230,255,101,253,64,2,222,253,201,1,223,254,128,250,3,252,193,255,78,0,153,0,173,255,72,253,223,243,194,9,34,250,31,251,18,255,254,0,225,254,215,0,57,1,23,1,251,253,67,0,198,255,108,255,169,251,58,0,31,20,90,1,27,1,145,254,124,252,30,2,209,0,74,254,128,255,121,255,54,0,7,0,101,3,35,1,207,251,7,3,195,255,111,255,201,1,50,2,52,5,19,238,99,0,86,5,184,0,212,3,104,252,80,0,246,254,104,255,171,248,246,254,108,1,104,250,16,1,227,8,55,2,60,0,50,0,56,246,126,254,68,253,117,1,119,26,241,255,78,254,91,1,215,0,143,254,236,255,231,254,13,255,187,254,227,0,229,254,103,253,182,255,80,1,94,253,144,255,143,254,203,255,116,254,72,1,4,14,227,253,211,253,92,255,25,5,207,252,50,254,194,7,225,4,194,253,130,0,152,0,185,246,87,254,186,1,13,241,66,1,40,253,51,2,77,255,22,2,108,2,87,252,78,2,255,255,197,255,72,2,175,0,63,255,88,255,251,255,106,255,156,0,81,255,78,255,11,255,199,226,239,254,212,0,221,255,62,1,78,255,190,1,201,255,230,255,42,0,210,255,247,254,255,2,74,1,39,1,142,3,202,255,234,1,136,11,86,2,238,245,124,253,147,1,149,0,168,255,37,2,2,254,84,2,31,255,219,246,226,254,92,245,5,0,88,248,250,254,154,3,25,2,134,2,194,255,238,255,0,32,228,1,112,0,34,255,45,255,32,255,61,1,112,0,82,0,171,252,1,0,176,0,37,254,94,255,200,0,63,255,166,0,28,255,42,255,72,0,161,1,229,255,240,255,4,0,139,1,253,253,80,229,28,0,209,255,114,2,83,255,63,0,90,0,141,0,217,0,13,4,79,1,168,17,128,252,111,0,91,0,112,253,153,255,39,253,227,255,141,2,169,253,245,255,174,10,134,254,221,254,60,0,228,0,47,0,170,241,64,255,141,2,221,2,171,253,130,3,92,254,36,6,123,255,102,255,73,1,253,254,31,255,218,0,174,255,117,0,44,1,33,254,21,1,19,3,73,249,136,0,237,241,190,2,77,5,12,13,106,1,74,254,131,0,73,250,111,1,45,254,186,6,118,247,87,1,133,254,197,4,206,253,252,254,133,4,132,10,37,0,167,255,190,254,190,254,0,32,228,254,235,0,240,253,113,0,153,254,44,0,74,0,119,0,107,252,147,1,154,1,106,255,157,0,2,2,168,0,151,1,10,255,225,255,254,1,105,0,193,1,4,18,123,2,166,255,20,251,6,3,228,254,176,255,200,1,7,0,72,244,188,254,44,255,152,255,138,254,72,254,244,4,176,10,53,0,102,251,109,254,74,254,234,253,121,0,5,1,15,254,183,255,10,0,250,254,17,0,178,248,178,0,197,250,224,0,43,12,76,254,64,254,129,1,126,3,255,255,105,0,238,255,12,1,86,1,14,1,123,3,111,1,121,0,187,254,182,249,181,255,95,243,67,255,230,251,193,3,239,244,208,254,205,255,144,1,228,254,214,252,56,3,185,255,121,255,194,0,41,1,215,254,105,4,148,2,6,2,122,9,31,255,251,0,69,18,80,255,48,254,40,1,72,251,89,254,149,252,187,253,61,253,130,251,243,1,246,252,28,0,29,0,101,0,139,239,129,255,159,241,169,1,225,1,239,253,89,253,11,0,10,1,127,0,67,254,15,2,191,253,54,1,185,5,200,237,141,255,59,0,232,254,57,255,231,255,213,0,87,252,88,1,167,247,183,252,142,254,0,1,0,2,74,4,126,255,58,0,135,255,98,254,0,32,233,1,216,254,223,255,98,0,49,0,39,255,209,2,214,255,94,254,29,255,248,255,205,0,236,254,151,1,62,251,110,255,220,254,113,255,113,0,210,3,133,10,247,255,248,251,245,6,241,6,41,255,46,252,200,252,68,0,94,255,55,0,175,11,180,252,170,2,241,1,150,1,102,252,167,9,87,2,6,3,127,255,12,5,20,252,9,3,42,0,58,1,154,255,61,252,22,245,196,245,254,1,99,1,116,1,8,255,121,254,93,255,214,254,49,2,117,0,159,4,38,0,182,0,19,7,252,255,72,1,243,255,56,254,49,1,112,1,101,249,254,244,206,251,5,4,5,1,90,250,87,1,12,0,59,245,253,3,137,254,253,255,101,255,116,0,195,0,92,13,64,0,139,0,12,3,187,0,48,254,5,1,199,254,128,255,185,0,119,14,88,12,192,3,194,2,41,0,149,1,10,0,167,4,97,1,219,253,131,0,164,0,105,0,1,0,23,0,130,1,73,0,3,254,91,10,95,250,190,252,135,249,123,253,237,3,247,252,183,2,212,0,140,5,65,0,189,2,25,0,79,1,136,0,103,1,144,255,106,255,191,0,136,1,254,254,140,251,139,2,57,238,155,1,251,0,87,255,36,3,173,255,48,255,149,254,81,0,152,0,75,0,86,251,53,255,247,255,157,0,157,1,194,255,46,255,17,21,234,255,105,254,132,0,224,254,56,9,131,0,1,250,41,2,36,246,116,255,250,0,235,4,226,255,255,255,230,6,99,0,239,253,91,0,108,15,250,254,88,241,130,254,173,254,67,253,116,255,237,252,67,0,245,255,75,1,196,252,69,254,84,2,47,0,98,6,31,0,194,254,39,0,147,0,98,253,248,252,195,2,103,252,172,0,203,3,139,4,48,0,175,255,179,250,75,255,56,11,104,255,130,3,51,4,17,2,91,0,25,247,109,11,176,252,77,2,118,7,37,2,64,4,231,2,137,253,42,0,8,250,23,0,124,1,251,255,133,1,133,251,47,255,7,248,224,0,50,248,8,2,248,252,193,0,168,245,178,255,222,255,125,255,22,0,56,255,228,255,18,0,72,1,215,0,67,0,61,0,50,0,184,255,45,1,49,255,157,1,208,2,206,231,199,3,53,243,149,0,116,246,247,253,252,252,234,254,137,0,97,255,164,3,145,255,195,4,13,2,17,0,84,253,51,251,16,249,66,0,253,246,61,255,241,253,16,1,42,254,156,254,249,255,174,254,146,0,253,3,131,252,92,244,79,2,129,0,255,254,209,0,198,255,26,2,123,240,64,2,119,252,126,253,212,247,153,0,225,2,172,253,61,2,236,0,137,252,100,249,142,254,67,255,40,255,198,255,202,2,10,0,186,253,5,2,170,255,194,1,109,255,202,254,162,0,211,6,112,253,249,13,188,2,190,0,83,253,86,255,241,0,91,0,130,255,191,21,185,1,206,255,80,253,183,255,170,3,64,1,126,255,185,252,130,4,149,0,66,254,246,255,245,255,12,0,109,253,118,255,125,2,42,254,165,3,81,254,235,0,170,255,254,255,105,254,37,233,6,255,134,5,13,2,110,0,165,1,255,0,107,255,86,0,122,1,191,254,100,5,118,0,223,244,142,251,180,0,151,4,140,7,32,0,24,254,135,255,100,254,71,254,141,1,249,0,84,255,161,255,164,1,119,1,124,255,41,255,89,255,50,255,0,32,140,255,195,255,201,254,13,1,103,2,159,254,141,255,129,254,110,1,117,253,60,255,158,255,85,0,93,3,31,2,25,255,237,0,237,1,124,1,2,253,88,255,155,12,147,2,189,2,181,0,68,244,249,255,154,0,42,1,42,1,255,254,224,255,175,233,48,0,102,0,248,252,108,255,146,255,60,1,123,253,212,0,213,0,63,2,187,255,31,0,41,2,95,253,251,255,208,255,108,255,123,255,11,0,143,0,10,0,159,0,63,1,43,0,38,29,162,0,228,0,166,255,75,0,151,0,103,0,18,246,243,255,174,254,11,0,70,254,123,0,33,244,60,254,7,0,106,0,246,1,227,0,14,248,90,0,244,1,228,255,122,253,250,254,194,255,178,255,40,0,163,1,105,26,245,255,40,0,209,0,61,0,105,255,188,255,11,255,111,254,26,0,133,255,189,0,199,255,99,2,6,0,251,250,157,255,134,252,25,14,210,254,216,252,127,2,83,243,30,255,107,0,54,0,148,255,196,254,195,255,200,255,228,0,240,255,195,0,19,1,214,0,196,255,77,0,11,228,130,0,8,0,244,0,144,247,8,253,194,1,70,255,134,254,32,0,227,252,214,0,15,242,62,254,51,1,239,255,115,255,16,0,0,4,148,1,241,247,224,254,96,255,216,15,109,3,166,254,54,252,169,255,80,1,193,3,154,2,73,2,47,254,207,250,94,1,174,254,211,234,83,255,217,254,72,0,55,255,21,2,206,1,123,255,87,252,99,7,8,1,71,0,89,252,128,2,175,2,84,3,126,254,171,255,244,233,50,1,240,0,128,2,67,0,94,0,122,252,161,254,95,254,253,255,28,1,38,0,100,255,103,1,53,0,139,0,185,0,18,1,53,10,213,0,2,5,51,11,30,0,210,4,113,252,87,1,163,255,121,249,57,0,210,252,237,255,70,1,0,255,143,255,72,0,105,12,65,13,131,255,204,1,251,254,9,254,5,252,87,253,3,255,67,252,99,255,139,255,25,255,44,255,166,5,225,0,63,244,57,1,77,254,131,1,96,252,184,2,167,252,60,254,66,0,241,247,14,3,14,0,162,255,51,0,242,0,90,254,236,0,15,241,102,253,92,1,196,0,46,245,173,1,96,254,246,254,65,251,182,253,84,0,72,1,210,254,219,0,55,254,236,253,4,253,85,0,216,7,218,252,90,11,131,250,111,1,67,3,203,2,38,252,39,255,88,0,184,254,57,2,182,253,24,12,249,0,153,253,197,1,176,0,228,253,24,3,88,246,141,8,108,3,159,254,111,0,212,0,249,255,85,2,102,255,50,3,111,254,128,250,236,2,198,9,146,5,175,244,45,4,70,1,163,253,120,0,203,239,241,243,217,2,82,0,224,0,64,1,97,1,179,255,93,255,190,254,220,0,207,251,10,0,33,2,250,253,59,254,50,0,126,254,46,248,102,2,63,253,218,252,96,252,125,11,248,253,221,255,184,4,157,1,132,3,138,0,98,254,223,254,241,255,181,255,185,0,139,254,137,2,5,255,154,2,148,10,255,244,19,253,97,255,144,255,198,1,127,254,13,4,210,255,231,255,242,255,66,0,40,2,160,0,216,255,216,253,100,255,151,0,89,235,29,2,14,255,174,255,116,251,81,3,251,252,120,255,94,255,180,255,23,0,141,254,34,255,59,247,212,1,169,1,156,254,162,1,253,255,190,254,11,242,148,0,4,1,101,255,229,12,91,255,142,243,59,253,54,254,102,3,130,1,59,0,95,255,21,2,106,255,86,2,128,1,132,3,47,251,182,255,48,254,249,253,107,253,201,255,254,245,34,1,209,5,203,6,229,8,106,3,53,250,65,254,93,0,53,1,55,1,53,255,237,255,223,8,0,251,131,255,69,254,230,253,90,10,214,255,34,1,245,0,107,255,24,0,38,0,123,255,102,6,210,0,17,255,76,255,4,2,244,255,49,253,237,255,251,253,210,231,75,255,167,255,62,1,229,1,119,2,11,0,51,255,199,255,1,1,61,2,184,255,17,1,189,253,107,0,251,255,112,0,169,1,145,9,181,10,246,2,144,2,105,253,230,254,208,255,211,255,218,254,64,254,70,234,61,0,255,255,48,254,249,254,80,253,141,255,241,255,148,255,199,253,64,254,208,255,76,255,151,255,14,0,76,255,234,1,18,1,113,2,180,253,136,255,60,255,207,254,130,255,179,1,70,246,123,245,170,242,31,0,97,0,89,255,142,255,247,0,15,30,67,255,188,253,219,0,241,0,188,0,71,1,179,0,63,255,135,0,80,255,127,0,223,1,17,2,234,0,112,0,234,0,154,254,226,254,85,4,124,11,158,253,243,255,166,245,239,1,75,5,194,253,213,255,39,250,220,254,9,254,52,2,149,254,24,0,199,254,107,5,221,0,228,241,15,3,125,2,43,0,71,5,217,0,235,255,149,0,224,243,190,0,253,254,55,255,170,254,55,255,166,0,107,9,198,251,27,1,130,254,43,253,157,0,155,0,183,249,176,253,15,2,113,244,9,0,216,0,14,2,79,0,54,0,124,255,202,0,17,3,161,3,219,6,105,253,110,1,105,241,210,12,49,1,60,2,220,255,145,255,25,255,119,0,91,2,77,5,103,255,41,2,107,1,8,253,92,251,122,3,147,0,252,240,52,241,150,0,1,1,180,253,22,255,241,1,105,1,225,253,255,0,81,255,135,254,49,0,152,253,56,255,19,16,227,253,130,0,166,2,126,242,6,254,38,255,219,250,121,3,29,0,152,255,254,255,20,2,119,254,1,2,232,252,246,0,250,255,76,255,90,0,127,0,250,12,86,2,182,0,81,0,82,0,67,0,217,255,87,0,196,255,248,255,167,255,185,0,99,0,231,255,27,0,9,0,197,255,3,227,49,0,239,255,116,0,171,255,6,0,207,254,88,0,92,255,99,0,61,0,97,254,142,255,224,254,1,0,91,255,244,255,5,0,113,255,114,255,247,253,11,255,203,255,38,0,157,255,125,14,204,255,0,0,215,255,121,255,147,0,39,255,62,0,160,247,255,0,132,0,8,1,65,0,219,255,204,0,174,254,232,254,192,0,72,255,98,255,155,241,230,255,203,0,174,1,227,255,240,255,77,0,230,0,201,254,85,2,249,9,154,251,193,255,154,0,81,254,95,255,59,1,30,1,109,255,177,0,253,255,93,0,193,1,253,0,219,255,101,0,12,255,179,255,42,0,128,254,22,0,36,0,235,0,147,236,243,0,136,255,151,255,30,255,142,255,57,254,108,254,164,0,7,254,220,1,132,255,235,244,174,255,152,244,253,255,0,0,134,0,162,255,8,1,203,255,203,255,108,0,253,255,179,252,3,245,228,0,77,255,196,255,254,255,65,0,33,0,103,255,240,255,107,255,169,247,209,0,95,252,224,254,227,0,96,10,131,255,214,255,17,0,30,0,47,13,145,254,53,0,250,254,161,254,108,0,242,254,11,0,199,255,74,255,205,255,107,255,225,254,141,255,232,255,99,0,180,255,42,27,181,255,252,255,38,0,88,255,138,0,109,0,17,255,211,255,49,0,28,0,160,250,49,0,66,0,173,255,127,255,195,255,157,255,135,0,14,0,163,255,111,0,37,0,240,255,2,0,180,255,104,1,179,255,82,0,161,0,149,0,132,249,18,0,98,0,222,255,244,255,220,255,191,255,126,0,199,255,28,0,7,2,252,7,41,1,73,0,38,255,51,0,17,0,21,0,186,255,224,255,183,255,217,255,218,255,245,255,60,0,38,0,127,255,151,255,83,255,200,0,7,0,124,0,182,255,36,245,48,10,199,255,43,255,54,0,56,255,134,0,208,0,222,255,236,0,143,0,101,0,71,1,46,2,75,0,61,1,18,12,68,255,32,2,70,255,15,0,116,0,237,0,76,0,151,255,29,0,212,254,229,255,45,255,71,0,112,255,183,0,179,255,38,0,240,255,39,0,56,0,116,227,143,255,140,255,224,255,222,0,60,0,76,0,235,255,59,0,52,0,104,0,127,1,73,0,149,0,88,0,127,0,34,0,229,248,210,255,50,0,11,0,97,255,33,255,93,255,107,255,95,0,93,255,136,247,237,255,87,252,73,255,66,0,47,254,255,254,85,1,186,255,111,0,228,0,52,0,83,0,63,0,204,255,69,255,16,0,21,246,205,255,168,12,175,255,87,0,140,255,73,255,74,255,96,0,234,255,65,255,149,255,217,0,246,255,41,255,9,0,249,255,159,255,181,254,201,255,1,2,114,254,98,5,67,10,175,247,51,2,182,5,143,254,242,1,152,4,43,254,220,0,71,252,134,255,20,255,206,254,236,254,31,0,35,0,89,255,46,2,122,255,45,0,202,255,16,0,36,0,18,0,44,1,134,9,62,0,79,255,77,0,78,10,148,255,141,255,64,13,18,1,133,255,190,255,201,0,112,254,170,0,142,0,151,0,76,1,53,0,5,254,81,0,115,253,163,255,124,243,251,255,10,0,213,255,79,0,39,15,77,0,191,0,24,0,23,0,48,255,6,0,147,255,159,255,126,0,206,254,117,2,26,0,252,253,79,0,21,0,131,0,43,0,3,255,121,242,72,3,141,2,161,255,208,255,44,1,254,251,188,254,115,252,129,254,195,0,86,1,120,255,64,255,166,1,6,1,243,255,22,2,53,12,8,0,136,6,176,0,219,254,211,0,67,251,25,2,125,2,246,255,140,255,107,255,44,0,53,0,105,0,7,0,159,255,3,0,17,0,8,0,235,255,249,255,215,255,218,255,161,236,175,255,1,0,165,0,196,0,98,0,35,0,221,255,8,0,228,255,113,0,236,255,108,0,126,255,191,255,172,0,42,11,41,0,33,243,138,0,10,0,161,255,226,255,83,255,85,0,42,0,30,0,137,255,161,0,195,0,125,0,224,255,136,0,63,1,223,255,22,20,50,0,100,0,128,0,166,255,203,255,189,255,53,255,28,0,19,0,37,0,119,255,132,255,151,255,231,255,179,242,6,255,38,1,153,1,157,255,208,251,129,254,244,255,212,0,236,254,61,13,155,255,171,0,215,255,214,253,217,254,75,254,86,0,158,0,14,255,167,0,135,0,7,0,107,255,48,0,252,255,172,255,47,19,27,1,5,0,242,255,105,0,149,255,128,254,102,0,183,0,47,0,67,0,15,236,251,255,16,0,101,255,181,0,110,0,24,0,179,255,224,255,120,0,1,0,22,0,167,0,166,255,106,255,251,255,163,0,212,255,228,255,54,0,14,244,82,255,58,0,152,0,225,255,77,255,134,255,199,255,232,0,117,254,159,236,61,0,141,255,31,0,14,0,82,0,147,255,217,255,59,0,207,255,123,255,52,0,17,0,57,0,52,0,193,255,19,1,146,0,104,0,53,0,47,0,201,255,55,1,7,19,230,255,48,0,162,255,245,255,198,255,63,0,140,0,182,255,162,255,243,254,179,255,44,13,212,243,16,0,209,255,182,255,95,255,115,0,58,0,9,255,137,255,143,1,42,0,75,255,154,0,38,255,232,255,19,255,58,0,237,254,163,11,187,0,132,255,56,1,45,1,207,10,248,255,40,0,233,255,250,255,218,255,204,255,149,254,247,254,178,255,26,255,30,1,121,255,175,254,175,255,170,0,243,255,198,255,139,255,7,2,80,237,157,0,63,255,9,0,62,0,235,255,180,0,128,0,70,1,213,0,136,9,62,0,167,253,201,255,2,0,238,255,170,254,142,0,102,1,136,253,135,254,6,14,8,255,234,254,21,255,228,255,242,0,123,255,144,0,26,0,251,254,113,0,45,0,233,255,64,248,179,255,128,0,249,0,248,255,246,254,218,255,250,255,120,249,211,255,172,255,135,254,154,0,17,0,173,255,212,255,156,0,119,255,43,0,91,0,253,0,17,0,185,255,164,255,178,0,12,0,18,0,248,255,151,255,101,0,156,27,71,0,175,255,84,0,223,255,79,0,53,0,249,255,171,255,247,254,117,0,61,1,114,0,72,0,30,254,94,254,71,255,159,255,12,1,249,249,177,255,110,255,208,255,211,255,69,243,44,255,125,4,91,255,177,0,98,255,179,255,100,0,86,0,187,255,107,0,219,0,0,254,3,255,94,254,211,255,16,0,125,21,72,255,207,0,67,0,46,0,109,0,228,255,247,255,33,0,63,0,240,255,39,0,92,0,27,0,23,0,246,255,0,224,0,0,50,0,199,255,68,0,68,254,58,4,247,0,118,255,120,0,216,1,76,253,212,0,216,249,66,0,245,11,146,1,96,255,81,1,83,253,249,253,227,0,233,254,92,0,217,239,119,254,212,255,6,0,127,255,59,0,239,0,151,0,153,0,217,255,116,0,134,0,216,255,171,0,118,0,207,0,55,10,38,0,89,255,121,249,85,0,121,255,74,255,168,255,246,0,53,0,29,0,254,255,16,0,232,0,32,2,210,255,118,255,122,0,204,255,32,5,9,0,92,0,13,0,4,0,66,0,221,255,122,255,200,255,85,0,213,255,225,255,28,0,141,243,100,0,153,255,70,0,253,255,186,0,213,255,122,0,32,244,229,255,210,255,135,255,1,0,37,0,0,0,196,255,2,0,156,255,104,255,38,255,175,0,106,254,175,0,63,255,68,0,48,255,233,255,26,255,221,0,69,13,45,0,48,0,37,0,81,1,11,0,15,0,187,255,252,255,174,255,53,0,33,0,200,255,75,0,158,255,187,255,245,255,237,255,244,255,81,0,204,255,52,21,121,0,82,0,209,1,10,0,27,255,126,0,32,0,119,0,183,1,126,0,204,7,171,255,175,255,199,255,88,0,232,0,108,0,234,255,232,255,27,0,120,255,91,0,224,255,18,0,226,0,223,255,15,0,117,0,145,0,199,225,9,0,58,0,154,255,143,255,26,0,130,247,28,0,91,254,245,255,186,255,233,255,186,255,137,255,160,255,123,255,208,0,20,0,90,241,242,255,23,0,41,0,76,255,49,8,153,255,169,253,146,0,251,0,179,255,211,253,180,255,160,255,69,0,10,1,60,1,74,0,239,255,29,255,223,0,33,0,251,254,135,0,190,31,250,0,251,255,199,255,35,0,126,1,212,255,136,0,81,0,42,0,176,255,179,0,183,255,181,255,199,255,18,1,241,255,188,243,164,12,196,0,150,0,205,255,222,0,66,255,13,0,83,0,199,254,107,255,89,0,231,254,244,255,214,255,37,1,55,2,19,0,213,255,146,0,102,0,217,255,82,14,95,0,76,0,255,255,12,0,27,0,7,0,251,255,5,1,132,0,41,255,217,254,205,255,240,1,77,0,100,0,16,0,227,254,137,2,161,255,24,1,77,0,121,0,140,245,25,0,132,251,96,11,171,254,165,255,76,9,176,255,250,255,13,1,222,255,82,253,48,255,19,0,228,0,24,0,251,255,106,255,11,0,214,0,196,254,163,4,87,2,194,255,30,247,16,255,48,0,170,255,87,0,86,0,221,1,248,14,67,0,135,0,68,0,235,2,83,1,129,1,1,255,32,255,184,0,70,0,171,0,122,255,44,10,25,255,72,0,170,0,51,0,31,245,188,253,170,255,119,254,193,255,177,255,105,255,78,1,78,0,73,1,234,254,102,0,230,255,201,255,53,242,134,254,9,255,176,0,54,255,147,0,169,0,87,0,24,0,180,243,217,243,106,0,45,0,142,255,171,255,45,255,154,0,172,0,246,0,112,1,126,255,58,0,121,255,70,0,102,0,106,255,180,255,249,255,13,0,255,255,227,255,20,0,249,255,112,0,22,255,141,255,118,255,216,255,106,0,178,0,148,227,231,253,25,0,88,3,204,1,35,12,146,0,248,253,137,253,138,255,137,1,179,0,144,0,170,255,47,0,82,0,215,11,28,0,164,0,204,254,101,254,72,0,138,0,122,1,242,0,253,0,12,0,158,0,228,255,196,255,227,255,210,255,251,255,245,255,84,0,193,10,143,255,191,255,3,0,5,0,13,0,10,236,182,255,130,255,127,255,174,255,198,255,116,0,15,0,68,0,243,0,224,255,126,0,208,255,11,0,249,255,75,0,10,0,166,0,103,255,8,0,213,255,218,255,81,0,215,255,13,0,100,0,27,0,46,0,71,254,200,255,35,0,4,0,51,0,104,29,52,0,115,255,103,255,39,0,220,255,170,255,80,0,221,255,50,0,210], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1844785);
/* memory initializer */ allocate([255,23,0,178,0,110,240,234,242,59,0,234,254,37,0,254,255,14,0,99,255,48,255,195,254,218,0,15,0,216,254,224,255,205,255,36,0,229,255,242,247,28,0,219,255,66,1,238,8,214,0,60,255,85,255,192,255,93,255,9,1,206,255,3,0,79,255,234,255,68,0,124,0,37,0,241,255,102,247,60,0,133,0,4,0,115,1,193,10,145,255,224,1,66,254,228,1,43,0,150,0,181,254,130,5,233,252,123,0,120,255,64,255,11,1,0,0,167,255,151,255,165,1,68,0,130,255,79,0,23,1,202,0,124,255,48,255,239,242,151,255,59,0,118,0,121,253,208,255,244,255,145,0,109,254,200,0,7,0,252,255,136,243,33,255,64,0,0,0,159,1,110,1,136,0,49,0,69,226,79,0,151,255,127,0,187,255,213,255,103,0,161,255,163,255,246,255,226,255,94,0,108,0,147,255,0,0,169,255,186,255,44,1,163,255,113,0,25,0,239,255,215,8,41,0,192,0,18,0,73,0,179,0,129,0,149,0,175,255,255,255,0,0,201,0,184,0,139,2,8,0,18,0,114,0,4,11,127,1,185,255,120,1,23,247,90,251,113,255,121,0,211,255,147,247,102,254,81,0,242,255,1,6,191,252,29,0,126,4,18,254,248,255,242,255,210,0,188,0,1,12,17,249,133,255,80,0,153,255,227,0,40,1,111,0,101,6,59,255,69,5,174,0,204,12,49,0,158,255,74,0,148,2,3,0,4,255,156,254,247,255,15,2,193,255,197,224,240,255,85,0,249,0,74,0,26,0,2,0,3,0,26,0,132,255,195,255,230,255,112,255,4,0,204,255,6,0,251,253,161,255,6,10,230,255,66,255,60,255,3,254,90,244,4,0,78,255,247,255,189,255,231,255,1,0,193,0,188,255,210,255,174,255,106,241,242,255,173,254,212,255,105,255,55,0,230,0,253,255,100,0,209,255,187,255,35,0,107,0,127,0,81,255,245,255,246,255,98,255,116,255,118,11,124,255,11,10,98,255,39,255,106,0,137,0,34,255,74,0,214,255,64,0,47,2,122,0,73,0,144,255,108,244,198,9,13,0,45,1,215,255,203,0,130,254,105,255,35,255,109,255,232,255,83,0,37,0,211,255,56,0,89,0,71,0,109,0,242,255,213,255,126,255,148,255,238,255,74,0,233,255,222,255,79,0,238,29,168,255,70,0,21,0,146,255,147,0,26,0,250,0,74,0,165,0,49,0,43,0,45,0,234,255,242,255,37,1,155,20,57,0,184,255,93,0,40,0,115,0,117,255,180,254,95,0,92,0,230,255,26,0,169,0,162,255,76,1,71,0,30,254,137,0,190,0,114,0,14,0,151,0,53,12,6,0,109,0,6,0,7,0,7,6,26,1,232,255,24,0,142,0,33,0,123,0,41,0,184,255,3,255,223,255,53,1,149,255,192,255,125,255,56,0,56,242,82,0,239,255,161,1,209,255,180,253,18,1,155,0,158,0,11,255,186,0,147,0,249,255,206,255,38,255,12,0,118,0,194,255,140,2,145,0,64,0,169,9,110,255,220,0,99,244,97,0,28,1,29,0,12,1,29,0,48,255,216,255,5,255,81,255,240,255,198,255,191,255,28,0,26,0,55,0,74,0,244,255,119,7,43,0,174,255,106,255,243,255,137,255,8,0,119,0,156,0,14,6,168,255,154,255,46,0,226,0,124,255,95,0,100,0,87,0,7,0,210,255,8,0,224,255,240,255,244,255,61,1,223,255,229,255,35,1,168,255,169,0,1,0,155,255,195,255,161,0,162,0,223,255,255,255,11,0,233,19,222,255,142,0,31,0,94,0,35,14,162,255,67,0,51,13,191,255,28,0,254,0,189,0,110,0,138,0,215,255,52,0,32,0,152,255,154,0,172,0,195,246,48,254,25,1,207,0,190,255,66,255,143,1,98,255,13,0,101,255,33,255,92,0,148,255,231,255,212,1,189,0,249,238,42,0,121,255,138,0,36,0,133,250,248,254,176,254,92,255,207,255,54,0,131,255,195,255,62,0,16,0,172,0,182,0,62,12,163,250,63,0,29,255,150,255,123,255,91,255,187,255,199,255,72,255,210,255,9,0,199,255,50,0,253,255,194,255,241,255,133,255,108,0,111,0,91,0,95,255,23,0,175,255,7,0,208,0,247,234,12,255,24,0,95,0,12,0,248,254,62,0,212,255,21,0,16,255,213,254,244,255,117,0,195,255,9,246,133,1,0,11,77,255,203,0,91,254,131,3,249,255,174,0,56,255,98,0,12,4,90,255,11,0,119,255,78,0,249,255,135,255,245,0,179,255,124,0,102,0,51,0,64,12,74,0,202,254,40,0,212,0,17,255,139,254,102,255,142,1,151,11,142,2,232,1,103,0,26,255,182,254,63,3,193,255,39,254,152,0,212,253,118,247,141,254,4,0,86,0,244,255,115,255,127,21,169,255,133,255,239,255,241,255,154,0,192,0,170,255,97,0,165,0,96,1,56,0,154,0,43,0,181,254,236,3,204,255,125,255,17,243,3,0,110,0,103,255,186,255,137,0,88,255,236,255,115,0,140,0,231,255,202,255,243,255,212,254,57,0,125,255,214,0,5,1,164,255,106,2,64,245,182,243,61,0,205,255,210,0,26,255,87,0,72,255,74,1,22,0,237,255,149,255,35,254,217,255,1,0,127,0,178,0,183,255,169,1,56,0,231,255,215,255,135,0,119,9,59,0,210,255,246,255,49,0,140,255,205,255,65,247,28,255,181,255,48,0,3,0,181,0,161,0,123,255,157,254,81,0,5,0,84,0,34,255,173,255,92,0,33,0,122,226,218,255,253,255,159,0,33,0,198,255,219,255,149,255,16,0,195,255,162,255,93,0,97,0,49,0,237,254,29,0,58,255,252,255,188,255,87,0,116,0,129,228,46,0,81,0,231,255,0,0,249,255,210,255,152,0,64,0,216,255,113,255,200,255,147,0,147,1,1,1,76,9,230,253,112,254,124,255,167,255,227,255,194,244,201,1,216,253,244,255,67,255,142,254,155,254,161,241,166,1,63,0,200,0,116,0,247,255,27,255,184,255,156,255,18,13,88,0,238,255,28,0,209,255,159,0,108,0,96,255,253,0,58,0,122,11,55,0,110,1,223,255,119,243,31,0,108,255,246,255,216,255,69,254,127,0,120,0,106,0,9,0,4,0,16,255,200,0,129,0,72,1,154,255,187,0,182,0,112,0,197,10,68,243,58,1,93,255,253,255,71,255,98,1,159,255,187,255,57,255,41,0,113,255,19,0,108,0,234,255,224,255,238,255,107,255,35,0,31,0,251,255,37,236,52,0,9,0,5,0,212,255,204,255,76,0,7,0,156,255,7,0,177,255,0,0,223,255,110,0,48,255,20,0,97,255,180,255,2,0,0,224,156,0,118,0,206,254,168,255,136,0,219,254,80,255,163,0,8,0,79,7,144,255,229,0,55,1,161,255,181,255,17,0,217,0,152,0,62,0,17,0,10,255,251,13,5,0,169,255,235,255,92,0,114,0,71,255,118,0,8,0,196,0,132,255,36,255,175,0,104,0,54,0,104,0,216,255,211,255,104,255,136,1,216,0,232,255,228,255,232,7,250,255,42,0,165,255,55,255,247,255,64,255,35,0,213,255,125,6,156,254,183,4,214,250,84,1,135,244,240,255,163,0,223,252,89,254,197,0,0,254,186,255,229,0,100,254,35,1,255,1,220,255,77,255,158,255,202,255,93,0,87,0,7,1,212,255,167,0,77,0,252,255,110,28,155,255,63,255,91,0,5,255,125,255,13,1,15,0,88,255,234,255,230,255,44,0,24,0,154,0,115,0,245,255,132,255,28,0,37,0,242,255,210,255,189,255,0,224,205,255,87,255,41,0,210,254,175,255,199,7,245,255,136,0,81,255,71,0,152,255,89,0,60,0,137,0,17,0,106,0,96,0,18,255,173,255,204,255,143,255,53,0,87,11,209,255,9,0,29,255,32,245,11,255,146,0,60,255,40,255,41,0,250,255,128,255,203,255,1,0,128,255,111,255,149,0,32,0,25,0,199,255,242,255,72,0,121,255,10,0,102,248,189,255,74,0,129,255,141,0,213,254,55,0,8,0,179,3,65,247,241,254,74,0,29,255,175,255,31,0,35,1,170,255,158,244,22,0,249,255,37,1,2,0,231,255,9,0,75,244,89,0,86,12,192,0,210,255,10,255,116,255,46,0,31,1,133,0,146,255,52,1,142,255,223,255,150,255,9,0,167,255,105,0,108,1,84,255,185,0,195,255,112,17,164,255,248,254,190,255,95,255,102,0,78,255,248,254,235,255,114,0,72,10,231,5,176,3,76,255,183,246,54,0,42,254,69,255,58,253,26,252,252,253,108,252,72,254,182,252,29,1,22,0,230,254,53,254,213,254,47,245,19,247,132,254,110,247,33,3,173,253,4,255,248,1,187,255,16,253,204,3,127,2,21,1,246,1,117,0,208,251,111,255,182,5,240,253,117,8,112,3,74,255,119,244,238,2,190,251,84,2,105,0,187,0,43,2,103,255,143,255,62,3,161,0,52,1,212,255,6,255,198,255,5,254,106,254,142,253,173,5,77,5,116,0,56,254,170,12,161,253,94,0,134,1,137,1,114,0,45,4,254,255,2,0,193,9,125,5,13,253,73,5,192,0,8,5,69,255,6,1,186,6,91,0,117,3,146,253,191,254,246,0,213,248,17,0,213,0,176,255,110,253,108,248,19,1,77,3,147,254,20,1,94,8,40,255,182,242,122,253,37,2,178,255,80,255,204,255,17,3,201,250,44,0,163,0,103,254,249,4,167,2,135,254,20,3,181,250,71,249,76,1,223,0,129,5,152,255,165,0,98,1,66,1,110,9,181,249,216,0,250,255,24,255,22,249,117,248,192,9,238,253,228,0,100,252,83,255,183,254,193,253,83,249,124,252,199,0,223,0,178,2,132,253,73,0,145,254,204,1,201,252,15,236,179,1,189,3,224,0,246,0,150,1,95,253,240,2,156,1,98,255,245,254,4,0,182,2,10,0,211,255,219,0,16,4,10,3,138,248,94,7,77,253,162,2,61,4,231,253,120,1,24,4,90,3,95,255,101,2,120,1,23,2,187,250,135,248,250,253,174,252,153,2,4,3,87,244,190,255,214,255,94,8,176,252,129,251,237,0,45,255,95,255,63,245,91,2,251,1,39,0,193,253,195,255,227,251,239,254,34,1,254,254,94,255,139,0,95,0,244,255,55,255,20,255,197,2,184,254,198,254,126,255,39,235,100,0,238,255,159,255,50,255,35,7,186,6,46,1,156,3,53,255,249,2,53,253,232,255,116,1,168,253,67,8,173,4,130,250,164,2,236,247,89,255,35,255,88,252,139,5,97,1,195,254,245,0,182,244,111,2,9,1,146,253,204,0,245,9,84,2,239,0,231,255,96,253,71,2,117,0,243,255,53,247,211,250,192,7,151,5,201,250,12,251,223,2,245,0,105,0,81,2,63,255,154,253,141,3,173,254,247,251,127,1,102,0,107,1,220,2,159,5,4,4,251,4,186,1,219,3,195,240,255,254,220,255,224,0,140,255,110,254,200,0,172,253,131,255,116,1,196,253,142,1,225,253,0,4,210,6,32,253,224,251,56,249,185,3,2,4,59,252,186,1,227,249,64,254,160,255,218,5,30,0,25,255,29,254,73,0,143,243,229,6,33,5,156,255,221,1,58,255,14,3,60,1,108,1,149,255,81,254,253,248,12,255,122,0,89,254,127,254,201,1,152,252,233,253,182,251,80,0,146,255,140,5,134,2,33,0,102,243,136,2,93,3,72,1,11,251,210,253,239,1,113,3,112,0,223,1,170,0,203,254,112,7,124,250,0,253,60,251,222,255,227,3,119,253,162,0,1,0,153,0,217,3,250,2,249,254,68,255,77,0,248,2,214,246,102,13,62,254,141,6,66,4,235,6,61,8,242,255,137,255,29,252,12,1,141,0,33,0,35,0,31,0,25,2,65,0,167,254,69,0,192,0,251,2,238,255,54,4,245,14,18,1,186,1,83,255,100,254,178,1,73,253,156,3,2,0,15,6,54,2,171,255,217,0,208,3,148,8,9,254,135,250,247,2,154,3,48,244,61,252,253,255,88,2,60,254,63,255,237,252,7,0,186,0,60,3,3,2,148,0,31,255,30,251,39,252,187,1,1,254,245,7,24,6,158,12,135,2,138,5,91,255,251,254,143,254,224,0,194,1,156,255,241,254,134,255,1,254,77,253,92,250,138,3,112,255,248,0,196,1,189,3,186,255,251,253,116,0,25,242,147,252,113,254,162,1,236,250,97,254,79,255,2,3,250,245,141,254,119,249,238,251,12,254,222,254,60,253,137,253,193,0,190,9,63,1,33,2,255,2,102,0,231,0,213,255,117,255,159,255,68,253,200,249,26,1,45,5,117,250,121,253,193,1,203,7,31,253,149,2,81,6,213,2,72,250,103,2,138,3,202,0,102,255,28,255,110,247,25,255,43,1,110,0,38,5,29,4,200,254,75,3,87,252,95,249,176,253,56,251,135,253,206,255,24,3,64,6,93,251,85,255,211,0,24,253,206,254,186,0,122,7,209,243,120,252,97,255,178,0,172,253,114,253,49,3,94,0,14,255,184,246,38,255,91,254,147,254,69,253,177,0,85,254,224,255,9,1,223,255,245,0,222,255,189,20,205,254,250,254,213,254,86,0,22,1,33,0,56,255,76,255,200,255,81,1,10,4,27,255,88,19,50,1,159,253,189,0,234,255,24,1,96,255,5,254,135,0,15,251,4,255,178,1,85,254,158,0,222,253,126,255,60,246,85,2,140,3,150,3,194,2,203,4,62,13,227,3,42,1,210,253,27,5,253,2,112,255,219,255,226,254,122,0,215,0,29,251,66,4,85,0,110,252,10,2,60,1,37,7,67,253,147,254,17,243,56,1,22,0,168,2,185,250,220,0,243,0,166,0,220,255,12,3,91,9,192,255,68,3,13,4,223,2,198,3,173,0,90,4,192,0,254,1,226,251,61,5,152,253,23,6,129,3,82,1,253,255,62,255,42,255,195,253,247,254,72,1,147,254,177,1,7,254,170,255,33,0,100,255,127,255,119,255,119,0,143,0,141,22,180,255,68,0,52,3,191,4,35,5,201,2,12,0,54,6,131,0,63,255,143,252,29,255,224,2,69,2,224,2,219,255,78,254,63,254,164,254,93,16,132,8,176,250,129,249,182,255,191,4,22,1,44,8,190,255,57,1,132,1,163,250,25,0,87,2,120,3,169,255,37,1,30,0,111,1,242,3,141,252,50,3,114,252,130,248,96,3,226,1,56,252,31,251,222,0,76,4,23,0,169,255,189,9,8,255,146,253,240,0,151,0,105,3,81,245,45,5,68,253,101,254,26,1,199,246,205,248,137,253,48,255,103,0,101,254,63,3,66,254,220,254,194,1,184,0,98,255,228,1,84,248,55,18,123,0,18,0,174,0,109,2,158,0,236,252,233,0,46,1,185,1,173,254,200,0,194,255,59,255,247,255,20,255,216,3,72,2,247,253,139,254,51,255,142,3,136,1,82,3,104,244,68,0,41,253,50,5,66,2,36,0,127,254,242,2,230,253,220,255,15,1,162,1,220,253,239,6,235,251,145,252,129,250,12,2,195,251,57,250,115,1,19,0,105,3,171,0,116,11,40,255,42,0,71,0,93,251,198,253,244,253,88,1,254,252,10,240,33,253,253,253,31,4,217,253,177,3,128,250,145,3,19,252,34,255,69,254,60,0,62,255,34,253,116,7,234,253,185,250,72,0,86,252,190,255,60,245,33,5,87,255,242,249,194,1,158,253,125,3,76,4,185,253,87,0,111,255,46,255,25,1,122,5,162,2,0,0,218,255,106,3,149,254,132,9,108,8,133,249,31,254,126,255,193,255,99,253,196,254,7,253,99,254,108,0,58,9,98,1,76,0,67,249,100,252,93,250,227,4,103,3,246,247,6,2,187,3,229,254,168,2,171,255,208,253,48,254,127,0,40,255,154,250,116,7,238,0,74,255,203,1,53,251,120,4,218,8,160,255,83,2,18,253,144,3,58,255,250,6,113,250,150,253,62,254,185,0,68,251,194,2,79,253,102,255,147,254,87,253,158,250,146,3,80,251,3,255,236,253,172,12,188,1,1,0,160,255,108,254,192,255,100,254,136,250,242,244,239,252,172,3,39,255,102,1,106,2,208,0,98,244,147,254,224,255,193,255,23,255,156,252,99,254,102,1,61,254,30,5,17,253,207,250,80,246,63,0,202,1,239,254,246,4,60,1,93,0,59,254,49,254,22,251,199,255,207,251,11,248,46,0,96,255,1,18,87,251,192,0,157,254,61,252,164,255,240,2,81,2,102,0,176,255,135,255,166,0,162,253,238,254,28,0,2,1,45,0,211,255,160,3,75,252,122,255,244,254,179,255,242,0,87,6,246,250,227,2,109,0,29,1,175,0,164,255,43,240,30,254,110,1,217,0,130,255,181,252,182,3,212,251,9,3,26,7,38,2,133,252,222,255,29,252,184,7,117,10,4,253,45,0,216,255,248,248,57,2,189,254,154,255,216,251,160,15,147,255,89,254,223,254,226,2,152,252,40,3,47,252,248,1,123,252,41,0,211,255,225,254,116,255,68,254,221,1,241,254,148,252,45,1,139,246,97,6,106,252,108,253,107,255,18,246,9,254,247,254,149,255,145,253,65,254,242,252,166,252,233,253,36,255,186,1,149,2,47,255,110,3,191,249,26,14,149,0,181,254,190,0,102,0,14,1,171,5,237,0,13,0,254,251,178,0,10,5,231,254,39,255,11,0,64,249,19,4,80,244,50,253,248,252,101,1,153,253,25,255,45,3,39,254,98,6,27,2,255,253,240,0,134,4,144,0,57,0,225,4,199,5,31,254,35,253,127,6,11,253,129,2,168,2,44,254,119,245,227,255,194,255,229,4,118,4,36,1,245,0,160,255,39,1,104,253,248,254,204,254,98,253,63,253,155,0,72,240,74,1,191,0,179,255,34,250,70,1,9,0,39,1,201,253,34,0,152,255,133,255,192,254,1,255,100,4,64,1,98,0,19,5,76,254,211,5,171,254,140,3,11,0,8,0,220,3,127,248,5,0,145,250,91,3,245,250,187,253,34,2,161,255,16,1,71,254,185,0,0,255,57,1,210,1,119,254,206,255,78,17,84,252,87,0,32,255,134,1,229,253,222,254,234,251,19,2,231,246,251,4,182,253,234,251,110,249,135,4,140,3,231,7,183,3,239,254,188,255,201,2,212,253,2,3,15,3,223,0,60,0,143,252,159,255,248,2,44,2,19,255,249,254,10,255,16,255,165,0,14,2,64,3,103,237,176,1,173,254,186,0,236,1,81,0,120,255,197,252,122,254,254,251,141,254,220,254,169,3,13,255,120,255,6,0,49,0,33,255,168,253,157,254,186,20,140,0,34,0,172,255,113,247,159,252,142,248,5,255,18,1,82,2,66,251,165,2,226,1,104,251,43,0,182,251,53,255,231,253,42,7,52,5,52,1,176,1,65,255,19,12,100,7,158,3,66,254,74,251,155,253,198,0,63,2,218,255,8,1,119,1,22,1,77,253,149,255,17,0,17,255,5,1,80,3,148,253,183,0,112,2,122,0,154,254,206,255,249,3,205,251,63,253,166,254,81,1,135,255,100,0,38,255,229,251,49,254,136,237,255,253,129,251,225,2,4,17,172,2,162,250,94,6,9,2,248,253,204,255,90,0,119,0,213,255,125,255,24,0,254,255,72,255,191,255,102,2,115,1,64,254,98,254,135,5,81,253,32,255,72,2,0,253,70,251,125,11,15,244,132,0,150,1,72,252,35,1,39,1,226,252,96,2,60,250,252,253,21,0,210,254,37,8,92,249,161,245,157,254,175,0,103,254,150,2,46,0,9,255,55,255,188,253,179,0,202,255,202,1,68,3,7,6,37,7,230,254,234,254,156,1,118,9,29,8,197,0,127,252,195,1,83,2,11,6,26,2,57,3,51,2,187,1,192,253,170,252,196,253,241,0,41,254,201,0,201,254,239,253,112,0,248,235,83,255,23,255,77,254,84,1,158,0,215,255,17,1,32,255,151,3,222,249,51,4,9,1,230,254,232,4,239,3,231,0,208,2,161,1,111,254,19,238,21,253,59,254,168,251,54,0,156,0,207,253,186,10,90,254,173,255,165,255,131,254,242,254,54,251,219,3,59,252,113,2,38,254,53,2,74,11,171,255,11,5,232,254,114,2,230,255,72,3,98,4,133,248,12,3,66,253,24,3,190,253,134,255,247,255,151,4,62,255,197,253,124,11,28,2,31,0,25,7,160,254,8,1,185,3,13,248,238,0,178,12,231,249,141,2,181,254,119,254,59,3,130,254,67,1,25,1,197,250,205,252,33,2,207,0,14,0,82,1,176,1,92,3,155,6,142,0,199,2,125,1,129,251,68,16,157,252,15,255,111,0,255,253,161,252,78,0,173,5,149,254,128,255,24,255,195,248,69,9,124,251,210,0,186,2,110,4,155,252,79,255,160,254,234,5,166,250,235,252,87,251,51,3,92,1,80,0,236,1,179,0,115,252,79,2,168,253,135,254,83,249,59,0,229,253,45,2,211,255,150,254,10,3,201,236,121,253,203,0,97,3,199,254,255,254,173,0,145,246,237,3,21,249,75,3,38,254,83,6,169,4,70,255,49,1,124,2,106,253,184,7,34,2,174,255,148,255,17,253,82,3,9,2,167,249,193,243,124,254,64,0,249,0,91,251,240,249,69,10,2,0,35,255,151,255,242,2,251,0,219,0,242,254,54,255,33,2,147,0,251,3,108,0,178,250,219,250,82,5,213,250,6,243,107,254,141,254,214,253,178,254,40,1,237,1,248,0,252,255,60,5,123,0,184,253,220,252,2,253,92,255,42,254,39,1,218,0,253,255,62,0,62,255,111,253,152,19,24,1,252,255,187,255,231,254,30,252,209,0,51,1,200,33,219,255,118,255,45,0,183,254,155,255,191,255,98,0,58,0,202,2,56,0,86,255,60,0,53,255,8,255,103,0,107,0,104,254,84,2,170,0,61,0,72,2,215,2,78,254,75,255,4,236,10,254,238,1,52,0,83,0,151,255,69,1,68,0,207,253,238,254,115,1,215,248,178,255,82,244,64,1,141,0,20,253,228,6,133,4,230,253,236,254,198,249,104,255,70,3,211,255,113,4,13,0,221,252,94,255,186,252,81,251,211,7,68,2,103,14,180,252,216,253,241,254,50,254,246,251,227,255,17,1,94,3,13,1,95,0,186,0,34,255,132,255,79,0,222,255,84,253,40,3,219,251,108,252,98,2,27,2,9,5,14,3,192,4,141,12,218,255,222,253,71,251,114,254,98,0,217,255,58,0,9,251,157,253,61,2,243,1,134,247,99,255,81,252,173,253,180,1,179,4,231,1,117,250,198,253,188,5,199,2,179,253,155,255,227,12,211,255,104,250,59,254,28,7,165,2,28,4,255,248,47,4,112,254,12,1,48,254,187,1,252,1,239,254,32,253,23,255,14,1,93,251,117,248,72,251,249,253,145,252,69,1,8,4,24,1,53,2,38,1,28,10,209,254,128,2,138,250,46,4,162,2,57,0,91,255,210,255,0,2,245,2,113,242,212,252,170,252,45,0,101,0,123,12,238,252,195,255,122,0,46,251,182,255,119,0,123,254,254,0,172,255,61,3,185,5,94,252,171,0,8,255,201,0,171,3,1,0,52,0,67,242,194,248,147,0,181,252,54,1,246,1,217,2,191,0,13,2,77,1,99,253,226,242,215,0,40,2,156,0,21,249,214,3,22,253,11,2,69,255,84,253,200,1,123,0,248,249,111,255,58,0,197,251,146,249,227,250,7,3,156,5,129,5,166,251,85,255,26,0,17,249,79,4,120,254,251,247,59,251,100,0,160,251,25,0,217,254,50,1,151,255,254,253,246,238,156,0,132,247,65,255,166,255,7,0,194,255,244,0,149,255,9,2,53,1,22,0,105,253,239,0,43,255,30,255,100,0,180,8,182,254,59,255,33,251,148,252,25,6,255,255,158,254,183,1,93,255,194,254,195,255,96,251,50,244,154,5,65,0,87,0,38,3,211,247,200,11,254,3,245,252,121,254,238,255,165,250,220,253,142,3,114,252,74,254,161,2,48,0,4,4,36,2,153,0,175,254,42,2,97,1,150,6,212,1,66,255,143,255,208,253,30,2,94,0,116,255,62,255,198,255,165,0,102,255,201,254,136,18,108,255,49,0,3,255,180,0,191,255,131,255,117,255,207,255,141,255,242,254,183,1,139,0,210,0,202,0,49,255,191,255,35,254,168,0,144,237,160,255,189,251,233,247,201,253,206,250,237,0,155,1,133,255,173,4,65,10,68,5,26,255,106,1,109,255,117,255,69,253,186,4,213,254,92,0,19,11,220,255,216,254,31,1,122,9,109,251,38,255,116,3,192,254,106,4,195,251,153,4,71,252,248,252,97,2,59,3,166,255,131,0,59,245,55,2,117,3,201,246,187,3,56,255,165,248,131,0,26,1,176,255,141,0,248,255,223,255,77,1,41,3,101,1,243,255,243,1,85,2,155,3,67,249,3,250,209,1,163,255,139,8,183,252,239,2,74,0,146,247,99,0,202,251,53,254,136,2,254,254,93,1,107,252,176,4,118,1,51,249,11,252,212,2,195,255,182,0,192,15,187,253,99,4,112,254,53,254,69,254,196,254,3,0,241,254,8,255,239,255,83,2,206,0,92,251,53,11,58,5,3,255,60,1,38,254,144,6,168,252,49,250,35,2,167,2,169,1,254,254,92,0,252,255,232,255,117,0,99,255,129,1,255,254,180,254,35,234,188,255,183,254,191,255,148,255,235,254,202,0,112,254,124,0,205,255,5,0,71,0,90,0,97,252,198,3,12,3,49,1,191,2,34,3,131,249,121,250,190,255,181,1,158,253,61,1,27,3,87,2,67,255,66,1,249,253,86,240,217,2,148,253,177,247,95,1,250,1,188,255,162,0,41,252,224,254,95,12,116,255,223,3,169,253,128,0,76,7,64,0,193,255,255,255,255,7,155,0,153,252,126,255,226,0,252,1,243,1,114,3,178,14,129,254,233,255,0,0,167,254,24,254,167,0,136,2,139,1,114,0,97,4,87,1,232,0,230,253,15,0,86,1,204,252,38,0,179,1,44,254,230,254,97,254,99,236,219,254,147,0,21,2,128,255,186,255,247,1,76,3,170,255,44,7,201,247,137,251,186,255,2,254,64,2,79,253,154,1,203,247,177,1,83,1,95,254,52,3,157,0,173,0,198,1,182,253,195,4,183,255,253,235,88,1,141,1,53,0,105,0,245,1,197,255,3,2,194,0,100,1,78,0,194,2,47,1,76,1,180,17,227,2,193,3,247,253,120,254,20,0,71,253,55,3,95,2,13,255,76,1,109,1,182,254,51,1,173,1,159,252,248,255,33,2,253,255,153,23,202,254,16,1,208,1,22,0,100,255,142,0,193,255,169,255,41,1,232,255,50,2,247,255,147,0,85,1,235,255,119,0,106,5,179,3,54,249,12,254,113,253,95,0,32,0,32,0,187,0,6,2,50,5,95,0,188,254,36,14,225,2,202,255,55,0,158,2,28,251,227,3,228,1,67,5,23,253,244,0,6,1,173,255,134,255,170,4,115,253,169,251,185,254,187,254,251,13,42,255,219,255,100,254,245,254,135,254,194,255,131,0,104,1,203,0,175,233,214,255,94,0,23,1,150,1,157,254,34,0,112,255,156,0,0,255,208,255,158,255,144,250,249,4,202,0,31,251,127,242,58,253,239,3,37,0,4,249,86,0,198,253,23,2,17,0,143,254,104,6,48,3,139,255,128,0,55,252,155,250,224,0,239,5,28,252,191,252,163,3,185,0,36,3,209,1,82,0,69,0,9,255,240,12,82,254,233,255,173,0,33,255,8,12,56,7,93,251,42,250,27,254,149,251,240,1,251,253,172,253,64,1,171,252,233,250,240,0,214,254,159,0,15,2,255,254,156,1,71,3,4,252,194,2,85,242,81,255,191,251,51,253,187,254,5,1,54,1,52,249,245,251,109,254,27,255,163,252,54,252,194,255,64,255,23,2,150,247,148,254,147,251,211,3,29,243,97,1,214,3,251,253,120,4,205,253,163,2,29,1,63,0,17,0,91,248,82,0,28,0,255,253,245,1,97,251,196,5,211,252,2,255,208,249,99,251,86,254,200,255,108,252,203,0,123,245,209,0,214,251,106,251,23,1,183,1,201,0,155,4,29,3,151,1,83,3,159,3,60,1,128,253,118,5,128,255,181,10,51,2,3,249,221,3,164,3,247,0,6,0,151,253,12,1,77,253,88,4,199,253,115,3,42,1,37,0,150,254,107,253,239,255,102,255,194,253,209,2,226,17,205,0,251,1,77,0,166,255,79,254,179,249,14,1,12,254,219,251,98,6,124,254,80,254,120,253,63,248,117,2,71,11,55,255,224,255,223,0,109,2,143,0,190,1,104,5,85,4,43,1,73,1,22,252,156,254,224,5,179,255,49,0,184,3,70,16,224,253,171,255,100,254,7,255,218,1,27,0,149,255,1,13,59,0,195,0,165,255,186,255,190,12,124,255,104,1,157,0,102,254,184,0,157,255,118,255,81,1,33,1,61,1,156,0,179,253,129,255,52,255,37,0,81,255,227,233,204,255,174,3,156,0,255,255,59,255,97,1,90,0,57,0,225,254,38,255,182,1,252,255,250,254,9,0,66,1,89,255,88,11,244,255,169,245,8,255,53,255,245,254,140,255,121,255,77,1,36,255,56,255,40,0,228,0,117,10,50,254,73,255,127,255,82,11,40,253,25,3,166,1,29,2,162,254,28,0,222,0,230,10,25,255,61,255,65,255,186,11,182,0,158,253,145,0,30,255,154,255,29,1,88,1,155,254,217,0,110,255,158,255,18,0,1,255,96,0,105,255,10,1,208,0,53,254,124,255,167,254,219,15,141,254,79,0,44,0,193,255,23,255,78,1,44,0,44,15,49,0,25,243,88,0,233,255,225,254,51,254,57,0,94,0,203,255,127,255,104,0,167,0,231,255,177,255,131,255,138,253,208,246,150,0,93,254,40,0,193,255,91,2,67,0,209,0,65,1,27,249,56,255,68,0,217,1,110,2,5,0,189,244,112,0,188,0,67,255,51,245,169,0,141,1,182,254,126,253,226,252,129,0,146,255,92,255,236,255,176,0,43,255,217,234,39,0,31,0,13,0,14,1,35,254,166,0,167,0,4,0,216,0,244,255,240,253,181,255,221,254,140,1,13,254,37,248,84,255,247,254,96,0,83,0,233,254,114,0,90,255,65,3,30,0,189,9,94,0,130,0,73,255,109,253,1,0,29,255,75,0,93,1,59,245,82,0,140,255,9,0,184,3,144,255,116,246,179,254,50,255,106,254,201,0,15,0,0,253,88,0,110,5,223,255,210,253,97,0,55,255,29,0,142,13,50,0,216,255,241,254,85,255,230,255,47,0,229,1,6,255,246,12,112,0,127,2,161,244,123,0,248,254,3,0,8,0,123,1,73,0,54,0,88,0,227,0,73,0,58,0,196,253,14,3,73,255,49,1,49,0,233,255,104,244,215,255,35,1,231,255,157,0,39,1,186,247,125,0,5,0,63,255,97,255,225,253,181,255,157,4,65,255,221,253,163,255,117,0,217,248,9,1,161,253,226,255,194,0,167,240,186,255,159,0,79,0,17,250,38,0,201,0,14,0,232,255,180,255,146,254,14,0,68,245,0,0,140,254,149,1,39,0,86,255,64,1,255,254,105,8,244,255,158,0,66,1,83,240,22,0,155,255,217,0,125,2,17,1,82,254,228,0,84,254,102,0,156,254,246,254,82,0,225,255,14,0,33,255,221,245,152,254,46,8,133,254,112,2,64,255,245,0,38,1,204,5,139,255,156,0,203,255,84,14,11,242,138,255,43,255,1,1,45,255,66,0,194,255,83,255,90,255,133,255,163,0,175,255,217,255,182,255,235,255,126,0,210,2,120,255,2,8,50,255,86,0,19,1,76,0,7,255,55,0,52,246,95,0,196,255,222,255,152,254,247,255,187,0,34,0,169,255,226,255,137,0,48,0,153,18,109,0,255,1,16,254,104,0,143,1,151,254,162,0,78,0,227,255,159,0,144,255,182,0,246,0,52,0,255,0,82,1,221,255,255,255,188,255,5,0,182,0,251,29,137,255,242,255,147,248,145,255,150,255,22,0,240,255,81,0,159,0,137,246,185,255,232,255,103,255,248,253,126,0,114,1,70,255,230,0,205,255,111,254,206,0,224,255,52,0,185,255,177,255,247,1,17,255,25,255,55,0,123,255,106,20,211,255,91,255,57,0,10,9,47,255,46,1,78,0,154,0,236,243,163,253,14,254,154,1,159,0,80,1,109,255,136,255,143,0,36,0,75,2,74,255,74,255,177,5,240,3,220,9,66,254,29,9,15,254,7,253,94,255,125,0,164,1,225,0,139,255,188,254,181,1,206,255,190,0,129,0,3,1,33,0,254,255,247,255,32,0,232,255,91,0,97,0,201,0,19,0,169,0,207,13,229,1,112,255,74,1,63,255,101,245,91,2,47,1,100,4,107,0,150,250,99,250,53,255,180,0,175,255,47,1,209,0,235,255,191,255,26,0,91,0,98,0,187,250,196,0,55,8,149,3,36,253,66,3,176,5,164,255,57,254,126,255,36,253,224,254,39,0,171,255,211,253,217,255,141,12,41,1,136,1,134,254,248,253,27,3,153,246,6,0,7,0,150,1,203,0,183,255,9,255,61,1,248,242,94,12,206,0,220,255,159,0,233,254,186,1,54,0,188,254,238,255,32,2,6,255,142,0,72,254,100,0,111,255,68,241,57,255,139,0,100,255,245,255,34,0,78,255,23,255,142,254,89,2,198,255,143,6,86,255,76,0,172,2,221,255,183,255,204,255,223,255,253,255,167,255,251,255,174,255,73,0,245,255,51,0,208,255,244,255,136,254,252,16,53,255,80,254,189,0,221,255,144,0,31,0,181,0,150,255,8,236,40,2,224,1,0,0,63,0,31,0,33,0,248,1,31,4,65,244,42,255,154,0,156,255,246,0,13,1,89,254,67,2,63,0,132,6,216,254,134,1,109,0,21,0,250,255,71,0,249,12,246,0,197,0,99,1,58,255,216,1,135,0,181,1,58,249,19,5,227,0,150,253,208,255,57,255,217,0,26,255,70,0,99,0,72,10,53,255,33,12,169,255,149,0,47,1,124,0,106,1,190,254,212,255,38,0,104,0,228,255,48,0,81,255,44,254,102,254,157,238,104,255,109,8,26,0,231,254,187,253,36,0,51,255,101,0,230,0,192,0,127,255,63,1,20,0,65,0,15,19,123,0,20,255,78,255,128,255,125,254,132,255,16,2,142,0,249,252,211,254,168,255,132,254,120,0,214,255,239,255,64,0,206,251,234,242,55,5,202,251,242,255,50,254,143,255,253,0,194,1,36,0,248,255,166,254,202,255,249,255,52,0,156,255,74,0,74,32,63,255,220,255,205,255,12,0,59,0,188,255,190,0,220,255,89,0,38,0,197,255,13,0,13,1,109,0,241,255,115,255,192,255,196,255,238,0,6,0,14,239,125,1,228,4,98,1,215,255,41,0,191,0,20,255,122,0,104,245,96,1,139,255,135,255,228,254,236,5,217,1,180,254,235,254,0,249,177,254,84,0,64,0,123,37,10,255,234,254,190,1,161,255,224,255,60,0,110,255,104,0,172,255,253,255,107,0,140,255,135,254,101,0,107,255,211,255,108,1,104,0,63,255,2,255,113,11,92,255,163,255,68,1,237,2,96,252,179,1,53,9,94,1,216,255,103,255,208,255,142,253,134,1,208,255,104,239,54,254,94,252,38,255,26,254,233,6,79,1,152,0,165,0,111,0,118,0,105,254,169,255,139,254,179,254,122,255,86,0,224,255,112,255,238,255,240,255,131,226,110,255,49,0,72,255,116,0,228,255,205,255,190,0,115,0,80,0,68,0,129,0,206,0,38,1,75,1,179,0,242,254,174,0,140,9,55,0,57,243,70,0,132,255,228,0,74,1,235,255,93,254,62,0,116,255,172,246,7,0,133,245,127,255,230,251,220,253,43,3,189,0,103,1,127,254,174,255,71,35,95,0,77,0,187,255,164,0,5,1,61,0,183,255,230,0,93,255,141,0,218,255,213,255,106,255,164,0,28,0,164,0,59,0,198,255,200,254,122,255,102,0,189,255,166,0,93,255,63,0,117,229,153,255,109,255,81,0,17,1,133,0,122,0,94,255,49,255,127,0,196,255,20,18,255,255,35,5,6,2,93,255,10,255,54,0,239,0,154,0,102,255,9,1,208,7,25,0,227,0,42,0,179,0,88,0,138,242,42,255,182,0,182,1,90,0,196,0,187,255,134,0,200,255,61,254,204,2,160,251,225,254,118,0,230,0,219,255,145,0,28,1,6,255,139,0,77,252,203,0,152,243,199,255,151,0,129,12,50,3,169,255,91,1,26,254,55,255,152,4,187,254,58,252,249,254,72,255,238,0,100,255,116,254,152,0,191,3,197,255,223,255,97,255,253,255,178,36,137,255,175,255,206,255,67,0,9,0,27,0,194,255,135,255,46,255,48,0,45,255,5,0,140,1,121,2,34,0,240,255,67,0,9,255,179,255,128,0,185,1,56,15,251,0,202,3,119,0,125,254,221,255,124,0,192,255,104,253,106,230,101,0,204,255,19,0,44,0,124,255,79,0,219,2,101,255,250,254,116,255,225,255,65,255,146,255,20,1,94,255,207,255,81,0,139,255,15,0,198,253,164,1,48,251,131,255,153,14,161,255,32,2,107,255,207,1,127,255,167,254,94,1,183,0,173,0,197,0,208,1,180,0,7,255,147,254,239,252,247,255,173,242,21,255,132,255,225,0,92,238,196,0,106,255,167,255,167,255,54,0,146,255,137,0,81,254,16,1,244,255,249,255,114,0,55,255,166,0,34,6,182,255,168,255,131,23,94,1,181,255,68,0,227,255,175,255,206,255,57,0,194,255,103,0,61,0,20,1,22,0,125,255,122,255,237,242,196,255,187,242,201,254,151,255,90,0,97,255,34,255,151,0,224,0,46,255,8,1,192,0,29,0,172,255,29,242,150,255,125,255,203,255,100,255,196,0,50,255,152,255,18,0,124,244,122,0,146,0,248,253,2,0,38,1,93,254,255,255,231,255,255,254,118,36,87,0,201,255,214,255,30,0,92,0,35,0,195,0,31,0,59,0,88,0,47,0,47,0,36,255,52,2,106,249,170,1,106,0,140,1,97,0,35,5,27,9,167,0,19,251,235,3,220,2,212,254,170,254,162,1,87,0,236,0,11,255,187,8,11,0,213,2,232,255,87,255,32,254,29,11,96,0,222,255,67,0,89,3,28,0,50,0,92,0,52,8,172,255,168,253,58,248,96,247,93,255,43,1,175,1,199,252,229,254,43,1,158,255,135,1,191,255,164,255,56,255,79,253,188,8,174,255,175,255,204,255,127,0,86,0,119,255,193,254,255,245,166,255,35,2,58,255,10,0,195,0,146,254,128,245,179,255,22,255,144,255,11,255,14,1,199,0,114,10,199,255,95,253,247,255,5,4,225,255,55,1,206,255,96,255,81,255,67,9,151,10,153,1,237,255,22,0,12,255,56,1,98,255,14,1,131,255,9,255,118,0,165,255,166,253,86,0,174,0,40,255,18,0,232,11,95,248,171,0,63,248,215,254,39,1,218,255,58,255,27,255,107,1,243,255,127,0,13,0,54,255,139,255,65,0,74,0,63,0,125,0,194,255,254,255,225,253,88,253,83,239,126,255,69,1,207,255,11,255,206,255,3,254,105,255,237,255,3,0,152,0,44,252,127,255,22,255,143,1,93,1,171,0,60,255,88,19,254,255,36,0,32,1,3,3,9,9,231,0,217,255,60,2,60,244,77,0,11,254,41,255,28,255,68,254,62,3,200,0,68,255,99,255,176,12,23,1,9,243,0,0,76,0,10,0,160,0,176,255,135,0,102,0,163,254,174,0,226,255,168,255,111,255,51,255,10,0,71,255,177,0,222,255,25,0,31,0,218,0,252,255,191,0,172,0,228,0,120,255,78,255,12,1,126,2,231,13,55,0,198,0,145,0,86,1,231,255,108,248,50,11,178,254,103,252,149,7,48,254,17,1,75,255,6,254,235,255,102,254,116,0,77,255,207,255,239,254,234,255,220,255,238,250,18,1,217,248,65,1,130,254,238,0,120,242,188,255,62,255,32,0,161,255,6,254,72,0,64,0,183,254,19,0,217,255,91,1,210,254,204,0,145,0,184,255,87,3,144,255,244,241,221,3,15,245,130,1,193,245,41,254,101,0,101,255,1,1,35,1,30,0,103,255,185,0,172,0,255,1,20,0,166,0,18,1,29,0,49,244,129,0,33,0,37,255,51,255,6,0,47,0,105,254,137,0,51,2,150,255,239,247,76,0,201,0,157,255,86,255,179,255,170,0,72,238,72,254,160,255,84,252,214,251,81,0,205,0,102,1,179,1,178,255,108,255,55,255,171,255,205,254,206,254,14,0,209,255,155,255,69,255,120,255,124,1,252,255,224,255,222,255,202,255,16,2,198,255,245,24,46,1,177,255,52,0,228,255,191,255,179,255,244,255,64,35,156,255,6,1,20,0,189,255,225,255,50,0,223,255,226,255,116,255,70,1,110,251,208,254,120,255,23,255,170,0,60,0,58,1,90,255,48,255,151,255,11,255,87,255,184,255,137,0,251,227,254,255,119,1,152,0,226,0,50,255,171,254,47,1,47,0,242,3,68,255,65,2,220,254,3,242,244,255,61,255,20,0,117,8,50,255,168,255,173,255,124,255,216,255,69,254,236,0,179,254,179,0,45,255,200,255,62,1,103,254,34,12,95,0,116,45,84,1,204,0,189,254,167,0,76,0,61,0,65,0,99,255,71,0,235,255,38,0,66,0,135,1,204,255,20,0,239,255,11,0,3,1,45,0,62,255,184,1,104,13,122,0,212,1,173,253,192,248,94,0,85,254,123,255,149,0,239,254,61,0,34,230,48,0,97,0,94,255,93,0,146,1,152,255,49,255,64,0,234,254,92,0,131,1,3,0,96,0,254,255,229,255,226,255,84,0,64,0,35,0,191,255,98,0,85,0,240,255,8,255,250,30,74,0,4,0,152,255,83,0,208,255,40,0,200,247,170,255,167,255,99,0,114,255,65,0,103,245,63,0,81,254,11,2,175,2,212,0,21,250,3,0,59,0,55,0,250,255,22,0,248,255,108,255,180,0,78,0,153,30,193,255,173,255,13,0,69,255,140,255,156,0,227,255,70,255,96,255,148,0,174,255,209,254,90,255,112,0,153,255,217,255,91,255,11,11,202,255,230,255,24,0,17,244,78,0,21,0,128,0,175,255,231,255,134,255,51,0,202,255,237,255,188,0,238,255,255,255,116,255,238,255,107,224,124,0,210,255,45,0,194,253,12,0,106,255,147,0,65,0,47,255,116,254,68,254,214,240,221,254,25,255,40,1,244,0,76,0,180,0,36,0,241,245,147,2,193,255,205,12,171,255,48,0,250,253,159,254,130,0,50,0,13,0,82,1,169,254,236,254,240,255,97,1,108,232,179,255,18,0,139,0,43,0,79,1,38,1,99,0,219,0,186,1,231,255,203,255,40,0,15,1,175,0,230,254,165,255,174,1,180,238,241,255,215,244,194,255,229,255,86,255,33,0,87,253,146,255,180,255,153,0,42,0,122,255,111,255,222,0,79,255,217,255,58,1,222,8,14,2,244,1,113,9,83,1,16,7,239,255,208,1,243,253,159,255,124,0,224,255,114,1,48,0,117,249,194,255,87,255,82,10,207,9,213,255,243,251,72,255,54,0,199,253,8,254,9,255,216,255,71,1,7,0,82,0,59,255,214,10,222,255,141,244,52,255,144,255,194,0,150,254,187,0,65,0,90,255,115,0,131,255,14,0,210,0,144,0,181,255,57,0,1,255,105,255,18,242,103,255,182,0,89,0,30,246,98,0,247,254,83,255,123,255,4,1,231,255,244,250,35,0,131,0,158,255,171,255,19,255,82,0,73,5,47,0,2,15,148,0,171,0,183,0,234,0,89,0,163,255,47,0,102,0,252,255,90,0,164,11,33,1,25,255,97,1,241,1,147,255,190,0,203,244,185,2,136,0,90,0,12,255,42,1,137,255,249,253,206,255,207,0,213,255,160,250,100,1,142,7,189,2,237,246,159,2,71,0,200,255,89,255,47,241,91,241,153,255,134,0,28,255,243,255,27,0,211,255,151,255,172,0,179,255,233,255,53,0,110,0,138,255,176,255,92,255,64,255,205,253,137,1,198,255,84,254,152,254,112,14,162,0,83,255,147,6,82,254,196,1,164,255,107,0,215,255,28,0,171,255,165,1,190,255,98,1,168,255,211,2,191,10,117,244,31,254,122,255,25,255,111,255,3,0,65,0,168,255,189,0,187,0,151,0,174,0,220,255,240,0,3,255,21,255,62,255,222,234,209,255,158,255,82,1,25,254,175,255,221,255,174,255,72,254,31,0,109,0,217,0,20,1,243,248,22,1,17,1,143,254,117,2,219,254,243,253,8,241,73,0,200,255,149,254,173,6,177,0,3,245,28,3,94,255,171,254,152,4,181,255,21,2,86,3,207,2,242,0,62,255,90,0,109,255,203,0,120,255,118,255,4,253,6,0,29,245,243,255,80,4,217,5,73,4,90,0,157,252,50,253,195,254,119,0,180,0,160,0,1,1,228,9,211,253,194], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1855025);
/* memory initializer */ allocate([255,14,0,153,2,240,5,200,1,58,3,138,1,163,253,140,3,222,0,116,255,121,0,121,0,232,0,124,0,96,0,169,255,48,0,205,255,41,0,115,225,219,255,130,0,245,255,223,255,119,255,16,0,42,0,229,5,248,255,119,0,173,255,238,255,64,0,41,0,78,255,228,255,182,0,20,2,166,2,181,255,21,1,26,255,186,255,185,255,248,255,106,255,65,1,102,231,236,255,125,255,191,255,139,0,41,255,101,255,229,255,146,255,255,254,32,0,201,0,215,0,184,0,228,34,150,255,206,255,66,0,15,0,212,255,203,0,218,255,19,0,178,255,65,0,135,0,133,255,166,0,117,0,76,0,4,0,34,0,166,255,96,23,59,0,184,255,100,1,192,255,6,0,194,255,43,0,170,255,81,255,150,255,10,0,25,0,228,14,121,255,15,243,142,0,92,1,155,255,221,255,122,1,6,255,150,255,213,254,237,0,40,0,224,255,236,0,247,253,63,0,113,255,26,2,0,255,43,0,211,255,106,6,214,2,103,243,109,0,27,252,3,0,0,255,229,255,74,255,178,255,4,240,247,255,231,0,34,0,9,0,250,255,155,0,26,11,53,0,126,255,122,254,110,255,168,0,182,255,25,248,69,252,64,2,139,253,180,255,70,0,140,0,225,254,111,254,198,3,103,1,161,4,30,255,201,2,241,2,29,253,114,239,36,13,75,0,43,255,27,0,84,255,222,255,171,0,138,255,210,255,92,255,243,255,202,255,53,255,102,255,244,255,65,0,63,241,132,242,41,1,152,255,163,255,175,255,69,0,77,255,191,254,51,0,47,0,242,0,241,255,112,255,213,255,11,11,67,0,207,254,54,0,28,244,57,0,241,255,85,254,55,1,51,255,226,0,22,254,37,0,107,1,168,255,104,254,198,255,222,0,102,255,182,255,203,255,75,19,165,1,67,0,26,0,132,0,60,0,159,255,255,255,213,255,72,1,2,0,204,1,190,255,245,255,211,255,200,255,170,255,183,214,127,255,58,0,231,255,39,0,28,0,26,0,45,0,195,255,117,255,234,255,121,255,230,254,251,253,144,254,55,0,209,255,30,0,146,255,47,0,75,0,243,255,65,0,215,255,104,0,137,18,107,255,157,255,28,0,165,1,5,2,200,255,81,0,203,254,67,0,214,255,250,255,17,0,196,255,105,255,50,0,172,255,247,255,29,0,184,255,53,244,82,0,61,255,41,0,242,255,50,255,222,255,198,255,238,255,30,0,106,8,236,255,2,0,255,255,41,0,246,255,7,0,86,0,238,1,123,0,72,1,73,0,213,0,227,255,17,0,43,0,164,255,195,255,247,255,126,255,143,255,33,0,228,255,235,229,58,255,71,255,20,255,183,0,148,255,227,2,60,0,98,0,198,254,66,0,10,0,167,243,97,255,222,244,118,0,37,0,215,255,137,255,15,12,43,0,220,255,42,0,106,0,82,255,205,242,164,255,114,255,19,255,94,0,197,255,133,255,139,255,144,0,181,255,146,0,244,254,49,2,120,251,80,1,197,5,207,0,89,0,130,0,127,0,179,14,140,254,48,0,99,0,204,0,84,0,209,0,103,0,118,0,125,0,70,1,227,255,50,255,139,0,195,255,94,0,77,0,224,25,93,255,23,0,27,0,152,255,150,0,180,255,51,255,70,255,226,255,29,255,198,255,17,0,25,0,120,230,237,255,190,255,211,255,184,255,41,0,49,0,177,255,105,0,252,255,139,255,219,255,73,255,216,0,229,255,233,255,225,255,96,245,53,0,233,255,210,255,247,255,246,255,50,0,244,255,206,255,200,255,35,0,122,21,146,255,254,255,44,0,255,255,13,0,52,0,238,255,195,255,176,255,227,255,25,0,61,0,219,255,93,0,237,255,67,0,75,0,215,255,254,0,161,0,118,0,205,242,142,1,247,255,48,255,113,255,207,0,121,255,224,255,171,0,187,0,62,255,210,1,201,255,158,0,34,0,105,0,122,19,27,0,215,255,20,0,87,0,146,255,39,0,80,0,219,255,8,0,231,255,212,255,148,255,85,255,146,254,208,0,31,255,1,0,132,255,21,0,81,0,147,215,205,255,33,0,205,255,141,0,220,255,106,0,156,255,64,1,122,0,3,0,10,1,72,0,248,255,144,255,55,0,149,255,198,239,187,255,0,0,71,0,103,255,176,255,206,255,20,0,144,255,225,0,66,248,17,1,237,255,129,255,109,0,231,255,47,0,57,0,158,255,246,255,42,0,231,255,10,0,24,0,41,0,183,255,45,0,61,242,142,254,141,12,54,0,169,255,67,0,71,255,100,0,223,255,215,255,3,0,218,255,70,0,148,255,136,255,189,255,112,255,75,255,223,255,152,255,173,1,89,0,81,3,206,11,51,245,171,254,184,0,8,255,98,2,152,1,34,255,184,0,84,0,192,255,223,1,110,255,47,0,156,255,13,0,17,0,249,255,58,0,243,255,220,255,233,255,255,255,231,255,10,0,106,10,143,255,215,255,116,255,248,11,105,0,31,0,226,11,181,255,124,255,143,255,80,0,156,255,217,255,216,0,252,255,7,0,213,255,242,0,19,0,249,251,219,2,181,241,232,255,236,255,109,0,126,0,164,11,19,0,245,255,208,255,57,0,118,255,245,255,45,255,105,255,28,2,143,255,146,255,0,0,97,254,150,0,176,255,176,255,209,0,174,255,164,235,131,255,120,1,8,0,131,0,118,255,30,0,102,252,192,254,181,0,181,255,138,0,144,255,146,0,184,255,64,0,181,255,250,254,8,19,245,255,195,255,37,0,51,255,48,0,47,247,82,0,106,0,93,0,190,255,48,0,71,0,29,0,72,0,32,0,29,0,17,0,5,0,34,0,29,0,227,255,184,255,50,0,234,225,142,255,139,255,47,0,11,0,19,0,100,0,48,0,228,255,248,255,53,0,21,0,80,0,213,255,37,0,164,0,22,0,241,255,118,235,233,255,224,255,108,0,52,0,7,0,95,255,11,0,84,0,141,0,248,255,244,255,231,255,111,0,146,0,160,255,66,0,220,28,54,0,17,0,202,255,62,0,44,0,190,255,243,255,26,0,13,0,85,0,177,255,235,255,98,0,156,0,181,0,153,255,68,255,221,255,77,255,83,0,117,0,164,255,49,0,71,255,216,14,166,255,14,0,42,0,94,0,173,255,78,255,100,255,248,255,33,0,42,0,204,0,42,0,1,0,171,255,47,0,10,0,52,42,36,0,8,0,26,0,209,255,205,255,67,255,83,0,209,255,233,255,104,0,26,228,189,255,55,0,21,0,68,0,8,0,172,255,196,255,213,255,142,0,215,255,27,0,184,255,186,255,86,255,115,255,202,0,58,255,151,255,41,0,31,242,222,255,108,255,34,0,194,255,95,255,236,255,183,255,128,0,162,0,105,223,4,0,185,255,210,255,12,0,27,0,48,0,215,255,50,0,237,255,168,255,7,0,79,0,29,0,237,255,225,255,207,255,109,255,162,248,153,255,43,255,28,0,73,255,23,16,87,0,6,0,250,255,51,0,66,255,89,255,140,255,23,0,230,255,7,0,218,255,66,21,179,248,175,255,197,0,105,0,134,255,65,0,220,0,32,0,199,255,217,255,241,255,4,0,112,0,201,255,117,255,199,252,217,3,147,255,254,9,218,0,94,0,65,0,72,255,197,12,101,0,191,255,42,0,116,1,218,255,58,0,8,0,113,255,224,253,244,254,121,0,38,0,61,0,193,255,246,255,226,255,204,255,180,255,182,255,222,229,251,255,96,255,76,0,179,255,74,0,118,1,107,252,239,0,53,255,38,2,172,255,207,254,36,1,205,255,36,0,135,0,177,255,27,0,187,255,203,254,209,17,189,255,11,0,196,255,43,0,18,0,254,255,8,0,241,255,20,0,22,0,254,255,215,255,164,246,37,0,177,255,67,0,27,0,172,255,97,1,43,255,224,246,58,0,39,0,126,0,178,255,158,255,166,255,253,255,247,255,213,255,254,255,227,255,251,255,107,255,42,0,98,0,147,255,137,0,58,0,173,255,218,255,51,0,125,25,50,0,97,0,225,255,8,0,132,0,185,255,201,255,11,0,120,0,2,0,213,255,136,0,219,255,171,255,150,0,133,0,67,0,215,255,60,254,152,255,4,0,126,0,100,0,156,245,148,255,147,255,192,255,103,2,181,255,45,0,10,0,199,255,199,255,148,255,167,0,38,255,246,255,181,254,230,255,235,255,161,25,73,0,169,253,126,0,233,255,250,0,153,255,252,255,228,255,236,255,221,255,237,255,51,0,9,0,231,255,216,255,44,212,254,255,28,0,244,255,23,0,153,13,169,0,159,0,39,255,208,255,114,0,163,255,222,255,65,255,193,255,31,0,182,0,79,0,90,0,55,0,67,0,111,255,153,1,190,0,145,225,230,255,18,0,71,0,143,255,176,255,69,0,235,255,229,255,135,255,51,0,108,255,103,0,196,0,166,10,189,255,206,11,228,255,26,0,157,255,51,0,24,0,61,0,104,0,89,0,199,255,233,255,144,255,43,0,6,0,13,0,72,255,88,255,117,0,227,255,73,7,253,255,20,0,8,0,30,0,32,0,175,255,80,0,236,255,197,255,37,0,19,0,149,255,176,240,253,254,44,0,23,0,127,255,24,0,190,255,229,255,1,244,116,0,9,0,180,255,56,0,173,255,25,0,54,0,236,255,2,0,230,0,56,0,215,255,131,0,241,255,194,255,61,0,56,0,74,0,222,255,110,0,254,17,252,255,18,0,209,255,75,1,150,255,178,255,70,0,53,0,70,0,234,255,77,0,185,255,196,255,155,255,70,0,7,0,104,0,249,255,39,0,229,255,42,28,253,0,241,255,0,0,160,255,32,0,50,0,246,255,33,0,10,8,11,0,241,255,42,0,242,255,51,0,4,0,253,255,245,255,170,255,10,0,33,0,21,0,238,255,225,255,249,255,53,0,249,255,95,0,7,0,75,0,206,211,7,0,17,0,240,255,173,255,37,254,137,252,139,251,1,0,155,255,5,0,210,255,110,0,166,255,209,255,241,255,19,0,66,0,18,240,104,0,43,0,105,0,130,255,181,0,43,0,137,249,175,255,245,255,33,0,223,255,33,0,28,0,212,255,35,0,250,255,218,255,68,0,216,255,67,0,73,0,227,255,171,0,206,46,42,0,248,255,190,255,190,255,40,0,237,255,14,0,33,0,193,255,24,0,94,0,162,255,150,255,72,2,74,1,148,255,255,240,14,3,212,254,245,255,209,254,82,255,39,255,253,255,24,0,168,0,187,0,90,255,54,0,238,0,243,254,229,255,182,0,252,255,184,255,209,255,32,0,39,0,198,29,210,255,189,255,203,255,56,0,123,0,206,255,69,0,220,255,237,254,116,2,201,255,195,0,200,255,247,254,124,255,217,255,252,255,169,0,113,0,76,255,237,255,88,0,229,230,42,0,255,254,156,4,103,1,79,1,237,14,116,0,79,0,3,0,163,255,67,0,212,255,58,0,240,255,9,1,172,0,217,255,212,255,18,0,92,0,4,0,218,0,122,0,79,244,150,0,138,0,106,2,66,0,150,253,146,1,179,8,10,0,38,0,52,1,82,1,186,255,9,1,23,4,152,255,74,255,49,1,94,255,157,255,254,1,236,255,142,255,17,2,214,255,15,242,52,0,176,255,198,254,204,2,225,255,3,1,59,0,183,255,139,255,38,0,212,255,240,255,182,255,60,236,35,0,10,0,226,255,54,0,217,0,36,0,51,255,164,0,203,241,21,242,13,255,133,255,209,255,169,255,224,255,62,0,129,0,254,255,131,0,220,255,54,255,59,255,37,0,221,255,70,254,117,255,187,255,197,255,29,0,194,255,189,255,239,255,214,255,74,0,10,0,107,0,74,0,147,255,40,0,30,216,223,255,118,243,102,254,150,255,0,2,40,0,239,255,109,0,67,0,99,0,170,0,53,0,34,0,188,255,240,255,55,15,185,255,140,255,1,0,96,2,66,0,41,255,34,0,77,0,50,0,211,255,183,255,3,0,11,0,223,255,18,0,222,255,58,0,25,0,68,17,96,0,77,0,189,255,23,0,173,255,188,229,226,0,224,255,106,255,102,255,30,0,244,255,248,255,249,255,89,0,42,0,173,0,205,255,38,0,196,248,40,0,208,255,216,255,81,0,34,0,81,0,66,0,16,0,20,0,3,0,99,0,41,0,123,0,52,0,154,0,20,0,218,255,6,0,137,42,212,255,22,0,217,255,55,0,222,255,25,0,211,255,234,255,139,0,19,0,236,255,192,255,62,247,39,254,143,255,60,1,127,0,225,255,128,0,149,254,132,255,196,0,3,1,196,255,48,241,215,255,153,255,104,0,176,255,123,254,179,0,110,0,83,0,102,12,60,0,59,255,101,0,66,0,209,255,149,255,96,0,229,255,45,0,235,255,6,0,116,0,205,255,248,255,174,253,121,1,233,254,158,0,97,255,243,17,93,255,46,255,19,0,3,0,220,254,189,255,14,0,115,0,215,255,131,255,102,255,249,254,155,255,4,0,245,255,167,255,130,0,58,0,32,0,92,0,16,0,126,0,163,255,157,255,113,239,187,255,88,0,5,0,143,255,238,255,35,0,31,0,208,255,240,255,35,0,62,0,233,244,14,0,121,0,19,0,41,0,125,0,154,255,26,0,168,204,6,0,226,255,249,255,60,0,4,0,36,0,216,255,230,255,54,0,199,255,247,255,226,255,13,0,255,255,73,0,125,255,29,0,0,1,39,0,205,255,244,255,252,6,4,0,10,0,198,255,17,0,220,255,254,255,13,0,59,0,236,255,235,255,173,0,129,0,77,254,149,255,42,255,33,0,6,12,13,0,31,0,148,0,97,244,201,254,38,0,25,0,9,255,226,253,34,0,106,0,120,254,85,0,53,255,182,0,24,255,167,1,117,2,73,255,32,3,46,254,73,12,62,246,207,254,39,0,22,0,41,0,0,0,242,255,159,2,75,255,125,12,109,0,84,11,72,0,192,255,8,0,158,1,133,0,244,0,249,254,53,0,187,255,70,0,68,202,243,255,21,0,50,0,12,0,242,255,244,255,249,255,97,0,224,255,24,0,51,0,232,255,227,255,53,0,34,0,237,255,219,246,208,3,25,0,198,255,18,0,208,255,70,246,201,255,225,255,91,255,220,255,28,0,230,255,92,0,60,0,137,0,69,0,35,235,131,255,174,7,102,255,190,255,243,255,172,255,243,255,81,0,210,255,160,255,50,0,206,255,142,255,15,0,30,0,45,255,109,255,213,253,158,15,88,0,102,1,97,255,151,255,205,255,147,255,240,255,70,0,91,0,12,1,125,0,161,255,194,255,38,0,101,243,7,14,241,255,92,0,184,255,115,0,144,0,216,255,142,0,172,0,72,0,239,255,23,0,1,0,28,0,218,255,121,255,220,0,176,255,77,255,9,0,224,255,250,255,37,0,223,255,253,255,167,255,146,28,5,0,194,0,243,255,23,0,31,0,42,0,84,0,197,0,93,255,5,255,239,254,193,0,206,0,155,253,138,1,141,13,27,10,67,253,62,0,45,1,152,255,200,0,164,0,55,255,39,254,52,0,39,254,128,0,131,254,148,1,187,255,26,255,231,253,157,0,133,1,249,255,223,10,242,11,95,0,197,255,82,6,1,0,4,0,53,0,250,255,28,0,10,0,2,0,82,0,28,0,248,255,242,255,25,0,59,0,10,0,252,255,36,0,247,252,136,236,29,0,8,0,85,0,213,255,119,255,222,255,53,0,198,255,1,0,229,255,91,0,15,0,80,0,237,255,70,255,211,1,94,0,130,254,129,0,71,1,237,11,35,255,143,1,251,244,66,4,22,1,254,255,93,255,114,254,126,0,246,254,180,0,21,255,70,0,238,255,222,255,211,255,159,0,224,255,66,0,11,0,105,12,68,255,27,0,35,0,204,255,114,0,228,255,120,255,186,0,98,8,100,0,92,0,6,0,58,0,186,255,159,0,242,255,224,255,9,0,6,0,229,255,183,255,28,0,23,0,232,255,101,0,148,0,80,0,204,255,229,255,203,255,220,255,4,0,182,255,47,0,226,255,148,255,34,0,45,28,12,0,31,0,239,255,71,255,246,12,199,0,192,0,122,13,169,255,3,0,47,0,46,0,115,255,49,0,83,0,174,255,124,255,174,255,68,0,138,0,249,251,20,255,134,1,219,255,23,0,162,255,249,255,9,0,114,244,202,248,213,255,23,0,25,0,177,255,63,255,179,255,252,242,229,242,117,255,56,0,163,0,26,243,174,255,231,255,35,0,96,0,73,0,166,0,102,255,174,0,135,255,14,0,167,255,101,0,89,241,168,254,16,255,221,255,145,1,242,255,47,0,207,255,24,0,178,255,24,0,6,0,68,0,51,0,111,255,20,0,83,0,57,0,147,0,156,255,60,0,33,0,203,255,11,0,37,0,95,233,163,255,189,255,247,255,117,0,112,0,205,255,60,0,48,0,49,0,72,1,37,1,127,0,198,254,50,244,118,1,211,12,170,255,76,2,166,254,180,1,249,255,230,255,168,255,104,0,205,0,150,0,147,0,34,0,126,0,85,0,46,0,131,255,137,255,75,0,13,0,144,0,137,14,19,1,185,255,43,0,163,0,183,255,220,254,131,254,177,255,33,0,79,0,177,255,34,0,162,255,18,0,229,0,63,0,28,0,212,255,97,0,234,241,77,0,161,255,94,255,163,0,62,0,36,24,81,0,205,255,237,255,251,255,109,0,71,0,7,0,219,255,156,255,225,255,162,255,188,0,169,0,242,255,46,10,95,254,18,0,237,238,231,255,180,0,108,0,17,0,33,0,48,0,210,255,163,255,179,255,32,0,219,255,185,255,241,254,208,255,239,254,242,255,115,0,197,255,200,254,250,242,26,244,71,0,90,255,123,1,209,0,114,255,22,0,89,0,215,255,216,255,249,255,206,255,8,0,241,255,12,0,186,255,229,255,229,255,25,0,225,255,38,0,251,255,15,11,167,255,248,255,206,255,146,255,88,5,197,255,253,246,6,0,179,0,75,0,189,0,170,0,201,255,74,1,186,255,172,0,67,0,20,254,199,255,176,242,9,0,163,255,120,211,14,0,255,255,235,255,65,0,241,255,45,0,234,255,40,0,246,255,215,255,23,0,227,255,160,255,201,255,190,255,199,255,195,255,227,255,241,255,155,255,153,217,33,0,42,0,221,255,42,0,212,255,198,255,11,0,216,255,27,0,21,0,203,2,197,254,1,255,141,255,200,6,4,0,41,0,186,255,205,255,148,255,160,0,247,255,87,0,250,255,36,0,236,255,188,255,10,0,82,0,223,255,214,255,15,0,199,255,216,255,225,255,21,0,39,39,62,0,215,255,246,255,85,0,191,255,244,255,195,255,184,255,158,253,128,0,180,255,198,0,111,1,44,238,60,0,158,0,243,255,122,255,211,255,223,255,245,255,205,255,184,255,111,0,68,255,232,0,18,254,229,255,42,0,46,0,233,255,137,0,102,12,242,241,211,0,152,0,155,0,213,254,56,0,233,255,133,255,132,0,50,0,28,0,192,255,28,0,9,0,239,255,31,0,112,0,237,255,4,0,45,0,249,227,54,0,195,255,249,255,87,0,164,0,195,0,227,255,208,255,28,0,196,255,70,0,187,255,112,0,217,254,5,0,167,255,38,0,36,0,19,211,17,0,230,255,192,255,34,255,91,0,233,255,167,255,0,0,162,255,143,8,182,255,172,255,195,255,215,255,57,0,24,0,221,255,228,255,219,255,230,1,131,0,115,14,235,254,64,0,131,255,13,255,14,1,57,1,144,255,145,0,47,0,210,244,2,255,146,255,229,255,187,255,170,254,136,255,216,0,35,0,24,0,62,0,217,255,227,255,98,9,249,255,253,255,14,0,209,255,229,255,4,0,27,0,20,0,81,0,138,0,75,0,178,0,165,1,129,244,248,243,172,255,216,255,198,255,61,255,74,255,101,0,69,255,6,0,173,255,13,1,224,255,157,255,51,0,218,255,44,0,82,0,242,255,221,255,0,0,8,0,233,255,2,42,183,255,199,255,68,0,107,0,85,0,77,0,101,0,1,0,228,255,103,0,246,255,48,0,55,0,33,0,163,255,238,255,8,0,28,0,242,255,193,253,28,0,64,210,90,0,70,255,58,0,38,0,214,255,108,8,174,255,28,0,233,255,43,0,43,0,8,0,25,0,65,0,0,0,203,255,28,0,168,255,132,1,220,255,107,1,64,0,252,11,56,0,64,1,54,255,151,242,73,0,173,254,99,255,117,1,40,255,213,255,171,0,140,0,75,254,113,255,252,244,155,255,53,0,145,255,65,0,217,255,65,0,226,255,69,0,201,255,49,0,45,0,126,0,174,0,220,0,73,0,155,255,196,255,105,255,243,255,215,255,208,255,247,255,25,0,134,255,176,255,110,246,19,0,94,0,14,0,238,255,237,255,60,0,76,243,246,255,62,13,241,255,147,254,241,255,183,255,34,255,51,1,70,0,161,255,237,0,114,255,93,255,212,255,118,255,249,255,6,0,220,255,189,255,9,0,234,255,251,39,200,255,248,255,44,0,101,255,139,255,234,255,224,255,182,255,242,255,224,6,17,239,240,24,12,248,58,11,56,246,7,250,102,0,83,27,13,251,187,243,26,4,197,255,20,6,22,252,0,6,0,4,75,7,40,0,124,251,189,245,43,255,246,251,108,253,35,1,61,252,189,254,206,1,220,252,171,8,165,252,173,6,38,2,194,242,63,1,24,0,132,2,82,12,151,17,87,248,232,2,194,0,105,255,25,251,218,250,217,11,125,252,238,255,1,0,0,0,2,0,0,0,28,0,67,251,115,241,35,246,79,255,116,251,105,1,155,254,119,253,53,254,44,5,159,9,220,243,5,243,193,253,72,245,148,255,135,255,4,254,204,253,175,252,251,252,224,254,0,0,8,0,0,0,254,255,5,0,179,2,166,253,221,8,69,9,21,248,18,3,195,11,162,12,149,250,202,254,147,2,154,254,34,4,238,249,7,4,27,3,206,8,219,253,78,1,69,1,87,2,220,255,255,255,255,255,254,255,3,0,4,0,62,254,235,253,135,249,120,248,246,251,132,253,90,250,192,254,135,10,160,4,185,2,102,4,135,4,154,11,193,1,226,255,246,247,109,251,84,253,190,255,137,3,213,255,1,0,0,0,3,0,0,0,3,0,228,0,16,1,177,255,50,253,186,7,155,2,56,245,227,5,155,248,228,252,140,4,35,0,168,238,116,238,125,249,93,16,85,25,17,254,185,6,153,249,242,253,202,1,0,0,129,1,73,255,255,1,103,255,23,248,136,254,132,11,210,245,114,252,27,253,85,254,200,251,80,8,53,2,29,254,255,6,82,247,211,255,76,251,31,3,0,2,74,237,182,5,255,1,142,248,15,0,0,0,0,0,1,0,3,0,8,0,157,252,83,253,116,255,179,20,120,1,133,252,121,6,51,7,71,250,239,250,6,2,224,237,47,1,235,254,118,253,159,255,4,9,89,253,208,2,85,255,37,254,243,254,0,0,251,255,4,0,255,255,9,0,125,251,166,236,148,6,3,248,171,3,51,3,17,253,91,255,163,255,233,246,50,1,197,3,135,19,45,2,201,255,25,252,30,0,220,255,221,3,112,249,198,249,62,1,253,255,248,255,252,255,1,0,247,255,110,254,0,32,219,1,32,8,94,254,53,249,239,254,201,255,71,254,26,3,177,255,16,1,9,248,21,3,218,8,106,3,191,9,115,2,155,8,188,4,228,251,133,1,14,0,232,255,197,255,10,0,133,0,233,253,120,251,141,251,110,255,180,0,40,4,134,14,124,250,129,4,81,7,219,253,94,249,57,250,209,0,213,2,84,252,104,8,56,7,166,2,189,9,0,18,245,255,0,0,255,255,253,255,253,255,2,0,78,1,169,2,161,2,0,224,118,15,217,243,105,6,220,5,160,4,244,254,181,243,59,2,190,3,105,253,249,251,154,252,94,253,182,251,239,253,78,0,188,4,120,0,248,255,243,255,251,255,214,255,219,255,14,254,24,5,19,246,194,6,157,254,182,5,11,9,225,7,109,254,38,248,43,2,111,5,119,3,247,7,110,1,135,0,85,0,115,1,11,5,31,255,79,1,211,255,0,0,1,0,2,0,255,255,2,0,185,251,251,254,177,12,140,12,171,248,166,3,121,249,247,250,118,5,17,247,51,255,123,6,130,2,81,4,239,2,48,11,147,4,23,252,62,1,222,254,60,0,202,255,5,0,3,0,5,0,2,0,1,0,151,255,78,2,36,0,62,255,40,7,129,253,9,3,171,12,66,2,4,11,172,1,228,7,111,2,200,247,204,255,181,254,9,252,248,11,165,254,209,254,180,251,61,0,255,255,255,255,0,0,2,0,255,255,80,2,127,0,119,3,186,251,253,244,13,10,146,245,99,249,41,245,48,0,246,254,63,252,196,4,40,254,167,0,129,12,94,4,83,255,24,5,230,255,125,252,76,0,0,0,3,0,0,0,1,0,255,255,50,253,22,253,179,3,244,253,142,0,190,3,183,249,247,252,174,250,129,1,190,253,221,228,157,0,222,254,77,5,89,249,228,1,117,0,80,247,104,241,186,252,160,255,255,255,11,0,5,0,4,0,2,0,219,1,86,254,244,1,1,253,0,247,224,4,152,8,219,248,32,252,31,255,195,253,173,251,192,252,251,9,206,244,125,13,239,16,168,255,120,251,126,249,162,255,223,255,0,0,0,0,1,0,254,255,249,255,109,255,0,224,180,4,99,251,66,253,164,253,254,252,8,4,83,255,2,3,93,3,99,2,3,254,34,3,45,254,71,3,235,1,239,252,11,2,99,253,73,0,222,255,0,0,0,0,254,255,253,255,253,255,30,1,121,247,42,251,207,6,131,1,76,247,132,250,145,242,91,249,189,246,61,254,246,8,13,8,246,11,158,251,47,250,6,251,51,0,17,22,86,255,149,8,109,1,255,255,243,255,4,0,3,0,251,255,241,255,253,239,21,3,36,16,118,19,52,248,16,3,236,2,75,8,207,13,43,250,82,250,168,254,157,252,40,0,63,3,82,251,66,0,30,2,97,6,158,246,117,0,137,255,238,255,49,0,18,0,40,0,12,254,40,3,42,253,168,4,39,14,246,5,28,254,56,4,58,246,189,253,35,5,161,248,84,0,235,6,170,244,107,5,182,251,23,6,154,251,140,2,128,252,32,0,255,255,3,0,1,0,3,0,254,255,233,0,14,3,0,32,54,2,67,253,160,254,23,4,69,2,210,251,87,12,123,251,207,249,63,6,46,252,105,253,93,252,235,245,210,19,13,3,217,253,178,253,9,255,193,255,202,255,206,255,253,0,118,255,199,254,131,1,68,244,144,251,142,2,253,250,38,5,178,1,80,0,50,250,182,2,0,254,137,1,18,255,68,253,24,255,194,2,198,5,0,224,121,1,89,2,18,0,255,255,253,255,0,0,250,255,253,255,173,8,203,13,162,252,0,7,14,255,154,241,164,1,99,7,150,3,44,5,234,0,205,252,167,253,59,9,183,251,51,9,242,2,131,255,245,0,153,253,213,12,204,0,0,0,6,0,252,255,253,255,255,255,131,253,161,2,209,4,70,11,9,1,61,255,30,255,217,9,25,1,46,255,17,7,83,245,231,240,17,247,129,2,212,245,117,239,107,0,21,3,139,4,216,245,49,254,251,255,10,0,2,0,246,255,39,0,100,5,242,2,43,236,221,15,159,249,54,249,188,249,145,7,23,7,15,4,112,14,175,253,170,8,219,251,57,4,63,251,14,8,131,253,212,249,149,0,142,253,3,255,253,255,239,255,2,0,33,0,1,0,118,0,13,2,158,0,189,4,142,3,151,255,99,250,225,250,207,8,93,254,166,246,6,6,10,241,113,251,26,252,181,251,99,6,142,6,168,251,237,254,122,0,206,255,0,0,3,0,0,0,255,255,255,255,230,3,76,240,135,248,197,251,97,255,61,7,76,254,85,253,42,1,211,0,199,2,32,16,71,248,66,252,24,4,130,2,92,254,73,1,130,251,203,1,113,8,29,0,252,255,0,0,255,255,250,255,1,0,85,5,29,4,8,4,184,3,86,3,101,9,242,19,71,7,233,11,213,3,161,252,115,254,252,1,253,250,137,253,17,0,20,2,83,250,224,251,66,0,245,1,229,255,255,255,3,0,255,255,243,255,254,255,239,254,148,244,71,3,79,254,117,254,4,255,153,7,195,0,205,254,239,250,62,250,39,252,60,17,7,252,50,4,151,10,228,3,151,3,183,0,246,255,163,253,38,0,1,0,255,255,255,255,2,0,1,0,67,8,90,254,71,14,76,248,193,5,15,248,157,9,168,251,13,251,179,0,118,254,118,252,7,251,80,254,58,4,111,1,48,253,210,6,111,253,83,2,189,2,16,0,255,255,0,0,0,0,2,0,253,255,1,255,187,1,208,248,181,246,40,1,2,1,93,253,35,255,150,1,40,255,105,231,239,251,38,4,199,0,169,6,248,251,165,249,161,246,198,0,183,251,241,254,157,255,0,0,1,0,254,255,2,0,243,255,87,1,37,255,89,250,243,6,118,2,104,248,187,251,214,249,194,255,202,250,251,10,209,252,31,5,226,243,212,254,67,0,24,0,98,0,252,2,34,251,203,0,6,0,0,0,252,255,0,0,1,0,0,0,238,255,88,249,109,250,160,254,151,245,180,253,31,1,203,2,58,254,176,2,88,254,200,6,156,251,4,4,99,226,16,253,30,254,149,254,181,255,48,253,149,253,193,1,0,0,3,0,0,0,16,0,253,255,69,251,180,9,162,13,221,253,63,253,240,6,226,254,212,249,80,11,47,247,42,255,8,249,14,251,206,253,110,251,226,253,17,3,70,6,23,2,51,0,131,250,249,255,255,255,255,255,0,0,255,255,2,0,84,254,189,253,189,251,189,245,239,8,11,253,165,5,101,254,96,255,55,2,108,0,231,250,252,238,122,254,107,252,89,1,135,247,128,252,188,14,200,4,179,2,231,255,1,0,1,0,1,0,254,255,1,0,25,1,85,5,164,249,183,253,157,13,169,0,234,2,117,254,48,4,33,6,207,251,232,2,250,4,112,242,11,4,118,252,190,242,255,249,155,252,25,11,145,1,4,0,255,255,253,255,253,255,255,255,253,255,219,255,164,249,136,252,17,3,0,13,81,4,223,13,34,27,104,249,130,10,253,247,92,247,90,241,145,248,15,254,227,4,163,4,202,231,90,15,85,0,203,251,16,0,233,255,176,255,126,255,43,0,66,0,50,252,67,2,1,248,233,241,102,253,56,247,11,18,190,26,88,0,119,253,105,4,1,255,239,13,132,255,41,0,58,0,122,2,28,251,184,2,232,9,202,249,209,0,12,0,154,255,237,254,27,0,216,0,86,4,3,1,213,247,239,6,72,241,86,2,185,1,239,248,81,254,22,0,33,252,147,253,84,0,245,248,49,6,47,2,179,251,42,0,200,1,120,254,150,252,252,255,0,0,0,0,1,0,255,255,0,0,141,254,45,255,173,254,48,251,182,1,133,245,17,252,226,4,223,20,93,3,231,250,191,253,59,8,167,245,101,243,252,3,129,255,50,2,119,21,192,243,98,254,239,253,12,0,203,255,222,255,151,0,106,0,126,244,193,253,252,248,23,12,255,254,177,253,126,0,199,3,221,253,241,254,48,2,206,3,249,242,194,247,133,250,27,23,172,251,132,1,14,251,246,253,80,1,167,0,1,0,253,255,254,255,2,0,253,255,200,254,19,0,28,13,99,4,92,253,9,255,185,2,36,2,232,6,150,4,243,253,3,255,89,254,34,2,187,246,132,244,225,251,0,247,203,0,29,5,194,253,248,255,0,0,253,255,4,0,0,0,4,0,41,255,0,32,98,253,247,250,245,249,208,254,218,5,57,252,239,253,186,253,99,247,216,6,65,1,61,2,184,251,64,0,128,4,169,255,62,2,6,255,27,2,62,0,7,0,2,0,255,255,253,255,3,0,47,254,243,0,101,251,60,3,59,246,33,255,198,0,141,252,28,253,89,4,227,248,236,247,94,243,179,6,197,7,25,7,215,2,104,6,58,13,254,249,160,252,45,0,0,0,252,255,0,0,0,0,2,0,96,2,41,250,235,4,124,255,31,5,94,1,25,2,175,10,148,5,151,0,44,5,35,2,113,240,156,248,104,0,231,7,116,7,238,251,106,4,228,4,67,253,9,0,0,0,254,255,255,255,1,0,1,0,90,2,0,224,40,245,107,253,104,6,187,1,124,13,30,253,61,3,125,2,36,1,232,0,72,5,15,19,149,5,144,3,137,2,57,6,52,1,182,254,68,0,63,0,253,255,4,0,199,255,26,0,25,0,226,4,144,1,25,237,211,0,68,245,104,253,228,3,85,1,227,251,65,1,154,9,252,2,231,2,39,253,12,0,229,254,166,254,118,0,7,255,103,255,231,246,219,255,0,0,255,255,0,0,1,0,1,0,96,1,146,252,32,9,134,253,126,245,169,242,123,244,237,253,235,4,138,1,163,0,30,252,77,3,235,4,122,3,120,5,23,1,116,7,161,0,130,247,84,7,76,0,1,0,255,255,255,255,10,0,0,0,47,0,157,251,75,6,233,1,106,2,208,252,249,255,209,7,90,251,65,7,67,245,201,254,181,254,221,2,132,5,110,5,11,250,238,4,143,250,249,254,52,12,158,255,0,0,1,0,0,0,1,0,254,255,2,2,51,242,166,246,39,14,249,0,224,251,3,2,255,4,5,11,221,1,183,0,177,2,158,4,98,5,7,5,57,253,240,4,55,253,234,254,217,0,104,253,31,255,255,255,0,0,6,0,2,0,9,0,109,251,47,12,60,5,51,251,119,248,192,7,203,250,250,3,10,0,181,4,63,0,102,1,172,251,57,254,99,254,86,3,242,249,89,254,76,255,225,9,0,224,238,255,0,0,254,255,255,255,0,0,0,0,90,253,235,14,220,250,135,4,78,2,25,255,155,8,3,250,218,3,193,16,90,4,111,4,118,251,103,252,198,255,179,2,11,0,74,249,242,254,237,253,18,2,65,0,0,0,255,255,1,0,4,0,0,0,96,251,177,250,62,28,235,253,227,247,92,251,113,0,64,250,234,1,238,5,196,5,163,248,166,3,244,0,48,7,72,253,32,254,84,246,252,12,127,246,78,4,120,0,1,0,245,255,254,255,18,0,253,255,8,252,189,0,5,241,133,249,210,255,76,255,157,245,206,7,99,250,83,4,56,247,165,0,111,253,41,236,32,255,222,4,213,1,165,1,121,4,124,4,84,0,238,255,3,0,0,0,0,0,250,255,0,0,190,255,50,255,231,8,36,255,70,6,91,254,54,250,99,254,43,251,118,1,107,14,235,1,250,252,154,1,23,3,124,1,57,13,103,2,74,252,148,253,59,255,65,0,255,255,3,0,253,255,2,0,255,255,28,254,116,5,17,1,249,241,37,5,11,252,27,6,122,255,90,2,211,251,221,2,113,251,233,0,63,1,250,254,94,1,12,3,105,254,16,254,251,250,46,5,243,255,0,0,2,0,255,255,0,0,255,255,184,254,142,253,176,252,233,2,233,251,208,15,132,254,56,254,154,248,101,3,195,251,139,254,13,11,110,2,217,1,138,1,237,0,129,247,143,4,178,236,246,0,100,0,255,255,1,0,250,255,1,0,250,255,186,255,35,0,77,6,37,10,27,5,220,6,96,251,58,4,203,3,44,248,77,250,18,254,216,255,233,2,228,10,194,252,76,0,24,2,46,248,145,1,199,255,236,255,0,0,0,0,0,0,0,0,0,0,248,255,244,0,135,7,138,4,144,246,122,250,207,1,167,255,193,4,226,252,138,1,9,250,49,253,102,253,230,3,238,5,105,246,23,244,106,251,120,245,209,243,2,0,0,0,254,255,2,0,2,0,3,0,69,4,145,253,124,6,157,249,177,5,0,10,251,2,66,245,163,3,6,7,246,9,122,5,146,3,105,252,139,7,129,254,77,254,185,253,183,1,9,0,174,251,244,255,255,255,0,0,0,0,0,0,254,255,177,254,38,253,202,247,122,250,16,10,227,240,1,4,135,249,254,255,89,3,176,254,61,244,205,0,84,4,108,1,235,252,77,255,171,0,75,1,156,8,15,2,243,255,1,0,253,255,2,0,1,0,252,255,203,253,45,255,117,255,7,7,195,0,147,252,136,253,102,1,12,255,77,250,118,5,223,8,38,2,195,7,158,8,175,254,199,0,132,228,77,2,195,0,46,254,72,0,255,255,2,0,1,0,0,0,0,0,229,255,131,254,154,249,0,224,5,0,215,3,55,250,236,255,49,253,18,255,255,2,59,2,56,255,242,2,204,1,142,6,96,5,101,255,50,248,38,1,57,254,80,0,2,0,26,0,3,0,10,0,25,0,93,252,182,251,114,251,107,243,53,248,190,2,104,0,131,246,34,247,92,5,22,9,219,255,44,250,156,6,132,2,253,250,107,1,112,2,29,254,241,255,90,1,250,255,2,0,0,0,1,0,3,0,2,0,131,246,0,224,68,252,166,4,194,2,69,252,111,1,191,3,62,255,45,253,176,251,119,1,42,2,62,252,27,255,66,0,112,1,18,0,106,255,56,0,200,3,241,255,0,0,255,255,251,255,0,0,9,0,6,255,48,253,118,7,59,3,198,0,123,253,229,7,32,0,76,248,63,253,185,1,117,1,32,3,11,247,211,6,224,5,231,253,61,249,88,251,61,6,65,240,24,0,0,0,254,255,1,0,1,0,1,0,125,255,58,6,103,255,103,4,172,10,213,1,210,253,245,255,166,4,115,0,91,252,196,7,49,7,78,238,105,5,59,2,95,9,173,6,193,255,177,241,135,245,57,0,252,255,11,0,252,255,0,0,253,255,170,1,95,239,195,10,180,255,125,249,146,9,139,254,47,13,165,255,24,255,255,1,136,2,118,3,158,4,131,6,65,0,43,244,189,253,97,3,138,8,95,11,25,2,0,0,2,0,253,255,0,0,7,0,73,2,0,32,217,244,0,32,151,21,141,234,122,248,121,239,76,251,161,7,87,251,191,0,206,12,66,249,3,1,22,245,109,16,219,16,23,232,162,253,126,248,82,14,188,254,18,255,199,254,48,253,89,250,229,253,230,252,79,12,66,249,116,13,108,3,72,2,97,253,15,254,151,1,141,3,121,247,15,10,246,0,95,253,14,1,56,3,248,6,55,255,161,28,77,2,186,255,255,255,4,0,251,255,253,255,248,255,95,254,126,1,226,10,52,252,8,2,130,4,118,3,9,2,144,23,81,253,207,14,246,253,54,251,96,2,172,1,123,3,12,250,9,252,123,4,254,4,47,2,250,255,3,0,0,0,6,0,2,0,253,255,115,0,2,14,225,244,95,0,204,1,16,11,22,9,127,249,184,6,197,1,197,3,130,4,196,1,71,249,161,250,243,254,90,8,16,248,55,0,94,253,154,252,132,255,0,0,5,0,0,0,251,255,253,255,229,254,53,4,44,10,246,4,198,251,39,249,184,26,58,246,220,3,2,249,98,5,207,4,182,1,92,251,30,1,28,2,118,255,30,4,145,255,239,246,74,0,56,0,253,255,254,255,0,0,224,255,5,0,3,6,137,250,245,28,121,252,94,249,245,6,1,255,46,254,100,250,91,13,124,7,84,3,78,2,154,251,175,249,227,250,72,234,15,255,35,13,55,251,122,10,108,2,250,255,58,0,2,0,70,255,239,255,113,244,107,2,180,8,189,245,209,243,218,2,132,14,230,253,155,255,185,248,252,253,142,0,176,246,22,250,126,234,199,252,2,2,202,2,234,2,26,245,57,2,87,254,4,0,188,255,70,0,24,0,12,0,49,3,236,254,221,242,130,244,103,0,187,253,99,252,139,2,49,2,43,0,178,1,200,2,227,253,6,248,245,250,59,254,69,254,40,239,192,250,253,4,93,2,252,255,0,0,255,255,255,255,1,0,2,0,94,252,20,1,147,12,108,254,80,252,15,254,72,3,22,1,158,255,104,250,144,251,73,248,185,248,178,251,90,250,170,3,181,2,190,235,255,255,61,4,29,247,1,0,1,0,255,255,255,255,254,255,3,0,86,251,200,254,23,251,181,7,34,6,89,249,155,249,127,2,169,252,133,7,202,3,92,2,33,5,12,3,206,235,165,253,220,0,37,253,136,11,152,252,166,0,30,0,0,0,254,255,255,255,3,0,255,255,25,253,248,1,83,5,156,5,96,6,134,253,59,253,214,246,87,0,125,4,140,13,84,8,212,11,241,251,164,255,39,8,34,252,211,254,198,3,251,252,223,251,42,0,0,0,254,255,0,0,2,0,2,0,252,0,217,0,41,14,237,246,212,0,131,254,159,251,128,6,205,254,144,6,145,8,194,248,69,255,228,243,254,0,95,253,83,2,203,7,157,2,81,253,3,254,13,0,0,0,8,0,253,255,11,0,253,255,216,253,169,255,6,0,117,11,245,254,144,250,40,0,132,2,32,0,150,11,150,250,80,246,68,252,136,4,119,5,25,4,62,15,212,247,243,253,188,6,69,0,223,255,0,0,254,255,0,0,2,0,2,0,60,254,125,237,91,243,2,254,170,253,139,250,87,3,37,6,95,8,177,255,246,249,239,255,51,252,160,246,153,6,133,0,67,251,16,3,214,2,148,3,124,254,122,254,1,0,255,255,253,255,255,255,0,0,170,0,51,255,167,244,0,32,47,254,47,12,55,17,59,253,109,254,91,3,139,254,235,250,139,250,18,253,168,255,21,1,207,247,34,255,122,255,168,255,91,251,206,3,200,255,199,255,173,255,235,255,102,0,114,2,142,255,0,247,211,3,212,248,156,252,237,4,178,8,251,254,67,2,215,3,143,2,238,245,11,7,117,0,152,251,109,1,131,15,211,13,235,255,234,252,194,255,2,0,3,0,23,0,253,255,31,0,249,4,140,12,175,249,20,16,231,254,213,2,228,254,55,4,37,1,81,241,21,10,175,249,253,254,237,255,49,248,224,11,251,243,14,250,32,4,164,255,129,3,243,0,255,255,36,0,237,255,246,255,210,255,231,0,105,4,107,1,70,248,142,252,4,249,63,1,199,18,85,249,157,250,71,250,23,9,197,252,87,253,154,1,232,248,53,246,12,4,228,2,218,2,81,253,100,0,255,255,255,255,255,255,1,0,252,255,236,254,47,1,229,246,160,244,184,248,146,241,156,1,62,251,106,6,96,17,146,2,43,255,104,3,51,11,227,0,100,3,178,253,245,8,223,6,126,249,207,249,116,255,1,0,253,255,255,255,26,0,246,255,225,254,130,3,118,246,157,15,137,249,195,250,200,255,177,2,179,248,60,2,4,248,104,2,213,245,234,254,171,11,93,9,249,247,247,0,128,0,86,2,196,6,110,255,0,0,3,0,255,255,253,255,5,0,74,3,85,2,11,3,7,250,222,252,94,8,124,249,35,9,34,242,165,245,197,6,5,250,210,255,88,2,106,2,157,252,103,253,244,5,136,1,150,250,49,243,45,0,0,0,9,0,249,255,253,255,248,255,32,255,184,245,109,255,7,254,175,8,237,6,7,7,96,249,194,0,94,251,225,253,7,3,109,251,115,21,241,246,135,243,199,254,157,254,123,255,183,251,125,0,234,255,254,255,2,0,1,0,253,255,246,255,158,254,89,250,106,253,199,254,50,239,48,15,135,255,189,254,88,4,223,252,23,250,210,252,146,249,152,253,73,251,91,1,227,1,158,2,132,3,221,255,139,252,14,0,1,0,0,0,1,0,254,255,7,0,80,254,26,254,253,249,17,3,245,18,136,3,157,3,127,3,57,251,96,246,67,13,6,254,216,252,207,0,197,0,106,3,96,252,67,5,149,255,232,5,39,4,74,255,1,0,252,255,255,255,250,255,3,0,44,251,233,251,6,3,26,0,138,253,95,3,31,4,184,245,93,251,234,253,149,253,201,251,242,245,11,248,146,2,205,4,250,254,142,10,191,242,117,247,228,6,66,0,0,0,7,0,0,0,7,0,253,255,165,2,68,254,193,247,120,235,123,238,125,249,29,8,77,6,203,5,16,250,64,6,231,6,124,4,6,8,140,6,74,7,15,3,105,247,253,2,56,2,219,10,85,253,4,0,17,0,0,0,224,255,15,0,45,0,228,0,115,246,240,2,206,9,135,249,241,251,113,0,83,4,226,251,27,249,35,251,33,246,77,2,199,1,72,1,128,2,189,253,66,9,33,5,228,253,31,0,1,0,255,255,252,255,2,0,253,255,21,255,208,253,199,1,225,14,102,0,147,1,235,255,52,7,146,1,148,0,224,255,197,21,75,241,247,254,50,253,113,254,163,254,110,1,175,251,91,0,89,7,34,0,1,0,1,0,5,0,0,0,9,0,33,1,134,251,27,3,56,246,156,1,132,4,210,254,78,252,15,8,247,245,239,254,102,250,141,0,130,2,137,253,248,18,16,252,169,0,216,255,191,0,11,247,170,255,6,0,1,0,254,255,0,0,1,0,139,0,163,7,169,251,80,252,140,0,206,251,47,4,224,250,227,253,152,2,9,7,132,252,69,6,42,249,114,253,88,253,90,224,120,0,232,255,246,3,161,254,136,255,0,0,254,255,1,0,255,255,255,255,14,4,79,20,11,3,85,251,128,0,206,1,184,0,121,14,244,250,57,247,79,246,50,10,44,17,65,16,199,15,87,4,70,3,188,0,197,253,251,10,133,248,139,248,13,0,99,0,236,255,254,255,11,0,139,1,155,0,107,10,54,255,177,245,23,5,112,252,58,249,73,4,185,253,204,13,38,255,22,250,215,240,122], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1865265);
/* memory initializer */ allocate([1,210,255,91,251,67,252,62,244,25,253,120,253,15,0,1,0,3,0,3,0,4,0,252,255,74,1,198,0,237,254,91,253,0,224,139,253,161,7,241,252,80,2,158,3,207,5,217,255,22,252,110,4,24,6,229,255,138,255,173,250,152,254,115,8,186,1,92,0,1,0,1,0,254,255,5,0,1,0,98,253,70,1,213,10,66,5,230,255,71,1,184,0,189,251,135,255,64,2,212,250,212,0,123,253,92,3,193,247,19,254,185,247,60,1,80,253,219,1,116,253,223,255,0,0,1,0,2,0,0,0,253,255,92,0,170,0,80,24,114,8,249,2,54,248,128,8,156,6,19,249,49,2,58,252,78,13,236,255,175,253,62,2,87,253,97,4,177,254,100,254,165,245,152,237,177,255,1,0,2,0,255,255,4,0,250,255,164,3,237,245,88,1,202,245,95,4,223,25,198,254,212,251,82,1,185,7,161,250,198,250,52,248,30,5,118,0,12,254,119,254,110,2,250,248,48,251,3,0,181,255,0,0,17,0,0,0,254,255,247,255,203,2,199,31,144,1,164,14,108,8,90,7,4,3,168,10,109,254,249,252,62,8,67,6,2,253,224,245,255,2,150,253,119,18,156,2,232,8,123,251,222,4,230,252,242,255,254,255,2,0,5,0,16,0,149,255,130,2,242,248,98,255,113,246,53,1,4,253,9,9,155,255,2,253,209,0,77,253,209,7,12,1,239,254,103,2,35,3,174,23,78,254,7,5,225,253,253,255,0,0,0,0,1,0,1,0,0,0,247,1,170,253,5,248,120,251,50,4,231,4,197,12,125,5,158,4,197,0,26,12,118,255,22,9,12,255,252,252,133,3,31,255,81,1,191,255,232,253,181,254,15,0,2,0,13,0,8,0,253,255,20,0,224,255,204,255,12,252,232,0,222,5,239,255,218,249,27,253,199,255,164,0,234,255,74,0,75,255,80,6,40,1,53,250,107,5,155,254,252,234,190,254,190,250,6,0,253,255,2,0,253,255,1,0,0,0,120,254,213,252,118,253,27,254,222,11,190,10,248,252,9,254,128,249,189,254,253,0,232,254,125,242,223,250,29,2,134,8,7,5,242,252,249,6,73,253,207,255,72,0,252,255,0,0,241,255,3,0,235,255,45,255,102,5,107,255,172,2,162,8,94,10,96,250,71,251,152,0,56,4,250,243,74,253,130,18,217,3,199,250,51,3,250,253,7,7,97,253,129,12,76,10,7,0,1,0,250,255,14,0,225,255,0,0,222,255,200,16,233,255,194,0,184,7,31,252,73,5,197,2,170,254,138,251,116,255,241,254,243,8,59,253,198,6,50,3,13,242,101,4,144,3,178,253,16,3,237,254,254,255,255,255,251,255,255,255,0,0,131,254,194,10,9,6,34,247,24,14,4,9,149,248,178,0,135,1,34,7,129,255,119,250,202,252,56,253,146,6,177,8,199,8,190,1,226,3,56,0,222,2,196,0,7,0,3,0,8,0,0,0,7,0,127,2,65,3,15,243,163,2,249,254,120,253,200,11,67,253,235,0,232,250,186,253,142,244,46,255,37,251,118,1,233,243,35,248,98,1,87,2,67,250,140,0,239,255,255,255,253,255,2,0,0,0,254,255,73,255,143,1,165,253,28,3,112,250,125,10,167,240,160,1,13,247,201,6,114,7,131,6,42,3,34,255,170,12,204,241,76,20,250,249,172,3,132,255,255,7,189,255,252,255,6,0,255,255,13,0,2,0,95,255,161,1,36,16,236,1,212,251,207,252,172,10,6,255,79,250,187,6,56,8,97,4,4,251,123,4,222,3,245,253,3,250,41,1,195,4,61,15,11,246,234,255,0,0,0,0,0,0,0,0,2,0,160,249,172,0,61,3,21,253,51,251,58,248,210,251,110,4,87,6,228,0,105,14,113,2,11,253,0,32,174,255,226,2,213,0,108,7,80,251,91,0,124,3,211,255,15,0,255,255,5,0,252,255,5,0,136,1,5,244,145,248,139,0,149,2,43,0,126,8,129,248,242,254,46,250,199,253,2,0,85,0,189,251,84,26,118,3,85,0,228,251,121,253,205,253,101,244,111,255,255,255,39,0,251,255,250,255,249,255,1,252,176,251,18,249,174,243,222,251,160,13,9,246,219,13,3,255,52,255,21,255,248,249,183,255,184,253,210,254,210,243,246,246,204,254,254,6,148,3,152,0,101,255,245,255,6,0,230,255,255,255,225,255,21,0,151,3,192,248,56,254,230,251,151,2,174,5,21,250,210,245,65,239,17,6,236,13,54,5,5,7,4,6,120,254,67,253,53,252,142,242,25,1,241,254,133,0,1,0,5,0,4,0,32,0,3,0,247,253,6,250,168,250,251,6,253,253,111,252,169,246,93,0,130,10,190,253,192,253,136,249,42,2,137,2,27,250,254,254,163,253,209,4,46,247,128,2,69,3,213,255,1,0,253,255,0,0,5,0,3,0,148,0,103,237,247,6,172,12,235,254,141,251,3,6,32,248,106,7,4,251,248,252,67,249,148,248,205,255,47,2,55,1,201,6,96,252,103,14,193,251,49,5,134,0,2,0,254,255,249,255,9,0,5,0,179,255,164,251,122,19,84,252,119,252,99,243,251,252,7,13,233,255,66,2,184,246,130,1,122,0,229,4,107,1,68,245,0,254,252,237,154,6,80,3,164,251,195,0,5,0,2,0,11,0,1,0,18,0,147,2,254,250,50,2,146,4,93,18,135,3,234,1,76,242,140,13,217,255,142,2,84,251,115,252,244,254,212,3,27,1,149,12,92,1,97,4,127,252,13,252,153,255,245,255,254,255,247,255,16,0,248,255,238,254,252,239,248,246,181,246,105,2,93,6,106,8,210,11,55,249,165,253,221,252,146,254,209,3,11,4,213,248,1,255,237,254,35,251,250,4,95,255,132,238,75,255,252,255,0,0,254,255,1,0,2,0,156,0,39,2,192,252,138,253,156,14,189,247,88,1,229,0,15,5,65,0,34,1,74,250,254,248,225,12,231,251,147,9,66,1,174,245,6,245,34,251,101,2,90,0,255,255,255,255,0,0,0,0,0,0,235,254,86,3,235,4,6,6,79,254,17,14,59,254,67,4,143,255,158,5,226,3,70,245,238,252,99,3,142,5,69,4,69,249,113,251,147,250,218,251,76,254,175,255,2,0,1,0,11,0,1,0,26,0,59,255,35,0,19,255,35,2,193,2,247,255,76,6,126,1,195,0,65,255,6,255,155,255,155,254,197,2,153,0,82,3,29,236,156,255,0,0,0,0,0,0,0,0,0,0,250,230,98,255,241,253,137,0,182,254,68,2,28,254,63,0,29,2,35,251,51,255,138,0,247,0,23,254,109,255,124,255,161,252,0,0,0,0,0,0,0,0,0,0,53,0,218,255,27,1,234,255,30,250,45,254,94,254,117,0,133,0,152,247,208,255,33,252,40,3,233,251,98,9,5,1,167,1,0,0,0,0,0,0,0,0,0,0,242,255,244,1,89,18,82,255,224,253,87,0,133,254,13,255,65,2,170,2,2,1,90,251,64,248,87,2,95,2,133,255,222,254,0,0,0,0,0,0,0,0,0,0,60,0,158,16,194,0,120,3,175,255,117,254,166,1,6,249,148,3,32,1,167,4,110,253,246,1,129,8,47,252,211,254,75,2,0,0,0,0,0,0,0,0,0,0,232,0,204,0,60,254,171,252,86,239,37,255,140,4,92,0,91,0,25,6,182,3,63,253,63,251,34,253,81,6,120,0,188,254,0,0,0,0,0,0,0,0,0,0,142,242,56,254,101,253,219,3,167,255,103,5,64,253,69,255,232,254,185,253,85,1,36,253,137,2,175,247,79,242,81,255,41,255,0,0,0,0,0,0,0,0,0,0,200,0,133,253,41,254,59,251,215,0,28,11,97,6,10,2,48,253,186,6,240,254,217,1,198,0,164,253,224,1,168,255,169,0,0,0,0,0,0,0,0,0,0,0,96,255,244,254,130,0,28,1,156,253,95,0,43,0,42,0,129,2,254,254,28,229,89,255,79,253,123,0,20,1,176,253,205,2,0,0,0,0,0,0,0,0,0,0,57,1,166,255,42,239,146,10,84,249,136,2,228,252,23,3,230,3,44,254,120,2,101,7,43,0,145,7,1,251,234,255,192,255,0,0,0,0,0,0,0,0,0,0,150,255,135,0,225,254,79,1,193,224,51,0,6,255,124,254,16,0,29,1,155,255,173,2,80,252,92,2,144,253,232,252,209,0,0,0,0,0,0,0,0,0,0,0,240,1,51,255,166,1,49,0,18,1,27,255,220,0,73,0,34,253,125,1,118,254,0,224,107,254,243,2,247,255,46,0,116,0,0,0,0,0,0,0,0,0,0,0,228,255,76,1,128,4,127,255,244,0,84,0,111,247,120,2,194,248,128,254,110,0,210,254,242,254,179,1,103,249,227,252,174,2,0,0,0,0,0,0,0,0,0,0,132,249,112,2,104,253,51,10,30,0,125,251,93,254,45,242,200,253,183,6,162,250,92,253,201,255,114,248,95,3,111,5,177,1,0,0,0,0,0,0,0,0,0,0,12,252,34,1,254,8,182,254,161,255,205,246,201,255,5,253,53,248,214,254,88,253,203,2,171,255,79,6,243,3,59,248,252,251,0,0,0,0,0,0,0,0,0,0,21,0,119,236,251,1,198,255,229,0,219,255,143,255,120,2,17,7,194,255,78,1,79,251,131,252,168,254,98,0,182,1,191,255,0,0,0,0,0,0,0,0,0,0,0,0,143,0,131,0,238,255,121,255,206,254,136,1,232,0,9,1,31,2,120,1,206,253,106,1,154,9,17,3,69,14,56,254,0,0,0,0,0,0,0,0,0,0,87,3,87,240,73,251,118,0,170,255,33,255,10,1,154,0,162,248,135,251,241,0,115,254,246,0,244,0,248,252,40,3,124,255,0,0,0,0,0,0,0,0,0,0,2,0,135,253,113,0,162,255,102,255,83,255,94,255,88,255,183,1,108,230,10,3,120,254,196,255,99,0,147,248,171,0,126,255,0,0,0,0,0,0,0,0,0,0,245,255,188,254,199,2,121,252,48,2,138,249,193,5,212,254,24,4,137,0,140,251,165,251,234,250,16,252,232,252,64,243,228,253,0,0,0,0,0,0,0,0,0,0,165,254,78,0,153,255,249,255,253,255,181,1,165,23,43,1,77,254,67,1,152,2,221,1,73,4,158,0,144,2,17,1,200,0,0,0,0,0,0,0,0,0,0,0,155,255,80,0,103,255,144,0,21,255,236,1,113,254,253,255,94,19,187,2,182,253,94,255,153,0,164,252,161,0,153,2,4,0,0,0,0,0,0,0,0,0,0,0,169,255,67,255,208,6,162,254,208,248,69,1,206,246,169,4,106,5,203,249,80,0,31,4,68,255,17,1,39,3,246,7,93,254,0,0,0,0,0,0,0,0,0,0,50,0,71,255,68,0,197,255,247,255,78,0,183,253,135,255,48,225,3,3,116,252,228,254,93,1,158,0,158,251,117,255,67,255,0,0,0,0,0,0,0,0,0,0,54,1,226,254,235,0,81,253,105,252,148,254,71,253,3,255,236,1,44,1,18,255,16,1,6,2,243,253,25,233,66,255,197,255,0,0,0,0,0,0,0,0,0,0,151,0,104,2,188,238,227,0,240,0,4,255,4,2,6,255,68,0,155,1,64,255,169,255,161,253,159,2,1,5,195,254,207,254,0,0,0,0,0,0,0,0,0,0,247,255,49,3,61,254,201,251,86,0,196,19,123,251,121,251,91,254,46,1,100,6,196,254,190,255,250,253,242,3,44,4,96,0,0,0,0,0,0,0,0,0,0,0,192,253,150,254,107,0,188,13,47,1,148,254,110,254,37,3,62,2,225,3,214,253,42,1,99,252,154,1,106,7,13,0,138,0,0,0,0,0,0,0,0,0,0,0,172,254,106,255,16,2,142,0,48,254,10,4,115,254,104,15,71,253,194,3,134,3,113,5,164,8,3,252,246,251,63,252,193,254,0,0,0,0,0,0,0,0,0,0,58,0,38,0,126,1,221,0,44,255,58,3,163,250,49,238,49,5,133,255,216,0,233,255,32,253,95,0,212,254,94,254,252,255,0,0,0,0,0,0,0,0,0,0,198,255,134,30,218,0,141,0,166,255,132,255,199,1,229,255,49,0,201,254,148,254,80,0,120,255,23,251,96,0,76,1,225,254,0,0,0,0,0,0,0,0,0,0,248,255,112,2,127,0,65,7,32,254,155,252,193,253,75,250,19,254,251,254,97,0,32,0,184,254,45,254,173,0,228,245,132,0,0,0,0,0,0,0,0,0,0,0,137,20,243,251,191,0,180,252,247,0,130,0,197,253,220,253,16,254,216,0,95,255,80,1,62,0,222,3,130,0,5,2,191,255,0,0,0,0,0,0,0,0,0,0,167,255,9,0,118,255,149,1,67,253,33,254,21,14,187,2,139,253,154,255,27,0,162,250,221,251,238,255,109,245,84,255,211,253,0,0,0,0,0,0,0,0,0,0,189,255,209,0,59,2,163,255,107,254,84,255,252,254,237,255,86,0,22,0,147,2,138,253,222,0,0,224,106,0,222,255,60,0,0,0,0,0,0,0,0,0,0,0,246,255,198,242,80,1,139,2,159,250,169,2,240,255,211,255,130,254,78,4,232,254,169,0,202,252,10,2,178,1,169,251,213,254,0,0,0,0,0,0,0,0,0,0,194,0,67,254,25,255,236,253,74,254,76,255,177,253,112,249,179,0,33,23,72,255,83,253,45,254,107,3,195,253,26,1,235,0,0,0,0,0,0,0,0,0,0,0,83,1,139,0,23,253,188,255,55,255,211,1,25,253,221,1,233,255,103,251,104,5,155,254,26,251,80,241,198,1,151,4,252,0,0,0,0,0,0,0,0,0,0,0,109,0,4,255,91,31,3,253,136,0,111,0,170,255,175,253,172,255,18,253,135,255,14,3,227,2,216,254,28,1,213,0,84,251,0,0,0,0,0,0,0,0,0,0,216,255,69,0,200,7,196,1,181,255,172,255,171,2,142,6,186,250,202,248,252,11,19,253,126,250,241,254,24,2,96,4,117,0,0,0,0,0,0,0,0,0,0,0,213,15,84,1,108,0,168,255,155,1,222,3,217,0,91,14,243,2,240,2,50,255,205,0,215,254,195,253,188,0,127,0,199,254,0,0,0,0,0,0,0,0,0,0,47,0,202,244,167,242,216,0,194,6,173,255,189,0,177,249,248,3,212,255,10,254,103,8,6,0,223,251,38,2,194,0,14,254,0,0,0,0,0,0,0,0,0,0,123,255,1,0,125,254,15,254,74,2,173,0,155,3,18,240,48,251,73,1,218,247,71,255,80,2,169,2,248,12,110,252,185,254,0,0,0,0,0,0,0,0,0,0,124,255,237,1,77,255,220,0,142,0,7,239,166,1,83,255,101,1,37,5,240,0,243,253,77,6,78,255,208,249,34,253,37,2,0,0,0,0,0,0,0,0,0,0,175,254,111,0,42,251,116,0,46,1,69,1,189,0,98,2,148,243,228,254,207,252,103,5,23,6,222,252,166,1,182,1,204,1,0,0,0,0,0,0,0,0,0,0,160,255,116,1,79,1,181,252,127,15,221,0,124,1,227,0,53,1,191,1,57,255,255,254,116,1,115,254,234,253,224,2,104,255,0,0,0,0,0,0,0,0,0,0,112,255,207,1,202,255,224,254,173,255,115,0,194,253,27,255,229,1,173,245,58,0,216,16,125,251,130,2,121,253,98,4,118,0,0,0,0,0,0,0,0,0,0,0,157,0,6,0,7,252,125,251,175,2,224,254,150,3,44,255,180,254,74,246,59,255,255,251,222,253,3,16,155,0,37,253,179,254,0,0,0,0,0,0,0,0,0,0,213,255,16,254,222,253,227,253,27,1,247,253,209,255,238,255,208,0,216,253,107,7,59,8,76,2,50,3,113,252,176,251,172,255,0,0,0,0,0,0,0,0,0,0,185,255,40,0,186,254,92,0,216,0,150,255,1,255,28,0,120,0,198,255,96,245,123,255,224,254,228,255,123,251,27,6,144,1,0,0,0,0,0,0,0,0,0,0,40,0,252,255,47,2,70,5,30,0,65,15,93,253,188,251,181,253,12,250,61,248,249,251,100,7,89,253,145,253,27,4,223,255,0,0,0,0,0,0,0,0,0,0,158,255,106,0,105,0,1,233,49,254,168,1,214,255,6,254,179,253,120,1,72,3,140,0,128,253,3,3,23,0,71,254,250,255,0,0,0,0,0,0,0,0,0,0,22,0,203,0,132,242,133,253,163,253,132,6,166,1,157,11,138,1,187,249,56,252,29,253,88,1,98,250,52,3,218,250,230,255,0,0,0,0,0,0,0,0,0,0,2,1,224,255,37,4,131,2,104,255,92,0,58,254,231,250,85,6,42,2,88,1,82,0,108,254,102,20,168,254,30,1,177,0,0,0,0,0,0,0,0,0,0,0,63,0,152,254,129,255,46,3,55,14,6,243,134,1,12,0,253,253,19,254,235,5,170,6,41,253,138,1,140,4,101,1,48,255,0,0,0,0,0,0,0,0,0,0,229,255,136,2,170,254,131,255,185,254,194,0,201,241,86,2,29,0,244,0,130,3,19,254,116,1,133,253,55,2,31,0,19,255,0,0,0,0,0,0,0,0,0,0,96,255,238,10,24,249,118,247,237,1,5,2,174,255,44,254,222,254,74,11,52,254,194,1,158,1,247,254,159,251,219,0,165,251,0,0,0,0,0,0,0,0,0,0,14,0,76,0,10,245,82,1,107,250,110,254,253,0,126,255,21,255,225,252,53,1,243,253,239,14,175,0,36,0,113,0,247,0,0,0,0,0,0,0,0,0,0,0,96,1,9,2,213,0,149,255,185,255,6,253,22,3,168,252,4,255,10,255,39,253,137,253,234,4,52,243,254,5,76,254,133,253,0,0,0,0,0,0,0,0,0,0,202,255,118,0,59,254,132,255,224,255,27,2,100,1,87,255,54,255,178,253,209,2,68,254,140,231,237,254,17,255,151,255,204,255,0,0,0,0,0,0,0,0,0,0,48,254,251,1,228,252,249,4,249,8,22,3,140,2,136,1,36,13,99,248,106,8,67,253,27,255,99,0,88,0,215,1,244,253,0,0,0,0,0,0,0,0,0,0,71,0,110,252,43,7,100,255,14,255,60,255,1,2,175,1,31,254,172,255,34,253,149,17,2,254,115,0,205,1,84,254,83,0,0,0,0,0,0,0,0,0,0,0,109,240,39,4,51,253,176,245,61,252,101,253,109,255,24,2,188,255,166,1,85,1,132,248,152,253,228,3,10,2,56,2,150,4,0,0,0,0,0,0,0,0,0,0,8,0,112,0,181,2,136,1,189,1,189,20,3,1,121,0,134,6,87,1,176,0,216,1,197,0,163,1,16,255,102,251,149,255,0,0,0,0,0,0,0,0,0,0,0,224,133,1,245,0,189,255,214,255,79,0,247,1,24,254,202,254,107,0,243,255,81,254,53,255,96,0,254,1,151,0,14,1,0,0,0,0,0,0,0,0,0,0,49,254,233,255,184,255,190,254,74,0,53,6,104,255,58,255,81,0,96,4,131,255,78,254,53,243,94,247,164,254,168,254,91,0,0,0,0,0,0,0,0,0,0,0,2,255,32,255,46,0,102,255,125,255,47,254,199,255,0,32,89,1,112,0,43,253,207,255,183,0,65,255,246,0,7,1,114,1,0,0,0,0,0,0,0,0,0,0,39,0,29,253,53,230,106,246,161,255,56,1,203,255,120,254,63,0,91,255,31,0,7,254,111,0,228,1,233,253,179,0,143,0,0,0,0,0,0,0,0,0,0,0,255,4,117,255,23,249,244,0,59,0,121,255,83,254,195,2,41,3,253,238,158,254,172,1,212,254,108,0,225,252,115,250,87,2,0,0,0,0,0,0,0,0,0,0,4,0,251,255,7,0,75,0,49,0,0,32,20,1,200,0,191,0,89,255,242,255,82,0,222,0,235,254,29,254,40,255,71,254,0,0,0,0,0,0,0,0,0,0,171,0,89,254,174,0,145,1,251,253,135,254,22,255,124,253,195,252,162,254,48,252,110,255,96,252,40,1,187,11,217,13,226,255,0,0,0,0,0,0,0,0,0,0,161,0,159,229,114,4,169,252,124,255,14,255,47,2,31,255,166,254,88,255,10,0,31,254,250,255,72,251,252,0,189,254,65,255,0,0,0,0,0,0,0,0,0,0,250,254,62,2,177,1,111,255,110,2,73,1,182,245,73,254,102,251,95,1,79,254,182,252,29,16,40,1,49,1,103,1,234,255,0,0,0,0,0,0,0,0,0,0,222,255,200,255,5,252,9,255,93,255,49,1,62,2,205,255,77,255,24,0,183,251,248,0,90,255,238,255,47,1,252,0,213,253,0,0,0,0,0,0,0,0,0,0,112,254,2,255,0,255,223,10,216,254,144,248,40,2,4,5,176,254,189,246,68,13,188,251,102,0,176,0,140,0,128,2,153,254,0,0,0,0,0,0,0,0,0,0,117,1,217,1,137,247,250,252,124,254,149,1,134,250,145,250,217,250,101,255,80,4,235,253,126,1,25,6,114,244,150,1,19,3,0,0,0,0,0,0,0,0,0,0,40,241,198,255,50,8,75,255,198,253,129,1,227,239,247,2,208,249,9,0,234,254,201,0,240,253,241,253,77,254,180,1,169,2,0,0,0,0,0,0,0,0,0,0,30,0,176,255,196,255,65,240,186,255,217,242,60,1,163,252,67,0,87,255,112,255,62,6,198,3,32,0,17,251,78,254,30,253,0,0,0,0,0,0,0,0,0,0,181,0,12,0,115,0,91,0,253,0,6,2,5,2,216,0,62,3,80,1,200,253,203,243,228,252,177,252,91,6,58,0,98,255,0,0,0,0,0,0,0,0,0,0,48,0,173,252,226,254,137,1,134,1,195,2,83,2,171,1,21,255,140,255,46,3,58,255,1,24,202,249,135,2,15,0,253,254,0,0,0,0,0,0,0,0,0,0,147,253,152,0,78,2,240,255,215,0,135,253,240,252,116,255,63,4,211,2,161,239,141,10,183,3,52,252,17,1,214,253,131,1,0,0,0,0,0,0,0,0,0,0,132,255,133,244,218,255,127,1,234,0,175,2,199,244,46,254,61,0,40,254,86,3,116,254,49,1,23,255,82,0,139,245,50,255,0,0,0,0,0,0,0,0,0,0,136,255,10,255,154,253,118,254,0,32,75,0,62,254,177,0,5,255,45,0,114,255,65,0,32,251,242,255,133,1,119,1,114,0,0,0,0,0,0,0,0,0,0,0,54,11,158,0,39,254,90,255,160,3,150,253,139,248,224,0,93,252,106,7,240,255,171,1,191,1,236,251,85,0,179,254,197,0,0,0,0,0,0,0,0,0,0,0,78,0,114,0,89,255,73,0,210,251,176,255,184,13,68,244,239,249,1,3,213,0,83,3,135,254,210,3,73,4,71,0,66,0,0,0,0,0,0,0,0,0,0,0,127,255,248,0,199,1,136,254,88,1,128,0,196,255,34,2,191,254,38,225,49,253,201,255,83,252,218,4,207,0,215,0,67,1,0,0,0,0,0,0,0,0,0,0,232,255,31,255,136,0,142,0,29,253,139,255,2,0,242,0,104,255,236,255,17,249,28,254,220,255,104,254,49,245,41,254,251,0,0,0,0,0,0,0,0,0,0,0,22,0,111,0,76,255,7,227,109,1,37,1,199,254,7,4,65,255,154,0,46,255,17,255,121,0,179,254,32,250,209,0,146,0,0,0,0,0,0,0,0,0,0,0,130,3,125,253,8,12,16,2,165,255,50,253,0,254,19,1,20,242,140,1,160,0,174,252,90,1,173,253,22,6,172,2,202,254,0,0,0,0,0,0,0,0,0,0,234,0,93,254,44,253,79,254,36,1,21,252,170,2,139,255,218,250,110,252,239,235,128,0,53,0,35,1,152,1,245,4,228,254,0,0,0,0,0,0,0,0,0,0,4,255,190,0,161,244,130,0,255,0,84,255,21,239,26,0,245,254,24,1,123,255,155,253,217,251,145,251,247,2,246,250,216,0,0,0,0,0,0,0,0,0,0,0,133,0,79,255,229,15,201,254,59,255,188,12,85,1,201,0,139,255,253,253,105,0,110,253,207,3,81,0,179,254,179,254,6,1,0,0,0,0,0,0,0,0,0,0,17,1,169,255,65,1,190,0,105,5,18,1,182,0,7,246,106,255,164,0,194,252,89,0,53,254,97,235,144,253,176,254,143,1,0,0,0,0,0,0,0,0,0,0,84,255,24,255,11,0,45,0,121,0,2,255,55,254,196,0,97,242,186,252,0,2,202,254,241,244,171,255,98,0,111,255,181,254,0,0,0,0,0,0,0,0,0,0,201,255,107,255,20,8,195,255,15,12,113,255,38,6,155,250,37,11,107,7,59,254,188,253,119,255,187,4,123,250,171,0,125,0,0,0,0,0,0,0,0,0,0,0,28,255,30,0,68,252,193,21,209,0,167,255,25,0,61,2,123,249,251,1,182,0,124,255,185,2,124,255,108,244,131,253,139,0,0,0,0,0,0,0,0,0,0,0,250,243,50,243,253,252,160,3,218,255,49,254,52,3,117,4,46,251,108,2,140,2,82,249,130,254,174,249,103,254,179,0,227,1,0,0,0,0,0,0,0,0,0,0,154,255,160,16,236,255,94,255,229,7,218,2,159,5,216,10,203,1,242,1,104,255,226,1,35,0,241,254,42,3,191,250,7,255,0,0,0,0,0,0,0,0,0,0,131,0,5,0,231,254,175,1,62,246,234,251,226,1,74,3,41,1,201,254,20,251,148,0,118,252,135,239,125,250,154,255,151,254,0,0,0,0,0,0,0,0,0,0,116,0,245,243,235,0,85,251,237,255,122,253,42,0,231,1,53,1,118,6,27,4,149,249,177,2,201,252,231,8,208,5,59,2,0,0,0,0,0,0,0,0,0,0,42,0,161,255,253,255,36,0,86,255,142,255,168,31,217,0,140,0,39,255,87,2,250,252,192,255,93,253,45,255,166,0,204,0,0,0,0,0,0,0,0,0,0,0,99,0,82,2,208,255,224,0,52,0,37,250,15,1,176,8,37,255,112,12,91,255,60,3,191,250,239,252,181,0,133,0,124,0,0,0,0,0,0,0,0,0,0,0,21,255,226,254,254,0,85,255,140,236,59,254,104,250,12,0,222,2,121,254,128,253,83,1,25,2,57,1,68,253,248,3,148,0,0,0,0,0,0,0,0,0,0,0,207,255,237,255,35,3,167,3,8,2,166,255,129,2,29,4,58,254,34,9,73,232,34,254,104,2,209,253,173,254,189,1,72,250,0,0,0,0,0,0,0,0,0,0,81,255,111,0,124,255,65,0,248,254,220,2,221,0,231,0,76,248,207,254,69,1,165,252,71,2,248,4,71,254,91,10,229,0,0,0,0,0,0,0,0,0,0,0,226,254,218,237,250,254,81,2,101,2,168,3,54,1,153,253,83,0,223,0,208,252,118,7,249,7,25,1,66,255,78,254,114,0,0,0,0,0,0,0,0,0,0,0,133,255,172,2,48,255,12,2,162,253,57,251,8,1,41,252,147,255,223,251,184,2,195,0,247,253,177,3,177,226,193,0,136,255,0,0,0,0,0,0,0,0,0,0,98,0,154,254,139,247,244,0,21,1,137,1,3,3,32,13,254,254,62,251,134,255,27,251,7,247,38,3,58,255,28,2,7,0,0,0,0,0,0,0,0,0,0,0,78,0,231,254,144,254,249,10,159,0,51,10,65,3,136,255,109,240,165,3,104,1,207,255,253,253,150,255,152,254,138,2,131,255,0,0,0,0,0,0,0,0,0,0,203,0,89,5,237,2,10,254,9,247,186,254,192,1,203,254,118,2,172,255,89,1,248,253,252,255,145,253,42,4,181,240,117,1,0,0,0,0,0,0,0,0,0,0,5,238,230,252,143,253,157,254,47,4,167,253,215,253,81,2,216,254,114,2,184,254,109,2,85,0,68,5,92,0,224,254,204,0,0,0,0,0,0,0,0,0,0,0,247,255,90,2,94,255,19,253,152,255,208,1,140,254,161,250,143,248,152,8,61,0,20,243,127,252,122,2,12,4,192,247,74,255,0,0,0,0,0,0,0,0,0,0,180,255,37,9,93,253,184,255,227,255,192,2,232,253,120,6,227,253,32,253,116,250,253,249,154,9,28,255,162,2,22,251,253,255,0,0,0,0,0,0,0,0,0,0,123,255,87,4,63,0,71,1,214,1,202,4,29,2,236,254,30,244,198,249,136,243,101,1,151,253,146,2,197,254,46,252,119,2,0,0,0,0,0,0,0,0,0,0,111,0,68,255,107,2,236,0,104,0,54,0,33,2,168,1,24,23,180,254,199,2,31,251,235,253,35,1,248,249,40,255,113,0,0,0,0,0,0,0,0,0,0,0,57,255,11,1,152,0,211,254,84,255,14,5,7,9,30,254,109,246,174,255,41,7,214,0,130,0,97,251,92,247,147,1,143,253,0,0,0,0,0,0,0,0,0,0,150,255,150,2,208,255,125,255,68,1,33,9,189,1,206,1,163,254,67,255,157,2,81,19,251,248,16,0,12,1,166,253,2,0,0,0,0,0,0,0,0,0,0,0,55,0,154,0,124,3,221,255,111,255,101,1,50,2,42,0,247,255,228,254,177,0,84,0,166,1,75,255,154,254,194,29,29,0,0,0,0,0,0,0,0,0,0,0,159,254,68,0,215,255,0,240,177,0,236,255,245,254,14,3,186,3,82,254,37,6,72,253,249,6,229,241,89,0,13,255,171,2,0,0,0,0,0,0,0,0,0,0,36,255,191,7,133,252,102,2,226,0,54,255,67,0,249,2,112,7,179,0,226,0,160,1,111,253,175,242,2,4,18,11,74,254,0,0,0,0,0,0,0,0,0,0,217,253,27,255,208,254,50,254,27,247,93,254,195,1,134,255,148,255,2,1,16,3,81,4,126,1,137,0,63,22,15,255,21,254,0,0,0,0,0,0,0,0,0,0,34,0,240,254,105,249,233,6,180,254,109,1,33,0,222,245,145,14,69,1,85,0,217,254,222,254,104,255,190,8,157,253,215,255,0,0,0,0,0,0,0,0,0,0,102,0,166,0,241,0,74,4,149,255,7,3,98,254,160,16,235,254,167,3,56,255,239,1,255,0,120,4,212,1,72,255,197,255,0,0,0,0,0,0,0,0,0,0,94,0,230,254,199,255,12,0,122,254,245,0,80,7,148,253,65,4,170,14,176,1,179,3,3,254,228,254,4,241,26,0,226,1,0,0,0,0,0,0,0,0,0,0,9,0,203,3,139,254,87,4,32,254,38,9,74,255,16,2,34,3,172,4,7,252,145,252,243,1,240,10,194,252,26,255,252,255,0,0,0,0,0,0,0,0,0,0,130,254,209,252,123,249,123,246,175,253,193,0,80,253,120,2,223,1,67,11,53,2,28,2,5,0,62,6,82,6,128,253,10,255,0,0,0,0,0,0,0,0,0,0,91,254,153,255,202,5,46,244,191,255,155,255,4,0,81,15,176,2,83,252,22,255,49,0,202,0,113,7,167,3,125,251,252,255,0,0,0,0,0,0,0,0,0,0,210,0,143,253,138,255,113,243,88,1,210,3,246,255,5,3,130,255,220,252,2,250,182,0,134,251,122,253,110,255,219,7,207,1,0,0,0,0,0,0,0,0,0,0,75,0,87,0,225,255,95,2,124,255,75,23,250,254,238,1,134,0,252,255,141,0,19,0,225,0,229,0,239,0,93,0,236,255,67,255,2,0,0,0,253,255,255,255,255,255,0,0,214,0,50,255,109,3,83,0,180,253,83,0,132,0,78,0,5,0,171,255,66,0,232,255,47,0,245,255,25,0,26,0,253,255,46,0,2,0,251,255,0,0,1,0,255,255,0,0,143,255,39,1,175,255,74,0,223,0,206,255,163,255,217,233,228,255,115,0,0,1,28,255,225,255,229,253,44,1,234,254,197,255,170,1,146,255,255,255,1,0,1,0,0,0,0,0,161,255,140,255,10,1,176,0,249,2,253,255,90,0,165,255,98,0,47,255,98,254,229,255,200,255,26,0,180,255,6,0,224,255,26,18,1,0,0,0,252,255,0,0,0,0,0,0,177,0,147,0,20,255,163,255,11,225,11,0,145,255,182,255,36,0,176,0,96,1,88,0,112,0,16,0,144,0,146,255,91,0,73,1,255,255,2,0,0,0,1,0,0,0,1,0,119,0,48,1,162,255,90,254,113,0,129,0,186,255,155,0,247,0,140,255,117,255,71,1,157,254,77,0,143,0,14,235,27,0,135,254,255,255,7,0,2,0,1,0,0,0,0,0,179,0,127,0,220,5,188,254,241,255,161,2,184,0,154,250,167,0,41,7,14,244,200,0,77,251,203,1,143,248,252,3,253,254,136,255,10,0,252,255,0,0,1,0,0,0,0,0,227,3,144,255,37,0,96,255,235,255,85,240,172,0,228,0,46,255,80,0,125,255,1,0,20,0,128,255,4,255,224,254,124,255,81,1,255,255,0,0,255,255,0,0,1,0,255,255,196,255,61,0,197,0,71,255,216,255,121,244,176,253,199,255,210,0,80,243,30,255,212,255,135,1,89,255,249,255,219,0,241,255,172,0,0,0,255,255,1,0,0,0,0,0,0,0,106,0,186,255,221,254,192,0,45,0,162,0,37,0,143,0,91,0,21,0,136,228,12,0,83,255,226,255,1,0,3,1,226,254,131,1,220,255,0,0,0,0,0,0,0,0,0,0,199,249,46,255,83,0,47,0,194,0,61,0,85,0,74,255,233,255,40,0,182,255,22,0,12,0,216,0,59,0,91,255,93,255,97,255,248,255,0,0,0,0,2,0,0,0,0,0,253,255,182,0,176,255,20,8,190,2,115,0,92,255,171,255,21,0,132,255,65,255,143,255,7,1,138,0,139,16,37,0,204,0,76,254,0,0,24,0,1,0,255,255,0,0,0,0,147,0,83,0,79,255,88,255,159,253,247,255,240,255,210,255,127,0,120,0,231,255,107,13,51,0,31,0,49,0,110,1,31,0,127,255,1,0,224,255,0,0,255,255,0,0,254,255,39,1,158,0,116,0,11,0,232,254,215,1,169,0,29,0,227,245,82,1,32,0,43,1,172,0,69,255,224,255,181,1,218,255,103,1,255,255,255,255,1,0,0,0,0,0,0,0,243,0,157,1,227,255,90,237,187,0,12,0,139,255,168,0,142,255,48,255,201,255,5,0,0,0,225,255,180,1,33,2,211,255,16,1,0,0,252,255,0,0,0,0,1,0,0,0,127,0,38,0,220,25,223,255,153,255,34,0,84,0,221,255,30,0,125,255,248,255,177,255,130,255,158,255,17,0,181,255,225,255,80,255,14,0,255,255,0,0,0,0,255,255,255,255,17,1,37,255,176,0,173,255,187,0,220,255,1,0,79,10,158,0,228,14,127,0,23,255,175,0,54,1,148,0,131,1,242,255,52,1,0,0,253,255,0,0,0,0,0,0,0,0,249,12,65,254,153,0,128,255,254,0,237,254,79,0,75,255,17,0,146,0,61,0,46,0,208,255,253,0,51,0,239,255,1,0,1,0,0,0,1,0,255,255,254,255,0,0,243,255,23,3,126,255,40,0,78,0,192,255,77,255,42,0,57,254,166,1,112,0,237,255,109,238,143,255,171,254,52,0,69,0,67,0,254,0,250,255,255,255,4,0,0,0,0,0,1,0,158,255,48,252,68,0,27,6,228,0,250,3,202,1,4,252,155,1,249,0,141,253,17,9,226,2,52,254,67,250,106,1,116,3,251,254,0,0,255,255,1,0,1,0,0,0,0,0,167,253,122,1,185,255,61,0,96,255,32,3,126,254,251,252,47,1,203,255,248,0,234,255,59,0,31,241,195,255,102,0,211,255,139,1,0,0,0,0,28,0,0,0,244,255,0,0,205,2,88,254,243,1,40,1,241,255,11,0,172,10,153,255,137,255,140,255,107,0,206,255,206,1,73,0,174,255,75,0,41,0,131,0,0,0,3,0,1,0,255,255,0,0,0,0,122,255,109,0,48,0,201,248,51,255,250,255,20,0,53,255,136,0,197,0,113,0,179,255,132,255,206,255,184,0,225,0,81,255,217,254,255,255,255,255,250,255,255,255,255,255,0,0,197,255,31,248,63,255,19,255,226,0,118,2,158,7,254,255,179,0,174,241,222,255,140,0,88,0,157,0,51,0,81,0,249,254,87,255,1,0,0,0,0,0,0,0,0,0,0,0,229,0,242,255,202,249,133,255,162,0,63,0,32,255,180,254,119,0,115,11,21,0,208,255,150,1,15,0,64,1,205,255,64,0,28,255,247,255,255,255,0,0,255,255,0,0,0,0,59,254,84,0,192,254,114,253,252,255,165,255,195,255,46,2,195,255,23,255,31,0,32,255,151,255,63,0,86,0,187,14,162,0,1,250,3,0,253,255,1,0,1,0,0,0,1,0,56,248,233,254,197,255,24,244,96,249,102,0,88,255,194,0,172,0,114,255,55,0,134,0,116,0,110,255,227,255,225,254,102,0,9,1,253,255,1,0,0,0,1,0,0,0,0,0,160,255,46,0,240,255,170,9,198,255,56,253,231,255,218,254,187,0,22,0,217,255,154,255,62,0,106,10,19,255,255,255,32,0,215,255,0,0,0,0,0,0,0,0,0,0,0,0,230,254,231,255,58,255,162,252,129,255,133,254,46,255,236,255,45,0,177,255,11,245,148,254,63,2,106,0,215,0,102,254,180,255,255,1,15,0,212,255,255,255,1,0,0,0,0,0,73,1,224,0,130,0,43,0,255,255,1,255,205,255,215,254,177,17,52,0,186,0,245,2,188,255,167,255,46,0,250,0,46,0,177,255,5,0,1,0,0,0,1,0,0,0,237,255,79,0,74,0,65,0,0,1,4,1,236,1,150,255,39,255,155,254,20,0,166,0,233,0,132,0,165,0,18,0,255,255,93,17,234,255,5,0,3,0,249,255,0,0,0,0,250,255,102,252,108,8,13,1,105,5,235,0,50,255,162,255,130,0,112,0,145,0,130,255,166,0,1,0,45,0,83,0,36,0,103,255,1,255,0,0,255,255,0,0,0,0,1,0,0,0,241,0,19,255,139,255,2,254,85,0,7,0,190,238,30,0,94,0,164,255,99,0,185,255,140,0,247,254,149,0,69,0,30,1,104,0,0,0,254,255,1,0,0,0,0,0,0,0,91,255,22,0,11,255,29,0,50,0,145,0,203,255,105,6,216,255,128,255,144,255,66,255,47,0,53,0,9,255,206,255,88,0,39,0,1,0,255,255,0,0,0,0,0,0,0,0,224,254,130,0,88,0,124,255,215,15,249,255,55,0,151,255,21,1,81,0,69,0,190,255,203,255,52,0,200,255,90,0,160,0,130,1,1,0,252,255,0,0,254,255,0,0,0,0,107,0,124,0,217,255,40,0,25,0,250,255,8,255,175,255,70,0,243,255,46,0,5,0,20,0,24,0,251,255,254,255,215,255,222,255,1,0,1,0,248,255,0,0,252,255,0,0,195,255,1,0,201,1,198,1,0,3,89,0,128,2,61,0,66,0,152,254,89,245,101,255,142,254,212,255,220,254,58,2,34,0,119,243,251,255,255,255,1,0,0,0,255,255,0,0,22,0,174,255,236,255,131,255,165,255,98,0,163,30,25,0,254,255,225,255,2,0,204,255,183,255,231,255,31,0,221,255,250,255,142,255,1,0,255,255,2,0,0,0,0,0,0,0,217,0,174,235,86,0,180,255,180,255,109,0,133,1,161,255,3,255,124,0,130,0,58,0,190,0,212,255,189,255,114,255,54,0,6,0,255,255,1,0,1,0,1,0,0,0,0,0,73,255,35,2,56,255,92,1,116,1,181,1,169,1,35,2,55,254,132,1,87,0,38,0,246,253,46,255,212,253,41,0,93,244,239,255,7,0,252,255,6,0,0,0,0,0,0,0,189,0,196,0,240,0,181,255,46,0,206,255,101,0,96,255,240,255,33,255,92,0,71,0,47,226,78,0,90,0,69,0,190,0,181,255,2,0,1,0,254,255,255,255,0,0,1,0,205,0,79,254,245,254,81,255,252,11,46,255,254,253,74,1,229,243,239,254,155,0,132,0,206,254,105,1,60,1,203,255,91,254,131,255,253,255,0,0,245,255,0,0,0,0,0,0,179,0,218,255,151,0,220,255,215,0,154,255,111,255,139,0,50,0,200,0,127,1,37,0,30,12,229,255,9,0,99,255,188,255,111,1,1,0,1,0,0,0,0,0,1,0,0,0,206,255,177,0,232,255,24,0,119,0,4,0,76,0,99,0,145,255,57,227,26,0,51,0,245,255,110,255,131,255,208,255,54,0,50,0,1,0,0,0,0,0,0,0,255,255,0,0,185,255,240,255,72,255,195,255,220,255,105,255,79,0,128,255,154,255,135,0,28,255,190,0,177,255,246,255,80,255,143,255,240,3,168,252,243,255,252,255,8,0,28,0,0,0,1,0,211,236,163,255,89,255,115,255,51,0,53,255,71,0,57,255,207,255,106,0,114,255,162,255,126,0,31,255,158,0,36,0,13,1,159,0,0,0,1,0,1,0,0,0,0,0,251,255,195,255,177,255,236,255,50,1,67,0,147,253,238,6,90,1,70,254,125,0,49,1,86,255,55,0,23,246,153,255,118,0,87,0,249,1,16,0,249,255,254,255,0,0,20,0,0,0,35,0,102,255,98,255,224,0,220,255,168,254,79,0,136,16,234,0,37,255,185,255,204,0,28,254,125,255,129,4,23,0,111,0,243,1,5,0,0,0,239,255,0,0,0,0,1,0,111,4,115,242,23,254,12,10,62,254,80,254,154,254,222,255,178,255,246,255,249,252,17,0,125,255,102,255,218,0,82,0,200,254,23,1,1,0,0,0,1,0,0,0,0,0,0,0,96,0,230,0,18,0,47,0,251,255,154,255,134,2,134,255,35,0,175,255,183,0,171,0,57,250,201,0,84,0,232,255,143,0,46,1,1,0,5,0,0,0,0,0,0,0,0,0,222,255,208,255,89,0,109,30,171,255,229,255,200,255,46,0,39,0,30,0,98,0,216,255,138,0,109,255,104,0,221,255,215,255,105,255,1,0,9,0,1,0,0,0,0,0,0,0,116,255,78,248,86,255,17,1,226,0,33,0,188,254,218,255,11,0,188,0,91,2,188,0,73,255,98,0,198,255,189,255,193,255,7,0,0,0,0,0,0,0,0,0,1,0,0,0,128,1,131,3,237,1,253,2,218,251,134,2,19,1,117,245,93,0,28,3,120,0,231,255,177,0,171,255,209,2,67,255,217,254,76,254,0,0,255,255,0,0,0,0,255,255,0,0,154,254,117,0,125,246,69,1,191,243,98,255,23,0,97,0,6,0,204,0,32,1,86,254,156,0,22,0,155,255,171,0,200,255,235,0,0,0,255,255,0,0,255,255,0,0,0,0,144,2,38,15,226,254,129,254,75,0,206,255,114,0,135,254,151,255,106,0,154,0,226,255,52,255,151,255,171,0,200,255,230,0,181,253,0,0,1,0,0,0,8,0,1,0,255,255,198,255,177,0,249,255,45,0,97,255,149,1,45,0,84,0,50,255,77,0,21,1,253,254,121,0,135,14,140,0,79,0,54,255,75,3,248,255,0,0,255,255,1,0,254,255,0,0,8,255,48,2,91,10,207,255,143,253,109,255,144,246,119,0,186,255,87,0,137,0,18,0,111,254,109,255,170,253,106,255,239,0,20,252,7,0,3,0,13,0,1,0,1,0,1,0,20,1,86,1,97,0,88,2,230,0,95,0,213,0,159,0,253,254,231,255,80,255,32,13,229,254,187,254,219,255,190,245,105,255,178,0,255,255,238,255,0,0,0,0,0,0,0,0,23,255,237,0,178,255,34,1,228,254,141,0,236,255,146,0,58,0,235,255,73,0,221,255,155,255,233,255,28,240,140,255,49,0,60,255,251,255,254,255,0,0,1,0,255,255,0,0,220,254,61,255,51,0,54,253,172,0,44,0,137,255,134,0,168,0,107,0,182,255,181,246,52,1,173,0,4,255,114,242,121,255,129,2,246,255,0,0,0,0,1,0,0,0,0,0,146,0,12,8,172,255,92,255,9,255,26,0,68,249,216,0,226,0,61,246,56,1,190,255,82,3,41,0,255,255,20,0,197,250,155,1,0,0,0,0,255,255,244,255,0,0,0,0,153,3,17,0,74,242,137,255,69,1,34,0,159,255,51,255,3,0,68,255,252,0,91,0,0,0,121,255,180,255,208,0,199,0,54,255,255,255,1,0,1,0,2,0,0,0,255,255,168,255,51,254,63,1,61,252,10,1,4,6,131,2,160,242,76,0,222,251,245,1,86,1,41,1,12,1,98,255,153,255,26,0,226,255,0,0,255,255,255,255,0,0,0,0,0,0,211,0,245,0,183,0,43,6,106,0,26,0,134,242,234,255,227,251,246,254,32,253,113,0,219,1,15,255,117,0,171,255,20,254,116,1,0,0,1,0,1,0,0,0,0,0,0,0,95,254,31,255,172,255,16,0,150,255,222,255,10,255,92,255,112,0,48,0,209,255,36,0,191,255,188,255,84,255,137,249,220,255,140,0,253,255,254,255,254,255,2,0,0,0,0,0,178,0,7,0,75,255,79,255,120,0,192,255,127,255,80,0,86,229,218,255,231,255,147,0,148,0,243,255,231,255,110,0,21,0,21,0,255,255,0,0,0,0,0,0,0,0,0,0,247,12,120,2,34,253,69,255,40], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1875505);
/* memory initializer */ allocate([0,7,255,101,255,255,255,83,255,95,0,28,0,254,255,20,0,212,255,35,0,120,0,209,255,35,255,251,255,2,0,249,255,1,0,0,0,0,0,63,0,12,1,252,254,93,254,187,0,181,255,28,255,40,1,42,254,177,0,253,253,62,1,124,0,52,1,92,0,115,1,230,11,106,1,255,255,255,255,246,255,1,0,0,0,0,0,156,254,240,255,57,255,117,0,181,255,46,0,148,255,242,255,132,255,83,255,50,19,181,255,38,254,105,0,87,0,190,0,73,255,48,255,0,0,0,0,1,0,1,0,0,0,255,255,162,0,89,0,49,0,198,254,28,245,9,1,249,254,253,255,172,243,60,1,112,0,128,0,179,254,118,255,142,255,115,255,225,254,22,255,255,255,0,0,0,0,0,0,0,0,1,0,221,2,126,0,88,254,123,254,130,2,176,1,134,0,5,255,151,1,205,255,105,255,21,254,204,254,91,0,50,0,252,14,87,0,100,0,251,255,250,255,0,0,1,0,0,0,0,0,48,1,191,6,83,0,248,255,216,0,175,255,67,255,152,0,189,255,15,0,54,1,163,255,6,0,219,255,54,0,146,255,241,255,78,0,0,0,0,0,1,0,12,0,0,0,255,255,129,0,58,255,1,0,208,255,190,255,109,255,30,0,8,1,172,255,102,0,42,0,126,0,1,0,205,230,225,0,205,255,8,0,123,0,0,0,255,255,0,0,255,255,0,0,0,0,138,254,66,0,0,255,176,255,141,251,47,1,210,7,57,255,158,255,158,255,217,255,180,255,180,0,15,0,56,254,148,0,73,255,118,0,254,255,1,0,0,0,0,0,0,0,0,0,151,0,13,0,142,255,65,0,12,24,76,0,174,255,226,255,230,255,163,0,81,0,167,0,173,255,155,255,55,0,216,255,161,0,231,252,248,255,0,0,0,0,255,255,255,255,0,0,154,255,223,255,55,0,125,255,178,1,108,0,70,0,68,0,62,0,121,7,147,255,235,0,110,0,124,0,231,255,198,255,180,255,18,0,255,255,255,255,0,0,0,0,0,0,0,0,151,255,102,227,247,255,82,0,53,0,213,255,251,255,18,0,90,0,91,0,20,0,222,255,26,0,163,255,206,255,210,255,179,255,105,0,0,0,6,0,244,255,250,255,1,0,0,0,202,250,212,3,93,255,161,254,254,253,25,2,62,0,212,254,80,0,194,254,14,0,14,242,204,255,140,255,232,254,28,2,250,0,249,252,249,255,0,0,0,0,0,0,0,0,0,0,251,1,61,1,95,254,20,255,122,246,184,255,166,254,203,9,46,1,71,255,30,0,3,6,205,0,87,0,144,255,30,254,216,254,132,0,255,255,0,0,255,255,1,0,0,0,0,0,192,255,48,255,97,255,1,0,80,1,194,255,242,255,13,0,81,0,101,0,126,1,32,0,116,0,251,255,215,255,25,0,81,255,107,225,1,0,0,0,1,0,0,0,0,0,0,0,127,29,249,255,86,0,91,255,199,255,239,255,183,0,49,255,69,0,54,0,157,255,231,255,167,0,198,255,107,0,175,255,165,0,172,0,2,0,254,255,0,0,1,0,0,0,247,255,26,0,28,0,86,0,73,255,192,254,224,255,116,0,203,255,207,255,241,255,133,0,229,254,104,255,64,2,230,25,185,0,44,0,25,0,20,0,1,0,244,255,1,0,255,255,0,0,111,255,205,255,142,255,227,255,28,255,78,0,103,254,235,0,147,0,45,0,64,255,177,0,165,255,68,0,244,245,204,255,81,0,181,0,251,255,13,0,255,255,255,255,239,255,0,0,191,255,233,255,228,255,9,0,242,0,14,0,221,255,88,0,77,0,236,255,37,0,71,228,198,255,51,0,137,0,126,0,166,255,136,0,0,0,4,0,255,255,0,0,0,0,0,0,246,254,174,255,51,255,48,3,203,254,195,12,29,4,113,1,40,255,210,254,18,0,168,0,139,1,17,1,87,1,243,0,158,255,203,255,1,0,0,0,0,0,1,0,0,0,0,0,191,255,180,255,58,7,33,252,58,254,233,253,111,11,111,255,101,0,23,0,20,0,234,0,182,255,77,0,114,0,4,0,150,255,15,2,245,255,4,0,0,0,1,0,255,255,0,0,61,2,210,255,207,0,80,10,68,252,47,0,26,0,246,255,61,1,39,255,251,255,157,252,253,255,213,0,52,0,53,0,84,254,81,255,0,0,0,0,255,255,255,255,0,0,255,255,33,255,201,255,135,0,184,0,57,1,0,0,52,11,245,0,141,243,47,253,221,254,9,0,247,254,136,255,151,255,220,255,198,1,55,0,255,255,49,0,0,0,1,0,255,255,0,0,221,254,41,0,84,0,45,2,55,255,4,247,173,1,27,1,21,0,254,255,132,0,30,1,132,255,149,0,242,255,146,0,64,1,214,254,0,0,255,255,1,0,254,255,0,0,0,0,170,255,91,242,131,0,3,242,185,0,26,0,59,255,191,255,160,255,147,0,203,255,106,255,221,255,221,255,179,0,68,0,99,255,0,0,0,0,2,0,0,0,1,0,2,0,255,255,234,255,38,255,13,0,89,250,112,254,32,1,241,250,0,0,137,255,69,0,200,255,117,255,157,0,230,255,134,255,195,255,218,255,148,255,255,255,1,0,0,0,0,0,0,0,0,0,27,255,7,13,103,0,148,255,10,0,192,11,56,253,50,0,27,0,152,0,205,254,150,255,148,0,179,255,78,255,210,255,7,0,142,255,0,0,247,255,0,0,0,0,1,0,0,0,164,3,69,254,55,1,181,255,62,0,176,255,77,255,203,1,24,255,96,255,2,0,169,0,134,0,252,254,41,0,107,255,23,0,92,0,254,255,0,0,11,0,1,0,0,0,0,0,16,0,166,255,194,253,85,255,163,0,5,1,213,254,178,11,74,0,22,241,116,254,85,255,13,0,227,255,211,255,88,255,225,254,122,254,1,0,0,0,0,0,252,255,0,0,255,255,89,0,66,253,175,8,101,0,7,255,167,11,36,0,179,254,130,254,154,1,250,254,185,0,110,255,98,0,248,255,195,254,233,254,145,252,0,0,0,0,0,0,0,0,4,0,0,0,158,255,187,254,75,0,27,255,243,255,112,0,145,233,222,255,167,255,7,1,101,255,80,0,140,0,206,255,33,0,143,0,196,255,179,255,1,0,254,255,0,0,255,255,1,0,0,0,52,0,192,253,225,253,138,251,77,252,72,255,193,1,185,255,181,255,100,255,172,242,206,255,25,254,51,1,151,2,24,252,97,254,212,246,249,255,255,255,255,255,0,0,0,0,0,0,64,0,3,0,221,255,11,0,14,0,58,255,254,255,150,224,140,0,245,255,163,255,29,0,191,255,74,1,34,0,110,0,237,255,119,255,2,0,0,0,0,0,0,0,0,0,0,0,212,4,47,1,121,10,234,0,39,255,106,254,117,254,132,254,247,0,93,1,155,255,223,255,114,1,217,255,139,0,59,0,18,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,166,0,235,255,240,234,139,255,216,254,114,0,230,0,1,255,131,0,203,255,13,0,211,255,200,0,7,0,200,255,87,0,46,0,223,0,197,255,0,0,255,255,0,0,0,0,255,255,214,0,1,254,175,0,204,0,133,255,209,255,72,254,6,0,23,0,92,0,157,254,80,0,235,236,18,255,219,255,78,0,38,255,175,0,0,0,2,0,0,0,0,0,0,0,0,0,110,255,74,0,243,255,252,255,27,0,211,255,51,0,81,0,176,255,53,0,238,255,173,0,110,255,192,255,248,255,0,32,79,0,15,0,0,0,253,255,0,0,1,0,0,0,0,0,253,255,240,255,228,255,32,1,195,255,4,0,69,255,6,0,251,255,242,255,77,0,244,255,203,255,16,0,215,255,249,255,246,255,254,255,7,0,255,255,247,255,1,0,0,0,0,0,227,254,221,255,248,255,221,0,188,255,114,0,135,0,248,255,53,255,75,255,165,255,251,7,198,255,127,0,201,0,111,0,46,0,168,254,245,255,207,255,0,0,1,0,0,0,255,255,96,255,70,255,58,0,153,18,33,1,51,0,111,255,51,0,224,255,71,0,62,0,175,0,243,255,181,0,203,0,141,0,56,255,106,0,255,255,4,0,254,255,0,0,0,0,0,0,35,3,180,255,160,255,84,252,44,1,101,13,172,255,221,11,6,1,247,255,217,255,120,0,139,253,203,254,233,0,138,254,142,1,126,3,244,255,1,0,1,0,1,0,0,0,0,0,230,254,221,9,225,255,80,255,87,246,53,0,102,0,158,253,180,0,111,255,42,0,205,255,223,0,27,0,187,255,215,2,242,255,205,255,0,0,0,0,0,0,253,255,0,0,216,255,214,0,72,0,41,0,1,0,190,0,78,0,28,255,21,255,105,0,245,237,116,255,210,255,249,255,49,0,9,0,237,255,137,0,254,255,9,0,1,0,0,0,0,0,0,0,0,0,114,255,250,254,29,0,114,255,39,0,217,255,164,255,95,0,50,0,230,254,2,0,150,255,114,0,8,0,35,0,78,0,135,255,29,10,1,0,252,255,246,255,1,0,1,0,0,0,64,255,59,0,31,1,144,1,189,255,179,228,211,254,190,1,115,0,7,0,33,0,196,255,111,0,102,0,8,0,206,0,46,0,225,255,255,255,255,255,254,255,0,0,0,0,0,0,152,255,76,1,33,255,42,4,68,255,246,4,34,255,53,1,216,254,3,1,12,3,52,254,134,248,218,0,212,253,210,0,146,11,130,0,1,0,254,255,2,0,0,0,1,0,0,0,192,254,147,254,246,254,54,3,137,255,56,3,200,254,58,0,191,248,235,0,48,0,111,240,118,0,205,254,65,253,93,252,208,253,105,0,254,255,253,255,0,0,0,0,0,0,1,0,156,0,208,255,187,0,214,0,44,255,180,0,86,1,117,1,181,7,128,0,251,255,146,0,216,255,245,255,71,0,196,255,76,0,17,0,0,0,0,0,255,255,2,0,0,0,7,0,214,0,63,0,18,1,60,11,191,255,58,1,144,1,88,1,140,0,39,0,193,0,30,255,124,0,151,243,68,0,46,0,196,255,195,254,2,0,0,0,255,255,0,0,7,0,0,0,96,255,118,0,233,0,239,0,47,254,96,0,253,0,106,12,168,255,43,1,112,1,36,255,197,0,141,1,159,254,49,254,54,255,153,255,252,255,0,0,0,0,0,0,0,0,0,0,175,2,64,254,19,253,87,0,221,255,112,0,53,1,223,255,240,255,88,0,141,0,63,0,205,255,18,1,143,255,180,255,46,0,239,254,255,255,1,0,0,0,1,0,0,0,1,0,214,254,50,255,158,2,47,1,61,254,235,254,19,254,148,1,83,255,28,1,148,0,114,2,190,254,216,254,188,255,228,11,70,254,114,4,249,255,2,0,0,0,1,0,0,0,0,0,198,250,18,0,46,11,223,0,250,0,4,1,144,0,3,1,218,255,121,253,90,2,96,255,75,0,251,255,248,255,34,0,237,0,50,0,2,0,0,0,1,0,255,255,255,255,0,0,100,254,105,8,165,3,222,1,0,3,186,0,88,254,111,253,126,242,69,254,38,1,224,0,44,254,198,255,136,255,227,249,211,0,92,254,0,0,0,0,1,0,255,255,0,0,0,0,198,0,227,0,144,255,94,1,41,1,209,254,108,0,64,255,153,0,32,0,99,245,145,255,187,251,56,255,220,1,70,1,241,254,115,2,0,0,252,255,0,0,0,0,0,0,255,255,206,1,152,253,126,0,60,1,147,246,204,0,162,254,35,242,249,254,126,254,144,255,227,1,197,250,124,2,70,0,237,253,96,0,38,0,8,0,255,255,0,0,253,255,0,0,0,0,202,254,152,251,104,2,173,254,88,255,132,255,119,252,105,255,129,254,76,0,137,0,212,255,105,14,124,254,184,0,7,7,154,255,94,252,6,0,255,255,255,255,255,255,0,0,0,0,228,254,24,1,39,0,40,253,143,0,15,0,181,0,30,3,126,1,10,0,219,8,244,255,2,242,229,255,101,1,2,2,203,253,135,255,0,0,255,255,0,0,247,255,255,255,0,0,173,1,240,255,177,11,169,244,47,0,120,255,30,0,24,3,185,254,165,254,187,255,206,255,163,255,33,255,74,254,158,0,203,0,37,254,0,0,252,255,255,255,2,0,0,0,0,0,119,242,159,1,61,252,252,0,141,1,79,252,64,254,25,255,126,255,161,2,248,1,55,0,157,254,221,0,29,0,167,0,237,255,134,0,255,255,255,255,252,255,0,0,242,255,254,255,44,0,177,1,233,253,40,255,181,9,33,0,19,0,156,255,71,255,85,255,91,0,80,1,48,255,140,0,253,255,46,0,189,255,140,255,32,0,0,0,5,0,3,0,0,0,0,0,220,0,91,0,191,255,241,255,87,255,217,0,73,255,87,255,209,255,181,0,240,254,138,0,90,255,110,0,247,255,41,0,211,228,33,0,251,255,254,255,1,0,1,0,0,0,255,255,164,0,34,240,147,255,230,0,36,255,212,6,198,250,10,255,14,255,158,255,44,1,217,0,54,255,126,255,157,0,253,255,237,255,59,254,0,0,2,0,0,0,0,0,0,0,0,0,240,163,36,0,112,0,0,0,192,24,20,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,42,43,43,44,44,45,45,46,46,47,47,48,48,48,49,49,49,50,50,50,51,254,254,254,252,249,243,230,196,177,153,140,133,130,129,0,0,2,2,4,4,6,6,8,8,10,10,12,12,14,14,16,16,18,18,20,20,0,0,0,0,2,2,4,4,6,6,8,8,0,0,0,0,0,0,0,0,2,2,4,4,6,6,0,0,2,2,4,4,0,0,0,0,2,2,0,0,0,0,0,0,1,1,0,0,0,0,0,0,3,2,2,0,0,0,0,0,0,8,16,0,0,0,0,0,4,3,3,2,0,0,0,0,4,4,3,3,0,0,0,0,0,1,3,5,0,0,0,0,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,23,33,23,2,21,0,1,9,0,49,219,118,5,57,243,78,245,65,1,62,12,49,252,73,17,50,18,64,9,43,29,0,26,67,16,90,9,104,210,127,236,104,1,67,243,78,245,65,1,62,250,86,239,95,250,61,9,45,253,69,250,81,245,96,6,55,7,67,251,86,2,88,0,58,253,76,246,94,5,54,4,69,253,81,0,88,249,67,251,74,252,74,251,80,249,72,1,58,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,0,45,252,78,253,96,229,126,228,98,231,101,233,67,228,82,236,94,240,83,234,110,235,91,238,102,243,93,227,127,249,92,251,89,249,96,243,108,253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,5,54,6,60,6,59,6,69,255,48,0,68,252,69,248,88,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,3,64,1,61,9,63,7,50,16,39,5,44,4,52,11,48,251,60,255,59,0,59,22,33,5,44,14,43,255,78,0,60,9,69,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,1,67,5,59,9,67,16,30,18,32,18,35,22,29,24,31,23,38,18,43,20,41,11,63,9,59,9,64,255,94,254,89,247,108,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,0,70,252,29,5,31,7,42,1,59,254,58,253,72,253,81,245,97,0,58,8,5,10,14,14,18,13,27,2,40,0,58,253,70,250,79,248,85,0,0,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,254,69,254,59,6,70,10,44,9,31,12,43,3,53,14,34,10,38,253,52,13,40,17,32,7,44,7,38,13,50,10,57,26,43,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,8,60,6,63,17,65,21,24,23,20,26,23,27,32,28,23,28,24,23,40,24,32,28,29,23,42,19,57,22,53,22,61,11,86,12,40,11,51,14,59,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,249,92,251,89,249,96,243,108,253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,249,92,251,89,249,96,243,108,253,46,255,65,255,57,247,93,253,74,247,92,248,87,233,126,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,254,85,250,78,255,75,249,77,2,54,5,50,253,68,1,50,6,42,252,81,1,63,252,70,0,67,2,57,254,76,11,35,4,64,1,61,11,35,18,25,12,24,13,29,13,36,246,93,249,73,254,73,13,46,9,49,249,100,9,53,2,53,5,53,254,61,0,56,0,56,243,63,251,60,255,62,4,57,250,69,4,57,14,39,4,51,13,68,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,11,28,2,40,3,44,0,49,0,46,2,44,2,51,0,47,4,39,2,62,6,46,0,54,3,54,2,58,4,63,6,51,6,57,7,53,6,52,6,55,11,45,14,36,8,53,255,82,7,55,253,78,15,46,22,31,255,84,25,7,30,249,28,3,28,4,32,0,34,255,30,6,30,6,32,9,31,19,26,27,26,30,37,20,28,34,17,70,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,252,79,249,71,251,69,247,70,248,66,246,68,237,73,244,69,240,70,241,67,236,62,237,70,240,66,234,65,236,63,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,9,254,26,247,33,247,39,249,41,254,45,3,49,9,45,27,36,59,21,243,33,242,39,249,46,254,51,2,60,6,61,17,55,34,42,62,250,66,249,35,249,42,248,45,251,48,244,56,250,60,251,62,248,66,248,76,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,243,106,240,106,246,87,235,114,238,110,242,98,234,110,235,106,238,103,235,107,233,108,230,112,246,96,244,95,251,91,247,93,234,94,251,86,9,67,252,80,246,85,255,70,7,60,9,58,5,61,12,50,15,50,18,49,17,54,10,41,7,46,255,51,7,49,8,52,9,41,6,47,2,55,13,41,10,44,6,50,5,53,13,49,4,63,6,64,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,14,11,11,14,9,11,18,11,21,9,23,254,32,241,32,241,34,235,39,233,42,223,41,225,46,228,38,244,21,29,45,232,53,211,48,230,65,213,43,237,39,246,30,9,18,26,20,27,0,57,242,82,251,75,237,97,221,125,27,0,28,0,31,252,27,6,34,8,30,10,24,22,33,19,22,32,26,31,21,41,26,44,23,47,16,65,14,71,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,250,76,254,44,0,45,0,52,253,64,254,59,252,70,252,75,248,82,239,102,247,77,3,24,0,42,0,48,0,55,250,59,249,71,244,83,245,87,226,119,1,58,253,29,255,36,1,38,2,43,250,55,0,58,0,64,253,74,246,90,253,74,247,92,248,87,233,126,253,74,247,92,248,87,233,126,253,74,247,92,248,87,233,126,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,22,25,34,0,16,0,254,9,4,41,227,118,2,65,250,71,243,79,5,52,9,50,253,70,10,54,26,34,19,22,40,0,57,2,41,36,26,69,211,127,241,101,252,76,250,71,243,79,5,52,6,69,243,90,0,52,8,43,254,69,251,82,246,96,2,59,2,75,253,87,253,100,1,56,253,74,250,85,0,59,253,81,249,86,251,95,255,66,255,77,1,70,254,86,251,72,0,61,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,13,15,7,51,2,80,217,127,238,91,239,96,230,81,221,98,232,102,233,97,229,119,232,99,235,110,238,102,220,127,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,3,55,7,56,7,55,8,61,253,53,0,68,249,74,247,88,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,252,71,0,58,7,61,9,41,18,25,9,32,5,43,9,47,0,44,0,51,2,46,19,38,252,66,15,38,12,42,9,34,0,89,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,0,75,2,72,8,77,14,35,18,31,17,35,21,30,17,45,20,42,18,45,27,26,16,54,7,66,16,56,11,73,10,67,246,116,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,2,66,247,34,1,32,11,31,5,52,254,55,254,67,0,73,248,89,3,52,7,4,10,8,17,8,16,19,3,37,255,61,251,73,255,70,252,78,0,0,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,255,70,247,72,14,60,16,37,0,47,18,35,11,37,12,41,10,41,2,48,12,41,13,41,0,59,3,50,19,40,3,66,18,50,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,12,48,11,49,26,45,22,22,23,22,27,21,33,20,26,28,30,24,27,34,18,42,25,39,18,50,12,70,21,54,14,71,11,83,25,32,21,49,21,54,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,0,80,251,89,249,94,252,92,0,39,0,65,241,84,221,127,254,73,244,104,247,91,225,127,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,243,103,243,91,247,89,242,92,248,76,244,87,233,110,232,105,246,78,236,112,239,99,178,127,186,127,206,127,210,127,252,66,251,78,252,71,248,72,2,59,255,55,249,70,250,75,248,89,222,119,253,75,32,20,30,22,212,127,0,54,251,61,0,58,255,60,253,61,248,67,231,84,242,74,251,65,5,52,2,57,0,61,247,69,245,70,18,55,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,4,45,10,28,10,31,33,245,52,213,18,15,28,0,35,234,38,231,34,0,39,238,32,244,102,162,0,0,56,241,33,252,29,10,37,251,51,227,39,247,52,222,69,198,67,193,44,251,32,7,55,227,32,1,0,0,27,36,33,231,34,226,36,228,38,228,38,229,34,238,35,240,34,242,32,248,37,250,35,0,30,10,28,18,26,25,29,41,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,251,85,250,81,246,77,249,81,239,80,238,73,252,74,246,83,247,71,247,67,255,61,248,66,242,66,0,59,2,59,253,81,253,76,249,72,250,78,244,72,242,68,253,70,250,76,251,66,251,62,0,57,252,61,247,60,1,54,2,58,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,17,246,32,243,42,247,49,251,53,0,64,3,68,10,66,27,47,57,251,71,0,24,255,36,254,42,254,52,247,57,250,63,252,65,252,67,249,82,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,235,126,233,124,236,110,230,126,231,124,239,105,229,121,229,117,239,102,230,117,229,116,223,122,246,95,242,100,248,95,239,111,228,114,250,89,254,80,252,82,247,85,248,81,255,72,5,64,1,67,9,56,0,69,1,69,7,69,249,69,250,67,240,77,254,64,2,61,250,67,253,64,2,57,253,65,253,66,0,62,9,51,255,66,254,71,254,75,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,19,250,18,250,14,0,26,244,31,240,33,231,33,234,37,228,39,226,42,226,47,214,45,220,49,222,41,239,32,9,69,185,63,193,66,192,77,182,54,217,52,221,41,246,36,0,40,255,30,14,28,26,23,37,12,55,11,65,37,223,39,220,40,219,38,226,46,223,42,226,40,232,49,227,38,244,40,246,38,253,46,251,31,20,29,30,25,44,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,233,112,241,71,249,61,0,53,251,66,245,77,247,80,247,84,246,87,222,127,235,101,253,39,251,53,249,61,245,75,241,77,239,91,231,107,231,111,228,122,245,76,246,44,246,52,246,57,247,58,240,72,249,69,252,69,251,74,247,86,254,73,244,104,247,91,225,127,254,73,244,104,247,91,225,127,254,73,244,104,247,91,225,127,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,29,16,25,0,14,0,246,51,253,62,229,99,26,16,252,85,232,102,5,57,6,57,239,73,14,57,20,40,20,10,29,0,54,0,37,42,12,97,224,127,234,117,254,74,252,85,232,102,5,57,250,93,242,88,250,44,4,55,245,89,241,103,235,116,19,57,20,58,4,84,6,96,1,63,251,85,243,106,5,63,6,75,253,90,255,101,3,55,252,79,254,75,244,97,249,50,1,60,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,7,34,247,88,236,127,220,127,239,91,242,95,231,84,231,86,244,89,239,91,225,127,242,76,238,103,243,90,219,127,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,0,65,254,79,0,72,252,92,250,56,3,68,248,71,243,98,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,3,65,249,69,8,77,246,66,3,62,253,68,236,81,0,30,1,7,253,23,235,74,16,66,233,124,17,37,44,238,50,222,234,127,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,20,34,19,31,27,44,19,16,15,36,15,36,21,28,25,21,30,20,31,12,27,16,24,42,0,93,14,56,15,57,26,38,232,127,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,252,79,234,69,240,75,254,58,1,58,243,78,247,83,252,81,243,99,243,81,250,38,243,62,250,58,254,59,240,73,246,76,243,86,247,83,246,87,0,0,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,254,76,238,86,12,70,5,64,244,70,11,55,5,56,0,69,2,65,250,74,5,54,7,54,250,76,245,82,254,77,254,77,25,42,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,18,31,19,26,36,24,24,23,27,16,24,30,31,29,22,41,22,42,16,60,15,52,14,60,3,78,240,123,21,53,22,56,25,61,21,33,19,50,17,61,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,11,80,5,76,2,84,5,78,250,55,4,61,242,83,219,127,251,79,245,104,245,91,226,127,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,252,86,244,88,251,82,253,72,252,67,248,72,240,89,247,69,255,59,5,66,4,57,252,71,254,71,2,58,255,74,252,44,255,69,0,62,249,51,252,47,250,42,253,41,250,53,8,76,247,78,245,83,9,52,0,67,251,90,1,67,241,72,251,75,248,80,235,83,235,64,243,31,231,64,227,94,9,75,17,63,248,74,251,35,254,27,13,91,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,4,39,0,42,7,34,11,29,8,31,6,37,7,42,3,40,8,33,13,43,13,36,4,47,3,55,2,58,6,60,8,44,11,44,14,42,7,48,4,56,4,52,13,37,9,49,19,58,10,48,12,45,0,69,20,33,8,63,35,238,33,231,28,253,24,10,27,0,34,242,52,212,39,232,19,17,31,25,36,29,24,33,34,15,30,20,22,73,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,253,78,248,74,247,72,246,72,238,75,244,71,245,63,251,70,239,75,242,72,240,67,248,53,242,59,247,52,245,68,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,9,254,30,246,31,252,33,255,33,7,31,12,37,23,31,38,20,64,247,71,249,37,248,44,245,49,246,56,244,59,248,63,247,67,250,68,246,79,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,234,127,231,127,231,120,229,127,237,114,233,117,231,118,230,117,232,113,228,118,225,120,219,124,246,94,241,102,246,99,243,106,206,127,251,92,17,57,251,86,243,94,244,91,254,77,0,71,255,73,4,64,249,81,5,64,15,57,1,67,0,68,246,67,1,68,0,77,2,64,0,68,251,78,7,55,5,59,2,65,14,54,15,44,5,60,2,70,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,17,243,16,247,17,244,27,235,37,226,41,216,42,215,48,209,39,224,46,216,52,205,46,215,52,217,43,237,32,11,61,201,56,210,62,206,81,189,45,236,35,254,28,15,34,1,39,1,30,17,20,38,18,45,15,54,0,79,36,240,37,242,37,239,32,1,34,15,29,15,24,25,34,22,31,16,35,18,31,28,33,41,36,28,27,47,21,62,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,232,115,234,82,247,62,0,53,0,59,242,85,243,89,243,94,245,92,227,127,235,100,242,57,244,67,245,71,246,77,235,85,240,88,233,104,241,98,219,127,246,82,248,48,248,61,248,66,249,70,242,75,246,79,247,83,244,92,238,108,251,79,245,104,245,91,226,127,251,79,245,104,245,91,226,127,251,79,245,104,245,91,226,127,20,241,2,54,3,74,20,241,2,54,3,74,228,127,233,104,250,53,255,54,7,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41,0,63,0,63,0,63,247,83,4,86,0,97,249,72,13,41,3,62,0,11,1,55,0,69,239,127,243,102,0,82,249,74,235,107,229,127,225,127,232,127,238,95,229,127,235,114,226,127,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,255,74,250,97,249,91,236,127,252,56,251,82,249,76,234,125,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,248,102,241,100,0,95,252,75,2,72,245,75,253,71,15,46,243,69,0,62,0,65,21,37,241,72,9,57,16,54,0,62,12,72,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38,1,41,17,30,250,27,3,26,22,37,240,35,252,38,248,38,253,37,3,38,5,42,0,35,16,39,22,14,48,27,37,21,60,12,68,2,97,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,245,97,236,84,245,79,250,73,252,74,243,86,243,96,245,97,237,117,248,78,251,33,252,48,254,53,253,62,243,71,246,79,244,86,243,90,242,97,0,0,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,249,99,242,95,2,95,0,76,251,74,0,70,245,75,1,68,0,65,242,73,3,62,4,62,255,68,243,75,11,55,5,64,12,70,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,29,253,26,0,22,30,31,249,35,241,34,253,34,3,36,255,34,5,32,11,35,5,34,12,39,11,30,29,34,26,29,39,19,66,31,21,31,31,25,50,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1885745);
/* memory initializer */ allocate([73,246,70,246,69,251,66,247,64,251,58,2,59,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,239,123,244,115,240,122,245,115,244,63,254,68,241,84,243,104,253,70,248,93,246,90,226,127,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,249,93,245,87,253,77,251,71,252,63,252,68,244,84,249,62,249,65,8,61,5,56,254,66,1,64,0,61,254,78,1,50,7,52,10,35,0,44,11,38,1,45,0,46,5,44,31,17,1,51,7,50,28,19,16,33,14,62,243,108,241,100,243,101,243,91,244,94,246,88,240,84,246,86,249,83,243,87,237,94,1,70,0,72,251,74,18,59,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38,1,41,17,24,0,15,9,8,25,13,18,15,9,13,19,10,37,12,18,6,29,20,33,15,30,4,45,1,58,0,62,7,61,12,38,11,45,15,39,11,42,13,44,16,45,12,41,10,49,30,34,18,42,10,55,17,51,17,46,0,89,26,237,22,239,26,239,30,231,28,236,33,233,37,229,33,233,40,228,38,239,33,245,40,241,41,250,38,1,41,17,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246,73,246,70,246,69,251,66,247,64,251,58,2,59,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,239,120,236,112,238,114,245,85,241,92,242,89,230,71,241,81,242,80,0,68,242,70,232,56,233,68,232,50,245,74,242,106,243,97,241,90,244,90,238,88,246,73,247,79,242,86,246,73,246,70,246,69,251,66,247,64,251,58,2,59,23,243,26,243,40,241,49,242,44,3,45,6,44,34,33,54,19,82,21,246,24,245,28,248,28,255,29,3,29,9,35,20,29,36,14,67,253,75,255,23,1,34,1,43,0,54,254,55,0,61,1,64,0,68,247,92,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,250,93,250,84,248,79,0,66,255,71,0,62,254,60,254,59,251,75,253,62,252,58,247,66,255,79,0,71,3,68,10,44,249,62,15,36,14,40,16,27,12,29,1,44,20,36,18,32,5,42,1,48,10,62,17,46,9,64,244,104,245,97,240,96,249,88,248,85,249,85,247,85,243,88,4,66,253,77,253,76,250,76,10,58,255,76,255,83,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,15,6,6,19,7,16,12,14,18,13,13,11,13,15,15,16,12,23,13,23,15,20,14,26,14,44,17,40,17,47,24,17,21,21,25,22,31,27,22,29,19,35,14,50,10,57,7,63,254,77,252,82,253,94,9,69,244,109,36,221,36,222,32,230,37,226,44,224,34,238,34,241,40,241,33,249,35,251,33,0,38,2,33,13,23,35,13,58,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,253,71,250,42,251,50,253,54,254,62,0,58,1,63,254,72,255,74,247,91,251,67,251,27,253,39,254,44,0,46,240,64,248,68,246,78,250,77,246,86,244,92,241,55,246,60,250,62,252,65,244,73,248,76,249,80,247,88,239,110,253,70,248,93,246,90,226,127,253,70,248,93,246,90,226,127,253,70,248,93,246,90,226,127,0,0,1,0,2,0,3,0,5,0,8,0,13,0,21,0,255,0,254,0,253,0,251,0,248,0,243,0,239,0,235,0,0,1,1,1,2,1,3,1,5,1,8,1,13,1,21,1,255,1,254,1,253,1,251,1,248,1,243,1,239,1,235,1,0,2,1,2,2,2,3,2,5,2,8,2,13,2,21,2,255,2,254,2,253,2,251,2,248,2,243,2,239,2,235,2,0,3,1,3,2,3,3,3,5,3,8,3,13,3,21,3,255,3,254,3,253,3,251,3,248,3,243,3,239,3,235,3,0,5,1,5,2,5,3,5,5,5,8,5,13,5,21,5,255,5,254,5,253,5,251,5,248,5,243,5,239,5,235,5,0,8,1,8,2,8,3,8,5,8,8,8,13,8,21,8,255,8,254,8,253,8,251,8,248,8,243,8,239,8,235,8,0,13,1,13,2,13,3,13,5,13,8,13,13,13,21,13,255,13,254,13,253,13,251,13,248,13,243,13,239,13,235,13,0,21,1,21,2,21,3,21,5,21,8,21,13,21,21,21,255,21,254,21,253,21,251,21,248,21,243,21,239,21,235,21,0,255,1,255,2,255,3,255,5,255,8,255,13,255,21,255,255,255,254,255,253,255,251,255,248,255,243,255,239,255,235,255,0,254,1,254,2,254,3,254,5,254,8,254,13,254,21,254,255,254,254,254,253,254,251,254,248,254,243,254,239,254,235,254,0,253,1,253,2,253,3,253,5,253,8,253,13,253,21,253,255,253,254,253,253,253,251,253,248,253,243,253,239,253,235,253,0,251,1,251,2,251,3,251,5,251,8,251,13,251,21,251,255,251,254,251,253,251,251,251,248,251,243,251,239,251,235,251,0,248,1,248,2,248,3,248,5,248,8,248,13,248,21,248,255,248,254,248,253,248,251,248,248,248,243,248,239,248,235,248,0,243,1,243,2,243,3,243,5,243,8,243,13,243,21,243,255,243,254,243,253,243,251,243,248,243,243,243,239,243,235,243,0,239,1,239,2,239,3,239,5,239,8,239,13,239,21,239,255,239,254,239,253,239,251,239,248,239,243,239,239,239,235,239,0,235,1,235,2,235,3,235,5,235,8,235,13,235,21,235,255,235,254,235,253,235,251,235,248,235,243,235,239,235,0,0,248,227,8,227,238,231,17,231,0,233,250,234,6,234,243,237,12,237,0,238,25,238,231,239,251,239,5,239,246,241,10,241,0,242,252,243,4,243,19,243,237,244,248,245,254,245,0,245,2,245,8,245,241,246,252,246,4,246,15,246,250,247,255,247,1,247,6,247,227,248,245,248,248,248,253,248,3,248,8,248,11,248,29,248,251,249,254,249,0,249,2,249,5,249,234,250,247,250,250,250,253,250,255,250,1,250,3,250,6,250,9,250,22,250,239,251,249,251,252,251,254,251,0,251,2,251,4,251,7,251,17,251,243,252,246,252,251,252,253,252,255,252,0,252,1,252,3,252,5,252,10,252,13,252,248,253,250,253,252,253,253,253,254,253,255,253,0,253,1,253,2,253,4,253,6,253,8,253,245,254,249,254,251,254,253,254,254,254,255,254,0,254,1,254,2,254,3,254,5,254,7,254,11,254,247,255,250,255,252,255,253,255,254,255,255,255,0,255,1,255,2,255,3,255,4,255,6,255,9,255,225,0,233,0,238,0,242,0,245,0,249,0,251,0,252,0,253,0,254,0,255,0,0,225,1,0,2,0,3,0,4,0,5,0,7,0,11,0,14,0,18,0,23,0,31,0,247,1,250,1,252,1,253,1,254,1,255,1,0,1,1,1,2,1,3,1,4,1,6,1,9,1,245,2,249,2,251,2,253,2,254,2,255,2,0,2,1,2,2,2,3,2,5,2,7,2,11,2,248,3,250,3,252,3,254,3,255,3,0,3,1,3,2,3,3,3,4,3,6,3,8,3,243,4,246,4,251,4,253,4,255,4,0,4,1,4,3,4,5,4,10,4,13,4,239,5,249,5,252,5,254,5,0,5,2,5,4,5,7,5,17,5,234,6,247,6,250,6,253,6,255,6,1,6,3,6,6,6,9,6,22,6,251,7,254,7,0,7,2,7,5,7,227,8,245,8,248,8,253,8,3,8,8,8,11,8,29,8,250,9,255,9,1,9,6,9,241,10,252,10,4,10,15,10,248,11,254,11,0,11,2,11,8,11,19,12,237,13,252,13,4,13,0,14,246,15,10,15,251,17,5,17,25,17,231,18,0,18,244,19,13,19,250,22,6,22,0,23,239,25,18,25,248,29,8,29,0,31,0,0,250,234,6,234,243,237,12,237,0,238,251,239,5,239,246,241,10,241,0,242,252,243,4,243,19,243,237,244,248,245,254,245,0,245,2,245,8,245,241,246,252,246,4,246,15,246,250,247,255,247,1,247,6,247,245,248,248,248,253,248,0,248,3,248,8,248,11,248,251,249,254,249,0,249,2,249,5,249,234,250,247,250,250,250,253,250,255,250,1,250,3,250,6,250,9,250,22,250,239,251,249,251,252,251,254,251,255,251,0,251,1,251,2,251,4,251,7,251,17,251,243,252,246,252,251,252,253,252,254,252,255,252,0,252,1,252,2,252,3,252,5,252,10,252,13,252,248,253,250,253,252,253,253,253,254,253,255,253,0,253,1,253,2,253,3,253,4,253,6,253,8,253,245,254,249,254,251,254,252,254,253,254,254,254,255,254,0,254,1,254,2,254,3,254,4,254,5,254,7,254,11,254,247,255,250,255,251,255,252,255,253,255,254,255,255,255,0,255,1,255,2,255,3,255,4,255,5,255,6,255,9,255,233,0,238,0,242,0,245,0,249,0,251,0,252,0,253,0,254,0,255,0,0,233,1,0,2,0,3,0,4,0,5,0,7,0,11,0,14,0,18,0,23,0,247,1,250,1,251,1,252,1,253,1,254,1,255,1,0,1,1,1,2,1,3,1,4,1,5,1,6,1,9,1,245,2,249,2,251,2,252,2,253,2,254,2,255,2,0,2,1,2,2,2,3,2,4,2,5,2,7,2,11,2,248,3,250,3,252,3,253,3,254,3,255,3,0,3,1,3,2,3,3,3,4,3,6,3,8,3,243,4,246,4,251,4,253,4,254,4,255,4,0,4,1,4,2,4,3,4,5,4,10,4,13,4,239,5,249,5,252,5,254,5,255,5,0,5,1,5,2,5,4,5,7,5,17,5,234,6,247,6,250,6,253,6,255,6,1,6,3,6,6,6,9,6,22,6,251,7,254,7,0,7,2,7,5,7,245,8,248,8,253,8,0,8,3,8,8,8,11,8,250,9,255,9,1,9,6,9,241,10,252,10,4,10,15,10,248,11,254,11,0,11,2,11,8,11,19,12,237,13,252,13,4,13,0,14,246,15,10,15,251,17,5,17,0,18,244,19,13,19,250,22,6,22,0,23,0,0,0,0,0,0,255,255,255,255,2,0,0,0,20,0,0,0,104,0,0,0,208,1,0,0,160,7,0,0,64,31,0,0,128,126,0,0,0,253,1,0,0,250,7,0,0,244,31,0,0,232,127,0,0,208,255,1,0,160,255,7,0,64,255,31,0,128,254,127,16,16,16,8,8,16,8,8,8,4,4,8,4,4,4,2,2,4,2,2,2,1,1,2,1,1,8,8,8,4,4,8,4,4,4,2,2,4,2,2,2,1,1,2,1,1,1,1,1,1,1,1,0,0,0,0,1,1,2,253,253,3,4,4,0,1,0,4,4,1,0,1,3,0,0,1,0,4,0,0,1,182,2,255,250,0,0,2,255,251,0,0,2,255,252,0,0,2,255,253,0,0,0,0,64,25,37,0,40,244,36,0,12,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,173,39,0,112,0,0,0,104,249,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,213,37,0,0,0,0,0,32,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,232,174,37,0,0,0,0,0,32,0,0,0,69,90,73,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,139,37,0,0,0,0,0,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,8,74,37,0,0,0,0,0,40,0,0,0,84,77,70,80,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,24,25,37,0,0,244,36,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,176,204,36,0,0,244,36,0,12,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,96,175,36,0,0,244,36,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,147,36,0,0,244,36,0,48,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,160,119,36,0,160,92,36,0,44,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,128,66,36,0,160,92,36,0,44,0,0,0,6,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,40,77,40,0,0,0,0,0,8,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,192,40,36,0,0,0,0,0,16,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,24,239,35,0,0,0,0,0,52,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,220,39,0,112,0,0,0,248,249,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,5,10,7,255,0,1,5,0,3,17,9,16,1,1,1,1,1,1,0,1,1,1,1,1,1,0,9,1,0,1,5,3,8,1,1,1,1,1,1,0,1,1,1,1,1,1,0,0,0,0,0,0,0,2,3,2,2,5,4,5,0,4,1,3,2,6,5,6,0,6,4,1,2,5,3,6,0,5,3,3,1,4,3,5,0,6,5,3,2,4,1,6,0,6,5,3,1,4,2,6,0,1,0,0,0,0,192,0,0,0,192,2,0,0,48,0,0,0,48,2,0,0,240,0,0,0,240,2,0,1,0,1,0,0,192,3,0,0,48,3,0,0,240,3,0,0,0,0,0,254,255,127,185,255,255,187,57,254,255,127,57,3,0,88,185,6,128,56,187,255,63,12,60,0,160,49,188,0,0,0,0,5,96,237,60,0,192,138,189,1,244,192,61,1,160,171,189,4,192,221,60,254,175,114,61,254,161,12,190,253,203,44,62,254,161,12,190,254,175,114,61,4,192,221,60,1,160,171,189,1,244,192,61,0,192,138,189,5,96,237,60,0,0,0,0,0,160,49,188,255,63,12,60,6,128,56,187,3,0,88,185,254,255,127,57,255,255,187,57,254,255,127,185,0,0,0,0,136,244,35,0,64,255,34,0,12,0,0,0,5,0,0,0,32,56,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,192,150,33,0,64,255,34,0,12,0,0,0,5,0,0,0,32,56,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,26,33,0,48,177,32,0,8,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,96,85,32,0,48,177,32,0,8,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,104,61,40,0,152,226,39,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,88,121,39,0,152,226,39,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,39,39,0,168,224,38,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,232,154,38,0,168,224,38,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,56,95,38,0,72,41,38,0,36,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,112,247,37,0,72,41,38,0,36,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,192,204,37,0,144,167,37,0,32,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,130,37,0,144,167,37,0,32,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,180,37,0,112,0,0,0,224,253,28,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,43,52,2,5,1,1,13,1,2,1,1,3,4,0,128,64,0,0,64,32,0,0,32,16,0,0,16,8,0,0,8,4,0,0,4,2,0,0,2,1,0,0,192,0,0,0,129,0,0,0,88,0,0,0,64,0,0,0,56,0,0,0,48,0,0,0,40,0,0,0,36,0,0,0,32,0,0,0,32,240,118,255,0,0,0,0,0,1,2,2,6,3,14,4,30,5,31,5,0,0,0,0,0,1,0,0,2,2,6,3,14,4,15,4,0,0,0,0,0,1,2,2,0,0,6,3,14,4,15,4,0,0,0,0,0,1,0,0,0,0,2,2,6,3,14,4,15,4,0,0,1,2,4,3,5,3,0,2,6,3,7,3,0,0,0,0,1,2,0,0,2,2,0,2,6,3,7,3,0,0,0,0,1,2,2,2,0,0,0,2,6,3,7,3,0,0,0,0,1,2,0,0,0,0,0,2,2,2,6,3,7,3,0,0,112,112,112,112,80,80,0,0,80,80,80,80,80,80,64,64,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,5,7,0,0,0,0,0,0,5,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,5,7,5,7,0,0,0,0,5,7,5,0,0,0,0,0,5,7,6,0,0,0,0,0,5,5,0,0,0,0,0,0,3,0,0,0,0,0,0,0,6,6,0,0,0,0,0,0,2,4,0,0,0,0,0,0,2,4,5,7,0,0,0,0,2,4,5,0,0,0,0,0,2,4,6,0,0,0,0,0,2,4,5,7,5,7,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,2,3,0,0,2,0,4,5,0,6,0,0,0,0,0,1,0,0,2,3,0,5,0,0,4,0,0,0,0,0,0,4,1,5,8,12,9,13,2,6,3,7,10,14,11,15,0,0,1,1,0,0,1,1,2,2,3,3,2,2,3,3,0,0,1,1,0,0,1,1,2,2,3,3,2,2,3,3,0,0,1,1,0,0,1,1,2,2,3,3,2,2,3,3,0,0,1,1,0,0,1,1,2,2,3,3,2,2,3,3,0,4,64,68,8,12,72,76,128,132,192,196,136,140,200,204,0,4,64,68,8,12,72,76,128,132,192,196,136,140,200,204,0,0,4,0,128,0,132,0,8,0,12,0,136,0,140,0,0,1,4,1,128,1,132,1,8,1,12,1,136,1,140,1,0,0,4,0,128,0,132,0,8,0,12,0,136,0,140,0,0,1,4,1,128,1,132,1,8,1,12,1,136,1,140,1,0,0,4,0,128,0,132,0,8,0,12,0,136,0,140,0,0,1,4,1,128,1,132,1,8,1,12,1,136,1,140,1,0,1,4,5,2,3,6,7,8,9,12,13,10,11,14,15,0,1,0,1,2,3,2,3,0,1,0,1,2,3,2,3,0,1,0,1,2,3,2,3,0,1,0,1,2,3,2,3,0,1,0,1,2,3,2,3,0,1,0,1,2,3,2,3,0,1,0,1,2,3,2,3,0,1,0,1,2,3,2,3,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,96,252,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,9,0,0,44,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,226,38,0,40,156,38,0,224,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,64,16,0,1,0,144,96,38,0,112,42,38,0,144,248,37,0,0,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,64,16,0,1,0,144,96,38,0,240,205,37,0,184,168,37,0,32,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,64,16,0,1,0,144,96,38,0,56,131,37,0,208,64,37,0,64,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,64,16,0,1,0,144,96,38,0,32,19,37,0,56,234,36,0,208,1,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,55,64,16,0,1,0,144,96,38,0,8,199,36,0,120,26,156,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,16,142,36,0,120,26,156,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,216,113,36,0,120,26,156,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,24,87,36,0,120,26,156,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,192,61,36,0,120,26,156,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,240,34,36,0,120,26,156,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,248,232,35,0,120,26,156,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,56,200,35,0,120,26,156,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,88,176,35,0,120,26,156,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,152,154,35,0,120,26,156,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,88,133,35,0,120,26,156,0,0,0,0,0,128,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,200,110,35,0,120,26,156,0,0,0,0,0,128,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,200,90,35,0,120,26,156,0,0,0,0,0,128,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,40,73,35,0,120,26,156,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,64,55,35,0,120,26,156,0,0,0,0,0,128,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,88,34,35,0,120,26,156,0,0,0,0,0,128,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,88,246,34,0,120,26,156,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,56,220,34,0,120,26,156,0,0,0,0,0,128,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,136,205,34,0,120,26,156,0,0,0,0,0,128,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,240,188,34,0,120,26,156,0,0,0,0,0,128,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,216,171,34,0,120,26,156,0,0,0,0,0,128,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,56,153,34,0,120,26,156,0,0,0,0,0,128,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,112,139,34,0,120,26,156,0,0,0,0,0,128,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,248,123,34,0,120,26,156,0,0,0,0,0,128,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,144,96,38,0,8,107,34,0,48,89,34,0,244,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,80,48,34,0,160,26,34,0,20,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,208,12,34,0,216,253,33,0,52,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,96,235,33,0,56,221,33,0,84,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,136,209,33,0,64,199,33,0,204,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,16,0,1,0,0,0,0,0,56,190,33,0,16,178,33,0,232,1,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,144,33,0,120,127,33,0,8,2,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,232,117,33,0,224,107,33,0,40,2,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,16,98,33,0,0,88,33,0,72,2,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,24,79,33,0,24,71,33,0,216,1,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,8,62,33,0,32,51,33,0,180,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,144,20,33,0,168,4,33,0,184,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,230,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,218,37,0,112,0,0,0,192,4,29,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,89,37,0,192,251,35,0,4,0,0,0,1,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,64,16,0,1,0,0,0,0,0,80,4,35,0,32,61,34,0,8,0,0,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,208,154,33,0,32,61,34,0,8,0,0,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,226,37,0,112,0,0,0,136,13,29,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,229,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,90,37,0,72,254,35,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,120,5,35,0,72,254,35,0,8,0,0,0,3,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,16,0,1,0,0,0,0,0,112,62,34,0,248,155,33,0,56,0,0,0,3,0,0,0,92,143,194,245,40,92,239,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,248,31,33,0,248,155,33,0,56,0,0,0,3,0,0,0,92,143,194,245,40,92,239,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,248,180,32,0,216,88,32,0,64,0,0,0,3,0,0,0,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,152,64,40,0,216,88,32,0,64,0,0,0,3,0,0,0,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,229,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,2,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,232,37,0,112,0,0,0,240,14,29,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,255,0,0,0,0,0,0,0,255,0,0,0,0,25,128,128,255,0,0,0,0,20,128,128,255,0,0,0,0,16,128,128,255,0,0,0,0,19,128,128,255,0,0,0,0,16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,0,0,0,0,1,2,3,6,7,8,11,12,13,0,0,0,0,0,0,0,1,3,6,8,9,10,10,11,11,12,12,13,13,3,4,6,7,8,8,9,10,10,10,11,12,12,6,6,7,8,8,9,10,10,10,11,12,12,12,8,7,8,9,9,10,10,11,11,11,12,12,13,9,8,9,9,10,10,11,11,11,12,12,12,13,10,9,9,10,11,11,11,12,11,12,12,13,13,11,9,10,11,11,11,12,12,12,12,13,13,13,11,10,10,11,11,12,12,13,13,13,13,13,13,11,10,10,11,11,11,12,12,13,13,14,13,14,11,10,11,11,12,12,12,12,13,13,14,14,14,12,11,11,12,12,12,13,13,13,14,14,14,15,12,11,12,12,12,13,13,13,13,14,14,15,15,13,12,12,12,13,13,13,13,14,14,14,14,15,0,0,0,0,0,0,0,5,4,5,6,7,8,9,10,4,3,4,5,6,7,7,8,5,4,4,5,6,7,7,8,6,5,5,6,6,7,8,8,7,6,6,6,7,7,8,9,8,7,6,7,7,8,8,10,9,7,7,8,8,8,9,9,10,8,8,8,9,9,9,10,1,3,6,7,8,9,10,11,3,4,6,7,8,8,9,9,6,6,7,8,8,9,9,10,7,7,8,8,9,9,10,10,8,8,9,9,10,10,10,11,9,8,9,9,10,10,11,11,10,9,9,10,10,11,12,12,11,10,10,10,11,11,12,12,11,10,9,9,9,9,9,10,11,10,9,8,7,7,7,8,9,10,9,8,6,6,6,6,6,8,9,9,7,6,4,4,4,6,7,9,9,7,6,4,4,4,6,7,9,9,7,6,4,4,4,6,7,9,9,8,6,6,6,6,6,8,9,10,9,8,7,7,7,7,8,10,11,10,9,9,9,9,9,10,11,0,0,0,0,0,0,0,13,12,11,11,10,11,11,12,13,12,11,10,9,8,9,10,11,12,12,10,9,8,7,8,9,10,11,11,9,8,5,4,5,8,9,11,10,8,7,4,1,4,7,8,11,11,9,8,5,4,5,8,9,11,11,10,9,8,7,8,9,10,11,12,11,10,9,8,9,10,11,12,13,12,12,11,10,10,11,12,13,0,0,0,0,0,0,0,4,5,8,5,4,8,9,8,11,5,5,8,5,4,8,8,7,10,9,8,11,8,8,10,11,10,11,4,5,8,4,4,8,8,8,10,4,4,8,4,4,7,8,7,9,8,8,10,7,7,9,10,9,10,8,8,11,8,7,10,11,10,12,8,7,10,7,7,9,10,9,11,11,10,12,10,9,11,11,10,11,0,0,0,0,0,0,0,1,4,8,4,5,8,9,9,10,4,6,9,6,6,9,9,9,10,9,10,13,9,9,11,11,10,12,4,6,10,6,7,10,10,10,12,5,7,11,6,7,10,9,9,11,9,10,13,8,9,12,10,11,12,8,10,15,9,11,15,13,14,16,8,10,14,9,10,14,12,12,15,11,12,16,10,11,15,12,12,15,0,0,0,0,0,0,0,9,7,9,8,6,8,9,8,9,8,6,7,6,5,6,7,6,8,9,7,8,8,6,8,9,7,9,8,6,7,6,5,6,7,6,8,6,5,6,5,3,5,6,5,6,8,6,7,6,5,6,8,6,8,9,7,9,8,6,8,8,7,9,8,6,7,6,4,6,8,6,7,9,7,9,7,6,8,9,7,9,0,0,0,0,0,0,0,4,5,6,7,8,8,9,10,10,10,11,11,12,11,12,12,10,5,4,5,6,7,7,8,8,9,9,9,10,10,10,10,11,8,6,5,5,6,7,7,8,8,8,9,9,9,10,10,10,10,8,7,6,6,6,7,7,8,8,8,9,9,9,10,10,10,10,8,8,7,7,7,7,8,8,8,8,9,9,9,10,10,10,10,8,8,7,7,7,7,8,8,8,9,9,9,9,10,10,10,10,8,9,8,8,8,8,8,8,8,9,9,9,10,10,10,10,10,8,9,8,8,8,8,8,8,9,9,9,10,10,10,10,10,10,8,10,9,8,8,9,9,9,9,9,10,10,10,10,10,10,11,8,10,9,9,9,9,9,9,9,10,10,10,10,10,10,11,11,8,11,9,9,9,9,9,9,10,10,10,10,10,11,10,11,11,8,11,10,9,9,10,9,10,10,10,10,10,11,11,11,11,11,8,11,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,9,11,10,9,9,10,10,10,10,10,10,11,11,11,11,11,11,9,11,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,9,12,10,10,10,10,10,10,10,11,11,11,11,11,11,12,12,9,9,8,8,8,8,8,8,8,8,8,8,8,8,8,8,9,5,0,0,0,0,0,0,0,6,5,6,6,7,8,9,10,10,10,11,11,12,5,4,4,5,6,7,7,8,8,9,10,10,11,6,4,5,5,6,6,7,8,8,9,9,10,10,6,5,5,5,6,7,7,8,8,9,9,10,10,7,6,6,6,6,7,7,8,8,9,9,10,10,8,7,6,7,7,7,8,8,8,9,10,10,11,9,7,7,7,7,8,8,9,9,9,10,10,11,9,8,8,8,8,8,9,9,9,10,10,11,11,9,8,8,8,8,8,9,9,10,10,10,11,11,10,9,9,9,9,9,9,10,10,10,11,11,12,10,9,9,9,9,10,10,10,10,11,11,11,12,11,10,9,10,10,10,10,10,11,11,11,11,12,11,10,10,10,10,10,10,11,11,12,12,12,12,0,0,0,0,0,0,0,11,9,11,10,7,10,11,9,11,10,7,10,7,5,7,9,7,10,11,9,11,9,7,9,11,9,11,9,7,9,7,5,7,9,7,9,7,5,7,5,1,5,7,5,7,9,7,9,7,5,7,9,7,9,11,9,11], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1895985);
/* memory initializer */ allocate([9,7,9,11,9,11,10,7,9,7,5,7,9,7,10,11,9,11,10,7,9,11,9,11,0,0,0,0,0,0,0,232,3,0,0,52,8,0,0,172,13,0,0,24,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,8,0,0,0,24,0,0,0,4,0,0,0,20,0,0,0,12,0,0,0,28,0,0,0,2,0,0,0,18,0,0,0,10,0,0,0,26,0,0,0,6,0,0,0,22,0,0,0,14,0,0,0,30,0,0,0,1,0,0,0,17,0,0,0,9,0,0,0,25,0,0,0,5,0,0,0,21,0,0,0,13,0,0,0,29,0,0,0,3,0,0,0,19,0,0,0,11,0,0,0,27,0,0,0,7,0,0,0,23,0,0,0,15,0,0,0,31,0,0,0,0,0,0,0,16,0,0,0,8,0,0,0,24,0,0,0,4,0,0,0,20,0,0,0,12,0,0,0,28,0,0,0,2,0,0,0,18,0,0,0,10,0,0,0,26,0,0,0,6,0,0,0,22,0,0,0,14,0,0,0,30,0,0,0,1,0,0,0,17,0,0,0,9,0,0,0,25,0,0,0,5,0,0,0,21,0,0,0,13,0,0,0,29,0,0,0,3,0,0,0,19,0,0,0,11,0,0,0,27,0,0,0,7,0,0,0,23,0,0,0,15,0,0,0,31,0,0,0,3,5,7,9,13,17,25,33,65,129,0,0,0,0,0,0,255,254,253,252,250,248,244,240,224,192,0,0,0,0,0,0,2,0,0,0,0,0,0,4,3,3,0,0,0,0,5,5,4,0,0,0,0,6,5,6,0,0,0,0,7,6,5,0,0,0,0,9,8,7,9,8,8,8,9,9,8,9,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,0,0,16,33,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,32,29,0,216,32,29,0,200,32,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,26,29,0,224,26,29,0,208,26,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,26,29,0,112,26,29,0,88,26,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,40,29,0,120,40,29,0,88,40,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,39,29,0,96,39,29,0,56,39,29,0,16,39,29,0,232,38,29,0,192,38,29,0,152,38,29,0,0,0,0,0,128,37,29,0,72,37,29,0,16,37,29,0,216,36,29,0,160,36,29,0,104,36,29,0,48,36,29,0,0,0,0,0,208,34,29,0,136,34,29,0,64,34,29,0,248,33,29,0,176,33,29,0,104,33,29,0,32,33,29,0,0,0,0,0,72,30,29,0,192,29,29,0,56,29,29,0,176,28,29,0,40,28,29,0,160,27,29,0,24,27,29,0,0,0,0,0,216,47,29,0,208,46,29,0,200,45,29,0,192,44,29,0,184,43,29,0,176,42,29,0,168,41,29,0,0,0,0,0,24,33,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,33,29,0,0,33,29,0,248,32,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,27,29,0,8,27,29,0,0,27,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,26,29,0,176,26,29,0,160,26,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,40,29,0,200,40,29,0,184,40,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,40,29,0,40,40,29,0,16,40,29,0,248,39,29,0,224,39,29,0,200,39,29,0,176,39,29,0,0,0,0,0,120,38,29,0,88,38,29,0,56,38,29,0,24,38,29,0,248,37,29,0,216,37,29,0,184,37,29,0,0,0,0,0,8,36,29,0,224,35,29,0,184,35,29,0,144,35,29,0,104,35,29,0,64,35,29,0,24,35,29,0,0,0,0,0,128,32,29,0,56,32,29,0,240,31,29,0,168,31,29,0,96,31,29,0,24,31,29,0,208,30,29,0,0,0,0,0,16,52,29,0,136,51,29,0,0,51,29,0,120,50,29,0,240,49,29,0,104,49,29,0,224,48,29,0,0,0,0,0,28,0,15,0,2,0,7,0,2,0,0,0,6,0,6,0,29,0,0,0,0,0,0,0,24,0,26,0,2,0,7,0,2,0,0,0,3,0,27,0,25,0,0,0,0,0,0,0,48,0,25,0,9,0,5,0,0,0,7,0,13,0,8,0,49,0,0,0,0,0,0,0,6,5,3,3,2,2,3,4,6,0,0,0,0,0,0,0,5,5,3,3,2,2,3,5,5,0,0,0,0,0,0,0,6,5,4,3,1,3,4,4,6,0,0,0,0,0,0,0,0,0,2,0,1,0,3,0,2,0,3,0,1,0,0,0,20,0,11,0,0,0,3,0,1,0,4,0,21,0,0,0,30,0,14,0,5,0,0,0,6,0,4,0,31,0,0,0,4,4,2,2,2,4,4,0,5,4,2,2,2,3,5,0,5,4,3,1,3,3,5,0,12,1,138,3,8,6,134,7,132,0,135,0,2,3,5,3,64,0,224,0,227,0,131,1,30,0,94,0,158,0,222,0,241,0,17,0,57,0,97,0,121,0,9,0,29,0,49,0,61,0,5,0,15,0,25,0,31,0,3,0,6,0,10,0,14,0,11,0,8,0,4,0,0,0,26,0,18,0,10,0,2,0,54,0,38,0,22,0,6,0,110,0,78,0,46,0,14,0,223,0,159,0,95,0,31,0,224,1,128,1,225,0,65,0,194,3,3,3,196,1,133,0,135,7,9,6,139,3,13,1,0,0,0,0,0,0,224,15,226,15,232,15,234,15,236,15,238,15,240,15,242,15,244,15,242,47,242,7,251,7,246,3,250,11,253,11,255,1,255,5,252,2,124,0,124,1,60,0,188,0,28,0,92,0,12,0,44,0,4,0,20,0,0,0,8,0,14,0,2,0,6,0,3,0,15,0,9,0,1,0,21,0,5,0,45,0,13,0,93,0,29,0,189,0,61,0,125,1,125,0,253,2,252,0,252,5,250,1,251,11,247,3,248,23,243,7,243,47,245,15,243,15,241,15,239,15,237,15,235,15,233,15,227,15,225,15,0,0,0,0,0,0,44,3,50,3,120,3,126,3,140,0,74,1,136,1,151,1,158,1,189,1,68,0,71,0,170,0,197,0,205,0,220,0,28,0,44,0,83,0,99,0,104,0,8,0,15,0,23,0,43,0,53,0,5,0,9,0,22,0,28,0,6,0,15,0,4,0,0,0,7,0,29,0,23,0,10,0,6,0,54,0,48,0,40,0,16,0,9,0,105,0,100,0,84,0,45,0,29,0,221,0,206,0,202,0,171,0,164,0,69,0,190,1,159,1,152,1,137,1,75,1,141,0,127,3,121,3,51,3,45,3,0,0,0,0,0,0,176,112,178,112,180,112,82,40,91,56,46,20,46,28,21,10,20,14,20,2,4,7,4,1,11,1,131,3,131,0,67,1,195,1,67,0,162,0,226,0,34,0,82,0,114,0,18,0,42,0,58,0,10,0,22,0,30,0,6,0,12,0,0,0,4,0,1,0,13,0,7,0,31,0,23,0,11,0,59,0,43,0,19,0,115,0,83,0,35,0,227,0,163,0,160,0,64,0,192,1,132,0,132,3,132,2,5,1,5,7,21,2,21,14,22,10,47,28,47,20,40,20,83,40,181,112,179,112,177,112,0,0,0,0,0,0,92,4,47,2,245,3,188,1,251,1,89,0,208,0,223,0,10,0,45,0,47,0,82,0,105,0,120,0,127,0,10,0,16,0,28,0,35,0,42,0,53,0,58,0,61,0,0,0,3,0,6,0,9,0,12,0,15,0,18,0,22,0,24,0,28,0,25,0,23,0,19,0,16,0,13,0,10,0,7,0,4,0,1,0,62,0,59,0,54,0,43,0,40,0,29,0,17,0,11,0,4,0,121,0,110,0,83,0,68,0,46,0,11,0,252,0,209,0,138,0,88,0,189,1,22,1,244,3,93,4,0,0,0,0,0,0,140,10,71,5,181,1,8,0,219,0,82,1,5,0,11,0,142,0,174,0,228,0,3,0,55,0,57,0,85,0,108,0,115,0,3,0,21,0,29,0,40,0,48,0,55,0,62,0,6,0,11,0,15,0,18,0,22,0,25,0,29,0,1,0,4,0,2,0,30,0,26,0,23,0,19,0,16,0,12,0,7,0,63,0,56,0,49,0,41,0,34,0,26,0,20,0,0,0,109,0,86,0,70,0,56,0,4,0,229,0,175,0,143,0,108,0,10,0,83,1,80,1,9,0,162,2,180,1,141,10,0,0,0,0,0,0,92,158,94,158,44,79,148,39,196,19,68,30,227,9,35,15,243,4,146,7,126,2,206,3,61,1,229,1,156,0,204,0,64,0,88,0,103,0,30,0,33,0,45,0,61,0,7,0,17,0,20,0,23,0,26,0,28,0,31,0,1,0,4,0,6,0,5,0,2,0,0,0,29,0,27,0,24,0,21,0,18,0,14,0,6,0,50,0,38,0,31,0,120,0,89,0,65,0,205,0,157,0,230,1,62,1,207,3,127,2,147,7,144,7,240,4,228,9,69,30,197,19,149,39,45,79,95,158,93,158,0,0,0,0,0,0,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,0,0,0,0,0,0,0,14,14,14,14,14,14,14,14,14,14,13,13,12,12,12,11,11,10,9,9,8,8,7,7,6,6,5,5,4,4,4,3,3,3,4,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14,14,14,14,14,14,14,14,0,0,0,0,0,0,0,10,10,10,10,9,9,9,9,9,9,8,8,8,8,8,8,7,7,7,7,7,6,6,6,6,6,5,5,5,5,4,4,3,3,4,5,5,5,5,6,6,6,6,6,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,0,0,0,0,0,0,0,15,15,15,14,14,13,13,12,12,11,11,10,10,10,9,9,9,8,8,8,7,7,7,6,6,6,5,5,5,4,4,3,3,3,4,4,5,5,5,6,6,6,7,7,7,8,8,8,8,9,9,10,10,10,11,11,12,12,13,13,13,14,15,15,15,0,0,0,0,0,0,0,11,10,10,9,9,8,8,8,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,8,8,8,8,9,9,10,11,0,0,0,0,0,0,0,12,11,10,9,9,9,8,8,8,8,8,7,7,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,4,4,4,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,7,7,7,7,7,8,8,8,8,8,9,9,9,10,10,12,0,0,0,0,0,0,0,16,16,15,14,13,13,12,12,11,11,10,10,9,9,8,8,7,7,7,6,6,6,6,5,5,5,5,5,5,5,4,4,4,4,4,4,5,5,5,5,5,5,5,6,6,6,7,7,7,8,8,9,9,10,10,11,11,11,12,13,13,14,15,16,16,0,0,0,0,0,0,0,7,0,5,0,0,0,4,0,6,0,0,0,0,0,0,0,7,0,1,0,2,0,0,0,6,0,0,0,0,0,0,0,15,0,6,0,0,0,2,0,14,0,0,0,0,0,0,0,3,3,1,3,3,0,0,0,3,2,2,2,3,0,0,0,4,3,1,2,4,0,0,0,3,0,0,0,2,0,0,0,2,1,2,0,0,0,0,0,132,2,66,0,64,1,67,1,62,0,190,0,17,0,81,0,9,0,41,0,5,0,21,0,0,0,8,0,14,0,2,0,6,0,3,0,15,0,9,0,1,0,22,0,6,0,46,0,14,0,94,0,30,0,191,0,63,0,32,0,65,1,67,0,133,2,0,0,0,0,0,0,36,7,147,3,206,1,229,0,44,0,8,0,23,0,62,0,5,0,20,0,29,0,0,0,3,0,6,0,8,0,11,0,13,0,12,0,9,0,7,0,4,0,1,0,30,0,21,0,10,0,63,0,56,0,9,0,45,0,230,0,207,1,200,1,37,7,0,0,0,0,0,0,200,1,230,1,100,0,226,0,229,0,48,0,51,0,115,0,122,0,26,0,58,0,2,0,26,0,31,0,7,0,1,0,2,0,2,0,12,0,0,0,27,0,3,0,59,0,27,0,123,0,120,0,112,0,49,0,242,0,227,0,101,0,231,1,201,1,0,0,0,0,0,0,248,58,250,58,126,29,188,14,92,7,172,3,212,1,148,0,20,0,75,0,11,0,59,0,19,0,3,0,15,0,5,0,1,0,6,0,0,0,8,0,28,0,4,0,36,0,116,0,21,0,149,0,213,1,173,3,93,7,189,14,127,29,251,58,249,58,0,0,0,0,0,0,204,0,103,0,5,0,112,0,3,0,26,0,57,0,63,0,10,0,18,0,24,0,29,0,1,0,3,0,7,0,10,0,13,0,11,0,8,0,4,0,2,0,30,0,25,0,19,0,11,0,0,0,62,0,27,0,24,0,113,0,50,0,4,0,205,0,0,0,0,0,0,0,12,3,135,1,109,0,40,0,55,0,102,0,21,0,49,0,0,0,11,0,18,0,26,0,1,0,7,0,10,0,14,0,1,0,15,0,11,0,8,0,4,0,27,0,19,0,12,0,1,0,50,0,26,0,103,0,96,0,41,0,194,0,108,0,13,3,0,0,0,0,0,0,128,21,130,21,194,10,98,5,178,2,94,1,173,0,84,0,28,0,60,0,15,0,31,0,8,0,11,0,13,0,0,0,2,0,1,0,14,0,12,0,9,0,6,0,20,0,61,0,29,0,85,0,174,0,95,1,179,2,99,5,195,10,131,21,129,21,0,0,0,0,0,0,10,9,9,9,8,8,7,7,6,6,5,5,4,4,4,3,3,3,4,4,4,5,5,6,6,7,7,8,8,8,9,9,10,0,0,0,0,0,0,0,11,10,9,8,7,6,6,6,5,5,5,4,4,4,4,4,4,4,4,4,4,4,5,5,5,6,6,6,7,8,9,9,11,0,0,0,0,0,0,0,9,9,8,8,8,7,7,7,7,6,6,5,5,5,4,3,2,3,4,4,5,5,6,6,7,7,7,7,8,8,8,9,9,0,0,0,0,0,0,0,14,14,13,12,11,10,9,8,7,7,6,6,5,4,4,3,2,3,3,4,5,5,6,7,7,8,9,10,11,12,13,14,14,0,0,0,0,0,0,0,9,8,7,7,6,6,6,6,5,5,5,5,4,4,4,4,4,4,4,4,4,5,5,5,5,5,6,6,6,7,7,7,9,0,0,0,0,0,0,0,10,9,8,7,7,7,6,6,5,5,5,5,4,4,4,4,3,4,4,4,4,5,5,5,5,6,6,7,7,7,8,8,10,0,0,0,0,0,0,0,13,13,12,11,10,9,8,7,6,6,5,5,4,4,4,3,3,3,4,4,4,4,5,6,6,7,8,9,10,11,12,13,13,0,0,0,0,0,0,0,168,3,174,3,213,1,148,0,20,0,75,0,11,0,59,0,19,0,3,0,15,0,5,0,1,0,6,0,0,0,8,0,28,0,4,0,36,0,116,0,21,0,149,0,214,1,175,3,169,3,0,0,0,0,0,0,36,3,147,1,206,0,101,0,36,0,12,0,19,0,4,0,7,0,10,0,13,0,15,0,1,0,0,0,14,0,11,0,8,0,5,0,24,0,13,0,37,0,102,0,207,0,200,0,37,3,0,0,0,0,0,0,60,0,146,0,24,0,31,0,78,0,13,0,37,0,4,0,16,0,0,0,10,0,2,0,3,0,3,0,11,0,1,0,17,0,5,0,38,0,14,0,79,0,72,0,25,0,147,0,61,0,0,0,0,0,0,0,128,7,130,7,194,3,226,1,254,0,121,0,61,0,28,0,12,0,4,0,0,0,6,0,2,0,7,0,1,0,5,0,13,0,29,0,62,0,126,0,255,0,227,1,195,3,131,7,129,7,0,0,0,0,0,0,76,0,39,0,109,0,40,0,55,0,14,0,21,0,0,0,5,0,8,0,11,0,14,0,1,0,15,0,12,0,9,0,6,0,1,0,26,0,15,0,8,0,41,0,18,0,108,0,77,0,0,0,0,0,0,0,28,0,15,0,5,0,0,0,48,0,54,0,14,0,25,0,1,0,8,0,14,0,1,0,5,0,2,0,15,0,9,0,6,0,26,0,15,0,55,0,49,0,1,0,6,0,4,0,29,0,0,0,0,0,0,0,84,40,43,20,11,5,67,1,162,0,82,0,46,0,21,0,4,0,14,0,0,0,3,0,6,0,4,0,1,0,15,0,5,0,22,0,47,0,83,0,163,0,160,0,132,2,20,10,85,40,0,0,0,0,0,0,10,10,9,8,7,7,6,6,5,4,4,3,2,3,3,4,5,5,6,7,7,8,9,10,10,0,0,0,0,0,0,0,10,9,8,7,6,5,5,4,4,4,4,4,3,3,4,4,4,4,5,5,6,7,8,8,10,0,0,0,0,0,0,0,8,8,7,7,7,6,6,5,5,4,4,3,2,3,4,4,5,5,6,6,7,7,7,8,8,0,0,0,0,0,0,0,12,12,11,10,9,8,7,6,5,4,3,3,2,3,3,4,5,6,7,8,9,10,11,12,12,0,0,0,0,0,0,0,8,7,7,6,6,5,5,4,4,4,4,4,3,4,4,4,4,4,5,5,5,6,6,7,8,0,0,0,0,0,0,0,9,8,7,6,6,6,5,5,4,4,4,3,3,3,4,4,4,5,5,6,6,6,7,7,9,0,0,0,0,0,0,0,14,13,11,9,8,7,6,5,4,4,3,3,3,3,3,4,4,5,6,7,8,8,10,12,14,0,0,0,0,0,0,0,96,0,126,0,49,0,25,0,13,0,4,0,0,0,6,0,2,0,7,0,1,0,5,0,14,0,30,0,62,0,127,0,97,0,0,0,0,0,0,0,4,0,3,0,30,0,1,0,1,0,14,0,1,0,4,0,6,0,5,0,2,0,15,0,6,0,14,0,31,0,0,0,5,0,0,0,0,0,0,0,232,0,246,0,117,0,52,0,59,0,27,0,31,0,4,0,0,0,5,0,12,0,28,0,60,0,53,0,122,0,247,0,233,0,0,0,0,0,0,0,0,1,2,1,130,0,66,0,34,0,18,0,10,0,6,0,0,0,7,0,11,0,19,0,35,0,67,0,131,0,3,1,1,1,0,0,0,0,0,0,44,0,23,0,5,0,28,0,3,0,10,0,15,0,3,0,6,0,4,0,0,0,11,0,4,0,29,0,10,0,4,0,45,0,0,0,0,0,0,0,124,0,63,0,25,0,13,0,28,0,8,0,15,0,5,0,0,0,6,0,2,0,9,0,29,0,14,0,30,0,24,0,125,0,0,0,0,0,0,0,84,1,171,0,43,0,11,0,3,0,10,0,1,0,6,0,1,0,7,0,4,0,11,0,0,0,4,0,20,0,84,0,85,1,0,0,0,0,0,0,8,8,7,6,5,4,3,3,2,3,3,4,5,6,7,8,8,0,0,0,0,0,0,0,8,7,6,5,4,4,3,3,3,3,3,4,4,5,6,6,8,0,0,0,0,0,0,0,8,8,7,6,6,5,5,3,1,3,4,5,6,6,7,8,8,0,0,0,0,0,0,0,9,9,8,7,6,5,4,3,1,3,4,5,6,7,8,9,9,0,0,0,0,0,0,0,7,6,5,5,4,4,4,3,3,3,3,4,4,5,5,5,7,0,0,0,0,0,0,0,8,7,6,5,5,4,4,3,2,3,3,4,5,5,6,6,8,0,0,0,0,0,0,0,12,11,9,7,5,4,3,3,2,3,3,4,4,6,8,10,12,0,0,0,0,0,0,0,4,0,26,0,3,0,14,0,0,0,3,0,5,0,4,0,2,0,15,0,12,0,27,0,5,0,0,0,0,0,0,0,56,0,16,0,29,0,7,0,15,0,5,0,0,0,6,0,2,0,9,0,6,0,17,0,57,0,0,0,0,0,0,0,112,0,46,0,57,0,29,0,12,0,15,0,0,0,4,0,13,0,10,0,22,0,47,0,113,0,0,0,0,0,0,0,5,5,4,4,3,3,3,3,3,4,4,5,5,0,0,0,6,5,5,4,4,3,2,3,3,4,4,5,6,0,0,0,7,6,6,5,4,4,1,3,4,4,5,6,7,0,0,0,9,7,7,9,9,0,0,0,0,0,2,0,6,0,14,0,30,0,62,0,255,0,254,0,251,1,250,1,249,1,248,1,1,0,0,0,2,0,15,0,12,0,29,0,57,0,56,0,55,0,54,0,53,0,52,0,0,0,7,0,5,0,4,0,2,0,13,0,12,0,6,0,15,0,29,0,57,0,56,0,3,0,2,0,0,0,2,0,6,0,14,0,30,0,62,0,126,0,254,0,255,1,254,1,1,0,0,0,2,0,6,0,14,0,63,0,61,0,124,0,121,0,120,0,251,0,250,0,1,2,3,4,5,6,8,8,9,9,9,9,1,2,3,5,5,6,7,7,7,7,7,7,2,3,3,3,3,4,4,4,5,6,7,7,2,2,2,3,4,5,6,7,8,9,10,10,1,2,3,4,5,7,7,8,8,8,9,9,0,0,0,0,32,30,94,30,28,3,26,5,24,7,22,9,20,11,18,13,17,15,144,0,143,1,142,2,141,3,140,4,139,5,138,6,137,7,73,0,200,0,72,1,199,1,71,2,198,2,70,3,197,3,37,0,101,0,165,0,228,0,36,1,100,1,164,1,227,1,19,0,51,0,83,0,115,0,147,0,179,0,211,0,243,0,10,0,26,0,42,0,58,0,74,0,90,0,106,0,122,0,6,0,14,0,22,0,30,0,38,0,46,0,54,0,62,0,4,0,8,0,12,0,16,0,20,0,24,0,28,0,0,0,29,0,25,0,21,0,17,0,13,0,9,0,5,0,63,0,55,0,47,0,39,0,31,0,23,0,15,0,7,0,123,0,107,0,91,0,75,0,59,0,43,0,27,0,11,0,8,0,240,0,208,0,176,0,144,0,112,0,80,0,48,0,228,1,165,1,101,1,37,1,229,0,226,0,162,0,98,0,202,3,71,3,199,2,196,2,68,2,73,1,201,0,198,0,150,7,139,6,136,6,141,4,138,4,143,2,140,2,145,0,46,15,19,13,21,11,23,9,25,7,27,5,29,3,95,30,33,30,0,0,0,0,0,0,44,118,23,59,85,21,8,6,171,10,242,15,5,3,7,3,99,7,70,0,12,1,188,1,171,2,182,3,253,3,128,0,135,0,223,0,86,1,217,1,248,1,255,1,42,0,65,0,97,0,148,0,212,0,234,0,242,0,253,0,9,0,11,0,26,0,38,0,49,0,64,0,75,0,107,0,115,0,119,0,122,0,124,0,0,0,2,0,6,0,8,0,11,0,14,0,17,0,20,0,22,0,25,0,28,0,30,0,33,0,35,0,38,0,40,0,43,0,45,0,47,0,49,0,51,0,54,0,56,0,55,0,52,0,50,0,48,0,46,0,44,0,41,0,39,0,36,0,34,0,31,0,29,0,26,0,23,0,21,0,18,0,15,0,12,0,9,0,7,0,3,0,1,0,125,0,123,0,120,0,116,0,114,0,84,0,65,0,54,0,39,0,27,0,20,0,10,0,254,0,243,0,235,0,213,0,149,0,110,0,66,0,43,0,16,0,249,1,218,1,87,1,84,1,192,0,129,0,34,0,183,3,176,3,189,1,13,1,71,0,248,7,84,5,6,3,243,15,196,14,9,6,138,29,84,21,45,118,0,0,0,0,0,0,60,161,32,199,63,161,62,161,61,161,34,231,144,80,147,99,146,115,73,40,206,49,206,57,37,20,229,24,229,28,68,8,28,10,124,12,108,3,35,4,15,5,63,6,183,1,22,2,133,2,29,3,157,3,9,1,64,1,128,1,200,1,207,1,122,0,138,0,162,0,193,0,229,0,20,0,55,0,67,0,78,0,86,0,97,0,108,0,124,0,11,0,28,0,31,0,35,0,37,0,41,0,44,0,46,0,50,0,52,0,55,0,58,0,60,0,63,0,1,0,3,0,6,0,8,0,10,0,12,0,11,0,9,0,7,0,4,0,2,0,0,0,61,0,59,0,56,0,53,0,51,0,47,0,45,0,42,0,38,0,36,0,32,0,29,0,26,0,125,0,109,0,98,0,87,0,79,0,68,0,60,0,21,0,230,0,198,0,163,0,139,0,123,0,108,0,201,1,129,1,65,1,10,1,218,0,30,3,134,2,23,2,16,2,56,7,56,6,8,5,109,3,125,12,29,10,69,8,230,28,230,24,38,20,207,57,207,49,78,40,147,115,144,115,145,80,35,231,36,199,37,199,34,199,35,199,33,199,0,0,0,0,0,0,152,165,154,165,156,165,158,165,152,197,134,229,204,58,202,82,205,98,72,13,103,29,120,41,103,49,102,57,165,6,188,14,189,20,177,28,80,3,83,3,95,7,95,10,94,12,94,14,174,1,173,3,45,5,45,6,45,7,213,0,212,1,148,2,20,3,148,3,20,0,148,0,20,1,116,1,180,1,244,1,11,0,75,0,139,0,187,0,219,0,251,0,27,0,59,0,83,0,99,0,115,0,3,0,19,0,35,0,47,0,55,0,63,0,7,0,15,0,21,0,25,0,29,0,1,0,5,0,9,0,6,0,2,0,30,0,26,0,22,0,16,0,8,0,0,0,56,0,48,0,40,0,28,0,12,0,124,0,108,0,92,0,68,0,36,0,4,0,228,0,196,0,164,0,116,0,52,0,245,1,181,1,117,1,21,1,149,0,21,0,149,3,21,3,149,2,213,1,214,0,46,7,46,6,46,5,174,3,175,1,95,14,95,12,88,12,88,10,88,7,81,3,178,28,178,24,189,14,178,14,103,57,96,57,121,41,100,41,73,13,194,114,203,82,205,58,135,229,153,197,159,165,157,165,155,165,153,165,0,0,0,0,0,0,92,14,47,7,29,0,36,7,15,0,13,1,36,3,147,3,233,3,128,0,135,0,250,0,100,1,147,1,222,1,245,1,16,0,42,0,65,0,100,0,115,0,142,0,164,0,179,0,214,0,229,0,244,0,251,0,2,0,9,0,19,0,30,0,38,0,44,0,51,0,63,0,65,0,76,0,83,0,94,0,101,0,112,0,115,0,120,0,123,0,126,0,2,0,5,0,7,0,11,0,13,0,17,0,20,0,23,0,26,0,29,0,33,0,36,0,39,0,42,0,45,0,48,0,51,0,54,0,58,0,55,0,52,0,49,0,46,0,43,0,40,0,37,0,34,0,30,0,27,0,24,0,21,0,18,0,14,0,12,0,8,0,6,0,3,0,127,0,124,0,121,0,118,0,113,0,106,0,95,0,88,0,77,0,70,0,64,0,56,0,45,0,39,0,31,0,20,0,18,0,3,0,0,0,245,0,238,0,215,0,200,0,165,0,143,0,124,0,101,0,66,0,43,0,17,0,2,0,223,1,200,1,101,1,251,0,228,0,129,0,6,0,232,3,37,3,202,1,12,1,37,7,150,3,28,0,93,14,0,0,0,0,0,0,220,41,239,20,85,4,156,14,43,2,137,4,64,7,79,7,114,1,69,2,71,2,10,3,161,3,28,0,139,0,214,0,12,1,72,1,79,1,134,1,209,1,8,0,15,0,70,0,93,0,120,0,135,0,150,0,165,0,188,0,216,0,222,0,246,0,5,0,20,0,36,0,47,0,58,0,61,0,73,0,80,0,88,0,95,0,102,0,109,0,117,0,124,0,4,0,11,0,19,0,24,0,27,0,31,0,34,0,38,0,42,0,45,0,49,0,52,0,56,0,59,0,63,0,3,0,6,0,10,0,7,0,4,0,0,0,60,0,57,0,53,0,50,0,46,0,43,0,39,0,35,0,32,0,28,0,25,0,22,0,16,0,5,0,125,0,122,0,110,0,103,0,96,0,89,0,81,0,74,0,66,0,59,0,52,0,37,0,21,0,6,0,247,0,223,0,217,0,189,0,166,0,151,0,144,0,121,0,106,0,71,0,68,0,9,0,210,1,135,1,132,1,73,1,13,1,215,0,184,0,29,0,166,3,11,3,156,2,70,2,115,1,20,1,65,7,58,5,136,4,157,14,118,10,84,4,221,41,0,0,0,0,0,0,96,6,102,6,236,6,34,7,96,7,110,7,76,0,78,0,244,0,10,1,72,1,86,1,212,1,242,1,49,3,112,3,119,3,150,3,177,3,36,0,100,0,123,0,138,0,165,0,212,0,235,0,250,0,154,1,185,1,201,1,217,1,16,0,48,0,51,0,67,0,83,0,107,0,122,0,202,0,210,0,222,0,230,0,246,0,14,0,31,0,35,0,43,0,59,0,63,0,103,0,112,0,119,0,5,0,13,0,18,0,27,0,44,0,53,0,58,0,4,0,11,0,23,0,31,0,9,0,8,0,10,0,0,0,24,0,12,0,5,0,60,0,54,0,45,0,28,0,19,0,14,0,6,0,122,0,113,0,104,0,100,0,60,0,52,0,40,0,32,0,15,0,247,0,231,0,223,0,211,0,203,0,123,0,116,0,84,0,68,0,60,0,49,0,17,0,218,1,202,1,186,1,155,1,251,0,248,0,213,0,170,0,139,0,132,0,101,0,37,0,182,3,151,3,144,3,113,3,50,3,243,1,213,1,87,1,73,1,11,1,245,0,79,0,77,0,111,7,97,7,35,7,237,6,103,6,97,6,0,0,0,0,0,0,13,13,12,12,12,12,12,12,12,11,11,11,11,11,11,11,11,10,10,10,10,10,10,10,10,9,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,4,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,13,13,0,0,0,0,0,0,0,15,14,13,12,12,12,11,11,11,10,10,10,10,10,10,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,10,11,11,11,12,12,12,13,13,15,0,0,0,0,0,0,0,16,16,16,16,16,16,15,15,15,14,14,14,13,13,13,12,12,12,11,11,11,11,10,10,10,10,10,9,9,9,9,9,8,8,8,8,8,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,8,8,8,8,8,8,9,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,13,13,13,14,14,14,15,15,15,16,16,16,16,16,16,0,0,0,0,0,0,0,16,16,16,16,16,16,15,15,15,14,14,14,14,14,13,13,13,13,12,12,12,12,12,12,11,11,11,11,11,10,10,10,10,10,9,9,9,9,9,9,8,8,8,8,8,8,7,7,7,7,7,6,6,6,6,6,6,5,5,5,5,5,4,4,4,4,4,5,5,5,5,5,5,6,6,6,6,6,7,7,7,7,7,7,8,8,8,8,8,9,9,9,9,9,9,10,10,10,10,10,11,11,11,11,11,12,12,12,12,12,12,13,13,13,13,14,14,14,14,14,15,15,15,16,16,16,16,16,16,0,0,0,0,0,0,0,13,12,11,11,10,10,10,10,10,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,10,10,11,11,11,13,0,0,0,0,0,0,0,14,13,12,12,11,11,11,11,10,10,10,10,10,9,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,11,11,11,12,12,12,14,0,0,0,0,0,0,0,11,11,11,11,11,11,10,10,10,10,10,10,10,10,10,10,10,10,10,9,9,9,9,9,9,9,9,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,7,7,7,7,7,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,4,4,4,4,5,5,5,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,0,0,0,0,0,0,0,248,255,255,255,28,0,0,0,40,0,0,0,48,0,0,0,52,0,0,0,60,0,0,0,68,0,0,0,76,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,192,0,0,0,208,0,0,0,224,0,0,0,240,0,0,0,0,1,0,0,16,1,0,0,32,1,0,0,48,1,0,0,64,1,0,0,80,1,0,0,96,1,0,0,112,1,0,0,0,0,0,0,136,189,37,0,0,0,0,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,224,156,37,0,0,0,0,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,248,105,37,0,0,0,0,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,160,42,37,0,0,0,0,0,72,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,136,4,37,0,0,0,0,0,80,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,88,218,36,0,0,0,0,0,88,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,192,0,0,0,0,192,255,223,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,74,38,0,112,0,0,0,8,53,29,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,237,127,183,127,92,127,221,126,59,126,118,125,143,124,134,123,92,122,19,121,0,0,0,0,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,2,2,1,0,1,4,5,2,7,8,3,7,4,9,5,6,7,8,9,10,16,16,16,19,16,19,22,22,22,22,26,24,26,22,22,27,27,27,26,26,26,29,29,29,27,27,27,26,34,34,34,29,29,29,27,27,37,34,34,32,32,29,29,38,37,35,35,34,35,40,40,40,38,38,48,48,46,46,58,56,56,69,69,83,16,17,17,18,18,18,19,19,19,19,20,20,20,20,20,21,21,21,21,21,21,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,24,24,24,25,24,24,24,25,26,26,26,26,25,27,27,27,27,27,28,28,28,28,30,30,30,31,31,33,1,3,3,1,3,3,1,2,1,2,1,1,1,1,1,1,0,0,0,64,197,66,197,88,69,186,158,83,190,139,65,75,0,0,0,64,130,211,72,50,248,244,162,34,223,85,168,17,197,66,197,88,158,215,32,123,242,251,251,115,107,20,98,104,197,66,197,88,116,31,191,69,146,210,10,48,167,226,125,24,69,186,158,83,242,251,251,115,205,60,65,109,19,166,83,98,69,186,158,83,112,40,179,65,205,60,65,45,85,26,18,23,190,139,65,75,107,20,98,104,19,166,83,98,167,226,125,88,190,139,65,75,158,215,32,59,52,112,186,40,38,90,195,20,0,0,0,64,197,66,197,88,69,186,158,83,190,139,65,75,0,0,0,64,130,211,72,50,248,244,162,34,223,85,168,17,130,211,72,50,116,31,191,69,112,40,179,65,158,215,32,59,130,211,72,50,89,29,130,39,45,185,54,27,209,154,223,13,248,244,162,34,146,210,10,48,205,60,65,45,52,112,186,40,248,244,162,34,45,185,54,27,51,195,190,18,78,99,142,9,223,85,168,17,167,226,125,24,85,26,18,23,38,90,195,20,223,85,168,17,209,154,223,13,78,99,142,9,98,40,223,4,4,0,0,0,8,0,0,0,8,0,0,0,5,0,0,0,5,0,0,0,11,0,0,0,11,0,0,0,4,0,0,0,4,0,0,0,7,0,0,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,1,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,2,2,4,4,5,5,5,5,5,5,5,5,5,5,5,5,2,3,3,4,4,4,5,5,5,5,5,5,5,5,5,5,3,3,3,3,4,4,4,4,5,5,5,5,5,5,5,5,3,3,4,4,4,4,4,4,4,4,4,4,5,5,5,5,2,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,1,3,3,5,5,5,6,6,6,6,6,6,6,6,6,6,1,2,5,5,6,6,6,6,6,6,6,6,6,6,6,6,1,3,4,4,5,5,5,5,6,6,6,6,6,6,6,6,2,2,3,4,4,5,5,5,5,5,6,6,6,6,6,6,1,4,4,4,4,5,5,5,5,5,6,6,6,6,6,6,2,2,2,5,5,5,6,6,6,6,6,6,6,6,6,6,1,3,3,3,6,6,6,6,7,7,7,7,7,7,7,7,1,3,3,3,5,6,7,7,7,7,7,7,7,7,7,7,2,2,3,3,3,6,6,6,6,6,7,7,7,7,7,7,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,1,3,5,7,9,11,13,15,19,21,23,25,27,29,31,0,2,1,9,5,21,13,29,3,19,11,27,7,23,15,31,0,2,6,1,9,5,13,29,3,19,11,27,7,23,15,31,0,4,2,6,1,9,5,13,3,19,11,27,7,23,15,31,0,4,2,10,6,14,1,9,5,13,3,11,7,23,15,31,0,2,10,6,14,1,9,5,13,3,11,27,7,23,15,31,0,1,5,3,19,11,27,59,7,39,23,55,15,47,31,63,0,1,3,19,11,43,27,59,7,39,23,55,15,47,31,63,0,1,5,13,3,19,11,27,7,39,23,55,15,47,31,63,0,2,1,5,13,3,19,11,27,7,23,55,15,47,31,63,0,1,9,5,13,3,19,11,27,7,23,55,15,47,31,63,0,2,1,3,19,11,27,59,7,39,23,55,15,47,31,63,0,1,5,3,7,39,23,55,15,79,47,111,31,95,63,127,0,1,5,3,7,23,55,119,15,79,47,111,31,95,63,127,0,2,1,5,3,7,39,23,55,15,47,111,31,95,63,127,0,1,8,9,2,3,10,11,4,5,12,13,6,7,14,15,20,21,28,29,22,23,30,31,16,17,24,25,32,33,40,41,34,35,42,43,48,49,56,57,50,51,58,59,18,19,26,27,36,37,44,45,38,39,46,47,52,53,60,61,54,55,62,63,4,8,12,32,0,0,0,0,0,8,16,24,32,40,48,56,57,49,41,33,25,17,9,1,2,10,18,26,34,42,50,58,59,51,43,35,27,19,11,3,4,12,20,28,36,44,52,60,61,53,45,37,29,21,13,5,6,14,22,30,38,46,54,62,63,55,47,39,31,23,15,7,59,58,57,56,48,49,50,51,43,42,41,40,32,33,34,35,27,26,25,24,16,17,18,19,11,10,9,8,0,1,2,3,4,5,6,7,15,14,13,12,20,21,22,23,31,30,29,28,36,37,38,39,47,46,45,44,52,53,54,55,63,62,61,60,25,17,18,26,27,19,11,3,2,10,9,1,0,8,16,24,32,40,48,56,57,49,41,42,50,58,59,51,43,35,34,33,29,21,22,30,31,23,15,7,6,14,13,5,4,12,20,28,36,44,52,60,61,53,45,46,54,62,63,55,47,39,38,37,3,11,2,10,1,9,0,8,16,24,17,25,18,26,19,27,35,43,34,42,33,41,32,40,48,56,49,57,50,58,51,59,60,52,61,53,62,54,63,55,47,39,46,38,45,37,44,36,28,20,29,21,30,22,31,23,15,7,14,6,13,5,12,4,24,25,16,17,8,9,0,1,2,3,10,11,18,19,26,27,28,29,20,21,12,13,4,5,6,7,14,15,22,23,30,31,39,38,47,46,55,54,63,62,61,60,53,52,45,44,37,36,35,34,43,42,51,50,59,58,57,56,49,48,41,40,33,32,0,1,2,3,8,9,10,11,16,17,18,19,24,25,26,27,32,33,34,35,40,41,42,43,48,49,50,51,56,57,58,59,4,5,6,7,12,13,14,15,20,21,22,23,28,29,30,31,36,37,38,39,44,45,46,47,52,53,54,55,60,61,62,63,6,7,15,14,13,5,12,4,3,11,2,10,9,1,0,8,16,24,17,25,18,26,19,27,20,28,21,29,22,30,23,31,39,47,38,46,37,45,36,44,35,43,34,42,33,41,32,40,49,48,56,57,58,50,59,51,60,52,61,53,54,55,63,62,0,1,2,3,4,5,6,7,15,14,13,12,11,10,9,8,16,17,18,19,20,21,22,23,31,30,29,28,27,26,25,24,32,33,34,35,36,37,38,39,47,46,45,44,43,42,41,40,48,49,50,51,52,53,54,55,63,62,61,60,59,58,57,56,0,8,9,1,2,3,11,10,18,19,27,26,25,17,16,24,32,40,41,33,34,35,43,42,50,49,48,56,57,58,59,51,52,60,61,62,63,55,54,53,45,44,36,37,38,46,47,39,31,23,22,30,29,28,20,21,13,12,4,5,6,14,15,7,24,25,16,17,8,9,0,1,2,3,10,11,18,19,26,27,28,29,20,21,12,13,4,5,6,7,14,15,22,23,30,31,38,39,46,47,54,55,62,63,60,61,52,53,44,45,36,37,34,35,42,43,50,51,58,59,56,57,48,49,40,41,32,33,0,8,1,9,2,10,3,11,19,27,18,26,17,25,16,24,32,40,33,41,34,42,35,43,51,59,50,58,49,57,48,56,60,52,61,53,62,54,63,55,47,39,46,38,45,37,44,36,31,23,30,22,29,21,28,20,12,4,13,5,14,6,15,7,0,8,16,24,25,26,27,19,11,3,2,1,9,17,18,10,4,12,20,28,29,30,31,23,15,7,6,5,13,21,22,14,36,44,52,60,61,62,63,55,47,39,38,37,45,53,54,46,32,40,48,56,57,58,59,51,43,35,34,33,41,49,50,42,0,8,9,1,2,3,11,10,19,27,26,18,17,16,24,25,33,32,40,41,42,34,35,43,51,59,58,50,49,57,56,48,52,60,61,53,54,62,63,55,47,39,38,46,45,44,36,37,29,28,20,21,22,30,31,23,14,15,7,6,5,13,12,4,24,16,8,0,1,2,3,11,19], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1906225);
/* memory initializer */ allocate([27,26,25,17,10,9,18,28,20,12,4,5,6,7,15,23,31,30,29,21,14,13,22,60,52,44,36,37,38,39,47,55,63,62,61,53,46,45,54,56,48,40,32,33,34,35,43,51,59,58,57,49,42,41,50,0,8,9,1,2,10,18,17,16,24,25,26,27,19,11,3,7,6,14,15,23,22,21,13,5,4,12,20,28,29,30,31,63,62,54,55,47,46,45,53,61,60,52,44,36,37,38,39,56,48,49,57,58,50,42,41,40,32,33,34,35,43,51,59,0,1,8,9,16,17,24,25,32,33,40,41,48,49,56,57,58,59,50,51,42,43,34,35,26,27,18,19,10,11,2,3,4,5,12,13,20,21,28,29,36,37,44,45,52,53,60,61,62,63,54,55,46,47,38,39,30,31,22,23,14,15,6,7,0,0,1,0,21,99,1,0,61,232,1,0,53,165,2,0,123,78,1,0,119,101,1,0,230,241,2,0,76,114,2,0,0,0,1,0,218,238,0,0,2,65,2,0,155,127,1,0,128,190,0,0,30,97,0,0,60,8,1,0,82,165,0,0,136,31,2,0,83,220,1,0,173,127,2,0,151,246,1,0,25,72,1,0,67,167,0,0,49,90,1,0,136,150,0,0,111,52,2,0,229,14,3,0,250,251,1,0,150,192,2,0,0,208,1,0,150,131,2,0,71,146,1,0,170,249,1,0,111,52,2,0,250,251,1,0,83,220,1,0,184,49,2,0,18,47,1,0,108,224,1,0,16,203,0,0,168,25,1,0,140,196,1,0,72,151,1,0,134,78,1,0,175,34,1,0,40,198,2,0,32,127,2,0,181,151,2,0,50,63,2,0,0,80,2,0,107,171,1,0,34,209,1,0,179,89,1,0,105,38,1,0,67,141,0,0,31,238,0,0,237,117,0,0,12,73,1,0,136,2,1,0,53,247,0,0,81,239,0,0,241,224,0,0,173,114,0,0,216,164,0,0,23,101,0,0,85,85,1,0,113,217,1,0,252,138,2,0,241,134,3,0,249,189,1,0,159,220,1,0,51,237,3,0,17,67,3,0,85,85,1,0,120,62,1,0,88,1,3,0,122,255,1,0,0,254,0,0,125,129,0,0,79,96,1,0,109,220,0,0,181,212,2,0,25,123,2,0,231,84,3,0,31,158,2,0,119,181,1,0,4,223,0,0,150,205,1,0,182,200,0,0,149,240,2,0,220,19,4,0,78,165,2,0,115,171,3,0,171,106,2,0,30,90,3,0,94,24,2,0,56,162,2,0,149,240,2,0,78,165,2,0,25,123,2,0,245,236,2,0,24,148,1,0,144,128,2,0,192,14,1,0,138,119,1,0,102,91,2,0,11,31,2,0,9,190,1,0,148,131,1,0,224,178,3,0,42,84,3,0,241,116,3,0,238,254,2,0,85,21,3,0,228,57,2,0,45,108,2,0,238,204,1,0,140,136,1,0,89,188,0,0,126,61,1,0,60,157,0,0,187,182,1,0,181,88,1,0,156,73,1,0,23,63,1,0,236,43,1,0,230,152,0,0,203,219,0,0,201,134,0,0,171,170,1,0,206,79,2,0,187,45,3,0,173,104,4,0,120,45,2,0,199,83,2,0,127,232,4,0,213,19,4,0,171,170,1,0,22,142,1,0,174,193,3,0,88,127,2,0,128,61,1,0,220,161,0,0,99,184,1,0,136,19,1,0,226,137,3,0,223,25,3,0,33,42,4,0,167,69,3,0,212,34,2,0,197,22,1,0,252,64,2,0,227,250,0,0,186,172,3,0,211,24,5,0,161,78,3,0,79,150,4,0,85,5,3,0,165,48,4,0,118,158,2,0,197,74,3,0,186,172,3,0,161,78,3,0,223,25,3,0,51,168,3,0,30,249,1,0,180,32,3,0,112,82,1,0,109,213,1,0,63,242,2,0,206,166,2,0,139,45,2,0,121,228,1,0,152,159,4,0,53,41,4,0,45,82,4,0,169,190,3,0,171,218,3,0,93,200,2,0,56,7,3,0,42,64,2,0,175,234,1,0,111,235,0,0,222,140,1,0,138,196,0,0,105,36,2,0,226,174,1,0,2,156,1,0,221,142,1,0,231,118,1,0,32,191,0,0,190,18,1,0,123,168,0,0,0,0,2,0,42,198,2,0,122,208,3,0,105,74,5,0,246,156,2,0,239,202,2,0,204,227,5,0,153,228,4,0,0,0,2,0,180,221,1,0,4,130,4,0,54,255,2,0,1,125,1,0,60,194,0,0,119,16,2,0,163,74,1,0,15,63,4,0,166,184,3,0,90,255,4,0,46,237,3,0,50,144,2,0,134,78,1,0,97,180,2,0,17,45,1,0,223,104,4,0,202,29,6,0,245,247,3,0,44,129,5,0,0,160,3,0,44,7,5,0,141,36,3,0,83,243,3,0,223,104,4,0,245,247,3,0,166,184,3,0,112,99,4,0,36,94,2,0,216,192,3,0,32,150,1,0,79,51,2,0,25,137,3,0,145,46,3,0,13,157,2,0,94,69,2,0,80,140,5,0,63,254,4,0,105,47,5,0,101,126,4,0,0,160,4,0,214,86,3,0,67,162,3,0,101,179,2,0,210,76,2,0,133,26,1,0,62,220,1,0,217,235,0,0,24,146,2,0,16,5,2,0,105,238,1,0,162,222,1,0,226,193,1,0,89,229,0,0,176,73,1,0,45,202,0,0,171,170,2,0,227,178,3,0,248,21,5,0,226,13,7,0,242,123,3,0,62,185,3,0,101,218,7,0,33,134,6,0,171,170,2,0,240,124,2,0,177,2,6,0,243,254,3,0,1,252,1,0,250,2,1,0,159,192,2,0,218,184,1,0,106,169,5,0,50,246,4,0,206,169,6,0,62,60,5,0,237,106,3,0,9,190,1,0,45,155,3,0,107,145,1,0,41,225,5,0,184,39,8,0,156,74,5,0,229,86,7,0,85,213,4,0,59,180,6,0,188,48,4,0,111,68,5,0,41,225,5,0,156,74,5,0,50,246,4,0,235,217,5,0,48,40,3,0,33,1,5,0,128,29,2,0,20,239,2,0,204,182,4,0,22,62,4,0,17,124,3,0,40,7,3,0,192,101,7,0,85,168,6,0,226,233,6,0,219,253,5,0,171,42,6,0,200,115,4,0,90,216,4,0,220,153,3,0,24,17,3,0,178,120,1,0,253,122,2,0,119,58,1,0,118,109,3,0,106,177,2,0,55,147,2,0,46,126,2,0,216,87,2,0,204,49,1,0,150,183,1,0,145,13,1,0,0,128,3,0,202,218,4,0,213,172,6,0,56,66,9,0,174,146,4,0,34,227,4,0,165,78,10,0,12,144,8,0,0,128,3,0,251,67,3,0,136,227,7,0,159,62,5,0,193,154,2,0,232,83,1,0,208,156,3,0,158,66,2,0,91,110,7,0,34,131,6,0,222,190,8,0,17,223,6,0,87,124,4,0,107,73,2,0,171,187,4,0,221,14,2,0,134,183,7,0,33,180,10,0,237,241,6,0,13,162,9,0,0,88,6,0,142,204,8,0,247,127,5,0,210,233,6,0,134,183,7,0,237,241,6,0,34,131,6,0,4,174,7,0,191,36,4,0,123,145,6,0,184,198,2,0,203,217,3,0,235,47,6,0,125,145,5,0,215,146,4,0,100,249,3,0,140,181,9,0,239,188,8,0,248,18,9,0,48,221,7,0,0,24,8,0,247,215,5,0,246,91,6,0,241,185,4,0,112,6,4,0,105,238,1,0,108,65,3,0,188,156,1,0,170,127,4,0,220,136,3,0,56,97,3,0,156,69,3,0,76,19,3,0,92,145,1,0,245,64,2,0,207,97,1,0,0,0,4,0,84,140,5,0,244,160,7,0,211,148,10,0,236,57,5,0,221,149,5,0,152,199,11,0,50,201,9,0,0,0,4,0,104,187,3,0,9,4,9,0,109,254,5,0,1,250,2,0,119,132,1,0,238,32,4,0,71,149,2,0,31,126,8,0,76,113,7,0,181,254,9,0,93,218,7,0,100,32,5,0,13,157,2,0,195,104,5,0,33,90,2,0,190,209,8,0,148,59,12,0,234,239,7,0,88,2,11,0,0,64,7,0,89,14,10,0,26,73,6,0,167,230,7,0,190,209,8,0,234,239,7,0,76,113,7,0,224,198,8,0,72,188,4,0,177,129,7,0,63,44,3,0,159,102,4,0,50,18,7,0,34,93,6,0,26,58,5,0,188,138,4,0,160,24,11,0,127,252,9,0,211,94,10,0,201,252,8,0,0,64,9,0,172,173,6,0,135,68,7,0,202,102,5,0,165,153,4,0,11,53,2,0,123,184,3,0,179,215,1,0,48,36,5,0,32,10,4,0,211,220,3,0,69,189,3,0,197,131,3,0,179,202,1,0,97,147,2,0,90,148,1,0,0,0,5,0,105,239,6,0,49,137,9,0,7,58,13,0,103,136,6,0,85,251,6,0,126,185,14,0,126,59,12,0,0,0,5,0,66,170,4,0,11,69,11,0,8,126,7,0,129,184,3,0,149,229,1,0,42,41,5,0,153,58,3,0,167,157,10,0,159,77,9,0,98,126,12,0,244,208,9,0,125,104,6,0,80,68,3,0,244,194,6,0,170,240,2,0,45,6,11,0,120,74,15,0,228,235,9,0,238,194,13,0,0,16,9,0,239,145,12,0,97,219,7,0,80,224,9,0,45,6,11,0,228,235,9,0,159,77,9,0,152,248,10,0,89,235,5,0,29,98,9,0,79,247,3,0,70,128,5,0,190,214,8,0,106,244,7,0,160,136,6,0,107,173,5,0,200,222,13,0,159,123,12,0,135,246,12,0,251,59,11,0,0,144,11,0,23,89,8,0,168,21,9,0,125,192,6,0,14,192,5,0,77,194,2,0,154,166,4,0,159,77,2,0,60,109,6,0,167,12,5,0,7,212,4,0,150,172,4,0,182,100,4,0,95,61,2,0,57,56,3,0,113,249,1,0,0,0,6,0,126,82,8,0,110,113,11,0,60,223,15,0,225,214,7,0,204,96,8,0,99,171,17,0,203,173,14,0,0,0,6,0,28,153,5,0,13,134,13,0,163,253,8,0,2,119,4,0,179,70,2,0,101,49,6,0,234,223,3,0,46,189,12,0,241,41,11,0,15,254,14,0,139,199,11,0,150,176,7,0,147,235,3,0,36,29,8,0,50,135,3,0,156,58,13,0,93,89,18,0,223,231,11,0,132,131,16,0,0,224,10,0,133,21,15,0,168,109,9,0,250,217,11,0,156,58,13,0,223,231,11,0,241,41,11,0,80,42,13,0,107,26,7,0,137,66,11,0,95,194,4,0,238,153,6,0,74,155,10,0,178,139,9,0,39,215,7,0,26,208,6,0,240,164,16,0,190,250,14,0,60,142,15,0,46,123,13,0,0,224,13,0,130,4,10,0,202,230,10,0,47,26,8,0,119,230,6,0,144,79,3,0,185,148,5,0,140,195,2,0,73,182,7,0,47,15,6,0,60,203,5,0,231,155,5,0,167,69,5,0,12,176,2,0,17,221,3,0,135,94,2,0,0,0,8,0,168,24,11,0,232,65,15,0,165,41,21,0,215,115,10,0,187,43,11,0,47,143,23,0,100,146,19,0,0,0,8,0,207,118,7,0,18,8,18,0,217,252,11,0,2,244,5,0,239,8,3,0,220,65,8,0,142,42,5,0,62,252,16,0,151,226,14,0,105,253,19,0,185,180,15,0,200,64,10,0,26,58,5,0,134,209,10,0,66,180,4,0,123,163,17,0,39,119,24,0,212,223,15,0,176,4,22,0,0,128,14,0,177,28,20,0,53,146,12,0,77,205,15,0,123,163,17,0,212,223,15,0,151,226,14,0,192,141,17,0,143,120,9,0,98,3,15,0,127,88,6,0,61,205,8,0,99,36,14,0,67,186,12,0,52,116,10,0,119,21,9,0,64,49,22,0,254,248,19,0,165,189,20,0,146,249,17,0,0,128,18,0,88,91,13,0,13,137,14,0,148,205,10,0,73,51,9,0,21,106,4,0,247,112,7,0,101,175,3,0,97,72,10,0,63,20,8,0,166,185,7,0,137,122,7,0,137,7,7,0,101,149,3,0,194,38,5,0,180,40,3,0,0,0,12,0,253,164,16,0,219,226,22,0,120,190,31,0,195,173,15,0,152,193,16,0,199,86,35,0,150,91,29,0,0,0,12,0,55,50,11,0,26,12,27,0,70,251,17,0,3,238,8,0,102,141,4,0,202,98,12,0,213,191,7,0,93,122,25,0,227,83,22,0,30,252,29,0,22,143,23,0,44,97,15,0,39,215,7,0,73,58,16,0,100,14,7,0,57,117,26,0,187,178,36,0,189,207,23,0,9,7,33,0,0,192,21,0,10,43,30,0,79,219,18,0,244,179,23,0,57,117,26,0,189,207,23,0,227,83,22,0,160,84,26,0,215,52,14,0,19,133,22,0,190,132,9,0,220,51,13,0,149,54,21,0,101,23,19,0,78,174,15,0,51,160,13,0,225,73,33,0,125,245,29,0,120,28,31,0,91,246,26,0,0,192,27,0,4,9,20,0,148,205,21,0,94,52,16,0,238,204,13,0,32,159,6,0,114,41,11,0,24,135,5,0,145,108,15,0,94,30,12,0,120,150,11,0,206,55,11,0,78,139,10,0,24,96,5,0,34,186,7,0,14,189,4,0,0,0,17,0,102,148,23,0,12,108,32,0,127,248,44,0,42,54,22,0,237,188,23,0,68,16,50,0,20,151,41,0,0,0,17,0,121,220,15,0,37,81,38,0,78,121,25,0,133,166,12,0,251,114,6,0,244,139,17,0,109,250,10,0,4,24,36,0,129,161,31,0,128,122,42,0,10,96,33,0,169,201,21,0,119,27,11,0,60,253,22,0,13,255,9,0,102,123,37,0,51,253,51,0,162,187,33,0,247,201,46,0,0,208,30,0,249,188,42,0,176,182,26,0,68,148,33,0,102,123,37,0,162,187,33,0,129,161,31,0,56,77,37,0,48,32,20,0,48,231,31,0,14,124,13,0,35,180,18,0,82,13,30,0,207,11,27,0,238,54,22,0,158,77,19,0,169,40,47,0,27,113,42,0,255,18,44,0,86,50,38,0,0,80,39,0,27,98,28,0,60,227,30,0,219,244,22,0,251,140,19,0,110,97,9,0,12,208,15,0,183,212,7,0,206,217,21,0,6,43,17,0,128,106,16,0,100,228,15,0,4,240,14,0,119,157,7,0,91,242,10,0,127,182,6,0,0,0,22,0,207,131,30,0,61,245,41,0,134,50,58,0,144,190,28,0,66,184,30,0,194,201,64,0,147,210,53,0,0,0,22,0,186,134,20,0,48,150,49,0,86,247,32,0,6,95,16,0,145,88,8,0,30,181,22,0,6,53,14,0,170,181,46,0,32,239,40,0,225,248,54,0,254,48,43,0,37,50,28,0,199,95,14,0,48,192,29,0,183,239,12,0,147,129,48,0,172,71,67,0,134,167,43,0,229,140,60,0,0,224,39,0,231,78,55,0,18,146,34,0,148,116,43,0,147,129,48,0,134,167,43,0,32,239,40,0,208,69,48,0,137,11,26,0,77,73,41,0,93,115,17,0,105,52,24,0,16,228,38,0,57,0,35,0,143,191,28,0,9,251,24,0,113,7,61,0,186,236,54,0,134,9,57,0,82,110,49,0,0,224,50,0,51,187,36,0,228,248,39,0,87,181,29,0,9,77,25,0,187,35,12,0,166,118,20,0,86,34,10,0,10,71,28,0,173,55,22,0,135,62,21,0,250,144,20,0,185,84,19,0,214,218,9,0,148,42,14,0,240,175,8,0,0,0,28,0,77,214,38,0,170,102,53,0,194,17,74,0,114,149,36,0,14,25,39,0,37,117,82,0,94,128,68,0,0,0,28,0,214,31,26,0,62,28,63,0,249,244,41,0,7,214,20,0,68,159,10,0,131,230,28,0,240,20,18,0,217,114,59,0,17,25,52,0,240,246,69,0,137,248,54,0,187,226,35,0,91,75,18,0,84,221,37,0,233,118,16,0,48,188,61,0,9,161,85,0,100,143,55,0,105,16,77,0,0,192,50,0,108,100,70,0,185,255,43,0,142,78,55,0,48,188,61,0,100,143,55,0,17,25,52,0,32,112,61,0,245,37,33,0,214,139,52,0,188,53,22,0,87,206,30,0,91,127,49,0,235,139,44,0,182,150,36,0,34,203,31,0,97,172,77,0,120,231,69,0,194,151,72,0,127,233,62,0,0,192,64,0,181,191,46,0,174,223,50,0,134,207,37,0,128,51,32,0,75,115,15,0,95,11,26,0,226,229,12,0,83,253,35,0,220,70,28,0,196,9,27,0,225,44,26,0,96,154,24,0,226,138,12,0,165,7,18,0,119,14,11,0,0,0,34,0,204,40,47,0,24,216,64,0,254,240,89,0,83,108,44,0,218,121,47,0,137,32,100,0,41,46,83,0,0,0,34,0,241,184,31,0,75,162,76,0,156,242,50,0,9,77,25,0,247,229,12,0,232,23,35,0,219,244,21,0,7,48,72,0,3,67,63,0,255,244,84,0,20,192,66,0,81,147,43,0,238,54,22,0,121,250,45,0,26,254,19,0,204,246,74,0,103,250,103,0,67,119,67,0,238,147,93,0,0,160,61,0,241,121,85,0,97,109,53,0,136,40,67,0,204,246,74,0,67,119,67,0,3,67,63,0,112,154,74,0,96,64,40,0,96,206,63,0,27,248,26,0,69,104,37,0,165,26,60,0,157,23,54,0,221,109,44,0,60,155,38,0,82,81,94,0,55,226,84,0,254,37,88,0,173,100,76,0,0,160,78,0,55,196,56,0,120,198,61,0,181,233,45,0,247,25,39,0,219,194,18,0,24,160,31,0,110,169,15,0,155,179,43,0,12,86,34,0,0,213,32,0,200,200,31,0,7,224,29,0,238,58,15,0,183,228,21,0,254,108,13,0,0,0,44,0,158,7,61,0,121,234,83,0,12,101,116,0,32,125,57,0,131,112,61,0,131,147,129,0,37,165,107,0,0,0,44,0,117,13,41,0,97,44,99,0,172,238,65,0,12,190,32,0,33,177,16,0,59,106,45,0,12,106,28,0,84,107,93,0,64,222,81,0,194,241,109,0,251,97,86,0,75,100,56,0,143,191,28,0,96,128,59,0,109,223,25,0,38,3,97,0,87,143,134,0,11,79,87,0,202,25,121,0,0,192,79,0,206,157,110,0,35,36,69,0,40,233,86,0,38,3,97,0,11,79,87,0,64,222,81,0,160,139,96,0,19,23,52,0,154,146,82,0,186,230,34,0,210,104,48,0,33,200,77,0,113,0,70,0,30,127,57,0,17,246,49,0,226,14,122,0,116,217,109,0,12,19,114,0,163,220,98,0,0,192,101,0,101,118,73,0,201,241,79,0,174,106,59,0,18,154,50,0,118,71,24,0,77,237,40,0,172,68,20,0,20,142,56,0,90,111,44,0,15,125,42,0,244,33,41,0,115,169,38,0,173,181,19,0,40,85,28,0,223,95,17,0,0,0,1,0,70,121,1,0,169,165,1,0,220,72,2,0,99,99,1,0,167,82,1,0,236,67,2,0,234,9,2,0,0,32,1,0,72,226,0,0,218,187,1,0,188,92,1,0,134,164,0,0,224,83,0,0,54,240,0,0,149,128,0,0,1,183,1,0,89,105,1,0,185,176,1,0,253,83,1,0,231,248,0,0,228,126,0,0,48,234,0,0,99,119,0,0,1,183,1,0,235,96,2,0,233,157,1,0,27,62,2,0,0,112,1,0,110,254,1,0,181,45,1,0,123,162,1,0,209,224,1,0,185,176,1,0,51,138,1,0,141,113,1,0,122,216,0,0,73,68,1,0,154,123,0,0,113,171,0,0,120,49,1,0,234,18,1,0,8,173,0,0,185,155,0,0,151,61,2,0,55,4,2,0,204,28,2,0,180,230,1,0,0,128,1,0,181,45,1,0,217,70,1,0,206,0,1,0,210,207,0,0,92,110,0,0,228,176,0,0,45,90,0,0,204,233,0,0,177,183,0,0,111,132,0,0,133,107,0,0,55,131,0,0,229,66,0,0,16,74,0,0,49,40,0,0,85,85,1,0,8,247,1,0,55,50,2,0,208,11,3,0,217,217,1,0,137,195,1,0,59,5,3,0,227,183,2,0,0,128,1,0,181,45,1,0,206,79,2,0,250,208,1,0,93,219,0,0,213,111,0,0,72,64,1,0,113,171,0,0,87,73,2,0,204,225,1,0,247,64,2,0,81,197,1,0,222,75,1,0,47,169,0,0,64,56,1,0,47,159,0,0,87,73,2,0,228,43,3,0,225,39,2,0,122,253,2,0,171,234,1,0,147,168,2,0,71,146,1,0,249,45,2,0,22,129,2,0,247,64,2,0,153,13,2,0,188,236,1,0,163,32,1,0,97,176,1,0,206,164,0,0,151,228,0,0,75,151,1,0,142,110,1,0,181,230,0,0,162,207,0,0,201,252,2,0,74,176,2,0,16,209,2,0,241,136,2,0,0,0,2,0,71,146,1,0,204,179,1,0,104,86,1,0,24,21,1,0,37,147,0,0,218,235,0,0,61,120,0,0,187,55,1,0,237,244,0,0,147,176,0,0,92,143,0,0,244,174,0,0,49,89,0,0,191,98,0,0,151,53,0,0,171,170,1,0,203,116,2,0,196,190,2,0,196,206,3,0,79,80,2,0,108,52,2,0,137,198,3,0,220,101,3,0,0,224,1,0,34,121,1,0,193,227,2,0,57,69,2,0,53,18,1,0,202,139,0,0,90,144,1,0,77,214,0,0,173,219,2,0,64,90,2,0,52,209,2,0,165,54,2,0,214,158,1,0,123,211,0,0,80,134,1,0,251,198,0,0,173,219,2,0,221,246,3,0,217,177,2,0,216,188,3,0,85,101,2,0,184,82,3,0,216,246,1,0,119,185,2,0,92,33,3,0,52,209,2,0,0,145,2,0,235,103,2,0,204,104,1,0,122,28,2,0,1,206,0,0,189,29,1,0,30,253,1,0,49,202,1,0,98,32,1,0,138,3,1,0,251,187,3,0,92,92,3,0,84,133,3,0,45,43,3,0,0,128,2,0,216,246,1,0,192,32,2,0,2,172,1,0,94,90,1,0,239,183,0,0,209,38,1,0,76,150,0,0,169,133,1,0,40,50,1,0,184,220,0,0,51,179,0,0,178,218,0,0,125,111,0,0,111,123,0,0,252,66,0,0,0,0,2,0,141,242,2,0,82,75,3,0,184,145,4,0,197,198,2,0,78,165,2,0,216,135,4,0,213,19,4,0,0,64,2,0,143,196,1,0,181,119,3,0,119,185,2,0,12,73,1,0,191,167,0,0,108,224,1,0,42,1,1,0,3,110,3,0,179,210,2,0,114,97,3,0,250,167,2,0,206,241,1,0,199,253,0,0,96,212,1,0,199,238,0,0,3,110,3,0,214,193,4,0,209,59,3,0,55,124,4,0,0,224,2,0,221,252,3,0,106,91,2,0,245,68,3,0,161,193,3,0,114,97,3,0,102,20,3,0,27,227,2,0,245,176,1,0,146,136,2,0,53,247,0,0,226,86,1,0,241,98,2,0,213,37,2,0,16,90,1,0,114,55,1,0,45,123,4,0,110,8,4,0,152,57,4,0,105,205,3,0,0,0,3,0,106,91,2,0,179,141,2,0,155,1,2,0,163,159,1,0,184,220,0,0,199,97,1,0,91,180,0,0,152,211,1,0,99,111,1,0,221,8,1,0,10,215,0,0,111,6,1,0,201,133,0,0,31,148,0,0,98,80,0,0,171,170,2,0,17,238,3,0,109,100,4,0,160,23,6,0,178,179,3,0,19,135,3,0,117,10,6,0,198,111,5,0,0,0,3,0,106,91,2,0,155,159,4,0,244,161,3,0,187,182,1,0,170,223,0,0,144,128,2,0,226,86,1,0,174,146,4,0,153,195,3,0,237,129,4,0,162,138,3,0,189,151,2,0,95,82,1,0,128,112,2,0,94,62,1,0,174,146,4,0,200,87,6,0,193,79,4,0,244,250,5,0,85,213,3,0,38,81,5,0,141,36,3,0,242,91,4,0,45,2,5,0,237,129,4,0,51,27,4,0,121,217,3,0,71,65,2,0,195,96,3,0,156,73,1,0,46,201,1,0,150,46,3,0,28,221,2,0,106,205,1,0,67,159,1,0,145,249,5,0,147,96,5,0,32,162,5,0,225,17,5,0,0,0,4,0,141,36,3,0,153,103,3,0,207,172,2,0,47,42,2,0,75,38,1,0,181,215,1,0,121,240,0,0,117,111,2,0,217,233,1,0,39,97,1,0,184,30,1,0,233,93,1,0,98,178,0,0,127,197,0,0,45,107,0,0,0,128,3,0,118,40,5,0,207,195,5,0,2,255,7,0,217,219,4,0,72,161,4,0,186,237,7,0,180,34,7,0,0,240,3,0,251,23,3,0,124,17,6,0,145,196,4,0,213,63,2,0,143,37,1,0,189,72,3,0,9,194,1,0,133,0,6,0,185,240,4,0,135,234,5,0,245,165,4,0,40,103,3,0,28,188,1,0,168,51,3,0,219,161,1,0,133,0,6,0,54,83,8,0,174,168,5,0,96,217,7,0,0,8,5,0,130,250,6,0,249,31,4,0,174,184,5,0,218,146,6,0,135,234,5,0,178,99,5,0,110,13,5,0,173,245,2,0,0,111,4,0,156,176,1,0,12,88,2,0,37,45,4,0,53,194,3,0,155,93,2,0,8,33,2,0,143,215,7,0,193,14,7,0,202,100,7,0,119,167,6,0,0,64,5,0,249,31,4,0,249,119,4,0,208,130,3,0,94,215,2,0,66,130,1,0,29,107,2,0,159,59,1,0,74,50,3,0,237,130,2,0,131,207,1,0,81,120,1,0,66,203,1,0,33,234,0,0,54,3,1,0,172,140,0,0,0,0,4,0,25,229,5,0,164,150,6,0,112,35,9,0,138,141,5,0,156,74,5,0,176,15,9,0,170,39,8,0,0,128,4,0,31,137,3,0,105,239,6,0,238,114,5,0,24,146,2,0,126,79,1,0,216,192,3,0,84,2,2,0,5,220,6,0,101,165,5,0,228,194,6,0,243,79,5,0,155,227,3,0,142,251,1,0,192,168,3,0,141,221,1,0,5,220,6,0,172,131,9,0,162,119,6,0,110,248,8,0,0,192,5,0,185,249,7,0,212,182,4,0,235,137,6,0,67,131,7,0,228,194,6,0,204,40,6,0,53,198,5,0,234,97,3,0,36,17,5,0,105,238,1,0,197,173,2,0,225,197,4,0,170,75,4,0,31,180,2,0,229,110,2,0,90,246,8,0,221,16,8,0,48,115,8,0,209,154,7,0,0,0,6,0,212,182,4,0,101,27,5,0,55,3,4,0,71,63,3,0,112,185,1,0,143,195,2,0,182,104,1,0,48,167,3,0,198,222,2,0,186,17,2,0,20,174,1,0,221,12,2,0,147,11,1,0,62,40,1,0,196,160,0,0,0,0,5,0,96,94,7,0,77,60,8,0,76,108,11,0,237,240,6,0,67,157,6,0,156,83,11,0,148,49,10,0,0,160,5,0,103,107,4,0,68,171,8,0,170,207,6,0,158,54,3,0,94,163,1,0,15,177,4,0,232,130,2,0,7,147,8,0,191,14,7,0,156,115,8,0,240,163,6,0,130,220,4,0,114,122,2,0,240,146,4,0,240,84,2,0,7,147,8,0,151,228,11,0,139,21,8,0,137,54,11,0,0,48,7,0,39,248,9,0,137,228,5,0,102,44,8,0,19,100,9,0,156,115,8,0,255,178,7,0,194,55,7,0,100,58,4,0,109,85,6,0,4,106,2,0,54,89,3,0,90,247,5,0,148,94,5,0,39,97,3,0,158,10,3,0,241,51,11,0,20,21,10,0,252,143,10,0,134,129,9,0,0,128,7,0,137,228,5,0,63,98,6,0,5,4,5,0,25,15,4,0,204,39,2,0,115,116,3,0,227,194,1,0,252,144,4,0,119,150,3,0,41,150,2,0,153,25,2,0,21,144,2,0,120,78,1,0,78,114,1,0,245,200,0,0,0,0,6,0,166,215,8,0,246,225,9,0,40,181,13,0,80,84,8,0,234,239,7,0,136,151,13,0,126,59,12,0,0,192,6,0,174,77,5,0,30,103,10,0,102,44,8,0,36,219,3,0,62,247,1,0,69,161,5,0,125,3,3,0,8,74,10,0,24,120,8,0,85,36,10,0,237,247,7,0,105,213,5,0,85,249,2,0,32,125,5,0,84,204,2,0,8,74,10,0,130,69,14,0,115,179,9,0,165,116,13,0,0,160,8,0,150,246,11,0,62,18,7,0,224,206,9,0,228,68,11,0,85,36,10,0,50,61,9,0,80,169,8,0,223,18,5,0,182,153,7,0,158,229,2,0,167,4,4,0,210,40,7,0,127,113,6,0,47,14,4,0,87,166,3,0,135,113,13,0,75,25,12,0,200,172,12,0,58,104,11,0,0,0,9,0,62,18,7,0,24,169,7,0,210,4,6,0,234,222,4,0,41,150,2,0,86,37,4,0,17,29,2,0,200,122,5,0,40,78,4,0,151,26,3,0,30,133,2,0,76,19,3,0,92,145,1,0,93,188,1,0,38,241,0,0,0,0,8,0,51,202,11,0,72,45,13,0,224,70,18,0,21,27,11,0,56,149,10,0,95,31,18,0,83,79,16,0,0,0,9,0,62,18,7,0,210,222,13,0,221,229,10,0,48,36,5,0,253,158,2,0,177,129,7,0,167,4,4,0,11,184,13,0,203,74,11,0,199,133,13,0,231,159,10,0,54,199,7,0,29,247,3,0,128,81,7,0,26,187,3,0,11,184,13,0,87,7,19,0,68,239,12,0,220,240,17,0,0,128,11,0,114,243,15,0,168,109,9,0,214,19,13,0,134,6,15,0,199,133,13,0,152,81,12,0,106,140,11,0,212,195,6,0,72,34,10,0,211,220,3,0,138,91,5,0,195,139,9,0,84,151,8,0,62,104,5,0,201,221,4,0,180,236,17,0,185,33,16,0,97,230,16,0,163,53,15,0,0,0,12,0,168,109,9,0,203,54,10,0,110,6,8,0,142,126,6,0,225,114,3,0,30,135,5,0,107,209,2,0,96,78,7,0,139,189,5,0,116,35,4,0,40,92,3,0,187,25,4,0,38,23,2,0,124,80,2,0,136,65,1,0,0,0,12,0,76,175,17,0,236,195,19,0,80,106,27,0,159,168,16,0,212,223,15,0,15,47,27,0,253,118,24,0,0,128,13,0,93,155,10,0,60,206,20,0,203,88,16,0,73,182,7,0,123,238,3,0,137,66,11,0,251,6,6,0,16,148,20,0,48,240,16,0,171,72,20,0,218,239,15,0,210,170,11,0,171,242,5,0,64,250,10,0,167,152,5,0,16,148,20,0,3,139,28,0,230,102,19,0,73,233,26,0,0,64,17,0,43,237,23,0,124,36,14,0,193,157,19,0,200,137,22,0,171,72,20,0,99,122,18,0,159,82,17,0,190,37,10,0,109,51,15,0,60,203,5,0,78,9,8,0,164,81,14,0,254,226,12,0,93,28,8,0,174,76,7,0,14,227,26,0,150,50,24,0,145,89,25,0,116,208,22,0,0,0,18,0,124,36,14,0,48,82,15,0,165,9,12,0,213,189,9,0,81,44,5,0,172,74,8,0,33,58,4,0,144,245,10,0,81,156,8,0,46,53,6,0,59,10,5,0,152,38,6,0,185,34,3,0,186,120,3,0,77,226,1,0,0,0,17,0,172,13,25,0,57,0,28,0,156,214,38,0,140,153,23,0,22,125,22,0,171,130,38,0,145,168,34,0,0,32,19,0,195,6,15,0,127,121,29,0,118,40,23,0,231,236,10,0,217,145,5,0,152,243,15,0,227,137,8,0,23,39,29,0,239,254,23,0,71,188,28,0,202,147,22,0,84,135,16,0,29,109,8,0,48,141,15,0,152,237,7,0,23,39,29,0,154,111,40,0,113,124,27,0,211,31,38,0,0,112,24,0,82,229,33,0,4,9,20,0,39,202,27,0,220,237,31,0,71,188,28,0,98,45,26,0,98,138,24,0,34,96,14,0,218,136,21,0,64,53,8,0,132,98,11,0,254,72,20,0,146,65,18,0,132,125,11,0,75,87,10,0,255,22,38,0,170,71,34,0,141,233,35,0,250,81,32,0,0,128,25,0,4,9,20,0,111,180,21,0,170,13,17,0,238,204,13,0,30,84,7,0,31,191,11,0,4,253,5,0,139,134,15,0,200,50,12,0,87,203,8,0,212,35,7,0,173,182,8,0,48,113,4,0,8,235,4,0,66,171,2,0,0,0,22,0,12,108,32,0,134,60,36,0,232,66,50,0,121,138,30,0,89,26,29,0,70,214,49,0,37,218,44,0,0,192,24,0,42,114,19,0,195,36,38,0,32,248,29,0,133,35,14,0,55,53,7,0,167,164,20,0,204,12,11,0,29,186,37,0,174,13,31,0,228,47,37,0,187,55,29,0,214,99,21,0,142,231,10,0,33,32,20,0,136,66,10,0,29,186,37,0,48,84,52,0,251,145,35,0,92,86,49,0,0,160,31,0,122,221,43,0,141,237,25,0,140,246,35,0,239,81,41,0,228,47,37,0,97,224,33,0,36,194,31,0,135,154,18,0,71,222,27,0,68,159,10,0,186,187,14,0,88,64,26,0,38,160,23,0,171,222,14,0,233,97,13,0,239,74,49,0,190,92,44,0,138,121,46,0,128,211,41,0,0,0,33,0,141,237,25,0,174,22,28,0,174,17,22,0,6,220,17,0,234,123,9,0,145,51,15,0,231,191,7,0,135,23,20,0,62,201,15,0,127,97,11,0,109,61,9,0,193,70,11,0,168,191,5,0,85,93,6,0,55,116,3,0,0,0,28,0,178,67,41,0,124,30,46,0,16,248,63,0,201,222,38,0,67,10,37,0,206,109,63,0,163,21,57,0,0,128,31,0,216,191,24,0,225,139,48,0,133,36,38,0,169,254,17,0,117,44,9,0,235,69,26,0,73,16,14,0,37,4,48,0,198,133,39,0,57,84,47,0,168,47,37,0,63,57,27,0,228,224,13,0,65,157,25,0,220,14,13,0,37,4,48,0,178,153,66,0,110,69,45,0,0,203,62,0,0,64,40,0,15,212,55,0,203,255,32,0,109,197,45,0,211,150,52,0,57,84,47,0,147,29,43,0,116,107,40,0,102,173,23,0,254,119,35,0,226,132,13,0,98,192,18,0,42,105,33,0,165,17,30,0,218,236,18,0,64,8,17,0,118,188,62,0,8,118,56,0,82,38,59,0,186,59,53,0,0,0,42,0,203,255,32,0,198,191,35,0,129,22,28,0,241,186,22,0,19,18,12,0,232,88,19,0,248,220,9,0,79,146,25,0,103,23,20,0,22,124,14,0,138,194,11,0,13,90,14,0,4,81,7,0,178,25,8,0,93,101,4,0,0,0,34,0,88,27,50,0,114,0,56,0,56,173,77,0,24,51,47,0,45,250,44,0,86,5,77,0,34,81,69,0,0,64,38,0,134,13,30,0,254,242,58,0,235,80,46,0,206,217,21,0,178,35,11,0,48,231,31,0,199,19,17,0,45,78,58,0,223,253,47,0,142,120,57,0,149,39,45,0,168,14,33,0,57,218,16,0,97,26,31,0,47,219,15,0,45,78,58,0,51,223,80,0,225,248,54,0,165,63,76,0,0,224,48,0,165,202,67,0,9,18,40,0,77,148,55,0,183,219,63,0,142,120,57,0,196,90,52,0,195,20,49,0,68,192,28,0,180,17,43,0,128,106,16,0,9,197,22,0,252,145,40,0,36,131,36,0,8,251,22,0,151,174,20,0,253,45,76,0,84,143,68,0,27,211,71,0,245,163,64,0,0,0,51,0,9,18,40,0,223,104,43,0,83,27,34,0,219,153,27,0,59,168,14,0,62,126,23,0,9,250,11,0,23,13,31,0,143,101,24,0,174,150,17,0,168,71,14,0,90,109,17,0,96,226,8,0,15,214,9,0,132,86,5,0,0,0,44,0,24,216,64,0,12,121,72,0,208,133,100,0,242,20,61,0,178,52,58,0,141,172,99,0,74,180,89,0,0,128,49,0,84,228,38,0,134,73,76,0,63,240,59,0,10,71,28,0,110,106,14,0,77,73,41,0,152,25,22,0,58,116,75,0,92,27,62,0,199,95,74,0,117,111,58,0,172,199,42,0,29,207,21,0,65,64,40,0,16,133,20,0,58,116,75,0,97,168,104,0,246,35,71,0,184,172,98,0,0,64,63,0,243,186,87,0,26,219,51,0,25,237,71,0,222,163,82,0,199,95,74,0,194,192,67,0,72,132,63,0,13,53,37,0,142,188,55,0,135,62,21,0,117,119,29,0,176,128,52,0,76,64,47,0,86,189,29,0,210,195,26,0,222,149,98,0,123,185,88,0,19,243,92,0,1,167,83,0,0,0,66,0,26,219,51,0,92,45,56,0,93,35,44,0,13,184,35,0,212,247,18,0,35,103,30,0,207,127,15,0,14,47,40,0,125,146,31,0,255,194,22,0,217,122,18,0,131,141,22,0,80,127,11,0,170,186,12,0,110,232,6,0,0,48,12,255,1,48,2,48,14,255,39,32,27,255,26,255,31,255,1,255,48,254,38,32,37,32,80,254,81,254,82,254,183,0,84,254,85,254,86,254,87,254,92,255,19,32,49,254,20,32,51,254,116,37,52,254,79,254,8,255,9,255,53,254,54,254,91,255,93,255,55,254,56,254,20,48,21,48,57,254,58,254,16,48,17,48,59,254,60,254,10,48,11,48,61,254,62,254,8,48,9,48,63,254,64,254,12,48,13,48,65,254,66,254,14,48,15,48,67,254,68,254,89,254,90,254,91,254,92,254,93,254,94,254,24,32,25,32,28,32,29,32,29,48,30,48,53,32,50,32,3,255,6,255,10,255,59,32,167,0,3,48,203,37,207,37,179,37,178,37,206,37,6,38,5,38,199,37,198,37,161,37,160,37,189,37,188,37,163,50,5,33,175,0,227,255,63,255,205,2,73,254,74,254,77,254,78,254,75,254,76,254,95,254,96,254,97,254,11,255,13,255,215,0,247,0,177,0,26,34,28,255,30,255,29,255,102,34,103,34,96,34,30,34,82,34,97,34,98,254,99,254,100,254,101,254,102,254,94,255,41,34,42,34,165,34,32,34,31,34,191,34,210,51,209,51,43,34,46,34,53,34,52,34,64,38,66,38,149,34,153,34,145,33,147,33,144,33,146,33,150,33,151,33,153,33,152,33,37,34,35,34,15,255,60,255,21,34,104,254,4,255,229,255,18,48,224,255,225,255,5,255,32,255,3,33,9,33,105,254,106,254,107,254,213,51,156,51,157,51,158,51,206,51,161,51,142,51,143,51,196,51,176,0,89,81,91,81,94,81,93,81,97,81,99,81,231,85,233,116,206,124,129,37,130,37,131,37,132,37,133,37,134,37,135,37,136,37,143,37,142,37,141,37,140,37,139,37,138,37,137,37,60,37,52,37,44,37,36,37,28,37,148,37,0,37,2,37,149,37,12,37,16,37,20,37,24,37,109,37,110,37,112,37,111,37,80,37,94,37,106,37,97,37,226,37,227,37,229,37,228,37,113,37,114,37,115,37,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,65,83,68,83,69,83,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,5,49,6,49,7,49,8,49,9,49,10,49,11,49,12,49,13,49,14,49,15,49,16,49,17,49,18,49,19,49,20,49,21,49,22,49,23,49,24,49,25,49,26,49,27,49,28,49,29,49,30,49,31,49,32,49,33,49,34,49,35,49,36,49,37,49,38,49,39,49,40,49,41,49,217,2,201,2,202,2,199,2,203,2,0,36,1,36,2,36,3,36,4,36,5,36,6,36,7,36,8,36,9,36,10,36,11,36,12,36,13,36,14,36,15,36,16,36,17,36,18,36,19,36,20,36,21,36,22,36,23,36,24,36,25,36,26,36,27,36,28,36,29,36,30,36,31,36,33,36,172,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,89,78,1,78,3,78,67,78,93,78,134,78,140,78,186,78,63,81,101,81,107,81,224,81,0,82,1,82,155,82,21,83,65,83,92,83,200,83,9,78,11,78,8,78,10,78,43,78,56,78,225,81,69,78,72,78,95,78,94,78,142,78,161,78,64,81,3,82,250,82,67,83,201,83,227,83,31,87,235,88,21,89,39,89,115,89,80,91,81,91,83,91,248,91,15,92,34,92,56,92,113,92,221,93,229,93,241,93,242,93,243,93,254,93,114,94,254,94,11,95,19,95,77,98,17,78,16,78,13,78,45,78,48,78,57,78,75,78,57,92,136,78,145,78,149,78,146,78,148,78,162,78,193,78,192,78,195,78,198,78,199,78,205,78,202,78,203,78,196,78,67,81,65,81,103,81,109,81,110,81,108,81,151,81,246,81,6,82,7,82,8,82,251,82,254,82,255,82,22,83,57,83,72,83,71,83,69,83,94,83,132,83,203,83,202,83,205,83,236,88,41,89,43,89,42,89,45,89,84,91,17,92,36,92,58,92,111,92,244,93,123,94,255,94,20,95,21,95,195,95,8,98,54,98,75,98,78,98,47,101,135,101,151,101,164,101,185,101,229,101,240,102,8,103,40,103,32,107,98,107,121,107,203,107,212,107,219,107,15,108,52,108,107,112,42,114,54,114,59,114,71,114,89,114,91,114,172,114,139,115,25,78,22,78,21,78,20,78,24,78,59,78,77,78,79,78,78,78,229,78,216,78,212,78,213,78,214,78,215,78,227,78,228,78,217,78,222,78,69,81,68,81,137,81,138,81,172,81,249,81,250,81,248,81,10,82,160,82,159,82,5,83,6,83,23,83,29,83,223,78,74,83,73,83,97,83,96,83,111,83,110,83,187,83,239,83,228,83,243,83,236,83,238,83,233,83,232,83,252,83,248,83,245,83,235,83,230,83,234,83,242,83,241,83,240,83,229,83,237,83,251,83,219,86,218,86,22,89,46,89,49,89,116,89,118,89,85,91,131,91,60,92,232,93,231,93,230,93,2,94,3,94,115,94,124,94,1,95,24,95,23,95,197,95,10,98,83,98,84,98,82,98,81,98,165,101,230,101,46,103,44,103,42,103,43,103,45,103,99,107,205,107,17,108,16,108,56,108,65,108,64,108,62,108,175,114,132,115,137,115,220,116,230,116,24,117,31,117,40,117,41,117,48,117,49,117,50,117,51,117,139,117,125,118,174,118,191,118,238,118,219,119,226,119,243,119,58,121,190,121,116,122,203,122,30,78,31,78,82,78,83,78,105,78,153,78,164,78,166,78,165,78,255,78,9,79,25,79,10,79,21,79,13,79,16,79,17,79,15,79,242,78,246,78,251,78,240,78,243,78,253,78,1,79,11,79,73,81,71,81,70,81,72,81,104,81,113,81,141,81,176,81,23,82,17,82,18,82,14,82,22,82,163,82,8,83,33,83,32,83,112,83,113,83,9,84,15,84,12,84,10,84,16,84,1,84,11,84,4,84,17,84,13,84,8,84,3,84,14,84,6,84,18,84,224,86,222,86,221,86,51,87,48,87,40,87,45,87,44,87,47,87,41,87,25,89,26,89,55,89,56,89,132,89,120,89,131,89,125,89,121,89,130,89,129,89,87,91,88,91,135,91,136,91,133,91,137,91,250,91,22,92,121,92,222,93,6,94,118,94,116,94,15,95,27,95,217,95,214,95,14,98,12,98,13,98,16,98,99,98,91,98,88,98,54,101,233,101,232,101,236,101,237,101,242,102,243,102,9,103,61,103,52,103,49,103,53,103,33,107,100,107,123,107,22,108,93,108,87,108,89,108,95,108,96,108,80,108,85,108,97,108,91,108,77,108,78,108,112,112,95,114,93,114,126,118,249,122,115,124,248,124,54,127,138,127,189,127,1,128,3,128,12,128,18,128,51,128,127,128,137,128,139,128,140,128,227,129,234,129,243,129,252,129,12,130,27,130,31,130,110,130,114,130,126,130,107,134,64,136,76,136,99,136,127,137,33,150,50,78,168,78,77,79,79,79,71,79,87,79,94,79,52,79,91,79,85,79,48,79,80], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1916465);
/* memory initializer */ allocate([79,81,79,61,79,58,79,56,79,67,79,84,79,60,79,70,79,99,79,92,79,96,79,47,79,78,79,54,79,89,79,93,79,72,79,90,79,76,81,75,81,77,81,117,81,182,81,183,81,37,82,36,82,41,82,42,82,40,82,171,82,169,82,170,82,172,82,35,83,115,83,117,83,29,84,45,84,30,84,62,84,38,84,78,84,39,84,70,84,67,84,51,84,72,84,66,84,27,84,41,84,74,84,57,84,59,84,56,84,46,84,53,84,54,84,32,84,60,84,64,84,49,84,43,84,31,84,44,84,234,86,240,86,228,86,235,86,74,87,81,87,64,87,77,87,71,87,78,87,62,87,80,87,79,87,59,87,239,88,62,89,157,89,146,89,168,89,158,89,163,89,153,89,150,89,141,89,164,89,147,89,138,89,165,89,93,91,92,91,90,91,91,91,140,91,139,91,143,91,44,92,64,92,65,92,63,92,62,92,144,92,145,92,148,92,140,92,235,93,12,94,143,94,135,94,138,94,247,94,4,95,31,95,100,95,98,95,119,95,121,95,216,95,204,95,215,95,205,95,241,95,235,95,248,95,234,95,18,98,17,98,132,98,151,98,150,98,128,98,118,98,137,98,109,98,138,98,124,98,126,98,121,98,115,98,146,98,111,98,152,98,110,98,149,98,147,98,145,98,134,98,57,101,59,101,56,101,241,101,244,102,95,103,78,103,79,103,80,103,81,103,92,103,86,103,94,103,73,103,70,103,96,103,83,103,87,103,101,107,207,107,66,108,94,108,153,108,129,108,136,108,137,108,133,108,155,108,106,108,122,108,144,108,112,108,140,108,104,108,150,108,146,108,125,108,131,108,114,108,126,108,116,108,134,108,118,108,141,108,148,108,152,108,130,108,118,112,124,112,125,112,120,112,98,114,97,114,96,114,196,114,194,114,150,115,44,117,43,117,55,117,56,117,130,118,239,118,227,119,193,121,192,121,191,121,118,122,251,124,85,127,150,128,147,128,157,128,152,128,155,128,154,128,178,128,111,130,146,130,139,130,141,130,139,137,210,137,0,138,55,140,70,140,85,140,157,140,100,141,112,141,179,141,171,142,202,142,155,143,176,143,194,143,198,143,197,143,196,143,225,93,145,144,162,144,170,144,166,144,163,144,73,145,198,145,204,145,50,150,46,150,49,150,42,150,44,150,38,78,86,78,115,78,139,78,155,78,158,78,171,78,172,78,111,79,157,79,141,79,115,79,127,79,108,79,155,79,139,79,134,79,131,79,112,79,117,79,136,79,105,79,123,79,150,79,126,79,143,79,145,79,122,79,84,81,82,81,85,81,105,81,119,81,118,81,120,81,189,81,253,81,59,82,56,82,55,82,58,82,48,82,46,82,54,82,65,82,190,82,187,82,82,83,84,83,83,83,81,83,102,83,119,83,120,83,121,83,214,83,212,83,215,83,115,84,117,84,150,84,120,84,149,84,128,84,123,84,119,84,132,84,146,84,134,84,124,84,144,84,113,84,118,84,140,84,154,84,98,84,104,84,139,84,125,84,142,84,250,86,131,87,119,87,106,87,105,87,97,87,102,87,100,87,124,87,28,89,73,89,71,89,72,89,68,89,84,89,190,89,187,89,212,89,185,89,174,89,209,89,198,89,208,89,205,89,203,89,211,89,202,89,175,89,179,89,210,89,197,89,95,91,100,91,99,91,151,91,154,91,152,91,156,91,153,91,155,91,26,92,72,92,69,92,70,92,183,92,161,92,184,92,169,92,171,92,177,92,179,92,24,94,26,94,22,94,21,94,27,94,17,94,120,94,154,94,151,94,156,94,149,94,150,94,246,94,38,95,39,95,41,95,128,95,129,95,127,95,124,95,221,95,224,95,253,95,245,95,255,95,15,96,20,96,47,96,53,96,22,96,42,96,21,96,33,96,39,96,41,96,43,96,27,96,22,98,21,98,63,98,62,98,64,98,127,98,201,98,204,98,196,98,191,98,194,98,185,98,210,98,219,98,171,98,211,98,212,98,203,98,200,98,168,98,189,98,188,98,208,98,217,98,199,98,205,98,181,98,218,98,177,98,216,98,214,98,215,98,198,98,172,98,206,98,62,101,167,101,188,101,250,101,20,102,19,102,12,102,6,102,2,102,14,102,0,102,15,102,21,102,10,102,7,102,13,103,11,103,109,103,139,103,149,103,113,103,156,103,115,103,119,103,135,103,157,103,151,103,111,103,112,103,127,103,137,103,126,103,144,103,117,103,154,103,147,103,124,103,106,103,114,103,35,107,102,107,103,107,127,107,19,108,27,108,227,108,232,108,243,108,177,108,204,108,229,108,179,108,189,108,190,108,188,108,226,108,171,108,213,108,211,108,184,108,196,108,185,108,193,108,174,108,215,108,197,108,241,108,191,108,187,108,225,108,219,108,202,108,172,108,239,108,220,108,214,108,224,108,149,112,142,112,146,112,138,112,153,112,44,114,45,114,56,114,72,114,103,114,105,114,192,114,206,114,217,114,215,114,208,114,169,115,168,115,159,115,171,115,165,115,61,117,157,117,153,117,154,117,132,118,194,118,242,118,244,118,229,119,253,119,62,121,64,121,65,121,201,121,200,121,122,122,121,122,250,122,254,124,84,127,140,127,139,127,5,128,186,128,165,128,162,128,177,128,161,128,171,128,169,128,180,128,170,128,175,128,229,129,254,129,13,130,179,130,157,130,153,130,173,130,189,130,159,130,185,130,177,130,172,130,165,130,175,130,184,130,163,130,176,130,190,130,183,130,78,134,113,134,29,82,104,136,203,142,206,143,212,143,209,143,181,144,184,144,177,144,182,144,199,145,209,145,119,149,128,149,28,150,64,150,63,150,59,150,68,150,66,150,185,150,232,150,82,151,94,151,159,78,173,78,174,78,225,79,181,79,175,79,191,79,224,79,209,79,207,79,221,79,195,79,182,79,216,79,223,79,202,79,215,79,174,79,208,79,196,79,194,79,218,79,206,79,222,79,183,79,87,81,146,81,145,81,160,81,78,82,67,82,74,82,77,82,76,82,75,82,71,82,199,82,201,82,195,82,193,82,13,83,87,83,123,83,154,83,219,83,172,84,192,84,168,84,206,84,201,84,184,84,166,84,179,84,199,84,194,84,189,84,170,84,193,84,196,84,200,84,175,84,171,84,177,84,187,84,169,84,167,84,191,84,255,86,130,87,139,87,160,87,163,87,162,87,206,87,174,87,147,87,85,89,81,89,79,89,78,89,80,89,220,89,216,89,255,89,227,89,232,89,3,90,229,89,234,89,218,89,230,89,1,90,251,89,105,91,163,91,166,91,164,91,162,91,165,91,1,92,78,92,79,92,77,92,75,92,217,92,210,92,247,93,29,94,37,94,31,94,125,94,160,94,166,94,250,94,8,95,45,95,101,95,136,95,133,95,138,95,139,95,135,95,140,95,137,95,18,96,29,96,32,96,37,96,14,96,40,96,77,96,112,96,104,96,98,96,70,96,67,96,108,96,107,96,106,96,100,96,65,98,220,98,22,99,9,99,252,98,237,98,1,99,238,98,253,98,7,99,241,98,247,98,239,98,236,98,254,98,244,98,17,99,2,99,63,101,69,101,171,101,189,101,226,101,37,102,45,102,32,102,39,102,47,102,31,102,40,102,49,102,36,102,247,102,255,103,211,103,241,103,212,103,208,103,236,103,182,103,175,103,245,103,233,103,239,103,196,103,209,103,180,103,218,103,229,103,184,103,207,103,222,103,243,103,176,103,217,103,226,103,221,103,210,103,106,107,131,107,134,107,181,107,210,107,215,107,31,108,201,108,11,109,50,109,42,109,65,109,37,109,12,109,49,109,30,109,23,109,59,109,61,109,62,109,54,109,27,109,245,108,57,109,39,109,56,109,41,109,46,109,53,109,14,109,43,109,171,112,186,112,179,112,172,112,175,112,173,112,184,112,174,112,164,112,48,114,114,114,111,114,116,114,233,114,224,114,225,114,183,115,202,115,187,115,178,115,205,115,192,115,179,115,26,117,45,117,79,117,76,117,78,117,75,117,171,117,164,117,165,117,162,117,163,117,120,118,134,118,135,118,136,118,200,118,198,118,195,118,197,118,1,119,249,118,248,118,9,119,11,119,254,118,252,118,7,119,220,119,2,120,20,120,12,120,13,120,70,121,73,121,72,121,71,121,185,121,186,121,209,121,210,121,203,121,127,122,129,122,255,122,253,122,125,124,2,125,5,125,0,125,9,125,7,125,4,125,6,125,56,127,142,127,191,127,4,128,16,128,13,128,17,128,54,128,214,128,229,128,218,128,195,128,196,128,204,128,225,128,219,128,206,128,222,128,228,128,221,128,244,129,34,130,231,130,3,131,5,131,227,130,219,130,230,130,4,131,229,130,2,131,9,131,210,130,215,130,241,130,1,131,220,130,212,130,209,130,222,130,211,130,223,130,239,130,6,131,80,134,121,134,123,134,122,134,77,136,107,136,129,137,212,137,8,138,2,138,3,138,158,140,160,140,116,141,115,141,180,141,205,142,204,142,240,143,230,143,226,143,234,143,229,143,237,143,235,143,228,143,232,143,202,144,206,144,193,144,195,144,75,145,74,145,205,145,130,149,80,150,75,150,76,150,77,150,98,151,105,151,203,151,237,151,243,151,1,152,168,152,219,152,223,152,150,153,153,153,88,78,179,78,12,80,13,80,35,80,239,79,38,80,37,80,248,79,41,80,22,80,6,80,60,80,31,80,26,80,18,80,17,80,250,79,0,80,20,80,40,80,241,79,33,80,11,80,25,80,24,80,243,79,238,79,45,80,42,80,254,79,43,80,9,80,124,81,164,81,165,81,162,81,205,81,204,81,198,81,203,81,86,82,92,82,84,82,91,82,93,82,42,83,127,83,159,83,157,83,223,83,232,84,16,85,1,85,55,85,252,84,229,84,242,84,6,85,250,84,20,85,233,84,237,84,225,84,9,85,238,84,234,84,230,84,39,85,7,85,253,84,15,85,3,87,4,87,194,87,212,87,203,87,195,87,9,88,15,89,87,89,88,89,90,89,17,90,24,90,28,90,31,90,27,90,19,90,236,89,32,90,35,90,41,90,37,90,12,90,9,90,107,91,88,92,176,91,179,91,182,91,180,91,174,91,181,91,185,91,184,91,4,92,81,92,85,92,80,92,237,92,253,92,251,92,234,92,232,92,240,92,246,92,1,93,244,92,238,93,45,94,43,94,171,94,173,94,167,94,49,95,146,95,145,95,144,95,89,96,99,96,101,96,80,96,85,96,109,96,105,96,111,96,132,96,159,96,154,96,141,96,148,96,140,96,133,96,150,96,71,98,243,98,8,99,255,98,78,99,62,99,47,99,85,99,66,99,70,99,79,99,73,99,58,99,80,99,61,99,42,99,43,99,40,99,77,99,76,99,72,101,73,101,153,101,193,101,197,101,66,102,73,102,79,102,67,102,82,102,76,102,69,102,65,102,248,102,20,103,21,103,23,103,33,104,56,104,72,104,70,104,83,104,57,104,66,104,84,104,41,104,179,104,23,104,76,104,81,104,61,104,244,103,80,104,64,104,60,104,67,104,42,104,69,104,19,104,24,104,65,104,138,107,137,107,183,107,35,108,39,108,40,108,38,108,36,108,240,108,106,109,149,109,136,109,135,109,102,109,120,109,119,109,89,109,147,109,108,109,137,109,110,109,90,109,116,109,105,109,140,109,138,109,121,109,133,109,101,109,148,109,202,112,216,112,228,112,217,112,200,112,207,112,57,114,121,114,252,114,249,114,253,114,248,114,247,114,134,115,237,115,9,116,238,115,224,115,234,115,222,115,84,117,93,117,92,117,90,117,89,117,190,117,197,117,199,117,178,117,179,117,189,117,188,117,185,117,194,117,184,117,139,118,176,118,202,118,205,118,206,118,41,119,31,119,32,119,40,119,233,119,48,120,39,120,56,120,29,120,52,120,55,120,37,120,45,120,32,120,31,120,50,120,85,121,80,121,96,121,95,121,86,121,94,121,93,121,87,121,90,121,228,121,227,121,231,121,223,121,230,121,233,121,216,121,132,122,136,122,217,122,6,123,17,123,137,124,33,125,23,125,11,125,10,125,32,125,34,125,20,125,16,125,21,125,26,125,28,125,13,125,25,125,27,125,58,127,95,127,148,127,197,127,193,127,6,128,24,128,21,128,25,128,23,128,61,128,63,128,241,128,2,129,240,128,5,129,237,128,244,128,6,129,248,128,243,128,8,129,253,128,10,129,252,128,239,128,237,129,236,129,0,130,16,130,42,130,43,130,40,130,44,130,187,130,43,131,82,131,84,131,74,131,56,131,80,131,73,131,53,131,52,131,79,131,50,131,57,131,54,131,23,131,64,131,49,131,40,131,67,131,84,134,138,134,170,134,147,134,164,134,169,134,140,134,163,134,156,134,112,136,119,136,129,136,130,136,125,136,121,136,24,138,16,138,14,138,12,138,21,138,10,138,23,138,19,138,22,138,15,138,17,138,72,140,122,140,121,140,161,140,162,140,119,141,172,142,210,142,212,142,207,142,177,143,1,144,6,144,247,143,0,144,250,143,244,143,3,144,253,143,5,144,248,143,149,144,225,144,221,144,226,144,82,145,77,145,76,145,216,145,221,145,215,145,220,145,217,145,131,149,98,150,99,150,97,150,91,150,93,150,100,150,88,150,94,150,187,150,226,152,172,153,168,154,216,154,37,155,50,155,60,155,126,78,122,80,125,80,92,80,71,80,67,80,76,80,90,80,73,80,101,80,118,80,78,80,85,80,117,80,116,80,119,80,79,80,15,80,111,80,109,80,92,81,149,81,240,81,106,82,111,82,210,82,217,82,216,82,213,82,16,83,15,83,25,83,63,83,64,83,62,83,195,83,252,102,70,85,106,85,102,85,68,85,94,85,97,85,67,85,74,85,49,85,86,85,79,85,85,85,47,85,100,85,56,85,46,85,92,85,44,85,99,85,51,85,65,85,87,85,8,87,11,87,9,87,223,87,5,88,10,88,6,88,224,87,228,87,250,87,2,88,53,88,247,87,249,87,32,89,98,89,54,90,65,90,73,90,102,90,106,90,64,90,60,90,98,90,90,90,70,90,74,90,112,91,199,91,197,91,196,91,194,91,191,91,198,91,9,92,8,92,7,92,96,92,92,92,93,92,7,93,6,93,14,93,27,93,22,93,34,93,17,93,41,93,20,93,25,93,36,93,39,93,23,93,226,93,56,94,54,94,51,94,55,94,183,94,184,94,182,94,181,94,190,94,53,95,55,95,87,95,108,95,105,95,107,95,151,95,153,95,158,95,152,95,161,95,160,95,156,95,127,96,163,96,137,96,160,96,168,96,203,96,180,96,230,96,189,96,197,96,187,96,181,96,220,96,188,96,216,96,213,96,198,96,223,96,184,96,218,96,199,96,26,98,27,98,72,98,160,99,167,99,114,99,150,99,162,99,165,99,119,99,103,99,152,99,170,99,113,99,169,99,137,99,131,99,155,99,107,99,168,99,132,99,136,99,153,99,161,99,172,99,146,99,143,99,128,99,123,99,105,99,104,99,122,99,93,101,86,101,81,101,89,101,87,101,95,85,79,101,88,101,85,101,84,101,156,101,155,101,172,101,207,101,203,101,204,101,206,101,93,102,90,102,100,102,104,102,102,102,94,102,249,102,215,82,27,103,129,104,175,104,162,104,147,104,181,104,127,104,118,104,177,104,167,104,151,104,176,104,131,104,196,104,173,104,134,104,133,104,148,104,157,104,168,104,159,104,161,104,130,104,50,107,186,107,235,107,236,107,43,108,142,109,188,109,243,109,217,109,178,109,225,109,204,109,228,109,251,109,250,109,5,110,199,109,203,109,175,109,209,109,174,109,222,109,249,109,184,109,247,109,245,109,197,109,210,109,26,110,181,109,218,109,235,109,216,109,234,109,241,109,238,109,232,109,198,109,196,109,170,109,236,109,191,109,230,109,249,112,9,113,10,113,253,112,239,112,61,114,125,114,129,114,28,115,27,115,22,115,19,115,25,115,135,115,5,116,10,116,3,116,6,116,254,115,13,116,224,116,246,116,247,116,28,117,34,117,101,117,102,117,98,117,112,117,143,117,212,117,213,117,181,117,202,117,205,117,142,118,212,118,210,118,219,118,55,119,62,119,60,119,54,119,56,119,58,119,107,120,67,120,78,120,101,121,104,121,109,121,251,121,146,122,149,122,32,123,40,123,27,123,44,123,38,123,25,123,30,123,46,123,146,124,151,124,149,124,70,125,67,125,113,125,46,125,57,125,60,125,64,125,48,125,51,125,68,125,47,125,66,125,50,125,49,125,61,127,158,127,154,127,204,127,206,127,210,127,28,128,74,128,70,128,47,129,22,129,35,129,43,129,41,129,48,129,36,129,2,130,53,130,55,130,54,130,57,130,142,131,158,131,152,131,120,131,162,131,150,131,189,131,171,131,146,131,138,131,147,131,137,131,160,131,119,131,123,131,124,131,134,131,167,131,85,134,106,95,199,134,192,134,182,134,196,134,181,134,198,134,203,134,177,134,175,134,201,134,83,136,158,136,136,136,171,136,146,136,150,136,141,136,139,136,147,137,143,137,42,138,29,138,35,138,37,138,49,138,45,138,31,138,27,138,34,138,73,140,90,140,169,140,172,140,171,140,168,140,170,140,167,140,103,141,102,141,190,141,186,141,219,142,223,142,25,144,13,144,26,144,23,144,35,144,31,144,29,144,16,144,21,144,30,144,32,144,15,144,34,144,22,144,27,144,20,144,232,144,237,144,253,144,87,145,206,145,245,145,230,145,227,145,231,145,237,145,233,145,137,149,106,150,117,150,115,150,120,150,112,150,116,150,118,150,119,150,108,150,192,150,234,150,233,150,224,122,223,122,2,152,3,152,90,155,229,156,117,158,127,158,165,158,187,158,162,80,141,80,133,80,153,80,145,80,128,80,150,80,152,80,154,80,0,103,241,81,114,82,116,82,117,82,105,82,222,82,221,82,219,82,90,83,165,83,123,85,128,85,167,85,124,85,138,85,157,85,152,85,130,85,156,85,170,85,148,85,135,85,139,85,131,85,179,85,174,85,159,85,62,85,178,85,154,85,187,85,172,85,177,85,126,85,137,85,171,85,153,85,13,87,47,88,42,88,52,88,36,88,48,88,49,88,33,88,29,88,32,88,249,88,250,88,96,89,119,90,154,90,127,90,146,90,155,90,167,90,115,91,113,91,210,91,204,91,211,91,208,91,10,92,11,92,49,92,76,93,80,93,52,93,71,93,253,93,69,94,61,94,64,94,67,94,126,94,202,94,193,94,194,94,196,94,60,95,109,95,169,95,170,95,168,95,209,96,225,96,178,96,182,96,224,96,28,97,35,97,250,96,21,97,240,96,251,96,244,96,104,97,241,96,14,97,246,96,9,97,0,97,18,97,31,98,73,98,163,99,140,99,207,99,192,99,233,99,201,99,198,99,205,99,210,99,227,99,208,99,225,99,214,99,237,99,238,99,118,99,244,99,234,99,219,99,82,100,218,99,249,99,94,101,102,101,98,101,99,101,145,101,144,101,175,101,110,102,112,102,116,102,118,102,111,102,145,102,122,102,126,102,119,102,254,102,255,102,31,103,29,103,250,104,213,104,224,104,216,104,215,104,5,105,223,104,245,104,238,104,231,104,249,104,210,104,242,104,227,104,203,104,205,104,13,105,18,105,14,105,201,104,218,104,110,105,251,104,62,107,58,107,61,107,152,107,150,107,188,107,239,107,46,108,47,108,44,108,47,110,56,110,84,110,33,110,50,110,103,110,74,110,32,110,37,110,35,110,27,110,91,110,88,110,36,110,86,110,110,110,45,110,38,110,111,110,52,110,77,110,58,110,44,110,67,110,29,110,62,110,203,110,137,110,25,110,78,110,99,110,68,110,114,110,105,110,95,110,25,113,26,113,38,113,48,113,33,113,54,113,110,113,28,113,76,114,132,114,128,114,54,115,37,115,52,115,41,115,58,116,42,116,51,116,34,116,37,116,53,116,54,116,52,116,47,116,27,116,38,116,40,116,37,117,38,117,107,117,106,117,226,117,219,117,227,117,217,117,216,117,222,117,224,117,123,118,124,118,150,118,147,118,180,118,220,118,79,119,237,119,93,120,108,120,111,120,13,122,8,122,11,122,5,122,0,122,152,122,151,122,150,122,229,122,227,122,73,123,86,123,70,123,80,123,82,123,84,123,77,123,75,123,79,123,81,123,159,124,165,124,94,125,80,125,104,125,85,125,43,125,110,125,114,125,97,125,102,125,98,125,112,125,115,125,132,85,212,127,213,127,11,128,82,128,133,128,85,129,84,129,75,129,81,129,78,129,57,129,70,129,62,129,76,129,83,129,116,129,18,130,28,130,233,131,3,132,248,131,13,132,224,131,197,131,11,132,193,131,239,131,241,131,244,131,87,132,10,132,240,131,12,132,204,131,253,131,242,131,202,131,56,132,14,132,4,132,220,131,7,132,212,131,223,131,91,134,223,134,217,134,237,134,212,134,219,134,228,134,208,134,222,134,87,136,193,136,194,136,177,136,131,137,150,137,59,138,96,138,85,138,94,138,60,138,65,138,84,138,91,138,80,138,70,138,52,138,58,138,54,138,86,138,97,140,130,140,175,140,188,140,179,140,189,140,193,140,187,140,192,140,180,140,183,140,182,140,191,140,184,140,138,141,133,141,129,141,206,141,221,141,203,141,218,141,209,141,204,141,219,141,198,141,251,142,248,142,252,142,156,143,46,144,53,144,49,144,56,144,50,144,54,144,2,145,245,144,9,145,254,144,99,145,101,145,207,145,20,146,21,146,35,146,9,146,30,146,13,146,16,146,7,146,17,146,148,149,143,149,139,149,145,149,147,149,146,149,142,149,138,150,142,150,139,150,125,150,133,150,134,150,141,150,114,150,132,150,193,150,197,150,196,150,198,150,199,150,239,150,242,150,204,151,5,152,6,152,8,152,231,152,234,152,239,152,233,152,242,152,237,152,174,153,173,153,195,158,205,158,209,158,130,78,173,80,181,80,178,80,179,80,197,80,190,80,172,80,183,80,187,80,175,80,199,80,127,82,119,82,125,82,223,82,230,82,228,82,226,82,227,82,47,83,223,85,232,85,211,85,230,85,206,85,220,85,199,85,209,85,227,85,228,85,239,85,218,85,225,85,197,85,198,85,229,85,201,85,18,87,19,87,94,88,81,88,88,88,87,88,90,88,84,88,107,88,76,88,109,88,74,88,98,88,82,88,75,88,103,89,193,90,201,90,204,90,190,90,189,90,188,90,179,90,194,90,178,90,105,93,111,93,76,94,121,94,201,94,200,94,18,95,89,95,172,95,174,95,26,97,15,97,72,97,31,97,243,96,27,97,249,96,1,97,8,97,78,97,76,97,68,97,77,97,62,97,52,97,39,97,13,97,6,97,55,97,33,98,34,98,19,100,62,100,30,100,42,100,45,100,61,100,44,100,15,100,28,100,20,100,13,100,54,100,22,100,23,100,6,100,108,101,159,101,176,101,151,102,137,102,135,102,136,102,150,102,132,102,152,102,141,102,3,103,148,105,109,105,90,105,119,105,96,105,84,105,117,105,48,105,130,105,74,105,104,105,107,105,94,105,83,105,121,105,134,105,93,105,99,105,91,105,71,107,114,107,192,107,191,107,211,107,253,107,162,110,175,110,211,110,182,110,194,110,144,110,157,110,199,110,197,110,165,110,152,110,188,110,186,110,171,110,209,110,150,110,156,110,196,110,212,110,170,110,167,110,180,110,78,113,89,113,105,113,100,113,73,113,103,113,92,113,108,113,102,113,76,113,101,113,94,113,70,113,104,113,86,113,58,114,82,114,55,115,69,115,63,115,62,115,111,116,90,116,85,116,95,116,94,116,65,116,63,116,89,116,91,116,92,116,118,117,120,117,0,118,240,117,1,118,242,117,241,117,250,117,255,117,244,117,243,117,222,118,223,118,91,119,107,119,102,119,94,119,99,119,121,119,106,119,108,119,92,119,101,119,104,119,98,119,238,119,142,120,176,120,151,120,152,120,140,120,137,120,124,120,145,120,147,120,127,120,122,121,127,121,129,121,44,132,189,121,28,122,26,122,32,122,20,122,31,122,30,122,159,122,160,122,119,123,192,123,96,123,110,123,103,123,177,124,179,124,181,124,147,125,121,125,145,125,129,125,143,125,91,125,110,127,105,127,106,127,114,127,169,127,168,127,164,127,86,128,88,128,134,128,132,128,113,129,112,129,120,129,101,129,110,129,115,129,107,129,121,129,122,129,102,129,5,130,71,130,130,132,119,132,61,132,49,132,117,132,102,132,107,132,73,132,108,132,91,132,60,132,53,132,97,132,99,132,105,132,109,132,70,132,94,134,92,134,95,134,249,134,19,135,8,135,7,135,0,135,254,134,251,134,2,135,3,135,6,135,10,135,89,136,223,136,212,136,217,136,220,136,216,136,221,136,225,136,202,136,213,136,210,136,156,137,227,137,107,138,114,138,115,138,102,138,105,138,112,138,135,138,124,138,99,138,160,138,113,138,133,138,109,138,98,138,110,138,108,138,121,138,123,138,62,138,104,138,98,140,138,140,137,140,202,140,199,140,200,140,196,140,178,140,195,140,194,140,197,140,225,141,223,141,232,141,239,141,243,141,250,141,234,141,228,141,230,141,178,142,3,143,9,143,254,142,10,143,159,143,178,143,75,144,74,144,83,144,66,144,84,144,60,144,85,144,80,144,71,144,79,144,78,144,77,144,81,144,62,144,65,144,18,145,23,145,108,145,106,145,105,145,201,145,55,146,87,146,56,146,61,146,64,146,62,146,91,146,75,146,100,146,81,146,52,146,73,146,77,146,69,146,57,146,63,146,90,146,152,149,152,150,148,150,149,150,205,150,203,150,201,150,202,150,247,150,251,150,249,150,246,150,86,151,116,151,118,151,16,152,17,152,19,152,10,152,18,152,12,152,252,152,244,152,253,152,254,152,179,153,177,153,180,153,225,154,233,156,130,158,14,159,19,159,32,159,231,80,238,80,229,80,214,80,237,80,218,80,213,80,207,80,209,80,241,80,206,80,233,80,98,81,243,81,131,82,130,82,49,83,173,83,254,85,0,86,27,86,23,86,253,85,20,86,6,86,9,86,13,86,14,86,247,85,22,86,31,86,8,86,16,86,246,85,24,87,22,87,117,88,126,88,131,88,147,88,138,88,121,88,133,88,125,88,253,88,37,89,34,89,36,89,106,89,105,89,225,90,230,90,233,90,215,90,214,90,216,90,227,90,117,91,222,91,231,91,225,91,229,91,230,91,232,91,226,91,228,91,223,91,13,92,98,92,132,93,135,93,91,94,99,94,85,94,87,94,84,94,211,94,214,94,10,95,70,95,112,95,185,95,71,97,63,97,75,97,119,97,98,97,99,97,95,97,90,97,88,97,117,97,42,98,135,100,88,100,84,100,164,100,120,100,95,100,122,100,81,100,103,100,52,100,109,100,123,100,114,101,161,101,215,101,214,101,162,102,168,102,157,102,156,105,168,105,149,105,193,105,174,105,211,105,203,105,155,105,183,105,187,105,171,105,180,105,208,105,205,105,173,105,204,105,166,105,195,105,163,105,73,107,76,107,51,108,51,111,20,111,254,110,19,111,244,110,41,111,62,111,32,111,44,111,15,111,2,111,34,111,255,110,239,110,6,111,49,111,56,111,50,111,35,111,21,111,43,111,47,111,136,111,42,111,236,110,1,111,242,110,204,110,247,110,148,113,153,113,125,113,138,113,132,113,146,113,62,114,146,114,150,114,68,115,80,115,100,116,99,116,106,116,112,116,109,116,4,117,145,117,39,118,13,118,11,118,9,118,19,118,225,118,227,118,132,119,125,119,127,119,97,119,193,120,159,120,167,120,179,120,169,120,163,120,142,121,143,121,141,121,46,122,49,122,170,122,169,122,237,122,239,122,161,123,149,123,139,123,117,123,151,123,157,123,148,123,143,123,184,123,135,123,132,123,185,124,189,124,190,124,187,125,176,125,156,125,189,125,190,125,160,125,202,125,180,125,178,125,177,125,186,125,162,125,191,125,181,125,184,125,173,125,210,125,199,125,172,125,112,127,224,127,225,127,223,127,94,128,90,128,135,128,80,129,128,129,143,129,136,129,138,129,127,129,130,129,231,129,250,129,7,130,20,130,30,130,75,130,201,132,191,132,198,132,196,132,153,132,158,132,178,132,156,132,203,132,184,132,192,132,211,132,144,132,188,132,209,132,202,132,63,135,28,135,59,135,34,135,37,135,52,135,24,135,85,135,55,135,41,135,243,136,2,137,244,136,249,136,248,136,253,136,232,136,26,137,239,136,166,138,140,138,158,138,163,138,141,138,161,138,147,138,164,138,170,138,165,138,168,138,152,138,145,138,154,138,167,138,106,140,141,140,140,140,211,140,209,140,210,140,107,141,153,141,149,141,252,141,20,143,18,143,21,143,19,143,163,143,96,144,88,144,92,144,99,144,89,144,94,144,98,144,93,144,91,144,25,145,24,145,30,145,117,145,120,145,119,145,116,145,120,146,128,146,133,146,152,146,150,146,123,146,147,146,156,146,168,146,124,146,145,146,161,149,168,149,169,149,163,149,165,149,164,149,153,150,156,150,155,150,204,150,210,150,0,151,124,151,133,151,246,151,23,152,24,152,175,152,177,152,3,153,5,153,12,153,9,153,193,153,175,154,176,154,230,154,65,155,66,155,244,156,246,156,243,156,188,158,59,159,74,159,4,81,0,81,251,80,245,80,249,80,2,81,8,81,9,81,5,81,220,81,135,82,136,82,137,82,141,82,138,82,240,82,178,83,46,86,59,86,57,86,50,86,63,86,52,86,41,86,83,86,78,86,87,86,116,86,54,86,47,86,48,86,128,88,159,88,158,88,179,88,156,88,174,88,169,88,166,88,109,89,9,91,251,90,11,91,245,90,12,91,8,91,238,91,236,91,233,91,235,91,100,92,101,92,157,93,148,93,98,94,95,94,97,94,226,94,218,94,223,94,221,94,227,94,224,94,72,95,113,95,183,95,181,95,118,97,103,97,110,97,93,97,85,97,130,97,124,97,112,97,107,97,126,97,167,97,144,97,171,97,142,97,172,97,154,97,164,97,148,97,174,97,46,98,105,100,111,100,121,100,158,100,178,100,136,100,144,100,176,100,165,100,147,100,149,100,169,100,146,100,174,100,173,100,171,100,154,100,172,100,153,100,162,100,179,100,117,101,119,101,120,101,174,102,171,102,180,102,177,102,35,106,31,106,232,105,1,106,30,106,25,106,253,105,33,106,19,106,10,106,243,105,2,106,5,106,237,105,17,106,80,107,78,107,164,107,197,107,198,107,63,111,124,111,132,111,81,111,102,111,84,111,134,111,109,111,91,111,120,111,110,111,142,111,122,111,112,111,100,111,151,111,88,111,213,110,111,111,96,111,95,111,159,113,172,113,177,113,168,113,86,114,155,114,78,115,87,115,105,116,139,116,131,116,126,116,128,116,127,117,32,118,41,118,31,118,36,118,38,118,33,118,34,118,154,118,186,118,228,118,142,119,135,119,140,119,145,119,139,119,203,120,197,120,186,120,202,120,190,120,213,120,188,120,208,120,63,122,60,122,64,122,61,122,55,122,59,122,175,122,174,122,173,123,177,123,196,123,180,123,198,123,199,123,193,123,160,123,204,123,202,124,224,125,244,125,239,125,251,125,216,125,236,125,221,125,232,125,227,125,218,125,222,125,233,125,158,125,217,125,242,125,249,125,117,127,119,127,175,127,233,127,38,128,155,129,156,129,157,129,160,129,154,129,152,129,23,133,61,133,26,133,238,132,44,133,45,133,19,133,17,133,35,133,33,133,20,133,236,132,37,133,255,132,6,133,130,135,116,135,118,135,96,135,102,135,120,135,104,135,89,135,87,135,76,135,83,135,91,136,93,136,16,137,7,137,18,137,19,137,21,137,10,137,188,138,210,138,199,138,196,138,149,138,203,138,248,138,178,138,201,138,194,138,191,138,176,138,214,138,205,138,182,138,185,138,219,138,76,140,78,140,108,140,224,140,222,140,230,140,228,140,236,140,237,140,226,140,227,140,220,140,234,140,225,140,109,141,159,141,163,141,43,142,16,142,29,142,34,142,15,142,41,142,31,142,33,142,30,142,186,142,29,143,27,143,31,143,41,143,38,143,42,143,28,143,30,143,37,143,105,144,110,144,104,144,109,144,119,144,48,145,45,145,39,145,49,145,135,145,137,145,139,145,131,145,197,146,187,146,183,146,234,146,172,146,228,146,193,146,179,146,188,146,210,146,199,146,240,146,178,146,173,149,177,149,4,151,6,151,7,151,9,151,96,151,141,151,139,151,143,151,33,152,43,152,28,152,179,152,10,153,19,153,18,153,24,153,221,153,208,153,223,153,219,153,209,153,213,153,210,153,217,153,183,154,238,154,239,154,39,155,69,155,68,155,119,155,111,155,6,157,9,157,3,157,169,158,190,158,206,158,168,88,82,159,18,81,24,81,20,81,16,81,21,81,128,81,170,81,221,81,145,82,147,82,243,82,89,86,107,86,121,86,105,86,100,86,120,86,106,86,104,86,101,86,113,86,111,86,108,86,98,86,118,86,193,88,190,88,199,88,197,88,110,89,29,91,52,91,120,91,240,91,14,92,74,95,178,97,145,97,169,97,138,97,205,97,182,97,190,97,202,97,200,97,48,98,197,100,193,100,203,100,187,100,188,100,218,100,196,100,199,100,194,100,205,100,191,100,210,100,212,100,190,100,116,101,198,102,201,102,185,102,196,102,199,102,184,102,61,106,56,106,58,106,89,106,107,106,88,106,57,106,68,106,98,106,97,106,75,106,71,106,53,106,95,106,72,106,89,107,119,107,5,108,194,111,177,111,161,111,195,111,164,111,193,111,167,111,179,111,192,111,185,111,182,111,166,111,160,111,180,111,190,113,201,113,208,113,210,113,200,113,213,113,185,113,206,113,217,113,220,113,195,113,196,113,104,115,156,116,163,116,152,116,159,116,158,116,226,116,12,117,13,117,52,118,56,118,58,118,231,118,229,118,160,119,158,119,159,119,165,119,232,120,218,120,236,120,231,120,166,121,77,122,78,122,70,122,76,122,75,122,186,122,217,123,17,124,201,123,228,123,219,123,225,123,233,123,230,123,213,124,214,124,10,126,17,126,8,126,27,126,35,126,30,126,29,126,9,126,16,126,121,127,178,127,240,127,241,127,238,127,40,128,179,129,169,129,168,129,251,129,8,130,88,130,89,130,74,133,89,133,72,133,104,133,105,133,67,133,73,133,109,133,106,133,94,133,131,135,159,135,158,135,162,135,141,135,97,136,42,137,50,137,37,137,43,137,33,137,170,137,166,137,230,138,250,138,235,138,241,138,0,139,220,138,231,138,238,138,254,138,1,139,2,139,247,138,237,138,243,138,246,138,252,138,107,140,109,140,147,140,244,140,68,142,49,142,52,142,66,142,57,142,53,142,59,143,47,143,56,143,51,143,168,143,166,143,117,144,116,144,120,144,114,144,124,144,122,144,52,145,146,145,32,147,54,147,248,146,51,147,47,147,34,147,252,146,43,147,4,147,26,147,16,147,38,147,33,147,21,147,46,147,25,147,187,149,167,150,168,150,170,150,213,150,14,151,17,151,22,151,13,151,19,151,15,151,91,151,92,151,102,151,152,151,48,152,56,152,59,152,55,152,45,152,57,152,36,152,16,153,40,153,30,153,27,153,33,153,26,153,237,153,226,153,241,153,184,154,188,154,251,154,237,154,40,155,145,155,21,157,35,157,38,157,40,157,18,157,27,157,216,158,212,158,141,159,156,159,42,81,31,81,33,81,50,81,245,82,142,86,128,86,144,86,133,86,135,86,143,86,213,88,211,88,209,88,206,88,48,91,42,91,36,91,122,91,55,92,104,92,188,93,186,93,189,93,184,93,107,94,76,95,189,95,201,97,194,97,199,97,230,97,203,97,50,98,52,98,206,100,202,100,216,100,224,100,240,100,230,100,236,100,241,100,226,100,237,100,130,101,131,101,217,102,214,102,128,106,148,106,132,106,162,106,156,106,219,106,163,106,126,106,151,106,144,106,160,106,92,107,174,107,218,107,8,108,216,111,241,111,223,111,224,111,219,111,228,111,235,111,239,111,128,111,236,111,225,111,233,111,213,111,238,111,240,111,231,113,223,113,238,113,230,113,229,113,237,113,236,113,244,113,224,113,53,114,70,114,112,115,114,115,169,116,176,116,166,116,168,116,70,118,66,118,76,118,234,118,179,119,170,119,176,119,172,119,167,119,173,119,239,119,247,120,250,120,244,120,239,120,1,121,167,121,170,121,87,122,191,122,7,124,13,124,254,123,247,123,12,124,224,123,224,124,220,124,222,124,226,124,223,124,217,124,221,124,46,126,62,126,70,126,55,126,50,126,67,126,43,126,61,126,49,126,69,126,65,126,52,126,57,126,72,126,53,126,63,126,47,126,68,127,243,127,252,127,113,128,114,128,112,128,111,128,115,128,198,129,195,129,186,129,194,129,192,129,191,129,189,129,201,129,190,129,232,129,9,130,113,130,170,133,132,133,126,133,156,133,145,133,148,133,175,133,155,133,135,133,168,133,138,133,103,134,192,135,209,135,179,135,210,135,198,135,171,135,187,135,186,135,200,135,203,135,59,137,54,137,68,137,56,137,61,137,172,137,14,139,23,139,25,139,27,139,10,139,32,139,29,139,4,139,16,139,65,140,63,140,115,140,250,140,253,140,252,140,248,140,251,140,168,141,73,142,75,142,72,142,74,142,68,143,62,143,66,143,69,143,63,143,127,144,125,144,132,144,129,144,130,144,128,144,57,145,163,145,158,145,156,145,77,147,130,147,40,147,117,147,74,147,101,147,75,147,24,147,126,147,108,147,91,147,112,147,90,147,84,147,202,149,203,149,204,149,200,149,198,149,177,150,184,150,214,150,28,151,30,151,160,151,211,151,70,152,182,152,53,153,1,154,255,153,174,155,171,155,170,155,173,155,59,157,63,157,139,158,207,158,222,158,220,158,221,158,219,158,62,159,75,159,226,83,149,86,174,86,217,88,216,88,56,91,93,95,227,97,51,98,244,100,242,100,254,100,6,101,250,100,251,100,247,100,183,101,220,102,38,103,179,106,172,106,195,106,187,106,184,106,194,106,174,106,175,106,95,107,120,107,175,107,9,112,11,112,254,111,6,112,250,111,17,112,15,112,251,113,252,113,254,113,248,113,119,115,117,115,167,116,191,116,21,117,86,118,88,118,82,118,189,119,191,119,187,119,188,119,14,121,174,121,97,122,98,122,96,122,196,122,197,122,43,124,39,124,42,124,30,124,35,124,33,124,231,124,84,126,85,126,94,126,90,126,97,126,82,126,89,126,72,127,249,127,251,127,119,128,118,128,205,129,207,129,10,130,207,133,169,133,205,133,208,133,201,133,176,133,186,133,185,133,166,133,239,135,236,135,242,135,224,135,134,137,178,137,244,137,40,139,57,139,44,139,43,139,80,140,5,141,89,142,99,142,102,142,100,142,95,142,85,142,192,142,73,143,77,143,135,144,131,144,136,144,171,145,172,145,208,145,148,147,138,147,150,147,162,147,179,147,174,147,172,147,176,147,152,147,154,147,151,147,212,149,214,149,208,149,213,149,226,150,220,150,217,150,219,150,222,150,36,151,163,151,166,151,173,151,249,151,77,152,79,152,76,152,78,152,83,152,186,152,62,153,63,153,61,153,46,153,165,153,14,154,193,154,3,155,6,155,79,155,78,155,77,155,202,155,201,155,253,155,200,155,192,155,81,157,93,157,96,157,224,158,21,159,44,159,51,81,165,86,222,88,223,88,226,88,245,91,144,159,236,94,242,97,247,97,246,97,245,97,0,101,15,101,224,102,221,102,229,106,221,106,218,106,211,106,27,112,31,112,40,112,26,112,29,112,21,112,24,112,6,114,13,114,88,114,162,114,120,115,122,115,189,116,202,116,227,116,135,117,134,117,95,118,97,118,199,119,25,121,177,121,107,122,105,122,62,124,63,124,56,124,61,124,55,124,64,124,107,126,109,126,121,126,105,126,106,126,133,127,115,126,182,127,185,127,184,127,216,129,233,133,221,133,234,133,213,133,228,133,229,133,247,133,251,135,5,136,13,136,249,135,254,135,96,137,95,137,86,137,94,137,65,139,92,139,88,139,73,139,90,139,78,139,79,139,70,139,89,139,8,141,10,141,124,142,114,142,135,142,118,142,108,142,122,142,116,142,84,143,78,143,173,143,138,144,139,144,177,145,174,145,225,147,209,147,223,147,195,147,200,147,220,147,221,147,214,147,226,147,205,147,216,147,228,147,215,147,232,147,220,149,180,150,227,150,42,151,39,151,97,151,220,151,251,151,94,152,88,152,91,152,188,152,69,153,73,153,22,154,25,154,13,155,232,155,231,155,214,155,219,155,137,157,97,157,114,157,106,157,108,157,146,158,151,158,147,158,180,158,248,82,168,86,183,86,182,86,180,86,188,86,228,88,64,91,67,91,125,91,246,91,201,93,248,97,250,97,24,101,20,101,25,101,230,102,39,103,236,106,62,112,48,112,50,112,16,114,123,115,207,116,98,118,101,118,38,121,42,121,44,121,43,121,199,122,246,122,76,124,67,124,77,124,239,124,240,124,174,143,125,126,124,126,130,126,76,127,0,128,218,129,102,130,251,133,249,133,17,134,250,133,6,134,11,134,7,134,10,134,20,136,21,136,100,137,186,137,248,137,112,139,108,139,102,139,111,139,95,139,107,139,15,141,13,141,137,142,129,142,133,142,130,142,180,145,203,145,24,148,3,148,253,147,225,149,48,151,196,152,82,153,81,153,168,153,43,154,48,154,55,154,53,154,19,156,13,156,121,158,181,158,232,158,47,159,95,159,99,159,97,159,55,81,56,81,193,86,192,86,194,86,20,89,108,92,205,93,252,97,254,97,29,101,28,101,149,101,233,102,251,106,4,107,250,106,178,107,76,112,27,114,167,114,214,116,212,116,105,118,211,119,80,124,143,126,140,126,188,127,23,134,45,134,26,134,35,136,34,136,33,136,31,136,106,137,108,137,189,137,116,139,119,139,125,139,19,141,138,142,141,142,139,142,95,143,175,143,186,145,46,148,51,148,53,148,58,148,56,148,50,148,43,148,226,149,56,151,57,151,50,151,255,151,103,152,101,152,87,153,69,154,67,154,64,154,62,154,207,154,84,155,81,155,45,156,37,156,175,157,180,157,194,157,184,157,157,158,239,158,25,159,92,159,102,159,103,159,60,81,59,81,200,86,202,86,201,86,127,91,212,93,210,93,78,95,255,97,36,101,10,107,97,107,81,112,88,112,128,115,228,116,138,117,110,118,108,118,179,121,96,124,95,124,126,128,125,128,223,129,114,137,111,137,252,137,128,139,22,141,23,141,145,142,147,142,97,143,72,145,68,148,81,148,82,148,61,151,62,151,195,151,193,151,107,152,85,153,85,154,77,154,210,154,26,155,73,156,49,156,62,156,59,156,211,157,215,157,52,159,108,159,106,159,148,159,204,86,214,93,0,98,35,101,43,101,42,101,236,102,16,107,218,116,202,122,100,124,99,124,101,124,147,126,150,126,148,126,226,129,56,134,63,134,49,136,138,139,144,144,143,144,99,148,96,148,100,148,104,151,111,152,92,153,90,154,91,154,87,154,211,154,212,154,209,154,84,156,87,156,86,156,229,157,159,158,244,158,209,86,233,88,44,101,94,112,113,118,114,118,215,119,80,127,136,127,54,136,57,136,98,136,147,139,146,139,150,139,119,130,27,141,192,145,106,148,66,151,72,151,68,151,198,151,112,152,95,154,34,155,88,155,95,156,249,157,250,157,124,158,125,158,7,159,119,159,114,159,243,94,22,107,99,112,108,124,110,124,59,136,192,137,161,142,193,145,114,148,112,148,113,152,94,153,214,154,35,155,204,158,100,112,218,119,154,139,119,148,201,151,98,154,101,154,156,126,156,139,170,142,197,145,125,148,126,148,124,148,119,156,120,156,247,158,84,140,127,148,26,158,40,114,106,154,49,155,27,158,30,158,114,124,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,54,78,63,78,133,78,160,78,130,81,150,81,171,81,249,82,56,83,105,83,182,83,10,89,128,91,219,93,122,94,127,94,244,94,80,95,97,95,52,101,224,101,146,117,118,118,181,143,182,150,168,0,198,2,253,48,254,48,157,48,158,48,0,0,0,0,5,48,6,48,7,48,252,48,59,255,61,255,61,39,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1926705);
/* memory initializer */ allocate([48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,231,33,184,33,185,33,207,49,204,0,90,78,138,0,2,82,145,68,176,159,136,81,177,159,7,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,255,228,255,7,255,2,255,49,50,22,33,33,33,155,48,156,48,128,46,132,46,134,46,135,46,136,46,138,46,140,46,141,46,149,46,156,46,157,46,165,46,167,46,170,46,172,46,174,46,182,46,188,46,190,46,198,46,202,46,204,46,205,46,207,46,214,46,215,46,222,46,227,46,0,0,0,0,0,0,131,2,80,2,91,2,84,2,117,2,83,1,248,0,75,1,138,2,106,2,66,78,92,78,245,81,26,83,130,83,7,78,12,78,71,78,141,78,215,86,12,250,110,92,115,95,15,78,135,81,14,78,46,78,147,78,194,78,201,78,200,78,152,81,252,82,108,83,185,83,32,87,3,89,44,89,16,92,255,93,225,101,179,107,204,107,20,108,63,114,49,78,60,78,232,78,220,78,233,78,225,78,221,78,218,78,12,82,28,83,76,83,34,87,35,87,23,89,47,89,129,91,132,91,18,92,59,92,116,92,115,92,4,94,128,94,130,94,201,95,9,98,80,98,21,108,54,108,67,108,63,108,59,108,174,114,176,114,138,115,184,121,138,128,30,150,14,79,24,79,44,79,245,78,20,79,241,78,0,79,247,78,8,79,29,79,2,79,5,79,34,79,19,79,4,79,244,78,18,79,177,81,19,82,9,82,16,82,166,82,34,83,31,83,77,83,138,83,7,84,225,86,223,86,46,87,42,87,52,87,60,89,128,89,124,89,133,89,123,89,126,89,119,89,127,89,86,91,21,92,37,92,124,92,122,92,123,92,126,92,223,93,117,94,132,94,2,95,26,95,116,95,213,95,212,95,207,95,92,98,94,98,100,98,97,98,102,98,98,98,89,98,96,98,90,98,101,98,239,101,238,101,62,103,57,103,56,103,59,103,58,103,63,103,60,103,51,103,24,108,70,108,82,108,92,108,79,108,74,108,84,108,75,108,76,108,113,112,94,114,180,114,181,114,142,115,42,117,127,118,117,122,81,127,120,130,124,130,128,130,125,130,127,130,77,134,126,137,153,144,151,144,152,144,155,144,148,144,34,150,36,150,32,150,35,150,86,79,59,79,98,79,73,79,83,79,100,79,62,79,103,79,82,79,95,79,65,79,88,79,45,79,51,79,63,79,97,79,143,81,185,81,28,82,30,82,33,82,173,82,174,82,9,83,99,83,114,83,142,83,143,83,48,84,55,84,42,84,84,84,69,84,25,84,28,84,37,84,24,84,61,84,79,84,65,84,40,84,36,84,71,84,238,86,231,86,229,86,65,87,69,87,76,87,73,87,75,87,82,87,6,89,64,89,166,89,152,89,160,89,151,89,142,89,162,89,144,89,143,89,167,89,161,89,142,91,146,91,40,92,42,92,141,92,143,92,136,92,139,92,137,92,146,92,138,92,134,92,147,92,149,92,224,93,10,94,14,94,139,94,137,94,140,94,136,94,141,94,5,95,29,95,120,95,118,95,210,95,209,95,208,95,237,95,232,95,238,95,243,95,225,95,228,95,227,95,250,95,239,95,247,95,251,95,0,96,244,95,58,98,131,98,140,98,142,98,143,98,148,98,135,98,113,98,123,98,122,98,112,98,129,98,136,98,119,98,125,98,114,98,116,98,55,101,240,101,244,101,243,101,242,101,245,101,69,103,71,103,89,103,85,103,76,103,72,103,93,103,77,103,90,103,75,103,208,107,25,108,26,108,120,108,103,108,107,108,132,108,139,108,143,108,113,108,111,108,105,108,154,108,109,108,135,108,149,108,156,108,102,108,115,108,101,108,123,108,142,108,116,112,122,112,99,114,191,114,189,114,195,114,198,114,193,114,186,114,197,114,149,115,151,115,147,115,148,115,146,115,58,117,57,117,148,117,149,117,129,118,61,121,52,128,149,128,153,128,144,128,146,128,156,128,144,130,143,130,133,130,142,130,145,130,147,130,138,130,131,130,132,130,120,140,201,143,191,143,159,144,161,144,165,144,158,144,167,144,160,144,48,150,40,150,47,150,45,150,51,78,152,79,124,79,133,79,125,79,128,79,135,79,118,79,116,79,137,79,132,79,119,79,76,79,151,79,106,79,154,79,121,79,129,79,120,79,144,79,156,79,148,79,158,79,146,79,130,79,149,79,107,79,110,79,158,81,188,81,190,81,53,82,50,82,51,82,70,82,49,82,188,82,10,83,11,83,60,83,146,83,148,83,135,84,127,84,129,84,145,84,130,84,136,84,107,84,122,84,126,84,101,84,108,84,116,84,102,84,141,84,111,84,97,84,96,84,152,84,99,84,103,84,100,84,247,86,249,86,111,87,114,87,109,87,107,87,113,87,112,87,118,87,128,87,117,87,123,87,115,87,116,87,98,87,104,87,125,87,12,89,69,89,181,89,186,89,207,89,206,89,178,89,204,89,193,89,182,89,188,89,195,89,214,89,177,89,189,89,192,89,200,89,180,89,199,89,98,91,101,91,147,91,149,91,68,92,71,92,174,92,164,92,160,92,181,92,175,92,168,92,172,92,159,92,163,92,173,92,162,92,170,92,167,92,157,92,165,92,182,92,176,92,166,92,23,94,20,94,25,94,40,95,34,95,35,95,36,95,84,95,130,95,126,95,125,95,222,95,229,95,45,96,38,96,25,96,50,96,11,96,52,96,10,96,23,96,51,96,26,96,30,96,44,96,34,96,13,96,16,96,46,96,19,96,17,96,12,96,9,96,28,96,20,98,61,98,173,98,180,98,209,98,190,98,170,98,182,98,202,98,174,98,179,98,175,98,187,98,169,98,176,98,184,98,61,101,168,101,187,101,9,102,252,101,4,102,18,102,8,102,251,101,3,102,11,102,13,102,5,102,253,101,17,102,16,102,246,102,10,103,133,103,108,103,142,103,146,103,118,103,123,103,152,103,134,103,132,103,116,103,141,103,140,103,122,103,159,103,145,103,153,103,131,103,125,103,129,103,120,103,121,103,148,103,37,107,128,107,126,107,222,107,29,108,147,108,236,108,235,108,238,108,217,108,182,108,212,108,173,108,231,108,183,108,208,108,194,108,186,108,195,108,198,108,237,108,242,108,210,108,221,108,180,108,138,108,157,108,128,108,222,108,192,108,48,109,205,108,199,108,176,108,249,108,207,108,233,108,209,108,148,112,152,112,133,112,147,112,134,112,132,112,145,112,150,112,130,112,154,112,131,112,106,114,214,114,203,114,216,114,201,114,220,114,210,114,212,114,218,114,204,114,209,114,164,115,161,115,173,115,166,115,162,115,160,115,172,115,157,115,221,116,232,116,63,117,64,117,62,117,140,117,152,117,175,118,243,118,241,118,240,118,245,118,248,119,252,119,249,119,251,119,250,119,247,119,66,121,63,121,197,121,120,122,123,122,251,122,117,124,253,124,53,128,143,128,174,128,163,128,184,128,181,128,173,128,32,130,160,130,192,130,171,130,154,130,152,130,155,130,181,130,167,130,174,130,188,130,158,130,186,130,180,130,168,130,161,130,169,130,194,130,164,130,195,130,182,130,162,130,112,134,111,134,109,134,110,134,86,140,210,143,203,143,211,143,205,143,214,143,213,143,215,143,178,144,180,144,175,144,179,144,176,144,57,150,61,150,60,150,58,150,67,150,205,79,197,79,211,79,178,79,201,79,203,79,193,79,212,79,220,79,217,79,187,79,179,79,219,79,199,79,214,79,186,79,192,79,185,79,236,79,68,82,73,82,192,82,194,82,61,83,124,83,151,83,150,83,153,83,152,83,186,84,161,84,173,84,165,84,207,84,195,84,13,131,183,84,174,84,214,84,182,84,197,84,198,84,160,84,112,84,188,84,162,84,190,84,114,84,222,84,176,84,181,87,158,87,159,87,164,87,140,87,151,87,157,87,155,87,148,87,152,87,143,87,153,87,165,87,154,87,149,87,244,88,13,89,83,89,225,89,222,89,238,89,0,90,241,89,221,89,250,89,253,89,252,89,246,89,228,89,242,89,247,89,219,89,233,89,243,89,245,89,224,89,254,89,244,89,237,89,168,91,76,92,208,92,216,92,204,92,215,92,203,92,219,92,222,92,218,92,201,92,199,92,202,92,214,92,211,92,212,92,207,92,200,92,198,92,206,92,223,92,248,92,249,93,33,94,34,94,35,94,32,94,36,94,176,94,164,94,162,94,155,94,163,94,165,94,7,95,46,95,86,95,134,95,55,96,57,96,84,96,114,96,94,96,69,96,83,96,71,96,73,96,91,96,76,96,64,96,66,96,95,96,36,96,68,96,88,96,102,96,110,96,66,98,67,98,207,98,13,99,11,99,245,98,14,99,3,99,235,98,249,98,15,99,12,99,248,98,246,98,0,99,19,99,20,99,250,98,21,99,251,98,240,98,65,101,67,101,170,101,191,101,54,102,33,102,50,102,53,102,28,102,38,102,34,102,51,102,43,102,58,102,29,102,52,102,57,102,46,102,15,103,16,103,193,103,242,103,200,103,186,103,220,103,187,103,248,103,216,103,192,103,183,103,197,103,235,103,228,103,223,103,181,103,205,103,179,103,247,103,246,103,238,103,227,103,194,103,185,103,206,103,231,103,240,103,178,103,252,103,198,103,237,103,204,103,174,103,230,103,219,103,250,103,201,103,202,103,195,103,234,103,203,103,40,107,130,107,132,107,182,107,214,107,216,107,224,107,32,108,33,108,40,109,52,109,45,109,31,109,60,109,63,109,18,109,10,109,218,108,51,109,4,109,25,109,58,109,26,109,17,109,0,109,29,109,66,109,1,109,24,109,55,109,3,109,15,109,64,109,7,109,32,109,44,109,8,109,34,109,9,109,16,109,183,112,159,112,190,112,177,112,176,112,161,112,180,112,181,112,169,112,65,114,73,114,74,114,108,114,112,114,115,114,110,114,202,114,228,114,232,114,235,114,223,114,234,114,230,114,227,114,133,115,204,115,194,115,200,115,197,115,185,115,182,115,181,115,180,115,235,115,191,115,199,115,190,115,195,115,198,115,184,115,203,115,236,116,238,116,46,117,71,117,72,117,167,117,170,117,121,118,196,118,8,119,3,119,4,119,5,119,10,119,247,118,251,118,250,118,231,119,232,119,6,120,17,120,18,120,5,120,16,120,15,120,14,120,9,120,3,120,19,120,74,121,76,121,75,121,69,121,68,121,213,121,205,121,207,121,214,121,206,121,128,122,126,122,209,122,0,123,1,123,122,124,120,124,121,124,127,124,128,124,129,124,3,125,8,125,1,125,88,127,145,127,141,127,190,127,7,128,14,128,15,128,20,128,55,128,216,128,199,128,224,128,209,128,200,128,194,128,208,128,197,128,227,128,217,128,220,128,202,128,213,128,201,128,207,128,215,128,230,128,205,128,255,129,33,130,148,130,217,130,254,130,249,130,7,131,232,130,0,131,213,130,58,131,235,130,214,130,244,130,236,130,225,130,242,130,245,130,12,131,251,130,246,130,240,130,234,130,228,130,224,130,250,130,243,130,237,130,119,134,116,134,124,134,115,134,65,136,78,136,103,136,106,136,105,136,211,137,4,138,7,138,114,141,227,143,225,143,238,143,224,143,241,144,189,144,191,144,213,144,197,144,190,144,199,144,203,144,200,144,212,145,211,145,84,150,79,150,81,150,83,150,74,150,78,150,30,80,5,80,7,80,19,80,34,80,48,80,27,80,245,79,244,79,51,80,55,80,44,80,246,79,247,79,23,80,28,80,32,80,39,80,53,80,47,80,49,80,14,80,90,81,148,81,147,81,202,81,196,81,197,81,200,81,206,81,97,82,90,82,82,82,94,82,95,82,85,82,98,82,205,82,14,83,158,83,38,85,226,84,23,85,18,85,231,84,243,84,228,84,26,85,255,84,4,85,8,85,235,84,17,85,5,85,241,84,10,85,251,84,247,84,248,84,224,84,14,85,3,85,11,85,1,87,2,87,204,87,50,88,213,87,210,87,186,87,198,87,189,87,188,87,184,87,182,87,191,87,199,87,208,87,185,87,193,87,14,89,74,89,25,90,22,90,45,90,46,90,21,90,15,90,23,90,10,90,30,90,51,90,108,91,167,91,173,91,172,91,3,92,86,92,84,92,236,92,255,92,238,92,241,92,247,92,0,93,249,92,41,94,40,94,168,94,174,94,170,94,172,94,51,95,48,95,103,95,93,96,90,96,103,96,65,96,162,96,136,96,128,96,146,96,129,96,157,96,131,96,149,96,155,96,151,96,135,96,156,96,142,96,25,98,70,98,242,98,16,99,86,99,44,99,68,99,69,99,54,99,67,99,228,99,57,99,75,99,74,99,60,99,41,99,65,99,52,99,88,99,84,99,89,99,45,99,71,99,51,99,90,99,81,99,56,99,87,99,64,99,72,99,74,101,70,101,198,101,195,101,196,101,194,101,74,102,95,102,71,102,81,102,18,103,19,103,31,104,26,104,73,104,50,104,51,104,59,104,75,104,79,104,22,104,49,104,28,104,53,104,43,104,45,104,47,104,78,104,68,104,52,104,29,104,18,104,20,104,38,104,40,104,46,104,77,104,58,104,37,104,32,104,44,107,47,107,45,107,49,107,52,107,109,107,130,128,136,107,230,107,228,107,232,107,227,107,226,107,231,107,37,108,122,109,99,109,100,109,118,109,13,109,97,109,146,109,88,109,98,109,109,109,111,109,145,109,141,109,239,109,127,109,134,109,94,109,103,109,96,109,151,109,112,109,124,109,95,109,130,109,152,109,47,109,104,109,139,109,126,109,128,109,132,109,22,109,131,109,123,109,125,109,117,109,144,109,220,112,211,112,209,112,221,112,203,112,57,127,226,112,215,112,210,112,222,112,224,112,212,112,205,112,197,112,198,112,199,112,218,112,206,112,225,112,66,114,120,114,119,114,118,114,0,115,250,114,244,114,254,114,246,114,243,114,251,114,1,115,211,115,217,115,229,115,214,115,188,115,231,115,227,115,233,115,220,115,210,115,219,115,212,115,221,115,218,115,215,115,216,115,232,115,222,116,223,116,244,116,245,116,33,117,91,117,95,117,176,117,193,117,187,117,196,117,192,117,191,117,182,117,186,117,138,118,201,118,29,119,27,119,16,119,19,119,18,119,35,119,17,119,21,119,25,119,26,119,34,119,39,119,35,120,44,120,34,120,53,120,47,120,40,120,46,120,43,120,33,120,41,120,51,120,42,120,49,120,84,121,91,121,79,121,92,121,83,121,82,121,81,121,235,121,236,121,224,121,238,121,237,121,234,121,220,121,222,121,221,121,134,122,137,122,133,122,139,122,140,122,138,122,135,122,216,122,16,123,4,123,19,123,5,123,15,123,8,123,10,123,14,123,9,123,18,123,132,124,145,124,138,124,140,124,136,124,141,124,133,124,30,125,29,125,17,125,14,125,24,125,22,125,19,125,31,125,18,125,15,125,12,125,92,127,97,127,94,127,96,127,93,127,91,127,150,127,146,127,195,127,194,127,192,127,22,128,62,128,57,128,250,128,242,128,249,128,245,128,1,129,251,128,0,129,1,130,47,130,37,130,51,131,45,131,68,131,25,131,81,131,37,131,86,131,63,131,65,131,38,131,28,131,34,131,66,131,78,131,27,131,42,131,8,131,60,131,77,131,22,131,36,131,32,131,55,131,47,131,41,131,71,131,69,131,76,131,83,131,30,131,44,131,75,131,39,131,72,131,83,134,82,134,162,134,168,134,150,134,141,134,145,134,158,134,135,134,151,134,134,134,139,134,154,134,133,134,165,134,153,134,161,134,167,134,149,134,152,134,142,134,157,134,144,134,148,134,67,136,68,136,109,136,117,136,118,136,114,136,128,136,113,136,127,136,111,136,131,136,126,136,116,136,124,136,18,138,71,140,87,140,123,140,164,140,163,140,118,141,120,141,181,141,183,141,182,141,209,142,211,142,254,143,245,143,2,144,255,143,251,143,4,144,252,143,246,143,214,144,224,144,217,144,218,144,227,144,223,144,229,144,216,144,219,144,215,144,220,144,228,144,80,145,78,145,79,145,213,145,226,145,218,145,92,150,95,150,188,150,227,152,223,154,47,155,127,78,112,80,106,80,97,80,94,80,96,80,83,80,75,80,93,80,114,80,72,80,77,80,65,80,91,80,74,80,98,80,21,80,69,80,95,80,105,80,107,80,99,80,100,80,70,80,64,80,110,80,115,80,87,80,81,80,208,81,107,82,109,82,108,82,110,82,214,82,211,82,45,83,156,83,117,85,118,85,60,85,77,85,80,85,52,85,42,85,81,85,98,85,54,85,53,85,48,85,82,85,69,85,12,85,50,85,101,85,78,85,57,85,72,85,45,85,59,85,64,85,75,85,10,87,7,87,251,87,20,88,226,87,246,87,220,87,244,87,0,88,237,87,253,87,8,88,248,87,11,88,243,87,207,87,7,88,238,87,227,87,242,87,229,87,236,87,225,87,14,88,252,87,16,88,231,87,1,88,12,88,241,87,233,87,240,87,13,88,4,88,92,89,96,90,88,90,85,90,103,90,94,90,56,90,53,90,109,90,80,90,95,90,101,90,108,90,83,90,100,90,87,90,67,90,93,90,82,90,68,90,91,90,72,90,142,90,62,90,77,90,57,90,76,90,112,90,105,90,71,90,81,90,86,90,66,90,92,90,114,91,110,91,193,91,192,91,89,92,30,93,11,93,29,93,26,93,32,93,12,93,40,93,13,93,38,93,37,93,15,93,48,93,18,93,35,93,31,93,46,93,62,94,52,94,177,94,180,94,185,94,178,94,179,94,54,95,56,95,155,95,150,95,159,95,138,96,144,96,134,96,190,96,176,96,186,96,211,96,212,96,207,96,228,96,217,96,221,96,200,96,177,96,219,96,183,96,202,96,191,96,195,96,205,96,192,96,50,99,101,99,138,99,130,99,125,99,189,99,158,99,173,99,157,99,151,99,171,99,142,99,111,99,135,99,144,99,110,99,175,99,117,99,156,99,109,99,174,99,124,99,164,99,59,99,159,99,120,99,133,99,129,99,145,99,141,99,112,99,83,101,205,101,101,102,97,102,91,102,89,102,92,102,98,102,24,103,121,104,135,104,144,104,156,104,109,104,110,104,174,104,171,104,86,105,111,104,163,104,172,104,169,104,117,104,116,104,178,104,143,104,119,104,146,104,124,104,107,104,114,104,170,104,128,104,113,104,126,104,155,104,150,104,139,104,160,104,137,104,164,104,120,104,123,104,145,104,140,104,138,104,125,104,54,107,51,107,55,107,56,107,145,107,143,107,141,107,142,107,140,107,42,108,192,109,171,109,180,109,179,109,116,110,172,109,233,109,226,109,183,109,246,109,212,109,0,110,200,109,224,109,223,109,214,109,190,109,229,109,220,109,221,109,219,109,244,109,202,109,189,109,237,109,240,109,186,109,213,109,194,109,207,109,201,109,208,109,242,109,211,109,253,109,215,109,205,109,227,109,187,109,250,112,13,113,247,112,23,113,244,112,12,113,240,112,4,113,243,112,16,113,252,112,255,112,6,113,19,113,0,113,248,112,246,112,11,113,2,113,14,113,126,114,123,114,124,114,127,114,29,115,23,115,7,115,17,115,24,115,10,115,8,115,255,114,15,115,30,115,136,115,246,115,248,115,245,115,4,116,1,116,253,115,7,116,0,116,250,115,252,115,255,115,12,116,11,116,244,115,8,116,100,117,99,117,206,117,210,117,207,117,203,117,204,117,209,117,208,117,143,118,137,118,211,118,57,119,47,119,45,119,49,119,50,119,52,119,51,119,61,119,37,119,59,119,53,119,72,120,82,120,73,120,77,120,74,120,76,120,38,120,69,120,80,120,100,121,103,121,105,121,106,121,99,121,107,121,97,121,187,121,250,121,248,121,246,121,247,121,143,122,148,122,144,122,53,123,71,123,52,123,37,123,48,123,34,123,36,123,51,123,24,123,42,123,29,123,49,123,43,123,45,123,47,123,50,123,56,123,26,123,35,123,148,124,152,124,150,124,163,124,53,125,61,125,56,125,54,125,58,125,69,125,44,125,41,125,65,125,71,125,62,125,63,125,74,125,59,125,40,125,99,127,149,127,156,127,157,127,155,127,202,127,203,127,205,127,208,127,209,127,199,127,207,127,201,127,31,128,30,128,27,128,71,128,67,128,72,128,24,129,37,129,25,129,27,129,45,129,31,129,44,129,30,129,33,129,21,129,39,129,29,129,34,129,17,130,56,130,51,130,58,130,52,130,50,130,116,130,144,131,163,131,168,131,141,131,122,131,115,131,164,131,116,131,143,131,129,131,149,131,153,131,117,131,148,131,169,131,125,131,131,131,140,131,157,131,155,131,170,131,139,131,126,131,165,131,175,131,136,131,151,131,176,131,127,131,166,131,135,131,174,131,118,131,154,131,89,134,86,134,191,134,183,134,194,134,193,134,197,134,186,134,176,134,200,134,185,134,179,134,184,134,204,134,180,134,187,134,188,134,195,134,189,134,190,134,82,136,137,136,149,136,168,136,162,136,170,136,154,136,145,136,161,136,159,136,152,136,167,136,153,136,155,136,151,136,164,136,172,136,140,136,147,136,142,136,130,137,214,137,217,137,213,137,48,138,39,138,44,138,30,138,57,140,59,140,92,140,93,140,125,140,165,140,125,141,123,141,121,141,188,141,194,141,185,141,191,141,193,141,216,142,222,142,221,142,220,142,215,142,224,142,225,142,36,144,11,144,17,144,28,144,12,144,33,144,239,144,234,144,240,144,244,144,242,144,243,144,212,144,235,144,236,144,233,144,86,145,88,145,90,145,83,145,85,145,236,145,244,145,241,145,243,145,248,145,228,145,249,145,234,145,235,145,247,145,232,145,238,145,122,149,134,149,136,149,124,150,109,150,107,150,113,150,111,150,191,150,106,151,4,152,229,152,151,153,155,80,149,80,148,80,158,80,139,80,163,80,131,80,140,80,142,80,157,80,104,80,156,80,146,80,130,80,135,80,95,81,212,81,18,83,17,83,164,83,167,83,145,85,168,85,165,85,173,85,119,85,69,86,162,85,147,85,136,85,143,85,181,85,129,85,163,85,146,85,164,85,125,85,140,85,166,85,127,85,149,85,161,85,142,85,12,87,41,88,55,88,25,88,30,88,39,88,35,88,40,88,245,87,72,88,37,88,28,88,27,88,51,88,63,88,54,88,46,88,57,88,56,88,45,88,44,88,59,88,97,89,175,90,148,90,159,90,122,90,162,90,158,90,120,90,166,90,124,90,165,90,172,90,149,90,174,90,55,90,132,90,138,90,151,90,131,90,139,90,169,90,123,90,125,90,140,90,156,90,143,90,147,90,157,90,234,91,205,91,203,91,212,91,209,91,202,91,206,91,12,92,48,92,55,93,67,93,107,93,65,93,75,93,63,93,53,93,81,93,78,93,85,93,51,93,58,93,82,93,61,93,49,93,89,93,66,93,57,93,73,93,56,93,60,93,50,93,54,93,64,93,69,93,68,94,65,94,88,95,166,95,165,95,171,95,201,96,185,96,204,96,226,96,206,96,196,96,20,97,242,96,10,97,22,97,5,97,245,96,19,97,248,96,252,96,254,96,193,96,3,97,24,97,29,97,16,97,255,96,4,97,11,97,74,98,148,99,177,99,176,99,206,99,229,99,232,99,239,99,195,99,157,100,243,99,202,99,224,99,246,99,213,99,242,99,245,99,97,100,223,99,190,99,221,99,220,99,196,99,216,99,211,99,194,99,199,99,204,99,203,99,200,99,240,99,215,99,217,99,50,101,103,101,106,101,100,101,92,101,104,101,101,101,140,101,157,101,158,101,174,101,208,101,210,101,124,102,108,102,123,102,128,102,113,102,121,102,106,102,114,102,1,103,12,105,211,104,4,105,220,104,42,105,236,104,234,104,241,104,15,105,214,104,247,104,235,104,228,104,246,104,19,105,16,105,243,104,225,104,7,105,204,104,8,105,112,105,180,104,17,105,239,104,198,104,20,105,248,104,208,104,253,104,252,104,232,104,11,105,10,105,23,105,206,104,200,104,221,104,222,104,230,104,244,104,209,104,6,105,212,104,233,104,21,105,37,105,199,104,57,107,59,107,63,107,60,107,148,107,151,107,153,107,149,107,189,107,240,107,242,107,243,107,48,108,252,109,70,110,71,110,31,110,73,110,136,110,60,110,61,110,69,110,98,110,43,110,63,110,65,110,93,110,115,110,28,110,51,110,75,110,64,110,81,110,59,110,3,110,46,110,94,110,104,110,92,110,97,110,49,110,40,110,96,110,113,110,107,110,57,110,34,110,48,110,83,110,101,110,39,110,120,110,100,110,119,110,85,110,121,110,82,110,102,110,53,110,54,110,90,110,32,113,30,113,47,113,251,112,46,113,49,113,35,113,37,113,34,113,50,113,31,113,40,113,58,113,27,113,75,114,90,114,136,114,137,114,134,114,133,114,139,114,18,115,11,115,48,115,34,115,49,115,51,115,39,115,50,115,45,115,38,115,35,115,53,115,12,115,46,116,44,116,48,116,43,116,22,116,26,116,33,116,45,116,49,116,36,116,35,116,29,116,41,116,32,116,50,116,251,116,47,117,111,117,108,117,231,117,218,117,225,117,230,117,221,117,223,117,228,117,215,117,149,118,146,118,218,118,70,119,71,119,68,119,77,119,69,119,74,119,78,119,75,119,76,119,222,119,236,119,96,120,100,120,101,120,92,120,109,120,113,120,106,120,110,120,112,120,105,120,104,120,94,120,98,120,116,121,115,121,114,121,112,121,2,122,10,122,3,122,12,122,4,122,153,122,230,122,228,122,74,123,59,123,68,123,72,123,76,123,78,123,64,123,88,123,69,123,162,124,158,124,168,124,161,124,88,125,111,125,99,125,83,125,86,125,103,125,106,125,79,125,109,125,92,125,107,125,82,125,84,125,105,125,81,125,95,125,78,125,62,127,63,127,101,127,102,127,162,127,160,127,161,127,215,127,81,128,79,128,80,128,254,128,212,128,67,129,74,129,82,129,79,129,71,129,61,129,77,129,58,129,230,129,238,129,247,129,248,129,249,129,4,130,60,130,61,130,63,130,117,130,59,131,207,131,249,131,35,132,192,131,232,131,18,132,231,131,228,131,252,131,246,131,16,132,198,131,200,131,235,131,227,131,191,131,1,132,221,131,229,131,216,131,255,131,225,131,203,131,206,131,214,131,245,131,201,131,9,132,15,132,222,131,17,132,6,132,194,131,243,131,213,131,250,131,199,131,209,131,234,131,19,132,195,131,236,131,238,131,196,131,251,131,215,131,226,131,27,132,219,131,254,131,216,134,226,134,230,134,211,134,227,134,218,134,234,134,221,134,235,134,220,134,236,134,233,134,215,134,232,134,209,134,72,136,86,136,85,136,186,136,215,136,185,136,184,136,192,136,190,136,182,136,188,136,183,136,189,136,178,136,1,137,201,136,149,137,152,137,151,137,221,137,218,137,219,137,78,138,77,138,57,138,89,138,64,138,87,138,88,138,68,138,69,138,82,138,72,138,81,138,74,138,76,138,79,138,95,140,129,140,128,140,186,140,190,140,176,140,185,140,181,140,132,141,128,141,137,141,216,141,211,141,205,141,199,141,214,141,220,141,207,141,213,141,217,141,200,141,215,141,197,141,239,142,247,142,250,142,249,142,230,142,238,142,229,142,245,142,231,142,232,142,246,142,235,142,241,142,236,142,244,142,233,142,45,144,52,144,47,144,6,145,44,145,4,145,255,144,252,144,8,145,249,144,251,144,1,145,0,145,7,145,5,145,3,145,97,145,100,145,95,145,98,145,96,145,1,146,10,146,37,146,3,146,26,146,38,146,15,146,12,146,0,146,18,146,255,145,253,145,6,146,4,146,39,146,2,146,28,146,36,146,25,146,23,146,5,146,22,146,123,149,141,149,140,149,144,149,135,150,126,150,136,150,137,150,131,150,128,150,194,150,200,150,195,150,241,150,240,150,108,151,112,151,110,151,7,152,169,152,235,152,230,156,249,158,131,78,132,78,182,78,189,80,191,80,198,80,174,80,196,80,202,80,180,80,200,80,194,80,176,80,193,80,186,80,177,80,203,80,201,80,182,80,184,80,215,81,122,82,120,82,123,82,124,82,195,85,219,85,204,85,208,85,203,85,202,85,221,85,192,85,212,85,196,85,233,85,191,85,210,85,141,85,207,85,213,85,226,85,214,85,200,85,242,85,205,85,217,85,194,85,20,87,83,88,104,88,100,88,79,88,77,88,73,88,111,88,85,88,78,88,93,88,89,88,101,88,91,88,61,88,99,88,113,88,252,88,199,90,196,90,203,90,186,90,184,90,177,90,181,90,176,90,191,90,200,90,187,90,198,90,183,90,192,90,202,90,180,90,182,90,205,90,185,90,144,90,214,91,216,91,217,91,31,92,51,92,113,93,99,93,74,93,101,93,114,93,108,93,94,93,104,93,103,93,98,93,240,93,79,94,78,94,74,94,77,94,75,94,197,94,204,94,198,94,203,94,199,94,64,95,175,95,173,95,247,96,73,97,74,97,43,97,69,97,54,97,50,97,46,97,70,97,47,97,79,97,41,97,64,97,32,98,104,145,35,98,37,98,36,98,197,99,241,99,235,99,16,100,18,100,9,100,32,100,36,100,51,100,67,100,31,100,21,100,24,100,57,100,55,100,34,100,35,100,12,100,38,100,48,100,40,100,65,100,53,100,47,100,10,100,26,100,64,100,37,100,39,100,11,100,231,99,27,100,46,100,33,100,14,100,111,101,146,101,211,101,134,102,140,102,149,102,144,102,139,102,138,102,153,102,148,102,120,102,32,103,102,105,95,105,56,105,78,105,98,105,113,105,63,105,69,105,106,105,57,105,66,105,87,105,89,105,122,105,72,105,73,105,53,105,108,105,51,105,61,105,101,105,240,104,120,105,52,105,105,105,64,105,111,105,68,105,118,105,88,105,65,105,116,105,76,105,59,105,75,105,55,105,92,105,79,105,81,105,50,105,82,105,47,105,123,105,60,105,70,107,69,107,67,107,66,107,72,107,65,107,155,107,13,250,251,107,252,107,249,107,247,107,248,107,155,110,214,110,200,110,143,110,192,110,159,110,147,110,148,110,160,110,177,110,185,110,198,110,210,110,189,110,193,110,158,110,201,110,183,110,176,110,205,110,166,110,207,110,178,110,190,110,195,110,220,110,216,110,153,110,146,110,142,110,141,110,164,110,161,110,191,110,179,110,208,110,202,110,151,110,174,110,163,110,71,113,84,113,82,113,99,113,96,113,65,113,93,113,98,113,114,113,120,113,106,113,97,113,66,113,88,113,67,113,75,113,112,113,95,113,80,113,83,113,68,113,77,113,90,113,79,114,141,114,140,114,145,114,144,114,142,114,60,115,66,115,59,115,58,115,64,115,74,115,73,115,68,116,74,116,75,116,82,116,81,116,87,116,64,116,79,116,80,116,78,116,66,116,70,116,77,116,84,116,225,116,255,116,254,116,253,116,29,117,121,117,119,117,131,105,239,117,15,118,3,118,247,117,254,117,252,117,249,117,248,117,16,118,251,117,246,117,237,117,245,117,253,117,153,118,181,118,221,118,85,119,95,119,96,119,82,119,86,119,90,119,105,119,103,119,84,119,89,119,109,119,224,119,135,120,154,120,148,120,143,120,132,120,149,120,133,120,134,120,161,120,131,120,121,120,153,120,128,120,150,120,123,120,124,121,130,121,125,121,121,121,17,122,24,122,25,122,18,122,23,122,21,122,34,122,19,122,27,122,16,122,163,122,162,122,158,122,235,122,102,123,100,123,109,123,116,123,105,123,114,123,101,123,115,123,113,123,112,123,97,123,120,123,118,123,99,123,178,124,180,124,175,124,136,125,134,125,128,125,141,125,127,125,133,125,122,125,142,125,123,125,131,125,124,125,140,125,148,125,132,125,125,125,146,125,109,127,107,127,103,127,104,127,108,127,166,127,165,127,167,127,219,127,220,127,33,128,100,129,96,129,119,129,92,129,105,129,91,129,98,129,114,129,33,103,94,129,118,129,103,129,111,129,68,129,97,129,29,130,73,130,68,130,64,130,66,130,69,130,241,132,63,132,86,132,118,132,121,132,143,132,141,132,101,132,81,132,64,132,134,132,103,132,48,132,77,132,125,132,90,132,89,132,116,132,115,132,93,132,7,133,94,132,55,132,58,132,52,132,122,132,67,132,120,132,50,132,69,132,41,132,217,131,75,132,47,132,66,132,45,132,95,132,112,132,57,132,78,132,76,132,82,132,111,132,197,132,142,132,59,132,71,132,54,132,51,132,104,132,126,132,68,132,43,132,96,132,84,132,110,132,80,132,11,135,4,135,247,134,12,135,250,134,214,134,245,134,77,135,248,134,14,135,9,135,1,135,246,134,13,135,5,135,214,136,203,136,205,136,206,136,222,136,219,136,218,136,204,136,208,136,133,137,155,137,223,137,229,137,228,137,225,137,224,137,226,137,220,137,230,137,118,138,134,138,127,138,97,138,63,138,119,138,130,138,132,138,117,138,131,138,129,138,116,138,122,138,60,140,75,140,74,140,101,140,100,140,102,140,134,140,132,140,133,140,204,140,104,141,105,141,145,141,140,141,142,141,143,141,141,141,147,141,148,141,144,141,146,141,240,141,224,141,236,141,241,141,238,141,208,141,233,141,227,141,226,141,231,141,242,141,235,141,244,141,6,143,255,142,1,143,0,143,5,143,7,143,8,143,2,143,11,143,82,144,63,144,68,144,73,144,61,144,16,145,13,145,15,145,17,145,22,145,20,145,11,145,14,145,110,145,111,145,72,146,82,146,48,146,58,146,102,146,51,146,101,146,94,146,131,146,46,146,74,146,70,146,109,146,108,146,79,146,96,146,103,146,111,146,54,146,97,146,112,146,49,146,84,146,99,146,80,146,114,146,78,146,83,146,76,146,86,146,50,146,159,149,156,149,158,149,155,149,146,150,147,150,145,150,151,150,206,150,250,150,253,150,248,150,245,150,115,151,119,151,120,151,114,151,15,152,13,152,14,152,172,152,246,152,249,152,175,153,178,153,176,153,181,153,173,154,171,154,91,155,234,156,237,156,231,156,128,158,253,158,230,80,212,80,215,80,232,80,243,80,219,80,234,80,221,80,228,80,211,80,236,80,240,80,239,80,227,80,224,80,216,81,128,82,129,82,233,82,235,82,48,83,172,83,39,86,21,86,12,86,18,86,252,85,15,86,28,86,1,86,19,86,2,86,250,85,29,86,4,86,255,85,249,85,137,88,124,88,144,88,152,88,134,88,129,88,127,88,116,88,139,88,122,88,135,88,145,88,142,88,118,88,130,88,136,88,123,88,148,88,143,88,254,88,107,89,220,90,238,90,229,90,213,90,234,90,218,90,237,90,235,90,243,90,226,90,224,90,219,90,236,90,222,90,221,90,217,90,232,90,223,90,119,91,224,91,227,91,99,92,130,93,128,93,125,93,134,93,122,93,129,93,119,93,138,93,137,93,136,93,126,93,124,93,141,93,121,93,127,93,88,94,89,94,83,94,216,94,209,94,215,94,206,94,220,94,213,94,217,94,210,94,212,94,68,95,67,95,111,95,182,95,44,97,40,97,65,97,94,97,113,97,115,97,82,97,83,97,114,97,108,97,128,97,116,97,84,97,122,97,91,97,101,97,59,97,106,97,97,97,86,97,41,98,39,98,43,98,43,100,77,100,91,100,93,100,116,100,118,100,114,100,115,100,125,100,117,100,102,100,166,100,78,100,130,100,94,100,92,100,75,100,83,100,96,100,80,100,127,100,63,100,108,100,107,100,89,100,101,100,119,100,115,101,160,101,161,102,160,102,159,102,5,103,4,103,34,103,177,105,182,105,201,105,160,105,206,105,150,105,176,105,172,105,188,105,145,105,153,105,142,105,167,105,141,105,169,105,190,105,175,105,191,105,196,105,189,105,164,105,212,105,185,105,202,105,154,105,207,105,179,105,147,105,170,105,161,105,158,105,217,105,151,105,144,105,194,105,181,105,165,105,198,105,74,107,77,107,75,107,158,107,159,107,160,107,195,107,196,107,254,107,206,110,245,110,241,110,3,111,37,111,248,110,55,111,251,110,46,111,9,111,78,111,25,111,26,111,39,111,24,111,59,111,18,111,237,110,10,111,54,111,115,111,249,110,238,110,45,111,64,111,48,111,60,111,53,111,235,110,7,111,14,111,67,111,5,111,253,110,246,110,57,111,28,111,252,110,58,111,31,111,13,111,30,111,8,111,33,111,135,113,144,113,137,113,128,113,133,113,130,113,143,113,123,113,134,113,129,113,151,113,68,114,83,114,151,114,149,114,147,114,67,115,77,115,81,115,76,115,98,116,115,116,113,116,117,116,114,116,103,116,110,116,0,117,2,117,3,117,125,117,144,117,22,118,8,118,12,118,21,118,17,118,10,118,20,118,184,118,129,119,124,119,133,119,130,119,110,119,128,119,111,119,126,119,131,119,178,120,170,120,180,120,173,120,168,120,126,120,171,120,158,120,165,120,160,120,172,120,162,120,164,120,152,121,138,121,139,121,150,121,149,121,148,121,147,121,151,121,136,121,146,121,144,121,43,122,74,122,48,122,47,122,40,122,38,122,168,122,171,122,172,122,238,122,136,123,156,123,138,123,145,123,144,123,150,123,141,123,140,123,155,123,142,123,133,123,152,123,132,82,153,123,164,123,130,123,187,124,191,124,188,124,186,124,167,125,183,125,194,125,163,125,170,125,193,125,192,125,197,125,157,125,206,125,196,125,198,125,203,125,204,125,175,125,185,125,150,125,188,125,159,125,166,125,174,125,169,125,161,125,201,125,115,127,226,127,227,127,229,127,222,127,36,128,93,128,92,128,137,129,134,129,131,129,135,129,141,129,140,129,139,129,21,130,151,132,164,132,161,132,159,132,186,132,206,132,194,132,172,132,174,132,171,132,185,132,180,132,193,132,205,132,170,132,154,132,177,132,208,132,157,132,167,132,187,132,162,132,148,132,199,132,204,132,155,132,169,132,175,132,168,132,214,132,152,132,182,132,207,132,160,132,215,132,212,132,210,132,219,132,176,132,145,132,97,134,51,135,35,135,40,135,107,135,64,135,46,135,30,135,33,135,25,135,27,135,67,135,44,135,65,135,62,135,70,135,32,135,50,135,42,135,45,135,60,135,18,135,58,135,49,135,53,135,66,135,38,135,39,135,56,135,36,135,26,135,48,135,17,135,247,136,231,136,241,136,242,136,250,136,254,136,238,136,252,136,246,136,251,136,240,136,236,136,235,136,157,137,161,137,159,137,158,137,233,137,235,137,232,137,171,138,153,138,139,138,146,138,143,138,150,138,61,140,104,140,105,140,213,140,207,140,215,140,150,141,9,142,2,142,255,141,13,142,253,141,10,142,3,142,7,142,6,142,5,142,254,141,0,142,4,142,16,143,17,143,14,143,13,143,35,145,28,145,32,145,34,145,31,145,29,145,26,145,36,145,33,145,27,145,122,145,114,145,121,145,115,145,165,146,164,146,118,146,155,146,122,146,160,146,148,146,170,146,141,146,166,146,154,146,171,146,121,146,151,146,127,146,163,146,238,146,142,146,130,146,149,146,162,146,125,146,136,146,161,146,138,146,134,146,140,146,153,146,167,146,126,146,135,146,169,146,157,146,139,146,45,146,158,150,161,150,255,150,88,151,125,151,122,151,126,151,131,151,128,151,130,151,123,151,132,151,129,151,127,151,206,151,205,151,22,152,173,152,174,152,2,153,0,153,7,153,157,153,156,153,195,153,185,153,187,153,186,153,194,153,189,153,199,153,177,154,227,154,231,154,62,155,63,155,96,155,97,155,95,155,241,156,242,156,245,156,167,158,255,80,3,81,48,81,248,80,6,81,7,81,246,80,254,80,11,81,12,81,253,80,10,81,139,82,140,82,241,82,239,82,72,86,66,86,76,86,53,86,65,86,74,86,73,86,70,86,88,86,90,86,64,86,51,86,61,86,44,86,62,86,56,86,42,86,58,86,26,87,171,88,157,88,177,88,160,88,163,88,175,88,172,88,165,88,161,88,255,88,255,90,244,90,253,90,247,90,246,90,3,91,248,90,2,91,249,90,1,91,7,91,5,91,15,91,103,92,153,93,151,93,159,93,146,93,162,93,147,93,149,93,160,93,156,93,161,93,154,93,158,93,105,94,93,94,96,94,92,94,243,125,219,94,222,94,225,94,73,95,178,95,139,97,131,97,121,97,177,97,176,97,162,97,137,97,155,97,147,97,175,97,173,97,159,97,146,97,170,97,161,97,141,97,102,97,179,97,45,98,110,100,112,100,150,100,160,100,133,100,151,100,156,100,143,100,139,100,138,100,140,100,163,100,159,100,104,100,177,100,152,100,118,101,122,101,121,101,123,101,178,101,179,101,181,102,176,102,169,102,178,102,183,102,170,102,175,102,0,106,6,106,23,106,229,105,248,105,21,106,241,105,228,105,32,106,255,105,236,105,226,105,27,106,29,106,254,105,39,106,242,105,238,105,20,106,247,105,231,105,64,106,8,106,230,105,251,105,13,106,252,105,235,105,9,106,4,106,24,106,37,106,15,106,246,105,38,106,7,106,244,105,22,106,81,107,165,107,163,107,162,107,166,107,1,108,0,108,255,107,2,108,65,111,38,111,126,111,135,111,198,111,146,111,141,111,137,111,140,111,98,111,79,111,133,111,90,111,150,111,118,111,108,111,130,111,85,111,114,111,82,111,80,111,87,111,148,111,147,111,93,111,0,111,97,111,107,111,125,111,103,111,144,111,83,111,139,111,105,111,127,111,149,111,99,111,119,111,106,111,123,111,178,113,175,113,155,113,176,113,160,113,154,113,169,113,181,113,157,113,165,113,158,113,164,113,161,113,170,113,156,113,167,113,179,113,152,114,154,114,88,115,82,115,94,115,95,115,96,115,93,115,91,115,97,115,90,115,89,115,98,115,135,116,137,116,138,116,134,116,129,116,125,116,133,116,136,116,124,116,121,116,8,117,7,117,126,117,37,118,30,118,25,118,29,118,28,118,35,118,26,118,40,118,27,118,156,118,157,118,158,118,155,118,141,119,143,119,137,119,136,119,205,120,187,120,207,120,204,120,209,120,206,120,212,120,200,120,195,120,196,120,201,120,154,121,161,121,160,121,156,121,162,121,155,121,118,107,57,122,178,122,180,122,179,122,183,123,203,123,190,123,172,123,206,123,175,123,185,123,202,123,181,123,197,124,200,124,204,124,203,124,247,125,219,125,234,125,231,125,215,125,225,125,3,126,250,125,230,125,246,125,241,125,240,125,238,125,223,125,118,127,172,127,176,127,173,127,237,127,235,127,234,127,236,127,230,127,232,127,100,128,103,128,163,129,159,129,158,129,149,129,162,129,153,129,151,129,22,130,79,130,83,130,82,130,80,130,78,130,81,130,36,133,59,133,15,133,0,133,41,133,14,133,9,133,13,133,31,133,10,133,39,133,28,133,251,132,43,133,250,132,8,133,12,133,244,132,42,133,242,132,21,133,247,132,235,132,243,132,252,132,18,133,234,132,233,132,22,133,254,132,40,133,29,133,46,133,2,133,253,132,30,133,246,132,49,133,38,133,231,132,232,132,240,132,239,132,249,132,24,133,32,133,48,133,11,133,25,133,47,133,98,134,86,135,99,135,100,135,119,135,225,135,115,135,88,135,84,135,91,135,82,135,97,135,90,135,81,135,94,135,109,135,106,135,80,135,78,135,95,135,93,135,111,135,108,135,122,135,110,135,92,135,101,135,79,135,123,135,117,135,98,135,103,135,105,135,90,136,5,137,12,137,20,137,11,137,23,137,24,137,25,137,6,137,22,137,17,137,14,137,9,137,162,137,164,137,163,137,237,137,240,137,236,137,207,138,198,138,184,138,211,138,209,138,212,138,213,138,187,138,215,138,190,138,192,138,197,138,216,138,195,138,186,138,189,138,217,138,62,140,77,140,143,140,229,140,223,140,217,140,232,140,218,140,221,140,231,140,160,141,156,141,161,141,155,141,32,142,35,142,37,142,36,142,46,142,21,142,27,142,22,142,17,142,25,142,38,142,39,142,20,142,18,142,24,142,19,142,28,142,23,142,26,142,44,143,36,143,24,143,26,143,32,143,35,143,22,143,23,143,115,144,112,144,111,144,103,144,107,144,47,145,43,145,41,145,42,145,50,145,38], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1936945);
/* memory initializer */ allocate([145,46,145,133,145,134,145,138,145,129,145,130,145,132,145,128,145,208,146,195,146,196,146,192,146,217,146,182,146,207,146,241,146,223,146,216,146,233,146,215,146,221,146,204,146,239,146,194,146,232,146,202,146,200,146,206,146,230,146,205,146,213,146,201,146,224,146,222,146,231,146,209,146,211,146,181,146,225,146,198,146,180,146,124,149,172,149,171,149,174,149,176,149,164,150,162,150,211,150,5,151,8,151,2,151,90,151,138,151,142,151,136,151,208,151,207,151,30,152,29,152,38,152,41,152,40,152,32,152,27,152,39,152,178,152,8,153,250,152,17,153,20,153,22,153,23,153,21,153,220,153,205,153,207,153,211,153,212,153,206,153,201,153,214,153,216,153,203,153,215,153,204,153,179,154,236,154,235,154,243,154,242,154,241,154,70,155,67,155,103,155,116,155,113,155,102,155,118,155,117,155,112,155,104,155,100,155,108,155,252,156,250,156,253,156,255,156,247,156,7,157,0,157,249,156,251,156,8,157,5,157,4,157,131,158,211,158,15,159,16,159,28,81,19,81,23,81,26,81,17,81,222,81,52,83,225,83,112,86,96,86,110,86,115,86,102,86,99,86,109,86,114,86,94,86,119,86,28,87,27,87,200,88,189,88,201,88,191,88,186,88,194,88,188,88,198,88,23,91,25,91,27,91,33,91,20,91,19,91,16,91,22,91,40,91,26,91,32,91,30,91,239,91,172,93,177,93,169,93,167,93,181,93,176,93,174,93,170,93,168,93,178,93,173,93,175,93,180,93,103,94,104,94,102,94,111,94,233,94,231,94,230,94,232,94,229,94,75,95,188,95,157,97,168,97,150,97,197,97,180,97,198,97,193,97,204,97,186,97,191,97,184,97,140,97,215,100,214,100,208,100,207,100,201,100,189,100,137,100,195,100,219,100,243,100,217,100,51,101,127,101,124,101,162,101,200,102,190,102,192,102,202,102,203,102,207,102,189,102,187,102,186,102,204,102,35,103,52,106,102,106,73,106,103,106,50,106,104,106,62,106,93,106,109,106,118,106,91,106,81,106,40,106,90,106,59,106,63,106,65,106,106,106,100,106,80,106,79,106,84,106,111,106,105,106,96,106,60,106,94,106,86,106,85,106,77,106,78,106,70,106,85,107,84,107,86,107,167,107,170,107,171,107,200,107,199,107,4,108,3,108,6,108,173,111,203,111,163,111,199,111,188,111,206,111,200,111,94,111,196,111,189,111,158,111,202,111,168,111,4,112,165,111,174,111,186,111,172,111,170,111,207,111,191,111,184,111,162,111,201,111,171,111,205,111,175,111,178,111,176,111,197,113,194,113,191,113,184,113,214,113,192,113,193,113,203,113,212,113,202,113,199,113,207,113,189,113,216,113,188,113,198,113,218,113,219,113,157,114,158,114,105,115,102,115,103,115,108,115,101,115,107,115,106,115,127,116,154,116,160,116,148,116,146,116,149,116,161,116,11,117,128,117,47,118,45,118,49,118,61,118,51,118,60,118,53,118,50,118,48,118,187,118,230,118,154,119,157,119,161,119,156,119,155,119,162,119,163,119,149,119,153,119,151,119,221,120,233,120,229,120,234,120,222,120,227,120,219,120,225,120,226,120,237,120,223,120,224,120,164,121,68,122,72,122,71,122,182,122,184,122,181,122,177,122,183,122,222,123,227,123,231,123,221,123,213,123,229,123,218,123,232,123,249,123,212,123,234,123,226,123,220,123,235,123,216,123,223,123,210,124,212,124,215,124,208,124,209,124,18,126,33,126,23,126,12,126,31,126,32,126,19,126,14,126,28,126,21,126,26,126,34,126,11,126,15,126,22,126,13,126,20,126,37,126,36,126,67,127,123,127,124,127,122,127,177,127,239,127,42,128,41,128,108,128,177,129,166,129,174,129,185,129,181,129,171,129,176,129,172,129,180,129,178,129,183,129,167,129,242,129,85,130,86,130,87,130,86,133,69,133,107,133,77,133,83,133,97,133,88,133,64,133,70,133,100,133,65,133,98,133,68,133,81,133,71,133,99,133,62,133,91,133,113,133,78,133,110,133,117,133,85,133,103,133,96,133,140,133,102,133,93,133,84,133,101,133,108,133,99,134,101,134,100,134,155,135,143,135,151,135,147,135,146,135,136,135,129,135,150,135,152,135,121,135,135,135,163,135,133,135,144,135,145,135,157,135,132,135,148,135,156,135,154,135,137,135,30,137,38,137,48,137,45,137,46,137,39,137,49,137,34,137,41,137,35,137,47,137,44,137,31,137,241,137,224,138,226,138,242,138,244,138,245,138,221,138,20,139,228,138,223,138,240,138,200,138,222,138,225,138,232,138,255,138,239,138,251,138,145,140,146,140,144,140,245,140,238,140,241,140,240,140,243,140,108,141,110,141,165,141,167,141,51,142,62,142,56,142,64,142,69,142,54,142,60,142,61,142,65,142,48,142,63,142,189,142,54,143,46,143,53,143,50,143,57,143,55,143,52,143,118,144,121,144,123,144,134,144,250,144,51,145,53,145,54,145,147,145,144,145,145,145,141,145,143,145,39,147,30,147,8,147,31,147,6,147,15,147,122,147,56,147,60,147,27,147,35,147,18,147,1,147,70,147,45,147,14,147,13,147,203,146,29,147,250,146,37,147,19,147,249,146,247,146,52,147,2,147,36,147,255,146,41,147,57,147,53,147,42,147,20,147,12,147,11,147,254,146,9,147,0,147,251,146,22,147,188,149,205,149,190,149,185,149,186,149,182,149,191,149,181,149,189,149,169,150,212,150,11,151,18,151,16,151,153,151,151,151,148,151,240,151,248,151,53,152,47,152,50,152,36,153,31,153,39,153,41,153,158,153,238,153,236,153,229,153,228,153,240,153,227,153,234,153,233,153,231,153,185,154,191,154,180,154,187,154,246,154,250,154,249,154,247,154,51,155,128,155,133,155,135,155,124,155,126,155,123,155,130,155,147,155,146,155,144,155,122,155,149,155,125,155,136,155,37,157,23,157,32,157,30,157,20,157,41,157,29,157,24,157,34,157,16,157,25,157,31,157,136,158,134,158,135,158,174,158,173,158,213,158,214,158,250,158,18,159,61,159,38,81,37,81,34,81,36,81,32,81,41,81,244,82,147,86,140,86,141,86,134,86,132,86,131,86,126,86,130,86,127,86,129,86,214,88,212,88,207,88,210,88,45,91,37,91,50,91,35,91,44,91,39,91,38,91,47,91,46,91,123,91,241,91,242,91,183,93,108,94,106,94,190,95,187,95,195,97,181,97,188,97,231,97,224,97,229,97,228,97,232,97,222,97,239,100,233,100,227,100,235,100,228,100,232,100,129,101,128,101,182,101,218,101,210,102,141,106,150,106,129,106,165,106,137,106,159,106,155,106,161,106,158,106,135,106,147,106,142,106,149,106,131,106,168,106,164,106,145,106,127,106,166,106,154,106,133,106,140,106,146,106,91,107,173,107,9,108,204,111,169,111,244,111,212,111,227,111,220,111,237,111,231,111,230,111,222,111,242,111,221,111,226,111,232,111,225,113,241,113,232,113,242,113,228,113,240,113,226,113,115,115,110,115,111,115,151,116,178,116,171,116,144,116,170,116,173,116,177,116,165,116,175,116,16,117,17,117,18,117,15,117,132,117,67,118,72,118,73,118,71,118,164,118,233,118,181,119,171,119,178,119,183,119,182,119,180,119,177,119,168,119,240,119,243,120,253,120,2,121,251,120,252,120,242,120,5,121,249,120,254,120,4,121,171,121,168,121,92,122,91,122,86,122,88,122,84,122,90,122,190,122,192,122,193,122,5,124,15,124,242,123,0,124,255,123,251,123,14,124,244,123,11,124,243,123,2,124,9,124,3,124,1,124,248,123,253,123,6,124,240,123,241,123,16,124,10,124,232,124,45,126,60,126,66,126,51,126,72,152,56,126,42,126,73,126,64,126,71,126,41,126,76,126,48,126,59,126,54,126,68,126,58,126,69,127,127,127,126,127,125,127,244,127,242,127,44,128,187,129,196,129,204,129,202,129,197,129,199,129,188,129,233,129,91,130,90,130,92,130,131,133,128,133,143,133,167,133,149,133,160,133,139,133,163,133,123,133,164,133,154,133,158,133,119,133,124,133,137,133,161,133,122,133,120,133,87,133,142,133,150,133,134,133,141,133,153,133,157,133,129,133,162,133,130,133,136,133,133,133,121,133,118,133,152,133,144,133,159,133,104,134,190,135,170,135,173,135,197,135,176,135,172,135,185,135,181,135,188,135,174,135,201,135,195,135,194,135,204,135,183,135,175,135,196,135,202,135,180,135,182,135,191,135,184,135,189,135,222,135,178,135,53,137,51,137,60,137,62,137,65,137,82,137,55,137,66,137,173,137,175,137,174,137,242,137,243,137,30,139,24,139,22,139,17,139,5,139,11,139,34,139,15,139,18,139,21,139,7,139,13,139,8,139,6,139,28,139,19,139,26,139,79,140,112,140,114,140,113,140,111,140,149,140,148,140,249,140,111,141,78,142,77,142,83,142,80,142,76,142,71,142,67,143,64,143,133,144,126,144,56,145,154,145,162,145,155,145,153,145,159,145,161,145,157,145,160,145,161,147,131,147,175,147,100,147,86,147,71,147,124,147,88,147,92,147,118,147,73,147,80,147,81,147,96,147,109,147,143,147,76,147,106,147,121,147,87,147,85,147,82,147,79,147,113,147,119,147,123,147,97,147,94,147,99,147,103,147,128,147,78,147,89,147,199,149,192,149,201,149,195,149,197,149,183,149,174,150,176,150,172,150,32,151,31,151,24,151,29,151,25,151,154,151,161,151,156,151,158,151,157,151,213,151,212,151,241,151,65,152,68,152,74,152,73,152,69,152,67,152,37,153,43,153,44,153,42,153,51,153,50,153,47,153,45,153,49,153,48,153,152,153,163,153,161,153,2,154,250,153,244,153,247,153,249,153,248,153,246,153,251,153,253,153,254,153,252,153,3,154,190,154,254,154,253,154,1,155,252,154,72,155,154,155,168,155,158,155,155,155,166,155,161,155,165,155,164,155,134,155,162,155,160,155,175,155,51,157,65,157,103,157,54,157,46,157,47,157,49,157,56,157,48,157,69,157,66,157,67,157,62,157,55,157,64,157,61,157,245,127,45,157,138,158,137,158,141,158,176,158,200,158,218,158,251,158,255,158,36,159,35,159,34,159,84,159,160,159,49,81,45,81,46,81,152,86,156,86,151,86,154,86,157,86,153,86,112,89,60,91,105,92,106,92,192,93,109,94,110,94,216,97,223,97,237,97,238,97,241,97,234,97,240,97,235,97,214,97,233,97,255,100,4,101,253,100,248,100,1,101,3,101,252,100,148,101,219,101,218,102,219,102,216,102,197,106,185,106,189,106,225,106,198,106,186,106,182,106,183,106,199,106,180,106,173,106,94,107,201,107,11,108,7,112,12,112,13,112,1,112,5,112,20,112,14,112,255,111,0,112,251,111,38,112,252,111,247,111,10,112,1,114,255,113,249,113,3,114,253,113,118,115,184,116,192,116,181,116,193,116,190,116,182,116,187,116,194,116,20,117,19,117,92,118,100,118,89,118,80,118,83,118,87,118,90,118,166,118,189,118,236,118,194,119,186,119,255,120,12,121,19,121,20,121,9,121,16,121,18,121,17,121,173,121,172,121,95,122,28,124,41,124,25,124,32,124,31,124,45,124,29,124,38,124,40,124,34,124,37,124,48,124,92,126,80,126,86,126,99,126,88,126,98,126,95,126,81,126,96,126,87,126,83,126,181,127,179,127,247,127,248,127,117,128,209,129,210,129,208,129,95,130,94,130,180,133,198,133,192,133,195,133,194,133,179,133,181,133,189,133,199,133,196,133,191,133,203,133,206,133,200,133,197,133,177,133,182,133,210,133,36,134,184,133,183,133,190,133,105,134,231,135,230,135,226,135,219,135,235,135,234,135,229,135,223,135,243,135,228,135,212,135,220,135,211,135,237,135,216,135,227,135,164,135,215,135,217,135,1,136,244,135,232,135,221,135,83,137,75,137,79,137,76,137,70,137,80,137,81,137,73,137,42,139,39,139,35,139,51,139,48,139,53,139,71,139,47,139,60,139,62,139,49,139,37,139,55,139,38,139,54,139,46,139,36,139,59,139,61,139,58,139,66,140,117,140,153,140,152,140,151,140,254,140,4,141,2,141,0,141,92,142,98,142,96,142,87,142,86,142,94,142,101,142,103,142,91,142,90,142,97,142,93,142,105,142,84,142,70,143,71,143,72,143,75,143,40,145,58,145,59,145,62,145,168,145,165,145,167,145,175,145,170,145,181,147,140,147,146,147,183,147,155,147,157,147,137,147,167,147,142,147,170,147,158,147,166,147,149,147,136,147,153,147,159,147,141,147,177,147,145,147,178,147,164,147,168,147,180,147,163,147,165,147,210,149,211,149,209,149,179,150,215,150,218,150,194,93,223,150,216,150,221,150,35,151,34,151,37,151,172,151,174,151,168,151,171,151,164,151,170,151,162,151,165,151,215,151,217,151,214,151,216,151,250,151,80,152,81,152,82,152,184,152,65,153,60,153,58,153,15,154,11,154,9,154,13,154,4,154,17,154,10,154,5,154,7,154,6,154,192,154,220,154,8,155,4,155,5,155,41,155,53,155,74,155,76,155,75,155,199,155,198,155,195,155,191,155,193,155,181,155,184,155,211,155,182,155,196,155,185,155,189,155,92,157,83,157,79,157,74,157,91,157,75,157,89,157,86,157,76,157,87,157,82,157,84,157,95,157,88,157,90,157,142,158,140,158,223,158,1,159,0,159,22,159,37,159,43,159,42,159,41,159,40,159,76,159,85,159,52,81,53,81,150,82,247,82,180,83,171,86,173,86,166,86,167,86,170,86,172,86,218,88,221,88,219,88,18,89,61,91,62,91,63,91,195,93,112,94,191,95,251,97,7,101,16,101,13,101,9,101,12,101,14,101,132,101,222,101,221,101,222,102,231,106,224,106,204,106,209,106,217,106,203,106,223,106,220,106,208,106,235,106,207,106,205,106,222,106,96,107,176,107,12,108,25,112,39,112,32,112,22,112,43,112,33,112,34,112,35,112,41,112,23,112,36,112,28,112,42,112,12,114,10,114,7,114,2,114,5,114,165,114,166,114,164,114,163,114,161,114,203,116,197,116,183,116,195,116,22,117,96,118,201,119,202,119,196,119,241,119,29,121,27,121,33,121,28,121,23,121,30,121,176,121,103,122,104,122,51,124,60,124,57,124,44,124,59,124,236,124,234,124,118,126,117,126,120,126,112,126,119,126,111,126,122,126,114,126,116,126,104,126,75,127,74,127,131,127,134,127,183,127,253,127,254,127,120,128,215,129,213,129,100,130,97,130,99,130,235,133,241,133,237,133,217,133,225,133,232,133,218,133,215,133,236,133,242,133,248,133,216,133,223,133,227,133,220,133,209,133,240,133,230,133,239,133,222,133,226,133,0,136,250,135,3,136,246,135,247,135,9,136,12,136,11,136,6,136,252,135,8,136,255,135,10,136,2,136,98,137,90,137,91,137,87,137,97,137,92,137,88,137,93,137,89,137,136,137,183,137,182,137,246,137,80,139,72,139,74,139,64,139,83,139,86,139,84,139,75,139,85,139,81,139,66,139,82,139,87,139,67,140,119,140,118,140,154,140,6,141,7,141,9,141,172,141,170,141,173,141,171,141,109,142,120,142,115,142,106,142,111,142,123,142,194,142,82,143,81,143,79,143,80,143,83,143,180,143,64,145,63,145,176,145,173,145,222,147,199,147,207,147,194,147,218,147,208,147,249,147,236,147,204,147,217,147,169,147,230,147,202,147,212,147,238,147,227,147,213,147,196,147,206,147,192,147,210,147,231,147,125,149,218,149,219,149,225,150,41,151,43,151,44,151,40,151,38,151,179,151,183,151,182,151,221,151,222,151,223,151,92,152,89,152,93,152,87,152,191,152,189,152,187,152,190,152,72,153,71,153,67,153,166,153,167,153,26,154,21,154,37,154,29,154,36,154,27,154,34,154,32,154,39,154,35,154,30,154,28,154,20,154,194,154,11,155,10,155,14,155,12,155,55,155,234,155,235,155,224,155,222,155,228,155,230,155,226,155,240,155,212,155,215,155,236,155,220,155,217,155,229,155,213,155,225,155,218,155,119,157,129,157,138,157,132,157,136,157,113,157,128,157,120,157,134,157,139,157,140,157,125,157,107,157,116,157,117,157,112,157,105,157,133,157,115,157,123,157,130,157,111,157,121,157,127,157,135,157,104,157,148,158,145,158,192,158,252,158,45,159,64,159,65,159,77,159,86,159,87,159,88,159,55,83,178,86,181,86,179,86,227,88,69,91,198,93,199,93,238,94,239,94,192,95,193,95,249,97,23,101,22,101,21,101,19,101,223,101,232,102,227,102,228,102,243,106,240,106,234,106,232,106,249,106,241,106,238,106,239,106,60,112,53,112,47,112,55,112,52,112,49,112,66,112,56,112,63,112,58,112,57,112,64,112,59,112,51,112,65,112,19,114,20,114,168,114,125,115,124,115,186,116,171,118,170,118,190,118,237,118,204,119,206,119,207,119,205,119,242,119,37,121,35,121,39,121,40,121,36,121,41,121,178,121,110,122,108,122,109,122,247,122,73,124,72,124,74,124,71,124,69,124,238,124,123,126,126,126,129,126,128,126,186,127,255,127,121,128,219,129,217,129,11,130,104,130,105,130,34,134,255,133,1,134,254,133,27,134,0,134,246,133,4,134,9,134,5,134,12,134,253,133,25,136,16,136,17,136,23,136,19,136,22,136,99,137,102,137,185,137,247,137,96,139,106,139,93,139,104,139,99,139,101,139,103,139,109,139,174,141,134,142,136,142,132,142,89,143,86,143,87,143,85,143,88,143,90,143,141,144,67,145,65,145,183,145,181,145,178,145,179,145,11,148,19,148,251,147,32,148,15,148,20,148,254,147,21,148,16,148,40,148,25,148,13,148,245,147,0,148,247,147,7,148,14,148,22,148,18,148,250,147,9,148,248,147,10,148,255,147,252,147,12,148,246,147,17,148,6,148,222,149,224,149,223,149,46,151,47,151,185,151,187,151,253,151,254,151,96,152,98,152,99,152,95,152,193,152,194,152,80,153,78,153,89,153,76,153,75,153,83,153,50,154,52,154,49,154,44,154,42,154,54,154,41,154,46,154,56,154,45,154,199,154,202,154,198,154,16,155,18,155,17,155,11,156,8,156,247,155,5,156,18,156,248,155,64,156,7,156,14,156,6,156,23,156,20,156,9,156,159,157,153,157,164,157,157,157,146,157,152,157,144,157,155,157,160,157,148,157,156,157,170,157,151,157,161,157,154,157,162,157,168,157,158,157,163,157,191,157,169,157,150,157,166,157,167,157,153,158,155,158,154,158,229,158,228,158,231,158,230,158,48,159,46,159,91,159,96,159,94,159,93,159,89,159,145,159,58,81,57,81,152,82,151,82,195,86,189,86,190,86,72,91,71,91,203,93,207,93,241,94,253,97,27,101,2,107,252,106,3,107,248,106,0,107,67,112,68,112,74,112,72,112,73,112,69,112,70,112,29,114,26,114,25,114,126,115,23,117,106,118,208,119,45,121,49,121,47,121,84,124,83,124,242,124,138,126,135,126,136,126,139,126,134,126,141,126,77,127,187,127,48,128,221,129,24,134,42,134,38,134,31,134,35,134,28,134,25,134,39,134,46,134,33,134,32,134,41,134,30,134,37,134,41,136,29,136,27,136,32,136,36,136,28,136,43,136,74,136,109,137,105,137,110,137,107,137,250,137,121,139,120,139,69,139,122,139,123,139,16,141,20,141,175,141,142,142,140,142,94,143,91,143,93,143,70,145,68,145,69,145,185,145,63,148,59,148,54,148,41,148,61,148,60,148,48,148,57,148,42,148,55,148,44,148,64,148,49,148,229,149,228,149,227,149,53,151,58,151,191,151,225,151,100,152,201,152,198,152,192,152,88,153,86,153,57,154,61,154,70,154,68,154,66,154,65,154,58,154,63,154,205,154,21,155,23,155,24,155,22,155,58,155,82,155,43,156,29,156,28,156,44,156,35,156,40,156,41,156,36,156,33,156,183,157,182,157,188,157,193,157,199,157,202,157,207,157,190,157,197,157,195,157,187,157,181,157,206,157,185,157,186,157,172,157,200,157,177,157,173,157,204,157,179,157,205,157,178,157,122,158,156,158,235,158,238,158,237,158,27,159,24,159,26,159,49,159,78,159,101,159,100,159,146,159,185,78,198,86,197,86,203,86,113,89,75,91,76,91,213,93,209,93,242,94,33,101,32,101,38,101,34,101,11,107,8,107,9,107,13,108,85,112,86,112,87,112,82,112,30,114,31,114,169,114,127,115,216,116,213,116,217,116,215,116,109,118,173,118,53,121,180,121,112,122,113,122,87,124,92,124,89,124,91,124,90,124,244,124,241,124,145,126,79,127,135,127,222,129,107,130,52,134,53,134,51,134,44,134,50,134,54,134,44,136,40,136,38,136,42,136,37,136,113,137,191,137,190,137,251,137,126,139,132,139,130,139,134,139,133,139,127,139,21,141,149,142,148,142,154,142,146,142,144,142,150,142,151,142,96,143,98,143,71,145,76,148,80,148,74,148,75,148,79,148,71,148,69,148,72,148,73,148,70,148,63,151,227,151,106,152,105,152,203,152,84,153,91,153,78,154,83,154,84,154,76,154,79,154,72,154,74,154,73,154,82,154,80,154,208,154,25,155,43,155,59,155,86,155,85,155,70,156,72,156,63,156,68,156,57,156,51,156,65,156,60,156,55,156,52,156,50,156,61,156,54,156,219,157,210,157,222,157,218,157,203,157,208,157,220,157,209,157,223,157,233,157,217,157,216,157,214,157,245,157,213,157,221,157,182,158,240,158,53,159,51,159,50,159,66,159,107,159,149,159,162,159,61,81,153,82,232,88,231,88,114,89,77,91,216,93,47,136,79,95,1,98,3,98,4,98,41,101,37,101,150,101,235,102,17,107,18,107,15,107,202,107,91,112,90,112,34,114,130,115,129,115,131,115,112,118,212,119,103,124,102,124,149,126,108,130,58,134,64,134,57,134,60,134,49,134,59,134,62,134,48,136,50,136,46,136,51,136,118,137,116,137,115,137,254,137,140,139,142,139,139,139,136,139,69,140,25,141,152,142,100,143,99,143,188,145,98,148,85,148,93,148,87,148,94,148,196,151,197,151,0,152,86,154,89,154,30,155,31,155,32,155,82,156,88,156,80,156,74,156,77,156,75,156,85,156,89,156,76,156,78,156,251,157,247,157,239,157,227,157,235,157,248,157,228,157,246,157,225,157,238,157,230,157,242,157,240,157,226,157,236,157,244,157,243,157,232,157,237,157,194,158,208,158,242,158,243,158,6,159,28,159,56,159,55,159,54,159,67,159,79,159,113,159,112,159,110,159,111,159,211,86,205,86,78,91,109,92,45,101,237,102,238,102,19,107,95,112,97,112,93,112,96,112,35,114,219,116,229,116,213,119,56,121,183,121,182,121,106,124,151,126,137,127,109,130,67,134,56,136,55,136,53,136,75,136,148,139,149,139,158,142,159,142,160,142,157,142,190,145,189,145,194,145,107,148,104,148,105,148,229,150,70,151,67,151,71,151,199,151,229,151,94,154,213,154,89,155,99,156,103,156,102,156,98,156,94,156,96,156,2,158,254,157,7,158,3,158,6,158,5,158,0,158,1,158,9,158,255,157,253,157,4,158,160,158,30,159,70,159,116,159,117,159,118,159,212,86,46,101,184,101,24,107,25,107,23,107,26,107,98,112,38,114,170,114,216,119,217,119,57,121,105,124,107,124,246,124,154,126,152,126,155,126,153,126,224,129,225,129,70,134,71,134,72,134,121,137,122,137,124,137,123,137,255,137,152,139,153,139,165,142,164,142,163,142,110,148,109,148,111,148,113,148,115,148,73,151,114,152,95,153,104,156,110,156,109,156,11,158,13,158,16,158,15,158,18,158,17,158,161,158,245,158,9,159,71,159,120,159,123,159,122,159,121,159,30,87,102,112,111,124,60,136,178,141,166,142,195,145,116,148,120,148,118,148,117,148,96,154,116,156,115,156,113,156,117,156,20,158,19,158,246,158,10,159,164,159,104,112,101,112,247,124,106,134,62,136,61,136,63,136,158,139,156,140,169,142,201,142,75,151,115,152,116,152,204,152,97,153,171,153,100,154,102,154,103,154,36,155,21,158,23,158,72,159,7,98,30,107,39,114,76,134,168,142,130,148,128,148,129,148,105,154,104,154,46,155,25,158,41,114,75,134,159,139,131,148,121,156,183,158,117,118,107,154,122,156,29,158,105,112,106,112,164,158,126,159,73,159,152,159,129,120,185,146,207,136,187,88,82,96,167,124,250,90,84,37,102,37,87,37,96,37,108,37,99,37,90,37,105,37,93,37,82,37,100,37,85,37,94,37,106,37,97,37,88,37,103,37,91,37,83,37,101,37,86,37,95,37,107,37,98,37,89,37,104,37,92,37,81,37,80,37,109,37,110,37,112,37,111,37,147,37,0,0,0,0,0,0,0,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,1,0,0,0,255,0,0,0,0,0,1,1,0,0,255,255,0,1,1,0,0,255,255,0,1,1,0,0,255,255,0,0,1,0,0,1,255,0,0,255,0,1,0,1,0,255,0,255,1,0,1,0,255,0,255,0,0,0,255,1,0,0,1,255,0,255,1,0,0,1,255,0,255,1,0,0,1,255,0,0,1,0,0,255,255,0,0,1,0,255,0,1,0,1,0,255,255,0,1,0,1,0,255,0,0,1,1,1,0,255,255,255,1,1,1,0,255,255,255,0,1,1,0,1,255,255,0,255,1,0,1,1,255,0,255,255,0,255,1,1,0,1,255,255,255,1,1,0,1,255,255,0,1,1,0,255,255,255,0,1,1,0,255,1,255,0,1,255,0,1,255,1,0,255,1,255,1,255,1,0,255,1,255,0,255,1,0,1,1,255,0,255,1,0,1,255,255,0,255,1,0,1,1,255,0,255,255,1,1,1,255,0,255,255,1,0,1,255,0,1,255,1,0,255,255,0,1,1,1,0,255,255,1,1,1,1,255,255,255,255,1,1,1,255,255,255,255,1,1,1,255,1,255,255,1,255,1,255,1,1,255,1,255,255,255,1,1,1,1,255,255,255,1,1,255,255,255,255,1,1,1,255,255,1,255,1,1,255,1,255,1,255,255,1,255,1,0,8,32,64,80,0,0,0,117,139,63,193,17,239,1,255,180,76,80,176,18,238,118,138,134,122,64,192,54,202,46,210,16,240,140,116,100,156,62,194,197,59,81,175,135,121,181,75,163,93,79,177,157,99,55,201,71,185,47,209,133,123,203,53,219,37,211,45,101,155,179,77,198,58,220,36,72,184,164,92,196,60,94,162,38,218,186,70,74,170,170,170,186,186,186,170,170,170,170,170,170,170,170,171,170,170,170,170,170,154,169,169,153,169,153,153,169,169,153,153,153,153,153,153,153,153,136,152,136,136,136,136,136,136,136,136,119,120,119,119,119,119,102,102,102,85,85,85,85,84,68,50,68,85,85,102,102,102,102,119,119,119,119,119,119,135,136,136,136,136,136,136,136,136,136,137,136,137,137,153,153,152,153,154,153,153,153,153,154,169,154,153,154,169,169,169,170,170,169,170,170,170,170,170,187,170,170,170,170,186,170,170,170,170,186,64,76,188,172,188,186,171,171,187,186,170,171,170,187,170,187,170,171,186,186,170,187,170,169,170,187,170,170,154,154,170,169,170,153,153,153,153,153,153,153,153,152,152,152,137,136,136,136,136,135,120,119,119,119,119,103,102,102,85,68,69,84,68,68,51,68,69,85,86,102,102,102,103,119,119,119,119,135,135,120,136,136,136,136,136,153,136,153,153,137,153,153,153,153,153,153,169,169,170,154,169,170,154,170,154,170,171,170,170,170,170,170,170,187,188,187,186,170,171,171,170,171,171,172,187,170,187,187,64,91,187,188,187,203,204,187,187,188,204,187,203,186,203,188,187,170,187,171,186,187,187,171,187,170,186,186,170,170,170,170,170,170,170,169,154,154,153,154,153,153,153,153,153,152,152,137,153,136,136,136,136,119,119,119,119,119,102,102,85,84,68,67,34,52,68,85,86,102,102,103,119,119,119,135,136,136,136,136,136,153,137,153,153,153,153,153,154,154,169,169,154,154,170,154,170,170,170,186,170,170,170,186,170,170,171,186,187,170,187,171,187,187,187,187,187,187,187,187,188,187,188,187,187,204,188,203,80,0,0,32,0,64,0,96,0,8,0,40,0,72,0,104,0,12,0,44,0,76,0,108,0,20,0,52,0,84,0,116,0,26,0,58,0,90,0,122,0,128,0,160,0,192,0,224,0,134,0,166,0,198,0,230,0,141,0,173,0,205,0,237,0,150,0,182,0,214,0,246,0,0,1,32,1,64,1,96,1,128,1,160,1,192,1,224,1,12,1,44,1,76,1,108,1,140,1,172,1,204,1,236,1,0,0,8,0,16,0,24,0,32,0,36,0,40,0,44,0,48,0,56,0,64,0,72,0,80,0,86,0,92,0,98,0,104,0,110,0,116,0,122,0,128,0,134,0,140,0,146,0,152,0,159,0,166,0,173,0,180,0,189,0,198,0,207,0,216,0,226,0,236,0,246,0,0,1,12,1,24,1,36,1,48,1,60,1,72,1,84,1,96,1,116,1,136,1,156,1,176,1,196,1,216,1,236,1,0,20,36,52,0,0,0,0,0,24,36,48,72,108,132,156,0,112,176,208,0,0,0,0,20,28,32,36,40,44,48,52,0,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,7,8,9,10,11,12,13,14,15,16,17,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,54,56,58,60,62,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,3,3,3,3,4,4,4,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,17,17,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,7,7,7,8,8,8,9,9,10,10,11,11,12,13,14,15,16,17,18,19,20,21,22,23,23,24,24,25,25,26,27,0,0,0,0,0,0,240,63,0,0,0,0,0,0,208,63,28,199,113,28,199,113,188,63,0,0,0,0,0,0,176,63,123,20,174,71,225,122,164,63,28,199,113,28,199,113,156,63,57,5,47,167,224,229,148,63,0,0,0,0,0,0,144,63,224,233,214,252,176,72,137,63,123,20,174,71,225,122,132,63,144,156,230,107,245,236,128,63,28,199,113,28,199,113,124,63,221,190,178,122,151,60,120,63,57,5,47,167,224,229,116,63,223,188,154,120,86,52,114,63,0,0,0,0,0,0,112,63,134,73,13,209,148,88,108,63,224,233,214,252,176,72,105,63,61,26,163,10,73,177,102,63,123,20,174,71,225,122,100,63,165,4,184,91,114,147,98,63,144,156,230,107,245,236,96,63,173,235,137,179,189,248,94,63,28,199,113,28,199,113,92,63,45,67,28,235,226,54,90,63,221,190,178,122,151,60,88,63,199,8,191,224,128,121,86,63,57,5,47,167,224,229,84,63,68,39,135,36,72,123,83,63,223,188,154,120,86,52,82,63,46,149,208,49,133,12,81,63,0,0,0,0,0,0,80,63,85,22,97,163,9,23,78,63,134,73,13,209,148,88,76,63,166,47,60,224,215,191,74,63,224,233,214,252,176,72,73,63,235,216,56,80,139,239,71,63,61,26,163,10,73,177,70,63,140,226,158,80,49,139,69,63,123,20,174,71,225,122,68,63,139,225,71,168,63,126,67,63,165,4,184,91,114,147,66,63,57,159,146,197,213,184,65,63,144,156,230,107,245,236,64,63,113,139,137,192,133,46,64,63,173,235,137,179,189,248,62,63,26,191,47,228,239,170,61,63,28,199,113,28,199,113,60,63,253,126,249,92,152,75,59,63,45,67,28,235,226,54,58,63,176,150,125,100,75,50,57,63,221,190,178,122,151,60,56,63,224,58,202,61,170,84,55,63,199,8,191,224,128,121,54,63,31,231,69,230,47,170,53,63,57,5,47,167,224,229,52,63,54,80,230,37,207,43,52,63,68,39,135,36,72,123,51,63,201,111,144,116,167,211,50,63,223,188,154,120,86,52,50,63,57,149,143,209,202,156,49,63,46,149,208,49,133,12,49,63,147,32,135,81,16,131,48,63,0,0,0,0,0,0,48,63,27,193,13,157,224,5,47,63,85,22,97,163,9,23,46,63,141,167,214,236,207,50,45,63,134,73,13,209,148,88,44,63,210,38,94,17,197,135,43,63,166,47,60,224,215,191,42,63,190,2,234,0,78,0,42,63,224,233,214,252,176,72,41,63,155,172,71,108,146,152,40,63,235,216,56,80,139,239,39,63,40,88,167,123,59,77,39,63,61,26,163,10,73,177,38,63,31,126,191,229,95,27,38,63,140,226,158,80,49,139,37,63,166,77,123,130,115,0,37,63,123,20,174,71,225,122,36,63,149,121,84,171,57,250,35,63,139,225,71,168,63,126,35,63,81,240,181,224,185,6,35,63,165,4,184,91,114,147,34,63,127,108,90,72,54,36,34,63,57,159,146,197,213,184,33,63,118,6,177,174,35,81,33,63,144,156,230,107,245,236,32,63,43,21,129,198,34,140,32,63,113,139,137,192,133,46,32,63,158,233,243,222,244,167,31,63,173,235,137,179,189,248,30,63,109,151,228,173,37,79,30,63,26,191,47,228,239,170,29,63,47,187,249,156,226,11,29,63,28,199,113,28,199,113,28,63,250,44,75,117,105,220,27,63,253,126,249,92,152,75,27,63,104,247,0,3,37,191,26,63,45,67,28,235,226,54,26,63,184,6,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,37,0,216,255,35,0,4,0,0,0,1,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,111,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,6,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,239,37,0,112,0,0,0,224,212,29,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,187,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,89,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,130,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,0,89,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,104,36,0,184,76,36,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,152,104,36,0,184,53,36,0,0,13,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,80,216,35,0,56,191,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,112,168,35,0,160,146,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,16,124,35,0,232,101,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,160,83,35,0,160,117,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,0,49,35,0,160,117,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,224,101,34,0,88,73,34,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,48,37,34,0,88,73,34,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,140,192,0,0,0,0,0,32,140,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,206,36,0,112,0,0,0,232,213,29,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,0,0,3,0,0,4,0,1,0,0,1,1,0,1,2,0,1,3,0,1,4,0,2,0,0,2,1,0,2,2,0,2,3,0,2,4,0,3,0,0,3,1,0,3,2,0,3,3,0,3,4,0,4,0,0,4,1,0,4,2,0,4,3,0,4,4,1,0,0,1,0,1,1,0,2,1,0,3,1,0,4,1,1,0,1,1,1,1,1,2,1,1,3,1,1,4,1,2,0,1,2,1,1,2,2,1,2,3,1,2,4,1,3,0,1,3,1,1,3,2,1,3,3,1,3,4,1,4,0,1,4,1,1,4,2,1,4,3,1,4,4,2,0,0,2,0,1,2,0,2,2,0,3,2,0,4,2,1,0,2,1,1,2,1,2,2,1,3,2,1,4,2,2,0,2,2,1,2,2,2,2,2,3,2,2,4,2,3,0,2,3,1,2,3,2,2,3,3,2,3,4,2,4,0,2,4,1,2,4,2,2,4,3,2,4,4,3,0,0,3,0,1,3,0,2,3,0,3,3,0,4,3,1,0,3,1,1,3,1,2,3,1,3,3,1,4,3,2,0,3,2,1,3,2,2,3,2,3,3,2,4,3,3,0,3,3,1,3,3,2,3,3,3,3,3,4,3,4,0,3,4,1,3,4,2,3,4,3,3,4,4,4,0,0,4,0,1,4,0,2,4,0,3,4,0,4,4,1,0,4,1,1,4,1,2,4,1,3,4,1,4,4,2,0,4,2,1,4,2,2,4,2,3,4,2,4,4,3,0,4,3,1,4,3,2,4,3,3,4,3,4,4,4,0,4,4,1,4,4,2,4,4,3,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,128,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,96,0,0,3,0,3,0,3,0,3,0,4,0,5,0,6,0,8,0,12,0,17,0,0,0,0,0,2,0,1,0,2,0,2,0,3,0,4,0,5,0,7,0,13,0,25,0,0,0,0,0,1,0,2,0,1,0,2,0,3,0,4,0,6,0,10,0,23,0,76,0,0,0,0,0,1,0,2,0,1,0,2,0,3,0,4,0,6,0,10,0,23,0,76,0,0,0,0,0,3,0,2,0,3,0,4,0,4,0,6,0,9,0,14,0,26,0,57,0,0,0,0,0,3,0,2,0,3,0,4,0,4,0,6,0,9,0,14,0,26,0,57,0,0,0,0,0,1,0,2,0,1,0,2,0,3,0,4,0,6,0,10,0,23,0,76,0,0,0,0,0,3,0,4,0,4,0,4,0,5,0,7,0,10,0,16,0,26,0,49,0,0,0,0,0,3,0,4,0,4,0,4,0,5,0,7,0,10,0,16,0,26,0,49,0,0,0,0,0,2,0,2,0,2,0,3,0,3,0,5,0,7,0,12,0,25,0,67,0,0,0,0,0,2,0,3,0,2,0,3,0,3,0,4,0,6,0,8,0,12,0,21,0,0,0,0,0,2,0,3,0,2,0,3,0,3,0,4,0,6,0,8,0,12,0,21,0,0,0,0,0,2,0,1,0,2,0,3,0,4,0,6,0,13,0,33,0,3,0,3,0,3,0,3,0,4,0,5,0,6,0,8,0,12,0,17,0,0,0,0,0,6,0,5,0,6,0,6,0,6,0,6,0,7,0,7,0,8,0,8,0,9,0,10,0,11,0,13,0,15,0,18,0,20,0,25,0,31,0,39,0,3,0,4,0,3,0,4,0,3,0,4,0,4,0,5,0,5,0,6,0,6,0,8,0,9,0,11,0,13,0,17,0,23,0,29,0,41,0,58,0,3,0,2,0,3,0,3,0,3,0,4,0,3,0,5,0,4,0,6,0,7,0,8,0,10,0,14,0,18,0,25,0,36,0,55,0,95,0,208,0,3,0,2,0,3,0,3,0,3,0,4,0,3,0,5,0,4,0,6,0,7,0,8,0,10,0,14,0,18,0,25,0,36,0,55,0,95,0,208,0,5,0,5,0,5,0,6,0,5,0,7,0,6,0,7,0,9,0,9,0,11,0,13,0,15,0,20,0,24,0,33,0,43,0,61,0,88,0,140,0,5,0,5,0,5,0,6,0,5,0,7,0,6,0,7,0,9,0,9,0,11,0,13,0,15,0,20,0,24,0,33,0,43,0,61,0,88,0,140,0,3,0,2,0,3,0,3,0,3,0,4,0,3,0,5,0,4,0,6,0,7,0,8,0,10,0,14,0,18,0,25,0,36,0,55,0,95,0,208,0,3,0,2,0,3,0,2,0,3,0,3,0,4,0,3,0,4,0,5,0,5,0,7,0,8,0,9,0,13,0,16,0,22,0,30,0,44,0,70,0,7,0,6,0,7,0,7,0,7,0,8,0,9,0,9,0,10,0,11,0,14,0,15,0,18,0,22,0,27,0,34,0,44,0,59,0,81,0,117,0,7,0,6,0,7,0,7,0,7,0,8,0,9,0,9,0,10,0,11,0,14,0,15,0,18,0,22,0,27,0,34,0,44,0,59,0,81,0,117,0,3,0,3,0,3,0,3,0,4,0,3,0,4,0,4,0,4,0,5,0,5,0,6,0,7,0,8,0,10,0,12,0,14,0,18,0,24,0,30,0,42,0,59,0,89,0,152,0,4,0,5,0,4,0,5,0,5,0,5,0,6,0,5,0,7,0,7,0,8,0,9,0,10,0,12,0,15,0,17,0,22,0,28,0,35,0,47,0,4,0,5,0,4,0,5,0,5,0,5,0,6,0,5,0,7,0,7,0,8,0,9,0,10,0,12,0,15,0,17,0,22,0,28,0,35,0,47,0,3,0,3,0,4,0,3,0,4,0,4,0,5,0,6,0,7,0,9,0,11,0,15,0,21], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1947185);
/* memory initializer */ allocate([0,30,0,48,0,83,0,6,0,5,0,6,0,6,0,6,0,6,0,7,0,7,0,8,0,8,0,9,0,10,0,11,0,13,0,15,0,18,0,20,0,25,0,31,0,39,0,7,0,8,0,7,0,8,0,8,0,8,0,8,0,8,0,8,0,9,0,9,0,10,0,10,0,11,0,11,0,12,0,12,0,14,0,15,0,16,0,18,0,19,0,21,0,24,0,27,0,30,0,35,0,40,0,46,0,53,0,0,0,0,0,4,0,5,0,4,0,5,0,4,0,5,0,5,0,5,0,5,0,6,0,6,0,6,0,6,0,8,0,7,0,9,0,9,0,11,0,11,0,14,0,15,0,17,0,20,0,24,0,28,0,34,0,41,0,51,0,64,0,83,0,0,0,0,0,5,0,6,0,5,0,6,0,5,0,6,0,6,0,6,0,6,0,6,0,7,0,7,0,7,0,8,0,8,0,9,0,9,0,10,0,11,0,11,0,13,0,14,0,16,0,17,0,19,0,22,0,25,0,29,0,33,0,39,0,46,0,54,0,64,0,79,0,98,0,123,0,161,0,220,0,64,1,0,2,5,0,6,0,5,0,6,0,5,0,6,0,6,0,6,0,6,0,6,0,7,0,7,0,7,0,8,0,8,0,9,0,9,0,10,0,11,0,11,0,13,0,14,0,16,0,17,0,19,0,22,0,25,0,29,0,33,0,39,0,46,0,54,0,64,0,79,0,98,0,123,0,161,0,220,0,64,1,0,2,6,0,7,0,6,0,6,0,7,0,7,0,7,0,7,0,7,0,8,0,9,0,8,0,10,0,10,0,11,0,12,0,13,0,15,0,16,0,18,0,21,0,24,0,27,0,33,0,38,0,46,0,55,0,68,0,84,0,107,0,140,0,191,0,3,0,3,0,3,0,4,0,3,0,3,0,4,0,3,0,4,0,4,0,4,0,5,0,4,0,5,0,6,0,6,0,7,0,7,0,8,0,9,0,10,0,12,0,14,0,16,0,20,0,22,0,28,0,34,0,42,0,53,0,71,0,95,0,6,0,7,0,6,0,6,0,7,0,7,0,7,0,7,0,7,0,8,0,9,0,8,0,10,0,10,0,11,0,12,0,13,0,15,0,16,0,18,0,21,0,24,0,27,0,33,0,38,0,46,0,55,0,68,0,84,0,107,0,140,0,191,0,3,0,4,0,3,0,4,0,3,0,4,0,4,0,4,0,4,0,4,0,5,0,5,0,5,0,6,0,7,0,7,0,8,0,9,0,11,0,12,0,14,0,16,0,20,0,24,0,29,0,36,0,45,0,60,0,80,0,113,0,173,0,46,1,9,0,9,0,8,0,9,0,10,0,9,0,10,0,10,0,10,0,12,0,11,0,13,0,13,0,14,0,16,0,17,0,19,0,20,0,24,0,26,0,30,0,35,0,40,0,48,0,56,0,68,0,83,0,102,0,128,0,165,0,0,0,0,0,9,0,9,0,8,0,9,0,10,0,9,0,10,0,10,0,10,0,12,0,11,0,13,0,13,0,14,0,16,0,17,0,19,0,20,0,24,0,26,0,30,0,35,0,40,0,48,0,56,0,68,0,83,0,102,0,128,0,165,0,0,0,0,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,6,0,6,0,7,0,7,0,7,0,8,0,9,0,10,0,11,0,12,0,14,0,17,0,19,0,22,0,27,0,33,0,40,0,51,0,64,0,84,0,114,0,164,0,1,1,0,0,0,0,6,0,6,0,6,0,6,0,6,0,6,0,7,0,6,0,7,0,7,0,8,0,8,0,8,0,9,0,10,0,10,0,11,0,13,0,13,0,15,0,17,0,18,0,21,0,25,0,27,0,33,0,38,0,45,0,54,0,66,0,0,0,0,0,6,0,6,0,6,0,6,0,6,0,6,0,7,0,6,0,7,0,7,0,8,0,8,0,8,0,9,0,10,0,10,0,11,0,13,0,13,0,15,0,17,0,18,0,21,0,25,0,27,0,33,0,38,0,45,0,54,0,66,0,0,0,0,0,4,0,4,0,5,0,4,0,5,0,4,0,5,0,6,0,6,0,6,0,7,0,8,0,9,0,10,0,12,0,14,0,17,0,21,0,27,0,33,0,44,0,58,0,82,0,121,0,7,0,8,0,7,0,8,0,8,0,8,0,8,0,8,0,8,0,9,0,9,0,10,0,10,0,11,0,11,0,12,0,12,0,14,0,15,0,16,0,18,0,19,0,21,0,24,0,27,0,30,0,35,0,40,0,46,0,53,0,0,0,0,0,96,187,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,130,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,104,36,0,184,76,36,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,152,104,36,0,184,53,36,0,0,13,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,80,216,35,0,56,191,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,112,168,35,0,160,146,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,16,124,35,0,232,101,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,160,83,35,0,96,164,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,0,49,35,0,96,164,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,146,32,0,112,0,0,0,56,226,29,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,187,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,130,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,104,36,0,184,76,36,0,8,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,152,104,36,0,184,53,36,0,0,13,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,80,216,35,0,56,191,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,112,168,35,0,160,146,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,16,124,35,0,232,101,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,160,83,35,0,96,164,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,0,49,35,0,96,164,34,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,56,143,64,8,0,1,0,0,0,0,0,248,146,34,0,104,133,34,0,16,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,109,33,0,112,0,0,0,72,228,29,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,6,0,9,0,12,0,16,0,20,0,24,0,29,0,34,0,40,0,46,0,53,0,60,0,68,0,76,0,84,0,93,0,102,0,111,0,121,0,131,0,141,0,151,0,162,0,173,0,184,0,195,0,207,0,219,0,231,0,243,0,0,1,0,0,0,0,0,0,4,4,4,4,6,8,10,12,14,18,22,30,56,4,4,4,4,6,6,10,12,14,16,20,26,66,4,4,4,4,6,8,12,16,20,26,34,42,12,4,4,4,6,6,8,10,14,18,26,32,42,18,4,4,4,6,8,10,12,14,18,24,32,44,12,4,4,4,6,8,10,12,14,18,24,30,40,18,4,4,4,6,8,10,12,14,18,24,30,40,18,4,4,4,6,8,10,12,14,18,24,30,40,18,8,8,8,12,16,20,24,28,36,2,2,2,26,0,0,0,4,4,4,4,6,8,10,12,14,18,22,30,56,4,4,4,4,6,6,10,12,14,16,20,26,66,4,4,4,4,6,8,12,16,20,26,34,42,12,4,4,4,6,6,8,10,14,18,26,32,42,18,4,4,4,6,8,10,12,14,18,24,32,44,12,4,4,4,6,8,10,12,14,18,24,30,40,18,4,4,4,6,8,10,12,14,18,24,30,40,18,4,4,4,6,8,10,12,14,18,24,30,40,18,8,8,8,12,16,20,24,28,36,2,2,2,26,0,0,0,4,4,4,4,4,4,6,6,8,8,10,12,16,20,24,28,34,42,50,54,76,158,4,4,4,4,4,4,6,6,6,8,10,12,16,18,22,28,34,40,46,54,54,192,4,4,4,4,4,4,6,6,8,10,12,16,20,24,30,38,46,56,68,84,102,26,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,18,22,26,32,38,46,52,64,70,76,36,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,12,12,12,12,12,12,16,20,24,28,32,40,48,56,64,76,90,2,2,2,2,2,0,0,4,4,4,4,4,4,6,6,8,8,10,12,16,20,24,28,34,42,50,54,76,158,4,4,4,4,4,4,6,6,6,8,10,12,16,18,22,28,34,40,46,54,54,192,4,4,4,4,4,4,6,6,8,10,12,16,20,24,30,38,46,56,68,84,102,26,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,18,22,26,32,38,46,52,64,70,76,36,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,6,6,6,6,6,6,8,10,12,14,16,20,24,28,32,38,46,52,60,68,58,54,12,12,12,12,12,12,16,20,24,28,32,40,48,56,64,76,90,2,2,2,2,2,0,0,1,0,2,0,3,0,4,0,3,0,3,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,43,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,235,0,0,0,0,0,1,0,2,0,3,0,4,0,11,0,235,3,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,0,1,1,0,8,16,1,0,8,64,1,0,8,80,1,0,16,48,2,0,32,48,2,0,16,192,2,0,32,192,2,0,16,240,2,0,32,240,2,0,64,48,4,0,64,192,4,0,64,240,4,0,0,0,0,0,0,1,1,0,8,16,1,0,8,64,1,0,8,80,1,0,16,48,2,0,32,48,2,0,16,192,2,0,32,192,2,0,16,240,2,0,32,240,2,0,64,48,4,0,64,192,4,0,64,240,4,0,0,0,0,0,0,241,1,0,8,16,1,0,8,64,1,0,8,80,1,0,16,48,2,0,32,48,2,0,16,192,2,0,32,192,2,0,16,144,2,0,32,144,2,0,16,96,2,0,32,96,2,0,16,176,2,0,32,176,2,0,16,224,2,0,32,224,2,0,16,112,2,0,32,112,2,0,16,208,2,0,32,208,2,0,16,240,2,0,32,240,2,0,64,240,4,0,0,0,0,0,0,241,1,0,8,16,1,0,8,64,1,0,8,80,1,0,16,48,2,0,32,48,2,0,16,192,2,0,32,192,2,0,16,144,2,0,32,144,2,0,16,96,2,0,32,96,2,0,16,176,2,0,32,176,2,0,16,224,2,0,32,224,2,0,16,112,2,0,32,112,2,0,16,208,2,0,32,208,2,0,16,240,2,0,32,240,2,0,64,240,4,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,3,0,0,0,4,0,0,0,0,0,0,0,245,255,247,255,249,255,251,255,253,255,255,255,1,0,3,0,5,0,7,0,9,0,11,0,13,0,15,0,18,0,17,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,35,0,37,0,39,0,41,0,43,0,45,0,47,0,49,0,51,0,53,0,55,0,57,0,59,0,61,0,63,0,65,0,67,0,69,0,71,0,73,0,75,0,77,0,79,0,81,0,83,0,85,0,87,0,89,0,91,0,93,0,95,0,97,0,99,0,101,0,103,0,105,0,107,0,109,0,111,0,113,0,115,0,117,0,119,0,121,0,123,0,125,0,127,0,129,0,131,0,133,0,135,0,137,0,139,0,141,0,143,0,145,0,147,0,149,0,151,0,153,0,155,0,157,0,159,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,8,0,0,0,12,0,0,0,9,0,0,0,13,0,0,0,2,0,0,0,6,0,0,0,3,0,0,0,7,0,0,0,10,0,0,0,14,0,0,0,11,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,129,165,129,129,189,153,129,129,126,0,0,0,0,0,0,126,255,219,255,255,195,231,255,255,126,0,0,0,0,0,0,0,0,108,254,254,254,254,124,56,16,0,0,0,0,0,0,0,0,16,56,124,254,124,56,16,0,0,0,0,0,0,0,0,24,60,60,231,231,231,24,24,60,0,0,0,0,0,0,0,24,60,126,255,255,126,24,24,60,0,0,0,0,0,0,0,0,0,0,24,60,60,24,0,0,0,0,0,0,255,255,255,255,255,255,231,195,195,231,255,255,255,255,255,255,0,0,0,0,0,60,102,66,66,102,60,0,0,0,0,0,255,255,255,255,255,195,153,189,189,153,195,255,255,255,255,255,0,0,30,14,26,50,120,204,204,204,204,120,0,0,0,0,0,0,60,102,102,102,102,60,24,126,24,24,0,0,0,0,0,0,63,51,63,48,48,48,48,112,240,224,0,0,0,0,0,0,127,99,127,99,99,99,99,103,231,230,192,0,0,0,0,0,0,24,24,219,60,231,60,219,24,24,0,0,0,0,0,128,192,224,240,248,254,248,240,224,192,128,0,0,0,0,0,2,6,14,30,62,254,62,30,14,6,2,0,0,0,0,0,0,24,60,126,24,24,24,126,60,24,0,0,0,0,0,0,0,102,102,102,102,102,102,102,0,102,102,0,0,0,0,0,0,127,219,219,219,123,27,27,27,27,27,0,0,0,0,0,124,198,96,56,108,198,198,108,56,12,198,124,0,0,0,0,0,0,0,0,0,0,0,254,254,254,254,0,0,0,0,0,0,24,60,126,24,24,24,126,60,24,126,0,0,0,0,0,0,24,60,126,24,24,24,24,24,24,24,0,0,0,0,0,0,24,24,24,24,24,24,24,126,60,24,0,0,0,0,0,0,0,0,0,24,12,254,12,24,0,0,0,0,0,0,0,0,0,0,0,48,96,254,96,48,0,0,0,0,0,0,0,0,0,0,0,0,192,192,192,254,0,0,0,0,0,0,0,0,0,0,0,36,102,255,102,36,0,0,0,0,0,0,0,0,0,0,16,56,56,124,124,254,254,0,0,0,0,0,0,0,0,0,254,254,124,124,56,56,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,60,60,60,24,24,24,0,24,24,0,0,0,0,0,102,102,102,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,108,254,108,108,108,254,108,108,0,0,0,0,24,24,124,198,194,192,124,6,6,134,198,124,24,24,0,0,0,0,0,0,194,198,12,24,48,96,198,134,0,0,0,0,0,0,56,108,108,56,118,220,204,204,204,118,0,0,0,0,0,48,48,48,96,0,0,0,0,0,0,0,0,0,0,0,0,0,12,24,48,48,48,48,48,48,24,12,0,0,0,0,0,0,48,24,12,12,12,12,12,12,24,48,0,0,0,0,0,0,0,0,0,102,60,255,60,102,0,0,0,0,0,0,0,0,0,0,0,24,24,126,24,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,48,0,0,0,0,0,0,0,0,0,0,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,0,2,6,12,24,48,96,192,128,0,0,0,0,0,0,60,102,195,195,219,219,195,195,102,60,0,0,0,0,0,0,24,56,120,24,24,24,24,24,24,126,0,0,0,0,0,0,124,198,6,12,24,48,96,192,198,254,0,0,0,0,0,0,124,198,6,6,60,6,6,6,198,124,0,0,0,0,0,0,12,28,60,108,204,254,12,12,12,30,0,0,0,0,0,0,254,192,192,192,252,6,6,6,198,124,0,0,0,0,0,0,56,96,192,192,252,198,198,198,198,124,0,0,0,0,0,0,254,198,6,6,12,24,48,48,48,48,0,0,0,0,0,0,124,198,198,198,124,198,198,198,198,124,0,0,0,0,0,0,124,198,198,198,126,6,6,6,12,120,0,0,0,0,0,0,0,0,24,24,0,0,0,24,24,0,0,0,0,0,0,0,0,0,24,24,0,0,0,24,24,48,0,0,0,0,0,0,0,6,12,24,48,96,48,24,12,6,0,0,0,0,0,0,0,0,0,126,0,0,126,0,0,0,0,0,0,0,0,0,0,96,48,24,12,6,12,24,48,96,0,0,0,0,0,0,124,198,198,12,24,24,24,0,24,24,0,0,0,0,0,0,0,124,198,198,222,222,222,220,192,124,0,0,0,0,0,0,16,56,108,198,198,254,198,198,198,198,0,0,0,0,0,0,252,102,102,102,124,102,102,102,102,252,0,0,0,0,0,0,60,102,194,192,192,192,192,194,102,60,0,0,0,0,0,0,248,108,102,102,102,102,102,102,108,248,0,0,0,0,0,0,254,102,98,104,120,104,96,98,102,254,0,0,0,0,0,0,254,102,98,104,120,104,96,96,96,240,0,0,0,0,0,0,60,102,194,192,192,222,198,198,102,58,0,0,0,0,0,0,198,198,198,198,254,198,198,198,198,198,0,0,0,0,0,0,60,24,24,24,24,24,24,24,24,60,0,0,0,0,0,0,30,12,12,12,12,12,204,204,204,120,0,0,0,0,0,0,230,102,102,108,120,120,108,102,102,230,0,0,0,0,0,0,240,96,96,96,96,96,96,98,102,254,0,0,0,0,0,0,195,231,255,255,219,195,195,195,195,195,0,0,0,0,0,0,198,230,246,254,222,206,198,198,198,198,0,0,0,0,0,0,124,198,198,198,198,198,198,198,198,124,0,0,0,0,0,0,252,102,102,102,124,96,96,96,96,240,0,0,0,0,0,0,124,198,198,198,198,198,198,214,222,124,12,14,0,0,0,0,252,102,102,102,124,108,102,102,102,230,0,0,0,0,0,0,124,198,198,96,56,12,6,198,198,124,0,0,0,0,0,0,255,219,153,24,24,24,24,24,24,60,0,0,0,0,0,0,198,198,198,198,198,198,198,198,198,124,0,0,0,0,0,0,195,195,195,195,195,195,195,102,60,24,0,0,0,0,0,0,195,195,195,195,195,219,219,255,102,102,0,0,0,0,0,0,195,195,102,60,24,24,60,102,195,195,0,0,0,0,0,0,195,195,195,102,60,24,24,24,24,60,0,0,0,0,0,0,255,195,134,12,24,48,96,193,195,255,0,0,0,0,0,0,60,48,48,48,48,48,48,48,48,60,0,0,0,0,0,0,0,128,192,224,112,56,28,14,6,2,0,0,0,0,0,0,60,12,12,12,12,12,12,12,12,60,0,0,0,0,16,56,108,198,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,48,48,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,12,124,204,204,204,118,0,0,0,0,0,0,224,96,96,120,108,102,102,102,102,124,0,0,0,0,0,0,0,0,0,124,198,192,192,192,198,124,0,0,0,0,0,0,28,12,12,60,108,204,204,204,204,118,0,0,0,0,0,0,0,0,0,124,198,254,192,192,198,124,0,0,0,0,0,0,56,108,100,96,240,96,96,96,96,240,0,0,0,0,0,0,0,0,0,118,204,204,204,204,204,124,12,204,120,0,0,0,224,96,96,108,118,102,102,102,102,230,0,0,0,0,0,0,24,24,0,56,24,24,24,24,24,60,0,0,0,0,0,0,6,6,0,14,6,6,6,6,6,6,102,102,60,0,0,0,224,96,96,102,108,120,120,108,102,230,0,0,0,0,0,0,56,24,24,24,24,24,24,24,24,60,0,0,0,0,0,0,0,0,0,230,255,219,219,219,219,219,0,0,0,0,0,0,0,0,0,220,102,102,102,102,102,102,0,0,0,0,0,0,0,0,0,124,198,198,198,198,198,124,0,0,0,0,0,0,0,0,0,220,102,102,102,102,102,124,96,96,240,0,0,0,0,0,0,118,204,204,204,204,204,124,12,12,30,0,0,0,0,0,0,220,118,102,96,96,96,240,0,0,0,0,0,0,0,0,0,124,198,96,56,12,198,124,0,0,0,0,0,0,16,48,48,252,48,48,48,48,54,28,0,0,0,0,0,0,0,0,0,204,204,204,204,204,204,118,0,0,0,0,0,0,0,0,0,195,195,195,195,102,60,24,0,0,0,0,0,0,0,0,0,195,195,195,219,219,255,102,0,0,0,0,0,0,0,0,0,195,102,60,24,60,102,195,0,0,0,0,0,0,0,0,0,198,198,198,198,198,198,126,6,12,248,0,0,0,0,0,0,254,204,24,48,96,198,254,0,0,0,0,0,0,14,24,24,24,112,24,24,24,24,14,0,0,0,0,0,0,24,24,24,24,0,24,24,24,24,24,0,0,0,0,0,0,112,24,24,24,14,24,24,24,24,112,0,0,0,0,0,0,118,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,56,108,198,198,198,254,0,0,0,0,0,0,0,60,102,194,192,192,192,194,102,60,12,6,124,0,0,0,0,204,0,0,204,204,204,204,204,204,118,0,0,0,0,0,12,24,48,0,124,198,254,192,192,198,124,0,0,0,0,0,16,56,108,0,120,12,124,204,204,204,118,0,0,0,0,0,0,204,0,0,120,12,124,204,204,204,118,0,0,0,0,0,96,48,24,0,120,12,124,204,204,204,118,0,0,0,0,0,56,108,56,0,120,12,124,204,204,204,118,0,0,0,0,0,0,0,0,60,102,96,96,102,60,12,6,60,0,0,0,0,16,56,108,0,124,198,254,192,192,198,124,0,0,0,0,0,0,198,0,0,124,198,254,192,192,198,124,0,0,0,0,0,96,48,24,0,124,198,254,192,192,198,124,0,0,0,0,0,0,102,0,0,56,24,24,24,24,24,60,0,0,0,0,0,24,60,102,0,56,24,24,24,24,24,60,0,0,0,0,0,96,48,24,0,56,24,24,24,24,24,60,0,0,0,0,0,198,0,16,56,108,198,198,254,198,198,198,0,0,0,0,56,108,56,0,56,108,198,198,254,198,198,198,0,0,0,0,24,48,96,0,254,102,96,124,96,96,102,254,0,0,0,0,0,0,0,0,0,110,59,27,126,216,220,119,0,0,0,0,0,0,62,108,204,204,254,204,204,204,204,206,0,0,0,0,0,16,56,108,0,124,198,198,198,198,198,124,0,0,0,0,0,0,198,0,0,124,198,198,198,198,198,124,0,0,0,0,0,96,48,24,0,124,198,198,198,198,198,124,0,0,0,0,0,48,120,204,0,204,204,204,204,204,204,118,0,0,0,0,0,96,48,24,0,204,204,204,204,204,204,118,0,0,0,0,0,0,198,0,0,198,198,198,198,198,198,126,6,12,120,0,0,198,0,124,198,198,198,198,198,198,198,124,0,0,0,0,0,198,0,198,198,198,198,198,198,198,198,124,0,0,0,0,0,24,24,126,195,192,192,192,195,126,24,24,0,0,0,0,0,56,108,100,96,240,96,96,96,96,230,252,0,0,0,0,0,0,195,102,60,24,255,24,255,24,24,24,0,0,0,0,0,252,102,102,124,98,102,111,102,102,102,243,0,0,0,0,0,14,27,24,24,24,126,24,24,24,24,24,216,112,0,0,0,24,48,96,0,120,12,124,204,204,204,118,0,0,0,0,0,12,24,48,0,56,24,24,24,24,24,60,0,0,0,0,0,24,48,96,0,124,198,198,198,198,198,124,0,0,0,0,0,24,48,96,0,204,204,204,204,204,204,118,0,0,0,0,0,0,118,220,0,220,102,102,102,102,102,102,0,0,0,0,118,220,0,198,230,246,254,222,206,198,198,198,0,0,0,0,0,60,108,108,62,0,126,0,0,0,0,0,0,0,0,0,0,56,108,108,56,0,124,0,0,0,0,0,0,0,0,0,0,0,48,48,0,48,48,96,192,198,198,124,0,0,0,0,0,0,0,0,0,0,254,192,192,192,192,0,0,0,0,0,0,0,0,0,0,0,254,6,6,6,6,0,0,0,0,0,0,192,192,194,198,204,24,48,96,206,155,6,12,31,0,0,0,192,192,194,198,204,24,48,102,206,150,62,6,6,0,0,0,0,24,24,0,24,24,24,60,60,60,24,0,0,0,0,0,0,0,0,0,54,108,216,108,54,0,0,0,0,0,0,0,0,0,0,0,216,108,54,108,216,0,0,0,0,0,0,17,68,17,68,17,68,17,68,17,68,17,68,17,68,17,68,85,170,85,170,85,170,85,170,85,170,85,170,85,170,85,170,221,119,221,119,221,119,221,119,221,119,221,119,221,119,221,119,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,248,24,24,24,24,24,24,24,24,24,24,24,24,24,248,24,248,24,24,24,24,24,24,24,24,54,54,54,54,54,54,54,246,54,54,54,54,54,54,54,54,0,0,0,0,0,0,0,254,54,54,54,54,54,54,54,54,0,0,0,0,0,248,24,248,24,24,24,24,24,24,24,24,54,54,54,54,54,246,6,246,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,0,0,0,0,0,254,6,246,54,54,54,54,54,54,54,54,54,54,54,54,54,246,6,254,0,0,0,0,0,0,0,0,54,54,54,54,54,54,54,254,0,0,0,0,0,0,0,0,24,24,24,24,24,248,24,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,31,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,31,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,0,24,24,24,24,24,24,24,255,24,24,24,24,24,24,24,24,24,24,24,24,24,31,24,31,24,24,24,24,24,24,24,24,54,54,54,54,54,54,54,55,54,54,54,54,54,54,54,54,54,54,54,54,54,55,48,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,48,55,54,54,54,54,54,54,54,54,54,54,54,54,54,247,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,247,54,54,54,54,54,54,54,54,54,54,54,54,54,55,48,55,54,54,54,54,54,54,54,54,0,0,0,0,0,255,0,255,0,0,0,0,0,0,0,0,54,54,54,54,54,247,0,247,54,54,54,54,54,54,54,54,24,24,24,24,24,255,0,255,0,0,0,0,0,0,0,0,54,54,54,54,54,54,54,255,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,255,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,255,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,63,0,0,0,0,0,0,0,0,24,24,24,24,24,31,24,31,0,0,0,0,0,0,0,0,0,0,0,0,0,31,24,31,24,24,24,24,24,24,24,24,0,0,0,0,0,0,0,63,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,255,54,54,54,54,54,54,54,54,24,24,24,24,24,255,24,255,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,24,24,24,24,24,24,24,24,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,240,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,220,216,216,216,220,118,0,0,0,0,0,0,120,204,204,204,216,204,198,198,198,204,0,0,0,0,0,0,254,198,198,192,192,192,192,192,192,192,0,0,0,0,0,0,0,0,254,108,108,108,108,108,108,108,0,0,0,0,0,0,0,254,198,96,48,24,48,96,198,254,0,0,0,0,0,0,0,0,0,126,216,216,216,216,216,112,0,0,0,0,0,0,0,0,102,102,102,102,102,124,96,96,192,0,0,0,0,0,0,0,118,220,24,24,24,24,24,24,0,0,0,0,0,0,0,126,24,60,102,102,102,60,24,126,0,0,0,0,0,0,0,56,108,198,198,254,198,198,108,56,0,0,0,0,0,0,56,108,198,198,198,108,108,108,108,238,0,0,0,0,0,0,30,48,24,12,62,102,102,102,102,60,0,0,0,0,0,0,0,0,0,126,219,219,219,126,0,0,0,0,0,0,0,0,0,3,6,126,219,219,243,126,96,192,0,0,0,0,0,0,28,48,96,96,124,96,96,96,48,28,0,0,0,0,0,0,0,124,198,198,198,198,198,198,198,198,0,0,0,0,0,0,0,0,254,0,0,254,0,0,254,0,0,0,0,0,0,0,0,0,24,24,126,24,24,0,0,255,0,0,0,0,0,0,0,48,24,12,6,12,24,48,0,126,0,0,0,0,0,0,0,12,24,48,96,48,24,12,0,126,0,0,0,0,0,0,14,27,27,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,216,216,216,112,0,0,0,0,0,0,0,0,24,24,0,126,0,24,24,0,0,0,0,0,0,0,0,0,0,118,220,0,118,220,0,0,0,0,0,0,0,56,108,108,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,15,12,12,12,12,12,236,108,108,60,28,0,0,0,0,0,216,108,108,108,108,108,0,0,0,0,0,0,0,0,0,0,112,216,48,96,200,248,0,0,0,0,0,0,0,0,0,0,0,0,0,124,124,124,124,124,124,124,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,1,0,136,88,1,0,0,250,0,0,128,187,0,0,68,172,0,0,0,125,0,0,192,93,0,0,34,86,0,0,128,62,0,0,224,46,0,0,17,43,0,0,64,31,0,0,182,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,172,128,187,0,125,0,0,0,0,32,0,64,0,96,0,128,0,160,0,192,0,224,0,0,1,32,1,64,1,96,1,128,1,160,1,192,1,0,0,32,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,160,0,192,0,224,0,0,1,64,1,128,1,0,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,160,0,192,0,224,0,0,1,64,1,0,0,32,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,176,0,192,0,224,0,0,1,0,0,8,0,16,0,24,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,0,0,8,0,16,0,24,0,32,0,40,0,48,0,56,0,64,0,80,0,96,0,112,0,128,0,144,0,160,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,0,0,0,0,1,2,3,0,4,17,5,18,33,49,65,6,19,81,97,7,34,113,20,50,129,145,161,8,35,66,177,193,21,82,209,240,36,51,98,114,130,9,10,22,23,24,25,26,37,38,39,40,41,42,52,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,225,226,227,228,229,230,231,232,233,234,241,242,243,244,245,246,247,248,249,250,0,0,0,0,0,0,0,1,2,3,17,4,5,33,49,6,18,65,81,7,97,113,19,34,50,129,8,20,66,145,161,177,193,9,35,51,82,240,21,98,114,209,10,22,36,52,225,37,241,23,24,25,26,38,39,40,41,42,53,54,55,56,57,58,67,68,69,70,71,72,73,74,83,84,85,86,87,88,89,90,99,100,101,102,103,104,105,106,115,116,117,118,119,120,121,122,130,131,132,133,134,135,136,137,138,146,147,148,149,150,151,152,153,154,162,163,164,165,166,167,168,169,170,178,179,180,181,182,183,184,185,186,194,195,196,197,198,199,200,201,202,210,211,212,213,214,215,216,217,218,226,227,228,229,230,231,232,233,234,242,243,244,245,246,247,248,249,250,0,0,0,0,0,0,0,0,1,5,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,3,3,2,4,3,5,5,4,4,0,0,1,125,0,0,0,0,0,0,0,0,0,2,1,2,4,4,3,4,7,5,4,4,0,1,2,119,0,0,0,0,0,0,0,0,0,0,0,64,31,0,0,128,62,0,0,0,125,0,0,0,0,0,0,0,0,0,0,17,43,0,0,34,86,0,0,68,172,0,0,0,0,0,0,0,0,0,0,224,46,0,0,192,93,0,0,128,187,0,0,0,119,1,0,0,238,2,0,0,0,0,0,0,0,0,0,126,129,165,129,189,153,129,126,126,255,219,255,195,231,255,126,108,254,254,254,124,56,16,0,16,56,124,254,124,56,16,0,56,124,56,254,254,124,56,124,16,16,56,124,254,124,56,124,0,0,24,60,60,24,0,0,255,255,231,195,195,231,255,255,0,60,102,66,66,102,60,0,255,195,153,189,189,153,195,255,15,7,15,125,204,204,204,120,60,102,102,102,60,24,126,24,63,51,63,48,48,112,240,224,127,99,127,99,99,103,230,192,153,90,60,231,231,60,90,153,128,224,248,254,248,224,128,0,2,14,62,254,62,14,2,0,24,60,126,24,24,126,60,24,102,102,102,102,102,0,102,0,127,219,219,123,27,27,27,0,62,99,56,108,108,56,204,120,0,0,0,0,126,126,126,0,24,60,126,24,126,60,24,255,24,60,126,24,24,24,24,0,24,24,24,24,126,60,24,0,0,24,12,254,12,24,0,0,0,48,96,254,96,48,0,0,0,0,192,192,192,254,0,0,0,36,102,255,102,36,0,0,0,24,60,126,255,255,0,0,0,255,255,126,60,24,0,0,0,0,0,0,0,0,0,0,48,120,120,48,48,0,48,0,108,108,108,0,0,0,0,0,108,108,254,108,254,108,108,0,48,124,192,120,12,248,48,0,0,198,204,24,48,102,198,0,56,108,56,118,220,204,118,0,96,96,192,0,0,0,0,0,24,48,96,96,96,48,24,0,96,48,24,24,24,48,96,0,0,102,60,255,60,102,0,0,0,48,48,252,48,48,0,0,0,0,0,0,0,48,48,96,0,0,0,252,0,0,0,0,0,0,0,0,0,48,48,0,6,12,24,48,96,192,128,0,124,198,206,222,246,230,124,0,48,112,48,48,48,48,252,0,120,204,12,56,96,204,252,0,120,204,12,56,12,204,120,0,28,60,108,204,254,12,30,0,252,192,248,12,12,204,120,0,56,96,192,248,204,204,120,0,252,204,12,24,48,48,48,0,120,204,204,120,204,204,120,0,120,204,204,124,12,24,112,0,0,48,48,0,0,48,48,0,0,48,48,0,0,48,48,96,24,48,96,192,96,48,24,0,0,0,252,0,0,252,0,0,96,48,24,12,24,48,96,0,120,204,12,24,48,0,48,0,124,198,222,222,222,192,120,0,48,120,204,204,252,204,204,0,252,102,102,124,102,102,252,0,60,102,192,192,192,102,60,0,248,108,102,102,102,108,248,0,254,98,104,120,104,98,254,0,254,98,104,120,104,96,240,0,60,102,192,192,206,102,62,0,204,204,204,252,204,204,204,0,120,48,48,48,48,48,120,0,30,12,12,12,204,204,120,0,230,102,108,120,108,102,230,0,240,96,96,96,98,102,254,0,198,238,254,254,214,198,198,0,198,230,246,222,206,198,198,0,56,108,198,198,198,108,56,0,252,102,102,124,96,96,240,0,120,204,204,204,220,120,28,0,252,102,102,124,108,102,230,0,120,204,224,112,28,204,120,0,252,180,48,48,48,48,120,0,204,204,204,204,204,204,252,0,204,204,204,204,204,120,48,0,198,198,198,214,254,238,198,0,198,198,108,56,56,108,198,0,204,204,204,120,48,48,120,0,254,198,140,24,50,102,254,0,120,96,96,96,96,96,120,0,192,96,48,24,12,6,2,0,120,24,24,24,24,24,120,0,16,56,108,198,0,0,0,0,0,0,0,0,0,0,0,255,48,48,24,0,0,0,0,0,0,0,120,12,124,204,118,0,224,96,96,124,102,102,220,0,0,0,120,204,192,204,120,0,28,12,12,124,204,204,118,0,0,0,120,204,252,192,120,0,56,108,96,240,96,96,240,0,0,0,118,204,204,124,12,248,224,96,108,118,102,102,230,0,48,0,112,48,48,48,120,0,12,0,12,12,12,204,204,120,224,96,102,108,120,108,230,0,112,48,48,48,48,48,120,0,0,0,204,254,254,214,198,0,0,0,248,204,204,204,204,0,0,0,120,204,204,204,120,0,0,0,220,102,102,124,96,240,0,0,118,204,204,124,12,30,0,0,220,118,102,96,240,0,0,0,124,192,120,12,248,0,16,48,124,48,48,52,24,0,0,0,204,204,204,204,118,0,0,0,204,204,204,120,48,0,0,0,198,214,254,254,108,0,0,0,198,108,56,108,198,0,0,0,204,204,204,124,12,248,0,0,252,152,48,100,252,0,28,48,48,224,48,48,28,0,24,24,24,0,24,24,24,0,224,48,48,28,48,48,224,0,118,220,0,0,0,0,0,0,0,16,56,108,198,198,254,0,120,204,192,204,120,24,12,120,0,204,0,204,204,204,126,0,28,0,120,204,252,192,120,0,126,195,60,6,62,102,63,0,204,0,120,12,124,204,126,0,224,0,120,12,124,204,126,0,48,48,120,12,124,204,126,0,0,0,120,192,192,120,12,56,126,195,60,102,126,96,60,0,204,0,120,204,252,192,120,0,224,0,120,204,252,192,120,0,204,0,112,48,48,48,120,0,124,198,56,24,24,24,60,0,224,0,112,48,48,48,120,0,198,56,108,198,254,198,198,0,48,48,0,120,204,252,204,0,28,0,252,96,120,96,252,0,0,0,127,12,127,204,127,0,62,108,204,254,204,204,206,0,120,204,0,120,204,204,120,0,0,204,0,120,204,204,120,0,0,224,0,120,204,204,120,0,120,204,0,204,204,204,126,0,0,224,0,204,204,204,126,0,0,204,0,204,204,124,12,248,195,24,60,102,102,60,24,0,204,0,204,204,204,204,120,0,24,24,126,192,192,126,24,24,56,108,100,240,96,230,252,0,204,204,120,252,48,252,48,48,248,204,204,250,198,207,198,199,14,27,24,60,24,24,216,112,28,0,120,12,124,204,126,0,56,0,112,48,48,48,120,0,0,28,0,120,204,204,120,0,0,28,0,204,204,204,126,0,0,248,0,248,204,204,204,0,252,0,204,236,252,220,204,0,60,108,108,62,0,126,0,0,56,108,108,56,0,124,0,0,48,0,48,96,192,204,120,0,0,0,0,252,192,192,0,0,0,0,0,252,12,12,0,0,195,198,204,222,51,102,204,15,195,198,204,219,55,111,207,3,24,24,0,24,24,24,24,0,0,51,102,204,102,51,0,0,0,204,102,51,102,204,0,0,34,136,34,136,34,136,34,136,85,170,85,170,85,170,85,170,219,119,219,238,219,119,219,238,24,24,24,24,24,24,24,24,24,24,24,24,248,24,24,24,24,24,248,24,248,24,24,24,54,54,54,54,246,54,54,54,0,0,0,0,254,54,54,54,0,0,248,24,248,24,24,24,54,54,246,6,246,54,54,54,54,54,54,54,54,54,54,54,0,0,254,6,246,54,54,54,54,54,246,6,254,0,0,0,54,54,54,54,254,0,0,0,24,24,248,24,248,0,0,0,0,0,0,0,248,24,24,24,24,24,24,24,31,0,0,0,24,24,24,24,255,0,0,0,0,0,0,0,255,24,24,24,24,24,24,24,31,24,24,24,0,0,0,0,255,0,0,0,24,24,24,24,255,24,24,24,24,24,31,24,31,24,24,24,54,54,54,54,55,54,54,54,54,54,55,48,63,0,0,0,0,0,63,48,55,54,54,54,54,54,247,0,255,0,0,0,0,0,255,0,247,54,54,54,54,54,55,48,55,54,54,54,0,0,255,0,255,0,0,0,54,54,247,0,247,54,54,54,24,24,255,0,255,0,0,0,54,54,54,54,255,0,0,0,0,0,255,0,255,24,24,24,0,0,0,0,255,54,54,54,54,54,54,54,63,0,0,0,24,24,31,24,31,0,0,0,0,0,31,24,31,24,24,24,0,0,0,0,63,54,54,54,54,54,54,54,255,54,54,54,24,24,255,24,255,24,24,24,24,24,24,24,248,0,0,0,0,0,0,0,31,24,24,24,255,255,255,255,255,255,255,255,0,0,0,0,255,255,255,255,240,240,240,240,240,240,240,240,15,15,15,15,15,15,15,15,255,255,255,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1957425);
/* memory initializer */ allocate([118,220,200,220,118,0,0,120,204,248,204,248,192,192,0,252,204,192,192,192,192,0,0,254,108,108,108,108,108,0,252,204,96,48,96,204,252,0,0,0,126,216,216,216,112,0,0,102,102,102,102,124,96,192,0,118,220,24,24,24,24,0,252,48,120,204,204,120,48,252,56,108,198,254,198,108,56,0,56,108,198,198,108,108,238,0,28,48,24,124,204,204,120,0,0,0,126,219,219,126,0,0,6,12,126,219,219,126,96,192,56,96,192,248,192,96,56,0,120,204,204,204,204,204,204,0,0,252,0,252,0,252,0,0,48,48,252,48,48,0,252,0,96,48,24,48,96,0,252,0,24,48,96,48,24,0,252,0,14,27,27,24,24,24,24,24,24,24,24,24,24,216,216,112,48,48,0,252,0,48,48,0,0,118,220,0,118,220,0,0,56,108,108,56,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,24,0,0,0,15,12,12,12,236,108,60,28,120,108,108,108,108,0,0,0,112,24,48,96,120,0,0,0,0,0,60,60,60,60,0,0,0,0,0,0,0,0,0,0,3,0,4,0,3,0,7,0,3,1,7,1,3,6,7,6,120,190,35,0,0,130,38,0,0,0,0,0,0,0,0,0,82,73,70,70,65,86,73,32,82,73,70,70,65,86,73,88,82,73,70,70,65,86,73,25,79,78,50,32,79,78,50,102,82,73,70,70,65,77,86,32,0,0,0,0,0,0,0,0,24,219,37,0,0,0,0,0,184,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,3,0,0,0,24,219,37,0,32,96,36,0,72,78,35,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,3,0,0,0,24,219,37,0,176,128,34,0,8,202,33,0,64,4,0,0,1,0,0,0,64,75,76,0,0,0,0,0,0,0,0,0,0,0,64,64,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,32,73,33,0,232,218,32,0,52,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,144,122,32,0,0,0,0,0,60,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,3,0,0,0,144,122,32,0,0,33,32,0,104,8,40,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,32,159,39,0,232,65,39,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,24,250,38,0,32,180,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,184,117,38,0,48,61,38,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,24,6,38,0,88,223,37,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,16,180,37,0,128,149,37,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,72,88,37,0,72,30,37,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,72,252,36,0,240,209,36,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,0,180,36,0,104,151,36,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,120,123,36,0,160,96,36,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,144,122,32,0,88,70,36,0,144,48,36,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,144,122,32,0,64,251,35,0,128,209,35,0,200,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,168,184,35,0,96,162,35,0,68,4,0,0,1,0,0,0,64,75,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,224,141,35,0,168,118,35,0,72,4,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,144,98,35,0,40,79,35,0,100,4,0,0,1,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,160,61,35,0,80,46,35,0,104,4,0,0,1,0,0,0,0,104,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,2,0,0,0,0,0,0,0,24,4,35,0,248,226,34,0,144,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,3,0,0,0,24,4,35,0,248,210,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,3,0,0,0,24,4,35,0,152,195,34,0,24,179,34,0,56,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,3,0,0,0,0,0,0,0,72,159,34,0,248,143,34,0,128,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,128,255,255,255,223,65,2,0,0,0,0,0,0,0,80,129,34,0,40,112,34,0,164,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,1,0,0,0,0,0,0,0,16,99,34,0,248,60,34,0,168,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,1,0,0,0,0,0,0,0,112,32,34,0,0,18,34,0,172,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,1,0,0,0,0,0,0,0,152,2,34,0,8,244,33,0,132,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,128,226,33,0,168,213,33,0,132,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,88,202,33,0,248,192,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,136,186,33,0,152,154,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,160,131,33,0,48,121,33,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,88,111,33,0,192,101,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,248,90,33,0,72,82,33,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,168,73,33,0,248,64,33,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,112,58,33,0,152,30,33,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,2,0,0,0,128,226,33,0,0,8,33,0,216,255,32,0,176,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,2,0,0,0,0,0,0,0,120,247,32,0,32,240,32,0,180,4,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,1,0,0,0,120,247,32,0,144,232,32,0,48,226,32,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,120,247,32,0,32,219,32,0,184,212,32,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,120,247,32,0,120,204,32,0,32,240,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,120,247,32,0,208,179,32,0,120,162,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,1,0,0,0,120,247,32,0,56,155,32,0,232,147,32,0,192,4,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,255,255,223,65,2,0,0,0,0,0,0,0,160,141,32,0,176,133,32,0,196,4,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,2,0,0,0,0,0,0,0,0,33,32,0,88,128,32,0,204,4,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,1,0,0,0,0,0,0,0,192,122,32,0,232,116,32,0,36,5,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,1,0,0,0,0,0,0,0,64,111,32,0,224,87,32,0,48,5,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,120,71,32,0,208,63,32,0,152,4,0,0,2,0,0,0,128,150,152,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,7,0,0,78,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,7,0,0,230,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,166,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,2,0,0,112,7,0,0,70,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,224,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,175,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,159,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,4,0,0,26,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,159,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,228,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,228,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,1,0,0,0,0,0,0,0,0,0,0,120,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,6,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,6,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,2,0,0,0,0,0,0,0,0,0,0,210,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,158,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,158,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,161,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,252,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,252,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,188,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,188,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,126,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,126,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,2,0,0,0,0,0,0,0,0,0,0,110,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,37,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,37,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,2,0,0,0,0,0,0,0,0,0,0,142,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,126,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,126,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,2,0,0,0,0,0,0,0,0,0,0,148,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,108,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,94,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,23,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,23,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,2,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,2,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,3,0,0,0,0,0,0,0,0,0,0,228,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,238,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,238,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,2,0,0,0,0,0,0,0,0,0,0,62,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,40,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,8,0,0,110,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,23,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,1,0,0,0,0,0,0,0,0,0,0,156,9,0,0,0,0,0,0,1,0,0,0,200,182,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,1,0,0,0,0,0,0,0,0,0,0,34,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,7,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,7,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,133,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,133,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,210,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,210,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,186,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,31,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,31,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,3,0,0,0,0,0,0,0,0,0,0,188,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,8,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,8,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,1,0,0,0,0,0,0,0,0,0,0,84,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,161,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,6,0,0,252,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,161,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,133,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,133,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,14,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,14,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,164,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,164,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,2,0,0,0,0,0,0,0,0,0,0,208,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,57,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,57,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,2,0,0,0,0,0,0,0,0,0,0,192,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,36,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,36,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,56,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,56,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,3,0,0,0,0,0,0,0,0,0,0,244,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,245,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,245,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,2,0,0,0,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,73,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,73,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,63,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,63], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1967666);
/* memory initializer */ allocate([37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,1,0,0,0,0,0,0,0,0,0,0,254,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,30,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,30,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,109,34,0,96,94,34,0,52,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,1,0,216,109,34,0,224,53,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,109,34,0,128,54,38,0,176,29,34,0,64,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,127,34,0,50,9,0,0,168,47,30,0,100,66,52,0,0,0,0,0,0,0,0,0,84,0,0,0,250,2,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,252,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,10,0,0,142,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,166,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,2,0,0,112,7,0,0,70,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,116,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,175,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,146,35,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,146,35,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,217,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,4,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,11,39,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,11,39,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,1,0,0,0,0,0,0,0,0,0,0,26,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,161,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,188,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,188,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,108,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,94,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,210,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,210,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,189,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,8,0,0,174,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,134,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,134,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,14,35,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,14,35,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,200,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,200,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,238,1,0,0,0,0,0,0,0,0,0,0,188,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,101,36,0,192,81,35,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,88,101,36,0,8,131,34,0,192,81,35,0,24,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,88,101,36,0,224,203,33,0,96,25,156,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,88,101,36,0,48,220,32,0,96,25,156,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,88,101,36,0,152,123,32,0,112,33,32,0,64,0,0,0,84,65,82,86,200,8,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,64,160,39,0,112,33,32,0,64,0,0,0,84,65,82,86,200,8,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,72,66,39,0,88,250,38,0,8,0,0,0,69,90,73,83,112,180,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,16,118,38,0,88,250,38,0,8,0,0,0,69,90,73,83,112,180,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,61,38,0,64,6,38,0,28,0,0,0,1,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,160,223,37,0,40,180,37,0,32,0,0,0,1,0,0,0,160,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,152,149,37,0,88,88,37,0,36,0,0,0,1,0,0,0,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,104,30,37,0,80,252,36,0,40,0,0,0,1,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,32,210,36,0,240,179,36,0,44,0,0,0,1,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,96,151,36,0,104,123,36,0,48,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,111,64,16,0,1,0,0,0,0,0,152,96,36,0,72,70,36,0,56,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,63,0,0,0,0,0,0,36,64,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,135,32,0,112,0,0,0,96,59,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,235,36,0,216,199,36,0,72,0,0,0,1,0,0,0,64,13,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,32,170,36,0,216,199,36,0,72,0,0,0,1,0,0,0,0,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,32,143,36,0,136,114,36,0,76,0,0,0,1,0,0,0,0,9,61,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,8,232,39,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,59,0,0,0,8,232,39,0,128,88,36,0,152,62,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,8,232,39,0,144,36,36,0,48,234,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,152,200,35,0,248,176,35,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,8,155,35,0,160,133,35,0,0,0,0,0,128,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,0,111,35,0,0,91,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,8,232,39,0,192,73,35,0,120,55,35,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,136,35,35,0,176,247,34,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,216,220,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,8,232,39,0,224,205,34,0,136,189,34,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,8,232,39,0,88,172,34,0,184,153,34,0,0,0,0,0,128,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,8,232,39,0,160,139,34,0,24,124,34,0,0,0,0,0,128,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,8,232,39,0,72,107,34,0,136,90,34,0,0,0,0,0,128,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,8,232,39,0,112,49,34,0,248,26,34,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,32,13,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,8,232,39,0,56,254,33,0,112,235,33,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,104,221,33,0,184,209,33,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,152,199,33,0,104,190,33,0,0,0,0,0,128,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,8,232,39,0,64,179,33,0,80,145,33,0,0,0,0,0,128,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,8,232,39,0,248,127,33,0,16,118,33,0,0,0,0,0,128,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,59,0,0,0,8,232,39,0,24,108,33,0,56,98,33,0,0,0,0,0,128,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,72,88,33,0,64,79,33,0,0,0,0,0,128,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,72,71,33,0,48,62,33,0,0,0,0,0,128,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,8,232,39,0,16,52,33,0,144,21,33,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,8,232,39,0,248,4,33,0,160,252,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,248,244,32,0,192,237,32,0,128,230,32,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,248,244,32,0,24,224,32,0,216,216,32,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,248,244,32,0,208,207,32,0,104,199,32,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,248,244,32,0,96,173,32,0,160,159,32,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,248,244,32,0,56,153,32,0,112,145,32,0,0,0,0,0,128,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,248,244,32,0,96,138,32,0,88,132,32,0,144,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,160,126,32,0,152,120,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,248,115,32,0,248,105,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,80,81,32,0,88,68,32,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,200,61,32,0,88,54,32,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,208,47,32,0,184,41,32,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,160,36,32,0,168,30,32,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,48,89,40,0,216,81,40,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,224,56,40,0,88,44,40,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,224,35,40,0,88,28,40,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,176,22,40,0,40,17,40,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,112,12,40,0,128,6,40,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,184,0,40,0,24,247,39,0,0,0,0,0,128,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,96,138,32,0,104,221,39,0,0,0,0,0,100,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,104,207,39,0,0,0,0,0,104,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,184,195,39,0,24,187,39,0,136,0,0,0,1,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,96,179,39,0,88,172,39,0,156,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,11,0,0,0,0,0,0,0,80,166,39,0,64,156,39,0,160,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,11,0,0,0,0,0,0,0,200,148,39,0,40,140,39,0,180,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,32,117,39,0,0,0,0,0,168,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,16,103,39,0,0,0,0,0,172,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,80,95,39,0,0,0,0,0,116,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,56,86,39,0,192,80,39,0,236,1,0,0,4,0,0,0,0,0,0,0,0,0,224,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,136,75,39,0,152,70,39,0,240,1,0,0,4,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,240,191,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,184,64,39,0,32,59,39,0,244,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,64,81,64,17,0,0,0,0,0,0,0,88,53,39,0,152,35,39,0,248,1,0,0,1,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,144,64,17,0,0,0,0,0,0,0,208,23,39,0,224,17,39,0,252,1,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,40,11,39,0,200,6,39,0,156,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,184,1,39,0,136,253,38,0,160,0,0,0,4,0,0,0,0,0,0,0,0,0,244,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,104,248,38,0,16,245,38,0,164,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,176,238,38,0,216,220,38,0,168,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,64,211,38,0,208,205,38,0,116,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,128,199,38,0,0,0,0,0,120,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,208,194,38,0,0,0,0,0,124,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,128,189,38,0,0,0,0,0,128,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,32,184,38,0,0,0,0,0,132,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,216,178,38,0,0,0,0,0,136,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,8,174,38,0,0,0,0,0,140,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,192,167,38,0,0,0,0,0,144,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,0,152,38,0,0,0,0,0,148,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,120,142,38,0,0,0,0,0,152,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,16,138,38,0,0,0,0,0,52,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,240,132,38,0,0,129,38,0,164,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,72,125,38,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,96,121,38,0,88,116,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,16,113,38,0,88,107,38,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,128,92,38,0,120,83,38,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,192,78,38,0,200,73,38,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,56,71,38,0,0,0,0,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,152,67,38,0,88,64,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,72,60,38,0,0,0,0,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,224,56,38,0,248,52,38,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,240,38,38,0,0,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,96,28,38,0,168,23,38,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,32,19,38,0,208,14,38,0,0,0,0,0,128,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,56,11,38,0,0,0,0,0,0,0,0,0,128,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,24,8,38,0,0,0,0,0,0,0,0,0,128,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,176,5,38,0,160,3,38,0,0,0,0,0,128,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,112,0,38,0,104,245,37,0,0,0,0,0,128,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,240,132,38,0,248,239,37,0,136,236,37,0,168,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,27,0,0,0,248,239,37,0,192,233,37,0,208,230,37,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,248,239,37,0,248,239,37,0,72,228,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,248,239,37,0,8,226,37,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,248,239,37,0,136,219,37,0,96,217,37,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,248,239,37,0,24,214,37,0,224,201,37,0,0,0,0,0,128,0,0,0,254,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,248,239,37,0,56,194,37,0,192,191,37,0,172,0,0,0,4,0,0,0,0,0,0,0,0,0,244,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,104,189,37,0,64,187,37,0,184,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,104,189,37,0,88,184,37,0,16,182,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,104,189,37,0,120,179,37,0,184,177,37,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,104,189,37,0,128,175,37,0,160,165,37,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,104,189,37,0,88,160,37,0,96,158,37,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,104,189,37,0,200,156,37,0,24,155,37,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,104,189,37,0,232,152,37,0,32,151,37,0,0,0,0,0,128,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,104,189,37,0,40,149,37,0,40,146,37,0,0,0,0,0,128,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,104,189,37,0,80,140,37,0,0,0,0,0,176,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,64,127,37,0,0,0,0,0,176,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,0,119,37,0,40,111,37,0,180,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,104,105,37,0,120,100,37,0,0,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,88,64,17,0,0,0,0,0,0,0,24,97,37,0,8,93,37,0,4,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,16,86,37,0,8,93,37,0,8,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,0,81,37,0,0,0,0,0,16,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,160,75,37,0,216,60,37,0,24,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,17,0,0,0,0,0,0,0,16,52,37,0,144,46,37,0,28,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,88,42,37,0,96,36,37,0,32,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,24,35,37,0,192,32,37,0,12,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,232,29,37,0,64,27,37,0,36,2,0,0,4,0,0,0,0,0,0,0,0,0,240,63,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,104,25,37,0,176,16,37,0,184,0,0,0,4,0,0,0,154,153,153,153,153,153,233,191,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,16,10,37,0,96,7,37,0,188,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,104,4,37,0,64,2,37,0,40,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,128,0,37,0,120,254,36,0,16,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,128,0,37,0,152,251,36,0,40,250,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,0,37,0,144,244,36,0,144,231,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,0,37,0,104,226,36,0,184,223,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1977906);
/* memory initializer */ allocate([128,0,37,0,48,218,36,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,0,37,0,224,215,36,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,0,37,0,144,213,36,0,192,211,36,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,128,0,37,0,144,209,36,0,88,207,36,0,192,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,24,205,36,0,160,196,36,0,196,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,112,191,36,0,72,189,36,0,200,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,80,187,36,0,104,185,36,0,204,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,40,184,36,0,16,182,36,0,208,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,144,179,36,0,232,177,36,0,20,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,152,251,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,104,226,36,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,0,176,36,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,112,166,36,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,56,162,36,0,0,0,0,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,224,215,36,0,0,0,0,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,24,160,36,0,0,0,0,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,24,158,36,0,0,0,0,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,96,156,36,0,0,0,0,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,64,154,36,0,0,0,0,0,0,0,0,0,128,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,208,152,36,0,0,0,0,0,0,0,0,0,128,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,240,150,36,0,0,0,0,0,0,0,0,0,128,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,216,149,36,0,0,0,0,0,0,0,0,0,128,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,128,147,36,0,0,0,0,0,0,0,0,0,128,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,40,140,36,0,32,135,36,0,0,0,0,0,128,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,144,179,36,0,216,132,36,0,0,0,0,0,212,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,128,130,36,0,128,128,36,0,172,2,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,128,130,36,0,24,127,36,0,136,125,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,128,130,36,0,16,123,36,0,136,121,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,128,130,36,0,32,120,36,0,0,0,0,0,24,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,56,112,36,0,56,108,36,0,216,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,56,112,36,0,136,106,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,56,112,36,0,144,104,36,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,56,112,36,0,208,102,36,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,56,112,36,0,64,101,36,0,144,99,36,0,224,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,64,17,0,0,0,0,0,0,0,72,96,36,0,184,94,36,0,176,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,59,0,0,0,72,96,36,0,80,93,36,0,248,84,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,216,80,36,0,152,78,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,72,96,36,0,120,179,37,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,176,76,36,0,40,75,36,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,152,73,36,0,216,71,36,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,200,69,36,0,40,68,36,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,248,66,36,0,0,0,0,0,0,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,16,60,36,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,88,56,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,0,55,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,176,53,36,0,64,52,36,0,0,0,0,0,128,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,88,51,36,0,56,50,36,0,0,0,0,0,128,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,104,48,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,32,46,36,0,152,41,36,0,0,0,0,0,128,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,8,32,36,0,144,25,36,0,0,0,0,0,128,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,16,18,36,0,128,12,36,0,0,0,0,0,128,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,72,96,36,0,168,7,36,0,40,4,36,0,0,0,0,0,128,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,26,0,0,0,72,96,36,0,248,0,36,0,224,248,35,0,180,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,18,0,0,0,48,244,35,0,128,240,35,0,40,231,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,48,244,35,0,40,11,39,0,56,223,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,48,244,35,0,192,219,35,0,216,215,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,48,244,35,0,112,214,35,0,224,212,35,0,232,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,56,209,35,0,136,206,35,0,236,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,160,204,35,0,128,198,35,0,240,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,240,194,35,0,208,192,35,0,244,0,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,40,191,35,0,248,189,35,0,248,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,64,188,35,0,248,185,35,0,252,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,232,183,35,0,144,182,35,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,232,180,35,0,8,175,35,0,4,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,136,171,35,0,216,169,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,104,168,35,0,24,167,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,16,165,35,0,160,163,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,128,0,37,0,240,161,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,112,49,34,0,200,159,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,0,158,35,0,248,152,35,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,200,149,35,0,232,147,35,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,160,126,32,0,152,146,35,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,216,145,35,0,8,145,35,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,48,143,35,0,104,141,35,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,32,140,35,0,208,137,35,0,0,0,0,0,128,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,216,131,35,0,112,127,35,0,0,0,0,0,128,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,240,125,35,0,208,123,35,0,0,0,0,0,128,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,160,122,35,0,0,0,0,0,0,0,0,0,128,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,32,121,35,0,0,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,176,119,35,0,248,117,35,0,8,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,128,116,35,0,200,114,35,0,12,1,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,56,109,35,0,0,0,0,0,16,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,56,105,35,0,216,102,35,0,20,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,224,101,35,0,16,101,35,0,24,1,0,0,1,0,0,0,63,66,15,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,40,100,35,0,32,99,35,0,28,1,0,0,1,0,0,0,63,66,15,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,48,98,35,0,0,0,0,0,80,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,64,97,35,0,0,0,0,0,56,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,64,97,35,0,88,95,35,0,128,89,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,64,97,35,0,80,166,39,0,112,86,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,64,97,35,0,232,84,35,0,136,83,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,64,97,35,0,192,82,35,0,216,81,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,64,97,35,0,96,80,35,0,192,78,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,64,97,35,0,120,77,35,0,120,76,35,0,60,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,200,71,35,0,0,0,0,0,32,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,184,68,35,0,0,0,0,0,36,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,144,67,35,0,232,65,35,0,40,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,17,0,0,0,144,67,35,0,0,176,36,0,240,64,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,144,67,35,0,136,63,35,0,88,62,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,144,67,35,0,200,149,35,0,56,61,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,144,67,35,0,240,59,35,0,0,0,0,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,64,58,35,0,240,53,35,0,52,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,232,50,35,0,224,49,35,0,64,2,0,0,1,0,0,0,236,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,248,48,35,0,128,48,35,0,68,2,0,0,1,0,0,0,74,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,176,47,35,0,24,47,35,0,56,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,8,46,35,0,48,43,35,0,52,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,248,244,32,0,0,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,255,239,65,27,0,0,0,248,244,32,0,0,39,35,0,0,0,0,0,100,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,224,31,35,0,0,0,0,0,40,3,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,27,0,0,0,224,31,35,0,152,251,36,0,96,26,35,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,224,31,35,0,104,19,35,0,72,15,35,0,60,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,200,12,35,0,8,10,35,0,64,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,128,7,35,0,136,2,35,0,68,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,24,255,34,0,40,252,34,0,68,3,0,0,1,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,80,244,34,0,184,238,34,0,72,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,0,0,0,0,120,234,34,0,8,231,34,0,76,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,0,0,0,0,184,229,34,0,0,0,0,0,72,3,0,0,1,0,0,0,157,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,184,229,34,0,32,229,34,0,0,0,0,0,0,0,0,0,128,0,0,0,157,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,184,229,34,0,16,228,34,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,184,226,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,104,225,34,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,72,224,34,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,88,219,34,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,0,217,34,0,0,0,0,0,0,0,0,0,128,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,96,215,34,0,0,0,0,0,0,0,0,0,128,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,120,214,34,0,0,0,0,0,0,0,0,0,128,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,184,213,34,0,0,0,0,0,0,0,0,0,128,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,136,212,34,0,0,0,0,0,0,0,0,0,128,0,0,0,131,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,200,211,34,0,0,0,0,0,0,0,0,0,128,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,160,210,34,0,0,0,0,0,0,0,0,0,128,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,232,209,34,0,0,0,0,0,0,0,0,0,128,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,72,208,34,0,0,0,0,0,0,0,0,0,128,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,200,204,34,0,0,0,0,0,0,0,0,0,128,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,229,34,0,248,201,34,0,0,0,0,0,76,3,0,0,1,0,0,0,157,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,248,201,34,0,32,229,34,0,0,0,0,0,0,0,0,0,128,0,0,0,157,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,248,201,34,0,168,200,34,0,88,199,34,0,32,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,26,0,0,0,0,0,0,0,128,198,34,0,88,197,34,0,72,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,88,196,34,0,56,195,34,0,76,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,216,193,34,0,160,192,34,0,80,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,32,188,34,0,152,185,34,0,84,2,0,0,1,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,24,211,35,0,72,184,34,0,56,183,34,0,80,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,199,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,24,182,34,0,104,181,34,0,84,1,0,0,1,0,0,0,236,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,192,255,223,64,17,0,0,0,0,0,0,0,32,180,34,0,160,178,34,0,88,1,0,0,1,0,0,0,74,14,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,192,255,223,64,17,0,0,0,0,0,0,0,40,177,34,0,152,175,34,0,92,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,240,170,34,0,56,167,34,0,80,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,48,164,34,0,200,162,34,0,84,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,248,160,34,0,224,159,34,0,88,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,232,158,34,0,224,157,34,0,0,0,0,0,128,0,0,0,240,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,120,156,34,0,232,151,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,136,149,34,0,232,147,34,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,240,146,34,0,192,145,34,0,0,0,0,0,128,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,80,145,34,0,112,144,34,0,0,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,160,143,34,0,192,142,34,0,0,0,0,0,128,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,18,0,0,0,200,165,34,0,144,141,34,0,32,138,34,0,96,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,64,17,0,0,0,0,0,0,0,176,135,34,0,112,134,34,0,100,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,64,17,0,0,0,0,0,0,0,88,133,34,0,80,132,34,0,104,1,0,0,1,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,48,131,34,0,80,130,34,0,108,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,232,128,34,0,168,127,34,0,112,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,240,126,34,0,224,122,34,0,88,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,64,120,34,0,48,119,34,0,116,1,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,144,117,34,0,0,0,0,0,120,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,176,115,34,0,96,114,34,0,124,1,0,0,1,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,32,113,34,0,0,0,0,0,84,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,25,0,0,0,0,0,0,0,152,111,34,0,0,0,0,0,92,2,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,72,110,34,0,0,0,0,0,96,2,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,0,0,0,0,136,109,34,0,0,106,34,0,104,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,17,0,0,0,0,0,0,0,80,103,34,0,144,102,34,0,184,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,10,0,0,0,0,0,0,0,200,101,34,0,0,0,0,0,28,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,184,132,37,0,0,0,0,0,192,1,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,11,0,0,0,184,132,37,0,0,101,34,0,0,0,0,0,200,1,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,10,0,0,0,0,101,34,0,120,100,34,0,0,0,0,0,44,2,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,192,99,34,0,0,0,0,0,48,2,0,0,4,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,0,0,0,0,0,0,224,255,255,239,71,17,0,0,0,0,0,0,0,184,98,34,0,0,0,0,0,112,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,27,0,0,0,0,0,0,0,216,96,34,0,0,0,0,0,128,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,34,64,19,0,0,0,0,0,0,0,216,93,34,0,0,0,0,0,132,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,46,64,19,0,0,0,0,0,0,0,240,86,34,0,0,0,0,0,136,1,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,36,64,19,0,0,0,0,0,0,0,96,82,34,0,0,0,0,0,140,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,19,0,0,0,0,0,0,0,200,76,34,0,0,0,0,0,144,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,64,19,0,0,0,0,0,0,0,24,73,34,0,120,69,34,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,200,66,34,0,8,64,34,0,148,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,17,0,0,0,0,0,0,0,72,59,34,0,176,55,34,0,44,3,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,27,0,0,0,72,59,34,0,16,53,34,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,72,59,34,0,176,46,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,19,0,0,0,72,59,34,0,8,42,34,0,32,39,34,0,208,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,64,9,0,0,0,8,42,34,0,40,37,34,0,216,35,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,208,34,34,0,64,33,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,48,32,34,0,176,30,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,40,29,34,0,0,26,34,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,144,23,34,0,112,22,34,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,224,21,34,0,208,20,34,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,208,19,34,0,224,18,34,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,168,17,34,0,192,16,34,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,0,15,34,0,168,11,34,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,42,34,0,248,9,34,0,64,8,34,0,212,1,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,10,0,0,0,248,9,34,0,0,7,34,0,0,0,0,0,120,3,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,0,0,0,0,0,0,0,0,48,6,34,0,160,4,34,0,168,3,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,34,0,0,0,0,0,0,0,200,3,34,0,240,1,34,0,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,34,0,0,0,200,3,34,0,8,1,34,0,0,0,0,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,34,0,0,0,200,3,34,0,152,251,36,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,34,0,0,0,200,3,34,0,16,0,34,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,34,0,0,0,200,3,34,0,176,252,33,0,0,0,0,0,232,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,26,0,0,0,0,0,0,0,184,250,33,0,152,249,33,0,176,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,18,0,0,0,0,0,0,0,144,248,33,0,16,247,33,0,152,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,19,0,0,0,144,248,33,0,48,246,33,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,144,248,33,0,24,245,33,0,0,0,0,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,144,248,33,0,192,219,35,0,0,0,0,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,144,248,33,0,24,243,33,0,0,0,0,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,144,248,33,0,32,143,36,0,0,0,0,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,144,248,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,232,3,0,0,247,73,62,179,212,0,71,150,134,134,201,112,123,100,55,42,6,7,10,11,0,0,0,0,120,0,0,0,0,0,0,0,0,128,64,192,32,160,96,224,16,144,80,208,48,176,112,240,8,136,72,200,40,168,104,232,24,152,88,216,56,184,120,248,4,132,68,196,36,164,100,228,20,148,84,212,52,180,116,244,12,140,76,204,44,172,108,236,28,156,92,220,60,188,124,252,2,130,66,194,34,162,98,226,18,146,82,210,50,178,114,242,10,138,74,202,42,170,106,234,26,154,90,218,58,186,122,250,6,134,70,198,38,166,102,230,22,150,86,214,54,182,118,246,14,142,78,206,46,174,110,238,30,158,94,222,62,190,126,254,1,129,65,193,33,161,97,225,17,145,81,209,49,177,113,241,9,137,73,201,41,169,105,233,25,153,89,217,57,185,121,249,5,133,69,197,37,165,101,229,21,149,85,213,53,181,117,245,13,141,77,205,45,173,109,237,29,157,93,221,61,189,125,253,3,131,67,195,35,163,99,227,19,147,83,211], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1988148);
/* memory initializer */ allocate([51,179,115,243,11,139,75,203,43,171,107,235,27,155,91,219,59,187,123,251,7,135,71,199,39,167,103,231,23,151,87,215,55,183,119,247,15,143,79,207,47,175,111,239,31,159,95,223,63,191,127,255,0,0,0,0,0,0,0,0,176,185,36,0,3,1,1,16,32,56,33,56,34,56,0,0,112,84,39,0,3,1,0,0,36,56,76,56,140,56,0,0,88,41,37,0,3,0,0,32,40,56,72,56,104,56,0,0,112,215,35,0,3,0,0,32,104,56,72,56,40,56,0,0,168,230,34,0,3,1,0,16,32,56,33,56,34,56,0,0,152,36,34,0,3,0,0,16,32,56,33,56,34,56,0,0,64,134,33,0,3,2,2,16,32,56,33,56,34,56,0,0,32,11,33,0,3,2,0,16,32,56,33,56,34,56,0,0,16,165,32,0,1,0,0,64,32,56,0,0,0,0,0,0,184,73,32,0,1,0,0,4,32,0,0,0,0,0,0,0,168,48,40,0,1,0,0,4,32,7,0,0,0,0,0,0,208,211,39,0,1,0,0,2,32,56,0,0,0,0,0,0,48,108,39,0,3,1,1,16,32,56,33,56,34,56,0,0,216,27,39,0,3,1,0,16,32,56,33,56,34,56,0,0,80,215,38,0,3,0,0,16,32,56,33,56,34,56,0,0,8,146,38,0,0,0,0,8,0,0,0,0,0,0,0,0,160,87,38,0,0,0,0,8,0,0,0,0,0,0,0,0,48,34,38,0,3,1,0,0,68,56,44,56,108,56,0,0,200,241,37,0,3,2,0,0,76,56,52,56,148,56,0,0,64,196,37,0,3,0,0,96,32,16,32,19,32,14,0,0,248,161,37,0,3,0,0,36,140,0,76,8,44,0,0,0,80,122,37,0,3,0,0,96,32,0,32,9,32,3,0,0,192,54,37,0,3,0,0,96,32,14,32,19,32,16,0,0,128,13,37,0,3,0,0,36,44,0,76,8,140,0,0,0,160,228,36,0,3,0,0,96,32,3,32,9,32,0,0,0,0,193,36,0,3,1,1,16,32,56,37,56,69,56,0,0,232,163,36,0,3,1,1,16,32,56,69,56,37,56,0,0,8,137,36,0,4,0,0,160,76,56,108,56,140,56,44,56,136,109,36,0,4,0,0,160,44,56,76,56,108,56,140,56,232,82,36,0,4,0,0,160,140,56,108,56,76,56,44,56,216,57,36,0,4,0,0,160,108,56,76,56,44,56,140,56,152,28,36,0,1,0,0,1,36,120,0,0,0,0,0,0,208,225,35,0,1,0,0,0,36,120,0,0,0,0,0,0,112,196,35,0,3,0,1,16,32,56,33,56,34,56,0,0,216,172,35,0,3,0,1,16,32,56,33,56,34,56,0,0,240,150,35,0,4,1,1,144,32,56,33,56,34,56,35,56,64,129,35,0,0,1,1,8,0,0,0,0,0,0,0,0,152,106,35,0,0,1,1,8,0,0,0,0,0,0,0,0,64,87,35,0,0,1,1,8,0,0,0,0,0,0,0,0,16,70,35,0,0,1,1,8,0,0,0,0,0,0,0,0,216,51,35,0,0,1,1,8,0,0,0,0,0,0,0,0,80,28,35,0,3,0,0,33,52,120,116,120,180,120,0,0,208,240,34,0,3,0,0,32,52,120,116,120,180,120,0,0,200,217,34,0,3,0,0,33,4,35,36,45,36,32,0,0,24,203,34,0,3,0,0,32,68,35,36,45,36,32,0,0,176,186,34,0,3,0,0,33,4,34,36,37,36,32,0,0,144,168,34,0,3,0,0,32,68,34,36,37,36,32,0,0,136,150,34,0,3,0,0,33,36,32,36,45,4,35,0,0,152,136,34,0,3,0,0,32,36,32,36,45,68,35,0,0,144,121,34,0,3,0,0,33,36,32,36,37,4,34,0,0,72,104,34,0,3,0,0,32,36,32,36,37,68,34,0,0,240,83,34,0,0,1,1,8,0,0,0,0,0,0,0,0,112,43,34,0,0,1,1,8,0,0,0,0,0,0,0,0,80,24,34,0,0,1,1,8,0,0,0,0,0,0,0,0,152,10,34,0,3,1,1,16,36,120,37,120,38,120,0,0,136,251,33,0,3,1,1,17,36,120,37,120,38,120,0,0,32,233,33,0,3,1,0,16,36,120,37,120,38,120,0,0,240,218,33,0,3,1,0,17,36,120,37,120,38,120,0,0,96,207,33,0,3,0,0,16,36,120,37,120,38,120,0,0,32,197,33,0,3,0,0,17,36,120,37,120,38,120,0,0,160,188,33,0,0,1,1,8,0,0,0,0,0,0,0,0,64,174,33,0,0,1,1,8,0,0,0,0,0,0,0,0,8,140,33,0,3,0,0,32,68,24,36,28,36,24,0,0,120,125,33,0,3,0,0,33,4,24,36,28,36,24,0,0,0,116,33,0,3,0,0,32,36,24,36,28,68,24,0,0,80,106,33,0,3,0,0,33,36,24,36,28,4,24,0,0,104,96,33,0,2,0,0,128,36,56,68,56,0,0,0,0,112,86,33,0,3,0,0,33,180,120,116,120,52,120,0,0,160,77,33,0,3,0,0,32,180,120,116,120,52,120,0,0,152,69,33,0,3,1,1,17,36,64,37,64,38,64,0,0,32,61,33,0,3,1,1,16,36,64,37,64,38,64,0,0,48,48,33,0,3,1,1,17,36,72,37,72,38,72,0,0,240,16,33,0,3,1,1,16,36,72,37,72,38,72,0,0,152,3,33,0,3,1,0,17,36,72,37,72,38,72,0,0,176,251,32,0,3,1,0,16,36,72,37,72,38,72,0,0,176,243,32,0,3,0,0,17,36,64,37,64,38,64,0,0,208,235,32,0,3,0,0,16,36,64,37,64,38,64,0,0,160,229,32,0,3,0,0,17,36,72,37,72,38,72,0,0,168,222,32,0,3,0,0,16,36,72,37,72,38,72,0,0,240,215,32,0,3,1,0,17,36,64,37,64,38,64,0,0,176,206,32,0,3,1,0,16,36,64,37,64,38,64,0,0,192,195,32,0,0,1,1,8,0,0,0,0,0,0,0,0,136,169,32,0,3,0,0,48,34,56,32,56,33,56,0,0,104,158,32,0,3,0,0,49,38,64,36,64,37,64,0,0,184,151,32,0,3,0,0,48,38,64,36,64,37,64,0,0,88,144,32,0,3,0,0,49,38,72,36,72,37,72,0,0,24,137,32,0,3,0,0,48,38,72,36,72,37,72,0,0,88,131,32,0,3,0,0,49,38,120,36,120,37,120,0,0,104,125,32,0,3,0,0,48,38,120,36,120,37,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,119,32,0,4,1,1,145,36,64,37,64,38,64,39,64,88,112,32,0,4,1,1,144,36,64,37,64,38,64,39,64,224,102,32,0,4,1,0,145,36,64,37,64,38,64,39,64,8,78,32,0,4,1,0,144,36,64,37,64,38,64,39,64,0,67,32,0,4,0,0,145,36,64,37,64,38,64,39,64,152,60,32,0,4,0,0,144,36,64,37,64,38,64,39,64,160,52,32,0,4,1,1,145,36,72,37,72,38,72,39,72,232,46,32,0,4,1,1,144,36,72,37,72,38,72,39,72,128,40,32,0,4,1,0,145,36,72,37,72,38,72,39,72,152,35,32,0,4,1,0,144,36,72,37,72,38,72,39,72,120,29,32,0,4,0,0,145,36,72,37,72,38,72,39,72,16,88,40,0,4,0,0,144,36,72,37,72,38,72,39,72,160,76,40,0,4,1,1,145,36,120,37,120,38,120,39,120,240,52,40,0,4,1,1,144,36,120,37,120,38,120,39,120,200,42,40,0,4,1,0,145,36,120,37,120,38,120,39,120,224,34,40,0,4,1,0,144,36,120,37,120,38,120,39,120,216,26,40,0,4,0,0,145,36,120,37,120,38,120,39,120,176,21,40,0,4,0,0,144,36,120,37,120,38,120,39,120,232,15,40,0,0,1,1,8,0,0,0,0,0,0,0,0,96,11,40,0,3,0,0,0,52,92,116,92,180,92,0,0,112,5,40,0,3,0,0,1,52,92,116,92,180,92,0,0,104,255,39,0,3,1,0,16,32,56,37,56,69,56,0,0,208,243,39,0,3,1,0,16,36,72,45,72,109,72,0,0,80,217,39,0,3,1,0,17,36,72,45,72,109,72], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+1998388);
/* memory initializer */ allocate([192,205,39,0,4,0,0,161,60,120,124,120,188,120,252,120,232,194,39,0,4,0,0,160,60,120,124,120,188,120,252,120,184,185,39,0,4,0,0,161,188,120,124,120,60,120,252,120,96,178,39,0,4,0,0,160,188,120,124,120,60,120,252,120,200,171,39,0,3,0,0,32,76,56,108,56,140,56,0,0,120,165,39,0,3,0,0,32,44,56,76,56,108,56,0,0,80,155,39,0,3,0,0,32,140,56,108,56,76,56,0,0,24,148,39,0,3,0,0,32,108,56,76,56,44,56,0,0,56,137,39,0,4,0,0,144,32,56,33,56,34,56,35,56,112,113,39,0,4,1,0,144,32,56,33,56,34,56,35,56,200,101,39,0,3,1,1,17,36,88,37,88,38,88,0,0,112,94,39,0,3,1,1,16,36,88,37,88,38,88,0,0,88,85,39,0,3,1,1,17,36,104,37,104,38,104,0,0,208,79,39,0,3,1,1,16,36,104,37,104,38,104,0,0,208,74,39,0,3,1,0,17,36,88,37,88,38,88,0,0,88,69,39,0,3,1,0,16,36,88,37,88,38,88,0,0,0,64,39,0,3,1,0,17,36,104,37,104,38,104,0,0,96,58,39,0,3,1,0,16,36,104,37,104,38,104,0,0,152,51,39,0,3,0,0,17,36,88,37,88,38,88,0,0,72,32,39,0,3,0,0,16,36,88,37,88,38,88,0,0,160,22,39,0,3,0,0,17,36,104,37,104,38,104,0,0,192,16,39,0,3,0,0,16,36,104,37,104,38,104,0,0,160,10,39,0,3,0,0,49,38,88,36,88,37,88,0,0,176,5,39,0,3,0,0,48,38,88,36,88,37,88,0,0,40,1,39,0,3,0,0,49,38,104,36,104,37,104,0,0,216,252,38,0,3,0,0,48,38,104,36,104,37,104,0,0,0,248,38,0,4,0,0,176,34,56,32,56,33,56,35,56,144,244,38,0,4,0,0,177,38,120,36,120,37,120,39,120,56,237,38,0,4,0,0,176,38,120,36,120,37,120,39,120,72,218,38,0,3,2,0,16,32,56,33,56,34,56,0,0,88,210,38,0,3,0,0,32,0,8,0,24,0,8,0,0,96,205,38,0,3,0,0,32,0,8,0,24,0,8,0,0,176,198,38,0,3,0,0,32,0,8,0,24,0,8,0,0,40,194,38,0,3,0,0,32,0,8,0,24,0,8,0,0,24,189,38,0,3,0,0,32,4,24,4,56,4,24,0,0,112,183,38,0,3,0,0,33,4,24,4,56,4,24,0,0,88,178,38,0,3,0,0,32,4,24,4,56,4,24,0,0,176,173,38,0,3,0,0,33,4,24,4,56,4,24,0,0,0,166,38,0,3,0,0,32,4,24,4,56,4,24,0,0,88,149,38,0,3,0,0,33,4,24,4,56,4,24,0,0,168,141,38,0,3,0,0,32,4,24,4,56,4,24,0,0,104,137,38,0,3,0,0,33,4,24,4,56,4,24,0,0,184,48,40,0,240,211,39,0,64,165,32,0,208,73,32,0,224,212,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,0,0,0,0,224,212,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,90,39,0,112,0,0,0,88,147,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,184,208,36,0,72,89,39,0,0,0,0,0,0,0,0,0,96,43,37,0,120,217,35,0,96,232,34,0,200,37,34,0,48,135,33,0,0,0,0,0,0,43,39,0,0,0,0,0,144,118,18,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,119,32,0,152,9,0,0,136,7,30,0,100,66,52,0,0,0,0,0,0,0,0,0,246,3,0,0,154,1,0,0,3,0,0,0,30,11,0,0,0,0,0,0,0,0,0,0,0,8,0,0,7,0,0,0,0,16,0,0,5,128,0,0,0,16,0,0,33,16,0,0,0,32,0,0,183,29,193,4,1,32,0,0,32,131,184,237,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,251,76,134,0,64,123,37,0,194,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,20,37,0,208,6,0,0,160,62,30,0,100,66,52,0,4,0,0,0,0,0,0,0,162,3,0,0,58,8,0,0,5,0,0,0,132,5,0,0,0,0,0,0,0,0,0,0,40,218,34,0,64,4,0,0,176,140,11,0,100,66,52,0,4,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,48,49,50,51,52,53,54,55,56,57,43,47,0,0,0,0,0,0,0,0,232,3,0,0,200,0,0,0,150,0,0,0,130,0,0,0,150,0,0,0,125,0,0,0,120,0,0,0,115,0,0,0,115,0,0,0,115,0,0,0,115,0,0,0,115,0,0,0,115,0,0,0,115,0,0,0,115,0,0,0,115,0,0,0,105,0,0,0,0,0,0,0,128,48,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,48,36,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,1,0,0,0,0,0,0,0,0,0,0,2,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,205,204,204,61,0,0,0,0,4,0,3,5,0,0,0,0,168,66,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,3,36,0,248,8,35,0,16,0,0,0,32,82,85,68,255,255,255,255,255,255,255,127,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,168,65,34,0,80,159,33,0,24,0,0,0,32,82,85,68,255,255,255,255,255,255,255,127,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,32,35,33,0,96,183,32,0,72,0,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,112,91,32,0,80,159,33,0,80,0,0,0,2,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,224,195,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,232,65,40,0,24,232,39,0,8,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,248,126,39,0,48,43,39,0,88,0,0,0,2,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,184,227,38,0,0,158,38,0,96,0,0,0,2,0,0,0,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,56,98,38,0,24,44,38,0,56,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,176,249,37,0,184,206,37,0,64,0,0,0,3,0,0,0,255,255,255,255,255,255,239,127,255,255,255,255,255,255,239,255,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,160,169,37,0,136,132,37,0,48,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,127,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,66,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,1,0,0,0,0,0,0,0,0,0,0,212,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,95,37,0,112,0,0,0,144,151,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,4,4,3,3,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,4,4,4,3,3,3,2,2,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,5,5,5,4,4,4,4,3,3,3,3,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,5,5,4,4,3,3,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,4,4,4,3,3,3,2,2,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,5,5,5,5,5,5,5,3,3,3,3,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,255,0,0,0,0,0,0,0,251,255,0,0,0,249,0,0,0,0,0,0,0,0,0,0,249,0,0,0,0,0,0,0,0,0,251,0,0,0,0,0,0,251,0,0,0,0,249,249,0,0,0,0,0,0,0,0,249,0,0,0,0,0,0,0,254,254,251,0,0,0,0,0,0,0,0,0,254,251,0,0,0,0,0,0,0,0,0,254,251,0,0,0,0,0,251,0,0,0,0,0,0,254,249,254,0,0,0,0,0,0,0,0,0,254,251,0,0,0,0,0,0,251,251,0,0,0,0,0,0,0,251,254,0,0,0,0,255,251,253,254,255,255,0,0,0,254,251,253,253,254,255,255,0,0,0,255,255,255,0,0,0,0,0,255,253,0,0,0,0,0,0,0,255,254,0,0,0,0,0,0,0,255,253,255,0,0,0,0,1,1,255,251,253,253,254,255,0,0,0,255,255,252,254,254,255,255,0,0,255,255,253,254,253,255,255,255,0,255,252,254,253,255,0,0,0,0,0,255,254,254,255,255,0,0,0,0,254,255,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,255,255,253,254,254,255,255,255,0,0,0,0,0,0,0,0,0,0,0,255,253,254,254,255,255,255,0,255,254,0,1,1,1,1,1,1,0,255,1,1,1,1,1,1,1,0,254,1,1,1,1,1,1,1,0,254,0,1,1,1,1,1,1,255,255,0,1,1,1,1,1,1,0,0,255,0,1,1,1,1,1,255,255,1,1,1,1,1,1,1,0,0,255,1,1,1,1,1,1,0,255,0,1,1,1,1,1,1,255,255,255,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,0,0,0,1,1,1,1,1,1,0,255,255,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,0,253,254,1,1,1,1,2,2,253,251,253,2,2,2,2,2,2,255,254,0,2,2,2,2,2,2,255,254,0,1,2,2,2,2,2,0,254,0,2,2,2,2,2,2,255,0,1,2,2,2,2,2,2,0,0,1,2,2,2,2,2,2,0,254,0,1,2,2,2,2,2,0,255,1,2,2,2,2,2,2,255,255,0,2,2,2,2,2,2,255,255,0,1,2,2,2,2,2,255,254,255,2,2,2,2,2,2,0,255,0,2,2,2,2,2,2,1,1,0,1,2,2,2,2,2,0,1,2,2,2,2,2,2,2,1,0,0,1,2,2,2,2,2,0,0,0,1,2,2,2,2,2,255,255,255,1,2,2,2,2,2,0,1,2,3,3,3,3,3,3,1,1,2,3,3,3,3,3,3,255,0,1,2,3,3,3,3,3,0,0,2,3,3,3,3,3,3,255,0,1,3,3,3,3,3,3,0,0,1,3,3,3,3,3,3,1,2,3,3,3,3,3,3,3,1,2,2,3,3,3,3,3,3,0,1,1,3,3,3,3,3,3,0,0,1,2,3,3,3,3,3,255,1,2,3,3,3,3,3,3,255,0,2,3,3,3,3,3,3,2,2,3,3,3,3,3,3,3,1,1,3,3,3,3,3,3,3,0,2,3,3,3,3,3,3,3,0,1,1,2,3,3,3,3,3,0,1,2,3,4,4,4,4,4,1,2,3,4,4,4,4,4,4,0,0,2,3,4,4,4,4,4,1,1,2,4,4,4,4,4,4,0,1,2,4,4,4,4,4,4,255,0,1,3,4,4,4,4,4,0,0,1,3,4,4,4,4,4,1,1,2,3,4,4,4,4,4,0,1,1,3,4,4,4,4,4,2,2,3,4,4,4,4,4,4,1,1,3,4,4,4,4,4,4,1,2,2,4,4,4,4,4,4,255,0,2,3,4,4,4,4,4,0,1,3,4,4,4,4,4,4,1,2,2,3,4,4,4,4,4,0,2,3,4,4,4,4,4,4,1,2,3,4,5,5,5,5,5,0,1,2,3,4,5,5,5,5,0,1,2,3,5,5,5,5,5,1,1,3,4,5,5,5,5,5,1,1,2,4,5,5,5,5,5,1,2,2,4,5,5,5,5,5,1,1,2,3,5,5,5,5,5,2,2,3,4,5,5,5,5,5,0,1,2,4,5,5,5,5,5,2,2,3,5,5,5,5,5,5,1,2,3,5,5,5,5,5,5,0,1,3,4,5,5,5,5,5,1,2,2,3,5,5,5,5,5,2,3,4,5,5,5,5,5,5,0,2,3,4,5,5,5,5,5,1,1,1,3,4,5,5,5,5,1,2,3,4,5,5,5,6,6,1,2,3,4,5,6,6,6,6,2,3,4,5,6,6,6,6,6,1,2,3,4,6,6,6,6,6,2,2,3,4,5,5,5,6,6,1,2,3,4,5,5,6,6,6,2,2,3,4,6,6,6,6,6,2,2,3,4,5,6,6,6,6,2,2,4,5,6,6,6,6,6,2,2,3,5,6,6,6,6,6,1,2,3,5,6,6,6,6,6,2,3,3,5,6,6,6,6,6,1,2,4,5,6,6,6,6,6,2,2,3,4,5,5,6,6,6,2,3,3,4,6,6,6,6,6,1,3,4,5,6,6,6,6,6,0,1,2,6,7,0,0,0,0,1,7,0,0,0,0,0,0,4,12,13,30,31,14,5,0,4,12,30,31,13,14,5,0,4,5,6,7,0,0,0,0,2,3,0,0,0,0,0,1,3,4,4,5,5,4,3,1,3,4,5,5,4,4,3,1,3,3,3,3,0,0,0,1,2,2,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,1,4,2,1,255,255,255,255,200,164,16,0,112,164,16,0,1,4,2,0,255,255,255,255,96,164,16,0,8,164,16,0,1,2,3,1,255,255,255,255,248,163,16,0,192,163,16,0,1,1,3,0,255,255,255,255,184,163,16,0,176,163,16,0,1,2,4,1,255,255,255,255,160,163,16,0,184,162,16,0,1,1,4,0,255,255,255,255,176,162,16,0,160,162,16,0,1,1,6,1,255,255,255,255,144,162,16,0,80,162,16,0,4,4,2,1,255,255,255,255,64,162,16,0,232,161,16,0,1,4,2,0,255,255,255,255,224,161,16,0,136,161,16,0,1,2,3,1,255,255,255,255,120,161,16,0,64,161,16,0,1,2,4,1,255,255,255,255,48,161,16,0,176,160,16,0,1,2,4,1,255,255,255,255,160,160,16,0,184,159,16,0,1,2,4,0,255,255,255,255,168,159,16,0,168,158,16,0,1,1,6,1,255,255,255,255,152,158,16,0,88,158,16,0,1,4,2,1,255,255,255,255,72,158,16,0,240,157,16,0,1,2,3,1,255,255,255,255,224,157,16,0,192,157,16,0,1,2,3,1,255,255,255,255,176,157,16,0,120,157,16,0,1,1,3,0,255,255,255,255,112,157,16,0,0,0,0,0,1,1,3,0,255,255,255,255,104,157,16,0,96,157,16,0,1,2,4,0,255,255,255,255,80,157,16,0,80,156,16,0,1,1,6,1,255,255,255,255,72,156,16,0,8,156,16,0,1,2,2,1,255,255,255,255,0,156,16,0,240,155,16,0,1,4,2,0,255,255,255,255,224,155,16,0,136,155,16,0,1,4,2,0,255,255,255,255,120,155,16,0,120,154,16,0,1,1,3,0,255,255,255,255,112,154,16,0,104,154,16,0,1,2,4,1,255,255,255,255,88,154,16,0,112,153,16,0,1,2,4,0,255,255,255,255,96,153,16,0,96,152,16,0,1,1,6,1,255,255,255,255,88,152,16,0,24,152,16,0,1,4,2,1,255,255,255,255,8,152,16,0,176,151,16,0,1,4,2,0,255,255,255,255,160,151,16,0,72,151,16,0,1,1,3,1,255,255,255,255,64,151,16,0,56,151,16,0,1,2,4,1,255,255,255,255,40,151,16,0,168,150,16,0,1,1,3,0,255,255,255,255,160,150,16,0,152,150,16,0,1,2,4,0,255,255,255,255,144,150,16,0,144,149,16,0,1,1,6,1,255,255,255,255,136,149,16,0,72,149,16,0,1,4,2,1,255,255,255,255,56,149,16,0,224,148,16,0,1,2,3,1,255,255,255,255,208,148,16,0,176,148,16,0,1,1,3,1,255,255,255,255,64,151,16,0,168,148,16,0,1,2,4,1,255,255,255,255,160,148,16,0,32,148,16,0,1,1,3,0,255,255,255,255,24,148,16,0,16,148,16,0,1,1,5,1,255,255,255,255,8,148,16,0,232,147,16,0,1,1,6,1,255,255,255,255,216,147,16,0,152,147,16,0,2,4,2,1,255,255,255,255,136,147,16,0,48,147,16,0,1,2,3,1,255,255,255,255,40,147,16,0,8,147,16,0,1,4,2,0,255,255,255,255,248,146,16,0,248,145,16,0,1,2,4,1,255,255,255,255,240,145,16,0,112,145,16,0,1,1,4,1,255,255,255,255,104,145,16,0,88,145,16,0,1,1,5,1,255,255,255,255,72,145,16,0,40,145,16,0,1,1,6,1,255,255,255,255,24,145,16,0,216,144,16,0,1,2,1,0,255,255,255,255,208,144,16,0,0,0,0,0,2,4,2,0,255,255,255,255,192,144,16,0,104,144,16,0,1,2,3,1,255,255,255,255,88,144,16,0,32,144,16,0,1,2,4,1,255,255,255,255,16,144,16,0,144,143,16,0,1,1,4,1,255,255,255,255,136,143,16,0,120,143,16,0,2,2,4,0,255,255,255,255,104,143,16,0,104,142,16,0,4,1,6,1,6,0,0,0,0,0,0,0,0,0,0,0,4,4,2,1,255,255,255,255,88,142,16,0,0,142,16,0,1,4,2,0,255,255,255,255,240,141,16,0,152,141,16,0,4,2,3,1,255,255,255,255,136,141,16,0,80,141,16,0,1,2,4,1,255,255,255,255,64,141,16,0,192,140,16,0,1,2,4,1,255,255,255,255,176,140,16,0,200,139,16,0,1,1,4,0,5,0,0,0,0,0,0,0,0,0,0,0,1,1,6,1,255,255,255,255,184,139,16,0,120,139,16,0,1,4,2,1,14,0,0,0,0,0,0,0,0,0,0,0,1,4,2,0,255,255,255,255,104,139,16,0,16,139,16,0,1,2,3,1,9,0,0,0,0,0,0,0,0,0,0,0,1,2,4,1,255,255,255,255,0,139,16,0,128,138,16,0,1,2,4,1,11,0,0,0,0,0,0,0,0,0,0,0,1,2,4,0,255,255,255,255,112,138,16,0,112,137,16,0,1,1,6,1,6,0,0,0,0,0,0,0,0,0,0,0,4,4,2,1,28,0,0,0,0,0,0,0,0,0,0,0,4,4,2,0,22,0,0,0,0,0,0,0,0,0,0,0,1,2,3,1,2,0,0,0,0,0,0,0,0,0,0,0,1,2,4,1,31,0,0,0,0,0,0,0,0,0,0,0,2,2,4,1,60,0,0,0,0,0,0,0,0,0,0,0,2,2,4,0,255,255,255,255,96,137,16,0,96,136,16,0,4,1,6,1,6,0,0,0,0,0,0,0,0,0,0,0,1,4,2,1,35,0,0,0,0,0,0,0,0,0,0,0,1,4,2,0,255,255,255,255,80,136,16,0,248,135,16,0,1,4,2,0,255,255,255,255,232,135,16,0,232,134,16,0,2,2,4,1,59,0,0,0,0,0,0,0,0,0,0,0,1,2,4,1,255,255,255,255,216,134,16,0,240,133,16,0,1,2,4,0,75,0,0,0,0,0,0,0,0,0,0,0,1,1,6,1,255,255,255,255,224,133,16,0,160,133,16,0,1,4,2,1,255,255,255,255,144,133,16,0,56,133,16,0,4,2,3,1,255,255,255,255,40,133,16,0,8,133,16,0,1,2,3,1,255,255,255,255,248,132,16,0,192,132,16,0,4,2,4,1,66,0,0,0,0,0,0,0,0,0,0,0,1,1,3,0,32,0,0,0,0,0,0,0,0,0,0,0,1,2,4,0,12,0,0,0,0,0,0,0,0,0,0,0,1,1,6,1,255,255,255,255,176,132,16,0,112,132,16,0,2,4,2,1,42,0,0,0,0,0,0,0,0,0,0,0,1,2,3,1,255,255,255,255,96,132,16,0,64,132,16,0,4,1,3,1,255,255,255,255,56,132,16,0,48,132,16,0,1,1,3,0,17,0,0,0,0,0,0,0,0,0,0,0,1,1,3,0,39,0,0,0,0,0,0,0,0,0,0,0,1,1,5,1,255,255,255,255,32,132,16,0,0,132,16,0,2,1,6,1,62,0,0,0,0,0,0,0,0,0,0,0,1,4,2,1,28,0,0,0,0,0,0,0,0,0,0,0,1,4,2,0,255,255,255,255,240,131,16,0,152,131,16,0,1,1,3,1,255,255,255,255,144,131,16,0,136,131,16,0,1,1,3,0,255,255,255,255,128,131,16,0,120,131,16,0,4,2,4,1,255,255,255,255,104,131,16,0,128,130,16,0,1,2,4,0,255,255,255,255,112,130,16,0,112,129,16,0,1,1,6,1,255,255,255,255,96,129,16,0,32,129,16,0,1,4,2,1,255,255,255,255,16,129,16,0,184,128,16,0,4,4,2,0,78,0,0,0,0,0,0,0,0,0,0,0,4,4,2,0,255,255,255,255,168,128,16,0,168,127,16,0,1,1,4,1,255,255,255,255,160,127,16,0,144,127,16,0,1,2,4,1,255,255,255,255,128,127,16,0,152,126,16,0,1,1,5,1,47,0,0,0,0,0,0,0,0,0,0,0,1,1,6,1,255,255,255,255,136,126,16,0,72,126,16,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,0,0,0,1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,253,254,255,0,3,5,6,8,40,253,254,0,1,7,9,11,13,20,255,0,0,1,6,8,10,13,41,0,0,0,2,5,5,6,8,14,0,0,0,2,6,7,8,11,47,0,0,1,2,5,7,8,10,32,0,0,1,3,8,10,12,14,47,0,0,2,4,9,10,12,14,40,0,0,3,5,9,10,12,14,22,0,1,3,5,10,14,18,22,31,0,2,5,6,10,10,10,12,46,0,2,5,7,12,14,15,18,44,1,1,4,5,7,7,8,9,15,1,2,2,2,4,5,7,9,26,1,2,2,3,6,7,7,8,47,1,2,2,3,6,8,10,13,22,1,3,4,7,13,17,21,24,41,1,4,0,4,10,12,13,14,17,2,3,3,3,6,8,10,13,48,2,3,3,4,9,12,14,17,47,2,3,3,5,10,12,14,17,25,2,3,5,7,8,9,9,9,13,2,3,5,9,16,21,25,28,33,2,4,5,8,12,14,17,19,26,2,4,6,8,12,13,13,15,20,2,4,7,12,20,26,30,32,35,3,3,5,6,12,14,16,19,34,3,4,4,5,7,9,10,11,48,3,4,5,6,8,9,10,11,16,3,5,5,5,7,9,10,13,35,3,5,5,7,10,12,13,15,49,3,5,7,7,8,7,9,12,21,3,5,7,8,12,14,15,15,24,3,5,7,10,16,21,24,27,44,3,5,8,14,21,26,28,29,42,3,6,10,13,18,19,20,22,27,3,6,11,16,24,27,28,29,31,4,5,4,3,4,6,8,11,18,4,6,5,6,9,10,12,14,20,4,6,7,6,6,6,7,8,46,4,6,7,9,13,16,18,20,48,4,6,7,9,14,17,20,23,31,4,6,9,11,14,15,15,17,21,4,8,13,20,27,32,35,36,38,5,6,6,4,5,6,7,6,6,5,7,7,8,9,9,10,12,49,5,8,9,9,10,11,12,13,42,5,8,10,12,15,16,17,19,42,5,8,12,17,26,31,32,33,44,5,9,13,16,20,22,23,23,35,6,8,8,7,6,5,6,8,15,6,8,8,8,9,10,12,16,24,6,8,8,9,10,10,11,11,13,6,8,10,13,19,21,24,26,32,6,9,10,11,13,13,14,16,49,7,9,9,10,13,14,16,19,27,7,10,12,13,16,16,17,17,27,7,10,12,14,17,19,20,22,48,8,9,10,9,10,11,11,11,19,8,11,12,12,13,13,13,13,17,8,11,13,14,16,17,19,20,27,8,12,17,22,26,28,29,30,33,10,14,16,19,21,22,22,24,28,10,15,17,18,21,22,23,25,43,0,1,2,14,15,3,13,4,5,6,7,9,8,10,11,12,0,1,13,14,15,2,12,3,4,5,6,7,8,9,10,11,0,1,2,62,63,3,61,4,5,6,57,58,59,60,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,0,1,61,62,63,2,60,3,4,5,6,57,58,59,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,0,0,2,0,3,0,12,0,28,0,60,0,124,0,125,0,0,0,126,0,127,0,61,0,29,0,13,0,4,0,5,0,0,0,4,0,12,0,28,0,120,0,121,0,122,0,123,0,0,0,124,0,125,0,126,0,127,0,29,0,13,0,5,0,0,0,2,0,3,0,4,0,5,0,12,0,13,0,56,0,57,0,58,0,59,0,60,0,0,0,61,0,62,0,63,0,0,0,2,0,3,0,24,0,25,0,112,0,204,1,205,1,206,1,207,1,208,1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,1,113,0,114,0,26,0,27,0,4,0,5,0,0,0,4,0,24,0,25,0,112,0,202,1,203,1,204,1,205,1,206,1,207,1,208,1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,1,228,0,113,0,26,0,27,0,5,0,0,0,2,0,3,0,4,0,5,0,12,0,13,0,224,0,225,0,226,0,227,0,228,0,229,0,230,0,206,1,207,1,208,1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,1,2,3,3,4,5,6,7,7,0,7,7,6,5,4,3,3,1,3,4,5,7,7,7,7,0,7,7,7,7,5,4,3,2,3,3,3,3,4,4,6,6,6,6,6,0,6,6,6,2,3,3,5,5,7,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,7,7,5,5,3,3,1,3,5,5,7,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,8,7,5,5,3,2,3,3,3,3,4,4,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,4,4,5,5,6,7,8,9,10,11,12,13,14,15,0,0,0,1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,9,9,0,1,2,31,3,29,30,4,5,6,27,28,7,24,25,26,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,2,8,1,3,3,1,4,4,16,0,0,0,0,0,0,0,18,19,20,21,22,23,24,25,26,27,28,14,15,16,17,29,9,10,11,12,13,30,4,5,6,7,8,31,0,1,2,3,4,8,11,5,6,6,4,0,8,9,10,11,12,13,14,15,16,17,5,6,7,18,19,20,21,22,4,23,24,25,26,27,0,1,2,3,28,29,30,31,4,8,10,8,6,0,8,0,1,6,1,0,1,2,4,8,0,1,7,2,3,4,5,6,1,6,1,1,1,1,0,4,1,7,1,1,1,1,1,1,2,0,0,0,0,0,0,0,0,1,7,2,6,3,4,5,1,7,1,1,1,1,1,1,2,0,0,0,0,0,0,0,0,1,2,31,3,4,5,6,7,8,29,30,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,1,7,1,0,0,3,2,6,20,0,0,0,0,0,0,0,0,28,29,1,2,3,4,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,30,31,5,6,7,8,9,10,4,6,3,23,6,0,0,0,0,1,31,2,3,4,5,6,7,26,27,28,29,30,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,2,6,1,0,2,11,18,0,2,3,4,5,6,1,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,0,3,8,5,3,2,3,2,16,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,0,2,8,1,2,4,4,4,0,16,0,0,0,0,0,0,0,0,1,15,14,2,13,3,12,4,5,6,7,8,9,10,11,1,9,1,1,1,1,1,0,1,2,8,0,0,0,0,0,0,1,14,15,2,13,3,12,4,5,6,7,8,9,10,11,1,9,1,0,3,1,1,0,2,0,8,0,0,0,0,0,15,14,1,13,2,3,12,4,5,6,7,8,9,10,11,0,1,9,1,1,1,1,1,0,2,0,8,0,0,0,0,0,7,5,8,6,9,4,10,11,0,1,2,3,12,13,14,15,1,7,1,0,2,2,1,2,8,0,0,0,0,0,0,0,0,1,255,2,254,3,4,5,6,7,8,251,252,253,9,10,11,12,246,247,248,249,250,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,243,244,245,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,1,11,1,0,0,2,2,0,9,9,29,104,100,0,0,0,0,5,4,1,0,1,2,3,3,0,4,2,4,0,1,2,1,0,4,3,3,0,2,1,0,3,1,2,4,0,1,2,0,3,2,1,0,1,2,3,0,1,2,4,0,1,2,3,1,4,2,0,0,1,2,3,0,1,2,3,6,7,4,5,0,4,10,11,12,13,14,15,0,2,3,4,5,6,14,15,0,2,6,7,0,0,0,0,1,3,4,4,4,4,4,4,2,3,3,3,3,3,4,4,1,2,3,3,0,0,0,0,0,0,0,2,0,4,0,6,0,8,0,10,0,12,0,14,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,206,36,0,192,0,34,0,64,0,0,0,3,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,2,0,0,0,0,0,0,0,0,0,0,208,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,101,34,0,112,0,0,0,120,177,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,12,39,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,2,0,0,210,0,0,0,0,0,0,0,0,0,0,0,88,200,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,2,0,0,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,55,32,0,40,30,40,0,8,0,0,0,5,0,0,0,168,188,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,112,88,39,0,40,30,40,0,8,0,0,0,5,0,0,0,168,188,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,133,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,74,38,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,103,34,0,112,0,0,0,56,179,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,234,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,74,38,0,160,19,38,0,24,0,0,0,3,0,0,0,154,153,153,153,153,153,169,63,123,20,174,71,225,122,132,63,0,0,0,0,0,0,36,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,234,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,110,34,0,112,0,0,0,40,181,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,8,39,0,112,0,0,0,240,133,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,110,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,83,36,0,0,0,0,0,0,0,0,0,160,58,36,0,0,0,0,0,4,0,0,0,200,29,36,0,1,0,0,0,8,0,0,0,16,228,35,0,1,0,0,0,12,0,0,0,96,197,35,0,2,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,173,35,0,200,151,35,0,80,130,35,0,36,0,0,0,20,0,0,0,24,0,0,0,248,107,35,0,0,0,0,0,0,0,0,0,40,88,35,0,0,0,0,0,4,0,0,0,0,71,35,0,1,0,0,0,8,0,0,0,168,52,35,0,3,0,0,0,12,0,0,0,48,29,35,0,3,0,0,0,16,0,0,0,64,242,34,0,1,0,0,0,20,0,0,0,104,218,34,0,1,0,0,0,24,0,0,0,216,203,34,0,1,0,0,0,28,0,0,0,72,187,34,0,1,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,169,34,0,200,151,35,0,80,130,35,0,36,0,0,0,20,0,0,0,24,0,0,0,248,107,35,0,0,0,0,0,0,0,0,0,40,88,35,0,0,0,0,0,4,0,0,0,0,71,35,0,1,0,0,0,8,0,0,0,168,52,35,0,3,0,0,0,12,0,0,0,48,29,35,0,3,0,0,0,16,0,0,0,64,242,34,0,1,0,0,0,20,0,0,0,104,218,34,0,1,0,0,0,24,0,0,0,72,187,34,0,5,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,11,37,0,200,151,35,0,64,151,34,0,20,0,0,0,28,0,0,0,32,0,0,0,72,137,34,0,1,0,0,0,0,0,0,0,72,122,34,0,4,0,0,0,4,0,0,0,72,105,34,0,4,0,0,0,8,0,0,0,80,130,35,0,0,0,0,0,12,0,0,0,24,85,34,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,100], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2003104);
/* memory initializer */ allocate([224,208,37,0,96,171,37,0,72,1,0,0,96,171,37,0,88,135,37,0,72,1,0,0,16,70,37,0,104,22,37,0,72,1,0,0,96,238,36,0,16,202,36,0,242,0,0,0,224,171,36,0,216,144,36,0,242,0,0,0,104,22,37,0,224,117,36,0,72,1,0,0,176,90,36,0,184,64,36,0,72,1,0,0,184,38,36,0,48,237,35,0,72,1,0,0,160,202,35,0,8,179,35,0,72,1,0,0,168,156,35,0,208,135,35,0,72,1,0,0,0,113,35,0,88,93,35,0,72,1,0,0,32,75,35,0,40,57,35,0,72,1,0,0,112,37,35,0,240,25,156,0,206,1,0,0,240,222,34,0,240,25,156,0,96,0,0,0,224,97,37,0,112,0,0,0,112,165,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,128,150,152,0,48,195,33,0,112,0,0,0,128,134,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,14,35,0,88,72,34,0,4,0,0,0,5,0,0,0,80,165,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,200,39,33,0,88,72,34,0,4,0,0,0,5,0,0,0,80,165,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,104,37,0,112,0,0,0,184,185,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,1,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,208,36,0,32,161,35,0,4,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,112,194,34,0,32,161,35,0,4,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,1,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,114,34,0,112,0,0,0,240,186,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,37,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,37,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,2,0,0,0,0,0,0,0,0,0,0,142,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,99,37,0,112,0,0,0,16,168,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,56,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,10,0,0,232,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,161,35,0,184,194,34,0,4,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,192,1,34,0,184,194,34,0,4,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,232,110,33,0,40,247,32,0,24,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,208,147,32,0,40,247,32,0,24,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,56,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,117,34,0,112,0,0,0,192,189,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,97,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,97,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,107,37,0,112,0,0,0,32,179,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,207,34,0,144,191,34,0,4,0,0,0,5,0,0,0,80,174,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,112,155,34,0,144,191,34,0,4,0,0,0,5,0,0,0,80,174,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,200,140,34,0,232,125,34,0,60,6,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,200,75,35,0,232,125,34,0,60,6,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,245,38,0,112,0,0,0,120,192,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,247,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,10,0,0,26,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,247,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,120,34,0,112,0,0,0,224,134,11,0,100,66,52,0,0,0,0,0,0,0,0,0,176,1,0,0,40,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,142,32,0,224,50,32,0,24,0,0,0,6,0,0,0,0,0,0,0,0,0,57,64,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,241,32,0,112,0,0,0,184,194,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,7,0,0,194,5,0,0,70,5,0,0,226,5,0,0,24,157,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,195,34,0,88,2,34,0,8,0,0,0,3,0,0,0,154,153,153,153,153,153,217,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,56,111,33,0,80,247,32,0,16,0,0,0,3,0,0,0,174,71,225,122,20,174,231,63,0,0,0,0,0,0,0,0,0,0,0,0,101,205,205,65,8,0,1,0,0,0,0,0,224,147,32,0,200,56,32,0,24,0,0,0,3,0,0,0,0,0,0,0,0,0,8,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,64,8,0,1,0,0,0,0,0,48,31,40,0,40,190,39,0,32,0,0,0,3,0,0,0,154,153,153,153,153,153,217,63,0,0,0,0,0,0,0,0,174,71,225,122,20,174,239,63,8,0,1,0,0,0,0,0,200,89,39,0,40,13,39,0,40,0,0,0,3,0,0,0,0,0,0,0,0,0,224,63,154,153,153,153,153,153,185,63,0,0,0,0,0,0,0,64,8,0,1,0,0,0,0,0,32,201,38,0,64,134,38,0,48,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,32,201,38,0,200,74,38,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,201,38,0,56,20,38,0,0,0,0,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,201,38,0,96,234,37,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,201,38,0,176,189,37,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,32,201,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,157,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,128,34,0,112,0,0,0,208,195,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,254,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,254,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,3,39,0,112,0,0,0,112,186,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,64,0,0,0,0,0,32,0,0,1,0,0,16,0,0,1,0,5,0,0,0,0,0,11,0,0,11,0,0,10,13,0,11,13,15,0,112,175,37,0,112,0,0,0,80,191,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,8,57,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,154,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,162,35,0,168,195,34,0,16,0,0,0,1,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,192,2,34,0,96,111,33,0,24,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,144,247,32,0,72,148,32,0,32,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,57,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,130,34,0,112,0,0,0,192,202,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,110,36,0,16,88,35,0,4,0,0,0,5,0,0,0,232,136,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,88,207,33,0,16,88,35,0,4,0,0,0,5,0,0,0,232,136,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,128,77,33,0,80,222,32,0,16,0,0,0,5,0,0,0,96,125,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,112,35,32,0,80,222,32,0,16,0,0,0,5,0,0,0,96,125,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,240,10,40,0,136,164,39,0,24,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,184,68,39,0,136,164,39,0,24,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,179,32,0,112,0,0,0,40,204,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,2,6,1,5,3,7,8,12,10,14,9,13,11,15,0,0,0,0,2,0,0,0,6,0,0,0,12,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,116,0,0,32,128,0,0,39,45,0,0,223,244,255,255,125,233,255,255,154,255,255,255,189,245,255,255,81,246,255,255,247,251,255,255,228,96,0,0,208,187,0,0,71,251,255,255,27,252,255,255,186,250,255,255,154,254,255,255,135,237,255,255,21,227,255,255,245,57,1,0,0,0,0,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,240,255,255,142,215,255,255,4,246,255,255,109,135,0,0,123,180,0,0,37,6,0,0,180,72,0,0,2,171,0,0,156,36,0,0,231,251,255,255,41,252,255,255,92,239,255,255,41,252,255,255,23,249,255,255,96,5,0,0,78,2,0,0,51,19,0,0,223,239,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,150,206,255,255,19,72,0,0,37,252,255,255,90,226,255,255,231,251,255,255,188,249,255,255,224,218,0,0,100,16,0,0,114,1,0,0,242,14,0,0,231,251,255,255,215,246,255,255,76,214,255,255,78,5,0,0,169,22,0,0,152,44,0,0,153,219,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,76,0,0,70,150,0,0,47,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,78,11,0,48,78,11,0,144,77,11,0,120,75,11,0,184,74,11,0,232,73,11,0,208,105,11,0,104,104,11,0,0,0,0,0,0,0,0,0,18,24,33,37,41,47,51,59,61,6,6,0,0,0,1,1,12,13,15,17,19,20,26,31,5,0,0,0,0,0,0,0,40,76,11,0,0,72,11,0,216,101,11,0,8,99,11,0,248,95,11,0,72,92,11,0,88,88,11,0,232,83,11,0,72,79,11,0,0,0,0,0,0,0,4,63,0,0,103,63,0,32,202,63,0,220,48,64,0,0,4,191,0,0,103,191,0,32,202,191,0,220,48,192,120,97,37,0,112,0,0,0,120,138,12,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,247,32,0,160,148,32,0,40,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,64,64,8,0,1,0,0,0,0,0,16,57,32,0,120,31,40,0,48,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,8,0,1,0,16,57,32,0,176,190,39,0,16,90,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,16,57,32,0,152,13,39,0,72,201,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,16,57,32,0,128,134,38,0,248,74,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,8,0,1,0,16,57,32,0,104,20,38,0,120,234,37,0,52,0,0,0,4,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,134,34,0,112,0,0,0,136,210,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,13,39,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,11,0,0,2,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,190,39,0,48,90,39,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,64,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,141,34,0,112,0,0,0,128,212,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,64,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,6,0,0,70,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,178,10,0,0,0,0,0,0,1,0,0,0,208,182,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1,0,1,0,1,0,1,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,5,6,7,8,9,10,12,13,15,17,20,22,25,28,32,36,40,45,50,56,63,71,80,90,101,113,127,144,162,182,203,226,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,3,3,4,4,5,5,6,7,8,9,10,11,12,13,15,16,18,20,22,24,26,28,30,33,33,35,35,36,37,37,39,39,42,44,46,48,50,52,53,54,55,56,57,58,59,60,61,62,63,64,35,0,0,0,43,1,0,0,27,0,0,0,29,0,0,0,28,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,96,187,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,130,36,0,56,158,36,0,32,0,0,0,3,0,0,0,0,0,0,0,0,112,167,64,0,0,0,0,0,0,0,0,0,0,0,0,126,132,46,65,8,0,1,0,0,0,0,0,152,104,36,0,184,76,36,0,8,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,16,64,8,0,1,0,152,104,36,0,184,53,36,0,0,13,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,80,216,35,0,56,191,35,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,112,168,35,0,160,146,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,16,124,35,0,232,101,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,152,104,36,0,160,83,35,0,32,66,35,0,40,0,0,0,3,0,0,0,205,204,204,204,204,24,134,64,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,0,49,35,0,32,66,35,0,40,0,0,0,3,0,0,0,205,204,204,204,204,24,134,64,0,0,0,0,0,0,0,0,0,0,0,0,240,105,248,64,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,38,0,112,0,0,0,80,215,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,2,0,1,3,0,0,0,0,4,0,1,3,4,5,6,7,8,9,10,11,12,13,14,15,4,0,1,3,4,5,6,7,8,9,10,11,12,13,14,15,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,3,0,1,3,4,5,6,7,4,0,2,4,5,6,7,8,9,10,11,12,13,14,15,16,4,0,2,4,5,6,7,8,9,10,11,12,13,14,15,16,4,0,2,4,5,6,7,8,9,10,11,12,13,14,15,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,4,0,1,2,3,4,5,6,7,8,9,10,11,12,13,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,3,0,1,2,3,4,5,16,2,0,1,16,2,0,1,16,2,0,1,16,2,0,1,16,2,0,1,16,2,0,1,16,2,0,1,16,0,0,0,0,11,0,0,0,2,0,0,0,28,0,0,0,42,0,0,0,36,1,0,0,8,0,0,0,66,0,0,0,32,0,0,0,6,0,0,0,7,0,0,0,35,0,0,0,0,0,0,0,4,0,0,0,44,1,0,0,33,0,0,0,5,0,0,0,43,1,0,0,70,0,0,0,80,0,0,0,76,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,46,1,0,0,50,1,0,0,54,1,0,0,48,1,0,0,52,1,0,0,56,1,0,0,54,0,0,0,56,0,0,0,58,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,110,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,4,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,14,0,0,0,13,0,0,0,12,0,0,0,34,0,0,0,255,255,255,255,224,98,34,0,112,0,0,0,168,44,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,45,33,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,5,0,0,6,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,23,35,0,112,80,34,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,224,171,33,0,112,80,34,0,4,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,116,37,0,112,0,0,0,104,221,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,76,37,0,112,0,0,0,224,191,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,47,43,46,45,42,39,35,38,41,44,40,37,34,33,36,32,16,20,17,18,21,24,28,25,22,19,23,26,29,30,27,31,63,59,62,61,58,55,51,54,57,60,56,53,50,49,52,48,64,72,65,66,73,80,88,81,74,67,75,82,89,90,83,91,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,16,20,17,18,21,24,28,25,22,19,23,26,29,30,27,31,155,147,154,153,146,139,131,138,145,152,144,137,130,129,136,128,47,43,46,45,42,39,35,38,41,44,40,37,34,33,36,32,63,59,62,61,58,55,51,54,57,60,56,53,50,49,52,48,96,104,97,98,105,112,120,113,106,99,107,114,121,122,115,123,68,76,69,70,77,84,92,85,78,71,79,86,93,94,87,95,100,108,101,102,109,116,124,117,110,103,111,118,125,126,119,127,187,179,186,185,178,171,163,170,177,184,176,169,162,161,168,160,159,151,158,157,150,143,135,142,149,156,148,141,134,133,140,132,191,183,190,189,182,175,167,174,181,188,180,173,166,165,172,164,88,222,30,0,24,249,30,0,152,222,30,0,88,249,30,0,8,16,19,22,22,26,26,27,16,16,22,22,26,27,27,29,19,22,26,26,27,29,29,35,22,24,27,27,29,32,34,38,26,27,29,29,32,35,38,46,27,29,34,34,35,40,46,56,29,34,34,37,40,48,56,69,34,37,38,40,48,58,69,83,64,0,0,0,32,0,0,0,192,0,0,0,96,0,0,0,1,0,1,0,5,0,245,1,17,0,73,0,0,0,72,0,75,0,53,0,3,0,52,0,201,3,244,1,201,0,74,0,217,15,200,3,16,0,55,0,1,0,200,0,117,0,247,1,203,0,116,0,2,0,246,1,202,0,241,1,240,1,129,31,249,7,128,31,131,31,248,7,119,0,245,0,54,0,251,7,118,0,130,31,244,0,247,0,250,7,113,0,246,0,203,3,202,3,216,15,241,0,245,3,141,31,229,7,19,0,49,0,240,0,219,15,243,0,228,7,48,0,243,1,231,7,244,3,230,7,112,0,25,63,242,1,24,63,218,15,51,0,225,7,253,1,252,1,115,0,255,1,197,15,196,15,199,15,247,3,114,0,5,0,5,0,5,0,121,0,5,0,13,0,29,0,120,0,105,0,4,0,1,0,7,0,104,0,28,0,31,0,4,0,107,0,12,0,4,0,30,0,6,0,106,0,21,0,15,0,20,0,23,0,7,0,22,0,14,0,17,0,9,0,209,0,208,0,129,1,211,0,123,0,16,0,19,0,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2013344);
/* memory initializer */ allocate([210,0,7,0,25,3,8,0,122,0,221,0,25,0,6,0,11,0,101,0,220,0,18,0,100,0,128,1,223,0,6,0,24,0,1,0,222,0,29,0,217,0,27,0,103,0,10,0,216,0,219,0,28,0,24,3,218,0,53,6,131,1,0,0,197,0,102,0,97,0,53,0,196,0,130,1,52,6,27,3,199,0,31,0,5,0,1,0,29,0,193,1,53,0,241,0,109,0,240,0,73,0,0,0,4,0,3,0,243,0,72,0,52,0,108,0,192,1,195,1,7,0,6,0,1,0,111,0,2,0,75,0,110,0,28,0,5,0,105,0,104,0,107,0,55,0,194,1,242,0,149,3,205,1,253,0,106,0,54,0,21,0,204,1,20,0,148,3,74,0,252,0,255,0,23,0,49,0,254,0,207,1,151,3,249,0,206,1,37,7,150,3,22,0,48,0,117,0,36,7,248,0,39,7,51,0,145,3,144,3,17,0,50,0,31,0,251,0,116,0,38,7,250,0,30,0,119,0,25,0,24,0,4,0,16,0,61,0,118,0,113,0,19,0,1,0,13,0,25,0,17,0,21,0,97,0,25,0,20,0,173,1,96,0,24,0,1,0,5,0,27,0,16,0,25,0,5,0,23,0,24,0,22,0,4,0,4,0,19,0,12,0,18,0,26,0,24,0,5,0,15,0,27,0,4,0,29,0,17,0,28,0,16,0,14,0,27,0,19,0,31,0,26,0,41,0,5,0,99,0,30,0,9,0,98,0,8,0,7,0,7,0,25,0,4,0,26,0,24,0,109,0,7,0,27,0,7,0,26,0,108,0,6,0,18,0,5,0,111,0,11,0,110,0,105,0,29,0,89,3,40,0,43,0,42,0,28,0,213,0,88,3,31,0,1,0,30,0,104,0,212,0,215,0,25,0,0,0,185,0,97,0,96,0,184,0,181,2,173,1,187,0,245,10,81,1,1,0,1,0,5,0,0,0,3,0,5,0,4,0,99,0,37,0,186,0,4,0,7,0,98,0,165,0,36,0,109,0,2,0,108,0,180,2,13,0,111,0,39,0,164,0,38,0,172,1,80,1,175,1,174,1,33,0,110,0,183,2,32,0,83,1,35,0,167,0,82,1,166,0,6,0,12,0,34,0,169,1,25,0,45,0,182,2,168,1,15,0,7,0,14,0,161,0,105,0,44,0,1,0,171,1,160,0,177,2,163,0,47,0,244,10,176,2,247,10,179,2,104,0,93,1,246,10,170,1,85,0,92,1,178,2,121,5,120,5,95,1,162,0,5,9,61,1,60,1,4,9,29,18,157,4,156,4,61,36,7,9,237,0,1,0,21,0,65,0,63,1,49,0,20,0,93,2,92,2,62,1,13,0,0,0,64,0,57,1,67,0,48,0,23,0,51,0,6,9,50,0,66,0,236,0,95,2,239,0,94,2,159,4,56,1,1,9,59,1,89,2,28,18,158,4,0,9,88,2,60,36,31,18,3,9,61,0,238,0,91,2,90,2,77,0,58,1,2,9,69,2,233,0,22,0,232,0,153,4,37,1,68,2,76,0,152,4,13,9,235,0,60,0,17,0,155,4,154,4,133,4,234,0,63,0,36,1,12,9,62,0,57,0,149,0,71,2,70,2,132,4,148,0,56,0,9,15,205,0,253,1,145,7,109,30,144,7,217,3,209,60,208,60,117,0,1,0,1,0,53,0,204,0,17,0,0,0,216,3,252,1,219,3,16,0,3,0,207,0,218,3,206,0,116,0,52,0,119,0,147,7,19,0,118,0,113,0,197,3,112,0,255,1,146,7,254,1,249,1,55,0,201,0,8,15,248,1,196,3,200,0,11,15,157,7,199,3,1,0,18,0,115,0,203,0,5,0,54,0,198,3,114,0,125,0,2,0,202,0,156,7,251,1,245,0,49,0,159,7,10,15,53,15,158,7,250,1,108,30,111,30,211,60,153,7,193,3,110,30,210,60,48,0,244,0,124,0,192,3,195,3,152,7,229,1,247,0,165,1,1,0,29,0,33,0,161,0,13,0,97,0,185,6,160,0,96,0,1,0,5,0,12,0,32,0,28,0,4,0,164,1,167,1,163,0,31,0,30,0,35,0,34,0,45,0,44,0,99,0,98,0,129,26,166,1,161,1,184,6,187,6,162,0,186,6,89,13,165,6,160,1,15,0,109,0,164,6,47,0,173,0,108,0,167,6,172,0,88,13,14,0,163,1,175,0,174,0,111,0,162,1,91,13,169,0,25,0,1,0,9,0,168,0,110,0,46,0,0,0,173,1,171,0,170,0,85,3,41,0,128,26,131,26,130,26,84,3,172,1,90,13,141,26,175,1,87,3,69,13,68,13,71,13,140,26,166,6,161,6,1,0,17,0,5,0,117,7,249,0,248,0,49,0,48,0,73,0,251,0,16,0,51,0,201,14,141,3,140,3,250,0,143,3,116,7,72,0,50,0,0,0,213,1,229,0,142,3,228,0,19,0,13,0,137,3,119,7,136,3,139,3,249,29,200,14,201,59,248,29,138,3,181,3,118,7,231,0,200,59,212,1,203,59,203,14,113,7,202,14,215,1,180,3,214,1,251,29,245,14,112,7,244,14,202,59,115,7,230,0,183,3,75,0,250,29,182,3,247,14,225,0,246,14,241,14,177,3,209,1,61,0,240,14,114,7,125,7,124,7,60,0,208,1,176,3,211,1,63,0,179,3,210,1,243,14,127,7,224,0,74,0,21,0,73,0,20,0,209,7,253,3,252,3,193,1,192,1,241,0,23,0,1,0,1,0,195,1,72,0,75,0,22,0,49,0,194,1,74,0,17,0,0,0,205,1,240,0,204,1,117,0,16,0,13,0,255,3,207,1,206,1,208,7,129,15,211,7,29,31,128,15,210,7,201,1,254,3,116,0,221,7,243,0,28,31,220,7,249,3,223,7,242,0,253,0,119,0,222,7,217,7,200,1,216,7,131,15,248,3,48,0,118,0,19,0,130,15,252,0,251,3,51,0,250,3,229,3,228,3,203,1,50,0,31,31,231,3,219,7,218,7,61,0,202,1,197,7,230,3,113,0,141,15,196,7,30,31,140,15,225,3,245,1,25,0,101,0,24,0,81,3,80,3,83,3,33,0,32,0,100,0,29,0,5,0,5,0,165,1,35,0,103,0,5,0,102,0,34,0,27,0,4,0,1,0,4,0,28,0,97,0,26,0,5,0,4,0,7,0,45,0,6,0,44,0,164,1,47,0,82,3,93,3,96,0,1,0,46,0,31,0,92,3,0,0,177,6,167,1,41,0,166,1,40,0,99,0,98,0,95,3,161,1,43,0,176,6,179,6,160,1,3,0,109,0,30,0,94,3,108,0,178,6,2,0,163,1,162,1,13,0,5,0,7,0,173,1,111,0,42,0,110,0,4,0,4,0,12,0,7,0,6,0,15,0,14,0,213,0,9,0,6,0,7,0,101,0,129,1,100,0,201,54,213,6,181,13,121,3,128,1,131,1,213,0,29,0,28,0,180,13,130,1,120,3,212,0,215,0,212,6,103,0,31,0,1,0,214,0,209,0,141,1,102,0,1,0,0,0,123,3,215,6,122,3,183,13,200,54,214,6,182,13,121,27,177,13,140,1,101,3,208,0,120,27,211,0,123,27,100,3,209,6,208,6,143,1,142,1,210,0,203,54,103,3,102,3,211,6,176,13,210,6,97,3,221,6,137,1,202,54,96,3,245,54,136,1,179,13,244,54,9,0,8,0,5,0,220,6,221,0,139,1,220,0,4,0,11,0,138,1,97,0,3,0,99,3,223,0,223,6,98,3,10,0,30,0,29,0,97,0,13,0,85,13,185,6,184,6,165,1,33,0,32,0,35,0,12,0,96,0,84,13,173,0,172,0,34,0,175,0,187,6,15,0,28,0,1,0,45,0,99,0,164,1,14,0,1,0,5,0,167,1,186,6,166,1,165,6,87,13,86,13,189,26,81,13,174,0,44,0,169,0,47,0,80,13,161,1,188,26,164,6,167,6,166,6,168,0,161,6,160,1,191,26,83,13,160,6,82,13,190,26,163,6,98,0,46,0,9,0,93,13,163,1,92,13,109,0,171,0,162,6,108,0,31,0,1,0,173,6,41,0,162,1,40,0,4,0,30,0,173,1,111,0,0,0,172,1,175,1,172,6,170,0,110,0,25,0,25,0,125,0,24,0,181,1,13,0,180,1,124,0,127,0,183,1,12,0,27,0,26,0,182,1,15,0,213,0,25,0,126,0,212,0,24,0,27,0,1,0,14,0,17,0,9,0,5,0,5,0,5,0,215,0,177,1,8,0,176,1,121,0,253,6,113,3,112,3,214,0,120,0,179,1,16,0,115,3,19,0,252,6,123,0,122,0,209,0,208,0,211,0,101,0,114,3,255,6,100,0,254,6,125,3,210,0,221,0,103,0,4,0,124,3,18,0,178,1,7,0,102,0,189,1,6,0,97,0,4,0,188,1,26,0,96,0,29,0,4,0,28,0,99,0,1,0,7,0,11,0,0,0,98,0,10,0,5,0,7,0,105,0,69,0,104,0,189,4,85,2,188,4,229,0,228,0,49,0,48,0,25,0,1,0,33,1,231,0,230,0,51,0,225,0,224,0,107,0,24,0,1,0,68,0,50,0,71,0,106,0,27,0,5,0,61,0,70,0,21,0,65,0,32,1,35,1,191,4,34,1,64,0,60,0,227,0,20,0,84,2,67,0,117,9,45,1,226,0,237,0,66,0,236,0,77,0,87,2,86,2,81,2,190,4,116,9,80,2,239,0,238,0,76,0,185,4,44,1,184,4,79,0,187,4,83,2,63,0,23,0,1,0,82,2,233,0,232,0,235,0,0,0,3,0,22,0,2,0,4,0,78,0,62,0,234,0,73,0,13,0,7,0,13,0,189,1,12,0,49,13,48,13,51,13,89,3,88,3,45,0,101,0,29,0,28,0,50,13,91,3,90,3,44,0,188,1,69,3,15,0,31,0,1,0,47,0,100,0,191,1,103,0,1,0,5,0,102,0,46,0,97,0,41,0,149,6,148,6,151,6,150,6,96,0,190,1,61,13,40,0,73,26,68,3,72,26,75,26,60,13,145,6,43,0,185,1,42,0,63,13,144,6,71,3,62,13,74,26,70,3,213,0,65,3,99,0,57,13,64,3,56,13,184,1,59,13,58,13,212,0,98,0,0,0,147,6,187,1,67,3,66,3,30,0,14,0,109,0,9,0,1,0,108,0,215,0,77,3,186,1,8,0,4,0,117,0,205,0,53,0,193,3,192,3,249,7,195,3,141,31,204,0,116,0,17,0,16,0,194,3,217,15,241,1,207,0,205,3,206,0,52,0,1,0,1,0,55,0,201,0,200,0,54,0,0,0,1,0,216,15,204,3,203,0,240,1,248,7,207,3,251,7,250,7,202,0,243,1,206,3,245,0,219,15,244,0,229,7,228,7,231,7,242,1,230,7,201,3,253,1,218,15,140,31,225,7,143,31,142,31,200,3,203,3,119,0,118,0,197,15,202,3,224,7,247,0,196,15,245,3,246,0,252,1,3,0,244,3,113,0,247,3,241,0,19,0,49,0,48,0,112,0,5,0,18,0,115,0,255,1,114,0,125,0,2,0,97,0,85,0,96,0,201,2,200,2,203,2,113,1,181,0,84,0,1,0,1,0,1,0,87,0,1,0,99,0,29,0,98,0,57,0,109,0,0,0,5,0,56,0,86,0,180,0,108,0,3,0,28,0,111,0,59,0,2,0,58,0,112,1,183,0,115,1,81,0,110,0,37,0,80,0,105,0,202,2,36,0,39,0,114,1,182,0,177,0,13,0,12,0,31,0,125,1,38,0,104,0,83,0,124,1,107,0,30,0,15,0,4,0,127,1,106,0,245,2,25,0,33,0,82,0,244,2,247,2,32,0,205,11,229,5,228,5,204,11,35,0,176,0,246,2,179,0,34,0,241,2,240,2,207,11,206,11,126,1,93,0,189,0,37,0,161,1,89,1,153,2,188,0,36,0,5,5,4,5,160,1,1,0,29,0,109,0,28,0,1,0,5,0,39,0,163,1,88,1,31,0,30,0,162,1,38,0,33,0,13,0,32,0,35,0,152,2,108,0,34,0,191,0,190,0,173,1,45,0,155,2,185,0,172,1,184,0,175,1,154,2,111,0,91,1,110,0,133,2,132,2,174,1,25,0,44,0,169,1,168,1,12,0,15,0,90,1,187,0,14,0,0,0,105,0,171,1,24,0,170,1,4,0,85,0,186,0,7,5,69,1,84,0,6,5,165,0,1,5,164,0,87,0,0,5,5,10,68,1,167,0,135,2,134,2,3,5,71,1,4,10,70,1,89,7,65,0,229,0,189,3,157,14,45,1,44,1,29,58,188,3,47,1,13,0,64,0,228,0,191,3,67,0,66,0,88,7,190,3,231,0,1,0,0,0,61,0,230,0,21,0,20,0,23,0,60,0,61,116,46,1,185,3,184,3,156,14,187,3,91,7,28,58,159,14,41,1,225,0,40,1,158,14,43,1,90,7,224,0,153,14,69,7,31,58,186,3,68,7,152,14,13,29,165,3,155,14,60,116,154,14,42,1,77,0,227,0,133,14,213,1,132,14,76,0,71,7,12,29,212,1,63,0,22,0,70,7,164,3,65,7,79,0,62,0,215,1,64,7,12,0,17,0,78,0,226,0,237,0,236,0,73,0,72,0,1,5,4,10,6,8,5,8,8,7,5,7,11,10,9,8,13,11,6,7,3,9,8,10,9,8,5,10,9,10,10,14,12,14,14,12,8,9,7,12,8,14,9,9,12,8,9,11,11,13,9,11,14,12,6,7,9,13,9,12,7,10,12,11,12,8,15,10,15,13,7,12,10,10,8,10,13,13,13,11,8,4,6,5,11,8,10,7,11,9,4,1,4,9,7,7,5,9,10,6,7,4,9,9,10,9,9,6,9,10,9,10,12,12,13,12,11,9,9,8,12,8,14,10,11,12,7,8,10,11,12,9,11,13,12,6,7,8,12,9,12,7,11,10,12,12,9,14,12,15,13,8,12,11,11,10,12,13,15,14,12,9,5,7,6,12,9,11,8,11,10,7,5,7,11,10,9,8,12,12,5,5,1,8,7,10,8,6,4,8,8,8,9,12,11,13,12,11,8,9,8,12,8,13,10,11,11,8,9,11,12,13,11,12,14,13,8,9,10,14,11,14,9,13,13,8,9,6,11,10,14,11,6,10,6,6,4,8,9,10,10,8,5,11,7,8,10,12,9,10,14,12,7,1,5,7,8,6,4,10,9,10,5,4,8,11,8,7,6,7,11,6,7,8,10,8,10,11,9,10,8,9,13,9,12,8,11,12,11,4,7,8,9,6,8,12,9,8,5,8,12,9,10,6,12,11,12,12,10,15,13,13,13,10,13,15,10,9,10,12,13,13,10,9,11,8,8,11,13,10,11,15,12,7,1,4,7,7,5,4,8,9,11,5,5,8,11,9,8,7,8,13,7,8,9,11,9,10,12,10,10,9,8,13,9,12,9,11,12,11,5,7,9,10,6,9,13,10,7,4,7,11,8,9,5,10,11,13,11,9,15,13,15,13,8,12,15,10,10,12,13,14,14,12,11,12,9,9,12,13,11,11,14,12,8,2,5,7,9,6,5,10,10,9,4,2,7,9,7,6,5,6,12,6,7,8,10,8,10,11,9,12,9,10,13,11,12,10,14,13,12,6,8,10,10,7,9,12,10,8,5,8,11,9,10,7,11,12,8,6,5,11,11,11,8,6,9,12,6,6,8,10,10,11,8,6,13,9,10,12,14,12,11,15,15,8,1,5,7,9,6,5,11,10,11,6,5,9,11,9,8,7,8,12,6,8,8,11,8,10,12,10,10,7,9,13,10,11,9,13,12,11,3,6,8,9,4,7,11,8,8,5,9,12,10,9,7,12,13,13,12,10,14,14,15,12,11,14,15,7,9,8,11,11,12,10,9,10,5,6,9,11,7,8,12,11,8,1,4,7,9,6,4,10,10,11,6,6,9,9,9,9,8,8,14,10,10,12,12,11,12,13,12,10,7,8,12,9,11,8,12,11,13,7,10,11,11,8,10,13,11,6,3,7,11,8,9,5,10,11,11,11,9,14,14,14,11,10,13,14,10,11,13,13,13,14,12,12,2,5,3,11,8,8,6,6,7,8,5,6,12,10,10,8,10,11,7,6,2,9,8,10,8,5,4,10,11,10,10,13,12,14,13,10,10,11,8,14,9,14,12,11,12,9,10,9,13,12,11,12,14,11,8,10,7,13,10,12,8,12,12,10,9,6,12,11,11,11,6,9,10,9,6,10,9,12,11,8,7,6,8,6,12,11,11,10,10,9,6,1,3,10,8,8,6,7,10,8,6,3,10,9,10,8,6,5,11,10,10,12,13,12,14,13,12,10,11,8,12,9,14,12,11,12,9,9,8,12,12,10,12,13,11,7,8,6,13,9,11,7,11,11,11,10,7,14,11,12,12,7,10,12,11,8,13,12,14,13,11,10,7,10,7,13,13,13,11,11,10,8,5,6,12,11,10,9,10,11,7,5,1,9,8,10,7,4,4,9,11,9,11,12,11,13,13,10,9,11,8,13,9,14,12,11,12,11,10,10,13,12,11,14,14,12,9,10,8,13,10,14,9,12,12,9,7,4,12,10,11,10,6,7,9,7,4,9,9,11,9,7,5,7,9,7,14,11,12,10,9,9,8,5,5,12,9,10,8,8,11,7,5,2,8,8,9,7,4,4,10,11,10,12,14,11,12,13,12,9,10,8,13,8,13,10,11,11,9,9,8,14,10,10,11,12,11,10,11,9,14,10,14,9,12,14,6,6,3,11,8,9,8,3,6,9,7,4,10,8,11,10,6,5,6,8,7,13,12,12,10,9,9,9,7,8,13,11,11,9,11,12,7,6,1,9,8,10,7,5,4,10,12,10,12,13,13,14,13,11,9,11,9,13,10,14,12,12,12,11,12,10,14,13,12,13,14,12,8,9,7,13,10,13,8,11,12,8,6,3,12,9,10,9,4,6,10,8,5,10,10,12,11,8,6,7,10,7,12,9,12,10,10,12,9,7,7,12,9,11,6,10,11,6,6,1,9,8,9,7,4,5,11,12,9,12,10,14,13,13,11,10,12,8,13,8,14,10,10,11,11,11,10,13,14,10,14,13,11,11,10,7,13,8,12,7,10,12,7,10,4,12,6,10,8,5,8,10,7,4,9,7,10,9,6,5,7,9,7,13,12,13,10,10,8,8,5,6,11,10,10,8,10,10,7,5,2,9,8,9,7,5,3,8,9,7,9,11,11,13,11,9,8,10,7,12,9,14,11,10,10,9,10,9,12,12,12,13,14,12,10,10,9,13,11,13,9,13,12,8,7,4,12,10,10,10,6,6,7,6,3,9,8,10,9,6,3,7,10,7,13,13,13,11,11,9,8,6,6,13,11,11,9,10,11,7,6,1,9,8,10,8,5,4,8,9,8,9,12,12,12,12,8,10,13,9,14,11,14,14,13,12,9,10,9,13,12,11,13,14,11,9,11,8,13,11,13,10,13,13,9,8,5,12,10,11,11,6,7,8,7,3,8,9,11,10,7,4,8,9,7,11,11,12,11,14,9,8,6,6,11,13,10,9,11,9,7,5,1,7,9,9,7,5,3,13,11,9,10,12,11,12,12,9,10,11,9,13,9,12,12,12,10,12,11,10,13,14,12,14,14,11,11,8,8,13,11,12,9,13,11,9,10,5,11,8,11,9,6,7,7,8,4,6,8,10,8,8,5,8,10,8,13,13,13,12,11,10,5,1,3,10,7,8,6,8,9,8,7,4,9,10,11,8,7,6,8,9,7,9,12,11,12,10,8,9,10,8,13,9,9,12,11,11,7,7,6,12,9,8,10,12,8,6,7,4,12,8,13,6,9,10,13,13,9,15,14,14,15,9,11,13,11,9,13,13,15,15,12,10,10,8,9,11,12,10,8,13,13,9,2,5,7,5,4,3,8,9,11,5,5,9,8,8,6,8,8,12,7,8,10,10,9,8,12,10,9,10,9,12,7,11,7,12,12,9,5,8,9,9,6,6,11,10,6,4,7,9,5,9,3,9,10,13,11,9,13,10,13,10,9,13,14,11,10,12,12,13,11,14,11,11,7,8,10,12,9,9,14,10,9,4,7,8,10,7,7,11,10,8,2,2,6,8,5,5,5,6,15,9,10,10,12,10,11,14,12,9,8,9,12,9,11,8,12,11,14,10,11,12,13,10,12,15,12,9,7,8,12,9,12,7,11,13,9,6,5,11,10,11,7,6,9,11,4,5,7,8,8,8,7,7,0,0,0,0,1,1,1,17,0,9,3,16,5,9,1,1,5,17,0,3,33,32,1,1,1,17,9,16,5,0,3,1,1,0,3,33,5,9,32,17,1,9,0,41,8,21,3,11,40,1,1,1,1,0,1,1,3,2,1,1,1,5,0,3,1,9,8,1,1,1,9,1,8,0,3,5,1,1,1,0,5,17,9,16,3,0,0,0,0,0,0,0,0,0,1,1,1,5,1,0,3,9,8,9,1,1,5,17,0,3,33,32,1,1,1,13,5,4,0,7,12,1,1,0,5,17,3,9,33,32,5,1,1,17,0,9,3,33,32,9,1,1,0,5,1,3,17,16,1,1,1,0,1,1,1,3,2,1,1,1,9,0,5,1,3,8,1,1,1,9,17,5,0,16,3,1,0,0,0,0,0,0,0,0,1,0,1,9,8,21,20,11,3,13,1,1,5,12,4,1,0,7,1,1,1,5,0,4,3,1,1,5,1,1,4,25,7,24,13,0,17,9,1,33,5,32,1,0,3,65,1,0,5,64,3,9,33,17,41,1,0,40,9,21,3,8,11,1,0,1,17,9,16,5,1,3,5,1,1,4,13,12,7,0,1,0,0,0,0,0,0,0,0,0,1,0,3,5,17,16,37,36,19,33,1,1,0,17,3,5,32,9,1,1,1,0,9,17,16,5,3,33,5,1,1,9,0,17,32,3,5,1,0,4,1,25,7,24,13,17,1,0,1,9,1,3,16,5,29,1,5,13,12,4,0,28,15,5,25,1,4,0,24,27,26,7,9,1,0,1,5,3,17,16,1,0,0,0,0,0,0,0,0,0,1,0,3,65,5,64,9,17,33,5,1,1,25,4,7,0,24,13,1,1,1,5,1,4,1,0,3,1,5,0,13,1,4,7,25,24,1,1,1,1,1,0,1,3,2,49,1,5,25,4,7,0,48,13,1,0,3,17,1,5,1,9,16,1,5,1,17,1,16,0,3,9,1,9,0,41,3,8,40,21,11,0,0,0,0,0,0,0,0,0,1,1,0,9,21,3,8,20,11,17,1,1,0,9,1,3,16,5,1,0,3,37,17,5,16,36,19,17,1,0,1,9,1,5,16,3,5,1,0,13,12,4,15,29,28,1,1,1,1,0,1,1,3,2,33,1,5,9,17,0,3,65,64,5,1,0,29,28,13,12,15,4,5,1,0,13,49,4,25,48,7,0,0,0,0,0,0,0,0,0,1,1,0,33,5,17,3,9,32,1,1,0,17,3,5,1,9,16,1,1,1,1,1,0,1,3,2,5,1,4,25,7,13,0,49,48,1,1,1,1,1,0,1,3,2,5,1,1,17,9,0,3,33,32,1,1,1,1,1,0,1,3,2,1,1,1,0,1,3,1,1,2,9,1,0,41,8,21,3,40,11,0,0,0,0,0,0,0,0,0,1,1,1,5,1,4,0,1,3,9,1,0,41,40,21,8,3,11,1,0,1,17,5,16,9,1,3,5,4,1,29,13,12,28,0,15,9,17,1,65,0,64,5,3,33,13,5,1,29,28,12,4,0,15,65,9,1,64,0,17,5,3,33,1,1,1,5,1,4,0,1,3,5,4,1,13,1,12,7,1,0,0,0,0,0,0,0,0,0,0,5,4,1,7,25,49,48,13,0,33,1,1,0,17,9,32,5,3,5,1,1,4,7,13,12,0,1,33,9,1,0,32,5,35,34,3,49,13,1,25,5,48,4,7,0,49,5,1,4,25,0,13,48,7,49,1,0,13,5,25,4,48,7,1,1,1,0,1,3,2,1,1,1,0,1,1,5,9,8,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,2,7,4,6,4,7,5,5,1,3,4,6,3,3,7,7,1,4,2,7,6,7,5,4,4,1,3,3,3,7,4,5,7,6,2,4,2,6,4,5,2,4,6,7,2,3,4,7,1,5,7,7,5,1,3,6,5,5,2,7,7,2,5,1,7,3,7,5,5,6,2,4,1,4,5,7,6,7,4,0,0,0,0,0,0,0,0,0,2,1,3,6,5,5,5,7,7,5,1,3,4,6,3,3,7,7,4,1,2,6,5,5,4,5,6,3,1,3,4,6,3,5,7,7,4,1,3,6,3,5,3,7,7,6,1,4,4,5,2,4,7,7,7,1,5,7,4,3,2,7,7,5,3,2,7,5,6,1,5,7,4,1,2,6,7,5,4,7,4,1,0,1,0,0,0,0,0,0,3,3,1,5,5,6,6,5,3,6,2,1,5,6,5,4,4,5,6,4,1,7,6,7,6,3,2,4,3,1,4,6,4,6,5,3,6,5,1,7,4,7,3,3,3,7,2,2,3,7,2,4,6,5,6,2,2,6,4,5,2,4,4,4,4,1,7,6,7,5,2,4,5,4,1,5,6,6,5,4,2,0,0,0,0,0,0,0,0,0,2,2,2,3,5,5,6,6,5,7,1,3,3,6,3,4,7,5,2,4,1,4,6,7,7,5,4,7,4,3,1,5,3,6,7,3,4,3,3,4,1,6,4,6,5,7,4,4,2,6,1,4,7,5,5,2,3,4,4,3,2,5,4,3,5,2,3,2,5,5,5,3,6,4,4,2,5,4,7,7,1,0,0,0,0,0,0,0,0,0,2,2,2,7,3,7,4,5,6,4,1,3,6,4,4,3,6,5,2,4,1,7,3,7,6,6,6,3,4,3,5,1,4,4,6,6,4,5,2,7,1,7,3,7,7,6,2,3,5,3,3,2,6,4,4,4,4,7,2,5,1,6,7,4,5,2,7,1,7,4,4,6,2,4,2,6,2,4,6,5,4,0,0,0,0,0,0,0,0,0,1,3,3,5,6,3,5,6,5,7,1,4,4,6,2,4,7,5,2,2,2,6,5,3,5,6,5,7,4,4,2,6,1,5,7,4,3,2,2,4,4,3,4,5,5,7,2,5,3,7,1,4,7,7,6,2,3,4,5,2,2,7,7,3,2,2,5,5,4,4,4,3,3,2,2,4,6,3,5,6,3,0,0,0,0,0,0,0,0,0,1,3,3,7,4,6,3,5,7,4,1,4,7,4,5,2,6,7,2,4,1,7,5,7,3,7,7,3,2,3,5,3,4,2,6,6,3,5,4,7,2,7,1,7,7,4,1,3,6,5,3,3,7,7,4,2,5,7,3,7,1,7,7,7,4,1,7,3,7,2,5,7,4,2,2,6,4,5,2,6,4,0,0,0,0,0,0,0,0,0,3,4,1,7,6,7,6,2,6,4,2,2,6,6,5,4,2,4,4,4,1,7,5,7,6,2,4,3,3,2,5,4,4,5,2,4,4,5,2,7,2,7,3,2,6,4,3,2,5,5,4,3,2,4,7,4,2,7,2,5,3,2,6,4,6,2,7,3,7,6,1,6,5,5,1,6,4,6,5,2,4,0,0,0,0,0,0,0,0,0,3,3,2,3,5,6,6,4,2,7,1,3,3,6,5,7,4,3,5,4,1,5,5,6,6,4,2,6,4,2,2,6,3,6,6,2,6,4,2,5,3,6,3,3,2,6,3,2,3,5,2,4,6,3,6,2,2,4,3,5,3,6,3,7,5,1,7,4,7,7,3,2,5,5,2,3,6,7,7,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,31,27,30,29,26,23,19,22,25,28,24,21,18,17,20,16,32,36,33,34,37,40,44,41,38,35,39,42,45,46,43,47,63,59,62,61,58,55,51,54,57,60,56,53,50,49,52,48,16,24,17,18,25,32,40,33,26,19,27,34,41,42,35,43,0,4,1,2,5,8,12,9,6,3,7,10,13,14,11,15,20,28,21,22,29,36,44,37,30,23,31,38,45,46,39,47,95,87,94,93,86,79,71,78,85,92,84,77,70,69,76,68,63,59,62,61,58,55,51,54,57,60,56,53,50,49,52,48,91,83,90,89,82,75,67,74,81,88,80,73,66,65,72,64,112,120,113,114,121,128,136,129,122,115,123,130,137,138,131,139,96,100,97,98,101,104,108,105,102,99,103,106,109,110,107,111,116,124,117,118,125,132,140,133,126,119,127,134,141,142,135,143,191,183,190,189,182,175,167,174,181,188,180,173,166,165,172,164,159,155,158,157,154,151,147,150,153,156,152,149,146,145,148,144,187,179,186,185,178,171,163,170,177,184,176,169,162,161,168,160,56,57,32,0,200,31,40,0,16,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,192,190,39,0,96,90,39,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,176,13,39,0,200,201,38,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,143,34,0,112,0,0,0,24,250,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,213,36,0,184,164,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,48,213,36,0,48,197,34,0,184,164,35,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,48,213,36,0,104,4,34,0,192,112,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,48,213,36,0,80,248,32,0,64,149,32,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,48,213,36,0,184,57,32,0,72,32,40,0,16,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,240,190,39,0,72,32,40,0,16,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,208,90,39,0,232,13,39,0,12,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,96,202,38,0,232,13,39,0,12,0,0,0,1,0,0,0,68,172,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,184,134,38,0,128,75,38,0,32,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,216,20,38,0,128,75,38,0,32,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,240,234,37,0,216,189,37,0,24,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,72,157,37,0,216,189,37,0,24,0,0,0,32,82,85,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,120,107,37,0,232,43,37,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,64,8,0,1,0,120,107,37,0,80,5,37,0,232,43,37,0,8,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,64,8,0,1,0,120,107,37,0,56,219,36,0,192,187,36,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,200,158,36,0,88,131,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,232,104,36,0,32,77,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,232,53,36,0,104,14,36,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,232,217,35,0,224,191,35,0,0,0,0,0,128,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,0,169,35,0,184,146,35,0,0,0,0,0,128,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,216,124,35,0,16,102,35,0,0,0,0,0,128,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,216,83,35,0,160,66,35,0,0,0,0,0,128,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,88,49,35,0,216,16,35,0,0,0,0,0,128,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,200,232,34,0,192,214,34,0,0,0,0,0,128,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,120,107,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,148,34,0,112,0,0,0,8,251,30,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,58,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,2,0,0,12,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,198,34,0,184,5,34,0,52,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,128,44,37,0,192,5,37,0,56,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,96,203,38,0,192,5,37,0,56,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,96,219,36,0,0,188,36,0,4,0,0,0,5,0,0,0,208,158,36,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,8,0,1,0,0,0,0,0,64,235,37,0,0,188,36,0,4,0,0,0,5,0,0,0,208,158,36,0,0,0,0,0,0,0,0,0,0,0,96,192,0,0,0,0,0,192,95,64,8,0,1,0,0,0,0,0,112,131,36,0,240,104,36,0,64,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,64,77,36,0,240,104,36,0,64,0,0,0,32,82,85,68,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,224,67,8,0,1,0,0,0,0,0,136,113,33,0,216,248,32,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,224,149,32,0,216,248,32,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,167,34,0,112,0,0,0,96,0,31,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,255,255,255,255,128,58,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,198,34,0,184,5,34,0,52,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,136,113,33,0,216,248,32,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,224,149,32,0,216,248,32,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,58,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,190,37,0,0,0,0,0,14,0,0,0,0,0,0,0,176,215,36,0,112,0,0,0,240,2,31,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,157,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,4,0,0,154,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,32,40,0,32,191,39,0,4,0,0,0,4,0,0,0,51,51,51,51,51,51,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,48,91,39,0,24,14,39,0,8,0,0,0,4,0,0,0,51,51,51,51,51,51,211,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,8,0,1,0,0,0,0,0,24,203,38,0,208,134,38,0,12,0,0,0,5,0,0,0,160,75,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,224,20,38,0,0,235,37,0,16,0,0,0,5,0,0,0,240,189,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,157,37,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,157,34,0,112,0,0,0,224,4,31,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,83,40,0,112,0,0,0,112,192,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,38,198,245,187,251,17,251,69,43,196,244,45,249,204,254,7,41,198,251,110,250,113,251,121,36,157,246,41,250,18,1,202,41,31,246,236,253,158,251,128,40,122,240,16,251,18,253,86,39,173,241,90,1,95,3,38,40,235,243,55,1,192,253,166,38,206,250,108,250,164,252,48,41,125,248,222,251,53,252,244,42,160,249,183,252,132,250,56,46,119,242,122,6,58,248,100,42,80,253,158,245,13,254,50,41,43,249,109,255,59,249,49,42,20,252,60,253,83,250,92,41,71,254,191,247,72,252,157,39,253,242,186,253,104,250,136,37,226,245,127,1,2,1,158,44,63,243,229,0,248,249,220,40,198,250,55,253,224,249,66,40,71,249,132,249,165,253,108,37,236,248,45,251,219,251,207,44,19,247,175,249,161,253,97,39,79,247,128,250,156,252,219,41,192,245,169,250,64,253,120,41,177,248,46,245,221,255,136,36,220,246,0,252,226,249,57,43,78,250,122,248,33,253,70,44,248,247,239,251,136,251,97,38,0,248,230,252,0,250,74,46,121,245,157,251,157,252,158,41,78,247,157,248,139,254,40,39,235,249,216,252,211,251,134,43,14,251,90,243,128,0,209,45,46,243,254,253,13,252,138,44,210,247,225,246,67,255,211,39,182,241,181,0,173,248,167,44,190,245,108,254,159,250,249,42,228,240,149,253,203,251,142,42,1,246,18,1,34,249,161,37,54,250,51,247,251,252,237,43,7,243,62,3,76,248,40,38,115,245,57,255,189,248,4,41,6,248,13,2,5,248,149,45,27,240,37,1,68,250,232,35,57,248,185,253,195,255,73,39,108,243,33,248,39,254,25,37,245,246,70,246,45,254,215,40,3,244,86,251,17,252,10,39,112,248,196,255,55,251,79,36,148,247,31,249,146,251,101,39,92,241,254,251,197,0,118,36,200,246,36,3,161,254,41,45,7,246,72,5,247,246,37,50,98,240,171,4,90,248,130,39,180,251,146,246,118,254,125,36,30,246,59,1,243,2,147,39,164,243,131,5,94,253,63,37,119,252,241,249,67,2,197,45,17,250,21,244,91,0,96,38,161,244,41,245,192,0,190,37,138,244,207,253,170,5,77,43,192,242,238,250,109,253,251,34,202,247,149,248,191,2], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2023584);
/* memory initializer */ allocate([159,33,50,249,4,239,46,3,216,29,241,247,223,241,52,0,162,27,198,252,27,239,23,17,34,30,72,2,114,239,135,7,211,24,72,252,208,236,55,12,157,27,108,253,243,230,247,15,121,32,124,255,108,244,148,252,40,27,114,250,134,240,232,255,83,36,34,253,240,243,249,254,12,37,194,253,95,238,210,1,78,28,165,255,105,241,64,253,133,32,119,250,238,243,238,253,69,25,54,251,107,237,61,3,252,25,144,254,206,233,113,5,35,31,2,251,20,247,181,4,61,28,69,253,28,242,48,7,58,31,4,5,87,245,220,2,45,35,70,253,86,238,141,8,51,27,197,0,89,245,124,1,79,33,135,0,105,240,43,255,136,34,166,3,58,244,201,253,141,39,162,1,44,243,141,254,223,24,105,1,242,246,250,9,212,30,172,0,129,235,65,18,18,26,131,1,208,234,46,17,96,24,172,2,49,240,195,4,162,43,230,252,39,236,171,4,245,45,120,253,135,231,4,8,93,42,249,252,3,241,110,1,208,48,79,253,188,223,234,13,213,30,114,251,148,236,220,3,144,33,28,4,158,232,15,12,109,28,82,7,203,233,251,13,244,26,224,7,55,237,163,13,82,33,155,246,78,243,194,7,210,36,238,1,101,228,174,19,45,40,52,2,238,223,250,20,45,34,97,247,116,240,36,11,181,37,130,245,52,239,120,5,42,38,18,247,225,233,137,16,42,33,252,255,120,228,144,17,17,30,71,251,48,235,111,12,51,25,33,3,28,239,214,253,219,28,14,7,111,235,33,2,26,29,2,247,163,238,138,5,113,34,166,250,61,233,120,8,84,40,154,246,3,234,19,10,159,34,238,245,47,242,211,1,245,26,168,249,159,243,64,13,166,30,156,0,220,228,53,13,248,30,165,251,172,232,208,18,201,23,169,253,240,238,192,254,153,30,222,4,136,240,147,253,227,34,217,9,144,229,4,8,196,34,152,7,226,239,40,0,237,29,222,255,217,244,176,9,241,22,218,1,66,243,128,14,111,29,22,255,165,237,216,0,224,22,143,0,234,235,73,0,240,34,150,255,14,233,79,14,222,27,170,1,9,233,79,11,215,39,243,3,102,237,113,1,6,33,8,1,173,232,11,5,142,30,111,246,19,239,188,17,56,24,58,245,184,245,217,5,182,23,37,239,117,245,158,1,135,27,101,241,118,243,36,4,43,22,39,241,99,245,105,254,181,18,33,240,188,245,24,253,183,15,218,242,195,243,42,253,200,16,153,246,203,242,255,253,36,17,141,244,252,244,232,5,207,17,119,239,107,248,184,7,46,26,120,243,37,249,144,6,64,17,63,242,228,251,168,11,242,27,86,239,77,251,148,14,41,14,110,239,84,243,115,5,118,25,216,244,232,250,71,11,26,24,99,248,58,244,133,15,69,20,109,246,76,240,149,13,74,24,84,244,127,248,4,15,219,18,152,241,120,248,15,13,12,26,105,240,11,245,23,12,177,20,213,243,156,241,86,9,234,20,250,237,154,245,224,5,100,16,237,243,205,239,111,4,212,13,179,244,89,240,100,0,193,21,190,249,89,240,117,7,245,16,213,247,80,239,252,0,183,21,194,244,8,241,242,1,196,17,129,238,174,244,229,255,56,20,66,246,229,237,196,5,222,12,99,242,102,241,204,2,56,19,51,251,157,239,147,254,185,12,66,242,235,242,46,11,166,20,100,248,99,242,246,252,102,25,21,244,104,255,38,11,232,22,160,239,204,251,123,13,48,18,206,243,136,242,179,0,19,23,14,253,196,249,44,12,61,28,160,241,202,249,76,11,243,19,208,240,220,242,38,3,108,26,181,245,134,242,134,0,138,20,245,244,228,244,228,251,166,22,67,249,47,239,205,0,28,21,67,251,222,242,193,1,80,24,78,245,26,244,187,253,127,16,122,246,91,245,161,14,143,18,173,242,181,247,116,0,28,15,72,244,142,240,249,8,163,26,173,244,75,239,9,11,111,16,110,237,8,245,97,3,196,18,42,250,51,248,80,18,162,20,91,247,220,253,231,13,204,21,136,248,202,253,18,17,24,24,215,244,96,253,213,15,183,25,93,238,222,244,134,6,111,25,235,243,108,240,141,5,38,18,2,249,93,250,66,14,27,23,100,252,28,248,128,3,134,30,171,239,176,243,215,7,46,24,66,247,47,237,231,8,129,18,62,240,40,243,43,7,225,31,207,241,161,242,65,12,247,28,209,246,216,247,194,16,10,16,43,246,194,255,89,11,45,19,183,243,154,253,16,16,74,19,47,243,115,254,76,4,83,255,151,3,53,6,13,235,243,255,28,3,217,254,1,230,188,248,195,252,117,4,53,238,250,8,186,252,104,253,115,236,140,252,183,251,26,8,251,237,155,255,25,1,30,11,73,238,142,4,197,1,125,9,234,232,111,3,104,253,66,9,180,234,135,5,142,254,93,249,137,237,123,250,253,4,99,253,7,230,85,8,48,1,56,252,240,237,124,1,74,2,217,247,228,236,56,5,19,1,174,255,99,233,101,246,33,4,222,255,216,234,230,8,34,249,98,3,235,233,153,7,9,247,107,255,74,235,7,5,59,242,228,3,121,235,249,8,35,3,153,4,77,232,187,0,76,255,149,253,198,231,231,252,23,246,18,6,63,236,113,245,52,255,139,253,35,233,17,252,110,255,57,1,50,234,62,3,101,1,101,3,37,231,28,255,193,253,151,243,175,238,23,252,239,249,114,255,180,233,148,249,147,6,185,6,75,238,125,3,132,7,241,255,97,233,147,8,13,8,250,254,161,234,215,11,14,1,55,1,24,236,120,7,102,6,13,250,187,237,186,243,201,255,253,0,206,236,100,1,112,249,87,1,21,232,63,247,58,249,48,252,205,232,108,247,179,244,35,2,182,236,35,251,126,0,132,248,213,234,7,255,85,241,114,250,38,234,63,2,133,245,122,248,42,238,6,253,93,7,192,0,8,233,213,252,254,245,212,251,131,232,40,247,242,243,48,252,89,237,70,0,65,251,64,11,198,238,202,2,80,241,100,11,173,237,12,255,180,242,204,6,115,238,172,2,239,235,184,254,24,234,239,253,15,241,6,249,73,238,55,253,121,237,162,251,86,234,158,10,52,241,6,7,180,233,153,249,161,241,228,249,49,232,157,6,174,245,147,250,69,238,249,1,219,249,141,249,242,236,189,252,48,247,107,248,24,235,184,5,101,254,201,7,215,230,237,1,144,243,111,255,252,231,123,250,243,1,175,249,177,230,218,254,186,6,117,250,163,233,135,244,8,250,81,255,240,237,174,253,233,232,200,255,254,231,212,254,77,239,132,4,197,232,40,2,173,245,109,10,137,240,137,3,194,239,253,6,79,233,56,5,39,248,60,8,241,232,19,6,240,241,86,4,153,229,242,250,120,242,77,0,60,232,141,251,90,240,10,251,171,239,26,236,32,243,68,4,225,244,129,234,189,244,192,7,237,247,193,237,134,239,119,250,220,239,77,241,22,241,238,4,246,243,244,235,154,242,112,11,40,253,187,232,195,244,227,4,114,246,183,238,241,246,44,255,76,239,199,231,55,248,238,6,122,247,132,234,4,241,153,8,140,250,234,228,226,246,62,9,243,250,20,232,212,239,57,5,71,248,103,230,166,239,220,6,211,250,250,235,22,251,232,2,184,241,209,235,146,250,45,6,177,244,83,238,186,242,125,9,183,248,20,240,145,243,235,7,50,246,209,231,54,243,46,7,234,248,154,238,63,245,163,10,95,251,1,230,67,237,251,0,221,245,68,231,72,247,40,7,217,0,19,233,94,249,134,0,84,1,42,230,235,251,78,8,116,248,5,237,197,247,218,7,125,246,126,231,170,249,248,10,162,250,209,243,119,243,9,2,108,240,212,233,222,247,92,254,105,245,95,228,217,241,184,2,217,246,158,232,128,239,60,2,106,246,12,239,87,238,114,3,45,245,222,231,115,248,23,2,92,250,197,236,189,239,208,6,238,247,246,230,17,250,34,4,133,245,43,236,95,251,88,3,88,247,77,228,116,246,175,2,219,245,92,235,139,247,167,12,31,252,101,237,39,250,197,0,149,243,224,239,162,236,116,254,6,242,66,236,218,240,121,253,144,245,163,228,236,242,143,6,213,249,121,233,7,252,22,10,133,248,99,228,29,245,51,5,234,247,100,234,8,247,194,2,122,244,61,236,41,242,203,252,203,241,17,230,213,248,248,3,72,253,21,234,156,235,74,253,213,242,150,232,13,245,117,11,39,253,196,232,149,253,60,6,140,245,146,234,189,238,153,0,63,243,23,239,144,242,110,6,97,250,13,240,118,240,177,0,15,242,63,239,217,245,200,4,253,243,181,233,75,243,120,7,9,253,50,230,147,242,2,10,197,253,122,235,116,246,1,3,160,254,111,230,174,243,70,2,177,251,48,235,63,247,6,10,17,249,208,227,112,248,2,6,65,248,110,241,109,246,170,1,227,240,10,236,151,250,239,7,111,251,186,230,101,245,13,1,205,243,82,233,80,246,159,255,8,241,157,241,204,236,22,254,22,239,59,231,221,247,99,253,141,255,207,236,17,240,187,252,191,237,54,243,63,246,30,9,164,245,250,250,61,249,246,9,84,241,209,242,147,252,158,3,119,240,35,246,225,247,63,11,191,245,68,235,8,254,39,12,185,249,216,236,204,1,253,15,48,251,55,248,80,6,48,18,135,248,103,242,104,251,47,12,68,247,220,239,34,250,35,9,15,246,18,246,127,4,241,13,10,246,227,238,174,1,75,12,222,247,208,240,99,3,59,15,135,249,211,244,10,5,106,16,69,248,203,240,3,255,59,9,52,245,87,249,176,2,243,14,149,244,81,247,8,9,116,14,180,243,62,248,48,253,157,19,229,252,151,243,242,0,160,7,232,242,194,248,229,5,224,9,25,241,155,243,97,0,155,19,62,253,127,245,111,255,95,5,181,240,26,237,127,254,184,9,133,246,51,238,157,254,67,6,12,244,62,242,40,7,220,12,142,245,71,241,12,3,74,9,112,245,29,239,116,248,86,13,111,251,76,245,134,4,169,10,55,243,193,241,210,0,184,5,180,244,218,246,207,247,233,5,113,241,186,238,38,251,58,12,215,248,228,250,241,251,194,16,173,248,38,249,25,246,226,12,246,246,250,239,70,255,197,15,186,251,16,252,34,6,218,12,171,0,6,243,195,245,231,10,0,250,21,246,219,245,114,13,120,249,173,242,33,248,86,14,106,251,207,247,218,2,205,21,137,250,26,250,182,255,212,18,44,248,10,240,156,252,73,17,253,252,68,252,38,252,56,14,147,244,217,247,30,251,136,13,102,246,20,243,149,246,54,5,173,241,40,247,123,254,164,15,194,248,88,253,239,0,218,15,196,242,179,250,30,0,177,11,182,241,239,241,216,253,153,4,144,251,175,245,186,1,22,17,167,249,35,246,2,3,104,6,201,240,156,243,133,252,53,15,184,249,76,244,13,0,205,12,146,246,125,252,31,4,118,17,59,246,90,254,184,253,147,13,53,241,70,248,175,253,6,10,169,242,178,243,0,251,58,9,25,244,248,241,224,0,2,4,164,240,24,237,91,251,49,14,145,252,144,240,49,247,100,11,222,248,97,249,28,0,18,7,163,254,23,253,76,246,236,12,35,243,8,252,27,6,245,20,225,248,132,247,5,249,170,16,249,250,39,251,97,248,142,15,147,246,39,248,177,245,26,9,104,242,241,19,174,249,228,245,33,248,97,25,13,250,110,243,114,252,126,25,255,246,19,248,2,249,169,20,157,255,148,242,112,254,149,22,169,249,215,249,199,245,139,20,98,253,203,243,92,249,199,24,24,251,181,254,106,243,31,31,90,253,109,247,74,250,231,23,73,253,84,244,254,249,220,23,238,1,225,242,244,249,203,19,201,3,232,246,109,245,171,29,77,254,39,250,248,247,17,27,49,253,140,246,127,249,70,20,72,2,90,244,201,247,218,23,68,254,125,250,77,245,208,21,33,1,244,248,13,245,156,20,227,0,100,251,223,242,120,29,11,250,214,248,67,249,98,23,66,250,210,245,91,249,232,19,3,253,80,249,66,244,47,21,107,255,163,240,123,251,227,29,26,0,115,246,29,250,137,18,48,254,57,249,198,246,232,20,13,252,186,251,49,248,156,24,96,253,226,253,98,248,19,26,4,252,218,250,221,251,50,28,12,248,165,253,98,246,75,30,22,250,130,246,51,251,177,19,193,1,224,251,155,246,54,26,27,247,192,250,20,247,168,26,189,250,50,247,251,0,180,23,191,248,41,252,220,250,227,21,127,247,86,245,59,250,206,22,221,251,236,241,54,252,212,19,235,252,177,254,147,246,47,24,158,249,48,248,175,247,228,19,244,250,17,246,246,251,185,20,179,1,82,249,198,248,252,23,49,2,128,247,180,246,96,26,92,1,64,246,158,248,5,25,17,1,182,251,38,245,30,27,196,250,16,254,155,250,118,20,81,253,106,246,211,246,47,27,142,252,215,248,243,247,148,24,3,255,179,247,105,247,206,22,194,253,9,253,113,243,42,27,52,250,128,253,45,245,74,29,86,249,70,251,150,247,116,26,21,252,45,251,28,246,126,23,228,0,150,247,172,251,31,27,126,247,172,245,158,251,94,28,5,253,16,244,190,251,129,24,58,250,208,251,177,0,126,18,169,1,160,244,101,1,217,27,168,0,255,249,233,246,36,28,78,254,22,253,156,245,223,26,57,0,241,243,226,250,15,18,158,253,50,253,125,242,165,25,225,253,50,248,173,254,144,18,235,254,238,247,131,250,11,29,120,250,144,248,7,254,236,15,150,0,58,251,28,242,170,27,228,255,80,250,106,251,53,23,66,254,210,250,122,251,30,15,144,249,86,246,227,245,90,3,37,0,197,242,119,241,229,13,33,250,128,249,201,242,8,13,76,248,249,243,88,247,114,12,60,0,167,239,161,252,128,13,251,252,6,244,103,246,35,16,111,252,244,247,215,245,79,17,77,253,238,239,52,252,133,13,178,254,160,241,41,249,214,7,53,254,90,247,13,241,42,5,32,0,0,245,125,243,73,17,151,248,25,245,102,248,152,17,23,0,163,242,139,248,18,12,139,252,194,246,64,243,137,12,197,246,110,241,190,252,240,12,65,250,199,241,213,249,88,16,123,249,5,243,32,251,142,8,93,252,26,243,128,244,131,11,27,255,73,237,85,251,228,7,166,249,116,245,203,243,166,8,186,254,0,239,109,249,214,12,197,245,148,246,102,246,232,3,245,245,223,239,146,247,192,9,189,245,229,241,103,250,251,7,113,247,137,247,13,241,11,10,16,246,133,248,106,243,230,7,35,250,240,240,139,247,125,10,100,251,75,250,58,240,74,6,247,246,217,238,107,251,36,9,70,246,137,239,252,253,206,6,201,245,208,241,158,247,11,2,243,250,106,239,118,246,141,14,93,245,58,244,216,249,226,13,155,250,152,239,200,252,11,5,198,249,87,237,106,250,172,5,3,2,112,244,10,241,168,16,130,252,23,243,222,248,46,10,84,250,86,238,58,252,172,4,194,252,57,237,232,248,30,4,249,252,200,245,25,240,110,16,159,1,8,239,148,251,228,11,235,1,226,239,114,248,220,3,123,252,231,242,141,242,193,6,9,244,37,247,214,242,75,15,144,3,83,244,173,246,197,14,44,1,103,246,22,244,152,10,156,3,186,250,74,251,134,16,149,1,217,246,153,2,86,7,151,252,31,255,227,255,182,13,56,0,202,250,164,242,34,11,167,5,165,245,178,243,230,5,62,253,227,239,77,246,43,12,25,3,100,249,202,240,107,10,213,0,99,244,30,245,160,4,176,246,21,244,155,243,91,8,28,3,225,247,143,241,184,5,53,250,114,241,62,245,103,9,132,251,181,240,223,249,52,10,13,249,111,243,33,247,102,9,202,244,135,244,64,246,92,8,126,0,194,241,58,245,136,11,244,251,12,1,113,250,93,0,117,248,255,240,49,242,133,1,119,244,201,242,241,242,204,33,121,234,130,249,53,2,3,29,25,245,25,246,182,252,93,33,99,239,129,250,36,252,82,31,125,243,74,244,105,0,63,28,170,240,66,252,28,5,163,28,150,241,149,254,26,10,147,26,194,241,78,247,121,252,227,31,5,245,35,254,69,247,140,36,22,241,107,249,84,253,18,33,218,244,210,254,70,253,10,33,104,243,5,2,23,1,138,31,197,245,210,250,36,10,75,34,55,245,33,246,71,254,133,25,185,244,125,252,72,253,226,28,255,246,150,249,136,255,89,32,60,241,234,255,25,5,198,35,195,238,245,252,133,3,71,35,136,235,171,251,142,6,13,34,190,241,154,1,205,251,149,28,131,243,206,252,40,247,254,30,175,246,66,251,162,248,64,32,167,238,221,254,181,253,190,28,189,242,66,4,242,254,230,36,210,236,193,250,39,254,251,31,138,237,216,252,142,4,80,29,251,240,209,255,11,1,93,31,158,247,253,250,129,254,37,29,111,245,171,252,15,3,151,36,204,241,123,253,158,254,251,34,111,242,204,254,101,248,228,33,133,245,205,247,205,5,57,29,69,244,153,252,68,254,79,31,233,244,119,249,151,4,35,27,221,237,9,250,233,251,198,29,241,245,119,255,64,252,172,36,73,239,61,253,214,250,190,32,117,235,253,250,203,253,200,26,214,239,250,251,118,2,211,33,245,245,156,251,126,249,59,34,33,241,231,253,239,9,113,31,6,242,118,247,164,253,80,32,209,246,63,248,66,251,199,26,44,241,9,250,161,249,10,28,176,244,192,249,36,249,128,27,184,244,167,255,206,249,117,24,181,242,248,254,230,3,76,30,165,237,249,249,190,252,2,30,242,237,10,253,71,249,135,34,120,239,140,244,167,7,147,36,185,237,92,248,39,0,203,30,224,241,122,250,104,250,124,34,140,243,180,250,224,250,66,30,109,240,135,255,136,246,46,36,72,243,75,253,50,3,246,29,164,242,108,255,176,13,176,28,145,243,96,2,59,6,16,35,213,239,200,248,24,5,52,26,221,239,33,0,172,252,160,30,179,238,29,247,79,0,20,35,238,240,234,244,197,1,135,30,4,238,253,245,176,3,180,32,186,238,9,249,255,11,175,33,248,235,38,249,72,11,38,29,47,243,121,3,152,3,224,32,197,255,216,250,223,248,248,30,48,250,98,254,61,246,174,31,47,252,233,251,6,248,86,32,81,253,195,249,242,249,52,31,82,255,47,252,198,247,161,33,245,249,164,249,9,250,40,35,250,248,78,252,31,249,250,34,152,252,132,250,198,249,235,34,210,1,20,253,68,251,77,37,183,254,79,255,176,250,195,36,238,255,154,251,224,249,155,34,242,252,24,254,198,250,251,34,38,255,213,255,71,251,171,35,187,255,59,254,23,252,109,35,17,250,189,251,81,251,31,36,227,250,202,253,134,251,80,33,175,249,225,254,223,250,83,30,23,253,107,255,8,248,102,32,169,254,1,1,183,245,165,39,131,252,216,253,143,249,182,36,109,252,218,0,6,248,231,37,86,251,93,253,200,249,114,37,68,253,85,254,82,249,226,34,241,1,91,250,62,251,69,36,213,250,93,255,240,249,239,32,247,250,39,252,132,250,5,35,113,253,141,2,53,250,70,37,23,252,73,252,152,251,245,35,121,253,219,255,142,252,155,33,200,255,2,2,255,248,84,36,244,255,212,250,201,253,69,34,238,0,72,255,80,250,213,38,230,250,187,255,0,249,144,36,23,1,136,254,129,248,220,35,227,254,95,0,134,247,194,38,11,254,54,252,222,249,149,32,43,250,168,252,212,247,76,34,43,252,174,252,10,252,249,37,220,253,32,250,186,251,245,38,43,250,226,1,199,247,3,34,179,254,253,251,193,251,138,35,43,254,197,254,69,249,175,34,230,251,107,253,28,248,153,34,90,2,158,252,130,248,241,34,255,251,150,247,209,251,36,33,118,248,44,254,125,247,217,35,145,248,32,255,192,247,204,33,119,255,207,247,66,251,103,35,51,252,131,250,252,252,112,36,56,254,150,2,91,246,117,39,71,253,127,0,191,247,213,37,43,3,201,246,0,252,138,33,162,255,52,254,66,248,244,30,115,255,3,254,47,246,93,30,99,253,149,255,237,244,188,33,216,251,210,255,151,246,20,38,84,2,233,248,187,250,220,34,48,1,35,2,202,245,226,36,234,2,127,251,113,249,238,36,234,254,239,253,72,248,40,33,49,2,224,255,144,247,99,39,193,255,248,249,172,250,174,36,2,251,56,2,149,251,12,38,207,255,51,247,114,252,52,14,169,246,165,251,226,241,126,23,124,243,146,248,240,248,155,22,87,242,164,251,226,245,13,17,26,244,160,249,148,245,125,18,112,247,19,248,92,246,36,21,63,245,159,249,96,246,103,17,209,242,1,253,185,242,104,17,148,249,41,252,231,244,199,15,37,246,38,0,129,240,78,13,154,245,72,0,107,237,183,16,43,248,31,4,209,238,225,16,159,250,164,252,54,241,159,14,149,233,117,253,25,244,200,13,122,234,105,1,36,240,96,25,234,236,120,255,127,245,161,17,122,235,39,2,86,240,157,25,171,242,164,255,9,244,90,16,245,247,187,0,47,0,66,24,235,239,24,251,63,248,150,23,9,239,95,1,180,247,209,16,84,237,227,247,151,248,128,17,25,241,76,247,3,250,206,21,151,241,197,4,155,242,156,21,246,236,171,4,51,245,118,25,219,244,119,252,248,245,91,21,112,247,214,1,237,239,43,16,215,249,240,0,91,242,161,20,122,248,39,253,244,242,94,20,202,244,79,5,63,239,230,11,74,242,0,250,114,243,57,21,191,244,50,251,96,251,253,18,164,240,209,251,25,245,61,22,118,239,142,248,34,250,164,15,161,240,244,248,177,246,144,14,48,241,169,2,91,237,37,14,42,244,97,248,218,245,13,20,193,240,44,0,140,241,233,13,133,242,159,4,75,235,162,19,54,245,219,246,12,249,209,22,68,246,45,254,118,243,215,21,1,249,241,1,88,246,190,19,198,240,226,248,207,247,181,22,24,245,83,0,67,250,80,17,111,238,134,6,183,235,218,20,211,237,171,251,104,247,167,12,207,238,120,253,185,241,99,8,242,241,80,251,110,239,65,17,33,247,240,249,118,243,94,25,248,238,84,3,19,242,89,9,42,231,168,252,84,238,95,19,156,239,177,252,133,250,60,19,194,234,30,255,46,244,158,16,73,235,230,250,136,246,25,16,202,243,226,246,67,248,109,13,165,238,72,250,119,244,131,12,125,242,239,253,13,239,8,23,199,232,31,2,82,243,195,7,131,237,36,255,1,237,6,17,177,238,254,253,247,243,231,17,144,246,20,254,17,247,127,11,85,236,163,1,193,236,238,20,247,235,219,3,43,239,108,17,192,242,216,6,254,233,87,13,231,237,227,5,199,232,43,3,172,237,67,254,29,9,241,3,19,234,191,248,80,5,58,5,104,245,96,245,220,11,234,3,86,241,234,245,40,9,238,2,0,238,226,246,202,2,251,7,121,243,250,244,125,8,116,255,210,237,119,244,101,1,202,255,70,240,184,246,135,10,66,7,98,236,51,253,239,8,16,8,202,240,46,253,183,12,167,10,50,238,180,254,43,10,18,7,254,234,27,1,34,7,95,15,26,239,250,2,55,13,1,253,167,237,50,246,130,7,98,8,40,239,238,243,105,6,54,0,7,233,190,247,153,3,200,7,122,233,128,253,38,6,176,4,5,235,166,251,36,7,157,11,39,235,34,0,218,8,251,5,102,236,255,244,168,4,6,12,38,238,117,0,198,7,156,3,66,239,148,250,153,10,142,0,62,236,224,244,207,5,150,255,220,231,143,252,74,3,161,2,199,234,27,255,60,6,15,3,178,233,32,245,50,2,143,7,159,233,39,248,88,3,102,254,209,242,2,243,174,10,234,0,72,244,188,245,188,12,221,2,179,242,34,241,53,6,3,3,67,239,40,242,34,5,168,4,21,242,136,240,130,8,206,0,77,234,30,251,10,6,126,255,25,241,70,251,225,11,134,2,156,240,119,254,176,11,72,255,189,236,25,249,133,7,186,10,0,236,29,247,184,5,136,9,109,241,232,242,169,10,22,254,178,236,61,241,229,3,68,0,180,245,185,239,194,14,48,0,110,240,234,239,58,8,46,252,146,234,200,250,110,5,102,4,79,235,169,252,128,2,40,254,121,240,218,241,21,6,152,9,32,235,13,250,112,6,250,252,236,233,143,246,123,4,227,3,22,232,212,252,108,4,210,12,37,238,29,249,127,8,71,14,234,240,92,253,240,13,222,11,193,241,120,249,53,13,35,10,108,244,44,245,191,12,80,16,231,242,132,251,2,17,67,6,142,242,36,250,116,13,60,3,174,231,9,249,166,2,141,5,251,242,248,243,75,13,97,4,137,237,124,248,192,7,70,255,37,236,86,253,4,7,51,3,38,245,96,242,18,2,165,1,199,244,8,241,36,10,116,8,89,239,187,249,234,8,73,2,171,238,86,253,21,254,124,253,156,238,123,251,21,9,199,7,53,239,210,0,18,11,87,8,208,241,191,247,153,2,198,226,92,245,154,245,156,250,185,228,138,247,84,241,75,242,83,228,97,250,163,246,216,243,176,225,23,244,9,243,250,244,35,223,56,245,202,238,30,243,149,232,153,240,20,251,90,241,57,225,238,249,120,242,210,245,86,231,14,248,218,240,111,249,111,221,220,247,137,250,49,251,15,228,214,245,152,250,207,252,151,224,245,245,105,254,31,245,178,227,71,247,214,249,4,1,88,227,213,240,35,240,194,250,61,226,188,240,218,246,126,1,20,222,116,241,130,249,41,253,86,225,150,244,22,249,135,242,146,229,14,248,243,250,60,248,17,229,188,247,56,252,96,241,32,228,229,235,198,245,7,245,224,223,116,241,41,246,203,249,201,229,66,245,51,244,37,255,133,224,154,249,178,251,153,243,250,221,25,237,133,240,185,243,109,219,155,236,71,243,22,252,45,232,41,249,171,243,117,254,203,230,112,243,11,238,29,254,57,225,155,234,185,252,178,245,222,227,58,240,242,253,216,244,170,224,52,251,138,248,146,249,99,220,143,250,210,249,25,246,121,220,123,245,132,253,211,245,140,220,236,245,103,242,41,246,121,223,5,237,138,246,83,0,80,223,175,247,236,246,131,247,150,222,45,238,254,240,41,248,34,215,91,239,114,248,220,247,11,218,141,243,10,247,152,248,103,218,207,240,52,244,104,243,127,217,165,236,113,239,120,247,232,217,209,246,27,247,199,243,205,227,234,250,177,245,189,249,203,226,248,238,122,241,209,253,208,233,15,248,234,246,250,243,50,216,84,234,221,237,239,241,41,219,231,239,145,252,81,246,83,223,182,234,28,248,97,250,111,231,198,235,187,249,251,240,129,223,230,240,81,253,24,245,61,224,249,251,232,241,149,240,242,214,0,246,81,251,222,247,249,212,200,241,68,245,31,244,198,221,98,236,145,235,118,251,87,216,101,245,216,237,5,237,6,225,171,235,148,248,240,241,167,218,36,242,52,237,118,241,17,226,155,237,100,251,61,250,143,220,181,233,233,248,92,244,102,222,197,246,141,245,70,241,17,217,18,234,9,242,2,241,124,223,19,252,173,247,74,243,165,215,151,233,10,246,132,244,214,223,230,242,223,242,129,238,52,224,97,248,82,238,63,238,233,229,154,245,20,247,170,239,158,251,22,250,229,230,44,255,54,0,132,249,208,234,132,250,254,0,38,245,154,235,78,3,245,254,131,249,79,230,46,3,207,254,27,248,129,233,204,5,1,249,114,246,45,229,170,255,143,244,170,243,53,230,249,248,145,250,139,243,75,234,227,251,190,249,140,252,145,229,67,251,151,254,194,254,181,231,212,255,18,240,181,245,109,234,79,254,68,252,222,1,226,238,190,5,28,243,98,246,123,232,95,245,196,2,126,246,35,236,228,253,125,246,233,241,241,233,194,247,21,254,146,251,183,237,186,244,87,0,149,242,223,237,86,251,182,253,145,244,80,237,110,1,142,250,234,246,123,232,94,1,97,0,41,246,186,237,184,247,245,249,141,248,51,236,79,244,12,1,116,241,145,237,127,0,197,252,90,251,232,232,120,4,137,240,238,246,14,229,74,248,88,245,76,247,230,230,206,253,56,254,102,253,103,233,183,249,19,2,184,251,157,233,112,253,15,242,80,253,181,240,110,0,112,237,67,249,215,238,135,254,118,243,13,243,208,228,184,252,80,253,168,242,149,236,197,4,215,248,77,0,165,230,126,246,17,255,1,255,62,229,138,252,192,247,46,250,109,231,127,245,248,249,29,238,178,235,19,251,45,245,82,240,112,234,171,2,157,249,243,244,120,234,190,4,66,252,234,245,41,237,56,9,227,247,42,238,222,237,109,1,216,243,138,239,184,232,201,252,93,246,50,246,6,237,187,5,231,249,185,242,66,233,211,0,249,252,199,251,184,238,76,10,17,251,25,0,22,231,144,250,108,242,146,254,215,234,143,250,152,243,60,250,203,239,186,5,81,246,6,2,160,238,255,254,80,244,158,0,204,237,1,251,216,250,224,240,129,238,123,4,61,250,200,254,58,235,27,2,57,242,113,249,28,233,111,249,187,242,146,242,39,234,74,7,7,240,121,246,101,237,251,4,20,253,95,238,177,237,208,255,138,247,77,238,173,237,216,244,175,246,171,252,109,232,141,253,86,251,5,240,136,238,85,248,86,253,94,243,12,240,39,244,73,243,105,236,48,235,244,255,247,246,148,242,7,238,101,255,24,245,242,251,221,228,29,248,36,251,10,250,117,233,166,248,185,237,109,241,126,234,27,1,10,244,190,255,26,242,10,253,225,236,93,251,143,18,144,14,80,226,64,245,248,12,5,18,185,233,97,244,104,15,99,10,148,236,23,251,10,255,136,11,131,239,73,246,166,6,199,16,172,244,7,250,154,9,71,19,59,236,151,1,112,9,210,15,237,228,106,242,201,10,165,8,107,232,175,240,120,12,74,7,31,232,213,252,103,9,198,14,10,233,76,249,183,4,150,13,191,232,219,244,159,8,152,10,105,229,105,243,189,10,11,14,56,243,171,243,109,5,204,14,8,235,144,248,188,7,213,19,189,227,138,250,3,12,196,17,99,237,97,242,195,10,236,10,22,226,173,238,134,10,22,10,171,228,70,239,200,1,248,14,69,234,213,243,193,255,129,14,108,239,132,239,170,5,207,10,39,241,110,247,190,0,207,16,174,234,233,239,166,7,226,8,124,227,115,242,186,13,121,12,14,238,237,247,7,3,144,18,195,242,138,249,184,5,36,21,19,237,101,242,196,3,109,13,137,232,254,244,130,6,51,18,251,221,113,236,221,6,215,12,55,233,219,238,1,4,99,12,100,233,12,249,104,15,77,14,178,238,104,252,146,7,145,18,102,228,191,248,239,17,186,17,35,242,255,253,147,5,197,20,163,226,60,251,67,11,233,11,75,226,129,245,82,7,175,10,242,221,61,240,116,10,146,14,202,224,189,240,161,4,47,10,86,232,48,249,21,13,37,20,190,232,53,2,89,12,178,12,178,230,156,253,138,7,223,8,121,230,91,250,254,255,82,6,253,220,201,239,168,4,204,15,197,227,14,242,64,6,138,16,190,237,79,0,83,2,199,11,122,240,174,1,167,10,17,20,77,235,9,0,130,14,171,18,133,229,117,245,248,255,132,9,152,228,135,251,13,5,6,9,213,228,16,243,254,5,9,7,71,240,228,2,58,7,214,15,139,218,124,242,58,16,150,20,204,238,99,251,202,16,53,20,68,227,25,238,238,255,84,10,140,230,45,251,87,17,90,24,131,242,211,254,248,16,112,17,221,237,250,5,243,12,244,16,33,238,3,246,170,14,98,14,197,241,83,242,3,8,181,11,220,234,85,246,253,8,43,6,42,233,3,1,80,5,44,9,118,235,178,250,26,4,70,3,90,234,37,255,233,24,118,22,175,233,120,244,154,3,131,3,255,247,145,251,86,20,9,4,99,249,162,248,227,18,150,255,216,246,80,242,136,16,243,255,85,246,226,246,179,19,102,4,237,252,11,246,40,15,90,8,169,243,219,246,222,18,71,11,12,249,15,252,96,24,13,8,25,239,221,242,2,11,118,3,208,242,73,245,8,16,207,0,78,243,224,237,158,10,218,5,130,254,205,251,30,17,132,13,144,246,184,239,202,13,48,3,36,249,108,245,253,18,110,2,169,248,207,247,36,20,73,11,64,246,142,246,138,14,111,10,99,245,76,243,13,13,152,7,33,240,5,240,234,12,11,1,35,242,32,241,163,14,74,3,181,245,34,2,162,22,102,7,191,248,159,251,31,17,124,15,78,247,138,247,161,13,94,14,92,242,108,253,203,20,39,4,39,244,198,243,30,17,36,7,113,245,143,253,225,24,35,11,136,249,230,244,232,17,240,253,83,237,194,245,38,17,49,8,99,254,3,248,217,19,219,11,30,241,154,245,180,17,71,4,184,243,190,248,95,20,88,7,22,242,253,248,64,19,158,2,64,237,27,250,69,20,67,7,195,251,8,241,73,16,132,3,79,248,58,243,41,11,62,11,85,239,212,239,104,12,13,7,231,235,113,241,196,13,144,4,190,250,172,248,125,21,212,6,122,236,127,244,115,14,82,1,126,242,232,243,78,13,133,253,41,249,119,243,180,13,139,1,53,246,170,0,99,23,193,2,84,241,208,251,15,22,208,13,202,244,97,250,162,19,140,12,183,240,103,243,85,14,96,8,101,241,226,0,115,22,252,2,252,247,204,252,146,20,21,12,114,243,20,241,105,9,87,9,210,238,228,245,173,13,38,255,124,238,29,249,84,16,58,255,216,242,11,250,10,17,122,255,153,246,224,0,41,19,205,13,167,250,135,244,120,18,252,6,16,237,85,249,63,16,83,3,130,242,43,249,185,16,158,12,58,248,243,240,159,13,199,6,211,243,92,0,11,24,235,15,140,245,88,246,238,15,179,253,245,249,36,248,66,10,43,7,77,239,180,253,216,18,213,2,167,253,55,247,152,14,220,13,36,240,195,255,213,20,25,12,49,239,7,0,151,25,238,11,117,236,251,251,154,22,247,12,6,245,40,253,16,21,199,0,48,251,56,255,108,20,49,12,61,10,165,0,145,231,42,1,85,14,25,2,68,229,28,6,62,6,90,251,165,231,219,9,116,8,224,255,18,229,103,5,85,3,195,249,75,232,169,5,97,5,131,249,110,235,108,0,100,10,48,0,204,235,251,253,111,7,121,254,211,233,242,3,208,14,206,0,102,235,245,255,215,4,216,10,143,244,161,10,231,15,149,0,165,227,53,12,156,5,32,254,244,231,60,255,93,5,88,248,115,236,50,12,85,13,9,251,200,235,211,12,244,11,188,255,161,230,190,8,140,10,229,247,183,237,91,0,112,11,64,249,208,235,66,7,72,17,60,3,137,238,88,0,112,10,212,245,58,240,193,10,103,20,133,255,163,229,247,8,141,16,92,254,94,234,73,5,136,18,255,250,255,239,100,18,79,4,52,245,113,237,232,7,163,14,135,248,185,240,120,15,166,9,120,250,90,234,103,2,239,18,182,250,42,235,197,6,216,20,88,0,87,226,167,15,84,9,192,244,57,237,13,4,143,17,111,5,203,233,117,255,133,20,101,6,206,230,253,5,175,4,27,3,117,234,237,4,117,5,21,251,100,239,254,14,234,2,70,0,16,230,92,2,48,6,166,0,148,236,0,12,124,1,25,252,235,234,219,8,158,11,171,6,86,243,240,20,82,20,109,254,179,234,16,11,134,14,61,249,104,237,202,2,54,16,49,252,72,237,61,0,109,11,206,252,23,237,15,0,181,20,65,2,90,240,187,12,145,20,194,7,209,233,212,11,168,14,136,7,99,238,145,14,206,12,133,7,30,231,223,4,243,19,185,6,11,237,55,12,207,12,166,11,45,246,165,15,14,18,156,2,196,231,247,2,146,23,61,1,125,233,210,18,210,253,57,0,55,241,1,11,124,17,80,6,131,240,184,17,65,23,8,8,233,223,155,10,35,17,53,10,217,226,100,3,202,22,64,4,128,237,60,19,73,25,168,252,177,228,76,16,95,19,219,254,214,235,76,0,171,10,181,252,25,232,7,15,173,12,178,4,79,229,104,2,249,9,103,5,11,241,19,15,236,16,51,8,104,242,38,14,62,8,123,10,88,245,150,15,108,3,143,4,38,243,138,13,151,15,173,6,150,246,237,15,241,19,171,3,232,245,184,12,111,18,176,2,226,249,224,11,208,241,239,16,242,4,25,243,164,236,135,12,32,5,10,245,195,237,67,10,103,10,125,246,70,239,124,14,255,8,34,244,72,238,249,8,81,255,234,242,142,235,199,9,117,255,144,252,118,240,232,5,68,4,221,241,89,238,41,18,83,5,105,246,2,236,60,12,169,7,215,249,180,235,51,13,74,255,158,250,236,230,134,17,93,9,55,248,90,236,182,19,12,5,162,251,49,238,13,10,97,252,130,250,83,242,146,14,179,2,190,236,244,238,198,10,239,3,187,240,70,240,23,11,233,249,220,246,83,236,213,15,68,3,221,249,137,237,16,20,86,4,252,241,131,235,239,10,25,252,140,247,166,236,221,5,166,1,133,240,150,232,166,10,182,5,239,244,11,234,39,20,246,7,48,246,129,236,243,8,125,7,177,243,163,234,30,17,108,255,94,244,30,233,191,7,39,3,96,245,155,237,228,13,184,3,45,254,71,246,58,9,178,6,122,239,147,237,140,19,100,251,168,241,230,232,69,14,79,5,219,250,126,234,179,11,12,3,221,251,89,235,105,15,176,9,11,247,247,240,6,17,66,1,22,249,185,240,242,13,252,0,143,243,180,241,8,20,158,0,121,241,9,238,205,12,9,254,89,245,167,241,176,14,28,251,245,242,215,235,33,9,132,1,105,248,55,242,168,8,108,8,248,243,43,239,235,16,16,7,76,250,82,237,236,14,224,1,56,246,186,239,216,13,134,254,225,249,60,234,162,9,94,254,163,244,48,232,114,11,119,0,170,248,181,232,226,13,243,3,71,247,223,230,239,16,167,3,142,244,116,236,242,12,184,250,154,242,102,232,135,13,16,252,156,240,193,237,166,8,128,253,80,236,21,245,175,14,132,5,37,241,193,241,84,17,217,2,253,253,246,241,9,4,56,0,204,239,164,244,211,11,73,11,99,242,246,242,186,8,57,1,67,239,15,241,145,17,207,253,182,245,233,231,196,11,208,255,179,243,36,237,187,13,55,252,133,238,99,233,197,10,229,253,179,239,108,246,251,11,52,2,103,239,199,236,78,5,51,5,183,244,201,243,143,16,235,251,13,250,84,237,22,9,162,251,138,242,188,240,170,21,152,0,194,245,196,228,160,11,81,1,7,245,25,237,5,18,221,255,19,240,128,250,214,18,131,251,123,236,43,252,115,19,112,252,96,231,206,247,57,22,136,252,194,244,241,242,206,18,111,253,174,238,99,246,17,14,57,252,251,236,164,245,104,15,87,0,112,234,176,251,188,23,174,0,249,230,99,1,250,20,71,249,19,233,218,4,145,17,173,251,29,236,167,255,162,15,45,250,194,235,35,4,61,22,201,249,215,236,43,5,74,18,226,247,96,237,50,3,156,15,219,253,164,234,225,254,177,17,161,3,89,234,105,252,143,21,25,245,228,244,129,250,47,22,39,243,122,240,67,255,130,25,37,242,94,240,124,252,127,27,213,242,9,237,89,244,43,28,149,254,29,237,210,252,103,25,152,255,14,236,174,246,240,26,41,3,201,236,77,3,140,17,96,1,35,230,50,248,69,28,146,249,121,239,204,242,107,24,215,1,31,238,140,248,147,27,84,0,162,233,172,254,202,24,221,252,135,231,25,247,202,22,209,255,231,237,4,250,166,20,44,249,147,248,59,245,44,24,59,254,169,242,25,251,5,25,5,248,43,231,150,3,205,21,135,255,221,233,48,7,216,20,203,252,86,236,85,246,128,19,223,248,224,243,147,246,230,21,3,249,54,239,132,0,8,20,171,246,166,238,223,0,0,25,163,245,122,237,95,253,148,19,168,2,26,238,135,249,224,25,163,254,244,241,13,253,145,24,188,248,118,240,196,253,238,26,102,248,169,235,139,251,148,18,151,245,46,234,207,251,173,16,81,254,66,240,186,0,129,22,148,3,20,233,141,248,228,18,249,3,14,236,61,252,35,13,32,251,52,231,66,243,166,18,230,248,30,233,79,3,228,14,22,246,50,239,57,251,15,23,80,5,153,234,186,251,11,27,36,251,179,246,11,1,132,24,59,253,226,244,99,255,208,22,100,4,86,239,121,3,134,12,114,252,71,235,56,249,16,13,70,2,26,237,203,246,44,22,121,245,123,231,132,248,245,26,38,252,235,234,10,244,140,23,73,253,201,233,44,7,238,13,179,250,150,235,128,247,74,19,134,2,224,240,105,247,239,11,48,255,20,232,20,255,216,11,203,252,51,235,107,240,109,28,203,253,197,240,173,253,10,17,74,0,169,232,172,2,242,22,183,252,184,238,85,245,161,24,171,246,167,234,113,233,45,5,200,255,32,246,139,228,234,253,158,248,50,243,90,233,241,255,82,245,94,247,128,234,82,251,159,254,181,241,41,236,192,3,130,252,16,239,71,232,220,255,123,255,58,244,106,233,253,254,255,251,110,240,69,229,238,4,217,252,153,249,113,235,106,252,38,243,189,253,24,237,205,1,146,247,235,253,130,232,206,255,148,253,248,1,45,233,241,0,177,250,230,254,246,232,65,2,1,3,57,243,79,229,78,252,46,254,237,242,118,232,179,5,0,254,39,253,63,227,235,2,124,254,170,251,9,231,94,8,120,251,47,246,173,228,48,1,242,1,143,245,155,229,167,2,126,254,79,254,154,235,152,6,187,251,248,251,101,236,63,2,184,0,213,241,115,239,116,2,77,242,37,251,201,226,56,254,70,249,50,250,192,230,201,2,7,251,127,251,145,231,146,6,162,253,233,241,135,228,217,5,185,255,93,248,218,229,20,6,71,249,114,243,30,232,156,254,45,3,241,245,68,235,120,2,197,248,156,249,146,233,113,252,59,249,127,1,61,232,125,254,247,246,145,252,121,230,238,253,31,250,221,247,224,236,199,4,66,245,232,248,8,231,49,254,81,243,211,247,3,235,240,4,110,245,30,244,202,240,146,250,4,252,133,252,221,231,144,4,82,248,126,248,214,235,132,6,175,249,132,248,203,230,152,3,111,251,128,246,14,232,213,7,232,253,17,250,104,230,158,255,250,253,110,248,152,226,99,1,179,251,20,249,143,233,98,2,9,255,176,250,165,228,177,0,240,247,90,248,212,228,198,253,84,247,127,239,106,225,23,3,142,250,42,245,46,226,224,1,157,243,128,239,23,225,130,4,162,254,179,246,57,236,168,6,244,248,95,244,233,236,244,253,113,245,188,0,81,234,150,1,172,249,9,244,59,228,62,5,125,1,51,244,66,229,119,2,54,254,186,242,2,238,163,253,11,0,166,240,58,224,31,255,54,249,168,245,125,228,146,1,82,245,13,244,7,227,33,7,15,246,219,238,197,228,20,255,249,251,103,253,136,233,63,8,160,249,32,241,20,226,178,255,144,253,193,243,42,231,107,2,97,248,185,240,58,224,152,1,113,248,145,241,65,231,119,7,192,246,103,238,52,228,115,8,168,254,63,245,53,9,136,17,172,8,206,233,105,5,134,12,252,8,71,235,139,5,253,9,83,20,68,242,6,1,219,16,80,15,201,248,244,12,115,12,76,6,23,234,193,6,46,9,137,6,76,232,67,6,238,23,187,5,233,244,197,250,244,12,107,14,54,242,205,253,10,18,108,12,60,238,207,1,16,18,39,12,18,234,222,4,79,21,28,13,168,233,224,1,101,8,46,21,179,244,232,6,219,18,145,3,53,234,107,255,5,21,14,17,31,243,217,3,88,14,84,10,164,255,254,254,95,11,185,22,91,247,100,13,217,12,23,13,43,242,102,253,223,12,119,18,203,244,35,0,241,25,64,16,44,240,111,2,131,26,84,12,48,238,94,10,8,17,68,18,232,237,106,5,126,20,226,18,111,238,160,13,222,17,16,15,198,232,127,1,129,17,72,16,242,239,217,6,68,14,192,16,2,243,64,5,41,19,204,9,204,237,44,6,10,16,32,12,80,247,235,7,174,19,147,6,238,249,190,1,115,14,240,22,59,244,29,18,247,15,250,13,102,236,69,10,232,13,211,20,220,236,247,5,18,26,219,9,221,239,99,250,244,10,224,9,144,238,27,255,27,13,224,7,95,234,82,14,90,13,22,17,27,238,168,4,215,14,155,3,60,230,248,7,140,11,192,1,54,235,164,9,136,22,189,15,19,233,110,13,116,25,201,13,245,229,177,10,119,21,168,2,97,234,56,15,95,22,9,7,162,236,124,19,93,19,8,14,138,230,226,253,64,17,162,22,29,245,40,16,2,17,16,8,168,237,251,11,48,23,183,4,188,242,229,10,102,19,101,9,242,240,195,6,198,12,179,12,217,251,231,6,161,21,36,8,211,246,209,1,44,12,180,17,187,252,219,5,67,10,2,18,92,247,122,0,23,12,58,14,32,242,238,9,50,11,145,10,254,230,62,12,227,16,186,2,79,237,219,2,67,7,40,12,134,235,249,9,164,11,169,12,18,237,49,5,190,20,71,6,32,230,164,9,66,7,148,13,246,251,84,255,132,19,208,7,70,234,61,10,124,16,38,6,198,242,179,254,40,7,34,13,235,239,121,8,106,26,249,11,175,231,28,11,152,21,151,12,99,237,14,2,55,20,108,6,85,239,106,11,74,17,110,9,206,245], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2033824);
/* memory initializer */ allocate([196,1,119,5,92,238,180,245,56,11,184,6,197,237,101,250,255,4,190,2,208,234,64,248,139,8,102,3,99,236,195,250,71,2,112,255,236,237,96,246,3,0,189,8,92,235,245,244,237,255,237,3,172,234,229,248,81,11,36,8,3,233,253,253,112,254,42,13,105,234,125,244,225,5,33,10,114,234,246,248,61,5,182,17,26,236,149,248,169,12,86,14,139,234,28,251,249,250,153,3,150,232,117,249,115,2,152,1,4,230,148,254,252,254,103,4,15,237,81,243,115,1,72,13,168,232,19,247,253,5,30,6,27,231,158,253,158,9,178,16,216,231,26,251,246,6,35,13,178,231,155,250,60,2,42,18,215,233,62,245,114,10,86,13,148,238,150,247,30,14,236,14,29,229,114,254,112,4,255,255,121,234,168,251,19,249,113,4,241,233,183,246,15,253,56,8,59,232,251,245,52,255,209,11,133,237,118,250,50,250,158,5,228,238,40,255,46,1,90,3,102,233,248,254,158,13,215,5,142,235,241,252,120,3,23,9,161,242,120,241,253,254,4,3,60,230,225,250,83,251,25,8,202,235,222,248,220,5,142,13,146,238,171,245,0,12,168,7,51,243,40,247,49,7,184,3,28,239,220,246,202,7,152,8,156,240,149,244,10,249,163,6,197,237,205,251,72,250,90,11,116,242,137,254,110,1,76,9,93,241,187,5,223,253,109,6,245,237,120,1,188,6,46,9,186,246,72,242,112,12,68,10,76,244,53,243,222,2,218,7,161,231,57,250,12,2,172,14,112,238,65,243,212,5,242,13,90,242,240,241,92,252,106,2,243,234,178,244,123,255,113,8,13,240,61,243,18,3,6,3,49,243,109,241,54,4,35,3,253,240,65,244,180,254,77,13,237,242,40,0,239,255,6,0,91,240,150,241,67,255,20,17,120,238,255,245,62,254,6,15,50,241,166,250,106,1,164,8,104,235,241,255,7,250,23,3,110,229,8,247,97,8,145,16,134,238,120,1,21,7,122,9,140,244,90,245,226,253,205,17,188,243,200,251,168,4,200,14,237,238,236,255,224,10,68,20,1,231,142,250,175,1,209,17,167,241,138,250,102,5,24,12,13,240,229,4,185,4,128,16,142,244,220,5,238,10,124,10,236,229,162,253,164,246,230,5,251,234,103,245,191,245,238,9,64,240,192,244,49,251,127,15,254,239,186,244,143,250,70,9,234,240,83,238,65,246,129,6,155,249,187,234,242,240,223,6,42,249,176,236,187,246,132,6,216,244,149,231,148,245,189,7,138,252,51,238,145,244,75,17,133,242,228,231,123,248,36,10,168,237,33,246,126,243,31,11,168,240,248,232,252,242,129,6,95,236,172,242,116,243,43,12,197,239,34,240,11,252,133,12,243,235,89,241,26,248,243,17,149,240,21,234,28,242,219,6,125,241,4,247,8,249,18,16,93,245,19,249,254,241,241,15,83,245,178,236,184,249,101,14,198,239,35,238,216,242,202,15,156,238,173,231,129,250,41,15,159,233,121,241,65,245,209,12,43,236,121,236,49,241,106,9,214,236,88,235,38,253,255,8,135,239,85,241,236,248,7,9,140,234,131,241,158,253,240,16,181,240,57,241,231,244,241,16,74,239,178,238,130,249,58,18,203,237,132,240,179,253,89,20,197,236,158,241,197,239,186,8,20,240,134,239,145,240,210,10,151,245,11,245,2,247,156,12,123,241,140,248,199,243,21,17,40,247,221,244,65,254,83,5,6,242,29,239,168,245,141,16,169,243,1,244,24,240,169,12,43,242,3,238,101,238,130,13,221,246,2,241,146,249,229,3,194,236,126,240,47,244,78,6,156,240,38,251,199,250,220,6,165,243,103,234,125,243,73,7,46,243,254,238,146,249,70,8,101,247,126,232,174,0,79,7,109,245,225,237,209,245,205,5,86,237,114,237,105,247,151,15,194,243,241,236,110,244,251,12,0,245,141,246,90,235,191,9,60,238,237,234,6,245,126,14,30,247,141,239,182,254,190,11,79,244,186,237,93,251,107,9,73,245,180,235,104,253,193,15,227,243,247,233,78,250,18,14,0,245,5,235,236,239,59,19,7,243,2,234,187,239,224,9,224,245,66,237,57,245,8,12,227,246,169,233,219,235,195,11,106,234,52,231,233,243,78,8,7,233,118,239,231,238,9,15,240,241,45,232,54,248,83,19,141,235,111,237,213,251,88,2,70,243,243,235,128,236,230,12,96,247,69,236,207,242,165,11,137,249,49,237,3,243,142,9,5,249,28,232,219,246,177,10,88,243,53,231,46,247,108,241,126,14,45,251,234,249,247,240,134,10,60,244,169,253,27,237,234,11,121,244,58,247,199,234,238,10,138,248,49,247,131,236,188,12,14,1,46,244,23,235,133,10,244,251,129,251,47,232,73,4,58,241,193,242,132,232,82,8,233,250,222,244,186,238,47,13,32,254,142,251,61,241,211,5,190,239,217,253,204,240,203,14,222,247,107,243,164,241,72,12,78,251,49,244,180,235,90,10,93,2,36,249,159,233,86,10,65,1,123,245,199,238,238,1,67,237,135,248,35,238,44,13,62,249,3,251,236,241,221,15,31,252,92,254,127,236,71,5,68,237,20,244,43,235,155,5,38,251,166,253,86,236,29,15,139,251,124,246,184,237,129,6,53,244,159,245,182,241,179,5,193,242,60,251,154,231,189,10,243,253,2,241,20,237,217,8,57,249,33,251,209,233,28,13,119,250,107,252,184,234,14,13,105,0,36,249,73,229,228,8,210,246,100,254,170,235,228,6,45,242,97,250,253,228,162,5,90,241,155,250,169,238,23,15,230,254,102,242,167,236,166,10,176,254,160,250,213,232,178,6,61,248,76,249,203,238,48,10,105,0,202,249,185,235,92,10,112,245,155,247,214,230,149,9,17,251,158,242,8,241,30,9,219,248,69,245,196,232,58,9,83,255,125,246,61,243,150,11,82,249,117,240,70,239,145,10,249,252,156,254,114,239,240,9,9,239,173,250,185,230,1,11,212,248,194,244,3,236,218,0,179,243,45,242,180,235,174,6,204,246,184,244,71,238,186,10,91,249,178,248,169,238,216,5,231,239,50,250,196,242,21,13,159,247,251,242,214,239,187,5,196,244,167,254,36,235,244,3,90,251,120,249,128,236,241,8,251,251,158,247,104,234,222,11,133,253,196,254,184,241,98,13,176,243,121,245,76,233,32,9,254,247,237,247,92,232,225,2,70,243,152,245,147,239,162,254,14,251,151,253,226,234,80,0,11,237,142,246,15,241,61,7,210,250,87,248,13,239,71,2,37,239,41,250,235,235,123,255,171,235,120,243,216,230,155,6,235,247,184,245,207,241,21,9,55,245,192,245,218,233,228,4,164,241,153,241,24,234,175,2,239,244,8,243,181,233,16,0,219,240,78,245,32,232,84,0,241,235,229,8,227,233,4,12,75,3,19,6,119,233,5,11,140,235,24,2,19,231,91,2,210,236,222,2,255,237,242,12,4,240,44,7,61,238,195,12,30,239,243,255,168,232,168,14,185,249,143,5,82,231,32,9,142,1,109,1,157,225,218,5,234,253,56,8,82,223,130,11,191,250,143,0,87,234,106,7,84,241,143,2,60,229,150,5,148,0,4,0,3,230,93,9,197,255,42,9,148,232,210,17,90,252,205,4,64,228,147,11,170,253,240,253,120,228,71,11,2,249,171,5,55,229,60,15,155,249,42,2,126,232,8,13,9,0,206,12,130,233,194,15,129,0,213,13,23,228,41,19,217,249,35,9,5,229,136,13,211,254,215,10,123,227,131,6,202,240,27,2,49,225,223,3,196,239,67,8,3,227,59,12,253,243,243,10,158,222,4,10,52,233,53,11,55,233,84,6,47,238,31,10,143,227,143,12,145,237,52,251,227,222,194,2,82,237,175,7,133,235,205,18,108,248,189,2,158,228,225,8,203,240,147,3,234,222,126,7,12,234,162,255,197,229,156,0,223,240,50,4,25,234,37,17,7,252,179,10,105,230,203,4,63,242,213,2,101,225,141,10,245,250,19,254,205,226,215,8,205,251,100,254,148,230,168,11,24,253,153,2,181,234,141,14,124,245,219,5,63,224,236,13,232,247,54,11,67,231,135,17,196,247,194,2,113,236,71,15,104,255,30,254,44,222,203,5,172,244,177,9,60,230,214,9,77,249,123,5,242,230,118,5,245,234,140,2,133,231,71,2,202,232,182,2,140,226,134,2,128,231,227,8,66,226,0,1,105,236,136,5,1,218,108,7,175,243,200,10,223,230,35,15,69,241,21,9,68,212,134,8,221,235,199,4,203,212,97,5,23,236,108,0,149,214,51,1,168,236,138,255,180,223,114,6,220,249,47,7,249,224,219,6,156,253,197,9,160,220,213,3,103,244,86,11,228,222,211,5,108,233,203,7,89,212,49,6,197,241,184,2,236,223,60,3,86,246,246,5,55,222,100,5,70,251,205,1,171,227,150,12,75,247,150,11,63,222,25,16,57,243,65,3,105,232,57,9,194,251,237,13,112,227,188,7,205,234,34,11,33,222,176,14,202,248,83,10,143,227,115,8,83,255,135,13,134,241,196,243,101,252,35,5,15,241,141,242,2,0,34,10,13,240,25,241,158,2,34,7,61,239,75,245,101,255,100,3,91,241,177,239,214,254,216,7,115,239,199,240,251,253,218,4,91,242,17,239,201,250,168,255,210,239,194,242,7,250,128,8,96,242,18,241,49,252,170,6,188,235,169,242,131,253,157,10,241,231,227,246,142,252,252,4,118,240,247,238,25,2,167,9,76,234,206,244,48,255,31,3,191,237,10,240,56,0,109,7,78,237,51,242,14,1,220,11,194,240,234,241,179,254,201,8,11,243,33,239,112,255,34,10,145,239,199,247,142,244,168,15,90,237,190,245,122,252,14,4,181,241,88,242,106,246,165,10,243,241,30,243,1,250,126,6,85,233,3,245,175,0,193,2,83,241,143,242,52,250,68,7,157,232,251,244,138,252,202,14,202,236,105,247,119,248,99,14,117,239,13,246,249,250,227,9,224,236,116,244,199,249,237,3,47,234,4,243,76,255,89,6,147,235,36,249,198,241,214,5,79,236,83,244,131,245,158,10,209,237,104,243,157,252,70,9,16,230,47,249,97,244,85,8,220,230,83,246,37,250,41,7,190,238,61,242,24,250,104,4,210,236,158,245,174,251,177,2,87,237,241,244,219,247,9,14,96,235,189,245,197,254,192,12,69,241,143,245,187,248,130,12,30,234,151,246,146,1,40,2,246,237,83,247,70,244,23,12,20,235,150,245,197,251,73,13,255,237,182,243,45,0,235,11,202,237,112,247,72,247,238,10,80,234,98,246,107,248,50,9,73,233,81,247,197,245,192,0,132,241,9,245,158,245,94,7,126,239,186,248,55,242,222,9,120,240,253,244,228,246,41,6,226,240,105,245,10,245,8,5,44,234,202,242,133,250,151,10,233,234,228,249,75,243,179,5,140,234,82,247,190,254,7,11,29,236,186,244,8,3,231,13,67,233,195,247,176,250,51,6,69,231,56,245,139,248,91,8,163,235,198,244,184,247,38,5,15,239,145,241,206,247,53,3,137,238,199,248,203,253,1,13,82,237,67,249,167,255,70,2,206,236,247,239,161,251,161,1,208,239,24,240,31,246,57,255,37,241,51,245,54,240,171,10,69,239,161,247,1,0,95,11,213,231,97,248,188,247,37,6,50,232,19,254,234,244,33,8,241,228,160,252,117,243,34,4,110,225,79,0,148,254,75,12,62,234,84,253,46,252,244,13,32,233,36,4,32,7,119,4,210,229,58,250,82,1,37,9,204,227,168,255,4,1,55,14,51,229,156,2,47,3,179,8,132,231,86,249,190,1,62,13,62,232,159,254,22,5,99,4,124,226,43,251,82,254,193,6,194,225,217,2,38,255,177,5,138,229,75,2,67,2,249,1,249,228,199,253,115,1,82,4,179,227,78,0,158,0,195,10,167,229,158,251,82,1,253,11,104,232,121,250,218,3,126,8,104,228,106,250,229,254,110,5,78,222,66,254,41,244,206,13,22,229,81,254,35,2,219,8,110,218,219,1,78,244,88,14,7,226,75,0,141,255,83,8,120,226,74,251,18,253,156,11,203,226,83,253,250,254,68,6,19,230,96,253,187,2,130,6,103,226,191,253,16,255,55,6,102,230,146,247,162,255,44,9,114,231,159,254,99,4,225,7,150,221,100,254,243,248,76,11,199,229,27,249,214,253,196,9,84,229,53,248,83,251,37,15,17,230,32,255,137,249,88,9,64,225,165,255,179,254,234,13,54,227,236,253,236,244,248,9,66,226,164,0,243,248,222,3,40,232,218,0,182,1,142,3,75,225,56,1,85,251,192,5,73,231,116,1,128,253,40,6,25,228,65,248,181,252,166,1,55,226,55,254,234,254,5,7,172,222,149,1,13,252,64,4,28,227,18,255,27,247,137,12,159,229,105,250,232,247,57,10,73,229,100,0,243,245,15,10,131,222,125,254,140,243,34,14,197,228,90,251,191,254,157,8,63,227,97,249,40,248,169,11,103,231,184,5,155,4,244,10,114,227,29,4,82,1,82,5,70,232,117,251,184,252,8,13,75,231,254,248,21,0,20,11,83,224,50,3,183,254,231,10,9,233,48,2,10,6,88,9,80,232,135,0,100,0,46,7,206,231,84,2,61,4,134,7,165,226,98,254,219,236,153,12,126,227,78,251,91,251,120,15,122,226,109,253,49,253,114,13,9,230,100,249,185,251,53,13,215,230,6,1,138,252,151,5,42,224,94,251,130,250,84,1,206,222,106,255,125,252,188,11,43,224,252,254,71,252,189,10,45,230,51,2,105,3,9,230,211,250,91,238,173,237,139,232,135,249,7,240,43,241,171,243,76,2,163,235,4,244,17,243,111,250,71,231,114,241,22,233,205,252,239,240,72,245,119,236,249,248,205,251,243,237,46,235,166,245,144,245,200,237,190,236,229,253,197,246,86,240,88,244,10,0,233,240,139,233,225,251,198,247,127,241,85,239,156,234,10,254,73,239,152,230,145,235,249,249,102,236,231,230,242,235,149,254,163,243,11,236,143,240,253,252,245,239,7,231,145,247,205,253,188,241,34,235,208,240,239,246,105,252,63,236,44,251,171,253,117,239,159,239,43,240,163,2,245,243,226,231,23,245,191,251,236,234,124,242,72,244,212,255,95,247,81,230,248,242,5,250,39,239,216,235,177,247,128,0,13,237,148,241,7,243,136,0,237,247,228,233,161,235,124,5,234,238,252,238,69,245,144,1,60,231,149,241,170,240,169,253,15,235,114,236,197,244,224,245,233,235,4,240,129,236,90,248,54,235,229,236,155,236,218,250,4,230,43,235,200,236,101,249,196,242,71,234,196,241,230,242,128,245,162,232,44,236,105,252,45,238,88,244,30,232,250,0,212,240,181,240,82,240,232,2,123,240,124,248,89,234,239,251,75,234,249,240,153,237,184,250,239,233,213,245,222,242,7,3,71,235,241,236,119,236,107,0,30,242,184,244,142,231,141,249,44,231,90,230,79,238,151,1,117,236,231,240,222,235,38,2,98,235,167,234,157,239,45,254,154,248,199,243,98,236,103,4,235,242,14,243,69,232,226,4,39,239,247,233,139,245,21,247,248,246,241,232,239,239,193,0,85,251,31,237,156,240,232,251,147,250,41,236,137,241,149,3,53,240,157,238,218,242,121,239,2,250,144,234,2,243,1,242,213,247,217,236,232,235,230,4,28,246,171,236,162,232,154,252,15,246,53,238,171,240,99,255,9,235,23,247,237,230,22,253,220,233,237,238,101,233,6,2,72,228,83,233,94,239,186,3,203,230,31,239,93,237,73,253,194,239,153,249,90,228,8,253,181,235,11,233,76,227,83,0,251,239,22,238,130,246,184,0,198,244,113,249,20,247,153,240,148,244,86,236,244,248,7,249,70,244,154,237,209,238,44,245,233,248,227,237,60,231,190,245,248,244,185,235,122,236,208,235,104,242,113,7,138,240,140,234,193,249,43,6,89,246,85,241,236,254,110,12,39,244,109,233,217,251,18,6,136,244,35,237,246,250,82,9,213,248,47,236,21,244,19,5,68,249,69,241,161,240,20,9,50,236,10,246,148,241,0,3,26,239,43,235,215,254,86,7,112,242,13,234,234,243,224,3,45,244,224,238,34,244,217,8,127,243,44,235,67,0,152,8,111,249,235,238,101,248,157,9,107,243,255,242,114,239,4,10,18,251,104,244,157,244,155,12,165,242,170,248,211,242,62,8,60,247,49,234,36,248,8,5,77,248,110,235,34,252,20,7,97,244,38,245,60,254,223,15,106,247,115,251,30,243,149,11,82,237,226,236,97,237,152,2,142,232,146,240,10,245,233,7,186,243,166,243,213,244,223,12,66,243,244,242,229,239,60,6,82,240,178,240,93,248,33,13,92,249,121,242,190,250,121,13,107,239,163,238,121,237,108,6,172,239,127,240,111,254,209,12,34,245,136,235,235,239,132,4,144,233,56,240,97,250,142,13,57,236,201,237,189,254,100,12,77,238,9,243,180,252,148,15,174,231,251,235,240,247,160,11,213,243,61,243,5,250,58,15,236,237,187,238,208,244,248,10,49,238,83,244,142,242,232,7,17,249,121,238,112,253,173,9,152,245,183,248,164,248,241,15,220,248,241,245,202,240,50,13,215,230,163,241,23,248,141,6,211,239,148,247,89,251,146,13,62,237,169,249,65,249,112,8,158,234,71,245,61,250,194,9,176,241,224,251,73,248,187,9,192,237,10,244,69,247,117,11,147,239,184,232,223,244,237,5,125,236,180,233,53,249,13,7,228,236,64,232,71,237,104,3,82,239,180,239,89,239,137,8,177,237,66,250,167,244,255,3,210,230,103,236,177,240,232,3,98,232,94,234,153,240,214,7,116,232,90,241,143,240,3,3,185,232,26,238,96,236,56,3,70,233,240,245,55,247,46,5,229,233,31,235,161,251,196,9,238,242,197,239,94,2,189,10,208,233,37,237,59,246,46,7,207,231,17,246,241,250,72,3,41,229,195,236,72,242,9,7,27,234,4,249,153,248,11,3,174,240,176,233,220,237,254,1,119,237,227,240,75,238,99,0,88,244,213,236,113,254,217,5,55,7,34,254,245,11,76,233,98,17,164,251,25,14,86,230,67,12,99,0,191,11,100,234,30,10,58,241,66,12,94,237,89,7,180,4,146,22,180,242,47,14,12,8,190,21,82,236,133,13,169,7,47,20,40,241,131,11,17,1,184,17,219,238,101,17,62,249,156,22,238,238,192,15,13,7,106,10,74,238,159,13,80,252,9,9,116,232,33,5,34,0,114,16,29,240,0,22,34,250,193,22,33,233,56,30,221,253,15,19,156,234,42,19,24,250,152,18,128,233,3,15,191,1,67,4,162,236,166,11,145,251,66,21,222,238,251,13,15,1,215,11,142,229,92,15,45,255,80,18,125,234,59,17,184,6,83,9,48,234,3,21,33,254,223,17,120,231,29,14,150,254,220,7,235,236,160,14,35,248,141,17,47,236,61,22,109,0,27,17,222,242,99,21,147,253,197,20,111,240,11,25,95,253,76,22,112,237,69,19,228,252,94,28,62,239,244,10,188,1,132,24,185,241,24,16,251,253,190,23,77,238,255,19,73,3,158,13,186,240,130,18,3,6,197,13,102,244,222,19,114,1,7,23,248,233,139,16,156,10,237,17,76,236,107,14,170,2,55,24,164,237,223,23,198,253,127,24,128,230,51,10,253,4,172,14,62,237,43,17,202,3,223,14,9,233,105,20,251,8,170,12,19,239,24,20,242,6,82,19,87,234,173,11,56,244,175,12,137,234,167,11,152,3,23,8,85,232,150,20,121,252,82,17,210,246,15,25,183,253,130,15,30,242,26,15,59,255,96,20,188,244,183,14,238,250,46,26,13,243,155,24,60,10,164,20,88,229,254,25,134,2,69,14,193,236,162,18,231,11,40,20,113,231,244,20,178,1,103,11,169,235,182,11,64,5,193,18,104,246,56,15,245,3,189,14,184,248,67,8,143,2,183,11,56,231,50,20,43,252,33,11,144,238,175,10,145,247,157,10,112,233,126,9,96,248,40,17,49,238,255,23,100,251,75,14,118,237,114,19,53,250,190,6,245,236,158,13,177,246,234,12,51,239,154,5,164,250,75,16,94,237,26,13,189,245,245,5,27,236,134,26,82,9,155,15,235,232,195,5,142,245,123,13,148,239,207,7,90,242,109,14,76,234,156,18,224,244,40,11,43,234,163,241,11,20,11,11,138,244,228,244,166,27,36,11,4,242,194,240,34,25,22,16,137,248,23,249,106,29,164,13,43,242,111,248,47,22,65,254,153,251,104,246,72,18,100,16,153,246,38,245,49,32,162,6,64,239,196,244,216,23,62,20,173,246,14,245,173,28,111,17,134,244,255,251,123,24,144,18,127,243,211,246,37,21,249,7,46,241,52,247,33,32,40,11,83,239,71,250,103,19,112,19,60,246,132,253,141,29,189,13,119,239,143,248,242,21,64,15,130,244,210,254,160,26,15,13,12,243,94,247,60,16,1,11,73,242,51,253,168,25,71,7,121,244,223,240,50,22,116,8,193,253,194,244,203,22,184,1,219,245,100,243,21,30,50,10,46,246,232,241,184,34,49,13,92,246,234,245,245,37,215,9,202,243,138,235,58,24,50,11,241,244,156,242,202,28,240,11,177,254,111,249,132,34,186,4,38,248,52,243,68,26,132,4,166,240,130,252,213,31,59,3,22,251,107,244,183,33,245,9,216,250,135,240,246,26,253,13,55,0,154,248,65,30,214,6,183,252,203,252,188,26,82,3,92,253,160,253,36,27,252,255,160,250,103,2,124,25,65,4,133,251,100,244,36,22,67,4,23,254,99,255,41,18,88,11,99,254,161,2,1,20,218,5,190,255,122,254,14,23,75,6,11,255,211,246,102,21,164,18,216,250,88,0,142,26,180,7,189,248,67,251,0,20,175,11,200,0,213,246,152,23,23,11,120,1,190,253,88,23,36,13,252,248,145,250,240,22,186,11,59,252,204,253,144,17,106,15,94,251,5,247,242,24,63,12,128,247,173,247,9,22,219,7,199,4,252,252,175,22,100,4,127,3,235,244,102,26,249,8,28,253,237,243,154,24,135,5,178,247,155,239,148,23,51,7,50,244,215,255,59,25,92,0,88,1,63,247,204,26,47,8,212,238,117,248,176,27,69,8,169,247,185,246,70,17,152,6,159,243,50,249,18,26,2,6,137,255,46,237,69,30,96,16,215,249,44,248,40,22,193,0,82,254,15,241,154,23,80,8,150,248,172,251,97,31,71,8,59,244,190,246,77,21,185,6,10,1,222,249,222,27,102,2,178,245,17,250,48,34,175,13,22,239,254,247,5,15,91,11,154,251,221,19,60,17,177,254,125,248,34,14,143,5,155,253,84,240,129,17,145,14,77,2,233,237,174,16,144,12,29,249,160,243,145,16,4,7,91,249,20,245,179,18,34,9,25,254,201,241,99,11,101,13,147,253,111,237,55,20,124,6,15,251,105,243,184,16,217,15,84,253,17,240,116,19,67,17,81,250,97,245,60,21,160,9,131,1,155,239,155,17,178,15,97,4,14,243,132,23,97,9,99,254,127,243,104,16,205,14,179,254,3,245,109,20,189,9,86,251,170,248,219,22,135,10,20,254,12,247,111,22,216,12,71,253,59,251,60,22,52,10,211,3,77,247,221,19,19,8,22,4,66,251,91,12,192,8,206,247,149,242,108,20,106,7,145,0,163,246,228,22,136,15,94,254,200,244,120,23,71,13,3,4,78,242,30,16,243,7,73,7,131,252,255,20,12,14,255,1,198,246,145,7,213,5,172,252,134,255,145,13,241,18,35,2,213,245,23,18,161,11,117,4,24,249,5,24,234,11,185,255,162,248,229,15,1,17,223,254,107,250,68,11,201,4,148,250,109,1,109,21,214,9,21,255,197,253,192,4,23,17,163,5,142,1,124,19,34,12,107,0,101,250,159,17,241,10,51,1,68,254,163,12,34,17,71,1,92,253,7,8,124,14,121,6,207,254,207,22,70,9,34,1,151,250,246,19,233,12,144,7,146,239,16,25,104,11,82,1,80,245,22,13,8,11,11,251,215,240,232,18,23,7,208,1,186,0,95,9,4,13,238,0,214,4,188,13,83,5,46,6,176,2,254,13,82,7,154,0,94,237,189,12,62,11,118,3,27,1,37,15,98,10,185,254,116,3,55,16,108,13,125,8,149,244,8,14,90,14,1,5,241,250,209,17,146,14,166,251,45,249,243,17,41,14,210,253,193,253,17,10,44,9,219,8,120,0,122,20,227,12,32,0,172,242,168,16,53,14,197,2,240,246,156,25,242,13,186,252,88,246,113,22,174,15,84,252,75,248,253,21,123,17,221,1,0,243,149,20,127,12,146,6,243,243,80,17,112,9,121,4,29,243,113,17,201,9,114,8,118,247,35,18,77,19,168,255,187,244,216,17,111,20,40,2,181,240,35,22,3,12,130,250,109,244,42,21,139,20,253,252,254,244,0,255,61,225,255,1,41,254,235,248,221,224,88,254,116,254,206,254,162,228,94,3,26,1,254,246,234,230,96,250,252,1,11,255,125,229,119,1,156,255,227,250,79,232,236,255,11,3,136,249,97,232,127,253,27,5,40,250,134,230,196,3,214,2,13,247,68,230,54,255,27,3,6,253,158,226,174,5,210,253,34,247,164,228,190,252,188,253,141,251,90,228,3,1,106,1,25,246,112,226,240,251,49,0,54,241,144,227,166,3,36,254,248,242,32,231,94,2,32,4,238,241,244,228,52,0,202,2,26,247,106,230,138,6,204,0,217,244,123,233,162,3,250,5,183,244,99,227,41,255,49,1,67,245,64,232,19,255,172,5,39,252,245,229,41,6,144,1,12,248,61,232,124,1,243,4,227,247,220,226,124,1,226,255,17,249,249,227,4,6,126,254,7,244,241,228,221,3,168,0,236,244,78,226,117,0,192,242,222,251,4,231,81,2,250,243,180,252,82,232,231,3,20,255,67,243,217,228,211,5,48,253,118,247,220,222,75,0,249,250,190,244,180,225,200,1,2,254,248,248,33,229,192,3,97,251,6,246,183,227,78,6,62,250,208,245,71,235,136,1,83,3,99,244,94,230,165,252,90,3,176,245,155,232,7,4,96,254,47,252,82,223,193,2,102,250,67,251,15,227,179,255,146,250,201,250,255,229,77,8,133,255,16,246,50,229,60,7,31,253,93,243,234,230,216,6,153,255,236,250,123,226,171,3,164,254,108,242,101,226,202,0,147,255,78,246,84,230,241,2,107,2,6,246,56,224,120,253,83,254,12,252,66,225,253,255,91,254,236,241,153,231,32,0,226,243,50,250,153,227,221,7,3,252,190,253,113,229,245,253,149,1,231,244,196,232,108,6,143,3,149,246,207,226,60,4,28,254,66,247,111,232,38,1,221,251,125,242,186,230,55,255,234,252,21,248,135,232,41,7,37,3,103,250,145,224,251,5,38,249,70,243,52,225,251,2,114,250,248,249,240,228,39,253,222,1,246,246,33,223,74,0,83,241,127,243,204,233,95,0,90,247,137,246,10,222,213,2,209,241,39,242,97,228,138,4,250,248,218,254,66,218,147,1,30,247,14,247,172,234,172,4,146,1,189,249,199,229,135,3,197,246,25,16,187,9,186,243,78,246,148,17,233,12,169,241,225,249,85,23,100,12,188,250,234,253,222,18,51,13,243,249,131,2,94,20,98,15,175,245,2,247,31,18,218,18,100,234,177,252,7,22,171,10,134,247,61,252,196,23,159,13,59,242,190,250,83,23,82,12,114,247,244,246,242,21,1,19,241,228,116,0,225,20,240,13,33,227,197,2,53,21,214,19,29,241,12,250,48,27,245,7,69,242,184,251,180,27,227,9,51,238,180,253,173,23,151,16,237,233,34,254,243,17,100,14,213,236,197,252,73,29,141,12,24,244,88,254,108,23,89,8,230,243,47,249,54,24,79,20,81,247,30,247,232,26,35,11,48,245,117,249,226,23,114,16,244,246,70,252,215,27,146,16,31,244,128,250,238,23,84,14,19,250,109,250,101,24,241,23,127,239,94,251,160,26,141,12,203,247,60,252,225,20,156,20,173,245,177,252,192,25,57,18,14,239,228,1,90,26,167,14,141,242,124,0,77,21,188,7,78,245,46,10,54,18,131,8,126,239,221,251,195,21,136,12,30,242,174,0,136,20,95,17,233,248,55,250,24,21,10,10,70,251,235,0,144,27,245,9,142,245,62,1,222,17,244,16,180,244,126,255,59,24,235,17,55,243,207,254,239,19,133,7,101,245,167,247,65,15,200,16,92,249,247,0,69,17,253,17,29,243,43,3,39,22,249,4,226,240,100,252,110,21,13,7,219,236,133,0,37,25,18,10,220,248,150,255,154,21,133,20,62,236,199,4,208,18,233,7,65,251,163,5,129,13,197,13,104,246,145,12,244,12,35,10,172,251,155,9,252,11,226,14,97,247,134,7,207,24,60,21,186,230,88,2,180,24,144,16,11,235,112,9,243,18,166,18,21,240,86,7,36,19,95,14,178,235,54,4,155,32,49,14,43,238,85,255,124,20,86,22,243,240,173,0,120,15,164,13,133,244,57,8,182,23,145,13,209,246,161,0,36,32,218,11,224,242,123,252,94,27,145,15,108,248,122,248,211,27,73,18,51,239,146,252,2,20,1,16,197,248,63,254,56,24,12,8,53,247,25,4,194,27,4,15,215,227,65,10,196,27,42,13,178,229,21,2,203,26,33,11,104,240,80,5,82,21,230,8,75,243,107,4,208,251,195,247,175,18,207,251,193,254,212,245,161,16,142,246,162,9,20,5,148,13,198,254,31,11,34,250,176,20,115,255,131,6,7,251,183,21,91,245,61,11,182,242,34,25,204,0,53,0,179,245,155,20,99,251,67,4,89,247,171,22,243,249,93,9,102,252,231,16,158,4,219,0,93,241,39,18,228,249,227,255,111,245,204,18,253,4,219,5,208,245,16,22,127,5,91,8,161,246,106,16,231,10,86,254,240,247,152,21,151,0,0,10,13,245,35,24,10,245,185,17,81,246,213,14,71,4,120,3,227,242,221,20,97,254,108,17,234,248,12,21,53,251,80,15,60,243,220,24,65,253,15,13,166,237,58,17,16,3,53,1,151,248,162,24,199,4,190,3,10,243,158,16,161,243,157,255,60,6,130,23,65,248,83,254,171,252,7,25,110,3,146,4,214,250,146,24,95,254,240,8,7,254,159,24,49,248,240,12,118,249,93,26,66,246,97,254,183,242,113,18,141,254,67,255,70,251,236,18,46,248,120,3,210,239,25,17,130,0,165,9,227,238,22,21,68,246,63,11,160,244,230,19,218,245,51,253,151,253,18,22,83,253,190,5,233,240,232,20,108,249,95,15,160,255,239,14,38,253,185,14,82,254,96,12,182,2,252,9,129,1,211,13,0,2,77,0,121,250,247,19,95,10,164,10,146,247,59,26,202,252,40,7,233,3,9,21,148,248,132,3,150,8,112,17,209,253,185,1,69,0,33,23,49,249,119,251,226,2,76,26,204,254,1,1,243,7,251,15,224,2,71,6,8,5,3,17,233,255,243,255,36,5,84,16,136,6,231,5,56,5,241,11,155,5,141,8,27,241,178,17,171,3,48,14,62,253,86,10,95,5,170,16,79,241,145,16,53,4,29,12,85,254,153,20,78,251,245,8,20,1,202,18,199,254,102,13,197,248,29,12,253,7,125,13,93,244,22,20,174,3,147,6,47,243,194,18,210,7,114,15,149,237,235,21,66,2,248,4,101,255,221,19,198,1,128,0,62,255,231,19,129,5,52,3,112,3,165,22,158,245,185,251,144,2,142,22,71,4,45,3,123,249,224,16,77,243,137,255,6,2,228,24,117,253,106,11,53,239,227,23,147,252,109,16,79,239,164,15,82,10,69,251,204,240,224,0,55,12,222,255,237,238,41,5,14,9,77,0,74,231,177,4,60,3,155,15,65,241,166,7,161,12,178,0,27,243,193,7,246,12,26,9,39,241,9,4,123,12,133,5,96,234,58,3,173,6,164,9,85,242,69,14,47,14,229,2,247,237,187,6,216,7,222,4,29,244,162,11,109,15,169,254,44,239,210,8,141,8,86,253,224,237,198,1,224,8,212,4,35,237,187,9,106,6,0,254,74,241,158,4,236,11,119,0,157,240,128,14,203,3,135,251,240,237,80,5,233,8,101,0,118,237,50,11,231,4,36,250,177,234,27,2,101,6,55,252,235,232,134,5,104,4,19,251,181,236,25,255,230,7,30,255,31,235,183,4,193,2,152,10,11,236,133,12,74,7,36,254,231,232,17,1,184,4,9,248,144,238,112,2,241,9,209,246,166,240,227,7,113,10,141,245,15,237,242,5,198,7,12,250,123,242,166,5,132,12,221,1,62,235,174,6,41,6,144,2,111,241,42,9,207,9,38,2,227,232,183,7,16,4,192,6,160,237,251,11,34,4,247,255,129,235,250,1,224,6,194,253,241,235,139,6,136,6,81,8,59,241,116,13,9,9,120,4,169,238,166,8,225,9,12,5,192,239,113,12,41,7,141,9,66,243,230,9,155,12,218,8,207,238,231,7,96,9,181,253,238,241,80,13,19,8,139,252,169,236,156,12,150,4,40,253,105,245,247,10,224,13,251,3,29,244,123,12,138,11,96,7,249,237,116,4,150,9,148,2,16,234,242,2,32,3,73,248,5,235,113,6,49,6,248,249,196,234,118,9,57,4,90,254,6,233,86,9,238,2,56,5,75,234,137,9,206,4,136,0,95,240,11,1,38,11,246,253,39,243,178,8,168,10,53,252,28,238,167,9,196,2,192,2,70,235,228,12,233,3,69,1,120,242,227,13,94,9,26,3,154,241,80,3,97,12,148,2,55,244,232,17,170,12,50,250,118,240,122,8,108,6,177,249,214,237,128,10,52,7,238,2,30,238,26,2,191,8,132,6,39,233,175,5,7,4,158,13,183,237,238,7,135,8,82,10,203,234,160,6,225,6,139,17,106,238,210,13,207,10,217,13,80,238,186,13,166,11,197,12,164,241,198,10,126,15,196,21,122,4,209,0,205,242,35,29,29,4,81,2,152,248,128,17,200,0,202,254,93,239,201,21,85,252,242,0,104,240,206,31,186,1,233,4,245,243,66,21,237,4,144,5,92,243,116,24,73,255,53,12,28,246,11,28,121,3,82,6,12,246,16,25,164,3,75,9,73,246,182,27,0,10,193,3,192,242,154,28,207,1,172,10,105,241,232,25,41,6,120,7,56,243,168,24,69,5,212,11,124,242,217,23,130,1,189,4,47,252,102,21,134,4,90,4,26,254,93,25,154,1,150,6,124,247,234,24,89,7,53,5,64,247,79,22,44,3,166,7,236,250,188,26,109,3,218,2,91,251,168,26,11,255,201,8,48,248,91,29,241,5,227,4,14,244,41,26,27,4,20,5,43,249,76,25,145,5,43,3,43,245,182,28,209,1,180,255,223,244,63,27,47,8,55,2,68,246,83,18,200,6,100,10,15,247,157,30,176,5,84,1,49,245,250,30,251,1,70,3,230,247,218,23,222,5,254,2,170,251,27,19,109,253,67,3,142,240,82,28,141,0,89,5,13,250,227,29,67,0,115,6,6,247,196,28,207,254,89,2,196,243,11,28,193,0,187,9,201,244,104,25,240,254,119,8,214,250,104,17,215,3,252,8,91,254,209,18,201,1,159,6,115,1,2,27,43,2,82,3,169,243,16,23,6,4,202,0,89,248,114,24,112,3,185,8,105,238,141,23,10,0,82,8,240,241,49,25,217,3,105,4,133,240,216,25,238,255,145,255,43,243,144,17,7,3,49,3,76,239,246,23,34,9,190,5,99,244,255,26,152,0,174,1,102,248,213,15,223,3,146,12,87,251,59,21,5,5,52,12,148,246,131,21,44,7,143,7,60,248,120,20,177,2,141,8,146,245,238,25,183,6,94,2,249,248,180,21,76,255,129,0,221,245,12,22,126,7,1,5,36,239,10,25,64,4,230,254,211,243,103,25,49,7,56,1,70,242,35,27,20,0,78,5,210,240,88,21,61,8,94,9,134,243,240,21,105,254,92,8,14,254,233,23,147,10,75,9,0,240,135,28,54,7,218,8,1,240,68,21,214,1,158,10,239,249,185,22,123,253,213,12,187,250,249,21,147,5,79,4,57,248,153,23,218,252,172,4,129,244,234,11,166,233,230,15,172,234,92,13,222,238,238,15,221,235,132,23,114,240,100,28,127,245,78,29,35,239,214,30,123,240,60,16,26,242,127,20,36,239,117,18,207,238,122,28,252,249,32,26,254,235,24,32,118,243,216,35,80,230,60,36,157,236,2,34,180,233,51,31,243,237,148,27,49,242,132,25,20,243,224,21,97,245,243,20,224,249,53,18,13,245,119,24,148,237,89,14,204,241,3,24,151,242,185,20,231,245,185,23,178,245,190,29,86,248,191,23,110,235,104,26,218,242,214,28,30,239,241,24,213,240,189,18,183,250,246,31,0,236,202,16,223,237,170,35,202,231,111,19,9,244,253,28,196,234,200,21,127,241,155,13,222,236,67,21,71,245,43,19,245,233,246,24,247,239,183,31,160,228,56,31,148,229,128,25,22,232,55,27,42,234,2,23,162,239,224,25,200,233,159,26,2,225,107,28,176,234,58,21,46,239,49,20,254,234,12,17,220,230,0,21,212,245,216,31,180,242,25,23,72,236,47,31,1,237,166,16,99,246,87,31,212,231,94,24,58,236,97,26,148,241,95,15,117,241,170,26,104,237,212,12,45,240,56,28,1,227,140,17,221,240,248,26,226,245,187,25,152,231,218,23,104,248,177,28,126,234,92,19,82,244,128,30,182,243,252,26,27,229,61,23,248,250,250,27,86,232,91,13,183,242,103,27,88,228,251,26,54,244,59,27,80,229,14,22,55,243,78,31,86,234,95,21,248,249,136,26,84,247,241,19,193,244,46,33,122,240,56,17,97,240,119,37,254,236,139,23,50,238,144,20,215,235,213,23,30,253,171,22,3,232,77,20,145,235,49,18,90,229,160,12,187,235,183,18,241,235,225,14,199,237,220,23,17,236,75,9,223,240,72,18,187,240,162,12,27,236,170,22,243,240,211,14,136,236,8,17,197,226,194,18,219,240,53,21,163,226,23,23,123,241,210,26,24,247,16,19,230,237,147,39,236,237,62,17,4,240,59,42,187,235,66,30,39,235,31,22,19,221,167,20,208,233,87,31,153,232,235,28,20,245,197,37,249,228,125,25,188,236,107,28,44,241,98,19,13,246,144,34,58,237,45,22,248,243,192,31,44,239,69,30,87,230,192,15,180,235,234,8,161,231,193,25,188,2,27,255,48,1,68,32,27,2,190,255,21,251,205,25,176,0,210,252,147,255,121,31,0,0,255,255,120,255,214,28,218,255,28,254,151,251,181,32,95,252,170,2,58,254,250,29,178,2,2,251,34,2,158,28,251,253,150,1,253,250,188,29,77,249,113,251,151,4,142,33,185,1,242,252,58,253,124,33,78,251,221,254,4,1,140,28,109,255,7,249,158,1,131,26,159,254,96,253,166,3,57,20,123,255,179,0,82,0,65,16,222,255,191,1,217,5,109,23,122,252,253,5,135,255,95,22,153,252,166,250,177,3,194,32,4,255,37,1,201,252,173,25,182,250,170,2,104,2,226,29,208,247,213,2,201,1,186,31,78,0,124,2,136,250,229,32,172,1,172,249,131,0,173,28,244,250,51,253,186,0,62,31,207,255,48,253,10,1,99,23,161,254,157,2,76,3,146,28,172,249,250,0,165,253,51,28,230,249,196,253,202,7,234,33,154,254,222,254,124,254,178,22,155,0,78,255,175,4,78,28,244,255,18,4,238,252,189,28,101,252,188,5,37,254,121,30,109,2,44,255,44,253,226,20,254,253,186,4,76,5,11,33,36,0,129,255,245,252,222,26,131,246,86,3,214,6,112,28,135,250,183,250,29,11,155,29,156,247,73,250,39,8,237,25,178,3,152,252,238,2,199,18,180,251,9,5,42,10,143,17,219,0,15,6,104,4,215,29,250,1,190,1,173,251,215,24,188,0,241,3,141,255,241,25,228,248,119,6,211,2,18,21,178,246,68,6,238,9,133,23,172,245,92,9,127,5,90,18,114,3,245,0,245,5,167,31,61,2,226,252,163,254,109,31,249,253,229,3,188,251,147,29,134,255,227,0,174,254,227,20,80,251,118,2,182,6,158,27,22,3,218,0,224,253,16,29,216,2,241,253,236,255,2,25,157,254,197,0,32,253,191,15,3,3,98,3,103,7,121,23,128,3,189,1,225,255,40,20,74,4,168,252,248,6,44,31,138,252,243,250,116,5,174,24,175,250,119,9,252,0,123,29,69,253,133,0,250,1,114,33,216,246,172,3,8,1,2,23,163,4,111,250,146,8,158,25,123,253,225,250,61,10,26,18,121,249,27,8,87,6,238,21,105,0,208,252,72,9,246,25,22,6,171,250,118,2,86,27,126,4,187,247,34,252,155,25,7,9,187,251,9,249,26,26,150,5,169,246,108,248,181,30,19,6,95,244,92,251,89,26,187,6,53,254,219,247,80,29,205,4,126,249,244,247,1,31,159,2,176,247,7,250,227,27,223,3,33,253,184,245,211,26,56,6,233,250,236,246,1,25,182,8,60,249,52,246,33,28,136,8,135,247,60,248,236,25,142,8,29,252,232,244,196,29,2,9,215,247,117,253,160,29,83,7,98,250,137,253,254,35,25,6,96,246,141,251,10,24,38,5,43,251,155,244,237,30,31,11,251,248,193,249,117,32,237,7,5,246,47,254,12,32,2,5,184,253,155,246,248,32,11,4,133,251,143,251,195,27,66,7,196,255,224,249,125,26,96,11,151,252,73,250,179,29,36,5,193,254,31,251,153,30,55,5,178,255,199,248,250,30,117,4,8,252,73,253,203,30,74,6,7,252,222,250,133,31,129,5,237,248,60,255,127,32,7,4,186,253,202,249,60,23,1,6,151,247,187,246,236,33,147,4,177,248,174,252,165,32,180,9,149,246,244,250,116,25,44,8,63,255,113,251,224,23,161,6,22,0,243,253,249,27,191,2,166,253,169,248,159,23,47,9,217,252,37,255,136,31,62,7,231,248,239,249,44,27,24,5,76,0,13,252,207,25,201,5,224,253,94,255,46,27,237,9,247,254,110,248,16,25,210,9,247,252,174,252,104,28,62,8,125,252,109,251,61,30,105,8,229,254,202,245,82,25,249,7,34,249,59,251,106,26,172,3,186,248,23,247,234,21,170,4,101,249,231,249,153,30,116,8,201,252,96,248,84,21,158,5,176,252,165,4,123,23,97,5,253,252,235,249,255,29,32,2,146,251,90,247,41,28,12,5,102,245,228,249,191,21,176,4,108,254,87,255,221,22,181,5,71,250,250,253,126,26,177,2,180,252,164,252,162,28,57,5,128,251,185,255,21,28,226,5,115,253,83,253,204,26,68,8,133,250,16,255,100,34,236,5,145,250,32,249,42,28,129,10,38,250,35,252,118,27,206,11,95,250,221,247,17,22,44,7,105,254,13,2,27,29,27,12,51,253,96,246,216,28,120,6,41,248,142,1,104,25,195,2,129,248,122,255,197,248,55,14,25,247,73,253,59,240,108,6,179,255,49,5,71,240,168,7,227,249,201,253,154,242,191,9,229,252,112,1,93,237,176,9,225,3,244,2,153,242,10,8,21,246,53,252,38,241,90,13,124,1,217,0,254,243,22,13,140,249,224,251,135,241,70,1,142,249,255,5,206,243,1,5,88,251,71,6,7,238,87,5,56,252,53,0,32,241,190,3,44,0,0,10,225,247,226,9,51,250,142,4,133,241,87,1,183,244,180,0,127,235,151,5,225,255,176,2,130,236,125,0,64,253,246,4,45,245,54,5,114,246,234,2,12,247,226,3,9,250,70,10,19,251,254,11,41,246,12,1,16,246,50,15,223,251,216,253,187,238,255,0,68,248,18,2,121,244,198,1,243,255,59,14,42,247,23,7,142,254,64,11,177,246,73,14,119,253,64,2,43,242,95,255,147,250,246,9,111,239,39,6,45,5,1,10,49,245,197,15,197,4,42,6,92,241,137,10,124,4,9,7,178,237,81,9,36,255,0,0,5,250,109,6,65,245,47,5,211,255,192,15,225,252,250,8,157,244,232,8,197,2,191,9,81,251,206,12,106,254,42,9,89,246,116,0,110,245,12,8,120,246,125,8,178,244,168,254,209,242,239,8,245,6,154,12,151,247,240,13,35,7,102,11,162,252,219,8,166,249,223,9,118,245,111,4,45,1,143,16,196,246,75,8,242,3,126,14,113,246,209,12,175,255,128,5,156,245,127,18,216,1,2,1,227,251,25,12,122,10,94,9,218,242,243,251,128,251,156,252,125,253,146,16,164,8,235,4,203,3,151,15,166,3,131,2,175,249,210,7,91,8,147,8,223,236,204,3,16,3,183,6,5,251,176,11,15,4,237,14,120,254,109,19,47,255,29,7,252,251,110,18,57,250,119,255,50,0,74,15,41,2,162,8,166,2,12,17,103,1,23,5,186,253,47,19,2,2,135,6,252,4,74,15,28,251,118,11,40,250,144,15,89,3,26,9,4,3,136,18,113,253,28,9,225,252,163,20,73,254,112,2,61,5,121,11,138,2,235,7,53,249,28,19,251,4,166,6,132,252,36,10,105,255,111,15,52,242,66,4,12,5,32,0,65,1,74,12,87,10,195,5,8,1,103,16,201,249,37,5], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2044064);
/* memory initializer */ allocate([60,254,203,246,218,8,96,16,206,11,247,251,171,246,46,22,118,251,194,250,215,13,126,19,38,254,59,250,57,251,152,19,69,253,215,244,132,3,251,14,51,254,49,247,139,255,18,18,180,4,242,247,69,251,51,17,144,8,37,244,175,254,126,15,108,0,193,252,23,1,11,22,177,5,148,253,164,244,156,20,33,246,178,255,61,4,84,21,70,248,130,248,75,252,125,18,32,0,111,1,144,248,46,20,98,7,127,249,184,1,144,18,250,253,164,254,0,11,27,19,111,14,70,246,162,250,251,17,246,0,83,248,221,13,129,15,76,4,217,243,144,2,153,14,157,250,102,3,98,254,223,17,116,2,155,254,53,251,35,24,151,251,218,250,103,246,224,17,87,254,158,255,183,255,192,24,111,1,137,252,174,11,111,16,43,8,29,251,140,9,229,13,33,249,182,249,254,7,153,20,138,12,134,5,236,255,56,10,231,12,180,245,237,3,141,16,185,254,221,243,128,253,103,14,59,255,252,2,60,2,110,21,134,2,1,253,108,5,88,21,104,0,182,10,28,255,67,15,20,255,37,7,189,253,233,17,154,247,38,254,11,250,166,15,233,255,184,245,160,246,52,15,244,255,53,249,162,244,3,19,250,246,144,254,154,255,231,17,57,248,243,247,21,2,179,17,44,15,90,250,103,255,41,17,32,6,14,0,223,254,148,20,160,250,3,255,19,245,89,13,121,12,239,245,171,9,238,13,90,13,105,2,70,5,65,7,208,14,232,255,240,254,42,13,153,0,135,4,90,11,61,11,255,1,114,8,12,6,181,10,6,1,51,3,25,245,150,14,136,16,33,248,206,5,149,13,127,11,170,251,10,252,104,21,26,11,113,1,191,2,148,13,195,11,98,6,91,252,225,13,60,17,244,249,82,252,157,19,131,250,81,2,68,9,147,20,45,8,81,8,128,3,61,9,237,18,68,248,0,0,239,14,164,247,81,0,206,12,5,22,204,5,105,10,188,254,69,14,10,0,192,0,84,6,171,20,104,8,226,2,35,247,136,19,54,8,188,10,140,249,99,18,39,11,173,247,125,254,68,20,149,4,164,2,58,5,205,12,36,9,231,246,240,247,255,15,93,3,24,248,16,5,191,19,141,8,153,12,73,253,66,10,52,24,89,228,151,7,202,252,195,17,51,237,189,12,64,7,147,16,8,229,115,13,192,1,229,17,177,226,178,3,250,1,226,25,182,225,99,13,214,1,79,13,128,220,197,12,40,250,239,15,192,230,0,9,9,3,245,21,136,219,124,10,0,253,231,20,192,230,118,20,42,255,73,23,185,224,188,6,237,243,117,16,125,224,91,2,10,255,40,28,21,227,96,12,54,249,210,23,236,225,73,1,157,250,125,25,177,229,152,16,208,251,185,23,159,231,119,8,182,246,1,18,254,219,235,11,247,251,157,26,141,227,45,6,151,248,238,23,125,231,229,10,169,2,71,17,118,230,85,6,100,249,128,24,150,223,95,12,193,248,28,24,146,222,146,17,111,251,236,18,116,222,111,6,146,254,65,24,153,221,45,6,143,254,13,21,133,224,38,2,64,255,254,25,209,217,200,9,217,251,191,27,194,224,38,3,18,2,30,22,176,229,29,6,220,241,69,16,164,218,95,16,173,247,174,17,243,227,64,2,197,244,25,18,81,222,247,10,122,237,125,14,142,225,23,7,34,0,50,14,82,222,9,9,198,252,79,27,1,223,15,8,130,243,77,30,242,218,207,8,210,253,53,16,158,225,120,18,96,249,135,22,253,226,89,4,195,2,240,17,139,231,25,9,72,7,87,12,254,214,141,6,79,239,206,13,206,220,133,9,19,242,127,17,187,213,155,10,178,236,135,12,179,217,238,11,210,240,19,18,3,224,202,11,206,246,151,21,186,214,172,12,67,245,250,16,113,216,7,13,244,243,244,23,155,216,244,12,228,250,253,21,24,218,130,8,14,244,19,14,166,222,222,4,144,253,153,14,216,222,139,1,161,243,89,21,106,211,250,10,224,237,186,20,191,225,161,10,108,240,88,27,105,220,159,6,127,250,7,26,195,225,162,9,17,240,243,15,249,227,44,7,33,237,29,14,58,217,62,5,129,242,188,25,159,224,201,1,254,254,112,18,90,224,17,0,71,251,246,28,251,221,14,5,168,254,61,21,210,216,203,15,88,249,254,18,191,219,22,6,105,250,144,26,253,230,249,19,94,3,15,18,206,223,107,10,28,255,31,23,37,236,20,13,87,8,97,23,71,221,173,10,15,236,165,19,121,233,55,17,207,2,98,1,242,231,186,252,71,244,95,1,201,232,200,247,2,250,135,253,234,227,231,255,66,237,197,249,189,227,28,241,136,250,103,0,203,231,139,244,178,255,70,249,100,236,143,242,19,239,85,248,244,233,243,238,242,254,178,252,145,233,107,242,196,0,65,255,28,235,42,240,43,254,45,246,182,225,89,242,206,252,214,247,202,229,115,245,117,0,222,253,132,228,138,250,163,0,234,254,77,228,154,245,232,253,146,253,230,224,85,245,72,250,237,249,74,224,228,241,247,247,186,251,120,231,246,246,249,1,4,246,166,222,72,240,57,247,109,0,34,228,221,243,225,248,124,252,214,228,244,242,51,253,163,253,55,228,184,241,150,247,69,3,137,231,117,243,127,247,95,254,78,233,225,240,67,250,218,250,239,233,145,239,130,243,157,1,147,229,222,247,223,255,227,243,206,230,246,238,2,253,243,2,167,230,105,244,178,252,93,4,62,228,108,246,184,250,78,251,61,223,0,244,175,244,147,254,226,236,23,242,135,244,188,246,184,221,247,254,167,238,56,251,26,222,128,252,46,236,13,253,144,216,168,253,33,230,44,1,242,223,31,255,40,238,104,251,88,229,183,245,57,242,42,248,189,234,10,250,39,233,165,251,92,234,197,246,79,237,35,4,100,229,17,246,162,245,72,248,51,229,10,244,124,234,133,254,48,235,239,246,216,241,196,247,28,233,90,238,133,248,133,254,51,225,207,250,174,253,6,3,243,234,187,253,163,235,215,245,37,236,199,248,199,236,80,255,52,234,74,0,45,236,52,255,132,229,66,255,168,231,162,1,86,226,61,248,204,252,175,248,175,222,146,244,183,249,60,5,38,231,105,252,145,236,65,2,202,224,4,248,175,248,244,245,11,227,47,249,80,247,11,248,138,228,75,250,30,228,1,246,204,221,9,248,52,233,225,247,148,229,71,251,219,233,179,249,135,225,42,248,83,253,183,248,73,230,46,253,55,242,179,253,42,231,159,250,21,252,228,253,166,226,205,250,42,242,163,1,208,231,115,249,193,236,30,245,197,221,106,244,55,236,132,247,37,223,66,249,189,237,202,242,151,217,87,242,166,233,127,246,71,216,227,247,113,233,88,254,21,219,184,251,182,241,231,253,182,222,114,252,151,248,82,234,247,10,147,6,75,253,5,231,123,2,245,13,34,251,136,226,232,8,92,8,44,0,209,221,112,4,135,11,230,252,27,234,149,10,4,8,148,3,30,226,142,2,101,3,135,0,229,228,199,3,129,5,102,3,102,225,75,8,238,12,206,3,233,228,2,11,250,4,114,249,27,234,185,8,245,3,215,1,73,228,57,7,112,6,198,0,20,230,98,6,200,2,219,255,145,227,210,3,40,1,197,254,16,226,176,13,220,12,40,255,100,225,185,4,197,4,255,254,23,225,153,8,229,6,7,250,91,228,199,14,72,10,129,250,67,234,109,6,130,5,146,253,162,230,63,11,157,4,9,253,95,228,65,12,194,11,38,2,175,227,47,7,79,3,219,252,26,230,149,8,26,1,184,251,124,221,37,6,196,7,190,251,127,225,250,4,68,3,82,251,41,225,154,11,183,13,183,251,208,228,128,6,76,5,118,246,74,230,50,11,225,8,51,1,203,227,53,3,35,11,101,250,129,232,167,6,209,7,193,246,110,224,10,4,55,8,239,0,192,232,120,7,45,1,47,254,45,232,73,3,123,1,55,2,57,231,50,0,238,1,146,2,70,230,215,3,79,2,131,252,132,234,101,3,139,8,81,246,174,230,60,0,9,6,45,252,207,229,3,2,182,7,203,255,196,230,219,6,45,5,5,251,51,232,57,10,161,9,145,253,94,227,113,8,82,2,189,247,100,227,250,2,57,6,44,248,15,231,167,2,230,5,46,246,241,231,241,0,160,11,161,249,121,222,214,11,205,15,94,255,101,231,66,0,161,8,201,247,204,234,255,4,195,12,202,248,218,230,55,5,168,10,161,249,180,224,46,4,124,9,129,251,199,231,221,10,45,9,130,248,226,232,115,4,49,12,108,255,86,231,177,9,65,12,240,248,244,227,186,6,131,9,190,249,162,229,37,7,179,14,135,251,199,229,241,6,173,8,188,4,201,226,43,7,43,14,33,254,125,227,10,0,102,9,199,249,199,223,57,12,228,3,202,244,74,223,254,5,53,5,166,248,173,226,25,13,62,6,5,247,45,227,141,10,22,9,113,251,8,223,228,8,236,10,226,253,148,215,247,5,89,10,115,251,8,224,30,14,14,10,54,249,93,234,38,6,197,6,114,4,188,36,28,226,67,0,79,0,206,33,124,240,78,5,196,255,169,33,70,237,117,0,14,9,206,30,103,238,248,6,176,4,188,33,19,232,39,15,21,252,182,37,76,229,24,7,205,0,158,36,103,230,145,3,83,7,84,31,250,231,110,4,86,9,106,30,150,236,30,8,191,248,243,33,25,232,199,2,196,2,79,35,64,234,128,11,146,248,227,38,72,236,153,5,167,253,153,31,241,228,21,12,226,244,39,33,144,228,111,9,19,0,172,36,89,235,249,13,161,245,143,33,53,227,252,8,28,252,144,35,101,237,173,5,2,246,191,29,175,234,84,2,164,0,132,38,121,228,105,13,154,253,52,34,204,238,187,8,60,252,246,36,204,237,43,1,226,248,135,39,82,234,129,10,7,251,163,42,209,226,145,10,17,252,169,44,78,228,130,5,82,251,154,38,249,226,149,11,153,248,204,29,157,235,1,3,155,245,233,31,58,235,214,8,70,0,142,34,80,231,147,7,14,253,235,27,39,234,224,4,53,252,156,41,147,234,167,3,137,0,98,30,123,230,4,10,116,248,174,34,203,235,190,4,151,254,100,38,177,236,26,1,254,1,58,39,10,232,55,15,134,248,29,31,26,230,238,13,79,254,125,33,106,238,246,13,71,251,206,32,63,237,7,4,189,250,152,39,164,225,52,10,11,6,162,38,144,227,232,6,197,251,215,32,71,230,62,253,198,255,40,31,98,226,229,0,125,255,241,40,94,221,142,4,109,255,162,42,10,239,117,12,148,246,200,40,178,235,152,255,171,251,219,43,126,230,77,9,111,246,39,33,128,224,62,4,230,0,247,38,21,232,167,252,122,255,147,32,158,230,208,4,223,246,34,43,102,238,95,4,206,247,19,49,40,234,45,7,242,247,25,46,42,234,120,2,240,250,168,39,15,234,231,5,131,248,120,30,183,230,51,0,199,250,5,31,72,234,134,9,58,243,154,25,6,241,52,8,196,5,105,35,112,234,30,255,160,251,42,42,48,228,13,255,122,0,189,40,200,228,16,1,218,252,238,34,46,221,162,5,120,254,241,38,69,236,241,7,119,244,107,28,200,239,242,11,192,255,119,43,144,234,237,17,101,243,154,37,246,229,179,10,114,244,31,27,14,235,118,17,240,3,224,226,57,252,120,11,22,252,82,222,179,254,50,27,46,10,194,226,192,242,84,14,7,5,139,224,197,252,28,20,73,4,46,230,198,1,88,19,96,0,235,225,66,248,89,12,44,254,117,227,148,251,231,15,220,255,67,224,241,254,79,20,22,15,34,220,98,248,253,10,86,7,129,217,72,252,186,18,194,11,183,227,151,5,106,16,164,9,82,218,157,0,158,18,22,4,101,219,206,4,121,23,142,11,6,211,192,255,182,33,128,20,146,229,53,2,206,10,92,8,22,223,247,255,36,11,247,4,229,211,167,251,223,19,121,11,151,223,44,8,143,17,240,4,1,217,223,2,225,14,205,255,168,220,24,252,119,12,204,254,93,227,61,248,95,10,111,5,24,228,235,255,237,16,113,8,112,232,252,249,215,13,128,3,205,224,244,251,193,7,249,5,208,219,212,7,74,20,34,1,212,211,184,252,122,22,118,6,86,220,162,246,196,16,157,11,152,231,70,3,235,13,199,4,93,229,56,245,183,13,119,0,211,227,42,248,12,17,250,2,201,234,233,251,181,17,166,0,70,228,127,253,229,7,127,2,76,222,55,247,4,14,143,1,48,231,38,250,232,13,120,253,135,228,114,247,6,19,2,10,19,227,210,255,188,14,187,253,40,232,28,3,23,20,173,7,101,233,175,3,152,22,214,11,81,223,185,5,24,28,1,16,189,223,21,3,62,22,171,7,138,214,149,248,116,22,85,10,190,223,219,252,114,14,227,8,35,229,52,252,31,25,88,12,173,230,107,1,106,27,57,12,117,231,178,250,71,20,244,5,107,221,171,243,23,16,205,6,58,232,245,254,43,15,189,252,170,227,8,4,213,25,177,15,50,211,234,242,41,18,98,13,169,229,225,1,4,24,215,4,238,234,90,255,189,20,93,12,234,224,44,4,172,16,16,255,232,214,208,8,236,30,12,11,244,235,252,255,107,22,152,4,61,222,120,0,183,12,139,253,97,218,182,7,166,34,10,17,89,214,59,251,149,14,77,2,224,223,205,248,174,22,95,10,166,223,231,4,199,33,150,13,233,207,31,250,83,35,112,24,208,211,168,252,224,27,73,18,88,209,46,253,5,31,237,12,68,225,49,254,190,26,100,16,25,222,15,255,242,28,227,20,103,26,184,237,4,254,196,4,56,20,33,232,176,3,121,0,187,26,221,233,168,250,235,253,240,21,4,233,65,250,73,253,142,23,31,236,240,248,84,252,20,29,169,234,204,255,89,7,111,16,65,232,6,254,35,6,129,26,198,238,119,253,12,12,230,18,162,235,234,7,182,11,105,16,98,233,133,2,19,7,18,27,247,235,108,248,162,6,188,24,237,237,180,2,211,11,141,24,38,239,150,255,60,14,111,24,182,234,73,248,230,2,103,16,188,237,53,254,4,7,216,21,132,234,65,5,20,5,6,17,76,234,68,247,114,0,12,18,13,233,229,249,120,3,28,19,130,226,185,254,93,254,126,18,83,228,7,0,101,2,43,15,70,234,79,248,56,4,234,21,130,236,52,255,66,3,21,16,174,230,9,251,85,1,185,25,13,236,124,3,145,4,232,25,157,241,46,1,186,11,182,24,25,235,41,252,30,251,30,17,232,227,38,253,98,255,107,20,116,230,61,254,99,4,92,21,184,230,154,252,65,250,71,20,254,230,171,250,129,255,239,28,83,231,51,252,176,254,3,18,126,230,204,252,68,248,99,19,217,235,254,247,58,252,62,17,197,233,45,255,26,252,66,23,15,233,238,2,43,249,42,17,68,237,12,251,254,0,249,27,186,231,14,252,177,2,101,19,242,241,68,9,175,6,104,24,220,231,213,3,96,3,73,25,40,235,13,2,168,253,239,17,48,229,149,251,124,252,170,24,216,230,3,252,137,254,206,22,191,231,81,251,176,3,188,20,93,235,204,247,243,4,246,16,28,233,155,249,180,250,48,22,220,238,53,251,152,255,36,19,254,239,169,5,206,15,69,18,68,239,150,255,118,12,150,29,227,231,176,252,67,7,93,25,217,227,125,255,214,2,137,21,115,235,187,247,4,0,47,24,72,227,63,255,7,254,253,22,19,239,68,1,122,255,18,24,63,232,200,254,4,248,120,16,200,231,238,248,196,253,20,22,133,228,72,253,59,255,219,27,235,227,146,254,196,255,168,19,61,237,22,250,16,11,218,28,254,237,162,253,161,13,115,16,89,236,197,4,231,11,210,15,211,237,48,6,189,5,196,26,74,235,187,248,206,0,56,30,48,237,254,248,31,13,146,24,145,242,242,5,150,9,232,6,102,23,72,234,222,245,63,15,206,20,6,250,35,250,168,9,154,14,187,247,112,239,188,12,72,21,120,252,131,237,155,5,129,28,164,241,250,239,0,16,63,23,112,253,16,243,130,8,121,23,182,243,116,241,203,14,117,21,159,234,159,249,182,11,118,28,250,242,13,242,78,11,176,25,156,237,12,245,62,3,19,24,66,239,236,242,147,18,193,21,62,249,77,245,252,17,177,23,22,242,211,245,189,10,21,20,110,240,41,245,102,15,11,19,161,247,244,242,3,11,69,33,44,248,92,245,98,8,154,24,79,253,235,243,76,20,104,25,191,242,61,250,59,7,194,32,44,249,116,250,146,13,124,33,50,242,128,245,151,17,136,29,23,242,59,247,81,17,75,24,167,246,217,249,178,13,80,28,29,247,71,248,162,13,241,28,181,243,164,253,118,16,47,25,64,242,4,2,107,2,122,27,195,252,87,249,196,6,227,28,156,254,96,247,202,4,84,20,34,243,108,241,235,7,243,21,235,248,206,239,6,12,245,22,47,0,165,245,118,6,82,21,168,1,86,253,91,12,88,21,22,248,242,254,68,11,255,20,83,253,238,253,134,11,118,28,221,255,105,244,194,7,202,19,171,253,226,1,131,13,212,16,251,240,227,246,83,12,125,27,190,250,7,239,145,8,40,26,51,253,217,250,93,14,225,19,204,240,25,254,138,8,16,20,166,239,44,250,5,3,164,22,107,252,49,3,185,9,146,25,14,242,187,247,199,4,69,25,174,250,223,255,15,1,173,23,70,250,67,249,236,9,51,20,201,248,8,4,244,9,131,20,119,245,141,6,3,3,176,29,0,253,136,253,102,18,247,25,128,237,5,251,89,5,29,23,101,244,224,251,163,0,119,20,85,242,29,247,56,8,189,16,117,243,42,243,83,4,243,28,76,248,121,249,148,8,94,28,250,246,122,248,12,255,39,25,47,249,185,252,221,12,248,14,182,244,72,244,163,1,43,25,133,254,105,254,5,12,66,19,124,251,203,244,83,8,242,22,230,246,224,0,178,2,138,25,92,247,231,244,66,6,69,17,45,246,6,6,246,12,157,36,40,244,107,242,14,22,38,29,223,235,73,250,43,16,225,27,253,249,7,243,153,13,117,35,147,249,187,241,189,225,119,1,150,255,225,253,117,222,157,250,182,253,51,254,94,216,132,252,46,8,182,2,89,224,126,1,248,1,187,254,156,222,164,255,94,0,112,253,220,226,38,0,152,0,132,1,182,223,241,254,53,254,141,252,1,225,104,253,254,251,222,252,107,223,147,255,85,3,161,0,158,221,181,250,75,4,118,2,3,221,250,255,84,4,99,253,164,227,16,250,213,255,105,254,125,226,82,255,156,2,254,245,202,220,130,255,227,0,89,251,8,224,1,3,34,1,161,250,252,218,55,0,194,3,8,250,25,222,29,2,243,2,250,251,142,217,166,249,70,3,204,249,191,222,66,253,20,3,50,248,139,216,234,249,146,254,207,248,57,224,78,0,199,5,235,248,88,220,58,254,57,1,6,249,126,226,196,251,63,3,118,246,104,226,67,253,20,8,127,249,145,225,55,250,51,6,240,248,211,229,172,253,159,255,34,3,6,227,241,255,172,2,61,252,41,228,35,254,117,255,86,254,95,224,146,255,220,255,248,254,60,226,126,248,178,253,155,255,33,226,79,251,23,1,148,2,80,225,74,248,246,2,33,247,208,222,89,255,184,8,137,251,198,222,177,250,112,2,28,253,150,227,228,251,38,4,117,255,136,225,39,255,91,0,254,248,138,228,98,249,69,252,103,2,196,220,184,248,101,0,122,247,72,219,28,253,86,2,101,253,0,223,96,251,232,7,8,251,148,221,198,253,127,252,176,246,193,214,250,250,26,2,0,250,232,221,136,252,191,251,139,250,88,228,95,251,124,2,28,251,104,217,233,0,40,9,242,252,240,224,210,250,134,254,101,248,217,227,134,254,128,5,67,247,237,222,247,249,134,3,61,248,53,220,62,250,156,3,53,249,33,224,32,252,179,255,72,245,105,223,148,0,89,254,219,249,111,220,119,253,2,255,66,251,21,221,200,1,25,1,143,248,123,221,179,0,118,254,182,245,71,220,245,2,11,6,217,250,209,217,45,253,185,1,112,249,50,221,82,253,249,5,11,250,236,218,146,251,16,8,86,252,33,232,81,252,165,2,225,255,13,227,155,253,210,252,46,0,249,218,102,252,82,254,243,247,222,211,12,251,38,5,163,251,2,224,64,3,159,2,90,247,43,215,218,253,136,6,138,252,20,4,137,36,141,249,209,234,10,4,213,31,57,254,234,231,249,2,101,32,114,243,26,237,170,3,141,31,164,0,246,235,15,5,225,33,22,10,142,234,198,254,37,31,165,246,145,235,5,254,52,35,63,246,113,233,92,9,122,32,2,252,191,237,20,250,53,33,158,7,151,236,204,254,233,28,13,6,254,236,144,255,148,32,187,11,200,236,206,255,99,36,91,5,222,233,109,253,233,36,192,9,85,234,13,10,188,35,34,247,81,237,62,3,192,27,74,254,189,240,10,2,176,41,91,253,173,230,90,251,124,39,2,254,138,230,85,254,79,32,189,253,85,231,66,6,177,31,121,248,190,238,38,247,244,31,192,1,186,235,159,249,112,34,30,255,117,233,247,2,9,37,151,255,75,233,206,8,23,26,46,254,226,233,168,255,34,27,127,3,186,232,87,249,25,39,114,5,58,234,236,2,7,31,28,2,220,229,131,5,97,27,232,0,255,231,185,2,122,28,59,251,34,235,28,249,84,41,152,7,115,240,202,250,164,35,171,4,193,240,119,252,83,39,123,2,81,236,152,2,184,41,49,0,239,237,94,5,64,37,247,252,249,241,252,0,226,37,171,253,141,244,56,3,204,35,10,252,160,247,134,9,73,41,15,247,184,238,53,8,190,27,251,1,226,241,38,1,115,31,80,254,18,250,103,253,97,40,35,2,220,244,144,4,213,46,20,254,205,234,64,5,16,25,46,1,59,236,65,249,232,47,227,5,65,238,162,2,137,42,122,252,235,241,186,253,32,37,44,1,222,241,129,2,230,29,177,2,195,247,17,8,27,36,252,1,241,238,31,4,181,32,176,2,184,243,127,253,249,31,218,3,21,243,96,4,2,29,249,6,83,241,124,6,134,31,175,253,224,243,210,7,251,36,70,249,109,242,57,9,176,32,100,0,131,241,252,252,165,30,155,253,132,236,205,5,6,29,104,7,17,232,80,254,143,30,77,252,190,244,57,1,114,43,8,253,249,236,156,1,220,32,229,254,121,239,49,6,162,40,164,248,61,243,65,1,40,27,5,3,56,244,151,255,54,35,121,0,55,247,49,6,73,40,47,252,52,237,83,6,93,46,26,5,36,229,112,251,182,34,175,255,60,246,117,254,134,42,221,2,166,230,171,236,178,16,152,15,226,251,111,239,179,20,166,16,208,249,106,245,22,15,200,17,119,249,0,238,168,9,88,14,77,249,229,244,0,11,163,15,234,246,147,235,148,11,4,22,90,0,196,236,114,13,151,19,184,251,255,250,241,12,161,21,238,247,32,241,147,7,255,16,105,252,133,248,25,10,75,19,178,249,114,242,51,7,186,21,86,253,40,241,102,3,195,22,144,0,135,236,172,5,120,18,59,253,95,241,190,10,52,28,3,1,173,248,108,7,114,25,198,252,23,239,38,6,24,28,24,5,224,234,164,5,64,24,119,2,1,243,192,20,75,22,251,249,202,228,6,13,194,15,4,4,196,226,149,16,122,16,44,255,89,230,207,22,187,17,0,254,173,233,47,23,163,14,94,251,246,230,17,19,28,13,182,249,230,235,30,10,34,11,124,8,180,235,255,15,9,10,139,254,77,236,137,23,222,16,180,2,107,234,20,19,185,13,114,1,108,229,109,29,180,22,24,254,231,233,176,9,221,15,210,4,173,243,192,5,183,23,164,4,157,242,97,20,114,13,90,3,166,237,197,11,141,21,26,10,159,238,178,8,42,21,252,13,5,231,219,13,111,21,236,7,84,242,155,19,179,18,1,0,58,240,18,10,1,12,79,12,66,245,163,7,117,17,16,15,192,233,123,6,230,23,165,9,2,239,217,4,184,26,54,12,67,234,194,19,76,20,34,5,150,249,94,16,108,15,95,2,47,251,12,16,242,18,128,253,27,252,100,13,167,12,98,5,168,230,181,10,14,27,232,10,164,239,179,14,139,16,226,7,118,243,152,12,14,22,147,5,106,234,253,26,206,19,141,253,1,245,154,15,97,13,111,7,141,247,174,10,47,21,145,0,203,239,151,16,51,9,222,2,102,254,217,9,42,16,240,255,149,246,81,9,63,19,57,8,67,232,7,14,42,12,82,2,166,239,226,18,38,23,20,252,109,227,41,13,78,23,192,1,126,228,89,22,139,22,238,0,142,238,67,15,207,13,41,249,188,247,130,15,19,24,144,250,185,227,95,8,215,32,46,14,201,234,134,17,86,25,214,255,174,248,81,6,189,24,7,2,178,230,69,10,26,18,7,254,152,225,38,9,48,28,85,5,126,251,152,5,223,18,8,6,156,236,87,233,5,7,250,1,172,238,7,229,35,4,43,251,232,234,26,229,116,3,222,254,141,231,65,228,11,2,29,255,45,237,206,230,132,5,62,254,40,240,187,231,189,6,81,252,246,233,53,232,77,5,93,2,156,239,210,233,139,8,83,255,138,237,250,235,166,9,65,1,14,230,29,236,227,5,19,252,72,235,126,235,152,7,43,6,245,227,112,234,188,5,87,254,111,232,225,236,84,7,69,252,61,230,233,235,159,8,11,5,128,239,177,236,54,7,0,7,40,228,218,228,27,2,212,2,239,238,219,236,30,10,79,4,11,227,192,233,176,6,160,5,3,233,91,229,162,1,103,3,84,229,33,234,198,2,229,249,21,232,71,233,78,5,95,6,85,235,10,234,66,2,90,8,253,227,140,232,91,1,160,8,61,232,125,235,84,8,169,1,23,239,167,233,151,1,79,244,50,235,64,236,95,4,211,248,147,234,32,233,185,0,171,246,127,230,198,235,147,1,71,253,193,229,196,238,166,10,103,3,250,235,3,234,43,7,253,252,10,234,247,238,157,11,90,3,94,235,249,232,45,0,177,254,251,238,232,233,160,6,234,249,29,228,253,229,115,2,103,254,193,238,72,231,35,0,26,5,41,226,34,232,110,4,197,0,214,241,40,234,227,7,133,3,37,242,56,236,152,4,202,6,45,236,197,240,39,8,10,1,10,240,89,231,199,5,104,1,190,231,156,235,57,255,59,250,186,240,57,236,76,5,241,255,64,226,143,236,205,1,97,9,26,232,13,232,234,4,205,253,17,232,152,236,6,5,229,255,231,239,36,233,89,4,196,5,219,235,239,236,138,4,106,253,227,237,89,236,155,4,197,2,123,234,180,234,115,254,200,4,11,238,51,229,134,2,211,1,153,231,53,240,212,1,22,1,40,235,191,230,106,3,64,250,170,228,54,231,78,0,250,248,205,236,78,238,196,10,53,255,96,232,235,238,188,5,28,4,79,239,68,228,174,3,189,254,104,230,65,239,47,9,69,0,214,228,251,237,210,2,241,5,151,239,15,235,251,2,230,249,31,229,36,234,20,253,157,2,217,229,37,242,222,255,19,5,115,240,160,233,84,0,111,0,201,237,55,237,125,8,249,251,57,230,67,232,23,5,0,1,84,226,87,239,97,233,212,239,46,230,58,245,88,235,160,240,8,233,231,240,93,230,240,243,196,227,122,234,3,226,184,240,106,221,103,230,130,223,15,235,110,219,127,235,243,230,33,239,190,238,218,243,32,231,250,238,88,234,149,239,49,229,107,236,16,244,36,239,65,234,147,243,250,243,145,232,69,236,159,245,4,233,108,231,132,233,83,240,39,237,59,238,97,234,43,240,165,238,18,232,60,235,168,250,124,240,59,231,46,232,130,245,137,233,35,245,234,234,170,231,142,238,9,232,62,234,161,241,61,239,152,232,20,242,187,235,235,227,179,238,145,227,62,232,44,236,175,238,68,245,10,235,175,231,247,244,79,229,225,233,83,244,72,237,136,240,116,238,100,225,163,225,214,225,147,233,97,230,185,233,44,233,43,234,68,226,194,234,216,239,66,241,134,239,176,239,65,230,227,246,27,237,57,236,75,230,66,1,66,230,154,232,92,244,249,240,74,234,101,244,143,234,116,248,167,228,53,235,145,236,95,249,170,237,128,245,8,229,28,244,193,222,253,234,121,233,11,246,132,226,220,234,134,230,244,245,59,230,147,236,233,230,6,251,241,230,74,240,208,235,208,251,104,234,102,234,206,227,215,246,19,237,59,237,201,232,53,251,95,232,18,228,168,229,143,247,155,220,125,227,162,222,233,238,110,236,86,234,216,234,174,255,217,239,147,239,11,236,211,242,17,243,19,233,89,240,59,236,151,232,184,230,134,240,146,237,106,244,56,233,251,244,95,231,13,237,224,235,237,247,166,240,220,241,167,238,222,242,52,233,139,238,155,235,74,238,40,234,74,240,65,231,31,239,37,232,221,236,105,238,244,243,115,241,118,238,172,223,244,237,164,231,65,230,10,239,59,227,33,240,158,230,63,236,79,234,229,1,84,232,102,245,75,228,208,239,201,231,162,225,74,228,39,240,144,226,232,230,241,230,87,239,241,226,106,246,52,231,37,237,43,235,115,226,191,238,225,237,255,238,65,228,155,239,127,245,147,235,107,230,247,235,108,229,15,232,235,225,140,235,28,237,115,229,113,240,212,240,202,238,32,230,141,238,119,237,68,236,4,243,84,226,96,245,103,230,159,234,116,231,88,249,97,238,221,239,161,227,148,243,180,235,52,228,67,234,115,242,173,2,142,232,123,232,238,240,64,2,184,243,245,223,245,250,78,254,48,232,141,228,92,240,73,5,153,240,227,225,216,246,220,255,98,238,145,229,174,245,119,2,183,241,235,210,246,245,112,240,185,232,106,221,203,250,157,252,213,229,94,221,186,249,168,254,4,241,231,224,226,246,20,248,154,242,147,224,35,244,96,253,228,240,32,220,205,241,229,248,94,239,156,220,195,245,16,252,245,241,11,222,26,248,16,253,35,238,144,224,162,243,194,245,12,237,33,225,131,250,0,1,17,238,111,228,232,249,197,3,205,228,25,226,44,252,40,3,197,235,15,230,228,242,172,4,66,228,227,228,18,245,75,8,45,229,54,233,8,243,254,252,167,232,55,227,60,246,246,252,240,231,0,231,90,252,17,246,171,229,72,226,157,254,247,250,56,229,190,230,103,250,149,249,78,237,108,231,150,236,120,1,225,234,94,221,49,247,112,254,26,241,150,230,149,250,220,241,122,236,7,232,80,251,4,240,253,235,171,218,223,244,230,250,93,239,212,230,213,238,174,254,155,235,102,229,141,252,201,4,7,232,185,231,139,247,42,2,201,240,99,230,152,243,219,248,210,240,4,224,169,255,70,252,181,227,205,229,88,247,196,254,40,234,74,226,85,0,80,254,139,240,247,224,8,254,112,255,247,237,56,226,218,0,200,254,67,237,223,221,180,252,229,251,130,238,188,222,135,250,58,254,51,238,110,228,210,254,228,246,33,230,200,225,241,254,206,255,171,243,148,226,169,251,97,247,250,241,124,227,9,251,5,2,166,238,118,227,5,254,78,2,198,230,156,226,9,245,154,2,129,236,238,222,221,242,239,252,206,226,139,226,224,251,209,248,179,226,132,223,86,252,76,255,47,235,197,225,189,253,219,246,59,238,105,228,80,255,45,242,185,235,92,222,32,250,102,239,245,243,110,228,53,247,32,0,93,240,125,228,187,251,233,252,109,234,99,224,90,253,142,255,50,244,231,215,234,247,219,243,191,240,126,231,74,255,188,241,59,243,255,219,217,253,166,245,190,243,158,219,66,249,88,249,188,238,157,215,48,249,125,242,189,239,95,222,6,247,239,239,66,234,151,230,39,251,49,254,198,243,238,217,208,246,236,236,111,225,145,242,171,5,68,250,253,222,10,243,56,9,77,254,242,222,222,239,158,5,0,252,47,219,44,238,48,5,79,253,250,212,126,243,230,8,32,8,179,223,55,245,110,255,72,254,183,226,198,245,90,255,157,1,198,223,12,244,10,2,171,247,83,223,10,235,67,5,61,254,115,222,117,240,127,11,202,2,81,224,244,245,248,4,44,249,106,225,183,235,93,2,52,250,73,224,128,237,93,8,0,1,212,225,95,237,183,5,212,252,61,227,185,240,236,9,4,0,218,224,187,242,59,9,86,5,65,227,148,239,216,6,66,252,58,226,79,242,148,2,148,3,50,217,175,241,93,12,60,3,239,221,190,239,62,0,182,6,39,219,96,237,162,10,210,4,232,224,112,238,138,0,248,5,250,223,130,242,69,254,119,2,180,225,58,247,143,2,113,4,119,221,183,243,89,4,61,3,119,225,30,243,227,4,230,0,59,219,83,245,67,1,186,248,64,219,184,239,246,4,13,6,179,220,204,240,82,252,27,1,193,223,247,240,21,5,226,6,159,220,109,240,215,255,86,253,31,219,165,239,227,7,145,255,244,217,150,243,66,6,153,252,104,223,86,246,181,5,226,5,232,217,147,244,204,7,219,4,17,220,44,241,180,0,25,2,156,220,155,246,116,4,230,249,124,219,184,246,53,1,94,255,222,213,146,243,251,255,36,250,50,224,68,238,78,254,198,252,152,226,219,246,80,4,183,255,112,219,158,245,246,11,56,0,181,223,225,246,208,7,87,251,119,208,174,243,7,5,128,253,122,211,184,247,178,3,117,251,20,221,49,238,72,1,96,249,239,212,139,239,253,10,72,3,248,219,3,242,176,8,247,7,17,221,247,242,224,4,238,250,36,225,54,240,229,1,224,247,251,219,101,248,143,8,144,252,246,213,248,248,212,9,188,254,145,216,66,247,213,3,201,250,124,209,8,245,183,12,133,2,112,214,247,239,3,5,173,253,17,226,209,244,163,9,227,252,40,214,242,240,126,14,2,6,185,213,179,244,128,5,223,252,110,217,8,241,0,1,154,249,102,215,193,242,11,9,162,255,251,210,17,240,57,16,74,8,182,218,216,247,5,6,225,1,229,221,127,246,18,4,112,8,84,225,119,240,166,250,141,6,160,27,164,242,118,5,51,249,36,24,72,248,0,5,27,242,12,30,255,248,28,11,92,249,171,32,19,249,32,12,137,245,253,35,62,243,172,14,42,242,178,37,172,245,146,5,218,250,32,30,20,245,102,14,73,248,148,28,67,242,5,11,146,253,10,29,222,245,1,9,40,247,69,28,251,248,255,0,214,243,215,33,65,248,58,5,16,244,216,25,72,252,219,15,164,245,119,34,209,250,82,5,180,250,210,38,70,249,7,5,198,246,39,28,223,251,121,7,221,250,84,29,207,249,102,3,66,248,25,32,160,241,137,5,158,243,137,32,19,246,148,6,183,253,126,31,225,246,252,0,16,245,12,32,244,239,25,12,247,245,21,30,217,242,64,2,64,244,182,28,238,252,110,9,175,247,36,27,248,245,71,6,31,255,4,30,173,246,28,5,135,242,114,32,126,242,90,9,82,250,246,32,35,245,19,4,174,250,215,35,228,247,96,8,61,248,155,32,107,245,161,13,51,239,64,22,183,246,54,11,83,3,121,34,37,251,171,8,213,245,97,34,178,249,72,2,47,246,221,32,128,254,141,5,60,247,12,36,22,244,207,12,140,247,198,24,118,245,219,13,149,255,69,39,84,246,21,11,160,243,15,29,164,253,105,12,105,240,69,30,216,251,233,16,9,237,207,33,127,247,204,8,65,242,42,33,28,255,166,7,95,243,17,41,104,244,119,7,220,246,210,31,162,252,92,7,69,249,108,30,102,253,188,11,181,244,105,30,172,249,37,16,167,242,22,40,109,241,127,13,101,244,122,33,119,252,167,17,215,237,169,35,254,245,207,1,95,246,235,36,253,241,112,7,16,244,149,25,68,247,194,11,85,238,7,28,132,245,151,11,126,242,144,38,50,243,30,4,88,246,193,35,93,252,193,4,251,245,85,34,115,242,241,2,248,245,27,26,49,241,5,7,128,240,145,26,71,248,7,9,60,254,192,24,220,249,52,10,64,243,60,31,16,252,218,2,108,244,97,29,221,251,37,6,146,241,212,31,123,240,40,10,12,242,85,30,4,250,224,9,240,240,236,28,178,240,120,17,113,255,190,34,138,250,227,12,155,241,136,22,7,248,207,5,131,253,11,20,207,244,159,9,213,252,39,25,224,249,172,13,242,249,82,221,114,229,57,235,84,250,68,231,15,218,216,243,34,252,4,223,84,231,146,241,81,253,21,232,168,213,203,241,250,238,80,237,148,218,31,238,235,245,36,232,237,214,5,237,36,246,75,226,162,226,233,246,19,245,66,218,185,221,93,246,38,248,162,230,157,226,149,237,138,255,158,223,234,220,120,249,195,254,162,221,213,212,208,240,110,250,127,231,33,230,121,229,114,255,135,223,12,226,163,247,5,251,203,230,36,223,251,241,250,239,165,229,186,225,198,233,62,246,122,225,219,229,154,243,114,246,113,215,110,216,165,240,196,246,146,214,237,222,93,234,44,245,253,218,241,229,23,243,33,247,234,220,15,219,253,233,91,240,129,216,227,224,141,230,172,239,123,227,177,230,12,235,208,2,185,218,217,220,15,225,112,252,194,218,142,222,115,242,128,254,79,226,152,215,123,243,153,251,104,224,84,222,166,236,184,244,246,223,42,223,130,228,65,241,112,227,124,223,250,242,17,249,138,222,210,219,121,224,178,239,100,228,220,211,59,234,165,244,153,223,8,221,242,238,248,249,160,212,30,216,19,247,128,254,163,235,160,226,112,236,197,250,255,232,252,224,157,232,151,250,192,213,247,223,199,239,51,250,219,215,41,221,85,231,140,249,0,233,176,215,19,241,59,249,255,214,243,227,61,232,40,244,215,225,4,218,65,230,40,235,200,233,42,225,98,242,8,246,226,216,252,214,81,243,204,252,99,231,195,221,102,238,149,244,187,223,89,225,187,231,240,249,28,216,199,226,79,224,142,240,230,228,134,213,70,232,161,237,241,227,40,213,162,238,19,249,48,228,23,220,82,248,51,246,166,231,209,219,247,246,68,239,201,222,127,217,131,246,160,253,100,219,92,225,57,223,184,247,241,224,11,228,121,230,245,255,168,227,255,218,132,247,108,253,177,216,116,218,45,246,241,255,228,229,82,220,35,232,146,239,244,223,100,209,156,235,254,246,18,218,206,229,237,239,53,243,57,229,90,228,151,246,161,238,80,227,7,226,129,238,236,239,109,221,70,229,193,236,124,244,33,221,44,215,255,233,110,247,77,222,214,220,248,227,217,249,239,223,6,218,147,228,4,243,70,241,247,215,217,241,48,237,9,224,215,226,6,240,134,2,29,224,19,228,200,0,242,1,159,223,134,231,174,2,50,255,210,216,159,231,248,251,184,248,167,221,121,223,251,252,87,255,67,220,185,231,201,3,241,255,145,223,29,233,249,255,214,7,46,218,141,227,255,0,42,5,179,219,197,227,71,0,25,255,179,222,185,231,31,1,187,252,19,215,253,234,135,4,169,5,26,214,80,225,126,255,102,0,10,222,219,226,70,251,178,2,105,219,52,235,79,4,98,12,66,214,137,224,193,252,97,6,15,220,39,229,112,245,210,8,27,223,18,235,131,250,226,0,150,220,58,233,205,254,221,249,114,212,43,227,70,245,124,252,6,217,219,232,42,248,75,254,8,219,123,237,239,254,37,4,209,214,228,229,167,251,124,6,167,216,56,234,59,4,243,254,134,221,125,233,64,6,206,5,51,215,145,220,27,251,192,255,203,208,89,233,2,0,1,3,117,205,249,229,114,6,157,5,76,213,222,230,28,251,119,253,126,210,110,225,251,247,198,2,166,208,179,229,159,248,37,253,123,220,49,232,97,246,182,252,31,213,244,238,213,1,164,1,32,211,4,229,247,253,125,3,59,218,154,234,182,252,81,1,146,214,173,235,136,253,175,250,42,216,116,231,126,6,253,4,105,216,84,235,131,9,165,13,237,212,95,230,143,2,56,0,31,213,90,236,103,4,154,254,34,206,110,240,68,5,177,254,92,200,205,225,8,1,61,1,236,196,187,215,4,254,167,5,235,205,66,222,160,253,137,0,236,204,11,222,220,244,81,254,108,212,86,234,52,247,192,249,12,222,58,227,205,252,57,251,37,207,168,217,78,249,135,255,40,214,246,229,32,2,21,13,82,207,254,232,69,246,242,246,76,207,198,227,181,1,232,0,220,211,150,235,20,8,175,2,38,209,128,223,142,253,168,10,66,208,156,234,118,4,18,0,219,215,70,224,142,246,211,7,150,203,29,232,21,242,14,245,89,198,150,217,37,251,21,0,125,202,223,233,245,5,251,1,115,192,252,218,67,253,163,0,123,206,195,234,9,255,5,252,205,209,57,239,75,255,37,251,209,205,112,238,168,11,99,4,220,201,21,225,114,251,221,253,12,208,47,224,14,247,9,250,103,211,34,237,167,11,62,7,239,209,142,232,139,4,148,7,179,44,200,236,93,243,79,12,36,44,40,230,30,250,151,4,238,35,236,237,244,247,86,9,36,41,69,240,125,253,144,3,174,38,11,242,186,249,47,5,181,37,48,242,64,247,77,7,220,38,205,235,89,254,102,10,28,48,92,240,59,248,25,1,93,47,64,237,15,251,93,255,154,41,199,245,223,246,182,5,181,38,152,236,184,246,148,3,144,50,217,237,90,248,204,1,188,50,93,235,139,251,41,0,33,48,157,244,219,241,1,4,185,44,178,244,88,245,95,1,55,47,31,244,46,248,224,255,38,45,65,240,193,250,113,254,183,50,100,241,68,242,221,4,67,47,45,246,64,245,225,0,227,48,119,242,115,245,38,2,91,57,98,236,104,235,180,11,228,47,201,242,65,251,240,253,242,53,210,234,117,246,142,4,109,52,254,234,162,248,209,2,161,50,93,239,222,245,28,3,234,47,200,247,96,237,55,6,211,52,154,237,27,244,62,5,149,48,205,247,22,234,69,8,74,46,121,247,87,242,149,2,243,47,160,240,171,253,71,253,171,48,123,235,251,253,224,253,35,50,2,240,214,250,88,255,24,56,211,233,23,243,67,7,81,54,56,238,43,239,69,8,39,45,172,242,201,248,175,255,67,52,161,243,124,233,186,10,134,46,158,249,10,239,28,4,118,49,122,237,71,0,50,252,1,51,74,243,184,238,169,6,198,58,182,233,13,237,203,11,82,55,210,239,118,234,27,11,220,49,203,248,228,229,72,11,146,53,186,246,98,225,17,15,239,51,129,249,155,223,233,15,48,39,200,239,181,242,141,5,190,42,246,234,82,247,182,3,36,41,15,231,42,249,133,7,33,40,172,232,2,250,131,2,109,41,82,237,97,249,27,0,236,42,223,235,157,251,171,254,109,45,4,233,220,251,48,0,201,40,51,240,129,246,55,1,36,42,245,241,181,239,15,7,78,47,202,233,177,247,208,3,226,45,91,237,177,245,123,3,21,45,77,235,41,244,196,6,152,44,1,246,17,235,150,8,63,45,0,235,64,253,165,2,176,40,114,243,68,242,104,3,179,37,197,234,174,249,183,12,245,38,243,235,28,252,83,15,187,45,221,237,82,254,228,252,242,42,107,245,253,241,254,8,220,41,2,236,123,253,14,1,20,55,182,215,71,4,251,5,144,50,143,224,81,4,27,253,220,51,133,228,1,254,18,1,184,54,170,227,229,254,139,0,74,45,120,230,165,255,135,6,212,45,59,222,234,2,15,0,21,57,83,228,214,249,159,4,27,51,176,231,18,253,252,255,164,54,144,231,200,249,52,3,86,57,21,222,185,1,126,0,211,60,88,221,247,253,115,4,26,61,195,218,85,1,185,2,88,62,142,218,88,255,97,4,104,60,1,216,153,5,255,255,86,58,49,225,234,251,56,4,148,59,50,226,149,248,92,6,125,60,64,223,46,251,204,5,90,62,66,222,233,248,139,7,117,64,88,214,142,1,143,4,18,63,95,216,155,1,150,3,237,56,205,226,71,253,89,2,222,55,196,224,28,0,1,1,177,57,120,229,18,247,38,6,64,55,7,232,135,247,233,4,178,57,129,231,217,243,141,7,30,55,136,223,59,4,237,253,131,59,177,228,79,244,126,8,166,51,83,233,35,2,133,252,204,57,198,221,230,4,10,255,168,62,35,220,19,252,15,6,103,64,154,216,139,254,140,5,229,58,249,218,198,3,51,0,226,50,188,230,164,3,200,251,159,49,248,231,223,255,195,253,25,61,102,229,224,239,58,11,226,51,7,226,47,6,253,250,85,48,18,228,232,5,107,252,192,50,185,225,90,253,15,3,155,42,54,229,199,254,37,10,226,50,253,220,125,0,104,8,226,49,38,217,165,7,7,254,194,48,63,229,12,251,65,3,222,53,219,231,118,255,233,254,165,49,66,223,252,7,227,0,212,47,26,230,203,0,55,254,129,55,96,229,248,251,120,2,30,59,181,223,224,254,128,2,51,53,243,231,190,251,100,1,220,54,11,227,213,2,28,254,158,50,183,225,25,10,68,248,132,51,52,223,2,9,234,249,43,56,4,217,84,8,80,253,195,55,127,217,138,4,179,0,122,53,56,222,85,6,135,252,250,45,83,229,22,253,22,1,188,49,246,223,30,1,90,0,62,53,94,216,75,7,49,255,40,47,220,221,19,5,123,253,52,50,236,218,202,4,62,0,16,46,42,227,202,255,140,255,211,53,202,220,231,1,95,1,175,46,207,225,121,0,66,3,194,46,203,217,228,8,252,255,136,49,208,224,227,10,237,252], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2054304);
/* memory initializer */ allocate([244,51,104,199,8,25,121,248,67,53,5,196,193,35,255,243,4,50,2,203,141,21,167,249,240,64,154,213,154,6,28,0,163,79,156,183,18,24,251,254,131,64,158,206,64,13,249,253,184,61,169,212,103,8,54,255,184,65,242,209,115,6,87,2,196,68,99,204,3,10,26,2,228,69,159,200,234,13,147,0,91,66,121,211,101,3,28,4,107,66,88,207,138,9,9,1,153,84,210,170,238,35,30,251,185,65,227,203,140,15,82,253,117,68,86,206,95,7,37,3,35,64,230,212,192,4,105,2,195,81,29,178,45,29,84,253,20,72,226,195,221,17,65,255,186,57,163,216,25,11,71,251,250,67,249,203,226,11,160,0,165,75,254,185,175,27,219,251,170,63,91,209,250,10,161,254,143,74,208,192,167,18,172,255,2,69,255,207,170,3,200,4,149,72,234,193,12,20,82,254,111,77,179,190,46,16,33,2,248,77,33,180,208,32,44,250,29,74,79,190,18,23,174,253,135,74,185,195,200,13,247,1,27,65,59,207,115,17,234,250,79,77,123,186,52,24,239,253,37,78,58,187,234,20,236,255,155,78,89,183,230,26,40,253,124,74,43,198,90,9,81,4,107,56,101,202,255,21,19,248,138,57,105,200,255,21,86,250,217,62,169,193,103,28,19,248,161,52,64,212,164,12,100,252,77,56,106,213,43,9,245,254,2,69,26,183,117,44,88,242,157,57,222,212,233,12,237,254,200,59,10,215,77,7,16,255,217,57,162,208,41,13,152,253,0,66,79,191,139,28,203,248,166,61,0,200,4,21,16,251,11,64,96,195,15,25,204,249,113,53,150,212,24,10,192,254,164,55,218,207,128,17,160,249,143,59,193,204,169,16,126,252,163,54,197,208,141,13,171,253,117,54,30,206,144,16,185,252,203,53,197,202,132,20,152,250,162,58,54,193,168,29,55,247,236,61,182,188,171,33,161,245,233,73,236,189,219,26,35,250,61,58,98,210,208,10,217,254,44,74,79,184,232,32,234,247,97,60,24,197,74,24,23,250,68,58,104,195,37,27,165,248,188,70,146,198,73,18,67,253,192,68,139,194,240,21,249,252,246,54,141,202,72,25,190,245,8,54,118,209,81,20,72,247,158,73,191,181,232,35,87,248,51,209,14,213,76,231,40,247,32,213,169,220,110,230,12,241,232,211,220,214,154,228,161,239,101,216,51,216,137,225,128,245,197,214,252,216,35,220,8,248,180,210,181,211,218,216,109,245,168,203,173,203,214,211,146,239,210,217,7,208,214,226,219,239,166,213,187,204,183,221,164,236,68,209,22,197,205,217,25,236,90,219,52,216,163,220,193,236,214,210,224,211,189,241,39,252,185,219,157,216,18,225,27,240,235,205,84,191,110,211,205,231,172,206,1,221,87,238,167,251,235,201,195,210,191,241,87,253,115,206,227,215,149,234,5,251,116,197,182,205,13,236,91,251,63,202,153,211,198,231,244,248,87,204,15,212,116,225,230,242,39,198,40,209,126,243,200,254,252,194,97,195,30,216,151,242,102,205,40,216,189,243,157,253,240,210,3,217,92,235,101,252,22,205,127,207,252,237,182,251,241,189,111,195,21,232,184,250,12,188,235,186,118,223,133,247,216,200,244,213,39,247,157,255,202,206,57,227,226,234,54,242,193,200,7,206,99,213,150,235,156,198,25,190,150,210,78,234,219,206,67,212,22,220,3,241,144,190,170,190,238,217,8,245,152,214,138,215,96,230,53,251,19,199,0,204,3,221,191,242,68,216,241,222,125,222,197,242,102,211,123,207,110,234,206,248,177,209,132,200,243,229,191,245,4,204,1,224,155,240,110,247,233,216,22,208,98,236,237,248,36,203,101,194,231,218,153,243,16,210,116,212,157,215,103,234,139,208,37,206,66,212,143,241,3,209,169,208,149,222,0,249,157,189,11,178,73,211,113,242,168,204,88,199,252,216,137,243,46,217,200,212,5,232,166,243,87,221,226,210,154,223,106,230,169,219,46,205,250,231,105,245,153,195,27,215,26,249,86,255,143,193,83,210,65,244,118,253,10,189,81,214,102,250,47,0,65,193,222,201,47,237,222,251,10,180,113,179,134,218,96,246,148,177,200,182,135,223,159,248,57,197,43,193,90,226,54,247,87,203,189,192,152,222,74,244,251,201,235,197,208,229,116,248,27,192,204,183,182,217,113,244,201,214,55,223,169,219,50,236,175,211,60,220,247,233,221,243,95,204,119,203,202,219,67,238,44,209,92,202,245,216,26,231,1,213,209,218,208,235,245,239,202,38,78,225,125,31,233,238,82,32,69,225,104,23,208,247,220,37,53,218,197,29,170,241,117,37,82,224,109,25,62,244,73,49,56,209,138,39,16,235,91,46,65,221,12,31,53,235,148,40,14,215,18,36,28,239,252,31,228,223,130,30,79,245,167,40,173,221,198,18,118,248,108,40,115,221,17,36,42,230,206,36,77,228,212,18,194,244,30,38,188,217,208,21,48,247,204,39,198,224,227,20,241,242,125,43,225,226,175,15,254,246,180,41,8,214,205,23,187,245,2,45,104,208,168,30,209,242,101,34,101,217,197,20,1,244,26,37,74,218,155,25,248,241,248,40,184,224,226,15,28,251,253,43,30,221,180,23,78,245,148,47,99,215,163,19,5,250,178,35,173,222,17,14,89,248,171,31,68,223,106,19,243,247,9,38,64,204,38,25,199,245,170,43,73,215,62,10,246,253,100,37,172,207,79,20,29,248,25,47,144,208,51,16,181,251,87,35,59,217,212,9,103,253,38,42,162,224,250,22,222,238,31,28,22,223,193,24,231,244,98,30,163,223,201,13,142,242,135,29,183,214,156,13,204,250,188,36,77,224,60,29,91,234,112,30,56,209,170,21,243,245,97,36,232,215,237,29,181,235,45,26,27,214,18,17,8,249,54,19,159,211,155,17,81,238,27,20,239,207,138,15,76,234,125,25,85,217,129,17,199,243,114,29,201,205,172,23,38,237,211,33,177,208,247,27,178,238,248,32,216,211,195,17,45,249,0,36,90,213,179,13,85,251,21,24,218,219,163,18,187,237,203,35,245,212,5,22,185,236,129,52,11,211,20,26,126,246,232,30,74,219,7,26,48,240,203,45,79,202,195,31,204,239,177,23,239,215,141,19,73,231,98,45,127,207,216,20,154,248,187,34,156,201,215,32,13,232,150,37,237,206,228,30,11,236,215,44,181,215,157,32,105,240,156,45,233,200,211,25,230,246,175,46,7,221,245,14,242,249,246,40,148,224,253,40,224,232,25,46,239,213,35,38,71,235,221,23,28,222,195,22,190,250,118,27,117,218,248,21,127,233,8,50,170,205,235,33,204,239,157,51,32,215,237,24,139,243,20,46,143,202,207,41,69,232,167,37,243,224,153,37,152,240,90,33,171,228,189,20,197,1,255,255,255,255,255,255,255,255,1,2,4,6,8,10,13,16,255,255,255,255,255,255,255,255,1,2,4,6,8,10,13,16,255,255,1,2,255,255,1,2,255,2,255,2,0,0,0,0,16,198,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,214,36,0,160,165,35,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,198,34,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,3,0,0,0,0,0,0,0,0,0,0,72,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,159,34,0,112,0,0,0,80,135,31,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,69,0,0,0,255,255,255,255,70,0,0,0,255,255,255,255,169,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,16,80,1,0,255,255,255,255,41,80,1,0,255,255,255,255,29,80,1,0,255,255,255,255,83,85,80,79,255,255,255,255,1,0,1,0,255,255,255,255,13,0,1,0,255,255,255,255,9,0,1,0,255,255,255,255,19,80,1,0,255,255,255,255,0,48,1,0,255,255,255,255,1,48,1,0,255,255,255,255,20,80,1,0,255,255,255,255,45,80,1,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,3,216,5,167,0,0,255,174,254,217,255,120,255,255,255,252,255,250,255,183,255,248,255,241,255,12,0,23,0,2,0,16,0,30,0,3,0,251,255,50,254,82,253,237,1,15,10,55,1,243,255,228,255,242,255,108,254,251,255,237,255,13,0,20,0,72,0,107,0,179,255,8,0,13,0,247,255,208,255,203,5,144,0,16,3,160,3,219,4,122,255,255,255,219,255,204,255,162,255,243,255,185,255,250,255,172,255,248,255,212,255,144,255,246,255,197,255,186,255,179,255,19,1,194,13,32,4,26,251,0,0,252,255,11,253,188,255,161,255,1,0,16,0,197,255,4,0,239,255,29,255,251,255,21,0,13,1,80,0,131,255,216,255,248,254,125,1,163,19,0,0,0,0,252,255,248,255,250,249,0,0,254,255,0,0,2,0,0,0,6,0,38,0,12,0,81,0,139,255,138,0,76,1,167,8,14,10,59,5,255,255,250,255,213,254,108,254,147,255,254,255,238,255,212,255,235,255,204,255,164,254,245,255,229,255,75,255,46,255,101,14,67,11,137,252,98,3,153,249,196,252,5,254,208,255,211,255,92,255,120,253,199,0,156,0,62,255,104,255,46,0,112,1,32,1,168,255,86,0,116,5,98,8,187,8,89,1,174,3,138,255,231,254,207,254,249,255,202,255,74,255,66,255,220,254,227,255,211,255,209,255,176,255,133,255,128,255,237,255,13,0,123,17,221,13,220,252,113,253,0,0,58,251,0,253,217,255,230,255,253,255,254,255,55,252,0,0,219,0,174,0,0,0,179,0,141,0,224,255,44,253,254,0,242,0,161,23,158,9,224,255,253,255,253,255,71,247,142,254,11,0,10,0,253,255,11,1,162,255,167,255,108,0,218,255,220,255,115,252,114,2,79,249,233,23,209,17,219,251,233,255,77,255,17,247,10,251,188,255,65,0,23,255,128,2,82,255,221,1,88,249,40,0,145,255,140,1,39,1,162,254,111,5,49,31,255,1,107,254,249,255,138,255,204,240,241,255,246,255,29,0,170,0,90,253,10,0,213,255,7,255,248,255,34,0,197,0,12,0,72,12,239,253,96,2,226,9,38,15,165,253,239,255,234,255,122,254,106,252,101,0,140,255,19,0,27,254,81,0,163,255,24,253,125,0,112,255,169,253,29,10,79,253,229,11,227,21,108,254,103,254,227,255,202,253,132,248,246,255,108,0,31,254,128,0,139,252,235,0,239,251,63,0,239,255,75,0,138,0,35,12,1,2,94,5,246,241,198,236,179,253,240,255,141,255,236,252,58,250,159,255,252,254,213,255,169,2,112,0,45,1,165,3,154,0,157,1,201,251,164,9,122,23,83,4,122,254,169,7,140,254,100,247,182,255,247,255,22,255,119,252,90,255,106,254,58,0,143,0,26,0,217,254,49,253,124,255,46,0,165,18,206,10,64,9,254,18,52,240,146,250,45,254,170,254,93,250,26,252,218,252,78,253,113,254,120,250,203,252,66,253,154,4,170,2,72,2,176,4,129,6,169,248,163,5,165,6,114,33,87,255,41,255,129,255,80,255,133,238,190,0,110,255,165,0,84,255,195,0,107,255,154,252,214,3,14,253,135,252,156,10,51,35,17,252,243,2,7,249,62,254,164,236,195,255,222,255,62,255,43,250,167,0,42,2,131,255,97,254,46,0,40,1,214,3,147,255,82,0,89,245,124,29,5,5,170,3,92,13,59,254,106,242,156,255,203,255,54,253,232,4,213,0,176,253,156,0,80,254,183,255,57,2,216,249,244,254,60,255,93,14,114,3,210,15,178,4,19,9,199,252,209,255,23,252,168,255,183,254,58,255,115,252,38,255,243,254,192,255,215,254,247,253,131,255,194,253,86,255,254,7,15,253,122,0,118,39,91,2,1,255,222,255,0,0,171,231,234,255,94,0,241,255,5,0,19,251,208,1,181,255,181,255,27,0,252,255,140,254,193,1,233,248,194,41,30,15,241,253,244,255,55,255,192,228,110,252,240,255,49,0,219,254,160,4,150,255,172,1,35,246,14,0,198,255,88,1,124,0,83,252,48,9,185,19,66,14,77,10,202,255,175,254,236,249,211,252,88,254,135,0,34,1,43,253,209,0,244,253,155,251,151,0,134,254,212,252,181,253,169,248,28,3,45,12,97,37,108,254,41,255,218,255,175,253,43,234,247,255,91,0,101,1,105,255,73,4,48,254,227,248,210,255,19,0,76,0,236,0,77,249,251,7,208,247,218,38,161,15,77,255,2,255,244,254,106,232,47,252,213,0,37,255,5,1,17,4,40,251,248,4,162,1,14,254,255,1,131,246,116,233,150,253,175,240,28,1,173,243,15,248,233,255,86,252,252,255,161,253,38,255,155,250,108,255,100,0,10,0,68,0,169,251,137,255,13,253,54,0,126,1,140,18,67,31,240,247,150,8,248,255,160,250,187,240,252,254,218,254,146,255,70,255,241,246,48,0,86,2,240,3,205,255,131,253,207,251,21,1,157,252,199,11,150,46,117,249,179,3,211,255,213,253,23,222,85,255,202,255,159,0,119,2,109,247,168,255,52,1,195,4,50,0,82,255,78,253,96,0,187,236,80,254,101,26,187,14,72,5,51,250,245,255,30,245,157,252,145,255,126,255,242,7,178,0,111,4,99,0,237,249,151,1,35,0,211,253,201,254,152,0,254,37,135,16,120,248,210,5,255,255,114,233,188,251,30,255,121,255,166,255,217,255,49,246,17,0,120,4,242,1,243,255,140,252,128,254,175,0,208,9,193,0,73,35,241,20,180,243,127,254,254,255,140,236,38,249,163,253,227,255,151,250,150,255,202,252,193,255,116,244,226,1,37,0,199,6,6,4,16,33,28,11,12,0,37,2,84,8,235,238,19,254,0,0,238,255,235,254,67,250,250,255,254,255,228,254,161,255,0,0,179,251,142,254,255,255,185,255,93,8,214,245,254,27,86,35,186,250,233,254,99,254,194,243,126,236,145,255,84,1,88,252,114,4,98,251,156,5,139,240,176,0,42,255,78,2,233,2,12,255,22,1,251,51,203,4,95,255,253,255,252,255,200,213,165,255,255,255,4,0,198,0,30,255,18,0,236,255,27,252,254,255,2,0,131,0,12,0,101,248,25,32,125,24,149,3,1,246,25,255,231,239,161,246,205,255,113,254,208,3,233,2,184,243,108,0,52,254,162,254,208,254,3,5,211,3,143,0,238,248,13,8,35,245,168,23,74,39,56,255,253,254,40,254,66,247,226,231,227,0,205,254,93,1,157,2,7,253,4,4,87,4,15,251,171,6,123,241,147,30,201,35,175,242,169,9,26,250,101,241,254,235,59,253,139,254,117,255,232,238,92,6,114,7,99,251,154,250,2,2,209,2,76,3,198,254,228,0,106,250,121,32,69,37,117,244,90,6,132,255,134,239,76,234,235,253,95,255,213,2,64,3,23,237,255,254,219,5,185,6,142,0,199,252,77,252,37,1,3,11,105,239,15,21,225,33,196,10,27,254,179,251,18,249,17,238,49,254,218,2,97,252,117,5,44,250,200,8,218,244,38,254,202,2,117,252,77,250,141,0,216,56,178,2,1,1,144,255,255,255,130,205,227,255,252,255,0,0,131,255,251,255,155,253,254,255,28,255,246,255,0,0,99,0,4,0,1,0,162,46,189,248,14,7,62,252,140,252,5,222,45,255,57,255,200,255,209,255,75,5,220,250,205,0,189,2,147,255,106,0,132,2,156,255,97,0,205,255,144,14,190,7,216,8,232,17,59,12,176,252,17,255,200,254,254,250,170,253,61,254,253,253,239,254,237,251,214,253,135,253,56,253,134,254,80,254,148,252,99,251,254,2,208,2,223,55,40,255,171,255,221,255,225,255,58,207,254,255,55,0,51,0,223,255,7,4,100,253,140,253,241,255,10,0,9,0,189,0,223,238,218,18,128,39,33,6,60,13,107,251,115,250,158,231,106,255,68,253,11,5,146,10,93,244,164,1,50,254,55,252,138,3,26,252,213,247,188,254,64,254,140,7,231,60,206,248,145,2,244,255,29,255,11,198,49,255,230,255,52,0,171,1,210,248,206,255,217,0,217,6,18,0,179,255,142,253,74,0,211,239,52,7,122,15,141,21,76,24,234,251,49,255,66,252,190,248,199,246,210,1,233,3,66,254,114,5,147,253,202,250,36,6,68,253,32,250,210,247,217,2,5,247,163,57,73,14,72,252,224,255,190,254,24,204,208,252,201,255,102,0,112,253,23,8,94,255,1,2,34,243,42,0,123,255,89,3,212,0,151,250,169,22,27,52,191,243,64,5,139,255,250,247,147,213,168,253,146,255,234,1,103,4,141,237,247,254,87,4,250,9,113,0,36,254,186,251,1,1,102,18,189,37,49,4,93,246,202,12,182,250,191,233,186,255,141,254,114,253,39,245,204,254,135,253,197,2,175,5,161,0,83,252,118,248,42,255,237,1,51,7,216,241,134,48,242,26,233,249,49,255,222,252,53,219,168,244,108,255,151,1,139,250,188,10,249,252,246,5,146,235,175,0,168,254,158,4,144,2,153,5,90,9,203,9,100,5,76,34,131,255,163,254,129,254,140,255,159,237,47,255,37,255,146,254,136,255,55,255,45,255,0,253,253,250,193,250,28,253,80,249,115,50,251,22,107,247,223,3,77,255,59,216,192,247,218,254,196,255,70,5,103,2,226,237,27,255,196,6,21,3,103,0,243,252,156,254,133,0,224,58,110,8,35,251,142,3,16,254,215,201,228,254,162,255,206,255,241,255,62,248,121,4,164,0,187,252,137,255,69,0,200,1,65,0,219,255,27,0,47,18,151,28,52,19,74,2,203,242,214,250,58,243,61,250,236,255,71,253,225,247,140,250,108,247,90,255,251,254,81,255,192,3,230,5,246,3,120,0,167,4,164,247,0,20,186,52,118,250,170,255,233,254,192,249,143,212,134,255,155,0,140,254,157,2,43,252,227,6,134,239,103,0,71,255,187,1,144,4,6,250,207,252,255,31,160,37,84,250,113,255,216,255,1,240,225,233,128,255,180,255,253,2,152,1,132,3,224,1,49,237,121,255,184,255,214,2,86,3,92,243,95,2,160,6,198,247,221,44,129,253,234,255,81,255,242,254,141,224,119,0,79,1,194,255,96,254,78,0,218,0,220,8,87,254,91,251,196,5,131,12,145,248,187,252,207,37,145,27,142,253,35,255,214,255,170,233,33,244,116,1,163,0,159,255,156,248,100,4,238,1,156,250,51,3,104,1,183,239,213,0,113,253,119,66,108,2,128,254,254,255,230,255,249,186,233,255,247,255,8,0,35,255,169,2,248,255,24,0,124,253,5,0,241,255,143,1,14,0,224,19,35,0,245,242,142,14,40,33,212,249,0,0,88,253,177,252,211,238,246,255,13,4,7,0,123,251,248,255,247,2,180,245,238,255,194,6,118,248,36,252,174,5,128,245,191,58,122,10,197,255,127,255,71,254,19,202,73,254,87,0,94,255,238,0,139,3,201,250,163,9,161,0,18,255,184,1,98,246,255,236,230,244,203,255,119,21,123,25,91,250,19,254,0,0,205,248,219,245,180,252,240,255,247,255,96,6,185,3,18,0,145,7,107,4,21,0,116,247,4,12,221,58,158,244,18,7,53,252,191,253,220,201,250,253,56,255,199,255,243,244,35,2,120,10,173,254,127,249,66,1,182,0,125,3,84,255,107,0,31,5,235,20,46,43,251,8,186,241,151,255,42,249,222,226,190,254,210,252,84,254,139,252,227,241,72,255,17,253,241,249,36,1,170,4,161,9,0,2,195,15,243,21,10,18,23,7,120,7,30,252,121,248,235,250,55,255,33,255,152,250,143,251,209,249,65,254,146,253,1,254,41,254,112,253,229,253,45,255,173,247,194,10,107,238,79,50,8,29,235,254,49,254,44,251,116,216,213,242,102,1,183,253,244,2,139,6,139,247,210,13,199,3,31,251,250,7,46,233,242,21,253,253,147,12,203,239,249,18,122,248,240,255,136,253,230,251,96,250,176,0,176,251,101,0,142,5,126,255,47,3,126,249,152,0,70,252,206,4,46,7,83,249,115,4,227,65,204,2,50,255,78,255,177,255,42,188,225,255,191,0,129,255,118,0,156,248,223,6,107,251,176,255,74,0,207,255,31,253,186,7,251,240,66,39,78,46,68,246,18,255,122,252,236,231,128,222,133,254,208,1,67,251,54,9,105,250,222,10,153,227,45,1,183,253,249,5,11,7,216,245,238,43,25,44,193,241,183,5,100,254,216,225,158,225,212,252,126,255,248,6,255,6,187,225,190,253,200,9,209,9,232,0,20,252,16,252,69,1,114,13,139,3,165,10,10,35,54,14,45,253,206,255,59,254,209,236,216,252,66,255,196,253,106,255,164,248,16,254,44,250,4,253,55,255,163,253,56,248,130,255,90,68,153,13,45,248,66,4,0,0,255,182,29,253,12,255,184,255,135,0,26,0,123,241,241,255,91,8,169,1,8,0,115,251,25,255,133,0,234,248,24,4,140,247,230,15,144,63,56,255,189,255,227,254,13,252,224,192,116,0,17,255,138,0,194,1,252,254,25,2,9,7,239,251,101,8,54,240,138,36,36,49,165,248,194,3,151,253,35,235,68,218,40,255,200,255,233,255,241,227,51,4,166,5,219,253,30,253,110,0,96,1,218,1,185,255,36,0,172,6,103,16,219,28,191,24,235,3,78,255,204,251,254,242,111,246,195,255,75,254,254,252,155,248,108,253,169,249,216,244,152,255,255,254,60,254,124,254,192,245,247,21,158,67,207,246,80,2,92,254,118,248,144,184,174,254,235,255,132,3,212,10,203,232,136,254,39,3,182,9,94,0,53,255,143,253,85,0,187,4,174,252,169,4,122,248,120,62,167,255,212,255,170,255,30,255,7,195,62,0,168,255,61,0,142,0,156,255,140,0,98,251,62,3,115,251,88,7,143,15,250,247,242,44,237,255,38,14,56,252,255,254,112,224,0,0,223,252,243,1,19,245,162,5,4,0,254,255,13,0,144,252,198,1,16,246,4,0,238,252,182,250,220,62,78,28,127,249,219,255,145,255,67,194,123,243,87,255,191,255,4,3,50,5,92,1,87,2,51,228,176,255,119,255,100,6,224,2,36,239,1,254,18,26,145,45,25,18,143,251,241,255,97,245,143,223,226,250,122,255,222,6,208,0,1,12,108,1,112,237,196,4,144,0,161,248,29,243,232,30,205,17,145,7,93,7,125,27,19,241,13,251,27,255,40,255,50,244,104,247,89,252,230,253,114,252,244,253,34,255,186,242,91,248,192,252,215,252,106,13,151,11,235,22,4,32,62,34,48,253,231,253,203,247,252,239,174,237,146,253,50,251,218,251,74,249,52,250,137,244,211,248,204,249,189,243,223,238,249,22,216,35,183,31,94,15,27,13,193,247,237,235,73,240,80,252,81,253,34,243,158,244,61,238,124,250,101,247,99,248,76,251,169,248,130,249,219,252,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,3,212,0,203,2,158,2,41,3,220,255,254,255,225,255,229,255,217,255,246,255,223,255,247,255,225,255,248,255,227,255,218,255,246,255,221,255,223,255,16,5,36,5,88,255,192,254,209,252,154,255,151,255,255,255,250,255,216,255,152,255,13,0,13,0,25,0,25,0,253,255,64,0,65,0,248,255,241,255,179,253,168,2,174,9,52,1,172,253,235,255,228,255,137,254,251,255,235,255,24,0,89,0,154,255,11,0,244,255,210,255,235,255,24,0,90,0,11,0,33,253,25,254,251,255,132,11,212,1,223,255,242,255,0,0,238,253,243,255,235,255,0,0,0,0,132,0,87,0,0,0,21,0,13,0,0,0,172,255,18,4,194,6,44,4,77,1,114,2,190,255,74,255,187,255,250,255,233,255,146,255,189,255,144,255,235,255,221,255,235,255,217,255,190,255,216,255,244,255,230,1,255,252,234,15,9,11,173,251,242,255,220,255,11,252,25,254,182,255,22,0,136,255,191,0,173,255,132,0,66,253,32,0,204,255,19,1,191,0,241,5,1,253,132,255,224,16,2,4,115,255,221,255,0,0,141,251,192,255,71,0,11,0,251,255,111,254,202,0,32,0,161,255,48,0,7,0,242,254,121,9,243,4,111,13,165,255,114,251,153,254,158,255,46,253,0,0,173,255,69,255,3,254,246,254,13,0,7,0,19,0,172,0,90,0,244,0,250,255,29,251,207,3,173,0,199,15,213,7,161,255,198,255,255,255,28,252,11,255,74,0,13,0,246,255,52,1,16,255,214,255,153,0,137,255,235,255,18,254,28,7,120,2,42,5,14,8,7,4,54,255,232,255,150,255,253,254,192,255,186,255,110,255,205,255,27,255,177,255,90,255,142,255,217,255,173,255,127,255,65,254,40,19,244,0,197,254,10,248,244,255,69,250,253,255,250,255,3,255,134,0,6,0,183,255,248,255,94,0,4,0,201,255,98,2,30,0,217,255,48,255,178,251,207,1,64,254,21,22,254,255,182,255,243,255,244,255,98,248,242,255,5,0,31,0,251,255,226,255,12,0,71,0,124,1,97,255,154,0,131,18,40,10,184,248,88,3,238,249,165,250,100,254,44,255,212,255,109,255,16,253,27,2,39,1,9,255,121,255,97,0,193,1,246,0,80,255,81,0,102,7,205,13,35,0,230,255,97,8,37,255,6,253,0,0,0,0,232,254,104,254,252,255,249,255,3,0,5,0,0,0,8,255,50,254,252,255,3,0,117,245,49,7,232,15,139,9,46,6,68,254,49,255,12,252,148,254,104,255,47,1,158,2,55,254,146,1,238,254,161,253,4,1,79,255,119,254,20,255,180,252,30,13,218,23,221,251,231,253,213,255,80,253,29,247,188,255,239,255,173,0,58,1,29,251,202,255,217,0,139,1,229,255,110,0,200,0,222,255,227,4,248,3,204,11,162,8,165,5,161,255,193,255,212,253,214,254,129,255,179,255,26,255,69,255,88,255,119,255,105,254,146,255,167,255,246,254,62,255,51,8,229,8,198,15,205,13,202,244,243,254,196,254,29,252,6,253,9,254,221,254,251,253,207,253,60,254,21,254,153,252,111,1,143,1,195,2,107,2,144,1,166,251,68,33,118,9,163,251,247,255,181,255,182,238,154,254,180,255,27,0,48,255,67,2,197,255,164,0,21,251,27,0,181,255,68,2,165,0,210,238,37,248,72,15,153,246,210,8,100,251,9,255,90,252,159,254,201,254,228,253,26,4,224,1,122,253,217,254,63,2,94,2,21,1,229,253,75,1,231,6,89,250,144,16,16,24,11,253,66,255,129,255,183,251,244,246,221,255,156,0,55,254,118,1,104,253,32,2,198,249,81,0,190,255,195,0,28,1,58,6,73,250,11,4,26,27,128,7,101,255,126,255,191,255,134,244,31,255,142,0,156,255,92,0,93,253,107,2,74,254,70,255,171,0,135,255,211,252,206,253,108,18,245,15,177,253,117,9,237,255,179,250,6,252,235,255,155,254,162,0,140,0,105,251,236,255,170,0,147,0,83,0,72,253,165,253,87,0,16,6,74,34,89,252,98,1,112,250,109,255,161,237,203,255,249,255,133,255,193,252,88,0,245,1,223,255,67,255,20,0,134,0,251,2,175,255,30,0,223,18,177,238,41,0,57,250,96,244,112,250,82,251,0,0,123,255,228,253,26,5,244,255,11,0,180,1,112,254,3,0,109,3,220,252,7,0,244,254,42,8,168,4,238,3,109,6,245,18,246,254,170,255,195,255,91,255,99,250,104,255,128,255,183,255,46,255,137,255,155,255,149,253,159,254,214,254,25,254,82,9,80,22,146,5,162,255,70,5,165,254,57,248,132,255,0,0,145,255,192,252,49,255,15,254,13,0,32,0,8,0,60,255,42,254,139,255,7,0,187,250,67,4,123,6,187,34,57,1,145,255,184,255,88,255,39,237,251,255,89,0,136,0,146,255,220,2,176,253,124,252,25,0,236,255,225,255,86,255,252,38,148,3,131,254,216,252,88,0,64,232,205,255,248,255,217,255,0,0,210,253,232,0,21,0,236,1,45,0,238,255,203,255,252,255,2,0,4,0,34,9,249,251,8,255,88,15,84,25,179,254,192,255,253,255,82,252,250,245,147,0,35,0,241,255,208,253,247,0,59,0,99,252,152,1,98,0,237,249,22,24,40,251,175,254,88,14,3,251,240,246,163,255,250,255,201,252,157,255,210,1,126,0,231,255,154,250,22,1,75,0,224,1,160,255,230,255,30,1,25,17,124,255,228,245,165,6,1,19,111,251,255,255,103,254,80,255,92,250,35,0,179,2,236,255,58,254,13,0,12,1,237,250,39,0,0,3,7,254,34,10,223,12,104,15,201,5,170,2,102,254,106,253,75,252,123,255,228,255,247,253,144,253,231,252,22,255,215,254,156,254,148,255,119,255,92,255,195,255,55,16,112,2,47,3,133,17,181,8,228,251,233,255,216,255,52,251,209,254,98,255,50,255,225,255,144,251,86,255,33,255,203,253,172,255,145,255,158,253,9,242,151,254,60,19,231,10,90,18,244,252,249,255,56,250,37,254,189,250,178,255,50,4,108,0,97,2,61,0,185,252,1,4,103,0,124,250,224,252,42,246,207,14,175,33,59,1,161,9,125,254,147,252,70,238,250,255,142,254,70,2,45,5,53,248,48,0,183,255,90,255,122,1,198,253,239,250,209,255,77,253,173,11,229,38,91,254,138,251,227,255,223,253,93,232,246,255,177,255,126,0,164,1,231,248,239,255,76,0,0,1,208,255,208,0,182,2,227,255,130,248,104,0,138,243,174,242,168,238,32,255,0,0,147,253,59,253,77,251,12,0,139,254,20,0,113,254,21,0,104,253,249,253,28,0,160,252,100,252,225,242,124,249,62,7,27,27,150,5,80,253,87,255,47,255,133,244,132,255,171,254,124,1,188,0,142,5,194,2,239,252,37,1,145,0,95,255,162,253,42,0,234,37,92,12,72,252,139,3,0,0,138,233,157,253,201,255,206,255,231,255,248,255,174,248,2,0,52,2,183,0,254,255,231,253,81,255,52,0,71,6,17,3,46,11,231,16,235,12,99,255,219,255,12,254,137,251,101,253,179,255,232,254,119,255,88,254,49,255,12,253,188,254,98,255,191,253,151,252,145,26,88,13,179,8,146,6,111,243,249,244,56,253,210,254,84,255,137,253,118,250,100,252,48,254,70,253,162,254,28,255,55,5,158,2,181,1,74,1,131,13,58,15,108,1,161,30,176,245,38,253,97,252,248,255,87,241,87,254,201,252,180,255,170,255,137,249,183,248,82,255,45,2,116,2,58,0,239,4,242,232,126,242,95,246,162,248,238,16,178,247,38,253,141,254,39,255,134,251,35,251,136,252,248,253,89,253,114,254,229,254,25,6,147,3,140,2,243,1,130,241,109,4,169,30,115,13,41,255,184,252,178,255,80,241,45,253,254,255,0,1,241,6,225,253,11,3,18,255,143,249,208,255,14,0,103,0,45,0,36,16,12,11,2,0,140,239,236,239,238,251,24,254,0,0,197,251,246,251,55,253,0,0,0,0,38,4,215,2,0,0,14,4,198,2,0,0,222,251,243,22,48,33,252,248,96,5,6,249,197,247,202,238,59,255,141,255,62,255,25,244,132,2,163,3,19,254,55,253,150,0,128,2,158,3,61,255,150,0,71,12,155,13,218,13,231,252,137,17,165,253,28,253,1,253,218,255,50,251,100,253,88,253,14,253,152,0,168,0,171,0,163,252,70,252,53,252,217,0,29,11,29,31,111,14,200,234,138,15,18,254,223,240,191,252,247,248,58,252,153,250,127,253,252,248,175,3,81,10,201,4,77,253,114,248,127,252,39,5,2,6,150,0,227,27,1,8,25,12,112,255,255,255,218,243,0,255,183,253,242,255,98,253,191,255,64,255,238,255,132,252,222,254,228,255,187,250,125,254,106,2,96,29,121,18,18,255,211,242,233,255,132,242,171,250,253,255,74,253,229,254,78,255,134,247,8,0,109,0,68,0,127,0,12,6,205,3,207,255,149,11,59,244,232,30,164,27,51,248,232,253,214,253,19,241,16,244,13,255,33,2,105,250,175,5,0,251,21,5,167,242,105,1,145,254,196,3,94,3,139,9,95,252,167,251,205,37,42,16,148,254,204,255,181,255,172,233,235,251,138,0,166,0,193,255,93,250,37,2,145,2,151,253,234,0,25,1,116,246,174,7,237,12,101,39,185,242,57,8,20,255,100,253,193,231,63,253,242,254,115,254,70,251,11,248,152,1,174,2,44,8,4,255,87,254,241,250,180,1,144,255,168,250,164,34,214,18,0,8,0,0,142,255,64,237,117,250,0,255,247,255,61,0,228,2,33,0,146,1,206,245,14,0,171,0,172,251,166,253,219,245,182,1,209,248,85,24,98,28,101,254,245,255,50,255,192,246,105,243,69,0,221,254,49,0,219,3,90,255,187,2,128,4,62,255,48,3,53,245,126,13,41,2,167,35,82,19,36,234,40,253,238,255,36,236,43,250,137,248,140,255,124,248,204,254,238,251,90,255,61,245,155,4,188,0,45,12,153,6,236,253,105,253,230,47,191,9,20,252,239,255,230,255,39,220,132,254,195,255,235,255,142,1,240,1,81,0,101,0,181,248,224,255,216,255,239,2,152,0,204,247,37,5,27,250,161,44,181,11,243,254,151,255,117,255,225,224,220,253,168,0,63,255,121,0,184,5,106,252,28,4,128,1,16,255,20,1,214,247,169,4,119,245,251,43,253,20,5,253,170,255,68,254,199,225,30,249,221,255,196,0,205,252,61,7,121,254,116,3,148,241,55,0,131,255,13,2,250,0,101,9,41,254,71,43,203,0,14,3,159,254,243,255,189,226,254,255,219,255,69,0,166,249,62,1,227,255,5,0,119,255,142,255,22,0,239,253,247,255,177,248,53,22,26,44,154,245,73,5,43,255,76,248,156,225,80,254,145,255,137,2,9,5,179,240,208,254,155,3,42,7,154,0,43,254,92,252,220,0,72,241,39,23,235,243,177,19,92,20,158,252,160,247,184,253,241,249,134,249,83,5,57,253,95,4,135,4,224,248,183,3,174,4,163,248,216,3,189,249,14,246,30,37,81,23,120,246,136,7,117,254,121,234,129,247,149,254,30,255,197,5,159,3,122,242,133,254,135,5,121,3,43,1,162,251,66,253,31,1,157,236,240,13,240,17,132,21,123,13,33,250,247,252,249,250,197,248,41,253,56,4,111,5,24,252,132,6,81,251,249,249,21,4,17,253,57,252,120,251,209,6,230,245,143,15,147,42,241,249,70,255,104,254,56,252,174,227,110,255,19,1,88,254,116,2,119,251,184,6,167,245,165,0,12,255,121,1,8,4,99,3,56,254,41,253,41,13,46,46,211,255,244,255,224,255,76,253,173,222,24,0,38,0,236,255,78,255,93,0,149,0,143,253,73,1,13,2,129,246,111,29,118,9,134,7,125,5,63,6,118,242,154,254,30,255,136,255,100,255,166,251,138,252,228,254,122,253,49,255,91,255,33,253,20,255,68,255,119,255,17,4,33,253,114,255,153,51,235,5,190,255,223,255,255,255,103,214,116,255,46,0,9,0,250,255,185,252,81,2,114,0,160,255,68,0,13,0,58,251,14,31,89,26,92,250,16,252,161,10,239,240,39,245,129,255,194,255,60,254,55,243,188,2,82,2,233,1,159,1,168,255,216,250,160,251,239,0,167,0,110,237,157,250,170,17,190,253,155,233,157,250,140,255,32,251,236,255,42,248,112,254,32,5,124,1,89,255,208,255,159,0,129,249,30,254,46,6,54,255,148,12,90,23,35,23,126,9,127,245,135,253,123,247,163,247,152,254,71,254,105,251,116,251,143,247,35,254,138,252,146,252,16,2,213,3,204,3,142,1,121,1,32,5,154,54,66,250,165,2,248,255,151,255,107,209,124,255,228,255,226,255,191,254,161,251,33,0,117,0,230,4,241,255,202,255,191,253,60,0,149,242,114,26,58,1,139,252,54,22,48,253,19,245,250,255,209,255,75,248,139,5,65,0,127,255,71,255,110,1,16,0,168,4,211,246,147,255,51,1,99,12,70,34,44,247,119,10,253,11,155,253,165,237,200,254,74,254,193,253,94,249,181,1,186,4,250,253,101,250,113,1,174,253,149,249,167,1,11,254,181,21,229,5,31,21,131,255,38,227,164,248,117,255,8,249,0,0,254,242,1,254,214,248,14,254,42,0,11,0,41,0,201,9,168,2,134,9,200,255,234,244,35,10,172,51,15,1,1,7,21,254,101,254,72,214,252,255,60,255,193,1,243,8,209,247,47,0,214,255,37,255,54,1,228,254,89,250,227,255,152,2,234,254,118,58,183,3,57,253,230,255,252,255,152,202,201,255,226,255,11,0,162,253,253,0,218,255,16,0,155,252,28,0,244,255,138,2,41,0,40,3,234,6,210,33,231,22,50,250,217,255,65,255,32,238,206,247,122,255,169,255,85,254,89,252,223,254,135,253,230,243,73,0,160,0,17,3,19,2,247,11,3,6,208,7,226,253,104,37,196,253,112,255,12,255,239,255,35,234,225,254,138,254,68,255,101,0,51,0,66,0,2,249,124,252,111,251,61,1,2,2,3,55,189,254,128,3,133,252,240,255,182,208,250,255,207,255,208,255,70,254,10,0,21,1,228,255,254,252,17,0,27,0,254,2,239,255,48,0,124,3,158,0,117,20,49,43,189,249,208,255,255,255,118,249,218,226,100,255,248,255,227,254,206,255,166,253,150,255,50,242,87,0,15,0,0,2,58,4,180,249,4,10,56,239,238,48,78,22,98,255,111,254,154,251,152,218,58,248,252,0,90,254,160,2,208,4,88,248,212,12,49,2,131,252,217,5,243,238,25,19,34,229,100,2,221,23,145,18,77,250,185,244,234,255,27,247,157,250,4,8,74,255,1,1,225,248,4,10,28,255,118,250,203,7,79,255,20,249,237,11,6,254,99,9,153,37,42,5,199,253,241,255,160,254,233,233,150,255,94,0,64,254,74,0,254,248,41,1,124,250,10,255,40,0,62,255,247,252,14,253,104,50,128,17,191,247,191,5,222,255,77,216,55,251,240,254,124,255,82,2,206,0,55,242,159,255,128,6,65,2,67,0,121,251,110,254,189,0,159,16,196,5,191,19,89,9,96,11,175,251,124,255,233,249,163,254,251,253,129,254,223,250,57,254,147,253,41,255,30,253,12,253,250,254,126,252,87,254,165,250,23,2,137,5,12,57,27,252,142,255,239,255,134,255,39,205,196,255,44,0,118,0,210,255,198,4,35,254,17,251,173,255,32,0,86,0,120,3,248,20,48,249,243,15,44,251,169,14,34,249,71,255,7,252,163,255,164,252,59,2,198,250,178,1,149,1,125,255,52,1,51,251,143,1,89,252,27,1,52,6,231,243,79,56,115,14,109,251,102,255,183,253,117,206,189,252,173,255,44,1,139,250,165,10,154,254,187,2,73,243,113,0,35,255,6,4,8,1,212,0,53,31,255,36,240,242,217,7,254,255,201,240,157,234,86,253,10,255,153,255,133,255,246,237,43,0,94,6,141,7,230,255,45,252,119,251,154,1,88,3,246,8,141,253,18,27,17,27,212,255,191,254,232,255,141,244,142,244,137,255,32,0,87,0,150,254,54,252,9,1,150,254,54,252,9,1,141,244,53,9,165,239,250,27,3,30,43,13,173,254,210,251,197,243,237,241,75,253,90,2,250,251,38,7,175,251,171,7,225,242,27,254,93,3,62,250,211,249,94,1,233,17,229,54,21,241,194,4,249,255,253,250,234,208,134,252,166,255,159,255,212,254,163,240,81,0,44,4,203,12,230,255,171,254,235,251,28,1,80,243,203,13,219,1,89,8,191,45,124,253,7,253,243,255,234,254,76,223,188,2,94,0,154,255,167,1,52,254,194,255,18,9,36,246,172,254,8,250,55,244,12,15,189,6,248,32,137,20,213,253,119,252,75,255,4,239,106,249,197,2,61,1,107,254,18,6,64,248,135,252,200,3,44,251,215,253,108,245,115,252,124,12,152,60,32,246,42,4,206,255,145,253,162,198,122,254,187,255,177,0,93,3,46,244,116,255,237,1,89,9,59,0,48,255,15,252,164,0,191,3,214,242,145,37,73,37,31,249,200,255,75,253,243,233,71,234,67,255,197,0,205,253,186,7,210,253,171,7,29,234,103,0,150,254,10,4,2,4,151,29,20,46,19,237,180,12,89,249,82,242,211,222,103,250,123,253,79,255,178,234,192,8,160,13,33,250,219,246,193,3,19,3,202,4,9,254,82,1,9,25,186,6,228,6,161,239,127,23,53,246,75,255,67,255,208,251,96,247,95,253,78,253,71,255,103,6,184,1,195,1,207,246,136,253,121,253,2,6,140,246,129,47,174,19,6,5,206,247,155,254,189,220,243,249,156,255,244,254,4,7,232,2,100,241,190,0,70,252,117,254,202,254,21,6,133,2,164,0,72,247,195,250,78,28,254,36,71,248,208,254,147,255,124,243,158,234,18,255,74,255,219,3,81,2,10,5,7,3,164,239,243,254,95,255,106,3,119,4,6,4,122,27,135,16,15,6,5,12,192,255,53,244,187,251,110,255,191,253,70,254,246,254,232,248,159,255,102,253,112,254,63,255,215,250,230,252,221,254,1,20,59,46,35,254,43,249,250,8,191,249,155,222,243,255,70,255,190,254,141,241,149,0,88,1,34,2,240,4,206,255,50,253,132,249,66,0,245,0,0,243,243,14,33,23,248,38,235,251,92,253,130,252,164,247,69,232,190,255,9,3,179,4,153,250,235,7,230,246,235,241,44,255,244,0,121,1,124,2,229,14,86,22,198,237,172,242,42,22,137,252,53,248,207,250,58,253,83,248,205,250,62,4,92,6,26,3,167,4,52,252,216,250,68,248,80,6,157,4,68,5,168,241,98,51,26,27,102,249,146,255,201,252,191,214,134,244,82,255,46,1,198,251,132,11,198,253,19,6,62,234,139,0,133,254,77,5,204,2,103,8,254,241,37,27,99,47,56,251,230,254,239,252,125,244,234,220,165,255,214,1,112,252,241,5,200,249,95,10,231,235,160,0,244,254,7,2,138,3,183,244,175,37,36,40,88,245,227,3,3,254,208,233,211,230,58,254,196,255,165,6,20,7,93,232,31,254,70,6,175,6,175,0,182,253,144,253,165,0,33,24,136,8,43,2,193,7,189,25,231,246,221,254,238,255,16,255,166,245,201,252,47,255,182,255,20,253,248,254,189,255,76,246,146,252,33,255,226,252,20,254,135,1,14,67,87,253,240,0,242,255,247,255,189,185,228,255,253,255,11,0,3,2,102,254,236,255,16,0,201,2,7,0,251,255,4,255,10,0,84,49,72,21,186,245,195,11,121,245,251,217,237,248,90,254,215,253,69,254,153,239,235,7,106,3,239,246,23,252,227,1,29,8,128,3,80,254,239,1,212,241,234,253,119,13,90,27,95,26,221,252,239,255,43,253,80,244,34,245,138,255,251,2,112,0,14,6,228,0,63,250,215,5,220,0,116,250,187,244,137,235,13,23,171,31,66,14,238,18,117,249,179,247,84,240,211,252,103,250,95,7,32,10,152,244,143,4,221,250,242,248,14,6,47,249,162,246,200,251,13,24,22,26,3,16,206,251,44,9,246,246,94,245,255,251,186,255,176,254,51,246,252,249,122,249,147,1,181,1,12,1,142,252,67,252,181,253,153,0,55,4,227,62,242,0,143,252,154,6,185,255,52,194,253,255,209,255,82,255,220,251,240,255,18,255,58,0,97,3,13,0,145,255,131,249,231,255,90,0,234,254,227,0,241,251,100,6,49,66,252,255,253,255,191,255,93,255,138,187,3,0,239,255,14,0,27,0,234,255,103,0,31,1,22,255,50,4,99,249], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2064544);
/* memory initializer */ allocate([162,61,82,250,62,2,165,253,149,255,165,196,127,255,236,255,234,255,0,0,120,5,215,253,51,0,69,2,203,255,21,0,103,0,247,255,3,0,253,255,102,9,188,252,168,51,57,31,86,239,159,254,214,255,79,214,197,240,169,251,122,0,106,248,162,2,106,251,151,1,205,230,114,2,39,255,115,13,33,8,112,12,32,56,248,242,207,8,247,248,149,253,200,206,89,253,202,254,58,255,23,245,136,2,110,11,74,254,71,248,203,1,94,1,44,6,146,254,247,0,94,249,180,66,200,9,229,253,122,253,80,255,122,186,130,254,239,255,231,255,234,6,3,1,206,245,201,255,49,2,82,0,189,255,161,2,98,0,235,255,71,9,227,252,120,245,147,56,7,21,168,254,218,255,69,254,253,205,23,249,115,0,135,1,125,255,204,247,193,2,80,9,244,252,6,1,118,3,105,237,125,245,250,9,88,238,101,37,159,41,70,254,114,254,33,251,38,234,238,228,163,1,26,253,192,2,36,6,44,250,81,10,214,6,131,249,123,11,174,231,20,239,209,238,135,249,16,19,207,28,135,251,99,251,89,255,83,250,9,243,117,251,74,254,68,254,10,5,30,5,237,1,158,7,188,7,233,2,108,247,86,242,237,28,227,38,133,10,101,244,22,253,237,242,95,232,70,254,230,253,45,6,77,8,109,238,63,2,63,251,156,249,134,253,62,5,13,7,232,1,61,26,48,241,59,30,238,10,161,13,62,245,147,252,185,241,35,254,25,253,18,6,155,243,255,6,133,251,135,2,215,250,106,250,39,3,144,249,173,253,143,20,42,38,135,13,45,4,125,240,102,249,62,233,36,253,187,255,62,252,190,243,168,251,239,247,169,254,131,253,30,255,251,4,64,9,71,3,3,1,219,4,182,245,132,65,79,7,76,1,162,255,89,254,239,188,43,255,250,255,199,0,7,251,136,10,114,255,44,1,133,248,231,255,53,0,173,254,219,255,131,10,20,11,33,12,79,22,209,18,70,254,21,254,180,253,57,248,120,250,47,254,2,254,231,253,86,252,36,252,198,251,233,252,190,252,111,252,113,249,14,17,128,11,42,28,43,14,137,4,117,251,239,253,156,243,221,252,174,255,240,252,127,248,241,250,58,252,117,253,196,249,203,254,48,255,1,254,255,254,64,54,111,15,97,253,255,246,26,13,3,210,71,252,229,255,188,254,82,253,235,242,57,2,161,0,162,7,44,2,162,255,229,244,215,252,137,0,216,1,141,27,215,22,113,11,186,32,70,237,36,244,218,247,245,253,68,239,133,250,43,246,19,251,235,251,233,241,82,244,38,250,16,8,175,6,89,3,147,9,113,247,38,50,222,35,181,240,81,6,219,254,181,216,230,235,89,252,97,255,181,6,204,4,229,227,245,253,252,11,146,8,216,0,13,251,118,252,130,1,239,236,58,51,135,22,77,254,59,16,82,250,254,214,18,248,245,255,226,251,67,15,182,6,248,237,127,255,92,1,153,0,214,4,2,243,74,250,110,0,163,30,30,251,210,0,194,27,173,235,86,241,161,255,254,255,246,243,140,249,86,2,156,255,16,0,182,242,30,2,165,255,187,9,115,254,66,0,209,8,97,246,232,31,215,56,188,240,36,7,142,254,24,240,133,205,92,252,52,255,204,4,140,8,170,227,181,253,156,7,143,13,18,1,113,252,169,249,180,1,213,249,91,1,240,254,81,245,159,62,104,255,249,255,252,255,56,254,186,194,33,0,230,255,5,0,249,254,58,0,211,255,9,6,172,254,10,1,116,10,73,231,48,5,229,19,41,236,193,29,117,246,149,255,209,249,218,249,43,242,1,2,175,7,99,254,87,248,155,1,42,6,125,11,151,253,193,246,57,9,214,12,99,238,42,44,17,43,193,245,109,253,39,251,134,225,5,227,92,254,136,3,37,247,40,12,93,247,218,11,72,226,14,2,46,253,18,7,229,6,191,21,189,69,86,241,142,4,249,253,156,248,1,180,164,252,173,255,240,255,77,232,251,4,250,15,116,254,9,251,11,1,176,0,54,2,137,255,37,0,168,247,88,254,188,59,244,19,144,249,234,254,246,255,63,200,199,249,91,255,201,255,201,7,140,1,154,2,132,0,96,237,42,255,214,255,2,6,2,2,219,8,31,243,245,9,179,64,233,252,199,254,105,253,116,254,151,190,218,255,200,1,160,254,1,2,13,247,5,13,240,245,109,0,97,255,123,0,31,3,71,14,107,7,220,242,135,24,222,48,209,252,36,255,78,253,154,246,176,218,89,254,238,2,134,1,136,250,40,253,9,5,25,245,86,250,8,10,70,237,116,31,237,8,207,231,18,20,115,23,139,240,194,254,219,246,181,249,105,247,157,251,228,11,96,3,35,246,52,253,150,7,122,244,187,252,221,8,166,248,126,254,13,247,255,29,27,60,93,245,247,255,192,254,241,241,140,199,60,254,202,255,181,0,50,4,106,1,104,8,212,227,192,255,132,254,252,4,253,9,217,10,107,251,144,15,23,51,204,9,42,254,172,255,55,252,56,215,128,254,198,0,93,253,29,1,87,247,168,3,148,243,87,254,179,0,158,253,46,248,169,248,235,6,132,245,65,65,41,7,41,255,65,255,73,254,120,189,51,255,203,0,204,254,34,1,124,7,243,248,176,10,210,0,58,255,44,1,179,248,28,4,143,17,159,60,187,5,64,240,189,255,47,251,148,198,125,255,32,252,224,254,27,252,95,239,162,255,110,254,147,250,3,1,82,4,235,14,105,1,194,11,240,9,57,27,135,29,204,7,215,253,117,254,108,244,97,242,13,255,45,254,0,251,198,251,148,250,106,251,113,243,146,254,202,254,175,252,103,252,167,235,181,248,9,34,111,40,13,6,136,249,44,255,230,237,116,230,110,255,175,253,210,10,225,3,219,12,156,4,127,234,236,1,176,0,200,252,45,252,38,239,65,33,145,3,123,29,93,245,145,251,185,238,206,255,108,242,60,254,193,8,240,0,38,254,195,7,175,240,92,254,51,253,135,5,151,0,230,4,129,50,61,251,144,9,221,6,159,24,36,216,166,255,147,254,68,255,135,246,194,3,116,248,182,0,150,250,130,0,250,254,146,236,213,1,83,252,92,253,65,25,36,16,95,12,88,12,65,22,9,246,238,251,156,253,159,253,67,248,162,249,31,251,226,252,33,251,227,252,157,253,56,247,99,250,179,251,181,251,204,241,251,18,226,73,201,250,42,3,217,252,95,250,180,170,148,255,216,255,54,4,102,16,23,234,216,254,140,1,5,6,179,0,16,255,88,252,66,0,140,34,184,30,142,2,33,240,208,233,90,237,66,241,230,255,17,252,79,248,107,239,159,254,198,254,145,8,158,7,162,0,250,11,166,10,226,0,128,250,67,7,74,10,12,36,228,3,248,36,45,255,89,254,179,235,196,255,165,234,213,254,233,251,53,250,143,255,96,255,207,253,206,251,15,250,46,235,193,253,133,11,228,47,50,40,15,254,153,240,238,253,42,220,193,230,241,255,75,252,98,247,196,248,236,225,89,0,116,1,56,1,197,2,134,11,172,9,137,255,169,244,16,6,19,58,242,38,16,254,254,253,109,255,77,203,76,232,241,255,19,1,74,10,128,250,230,6,80,252,169,220,169,255,47,0,194,1,46,1,171,12,42,32,162,29,45,13,103,8,126,253,214,239,72,242,74,253,230,254,162,249,35,250,28,241,101,253,97,249,231,249,87,254,199,251,28,252,70,254,97,218,60,0,173,13,239,20,166,39,226,233,0,0,20,253,40,249,112,231,35,0,10,8,244,255,78,12,237,255,135,251,79,23,219,255,135,247,8,243,38,229,7,246,186,234,109,247,95,225,188,244,115,254,238,248,218,254,87,241,209,251,19,247,176,252,103,252,170,254,39,253,38,243,59,251,210,245,230,251,171,242,139,251,22,18,44,53,217,30,57,253,177,255,228,250,210,211,34,241,19,255,196,3,66,1,20,11,180,3,249,240,109,6,38,2,73,247,95,230,58,17,210,233,70,31,104,240,227,14,93,251,80,248,184,240,51,252,138,252,248,5,149,247,215,10,50,4,153,250,159,7,255,251,41,5,186,248,160,3,27,22,15,45,155,8,60,254,1,28,94,248,71,224,216,254,244,255,191,243,112,240,7,253,241,249,156,0,62,1,60,0,84,246,72,236,60,252,197,0,98,11,158,244,157,13,131,240,107,53,250,253,250,253,27,253,65,252,106,211,6,2,148,253,108,2,193,2,63,253,75,3,127,246,128,9,163,244,238,12,163,30,115,7,254,3,178,34,36,31,85,241,34,255,193,255,49,237,217,240,111,252,23,254,137,255,100,239,246,251,214,253,24,241,96,252,15,254,30,239,239,53,59,37,156,5,76,6,243,6,140,210,88,234,131,255,98,255,63,255,160,224,70,251,189,252,178,250,86,252,115,255,37,250,245,251,100,255,81,255,52,53,39,235,74,21,41,247,187,6,198,211,54,249,235,248,200,254,75,255,84,17,77,238,239,6,89,7,31,253,240,2,104,250,49,2,195,253,238,0,177,20,182,32,168,34,14,30,138,25,80,249,72,239,60,237,227,241,207,245,109,245,204,244,74,238,73,246,164,240,186,239,191,247,243,242,44,242,2,244,176,248,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,198,34,0,160,25,156,0,20,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,88,113,33,0,160,25,156,0,24,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,248,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,160,34,0,112,0,0,0,64,177,31,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,177,15,176,15,166,15,163,15,161,15,160,15,147,15,145,15,144,15,129,15,128,15,113,15,112,15,97,15,96,15,81,15,225,0,193,0,177,0,161,0,160,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,222,0,46,7,118,5,110,0,117,0,85,0,19,0,51,0,13,0,7,0,210,7,82,0,101,0,206,0,131,1,62,0,1,0,46,0,53,15,3,0,67,2,26,0,6,0,165,1,67,0,18,0,67,14,182,0,22,0,53,1,118,1,67,6,53,0,30,0,53,7,131,2,37,1,174,0,210,0,101,1,3,1,3,6,229,0,67,12,181,2,165,4,165,0,67,4,101,2,118,4,18,2,18,1,118,3,46,1,210,2,131,0,131,4,94,1,165,6,53,3,94,0,37,0,210,1,246,0,210,3,46,3,181,3,90,0,3,2,165,2,210,11,78,0,50,0,181,1,181,0,101,10,37,2,118,2,14,0,10,0,229,3,67,1,229,1,54,0,146,0,5,0,9,0,101,6,118,0,195,0,58,0,21,0,35,0,2,0,11,0,0,0,8,11,11,7,7,7,6,6,4,3,11,8,10,8,9,6,4,9,12,10,11,7,5,9,11,10,12,8,6,10,11,12,9,7,12,10,9,8,10,9,9,11,9,12,10,11,11,12,12,11,10,9,10,10,10,11,11,9,11,11,9,10,10,8,12,11,10,7,11,11,12,8,6,10,10,12,10,10,7,5,10,9,10,8,8,6,4,11,11,8,6,7,6,5,4,2,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,177,15,176,15,166,15,163,15,161,15,160,15,147,15,145,15,144,15,131,15,129,15,128,15,113,15,112,15,97,15,96,15,81,15,80,15,65,15,241,0,209,0,193,0,177,0,176,0,161,0,160,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,238,0,165,3,115,11,78,0,53,0,21,0,35,0,19,0,13,0,7,0,115,6,243,1,254,2,150,0,51,1,30,0,1,0,22,1,245,0,245,3,115,4,82,0,26,0,213,1,37,0,115,0,51,6,134,0,54,0,46,1,85,1,6,0,85,0,14,0,6,1,62,2,146,1,117,0,115,1,174,1,213,0,245,8,46,0,254,1,6,4,174,0,62,14,6,2,62,1,115,3,85,13,62,6,51,14,62,3,245,1,115,2,62,0,165,6,146,0,213,3,245,4,62,5,22,0,254,0,165,7,37,1,6,5,146,2,190,0,37,4,115,15,245,2,86,0,51,2,165,2,37,12,126,0,38,0,85,3,51,0,85,5,165,1,6,3,70,0,10,0,37,2,110,0,165,0,18,0,243,0,5,0,9,0,62,7,115,7,179,0,50,0,101,0,3,0,2,0,11,0,0,0,0,0,0,0,0,0,8,11,12,7,7,7,6,6,4,3,11,9,10,8,9,6,4,9,12,10,11,7,5,10,11,11,12,8,6,9,11,11,9,7,11,11,9,8,10,9,9,12,9,9,11,9,12,10,11,12,12,12,12,11,10,11,10,11,10,10,11,11,9,10,11,9,11,10,8,12,12,10,7,11,11,12,8,6,10,10,12,10,10,7,5,10,8,10,8,9,6,4,11,12,8,6,7,6,5,4,2,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,178,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,150,15,147,15,145,15,144,15,131,15,129,15,128,15,115,15,113,15,112,15,97,15,96,15,81,15,80,15,65,15,64,15,49,15,225,0,209,0,193,0,192,0,177,0,176,0,161,0,160,0,147,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,69,0,68,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,42,0,197,4,163,2,74,0,21,0,5,0,3,0,19,0,13,0,7,0,113,1,50,0,113,3,118,0,66,0,17,0,14,0,170,0,213,4,163,3,163,6,98,0,26,0,213,6,242,7,35,2,213,12,106,0,1,0,246,0,35,6,242,3,234,7,241,1,33,0,213,3,194,8,246,7,242,0,227,0,234,15,197,2,170,1,130,0,163,4,182,0,113,0,178,3,35,0,182,1,163,8,2,0,178,11,197,0,234,2,35,12,246,15,35,4,178,7,197,1,213,7,234,1,234,6,194,2,246,1,213,1,178,1,178,0,241,4,234,3,162,1,162,2,213,2,35,1,213,0,242,1,85,0,178,5,194,4,2,1,97,0,213,5,194,0,241,0,163,0,69,0,22,0,163,1,194,1,213,8,197,3,234,0,10,0,6,0,162,0,54,0,241,2,114,0,34,0,37,0,9,0,246,3,163,10,99,0,18,0,49,0,53,0,51,0,11,0,0,0,0,0,0,0,8,11,12,7,7,7,6,6,4,3,10,8,10,8,8,6,4,9,12,10,11,7,5,11,11,11,12,8,6,9,11,11,12,9,7,11,12,12,9,8,12,10,9,8,11,9,9,12,11,9,12,9,12,11,11,12,12,12,11,10,11,10,11,10,10,11,11,9,11,11,9,10,11,9,12,10,8,11,11,9,7,11,12,11,12,8,6,10,9,12,10,10,7,5,10,8,10,8,8,6,4,11,12,8,6,7,6,6,4,2,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,178,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,150,15,147,15,145,15,144,15,131,15,129,15,128,15,115,15,113,15,112,15,97,15,96,15,81,15,80,15,64,15,49,15,48,15,33,15,33,1,241,0,225,0,209,0,208,0,193,0,192,0,177,0,176,0,163,0,161,0,160,0,147,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,97,0,3,4,177,13,18,0,113,0,86,0,53,0,35,0,13,0,7,0,67,2,211,1,106,2,161,0,162,0,17,0,14,0,170,1,49,5,147,0,34,2,50,0,6,0,242,7,211,4,67,12,114,0,1,0,67,3,242,5,170,4,242,3,49,0,69,0,67,1,170,0,49,11,242,0,195,0,147,6,242,11,3,2,225,0,177,3,211,2,177,0,106,5,210,1,138,0,106,4,226,1,3,0,3,1,177,1,226,2,147,2,106,1,226,4,67,4,33,5,33,3,67,0,211,0,226,0,3,7,210,0,49,7,147,10,147,3,3,8,34,4,131,3,138,1,106,0,33,0,106,9,3,3,82,0,226,12,49,13,138,3,19,0,242,1,147,14,131,0,5,0,210,2,33,1,34,0,234,0,54,0,34,1,147,1,49,3,131,1,170,2,74,0,26,0,49,1,42,0,106,3,10,0,98,0,37,0,9,0,226,6,177,5,83,0,2,0,22,0,21,0,51,0,11,0,0,0,0,0,0,0,8,11,12,7,7,7,6,6,4,3,10,9,10,8,8,6,4,9,12,10,10,7,5,11,11,12,8,6,10,11,11,12,9,7,10,11,12,9,8,12,12,10,8,10,10,9,11,9,9,11,9,12,10,11,11,12,12,12,12,11,10,11,11,11,11,10,11,12,10,12,11,10,10,11,9,12,11,8,12,12,10,8,11,12,9,7,10,11,11,8,6,9,10,12,10,10,7,5,11,8,10,8,8,6,4,11,12,8,6,7,6,6,4,2,0,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,150,15,149,15,147,15,145,15,144,15,134,15,131,15,129,15,128,15,115,15,113,15,112,15,99,15,97,15,96,15,81,15,80,15,65,15,64,15,48,15,33,15,32,15,17,1,1,1,241,0,225,0,224,0,209,0,208,0,193,0,192,0,179,0,177,0,176,0,163,0,161,0,160,0,147,0,145,0,144,0,131,0,129,0,128,0,115,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,246,0,118,6,182,14,243,0,86,0,106,0,57,0,3,0,13,0,7,0,162,0,115,1,202,0,37,0,130,0,25,0,1,0,182,0,118,2,227,2,178,0,98,0,26,0,117,1,227,1,229,11,74,0,41,0,165,7,227,0,10,3,118,1,35,0,66,0,202,5,165,0,66,1,82,0,165,4,2,11,34,13,117,3,101,0,34,5,227,13,10,1,245,0,54,1,117,2,178,1,245,3,227,3,2,0,227,8,162,1,54,11,10,2,118,0,227,12,229,7,10,7,165,3,182,2,54,0,229,1,165,2,227,5,182,7,245,7,54,7,165,11,117,0,2,3,229,15,182,1,2,1,227,4,34,0,165,8,202,1,229,0,10,15,229,5,150,0,118,10,54,3,54,2,18,0,182,3,245,11,115,0,53,0,178,2,10,0,118,4,34,1,22,0,9,0,34,3,245,1,229,3,165,1,202,3,114,0,6,0,165,6,50,0,202,2,138,0,194,0,21,0,14,0,2,7,182,6,99,0,51,0,42,0,5,0,19,0,11,0,0,0,0,0,0,0,0,0,8,11,12,8,7,7,6,6,4,3,9,9,10,8,8,6,4,10,12,10,10,7,5,10,11,12,8,6,11,12,11,9,7,9,11,12,9,7,11,12,12,10,8,12,12,10,9,10,10,9,12,10,9,12,9,12,10,11,12,12,12,12,11,10,11,11,12,11,11,11,12,10,12,12,10,10,12,9,12,11,9,12,11,8,12,12,10,7,11,12,9,7,10,10,11,11,8,6,10,10,12,10,10,7,5,11,8,10,8,8,6,4,11,12,8,7,7,6,6,4,2,0,0,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,150,15,149,15,147,15,145,15,144,15,134,15,129,15,128,15,115,15,113,15,112,15,99,15,97,15,96,15,83,15,81,15,80,15,65,15,64,15,49,15,48,15,32,15,16,15,1,15,0,15,33,1,17,1,1,1,0,1,241,0,240,0,225,0,224,0,209,0,208,0,195,0,193,0,192,0,177,0,176,0,163,0,161,0,160,0,147,0,145,0,144,0,129,0,128,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,83,0,154,0,226,14,211,0,106,0,82,0,58,0,53,0,13,0,7,0,98,0,37,1,66,1,25,0,243,1,41,0,14,0,130,0,218,10,227,2,226,0,34,0,6,0,101,0,227,5,101,7,50,0,57,0,153,15,226,5,153,0,51,0,98,3,153,7,101,15,115,0,74,0,165,2,98,1,66,7,165,1,217,0,66,3,90,0,170,0,243,14,130,1,218,1,130,3,90,3,243,0,115,6,101,1,229,0,243,6,37,2,66,8,90,2,227,7,153,3,165,7,42,7,42,15,227,9,115,2,154,4,229,2,153,11,226,2,115,14,98,5,243,2,42,3,66,15,218,0,153,9,42,1,101,3,165,0,227,0,153,1,227,3,154,1,226,1,115,1,229,6,89,0,227,1,218,2,42,0,10,0,218,6,165,15,66,0,229,1,19,0,226,3,90,1,165,3,66,4,26,0,5,0,165,4,101,2,165,8,37,0,154,2,114,0,22,0,153,5,194,0,66,2,178,0,2,0,21,0,1,0,227,11,226,6,99,0,35,0,18,0,9,0,3,0,11,0,0,0,0,0,0,0,0,0,8,11,12,8,7,7,6,6,4,3,9,9,10,8,9,6,4,9,12,10,10,7,5,10,11,12,8,6,12,11,9,7,10,12,12,10,7,10,11,12,10,8,11,10,8,12,10,9,10,10,10,12,10,10,12,10,12,10,11,12,12,12,12,12,11,11,11,12,11,12,11,11,11,12,10,12,10,11,12,10,12,12,9,11,9,11,8,12,12,9,7,11,12,12,9,7,10,10,11,11,8,6,11,10,12,10,10,7,5,11,8,10,8,8,6,4,12,12,8,7,7,6,6,4,2,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,177,15,176,15,166,15,163,15,161,15,160,15,150,15,149,15,147,15,145,15,144,15,134,15,133,15,129,15,128,15,118,15,113,15,112,15,99,15,97,15,96,15,83,15,81,15,80,15,67,15,65,15,64,15,49,15,48,15,32,15,16,15,0,15,240,14,225,14,49,1,33,1,32,1,17,1,16,1,1,1,0,1,241,0,240,0,227,0,225,0,224,0,209,0,208,0,195,0,192,0,179,0,177,0,176,0,161,0,160,0,145,0,144,0,129,0,128,0,117,0,113,0,112,0,101,0,99,0,97,0,96,0,86,0,85,0,83,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,34,0,178,11,66,9,43,0,114,0,2,0,26,0,57,0,13,0,7,0,123,0,142,0,219,6,234,0,91,1,46,0,6,0,89,9,123,2,14,10,171,1,138,0,18,0,30,0,117,5,91,0,171,2,194,0,21,0,106,3,178,4,153,0,27,0,25,5,25,12,219,0,78,0,66,0,89,1,178,3,14,3,235,0,82,2,171,14,138,1,226,0,171,6,66,2,123,1,82,4,25,3,82,1,91,2,106,1,171,0,82,0,178,5,14,1,142,3,138,2,89,3,25,0,138,7,82,12,142,13,217,14,217,2,98,6,25,1,178,9,171,11,25,13,91,12,178,0,66,5,138,11,178,2,66,1,91,6,142,5,98,0,142,1,138,3,217,0,25,4,98,1,171,3,117,0,178,7,50,0,14,2,171,7,107,0,91,4,178,1,153,1,42,0,117,3,117,7,171,10,217,1,59,0,14,6,66,3,117,1,98,2,10,0,5,0,89,5,106,0,89,13,25,2,14,0,74,0,9,0,25,7,89,0,219,2,210,0,219,1,37,0,1,0,217,6,245,0,53,0,251,0,58,0,11,0,3,0,0,0,0,0,0,0,7,12,12,8,7,7,6,6,4,3,10,9,11,8,9,6,4,12,10,12,10,10,7,5,11,11,12,8,6,10,11,9,7,12,12,10,7,10,12,12,10,8,10,12,10,8,12,10,9,12,11,9,11,10,10,11,11,10,10,10,10,11,11,12,12,12,11,11,11,12,12,12,12,11,11,12,10,12,11,12,10,11,12,10,12,9,12,9,11,8,12,11,8,12,12,9,7,11,11,12,9,7,11,10,11,11,8,6,12,9,12,10,10,7,5,11,9,11,8,9,6,4,12,8,7,8,6,6,4,2,0,0,0,0,0,0,0,16,248,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,212,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,177,15,176,15,163,15,161,15,160,15,150,15,147,15,145,15,144,15,134,15,133,15,129,15,128,15,118,15,117,15,113,15,112,15,102,15,97,15,96,15,81,15,80,15,67,15,65,15,64,15,51,15,49,15,48,15,35,15,33,15,32,15,17,15,16,15,0,15,240,14,224,14,193,14,192,14,81,1,65,1,64,1,49,1,33,1,32,1,17,1,16,1,3,1,0,1,240,0,224,0,211,0,208,0,195,0,193,0,192,0,177,0,176,0,161,0,160,0,145,0,144,0,129,0,128,0,117,0,113,0,112,0,101,0,97,0,96,0,86,0,85,0,83,0,82,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,1,0,98,13,189,0,34,0,155,0,50,0,25,0,5,0,7,0,77,3,154,0,43,1,82,0,107,0,58,0,6,0,253,6,125,1,26,8,27,3,26,3,18,0,17,0,2,2,253,0,27,5,210,0,29,0,26,1,130,7,141,1,123,0,125,6,125,3,33,0,141,14,98,5,141,0,187,0,61,5,42,8,2,0,13,0,2,3,125,0,59,5,59,0,77,10,125,2,253,1,42,4,194,1,26,4,130,1,77,1,98,1,194,0,42,3,154,13,42,1,2,1,125,8,43,7,154,3,98,3,154,1,98,12,194,4,27,13,141,2,98,7,125,14,65,14,154,5,77,2,59,9,43,5,27,1,77,6,61,1,130,3,98,2,65,6,98,4,77,0,194,12,59,3,141,6,65,1,43,13,27,0,65,0,193,0,65,12,226,1,235,0,42,6,130,0,97,0,253,2,125,4,59,1,42,0,61,0,91,0,42,2,194,2,65,2,98,0,170,0,11,0,226,0,26,0,61,3,26,2,106,0,9,0,43,3,43,0,253,4,66,0,107,1,45,0,14,0,65,4,205,0,90,0,171,0,10,0,57,0,3,0,0,0,7,12,8,7,8,6,6,4,3,10,9,11,8,9,6,4,11,10,12,10,10,7,5,10,11,12,8,6,10,11,9,7,12,10,7,12,12,10,8,11,12,10,8,10,12,11,9,12,11,9,11,9,11,10,10,11,11,10,12,10,10,12,11,10,11,11,12,12,12,11,11,12,12,12,12,12,12,11,11,11,11,10,12,12,10,12,10,12,9,12,9,11,8,12,9,8,11,9,7,11,11,12,12,9,7,11,10,11,11,8,6,9,12,10,10,7,5,11,9,11,8,9,6,4,12,8,7,8,6,6,4,2,0,0,0,0,0,16,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,211,15,210,15,209,15,208,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,177,15,176,15,165,15,163,15,161,15,160,15,147,15,145,15,144,15,129,15,128,15,118,15,113,15,112,15,102,15,97,15,96,15,86,15,81,15,80,15,65,15,64,15,49,15,48,15,35,15,33,15,32,15,19,15,17,15,16,15,3,15,1,15,0,15,241,14,240,14,224,14,208,14,192,14,176,14,145,1,129,1,128,1,113,1,97,1,64,1,48,1,35,1,32,1,16,1,0,1,243,0,240,0,224,0,208,0,192,0,177,0,176,0,161,0,160,0,145,0,144,0,133,0,129,0,128,0,117,0,113,0,112,0,102,0,101,0,99,0,97,0,96,0,86,0,85,0,83,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,107,0,190,0,82,0,243,0,91,0,58,0,9,0,7,0,218,0,251,3,35,1,179,0,179,1,46,0,6,0,10,3,90,0,74,0,74,3,114,0,5,0,218,2,115,1,251,4,50,0,19,0,155,3,155,11,30,1,2,0,251,0,30,2,155,0,126,0,26,14,202,3,123,0,251,2,51,0,171,3,99,4,138,0,115,7,30,4,43,0,27,3,90,6,26,1,10,6,218,1,99,9,35,3,171,11,158,5,10,1,171,5,251,12,27,7,158,7,158,15,99,2,155,7,99,5,158,1,171,1,99,14,155,2,202,4,171,13,99,6,27,11,10,2,30,10,26,2,99,0,30,6,251,6,90,2,99,1,115,5,10,0,35,2,27,1,26,12,90,1,99,8,171,0,202,2,178,0,10,10,202,1,163,0,115,11,35,0,18,0,158,3,26,0,202,12,251,1,94,0,155,10,202,0,115,3,158,0,34,0,171,7,30,0,251,14,154,0,11,0,26,4,155,1,99,3,74,1,106,0,21,0,155,6,115,0,35,5,27,0,43,1,3,0,1,0,26,6,62,0,42,0,227,0,59,0,14,0,13,0,0,0,0,0,7,8,7,8,7,6,4,3,10,10,11,9,9,6,4,10,10,9,10,7,5,10,11,12,8,6,12,12,9,6,11,12,10,7,12,10,8,11,8,12,11,8,11,11,9,12,11,9,11,9,12,10,12,11,10,12,12,11,12,12,11,11,11,11,11,12,12,12,12,12,12,12,12,11,12,11,12,11,12,11,10,10,10,12,9,12,9,10,8,12,10,8,12,10,7,11,11,12,10,7,12,11,12,9,6,11,11,12,8,6,12,10,10,10,7,5,11,9,11,9,9,6,4,12,8,7,8,7,6,4,2,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,212,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,178,15,177,15,176,15,165,15,163,15,161,15,160,15,149,15,147,15,145,15,144,15,133,15,131,15,129,15,128,15,113,15,112,15,102,15,97,15,96,15,86,15,81,15,80,15,70,15,65,15,64,15,54,15,49,15,48,15,38,15,33,15,32,15,17,15,16,15,1,15,0,15,243,14,241,14,240,14,227,14,225,14,224,14,211,14,209,14,208,14,193,14,192,14,177,14,176,14,160,14,144,14,128,14,112,14,225,1,209,1,208,1,193,1,177,1,161,1,128,1,112,1,99,1,96,1,80,1,64,1,48,1,35,1,32,1,19,1,16,1,0,1,240,0,224,0,209,0,208,0,193,0,192,0,177,0,176,0,161,0,160,0,149,0,145,0,144,0,133,0,129,0,128,0,118,0,117,0,115,0,113,0,112,0,102,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,52,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,23,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,29,0,124,8,232,10,58,0,28,0,8,0,12,0,50,0,6,0,3,0,165,3,236,1,165,1,128,0,48,0,5,0,1,0,64,0,252,3,212,2,84,1,252,2,60,0,21,0,26,5,0,0,236,2,124,7,210,0,24,0,232,3,236,4,124,2,250,1,34,0,101,7,165,14,84,0,16,0,236,8,172,10,186,3,66,0,93,6,212,10,92,0,40,0,192,3,229,0,92,3,250,4,220,0,165,6,92,7,200,0,165,5,212,4,186,0,192,1,232,5,44,1,232,0,176,1,176,0,93,2,44,0,82,10,92,2,232,1,250,0,72,3,82,6,124,11,101,3,26,3,82,14,26,1,0,2,186,1,172,2,212,6,252,1,186,5,252,13,72,2,232,14,26,11,252,12,101,15,92,11,192,13,124,0,72,5,165,8,252,0,176,3,72,1,172,6,82,2,26,7,232,2,64,2,172,0,26,2,64,1,232,8,172,1,236,0,82,1,165,0,104,0,26,0,108,0,192,5,92,1,37,0,176,5,124,1,20,0,124,4,212,0,232,6,192,0,2,0,93,10,232,4,124,10,212,1,32,0,165,4,176,7,124,3,93,1,42,0,93,0,72,0,124,6,122,0,4,0,252,4,250,2,72,6,0,1,82,0,90,0,13,0,101,1,101,0,165,2,112,0,240,0,61,0,9,0,252,5,72,14,154,0,18,0,221,0,52,0,10,0,14,0,7,0,0,0,0,0,7,12,12,8,7,7,6,6,4,3,10,9,11,8,8,6,4,10,10,12,9,10,7,5,11,10,10,11,8,5,10,11,12,9,6,12,12,9,6,12,12,10,7,11,12,10,7,10,8,12,11,8,12,11,8,11,11,9,11,11,9,12,11,9,12,9,12,10,11,11,10,12,12,11,12,12,11,10,11,12,11,11,11,12,11,12,12,12,12,12,12,12,11,12,11,11,11,11,12,11,12,10,10,10,9,12,9,12,9,12,8,10,8,12,10,8,11,10,7,11,11,12,9,7,12,11,12,9,6,11,11,12,9,6,10,10,11,8,5,12,10,12,9,10,7,5,10,9,11,8,8,6,4,12,12,8,7,8,6,6,4,3,0,0,0,0,0,0,0,16,248,15,247,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,178,15,177,15,176,15,165,15,163,15,161,15,160,15,149,15,147,15,145,15,144,15,129,15,128,15,117,15,113,15,112,15,97,15,96,15,81,15,80,15,65,15,64,15,54,15,49,15,48,15,38,15,33,15,32,15,22,15,17,15,16,15,6,15,1,15,0,15,241,14,240,14,225,14,224,14,208,14,192,14,179,14,177,14,176,14,163,14,161,14,160,14,144,14,129,14,128,14,113,14,112,14,97,14,96,14,80,14,64,14,48,14,16,14,0,14,65,2,64,2,49,2,208,1,192,1,179,1,176,1,160,1,144,1,128,1,112,1,96,1,80,1,64,1,48,1,32,1,16,1,0,1,240,0,224,0,209,0,208,0,193,0,192,0,177,0,176,0,165,0,161,0,160,0,150,0,149,0,145,0,144,0,134,0,133,0,129,0,128,0,117,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,52,0,156,5,128,2,28,0,76,0,189,0,32,0,60,0,10,0,3,0,253,0,140,0,50,3,213,1,85,0,62,0,1,0,228,7,100,2,178,0,162,0,92,0,5,0,162,2,29,1,50,1,108,7,18,0,24,0,228,1,228,5,178,2,50,4,125,1,14,0,93,5,85,9,100,1,40,0,98,13,36,11,222,2,30,0,64,3,20,0,85,5,128,1,221,0,178,1,146,0,108,3,236,0,228,0,192,0,100,12,93,9,222,1,228,10,50,12,162,1,228,6,50,8,164,1,93,1,50,7,29,3,156,15,226,3,226,9,253,2,36,2,29,5,228,2,156,1,178,5,85,3,100,0,108,1,140,3,128,8,128,4,178,6,64,5,128,0,93,7,85,1,36,4,128,6,98,10,128,10,140,7,156,13,140,15,98,5,242,15,100,4,85,11,226,1,50,0,242,7,64,1,228,3,98,6,85,7,128,3,108,2,50,2,29,0,64,0,226,0,93,3,242,0,98,1,253,1,242,3,12,0,162,14,242,5,114,0,228,4,50,15,140,1,157,0,36,3,156,7,108,0,84,0,93,15,29,2,21,0,36,0,162,6,156,0,4,0,98,0,108,5,98,2,0,0,46,0,242,1,36,1,156,3,94,0,16,0,36,7,164,0,222,0,98,3,82,0,13,0,178,3,125,0,226,5,213,0,93,0,53,0,9,0,156,9,34,0,44,0,61,0,8,0,2,0,6,0,7,0,0,0,0,0,0,0,6,12,12,8,7,8,6,6,4,3,10,9,11,9,9,6,4,11,10,10,10,7,5,11,11,10,11,8,5,11,11,11,12,9,6,11,12,9,6,12,12,10,7,10,7,11,10,8,11,8,11,8,11,8,12,12,9,12,12,9,11,12,9,12,12,10,12,10,12,10,10,11,12,12,11,12,11,11,11,12,11,11,11,12,12,12,11,11,12,12,12,12,12,12,12,12,12,12,12,12,11,11,11,11,10,10,10,10,9,9,11,9,11,9,11,8,12,11,8,11,12,10,8,12,12,10,7,12,10,7,11,12,9,6,10,11,12,8,6,11,10,11,8,5,11,9,10,10,7,5,10,9,11,9,9,6,4,12,8,7,8,6,6,4,3,0,0,0,0,16,248,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,182,15,181,15,179,15,178,15,177,15,176,15,166,15,165,15,163,15,161,15,160,15,149,15,147,15,145,15,144,15,133,15,129,15,128,15,113,15,112,15,97,15,96,15,81,15,80,15,69,15,65,15,64,15,49,15,48,15,33,15,32,15,17,15,16,15,1,15,0,15,241,14,240,14,225,14,224,14,208,14,198,14,192,14,182,14,176,14,160,14,144,14,128,14,112,14,96,14,80,14,64,14,51,14,49,14,48,14,32,14,16,14,0,14,240,13,225,13,224,13,192,13,176,13,160,13,80,2,64,2,240,1,224,1,208,1,192,1,176,1,160,1,144,1,128,1,112,1,96,1,80,1,64,1,48,1,32,1,17,1,16,1,1,1,0,1,241,0,240,0,225,0,224,0,209,0,208,0,198,0,193,0,192,0,177,0,176,0,161,0,160,0,149,0,145,0,144,0,133,0,129,0,128,0,117,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,0,0,0,0,0,0,25,0,125,2,132,0,68,0,157,0,61,0,10,0,2,0,3,0,234,0,253,2,122,1,198,1,182,0,38,0,14,0,149,0,96,2,42,3,96,3,6,0,5,0,182,5,106,3,246,6,4,7,250,0,16,0,121,2,212,4,246,0,106,6,29,0,41,0,249,5,70,8,246,4,212,1,56,0,70,4,96,1,29,3,117,0,84,0,212,2,90,0,253,5,64,0,234,6,85,0,96,4,154,0,42,5,160,0,216,0,128,3,125,1,42,9,249,0,122,13,121,1,4,3,42,0,4,1,160,1,128,7,125,0,249,3,70,12,234,3,106,14,4,2,253,1,29,5,170,2,234,5,170,0,128,0,125,6,234,9,149,12,249,9,182,7,182,13,42,1,4,9,84,4,182,15,96,9,212,8,149,4,128,15,96,5,4,11,122,5,121,0,149,7,125,14,96,0,106,7,182,3,149,3,128,1,160,2,106,0,149,1,149,2,70,6,253,3,249,1,84,1,249,13,198,0,149,15,246,1,128,4,0,0,121,10,170,4,224,0,70,2,26,0,121,4,21,0,96,13,128,2,24,0,234,1,122,3,58,0,29,1,253,0,53,0,125,10,160,4,70,1,36,0,182,1,4,5,70,0,32,0,9,0,212,0,170,3,121,6,106,2,54,0,8,0,246,2,170,1,106,1,84,2,57,0,13,0,4,0,118,1,234,2,122,0,118,0,22], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2074784);
/* memory initializer */ allocate([1,0,121,8,88,0,20,0,213,0,93,0,52,0,12,0,7,0,0,0,0,0,0,0,6,12,8,7,8,7,6,4,3,10,10,11,9,9,6,4,11,10,10,10,7,5,12,11,11,11,8,5,12,11,11,12,9,6,12,12,11,9,6,12,12,10,7,11,10,7,11,7,11,8,11,8,11,11,8,11,9,12,9,12,9,12,9,12,9,12,10,10,12,10,12,10,11,11,10,11,11,11,12,12,12,12,12,12,12,12,11,12,12,12,12,12,12,12,12,12,12,12,11,11,11,11,10,10,10,10,10,11,10,12,9,12,9,12,9,11,8,12,11,8,11,8,11,8,12,10,7,12,10,7,11,10,7,12,11,9,6,11,11,12,8,6,12,10,11,11,8,5,11,10,10,10,7,5,10,9,11,9,9,6,4,12,8,7,8,7,6,4,3,0,0,0,0,0,0,0,0,16,248,15,246,15,245,15,244,15,243,15,242,15,241,15,240,15,230,15,229,15,228,15,227,15,226,15,225,15,224,15,214,15,213,15,211,15,210,15,209,15,208,15,198,15,197,15,195,15,194,15,193,15,192,15,181,15,179,15,178,15,177,15,176,15,165,15,163,15,161,15,160,15,149,15,145,15,144,15,131,15,129,15,128,15,115,15,113,15,112,15,97,15,96,15,81,15,80,15,69,15,65,15,64,15,49,15,48,15,33,15,32,15,16,15,0,15,240,14,224,14,213,14,209,14,208,14,192,14,176,14,160,14,144,14,128,14,112,14,96,14,80,14,64,14,48,14,32,14,16,14,0,14,240,13,224,13,208,13,192,13,176,13,160,13,144,13,128,13,96,13,209,12,128,2,112,2,96,2,80,2,64,2,48,2,32,2,16,2,0,2,240,1,224,1,208,1,192,1,176,1,161,1,160,1,144,1,128,1,112,1,96,1,80,1,64,1,48,1,33,1,32,1,17,1,16,1,1,1,0,1,241,0,240,0,225,0,224,0,209,0,208,0,193,0,192,0,177,0,176,0,165,0,161,0,160,0,145,0,144,0,129,0,128,0,117,0,113,0,112,0,101,0,99,0,97,0,96,0,85,0,83,0,82,0,81,0,80,0,70,0,69,0,67,0,66,0,65,0,64,0,54,0,53,0,51,0,50,0,49,0,48,0,38,0,37,0,36,0,35,0,34,0,33,0,32,0,24,0,22,0,21,0,20,0,19,0,18,0,17,0,16,0,31,0,113,13,63,1,108,0,167,0,103,0,28,0,8,0,5,0,241,6,44,0,186,4,114,0,170,1,2,0,6,0,172,6,175,2,239,6,143,1,10,0,9,0,172,2,42,4,225,6,143,6,177,0,0,0,23,3,23,12,18,6,15,1,17,0,186,15,42,0,114,1,12,0,172,5,215,3,55,0,143,14,242,2,65,0,225,11,127,5,74,0,175,0,111,0,170,6,151,0,1,1,18,0,129,0,113,5,146,0,175,14,191,1,215,0,49,0,1,0,242,1,23,15,58,5,191,0,143,3,23,2,113,3,241,1,186,1,42,2,191,2,143,2,143,0,241,3,225,0,186,0,242,0,191,14,175,6,143,4,225,15,113,2,186,7,58,13,18,12,172,8,23,7,172,0,18,4,1,9,225,4,225,7,23,4,175,12,172,4,172,1,242,4,186,3,215,5,241,7,215,1,175,4,239,4,172,3,170,0,225,1,113,0,241,0,44,1,239,3,42,8,18,1,225,3,250,1,172,13,49,1,18,14,15,0,23,11,127,0,239,10,122,0,170,2,97,0,113,6,39,0,58,1,143,5,255,0,58,3,50,0,1,3,33,0,143,12,127,3,119,0,241,2,225,2,58,0,60,0,18,2,23,8,225,12,63,0,7,0,23,0,1,5,186,2,191,6,87,0,16,0,239,2,23,1,127,1,239,0,106,0,25,0,113,1,239,1,186,6,42,1,250,0,34,0,14,0,225,10,175,1,82,0,47,0,79,0,26,0,4,0,3,0,6,12,9,7,8,7,6,4,3,11,9,11,9,9,6,4,11,11,11,11,7,5,11,11,11,12,8,5,12,12,12,9,6,12,12,9,6,12,10,7,12,10,7,12,11,7,11,8,11,8,12,11,8,12,8,12,9,9,9,9,9,12,12,10,10,10,10,10,10,10,11,11,11,11,11,11,11,12,12,12,12,11,12,12,12,12,12,12,12,12,12,12,12,12,11,11,11,11,11,11,11,12,11,10,10,10,10,10,9,10,12,9,12,9,12,9,12,9,12,9,12,8,11,8,11,8,11,11,8,10,7,10,7,12,10,7,11,12,9,6,11,12,12,9,6,12,11,11,12,8,5,12,10,11,11,7,5,11,10,11,9,9,6,4,12,9,7,8,7,6,4,3,0,0,0,0,4,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,101,0,102,0,104,0,106,0,108,0,110,0,112,0,114,0,116,0,118,0,120,0,122,0,124,0,126,0,128,0,130,0,132,0,134,0,136,0,138,0,140,0,142,0,144,0,146,0,148,0,150,0,152,0,155,0,158,0,161,0,164,0,167,0,170,0,173,0,176,0,179,0,182,0,185,0,188,0,191,0,194,0,197,0,200,0,203,0,207,0,211,0,215,0,219,0,223,0,227,0,231,0,235,0,239,0,243,0,247,0,251,0,255,0,4,1,9,1,14,1,19,1,24,1,29,1,34,1,39,1,44,1,49,1,55,1,61,1,67,1,73,1,79,1,85,1,91,1,97,1,103,1,110,1,117,1,124,1,131,1,138,1,145,1,152,1,160,1,168,1,176,1,184,1,192,1,200,1,209,1,218,1,227,1,236,1,245,1,254,1,8,2,18,2,28,2,38,2,48,2,59,2,70,2,81,2,92,2,103,2,115,2,127,2,139,2,151,2,164,2,177,2,190,2,203,2,217,2,231,2,245,2,3,3,18,3,33,3,48,3,64,3,80,3,96,3,113,3,130,3,147,3,165,3,183,3,201,3,220,3,239,3,2,4,22,4,42,4,63,4,84,4,105,4,127,4,149,4,172,4,195,4,219,4,243,4,12,5,37,5,63,5,89,5,116,5,143,5,171,5,199,5,228,5,1,6,31,6,61,6,92,6,124,6,156,6,189,6,223,6,1,7,36,7,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,60,0,0,0,62,0,0,0,64,0,0,0,66,0,0,0,68,0,0,0,70,0,0,0,72,0,0,0,74,0,0,0,76,0,0,0,78,0,0,0,80,0,0,0,82,0,0,0,84,0,0,0,86,0,0,0,88,0,0,0,90,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,98,0,0,0,100,0,0,0,102,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,110,0,0,0,112,0,0,0,114,0,0,0,116,0,0,0,119,0,0,0,122,0,0,0,125,0,0,0,128,0,0,0,131,0,0,0,134,0,0,0,137,0,0,0,140,0,0,0,143,0,0,0,146,0,0,0,149,0,0,0,152,0,0,0,155,0,0,0,158,0,0,0,161,0,0,0,164,0,0,0,167,0,0,0,170,0,0,0,173,0,0,0,177,0,0,0,181,0,0,0,185,0,0,0,189,0,0,0,193,0,0,0,197,0,0,0,201,0,0,0,205,0,0,0,209,0,0,0,213,0,0,0,217,0,0,0,221,0,0,0,225,0,0,0,229,0,0,0,234,0,0,0,239,0,0,0,245,0,0,0,249,0,0,0,254,0,0,0,3,1,0,0,8,1,0,0,13,1,0,0,18,1,0,0,23,1,0,0,28,1,0,0,255,163,112,63,0,60,91,63,0,220,33,63,254,215,172,62,0,0,114,61,1,48,6,190,3,48,76,190,254,95,34,190,0,192,102,189,255,255,66,61,2,160,218,61,252,95,212,61,0,64,85,61,252,255,120,188,0,128,130,189,0,224,150,189,0,128,62,189,0,0,128,186,1,128,28,61,0,192,89,61,255,255,35,61,0,0,25,60,0,128,177,188,0,192,26,189,255,255,7,189,2,0,85,188,253,255,46,60,2,0,212,60,255,127,215,60,5,0,98,60,254,255,111,187,1,128,137,188,2,128,162,188,3,0,81,188,0,0,16,186,255,255,36,60,255,255,102,60,253,255,46,60,1,0,44,59,1,0,176,187,0,0,25,188,0,0,5,188,255,255,79,187,0,0,24,59,255,255,183,59,0,0,182,59,255,255,59,59,1,0,32,186,1,0,68,187,2,0,92,187,255,255,3,187,254,255,255,184,252,255,175,58,253,255,223,58,0,0,152,58,254,255,127,57,0,0,224,185,1,0,32,186,0,0,224,185,254,255,255,184,1,0,128,56,254,255,255,56,1,0,128,56,0,0,0,0,0,0,0,0,0,0,0,0,3,255,16,0,3,255,24,0,2,255,4,1,3,255,8,1,5,255,32,0,4,255,16,1,2,0,0,4,2,0,0,8,2,0,0,12,3,0,0,16,3,0,0,24,2,0,1,3,3,0,1,7,2,255,16,0,2,255,20,0,2,255,24,0,2,255,28,0,4,255,32,0,4,255,48,0,2,255,4,1,3,255,8,1,4,255,16,1,2,0,0,4,3,0,0,8,4,0,0,16,2,0,1,3,3,0,1,7,0,0,0,0,0,0,3,0,16,0,5,0,114,0,7,0,113,0,7,0,84,1,9,0,171,10,12,0,168,10,12,0,20,0,5,0,112,0,7,0,2,0,3,0,3,0,3,0,12,0,4,0,11,0,4,0,3,0,4,0,17,0,5,0,115,0,7,0,84,0,7,0,171,0,8,0,171,2,10,0,83,21,13,0,82,21,13,0,85,21,13,0,84,21,13,0,13,0,4,0,30,0,5,0,18,0,5,0,62,0,6,0,43,0,6,0,2,0,4,0,63,0,6,0,29,0,5,0,19,0,5,0,3,0,3,0,31,0,5,0,41,0,6,0,61,0,6,0,12,0,7,0,105,0,10,0,69,3,13,0,2,0,5,0,40,0,6,0,2,0,3,0,1,0,3,0,14,0,4,0,12,0,4,0,21,0,5,0,7,0,6,0,27,0,8,0,107,0,10,0,106,0,10,0,68,3,13,0,71,3,13,0,70,3,13,0,161,1,12,0,160,1,12,0,11,0,4,0,26,0,5,0,18,0,5,0,0,0,5,0,60,0,6,0,8,0,4,0,27,0,5,0,19,0,5,0,1,0,5,0,4,0,3,0,4,0,4,0,63,0,6,0,20,0,5,0,86,0,7,0,92,1,9,0,213,21,13,0,60,0,6,0,42,0,6,0,0,0,3,0,1,0,3,0,14,0,4,0,13,0,4,0,12,0,5,0,175,0,8,0,187,2,10,0,212,21,13,0,215,21,13,0,214,21,13,0,209,21,13,0,208,21,13,0,211,21,13,0,210,21,13,0,11,0,4,0,25,0,5,0,13,0,5,0,62,0,6,0,49,0,6,0,7,0,4,0,5,0,4,0,61,0,6,0,48,0,6,0,5,0,3,0,8,0,4,0,26,0,5,0,0,0,4,0,54,0,6,0,17,0,8,0,6,1,12,0,10,0,7,0,110,0,7,0,2,0,3,0,3,0,3,0,3,0,4,0,2,0,4,0,111,0,7,0,33,0,9,0,15,2,13,0,14,2,13,0,1,1,12,0,0,1,12,0,3,1,12,0,2,1,12,0,5,1,12,0,4,1,12,0,12,0,4,0,30,0,5,0,3,0,5,0,62,0,6,0,63,0,6,0,9,0,4,0,14,0,4,0,11,0,7,0,9,0,7,0,2,0,3,0,14,0,4,0,30,0,5,0,12,0,4,0,31,0,5,0,110,0,7,0,173,0,10,0,175,0,10,0,20,0,7,0,4,0,3,0,3,0,3,0,26,0,5,0,23,0,5,0,42,0,8,0,118,5,13,0,239,10,14,0,238,10,14,0,113,5,13,0,112,5,13,0,115,5,13,0,114,5,13,0,117,5,13,0,116,5,13,0,3,0,4,0,22,0,5,0,4,0,5,0,54,0,6,0,11,0,6,0,10,0,4,0,0,0,3,0,111,0,7,0,172,0,10,0,4,0,3,0,5,0,4,0,3,0,3,0,1,0,3,0,4,0,4,0,47,0,6,0,38,5,11,0,149,20,13,0,166,0,8,0,7,0,3,0,6,0,3,0,45,0,6,0,44,0,6,0,148,20,13,0,151,20,13,0,150,20,13,0,145,20,13,0,144,20,13,0,147,20,13,0,146,20,13,0,61,41,14,0,60,41,14,0,63,41,14,0,0,0,3,0,40,0,6,0,165,0,8,0,72,1,9,0,167,0,8,0,46,0,6,0,21,0,5,0,78,10,12,0,62,41,14,0,4,0,3,0,5,0,4,0,3,0,3,0,1,0,3,0,4,0,4,0,47,0,6,0,38,5,11,0,149,20,13,0,166,0,8,0,7,0,3,0,6,0,3,0,45,0,6,0,44,0,6,0,148,20,13,0,151,20,13,0,150,20,13,0,145,20,13,0,144,20,13,0,147,20,13,0,146,20,13,0,61,41,14,0,60,41,14,0,63,41,14,0,0,0,3,0,40,0,6,0,165,0,8,0,72,1,9,0,167,0,8,0,46,0,6,0,21,0,5,0,78,10,12,0,62,41,14,0,4,0,3,0,5,0,4,0,3,0,3,0,1,0,3,0,4,0,4,0,47,0,6,0,38,5,11,0,149,20,13,0,166,0,8,0,7,0,3,0,6,0,3,0,45,0,6,0,44,0,6,0,148,20,13,0,151,20,13,0,150,20,13,0,145,20,13,0,144,20,13,0,147,20,13,0,146,20,13,0,61,41,14,0,60,41,14,0,63,41,14,0,0,0,3,0,40,0,6,0,165,0,8,0,72,1,9,0,167,0,8,0,46,0,6,0,21,0,5,0,78,10,12,0,62,41,14,0,3,0,3,0,17,0,5,0,32,0,6,0,116,0,7,0,13,1,9,0,99,8,12,0,96,8,12,0,10,0,5,0,117,0,7,0,1,0,3,0,0,0,3,0,11,0,4,0,10,0,4,0,24,0,5,0,56,0,6,0,66,0,7,0,15,1,9,0,14,1,9,0,25,2,10,0,195,16,13,0,194,16,13,0,197,16,13,0,196,16,13,0,15,0,4,0,4,0,4,0,25,0,5,0,11,0,5,0,57,0,6,0,9,0,4,0,27,0,5,0,26,0,5,0,59,0,6,0,5,0,3,0,1,0,4,0,62,0,6,0,1,0,5,0,226,0,8,0,111,28,13,0,217,56,14,0,57,0,6,0,31,0,6,0,2,0,3,0,1,0,3,0,9,0,4,0,8,0,4,0,0,0,5,0,112,0,7,0,199,1,9,0,140,3,10,0,26,7,11,0,216,56,14,0,219,56,14,0,218,56,14,0,221,56,14,0,220,56,14,0,13,0,4,0,29,0,5,0,14,0,5,0,63,0,6,0,60,0,6,0,12,0,4,0,6,0,4,0,61,0,6,0,30,0,6,0,6,0,3,0,11,0,4,0,17,0,5,0,30,0,5,0,116,0,7,0,170,3,10,0,92,29,13,0,1,0,6,0,33,0,6,0,1,0,3,0,2,0,3,0,7,0,4,0,6,0,4,0,62,0,6,0,235,0,8,0,212,1,9,0,175,14,12,0,187,58,14,0,186,58,14,0,89,29,13,0,88,29,13,0,91,29,13,0,90,29,13,0,10,0,4,0,28,0,5,0,1,0,5,0,63,0,6,0,59,0,6,0,1,0,4,0,9,0,4,0,32,0,6,0,0,0,6,0,4,0,3,0,10,0,4,0,23,0,5,0,4,0,4,0,22,0,6,0,106,1,9,0,177,22,13,0,23,0,7,0,91,0,7,0,6,0,3,0,7,0,3,0,1,0,4,0,0,0,4,0,10,0,6,0,215,2,10,0,90,11,12,0,176,22,13,0,179,22,13,0,178,22,13,0,109,45,14,0,108,45,14,0,111,45,14,0,110,45,14,0,6,0,4,0,10,0,5,0,4,0,5,0,44,0,6,0,23,0,6,0,3,0,4,0,7,0,4,0,22,0,7,0,180,0,8,0,5,0,3,0,13,0,4,0,5,0,4,0,9,0,4,0,51,0,6,0,147,1,9,0,44,25,13,0,97,0,8,0,49,0,7,0,0,0,2,0,7,0,3,0,16,0,5,0,17,0,5,0,200,0,8,0,47,25,13,0,91,50,14,0,90,50,14,0,41,25,13,0,40,25,13,0,43,25,13,0,42,25,13,0,93,50,14,0,92,50,14,0,24,0,5,0,26,0,6,0,27,0,6,0,101,0,7,0,25,0,6,0,4,0,4,0,7,0,4,0,96,0,8,0,36,3,10,0,6,0,3,0,0,0,3,0,2,0,4,0,15,0,4,0,57,0,6,0,217,1,9,0,130,29,13,0,97,7,11,0,190,3,10,0,1,0,2,0,2,0,2,0,15,0,6,0,14,0,6,0,98,7,11,0,7,59,14,0,6,59,14,0,29,59,14,0,28,59,14,0,31,59,14,0,30,59,14,0,25,59,14,0,24,59,14,0,27,59,14,0,56,0,6,0,222,1,9,0,237,0,8,0,191,3,10,0,238,0,8,0,58,0,6,0,6,0,5,0,192,14,12,0,26,59,14,0,0,0,2,0,2,0,3,0,15,0,5,0,6,0,4,0,28,0,6,0,208,1,10,0,140,14,13,0,27,29,14,0,26,29,14,0,3,0,2,0,2,0,2,0,234,0,9,0,233,0,9,0,137,14,13,0,136,14,13,0,139,14,13,0,138,14,13,0,101,29,14,0,100,29,14,0,103,29,14,0,102,29,14,0,97,29,14,0,96,29,14,0,173,3,11,0,99,29,14,0,98,29,14,0,29,29,14,0,28,29,14,0,59,0,7,0,215,1,10,0,31,29,14,0,30,29,14,0,2,0,2,0,15,0,4,0,28,0,5,0,12,0,4,0,59,0,6,0,172,1,9,0,216,26,13,0,179,53,14,0,178,53,14,0,1,0,2,0,0,0,2,0,105,0,7,0,104,0,7,0,189,53,14,0,188,53,14,0,191,53,14,0,190,53,14,0,185,53,14,0,184,53,14,0,187,53,14,0,186,53,14,0,181,53,14,0,180,53,14,0,169,1,9,0,168,1,9,0,90,3,10,0,215,0,8,0,213,0,8,0,58,0,6,0,27,0,5,0,183,53,14,0,182,53,14,0,3,0,4,0,9,0,6,0,208,0,8,0,163,1,9,0,68,3,10,0,20,13,12,0,43,26,13,0,4,0,4,0,21,0,7,0,0,0,3,0,15,0,4,0,11,0,4,0,12,0,4,0,14,0,4,0,9,0,4,0,27,0,5,0,10,0,5,0,20,0,5,0,13,0,5,0,42,0,6,0,20,0,7,0,139,6,11,0,42,26,13,0,8,0,4,0,11,0,5,0,43,0,6,0,11,0,6,0,105,0,7,0,53,0,6,0,8,0,6,0,7,0,4,0,12,0,5,0,10,0,4,0,60,0,6,0,50,0,7,0,48,0,7,0,197,0,9,0,33,6,12,0,32,6,12,0,31,0,5,0,51,0,7,0,1,0,3,0,0,0,3,0,14,0,4,0,13,0,4,0,12,0,4,0,4,0,4,0,13,0,5,0,38,0,6,0,39,0,6,0,20,0,6,0,99,0,8,0,137,1,10,0,35,6,12,0,34,6,12,0,11,0,4,0,18,0,5,0,61,0,6,0,34,0,6,0,21,0,6,0,11,0,5,0,35,0,6,0,7,0,4,0,16,0,5,0,15,0,4,0,12,0,5,0,67,0,7,0,16,0,6,0,68,0,8,0,20,1,10,0,85,4,12,0,24,0,5,0,35,0,7,0,1,0,3,0,0,0,3,0,14,0,4,0,13,0,4,0,9,0,4,0,25,0,5,0,9,0,5,0,23,0,6,0,22,0,6,0,66,0,7,0,139,0,9,0,84,4,12,0,87,4,12,0,86,4,12,0,11,0,4,0,21,0,5,0,10,0,5,0,41,0,6,0,32,0,6,0,13,0,5,0,40,0,6,0,7,0,4,0,17,0,5,0,1,0,3,0,26,0,5,0,41,0,6,0,42,0,6,0,160,0,8,0,133,2,10,0,37,20,13,0,2,0,5,0,0,0,7,0,2,0,3,0,3,0,3,0,12,0,4,0,11,0,4,0,8,0,4,0,18,0,5,0,1,0,6,0,81,0,7,0,1,0,7,0,67,1,9,0,8,5,11,0,36,20,13,0,39,20,13,0,38,20,13,0,15,0,4,0,28,0,5,0,3,0,5,0,55,0,6,0,43,0,6,0,19,0,5,0,54,0,6,0,29,0,5,0,1,0,5,0,4,0,3,0,31,0,5,0,61,0,6,0,6,0,5,0,22,0,7,0,83,0,9,0,74,1,11,0,52,0,6,0,42,0,8,0,2,0,3,0,3,0,3,0,11,0,4,0,12,0,4,0,28,0,5,0,55,0,6,0,23,0,7,0,43,0,8,0,40,0,8,0,164,0,10,0,45,5,13,0,44,5,13,0,47,5,13,0,46,5,13,0,0,0,3,0,29,0,5,0,7,0,5,0,4,0,5,0,53,0,6,0,20,0,5,0,54,0,6,0,21,0,5,0,60,0,6,0,4,0,3,0,10,0,4,0,7,0,5,0,29,0,5,0,9,0,6,0,243,1,9,0,199,7,11,0,8,0,6,0,240,1,9,0,3,0,3,0,2,0,3,0,13,0,4,0,12,0,4,0,23,0,5,0,125,0,7,0,242,1,9,0,198,7,11,0,197,7,11,0,18,31,13,0,39,62,14,0,38,62,14,0,17,31,13,0,16,31,13,0,0,0,3,0,30,0,5,0,6,0,5,0,57,0,6,0,56,0,6,0,63,0,6,0,44,0,6,0,5,0,5,0,45,0,6,0,2,0,3,0,7,0,4,0,24,0,5,0,3,0,4,0,5,0,5,0,53,0,7,0,79,0,9,0,18,0,7,0,229,4,13,0,5,0,3,0,4,0,3,0,13,0,4,0,14,0,4,0,51,0,6,0,38,0,8,0,157,0,10,0,228,4,13,0,231,4,13,0,230,4,13,0,225,4,13,0,224,4,13,0,227,4,13,0,226,4,13,0,0,0,3,0,31,0,5,0,12,0,5,0,61,0,6,0,60,0,6,0,50,0,6,0,52,0,7,0,27,0,6,0,8,0,6,0,0,0,3,0,4,0,4,0,28,0,5,0,15,0,4,0,2,0,4,0,7,0,5,0,117,0,7,0,232,0,8,0,42,29,13,0,5,0,3,0,4,0,3,0,13,0,4,0,12,0,4,0,119,0,7,0,150,14,12,0,87,58,14,0,86,58,14,0,93,58,14,0,92,58,14,0,95,58,14,0,94,58,14,0,41,29,13,0,40,29,13,0,3,0,3,0,6,0,5,0,10,0,5,0,44,0,7,0,23,0,6,0,118,0,7,0,211,1,9,0,164,3,10,0,45,0,7,0,10,0,4,0,36,0,6,0,191,0,8,0,133,0,8,0,17,2,10,0,66,8,12,0,135,16,13,0,24,0,5,0,32,0,6,0,1,0,3,0,2,0,3,0,14,0,4,0,13,0,4,0,7,0,4,0,19,0,5,0,37,0,6,0,94,0,7,0,67,0,7,0,190,0,8,0,9,1,9,0,134,16,13,0,65,8,12,0,64,8,12,0,15,0,4,0,1,0,4,0,17,0,5,0,0,0,5,0,46,0,6,0,25,0,5,0,1,0,5,0,6,0,4,0,22,0,5,0,2,0,3,0,15,0,5,0,111,0,7,0,97,0,7,0,116,3,10,0,168,27,13,0,83,55,14,0,18,0,5,0,54,0,6,0,0,0,3,0,1,0,3,0,10,0,4,0,11,0,4,0,26,0,5,0,49,0,6,0,96,0,7,0,220,0,8,0,187,1,9,0,235,6,11,0,171,27,13,0,82,55,14,0,85,55,14,0,84,55,14,0,14,0,4,0,6,0,4,0,19,0,5,0,14,0,5,0,62,0,6,0,8,0,4,0,30,0,5,0,25,0,5,0,63,0,6,0,3,0,3,0,28,0,5,0,37,0,6,0,36,0,6,0,218,1,9,0,189,29,13,0,124,59,14,0,60,0,6,0,61,0,6,0,0,0,3,0,1,0,3,0,11,0,4,0,10,0,4,0,11,0,5,0,119,0,7,0,236,0,8,0,182,3,10,0,110,7,11,0,191,29,13,0,251,118,15,0,250,118,15,0,121,59,14,0,120,59,14,0,13,0,4,0,31,0,5,0,19,0,5,0,10,0,5,0,8,0,5,0,12,0,4,0,8,0,4,0,9,0,5,0,58,0,6,0,5,0,3,0,3,0,4,0,4,0,5,0,16,0,5,0,143,0,8,0,117,4,11,0,209,17,13,0,121,0,7,0,39,0,6,0,2,0,3,0,3,0,3,0,1,0,4,0,0,0,4,0,38,0,6,0,70,0,7,0,28,1,9,0,119,4,11,0,237,8,12,0,208,17,13,0,211,17,13,0,210,17,13,0,217,17,13,0,216,17,13,0,13,0,4,0,31,0,5,0,18,0,5,0,5,0,5,0,61,0,6,0,12,0,4,0,14,0,4,0,34,0,6,0,120,0,7,0,5,0,3,0,12,0,4,0,27,0,5,0,0,0,4,0,6,0,6,0,226,3,10,0,61,62,14,0,15,0,7,0,52,0,6,0,3,0,3,0,2,0,3,0,30,0,5,0,29,0,5,0,125,0,7,0,240,1,9,0,198,7,11,0,60,62,14,0,63,62,14,0,62,62,14,0,57,62,14,0,56,62,14,0,59,62,14,0,58,62,14,0,8,0,4,0,28,0,5,0,2,0,5,0,63,0,6,0,53,0,6,0,9,0,4,0,1,0,3,0,14,0,7,0,249,0,8,0,4,0,3,0,11,0,4,0,1,0,4,0,10,0,4,0,30,0,6,0,224,0,9,0,30,14,13,0,113,0,8,0,57,0,7,0,7,0,3,0,6,0,3,0,13,0,5,0,12,0,5,0,32,0,7,0,194,1,10,0,63,28,14,0,62,28,14,0,25,14,13,0,24,14,13,0,27,14,13,0,26,14,13,0,29,14,13,0,28,14,13,0,0,0,4,0,9,0,5,0,29,0,6,0,31,0,6,0,17,0,6,0,5,0,4,0,1,0,3,0,67,0,8,0,66,0,8,0,4,0,3,0,13,0,4,0,7,0,4,0,2,0,3,0,20,0,5,0,108,1,9,0,209,22,13,0,223,2,10,0,110,1,9,0,0,0,2,0,7,0,3,0,44,0,6,0,43,0,6,0,222,2,10,0,208,22,13,0,211,22,13,0,210,22,13,0,181,45,14,0,180,45,14,0,183,45,14,0,182,45,14,0,217,22,13,0,216,22,13,0,12,0,5,0,42,0,6,0,90,0,7,0,27,0,6,0,26,0,6,0,23,0,5,0,12,0,4,0,183,5,11,0,181,5,11,0,2,0,2,0,15,0,4,0,28,0,5,0,12,0,4,0,59,0,6,0,172,1,9,0,216,26,13,0,179,53,14,0,178,53,14,0,1,0,2,0,0,0,2,0,105,0,7,0,104,0,7,0,189,53,14,0,188,53,14,0,191,53,14,0,190,53,14,0,185,53,14,0,184,53,14,0,187,53,14,0,186,53,14,0,181,53,14,0,180,53,14,0,169,1,9,0,168,1,9,0,90,3,10,0,215,0,8,0,213,0,8,0,58,0,6,0,27,0,5,0,183,53,14,0,182,53,14,0,11,0,5,0,43,0,7,0,84,0,8,0,183,1,9,0,217,6,11,0,177,13,12,0,176,13,12,0,2,0,4,0,171,0,9,0,9,0,4,0,10,0,4,0,7,0,4,0,8,0,4,0,15,0,4,0,12,0,4,0,3,0,4,0,29,0,5,0,4,0,4,0,11,0,4,0,6,0,4,0,26,0,5,0,3,0,6,0,170,0,9,0,1,0,4,0,0,0,5,0,20,0,6,0,108,0,7,0,218,0,8,0,2,0,6,0,109,3,10,0,28,0,5,0,55,0,6,0,29,0,5,0,4,0,6,0,182,0,8,0,106,0,8,0,185,5,11,0,225,22,13,0,224,22,13,0,7,0,4,0,111,1,9,0,12,0,4,0,13,0,4,0,9,0,4,0,8,0,4,0,15,0,4,0,10,0,4,0,3,0,4,0,23,0,5,0,2,0,4,0,4,0,4,0,28,0,5,0,44,0,6,0,107,0,8,0,113,11,12,0,5,0,4,0,3,0,5,0,27,0,6,0,90,0,7,0,52,0,7,0,5,0,6,0,221,2,10,0,0,0,4,0,12,0,5,0,3,0,4,0,127,0,7,0,161,0,8,0,160,0,8,0,12,2,10,0,52,8,12,0,107,16,13,0,7,0,4,0,130,0,8,0,14,0,4,0,13,0,4,0,11,0,4,0,12,0,4,0,0,0,3,0,9,0,4,0,2,0,4,0,17,0,5,0,30,0,5,0,21,0,5,0,62,0,6,0,64,0,7,0,27,4,11,0,106,16,13,0,6,0,4,0,10,0,5,0,41,0,6,0,126,0,7,0,81,0,7,0,33,0,6,0,7,1,9,0,4,0,4,0,11,0,5,0,7,0,4,0,27,0,6,0,246,0,8,0,233,0,8,0,161,3,10,0,64,7,11,0,130,14,12,0,31,0,5,0,239,1,9,0,1,0,3,0,2,0,3,0,11,0,4,0,12,0,4,0,13,0,4,0,8,0,4,0,28,0,5,0,3,0,5,0,18,0,5,0,2,0,5,0,117,0,7,0,209,1,9,0,7,29,13,0,6,29,13,0,10,0,4,0,19,0,5,0,59,0,6,0,26,0,6,0,122,0,7,0,60,0,6,0,238,1,9,0,0,0,4,0,12,0,5,0,13,0,4,0,61,0,6,0,66,0,7,0,55,0,7,0,217,0,9,0,98,3,11,0,198,6,12,0,31,0,5,0,134,0,8,0,1,0,3,0,2,0,3,0,12,0,4,0,11,0,4,0,10,0,4,0,1,0,4,0,15,0,5,0,37,0,6,0,60,0,6,0,26,0,6,0,135,0,8,0,176,1,10,0,143,13,13,0,142,13,13,0,14,0,4,0,19,0,5,0,12,0,5,0,36,0,6,0,32,0,6,0,17,0,5,0,109,0,8,0,0,0,4,0,14,0,5,0,0,0,3,0,18,0,5,0,118,0,7,0,119,0,7,0,77,1,9,0,51,5,11,0,201,20,13,0,19,0,5,0,165,0,8,0,2,0,3,0,3,0,3,0,11,0,4,0,12,0,4,0,8,0,4,0,26,0,5,0,43,0,6,0,117,0,7,0,116,0,7,0,167,0,8,0,152,2,10,0,200,20,13,0,203,20,13,0,202,20,13,0,15,0,4,0,28,0,5,0,7,0,5,0,42,0,6,0,40,0,6,0,27,0,5,0,164,0,8,0,2,0,4,0,6,0,5,0,2,0,3,0,26,0,5,0,43,0,6,0,58,0,6,0,237,0,8,0,131,2,10,0,10,10,12,0,4,0,5,0,161,0,8,0,4,0,3,0,3,0,3,0,11,0,4,0,12,0,4,0,31,0,5,0,6,0,5,0,119,0,7,0,163,0,8,0,162,0,8,0,64,1,9,0,23,20,13,0,22,20,13,0,9,10,12,0,8,10,12,0,0,0,3,0,30,0,5,0,7,0,5,0,42,0,6,0,41,0,6,0,28,0,5,0,236,0,8,0,27,0,5,0,5,0,5,0,2,0,3,0,2,0,4,0,24,0,5,0,29,0,5,0,53,0,6,0,228,0,8,0,207,1,11,0,29,0,7,0,114,0,9,0,4,0,3,0,5,0,3,0,6,0,4,0,7,0,4,0,6,0,5,0,115,0,7,0,56,0,8,0,206,1,11,0,155,3,12,0,152,3,12,0,51,7,13,0,50,7,13,0,53,7,13,0,52,7,13,0,0,0,3,0,31,0,5,0,27,0,5,0,52,0,6,0,15,0,6,0,30,0,5,0,229,0,8,0,25,0,5,0,56,0,6,0,22,0,5,0,80,0,7,0,114,1,9,0,231,2,10,0,50,23,13,0,103,46,14,0,102,46,14,0,6,0,4,0,81,0,7,0,1,0,3,0,0,0,3,0,13,0,4,0,12,0,4,0,9,0,4,0,28,0,5,0,9,0,5,0,28,0,6,0,29,0,6,0,93,0,7,0,184,0,8,0,205,5,11,0,49,23,13,0,48,23,13,0,15,0,4,0,5,0,4,0,15,0,5,0,8,0,5,0,41,0,6,0,29,0,5,0,47,0,6,0,8,0,4,0,21,0,5,0,9,0,4,0,33,0,6,0,64,0,7,0,173,0,8,0,176,2,10,0,137,21,13,0,136,21,13,0,28,0,5,0,95,0,7,0,0,0,3,0,15,0,4,0,13,0,4,0,12,0,4,0,6,0,4,0,17,0,5,0,42,0,6,0,87,0,7,0,94,0,7,0,65,0,7,0,89,1,9,0,99,5,11,0,139,21,13,0,138,21,13,0,1,0,3,0,5,0,4,0,20,0,5,0,59,0,6,0,46,0,6,0,4,0,4,0,58,0,6,0,7,0,4,0,22,0,5,0,14,0,4,0,7,0,5,0,70,0,7,0,69,0,7,0,100,0,9,0,42,3,12,0,87,6,13,0,24,0,5,0,13,0,6,0,0,0,3,0,15,0,4,0,10,0,4,0,11,0,4,0,26,0,5,0,54,0,6,0,71,0,7,0,68,0,7,0,24,0,7,0,51,0,8,0,203,0,10,0,86,6,13,0,41,3,12,0,40,3,12,0,2,0,3,0,6,0,4,0,25,0,5,0,14,0,5,0,55,0,6,0,9,0,4,0,15,0,5,0,2,0,4,0,16,0,5,0,3,0,3,0,24,0,5,0,35,0,6,0,119,0,7,0,148,1,9,0,86,25,13,0,175,50,14,0,58,0,6,0,118,0,7,0,2,0,3,0,1,0,3,0,31,0,5,0,30,0,5,0,20,0,5,0,34,0,6,0,100,0,7,0,151,1,9,0,150,1,9,0,43,3,10,0,84,6,11,0,174,50,14,0,85,25,13,0,84,25,13,0,0,0,3,0,9,0,4,0,28,0,5,0,21,0,5,0,16,0,5,0,13,0,4,0,23,0,5,0,22,0,5,0,51,0,6,0,5,0,3,0,6,0,4,0,62,0,6,0,16,0,5,0,72,0,7,0,63,9,12,0,250,36,14,0,50,0,6,0,103,0,7,0,2,0,3,0,1,0,3,0,27,0,5,0,30,0,5,0,52,0,6,0,102,0,7,0,146,0,8,0,38,1,9,0,78,2,10,0,158,4,11,0,247,73,15,0,246,73,15,0,249,36,14,0,248,36,14,0,0,0,3,0,7,0,4,0,24,0,5,0,17,0,5,0,63,0,6,0,14,0,4,0,19,0,5,0,53,0,6,0,37,0,6,0,5,0,3,0,8,0,4,0,18,0,5,0,28,0,5,0,28,0,6,0,234,0,9,0,117,29,14,0,30,0,6,0,102,0,7,0,1,0,3,0,2,0,3,0,27,0,5,0,26,0,5,0,31,0,6,0,59,0,7,0,116,0,8,0,214,1,10,0,175,3,11,0,116,29,14,0,119,29,14,0,118,29,14,0,185,14,13,0,184,14,13,0,15,0,4,0,6,0,4,0,19,0,5,0,59,0,6,0,58,0,6,0,0,0,3,0,24,0,5,0,50,0,6,0,103,0,7,0,4,0,3,0,10,0,4,0,27,0,5,0,12,0,4,0,13,0,5,0,230,0,8,0,132,6,11,0,114,0,7,0,231,0,8,0,2,0,3,0,1,0,3,0,23,0,5,0,22,0,5,0,24,0,6,0,209,0,8,0,160,1,9,0,134,6,11,0,15,13,12,0,10,13,12,0,23,26,13,0,22,26,13,0,29,26,13,0,28,26,13,0,15,0,4,0,29,0,5,0,14,0,5,0,53,0,6,0,56,0,6,0,0,0,3,0,15,0,5,0,25,0,6,0,105,0,7,0,3,0,3,0,12,0,4,0,27,0,5,0,0,0,3,0,3,0,4,0,46,0,6,0,81,0,9,0,188,0,8,0,83,0,9,0,4,0,3,0,2,0,3,0,22,0,5,0,21,0,5,0,21,0,7,0,80,0,9,0,164,0,10,0,148,2,12,0,43,5,13,0,42,5,13,0,45,5,13,0,44,5,13,0,47,5,13,0,46,5,13,0,14,0,4,0,26,0,5,0,4,0,5,0,40,0,6,0,41,0,6,0,15,0,4,0,11,0,6,0,95,0,7,0,189,0,8,0,8,0,5,0,37,0,7,0,122,1,9,0,247,2,10,0,219,11,12,0,180,23,13,0,107,47,14,0,29,0,5,0,106,47,14,0,8,0,4,0,7,0,4,0,1,0,4,0,2,0,4,0,10,0,4,0,6,0,4,0,0,0,4,0,28,0,5,0,9,0,4,0,13,0,4,0,15,0,4,0,12,0,4,0,3,0,4,0,10,0,5,0,22,0,5,0,19,0,6,0,93,0,7,0,36,0,7,0,188,0,8,0,92,0,7,0,236,5,11,0,11,0,5,0,95,0,7,0,15,0,5,0,16,0,6,0,75,0,8,0,198,0,8,0,29,3,10,0,113,12,12,0,112,12,12,0,1,0,4,0,115,12,12,0,8,0,4,0,9,0,4,0,2,0,4,0,3,0,4,0,11,0,4,0,6,0,4,0,0,0,4,0,28,0,5,0,5,0,4,0,13,0,4,0,15,0,4,0,10,0,4,0,25,0,5,0,19,0,6,0,29,0,5,0,48,0,6,0,98,0,7,0,36,0,7,0,74,0,8,0,143,1,9,0,114,12,12,0,14,0,5,0,17,0,6,0,27,0,5,0,3,0,6,0,141,0,8,0,64,0,7,0,57,2,10,0,113,4,11,0,224,8,12,0,3,0,4,0,195,17,13,0,10,0,4,0,9,0,4,0,4,0,4,0,5,0,4,0,14,0,4,0,7,0,4,0,1,0,4,0,30,0,5,0,6,0,4,0,12,0,4,0,11,0,4,0,2,0,4,0,0,0,5,0,65,0,7,0,31,0,5,0,34,0,6,0,2,0,6,0,143,0,8,0,140,0,8,0,29,1,9,0,194,17,13,0,26,0,5,0,33,0,6,0,31,0,5,0,3,0,6,0,3,0,7,0,67,0,7,0,11,0,9,0,21,0,10,0,81,0,12,0,3,0,4,0,80,0,12,0,13,0,4,0,12,0,4,0,4,0,4,0,6,0,4,0,14,0,4,0,10,0,4,0,1,0,4,0,30,0,5,0,5,0,4,0,9,0,4,0,7,0,4,0,17,0,5,0,2,0,6,0,4,0,8,0,2,0,4,0,45,0,6,0,32,0,6,0,66,0,7,0,1,0,7,0,0,0,7,0,41,0,11,0,23,0,5,0,44,0,6,0,3,0,4,0,31,0,6,0,58,0,7,0,93,0,7,0,115,1,9,0,228,2,10,0,45,23,13,0,4,0,4,0,44,23,13,0,15,0,4,0,14,0,4,0,9,0,4,0,8,0,4,0,12,0,4,0,10,0,4,0,1,0,4,0,22,0,5,0,2,0,4,0,5,0,4,0,26,0,5,0,47,0,6,0,56,0,7,0,202,5,11,0,6,0,4,0,55,0,6,0,30,0,6,0,59,0,7,0,57,0,7,0,184,0,8,0,151,11,12,0,0,0,4,0,54,0,6,0,6,0,4,0,55,0,6,0,93,0,7,0,12,0,6,0,185,0,8,0,227,2,10,0,196,5,11,0,4,0,4,0,21,23,13,0,0,0,3,0,15,0,4,0,8,0,4,0,7,0,4,0,12,0,4,0,9,0,4,0,29,0,5,0,22,0,5,0,28,0,5,0,26,0,5,0,11,0,5,0,94,0,7,0,112,1,9,0,20,23,13,0,10,0,4,0,10,0,5,0,54,0,6,0,95,0,7,0,27,0,7,0,26,0,7,0,139,11,12,0,2,0,4,0,7,0,5,0,12,0,4,0,11,0,5,0,121,0,7,0,34,0,6,0,240,0,8,0,25,1,9,0,48,2,10,0,29,0,5,0,196,8,12,0,1,0,3,0,0,0,3,0,10,0,4,0,9,0,4,0,11,0,4,0,7,0,4,0,28,0,5,0,61,0,6,0,13,0,5,0,8,0,5,0,21,0,6,0,141,0,8,0,139,17,13,0,138,17,13,0,13,0,4,0,16,0,5,0,9,0,5,0,20,0,6,0,71,0,7,0,241,0,8,0,99,4,11,0,31,0,5,0,12,0,5,0,0,0,3,0,26,0,5,0,51,0,6,0,12,0,5,0,70,0,7,0,227,1,9,0,197,3,10,0,23,0,5,0,33,30,13,0,2,0,3,0,1,0,3,0,9,0,4,0,10,0,4,0,7,0,4,0,27,0,5,0,61,0,6,0,27,0,6,0,34,0,6,0,121,0,7,0,240,0,8,0,32,30,13,0,35,30,13,0,34,30,13,0,14,0,4,0,22,0,5,0,24,0,5,0,50,0,6,0,26,0,6,0,71,0,7,0,137,7,11,0,31,0,5,0,16,0,5,0,29,0,5,0,97,0,7,0,78,0,8,0,158,0,9,0,124,2,11,0,245,9,13,0,244,9,13,0,3,0,4,0,96,0,7,0,0,0,3,0,15,0,4,0,11,0,4,0,10,0,4,0,9,0,4,0,5,0,4,0,13,0,5,0,49,0,6,0,8,0,5,0,56,0,6,0,18,0,6,0,38,0,7,0,63,1,10,0,251,4,12,0,13,0,4,0,2,0,4,0,12,0,5,0,57,0,6,0,28,0,6,0,15,0,5,0,29,0,6,0,8,0,4,0,25,0,5,0,7,0,4,0,25,0,6,0,171,0,8,0,170,0,8,0,25,1,10,0,97,4,12,0,96,4,12,0,27,0,5,0,71,0,8,0,1,0,3,0,0,0,3,0,12,0,4,0,11,0,4,0,9,0,4,0,5,0,4,0,13,0,5,0,53,0,6,0,61,0,6,0,60,0,6,0,24,0,6,0,34,0,7,0,141,0,9,0,49,2,11,0,14,0,4,0,31,0,5,0,9,0,5,0,43,0,6,0,16,0,6,0,52,0,6,0,84,0,7,0,8,0,4,0,20,0,5,0,12,0,4,0,5,0,5,0,8,0,6,0,91,0,7,0,77,0,9,0,49,1,11,0,97,2,12,0,26,0,5,0,18,0,7,0,0,0,3,0,15,0,4,0,10,0,4,0,9,0,4,0,6,0,4,0,27,0,5,0,6,0,5,0,28,0,6,0,44,0,6,0,21,0,6,0,90,0,7,0,39,0,8,0,153,0,10,0,96,2,12,0,14,0,4,0,4,0,4,0,15,0,5,0,7,0,5,0,29,0,6,0,11,0,5,0,20,0,6,0,8,0,4,0,23,0,5,0,15,0,4,0,19,0,5,0,117,0,7,0,36,0,6,0,149,0,8,0,81,2,10,0,160,4,11,0,16,0,5,0,200,0,8,0,2,0,3,0,1,0,3,0,1,0,4,0,0,0,4,0,26,0,5,0,17,0,5,0,44,0,6,0,101,0,7,0,116,0,7,0,75,0,7,0,201,0,8,0,41,1,9,0,67,9,12,0,66,9,12,0,3,0,3,0,10,0,4,0,28,0,5,0,24,0,5,0,51,0,6,0,23,0,5,0,45,0,6,0,27,0,5,0,59,0,6,0,3,0,3,0,26,0,5,0,45,0,6,0,56,0,6,0,40,0,7,0,149,3,10,0,81,14,12,0,55,0,6,0,228,0,8,0,1,0,3,0,0,0,3,0,31,0,5,0,30,0,5,0,23,0,5,0,58,0,6,0,115,0,7,0,42,0,7,0,43,0,7,0,41,0,7,0,203,1,9,0,41,7,11,0,161,28,13,0,160,28,13,0,4,0,3], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2085024);
/* memory initializer */ allocate([10,0,4,0,4,0,4,0,24,0,5,0,54,0,6,0,11,0,5,0,44,0,6,0,25,0,5,0,59,0,6,0,4,0,3,0,4,0,4,0,63,0,6,0,23,0,5,0,117,0,7,0,245,1,9,0,209,7,11,0,23,0,6,0,246,1,9,0,1,0,3,0,0,0,3,0,27,0,5,0,26,0,5,0,10,0,5,0,50,0,6,0,116,0,7,0,248,0,8,0,249,0,8,0,247,1,9,0,233,3,10,0,160,15,12,0,67,31,13,0,66,31,13,0,3,0,3,0,10,0,4,0,30,0,5,0,28,0,5,0,59,0,6,0,24,0,5,0,22,0,6,0,22,0,5,0,51,0,6,0,4,0,3,0,7,0,4,0,24,0,5,0,30,0,5,0,54,0,6,0,49,0,7,0,119,1,9,0,119,0,7,0,118,1,9,0,1,0,3,0,0,0,3,0,26,0,5,0,25,0,5,0,58,0,6,0,25,0,6,0,92,0,7,0,186,0,8,0,97,0,8,0,193,0,9,0,128,1,10,0,2,3,11,0,7,6,12,0,6,6,12,0,2,0,3,0,10,0,4,0,31,0,5,0,28,0,5,0,55,0,6,0,22,0,5,0,118,0,7,0,13,0,5,0,47,0,6,0,0,0,3,0,10,0,4,0,26,0,5,0,12,0,4,0,29,0,5,0,57,0,6,0,120,0,7,0,94,0,7,0,147,3,11,0,2,0,3,0,1,0,3,0,22,0,5,0,15,0,5,0,46,0,6,0,95,0,7,0,115,0,8,0,229,0,9,0,200,1,10,0,74,14,13,0,151,28,14,0,150,28,14,0,73,14,13,0,72,14,13,0,4,0,3,0,6,0,4,0,31,0,5,0,27,0,5,0,29,0,6,0,56,0,6,0,56,0,7,0,61,0,6,0,121,0,7,0,176,138,33,0,112,0,0,0,168,250,31,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,139,33,0,112,0,0,0,40,2,32,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,15,33,0,24,168,32,0,92,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,0,77,32,0,8,52,40,0,12,0,0,0,4,0,0,0,21,183,49,10,254,6,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,24,216,39,0,160,112,39,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,144,31,39,0,128,217,38,0,28,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,192,91,64,9,0,0,0,0,0,0,0,136,148,38,0,16,90,38,0,32,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,136,148,38,0,216,36,38,0,80,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,148,38,0,192,198,37,0,72,163,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,148,38,0,248,124,37,0,192,57,37,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,148,38,0,96,15,37,0,232,229,36,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,104,195,36,0,8,165,36,0,4,0,0,0,1,0,0,0,225,255,255,255,255,255,255,255,0,0,0,0,0,0,63,192,0,0,0,0,0,0,240,191,9,0,0,0,0,0,0,0,192,138,36,0,216,110,36,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,192,138,36,0,216,36,38,0,80,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,192,138,36,0,240,83,36,0,216,58,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,192,138,36,0,136,30,36,0,152,228,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,192,138,36,0,144,197,35,0,24,174,35,0,40,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,248,151,35,0,128,130,35,0,48,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,248,151,35,0,216,36,38,0,80,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,248,151,35,0,88,108,35,0,88,88,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,248,151,35,0,56,71,35,0,8,53,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,248,151,35,0,184,29,35,0,144,242,34,0,52,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,192,218,34,0,8,204,34,0,56,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,120,187,34,0,104,169,34,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,104,151,34,0,104,137,34,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,128,122,34,0,160,105,34,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,128,122,34,0,216,36,38,0,80,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,128,122,34,0,240,83,36,0,152,85,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,128,122,34,0,136,30,36,0,144,45,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,128,122,34,0,152,25,34,0,48,11,34,0,76,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,152,25,34,0,216,36,38,0,80,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,152,25,34,0,240,83,36,0,80,252,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,152,25,34,0,136,30,36,0,16,234,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,152,25,34,0,168,219,33,0,48,208,33,0,80,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,168,219,33,0,32,198,33,0,40,189,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,168,219,33,0,216,175,33,0,176,141,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,168,219,33,0,56,126,33,0,168,116,33,0,96,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,16,107,33,0,56,97,33,0,100,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,16,107,33,0,240,86,33,0,72,78,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,16,107,33,0,120,70,33,0,144,61,33,0,104,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,46,64,9,0,0,0,120,70,33,0,240,86,33,0,72,78,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,120,70,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,15,33,0,88,168,32,0,92,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,40,77,32,0,56,52,40,0,12,0,0,0,4,0,0,0,21,183,49,10,254,6,227,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,104,216,39,0,184,112,39,0,16,0,0,0,4,0,0,0,0,0,0,0,0,0,224,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,168,31,39,0,192,217,38,0,28,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,192,91,64,9,0,0,0,0,0,0,0,168,148,38,0,32,90,38,0,32,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,168,148,38,0,232,36,38,0,104,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,168,148,38,0,200,198,37,0,88,163,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,168,148,38,0,32,125,37,0,208,57,37,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,168,148,38,0,112,15,37,0,248,229,36,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,120,195,36,0,32,165,36,0,4,0,0,0,1,0,0,0,225,255,255,255,255,255,255,255,0,0,0,0,0,0,63,192,0,0,0,0,0,0,240,191,9,0,0,0,0,0,0,0,208,138,36,0,240,110,36,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,208,138,36,0,232,36,38,0,104,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,208,138,36,0,248,83,36,0,240,58,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,208,138,36,0,176,30,36,0,184,228,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,208,138,36,0,160,197,35,0,48,174,35,0,40,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,8,152,35,0,160,130,35,0,48,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,8,152,35,0,232,36,38,0,104,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,152,35,0,96,108,35,0,112,88,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,152,35,0,64,71,35,0,32,53,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,8,152,35,0,240,29,35,0,168,242,34,0,52,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,208,218,34,0,40,204,34,0,56,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,136,187,34,0,128,169,34,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,120,151,34,0,136,137,34,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,144,122,34,0,184,105,34,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,144,122,34,0,232,36,38,0,104,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,122,34,0,248,83,36,0,216,85,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,122,34,0,176,30,36,0,176,45,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,144,122,34,0,168,25,34,0,72,11,34,0,76,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,168,25,34,0,232,36,38,0,104,243,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,168,25,34,0,248,83,36,0,104,252,33,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,168,25,34,0,176,30,36,0,80,234,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,168,25,34,0,184,219,33,0,72,208,33,0,80,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,184,219,33,0,48,198,33,0,64,189,33,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,219,33,0,240,175,33,0,184,141,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,184,219,33,0,80,126,33,0,192,116,33,0,96,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,40,107,33,0,80,97,33,0,100,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,40,107,33,0,248,86,33,0,96,78,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,40,107,33,0,136,70,33,0,168,61,33,0,104,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,46,64,9,0,0,0,136,70,33,0,248,86,33,0,96,78,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,136,70,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,80,34,0,232,171,33,0,92,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,168,45,33,0,240,193,32,0,28,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,192,91,64,9,0,0,0,0,0,0,0,224,100,32,0,32,75,40,0,32,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,224,100,32,0,96,242,39,0,56,135,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,100,32,0,136,50,39,0,96,236,38,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,100,32,0,240,164,38,0,96,105,38,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,224,100,32,0,192,50,38,0,56,255,37,0,36,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,160,212,37,0,80,174,37,0,4,0,0,0,1,0,0,0,225,255,255,255,255,255,255,255,0,0,0,0,0,0,63,192,0,0,0,0,0,0,240,191,9,0,0,0,0,0,0,0,112,138,37,0,80,73,37,0,20,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,112,138,37,0,96,242,39,0,56,135,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,112,138,37,0,144,24,37,0,104,240,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,112,138,37,0,80,204,36,0,144,174,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,112,138,37,0,128,146,36,0,56,119,36,0,40,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,40,92,36,0,40,66,36,0,48,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,40,92,36,0,96,242,39,0,56,135,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,40,92,36,0,56,40,36,0,176,238,35,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,40,92,36,0,176,203,35,0,56,180,35,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,40,92,36,0,152,157,35,0,24,137,35,0,52,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,80,114,35,0,160,94,35,0,56,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,8,76,35,0,216,57,35,0,60,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,32,38,35,0,8,251,34,0,64,0,0,0,4,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,0,0,0,0,192,223,34,0,8,208,34,0,72,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,192,223,34,0,96,242,39,0,56,135,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,192,223,34,0,144,24,37,0,16,192,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,192,223,34,0,80,204,36,0,16,175,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,192,223,34,0,232,155,34,0,48,141,34,0,76,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,64,9,0,0,0,232,155,34,0,96,242,39,0,56,135,39,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,155,34,0,144,24,37,0,88,126,34,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,155,34,0,80,204,36,0,32,109,34,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,232,155,34,0,200,92,34,0,48,52,34,0,80,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,200,92,34,0,208,28,34,0,184,14,34,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,200,92,34,0,168,255,33,0,120,237,33,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,200,92,34,0,40,223,33,0,144,211,33,0,96,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,9,0,0,0,0,0,0,0,192,200,33,0,56,191,33,0,100,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,192,200,33,0,240,180,33,0,192,147,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,192,200,33,0,96,129,33,0,56,119,33,0,104,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,0,0,0,0,46,64,9,0,0,0,96,129,33,0,240,180,33,0,192,147,33,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,96,129,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,239,34,0,176,42,34,0,0,0,0,0,0,0,0,0,232,239,34,0,192,42,34,0,0,0,0,0,0,0,0,0,88,116,37,0,144,22,36,0,0,0,0,0,0,0,0,0,2,7,7,2,0,0,0,0,0,0,4,4,0,0,0,0,0,0,0,0,2,7,7,2,0,0,0,0,0,0,2,7,5,5,7,2,0,0,0,0,2,7,7,2,6,6,0,0,0,0,2,7,5,5,7,2,8,8,0,0,2,7,7,2,6,7,7,6,0,0,2,7,5,5,7,2,6,7,7,6,72,204,34,0,112,0,0,0,208,153,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,7,8,11,12,255,255,255,255,255,255,0,0,0,0,0,0,1,3,5,7,10,12,13,255,255,255,255,255,255,0,0,0,0,1,2,2,9,13,15,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,2,2,6,9,11,12,13,255,255,255,255,0,0,0,0,0,0,0,0,2,2,6,9,11,12,13,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,2,2,6,9,11,12,13,255,255,255,255,0,0,0,0,0,0,0,0,2,2,6,9,11,12,13,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,3,2,10,11,11,12,12,14,255,0,0,0,0,0,0,0,0,0,0,3,2,10,11,11,12,12,14,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,3,2,10,11,11,12,12,14,255,0,0,0,0,0,0,0,0,0,0,3,2,10,11,11,12,12,14,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,1,6,8,11,12,12,255,255,0,0,0,0,0,0,0,0,0,0,0,1,6,8,11,12,12,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,12,16,32,48,48,48,48,48,48,48,48,48,48,48,48,48,0,0,0,16,20,36,56,56,56,56,56,56,56,56,56,56,56,56,56,0,0,0,32,40,60,60,60,60,60,60,60,60,60,60,60,60,60,60,0,0,0,0,0,0,0,20,24,32,48,48,48,48,48,48,48,48,48,0,0,0,0,0,0,4,24,28,36,56,56,56,56,56,56,56,56,56,0,0,0,0,0,0,20,44,52,60,60,60,60,60,60,60,60,60,60,0,0,0,0,0,0,0,0,0,16,24,32,40,48,48,48,48,48,48,0,0,0,0,0,0,0,0,4,20,28,36,44,56,56,56,56,56,56,0,0,0,0,0,0,0,0,20,40,48,60,60,60,60,60,60,60,60,0,0,0,0,0,0,0,0,0,0,12,24,32,48,48,48,48,48,48,0,0,0,0,0,0,0,0,0,0,16,28,36,56,56,56,56,56,56,0,0,0,0,0,0,0,0,0,0,32,48,60,60,60,60,60,60,60,0,0,0,0,0,0,0,0,0,0,0,8,20,32,40,48,48,48,48,0,0,0,0,0,0,0,0,0,0,0,12,24,36,44,56,56,56,56,0,0,0,0,0,0,0,0,0,0,0,28,44,60,60,60,60,60,60,0,0,0,168,81,40,0,168,246,39,0,20,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,160,139,39,0,8,53,39,0,48,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,56,238,38,0,80,167,38,0,28,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,248,106,38,0,152,52,38,0,36,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,0,0,0,0,0,248,255,37,0,176,213,37,0,44,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,16,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,233,39,0,112,0,0,0,240,19,32,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,77,40,0,0,0,0,0,8,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,136,244,39,0,0,0,0,0,56,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,232,137,39,0,0,0,0,0,60,0,0,0,84,77,70,83,255,255,255,255,255,255,255,255,0,0,0,0,0,0,240,191,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,40,52,39,0,0,0,0,0,80,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,0,0,0,0,0,112,237,38,0,0,0,0,0,64,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,223,65,8,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,31,36,0,112,0,0,0,64,21,32,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,3,0,3,0,3,0,15,0,15,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,255,255,255,255,15,15,15,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,255,0,255,0,255,0,255,0,0,0,255,0,0,0,7,10,12,13,15,17,19,0,3,5,7,9,13,17,25,0,96,113,39,0,48,32,39,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,191,0,0,0,0,0,0,240,63,9,0,0,0,96,113,39,0,64,218,38,0,64,149,38,0,0,0,0,0,128,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,96,113,39,0,144,90,38,0,96,37,38,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,96,113,39,0,224,243,37,0,80,199,37,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,96,113,39,0,160,163,37,0,208,26,156,0,8,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,64,9,0,0,0,160,163,37,0,120,58,37,0,192,15,37,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,160,163,37,0,72,230,36,0,184,195,36,0,0,0,0,0,128,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,160,163,37,0,136,165,36,0,32,139,36,0,0,0,0,0,128,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,160,163,37,0,88,111,36,0,64,84,36,0,0,0,0,0,128,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,224,193,0,0,192,255,255,255,223,65,9,0,0,0,160,163,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,217,39,0,112,0,0,0,80,23,32,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,236,32,0,112,0,0,0,32,155,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,1,3,0,0,0,0,0,0,0,0,1,1,0,1,1,1,3,0,0,0,0,0,0,0,0,1,1,0,1,1,1,3,3,0,4,0,0,0,0,0,1,1,0,1,1,1,1,1,2,3,3,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,55,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,2,0,1,0,0,0,2,0,1,3,0,0,2,0,1,3,4,0,2,0,1,4,5,3,0,0,0,0,1,0,0,0,0,1,1,0,0,0,2,0,1,0,0,3,0,1,0,0,3,0,1,1,0,4,0,1,1,3,0,0,0,3,3,3,3,9,9,8,8,13,13,17,0,0,0,0,0,1,1,2,2,4,4,7,7,12,12,16,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,255,255,255,104,55,43,112,164,178,111,61,134,88,141,67,53,40,121,184,199,111,111,79,37,67,57,0,154,103,89,68,68,68,108,108,108,154,210,132,108,94,181,149,149,149,44,0,0,0,0,0,0,0,116,111,0,0,0,0,0,0,100,114,97,119,32,97,32,112,111,105,110,116,32,102,111,114,32,101,97,99,104,32,115,97,109,112,108,101,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,105,115,99,111,110,115,105,110,95,67,101,110,0,115,105,102,102,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,105,115,99,111,110,115,105,110,95,78,111,114,116,104,0,0,0,0,0,0,0,73,80,52,0,0,0,0,0,118,109,100,0,0,0,0,0,110,108,118,108,32,102,114,111,109,32,37,100,44,32,110,108,118,108,32,116,111,32,37,100,10,0,0,0,0,0,0,0,83,116,97,114,116,32,116,105,109,101,32,105,103,110,111,114,101,100,32,105,110,32,97,32,112,117,114,101,108,121,32,114,101,108,97,116,105,118,101,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,105,100,51,118,50,32,118,101,114,58,37,100,32,102,108,97,103,115,58,37,48,50,88,32,108,101,110,58,37,100,10,0,101,110,99,111,100,101,95,97,117,100,105,111,32,37,100,46,37,100,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,83,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,105,76,66,67,32,98,108,111,99,107,32,115,105,122,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,65,82,77,111,118,105,101,10,0,0,0,0,0,0,0,0,97,117,100,105,111,47,120,45,112,110,45,114,101,97,108,97,117,100,105,111,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,78,0,0,0,0,0,0,0,82,101,97,108,77,101,100,105,97,0,0,0,0,0,0,0,103,101,110,114,101,0,0,0,80,67,83,95,78,65,68,50,55,95,87,97,115,104,105,110,103,116,111,110,95,83,111,117,116,104,0,0,0,0,0,0,37,117,58,37,117,58,37,117,46,37,117,0,0,0,0,0,121,117,118,52,50,48,112,0,115,101,116,32,99,104,97,110,110,101,108,32,100,105,115,112,108,97,121,32,109,111,100,101,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,97,115,104,105,110,103,116,111,110,95,78,111,114,116,104,0,0,0,0,0,0,114,97,119,32,100,97,116,97,0,0,0,0,0,0,0,0,109,106,112,103,44,109,106,112,101,103,44,109,112,111,0,0,80,67,83,95,78,65,68,50,55,95,86,105,114,103,105,110,105,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,101,110,100,32,97,116,111,109,10,0,121,117,118,97,52,52,52,112,49,48,98,101,0,0,0,0,77,101,100,105,117,109,80,117,114,112,108,101,0,0,0,0,70,105,108,101,32,101,110,100,115,32,98,101,102,111,114,101,32,102,105,114,115,116,32,112,97,99,107,101,116,10,0,0,115,101,108,101,99,116,32,108,111,119,32,115,104,105,98,97,116,97,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,116,114,121,32,114,101,100,117,99,105,110,103,32,116,97,114,103,101,116,32,98,105,116,114,97,116,101,10,0,0,0,0,115,112,101,101,100,32,112,114,101,115,101,116,115,32,97,114,101,32,108,105,115,116,101,100,32,105,110,32,120,50,54,52,32,45,45,104,101,108,112,10,0,0,0,0,0,0,0,0,99,100,32,33,61,32,40,105,99,111,110,118,95,116,41,45,49,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,86,105,114,103,105,110,105,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,71,67,83,95,68,101,105,114,95,101,122,95,90,111,114,0,100,105,114,101,99,116,45,112,114,101,100,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,100,105,97,109,111,110,100,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,97,108,105,97,115,32,102,111,114,32,69,80,90,83,41,0,0,0,0,0,0,101,109,105,116,32,109,97,99,114,111,98,108,111,99,107,32,105,110,102,111,32,102,111,114,32,82,70,67,32,50,49,57,48,32,112,97,99,107,101,116,105,122,97,116,105,111,110,44,32,116,104,101,32,112,97,114,97,109,101,116,101,114,32,118,97,108,117,101,32,105,115,32,116,104,101,32,109,97,120,105,109,117,109,32,112,97,121,108,111,97,100,32,115,105,122,101,0,0,0,0,0,0,0,0,104,109,109,44,32,115,101,101,109,115,32,116,104,101,32,104,101,97,100,101,114,115,32,97,114,101,32,110,111,116,32,99,111,109,112,108,101,116,101,44,32,116,114,121,105,110,103,32,116,111,32,103,117,101,115,115,32,116,105,109,101,95,105,110,99,114,101,109,101,110,116,95,98,105,116,115,10,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,111,118,101,114,114,101,97,100,32,37,100,10,0,0,0,0,98,97,100,32,111,112,116,105,111,110,32,39,37,115,39,58,32,39,37,115,39,10,0,0,99,101,110,116,101,114,101,100,0,0,0,0,0,0,0,0,104,45,62,97,118,99,116,120,45,62,115,97,109,112,108,101,95,97,115,112,101,99,116,95,114,97,116,105,111,46,100,101,110,0,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,71,114,97,112,104,105,99,115,32,40,83,77,67,41,0,0,0,0,0,0,0,0,65,99,111,117,115,116,105,99,0,0,0,0,0,0,0,0,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,83,101,103,109,101,110,116,32,102,105,110,105,115,104,101,100,32,97,116,32,112,116,115,61,37,108,108,100,10,0,0,0,80,67,83,95,78,65,68,50,55,95,86,101,114,109,111,110,116,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2095264);
/* memory initializer */ allocate([80,67,83,95,78,65,68,50,55,95,85,116,97,104,95,83,111,117,116,104,0,0,0,0,114,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,111,114,99,101,100,32,102,114,97,109,101,115,32,97,114,114,97,121,10,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,102,108,117,115,104,95,112,97,99,107,101,116,115,0,0,0,80,67,83,95,78,65,68,50,55,95,85,116,97,104,95,67,101,110,116,114,97,108,0,0,70,105,108,101,32,105,115,32,101,110,99,114,121,112,116,101,100,10,0,0,0,0,0,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,51,100,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,116,97,104,95,78,111,114,116,104,0,0,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,79,112,117,115,0,0,0,0,102,105,108,101,110,97,109,101,32,37,115,44,32,108,101,110,32,37,100,10,0,0,0,0,102,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,111,114,32,114,101,112,108,97,99,101,32,115,116,114,101,97,109,10,0,0,0,0,0,37,100,47,37,100,0,0,0,84,82,75,0,0,0,0,0,65,117,100,105,111,32,101,110,99,111,100,105,110,103,32,102,97,105,108,101,100,32,40,97,118,99,111,100,101,99,95,101,110,99,111,100,101,95,97,117,100,105,111,50,41,10,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,83,111,117,116,104,0,0,0,115,101,103,109,101,110,116,0,114,101,97,100,95,116,105,109,101,115,116,97,109,112,40,88,44,37,100,44,37,108,108,100,44,37,108,108,100,41,10,0,102,105,108,109,95,99,112,107,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,83,111,117,116,104,95,67,101,110,0,0,0,0,0,0,0,99,111,100,105,110,103,32,37,115,0,0,0,0,0,0,0,115,100,114,50,0,0,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,67,101,110,116,114,97,108,0,115,101,116,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,105,110,118,97,108,105,100,32,101,110,99,111,100,101,100,32,116,114,105,112,108,101,116,10,0,0,0,0,0,0,0,0,109,117,108,116,105,112,108,101,32,118,105,100,101,111,32,115,116,114,101,97,109,115,32,115,117,112,112,111,114,116,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,78,111,114,116,104,95,67,101,110,0,0,0,0,0,0,0,69,110,99,111,100,101,114,32,100,105,100,32,110,111,116,32,112,114,111,100,117,99,101,32,112,114,111,112,101,114,32,112,116,115,44,32,109,97,107,105,110,103,32,115,111,109,101,32,117,112,46,10,0,0,0,0,80,67,83,95,78,65,68,50,55,95,84,101,120,97,115,95,78,111,114,116,104,0,0,0,114,0,0,0,0,0,0,0,115,104,111,119,119,97,118,101,115,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,121,117,118,97,52,50,50,112,49,48,108,101,0,0,0,0,77,101,100,105,117,109,79,114,99,104,105,100,0,0,0,0,108,111,119,95,115,104,105,98,97,116,97,0,0,0,0,0,116,114,121,32,114,101,100,117,99,105,110,103,32,116,97,114,103,101,116,32,98,105,116,114,97,116,101,32,111,114,32,114,101,100,117,99,105,110,103,32,113,112,95,109,105,110,32,40,99,117,114,114,101,110,116,108,121,32,37,100,41,10,0,0,112,114,101,115,101,116,32,117,115,97,103,101,58,32,45,118,112,114,101,32,60,115,112,101,101,100,62,32,45,118,112,114,101,32,60,112,114,111,102,105,108,101,62,10,0,0,0,0,99,111,109,112,117,116,101,95,112,99,114,0,0,0,0,0,112,32,60,61,32,101,110,100,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,84,101,110,110,101,115,115,101,101,0,0,0,0,0,71,67,83,95,67,111,116,101,95,100,95,73,118,111,105,114,101,0,0,0,0,0,0,0,100,105,114,101,99,116,0,0,112,99,109,95,117,51,50,98,101,0,0,0,0,0,0,0,100,105,97,0,0,0,0,0,77,80,69,71,45,50,32,80,83,32,40,83,86,67,68,41,0,0,0,0,0,0,0,0,109,98,95,105,110,102,111,0,98,101,102,111,114,101,32,116,105,109,101,95,105,110,99,114,101,109,101,110,116,0,0,0,109,98,95,98,105,116,109,97,115,107,95,115,105,122,101,32,109,105,115,109,97,116,99,104,101,115,10,0,0,0,0,0,80,111,115,115,105,98,108,101,32,116,117,110,101,115,58,0,102,111,114,119,97,114,100,0,33,112,105,99,45,62,104,119,97,99,99,101,108,95,112,105,99,116,117,114,101,95,112,114,105,118,97,116,101,0,0,0,73,68,88,0,0,0,0,0,115,109,99,0,0,0,0,0,85,110,107,110,111,119,110,32,115,116,114,101,97,109,32,118,101,114,115,105,111,110,32,37,100,10,0,0,0,0,0,0,69,97,115,121,32,76,105,115,116,101,110,105,110,103,0,0,116,98,99,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,83,111,117,116,104,95,68,97,107,111,116,97,95,83,0,0,0,0,0,0,0,0,84,80,69,49,0,0,0,0,117,115,101,32,116,97,98,108,101,32,111,102,32,99,111,110,116,101,110,116,115,0,0,0,80,67,83,95,78,65,68,50,55,95,83,111,117,116,104,95,68,97,107,111,116,97,95,78,0,0,0,0,0,0,0,0,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,115,104,97,114,101,47,102,102,109,112,101,103,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,115,101,108,101,99,116,32,115,116,114,101,97,109,32,109,97,116,99,104,105,110,103,32,105,100,101,110,116,105,102,105,101,114,32,39,37,115,39,10,0,0,0,0,0,0,0,114,101,99,111,114,100,32,111,114,32,116,114,97,110,115,99,111,100,101,32,34,100,117,114,97,116,105,111,110,34,32,115,101,99,111,110,100,115,32,111,102,32,97,117,100,105,111,47,118,105,100,101,111,0,0,0,80,67,83,95,78,65,68,50,55,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,83,0,0,0,0,0,0,118,105,100,101,111,0,0,0,80,67,83,95,78,65,68,50,55,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,78,0,0,0,0,0,0,118,111,108,117,109,101,32,37,115,44,32,108,101,110,32,37,100,10,0,0,0,0,0,0,84,80,51,0,0,0,0,0,101,110,99,111,100,101,114,32,60,45,32,116,121,112,101,58,97,117,100,105,111,32,102,114,97,109,101,95,112,116,115,58,37,115,32,102,114,97,109,101,95,112,116,115,95,116,105,109,101,58,37,115,32,116,105,109,101,95,98,97,115,101,58,37,100,47,37,100,10,0,0,0,80,67,83,95,78,65,68,50,55,95,82,104,111,100,101,95,73,115,108,97,110,100,0,0,80,67,83,95,78,65,68,50,55,95,80,101,110,110,115,121,108,118,97,110,105,97,95,83,0,0,0,0,0,0,0,0,123,37,42,100,125,123,125,37,99,0,0,0,0,0,0,0,35,102,111,114,109,97,116,58,32,102,114,97,109,101,32,99,104,101,99,107,115,117,109,115,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,80,101,110,110,115,121,108,118,97,110,105,97,95,78,0,0,0,0,0,0,0,0,109,107,97,0,0,0,0,0,49,46,50,46,53,0,0,0,115,98,103,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,79,114,101,103,111,110,95,83,111,117,116,104,0,0,111,110,108,121,32,49,54,45,44,32,50,48,45,44,32,50,52,45,32,97,110,100,32,51,50,45,98,105,116,32,80,67,77,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,76,65,84,77,47,76,79,65,83,32,109,117,120,101,114,0,68,73,82,69,67,84,73,86,69,0,0,0,0,0,0,0,83,65,85,67,69,48,48,0,80,67,83,95,78,65,68,50,55,95,79,114,101,103,111,110,95,78,111,114,116,104,0,0,121,117,118,97,52,50,50,112,49,48,98,101,0,0,0,0,77,101,100,105,117,109,66,108,117,101,0,0,0,0,0,0,115,101,108,101,99,116,32,115,104,105,98,97,116,97,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,0,0,0,0,116,97,114,103,101,116,58,32,37,46,50,102,32,107,98,105,116,47,115,44,32,101,120,112,101,99,116,101,100,58,32,37,46,50,102,32,107,98,105,116,47,115,44,32,97,118,103,32,81,80,58,32,37,46,52,102,10,0,0,0,0,0,0,0,117,115,101,32,97,110,32,101,110,99,111,100,105,110,103,32,112,114,101,115,101,116,32,40,101,46,103,46,32,45,118,112,114,101,32,109,101,100,105,117,109,41,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,97,109,105,0,0,0,0,102,102,95,97,118,99,111,100,101,99,95,108,111,99,107,101,100,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,79,107,108,97,104,111,109,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,67,83,95,67,111,114,114,101,103,111,95,65,108,101,103,114,101,0,0,0,0,0,0,119,101,105,103,104,116,112,0,116,101,115,97,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,72,46,50,54,51,32,101,110,99,111,100,101,114,0,0,0,102,111,114,99,101,32,108,111,111,112,32,111,118,101,114,32,105,110,112,117,116,32,102,105,108,101,32,115,101,113,117,101,110,99,101,0,0,0,0,0,108,111,119,95,100,101,108,97,121,32,102,108,97,103,32,105,110,99,111,114,114,101,99,116,108,121,44,32,99,108,101,97,114,105,110,103,32,105,116,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,10,0,0,0,0,0,0,0,98,97,99,107,119,97,114,100,0,0,0,0,0,0,0,0,33,112,105,99,45,62,102,46,100,97,116,97,91,48,93,0,81,117,105,99,107,84,105,109,101,32,56,66,80,83,32,118,105,100,101,111,0,0,0,0,67,104,111,114,117,115,0,0,112,112,109,0,0,0,0,0,116,98,110,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,79,107,108,97,104,111,109,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,83,101,110,100,105,110,103,32,78,65,76,32,37,120,32,111,102,32,108,101,110,32,37,100,32,77,61,37,100,10,0,0,80,67,83,95,78,65,68,50,55,95,79,104,105,111,95,83,111,117,116,104,0,0,0,0,72,79,77,69,0,0,0,0,102,111,114,109,97,116,32,37,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,115,112,108,105,116,32,72,50,54,51,32,112,97,99,107,101,116,44,32,117,115,101,32,45,109,98,95,105,110,102,111,32,37,100,32,111,114,32,108,111,119,101,114,46,10,0,116,0,0,0,0,0,0,0,101,110,99,111,100,101,100,95,98,121,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,37,115,10,0,0,0,114,116,112,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,79,104,105,111,95,78,111,114,116,104,0,0,0,0,35,69,88,84,45,88,45,69,78,68,76,73,83,84,10,0,37,100,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,111,114,116,104,95,68,97,107,111,116,97,95,83,0,0,0,0,0,0,0,0,9,60,115,116,114,101,97,109,84,121,112,101,62,37,115,60,47,115,116,114,101,97,109,84,121,112,101,62,10,0,0,0,109,117,108,116,105,112,108,101,32,101,100,105,116,32,108,105,115,116,32,101,110,116,114,105,101,115,44,32,97,47,118,32,100,101,115,121,110,99,32,109,105,103,104,116,32,111,99,99,117,114,44,32,112,97,116,99,104,32,119,101,108,99,111,109,101,10,0,0,0,0,0,0,69,88,84,58,47,80,68,82,47,100,101,102,97,117,108,116,47,0,0,0,0,0,0,0,109,97,116,101,114,105,97,108,32,100,97,116,97,32,108,111,110,103,101,114,32,116,104,97,110,32,109,97,112,32,100,97,116,97,10,0,0,0,0,0,100,101,102,97,117,108,116,32,100,101,108,97,121,32,98,101,116,119,101,101,110,32,102,114,97,109,101,115,32,40,105,110,32,104,117,110,100,114,101,100,116,104,115,32,111,102,32,115,101,99,111,110,100,41,0,0,84,80,50,0,0,0,0,0,112,107,116,46,115,105,122,101,32,124,124,32,33,112,107,116,46,100,97,116,97,0,0,0,80,67,83,95,78,65,68,50,55,95,78,111,114,116,104,95,68,97,107,111,116,97,95,78,0,0,0,0,0,0,0,0,56,57,97,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,111,114,116,104,95,67,97,114,111,108,105,110,97,0,0,0,0,0,0,0,0,77,97,108,102,111,114,109,101,100,32,65,65,67,32,98,105,116,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,58,32,117,115,101,32,97,117,100,105,111,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,39,97,97,99,95,97,100,116,115,116,111,97,115,99,39,32,116,111,32,102,105,120,32,105,116,32,40,39,45,98,115,102,58,97,32,97,97,99,95,97,100,116,115,116,111,97,115,99,39,32,111,112,116,105,111,110,32,119,105,116,104,32,102,102,109,112,101,103,41,10,0,0,0,0,0,111,110,84,101,120,116,68,97,116,97,0,0,0,0,0,0,119,114,105,116,101,95,104,101,97,100,101,114,0,0,0,0,114,116,112,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,89,111,114,107,95,76,111,110,103,95,73,115,0,0,0,0,0,0,59,70,70,77,69,84,65,68,65,84,65,0,0,0,0,0,59,70,70,77,69,84,65,68,65,84,65,0,0,0,0,0,114,115,111,0,0,0,0,0,117,110,107,110,111,119,110,32,83,67,72,108,32,104,101,97,100,101,114,105,100,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,89,111,114,107,95,87,101,115,116,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,115,111,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,89,111,114,107,95,67,101,110,116,114,97,108,0,0,0,0,0,0,102,102,99,111,110,99,97,116,0,0,0,0,0,0,0,0,114,115,100,0,0,0,0,0,121,117,118,97,52,50,48,112,49,48,108,101,0,0,0,0,77,101,100,105,117,109,65,113,117,97,77,97,114,105,110,101,0,0,0,0,0,0,0,0,81,80,50,76,65,77,66,68,65,0,0,0,0,0,0,0,115,104,105,98,97,116,97,0,69,114,114,111,114,58,32,50,112,97,115,115,32,99,117,114,118,101,32,102,97,105,108,101,100,32,116,111,32,99,111,110,118,101,114,103,101,10,0,0,98,114,111,107,101,110,32,102,102,109,112,101,103,32,100,101,102,97,117,108,116,32,115,101,116,116,105,110,103,115,32,100,101,116,101,99,116,101,100,10,0,0,0,0,0,0,0,0,33,102,102,95,97,118,99,111,100,101,99,95,108,111,99,107,101,100,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,89,111,114,107,95,69,97,115,116,0,71,67,83,95,67,104,117,97,0,0,0,0,0,0,0,0,119,101,105,103,104,116,45,98,0,0,0,0,0,0,0,0,116,101,115,97,0,0,0,0,87,114,105,116,101,32,115,108,105,99,101,32,115,116,97,114,116,32,112,111,115,105,116,105,111,110,32,97,116,32,101,118,101,114,121,32,71,79,66,32,104,101,97,100,101,114,32,105,110,115,116,101,97,100,32,111,102,32,106,117,115,116,32,71,79,66,32,110,117,109,98,101,114,46,0,0,0,0,0,0,100,105,118,120,32,115,116,121,108,101,32,112,97,99,107,101,100,32,98,32,102,114,97,109,101,115,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,32,37,115,0,0,0,0,0,97,114,110,114,95,116,121,112,101,0,0,0,0,0,0,0,65,114,116,119,111,114,120,32,68,97,116,97,32,70,111,114,109,97,116,32,100,101,109,117,120,101,114,0,0,0,0,0,114,112,108,0,0,0,0,0,115,114,99,45,62,102,46,98,117,102,91,48,93,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,105,110,100,101,120,32,116,97,98,108,101,10,0,0,0,0,0,0,56,98,112,115,0,0,0,0,66,105,103,32,66,97,110,100,0,0,0,0,0,0,0,0,116,98,114,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,77,101,120,105,99,111,95,87,101,115,116,0,0,0,0,0,0,0,45,100,0,0,0,0,0,0,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,43,45,46,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,77,101,120,105,99,111,95,67,101,110,116,0,0,0,0,0,0,0,70,70,77,80,69,71,95,68,65,84,65,68,73,82,0,0,83,101,108,101,99,116,101,100,32,115,116,114,101,97,109,32,105,100,58,37,100,32,116,121,112,101,58,37,115,10,0,0,73,110,118,97,108,105,100,32,114,105,102,102,32,105,110,100,101,120,32,37,100,32,62,32,37,100,10,0,0,0,0,0,114,109,0,0,0,0,0,0,105,110,112,117,116,95,102,105,108,101,95,105,110,100,101,120,0,0,0,0,0,0,0,0,83,107,105,112,105,110,103,32,102,111,114,101,105,103,110,32,115,116,114,101,97,109,32,37,100,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,77,101,120,105,99,111,95,69,97,115,116,0,0,0,0,0,0,0,108,111,111,112,101,110,100,32,99,97,110,39,116,32,98,101,32,108,101,115,115,32,111,114,32,101,113,117,97,108,32,116,111,32,108,111,111,112,115,116,97,114,116,10,0,0,0,0,99,111,109,109,101,110,116,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,74,101,114,115,101,121,0,0,0,0,102,114,101,101,0,0,0,0,102,102,32,97,115,102,32,98,97,100,32,110,111,110,32,122,101,114,111,10,0,0,0,0,85,110,107,110,111,119,110,32,77,79,86,32,102,105,101,108,100,32,111,114,100,101,114,32,48,120,37,48,52,120,10,0,115,101,116,32,116,104,101,32,109,111,118,105,101,32,102,114,97,109,101,32,114,97,116,101,0,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,98,105,110,97,114,121,32,116,97,103,32,39,37,115,39,46,10,0,0,0,0,0,0,68,101,99,111,100,105,110,103,32,102,105,108,101,32,45,32,118,37,100,46,37,48,50,100,44,32,99,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,37,117,10,0,84,80,49,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,119,95,72,97,109,112,115,104,105,114,101,0,48,0,0,0,0,0,0,0,108,111,103,105,99,97,108,45,102,105,108,101,105,110,102,111,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,118,97,100,97,95,87,101,115,116,0,0,0,114,108,50,0,0,0,0,0,115,97,116,117,114,97,116,105,111,110,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,118,97,100,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,0,33,102,115,45,62,105,110,91,105,110,93,46,104,97,118,101,95,110,101,120,116,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,78,65,68,50,55,95,78,101,118,97,100,97,95,69,97,115,116,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,111,117,98,108,101,0,0,108,97,118,102,105,46,115,105,108,101,110,99,101,95,115,116,97,114,116,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,78,101,98,114,97,115,107,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,69,120,112,101,99,116,101,100,32,105,110,32,99,104,97,110,110,101,108,32,110,97,109,101,44,32,103,111,116,32,34,37,46,56,115,34,10,0,0,0,121,117,118,97,52,50,48,112,49,48,98,101,0,0,0,0,77,97,114,111,111,110,0,0,69,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,115,101,112,97,114,97,116,111,114,32,39,45,39,32,105,110,32,99,104,97,110,110,101,108,32,109,97,112,32,39,37,115,39,10,0,0,0,0,0,0,115,101,108,101,99,116,32,108,105,112,115,104,105,116,122,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,0,0,0,114,99,101,45,62,110,101,119,95,113,115,99,97,108,101,32,62,61,32,48,0,0,0,0,79,112,101,110,67,76,58,32,100,101,118,105,99,101,32,105,100,32,97,110,100,32,100,101,118,105,99,101,32,115,107,105,112,32,99,111,117,110,116,32,99,111,110,102,105,103,117,114,101,100,59,32,100,114,111,112,112,105,110,103,32,115,107,105,112,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,100,10,0,0,0,0,0,0,0,0,78,111,32,108,111,99,107,32,109,97,110,97,103,101,114,32,105,115,32,115,101,116,44,32,112,108,101,97,115,101,32,115,101,101,32,97,118,95,108,111,99,107,109,103,114,95,114,101,103,105,115,116,101,114,40,41,10,0,0,0,0,0,0,0,115,101,116,32,112,111,105,110,116,115,32,111,102,32,116,114,97,110,115,102,101,114,32,102,117,110,99,116,105,111,110,0,80,67,83,95,78,65,68,50,55,95,78,101,98,114,97,115,107,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,71,67,83,95,67,97,114,116,104,97,103,101,0,0,0,0,119,101,105,103,104,116,98,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,101,115,97,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,97,108,105,97,115,32,102,111,114,32,102,117,108,108,41,0,0,109,97,112,0,0,0,0,0,115,116,114,117,99,116,117,114,101,100,95,115,108,105,99,101,115,0,0,0,0,0,0,0,100,105,118,120,95,112,97,99,107,101,100,0,0,0,0,0,109,106,112,101,103,58,32,101,114,114,111,114,44,32,100,101,99,111,100,101,95,97,112,112,32,112,97,114,115,101,114,32,114,101,97,100,32,111,118,101,114,32,116,104,101,32,101,110,100,10,0,0,0,0,0,0,80,111,115,115,105,98,108,101,32,112,114,101,115,101,116,115,58,0,0,0,0,0,0,0,97,108,116,114,101,102,32,110,111,105,115,101,32,114,101,100,117,99,116,105,111,110,32,102,105,108,116,101,114,32,116,121,112,101,0,0,0,0,0,0,33,100,115,116,45,62,102,46,98,117,102,91,48,93,0,0,105,100,32,81,117,97,107,101,32,73,73,32,67,73,78,32,118,105,100,101,111,0,0,0,83,108,111,119,32,82,111,99,107,0,0,0,0,0,0,0,102,112,115,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,111,110,116,97,110,97,95,83,111,117,116,104,0,65,112,112,108,121,32,97,32,116,119,111,45,112,111,108,101,32,66,117,116,116,101,114,119,111,114,116,104,32,98,97,110,100,45,114,101,106,101,99,116,32,102,105,108,116,101,114,46,0,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,116,101,109,112,111,46,99,0,101,120,112,114,0,0,0,0,82,77,83,32,116,114,111,117,103,104,32,100,66,58,32,37,102,10,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,111,110,116,97,110,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,114,101,97,100,105,110,103,32,102,105,108,101,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,37,108,108,100,0,0,0,0,39,101,120,116,39,32,108,105,115,116,32,116,121,112,101,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,32,105,110,32,102,97,118,111,114,32,111,102,32,39,99,115,118,39,10,0,105,110,118,97,108,105,100,32,99,111,100,101,32,108,101,110,103,116,104,115,32,115,101,116,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,73,65,82,84,0,0,0,0,111,99,104,0,0,0,0,0,115,101,116,32,99,104,97,112,116,101,114,115,32,109,97,112,112,105,110,103,0,0,0,0,115,101,116,32,100,101,108,97,121,32,105,110,32,109,105,108,108,105,115,101,99,111,110,100,115,0,0,0,0,0,0,0,78,85,76,76,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,111,110,116,97,110,97,95,78,111,114,116,104,0,100,101,102,97,117,108,116,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,114,101,100,115,112,97,114,107,0,0,0,0,0,0,0,0,105,110,37,100,0,0,0,0,115,97,109,112,108,101,95,102,109,116,115,0,0,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,53,0,114,101,115,101,114,118,101,100,95,109,111,111,118,95,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,44,32,110,101,101,100,101,100,32,37,108,108,100,32,97,100,100,105,116,105,111,110,97,108,10,0,0,0,0,0,0,0,0,99,111,109,112,97,116,105,98,108,101,95,98,114,97,110,100,115,0,0,0,0,0,0,0,115,116,97,114,116,95,115,97,109,112,108,101,0,0,0,0,37,102,0,0,0,0,0,0,84,69,78,0,0,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,52,0,65,117,100,105,111,32,102,105,108,116,101,114,32,103,114,97,112,104,32,111,117,116,112,117,116,32,105,115,32,110,111,116,32,110,111,114,109,97,108,105,122,101,100,32,97,110,100,32,101,110,99,111,100,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,112,97,114,97,109,101,116,101,114,32,99,104,97,110,103,101,115,10,0,0,0,0,0,114,101,97,108,116,101,120,116,0,0,0,0,0,0,0,0,34,73,110,118,97,108,105,100,32,112,97,114,116,105,116,105,111,110,32,116,121,112,101,46,34,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,109,97,120,95,116,120,95,115,105,122,101,46,34,0,0,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,51,0,71,101,110,101,114,97,116,101,32,82,71,66,32,116,101,115,116,32,112,97,116,116,101,114,110,46,0,0,0,0,0,0,100,0,0,0,0,0,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,99,111,101,102,44,32,122,101,114,111,95,99,111,117,110,116,115,46,99,111,101,102,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,99,111,101,102,41,41,0,0,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,50,0,114,0,0,0,0,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,115,105,122,101,32,105,115,32,37,100,120,37,100,32,119,104,105,99,104,32,99,97,110,110,111,116,32,99,111,110,116,97,105,110,32,116,104,101,32,112,114,111,118,105,100,101,100,32,102,105,108,101,32,115,105,122,101,32,111,102,32,37,100,120,37,100,10,0,0,0,0,0,0,0,80,67,83,95,68,72,68,78,95,71,101,114,109,97,110,121,95,122,111,110,101,95,49,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,33,40,108,102,109,45,62,97,98,111,118,101,95,121,91,84,88,95,49,54,88,49,54,93,32,38,32,108,102,109,45,62,97,98,111,118,101,95,121,91,84,88,95,56,88,56,93,41,0,0,0,0,0,0,0,0,115,101,110,100,32,111,110,101,32,102,114,97,109,101,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,44,32,98,117,116,32,115,107,105,112,32,115,112,97,116,105,97,108,32,105,110,116,101,114,108,97,99,105,110,103,32,99,104,101,99,107,0,0,0,0,0,0,0,100,101,105,110,116,101,114,108,97,99,101,32,97,108,108,32,102,114,97,109,101,115,0,0,80,67,83,95,66,101,108,103,101,95,76,97,109,98,101,114,116,95,55,50,0,0,0,0,114,0,0,0,0,0,0,0,121,117,118,97,52,52,52,112,57,108,101,0,0,0,0,0,77,97,103,101,110,116,97,0,80,73,0,0,0,0,0,0,108,105,112,115,104,105,116,122,0,0,0,0,0,0,0,0,102,105,108,116,101,114,95,115,105,122,101,37,50,32,61,61,32,49,0,0,0,0,0,0,79,112,101,110,67,76,58,32,102,114,97,109,101,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,44,32,100,105,115,97,98,108,105,110,103,32,111,112,101,110,99,108,10,0,0,0,0,0,0,108,117,109,97,95,97,109,111,117,110,116,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,116,104,114,101,97,100,32,108,111,99,107,105,110,103,32,97,114,111,117,110,100,32,97,118,99,111,100,101,99,95,111,112,101,110,47,99,108,111,115,101,40,41,10,0,0,0,0,0,0,0,0,80,67,83,95,77,71,73,95,65,117,115,116,114,105,97,95,69,97,115,116,0,0,0,0,71,67,83,95,67,97,112,101,0,0,0,0,0,0,0,0,56,120,56,100,99,116,0,0,114,111,116,97,116,101,32,99,111,117,110,116,101,114,45,99,108,111,99,107,119,105,115,101,0,0,0,0,0,0,0,0,112,99,109,95,117,50,52,108,101,0,0,0,0,0,0,0,101,115,97,0,0,0,0,0,117,115,101,32,111,118,101,114,108,97,112,112,101,100,32,98,108,111,99,107,32,109,111,116,105,111,110,32,99,111,109,112,101,110,115,97,116,105,111,110,46,0,0,0,0,0,0,0,49,47,52,32,115,117,98,112,101,108,32,77,67,0,0,0,109,106,112,101,103,58,32,65,112,112,108,101,32,77,74,80,69,71,45,65,32,104,101,97,100,101,114,32,102,111,117,110,100,10,0,0,0,0,0,0,69,114,114,111,114,32,115,101,116,116,105,110,103,32,112,114,101,115,101,116,47,116,117,110,101,32,37,115,47,37,115,46,10,0,0,0,0,0,0,0,97,114,110,114,45,116,121,112,101,0,0,0,0,0,0,0,100,114,111,112,32,111,100,100,32,102,105,101,108,100,115,0,110,111,32,102,114,97,109,101,32,98,117,102,102,101,114,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,0,105,100,99,105,110,0,0,0,109,97,114,103,105,110,0,0,83,121,109,112,104,111,110,105,99,32,82,111,99,107,0,0,44,32,83,65,82,32,37,100,58,37,100,32,68,65,82,32,37,100,58,37,100,0,0,0,80,67,83,95,77,71,73,95,65,117,115,116,114,105,97,95,67,101,110,116,114,97,108,0,115,101,108,101,99,116,32,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,32,111,114,32,99,111,114,114,117,112,116,32,112,97,114,116,105,116,105,111,110,32,37,100,32,108,101,110,103,116,104,0,80,67,83,95,77,71,73,95,65,117,115,116,114,105,97,95,87,101,115,116,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,105,108,101,32,98,117,102,102,101,114,10,0,102,102,99,97,116,44,102,102,99,111,110,99,97,116,0,0,97,98,111,118,101,32,98,101,108,111,119,32,108,101,102,116,32,102,105,114,115,116,0,0,115,101,116,32,116,104,114,101,115,104,111,108,100,105,110,103,32,109,111,100,101,0,0,0,109,97,112,95,99,104,97,112,116,101,114,115,0,0,0,0,108,117,109,97,95,116,104,114,101,115,104,111,108,100,0,0,109,97,120,105,109,117,109,32,98,117,102,102,101,114,105,110,103,32,100,117,114,97,116,105,111,110,32,102,111,114,32,105,110,116,101,114,108,101,97,118,105,110,103,0,0,0,0,0,80,67,83,95,90,97,110,100,101,114,105,106,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,0,0,0,0,0,109,97,114,107,32,97,115,32,116,111,112,45,102,105,101,108,100,45,102,105,114,115,116,0,80,67,83,95,89,111,102,102,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,0,119,58,37,115,32,104,58,37,115,32,102,108,97,103,115,58,39,37,115,39,32,105,110,116,101,114,108,58,37,100,10,0,83,116,97,114,116,105,110,103,32,115,101,99,111,110,100,32,112,97,115,115,58,32,109,111,118,105,110,103,32,116,104,101,32,109,111,111,118,32,97,116,111,109,32,116,111,32,116,104,101,32,98,101,103,105,110,110,105,110,103,32,111,102,32,116,104,101,32,102,105,108,101,10,0,0,0,0,0,0,0,0,109,105,110,111,114,95,118,101,114,115,105,111,110,0,0,0,108,117,109,97,95,115,116,114,101,110,103,116,104,0,0,0,111,117,116,95,119,0,0,0,84,84,50,0,0,0,0,0,80,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,85,84,77,95,51,50,78,0,102,105,108,116,101,114,32,45,62,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,116,105,109,101,95,98,97,115,101,58,37,100,47,37,100,10,0,0,0,77,97,115,107,32,105,109,97,103,101,32,115,105,122,101,32,37,100,120,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,119,105,116,104,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,115,101,116,32,98,111,116,116,111,109,32,106,117,110,107,32,115,105,122,101,0,0,0,0,110,58,37,108,108,100,32,109,115,101,95,97,118,103,58,37,48,46,50,102,32,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,112,112,46,99,0,0,0,0,0,80,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,85,84,77,95,51,49,78,0,98,111,116,116,111,109,32,102,105,114,115,116,0,0,0,0,109,98,109,105,45,62,109,111,100,101,32,61,61,32,78,69,65,82,69,83,84,77,86,32,124,124,32,109,98,109,105,45,62,109,111,100,101,32,61,61,32,78,69,65,82,77,86,32,124,124,32,109,98,109,105,45,62,109,111,100,101,32,61,61,32,90,69,82,79,77,86,0,87,0,0,0,0,0,0,0,80,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,85,84,77,95,51,48,78,0,104,0,0,0,0,0,0,0,99,115,0,0,0,0,0,0,97,99,51,0,0,0,0,0,72,0,0,0,0,0,0,0,80,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,85,84,77,95,50,57,78,0,99,109,45,62,98,105,116,95,100,101,112,116,104,32,62,32,66,73,84,83,95,56,0,0,97,108,108,102,0,0,0,0,102,114,97,99,0,0,0,0,80,67,83,95,66,101,114,110,95,49,57,51,56,95,83,119,105,115,115,95,78,101,119,0,118,102,46,99,58,32,104,97,118,101,32,116,111,32,82,69,65,76,76,79,67,65,84,69,32,98,117,102,102,101,114,32,109,101,109,111,114,121,32,58,40,10,0,0,0,0,0,0,121,117,118,97,52,52,52,112,57,98,101,0,0,0,0,0,76,105,110,101,110,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,10,0,0,0,0,0,0,115,101,108,101,99,116,32,116,114,105,97,110,103,117,108,97,114,32,100,105,116,104,101,114,32,119,105,116,104,32,104,105,103,104,32,112,97,115,115,0,115,101,116,32,105,110,112,117,116,32,116,111,32,111,117,116,112,117,116,32,112,108,97,110,101,32,109,97,112,112,105,110,103,0,0,0,0,0,0,0,113,115,99,97,108,101,91,105,93,32,62,61,32,48,0,0,110,111,116,32,99,111,109,112,105,108,101,100,32,119,105,116,104,32,116,104,114,101,97,100,32,115,117,112,112,111,114,116,33,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,97,115,115,117,109,101,100,32,112,105,99,116,117,114,101,32,102,105,101,108,100,32,112,97,114,105,116,121,0,0,0,0,80,67,83,95,86,111,105,114,111,108,95,85,110,105,102,105,101,95,83,95,65,108,103,101,114,105,101,0,0,0,0,0,71,67,83,95,67,97,109,112,111,95,73,110,99,104,97,117,115,112,101,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,108,102,95,114,101,102,95,102,114,97,109,101,0,0,0,0,98,56,120,56,0,0,0,0,69,80,90,83,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,0,111,98,109,99,0,0,0,0,113,117,97,114,116,101,114,95,115,97,109,112,108,101,0,0,69,114,114,111,114,58,32,110,97,108,32,98,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,97,108,116,114,101,102,32,110,111,105,115,101,32,114,101,100,117,99,116,105,111,110,32,102,105,108,116,101,114,32,115,116,114,101,110,103,116,104,0,0,115,101,108,101,99,116,32,105,110,116,101,114,112,111,108,97,116,105,111,110,32,109,111,100,101,0,0,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,115,116,97,114,116,32,97,32,102,114,97,109,101,32,111,117,116,115,105,100,101,32,83,69,84,85,80,32,115,116,97,116,101,10,0,0,0,77,105,99,114,111,115,111,102,116,32,86,105,100,101,111,32,49,0,0,0,0,0,0,0,80,115,121,99,104,101,100,101,108,105,99,32,82,111,99,107,0,0,0,0,0,0,0,0,66,105,116,115,116,114,101,97,109,32,114,101,113,117,105,114,101,100,32,102,101,97,116,117,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,105,115,32,100,101,99,111,100,101,114,0,0,0,0,0,0,0,0,58,32,37,115,0,0,0,0,80,67,83,95,86,111,105,114,111,108,95,85,110,105,102,105,101,95,78,95,65,108,103,101,114,105,101,0,0,0,0,0,118,97,108,0,0,0,0,0,101,110,97,98,108,101,32,115,104,97,114,112,101,110,105,110,103,0,0,0,0,0,0,0,40,100,101,112,114,101,99,97,116,101,100,44,32,116,104,105,115,32,111,112,116,105,111,110,32,105,115,32,97,108,119,97,121,115,32,115,101,116,41,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,114,99,95,109,105,110,95,113,117,97,110,116,105,122,101,114,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,99,102,103,45,62,114,99,95,109,97,120,95,113,117,97,110,116,105,122,101,114,93,0,80,67,83,95,86,111,105,114,111,108,95,83,95,65,108,103,101,114,105,101,95,97,110,99,105,101,110,0,0,0,0,0,73,79,32,101,114,114,111,114,58,32,37,115,10,0,0,0,73,110,118,97,108,105,100,32,116,105,109,101,32,100,117,114,97,116,105,111,110,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,39,37,115,39,32,102,111,114,32,115,101,103,109,101,110,116,95,116,105,109,101,32,111,112,116,105,111,110,10,0,0,0,0,0,0,0,83,105,110,103,108,101,32,102,114,97,109,101,58,37,115,44,32,77,117,108,116,105,32,102,114,97,109,101,58,37,115,10,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,114,99,95,109,105,110,95,113,117,97,110,116,105,122,101,114,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,99,102,103,45,62,114,99,95,109,97,120,95,113,117,97,110,116,105,122,101,114,93,0,99,104,114,111,109,97,95,116,109,112,0,0,0,0,0,0,111,117,116,102,105,108,101,91,44,109,101,116,97,100,97,116,97,93,58,105,110,102,105,108,101,91,44,109,101,116,97,100,97,116,97,93,0,0,0,0,109,97,120,95,105,110,116,101,114,108,101,97,118,101,95,100,101,108,116,97,0,0,0,0,80,67,83,95,86,111,105,114,111,108,95,78,95,65,108,103,101,114,105,101,95,97,110,99,105,101,110,0,0,0,0,0,119,97,118,101,102,111,114,109,0,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,114,51,100,0,0,0,0,0,80,67,83,95,84,67,95,49,57,52,56,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,0,0,0,0,0,0,99,98,0,0,0,0,0,0,115,104,111,119,115,112,101,99,116,114,117,109,0,0,0,0,115,112,101,99,105,102,105,101,100,32,102,114,97,109,101,32,116,121,112,101,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,109,97,120,32,66,45,102,114,97,109,101,115,10,0,0,0,0,0,0,0,113,99,112,0,0,0,0,0,109,97,106,111,114,95,98,114,97,110,100,0,0,0,0,0,86,105,101,119,115,32,97,114,101,32,111,110,101,32,97,102,116,101,114,32,116,104,101,32,111,116,104,101,114,0,0,0,73,78,84,82,65,56,88,56,95,67,72,82,79,77,65,0,115,101,116,32,114,111,117,110,100,105,110,103,32,109,101,116,104,111,100,32,102,111,114,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2105504);
/* memory initializer */ allocate([116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,112,118,102,0,0,0,0,0,83,107,105,112,112,105,110,103,32,37,115,46,10,0,0,0,84,65,76,0,0,0,0,0,80,67,83,95,84,67,95,49,57,52,56,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,0,0,0,0,0,0,69,114,114,111,114,32,105,110,32,97,118,95,98,117,102,102,101,114,115,105,110,107,95,103,101,116,95,102,114,97,109,101,95,102,108,97,103,115,40,41,58,32,37,115,10,0,0,0,102,109,45,62,112,114,118,50,32,38,38,32,102,109,45,62,115,114,99,50,32,38,38,32,102,109,45,62,110,120,116,50,0,0,0,0,0,0,0,0,112,118,97,0,0,0,0,0,99,108,69,110,113,117,101,117,101,67,111,112,121,66,117,102,102,101,114,0,0,0,0,0,80,67,83,95,84,114,105,110,105,100,97,100,95,49,57,48,51,95,84,114,105,110,105,100,97,100,0,0,0,0,0,0,100,101,102,97,117,108,116,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,111,110,111,119,0,0,0,116,0,0,0,0,0,0,0,112,115,120,115,116,114,0,0,37,89,37,109,37,100,0,0,115,101,116,32,108,117,109,97,32,112,108,97,110,101,0,0,65,86,95,76,79,71,95,70,79,82,67,69,95,50,53,54,67,79,76,79,82,0,0,0,83,72,65,53,49,50,47,50,50,52,0,0,0,0,0,0,115,101,116,32,116,104,101,32,114,97,110,100,111,109,32,115,101,101,100,0,0,0,0,0,80,67,83,95,84,77,54,53,95,73,114,105,115,104,95,78,97,116,95,71,114,105,100,0,99,111,115,0,0,0,0,0,68,101,99,111,100,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,70,67,0,0,0,0,0,0,70,111,114,99,105,110,103,32,102,117,108,108,32,105,110,116,101,114,110,97,108,32,72,32,99,104,114,111,109,97,32,100,117,101,32,116,111,32,105,110,112,117,116,32,104,97,118,105,110,103,32,110,111,110,32,115,117,98,115,97,109,112,108,101,100,32,99,104,114,111,109,97,10,0,0,0,0,0,0,0,102,105,114,115,116,76,117,109,83,114,99,89,32,62,61,32,108,97,115,116,73,110,76,117,109,66,117,102,32,45,32,118,76,117,109,66,117,102,83,105,122,101,32,43,32,49,0,0,86,66,86,32,98,117,102,102,101,114,32,40,37,108,108,100,41,32,62,32,108,101,118,101,108,32,108,105,109,105,116,32,40,37,100,41,10,0,0,0,119,105,100,116,104,0,0,0,110,101,97,114,101,115,116,32,110,101,105,103,104,98,111,114,0,0,0,0,0,0,0,0,112,109,112,0,0,0,0,0,105,99,104,0,0,0,0,0,84,114,101,97,116,105,110,103,32,37,115,32,97,115,32,109,111,110,111,10,0,0,0,0,97,0,0,0,0,0,0,0,80,67,83,95,84,105,109,98,97,108,97,105,95,49,57,52,56,95,85,84,77,95,53,48,78,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,114,97,110,103,101,32,60,61,32,49,54,32,124,124,32,33,115,45,62,109,115,109,112,101,103,52,95,118,101,114,115,105,111,110,0,0,0,0,0,0,115,101,116,32,108,111,103,111,32,121,32,112,111,115,105,116,105,111,110,0,0,0,0,0,115,45,62,97,118,99,116,120,45,62,99,111,100,101,99,95,105,100,32,33,61,32,65,86,95,67,79,68,69,67,95,73,68,95,72,50,54,52,0,0,112,106,115,0,0,0,0,0,87,76,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,112,111,115,61,37,100,44,32,118,97,108,61,37,100,33,10,0,92,97,108,112,104,97,38,72,37,50,88,38,37,49,91,92,125,93,37,110,0,0,0,0,92,37,99,0,0,0,0,0,115,97,109,112,108,101,32,99,111,117,110,116,32,109,105,115,109,97,116,99,104,58,32,37,117,32,33,61,32,37,100,10,0,0,0,0,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,115,104,111,117,108,100,32,98,101,32,37,100,32,103,111,116,32,37,100,10,0,65,68,80,67,77,32,89,97,109,97,104,97,0,0,0,0,32,100,117,112,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,0,0,0,80,67,83,95,84,105,109,98,97,108,97,105,95,49,57,52,56,95,85,84,77,95,52,57,78,0,0,0,0,0,0,0,115,101,116,32,99,111,101,102,102,105,99,105,101,110,116,32,102,97,99,116,111,114,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,99,101,110,116,101,114,95,109,105,120,108,101,118,0,0,0,104,45,62,112,97,114,97,109,46,114,99,46,112,115,122,95,115,116,97,116,95,105,110,0,99,101,110,116,101,114,95,109,105,120,108,101,118,0,0,0,97,108,116,101,114,110,97,116,101,32,98,105,116,115,116,114,101,97,109,32,115,121,110,116,97,120,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,114,101,100,117,99,101,100,32,115,97,109,112,108,101,114,97,116,101,115,46,32,119,114,105,116,105,110,103,32,111,102,32,101,120,116,101,110,100,101,100,32,98,105,116,115,116,114,101,97,109,32,105,110,102,111,114,109,97,116,105,111,110,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,0,0,0,80,114,101,102,101,114,114,101,100,32,83,116,101,114,101,111,32,68,111,119,110,109,105,120,32,77,111,100,101,0,0,0,84,111,111,32,109,97,110,121,32,98,105,116,115,32,112,101,114,32,102,114,97,109,101,32,114,101,113,117,101,115,116,101,100,10,0,0,0,0,0,0,121,117,118,97,52,50,50,112,57,108,101,0,0,0,0,0,76,105,109,101,71,114,101,101,110,0,0,0,0,0,0,0,97,108,108,0,0,0,0,0,78,111,116,32,101,118,97,108,117,97,116,105,110,103,32,97,32,102,117,114,116,104,101,114,32,112,114,111,103,114,97,109,95,99,111,110,102,105,103,95,101,108,101,109,101,110,116,32,97,115,32,116,104,105,115,32,99,111,110,115,116,114,117,99,116,32,105,115,32,100,117,98,105,111,117,115,32,97,116,32,98,101,115,116,46,10,0,0,73,110,118,97,108,105,100,32,99,111,100,101,99,32,105,100,32,37,100,46,10,0,0,0,116,114,105,97,110,103,117,108,97,114,95,104,112,0,0,0,108,111,115,116,32,99,32,102,114,97,109,101,32,37,100,10,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,32,105,115,32,116,111,111,32,108,111,119,46,32,101,115,116,105,109,97,116,101,100,32,109,105,110,105,109,117,109,32,105,115,32,37,100,32,107,98,112,115,10,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,120,111,102,102,115,101,116,32,37,100,0,0,0,0,0,0,123,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,114,111,112,45,114,101,99,116,32,37,117,44,37,117,44,37,117,44,37,117,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,99,117,114,118,101,115,46,99,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,56,0,0,0,73,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,32,40,115,104,111,117,108,100,32,98,101,32,52,54,41,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,119,109,97,112,114,111,100,101,99,46,99,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,112,97,100,100,105,110,103,32,98,105,116,115,32,105,110,32,114,97,119,32,80,67,77,32,116,105,108,101,10,0,105,62,61,48,0,0,0,0,80,67,83,95,84,105,109,98,97,108,97,105,95,49,57,52,56,95,66,111,114,110,101,111,0,0,0,0,0,0,0,0,112,114,101,118,95,98,108,111,99,107,95,108,101,110,95,98,105,116,115,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,71,67,83,95,67,97,109,97,99,117,112,97,0,0,0,0,60,98,62,0,0,0,0,0,105,110,118,97,108,105,100,32,84,73,70,70,32,104,101,97,100,101,114,32,105,110,32,69,120,105,102,32,100,97,116,97,10,0,0,0,0,0,0,0,106,111,105,110,116,0,0,0,114,101,115,101,116,95,99,111,117,110,116,0,0,0,0,0,112,52,120,52,0,0,0,0,66,108,111,99,107,32,115,105,122,101,32,37,105,32,105,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,99,98,112,48,32,99,104,117,110,107,32,116,111,111,32,108,97,114,103,101,32,40,37,117,32,98,121,116,101,115,41,10,0,0,0,0,0,0,0,0,82,101,115,101,114,118,101,100,32,98,105,116,32,115,104,111,117,108,100,32,98,101,32,122,101,114,111,10,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,116,105,116,105,111,110,115,10,0,0,0,0,0,101,112,122,115,0,0,0,0,85,115,101,32,97,108,116,101,114,110,97,116,105,118,101,32,105,110,116,101,114,32,86,76,67,46,0,0,0,0,0,0,107,101,121,0,0,0,0,0,77,80,69,71,52,32,86,105,100,101,111,32,68,101,99,111,100,101,114,0,0,0,0,0,98,111,111,107,45,62,100,105,109,101,110,115,105,111,110,115,0,0,0,0,0,0,0,0,109,106,112,101,103,58,32,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,69,88,73,70,32,100,97,116,97,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,100,101,98,111,111,107,32,105,110,32,118,111,114,98,105,115,95,102,108,111,111,114,95,100,101,99,111,100,101,46,10,0,0,0,0,0,0,0,79,118,101,114,114,105,100,101,32,116,104,101,32,120,50,54,52,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,117,115,105,110,103,32,97,32,58,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,107,101,121,61,118,97,108,117,101,32,112,97,114,97,109,101,116,101,114,115,0,0,0,0,0,0,0,0,97,114,110,114,45,115,116,114,101,110,103,116,104,0,0,0,37,100,32,109,111,100,101,115,32,40,101,105,116,104,101,114,32,97,32,102,97,108,115,101,32,112,111,115,105,116,105,118,101,32,111,114,32,97,32,115,97,109,112,108,101,32,102,114,111,109,32,97,110,32,117,110,107,110,111,119,110,32,101,110,99,111,100,101,114,41,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,108,111,99,107,32,116,121,112,101,32,48,120,37,48,56,88,10,0,0,108,105,98,97,118,99,111,100,101,99,47,118,109,100,97,118,46,99,0,0,0,0,0,0,104,0,0,0,0,0,0,0,84,69,77,80,0,0,0,0,112,105,99,116,95,116,121,112,101,58,32,37,99,10,0,0,79,108,100,32,87,77,86,51,32,118,101,114,115,105,111,110,32,100,101,116,101,99,116,101,100,44,32,115,111,109,101,32,102,114,97,109,101,115,32,109,97,121,32,98,101,32,100,101,99,111,100,101,100,32,105,110,99,111,114,114,101,99,116,108,121,10,0,0,0,0,0,0,109,115,118,105,100,101,111,49,0,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,80,114,111,103,114,101,115,115,105,118,101,32,82,111,99,107,0,0,0,0,0,0,0,0,52,58,50,58,48,32,118,105,100,101,111,32,114,101,113,117,105,114,101,115,32,101,118,101,110,32,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,46,10,0,0,0,0,98,116,55,48,57,0,0,0,80,108,97,110,101,32,104,97,115,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,115,121,109,98,111,108,32,121,101,116,32,97,32,115,108,105,99,101,32,104,97,115,32,97,32,108,101,110,103,116,104,32,111,102,32,122,101,114,111,46,10,0,0,0,0,0,0,0,44,32,37,100,44,32,37,100,47,37,100,0,0,0,0,0,80,67,83,95,84,97,110,97,110,97,114,105,118,101,95,85,84,77,95,51,57,83,0,0,48,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,32,116,111,111,32,108,97,114,103,101,10,0,0,73,110,118,97,108,105,100,32,115,108,105,99,101,32,115,105,122,101,32,40,37,100,47,37,100,41,10,0,0,0,0,0,49,46,50,46,53,0,0,0,115,101,116,32,116,104,101,32,97,108,112,104,97,32,103,97,105,110,32,102,111,114,32,116,104,101,32,114,101,100,32,99,104,97,110,110,101,108,0,0,110,111,116,32,101,110,111,117,103,104,32,115,112,97,99,101,32,102,111,114,32,108,101,110,32,108,101,102,116,10,0,0,105,110,118,97,108,105,100,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,40,37,100,41,10,0,0,67,111,109,112,114,101,115,115,105,110,103,32,102,97,105,108,101,100,10,0,0,0,0,0,115,101,116,32,114,101,100,32,109,105,100,116,111,110,101,115,0,0,0,0,0,0,0,0,80,67,83,95,84,97,110,97,110,97,114,105,118,101,95,85,84,77,95,51,56,83,0,0,67,97,110,110,111,116,32,114,101,97,100,32,102,105,108,101,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,108,112,0,0,0,0,0,0,50,0,0,0,0,0,0,0,71,101,111,103,65,110,103,117,108,97,114,85,110,105,116,115,71,101,111,75,101,121,0,0,10,0,0,0,0,0,0,0,114,112,115,32,37,100,32,105,110,118,97,108,105,100,10,0,107,101,101,112,95,97,115,115,95,109,97,114,107,117,112,0,82,97,110,32,111,117,102,32,111,102,32,100,97,116,97,32,98,101,102,111,114,101,32,101,110,100,45,111,102,45,105,109,97,103,101,10,0,0,0,0,117,110,100,101,114,114,101,97,100,10,0,0,0,0,0,0,119,101,105,114,100,32,112,114,101,100,105,99,116,105,111,110,10,0,0,0,0,0,0,0,117,115,101,108,101,115,115,32,99,111,108,111,114,109,97,112,32,102,111,117,110,100,32,111,114,32,102,105,108,101,32,105,115,32,99,111,114,114,117,112,116,101,100,44,32,116,114,121,105,110,103,32,116,111,32,114,101,99,111,118,101,114,10,0,60,47,37,99,37,115,62,0,92,78,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,83,111,110,105,99,32,118,101,114,115,105,111,110,44,32,112,108,101,97,115,101,32,114,101,112,111,114,116,10,0,0,0,0,0,0,0,99,111,101,102,95,115,117,109,32,60,32,48,120,55,102,102,102,102,102,102,102,0,0,0,69,114,114,111,114,32,115,45,62,109,97,120,95,114,101,102,95,102,114,97,109,101,115,32,105,115,32,37,100,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,67,97,110,110,111,116,32,98,117,105,108,100,32,86,76,67,32,116,97,98,108,101,10,0,109,105,115,115,105,110,103,32,115,104,111,114,116,101,110,32,109,97,103,105,99,32,39,97,106,107,103,39,10,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,80,67,83,95,84,97,110,97,110,97,114,105,118,101,95,76,97,98,111,114,100,101,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,32,102,111,114,32,102,114,97,109,101,10,0,0,0,0,123,92,105,49,125,37,115,123,92,105,48,125,92,78,0,0,83,108,105,99,101,32,105,110,100,105,99,97,116,101,115,32,77,66,32,111,102,102,115,101,116,32,37,100,44,32,103,111,116,32,37,100,10,0,0,0,82,101,97,108,86,105,100,101,111,32,50,46,48,0,0,0,115,101,116,32,109,101,116,97,100,97,116,97,32,105,110,102,111,114,109,97,116,105,111,110,32,111,102,32,111,117,116,102,105,108,101,32,102,114,111,109,32,105,110,102,105,108,101,0,78,0,0,0,0,0,0,0,83,108,105,99,101,32,116,121,112,101,32,109,105,115,109,97,116,99,104,10,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,116,105,109,101,115,116,97,109,112,32,111,102,102,115,101,116,0,0,0,0,0,86,105,100,101,111,32,111,112,116,105,111,110,115,58,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,109,99,86,97,114,0,0,0,76,83,68,58,0,0,0,0,116,111,111,32,109,97,110,121,32,112,97,99,107,101,116,32,98,121,116,101,115,0,0,0,67,108,97,105,109,101,100,32,98,105,116,114,97,116,101,32,97,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,109,105,115,109,97,116,99,104,46,10,0,0,0,0,0,0,110,111,0,0,0,0,0,0,117,110,107,110,111,119,110,32,112,114,111,102,105,108,101,32,37,100,44,32,117,115,101,32,91,48,32,45,32,97,112,99,111,44,32,49,32,45,32,97,112,99,115,44,32,50,32,45,32,97,112,99,110,32,40,100,101,102,97,117,108,116,41,44,32,51,32,45,32,97,112,99,104,93,10,0,0,0,0,0,115,101,116,32,116,104,101,32,112,105,120,101,108,32,98,108,97,99,107,32,116,104,114,101,115,104,111,108,100,0,0,0,115,108,105,99,101,32,116,97,98,108,101,32,116,111,111,32,115,109,97,108,108,10,0,0,101,114,114,111,114,44,32,119,114,111,110,103,32,112,105,99,116,117,114,101,32,100,97,116,97,32,115,105,122,101,10,0,80,66,77,32,40,80,111,114,116,97,98,108,101,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,80,65,77,32,40,80,111,114,116,97,98,108,101,32,65,110,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,83,101,116,32,105,109,97,103,101,32,114,101,115,111,108,117,116,105,111,110,32,40,105,110,32,100,111,116,115,32,112,101,114,32,105,110,99,104,41,0,119,105,100,116,104,61,37,100,32,104,101,105,103,104,116,61,37,100,32,100,101,112,116,104,61,37,100,32,99,111,108,111,114,95,116,121,112,101,61,37,100,32,99,111,109,112,114,101,115,115,105,111,110,95,116,121,112,101,61,37,100,32,102,105,108,116,101,114,95,116,121,112,101,61,37,100,32,105,110,116,101,114,108,97,99,101,95,116,121,112,101,61,37,100,10,0,80,71,83,32,115,117,98,116,105,116,108,101,32,100,101,99,111,100,101,114,0,0,0,0,108,97,118,102,105,46,98,98,111,120,46,121,49,0,0,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,105,101,115,32,111,102,32,52,10,0,0,0,0,0,0,0,115,97,114,95,100,101,110,0,80,67,83,95,83,117,100,97,110,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,110,111,45,0,0,0,0,0,116,103,112,32,109,117,120,101,114,0,0,0,0,0,0,0,73,83,79,58,32,70,105,108,101,32,84,121,112,101,32,77,97,106,111,114,32,66,114,97,110,100,58,32,37,46,52,115,10,0,0,0,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,80,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,115,32,115,116,111,114,101,100,32,105,110,32,83,79,70,32,97,110,100,32,77,88,77,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,83,107,105,112,32,98,108,111,99,107,32,105,110,32,105,110,116,114,97,32,102,114,97,109,101,10,0,0,0,0,0,0,101,110,100,95,112,116,115,0,104,101,97,100,101,114,32,101,114,114,111,114,10,0,0,0,67,111,100,101,100,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,117,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,67,66,80,0,0,0,0,0,0,0,0,98,105,116,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,0,0,0,0,0,0,98,105,116,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,0,0,0,0,0,0,115,101,116,32,115,116,114,101,97,109,32,105,110,100,101,120,0,0,0,0,0,0,0,0,32,37,46,50,115,58,37,46,50,115,0,0,0,0,0,0,80,67,83,95,83,117,100,97,110,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,65,68,85,32,40,65,112,112,108,105,99,97,116,105,111,110,32,68,97,116,97,32,85,110,105,116,41,32,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,102,102,109,112,101,103,46,99,0,0,0,0,0,0,0,0,65,68,85,32,40,65,112,112,108,105,99,97,116,105,111,110,32,68,97,116,97,32,85,110,105,116,41,32,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,97,108,116,101,114,110,97,116,101,95,115,99,97,110,0,0,109,97,114,107,101,114,32,109,105,115,115,105,110,103,32,97,102,116,101,114,32,102,105,114,115,116,32,80,32,112,97,114,116,105,116,105,111,110,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,103,111,112,95,116,105,109,101,99,111,100,101,0,0,0,0,77,97,105,110,0,0,0,0,78,58,37,108,108,100,32,80,84,83,58,37,115,32,84,58,37,102,32,80,79,83,58,37,115,0,0,0,0,0,0,0,73,83,58,32,37,100,44,32,77,83,83,58,32,37,100,44,32,84,71,58,32,37,100,44,32,76,70,76,58,32,37,100,44,32,98,97,110,100,115,58,32,37,100,10,0,0,0,0,80,97,114,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,46,10,0,0,0,115,111,102,48,58,32,112,105,99,116,117,114,101,58,32,37,100,120,37,100,10,0,0,0,100,104,116,32,111,102,102,115,58,32,48,120,37,120,10,0,123,92,102,110,125,0,0,0,77,105,115,109,97,116,99,104,101,100,32,39,91,39,32,102,111,117,110,100,32,105,110,32,116,104,101,32,102,111,108,108,111,119,105,110,103,58,32,34,37,115,34,46,10,0,0,0,108,111,115,115,121,58,37,105,44,32,118,101,114,115,105,111,110,58,37,105,44,32,109,111,100,101,58,32,37,105,10,0,80,67,83,95,83,99,104,119,97,114,122,101,99,107,95,85,84,77,95,51,51,83,0,0,112,114,111,102,105,108,101,0,67,81,32,108,101,118,101,108,32,109,117,115,116,32,98,101,32,98,101,116,119,101,101,110,32,109,105,110,105,109,117,109,32,97,110,100,32,109,97,120,105,109,117,109,32,113,117,97,110,116,105,122,101,114,32,118,97,108,117,101,32,40,37,100,45,37,100,41,10,0,0,0,100,105,109,101,110,115,105,111,110,32,99,104,97,110,103,101,33,32,37,100,120,37,100,32,45,62,32,37,100,120,37,100,10,0,0,0,0,0,0,0,68,101,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,66,85,71,33,32,85,110,107,110,111,119,110,32,99,111,100,101,99,32,105,110,32,102,114,97,109,101,32,100,101,99,111,100,101,114,32,99,111,109,112,114,101,115,115,105,111,110,32,115,119,105,116,99,104,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,114,111,98,97,98,105,108,105,116,121,32,101,110,99,111,117,110,116,101,114,101,100,46,10,0,0,0,0,0,0,0,75,77,86,67,32,115,117,112,112,111,114,116,115,32,102,114,97,109,101,115,32,60,61,32,51,50,48,120,50,48,48,10,0,0,0,0,0,0,0,0,115,45,62,114,111,111,116,46,110,101,120,116,0,0,0,0,83,101,103,109,101,110,116,97,116,105,111,110,32,115,121,109,98,111,108,32,118,97,108,117,101,32,105,110,99,111,114,114,101,99,116,10,0,0,0,0,123,92,97,110,50,125,0,0,97,102,116,101,114,32,116,105,101,114,50,10,0,0,0,0,73,110,118,97,108,105,100,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,116,105,109,101,98,97,115,101,46,10,0,0,69,109,112,116,121,32,98,97,110,100,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,0,32,76,79,79,80,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,57,10,0,104,50,54,51,105,0,0,0,73,110,118,97,108,105,100,32,71,79,80,32,104,101,97,100,101,114,44,32,115,107,105,112,112,105,110,103,32,102,114,97,109,101,115,46,10,0,0,0,84,114,97,110,115,102,111,114,109,32,37,100,0,0,0,0,77,111,116,105,111,110,32,118,101,99,116,111,114,115,32,112,111,105,110,116,32,111,117,116,32,111,102,32,116,104,101,32,102,114,97,109,101,46,10,0,66,105,116,32,97,108,108,111,99,97,116,105,111,110,115,32,102,97,105,108,101,100,10,0,110,111,116,32,101,110,111,117,103,104,32,101,120,116,114,97,100,97,116,97,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,83,97,112,112,101,114,95,72,105,108,108,95,85,84,77,95,50,49,83,0,108,105,98,97,118,99,111,100,101,99,47,104,117,102,102,121,117,118,100,101,99,46,99,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,68,101,99,111,100,105,110,103,32,83,80,83,10,0,0,0,100,101,102,97,117,108,116,0,102,54,52,98,101,0,0,0,37,48,50,120,0,0,0,0,114,105,103,104,116,95,108,101,102,116,0,0,0,0,0,0,97,118,95,98,117,102,102,101,114,95,103,101,116,95,114,101,102,95,99,111,117,110,116,40,104,45,62,114,101,102,95,108,105,115,116,91,108,105,115,116,93,91,105,110,100,101,120,93,46,102,46,98,117,102,91,48,93,41,32,62,32,48,0,0,116,111,111,32,109,97,110,121,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,32,37,100,10,0,0,0,65,86,67,45,112,97,114,115,101,114,58,32,110,97,108,32,108,101,110,103,116,104,32,115,105,122,101,32,105,110,118,97,108,105,100,10,0,0,0,0,103,114,97,121,32,99,104,114,111,109,97,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,72,46,50,54,51,32,47,32,72,46,50,54,51,45,49,57,57,54,44,32,72,46,50,54,51,43,32,47,32,72,46,50,54,51,45,49,57,57,56,32,47,32,72,46,50,54,51,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,116,121,112,101,32,105,110,100,101,120,32,37,100,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,103,105,102,102,108,97,103,115,0,0,0,0,0,0,0,0,112,116,115,0,0,0,0,0,97,118,99,116,120,45,62,115,97,109,112,108,101,95,114,97,116,101,32,62,32,48,0,0,112,111,115,116,102,105,108,116,101,114,32,111,110,47,111,102,102,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,0,67,104,97,110,103,101,32,102,105,101,108,100,32,111,114,100,101,114,0,0,0,0,0,0,80,67,83,95,83,97,112,112,101,114,95,72,105,108,108,95,85,84,77,95,50,48,83,0,112,105,120,101,108,95,99,111,117,110,116,100,111,119,110,32,60,32,48,32,40,37,100,41,10,0,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,115,104,111,117,108,100,32,98,101,32,48,45,57,44,32,110,111,116,32,37,100,10,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,100,101,102,108,97,116,101,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,105,110,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,117,110,100,101,114,114,101,97,100,58,32,37,100,32,111,114,105,103,32,115,105,122,101,58,32,37,100,10,0,0,0,0,115,101,116,32,97,108,108,32,111,117,116,112,117,116,32,102,114,97,109,101,115,32,114,101,97,100,45,111,110,108,121,0,98,108,111,99,107,105,110,103,32,115,116,114,97,116,101,103,121,32,99,104,97,110,103,101,32,100,101,116,101,99,116,101,100,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,0,0,101,120,116,114,97,100,97,116,97,32,99,111,110,116,97,105,110,115,32,37,100,32,98,121,116,101,115,32,116,111,111,32,109,97,110,121,46,10,0,0,102,115,45,62,115,108,105,99,101,95,99,111,100,105,110,103,95,109,111,100,101,32,61,61,32,48,0,0,0,0,0,0,98,121,116,101,115,116,114,101,97,109,32,101,110,100,32,109,105,115,109,97,116,99,104,105,110,103,32,98,121,32,37,100,10,0,0,0,0,0,0,0,76,97,121,101,114,32,37,115,46,37,115,32,109,97,116,99,104,101,100,10,0,0,0,0,113,117,101,117,101,58,37,100,32,45,62,32,102,114,97,109,101,32,116,105,109,101,58,37,102,10,0,0,0,0,0,0,114,111,111,109,95,116,121,112,101,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,111,108,111,114,32,60,32,52,0,0,0,0,0,0,0,37,100,120,37,100,0,0,0,73,110,118,97,108,105,100,32,99,108,117,116,32,100,101,112,116,104,32,48,120,37,120,33,10,0,0,0,0,0,0,0,80,97,99,107,105,110,103,32,116,111,32,51,50,98,105,116,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,0,99,104,97,110,110,101,108,115,32,104,97,118,101,32,100,105,102,102,101,114,105,110,103,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,10,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,98,105,116,32,100,101,112,116,104,32,109,105,115,109,97,116,99,104,101,115,32,37,100,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,113,117,97,110,116,10,0,0,68,83,87,49,0,0,0,0,78,111,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,115,112,101,99,105,102,105,101,100,46,32,84,104,101,32,101,110,99,111,100,101,114,32,119,105,108,108,32,103,117,101,115,115,32,116,104,101,32,108,97,121,111,117,116,44,32,98,117,116,32,105,116,32,109,105,103,104,116,32,98,101,32,105,110,99,111,114,114,101,99,116,46,10,0,0,0,0,0,88,57,54,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,97,116,32,37,100,32,98,105,116,115,10,0,78,101,99,101,115,115,97,114,121,32,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,33,10,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,53,83,0,0,105,110,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,0,121,117,118,97,52,50,50,112,57,98,101,0,0,0,0,0,76,105,109,101,0,0,0,0,109,105,110,0,0,0,0,0,115,101,108,101,99,116,32,116,114,105,97,110,103,117,108,97,114,32,100,105,116,104,101,114,0,0,0,0,0,0,0,0,72,46,50,54,51,32,47,32,72,46,50,54,51,45,49,57,57,54,44,32,72,46,50,54,51,43,32,47,32,72,46,50,54,51,45,49,57,57,56,32,47,32,72,46,50,54,51,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,66,108,111,99,107,101,100,32,89,85,86,0,0,0,0,0,111,118,101,114,102,108,111,119,0,0,0,0,0,0,0,0,77,97,120,32,101,120,116,114,97,32,99,111,100,101,98,111,111,107,32,114,101,99,97,108,99,117,108,97,116,105,111,110,32,112,97,115,115,101,115,44,32,109,111,114,101,32,105,115,32,98,101,116,116,101,114,32,97,110,100,32,115,108,111,119,101,114,0,0,0,0,0,0,116,98,58,37,100,47,37,100,32,115,97,109,112,108,101,102,109,116,58,37,115,32,115,97,109,112,108,101,114,97,116,101,58,37,100,32,99,104,108,97,121,111,117,116,58,37,115,10,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,105,110,116,101,114,32,99,98,112,32,37,100,10,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,100,97,116,97,10,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,102,114,97,109,101,32,100,97,116,97,10,0,0,0,0,0,0,66,77,80,32,99,111,100,105,110,103,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,104,101,105,103,104,116,32,110,111,116,32,100,105,118,105,115,105,98,108,101,32,98,121,32,50,32,40,37,100,120,37,100,41,10,0,0,0,0,0,0,115,116,97,116,101,32,61,61,32,118,108,99,0,0,0,0,68,67,32,118,97,108,117,101,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,58,32,37,100,10,0,0,0,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,71,67,83,95,66,117,107,105,116,95,82,105,109,112,97,104,0,0,0,0,0,0,0,0,91,56,45,57,93,32,37,100,10,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,0,0,112,56,120,56,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,66,108,111,99,107,32,108,101,110,103,116,104,32,105,115,32,110,111,116,32,101,118,101,110,108,121,32,100,105,118,105,115,105,98,108,101,32,98,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,117,98,98,108,111,99,107,115,46,10,0,0,0,0,0,0,0,66,117,102,102,101,114,32,97,117,100,105,111,32,102,114,97,109,101,115,44,32,97,110,100,32,109,97,107,101,32,116,104,101,109,32,97,118,97,105,108,97,98,108,101,32,116,111,32,116,104,101,32,101,110,100,32,111,102,32,116,104,101,32,102,105,108,116,101,114,32,103,114,97,112,104,46,0,0,0,0,102,117,108,108,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,115,108,111,119,101,115,116,41,0,0,0,0,0,0,0,0,97,105,118,0,0,0,0,0,65,100,118,97,110,99,101,100,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,0,88,45,68,105,115,112,111,115,105,116,105,111,110,0,0,0,109,106,112,101,103,58,32,105,110,118,97,108,105,100,32,84,73,70,70,32,104,101,97,100,101,114,32,105,110,32,69,88,73,70,32,100,97,116,97,10,0,0,0,0,0,0,0,0,99,104,101,99,107,101,114,98,111,97,114,100,95,108,114,0,120,50,54,52,45,112,97,114,97,109,115,0,0,0,0,0,97,108,116,114,101,102,32,110,111,105,115,101,32,114,101,100,117,99,116,105,111,110,32,109,97,120,32,102,114,97,109,101,32,99,111,117,110,116,0,0,77,101,116,97,108,0,0,0,83,80,65,84,0,0,0,0,99,111,109,109,101,110,116,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,65,73,70,67,0,0,0,0,77,105,99,114,111,115,111,102,116,32,82,76,69,0,0,0,69,120,116,101,110,115,105,111,110,32,102,108,97,103,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,68,84,83,10,0,0,71,111,116,104,105,99,32,82,111,99,107,0,0,0,0,0,52,50,50,112,49,54,0,0,73,110,118,97,108,105,100,32,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,37,100,32,102,111,114,32,37,100,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,67,97,110,110,111,116,32,115,101,108,101,99,116,32,115,97,109,112,108,101,32,114,97,116,101,32,102,111,114,32,116,104,101,32,108,105,110,107,32,98,101,116,119,101,101,110,32,102,105,108,116,101,114,115,32,37,115,32,97,110,100,32,37,115,46,10,0,0,0,0,0,0,40,37,115,41,0,0,0,0,66,105,116,115,32,112,101,114,32,115,97,109,112,108,101,32,100,105,102,102,101,114,44,32,116,104,105,115,32,98,108,111,99,107,58,32,37,105,44,32,104,101,97,100,101,114,32,98,108,111,99,107,58,32,37,105,10,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,119,116,118,101,110,99,46,99,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,117,110,107,110,111,119,110,32,102,111,114,109,97,116,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,37,48,50,108,108,100,58,37,48,50,108,108,100,46,37,48,51,108,108,100,0,0,0,0,37,117,58,37,117,46,37,117,0,0,0,0,0,0,0,0,100,115,54,52,0,0,0,0,111,114,105,103,105,110,97,116,111,114,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,114,97,116,101,32,112,101,114,32,99,104,97,110,110,101,108,32,37,100,10,0,103,111,116,32,97,32,118,97,108,105,100,32,105,110,116,101,103,101,114,32,40,37,108,100,41,10,0,0,0,0,0,0,70,111,114,109,97,116,32,37,115,32,100,101,116,101,99,116,101,100,32,111,110,108,121,32,119,105,116,104,32,108,111,119,32,115,99,111,114,101,32,111,102,32,37,100,44,32,109,105,115,100,101,116,101,99,116,105,111,110,32,112,111,115,115,105,98,108,101,33,10,0,0,0,44,32,48,120,37,48,56,120,0,0,0,0,0,0,0,0,65,32,115,116,114,105,110,103,32,100,101,115,99,114,105,98,105,110,103,32,102,114,97,109,101,32,115,105,122,101,44,32,115,117,99,104,32,97,115,32,54,52,48,120,52,56,48,32,111,114,32,104,100,55,50,48,46,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,118,105,100,101,111,0,0,0,85,110,107,110,111,119,110,32,116,97,103,58,32,37,100,10,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,111,110,102,105,103,117,114,101,32,105,110,112,117,116,32,112,97,100,32,111,110,32,37,115,10,0,0,0,0,37,115,10,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,117,98,116,105,116,108,101,115,32,99,111,100,101,99,58,32,37,115,10,0,0,0,0,0,0,0,0,98,97,100,32,68,84,83,32,115,121,110,99,119,111,114,100,32,48,120,37,120,10,0,0,60,83,109,111,111,116,104,83,116,114,101,97,109,105,110,103,77,101,100,105,97,32,77,97,106,111,114,86,101,114,115,105,111,110,61,34,50,34,32,77,105,110,111,114,86,101,114,115,105,111,110,61,34,48,34,32,68,117,114,97,116,105,111,110,61,34,37,108,108,117,34,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,37,120,10,0,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,114,98,0,0,0,0,0,0,115,101,103,109,101,110,116,95,116,105,109,101,44,32,115,101,103,109,101,110,116,95,116,105,109,101,115,44,32,97,110,100,32,115,101,103,109,101,110,116,95,102,114,97,109,101,115,32,111,112,116,105,111,110,115,32,97,114,101,32,109,117,116,117,97,108,108,121,32,101,120,99,108,117,115,105,118,101,44,32,115,101,108,101,99,116,32,106,117,115,116,32,111,110,101,32,111,102,32,116,104,101,109,10,0,0,0,0,0,0,0,0,111,117,116,112,117,116,95,116,115,95,111,102,102,115,101,116,0,0,0,0,0,0,0,0,109,97,112,95,109,101,116,97,100,97,116,97,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,49,83,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,48,83,0,0,109,112,52,32,109,117,120,101,114,0,0,0,0,0,0,0,113,116,32,32,0,0,0,0,84,73,77,0,0,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,57,83,0,0,111,115,116,45,62,115,111,117,114,99,101,95,105,110,100,101,120,32,62,61,32,48,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,56,83,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,55,83,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,102,54,52,98,101,0,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,99,111,110,99,97,116,0,0,121,117,118,97,52,50,48,112,57,108,101,0,0,0,0,0,76,105,103,104,116,89,101,108,108,111,119,0,0,0,0,0,109,97,120,0,0,0,0,0,116,114,105,97,110,103,117,108,97,114,0,0,0,0,0,0,117,110,100,101,114,102,108,111,119,0,0,0,0,0,0,0,112,97,102], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2115744);
/* memory initializer */ allocate([104,101,105,103,104,116,32,110,111,116,32,100,105,118,105,115,105,98,108,101,32,98,121,32,52,32,40,37,100,120,37,100,41,10,0,0,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,71,67,83,95,66,111,103,111,116,97,0,0,0,0,0,0,105,56,120,56,0,0,0,0,112,99,109,95,117,50,52,98,101,0,0,0,0,0,0,0,102,117,108,108,0,0,0,0,85,115,101,32,117,110,108,105,109,105,116,101,100,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,46,0,0,0,83,105,109,112,108,101,32,83,116,117,100,105,111,32,80,114,111,102,105,108,101,0,0,0,99,98,114,0,0,0,0,0,97,114,110,114,45,109,97,120,102,114,97,109,101,115,0,0,99,0,0,0,0,0,0,0,109,115,114,108,101,0,0,0,65,118,97,110,116,103,97,114,100,101,0,0,0,0,0,0,91,48,120,37,120,93,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,80,67,83,95,83,65,68,54,57,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,102,105,108,116,101,114,0,0,45,37,45,49,55,115,32,32,37,115,10,0,0,0,0,0,70,105,108,101,32,99,111,110,116,97,105,110,115,32,110,111,32,102,114,97,109,101,115,32,63,63,63,10,0,0,0,0,112,111,105,110,116,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,98,121,116,101,115,32,116,111,32,98,101,32,119,114,105,116,116,101,110,32,97,115,32,112,97,100,100,105,110,103,32,105,110,32,97,32,109,101,116,97,100,97,116,97,32,104,101,97,100,101,114,0,0,0,0,0,0,0,80,67,83,95,82,68,95,78,101,116,104,101,114,108,97,110,100,115,95,78,101,119,0,0,102,105,108,101,46,115,116,114,101,97,109,46,99,104,97,110,110,101,108,91,58,115,121,110,99,102,105,108,101,46,115,121,110,99,115,116,114,101,97,109,93,0,0,0,0,0,0,0,115,101,116,32,99,111,110,116,97,105,110,101,114,32,102,111,114,109,97,116,32,117,115,101,100,32,102,111,114,32,116,104,101,32,115,101,103,109,101,110,116,115,0,0,0,0,0,0,80,67,83,95,82,68,95,78,101,116,104,101,114,108,97,110,100,115,95,79,108,100,0,0,49,50,55,46,48,46,48,46,49,0,0,0,0,0,0,0,112,115,112,32,109,117,120,101,114,0,0,0,0,0,0,0,104,97,110,100,108,101,114,95,110,97,109,101,0,0,0,0,84,111,110,101,45,115,101,116,32,34,37,46,42,115,34,32,110,111,116,32,100,101,102,105,110,101,100,10,0,0,0,0,84,73,77,69,0,0,0,0,80,67,83,95,81,97,116,97,114,95,78,97,116,105,111,110,97,108,95,71,114,105,100,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,117,108,116,105,115,116,114,101,97,109,32,111,112,117,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,82,84,80,10,0,0,37,108,108,100,32,44,32,37,108,108,100,32,59,32,37,108,108,100,0,0,0,0,0,0,84,104,101,32,65,117,100,105,111,32,83,116,114,101,97,109,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,51,50,78,0,0,0,114,109,0,0,0,0,0,0,73,71,78,82,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,51,49,78,0,0,0,101,110,100,0,0,0,0,0,115,101,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,109,111,100,101,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,51,48,78,0,0,0,100,97,116,97,0,0,0,0,114,97,119,32,77,74,80,69,71,32,118,105,100,101,111,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,57,78,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,39,114,101,100,49,39,32,97,116,111,109,10,0,0,0,0,0,97,117,100,105,111,32,100,97,116,97,32,99,111,114,114,117,112,116,105,111,110,10,0,0,121,117,118,97,52,50,48,112,57,98,101,0,0,0,0,0,76,105,103,104,116,83,116,101,101,108,66,108,117,101,0,0,100,101,102,97,117,108,116,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,115,101,108,101,99,116,32,114,101,99,116,97,110,103,117,108,97,114,32,100,105,116,104,101,114,0,0,0,0,0,0,0,65,86,70,111,114,109,97,116,67,111,110,116,101,120,116,0,67,80,66,32,37,115,58,32,37,46,48,108,102,32,98,105,116,115,32,105,110,32,97,32,37,46,48,108,102,45,98,105,116,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,119,105,100,116,104,32,110,111,116,32,100,105,118,105,115,105,98,108,101,32,98,121,32,50,32,40,37,100,120,37,100,41,10,0,0,0,0,0,0,0,44,32,109,97,120,46,32,37,100,32,107,98,47,115,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,56,78,0,0,0,71,67,83,95,66,101,114,110,95,49,56,57,56,0,0,0,105,52,120,52,0,0,0,0,122,101,114,111,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,40,102,97,115,116,101,115,116,41,0,0,0,0,0,0,0,0,117,109,118,0,0,0,0,0,65,100,118,97,110,99,101,100,32,83,99,97,108,97,98,108,101,32,84,101,120,116,117,114,101,32,80,114,111,102,105,108,101,0,0,0,0,0,0,0,115,51,50,98,101,0,0,0,95,74,80,83,74,80,83,95,10,0,0,0,0,0,0,0,118,98,114,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,116,111,32,108,111,111,107,32,97,104,101,97,100,32,102,111,114,32,97,108,116,101,114,110,97,116,101,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,32,115,101,108,101,99,116,105,111,110,0,0,32,73,68,82,0,0,0,0,111,109,97,0,0,0,0,0,87,101,115,116,119,111,111,100,32,83,116,117,100,105,111,115,32,86,81,65,32,40,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,100,32,65,110,105,109,97,116,105,111,110,41,32,118,105,100,101,111,0,66,108,117,101,103,114,97,115,115,0,0,0,0,0,0,0,32,32,32,32,83,116,114,101,97,109,32,35,37,100,58,37,100,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,55,78,0,0,0,73,110,112,117,116,32,108,105,110,107,32,37,115,32,112,97,114,97,109,101,116,101,114,115,32,40,115,105,122,101,32,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,32,100,111,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,111,117,116,112,117,116,32,108,105,110,107,32,37,115,32,112,97,114,97,109,101,116,101,114,115,32,40,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,10,0,0,0,115,51,50,98,101,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,54,78,0,0,0,109,117,120,101,114,0,0,0,37,115,37,115,0,0,0,0,102,102,108,97,103,115,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,116,97,103,32,37,100,32,102,111,114,32,119,114,105,116,101,10,0,0,0,0,0,109,101,116,97,100,97,116,97,95,104,101,97,100,101,114,95,112,97,100,100,105,110,103,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,53,78,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,37,100,33,10,0,0,109,97,112,32,97,110,32,97,117,100,105,111,32,99,104,97,110,110,101,108,32,102,114,111,109,32,111,110,101,32,115,116,114,101,97,109,32,116,111,32,97,110,111,116,104,101,114,0,109,97,105,110,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,67,72,65,80,84,69,82,37,48,51,100,0,0,0,0,0,111,109,97,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,52,78,0,0,0,116,103,50,32,109,117,120,101,114,0,0,0,0,0,0,0,114,97,116,101,0,0,0,0,111,112,117,115,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,79,86,80,56,48,0,0,0,111,103,103,32,112,97,103,101,44,32,117,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,10,0,0,68,105,115,112,111,115,105,116,105,111,110,0,0,0,0,0,45,37,46,50,115,45,37,46,50,115,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,51,78,0,0,0,78,111,32,109,111,114,101,32,105,110,112,117,116,115,32,116,111,32,114,101,97,100,32,102,114,111,109,44,32,102,105,110,105,115,104,105,110,103,46,10,0,0,0,0,0,0,0,0,110,111,32,115,121,110,99,112,111,105,110,116,32,97,116,32,98,97,99,107,112,116,114,32,112,111,115,10,0,0,0,0,77,69,84,65,68,65,84,65,95,66,76,79,67,75,95,80,73,67,84,85,82,69,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,50,78,0,0,0,109,117,45,108,97,119,0,0,128,116,104,101,111,114,97,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,49,78,0,0,0,83,112,101,101,120,32,32,32,0,0,0,0,0,0,0,0,98,97,100,32,115,105,122,101,58,32,37,105,10,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,102,105,115,104,101,97,100,0,78,111,32,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,102,111,117,110,100,10,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,50,48,78,0,0,0,79,112,117,115,72,101,97,100,0,0,0,0,0,0,0,0,45,45,37,115,13,10,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,57,78,0,0,0,52,52,49,48,48,0,0,0,103,98,114,112,49,54,108,101,0,0,0,0,0,0,0,0,76,105,103,104,116,83,108,97,116,101,71,114,97,121,0,0,37,100,37,42,49,91,58,47,93,37,100,37,99,0,0,0,114,101,99,116,97,110,103,117,108,97,114,0,0,0,0,0,114,97,116,101,99,111,110,116,114,111,108,95,101,110,100,58,32,115,116,97,116,115,32,102,105,108,101,32,99,111,117,108,100,32,110,111,116,32,98,101,32,119,114,105,116,116,101,110,32,116,111,10,0,0,0,0,105,110,118,97,108,105,100,32,67,83,80,32,40,111,110,108,121,32,73,52,50,48,47,89,86,49,50,47,78,86,49,50,47,73,52,50,50,47,89,86,49,54,47,78,86,49,54,47,73,52,52,52,47,89,86,50,52,47,66,71,82,47,66,71,82,65,47,82,71,66,32,115,117,112,112,111,114,116,101,100,41,10,0,0,0,0,0,0,109,112,101,103,116,115,114,97,119,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,44,32,37,100,32,107,98,47,115,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,56,78,0,0,0,71,67,83,95,66,101,114,109,117,100,97,95,49,57,53,55,0,0,0,0,0,0,0,0,1,118,105,100,101,111,0,0,97,108,108,0,0,0,0,0,122,101,114,111,0,0,0,0,72,46,50,54,51,112,32,101,110,99,111,100,101,114,0,0,115,118,99,100,0,0,0,0,65,100,118,97,110,99,101,100,32,67,111,114,101,32,80,114,111,102,105,108,101,0,0,0,83,105,103,110,97,108,32,72,82,68,32,105,110,102,111,114,109,97,116,105,111,110,32,40,114,101,113,117,105,114,101,115,32,118,98,118,45,98,117,102,115,105,122,101,59,32,99,98,114,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,46,109,112,52,41,0,0,108,97,103,45,105,110,45,102,114,97,109,101,115,0,0,0,32,102,105,120,0,0,0,0,127,70,76,65,67,0,0,0,84,104,101,32,105,110,112,117,116,32,105,110,100,101,120,32,102,105,108,101,110,97,109,101,32,105,115,32,116,111,111,32,115,104,111,114,116,32,116,111,32,103,117,101,115,115,32,116,104,101,32,97,115,115,111,99,105,97,116,101,100,32,46,83,85,66,32,102,105,108,101,10,0,0,0,0,0,0,0,0,119,115,95,118,113,97,0,0,67,101,108,116,105,99,0,0,83,116,114,101,97,109,32,104,101,97,100,101,114,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,55,78,0,0,0,66,66,67,68,0,0,0,0,84,73,84,50,0,0,0,0,117,115,101,116,111,99,0,0,67,69,76,84,32,32,32,32,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,54,78,0,0,0,100,101,109,117,120,101,114,0,73,110,118,97,108,105,100,32,115,101,103,109,101,110,116,32,102,105,108,101,110,97,109,101,32,116,101,109,112,108,97,116,101,32,39,37,115,39,10,0,101,110,97,98,108,101,32,102,108,117,115,104,105,110,103,32,111,102,32,116,104,101,32,73,47,79,32,99,111,110,116,101,120,116,32,97,102,116,101,114,32,101,97,99,104,32,112,97,99,107,101,116,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,53,78,0,0,0,110,117,116,45,62,104,101,97,100,101,114,95,108,101,110,91,48,93,32,61,61,32,48,0,109,97,112,95,99,104,97,110,110,101,108,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,52,78,0,0,0,105,112,111,100,32,109,117,120,101,114,0,0,0,0,0,0,86,101,114,115,105,111,110,32,37,100,0,0,0,0,0,0,51,71,80,32,40,51,71,80,80,32,102,105,108,101,32,102,111,114,109,97,116,41,0,0,84,68,65,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,51,78,0,0,0,79,117,116,112,117,116,32,102,105,108,101,32,105,115,32,101,109,112,116,121,44,32,110,111,116,104,105,110,103,32,119,97,115,32,101,110,99,111,100,101,100,32,40,99,104,101,99,107,32,45,115,115,32,47,32,45,116,32,47,32,45,102,114,97,109,101,115,32,112,97,114,97,109,101,116,101,114,115,32,105,102,32,117,115,101,100,41,10,0,0,0,0,0,0,0,0,111,103,103,0,0,0,0,0,109,111,111,118,32,97,116,111,109,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,89,97,109,97,104,97,32,83,77,65,70,32,115,116,101,114,101,111,32,105,115,32,101,120,112,101,114,105,109,101,110,116,97,108,44,32,97,100,100,32,39,45,115,116,114,105,99,116,32,37,100,39,32,105,102,32,121,111,117,32,119,97,110,116,32,116,111,32,117,115,101,32,105,116,46,10,0,0,0,0,123,68,69,70,65,85,76,84,125,123,125,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,50,78,0,0,0,123,37,100,125,123,37,99,0,37,48,50,120,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,49,78,0,0,0,97,117,100,105,111,47,120,45,109,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,111,103,103,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,115,105,122,101,32,98,117,116,32,110,111,32,100,97,116,97,32,105,110,32,104,101,97,100,101,114,115,116,114,105,112,10,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,49,48,78,0,0,0,110,117,118,0,0,0,0,0,111,110,108,121,32,116,105,103,104,116,108,121,32,112,97,99,107,101,100,32,80,67,77,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,77,117,120,105,110,103,32,77,80,69,71,45,52,32,65,79,84,32,37,100,32,105,110,32,76,65,84,77,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,67,76,79,67,75,80,65,85,83,69,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,57,78,0,0,0,0,103,98,114,112,49,54,98,101,0,0,0,0,0,0,0,0,76,105,103,104,116,83,107,121,66,108,117,101,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,105,109,97,103,101,32,115,105,122,101,10,0,0,0,0,0,0,0,0,115,101,116,32,100,105,116,104,101,114,32,109,101,116,104,111,100,0,0,0,0,0,0,0,59,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,119,105,100,116,104,32,120,32,104,101,105,103,104,116,32,40,37,100,120,37,100,41,10,0,44,32,112,97,115,115,32,50,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,56,78,0,0,0,0,71,67,83,95,66,101,108,103,101,95,49,57,53,48,0,0,110,111,110,101,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,115,101,116,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,109,101,116,104,111,100,0,0,0,0,109,115,109,112,101,103,52,118,50,32,101,110,99,111,100,101,114,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,67,111,100,105,110,103,32,80,114,111,102,105,108,101,0,108,111,111,112,0,0,0,0,88,70,82,77,32,37,100,10,0,0,0,0,0,0,0,0,110,97,108,45,104,114,100,0,69,110,97,98,108,101,32,117,115,101,32,111,102,32,97,108,116,101,114,110,97,116,101,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,32,40,50,45,112,97,115,115,32,111,110,108,121,41,0,0,66,0,0,0,0,0,0,0,67,105,110,101,112,97,107,0,82,101,118,105,118,97,108,0,109,110,103,0,0,0,0,0,37,99,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,55,78,0,0,0,0,97,114,116,105,115,116,0,0,110,117,116,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,54,78,0,0,0,0,101,110,99,111,100,101,114,0,49,0,0,0,0,0,0,0,84,69,78,67,0,0,0,0,80,78,71,32,105,110,32,105,99,111,32,114,101,113,117,105,114,101,115,32,112,105,120,101,108,32,102,111,114,109,97,116,32,116,111,32,98,101,32,114,103,98,97,10,0,0,0,0,99,111,114,114,101,99,116,32,115,105,110,103,108,101,32,116,105,109,101,115,116,97,109,112,32,111,118,101,114,102,108,111,119,115,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,53,78,0,0,0,0,37,115,10,0,0,0,0,0,105,110,118,97,108,105,100,32,101,108,105,115,105,111,110,32,104,101,97,100,101,114,10,0,91,45,93,105,110,112,117,116,95,102,105,108,101,95,105,100,91,58,115,116,114,101,97,109,95,115,112,101,99,105,102,105,101,114,93,91,44,115,121,110,99,95,102,105,108,101,95,105,100,91,58,115,116,114,101,97,109,95,115,112,101,99,105,102,105,101,114,93,93,0,0,0,69,114,114,111,114,32,119,104,101,110,32,108,111,97,100,105,110,103,32,102,105,114,115,116,32,115,101,103,109,101,110,116,32,39,37,115,39,10,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,52,78,0,0,0,0,9,60,105,100,62,37,115,60,47,105,100,62,10,0,0,0,105,115,109,118,32,109,117,120,101,114,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,109,100,104,100,63,10,0,108,105,98,97,118,102,111,114,109,97,116,47,103,120,102,101,110,99,46,99,0,0,0,0,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,111,114,32,105,110,118,97,108,105,100,32,109,97,112,32,112,114,101,97,109,98,108,101,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,95,100,101,108,97,121,0,0,0,84,68,65,84,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,51,50,0,0,0,0,0,0,0,118,105,100,101,111,58,37,49,46,48,102,107,66,32,97,117,100,105,111,58,37,49,46,48,102,107,66,32,115,117,98,116,105,116,108,101,58,37,49,46,48,102,32,100,97,116,97,58,37,49,46,48,102,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,58,37,49,46,48,102,107,66,32,109,117,120,105,110,103,32,111,118,101,114,104,101,97,100,32,37,102,37,37,10,0,0,0,0,0,0,71,73,70,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,51,49,0,0,0,0,0,0,0,97,118,101,99,116,111,114,115,99,111,112,101,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,102,108,118,101,110,99,46,99,0,0,0,0,65,117,100,105,111,32,99,111,100,101,99,32,40,37,120,41,0,0,0,0,0,0,0,0,102,108,97,99,32,109,117,120,101,114,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,51,48,0,0,0,0,0,0,0,69,120,112,101,99,116,101,100,32,99,104,97,112,116,101,114,32,101,110,100,32,116,105,109,101,115,116,97,109,112,44,32,102,111,117,110,100,32,37,115,46,10,0,0,0,0,0,0,117,110,107,110,111,119,110,32,49,83,78,104,32,104,101,97,100,101,114,105,100,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,57,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,100,118,32,112,99,109,32,102,114,97,109,101,115,10,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,56,0,0,0,0,0,0,0,76,105,110,101,32,37,100,58,32,105,110,118,97,108,105,100,32,100,117,114,97,116,105,111,110,32,39,37,115,39,10,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,103,98,114,112,49,48,108,101,0,0,0,0,0,0,0,0,76,105,103,104,116,83,101,97,71,114,101,101,110,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,118,105,100,101,111,32,114,97,116,101,10,0,0,0,0,0,0,0,0,100,105,116,104,101,114,95,109,101,116,104,111,100,0,0,0,44,37,100,44,37,100,44,37,100,44,37,100,44,37,100,32,0,0,0,0,0,0,0,0,102,114,109,97,97,108,97,99,0,0,0,0,0,0,0,0,83,101,108,101,99,116,32,98,111,116,104,32,99,104,97,110,110,101,108,115,0,0,0,0,117,115,105,110,103,32,83,65,82,61,37,100,47,37,100,10,0,0,0,0,0,0,0,0,44,32,112,97,115,115,32,49,0,0,0,0,0,0,0,0,115,107,105,112,112,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,58,32,37,88,10,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,55,0,0,0,0,0,0,0,71,67,83,95,66,101,105,106,105,110,103,95,49,57,53,52,0,0,0,0,0,0,0,0,112,97,114,116,105,116,105,111,110,115,0,0,0,0,0,0,112,99,109,95,117,49,54,108,101,0,0,0,0,0,0,0,109,101,95,109,101,116,104,111,100,0,0,0,0,0,0,0,109,115,109,112,101,103,52,118,51,32,101,110,99,111,100,101,114,0,0,0,0,0,0,0,67,111,100,101,32,83,99,97,108,97,98,108,101,32,80,114,111,102,105,108,101,0,0,0,115,116,97,116,115,0,0,0,97,117,116,111,45,97,108,116,45,114,101,102,0,0,0,0,65,114,116,119,111,114,120,32,68,97,116,97,32,70,111,114,109,97,116,0,0,0,0,0,84,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,109,111,114,101,32,116,104,97,110,32,50,53,54,32,97,117,100,105,111,32,116,114,97,99,107,115,32,40,37,100,41,10,0,0,0,0,0,0,0,0,110,117,116,0,0,0,0,0,99,105,110,101,112,97,107,0,76,97,116,105,110,0,0,0,69,82,82,79,82,58,32,121,117,118,52,109,112,101,103,32,99,97,110,32,111,110,108,121,32,104,97,110,100,108,101,32,121,117,118,52,52,52,112,44,32,121,117,118,52,50,50,112,44,32,121,117,118,52,50,48,112,44,32,121,117,118,52,49,49,112,32,97,110,100,32,103,114,97,121,56,32,112,105,120,101,108,32,102,111,114,109,97,116,115,46,32,65,110,100,32,117,115,105,110,103,32,39,115,116,114,105,99,116,32,45,49,39,32,97,108,115,111,32,121,117,118,52,52,52,112,57,44,32,121,117,118,52,50,50,112,57,44,32,121,117,118,52,50,48,112,57,44,32,121,117,118,52,52,52,112,49,48,44,32,121,117,118,52,50,50,112,49,48,44,32,121,117,118,52,50,48,112,49,48,44,32,121,117,118,52,52,52,112,49,50,44,32,121,117,118,52,50,50,112,49,50,44,32,121,117,118,52,50,48,112,49,50,44,32,121,117,118,52,52,52,112,49,52,44,32,121,117,118,52,50,50,112,49,52,44,32,121,117,118,52,50,48,112,49,52,44,32,121,117,118,52,52,52,112,49,54,44,32,121,117,118,52,50,50,112,49,54,44,32,121,117,118,52,50,48,112,49,54,32,97,110,100,32,103,114,97,121,49,54,32,112,105,120,101,108,32,102,111,114,109,97,116,115,46,32,85,115,101,32,45,112,105,120,95,102,109,116,32,116,111,32,115,101,108,101,99,116,32,111,110,101,46,10,0,0,32,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,54,0,0,0,0,0,0,0,110,117,108,108,0,0,0,0,71,117,101,115,115,101,100,32,67,104,97,110,110,101,108,32,76,97,121,111,117,116,32,102,111,114,32,32,73,110,112,117,116,32,83,116,114,101,97,109,32,35,37,100,46,37,100,32,58,32,37,115,10,0,0,0,110,115,118,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,112,116,105,111,110,115,32,115,116,114,105,110,103,32,37,115,10,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,53,0,0,0,0,0,0,0,100,101,99,111,100,101,114,0,114,101,115,101,110,100,95,104,101,97,100,101,114,115,0,0,112,98,45,62,115,101,101,107,97,98,108,101,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,52,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,116,97,103,58,32,37,117,0,0,0,0,99,111,114,114,101,99,116,95,116,115,95,111,118,101,114,102,108,111,119,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,69,114,114,111,114,32,110,117,116,45,62,104,101,97,100,101,114,95,108,101,110,91,105,93,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,115,116,114,101,97,109,32,109,97,112,112,105,110,103,0,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,51,0,0,0,0,0,0,0,79,118,101,114,114,105,100,101,32,109,97,106,111,114,32,98,114,97,110,100,0,0,0,0,102,102,32,97,115,102,32,98,97,100,32,104,101,97,100,101,114,32,37,120,32,32,97,116,58,37,108,108,100,10,0,0,70,111,117,110,100,32,100,117,112,108,105,99,97,116,101,100,32,77,79,79,86,32,65,116,111,109,46,32,83,107,105,112,112,101,100,32,105,116,10,0,115,117,98,102,112,115,0,0,73,110,118,97,108,105,100,32,65,80,69,32,116,97,103,32,107,101,121,32,39,37,115,39,46,10,0,0,0,0,0,0,110,105,115,116,115,112,104,101,114,101,0,0,0,0,0,0,70,105,108,101,32,116,114,117,110,99,97,116,101,100,10,0,84,89,69,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,50,0,0,0,0,0,0,0,110,99,0,0,0,0,0,0,10,0,0,0,0,0,0,0,109,120,103,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,49,0,0,0,0,0,0,0,98,114,105,103,104,116,110,101,115,115,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,50,48,0,0,0,0,0,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,104,105,115,116,111,103,114,97,109,95,37,100,100,98,58,32,37,108,108,100,10,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,57,0,0,0,0,0,0,0,115,109,112,116,101,49,55,48,109,0,0,0,0,0,0,0,102,108,111,97,116,0,0,0,109,120,102,0,0,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,56,0,0,0,0,0,0,0,37,108,102,37,110,32,42,37,110,0,0,0,0,0,0,0,103,98,114,112,49,48,98,101,0,0,0,0,0,0,0,0,76,105,103,104,116,83,97,108,109,111,110,0,0,0,0,0,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,84,104,105,115,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,39,124,39,32,116,111,32,115,101,112,97,114,97,116,101,32,116,104,101,32,109,97,112,112,105,110,103,115,46,10,0,0,0,115,101,116,32,100,105,116,104,101,114,32,115,99,97,108,101,0,0,0,0,0,0,0,0,119,58,37,100,44,37,100,44,37,100,0,0,0,0,0,0,98,111,116,104,0,0,0,0,99,97,110,110,111,116,32,99,114,101,97,116,101,32,118,97,108,105,100,32,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,10,0,0,0,0,0,0,0,0,44,32,0,0,0,0,0,0,112,111,105,110,116,115,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,55,0,0,0,0,0,0,0,71,67,83,95,66,101,100,117,97,114,97,109,0,0,0,0,97,110,97,108,121,115,101,0,83,104,111,119,32,97,108,108,32,102,114,97,109,101,115,32,98,101,102,111,114,101,32,116,104,101,32,102,105,114,115,116,32,107,101,121,102,114,97,109,101,0,0,0,0,0,0,0,119,109,118,49,32,101,110,99,111,100,101,114,0,0,0,0,37,100,37,110,0,0,0,0,65,100,118,97,110,99,101,100,32,82,101,97,108,32,84,105,109,101,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,0,0,0,0,0,0,0,67,79,76,82,32,37,100,10,0,0,0,0,0,0,0,0,76,105,109,105,116,32,116,104,101,32,115,105,122,101,32,111,102,32,101,97,99,104,32,115,108,105,99,101,32,105,110,32,98,121,116,101,115,0,0,0,81,117,97,108,105,116,121,47,83,112,101,101,100,32,114,97,116,105,111,32,109,111,100,105,102,105,101,114,0,0,0,0,70,0,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,118,105,100,101,111,32,40,82,80,90,65,41,0,0,66,101,98,111,98,0,0,0,87,97,114,110,105,110,103,58,32,103,101,110,101,114,97,116,105,110,103,32,110,111,110,32,115,116,97,110,100,97,114,100,32,89,85,86,32,115,116,114,101,97,109,46,32,77,106,112,101,103,116,111,111,108,115,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,32,32,32,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,54,0,0,0,0,0,0,0,98,97,110,100,114,101,106,101,99,116,0,0,0,0,0,0,115,116,97,114,116,95,104,101,114,101,32,60,61,32,115,116,111,112,95,104,101,114,101,32,38,38,32,102,114,97,103,45,62,112,111,115,105,116,105,111,110,91,49,93,32,60,61,32,115,116,97,114,116,95,104,101,114,101,0,0,0,0,0,0,116,50,0,0,0,0,0,0,105,110,99,111,109,112,97,116,105,98,108,101,32,118,101,114,115,105,111,110,0,0,0,0,82,77,83,32,112,101,97,107,32,100,66,58,32,37,102,10,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,53,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,37,46,54,103,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,115,101,103,109,101,110,116,32,39,37,115,39,10,0,0,0,0,116,111,111,32,109,97,110,121,32,108,101,110,103,116,104,32,111,114,32,100,105,115,116,97,110,99,101,32,115,121,109,98,111,108,115,0,0,0,0,0,112,0,0,0,0,0,0,0,105,99,104,0,0,0,0,0,100,101,108,97,121,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,98,121,116,101,115,32,116,111,32,115,107,105,112,32,98,101,102,111,114,101,32,114,101,97,100,105,110,103,32,104,101,97,100,101,114,32,97,110,100,32,102,114,97,109,101,115,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,52,0,0,0,0,0,0,0,116,97,114,103,101,116,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,105,110,32,116,104,101,32,97,117,100,105,111,32,115,116,114,101,97,109,0,0,0,0,69,114,114,111,114,32,110,117,116,45,62,104,101,97,100,101,114,95,99,111,117,110,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,105,110,112,117,116,115,46,0,0,0,0,0,0,0,109,97,112,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,113,117,101,117,101,46,104,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,58,32,37,115,46,10,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,51,0,0,0,0,0,0,0,98,114,97,110,100,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,102,97,100,101,45,111,117,116,0,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,84,89,69,82,0,0,0,0,65,116,32,108,101,97,115,116,32,111,110,101,32,100,101,108,97,121,32,62,48,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,50,0,0,0,0,0,0,0,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,0,102,109,116,58,37,115,32,99,108,58,37,115,32,45,62,32,102,109,116,58,37,115,32,99,108,58,37,115,10,0,0,0,99,0,0,0,0,0,0,0,33,105,115,95,99,111,109,112,111,117,110,100,32,61,61,32,40,99,109,45,62,114,101,102,101,114,101,110,99,101,95,109,111,100,101,32,61,61,32,83,73,78,71,76,69,95,82,69,70,69,82,69,78,67,69,41,0,0,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,49,0,0,0,0,0,0,0,114,103,98,116,101,115,116,115,114,99,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,112,97,114,116,105,116,105,111,110,44,32,122,101,114,111,95,99,111,117,110,116,115,46,112,97,114,116,105,116,105,111,110,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,112,97,114,116,105,116,105,111,110,41,41,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,49,48,0,0,0,0,0,0,0,109,120,102,0,0,0,0,0,50,53,0,0,0,0,0,0,104,58,37,100,32,109,97,120,95,119,58,37,100,10,0,0,109,118,105,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,57,0,0,0,0,0,0,0,0,37,100,32,37,99,10,0,0,98,116,52,55,48,0,0,0,33,40,108,102,109,45,62,105,110,116,95,52,120,52,95,117,118,32,38,32,108,102,109,45,62,108,101,102,116,95,117,118,91,84,88,95,49,54,88,49,54,93,41,0,0,0,0,0,115,101,110,100,95,102,114,97,109,101,95,110,111,115,112,97,116,105,97,108,0,0,0,0,97,108,108,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,56,0,0,0,0,0,0,0,0,112,116,115,0,0,0,0,0,103,98,114,112,57,108,101,0,76,105,103,104,116,80,105,110,107,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,37,115,10,0,0,0,0,0,0,0,0,100,105,116,104,101,114,95,115,99,97,108,101,0,0,0,0,102,108,97,103,115,61,48,120,37,88,0,0,0,0,0,0,105,110,58,37,100,32,111,117,116,58,37,100,32,116,121,112,101,58,37,99,32,100,117,114,58,37,108,108,100,32,99,112,98,100,117,114,58,37,108,108,100,32,113,58,37,46,50,102,32,97,113,58,37,46,50,102,32,116,101,120,58,37,100,32,109,118,58,37,100,32,109,105,115,99,58,37,100,32,105,109,98,58,37,100,32,112,109,98,58,37,100,32,115,109,98,58,37,100,32,100,58,37,99,32,114,101,102,58,0,0,0,0,83,101,108,101,99,116,32,83,117,98,47,82,105,103,104,116,32,99,104,97,110,110,101,108], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2125984);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,104,45,62,105,95,114,101,102,91,48,93,32,43,32,104,45,62,105,95,114,101,102,91,49,93,32,60,61,32,88,50,54,52,95,82,69,70,95,77,65,88,0,0,0,0,0,0,0,108,121,0,0,0,0,0,0,44,32,37,100,32,72,122,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,55,0,0,0,0,0,0,0,0,71,67,83,95,66,97,114,98,97,100,111,115,0,0,0,0,100,117,109,112,45,121,117,118,0,0,0,0,0,0,0,0,99,99,108,111,99,107,0,0,115,104,111,119,97,108,108,0,72,121,98,114,105,100,32,80,114,111,102,105,108,101,0,0,115,108,105,99,101,45,109,97,120,45,115,105,122,101,0,0,99,112,117,45,117,115,101,100,0,0,0,0,0,0,0,0,100,114,111,112,95,111,100,100,0,0,0,0,0,0,0,0,115,108,105,99,101,58,37,100,32,37,115,32,109,98,58,37,100,32,37,99,37,115,37,115,32,112,112,115,58,37,117,32,102,114,97,109,101,58,37,100,32,112,111,99,58,37,100,47,37,100,32,114,101,102,58,37,100,47,37,100,32,113,112,58,37,100,32,108,111,111,112,58,37,100,58,37,100,58,37,100,32,119,101,105,103,104,116,58,37,100,37,115,32,37,115,10,0,0,0,0,0,0,0,0,114,112,122,97,0,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,32,116,111,32,114,101,110,100,101,114,0,0,0,70,97,115,116,32,70,117,115,105,111,110,0,0,0,0,0,39,37,115,39,32,105,115,32,110,111,116,32,97,32,111,102,102,105,99,105,97,108,32,121,117,118,52,109,112,101,103,112,105,112,101,32,112,105,120,101,108,32,102,111,114,109,97,116,46,32,85,115,101,32,39,45,115,116,114,105,99,116,32,45,49,39,32,116,111,32,101,110,99,111,100,101,32,116,111,32,116,104,105,115,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,0,0,0,32,37,48,50,120,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,54,0,0,0,0,0,0,0,0,116,111,112,0,0,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,114,116,105,116,105,111,110,32,115,105,122,101,32,100,97,116,97,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,53,0,0,0,0,0,0,0,0,37,115,37,115,0,0,0,0,37,108,108,100,0,0,0,0,97,98,108,0,0,0,0,0,109,111,100,101,0,0,0,0,109,118,0,0,0,0,0,0,108,115,0,0,0,0,0,0,37,108,108,100,0,0,0,0,115,107,105,112,95,105,110,105,116,105,97,108,95,98,121,116,101,115,0,0,0,0,0,0,80,67,83,95,80,117,108,107,111,118,111,95,71,97,117,115,115,95,122,111,110,101,95,52,0,0,0,0,0,0,0,0,116,102,102,0,0,0,0,0,110,117,116,45,62,102,114,97,109,101,95,99,111,100,101,91,39,78,39,93,46,102,108,97,103,115,32,61,61,32,70,76,65,71,95,73,78,86,65,76,73,68,0,0,0,0,0,0,112,114,101,115,101,116,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,56,0,0,0,105,104,0,0,0,0,0,0,115,101,116,32,116,105,109,101,115,99,97,108,101,32,111,102,32,97,108,108,32,118,105,100,101,111,32,116,114,97,99,107,115,0,0,0,0,0,0,0,37,89,45,37,109,45,37,100,32,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,108,112,102,114,0,0,0,0,105,104,0,0,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,71,69,79,66,32,102,114,97,109,101,44,32,100,97,116,97,32,116,114,117,110,99,97,116,101,100,46,10,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,55,0,0,0,100,101,102,97,117,108,116,0,101,110,100,0,0,0,0,0,106,98,0,0,0,0,0,0,108,97,118,102,105,46,112,115,110,114,46,112,115,110,114,95,97,118,103,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,54,0,0,0,48,0,0,0,0,0,0,0,115,105,110,101,0,0,0,0,98,0,0,0,0,0,0,0,109,98,109,105,45,62,114,101,102,95,102,114,97,109,101,91,49,93,32,61,61,32,78,79,78,69,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,111,117,116,112,117,116,32,102,111,114,109,97,116,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,115,117,105,116,97,98,108,101,32,111,117,116,112,117,116,32,102,111,114,109,97,116,10,0,0,0,115,101,116,32,116,111,112,32,114,105,103,104,116,32,120,32,99,111,111,114,100,105,110,97,116,101,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,53,0,0,0,105,104,0,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,115,116,114,101,110,103,116,104,0,0,0,0,0,109,116,118,0,0,0,0,0,109,97,105,110,95,104,0,0,109,115,110,119,99,116,99,112,0,0,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,52,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,111,110,121,120,95,105,102,46,99,0,0,0,0,0,0,0,115,109,112,116,101,50,52,48,109,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,102,108,97,103,115,0,0,115,101,116,32,108,111,119,32,100,114,111,112,112,105,110,103,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,109,112,115,117,98,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,51,0,0,0,100,101,102,97,117,108,116,0,103,101,116,95,105,109,97,103,101,58,32,37,100,58,37,100,44,32,118,102,58,32,37,100,58,37,100,10,0,0,0,0,103,98,114,112,57,98,101,0,76,105,103,104,116,71,114,101,121,0,0,0,0,0,0,0,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,102,111,114,99,101,32,114,101,115,97,109,112,108,105,110,103,0,0,0,0,0,0,0,0,109,97,112,112,105,110,103,0,100,105,115,97,98,108,105,110,103,32,97,100,97,112,116,105,118,101,32,66,45,102,114,97,109,101,115,10,0,0,0,0,115,117,98,0,0,0,0,0,104,45,62,115,104,46,119,101,105,103,104,116,91,106,93,91,105,93,46,105,95,100,101,110,111,109,32,61,61,32,100,101,110,111,109,0,0,0,0,0,112,97,114,105,116,121,0,0,109,112,108,50,0,0,0,0,44,32,113,61,37,100,45,37,100,0,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,50,0,0,0,71,67,83,95,66,97,116,97,118,105,97,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,108,102,95,114,101,102,95,102,114,97,109,101,95,115,105,103,110,95,98,105,97,115,0,0,108,111,103,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,70,114,97,109,101,32,100,97,116,97,32,109,105,103,104,116,32,98,101,32,115,112,108,105,116,32,105,110,116,111,32,109,117,108,116,105,112,108,101,32,99,104,117,110,107,115,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,55,0,0,0,66,97,115,105,99,32,65,110,105,109,97,116,101,100,32,84,101,120,116,117,114,101,32,80,114,111,102,105,108,101,0,0,117,110,107,110,111,119,110,32,99,111,108,111,114,115,112,97,99,101,32,37,100,10,0,0,97,117,116,111,0,0,0,0,108,105,98,118,112,120,45,118,112,57,32,101,110,99,111,100,101,114,0,0,0,0,0,0,105,110,116,101,114,112,0,0,80,111,115,115,105,98,108,121,32,116,111,111,32,109,97,110,121,32,115,108,105,99,101,115,32,40,37,100,32,62,61,32,37,100,41,44,32,105,110,99,114,101,97,115,101,32,77,65,88,95,83,76,73,67,69,83,32,97,110,100,32,114,101,99,111,109,112,105,108,101,32,105,102,32,116,104,101,114,101,32,97,114,101,32,97,114,116,105,102,97,99,116,115,10,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,86,32,47,32,88,120,97,110,0,0,0,0,0,0,0,0,83,119,105,110,103,0,0,0,87,97,114,110,105,110,103,58,32,103,101,110,101,114,97,116,105,110,103,32,114,97,114,101,108,121,32,117,115,101,100,32,52,58,49,58,49,32,89,85,86,32,115,116,114,101,97,109,44,32,115,111,109,101,32,109,106,112,101,103,116,111,111,108,115,32,109,105,103,104,116,32,110,111,116,32,119,111,114,107,46,10,0,0,0,0,0,0,66,105,116,115,116,114,101,97,109,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,105,115,32,100,101,99,111,100,101,114,0,37,48,56,120,32,0,0,0,109,112,106,112,101,103,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,49,0,0,0,110,101,103,97,116,101,95,97,108,112,104,97,58,37,100,10,0,0,0,0,0,0,0,0,115,104,97,114,112,0,0,0,109,112,101,103,118,105,100,101,111,0,0,0,0,0,0,0,108,111,119,112,97,115,115,0,100,101,105,110,116,101,114,108,101,97,118,101,0,0,0,0,114,99,95,109,97,120,95,113,117,97,110,116,105,122,101,114,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,54,51,93,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,53,48,0,0,0,37,45,49,50,115,0,0,0,37,46,54,103,0,0,0,0,100,101,102,97,117,108,116,0,112,116,115,0,0,0,0,0,114,99,95,109,97,120,95,113,117,97,110,116,105,122,101,114,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,54,51,93,0,0,0,0,116,101,109,112,111,114,97,108,32,108,117,109,97,32,115,116,114,101,110,103,116,104,0,0,101,110,99,111,100,101,114,47,115,108,105,99,101,116,121,112,101,45,99,108,46,99,0,0,115,104,105,102,116,32,116,105,109,101,115,116,97,109,112,115,32,115,111,32,116,104,101,121,32,97,114,101,32,110,111,110,32,110,101,103,97,116,105,118,101,0,0,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,52,57,0,0,0,115,116,97,110,100,97,114,100,32,104,105,115,116,111,103,114,97,109,0,0,0,0,0,0,115,101,116,32,116,104,101,32,97,110,116,105,98,97,110,100,105,110,103,32,108,101,118,101,108,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,115,116,114,101,97,109,32,110,117,109,98,101,114,10,0,0,108,117,109,0,0,0,0,0,80,67,83,95,71,68,65,57,52,95,77,71,65,95,122,111,110,101,95,52,56,0,0,0,115,112,101,99,105,102,105,101,100,32,102,114,97,109,101,32,116,121,112,101,32,40,37,100,41,32,97,116,32,37,100,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,107,101,121,102,114,97,109,101,32,105,110,116,101,114,118,97,108,10,0,0,0,0,0,0,0,118,105,100,101,111,95,116,114,97,99,107,95,116,105,109,101,115,99,97,108,101,0,0,0,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,32,97,108,114,101,97,100,121,32,115,101,116,32,116,111,32,37,100,58,37,100,44,32,105,103,110,111,114,105,110,103,32,39,112,97,115,112,39,32,97,116,111,109,32,40,37,100,58,37,100,41,10,0,102,114,97,109,101,115,101,113,0,0,0,0,0,0,0,0,73,78,84,69,82,56,88,56,95,76,85,77,65,0,0,0,114,111,117,110,100,0,0,0,100,101,102,97,117,108,116,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,0,0,80,67,83,95,80,111,105,110,116,95,78,111,105,114,101,95,85,84,77,95,51,50,83,0,112,114,111,103,114,101,115,115,61,37,115,10,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,102,105,101,108,100,109,97,116,99,104,46,99,0,0,0,0,0,99,108,67,114,101,97,116,101,80,114,111,103,114,97,109,87,105,116,104,83,111,117,114,99,101,0,0,0,0,0,0,0,80,67,83,95,66,114,105,116,105,115,104,95,78,97,116,105,111,110,97,108,95,71,114,105,100,0,0,0,0,0,0,0,115,101,108,101,99,116,32,98,111,116,116,111,109,32,102,105,101,108,100,0,0,0,0,0,97,116,116,97,99,104,109,101,110,116,0,0,0,0,0,0,84,105,109,101,99,111,100,101,32,102,114,97,109,101,32,114,97,116,101,32,37,100,47,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,103,114,97,121,0,0,0,0,39,105,110,39,32,111,114,32,39,111,117,116,39,32,102,111,114,32,102,97,100,101,45,105,110,47,102,97,100,101,45,111,117,116,0,0,0,0,0,0,37,89,45,37,109,45,37,100,0,0,0,0,0,0,0,0,115,97,109,112,108,101,0,0,121,0,0,0,0,0,0,0,65,86,95,76,79,71,95,70,79,82,67,69,95,67,79,76,79,82,0,0,0,0,0,0,83,72,65,50,53,54,0,0,115,101,101,100,0,0,0,0,80,67,83,95,78,84,70,95,83,117,100,95,70,114,97,110,99,101,0,0,0,0,0,0,115,105,110,0,0,0,0,0,68,69,67,79,68,69,82,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,109,112,101,103,116,115,0,0,102,114,111,110,116,32,114,105,103,104,116,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,110,118,101,114,115,105,111,110,32,116,111,32,112,108,97,110,97,114,32,82,71,66,32,37,115,32,45,62,32,37,115,10,0,0,70,111,114,99,105,110,103,32,102,117,108,108,32,105,110,116,101,114,110,97,108,32,72,32,99,104,114,111,109,97,32,100,117,101,32,116,111,32,111,100,100,32,111,117,116,112,117,116,32,115,105,122,101,10,0,0,86,66,86,32,98,105,116,114,97,116,101,32,40,37,108,108,100,41,32,62,32,108,101,118,101,108,32,108,105,109,105,116,32,40,37,100,41,10,0,0,115,101,116,32,118,101,114,116,105,99,97,108,32,111,102,102,115,101,116,0,0,0,0,0,110,101,105,103,104,98,111,114,0,0,0,0,0,0,0,0,116,115,102,0,0,0,0,0,10,0,0,0,0,0,0,0,97,117,116,111,113,0,0,0,80,67,83,95,78,84,70,95,67,101,110,116,114,101,95,70,114,97,110,99,101,0,0,0,102,99,99,0,0,0,0,0,115,101,116,32,120,32,102,111,114,32,116,104,101,32,114,101,99,116,97,110,103,117,108,97,114,32,115,101,97,114,99,104,32,97,114,101,97,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,115,45,62,112,105,99,116,95,116,121,112,101,61,61,65,86,95,80,73,67,84,85,82,69,95,84,89,80,69,95,80,0,115,101,116,32,108,111,103,111,32,120,32,112,111,115,105,116,105,111,110,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,87,76,32,109,111,100,101,32,49,58,32,105,110,118,97,108,105,100,32,112,111,115,105,116,105,111,110,33,10,0,0,0,92,97,108,112,104,97,37,49,91,92,125,93,37,110,0,0,123,125,92,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,58,32,37,100,10,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,32,37,100,10,0,97,100,112,99,109,95,121,97,109,97,104,97,0,0,0,0,97,100,112,99,109,95,101,97,0,0,0,0,0,0,0,0,80,67,83,95,78,84,70,95,78,111,114,100,95,70,114,97,110,99,101,0,0,0,0,0,101,120,112,114,0,0,0,0,65,108,108,111,119,32,67,104,97,110,103,105,110,103,32,77,101,116,97,100,97,116,97,32,80,101,114,45,70,114,97,109,101,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,122,111,110,101,115,10,0,0,65,108,108,111,119,32,67,104,97,110,103,105,110,103,32,77,101,116,97,100,97,116,97,32,80,101,114,45,70,114,97,109,101,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,105,120,105,110,103,32,108,101,118,101,108,46,32,109,117,115,116,32,98,101,32,98,101,116,119,101,101,110,32,56,48,100,66,32,97,110,100,32,49,49,49,100,66,10,0,0,0,100,109,105,120,95,109,111,100,101,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,58,32,37,100,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,99,111,109,98,101,100,32,112,105,120,101,108,115,32,105,110,115,105,100,101,32,97,110,121,32,111,102,32,116,104,101,32,98,108,111,99,107,121,32,98,121,32,98,108,111,99,107,120,32,115,105,122,101,32,98,108,111,99,107,115,32,111,110,32,116,104,101,32,102,114,97,109,101,32,102,111,114,32,116,104,101,32,102,114,97,109,101,32,116,111,32,98,101,32,100,101,116,101,99,116,101,100,32,97,115,32,99,111,109,98,101,100,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,114,111,102,105,108,101,32,37,100,10,0,103,98,114,112,0,0,0,0,76,105,103,104,116,71,114,101,101,110,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,99,111,108,111,114,10,0,0,0,0,0,99,104,97,110,110,101,108,32,101,108,101,109,101,110,116,32,37,100,46,37,100,32,105,115,32,110,111,116,32,97,108,108,111,99,97,116,101,100,10,0,56,83,86,88,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,109,111,114,101,32,116,104,97,110,32,50,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,114,101,115,0,0,0,0,0,115,105,122,101,115,32,105,110,118,97,108,105,100,10,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,69,114,114,111,114,33,32,71,111,116,32,110,111,32,102,111,114,109,97,116,32,111,114,32,110,111,32,107,101,121,102,114,97,109,101,33,10,0,0,0,99,111,110,116,105,110,117,105,110,103,32,97,110,121,119,97,121,44,32,97,116,32,99,111,110,115,116,97,110,116,32,81,80,61,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,118,97,108,105,100,32,112,105,120,109,97,112,32,100,101,112,116,104,10,0,0,0,91,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,51,100,45,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,51,100,93,0,0,0,0,0,0,0,83,101,108,101,99,116,32,77,97,105,110,47,76,101,102,116,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,10,13,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,120,50,54,52,95,99,108,105,112,51,40,32,100,101,110,111,109,44,32,48,44,32,55,32,41,32,61,61,32,100,101,110,111,109,0,0,0,0,0,0,112,111,105,110,116,45,62,110,101,120,116,0,0,0,0,0,119,109,118,50,0,0,0,0,44,32,37,100,47,37,100,0,115,45,62,115,117,98,102,114,97,109,101,95,108,101,110,32,60,61,32,40,49,32,60,60,32,49,51,41,0,0,0,0,69,120,112,101,99,116,32,119,114,111,110,103,32,111,117,116,112,117,116,32,115,105,110,99,101,32,105,110,118,101,114,115,101,32,76,80,67,32,102,105,108,116,101,114,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,119,109,97,101,110,99,46,99,0,0,0,0,0,80,67,83,95,78,84,70,95,70,114,97,110,99,101,95,73,73,73,0,0,0,0,0,0,108,101,110,32,37,100,32,105,110,118,97,108,105,100,10,0,71,67,83,95,65,114,99,95,49,57,54,48,0,0,0,0,123,92,105,48,125,0,0,0,69,88,73,70,32,99,104,117,110,107,32,112,114,101,115,101,110,116,44,32,98,117,116,32,69,120,105,102,32,98,105,116,32,110,111,116,32,115,101,116,32,105,110,32,116,104,101,32,86,80,56,88,32,104,101,97,100,101,114,10,0,0,0,0,82,101,99,97,108,99,117,108,97,116,101,32,116,104,101,32,99,114,111,112,32,97,114,101,97,32,97,102,116,101,114,32,116,104,105,115,32,109,97,110,121,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,71,111,116,32,105,110,99,111,114,114,101,99,116,32,98,108,111,99,107,32,37,48,50,88,32,119,105,116,104,32,115,105,122,101,32,37,105,10,0,0,99,113,109,56,112,0,0,0,112,99,109,95,117,49,54,98,101,0,0,0,0,0,0,0,112,114,111,98,108,101,109,58,32,102,111,117,110,100,32,98,111,116,104,32,67,66,80,48,32,97,110,100,32,67,66,80,90,32,99,104,117,110,107,115,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,109,97,114,107,101,114,10,0,0,0,85,110,115,112,101,99,105,102,105,101,100,32,99,111,108,111,114,115,112,97,99,101,10,0,99,104,117,110,107,115,0,0,119,109,118,49,0,0,0,0,32,86,80,51,32,37,115,102,114,97,109,101,32,35,37,100,58,32,81,32,105,110,100,101,120,32,61,32,37,100,10,0,83,105,109,112,108,101,32,70,97,99,101,32,65,110,105,109,97,116,105,111,110,32,80,114,111,102,105,108,101,0,0,0,33,40,112,115,105,122,101,32,37,32,98,111,111,107,45,62,110,100,105,109,101,110,115,105,111,110,115,41,0,0,0,0,80,101,103,97,115,117,115,32,108,111,115,115,108,101,115,115,32,106,112,101,103,32,104,101,97,100,101,114,32,102,111,117,110,100,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,111,114,98,105,115,100,101,99,46,99,0,0,116,101,109,112,111,114,97,108,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,83,101,116,117,112,32,104,101,97,100,101,114,10,0,0,0,73,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,115,105,122,101,58,32,37,105,120,37,105,43,37,105,120,37,105,32,111,102,32,37,105,120,37,105,10,0,0,0,0,0,97,118,99,116,120,45,62,98,108,111,99,107,95,97,108,105,103,110,32,42,32,115,105,108,101,110,116,95,99,104,117,110,107,115,32,60,61,32,102,114,97,109,101,45,62,110,98,95,115,97,109,112,108,101,115,32,42,32,97,118,99,116,120,45,62,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,105,104,0,0,0,0,0,0,68,101,98,108,111,99,107,105,110,103,32,115,119,105,116,99,104,101,100,32,105,110,115,105,100,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,69,114,114,111,114,32,105,110,32,87,86,67,49,32,105,110,116,101,114,108,97,99,101,100,32,102,114,97,109,101,10,0,85,110,115,117,112,112,111,114,116,101,100,32,115,112,114,105,116,101,32,102,101,97,116,117,114,101,10,0,0,0,0,0,120,97,110,95,119,99,52,0,32,110,111,110,101,33,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,78,97,116,105,111,110,97,108,32,70,111,108,107,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,69,82,82,79,82,58,32,79,110,108,121,32,114,97,119,118,105,100,101,111,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,115,101,116,32,100,101,115,116,105,110,97,116,105,111,110,32,99,111,108,111,114,32,109,97,116,114,105,120,0,0,0,0,67,97,110,110,111,116,32,98,117,105,108,100,32,72,117,102,102,109,97,110,32,99,111,100,101,115,10,0,0,0,0,0,32,32,115,105,122,101,61,37,100,10,0,0,0,0,0,0,80,67,83,95,78,84,70,95,70,114,97,110,99,101,95,73,73,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,119,105,110,100,111,119,32,116,121,112,101,44,32,98,114,111,107,101,110,32,115,97,109,112,108,101,63,10,0,0,0,0,73,110,118,97,108,105,100,47,117,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,46,10,0,0,0,0,0,78,111,110,45,115,107,105,112,32,114,111,119,32,119,105,116,104,32,122,101,114,111,32,115,105,122,101,10,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,114,97,0,0,0,0,0,0,116,111,107,101,110,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,73,110,116,101,114,112,111,108,97,116,101,100,32,102,114,97,109,101,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,116,105,102,102,101,110,99,46,99,0,0,0,0,114,109,0,0,0,0,0,0,80,67,83,95,78,84,70,95,70,114,97,110,99,101,95,73,0,0,0,0,0,0,0,0,112,114,101,115,101,116,32,110,97,109,101,0,0,0,0,0,72,111,119,32,109,97,110,121,32,116,105,109,101,115,32,115,104,111,117,108,100,32,116,104,101,32,98,111,120,98,108,117,114,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,108,117,109,97,0,0,0,0,78,79,80,84,83,0,0,0,71,101,111,103,76,105,110,101,97,114,85,110,105,116,83,105,122,101,71,101,111,75,101,121,0,0,0,0,0,0,0,0,44,32,0,0,0,0,0,0,73,109,97,103,101,32,100,97,116,97,32,115,105,122,101,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,0,115,117,98,118,105,101,119,101,114,49,32,100,101,99,111,100,101,114,0,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,105,109,97,103,101,10,0,0,0,0,111,118,101,114,114,101,97,100,10,0,0,0,0,0,0,0,108,117,109,97,32,112,114,101,100,105,99,116,105,111,110,58,37,100,10,0,0,0,0,0,105,110,118,97,108,105,100,32,100,101,112,116,104,10,0,0,116,97,103,32,115,116,97,99,107,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,123,92,97,110,49,125,123,92,112,111,115,40,37,100,44,37,100,41,125,0,0,0,0,0,78,111,32,109,97,110,100,97,116,111,114,121,32,104,101,97,100,101,114,115,32,112,114,101,115,101,110,116,10,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,32,115,112,97,99,101,10,0,0,0,0,0,0,0,0,83,77,86,74,80,69,71,32,100,101,99,111,100,101,114,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,97,109,112,108,101,32,102,111,114,109,97,116,32,109,105,115,109,97,116,99,104,10,0,77,111,100,101,58,32,37,115,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,65,84,70,95,78,111,114,100,95,100,101,95,71,117,101,114,114,101,0,0,82,76,69,32,98,117,102,102,101,114,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,60,66,82,0,0,0,0,0,83,105,122,101,32,109,105,115,109,97,116,99,104,10,0,0,114,112,114,32,116,111,111,32,108,97,114,103,101,10,0,0,114,118,50,48,0,0,0,0,84,0,0,0,0,0,0,0,67,79,85,78,84,32,69,82,82,79,82,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,109,97,107,101,95,110,111,110,95,110,101,103,97,116,105,118,101,0,0,0,0,0,0,0,97,110,117,108,108,115,114,99,0,0,0,0,0,0,0,0,102,114,97,109,101,58,37,117,32,112,98,108,97,99,107,58,37,117,32,112,116,115,58,37,108,108,100,32,116,58,37,102,32,116,121,112,101,58,37,99,32,108,97,115,116,95,107,101,121,102,114,97,109,101,58,37,100,10,0,0,0,0,0,0,105,67,111,117,110,116,0,0,68,101,99,111,100,101,114,39,115,32,115,116,111,109,97,99,104,32,105,115,32,99,114,121,105,110,103,44,32,105,116,32,97,116,101,32,116,111,111,32,109,97,110,121,32,115,97,109,112,108,101,115,10,0,0,0,98,97,100,32,112,97,99,107,101,116,32,99,104,101,99,107,115,117,109,10,0,0,0,0,70,114,97,109,101,32,35,37,100,44,32,73,70,81,58,32,37,115,10,0,0,0,0,0,121,101,115,0,0,0,0,0,105,108,108,101,103,97,108,32,99,111,117,110,116,32,37,100,32,97,116,32,37,100,10,0,101,110,99,111,100,105,110,103,32,119,105,116,104,32,80,114,111,82,101,115,32,115,116,97,110,100,97,114,100,32,40,97,112,99,110,41,32,112,114,111,102,105,108,101,10,0,0,0,112,105,120,101,108,95,98,108,97,99,107,95,116,104,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,108,105,99,101,115,10,0,0,0,0,0,0,0,101,114,114,111,114,44,32,119,114,111,110,103,32,112,105,99,116,117,114,101,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,0,0,0,112,98,109,0,0,0,0,0,112,97,109,0,0,0,0,0,100,112,105,0,0,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,115,105,122,101,10,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,115,101,101,107,32,116,111,32,108,97,115,116,32,112,97,114,116,105,116,105,111,110,32,64,32,48,120,37,108,108,120,32,40,37,108,108,100,41,32,45,32,112,97,114,116,105,97,108,32,102,105,108,101,63,10,0,0,0,0,0,0,0,116,111,111,32,109,117,99,104,32,82,76,69,32,100,97,116,97,10,0,0,0,0,0,0,101,120,112,101,99,116,101,100,32,112,97,108,101,116,116,101,32,97,102,116,101,114,32,105,109,97,103,101,32,100,97,116,97,10,0,0,0,0,0,0,108,97,118,102,105,46,98,98,111,120,46,120,50,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,114,101,115,101,114,118,101,100,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,40,37,100,41,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,80,67,83,95,68,97,116,117,109,95,55,51,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,0,0,0,0,0,112,114,101,0,0,0,0,0,114,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,112,101,114,45,102,105,108,101,32,111,112,116,105,111,110,115,58,0,0,0,0,0,0,97,108,112,104,97,0,0,0,116,114,117,101,0,0,0,0,117,115,101,32,101,100,105,116,32,108,105,115,116,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,102,105,101,108,100,32,115,105,122,101,32,37,100,10,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,10,0,0,0,0,78,111,110,45,107,101,121,32,102,114,97,109,101,32,104,97,115,32,110,111,32,77,88,77,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,84,105,109,101,115,116,97,109,112,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,32,112,97,115,115,101,100,0,0,0,0,0,98,117,102,102,101,114,32,110,111,116,32,102,117,108,108,121,32,99,111,110,115,117,109,101,100,10,0,0,0,0,0,0,68,105,115,112,108,97,121,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,0,0,0,0,0,0,77,83,32,82,76,69,58,32,101,110,100,101,100,32,102,114,97,109,101,32,100,101,99,111,100,101,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,108,101,102,116,32,111,118,101,114,10,0,0,0,0,0,13,10,0,0,0,0,0,0,99,98,112,95,114,100,0,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,111,110,116,101,120,116,32,115,99,114,97,116,99,104,32,98,117,102,102,101,114,115,46,10,0,0,0,0,83,97,109,112,108,105,110,103,32,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,83,97,109,112,108,105,110,103,32,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,115,116,114,101,97,109,95,105,110,100,101,120,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,32,37,122,117,32,98,121,116,101,115,10,0,0,0,0,0,0,80,67,83,95,71,68,52,57,95,83,111,117,116,104,95,73,115,108,97,110,100,95,71,114,105,100,0,0,0,0,0,0,109,112,51,97,100,117,102,108,111,97,116,0,0,0,0,0,109,112,51,97,100,117,0,0,85,115,101,32,100,97,116,97,32,112,97,114,116,105,116,105,111,110,105,110,103,46,0,0,37,115,32,32,32,32,13,0,109,97,114,107,101,114,32,109,105,115,115,105,110,103,32,97,102,116,101,114,32,102,105,114,115,116,32,73,32,112,97,114,116,105,116,105,111,110,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,109,112,101,103,50,118,105,100,101,111,32,101,110,99,111,100,101,114,0,0,0,0,0,0,83,78,82,32,83,99,97,108,97,98,108,101,0,0,0,0,84,66,58,37,102,32,70,82,65,77,69,95,82,65,84,69,58,37,102,32,83,65,77,80,76,69,95,82,65,84,69,58,37,102,10,0,0,0,0,0,84,111,111,32,109,97,110,121,32,98,97,110,100,115,58,32,37,105,10,0,0,0,0,0,73,110,100,105,99,97,116,101,100,32,101,110,100,32,111,102,102,115,101,116,32,111,102,32,115,117,98,115,116,114,101,97,109,32,37,100,32,100,97,116,97,32,105,115,32,115,109,97,108,108,101,114,32,116,104,97,110,32,99,97,108,99,117,108,97,116,101,100,32,115,116,97,114,116,32,111,102,102,115,101,116,46,10,0,0,0,0,0,65,77,86,32,86,105,100,101,111,0,0,0,0,0,0,0,108,111,119,114,101,115,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,32,119,105,116,104,32,108,111,115,115,108,101,115,115,32,106,112,101,103,10,0,0,0,0,0,0,100,104,116,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,0,0,0,0,0,0,123,92,99,125,0,0,0,0,66,97,100,32,40,101,109,112,116,121,63,41,32,108,97,98,101,108,32,102,111,117,110,100,32,105,110,32,116,104,101,32,102,111,108,108,111,119,105,110,103,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,108,111,114,115,112,97,99,101,44,32,105,110,100,101,120,32,61,32,37,105,10,0,80,67,83,95,71,68,52,57,95,78,111,114,116,104,95,73,115,108,97,110,100,95,71,114,105,100,0,0,0,0,0,0,109,112,101,103,0,0,0,0,84,117,110,101,32,116,104,101,32,101,110,99,111,100,105,110,103,32,112,97,114,97,109,115,32,40,99,102,46,32,120,50,54,52,32,45,45,102,117,108,108,104,101,108,112,41,0,0,78,101,105,116,104,101,114,32,98,105,116,114,97,116,101,32,110,111,114,32,99,111,110,115,116,114,97,105,110,101,100,32,113,117,97,108,105,116,121,32,115,112,101,99,105,102,105,101,100,44,32,117,115,105,110,103,32,100,101,102,97,117,108,116,32,98,105,116,114,97,116,101,32,111,102,32,37,100,107,98,105,116,47,115,101,99,10,0,85,110,115,117,112,112,111,114,116,101,100,32,111,117,116,112,117,116,32,99,111,108,111,114,115,112,97,99,101,32,40,37,100,41,10,0,0,0,0,0,49,46,50,46,53,0,0,0,66,85,71,33,32,85,110,107,110,111,119,110,32,77,83,90,72,32,99,111,109,112,114,101,115,115,105,111,110,32,105,110,32,102,114,97,109,101,32,100,101,99,111,100,101,114,46,10,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,122,101,114,111,115,32,114,101,109,97,105,110,105,110,103,46,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,74,80,69,71,45,76,83,0,114,101,113,117,101,115,116,95,115,97,109,112,108,101,115,32,99,104,97,110,103,101,100,32,98,101,102,111,114,101,32,116,104,101,32,98,117,102,102,101,114,32,119,97,115,32,114,101,116,117,114,110,101,100,46,10,0,0,0,0,0,0,0,0,104,101,105,103,104,116,32,60,61,32,54,52,0,0,0,0,123,92,97,110,49,125,0,0,116,105,101,114,50,10,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,98,97,110,100,32,104,101,97,100,101,114,58,32,37,100,10,0,0,0,100,101,102,97,117,108,116,0,32,77,81,0,0,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,65,10,0,73,110,118,97,108,105,100,32,97,115,112,101,99,116,32,114,97,116,105,111,46,10,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,58,32,37,100,32,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,32,115,105,122,101,33,10,0,0,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,0,0,115,99,97,108,101,102,97,99,116,111,114,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,0,0,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,62,32,56,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,80,67,83,95,71,68,52,57,95,78,90,95,77,97,112,95,71,114,105,100,0,0,0,0,105,32,60,32,40,49,32,60,60,32,49,49,41,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,118,112,115,95,109,97,120,95,110,117,109,95,114,101,111,114,100,101,114,95,112,105,99,115,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,102,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,114,111,119,95,105,110,116,101,114,108,101,97,118,101,100,95,108,114,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,112,105,99,116,117,114,101,44,32,100,101,102,97,117,108,116,32,105,115,32,37,100,10,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,80,79,67,32,116,121,112,101,32,37,100,10,0,0,0,0,105,108,108,101,103,97,108,32,109,101,109,111,114,121,32,109,97,110,97,103,101,109,101,110,116,32,99,111,110,116,114,111,108,32,111,112,101,114,97,116,105,111,110,32,37,100,10,0,99,98,112,32,116,111,111,32,108,97,114,103,101,32,40,37,117,41,32,97,116,32,37,100,32,37,100,10,0,0,0,0,68,101,99,111,100,105,110,103,32,112,112,115,32,37,100,32,102,114,111,109,32,97,118,99,67,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,104,50,54,51,0,0,0,0,105,108,108,101,103,97,108,32,109,98,97,32,97,116,32,37,100,32,37,100,10,0,0,0,76,90,87,32,100,101,99,111,100,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,71,73,70,32,101,110,99,111,100,101,114,0,0,0,0,0,84,66,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,111,115,116,102,105,108,116,101,114,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,37,100,10,0,0,99,104,97,110,103,101,95,102,105,101,108,100,95,111,114,100,101,114,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,112,108,97,110,101,32,37,105,10,0,0,0,0,0,0,0,0,80,67,83,95,78,97,112,97,114,105,109,97,95,85,84,77,95,50,48,78,0,0,0,0,112,105,120,101,108,95,99,111,117,110,116,100,111,119,110,32,60,32,48,32,40,37,100,41,32,97,116,32,108,105,110,101,32,37,100,10,0,0,0,0,71,101,110,101,114,97,116,101,100,32,100,101,102,97,117,108,116,32,112,97,108,101,116,116,101,10,0,0,0,0,0,0,67,97,110,110,111,116,32,100,101,116,101,114,109,105,110,101,32,100,101,102,108,97,116,101,32,98,117,102,102,101,114,32,115,105,122,101,46,10,0,0,105,110,118,97,108,105,100,32,112,97,114,116,105,116,105,111,110,32,111,114,100,101,114,115,58,32,109,105,110,61,37,100], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2136224);
/* memory initializer */ allocate([32,109,97,120,61,37,100,10,0,0,0,0,0,0,0,0,98,116,55,48,57,0,0,0,111,118,101,114,114,101,97,100,58,32,37,100,10,0,0,0,114,111,0,0,0,0,0,0,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,32,99,104,97,110,103,101,32,100,101,116,101,99,116,101,100,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,0,0,0,0,101,120,116,114,97,100,97,116,97,32,78,85,76,76,32,111,114,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,115,108,105,99,101,32,100,97,116,97,46,10,0,98,121,116,101,115,32,60,32,40,49,32,60,60,32,50,52,41,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,80,97,114,97,109,101,116,101,114,115,32,102,111,114,32,105,110,112,117,116,32,108,105,110,107,32,37,115,32,40,115,105,122,101,32,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,32,100,111,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,111,117,116,112,117,116,32,108,105,110,107,32,112,97,114,97,109,101,116,101,114,115,32,40,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,10,0,0,77,105,120,105,110,103,32,76,101,118,101,108,0,0,0,0,83,108,105,99,101,32,115,105,122,101,115,32,109,105,115,109,97,116,99,104,58,32,103,111,116,32,37,100,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,0,0,0,0,85,110,107,110,111,119,110,32,111,112,99,111,100,101,32,37,100,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,105,122,101,58,0,0,0,68,86,66,83,117,98,32,101,114,114,111,114,58,32,108,105,110,101,32,111,118,101,114,102,108,111,119,10,0,0,0,0,68,101,115,99,114,105,112,116,111,114,32,37,100,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,100,110,120,104,100,101,110,99,46,99,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,105,100,32,37,100,10,0,0,0,0,0,110,117,109,95,114,101,102,115,32,111,102,32,51,10,0,0,80,67,83,95,78,97,104,114,119,97,110,95,49,57,54,55,95,85,84,77,95,52,48,78,0,0,0,0,0,0,0,0,84,68,76,84,0,0,0,0,117,115,101,100,95,97,98,105,116,115,32,33,61,32,49,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,88,67,104,32,101,120,116,101,110,115,105,111,110,10,0,0,0,68,101,99,111,100,101,100,32,100,97,116,97,32,101,120,99,101,101,100,101,100,32,108,105,110,101,115,105,122,101,33,10,0,0,0,0,0,0,0,0,100,101,99,111,117,112,108,101,32,118,97,108,117,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,97,110,117,108,108,115,105,110,107,0,0,0,0,0,0,0,69,66,85,32,43,37,100,32,115,99,97,108,101,10,0,0,99,111,109,98,112,101,108,0,118,100,97,95,118,108,100,0,76,105,103,104,116,71,111,108,100,101,110,82,111,100,89,101,108,108,111,119,0,0,0,0,86,97,108,117,101,32,37,100,32,102,111,114,32,112,97,114,97,109,101,116,101,114,32,39,37,115,39,32,111,117,116,32,111,102,32,37,115,32,102,111,114,109,97,116,32,114,97,110,103,101,32,91,37,100,32,45,32,37,100,93,10,0,0,0,83,105,110,103,108,101,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,46,42,115,39,32,105,115,32,105,110,116,101,114,112,114,101,116,101,100,32,97,115,32,97,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,44,32,115,119,105,116,99,104,32,116,111,32,116,104,101,32,115,121,110,116,97,120,32,39,37,46,42,115,99,39,32,111,116,104,101,114,119,105,115,101,32,105,116,32,119,105,108,108,32,98,101,32,105,110,116,101,114,112,114,101,116,101,100,32,97,115,32,97,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,110,117,109,98,101,114,32,105,110,32,97,32,108,97,116,101,114,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,0,115,119,114,95,102,108,97,103,115,0,0,0,0,0,0,0,104,50,54,51,0,0,0,0,84,111,111,32,109,97,110,121,32,86,76,67,115,32,40,37,100,41,32,116,111,32,98,101,32,114,101,97,100,46,10,0,109,97,120,95,101,120,116,114,97,95,99,98,95,105,116,101,114,97,116,105,111,110,115,0,50,110,100,32,112,97,115,115,32,104,97,115,32,109,111,114,101,32,102,114,97,109,101,115,32,116,104,97,110,32,49,115,116,32,112,97,115,115,32,40,37,100,41,10,0,0,0,0,73,110,118,97,108,105,100,32,109,98,95,116,121,112,101,32,37,100,32,105,110,32,66,32,102,114,97,109,101,10,0,0,78,101,105,116,104,101,114,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,110,111,114,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,100,97,116,97,10,0,0,0,83,99,114,101,101,110,32,111,102,102,115,101,116,32,100,97,116,97,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,109,97,105,110,0,0,0,0,105,110,118,97,108,105,100,32,66,77,80,32,104,101,97,100,101,114,10,0,0,0,0,0,110,101,101,100,101,100,32,37,100,32,104,97,100,32,37,100,10,0,0,0,0,0,0,0,40,102,105,114,115,116,95,121,38,49,41,32,61,61,32,48,0,0,0,0,0,0,0,0,82,117,110,32,118,97,108,117,101,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,32,91,83,65,82,32,37,100,58,37,100,32,68,65,82,32,37,100,58,37,100,93,0,0,80,67,83,95,78,97,104,114,119,97,110,95,49,57,54,55,95,85,84,77,95,51,57,78,0,0,0,0,0,0,0,0,71,67,83,95,65,114,99,95,49,57,53,48,0,0,0,0,91,48,45,49,93,32,37,100,10,0,0,0,0,0,0,0,37,100,44,37,108,100,44,37,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,99,111,117,110,116,58,32,37,117,46,10,0,0,0,0,0,0,99,113,109,56,105,0,0,0,68,97,109,97,103,101,100,32,99,104,97,110,110,101,108,32,100,97,116,97,46,10,0,0,66,117,102,102,101,114,32,118,105,100,101,111,32,102,114,97,109,101,115,44,32,97,110,100,32,109,97,107,101,32,116,104,101,109,32,97,118,97,105,108,97,98,108,101,32,116,111,32,116,104,101,32,101,110,100,32,111,102,32,116,104,101,32,102,105,108,116,101,114,32,103,114,97,112,104,46,0,0,0,0,112,108,97,99,101,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,32,97,116,32,101,118,101,114,121,32,107,101,121,102,114,97,109,101,32,105,110,115,116,101,97,100,32,111,102,32,105,110,32,101,120,116,114,97,100,97,116,97,0,0,109,112,101,103,0,0,0,0,83,99,97,108,97,98,108,101,32,84,101,120,116,117,114,101,32,80,114,111,102,105,108,101,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,99,104,101,99,107,101,114,98,111,97,114,100,95,114,108,0,84,68,65,84,0,0,0,0,115,112,97,116,105,97,108,0,107,102,95,109,97,120,95,100,105,115,116,58,0,0,0,0,74,97,122,122,0,0,0,0,67,97,110,110,111,116,32,112,97,114,97,108,108,101,108,105,122,101,32,100,101,98,108,111,99,107,105,110,103,32,116,121,112,101,32,49,44,32,100,101,99,111,100,105,110,103,32,115,117,99,104,32,102,114,97,109,101,115,32,105,110,32,115,101,113,117,101,110,116,105,97,108,32,111,114,100,101,114,10,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,100,97,116,97,46,10,0,0,0,87,77,47,67,111,109,112,111,115,101,114,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,67,79,77,77,32,116,97,103,32,111,114,32,105,110,118,97,108,105,100,32,98,108,111,99,107,95,97,108,105,103,110,32,118,97,108,117,101,10,0,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,73,73,32,47,32,88,97,110,0,0,0,0,0,0,0,0,83,99,97,108,97,98,108,101,32,99,111,110,102,105,103,117,114,97,116,105,111,110,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,68,84,83,10,0,0,0,0,0,0,0,0,70,111,108,107,45,82,111,99,107,0,0,0,0,0,0,0,37,115,32,87,37,100,32,72,37,100,32,70,37,100,58,37,100,32,73,37,99,32,65,37,100,58,37,100,37,115,10,0,52,50,48,112,49,54,0,0,100,112,100,115,32,99,104,117,110,107,32,115,105,122,101,32,37,108,108,100,32,105,110,118,97,108,105,100,10,0,0,0,120,111,98,88,0,0,0,0,112,105,99,107,105,110,103,32,37,115,32,111,117,116,32,111,102,32,37,100,32,114,101,102,58,37,115,32,97,108,112,104,97,58,37,100,10,0,0,0,32,32,112,116,115,61,0,0,67,97,110,110,111,116,32,100,101,116,101,114,109,105,110,101,32,99,117,115,116,111,109,32,115,97,109,112,108,105,110,103,32,114,97,116,101,10,0,0,105,110,100,101,120,32,60,32,87,84,86,95,70,73,76,69,83,0,0,0,0,0,0,0,80,67,83,95,78,97,104,114,119,97,110,95,49,57,54,55,95,85,84,77,95,51,56,78,0,0,0,0,0,0,0,0,102,111,114,109,97,116,32,98,117,102,102,101,114,32,115,105,122,101,32,117,110,100,101,114,102,108,111,119,10,0,0,0,37,108,108,100,58,0,0,0,37,117,58,37,117,58,37,117,46,37,117,0,0,0,0,0,99,111,109,109,101,110,116,0,73,110,118,97,108,105,100,32,114,97,116,101,32,102,108,97,103,32,37,100,10,0,0,0,104,101,97,100,101,114,58,32,39,37,115,39,32,61,32,39,37,115,39,10,0,0,0,0,109,112,99,56,0,0,0,0,97,97,99,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,117,110,99,111,100,101,100,102,114,97,109,101,99,114,99,101,110,99,46,99,0,0,0,0,0,0,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,37,115,37,115,0,0,0,0,102,97,108,115,101,0,0,0,116,66,97,75,0,0,0,0,119,97,114,110,105,110,103,58,32,70,108,97,115,104,32,80,108,97,121,101,114,32,108,105,109,105,116,32,111,102,32,49,54,48,48,48,32,102,114,97,109,101,115,32,114,101,97,99,104,101,100,10,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,115,119,102,100,101,99,46,99,0,0,0,0,91,83,84,89,76,69,93,0,86,105,100,101,111,32,115,111,117,114,99,101,32,102,105,108,116,101,114,115,32,109,117,115,116,32,115,101,116,32,116,104,101,105,114,32,111,117,116,112,117,116,32,108,105,110,107,39,115,32,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,10,0,0,0,0,0,83,82,84,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,97,32,115,105,110,103,108,101,32,115,117,98,116,105,116,108,101,115,32,115,116,114,101,97,109,46,10,0,0,0,115,116,114,97,121,32,68,84,83,45,72,68,32,102,114,97,109,101,10,0,0,0,0,0,60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,110,99,111,100,105,110,103,61,34,117,116,102,45,56,34,63,62,10,0,77,117,108,116,105,112,108,101,32,118,105,100,101,111,32,115,116,114,101,97,109,115,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,111,117,114,105,95,87,101,115,116,0,37,45,49,50,115,37,115,10,0,0,0,0,0,0,0,0,32,45,62,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,100,116,115,58,37,115,32,100,116,115,95,116,105,109,101,58,37,115,10,0,0,0,0,0,0,109,112,99,0,0,0,0,0,109,97,107,101,95,122,101,114,111,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,111,117,114,105,95,67,101,110,116,114,97,108,0,0,0,0,0,0,116,105,109,101,32,98,97,115,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,102,105,108,101,32,105,115,32,110,111,116,32,115,101,101,107,97,98,108,101,32,45,32,110,111,116,32,112,97,114,115,105,110,103,32,108,97,115,116,32,112,97,114,116,105,116,105,111,110,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,111,117,114,105,95,69,97,115,116,0,117,115,101,95,101,100,105,116,108,105,115,116,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,95,99,111,117,110,116,61,37,100,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,100,101,115,99,114,105,112,116,105,111,110,46,10,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,105,115,115,105,112,112,105,95,87,101,115,116,0,0,0,0,0,0,100,114,111,112,95,102,114,97,109,101,115,61,37,100,10,0,80,67,83,95,78,65,68,56,51,95,77,105,115,115,105,115,115,105,112,112,105,95,69,97,115,116,0,0,0,0,0,0,109,112,50,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,110,110,101,115,111,116,97,95,83,111,117,116,104,0,0,0,0,0,0,0,109,112,51,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,110,110,101,115,111,116,97,95,67,101,110,116,0,0,0,0,0,0,0,0,98,116,54,48,49,0,0,0,85,110,97,98,108,101,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,104,105,110,116,105,110,103,32,111,102,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,110,110,101,115,111,116,97,95,78,111,114,116,104,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,121,45,97,120,105,115,32,115,105,122,101,32,111,102,32,116,104,101,32,119,105,110,100,111,119,32,117,115,101,100,32,100,117,114,105,110,103,32,99,111,109,98,101,100,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,0,0,0,0,121,117,118,52,50,50,112,57,108,101,0,0,0,0,0,0,76,105,103,104,116,67,121,97,110,0,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,115,101,116,32,98,121,32,111,112,116,105,111,110,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,37,115,32,102,111,114,109,97,116,0,100,111,119,110,109,105,120,0,115,101,116,32,102,108,97,103,115,0,0,0,0,0,0,0,102,114,97,109,101,32,62,61,32,48,32,38,38,32,102,114,97,109,101,32,60,32,114,99,45,62,110,117,109,95,101,110,116,114,105,101,115,0,0,0,97,117,116,111,115,101,108,101,99,116,105,111,110,0,0,0,115,108,105,99,101,45,109,97,120,45,115,105,122,101,32,118,105,111,108,97,116,101,100,32,40,102,114,97,109,101,32,37,100,44,32,99,97,117,115,101,58,32,115,108,105,99,101,45,109,105,110,45,109,98,115,41,10,0,0,0,0,0,0,0,44,32,37,100,120,37,100,0,80,67,83,95,78,65,68,56,51,95,77,105,99,104,105,103,97,110,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,67,83,95,65,114,97,116,117,0,0,0,0,0,0,0,99,113,109,52,112,99,0,0,108,111,99,97,108,95,104,101,97,100,101,114,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,51,0,0,0,0,0,0,0,78,45,98,105,116,32,80,114,111,102,105,108,101,0,0,0,109,106,112,101,103,58,32,65,100,111,98,101,32,104,101,97,100,101,114,32,102,111,117,110,100,44,32,116,114,97,110,115,102,111,114,109,61,37,100,10,0,0,0,0,0,0,0,0,68,105,114,101,99,116,32,77,86,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,0,0,0,0,0,0,0,107,102,95,109,105,110,95,100,105,115,116,58,0,0,0,0,100,101,98,108,111,99,107,105,110,103,32,102,105,108,116,101,114,32,112,97,114,97,109,101,116,101,114,115,32,37,100,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,0,0,0,120,97,110,95,119,99,51,0,70,111,108,107,0,0,0,0,32,67,52,52,52,112,49,54,32,88,89,83,67,83,83,61,52,52,52,80,49,54,0,0,37,48,46,51,102,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,99,104,105,103,97,110,95,67,101,110,116,114,97,108,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,105,99,104,105,103,97,110,95,78,111,114,116,104,0,0,0,0,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,99,111,100,101,99,0,0,0,32,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,104,101,97,100,101,114,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,0,115,116,114,101,97,109,58,37,100,32,115,116,97,114,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,100,116,115,58,37,115,32,100,116,115,95,116,105,109,101,58,37,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,10,0,0,0,0,0,115,101,108,101,99,116,32,100,105,115,112,108,97,121,32,109,111,100,101,0,0,0,0,0,100,111,32,110,111,116,32,99,104,97,110,103,101,32,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,73,115,0,0,0,0,0,0,115,101,103,109,101,110,116,95,102,111,114,109,97,116,0,0,69,114,114,111,114,32,110,117,116,45,62,116,105,109,101,95,98,97,115,101,91,105,93,46,100,101,110,32,105,115,32,40,37,108,108,100,41,10,0,0,105,116,101,109,95,110,117,109,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,99,111,100,101,99,32,110,97,109,101,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,115,115,97,99,104,117,115,101,116,116,115,0,78,117,109,98,101,114,32,111,102,32,108,111,111,107,97,104,101,97,100,32,101,110,116,114,105,101,115,32,102,111,114,32,73,83,77,32,102,105,108,101,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,83,97,109,112,108,101,68,101,108,116,97,32,37,100,32,105,110,32,83,84,84,83,44,32,97,116,32,37,100,32,115,116,58,37,100,10,0,0,0,0,82,101,99,117,114,115,105,111,110,32,108,111,111,112,32,111,110,32,34,37,46,42,115,34,10,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,116,121,112,101,32,37,100,46,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,114,121,108,97,110,100,0,0,0,0,0,0,100,117,112,95,102,114,97,109,101,115,61,37,100,10,0,0,67,97,110,110,111,116,32,114,101,115,112,101,99,116,32,109,97,120,32,100,101,108,97,121,58,32,102,114,97,109,101,32,115,105,122,101,32,61,32,48,10,0,0,0,0,0,0,0,68,111,110,39,116,32,107,110,111,119,32,104,111,119,32,116,111,32,115,112,108,105,116,32,102,114,97,109,101,115,32,102,111,114,32,118,105,100,101,111,32,102,111,114,109,97,116,32,37,105,46,32,86,105,100,101,111,32,115,116,114,101,97,109,32,119,105,108,108,32,98,101,32,98,114,111,107,101,110,33,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,105,110,101,95,87,101,115,116,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,114,109,100,101,99,46,99,0,0,0,0,0,100,97,116,101,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,97,105,110,101,95,69,97,115,116,0,0,0,0,98,101,103,105,110,0,0,0,112,105,120,101,108,95,102,111,114,109,97,116,0,0,0,0,115,101,116,32,115,108,105,100,105,110,103,32,109,111,100,101,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,76,111,117,105,115,105,97,110,97,95,83,111,117,116,104,0,0,0,0,0,0,0,111,118,115,117,98,0,0,0,99,97,118,115,0,0,0,0,109,106,112,101,103,0,0,0,80,67,83,95,78,65,68,56,51,95,76,111,117,105,115,105,97,110,97,95,78,111,114,116,104,0,0,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,39,114,101,100,49,39,32,97,116,111,109,10,0,0,0,0,0,0,104,101,97,100,101,114,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,0,98,108,111,99,107,121,0,0,121,117,118,52,50,50,112,57,98,101,0,0,0,0,0,0,76,105,103,104,116,67,111,114,97,108,0,0,0,0,0,0,69,110,99,111,117,110,116,101,114,101,100,32,69,79,70,32,119,104,105,108,101,32,114,101,97,100,105,110,103,32,105,110,100,101,120,46,10,0,0,0,111,99,116,97,103,111,110,97,108,0,0,0,0,0,0,0,102,108,97,103,115,0,0,0,102,97,105,108,101,100,32,116,111,32,114,101,110,97,109,101,32,34,37,115,34,32,116,111,32,34,37,115,34,10,0,0,97,117,116,111,0,0,0,0,114,43,98,0,0,0,0,0,37,115,41,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,75,101,110,116,117,99,107,121,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,67,83,95,76,105,115,98,111,110,0,0,0,0,0,0,99,113,109,52,112,121,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,105,103,110,111,114,101,32,99,114,111,112,112,105,110,103,32,105,110,102,111,114,109,97,116,105,111,110,32,102,114,111,109,32,115,112,115,0,0,0,0,109,115,109,112,101,103,52,0,77,97,105,110,32,80,114,111,102,105,108,101,0,0,0,0,104,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,111,114,32,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,112,105,99,116,117,114,101,10,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,100,105,114,101,99,116,45,112,114,101,100,0,0,0,0,0,107,102,95,109,111,100,101,58,0,0,0,0,0,0,0,0,100,101,98,108,111,99,107,105,110,103,95,102,105,108,116,101,114,95,105,100,99,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,73,110,116,101,114,112,108,97,121,32,77,86,69,32,118,105,100,101,111,0,0,0,0,0,72,97,114,100,32,82,111,99,107,0,0,0,0,0,0,0,32,67,52,50,50,112,49,54,32,88,89,83,67,83,83,61,52,50,50,80,49,54,0,0,32,32,100,116,115,61,0,0,80,67,83,95,78,65,68,56,51,95,75,101,110,116,117,99,107,121,95,78,111,114,116,104,0,0,0,0,0,0,0,0,111,117,116,58,37,99,37,100,0,0,0,0,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,80,67,83,95,78,65,68,56,51,95,75,97,110,115,97,115,95,83,111,117,116,104,0,0,37,99,37,99,37,99,37,99,37,99,32,37,45,49,54,115,32,32,32,32,32,32,32,37,100,32,32,32,32,32,32,32,32,32,32,32,32,37,50,100,10,0,0,0,0,0,0,0,115,101,103,109,101,110,116,58,39,37,115,39,32,115,116,97,114,116,115,32,119,105,116,104,32,112,97,99,107,101,116,32,115,116,114,101,97,109,58,37,100,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,102,114,97,109,101,58,37,100,10,0,0,115,101,116,32,112,97,99,107,101,116,32,115,105,122,101,0,65,84,82,65,67,51,58,32,85,110,115,117,112,112,111,114,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,10,0,0,0,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,75,97,110,115,97,115,95,78,111,114,116,104,0,0,73,110,118,97,108,105,100,32,65,84,82,65,67,45,88,32,99,104,97,110,110,101,108,32,105,100,58,32,37,100,10,0,69,114,114,111,114,32,110,117,116,45,62,116,105,109,101,95,98,97,115,101,91,105,93,46,110,117,109,32,105,115,32,40,37,108,108,100,41,10,0,0,67,104,97,110,110,101,108,32,99,104,97,110,103,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,80,114,105,109,101,114,32,112,97,99,107,32,105,116,101,109,32,108,101,110,103,116,104,32,37,100,0,0,0,0,0,0,46,47,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,111,119,97,95,83,111,117,116,104,0,0,0,0,105,115,109,95,108,111,111,107,97,104,101,97,100,0,0,0,115,112,120,0,0,0,0,0,50,55,48,0,0,0,0,0,108,105,115,115,97,106,111,117,115,95,120,121,0,0,0,0,99,97,110,110,111,116,32,102,105,110,100,32,115,121,110,99,32,119,111,114,100,10,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,109,105,109,101,116,121,112,101,58,32,37,115,44,32,115,107,105,112,112,105,110,103,46,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,111,119,97,95,78,111,114,116,104,0,0,0,0,32,100,117,112,61,37,100,32,100,114,111,112,61,37,100,0,83,80,58,32,37,108,108,100,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,110,100,105,97,110,97,95,87,101,115,116,0,0,117,108,97,119,0,0,0,0,112,97,99,107,97,103,101,32,116,121,112,101,58,37,100,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,110,100,105,97,110,97,95,69,97,115,116,0,0,115,116,114,105,99,116,0,0,117,110,97,98,108,101,32,116,111,32,99,111,109,112,117,116,101,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,108,97,115,116,32,112,97,99,107,101,116,10,0,0,98,0,0,0,0,0,0,0,97,117,100,105,111,32,99,111,109,112,114,101,115,115,105,111,110,32,37,105,32,40,102,111,114,109,97,116,32,37,105,44,32,119,105,100,116,104,32,37,105,41,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,108,108,105,110,111,105,115,95,87,101,115,116,0,111,104,115,117,98,0,0,0,68,101,108,97,121,32,98,101,116,119,101,101,110,32,116,104,101,32,102,105,114,115,116,32,112,97,99,107,101,116,32,97,110,100,32,108,97,115,116,32,112,97,99,107,101,116,32,105,110,32,116,104,101,32,109,117,120,105,110,103,32,113,117,101,117,101,32,105,115,32,37,108,108,100,32,62,32,37,108,108,100,58,32,102,111,114,99,105,110,103,32,111,117,116,112,117,116,10,0,0,0,0,0,0,70,79,82,77,65,84,61,0,91,37,108,108,100,93,91,93,37,99,0,0,0,0,0,0,102,102,115,101,114,118,101,114,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,108,108,105,110,111,105,115,95,69,97,115,116,0,115,101,116,32,115,97,109,112,108,101,32,114,97,116,101,0,115,101,116,32,116,104,101,32,120,45,97,120,105,115,32,115,105,122,101,32,111,102,32,116,104,101,32,119,105,110,100,111,119,32,117,115,101,100,32,100,117,114,105,110,103,32,99,111,109,98,101,100,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,0,0,0,0,121,117,118,52,52,52,112,49,48,108,101,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,112,101,103,116,115,101,110,99,46,99,0,76,105,103,104,116,66,108,117,101,0,0,0,0,0,0,0,37,103,0,0,0,0,0,0,55,46,49,40,119,105,100,101,45,115,105,100,101,41,0,0,115,101,116,32,114,101,109,97,116,114,105,120,32,109,97,120,118,97,108,0,0,0,0,0,102,105,110,97,108,32,114,97,116,101,102,97,99,116,111,114,58,32,37,46,50,102,10,0,83,101,108,101,99,116,32,116,104,101,32,99,104,97,110,110,101,108,32,116,111,32,100,101,99,111,100,101,32,102,111,114,32,100,117,97,108,32,109,111,110,111,0,0,0,0,0,0,102,114,97,109,101,61,37,52,100,32,81,80,61,37,46,50,102,32,78,65,76,61,37,100,32,83,108,105,99,101,58,37,99,32,80,111,99,58,37,45,51,100,32,73,58,37,45,52,100,32,80,58,37,45,52,100,32,83,75,73,80,58,37,45,52,100,32,115,105,122,101,61,37,100,32,98,121,116,101,115,37,115,10,0,0,0,0,0,99,104,97,110,103,105,110,103,32,112,97,99,107,101,116,32,115,105,122,101,32,116,111,32,37,100,10,0,0,0,0,0,37,115,44,32,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,100,97,104,111,95,87,101,115,116,0,0,0,0,71,67,83,95,65,103,97,100,101,122,0,0,0,0,0,0,98,111,116,116,111,109,0,0,99,113,109,52,105,99,0,0,112,99,109,95,117,56,0,0,105,103,110,111,114,101,99,114,111,112,0,0,0,0,0,0,77,80,69,71,45,50,32,80,83,32,40,86,79,66,41,0,67,111,114,101,32,80,114,111,102,105,108,101,0,0,0,0,118,98,118,32,98,117,102,102,101,114,58,32,37,100,44,32,98,105,116,114,97,116,101,58,37,100,10,0,0,0,0,0,109,106,112,101,103,58,32,74,70,73,70,32,104,101,97,100,101,114,32,102,111,117,110,100,32,40,118,101,114,115,105,111,110,58,32,37,120,46,37,120,41,32,83,65,82,61,37,100,47,37,100,10,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,112,97,114,116,105,116,105,111,110,115,32,116,111,32,99,111,110,115,105,100,101,114,46,32,80,111,115,115,105,98,108,101,32,118,97,108,117,101,115,58,32,112,56,120,56,44,32,112,52,120,52,44,32,98,56,120,56,44,32,105,56,120,56,44,32,105,52,120,52,44,32,110,111,110,101,44,32,97,108,108,0,0,0,0,0,0,107,101,121,102,114,97,109,105,110,103,32,115,101,116,116,105,110,103,115,10,32,32,37,42,115,37,100,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,0,0,0,0,81,80,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,112,101,115,95,101,120,116,32,37,88,32,105,115,32,105,110,118,97,108,105,100,10,0,0,105,110,116,101,114,112,108,97,121,118,105,100,101,111,0,0,82,111,99,107,32,38,32,82,111,108,108,0,0,0,0,0,78,111,116,32,97,32,77,117,115,101,112,97,99,107,56,32,102,105,108,101,10,0,0,0,32,67,52,50,48,112,49,54,32,88,89,83,67,83,83,61,52,50,48,80,49,54,0,0,32,32,100,117,114,97,116,105,111,110,61,37,48,46,51,102,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,100,97,104,111,95,67,101,110,116,114,97,108,0,73,68,51,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,73,100,97,104,111,95,69,97,115,116,0,0,0,0,99,0,0,0,0,0,0,0,102,102,99,111,110,99,97,116,32,118,101,114,115,105,111,110,32,49,46,48,10,0,0,0,101,110,97,98,108,101,100,32,119,104,101,110,32,114,101,113,117,105,114,101,100,32,98,121,32,116,97,114,103,101,116,32,102,111,114,109,97,116,0,0,80,67,83,95,78,65,68,56,51,95,71,101,111,114,103,105,97,95,87,101,115,116,0,0,69,114,114,111,114,32,110,117,116,45,62,116,105,109,101,95,98,97,115,101,95,99,111,117,110,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,37,105,10,0,0,0,0,0,110,101,118,101,114,32,111,118,101,114,119,114,105,116,101,32,111,117,116,112,117,116,32,102,105,108,101,115,0,0,0,0,80,67,83,95,78,65,68,56,51,95,71,101,111,114,103,105,97,95,69,97,115,116,0,0,77,97,120,105,109,117,109,32,102,114,97,103,109,101,110,116,32,115,105,122,101,0,0,0,49,56,48,0,0,0,0,0,51,103,112,0,0,0,0,0,84,88,88,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,53,0,111,117,116,95,116,105,109,101,61,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,54,100,10,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,104,101,97,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,44,32,115,117,112,112,111,114,116,101,100,32,97,114,101,32,52,48,48,48,44,32,56,48,48,48,44,32,49,49,48,50,53,44,32,50,50,48,53,48,32,97,110,100,32,52,52,49,48,48,10,0,0,0,69,120,97,99,116,108,121,32,111,110,101,32,77,105,99,114,111,68,86,68,32,115,116,114,101,97,109,32,105,115,32,110,101,101,100,101,100,46,10,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,52,0,123,37,100,125,123,37,100,125,0,0,0,0,0,0,0,0,65,112,112,108,105,99,97,116,105,111,110,32,112,114,111,118,105,100,101,100,32,100,117,114,97,116,105,111,110,58,32,37,108,108,100,32,47,32,116,105,109,101,115,116,97,109,112,58,32,37,108,108,100,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,102,111,114,32,109,111,118,47,109,112,52,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,100,53,101,110,99,46,99,0,0,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,51,0,77,97,116,114,111,115,107,97,32,65,117,100,105,111,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,50,0,68,105,97,108,111,103,117,101,58,32,37,115,44,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,37,115,13,10,0,0,0,118,115,117,98,0,0,0,0,103,111,116,32,97,117,100,105,111,32,112,97,99,107,101,116,44,32,98,117,116,32,110,111,32,97,117,100,105,111,32,115,116,114,101,97,109,32,112,114,101,115,101,110,116,10,0,0,66,85,71,58,32,65,76,83,32,111,102,102,115,101,116,32,105,115,32,110,111,116,32,98,121,116,101,45,97,108,105,103,110,101,100,10,0,0,0,0,37,100,37,42,49,91,46,58,93,37,100,37,42,49,91,46,58,93,37,100,37,42,49,91,46,58,93,37,100,0,0,0,80,67,83,95,78,65,68,56,51,95,72,97,119,97,105,105,95,122,111,110,101,95,49,0,73,77,65,95,65,68,80,67,77,95,83,111,117,110,100,0,98,108,111,99,107,120,0,0,121,117,118,52,52,52,112,49,48,98,101,0,0,0,0,0,76,101,109,111,110,67,104,105,102,102,111,110,0,0,0,0,45,68,66,76,95,77,73,78,0,0,0,0,0,0,0,0,55,46,49,40,119,105,100,101,41,0,0,0,0,0,0,0,114,101,109,97,116,114,105,120,95,109,97,120,118,97,108,0,46,109,98,116,114,101,101,46,116,101,109,112,0,0,0,0,100,117,97,108,95,109,111,110,111,95,109,111,100,101,0,0,32,83,83,73,77,32,89,58,37,46,53,102,0,0,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,102,105,108,101,32,58,32,37,115,10,0,0,0,0,0,0,0,112,99,44,32,0,0,0,0,80,67,83,95,78,65,68,56,51,95,70,108,111,114,105,100,97,95,78,111,114,116,104,0,71,67,83,95,65,102,103,111,111,121,101,0,0,0,0,0,116,111,112,0,0,0,0,0,99,113,109,52,105,121,0,0,115,107,105,112,32,98,105,116,115,116,114,101,97,109,32,101,110,99,111,100,105,110,103,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,83,105,109,112,108,101,32,83,99,97,108,97,98,108,101,32,80,114,111,102,105,108,101,0,115,101,113,117,101,110,99,101,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,0,0,0,0,0,0,0,50,53,0,0,0,0,0,0,112,97,114,116,105,116,105,111,110,115,0,0,0,0,0,0,114,99,95,50,112,97,115,115,95,118,98,114,95,109,97,120,115,101,99,116,105,111,110,95,112,99,116,58,0,0,0,0,99,97,98,97,99,95,105,110,105,116,95,105,100,99,32,37,117,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,105,100,32,82,111,81,32,118,105,100,101,111,0,0,0,0,77,117,115,105,99,97,108,0,32,67,52,52,52,112,49,52,32,88,89,83,67,83,83,61,52,52,52,80,49,52,0,0,112,110,115,0,0,0,0,0,32,32,107,101,121,102,114,97,109,101,61,37,100,10,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,105,76,66,67,32,102,105,108,101,32,104,101,97,100,101,114,10,0,0,80,67,83,95,78,65,68,56,51,95,70,108,111,114,105,100,97,95,87,101,115,116,0,0,99,111,109,109,101,110,116,0,105,110,118,97,108,105,100,32,99,104,97,110,110,101,108,115,58,32,37,117,10,0,0,0,80,67,83,95,78,65,68,56,51,95,70,108,111,114,105,100,97,95,69,97,115,116,0,0,37,45,51,50,115,32,35,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,35,69,88,84,45,88,45,84,65,82,71,69,84,68,85,82,65,84,73,79,78,58,37,108,108,100,10,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,66,77,80,32,109,117,115,116,32,98,101,32,49,98,105,116,44,32,52,98,105,116,44,32,56,98,105,116,44,32,49,54,98,105,116,44,32,50,52,98,105,116,44,32,111,114,32,51,50,98,105,116,10,0,0,0,97,117,116,111,0,0,0,0,80,67,83,95,78,65,68,56,51,95,68,101,108,97,119,97], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2146464);
/* memory initializer */ allocate([114,101,0,0,0,0,0,0,35,69,88,84,73,78,70,58,37,100,44,10,0,0,0,0,109,97,120,95,100,105,115,116,97,110,99,101,32,37,100,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,75,65,71,83,105,122,101,32,37,105,32,45,32,103,117,101,115,115,105,110,103,32,0,0,69,109,112,116,121,32,112,108,97,121,108,105,115,116,10,0,80,67,83,95,78,65,68,56,51,95,67,111,110,110,101,99,116,105,99,117,116,0,0,0,60,109,97,110,105,102,101,115,116,32,120,109,108,110,115,61,34,104,116,116,112,58,47,47,110,115,46,97,100,111,98,101,46,99,111,109,47,102,52,109,47,49,46,48,34,62,10,0,110,0,0,0,0,0,0,0,102,114,97,103,95,115,105,122,101,0,0,0,0,0,0,0,57,48,0,0,0,0,0,0,115,105,122,101,32,60,32,115,105,122,101,111,102,40,98,117,102,102,101,114,41,0,0,0,109,97,116,114,111,115,107,97,32,109,117,120,101,114,0,0,109,97,112,32,112,97,99,107,101,116,32,110,111,116,32,102,111,117,110,100,10,0,0,0,109,105,110,105,109,117,109,32,118,97,108,105,100,32,100,101,108,97,121,32,98,101,116,119,101,101,110,32,102,114,97,109,101,115,32,40,105,110,32,104,117,110,100,114,101,100,116,104,115,32,111,102,32,115,101,99,111,110,100,41,0,0,0,0,84,88,88,88,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,111,108,111,114,97,100,111,95,83,111,117,116,104,0,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,103,105,102,46,99,0,0,0,0,0,0,0,111,117,116,95,116,105,109,101,95,109,115,61,37,108,108,100,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,111,108,111,114,97,100,111,95,67,101,110,116,114,97,108,0,0,0,0,0,0,115,105,122,101,0,0,0,0,86,105,100,101,111,32,99,111,100,101,99,32,40,37,120,41,0,0,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,80,67,83,95,78,65,68,56,51,95,67,111,108,111,114,97,100,111,95,78,111,114,116,104,0,0,0,0,0,0,0,0,69,78,68,61,37,108,108,100,10,0,0,0,0,0,0,0,69,78,68,61,37,108,108,100,0,0,0,0,0,0,0,0,99,104,117,110,107,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,10,0,0,0,80,67,83,95,78,65,68,56,51,95,65,114,107,97,110,115,97,115,95,83,111,117,116,104,0,0,0,0,0,0,0,0,104,115,117,98,0,0,0,0,37,100,32,102,114,97,109,101,40,115,41,10,0,0,0,0,68,101,116,101,99,116,101,100,32,116,105,109,101,99,111,100,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,80,67,83,95,78,65,68,56,51,95,65,114,107,97,110,115,97,115,95,78,111,114,116,104,0,0,0,0,0,0,0,0,76,105,110,101,32,37,100,58,32,100,117,114,97,116,105,111,110,32,119,105,116,104,111,117,116,32,102,105,108,101,10,0,115,101,116,32,119,104,101,116,104,101,114,32,111,114,32,110,111,116,32,99,104,114,111,109,97,32,105,115,32,99,111,110,115,105,100,101,114,101,100,32,105,110,32,116,104,101,32,99,111,109,98,101,100,32,102,114,97,109,101,32,100,101,99,105,115,105,111,110,0,0,0,0,121,117,118,52,52,52,112,57,108,101,0,0,0,0,0,0,76,97,119,110,71,114,101,101,110,0,0,0,0,0,0,0,45,68,66,76,95,77,65,88,0,0,0,0,0,0,0,0,55,46,49,0,0,0,0,0,77,117,120,105,110,103,32,118,97,114,105,97,98,108,101,32,112,97,99,107,101,116,32,115,105,122,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,111,110,32,110,111,110,32,115,101,101,107,97,98,108,101,32,111,117,116,112,117,116,10,0,0,0,0,0,0,0,114,101,109,97,116,114,105,120,95,118,111,108,117,109,101,0,35,111,112,116,105,111,110,115,58,32,37,115,10,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,105,110,118,97,108,105,100,32,65,76,65,67,32,109,97,103,105,99,32,99,111,111,107,105,101,10,0,0,0,0,0,0,65,65,67,32,100,101,99,111,100,101,114,0,0,0,0,0,32,80,83,78,82,32,89,58,37,53,46,50,102,32,85,58,37,53,46,50,102,32,86,58,37,53,46,50,102,0,0,0,109,109,102,0,0,0,0,0,116,118,44,32,0,0,0,0,86,101,114,115,105,111,110,32,37,100,46,37,100,0,0,0,80,67,83,95,78,65,68,56,51,95,65,114,105,122,111,110,97,95,87,101,115,116,0,0,71,67,83,95,65,105,110,95,101,108,95,65,98,100,0,0,70,105,114,115,116,32,105,110,112,117,116,32,108,105,110,107,32,37,115,32,112,97,114,97,109,101,116,101,114,115,32,40,115,105,122,101,32,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,32,100,111,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,115,101,99,111,110,100,32,105,110,112,117,116,32,108,105,110,107,32,37,115,32,112,97,114,97,109,101,116,101,114,115,32,40,37,100,120,37,100,44,32,83,65,82,32,37,100,58,37,100,41,10,0,0,0,0,0,0,0,99,113,109,52,112,0,0,0,110,111,111,117,116,0,0,0,109,115,109,112,101,103,52,118,50,0,0,0,0,0,0,0,83,105,109,112,108,101,32,80,114,111,102,105,108,101,0,0,97,115,112,101,99,116,32,114,97,116,105,111,32,104,97,115,32,102,111,114,98,105,100,100,101,110,32,48,32,118,97,108,117,101,10,0,0,0,0,0,112,111,108,97,114,105,116,121,32,37,100,10,0,0,0,0,82,101,100,117,99,101,32,102,108,117,99,116,117,97,116,105,111,110,115,32,105,110,32,81,80,32,40,98,101,102,111,114,101,32,99,117,114,118,101,32,99,111,109,112,114,101,115,115,105,111,110,41,0,0,0,0,114,99,95,50,112,97,115,115,95,118,98,114,95,109,105,110,115,101,99,116,105,111,110,95,112,99,116,58,0,0,0,0,97,100,102,0,0,0,0,0,102,105,114,115,116,95,109,98,95,105,110,95,115,108,105,99,101,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,66,105,110,107,32,50,32,118,105,100,101,111,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,0,0,109,109,0,0,0,0,0,0,114,111,113,0,0,0,0,0,82,101,116,114,111,0,0,0,32,67,52,50,50,112,49,52,32,88,89,83,67,83,83,61,52,50,50,80,49,52,0,0,115,116,114,101,97,109,32,35,37,100,58,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,114,105,122,111,110,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,79,112,116,105,111,110,32,37,115,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,109,107,118,116,105,109,101,115,116,97,109,112,95,118,50,0,108,101,110,32,62,61,32,109,97,120,95,98,117,102,102,101,114,95,115,105,122,101,0,0,75,101,121,32,39,37,115,39,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,114,105,122,111,110,97,95,69,97,115,116,0,0,110,97,109,101,0,0,0,0,78,79,0,0,0,0,0,0,97,118,105,45,62,102,114,97,109,101,115,95,104,100,114,95,97,108,108,0,0,0,0,0,109,105,99,114,111,100,118,100,0,0,0,0,0,0,0,0,83,101,101,107,32,102,97,105,108,101,100,10,0,0,0,0,73,110,118,97,108,105,100,32,110,101,103,97,116,105,118,101,32,100,97,116,97,32,115,105,122,101,32,39,37,100,39,32,102,111,117,110,100,10,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,54,0,0,115,104,105,102,116,32,116,105,109,101,115,116,97,109,112,115,32,115,111,32,116,104,101,121,32,115,116,97,114,116,32,97,116,32,48,0,0,0,0,0,109,117,120,105,110,103,32,65,68,80,67,77,32,65,70,67,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,91,69,118,101,110,116,115,93,0,0,0,0,0,0,0,0,69,114,114,111,114,32,115,116,114,101,97,109,95,99,111,117,110,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,117,110,107,110,111,119,110,32,111,112,101,114,97,116,105,111,110,97,108,32,112,97,116,116,101,114,110,58,32,37,48,50,120,104,32,37,48,50,120,104,32,45,32,103,117,101,115,115,105,110,103,32,79,80,49,97,10,0,0,0,0,0,0,0,97,117,116,104,111,114,0,0,109,105,99,114,111,100,118,100,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,53,0,0,77,105,110,105,109,117,109,32,102,114,97,103,109,101,110,116,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,111,118,101,114,119,114,105,116,101,32,111,117,116,112,117,116,32,102,105,108,101,115,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,115,102,100,101,99,46,99,0,0,0,0,114,111,116,97,116,101,0,0,97,113,116,100,101,99,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,65,65,67,32,101,120,116,114,97,100,97,116,97,44,32,117,110,97,98,108,101,32,116,111,32,100,101,116,101,114,109,105,110,101,32,115,97,109,112,108,101,114,97,116,101,46,10,0,0,0,78,111,110,32,65,83,67,73,73,32,107,101,121,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,10,0,78,117,109,98,101,114,32,111,102,32,115,101,101,107,32,101,110,116,114,105,101,115,32,105,115,32,108,101,115,115,32,116,104,97,110,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,58,32,37,122,117,32,118,115,46,32,37,117,10,0,0,0,0,0,0,0,109,103,115,116,115,0,0,0,37,100,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,52,0,0,116,111,116,97,108,95,115,105,122,101,61,37,108,108,100,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,51,0,0,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,50,0,0,69,114,114,111,114,32,108,111,97,100,105,110,103,32,105,109,97,103,101,32,102,105,108,101,32,39,37,115,39,10,0,0,109,100,53,0,0,0,0,0,109,97,120,95,118,111,108,117,109,101,58,32,37,46,49,102,32,100,66,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,67,97,108,105,102,111,114,110,105,97,95,49,0,0,100,97,114,0,0,0,0,0,102,105,120,101,100,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,114,101,112,108,97,121,103,97,105,110,46,99,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,49,48,0,0,0,0,0,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,32,97,102,116,101,114,32,99,104,97,110,110,101,108,32,110,97,109,101,32,105,110,32,34,37,46,56,115,34,10,0,0,0,0,0,0,99,104,114,111,109,97,0,0,79,112,101,110,67,76,58,32,102,97,116,97,108,32,101,114,114,111,114,44,32,97,98,111,114,116,105,110,103,32,101,110,99,111,100,101,10,0,0,0,121,117,118,52,52,52,112,57,98,101,0,0,0,0,0,0,76,97,118,101,110,100,101,114,66,108,117,115,104,0,0,0,68,66,76,95,77,73,78,0,55,46,48,40,102,114,111,110,116,41,0,0,0,0,0,0,33,115,45,62,105,110,112,117,116,95,102,114,97,109,101,115,91,105,93,0,0,0,0,0,115,101,116,32,114,101,109,97,116,114,105,120,32,118,111,108,117,109,101,0,0,0,0,0,119,98,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,110,118,97,108,105,100,32,68,84,83,58,32,80,84,83,32,105,115,32,108,101,115,115,32,116,104,97,110,32,68,84,83,10,0,0,0,0,0,0,37,100,32,98,112,99,44,32,0,0,0,0,0,0,0,0,48,46,56,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,57,0,71,67,83,95,65,71,68,56,52,0,0,0,0,0,0,0,105,110,112,117,116,115,32,109,117,115,116,32,98,101,32,111,102,32,115,97,109,101,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,99,113,109,52,105,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,102,108,97,103,115,50,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,115,32,110,111,116,32,115,101,116,32,97,110,100,32,99,97,110,110,111,116,32,98,101,32,103,117,101,115,115,101,100,32,102,114,111,109,32,116,104,101,32,109,97,112,115,46,10,0,0,100,99,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,10,0,0,73,110,118,97,108,105,100,32,104,111,114,105,122,111,110,116,97,108,32,111,114,32,118,101,114,116,105,99,97,108,32,115,105,122,101,32,118,97,108,117,101,46,10,0,0,0,0,0,99,112,108,120,98,108,117,114,0,0,0,0,0,0,0,0,114,99,95,50,112,97,115,115,95,118,98,114,95,98,105,97,115,95,112,99,116,58,0,0,70,114,97,109,101,32,110,117,109,32,103,97,112,32,37,100,32,37,100,10,0,0,0,0,83,111,110,121,32,80,108,97,121,83,116,97,116,105,111,110,32,77,68,69,67,32,40,77,111,116,105,111,110,32,68,69,67,111,100,101,114,41,0,0,80,111,108,107,97,0,0,0,32,67,52,50,48,112,49,52,32,88,89,83,67,83,83,61,52,50,48,80,49,52,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,58,32,37,115,46,10,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,56,0,65,112,112,108,121,32,97,32,116,119,111,45,112,111,108,101,32,66,117,116,116,101,114,119,111,114,116,104,32,98,97,110,100,45,112,97,115,115,32,102,105,108,116,101,114,46,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,49,0,0,0,0,0,0,98,117,102,102,101,114,32,101,114,114,111,114,0,0,0,0,82,77,83,32,108,101,118,101,108,32,100,66,58,32,37,102,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,55,0,37,45,51,50,115,32,35,82,82,71,71,66,66,10,0,0,78,79,80,84,83,0,0,0,89,69,83,0,0,0,0,0,105,110,118,97,108,105,100,32,115,116,111,114,101,100,32,98,108,111,99,107,32,108,101,110,103,116,104,115,0,0,0,0,112,97,100,32,108,97,115,116,32,102,114,97,109,101,32,119,105,116,104,32,122,101,114,111,115,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,115,101,116,32,111,117,116,112,117,116,32,103,97,105,110,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,54,0,97,118,111,105,100,95,110,101,103,97,116,105,118,101,95,116,115,0,0,0,0,0,0,0,119,104,111,108,101,95,108,101,110,0,0,0,0,0,0,0,79,80,65,116,111,109,0,0,105,110,112,117,116,115,0,0,113,117,101,117,101,45,62,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,53,0,109,105,110,95,102,114,97,103,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,116,114,101,120,10,0,0,0,0,0,0,121,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,111,117,116,0,0,0,0,0,110,98,95,101,99,104,111,101,115,58,37,100,10,0,0,0,40,37,100,41,0,0,0,0,68,101,108,97,121,32,109,117,115,116,32,98,101,32,110,111,110,32,110,101,103,97,116,105,118,101,32,110,117,109,98,101,114,46,10,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,52,0,100,101,102,97,117,108,116,0,116,111,116,97,108,95,115,105,122,101,61,78,47,65,10,0,116,112,95,111,114,105,103,32,61,61,32,42,116,112,0,0,115,101,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,0,0,0,109,98,109,105,45,62,114,101,102,95,102,114,97,109,101,91,48,93,32,61,61,32,118,112,57,95,103,101,116,95,115,101,103,100,97,116,97,40,38,99,109,45,62,115,101,103,44,32,115,101,103,109,101,110,116,95,105,100,44,32,83,69,71,95,76,86,76,95,82,69,70,95,70,82,65,77,69,41,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,51,0,71,101,110,101,114,97,116,101,32,116,101,115,116,32,112,97,116,116,101,114,110,46,0,0,109,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,117,118,95,109,111,100,101,44,32,122,101,114,111,95,99,111,117,110,116,115,46,117,118,95,109,111,100,101,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,117,118,95,109,111,100,101,41,41,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,50,0,102,111,114,109,97,116,0,0,115,101,116,32,102,114,97,109,101,32,114,97,116,101,0,0,115,58,37,100,120,37,100,32,114,58,37,100,47,37,100,32,114,117,108,101,58,37,115,32,115,116,97,121,95,114,117,108,101,58,37,100,32,98,111,114,110,95,114,117,108,101,58,37,100,32,115,116,105,116,99,104,58,37,100,32,115,101,101,100,58,37,117,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,115,107,97,95,122,111,110,101,95,49,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,119,105,100,116,104,32,105,115,32,37,100,32,119,104,105,99,104,32,99,97,110,110,111,116,32,99,111,110,116,97,105,110,32,116,104,101,32,112,114,111,118,105,100,101,100,32,115,116,114,105,110,103,32,119,105,100,116,104,32,111,102,32,37,100,10,0,115,97,114,0,0,0,0,0,33,40,108,102,109,45,62,108,101,102,116,95,117,118,91,84,88,95,56,88,56,93,32,38,32,108,102,109,45,62,108,101,102,116,95,117,118,91,84,88,95,52,88,52,93,41,0,0,115,101,110,100,32,111,110,101,32,102,114,97,109,101,32,102,111,114,32,101,97,99,104,32,102,105,101,108,100,0,0,0,115,112,101,99,105,102,121,32,119,104,105,99,104,32,102,114,97,109,101,115,32,116,111,32,100,101,105,110,116,101,114,108,97,99,101,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,98,97,109,97,95,87,101,115,116,0,0,115,101,116,32,116,104,101,32,97,114,101,97,32,99,111,109,98,105,110,103,32,116,104,114,101,115,104,111,108,100,32,117,115,101,100,32,102,111,114,32,99,111,109,98,101,100,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,0,0,79,112,101,110,67,76,58,32,37,115,10,0,0,0,0,0,110,0,0,0,0,0,0,0,121,117,118,52,50,50,112,49,48,108,101,0,0,0,0,0,76,97,118,101,110,100,101,114,0,0,0,0,0,0,0,0,68,66,76,95,77,65,88,0,55,46,48,0,0,0,0,0,114,109,118,111,108,0,0,0,46,116,101,109,112,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,102,102,109,112,101,103,95,102,105,108,116,101,114,46,99,0,115,101,116,32,108,117,109,97,32,109,97,116,114,105,120,32,118,101,114,116,105,99,97,108,32,115,105,122,101,0,0,0,44,32,37,115,0,0,0,0,80,67,83,95,78,65,68,56,51,95,65,108,97,98,97,109,97,95,69,97,115,116,0,0,71,67,83,95,65,71,68,54,54,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,99,113,109,56,0,0,0,0,112,99,109,95,115,51,50,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,114,111,116,97,116,101,32,99,108,111,99,107,119,105,115,101,0,0,0,0,0,0,0,0,97,108,108,111,119,32,110,111,110,45,115,112,101,99,45,99,111,109,112,108,105,97,110,116,32,115,112,101,101,100,117,112,32,116,114,105,99,107,115,0,72,46,50,54,51,43,32,47,32,72,46,50,54,51,45,49,57,57,56,32,47,32,72,46,50,54,51,32,118,101,114,115,105,111,110,32,50,0,0,0,105,108,108,101,103,97,108,32,100,99,32,118,108,99,10,0,118,98,118,95,100,101,108,97,121,32,37,100,44,32,114,101,102,32,37,100,32,116,121,112,101,58,37,100,10,0,0,0,65,80,80,120,32,40,37,115,32,47,32,37,56,88,41,32,108,101,110,61,37,100,10,0,76,111,111,112,32,102,105,108,116,101,114,32,112,97,114,97,109,101,116,101,114,115,44,32,105,110,32,60,97,108,112,104,97,58,98,101,116,97,62,32,102,111,114,109,46,0,0,0,50,32,112,97,115,115,32,114,97,116,101,32,99,111,110,116,114,111,108,32,115,101,116,116,105,110,103,115,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,0,0,0,100,114,111,112,32,101,118,101,110,32,102,105,101,108,100,115,0,0,0,0,0,0,0,0,70,111,117,110,100,32,114,101,102,101,114,101,110,99,101,32,97,110,100,32,110,111,110,45,114,101,102,101,114,101,110,99,101,32,102,105,101,108,100,115,32,105,110,32,116,104,101,32,115,97,109,101,32,102,114,97,109,101,44,32,119,104,105,99,104,0,0,0,0,0,0,0,109,100,101,99,0,0,0,0,110,98,95,102,114,97,109,101,115,0,0,0,0,0,0,0,65,99,105,100,32,74,97,122,122,0,0,0,0,0,0,0,32,67,52,52,52,112,49,50,32,88,89,83,67,83,83,61,52,52,52,80,49,50,0,0,48,0,0,0,0,0,0,0,102,114,97,109,101,32,105,100,32,35,37,100,32,40,112,116,115,95,116,105,109,101,61,37,102,41,32,115,101,108,101,99,116,101,100,32,102,114,111,109,32,97,32,115,101,116,32,111,102,32,37,100,32,105,109,97,103,101,115,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,50,51,78,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,32,111,114,32,99,111,114,114,117,112,116,32,112,97,114,116,105,116,105,111,110,32,0,0,102,105,101,108,100,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,111,111,108,32,100,101,99,111,100,101,114,32,37,100,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,32,37,99,37,99,37,99,32,37,45,49,54,115,32,37,45,49,48,115,32,37,115,10,0,35,69,88,84,45,88,45,65,76,76,79,87,45,67,65,67,72,69,58,37,115,10,0,0,97,98,111,118,101,32,98,101,108,111,119,32,104,97,108,102,32,104,101,105,103,104,116,32,114,105,103,104,116,32,102,105,114,115,116,0,0,0,0,0,102,111,114,99,101,32,97,32,99,111,110,115,116,97,110,116,32,113,117,97,110,116,105,122,101,114,32,112,97,114,97,109,101,116,101,114,0,0,0,0,115,101,116,32,108,117,109,97,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,37,46,54,103,0,0,0,0,109,97,116,114,111,115,107,97,44,119,101,98,109,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,117,115,101,32,119,97,108,108,99,108,111,99,107,32,97,115,32,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,109,97,114,107,32,97,115,32,98,111,116,116,111,109,45,102,105,101,108,100,45,102,105,114,115,116,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,102,111,117,114,99,99,32,108,101,110,103,116,104,32,37,100,10,0,0,0,79,80,49,97,0,0,0,0,109,52,118,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,105,119,0,0,0,0,0,0,77,97,120,105,109,117,109,32,102,114,97,103,109,101,110,116,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,119,114,111,110,103,32,99,104,117,110,107,32,99,111,117,110,116,32,37,100,10,0,0,0,115,101,116,32,108,117,109,97,32,112,114,101,45,102,105,108,116,101,114,32,114,97,100,105,117,115,0,0,0,0,0,0,78,111,32,119,97,118,32,99,111,100,101,99,32,116,97,103,32,102,111,117,110,100,32,102,111,114,32,99,111,100,101,99,32,37,115,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,105,110,95,104,0,0,0,0,84,67,79,0,0,0,0,0,116,105,109,101,100,32,73,68,51,32,109,101,116,97,100,97,116,97,0,0,0,0,0,0,102,0,0,0,0,0,0,0,98,105,116,114,97,116,101,61,37,54,46,49,102,107,98,105,116,115,47,115,0,0,0,0,115,101,116,32,116,111,112,32,106,117,110,107,32,115,105,122,101,0,0,0,0,0,0,0,108,120,102,0,0,0,0,0,108,97,118,102,105,46,112,115,110,114,46,112,115,110,114,46,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,118,102,0,0,0,0,0,116,105,109,101,100,95,105,100,51,0,0,0,0,0,0,0,116,111,112,32,102,105,114,115,116,0,0,0,0,0,0,0,108,111,97,115,0,0,0,0,109,98,109,105,45,62,114,101,102,95,102,114,97,109,101,91,48,93,32,61,61,32,76,65,83,84,95,70,82,65,77,69,0,0,0,0,0,0,0,0,120,49,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,108,109,108,109,52,0,0,0,68,86,68,32,78,97,118,32,112,97,99,107,101,116,0,0,115,101,116,32,116,104,101,32,112,97,100,32,97,114,101,97,32,104,101,105,103,104,116,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,112,105,120,101,108,32,102,111,114,109,97,116,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,99,104,114,111,109,97,95,115,116,114,101,110,103,116,104,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,87,0,0,0,0,0,0,0,100,118,100,95,110,97,118,95,112,97,99,107,101,116,0,0,99,109,45,62,98,105,116,95,100,101,112,116,104,32,61,61,32,66,73,84,83,95,56,0,97,0,0,0,0,0,0,0,108,97,116,109,0,0,0,0,97,108,108,95,102,108,97,103,115,0,0,0,0,0,0,0,108,111,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,83,77,80,84,69,32,51,51,54,77,32,75,101,121,45,76,101,110,103,116,104,45,86,97,108,117,101,32,40,75,76,86,41,32,109,101,116,97,100,97,116,97,0,0,0,0,0,0,99,116,104,114,101,115,104,0,65,68,76,95,80,111,119,101,114,88,112,114,101,115,115,95,83,99,104,101,109,101,95,71,101,116,0,0,0,0,0,0,118,102,45,62,104,32,62,32,48,0,0,0,0,0,0,0,121,117,118,52,50,50,112,49,48,98,101,0,0,0,0,0,75,104,97,107,105,0,0,0,45,70,76,84,95,77,73,78,0,0,0,0,0,0,0,0,106,118,0,0,0,0,0,0,54,46,49,40,102,114,111,110,116,41,0,0,0,0,0,0,115,101,116,32,76,70,69,32,109,105,120,32,108,101,118,101,108,0,0,0,0,0,0,0,105,110,37,100,0,0,0,0,115,116,97,116,105,115,116,105,99,115,32,97,114,101,32,100,97,109,97,103,101,100,32,97,116,32,108,105,110,101,32,37,100,44,32,112,97,114,115,101,114,32,111,117,116,61,37,100,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,46,46,80,67,77,0,0,0,101,120,116,114,97,95,115,108,111,119,0,0,0,0,0,0,32,40,37,115,32,47,32,48,120,37,48,52,88,41,0,0,107,108,118,0,0,0,0,0,71,67,83,95,65,100,105,110,100,97,110,0,0,0,0,0,114,101,112,101,97,116,32,108,97,115,116,32,98,111,116,116,111,109,32,102,114,97,109,101,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,108,102,109,118,0,0,0,0,106,97,99,111,115,117,98,0,99,113,109,52,0,0,0,0,102,97,115,116,0,0,0,0,104,50,54,51,112,0,0,0,100,99,32,111,118,101,114,102,108,111,119,32,97,116,32,37,100,120,37,100,10,0,0,0,112,114,111,102,105,108,101,58,32,37,100,44,32,108,101,118,101,108,58,32,37,100,32,112,115,58,32,37,100,32,99,102,58,37,100,32,118,98,118,32,98,117,102,102,101,114,58,32,37,100,44,32,98,105,116,114,97,116,101,58,37,100,10,0,77,101,116,97,115,111,102,116,32,77,74,80,69,71,32,67,111,100,101,99,0,0,0,0,100,101,98,108,111,99,107,0,114,99,95,98,117,102,95,111,112,116,105,109,97,108,95,115,122,58,0,0,0,0,0,0,99,111,110,116,105,110,117,101,32,97,112,112,108,121,105,110,103,32,116,104,101,32,108,97,115,116,32,99,108,117,116,32,97,102,116,101,114,32,101,111,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,105,101,108,100,32,109,111,100,101,32,99,111,109,98,105,110,97,116,105,111,110,32,37,100,47,37,100,10,0,0,0,67,105,114,114,117,115,32,76,111,103,105,99,32,65,99,99,117,80,97,107,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,65,99,105,100,32,80,117,110,107,0,0,0,0,0,0,0,32,67,52,50,50,112,49,50,32,88,89,83,67,83,83,61,52,50,50,80,49,50,0,0,67,111,100,101,99,32,100,111,101,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,32,114,101,113,117,101,115,116,101,100,32,99,97,112,97,98,105,108,105,116,121,0,0,0,37,89,32,45,32,37,109,32,45,32,37,100,84,37,72,58,37,77,58,37,83,0,0,0,105,67,69,68,114,97,119,32,116,101,120,116,0,0,0,0,78,101,103,97,116,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,115,101,116,32,116,104,101,32,111,114,100,101,114,0,0,0,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,105,0,0,0,0,0,0,0,103,95,112,114,111,102,105,108,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,51,93,0,0,0,0,105,100,102,0,0,0,0,0,102,109,116,0,0,0,0,0,35,69,88,84,45,88,45,77,69,68,73,65,45,83,69,81,85,69,78,67,69,58,37,100,10,0,0,0,0,0,0,0,115,101,116,32,112,114,111,103,114,101,115,115,105,118,101,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,106,97,99,111,115,117,98,0,110,0,0,0,0,0,0,0,103,95,112,114,111,102,105,108,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,51,93,0,0,0,0,108,117,109,97,95,116,109,112,0,0,0,0,0,0,0,0,98,121,116,101,115,32,60,32,80,65,71,69,95,76,79,67,75,69,68,95,66,85,70,95,83,73,90,69,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,101,88,116,101,110,100,101,100,32,66,73,78,97,114,121,32,116,101,120,116,0,0,0,0,117,115,101,95,119,97,108,108,99,108,111,99,107,95,97,115,95,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,108,101,118,101,108,115,0,0,105,118,102,0,0,0,0,0,97,110,116,105,98,97,110,100,105,110,103,0,0,0,0,0,115,116,114,101,97,109,32,104,101,97,100,101,114,32,37,100,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,34,79,80,65,116,111,109,34,32,119,105,116,104,32,37,117,32,69,67,115,32,45,32,97,115,115,117,109,105,110,103,32,37,115,10,0,0,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,114,40,88,44,89,41,0,0,105,118,102,0,0,0,0,0,120,98,105,110,0,0,0,0,66,45,114,101,102,32,97,116,32,102,114,97,109,101,32,37,100,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,66,45,112,121,114,97,109,105,100,32,37,115,32,97,110,100,32,37,100,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,10,0,0,0,0,0,0,0,102,114,97,103,95,100,117,114,97,116,105,111,110,0,0,0,101,114,114,111,114,32,117,110,97,108,105,103,110,101,100,32,99,104,117,110,107,10,0,0,86,105,101,119,115,32,97,114,101,32,112,97,99,107,101,100,32,111,110,32,116,111,112,32,111,102,32,101,97,99,104,32,111,116,104,101,114,0,0,0,78,111,32,98,109,112,32,99,111,100,101,99,32,116,97,103,32,102,111,117,110,100,32,102,111,114,32,99,111,100,101,99,32,37,115,10,0,0,0,0,73,78,84,82,65,56,88,56,95,76,85,77,65,0,0,0,65,115,115,117,109,101,32,116,104,101,32,102,105,114,115,116,32,80,84,83,32,115,104,111,117,108,100,32,98,101,32,116,104,105,115,32,118,97,108,117,101,46,0,0,0,0,0,0,70,111,114,109,97,116,32,110,97,109,101,32,116,111,111,32,108,111,110,103,10,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,57,78,0,0,0,105,118,56,0,0,0,0,0,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,102,114,97,109,101,32,37,115,44,32,115,107,105,112,112,101,100,10,0,0,0,0,0,0,0,0,66,105,110,97,114,121,32,116,101,120,116,0,0,0,0,0,98,105,116,114,97,116,101,61,78,47,65,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,56,78,0,0,0,102,109,45,62,112,114,118,32,38,38,32,102,109,45,62,115,114,99,32,38,38,32,102,109,45,62,110,120,116,0,0,0,105,115,115,0,0,0,0,0,99,108,67,114,101,97,116,101,80,114,111,103,114,97,109,87,105,116,104,66,105,110,97,114,121,0,0,0,0,0,0,0,98,105,110,116,101,120,116,0,98,111,116,116,111,109,0,0,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,68,114,111,112,32,102,114,97,109,101,32,105,115,32,111,110,108,121,32,97,108,108,111,119,101,100,32,119,105,116,104,32,51,48,48,48,48,47,49,48,48,49,32,111,114,32,54,48,48,48,48,47,49,48,48,49,32,70,80,83,10,0,0,0,121,117,118,52,49,49,112,0,116,121,112,101,0,0,0,0,117,110,100,0,0,0,0,0,73,110,118,97,108,105,100,32,97,108,112,104,97,32,118,97,108,117,101,32,115,112,101,99,105,102,105,101,114,32,39,37,115,39,32,105,110,32,39,37,115,39,10,0,0,0,0,0,102,108,97,103,115,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,55,78,0,0,0,84,69,82,77,0,0,0,0,73,110,112,117,116,32,112,105,99,116,117,114,101,32,119,105,100,116,104,32,40,37,100,41,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,115,116,114,105,100,101,32,40,37,100,41,10,0,0,0,83,72,65,50,50,52,0,0,110,0,0,0,0,0,0,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,0,70,73,76,69,0,0,0,0,115,99,97,108,101,0,0,0,116,97,110,104,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,0,0,0,0,0,0,0,0,105,114,99,97,109,0,0,0,70,82,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,108,97,110,97,114,32,82,71,66,32,99,111,110,118,101,114,115,105,111,110,32,37,115,32,45,62,32,37,115,10,0,0,0,0,0,37,100,120,37,100,32,45,62,32,37,100,120,37,100,32,105,115,32,105,110,118,97,108,105,100,32,115,99,97,108,105,110,103,32,100,105,109,101,110,115,105,111,110,10,0,0,0,0,87,97,114,110,105,110,103,58,32,100,115,116,83,116,114,105,100,101,32,105,115,32,110,111,116,32,97,108,105,103,110,101,100,33,10,32,32,32,32,32,32,32,32,32,45,62,99,97,110,110,111,116,32,100,111,32,97,108,105,103,110,101,100,32,109,101,109,111,114,121,32,97,99,99,101,115,115,101,115,32,97,110,121,109,111,114,101,10,0,0,0,0,0,0,0,0,68,80,66,32,115,105,122,101,32,40,37,100,32,102,114,97,109,101,115,44,32,37,100,32,109,98,115,41,32,62,32,108,101,118,101,108,32,108,105,109,105,116,32,40,37,100,32,102,114,97,109,101,115,44,32,37,100,32,109,98,115,41,10,0,101,120,112,101,114,105,109,101,110,116,97,108,0,0,0,0,121,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,54,78,0,0,0,105,115,114,0,0,0,0,0,37,102,32,0,0,0,0,0,105,114,99,97,109,0,0,0,112,112,58,32,111,112,116,105,111,110,58,32,37,115,10,0,119,101,98,118,116,116,0,0,111,104,0,0,0,0,0,0,120,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,97,120,118,97,108,58,32,37,100,10,0,0,0,0,0,115,45,62,117,118,108,105,110,101,115,105,122,101,32,61,61,32,99,45,62,117,118,115,116,114,105,100,101,0,0,0,0,105,112,109,111,118,105,101,0,120,58,37,100,32,121,58,37,100,44,32,119,58,37,100,32,104,58,37,100,32,98,97,110,100,58,37,100,32,115,104,111,119,58,37,100,10,0,0,0,99,111,110,99,101,97,108,105,110,103,32,37,100,32,68,67,44,32,37,100,32,65,67,44,32,37,100,32,77,86,32,101,114,114,111,114,115,32,105,110,32,37,99,32,102,114,97,109,101,10,0,0,0,0,0,0,110,101,120,116,61,37,108,108,100,44,32,110,101,119,61,37,108,108,100,10,0,0,0,0,84,114,121,105,110,103,32,116,111,32,114,101,109,111,118,101,32,37,100,32,109,111,114,101,32,115,97,109,112,108,101,115,32,116,104,97,110,32,116,104,101,114,101,32,97,114,101,32,105,110,32,116,104,101,32,113,117,101,117,101,10,0,0,0,83,70,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,112,111,115,61,37,100,44,32,118,97,108,61,37,100,33,10,0,92,37,49,91,49,50,51,52,93,99,38,72,37,88,38,37,49,91,92,125,93,37,110,0,92,78,0,0,0,0,0,0,98,112,115,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,58,32,37,100,10,0,73,110,118,97,108,105,100,32,118,101,114,115,105,111,110,32,37,100,10,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,53,78,0,0,0,65,68,80,67,77,32,83,104,111,99,107,119,97,118,101,32,70,108,97,115,104,0,0,0,32,115,99,0,0,0,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,68,84,75,0,0,0,0,0,86,80,108,97,121,101,114,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,105,110,103,101,110,105,101,110,116,0,0,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,98,108,111,99,107,32,111,118,101,114,108,97,112,112,105,110,103,32,112,105,120,101,108,115,0,0,112,101,114,95,102,114,97,109,101,95,109,101,116,97,100,97,116,97,0,0,0,0,0,0,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,116,111,111,32,115,109,97,108,108,44,32,117,115,105,110,103,32,46,48,49,10,0,112,101,114,95,102,114,97,109,101,95,109,101,116,97,100,97,116,97,0,0,0,0,0,0,109,105,120,105,110,103,95,108,101,118,101,108,32,109,117,115,116,32,98,101,32,115,101,116,32,105,102,32,114,111,111,109,95,116,121,112,101,32,105,115,32,115,101,116,10,0,0,0,112,101,114,99,101,110,116,97,103,101,32,111,102,32,100,121,110,97,109,105,99,32,114,97,110,103,101,32,99,111,109,112,114,101,115,115,105,111,110,32,116,111,32,97,112,112,108,121,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,99,97,108,99,117,108,97,116,101,32,112,47,99,47,110,47,117,47,98,0,0,0,0,0,65,68,76,95,65,100,97,112], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2156704);
/* memory initializer */ allocate([116,101,114,95,78,117,109,98,101,114,79,102,65,100,97,112,116,101,114,115,95,71,101,116,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,0,0,0,121,117,118,52,50,48,112,49,48,108,101,0,0,0,0,0,73,118,111,114,121,0,0,0,45,70,76,84,95,77,65,88,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,105,110,100,101,120,32,37,100,10,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,101,120,116,114,97,100,97,116,97,46,10,0,0,0,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,101,109,112,116,121,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,0,54,46,49,0,0,0,0,0,108,102,101,95,109,105,120,95,108,101,118,101,108,0,0,0,99,102,114,109,32,105,110,32,118,101,114,115,105,111,110,32,37,100,10,0,0,0,0,0,49,46,50,46,53,0,0,0,73,110,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,119,58,37,104,100,44,37,104,100,44,37,104,100,44,37,104,100,44,37,104,100,44,37,104,100,44,37,104,100,44,37,104,100,0,0,0,0,0,0,0,80,97,108,101,116,116,101,32,112,97,114,97,109,101,116,101,114,115,32,105,110,118,97,108,105,100,44,32,104,101,97,100,101,114,32,112,114,111,98,97,98,108,121,32,99,111,114,114,117,112,116,10,0,0,0,0,117,110,107,110,111,119,110,32,88,65,45,65,68,80,67,77,32,102,105,108,116,101,114,32,37,100,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,105,110,118,97,108,105,100,32,99,111,114,114,101,99,116,105,111,110,32,98,108,111,99,107,32,112,111,115,105,116,105,111,110,10,0,0,0,0,0,105,110,118,97,108,105,100,32,112,105,120,109,97,112,32,102,111,114,109,97,116,10,0,0,84,105,109,101,32,99,111,100,101,32,62,61,32,49,48,48,32,104,111,117,114,115,46,10,0,0,0,0,0,0,0,0,32,125,59,10,0,0,0,0,85,110,107,110,111,119,110,32,100,101,102,105,110,101,32,39,37,115,39,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,52,78,0,0,0,79,118,101,114,108,97,112,112,105,110,103,32,99,111,112,121,10,0,0,0,0,0,0,0,73,49,54,46,46,52,37,115,58,32,37,52,46,49,102,37,37,32,37,52,46,49,102,37,37,32,37,52,46,49,102,37,37,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,56,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,10,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,105,110,116,114,97,32,98,108,111,99,107,58,32,37,100,32,120,32,37,100,32,40,37,100,41,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,119,109,97,118,111,105,99,101,46,99,0,0,0,32,40,37,115,41,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,87,97,105,116,105,110,103,32,102,111,114,32,115,101,101,107,97,98,108,101,32,116,105,108,101,10,0,0,0,0,0,0,40,112,117,116,95,98,105,116,115,95,99,111,117,110,116,40,38,115,45,62,112,98,41,32,38,32,55,41,32,61,61,32,48,0,0,0,0,0,0,0,118,112,108,97,121,101,114,0,73,110,118,97,108,105,100,32,108,97,115,116,32,102,114,97,109,101,32,98,105,116,32,111,102,102,115,101,116,32,37,100,32,62,32,98,117,102,32,115,105,122,101,32,37,100,32,40,37,100,41,10,0,0,0,0,65,110,103,117,108,97,114,95,68,77,83,95,72,101,109,105,115,112,104,101,114,101,0,0,114,101,112,101,97,116,108,97,115,116,0,0,0,0,0,0,60,47,105,62,0,0,0,0,73,103,110,111,114,105,110,103,32,101,120,116,114,97,32,69,88,73,70,32,99,104,117,110,107,10,0,0,0,0,0,0,106,111,105,110,116,95,115,116,101,114,101,111,0,0,0,0,114,101,115,101,116,0,0,0,77,105,115,109,97,116,99,104,105,110,103,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,105,110,32,97,32,115,101,113,117,101,110,99,101,58,32,37,100,32,97,110,100,32,37,100,10,0,99,113,109,102,105,108,101,0,112,114,111,98,108,101,109,58,32,110,111,32,86,80,84,90,32,99,104,117,110,107,32,102,111,117,110,100,10,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,98,105,116,115,116,114,101,97,109,32,114,101,97,100,101,114,10,0,0,85,112,115,99,97,108,105,110,103,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,79,117,116,112,117,116,32,101,118,101,110,32,112,111,116,101,110,116,105,97,108,108,121,32,99,111,114,114,117,112,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,72,46,50,54,51,32,47,32,72,46,50,54,51,45,49,57,57,54,0,0,0,0,0,0,68,97,116,97,32,112,97,99,107,101,116,32,119,105,116,104,111,117,116,32,112,114,105,111,114,32,118,97,108,105,100,32,104,101,97,100,101,114,115,10,0,0,0,0,0,0,0,0,100,99,60,48,32,97,116,32,37,100,120,37,100,10,0,0,115,100,101,32,119,58,37,100,44,32,104,58,37,100,10,0,114,99,45,62,116,121,112,101,32,61,61,32,48,32,124,124,32,114,99,45,62,116,121,112,101,32,61,61,32,50,0,0,73,110,116,101,108,40,82,41,32,74,80,69,71,32,76,105,98,114,97,114,121,44,32,118,101,114,115,105,111,110,32,49,0,0,0,0,0,0,0,0,109,111,100,101,95,110,117,109,98,101,114,0,0,0,0,0,85,115,101,32,109,97,99,114,111,98,108,111,99,107,32,116,114,101,101,32,114,97,116,101,99,111,110,116,114,111,108,46,0,0,0,0,0,0,0,0,114,99,95,98,117,102,95,105,110,105,116,105,97,108,95,115,122,58,0,0,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,98,105,103,101,110,100,105,97,110,32,102,108,97,103,32,61,32,37,105,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,111,100,100,32,100,105,109,101,110,115,105,111,110,115,32,40,37,100,32,120,32,37,100,41,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,0,117,110,115,101,116,32,99,117,114,95,112,105,99,95,112,116,114,32,111,110,32,115,108,105,99,101,32,37,100,10,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,32,73,109,97,103,101,32,118,50,0,0,115,101,116,32,116,104,101,32,104,101,105,103,104,116,32,99,114,111,112,32,97,114,101,97,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,82,65,78,71,69,82,69,68,32,115,104,111,117,108,100,32,98,101,32,115,101,116,32,116,111,32,48,32,105,110,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,10,0,0,99,108,106,114,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,32,37,115,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,84,77,95,122,111,110,101,95,51,78,0,0,0,84,114,105,98,97,108,0,0,67,117,115,116,111,109,32,86,50,49,48,32,115,116,114,105,100,101,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,32,67,52,50,48,112,49,50,32,88,89,83,67,83,83,61,52,50,48,80,49,50,0,0,100,115,116,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,37,89,32,45,32,37,109,32,45,32,37,100,32,37,72,58,37,77,58,37,83,0,0,0,83,117,98,86,105,101,119,101,114,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,114,101,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,86,81,70,32,84,119,105,110,86,81,32,115,104,111,117,108,100,32,104,97,118,101,32,111,110,108,121,32,111,110,101,32,102,114,97,109,101,32,112,101,114,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,114,97,116,101,10,0,0,0,0,0,84,111,111,32,102,101,119,32,115,108,105,99,101,32,112,114,111,112,101,114,116,105,101,115,32,40,37,100,32,47,32,37,100,41,10,0,0,0,0,0,67,97,109,116,97,115,105,97,32,101,114,114,111,114,58,32,117,110,107,110,111,119,110,32,100,101,112,116,104,32,37,105,32,98,112,112,10,0,0,0,115,101,116,32,116,104,101,32,98,108,117,101,32,103,97,105,110,32,102,111,114,32,116,104,101,32,114,101,100,32,99,104,97,110,110,101,108,0,0,0,82,101,97,100,32,116,111,107,101,110,32,102,114,111,109,32,115,116,114,101,97,109,32,37,105,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,37,105,62,61,37,105,41,10,0,0,0,0,0,0,0,70,114,97,109,101,32,119,105,116,104,32,115,112,114,105,116,101,0,0,0,0,0,0,0,115,45,62,110,117,109,95,101,110,116,114,105,101,115,32,60,32,51,50,0,0,0,0,0,115,101,116,32,98,108,117,101,32,115,104,97,100,111,119,115,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,95,77,105,99,104,105,103,97,110,95,77,105,99,104,105,103,97,110,95,87,101,115,116,0,0,105,109,97,103,101,50,0,0,115,117,98,118,105,101,119,101,114,0,0,0,0,0,0,0,102,111,114,99,101,32,102,111,114,109,97,116,0,0,0,0,108,117,109,97,95,112,111,119,101,114,0,0,0,0,0,0,35,69,88,84,45,88,45,86,69,82,83,73,79,78,58,51,10,0,0,0,0,0,0,0,71,101,111,103,76,105,110,101,97,114,85,110,105,116,115,71,101,111,75,101,121,0,0,0,73,109,97,103,101,32,100,97,116,97,32,105,115,32,109,105,115,115,105,110,103,10,0,0,83,117,98,86,105,101,119,101,114,49,32,115,117,98,116,105,116,108,101,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,116,111,32,114,101,97,100,32,112,97,108,101,116,116,101,10,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,47,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,10,0,0,102,114,97,109,101,32,110,117,109,32,37,100,32,108,101,102,116,32,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,115,118,113,49,101,110,99,46,99,0,0,0,0,114,108,101,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,40,99,111,109,112,114,101,115,115,105,111,110,41,32,116,121,112,101,10,0,13,10,13,10,0,0,0,0,123,92,97,110,49,125,123,92,109,111,118,101,40,37,100,44,37,100,44,37,100,44,37,100,41,125,0,0,0,0,0,0,83,111,110,105,99,58,32,118,101,114,58,32,37,100,46,37,100,32,108,115,58,32,37,100,32,100,114,58,32,37,100,32,116,97,112,115,58,32,37,100,32,98,108,111,99,107,58,32,37,100,32,102,114,97,109,101,58,32,37,100,32,100,111,119,110,115,97,109,112,58,32,37,100,10,0,0,0,0,0,0,98,45,62,112,97,114,101,110,116,61,61,48,76,32,124,124,32,98,45,62,112,97,114,101,110,116,45,62,115,116,114,105,100,101,32,61,61,32,98,45,62,115,116,114,105,100,101,42,50,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,32,115,117,98,115,97,109,112,108,101,32,109,111,100,101,32,37,100,32,37,100,10,0,77,74,80,69,71,32,99,111,100,101,99,32,102,97,105,108,101,100,32,116,111,32,111,112,101,110,10,0,0,0,0,0,48,120,70,48,32,111,112,99,111,100,101,0,0,0,0,0,99,104,97,110,110,101,108,115,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,95,97,108,105,103,110,58,32,37,100,46,32,77,111,100,101,32,37,115,32,103,117,101,115,115,101,100,32,98,97,115,101,100,32,111,110,32,98,105,116,114,97,116,101,58,32,37,100,10,0,0,105,110,118,97,108,105,100,32,112,114,101,100,95,111,114,100,101,114,32,37,100,10,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,99,111,117,110,116,46,10,0,0,0,80,67,83,95,78,65,68,95,77,105,99,104,105,103,97,110,95,77,105,99,104,105,103,97,110,95,79,108,100,95,67,101,110,116,114,97,108,0,0,0,115,117,98,99,111,100,101,99,32,37,100,0,0,0,0,0,38,110,98,115,112,59,0,0,102,54,52,98,101,32,100,101,109,117,120,101,114,0,0,0,83,108,105,99,101,32,116,121,112,101,32,109,105,115,109,97,116,99,104,10,0,0,0,0,73,110,99,111,114,114,101,99,116,32,105,110,116,114,97,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,10,0,0,0,0,0,0,0,0,115,45,62,108,111,111,112,95,102,105,108,116,101,114,61,61,49,0,0,0,0,0,0,0,80,79,83,32,69,82,82,79,82,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,83,72,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,87,104,101,116,104,101,114,32,116,111,32,114,101,115,112,101,99,116,32,107,110,111,119,110,32,108,105,109,105,116,97,116,105,111,110,115,32,105,110,32,81,117,97,107,101,32,51,32,100,101,99,111,100,101,114,0,68,105,109,101,110,115,105,111,110,115,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,49,54,10,0,0,0,0,83,117,98,86,105,101,119,101,114,32,118,49,32,115,117,98,116,105,116,108,101,0,0,0,99,111,110,115,105,100,101,114,32,116,104,105,110,103,115,32,116,104,97,116,32,97,32,115,97,110,101,32,101,110,99,111,100,101,114,32,115,104,111,117,108,100,110,39,116,32,100,111,32,97,115,32,97,110,32,101,114,114,111,114,0,0,0,0,102,67,111,100,101,0,0,0,100,101,102,97,117,108,116,0,83,105,114,44,32,73,32,103,111,116,32,99,97,114,115,105,99,107,32,105,110,32,121,111,117,114,32,111,102,102,105,99,101,46,32,78,111,116,32,100,101,99,111,100,105,110,103,32,116,104,101,32,114,101,115,116,32,111,102,32,112,97,99,107,101,116,46,10,0,0,0,0,98,97,100,32,115,117,112,101,114,98,108,111,99,107,32,116,121,112,101,10,0,0,0,0,66,97,100,108,121,32,114,101,99,101,105,118,101,100,32,112,97,99,107,101,116,115,32,105,110,32,102,114,97,109,101,46,0,0,0,0,0,0,0,0,112,114,111,102,105,108,101,32,37,100,44,32,37,100,32,115,108,105,99,101,115,44,32,105,110,116,101,114,108,97,99,105,110,103,58,32,37,115,44,32,37,100,32,98,105,116,115,32,112,101,114,32,77,66,10,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,99,104,97,110,110,101,108,115,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,102,114,97,109,101,32,119,105,100,116,104,32,110,101,101,100,115,32,116,111,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,50,10,0,0,112,105,99,95,116,104,0,0,117,110,115,117,112,112,111,114,116,101,100,32,115,108,105,99,101,32,100,105,109,101,110,115,105,111,110,58,32,37,100,32,120,32,37,100,10,0,0,0,97,99,32,116,101,120,32,100,97,109,97,103,101,100,32,37,100,44,32,37,100,10,0,0,80,66,77,32,40,80,111,114,116,97,98,108,101,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,80,78,71,32,101,110,99,111,100,101,114,0,0,0,0,0,112,110,103,58,32,116,97,103,61,37,99,37,99,37,99,37,99,32,108,101,110,103,116,104,61,37,117,10,0,0,0,0,80,114,101,118,105,111,117,115,80,97,114,116,105,116,105,111,110,32,112,111,105,110,116,115,32,116,111,32,116,104,105,115,32,112,97,114,116,105,116,105,111,110,32,111,114,32,102,111,114,119,97,114,100,10,0,0,66,105,116,109,97,112,32,100,105,109,101,110,115,105,111,110,115,32,108,97,114,103,101,114,32,116,104,97,110,32,118,105,100,101,111,46,10,0,0,0,105,109,97,103,101,32,100,97,116,97,32,112,111,115,115,105,98,108,121,32,99,111,114,114,117,112,116,101,100,10,0,0,108,97,118,102,105,46,98,98,111,120,46,120,49,0,0,0,112,99,109,95,102,51,50,108,101,0,0,0,0,0,0,0,80,67,77,32,68,86,68,32,117,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,100,101,112,116,104,32,37,105,10,0,0,0,0,114,101,115,101,114,118,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,100,41,10,0,0,0,0,0,0,80,55,10,87,73,68,84,72,32,37,100,10,72,69,73,71,72,84,32,37,100,10,68,69,80,84,72,32,37,100,10,77,65,88,86,65,76,32,37,100,10,84,85,80,76,84,89,80,69,32,37,115,10,69,78,68,72,68,82,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,80,67,83,95,78,65,68,95,77,105,99,104,105,103,97,110,95,77,105,99,104,105,103,97,110,95,69,97,115,116,0,0,114,97,116,105,111,0,0,0,115,117,98,118,105,101,119,101,114,49,0,0,0,0,0,0,109,97,105,110,0,0,0,0,98,97,115,101,108,105,110,101,32,112,114,111,102,105,108,101,32,100,111,101,115,110,39,116,32,115,117,112,112,111,114,116,32,102,97,107,101,32,105,110,116,101,114,108,97,99,105,110,103,10,0,0,0,0,0,0,105,111,100,115,32,118,105,100,101,111,32,112,114,111,102,105,108,101,32,97,116,111,109,46,0,0,0,0,0,0,0,0,119,114,111,110,103,32,115,97,109,112,108,101,32,99,111,117,110,116,10,0,0,0,0,0,117,110,99,111,109,112,114,101,115,115,101,100,32,102,114,97,109,101,32,116,111,111,32,115,104,111,114,116,10,0,0,0,70,105,114,115,116,32,112,105,99,116,117,114,101,32,104,97,115,32,110,111,32,83,79,70,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,68,67,84,32,98,108,111,99,107,32,37,100,44,37,100,10,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,32,37,100,44,37,100,10,0,0,0,0,0,115,116,97,114,116,95,112,116,115,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,0,0,99,111,100,101,99,32,37,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,105,115,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,37,100,32,102,114,101,101,32,99,111,108,111,117,114,40,115,41,10,0,0,0,0,0,0,77,83,32,82,76,69,58,32,102,114,97,109,101,32,112,116,114,32,106,117,115,116,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,114,117,110,41,10,0,0,0,0,0,0,0,0,92,78,0,0,0,0,0,0,85,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,113,112,32,115,101,108,101,99,116,105,111,110,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,111,117,114,105,95,87,101,115,116,0,101,110,99,111,100,105,110,103,32,37,100,32,99,104,97,110,110,101,108,40,115,41,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,0,0,101,110,99,111,100,105,110,103,32,37,100,32,99,104,97,110,110,101,108,40,115,41,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,112,50,10,0,0,0,82,101,97,108,84,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,78,111,32,65,86,70,111,114,109,97,116,67,111,110,116,101,120,116,44,32,115,107,105,112,112,101,100,32,73,68,51,32,99,104,97,112,116,101,114,32,100,97,116,97,10,0,0,0,80,101,114,45,102,105,108,101,32,109,97,105,110,32,111,112,116,105,111,110,115,58,0,0,111,117,116,112,117,116,37,100,0,0,0,0,0,0,0,0,100,97,116,97,95,112,97,114,116,105,116,105,111,110,105,110,103,0,0,0,0,0,0,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,32,0,0,0,0,115,108,105,99,101,32,98,101,108,111,119,32,109,111,110,105,116,111,114,32,46,46,46,10,0,0,0,0,0,0,0,0,83,112,97,116,105,97,108,108,121,32,83,99,97,108,97,98,108,101,0,0,0,0,0,0,100,101,102,97,117,108,116,0,84,111,111,32,115,109,97,108,108,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,40,37,105,41,33,10,0,10,0,0,0,0,0,0,0,73,110,100,105,99,97,116,101,100,32,108,101,110,103,116,104,32,111,102,32,115,117,98,115,116,114,101,97,109,32,37,100,32,100,97,116,97,32,103,111,101,115,32,111,102,102,32,101,110,100,32,111,102,32,112,97,99,107,101,116,46,10,0,0,97,109,118,0,0,0,0,0,99,108,97,115,115,61,37,100,32,105,110,100,101,120,61,37,100,32,110,98,95,99,111,100,101,115,61,37,100,10,0,0,100,113,116,32,111,102,102,115,58,32,48,120,37,120,10,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,111,117,114,105,95,67,101,110,116,114,97,108,0,0,0,0,0,0,78,111,32,115,117,99,104,32,98,97,99,107,114,101,102,101,114,101,110,99,101,33,32,66,117,103,103,121,32,115,97,109,112,108,101,46,10,0,0,0,105,98,117,115,0,0,0,0,93,0,0,0,0,0,0,0,76,79,67,79,32,99,111,100,101,99,32,118,101,114,115,105,111,110,32,37,105,0,0,0,114,101,97,108,116,101,120,116,0,0,0,0,0,0,0,0,116,117,110,101,0,0,0,0,82,97,116,101,32,99,111,110,116,114,111,108,32,112,97,114,97,109,101,116,101,114,115,32,115,101,116,32,119,105,116,104,111,117,116,32,97,32,98,105,116,114,97,116,101,10,0,0,32,32,65,100,100,105,116,105,111,110,97,108,32,105,110,102,111,114,109,97,116,105,111,110,58,32,37,115,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,108,99,108,101,110,99,46,99,0,0,0,0,0,68,101,99,111,100,101,100,32,115,105,122,101,32,100,105,102,102,101,114,115,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,0,0,0,0,0,122,101,114,111,95,114,117,110,95,108,105,110,101,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,106,112,101,103,108,115,0,0,105,109,97,103,101,50,0,0,108,105,98,97,118,102,105,108,116,101,114,47,102,105,102,111,46,99,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,106,112,101,103,50,48,48,48,100,101,99,46,99,0,0,0,0,0,0,0,0,74,82,0,0,0,0,0,0,97,102,116,101,114,32,114,97,116,101,32,99,111,110,116,114,111,108,10,0,0,0,0,0,66,97,110,100,32,98,117,102,102,101,114,32,112,111,105,110,116,115,32,116,111,32,110,111,32,100,97,116,97,33,10,0,116,98,0,0,0,0,0,0,32,65,73,86,0,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,68,10,0,73,110,118,97,108,105,100,32,109,97,114,107,101,114,10,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,111,117,114,105,95,69,97,115,116,0,73,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,33,10,0,0,0,0,73,110,118,97,108,105,100,47,117,110,115,117,112,112,111,114,116,101,100,32,109,118,32,114,101,115,111,108,117,116,105,111,110,58,32,37,100,33,10,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,111,117,116,32,111,102,32,97,114,114,97,121,10,0,0,0,0,0,103,111,116,32,37,88,46,10,0,0,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,101,120,116,114,97,32,112,108,97,110,101,115,32,98,101,121,111,110,100,32,56,10,0,10,0,0,0,0,0,0,0,83,65,77,73,32,115,117,98,116,105,116,108,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,99,97,108,101,114,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,118,112,115,95,109,97,120,95,100,101,99,95,112,105,99,95,98,117,102,102,101,114,105,110,103,95,109,105,110,117,115,49,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,115,101,116,32,99,111,109,109,97,110,100,115,32,102,105,108,101,0,0,0,0,0,0,0,32,33,61,32,0,0,0,0,114,111,119,95,105,110,116,101,114,108,101,97,118,101,100,95,114,108,0,0,0,0,0,0,114,101,102,101,114,101,110,99,101,32,112,105,99,116,117,114,101,32,109,105,115,115,105,110,103,32,100,117,114,105,110,103,32,114,101,111,114,100,101,114,10,0,0,0,0,0,0,0,112,111,99,95,99,121,99,108,101,95,108,101,110,103,116,104,32,111,118,101,114,102,108,111,119,32,37,117,10,0,0,0,114,101,102,101,114,101,110,99,101,32,99,111,117,110,116,32,37,100,32,111,118,101,114,102,108,111,119,10,0,0,0,0,114,101,102,32,37,117,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,0,68,101,99,111,100,105,110,103,32,115,112,115,32,37,100,32,102,114,111,109,32,97,118,99,67,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,69,114,114,111,114,32,97,116,32,77,66,58,32,37,100,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,105,115,115,105,112,112,105,95,87,101,115,116,0,0,0,0,0,0,76,90,87,32,105,110,105,116,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,103,105,102,46,99,0,0,0,0,0,0,0,0,79,110,108,121,32,109,111,110,111,32,115,111,117,110,100,32,105,115,32,115,117,112,112,111,114,116,101,100,32,40,114,101,113,117,101,115,116,101,100,32,99,104,97,110,110,101,108,115,58,32,37,100,41,46,10,0,83,97,109,112,108,101,32,114,97,116,101,115,32,111,116,104,101,114,32,116,104,97,110,32,56,107,72,122,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,119,104,101,110,32,116,104,101,32,99,111,109,112,108,105,97,110,99,101,32,108,101,118,101,108,32,105,115,32,104,105,103,104,101,114,32,116,104,97,110,32,117,110,111,102,102,105,99,105,97,108,46,32,82,101,115,97,109,112,108,101,32,111,114,32,114,101,100,117,99,101,32,116,104,101,32,99,111,109,112,108,105,97,110,99,101,32,108,101,118,101,108,46,10,0,0,0,0,0,111,117,116,112,117,116,37,100,0,0,0,0,0,0,0,0,71,46,55,50,51,46,49,32,100,101,99,111,100,101,114,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,102,114,119,117,32,68,101,99,111,100,101,114,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,0,0,115,97,109,105,0,0,0,0,112,105,120,101,108,95,99,111,117,110,116,100,111,119,110,32,60,32,48,32,40,37,100,41,32,40,108,105,110,101,97,37,100,41,10,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,105,110,118,97,108,105,100,32,99,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,58,32,37,100,10,0,0,111,117,116,95,104,0,0,0,67,82,67,32,101,114,114,111,114,32,97,116,32,80,84,83,32,37,108,108,100,10,0,0,115,97,109,112,108,101,32,114,97,116,101,32,99,104,97,110,103,101,32,100,101,116,101,99,116,101,100,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,100,111,32,110,111,116,104,105,110,103,0,0,0,0,0,0,104,101,97,100,101,114,32,99,114,99,32,109,105,115,109,97,116,99,104,10,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,102,114,97,109,101,32,100,97,116,97,32,116,111,32,100,101,99,111,100,101,46,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,102,118,49,101,110,99,46,99,0,0,0,0,97,116,32,37,108,108,100,10,0,0,0,0,0,0,0,0,99,104,108,105,115,116,0,0,66,105,116,114,97,116,101,32,98,121,116,101,32,105,115,32,109,105,115,115,105,110,103,44,32,103,117,101,115,115,105,110,103,32,116,104,101,32,98,105,116,114,97,116,101,32,102,114,111,109,32,112,97,99,107,101,116,32,115,105,122,101,46,10,0,0,0,0,0,0,0,0,77,86,32,37,100,32,37,100,32,111,117,116,32,111,102,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,109,105,120,105,110,103,95,108,101,118,101,108,0,0,0,0,105,110,118,97,108,105,100,32,115,108,105,99,101,32,115,105,122,101,32,37,100,10,0,0,77,86,32,37,100,32,37,100,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,115,117,98,116,105,116,108,101,95,112,97,99,107,101,116,32,115,105,122,101,61,37,116,100,10,0,0,0,0,0,0,0,10,13,0,0,0,0,0,0,85,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,98,108,111,99,107,32,48,120,37,120,10,0,0,0,69,110,99,111,100,105,110,103,32,37,100,0,0,0,0,0,68,80,67,77,32,88,97,110,0,0,0,0,0,0,0,0,105,110,100,101,120,32,62,61,32,48,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,98,32,115,99,97,110,32,105,110,100,101,120,10,0,0,102,114,97,109,101,108,105,115,116,32,102,117,108,108,10,0,80,67,83,95,78,65,68,50,55,95,77,105,115,115,105,115,115,105,112,112,105,95,69,97,115,116,0,0,0,0,0,0,87,68,76,84,0,0,0,0,40,113,117,97,110,116,95,108,101,118,101,108,115,91,97,98,105,116,115,93,32,45,32,49,41,32,47,32,50,32,62,61,32,113,117,97,110,116,105,122,101,95,118,97,108,117,101,40,112,101,97,107,44,32,42,113,117,97,110,116,41,0,0,0,88,67,104,32,119,105,116,104,32,102,101,119,101,114,32,116,104,97,110,32,50,32,98,97,115,101,32,99,104,97,110,110,101,108,115,0,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,87,114,111,110,103,32,108,105,110,101,32,108,101,110,103,116,104,32,37,100,32,111,114,32,108,105,110,101,32,110,111,116,32,116,101,114,109,105,110,97,116,101,100,32,112,114,111,112,101,114,108,121,32,40,102,111,117,110,100,32,48,120,37,48,50,120,41,33,10,0,0,0,73,110,118,97,108,105,100,32,113,117,97,110,116,105,122,101,114,32,37,100,32,97,116,32,112,111,115,105,116,105,111,110,32,37,100,44,32,111,117,116,115,105,100,101,32,91,45,54,51,44,32,54,51,93,32,114,97,110,103,101,10,0,0,0,80,74,83,32,40,80,104,111,101,110,105,120,32,74,97,112,97,110,105,109,97,116,105,111,110,32,83,111,99,105,101,116,121,41,32,115,117,98,116,105,116,108,101,0,0,0,0,0,111,117,116,37,100,0,0,0,112,99,110,117,98,0,0,0,65,68,76,95,77,97,105,110,95,67,111,110,116,114,111,108,95,68,101,115,116,114,111,121,0,0,0,0,0,0,0,0,121,117,118,52,50,48,112,49,48,98,101,0,0,0,0,0,73,110,100,105,103,111,0,0,70,76,84,95,77,73,78,0,104,101,120,97,103,111,110,97,108,0,0,0,0,0,0,0,115,101,116,32,115,117,114,114,111,117,110,100,32,109,105,120,32,76,101,118,101,108,0,0,72,46,50,54,49,0,0,0,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,99,111,100,101,32,116,97,98,108,101,32,37,100,46,10,0,0,109,105,110,105,109,97,108,32,110,117,109,98,101,114,32,111,102,32,115,116,114,105,112,115,32,99,97,110,32,110,111,116,32,101,120,99,101,101,100,32,109,97,120,105,109,97,108,32,40,103,111,116,32,37,105,32,97,110,100,32,37,105,41,10,0,0,0,0,0,0,0,0,32,37,100,0,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,115,99,114,111,108,108,105,110,103,10,0,78,111,116,104,105,110,103,32,99,111,110,115,117,109,101,100,10,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,112,105,99,116,117,114,101,32,116,121,112,101,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,77,105,115,109,97,116,99,104,105,110,103,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,37,100,32,97,110,100,32,108,97,121,111,117,116,32,39,37,115,39,32,40,37,100,32,99,104,97,110,110,101,108,115,41,10,0,0,0,0,0,80,97,108,101,116,116,101,32,105,115,32,110,111,116,32,105,110,32,48,82,71,66,32,102,111,114,109,97,116,10,0,0,80,97,108,101,116,116,101,32,100,97,116,97,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,66,77,80,32,102,105,108,101,44,32,112,97,116,99,104,32,119,101,108,99,111,109,101,10,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,110,110,101,115,111,116,97,95,83,111,117,116,104,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,100,101,32,105,110,32,105,110,105,116,95,118,108,99,10,0,0,0,0,0,0,0,40,42,102,114,97,109,101,41,45,62,105,95,114,101,102,101,114,101,110,99,101,95,99,111,117,110,116,32,62,32,48,0,102,111,110,116,32,104,101,105,103,104,116,32,37,105,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,67,111,112,121,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,64,37,100,44,32,37,100,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,117,110,107,110,111,119,110,0,85,110,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,58,32,37,100,33,10,0,112,106,115,0,0,0,0,0,65,110,103,117,108,97,114,95,68,77,83,0,0,0,0,0,67,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,101,114,114,111,114,33,10,0,0,0,102,111,114,99,101,32,116,101,114,109,105,110,97,116,105,111,110,32,119,104,101,110,32,116,104,101,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,32,116,101,114,109,105,110,97,116,101,115,0,0,0,0,65,83,83,32,101,110,99,111,100,101,114,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,111,110,101,32,65,83,83,32,114,101,99,116,97,110,103,108,101,32,102,105,101,108,100,46,10,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,111,102,102,115,101,116,32,112,97,115,115,101,100,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,106,118,116,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,73,110,118,97,108,105,100,32,109,97,115,116,101,114,32,99,104,97,110,110,101,108,46,10,0,0,0,0,0,0,0,0,111,117,116,112,117,116,95,99,111,114,114,117,112,116,0,0,33,115,116,114,99,109,112,40,99,116,120,45,62,102,105,108,116,101,114,45,62,110,97,109,101,44,32,34,98,117,102,102,101,114,115,105,110,107,34,41,32,124,124,32,33,115,116,114,99,109,112,40,99,116,120,45,62,102,105,108,116,101,114,45,62,110,97,109,101,44,32,34,102,102,98,117,102,102,101,114,115,105,110,107,34,41,0,0,104,50,54,51,0,0,0,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,88,45,76,97,110,103,117,97,103,101,0,0,0,0,0,0,105,110,116,114,97,32,109,97,116,114,105,120,32,115,112,101,99,105,102,105,101,115,32,105,110,118,97,108,105,100,32,68,67,32,113,117,97,110,116,105,122,101,114,32,37,100,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,0,0,67,83,61,73,84,85,54,48,49,0,0,0,0,0,0,0,116,111,112,95,98,111,116,116,111,109,0,0,0,0,0,0,37,46,50,115,37,46,50,115,0,0,0,0,0,0,0,0,109,98,116,114,101,101,0,0,114,99,95,98,117,102,95,115,122,58,0,0,0,0,0,0,72,105,112,45,72,111,112,0,67,104,97,110,103,105,110,103,32,102,105,101,108,100,32,109,111,100,101,32,40,37,100,32,45,62,32,37,100,41,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,73,110,118,97,108,105,100,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,115,105,122,101,58,32,37,100,46,10,0,0,0,0,0,99,111,109,109,101,110,116,0,78,111,32,97,117,100,105,111,32,115,116,114,101,97,109,32,112,114,101,115,101,110,116,46,10,0,0,0,0,0,0,0,102,105,108,101,32,105,115,32,110,111,116,32,115,101,101,107,97,98,108,101,10,0,0,0,65,84,73,32,86,67,82,49,0,0,0,0,0,0,0,0,57,54,48,47,49,50,48,32,77,68,67,84,32,119,105,110,100,111,119,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,68,84,83,10,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,99,51,100,101,99,46,99,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,110,110,101,115,111,116,97,95,67,101,110,116,0,0,0,0,0,0,0,0,76,111,45,70,105,0,0,0,32,67,52,52,52,112,49,48,32,88,89,83,67,83,83,61,52,52,52,80,49,48,0,0,52,50,48,112,97,108,100,118,0,0,0,0,0,0,0,0,100,112,100,115,32,99,104,117,110,107,32,115,105,122,101,32,37,108,108,100,32,110,111,116,32,100,105,118,105,115,105,98,108,101,32,98,121,32,52,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,115,32,102,111,114,32,97,117,100,105,111,32,116,114,97,99,107,32,37,100,46,10,0,113,117,101,114,121,95,102,111,114,109,97,116,115,32,110,111,116,32,102,105,110,105,115,104,101,100,10,0,0,0,0,0,73,103,110,111,114,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,115,101,116,32,105,110,118,97,108,105,100,32,116,105,109,101,98,97,115,101,32,37,100,47,37,100,32,102,111,114,32,115,116,58,37,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,105,110,102,111,32,115,105,122,101,32,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,74,65,67,79,115,117,98,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,104,117,110,107,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,0,32,37,46,42,115,0,0,0,10,9,32,0,0,0,0,0,116,105,116,108,101,0,0,0,78,79,78,69,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,67,79,77,77,32,116,97,103,32,110,111,116,32,102,111,117,110,100,33,10,0,0,0,0,99,111,109,109,101,110,116,0,109,105,115,115,105,110,103,32,99,111,108,111,110,32,105,110,32,107,101,121,58,118,97,108,117,101,32,112,97,105,114,32,39,37,115,39,10,0,0,0,97,117,100,105,111,47,97,97,99,112,0,0,0,0,0,0,106,112,101,103,0,0,0,0,33,34,114,101,97,99,104,101,100,34,0,0,0,0,0,0,83,101,101,107,32,116,97,98,108,101,32,67,82,67,32,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2166944);
/* memory initializer */ allocate([114,114,111,114,10,0,0,0,32,98,115,102,115,58,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,32,118,101,114,115,105,111,110,58,32,37,48,88,10,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,115,119,102,101,110,99,46,99,0,0,0,0,48,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,110,110,101,115,111,116,97,95,78,111,114,116,104,0,0,0,0,0,0,0,91,70,79,78,84,93,0,0,42,42,42,42,42,42,42,42,32,83,84,65,82,84,32,83,67,82,73,80,84,32,42,42,42,42,42,42,42,42,0,0,70,97,105,108,101,100,32,116,111,32,99,111,110,102,105,103,117,114,101,32,111,117,116,112,117,116,32,112,97,100,32,111,110,32,37,115,10,0,0,0,10,10,0,0,0,0,0,0,37,105,32,115,97,109,112,108,101,115,32,105,110,32,65,65,67,32,102,114,97,109,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,37,115,32,102,111,114,32,119,114,105,116,105,110,103,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,97,117,100,105,111,32,115,116,114,101,97,109,115,0,0,106,97,99,111,115,117,98,0,102,0,0,0,0,0,0,0,35,69,88,84,77,51,85,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,99,104,105,103,97,110,95,83,111,117,116,104,0,0,0,0,0,0,0,0,105,108,98,99,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,112,99,109,100,101,99,46,99,0,0,0,0,69,73,65,45,54,48,56,32,99,108,111,115,101,100,32,99,97,112,116,105,111,110,115,0,97,103,103,114,101,115,115,105,118,101,0,0,0,0,0,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,115,97,109,112,108,101,95,114,97,116,101,32,105,115,32,40,37,108,108,100,41,10,0,105,110,99,111,110,115,105,115,116,101,110,116,32,70,111,111,116,101,114,80,97,114,116,105,116,105,111,110,32,118,97,108,117,101,58,32,37,108,108,117,32,33,61,32,37,108,108,117,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,99,104,105,103,97,110,95,67,101,110,116,114,97,108,0,0,0,0,0,0,101,105,97,95,54,48,56,0,105,111,100,115,95,118,105,100,101,111,95,112,114,111,102,105,108,101,0,0,0,0,0,0,83,84,83,90,32,115,97,109,112,108,101,32,115,105,122,101,32,37,100,32,105,110,118,97,108,105,100,32,40,116,111,111,32,115,109,97,108,108,41,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,32,102,111,117,110,100,44,32,65,76,65,67,32,101,120,112,101,99,116,115,32,97,32,51,54,45,98,121,116,101,32,81,117,105,99,107,84,105,109,101,32,97,116,111,109,46,0,105,102,102,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,105,99,104,105,103,97,110,95,78,111,114,116,104,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,101,110,99,111,100,105,110,103,10,0,0,0,0,0,0,0,77,80,76,50,32,115,117,98,116,105,116,108,101,0,0,0,114,111,113,0,0,0,0,0,115,105,122,101,61,37,56,46,48,102,107,66,32,116,105,109,101,61,0,0,0,0,0,0,114,111,113,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,73,115,0,0,0,0,0,0,109,112,108,50,0,0,0,0,105,100,99,105,110,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,115,115,97,99,104,117,115,101,116,116,115,0,77,105,99,114,111,68,86,68,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,37,100,58,37,100,58,48,120,37,88,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,114,121,108,97,110,100,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,115,116,101,114,101,111,51,100,46,99,0,0,0,0,0,0,0,109,105,99,114,111,100,118,100,0,0,0,0,0,0,0,0,111,119,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,105,110,101,95,87,101,115,116,0,0,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,99,97,108,99,117,108,97,116,101,32,112,47,99,47,110,0,65,68,76,95,77,97,105,110,95,67,111,110,116,114,111,108,95,67,114,101,97,116,101,0,121,117,118,52,50,48,112,57,108,101,0,0,0,0,0,0,73,110,100,105,97,110,82,101,100,0,0,0,0,0,0,0,70,76,84,95,77,65,88,0,54,46,48,40,102,114,111,110,116,41,0,0,0,0,0,0,115,117,114,114,111,117,110,100,95,109,105,120,95,108,101,118,101,108,0,0,0,0,0,0,114,101,102,58,0,0,0,0,77,105,115,115,105,110,103,32,99,111,101,102,102,32,116,97,98,108,101,10,0,0,0,0,67,111,117,112,108,105,110,103,32,83,116,97,114,116,32,66,97,110,100,0,0,0,0,0,67,111,117,112,108,105,110,103,32,83,116,97,114,116,32,66,97,110,100,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,77,97,105,110,101,95,69,97,115,116,0,0,0,0,107,98,47,115,58,37,46,50,102,10,0,0,0,0,0,0,37,115,58,32,37,115,0,0,115,117,98,114,105,112,0,0,65,110,103,117,108,97,114,95,71,111,110,0,0,0,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,102,108,97,116,0,0,0,0,112,99,109,95,115,51,50,108,101,0,0,0,0,0,0,0,99,108,111,115,101,100,32,71,79,80,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,118,105,100,101,111,95,101,110,99,46,99,0,0,0,0,0,0,124,108,101,118,101,108,124,32,111,118,101,114,102,108,111,119,32,105,110,32,51,46,32,101,115,99,44,32,113,112,61,37,100,10,0,0,0,0,0,0,109,97,116,114,105,120,32,100,97,109,97,103,101,100,10,0,65,86,73,68,0,0,0,0,85,115,101,32,97,99,99,101,115,115,32,117,110,105,116,32,100,101,108,105,109,105,116,101,114,115,46,0,0,0,0,0,100,101,99,111,100,101,114,32,98,117,102,102,101,114,32,109,111,100,101,108,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,0,0,0,84,104,105,115,32,115,116,114,101,97,109,32,119,97,115,32,103,101,110,101,114,97,116,101,100,32,98,121,32,97,32,98,114,111,107,101,110,32,101,110,99,111,100,101,114,44,32,105,110,118,97,108,105,100,32,56,120,56,32,105,110,102,101,114,101,110,99,101,10,0,0,0,118,99,114,49,0,0,0,0,80,67,83,95,78,65,68,50,55,95,76,111,117,105,115,105,97,110,97,95,83,111,117,116,104,0,0,0,0,0,0,0,84,114,97,105,108,101,114,0,32,67,52,50,50,112,49,48,32,88,89,83,67,83,83,61,52,50,50,80,49,48,0,0,115,116,58,37,100,32,104,97,115,32,116,111,111,32,108,97,114,103,101,32,116,105,109,101,98,97,115,101,44,32,114,101,100,117,99,105,110,103,10,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,32,119,105,116,104,32,101,109,98,101,100,100,101,100,32,116,105,109,105,110,103,0,0,0,0,80,67,83,95,78,65,68,50,55,95,76,111,117,105,115,105,97,110,97,95,78,111,114,116,104,0,0,0,0,0,0,0,115,114,116,0,0,0,0,0,100,111,32,110,111,116,32,115,104,111,119,32,112,114,111,103,114,97,109,32,98,97,110,110,101,114,0,0,0,0,0,0,108,111,110,103,0,0,0,0,72,101,97,100,101,114,32,99,104,117,110,107,32,115,105,122,101,32,105,115,32,105,110,99,111,114,114,101,99,116,10,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,115,101,103,109,101,110,116,32,108,105,115,116,32,39,37,115,39,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,102,114,97,109,101,32,114,101,99,111,114,100,10,0,0,0,0,99,61,73,78,32,37,115,32,37,115,13,10,0,0,0,0,109,111,100,101,0,0,0,0,80,67,83,95,78,65,68,50,55,95,75,101,110,116,117,99,107,121,95,83,111,117,116,104,0,0,0,0,0,0,0,0,115,116,45,62,99,111,100,101,99,45,62,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,62,32,48,0,0,0,0,68,86,66,32,116,101,108,101,116,101,120,116,0,0,0,0,99,111,110,115,105,100,101,114,32,97,108,108,32,115,112,101,99,32,110,111,110,32,99,111,109,112,108,105,97,110,99,105,101,115,32,97,115,32,101,114,114,111,114,115,0,0,0,0,97,117,116,111,0,0,0,0,105,110,118,97,108,105,100,32,97,115,112,101,99,116,32,114,97,116,105,111,32,37,100,47,37,100,10,0,0,0,0,0,70,97,105,108,101,100,32,114,101,97,100,105,110,103,32,85,73,68,10,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,75,101,110,116,117,99,107,121,95,78,111,114,116,104,0,0,0,0,0,0,0,0,100,118,98,95,116,101,108,101,116,101,120,116,0,0,0,0,116,105,116,108,101,0,0,0,105,111,100,115,32,97,117,100,105,111,32,112,114,111,102,105,108,101,32,97,116,111,109,46,0,0,0,0,0,0,0,0,83,84,83,90,32,115,97,109,112,108,101,32,115,105,122,101,32,37,100,32,105,110,118,97,108,105,100,32,40,116,111,111,32,108,97,114,103,101,41,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,0,104,105,100,101,95,98,97,110,110,101,114,0,0,0,0,0,79,110,108,121,32,97,117,100,105,111,44,32,118,105,100,101,111,44,32,97,110,100,32,115,117,98,116,105,116,108,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,77,97,116,114,111,115,107,97,46,10,0,0,0,78,111,32,101,118,101,110,116,115,32,105,110,32,115,99,114,105,112,116,10,0,0,0,0,67,79,77,78,84,0,0,0,60,83,65,77,73,62,0,0,80,67,83,95,78,65,68,50,55,95,75,97,110,115,97,115,95,83,111,117,116,104,0,0,73,110,99,111,114,114,101,99,116,32,66,79,77,32,118,97,108,117,101,10,0,0,0,0,72,68,77,86,32,80,114,101,115,101,110,116,97,116,105,111,110,32,71,114,97,112,104,105,99,32,83,116,114,101,97,109,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,115,105,122,101,61,78,47,65,32,116,105,109,101,61,0,0,77,97,120,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,32,116,111,111,32,108,111,119,10,0,0,0,0,0,65,68,80,67,77,32,105,110,32,82,83,79,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,65,117,100,105,111,32,102,111,114,109,97,116,32,37,105,0,80,67,83,95,78,65,68,50,55,95,75,97,110,115,97,115,95,78,111,114,116,104,0,0,104,100,109,118,95,112,103,115,95,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,114,109,45,62,97,117,100,105,111,95,112,107,116,95,99,110,116,32,62,32,48,0,0,0,117,110,107,110,111,119,110,32,115,117,98,102,111,114,109,97,116,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,66,76,77,95,49,55,78,95,102,101,101,116,0,0,73,67,82,68,0,0,0,0,77,79,86,32,116,101,120,116,0,0,0,0,0,0,0,0,98,117,102,102,101,114,115,105,110,107,0,0,0,0,0,0,60,116,105,109,101,0,0,0,115,101,116,32,102,114,97,109,101,32,115,105,122,101,0,0,80,67,83,95,78,65,68,50,55,95,73,111,119,97,95,83,111,117,116,104,0,0,0,0,48,0,0,0,0,0,0,0,109,111,118,95,116,101,120,116,0,0,0,0,0,0,0,0,115,108,105,100,101,0,0,0,111,117,116,95,119,0,0,0,114,97,119,32,67,104,105,110,101,115,101,32,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,118,105,100,101,111,0,0,0,0,80,67,83,95,78,65,68,50,55,95,66,76,77,95,49,54,78,95,102,101,101,116,0,0,114,97,119,32,76,79,65,83,47,76,65,84,77,0,0,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,97,116,111,109,10,0,0,0,0,0,84,65,76,66,0,0,0,0,85,110,107,110,111,119,110,32,101,110,116,114,121,32,37,100,61,62,37,100,32,105,110,32,114,97,116,101,45,109,97,112,45,116,97,98,108,101,46,10,32,0,0,0,0,0,0,0,101,120,112,101,99,116,101,100,32,110,111,110,32,101,109,112,116,121,32,115,105,103,110,97,108,101,100,32,80,69,83,32,112,97,99,107,101,116,44,32,116,114,121,105,110,103,32,116,111,32,114,101,99,111,118,101,114,10,0,0,0,0,0,0,110,111,32,102,111,114,99,101,100,32,99,97,108,99,117,108,97,116,105,111,110,0,0,0,108,105,98,97,116,105,97,100,108,120,120,46,115,111,0,0,121,117,118,52,50,48,112,57,98,101,0,0,0,0,0,0,72,111,116,80,105,110,107,0,73,54,52,95,77,73,78,0,85,110,115,117,112,112,111,114,116,101,100,32,97,117,100,105,111,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,54,46,48,0,0,0,0,0,115,101,116,32,115,117,114,114,111,117,110,100,32,109,105,120,32,108,101,118,101,108,0,0,32,105,110,58,37,42,100,32,111,117,116,58,37,42,100,32,116,121,112,101,58,37,99,32,100,117,114,58,37,108,108,100,32,99,112,98,100,117,114,58,37,108,108,100,32,113,58,37,102,32,97,113,58,37,102,32,116,101,120,58,37,100,32,109,118,58,37,100,32,109,105,115,99,58,37,100,32,105,109,98,58,37,100,32,112,109,98,58,37,100,32,115,109,98,58,37,100,32,100,58,37,99,0,0,69,82,82,79,82,58,32,115,116,101,112,95,105,110,100,101,120,32,61,32,37,105,10,0,99,112,108,95,115,116,97,114,116,95,98,97,110,100,0,0,99,112,108,95,115,116,97,114,116,95,98,97,110,100,0,0,80,67,83,95,78,65,68,50,55,95,73,111,119,97,95,78,111,114,116,104,0,0,0,0,80,83,78,82,32,77,101,97,110,32,89,58,37,54,46,51,102,32,85,58,37,54,46,51,102,32,86,58,37,54,46,51,102,32,65,118,103,58,37,54,46,51,102,32,71,108,111,98,97,108,58,37,54,46,51,102,32,107,98,47,115,58,37,46,50,102,10,0,0,0,0,0,91,37,100,93,0,0,0,0,115,115,97,0,0,0,0,0,65,110,103,117,108,97,114,95,71,114,97,100,0,0,0,0,115,101,116,32,111,112,97,99,105,116,121,32,102,111,114,32,97,108,108,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,99,113,109,0,0,0,0,0,99,103,111,112,0,0,0,0,118,98,118,95,100,101,108,97,121,32,60,32,48,120,70,70,70,70,0,0,0,0,0,0,50,46,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,105,110,32,51,46,32,101,115,99,10,0,0,0,0,0,0,0,0,112,100,101,32,40,37,100,44,37,100,41,32,40,37,100,44,37,100,41,32,40,37,100,44,37,100,41,10,0,0,0,0,99,111,109,109,101,110,116,58,32,39,37,115,39,10,0,0,102,51,50,108,101,0,0,0,105,99,111,0,0,0,0,0,97,117,100,0,0,0,0,0,114,99,95,111,118,101,114,115,104,111,111,116,95,112,99,116,58,0,0,0,0,0,0,0,67,97,110,110,111,116,32,40,114,101,45,41,105,110,105,116,105,97,108,105,122,101,32,99,111,110,116,101,120,116,32,100,117,114,105,110,103,32,112,97,114,97,108,108,101,108,32,100,101,99,111,100,105,110,103,46,10,0,0,0,0,0,0,0,52,88,32,77,111,118,105,101,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,66,76,77,95,49,53,78,95,102,101,101,116,0,0,83,104,111,119,116,117,110,101,115,0,0,0,0,0,0,0,32,67,52,50,48,112,49,48,32,88,89,83,67,83,83,61,52,50,48,80,49,48,0,0,115,116,58,37,100,32,114,101,109,111,118,105,110,103,32,99,111,109,109,111,110,32,102,97,99,116,111,114,32,37,100,32,102,114,111,109,32,116,105,109,101,98,97,115,101,10,0,0,65,83,83,32,40,65,100,118,97,110,99,101,100,32,83,83,65,41,32,115,117,98,116,105,116,108,101,0,0,0,0,0,105,99,111,0,0,0,0,0,102,51,50,108,101,0,0,0,80,67,83,95,78,65,68,50,55,95,73,110,100,105,97,110,97,95,87,101,115,116,0,0,104,110,109,0,0,0,0,0,97,115,115,0,0,0,0,0,34,44,10,13,0,0,0,0,99,61,73,78,32,37,115,32,37,115,47,37,100,13,10,0,112,97,99,107,101,116,115,105,122,101,0,0,0,0,0,0,65,84,82,65,67,51,32,105,110,32,79,77,65,32,105,115,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,50,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,66,76,77,95,49,52,78,95,102,101,101,116,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,88,83,85,66,0,0,0,0,99,111,109,112,108,105,97,110,116,0,0,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,37,100,0,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,104,101,105,103,104,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,1,118,111,114,98,105,115,0,117,110,107,110,111,119,110,32,112,97,114,116,105,116,105,111,110,32,116,121,112,101,32,37,105,10,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,80,67,83,95,78,65,68,50,55,95,73,110,100,105,97,110,97,95,69,97,115,116,0,0,120,115,117,98,0,0,0,0,105,111,100,115,95,97,117,100,105,111,95,112,114,111,102,105,108,101,0,0,0,0,0,0,97,117,100,105,111,47,111,103,103,0,0,0,0,0,0,0,85,115,105,110,103,32,97,98,115,111,108,117,116,101,32,112,97,116,104,32,111,110,32,117,115,101,114,32,114,101,113,117,101,115,116,44,32,116,104,105,115,32,105,115,32,97,32,112,111,115,115,105,98,108,101,32,115,101,99,117,114,105,116,121,32,105,115,115,117,101,10,0,83,117,98,116,105,116,108,101,32,99,111,100,101,99,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,80,97,103,101,32,97,116,32,37,108,108,100,32,105,115,32,109,105,115,115,105,110,103,32,103,114,97,110,117,108,101,10,0,0,0,0,0,0,0,0,102,108,97,103,115,0,0,0,104,108,115,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,73,108,108,105,110,111,105,115,95,87,101,115,116,0,108,105,98,97,118,102,111,114,109,97,116,47,110,117,116,101,110,99,46,99,0,0,0,0,67,97,110,110,111,116,32,114,101,97,100,32,66,79,77,32,118,97,108,117,101,44,32,105,110,112,117,116,32,116,111,111,32,115,104,111,114,116,10,0,114,97,119,32,85,84,70,45,56,32,116,101,120,116,0,0,115,116,114,101,97,109,95,37,100,95,37,100,95,112,115,110,114,95,97,108,108,61,37,50,46,50,102,10,0,0,0,0,83,69,69,75,84,79,58,32,37,108,108,100,10,0,0,0,80,67,83,95,78,65,68,50,55,95,73,108,108,105,110,111,105,115,95,69,97,115,116,0,116,101,120,116,0,0,0,0,97,108,97,119,0,0,0,0,109,105,115,115,105,110,103,32,102,114,97,109,101,115,10,0,80,67,83,95,78,65,68,50,55,95,73,100,97,104,111,95,87,101,115,116,0,0,0,0,68,86,66,32,115,117,98,116,105,116,108,101,115,0,0,0,37,100,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,102,105,110,100,32,97,98,115,111,108,117,116,101,32,111,102,102,115,101,116,32,111,102,32,37,108,108,88,32,105,110,32,66,111,100,121,83,73,68,32,37,105,32,45,32,112,97,114,116,105,97,108,32,102,105,108,101,63,10,0,0,0,115,101,116,32,116,104,101,32,98,101,101,112,32,102,101,113,117,101,110,99,121,32,102,97,99,116,111,114,0,0,0,0,80,67,83,95,78,65,68,50,55,95,73,100,97,104,111,95,67,101,110,116,114,97,108,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,117,108,116,105,112,108,101,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,115,117,112,112,111,114,116,0,0,100,118,98,95,115,117,98,116,105,116,108,101,0,0,0,0,105,110,95,104,0,0,0,0,40,40,65,86,70,114,97,109,101,32,42,41,112,107,116,45,62,100,97,116,97,41,45,62,98,117,102,0,0,0,0,0,104,108,115,44,97,112,112,108,101,104,116,116,112,0,0,0,70,79,82,77,65,84,61,84,73,77,69,0,0,0,0,0,91,37,108,108,100,93,91,37,108,108,100,93,37,99,0,0,80,67,83,95,78,65,68,50,55,95,73,100,97,104,111,95,69,97,115,116,0,0,0,0,13,10,45,45,37,115,13,10,0,0,0,0,0,0,0,0,68,86,68,32,115,117,98,116,105,116,108,101,115,0,0,0,104,101,118,99,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,100,98,103,108,118,108,0,0,114,98,0,0,0,0,0,0,98,103,114,52,56,108,101,0,112,107,116,91,51,93,32,38,32,48,120,50,48,0,0,0,72,111,110,101,121,68,101,119,0,0,0,0,0,0,0,0,73,54,52,95,77,65,88,0,53,46,49,40,115,105,100,101,41,0,0,0,0,0,0,0,115,119,115,99,97,108,101,114,0,0,0,0,0,0,0,0,115,108,101,118,0,0,0,0,98,97,100,32,102,114,97,109,101,32,110,117,109,98,101,114,32,40,37,100,41,32,97,116,32,115,116,97,116,115,32,108,105,110,101,32,37,100,10,0,112,101,114,45,99,104,97,110,110,101,108,32,115,97,109,112,108,101,32,99,111,117,110,116,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,83,101,108,101,99,116,101,100,32,98,121,32,116,104,101,32,69,110,99,111,100,101,114,0,83,101,108,101,99,116,101,100,32,98,121,32,116,104,101,32,69,110,99,111,100,101,114,0,80,67,83,95,78,65,68,50,55,95,71,101,111,114,103,105,97,95,87,101,115,116,0,0,83,83,73,77,32,77,101,97,110,32,89,58,37,46,55,102,32,40,37,54,46,51,102,100,98,41,10,0,0,0,0,0,109,97,120,32,114,101,115,121,110,99,32,115,105,122,101,32,114,101,97,99,104,101,100,44,32,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,115,121,110,99,32,98,121,116,101,10,0,0,0,0,0,0,37,99,0,0,0,0,0,0,100,118,100,95,115,117,98,116,105,116,108,101,0,0,0,0,65,110,103,117,108,97,114,95,65,114,99,95,83,101,99,111,110,100,0,0,0,0,0,0,97,108,108,95,111,112,97,99,105,116,121,0,0,0,0,0,99,111,110,115,116,114,97,105,110,101,100,45,105,110,116,114,97,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,100,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,118,111,98,0,0,0,0,0,49,46,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,105,110,32,51,46,32,101,115,99,10,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,44,32,103,117,101,115,115,105,110,103,32,109,105,115,115,105,110,103,32,118,97,108,117,101,115,10,0,0,0,0,114,101,115,116,97,114,116,32,105,110,116,101,114,118,97,108,58,32,37,100,10,0,0,0,102,97,115,116,45,112,115,107,105,112,0,0,0,0,0,0,114,99,95,117,110,100,101,114,115,104,111,111,116,95,112,99,116,58,0,0,0,0,0,0,104,50,54,52,95,115,108,105,99,101,95,104,101,97,100,101,114,95,105,110,105,116,40,41,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,70,117,114,116,104,101,114,32,102,108,97,103,115,32,115,101,116,32,98,117,116,32,110,111,32,98,121,116,101,115,32,108,101,102,116,10,0,0,0,0,52,120,109,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,71,101,111,114,103,105,97,95,69,97,115,116,0,0,82,97,118,101,0,0,0,0,83,101,101,107,32,116,97,98,108,101,32,105,115,32,116,111,111,32,98,105,103,10,0,0,32,67,52,52,52,112,57,32,88,89,83,67,83,83,61,52,52,52,80,57,0,0,0,0,32,9,13,10,0,0,0,0,67,111,110,116,97,105,110,101,114,32,114,101,112,111,114,116,115,32,110,111,32,102,114,97,109,101,115,10,0,0,0,0,83,77,86,32,40,83,101,108,101,99,116,97,98,108,101,32,77,111,100,101,32,86,111,99,111,100,101,114,41,0,0,0,78,111,32,112,97,99,107,101,116,115,32,119,101,114,101,32,115,101,110,116,32,102,111,114,32,115,111,109,101,32,111,102,32,116,104,101,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,115,46,10,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,100,101,116,101,114,109,105,110,101,32,102,105,108,101,32,115,105,122,101,44,32,115,107,105,112,112,105,110,103,32,84,79,67,32,116,97,98,108,101,46,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,53,0,69,86,82,67,32,40,69,110,104,97,110,99,101,100,32,86,97,114,105,97,98,108,101,32,82,97,116,101,32,67,111,100,101,99,41,0,0,0,0,0,32,37,45,50,48,115,32,37,115,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,115,101,103,109,101,110,116,46,99,0,0,0,67,97,110,110,111,116,32,66,97,115,101,54,52,45,101,110,99,111,100,101,32,37,116,100,32,37,116,100,33,10,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,52,0,102,54,52,108,101,32,100,101,109,117,120,101,114,0,0,0,101,118,114,99,0,0,0,0,99,111,110,115,105,100,101,114,32,116,104,105,110,103,115,32,116,104,97,116,32,118,105,111,108,97,116,101,32,116,104,101,32,115,112,101,99,44,32,97,114,101,32,102,97,115,116,32,116,111,32,99,104,101,99,107,32,97,110,100,32,104,97,118,101,32,110,111,116,32,98,101,101,110,32,115,101,101,110,32,105,110,32,116,104,101,32,119,105,108,100,32,97,115,32,101,114,114,111,114,115,0,0,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,119,105,100,116,104,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,0,104,100,115,0,0,0,0,0,45,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,51,0,104,50,54,52,0,0,0,0,86,111,120,119,97,114,101,32,77,101,116,97,83,111,117,110,100,0,0,0,0,0,0,0,83,107,105,112,32,119,114,105,116,105,110,103,32,105,111,100,115,32,97,116,111,109,46,0,46,46,47,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,47,32,77,79,86,0,65,95,77,83,47,65,67,77,0,0,0,0,0,0,0,0,104,50,54,51,0,0,0,0,40,110,111,110,101,41,0,0,102,111,114,99,101,32,115,112,101,99,105,102,105,99,32,99,112,117,32,102,108,97,103,115,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,50,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,109,101,109,111,114,121,32,115,116,114,101,97,109,10,0,0,0,0,109,101,116,97,115,111,117,110,100,0,0,0,0,0,0,0,104,50,54,49,0,0,0,0,42,58,37,50,46,50,102,32,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,112,112,101,110,100,32,112,97,108,101,116,116,101,32,116,111,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,0,86,78,58,76,97,118,102,53,53,46,51,51,46,49,48,48,44,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,72,97,119,97,105,105,95,122,111,110,101,95,49,0,10,0,0,0,0,0,0,0,84,65,75,32,40,84,111,109,39,115,32,108,111,115,115,108,101,115,115,32,65,117,100,105,111,32,75,111,109,112,114,101,115,115,111,114,41,0,0,0,73,110,118,97,108,105,100,32,101,118,101,110,116,32,34,37,115,34,32,97,116,32,108,105,110,101,32,37,100,10,0,0,108,101,110,32,62,32,48,32,38,38,32,108,101,110,32,60,61,32,115,105,122,101,111,102,40,109,100,53,41,0,0,0,80,67,83,95,78,65,68,50,55,95,70,108,111,114,105,100,97,95,78,111,114,116,104,0,116,97,107,0,0,0,0,0,37,115,124,0,0,0,0,0,118,105,100,101,111,47,119,101,98,109,0,0,0,0,0,0,103,120,102,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,70,108,111,114,105,100,97,95,87,101,115,116,0,0,111,117,116,112,117,116,32,102,111,114,109,97,116,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,82,70,67,32,51,51,56,57,32,67,111,109,102,111,114,116,32,78,111,105,115,101,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,32,119,97,118,112,97,99,107,32,98,108,111,99,107,46,10,0,105,110,95,119,0,0,0,0,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,69,120,116,114,97,100,97,116,97,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,46,10,0,0,80,67,83,95,78,65,68,50,55,95,70,108,111,114,105,100,97,95,69,97,115,116,0,0,64,37,117,32,64,37,117,32,37,110,0,0,0,0,0,0,99,111,109,102,111,114,116,110,111,105,115,101,0,0,0,0,112,97,99,107,101,116,95,115,105,122,101,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,101,110,97,98,108,101,32,99,111,109,98,32,100,101,98,117,103,0,0,0,0,0,0,0,79,112,101,110,67,76,58,32,85,110,97,98,108,101,32,116,111,32,113,117,101,114,121,32,112,114,111,103,114,97,109,32,98,105,110,97,114,121,44,32,110,111,32,99,97,99,104,101,32,102,105,108,101,32,103,101,110,101,114,97,116,101,100,10,0,0,0,0,0,0,0,0,98,103,114,52,56,98,101,0,71,114,101,101,110,89,101,108,108,111,119,0,0,0,0,0,85,73,78,84,51,50,95,77,65,88,0,0,0,0,0,0,53,46,49,0,0,0,0,0,101,114,114,111,114,32,100,105,102,102,117,115,105,111,110,0,99,101,110,116,101,114,95,109,105,120,95,108,101,118,101,108,0,0,0,0,0,0,0,0,32,105,110,58,37,100,32,0,69,82,82,79,82,58,32,115,116,101,112,95,105,110,100,101,120,32,61,32,37,105,47,37,105,10,0,0,0,0,0,0,97,117,116,111,0,0,0,0,97,117,116,111,0,0,0,0,80,67,83,95,78,65,68,50,55,95,68,101,108,97,119,97,114,101,0,0,0,0,0,0,103,120,102,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,102,114,97,109,101,32,102,105,108,101,110,97,109,101,32,110,117,109,98,101,114,32,37,100,32,102,114,111,109,32,112,97,116,116,101,114,110,32,39,37,115,39,32,40,101,105,116,104,101,114,32,115,101,116,32,117,112,100,97,116,101,102,105,114,115,116,32,111,114,32,117,115,101,32,97,32,112,97,116,116,101,114,110,32,108,105,107,101,32,37,37,48,51,100,32,119,105,116,104,105,110,32,116,104,101,32,102,105,108,101,110,97,109,101,32,112,97,116,116,101,114,110,41,10,0,0,0,0,0,0,117,110,107,110,111,119,110,95,99,111,100,101,99,0,0,0,79,112,117,115,32,40,79,112,117,115,32,73,110,116,101,114,97,99,116,105,118,101,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,65,110,103,117,108,97,114,95,65,114,99,95,77,105,110,117,116,101,0,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,51,32,111,112,97,99,105,116,121,0,0,98,102,102,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,105,108,109,101,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,110,101,103,97,116,105,118,101,32,98,105,116,115,10,0,0,114,101,118,101,114,115,101,32,101,115,99,32,109,105,115,115,105,110,103,10,0,0,0,0,0,84,77,80,71,69,88,83,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,118,105,100,101,111,32,102,114,97,109,101,114,97,116,101,0,85,115,101,32,101,120,116,101,114,110,97,108,32,104,117,102,102,109,97,110,32,116,97,98,108,101,46,0,0,0,0,0,72,105,103,104,32,112,114,111,102,105,108,101,32,56,120,56,32,116,114,97,110,115,102,111,114,109,46,0,0,0,0,0,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,0,0,0,0,0,0,82,101,105,110,105,116,32,99,111,110,116,101,120,116,32,116,111,32,37,100,120,37,100,44,32,112,105,120,95,102,109,116,58,32,37,115,10,0,0,0,103,115,109,0,0,0,0,0,70,70,109,112,101,103,32,118,105,100,101,111,32,99,111,100,101,99,32,35,49,0,0,0,80,67,83,95,78,65,68,50,55,95,67,111,110,110,101,99,116,105,99,117,116,0,0,0,80,115,121,99,104,97,100,101,108,105,99,0,0,0,0,0,32,67,52,50,50,112,57,32,88,89,83,67,83,83,61,52,50,50,80,57,0,0,0,0,112,110,103,0,0,0,0,0,37,48,42,100,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,109,111,100,101,10,0,0,0,0,0,0,0,111,112,117,115,0,0,0,0,99,111,108,111,114,32,102,111,114,109,97,116,32,37,46,49,54,115,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,121,116,101,115,32,112,101,114,32,115,97,109,112,108,101,58,32,37,117,10,0,0,0,80,67,83,95,78,65,68,50,55,95,67,111,108,111,114,97,100,111,95,83,111,117,116,104,0,0,0,0,0,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,65,117,100,105,111,0,0,0,0,0,0,83,0,0,0,0,0,0,0,33,34,73,110,118,97,108,105,100,32,108,105,115,116,32,116,121,112,101,34,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,116,104,101,32,112,97,114,97,109,101,116,101,114,32,115,101,116,115,46,10,0,103,105,102,0,0,0,0,0,84,67,79,80,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,111,108,111,114,97,100,111,95,67,101,110,116,114,97,108,0,0,0,0,0,0,102,51,50,98,101,32,100,101,109,117,120,101,114,0,0,0,112,97,102,95,97,117,100,105,111,0,0,0,0,0,0,0,99,97,114,101,102,117,108,0,35,69,88,84,45,88,45,77,69,68,73,65,45,83,69,81,85,69,78,67,69,58,37,108,108,100,10,0,0,0,0,0,69,114,114,111,114,32,115,116,45,62,99,111,100,101,99,45,62,101,120,116,114,97,100,97,116,97,95,115,105,122,101,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,37,89,45,37,109,45,37,100,32,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,104,101,97,100,101,114,115,0,80,67,83,95,78,65,68,50,55,95,67,111,108,111,114,97,100,111,95,78,111,114,116,104,0,0,0,0,0,0,0,0,83,111,110,105,99,32,108,111,115,115,108,101,115,115,0,0,60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,110,99,111,100,105,110,103,61,34,117,116,102,45,56,34,63,62,10,0,115,107,105,112,95,105,111,100,115,0,0,0,0,0,0,0,103,105,102,0,0,0,0,0,115,116,114,101,97,109,32,37,100,44,32,101,114,114,111,114,32,111,112,101,110,105,110,103,32,97,108,105,97,115,58,32,112,97,116,104,61,39,37,115,39,44,32,100,105,114,61,39,37,115,39,44,32,102,105,108,101,110,97,109,101,61,39,37,115,39,44,32,118,111,108,117,109,101,61,39,37,115,39,44,32,110,108,118,108,95,102,114,111,109,61,37,100,44,32,110,108,118,108,95,116,111,61,37,100,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,79,118,101,114,102,108,111,119,32,105,110,32,100,105,115,112,108,97,121,32,119,105,100,116,104,10,0,0,0,0,0,0,119,101,98,109,0,0,0,0,105,110,118,97,108,105,100,32,105,110,100,101,120,32,108,101,110,103,116,104,10,0,0,0,99,112,117,102,108,97,103,115,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,114,107,97,110,115,97,115,95,83,111,117,116,104,0,0,0,0,0,0,0,0,109,105,110,95,100,101,108,97,121,0,0,0,0,0,0,0,115,111,110,105,99,108,115,0,80,82,73,86,0,0,0,0,103,55,50,57,0,0,0,0,118,105,100,101,111,95,101,110,99,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,80,65,76,56,0,0,0,115,116,114,101,97,109,95,37,100,95,37,100,95,112,115,110,114,95,37,99,61,37,50,46,50,102,10,0,0,0,0,0,10,0,0,0,0,0,0,0,103,55,50,51,95,49,0,0,80,67,83,95,78,65,68,50,55,95,65,114,107,97,110,115,97,115,95,78,111,114,116,104,0,0,0,0,0,0,0,0,83,111,110,105,99,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,103,55,50,50,0,0,0,0,79,109,110,105,97,32,65,47,88,69,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,114,105,122,111,110,97,95,87,101,115,116,0,0,102,114,109,0,0,0,0,0,102,102,109,112,101,103,0,0,115,111,110,105,99,0,0,0,116,114,105,109,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,35,115,111,102,116,119,97,114,101,58,32,37,115,10,0,0,83,84,65,82,84,61,37,108,108,100,10,0,0,0,0,0,69,120,112,101,99,116,101,100,32,99,104,97,112,116,101,114,32,115,116,97,114,116,32,116,105,109,101,115,116,97,109,112,44,32,102,111,117,110,100,32,37,115,46,10,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,102,102,109,101,110,99,46,99,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,114,105,122,111,110,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,105,110,112,117,116,32,102,111,114,109,97,116,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,98,121,116,101,115,32,112,101,114,32,115,97,109,112,108,101,58,32,37,100,10,0,87,97,118,101,32,115,121,110,116,104,101,115,105,115,32,112,115,101,117,100,111,45,99,111,100,101,99,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,46,10,77,97,121,98,101,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,111,117,116,95,119,58,39,37,115,39,32,111,114,32,102,111,114,32,111,117,116,95,104,58,39,37,115,39,32,105,115,32,115,101,108,102,45,114,101,102,101,114,101,110,99,105,110,103,46,10,0,0,70,105,108,101,32,99,111,110,116,97,105,110,115,32,110,111,32,102,114,97,109,101,115,32,63,63,63,10,0,0,0,0,102,114,97,109,101,99,114,99,0,0,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,114,105,122,111,110,97,95,69,97,115,116,0,0,119,97,118,101,115,121,110,116,104,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,99,111,109,98,100,98,103,0,79,112,101,110,67,76,58,32,85,110,97,98,108,101,32,116,111,32,113,117,101,114,121,32,112,114,111,103,114,97,109,32,98,105,110,97,114,121,32,115,105,122,101,44,32,110,111,32,99,97,99,104,101,32,102,105,108,101,32,103,101,110,101,114,97,116,101,100,10,0,0,0,103,114,97,121,56,97,0,0,71,114,101,101,110,0,0,0,73,78,84,95,77,73,78,0,52,46,49,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,101,100], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2177184);
/* memory initializer */ allocate([115,101,116,32,99,101,110,116,101,114,32,109,105,120,32,108,101,118,101,108,0,0,0,0,50,110,100,32,112,97,115,115,32,104,97,115,32,109,111,114,101,32,102,114,97,109,101,115,32,116,104,97,110,32,49,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,0,0,0,0,0,69,82,82,79,82,58,32,98,108,111,99,107,95,112,114,101,100,105,99,116,111,114,91,49,93,32,61,32,37,100,10,0,105,110,118,97,108,105,100,32,65,65,67,32,109,97,103,105,99,32,99,111,111,107,105,101,10,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,67,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,67,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,86,73,73,0,0,0,0,0,0,0,0,114,101,102,32,37,99,32,76,37,100,58,37,115,10,0,0,67,111,100,101,99,32,48,120,37,120,32,105,115,32,110,111,116,32,105,110,32,116,104,101,32,102,117,108,108,32,108,105,115,116,46,10,0,0,0,0,115,107,105,112,112,105,110,103,32,97,100,100,105,116,111,110,97,108,32,65,68,80,67,32,99,104,117,110,107,10,0,0,105,109,97,103,101,50,0,0,76,117,99,97,115,65,114,116,115,32,86,73,77,65,32,97,117,100,105,111,0,0,0,0,65,110,103,117,108,97,114,95,68,101,103,114,101,101,0,0,99,51,95,111,112,97,99,105,116,121,0,0,0,0,0,0,116,102,102,0,0,0,0,0,112,99,109,95,115,51,50,98,101,0,0,0,0,0,0,0,72,46,50,54,51,32,97,100,118,97,110,99,101,100,32,105,110,116,114,97,32,99,111,100,105,110,103,32,47,32,77,80,69,71,45,52,32,65,67,32,112,114,101,100,105,99,116,105,111,110,0,0,0,0,0,0,118,98,118,32,98,117,102,102,101,114,32,111,118,101,114,102,108,111,119,10,0,0,0,0,50,46,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,105,110,32,114,118,108,99,32,101,115,99,10,0,0,0,0,0,0,71,79,80,32,40,37,115,41,32,99,108,111,115,101,100,95,103,111,112,61,37,100,32,98,114,111,107,101,110,95,108,105,110,107,61,37,100,10,0,0,101,120,116,101,114,110,95,104,117,102,102,0,0,0,0,0,56,120,56,100,99,116,0,0,114,99,95,109,97,120,95,113,117,97,110,116,105,122,101,114,58,0,0,0,0,0,0,0,99,104,97,110,103,105,110,103,32,119,105,100,116,104,32,37,100,32,45,62,32,37,100,32,47,32,104,101,105,103,104,116,32,37,100,32,45,62,32,37,100,32,111,110,32,115,108,105,99,101,32,37,100,10,0,0,37,46,54,103,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,105,110,118,97,108,105,100,32,102,112,115,32,40,37,100,47,37,100,41,10,0,0,0,0,102,102,118,49,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,86,73,0,85,115,105,110,103,32,100,101,102,97,117,108,116,32,118,105,100,101,111,32,116,105,109,101,32,98,97,115,101,32,115,105,110,99,101,32,104,97,118,105,110,103,32,110,111,32,97,117,100,105,111,32,112,97,99,107,101,116,32,98,101,102,111,114,101,32,116,104,101,32,102,105,114,115,116,32,118,105,100,101,111,32,112,97,99,107,101,116,0,0,0,0,0,0,0,0,78,101,119,32,87,97,118,101,0,0,0,0,0,0,0,0,32,67,52,50,48,112,57,32,88,89,83,67,83,83,61,52,50,48,80,57,0,0,0,0,32,32,78,111,32,80,114,111,103,114,97,109,10,0,0,0,118,105,109,97,0,0,0,0,83,116,97,116,105,115,116,105,99,115,58,32,37,108,108,100,32,98,121,116,101,115,32,114,101,97,100,44,32,37,100,32,115,101,101,107,115,10,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,86,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,111,112,101,110,32,116,104,101,32,39,37,115,39,32,112,114,111,116,111,99,111,108,32,102,111,114,32,119,114,105,116,105,110,103,10,0,0,0,0,0,0,0,105,76,66,67,32,40,73,110,116,101,114,110,101,116,32,76,111,119,32,66,105,116,114,97,116,101,32,67,111,100,101,99,41,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,97,110,110,111,116,32,111,112,101,110,32,116,104,101,32,104,50,54,52,95,109,112,52,116,111,97,110,110,101,120,98,32,66,83,70,33,10,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,118,105,101,110,99,46,99,0,0,0,0,40,105,110,116,54,52,95,116,41,115,116,50,45,62,116,105,109,101,95,98,97,115,101,46,110,117,109,32,42,32,97,115,116,50,45,62,114,97,116,101,32,61,61,32,40,105,110,116,54,52,95,116,41,115,116,50,45,62,116,105,109,101,95,98,97,115,101,46,100,101,110,32,42,32,97,115,116,50,45,62,115,99,97,108,101,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,73,86,0,102,51,50,108,101,32,100,101,109,117,120,101,114,0,0,0,105,108,98,99,0,0,0,0,97,98,111,114,116,32,100,101,99,111,100,105,110,103,32,111,110,32,109,105,110,111,114,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,0,111,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,69,120,97,99,116,108,121,32,111,110,101,32,65,83,83,47,83,83,65,32,115,116,114,101,97,109,32,105,115,32,110,101,101,100,101,100,46,10,0,0,69,114,114,111,114,32,115,116,99,45,62,100,101,99,111,100,101,95,100,101,108,97,121,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,117,105,100,0,0,0,0,0,116,105,116,108,101,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,73,73,73,0,0,0,0,0,0,0,0,73,65,67,32,40,73,110,100,101,111,32,65,117,100,105,111,32,67,111,100,101,114,41,0,83,101,110,100,32,82,84,67,80,32,66,89,69,32,112,97,99,107,101,116,115,32,119,104,101,110,32,102,105,110,105,115,104,105,110,103,0,0,0,0,97,115,102,45,62,112,97,99,107,101,116,95,115,105,122,101,95,108,101,102,116,32,60,32,70,82,65,77,69,95,72,69,65,68,69,82,95,83,73,90,69,32,124,124,32,97,115,102,45,62,112,97,99,107,101,116,95,115,101,103,109,101,110,116,115,32,60,32,49,0,0,0,115,116,114,101,97,109,32,37,100,44,32,109,105,115,115,105,110,103,32,109,97,110,100,97,116,111,114,121,32,97,116,111,109,115,44,32,98,114,111,107,101,110,32,104,101,97,100,101,114,10,0,0,0,0,0,0,45,45,62,62,32,37,100,0,97,108,112,104,97,95,109,111,100,101,0,0,0,0,0,0,109,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,102,114,97,109,101,115,58,32,37,117,10,0,0,0,0,102,108,118,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,73,73,0,98,121,116,101,115,0,0,0,105,97,99,0,0,0,0,0,67,72,65,80,0,0,0,0,37,99,58,37,50,46,50,102,32,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,67,97,108,105,102,111,114,110,105,97,95,73,0,0,82,101,97,108,65,117,100,105,111,32,76,111,115,115,108,101,115,115,0,0,0,0,0,0,49,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,49,48,0,0,0,0,0,0,0,0,103,97,109,109,97,0,0,0,114,97,108,102,0,0,0,0,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,0,97,112,97,100,0,0,0,0,70,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,105,109,97,103,101,32,102,114,111,109,32,102,105,108,101,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,57,0,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,101,118,101,110,10,0,0,0,0,109,101,97,110,95,118,111,108,117,109,101,58,32,37,46,49,102,32,100,66,10,0,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,32,97,117,100,105,111,0,0,119,58,37,100,32,104,58,37,100,32,102,109,116,58,37,115,32,115,97,114,58,37,100,47,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,102,109,116,58,37,115,32,115,97,114,58,37,100,47,37,100,32,102,108,97,103,115,58,48,120,37,48,120,10,0,0,0,118,111,108,117,109,101,58,37,102,32,118,111,108,117,109,101,95,100,66,58,37,102,10,0,115,101,116,32,109,105,110,105,109,117,109,32,100,117,114,97,116,105,111,110,32,105,110,32,115,101,99,111,110,100,115,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,56,0,105,32,60,32,40,115,105,122,101,111,102,40,102,114,101,113,105,110,102,111,115,41,32,47,32,115,105,122,101,111,102,40,40,102,114,101,113,105,110,102,111,115,41,91,48,93,41,41,0,0,0,0,0,0,0,0,102,108,118,0,0,0,0,0,98,109,118,95,97,117,100,105,111,0,0,0,0,0,0,0,105,110,102,105,110,105,116,121,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,117,116,32,99,104,97,110,110,101,108,32,110,97,109,101,32,34,37,46,56,115,34,10,0,0,0,0,0,0,0,0,101,110,97,98,108,101,32,99,111,109,98,109,97,116,99,104,105,110,103,32,97,108,108,32,116,104,101,32,116,105,109,101,0,0,0,0,0,0,0,0,79,112,101,110,67,76,58,32,117,110,97,98,108,101,32,116,111,32,111,112,101,110,32,99,108,98,105,110,32,102,105,108,101,32,102,111,114,32,119,114,105,116,101,10,0,0,0,0,98,103,114,52,52,52,98,101,0,0,0,0,0,0,0,0,71,114,97,121,0,0,0,0,73,78,84,95,77,65,88,0,53,46,48,40,115,105,100,101,41,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,106,111,105,110,46,99,0,0,0,98,97,121,101,114,32,100,105,116,104,101,114,0,0,0,0,99,108,101,118,0,0,0,0,102,108,105,99,0,0,0,0,50,110,100,32,112,97,115,115,32,104,97,115,32,102,101,119,101,114,32,102,114,97,109,101,115,32,116,104,97,110,32,49,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,0,0,0,0,69,82,82,79,82,58,32,98,108,111,99,107,95,112,114,101,100,105,99,116,111,114,91,48,93,32,61,32,37,100,10,0,99,104,97,110,110,101,108,95,99,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,99,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,55,0,87,101,105,103,104,116,101,100,32,80,45,70,114,97,109,101,115,58,32,89,58,37,46,49,102,37,37,32,85,86,58,37,46,49,102,37,37,10,0,0,110,111,110,101,0,0,0,0,115,101,116,32,116,105,109,101,32,111,118,101,114,32,119,104,105,99,104,32,100,101,99,114,101,97,115,101,32,111,102,32,118,111,108,117,109,101,32,105,115,32,100,101,116,101,114,109,105,110,101,100,0,0,0,0,56,83,86,88,32,102,105,98,111,110,97,99,99,105,0,0,65,110,103,117,108,97,114,95,82,97,100,105,97,110,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,50,32,111,112,97,99,105,116,121,0,0,100,101,102,97,117,108,116,0,105,110,116,101,114,108,97,99,101,100,0,0,0,0,0,0,97,105,99,0,0,0,0,0,115,116,117,102,102,105,110,103,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,37,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,109,97,112,112,101,100,32,37,100,46,10,0,0,0,0,0,0,49,46,32,109,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,105,110,32,114,118,108,99,32,101,115,99,10,0,0,0,0,0,0,104,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,111,114,32,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,102,105,114,115,116,32,102,105,101,108,100,10,0,0,0,0,0,0,77,74,80,69,71,32,100,101,99,111,100,101,114,0,0,0,79,110,101,32,114,101,102,101,114,101,110,99,101,32,112,101,114,32,112,97,114,116,105,116,105,111,110,44,32,97,115,32,111,112,112,111,115,101,100,32,116,111,32,111,110,101,32,114,101,102,101,114,101,110,99,101,32,112,101,114,32,109,97,99,114,111,98,108,111,99,107,0,114,99,95,109,105,110,95,113,117,97,110,116,105,122,101,114,58,0,0,0,0,0,0,0,110,111,110,45,101,120,105,115,116,105,110,103,32,83,80,83,32,37,117,32,114,101,102,101,114,101,110,99,101,100,10,0,78,79,80,84,83,0,0,0,65,83,85,83,32,86,50,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,54,0,67,97,98,97,114,101,116,0,32,67,52,52,52,32,88,89,83,67,83,83,61,52,52,52,0,0,0,0,0,0,0,0,32,32,80,114,111,103,114,97,109,32,37,100,32,37,115,10,0,0,0,0,0,0,0,0,56,115,118,120,95,102,105,98,0,0,0,0,0,0,0,0,98,97,110,100,112,97,115,115,0,0,0,0,0,0,0,0,102,108,97,99,0,0,0,0,100,101,102,97,117,108,116,0,115,50,0,0,0,0,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,53,0,102,108,97,99,0,0,0,0,80,101,97,107,32,108,101,118,101,108,32,100,66,58,32,37,102,10,0,0,0,0,0,0,56,83,86,88,32,101,120,112,111,110,101,110,116,105,97,108,0,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,93,10,0,0,0,0,0,0,102,105,108,101,32,37,115,10,0,0,0,0,0,0,0,0,104,50,54,52,95,109,112,52,116,111,97,110,110,101,120,98,0,0,0,0,0,0,0,0,84,105,109,101,32,98,97,115,101,32,105,115,32,105,110,97,99,99,117,114,97,116,101,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,116,121,112,101,0,0,0,0,0,0,112,97,100,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,102,105,108,109,115,116,114,105,112,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,52,0,115,51,50,98,101,32,100,101,109,117,120,101,114,0,0,0,111,117,116,95,103,97,105,110,0,0,0,0,0,0,0,0,56,115,118,120,95,101,120,112,0,0,0,0,0,0,0,0,101,120,112,108,111,100,101,0,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,111,102,32,115,105,108,101,110,99,101,32,116,111,32,97,100,100,0,0,0,0,0,69,114,114,111,114,32,115,116,99,45,62,109,115,98,95,112,116,115,95,115,104,105,102,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,103,101,110,101,114,97,116,105,111,110,95,117,105,100,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,109,105,120,46,99,0,0,0,102,105,108,109,115,116,114,105,112,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,51,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,115,46,10,0,71,46,55,50,57,0,0,0,115,101,110,100,95,98,121,101,0,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,116,114,97,99,107,32,105,100,32,37,100,10,0,0,0,0,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,115,116,101,114,101,111,32,109,111,100,101,32,105,115,32,110,111,116,32,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,102,97,100,101,45,105,110,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,50,0,100,101,99,97,121,91,37,100,93,58,32,37,102,32,105,115,32,111,117,116,32,111,102,32,97,108,108,111,119,101,100,32,114,97,110,103,101,58,32,40,48,44,32,49,93,10,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,104,0,0,0,0,0,0,0,103,55,50,57,0,0,0,0,80,73,67,0,0,0,0,0,37,102,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,98,101,115,116,95,100,105,115,116,32,60,32,73,78,84,54,52,95,77,65,88,0,0,0,80,83,78,82,61,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,115,107,97,95,122,111,110,101,95,49,0,33,105,115,95,99,111,109,112,111,117,110,100,0,0,0,0,102,102,109,101,116,97,100,97,116,97,0,0,0,0,0,0,71,46,55,50,51,46,49,0,116,101,115,116,115,114,99,0,114,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,98,97,109,97,95,87,101,115,116,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,121,95,109,111,100,101,44,32,122,101,114,111,95,99,111,117,110,116,115,46,121,95,109,111,100,101,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,121,95,109,111,100,101,41,41,0,0,0,0,0,0,0,103,55,50,51,95,49,0,0,114,97,116,101,0,0,0,0,45,97,112,97,100,32,105,115,32,102,111,114,119,97,114,100,101,100,32,116,111,32,108,97,118,102,105,32,115,105,109,105,108,97,114,108,121,32,116,111,32,45,97,102,32,97,112,97,100,61,37,115,46,10,0,0,102,102,109,101,116,97,100,97,116,97,0,0,0,0,0,0,77,111,108,100,32,99,111,108,111,114,32,105,115,32,115,101,116,32,119,104,105,108,101,32,109,111,108,100,32,105,115,110,39,116,44,32,105,103,110,111,114,105,110,103,32,116,104,101,32,99,111,108,111,114,46,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,65,108,97,98,97,109,97,95,69,97,115,116,0,0,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,0,0,67,111,110,115,116,114,97,105,110,101,100,32,69,110,101,114,103,121,32,76,97,112,112,101,100,32,84,114,97,110,115,102,111,114,109,32,40,67,69,76,84,41,0,0,0,0,0,0,119,58,37,100,10,0,0,0,100,115,116,95,118,95,99,104,114,95,112,111,115,0,0,0,102,102,109,0,0,0,0,0,33,40,108,102,109,45,62,108,101,102,116,95,117,118,91,84,88,95,49,54,88,49,54,93,32,38,32,108,102,109,45,62,108,101,102,116,95,117,118,91,84,88,95,52,88,52,93,41,0,0,0,0,0,0,0,0,115,101,110,100,95,102,105,101,108,100,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,100,101,105,110,116,0,0,0,99,101,108,116,0,0,0,0,102,102,109,0,0,0,0,0,102,117,108,108,0,0,0,0,119,98,0,0,0,0,0,0,104,0,0,0,0,0,0,0,98,103,114,52,52,52,108,101,0,0,0,0,0,0,0,0,71,111,108,100,101,110,82,111,100,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,53,46,48,0,0,0,0,0,98,97,121,101,114,0,0,0,111,117,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,104,97,58,97,58,49,50,56,58,55,44,118,97,58,97,44,100,114,58,97,0,0,0,0,101,109,112,116,121,32,115,116,97,116,115,32,102,105,108,101,10,0,0,0,0,0,0,0,69,82,82,79,82,58,32,115,116,101,112,95,105,110,100,101,120,91,37,100,93,32,61,32,37,105,10,0,0,0,0,0,101,112,97,102,0,0,0,0,83,116,101,114,101,111,32,82,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,83,116,101,114,101,111,32,82,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,85,110,107,110,111,119,110,32,69,82,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,37,100,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,48,0,0,0,0,0,0,0,105,56,99,32,100,99,44,104,44,118,44,112,58,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,10,0,0,108,117,109,97,95,109,115,105,122,101,95,121,0,0,0,0,73,110,118,97,108,105,100,32,85,84,70,45,56,32,105,110,32,100,101,99,111,100,101,100,32,115,117,98,116,105,116,108,101,115,32,116,101,120,116,59,32,109,97,121,98,101,32,109,105,115,115,105,110,103,32,45,115,117,98,95,99,104,97,114,101,110,99,32,111,112,116,105,111,110,10,0,0,0,0,0,81,68,101,115,105,103,110,32,77,117,115,105,99,0,0,0,76,105,110,101,97,114,95,77,105,108,101,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,78,97,117,116,105,99,97,108,0,0,0,0,0,0,99,50,95,111,112,97,99,105,116,121,0,0,0,0,0,0,99,97,98,97,99,45,105,100,99,0,0,0,0,0,0,0,99,108,111,99,107,0,0,0,117,115,101,32,111,110,108,121,32,98,105,116,101,120,97,99,116,32,102,117,110,99,116,105,111,110,115,32,40,101,120,99,101,112,116,32,40,73,41,68,67,84,41,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,73,32,99,98,112,121,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,102,105,114,115,116,32,102,105,101,108,100,32,109,105,115,115,105,110,103,10,0,0,0,0,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,84,72,80,32,118,105,100,101,111,0,0,0,0,0,109,105,120,101,100,45,114,101,102,115,0,0,0,0,0,0,113,117,97,110,116,105,122,101,114,32,115,101,116,116,105,110,103,115,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,0,0,0,0,0,100,114,111,112,95,101,118,101,110,0,0,0,0,0,0,0,80,80,83,32,99,104,97,110,103,101,32,102,114,111,109,32,37,100,32,116,111,32,37,100,32,102,111,114,98,105,100,100,101,110,10,0,0,0,0,0,109,105,100,95,115,105,100,101,0,0,0,0,0,0,0,0,67,111,117,112,108,105,110,103,32,83,116,97,114,116,32,66,97,110,100,0,0,0,0,0,32,32,84,80,75,58,0,0,97,115,118,50,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,54,120,53,0,0,0,0,0,78,97,116,105,118,101,32,65,109,101,114,105,99,97,110,0,32,67,52,50,50,32,88,89,83,67,83,83,61,52,50,50,0,0,0,0,0,0,0,0,110,97,109,101,0,0,0,0,100,101,102,97,117,108,116,0,113,100,109,99,0,0,0,0,112,114,111,98,95,103,97,114,102,32,60,61,32,50,53,53,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,102,105,114,115,116,32,102,105,101,108,100,0,0,0,0,0,0,118,112,56,47,100,101,99,111,100,101,114,47,100,101,99,111,100,101,102,114,97,109,101,46,99,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,65,65,67,32,76,65,84,77,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,32,76,65,84,77,32,115,121,110,116,97,120,41,0,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,97,32,115,105,110,103,108,101,32,97,108,108,111,99,97,116,101,100,32,98,108,111,99,107,0,0,0,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,108,105,115,116,32,101,110,116,114,121,32,39,37,115,39,32,105,110,32,108,105,115,116,32,102,105,108,101,10,0,0,0,0,0,59,32,99,111,110,102,105,103,61,0,0,0,0,0,0,0,97,98,50,114,0,0,0,0,113,112,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,101,97,0,0,0,0,0,0,108,117,109,97,95,115,116,114,101,110,103,116,104,0,0,0,115,51,50,108,101,32,100,101,109,117,120,101,114,0,0,0,78,79,80,84,83,0,0,0,97,97,99,95,108,97,116,109,0,0,0,0,0,0,0,0,100,101,116,101,99,116,32,105,109,112,114,111,112,101,114,32,98,105,116,115,116,114,101,97,109,32,108,101,110,103,116,104,0,0,0,0,0,0,0,0,98,102,102,0,0,0,0,0,69,114,114,111,114,32,115,116,99,45,62,116,105,109,101,95,98,97,115,101,95,105,100,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,101,97,95,99,100,97,116,97,0,0,0,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,95,112,108,97,116,102,111,114,109,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,66,105,110,107,32,65,117,100,105,111,32,40,68,67,84,41,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,85,115,101,32,109,111,100,101,32,48,32,102,111,114,32,72,50,54,52,32,105,110,32,82,84,80,0,0,0,0,0,0,103,101,116,95,119,97,118,95,104,101,97,100,101,114,32,102,97,105,108,101,100,10,0,0,100,120,97,0,0,0,0,0,108,117,109,97,95,112,114,101,95,102,105,108,116,101,114,95,114,97,100,105,117,115,0,0,86,95,77,83,47,86,70,87,47,70,79,85,82,67,67,0,37,89,45,37,109,45,37,100,32,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,109,97,120,95,97,108,108,111,99,0,0,0,0,0,0,0,105,119,0,0,0,0,0,0,98,105,110,107,97,117,100,105,111,95,100,99,116,0,0,0,71,69,79,66,0,0,0,0,115,101,116,32,98,105,116,109,97,112,32,102,105,108,101,110,97,109,101,0,0,0,0,0,100,118,0,0,0,0,0,0,37,88,0,0,0,0,0,0,106,116,0,0,0,0,0,0,108,97,118,102,105,46,112,115,110,114,46,109,115,101,95,97,118,103,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,100,101,102,97,117,108,116,0,66,105,110,107,32,65,117,100,105,111,32,40,82,68,70,84,41,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,98,101,115,116,95,102,105,108,116,101,114,95,100,105,102,102,91,83,87,73,84,67,72,65,66,76,69,95,70,73,76,84,69,82,83,93,32,61,61,32,48,0,0,0,0,0,0,0,115,101,116,32,116,111,112,32,108,101,102,116,32,121,32,99,111,111,114,100,105,110,97,116,101,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,98,105,110,107,97,117,100,105,111,95,114,100,102,116,0,0,104,101,105,103,104,116,0,0,97,102,111,114,109,97,116,0,108,115,0,0,0,0,0,0,99,97,110,110,111,116,32,97,100,106,117,115,116,32,97,117,100,105,111,32,98,121,116,101,115,10,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,109,97,105,110,95,119,0,0,119,105,100,116,104,32,109,117,115,116,32,98,101,32,101,118,101,110,10,0,0,0,0,0,65,84,82,65,67,49,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,41,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,109,98,95,110,111,114,109,95,97,99,116,105,118,105,116,121,95,109,97,112,0,0,0,0,100,115,116,95,104,95,99,104,114,95,112,111,115,0,0,0,100,116,115,104,100,0,0,0,97,108,108,115,0,0,0,0,115,101,116,32,104,105,103,104,32,100,114,111,112,112,105,110,103,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,100,116,115,0,0,0,0,0,97,116,114,97,99,49,0,0,100,115,105,99,105,110,0,0,101,110,97,98,108,101,32,99,111,109,98,109,97,116,99,104,105,110,103,32,111,110,108,121,32,111,110,32,115,99,101,110,101,32,99,104,97,110,103,101,0,0,0,0,0,0,0,0,79,112,101,110,67,76,58,32,107,101,114,110,101,108,32,98,117,105,108,100,32,101,114,114,111,114,115,32,119,114,105,116,116,101,110,32,116,111,32,120,50,54,52,95,107,101,114,110,101,108,95,98,117,105,108,100,95,108,111,103,46,116,120,116,10,0,0,0,0,0,0,0,118,102,45,62,119,32,62,32,48,0,0,0,0,0,0,0,114,103,98,52,52,52,98,101,0,0,0,0,0,0,0,0,71,111,108,100,0,0,0,0,34,37,115,34,0,0,0,0,51,46,49,0,0,0,0,0,108,101,97,118,101,32,99,104,111,105,99,101,32,116,111,32,115,119,115,0,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,0,0,0,0,97,99,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,109,101,114,103,101,112,108,97,110,101,115,46,99,0,0,0,0,114,99,95,108,111,111,107,97,104,101,97,100,61,37,100,0,109,105,115,109,97,116,99,104,32,105,110,32,99,111,100,101,100,32,115,97,109,112,108,101,32,99,111,117,110,116,10,0,100,110,120,104,100,0,0,0,115,116,101,114,101,111,95,114,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,115,116,101,114,101,111,95,114,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,100,101,102,97,117,108,116,0,105,110,105,116,105,97,108,105,122,105,110,103,32,108,97,116,109,99,116,120,10,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,105,37,100,32,118,44,104,44,100,99,44,100,100,108,44,100,100,114,44,118,114,44,104,100,44,118,108,44,104,117,58,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,10,0,0,0,0,0,0,0,0,115,108,111,119,0,0,0,0,73,110,118,97,108,105,100,32,109,101,100,105,97,32,116,121,112,101,32,102,111,114,32,115,117,98,116,105,116,108,101,115,10,0,0,0,0,0,0,0,77,80,69,71,45,52,32,65,117,100,105,111,32,76,111,115,115,108,101,115,115,32,67,111,100,105,110,103,32,40,65,76,83,41,0,0,0,0,0,0,76,105,110,101,97,114,95,70,97,116,104,111,109,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,49,32,111,112,97,99,105,116,121,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,109,98,95,97,99,116,105,118,105,116,121,95,109,97,112,0,99,97,98,97,99,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,100,105,114,97,99,0,0,0,98,105,116,101,120,97,99,116,0,0,0,0,0,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,112,105,99,116,117,114,101,32,115,105,122,101,32,111,102,32,37,100,120,37,100,32,105,115,32,110,111,116,32,118,97,108,105,100,32,102,111,114,32,116,104,101,32,72,46,50,54,51,32,99,111,100,101,99,46,10,86,97,108,105,100,32,115,105,122,101,115,32,97,114,101,32,49,50,56,120,57,54,44,32,49,55,54,120,49,52,52,44,32,51,53,50,120,50,56,56,44,32,55,48,52,120,53,55,54,44,32,97,110,100,32,49,52,48,56,120,49,49,53,50,46,32,84,114,121,32,72,46,50,54,51,43,46,10,0,0,0,0,73,32,99,98,112,99,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,99,32,99,111,100,101,32,97,116,10,0,0,0,0,0,116,104,112,0,0,0,0,0,78,111,110,45,115,116,114,105,99,116,32,40,110,111,116,32,66,108,117,45,114,97,121,32,99,111,109,112,97,116,105,98,108,101,41,0,0,0,0,0,114,99,95,116,97,114,103,101,116,95,98,105,116,114,97,116,101,58,0,0,0,0,0,0,114,101,112,101,97,116,108,97,115,116,0,0,0,0,0,0,110,111,110,45,101,120,105,115,116,105,110,103,32,80,80,83,32,37,117,32,114,101,102,101,114,101,110,99,101,100,10,0,114,105,103,104,116,95,115,105,100,101,0,0,0,0,0,0,99,112,108,95,115,116,97,114,116,95,98,97,110,100,0,0,32,32,70,84,80,75,58,0,65,83,85,83,32,86,49,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,74,117,110,103,108,101,0,0,32,67,52,50,48,106,112,101,103,32,88,89,83,67,83,83,61,52,50,48,74,80,69,71,0,0,0,0,0,0,0,0,65,66,73,32,118,101,114,115,105,111,110,32,109,105,115,109,97,116,99,104,0,0,0,0,32,32,32,32,0,0,0,0,100,102,97,0,0,0,0,0,109,112,52,97,108,115,0,0,110,101,103,97,116,101,0,0,100,97,116,97,95,115,122,0,111,114,100,101,114,0,0,0,98,102,102,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,57,78,0,0,0,105,110,116,101,114,108,101,97,118,101,0,0,0,0,0,0,100,97,117,100,0,0,0,0,103,95,116,105,109,101,98,97,115,101,46,110,117,109,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,99,102,103,45,62,103,95,116,105,109,101,98,97,115,101,46,100,101,110,93,0,0,0,0,84,114,117,101,72,68,0,0,46,0,0,0,0,0,0,0,35,69,88,84,73,78,70,58,37,102,44,10,37,115,10,0,112,114,111,103,95,116,104,114,101,115,0,0,0,0,0,0,84,111,111,32,109,117,99,104,32,101,120,116,114,97,100,97,116,97,33,10,0,0,0,0,99,114,99,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,103,95,116,105,109,101,98,97,115,101,46,110,117,109,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,99,102,103,45,62,103,95,116,105,109,101,98,97,115,101,46,100,101,110,93,0,0,0,0,115,112,97,116,105,97,108,32,99,104,114,111,109,97,32,115,116,114,101,110,103,116,104,0,99,108,69,110,113,117,101,117,101,67,111,112,121,66,117,102,102,101,114,32,101,114,114,111,114,32,39,37,100,39,10,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,56,78,0,0,0,115,50,52,98,101,32,100,101,109,117,120,101,114,0,0,0,116,114,117,101,104,100,0,0,98,117,102,102,101,114,0,0,115,101,116,32,104,105,115,116,111,103,114,97,109,32,109,111,100,101,0,0,0,0,0,0,115,101,116,32,116,104,101,32,105,110,116,101,110,115,105,116,121,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,100,101,99,32,116,97,103,32,39,48,120,37,48,52,120,39,32,102,111,114,32,115,116,114,101,97,109,32,110,117,109,98,101,114,32,37,100,10,0,0,0,0,0,0,0,0,109,111,100,105,102,105,99,97,116,105,111,110,95,100,97,116,101,0,0,0,0,0,0,0,84,104,101,32,110,101,105,103,104,98,111,114,104,111,111,100,32,116,111,32,102,105,116,32,116,104,101,32,103,114,97,100,105,101,110,116,32,116,111,46,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,55,78,0,0,0,98,40,88,44,89,41,0,0,86,81,70,32,84,119,105,110,86,81,0,0,0,0,0,0,66,45,114,101,102,32,97,116,32,102,114,97,109,101,32,37,100,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,66,45,112,121,114,97,109,105,100,32,37,115,32,10,0,0,0,0,0,0,104,50,54,52,95,109,111,100,101,48,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,102,111,114,32,99,109,111,118,32,97,116,111,109,32,33,10,0,0,0,0,116,97,98,0,0,0,0,0,86,95,81,85,73,67,75,84,73,77,69,0,0,0,0,0,73,78,84,69,82,52,88,52,95,67,72,82,79,77,65,0,83,83,82,0,0,0,0,0,115,116,97,114,116,95,116,105,109,101,0,0,0,0,0,0,99,111,110,99,97,116,0,0,100,101,102,97,117,108,116,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,54,78,0,0,0,116,102,102,0,0,0,0,0,116,119,105,110,118,113,0,0,71,69,79,0,0,0,0,0,76,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,53,78,0,0,0,99,100,120,108,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,108,67,114,101,97,116,101,75,101,114,110,101,108,0,0,77,80,49,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,49,41,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,116,111,112,32,102,105,101,108,100,0,0,0,0,0,0,0,0,100,97,116,97,0,0,0,0,84,105,109,101,99,111,100,101,32,102,114,97,109,101,32,114,97,116,101,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,0,99,100,103,0,0,0,0,0,121,117,118,52,49,48,112,0,0,0,0,255,0,0,0,0,67,97,110,110,111,116,32,102,105,110,100,32,99,111,108,111,114,32,39,37,115,39,10,0,115,101,116,32,112,108,97,110,101,115,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,52,78,0,0,0,65,86,95,76,79,71,95,70,79,82,67,69,95,78,79,67,79,76,79,82,0,0,0,0,99,97,118,115,118,105,100,101,111,0,0,0,0,0,0,0,73,77,71,85,84,73,76,83,0,0,0,0,0,0,0,0,102,114,97,109,101,45,62,105,95,114,101,102,101,114,101,110,99,101,95,99,111,117,110,116,32,62,32,48,0,0,0,0,83,72,65,49,54,48,0,0,115,101,116,32,109,97,120,32,110,117,109,98,101,114,32,111,102,32,115,116,101,112,115,32,117,115,101,100,32,116,111,32,99,111,109,112,117,116,101,32,116,104,101,32,109,97,112,112,105,110,103,0,0,0,0,0,109,112,49,0,0,0,0,0,89,67,103,67,111,0,0,0,99,111,115,104,0,0,0,0,100,101,102,97,117,108,116,0,66,85,70,70,69,82,95,84,79,79,95,83,77,65,76,76,0,0,0,0,0,0,0,0,97,117,100,105,111,32,102,111,114,109,97,116,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,102,114,111,110,116,32,108,101,102,116,0,0,0,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,37,115,32,45,62,32,37,115,32,99,111,110,118,101,114,116,101,114,10,0,0,0,0,0,0,69,120,97,99,116,108,121,32,111,110,101,32,115,99,97,108,101,114,32,97,108,103,111,114,105,116,104,109,32,109,117,115,116,32,98,101,32,99,104,111,115,101,110,44,32,103,111,116,32,37,88,10,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,98,105,99,117,98,105,99,0,102,114,97,109,101,32,77,66,32,115,105,122,101,32,40,37,100,120,37,100,41,32,62,32,108,101,118,101,108,32,108,105,109,105,116,32,40,37,100,41,10,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,85,84,77,95,122,111,110,101,95,51,78,0,0,0,105,115,102,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2187424);
/* memory initializer */ allocate([112,112,58,32,37,115,58,58,37,115,10,0,0,0,0,0,100,101,102,97,117,108,116,0,82,101,97,108,65,117,100,105,111,32,83,73,80,82,32,47,32,65,67,69,76,80,46,78,69,84,0,0,0,0,0,0,115,114,99,95,118,95,99,104,114,95,112,111,115,0,0,0,99,120,58,32,37,100,44,32,99,121,58,32,37,100,44,32,99,119,58,32,37,100,44,32,99,104,58,32,37,100,44,32,114,120,58,32,37,100,44,32,114,121,58,32,37,100,44,32,101,100,103,101,58,32,37,100,32,98,108,111,99,107,115,105,122,101,58,32,37,100,32,99,111,110,116,114,97,115,116,58,32,37,100,32,115,101,97,114,99,104,58,32,37,100,10,0,69,78,68,72,68,82,0,0,99,97,102,0,0,0,0,0,115,45,62,108,105,110,101,115,105,122,101,32,61,61,32,99,45,62,115,116,114,105,100,101,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,37,108,108,100,9,0,0,0,97,102,113,45,62,114,101,109,97,105,110,105,110,103,95,115,97,109,112,108,101,115,32,61,61,32,97,102,113,45,62,114,101,109,97,105,110,105,110,103,95,100,101,108,97,121,0,0,83,70,32,109,111,100,101,32,49,58,32,105,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,115,33,10,0,92,37,49,91,49,50,51,52,93,99,37,49,91,92,125,93,37,110,0,0,0,0,0,0,13,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,97,108,108,32,99,104,97,110,110,101,108,115,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,80,67,83,95,77,95,112,111,114,97,108,111,107,111,95,85,84,77,95,51,50,83,0,0,97,100,112,99,109,95,115,119,102,0,0,0,0,0,0,0,32,32,35,37,100,58,32,116,111,116,100,105,102,102,61,37,48,56,108,108,120,32,109,97,120,98,100,105,102,102,61,37,48,56,108,108,120,37,115,37,115,37,115,37,115,10,0,0,97,100,112,99,109,95,100,116,107,0,0,0,0,0,0,0,115,105,112,114,0,0,0,0,65,67,45,51,32,69,110,99,111,100,101,114,0,0,0,0,111,118,101,114,108,97,112,0,72,82,68,32,119,105,116,104,32,118,101,114,121,32,108,97,114,103,101,32,116,105,109,101,115,99,97,108,101,32,97,110,100,32,98,117,102,115,105,122,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,70,105,120,101,100,45,80,111,105,110,116,32,65,67,45,51,32,69,110,99,111,100,101,114,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,97,117,100,105,111,32,115,101,114,118,105,99,101,32,116,121,112,101,32,102,111,114,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,0,100,114,99,95,115,99,97,108,101,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,115,99,0,0,0,0,0,0,79,112,101,110,67,76,58,32,67,111,109,112,105,108,97,116,105,111,110,32,102,97,105,108,101,100,44,32,117,110,97,98,108,101,32,116,111,32,99,114,101,97,116,101,32,102,105,108,101,32,120,50,54,52,95,107,101,114,110,101,108,95,98,117,105,108,100,95,108,111,103,46,116,120,116,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,10,0,0,0,0,0,114,103,98,52,52,52,108,101,0,0,0,0,0,0,0,0,71,104,111,115,116,87,104,105,116,101,0,0,0,0,0,0,37,108,108,88,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,65,65,67,32,102,114,97,109,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,113,117,97,100,40,115,105,100,101,41,0,0,0,0,0,0,97,117,116,111,0,0,0,0,105,110,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,0,102,97,0,0,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,112,105,99,116,117,114,101,46,10,0,0,0,0,0,0,0,0,70,111,114,109,97,116,32,37,105,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,105,110,102,108,97,116,101,58,32,37,100,46,10,0,0,0,0,0,0,77,105,115,115,105,110,103,32,111,114,32,105,110,99,111,109,112,108,101,116,101,32,101,120,116,114,97,100,97,116,97,46,10,0,0,0,0,0,0,0,114,99,95,108,111,111,107,97,104,101,97,100,61,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,105,110,32,112,97,99,107,101,116,10,0,0,0,0,67,104,114,111,109,97,32,117,110,112,97,99,107,105,110,103,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,72,68,67,68,0,0,0,0,72,68,67,68,0,0,0,0,114,101,100,32,37,48,120,44,32,103,114,101,101,110,32,37,48,120,44,32,98,108,117,101,32,37,48,120,10,0,0,0,67,111,108,111,114,32,105,110,100,101,120,32,48,32,105,115,32,110,111,116,32,116,114,97,110,115,112,97,114,101,110,116,46,32,84,114,97,110,115,112,97,114,101,110,99,121,32,119,105,108,108,32,98,101,32,109,101,115,115,101,100,32,117,112,46,10,0,0,0,0,0,0,115,101,116,32,80,104,111,116,111,115,104,111,112,32,99,117,114,118,101,115,32,102,105,108,101,32,110,97,109,101,0,0,97,117,100,105,111,32,99,111,110,102,105,103,32,99,104,97,110,103,101,100,10,0,0,0,10,0,0,0,0,0,0,0,95,119,105,100,116,104,0,0,80,67,83,95,77,95,112,111,114,97,108,111,107,111,95,85,84,77,95,51,50,78,0,0,118,101,99,116,111,114,95,115,101,103,109,101,110,116,32,111,118,101,114,114,101,97,100,10,0,0,0,0,0,0,0,0,105,49,54,32,118,44,104,44,100,99,44,112,58,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,32,37,50,46,48,102,37,37,10,0,0,119,109,118,50,0,0,0,0,32,37,48,50,88,0,0,0,10,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,105,110,116,101,114,32,98,108,111,99,107,58,32,37,100,32,120,32,37,100,32,40,37,100,41,10,0,0,0,0,0,0,0,0,115,105,122,101,32,60,61,32,49,54,48,32,47,32,50,0,99,97,102,0,0,0,0,0,100,105,115,99,97,114,100,32,37,100,47,37,100,32,115,97,109,112,108,101,115,10,0,0,82,101,115,101,114,118,101,100,32,98,105,116,0,0,0,0,65,114,105,116,104,109,101,116,105,99,32,99,111,100,105,110,103,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,84,83,67,32,65,47,53,50,66,32,40,65,67,45,51,44,32,69,45,65,67,45,51,41,0,0,0,0,0,0,0,110,98,95,102,114,97,109,101,115,32,105,115,32,37,100,10,0,0,0,0,0,0,0,0,76,105,110,101,97,114,95,89,97,114,100,95,73,110,100,105,97,110,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,99,49,95,111,112,97,99,105,116,121,0,0,0,0,0,0,123,92,105,49,125,0,0,0,115,107,105,112,112,105,110,103,32,117,110,115,117,112,112,111,114,116,101,100,32,65,76,80,72,65,32,99,104,117,110,107,10,0,0,0,0,0,0,0,87,97,118,80,97,99,107,32,101,110,99,111,100,101,114,0,67,111,110,116,101,120,116,32,102,111,114,32,98,108,111,99,107,32,37,100,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,10,0,0,0,0,86,97,108,117,101,32,98,121,32,119,104,105,99,104,32,116,104,101,32,119,105,100,116,104,47,104,101,105,103,104,116,32,115,104,111,117,108,100,32,98,101,32,100,105,118,105,115,105,98,108,101,0,0,0,0,0,115,108,105,99,101,115,45,109,97,120,0,0,0,0,0,0,112,99,109,95,115,50,52,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,112,114,111,98,108,101,109,58,32,67,66,70,48,32,99,104,117,110,107,32,116,111,111,32,108,97,114,103,101,32,40,48,120,37,88,32,98,121,116,101,115,41,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,112,57,46,99,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,97,114,116,32,99,111,100,101,32,48,120,37,120,10,0,0,0,0,0,0,0,0,73,110,116,101,114,108,97,99,105,110,103,0,0,0,0,0,112,108,97,99,101,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,32,105,110,32,101,120,116,114,97,100,97,116,97,32,105,110,115,116,101,97,100,32,111,102,32,101,118,101,114,121,32,107,101,121,102,114,97,109,101,0,0,0,0,0,84,104,101,32,115,112,101,99,105,102,105,101,100,32,112,105,99,116,117,114,101,32,115,105,122,101,32,111,102,32,37,100,120,37,100,32,105,115,32,110,111,116,32,118,97,108,105,100,32,102,111,114,32,116,104,101,32,72,46,50,54,49,32,99,111,100,101,99,46,10,86,97,108,105,100,32,115,105,122,101,115,32,97,114,101,32,49,55,54,120,49,52,52,44,32,51,53,50,120,50,56,56,10,0,72,101,97,100,101,114,32,112,97,99,107,101,116,32,112,97,115,115,101,100,32,116,111,32,102,114,97,109,101,32,100,101,99,111,100,101,114,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,77,66,95,116,121,112,101,10,0,0,0,0,0,0,0,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,114,101,97,108,95,99,104,32,61,61,32,50,0,0,0,0,77,74,80,69,71,32,40,77,111,116,105,111,110,32,74,80,69,71,41,0,0,0,0,0,78,111,116,32,97,32,86,111,114,98,105,115,32,73,32,97,117,100,105,111,32,112,97,99,107,101,116,46,10,0,0,0,110,111,114,109,97,108,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,58,0,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,103,110,97,116,117,114,101,32,105,110,32,83,101,116,117,112,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,68,101,112,116,104,32,109,105,115,109,97,116,99,104,46,32,67,111,110,116,97,105,110,101,114,32,37,105,32,98,112,112,44,32,70,114,97,109,101,32,100,97,116,97,58,32,37,105,32,98,112,112,10,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,98,121,116,101,115,116,114,101,97,109,95,101,110,100,32,45,32,98,121,116,101,115,116,114,101,97,109,32,62,61,32,97,118,99,116,120,45,62,119,105,100,116,104,32,47,32,50,0,112,112,115,95,105,100,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,118,99,49,105,109,97,103,101,0,0,0,0,0,0,0,0,111,117,116,95,104,0,0,0,108,101,102,116,95,115,105,100,101,0,0,0,0,0,0,0,83,101,108,101,99,116,101,100,32,98,121,32,116,104,101,32,69,110,99,111,100,101,114,0,32,100,66,70,83,0,0,0,49,32,102,111,114,32,114,101,115,101,114,118,101,100,32,82,69,83,95,84,82,65,78,83,84,65,66,32,105,115,32,102,111,114,98,105,100,100,101,110,10,0,0,0,0,0,0,0,97,115,118,49,0,0,0,0,73,110,118,97,108,105,100,32,111,112,99,111,100,101,32,115,101,101,110,32,64,37,100,10,0,0,0,0,0,0,0,0,66,77,73,49,0,0,0,0,80,67,83,95,77,111,110,116,101,95,77,97,114,105,111,95,73,116,97,108,121,95,50,0,99,57,51,0,0,0,0,0,98,105,116,115,32,112,101,114,32,114,97,119,32,115,97,109,112,108,101,58,32,37,100,32,33,61,32,49,48,45,98,105,116,10,0,0,0,0,0,0,80,111,112,47,70,117,110,107,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,115,116,114,105,100,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,32,67,52,50,48,109,112,101,103,50,32,88,89,83,67,83,83,61,52,50,48,77,80,69,71,50,0,0,0,0,0,0,70,114,97,109,101,32,119,105,116,104,32,103,114,97,100,105,101,110,116,32,112,114,101,100,105,99,116,105,111,110,0,0,99,111,108,111,114,95,109,111,100,101,0,0,0,0,0,0,101,110,100,32,37,102,10,0,101,97,99,51,0,0,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,84,104,105,115,32,118,101,114,115,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,37,100,32,107,72,122,32,45,32,37,100,32,107,98,105,116,47,115,47,99,104,32,109,111,100,101,46,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,84,111,111,32,109,97,110,121,32,115,108,105,99,101,32,112,114,111,112,101,114,116,105,101,115,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,77,86,32,111,117,116,32,111,102,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,114,98,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,32,116,121,112,101,32,40,37,100,41,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,98,115,0,0,0,0,0,0,80,67,83,95,77,111,110,116,101,95,77,97,114,105,111,95,73,116,97,108,121,95,49,0,65,84,82,65,67,51,43,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,32,51,43,41,0,103,101,110,101,114,97,116,101,32,97,32,114,101,112,111,114,116,0,0,0,0,0,0,0,108,114,0,0,0,0,0,0,44,37,102,44,37,102,10,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,116,104,101,32,99,111,110,102,105,103,32,105,110,102,111,46,10,0,0,0,0,71,101,111,103,80,114,105,109,101,77,101,114,105,100,105,97,110,71,101,111,75,101,121,0,98,114,115,116,109,0,0,0,87,114,105,116,105,110,103,32,109,101,116,97,100,97,116,97,32,119,105,116,104,32,107,101,121,32,39,37,115,39,32,102,97,105,108,101,100,10,0,0,115,117,98,118,105,101,119,101,114,49,0,0,0,0,0,0,80,97,108,101,116,116,101,32,101,110,116,114,121,32,115,105,122,101,32,37,105,32,98,105,116,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,0,0,0,102,114,97,109,101,32,110,117,109,32,37,100,32,105,110,99,111,109,112,108,101,116,101,32,112,105,99,32,120,32,37,100,32,121,32,37,100,32,108,101,102,116,32,37,100,10,0,0,98,101,115,116,95,118,101,99,116,111,114,95,109,101,97,110,32,33,61,32,45,57,57,57,0,0,0,0,0,0,0,0,99,111,100,101,114,0,0,0,105,110,118,97,108,105,100,32,99,111,108,111,114,109,97,112,32,116,121,112,101,10,0,0,13,10,0,0,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,65,83,83,32,101,118,101,110,116,46,10,0,0,0,0,0,0,0,0,123,92,102,110,125,0,0,0,37,115,32,102,105,108,101,115,32,104,97,118,101,32,101,120,97,99,116,108,121,32,111,110,101,32,115,116,114,101,97,109,10,0,0,0,0,0,0,0,82,101,115,111,108,117,116,105,111,110,32,116,111,111,32,108,111,119,10,0,0,0,0,0,69,114,114,111,114,32,115,45,62,115,112,97,116,105,97,108,95,100,101,99,111,109,112,111,115,105,116,105,111,110,95,99,111,117,110,116,32,105,115,32,37,100,10,0,0,0,0,0,49,0,0,0,0,0,0,0,101,110,99,111,117,110,116,101,114,101,100,32,114,101,112,101,97,116,32,98,108,111,99,107,32,111,112,99,111,100,101,32,40,37,48,50,88,41,32,98,117,116,32,110,111,116,32,101,110,111,117,103,104,32,98,108,111,99,107,115,32,114,101,110,100,101,114,101,100,32,121,101,116,10,0,0,0,0,0,0,83,111,117,110,100,58,32,110,111,32,100,97,116,97,10,0,53,107,48,0,0,0,0,0,111,118,101,114,114,101,97,100,58,32,37,100,10,0,0,0,119,114,111,110,103,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,10,0,0,0,80,67,83,95,77,104,97,115,116,95,85,84,77,95,122,111,110,101,95,51,50,83,0,0,115,117,98,99,111,100,101,99,32,37,100,58,32,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,102,114,97,109,101,10,0,0,0,0,0,0,73,68,61,34,83,111,117,114,99,101,34,0,0,0,0,0,115,50,52,108,101,32,100,101,109,117,120,101,114,0,0,0,73,110,99,111,114,114,101,99,116,32,111,114,32,117,110,107,110,111,119,110,32,115,108,105,99,101,32,104,101,97,100,101,114,10,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,105,110,116,114,97,32,112,114,101,100,105,99,116,105,111,110,32,99,111,100,101,10,0,0,0,0,0,0,0,0,115,45,62,109,111,100,105,102,105,101,100,95,113,117,97,110,116,61,61,49,0,0,0,0,98,111,97,0,0,0,0,0,72,69,65,68,69,82,32,69,82,82,79,82,10,0,0,0,83,87,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,113,117,97,107,101,51,95,99,111,109,112,97,116,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,97,116,114,97,99,51,112,0,100,101,116,101,99,116,32,98,105,116,115,116,114,101,97,109,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,100,101,118,105,97,116,105,111,110,115,0,0,0,0,0,0,0,109,118,0,0,0,0,0,0,116,104,114,101,115,104,0,0,73,39,109,32,112,101,100,97,108,105,110,103,32,98,97,99,107,119,97,114,100,115,10,0,65,118,105,100,32,49,58,49,32,49,48,45,98,105,116,32,82,71,66,32,80,97,99,107,101,114,0,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,118,97,108,117,101,32,37,100,32,105,110,32,113,100,109,50,95,103,101,116,95,118,108,99,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,112,105,116,99,104,32,102,105,108,116,101,114,46,0,116,111,111,32,108,97,114,103,101,32,113,117,97,110,116,105,115,101,114,44,32,109,97,120,105,109,117,109,32,105,115,32,54,52,10,0,0,0,0,0,110,101,101,100,32,89,85,86,52,50,50,80,49,48,10,0,117,110,107,110,111,119,110,32,115,116,114,101,97,109,32,99,108,97,115,115,32,40,37,100,41,10,0,0,0,0,0,0,112,105,99,116,117,114,101,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,115,101,116,32,116,104,101,32,112,105,99,116,117,114,101,32,98,108,97,99,107,32,114,97,116,105,111,32,116,104,114,101,115,104,111,108,100,0,0,0,105,110,118,97,108,105,100,32,112,108,97,110,101,32,100,97,116,97,32,115,105,122,101,10,0,0,0,0,0,0,0,0,80,80,77,32,40,80,111,114,116,97,98,108,101,32,80,105,120,101,108,77,97,112,41,32,105,109,97,103,101,0,0,0,98,109,118,0,0,0,0,0,112,98,109,0,0,0,0,0,79,110,108,121,32,111,110,101,32,111,102,32,39,100,112,105,39,32,111,114,32,39,100,112,109,39,32,111,112,116,105,111,110,115,32,115,104,111,117,108,100,32,98,101,32,115,101,116,10,0,0,0,0,0,0,0,99,104,117,110,107,32,116,111,111,32,98,105,103,10,0,0,83,117,98,116,105,116,108,101,32,111,117,116,32,111,102,32,118,105,100,101,111,32,98,111,117,110,100,115,46,32,120,32,61,32,37,100,44,32,121,32,61,32,37,100,44,32,118,105,100,101,111,32,119,105,100,116,104,32,61,32,37,100,44,32,118,105,100,101,111,32,104,101,105,103,104,116,32,61,32,37,100,46,10,0,0,0,0,0,112,114,111,100,117,99,116,95,117,105,100,0,0,0,0,0,70,105,108,101,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,37,100,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,117,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,100,101,112,116,104,32,40,37,100,41,10,0,0,82,71,66,95,65,76,80,72,65,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,77,105,110,110,97,95,78,105,103,101,114,105,97,95,69,97,115,116,0,0,48,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,76,111,115,115,108,101,115,115,0,0,0,0,73,110,112,117,116,32,102,114,97,109,101,32,115,105,122,101,115,32,100,111,32,110,111,116,32,109,97,116,99,104,32,40,37,100,120,37,100,32,118,115,32,37,100,120,37,100,41,46,10,0,0,0,0,0,0,0,98,97,115,101,108,105,110,101,32,112,114,111,102,105,108,101,32,100,111,101,115,110,39,116,32,115,117,112,112,111,114,116,32,105,110,116,101,114,108,97,99,105,110,103,10,0,0,0,68,111,110,39,116,32,115,101,110,100,32,82,84,67,80,32,115,101,110,100,101,114,32,114,101,112,111,114,116,115,0,0,115,121,115,116,101,109,66,105,116,114,97,116,101,61,34,0,85,110,107,110,111,119,110,32,115,101,99,111,110,100,97,114,121,32,102,114,97,109,101,32,104,101,97,100,101,114,32,40,119,114,111,110,103,32,99,111,100,101,99,95,116,97,103,63,41,10,0,0,0,0,0,0,67,97,110,32,110,111,116,32,112,114,111,99,101,115,115,32,83,79,83,32,119,105,116,104,111,117,116,32,83,79,70,32,100,97,116,97,44,32,115,107,105,112,112,105,110,103,10,0,98,117,102,102,101,114,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,0,69,109,112,116,121,32,102,114,97,109,101,32,102,111,117,110,100,32,98,117,116,32,105,116,32,105,115,32,110,111,116,32,97,32,115,107,105,112,32,102,114,97,109,101,46,10,0,0,75,101,121,102,114,97,109,101,32,119,105,116,104,111,117,116,32,100,97,116,97,32,102,111,117,110,100,10,0,0,0,0,84,105,109,101,115,116,97,109,112,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,100,114,111,112,112,101,100,32,97,103,97,105,110,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,115,115,50,46,99,0,0,0,0,0,0,0,79,110,108,121,32,86,80,56,44,86,80,57,32,118,105,100,101,111,32,97,110,100,32,86,111,114,98,105,115,44,79,112,117,115,40,101,120,112,101,114,105,109,101,110,116,97,108,44,32,117,115,101,32,45,115,116,114,105,99,116,32,45,50,41,32,97,117,100,105,111,32,97,110,100,32,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,87,101,98,77,46,10,0,0,0,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,103,101,97,98,108,101,32,112,97,108,101,116,116,101,32,101,110,116,114,105,101,115,58,32,37,100,10,0,0,0,0,0,77,83,32,82,76,69,58,32,102,114,97,109,101,47,115,116,114,101,97,109,32,112,116,114,32,106,117,115,116,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,99,111,112,121,41,10,0,0,0,0,0,0,0,0,76,67,0,0,0,0,0,0,123,92,114,125,0,0,0,0,98,105,116,0,0,0,0,0,113,112,95,114,100,0,0,0,80,67,83,95,77,105,110,110,97,95,78,105,103,101,114,105,97,95,77,105,100,95,66,101,108,116,0,0,0,0,0,0,115,114,99,45,62,102,46,98,117,102,91,48,93,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,97,117,100,105,111,101,110,99,95,116,101,109,112,108,97,116,101,46,99,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,97,117,100,105,111,101,110,99,95,116,101,109,112,108,97,116,101,46,99,0,0,0,0,0,0,115,101,116,32,102,111,114,109,97,116,32,110,97,109,101,0,114,101,112,111,114,116,0,0,119,109,97,108,111,115,115,108,101,115,115,0,0,0,0,0,99,111,109,109,101,110,116,0,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,0,0,0,0,77,80,69,71,52,32,101,110,99,111,100,101,114,0,0,0,69,114,114,111,114,44,32,118,105,100,101,111,32,112,97,99,107,101,116,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,40,98,95,99,111,100,101,61,48,41,10,0,0,102,112,115,61,37,46,49,102,10,0,0,0,0,0,0,0,77,80,69,71,45,50,32,118,105,100,101,111,0,0,0,0,72,105,103,104,0,0,0,0,73,110,105,116,105,110,103,32,86,76,67,10,0,0,0,0,37,100,32,99,104,97,110,110,101,108,115,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,111,118,116,101,120,116,101,110,99,46,99,0,80,84,83,0,0,0,0,0,73,110,118,97,108,105,100,32,110,111,110,114,101,115,116,97,114,116,95,115,117,98,115,116,114,46,10,0,0,0,0,0,77,74,80,69,71,32,40,77,111,116,105,111,110,32,74,80,69,71,41,0,0,0,0,0,113,115,99,97,108,101,91,37,100,93,58,32,37,100,10,0,100,113,116,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,0,0,0,0,0,0,80,67,83,95,77,105,110,110,97,95,78,105,103,101,114,105,97,95,87,101,115,116,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,46,10,0,0,123,92,37,99,48,125,0,0,67,97,110,110,111,116,32,99,114,101,97,116,101,32,116,104,101,32,108,105,110,107,32,37,115,58,37,100,32,45,62,32,37,115,58,37,100,10,0,0,73,110,118,97,108,105,100,32,119,105,110,100,111,119,32,116,121,112,101,44,32,98,114,111,107,101,110,32,115,97,109,112,108,101,63,10,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,57,32,80,114,111,102,101,115,115,105,111,110,97,108,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,115,105,122,101,32,109,117,115,116,32,98,101,32,62,61,32,49,50,32,105,110,115,116,101,97,100,32,111,102,32,37,105,10,0,0,0,0,0,65,100,118,97,110,99,101,100,32,103,108,111,98,97,108,32,111,112,116,105,111,110,115,58,0,0,0,0,0,0,0,0,109,101,100,105,117,109,0,0,68,111,110,39,116,32,116,114,121,32,116,111,32,114,101,115,121,110,99,104,114,111,110,105,122,101,32,98,121,32,108,111,111,107,105,110,103,32,102,111,114,32,97,32,99,101,114,116,97,105,110,32,111,112,116,105,111,110,97,108,32,115,116,97,114,116,32,99,111,100,101,0,70,97,105,108,101,100,32,116,111,32,103,101,116,32,99,111,110,102,105,103,58,32,37,115,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,102,114,97,109,101,58,32,37,115,10,0,0,0,0,0,97,118,99,116,120,45,62,119,105,100,116,104,32,38,38,32,97,118,99,116,120,45,62,104,101,105,103,104,116,0,0,0,77,116,104,114,101,97,100,50,32,100,101,99,111,100,101,100,32,115,105,122,101,32,100,105,102,102,101,114,115,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,122,101,114,111,32,114,117,110,32,101,115,99,97,112,101,32,99,111,100,101,33,32,40,37,35,120,41,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,49,54,98,105,116,32,120,102,114,109,0,0,0,0,0,0,119,105,100,116,104,32,60,61,32,54,52,0,0,0,0,0,102,105,102,111,45,62,114,111,111,116,46,110,101,120,116,0,74,76,0,0,0,0,0,0,114,97,116,101,32,99,111,110,116,114,111,108,10,0,0,0,66,117,102,102,101,114,32,99,111,110,116,97,105,110,115,32,73,80,32,102,114,97,109,101,115,33,10,0,0,0,0,0,105,110,116,98,0,0,0,0,32,65,73,67,0,0,0,0,73,110,118,97,108,105,100,32,100,101,99,111,100,101,32,116,121,112,101,44,32,99,111,114,114,117,112,116,101,100,32,104,101,97,100,101,114,63,10,0,66,97,100,32,118,97,108,117,101,32,102,111,114,32,114,101,115,101,114,118,101,100,32,102,105,101,108,100,10,0,0,0,80,67,83,95,77,105,110,110,97,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,84,111,111,32,109,97,110,121,32,99,111,114,114,101,99,116,105,111,110,115,58,32,37,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,97,110,100,32,104,101,97,100,101,114,32,115,101,113,117,101,110,99,101,33,10,0,0,73,110,118,97,108,105,100,32,99,101,108,108,58,32,120,61,37,100,44,32,121,61,37,100,44,32,119,61,37,100,44,32,104,61,37,100,10,0,0,0,102,114,97,109,101,32,104,101,97,100,101,114,32,99,104,101,99,107,32,102,97,105,108,101,100,33,10,0,0,0,0,0,98,105,116,109,97,112,32,40,99,111,109,112,114,101,115,115,105,111,110,32,37,105,44,32,98,112,112,32,37,105,44,32,104,97,109,32,37,105,41,0,37,108,108,117,32,0,0,0,119,109,97,112,114,111,0,0,66,71,82,50,52,32,111,117,116,112,117,116,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,10,0,0,0,0,65,116,116,101,109,112,116,105,110,103,32,116,111,32,119,114,105,116,101,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,118,112,115,95,109,97,120,95,115,117,98,95,108,97,121,101,114,115,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,61,37,115,58,0,0,0,0,0,109,105,115,109,97,116,99,104,105,110,103,32,99,104,101,99,107,115,117,109,32,111,102,32,112,108,97,110,101,32,37,100,32,45,32,0,0,0,0,0,99,111,108,95,105,110,116,101,114,108,101,97,118,101,100,95,108,114,0,0,0,0,0,0,105,108,108,101,103,97,108,32,114,101,111,114,100,101,114,105,110,103,95,111,102,95,112,105,99,95,110,117,109,115,95,105,100,99,10,0,0,0,0,0,108,111,103,50,95,109,97,120,95,112,111,99,95,108,115,98,32,40,37,100,41,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,105,108,108,101,103,97,108,32,114,101,111,114,100,101,114,105,110,103,95,111,102,95,112,105,99,95,110,117,109,115,95,105,100,99,32,37,100,10,0,0,80,32,115,117,98,95,109,98,95,116,121,112,101,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,32,97,116,32,37,100,32,37,100,10,0,97,118,99,67,32,37,100,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,46,102,46,112,105,99,116,95,116,121,112,101,32,61,61,32,115,45,62,112,105,99,116,95,116,121,112,101,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,32,97,108,105,103,110,109,101,110,116,32,37,100,10,0,0,0,0,0,80,67,83,95,77,105,110,110,97,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,46,10,0,0,0,0,0,0,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,80,65,76,56,0,0,0,0,0,0,0,112,105,116,99,104,95,100,101,108,97,121,95,105,110,116,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,37,100,10,0,0,0,0,0,0,115,99,101,110,101,0,0,0,69,120,112,101,99,116,101,100,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,32,45,32,115,107,105,112,112,105,110,103,32,112,97,99,107,101,116,10,0,0,0,0,73,110,118,97,108,105,100,32,100,105,115,112,108,97,121,32,105,110,102,111,32,115,105,122,101,32,37,100,10,0,0,0,102,114,119,117,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,10,0,0,109,111,110,111,32,114,105,103,104,116,0,0,0,0,0,0,70,114,97,112,115,58,32,112,108,97,110,101,32,37,105,32,111,102,102,115,101,116,32,105,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,98,105,110,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,86,111,105,99,101,0,0,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,70,76,73,95,76,67,32,99,104,117,110,107,32,105,110,32,110,111,110,45,112,97,108,101,116,116,105,122,101,100,32,70,76,67,10,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,98,108,111,99,107,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,0,67,117,115,116,111,109,32,112,97,108,101,116,116,101,0,0,37,100,32,72,122,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,115,114,99,95,104,95,99,104,114,95,112,111,115,0,0,0,100,101,99,111,100,101,95,102,114,97,109,101,40,41,32,102,97,105,108,101,100,10,0,0,99,114,99,32,99,104,101,99,107,32,102,97,105,108,101,100,32,102,114,111,109,32,111,102,102,115,101,116,32,37,105,32,40,102,114,97,109,101,32,37,108,108,100,41,32,116,111,32,37,105,32,40,102,114,97,109,101,32,37,108,108,100,41,10,0,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,105,108,108,101,103,97,108,32,115,97,109,112,108,101,32,114,97,116,101,32,99,111,100,101,32,37,100,10,0,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,100,97,116,97,32,115,105,122,101,46,10,0,0,0,0,0,0,98,121,116,101,115,32,60,32,112,107,116,45,62,115,105,122,101,32,47,32,102,45,62,115,108,105,99,101,95,99,111,117,110,116,0,0,0,0,0,0,97,116,32,37,102,32,115,101,99,111,110,100,115,10,0,0,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,116,104,101,32,99,108,97,105,109,101,100,32,98,105,116,114,97,116,101,46,10,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,102,111,114,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,98,105,116,115,58,32,37,100,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,110,0,0,0,0,0,0,0,65,108,108,111,119,32,67,104,97,110,103,105,110,103,32,77,101,116,97,100,97,116,97,32,80,101,114,45,70,114,97,109,101,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,108,105,99,101,32,115,105,122,101,32,37,100,32,40,111,110,108,121,32,37,100,32,98,121,116,101,115,32,108,101,102,116,41,10,0,0,0,0,0,85,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,100,118,100,95,115,117,98,116,105,116,108,101,32,116,111,111,32,98,105,103,10,0,0,0,10,0,0,0,0,0,0,0,56,45,98,105,116,32,112,105,120,101,108,32,115,116,114,105,110,103,32,105,110,32,37,100,45,98,105,116,32,114,101,103,105,111,110,33,10,0,0,0,80,97,99,107,105,110,103,32,37,100,0,0,0,0,0,0,120,97,110,95,100,112,99,109,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,98,32,104,101,105,103,104,116,32,116,111,111,32,98,105,103,58,32,37,100,10,0,0,68,114,111,112,112,105,110,103,32,102,114,97,109,101,32,119,105,116,104,111,117,116,32,115,101,113,117,101,110,99,101,32,104,101,97,100,101,114,10,0,80,67,83,95,77,97,115,115,97,119,97,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,0,0,0,0,0,66,68,76,84,0,0,0,0,112,101,97,107,95,99,98,32,62,61,32,45,50,48,52,55,0,0,0,0,0,0,0,0,88,67,104,32,101,120,116,101,110,115,105,111,110,32,97,109,111,100,101,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,0,67,97,109,83,116,117,100,105,111,32,99,111,100,101,99,32,101,114,114,111,114,58,32,105,110,118,97,108,105,100,32,100,101,112,116,104,32,37,105,32,98,112,112,10,0,0,0,0,70,114,97,109,101,32,101,110,100,101,100,32,101,110,101,120,112,101,99,116,101,100,108,121,33,10,0,0,0,0,0,0,115,117,98,112,97,99,107,101,116,91,37,105,93,32,37,105,32,37,105,10,0,0,0,0,119,109,97,118,111,105,99,101,0,0,0,0,0,0,0,0,111,117,116,48,0,0,0,0,100,105,115,97,98,108,101,32,99,111,109,98,109,97,116,99,104,105,110,103,0,0,0,0,119,0,0,0,0,0,0,0,100,120,118,97,50,95,118,108,100,0,0,0,0,0,0,0,71,97,105,110,115,98,111,114,111,0,0,0,0,0,0,0,32,40,100,101,102,97,117,108,116,32,0,0,0,0,0,0,98,105,110,107,0,0,0,0,113,117,97,100,0,0,0,0,115,101,116,32,100,105,116,104,101,114,105,110,103,32,97,108,103,111,114,105,116,104,109,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,104,50,54,49,0,0,0,0,104,49,58,97,44,118,49,58,97,44,100,114,58,97,0,0,85,110,107,110,111,119,110,32,99,111,100,105,110,103,32,116,121,112,101,58,32,37,100,46,10,0,0,0,0,0,0,0,82,101,115,111,108,117,116,105,111,110,32,108,97,114,103,101,114,32,116,104,97,110,32,98,117,102,102,101,114,32,115,105,122,101,46,32,73,110,118,97,108,105,100,32,104,101,97,100,101,114,63,10,0,0,0,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,101,115,32,111,102,32,102,111,117,114,32,40,103,111,116,32,37,105,120,37,105,41,10,0,37,102,0,0,0,0,0,0,98,95,97,100,97,112,116,32,109,101,116,104,111,100,32,115,112,101,99,105,102,105,101,100,32,105,110,32,115,116,97,116,115,32,102,105,108,101,32,110,111,116,32,118,97,108,105,100,10,0,0,0,0,0,0,0,116,105,108,101,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,65,68,80,67,77,32,89,97,109,97,104,97,0,0,0,0,78,111,32,115,101,113,117,101,110,99,101,32,104,101,97,100,101,114,32,100,101,99,111,100,101,100,32,121,101,116,10,0,104,100,99,100,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,104,100,99,100,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,37,115,46,10,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,104,101,97,100,101,114,32,108,101,110,103,116,104,10,0,0,112,115,102,105,108,101,0,0,67,111,109,109,97,110,100,32,100,97,116,97,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,78,111,110,45,98,121,116,101,45,97,108,105,103,110,101,100,32,97,117,100,105,111,45,115,112,101,99,105,102,105,99,32,99,111,110,102,105,103,0,0,100,101,99,108,97,114,101,100,32,102,105,108,101,32,115,105,122,101,32,105,115,32,108,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2197664);
/* memory initializer */ allocate([115,115,32,116,104,97,110,32,104,101,97,100,101,114,32,115,105,122,101,32,40,37,100,32,60,32,37,100,41,10,0,0,80,67,83,95,77,101,114,99,104,105,99,104,95,83,97,104,97,114,97,0,0,0,0,0,84,111,111,32,108,111,110,103,32,86,76,67,32,40,37,100,41,32,105,110,32,105,110,105,116,95,118,108,99,10,0,0,110,111,116,32,101,110,111,117,103,104,32,101,120,116,114,97,100,97,116,97,10,0,0,0,117,118,65,67,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,73,110,99,111,114,114,101,99,116,32,49,54,120,49,54,32,98,108,111,99,107,32,116,121,112,101,32,37,100,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,67,111,117,108,100,32,110,111,116,32,117,112,100,97,116,101,32,116,105,109,101,115,116,97,109,112,115,32,102,111,114,32,100,105,115,99,97,114,100,101,100,32,115,97,109,112,108,101,115,46,10,0,0,0,0,0,48,0,0,0,0,0,0,0,98,108,111,99,107,95,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,10,0,98,102,105,0,0,0,0,0,83,112,101,101,120,0,0,0,76,105,110,101,97,114,95,89,97,114,100,95,83,101,97,114,115,0,0,0,0,0,0,0,79,102,102,115,101,116,32,111,102,32,37,100,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,48,32,111,112,97,99,105,116,121,0,0,105,108,108,101,103,97,108,32,113,115,99,97,108,101,32,48,10,0,0,0,0,0,0,0,65,86,83,117,98,116,105,116,108,101,32,114,101,99,116,97,110,103,108,101,32,97,115,115,32,34,37,115,34,32,100,111,101,115,32,110,111,116,32,108,111,111,107,32,108,105,107,101,32,97,32,83,83,65,32,109,97,114,107,117,112,10,0,0,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,110,111,116,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,46,32,101,120,116,114,97,32,98,121,116,101,115,32,97,116,32,116,104,101,32,101,110,100,32,119,105,108,108,32,98,101,32,115,107,105,112,112,101,100,46,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,109,117,108,116,105,45,99,104,97,110,110,101,108,32,65,77,82,0,0,0,0,0,0,0,109,117,108,116,105,45,99,104,97,110,110,101,108,32,65,77,82,0,0,0,0,0,0,0,115,108,105,99,101,115,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,114,114,101,108,97,116,105,111,110,46,10,0,0,0,103,108,111,98,97,108,95,104,101,97,100,101,114,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,115,105,110,107,46,99,0,0,0,0,0,0,0,0,116,105,109,101,98,97,115,101,32,37,100,47,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,77,80,69,71,32,52,32,115,116,97,110,100,97,114,100,44,32,116,104,101,32,109,97,120,105,109,117,109,32,97,100,109,105,116,116,101,100,32,118,97,108,117,101,32,102,111,114,32,116,104,101,32,116,105,109,101,98,97,115,101,32,100,101,110,111,109,105,110,97,116,111,114,32,105,115,32,37,100,10,0,99,98,112,99,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,98,112,32,37,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,109,106,112,101,103,0,0,0,98,111,116,116,111,109,95,116,111,112,0,0,0,0,0,0,84,89,69,82,0,0,0,0,83,116,114,105,99,116,108,121,32,104,105,101,114,97,114,99,104,105,99,97,108,32,112,121,114,97,109,105,100,0,0,0,114,99,95,101,110,100,95,117,115,97,103,101,58,0,0,0,71,114,117,110,103,101,0,0,65,32,110,111,110,45,105,110,116,114,97,32,115,108,105,99,101,32,105,110,32,97,110,32,73,68,82,32,78,65,76,32,117,110,105,116,46,10,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,100,101,115,99,114,105,112,116,105,111,110,46,10,0,0,0,0,105,110,100,101,112,0,0,0,68,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,97,117,116,111,0,0,0,0,32,37,53,46,49,102,0,0,79,110,108,121,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,97,110,100,32,112,105,99,116,117,114,101,115,32,97,114,101,32,97,108,108,111,119,101,100,32,105,110,32,65,73,70,70,46,10,0,0,0,99,111,109,109,101,110,116,0,84,104,101,111,114,97,0,0,69,115,99,97,112,101,32,115,97,109,112,108,101,32,114,97,116,101,32,105,110,100,101,120,32,105,108,108,101,103,97,108,32,105,110,32,65,68,84,83,10,0,0,0,0,0,0,0,112,104,100,114,45,62,102,114,97,109,101,95,115,105,122,101,32,60,61,32,115,105,122,101,111,102,40,98,117,102,51,41,0,0,0,0,0,0,0,0,80,67,83,95,77,101,114,99,104,105,99,104,95,83,117,100,95,77,97,114,111,99,0,0,98,105,116,115,32,117,110,115,112,101,99,105,102,105,101,100,32,102,111,114,32,110,111,110,32,65,68,80,67,77,10,0,67,104,114,105,115,116,105,97,110,32,82,97,112,0,0,0,32,67,52,50,48,112,97,108,100,118,32,88,89,83,67,83,83,61,52,50,48,80,65,76,68,86,0,0,0,0,0,0,52,50,48,109,112,101,103,50,0,0,0,0,0,0,0,0,98,101,116,104,115,111,102,116,118,105,100,0,0,0,0,0,116,119,111,32,100,112,100,115,32,99,104,117,110,107,115,32,112,114,101,115,101,110,116,10,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,53,46,49,32,65,68,80,67,77,32,97,117,100,105,111,32,115,116,114,101,97,109,32,40,48,120,37,48,52,88,41,10,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,118,102,105,108,116,101,114,103,114,97,112,104,46,99,0,0,0,0,0,115,116,97,114,116,32,37,102,44,32,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,99,104,97,110,110,101,108,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,0,105,109,97,103,101,47,106,112,101,103,0,0,0,0,0,0,115,112,101,101,120,0,0,0,101,110,99,114,121,112,116,101,100,32,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,32,40,115,116,58,37,100,41,44,32,100,101,99,111,100,105,110,103,32,119,105,108,108,32,108,105,107,101,108,121,32,102,97,105,108,10,0,0,0,32,45,45,62,32,0,0,0,13,10,0,0,0,0,0,0,32,32,117,110,114,101,99,111,103,110,105,122,101,100,32,87,67,51,32,99,104,117,110,107,58,32,37,99,37,99,37,99,37,99,32,40,48,120,37,48,50,88,37,48,50,88,37,48,50,88,37,48,50,88,41,10,0,0,0,0,0,0,0,0,37,115,32,99,111,100,101,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,117,110,107,110,111,119,110,32,103,117,105,100,58,32,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,115,105,122,101,0,0,0,0,58,32,61,0,0,0,0,0,68,69,83,67,82,73,80,84,73,79,78,0,0,0,0,0,13,10,0,0,0,0,0,0,97,118,115,0,0,0,0,0,109,105,109,101,95,116,121,112,101,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,104,97,114,115,95,112,101,114,95,102,114,97,109,101,0,116,111,116,97,108,102,114,97,109,101,115,32,37,100,32,105,110,118,97,108,105,100,10,0,32,32,32,32,115,116,114,101,97,109,58,37,100,32,99,111,100,101,99,58,37,115,32,116,121,112,101,58,37,115,0,0,115,116,97,114,116,84,105,109,101,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,116,97,103,95,108,101,110,32,60,32,48,120,51,102,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,77,101,114,99,104,105,99,104,95,78,111,114,100,95,77,97,114,111,99,0,91,83,73,90,69,93,0,0,13,10,0,0,0,0,0,0,83,111,117,114,99,101,32,102,105,108,116,101,114,115,32,97,110,100,32,102,105,108,116,101,114,115,32,119,105,116,104,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,105,110,112,117,116,32,109,117,115,116,32,115,101,116,32,99,111,110,102,105,103,95,112,114,111,112,115,40,41,32,99,97,108,108,98,97,99,107,115,32,111,110,32,97,108,108,32,111,117,116,112,117,116,115,10,0,0,0,10,0,0,0,0,0,0,0,87,114,111,110,103,32,65,65,67,32,102,105,108,101,32,102,111,114,109,97,116,10,0,0,99,111,109,109,101,110,116,0,37,115,47,77,97,110,105,102,101,115,116,46,116,109,112,0,117,110,115,117,112,112,111,114,116,101,100,32,97,117,100,105,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,37,105,32,98,121,116,101,115,32,111,102,32,101,120,116,114,97,100,97,116,97,10,0,0,97,118,114,0,0,0,0,0,77,117,115,101,112,97,99,107,32,83,86,56,0,0,0,0,69,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,114,97,119,32,86,67,45,49,32,118,105,100,101,111,0,0,80,67,83,95,77,97,108,111,110,103,111,95,49,57,56,55,95,85,84,77,95,51,50,83,0,0,0,0,0,0,0,0,115,49,54,98,101,32,100,101,109,117,120,101,114,0,0,0,109,117,115,101,112,97,99,107,56,0,0,0,0,0,0,0,98,105,116,115,116,114,101,97,109,0,0,0,0,0,0,0,69,114,114,111,114,32,115,116,114,101,97,109,95,105,100,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,112,114,111,100,117,99,116,95,118,101,114,115,105,111,110,0,80,67,83,95,77,97,107,97,115,115,97,114,95,78,69,73,69,90,0,0,0,0,0,0,78,101,108,108,121,109,111,115,101,114,32,65,115,97,111,0,115,107,105,112,95,114,116,99,112,0,0,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,68,95,87,69,66,86,84,84,47,83,85,66,84,73,84,76,69,83,0,0,0,0,0,0,77,65,73,78,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,86,0,110,101,108,108,121,109,111,115,101,114,0,0,0,0,0,0,65,80,73,67,0,0,0,0,118,0,0,0,0,0,0,0,102,114,97,109,101,61,37,100,10,0,0,0,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,73,86,0,0,0,0,0,0,0,0,77,111,110,107,101,121,39,115,32,65,117,100,105,111,0,0,110,111,95,114,101,115,121,110,99,95,115,101,97,114,99,104,0,0,0,0,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,73,73,73,0,0,0,0,0,0,0,97,112,101,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,115,61,37,115,58,0,0,0,0,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,73,73,0,0,0,0,0,0,0,0,109,114,0,0,0,0,0,0,86,111,120,119,97,114,101,32,82,84,50,57,32,77,101,116,97,115,111,117,110,100,0,0,100,115,116,95,102,111,114,109,97,116,0,0,0,0,0,0,80,67,83,95,76,117,122,111,110,95,80,104,105,108,105,112,112,105,110,101,115,95,73,0,118,111,120,119,97,114,101,0,110,111,110,101,0,0,0,0,120,50,54,52,95,107,101,114,110,101,108,95,98,117,105,108,100,95,108,111,103,46,116,120,116,0,0,0,0,0,0,0,118,100,112,97,117,95,109,112,101,103,52,0,0,0,0,0,70,117,99,104,115,105,97,0,41,0,0,0,0,0,0,0,52,46,48,0,0,0,0,0,115,119,115,95,100,105,116,104,101,114,0,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,0,0,0,0,0,102,97,115,116,0,0,0,0,38,72,37,56,120,0,0,0,98,95,97,100,97,112,116,61,37,100,0,0,0,0,0,0,97,100,112,99,109,95,121,97,109,97,104,97,0,0,0,0,83,116,97,110,100,97,114,100,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,83,116,97,110,100,97,114,100,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,115,101,116,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,32,102,111,114,32,97,108,108,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,108,97,121,101,114,115,0,80,67,83,95,76,111,109,101,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,0,118,0,0,0,0,0,0,0,115,107,105,112,32,37,100,47,37,100,32,115,97,109,112,108,101,115,10,0,0,0,0,0,65,84,82,65,67,51,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,32,51,41,0,0,0,76,105,110,101,97,114,95,67,104,97,105,110,95,83,101,97,114,115,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,48,95,111,112,97,99,105,116,121,0,0,0,0,0,0,115,108,105,99,101,45,109,105,110,45,109,98,115,0,0,0,65,86,73,79,67,111,110,116,101,120,116,0,0,0,0,0,102,111,114,99,101,32,108,111,119,32,100,101,108,97,121,0,105,110,116,114,97,95,113,117,97,110,116,95,98,105,97,115,32,61,32,37,100,32,105,110,116,101,114,95,113,117,97,110,116,95,98,105,97,115,32,61,32,37,100,10,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,0,0,0,48,48,32,109,111,116,105,111,110,95,116,121,112,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,83,105,110,103,108,101,32,102,105,101,108,100,10,0,0,0,115,116,114,105,99,116,0,0,114,99,95,114,101,115,105,122,101,95,100,111,119,110,95,116,104,114,101,115,104,58,0,0,115,108,105,99,101,32,116,121,112,101,32,37,100,32,116,111,111,32,108,97,114,103,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,67,104,97,110,110,101,108,32,67,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,32,32,83,80,75,58,0,0,116,104,101,111,114,97,0,0,80,67,83,95,76,101,105,103,111,110,95,71,104,97,110,97,95,71,114,105,100,0,0,0,84,111,112,32,52,48,0,0,32,67,52,49,49,32,88,89,83,67,83,83,61,52,49,49,0,0,0,0,0,0,0,0,32,32,32,32,67,104,97,112,116,101,114,32,35,37,100,46,37,100,58,32,0,0,0,0,97,116,114,97,99,51,0,0,80,67,83,95,80,83,65,68,53,54,95,80,101,114,117,95,101,97,115,116,95,122,111,110,101,0,0,0,0,0,0,0,71,83,77,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,0,0,0,68,0,0,0,0,0,0,0,100,97,116,101,0,0,0,0,72,101,97,100,101,114,32,99,104,117,110,107,32,105,115,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,0,115,101,103,109,101,110,116,58,39,37,115,39,32,99,111,117,110,116,58,37,100,32,101,110,100,101,100,10,0,0,0,0,118,109,100,45,62,102,114,97,109,101,95,99,111,117,110,116,32,42,32,118,109,100,45,62,102,114,97,109,101,115,95,112,101,114,95,98,108,111,99,107,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,32,102,111,114,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,115,116,114,105,110,103,10,0,0,0,0,0,85,82,76,67,111,110,116,101,120,116,0,0,0,0,0,0,118,99,49,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,80,101,114,117,95,99,101,110,116,114,97,108,0,115,0,0,0,0,0,0,0,115,49,54,108,101,32,100,101,109,117,120,101,114,0,0,0,103,115,109,95,109,115,0,0,118,101,114,105,102,121,32,101,109,98,101,100,100,101,100,32,67,82,67,115,0,0,0,0,115,101,116,32,114,101,102,101,114,101,110,99,101,32,115,116,114,101,97,109,0,0,0,0,105,110,100,101,120,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,0,0,112,114,111,100,117,99,116,95,110,97,109,101,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,80,101,114,117,95,119,101,115,116,95,122,111,110,101,0,0,0,0,0,0,0,77,76,80,32,40,77,101,114,105,100,105,97,110,32,76,111,115,115,108,101,115,115,32,80,97,99,107,105,110,103,41,0,98,61,65,83,58,37,100,13,10,0,0,0,0,0,0,0,85,115,101,32,82,70,67,32,50,49,57,48,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,105,110,115,116,101,97,100,32,111,102,32,82,70,67,32,52,54,50,57,32,102,111,114,32,72,46,50,54,51,0,0,0,0,0,0,0,0,99,100,101,99,0,0,0,0,68,95,87,69,66,86,84,84,47,77,69,84,65,68,65,84,65,0,0,0,0,0,0,0,84,121,112,101,32,37,100,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,45,0,0,0,0,0,0,0,101,110,99,111,100,101,114,0,83,116,97,114,116,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,50,48,83,0,109,108,112,0,0,0,0,0,80,117,98,108,105,115,104,101,114,47,83,116,117,100,105,111,32,108,111,103,111,116,121,112,101,0,0,0,0,0,0,0,115,101,116,32,108,111,103,103,105,110,103,32,108,101,118,101,108,0,0,0,0,0,0,0,102,114,97,109,101,61,37,53,100,32,102,112,115,61,37,51,46,42,102,32,113,61,37,51,46,49,102,32,0,0,0,0,97,118,105,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,37,115,10,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,109,117,115,116,32,98,101,32,60,32,54,53,53,51,54,10,0,0,0,0,86,105,100,101,111,32,102,111,114,109,97,116,32,37,105,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,57,83,0,77,117,115,101,112,97,99,107,32,83,86,55,0,0,0,0,97,115,102,32,100,101,109,117,120,101,114,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,102,105,108,101,32,119,104,105,108,101,32,114,101,97,100,105,110,103,32,73,78,70,79,32,116,97,103,10,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,56,83,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,109,117,115,101,112,97,99,107,55,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,102,109,116,115,61,37,115,58,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,55,83,0,109,111,110,111,32,108,101,102,116,0,0,0,0,0,0,0,73,77,67,32,40,73,110,116,101,108,32,77,117,115,105,99,32,67,111,100,101,114,41,0,100,115,116,104,0,0,0,0,115,0,0,0,0,0,0,0,99,97,118,115,118,105,100,101,111,0,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,50,49,78,0,108,97,116,109,0,0,0,0,105,109,99,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,118,105,100,101,111,32,112,97,99,107,101,116,10,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,100,101,99,32,71,85,73,68,46,10,0,0,0,0,105,110,118,97,108,105,100,32,112,97,121,108,111,97,100,32,108,101,110,103,116,104,32,37,117,10,0,0,0,0,0,0,99,111,109,98,109,97,116,99,104,105,110,103,0,0,0,0,79,112,101,110,67,76,58,32,67,111,109,112,105,108,97,116,105,111,110,32,102,97,105,108,101,100,44,32,117,110,97,98,108,101,32,116,111,32,103,101,116,32,98,117,105,108,100,32,108,111,103,10,0,0,0,0,121,117,118,52,52,52,112,49,54,98,101,0,0,0,0,0,70,111,114,101,115,116,71,114,101,101,110,0,0,0,0,0,32,116,111,32,0,0,0,0,65,65,67,32,110,111,116,32,121,101,116,32,99,111,114,114,101,99,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,51,46,48,40,98,97,99,107,41,0,0,0,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,104,111,114,105,122,111,110,116,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,105,110,116,101,114,110,97,108,95,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,37,108,108,100,44,37,108,108,100,44,37,99,0,0,0,0,100,101,0,0,0,0,0,0,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,0,0,0,0,0,0,0,98,95,97,100,97,112,116,61,0,0,0,0,0,0,0,0,65,68,80,67,77,32,67,68,82,79,77,32,88,65,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,97,108,108,0,0,0,0,0,77,117,108,116,105,112,108,101,32,112,114,111,103,114,97,109,115,0,0,0,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,50,48,78,0,117,118,68,67,0,0,0,0,84,104,105,114,100,32,104,101,97,100,101,114,32,105,115,32,110,111,116,32,116,104,101,32,115,101,116,117,112,32,104,101,97,100,101,114,46,10,0,0,67,111,117,108,100,32,110,111,116,32,117,112,100,97,116,101,32,116,105,109,101,115,116,97,109,112,115,32,102,111,114,32,115,107,105,112,112,101,100,32,115,97,109,112,108,101,115,46,10,0,0,0,0,0,0,0,97,118,105,0,0,0,0,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,32,97,117,100,105,111,0,0,0,0,0,0,0,76,105,110,101,97,114,95,67,104,97,105,110,95,66,101,110,111,105,116,0,0,0,0,0,85,110,107,110,111,119,110,45,37,100,0,0,0,0,0,0,115,101,116,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,97,108,108,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,115,0,115,108,105,99,101,45,109,97,120,45,109,98,115,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,108,111,119,95,100,101,108,97,121,0,0,0,0,0,0,0,113,109,105,110,32,97,110,100,32,111,114,32,113,109,97,120,32,97,114,101,32,105,110,118,97,108,105,100,44,32,116,104,101,121,32,109,117,115,116,32,98,101,32,48,32,60,32,109,105,110,32,60,61,32,109,97,120,10,0,0,0,0,0,0,109,112,101,103,52,0,0,0,77,84,95,68,77,86,32,105,110,32,112,114,111,103,114,101,115,115,105,118,101,95,115,101,113,117,101,110,99,101,10,0,100,101,99,111,100,101,32,102,114,97,109,101,32,117,110,117,115,101,100,32,37,116,100,32,98,121,116,101,115,10,0,0,98,95,112,121,114,97,109,105,100,0,0,0,0,0,0,0,114,99,95,114,101,115,105,122,101,95,117,112,95,116,104,114,101,115,104,58,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,66,32,37,100,32,37,100,10,0,0,83,116,101,114,101,111,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,109,111,100,101,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,99,111,117,112,108,105,110,103,0,0,0,0,0,0,0,0,116,58,32,37,45,49,48,115,32,77,58,37,54,46,49,102,32,83,58,37,54,46,49,102,32,32,32,32,32,73,58,37,54,46,49,102,32,76,85,70,83,32,32,32,32,32,76,82,65,58,37,54,46,49,102,32,76,85,0,0,0,0,0,0,79,110,50,32,86,80,51,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,57,78,0,71,97,110,103,115,116,97,0,32,67,109,111,110,111,49,54,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,100,115,105,99,105,110,97,117,100,105,111,0,0,0,0,0,105,110,37,100,58,37,99,37,100,0,0,0,0,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,80,67,83,95,80,83,65,68,53,54,95,85,84,77,95,122,111,110,101,95,49,56,78,0,97,117,0,0,0,0,0,0,87,97,118,80,97,99,107,0,32,37,115,37,115,32,37,45,49,53,115,32,37,115,10,0,35,69,88,84,45,88,45,69,78,68,76,73,83,84,10,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,116,104,100,0,0,0,0,0,115,101,116,32,112,114,111,98,105,110,103,32,115,105,122,101,0,0,0,0,0,0,0,0,80,67,83,95,76,97,95,67,97,110,111,97,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,0,0,0,0,0,115,56,32,100,101,109,117,120,101,114,0,0,0,0,0,0,119,97,118,112,97,99,107,0,99,114,99,99,104,101,99,107,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,110,32,60,61,32,115,121,110,99,112,111,105,110,116,95,99,111,117,110,116,32,43,32,49,0,0,0,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,99,111,109,109,101,110,116,32,104,101,97,100,101,114,44,32,37,105,32,99,111,109,109,101,110,116,115,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,99,111,109,112,97,110,121,95,110,97,109,101,0,0,0,0,77,117,108,116,105,112,108,101,32,102,105,115,98,111,110,101,32,102,111,114,32,116,104,101,32,115,97,109,101,32,115,116,114,101,97,109,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,76,97,95,67,97,110,111,97,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,0,0,0,0,0,97,115,116,0,0,0,0,0,81,67,69,76,80,32,47,32,80,117,114,101,86,111,105,99,101,0,0,0,0,0,0,0,105,0,0,0,0,0,0,0,114,102,99,50,49,57,48,0,83,112,101,101,120,0,0,0,37,42,88,32,37,88,32,37,88,32,37,88,0,0,0,0,68,95,87,69,66,86,84,84,47,68,69,83,67,82,73,80,84,73,79,78,83,0,0,0,67,111,100,101,99,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,97,115,116,0,0,0,0,0,37,115,47,37,115,0,0,0,108,105,115,115,97,106,111,117,115,0,0,0,0,0,0,0,80,67,83,95,75,101,114,116,97,117,95,85,84,77,95,122,111,110,101,95,52,56,78,0,113,99,101,108,112,0,0,0,110,117,115,45,62,107,101,121,102,114,97,109,101,95,112,116,115,91,107,93,32,62,32,108,97,115,116,95,112,116,115,0,105,110,112,117,116,32,102,105,108,101,0,0,0,0,0,0,66,97,110,100,47,97,114,116,105,115,116,32,108,111,103,111,116,121,112,101,0,0,0,0,108,111,103,108,101,118,101,108,0,0,0,0,0,0,0,0,115,116,114,101,97,109,95,37,100,95,37,100,95,113,61,37,46,49,102,10,0,0,0,0,97,115,115,0,0,0,0,0,80,67,83,95,75,101,114,116,97,117,95,85,84,77,95,122,111,110,101,95,52,55,78,0,108,105,98,97,118,102,111,114,109,97,116,47,110,117,116,100,101,99,46,99,0,0,0,0,83,109,97,99,107,101,114,32,97,117,100,105,111,0,0,0,111,117,116,112,117,116,32,102,105,108,101,0,0,0,0,0,116,111,111,32,109,97,110,121,32,115,116,114,101,97,109,115,10,0,0,0,0,0,0,0,112,99,109,0,0,0,0,0,97,115,115,0,0,0,0,0,101,100,105,116,32,117,110,105,116,115,32,99,111,117,110,116,32,37,100,10,0,0,0,0,80,67,83,95,75,101,114,116,97,117,95,83,105,110,103,97,112,111,114,101,95,71,114,105,100,0,0,0,0,0,0,0,99,108,105,112,112,105,110,103,10,0,0,0,0,0,0,0,115,109,97,99,107,97,117,100,105,111,0,0,0,0,0,0,83,117,99,99,101,115,115,102,117,108,108,121,32,111,112,101,110,101,100,32,116,104,101,32,102,105,108,101,46,10,0,0,112,97,110,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,109,97,112,32,69,100,105,116,85,110,105,116,32,37,108,108,100,32,105,110,32,73,110,100,101,120,83,73,68,32,37,105,32,116,111,32,97,110,32,111,102,102,115,101,116,10,0,0,0,0,0,0,0,0,98,101,101,112,95,102,97,99,116,111,114,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,86,98,0,84,84,65,32,40,84,114,117,101,32,65,117,100,105,111,41,0,0,0,0,0,0,0,0,109,108,0,0,0,0,0,0,99,111,109,109,101,110,116,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,37,115,32,102,105,108,101,32,37,115,46,10,0,0,0,0,0,0,100,115,116,119,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,117,120,46,99,0,0,0,0,0,0,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,97,115,102,0,0,0,0,0,37,102,32,37,102,0,0,0,91,37,108,108,100,93,91,37,108,108,100,93,37,99,37,110,0,0,0,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,73,73,98,0,0,0,0,0,0,0,0,67,111,110,116,101,110,116,45,108,101,110,103,116,104,58,32,37,100,13,10,13,10,0,0,116,116,97,0,0,0,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,82,101,102,101,114,101,110,99,101,32,70,114,97,109,101,34,0,0,79,112,101,110,105,110,103,32,97,110,32,37,115,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,0,115,101,116,32,99,111,109,98,109,97,116,99,104,105,110,103,32,109,111,100,101,0,0,0,79,112,101,110,67,76,58,32,67,111,109,112,105,108,97,116,105,111,110,32,102,97,105,108,101,100,44,32,117,110,97,98,108,101,32,116,111,32,97,108,108,111,99,32,98,117,105,108,100,32,108,111,103,10,0,0,99,108,0,0,0,0,0,0,121,117,118,52,52,52,112,49,54,108,101,0,0,0,0,0,70,108,111,114,97,108,87,104,105,116,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,32,40,102,114,111,109,32,0,51,46,48,0,0,0,0,0,100,115,116,95,104,95,99,104,114,95,112,111,115,0,0,0,115,101,116,32,105,110,116,101,114,110,97,108,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,104,98,58,97,44,118,98,58,97,44,100,114,58,97,0,0,37,100,0,0,0,0,0,0,100,105,114,101,99,116,61,97,117,116,111,32,110,111,116,32,117,115,101,100,32,111,110,32,116,104,101,32,102,105,114,115,116,32,112,97,115,115,10,0,97,100,112,99,109,95,120,97,0,0,0,0,0,0,0,0,65,47,68,32,67,111,110,118,101,114,116,101,114,32,84,121,112,101,0,0,0,0,0,0,65,47,68,32,67,111,110,118,101,114,116,101,114,32,84,121,112,101,0,0,0,0,0,0,98,0,0,0,0,0,0,0,102,114,97,109,101,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,32,37,100,32,60,60,32,37,100,10,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,73,98,0,117,0,0,0,0,0,0,0,70,105,114,115,116,32,104,101,97,100,101,114,32,105,115,32,110,111,116,32,116,104,101,32,105,100,32,104,101,97,100,101,114,46,10,0,0,0,0,0,114,97,119,32,77,80,69,71,45,84,83,32,40,77,80,69,71,45,50,32,84,114,97,110,115,112,111,114,116,32,83,116,114,101,97,109,41,0,0,0,68,83,80,32,71,114,111,117,112,32,84,114,117,101,83,112,101,101,99,104,0,0,0,0,115,107,105,112,32,119,104,111,108,101,32,102,114,97,109,101,44,32,115,107,105,112,32,108,101,102,116,58,32,37,100,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,112,116,105,111,110,115,32,102,111,114,32,37,115,32,102,105,108,101,32,37,115,46,10,0,0,76,105,110,101,97,114,95,76,105,110,107,95,83,101,97,114,115,0,0,0,0,0,0,0,85,115,101,114,45,68,101,102,105,110,101,100,0,0,0,0,97,108,108,95,101,120,112,114,0,0,0,0,0,0,0,0,115,108,105,99,101,45,109,97,120,45,115,105,122,101,0,0,112,99,109,95,115,50,52,108,101,0,0,0,0,0,0,0,117,115,101,32,105,110,116,101,114,108,97,99,101,100,32,68,67,84,0,0,0,0,0,0,114,101,109,111,118,105,110,103,32,99,111,109,109,111,110,32,102,97,99,116,111,114,115,32,102,114,111,109,32,102,114,97,109,101,114,97,116,101,10,0,33,115,45,62,112,114,111,103,114,101,115,115,105,118,101,95,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,77,80,69,71,45,49,32,83,121,115,116,101,109,115,32,47,32,77,80,69,71,32,112,114,111,103,114,97,109,32,115,116,114,101,97,109,32,40,86,67,68,41,0,0,0,0,0,0,77,111,110,111,32,115,116,114,101,97,109,32,119,105,116,104,32,50,32,115,117,98,115,116,114,101,97,109,115,44,32,105,103,110,111,114,105,110,103,32,50,110,100,10,0,0,0,0,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,74,52,52,52,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,52,52,52,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,74,52,50,50,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,52,50,50,80,0,0,75,101,101,112,32,115,111,109,101,32,66,45,102,114,97,109,101,115,32,97,115,32,114,101,102,101,114,101,110,99,101,115,46,0,0,0,0,0,0,0,114,99,95,114,101,115,105,122,101,95,97,108,108,111,119,101,100,58,0,0,0,0,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,66,32,37,100,32,37,100,44,32,98,121,116,101,115,116,114,101,97,109,32,37,116,100,10,0,0,99,104,95,109,111,100,101,0,83,116,101,114,101,111,32,82,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,108,97,118,102,105,46,114,49,50,56,46,116,114,117,101,95,112,101,97,107,115,95,99,104,37,100,0,0,0,0,0,0,111,102,100,101,99,0,0,0,118,112,51,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,86,97,0,67,117,108,116,0,0,0,0,116,114,117,101,115,112,101,101,99,104,0,0,0,0,0,0,115,101,101,107,32,116,97,98,108,101,32,116,114,117,110,99,97,116,101,100,10,0,0,0,32,67,109,111,110,111,0,0,112,111,115,0,0,0,0,0,37,100,32,107,98,47,115,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,115,101,101,107,116,97,98,108,101,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,97,110,118,97,115,32,115,105,122,101,58,32,37,115,46,10,0,0,0,0,0,0,0,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,0,0,0,0,112,97,100,32,37,100,32,37,100,10,0,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,73,73,97,0,0,0,0,0,0,0,0,67,111,111,107,32,47,32,67,111,111,107,101,114,32,47,32,71,101,99,107,111,32,40,82,101,97,108,65,117,100,105,111,32,71,50,41,0,0,0,0,110,0,0,0,0,0,0,0,48,48,48,0,0,0,0,0,70,97,105,108,117,114,101,32,111,99,99,117,114,114,101,100,32,119,104,101,110,32,101,110,100,105,110,103,32,115,101,103,109,101,110,116,32,39,37,115,39,10,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,88,105,112,104,32,99,111,100,101,99,32,73,68,10,0,0,0,0,0,0,114,97,119,32,84,114,117,101,72,68,0,0,0,0,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,73,97,0,117,51,50,98,101,32,100,101,109,117,120,101,114,0,0,0,99,111,111,107,0,0,0,0,83,117,112,112,111,114,116,101,100,32,104,119,97,99,99,101,108,115,58,32,0,0,0,0,115,101,116,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,32,102,108,97,103,115,0,0,0,0,0,0,0,107,101,121,102,114,97,109,101,32,98,101,102,111,114,101,32,102,105,114,115,116,32,115,121,110,99,112,111,105,110,116,32,105,110,32,105,110,100,101,120,10,0,0,0,0,0,0,0,68,117,112,108,105,99,97,116,101,32,115,111,110,121,95,109,112,101,103,52,95,101,120,116,114,97,100,97,116,97,10,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,73,0,0,0,81,68,101,115,105,103,110,32,77,117,115,105,99,32,67,111,100,101,99,32,50,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,104,119,97,99,99,101,108,58,32,37,115,46,10,0,0,0,0,0,0,85,115,101,32,77,80,52,65,45,76,65,84,77,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,105,110,115,116,101,97,100,32,111,102,32,77,80,69,71,52,45,71,69,78,69,82,73,67,32,102,111,114,32,65,65,67,0,0,0,0,105,84,117,110,83,77,80,66,0,0,0,0,0,0,0,0,109,111,118,0,0,0,0,0,68,95,87,69,66,86,84,84,47,67,65,80,84,73,79,78,83,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,105,110,118,97,108,105,100,32,116,97,103,32,119,105,116,104,32,110,111,32,84,97,103,78,97,109,101,46,10,0,0,80,67,83,95,75,97,108,105,97,110,112,117,114,95,73,110,100,105,97,95,48,0,0,0,113,100,109,50,0,0,0,0,97,117,116,111,0,0,0,0,73,108,108,117,115,116,114,97,116,105,111,110,0,0,0,0,97,115,102,0,0,0,0,0,113,61,37,50,46,49,102,32,0,0,0,0,0,0,0,0,115,116,114,101,97,109,32,37,100,44,32,111,102,102,115,101,116,32,48,120,37,108,108,120,58,32,112,97,114,116,105,97,108,32,102,105,108,101,10,0,86,78,58,76,97,118,102,44,0,0,0,0,0,0,0,0,80,67,83,95,74,65,68,54,57,95,74,97,109,97,105,99,97,95,71,114,105,100,0,0,71,83,77,0,0,0,0,0,123,125,0,0,0,0,0,0,110,111,110,101,0,0,0,0,123,68,69,70,65,85,76,84,125,123,125,37,99,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,97,113,116,105,116,108,101,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,74,97,109,97,105,99,97,95,49,56,55,53,95,79,108,100,95,71,114,105,100,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,98,105,113,117,97,100,115,46,99,0,0,0,0,0,0,0,0,103,115,109,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,102,114,97,109,101,114,97,116,101,32,37,115,46,10,0,0,0,0,45,109,97,112,95,99,104,97,110,110,101,108,32,105,115,32,102,111,114,119,97,114,100,101,100,32,116,111,32,108,97,118,102,105,32,115,105,109,105,108,97,114,108,121,32,116,111,32,45,97,102,32,112,97,110,61,37,115,46,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2207904);
/* memory initializer */ allocate([87,101,98,77,0,0,0,0,65,80,69,84,65,71,69,88,0,0,0,0,0,0,0,0,80,67,83,95,73,110,100,105,97,110,95,49,57,55,53,95,85,84,77,95,52,56,78,0,87,101,115,116,119,111,111,100,32,65,117,100,105,111,32,40,83,78,68,49,41,0,0,0,105,110,116,101,114,108,101,97,118,101,32,114,111,119,115,32,114,105,103,104,116,32,102,105,114,115,116,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,102,105,108,101,32,37,115,32,102,111,114,32,119,114,105,116,105,110,103,46,10,0,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,115,114,99,95,102,111,114,109,97,116,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,32,48,120,37,120,10,0,0,0,0,0,0,0,76,65,84,77,32,112,97,99,107,101,116,32,115,105,122,101,32,108,97,114,103,101,114,32,116,104,97,110,32,109,97,120,105,109,117,109,32,115,105,122,101,32,48,120,49,102,102,102,10,0,0,0,0,0,0,0,80,67,83,95,73,110,100,105,97,110,95,49,57,55,53,95,85,84,77,95,52,55,78,0,119,101,115,116,119,111,111,100,95,115,110,100,49,0,0,0,97,112,101,0,0,0,0,0,73,109,97,103,101,32,115,105,122,101,32,109,117,115,116,32,109,97,116,99,104,32,101,110,99,111,100,101,114,32,105,110,105,116,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,115,105,122,101,0,0,0,37,117,58,37,117,58,37,117,46,37,117,32,37,117,58,37,117,58,37,117,46,37,117,32,37,110,0,0,0,0,0,0,78,111,32,102,105,108,101,110,97,109,101,32,115,112,101,99,105,102,105,101,100,32,97,110,100,32,110,111,32,39,102,105,108,101,110,97,109,101,39,32,116,97,103,105,110,32,115,116,114,101,97,109,32,35,37,100,58,37,100,46,10,0,0,0,70,97,105,108,101,100,32,112,97,114,115,105,110,103,32,114,97,116,101,95,100,105,118,105,115,111,114,10,0,0,0,0,99,111,109,98,109,97,116,99,104,0,0,0,0,0,0,0,79,112,101,110,67,76,58,32,67,111,109,112,105,108,97,116,105,111,110,32,102,97,105,108,101,100,44,32,117,110,97,98,108,101,32,116,111,32,113,117,101,114,121,32,98,117,105,108,100,32,108,111,103,10,0,0,97,112,99,0,0,0,0,0,121,117,118,52,50,50,112,49,54,98,101,0,0,0,0,0,70,105,114,101,66,114,105,99,107,0,0,0,0,0,0,0,32,37,115,0,0,0,0,0,50,46,49,0,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,118,101,114,116,105,99,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,111,117,116,95,115,97,109,112,108,101,95,102,109,116,0,0,100,101,102,97,117,108,116,0,58,13,10,0,0,0,0,0,100,105,114,101,99,116,61,51,0,0,0,0,0,0,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,84,72,80,0,0,0,0,0,97,100,95,99,111,110,118,95,116,121,112,101,0,0,0,0,97,100,95,99,111,110,118,95,116,121,112,101,0,0,0,0,115,101,116,32,98,108,117,101,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,80,67,83,95,73,110,100,105,97,110,95,49,57,53,52,95,85,84,77,95,52,56,78,0,99,111,100,101,100,32,121,44,37,115,44,37,115,32,105,110,116,114,97,58,32,37,46,49,102,37,37,32,37,46,49,102,37,37,32,37,46,49,102,37,37,37,115,10,0,0,0,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,65,76,65,67,32,40,65,112,112,108,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,102,114,97,109,101,32,102,105,108,101,110,97,109,101,32,119,105,116,104,32,115,116,114,102,116,105,109,101,10,0,0,0,0,0,115,107,105,112,32,37,100,32,115,97,109,112,108,101,115,32,100,117,101,32,116,111,32,115,105,100,101,32,100,97,116,97,10,0,0,0,0,0,0,0,97,110,109,0,0,0,0,0,78,111,32,101,120,116,114,97,100,97,116,97,32,116,111,32,100,117,109,112,32,105,110,32,115,116,114,101,97,109,32,35,37,100,58,37,100,46,10,0,76,105,110,101,97,114,95,76,105,110,107,95,66,101,110,111,105,116,0,0,0,0,0,0,117,110,100,101,102,105,110,101,100,0,0,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,51,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,105,108,100,99,116,0,0,0,110,111,116,105,99,101,58,32,98,95,102,114,97,109,101,95,115,116,114,97,116,101,103,121,32,111,110,108,121,32,97,102,102,101,99,116,115,32,116,104,101,32,102,105,114,115,116,32,112,97,115,115,10,0,0,0,105,110,118,97,108,105,100,32,109,98,32,116,121,112,101,32,105,110,32,66,32,70,114,97,109,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,115,116,114,101,97,109,95,116,121,112,101,32,37,88,32,105,110,32,33,77,76,80,0,0,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,74,52,52,52,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,52,52,52,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,74,52,52,48,80,32,124,124,32,97,118,99,116,120,45,62,112,105,120,95,102,109,116,32,61,61,32,65,86,95,80,73,88,95,70,77,84,95,89,85,86,52,52,48,80,0,0,98,45,112,121,114,97,109,105,100,0,0,0,0,0,0,0,114,99,95,100,114,111,112,102,114,97,109,101,95,116,104,114,101,115,104,58,0,0,0,0,83,99,101,110,101,32,100,101,116,101,99,116,105,111,110,32,105,115,32,105,103,110,111,114,101,100,32,105,110,32,97,115,101,108,101,99,116,32,102,105,108,116,101,114,10,0,0,0,98,121,116,101,115,116,114,101,97,109,32,111,118,101,114,114,101,97,100,32,37,116,100,10,0,0,0,0,0,0,0,0,108,111,103,0,0,0,0,0,115,116,101,114,101,111,95,114,101,109,97,116,114,105,120,105,110,103,0,0,0,0,0,0,108,97,118,102,105,46,114,49,50,56,46,115,97,109,112,108,101,95,112,101,97,107,115,95,99,104,37,100,0,0,0,0,97,109,114,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,51,0,0,0,80,67,83,95,73,110,100,105,97,110,95,49,57,53,52,95,85,84,77,95,52,55,78,0,67,111,109,101,100,121,0,0,97,108,97,99,0,0,0,0,106,108,115,0,0,0,0,0,110,0,0,0,0,0,0,0,44,32,98,105,116,114,97,116,101,58,32,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,67,111,100,101,99,32,65,86,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,105,110,112,117,116,32,102,105,108,101,32,35,37,100,32,40,37,115,41,32,104,97,115,32,110,111,116,32,98,101,101,110,32,117,115,101,100,32,102,111,114,32,97,110,121,32,115,116,114,101,97,109,46,32,84,104,101,32,109,111,115,116,32,108,105,107,101,108,121,32,114,101,97,115,111,110,32,105,115,32,101,105,116,104,101,114,32,119,114,111,110,103,32,116,121,112,101,32,40,101,46,103,46,32,97,32,118,105,100,101,111,32,111,112,116,105,111,110,32,119,105,116,104,32,110,111,32,118,105,100,101,111,32,115,116,114,101,97,109,115,41,32,111,114,32,116,104,97,116,32,105,116,32,105,115,32,97,32,112,114,105,118,97,116,101,32,111,112,116,105,111,110,32,111,102,32,115,111,109,101,32,100,101,99,111,100,101,114,32,119,104,105,99,104,32,119,97,115,32,110,111,116,32,97,99,116,117,97,108,108,121,32,117,115,101,100,32,102,111,114,32,97,110,121,32,115,116,114,101,97,109,46,10,0,0,73,110,118,97,108,105,100,32,67,77,65,80,32,99,104,117,110,107,32,115,105,122,101,32,37,100,10,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,117,10,0,0,0,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,52,83,0,0,0,83,104,111,114,116,101,110,0,67,111,100,101,99,32,65,86,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,105,110,112,117,116,32,102,105,108,101,32,35,37,100,32,40,37,115,41,32,105,115,32,110,111,116,32,97,32,100,101,99,111,100,105,110,103,32,111,112,116,105,111,110,46,10,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,99,111,108,111,114,32,110,97,109,101,115,0,0,0,0,0,0,115,101,116,32,105,110,105,116,105,97,108,32,116,105,109,101,115,116,97,109,112,32,111,102,102,115,101,116,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,111,112,117,115,47,52,56,48,48,48,13,10,0,0,0,0,0,0,0,0,116,114,117,101,104,100,0,0,103,101,110,114,101,0,0,0,79,117,116,112,117,116,32,105,115,32,110,111,116,32,115,101,101,107,97,98,108,101,10,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,51,83,0,0,0,117,51,50,108,101,32,100,101,109,117,120,101,114,0,0,0,115,104,111,114,116,101,110,0,37,115,58,32,99,111,117,108,100,32,110,111,116,32,115,101,101,107,32,116,111,32,112,111,115,105,116,105,111,110,32,37,48,46,51,102,10,0,0,0,101,114,114,95,100,101,116,101,99,116,0,0,0,0,0,0,35,69,88,84,45,88,45,84,65,82,71,69,84,68,85,82,65,84,73,79,78,58,37,100,10,0,0,0,0,0,0,0,105,110,100,101,120,32,111,118,101,114,102,108,111,119,32,66,10,0,0,0,0,0,0,0,108,111,99,97,108,32,116,97,103,32,37,35,48,52,120,32,101,120,116,101,110,100,115,32,112,97,115,116,32,101,110,100,32,111,102,32,108,111,99,97,108,32,115,101,116,32,64,32,37,35,108,108,120,10,0,0,99,111,111,107,105,101,115,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,50,83,0,0,0,77,80,51,111,110,77,80,52,0,0,0,0,0,0,0,0,37,115,58,32,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,99,111,100,101,99,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,37,115,32,102,111,114,32,119,114,105,116,105,110,103,10,0,0,108,97,116,109,0,0,0,0,37,115,0,0,0,0,0,0,86,101,114,32,49,10,66,114,32,37,46,54,102,10,73,112,103,32,49,10,80,112,105,32,37,100,10,66,112,105,111,112,32,37,100,10,80,105,120,32,48,10,67,102,32,37,100,10,67,103,32,37,100,10,83,108,32,37,100,10,110,108,49,54,32,37,100,10,86,105,32,49,10,102,49,32,49,10,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,109,105,109,101,116,121,112,101,0,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,105,110,100,101,120,32,101,110,116,114,105,101,115,32,37,117,32,40,37,120,41,10,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,49,83,0,0,0,109,112,51,111,110,52,0,0,71,73,70,32,100,101,109,117,120,101,114,0,0,0,0,0,97,0,0,0,0,0,0,0,65,32,98,114,105,103,104,116,32,99,111,108,111,117,114,101,100,32,102,105,115,104,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,98,105,116,95,114,97,116,101,0,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,103,55,50,50,46,99,0,0,0,0,0,0,73,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,102,114,97,109,101,32,99,104,97,110,103,101,100,32,102,114,111,109,32,114,97,116,101,58,37,100,32,102,109,116,58,37,115,32,99,104,58,37,100,32,99,104,108,58,37,115,32,116,111,32,114,97,116,101,58,37,100,32,102,109,116,58,37,115,32,99,104,58,37,100,32,99,104,108,58,37,115,10,0,0,0,0,0,0,99,111,108,111,114,115,0,0,44,32,37,56,100,44,32,48,120,37,48,56,120,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,0,65,68,85,32,40,65,112,112,108,105,99,97,116,105,111,110,32,68,97,116,97,32,85,110,105,116,41,32,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,112,105,120,101,108,95,102,111,114,109,97,116,0,0,0,0,97,117,116,104,111,114,0,0,86,105,100,101,111,32,99,111,100,101,99,32,39,37,115,39,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,69,110,99,111,100,101,114,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,48,0,0,0,0,0,0,0,109,112,51,97,100,117,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,115,101,116,32,73,47,79,32,111,112,101,114,97,116,105,111,110,32,109,97,120,105,109,117,109,32,98,108,111,99,107,32,115,105,122,101,0,0,0,0,58,99,37,100,61,99,37,100,0,0,0,0,0,0,0,0,84,73,77,69,66,65,83,69,61,37,100,47,37,100,10,0,83,84,65,82,84,61,37,108,108,100,0,0,0,0,0,0,102,102,109,45,62,112,97,99,107,101,116,95,101,110,100,32,62,61,32,102,102,109,45,62,112,97,99,107,101,116,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,0,70,76,65,67,32,40,70,114,101,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,0,105,114,114,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,100,10,0,0,0,0,115,114,99,104,0,0,0,0,85,110,107,110,111,119,110,32,116,97,103,32,37,99,37,99,37,99,37,99,10,0,0,0,67,97,110,39,116,32,105,110,105,116,105,97,108,105,122,101,32,68,86,32,102,111,114,109,97,116,33,10,77,97,107,101,32,115,117,114,101,32,116,104,97,116,32,121,111,117,32,115,117,112,112,108,121,32,101,120,97,99,116,108,121,32,116,119,111,32,115,116,114,101,97,109,115,58,10,32,32,32,32,32,118,105,100,101,111,58,32,50,53,102,112,115,32,111,114,32,50,57,46,57,55,102,112,115,44,32,97,117,100,105,111,58,32,50,99,104,47,52,56,107,72,122,47,80,67,77,10,32,32,32,32,32,40,53,48,77,98,112,115,32,97,108,108,111,119,115,32,97,110,32,111,112,116,105,111,110,97,108,32,115,101,99,111,110,100,32,97,117,100,105,111,32,115,116,114,101,97,109,41,10,0,0,0,0,67,97,110,39,116,32,100,101,116,101,114,109,105,110,101,32,112,114,111,102,105,108,101,32,111,102,32,68,86,32,105,110,112,117,116,32,115,116,114,101,97,109,46,10,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,55,83,0,0,0,90,101,114,111,32,70,80,83,32,114,101,112,111,114,116,101,100,44,32,100,101,102,97,117,108,116,105,110,103,32,116,111,32,49,48,10,0,0,0,0,102,108,97,99,0,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,102,111,114,109,97,116,46,32,79,110,108,121,32,89,86,49,50,44,32,73,52,50,48,44,32,73,52,50,50,44,32,73,52,52,52,32,105,109,97,103,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,76,105,110,101,32,37,100,58,32,102,105,108,101,110,97,109,101,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,67,68,88,76,32,100,101,109,117,120,101,114,0,0,0,0,115,101,116,32,115,99,101,110,101,32,99,104,97,110,103,101,32,100,101,116,101,99,116,105,111,110,32,116,104,114,101,115,104,111,108,100,0,0,0,0,45,68,86,69,67,84,79,82,73,90,69,61,49,0,0,0,121,117,118,52,50,50,112,49,54,108,101,0,0,0,0,0,68,111,100,103,101,114,66,108,117,101,0,0,0,0,0,0,37,99,0,0,0,0,0,0,115,116,101,114,101,111,0,0,100,115,116,95,118,95,99,104,114,95,112,111,115,0,0,0,109,117,120,105,110,103,32,99,111,100,101,99,32,99,117,114,114,101,110,116,108,121,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,98,105,116,101,120,97,99,116,0,0,0,0,0,0,0,0,44,13,10,0,0,0,0,0,49,115,116,32,112,97,115,115,32,119,97,115,32,108,111,115,115,108,101,115,115,44,32,98,105,116,114,97,116,101,32,112,114,101,100,105,99,116,105,111,110,32,119,105,108,108,32,98,101,32,105,110,97,99,99,117,114,97,116,101,10,0,0,0,97,100,112,99,109,95,116,104,112,0,0,0,0,0,0,0,78,111,116,32,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,112,97,99,107,101,116,32,116,97,98,108,101,10,0,0,0,0,0,78,111,116,32,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,0,0,0,0,98,108,117,101,0,0,0,0,110,111,32,100,101,99,111,100,101,114,32,99,111,110,102,105,103,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,54,83,0,0,0,32,105,110,116,101,114,58,32,37,46,49,102,37,37,32,37,46,49,102,37,37,32,37,46,49,102,37,37,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,83,105,101,114,114,97,32,86,77,68,32,97,117,100,105,111,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,101,100,105,97,32,116,121,112,101,32,102,111,114,32,97,117,100,105,111,10,0,0,0,116,111,111,32,109,97,110,121,32,98,108,111,99,107,115,58,32,37,117,10,0,0,0,0,47,100,101,118,47,115,116,100,105,110,0,0,0,0,0,0,76,105,110,101,97,114,95,76,105,110,107,0,0,0,0,0,37,46,49,53,103,37,115,0,99,51,95,101,120,112,114,0,37,100,44,37,100,0,0,0,110,111,114,109,97,108,105,122,101,32,97,100,97,112,116,105,118,101,32,113,117,97,110,116,105,122,97,116,105,111,110,0,109,98,95,116,104,114,101,115,104,111,108,100,32,116,111,111,32,108,97,114,103,101,44,32,109,97,120,32,105,115,32,37,100,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,98,32,116,121,112,101,32,105,110,32,80,32,70,114,97,109,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,115,116,114,101,97,109,95,116,121,112,101,32,37,88,32,105,110,32,77,76,80,0,0,0,0,0,0,0,0,78,111,32,74,80,69,71,32,100,97,116,97,32,102,111,117,110,100,32,105,110,32,105,109,97,103,101,10,0,0,0,0,73,110,102,108,117,101,110,99,101,115,32,104,111,119,32,111,102,116,101,110,32,66,45,102,114,97,109,101,115,32,97,114,101,32,117,115,101,100,0,0,114,97,116,101,32,99,111,110,116,114,111,108,32,115,101,116,116,105,110,103,115,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,100,10,32,32,37,42,115,37,112,40,37,122,117,41,10,32,32,37,42,115,37,117,10,0,0,0,0,0,101,88,116,101,110,100,101,100,32,66,73,78,97,114,121,32,116,101,120,116,32,40,88,66,73,78,41,32,100,101,109,117,120,101,114,0,0,0,0,0,32,45,62,32,115,101,108,101,99,116,58,37,102,32,115,101,108,101,99,116,95,111,117,116,58,37,100,10,0,0,0,0,104,45,62,98,108,111,99,107,95,111,102,102,115,101,116,91,49,53,93,32,61,61,32,40,52,32,42,32,40,40,115,99,97,110,56,91,49,53,93,32,45,32,115,99,97,110,56,91,48,93,41,32,38,32,55,41,32,60,60,32,104,45,62,112,105,120,101,108,95,115,104,105,102,116,41,32,43,32,52,32,42,32,104,45,62,108,105,110,101,115,105,122,101,32,42,32,40,40,115,99,97,110,56,91,49,53,93,32,45,32,115,99,97,110,56,91,48,93,41,32,62,62,32,51,41,0,0,0,115,101,97,114,99,104,0,0,72,68,67,68,0,0,0,0,108,97,118,102,105,46,114,49,50,56,46,76,82,65,46,104,105,103,104,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,108,97,114,103,101,115,116,32,102,114,97,109,101,32,115,105,122,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,102,105,108,101,32,115,105,122,101,10,0,0,0,0,0,0,105,110,100,101,111,51,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,51,78,0,0,0,117,110,107,110,111,119,110,32,98,108,111,99,107,32,40,99,104,97,114,97,99,116,101,114,32,61,32,37,99,44,32,100,101,99,105,109,97,108,32,61,32,37,100,44,32,104,101,120,32,61,32,37,120,41,33,33,33,10,0,0,0,0,0,0,83,111,117,116,104,101,114,110,32,82,111,99,107,0,0,0,118,109,100,97,117,100,105,111,0,0,0,0,0,0,0,0,84,104,101,32,112,105,120,101,108,32,102,111,114,109,97,116,32,39,37,115,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,37,100,46,37,48,54,100,0,85,110,107,110,111,119,110,32,105,110,112,117,116,32,102,111,114,109,97,116,58,32,39,37,115,39,10,0,0,0,0,0,37,115,0,0,0,0,0,0,83,116,97,116,105,115,116,105,99,115,58,32,37,100,32,115,101,101,107,115,44,32,37,100,32,119,114,105,116,101,111,117,116,115,10,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,50,78,0,0,0,78,85,76,76,0,0,0,0,77,65,67,69,32,40,77,97,99,105,110,116,111,115,104,32,65,117,100,105,111,32,67,111,109,112,114,101,115,115,105,111,110,47,69,120,112,97,110,115,105,111,110,41,32,54,58,49,0,0,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,111,112,101,110,32,116,104,101,32,39,37,115,39,32,112,114,111,116,111,99,111,108,32,102,111,114,32,114,101,97,100,105,110,103,10,0,0,0,0,0,0,0,69,114,114,111,114,32,99,111,110,102,105,103,117,114,105,110,103,32,102,105,108,116,101,114,46,10,0,0,0,0,0,0,37,115,32,105,115,32,102,114,101,101,32,115,111,102,116,119,97,114,101,59,32,121,111,117,32,99,97,110,32,114,101,100,105,115,116,114,105,98,117,116,101,32,105,116,32,97,110,100,47,111,114,32,109,111,100,105,102,121,10,105,116,32,117,110,100,101,114,32,116,104,101,32,116,101,114,109,115,32,111,102,32,116,104,101,32,71,78,85,32,71,101,110,101,114,97,108,32,80,117,98,108,105,99,32,76,105,99,101,110,115,101,32,97,115,32,112,117,98,108,105,115,104,101,100,32,98,121,10,116,104,101,32,70,114,101,101,32,83,111,102,116,119,97,114,101,32,70,111,117,110,100,97,116,105,111,110,59,32,101,105,116,104,101,114,32,118,101,114,115,105,111,110,32,50,32,111,102,32,116,104,101,32,76,105,99,101,110,115,101,44,32,111,114,10,40,97,116,32,121,111,117,114,32,111,112,116,105,111,110,41,32,97,110,121,32,108,97,116,101,114,32,118,101,114,115,105,111,110,46,10,10,37,115,32,105,115,32,100,105,115,116,114,105,98,117,116,101,100,32,105,110,32,116,104,101,32,104,111,112,101,32,116,104,97,116,32,105,116,32,119,105,108,108,32,98,101,32,117,115,101,102,117,108,44,10,98,117,116,32,87,73,84,72,79,85,84,32,65,78,89,32,87,65,82,82,65,78,84,89,59,32,119,105,116,104,111,117,116,32,101,118,101,110,32,116,104,101,32,105,109,112,108,105,101,100,32,119,97,114,114,97,110,116,121,32,111,102,10,77,69,82,67,72,65,78,84,65,66,73,76,73,84,89,32,111,114,32,70,73,84,78,69,83,83,32,70,79,82,32,65,32,80,65,82,84,73,67,85,76,65,82,32,80,85,82,80,79,83,69,46,32,32,83,101,101,32,116,104,101,10,71,78,85,32,71,101,110,101,114,97,108,32,80,117,98,108,105,99,32,76,105,99,101,110,115,101,32,102,111,114,32,109,111,114,101,32,100,101,116,97,105,108,115,46,10,10,89,111,117,32,115,104,111,117,108,100,32,104,97,118,101,32,114,101,99,101,105,118,101,100,32,97,32,99,111,112,121,32,111,102,32,116,104,101,32,71,78,85,32,71,101,110,101,114,97,108,32,80,117,98,108,105,99,32,76,105,99,101,110,115,101,10,97,108,111,110,103,32,119,105,116,104,32,37,115,59,32,105,102,32,110,111,116,44,32,119,114,105,116,101,32,116,111,32,116,104,101,32,70,114,101,101,32,83,111,102,116,119,97,114,101,10,70,111,117,110,100,97,116,105,111,110,44,32,73,110,99,46,44,32,53,49,32,70,114,97,110,107,108,105,110,32,83,116,114,101,101,116,44,32,70,105,102,116,104,32,70,108,111,111,114,44,32,66,111,115,116,111,110,44,32,77,65,32,48,50,49,49,48,45,49,51,48,49,32,85,83,65,10,0,0,0,0,0,0,0,105,110,105,116,105,97,108,95,111,102,102,115,101,116,0,0,97,61,102,109,116,112,58,37,100,32,118,98,114,61,37,115,13,10,0,0,0,0,0,0,97,118,105,115,116,45,62,102,114,97,109,101,115,95,104,100,114,95,115,116,114,109,0,0,121,117,118,44,114,103,98,0,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,116,105,109,101,115,116,97,109,112,32,37,108,108,100,32,105,110,32,105,110,100,101,120,32,37,108,108,100,32,46,46,32,37,108,108,100,10,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,49,78,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,99,114,101,97,116,101,32,115,99,97,108,101,32,99,111,110,116,101,120,116,32,102,111,114,32,116,104,101,32,99,111,110,118,101,114,115,105,111,110,32,102,109,116,58,37,115,32,115,58,37,100,120,37,100,32,45,62,32,102,109,116,58,37,115,32,115,58,37,100,120,37,100,10,0,116,98,0,0,0,0,0,0,117,50,52,98,101,32,100,101,109,117,120,101,114,0,0,0,109,97,99,101,54,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,37,115,32,39,37,115,39,32,119,97,115,32,115,112,101,99,105,102,105,101,100,32,116,104,114,111,117,103,104,32,116,104,101,32,37,115,32,111,112,116,105,111,110,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,44,32,119,104,105,99,104,32,105,115,32,102,101,100,32,102,114,111,109,32,97,32,99,111,109,112,108,101,120,32,102,105,108,116,101,114,103,114,97,112,104,46,10,37,115,32,97,110,100,32,45,102,105,108,116,101,114,95,99,111,109,112,108,101,120,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,116,111,103,101,116,104,101,114,32,102,111,114,32,116,104,101,32,115,97,109,101,32,115,116,114,101,97,109,46,10,0,0,0,0,0,0,115,101,116,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,32,102,108,97,103,115,32,40,100,101,112,114,101,99,97,116,101,100,59,32,117,115,101,32,101,114,114,95,100,101,116,101,99,116,44,32,115,97,118,101,32,118,105,97,32,97,118,99,111,110,118,41,0,68,105,97,108,111,103,117,101,58,32,37,108,100,44,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,37,115,13,10,0,0,105,110,100,101,120,32,111,118,101,114,102,108,111,119,32,65,32,37,100,32,43,32,37,108,108,117,32,62,61,32,37,100,10,0,0,0,0,0,0,0,91,83,99,114,105,112,116,32,73,110,102,111,93,0,0,0,108,111,99,97,108,32,116,97,103,32,37,35,48,52,120,32,119,105,116,104,32,48,32,115,105,122,101,10,0,0,0,0,115,101,116,32,80,65,84,44,32,80,77,84,32,97,110,100,32,83,68,84,32,118,101,114,115,105,111,110,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,53,48,78,0,0,0,116,116,0,0,0,0,0,0,77,65,67,69,32,40,77,97,99,105,110,116,111,115,104,32,65,117,100,105,111,32,67,111,109,112,114,101,115,115,105,111,110,47,69,120,112,97,110,115,105,111,110,41,32,51,58,49,0,0,0,0,0,0,0,0,45,102,105,108,116,101,114,95,115,99,114,105,112,116,0,0,82,84,80,32,109,117,120,101,114,32,102,108,97,103,115,0,112,107,116,110,117,109,58,37,100,44,32,112,107,116,99,116,58,37,100,32,32,112,116,115,58,32,37,108,108,100,10,0,37,100,47,37,100,0,0,0,10,0,0,0,0,0,0,0,115,116,101,114,101,111,95,109,111,100,101,0,0,0,0,0,65,80,69,32,84,97,103,32,105,115,32,97,32,104,101,97,100,101,114,10,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,117,108,116,114,97,32,115,105,109,112,108,101,47,115,108,111,119,32,112,111,115,116,112,114,111,99,101,115,115,0,0,0,78,111,32,102,114,97,109,101,115,32,105,110,32,116,104,101,32,102,105,108,101,33,10,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,57,78,0,0,0,112,114,111,103,114,101,115,115,105,118,101,0,0,0,0,0,109,97,99,101,51,0,0,0,45,118,102,47,45,97,102,47,45,102,105,108,116,101,114,0,77,111,118,105,101,47,118,105,100,101,111,32,115,99,114,101,101,110,32,99,97,112,116,117,114,101,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,102,105,110,100,32,100,101,102,97,117,108,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,102,111,114,32,73,110,112,117,116,32,83,116,114,101,97,109,32,35,37,100,46,37,100,10,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,115,97,109,112,108,101,32,102,111,114,109,97,116,115,0,0,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,56,78,0,0,0,109,112,101,103,50,32,115,111,102,116,32,51,58,50,32,112,117,108,108,100,111,119,110,0,70,105,101,108,100,32,111,114,100,101,114,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,50,0,0,0,83,116,114,101,97,109,99,111,112,121,32,114,101,113,117,101,115,116,101,100,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,44,32,119,104,105,99,104,32,105,115,32,102,101,100,32,102,114,111,109,32,97,32,99,111,109,112,108,101,120,32,102,105,108,116,101,114,103,114,97,112,104,46,32,70,105,108,116,101,114,105,110,103,32,97,110,100,32,115,116,114,101,97,109,99,111,112,121,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,116,111,103,101,116,104,101,114,46,10,0,0,0,0,0,0,0,110,111,95,98,105,116,115,116,114,101,97,109,0,0,0,0,65,115,112,101,99,116,82,97,116,105,111,89,0,0,0,0,115,111,102,116,112,117,108,108,100,111,119,110,58,32,85,110,101,120,112,101,99,116,101,100,32,102,105,101,108,100,32,102,108,97,103,115,58,32,115,116,97,116,101,61,37,100,32,116,111,112,95,102,105,101,108,100,95,102,105,114,115,116,61,37,100,32,114,101,112,101,97,116,95,102,105,114,115,116,95,102,105,101,108,100,61,37,100,10,0,0,0,0,0,0,0,0,105,108,112,97,99,107,58,32,117,110,107,110,111,119,110,32,109,111,100,101,32,37,100,32,40,102,97,108,108,98,97,99,107,32,116,111,32,108,105,110,101,97,114,41,10,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,55,78,0,0,0,102,105,101,108,100,95,111,114,100,101,114,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,119,109,97,118,50,0,0,0,118,102,95,101,113,50,58,32,99,61,37,46,50,102,32,98,61,37,46,50,102,32,103,61,37,46,52,102,32,115,61,37,46,50,102,32,10,0,0,0,79,110,108,121,32,118,105,100,101,111,32,97,110,100,32,97,117,100,105,111,32,102,105,108,116,101,114,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,32,99,117,114,114,101,110,116,108,121,46,10,0,0,98,114,105,103,104,116,110,101,115,115,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,102,114,97,109,101,32,102,114,111,109,32,102,105,108,101,10,0,48,120,37,108,108,120,0,0,102,115,45,62,111,110,95,101,118,101,110,116,0,0,0,0,112,111,115,116,112,114,111,99,101,115,115,32,55,0,0,0,80,67,83,95,73,68,55,52,95,85,84,77,95,122,111,110,101,95,52,54,78,0,0,0,83,107,105,112,32,112,114,111,99,101,115,115,105,110,103,32,97,108,112,104,97,0,0,0,115,114,99,45,62,97,117,100,105,111,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,49,0,0,0,105,110,116,101,114,108,101,97,118,101,32,114,111,119,115,32,108,101,102,116,32,102,105,114,115,116,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,118,111,108,117,109,101,100,101,116,101,99,116,46,99,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,32,105,110,32,109,97,116,114,105,120,32,34,37,115,34,32,97,116,32,99,111,101,102,102,32,37,100,10,0,0,0,0,0,0,0,0,115,114,99,119,0,0,0,0,118,111,108,117,109,101,95,105,58,37,100,47,50,53,53,32,0,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,80,67,83,95,71,97,114,111,117,97,95,85,84,77,95,122,111,110,101,95,51,51,78,0,52,58,50,58,48,32,112,108,97,110,97,114,32,45,62,32,52,58,50,58,50,32,112,97,99,107,101,100,32,114,101,105,110,116,101,114,108,97,99,101,114,0,0,0,0,0,0,0,115,107,105,112,95,97,108,112,104,97,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,119,109,97,118,49,0,0,0,99,116,120,45,62,112,101,110,100,105,110,103,95,102,114,97,109,101,95,99,111,117,110,116,32,60,61,32,56,0,0,0,43,112,97,115,115,50,0,0,67,104,97,110,110,101,108,32,34,37,46,56,115,34,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,32,105,110,32,116,104,101,32,99,104,111,115,101,110,32,108,97,121,111,117,116,10,0,0,0,0,0,115,99,116,104,114,101,115,104,0,0,0,0,0,0,0,0,79,112,101,110,67,76,58,32,117,110,97,98,108,101,32,116,111,32,99,114,101,97,116,101,32,112,114,111,103,114,97,109,10,0,0,0,0,0,0,0,121,117,118,52,50,48,112,49,54,98,101,0,0,0,0,0,68,105,109,71,114,97,121,0,60,99,104,97,110,110,101,108,95,108,97,121,111,117,116,62,0,0,0,0,0,0,0,0,109,111,110,111,0,0,0,0,105,32,60,32,99,116,120,45,62,110,98,95,105,110,112,117,116,115,0,0,0,0,0,0,115,111,117,114,99,101,32,104,111,114,105,122,111,110,116,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,105,110,95,115,97,109,112,108,101,95,102,109,116,0,0,0,98,101,0,0,0,0,0,0,13,10,0,0,0,0,0,0,113,112,61,48,0,0,0,0,65,68,80,67,77,32,83,104,111,99,107,119,97,118,101,32,70,108,97,115,104,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,103,0,0,0,0,0,0,0,101,112,67,111,110,102,105,103,32,37,100,0,0,0,0,0,80,67,83,95,70,97,104,117,100,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,114,101,102,99,111,117,110,116,101,100,95,102,114,97,109,101,115,0,0,0,0,0,0,0,100,105,114,101,99,116,32,109,118,115,32,32,115,112,97,116,105,97,108,58,37,46,49,102,37,37,32,116,101,109,112,111,114,97,108,58,37,46,49,102,37,37,10,0,0,0,0,0,32,86,111,114,98,105,115,32,105,100,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,102,114,97,109,105,110,103,32,102,108,97,103,32,110,111,116,32,115,101,116,41,46,32,10,0,0,0,0,0,0,66,105,116,115,32,111,118,101,114,99,111,110,115,117,109,112,116,105,111,110,58,32,37,105,32,62,32,37,105,10,0,0,100,118,97,117,100,105,111,0,105,110,118,97,108,105,100,32,112,97,99,107,101,116,58,32,78,85,76,76,32,100,97,116,97,44,32,115,105,122,101,32,33,61,32,48,10,0,0,0,100,101,99,97,121,115,0,0,43,112,97,115,115,49,0,0,76,105,110,101,97,114,95,70,111,111,116,95,73,110,100,105,97,110,0,0,0,0,0,0,85,110,107,110,111,119,110,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,116,97,103,32,37,100,47,48,88,37,48,88,10,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,50,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,115,116,101,114,101,111,0,0,80,67,77,32,68,45,67,105,110,101,109,97,32,97,117,100,105,111,32,115,105,103,110,101,100,32,50,52,45,98,105,116,0,0,0,0,0,0,0,0,100,101,98,108,111,99,107,0,110,97,113,0,0,0,0,0,102,114,97,109,101,114,97,116,101,32,110,111,116,32,115,101,116,10,0,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,108,105,115,116,32,111,102,32,99,104,97,110,110,101,108,32,109,97,112,112,101,100,58,32,39,37,115,39,46,10,0,0,0,0,102,97,115,116,32,115,105,109,112,108,101,32,112,111,115,116,112,114,111,99,101,115,115,0,105,110,118,97,108,105,100,32,109,98,32,116,121,112,101,32,105,110,32,73,32,70,114,97,109,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,37,100,32,115,117,98,115,116,114,101,97,109,115,32,40,109,111,114,101,32,116,104,97,110,32,116,104,101,32,109,97,120,105,109,117,109,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,100,101,99,111,100,101,114,41,0,0,69,79,73,32,109,105,115,115,105,110,103,44,32,101,109,117,108,97,116,105,110,103,10,0,98,45,98,105,97,115,0,0,103,95,108,97,103,95,105,110,95,102,114,97,109,101,115,58,0,0,0,0,0,0,0,0,32,115,97,109,112,108,101,115,95,110,58,37,100,32,99,111,110,115,117,109,101,100,95,115,97,109,112,108,101,115,95,110,58,37,100,0,0,0,0,0,99,111,110,116,101,120,116,95,99,111,117,110,116,32,62,32,48,0,0,0,0,0,0,0,56,108,101,118,101,108,0,0,104,100,99,100,0,0,0,0,108,97,118,102,105,46,114,49,50,56,46,76,82,65,46,108,111,119,0,0,0,0,0,0,72,46,50,54,52,32,47,32,65,86,67,32,47,32,77,80,69,71,45,52,32,65,86,67,32,47,32,77,80,69,71,45,52,32,112,97,114,116,32,49,48,0,0,0,0,0,0,0,80,67,83,95,70,97,104,117,100,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,112,114,101,95,100,101,99,111,100,101,114,0,0,0,0,0,68,114,101,97,109,0,0,0,86,111,114,98,105,115,0,0,37,115,10,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,101,110,97,98,108,101,10,0,0,0,44,32,115,116,97,114,116,58,32,0,0,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,114,99,95,111,118,101,114,114,105,100,101,10,0,0,0,0,0,0,66,111,111,115,116,32,111,114], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2218144);
/* memory initializer */ allocate([32,99,117,116,32,117,112,112,101,114,32,102,114,101,113,117,101,110,99,105,101,115,46,0,115,101,116,32,116,101,109,112,111,32,115,99,97,108,101,32,102,97,99,116,111,114,0,0,115,49,0,0,0,0,0,0,100,97,116,97,32,101,114,114,111,114,0,0,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,100,111,95,110,111,116,104,105,110,103,0,0,0,0,0,0,118,111,114,98,105,115,0,0,77,97,120,32,108,101,118,101,108,58,32,37,102,10,0,0,37,100,44,37,100,44,37,100,0,0,0,0,0,0,0,0,118,101,114,115,105,111,110,0,37,48,56,88,32,0,0,0,114,101,115,101,116,32,116,105,109,101,115,116,97,109,112,115,32,97,116,32,116,104,101,32,98,101,103,105,110,32,111,102,32,101,97,99,104,32,115,101,103,109,101,110,116,0,0,0,83,111,102,116,119,97,114,101,32,101,113,117,97,108,105,122,101,114,0,0,0,0,0,0,111,102,102,0,0,0,0,0,100,101,102,97,117,108,116,0,104,101,97,100,101,114,32,99,114,99,32,109,105,115,109,97,116,99,104,0,0,0,0,0,110,0,0,0,0,0,0,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,115,101,116,32,105,110,112,117,116,32,116,101,120,116,32,115,117,98,116,105,116,108,101,115,32,99,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,32,109,111,100,101,0,0,0,0,0,0,0,0,117,50,52,108,101,32,100,101,109,117,120,101,114,0,0,0,68,67,65,32,40,68,84,83,32,67,111,104,101,114,101,110,116,32,65,99,111,117,115,116,105,99,115,41,0,0,0,0,115,101,116,32,105,110,112,117,116,32,103,97,105,110,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,105,110,116,101,114,32,109,97,116,114,105,120,46,10,0,0,0,0,102,95,101,114,114,95,100,101,116,101,99,116,0,0,0,0,115,111,102,116,32,118,105,100,101,111,32,101,113,117,97,108,105,122,101,114,0,0,0,0,112,97,100,95,108,101,110,0,69,114,114,111,114,32,115,121,110,99,112,111,105,110,116,95,99,111,117,110,116,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,0,0,112,97,114,116,105,116,105,111,110,32,37,105,58,32,98,97,100,32,84,104,105,115,80,97,114,116,105,116,105,111,110,32,61,32,37,108,108,88,10,0,102,114,97,109,101,95,108,105,115,116,45,62,101,110,100,32,33,61,32,48,76,0,0,0,116,97,98,108,101,115,95,118,101,114,115,105,111,110,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,32,111,118,101,114,108,97,112,58,32,111,117,116,112,117,116,32,108,97,121,111,117,116,32,119,105,108,108,32,98,101,32,100,101,116,101,114,109,105,110,101,100,32,98,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,100,105,115,116,105,110,99,116,32,105,110,112,117,116,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,115,117,98,95,99,104,97,114,101,110,99,95,109,111,100,101,0,0,0,0,0,0,0,0,100,116,115,0,0,0,0,0,109,112,95,105,109,97,103,101,58,32,117,110,107,110,111,119,110,32,111,117,116,95,102,109,116,58,32,48,120,37,88,10,0,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,105,110,116,114,97,32,109,97,116,114,105,120,46,10,0,0,0,0,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,105,110,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,97,116,116,97,99,104,109,101,110,116,10,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,0,115,101,116,32,105,110,112,117,116,32,116,101,120,116,32,115,117,98,116,105,116,108,101,115,32,99,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,0,0,0,0,0,100,101,108,97,121,91,37,100,93,58,32,37,102,32,105,115,32,111,117,116,32,111,102,32,97,108,108,111,119,101,100,32,114,97,110,103,101,58,32,40,48,44,32,57,48,48,48,48,93,10,0,0,0,0,0,0,98,115,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,0,0,0,0,0,65,84,83,67,32,65,47,53,50,65,32,40,65,67,45,51,41,0,0,0,0,0,0,0,105,109,97,103,101,50,0,0,85,110,107,110,111,119,110,32,112,105,120,101,108,32,102,111,114,109,97,116,32,114,101,113,117,101,115,116,101,100,58,32,37,115,46,10,0,0,0,0,68,117,114,105,110,103,32,112,101,114,102,111,114,109,97,110,99,101,0,0,0,0,0,0,124,0,0,0,0,0,0,0,98,101,115,116,95,114,97,116,101,32,60,32,73,78,84,95,77,65,88,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,37,100,32,105,110,118,97,108,105,100,10,0,115,101,116,32,116,104,101,32,39,124,39,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,99,104,97,110,110,101,108,115,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,0,0,115,97,109,112,108,101,95,102,109,116,115,0,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,52,78,0,0,0,105,115,95,105,110,116,101,114,95,109,111,100,101,40,109,111,100,101,41,0,0,0,0,0,115,117,98,95,99,104,97,114,101,110,99,0,0,0,0,0,97,99,51,0,0,0,0,0,73,110,118,97,108,105,100,32,97,115,112,101,99,116,32,114,97,116,105,111,58,32,37,115,10,0,0,0,0,0,0,0,65,115,112,101,99,116,82,97,116,105,111,88,0,0,0,0,78,117,108,108,32,118,105,100,101,111,32,115,111,117,114,99,101,44,32,114,101,116,117,114,110,32,117,110,112,114,111,99,101,115,115,101,100,32,118,105,100,101,111,32,102,114,97,109,101,115,46,0,0,0,0,0,115,101,103,109,101,110,116,95,105,100,32,62,61,32,48,32,38,38,32,115,101,103,109,101,110,116,95,105,100,32,60,32,77,65,88,95,83,69,71,77,69,78,84,83,0,0,0,0,50,53,0,0,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,51,78,0,0,0,112,107,116,95,116,105,109,101,98,97,115,101,0,0,0,0,73,110,118,97,108,105,100,32,102,114,101,113,117,101,110,99,121,32,37,102,46,32,70,114,101,113,117,101,110,99,121,32,109,117,115,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,104,97,108,102,32,116,104,101,32,115,97,109,112,108,101,45,114,97,116,101,32,37,100,46,10,0,0,0,0,0,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,0,118,112,57,47,100,101,99,111,100,101,114,47,118,112,57,95,100,101,99,111,100,101,102,114,97,109,101,46,99,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,114,97,116,101,32,118,97,108,117,101,58,32,37,115,10,0,0,0,0,115,0,0,0,0,0,0,0,97,108,108,95,99,104,97,110,110,101,108,95,99,111,117,110,116,115,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,115,101,116,32,116,105,109,101,32,98,97,115,101,10,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,104,0,0,0,0,0,0,0,51,50,48,120,50,52,48,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,0,115,97,109,112,108,101,32,102,111,114,109,97,116,32,97,117,100,105,111,32,100,101,99,111,100,101,114,115,32,115,104,111,117,108,100,32,112,114,101,102,101,114,0,0,0,0,0,0,97,97,99,0,0,0,0,0,105,114,108,0,0,0,0,0,66,111,116,104,32,45,102,105,108,116,101,114,32,97,110,100,32,45,102,105,108,116,101,114,95,115,99,114,105,112,116,32,115,101,116,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,46,10,0,0,115,58,37,100,120,37,100,32,114,58,37,100,47,37,100,32,114,117,108,101,58,37,100,32,115,116,105,116,99,104,58,37,100,32,115,99,114,111,108,108,58,37,100,32,102,117,108,108,58,37,100,32,115,101,101,100,58,37,117,10,0,0,0,0,82,101,115,99,97,108,101,100,32,118,97,108,117,101,32,102,111,114,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,32,105,115,32,116,111,111,32,98,105,103,46,10,0,33,40,108,102,109,45,62,108,101,102,116,95,117,118,91,84,88,95,49,54,88,49,54,93,38,108,102,109,45,62,108,101,102,116,95,117,118,91,84,88,95,56,88,56,93,41,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,97,105,110,32,119,58,37,100,32,104,58,37,100,32,102,109,116,58,37,115,32,111,118,101,114,108,97,121,32,119,58,37,100,32,104,58,37,100,32,102,109,116,58,37,115,32,101,111,102,95,97,99,116,105,111,110,58,37,115,10,0,0,0,115,101,110,100,32,111,110,101,32,102,114,97,109,101,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,0,114,101,113,117,101,115,116,95,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,0,77,80,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,51,41,0,0,0,0,0,0,0,0,99,111,109,112,108,101,120,0,118,112,57,47,118,112,57,95,99,120,95,105,102,97,99,101,46,99,0,0,0,0,0,0,70,105,108,116,101,114,103,114,97,112,104,32,115,99,114,105,112,116,0,0,0,0,0,0,121,49,0,0,0,0,0,0,67,111,109,112,105,108,105,110,103,32,79,112,101,110,67,76,32,107,101,114,110,101,108,115,46,46,46,10,0,0,0,0,119,0,0,0,0,0,0,0,121,117,118,52,50,48,112,49,54,108,101,0,0,0,0,0,68,101,101,112,83,107,121,66,108,117,101,0,0,0,0,0,60,99,111,108,111,114,62,0,69,118,97,108,0,0,0,0,108,111,119,32,102,114,101,113,117,101,110,99,121,32,50,0,115,114,99,95,104,95,99,104,114,95,112,111,115,0,0,0,115,101,116,32,105,110,112,117,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,102,111,114,99,101,113,117,97,110,116,0,0,0,0,0,0,44,32,13,10,0,0,0,0,32,0,0,0,0,0,0,0,97,100,112,99,109,95,115,119,102,0,0,0,0,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,77,111,100,101,0,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,77,111,100,101,0,0,0,0,115,101,116,32,103,114,101,101,110,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,0,76,111,119,32,68,101,108,97,121,32,83,66,82,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,51,48,78,0,0,0,75,97,114,97,111,107,101,0,56,120,56,32,116,114,97,110,115,102,111,114,109,32,105,110,116,114,97,58,37,46,49,102,37,37,37,115,10,0,0,0,32,86,111,114,98,105,115,32,105,100,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,105,108,108,101,103,97,108,32,98,108,111,99,107,115,105,122,101,41,46,32,10,0,108,120,0,0,0,0,0,0,77,105,120,101,100,32,102,105,101,108,100,47,102,114,97,109,101,32,100,105,114,101,99,116,32,109,111,100,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,109,112,51,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,111,108,111,114,32,99,111,110,118,101,114,115,105,111,110,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,0,70,105,108,116,101,114,103,114,97,112,104,0,0,0,0,0,76,105,110,101,97,114,95,70,111,111,116,95,67,108,97,114,107,101,0,0,0,0,0,0,115,111,102,116,119,97,114,101,0,0,0,0,0,0,0,0,99,50,95,101,120,112,114,0,112,99,109,95,115,50,52,100,97,117,100,0,0,0,0,0,102,105,108,116,101,114,0,0,114,111,116,97,116,101,32,99,111,117,110,116,101,114,45,99,108,111,99,107,119,105,115,101,32,119,105,116,104,32,118,101,114,116,105,99,97,108,32,102,108,105,112,0,0,0,0,0,116,114,117,110,99,97,116,101,100,0,0,0,0,0,0,0,97,117,116,111,109,97,116,105,99,32,116,104,114,101,97,100,32,110,117,109,98,101,114,32,100,101,116,101,99,116,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,44,32,112,97,116,99,104,32,119,101,108,99,111,109,101,10,0,0,0,0,0,0,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,111,110,116,101,120,116,32,115,99,114,97,116,99,104,32,98,117,102,102,101,114,115,46,10,0,0,0,0,0,0,0,115,107,105,112,32,119,105,116,104,32,112,114,101,118,105,110,116,114,97,10,0,0,0,0,77,76,80,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,117,112,32,116,111,32,50,32,115,117,98,115,116,114,101,97,109,115,46,10,0,0,109,97,114,107,101,114,32,112,97,114,115,101,114,32,117,115,101,100,32,37,100,32,98,121,116,101,115,32,40,37,100,32,98,105,116,115,41,10,0,0,66,108,117,114,97,121,32,99,111,109,112,97,116,105,98,105,108,105,116,121,32,119,111,114,107,97,114,111,117,110,100,115,46,0,0,0,0,0,0,0,103,95,112,97,115,115,58,0,32,105,110,116,101,114,108,97,99,101,95,116,121,112,101,58,37,99,32,112,105,99,116,95,116,121,112,101,58,37,99,32,115,99,101,110,101,58,37,102,0,0,0,0,0,0,0,0,104,45,62,109,98,95,121,32,60,32,104,45,62,109,98,95,104,101,105,103,104,116,0,0,109,101,114,103,101,32,102,105,101,108,100,115,0,0,0,0,52,108,101,118,101,108,0,0,83,116,97,110,100,97,114,100,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,108,97,118,102,105,46,114,49,50,56,46,76,82,65,0,0,104,50,54,52,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,0,107,97,0,0,0,0,0,0,115,101,116,32,103,114,105,100,32,115,105,122,101,0,0,0,69,117,114,111,100,97,110,99,101,0,0,0,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,69,114,114,111,114,46,32,89,85,86,52,77,80,69,71,32,115,116,114,101,97,109,32,104,101,97,100,101,114,32,119,114,105,116,101,32,102,97,105,108,101,100,46,10,0,0,0,0,84,105,109,101,108,105,110,101,32,40,39,101,110,97,98,108,101,39,32,111,112,116,105,111,110,41,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,102,105,108,116,101,114,32,39,37,115,39,10,0,0,0,0,0,0,78,47,65,0,0,0,0,0,115,101,116,32,116,104,101,32,102,114,97,109,101,115,32,98,97,116,99,104,32,115,105,122,101,0,0,0,0,0,0,0,37,115,32,39,37,115,39,32,119,97,115,32,100,101,102,105,110,101,100,32,102,111,114,32,37,115,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,32,98,117,116,32,99,111,100,101,99,32,99,111,112,121,32,119,97,115,32,115,101,108,101,99,116,101,100,46,10,70,105,108,116,101,114,105,110,103,32,97,110,100,32,115,116,114,101,97,109,99,111,112,121,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,116,111,103,101,116,104,101,114,46,10,0,0,112,114,111,98,95,103,97,114,102,32,62,61,32,48,0,0,102,105,114,115,116,95,102,105,101,108,100,0,0,0,0,0,102,114,97,103,109,101,110,116,95,105,100,120,32,60,61,32,110,117,109,95,116,111,107,101,110,95,112,97,114,116,105,116,105,111,110,115,0,0,0,0,80,67,83,95,69,68,53,48,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,0,86,111,105,99,101,32,79,118,101,114,0,0,0,0,0,0,109,112,50,0,0,0,0,0,77,97,120,32,99,104,97,110,110,101,108,32,109,97,112,112,105,110,103,32,102,111,114,32,111,117,116,112,117,116,32,37,100,46,37,100,32,114,101,97,99,104,101,100,10,0,0,0,37,115,58,32,37,115,10,0,114,101,115,101,116,95,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,0,0,118,97,100,0,0,0,0,0,97,98,111,118,101,32,98,101,108,111,119,32,104,97,108,102,32,104,101,105,103,104,116,32,108,101,102,116,32,102,105,114,115,116,0,0,0,0,0,0,115,101,116,32,113,117,97,108,105,116,121,0,0,0,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,118,111,108,117,109,101,100,101,116,101,99,116,0,0,0,0,80,67,83,95,69,103,121,112,116,95,49,57,48,55,95,69,120,116,95,80,117,114,112,108,101,0,0,0,0,0,0,0,118,111,0,0,0,0,0,0,108,114,0,0,0,0,0,0,68,80,67,77,32,83,111,108,0,0,0,0,0,0,0,0,117,49,54,98,101,32,100,101,109,117,120,101,114,0,0,0,93,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,115,105,122,101,32,105,110,32,98,121,116,101,115,32,102,111,114,32,101,97,99,104,32,99,104,117,110,107,0,0,0,0,107,101,101,112,32,116,104,101,32,115,97,109,101,32,105,110,112,117,116,32,102,105,101,108,100,0,0,0,0,0,0,0,110,111,32,105,110,100,101,120,32,97,116,32,116,104,101,32,101,110,100,10,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,100,47,37,100,41,32,102,111,117,110,100,32,102,111,114,32,115,116,114,101,97,109,32,35,37,100,44,32,116,105,109,101,32,98,97,115,101,32,102,111,114,99,101,100,32,116,111,32,49,47,52,56,48,48,48,10,0,0,100,111,110,39,116,32,111,102,102,115,101,116,32,100,116,115,47,112,116,115,0,0,0,0,80,67,83,95,69,103,121,112,116,95,49,57,48,55,95,80,117,114,112,108,101,95,66,101,108,116,0,0,0,0,0,0,69,109,101,114,103,101,110,99,121,0,0,0,0,0,0,0,115,111,108,95,100,112,99,109,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,58,32,37,115,46,10,0,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,79,109,105,116,32,116,104,101,32,98,97,115,101,32,100,97,116,97,32,111,102,102,115,101,116,32,105,110,32,116,102,104,100,32,97,116,111,109,115,0,85,110,107,110,111,119,110,32,99,111,118,101,114,32,116,121,112,101,58,32,48,120,37,120,46,10,0,0,0,0,0,0,108,114,0,0,0,0,0,0,85,115,105,110,103,32,37,46,49,54,108,108,120,32,102,111,114,32,97,116,116,97,99,104,109,101,110,116,32,37,100,10,0,0,0,0,0,0,0,0,68,95,87,69,66,86,84,84,47,77,69,84,65,68,65,84,65,0,0,0,0,0,0,0,80,67,83,95,69,103,121,112,116,95,49,57,48,55,95,82,101,100,95,66,101,108,116,0,101,109,0,0,0,0,0,0,68,80,67,77,32,88,97,110,0,0,0,0,0,0,0,0,105,110,95,119,0,0,0,0,68,97,116,97,32,115,116,114,101,97,109,32,101,110,99,111,100,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,121,101,116,32,40,111,110,108,121,32,115,116,114,101,97,109,99,111,112,121,41,10,0,0,0,0,0,0,0,68,117,114,105,110,103,32,114,101,99,111,114,100,105,110,103,0,0,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,115,101,116,32,114,105,103,104,116,32,106,117,110,107,32,115,105,122,101,0,0,0,0,0,100,101,99,111,100,101,95,97,117,100,105,111,32,37,100,46,37,100,0,0,0,0,0,0,115,104,111,119,32,115,116,97,110,100,97,114,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,0,0,0,108,97,118,102,105,46,112,115,110,114,46,109,115,101,46,0,80,67,83,95,68,111,117,97,108,97,95,85,84,77,95,122,111,110,101,95,51,50,78,0,67,111,109,109,101,110,116,97,114,121,0,0,0,0,0,0,100,101,0,0,0,0,0,0,120,97,110,95,100,112,99,109,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,37,115,32,116,121,112,101,32,39,37,115,39,10,0,0,0,80,97,121,108,111,97,100,32,101,120,116,101,110,115,105,111,110,32,37,120,32,37,100,10,0,0,0,0,0,0,0,0,112,114,111,103,114,101,115,115,105,118,101,0,0,0,0,0,40,99,109,45,62,105,110,116,101,114,112,95,102,105,108,116,101,114,32,61,61,32,83,87,73,84,67,72,65,66,76,69,41,32,124,124,32,40,99,109,45,62,105,110,116,101,114,112,95,102,105,108,116,101,114,32,61,61,32,98,101,115,116,95,109,98,109,111,100,101,46,105,110,116,101,114,112,95,102,105,108,116,101,114,41,32,124,124,32,33,105,115,95,105,110,116,101,114,95,98,108,111,99,107,40,38,98,101,115,116,95,109,98,109,111,100,101,41,0,0,121,48,0,0,0,0,0,0,80,67,83,95,67,111,114,114,101,103,111,95,65,108,101,103,114,101,95,85,84,77,95,50,52,83,0,0,0,0,0,0,99,111,0,0,0,0,0,0,100,101,102,97,117,108,116,0,68,80,67,77,32,73,110,116,101,114,112,108,97,121,0,0,85,110,107,110,111,119,110,32,37,115,32,39,37,115,39,10,0,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,115,101,116,32,108,117,109,97,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,118,111,108,117,109,101,0,0,97,98,117,102,102,101,114,115,105,110,107,0,0,0,0,0,80,67,83,95,67,111,114,114,101,103,111,95,65,108,101,103,114,101,95,85,84,77,95,50,51,83,0,0,0,0,0,0,68,105,97,108,111,103,117,101,0,0,0,0,0,0,0,0,105,110,116,101,114,112,108,97,121,95,100,112,99,109,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,97,110,97,103,108,121,112,104,32,121,101,108,108,111,119,32,98,108,117,101,32,104,97,108,102,32,99,111,108,111,114,0,77,97,116,99,104,101,100,32,37,115,32,39,37,115,39,32,102,111,114,32,99,111,100,101,99,32,39,37,115,39,46,10,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,109,98,95,97,99,116,105,118,105,116,121,95,109,97,112,0,100,101,102,97,117,108,116,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,109,97,105,110,0,0,0,0,80,67,83,95,67,97,114,116,104,97,103,101,95,83,117,100,95,84,117,110,105,115,105,101,0,0,0,0,0,0,0,0,104,105,0,0,0,0,0,0,100,105,0,0,0,0,0,0,68,80,67,77,32,105,100,32,82,111,81,0,0,0,0,0,99,116,120,45,62,112,101,110,100,105,110,103,95,102,114,97,109,101,95,99,111,117,110,116,0,0,0,0,0,0,0,0,100,101,99,111,100,101,114,0,100,101,102,105,110,101,32,97,110,32,101,120,99,108,117,115,105,111,110,32,98,97,110,100,32,119,104,105,99,104,32,101,120,99,108,117,100,101,115,32,116,104,101,32,108,105,110,101,115,32,98,101,116,119,101,101,110,32,121,48,32,97,110,100,32,121,49,32,102,114,111,109,32,116,104,101,32,102,105,101,108,100,32,109,97,116,99,104,105,110,103,32,100,101,99,105,115,105,111,110,0,0,0,0,104,32,61,61,32,45,49,32,124,124,32,104,32,62,61,32,118,102,45,62,104,0,0,0,118,97,97,112,105,95,118,108,100,0,0,0,0,0,0,0,68,101,101,112,80,105,110,107,0,0,0,0,0,0,0,0,60,100,117,114,97,116,105,111,110,62,0,0,0,0,0,0,115,105,108,101,110,99,101,100,101,116,101,99,116,0,0,0,80,72,73,0,0,0,0,0,76,70,69,50,0,0,0,0,115,119,115,58,32,105,110,105,116,70,105,108,116,101,114,32,102,97,105,108,101,100,10,0,115,111,117,114,99,101,32,118,101,114,116,105,99,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,0,0,111,117,116,95,115,97,109,112,108,101,95,114,97,116,101,0,102,113,0,0,0,0,0,0,115,45,62,110,98,95,105,110,112,117,116,115,32,38,38,32,115,45,62,110,98,95,105,110,112,117,116,115,32,60,61,32,52,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,100,105,102,102,101,114,101,110,116,32,107,101,121,105,110,116,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,46,42,115,32,118,115,32,37,46,42,115,41,10,0,0,0,0,0,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,52,45,98,105,116,0,0,0,100,104,101,97,100,112,104,111,110,101,95,109,111,100,101,0,100,104,101,97,100,112,104,111,110,101,95,109,111,100,101,0,103,114,101,101,110,0,0,0,65,65,67,32,100,97,116,97,32,114,101,115,105,108,105,101,110,99,101,32,40,102,108,97,103,115,32,37,120,41,0,0,80,67,83,95,67,97,114,116,104,97,103,101,95,78,111,114,100,95,84,117,110,105,115,105,101,0,0,0,0,0,0,0,72,101,97,114,105,110,103,32,73,109,112,97,105,114,101,100,0,0,0,0,0,0,0,0,102,105,101,108,100,32,109,98,115,58,32,105,110,116,114,97,58,32,37,46,49,102,37,37,37,115,10,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,114,97,116,101,10,0,0,0,0,0,48,0,0,0,0,0,0,0,114,111,113,95,100,112,99,109,0,0,0,0,0,0,0,0,109,101,100,105,117,109,0,0,101,110,99,111,100,101,114,0,76,105,110,101,97,114,95,70,111,111,116,95,77,111,100,105,102,105,101,100,95,65,109,101,114,105,99,97,110,0,0,0,32,47,32,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,49,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,103,102,95,97,99,116,105,118,101,95,102,108,97,103,115,0,110,102,0,0,0,0,0,0,101,114,114,111,114,91,63,93,32,118,97,114,105,97,98,108,101,115,32,119,105,108,108,32,98,101,32,115,101,116,32,100,117,114,105,110,103,32,101,110,99,111,100,105,110,103,0,0,99,98,112,121,32,37,100,32,105,110,118,97,108,105,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,109,117,108,116,105,32,116,104,114,101,97,100,101,100,32,101,110,99,111,100,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,40,117,118,32,115,116,114,105,100,101,32,109,105,115,109,97,116,99,104,41,10,0,0,0,0,0,0,0,115,107,105,112,112,101,100,32,77,66,32,105,110,32,73,32,102,114,97,109,101,32,97,116,32,37,100,32,37,100,10,0,66,108,111,99,107,32,115,105,122,101,32,112,111,119,50,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,109,97,120,105,109,117,109,32,40,37,100,41,46,10,0,109,106,112,101,103,58,32,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,105,110,103,32,116,121,112,101,32,40,37,120,41,10,0,0,0,0,98,108,117,114,97,121,45,99,111,109,112,97,116,0,0,0,103,95,101,114,114,111,114,95,114,101,115,105,108,105,101,110,116,58,0,0,0,0,0,0,102,111,114,99,101,32,116,101,114,109,105,110,97,116,105,111,110,32,119,104,101,110,32,116,104,101,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,32,116,101,114,109,105,110,97,116,101,115,0,0,0,0,110,58,37,102,32,112,116,115,58,37,102,32,116,58,37,102,32,107,101,121,58,37,100,0,100,101,99,111,100,101,95,115,108,105,99,101,95,104,101,97,100,101,114,32,101,114,114,111,114,10,0,0,0,0,0,0,50,108,101,118,101,108,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,108,97,118,102,105,46,114,49,50,56,46,73,0,0,0,0,67,114,101,97,116,105,118,101,32,89,85,86,32,40,67,89,85,86,41,0,0,0,0,0,80,67,83,95,67,97,114,116,104,97,103,101,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,0,0,0,0,0,104,105,0,0,0,0,0,0,80,111,112,45,70,111,108,107,0,0,0,0,0,0,0,0,82,101,97,108,65,117,100,105,111,32,50,46,48,32,40,50,56,46,56,75,41,0,0,0,89,85,86,52,77,80,69,71,32,115,116,114,101,97,109,32,99,111,110,116,97,105,110,115,32,109,105,120,101,100,32,105,110,116,101,114,108,97,99,101,100,32,97,110,100,32,110,111,110,45,105,110,116,101,114,108,97,99,101,100,32,102,114,97,109,101,115,46,10,0,0,0,114,101,112,108,97,121,103,97,105,110,0,0,0,0,0,0,115,101,116,32,101,110,97,98,108,101,32,101,120,112,114,101,115,115,105,111,110,0,0,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,101,114,114,111,114,0,99,111,112,121,0,0,0,0,67,111,109,112,117,116,101,32,97,110,100,32,97,112,112,108,121,32,97,32,108,111,111,107,117,112,32,116,97,98,108,101,32,116,111,32,116,104,101,32,82,71,66,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,105,110,116,101,114,110,97,108,32,102,114,97,109,101,32,98,117,102,102,101,114,115,0,0,0,0,0,115,101,116,32,116,104,101,32,109,97,112,0,0,0,0,0,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,55,0,0,0,0,0,86,105,115,117,97,108,108,121,32,73,109,112,97,105,114,101,100,0,0,0,0,0,0,0,114,97,95,50,56,56,0,0,110,111,110,101,0,0,0,0,103,95,116,105,109,101,98,97,115,101,46,100,101,110,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,49,48,48,48,48,48,48,48,48,48,93,0,0,0,0,0,37,115,37,115,47,37,115,46,97,118,112,114,101,115,101,116,0,0,0,0,0,0,0,0,115,101,116,114,108,105,109,105,116,0,0,0,0,0,0,0,119,114,105,116,101,32,97,32,104,101,97,100,101,114,32,116,111,32,116,104,101,32,102,105,114,115,116,32,115,101,103,109,101,110,116,32,97,110,100,32,97,32,116,114,97,105,108,101,114,32,116,111,32,116,104,101,32,108,97,115,116,32,111,110,101,0,0,0,0,0,0,0,115,101,116,32,105,110,116,101,114,108,97,99,105,110,103,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,111,110,0,0,0,0,0,0,98,0,0,0,0,0,0,0,103,95,116,105,109,101,98,97,115,101,46,100,101,110,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,49,48,48,48,48,48,48,48,48,48,93,0,0,0,0,0,109,50,118,0,0,0,0,0,99,104,114,111,109,97,95,115,112,97,116,105,97,108,0,0,99,108,69,110,113,117,101,117,101,82,101,97,100,66,117,102,102,101,114,32,101,114,114,111,114,32,39,37,100,39,10,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,54,0,0,0,0,0,118,105,0,0,0,0,0,0,82,101,97,108,65,117,100,105,111,32,49,46,48,32,40,49,52,46,52,75,41,0,0,0,117,49,54,108,101,32,100,101,109,117,120,101,114,0,0,0,47,46,97,118,99,111,110,118,0,0,0,0,0,0,0,0,99,104,117,110,107,95,115,105,122,101,0,0,0,0,0,0,109,111,100,101,0,0,0,0,105,110,116,101,110,115,105,116,121,0,0,0,0,0,0,0,110,117,116,45,62,110,101,120,116,95,115,116,97,114,116,99,111,100,101,32,61,61,32,40,48,120,69,52,65,68,69,69,67,65,52,53,54,57,85,76,76,32,43,32,40,40,40,117,105,110,116,54,52,95,116,41,40,39,78,39,60,60,56,41,32,43,32,39,75,39,41,60,60,52,56,41,41,0,0,0,85,110,107,110,111,119,110,32,102,114,97,109,101,32,108,97,121,111,117,116,32,116,121,112,101,58,32,37,100,10,0,0,114,97,100,105,117,115,0,0,109,112,101,103,116,115,95,99,111,112,121,116,115,0,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,53,0,0,0,0,0,69,102,102,101,99,116,115,0,114,97,95,49,52,52,0,0,37,115,37,115,47,37,115,45,37,115,46,97,118,112,114,101,115,101,116,0,0,0,0,0,103,40,88,44,89,41,0,0,115,116,101,112,58,37,100,32,102,114,97,109,101,95,114,97,116,101,58,37,100,47,37,100,40,37,102,41,32,45,62,32,102,114,97,109,101,95,114,97,116,101,58,37,100,47,37,100,40,37,102,41,10,0,0,0,66,0,0,0,0,0,0,0,111,109,105,116,95,116,102,104,100,95,111,102,102,115,101,116,0,0,0,0,0,0,0,0,37,115,45,37,115,0,0,0,86,105,101,119,115,32,97,114,101,32,112,97,99,107,101,100,32,110,101,120,116,32,116,111,32,101,97,99,104,32,111,116,104,101,114,0,0,0,0,0,65,116,116,97,99,104,109,101,110,116,32,115,116,114,101,97,109,32,37,100,32,104,97,115,32,110,111,32,109,105,109,101,116,121,112,101,32,116,97,103,32,97,110,100,32,105,116,32,99,97,110,110,111,116,32,98,101,32,100,101,100,117,99,101,100,32,102,114,111,109,32,116,104,101,32,99,111,100,101,99,32,105,100,46,10,0,0,0,73,78,84,82,65,52,88,52,95,67,72,82,79,77,65,0,68,95,87,69,66,86,84,84,47,68,69,83,67,82,73,80,84,73,79,78,83,0,0,0,50,53,0,0,0,0,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,52,0,0,0,0,0,65,32,39,124,39,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,112,105,120,101,108,32,102,111,114,109,97,116,115,0,0,0,112,97,110,0,0,0,0,0,101,102,0,0,0,0,0,0,65,77,82,45,87,66,32,40,65,100,97,112,116,105,118,101,32,77,117,108,116,105,45,82,97,116,101,32,87,105,100,101,66,97,110,100,41,0,0,0,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,115,104,97,114,101,47,102,102,109,112,101,103,0,0,0,0,0,82,101,99,111,114,100,105,110,103,32,76,111,99,97,116,105,111,110,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,106,101,99,116,32,102,114,97,109,101,32,105,110,116,111,32,102,105,108,116,101,114,32,110,101,116,119,111,114,107,58,32,37,115,10,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,51,0,0,0,0,0,108,97,121,111,117,116,115,0,77,97,105,110,32,65,117,100,105,111,32,83,101,114,118,105,99,101,0,0,0,0,0,0,97,109,114,95,119,98,0,0,67,111,109,98,101,100,32,112,105,120,101,108,32,115,104,111,117,108,100,32,110,111,116,32,98,101,32,108,97,114,103,101,114,32,116,104,97,110,32,98,108,111,99,107,120,32,120,32,98,108,111,99,107,121,10,0,99,108,67,114,101,97,116,101,73,109,97,103,101,50,68,0,72,79,77,69,0,0,0,0,116,111,112,0,0,0,0,0,97,117,100,105,111,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,116,105,109,101,99,111,100,101,44,32,115,121,110,116,97,120,58,32,104,104,58,109,109,58,115,115,91,58,59,46,93,102,102,10,0,0,0,0,0,0,99,111,109,109,101,110,116,0,121,117,118,52,52,52,112,0,116,121,112,101,58,37,115,32,115,116,97,114,116,95,116,105,109,101,58,37,102,32,100,117,114,97,116,105,111,110,58,37,102,32,97,108,112,104,97,58,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,48,120,82,82,71,71,66,66,91,65,65,93,32,99,111,108,111,114,32,115,116,114,105,110,103,58,32,39,37,115,39,10,0,0,0,0,0,0,0,0,112,108,97,110,101,115,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,50,0,0,0,0,0,109,97,0,0,0,0,0,0,103,0,0,0,0,0,0,0,65,77,82,45,78,66,32,40,65,100,97,112,116,105,118,101,32,77,117,108,116,105,45,82,97,116,101,32,78,97,114,114,111,119,66,97,110,100,41,0,78,79,95,67,79,76,79,82,0,0,0,0,0,0,0,0,97,118,95,105,109,97,103,101,95,103,101,116,95,108,105,110,101,115,105,122,101,32,102,97,105,108,101,100,10,0,0,0,82,73,80,69,77,68,51,50,48,0,0,0,0,0,0,0,102,114,97,109,101,0,0,0,110,98,95,115,116,101,112,115,0,0,0,0,0,0,0,0,65,86,67,79,78,86,95,68,65,84,65,68,73,82,0,0,115,109,112,116,101,50,52,48,109,0,0,0,0,0,0,0,115,105,110,104,0,0,0,0,115,101,116,32,108,111,119,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,66,85,71,50,0,0,0,0,70,76,0,0,0,0,0,0,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,37,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,97,115,32,111,117,116,112,117,116,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,100,101,115,99,0,0,0,0,98,105,108,105,110,101,97,114,0,0,0,0,0,0,0,0,70,105,108,116,101,114,32,108,101,110,103,116,104,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,115,101,116,32,104,111,114,105,122,111,110,116,97,108,32,111,102,102,115,101,116,0,0,0,33,115,45,62,112,114,101,111,117,116,46,99,111,117,110,116,0,0,0,0,0,0,0,0,65,86,67,45,73,110,116,114,97,32,83,69,73,32,105,115,32,116,111,111,32,108,97,114,103,101,32,40,37,100,41,10,0,0,0,0,0,0,0,0,80,67,83,95,67,95,73,110,99,104,97,117,115,112,101,95,65,114,103,101,110,116,105,110,97,95,49,0,0,0,0,0,97,117,100,105,111,32,115,101,114,118,105,99,101,32,116,121,112,101,0,0,0,0,0,0,105,99,108,0,0,0,0,0,97,109,114,95,110,98,0,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,112,112,58,32,37,115,10,0,66,117,116,116,101,114,119,111,114,116,104,32,102,105,108,116,101,114,32,99,117,114,114,101,110,116,108,121,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,101,118,101,110,32,102,105,108,116,101,114,32,111,114,100,101,114,115,10,0,0,97,121,98,104,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,32,98,117,102,102,101,114,32,102,111,114,32,114,101,97,100,105,110,103,32,112,114,101,115,101,116,46,10,0,0,0,0,0,69,120,112,101,99,116,101,100,32,116,111,32,114,101,97,100,32,37,100,32,80,83,32,98,105,116,115,32,97,99,116,117,97,108,108,121,32,114,101,97,100,32,37,100,46,10,0,0,108,105,98,97,118,99,111,100,101,99,47,115,110,111,119,46,99,0,0,0,0,0,0,0,105,110,99,114,101,97,115,101,0,0,0,0,0,0,0,0,79,112,101,110,67,76,32,115,117,112,112,111,114,116,32,119,97,115,32,110,111,116,32,101,110,97,98,108,101,100,32,105,110,32,116,104,105,115,32,98,117,105,108,100,44,32,99,97,110,110,111,116,32,98,101,32,115,101,108,101,99,116,101,100,10,0,0,0,0,0,0,0,106,111,105,110,0,0,0,0,84,85,80,76,69,84,89,80], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2228384);
/* memory initializer */ allocate([69,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,111,116,105,111,110,95,101,115,116,46,99,0,119,0,0,0,0,0,0,0,37,50,88,32,0,0,0,0,66,108,111,99,107,32,115,116,97,114,116,32,105,110,102,111,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,99,121,99,108,101,58,37,100,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,117,100,105,111,95,102,114,97,109,101,95,113,117,101,117,101,46,99,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,111,100,101,32,116,97,98,108,101,32,105,110,100,101,120,101,115,58,32,37,100,33,10,0,0,0,0,0,0,92,99,38,72,37,88,38,37,49,91,92,125,93,37,110,0,37,46,42,115,0,0,0,0,105,110,118,97,108,105,100,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,115,58,32,109,105,110,61,37,100,32,109,97,120,61,37,100,10,0,0,0,0,0,0,0,69,114,114,111,114,32,58,32,37,100,32,98,105,116,115,32,108,101,102,116,10,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,80,67,83,95,67,97,109,97,99,117,112,97,95,85,84,77,95,51,51,83,0,0,0,0,115,101,116,32,51,68,32,76,85,84,32,102,105,108,101,32,110,97,109,101,0,0,0,0,65,68,80,67,77,32,77,105,99,114,111,115,111,102,116,0,97,117,100,105,111,95,115,101,114,118,105,99,101,95,116,121,112,101,0,0,0,0,0,0,71,46,55,50,54,32,65,68,80,67,77,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,101,97,114,119,97,120,0,0,49,47,37,100,32,102,114,97,109,101,32,100,114,111,112,58,10,0,0,0,0,0,0,0,67,111,109,112,114,101,115,115,101,100,32,100,97,116,97,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,0,0,0,0,0,0,0,0,65,68,80,67,77,32,67,114,101,97,116,105,118,101,32,84,101,99,104,110,111,108,111,103,121,0,0,0,0,0,0,0,50,52,0,0,0,0,0,0,48,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,99,111,110,115,116,97,110,116,32,114,97,116,101,45,102,97,99,116,111,114,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,50,112,97,115,115,46,10,0,0,0,0,0,0,0,108,111,114,111,95,115,117,114,114,111,117,110,100,95,109,105,120,95,108,101,118,101,108,0,69,45,65,67,51,32,100,101,99,111,100,101,114,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,121,48,0,0,0,0,0,0,40,83,73,41,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,97,99,101,110,99,46,99,0,0,0,0,0,118,97,97,112,105,95,105,100,99,116,0,0,0,0,0,0,68,97,114,107,86,105,111,108,101,116,0,0,0,0,0,0,60,115,97,109,112,108,101,95,102,109,116,62,0,0,0,0,65,68,84,83,32,104,101,97,100,101,114,32,100,101,116,101,99,116,101,100,44,32,112,114,111,98,97,98,108,121,32,97,115,32,114,101,115,117,108,116,32,111,102,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,109,105,115,112,97,114,115,105,110,103,10,0,0,0,80,73,0,0,0,0,0,0,99,104,97,114,115,101,116,32,108,105,102,101,116,105,109,101,32,115,101,116,32,116,111,32,37,100,32,102,114,97,109,101,40,115,41,10,0,0,0,0,80,97,99,107,101,116,32,119,105,116,104,32,111,100,100,32,115,105,122,101,44,32,105,103,110,111,114,105,110,103,32,108,97,115,116,32,98,121,116,101,10,0,0,0,0,0,0,0,115,117,114,114,111,117,110,100,32,100,105,114,101,99,116,32,114,105,103,104,116,0,0,0,83,119,83,99,97,108,101,114,58,32,122,101,114,111,32,118,101,99,116,111,114,32,105,110,32,115,99,97,108,105,110,103,10,0,0,0,0,0,0,0,115,114,99,95,118,95,99,104,114,95,112,111,115,0,0,0,115,101,116,32,111,117,116,112,117,116,32,115,97,109,112,108,101,32,114,97,116,101,0,0,115,105,122,101,32,109,105,115,109,97,116,99,104,32,37,100,32,37,100,10,0,0,0,0,116,109,112,110,111,105,115,101,0,0,0,0,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,37,105,0,0,0,0,0,49,46,50,46,53,0,0,0,89,79,80,32,104,97,115,32,105,110,118,97,108,105,100,32,100,105,109,101,110,115,105,111,110,115,10,0,0,0,0,0,91,37,49,53,91,48,45,57,65,45,90,97,45,122,43,32,93,93,37,99,0,0,0,0,37,100,32,0,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,52,0,0,0,73,110,118,97,108,105,100,32,99,104,114,111,109,97,32,98,108,111,99,107,32,111,102,102,115,101,116,10,0,0,0,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,118,99,108,97,115,115,32,37,100,44,32,110,99,111,108,111,114,115,32,37,100,44,32,98,112,112,32,37,100,44,32,98,101,32,37,100,44,32,108,115,105,122,101,32,37,100,44,32,120,111,102,102,115,101,116,32,37,100,10,0,0,0,0,0,78,111,32,109,111,114,101,32,116,104,97,110,32,52,32,115,117,98,116,105,116,108,101,32,99,111,108,111,114,115,32,115,117,112,112,111,114,116,101,100,32,40,37,100,32,102,111,117,110,100,46,41,10,0,0,0,114,0,0,0,0,0,0,0,57,54,48,47,49,50,48,32,77,68,67,84,32,119,105,110,100,111,119,0,0,0,0,0,32,48,120,37,48,50,88,44,0,0,0,0,0,0,0,0,95,104,101,105,103,104,116,0,80,67,83,95,67,97,109,97,99,117,112,97,95,85,84,77,95,51,50,83,0,0,0,0,115,105,122,101,95,115,101,103,109,101,110,116,32,111,118,101,114,114,101,97,100,10,0,0,102,114,97,109,101,0,0,0,32,115,107,105,112,58,37,46,49,102,37,37,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,105,110,100,101,120,32,60,32,101,115,99,0,0,0,0,0,73,73,45,99,98,112,32,105,108,108,101,103,97,108,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,35,37,100,32,118,97,108,117,101,115,58,0,0,0,0,0,97,100,112,99,109,95,103,55,50,54,108,101,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,102,105,108,108,32,98,105,116,115,10,0,0,0,0,102,114,97,109,101,91,37,105,93,32,119,111,117,108,100,32,104,97,118,101,32,116,111,32,115,107,105,112,32,37,105,32,98,105,116,115,10,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,100,97,116,97,32,111,114,32,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,32,116,111,111,32,108,111,119,44,32,99,97,110,110,111,116,32,101,110,99,111,100,101,10,0,111,117,116,112,117,116,95,115,97,109,112,108,101,95,98,105,116,115,0,0,0,0,0,0,73,110,112,117,116,32,112,97,99,107,101,116,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,60,32,37,100,41,10,0,0,76,105,110,101,97,114,95,70,111,111,116,95,85,83,95,83,117,114,118,101,121,0,0,0,112,97,103,101,95,110,117,109,98,101,114,0,0,0,0,0,60,105,62,0,0,0,0,0,99,49,95,101,120,112,114,0,105,110,118,97,108,105,100,32,65,76,80,72,65,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,115,105,122,101,58,32,37,100,10,0,98,105,116,115,60,48,46,57,10,0,0,0,0,0,0,0,69,114,114,111,114,32,99,114,101,97,116,105,110,103,32,102,114,97,109,101,32,100,101,99,111,100,101,32,99,111,110,116,101,120,116,10,0,0,0,0,114,111,117,110,100,0,0,0,112,114,111,98,108,101,109,58,32,102,111,117,110,100,32,98,111,116,104,32,67,66,70,48,32,97,110,100,32,67,66,70,90,32,99,104,117,110,107,115,10,0,0,0,0,0,0,0,111,112,101,110,45,103,111,112,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,72,101,97,100,101,114,32,115,105,122,101,32,108,97,114,103,101,114,32,116,104,97,110,32,100,97,116,97,32,112,114,111,118,105,100,101,100,10,0,0,79,110,50,32,86,80,54,32,40,70,108,97,115,104,32,118,101,114,115,105,111,110,44,32,119,105,116,104,32,97,108,112,104,97,32,99,104,97,110,110,101,108,41,0,0,0,0,0,112,115,110,114,0,0,0,0,99,98,112,99,32,37,100,32,105,110,118,97,108,105,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,110,111,110,32,108,105,110,101,97,114,32,113,117,97,110,116,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,113,109,97,120,32,60,61,32,49,50,32,99,117,114,114,101,110,116,108,121,10,0,0,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,40,115,116,114,105,100,101,32,99,104,97,110,103,101,100,41,10,0,0,0,109,105,100,115,116,114,101,97,109,32,114,101,99,111,110,102,105,103,117,114,97,116,105,111,110,32,119,105,116,104,32,109,117,108,116,105,116,104,114,101,97,100,105,110,103,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,44,32,116,114,121,32,45,116,104,114,101,97,100,115,32,49,10,0,0,0,115,108,105,99,101,32,109,105,115,109,97,116,99,104,10,0,108,105,98,97,118,99,111,100,101,99,47,118,111,114,98,105,115,101,110,99,46,99,0,0,66,108,111,99,107,32,115,105,122,101,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,109,97,120,105,109,117,109,32,40,37,100,41,46,10,0,0,0,0,0,0,81,80,58,32,37,100,10,0,68,97,116,97,32,112,97,99,107,101,116,32,98,101,102,111,114,101,32,118,97,108,105,100,32,104,101,97,100,101,114,115,10,0,0,0,0,0,0,0,85,115,101,32,80,101,114,105,111,100,105,99,32,73,110,116,114,97,32,82,101,102,114,101,115,104,32,105,110,115,116,101,97,100,32,111,102,32,73,68,82,32,102,114,97,109,101,115,46,0,0,0,0,0,0,0,103,95,116,105,109,101,98,97,115,101,58,0,0,0,0,0,118,111,114,98,105,115,0,0,67,117,114,115,111,114,32,104,111,116,32,115,112,111,116,32,105,115,32,110,111,116,32,105,110,32,105,109,97,103,101,58,32,37,105,120,37,105,32,111,102,32,37,105,120,37,105,32,99,117,114,115,111,114,32,115,105,122,101,10,0,0,0,0,117,110,107,110,111,119,110,32,98,108,111,99,107,32,116,121,112,101,58,32,37,100,10,0,108,105,98,97,118,99,111,100,101,99,47,118,99,114,49,46,99,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,72,69,86,67,32,112,114,111,102,105,108,101,58,32,37,100,10,0,0,0,0,0,0,0,108,97,118,102,105,46,115,99,101,110,101,95,115,99,111,114,101,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,78,65,76,32,99,111,100,101,58,32,37,100,32,40,37,100,32,98,105,116,115,41,10,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,32,73,109,97,103,101,0,0,0,0,0,119,0,0,0,0,0,0,0,101,115,116,105,109,97,116,105,111,110,0,0,0,0,0,0,65,47,68,32,67,111,110,118,101,114,116,101,114,32,84,121,112,101,0,0,0,0,0,0,108,97,118,102,105,46,114,49,50,56,46,83,0,0,0,0,69,120,116,101,110,100,101,100,32,77,86,115,32,117,110,97,118,97,105,108,97,98,108,101,32,105,110,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,10,0,0,0,0,0,99,121,117,118,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,118,97,108,117,101,115,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,10,0,0,0,0,0,0,83,83,69,52,46,49,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,80,67,83,95,66,111,103,111,116,97,95,67,111,108,111,109,98,105,97,95,54,69,0,0,115,108,105,99,101,0,0,0,118,50,49,48,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,10,0,0,69,108,101,99,116,114,111,110,105,99,0,0,0,0,0,0,86,50,49,48,32,68,101,99,111,100,101,114,0,0,0,0,65,68,80,67,77,32,73,77,65,32,82,97,100,105,99,97,108,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,58,32,37,100,10,0,0,0,0,89,85,86,52,77,80,69,71,32,104,97,115,32,105,110,118,97,108,105,100,32,104,101,97,100,101,114,46,10,0,0,0,102,114,97,109,101,32,105,110,102,111,114,109,97,116,105,111,110,32,102,108,97,103,115,32,37,88,10,0,0,0,0,0,115,101,116,32,115,111,117,114,99,101,32,99,111,108,111,114,32,109,97,116,114,105,120,0,115,108,105,99,101,0,0,0,32,32,68,117,114,97,116,105,111,110,58,32,0,0,0,0,115,119,115,95,102,108,97,103,115,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,58,32,37,100,46,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,66,97,100,32,98,105,116,114,97,116,101,32,112,101,114,32,99,104,97,110,110,101,108,32,118,97,108,117,101,32,37,100,10,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,112,97,115,115,119,111,114,100,32,102,111,114,32,101,110,99,114,121,112,116,101,100,32,115,116,114,101,97,109,46,32,80,108,101,97,115,101,32,117,115,101,32,116,104,101,32,45,112,97,115,115,119,111,114,100,32,111,112,116,105,111,110,10,0,83,108,105,99,101,32,112,114,111,112,101,114,116,105,101,115,32,99,104,117,110,107,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,83,107,105,112,112,105,110,103,32,117,110,107,110,111,119,110,32,98,108,111,99,107,32,116,121,112,101,32,37,105,10,0,115,101,116,32,116,104,101,32,103,114,101,101,110,32,103,97,105,110,32,102,111,114,32,116,104,101,32,114,101,100,32,99,104,97,110,110,101,108,0,0,73,110,112,117,116,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,115,101,116,32,103,114,101,101,110,32,115,104,97,100,111,119,115,0,0,0,0,0,0,0,80,67,83,95,66,111,103,111,116,97,95,67,111,108,111,109,98,105,97,95,51,69,0,0,115,101,108,101,99,116,32,109,117,108,116,105,116,104,114,101,97,100,105,110,103,32,116,121,112,101,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,114,97,100,0,0,0,85,110,107,110,111,119,110,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,37,115,10,0,0,0,0,73,110,118,97,108,105,100,32,109,97,120,95,97,108,108,111,99,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,119,114,105,116,101,95,104,101,97,100,101,114,95,116,114,97,105,108,101,114,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,115,112,101,101,120,47,37,100,13,10,0,0,71,101,111,103,71,101,111,100,101,116,105,99,68,97,116,117,109,71,101,111,75,101,121,0,84,121,112,101,32,111,102,32,71,101,111,84,73,70,70,32,107,101,121,32,37,100,32,105,115,32,119,114,111,110,103,10,0,0,0,0,0,0,0,0,80,74,83,32,115,117,98,116,105,116,108,101,0,0,0,0,73,110,99,111,114,114,101,99,116,32,112,97,108,101,116,116,101,58,32,37,105,32,99,111,108,111,114,115,32,119,105,116,104,32,111,102,102,115,101,116,32,37,105,10,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,66,32,37,100,32,37,100,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,109,98,101,100,100,101,100,32,109,101,115,115,97,103,101,58,10,37,115,10,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,114,95,116,121,112,101,10,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,108,111,114,109,97,112,32,116,121,112,101,0,0,0,92,78,0,0,0,0,0,0,37,100,13,10,37,48,50,100,58,37,48,50,100,58,37,48,50,100,44,37,48,51,100,32,45,45,62,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,44,37,48,51,100,13,10,0,0,0,0,0,0,0,123,92,99,125,0,0,0,0,79,110,108,121,32,109,111,110,111,32,97,110,100,32,115,116,101,114,101,111,32,115,116,114,101,97,109,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,32,98,121,32,110,111,119,10,0,0,0,0,0,0,114,97,119,32,77,80,69,71,45,50,32,118,105,100,101,111,0,0,0,0,0,0,0,0,115,45,62,108,97,115,116,95,112,105,99,116,117,114,101,91,48,93,45,62,100,97,116,97,91,48,93,0,0,0,0,0,69,114,114,111,114,32,115,45,62,118,101,114,115,105,111,110,32,105,115,32,37,100,10,0,116,104,114,101,97,100,115,0,101,110,99,111,117,110,116,101,114,101,100,32,114,101,112,101,97,116,32,98,108,111,99,107,32,111,112,99,111,100,101,32,40,37,48,50,88,41,32,98,117,116,32,110,111,32,98,108,111,99,107,115,32,114,101,110,100,101,114,101,100,32,121,101,116,10,0,0,0,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,98,105,103,10,0,0,0,0,0,0,54,107,53,0,0,0,0,0,99,111,109,112,97,110,100,0,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,98,108,111,99,107,32,115,105,122,101,58,32,37,100,10,0,0,119,114,111,110,103,32,100,105,109,101,110,115,105,111,110,32,110,117,109,98,101,114,10,0,80,67,83,95,66,111,103,111,116,97,95,67,111,108,111,109,98,105,97,95,66,111,103,111,116,97,0,0,0,0,0,0,117,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,99,104,117,110,107,32,37,120,10,0,0,0,116,104,114,101,97,100,95,116,121,112,101,0,0,0,0,0,73,68,61,83,111,117,114,99,101,0,0,0,0,0,0,0,83,108,105,99,101,32,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,68,84,75,0,0,0,0,0,117,56,32,100,101,109,117,120,101,114,0,0,0,0,0,0,100,113,117,97,110,116,32,110,101,101,100,101,100,10,0,0,115,45,62,117,109,118,112,108,117,115,32,61,61,32,48,0,73,110,118,97,108,105,100,32,115,108,105,99,101,32,99,111,117,110,116,58,32,37,100,46,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,111,112,99,111,100,101,32,37,100,32,105,110,32,114,112,122,97,32,99,104,117,110,107,46,32,83,107,105,112,32,114,101,109,97,105,110,105,110,103,32,37,100,32,98,121,116,101,115,32,111,102,32,99,104,117,110,107,32,100,97,116,97,46,10,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,82,111,81,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,13,10,0,0,0,0,0,0,65,112,112,108,121,105,110,103,32,117,110,115,112,101,99,105,102,105,99,32,45,102,114,97,109,101,115,32,116,111,32,110,111,110,32,118,105,100,101,111,32,115,116,114,101,97,109,115,44,32,109,97,121,98,101,32,121,111,117,32,109,101,97,110,116,32,45,118,102,114,97,109,101,115,32,63,10,0,0,0,73,110,118,97,108,105,100,32,98,117,102,102,101,114,32,115,105,122,101,44,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,32,60,32,101,120,112,101,99,116,101,100,32,102,114,97,109,101,95,115,105,122,101,32,37,100,10,0,0,0,109,105,99,114,111,115,101,99,111,110,100,115,32,102,111,114,32,101,97,99,104,32,99,104,117,110,107,0,0,0,0,0,116,101,120,0,0,0,0,0,116,104,114,101,115,104,111,108,100,32,98,101,108,111,119,32,119,104,105,99,104,32,97,32,112,105,120,101,108,32,118,97,108,117,101,32,105,115,32,99,111,110,115,105,100,101,114,101,100,32,98,108,97,99,107,0,115,104,111,114,116,32,112,97,99,107,101,116,115,32,97,114,101,32,115,104,111,114,116,33,10,0,0,0,0,0,0,0,97,118,114,112,0,0,0,0,65,118,105,100,32,49,58,49,32,49,48,45,98,105,116,32,82,71,66,32,80,97,99,107,101,114,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,111,118,101,114,114,101,97,100,32,105,110,32,113,100,109,50,95,102,102,116,95,100,101,99,111,100,101,95,116,111,110,101,115,40,41,10,0,0,0,0,67,111,100,101,98,111,111,107,32,103,97,105,110,32,115,97,110,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,46,0,0,0,0,0,0,116,111,111,32,102,101,119,32,98,105,116,115,32,112,101,114,32,77,66,44,32,112,108,101,97,115,101,32,115,101,116,32,97,116,32,108,101,97,115,116,32,49,50,56,10,0,0,0,69,79,70,32,98,101,102,111,114,101,32,118,105,100,101,111,32,102,114,97,109,101,115,10,0,0,0,0,0,0,0,0,112,105,99,116,117,114,101,32,104,101,97,100,101,114,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,112,105,99,116,117,114,101,95,98,108,97,99,107,95,114,97,116,105,111,95,116,104,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,112,105,99,116,117,114,101,10,0,112,112,109,0,0,0,0,0,80,80,77,32,40,80,111,114,116,97,98,108,101,32,80,105,120,101,108,77,97,112,41,32,105,109,97,103,101,0,0,0,108,105,98,97,118,99,111,100,101,99,47,112,110,103,101,110,99,46,99,0,0,0,0,0,78,111,32,98,121,116,101,115,32,108,101,102,116,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,115,117,102,102,105,99,105,101,110,116,32,82,76,69,32,100,97,116,97,32,102,111,114,32,115,117,98,116,105,116,108,101,10,0,0,0,0,0,70,105,101,108,100,32,100,111,109,105,110,97,110,99,101,32,37,100,32,115,117,112,112,111,114,116,0,0,0,0,0,0,105,110,118,97,108,105,100,32,80,67,88,32,102,105,108,101,10,0,0,0,0,0,0,0,110,58,37,108,108,100,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,85,115,101,32,76,65,84,77,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,102,111,114,32,65,65,67,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,82,71,66,0,0,0,0,0,117,110,107,110,111,119,110,47,105,110,118,97,108,105,100,32,99,111,100,101,0,0,0,0,80,67,83,95,66,111,103,111,116,97,95,67,111,108,111,109,98,105,97,95,51,87,0,0,110,117,109,98,101,114,32,111,102,32,115,108,105,99,101,115,44,32,117,115,101,100,32,105,110,32,112,97,114,97,108,108,101,108,105,122,101,100,32,101,110,99,111,100,105,110,103,0,97,100,112,99,109,95,100,116,107,0,0,0,0,0,0,0,99,104,97,110,110,101,108,115,112,108,105,116,0,0,0,0,115,101,116,32,115,97,109,112,108,101,32,40,112,105,120,101,108,41,32,97,115,112,101,99,116,32,114,97,116,105,111,0,80,114,101,115,101,116,32,37,115,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,115,116,114,101,97,109,32,37,100,58,37,100,44,32,98,117,116,32,99,111,117,108,100,32,110,111,116,32,98,101,32,111,112,101,110,101,100,46,10,0,100,101,102,97,117,108,116,0,82,117,110,32,97,32,115,101,99,111,110,100,32,112,97,115,115,32,116,111,32,112,117,116,32,116,104,101,32,105,110,100,101,120,32,40,109,111,111,118,32,97,116,111,109,41,32,97,116,32,116,104,101,32,98,101,103,105,110,110,105,110,103,32,111,102,32,116,104,101,32,102,105,108,101,0,0,0,0,0,117,110,100,0,0,0,0,0,84,111,111,32,115,109,97,108,108,32,78,85,86,32,118,105,100,101,111,32,102,114,97,109,101,10,0,0,0,0,0,0,73,110,116,101,114,108,97,99,101,100,32,109,111,100,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,77,120,80,69,71,10,0,98,105,116,109,97,112,32,102,101,97,116,117,114,101,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,32,37,100,10,0,0,73,110,118,97,108,105,100,32,113,117,97,108,105,116,121,32,115,101,116,116,105,110,103,32,37,100,10,0,0,0,0,0,101,110,100,105,0,0,0,0,102,114,97,109,101,45,62,108,105,110,101,115,105,122,101,91,48,93,32,61,61,32,99,116,120,45,62,108,97,115,116,95,112,105,99,45,62,108,105,110,101,115,105,122,101,91,48,93,0,0,0,0,0,0,0,0,109,105,109,101,116,121,112,101,0,0,0,0,0,0,0,0,72,101,97,100,101,114,32,118,101,114,115,105,111,110,32,100,111,101,115,110,39,116,32,109,97,116,99,104,32,99,111,100,101,99,32,116,97,103,10,0,77,83,32,82,76,69,58,32,98,121,116,101,115,116,114,101,97,109,32,111,118,101,114,114,117,110,44,32,37,100,32,114,111,119,115,32,108,101,102,116,10,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,10,0,0,0,0,68,95,87,69,66,86,84,84,47,67,65,80,84,73,79,78,83,0,0,0,0,0,0,0,123,92,117,49,125,0,0,0,83,116,114,105,99,116,108,121,32,101,110,102,111,114,99,101,32,103,111,112,32,115,105,122,101,0,0,0,0,0,0,0,80,67,83,95,66,111,103,111,116,97,95,85,84,77,95,122,111,110,101,95,49,56,78,0,115,108,105,99,101,115,0,0,33,100,115,116,45,62,102,46,98,117,102,91,48,93,0,0,42,112,97,100,100,105,110,103,32,62,61,32,48,0,0,0,65,68,80,67,77,32,73,77,65,32,68,105,97,108,111,103,105,99,32,79,75,73,0,0,42,112,97,100,100,105,110,103,32,62,61,32,48,0,0,0,102,111,114,109,97,116,95,110,97,109,101,0,0,0,0,0,73,110,118,97,108,105,100,32,108,105,110,101,32,102,111,117,110,100,32,105,110,32,116,104,101,32,112,114,101,115,101,116,32,102,105,108,101,46,10,0,76,121,114,105,99,105,115,116,47,116,101,120,116,32,119,114,105,116,101,114,0,0,0,0,109,112,51,102,108,111,97,116,0,0,0,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,111,117,116,112,117,116,115,0,0,0,109,112,51,0,0,0,0,0,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,77,80,69,71,45,52,10,0,0,0,0,0,0,0,0,69,114,114,111,114,44,32,118,105,100,101,111,32,112,97,99,107,101,116,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,40,102,95,99,111,100,101,61,48,41,10,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,52,58,50,58,50,0,0,0,115,97,109,112,108,101,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,77,117,108,116,105,99,104,97,110,110,101,108,32,77,80,67,32,83,86,56,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,102,114,97,109,101,58,32,117,115,101,100,32,37,105,32,111,102,32,37,105,32,98,105,116,115,10,0,0,0,0,0,0,0,115,45,62,101,110,100,32,62,61,32,115,45,62,112,116,114,0,0,0,0,0,0,0,0,101,120,116,114,97,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,69,120,112,114,101,115,115,105,111,110,32,100,101,116,101,114,109,105,110,105,110,103,32,116,104,101,32,102,114,97,109,101,32,116,105,109,101,115,116,97,109,112,0,0,0,0,0,0,84,104,101,114,101,32,109,117,115,116,32,98,101,32,110,111,32,101,120,116,114,97,119,111,114,100,32,102,111,114,32,77,76,80,46,10,0,0,0,0,109,106,112,101,103,0,0,0,99,104,97,110,110,101,108,109,97,112,0,0,0,0,0,0,105,110,100,101,120,61,37,100,10,0,0,0,0,0,0,0,115,101,99,111,110,100,32,102,105,101,108,100,32,111,102,102,115,58,32,48,120,37,120,10,0,0,0,0,0,0,0,0,80,67,83,95,66,111,103,111,116,97,95,85,84,77,95,122,111,110,101,95,49,55,78,0,100,101,99,111,100,105,110,103,32,109,117,115,116,32,115,116,97,114,116,32,119,105,116,104,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,111,102,102,115,101,116,0,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,84,104,105,115,32,118,101,114,115,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,37,100,32,107,72,122,32,45,32,37,100,32,107,98,105,116,47,115,47,99,104,32,109,111,100,101,46,10,0,0,0,0,0,0,78,111,32,111,117,116,112,117,116,32,112,97,100,32,99,97,110,32,98,101,32,97,115,115,111,99,105,97,116,101,100,32,116,111,32,108,105,110,107,32,108,97,98,101,108,32,39,37,115,39,46,10,0,0,0,0,97,100,112,99,109,95,105,109,97,95,111,107,105,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,112,105,120,101,108,32,102,111,114,109,97,116,115,0,0,0,0,98,117,102,102,101,114,32,115,105,122,101,32,37,100,32,105,115,32,111,100,100,10,0,0,73,110,112,117,116,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,46,10,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,32,115,116,114,101,97,109,46,10,0,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,101,110,99,111,100,105,110,103,32,112,114,101,115,101,116,32,40,99,102,46,32,120,50,54,52,32,45,45,102,117,108,108,104,101,108,112,41,0,0,0,116,105,116,108,101,0,0,0,37,115,10,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,100,101,99,111,100,101,114,58,32,37,115,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,116,104,114,101,97,100,49,32,100,101,99,111,100,101,100,32,115,105,122,101,32,100,105,102,102,101,114,115,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,10,0,0,0,0,79,117,116,112,117,116,32,109,111,114,101,32,98,121,116,101,115,32,116,104,97,110,32,108,101,110,103,116,104,32,40,37,100,32,111,102,32,37,100,41,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,77,86,10,0,0,0,0,0,83,97,109,112,108,101,32,105,110,116,101,114,108,101,97,118,101,100,32,105,109,97,103,101,115,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,74,67,0,0,0,0,0,0,97,102,116,101,114,32,116,105,101,114,49,10,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,98,97,110,100,58,32,37,100,44,32,112,108,97,110,101,58,32,37,100,10,0,0,0,0,0,0,0,115,101,116,32,101,120,112,114,101,115,115,105,111,110,32,100,101,116,101,114,109,105,110,105,110,103,32,116,104,101,32,111,117,116,112,117,116,32,116,105,109,101,98,97,115,101,0,0,32,43,0,0,0,0,0,0,109,111,116,105,111,110,32,111,102,102,115,101,116,32,97,98,111,118,101,32,108,105,109,105,116,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,87,114,111,110,103,32,73,110,116,101,108,32,72,50,54,51,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,0,80,67,83,95,66,101,114,110,95,49,56,57,56,95,83,119,105,115,115,95,79,108,100,0,70,105,108,101,32,39,37,115,39,32,97,108,114,101,97,100,121,32,101,120,105,115,116,115,46,32,69,120,105,116,105,110,103,46,10,0,0,0,0,0,108,111,103,95,108,101,118,101,108,95,111,102,102,115,101,116,0,0,0,0,0,0,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,37,100,32,37,100,32,111,117,116,115,105,100,101,32,114,101,102,101,114,101,110,99,101,10,0,0,115,101,116,32,103,97,105,110,0,0,0,0,0,0,0,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,37,100,32,37,100,32,111,117,116,115,105,100,101,32,114,101,102,101,114,101,110,99,101,10,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,65,70,67,0,0,0,0,0,83,107,105,112,67,101,108,108,32,112,114,111,99,101,100,117,114,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,33,10,0,0,0,0,0,0,0,0,102,114,97,109,101,32,116,111,111,32,115,109,97,108,108,33,10,0,0,0,0,0,0,0,100,101,99,111,100,101,95,98,121,116,101,114,117,110,32,101,110,100,101,100,32,98,101,102,111,114,101,32,112,108,97,110,101,32,115,105,122,101,10,0,70,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,0,71,108,111,98,97,108,32,111,112,116,105,111,110,115,32,40,97,102,102,101,99,116,32,119,104,111,108,101,32,112,114,111,103,114,97,109,32,105,110,115,116,101,97,100,32,111,102,32,106,117,115,116,32,111,110,101,32,102,105,108,101,58,0,0,112,114,101,100,105,99,116,105,111,110,32,116,121,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,97,100,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,84,79,80,32,70,105,101,108,100,10,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,102,114,97,109,101,44,32,68,80,66,32,102,117,108,108,46,10,0,0,0,0,0,0,118,112,115,95,114,101,115,101,114,118,101,100,95,102,102,102,102,95,49,54,98,105,116,115,32,105,115,32,110,111,116,32,48,120,102,102,102,102,10,0,99,0,0,0,0,0,0,0,59,32,0,0,0,0,0,0,105,115,116,0,0,0,0,0,99,111,108,95,105,110,116,101,114,108,101,97,118,101,100,95,114,108,0,0,0,0,0,0,77,97,110,100,101,108,98,114,111,116,32,99,97,99,104,101,32,105,115,32,116,111,111,32,115,109,97,108,108,33,10,0,108,111,110,103,95,116,101,114,109,95,112,105,99,95,105,100,120,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,108,111,103,50,95,109,97,120,95,102,114,97,109,101,95,110,117,109,95,109,105,110,117,115,52,32,111,117,116,32,111,102,32,114,97,110,103,101,32,40,48,45,49,50,41,58,32,37,100,10,0,0,0,0,0,0,109,105,115,115,105,110,103,32,112,105,99,116,117,114,101,32,105,110,32,97,99,99,101,115,115,32,117,110,105,116,32,119,105,116,104,32,115,105,122,101,32,37,100,10,0,0,0,0,66,32,115,117,98,95,109,98,95,116,121,112,101,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,32,97,116,32,37,100,32,37,100,10,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,49,100,101,99,46,99,0,0,0,0,77,105,115,115,105,110,103,32,71,83,77,32,109,97,103,105,99,33,10,0,0,0,0,0,80,67,83,95,66,101,108,103,101,95,76,97,109,98,101,114,116,95,53,48,0,0,0,0,105,109,97,103,101,32,105,115,32,111,117,116,115,105,100,101,32,116,104,101,32,115,99,114,101,101,110,32,100,105,109,101,110,115,105,111,110,115,46,10,0,0,0,0,0,0,0,0,99,104,114,111,109,97,95,115,97,109,112,108,101,95,108,111,99,97,116,105,111,110,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,97,99,107,101,116,32,115,105,122,101,32,37,100,32,105,115,32,117,110,107,110,111,119,110,46,10,0,0,0,0,0,97,100,112,99,109,95,97,102,99,0,0,0,0,0,0,0,68,101,99,111,100,105,110,103,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,99,104,97,110,110,101,108,0,0,66,105,116,114,97,116,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,117,115,101,32,54,46,51,107,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,112,97,114,115,105,110,103,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,73,110,118,97,108,105,100,32,99,104,117,110,107,32,115,105,122,101,32,37,100,32,116,121,112,101,32,37,48,50,88,10,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,44,32,110,101,101,100,32,37,105,44,32,104,97,118,101,32,37,105,10,0,0,70,114,97,112,115,58,32,101,114,114,111,114,32,105,110,32,100,97,116,97,32,115,116,114,101,97,109,10,0,0,0,0,97,110,97,103,108,121,112,104,32,121,101,108,108,111,119,32,98,108,117,101,32,103,114,97,121,0,0,0,0,0,0,0,78,111,116,32,111,118,101,114,119,114,105,116,105,110,103,32,45,32,101,120,105,116,105,110,103,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,95,112,116,114,32,61,32,37,100,32,62,32,112,105,120,101,108,95,108,105,109,105,116,32,61,32,37,100,10,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,105,102,114,97,109,101,0,0,37,100,32,99,104,97,110,110,101,108,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,109,97,120,32,37,100,41,10,0,0,0,0,0,100,101,99,114,101,97,115,101,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,10,0,115,97,109,112,108,101,47,102,114,97,109,101,32,110,117,109,98,101,114,32,109,105,115,109,97,116,99,104,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,0,0,0,0,0,0,0,114,101,115,101,114,118,101,100,32,98,108,111,99,107,115,105,122,101,32,99,111,100,101,58,32,48,10,0,0,0,0,0,115,101,108,101,99,116,32,112,101,114,109,105,115,115,105,111,110,115,32,109,111,100,101,0,90,101,114,111,32,115,108,105,99,101,115,32,102,111,117,110,100,46,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,82,67,32,109,105,115,109,97,116,99,104,32,37,88,33,0,0,0,0,0,0,0,0,84,105,108,101,32,115,117,112,112,111,114,116,0,0,0,0,67,108,97,105,109,101,100,32,98,105,116,114,97,116,101,32,97,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,109,105,115,109,97,116,99,104,46,10,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,46,10,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,105,110,116,101,114,32,102,114,97,109,101,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,112,101,114,95,102,114,97,109,101,95,109,101,116,97,100,97,116,97,0,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,105,110,112,117,116,115,0,0,0,0,37,100,32,115,108,105,99,101,115,32,102,111,114,32,37,100,120,37,100,0,0,0,0,0,114,101,112,101,97,116,32,111], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2238624);
/* memory initializer */ allocate([118,101,114,108,97,121,32,111,102,32,116,104,101,32,108,97,115,116,32,111,118,101,114,108,97,121,32,102,114,97,109,101,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,68,86,67,80,82,79,32,72,68,32,101,110,99,111,100,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,10,0,0,0,0,0,0,0,32,48,120,37,48,54,120,0,52,45,98,105,116,32,112,105,120,101,108,32,115,116,114,105,110,103,32,105,110,32,37,100,45,98,105,116,32,114,101,103,105,111,110,33,10,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,98,105,116,109,97,112,32,98,117,102,102,101,114,115,46,10,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,100,97,116,97,32,115,116,97,114,116,32,111,102,102,115,101,116,10,0,0,0,0,0,0,68,80,67,77,32,83,111,108,0,0,0,0,0,0,0,0,99,105,100,32,37,100,10,0,105,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,115,105,122,101,10,0,0,0,83,99,104,114,111,101,100,105,110,103,101,114,32,37,100,46,37,100,46,37,100,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,50,51,78,0,0,0,102,105,108,101,0,0,0,0,68,105,109,101,110,115,105,111,110,115,32,109,117,115,116,32,98,101,32,97,32,105,110,116,101,103,101,114,32,109,117,108,116,105,112,108,121,32,111,102,32,116,104,101,32,99,104,114,111,109,97,32,115,117,98,115,97,109,112,108,105,110,103,10,0,0,0,0,0,0,0,0,99,111,108,111,114,95,114,97,110,103,101,0,0,0,0,0,84,83,87,49,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,100,99,97,101,110,99,46,99,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,67,82,89,79,32,65,80,67,0,0,0,0,0,0,68,111,119,110,109,105,120,105,110,103,32,37,100,32,99,104,97,110,110,101,108,115,0,0,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,10,0,0,0,0,67,111,110,102,108,105,99,116,105,110,103,32,102,108,97,103,115,46,0,0,0,0,0,0,68,101,99,105,109,97,116,105,111,110,32,117,110,115,117,112,112,111,114,116,101,100,33,10,0,0,0,0,0,0,0,0,115,117,98,112,97,99,107,101,116,91,37,105,93,32,115,105,122,101,32,37,105,32,106,115,32,37,105,32,37,105,32,98,108,111,99,107,95,97,108,105,103,110,32,37,105,10,0,0,70,105,108,101,32,39,37,115,39,32,97,108,114,101,97,100,121,32,101,120,105,115,116,115,46,32,79,118,101,114,119,114,105,116,101,32,63,32,91,121,47,78,93,32,0,0,0,0,10,0,0,0,0,0,0,0,115,101,116,32,119,104,101,116,104,101,114,32,111,114,32,110,111,116,32,99,104,114,111,109,97,32,105,115,32,105,110,99,108,117,100,101,100,32,100,117,114,105,110,103,32,116,104,101,32,109,97,116,99,104,32,99,111,109,112,97,114,105,115,111,110,115,0,0,0,0,0,0,79,112,101,110,67,76,32,97,99,99,101,108,101,114,97,116,105,111,110,32,101,110,97,98,108,101,100,32,119,105,116,104,32,37,115,32,37,115,32,37,115,10,0,0,0,0,0,0,118,97,97,112,105,95,109,111,99,111,0,0,0,0,0,0,68,97,114,107,84,117,114,113,117,111,105,115,101,0,0,0,60,112,105,120,95,102,109,116,62,0,0,0,0,0,0,0,69,0,0,0,0,0,0,0,83,68,82,0,0,0,0,0,83,119,83,99,97,108,101,114,58,32,114,101,100,117,99,105,110,103,32,47,32,97,108,105,103,110,105,110,103,32,102,105,108,116,101,114,115,105,122,101,32,37,100,32,45,62,32,37,100,10,0,0,0,0,0,0,115,99,97,108,101,114,32,112,97,114,97,109,32,49,0,0,105,110,95,115,97,109,112,108,101,95,114,97,116,101,0,0,77,80,69,71,45,49,47,50,32,118,105,100,101,111,32,88,118,77,67,32,40,88,45,86,105,100,101,111,32,77,111,116,105,111,110,32,67,111,109,112,101,110,115,97,116,105,111,110,41,0,0,0,0,0,0,0,116,110,0,0,0,0,0,0,70,114,97,109,101,32,99,111,100,105,110,103,32,116,121,112,101,58,32,37,100,10,0,0,73,110,118,97,108,105,100,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,99,105,110,101,112,97,107,101,110,99,46,99,0,84,101,120,116,0,0,0,0,107,101,121,105,110,116,61,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,100,114,97,119,105,110,103,32,116,105,108,101,10,0,0,0,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,50,46,54,45,98,105,116,0,119,101,105,103,104,116,101,100,32,112,114,101,100,105,99,116,105,111,110,32,110,111,116,32,121,101,116,32,115,117,112,112,111,114,116,101,100,10,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,0,0,0,0,70,111,114,109,97,116,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,83,97,109,112,108,101,32,102,111,114,109,97,116,32,119,97,115,32,110,111,116,32,115,101,116,32,111,114,32,119,97,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,115,101,116,32,114,101,100,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,0,0,0,65,117,100,105,111,32,100,97,116,97,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,32,37,100,10,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,50,50,78,0,0,0,115,121,109,98,111,108,115,95,115,105,122,101,32,60,61,32,50,32,124,124,32,33,115,121,109,98,111,108,115,0,0,0,105,67,69,68,114,97,119,32,116,101,120,116,0,0,0,0,99,111,108,111,114,115,112,97,99,101,0,0,0,0,0,0,32,105,110,116,101,114,58,37,46,49,102,37,37,0,0,0,73,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,10,0,0,0,0,0,0,32,86,111,114,98,105,115,32,105,100,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,110,111,32,118,111,114,98,105,115,32,115,105,103,110,97,116,117,114,101,41,46,32,10,0,0,0,0,0,0,0,77,105,120,101,100,32,102,114,97,109,101,47,102,105,101,108,100,32,100,105,114,101,99,116,32,109,111,100,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,113,117,97,110,116,95,105,110,100,101,120,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,97,100,112,99,109,95,105,109,97,95,97,112,99,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,33,112,105,99,116,117,114,101,45,62,101,120,116,101,110,100,101,100,95,100,97,116,97,32,124,124,32,112,105,99,116,117,114,101,45,62,101,120,116,101,110,100,101,100,95,100,97,116,97,32,61,61,32,112,105,99,116,117,114,101,45,62,100,97,116,97,0,0,0,0,0,0,49,58,49,40,0,0,0,0,70,114,97,109,101,32,100,97,116,97,32,100,111,101,115,110,39,116,32,109,97,116,99,104,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,33,10,0,0,0,0,0,0,0,0,69,114,114,111,114,44,32,98,111,116,104,32,45,121,32,97,110,100,32,45,110,32,115,117,112,112,108,105,101,100,46,32,69,120,105,116,105,110,103,46,10,0,0,0,0,0,0,0,76,105,110,101,97,114,95,70,111,111,116,0,0,0,0,0,83,111,117,110,100,32,85,110,105,116,32,105,100,32,33,61,32,48,120,50,56,46,10,0,112,97,103,101,95,110,97,109,101,0,0,0,0,0,0,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,77,68,67,84,10,0,0,0,0,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,115,101,116,32,99,111,108,111,114,32,99,111,109,112,111,110,101,110,116,32,35,48,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,78,111,32,101,120,116,114,97,100,97,116,97,32,112,114,111,118,105,100,101,100,10,0,0,68,105,97,108,111,103,117,101,58,32,0,0,0,0,0,0,113,112,60,61,48,46,48,10,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,85,110,107,110,111,119,110,32,101,115,99,97,112,101,32,99,111,100,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,73,68,32,109,111,100,101,0,0,0,0,0,0,0,0,84,104,101,32,102,105,108,101,32,105,115,32,99,111,114,114,117,112,116,101,100,44,32,112,105,116,99,104,95,108,97,103,32,61,32,48,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,98,45,112,121,114,97,109,105,100,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,32,108,101,110,103,116,104,32,37,100,32,105,110,32,99,104,97,110,110,101,108,32,100,97,116,97,33,10,0,0,0,0,0,0,0,100,111,32,110,111,116,32,100,114,97,119,32,101,100,103,101,115,0,0,0,0,0,0,0,10,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,58,32,37,100,32,120,32,37,100,32,40,37,100,41,10,0,0,0,0,0,0,98,32,102,114,97,109,101,115,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,119,105,116,104,32,108,111,119,32,100,101,108,97,121,10,0,97,108,108,111,99,95,102,114,97,109,101,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,40,104,119,97,99,99,101,108,32,112,114,105,118,97,116,101,32,100,97,116,97,32,97,108,108,111,99,97,116,105,111,110,41,10,0,0,83,111,117,114,99,101,70,105,108,101,110,97,109,101,0,0,109,98,32,105,110,99,114,32,100,97,109,97,103,101,100,10,0,0,0,0,0,0,0,0,83,97,109,112,108,105,110,103,32,114,97,116,101,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,109,97,120,105,109,117,109,32,40,37,100,41,46,10,0,0,0,70,111,117,110,100,32,69,79,73,32,98,101,102,111,114,101,32,97,110,121,32,83,79,70,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,108,101,102,116,95,114,105,103,104,116,0,0,0,0,0,0,100,97,116,101,0,0,0,0,105,110,116,114,97,45,114,101,102,114,101,115,104,0,0,0,103,95,104,58,0,0,0,0,77,97,105,110,32,83,116,105,108,108,32,80,105,99,116,117,114,101,32,112,114,111,102,105,108,101,32,98,105,116,115,116,114,101,97,109,10,0,0,0,115,116,114,105,99,108,121,32,97,112,112,108,121,32,100,101,102,97,117,108,116,32,100,105,115,112,108,97,121,32,119,105,110,100,111,119,32,115,105,122,101,0,0,0,0,0,0,0,37,102,0,0,0,0,0,0,70,117,110,107,0,0,0,0,110,101,120,116,95,97,118,99,32,45,32,98,117,102,95,105,110,100,101,120,32,43,32,99,111,110,115,117,109,101,100,32,61,61,32,110,97,108,115,105,122,101,0,0,0,0,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,109,105,109,101,116,121,112,101,58,32,37,115,46,10,0,112,114,101,100,109,0,0,0,97,114,116,105,115,116,0,0,97,100,95,99,111,110,118,95,116,121,112,101,0,0,0,0,108,97,118,102,105,46,114,49,50,56,46,77,0,0,0,0,100,105,115,97,98,108,101,32,100,101,99,111,100,105,110,103,32,111,102,32,116,104,101,32,88,67,104,32,101,120,116,101,110,115,105,111,110,0,0,0,71,111,116,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,112,105,99,116,117,114,101,32,105,110,32,115,116,114,101,97,109,32,37,100,44,32,105,103,110,111,114,105,110,103,46,10,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,72,117,102,102,89,85,86,0,77,80,69,71,45,52,32,65,79,84,32,37,100,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,68,84,83,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,50,49,78,0,0,0,97,117,100,105,111,32,104,101,97,100,101,114,32,105,110,118,97,108,105,100,10,0,0,0,99,111,108,111,114,95,116,114,99,0,0,0,0,0,0,0,84,101,99,104,110,111,45,73,110,100,117,115,116,114,105,97,108,0,0,0,0,0,0,0,71,46,55,50,50,32,65,68,80,67,77,0,0,0,0,0,52,52,52,80,49,54,0,0,52,50,48,106,112,101,103,0,73,110,118,97,108,105,100,32,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,58,32,37,100,10,0,0,0,0,0,0,85,110,99,111,109,109,111,110,32,118,101,114,115,105,111,110,32,37,100,0,0,0,0,0,65,108,108,111,119,101,100,32,116,104,114,101,97,100,32,116,121,112,101,115,0,0,0,0,32,32,0,0,0,0,0,0,67,97,110,110,111,116,32,100,101,116,101,114,109,105,110,101,32,97,100,100,105,116,105,111,110,97,108,32,112,97,114,97,109,101,116,101,114,115,10,0,110,32,61,61,32,115,105,110,107,95,108,105,110,107,115,95,99,111,117,110,116,0,0,0,87,77,47,77,101,100,105,97,84,104,117,109,98,84,121,112,101,0,0,0,0,0,0,0,83,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,37,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,32,97,110,121,32,115,116,114,101,97,109,115,46,10,0,0,0,0,0,0,0,78,65,82,0,0,0,0,0,37,46,42,115,10,0,0,0,45,45,62,0,0,0,0,0,32,32,102,114,111,110,115,97,121,58,32,37,115,10,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,119,97,118,101,32,103,117,105,100,10,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,37,42,100,58,37,42,100,58,37,42,100,46,37,42,100,37,99,0,0,0,0,0,0,0,100,105,115,99,0,0,0,0,116,111,111,32,98,105,103,32,104,101,97,100,101,114,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,83,112,101,99,105,102,105,101,100,32,112,114,111,98,101,32,115,105,122,101,32,118,97,108,117,101,32,37,117,32,99,97,110,110,111,116,32,98,101,32,60,32,37,117,10,0,0,0,46,46,0,0,0,0,0,0,44,32,37,100,32,115,97,109,112,108,101,115,0,0,0,0,84,84,89,32,100,101,109,117,120,101,114,0,0,0,0,0,72,101,97,100,101,114,32,67,82,67,32,101,114,114,111,114,10,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,101,97,116,117,114,101,115,32,48,120,37,48,50,120,10,0,0,0,0,102,105,108,101,110,97,109,101,58,39,37,115,39,32,102,111,114,109,97,116,58,37,115,10,0,0,0,0,0,0,0,0,99,111,110,116,101,110,116,0,37,48,50,120,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,97,105,108,101,100,32,116,111,32,117,110,99,111,109,112,114,101,115,115,32,111,110,101,32,98,105,116,109,97,112,10,0,0,0,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,50,48,78,0,0,0,91,67,79,76,70,93,0,0,91,37,100,58,37,100,58,37,100,93,0,0,0,0,0,0,99,111,108,111,114,95,112,114,105,109,97,114,105,101,115,0,99,105,114,99,117,108,97,114,32,102,105,108,116,101,114,32,99,104,97,105,110,32,100,101,116,101,99,116,101,100,10,0,32,32,88,49,58,37,48,51,100,32,88,50,58,37,48,51,100,32,89,49,58,37,48,51,100,32,89,50,58,37,48,51,100,0,0,0,0,0,0,0,97,100,112,99,109,95,103,55,50,50,0,0,0,0,0,0,84,111,111,32,108,97,114,103,101,32,84,114,117,101,72,68,32,102,114,97,109,101,32,111,102,32,37,100,32,98,121,116,101,115,0,0,0,0,0,0,68,97,116,97,32,116,121,112,101,32,48,120,37,48,52,120,32,105,110,32,73,69,67,32,54,49,57,51,55,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,99,59,32,117,115,101,32,112,99,109,95,115,51,50,108,101,32,111,114,32,112,99,109,95,115,51,50,98,101,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,10,0,37,115,47,70,114,97,103,109,101,110,116,115,40,37,115,61,37,108,108,117,41,0,0,0,32,61,32,0,0,0,0,0,101,114,114,111,114,32,119,104,101,110,32,114,101,97,100,105,110,103,32,99,111,109,109,101,110,116,10,0,0,0,0,0,84,111,111,32,109,97,110,121,32,102,114,97,109,101,115,58,32,37,105,10,0,0,0,0,102,102,109,112,101,103,95,111,112,116,46,99,0,0,0,0,34,37,115,34,10,0,0,0,119,114,105,116,101,32,104,101,97,100,101,114,47,116,114,97,105,108,101,114,32,116,111,32,101,97,99,104,32,115,101,103,109,101,110,116,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,105,76,66,67,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,109,111,100,101,61,37,100,13,10,0,0,0,0,0,0,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,57,78,0,0,0,116,105,99,107,115,95,112,101,114,95,102,114,97,109,101,0,65,68,80,67,77,32,73,77,65,32,70,117,110,99,111,109,32,73,83,83,0,0,0,0,97,108,97,119,32,100,101,109,117,120,101,114,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,104,117,110,107,95,100,117,114,97,116,105,111,110,0,0,78,111,116,32,97,108,108,32,115,116,114,101,97,109,32,104,101,97,100,101,114,115,32,102,111,117,110,100,46,10,0,0,79,110,101,70,105,101,108,100,32,102,114,97,109,101,32,108,97,121,111,117,116,32,105,115,110,39,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,82,101,101,109,105,116,32,80,65,84,47,80,77,84,32,98,101,102,111,114,101,32,119,114,105,116,105,110,103,32,116,104,101,32,110,101,120,116,32,112,97,99,107,101,116,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,56,78,0,0,0,114,99,95,109,105,110,95,118,98,118,95,117,115,101,0,0,97,100,112,99,109,95,105,109,97,95,105,115,115,0,0,0,112,114,111,103,114,97,109,0,101,113,117,97,108,105,122,101,114,0,0,0,0,0,0,0,102,97,115,116,115,116,97,114,116,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,111,118,101,114,32,97,114,116,46,10,0,0,0,0,0,0,0,65,116,116,97,99,104,109,101,110,116,32,115,116,114,101,97,109,32,37,100,32,104,97,115,32,110,111,32,102,105,108,101,110,97,109,101,32,116,97,103,46,10,0,0,0,0,0,0,37,115,95,37,100,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,55,78,0,0,0,114,99,95,109,97,120,95,118,98,118,95,117,115,101,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,97,120,105,115,32,67,68,82,79,77,32,88,65,0,0,0,0,99,104,97,112,116,101,114,0,67,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,69,114,114,111,114,32,114,101,105,110,105,116,105,97,108,105,122,105,110,103,32,102,105,108,116,101,114,115,33,10,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,54,78,0,0,0,114,101,113,117,101,115,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,97,100,112,99,109,95,101,97,95,109,97,120,105,115,95,120,97,0,0,0,0,0,0,0,112,105,120,95,102,109,116,115,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,37,115,32,105,110,100,101,120,32,37,100,32,119,104,105,108,101,32,112,114,111,99,101,115,115,105,110,103,32,109,101,116,97,100,97,116,97,32,109,97,112,115,46,10,0,0,0,0,73,110,118,97,108,105,100,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,100,97,116,97,32,115,105,122,101,58,32,37,100,32,62,61,32,37,100,46,10,0,0,97,116,101,109,112,111,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,53,78,0,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,0,0,0,0,0,103,97,105,110,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,88,65,83,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,101,116,97,100,97,116,97,32,116,121,112,101,32,37,99,46,10,0,0,0,0,0,0,67,97,110,110,111,116,32,102,105,110,100,32,97,32,109,97,116,99,104,105,110,103,32,115,116,114,101,97,109,32,102,111,114,32,117,110,108,97,98,101,108,101,100,32,105,110,112,117,116,32,112,97,100,32,37,100,32,111,110,32,102,105,108,116,101,114,32,37,115,10,0,0,100,101,102,97,117,108,116,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,52,78,0,0,0,115,101,116,32,100,101,115,105,114,101,100,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,0,0,0,0,97,100,112,99,109,95,101,97,95,120,97,115,0,0,0,0,97,121,98,103,0,0,0,0,73,110,118,97,108,105,100,32,109,101,116,97,100,97,116,97,32,115,112,101,99,105,102,105,101,114,32,37,115,46,10,0,100,105,115,97,98,108,101,0,114,101,112,101,97,116,108,97,115,116,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,116,111,111,32,102,97,114,32,98,97,99,107,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,49,51,78,0,0,0,37,100,32,37,100,32,37,100,0,0,0,0,0,0,0,0,114,101,113,117,101,115,116,95,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,69,65,67,83,0,0,66,105,116,45,100,101,112,116,104,32,56,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,112,114,111,102,105,108,101,32,62,32,49,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,112,116,101,114,32,105,110,100,101,120,32,37,100,32,105,110,32,109,101,116,97,100,97,116,97,32,115,112,101,99,105,102,105,101,114,46,10,0,0,0,0,0,0,0,0,97,115,116,114,101,97,109,115,121,110,99,0,0,0,0,0,109,99,104,114,111,109,97,0,79,112,101,110,67,76,32,97,99,99,101,108,101,114,97,116,105,111,110,32,100,105,115,97,98,108,101,100,44,32,115,119,105,116,99,104,97,98,108,101,32,103,114,97,112,104,105,99,115,32,100,101,116,101,99,116,101,100,10,0,0,0,0,0,98,103,114,53,53,53,108,101,0,0,0,0,0,0,0,0,68,97,114,107,83,108,97,116,101,71,114,97,121,0,0,0,60,118,105,100,101,111,95,114,97,116,101,62,0,0,0,0,85,110,107,110,111,119,110,32,102,117,110,99,116,105,111,110,32,105,110,32,39,37,115,39,10,0,0,0,0,0,0,0,115,117,114,114,111,117,110,100,32,100,105,114,101,99,116,32,108,101,102,116,0,0,0,0,115,119,115,58,32,102,105,108,116,101,114,83,105,122,101,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,44,32,116,114,121,32,108,101,115,115,32,101,120,116,114,101,109,101,32,115,99,97,108,105,110,103,32,111,114,32,105,110,99,114,101,97,115,101,32,77,65,88,95,70,73,76,84,69,82,95,83,73,90,69,32,97,110,100,32,114,101,99,111,109,112,105,108,101,10,0,0,0,0,112,97,114,97,109,49,0,0,115,101,116,32,105,110,112,117,116,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,108,111,119,112,97,115,115,53,0,0,0,0,0,0,0,0,69,110,100,0,0,0,0,0,100,105,102,102,101,114,101,110,116,32,105,110,116,101,114,108,97,99,101,100,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,115,32,118,115,32,37,115,41,10,0,0,0,0,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,51,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,77,111,100,101,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,77,111,100,101,0,0,114,101,100,0,0,0,0,0,83,66,82,43,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,50,51,0,0,0,0,0,0,0,71,79,80,32,116,105,109,101,99,111,100,101,32,102,114,97,109,101,32,115,116,97,114,116,32,110,117,109,98,101,114,44,32,105,110,32,110,111,110,45,100,114,111,112,45,102,114,97,109,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,109,98,32,66,32,32,37,115,10,0,0,0,0,0,0,0,32,69,114,114,111,114,32,103,101,110,101,114,97,116,105,110,103,32,118,108,99,32,116,97,98,108,101,115,46,32,10,0,33,118,45,62,102,105,101,108,100,95,109,111,100,101,0,0,97,100,112,99,109,95,105,109,97,95,101,97,95,101,97,99,115,0,0,0,0,0,0,0,69,114,114,111,114,32,97,112,112,108,121,105,110,103,32,112,97,114,97,109,101,116,101,114,32,99,104,97,110,103,101,115,46,10,0,0,0,0,0,0,78,111,32,39,61,39,32,99,104,97,114,97,99,116,101,114,32,105,110,32,109,101,116,97,100,97,116,97,32,115,116,114,105,110,103,32,37,115,46,10,0,0,0,0,0,0,0,0,76,105,110,101,97,114,95,77,101,116,101,114,0,0,0,0,109,111,100,101,108,0,0,0,99,48,95,101,120,112,114,0,69,114,114,111,114,32,101,118,97,108,117,97,116,105,110,103,32,114,99,95,101,113,32,34,37,115,34,10,0,0,0,0,112,99,109,95,115,50,52,98,101,0,0,0,0,0,0,0,98,45,98,105,97,115,0,0,101,109,117,95,101,100,103,101,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,100,99,32,118,108,99,10,0,108,111,119,32,100,101,108,97,121,32,102,111,114,99,105,110,103,32,105,115,32,111,110,108,121,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,109,112,101,103,50,10,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,32,40,37,100,32,37,112,41,10,0,0,0,0,32,97,116,32,37,100,10,0,101,110,100,32,109,105,115,109,97,116,99,104,32,108,101,102,116,61,37,100,32,37,48,88,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,47,117,110,107,110,111,119,110,32,115,97,109,112,108,105,110,103,32,114,97,116,101,10,0,0,104,117,102,102,109,97,110,32,116,97,98,108,101,32,100,101,99,111,100,101,32,101,114,114,111,114,10,0,0,0,0,0,110,101,101,100,32,100,105,99,116,105,111,110,97,114,121,0,67,97,108,99,117,108,97,116,101,32,97,110,100,32,112,114,105,110,116,32,83,83,73,77,32,115,116,97,116,115,46,0,103,95,119,58,0,0,0,0,77,97,105,110,32,49,48,32,112,114,111,102,105,108,101,32,98,105,116,115,116,114,101,97,109,10,0,0,0,0,0,0,115,116,114,105,99,116,45,100,105,115,112,108,97,121,119,105,110,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,83,80,83,32,100,101,99,111,100,105,110,103,32,102,97,105,108,117,114,101,44,32,116,114,121,105,110,103,32,97,103,97,105,110,32,119,105,116,104,32,116,104,101,32,99,111,109,112,108,101,116,101,32,78,65,76,10,0,0,0,0,0,0,0,83,101,97,114,99,104,32,109,101,116,104,111,100,32,102,111,114,32,115,101,108,101,99,116,105,110,103,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,0,0,0,0,83,101,116,32,116,104,101,32,100,101,99,111,100,105,110,103,32,108,97,121,101,114,0,0,78,111,116,32,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,0,0,0,0,37,46,51,102,0,0,0,0,100,105,115,97,98,108,101,95,120,99,104,0,0,0,0,0,49,46,50,46,53,0,0,0,104,117,102,102,121,117,118,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,50,50,0,0,0,0,0,0,0,116,105,109,101,99,111,100,101,95,102,114,97,109,101,95,115,116,97,114,116,0,0,0,0,68,97,114,107,119,97,118,101,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,83,69,65,68,0,0,52,50,50,80,49,54,0,0,116,104,114,101,97,100,95,116,121,112,101,0,0,0,0,0,102,114,111,109,0,0,0,0,114,101,109,111,118,101,32,97,108,108,32,102,114,97,103,109,101,110,116,115,32,119,104,101,110,32,102,105,110,105,115,104,101,100,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,50,49,0,0,0,0,0,0,0,109,97,120,95,112,114,101,100,105,99,116,105,111,110,95,111,114,100,101,114,0,0,0,0,97,100,112,99,109,95,105,109,97,95,101,97,95,115,101,97,100,0,0,0,0,0,0,0,97,115,116,97,116,115,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,105,110,100,101,120,32,37,100,32,105,110,32,99,104,97,112,116,101,114,32,109,97,112,112,105,110,103,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,108,111,103,108,101,118,101,108,32,34,37,115,34,46,32,80,111,115,115,105,98,108,101,32,108,101,118,101,108,115,32,97,114,101,32,110,117,109,98,101,114,115,32,111,114,58,10,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,39,66,79,68,89,39,32,99,104,117,110,107,32,105,115,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,0,105,110,100,105,118,105,100,117,97,108,95,104,101,97,100,101,114,95,116,114,97,105,108,101,114,0,0,0,0,0,0,0,97,117,100,105,111,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,71,55,50,54,45,37,100,47,37,100,13,10,0,0,0,0,0,0,0,0,109,112,103,44,109,112,101,103,44,109,49,118,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,50,48,0,0,0,0,0,0,0,109,105,110,95,112,114,101,100,105,99,116,105,111,110,95,111,114,100,101,114,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,50,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,54,48,48,120,50,52,48,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,105,110,100,101,120,32,37,100,32,119,104,105,108,101,32,112,114,111,99,101,115,115,105,110,103,32,109,101,116,97,100,97,116,97,32,109,97,112,115,10,0,0,0,0,0,109,105,99,114,111,115,101,99,111,110,100,115,32,98,121,32,119,104,105,99,104,32,97,117,100,105,111,32,112,97,99,107,101,116,115,32,115,104,111,117,108,100,32,98,101,32,105,110,116,101,114,108,101,97,118,101,100,32,101,97,114,108,105,101,114,0,0,0,0,0,0,0,114,101,102,101,114,101,110,99,101,95,115,116,114,101,97,109,0,0,0,0,0,0,0,0,78,111,32,109,97,105,110,32,115,116,97,114,116,99,111,100,101,32,102,111,117,110,100,46,10,0,0,0,0,0,0,0,83,101,103,109,101,110,116,101,100,70,114,97,109,101,32,108,97,121,111,117,116,32,105,115,110,39,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,97,115,104,111,119,105,110,102,111,0,0,0,0,0,0,0,114,101,115,101,110,100,95,104,101,97,100,101,114,115,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,57,0,0,0,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,95,108,101,118,101,108,0,0,0,0,0,0,0,97,100,112,99,109,95,101,97,95,114,50,0,0,0,0,0,112,114,101,108,111,97,100,0,109,61,37,115,32,37,100,32,82,84,80,47,65,86,80,32,37,100,13,10,0,0,0,0,67,114,101,97,116,101,32,97,32,108,105,118,101,32,115,109,111,111,116,104,32,115,116,114,101,97,109,105,110,103,32,102,101,101,100,32,40,102,111,114,32,112,117,115,104,105,110,103,32,116,111,32,97,32,112,117,98,108,105,115,104,105,110,103,32,112,111,105,110,116,41,0,113,117,105,99,107,116,105,109,101,95,118,101,114,115,105,111,110,0,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,83,112,105,110,110,105,110,103,32,110,111,105,115,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,44,32,117,115,105,110,103,32,112,105,110,107,32,110,111,105,115,101,32,105,110,115,116,101,97,100,46,10,0,0,0,0,0,0,49,0,0,0,0,0,0,0,100,97,116,101,0,0,0,0,97,115,101,116,114,97,116,101,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,56,0,0,0,0,0,0,0,97,100,106,117,115,116,32,115,101,110,115,105,116,105,118,105,116,121,32,111,102,32,98,95,102,114,97,109,101,95,115,116,114,97,116,101,103,121,32,49,0,0,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,51,0,0,0,0,0,0,0,0,105,109,97,103,101,50,0,0,66,97,110,100,47,79,114,99,104,101,115,116,114,97,0,0,49,46,50,46,53,0,0,0,79,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,115,117,112,112,111,114,116,101,100,32,105,110,32,116,104,101,32,82,84,80,32,109,117,120,101,114,10,0,0,0,0,0,73,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,102,114,97,109,101,32,99,104,97,110,103,101,100,32,102,114,111,109,32,115,105,122,101,58,37,100,120,37,100,32,102,109,116,58,37,115,32,116,111,32,115,105,122,101,58,37,100,120,37,100,32,102,109,116,58,37,115,10,0,0,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,111,110,32,115,101,101,107,97,98,108,101,32,111,117,116,112,117,116,10,0,0,0,0,0,82,83,68,0,0,0,0,0,97,117,116,104,111,114,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,55,0,0,0,0,0,0,0,98,95,115,101,110,115,105,116,105,118,105,116,121,0,0,0,97,100,112,99,109,95,101,97,95,114,51,0,0,0,0,0,67,111,100,101,99,32,65,86,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,111,117,116,112,117,116,32,102,105,108,101,32,35,37,100,32,40,37,115,41,32,104,97,115,32,110,111,116,32,98,101,101,110,32,117,115,101,100,32,102,111,114,32,97,110,121,32,115,116,114,101,97,109,46,32,84,104,101,32,109,111,115,116,32,108,105,107,101,108,121,32,114,101,97,115,111,110,32,105,115,32,101,105,116,104,101,114,32,119,114,111,110,103,32,116,121,112,101,32,40,101,46,103,46,32,97,32,118,105,100,101,111,32,111,112,116,105,111,110,32,119,105,116,104,32,110,111,32,118,105,100,101,111,32,115,116,114,101,97,109,115,41,32,111,114,32,116,104,97,116,32,105,116,32,105,115,32,97,32,112,114,105,118,97,116,101,32,111,112,116,105,111,110,32,111,102,32,115,111,109,101,32,101,110,99,111,100,101,114,32,119,104,105,99,104,32,119,97,115,32,110,111,116,32,97,99,116,117,97,108,108,121,32,117,115,101,100,32,102,111,114,32,97,110,121,32,115,116,114,101,97,109,46,10,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,102,105,108,116,101,114,115,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,109,105,109,101,116,121,112,101,58,32,37,115,46,10,0,73,110,118,97,108,105,100,32,102,114,97,109,101,114,97,116,101,10,0,0,0,0,0,0,97,115,101,116,110,115,97,109,112,108,101,115,0,0,0,0,111,117,116,32,111,102,32,109,101,109,111,114,121,44,32,117,110,97,98,108,101,32,116,111,32,114,101,97,100,32,73,78,70,79,32,116,97,103,10,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,54,0,0,0,0,0,0,0,109,118,48,95,116,104,114,101,115,104,111,108,100,0,0,0,115,101,116,32,115,104,101,108,102,32,116,114,97,110,115,105,116,105,111,110,32,115,116,101,101,112,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,49,0,0,0,0,0,0,0,0,49,46,50,46,53,0,0,0,67,111,100,101,99,32,65,86,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,111,117,116,112,117,116,32,102,105,108,101,32,35,37,100,32,40,37,115,41,32,105,115,32,110,111,116,32,97,110,32,101,110,99,111,100,105,110,103,32,111,112,116,105,111,110,46,10,0,0,0,73,67,79,80,0,0,0,0,60,119,105,110,100,111,119,0,83,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,39,37,115,39,32,105,110,32,102,105,108,116,101,114,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,37,115,32,109,97,116,99,104,101,115,32,110,111,32,115,116,114,101,97,109,115,46,10,0,0,0,0,0,0,0,0,114,97,119,118,105,100,101,111,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,0,0,0,0,0,0,0,0,99,111,108,111,114,32,98,97,115,101,100,32,111,110,32,112,111,105,110,116,32,99,108,111,115,101,115,116,32,116,111,32,116,104,101,32,111,114,105,103,105,110,32,111,102,32,116,104,101,32,105,116,101,114,97,116,105,111,110,115,0,0,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,53,0,0,0,0,0,0,0,109,117,108,116,105,112,108,105,101,100,32,98,121,32,113,115,99,97,108,101,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,32,97,110,100,32,97,100,100,101,100,32,116,111,32,115,99,101,110,101,95,99,104,97,110,103,101,95,115,99,111,114,101,0,0,0,0,0,97,100,112,99,109,95,101,97,95,114,49,0,0,0,0,0,97,110,97,103,108,121,112,104,32,121,101,108,108,111,119,32,98,108,117,101,32,100,117,98,111,105,115,0,0,0,0,0,65,116,116,97,99,104,109,101,110,116,32,37,115,32,116,111,111,32,108,97,114,103,101,32,116,111,32,102,105,116,32,105,110,116,111,32,109,101,109,111,114,121,46,10,0,0,0,0,102,111,114,99,101,95,111,97,114,0,0,0,0,0,0,0,54,52,48,120,53,49,50,0,67,82,73,32,65,68,88,0,121,117,118,52,52,52,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,52,0,0,0,0,0,0,0,109,105,110,58,32,37,102,32,37,102,32,37,102,32,124,32,109,97,120,58,32,37,102,32,37,102,32,37,102,10,0,0,115,99,95,102,97,99,116,111,114,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,65,77,86,0,0,0,114,97,119,32,100,97,116,97,0,0,0,0,0,0,0,0,72,105,103,104,32,98,105,116,45,100,101,112,116,104,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,112,114,111,102,105,108,101,32,60,32,50,0,0,0,0,0,67,111,117,108,100,32,110,111], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2248864);
/* memory initializer */ allocate([116,32,103,101,116,32,115,105,122,101,32,111,102,32,116,104,101,32,97,116,116,97,99,104,109,101,110,116,32,37,115,46,10,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,97,117,100,105,111,32,112,97,99,107,101,116,10,0,0,0,0,0,97,114,101,115,97,109,112,108,101,0,0,0,0,0,0,0,80,97,100,100,105,110,103,32,115,104,111,117,108,100,32,98,101,32,48,46,10,0,0,0,101,120,112,101,99,116,101,100,32,114,101,115,101,114,118,101,100,32,98,121,116,101,32,116,111,32,98,101,32,48,120,53,53,10,0,0,0,0,0,0,116,111,112,32,102,105,101,108,100,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,77,105,99,114,111,32,68,101,118,105,99,101,115,44,32,73,110,99,46,0,0,0,0,85,110,107,110,111,119,110,32,115,101,99,116,111,114,32,116,121,112,101,32,37,48,50,88,10,0,0,0,0,0,0,0,98,103,114,53,53,53,98,101,0,0,0,0,0,0,0,0,68,97,114,107,83,108,97,116,101,66,108,117,101,0,0,0,60,105,109,97,103,101,95,115,105,122,101,62,0,0,0,0,98,101,116,119,101,101,110,0,85,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,83,68,76,0,0,0,0,0,109,105,110,70,105,108,116,101,114,83,105,122,101,32,62,32,48,0,0,0,0,0,0,0,115,99,97,108,101,114,32,112,97,114,97,109,32,48,0,0,117,115,101,100,95,99,104,97,110,110,101,108,95,99,111,117,110,116,0,0,0,0,0,0,108,53,0,0,0,0,0,0,37,108,108,100,44,37,108,108,100,0,0,0,0,0,0,0,83,116,97,114,116,0,0,0,105,110,116,101,114,108,97,99,101,100,61,37,52,115,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,50,45,98,105,116,0,0,0,100,115,117,114,101,120,95,109,111,100,101,0,0,0,0,0,100,115,117,114,101,120,95,109,111,100,101,0,0,0,0,0,109,0,0,0,0,0,0,0,65,117,100,105,111,32,111,98,106,101,99,116,32,116,121,112,101,32,37,115,37,100,0,0,80,67,83,95,66,101,105,106,105,110,103,95,71,97,117,115,115,95,122,111,110,101,95,49,51,0,0,0,0,0,0,0,114,97,116,101,45,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,97,108,32,113,117,97,110,116,105,122,97,116,105,111,110,0,0,0,0,32,32,76,48,58,37,52,46,49,102,37,37,32,76,49,58,37,52,46,49,102,37,37,32,66,73,58,37,52,46,49,102,37,37,0,0,0,0,0,0,32,73,110,118,97,108,105,100,32,99,111,100,101,32,108,101,110,103,116,104,115,32,119,104,105,108,101,32,103,101,110,101,114,97,116,105,110,103,32,118,108,99,115,46,32,10,0,0,82,101,102,101,114,101,110,99,101,100,32,102,114,97,109,101,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,97,109,118,0,0,0,73,110,118,97,108,105,100,32,109,101,100,105,97,32,116,121,112,101,32,102,111,114,32,118,105,100,101,111,10,0,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,97,116,116,97,99,104,109,101,110,116,32,102,105,108,101,32,37,115,46,10,0,0,0,0,0,82,97,115,116,101,114,80,105,120,101,108,73,115,80,111,105,110,116,0,0,0,0,0,0,109,97,107,101,0,0,0,0,120,111,114,0,0,0,0,0,113,109,105,110,32,60,61,32,113,109,97,120,0,0,0,0,98,45,97,100,97,112,116,0,111,110,108,121,32,100,101,99,111,100,101,47,101,110,99,111,100,101,32,103,114,97,121,115,99,97,108,101,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,55,0,0,0,99,108,111,115,101,100,32,103,111,112,32,119,105,116,104,32,115,99,101,110,101,32,99,104,97,110,103,101,32,100,101,116,101,99,116,105,111,110,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,121,101,116,44,32,115,101,116,32,116,104,114,101,115,104,111,108,100,32,116,111,32,49,48,48,48,48,48,48,48,48,48,10,0,0,0,0,0,0,73,110,116,101,114,108,97,99,101,100,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,32,105,115,32,110,111,116,32,102,117,108,108,121,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,83,121,115,116,101,109,32,115,116,97,114,116,0,0,0,0,73,110,118,97,108,105,100,32,77,88,70,32,100,97,116,97,32,102,111,117,110,100,32,105,110,32,118,105,100,101,111,32,115,116,114,101,97,109,10,0,67,104,97,110,110,101,108,32,103,114,111,117,112,115,32,119,105,116,104,32,100,105,102,102,101,114,105,110,103,32,115,97,109,112,108,101,32,114,97,116,101,115,32,97,114,101,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,114,101,115,116,97,114,116,32,109,97,114,107,101,114,58,32,37,100,10,0,0,0,0,0,115,115,105,109,0,0,0,0,103,95,112,114,111,102,105,108,101,58,0,0,0,0,0,0,102,51,50,98,101,0,0,0,77,97,105,110,32,112,114,111,102,105,108,101,32,98,105,116,115,116,114,101,97,109,10,0,65,112,112,108,121,32,100,101,102,97,117,108,116,32,100,105,115,112,108,97,121,32,119,105,110,100,111,119,32,102,114,111,109,32,86,85,73,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,111,117,116,112,117,116,115,0,0,0,0,0,0,0,80,97,114,116,105,116,105,111,110,101,100,32,72,46,50,54,52,32,115,117,112,112,111,114,116,32,105,115,32,105,110,99,111,109,112,108,101,116,101,10,0,0,0,0,0,0,0,0,112,114,101,100,105,99,116,105,111,110,95,111,114,100,101,114,95,109,101,116,104,111,100,0,108,97,121,101,114,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,69,110,99,111,100,101,100,0,77,58,37,54,46,49,102,32,83,58,37,54,46,49,102,32,32,32,32,32,73,58,37,54,46,49,102,32,76,85,70,83,32,32,32,32,32,76,82,65,58,37,54,46,49,102,32,76,85,32,32,32,32,32,0,0,68,67,65,32,100,101,99,111,100,101,114,0,0,0,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,80,67,83,95,66,97,116,97,118,105,97,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,0,0,0,0,0,0,116,114,101,108,108,105,115,0,71,111,116,104,105,99,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,84,72,80,0,0,0,0,0,52,50,48,80,49,54,0,0,65,86,70,105,108,116,101,114,0,0,0,0,0,0,0,0,116,111,0,0,0,0,0,0,114,101,109,111,118,101,95,97,116,95,101,120,105,116,0,0,67,97,110,110,111,116,32,109,97,112,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,45,32,117,110,115,117,112,112,111,114,116,101,100,32,116,121,112,101,46,10,0,0,0,102,51,50,98,101,0,0,0,80,67,83,95,66,97,116,97,118,105,97,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,0,0,0,0,0,0,99,104,114,111,109,97,32,81,80,32,111,102,102,115,101,116,32,102,114,111,109,32,108,117,109,97,0,0,0,0,0,0,97,100,112,99,109,95,116,104,112,0,0,0,0,0,0,0,79,117,116,112,117,116,32,119,105,116,104,32,108,97,98,101,108,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,32,105,110,32,97,110,121,32,100,101,102,105,110,101,100,32,102,105,108,116,101,114,32,103,114,97,112,104,44,32,111,114,32,119,97,115,32,97,108,114,101,97,100,121,32,117,115,101,100,32,101,108,115,101,119,104,101,114,101,46,10,0,0,0,0,0,0,114,101,112,101,97,116,0,0,115,101,116,32,116,104,101,32,115,101,113,117,101,110,99,101,32,110,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,115,101,103,109,101,110,116,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,71,55,50,50,47,37,100,47,37,100,13,10,0,0,0,0,0,0,0,0,97,112,104,97,115,101,114,0,118,105,100,101,111,47,120,45,109,112,101,103,0,0,0,0,112,114,111,98,101,115,105,122,101,0,0,0,0,0,0,0,80,67,83,95,66,97,116,97,118,105,97,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,0,0,0,0,0,0,101,97,51,0,0,0,0,0,99,104,114,111,109,97,111,102,102,115,101,116,0,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,50,45,98,105,116,0,0,0,77,105,115,115,105,110,103,32,37,115,32,115,116,114,101,97,109,32,119,104,105,99,104,32,105,115,32,114,101,113,117,105,114,101,100,32,98,121,32,116,104,105,115,32,102,102,109,10,0,0,0,0,0,0,0,0,97,117,100,105,111,95,112,114,101,108,111,97,100,0,0,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,116,104,101,32,69,65,51,32,104,101,97,100,101,114,32,33,10,0,117,110,107,110,111,119,110,32,100,105,115,112,111,115,105,116,105,111,110,32,116,121,112,101,32,39,37,115,39,10,0,0,37,116,105,32,98,121,116,101,115,32,111,102,32,99,111,109,109,101,110,116,32,104,101,97,100,101,114,32,114,101,109,97,105,110,10,0,0,0,0,0,10,0,0,0,0,0,0,0,83,101,114,105,97,108,32,110,117,109,98,101,114,32,105,110,32,102,105,115,98,111,110,101,32,100,111,101,115,110,39,116,32,109,97,116,99,104,32,97,110,121,32,115,116,114,101,97,109,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,109,105,110,103,32,118,97,108,117,101,115,46,10,0,77,80,69,71,45,84,83,32,109,117,120,105,110,103,32,102,108,97,103,115,0,0,0,0,80,67,83,95,66,97,116,97,118,105,97,95,78,69,73,69,90,0,0,0,0,0,0,0,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,32,116,111,32,99,111,110,115,105,100,101,114,32,102,111,114,32,109,111,116,105,111,110,32,99,111,109,112,101,110,115,97,116,105,111,110,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,50,0,0,0,110,117,108,108,0,0,0,0,105,115,109,108,0,0,0,0,115,112,101,101,120,0,0,0,97,112,97,100,0,0,0,0,112,114,101,109,105,101,114,101,95,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,110,111,110,45,0,0,0,0,77,121,116,104,84,86,86,105,100,101,111,0,0,0,0,0,97,108,112,104,97,95,109,111,100,101,0,0,0,0,0,0,109,0,0,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,51,53,0,0,0,0,0,0,0,97,110,117,108,108,0,0,0,114,101,102,115,0,0,0,0,120,119,100,0,0,0,0,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,50,46,54,45,98,105,116,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,110,117,108,108,0,0,0,67,111,110,100,117,99,116,111,114,0,0,0,0,0,0,0,100,101,99,111,100,101,114,32,45,62,32,105,115,116,95,105,110,100,101,120,58,37,100,32,116,121,112,101,58,118,105,100,101,111,32,102,114,97,109,101,95,112,116,115,58,37,115,32,102,114,97,109,101,95,112,116,115,95,116,105,109,101,58,37,115,32,98,101,115,116,95,101,102,102,111,114,116,95,116,115,58,37,108,108,100,32,98,101,115,116,95,101,102,102,111,114,116,95,116,115,95,116,105,109,101,58,37,115,32,107,101,121,102,114,97,109,101,58,37,100,32,102,114,97,109,101,95,116,121,112,101,58,37,100,32,116,105,109,101,95,98,97,115,101,58,37,100,47,37,100,10,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,51,51,0,0,0,0,0,0,0,115,112,0,0,0,0,0,0,109,105,110,105,109,117,109,32,105,110,116,101,114,118,97,108,32,98,101,116,119,101,101,110,32,73,68,82,45,102,114,97,109,101,115,0,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,51,0,0,0,110,101,119,112,32,62,61,32,49,0,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,61,110,111,119,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,116,121,112,101,58,32,37,100,46,10,0,0,0,0,0,101,110,100,95,104,101,97,100,0,0,0,0,0,0,0,0,102,105,108,116,101,114,115,0,120,45,62,109,118,95,98,101,115,116,95,114,101,102,95,105,110,100,101,120,91,114,101,102,93,32,60,61,32,50,0,0,77,88,70,32,40,77,97,116,101,114,105,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,32,68,45,49,48,32,77,97,112,112,105,110,103,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,51,49,0,0,0,0,0,0,0,107,101,121,105,110,116,95,109,105,110,0,0,0,0,0,0,117,115,101,32,99,111,110,115,116,97,110,116,32,115,107,105,114,116,32,103,97,105,110,0,65,68,80,67,77,32,83,111,117,110,100,32,66,108,97,115,116,101,114,32,80,114,111,32,52,45,98,105,116,0,0,0,104,116,116,112,58,0,0,0,73,110,118,97,108,105,100,32,102,105,108,101,32,105,110,100,101,120,32,37,100,32,105,110,32,102,105,108,116,101,114,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,37,115,46,10,0,0,0,73,110,100,101,120,83,73,68,32,37,105,32,115,101,103,109,101,110,116,32,97,116,32,37,108,108,100,32,109,105,115,115,105,110,103,32,69,100,105,116,85,110,105,116,66,121,116,101,67,111,117,110,116,32,97,110,100,32,73,110,100,101,120,69,110,116,114,121,65,114,114,97,121,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,121,110,99,32,99,111,100,101,0,109,105,110,99,111,108,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,57,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,100,111,119,110,115,99,97,108,101,32,102,114,97,109,101,115,32,102,111,114,32,100,121,110,97,109,105,99,32,66,45,102,114,97,109,101,32,100,101,99,105,115,105,111,110,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,52,0,0,0,97,121,98,100,0,0,0,0,116,105,116,108,101,0,0,0,97,109,105,120,0,0,0,0,102,102,109,0,0,0,0,0,100,101,99,114,101,97,115,101,32,111,114,32,105,110,99,114,101,97,115,101,32,119,47,104,32,105,102,32,110,101,99,101,115,115,97,114,121,32,116,111,32,107,101,101,112,32,116,104,101,32,111,114,105,103,105,110,97,108,32,65,82,0,0,0,112,107,116,45,62,115,105,122,101,32,61,61,32,40,40,45,49,45,48,120,55,102,102,102,102,102,102,102,41,32,47,32,51,32,42,32,50,32,43,32,40,105,110,116,41,115,105,122,101,111,102,40,65,86,70,114,97,109,101,41,41,0,0,0,77,84,86,32,102,105,108,101,115,32,119,105,116,104,111,117,116,32,97,117,100,105,111,0,121,117,118,52,50,50,0,0,70,79,82,77,65,84,61,37,100,0,0,0,0,0,0,0,91,37,108,108,100,93,91,93,37,99,37,110,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,55,0,0,0,0,0,0,0,77,65,88,32,0,0,0,0,98,114,100,95,115,99,97,108,101,0,0,0,0,0,0,0,67,111,110,116,101,110,116,45,116,121,112,101,58,32,105,109,97,103,101,47,106,112,101,103,13,10,0,0,0,0,0,0,65,68,80,67,77,32,89,97,109,97,104,97,0,0,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,32,114,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,116,119,111,32,112,97,99,107,101,116,115,46,0,0,0,0,0,0,45,116,111,32,118,97,108,117,101,32,115,109,97,108,108,101,114,32,116,104,97,110,32,45,115,115,59,32,105,103,110,111,114,105,110,103,32,45,116,111,46,10,0,0,0,0,0,0,116,111,112,0,0,0,0,0,79,112,101,110,67,76,58,32,85,110,97,98,108,101,32,116,111,32,109,97,112,32,112,97,103,101,45,108,111,99,107,101,100,32,98,117,102,102,101,114,44,32,101,114,114,111,114,32,39,37,100,39,10,0,0,0,98,103,114,53,54,53,108,101,0,0,0,0,0,0,0,0,68,97,114,107,83,101,97,71,114,101,101,110,0,0,0,0,100,116,115,32,60,32,112,99,114,44,32,84,83,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,60,98,105,110,97,114,121,62,0,0,0,0,0,0,0,0,115,116,101,114,101,111,0,0,98,105,116,111,114,0,0,0,119,105,100,101,32,114,105,103,104,116,0,0,0,0,0,0,102,105,108,116,101,114,50,83,105,122,101,32,62,32,48,0,112,97,114,97,109,48,0,0,115,101,116,32,117,115,101,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,0,0,102,102,109,112,101,103,100,101,105,110,116,0,0,0,0,0,76,97,121,101,114,0,0,0,48,0,0,0,0,0,0,0,97,100,112,99,109,95,115,98,112,114,111,95,50,0,0,0,76,111,47,82,111,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,76,111,47,82,111,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,115,101,116,32,109,97,115,116,101,114,32,112,111,105,110,116,115,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,105,110,118,97,108,105,100,32,108,111,119,32,100,101,108,97,121,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,105,110,100,101,120,32,37,100,10,0,0,0,0,0,0,0,110,117,109,32,99,104,97,110,110,101,108,115,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,53,0,0,0,0,0,0,0,114,101,102,105,110,101,32,116,104,101,32,116,119,111,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,117,115,101,100,32,105,110,32,98,105,100,105,114,101,99,116,105,111,110,97,108,32,109,97,99,114,111,98,108,111,99,107,115,0,32,32,66,49,54,46,46,56,58,32,37,52,46,49,102,37,37,32,37,52,46,49,102,37,37,32,37,52,46,49,102,37,37,32,32,100,105,114,101,99,116,58,37,52,46,49,102,37,37,32,32,115,107,105,112,58,37,52,46,49,102,37,37,0,67,111,100,101,98,111,111,107,32,108,111,111,107,117,112,32,116,121,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,10,0,0,0,73,108,108,101,103,97,108,32,68,67,32,86,76,67,10,0,109,112,101,103,116,115,114,97,119,0,0,0,0,0,0,0,97,100,112,99,109,95,121,97,109,97,104,97,0,0,0,0,115,116,97,114,116,95,100,105,115,112,108,97,121,95,116,105,109,101,32,109,117,115,116,32,98,101,32,48,46,10,0,0,45,116,32,97,110,100,32,45,116,111,32,99,97,110,110,111,116,32,98,101,32,117,115,101,100,32,116,111,103,101,116,104,101,114,59,32,117,115,105,110,103,32,45,116,46,10,0,0,82,97,115,116,101,114,80,105,120,101,108,73,115,65,114,101,97,0,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,118,105,118,105,100,108,105,103,104,116,0,0,0,0,0,0,108,105,109,105,116,105,110,103,32,81,80,32,37,102,32,45,62,32,37,102,10,0,0,0,98,102,114,97,109,101,115,0,103,114,97,121,0,0,0,0,119,109,118,49,0,0,0,0,81,80,32,82,68,32,110,101,101,100,115,32,109,98,100,61,50,10,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,112,105,99,116,117,114,101,32,98,117,102,102,101,114,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,0,114,101,115,101,114,118,101,100,0,0,0,0,0,0,0,0,52,50,48,0,0,0,0,0,118,99,100,0,0,0,0,0,67,104,97,110,110,101,108,32,103,114,111,117,112,32,50,32,99,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,32,116,104,97,110,32,103,114,111,117,112,32,49,46,10,0,115,116,97,114,116,99,111,100,101,58,32,37,88,10,0,0,115,109,97,114,116,0,0,0,103,95,116,104,114,101,97,100,115,58,0,0,0,0,0,0,73,110,118,97,108,105,100,32,100,101,108,116,97,32,105,110,32,115,99,97,108,105,110,103,32,108,105,115,116,32,100,97,116,97,58,32,37,100,46,10,0,0,0,0,0,0,0,0,97,112,112,108,121,95,100,101,102,100,105,115,112,119,105,110,0,0,0,0,0,0,0,0,111,117,116,112,117,116,115,0,68,101,99,111,100,105,110,103,32,105,110,32,99,104,117,110,107,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,112,97,114,116,105,116,105,111,110,101,100,32,115,108,105,99,101,115,46,10,0,0,0,0,109,97,120,95,112,97,114,116,105,116,105,111,110,95,111,114,100,101,114,0,0,0,0,0,69,88,82,0,0,0,0,0,68,111,108,98,121,32,72,101,97,100,112,104,111,110,101,32,77,111,100,101,0,0,0,0,100,101,102,97,117,108,116,0,68,84,83,45,72,68,32,77,65,0,0,0,0,0,0,0,100,118,118,105,100,101,111,0,105,100,120,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,51,0,0,0,0,0,0,0,97,109,101,114,103,101,0,0,98,105,100,105,114,95,114,101,102,105,110,101,0,0,0,0,69,116,104,110,105,99,0,0,65,68,80,67,77,32,83,104,111,99,107,119,97,118,101,32,70,108,97,115,104,0,0,0,52,52,52,80,49,52,0,0,66,97,100,32,115,101,101,107,32,116,97,98,108,101,32,115,105,122,101,10,0,0,0,0,48,48,48,53,50,50,48,48,0,0,0,0,0,0,0,0,79,112,116,105,111,110,32,39,37,115,39,32,110,111,116,32,102,111,117,110,100,10,0,0,73,110,112,117,116,0,0,0,84,111,111,32,109,97,110,121,32,102,114,97,109,101,115,44,32,115,101,101,107,105,110,103,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,10,0,0,0,0,0,0,0,109,105,110,105,109,117,109,32,102,114,97,103,109,101,110,116,32,100,117,114,97,116,105,111,110,32,40,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,41,0,0,0,0,0,69,114,114,111,114,32,99,111,110,102,105,103,117,114,105,110,103,32,102,105,108,116,101,114,115,46,10,0,0,0,0,0,113,95,99,117,114,32,33,61,32,78,85,76,76,0,0,0,109,112,51,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,50,49,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,97,108,108,32,102,114,97,109,101,115,0,0,0,0,0,0,97,100,112,99,109,95,115,119,102,0,0,0,0,0,0,0,83,116,114,101,97,109,32,109,97,112,32,39,37,115,39,32,109,97,116,99,104,101,115,32,110,111,32,115,116,114,101,97,109,115,46,10,0,0,0,0,118,101,114,98,111,115,101,0,115,101,103,109,101,110,116,95,115,116,97,114,116,95,110,117,109,98,101,114,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,74,80,69,71,47,57,48,48,48,48,13,10,0,0,0,0,0,0,0,0,114,97,119,32,77,80,69,71,45,49,32,118,105,100,101,111,0,0,0,0,0,0,0,0,105,110,100,101,120,32,60,32,99,116,120,45,62,109,97,120,95,115,122,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,49,57,0,0,0,0,0,0,0,97,102,111,114,109,97,116,0,97,108,108,0,0,0,0,0,65,68,80,67,77,32,67,114,101,97,116,105,118,101,32,84,101,99,104,110,111,108,111,103,121,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,105,110,100,101,120,58,32,37,100,46,10,0,0,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,117,115,101,100,32,116,111,32,112,114,111,98,101,32,102,112,115,0,0,0,0,0,0,105,110,102,111,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,46,0,0,0,0,0,0,0,109,112,101,103,116,115,95,102,108,97,103,115,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,49,55,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,97,108,108,32,102,114,97,109,101,115,32,101,120,99,101,112,116,32,107,101,121,102,114,97,109,101,115,0,0,0,0,0,97,100,112,99,109,95,99,116,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,117,116,112,117,116,32,108,105,110,107,32,108,97,98,101,108,58,32,37,115,46,10,0,70,108,117,115,104,32,102,114,97,103,109,101,110,116,115,32,111,110,32,99,97,108,108,101,114,32,114,101,113,117,101,115,116,115,0,0,0,0,0,0,103,97,112,108,101,115,115,95,112,108,97,121,98,97,99,107,0,0,0,0,0,0,0,0,112,116,115,32,104,97,115,32,110,111,32,118,97,108,117,101,10,0,0,0,0,0,0,0,76,97,118,102,0,0,0,0,115,116,101,114,101,111,95,109,111,100,101,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,49,53,0,0,0,0,0,0,0,110,111,107,101,121,0,0,0,120,102,97,99,101,0,0,0,71,46,55,50,54,32,65,68,80,67,77,0,0,0,0,0,93,0,0,0,0,0,0,0,65,114,116,105,115,116,47,112,101,114,102,111,114,109,101,114,0,0,0,0,0,0,0,0,100,101,99,111,100,101,95,118,105,100,101,111,32,37,100,46,37,100,0,0,0,0,0,0,80,67,83,95,65,114,99,95,49,57,53,48,95,76,111,49,51,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,97,108,108,32,98,105,100,105,114,101,99,116,105,111,110,97,108,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,97,100,112,99,109,95,103,55,50,54,0,0,0,0,0,0,35,32,116,105,109,101,99,111,100,101,32,102,111,114,109,97,116,32,118,50,10,0,0,0,83,121,110,99,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,105,110,32,109,97,112,32,37,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,97,110,121,32,115,116,114,101,97,109,115,46,10,0,0,0,0,0,0,0,0,123,37,108,108,100,125,0,0,123,37,100,125,123,37,42,100,125,37,54,108,102,0,0,0,73,110,118,97,108,105,100,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,32,115,105,122,101,58,32,37,100,46,10,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,112,114,111,116,111,99,111,108,115,0,0,0,0,0,0,0,0,37,100,44,32,37,49,48,108,108,100,44,32,37,49,48,108,108,100,44,32,37,56,100,44,32,37,56,100,44,32,0,0,80,67,83,95,65,114,97,116,117,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,98,105,100,105,114,0,0,0,99,115,103,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,0,0,0,101,114,114,111,114,95,116,101,114,109,32,62,61,32,48,46,48,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,121,110,99,32,102,105,108,101,32,105,110,100,101,120,58,32,37,100,46,10,0,0,0,119,101,98,109,0,0,0,0,79,110,108,121,32,118,105,100,101,111,32,97,110,100,32,97,117,100,105,111,32,102,105,108,116,101,114,115,32,115,117,112,112,111,114,116,101,100,32,99,117,114,114,101,110,116,108,121,46,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,32,98,117,102,102,101,114,0,115,104,111,119,32,116,105,109,101,32,117,110,116,105,108,32,99,111,110,118,101,114,103,101,110,99,101,0,0,0,0,0,80,67,83,95,65,114,97,116,117,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,100,105,115,99,97,114,100,32,97,108,108,32,110,111,110,45,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,97,100,112,99,109,95,101,97,0,0,0,0,0,0,0,0,97,110,97,103,108,121,112,104,32,121,101,108,108,111,119,32,98,108,117,101,32,99,111,108,111,114,0,0,0,0,0,0,109,97,112,99,104,97,110,58,32,105,110,118,97,108,105,100,32,97,117,100,105,111,32,99,104,97,110,110,101,108,32,35,37,100,46,37,100,46,37,100,10,0,0,0,0,0,0,0,70,105,108,101,32,105,115,32,98,114,111,107,101,110,44,32,107,101,121,102,114,97,109,101,115,32,110,111,116,32,99,111,114,114,101,99,116,108,121,32,109,97,114,107,101,100,33,10,0,0,0,0,0,0,0,0,97,102,97,100,101,0,0,0,102,111,114,99,101,95,111,114,105,103,105,110,97,108,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,85,110,107,110,111,119,110,32,102,111,114,109,97,116,32,118,101,114,115,105,111,110,32,37,105,10,0,0,0,0,0,0,65,68,84,83,32,104,101,97,100,101,114,32,100,101,116,101,99,116,101,100,32,45,32,65,68,84,83,32,119,105,108,108,32,110,111,116,32,98,101,32,105,110,99,111,114,114,101,99,116,108,121,32,109,117,120,101,100,32,105,110,116,111,32,76,65,84,77,10,0,0,0,0,100,101,102,97,117,108,116,0,112,117,116,95,105,109,97,103,101,40,41,32,115,97,121,115,32,115,107,105,112,10,0,0,99,111,109,112,32,33,61,32,48,0,0,0,0,0,0,0,80,67,83,95,65,114,97,116,117,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,77,73,78,32,0,0,0,0,110,111,114,101,102,0,0,0,83,69,71,65,32,67,82,73,32,65,68,88,32,65,68,80,67,77,0,0,0,0,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,32,109,105,115,115,105,110,103,32,69,79,83,32,115,116,97,116,115,32,112,97,99,107,101,116,0,0,0,0,35,84,32,37,115,0,0,0,109,97,112,99,104,97,110,58,32,115,116,114,101,97,109,32,35,37,100,46,37,100,32,105,115,32,110,111,116,32,97,110,32,97,117,100,105,111,32,115,116,114,101,97,109,46,10,0,68,75,73,70,0,0,0,0,70,97,105,108,101,100,32,112,97,114,115,105,110,103,32,115,116,101,114,101,111,32,102,108,97,103,10,0,0,0,0,0,98,111,116,116,111,109,32,102,105,101,108,100,0,0,0,0,79,112,101,110,67,76,58,32,85,110,97,98,108,101,32,116,111,32,97,108,108,111,99,97,116,101,32,112,97,103,101,45,108,111,99,107,101,100,32,98,117,102,102,101,114,44,32,101,114,114,111,114,32,39,37,100,39,10,0,0,0,0,0,0,98,103,114,53,54,53,98,101,0,0,0,0,0,0,0,0,68,97,114,107,83,97,108,109,111,110,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,60,114,97,116,105,111,110,97,108,62,0,0,0,0,0,0,98,105,116,97,110,100,0,0,87,82,0,0,0,0,0,0,102,105,108,116,101,114,83,105,122,101,32,62,32,48,0,0,100,101,115,116,105,110,97,116,105,111,110,32,114,97,110,103,101,0,0,0,0,0,0,0,111,117,116,95,99,104,97,110,110,101,108,95,99,111,117,110,116,0,0,0,0,0,0,0,102,100,0,0,0,0,0,0,105,110,103,101,110,105,101,110,116,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,68,105,97,108,111,103,117,101,0,0,0,0,0,0,0,0,102,97,107,101,0,0,0,0,65,68,80,67,77,32,77,105,99,114,111,115,111,102,116,0,108,111,114,111,95,115,117,114,109,105,120,108,101,118,0,0,108,111,114,111,95,115,117,114,109,105,120,108,101,118,0,0,109,97,115,116,101,114,0,0,77,111,114,101,32,116,104,97,110,32,111,110,101,32,65,65,67,32,82,68,66,32,112,101,114,32,65,68,84,83,32,102,114,97,109,101,0,0,0,0,108,101,110,32,112,114,101,102,105,120,0,0,0,0,0,0,80,67,83,95,76,105,115,98,111,110,95,80,111,114,116,117,103,101,115,101,95,71,114,105,100,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,117,115,101,108,101,115,115,32,102,114,97,109,101,115,0,0,66,117,103,32,105,110,32,99,111,100,101,118,101,99,116,111,114,32,118,101,99,116,111,114,32,98,117,105,108,100,105,110,103,32,99,111,100,101,46,32,10,0,0,0,0,0,0,0,109,98,32,80,32,32,37,115,32,32,80,49,54,46,46,52,58,32,37,52,46,49,102,37,37,32,37,52,46,49,102,37,37,32,37,52,46,49,102,37,37,32,37,52,46,49,102,37,37,32,37,52,46,49,102,37,37,32,32,32,32,115,107,105,112,58,37,52,46,49,102,37,37,10,0,0,0,0,0,0,79,118,101,114,114,105,100,105,110,103,32,105,110,118,97,108,105,100,32,109,113,117,97,110,116,32,37,100,10,0,0,0,97,100,112,99,109,95,97,100,120,0,0,0,0,0,0,0,114,101,116,32,60,61,32,48,0,0,0,0,0,0,0,0,112,105,112,101,100,32,105,109,97,103,101,50,32,115,101,113,117,101,110,99,101,0,0,0,109,97,112,99,104,97,110,58,32,105,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,115,116,114,101,97,109,32,105,110,100,101,120,32,35,37,100,46,37,100,10,0,0,0,0,0,0,0,0,77,111,100,101,108,84,121,112,101,71,101,111,99,101,110,116,114,105,99,0,0,0,0,0,99,111,109,112,117,116,101,114,0,0,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,91,108,97,118,99,32,114,99,93,32,69,114,114,111,114,58,32,50,112,97,115,115,32,99,117,114,118,101,32,102,97,105,108,101,100,32,116,111,32,99,111,110,118,101,114,103,101,10,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,105,110,116,114,97,45,114,101,102,114,101,115,104,0,0,0,117,115,101,32,105,110,116,101,114,110,97,108,32,50,45,112,97,115,115,32,114,97,116,101,99,111,110,116,114,111,108,32,105,110,32,115,101,99,111,110,100,32,112,97,115,115,32,109,111,100,101,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,51,0,0,0,0,0,0,0,67,66,80,32,82,68,32,110,101,101,100,115,32,116,114,101,108,108,105,115,32,113,117,97,110,116,10,0,0,0,0,0,37,53,100,0,0,0,0,0,115,116,117,102,102,105,110,103,32,115,116,97,114,116,0,0,115,45,62,100,114,111,112,95,102,114,97,109,101,95,116,105,109,101,99,111,100,101,32,61,61,32,33,33,40,115,45,62,116,99,46,102,108,97,103,115,32,38,32,65,86,95,84,73,77,69,67,79,68,69,95,70,76,65,71,95,68,82,79,80,70,82,65,77,69,41,0,0,116,111,112,0,0,0,0,0,105,110,118,97,108,105,100,47,117,110,107,110,111,119,110,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,10,0,0,0,0,0,0,0,0,105,109,97,103,101,50,112,105,112,101,32,100,101,109,117,120,101,114,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,117,102,102,101,114,10,0,115,105,109,112,108,101,0,0,103,95,117,115,97,103,101,58,0,0,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,118,117,105,32,100,101,102,97,117,108,116,32,100,105,115,112,108,97,121,32,119,105,110,100,111,119,44,32,111,114,105,103,105,110,97,108,32,118,97,108,117,101,115,32,97,114,101,32,108,58,37,117,32,114,58,37,117,32,116,58,37,117,32,98,58,37,117,10,0,72,69,86,67,32,100,101,99,111,100,101,114,0,0,0,0,101,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,105,120,32,111,102,32,105,100,114,32,97,110,100,32,110,111,110,45,105,100,114,32,115,108,105,99,101,115,10,0,0,109,105,110,95,112,97,114,116,105,116,105,111,110,95,111,114,100,101,114,0,0,0,0,0,85,110,107,110,111,119,110,32,100,97,116,97,32,116,121,112,101,32,102,111,114,32,104,101,97,100,101,114,32,118,97,114,105,97,98,108,101,32,37,115,10,0,0,0,0,0,0,0,100,104,101,97,100,112,104,111,110,101,95,109,111,100,101,0,101,110,97,98,108,101,32,116,114,117,101,45,112,101,97,107,32,109,111,100,101,0,0,0,68,84,83,45,72,68,32,72,82,65,0,0,0,0,0,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,51,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,51,32,47,32,83,86,81,51,0,0,0,80,67,83,95,65,102,103,111,111,121,101,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,73,110,115,116,114,117,109,101,110,116,97,108,32,82,111,99,107,0,0,0,0,0,0,0,65,68,80,67,77,32,67,68,82,79,77,32,88,65,0,0,52,50,50,80,49,52,0,0,57,55,48,49,50,48,48,48,0,0,0,0,0,0,0,0,108,106,112,103,0,0,0,0,83,101,116,116,105,110,103,32,39,37,115,39,32,116,111,32,118,97,108,117,101,32,39,37,115,39,10,0,0,0,0,0,79,117,116,112,117,116,0,0,109,105,110,95,102,114,97,103,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,115,116,114,101,97,109,115,10,0,0,109,97,112,99,104,97,110,58,32,105,110,118,97,108,105,100,32,105,110,112,117,116,32,102,105,108,101,32,105,110,100,101,120,58,32,37,100,10,0,0,108,105,98,97,118,102,111,114,109,97,116,47,105,102,102,46,99,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,70,111,114,32,118,105,110,116,97,103,101,32,99,111,109,112,97,116,105,98,105,108,105,116,121,32,102,112,115,32,109,117,115,116,32,98,101,32,51,48,10,0,0,0,0,0,0,0,97,101,99,104,111,0,0,0,105,110,99,111,109,112,108,101,116,101,32,104,101,97,100,101,114,10,0,0,0,0,0,0,80,67,83,95,65,102,103,111,111,121,101,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,0,0,0,0,0,100,105,115,99,97,114,100,32,110,111,32,102,114,97,109,101,0,0,0,0,0,0,0,0,97,100,112,99,109,95,120,97,0,0,0,0,0,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,44,32,109,97,112,99,104,97,110,32,117,115,97,103,101,58,32,91,102,105,108,101,46,115,116,114,101,97,109,46,99,104,97,110,110,101,108,124,45,49,93,91,58,115,121,110,99,102,105,108,101,58,115,121,110,99,115,116,114,101,97,109,93,10,0,0,0,0,105,110,102,111,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,97,102,116,101,114,32,119,104,105,99,104,32,116,104,101,32,105,110,100,101,120,32,119,114,97,112,115,0,0,97,61,114,116,112,109,97,112,58,37,100,32,86,80,56,47,57,48,48,48,48,13,10,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,84,67,79,78,0,0,0,0,73,110,118,97,108,105,100,32,66,77,80,10,0,0,0,0,80,67,83,95,65,105,110,95,101,108,95,65,98,100,95,66,97,104,114,97,105,110,95,71,114,105,100,0,0,0,0,0,110,111,110,101,0,0,0,0,65,68,80,67,77,32,52,88,32,77,111,118,105,101,0,0,109,117,108,97,119,32,100,101,109,117,120,101,114,0,0,0,105,110,118,97,108,105,100,32,114,101,115,111,108,117,116,105,111,110,58,32,37,117,120,37,117,10,0,0,0,0,0,0,97,100,101,108,97,121,0,0,37,100,46,37,100,46,37,100,58,37,100,46,37,100,0,0,102,112,115,112,114,111,98,101,115,105,122,101,0,0,0,0,35,69,88,84,45,88,45,86,69,82,83,73,79,78,58,51,10,0,0,0,0,0,0,0,82,101,112,108,97,99,101,115,0,0,0,0,0,0,0,0,37,46,50,120,0,0,0,0,117,115,101,114,45,97,103,101,110,116,0,0,0,0,0,0,77,105,110,105,109,117,109,32,80,69,83,32,112,97,99,107,101,116,32,112,97,121,108,111,97,100,32,105,110,32,98,121,116,101,115,0,0,0,0,0,80,67,83,95,65,105,110,95,101,108,95,65,98,100,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,0,0,0,115,107,105,112,32,100,101,99,111,100,105,110,103,32,102,111,114,32,116,104,101,32,115,101,108,101,99,116,101,100,32,102,114,97,109,101,115,0,0,0,97,100,112,99,109,95,52,120,109,0,0,0,0,0,0,0,37,100,58,37,100,46,37,100,0,0,0,0,0,0,0,0,37,115,47,105,110,100,101,120,46,102,52,109,46,116,109,112,0,0,0,0,0,0,0,0,102,114,97,103,95,99,117,115,116,111,109,0,0,0,0,0,104,100,95,118,105,100,101,111,0,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,97,108,108,111,99,32,109,97,112,32,111,102,102,115,101,116,115,10,0,0,101,110,99,111,100,105,110,103,95,116,111,111,108,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,97,99,111,110,118,101,114,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2259104);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,105,114,115,116,32,97,110,100,32,108,97,115,116,32,115,97,109,112,108,101,32,118,97,108,117,101,115,10,0,0,0,80,67,83,95,65,105,110,95,101,108,95,65,98,100,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,0,0,115,107,105,112,95,102,114,97,109,101,0,0,0,0,0,0,120,98,109,0,0,0,0,0,65,68,80,67,77,32,77,105,99,114,111,115,111,102,116,0,71,114,97,112,104,105,99,32,67,111,110,116,114,111,108,32,69,120,116,101,110,115,105,111,110,32,98,108,111,99,107,39,115,32,115,105,122,101,32,108,101,115,115,32,116,104,97,110,32,52,46,10,0,0,0,0,37,115,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,115,101,116,32,116,104,101,32,39,99,114,101,97,116,105,111,110,95,116,105,109,101,39,32,109,101,116,97,100,97,116,97,32,116,97,103,32,105,110,115,116,101,97,100,46,10,0,0,0,0,0,0,0,0,76,101,97,100,32,97,114,116,105,115,116,47,108,101,97,100,32,112,101,114,102,111,114,109,101,114,47,115,111,108,111,105,115,116,0,0,0,0,0,0,71,73,70,32,109,117,120,101,114,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,97,32,115,105,110,103,108,101,32,118,105,100,101,111,32,71,73,70,32,115,116,114,101,97,109,46,10,0,0,0,0,0,103,55,50,57,32,100,101,109,117,120,101,114,0,0,0,0,115,116,45,62,99,111,100,101,99,45,62,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,62,32,48,0,0,0,0,115,117,98,50,118,105,100,101,111,58,32,114,101,99,116,97,110,103,108,101,32,111,118,101,114,102,108,111,119,105,110,103,10,0,0,0,0,0,0,0,44,32,83,61,37,100,0,0,116,112,32,45,32,99,112,105,45,62,116,111,107,32,60,61,32,103,101,116,95,116,111,107,101,110,95,97,108,108,111,99,40,99,109,45,62,109,98,95,114,111,119,115,44,32,99,109,45,62,109,98,95,99,111,108,115,41,0,0,0,0,0,0,80,67,83,95,65,105,110,95,101,108,95,65,98,100,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,0,0,115,107,105,112,32,73,68,67,84,47,100,101,113,117,97,110,116,105,122,97,116,105,111,110,32,102,111,114,32,116,104,101,32,115,101,108,101,99,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,97,100,112,99,109,95,109,115,0,0,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,61,37,70,84,37,84,37,122,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,97,108,117,101,32,116,121,112,101,32,37,100,32,105,110,32,116,97,103,32,37,115,46,10,0,0,0,70,97,105,108,101,100,32,116,111,32,117,112,100,97,116,101,32,104,101,97,100,101,114,32,119,105,116,104,32,99,111,114,114,101,99,116,32,102,105,108,101,115,105,122,101,46,10,0,112,114,111,116,111,99,111,108,115,0,0,0,0,0,0,0,45,49,51,49,48,55,50,32,60,61,32,114,118,32,38,38,32,114,118,32,60,61,32,49,51,49,48,55,49,0,0,0,110,101,103,97,116,105,118,101,32,99,116,115,44,32,112,114,101,118,105,111,117,115,32,116,105,109,101,115,116,97,109,112,115,32,109,105,103,104,116,32,98,101,32,119,114,111,110,103,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,109,97,103,105,99,32,99,104,117,110,107,32,105,110,32,102,105,108,101,10,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,56,0,0,0,115,107,105,112,95,105,100,99,116,0,0,0,0,0,0,0,111,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,115,101,116,32,98,97,110,100,45,119,105,100,116,104,0,0,65,68,80,67,77,32,73,77,65,32,76,111,107,105,32,83,68,76,32,77,74,80,69,71,0,0,0,0,0,0,0,0,102,76,97,67,0,0,0,0,102,114,97,109,101,115,58,100,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,97,99,107,105,110,103,32,109,101,116,104,111,100,0,0,0,0,0,0,98,108,111,99,107,115,105,122,101,0,0,0,0,0,0,0,116,114,101,101,91,48,93,32,60,61,32,48,32,38,38,32,116,114,101,101,91,49,93,32,62,32,48,0,0,0,0,0,91,67,72,65,80,84,69,82,93,0,0,0,0,0,0,0,115,117,98,50,118,105,100,101,111,58,32,117,115,105,110,103,32,37,100,120,37,100,32,99,97,110,118,97,115,10,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,32,98,117,102,102,101,114,115,0,0,0,0,0,0,0,0,99,111,110,118,101,114,103,101,110,99,101,0,0,0,0,0,84,73,77,69,66,65,83,69,61,37,100,47,37,100,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,99,97,110,110,111,116,32,102,105,110,100,32,70,70,77,32,115,121,110,99,119,111,114,100,10,0,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,55,0,0,0,97,118,100,105,115,99,97,114,100,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,115,109,106,112,101,103,0,0,0,0,0,0,0,0,97,121,98,99,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,112,114,111,103,114,101,115,115,32,85,82,76,32,34,37,115,34,58,32,37,115,10,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,0,0,0,111,117,116,112,117,116,32,104,111,114,105,122,111,110,116,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,105,115,32,116,111,111,32,98,105,103,58,32,37,100,10,0,0,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,102,105,110,100,32,68,86,32,104,101,97,100,101,114,46,10,0,121,117,118,52,50,48,0,0,102,105,108,101,105,110,102,111,0,0,0,0,0,0,0,0,99,51,102,0,0,0,0,0,99,111,110,118,101,114,115,105,111,110,95,109,97,112,91,105,93,46,102,109,116,32,38,38,32,105,110,108,105,110,107,45,62,119,32,38,38,32,105,110,108,105,110,107,45,62,104,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,54,0,0,0,68,79,77,65,73,78,95,0,115,107,105,112,32,108,111,111,112,32,102,105,108,116,101,114,105,110,103,32,112,114,111,99,101,115,115,32,102,111,114,32,116,104,101,32,115,101,108,101,99,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,73,110,118,97,108,105,100,32,109,97,103,105,99,32,102,111,114,32,68,70,65,10,0,0,65,68,80,67,77,32,73,77,65,32,87,101,115,116,119,111,111,100,0,0,0,0,0,0,97,101,118,97,108,115,114,99,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,115,105,122,101,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,115,51,48,50,109,46,32,40,37,100,32,62,32,54,53,53,51,53,41,10,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,32,114,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,116,119,111,32,112,97,99,107,101,116,115,32,102,111,114,32,101,97,99,104,32,108,97,121,101,114,46,0,0,0,0,0,0,0,112,105,112,101,58,0,0,0,32,9,13,10,0,0,0,0,67,111,117,108,100,32,110,111,116,32,112,97,114,115,101,32,102,114,97,109,101,114,97,116,101,58,32,37,115,46,10,0,98,111,116,116,111,109,0,0,79,112,101,110,67,76,58,32,85,110,97,98,108,101,32,116,111,32,99,111,109,112,105,108,101,32,107,101,114,110,101,108,32,39,37,115,39,32,40,37,100,41,10,0,0,0,0,0,114,103,98,53,53,53,108,101,0,0,0,0,0,0,0,0,68,97,114,107,82,101,100,0,60,115,116,114,105,110,103,62,0,0,0,0,0,0,0,0,105,102,110,111,116,0,0,0,119,105,100,101,32,108,101,102,116,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,100,115,116,95,114,97,110,103,101,0,0,0,0,0,0,0,67,65,70,32,102,105,108,101,115,32,104,97,118,101,32,101,120,97,99,116,108,121,32,111,110,101,32,115,116,114,101,97,109,10,0,0,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,99,111,117,110,116,0,0,0,0,0,0,0,0,109,101,100,105,97,110,100,101,105,110,116,0,0,0,0,0,86,52,32,83,116,121,108,101,115,0,0,0,0,0,0,0,98,102,102,0,0,0,0,0,97,100,112,99,109,95,109,115,0,0,0,0,0,0,0,0,76,111,47,82,111,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,76,111,47,82,111,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,77,105,115,115,105,110,103,32,112,97,99,107,101,116,32,116,97,98,108,101,46,32,73,116,32,105,115,32,114,101,113,117,105,114,101,100,32,119,104,101,110,32,98,108,111,99,107,32,115,105,122,101,32,111,114,32,102,114,97,109,101,32,115,105,122,101,32,97,114,101,32,118,97,114,105,97,98,108,101,46,10,0,0,0,0,0,0,0,118,105,110,116,97,103,101,0,65,115,115,117,109,105,110,103,32,97,110,32,105,110,99,111,114,114,101,99,116,108,121,32,101,110,99,111,100,101,100,32,55,46,49,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,110,115,116,101,97,100,32,111,102,32,97,32,115,112,101,99,45,99,111,109,112,108,105,97,110,116,32,55,46,49,40,119,105,100,101,41,32,108,97,121,111,117,116,44,32,117,115,101,32,45,115,116,114,105,99,116,32,37,100,32,116,111,32,100,101,99,111,100,101,32,97,99,99,111,114,100,105,110,103,32,116,111,32,116,104,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,105,110,115,116,101,97,100,46,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,119,105,100,116,104,47,104,101,105,103,104,116,10,0,0,0,0,0,0,0,109,97,120,32,110,117,109,32,115,117,98,102,114,97,109,101,115,0,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,53,0,0,0,115,107,105,112,95,108,111,111,112,95,102,105,108,116,101,114,0,0,0,0,0,0,0,0,32,77,111,114,101,32,99,111,100,101,108,101,110,103,116,104,115,32,116,104,97,110,32,99,111,100,101,115,32,105,110,32,99,111,100,101,98,111,111,107,46,32,10,0,0,0,0,0,109,98,32,73,32,32,37,115,10,0,0,0,0,0,0,0,66,105,116,115,32,111,118,101,114,99,111,110,115,117,109,112,116,105,111,110,58,32,37,105,32,62,32,37,105,32,97,116,32,37,105,120,37,105,10,0,97,100,112,99,109,95,105,109,97,95,119,115,0,0,0,0,97,118,99,116,120,45,62,99,111,100,101,99,45,62,101,110,99,111,100,101,50,0,0,0,99,111,100,101,99,32,37,100,0,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,77,111,100,101,108,84,121,112,101,71,101,111,103,114,97,112,104,105,99,0,0,0,0,0,100,111,99,117,109,101,110,116,95,110,97,109,101,0,0,0,115,111,102,116,108,105,103,104,116,0,0,0,0,0,0,0,91,108,97,118,99,32,114,99,93,32,69,114,114,111,114,58,32,98,105,116,114,97,116,101,32,116,111,111,32,108,111,119,32,102,111,114,32,116,104,105,115,32,118,105,100,101,111,32,119,105,116,104,32,116,104,101,115,101,32,112,97,114,97,109,101,116,101,114,115,46,10,0,112,99,109,95,115,49,54,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,115,99,101,110,101,99,117,116,0,0,0,0,0,0,0,0,112,97,115,115,50,0,0,0,109,115,109,112,101,103,52,0,109,112,101,103,50,32,115,116,121,108,101,32,113,117,97,110,116,105,122,97,116,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,68,67,84,32,99,111,101,102,102,115,32,111,102,32,77,66,32,97,116,32,37,100,120,37,100,58,10,0,0,0,0,0,84,101,120,116,117,114,101,32,83,104,97,112,101,32,76,97,121,101,114,32,115,116,97,114,116,0,0,0,0,0,0,0,115,45,62,109,98,95,115,107,105,112,95,114,117,110,32,61,61,32,48,0,0,0,0,0,97,108,116,0,0,0,0,0,114,101,115,116,97,114,116,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,109,97,114,107,101,114,61,37,120,32,97,118,97,105,108,95,115,105,122,101,95,105,110,95,98,117,102,61,37,116,100,10,0,0,0,0,0,0,0,0,87,101,105,103,104,116,101,100,32,112,114,101,100,105,99,116,105,111,110,32,97,110,97,108,121,115,105,115,32,109,101,116,104,111,100,46,0,0,0,0,103,101,110,101,114,105,99,32,115,101,116,116,105,110,103,115,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,117,10,32,32,37,42,115,123,37,117,47,37,117,125,10,32,32,37,42,115,37,117,10,32,32,37,42,115,37,100,10,32,32,37,42,115,37,117,10,0,0,76,111,119,101,114,32,116,104,101,32,100,101,99,111,100,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,98,121,32,97,32,112,111,119,101,114,32,111,102,32,116,119,111,0,85,110,107,110,111,119,110,32,83,65,82,32,105,110,100,101,120,58,32,37,117,46,10,0,77,97,105,110,32,83,116,105,108,108,32,80,105,99,116,117,114,101,0,0,0,0,0,0,101,88,116,101,110,100,101,100,32,66,73,78,97,114,121,32,116,101,120,116,32,40,88,66,73,78,41,0,0,0,0,0,49,0,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,78,65,76,32,37,100,32,105,110,32,103,108,111,98,97,108,32,104,101,97,100,101,114,47,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,116,111,107,91,116,105,108,101,95,114,111,119,93,91,116,105,108,101,95,99,111,108,93,32,61,61,32,116,111,107,95,101,110,100,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,112,97,115,115,101,115,32,116,111,32,117,115,101,32,102,111,114,32,67,104,111,108,101,115,107,121,32,102,97,99,116,111,114,105,122,97,116,105,111,110,32,100,117,114,105,110,103,32,76,80,67,32,97,110,97,108,121,115,105,115,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,116,114,117,101,0,0,0,0,68,84,83,32,57,54,47,50,52,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,58,32,109,111,114,101,32,116,104,97,110,32,49,48,48,48,48,48,48,32,102,114,97,109,101,115,10,0,0,0,0,0,0,0,115,118,113,51,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,52,0,0,0,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,98,105,116,114,97,116,101,32,112,101,110,97,108,116,121,32,99,111,109,112,101,110,115,97,116,105,111,110,32,40,49,46,48,32,61,32,50,53,54,41,0,0,0,0,0,0,114,101,97,99,104,101,100,32,116,101,114,109,105,110,97,116,105,110,103,32,99,104,97,114,97,99,116,101,114,32,98,117,116,32,110,111,116,32,97,108,108,32,102,114,97,109,101,115,32,114,101,97,100,46,10,0,73,110,115,116,114,117,109,101,110,116,97,108,32,80,111,112,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,68,117,99,107,32,68,75,52,0,0,0,0,0,0,52,50,48,80,49,52,0,0,119,111,114,100,115,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,0,37,115,32,35,37,100,44,32,37,115,44,32,37,115,32,39,37,115,39,58,10,0,0,0,110,117,109,98,101,114,32,111,102,32,108,111,111,107,97,104,101,97,100,32,102,114,97,103,109,101,110,116,115,0,0,0,85,110,107,110,111,119,110,32,116,97,114,103,101,116,58,32,37,115,10,0,0,0,0,0,40,101,110,101,114,103,121,41,32,62,61,32,69,78,69,82,71,89,95,77,73,78,32,38,38,32,40,101,110,101,114,103,121,41,32,60,61,32,69,78,69,82,71,89,95,77,65,88,0,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,118,105,111,98,117,102,46,99,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,51,0,0,0,109,101,112,99,0,0,0,0,97,100,112,99,109,95,105,109,97,95,100,107,52,0,0,0,104,116,116,112,115,32,112,114,111,116,111,99,111,108,32,110,111,116,32,102,111,117,110,100,44,32,114,101,99,111,109,112,105,108,101,32,119,105,116,104,32,111,112,101,110,115,115,108,32,111,114,32,103,110,117,116,108,115,32,101,110,97,98,108,101,100,46,10,0,0,0,0,121,117,118,52,49,49,112,0,119,97,114,110,105,110,103,0,115,101,103,109,101,110,116,95,119,114,97,112,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,116,104,101,111,114,97,47,57,48,48,48,48,13,10,97,61,102,109,116,112,58,37,100,32,100,101,108,105,118,101,114,121,45,109,101,116,104,111,100,61,105,110,108,105,110,101,59,32,119,105,100,116,104,61,37,100,59,32,104,101,105,103,104,116,61,37,100,59,32,115,97,109,112,108,105,110,103,61,37,115,59,32,99,111,110,102,105,103,117,114,97,116,105,111,110,61,37,115,13,10,0,0,0,0,0,0,0,0,99,114,45,62,115,98,95,105,110,100,101,120,32,60,32,115,98,115,95,105,110,95,102,114,97,109,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,97,119,32,77,76,80,0,108,105,98,97,118,102,111,114,109,97,116,47,97,118,105,100,101,99,46,99,0,0,0,0,117,108,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,50,0,0,0,109,97,120,105,109,117,109,32,109,97,99,114,111,98,108,111,99,107,32,76,97,103,114,97,110,103,101,32,102,97,99,116,111,114,32,40,86,66,82,41,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,68,117,99,107,32,68,75,51,0,0,0,0,0,0,117,108,0,0,0,0,0,0,111,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,121,117,118,52,50,50,112,0,109,97,120,105,109,117,109,32,109,117,120,105,110,103,32,111,114,32,100,101,109,117,120,105,110,103,32,100,101,108,97,121,32,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,0,0,0,0,0,0,0,0,76,111,111,112,101,110,100,32,118,97,108,117,101,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,97,110,100,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,44,0,0,0,0,0,0,0,68,101,112,101,110,100,115,0,37,42,91,94,44,93,44,37,100,58,37,100,58,37,100,37,42,99,37,100,44,37,100,58,37,100,58,37,100,37,42,99,37,100,0,0,0,0,0,0,37,115,58,32,85,110,105,118,101,114,115,97,108,32,76,97,98,101,108,58,32,0,0,0,97,115,102,95,115,116,114,101,97,109,0,0,0,0,0,0,116,0,0,0,0,0,0,0,112,101,115,95,112,97,121,108,111,97,100,95,115,105,122,101,0,0,0,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,49,0,0,0,109,98,108,109,97,120,0,0,97,100,112,99,109,95,105,109,97,95,100,107,51,0,0,0,100,118,53,48,0,0,0,0,87,114,105,116,101,32,115,101,112,97,114,97,116,101,32,109,111,111,102,47,109,100,97,116,32,97,116,111,109,115,32,102,111,114,32,101,97,99,104,32,116,114,97,99,107,0,0,0,105,116,105,109,101,58,48,120,37,108,108,120,44,32,112,99,116,58,37,100,44,32,105,99,116,58,37,100,10,0,0,0,109,101,100,105,97,95,116,121,112,101,0,0,0,0,0,0,45,45,62,62,32,37,108,108,100,0,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,84,111,111,32,109,97,110,121,32,116,97,103,32,102,105,101,108,100,115,32,40,37,100,41,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,65,86,67,111,100,101,99,73,68,32,37,115,46,10,0,0,0,0,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,116,114,97,110,115,102,111,114,109,32,115,105,122,101,46,34,0,0,85,110,115,117,112,112,111,114,116,101,100,32,102,105,108,101,32,118,101,114,115,105,111,110,32,45,32,37,100,46,37,48,50,100,10,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,53,48,0,0,0,109,105,110,105,109,117,109,32,109,97,99,114,111,98,108,111,99,107,32,76,97,103,114,97,110,103,101,32,102,97,99,116,111,114,32,40,86,66,82,41,0,0,0,0,0,0,0,0,119,101,98,112,0,0,0,0,65,68,80,67,77,32,73,77,65,32,87,65,86,0,0,0,99,111,108,111,114,0,0,0,100,118,0,0,0,0,0,0,77,101,100,105,97,32,40,101,46,103,46,32,108,97,98,101,108,32,115,105,100,101,32,111,102,32,67,68,41,0,0,0,115,117,98,50,118,105,100,101,111,58,32,110,111,110,45,98,105,116,109,97,112,32,115,117,98,116,105,116,108,101,10,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,52,57,0,0,0,109,98,108,109,105,110,0,0,97,100,112,99,109,95,105,109,97,95,119,97,118,0,0,0,73,110,118,97,108,105,100,32,117,115,97,103,101,32,111,102,32,115,101,103,101,109,101,110,116,32,102,101,97,116,117,114,101,32,111,110,32,115,109,97,108,108,32,98,108,111,99,107,115,0,0,0,0,0,0,0,52,56,48,48,48,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,71,85,73,68,32,118,97,108,117,101,32,105,110,32,116,97,103,32,37,115,46,10,0,0,0,0,0,0,37,100,58,37,100,58,37,100,0,0,0,0,0,0,0,0,115,111,102,116,112,117,108,108,100,111,119,110,58,32,37,108,108,100,32,102,114,97,109,101,115,32,105,110,44,32,37,108,108,100,32,102,114,97,109,101,115,32,111,117,116,10,0,0,37,100,58,37,100,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,98,105,116,32,115,116,114,101,97,109,32,102,105,108,116,101,114,115,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,37,100,58,37,100,58,37,100,58,37,100,0,0,0,0,0,80,67,83,95,65,71,68,56,52,95,65,77,71,95,122,111,110,101,95,52,56,0,0,0,105,110,99,114,101,97,115,101,32,116,104,101,32,113,117,97,110,116,105,122,101,114,32,102,111,114,32,109,97,99,114,111,98,108,111,99,107,115,32,99,108,111,115,101,32,116,111,32,98,111,114,100,101,114,115,0,112,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,81,117,105,99,107,84,105,109,101,0,0,0,0,0,37,108,102,58,37,108,102,58,37,108,102,58,37,108,102,58,37,108,102,58,37,108,102,58,37,108,102,58,37,108,102,0,52,52,56,48,48,48,0,0,37,100,58,37,100,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,32,102,114,97,109,101,10,0,0,121,97,100,105,102,0,0,0,82,101,102,101,114,101,110,99,101,100,32,102,114,97,109,101,32,119,105,116,104,32,105,110,118,97,108,105,100,32,115,105,122,101,0,0,0,0,0,0,115,101,116,32,112,101,114,105,111,100,32,109,111,100,101,0,108,105,98,97,118,102,105,108,116,101,114,47,102,114,97,109,101,115,121,110,99,46,99,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,56,0,0,0,98,111,114,100,101,114,95,109,97,115,107,0,0,0,0,0,115,114,99,45,62,118,105,100,101,111,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,113,116,0,0,0,0,97,110,97,103,108,121,112,104,32,114,101,100,32,103,114,101,101,110,32,103,114,97,121,0,112,111,119,101,114,32,60,61,32,48,120,56,48,48,48,32,42,32,48,120,56,48,48,48,0,0,0,0,0,0,0,0,49,48,48,56,48,48,48,48,0,0,0,0,0,0,0,0,111,117,116,95,104,95,99,104,114,95,112,111,115,0,0,0,109,112,116,101,115,116,115,114,99,0,0,0,0,0,0,0,110,58,37,102,32,116,58,37,102,32,112,116,115,58,37,102,32,112,114,101,99,105,115,105,111,110,58,37,115,32,0,0,115,101,116,32,111,117,116,112,117,116,32,102,111,114,109,97,116,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,102,108,97,103,115,0,0,110,111,105,115,101,0,0,0,109,112,32,114,101,113,117,101,115,116,95,102,114,97,109,101,32,114,101,116,61,37,100,10,0,0,0,0,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,55,0,0,0,84,111,111,32,108,97,114,103,101,32,111,114,32,105,110,118,97,108,105,100,32,51,68,32,76,85,84,32,115,105,122,101,10,0,0,0,0,0,0,0,102,114,97,109,101,32,115,107,105,112,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,0,0,0,100,101,102,97,117,108,116,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,32,112,108,97,110,97,114,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,46,115,122,32,105,110,100,105,99,97,116,101,115,32,116,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,46,0,0,0,0,0,0,50,48,52,56,0,0,0,0,73,109,97,103,101,32,115,105,122,101,32,109,117,115,116,32,109,97,116,99,104,32,101,110,99,111,100,101,114,32,105,110,105,116,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,115,105,122,101,0,0,0,69,120,112,101,99,116,101,100,32,111,117,116,32,99,104,97,110,110,101,108,32,110,97,109,101,44,32,103,111,116,32,34,37,46,56,115,34,10,0,0,97,117,116,111,109,97,116,105,99,32,40,115,97,109,101,32,118,97,108,117,101,32,97,115,32,39,111,114,100,101,114,39,41,0,0,0,0,0,0,0,115,117,109,95,105,110,116,101,114,95,99,111,115,116,0,0,114,103,98,53,53,53,98,101,0,0,0,0,0,0,0,0,68,97,114,107,79,114,99,104,105,100,0,0,0,0,0,0,60,102,108,111,97,116,62,0,105,102,0,0,0,0,0,0,87,76,0,0,0,0,0,0,115,105,122,101,70,97,99,116,111,114,32,62,32,48,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,111,117,114,99,101,32,114,97,110,103,101,0,0,0,0,105,110,95,99,104,97,110,110,101,108,95,99,111,117,110,116,0,0,0,0,0,0,0,0,109,100,0,0,0,0,0,0,65,108,105,103,110,109,101,110,116,0,0,0,0,0,0,0,116,102,102,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,87,101,115,116,119,111,111,100,0,0,0,0,0,0,108,111,114,111,95,99,109,105,120,108,101,118,0,0,0,0,108,111,114,111,95,99,109,105,120,108,101,118,0,0,0,0,105,110,118,97,108,105,100,32,100,101,102,97,117,108,116,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,40,37,100,41,10,0,0,0,0,0,115,116,114,111,110,103,95,99,111,110,116,114,97,115,116,0,101,120,116,114,97,100,97,116,97,32,119,114,111,110,103,32,111,114,32,109,105,115,115,105,110,103,10,0,0,0,0,0,108,111,103,50,32,102,114,97,109,101,32,115,105,122,101,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,54,0,0,0,115,107,105,112,99,109,112,0,32,37,117,46,32,67,111,100,101,98,111,111,107,32,104,97,115,32,116,111,111,32,109,97,110,121,32,101,110,116,114,105,101,115,32,40,37,117,41,46,10,0,0,0,0,0,0,0,99,111,110,115,101,99,117,116,105,118,101,32,66,45,102,114,97,109,101,115,58,37,115,10,0,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,0,0,0,0,0,0,0,0,112,99,109,95,115,56,95,112,108,97,110,97,114,0,0,0,98,117,102,102,101,114,32,115,109,97,108,108,101,114,32,116,104,97,110,32,109,105,110,105,109,117,109,32,115,105,122,101,10,0,0,0,0,0,0,0,48,46,51,0,0,0,0,0,57,48,48,48,48,48,48,0,77,111,100,101,108,84,121,112,101,80,114,111,106,101,99,116,101,100,0,0,0,0,0,0,100,97,116,101,0,0,0,0,115,99,114,101,101,110,0,0,91,108,97,118,99,32,114,99,93,32,85,115,105,110,103,32,97,108,108,32,111,102,32,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,32,105,115,32,110,111,116,32,110,101,99,101,115,115,97,114,121,32,102,111,114,32,116,104,105,115,32,118,105,100,101,111,32,119,105,116,104,32,116,104,101,115,101,32,112,97,114,97,109,101,116,101,114,115,46,10,0,0,0,0,0,0,0,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,46,0,0,0,107,101,121,105,110,116,45,109,105,110,0,0,0,0,0,0,117,115,101,32,105,110,116,101,114,110,97,108,32,50,45,112,97,115,115,32,114,97,116,101,99,111,110,116,114,111,108,32,105,110,32,102,105,114,115,116,32,32,112,97,115,115,32,109,111,100,101,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,0,114,101,102,45,62,115,105,122,101,32,62,61,32,111,102,102,115,101,116,32,43,32,115,45,62,109,98,95,115,116,114,105,100,101,32,42,32,40,40,102,45,62,104,101,105,103,104,116,43,49,53,41,47,49,54,41,0,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,58,32,39,37,115,39,46,10,0,0,0,0,84,101,120,116,117,114,101,32,84,105,108,101,32,115,116,97,114,116,0,0,0,0,0,0,109,112,101,103,49,118,105,100,101,111,32,101,110,99,111,100,101,114,0,0,0,0,0,0,112,102,0,0,0,0,0,0,65,115,115,105,103,110,109,101,110,116,32,111,102,32,109,97,116,114,105,120,32,99,104,97,110,110,101,108,32,37,100,32,116,111,32,105,110,118,97,108,105,100,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,37,100,0,0,0,0,77,74,80,69,71,32,112,97,99,107,101,116,32,48,120,37,120,32,116,111,111,32,98,105,103,32,40,37,100,47,37,100,41,44,32,99,111,114,114,117,112,116,32,100,97,116,97,63,10,0,0,0,0,0,0,0,119,101,105,103,104,116,112,0,118,112,120,95,99,111,100,101,99,95,101,110,99,95,99,102,103,10,0,0,0,0,0,0,108,111,119,114,101,115,0,0,114,117,110,32,111,118,101,114,102,108,111,119,32,97,116,32,37,100,120,37,100,32,105,58,37,100,10,0,0,0,0,0,68,101,99,111,100,105,110,103,32,86,85,73,10,0,0,0,77,97,105,110,32,49,48,0,115,101,116,32,97,110,32,101,120,112,114,101,115,115,105,111,110,32,116,111,32,117,115,101,32,102,111,114,32,115,101,108,101,99,116,105,110,103,32,102,114,97,109,101,115,0,0,0,65,86,67,58,32,67,111,110,115,117,109,101,100,32,111,110,108,121,32,37,100,32,98,121,116,101,115,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,0,0,0,0,0,108,112,99,95,112,97,115,115,101,115,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,69,110,99,111,100,101,100,0,0,0,0,0,0,0,68,84,83,45,69,83,0,0,101,110,97,98,108,101,32,112,101,97,107,45,115,97,109,112,108,101,32,109,111,100,101,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,49,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,49,32,47,32,83,86,81,49,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,53,0,0,0,102,114,97,109,101,32,115,107,105,112,32,101,120,112,111,110,101,110,116,0,0,0,0,0,77,101,100,105,116,97,116,105,118,101,0,0,0,0,0,0,83,77,80,84,69,32,51,48,50,77,0,0,0,0,0,0,52,52,52,80,49,50,0,0,87,79,82,68,0,0,0,0,78,111,32,111,112,116,105,111,110,32,110,97,109,101,32,110,101,97,114,32,39,37,115,39,10,0,0,0,0,0,0,0,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,32,105,115,32,110,111,116,32,118,97,108,105,100,10,0,0,0,108,111,111,107,97,104,101,97,100,95,99,111,117,110,116,0,54,48,48,48,48,48,48,0,116,114,101,98,108,101,0,0,84,101,109,112,111,32,118,97,108,117,101,32,37,102,32,101,120,99,101,101,100,115,32,91,48,46,53,44,32,50,46,48,93,32,114,97,110,103,101,10,0,0,0,0,0,0,0,0,98,50,0,0,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,52,0,0,0,115,116,114,101,97,109,32,101,114,114,111,114,0,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,32,111,114,32,99,111,114,114,117,112,116,32,104,101,97,100,101,114,32,108,101,110,103,116,104,0,0,0,0,0,0,0,115,107,105,112,95,101,120,112,0,0,0,0,0,0,0,0,115,51,48,50,109,0,0,0,77,105,110,32,108,101,118,101,108,58,32,37,102,10,0,0,55,50,48,120,52,56,48,0,101,114,114,111,114,0,0,0,112,108,97,110,101,95,99,104,101,99,107,115,117,109,115,58,32,91,32,0,0,0,0,0,115,101,116,32,115,101,103,109,101,110,116,32,115,112,108,105,116,32,102,114,97,109,101,32,110,117,109,98,101,114,115,0,84,104,101,111,114,97,32,99,111,110,102,105,103,117,97,116,105,111,110,32,105,110,102,111,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,115,58,37,100,120,37,100,32,82,68,70,84,32,119,105,110,100,111,119,32,115,105,122,101,58,37,100,10,0,0,0,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,102,108,97,103,115,32,115,101,116,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,112,101,114,45,102,114,97,109,101,32,111,117,116,112,117,116,32,115,97,109,112,108,101,115,0,0,0,0,0,0,109,105,110,95,108,111,103,50,32,60,61,32,109,97,120,95,108,111,103,50,0,0,0,0,109,108,112,0,0,0,0,0,111,115,102,0,0,0,0,0,80,67,77,32,109,117,45,108,97,119,0,0,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,51,0,0,0,102,114,97,109,101,32,115,107,105,112,32,102,97,99,116,111,114,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,48,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,80,67,77,32,109,117,45,108,97,119,0,0,0,0,0,0,105,110,95,103,97,105,110,0,55,50,48,120,53,55,54,0,109,97,120,95,100,101,108,97,121,0,0,0,0,0,0,0,115,101,116,32,115,105,108,101,110,99,101,32,112,97,99,107,101,116,32,115,105,122,101,0,85,115,101,115,0,0,0,0,98,114,111,107,101,110,32,101,110,99,114,121,112,116,101,100,32,109,120,102,32,102,105,108,101,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,117,120,114,97,116,101,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,50,0,0,0,115,101,103,95,100,97,116,97,32,60,61,32,115,101,103,95,102,101,97,116,117,114,101,95,100,97,116,97,95,109,97,120,91,102,101,97,116,117,114,101,95,105,100,93,0,0,0,0,115,107,105,112,95,102,97,99,116,111,114,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,32,40,109,97,120,32,37,100,41,10,0,0,0,0,0,112,99,109,95,108,120,102,0,97,99,51,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,115,97,109,112,108,101,32,102,111,114,109,97,116,58,32,37,115,46,10,0,0,0,0,0,0,0,115,101,112,97,114,97,116,101,95,109,111,111,102,0,0,0,109,97,110,100,101,108,98,114,111,116,0,0,0,0,0,0,115,101,97,115,111,110,95,110,117,109,98,101,114,0,0,0,106,32,62,32,48,0,0,0,84,104,101,32,77,97,116,114,111,115,107,97,32,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,121,101,116,32,115,117,112,112,111,114,116,32,109,117,120,105,110,103,32,37,115,10,0,0,0,0,0,0,116,0,0,0,0,0,0,0,84,84,65,49,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,49,0,0,0,102,114,97,109,101,32,115,107,105,112,32,116,104,114,101,115,104,111,108,100,0,0,0,0,121,117,118,49,48,0,0,0,65,116,32,108,101,97,115,116,32,111,110,101,32,100,101,99,97,121,32,38,32,100,101,108,97,121,32,109,117,115,116,32,98,101,32,115,101,116,46,10,0,0,0,0,0,0,0,0,101,111,98,32,60,61,32,100,101,102,97,117,108,116,95,101,111,98,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,124,50,48,124,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,102,111,114,32,66,108,117,45,114,97,121,32,109,101,100,105,97,0,0,0,0,100,118,100,0,0,0,0,0,76,101,97,102,108,101,116,32,112,97,103,101,0,0,0,0,100,101,102,97,117,108,116,0,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,0,116,112,95,111,114,105,103,32,60,32,42,116,112,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,103,101,116,32,97,32,98,108,97,110,107,32,99,97,110,118,97,115,46,10,0,0,0,0,0,0,101,120,112,114,115,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,53,48,0,0,0,115,107,105,112,95,116,104,114,101,115,104,111,108,100,0,0,109,98,109,105,45,62,105,110,116,101,114,112,95,102,105,108,116,101,114,32,61,61,32,99,109,45,62,105,110,116,101,114,112,95,102,105,108,116,101,114,0,0,0,0,0,0,0,0,112,99,109,95,98,108,117,114,97,121,0,0,0,0,0,0,49,0,0,0,0,0,0,0,117,115,101,32,111,100,109,108,32,105,110,100,101,120,0,0,37,108,108,117,0,0,0,0,110,117,108,108,115,114,99,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,112,114,101,100,95,99,111,109,109,111,110,46,104,0,0,98,119,108,32,62,61,32,48,0,0,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,98,115,102,115,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,52,57,0,0,0,100,101,99,111,100,101,32,97,116,32,49,61,32,49,47,50,44,32,50,61,49,47,52,44,32,51,61,49,47,56,32,114,101,115,111,108,117,116,105,111,110,115,0,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,112,111,108,101,115,0,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,99,109,45,62,102,114,97,109,101,95,112,97,114,97,108,108,101,108,95,100,101,99,111,100,105,110,103,95,109,111,100,101,32,124,124,32,99,109,45,62,101,114,114,111,114,95,114,101,115,105,108,105,101,110,116,95,109,111,100,101,0,0,0,0,115,99,97,110,95,111,102,102,115,101,116,0,0,0,0,0,54,52,48,120,52,56,48,0,100,101,102,97,117,108,116,0,100,101,105,110,116,101,114,108,97,99,101,32,105,110,112,117,116,32,102,114,111,109,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,0,0,0,0,0,112,101,114,105,111,100,0,0,98,115,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,0,0,0,0,0,115,105,122,101,0,0,0,0,80,67,83,95,65,71,68,54,54,95,65,77,71,95,122,111,110,101,95,52,56], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2269344);
/* memory initializer */ allocate([108,111,119,114,101,115,0,0,112,99,109,95,102,54,52,108,101,0,0,0,0,0,0,0,97,114,103,103,0,0,0,0,49,56,51,53,48,48,56,0,79,110,108,121,32,111,110,101,32,111,102,32,116,104,101,32,102,105,108,101,110,97,109,101,32,111,114,32,112,97,116,116,101,114,110,32,111,112,116,105,111,110,115,32,99,97,110,32,98,101,32,117,115,101,100,10,0,0,0,0,0,0,0,0,111,117,116,112,117,116,32,118,101,114,116,105,99,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,0,0,115,115,95,120,32,60,61,32,49,0,0,0,0,0,0,0,33,40,108,102,109,45,62,105,110,116,95,52,120,52,95,121,32,38,32,108,102,109,45,62,108,101,102,116,95,121,91,84,88,95,49,54,88,49,54,93,41,0,0,0,0,0,0,0,102,111,114,109,97,116,0,0,99,51,95,102,108,97,103,115,0,0,0,0,0,0,0,0,115,101,110,100,95,102,114,97,109,101,0,0,0,0,0,0,109,112,32,114,101,113,117,101,115,116,95,102,114,97,109,101,10,0,0,0,0,0,0,0,80,67,83,95,65,100,105,110,100,97,110,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,0,0,0,0,0,76,85,84,95,51,68,95,83,73,90,69,32,0,0,0,0,108,101,118,101,108,0,0,0,99,108,105,112,118,97,108,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,115,105,109,112,108,101,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,46,98,117,102,32,110,111,116,32,115,101,116,46,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,102,111,114,109,97,116,46,32,79,110,108,121,32,89,86,49,50,32,97,110,100,32,73,52,50,48,32,105,109,97,103,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,0,0,0,120,95,115,116,101,112,95,113,52,32,60,61,32,56,48,0,108,105,102,101,0,0,0,0,115,101,116,32,116,104,101,32,102,105,101,108,100,32,116,111,32,109,97,116,99,104,32,102,114,111,109,0,0,0,0,0,109,111,100,101,95,115,101,108,101,99,116,105,111,110,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,39,121,48,39,10,0,0,0,0,114,103,98,53,54,53,108,101,0,0,0,0,0,0,0,0,68,97,114,107,111,114,97,110,103,101,0,0,0,0,0,0,60,100,111,117,98,108,101,62,0,0,0,0,0,0,0,0,103,99,100,0,0,0,0,0,100,111,119,110,109,105,120,32,114,105,103,104,116,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,104,0,0,0,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,115,114,99,95,114,97,110,103,101,0,0,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,99,104,97,110,110,101,108,32,99,111,117,110,116,0,99,117,98,105,99,105,112,111,108,100,101,105,110,116,0,0,85,110,100,101,114,108,105,110,101,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,100,61,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,119,115,0,0,0,0,76,116,47,82,116,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,76,116,47,82,116,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,65,67,51,32,100,101,99,111,100,101,114,0,0,0,0,0,115,116,101,114,101,111,32,119,105,116,104,32,83,67,69,10,0,0,0,0,0,0,0,0,110,101,103,97,116,105,118,101,0,0,0,0,0,0,0,0,117,110,107,32,98,105,116,32,50,10,0,0,0,0,0,0,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,0,0,0,0,0,0,0,80,67,83,95,65,100,105,110,100,97,110,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,0,0,0,0,0,100,116,115,95,104,100,95,109,97,0,0,0,0,0,0,0,32,37,117,46,32,67,111,100,101,98,111,111,107,39,115,32,100,105,109,101,110,115,105,111,110,32,105,115,32,105,110,118,97,108,105,100,32,40,37,100,41,46,10,0,0,0,0,0,32,37,52,46,49,102,37,37,0,0,0,0,0,0,0,0,67,111,109,112,108,101,120,0,115,101,116,32,108,117,109,97,32,109,97,116,114,105,120,32,104,111,114,105,122,111,110,116,97,108,32,115,105,122,101,0,112,99,109,95,102,54,52,98,101,0,0,0,0,0,0,0,58,37,115,0,0,0,0,0,50,53,49,54,48,48,48,0,86,101,114,116,105,99,97,108,85,110,105,116,115,71,101,111,75,101,121,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,114,101,102,108,101,99,116,0,91,108,97,118,99,32,114,99,93,32,101,115,116,105,109,97,116,101,100,32,116,97,114,103,101,116,32,97,118,101,114,97,103,101,32,113,112,58,32,37,46,51,102,10,0,0,0,0,109,105,110,45,107,101,121,105,110,116,0,0,0,0,0,0,99,99,108,111,99,107,95,102,108,105,112,0,0,0,0,0,112,97,115,115,49,0,0,0,109,115,109,112,101,103,52,118,50,0,0,0,0,0,0,0,119,105,100,116,104,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,50,10,0,0,0,0,10,0,0,0,0,0,0,0,84,101,120,116,117,114,101,32,83,78,82,32,76,97,121,101,114,32,115,116,97,114,116,0,68,114,111,112,32,102,114,97,109,101,32,116,105,109,101,32,99,111,100,101,32,111,110,108,121,32,97,108,108,111,119,101,100,32,119,105,116,104,32,49,48,48,49,47,51,48,48,48,48,32,102,112,115,10,0,0,76,111,115,115,108,101,115,115,32,99,104,101,99,107,32,102,97,105,108,101,100,32,45,32,101,120,112,101,99,116,101,100,32,37,48,50,120,44,32,99,97,108,99,117,108,97,116,101,100,32,37,48,50,120,46,10,0,0,0,0,0,0,0,0,101,115,99,97,112,105,110,103,32,114,101,109,111,118,101,100,32,37,116,100,32,98,121,116,101,115,10,0,0,0,0,0,87,101,105,103,104,116,101,100,32,112,114,101,100,105,99,116,105,111,110,32,102,111,114,32,66,45,102,114,97,109,101,115,46,0,0,0,0,0,0,0,32,32,65,100,100,105,116,105,111,110,97,108,32,105,110,102,111,114,109,97,116,105,111,110,58,32,37,115,10,0,0,0,74,80,69,71,32,50,48,48,48,32,100,105,103,105,116,97,108,32,99,105,110,101,109,97,32,52,75,0,0,0,0,0,37,115,0,0,0,0,0,0,105,108,108,101,103,97,108,32,97,99,32,118,108,99,32,99,111,100,101,32,97,116,32,37,100,120,37,100,10,0,0,0,108,111,103,50,95,112,97,114,97,108,108,101,108,95,109,101,114,103,101,95,108,101,118,101,108,95,109,105,110,117,115,50,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,77,97,105,110,0,0,0,0,101,120,112,114,0,0,0,0,78,65,76,32,37,100,47,37,100,32,97,116,32,37,100,47,37,100,32,108,101,110,103,116,104,32,37,100,32,112,97,115,115,32,37,100,10,0,0,0,109,101,114,103,101,0,0,0,99,104,111,108,101,115,107,121,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,88,32,77,111,100,101,0,0,68,84,83,0,0,0,0,0,115,97,109,112,108,101,0,0,115,118,113,49,0,0,0,0,80,77,95,83,116,111,99,107,104,111,108,109,0,0,0,0,100,116,115,95,104,100,95,104,114,97,0,0,0,0,0,0,108,97,121,111,117,116,0,0,83,112,97,99,101,0,0,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,52,50,50,80,49,50,0,0,116,114,97,99,107,0,0,0,58,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,110,117,109,98,101,114,32,111,102,32,102,114,97,103,109,101,110,116,115,32,107,101,112,116,32,111,117,116,115,105,100,101,32,111,102,32,116,104,101,32,109,97,110,105,102,101,115,116,32,98,101,102,111,114,101,32,114,101,109,111,118,105,110,103,32,102,114,111,109,32,100,105,115,107,0,0,0,0,0,0,50,48,52,48,48,48,48,0,110,0,0,0,0,0,0,0,112,114,111,98,95,108,97,115,116,32,60,61,32,50,53,53,0,0,0,0,0,0,0,0,84,101,108,101,99,105,110,101,32,112,97,116,116,101,114,110,32,37,115,32,121,105,101,108,100,115,32,117,112,32,116,111,32,37,100,32,102,114,97,109,101,115,32,112,101,114,32,102,114,97,109,101,44,32,112,116,115,32,97,100,118,97,110,99,101,32,102,97,99,116,111,114,58,32,37,100,47,37,100,10,0,0,0,0,0,0,0,0,65,32,115,116,114,101,97,109,32,109,117,115,116,32,115,116,97,114,116,32,119,105,116,104,32,97,32,99,111,109,112,108,101,116,101,32,107,101,121,32,102,114,97,109,101,0,0,0,99,116,120,32,62,61,32,48,32,38,38,32,99,116,120,32,60,32,67,79,77,80,95,73,78,84,69,82,95,67,79,78,84,69,88,84,83,0,0,0,80,77,95,66,114,117,115,115,101,108,115,0,0,0,0,0,100,116,115,95,57,54,95,50,52,0,0,0,0,0,0,0,112,99,109,95,102,51,50,108,101,0,0,0,0,0,0,0,121,117,118,52,50,48,112,0,102,97,116,97,108,0,0,0,115,101,103,109,101,110,116,95,102,114,97,109,101,115,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,118,102,95,115,104,111,119,115,112,101,99,116,114,117,109,46,99,0,0,97,98,50,108,0,0,0,0,113,117,97,108,105,116,121,0,109,106,112,103,44,109,106,112,101,103,0,0,0,0,0,0,109,117,108,97,119,0,0,0,80,77,95,70,101,114,114,111,0,0,0,0,0,0,0,0,100,116,115,95,101,115,0,0,115,101,116,32,108,117,109,97,32,114,97,100,105,117,115,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,109,117,108,97,119,0,0,0,32,37,48,56,88,0,0,0,52,56,48,120,52,56,48,0,116,115,0,0,0,0,0,0,97,117,116,111,0,0,0,0,121,98,102,45,62,121,95,119,105,100,116,104,32,45,32,121,98,102,45,62,121,95,99,114,111,112,95,119,105,100,116,104,32,62,61,32,48,0,0,0,37,100,47,37,100,0,0,0,115,111,117,114,99,101,32,116,114,97,99,107,32,37,100,58,32,115,116,114,101,97,109,32,37,100,44,32,110,111,32,100,101,115,99,114,105,112,116,111,114,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,99,111,117,110,116,32,37,100,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,69,110,97,98,108,101,32,109,50,116,115,32,109,111,100,101,46,0,0,0,0,0,0,0,80,77,95,74,97,107,97,114,116,97,0,0,0,0,0,0,99,101,108,108,97,117,116,111,0,0,0,0,0,0,0,0,100,116,115,0,0,0,0,0,112,99,109,95,102,51,50,98,101,0,0,0,0,0,0,0,52,56,48,120,53,55,54,0,37,100,0,0,0,0,0,0,70,114,97,103,109,101,110,116,32,97,116,32,118,105,100,101,111,32,107,101,121,102,114,97,109,101,115,0,0,0,0,0,101,112,105,115,111,100,101,95,115,111,114,116,0,0,0,0,110,117,108,108,115,105,110,107,0,0,0,0,0,0,0,0,115,101,116,32,108,117,109,97,32,114,97,100,105,117,115,0,83,116,97,114,116,105,110,103,32,110,101,119,32,99,108,117,115,116,101,114,32,97,116,32,111,102,102,115,101,116,32,37,108,108,117,32,98,121,116,101,115,44,32,112,116,115,32,37,108,108,117,100,116,115,32,37,108,108,117,10,0,0,0,0,80,77,95,66,101,114,110,0,109,112,101,103,50,95,97,97,99,95,104,101,0,0,0,0,112,105,99,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,48,124,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,69,114,114,111,114,32,119,104,101,110,32,112,97,114,115,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,97,110,103,108,101,32,99,111,109,109,97,110,100,10,0,0,0,0,0,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,67,111,118,101,114,32,40,98,97,99,107,41,0,0,0,0,104,97,108,102,32,120,49,58,37,100,32,120,50,58,37,100,32,121,49,58,37,100,32,121,50,58,37,100,32,109,97,120,95,109,97,115,107,95,115,105,122,101,58,37,100,10,0,0,102,105,108,101,115,105,122,101,0,0,0,0,0,0,0,0,106,114,0,0,0,0,0,0,83,117,98,116,105,116,108,101,32,101,110,99,111,100,105,110,103,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,115,116,97,116,115,32,102,105,108,101,32,37,115,58,32,37,115,10,0,0,0,0,0,0,0,80,77,95,82,111,109,101,0,109,112,101,103,50,95,97,97,99,95,108,111,119,0,0,0,112,99,109,95,100,118,100,0,115,101,116,32,112,111,115,116,112,114,111,99,101,115,115,32,115,117,98,102,105,108,116,101,114,115,0,0,0,0,0,0,115,118,99,100,0,0,0,0,117,115,101,95,111,100,109,108,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,121,116,101,32,97,114,114,97,121,32,105,110,32,116,97,103,32,37,115,46,10,0,0,0,0,0,0,112,0,0,0,0,0,0,0,116,111,116,97,108,95,115,115,101,32,62,61,32,48,0,0,48,0,0,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,101,110,99,111,100,101,114,115,0,80,77,95,77,97,100,114,105,100,0,0,0,0,0,0,0,97,97,99,95,101,108,100,0,112,111,108,101,115,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,49,52,49,49,50,48,48,0,105,119,0,0,0,0,0,0,99,117,98,105,99,32,114,111,111,116,0,0,0,0,0,0,108,117,109,97,95,115,116,114,101,110,103,116,104,0,0,0,33,40,108,102,109,45,62,108,101,102,116,95,121,91,84,88,95,49,54,88,49,54,93,32,38,32,108,102,109,45,62,108,101,102,116,95,121,91,84,88,95,56,88,56,93,41,0,0,78,0,0,0,0,0,0,0,82,71,66,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,112,114,111,102,105,108,101,32,48,0,0,115,101,116,32,98,108,97,99,107,32,109,111,100,101,0,0,100,101,102,97,117,108,116,0,80,77,95,66,111,103,111,116,97,0,0,0,0,0,0,0,97,97,99,95,108,100,0,0,112,99,109,95,115,51,50,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,120,58,37,102,32,120,105,58,37,100,32,121,58,37,102,32,121,105,58,37,100,10,0,0,97,110,97,103,108,121,112,104,32,114,101,100,32,99,121,97,110,32,104,97,108,102,32,99,111,108,111,114,0,0,0,0,109,117,120,114,97,116,101,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,116,111,107,0,0,0,0,0,111,117,116,95,118,95,99,104,114,95,112,111,115,0,0,0,102,105,108,116,101,114,32,33,61,32,83,87,73,84,67,72,65,66,76,69,0,0,0,0,97,108,108,95,115,116,114,101,110,103,116,104,0,0,0,0,102,111,114,99,101,32,116,101,114,109,105,110,97,116,105,111,110,32,119,104,101,110,32,116,104,101,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,32,116,101,114,109,105,110,97,116,101,115,0,0,0,0,99,51,115,0,0,0,0,0,100,101,102,97,117,108,116,0,80,77,95,80,97,114,105,115,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,99,111,110,115,101,99,117,116,105,118,101,32,100,114,111,112,112,101,100,32,102,114,97,109,101,115,32,40,112,111,115,105,116,105,118,101,41,44,32,111,114,32,116,104,101,32,109,105,110,105,109,117,109,32,105,110,116,101,114,118,97,108,32,98,101,116,119,101,101,110,32,100,114,111,112,112,101,100,32,102,114,97,109,101,115,32,40,110,101,103,97,116,105,118,101,41,0,0,0,0,0,0,37,102,32,37,102,32,37,102,0,0,0,0,0,0,0,0,97,97,99,95,104,101,95,118,50,0,0,0,0,0,0,0,109,105,110,118,97,108,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,79,112,116,105,111,110,32,45,45,116,117,110,101,61,115,115,105,109,32,105,115,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,32,105,110,32,86,80,57,46,0,0,0,50,51,50,52,0,0,0,0,67,111,110,102,108,105,99,116,105,110,103,32,102,108,97,103,115,46,0,0,0,0,0,0,102,105,101,108,100,0,0,0,115,117,98,112,101,108,95,114,101,102,105,110,101,0,0,0,119,32,61,61,32,45,49,32,124,124,32,119,32,62,61,32,118,102,45,62,119,0,0,0,114,103,98,53,54,53,98,101,0,0,0,0,0,0,0,0,68,97,114,107,79,108,105,118,101,71,114,101,101,110,0,0,60,105,110,116,54,52,62,0,118,32,33,61,32,48,0,0,104,121,112,111,116,0,0,0,68,82,0,0,0,0,0,0,100,101,115,99,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,0,0,0,0,0,0,83,87,82,101,115,97,109,112,108,101,114,0,0,0,0,0,99,105,0,0,0,0,0,0,121,97,100,105,102,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,116,97,108,105,99,0,0,100,105,102,102,101,114,101,110,116,32,98,108,117,114,97,121,95,99,111,109,112,97,116,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,87,65,86,0,0,0,108,116,114,116,95,115,117,114,109,105,120,108,101,118,0,0,108,116,114,116,95,115,117,114,109,105,120,108,101,118,0,0,98,97,112,32,37,100,32,105,115,32,105,110,118,97,108,105,100,32,105,110,32,112,108,97,105,110,32,65,67,45,51,10,0,0,0,0,0,0,0,0,109,111,110,111,32,119,105,116,104,32,67,80,69,10,0,0,109,101,100,105,117,109,95,99,111,110,116,114,97,115,116,0,117,110,107,32,98,105,116,32,49,10,0,0,0,0,0,0,101,100,32,100,101,99,111,100,101,32,102,108,97,103,115,0,80,77,95,76,105,115,98,111,110,0,0,0,0,0,0,0,97,97,99,95,104,101,0,0,32,37,117,46,32,67,111,100,101,98,111,111,107,32,115,101,116,117,112,32,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,0,102,114,97,109,101,32,37,99,58,37,45,53,100,32,65,118,103,32,81,80,58,37,53,46,50,102,32,32,115,105,122,101,58,37,54,46,48,102,10,0,77,97,105,110,0,0,0,0,112,99,109,95,115,50,52,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,102,97,115,116,0,0,0,0,80,114,111,118,105,100,101,100,32,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,44,32,110,101,101,100,115,32,116,111,32,98,101,32,37,100,10,0,0,0,112,97,99,107,101,116,115,105,122,101,0,0,0,0,0,0,86,101,114,116,105,99,97,108,68,97,116,117,109,71,101,111,75,101,121,0,0,0,0,0,97,114,116,105,115,116,0,0,112,105,110,108,105,103,104,116,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,116,111,107,0,0,0,0,0,91,108,97,118,99,32,114,99,93,32,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,58,32,37,100,32,98,112,115,32,32,101,120,112,101,99,116,101,100,32,98,105,116,114,97,116,101,58,32,37,100,32,98,112,115,10,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,105,110,102,105,110,105,116,101,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,114,101,115,101,114,118,101,100,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,49,0,0,0,0,0,0,0,83,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,34,37,115,34,32,109,97,116,99,104,101,100,32,97,32,37,115,32,115,116,114,101,97,109,44,99,117,114,114,101,110,116,108,121,32,117,110,115,117,112,112,111,114,116,101,100,32,98,121,32,108,105,98,97,118,102,105,108,116,101,114,10,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,0,0,0,0,0,0,61,0,0,0,0,0,0,0,84,101,120,116,117,114,101,32,83,112,97,116,105,97,108,32,76,97,121,101,114,32,115,116,97,114,116,0,0,0,0,0,87,105,100,116,104,32,111,114,32,72,101,105,103,104,116,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,116,111,32,98,101,32,109,117,108,116,105,112,108,105,101,115,32,111,102,32,52,48,57,54,10,97,100,100,32,39,45,115,116,114,105,99,116,32,37,100,39,32,105,102,32,121,111,117,32,119,97,110,116,32,116,111,32,117,115,101,32,116,104,101,109,32,97,110,121,119,97,121,46,10,0,0,0,0,0,0,112,115,0,0,0,0,0,0,69,120,116,114,97,99,116,105,110,103,32,37,100,45,99,104,97,110,110,101,108,32,100,111,119,110,109,105,120,32,40,48,120,37,108,108,120,41,32,102,114,111,109,32,115,117,98,115,116,114,101,97,109,32,37,100,46,32,70,117,114,116,104,101,114,32,115,117,98,115,116,114,101,97,109,115,32,119,105,108,108,32,98,101,32,115,107,105,112,112,101,100,46,10,0,0,100,101,99,111,100,101,95,115,111,115,58,32,97,99,47,100,99,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,119,101,105,103,104,116,98,0,37,115,58,32,37,115,10,0,74,80,69,71,32,50,48,48,48,32,100,105,103,105,116,97,108,32,99,105,110,101,109,97,32,50,75,0,0,0,0,0,92,70,0,0,0,0,0,0,105,108,108,101,103,97,108,32,100,99,32,37,100,32,97,116,32,37,100,32,37,100,10,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,112,112,115,95,116,99,95,111,102,102,115,101,116,95,100,105,118,50,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,112,111,115,0,0,0,0,0,65,86,67,58,32,110,97,108,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,108,101,118,105,110,115,111,110,0,0,0,0,0,0,0,0,87,114,111,110,103,32,115,105,122,105,110,103,32,111,114,32,109,105,115,115,105,110,103,32,115,105,122,101,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,0,100,115,117,114,101,120,95,109,111,100,101,0,0,0,0,0,73,110,118,97,108,105,100,32,76,70,69,32,118,97,108,117,101,58,32,37,100,10,0,0,100,105,115,97,98,108,101,32,97,110,121,32,112,101,97,107,32,109,111,100,101,0,0,0,70,76,86,32,47,32,83,111,114,101,110,115,111,110,32,83,112,97,114,107,32,47,32,83,111,114,101,110,115,111,110,32,72,46,50,54,51,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,80,77,95,71,114,101,101,110,119,105,99,104,0,0,0,0,97,97,99,95,108,116,112,0,80,117,110,107,0,0,0,0,100,101,102,97,117,108,116,32,97,114,101,115,97,109,112,108,101,32,102,105,108,116,101,114,32,111,112,116,105,111,110,115,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,52,50,48,80,49,50,0,0,84,82,67,75,0,0,0,0,61,0,0,0,0,0,0,0,115,45,62,115,116,114,101,97,109,115,91,32,115,45,62,110,98,95,115,116,114,101,97,109,115,32,45,32,49,32,93,32,61,61,32,115,116,0,0,0,85,110,115,112,101,99,105,102,105,101,100,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,0,0,0,0,0,0,101,120,116,114,97,95,119,105,110,100,111,119,95,115,105,122,101,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,108,117,116,114,103,98,0,0,100,97,116,97,95,115,116,97,114,116,32,60,61,32,100,97,116,97,95,101,110,100,0,0,109,97,112,0,0,0,0,0,116,102,102,0,0,0,0,0,69,108,108,105,112,115,101,95,83,112,104,101,114,101,0,0,97,97,99,95,115,115,114,0,112,99,109,95,115,49,54,108,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,119,51,102,100,105,102,0,0,108,0,0,0,0,0,0,0,103,95,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,54,53,53,51,53,93,0,0,0,0,0,52,52,49,48,48,0,0,0,112,97,110,105,99,0,0,0,115,101,116,32,115,101,103,109,101,110,116,32,115,112,108,105,116,32,116,105,109,101,32,112,111,105,110,116,115,0,0,0,105,110,116,108,95,116,104,114,101,115,0,0,0,0,0,0,89,67,98,67,114,45,52,58,52,58,52,0,0,0,0,0,109,97,120,95,102,105,108,101,95,115,105,122,101,0,0,0,48,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,103,95,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,49,54,51,56,51,93,0,0,0,0,0,118,105,100,101,111,47,120,45,109,106,112,101,103,0,0,0,115,112,97,116,105,97,108,32,108,117,109,97,32,115,116,114,101,110,103,116,104,0,0,0,97,108,0,0,0,0,0,0,99,108,69,110,113,117,101,117,101,78,68,82,97,110,103,101,75,101,114,110,101,108,32,101,114,114,111,114,32,39,37,100,39,10,0,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,0,0,0,0,0,97,97,99,95,108,111,119,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,0,0,0,97,108,0,0,0,0,0,0,50,50,52,48,48,48,0,0,112,114,105,110,116,32,115,112,101,99,105,102,105,99,32,100,101,98,117,103,32,105,110,102,111,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,104,105,115,116,111,103,114,97,109,46,99,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,0,114,95,102,114,97,109,101,95,114,97,116,101,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,115,117,98,32,100,101,115,99,114,105,112,116,111,114,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,0,118,97,114,105,97,98,108,101,32,37,115,0,0,0,0,0,84,104,101,32,109,97,120,105,109,117,109,32,97,109,111,117,110,116,32,98,121,32,119,104,105,99,104,32,116,104,101,32,102,105,108,116,101,114,32,119,105,108,108,32,99,104,97,110,103,101,32,97,110,121,32,111,110,101,32,112,105,120,101,108,46,0,0,0,0,0,0,0,109,112,101,103,116,115,95,109,50,116,115,95,109,111,100,101,0,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,79,83,85,57,49,65,0,0,97,97,99,95,109,97,105,110,0,0,0,0,0,0,0,0,112,99,109,95,115,49,54,98,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,119,32,60,61,32,54,52,0,98,58,97,0,0,0,0,0,50,53,53,0,0,0,0,0,100,101,102,97,117,108,116,0,101,110,99,111,100,101,114,47,115,108,105,99,101,116,121,112,101,46,99,0,0,0,0,0,102,114,97,103,95,107,101,121,102,114,97,109,101,0,0,0,100,105,115,99,0,0,0,0,115,98,115,0,0,0,0,0,70,108,117,115,104,105,110,103,32,99,108,117,115,116,101,114,32,97,116,32,111,102,102,115,101,116,32,37,108,108,117,32,98,121,116,101,115,10,0,0,73,78,84,69,82,52,88,52,95,76,85,77,65,0,0,0,83,66,82,0,0,0,0,0,65,32,115,116,114,105,110,103,32,100,101,115,99,114,105,98,105,110,103,32,100,101,115,105,114,101,100,32,111,117,116,112,117,116,32,102,114,97,109,101,114,97,116,101,0,0,0,0,69,108,108,105,112,115,101,95,79,83,85,56,54,70,0,0,112,105,120,95,102,109,116,115,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,0,101,120,114,0,0,0,0,0,80,67,77,32,90,111,114,107,0,0,0,0,0,0,0,0,51,50,55,54,56,48,0,0,98,102,102,0,0,0,0,0,67,111,118,101,114,32,40,102,114,111,110,116,41,0,0,0,73,103,110,111,114,105,110,103,32,109,101,116,97,100,97,116,97,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,83,117,98,116,105,116,108,101,32,112,97,99,107,101,116,115,32,109,117,115,116,32,104,97,118,101,32,97,32,112,116,115,10,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,71,69,77,95,49,48,67,0,112,114,111,102,105,108,101,0,112,99,109,95,122,111,114,107,0,0,0,0,0,0,0,0,98,108,111,99,107,120,32,97,110,100,32,98,108,111,99,107,121,32,115,101,116,116,105,110,103,115,32,109,117,115,116,32,98,101,32,112,111,119,101,114,32,111,102,32,116,119,111,10,0,0,0,0,0,0,0,0,99,108,67,114,101,97,116,101,67,111,110,116,101,120,116,0,98,117,102,115,105,122,101,0,84,104,105,115,32,102,105,108,101,32,104,97,115,32,98,101,101,110,32,103,101,110,101,114,97,116,101,100,32,98,121,32,97,32,116,111,116,97,108,108,121,32,98,114,111,107,101,110,32,109,117,120,101,114,46,10,0,0,0,0,0,0,0,0,102,105,101,108,100,95,116,121,112,101,0,0,0,0,0,0,118,105,100,101,111,0,0,0,37,100,58,37,100,58,37,100,37,99,37,100,0,0,0,0,73,68,51,0,0,0,0,0,108,105,98,97,118,117,116,105,108,47,114,97,110,100,111,109,95,115,101,101,100,46,99,0,121,117,118,52,50,50,112,0,111,117,116,0,0,0,0,0,118,105,103,110,101,116,116,101,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,97,98,99,100,101,102,0,0,69,108,108,105,112,115,101,95,87,71,83,95,56,52,0,0,111,117,116,37,100,0,0,0,101,110,99,111,100,101,114,115,0,0,0,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,109,97,99,114,111,98,108,111,99,107,32,114,111,119,115,32,97,116,32,116,104,101,32,98,111,116,116,111,109,32,119,104,105,99,104,32,97,114,101,32,115,107,105,112,112,101,100,0,0,0,0,0,0,0,115,101,116,32,119,105,100,116,104,0,0,0,0,0,0,0,80,67,77,32,68,45,67,105,110,101,109,97,32,97,117,100,105,111,32,115,105,103,110,101,100,32,50,52,45,98,105,116,0,0,0,0,0,0,0,0,73,102,32,121,111,117,32,119,97,110,116,32,116,111,32,104,101,108,112,44,32,117,112,108,111,97,100,32,97,32,115,97,109,112,108,101,32,111,102,32,116,104,105,115,32,102,105,108,101,32,116,111,32,102,116,112,58,47,47,117,112,108,111,97,100,46,102,102,109,112,101,103,46,111,114,103,47,77,80,108,97,121,101,114,47,105,110,99,111,109,105,110,103,47,32,97,110,100,32,99,111,110,116,97,99,116,32,116,104,101,32,102,102,109,112,101,103,45,100,101,118,101,108,32,109,97,105,108,105,110,103,32,108,105,115,116,46,10,0,0,0,0,0,0,97,98,115,40,100,115,116,95,108,105,110,101,115,105,122,101,41,32,62,61,32,98,121,116,101,119,105,100,116,104,0,0,82,73,80,69,77,68,50,53,54,0,0,0,0,0,0,0,99,111,109,109,111,110,47,102,114,97,109,101,46,99,0,0,109,105,110,114,97,116,101,0,108,0,0,0,0,0,0,0,115,109,112,116,101,49,55,48,109,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,39,41,39,32,111,114,32,116,111,111,32,109,97,110,121,32,97,114,103,115,32,105,110,32,39,37,115,39,10,0,0,0,108,111,119,0,0,0,0,0,73,110,116,101,114,110,97,108,32,98,117,103,44,32,115,104,111,117,108,100,32,110,111,116,32,104,97,118,101,32,104,97,112,112,101,110,101,100,0,0,99,98,114,0,0,0,0,0,41,0,0,0,0,0,0,0,118,102,108,105,112,0,0,0,115,101,116,112,116,115,0,0,100,101,115,99,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,66,117,102,102,101,114,32,37,100,32,100,111,101,115,32,110,111,116,32,99,111,110,116,97,105,110,32,97,32,100,101,99,111,100,101,100,32,102,114,97,109,101,0,0,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,98,108,97,99,107,0,0,0,115,101,116,32,109,111,108,100,32,99,111,108,111,114,0,0,37,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,97,115,32,105,110,112,117,116,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,97,115,116,32,98,105,108,105,110,101,97,114,0,0,0,48,0,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,32,110,111,116,32,97,118,97,105,108,97,98,108,101,32,97,116,32,116,104,105,115,32,115,97,109,112,108,105,110,103,32,114,97,116,101,44,32,117,115,105,110,103,32,116,114,105,97,110,103,117,108,97,114,32,104,112,32,100,105,116,104,101,114,10,0,120,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,87,97,114,95,79,102,102,105,99,101,0,0,0,0,0,0,98,32,61,61,32,49,32,124,124,32,98,32,61,61,32,51,0,0,0,0,0,0,0,0,115,107,105,112,95,98,111,116,116,111,109,0,0,0,0,0,111,115,114,0,0,0,0,0,112,99,109,95,115,50,52,100,97,117,100,0,0,0,0,0,33,115,45,62,32,105,110,95,99,104,95,108,97,121,111,117,116,32,124,124,32,105,110,32,45,62,99,104,95,99,111,117,110,116,32,61,61,32,97,118,95,103,101,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,95,110,98,95,99,104,97,110,110,101,108,115,40,115,45,62,32,105,110,95,99,104,95,108,97,121,111,117,116,41,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,66,117,116,116,101,114,119,111,114,116,104,32,102,105,108,116,101,114,32,99,117,114,114,101,110,116,108,121,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,108,111,119,45,112,97,115,115,32,102,105,108,116,101,114,32,109,111,100,101,10,0,0,0,0,0,0,0,0,97,114,99,104,0,0,0,0,109,97,120,114,97,116,101,0,105,99,99,95,112,97,114,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,115,45,62,108,97,115,116,95,112,105,99,116,117,114,101,91,105,93,45,62,100,97,116,97,91,48,93,32,33,61,32,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,45,62,100,97,116,97,91,48,93,0,0,0,0,0,0,105,110,112,117,116,32,104,111,114,105,122,111,110,116,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,0,0,0,0,0,0,79,114,105,32,120,44,32,65,118,103,32,120,44,32,70,105,110,32,120,44,32,79,114,105,32,121,44,32,65,118,103,32,121,44,32,70,105,110,32,121,44,32,79,114,105,32,97,110,103,108,101,44,32,65,118,103,32,97,110,103,108,101,44,32,70,105,110,32,97,110,103,108,101,44,32,79,114,105,32,122,111,111,109,44,32,65,118,103,32,122,111,111,109,44,32,70,105,110,32,122,111,111,109,10,0,0,0,0,0,0,0,0,84,85,80,76,84,89,80,69,0,0,0,0,0,0,0,0,115,45,62,113,117,97,114,116,101,114,95,115,97,109,112,108,101,61,61,48,32,124,124,32,115,45,62,113,117,97,114,116,101,114,95,115,97,109,112,108,101,61,61,49,0,0,0,0,121,0,0,0,0,0,0,0,83,112,101,99,105,97,108,32,109,111,100,101,115,32,115,117,112,112,111,114,116,0,0,0,87,97,114,110,105,110,103,32,77,86,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,0,82,101,100,117,99,101,100,32,115,97,109,112,108,105,110,103,32,114,97,116,101,0,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,70,97,105,108,101,100,32,116,111,32,114,101,97,108,108,111,99,97,116,101,32,115,99,97,108,101,100,32,108,97,115,116,32,115,111,117,114,99,101,32,98,117,102,102,101,114,0,0,33,97,102,113,45,62,102,114,97,109,101,95,99,111,117,110,116,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,103,97,105,110,32,108,111,99,97,116,105,111,110,58,32,99,104,61,37,100,44,32,115,98,61,37,100,44,32,112,111,115,61,37,100,44,32,118,97,108,61,37,100,10,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,115,101,116,32,77,80,108,97,121,101,114,32,102,105,108,116,101,114,32,110,97,109,101,32,97,110,100,32,112,97,114,97,109,101,116,101,114,115,0,0,92,99,37,49,91,92,125,93,37,110,0,0,0,0,0,0,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,97,120,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,110,111,32,101,110,100,32,116,97,103,32,102,111,117,110,100,46,32,105,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,46,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,69,108,108,105,112,115,101,95,83,116,114,117,118,101,95,49,56,54,48,0,0,0,0,0,97,100,112,99,109,95,109,115,0,0,0,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,69,79,70,10,0,110,117,109,98,101,114,32,111,102,32,109,97,99,114,111,98,108,111,99,107,32,114,111,119,115,32,97,116,32,116,104,101,32,116,111,112,32,119,104,105,99,104,32,97,114,101,32,115,107,105,112,112,101,100,0,0,109,97,120,118,97,108,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,98,108,111,99,107,120,32,97,110,100,32,98,108,111,99,107,121,32,115,101,116,116,105,110,103,115,32,109,117,115,116,32,98,101,32,112,111,119,101,114,32,111,102,32,116,119,111,10,0,0,0,0,0,0,0,0,99,113,95,108,101,118,101,108,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,48,46,46,54,51,93,0,0,0,97,100,112,99,109,95,99,116,0,0,0,0,0,0,0,0,49,49,53,48,48,48,48,0,116,115,95,108,97,121,101,114,95,105,100,91,105,93,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,99,102,103,45,62,116,115,95,110,117,109,98,101,114,95,108,97,121,101,114,115,45,49,93,0,98,0,0,0,0,0,0,0,115,101,116,32,110,111,105,115,101,32,115,105,103,109,97,32,99,111,110,115,116,97,110,116,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,67,82,70,32,109,97,120,32,109,117,115,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,67,82,70,10,0,0,0,0,0,0,0,108,116,114,116,95,115,117,114,114,111,117,110,100,95,109,105,120,95,108,101,118,101,108,0,85,110,107,110,111,119,110,32,70,111,117,114,67,67,58,32,37,88,10,0,0,0,0,0,109,97,114,107,32,109,97,105,110,32,105,110,112,117,116,32,97,115,32,97,32,112,114,101,45,112,114,111,99,101,115,115,101,100,32,105,110,112,117,116,32,97,110,100,32,97,99,116,105,118,97,116,101,32,99,108,101,97,110,32,115,111,117,114,99,101,32,105,110,112,117,116,32,115,116,114,101,97,109,0,104,105,101,114,97,114,99,104,105,99,97,108,95,109,111,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2279584);
/* memory initializer */ allocate([105,111,110,0,0,0,0,0,100,105,102,102,32,62,61,32,48,32,38,38,32,100,105,102,102,32,60,61,32,49,50,48,0,0,0,0,0,0,0,0,114,103,98,52,56,108,101,0,68,97,114,107,77,97,103,101,110,116,97,0,0,0,0,0,60,105,110,116,62,0,0,0,114,97,110,100,111,109,0,0,100,111,119,110,109,105,120,32,108,101,102,116,0,0,0,0,51,0,0,0,0,0,0,0,101,120,112,101,114,105,109,101,110,116,97,108,0,0,0,0,100,115,116,95,102,111,114,109,97,116,0,0,0,0,0,0,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,44,32,37,102,10,0,115,45,62,100,105,116,104,101,114,46,110,111,105,115,101,46,99,104,95,99,111,117,110,116,32,61,61,32,112,114,101,111,117,116,45,62,99,104,95,99,111,117,110,116,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,52,120,109,46,99,0,0,0,0,0,0,0,0,116,114,97,110,115,112,97,114,101,110,99,121,0,0,0,0,108,105,110,105,112,111,108,100,101,105,110,116,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,119,111,114,107,32,98,117,102,102,101,114,46,10,0,0,0,0,66,108,111,99,107,32,115,105,122,101,32,37,105,120,37,105,0,0,0,0,0,0,0,0,73,110,102,108,97,116,101,32,102,97,105,108,101,100,32,119,105,116,104,32,114,101,116,117,114,110,32,99,111,100,101,58,32,37,100,46,10,0,0,0,70,105,108,101,32,112,114,111,98,97,98,108,121,32,99,111,114,114,117,112,116,10,0,0,66,111,108,100,0,0,0,0,98,108,117,114,97,121,95,99,111,109,112,97,116,61,37,100,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,114,111,109,97,32,98,108,111,99,107,32,112,111,115,105,116,105,111,110,10,0,0,97,100,112,99,109,95,105,109,97,95,119,97,118,0,0,0,76,116,47,82,116,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,76,116,47,82,116,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,112,105,120,102,111,114,109,97,116,32,37,100,44,32,112,105,120,100,101,112,116,104,32,37,100,44,32,98,117,110,105,116,32,37,100,44,32,98,105,116,111,114,100,101,114,32,37,100,44,32,98,112,97,100,32,37,100,10,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,98,105,116,32,97,108,108,111,99,97,116,105,111,110,10,0,0,0,0,0,0,0,0,78,111,32,115,117,98,116,105,116,108,101,32,98,105,116,109,97,112,32,97,118,97,105,108,97,98,108,101,46,10,0,0,78,117,109,98,101,114,32,111,102,32,98,97,110,100,115,32,40,37,100,41,32,101,120,99,101,101,100,115,32,108,105,109,105,116,32,40,37,100,41,46,10,0,0,0,0,0,0,0,108,105,110,101,97,114,95,99,111,110,116,114,97,115,116,0,118,108,99,32,108,101,110,103,116,104,32,111,118,101,114,102,108,111,119,10,0,0,0,0,115,116,97,116,105,99,32,117,110,115,105,103,110,101,100,32,99,104,97,114,32,105,109,97,103,101,95,98,105,116,115,91,93,32,61,32,123,10,0,0,85,110,101,120,112,101,99,116,101,100,32,112,114,101,112,114,111,99,101,115,115,111,114,32,100,105,114,101,99,116,105,118,101,10,0,0,0,0,0,0,32,37,115,32,61,32,37,120,10,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,80,108,101,115,115,105,115,95,49,56,49,55,0,0,0,0,78,111,32,112,97,108,101,116,116,101,32,102,111,117,110,100,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,87,78,86,49,32,102,114,97,109,101,32,104,101,97,100,101,114,32,118,97,108,117,101,32,37,105,0,0,0,0,0,0,115,107,105,112,95,116,111,112,0,0,0,0,0,0,0,0,86,111,114,98,105,115,32,116,105,109,101,32,100,111,109,97,105,110,32,116,114,97,110,115,102,111,114,109,32,100,97,116,97,32,110,111,110,122,101,114,111,46,32,10,0,0,0,0,102,114,97,109,101,32,37,99,58,37,45,53,100,32,65,118,103,32,81,80,58,37,53,46,50,102,32,32,115,105,122,101,58,37,54,46,48,102,32,32,80,83,78,82,32,77,101,97,110,32,89,58,37,53,46,50,102,32,85,58,37,53,46,50,102,32,86,58,37,53,46,50,102,32,65,118,103,58,37,53,46,50,102,32,71,108,111,98,97,108,58,37,53,46,50,102,10,0,0,0,0,0,0,0,83,105,109,112,108,101,0,0,114,108,58,37,100,32,114,108,99,58,37,100,32,100,99,58,37,100,32,109,118,58,37,100,32,109,98,114,108,58,37,100,32,113,112,58,37,100,32,109,115,112,101,108,58,37,100,32,112,101,114,95,109,98,95,97,98,116,58,37,100,32,97,98,116,95,116,121,112,101,58,37,100,32,99,98,112,58,37,100,32,105,105,58,37,100,10,0,10,0,0,0,0,0,0,0,112,99,109,95,117,50,52,98,101,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,32,86,76,67,32,99,111,100,101,44,32,115,107,105,112,112,105,110,103,10,0,0,110,98,95,115,97,109,112,108,101,115,32,40,37,100,41,32,33,61,32,102,114,97,109,101,95,115,105,122,101,32,40,37,100,41,32,40,97,118,99,111,100,101,99,95,101,110,99,111,100,101,95,97,117,100,105,111,50,41,10,0,0,0,0,0,102,114,97,109,101,91,37,105,93,32,119,111,117,108,100,32,104,97,118,101,32,116,111,32,115,107,105,112,32,37,105,32,98,105,116,115,10,0,0,0,80,97,99,107,101,116,32,108,111,115,115,32,100,101,116,101,99,116,101,100,33,32,115,101,113,32,37,120,32,118,115,32,37,120,10,0,0,0,0,0,49,56,0,0,0,0,0,0,86,101,114,116,105,99,97,108,67,105,116,97,116,105,111,110,71,101,111,75,101,121,0,0,44,32,0,0,0,0,0,0,13,10,0,0,0,0,0,0,112,104,111,101,110,105,120,0,65,76,80,72,65,32,99,104,117,110,107,32,112,114,101,115,101,110,116,44,32,98,117,116,32,97,108,112,104,97,32,98,105,116,32,110,111,116,32,115,101,116,32,105,110,32,116,104,101,32,86,80,56,88,32,104,101,97,100,101,114,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,116,111,111,98,105,103,32,60,61,32,52,48,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,99,104,97,110,110,101,108,115,32,99,111,100,101,100,32,105,110,32,97,32,112,97,99,107,101,116,46,10,0,84,104,114,101,115,104,111,108,100,32,98,101,108,111,119,32,119,104,105,99,104,32,116,104,101,32,112,105,120,101,108,32,105,115,32,99,111,110,115,105,100,101,114,101,100,32,98,108,97,99,107,0,0,0,0,0,112,99,109,95,115,49,54,108,101,0,0,0,0,0,0,0,112,114,111,98,108,101,109,58,32,102,111,117,110,100,32,97,32,112,97,108,101,116,116,101,32,99,104,117,110,107,32,119,105,116,104,32,37,100,32,99,111,108,111,114,115,10,0,0,107,101,121,105,110,116,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,85,110,107,110,111,119,110,32,112,114,111,102,105,108,101,32,37,100,10,0,0,0,0,0,118,112,54,97,0,0,0,0,97,108,119,97,121,115,32,116,114,121,32,97,32,109,98,32,119,105,116,104,32,109,118,61,60,48,44,48,62,0,0,0,109,115,109,112,101,103,52,118,49,0,0,0,0,0,0,0,100,105,100,32,110,111,116,32,109,97,116,99,104,32,97,110,121,32,115,116,114,101,97,109,0,0,0,0,0,0,0,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,49,54,10,0,0,0,0,0,0,63,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,117,102,102,109,97,110,32,116,97,98,108,101,10,0,0,83,116,105,108,108,32,84,101,120,116,117,114,101,32,79,98,106,101,99,116,32,115,116,97,114,116,0,0,0,0,0,0,87,105,100,116,104,32,47,32,72,101,105,103,104,116,32,105,115,32,105,110,118,97,108,105,100,32,102,111,114,32,77,80,69,71,50,10,0,0,0,0,83,0,0,0,0,0,0,0,114,99,45,62,116,121,112,101,32,61,61,32,50,0,0,0,69,120,116,114,97,99,116,105,110,103,32,37,100,45,99,104,97,110,110,101,108,32,100,111,119,110,109,105,120,32,102,114,111,109,32,115,117,98,115,116,114,101,97,109,32,37,100,46,32,70,117,114,116,104,101,114,32,115,117,98,115,116,114,101,97,109,115,32,119,105,108,108,32,98,101,32,115,107,105,112,112,101,100,46,10,0,0,0,65,86,82,110,32,105,110,116,101,114,108,97,99,101,100,32,112,105,99,116,117,114,101,32,109,97,114,107,101,114,32,102,111,117,110,100,10,0,0,0,83,101,116,117,112,32,104,101,97,100,101,114,32,99,111,114,114,117,112,116,46,10,0,0,78,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,116,111,32,108,111,111,107,32,97,104,101,97,100,32,102,111,114,32,102,114,97,109,101,116,121,112,101,32,97,110,100,32,114,97,116,101,99,111,110,116,114,111,108,0,0,0,0,86,80,57,69,95,83,69,84,95,70,82,65,77,69,95,80,65,82,65,76,76,69,76,95,68,69,67,79,68,73,78,71,0,0,0,0,0,0,0,0,87,114,111,110,103,32,112,97,99,107,101,116,32,116,121,112,101,32,105,110,32,83,101,116,117,112,32,104,101,97,100,101,114,10,0,0,0,0,0,0,74,80,69,71,32,50,48,48,48,32,110,111,32,99,111,100,101,115,116,114,101,97,109,32,114,101,115,116,114,105,99,116,105,111,110,115,0,0,0,0,80,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,100,97,116,97,33,32,40,110,101,101,100,32,37,105,32,103,111,116,32,37,105,41,10,0,0,0,0,0,0,0,0,32,37,53,100,0,0,0,0,115,107,105,112,112,105,110,103,32,115,109,97,108,108,32,106,117,110,107,32,112,97,99,107,101,116,10,0,0,0,0,0,98,121,116,101,115,116,114,101,97,109,95,101,110,100,32,45,32,98,121,116,101,115,116,114,101,97,109,32,62,61,32,52,32,43,32,97,118,99,116,120,45,62,119,105,100,116,104,0,112,112,115,95,98,101,116,97,95,111,102,102,115,101,116,95,100,105,118,50,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,107,101,121,0,0,0,0,0,110,97,108,95,108,101,110,103,116,104,95,115,105,122,101,0,119,109,118,51,105,109,97,103,101,0,0,0,0,0,0,0,105,119,0,0,0,0,0,0,102,105,120,101,100,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,37,100,0,0,76,111,47,82,111,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,76,70,69,83,99,97,108,101,73,110,100,101,120,32,108,97,114,103,101,114,32,116,104,97,110,32,49,50,55,0,0,0,110,111,110,101,0,0,0,0,70,65,83,84,85,86,77,67,32,117,110,97,118,97,105,108,97,98,108,101,32,105,110,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,10,0,102,108,118,49,0,0,0,0,73,110,118,97,108,105,100,32,67,111,100,101,10,0,0,0,80,97,108,101,116,116,101,32,100,97,116,97,32,114,117,110,115,32,98,101,121,111,110,100,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,0,118,52,49,48,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,44,32,99,111,110,116,105,110,117,105,110,103,32,97,110,121,119,97,121,46,10,0,0,0,0,0,69,108,108,105,112,115,101,95,78,87,76,95,49,48,68,0,83,83,69,51,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,110,115,115,101,32,119,101,105,103,104,116,0,0,0,0,0,118,50,49,48,120,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,83,111,117,108,0,0,0,0,118,50,49,48,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,10,0,0,97,114,101,115,97,109,112,108,101,95,115,119,114,95,111,112,116,115,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,100,10,0,0,0,0,0,0,0,52,52,52,80,49,48,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,102,111,114,32,102,114,97,109,101,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,115,105,110,103,101,114,0,0,115,114,99,0,0,0,0,0,80,114,111,99,101,115,115,105,110,103,32,99,111,109,109,97,110,100,32,116,105,109,101,58,37,102,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,10,0,0,0,115,45,62,110,98,95,115,116,114,101,97,109,115,62,48,0,110,117,109,98,101,114,32,111,102,32,102,114,97,103,109,101,110,116,115,32,107,101,112,116,32,105,110,32,116,104,101,32,109,97,110,105,102,101,115,116,0,0,0,0,0,0,0,0,49,53,0,0,0,0,0,0,73,110,99,111,110,115,105,115,116,101,110,116,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,117,114,97,116,105,111,110,46,10,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,100,51,100,32,102,111,114,109,97,116,32,40,37,48,56,120,41,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,105,10,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,111,114,109,97,116,10,0,73,110,118,97,108,105,100,32,113,117,97,110,116,105,115,101,114,115,32,37,100,32,47,32,37,100,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,117,110,115,104,97,114,112,0,71,111,116,32,37,105,32,116,111,107,101,110,115,32,102,111,114,32,37,105,32,98,108,111,99,107,115,10,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,32,40,37,100,41,10,0,0,0,0,0,0,0,114,103,0,0,0,0,0,0,69,110,99,111,100,101,32,115,116,114,105,112,32,102,97,105,108,101,100,10,0,0,0,0,103,115,0,0,0,0,0,0,69,108,108,105,112,115,101,95,78,87,76,95,57,68,0,0,110,115,115,101,119,0,0,0,112,99,109,95,117,50,52,108,101,0,0,0,0,0,0,0,103,0,0,0,0,0,0,0,113,117,105,101,116,0,0,0,82,97,100,105,117,115,32,111,102,32,116,104,101,32,108,117,109,97,32,98,108,117,114,114,105,110,103,32,98,111,120,0,115,101,103,109,101,110,116,95,116,105,109,101,115,0,0,0,89,67,98,67,114,45,52,58,50,58,50,0,0,0,0,0,71,101,111,103,67,105,116,97,116,105,111,110,71,101,111,75,101,121,0,0,0,0,0,0,102,114,97,109,101,95,115,105,122,101,0,0,0,0,0,0,37,115,37,51,105,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,85,110,107,110,111,119,110,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,71,101,111,84,73,70,70,32,107,101,121,32,37,100,10,0,0,112,106,115,0,0,0,0,0,0,0,0,0,0,0,0,0,84,82,85,69,86,73,83,73,79,78,45,88,70,73,76,69,46,0,0,0,0,0,0,0,66,105,116,32,100,101,112,116,104,32,37,105,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,100,97,116,97,32,116,121,112,101,58,32,37,100,10,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,66,45,102,114,97,109,101,32,112,105,99,116,117,114,101,32,105,100,10,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,46,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,110,118,97,108,105,100,32,40,99,111,109,112,114,101,115,115,105,111,110,41,32,116,121,112,101,10,0,0,0,0,0,91,98,114,93,0,0,0,0,79,110,108,121,32,83,85,66,84,73,84,76,69,95,65,83,83,32,116,121,112,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,123,92,102,115,125,0,0,0,114,97,119,32,77,74,80,69,71,32,118,105,100,101,111,0,108,105,98,97,118,99,111,100,101,99,47,115,110,111,119,101,110,99,46,99,0,0,0,0,73,110,118,97,108,105,100,32,114,101,102,10,0,0,0,0,77,74,80,69,71,32,99,111,100,101,99,32,110,111,116,32,102,111,117,110,100,10,0,0,119,97,114,110,105,110,103,58,32,98,108,111,99,107,32,99,111,117,110,116,101,114,32,106,117,115,116,32,119,101,110,116,32,110,101,103,97,116,105,118,101,32,40,116,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,41,10,0,0,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,56,107,53,0,0,0,0,0,105,110,100,101,120,32,60,32,99,116,120,45,62,109,97,120,95,115,122,32,45,32,49,0,73,110,99,114,101,97,115,105,110,103,32,98,108,111,99,107,32,115,105,122,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,80,67,77,32,65,45,108,97,119,0,0,0,0,0,0,0,119,114,111,110,103,32,99,104,97,110,110,101,108,32,110,117,109,98,101,114,10,0,0,0,69,108,108,105,112,115,101,95,75,114,97,115,115,111,119,115,107,121,95,49,57,52,48,0,105,110,99,111,114,114,101,99,116,32,112,97,108,101,116,116,101,32,99,104,97,110,103,101,32,98,108,111,99,107,32,115,105,122,101,32,37,100,10,0,105,110,116,114,97,95,100,99,95,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,62,0,0,0,0,0,0,0,101,110,99,111,100,105,110,103,32,97,115,32,50,52,32,98,105,116,115,45,112,101,114,45,115,97,109,112,108,101,10,0,67,104,97,110,103,105,110,103,32,100,105,109,101,110,115,105,111,110,115,32,116,111,32,37,100,120,37,100,10,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,73,110,99,111,114,114,101,99,116,32,77,66,32,116,121,112,101,32,99,111,100,101,10,0,80,67,77,32,65,45,108,97,119,0,0,0,0,0,0,0,115,45,62,97,108,116,95,105,110,116,101,114,95,118,108,99,32,61,61,32,48,0,0,0,82,101,97,108,86,105,100,101,111,32,50,46,48,0,0,0,119,97,114,110,105,110,103,58,32,98,108,111,99,107,32,99,111,117,110,116,101,114,32,106,117,115,116,32,119,101,110,116,32,110,101,103,97,116,105,118,101,32,40,116,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,41,10,0,0,0,0,0,87,97,114,110,105,110,103,58,32,100,105,109,101,110,115,105,111,110,115,32,110,111,116,32,112,111,119,101,114,32,111,102,32,116,119,111,10,0,0,0,87,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,92,78,0,0,0,0,0,0,51,53,50,120,50,52,48,0,108,105,98,97,118,99,111,100,101,99,47,114,97,119,100,101,99,46,99,0,0,0,0,0,102,100,101,98,117,103,0,0,112,84,101,120,0,0,0,0,116,111,111,32,115,104,111,114,116,32,112,97,99,107,101,116,115,32,97,114,101,32,116,111,111,32,115,104,111,114,116,33,10,0,0,0,0,0,0,0,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,97,118,114,112,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,104,97,115,32,101,114,114,111,114,115,44,32,97,110,100,32,67,32,108,105,115,116,32,105,115,32,110,111,116,32,101,109,112,116,121,0,0,0,0,0,87,114,111,110,103,32,100,97,116,97,32,105,110,32,114,101,115,101,114,118,101,100,32,102,114,97,109,101,32,97,114,101,97,46,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,10,0,0,0,0,0,0,118,101,110,100,111,114,32,73,68,32,115,104,111,117,108,100,32,98,101,32,52,32,98,121,116,101,115,10,0,0,0,0,68,105,115,112,111,115,105,116,105,111,110,0,0,0,0,0,105,110,118,97,108,105,100,32,100,97,116,97,32,115,105,122,101,10,0,0,0,0,0,0,98,108,97,99,107,95,109,105,110,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,112,105,99,116,117,114,101,32,104,101,97,100,101,114,10,0,0,112,112,109,0,0,0,0,0,98,112,112,32,124,124,32,33,112,114,101,100,0,0,0,0,105,110,102,108,97,116,101,73,110,105,116,32,114,101,116,117,114,110,101,100,32,101,114,114,111,114,32,37,100,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,68,101,99,111,100,101,100,32,37,100,32,112,105,120,101,108,115,44,32,119,104,101,110,32,108,105,110,101,32,115,104,111,117,108,100,32,98,101,32,37,100,32,112,105,120,101,108,115,10,0,0,0,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,80,67,88,32,100,97,116,97,32,105,115,32,99,111,114,114,117,112,116,101,100,10,0,0,73,110,118,97,108,105,100,32,101,100,105,116,32,114,97,116,101,32,40,37,100,47,37,100,41,32,102,111,117,110,100,32,111,110,32,115,116,114,101,97,109,32,35,37,100,44,32,100,101,102,97,117,108,116,105,110,103,32,116,111,32,50,53,47,49,10,0,0,0,0,0,0,79,80,84,73,77,73,90,69,68,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,80,67,77,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,101,116,32,116,104,101,32,102,105,114,115,116,32,112,105,100,46,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,71,82,65,89,83,67,65,76,69,95,65,76,80,72,65,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,69,108,108,105,112,115,101,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,49,57,54,55,0,0,0,0,0,0,100,99,0,0,0,0,0,0,112,99,109,95,115,50,52,98,101,0,0,0,0,0,0,0,115,97,114,0,0,0,0,0,51,53,50,120,50,56,56,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,113,117,101,117,101,46,104,0,0,0,0,0,0,0,37,115,32,112,114,111,102,105,108,101,32,100,111,101,115,110,39,116,32,115,117,112,112,111,114,116,32,52,58,50,58,50,10,0,0,0,0,0,0,0,77,97,107,101,32,116,104,101,32,105,110,105,116,105,97,108,32,109,111,111,118,32,97,116,111,109,32,101,109,112,116,121,32,40,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,81,117,105,99,107,84,105,109,101,41,0,0,0,48,0,0,0,0,0,0,0,116,114,97,99,107,0,0,0,101,114,114,111,114,32,100,117,114,105,110,103,32,108,122,111,32,100,101,99,111,109,112,114,101,115,115,105,111,110,10,0,83,79,70,32,100,97,116,97,32,100,101,99,111,100,101,32,101,114,114,111,114,10,0,0,100,105,109,101,110,115,105,111,110,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,73,110,118,97,108,105,100,32,113,117,97,108,105,116,121,32,115,101,116,116,105,110,103,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,32,43,37,100,44,37,100,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,105,109,101,115,116,97,109,112,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,112,97,115,115,101,100,0,0,0,0,0,0,69,114,114,111,114,32,115,116,114,105,112,112,105,110,103,32,97,32,87,97,118,80,97,99,107,32,112,97,99,107,101,116,46,10,0,0,0,0,0,0,69,110,99,111,100,101,114,32,118,101,114,115,105,111,110,32,37,100,46,37,100,10,0,0,77,83,32,82,76,69,32,119,97,114,110,105,110,103,58,32,110,111,32,101,110,100,45,111,102,45,112,105,99,116,117,114,101,32,99,111,100,101,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,123,92,98,49,125,0,0,0,116,114,97,110,115,112,111,115,101,0,0,0,0,0,0,0,115,116,114,105,99,116,95,103,111,112,0,0,0,0,0,0,69,108,108,105,112,115,101,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,49,57,50,52,0,0,0,0,0,0,105,109,97,103,101,50,32,100,101,109,117,120,101,114,0,0,109,97,99,114,111,98,108,111,99,107,32,116,104,114,101,115,104,111,108,100,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,97,32,112,105,99,116,117,114,101,46,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,112,120,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,109,112,50,0,0,0,0,0,79,116,104,101,114,32,102,105,108,101,32,105,99,111,110,0,111,117,116,112,117,116,115,0,77,80,69,71,45,52,32,112,97,114,116,32,50,0,0,0,117,110,116,101,115,116,101,100,10,0,0,0,0,0,0,0,77,80,69,71,45,49,32,118,105,100,101,111,0,0,0,0,100,97,116,97,115,116,114,101,97,109,0,0,0,0,0,0,109,112,101,103,118,105,100,101,111,0,0,0,0,0,0,0,109,97,120,98,97,110,100,115,32,37,100,32,116,111,111,32,104,105,103,104,10,0,0,0,115,117,98,98,97,110,100,32,105,110,100,101,120,32,105,110,118,97,108,105,100,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,111,111,32,109,97,110,121,32,99,111,100,101,115,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,101,120,112,114,0,0,0,0,44,32,100,114,111,112,112,105,110,103,32,105,116,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,32,111,114,32,99,111,114,114,117,112,116,32,112,97,114,116,105,116,105,111,110,32,0,0,83,116,114,101,97,109,32,112,97,114,97,109,101,116,101,114,115,32,110,111,116,32,115,101,101,110,59,32,115,107,105,112,112,105,110,103,32,102,114,97,109,101,46,10,0,0,0,0,97,118,99,116,120,45,62,99,111,100,101,99,45,62,112,114,105,118,95,100,97,116,97,95,115,105,122,101,32,61,61,32,115,105,122,101,111,102,40,77,112,101,103,69,110,99,67,111,110,116,101,120,116,41,0,0,100,113,116,58,32,105,110,118,97,108,105,100,32,112,114,101,99,105,115,105,111,110,10,0,115,101,99,111,110,100,95,102,105,101,108,100,95,111,102,102,115,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,69,108,108,105,112,115,101,95,73,110,100,111,110,101,115,105,97,110,95,78,97,116,105,111,110,97,108,95,83,112,104,101,114,111,105,100,0,0,0,0,82,101,115,111,108,117,116,105,111,110,32,99,104,97,110,103,105,110,103,0,0,0,0,0,109,98,95,116,104,114,101,115,104,111,108,100,0,0,0,0,92,78,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,105,10,0,0,0,0,0,112,99,109,95,115,50,52,108,101,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,108,111,99,111,46,99,0,0,0,0,0,0,0,73,110,99,111,109,112,97,116,105,98,108,101,32,112,105,120,101,108,32,102,111,114,109,97,116,32,39,37,115,39,32,102,111,114,32,99,111,100,101,99,32,39,37,115,39,44,32,97,117,116,111,45,115,101,108,101,99,116,105,110,103,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,0,109,111,100,101,108,0,0,0,112,114,101,115,101,116,0,0,87,77,47,80,105,99,116,117,114,101,0,0,0,0,0,0,37,115,10,0,0,0,0,0,68,101,102,108,97,116,101,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,108,101,110,32,37,100,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,76,97,103,97,114,105,116,104,32,102,114,97,109,101,32,116,121,112,101,58,32,37,35,120,10,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,32,39,37,115,39,10,0,0,0,0,0,0,0,68,97,116,97,32,111,118,101,114,114,117,110,10,0,0,0,74,80,69,71,32,112,97,114,97,109,115,58,32,73,76,86,61,37,105,32,80,116,61,37,105,32,66,80,80,61,37,105,44,32,115,99,97,110,32,61,32,37,105,10,0,0,0,0,84,114,97,110,115,102,111,114,109,115,32,109,105,115,109,97,116,99,104,44,32,77,67,84,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,108,105,98,97,118,99,111,100,101,99,47,106,112,101,103,50,48,48,48,46,99,0,0,0,100,101,102,97,117,108,116,0,86,84,0,0,0,0,0,0,97,102,116,101,114,32,100,119,116,32,45,62,32,116,105,101,114,49,10,0,0,0,0,0,67,111,108,111,114,32,112,108,97,110,101,115,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,100,32,121,101,116,10,0,0,0,0,0,0,0,101,120,112,114,0,0,0,0,32,76,79,78,71,0,0,0,109,111,116,105,111,110,32,111,102,102,115,101,116,32,60,32,48,32,40,37,100,41,10,0,83,65,67,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,69,108,108,105,112,115,101,95,72,101,108,109,101,114,116,95,49,57,48,54,0,0,0,0,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,69,109,112,116,121,32,109,97,99,114,111,98,108,111,99,107,32,105,110,32,97,110,32,73,78,84,82,65,32,112,105,99,116,117,114,101,33,10,0,0,114,101,102,95,109,98,32,117,110,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,115,101,116,32,102,114,101,113,117,101,110,99,121,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,73,110,118,97,108,105,100,32,86,81,95,78,85,76,76,32,99,111,100,101,58,32,37,100,10,0,0,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,100,101,99,111,100,101,114,115,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,89,85,89,50,32,111,117,116,112,117,116,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,10,0,0,0,0,0,119,114,105,116,101,111,102,102,115,101,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,66,79,84,84,79,77,32,70,105,101,108,100,10,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,114,101,102,32,119,105,116,104,32,80,79,67,32,37,100,10,0,118,112,115,95,114,101,115,101,114,118,101,100,95,116,104,114,101,101,95,50,98,105,116,115,32,105,115,32,110,111,116,32,116,104,114,101,101,10,0,0,115,113,117,97,114,101,32,114,111,111,116,0,0,0,0,0,115,101,116,32,99,111,109,109,97,110,100,115,0,0,0,0,112,108,97,110,101,32,37,100,32,45,32,99,111,114,114,101,99,116,32,0,0,0,0,0,98,108,97,99,107,0,0,0,102,111,114,99,101,32,67,70,82,32,102,111,114,32,105,110,112,117,116,32,102,114,111,109,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,99,104,101,99,107,101,114,98,111,97,114,100,95,108,114,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,115,116,114,101,97,109,32,112,114,111,102,105,108,101,0,0,0,115,101,116,32,105,110,110,101,114,32,99,111,108,111,114,105,110,103,32,109,111,100,101,0,97,98,115,95,100,105,102,102,95,112,105,99,95,110,117,109,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,109,111,108,100,95,99,111,108,111,114,0,0,0,0,0,0,105,108,108,101,103,97,108,32,98,105,116,32,100,101,112,116,104,32,118,97,108,117,101,32,40,37,100,44,32,37,100,41,10,0,0,0,0,0,0,0,110,111,110,45,101,120,105,115,116,105,110,103,32,83,80,83,32,37,117,32,114,101,102,101,114,101,110,99,101,100,10,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,102,111,114,32,97,110,32,105,110,116,114,97,32,80,67,77,32,98,108,111,99,107,46,10,0,0,0,0,0,0,0,0,108,101,102,116,32,98,108,111,99,107,32,117,110,97,118,97,105,108,97,98,108,101,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,105,110,116,114,97,32,109,111,100,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,82,101,118,101,114,116,105,110,103,32,112,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,115,32,99,104,97,110,103,101,32,100,117,101,32,116,111,32,104,101,97,100,101,114,32,100,101,99,111,100,105,110,103,32,102,97,105,108,117,114,101,10,0,0,0,0,0,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,46,102,46,112,105,99,116,95,116,121,112,101,32,61,61,32,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,95,112,116,114,45,62,102,46,112,105,99,116,95,116,121,112,101,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,69,108,108,105,112,115,101,95,71,82,83,95,49,57,56,48,0,0,0,0,0,0,0,0,112,105,99,116,117,114,101,32,100,111,101,115,110,39,116,32,104,97,118,101,32,101,105,116,104,101,114,32,103,108,111,98,97,108,32,111,114,32,108,111,99,97,108,32,112,97,108,101,116,116,101,46,10,0,0,0,109,101,95,116,104,114,101,115,104,111,108,100,0,0,0,0,71,73,70,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,54,53,53,51,53,120,54,53,53,51,53,10,0,0,0,0,0,71,46,55,50,57,68,32,64,32,54,46,52,107,98,105,116,47,115,0,0,0,0,0,0,112,99,109,95,117,51,50,98,101,0,0,0,0,0,0,0,70,114,97,109,101,32,105,110,118,97,108,105,100,108,121,32,115,112,108,105,116,44,32,109,105,115,115,105,110,103,32,112,97,114,115,101,114,63,10,0,66,105,116,114,97,116,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,121,101,116,44,32,117,115,101,32,54,46,51,107,10,0,0,0,0,82,101,113,117,101,115,116,101,100,32,116,114,101,108,108,105,115,32,118,97,108,117,101,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,32,85,115,105,110,103,32,37,100,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,66,105,116,115,32,112,101,114,32,71,55,50,50,32,99,111,100,101,119,111,114,100,0,0,71,50,77,50,32,97,110,100,32,71,50,77,51,32,97,114,101,32,110,111,116,32,121,101,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,70,105,101,108,100,32,115,105,122,101,32,37,105,32,105,115,32,116,111,111,32,115,109,97,108,108,32,40,114,101,113,117,105,114,101,100,32,37,105,41,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,108,101,110,103,116,104,32,37,100,32,40,115,104,111,117,108,100,32,98,101,32,37,100,41,10,0,97,110,97,103,108,121,112,104,32,114,101,100,32,99,121,97,110,32,103,114,97,121,0,0,70,76,86,32,47,32,83,111,114,101,110,115,111,110,32,83,112,97,114,107,32,47,32,83,111,114,101,110,115,111,110,32,72,46,50,54,51,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,80,114,105,110,116,32,104,101,108,112,32,47,32,105,110,102,111,114,109,97,116,105,111,110,32,47,32,99,97,112,97,98,105,108,105,116,105,101,115,58,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,117,110,107,95,115,105,122,101,32,61,32,37,117,32,62,32,102,114,97,109,101,95,115,105,122,101,32,61,32,37,117,10,0,0,0,0,0,0,73,110,112,117,116,32,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,44,32,105,110,112,117,116,32,109,117,115,116,32,98,101,32,109,97,120,32,52,48,57,54,120,52,48,57,54,32,33,10,0,0,0,0,0,0,49,46,50,46,53,0,0,0,101,110,99,111,100,105,110,103,32,97,115,32,50,52,32,98,105,116,115,45,112,101,114,45,115,97,109,112,108,101,10,0,115,107,105,112,105,110,103,32,118,111,114,98,105,115,32,99,111,109,109,101,110,116,10,0,105,110,95,104,95,99,104,114,95,112,111,115,0,0,0,0,99,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,119,114,97,112,32,98,117,102,102,101,114,32,111,102,32,115,105,122,101,32,37,100,0,0,0,0,0,0,115,97,109,112,108,101,47,102,114,97,109,101,32,110,117,109,98,101,114,32,105,110,118,97,108,105,100,59,32,117,116,102,56,32,102,115,99,107,101,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,70,73,67,32,72,101,97,100,101,114,46,10,0,0,0,0,109,111,100,101,0,0,0,0,37,100,10,0,0,0,0,0,83,108,105,99,101,32,112,111,105,110,116,101,114,32,99,104,97,105,110,32,98,114,111,107,101,110,10,0,0,0,0,0,86,101,114,115,105,111,110,32,37,100,0,0,0,0,0,0,70,114,97,109,101,32,35,37,100,44,32,37,115,10,0,0,68,105,109,101,110,115,105,111,110,115,32,115,104,111,117,108,100,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,116,119,111,46,10,0,0,0,0,0,0,0,0,105,110,116,101,114,32,102,114,97,109,101,32,119,105,116,104,111,117,116,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,105,110,116,114,97,32,102,114,97,109,101,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,116,105,110,116,101,114,108,97,99,101,0,0,0,0,0,0,69,45,65,67,45,51,32,69,110,99,111,100,101,114,0,0,110,98,95,105,110,112,117,116,115,0,0,0,0,0,0,0,110,111,32,115,108,105,99,101,32,100,97,116,97,10,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,102,111,114,99,101,32,112,97,99,107,101,100,32,82,71,66,32,105,110,32,105,110,112,117,116,32,97,110,100,32,111,117,116,112,117,116,32,40,100,101,112,114,101,99,97,116,101,100,41,0,0,0,0,0,0,0,70,111,117,110,100,32,110,111,32,68,86,32,112,114,111,102,105,108,101,32,102,111,114,32,37,105,120,37,105,32,37,115,32,118,105,100,101,111,46,32,86,97,108,105,100,32,68,86,32,112,114,111,102,105,108,101,115,32,97,114,101,58,10,0,70,97,105,108,101,100,32,116,111,32,114,101,97,108,108,111,99,97,116,101,32,115,99,97,108,101,100,32,115,111,117,114,99,101,32,98,117,102,102,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2289824);
/* memory initializer */ allocate([114,0,0,0,0,0,0,0,32,48,120,37,48,54,120,64,64,37,48,50,120,32,40,48,120,37,120,44,48,120,37,120,41,0,0,0,0,0,0,0,112,97,108,101,116,116,101,58,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,98,106,101,99,116,32,108,111,99,97,116,105,111,110,33,32,37,100,45,37,100,32,37,100,45,37,100,32,37,48,50,120,10,0,0,0,0,0,0,99,51,95,115,116,114,101,110,103,116,104,0,0,0,0,0,82,76,69,32,111,118,101,114,114,101,97,100,10,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,58,32,37,100,10,0,0,0,0,0,0,102,105,108,116,101,114,0,0,68,80,88,32,109,97,114,107,101,114,32,110,111,116,32,102,111,117,110,100,10,0,0,0,115,111,108,95,100,112,99,109,0,0,0,0,0,0,0,0,118,105,100,101,111,32,112,97,114,97,109,101,116,101,114,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,68,78,120,72,68,46,32,86,97,108,105,100,32,68,78,120,72,68,32,112,114,111,102,105,108,101,115,58,10,0,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,100,32,37,100,44,32,99,117,114,32,102,105,101,108,100,32,37,100,10,0,0,0,0,68,101,108,97,121,32,102,114,97,109,101,32,111,118,101,114,102,108,111,119,10,0,0,0,69,108,108,105,112,115,101,95,69,118,101,114,101,115,116,95,49,56,51,48,95,77,111,100,105,102,105,101,100,0,0,0,66,105,116,100,101,112,116,104,32,103,114,101,97,116,101,114,32,116,104,97,110,32,56,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,105,110,32,40,37,100,41,32,111,114,32,111,117,116,32,40,37,100,41,10,0,0,0,0,97,117,116,111,100,101,116,101,99,116,32,97,32,115,117,105,116,97,98,108,101,32,110,117,109,98,101,114,32,111,102,32,116,104,114,101,97,100,115,32,116,111,32,117,115,101,0,0,67,79,80,89,0,0,0,0,112,101,97,107,95,99,98,32,60,61,32,48,0,0,0,0,104,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,109,111,100,101,32,37,100,10,0,0,0,0,0,0,0,0,103,111,116,32,97,32,98,117,102,102,101,114,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,119,104,101,110,32,37,100,32,119,101,114,101,32,101,120,112,101,99,116,101,100,10,0,0,0,0,0,0,0,101,114,114,111,114,32,100,117,114,105,110,103,32,122,108,105,98,32,100,101,99,111,109,112,114,101,115,115,105,111,110,10,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,89,85,86,32,98,121,116,101,32,111,114,100,101,114,33,10,0,0,0,0,97,114,110,114,95,116,121,112,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,51,93,0,0,0,102,114,97,109,101,32,115,117,98,112,97,99,107,101,116,32,115,105,122,101,32,116,111,116,97,108,32,62,32,97,118,99,116,120,45,62,98,108,111,99,107,95,97,108,105,103,110,33,10,0,0,0,0,0,0,0,118,99,100,0,0,0,0,0,116,115,95,114,97,116,101,95,100,101,99,105,109,97,116,111,114,32,102,97,99,116,111,114,115,32,97,114,101,32,110,111,116,32,112,111,119,101,114,115,32,111,102,32,50,0,0,0,10,10,32,32,84,114,117,101,32,112,101,97,107,58,10,32,32,32,32,80,101,97,107,58,32,32,32,32,32,32,37,53,46,49,102,32,100,66,70,83,0,0,0,0,0,0,0,0,112,112,115,114,99,0,0,0,119,101,105,103,104,116,112,95,104,112,101,108,0,0,0,0,114,103,98,52,56,98,101,0,68,97,114,107,75,104,97,107,105,0,0,0,0,0,0,0,60,102,108,97,103,115,62,0,112,114,105,110,116,0,0,0,68,76,0,0,0,0,0,0,115,101,116,32,116,104,101,32,98,111,120,32,116,104,105,99,107,110,101,115,115,0,0,0,98,105,99,117,98,105,99,32,115,112,108,105,110,101,0,0,115,111,117,114,99,101,32,102,111,114,109,97,116,0,0,0,115,45,62,105,110,46,112,108,97,110,97,114,0,0,0,0,100,101,102,97,117,108,116,0,109,112,101,103,118,105,100,101,111,95,120,118,109,99,0,0,108,105,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,115,119,97,112,112,101,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,68,105,116,104,101,114,32,116,121,112,101,0,0,0,0,0,105,32,62,61,32,115,105,122,101,0,0,0,0,0,0,0,66,97,99,107,67,111,108,111,117,114,0,0,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,108,111,97,100,105,110,103,32,112,97,108,101,116,116,101,10,0,0,0,98,108,117,114,97,121,95,99,111,109,112,97,116,61,0,0,65,68,80,67,77,32,73,77,65,32,76,111,107,105,32,83,68,76,32,77,74,80,69,71,0,0,0,0,0,0,0,0,115,116,99,32,48,120,37,48,50,120,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,108,116,114,116,95,99,109,105,120,108,101,118,0,0,0,0,105,110,118,97,108,105,100,32,111,102,102,115,101,116,32,37,100,32,100,117,114,105,110,103,32,67,57,51,32,100,101,99,111,100,105,110,103,10,0,0,108,116,114,116,95,99,109,105,120,108,101,118,0,0,0,0,100,101,108,116,97,32,98,105,116,32,97,108,108,111,99,97,116,105,111,110,32,115,116,114,97,116,101,103,121,32,114,101,115,101,114,118,101,100,10,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,108,101,110,103,116,104,10,0,0,101,120,112,101,99,116,101,100,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,10,0,0,0,0,0,0,100,101,99,111,100,101,95,98,97,110,100,95,116,121,112,101,115,58,32,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,0,108,105,103,104,116,101,114,0,112,116,114,32,111,118,101,114,102,108,111,119,32,105,110,32,114,101,97,100,95,104,117,102,102,109,97,110,95,116,97,98,108,101,115,10,0,0,0,0,66,117,102,102,101,114,32,97,117,100,105,111,32,102,114,97,109,101,115,44,32,97,110,100,32,109,97,107,101,32,116,104,101,109,32,97,99,99,101,115,115,105,98,108,101,32,116,111,32,116,104,101,32,102,105,108,116,101,114,99,104,97,105,110,46,0,0,0,0,0,0,0,110,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,40,37,100,32,60,32,37,100,41,44,32,116,114,121,105,110,103,32,116,111,32,100,101,99,111,100,101,32,97,110,121,119,97,121,10,0,0,0,0,0,101,100,32,115,97,109,112,108,101,32,98,105,116,32,100,101,112,116,104,0,0,0,0,0,69,108,108,105,112,115,101,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,55,53,95,68,101,102,105,110,105,116,105,111,110,0,0,0,0,110,98,95,99,111,100,101,115,32,43,32,49,32,60,61,32,40,115,105,122,101,111,102,40,108,111,99,97,108,98,117,102,41,32,47,32,115,105,122,101,111,102,40,40,108,111,99,97,108,98,117,102,41,91,48,93,41,41,0,0,0,0,0,0,105,100,102,0,0,0,0,0,116,104,114,101,97,100,115,0,37,100,32,98,105,116,115,32,108,101,102,116,32,105,110,32,112,97,99,107,101,116,32,37,88,10,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,102,108,111,111,114,48,32,100,101,99,58,32,98,111,111,107,110,117,109,98,101,114,32,116,111,111,32,104,105,103,104,33,10,0,0,0,0,0,0,0,101,110,99,111,100,101,114,47,101,110,99,111,100,101,114,46,99,0,0,0,0,0,0,0,111,100,100,32,115,112,114,105,116,101,115,32,115,117,112,112,111,114,116,0,0,0,0,0,85,110,107,110,111,119,110,32,98,108,111,99,107,32,116,121,112,101,32,37,100,10,0,0,112,99,109,95,117,51,50,108,101,0,0,0,0,0,0,0,65,115,112,101,99,116,58,32,37,105,58,37,105,10,0,0,70,114,97,109,101,32,108,97,114,103,101,114,32,116,104,97,110,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,0,0,0,24,65,80,82,71,65,80,82,71,48,48,48,49,0,0,0,0,0,0,0,0,109,111,114,101,32,115,97,109,112,108,101,115,32,116,104,97,110,32,102,114,97,109,101,32,115,105,122,101,32,40,97,118,99,111,100,101,99,95,101,110,99,111,100,101,95,97,117,100,105,111,50,41,10,0,0,0,108,111,119,114,101,115,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,32,119,105,116,104,32,114,97,119,118,105,100,101,111,10,0,0,0,115,105,122,101,60,61,48,120,55,102,102,102,102,102,102,102,32,38,38,32,112,32,45,32,112,107,116,45,62,100,97,116,97,32,62,61,32,115,105,122,101,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,117,110,105,116,32,101,120,116,101,110,115,105,111,110,0,0,111,114,32,115,101,116,32,97,32,102,114,97,109,101,114,97,116,101,32,119,105,116,104,32,34,45,114,32,120,120,120,34,46,10,0,0,0,0,0,0,86,101,114,116,105,99,97,108,67,83,84,121,112,101,71,101,111,75,101,121,0,0,0,0,74,83,32,109,111,110,111,32,83,111,117,110,100,32,85,110,105,116,32,105,100,32,33,61,32,51,46,10,0,0,0,0,73,110,118,97,108,105,100,32,71,101,111,84,73,70,70,32,107,101,121,32,37,100,10,0,85,110,115,117,112,112,111,114,116,101,100,32,98,108,111,99,107,32,97,108,105,103,110,46,0,0,0,0,0,0,0,0,99,111,100,101,100,32,99,111,101,102,102,32,112,97,116,116,101,114,110,32,100,97,109,97,103,101,100,10,0,0,0,0,111,118,101,114,108,97,121,0,79,110,108,121,32,83,85,66,84,73,84,76,69,95,65,83,83,32,116,121,112,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,65,83,83,32,112,97,99,107,101,116,10,0,0,0,0,0,102,105,108,116,101,114,95,115,105,122,101,32,37,32,50,32,61,61,32,49,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,112,101,100,101,99,46,99,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,114,101,110,100,105,116,105,111,110,32,112,97,114,97,109,101,116,101,114,0,85,110,107,110,111,119,110,32,111,112,99,111,100,101,0,0,69,110,99,111,117,110,116,101,114,101,100,32,97,32,98,97,100,32,111,114,32,99,111,114,114,117,112,116,101,100,32,102,114,97,109,101,10,0,0,0,78,111,116,101,58,32,108,105,98,111,112,101,110,99,111,114,101,95,97,109,114,110,98,32,115,117,112,112,111,114,116,115,32,100,116,120,10,0,0,0,100,112,98,45,115,105,122,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,100,97,116,97,46,10,0,0,100,101,110,111,105,115,101,114,0,0,0,0,0,0,0,0,109,118,48,0,0,0,0,0,105,108,108,101,103,97,108,32,77,86,32,99,111,100,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,109,97,116,99,104,101,100,32,111,110,108,121,32,97,108,114,101,97,100,121,32,117,115,101,100,32,115,116,114,101,97,109,115,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,80,69,71,45,50,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,49,54,51,56,51,120,49,54,51,56,51,10,0,0,32,0,0,0,0,0,0,0,77,101,115,104,32,79,98,106,101,99,116,32,80,108,97,110,101,32,115,116,97,114,116,0,67,114,101,97,116,105,111,110,84,105,109,101,0,0,0,0,79,110,108,121,32,72,105,103,104,40,49,41,32,97,110,100,32,52,58,50,58,50,40,48,41,32,112,114,111,102,105,108,101,115,32,115,117,112,112,111,114,116,32,52,58,50,58,50,32,99,111,108,111,114,32,115,97,109,112,108,105,110,103,10,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,83,117,98,115,116,114,101,97,109,32,109,105,110,32,99,104,97,110,110,101,108,32,99,97,110,110,111,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,109,97,120,32,99,104,97,110,110,101,108,46,10,0,0,0,0,0,0,115,45,62,112,105,99,116,117,114,101,95,112,116,114,32,61,61,32,115,45,62,112,105,99,116,117,114,101,0,0,0,0,109,111,110,111,0,0,0,0,99,104,37,100,0,0,0,0,114,99,45,108,111,111,107,97,104,101,97,100,0,0,0,0,86,80,57,69,95,83,69,84,95,84,73,76,69,95,82,79,87,83,0,0,0,0,0,0,74,80,69,71,32,50,48,48,48,32,99,111,100,101,115,116,114,101,97,109,32,114,101,115,116,114,105,99,116,105,111,110,32,49,0,0,0,0,0,0,92,67,0,0,0,0,0,0,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,104,101,105,103,104,116,115,46,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,114,101,118,95,115,101,108,101,99,116,101,100,95,110,0,68,105,115,99,111,0,0,0,105,115,32,97,118,99,0,0,108,105,98,97,118,102,111,114,109,97,116,47,102,108,97,99,95,112,105,99,116,117,114,101,46,99,0,0,0,0,0,0,110,111,110,101,0,0,0,0,77,105,115,115,105,110,103,32,99,104,97,110,110,101,108,32,108,105,115,116,10,0,0,0,65,117,116,104,111,114,0,0,108,111,114,111,95,115,117,114,109,105,120,108,101,118,0,0,74,111,105,110,116,32,115,116,101,114,101,111,32,99,111,100,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,109,111,100,101,0,0,0,0,73,68,51,0,0,0,0,0,97,117,116,104,111,114,0,0,73,110,116,101,108,32,72,46,50,54,51,0,0,0,0,0,65,68,84,83,32,102,114,97,109,101,32,115,105,122,101,32,116,111,111,32,108,97,114,103,101,58,32,37,117,32,40,109,97,120,32,37,100,41,10,0,1,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,54,55,95,68,101,102,105,110,105,116,105,111,110,0,0,0,0,99,117,114,114,101,110,116,95,116,114,97,99,107,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,101,114,114,111,114,0,0,0,66,97,115,115,0,0,0,0,100,101,102,97,117,108,116,32,115,99,97,108,101,32,102,105,108,116,101,114,32,111,112,116,105,111,110,115,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,52,50,50,80,49,48,0,0,89,85,86,52,77,80,69,71,50,0,0,0,0,0,0,0,73,103,110,111,114,101,32,108,101,110,103,116,104,0,0,0,83,73,78,71,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,58,32,37,100,10,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,120,109,118,46,99,0,0,0,0,0,0,0,84,104,105,115,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,97,32,115,105,110,103,108,101,32,87,97,118,80,97,99,107,32,115,116,114,101,97,109,46,10,0,0,0,0,0,0,67,111,112,121,105,110,103,32,100,97,116,97,32,105,110,32,97,118,102,105,108,116,101,114,46,10,0,0,0,0,0,0,65,102,116,101,114,32,97,118,102,111,114,109,97,116,95,102,105,110,100,95,115,116,114,101,97,109,95,105,110,102,111,40,41,32,112,111,115,58,32,37,108,108,100,32,98,121,116,101,115,32,114,101,97,100,58,37,108,108,100,32,115,101,101,107,115,58,37,100,32,102,114,97,109,101,115,58,37,100,10,0,85,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,32,37,48,51,88,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,105,116,108,101,0,0,0,119,105,110,100,111,119,95,115,105,122,101,0,0,0,0,0,80,108,101,97,115,101,32,112,114,101,102,105,120,32,116,97,114,103,101,116,32,119,105,116,104,32,34,112,97,108,45,34,44,32,34,110,116,115,99,45,34,32,111,114,32,34,102,105,108,109,45,34,44,10,0,0,110,97,114,0,0,0,0,0,32,110,111,116,101,58,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,115,101,101,110,32,40,37,99,37,99,37,99,37,99,41,10,0,0,0,10,0,0,0,0,0,0,0,87,69,66,86,84,84,0,0,32,32,100,111,121,116,115,99,104,58,32,37,115,10,0,0,116,105,108,101,0,0,0,0,83,111,110,121,32,87,97,118,101,54,52,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,37,100,58,37,100,58,37,100,46,37,100,37,99,37,110,0,68,73,83,67,78,85,77,66,69,82,0,0,0,0,0,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,0,99,111,100,101,100,32,108,101,110,103,116,104,32,105,115,32,109,111,114,101,32,116,104,97,110,32,116,119,111,32,98,121,116,101,115,10,0,0,0,0,46,46,47,0,0,0,0,0,117,110,107,110,111,119,110,0,116,105,116,108,101,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,37,100,10,0,0,0,0,0,0,73,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,32,105,115,32,110,111,116,32,109,97,112,112,101,100,32,116,111,32,97,110,121,32,115,108,97,118,101,46,10,0,0,0,115,116,97,114,116,79,102,80,97,114,97,103,114,97,112,104,0,0,0,0,0,0,0,0,77,68,53,61,0,0,0,0,83,87,70,32,40,83,104,111,99,107,87,97,118,101,32,70,108,97,115,104,41,32,40,65,86,77,50,41,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,51,55,95,65,100,106,117,115,116,109,101,110,116,0,0,0,0,91,98,114,93,0,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,32,111,114,32,99,111,114,114,117,112,116,32,112,97,114,116,105,116,105,111,110,32,0,0,37,100,0,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,119,104,105,99,104,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,32,105,110,116,111,32,116,104,101,32,114,99,32,98,117,102,102,101,114,32,98,101,102,111,114,101,32,100,101,99,111,100,105,110,103,32,115,116,97,114,116,115,0,37,100,10,37,48,50,100,58,37,48,50,100,58,37,48,50,100,44,37,48,51,100,32,45,45,62,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,44,37,48,51,100,0,0,97,117,116,111,45,105,110,115,101,114,116,105,110,103,32,102,105,108,116,101,114,32,39,37,115,39,32,98,101,116,119,101,101,110,32,116,104,101,32,102,105,108,116,101,114,32,39,37,115,39,32,97,110,100,32,116,104,101,32,102,105,108,116,101,114,32,39,37,115,39,10,0,37,42,100,58,37,42,50,100,58,37,42,50,100,37,42,49,91,44,46,93,37,42,51,100,32,45,45,62,32,37,42,100,58,37,42,50,100,58,37,42,50,100,37,42,49,91,44,46,93,37,51,100,0,0,0,0,112,99,109,95,115,51,50,98,101,0,0,0,0,0,0,0,99,111,100,101,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,73,110,118,97,108,105,100,32,65,65,67,32,112,97,99,107,101,116,32,105,110,32,73,69,67,32,54,49,57,51,55,10,0,0,0,0,0,0,0,0,116,114,117,110,99,97,116,105,110,103,32,102,114,97,99,116,105,111,110,97,108,32,112,97,114,116,32,111,102,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,102,41,10,0,37,115,47,70,114,97,103,109,101,110,116,73,110,102,111,40,37,115,61,37,108,108,117,41,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,37,100,0,0,0,0,0,0,116,114,101,101,115,105,122,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,100,101,116,101,114,109,105,110,101,32,110,111,114,109,32,40,80,65,76,47,78,84,83,67,47,78,84,83,67,45,70,105,108,109,41,32,102,111,114,32,116,97,114,103,101,116,46,10,0,0,0,0,0,0,70,105,110,105,115,104,101,100,32,115,112,108,105,116,116,105,110,103,32,116,104,101,32,99,111,109,109,97,110,100,108,105,110,101,46,10,0,0,0,0,115,101,116,32,97,112,112,114,111,120,105,109,97,116,105,111,110,32,118,97,108,117,101,32,117,115,101,100,32,102,111,114,32,116,104,101,32,115,101,103,109,101,110,116,32,116,105,109,101,115,0,0,0,0,0,0,89,67,98,67,114,45,52,58,50,58,48,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,100,101,102,97,117,108,116,0,109,106,112,101,103,0,0,0,97,108,97,119,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,83,71,65,95,49,57,50,50,0,0,0,0,116,104,117,109,98,110,97,105,108,0,0,0,0,0,0,0,114,99,95,105,110,105,116,95,111,99,99,117,112,97,110,99,121,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,97,108,97,119,0,0,0,0,78,84,83,67,0,0,0,0,109,97,120,32,109,101,109,111,114,121,32,117,115,101,100,32,102,111,114,32,98,117,102,102,101,114,105,110,103,32,114,101,97,108,45,116,105,109,101,32,102,114,97,109,101,115,0,0,105,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,100,32,102,111,114,32,105,110,102,111,32,112,97,99,107,101,116,10,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,115,116,114,101,97,109,10,0,0,0,0,0,0,78,85,77,95,76,79,79,80,83,0,0,0,0,0,0,0,109,112,101,103,116,115,95,115,116,97,114,116,95,112,105,100,0,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,65,114,99,0,112,114,111,98,95,105,110,116,114,97,32,62,61,32,48,0,110,111,105,115,101,32,114,101,100,117,99,116,105,111,110,0,112,99,109,95,115,51,50,108,101,0,0,0,0,0,0,0,80,65,76,0,0,0,0,0,101,109,112,116,121,95,109,111,111,118,0,0,0,0,0,0,110,101,116,119,111,114,107,0,37,42,91,94,44,93,44,37,100,58,37,100,58,37,100,37,42,99,37,100,44,37,100,58,37,100,58,37,100,37,42,99,37,100,0,0,0,0,0,0,86,95,81,85,73,67,75,84,73,77,69,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,82,71,83,0,103,105,102,0,0,0,0,0,110,114,0,0,0,0,0,0,106,50,107,0,0,0,0,0,80,67,77,32,65,45,108,97,119,32,47,32,71,46,55,49,49,32,65,45,108,97,119,0,65,115,115,117,109,105,110,103,32,37,115,32,102,111,114,32,116,97,114,103,101,116,46,10,0,0,0,0,0,0,0,0,51,50,120,51,50,32,112,105,120,101,108,115,32,39,102,105,108,101,32,105,99,111,110,39,0,0,0,0,0,0,0,0,97,117,100,105,111,99,111,100,101,99,105,100,0,0,0,0,83,117,98,116,105,116,108,101,32,100,117,114,97,116,105,111,110,32,114,101,100,117,99,101,100,32,102,114,111,109,32,37,100,32,116,111,32,37,100,37,115,10,0,0,0,0,0,0,116,101,108,101,99,105,110,101,0,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,73,71,78,0,109,97,120,105,109,117,109,32,76,97,103,114,97,110,103,101,32,102,97,99,116,111,114,32,40,86,66,82,41,0,0,0,112,99,109,95,97,108,97,119,0,0,0,0,0,0,0,0,102,105,108,109,45,0,0,0,109,97,107,101,114,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,115,119,97,112,117,118,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,56,48,95,66,101,110,111,105,116,0,0,0,0,0,0,108,109,97,120,0,0,0,0,119,0,0,0,0,0,0,0,80,67,77,32,109,117,45,108,97,119,32,47,32,71,46,55,49,49,32,109,117,45,108,97,119,0,0,0,0,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,0,0,0,0,0,0,0,0,100,101,99,111,100,101,114,115,0,0,0,0,0,0,0,0,110,116,115,99,45,0,0,0,115,113,117,0,0,0,0,0,115,101,116,32,99,111,108,111,114,0,0,0,0,0,0,0,58,102,114,97,109,101,95,114,97,116,101,61,37,100,47,37,100,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,109,97,114,107,101,114,0,0,0,0,105,110,110,101,114,0,0,0,98,108,97,99,107,0,0,0,115,117,112,101,114,50,120,115,97,105,0,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,54,54,95,77,105,99,104,105,103,97,110,0,0,0,0,109,105,110,105,109,117,109,32,76,97,103,114,97,110,103,101,32,102,97,99,116,111,114,32,40,86,66,82,41,0,0,0,112,99,109,95,109,117,108,97,119,0,0,0,0,0,0,0,97,114,99,103,0,0,0,0,112,97,108,45,0,0,0,0,105,110,112,117,116,32,118,101,114,116,105,99,97,108,32,99,104,114,111,109,97,32,112,111,115,105,116,105,111,110,32,105,110,32,108,117,109,97,32,103,114,105,100,47,50,53,54,0,114,103,98,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,108,108,111,99,97,116,101,32,108,97,115,116,32,102,114,97,109,101,32,98,117,102,102,101,114,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,110,111,105,115,101,32,115,101,101,100,0,0,0,0,0,113,117,101,114,121,32,37,88,10,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,54,54,0,0,0,0,0,105,110,32,97,110,100,32,111,117,116,32,109,117,115,116,32,98,101,32,100,101,102,105,110,101,100,10,0,0,0,0,0,108,109,105,110,0,0,0,0,119,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,97,114,110,114,95,115,116,114,101,110,103,116,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,54,93,0,0,0,0,0,0,0,0,50,52,48,48,48,47,49,48,48,49,0,0,0,0,0,0,116,115,95,114,97,116,101,95,100,101,99,105,109,97,116,111,114,91,99,102,103,45,62,116,115,95,110,117,109,98,101,114,95,108,97,121,101,114,115,45,49,93,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,49,93,0,0,51,45,119,97,121,32,109,97,116,99,104,32,43,32,52,116,104,47,53,116,104,32,109,97,116,99,104,101,115,32,111,110,32,99,111,109,98,101,100,32,40,112,47,99,47,110,32,43,32,117,47,98,41,0,0,0,119,101,105,103,104,116,112,95,115,99,97,108,101,100,95,105,109,97,103,101,115,0,0,0,118,100,112,97,117,95,118,99,49,0,0,0,0,0,0,0,68,97,114,107,71,114,101,101,110,0,0,0,0,0,0,0,37,45,49,50,115,32,0,0,112,111,119,0,0,0,0,0,116,111,112,32,98,97,99,107,32,114,105,103,104,116,0,0,115,101,116,32,99,111,108,111,114,32,111,102,32,116,104,101,32,98,111,120,0,0,0,0,115,105,110,99,0,0,0,0,115,114,99,95,102,111,114,109,97,116,0,0,0,0,0,0,115,45,62,109,105,100,98,117,102,46,99,104,95,99,111,117,110,116,32,61,61,32,115,45,62,111,117,116,46,99,104,95,99,111,117,110,116,0,0,0,117,115,101,32,79,112,101,110,67,76,32,102,105,108,116,101,114,105,110,103,32,99,97,112,97,98,105,108,105,116,105,101,115,0,0,0,0,0,0,0,108,105,110,98,108,101,110,100,100,101,105,110,116,0,0,0,80,114,105,109,97,114,121,67,111,108,111,117,114,0,0,0,100,105,102,102,101,114,101,110,116,32,111,112,101,110,95,103,111,112,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,0,97,100,112,99,109,95,105,109,97,95,115,109,106,112,101,103,0,0,0,0,0,0,0,0,76,111,47,82,111,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,76,111,47,82,111,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,110,101,119,32,99,111,117,112,108,105,110,103,32,108,101,97,107,32,105,110,102,111,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,97,110,100,32,116,121,112,101,10,0,0,0,0,0,0,105,110,99,114,101,97,115,101,95,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,97,116,97,32,105,110,32,114,101,97,100,95,104,117,102,102,109,97,110,95,116,97,98,108,101,115,10,0,0,0,0,32,37,115,32,61,32,37,100,10,0,0,0,0,0,0,0,69,108,108,105,112,115,101,95,67,108,97,114,107,101,95,49,56,53,56,0,0,0,0,0,115,99,101,110,101,32,99,104,97,110,103,101,32,116,104,114,101,115,104,111,108,100,0,0,85,110,107,110,111,119,110,32,84,104,101,111,114,97,32,99,111,110,102,105,103,32,112,97,99,107,101,116,58,32,37,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,108,111,111,114,32,116,121,112,101,33,10,0,0,0,0,104,45,62,116,104,114,101,97,100,91,105,93,45,62,102,101,110,99,45,62,105,95,114,101,102,101,114,101,110,99,101,95,99,111,117,110,116,32,61,61,32,49,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,101,120,116,114,97,100,97,116,97,10,0,0,0,112,99,109,95,117,56,0,0,68,105,115,112,108,97,121,32,100,105,109,101,110,115,105,111,110,115,58,32,37,105,120,37,105,10,0,0,0,0,0,0,101,120,116,101,110,100,101,100,95,100,97,116,97,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,0,51,48,48,48,48,47,49,48,48,49,0,0,0,0,0,0,80,114,111,106,83,116,114,97,105,103,104,116,86,101,114,116,80,111,108,101,76,111,110,103,71,101,111,75,101,121,0,0,71,101,111,84,73,70,70,32,107,101,121,32,100,105,114,101,99,116,111,114,121,32,98,117,102,102,101,114,32,115,104,111,114,116,101,114,32,116,104,97,110,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,111,114,0,0,0,0,0,0,114,101,113,117,101,115,116,101,100,32,98,105,116,114,97,116,101,32,105,115,32,116,111,111,32,108,111,119,10,0,0,0,102,114,97,109,101,114,101,102,0,0,0,0,0,0,0,0,117,115,101,32,103,109,99,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,83,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,34,37,115,34,32,37,115,10,0,0,0,0,0,0,0,77,80,69,71,45,49,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,52,48,57,53,120,52,48,57,53,10,0,0,0,0,124,0,0,0,0,0,0,0,77,101,115,104,32,79,98,106,101,99,116,32,115,116,97,114,116,0,0,0,0,0,0,0,83,101,116,32,112,114,111,102,105,108,101,32,97,110,100,32,108,101,118,101,108,10,0,0,80,0,0,0,0,0,0,0,37,100,32,99,104,97,110,110,101,108,115,32,40,109,111,114,101,32,116,104,97,110,32,116,104,101,32,109,97,120,105,109,117,109,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,100,101,99,111,100,101,114,41,0,0,0,0,82,67,84,0,0,0,0,0,83,116,114,101,110,103,116,104,32,111,102,32,112,115,121,99,104,111,118,105,115,117,97,108,32,111,112,116,105,109,105,122,97,116,105,111,110,44,32,105,110,32,60,112,115,121,45,114,100,62,58,60,112,115,121,45,116,114,101,108,108,105,115,62,32,102,111,114,109,97,116,46,0,0,0,0,0,0,0,0,86,80,57,69,95,83,69,84,95,84,73,76,69,95,67,79,76,85,77,78,83,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,74,80,69,71,32,50,48,48,48,32,99,111,100,101,115,116,114,101,97,109,32,114,101,115,116,114,105,99,116,105,111,110,32,48,0,0,0,0,0,0,123,92,117,48,125,0,0,0,37,100,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,119,105,100,116,104,115,46,10,0,0,0,68,101,99,111,100,105,110,103,32,110,97,108,32,117,110,105,116,32,37,100,32,37,100,32,102,114,111,109,32,104,118,99,67,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,99,112,98,95,99,111,117,110,116,32,37,100,32,105,110,118,97,108,105,100,10,0,0,0,115,101,108,101,99,116,101,100,95,110,0,0,0,0,0,0,105,115,95,97,118,99,0,0,76,80,67,32,97,108,103,111,114,105,116,104,109,0,0,0,51,50,45,98,105,116,32,117,110,115,105,103,110,101,100,32,105,110,116,0,0,0,0,0,76,111,47,82,111,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,73,110,118,97,108,105,100,32,98,105,116,32,97,108,108,111,99,97,116,105,111,110,32,105,110,100,101,120,10,0,0,0,115,101,116,32,112,101,97,107,32,109,111,100,101,0,0,0,104,50,54,51,105,0,0,0,69,108,108,105,112,115,101,95,66,101,115,115,101,108,95,78,97,109,105,98,105,97,0,0,115,99,95,116,104,114,101,115,104,111,108,100,0,0,0,0,65,108,116,101,114,110,82,111,99,107,0,0,0,0,0,0,115,99,97,108,101,95,115,119,115,95,111,112,116,115,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,0,0,52,50,48,80,49,48,0,0,114,101,112,111,114,116,101,100,32,102,105,108,101,32,108,101,110,103,116,104,32,40,48,120,37,108,108,120,41,32,101,120,99,101,101,100,115,32,110,117,109,98,101,114,32,111,102,32,97,118,97,105,108,97,98,108,101,32,115,101,99,116,111,114,115,32,40,48,120,37,108,108,120,41,10,0,0,0,0,0,105,103,110,111,114,101,95,108,101,110,103,116,104,0,0,0,114,101,109,105,120,101,114,0,83,97,109,112,108,101,115,32,100,114,111,112,112,101,100,32,100,117,101,32,116,111,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,117,114,101,46,10,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,99,111,100,101,99,32,112,97,114,97,109,101,116,101,114,115,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,40,37,115,41,58,32,37,115,10,67,111,110,115,105,100,101,114,32,105,110,99,114,101,97,115,105,110,103,32,116,104,101,32,118,97,108,117,101,32,102,111,114,32,116,104,101,32,39,97,110,97,108,121,122,101,100,117,114,97,116,105,111,110,39,32,97,110,100,32,39,112,114,111,98,101,115,105,122,101,39,32,111,112,116,105,111,110,115,10,0,115,109,111,111,116,104,32,115,116,114,101,97,109,105,110,103,32,109,117,120,101,114,0,0,50,53,0,0,0,0,0,0,69,108,108,105,112,115,101,95,66,101,115,115,101,108,95,77,111,100,105,102,105,101,100,0,115,116,114,101,97,109,95,99,111,100,101,99,95,116,97,103,0,0,0,0,0,0,0,0,112,99,109,95,115,56,0,0,100,114,111,112,0,0,0,0,84,114,97,105,108,105,110,103,32,111,112,116,105,111,110,115,32,119,101,114,101,32,102,111,117,110,100,32,111,110,32,116,104,101,32,99,111,109,109,97,110,100,108,105,110,101,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,37,115,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,102,111,114,32,37,115,58,32,37,115,10,0,0,0,0,78,111,116,32,97,32,86,66,86,32,102,105,108,101,10,0,115,101,103,109,101,110,116,95,116,105,109,101,95,100,101,108,116,97,0,0,0,0,0,0,118,105,100,101,111,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,118,111,114,98,105,115,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,99,111,110,102,105,103,117,114,97,116,105,111,110,61,37,115,13,10,0,0,115,98,103,95,100,101,109,117,120,101,114,0,0,0,0,0,66,108,97,99,107,109,97,110,32,119,105,110,100,111,119,0,114,97,119,32,77,80,69,71,45,52,32,118,105,100,101,111,0,0,0,0,0,0,0,0,117,98,0,0,0,0,0,0,69,108,108,105,112,115,101,95,66,101,115,115,101,108,95,49,56,52,49,0,0,0,0,0,117,115,101,32,98,101,115,116,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,0,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,117,98,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,112,97,115,115,116,104,114,111,117,103,104,0,0,0,0,0,114,116,98,117,102,115,105,122,101,0,0,0,0,0,0,0,115,116,114,101,97,109,95,115,101,103,109,101,110,116,32,109,117,120,101,114,0,0,0,0,118,0,0,0,0,0,0,0,109,97,116,101,114,105,97,108,32,116,114,97,99,107,32,37,100,58,32,68,97,116,97,68,101,102,105,110,105,116,105,111,110,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,76,79,79,80,95,77,79,68,69,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,102,105,114,115,116,32,112,105,100,32,111,102,32,116,104,101,32,80,77,84,46,0,0,0,69,108,108,105,112,115,101,95,65,117,115,116,114,97,108,105,97,110,95,78,97,116,105,111,110,97,108,95,83,112,104,101,114,111,105,100,0,0,0,0,117,115,101,32,102,101,119,101,115,116,32,98,105,116,115,0,112,99,109,95,117,49,54,98,101,0,0,0,0,0,0,0,118,102,114,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,0,0,0,0,0,109,97,120,105,109,117,109,32,109,111,111,118,32,115,105,122,101,32,115,111,32,105,116,32,99,97,110,32,98,101,32,112,108,97,99,101,100,32,97,116,32,116,104,101,32,98,101,103,105,110,0,0,0,0,0,0,101,112,105,115,111,100,101,95,105,100,0,0,0,0,0,0,87,114,105,116,105,110,103,32,98,108,111,99,107,32,97,116,32,111,102,102,115,101,116,32,37,108,108,117,44,32,115,105,122,101,32,37,100,44,32,112,116,115,32,37,108,108,100,44,32,100,117,114,97,116,105,111,110,32,37,100,10,0,0,0,67,111,109,112,108,101,116,101,108,121,32,115,105,108,101,110,116,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,65,95,81,85,73,67,75,84,73,77,69,0,0,0,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,60,83,89,78,67,0,0,0,69,108,108,105,112,115,101,95,65,105,114,121,95,77,111,100,105,102,105,101,100,95,49,56,52,57,0,0,0,0,0,0,114,97,119,0,0,0,0,0,98,105,116,115,0,0,0,0,106,112,99,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,79,110,108,121,32,49,120,49,32,99,104,114,111,109,97,32,98,108,111,99,107,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,32,65,98,111,114,116,101,100,33,10,0,99,102,114,0,0,0,0,0,79,116,104,101,114,0,0,0,115,116,101,114,101,111,51,100,0,0,0,0,0,0,0,0,115,116,101,114,101,111,0,0,80,97,99,107,101,116,32,115,105,122,101,32,37,100,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,109,97,120,32,82,84,80,32,112,97,121,108,111,97,100,32,115,105,122,101,32,37,100,10,0,0,0,82,83,79,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,109,111,110,111,10,0,77,117,108,116,105,112,108,101,32,102,114,97,109,101,115,32,105,110,32,97,32,112,97,99,107,101,116,32,102,114,111,109,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,85,110,107,110,111,119,110,32,98,105,116,115,32,112,101,114], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2300064);
/* memory initializer */ allocate([32,115,97,109,112,108,101,0,85,110,107,110,111,119,110,32,99,111,100,101,99,32,116,97,103,58,32,37,115,10,0,0,69,108,108,105,112,115,101,95,65,105,114,121,95,49,56,51,48,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,117,115,101,32,109,98,99,109,112,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,112,99,109,95,117,49,54,108,101,0,0,0,0,0,0,0,113,37,115,0,0,0,0,0,114,109,44,114,97,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,103,112,111,115,32,109,105,115,109,97,116,99,104,32,111,117,114,32,112,111,115,61,37,108,108,117,44,32,101,110,100,61,37,108,108,100,10,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,116,114,101,97,109,32,116,121,112,101,32,37,48,56,120,10,0,0,0,114,101,113,117,101,115,116,101,100,32,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,40,37,100,41,32,97,110,100,32,97,99,116,117,97,108,108,121,32,115,116,111,114,101,100,32,40,37,100,41,32,100,105,102,102,101,114,10,0,0,0,116,114,117,110,99,97,116,101,100,32,102,105,108,101,10,0,68,97,116,117,109,69,95,83,112,104,101,114,101,0,0,0,109,97,99,114,111,98,108,111,99,107,32,100,101,99,105,115,105,111,110,32,97,108,103,111,114,105,116,104,109,32,40,104,105,103,104,32,113,117,97,108,105,116,121,32,109,111,100,101,41,0,0,0,0,0,0,0,115,101,116,32,102,105,108,116,101,114,45,119,105,100,116,104,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,113,58,118,0,0,0,0,0,99,111,109,109,101,110,116,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,100,10,0,0,0,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,99,111,100,101,99,115,0,0,0,99,117,98,105,99,0,0,0,54,48,0,0,0,0,0,0,99,0,0,0,0,0,0,0,78,111,32,115,117,99,104,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,115,46,10,0,0,0,0,0,0,118,105,100,101,111,95,115,105,122,101,61,37,100,120,37,100,58,112,105,120,95,102,109,116,61,37,100,58,116,105,109,101,95,98,97,115,101,61,37,100,47,37,100,58,112,105,120,101,108,95,97,115,112,101,99,116,61,37,100,47,37,100,58,115,119,115,95,112,97,114,97,109,61,102,108,97,103,115,61,37,100,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,111,111,108,32,100,101,99,111,100,101,114,32,48,0,0,0,0,0,0,0,115,101,116,32,111,117,116,122,32,109,111,100,101,0,0,0,115,101,116,32,100,101,97,116,104,32,99,111,108,111,114,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,0,0,0,0,0,0,0,109,98,100,0,0,0,0,0,112,99,109,95,115,49,54,98,101,0,0,0,0,0,0,0,97,110,97,103,108,121,112,104,32,114,101,100,32,99,121,97,110,32,100,117,98,111,105,115,0,0,0,0,0,0,0,0,80,108,101,97,115,101,32,117,115,101,32,45,113,58,97,32,111,114,32,45,113,58,118,44,32,45,113,115,99,97,108,101,32,105,115,32,97,109,98,105,103,117,111,117,115,10,0,0,105,110,95,118,95,99,104,114,95,112,111,115,0,0,0,0,115,112,112,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,97,100,120,0,0,0,0,0,101,118,97,108,32,101,120,112,114,101,115,115,105,111,110,115,32,112,101,114,45,102,114,97,109,101,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,116,120,45,62,101,111,98,115,91,105,93,91,107,93,0,0,0,0,0,0,99,51,95,115,101,101,100,0,118,102,95,111,112,101,110,40,41,32,111,102,32,37,115,32,119,105,116,104,32,97,114,103,61,37,115,32,102,97,105,108,101,100,10,0,0,0,0,0,68,97,116,117,109,69,95,79,83,85,57,49,65,0,0,0,118,97,108,117,101,115,0,0,120,118,109,99,95,97,99,99,101,108,101,114,97,116,105,111,110,0,0,0,0,0,0,0,103,97,109,109,97,118,97,108,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,100,97,116,97,0,0,0,0,97,114,110,114,95,109,97,120,95,102,114,97,109,101,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,48,46,46,49,53,93,0,0,0,0,112,114,111,102,105,108,101,58,118,0,0,0,0,0,0,0,116,115,95,116,97,114,103,101,116,95,98,105,116,114,97,116,101,32,101,110,116,114,105,101,115,32,97,114,101,32,110,111,116,32,115,116,114,105,99,116,108,121,32,105,110,99,114,101,97,115,105,110,103,0,0,0,66,97,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,80,97,99,107,101,116,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,80,86,70,49,10,0,0,0,105,110,118,97,108,105,100,32,115,116,114,101,97,109,105,100,10,0,0,0,0,0,0,0,112,99,110,95,117,98,0,0,109,101,109,115,101,116,95,105,110,116,49,54,0,0,0,0,109,105,115,115,109,97,116,99,104,105,110,103,32,115,101,99,116,111,114,95,99,111,117,110,116,10,0,0,0,0,0,0,118,100,112,97,117,95,119,109,118,51,0,0,0,0,0,0,68,97,114,107,71,114,97,121,0,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,110,111,116,0,0,0,0,0,84,66,82,0,0,0,0,0,67,97,110,110,111,116,32,40,114,101,41,97,108,108,111,99,97,116,101,32,112,97,99,107,101,116,32,98,117,102,102,101,114,10,0,0,0,0,0,0,115,101,116,32,104,101,105,103,104,116,32,111,102,32,116,104,101,32,98,111,120,0,0,0,110,101,97,114,101,115,116,32,110,101,105,103,104,98,111,114,32,47,32,112,111,105,110,116,0,0,0,0,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,104,101,105,103,104,116,0,0,0,0,0,0,115,45,62,109,105,100,98,117,102,46,99,104,95,99,111,117,110,116,32,61,61,32,115,45,62,117,115,101,100,95,99,104,95,99,111,117,110,116,0,0,111,112,101,110,99,108,0,0,108,98,0,0,0,0,0,0,34,0,0,0,0,0,0,0,70,111,110,116,115,105,122,101,0,0,0,0,0,0,0,0,111,112,101,110,95,103,111,112,61,37,100,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,82,97,100,105,99,97,108,0,0,0,0,0,0,0,108,111,114,111,0,0,0,0,108,111,114,111,0,0,0,0,110,101,119,32,115,110,114,32,111,102,102,115,101,116,115,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,83,99,97,108,101,102,97,99,116,111,114,32,40,37,100,41,32,111,117,116,32,111,102,32,114,97,110,103,101,46,10,0,100,97,114,107,101,114,0,0,114,117,110,32,37,100,32,111,118,101,102,108,111,119,10,0,118,32,60,32,50,57,0,0,68,97,116,117,109,69,95,79,83,85,56,54,70,0,0,0,115,108,105,99,101,95,102,108,97,103,115,0,0,0,0,0,73,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,33,10,0,0,0,0,0,98,111,111,107,95,105,100,120,0,0,0,0,0,0,0,0,110,111,110,45,115,116,114,105,99,116,108,121,45,109,111,110,111,116,111,110,105,99,32,80,84,83,10,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,58,32,37,105,10,0,0,0,112,99,109,95,115,49,54,108,101,0,0,0,0,0,0,0,68,105,115,112,108,97,121,32,101,120,116,101,110,100,101,100,32,105,110,102,111,58,10,0,69,110,99,111,100,105,110,103,32,116,111,32,97,32,112,108,97,110,97,114,32,115,97,109,112,108,101,32,102,111,114,109,97,116,44,32,119,105,116,104,32,109,111,114,101,32,116,104,97,110,32,37,100,32,99,104,97,110,110,101,108,115,44,32,98,117,116,32,101,120,116,101,110,100,101,100,95,100,97,116,97,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,80,108,101,97,115,101,32,117,115,101,32,45,112,114,111,102,105,108,101,58,97,32,111,114,32,45,112,114,111,102,105,108,101,58,118,44,32,45,112,114,111,102,105,108,101,32,105,115,32,97,109,98,105,103,117,111,117,115,10,0,0,0,0,0,80,114,111,106,65,122,105,109,117,116,104,65,110,103,108,101,71,101,111,75,101,121,0,0,46,0,0,0,0,0,0,0,110,111,114,109,97,108,0,0,37,99,32,113,112,58,37,100,60,37,50,46,49,102,60,37,100,32,37,100,32,119,97,110,116,58,37,100,32,116,111,116,97,108,58,37,100,32,99,111,109,112,58,37,102,32,115,116,95,113,58,37,50,46,50,102,32,115,105,122,101,58,37,100,32,118,97,114,58,37,108,108,100,47,37,108,108,100,32,98,114,58,37,100,32,102,112,115,58,37,100,10,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,0,0,0,114,101,102,0,0,0,0,0,103,109,99,0,0,0,0,0,105,103,110,111,114,105,110,103,32,111,118,101,114,102,108,111,119,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,65,109,98,105,103,117,111,117,115,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,34,37,115,34,44,32,117,115,105,110,103,32,35,37,100,10,0,0,0,0,0,119,47,104,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,0,0,0,45,0,0,0,0,0,0,0,70,66,65,32,79,98,106,101,99,116,32,80,108,97,110,101,32,115,116,97,114,116,0,0,77,80,69,71,49,47,50,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,37,100,47,37,100,32,102,112,115,44,32,116,104,101,114,101,32,109,97,121,32,98,101,32,65,86,32,115,121,110,99,32,105,115,115,117,101,115,10,0,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,77,97,120,32,99,104,97,110,110,101,108,32,109,117,115,116,32,98,101,32,101,113,117,97,108,32,109,97,120,32,109,97,116,114,105,120,32,99,104,97,110,110,101,108,46,10,0,0,80,82,67,84,0,0,0,0,112,115,121,45,114,100,0,0,86,80,57,69,95,83,69,84,95,76,79,83,83,76,69,83,83,0,0,0,0,0,0,0,49,46,50,46,53,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,92,117,0,0,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,10,0,0,0,0,0,0,0,110,117,109,95,116,105,108,101,95,114,111,119,115,95,109,105,110,117,115,49,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,73,110,118,97,108,105,100,32,78,65,76,32,117,110,105,116,32,115,105,122,101,32,105,110,32,101,120,116,114,97,100,97,116,97,46,10,0,0,0,0,79,118,101,114,114,101,97,100,32,86,85,73,32,98,121,32,37,100,32,98,105,116,115,10,0,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,72,50,54,52,32,68,101,99,111,100,101,114,0,0,0,0,108,112,99,95,116,121,112,101,0,0,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,108,111,114,111,95,99,109,105,120,108,101,118,0,0,0,0,68,105,100,110,39,116,32,103,101,116,32,115,117,98,102,114,97,109,101,32,68,83,89,78,67,10,0,0,0,0,0,0,112,101,97,107,0,0,0,0,72,46,50,54,51,43,32,47,32,72,46,50,54,51,45,49,57,57,56,32,47,32,72,46,50,54,51,32,118,101,114,115,105,111,110,32,50,0,0,0,68,97,116,117,109,69,95,71,69,77,49,48,67,0,0,0,99,111,110,116,101,120,116,32,109,111,100,101,108,0,0,0,78,111,105,115,101,0,0,0,77,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,116,104,114,101,97,100,115,0,0,0,0,0,0,0,77,105,114,105,108,108,105,115,32,70,73,67,0,0,0,0,52,52,52,80,57,0,0,0,116,114,117,110,99,97,116,101,100,32,102,105,108,101,10,0,87,65,86,32,100,101,109,117,120,101,114,0,0,0,0,0,82,69,77,88,0,0,0,0,100,101,99,111,100,105,110,103,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,102,97,105,108,101,100,10,0,0,48,0,0,0,0,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,102,105,108,101,32,37,115,46,10,0,115,109,97,114,116,98,108,117,114,0,0,0,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,68,97,116,117,109,69,95,87,71,83,56,52,0,0,0,0,99,111,110,116,101,120,116,0,102,105,99,0,0,0,0,0,102,114,97,109,101,115,58,118,0,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,111,112,116,105,111,110,32,39,37,115,39,46,10,0,0,0,0,0,0,115,101,116,32,115,101,103,109,101,110,116,32,100,117,114,97,116,105,111,110,0,0,0,0,86,111,114,98,105,115,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,105,110,102,111,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,111,112,116,105,111,110,32,39,37,99,39,32,114,101,113,117,105,114,101,115,32,97,110,32,97,114,103,117,109,101,110,116,0,0,0,0,0,0,0,0,98,108,97,99,107,109,97,110,0,0,0,0,0,0,0,0,109,52,118,0,0,0,0,0,115,104,111,119,105,110,102,111,0,0,0,0,0,0,0,0,114,101,100,117,99,101,32,98,117,102,102,101,114,105,110,103,0,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,68,97,116,117,109,69,95,87,97,114,79,102,102,105,99,101,0,0,0,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,79,112,101,110,77,71,32,97,117,100,105,111,10,0,0,0,100,101,102,108,97,116,101,45,98,97,115,101,100,32,99,111,100,101,114,0,0,0,0,0,72,46,50,54,53,32,47,32,72,69,86,67,32,40,72,105,103,104,32,69,102,102,105,99,105,101,110,99,121,32,86,105,100,101,111,32,67,111,100,105,110,103,41,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,99,111,100,101,99,58,118,0,109,97,120,32,109,101,109,111,114,121,32,117,115,101,100,32,102,111,114,32,116,105,109,101,115,116,97,109,112,32,105,110,100,101,120,32,40,112,101,114,32,115,116,114,101,97,109,41,0,0,0,0,0,0,0,0,101,97,51,0,0,0,0,0,85,110,107,110,111,119,110,32,86,80,56,32,104,101,97,100,101,114,32,116,121,112,101,32,48,120,37,48,50,88,10,0,114,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,104,101,97,100,101,114,32,116,121,112,101,32,37,88,10,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,115,111,117,114,99,101,32,116,114,97,99,107,32,115,101,113,117,101,110,99,101,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,0,0,102,105,115,98,111,110,101,0,84,73,84,76,69,0,0,0,79,112,117,115,84,97,103,115,0,0,0,0,0,0,0,0,109,112,101,103,116,115,95,112,109,116,95,115,116,97,114,116,95,112,105,100,0,0,0,0,1,68,105,114,101,99,116,32,83,104,111,119,32,83,97,109,112,108,101,115,32,101,109,98,101,100,100,101,100,32,105,110,32,79,103,103,0,0,0,0,68,97,116,117,109,69,95,83,116,114,117,118,101,49,56,54,48,0,0,0,0,0,0,0,100,101,102,108,97,116,101,0,83,111,102,100,101,99,0,0,104,101,118,99,0,0,0,0,79,112,116,105,111,110,32,39,37,115,39,32,119,97,115,32,114,101,109,111,118,101,100,46,32,73,102,32,121,111,117,32,97,114,101,32,108,111,111,107,105,110,103,32,102,111,114,32,97,110,32,111,112,116,105,111,110,32,116,111,32,112,114,101,115,101,114,118,101,32,116,104,101,32,113,117,97,108,105,116,121,32,40,119,104,105,99,104,32,105,115,32,110,111,116,32,119,104,97,116,32,45,37,115,32,119,97,115,32,102,111,114,41,44,32,117,115,101,32,45,113,115,99,97,108,101,32,48,32,111,114,32,97,110,32,101,113,117,105,118,97,108,101,110,116,32,113,117,97,108,105,116,121,32,102,97,99,116,111,114,32,111,112,116,105,111,110,46,10,0,0,0,0,0,0,0,109,111,111,118,95,115,105,122,101,0,0,0,0,0,0,0,115,101,116,102,105,101,108,100,0,0,0,0,0,0,0,0,111,103,103,44,111,103,118,0,115,104,111,119,0,0,0,0,37,108,108,100,44,37,100,44,0,0,0,0,0,0,0,0,65,95,77,83,47,65,67,77,0,0,0,0,0,0,0,0,65,117,100,105,111,32,112,97,99,107,101,116,32,105,110,32,102,105,108,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,32,115,116,114,101,97,109,33,10,0,0,0,0,0,68,97,116,117,109,69,95,80,108,101,115,115,105,115,49,56,49,55,0,0,0,0,0,0,115,101,116,32,109,111,100,101,0,0,0,0,0,0,0,0,42,63,91,93,123,125,0,0,114,117,110,45,108,101,110,103,116,104,32,99,111,100,101,114,0,0,0,0,0,0,0,0,106,112,50,0,0,0,0,0,72,78,77,32,52,32,118,105,100,101,111,0,0,0,0,0,77,117,108,116,105,112,108,101,32,107,101,121,102,114,97,109,101,115,32,119,105,116,104,32,115,97,109,101,32,80,84,83,10,0,0,0,0,0,0,0,103,111,112,95,116,105,109,101,99,111,100,101,0,0,0,0,116,105,116,108,101,45,115,111,114,116,0,0,0,0,0,0,115,101,112,97,114,97,116,101,102,105,101,108,100,115,0,0,97,117,100,105,111,115,97,109,112,108,101,115,105,122,101,0,98,101,110,99,104,58,32,37,56,108,108,117,32,37,115,32,10,0,0,0,0,0,0,0,121,98,102,45,62,121,95,104,101,105,103,104,116,32,45,32,121,98,102,45,62,121,95,99,114,111,112,95,104,101,105,103,104,116,32,60,32,49,54,0,68,97,116,117,109,69,95,78,87,76,49,48,68,0,0,0,114,108,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,104,110,109,52,118,105,100,101,111,0,0,0,0,0,0,0,109,101,116,97,100,97,116,97,58,103,0,0,0,0,0,0,37,46,52,100,45,37,46,50,100,45,37,46,50,100,32,37,115,0,0,0,0,0,0,0,68,105,103,105,116,97,108,32,115,105,103,110,97,116,117,114,101,32,100,101,116,101,99,116,101,100,33,10,0,0,0,0,37,100,0,0,0,0,0,0,78,101,120,116,32,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,122,101,114,111,10,0,0,0,0,0,0,0,77,88,70,0,0,0,0,0,109,120,102,95,100,49,48,0,68,97,116,117,109,69,95,78,87,76,57,68,0,0,0,0,114,97,119,32,40,110,111,32,101,110,99,111,100,105,110,103,41,0,0,0,0,0,0,0,119,105,100,116,104,0,0,0,87,101,98,80,0,0,0,0,102,98,32,33,61,32,78,85,76,76,0,0,0,0,0,0,116,105,109,101,99,111,100,101,61,37,115,0,0,0,0,0,99,111,100,101,99,115,0,0,99,117,98,0,0,0,0,0,115,101,116,32,108,101,118,101,108,0,0,0,0,0,0,0,73,110,100,101,120,83,73,68,32,37,105,32,115,101,103,109,101,110,116,32,97,116,32,37,108,108,100,32,73,110,100,101,120,69,110,116,114,121,65,114,114,97,121,32,116,111,111,32,115,109,97,108,108,10,0,0,84,105,108,101,32,100,101,99,111,100,101,114,32,116,104,114,101,97,100,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,0,0,0,0,0,67,97,110,110,111,116,32,99,111,110,110,101,99,116,32,118,105,100,101,111,32,102,105,108,116,101,114,32,116,111,32,97,117,100,105,111,32,105,110,112,117,116,10,0,0,0,0,0,111,117,116,122,0,0,0,0,100,101,97,116,104,95,99,111,108,111,114,0,0,0,0,0,73,110,118,97,108,105,100,32,97,117,100,105,111,95,100,97,116,97,95,115,105,122,101,32,40,37,100,41,32,111,114,32,102,114,97,109,101,115,95,99,111,117,110,116,32,40,37,100,41,10,0,0,0,0,0,0,68,97,116,117,109,69,95,75,114,97,115,115,111,119,115,107,121,49,57,54,48,0,0,0,114,97,119,0,0,0,0,0,119,101,98,112,0,0,0,0,115,101,116,32,116,104,101,32,115,105,110,101,32,102,114,101,113,117,101,110,99,121,0,0,97,114,99,100,0,0,0,0,118,115,116,97,116,115,95,37,48,50,100,37,48,50,100,37,48,50,100,46,108,111,103,0,97,117,100,105,111,32,99,111,109,112,114,101,115,115,105,111,110,32,40,102,111,114,109,97,116,32,37,105,41,0,0,0,112,99,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,32,111,114,32,115,101,103,109,101,110,116,95,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,32,97,110,100,32,73,32,99,97,110,110,111,116,32,99,97,108,99,117,108,97,116,101,32,116,104,101,109,32,102,114,111,109,32,111,116,104,101,114,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,102,114,97,109,101,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,116,120,45,62,100,113,99,111,101,102,102,91,105,93,91,107,93,0,0,0,99,50,102,0,0,0,0,0,13,10,0,0,0,0,0,0,111,112,116,115,32,47,32,109,95,115,116,114,117,99,116,95,115,101,116,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,13,10,0,0,0,0,0,0,68,97,116,117,109,69,95,73,110,116,101,114,110,97,116,105,111,110,97,108,49,57,54,55,0,0,0,0,0,0,0,0,111,117,116,0,0,0,0,0,97,114,105,116,104,109,101,116,105,99,32,99,111,100,101,114,0,0,0,0,0,0,0,0,99,108,105,112,0,0,0,0,109,106,112,103,0,0,0,0,71,111,50,77,101,101,116,105,110,103,0,0,0,0,0,0,115,104,97,114,112,110,101,115,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,55,93,0,0,0,0,102,105,108,116,101,114,58,118,0,0,0,0,0,0,0,0,116,115,95,112,101,114,105,111,100,105,99,105,116,121,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,54,93,0,0,0,0,0,0,115,101,116,32,98,108,117,101,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,51,45,119,97,121,32,109,97,116,99,104,32,40,112,47,99,47,110,41,0,0,0,0,0,100,111,119,110,115,99,97,108,101,50,0,0,0,0,0,0,118,100,112,97,117,95,109,112,101,103,50,0,0,0,0,0,68,97,114,107,71,111,108,100,101,110,82,111,100,0,0,0,32,32,37,115,37,45,49,55,115,32,0,0,0,0,0,0,116,115,44,109,50,116,44,109,50,116,115,44,109,116,115,0,115,113,114,116,0,0,0,0,116,111,112,32,98,97,99,107,32,99,101,110,116,101,114,0,115,101,116,32,119,105,100,116,104,32,111,102,32,116,104,101,32,98,111,120,0,0,0,0,76,97,110,99,122,111,115,0,100,115,116,104,0,0,0,0,33,115,45,62,114,101,115,97,109,112,108,101,0,0,0,0,115,101,116,32,109,111,116,105,111,110,32,115,101,97,114,99,104,32,100,101,116,97,105,108,101,100,32,108,111,103,32,102,105,108,101,32,110,97,109,101,0,0,0,0,0,0,0,0,97,117,116,111,108,101,118,101,108,115,0,0,0,0,0,0,115,101,116,32,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,70,111,110,116,110,97,109,101,0,0,0,0,0,0,0,0,111,112,101,110,95,103,111,112,61,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,114,97,100,0,0,0,76,116,47,82,116,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,76,116,47,82,116,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,110,101,119,32,98,105,116,32,97,108,108,111,99,97,116,105,111,110,32,105,110,102,111,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,73,102,32,121,111,117,32,104,101,97,114,100,32,97,110,32,97,117,100,105,98,108,101,32,97,114,116,105,102,97,99,116,44,32,116,104,101,114,101,32,109,97,121,32,98,101,32,97,32,98,117,103,32,105,110,32,116,104,101,32,100,101,99,111,100,101,114,46,32,67,108,105,112,112,101,100,32,110,111,105,115,101,32,103,97,105,110,32,40,37,100,32,45,62,32,37,100,41,0,0,0,0,0,0,99,114,111,115,115,95,112,114,111,99,101,115,115,0,0,0,48,32,99,111,101,102,102,10,0,0,0,0,0,0,0,0,110,117,109,95,115,102,98,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,68,97,116,117,109,69,95,73,110,116,101,114,110,97,116,105,111,110,97,108,49,57,50,52,0,0,0,0,0,0,0,0,118,97,114,105,97,98,108,101,32,108,101,110,103,116,104,32,99,111,100,101,114,32,47,32,72,117,102,102,109,97,110,32,99,111,100,101,114,0,0,0,67,111,114,114,117,112,116,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,0,70,108,111,111,114,32,48,32,98,97,114,107,32,109,97,112,32,115,105,122,101,32,105,115,32,48,46,10,0,0,0,0,82,101,97,100,32,37,105,32,98,105,116,115,32,105,110,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,103,50,109,0,0,0,0,0,80,114,111,103,114,101,115,115,105,118,101,32,83,101,103,109,101,110,116,101,100,32,70,114,97,109,101,32,109,111,100,101,58,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,121,101,116,41,10,0,0,77,80,69,71,45,84,83,32,40,77,80,69,71,45,50,32,84,114,97,110,115,112,111,114,116,32,83,116,114,101,97,109,41,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,112,97,99,107,101,116,32,111,102,32,115,105,122,101,32,37,108,108,100,10,0,37,115,58,37,99,0,0,0,80,114,111,106,83,99,97,108,101,65,116,67,101,110,116,101,114,71,101,111,75,101,121,0,71,101,111,84,73,70,70,95,75,101,121,95,82,101,118,105,115,105,111,110,0,0,0,0,110,101,103,97,116,105,111,110,0,0,0,0,0,0,0,0,113,32,62,32,48,46,48,0,112,99,109,95,115,49,54,98,101,95,112,108,97,110,97,114,0,0,0,0,0,0,0,0,37,117,47,37,117,0,0,0,117,115,101,32,102,105,120,101,100,32,113,115,99,97,108,101,0,0,0,0,0,0,0,0,100,99,32,111,118,101,114,102,108,111,119,43,32,67,32,113,115,99,97,108,101,58,32,37,100,47,47,10,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,34,37,115,34,10,0,0,72,46,50,54,51,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,50,48,52,56,120,49,49,53,50,10,0,0,0,0,0,43,0,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,115,105,122,101,32,45,32,109,117,108,116,105,112,108,101,32,102,114,97,109,101,115,32,105,110,32,98,117,102,102,101,114,63,10,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,115,105,122,101,32,45,32,109,117,108,116,105,112,108,101,32,102,114,97,109,101,115,32,105,110,32,98,117,102,102,101,114,63,10,0,0,0,0,0,0,70,66,65,32,79,98,106,101,99,116,32,115,116,97,114,116,0,0,0,0,0,0,0,0,77,80,69,71,49,47,50,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,37,100,47,37,100,32,102,112,115,10,0,0,0,0,0,113,112,58,37,100,32,102,99,58,37,50,100,37,50,100,37,50,100,37,50,100,32,37,115,32,37,115,32,37,115,32,37,115,32,37,115,32,100,99,58,37,100,32,112,115,116,114,117,99,116,58,37,100,32,102,100,99,116,58,37,100,32,99,109,118,58,37,100,32,113,116,121,112,101,58,37,100,32,105,118,108,99,58,37,100,32,114,102,102,58,37,100,32,37,115,10,0,0,0,0,0,0,0,0,77,97,120,32,109,97,116,114,105,120,32,99,104,97,110,110,101,108,32,99,97,110,110,111,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,37,100,46,10,0,0,109,112,103,44,109,112,101,103,0,0,0,0,0,0,0,0,85,115,101,32,112,115,121,99,104,111,118,105,115,117,97,108,32,111,112,116,105,109,105,122,97,116,105,111,110,115,46,0,86,80,56,69,95,83,69,84,95,77,65,88,95,73,78,84,82,65,95,66,73,84,82,65,84,69,95,80,67,84,0,0,85,110,107,110,111,119,110,32,102,108,97,103,32,115,101,116,32,40,37,100,41,46,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,123,92,117,49,125,0,0,0,83,69,80,66,50,32,109,97,114,107,101,114,32,109,105,115,115,105,110,103,10,0,0,0,78,111,32,99,111,109,109,97,110,100,32,115,112,101,99,105,102,105,101,100,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,0,0,0,0,110,117,109,95,116,105,108,101,95,99,111,108,117,109,110,115,95,109,105,110,117,115,49,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,110,97,108,95,117,110,105,116,95,116,121,112,101,58,32,37,100,44,32,110,117,104,95,108,97,121,101,114,95,105,100,58,32,37,100,116,101,109,112,111,114,97,108,95,105,100,58,32,37,100,10,0,0,0,0,0,67,108,105,112,112,105,110,103,32,105,108,108,101,103,97,108,32,110,117,109,95,114,101,111,114,100,101,114,95,102,114,97,109,101,115,32,37,100,10,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,67,65,86,76,67,32,52,58,52,58,52,0,0,0,0,0,76,80,67,32,99,111,101,102,102,105,99,105,101,110,116,32,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,99,111,109,112,114,101,115,115,105,111,110,32,97,116,116,114,105,98,117,116,101,10,0,0,76,116,47,82,116,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,83,116,114,101,97,109,32,119,105,116,104,32,104,105,103,104,32,102,114,101,113,117,101,110,99,105,101,115,32,86,81,32,99,111,100,105,110,103,10,0,105,110,106,101,99,116,32,109,101,116,97,100,97,116,97,32,105,110,32,116,104,101,32,102,105,108,116,101,114,103,114,97,112,104,0,0,0,0,0,0,104,50,54,51,112,0,0,0,86,111,98,83,117,98,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,68,97,116,117,109,69,95,73,110,100,111,110,101,115,105,97,110,78,97,116,105,111,110,97,108,83,112,104,101,114,111,105,100,0,0,0,0,0,0,0,118,108,99,0,0,0,0,0,71,111,115,112,101,108,0,0,116,104,114,101,97,100,115,0,83,105,103,109,97,116,101,108,32,77,111,116,105,111,110,32,86,105,100,101,111,0,0,0,52,50,50,80,57,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,105,108,101,32,97,108,108,111,99,97,116,105,111,110,32,116,97,98,108,101,32,100,101,112,116,104,32,40,48,120,37,120,41,10,0,78,111,32,115,101,101,107,32,116,97,98,108,101,32,97,116,32,103,105,118,101,110,32,112,111,115,105,116,105,111,110,10,0,0,0,0,0,0,0,0,78,101,118,101,114,32,119,114,105,116,101,32,82,70,54,52,32,104,101,97,100,101,114,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,102,105,108,101,32,115,105,122,101,46,0,0,0,0,0,0,0,0,100,115,54,52,0,0,0,0,112,101,114,115,111,110,110,101,108,0,0,0,0,0,0,0,78,111,32,115,117,99,104,32,111,112,116,105,111,110,58,32,37,115,46,10,0,0,0,0,109,97,120,95,97,110,97,108,121,122,101,95,100,117,114,97,116,105,111,110,32,37,100,32,114,101,97,99,104,101,100,32,97,116,32,37,108,108,100,32,109,105,99,114,111,115,101,99,111,110,100,115,10,0,0,0,116,114,117,110,99,97,116,101,0,0,0,0,0,0,0,0,67,97,110,32,100,101,109,117,120,32,77,117,115,101,112,97,99,107,32,83,86,55,44,32,103,111,116,32,118,101,114,115,105,111,110,32,37,48,50,88,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,39,37,115,39,32,102,111,114,32,111,112,116,105,111,110,32,39,37,115,39,44,32,114,101,113,117,105,114,101,100,32,115,121,110,116,97,120,32,105,115,32,39,105,110,100,101,120,58,118,97,108,117,101,39,10,0,0,0,109,112,50,44,109,50,97,44,109,112,97,0,0,0,0,0,84,65,71,0,0,0,0,0,68,97,116,117,109,69,95,72,101,108,109,101,114,116,49,57,48,54,0,0,0,0,0,0,99,111,100,101,114,0,0,0,115,109,118,0,0,0,0,0,98,58,118,0,0,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,111,112,116,105,111,110,32,39,37,115,39,32,40,37,115,41,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,48,46,10,0,0,115,101,103,109,101,110,116,95,116,105,109,101,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,65,77,82,45,87,66,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,111,99,116,101,116,45,97,108,105,103,110,61,49,13,10,0,0,0,0,0,105,109,109,101,100,105,97,116,101,32,115,101,113,117,101,110,99,101,115,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,0,72,97,109,109,105,110,103,32,119,105,110,100,111,119,0,0,114,97,119,32,72,69,86,67,32,118,105,100,101,111,0,0,117,56,0,0,0,0,0,0,68,97,116,117,109,69,95,71,82,83,49,57,56,48,0,0,103,108,111,98,97,108,95,113,117,97,108,105,116,121,0,0,66,82,101,110,100,101,114,32,80,73,88,32,105,109,97,103,101,0,0,0,0,0,0,0,117,56,0,0,0,0,0,0,80,108,101,97,115,101,32,117,115,101,32,45,98,58,97,32,111,114,32,45,98,58,118,44,32,45,98,32,105,115,32,97,109,98,105,103,117,111,117,115,10,0,0,0,0,0,0,0,105,110,100,101,120,109,101,109,0,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,109,97,116,101,114,105,97,108,32,116,114,97,99,107,32,37,100,58,32,110,111,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,115,111,117,114,99,101,32,116,114,97,99,107,32,102,111,117,110,100,10,0,67,79,77,77,69,78,84,0,83,101,116,32,115,101,114,118,105,99,101,95,105,100,32,102,105,101,108,100,46,0,0,0,68,97,116,117,109,69,95,69,118,101,114,101,115,116,49,56,51,48,77,111,100,105,102,105,101,100,0,0,0,0,0,0,105,110,116,101,114,32,113,117,97,110,116,32,98,105,97,115,0,0,0,0,0,0,0,0,73,77,75,72,0,0,0,0,98,114,101,110,100,101,114,95,112,105,120,0,0,0,0,0,87,114,105,116,101,32,116,104,101,32,88,105,110,103,32,104,101,97,100,101,114,32,99,111,110,116,97,105,110,105,110,103,32,102,105,108,101,32,100,117,114,97,116,105,111,110,46,0,102,114,97,109,101,115,58,97,0,0,0,0,0,0,0,0,65,100,100,32,82,84,80,32,104,105,110,116,32,116,114,97,99,107,115,0,0,0,0,0,115,121,110,111,112,115,105,115,0,0,0,0,0,0,0,0,97,97,99,32,98,105,116,115,116,114,101,97,109,32,101,114,114,111,114,10,0,0,0,0,115,99,97,108,101,0,0,0,68,105,97,108,111,103,117,101,58,32,37,100,44,0,0,0,86,95,77,83,47,86,70,87,47,70,79,85,82,67,67,0,68,97,116,117,109,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,55,53,68,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,112,98,105,97,115,0,0,0,106,50,99,0,0,0,0,0,88,45,102,97,99,101,32,105,109,97,103,101,0,0,0,0,113,58,97,0,0,0,0,0,84,83,79,84,0,0,0,0,114,101,109,111,118,101,32,97,108,108,32,102,114,97,103,109,101,110,116,115,32,119,104,101,110,32,102,105,110,105,115,104,101,100,0,0,0,0,0,0,97,117,100,105,111,115,97,109,112,108,101,114,97,116,101,0,65,108,108,111,99,97,116,101,32,115,116,114,101,97,109,115,32,97,99,99,111,114,100,105,110,103,32,116,111,32,116,104,101,32,111,110,77,101,116,97,68,97,116,97,32,97,114,114,97,121,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,47,32,77,79,86,0,37,108,108,100,0,0,0,0,255,0,0,0,0,0,0,0,68,97,116,117,109,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,54,55,68,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,0,105,110,116,114,97,32,113,117,97,110,116,32,98,105,97,115,0,0,0,0,0,0,0,0,120,102,97,99,101,0,0,0,37,108,108,100,10,0,0,0,99,111,100,101,99,58,97,0,115,117,98,0,0,0,0,0,37,42,51,115,37,42,91,32,93,37,51,115,37,42,91,32,93,37,50,100,37,42,91,32,93,37,56,115,37,42,91,32,93,37,52,100,0,0,0,0,123,37,100,125,123,125,37,54,108,102,0,0,0,0,0,0,65,83,70,32,69,120,116,101,110,100,101,100,32,67,111,110,116,101,110,116,32,69,110,99,114,121,112,116,105,111,110,0,80,101,114,45,102,114,97,109,101,32,77,68,53,32,116,101,115,116,105,110,103,0,0,0,68,97,116,117,109,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,51,55,65,100,106,117,115,116,109,101,110,116,0,0,0,0,0,0,0,105,98,105,97,115,0,0,0,115,108,111,112,101,0,0,0,67,80,105,65,32,118,105,100,101,111,32,102,111,114,109,97,116,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,113,117,97,100,114,97,116,105,99,0,0,0,0,0,0,0,115,104,111,119,32,97,118,97,105,108,97,98,108,101,32,102,111,114,109,97,116,115,0,0,108,101,118,101,108,0,0,0,109,107,118,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,119,111,114,107,101,114,45,62,100,97,116,97,50,0,0,0,0,0,0,0,0,98,117,102,102,101,114,0,0,115,101,116,32,119,104,105,116,101,32,109,111,100,101,0,0,115,97,98,0,0,0,0,0,119,104,105,116,101,0,0,0,120,115,99,97,108,101,61,37,102,32,121,115,99,97,108,101,61,37,102,32,100,109,97,120,61,37,102,10,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,83,71,65,49,57,50,50,0,0,0,0,0,0,0,108,105,109,105,116,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,114,97,110,103,101,32,40,49,48,50,51,32,102,111,114,32,68,105,118,88,32,112,108,97,121,101,114,41,0,0,0,0,0,0,0,99,112,105,97,0,0,0,0,97,110,97,103,108,121,112,104,32,114,101,100,32,99,121,97,110,32,99,111,108,111,114,0,37,108,108,117,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,37,108,108,117,32,111,114,32,115,105,122,101,32,37,117,10,0,116,118,0,0,0,0,0,0,103,111,116,32,97,117,100,105,111,32,112,97,99,107,101,116,32,119,105,116,104,111,117,116,32,104,97,118,105,110,103,32,97,110,32,97,117,100,105,111,32,115,116,114,101,97,109,10,0,0,0,0,0,0,0,0,105,100,32,37,100,0,0,0,112,97,99,107,101,116,32,115,105,122,101,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,101,118,97,108,32,101,120,112,114,101,115,115,105,111,110,115,32,111,110,99,101,32,100,117,114,105,110,103,32,105,110,105,116,105,97,108,105,122,97,116,105,111,110,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,116,120,45,62,113,99,111,101,102,102,91,105,93,91,107,93,0,0,0,0,108,97,116,109,44,108,111,97,115,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,102,108,97,103,115,0,0,32,67,111,109,112,114,101,115,115,105,111,110,32,98,121,32,74,111,104,110,32,77,32,80,104,105,108,108,105,112,115,32,67,111,112,121,114,105,103,104,116,32,40,67,41,32,49,57,57,53,32,84,104,101,32,66,105,116,109,97,112,32,66,114,111,116,104,101,114,115,32,76,116,100,46,0,0,0,0,0,39,37,115,39,32,105,115,32,97,32,119,114,97,112,112,101,100,32,77,80,108,97,121,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2310304);
/* memory initializer */ allocate([114,32,102,105,108,116,101,114,32,40,108,105,98,109,112,99,111,100,101,99,115,41,46,32,84,104,105,115,32,102,105,108,116,101,114,32,109,97,121,32,98,101,32,114,101,109,111,118,101,100,10,111,110,99,101,32,105,116,32,104,97,115,32,98,101,101,110,32,112,111,114,116,101,100,32,116,111,32,97,32,110,97,116,105,118,101,32,108,105,98,97,118,102,105,108,116,101,114,46,10,0,0,0,0,106,115,115,44,106,115,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,65,114,99,0,0,0,105,110,0,0,0,0,0,0,109,101,95,114,97,110,103,101,0,0,0,0,0,0,0,0,118,97,108,91,37,100,93,91,37,100,93,32,61,32,37,100,10,0,0,0,0,0,0,0,65,118,105,100,32,65,86,73,32,67,111,100,101,99,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,116,114,97,110,115,102,111,114,109,32,115,105,122,101,46,34,0,0,116,105,108,101,95,114,111,119,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,48,46,46,50,93,0,0,0,35,83,32,37,115,0,0,0,85,110,107,110,111,119,110,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,58,32,37,115,10,0,0,0,0,0,116,115,95,110,117,109,98,101,114,95,108,97,121,101,114,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,53,93,0,0,0,0,67,117,114,114,101,110,116,108,121,32,111,110,108,121,32,86,80,56,32,105,115,32,115,117,112,112,111,114,116,101,100,33,10,0,0,0,0,0,0,0,98,108,117,101,95,101,120,112,114,0,0,0,0,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,33,32,82,101,97,100,32,37,100,32,111,102,32,37,100,32,98,121,116,101,115,10,0,0,70,97,105,108,101,100,32,112,97,114,115,105,110,103,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,0,112,99,110,0,0,0,0,0,100,111,119,110,115,99,97,108,101,49,0,0,0,0,0,0,118,100,112,97,117,95,109,112,101,103,49,0,0,0,0,0,68,97,114,107,67,121,97,110,0,0,0,0,0,0,0,0,111,110,108,121,32,111,110,101,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,32,32,32,32,32,37,45,49,53,115,32,0,0,0,0,0,116,114,117,110,99,0,0,0,69,120,112,101,114,105,109,101,110,116,97,108,32,102,101,97,116,117,114,101,0,0,0,0,84,66,67,0,0,0,0,0,115,101,116,32,118,101,114,116,105,99,97,108,32,112,111,115,105,116,105,111,110,32,111,102,32,116,104,101,32,116,111,112,32,98,111,120,32,101,100,103,101,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,116,97,103,32,37,88,10,0,71,97,117,115,115,105,97,110,0,0,0,0,0,0,0,0,100,101,115,116,105,110,97,116,105,111,110,32,119,105,100,116,104,0,0,0,0,0,0,0,111,117,116,45,62,99,104,95,99,111,117,110,116,32,61,61,32,105,110,45,62,99,104,95,99,111,117,110,116,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,97,108,0,0,0,0,0,0,73,110,103,101,110,105,101,110,116,32,112,97,99,107,101,116,58,32,115,105,122,101,61,37,100,44,32,119,105,100,116,104,61,37,100,44,32,104,101,105,103,104,116,61,37,100,44,32,117,110,107,49,61,37,100,32,117,110,107,50,61,37,100,10,0,0,0,0,0,0,0,0,78,97,109,101,0,0,0,0,100,105,102,102,101,114,101,110,116,32,105,110,116,114,97,95,114,101,102,114,101,115,104,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,81,117,105,99,107,84,105,109,101,0,0,0,0,0,108,116,114,116,0,0,0,0,108,116,114,116,0,0,0,0,101,120,112,111,110,101,110,116,32,111,117,116,45,111,102,45,114,97,110,103,101,10,0,0,73,102,32,121,111,117,32,104,101,97,114,100,32,97,110,32,97,117,100,105,98,108,101,32,97,114,116,105,102,97,99,116,44,32,116,104,101,114,101,32,109,97,121,32,98,101,32,97,32,98,117,103,32,105,110,32,116,104,101,32,100,101,99,111,100,101,114,46,32,67,108,105,112,112,101,100,32,105,110,116,101,110,115,105,116,121,32,115,116,101,114,101,111,32,112,111,115,105,116,105,111,110,32,40,37,100,32,45,62,32,37,100,41,0,0,0,0,0,0,0,99,111,108,111,114,95,110,101,103,97,116,105,118,101,0,0,101,114,114,111,114,32,100,99,32,114,117,110,32,33,61,32,48,10,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,82,71,83,0,0,0,100,116,103,95,97,99,116,105,118,101,95,102,111,114,109,97,116,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,101,120,116,114,97,100,97,116,97,33,10,0,0,0,0,0,70,108,111,111,114,32,48,32,114,97,116,101,32,105,115,32,48,46,10,0,0,0,0,0,69,120,116,114,97,32,100,97,116,97,58,32,37,105,32,98,105,116,115,32,108,101,102,116,44,32,118,97,108,117,101,58,32,37,88,10,0,0,0,0,97,118,114,110,0,0,0,0,65,100,118,97,110,99,101,100,32,80,114,111,102,105,108,101,32,108,101,118,101,108,32,37,105,58,10,102,114,109,114,116,113,95,112,111,115,116,112,114,111,99,61,37,105,44,32,98,105,116,114,116,113,95,112,111,115,116,112,114,111,99,61,37,105,10,76,111,111,112,70,105,108,116,101,114,61,37,105,44,32,67,104,114,111,109,97,70,111,114,109,97,116,61,37,105,44,32,80,117,108,108,100,111,119,110,61,37,105,44,32,73,110,116,101,114,108,97,99,101,58,32,37,105,10,84,70,67,84,82,102,108,97,103,61,37,105,44,32,70,73,78,84,69,82,80,102,108,97,103,61,37,105,10,0,0,0,0,0,0,85,115,101,114,32,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,60,32,37,108,108,100,41,10,0,0,0,105,109,97,103,101,50,112,105,112,101,0,0,0,0,0,0,102,105,108,116,101,114,58,97,0,0,0,0,0,0,0,0,80,114,111,106,83,99,97,108,101,65,116,78,97,116,79,114,105,103,105,110,71,101,111,75,101,121,0,0,0,0,0,0,71,101,111,84,73,70,70,95,86,101,114,115,105,111,110,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,112,105,99,116,95,116,121,112,101,32,61,61,32,114,99,101,45,62,110,101,119,95,112,105,99,116,95,116,121,112,101,0,102,112,115,0,0,0,0,0,113,115,99,97,108,101,0,0,100,99,32,111,118,101,114,102,108,111,119,43,32,76,32,113,115,99,97,108,101,58,32,37,100,47,47,10,0,0,0,0,78,111,32,37,115,32,115,116,114,101,97,109,32,119,105,116,104,32,105,110,100,101,120,32,39,37,100,39,32,102,111,117,110,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,97,115,112,101,99,116,32,114,97,116,105,111,32,37,105,47,37,105,44,32,108,105,109,105,116,32,105,115,32,50,53,53,47,50,53,53,32,114,101,100,117,99,105,110,103,10,0,0,0,0,88,0,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,109,98,100,45,62,112,108,97,110,101,91,49,93,46,115,117,98,115,97,109,112,108,105,110,103,95,120,32,61,61,32,109,98,100,45,62,112,108,97,110,101,91,49,93,46,115,117,98,115,97,109,112,108,105,110,103,95,121,0,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,102,103,115,32,115,116,97,114,116,0,0,0,0,0,0,0,83,105,109,117,108,97,116,101,32,101,114,114,111,114,115,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,32,116,111,32,116,101,115,116,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,46,0,0,0,0,0,105,110,105,116,105,97,108,32,115,107,105,112,32,111,118,101,114,102,108,111,119,10,0,0,77,76,80,32,109,117,115,116,32,104,97,118,101,32,48,120,51,49,101,97,32,115,121,110,99,32,119,111,114,100,46,10,0,0,0,0,0,0,0,0,82,71,66,0,0,0,0,0,112,105,112,101,100,32,105,109,97,103,101,50,32,115,101,113,117,101,110,99,101,0,0,0,112,115,121,0,0,0,0,0,86,80,56,69,95,83,69,84,95,67,81,95,76,69,86,69,76,0,0,0,0,0,0,0,80,78,71,32,102,105,108,116,101,114,32,102,108,97,103,32,115,101,116,46,10,0,0,0,85,110,107,110,111,119,110,32,112,97,108,101,116,116,101,0,92,85,0,0,0,0,0,0,83,69,80,66,49,32,109,97,114,107,101,114,32,109,105,115,115,105,110,103,10,0,0,0,78,111,32,116,97,114,103,101,116,32,115,112,101,99,105,102,105,101,100,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,0,0,0,0,0,112,112,115,95,99,114,95,113,112,95,111,102,102,115,101,116,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,115,108,105,99,101,32,115,101,103,109,101,110,116,46,10,0,0,0,0,0,0,116,105,109,101,95,115,99,97,108,101,47,110,117,109,95,117,110,105,116,115,95,105,110,95,116,105,99,107,32,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,40,37,100,47,37,100,41,10,0,0,0,0,115,97,109,112,108,101,115,95,110,0,0,0,0,0,0,0,72,105,103,104,32,52,58,52,58,52,32,73,110,116,114,97,0,0,0,0,0,0,0,0,108,112,99,95,99,111,101,102,102,95,112,114,101,99,105,115,105,111,110,0,0,0,0,0,70,111,117,110,100,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,99,111,109,112,114,101,115,115,105,111,110,32,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,0,108,116,114,116,95,115,117,114,109,105,120,108,101,118,0,0,69,82,82,79,82,58,32,98,108,111,99,107,32,99,111,100,101,32,108,111,111,107,45,117,112,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,109,101,116,97,100,97,116,97,0,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,56,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,73,71,78,0,0,0,115,117,98,45,112,101,108,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,113,117,97,108,105,116,121,0,0,0,0,0,0,0,83,111,117,110,100,32,67,108,105,112,0,0,0,0,0,0,115,108,105,99,101,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,86,105,100,101,111,0,0,0,0,0,0,52,50,48,80,57,0,0,0,102,105,108,101,110,97,109,101,32,101,120,99,101,101,100,115,32,98,117,102,102,101,114,32,115,105,122,101,59,32,114,101,109,97,105,110,105,110,103,32,100,105,114,101,99,116,111,114,121,32,101,110,116,114,105,101,115,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,110,101,118,101,114,0,0,0,82,70,54,52,0,0,0,0,80,82,83,78,0,0,0,0,109,112,111,0,0,0,0,0,68,84,83,32,100,105,115,99,111,110,116,105,110,117,105,116,121,32,105,110,32,115,116,114,101,97,109,32,37,100,58,32,112,97,99,107,101,116,32,37,100,32,119,105,116,104,32,68,84,83,32,37,108,108,100,44,32,112,97,99,107,101,116,32,37,100,32,119,105,116,104,32,68,84,83,32,37,108,108,100,10,0,0,0,0,0,0,0,37,48,50,120,0,0,0,0,99,111,100,101,99,58,115,0,108,98,99,0,0,0,0,0,48,0,0,0,0,0,0,0,70,114,97,109,101,32,114,97,116,101,32,109,97,121,32,110,111,116,32,101,120,99,101,101,100,32,50,53,53,102,112,115,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,104,117,110,107,32,115,105,122,101,58,32,37,117,10,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,56,48,95,66,101,110,111,105,116,0,0,0,0,0,0,0,0,115,117,98,113,0,0,0,0,112,97,102,95,118,105,100,101,111,0,0,0,0,0,0,0,114,111,116,97,116,101,0,0,84,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,99,104,97,110,110,101,108,46,10,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,112,116,105,111,110,32,39,37,115,39,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,39,37,115,39,46,10,0,0,65,112,112,108,101,32,72,84,84,80,32,76,105,118,101,32,83,116,114,101,97,109,105,110,103,32,99,111,109,112,97,116,105,98,108,101,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,65,77,82,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,111,99,116,101,116,45,97,108,105,103,110,61,49,13,10,0,0,0,0,0,0,0,0,112,114,101,112,114,111,103,114,97,109,109,101,100,32,115,101,113,117,101,110,99,101,115,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,0,0,0,0,0,104,97,109,109,105,110,103,0,104,101,118,99,0,0,0,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,73,67,79,32,97,108,114,101,97,100,121,32,99,111,110,116,97,105,110,115,32,37,100,32,105,109,97,103,101,115,10,0,117,119,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,54,54,77,105,99,104,105,103,97,110,0,0,0,0,0,0,0,100,105,97,109,111,110,100,32,116,121,112,101,32,38,32,115,105,122,101,32,102,111,114,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,112,114,101,45,112,97,115,115,0,0,0,0,0,0,76,117,99,97,115,65,114,116,115,32,83,77,85,83,72,32,118,105,100,101,111,0,0,0,117,119,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,102,111,117,110,100,58,32,37,100,44,32,111,102,102,115,101,116,58,32,37,100,10,0,0,0,0,84,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,115,116,97,110,100,97,114,100,46,10,0,0,0,0,0,0,100,101,99,114,121,112,116,105,111,110,32,107,101,121,0,0,35,69,88,84,77,51,85,10,0,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,98,119,32,60,32,98,115,32,38,38,32,98,104,32,60,32,98,115,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,115,111,117,114,99,101,32,116,114,97,99,107,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,0,0,0,95,95,78,85,77,95,65,95,84,82,65,67,75,83,0,0,78,111,32,108,111,110,103,101,114,32,114,101,99,101,105,118,105,110,103,32,112,108,97,121,108,105,115,116,32,37,100,10,0,0,0,0,0,0,0,0,104,101,118,99,32,100,101,109,117,120,101,114,0,0,0,0,114,101,109,111,118,101,108,111,103,111,0,0,0,0,0,0,109,112,101,103,116,115,95,115,101,114,118,105,99,101,95,105,100,0,0,0,0,0,0,0,109,112,101,103,32,109,117,120,101,114,0,0,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,54,54,0,0,0,0,0,0,0,112,114,101,95,100,105,97,95,115,105,122,101,0,0,0,0,35,32,86,111,98,83,117,98,32,105,110,100,101,120,32,102,105,108,101,44,0,0,0,0,115,97,110,109,0,0,0,0,119,114,105,116,101,95,120,105,110,103,0,0,0,0,0,0,37,115,58,32,73,110,118,97,108,105,100,32,111,112,116,105,111,110,32,111,114,32,97,114,103,117,109,101,110,116,58,32,39,37,115,39,44,32,112,97,114,115,101,100,32,97,115,32,39,37,115,39,32,61,32,39,37,115,39,10,0,0,0,0,37,115,47,115,116,114,101,97,109,37,100,46,97,98,115,116,0,0,0,0,0,0,0,0,104,50,54,52,32,100,101,109,117,120,101,114,0,0,0,0,114,116,112,104,105,110,116,0,104,50,54,49,32,100,101,109,117,120,101,114,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,13,10,0,0,0,0,0,0,101,110,99,95,107,101,121,95,105,100,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,101,100,105,97,32,112,97,99,107,101,116,32,108,101,110,103,116,104,10,0,0,0,0,68,97,116,117,109,69,95,67,108,97,114,107,101,49,56,53,56,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,85,110,107,110,111,119,110,32,118,97,108,117,101,32,39,37,100,39,32,102,111,114,32,112,97,116,116,101,114,110,95,116,121,112,101,32,111,112,116,105,111,110,10,0,0,0,0,0,99,104,114,111,109,97,0,0,115,117,110,114,97,115,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,50,58,48,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,108,97,98,101,108,10,0,0,0,0,102,102,112,114,101,115,101,116,91,37,115,93,58,32,115,101,116,32,39,37,115,39,32,61,32,39,37,115,39,10,0,0,97,114,116,105,115,116,45,115,111,114,116,0,0,0,0,0,66,65,78,68,87,73,68,84,72,61,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,0,114,101,109,111,118,101,95,97,116,95,101,120,105,116,0,0,79,110,108,121,32,56,48,48,48,32,98,47,115,32,97,110,100,32,54,52,48,48,32,98,47,115,32,98,105,116,114,97,116,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,32,80,114,111,118,105,100,101,100,58,32,37,100,32,98,47,115,10,0,0,0,0,97,117,100,105,111,100,97,116,97,114,97,116,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,108,118,95,109,101,116,97,100,97,116,97,0,0,0,0,44,32,70,61,48,120,37,48,88,0,0,0,0,0,0,0,37,46,54,103,0,0,0,0,105,109,97,103,101,50,112,105,112,101,0,0,0,0,0,0,68,97,116,117,109,69,95,66,101,115,115,101,108,78,97,109,105,98,105,97,0,0,0,0,100,99,116,109,97,120,0,0,121,117,118,52,0,0,0,0,37,115,58,32,73,110,118,97,108,105,100,32,115,121,110,116,97,120,58,32,39,37,115,39,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,115,116,111,114,101,32,112,111,115,105,116,105,111,110,32,97,102,116,101,114,32,114,101,97,100,105,110,103,32,105,110,100,101,120,10,0,101,110,99,114,121,112,116,105,111,110,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,117,112,100,97,116,101,32,104,101,97,100,101,114,32,119,105,116,104,32,99,111,114,114,101,99,116,32,100,117,114,97,116,105,111,110,46,10,0,116,98,58,37,102,32,115,97,109,112,108,101,95,114,97,116,101,58,37,102,32,110,98,95,99,104,97,110,110,101,108,115,58,37,102,10,0,0,0,0,83,116,114,101,97,109,32,100,105,115,99,111,118,101,114,101,100,32,97,102,116,101,114,32,104,101,97,100,32,97,108,114,101,97,100,121,32,112,97,114,115,101,100,10,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,101,101,107,32,97,116,32,112,114,101,97,109,98,108,101,10,0,0,0,0,0,68,97,116,117,109,69,95,66,101,115,115,101,108,77,111,100,105,102,105,101,100,0,0,0,57,47,55,32,119,97,118,101,108,101,116,44,32,111,110,108,121,32,117,115,101,100,32,105,110,32,115,110,111,119,0,0,117,110,97,98,108,101,32,116,111,32,114,101,119,114,105,116,101,32,70,76,65,67,32,104,101,97,100,101,114,46,10,0,115,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,81,84,32,52,58,52,58,52,58,52,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,86,111,114,98,105,115,67,111,109,109,101,110,116,32,109,101,116,97,100,97,116,97,10,0,0,0,112,117,108,108,117,112,0,0,13,10,0,0,0,0,0,0,111,110,108,121,32,65,86,95,80,73,88,95,70,77,84,95,82,71,66,65,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,109,97,103,105,99,32,110,117,109,98,101,114,32,110,111,116,32,102,111,117,110,100,10,0,116,114,117,110,99,97,116,101,32,101,120,105,115,116,105,110,103,32,102,105,108,101,115,32,111,110,32,119,114,105,116,101,0,0,0,0,0,0,0,0,113,117,97,0,0,0,0,0,91,83,84,82,69,65,77,93,0,0,0,0,0,0,0,0,119,32,61,61,32,104,32,38,38,32,119,32,61,61,32,108,101,118,101,108,42,108,101,118,101,108,42,108,101,118,101,108,0,0,0,0,0,0,0,0,102,111,114,109,97,116,115,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,119,111,114,107,101,114,45,62,100,97,116,97,49,0,0,0,0,0,0,0,0,69,114,114,111,114,32,99,111,110,102,105,103,117,114,105,110,103,32,116,104,101,32,37,115,32,102,105,108,116,101,114,0,119,104,105,116,101,0,0,0,91,67,72,65,80,84,69,82,93,0,0,0,0,0,0,0,115,101,116,32,108,105,102,101,32,99,111,108,111,114,0,0,100,101,102,97,117,108,116,0,116,101,120,94,113,67,111,109,112,0,0,0,0,0,0,0,114,101,115,121,110,99,105,110,103,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,50,52,45,98,105,116,32,80,97,114,105,115,32,80,67,77,32,102,111,114,109,97,116,0,68,97,116,117,109,69,95,66,101,115,115,101,108,49,56,52,49,0,0,0,0,0,0,0,119,57,55,0,0,0,0,0,118,52,48,56,0,0,0,0,97,114,99,99,0,0,0,0,61,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,48,120,37,48,52,120,10,0,0,109,112,101,103,0,0,0,0,102,97,105,108,101,100,32,114,101,97,100,105,110,103,32,100,120,97,95,101,120,116,114,97,10,0,0,0,0,0,0,0,67,97,110,39,116,32,112,114,111,99,101,115,115,32,68,86,32,102,114,97,109,101,32,35,37,100,46,32,73,110,115,117,102,102,105,99,105,101,110,116,32,118,105,100,101,111,32,100,97,116,97,32,111,114,32,115,101,118,101,114,101,32,115,121,110,99,32,112,114,111,98,108,101,109,46,10,0,0,0,0,100,118,44,100,105,102,0,0,105,110,105,116,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,116,120,45,62,99,111,101,102,102,91,105,93,91,107,93,0,0,0,0,0,99,104,117,110,107,32,115,105,122,101,32,116,111,111,32,98,105,103,10,0,0,0,0,0,99,50,95,102,108,97,103,115,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,102,105,108,116,101,114,32,37,115,10,0,0,0,0,0,0,68,97,116,117,109,69,95,65,117,115,116,114,97,108,105,97,110,78,97,116,105,111,110,97,108,83,112,104,101,114,111,105,100,0,0,0,0,0,0,0,51,68,32,76,85,84,32,105,115,32,101,109,112,116,121,10,0,0,0,0,0,0,0,0,53,47,51,32,119,97,118,101,108,101,116,44,32,111,110,108,121,32,117,115,101,100,32,105,110,32,115,110,111,119,0,0,115,107,105,112,112,105,110,103,32,37,100,32,98,121,116,101,115,32,111,102,32,101,110,100,45,111,102,45,102,114,97,109,101,32,109,97,114,107,101,114,32,99,104,117,110,107,10,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,116,104,101,32,118,97,108,117,101,32,37,100,32,102,111,114,32,116,104,101,32,99,111,109,112,111,110,101,110,116,32,37,100,46,10,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,52,58,52,0,0,0,0,0,0,0,51,48,50,0,0,0,0,0,116,105,108,101,95,99,111,108,117,109,110,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,48,46,46,54,93,0,0,0,0,0,0,0,0,35,10,13,0,0,0,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,32,109,105,115,115,105,110,103,32,69,79,83,32,115,116,97,116,115,32,112,97,99,107,101,116,0,0,0,0,115,101,116,32,103,114,101,101,110,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,102,105,108,101,0,0,0,0,110,111,110,45,115,116,97,110,100,97,114,100,32,99,100,120,108,32,102,105,108,101,10,0,50,45,119,97,121,32,109,97,116,99,104,32,43,32,51,114,100,32,109,97,116,99,104,32,111,110,32,99,111,109,98,101,100,32,43,32,52,116,104,47,53,116,104,32,109,97,116,99,104,101,115,32,105,102,32,115,116,105,108,108,32,99,111,109,98,101,100,32,40,112,47,99,32,43,32,117,32,43,32,117,47,98,41,0,0,0,0,0,100,111,119,110,115,99,97,108,101,95,104,112,101,108,0,0,118,100,112,97,117,95,104,50,54,52,0,0,0,0,0,0,68,97,114,107,66,108,117,101,0,0,0,0,0,0,0,0,86,97,108,117,101,32,37,102,32,102,111,114,32,112,97,114,97,109,101,116,101,114,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,115,101,116,32,111,102,32,51,50,98,105,116,32,105,110,116,101,103,101,114,32,102,108,97,103,115,10,0,0,99,101,105,108,0,0,0,0,69,88,80,69,82,73,77,69,78,84,65,76,0,0,0,0,116,111,112,32,98,97,99,107,32,108,101,102,116,0,0,0,115,101,116,32,104,111,114,105,122,111,110,116,97,108,32,112,111,115,105,116,105,111,110,32,111,102,32,116,104,101,32,108,101,102,116,32,98,111,120,32,101,100,103,101,0,0,0,0,102,97,115,116,32,98,105,108,105,110,101,97,114,0,0,0,100,115,116,119,0,0,0,0,111,117,116,45,62,98,112,115,32,61,61,32,105,110,45,62,98,112,115,0,0,0,0,0,108,101,115,115,32,101,120,104,97,117,115,116,105,118,101,32,115,101,97,114,99,104,0,0,100,101,114,105,110,103,0,0,83,116,121,108,101,0,0,0,105,110,116,114,97,95,114,101,102,114,101,115,104,61,37,100,0,0,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,113,116,0,0,0,0,80,114,101,102,101,114,114,101,100,32,83,116,101,114,101,111,32,68,111,119,110,109,105,120,32,77,111,100,101,0,0,0,80,114,101,102,101,114,114,101,100,32,83,116,101,114,101,111,32,68,111,119,110,109,105,120,32,77,111,100,101,0,0,0,98,97,110,100,119,105,100,116,104,32,99,111,100,101,32,61,32,37,100,32,62,32,54,48,10,0,0,0,0,0,0,0,115,107,105,112,112,105,110,103,32,67,65,70,32,99,104,117,110,107,58,32,37,48,56,88,32,40,37,99,37,99,37,99,37,99,41,44,32,115,105,122,101,32,37,108,108,100,10,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,99,114,111,115,115,111,118,101,114,32,98,97,110,100,32,105,110,100,101,120,32,98,101,121,111,110,100,32,97,114,114,97,121,32,98,111,117,110,100,115,58,32,37,100,10,0,0,0,0,0,0,0,0,84,78,83,32,102,105,108,116,101,114,32,111,114,100,101,114,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,109,97,120,105,109,117,109,32,37,100,46,10,0,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,37,100,32,98,105,116,115,32,108,101,102,116,32,98,101,102,111,114,101,32,100,101,99,111,100,101,95,105,95,98,108,111,99,107,40,41,10,0,0,0,68,97,116,117,109,69,95,65,105,114,121,77,111,100,105,102,105,101,100,49,56,52,57,0,119,53,51,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,116,111,111,32,109,97,110,121,32,102,114,97,109,101,115,32,105,110,32,98,108,111,99,107,10,0,0,0,0,0,0,0,70,108,111,111,114,32,48,32,111,114,100,101,114,32,105,115,32,48,46,10,0,0,0,0,112,114,111,102,105,108,101,32,37,115,44,32,108,101,118,101,108,32,37,115,44,32,37,115,32,37,100,45,98,105,116,10,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,110,111,116,32,102,117,108,108,121,32,114,101,97,100,10,0,0,118,51,48,56,0,0,0,0,79,110,108,121,32,52,58,50,58,48,32,99,104,114,111,109,97,32,102,111,114,109,97,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,33,97,118,112,107,116,45,62,100,97,116,97,32,124,124,32,97,118,112,107,116,45,62,100,97,116,97,32,33,61,32,97,118,99,116,120,45,62,105,110,116,101,114,110,97,108,45,62,98,121,116,101,95,98,117,102,102,101,114,0,0,0,0,0,108,105,116,116,108,101,32,101,110,100,105,97,110,32,98,121,116,101,32,111,114,100,101,114,0,0,0,0,0,0,0,0,70,105,108,101,32,102,111,114,32,112,114,101,115,101,116,32,39,37,115,39,32,110,111,116,32,102,111,117,110,100,10,0,80,114,111,106,67,101,110,116,101,114,78,111,114,116,104,105,110,103,71,101,111,75,101,121,0,0,0,0,0,0,0,0,77,111,100,101,108,84,105,101,112,111,105,110,116,84,97,103,0,0,0,0,0,0,0,0,108,105,103,104,116,101,110,0,73,110,112,117,116,32,105,115,32,108,111,110,103,101,114,32,116,104,97,110,32,50,45,112,97,115,115,32,108,111,103,32,102,105,108,101,10,0,0,0,99,104,114,111,109,97,108,111,99,0,0,0,0,0,0,0,112,115,110,114,0,0,0,0,117,115,101,32,108,111,111,112,32,102,105,108,116,101,114,0,100,99,32,111,118,101,114,102,108,111,119,45,32,98,108,111,99,107,58,32,37,100,32,113,115,99,97,108,101,58,32,37,100,47,47,10,0,0,0,0,100,37,49,91,97,118,93,37,100,37,99,0,0,0,0,0,109,97,120,32,98,32,102,114,97,109,101,115,32,109,117,115,116,32,98,101,32,48,32,111,114,32,112,111,115,105,116,105,118,101,32,102,111,114,32,109,112,101,103,118,105,100,101,111,32,98,97,115,101,100,32,101,110,99,111,100,101,114,115,10,0,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,72,101,97,100,101,114,32,109,105,115,115,105,110,103,10,0,72,101,97,100,101,114,32,109,105,115,115,105,110,103,10,0,101,120,116,101,110,115,105,111,110,32,115,116,97,114,116,0,101,114,114,111,114,95,114,97,116,101,0,0,0,0,0,0,102,105,114,115,116,32,109,98,95,105,110,99,114,32,100,97,109,97,103,101,100,10,0,0,114,101,115,116,97,114,116,32,104,101,97,100,101,114,32,115,121,110,99,32,105,110,99,111,114,114,101,99,116,32,40,103,111,116,32,48,120,37,48,52,120,41,10,0,0,0,0,0,115,101,113,117,101,110,116,105,97,108,32,68,67,84,0,0,65,81,32,115,116,114,101,110,103,116,104,46,32,82,101,100,117,99,101,115,32,98,108,111,99,107,105,110,103,32,97,110,100,32,98,108,117,114,114,105,110,103,32,105,110,32,102,108,97,116,32,97,110,100,32,116,101,120,116,117,114,101,100,32,97,114,101,97,115,46,0,0,86,80,56,69,95,83,69,84,95,65,82,78,82,95,84,89,80,69,0,0,0,0,0,0,78,117,108,108,102,114,97,109,101,32,105,110,115,101,114,116,105,111,110,32,102,108,97,103,32,115,101,116,46,10,0,0,85,110,107,110,111,119,110,32,112,105,120,95,102,109,116,44,32,112,114,111,102,105,108,101,58,32,37,100,44,32,99,111,108,111,117,114,95,115,112,97,99,101,58,32,37,100,44,32,99,111,109,112,111,110,101,110,116,115,58,32,37,100,44,32,112,114,101,99,105,115,105,111,110,58,32,37,100,44,32,99,100,120,91,49,93,58,32,37,100,44,32,99,100,121,91,49,93,58,32,37,100,44,32,99,100,120,91,50,93,58,32,37,100,44,32,99,100,121,91,50,93,58,32,37,100,10,0,0,123,92,98,48,125,0,0,0,100,105,109,101,110,115,105,111,110,115,32,48,10,0,0,0,77,105,115,115,105,110,103,32,102,108,97,103,32,116,101,114,109,105,110,97,116,111,114,32,111,114,32,101,120,116,114,97,110,101,111,117,115,32,100,97,116,97,32,102,111,117,110,100,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,102,108,97,103,115,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,0,0,0,0,112,112,115,95,99,98,95,113,112,95,111,102,102,115,101,116,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,84,104,101,32,115,108,105,99,101,95,113,112,32,37,100,32,105,115,32,111,117,116,115,105,100,101,32,116,104,101,32,118,97,108,105,100,32,114,97,110,103,101,32,91,37,100,44,32,53,49,93,46,10,0,0,0,120,98,105,110,0,0,0,0,84,114,117,110,99,97,116,101,100,32,86,85,73,10,0,0,99,111,110,115,117,109,101,100,95,115,97,109,112,108,101,115,95,110,0,0,0,0,0,0,72,105,103,104,32,52,58,52,58,52,32,80,114,101,100,105,99,116,105,118,101,0,0,0,70,76,65,67,32,101,110,99,111,100,101,114,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,76,116,47,82,116,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,67,111,114,101,32,97,117,120,105,108,105,97,114,121,32,100,97,116,97,32,114,101,115,101,114,118,101,100,32,99,111,110,116,101,110,116,0,0,0,0,118,101,114,98,111,115,101,32,108,111,103,103,105,110,103,32,108,101,118,101,108,0,0,0,102,114,97,109,101,32,37,108,108,100,58,32,97,117,100,105,111,32,115,105,122,101,32,105,110,32,104,101,97,100,101,114,32,40,37,117,41,32,62,32,115,105,122,101,32,111,102,32,112,97,99,107,101,116,32,108,101,102,116,32,40,37,117,41,10,0,0,0,0,0,0,0,119,109,118,50,0,0,0,0,68,97,116,117,109,69,95,65,105,114,121,49,56,51,48,0,110,111,105,115,101,32,112,114,101,115,101,114,118,105,110,103,32,115,117,109,32,111,102,32,115,113,117,97,114,101,100,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,97,117,100,105,111,32,98,108,111,99,107,10,0,71,97,109,101,0,0,0,0,65,108,108,111,119,101,100,32,116,104,114,101,97,100,32,116,121,112,101,115,0,0,0,0,80,105,110,110,97,99,108,101,32,84,65,82,71,65,32,67,105,110,101,87,97,118,101,32,89,85,86,49,54,0,0,0,52,50,48,80,65,76,68,86,0,0,0,0,0,0,0,0,98,97,100,32,102,105,108,101,110,97,109,101,32,108,101,110,103,116,104,44,32,114,101,109,97,105,110,105,110,103,32,100,105,114,101,99,116,111,114,121,32,101,110,116,114,105,101,115,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,0,65,108,119,97,121,115,32,119,114,105,116,101,32,82,70,54,52,32,104,101,97,100,101,114,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,102,105,108,101,32,115,105,122,101,46,0,0,0,0,0,0,0,82,73,70,70,0,0,0,0,112,114,111,100,117,99,101,114,0,0,0,0,0,0,0,0,66,112,115,32,37,100,32,97,110,100,32,115,105,103,110,32,37,100,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,101,115,99,97,112,101,32,77,80,108,97,121,101,114,32,102,105,108,116,101,114,115,32,97,114,103,32,39,37,115,39,10,0,0,0,0,0,0,78,111,110,45,105,110,99,114,101,97,115,105,110,103,32,68,84,83,32,105,110,32,115,116,114,101,97,109,32,37,100,58,32,112,97,99,107,101,116,32,37,100,32,119,105,116,104,32,68,84,83,32,37,108,108,100,44,32,112,97,99,107,101,116,32,37,100,32,119,105,116,104,32,68,84,83,32,37,108,108,100,10,0,0,0,0,0,0,110,111,32,118,105,100,101,111,32,115,116,114,101,97,109,32,97,110,100,32,110,111,32,109,105,110,32,102,114,97,103,32,100,117,114,97,116,105,111,110,32,115,101,116,10,0,0,0,80,108,101,97,115,101,32,117,115,101,32,45,112,114,101,115,101,116,32,60,115,112,101,101,100,62,32,45,113,112,32,48,10,0,0,0,0,0,0,0,112,112,0,0,0,0,0,0,33,115,45,62,119,114,105,116,101,95,102,108,97,103,0,0,68,97,116,117,109,95,78,111,114,100,95,100,101,95,71,117,101,114,114,101,0,0,0,0,110,115,115,101,0,0,0,0,116,97,114,103,97,95,121,50,49,54,0,0,0,0,0,0,104,116,116,112,115,58,0,0,108,105,98,120,50,54,52,45,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,65,86,79,112,116,105,111,110,32,39,37,115,39,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,39,37,115,39,46,10,0,0,104,108,115,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,80,67,77,65,47,37,100,47,37,100,13,10,0,0,0,0,0,0,0,0,112,105,120,100,101,115,99,116,101,115,116,0,0,0,0,0,117,110,107,110,111,119,110,32,111,112,116,105,111,110,58,32,39,37,99,39,0,0,0,0,76,73,83,84,0,0,0,0,72,97,110,110,32,119,105,110,100,111,119,0,0,0,0,0,114,97,119,32,72,46,50,54,52,32,118,105,100,101,111,0,115,116,114,101,97,109,95,105,110,100,101,120,32,62,61,32,48,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,68,97,116,117,109,95,65,110,99,105,101,110,110,101,95,84,114,105,97,110,103,117,108,97,116,105,111,110,95,70,114,97,110,99,97,105,115,101,0,0,115,117,109,32,111,102,32,115,113,117,97,114,101,100,32,118,101,114,116,105,99,97,108,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,77,83,32,52,58,52,58,52,58,52,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,99,111,100,101,99,58,100,0,99,114,121,112,116,111,107,101,121,0,0,0,0,0,0,0,76,111,111,112,115,116,97,114,116,32,118,97,108,117,101,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,97,110,100,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,0,100,101,112,116,104,32,37,100,0,0,0,0,0,0,0,0,109,111,118,32,109,117,120,101,114,0,0,0,0,0,0,0,97,115,115,44,115,115,97,0,85,84,70,45,56,0,0,0,37,115,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,109,97,116,101,114,105,97,108,32,116,114,97,99,107,32,115,101,113,117,101,110,99,101,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,95,95,78,85,77,95,73,95,84,82,65,67,75,83,0,0,97,115,102,44,119,109,118,44,119,109,97,0,0,0,0,0,112,114,101,118,95,102,111,114,99,101,100,95,116,0,0,0,83,101,116,32,111,114,105,103,105,110,97,108,95,110,101,116,119,111,114,107,95,105,100,32,102,105,101,108,100,46,0,0,112,105,100,32,37,120,32,105,115,32,110,111,116,32,80,69,83,10,0,0,0,0,0,0,109,117,120,32,114,97,116,101,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,68,97,116,117,109,95,87,71,83,56,52,0,0,0,0,0,118,115,115,101,0,0,0,0,37,115,10,0,0,0,0,0,97,121,117,118,0,0,0,0,69,110,97,98,108,101,32,73,68,51,118,49,32,119,114,105,116,105,110,103,46,32,73,68,51,118,49,32,116,97,103,115,32,97,114,101,32,119,114,105,116,116,101,110,32,105,110,32,85,84,70,45,56,32,119,104,105,99,104,32,109,97,121,32,110,111,116,32,98,101,32,115,117,112,112,111,114,116,101,100,32,98,121,32,109,111,115,116,32,115,111,102,116,119,97,114,101,46,0,0,0,0,0,0,100,105,115,97,98,108,101,32,100,97,116,97,0,0,0,0,77,79,86,32,109,117,120,101,114,32,102,108,97,103,115,0,83,69,69,75,84,79,58,32,37,108,108,100,10,0,0,0,108,111,99,97,116,105,111,110,0,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,32,45,45,62,32,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,0,0,0,73,110,118,97,108,105,100,32,116,97,103,32,115,105,122,101,32,37,117,46,10,0,0,0,70,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,99,111,100,101,99,32,112,114,105,118,97,116,101,32,100,97,116,97,10,0,0,0,0,105,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,32,101,108,101,109,101,110,116,0,0,68,97,116,117,109,95,87,71], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2320544);
/* memory initializer */ allocate([83,55,50,95,84,114,97,110,115,105,116,95,66,114,111,97,100,99,97,115,116,95,69,112,104,101,109,101,114,105,115,0,67,111,117,108,100,32,102,105,110,100,32,110,111,32,102,105,108,101,32,119,105,116,104,32,112,97,116,104,32,39,37,115,39,32,97,110,100,32,105,110,100,101,120,32,105,110,32,116,104,101,32,114,97,110,103,101,32,37,100,45,37,100,10,0,115,117,109,32,111,102,32,97,98,115,111,108,117,116,101,32,118,101,114,116,105,99,97,108,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,105,109,51,50,0,0,0,0,65,118,105,100,32,77,101,114,105,100,105,101,110,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,0,0,100,110,0,0,0,0,0,0,84,83,79,80,0,0,0,0,73,86,61,0,0,0,0,0,109,105,110,105,109,117,109,32,102,114,97,103,109,101,110,116,32,100,117,114,97,116,105,111,110,32,40,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,41,0,0,0,0,0,118,105,100,101,111,99,111,100,101,99,105,100,0,0,0,0,102,108,118,100,101,99,0,0,112,104,97,115,101,0,0,0,78,79,80,84,83,0,0,0,68,97,116,117,109,95,87,71,83,55,50,0,0,0,0,0,118,115,97,100,0,0,0,0,97,118,117,105,0,0,0,0,102,111,114,99,101,32,100,97,116,97,32,99,111,100,101,99,32,40,39,99,111,112,121,39,32,116,111,32,99,111,112,121,32,115,116,114,101,97,109,41,0,0,0,0,0,0,0,0,84,111,111,32,100,101,101,112,108,121,32,110,101,115,116,101,100,32,79,68,77,76,32,105,110,100,101,120,101,115,10,0,69,120,116,32,68,82,77,32,112,114,111,116,101,99,116,101,100,32,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,44,32,100,101,99,111,100,105,110,103,32,119,105,108,108,32,108,105,107,101,108,121,32,102,97,105,108,33,10,0,0,100,101,102,97,117,108,116,0,68,97,116,117,109,95,67,111,110,97,107,114,121,95,49,57,48,53,0,0,0,0,0,0,48,0,0,0,0,0,0,0,111,99,116,97,118,101,0,0,48,49,50,118,0,0,0,0,100,99,111,100,101,99,0,0,105,110,118,101,114,116,101,100,32,112,97,114,97,98,111,108,97,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,99,111,100,101,99,10,0,0,0,110,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,112,98,105,45,62,116,105,108,101,95,119,111,114,107,101,114,115,0,0,0,0,115,101,116,32,110,111,114,109,97,108,105,122,101,100,32,105,116,101,114,97,116,105,111,110,32,99,111,117,110,116,32,109,111,100,101,0,0,0,0,0,115,116,97,114,116,105,0,0,33,102,115,45,62,102,114,97,109,101,95,114,101,97,100,121,0,0,0,0,0,0,0,0,115,104,111,119,32,98,117,105,108,100,32,99,111,110,102,105,103,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,108,105,102,101,95,99,111,108,111,114,0,0,0,0,0,0,115,116,105,116,99,104,32,98,111,117,110,100,97,114,105,101,115,0,0,0,0,0,0,0,115,101,116,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,0,0,0,68,97,116,117,109,95,68,101,117,116,115,99,104,101,95,72,97,117,112,116,100,114,101,105,101,99,107,115,110,101,116,122,0,0,0,0,0,0,0,0,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,97,108,44,32,115,108,111,119,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,118,99,111,100,101,99,46,99,0,0,0,65,118,105,100,32,49,58,49,32,49,48,45,98,105,116,32,82,71,66,32,80,97,99,107,101,114,0,0,0,0,0,0,97,110,97,103,108,121,112,104,32,114,101,100,32,98,108,117,101,32,103,114,97,121,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,111,112,116,105,111,110,115,32,102,114,111,109,32,105,110,100,105,99,97,116,101,100,32,112,114,101,115,101,116,32,102,105,108,101,0,0,106,112,101,103,0,0,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,116,114,97,110,115,102,111,114,109,32,115,105,122,101,46,34,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,78,97,78,32,102,111,114,32,118,111,108,117,109,101,44,32,115,101,116,116,105,110,103,32,116,111,32,48,10,0,0,0,0,0,115,112,101,99,105,102,121,32,119,104,101,110,32,116,111,32,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,116,120,45,62,122,99,111,101,102,102,95,98,108,107,0,0,0,0,0,0,99,50,115,0,0,0,0,0,115,101,116,32,110,111,105,115,101,32,116,111,108,101,114,97,110,99,101,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,46,10,0,0,0,0,0,68,97,116,117,109,95,82,101,115,101,97,117,95,78,97,116,105,111,110,97,108,95,66,101,108,103,101,95,49,57,55,50,0,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,39,46,37,115,39,32,102,105,108,101,32,116,121,112,101,10,0,0,0,114,100,0,0,0,0,0,0,116,114,97,99,107,95,112,101,97,107,32,61,32,37,46,54,102,10,0,0,0,0,0,0,97,118,114,112,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,112,97,114,115,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,102,111,114,32,116,104,101,32,99,111,109,112,111,110,101,110,116,32,37,100,32,97,110,100,32,99,111,108,111,114,32,37,100,46,10,0,0,0,0,0,0,110,111,105,115,101,95,115,101,110,115,105,116,105,118,105,116,121,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,54,93,0,0,0,0,102,112,114,101,0,0,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,32,114,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,116,119,111,32,112,97,99,107,101,116,115,46,0,0,0,0,0,0,103,114,101,101,110,95,101,120,112,114,0,0,0,0,0,0,77,52,65,32,0,0,0,0,112,101,114,115,112,101,99,116,105,118,101,0,0,0,0,0,124,0,0,0,0,0,0,0,112,99,95,110,95,117,98,0,115,117,109,95,105,110,116,114,97,95,99,111,115,116,0,0,121,117,118,97,52,50,48,112,0,0,0,0,0,0,0,0,67,121,97,110,0,0,0,0,86,97,108,117,101,32,37,102,32,102,111,114,32,112,97,114,97,109,101,116,101,114,32,39,37,115,39,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,37,103,32,45,32,37,103,93,10,0,0,0,0,0,102,108,111,111,114,0,0,0,85,110,107,110,111,119,110,32,101,114,114,111,114,32,111,99,99,117,114,114,101,100,0,0,84,66,76,0,0,0,0,0,105,110,118,101,114,116,0,0,98,105,108,105,110,101,97,114,0,0,0,0,0,0,0,0,115,111,117,114,99,101,32,104,101,105,103,104,116,0,0,0,105,110,112,117,116,37,100,0,111,117,116,45,62,112,108,97,110,97,114,32,61,61,32,105,110,45,62,112,108,97,110,97,114,0,0,0,0,0,0,0,108,101,115,115,0,0,0,0,100,114,0,0,0,0,0,0,70,111,114,109,97,116,0,0,65,68,80,67,77,32,73,77,65,32,68,105,97,108,111,103,105,99,32,79,75,73,0,0,105,110,116,114,97,95,114,101,102,114,101,115,104,61,0,0,100,109,105,120,95,109,111,100,101,0,0,0,0,0,0,0,100,109,105,120,95,109,111,100,101,0,0,0,0,0,0,0,87,97,114,110,105,110,103,58,32,110,101,119,32,114,101,109,97,116,114,105,120,105,110,103,32,115,116,114,97,116,101,103,121,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,95,109,97,115,116,101,114,58,32,37,100,10,0,0,0,101,114,114,111,114,32,105,110,32,115,112,101,99,116,114,97,108,32,100,97,116,97,44,32,69,83,67,32,111,118,101,114,102,108,111,119,10,0,0,0,101,110,100,32,109,105,115,109,97,116,99,104,10,0,0,0,112,114,101,115,101,116,95,110,97,109,101,0,0,0,0,0,68,97,116,117,109,95,77,105,108,105,116,97,114,95,71,101,111,103,114,97,112,104,105,115,99,104,101,95,73,110,115,116,105,116,117,116,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,110,101,101,100,101,100,32,102,111,114,32,116,104,101,32,98,108,111,99,107,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,114,97,116,101,10,0,0,0,0,0,0,70,108,111,111,114,32,118,97,108,117,101,32,105,115,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,98,108,111,99,107,115,105,122,101,58,32,37,117,32,40,37,117,41,10,0,0,0,0,0,0,0,0,52,58,52,58,52,0,0,0,66,117,102,102,101,114,32,111,118,101,114,114,117,110,10,0,79,112,101,110,69,88,82,32,105,109,97,103,101,0,0,0,82,101,115,101,114,118,101,100,32,76,69,86,69,76,32,37,105,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,109,105,110,105,109,117,109,32,114,101,113,117,105,114,101,100,32,112,97,99,107,101,116,32,115,105,122,101,32,37,108,108,100,32,40,109,97,120,32,97,108,108,111,119,101,100,32,105,115,32,37,100,41,10,0,0,118,115,117,98,0,0,0,0,115,101,116,32,116,104,101,32,115,117,98,116,105,116,108,101,32,111,112,116,105,111,110,115,32,116,111,32,116,104,101,32,105,110,100,105,99,97,116,101,100,32,112,114,101,115,101,116,0,0,0,0,0,0,0,0,115,101,116,32,116,105,109,101,32,111,118,101,114,32,119,104,105,99,104,32,105,110,99,114,101,97,115,101,32,111,102,32,118,111,108,117,109,101,32,105,115,32,100,101,116,101,114,109,105,110,101,100,0,0,0,0,80,114,111,106,67,101,110,116,101,114,69,97,115,116,105,110,103,71,101,111,75,101,121,0,77,111,100,101,108,84,114,97,110,115,102,111,114,109,97,116,105,111,110,84,97,103,0,0,104,97,114,100,108,105,103,104,116,0,0,0,0,0,0,0,115,116,117,102,102,105,110,103,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,99,111,108,111,114,109,97,116,114,105,120,0,0,0,0,0,77,52,86,32,0,0,0,0,108,111,111,112,0,0,0,0,73,32,102,114,97,109,101,32,116,111,111,32,108,111,110,103,44,32,105,103,110,111,114,105,110,103,32,101,120,116,32,104,101,97,100,101,114,10,0,0,85,110,97,98,108,101,32,116,111,32,108,111,111,112,58,32,37,115,10,0,0,0,0,0,98,32,102,114,97,109,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,73,68,51,32,116,97,103,10,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,73,68,51,32,116,97,103,10,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,32,109,97,112,112,101,100,58,32,39,37,100,39,46,10,0,0,0,0,0,0,0,0,115,108,105,99,101,32,115,116,97,114,116,0,0,0,0,0,113,117,97,110,116,105,122,101,114,95,110,111,105,115,101,95,115,104,97,112,105,110,103,0,84,111,111,32,109,97,110,121,32,102,114,97,99,116,105,111,110,97,108,32,98,105,116,115,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,0,97,113,45,115,116,114,101,110,103,116,104,0,0,0,0,0,86,80,56,69,95,83,69,84,95,65,82,78,82,95,83,84,82,69,78,71,84,72,0,0,77,117,108,116,105,116,104,114,101,97,100,32,101,110,99,111,100,101,114,32,102,108,97,103,32,115,101,116,46,10,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,115,101,112,97,114,97,116,105,111,110,32,37,100,47,37,100,10,0,0,0,0,0,0,0,0,92,98,0,0,0,0,0,0,117,110,111,114,100,101,114,101,100,32,115,108,105,99,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,73,110,118,97,108,105,100,32,102,108,97,103,115,32,99,104,97,114,32,39,37,99,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,0,83,80,83,32,37,117,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,46,10,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,10,0,0,0,0,0,0,105,108,108,101,103,97,108,32,97,115,112,101,99,116,32,114,97,116,105,111,10,0,0,0,66,79,84,84,79,77,70,73,82,83,84,0,0,0,0,0,72,105,103,104,32,52,58,52,58,52,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,108,97,99,101,110,99,46,99,0,0,0,0,102,108,111,97,116,0,0,0,108,116,114,116,95,99,109,105,120,108,101,118,0,0,0,0,79,118,101,114,114,101,97,100,32,97,117,120,105,108,105,97,114,121,32,100,97,116,97,32,98,121,32,37,100,32,98,105,116,115,10,0,0,0,0,0,118,101,114,98,111,115,101,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,55,0,0,0,68,97,116,117,109,95,90,97,110,100,101,114,105,106,0,0,98,105,116,0,0,0,0,0,72,111,117,115,101,0,0,0,116,104,114,101,97,100,95,116,121,112,101,0,0,0,0,0,101,120,114,0,0,0,0,0,52,50,48,77,80,69,71,50,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,103,117,105,100,32,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,44,32,101,120,112,101,99,116,101,100,32,100,105,114,95,101,110,116,114,121,95,103,117,105,100,59,32,114,101,109,97,105,110,105,110,103,32,100,105,114,101,99,116,111,114,121,32,101,110,116,114,105,101,115,32,105,103,110,111,114,101,100,10,0,0,0,0,97,108,119,97,121,115,0,0,87,65,86,69,0,0,0,0,80,82,79,68,0,0,0,0,58,61,0,0,0,0,0,0,83,116,114,101,97,109,32,35,37,100,58,32,110,111,116,32,101,110,111,117,103,104,32,102,114,97,109,101,115,32,116,111,32,101,115,116,105,109,97,116,101,32,114,97,116,101,59,32,99,111,110,115,105,100,101,114,32,105,110,99,114,101,97,115,105,110,103,32,112,114,111,98,101,115,105,122,101,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,97,117,100,105,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,115,112,114,101,0,0,0,0,66,111,111,115,116,32,111,114,32,99,117,116,32,108,111,119,101,114,32,102,114,101,113,117,101,110,99,105,101,115,46,0,73,110,118,97,108,105,100,32,116,101,109,112,111,32,118,97,108,117,101,32,39,37,115,39,10,0,0,0,0,0,0,0,98,49,0,0,0,0,0,0,68,97,116,117,109,95,89,111,102,102,0,0,0,0,0,0,102,105,108,101,32,101,114,114,111,114,0,0,0,0,0,0,115,117,109,32,111,102,32,115,113,117,97,114,101,100,32,113,117,97,110,116,105,122,97,116,105,111,110,32,101,114,114,111,114,115,32,40,97,118,111,105,100,44,32,108,111,119,32,113,117,97,108,105,116,121,41,0,69,115,99,97,112,101,32,49,51,48,0,0,0,0,0,0,68,67,32,111,102,102,115,101,116,58,32,37,102,10,0,0,115,101,116,32,116,104,101,32,118,105,100,101,111,32,111,112,116,105,111,110,115,32,116,111,32,116,104,101,32,105,110,100,105,99,97,116,101,100,32,112,114,101,115,101,116,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,111,112,116,105,111,110,32,39,37,115,39,32,40,37,115,41,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,39,37,115,39,46,10,0,0,0,0,0,0,0,110,58,37,108,108,100,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,112,111,115,58,37,108,108,100,32,102,109,116,58,37,115,32,99,104,97,110,110,101,108,115,58,37,100,32,99,104,108,97,121,111,117,116,58,37,115,32,114,97,116,101,58,37,100,32,110,98,95,115,97,109,112,108,101,115,58,37,100,32,99,104,101,99,107,115,117,109,58,37,48,56,88,32,0,0,77,51,85,56,32,102,111,114,109,97,116,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,80,67,77,85,47,37,100,47,37,100,13,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,105,110,118,97,108,105,100,32,119,105,110,100,111,119,32,115,105,122,101,0,0,0,0,0,104,97,110,110,0,0,0,0,110,98,95,111,117,116,95,115,97,109,112,108,101,115,0,0,104,50,54,52,0,0,0,0,42,116,111,112,95,105,110,100,101,120,32,60,61,32,114,99,45,62,119,111,114,115,116,95,113,117,97,108,105,116,121,32,38,38,32,42,116,111,112,95,105,110,100,101,120,32,62,61,32,114,99,45,62,98,101,115,116,95,113,117,97,108,105,116,121,0,0,0,0,0,0,0,111,99,108,0,0,0,0,0,117,49,54,108,101,0,0,0,68,97,116,117,109,95,89,97,99,97,114,101,0,0,0,0,115,117,109,32,111,102,32,97,98,115,111,108,117,116,101,32,68,67,84,32,116,114,97,110,115,102,111,114,109,101,100,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,0,101,115,99,97,112,101,49,51,48,0,0,0,0,0,0,0,117,49,54,108,101,0,0,0,111,117,116,95,103,97,105,110,32,109,97,121,32,99,97,117,115,101,32,99,108,105,112,112,105,110,103,10,0,0,0,0,118,112,114,101,0,0,0,0,115,112,101,99,105,102,121,32,104,111,119,32,109,97,110,121,32,109,105,99,114,111,115,101,99,111,110,100,115,32,97,114,101,32,97,110,97,108,121,122,101,100,32,116,111,32,112,114,111,98,101,32,116,104,101,32,105,110,112,117,116,0,0,0,112,97,99,107,101,116,95,115,105,122,101,0,0,0,0,0,79,103,103,32,109,117,120,101,114,0,0,0,0,0,0,0,51,103,50,97,0,0,0,0,69,114,114,111,114,32,115,116,114,101,97,109,95,105,100,95,112,108,117,115,49,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,0,0,0,112,97,100,0,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,105,110,112,117,116,32,108,105,110,107,10,0,0,0,0,0,83,65,77,80,76,69,95,87,73,68,84,72,0,0,0,0,109,112,101,103,116,115,95,111,114,105,103,105,110,97,108,95,110,101,116,119,111,114,107,95,105,100,0,0,0,0,0,0,115,101,114,118,105,99,101,95,112,114,111,118,105,100,101,114,0,0,0,0,0,0,0,0,98,117,102,102,101,114,32,115,105,122,101,32,37,100,44,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,68,97,116,117,109,95,83,116,111,99,107,104,111,108,109,95,49,57,51,56,0,0,0,0,115,117,109,32,111,102,32,97,98,115,111,108,117,116,101,32,72,97,100,97,109,97,114,100,32,116,114,97,110,115,102,111,114,109,101,100,32,100,105,102,102,101,114,101,110,99,101,115,0,0,0,0,0,0,0,0,85,115,105,110,103,32,34,37,115,34,32,102,111,114,32,105,110,112,117,116,32,37,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,108,97,110,103,105,100,120,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,89,85,86,32,52,58,49,58,49,32,49,50,45,98,105,116,0,0,0,119,114,105,116,101,95,105,100,51,118,49,0,0,0,0,0,115,101,116,32,116,104,101,32,97,117,100,105,111,32,111,112,116,105,111,110,115,32,116,111,32,116,104,101,32,105,110,100,105,99,97,116,101,100,32,112,114,101,115,101,116,0,0,0,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,51,103,50,98,0,0,0,0,109,111,118,102,108,97,103,115,0,0,0,0,0,0,0,0,109,111,100,101,108,0,0,0,37,46,42,115,10,37,46,42,115,10,37,46,42,115,0,0,115,101,116,32,116,104,101,32,102,97,100,101,32,100,105,114,101,99,116,105,111,110,0,0,85,110,115,117,112,112,111,114,116,101,100,32,101,110,99,111,100,105,110,103,32,116,121,112,101,0,0,0,0,0,0,0,68,97,116,117,109,95,78,111,114,100,95,83,97,104,97,114,97,95,49,57,53,57,0,0,92,42,63,91,93,123,125,0,115,97,116,100,0,0,0,0,105,109,50,52,0,0,0,0,78,117,109,98,101,114,32,111,102,32,100,101,108,97,121,115,32,37,100,32,100,105,102,102,101,114,115,32,102,114,111,109,32,110,117,109,98,101,114,32,111,102,32,100,101,99,97,121,115,32,37,100,46,10,0,0,121,52,49,112,0,0,0,0,40,33,116,121,112,101,32,38,38,32,33,112,108,97,110,101,41,32,124,124,32,40,116,121,112,101,32,38,38,32,112,108,97,110,101,41,0,0,0,0,97,112,114,101,0,0,0,0,97,108,98,117,109,45,115,111,114,116,0,0,0,0,0,0,115,101,116,32,108,105,115,116,32,111,102,32,100,101,108,97,121,115,32,102,111,114,32,101,97,99,104,32,99,104,97,110,110,101,108,0,0,0,0,0,85,82,73,61,0,0,0,0,109,105,110,95,102,114,97,103,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,51,103,112,52,0,0,0,0,97,117,116,111,0,0,0,0,110,117,109,95,56,120,56,95,98,108,111,99,107,115,95,119,105,100,101,95,108,111,111,107,117,112,91,98,115,105,122,101,93,32,61,61,32,110,117,109,95,56,120,56,95,98,108,111,99,107,115,95,104,105,103,104,95,108,111,111,107,117,112,91,98,115,105,122,101,93,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,111,119,100,101,110,111,105,115,101,0,0,0,0,0,0,0,66,114,111,107,101,110,32,70,76,86,32,102,105,108,101,44,32,119,104,105,99,104,32,115,97,121,115,32,110,111,32,115,116,114,101,97,109,115,32,112,114,101,115,101,110,116,44,32,116,104,105,115,32,109,105,103,104,116,32,102,97,105,108,10,0,0,0,0,0,0,0,0,97,118,95,105,110,116,101,114,108,101,97,118,101,100,95,119,114,105,116,101,95,102,114,97,109,101,40,41,0,0,0,0,70,105,108,116,101,114,32,97,117,100,105,111,32,115,105,103,110,97,108,32,97,99,99,111,114,100,105,110,103,32,116,111,32,97,32,115,112,101,99,105,102,105,101,100,32,101,120,112,114,101,115,115,105,111,110,46,0,0,0,0,0,0,0,0,68,97,116,117,109,95,66,101,114,110,95,49,57,51,56,0,115,117,109,32,111,102,32,115,113,117,97,114,101,100,32,101,114,114,111,114,115,0,0,0,42,116,111,107,32,60,32,116,111,107,95,101,110,100,0,0,65,112,112,108,101,32,73,110,116,101,114,109,101,100,105,97,116,101,32,67,111,100,101,99,0,0,0,0,0,0,0,0,109,105,95,99,111,108,32,62,61,32,48,32,38,38,32,109,105,95,99,111,108,32,60,32,99,109,45,62,109,105,95,99,111,108,115,0,0,0,0,0,118,105,100,101,111,32,98,105,116,115,116,114,101,97,109,95,102,105,108,116,101,114,115,0,118,112,114,112,0,0,0,0,79,68,77,76,32,105,110,100,101,120,32,105,110,118,97,108,105,100,10,0,0,0,0,0,65,83,70,95,76,105,99,101,110,115,101,95,85,82,76,0,51,103,112,54,0,0,0,0,80,114,111,118,105,100,101,32,97,110,32,105,100,101,110,116,105,116,121,32,72,97,108,100,32,67,76,85,84,46,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,109,97,120,95,116,120,95,115,105,122,101,46,34,0,0,0,0,0,114,97,116,101,0,0,0,0,101,118,97,108,32,118,111,108,117,109,101,32,101,120,112,114,101,115,115,105,111,110,32,112,101,114,45,102,114,97,109,101,0,0,0,0,0,0,0,0,68,97,116,117,109,95,86,111,105,114,111,108,95,85,110,105,102,105,101,95,49,57,54,48,0,0,0,0,0,0,0,0,115,115,101,0,0,0,0,0,111,0,0,0,0,0,0,0,97,105,99,0,0,0,0,0,65,32,115,116,114,101,97,109,32,109,117,115,116,32,115,116,97,114,116,32,119,105,116,104,32,97,32,99,111,109,112,108,101,116,101,32,107,101,121,32,102,114,97,109,101,0,0,0,118,98,115,102,0,0,0,0,45,115,101,103,95,100,97,116,97,32,60,61,32,115,101,103,95,102,101,97,116,117,114,101,95,100,97,116,97,95,109,97,120,91,102,101,97,116,117,114,101,95,105,100,93,0,0,0,115,101,116,32,102,114,97,109,101,32,115,105,122,101,0,0,48,0,0,0,0,0,0,0,112,97,114,0,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,100,101,99,105,109,97,108,115,32,116,111,32,115,104,111,119,0,0,116,105,108,101,95,114,111,119,115,32,61,61,32,49,0,0,110,111,114,109,97,108,105,122,101,100,95,105,116,101,114,97,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,100,117,114,97,116,105,111,110,105,0,0,0,0,0,0,0,115,101,116,32,109,111,108,100,32,115,112,101,101,100,32,102,111,114,32,100,101,97,100,32,99,101,108,108,115,0,0,0,115,116,105,116,99,104,0,0,98,115,105,122,101,32,61,61,32,66,76,79,67,75,95,56,88,56,0,0,0,0,0,0,98,117,105,108,100,99,111,110,102,0,0,0,0,0,0,0,97,115,112,101,99,116,0,0,68,97,116,117,109,95,86,111,105,114,111,108,95,49,56,55,53,0,0,0,0,0,0,0,115,117,109,32,111,102,32,97,98,115,111,108,117,116,101,32,100,105,102,102,101,114,101,110,99,101,115,44,32,102,97,115,116,32,40,100,101,102,97,117,108,116,41,0,0,0,0,0,77,83,32,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,86,57,32,83,99,114,101,101,110,0,0,0,0,0,0,0,0,115,101,103,109,101,110,116,95,105,100,32,62,61,32,48,32,38,38,32,115,101,103,109,101,110,116,95,105,100,32,60,32,77,65,88,95,83,69,71,77,69,78,84,83,0,0,0,0,97,114,98,103,0,0,0,0,97,117,100,105,111,32,98,105,116,115,116,114,101,97,109,95,102,105,108,116,101,114,115,0,51,50,48,120,53,49,56,0,102,117,108,108,0,0,0,0,68,105,114,101,99,116,32,112,97,100,100,105,110,103,32,105,109,112,111,115,115,105,98,108,101,32,97,108,108,111,99,97,116,105,110,103,32,110,101,119,32,102,114,97,109,101,10,0,33,40,108,102,109,45,62,108,101,102,116,95,121,91,84,88,95,56,88,56,93,32,38,32,108,102,109,45,62,108,101,102,116,95,121,91,84,88,95,52,88,52,93,41,0,0,0,0,101,118,97,108,0,0,0,0,46,47,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,98,108,111,99,107,46,104,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,105,110,116,101,114,108,97,99,105,110,103,32,109,111,100,101,0,0,0,0,37,50,53,53,91,94,58,61,93,0,0,0,0,0,0,0,68,97,116,117,109,95,84,114,117,99,105,97,108,95,67,111,97,115,116,95,49,57,52,56,0,0,0,0,0,0,0,0,115,97,100,0,0,0,0,0,109,51,100,0,0,0,0,0,109,115,115,50,0,0,0,0,100,101,102,97,117,108,116,0,115,112,101,99,105,102,121,32,116,104,101,32,102,105,108,116,101,114,0,0,0,0,0,0,99,112,117,95,117,115,101,100,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,45,49,54,46,46,49,54,93,0,100,101,112,114,101,99,97,116,101,100,0,0,0,0,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,46,115,122,32,105,110,100,105,99,97,116,101,115,32,116,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,46,0,0,0,0,0,0,100,101,102,97,117,108,116,0,121,95,115,116,101,112,95,113,52,32,60,61,32,56,48,0,115,101,116,32,114,101,100,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,50,45,119,97,121,32,109,97,116,99,104,32,43,32,51,114,100,32,109,97,116,99,104,32,40,115,97,109,101,32,111,114,100,101,114,41,32,111,110,32,99,111,109,98,101,100,32,40,112,47,99,32,43,32,117,41,0,0,0,0,0,0,0,0,109,98,95,105,110,116,114,97,95,99,111,115,116,95,115,97,116,100,95,56,120,56,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,39,120,48,39,10,0,0,0,0,121,117,118,106,52,52,48,112,0,0,0,0,0,0,0,0,67,114,105,109,115,111,110,0,114,111,111,116,0,0,0,0,85,78,75,78,79,87,78,0,116,111,112,32,102,114,111,110,116,32,114,105,103,104,116,0,115,97,114,0,0,0,0,0,98,115,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,0,0,0,0,0,108,117,109,97,32,98,105,99,117,98,105,99,32,47,32,99,104,114,111,109,97,32,98,105,108,105,110,101,97,114,0,0,115,114,99,104,0,0,0,0,99,111,109,112,101,110,115,97,116,105,110,103,32,97,117,100,105,111,32,116,105,109,101,115,116,97,109,112,32,100,114,105,102,116,58,37,102,32,99,111,109,112,101,110,115,97,116,105,111,110,58,37,100,32,105,110,58,37,100,10,0,0,0,0,101,120,104,97,117,115,116,105,118,101,32,115,101,97,114,99,104,0,0,0,0,0,0,0,97,118,100,101,98,108,111,99,107,0,0,0,0,0,0,0,86,52,43,32,83,116,121,108,101,115,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,111,107,105,0,0,0,100,105,102,102,101,114,101,110,116,32,98,95,112,121,114,97,109,105,100,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,79,114,105,103,105,110,97,108,32,66,105,116,32,83,116,114,101,97,109,0,0,0,0,0,79,114,105,103,105,110,97,108,32,66,105,116,32,83,116,114,101,97,109,0,0,0,0,0,110,101,119,32,99,111,117,112,108,105,110,103,32,99,111,111,114,100,105,110,97,116,101,115,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,73,110,118,97,108,105,100,32,118,68,107,49,91,37,100,93,58,32,37,100,10,0,0,0,83,83,82,0,0,0,0,0,112,114,101,115,116,114,101,97,109,32,60,61,32,98,117,102,32,43,32,108,101,110,103,116,104,0,0,0,0,0,0,0,115,101,108,101,99,116,32,97,32,99,111,108,111,114,32,99,117,114,118,101,115,32,112,114,101,115,101,116,0,0,0,0,68,97,116,117,109,95,84,114,105,110,105,100,97,100,95,49,57,48,51,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,112,114,101,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,79,108,100,32,40,60,97,108,112,104,97,51,41,32,84,104,101,111,114,97,32,98,105,116,115,116,114,101,97,109,44,32,102,108,105,112,112,101,100,32,105,109,97,103,101,10,0,0,116,0,0,0,0,0,0,0,98,105,116,115,0,0,0,0,52,58,50,58,50,0,0,0,69,102,102,101,99,116,32,102,108,97,103,32,115,101,116,10,0,0,0,0,0,0,0,0,108,117,109,97,95,109,115,105,122,101,95,120,0,0,0,0,67,97,110,111,112,117,115,32,76,111,115,115,108,101,115,115,32,67,111,100,101,99,0,0,98,102,114,97,99,116,105,111,110,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,73,110,118,97,108,105,100,32,110,101,103,97,116,105,118,101,32,117,115,101,114,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,10,0,0,0,104,115,117,98,0,0,0,0,97,98,115,102,0,0,0,0,80,114,111,106,67,101,110,116,101,114,76,97,116,71,101,111,75,101,121,0,0,0,0,0,77,111,100,101,108,80,105,120,101,108,83,99,97,108,101,84,97,103,0,0,0,0,0,0,105,110,100,101,120,32,60,32,99,116,120,45,62,109,97,120,95,115,122,0,0,0,0,0,101,120,99,108,117,115,105,111,110,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,109,97,120,32,98,105,116,114,97,116,101,32,112,111,115,115,105,98,108,121,32,116,111,111,32,115,109,97,108,108,32,111,114,32,116,114,121,32,116,114,101,108,108,105,115,32,119,105,116,104,32,108,97,114,103,101,32,108,109,97,120,32,111,114,32,105,110,99,114,101,97,115,101,32,113,109,97,120,10,0,112,99,109,95,115,49,54,98,101,0,0,0,0,0,0,0,116,114,97,110,115,102,101,114,0,0,0,0,0,0,0,0,115,101,116,32,116,114,97,110,115,112,111,115,101,32,100,105,114,101,99,116,105,111,110,0,117,115,101,32,49,47,52,45,112,101,108,32,109,111,116,105,111,110,32,99,111,109,112,101,110,115,97,116,105,111,110,0,101,120,116,32,104,101,97,100,101,114,32,109,105,115,115,105,110,103,44,32,37,100,32,108,101,102,116,10,0,0,0,0,68,101,99,111,100,101,32,101,114,114,111,114,58,32,37,115,10,0,0,0,0,0,0,0,113,112,101,108,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,83,0,0,0,0,0,0,0,83,82,0,0,0,0,0,0,86,105,100,101,111,32,79,98,106,101,99,116,32,80,108,97,110,101,32,115,116,97,114,116,0,0,0,0,0,0,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,99,104,114,111,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,113,115,99,97,108,101,32,61,61,32,48,10,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,37,100,32,115,112,101,99,105,102,105,101,100,32,97,115,32,111,117,116,112,117,116,32,102,114,111,109,32,109,97,116,114,105,120,46,10,0,0,0,0,37,115,32,37,115,32,112,58,37,100,32,62,62,58,37,100,32,105,108,118,58,37,100,32,98,105,116,115,58,37,100,32,115,107,105,112,58,37,100,32,37,115,32,99,111,109,112,58,37,100,10,0,0,0,0,0,65,117,116,111,45,118,97,114,105,97,110,99,101,32,65,81,32,40,101,120,112,101,114,105,109,101,110,116,97,108,41,0,86,80,56,69,95,83,69,84,95,65,82,78,82,95,77,65,88,70,82,65,77,69,83,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,100,105,109,101,110,115,105,111,110,32,37,100,120,37,100,46,10,0,0,123,92,98,49,125,0,0,0,114,101,99,116,97,110,103,117,108,97,114,32,115,108,105,99,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,43,124,0,0,0,0,0,0,80,80,83,32,105,100,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,0,73,110,100,101,112,101,110,100,101,110,116,32,115,108,105,99,101,32,115,101,103,109,101,110,116,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,67,117,114,114,101,110,116,32,112,114,111,102,105,108,101,32,100,111,101,115,110,39,116,32,112,114,111,118,105,100,101,32,109,111,114,101,32,82,66,83,80,32,100,97,116,97,32,105,110,32,80,80,83,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,0,84,79,80,70,73,82,83,84,0,0,0,0,0,0,0,0,72,105,103,104,32,52,58,50,58,50,32,73,110,116,114,97,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,105,110,116,101,114,108,97,99,101,32,109,111,100,101,0,0,0,115,97,109,112,108,101,114,97,116,101,32,62,32,48,0,0,112,105,120,101,108,65,115,112,101,99,116,82,97,116,105,111,0,0,0,0,0,0,0,0,76,111,47,82,111,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,73,110,118,97,108,105,100,32,100,111,119,110,109,105,120,32,99,111,101,102,102,105,99,105,101,110,116,32,99,111,100,101,32,37,117,10,0,0,0,0,105,110,102,111,114,109,97,116,105,111,110,32,108,111,103,103,105,110,103,32,108,101,118,101,108,0,0,0,0,0,0,0,67,104,97,110,103,105,110,103,32,102,114,97,109,101,32,112,114,111,112,101,114,116,105,101,115,32,111,110,32,116,104,101,32,102,108,121,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,119,109,118,49,0,0,0,0,68,97,116,117,109,95,84,111,107,121,111,0,0,0,0,0,112,114,101,99,109,112,0,0,65,99,105,100,0,0,0,0,110,98,95,102,114,97,109,101,115,32,109,117,115,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,111,114,32,101,113,117,97,108,32,116,111,32,37,100,120,37,100,61,37,100,10,0,0,0,0,0,0,0,65,86,70,105,108,116,101,114,71,114,97,112,104,0,0,0,99,108,108,99,0,0,0,0,52,50,48,74,80,69,71,0,37,89,45,37,109,45,37,100,32,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,87,114,105,116,101,32,82,70,54,52,32,104,101,97,100,101,114,32,105,102,32,102,105,108,101,32,103,114,111,119,115,32,108,97,114,103,101,32,101,110,111,117,103,104,46,0,0,0,110,111,116,101,0,0,0,0,102,105,108,116,101,114,61,0,105,109,97,103,101,50,0,0,87,77,65,80,0,0,0,0,98,105,116,115,116,114,101,97,109,95,102,105,108,116,101,114,115,0,0,0,0,0,0,0,98,97,116,99,104,32,115,105,122,101,58,32,37,100,32,102,114,97,109,101,115,10,0,0,112,114,111,98,95,108,97,115,116,32,62,61,32,48,0,0,80,114,111,118,105,100,101,100,32,112,97,116,116,101,114,110,32,105,110,99,108,117,100,101,115,32,110,111,110,45,110,117,109,101,114,105,99,32,99,104,97,114,97,99,116,101,114,115,46,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,111,111,108,32,100,101,99,111,100,101,114,32,48,0,0,0,0,0,0,0,102,109,116,58,37,115,32,115,105,122,101,58,37,100,120,37,100,32,45,62,32,115,105,122,101,58,37,100,120,37,100,10,0,0,0,0,0,0,0,0,68,97,116,117,109,95,84,77,55,53,0,0,0,0,0,0,112,114,101,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,77,83,32,69,120,112,114,101,115,115,105,111,110,32,69,110,99,111,100,101,114,32,83,99,114,101,101,110,0,0,0,0,111,118,101,114,108,97,121,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,115,0,0,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,37,115,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,39,37,115,39,46,10,0,0,0,0,0,109,51,117,56,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,76,49,54,47,37,100,47,37,100,13,10,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,114,0,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,115,101,116,32,119,105,110,100,111,119,32,102,117,110,99,116,105,111,110,0,0,0,0,0,110,117,108,108,0,0,0,0,109,97,120,0,0,0,0,0,118,105,100,101,111,47,120,45,104,50,54,51,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,68,97,116,117,109,95,84,77,54,53,0,0,0,0,0,0,112,114,101,109,101,0,0,0,109,116,115,50,0,0,0,0,108,117,109,97,95,114,97,100,105,117,115,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,98,115,102,0,0,0,0,0,110,58,37,108,108,100,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,112,111,115,58,37,108,108,100,32,102,109,116,58,37,115,32,115,97,114,58,37,100,47,37,100,32,115,58,37,100,120,37,100,32,105,58,37,99,32,105,115,107,101,121,58,37,100,32,116,121,112,101,58,37,99,32,99,104,101,99,107,115,117,109,58,37,48,56,88,32,112,108,97,110,101,95,99,104,101,99,107,115,117,109,58,91,37,48,56,88], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2330784);
/* memory initializer */ allocate([97,110,97,108,121,122,101,100,117,114,97,116,105,111,110,0,115,101,108,101,99,116,32,105,110,116,101,114,108,97,99,101,32,109,111,100,101,0,0,0,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,101,118,101,110,10,0,0,0,0,121,98,102,45,62,121,95,104,101,105,103,104,116,32,45,32,121,98,102,45,62,121,95,99,114,111,112,95,104,101,105,103,104,116,32,62,61,32,48,0,102,114,97,109,101,32,115,105,122,101,32,62,32,50,109,97,120,95,100,105,115,116,97,110,99,101,32,97,110,100,32,110,111,32,99,104,101,99,107,115,117,109,10,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,115,111,108,118,101,32,109,97,116,101,114,105,97,108,32,116,114,97,99,107,32,115,116,114,111,110,103,32,114,101,102,10,0,0,0,0,83,65,77,80,76,69,95,82,65,84,69,0,0,0,0,0,83,101,116,32,116,114,97,110,115,112,111,114,116,95,115,116,114,101,97,109,95,105,100,32,102,105,101,108,100,46,0,0,115,101,114,118,105,99,101,95,110,97,109,101,0,0,0,0,86,66,86,32,98,117,102,102,101,114,32,115,105,122,101,32,110,111,116,32,115,101,116,44,32,109,117,120,105,110,103,32,109,97,121,32,102,97,105,108,10,0,0,0,0,0,0,0,68,97,116,117,109,95,84,105,109,98,97,108,97,105,95,49,57,52,56,0,0,0,0,0,97,109,111,117,110,116,32,111,102,32,109,111,116,105,111,110,32,112,114,101,100,105,99,116,111,114,115,32,102,114,111,109,32,116,104,101,32,112,114,101,118,105,111,117,115,32,102,114,97,109,101,0,0,0,0,0,37,100,0,0,0,0,0,0,84,101,99,104,83,109,105,116,104,32,83,99,114,101,101,110,32,67,111,100,101,99,32,50,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,32,98,117,102,102,101,114,115,0,0,0,0,0,0,0,0,83,101,108,101,99,116,32,73,68,51,118,50,32,118,101,114,115,105,111,110,32,116,111,32,119,114,105,116,101,46,32,67,117,114,114,101,110,116,108,121,32,51,32,97,110,100,32,52,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,0,111,118,101,114,114,105,100,101,32,116,104,101,32,111,112,116,105,111,110,115,32,102,114,111,109,32,102,102,115,101,114,118,101,114,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,39,37,115,39,10,0,0,0,0,0,0,87,97,114,110,105,110,103,44,32,101,120,116,101,110,115,105,111,110,32,105,115,32,110,111,116,32,46,109,52,97,32,110,111,114,32,46,109,52,118,32,81,117,105,99,107,116,105,109,101,47,73,112,111,100,32,109,105,103,104,116,32,110,111,116,32,112,108,97,121,32,116,104,101,32,102,105,108,101,10,0,102,52,118,32,109,117,120,101,114,0,0,0,0,0,0,0,109,97,107,101,0,0,0,0,108,117,109,97,95,114,97,100,105,117,115,0,0,0,0,0,87,114,105,116,105,110,103,32,98,108,111,99,107,32,97,116,32,111,102,102,115,101,116,32,37,108,108,117,44,32,115,105,122,101,32,37,100,44,32,112,116,115,32,37,108,108,100,44,32,100,116,115,32,37,108,108,100,44,32,100,117,114,97,116,105,111,110,32,37,100,44,32,102,108,97,103,115,32,37,100,10,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,99,111,109,98,105,110,101,100,32,101,110,99,111,100,105,110,103,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,104,0,0,0,0,0,0,0,68,97,116,117,109,95,84,97,110,97,110,97,114,105,118,101,95,49,57,50,53,0,0,0,37,42,63,91,93,123,125,0,108,97,115,116,95,112,114,101,100,0,0,0,0,0,0,0,105,109,56,0,0,0,0,0,116,115,99,99,50,0,0,0,97,0,0,0,0,0,0,0,111,118,101,114,114,105,100,101,95,102,102,115,101,114,118,101,114,0,0,0,0,0,0,0,84,83,79,65,0,0,0,0,102,117,108,108,32,120,49,58,37,100,32,120,50,58,37,100,32,121,49,58,37,100,32,121,50,58,37,100,32,109,97,120,95,109,97,115,107,95,115,105,122,101,58,37,100,10,0,0,77,69,84,72,79,68,61,0,110,117,109,98,101,114,32,111,102,32,102,114,97,103,109,101,110,116,115,32,107,101,112,116,32,111,117,116,115,105,100,101,32,111,102,32,116,104,101,32,109,97,110,105,102,101,115,116,32,98,101,102,111,114,101,32,114,101,109,111,118,105,110,103,32,102,114,111,109,32,100,105,115,107,0,0,0,0,0,0,109,52,118,0,0,0,0,0,119,111,114,107,101,114,45,62,115,116,97,116,117,115,95,32,60,61,32,79,75,0,0,0,118,105,100,101,111,100,97,116,97,114,97,116,101,0,0,0,70,111,117,110,100,32,105,110,118,97,108,105,100,32,105,110,100,101,120,32,101,110,116,114,105,101,115,44,32,99,108,101,97,114,105,110,103,32,116,104,101,32,105,110,100,101,120,46,10,0,0,0,0,0,0,0,115,101,116,32,108,101,102,116,32,106,117,110,107,32,115,105,122,101,0,0,0,0,0,0,109,117,120,101,114,32,60,45,32,116,121,112,101,58,37,115,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,32,115,105,122,101,58,37,100,10,0,119,0,0,0,0,0,0,0,68,97,116,117,109,95,83,117,100,97,110,0,0,0,0,0,100,105,97,109,111,110,100,32,116,121,112,101,32,38,32,115,105,122,101,32,102,111,114,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,0,0,0,0,77,83,32,65,84,67,32,83,99,114,101,101,110,0,0,0,115,117,98,102,105,108,116,101,114,115,0,0,0,0,0,0,115,101,116,32,116,104,101,32,105,110,105,116,105,97,108,32,100,101,109,117,120,45,100,101,99,111,100,101,32,100,101,108,97,121,0,0,0,0,0,0,74,85,78,75,0,0,0,0,115,116,114,110,0,0,0,0,65,83,70,95,75,101,121,95,73,68,0,0,0,0,0,0,109,52,97,0,0,0,0,0,115,101,116,32,112,104,97,115,101,32,109,111,100,101,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,108,102,95,115,121,110,99,45,62,99,117,114,95,115,98,95,99,111,108,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,82,101,102,101,114,101,110,99,101,32,102,114,97,109,101,34,0,0,102,114,97,109,101,0,0,0,115,101,116,32,116,111,112,32,108,101,102,116,32,120,32,99,111,111,114,100,105,110,97,116,101,0,0,0,0,0,0,0,68,97,116,117,109,95,83,101,114,105,110,100,117,110,103,0,100,105,97,95,115,105,122,101,0,0,0,0,0,0,0,0,81,45,70,97,99,116,111,114,0,0,0,0,0,0,0,0,109,115,97,49,0,0,0,0,109,117,120,112,114,101,108,111,97,100,0,0,0,0,0,0,113,32,60,61,32,114,99,45,62,119,111,114,115,116,95,113,117,97,108,105,116,121,32,38,38,32,113,32,62,61,32,114,99,45,62,98,101,115,116,95,113,117,97,108,105,116,121,0,115,101,116,32,116,104,101,32,112,97,100,32,97,114,101,97,32,119,105,100,116,104,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,104,101,105,103,104,116,32,102,111,114,32,100,118,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,108,111,103,97,114,105,116,104,109,105,99,0,0,0,0,0,115,101,116,32,100,101,112,116,104,0,0,0,0,0,0,0,100,101,99,105,109,97,108,115,0,0,0,0,0,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,32,111,114,32,99,111,114,114,117,112,116,32,116,105,108,101,32,115,105,122,101,0,0,0,115,101,116,32,105,116,101,114,97,116,105,111,110,32,99,111,117,110,116,32,109,111,100,101,0,0,0,0,0,0,0,0,37,115,32,102,105,108,116,101,114,32,110,111,116,32,112,114,101,115,101,110,116,44,32,99,97,110,110,111,116,32,108,105,109,105,116,32,114,101,99,111,114,100,105,110,103,32,116,105,109,101,46,10,0,0,0,0,109,111,108,100,0,0,0,0,102,117,108,108,0,0,0,0,115,104,111,119,32,118,101,114,115,105,111,110,0,0,0,0,115,101,116,32,100,105,116,104,101,114,105,110,103,0,0,0,68,97,116,117,109,95,83,101,103,111,114,97,0,0,0,0,105,110,116,101,114,108,97,99,101,100,32,68,67,84,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,77,83,32,83,99,114,101,101,110,32,49,0,0,0,0,0,121,0,0,0,0,0,0,0,97,110,97,103,108,121,112,104,32,103,114,101,101,110,32,109,97,103,101,110,116,97,32,104,97,108,102,32,99,111,108,111,114,0,0,0,0,0,0,0,115,101,99,111,110,100,115,0,110,111,105,115,101,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,115,99,97,108,101,100,32,108,97,115,116,32,115,111,117,114,99,101,32,98,117,102,102,101,114,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,99,111,108,111,114,32,114,97,110,103,101,0,0,85,115,105,110,103,32,77,83,32,115,116,121,108,101,32,97,117,100,105,111,32,99,111,100,101,99,32,116,97,103,44,32,116,104,101,32,102,105,108,101,32,109,97,121,32,98,101,32,117,110,112,108,97,121,97,98,108,101,33,10,0,0,0,0,110,58,37,102,32,116,105,109,101,58,37,102,32,97,110,103,108,101,58,37,102,47,80,73,10,0,0,0,0,0,0,0,119,111,114,107,101,114,45,62,115,116,97,116,117,115,95,32,61,61,32,78,79,84,95,79,75,0,0,0,0,0,0,0,118,115,117,98,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,110,111,105,115,101,32,115,101,101,100,0,0,0,0,0,80,97,115,115,32,116,104,114,111,117,103,104,32,116,104,101,32,109,97,105,110,32,105,110,112,117,116,46,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,111,110,121,120,99,95,105,110,116,46,104,0,0,0,0,99,50,95,115,116,114,101,110,103,116,104,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,111,110,121,120,99,95,105,110,116,46,104,0,0,0,0,115,117,112,112,111,114,116,101,100,44,97,100,100,105,110,103,10,0,0,0,0,0,0,0,68,97,116,117,109,95,83,99,104,119,97,114,122,101,99,107,0,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,98,117,102,102,101,114,32,100,105,109,101,110,115,105,111,110,115,0,0,0,0,0,105,108,100,99,116,99,109,112,0,0,0,0,0,0,0,0,109,97,120,0,0,0,0,0,99,117,98,101,0,0,0,0,109,115,115,49,0,0,0,0,115,101,116,32,65,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,101,110,97,98,108,101,95,97,117,116,111,95,97,108,116,95,114,101,102,32,101,120,112,101,99,116,101,100,32,98,111,111,108,101,97,110,0,0,0,0,115,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,100,101,109,117,120,45,100,101,99,111,100,101,32,100,101,108,97,121,0,0,0,0,0,0,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,46,98,117,102,32,110,111,116,32,115,101,116,46,0,0,0,0,0,0,0,0,108,111,103,97,114,105,116,104,109,105,99,0,0,0,0,0,114,101,100,95,101,120,112,114,0,0,0,0,0,0,0,0,85,115,105,110,103,32,77,83,32,115,116,121,108,101,32,118,105,100,101,111,32,99,111,100,101,99,32,116,97,103,44,32,116,104,101,32,102,105,108,101,32,109,97,121,32,98,101,32,117,110,112,108,97,121,97,98,108,101,33,10,0,0,0,0,112,99,95,117,0,0,0,0,79,112,101,110,67,76,58,32,85,110,97,98,108,101,32,116,111,32,102,105,110,100,32,97,32,99,111,109,112,97,116,105,98,108,101,32,100,101,118,105,99,101,10,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,109,112,46,99,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,102,97,100,101,46,99,0,0,0,121,117,118,52,52,48,112,0,67,111,114,110,115,105,108,107,0,0,0,0,0,0,0,0,116,97,121,108,111,114,0,0,83,116,114,101,97,109,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,0,84,70,82,0,0,0,0,0,105,119,0,0,0,0,0,0,98,105,99,117,98,105,99,0,115,111,117,114,99,101,32,119,105,100,116,104,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,111,109,112,101,110,115,97,116,101,32,102,111,114,32,116,105,109,101,115,116,97,109,112,32,100,101,108,116,97,32,111,102,32,37,102,10,0,101,120,104,97,117,115,116,105,118,101,0,0,0,0,0,0,118,97,0,0,0,0,0,0,108,105,115,116,32,33,61,32,78,85,76,76,0,0,0,0,77,97,112,112,105,110,103,32,119,105,116,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,105,110,112,117,116,32,97,110,100,47,111,114,32,112,108,97,110,101,32,110,117,109,98,101,114,46,10,0,0,0,84,105,109,101,114,0,0,0,65,68,80,67,77,32,73,77,65,32,70,117,110,99,111,109,32,73,83,83,0,0,0,0,98,95,112,121,114,97,109,105,100,61,37,100,0,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,110,101,119,32,99,111,117,112,108,105,110,103,32,115,116,114,97,116,101,103,121,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,32,105,110,32,98,108,111,99,107,32,48,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,118,68,107,48,91,37,100,93,58,32,37,100,10,0,0,0,80,117,108,115,101,32,100,97,116,97,32,99,111,114,114,117,112,116,32,111,114,32,105,110,118,97,108,105,100,46,10,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,72,117,102,102,109,97,110,32,116,97,98,108,101,115,46,10,0,0,112,114,101,115,101,116,0,0,68,97,116,117,109,95,83,97,112,112,101,114,95,72,105,108,108,95,49,57,52,51,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,97,99,114,111,98,108,111,99,107,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,0,0,0,84,104,101,111,114,97,32,98,105,116,115,116,114,101,97,109,32,118,101,114,115,105,111,110,32,37,88,10,0,0,0,0,112,111,115,0,0,0,0,0,102,108,111,111,114,95,115,101,116,117,112,45,62,100,97,116,97,46,116,49,46,99,108,97,115,115,95,109,97,115,116,101,114,98,111,111,107,91,106,93,0,0,0,0,0,0,0,0,52,58,50,58,48,0,0,0,69,102,102,101,99,116,32,112,97,114,97,109,115,32,50,58,32,0,0,0,0,0,0,0,90,101,114,111,67,111,100,101,99,32,76,111,115,115,108,101,115,115,32,86,105,100,101,111,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,78,79,82,77,45,54,32,86,76,67,10,0,0,0,0,0,115,101,116,32,109,111,100,101,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,97,108,112,104,97,32,103,97,105,110,32,102,111,114,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,105,99,111,110,118,32,99,111,110,116,101,120,116,32,119,105,116,104,32,105,110,112,117,116,32,99,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,32,34,37,115,34,10,0,0,0,0,0,0,0,0,99,104,0,0,0,0,0,0,109,117,120,100,101,108,97,121,0,0,0,0,0,0,0,0,80,114,111,106,67,101,110,116,101,114,76,111,110,103,71,101,111,75,101,121,0,0,0,0,85,110,107,110,111,119,110,32,70,105,108,108,79,114,100,101,114,32,118,97,108,117,101,32,37,100,44,32,116,114,121,105,110,103,32,100,101,102,97,117,108,116,32,111,110,101,10,0,100,111,100,103,101,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,115,99,97,108,101,100,32,115,111,117,114,99,101,32,98,117,102,102,101,114,0,114,99,32,98,117,102,102,101,114,32,117,110,100,101,114,102,108,111,119,10,0,0,0,0,99,111,108,111,114,112,114,105,109,0,0,0,0,0,0,0,119,105,100,101,0,0,0,0,113,112,101,108,0,0,0,0,115,107,105,112,58,37,100,32,114,108,58,37,100,32,114,108,99,58,37,100,32,100,99,58,37,100,32,109,118,58,37,100,32,109,98,114,108,58,37,100,32,113,112,58,37,100,32,32,32,10,0,0,0,0,0,0,83,116,114,101,97,109,32,102,105,110,105,115,104,101,100,44,32,108,111,111,112,105,110,103,46,10,0,0,0,0,0,0,118,112,56,47,100,101,99,111,100,101,114,47,111,110,121,120,100,95,105,102,46,99,0,0,79,66,77,67,32,105,115,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,115,105,109,112,108,101,32,109,98,32,100,101,99,105,115,105,111,110,10,0,71,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,80,69,71,32,97,117,100,105,111,32,102,114,97,109,101,46,10,0,101,111,98,32,60,61,32,49,54,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,77,80,69,71,32,97,117,100,105,111,32,102,114,97,109,101,46,10,0,83,0,0,0,0,0,0,0,86,105,115,117,97,108,32,79,98,106,101,99,116,32,83,116,97,114,116,0,0,0,0,0,99,104,114,111,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,49,50,100,101,99,46,99,0,0,78,117,109,98,101,114,32,111,102,32,112,114,105,109,105,116,105,118,101,32,109,97,116,114,105,99,101,115,32,99,97,110,110,111,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,37,100,46,10,0,0,0,0,0,0,0,0,97,117,116,111,118,97,114,105,97,110,99,101,0,0,0,0,66,85,71,33,32,85,110,107,110,111,119,110,32,99,111,100,101,99,32,105,110,32,99,111,109,112,114,101,115,115,105,111,110,32,115,119,105,116,99,104,46,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,111,109,112,111,110,101,110,116,115,58,32,37,100,10,0,0,0,0,0,0,0,92,66,0,0,0,0,0,0,122,101,114,111,32,102,114,97,109,101,114,97,116,101,10,0,85,110,107,110,111,119,110,32,102,108,97,103,32,39,37,115,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,99,111,109,109,97,110,100,32,35,37,100,10,0,68,101,99,111,100,105,110,103,32,80,80,83,10,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,109,101,114,103,105,110,103,32,77,86,80,32,99,97,110,100,105,100,97,116,101,115,58,32,37,100,46,10,0,0,65,100,106,117,115,116,32,99,111,108,111,114,115,32,117,115,105,110,103,32,97,32,72,97,108,100,32,67,76,85,84,46,0,0,0,0,0,0,0,0,56,120,56,68,67,84,0,0,80,82,79,71,82,69,83,83,73,86,69,0,0,0,0,0,72,105,103,104,32,52,58,50,58,50,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,85,110,107,110,111,119,110,32,108,105,110,101,32,111,114,100,101,114,10,0,0,0,0,0,108,111,114,111,0,0,0,0,73,110,118,97,108,105,100,32,109,111,100,101,32,37,100,32,102,111,114,32,101,109,98,101,100,100,101,100,32,100,111,119,110,109,105,120,32,99,111,101,102,102,105,99,105,101,110,116,115,10,0,0,0,0,0,0,105,110,102,111,0,0,0,0,67,104,97,110,103,105,110,103,32,102,114,97,109,101,32,112,114,111,112,101,114,116,105,101,115,32,111,110,32,116,104,101,32,102,108,121,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,97,108,108,32,102,105,108,116,101,114,115,46,10,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,51,0,0,0,0,0,0,0,68,97,116,117,109,95,83,111,117,116,104,95,65,109,101,114,105,99,97,110,95,68,97,116,117,109,95,49,57,54,57,0,109,112,100,101,99,105,109,97,116,101,0,0,0,0,0,0,109,98,99,109,112,0,0,0,73,110,115,116,114,117,109,101,110,116,97,108,0,0,0,0,79,117,116,112,117,116,32,112,97,100,32,34,37,115,34,32,119,105,116,104,32,116,121,112,101,32,37,115,32,111,102,32,116,104,101,32,102,105,108,116,101,114,32,105,110,115,116,97,110,99,101,32,34,37,115,34,32,111,102,32,37,115,32,110,111,116,32,99,111,110,110,101,99,116,101,100,32,116,111,32,97,110,121,32,100,101,115,116,105,110,97,116,105,111,110,10,0,0,0,0,0,0,0,0,122,101,114,111,99,111,100,101,99,0,0,0,0,0,0,0,89,83,67,83,83,61,0,0,116,105,116,108,101,0,0,0,97,117,116,111,0,0,0,0,78,79,84,69,0,0,0,0,109,112,0,0,0,0,0,0,80,114,111,98,101,32,98,117,102,102,101,114,32,115,105,122,101,32,108,105,109,105,116,32,111,102,32,37,100,32,98,121,116,101,115,32,114,101,97,99,104,101,100,10,0,0,0,0,83,117,99,99,101,115,115,0,65,65,67,76,0,0,0,0,116,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,32,97,110,100,32,100,111,101,115,32,110,111,116,104,105,110,103,0,0,0,0,0,0,67,111,109,112,117,116,101,32,97,110,100,32,97,112,112,108,121,32,97,32,108,111,111,107,117,112,32,116,97,98,108,101,32,116,111,32,116,104,101,32,89,85,86,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,0,118,112,57,47,118,112,57,95,100,120,95,105,102,97,99,101,46,99,0,0,0,0,0,0,60,112,97,114,97,109,32,110,97,109,101,61,34,37,115,34,32,118,97,108,117,101,61,34,37,100,34,32,118,97,108,117,101,116,121,112,101,61,34,100,97,116,97,34,47,62,10,0,115,101,116,32,116,104,101,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,115,99,97,110,110,105,110,103,32,109,111,100,101,0,0,0,68,97,116,117,109,95,82,84,51,56,0,0,0,0,0,0,115,117,98,45,112,101,108,32,77,69,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,0,0,0,88,66,77,32,40,88,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,115,101,108,101,99,116,32,108,117,109,97,32,109,111,100,101,0,0,0,0,0,0,0,0,103,95,119,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,54,53,53,51,53,93,0,0,0,0,0,105,115,121,110,99,0,0,0,77,105,115,115,105,110,103,32,97,114,103,117,109,101,110,116,32,102,111,114,32,111,112,116,105,111,110,32,39,37,115,39,46,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,32,98,117,102,102,101,114,115,0,0,0,0,0,0,0,0,102,102,99,111,110,99,97,116,32,102,111,114,109,97,116,0,77,117,108,116,105,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,58,32,84,70,70,58,37,100,32,66,70,70,58,37,100,32,80,114,111,103,114,101,115,115,105,118,101,58,37,100,32,85,110,100,101,116,101,114,109,105,110,101,100,58,37,100,10,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,77,80,69,71,52,45,71,69,78,69,82,73,67,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,112,114,111,102,105,108,101,45,108,101,118,101,108,45,105,100,61,49,59,109,111,100,101,61,65,65,67,45,104,98,114,59,115,105,122,101,108,101,110,103,116,104,61,49,51,59,105,110,100,101,120,108,101,110,103,116,104,61,51,59,105,110,100,101,120,100,101,108,116,97,108,101,110,103,116,104,61,51,37,115,13,10,0,0,0,60,112,97,114,97,109,32,110,97,109,101,61,34,37,115,34,32,118,97,108,117,101,61,34,37,115,34,32,118,97,108,117,101,116,121,112,101,61,34,100,97,116,97,34,47,62,10,0,115,112,101,101,100,32,102,97,99,116,111,114,32,111,116,104,101,114,32,116,104,97,110,32,49,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,83,116,97,114,116,105,110,103,32,115,101,113,117,101,110,99,101,32,110,117,109,98,101,114,0,0,0,0,0,0,0,0,119,105,110,95,102,117,110,99,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,103,95,119,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,49,54,51,56,51,93,0,0,0,0,0,114,97,119,32,72,46,50,54,51,0,0,0,0,0,0,0,108,117,109,97,95,115,112,97,116,105,97,108,0,0,0,0,117,49,54,98,101,0,0,0,68,97,116,117,109,95,65,109,101,114,115,102,111,111,114,116,0,0,0,0,0,0,0,0,99,108,83,101,116,75,101,114,110,101,108,65,114,103,32,101,114,114,111,114,32,39,37,100,39,10,0,0,0,0,0,0,115,117,98,99,109,112,0,0,120,98,109,0,0,0,0,0,78,69,65,82,69,83,84,77,86,32,60,61,32,109,32,38,38,32,109,32,60,61,32,83,80,76,73,84,77,86,0,0,117,49,54,98,101,0,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,97,108,108,111,119,32,115,101,101,107,105,110,103,32,116,111,32,110,111,110,45,107,101,121,102,114,97,109,101,115,32,111,110,32,100,101,109,117,120,101,114,32,108,101,118,101,108,32,119,104,101,110,32,115,117,112,112,111,114,116,101,100,0,0,48,0,0,0,0,0,0,0,60,47,115,109,105,108,62,10,0,0,0,0,0,0,0,0,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,0,104,101,97,100,101,114,95,105,100,120,32,105,110,118,97,108,105,100,10,0,0,0,0,0,110,111,32,109,97,116,101,114,105,97,108,32,112,97,99,107,97,103,101,32,102,111,117,110,100,10,0,0,0,0,0,0,78,85,77,95,67,72,65,78,78,69,76,83,0,0,0,0,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,0,109,112,101,103,116,115,95,116,114,97,110,115,112,111,114,116,95,115,116,114,101,97,109,95,105,100,0,0,0,0,0,0,80,114,101,100,101,102,105,110,101,100,32,83,76,67,111,110,102,105,103,68,101,115,99,114,105,112,116,111,114,0,0,0,68,97,116,117,109,95,76,111,109,97,95,81,117,105,110,116,97,110,97,0,0,0,0,0,37,115,32,105,110,32,77,80,69,71,45,49,32,115,121,115,116,101,109,32,115,116,114,101,97,109,115,32,105,115,32,110,111,116,32,119,105,100,101,108,121,32,115,117,112,112,111,114,116,101,100,44,32,99,111,110,115,105,100,101,114,32,117,115,105,110,103,32,116,104,101,32,118,111,98,32,111,114,32,116,104,101,32,100,118,100,32,109,117,120,101,114,32,116,111,32,102,111,114,99,101,32,97,32,77,80,69,71,45,50,32,112,114,111,103,114,97,109,32,115,116,114,101,97,109,46,10,0,99,109,112,95,102,117,110,99,0,0,0,0,0,0,0,0,108,97,110,103,105,100,120,58,0,0,0,0,0,0,0,0,67,111,109,109,111,100,111,114,101,32,67,68,88,76,32,118,105,100,101,111,0,0,0,0,105,100,51,118,50,95,118,101,114,115,105,111,110,0,0,0,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,69,105,116,104,101,114,32,89,67,98,67,114,32,111,114,32,82,71,66,32,98,117,116,32,110,111,116,32,98,111,116,104,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,115,101,116,32,102,114,97,109,101,32,115,116,101,112,0,0,104,45,62,102,114,97,109,101,115,46,98,95,104,97,118,101,95,108,111,119,114,101,115,0,60,47,98,111,100,121,62,10,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,0,70,114,97,109,101,32,112,97,99,107,32,111,117,116,112,117,116,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,121,110,97,109,105,99,32,98,117,102,102,101,114,10,0,0,73,78,84,82,65,52,88,52,95,76,85,77,65,0,0,0,85,110,107,110,111,119,110,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,116,114,97,99,107,32,116,121,112,101,32,37,108,108,117,10,0,102,112,115,61,37,100,47,37,100,10,0,0,0,0,0,0,68,97,116,117,109,95,81,111,114,110,111,113,0,0,0,0,80,97,116,116,101,114,110,32,116,121,112,101,32,39,103,108,111,98,95,115,101,113,117,101,110,99,101,39,32,105,115,32,100,101,112,114,101,99,97,116,101,100,58,32,117,115,101,32,112,97,116,116,101,114,110,95,116,121,112,101,32,39,103,108,111,98,39,32,105,110,115,116,101,97,100,10,0,0,0,0,102,117,108,108,45,112,101,108,32,77,69,32,99,111,109,112,97,114,101,32,102,117,110,99,116,105,111,110,0,0,0,0,70,111,114,99,101,32,108,105,98,97,118,102,105,108,116,101,114,32,110,111,116,32,116,111,32,117,115,101,32,97,110,121,32,111,102,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,32,102,111,114,32,116,104,101,32,105,110,112,117,116,32,116,111,32,116,104,101,32,110,101,120,116,32,102,105,108,116,101,114,46,0,0,0,0,0,0,0,105,109,49,0,0,0,0,0,99,100,120,108,0,0,0,0,116,118,115,116,100,0,0,0,111,117,116,112,117,116,32,102,105,101,108,100,32,111,114,100,101,114,0,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,35,0,0,0,0,0,0,0,101,120,116,114,97,95,119,105,110,100,111,119,95,115,105,122,101,0,0,0,0,0,0,0,60,47,115,119,105,116,99,104,62,10,0,0,0,0,0,0,104,101,105,103,104,116,0,0,73,110,118,97,108,105,100,32,107,101,121,102,114,97,109,101,115,32,111,98,106,101,99,116,44,32,115,107,105,112,112,105,110,103,46,10,0,0,0,0,99,104,97,110,103,105,110,103,32,116,111,32,37,108,108,100,46,32,84,104,105,115,32,109,97,121,32,114,101,115,117,108,116,32,105,110,32,105,110,99,111,114,114,101,99,116,32,116,105,109,101,115,116,97,109,112,115,32,105,110,32,116,104,101,32,111,117,116,112,117,116,32,102,105,108,101,46,10,0,0,68,97,116,117,109,95,81,97,116,97,114,95,49,57,52,56,0,0,0,0,0,0,0,0,99,109,112,0,0,0,0,0,88,87,68,32,40,88,32,87,105,110,100,111,119,32,68,117,109,112,41,32,105,109,97,103,101,0,0,0,0,0,0,0,99,108,101,97,110,95,115,114,99,0,0,0,0,0,0,0,99,108,67,114,101,97,116,101,67,111,109,109,97,110,100,81,117,101,117,101,0,0,0,0,99,104,97,110,110,101,108,0,83,117,98,116,105,116,108,101,32,45,32,37,115,45,120,120,59,48,50,0,0,0,0,0,110,111,110,45,105,110,116,101,114,108,101,97,118,101,100,32,65,86,73,10,0,0,0,0,115,101,116,32,102,105,101,108,100,32,116,121,112,101,32,40,116,111,112,32,111,114,32,98,111,116,116,111,109,41,0,0,37,48,50,117,58,37,48,50,117,58,37,48,50,117,37,99,37,48,50,117,0,0,0,0,65,83,70,95,80,114,111,116,101,99,116,105,111,110,95,84,121,112,101,0,0,0,0,0,60,47,37,115,62,10,0,0,115,105,122,101,111,102,40,116,109,112,41,32,62,61,32,97,118,95,115,104,97,95,115,105,122,101,0,0,0,0,0,0,98,103,114,50,52,0,0,0,105,110,0,0,0,0,0,0,101,118,97,108,32,118,111,108,117,109,101,32,101,120,112,114,101,115,115,105,111,110,32,111,110,99,101,0,0,0,0,0,98,105,107,101,115,104,101,100,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,112,116,105,111,110,32,116,121,112,101,46,10,0,0,0,68,97,116,117,109,95,81,97,116,97,114,0,0,0,0,0,98,97,99,107,119,97,114,100,32,112,114,101,100,105,99,116,101,100,32,77,86,115,32,111,102,32,66,45,102,114,97,109,101,115,0,0,0,0,0,0,69,120,116,114,97,99,116,32,97,110,32,97,108,112,104,97,32,99,104,97,110,110,101,108,32,97,115,32,97,32,103,114,97,121,115,99,97,108,101,32,105,109,97,103,101,32,99,111,109,112,111,110,101,110,116,46,0,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,32,62,61,32,48,0,0,0,113,0,0,0,0,0,0,0,120,119,100,0,0,0,0,0,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,46,32,85,112,100,97,116,101,32,121,111,117,114,32,70,70,109,112,101,103,32,118,101,114,115,105,111,110,32,116,111,32,116,104,101,32,110,101,119,101,115,116,32,111,110,101,32,102,114,111,109,32,71,105,116,46,32,73,102,32,116,104,101,32,112,114,111,98,108,101,109,32,115,116,105,108,108,32,111,99,99,117,114,115,44,32,105,116,32,109,101,97,110,115,32,116,104,97,116,32,121,111,117,114,32,102,105,108,101,32,104,97,115,32,97,32,102,101,97,116,117,114,101,32,119,104,105,99,104,32,104,97,115,32,110,111,116,32,98,101,101,110,32,105,109,112,108,101,109,101,110,116,101,100,46,10,0,108,105,98,97,118,117,116,105,108,47,105,109,103,117,116,105,108,115,46,99,0,0,0,0,82,73,80,69,77,68,49,54,48,0,0,0,0,0,0,0,108,105,115,116,91,48,93,0,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,115,101,116,32,99,111,100,101,98,111,111,107,32,108,101,110,103,116,104,0,0,0,0,0,98,116,52,55,48,98,103,0,69,114,114,111,114,32,111,99,99,117,114,114,101,100,32,105,110,32,109,109,97,112,40,41,58,32,37,115,10,0,0,0,77,105,115,115,105,110,103,32,39,41,39,32,105,110,32,39,37,115,39,10,0,0,0,0,115,101,116,32,104,105,103,104,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,66,85,71,0,0,0,0,0,80,97,99,107,101,116,83,105,122,101,0,0,0,0,0,0,108,111,103,0,0,0,0,0,43,0,0,0,0,0,0,0,39,92,0,0,0,0,0,0,100,101,102,97,117,108,116,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,117,110,115,99,97,108,101,100,46,99,0,0,0,100,101,115,99,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,111,111,108,32,100,101,99,111,100,101,114,32,37,100,0,0,0,0,0,0,100,101,115,99,0,0,0,0,105,116,101,114,97,116,105,111,110,95,99,111,117,110,116,0,97,116,114,105,109,0,0,0,115,116,105,116,99,104,32,98,111,117,110,100,97,114,105,101,115,0,0,0,0,0,0,0,100,101,112,114,101,99,97,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,117,115,101,100,44,32,109,97,107,101,32,115,117,114,101,32,121,111,117,32,100,105,100,32,115,101,116,32,114,97,110,103,101,32,99,111,114,114,101,99,116,108,121,10,0,0,0,0,83,108,105,99,101,115,32,115,116,97,114,116,32,105,110,32,116,104,101,32,109,105,100,100,108,101,33,10,0,0,0,0,115,116,97,114,116,32,102,105,108,108,105,110,103,32,116,104,101,32,119,104,111,108,101,32,118,105,100,101,111,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,108,108,111,99,97,116,101,32,102,114,97,109,101,10,0,0,0,0,0,102,97,115,116,95,98,105,108,105,110,101,97,114,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,10,0,0,0,0,0,0,48,0,0,0,0,0,0,0,100,105,116,104,101,114,0,0,68,114,97,119,32,97,32,99,111,108,111,114,101,100,32,103,114,105,100,32,111,110,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,68,97,116,117,109,95,80,117,108,107,111,118,111,95,49,57,52,50,0,0,0,0,0,0,118,101,114,115,105,111,110,0,98,98,0,0,0,0,0,0,111,115,102,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,52,58,52,32,49,48,45,98,105,116,0,0,0,0,0,0,0,33,115,45,62,111,117,116,95,99,104,95,108,97,121,111,117,116,32,124,124,32,111,117,116,45,62,99,104,95,99,111,117,110,116,32,61,61,32,97,118,95,103,101,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,95,110,98,95,99,104,97,110,110,101,108,115,40,115,45,62,111,117,116,95,99,104,95,108,97,121,111,117,116,41,0,0,0,0,0,0,0,104,101,108,112,0,0,0,0,66,105,113,117,97,100,32,102,105,108,116,101,114,32,109,117,115,116,32,104,97,118,101,32,111,114,100,101,114,32,111,102,32,50,10,0,0,0,0,0,97,103,109,104,0,0,0,0,118,99,0,0,0,0,0,0,105,105,100,95,112,97,114,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,111,117,116,95,114,97,110,103,101,0,0,0,0,0,0,0,66,105,116,115,80,101,114,83,97,109,112,108,101,0,0,0,119,0,0,0,0,0,0,0,77,65,88,86,65,76,0,0,114,111,116,104,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,120,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,109,111,100,101,32,86,76,67,10,0,0,0,0,0,67,97,110,110,111,116,32,117,115,101,32,110,101,120,116,32,112,105,99,116,117,114,101,32,105,110,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,10,0,0,0,104,115,117,98,0,0,0,0,65,100,100,105,116,105,111,110,97,108,32,115,117,98,115,116,114,101,97,109,115,0,0,0,112,97,115,115,0,0,0,0,115,101,116,32,116,104,101,32,108,101,110,103,116,104,32,111,102,32,116,104,101,32,99,121,99,108,101,32,116,111,32,117,115,101,32,102,111,114,32,100,101,106,117,100,100,101,114,105,110,103,0,0,0,0,0,0,105,32,60,32,70,82,65,77,69,95,66,85,70,70,69,82,83,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,84,111,111,32,109,97,110,121,32,116,111,110,101,115,58,32,37,100,32,40,109,97,120,46,32,52,56,41,44,32,102,114,97,109,101,58,32,37,100,33,10,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,110,111,105,115,101,32,115,101,101,100,0,0,0,0,0,92,37,49,91,98,105,115,117,93,37,49,91,48,49,92,125,93,37,110,0,0,0,0,0,113,117,101,114,121,58,32,37,88,10,0,0,0,0,0,0,68,101,102,97,117,108,116,44,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,105,110,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,101,108,101,109,101,110,116,32,99,104,97,110,110,101,108,32,99,111,117,110,116,10,0,0,73,110,99,111,114,114,101,99,116,32,115,108,105,99,101,32,115,105,122,101,10,0,0,0,40,99,41,67,82,73,0,0,68,97,116,117,109,95,71,101,111,99,101,110,116,114,105,99,95,68,97,116,117,109,95,111,102,95,65,117,115,116,114,97,108,105,97,95,49,57,57,52,0,0,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,87,65,86,0,0,0,102,111,114,119,97,114,100,32,112,114,101,100,105,99,116,101,100,32,77,86,115,32,111,102,32,66,45,102,114,97,109,101,115,0,0,0,0,0,0,0,51,100,108,0,0,0,0,0,118,52,49,48,0,0,0,0,97,0,0,0,0,0,0,0,109,101,114,103,101,112,108,97,110,101,115,0,0,0,0,0,99,108,101,97,110,95,115,114,99,0,0,0,0,0,0,0,107,102,95,109,105,110,95,100,105,115,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,97,117,116,111,32,109,111,100,101,44,32,117,115,101,32,48,32,111,114,32,107,102,95,109,97,120,95,100,105,115,116,32,105,110,115,116,101,97,100,46,0,0,0,65,68,80,67,77,32,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,65,70,67,0,0,0,0,0,115,101,116,32,99,97,110,118,97,115,32,115,105,122,101,32,40,87,120,72,32,111,114,32,97,98,98,114,101,118,105,97,116,105,111,110,41,0,0,0,99,113,95,108,101,118,101,108,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,99,102,103,45,62,114,99,95,109,105,110,95,113,117,97,110,116,105,122,101,114,46,46,99,102,103,45,62,114,99,95,109,97,120,95,113,117,97,110,116,105,122,101,114,93,0,0,0,0,108,105,110,101,97,114,0,0,65,84,83,67,32,65,47,53,50,65,32,40,65,67,45,51,41,0,0,0,0,0,0,0,115,105,103,109,97,0,0,0,97,0,0,0,0,0,0,0,83,97,109,112,108,105,110,103], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2341024);
/* memory initializer */ allocate([82,97,116,101,0,0,0,0,65,84,83,67,32,65,47,53,50,65,32,40,65,67,45,51,41,0,0,0,0,0,0,0,86,66,86,32,112,97,114,97,109,101,116,101,114,115,32,99,97,110,110,111,116,32,98,101,32,99,104,97,110,103,101,100,32,119,104,101,110,32,78,65,76,32,72,82,68,32,105,115,32,105,110,32,117,115,101,10,0,0,0,0,0,0,0,0,108,111,114,111,95,99,101,110,116,101,114,95,109,105,120,95,108,101,118,101,108,0,0,0,65,84,83,67,32,65,47,53,50,66,32,40,65,67,45,51,44,32,69,45,65,67,45,51,41,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,32,37,100,10,0,0,0,0,50,45,119,97,121,32,109,97,116,99,104,32,43,32,51,114,100,32,109,97,116,99,104,32,111,110,32,99,111,109,98,101,100,32,40,112,47,99,32,43,32,117,41,0,0,0,0,0,120,50,54,52,95,108,111,111,107,97,104,101,97,100,46,99,108,98,105,110,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,48,0,0,0,0,0,0,0,103,114,97,121,49,54,108,101,0,0,0,0,0,0,0,0,67,111,114,110,102,108,111,119,101,114,66,108,117,101,0,0,65,65,67,32,76,65,84,77,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,32,76,65,84,77,32,115,121,110,116,97,120,41,0,0,0,0,119,104,105,108,101,0,0,0,77,117,108,116,105,99,111,108,111,114,32,99,104,97,114,115,101,116,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,44,32,101,120,116,101,110,100,101,100,32,119,105,116,104,32,53,116,104,32,99,111,108,111,114,32,40,99,111,108,114,97,109,41,0,0,0,83,84,82,69,65,77,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,0,56,83,86,88,32,101,120,112,111,110,101,110,116,105,97,108,0,0,0,0,0,0,0,0,116,111,112,32,102,114,111,110,116,32,99,101,110,116,101,114,0,0,0,0,0,0,0,0,105,110,95,119,0,0,0,0,97,114,101,97,32,97,118,101,114,97,103,105,110,103,0,0,115,114,99,119,0,0,0,0,97,100,100,105,110,103,32,37,100,32,97,117,100,105,111,32,115,97,109,112,108,101,115,32,111,102,32,115,105,108,101,110,99,101,10,0,0,0,0,0,97,118,99,116,120,45,62,119,105,100,116,104,32,37,32,49,54,32,61,61,32,48,32,38,38,32,97,118,99,116,120,45,62,104,101,105,103,104,116,32,37,32,49,54,32,61,61,32,48,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,58,32,37,100,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,0,0,0,0,115,109,111,100,101,0,0,0,97,104,100,101,98,108,111,99,107,0,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,115,104,111,117,108,100,32,98,101,32,48,45,57,44,32,110,111,116,32,37,105,10,0,0,0,0,0,0,0,0,86,101,114,115,105,111,110,32,37,105,46,37,105,0,0,0,67,111,117,108,100,32,110,111,116,32,114,101,115,101,116,32,105,110,102,108,97,116,101,58,32,37,100,46,10,0,0,0,102,114,97,109,101,32,105,115,32,116,111,111,32,111,100,100,32,37,100,10,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,80,108,97,121,82,101,115,89,0,0,0,0,0,0,0,0,121,52,49,112,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,100,105,118,105,115,105,98,108,101,32,98,121,32,56,46,10,0,0,0,0,0,0,76,117,109,97,32,100,101,99,111,100,105,110,103,32,102,97,105,108,101,100,10,0,0,0,97,100,112,99,109,95,105,109,97,95,105,115,115,0,0,0,98,95,112,121,114,97,109,105,100,61,0,0,0,0,0,0,108,97,118,99,120,119,100,101,110,99,0,0,0,0,0,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,0,0,0,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,0,0,0,0,105,110,118,97,108,105,100,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,105,110,118,97,108,105,100,32,99,111,117,112,108,105,110,103,32,114,97,110,103,101,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,0,0,0,79,110,108,121,32,115,105,110,103,108,101,32,114,101,99,116,115,32,115,117,112,112,111,114,116,101,100,32,40,37,100,32,105,110,32,115,117,98,116,105,116,108,101,46,41,10,0,0,73,110,118,97,108,105,100,32,110,117,109,95,98,97,110,100,115,95,48,58,32,37,100,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,116,105,109,101,32,99,111,100,101,10,0,0,0,0,0,0,80,117,108,115,101,32,116,111,111,108,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,101,105,103,104,116,32,115,104,111,114,116,32,115,101,113,117,101,110,99,101,46,10,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,115,105,122,101,32,109,105,115,109,97,116,99,104,32,37,100,32,37,100,32,37,100,10,0,99,117,114,118,101,115,32,37,100,32,40,105,110,116,105,100,61,37,100,41,32,91,37,100,32,112,111,105,110,116,115,93,58,32,91,37,115,93,10,0,83,105,122,101,32,118,97,108,117,101,32,37,100,120,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,111,110,108,121,32,97,99,99,101,112,116,115,32,97,32,115,105,122,101,32,111,102,32,37,100,120,37,100,10,0,0,0,35,100,101,102,105,110,101,32,105,109,97,103,101,95,104,101,105,103,104,116,32,37,117,10,0,0,0,0,0,0,0,0,35,100,101,102,105,110,101,32,37,50,53,53,115,32,37,117,0,0,0,0,0,0,0,0,68,97,116,117,109,95,80,111,105,110,116,101,95,78,111,105,114,101,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,115,101,108,101,99,116,101,100,10,0,0,0,0,0,0,0,70,114,97,109,101,32,100,97,116,97,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,105,110,112,117,116,32,98,117,102,102,101,114,10,0,107,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,102,111,114,119,97,114,100,32,112,114,101,100,105,99,116,101,100,32,77,86,115,32,111,102,32,80,45,102,114,97,109,101,115,0,0,0,0,0,0,0,104,117,102,102,109,97,110,32,116,114,101,101,32,111,118,101,114,102,108,111,119,10,0,0,110,0,0,0,0,0,0,0,115,45,62,110,111,95,114,111,117,110,100,105,110,103,61,61,49,0,0,0,0,0,0,0,114,101,115,95,115,101,116,117,112,45,62,98,111,111,107,115,91,106,93,91,107,93,0,0,52,58,48,58,48,0,0,0,84,111,111,32,109,97,110,121,32,101,102,102,101,99,116,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,0,68,120,116,111,114,121,0,0,83,117,112,101,114,102,114,97,109,101,32,101,110,99,111,100,101,115,32,62,52,56,48,32,115,97,109,112,108,101,115,32,40,37,100,41,44,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,0,0,0,32,40,37,102,59,37,102,41,0,0,0,0,0,0,0,0,97,97,0,0,0,0,0,0,85,84,70,45,56,0,0,0,80,97,99,107,101,116,32,108,111,115,115,32,100,101,116,101,99,116,101,100,33,32,115,101,113,32,37,120,32,118,115,32,37,120,10,0,0,0,0,0,66,105,116,115,116,114,101,97,109,32,115,112,108,105,99,105,110,103,0,0,0,0,0,0,99,119,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,50,0,0,0,99,97,110,118,97,115,95,115,105,122,101,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,50,0,0,0,80,114,111,106,70,97,108,115,101,79,114,105,103,105,110,78,111,114,116,104,105,110,103,71,101,111,75,101,121,0,0,0,67,111,108,111,114,32,109,111,100,101,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,92,78,0,0,0,0,0,0,100,105,118,105,100,101,0,0,109,105,115,115,105,110,103,32,87,69,66,80,32,116,97,103,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,113,98,108,117,114,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,98,105,116,115,32,102,111,114,32,97,108,112,104,97,32,112,108,97,110,101,0,0,0,0,66,108,111,99,107,32,37,100,32,104,97,115,32,105,110,118,97,108,105,100,32,115,105,122,101,32,40,115,105,122,101,32,37,100,32,118,115,46,32,37,100,32,98,121,116,101,115,32,108,101,102,116,41,10,0,0,112,114,111,98,108,101,109,58,32,102,111,117,110,100,32,98,111,116,104,32,67,80,76,48,32,97,110,100,32,67,80,76,90,32,99,104,117,110,107,115,10,0,0,0,0,0,0,0,108,105,109,105,116,0,0,0,102,117,108,108,114,97,110,103,101,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,108,111,99,107,32,98,117,102,102,101,114,115,10,0,0,0,0,0,0,0,67,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,79,110,50,32,86,80,56,0,79,110,50,32,86,80,54,32,40,70,108,97,115,104,32,118,101,114,115,105,111,110,41,0,117,115,101,32,102,111,117,114,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,112,101,114,32,109,97,99,114,111,98,108,111,99,107,32,40,77,80,69,71,45,52,41,0,113,115,99,97,108,101,58,37,100,32,114,108,99,58,37,100,32,114,108,58,37,100,32,100,99,58,37,100,32,109,98,114,108,58,37,100,32,115,108,105,99,101,58,37,100,32,32,32,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,99,111,100,101,99,10,0,0,0,52,77,86,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,99,111,100,101,99,10,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,103,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,79,110,50,32,86,80,51,0,82,84,67,83,84,65,82,84,0,0,0,0,0,0,0,0,86,105,100,101,111,32,83,101,115,115,105,111,110,32,69,114,114,111,114,0,0,0,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,108,117,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,0,0,109,98,95,121,32,60,32,115,45,62,109,98,95,104,101,105,103,104,116,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,97,116,114,105,99,101,115,32,109,97,121,32,99,104,97,110,103,101,32,111,110,108,121,32,111,110,99,101,32,112,101,114,32,97,99,99,101,115,115,32,117,110,105,116,46,10,0,100,101,99,111,100,101,95,115,111,115,58,32,105,110,100,101,120,40,37,100,41,32,111,117,116,32,111,102,32,99,111,109,112,111,110,101,110,116,115,10,0,0,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,99,111,109,109,101,110,116,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,0,86,97,114,105,97,110,99,101,32,65,81,32,40,99,111,109,112,108,101,120,105,116,121,32,109,97,115,107,41,0,0,0,86,80,56,69,95,83,69,84,95,84,79,75,69,78,95,80,65,82,84,73,84,73,79,78,83,0,0,0,0,0,0,0,83,101,116,117,112,32,104,101,97,100,101,114,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,102,111,114,32,90,76,73,66,58,32,40,37,100,41,46,10,0,0,0,0,0,0,83,117,112,112,111,114,116,32,102,111,114,32,105,109,97,103,101,32,111,102,102,115,101,116,115,0,0,0,0,0,0,0,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,123,92,105,48,125,0,0,0,66,97,100,32,85,70,69,80,32,116,121,112,101,32,40,37,100,41,10,0,0,0,0,0,83,105,101,114,114,97,32,86,77,68,32,97,117,100,105,111,0,0,0,0,0,0,0,0,124,43,93,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,97,114,115,101,100,32,83,80,83,58,32,105,100,32,37,100,59,32,99,111,100,101,100,32,119,120,104,58,32,37,100,120,37,100,59,32,99,114,111,112,112,101,100,32,119,120,104,58,32,37,100,120,37,100,59,32,112,105,120,95,102,109,116,58,32,37,115,46,10,0,0,73,110,118,97,108,105,100,32,99,111,108,108,111,99,97,116,101,100,95,114,101,102,95,105,100,120,58,32,37,100,46,10,0,0,0,0,0,0,0,0,82,69,68,85,0,0,0,0,105,110,116,101,114,108,97,99,101,95,116,121,112,101,0,0,72,105,103,104,32,49,48,32,73,110,116,114,97,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,0,0,0,115,101,116,32,116,104,101,32,119,105,100,116,104,32,99,114,111,112,32,97,114,101,97,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,32,108,112,99,32,112,114,101,99,105,115,105,111,110,58,32,37,100,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,108,97,99,100,101,99,46,99,0,0,0,0,108,105,110,101,32,111,114,100,101,114,32,58,32,37,100,10,0,0,0,0,0,0,0,0,76,116,47,82,116,32,68,111,119,110,109,105,120,32,80,114,101,102,101,114,114,101,100,0,65,117,120,105,108,105,97,114,121,32,68,101,99,111,100,101,32,84,105,109,101,32,83,116,97,109,112,32,70,108,97,103,0,0,0,0,0,0,0,0,86,76,67,32,116,97,98,108,101,115,32,105,110,105,116,105,97,108,105,122,101,100,46,10,0,0,0,0,0,0,0,0,108,101,118,101,108,0,0,0,115,119,115,95,112,97,114,97,109,0,0,0,0,0,0,0,76,79,79,80,70,73,76,84,69,82,32,115,104,97,108,108,32,110,111,116,32,98,101,32,101,110,97,98,108,101,100,32,105,110,32,83,105,109,112,108,101,32,80,114,111,102,105,108,101,10,0,0,0,0,0,0,109,115,109,112,101,103,52,118,51,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,86,66,76,69,32,86,101,114,115,105,111,110,58,32,37,100,10,0,0,0,80,97,108,101,116,116,101,32,99,104,97,110,103,101,32,114,117,110,115,32,98,101,121,111,110,100,32,101,110,116,114,121,32,50,53,54,10,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,118,52,49,48,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,46,10,0,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,81,84,32,52,58,52,58,52,58,52,0,0,68,97,116,117,109,95,80,97,108,101,115,116,105,110,101,95,49,57,50,51,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,81,84,32,52,58,52,58,52,58,52,0,0,83,83,69,50,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,112,102,0,0,0,0,0,0,118,51,48,56,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,46,10,0,0,0,0,0,0,0,0,40,80,114,111,98,97,98,108,121,41,32,112,97,100,100,101,100,32,100,97,116,97,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,67,108,97,115,115,105,99,97,108,0,0,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,73,110,112,117,116,32,112,97,100,32,34,37,115,34,32,119,105,116,104,32,116,121,112,101,32,37,115,32,111,102,32,116,104,101,32,102,105,108,116,101,114,32,105,110,115,116,97,110,99,101,32,34,37,115,34,32,111,102,32,37,115,32,110,111,116,32,99,111,110,110,101,99,116,101,100,32,116,111,32,97,110,121,32,115,111,117,114,99,101,10,0,0,0,0,0,0,100,120,116,111,114,121,0,0,69,114,114,111,114,32,101,110,99,111,100,105,110,103,32,112,108,97,110,101,32,37,100,46,10,0,0,0,0,0,0,0,37,100,58,37,100,0,0,0,105,109,97,103,101,47,106,112,101,103,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,115,108,105,99,101,32,115,105,122,101,10,0,0,0,85,115,101,32,82,70,54,52,32,104,101,97,100,101,114,32,114,97,116,104,101,114,32,116,104,97,110,32,82,73,70,70,32,102,111,114,32,108,97,114,103,101,32,102,105,108,101,115,46,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,83,111,117,114,99,101,32,97,110,100,32,100,101,115,116,105,110,97,116,105,111,110,32,99,111,108,111,114,32,115,112,97,99,101,32,109,117,115,116,32,110,111,116,32,98,101,32,105,100,101,110,116,105,99,97,108,10,0,0,0,0,0,0,0,99,111,109,112,97,116,58,32,99,97,108,108,101,100,32,119,105,116,104,32,97,114,103,115,61,91,37,115,93,10,0,0,65,108,108,32,105,110,102,111,32,102,111,117,110,100,10,0,84,101,101,32,109,117,120,101,114,0,0,0,0,0,0,0,97,117,100,105,111,0,0,0,102,105,120,32,115,117,98,116,105,116,108,101,115,32,100,117,114,97,116,105,111,110,0,0,108,105,98,97,118,99,111,100,101,99,47,117,116,105,108,115,46,99,0,0,0,0,0,0,119,97,114,110,105,110,103,58,32,117,110,107,110,111,119,110,32,101,115,99,97,112,101,32,48,120,37,48,50,88,10,0,100,101,112,116,104,32,111,102,32,37,105,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,65,117,100,105,111,84,97,103,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,77,68,67,84,10,0,0,0,0,0,0,0,0,70,114,97,109,101,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,73,110,102,108,97,116,101,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,67,104,97,110,110,101,108,32,99,111,117,110,116,32,37,100,0,0,0,0,0,0,0,0,110,111,32,115,112,97,99,101,32,102,111,114,32,116,109,50,95,114,101,97,100,95,115,116,114,101,97,109,10,0,0,0,73,110,118,97,108,105,100,32,105,110,100,101,120,32,118,97,108,117,101,46,10,0,0,0,115,101,116,32,116,104,101,32,114,101,100,32,103,97,105,110,32,102,111,114,32,116,104,101,32,114,101,100,32,99,104,97,110,110,101,108,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,10,0,0,0,0,0,0,109,99,100,101,105,110,116,0,115,101,116,32,114,101,100,32,115,104,97,100,111,119,115,0,68,97,116,117,109,95,80,97,100,97,110,103,95,49,56,56,52,0,0,0,0,0,0,0,100,101,98,117,103,95,109,118,0,0,0,0,0,0,0,0,86,66,76,69,32,76,111,115,115,108,101,115,115,32,67,111,100,101,99,0,0,0,0,0,102,105,120,95,115,117,98,95,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,32,109,97,116,99,104,101,100,32,97,115,32,37,115,46,10,0,0,0,0,0,0,0,0,108,117,109,97,95,114,97,100,105,117,115,0,0,0,0,0,102,102,99,111,110,99,97,116,0,0,0,0,0,0,0,0,65,65,67,32,119,105,116,104,32,110,111,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,32,105,115,32,99,117,114,114,101,110,116,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,71,101,111,103,114,97,112,104,105,99,84,121,112,101,71,101,111,75,101,121,0,0,0,0,87,77,65,80,0,0,0,0,37,115,37,53,105,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,113,0,0,0,0,0,0,73,70,68,32,111,102,102,115,101,116,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,105,109,97,103,101,32,115,105,122,101,10,0,0,115,101,113,0,0,0,0,0,86,80,108,97,121,101,114,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,80,105,120,101,108,32,102,111,114,109,97,116,32,39,37,115,39,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,70,105,108,101,32,119,105,116,104,111,117,116,32,99,111,108,111,114,109,97,112,32,104,97,115,32,99,111,108,111,114,109,97,112,32,105,110,102,111,114,109,97,116,105,111,110,32,115,101,116,46,10,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,58,32,37,100,10,0,0,99,111,108,111,114,32,115,97,116,117,114,97,116,105,111,110,32,109,117,108,116,105,112,108,105,101,114,0,0,0,0,0,37,99,32,104,112,101,108,58,37,100,44,32,116,112,101,108,58,37,100,32,97,113,112,58,37,100,32,113,112,58,37,100,44,32,115,108,105,99,101,95,110,117,109,58,37,48,50,88,10,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,84,73,70,70,47,73,70,70,47,69,88,80,69,82,73,77,69,78,84,65,76,32,40,99,111,109,112,114,101,115,115,105,111,110,41,32,116,121,112,101,0,0,0,0,0,0,0,0,65,86,80,97,99,107,101,116,32,105,115,32,110,111,116,32,99,108,101,97,110,32,40,99,111,110,116,97,105,110,115,32,116,105,109,105,110,103,32,105,110,102,111,114,109,97,116,105,111,110,41,46,32,89,111,117,32,110,101,101,100,32,116,111,32,117,112,103,114,97,100,101,32,121,111,117,114,32,108,105,98,97,118,102,111,114,109,97,116,32,111,114,32,115,97,110,105,116,105,122,101,32,121,111,117,114,32,112,97,99,107,101,116,46,10,0,0,0,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,65,77,86,32,86,105,100,101,111,0,0,0,0,0,0,0,83,111,110,105,99,32,108,111,115,115,108,101,115,115,0,0,115,45,62,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,45,62,100,97,116,97,91,48,93,0,0,0,0,0,104,50,54,51,0,0,0,0,101,114,114,111,114,32,97,116,32,101,110,100,32,111,102,32,102,114,97,109,101,10,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,112,101,114,32,106,112,101,103,46,10,0,0,0,0,0,83,77,67,32,100,101,99,111,100,101,114,32,106,117,115,116,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,114,111,119,32,112,116,114,32,61,32,37,100,44,32,104,101,105,103,104,116,32,61,32,37,100,41,10,0,0,0,0,0,0,0,0,83,109,97,99,107,101,114,32,97,117,100,105,111,0,0,0,49,54,107,0,0,0,0,0,117,110,107,110,111,119,110,32,115,104,111,114,116,101,110,32,102,117,110,99,116,105,111,110,32,37,100,10,0,0,0,0,98,97,100,32,109,97,103,105,99,32,110,117,109,98,101,114,10,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,68,97,116,117,109,95,79,83,95,83,78,95,49,57,56,48,0,0,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,112,97,108,101,116,116,101,32,98,108,111,99,107,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,0,118,105,115,117,97,108,105,122,101,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,40,77,86,115,41,0,0,92,78,0,0,0,0,0,0,69,110,99,111,100,105,110,103,32,37,100,32,99,104,97,110,110,101,108,40,115,41,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,32,79,110,108,121,32,50,44,32,52,44,32,54,32,97,110,100,32,56,32,99,104,97,110,110,101,108,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,102,114,97,109,101,32,104,97,115,32,105,110,118,97,108,105,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,68,113,117,97,110,116,32,102,111,114,32,66,45,102,114,97,109,101,10,0,0,0,0,0,78,101,119,32,102,114,97,109,101,32,98,117,116,32,115,116,105,108,108,32,37,100,32,77,66,32,108,101,102,116,46,10,0,0,0,0,0,0,0,0,118,98,108,101,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,45,32,110,101,101,100,32,97,116,32,108,101,97,115,116,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,10,0,0,0,0,0,0,0,0,115,45,62,117,110,114,101,115,116,114,105,99,116,101,100,95,109,118,32,61,61,32,48,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,114,118,50,48,0,0,0,0,77,79,86,32,99,104,117,110,107,32,115,105,122,101,32,33,61,32,101,110,99,111,100,101,100,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,68,105,109,101,110,115,105,111,110,115,32,109,117,115,116,32,98,101,32,100,105,118,105,115,105,98,108,101,32,98,121,32,49,54,10,0,0,0,0,0,67,104,117,110,107,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,89,0,0,0,0,0,0,0,65,117,100,105,111,32,109,117,115,116,32,98,101,32,50,50,48,53,48,32,72,122,10,0,105,110,118,97,108,105,100,32,118,105,100,101,111,95,98,97,115,101,10,0,0,0,0,0,60,98,114,62,0,0,0,0,102,111,114,99,101,32,115,117,98,116,105,116,108,101,32,116,97,103,47,102,111,117,114,99,99,0,0,0,0,0,0,0,97,118,99,116,120,45,62,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,32,61,61,32,50,0,0,0,0,0,0,0,115,101,101,107,50,97,110,121,0,0,0,0,0,0,0,0,105,84,101,120,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,32,98,117,102,102,101,114,115,0,0,0,0,0,0,0,0,87,114,111,110,103,32,112,97,99,107,101,116,32,116,97,105,108,115,32,97,114,101,32,119,114,111,110,103,33,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,98,108,111,99,107,32,97,108,105,103,110,10,0,0,0,0,0,0,0,0,80,101,114,99,101,110,116,97,103,101,32,111,102,32,116,104,101,32,112,105,120,101,108,115,32,116,104,97,116,32,104,97,118,101,32,116,111,32,98,101,32,98,101,108,111,119,32,116,104,101,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,116,104,101,32,102,114,97,109,101,32,116,111,32,98,101,32,99,111,110,115,105,100,101,114,101,100,32,98,108,97,99,107,46,0,0,0,0,0,0,65,74,65,32,75,111,110,97,32,49,48,45,98,105,116,32,82,71,66,32,67,111,100,101,99,0,0,0,0,0,0,0,65,74,65,32,75,111,110,97,32,49,48,45,98,105,116,32,82,71,66,32,67,111,100,101,99,0,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,80,114,111,98,108,101,109,58,32,112,105,120,101,108,95,112,116,114,32,61,32,37,100,44,32,112,105,120,101,108,95,108,105,109,105,116,32,61,32,37,100,10,0,0,0,0,0,0,66,111,103,117,115,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,40,37,105,44,37,105,41,44,32,98,108,111,99,107,32,115,105,122,101,32,37,105,120,37,105,32,97,116,32,37,105,44,37,105,10,0,65,65,67,76,0,0,0,0,80,97,108,101,116,116,101,32,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,117,10,0,84,104,105,115,32,102,105,108,101,32,116,114,105,103,103,101,114,115,32,115,111,109,101,32,109,105,115,115,105,110,103,32,99,111,100,101,46,32,80,108,101,97,115,101,32,99,111,110,116,97,99,116,32,116,104,101,32,100,101,118,101,108,111,112,101,114,115,46,10,80,111,115,105,116,105,111,110,58,32,37,115,10,0,0,0,0,0,0,66,105,116,114,97,116,101,32,105,115,32,49,47,56,32,97,110,100,32,102,105,114,115,116,32,49,54,32,98,105,116,115,32,97,114,101,32,111,110,46,0,0,0,0,0,0,0,0,111,102,102,115,101,116,32,33,61,32,48,120,50,99,0,0,110,117,116,47,109,117,108,116,105,109,101,100,105,97,32,99,111,110,116,97,105,110,101,114,0,0,0,0,0,0,0,0,97,108,112,104,97,32,98,105,116,115,32,115,104,111,117,108,100,32,98,101,32,48,44,32,56,32,111,114,32,49,54,10,0,0,0,0,0,0,0,0,115,108,105,99,101,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,0,0,69,114,114,111,114,32,42,115,116,114,101,97,109,95,105,100,32,105,115,32,40,37,108,108,100,41,10,0,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,115,101,116,32,109,105,110,105,109,117,109,32,100,101,116,101,99,116,101,100,32,98,108,97,99,107,32,100,117,114,97,116,105,111,110,32,105,110,32,115,101,99,111,110,100,115,0,0,80,71,77,89,85,86,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,32,89,85,86,41,32,105,109,97,103,101,0,0,0,0,0,80,71,77,89,85,86,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,32,89,85,86,41,32,105,109,97,103,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,49,46,50,46,53,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,76,69,32,100,97,116,97,32,108,101,110,103,116,104,32,37,117,32,105,115,32,37,117,32,98,121,116,101,115,32,115,104,111,114,116,101,114,32,116,104,97,110,32,101,120,112,101,99,116,101,100,10,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,102,109,116,10,0,0,0,0,0,105,110,118,97,108,105,100,32,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,10,0,0,0,0,0,0,0,105,110,100,101,120,32,101,110,116,114,121,32,37,105,32,43,32,84,101,109,112,111,114,97,108,79,102,102,115,101,116,32,37,105,32,61,32,37,105,44,32,119,104,105,99,104,32,105,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,68,69,70,65,85,76,84,95,86,79,76,0,0,0,0,0,115,101,116,32,109,105,110,105,109,117,109,32,108,117,109,105,110,97,110,99,101,32,118,97,108,117,101,32,102,111,114,32,98,111,117,110,100,105,110,103,32,98,111,120,0,0,0,0,112,99,109,95,102,51,50,98,101,0,0,0,0,0,0,0,98,108,111,99,107,95,115,105,122,101,32,104,97,115,32,99,104,97,110,103,101,100,32,37,100,32,33,61,32,37,100,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,80,69,71,84,83,32,109,117,120,101,114,0,0,0,0,71,82,65,89,83,67,65,76,69,0,0,0,0,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,65,117,100,105,111,0,0,0,0,0,0,116,105,109,101,115,116,97,109,112,95,108,101,110,32,62,32,54,52,0,0,0,0,0,0,68,97,116,117,109,95,79,83,71,66,95,49,57,55,48,95,83,78,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,10,0,118,105,115,109,118,0,0,0,37,100,58,37,100,58,37,100,58,37,100,0,0,0,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,32,118,105,100,101,111,0,0,77,80,51,32,109,117,120,101,114,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,112,105,120,101,108,32,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,46,0,0,0,0,0,0,115,116,97,103,0,0,0,0,113,117,101,117,101,45,62,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,0,0,37,115,32,112,114,111,102,105,108,101,32,100,111,101,115,110,39,116,32,115,117,112,112,111,114,116,32,52,58,52,58,52,10,0,0,0,0,0,0,0,68,105,115,112,108,97,121,72,101,105,103,104,116,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,102,52,118,0,103,101,110,114,101,0,0,0,84,114,105,101,100,32,116,111,32,99,111,112,121,32,65,86,67,111,100,101,99,67,111,110,116,101,120,116,32,37,112,32,105,110,116,111,32,97,108,114,101,97,100,121,45,105,110,105,116,105,97,108,105,122,101,100,32,37,112,10,0,0,0,0,110,111,116,32,97,32,110,117,118,32,118,105,100,101,111,32,102,114,97,109,101,10,0,0,78,101,108,108,121,109,111,115,101,114,32,119,111,114,107,115,32,111,110,108,121,32,119,105,116,104,32,56,48,48,48,44,32,49,54,48,48,48,44,32,49,49,48,50,53,44,32,50,50,48,53,48,32,97,110,100,32,52,52,49,48,48,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,76,101,102,116,111,118,101,114,32,98,121,116,101,115,58,32,37,100,46,10,0,0,0,0,104,117,102,102,109,97,110,32,116,97,98,108,101,32,100,101,99,111,100,101,32,101,114,114,111,114,10,0,0,0,0,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,116,105,111,110,32,86,105,100,101,111,32,67,111,109,112,114,101,115,115,111,114,32,50,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,32,37,88,10,0,0,85,110,101,120,112,101,99,116,101,100,32,103,114,97,110,100,99,104,105,108,100,114,101,110,10,0,0,0,0,0,0,0,115,116,97,114,116,105,0,0,70,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,32,116,111,111,32,115,109,97,108,108,0,0,0,0,0,0,0,0,67,97,110,39,116,32,119,114,105,116,101,32,112,97,99,107,101,116,32,119,105,116,104,32,117,110,107,110,111,119,110,32,116,105,109,101,115,116,97,109,112,10,0,0,0,0,0,0,98,121,116,101,115,116,114,101,97,109,32,111,118,101,114,114,117,110,10,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,101,110,99,111,100,101,114,0,123,92,105,49,125,0,0,0,82,68,32,111,112,116,105,109,97,108,32,77,66,32,108,101,118,101,108,32,114,101,115,105,100,117,97,108,32,115,107,105,112,112,105,110,103,0,0,0,68,97,116,117,109,95,79,83,71,66,95,49,57,51,54,0,78,111,32,115,117,99,104,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,115,46,10,0,0,0,0,0,0,116,104,114,101,97,100,105,110,103,32,111,112,101,114,97,116,105,111,110,115,0,0,0,0,33,112,105,99,45,62,102,46,98,117,102,91,48,93,0,0,114,115,0,0,0,0,0,0,98,109,118,95,118,105,100,101,111,0,0,0,0,0,0,0,82,101,97,100,32,97,117,100,105,111,32,102,114,111,109,32,97,32,109,111,118,105,101,32,115,111,117,114,99,101,46,0,73,110,118,97,108,105,100,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,0,102,111,114,99,101,32,115,117,98,116,105,116,108,101,32,99,111,100,101,99,32,40,39,99,111,112,121,39,32,116,111,32,99,111,112,121,32,115,116,114,101,97,109,41,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,84,68,69,78,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,80,97,115,115,32,111,110,32,116,104,101,32,97,117,100,105,111,32,105,110,112,117,116,32,116,111,32,78,32,97,117,100,105,111,32,111,117,116,112,117,116,115,46,0,0,0,0,0,109,112,101,103,52,0,0,0,35,69,88,84,73,78,70,58,0,0,0,0,0,0,0,0,110,117,109,98,101,114,32,111,102,32,102,114,97,103,109,101,110,116,115,32,107,101,112,116,32,105,110,32,116,104,101,32,109,97,110,105,102,101,115,116,0,0,0,0,0,0,0,0,68,105,115,112,108,97,121,87,105,100,116,104,0,0,0,0,98,101,102,111,114,101,32,118,111,112,95,99,111,100,105,110,103,95,116,121,112,101,32,105,110,32,118,105,100,101,111,32,112,97,99,107,101,100,32,104,101,97,100,101,114,0,0,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,119,105,100,116,104,0,0,0,102,105,108,101,112,111,115,105,116,105,111,110,115,0,0,0,77,80,69,71,45,50,32,118,105,100,101,111,0,0,0,0,84,111,111,32,115,109,97,108,108,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,40,37,105,41,33,10,0,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,110,111,116,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,46,32,101,120,116,114,97,32,98,121,116,101,115,32,97,116,32,116,104,101,32,101,110,100,32,119,105,108,108,32,98,101,32,115,107,105,112,112,101,100,46,10,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,65,83,83,32,101,118,101,110,116,46,10,0,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,32,115,105,122,101,32,37,100,47,37,100,10,0,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,83,101,116,32,80,84,83,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,97,117,100,105,111,32,102,114,97,109,101,46,0,0,0,0,0,84,114,117,101,72,68,0,0,109,108,112,112,97,114,115,101,58,32,80,97,114,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,46,10,0,108,105,98,97,118,99,111,100,101,99,47,109,106,112,101,103,101,110,99,46,99,0,0,0,97,98,111,114,116,105,110,103,46,10,0,0,0,0,0,0,102,105,101,108,100,32,115,105,122,101,58,32,48,120,37,120,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,112,114,101,115,101,116,32,39,37,115,39,10,0,0,0,0,68,97,116,117,109,95,78,83,87,67,95,57,90,95,50,0,105,110,118,97,108,105,100,32,119,105,100,116,104,47,104,101,105,103,104,116,33,10,0,0,116,104,114,101,97,100,95,111,112,115,0,0,0,0,0,0,65,86,80,97,99,107,101,116,32,105,115,32,110,111,116,32,99,108,101,97,110,32,40,99,111,110,116,97,105,110,115,32,116,105,109,105,110,103,32,105,110,102,111,114,109,97,116,105,111,110,32,97,110,100,32,97,32,116,114,97,105,108,105,110,103,32,108,105,110,101,32,98,114,101,97,107,41,46,32,89,111,117,32,110,101,101,100,32,116,111,32,117,112,103,114,97,100,101,32,121,111,117,114,32,108,105,98,97,118,102,111,114,109,97,116,32,111,114,32,115,97,110,105,116,105,122,101,32,121,111,117,114,32,112,97,99,107,101,116,46,10,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,116,97,103,32,37,48,56,88,10,0,0,0,0,0,0,0,0,85,116,32,86,105,100,101,111,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,99,32,99,111,100,101,32,97,116,10,0,0,0,0,0,77,65,67,69,32,40,77,97,99,105,110,116,111,115,104,32,65,117,100,105,111,32,67,111], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2351264);
/* memory initializer */ allocate([109,112,114,101,115,115,105,111,110,47,69,120,112,97,110,115,105,111,110,41,32,54,58,49,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,76,105,109,105,116,101,100,32,114,97,110,103,101,32,89,85,86,32,105,115,32,110,111,110,45,115,116,97,110,100,97,114,100,44,32,115,101,116,32,115,116,114,105,99,116,95,115,116,100,95,99,111,109,112,108,105,97,110,99,101,32,116,111,32,97,116,32,108,101,97,115,116,32,117,110,111,102,102,105,99,105,97,108,32,116,111,32,117,115,101,32,105,116,46,10,0,115,99,111,100,101,99,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,78,111,110,45,105,110,116,101,114,108,101,97,118,101,100,32,65,86,73,32,119,105,116,104,111,117,116,32,105,110,100,101,120,44,32,115,119,105,116,99,104,105,110,103,32,116,111,32,105,110,116,101,114,108,101,97,118,101,100,10,0,0,0,0,108,105,98,120,50,54,52,32,72,46,50,54,52,32,47,32,65,86,67,32,47,32,77,80,69,71,45,52,32,65,86,67,32,47,32,77,80,69,71,45,52,32,112,97,114,116,32,49,48,32,82,71,66,0,0,0,83,101,99,114,101,116,32,100,97,116,97,58,10,0,0,0,77,97,120,72,101,105,103,104,116,0,0,0,0,0,0,0,108,105,98,118,112,120,32,86,80,57,0,0,0,0,0,0,108,105,98,118,112,120,32,86,80,57,0,0,0,0,0,0,68,101,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,90,76,73,66,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,111,102,102,115,101,116,115,10,0,0,85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,37,105,10,0,0,102,114,97,109,101,32,102,105,110,105,115,104,101,100,32,119,105,116,104,32,37,100,32,100,105,102,102,10,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,32,116,121,112,101,32,37,105,10,0,0,0,0,0,0,74,80,69,71,45,76,83,32,112,97,114,97,109,115,58,32,37,105,120,37,105,32,78,69,65,82,61,37,105,32,77,86,61,37,105,32,84,40,37,105,44,37,105,44,37,105,41,32,82,69,83,69,84,61,37,105,44,32,76,73,77,73,84,61,37,105,44,32,113,98,112,112,61,37,105,44,32,82,65,78,71,69,61,37,105,10,0,0,83,79,67,32,109,97,114,107,101,114,32,110,111,116,32,112,114,101,115,101,110,116,10,0,114,101,115,32,43,32,49,32,60,32,40,48,120,55,102,102,102,102,102,102,102,41,0,0,66,117,102,102,101,114,32,105,110,112,117,116,32,102,114,97,109,101,115,32,97,110,100,32,115,101,110,100,32,116,104,101,109,32,119,104,101,110,32,116,104,101,121,32,97,114,101,32,114,101,113,117,101,115,116,101,100,46,0,0,0,0,0,0,86,77,0,0,0,0,0,0,111,110,99,101,0,0,0,0,100,119,116,10,0,0,0,0,10,0,0,0,0,0,0,0,80,97,115,115,119,111,114,100,45,112,114,111,116,101,99,116,101,100,32,99,108,105,112,33,10,0,0,0,0,0,0,0,32,85,77,86,0,0,0,0,100,101,99,111,100,101,32,102,105,110,105,115,104,101,100,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,108,101,102,116,32,111,118,101,114,10,0,0,0,0,0,0,0,0,83,101,116,32,116,105,109,101,98,97,115,101,32,102,111,114,32,116,104,101,32,97,117,100,105,111,32,111,117,116,112,117,116,32,108,105,110,107,46,0,112,108,97,99,101,98,111,0,73,110,116,101,108,32,72,50,54,51,32,102,114,101,101,32,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,68,97,116,117,109,95,78,111,117,118,101,108,108,101,95,84,114,105,97,110,103,117,108,97,116,105,111,110,95,70,114,97,110,99,97,105,115,101,0,0,112,105,99,116,117,114,101,32,98,117,102,102,101,114,32,97,108,108,111,99,97,116,105,111,110,115,0,0,0,0,0,0,65,108,108,111,99,97,116,101,100,32,116,105,108,101,32,115,105,122,101,32,37,100,32,109,105,115,109,97,116,99,104,101,115,32,112,97,114,97,109,101,116,101,114,115,32,37,100,10,0,0,0,0,0,0,0,0,69,109,112,116,121,32,109,97,99,114,111,98,108,111,99,107,32,105,110,32,97,110,32,73,78,84,82,65,32,112,105,99,116,117,114,101,33,10,0,0,72,122,0,0,0,0,0,0,117,116,118,105,100,101,111,0,83,116,97,99,107,32,111,118,101,114,102,108,111,119,32,40,99,111,114,114,117,112,116,101,100,32,98,105,110,97,114,121,32,116,114,101,101,41,33,10,0,0,0,0,0,0,0,0,121,117,118,106,0,0,0,0,73,65,67,32,40,73,110,100,101,111,32,65,117,100,105,111,32,67,111,100,101,114,41,0,8,4,4,8,4,4,8,2,4,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,32,32,105,100,32,67,73,78,32,118,105,100,101,111,58,32,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,111,102,32,37,100,10,0,0,72,117,102,102,121,117,118,32,70,70,109,112,101,103,32,118,97,114,105,97,110,116,0,0,100,105,115,97,98,108,101,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,72,117,102,102,121,117,118,32,70,70,109,112,101,103,32,118,97,114,105,97,110,116,0,0,105,110,118,97,108,105,100,32,99,104,117,110,107,32,105,100,58,32,37,100,10,0,0,0,97,99,116,105,118,101,95,112,97,114,97,109,101,116,101,114,95,115,101,116,95,105,100,32,37,100,32,105,110,118,97,108,105,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,114,101,102,101,114,101,110,99,101,32,105,110,100,101,120,46,10,0,0,0,0,0,0,0,77,97,120,87,105,100,116,104,0,0,0,0,0,0,0,0,104,97,108,102,32,111,102,32,115,105,110,101,32,119,97,118,101,0,0,0,0,0,0,0,99,111,109,109,97,110,100,115,0,0,0,0,0,0,0,0,86,101,114,105,102,121,105,110,103,32,99,104,101,99,107,115,117,109,32,102,111,114,32,102,114,97,109,101,32,119,105,116,104,32,80,79,67,32,37,100,58,32,0,0,0,0,0,0,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,108,105,98,118,112,120,47,46,46,47,100,105,115,116,32,45,45,100,105,115,97,98,108,101,45,101,120,97,109,112,108,101,115,32,45,45,100,105,115,97,98,108,101,45,100,111,99,115,32,45,45,100,105,115,97,98,108,101,45,114,117,110,116,105,109,101,45,99,112,117,45,100,101,116,101,99,116,32,45,45,100,105,115,97,98,108,101,45,109,117,108,116,105,116,104,114,101,97,100,32,45,45,100,105,115,97,98,108,101,45,111,112,116,105,109,105,122,97,116,105,111,110,115,32,45,45,116,97,114,103,101,116,61,103,101,110,101,114,105,99,45,103,110,117,0,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,99,104,101,99,107,101,114,98,111,97,114,100,95,114,108,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,32,111,114,32,99,111,114,114,117,112,116,32,116,105,108,101,32,108,101,110,103,116,104,0,114,101,102,101,114,101,110,99,101,32,99,111,117,110,116,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,115,101,116,32,111,117,116,101,114,32,99,111,108,111,114,105,110,103,32,109,111,100,101,0,116,114,105,109,0,0,0,0,68,105,102,102,101,114,101,110,116,32,99,104,114,111,109,97,32,97,110,100,32,108,117,109,97,32,98,105,116,32,100,101,112,116,104,0,0,0,0,0,115,116,105,116,99,104,0,0,110,111,110,45,101,120,105,115,116,105,110,103,32,80,80,83,32,37,117,32,114,101,102,101,114,101,110,99,101,100,10,0,115,116,97,114,116,95,102,117,108,108,0,0,0,0,0,0,109,98,95,116,121,112,101,32,37,100,32,105,110,32,37,99,32,115,108,105,99,101,32,116,111,111,32,108,97,114,103,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,111,118,101,114,102,108,111,119,32,105,110,32,100,101,99,111,100,101,95,99,97,98,97,99,95,109,98,95,109,118,100,10,0,0,0,0,0,0,0,0,82,101,97,108,108,111,99,97,116,105,110,103,32,102,114,97,109,101,32,100,117,101,32,116,111,32,100,105,102,102,101,114,105,110,103,32,115,116,114,105,100,101,10,0,0,0,0,0,101,118,97,108,32,101,120,112,114,101,115,115,105,111,110,115,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,0,116,111,112,32,98,108,111,99,107,32,117,110,97,118,97,105,108,97,98,108,101,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,105,110,116,114,97,32,109,111,100,101,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,68,105,115,99,97,114,100,105,110,103,32,101,120,99,101,115,115,105,118,101,32,98,105,116,115,116,114,101,97,109,32,105,110,32,112,97,99,107,101,100,32,120,118,105,100,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,71,83,77,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,0,0,0,118,101,114,121,115,108,111,119,0,0,0,0,0,0,0,0,68,97,116,117,109,95,68,97,116,117,109,95,55,51,0,0,108,117,116,51,100,0,0,0,99,111,100,101,61,37,48,50,120,32,39,37,99,39,10,0,98,117,102,102,101,114,115,0,78,111,32,97,118,97,105,108,97,98,108,101,32,99,111,108,111,114,44,32,99,97,110,32,110,111,116,32,117,115,101,32,116,114,97,110,115,112,97,114,101,110,99,121,10,0,0,0,71,46,55,50,57,32,64,32,56,107,98,105,116,47,115,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,32,73,109,97,103,101,32,118,50,0,0,71,46,55,50,54,32,65,68,80,67,77,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,79,110,108,121,32,109,111,110,111,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,45,104,101,108,112,0,0,0,82,101,113,117,101,115,116,101,100,32,102,114,97,109,101,32,115,105,122,101,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,32,85,115,105,110,103,32,37,100,32,105,110,115,116,101,97,100,32,111,102,32,37,100,10,0,0,0,0,98,105,116,115,95,112,101,114,95,99,111,100,101,119,111,114,100,0,0,0,0,0,0,0,87,114,111,110,103,32,109,97,103,105,99,32,37,48,56,88,10,0,0,0,0,0,0,0,83,101,108,101,99,116,32,118,105,100,101,111,32,102,114,97,109,101,115,32,116,111,32,112,97,115,115,32,105,110,32,111,117,116,112,117,116,46,0,0,105,110,99,111,114,114,101,99,116,32,109,97,114,107,101,114,10,0,0,0,0,0,0,0,84,104,105,115,32,102,105,108,101,32,105,115,32,101,110,99,111,100,101,100,32,119,105,116,104,32,70,114,97,112,115,32,118,101,114,115,105,111,110,32,37,100,46,32,84,104,105,115,32,99,111,100,101,99,32,99,97,110,32,111,110,108,121,32,100,101,99,111,100,101,32,118,101,114,115,105,111,110,115,32,60,61,32,53,46,10,0,0,102,108,118,0,0,0,0,0,97,110,97,103,108,121,112,104,32,103,114,101,101,110,32,109,97,103,101,110,116,97,32,103,114,97,121,0,0,0,0,0,115,110,0,0,0,0,0,0,50,52,66,112,112,32,70,76,67,32,85,110,115,117,112,112,111,114,116,101,100,32,100,117,101,32,116,111,32,108,97,99,107,32,111,102,32,116,101,115,116,32,102,105,108,101,115,46,10,0,0,0,0,0,0,0,101,114,114,111,114,32,119,104,105,108,101,32,99,111,109,112,114,101,115,115,105,110,103,32,98,108,111,99,107,32,37,100,120,37,100,10,0,0,0,0,73,110,115,101,114,116,105,110,103,32,107,101,121,32,102,114,97,109,101,32,97,116,32,102,114,97,109,101,32,37,100,10,0,0,0,0,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,118,50,0,0,0,69,114,114,111,114,32,117,112,100,97,116,105,110,103,32,77,68,53,32,99,104,101,99,107,115,117,109,10,0,0,0,0,115,107,105,112,105,110,103,32,102,108,97,99,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,49,10,0,0,0,114,97,110,103,101,0,0,0,74,117,110,107,32,102,114,97,109,101,32,116,105,108,108,32,111,102,102,115,101,116,32,37,105,10,0,0,0,0,0,0,87,86,67,49,0,0,0,0,98,114,111,107,101,110,32,115,116,114,101,97,109,44,32,105,110,118,97,108,105,100,32,112,97,100,100,105,110,103,10,0,70,114,97,109,101,32,100,97,116,97,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,105,110,116,101,114,118,97,108,115,32,100,101,102,105,110,105,116,105,111,110,115,46,10,0,114,111,116,119,0,0,0,0,83,101,116,32,112,101,114,109,105,115,115,105,111,110,115,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,118,105,100,101,111,32,102,114,97,109,101,46,0,0,0,0,0,10,0,0,0,0,0,0,0,118,101,114,58,37,100,32,107,101,121,102,114,97,109,101,58,37,100,32,99,111,100,101,114,58,37,100,32,101,99,58,37,100,32,115,108,105,99,101,115,58,37,100,32,98,112,115,58,37,100,10,0,0,0,0,0,87,114,111,110,103,32,109,97,103,105,99,32,110,117,109,98,101,114,32,37,100,10,0,0,102,114,97,109,101,32,101,114,97,115,117,114,101,10,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,115,107,105,112,32,118,97,108,117,101,10,0,0,0,0,0,0,69,115,99,97,112,101,32,115,105,122,101,115,58,32,37,105,44,32,37,105,44,32,37,105,10,0,0,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,105,110,116,114,97,32,102,114,97,109,101,10,0,0,117,110,115,117,112,112,111,114,116,101,100,32,109,98,32,109,111,100,101,32,37,105,10,0,68,105,109,101,110,115,105,111,110,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,100,97,114,0,0,0,0,0,48,0,0,0,0,0,0,0,70,114,97,109,101,32,104,101,97,100,101,114,32,37,88,0,99,111,109,112,114,58,37,50,100,44,32,100,115,105,122,101,58,37,100,10,0,0,0,0,98,105,116,115,116,114,101,97,109,32,119,114,105,116,116,101,110,32,98,101,121,111,110,100,32,98,117,102,102,101,114,32,115,105,122,101,10,0,0,0,84,101,109,112,111,114,97,108,108,121,32,105,110,116,101,114,108,101,97,118,101,32,97,117,100,105,111,32,105,110,112,117,116,115,46,0,0,0,0,0,69,110,100,32,98,111,116,104,32,115,116,114,101,97,109,115,46,0,0,0,0,0,0,0,83,101,108,101,99,116,101,100,32,112,97,108,101,116,116,101,58,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,97,108,116,114,101,102,32,98,117,102,102,101,114,0,0,0,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,114,101,99,111,110,115,116,114,117,99,116,32,116,111,111,32,108,97,114,103,101,32,83,80,85,32,112,97,99,107,101,116,115,32,97,98,111,114,116,101,100,46,10,0,0,65,67,32,69,79,66,32,109,97,114,107,101,114,32,105,115,32,97,98,115,101,110,116,32,112,111,115,61,37,100,10,0,85,110,107,110,111,119,110,32,111,98,106,101,99,116,32,99,111,100,105,110,103,32,37,100,10,0,0,0,0,0,0,0,70,114,97,109,101,32,115,105,122,101,58,32,37,100,120,37,100,59,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,115,44,32,102,114,97,109,101,114,97,116,101,58,32,37,100,47,37,100,10,0,0,99,50,95,115,101,101,100,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,32,97,117,100,105,111,0,0,0,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,65,112,112,108,121,32,97,32,108,105,98,109,112,99,111,100,101,99,115,32,102,105,108,116,101,114,32,116,111,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,68,80,67,77,32,105,100,32,82,111,81,0,0,0,0,0,112,105,120,101,108,32,102,111,114,109,97,116,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,68,78,120,72,68,10,0,0,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,0,115,108,111,119,101,114,0,0,69,114,114,111,114,32,105,110,32,100,105,114,97,99,95,100,101,99,111,100,101,95,100,97,116,97,95,117,110,105,116,10,0,0,0,0,0,0,0,0,68,97,116,117,109,95,78,71,79,95,49,57,52,56,0,0,115,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,116,111,32,116,114,121,32,116,111,32,103,117,101,115,115,32,116,104,101,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,85,110,107,110,111,119,110,32,99,104,114,111,109,97,32,102,111,114,109,97,116,32,37,100,10,0,0,0,0,0,0,0,118,105,115,117,97,108,105,122,101,32,98,108,111,99,107,32,116,121,112,101,115,0,0,0,100,97,116,0,0,0,0,0,73,103,110,111,114,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,116,121,112,101,32,37,100,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,118,99,49,105,109,97,103,101,0,0,0,0,0,0,0,0,115,101,116,32,66,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,10,0,0,0,67,114,101,97,116,105,118,101,32,89,85,86,32,40,67,89,85,86,41,0,0,0,0,0,101,114,114,111,114,32,100,117,114,105,110,103,32,108,122,111,32,100,101,99,111,109,112,114,101,115,115,105,111,110,10,0,85,110,115,117,112,112,111,114,116,101,100,32,115,117,98,115,97,109,112,108,101,33,10,0,116,115,95,114,97,116,101,95,100,101,99,105,109,97,116,111,114,32,102,97,99,116,111,114,115,32,97,114,101,32,110,111,116,32,112,111,119,101,114,115,32,111,102,32,50,0,0,0,77,101,109,111,114,121,32,100,101,97,108,108,111,99,97,116,101,100,46,10,0,0,0,0,71,101,116,116,105,110,103,32,104,101,108,112,58,10,32,32,32,32,45,104,32,32,32,32,32,32,45,45,32,112,114,105,110,116,32,98,97,115,105,99,32,111,112,116,105,111,110,115,10,32,32,32,32,45,104,32,108,111,110,103,32,45,45,32,112,114,105,110,116,32,109,111,114,101,32,111,112,116,105,111,110,115,10,32,32,32,32,45,104,32,102,117,108,108,32,45,45,32,112,114,105,110,116,32,97,108,108,32,111,112,116,105,111,110,115,32,40,105,110,99,108,117,100,105,110,103,32,97,108,108,32,102,111,114,109,97,116,32,97,110,100,32,99,111,100,101,99,32,115,112,101,99,105,102,105,99,32,111,112,116,105,111,110,115,44,32,118,101,114,121,32,108,111,110,103,41,10,32,32,32,32,83,101,101,32,109,97,110,32,37,115,32,102,111,114,32,100,101,116,97,105,108,101,100,32,100,101,115,99,114,105,112,116,105,111,110,32,111,102,32,116,104,101,32,111,112,116,105,111,110,115,46,10,10,0,0,0,0,0,0,99,113,95,108,101,118,101,108,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,48,46,46,54,51,93,0,0,0,115,101,116,32,108,101,118,101,108,115,32,109,111,100,101,0,115,101,116,32,97,108,112,104,97,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,72,50,54,52,0,0,0,0,10,10,32,32,83,97,109,112,108,101,32,112,101,97,107,58,10,32,32,32,32,80,101,97,107,58,32,32,32,32,32,32,37,53,46,49,102,32,100,66,70,83,0,0,0,0,0,0,112,99,95,110,0,0,0,0,79,112,101,110,67,76,58,32,37,115,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,113,117,105,114,101,100,32,105,109,97,103,101,32,102,111,114,109,97,116,115,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,103,114,97,121,49,54,98,101,0,0,0,0,0,0,0,0,67,111,114,97,108,0,0,0,32,10,9,0,0,0,0,0,115,116,0,0,0,0,0,0,80,114,111,116,111,99,111,108,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,84,70,67,0,0,0,0,0,105,104,0,0,0,0,0,0,101,114,114,111,114,32,100,105,102,102,117,115,105,111,110,32,100,105,116,104,101,114,0,0,100,105,115,99,97,114,100,105,110,103,32,37,100,32,97,117,100,105,111,32,115,97,109,112,108,101,115,10,0,0,0,0,77,80,69,71,45,50,32,118,105,100,101,111,0,0,0,0,79,110,108,121,32,109,111,110,111,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,115,101,116,32,115,101,97,114,99,104,32,115,116,114,97,116,101,103,121,0,0,0,0,0,104,97,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,73,78,70,79,32,99,104,117,110,107,46,10,0,0,0,100,105,116,104,101,114,95,116,121,112,101,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,110,99,111,100,101,100,95,98,117,102,95,115,105,122,101,32,48,0,0,0,0,0,0,80,108,97,121,82,101,115,88,0,0,0,0,0,0,0,0,69,110,99,111,100,105,110,103,32,37,100,32,97,110,100,32,98,112,112,32,37,100,0,0,98,117,102,102,101,114,32,116,111,111,32,98,105,103,32,102,111,114,32,100,101,99,111,100,101,114,10,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,83,69,65,68,0,0,100,105,102,102,101,114,101,110,116,32,98,102,114,97,109,101,115,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,0,0,117,110,101,120,112,101,99,116,101,100,32,115,116,97,114,116,32,99,111,100,101,32,48,120,37,48,50,120,10,0,0,0,111,102,102,0,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,116,121,112,101,32,37,120,32,97,116,32,37,100,120,37,100,10,0,0,0,0,111,102,102,0,0,0,0,0,69,110,104,97,110,99,101,100,32,99,111,117,112,108,105,110,103,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,117,110,107,32,116,121,112,101,32,37,100,10,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,116,111,111,32,109,97,110,121,32,81,77,70,32,115,117,98,98,97,110,100,115,58,32,37,100,10,0,0,0,73,110,118,97,108,105,100,32,80,114,101,100,105,99,116,111,114,32,82,101,115,101,116,32,71,114,111,117,112,46,10,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,32,97,117,100,105,111,0,0,112,97,99,107,101,116,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,10,0,0,37,102,47,37,102,32,0,0,97,98,117,102,102,101,114,0,98,97,100,32,109,97,103,105,99,32,110,117,109,98,101,114,10,0,0,0,0,0,0,0,77,111,114,101,32,116,104,97,110,32,37,100,32,99,104,97,110,110,101,108,115,0,0,0,115,108,111,119,0,0,0,0,68,97,116,117,109,95,78,101,119,95,90,101,97,108,97,110,100,95,71,101,111,100,101,116,105,99,95,68,97,116,117,109,95,49,57,52,57,0,0,0,33,118,108,99,45,62,116,97,98,108,101,95,115,105,122,101,0,0,0,0,0,0,0,0,69,120,116,114,97,32,98,105,116,115,32,67,82,67,32,101,114,114,111,114,10,0,0,0,118,105,115,95,109,98,95,116,121,112,101,0,0,0,0,0,101,88,116,101,110,100,101,100,32,66,73,78,97,114,121,32,116,101,120,116,0,0,0,0,105,110,118,97,108,105,100,32,113,105,32,37,100,32,62,32,54,51,10,0,0,0,0,0,118,115,117,98,0,0,0,0,66,105,110,107,32,65,117,100,105,111,32,40,68,67,84,41,0,0,0,0,0,0,0,0,114,101,115,95,115,101,116,117,112,45,62,99,108,97,115,115,98,111,111,107,0,0,0,0,112,114,111,102,105,108,101,32,37,115,44,32,108,101,118,101,108,32,37,115,10,0,0,0,32,37,100,46,37,46,50,100,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,98,108,111,99,107,32,105,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,32,73,109,97,103,101,0,0,0,0,0,73,110,112,117,116,32,114,101,115,111,108,117,116,105,111,110,32,108,97,114,103,101,114,32,116,104,97,110,32,97,99,116,117,97,108,32,102,114,97,109,101,46,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,98,108,117,101,32,103,97,105,110,32,102,111,114,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0,67,111,100,101,99,32,39,37,115,39,32,105,115,32,98,105,116,109,97,112,45,98,97,115,101,100,44,32,115,117,98,116,105,116,108,101,115,32,99,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,0,49,58,49,0,0,0,0,0,112,45,112,107,116,45,62,100,97,116,97,32,61,61,32,112,107,116,45,62,115,105,122,101,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,97,114,116,32,98,105,116,33,10,0,0,0,0,0,103,117,101,115,115,95,108,97,121,111,117,116,95,109,97,120,0,0,0,0,0,0,0,0,80,114,111,106,70,97,108,115,101,79,114,105,103,105,110,69,97,115,116,105,110,103,71,101,111,75,101,121,0,0,0,0,70,114,97,109,101,32,100,101,99,111,100,105,110,103,32,101,114,114,111,114,33,10,0,0,84,105,108,101,100,32,105,109,97,103,101,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,0,0,0,65,83,85,83,32,86,50,0,10,0,0,0,0,0,0,0,65,83,85,83,32,86,50,0,100,105,102,102,101,114,101,110,99,101,0,0,0,0,0,0,65,83,83,32,40,65,100,118,97,110,99,101,100,32,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,65,83,83,32,40,65,100,118,97,110,99,101,100,32,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,88,118,105,100,32,114,97,116,101,99,111,110,116,114,111,108,32,114,101,113,117,105,114,101,115,32,108,105,98,97,118,99,111,100,101,99,32,99,111,109,112,105,108,101,100,32,119,105,116,104,32,88,118,105,100,32,115,117,112,112,111,114,116,46,10,0,0,0,0,0,0,0,115,45,62,115,97,109,112,108,101,115,32,62,61,32,48,0,70,70,84,32,115,105,122,101,32,37,100,32,110,111,116,32,112,111,119,101,114,32,111,102,32,50,46,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,99,114,101,101,110,32,109,111,100,101,0,97,108,112,104,97,95,98,105,116,115,0,0,0,0,0,0,80,97,100,100,105,110,103,32,98,121,116,101,115,0,0,0,70,114,97,109,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,98,121,116,101,115,41,46,32,84,114,117,110,99,97,116,101,100,32,102,105,108,101,63,10,0,0,0,0,100,116,120,32,109,111,100,101,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,32,112,108,97,110,97,114,0,67,82,67,32,101,114,114,111,114,46,10,0,0,0,0,0,118,105,100,101,111,102,111,114,109,97,116,0,0,0,0,0,70,111,117,114,67,67,0,0,109,118,52,0,0,0,0,0,101,114,114,111,114,44,32,115,108,105,99,101,32,99,111,100,101,32,119,97,115,32,37,88,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,97,110,121,32,99,111,100,101,99,10,0,0,0,0,0,0,0,102,102,97,98,117,102,102,101,114,115,105,110,107,0,0,0,87,97,114,110,105,110,103,32,118,98,118,95,100,101,108,97,121,32,119,105,108,108,32,98,101,32,115,101,116,32,116,111,32,48,120,70,70,70,70,32,40,61,86,66,82,41,32,97,115,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,118,98,118,32,98,117,102,102,101,114,32,105,115,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,116,104,101,32,103,105,118,101,110,32,98,105,116,114,97,116,101,33,10,0,68,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,82,84,67,84,73,77,69,0,71,114,111,117,112,32,111,102,32,86,79,80,32,115,116,97,114,116,0,0,0,0,0,0,100,97,116,101,0,0,0,0,108,117,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,73,82,32,102,105,108,116,101,114,32,104,97,115,32,115,116,97,116,101,32,100,97,116,97,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,99,111,109,112,111,110,101,110,116,58,32,37,100,10,0,0,116,114,97,99,107,0,0,0,116,105,116,108,101,0,0,0,118,97,114,105,97,110,99,101,0,0,0,0,0,0,0,0,86,80,56,69,95,83,69,84,95,83,84,65,84,73,67,95,84,72,82,69,83,72,79,76,68,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,102,111,114,32,90,76,73,66,58,32,40,37,100,41,46,10,0,0,101,120,116,114,97,32,99,98,108,107,32,115,116,121,108,101,115,32,37,88,10,0,0,0,92,105,0,0,0,0,0,0,73,110,100,101,112,101,110,100,101,110,116,32,83,101,103,109,101,110,116,32,68,101,99,111,100,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,67,111,109,109,97,110,100,32,119,97,115,32,112,97,114,115,101,100,32,97,115,58,32,102,108,97,103,115,58,91,37,115,93,32,116,97,114,103,101,116,58,37,115,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,10,0,0,109,97,120,32,116,114,97,110,115,102,111,114,109,32,98,108,111,99,107,32,115,105,122,101,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,90,101,114,111,32,114,101,102,115,32,102,111,114,32,97,32,102,114,97,109,101,32,119,105,116,104,32,80,32,111,114,32,66,32,115,108,105,99,101,115,46,10,0,0,0,0,0,0,67,79,78,83,84,82,0,0,80,73,67,84,95,84,89,80,69,95,66,73,0,0,0,0,68,97,110,99,101,0,0,0,72,105,103,104,32,49,48,0,108,101,110,32,60,32,115,105,122,101,111,102,40,109,105,109,101,116,121,112,101,41,0,0,32,98,108,111,99,107,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,0,115,45,62,109,97,120,95,98,108,111,99,107,115,105,122,101,0,0,0,0,0,0,0,0,80,114,111,116,101,99,116,32,115,108,105,99,101,115,32,119,105,116,104,32,67,82,67,115,0,0,0,0,0,0,0,0,108,105,110,101,79,114,100,101,114,0,0,0,0,0,0,0,97,108,98,117,109,0,0,0,108,116,114,116,0,0,0,0,110,83,89,78,67,65,85,88,32,109,105,115,109,97,116,99,104,32,37,35,120,10,0,0,115,117,98,112,97,99,107,101,116,32,37,105,32,74,111,105,110,116,45,115,116,101,114,101,111,32,86,76,67,32,117,115,101,100,46,10,0,0,0,0,102,111,114,99,101,32,102,114,97,109,101,32,108,111,103,103,105,110,103,32,108,101,118,101,108,0,0,0,0,0,0,0,97,105,102,44,97,105,102,102,44,97,102,99,44,97,105,102,99,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,102,114,97,109,101,95,114,97,116,101,0,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,50,0,0,0,0,0,0,0,97,97,99,44,97,100,116,115,0,0,0,0,0,0,0,0,109,101,100,105,117,109,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,112,105,120,101,108,95,102,109,116,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,0,0,0,0,0,114,97,119,32,69,45,65,67,45,51,0,0,0,0,0,0,68,97,116,117,109,95,78,97,112,97,114,105,109,97,95,49,57,55,50,0,0,0,0,0,115,116,100,32,84,65,71,32,116,114,117,110,99,97,116,101,100,10,0,0,0,0,0,0,118,105,115,117,97,108,105,122,101,32,113,117,97,110,116,105,122,97,116,105,111,110,32,112,97,114,97,109,101,116,101,114,32,40,81,80,41,44,32,108,111,119,101,114,32,81,80,32,97,114,101,32,116,105,110,116,101,100,32,103,114,101,101,110,101,114,0,0,0,0,0,0,84,114,97,110,99,101,0,0,97,117,116,111,45,105,110,115,101,114,116,101,100,32,102,105,102,111,32,37,100,0,0,0,119,109,118,51,105,109,97,103,101,0,0,0,0,0,0,0,89,85,86,52,77,80,69,71,32,115,116,114,101,97,109,32,99,111,110,116,97,105,110,115,32,97,110,32,117,110,107,110,111,119,110,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,109,101,116,97,100,97,116,97,32,101,110,116,114,121,59,32,107,101,121,58,37,115,44,32,116,121,112,101,58,37,100,44,32,108,101,110,103,116,104,58,48,120,37,120,10,0,0,0,0,0,0,0,70,82,65,77,69,0,0,0,114,102,54,52,0,0,0,0,99,111,100,105,110,103,95,104,105,115,116,111,114,121,0,0,78,65,77,69,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,40,37,100,32,98,121,116,101,115,41,0,120,109,118,45,62,118,105,100,101,111,46,115,116,114,101,97,109,95,105,110,100,101,120,32,60,32,115,45,62,110,98,95,115,116,114,101,97,109,115,0,73,110,118,97,108,105,100,32,87,97,118,80,97,99,107,32,112,97,99,107,101,116,46,10,0,0,0,0,0,0,0,0,84,104,105,115,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,46,32,85,115,101,32,39,124,39,32,116,111,32,115,101,112,97,114,97,116,101,32,116,104,101,32,108,105,115,116,32,105,116,101,109,115,46,10,0,105,110,116,101,114,114,117,112,116,101,100,10,0,0,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,32,104,101,97,100,101,114,46,10,0,0,124,0,0,0,0,0,0,0,117,110,107,110,111,119,110,0,87,77,47,80,105,99,116,117,114,101,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,115,101,116,32,97,117,100,105,111,32,102,105,108,116,101,114,115,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,112,115,58,32,37,100,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,100,101,99,58,32,37,100,0,0,0,0,0,0,0,118,116,116,0,0,0,0,0,239,187,191,87,69,66,86,84,84,0,0,0,0,0,0,0,32,32,105,110,103,108,105,115,104,58,32,37,115,10,0,0,119,54,52,0,0,0,0,0,83,111,110,121,32,87,97,118,101,54,52,0,0,0,0,0,67,111,100,101,99,80,114,105,118,97,116,101,68,97,116,97,0,0,0,0,0,0,0,0,77,97,108,102,111,114,109,101,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,116,114,97,99,107,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,10,0,0,0,0,0,0,67,114,101,97,116,105,118,101,32,86,111,105,99,101,0,0,117,110,107,110,111,119,110,32,112,97,99,107,101,116,32,116,121,112,101,32,37,100,10,0,79,110,108,121,32,87,77,86,51,32,105,115,32,97,99,99,101,112,116,101,100,33,10,0,73,68,51,0,0,0,0,0,58,47,47,0,0,0,0,0,44,32,37,115,0,0,0,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,105,100,32,37,105,10,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,110,111,110,115,101,110,115,101,32,115,97,109,112,108,101,114,97,116,101,10,0,0,0,0,105,110,118,97,108,105,100,32,97,117,100,105,111,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,0,0,0,0,77,97,120,105,109,117,109,32,37,100,32,115,108,97,118,101,32,109,117,120,101,114,115,32,114,101,97,99,104,101,100,46,10,0,0,0,0,0,0,0,99,97,112,116,105,111,110,115,0,0,0,0,0,0,0,0,77,68,53,32,109,101,116,97,100,97,116,97,32,98,108,111,99,107,32,67,82,67,32,101,114,114,111,114,46,10,0,0,97,118,109,50,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,109,97,112,32,102,111,114,109,97,116,32,37,100,44,32,115,107,105,112,112,101,100,10,0,0,0,0,0,0,102,97,115,116,0,0,0,0,68,97,116,117,109,95,78,97,104,114,119,97,110,95,49,57,54,55,0,0,0,0,0,0,13,10,0,0,0,0,0,0,91,68,69,76,65,89,93,0,118,105,115,95,113,112,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,116,105,109,101,115,116,97,109,112,115,32,105,110,32,101,118,101,110,116,32,110,117,109,98,101,114,32,37,100,46,10,0,0,0,0,13,10,0,0,0,0,0,0,63,0,0,0,0,0,0,0,67,104,114,111,110,111,109,97,115,116,101,114,32,68,70,65,0,0,0,0,0,0,0,0,116,121,112,101,61,37,120,32,108,101,110,61,37,105,32,112,107,116,95,111,102,102,115,101,116,61,37,105,10,0,0,0,73,69,67,32,54,49,57,51,55,32,40,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,32,105,110,32,83,47,80,68,73,70,41,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,102,41,10,0,0,0,0,0,0,0,37,115,47,116,101,109,112,0,0,10,83,77,74,80,69,71,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,37,120,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,97,117,100,105,111,32,112,97,114,116,32,115,105,122,101,10,0,0,0,0,0,0,0,0,97,102,0,0,0,0,0,0,82,101,97,100,105,110,103,32,111,112,116,105,111,110,32,39,37,115,39,32,46,46,46,0,101,120,116,101,110,100,101,100,32,102,111,114,109,97,116,0,118,49,46,51,46,48,0,0,97,61,114,116,112,109,97,112,58,37,100,32,77,80,52,65,45,76,65,84,77,47,37,100,47,37,100,13,10,97,61,102,109,116,112,58,37,100,32,112,114,111,102,105,108,101,45,108,101,118,101,108,45,105,100,61,37,100,59,99,112,114,101,115,101,110,116,61,48,59,99,111,110,102,105,103,61,37,115,13,10,0,0,0,0,0,0,0,116,114,97,99,107,73,68,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,84,0,0,0,0,0,0,67,78,65,77,69,32,116,111,32,105,110,99,108,117,100,101,32,105,110,32,82,84,67,80,32,83,82,32,112,97,99,107,101,116,115,0,0,0,0,0,115,97,116,117,114,97,116,105,111,110,0,0,0,0,0,0,118,105,100,101,111,47,120,45,104,50,54,49,0,0,0,0,102,97,115,116,101,114,0,0,117,50,52,108,101,0,0,0,68,97,116,117,109,95,78,111,114,116,104,95,65,109,101,114,105,99,97,110,95,68,97,116,117,109,95,49,57,56,51,0,98,117,103,115,0,0,0,0,100,102,97,0,0,0,0,0,117,50,52,108,101,0,0,0,100,101,102,97,117,108,116,0,108,97,121,111,117,116,0,0,114,101,100,117,99,101,32,116,104,101,32,108,97,116,101,110,99,121,32,105,110,116,114,111], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2361504);
/* memory initializer */ allocate([100,117,99,101,100,32,98,121,32,111,112,116,105,111,110,97,108,32,98,117,102,102,101,114,105,110,103,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,115,121,115,116,101,109,66,105,116,114,97,116,101,0,0,0,110,117,116,45,62,102,114,97,109,101,95,99,111,100,101,91,39,78,39,93,46,102,108,97,103,115,32,61,61,32,70,76,65,71,95,73,78,86,65,76,73,68,0,0,0,0,0,0,76,97,115,116,32,102,114,97,109,101,32,109,117,115,116,32,104,97,118,101,32,98,101,101,110,32,100,97,109,97,103,101,100,32,37,108,108,100,32,62,32,37,108,108,100,32,43,32,37,100,10,0,0,0,0,0,120,32,62,61,32,110,98,95,112,116,115,101,115,32,45,32,73,110,100,101,120,69,110,116,114,121,67,111,117,110,116,32,37,105,32,60,32,73,110,100,101,120,68,117,114,97,116,105,111,110,32,37,108,108,100,63,10,0,0,0,0,0,0,0,65,85,68,73,79,95,70,79,82,77,65,84,0,0,0,0,87,101,98,77,32,80,114,111,106,101,99,116,32,86,80,57,32,68,101,99,111,100,101,114,32,118,49,46,51,46,48,0,109,50,116,115,0,0,0,0,70,111,117,110,100,32,116,97,103,32,37,120,32,101,120,112,101,99,116,101,100,32,37,120,10,0,0,0,0,0,0,0,118,101,114,121,102,97,115,116,0,0,0,0,0,0,0,0,68,97,116,117,109,95,78,65,68,95,77,105,99,104,105,103,97,110,0,0,0,0,0,0,70,105,114,115,116,32,83,67,82,58,32,37,108,108,100,32,70,105,114,115,116,32,68,84,83,58,32,37,108,108,100,10,0,0,0,0,0,0,0,0,109,101,109,111,114,121,32,109,97,110,97,103,101,109,101,110,116,32,99,111,110,116,114,111,108,32,111,112,101,114,97,116,105,111,110,115,32,40,72,46,50,54,52,41,0,0,0,0,100,101,108,97,121,58,0,0,66,105,116,109,97,112,32,66,114,111,116,104,101,114,115,32,74,86,32,118,105,100,101,111,0,0,0,0,0,0,0,0,73,68,51,0,0,0,0,0,108,117,116,0,0,0,0,0,115,101,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,0,0,0,0,0,0,60,37,115,32,115,121,115,116,101,109,66,105,116,114,97,116,101,61,34,37,100,34,62,10,0,0,0,0,0,0,0,0,70,52,86,32,65,100,111,98,101,32,70,108,97,115,104,32,86,105,100,101,111,0,0,0,100,97,116,101,0,0,0,0,117,110,100,0,0,0,0,0,116,105,116,108,101,0,0,0,115,117,112,101,114,102,97,115,116,0,0,0,0,0,0,0,68,97,116,117,109,95,78,111,114,116,104,95,65,109,101,114,105,99,97,110,95,68,97,116,117,109,95,49,57,50,55,0,67,111,117,108,100,32,110,111,116,32,111,112,101,110,32,102,105,108,101,32,58,32,37,115,10,0,0,0,0,0,0,0,109,109,99,111,0,0,0,0,114,97,115,0,0,0,0,0,106,118,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,84,68,82,67,0,0,0,0,35,69,88,84,45,88,45,69,78,68,76,73,83,84,0,0,119,105,110,100,111,119,95,115,105,122,101,0,0,0,0,0,97,117,100,105,111,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,116,105,109,101,115,0,0,0,78,111,110,45,109,111,110,111,116,111,110,111,117,115,32,68,84,83,32,105,110,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,59,32,112,114,101,118,105,111,117,115,58,32,37,108,108,100,44,32,99,117,114,114,101,110,116,58,32,37,108,108,100,59,32,0,0,0,0,0,0,117,108,116,114,97,102,97,115,116,0,0,0,0,0,0,0,68,97,116,117,109,95,77,95,112,111,114,97,108,111,107,111,0,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,99,111,103,110,105,116,105,111,110,0,0,0,0,0,0,0,65,112,112,108,101,32,80,114,111,82,101,115,32,40,105,67,111,100,101,99,32,80,114,111,41,0,0,0,0,0,0,0,107,101,114,110,100,101,105,110,116,0,0,0,0,0,0,0,115,101,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,115,116,114,110,0,0,0,0,80,111,116,69,110,99,111,100,101,114,0,0,0,0,0,0,68,82,77,32,112,114,111,116,101,99,116,101,100,32,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,44,32,100,101,99,111,100,105,110,103,32,119,105,108,108,32,108,105,107,101,108,121,32,102,97,105,108,33,10,0,0,0,0,0,0,118,105,100,101,111,0,0,0,115,112,101,99,105,102,121,32,119,104,101,110,32,116,111,32,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,32,37,100,0,0,0,0,0,78,111,32,99,104,97,110,110,101,108,115,32,97,114,101,32,117,115,101,100,32,102,114,111,109,32,105,110,112,117,116,32,115,116,114,101,97,109,32,37,100,46,10,0,0,0,0,0,111,110,108,121,32,49,32,112,115,121,32,116,117,110,105,110,103,32,99,97,110,32,98,101,32,117,115,101,100,58,32,105,103,110,111,114,105,110,103,32,116,117,110,101,32,37,115,10,0,0,0,0,0,0,0,0,68,97,116,117,109,95,77,111,110,116,101,95,77,97,114,105,111,0,0,0,0,0,0,0,101,114,0,0,0,0,0,0,104,0,0,0,0,0,0,0,112,114,111,114,101,115,0,0,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,0,60,115,119,105,116,99,104,62,10,0,0,0,0,0,0,0,104,115,105,110,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,58,37,100,32,99,104,108,97,121,111,117,116,58,37,115,32,100,117,114,97,116,105,111,110,58,37,108,108,100,10,0,0,0,0,0,0,0,115,97,114,0,0,0,0,0,98,115,108,32,62,61,32,48,0,0,0,0,0,0,0,0,111,117,116,101,114,0,0,0,116,114,105,109,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,115,101,101,100,0,0,0,0,115,99,114,111,108,108,32,112,97,116,116,101,114,110,32,100,111,119,110,119,97,114,100,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,121,97,100,105,102,46,99,0,0,102,114,97,109,101,0,0,0,101,102,102,101,99,116,58,37,115,32,116,121,112,101,58,37,115,32,109,115,105,122,101,95,120,58,37,100,32,109,115,105,122,101,95,121,58,37,100,32,97,109,111,117,110,116,58,37,48,46,50,102,10,0,0,0,105,110,118,97,108,105,100,32,116,117,110,101,32,39,37,115,39,10,0,0,0,0,0,0,68,97,116,117,109,95,77,104,97,115,116,0,0,0,0,0,112,116,115,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,116,105,110,116,101,114,108,97,99,101,46,99,0,0,0,0,0,76,97,103,97,114,105,116,104,32,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,104,101,108,112,0,0,0,0,118,111,108,117,109,101,0,0,97,103,109,103,0,0,0,0,115,101,116,32,105,110,112,117,116,32,99,111,108,111,114,32,114,97,110,103,101,0,0,0,60,98,111,100,121,62,10,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,114,32,101,118,97,108,117,97,116,105,110,103,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,111,112,116,105,111,110,32,37,115,58,32,105,110,118,97,108,105,100,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,111,114,32,110,111,110,45,112,111,115,105,116,105,118,101,32,111,114,32,105,110,100,101,102,105,110,105,116,101,32,118,97,108,117,101,32,37,102,10,0,0,0,115,97,114,0,0,0,0,0,101,110,100,97,108,108,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,108,97,103,32,98,117,102,102,101,114,115,0,0,99,49,102,0,0,0,0,0,105,110,116,101,114,108,97,99,101,0,0,0,0,0,0,0,109,112,0,0,0,0,0,0,116,111,117,104,111,117,0,0,68,97,116,117,109,95,77,105,110,110,97,0,0,0,0,0,115,116,97,114,116,99,111,100,101,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,103,117,101,115,115,32,116,104,101,32,102,111,114,109,97,116,32,102,114,111,109,32,116,104,101,32,101,120,116,101,110,115,105,111,110,10,0,0,108,97,103,97,114,105,116,104,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,116,115,95,114,97,116,101,95,100,101,99,105,109,97,116,111,114,91,99,102,103,45,62,116,115,95,110,117,109,98,101,114,95,108,97,121,101,114,115,32,45,32,49,93,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,49,93,0,0,0,0,0,0,0,0,99,104,97,110,103,101,32,97,117,100,105,111,32,118,111,108,117,109,101,32,40,50,53,54,61,110,111,114,109,97,108,41,0,0,0,0,0,0,0,0,97,114,110,114,95,116,121,112,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,51,93,0,0,0,108,101,118,101,108,115,95,109,111,100,101,0,0,0,0,0,97,108,112,104,97,95,101,120,112,114,0,0,0,0,0,0,101,110,99,111,100,101,114,47,99,97,98,97,99,46,99,0,60,47,104,101,97,100,62,10,0,0,0,0,0,0,0,0,50,45,119,97,121,32,109,97,116,99,104,32,40,112,47,99,41,0,0,0,0,0,0,0,79,112,101,110,67,76,58,32,109,97,108,108,111,99,32,111,102,32,105,110,115,116,97,108,108,101,100,32,112,108,97,116,102,111,114,109,115,32,98,117,102,102,101,114,32,102,97,105,108,101,100,10,0,0,0,0,100,101,102,97,117,108,116,0,98,103,114,97,0,0,0,0,67,104,111,99,111,108,97,116,101,0,0,0,0,0,0,0,69,114,114,111,114,32,115,101,116,116,105,110,103,32,111,112,116,105,111,110,32,37,115,32,116,111,32,118,97,108,117,101,32,37,115,46,10,0,0,0,105,115,105,110,102,0,0,0,80,82,79,84,79,67,79,76,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,116,111,112,32,102,114,111,110,116,32,108,101,102,116,0,0,105,110,95,104,0,0,0,0,101,114,114,111,114,95,100,105,102,102,117,115,105,111,110,0,67,111,110,116,101,120,116,32,104,97,115,32,110,111,116,32,98,101,101,110,32,105,110,105,116,105,97,108,105,122,101,100,10,0,0,0,0,0,0,0,120,49,118,100,101,98,108,111,99,107,0,0,0,0,0,0,115,101,97,114,99,104,0,0,67,111,108,108,105,115,105,111,110,115,0,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,101,97,95,115,101,97,100,0,0,0,0,0,0,0,98,102,114,97,109,101,115,61,37,100,0,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,99,111,117,112,108,105,110,103,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,109,111,110,111,32,111,114,32,100,117,97,108,45,109,111,110,111,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,97,99,115,98,114,46,99,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,115,99,97,108,101,102,97,99,116,111,114,32,98,97,110,100,115,32,105,110,32,103,114,111,117,112,32,40,37,100,41,32,101,120,99,101,101,100,115,32,108,105,109,105,116,32,40,37,100,41,46,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,48,47,48,46,50,50,32,48,46,52,57,47,48,46,52,52,32,49,47,48,46,56,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,100,10,0,0,122,101,114,111,108,97,116,101,110,99,121,0,0,0,0,0,68,97,116,117,109,95,77,97,115,115,97,119,97,0,0,0,67,82,67,32,101,114,114,111,114,10,0,0,0,0,0,0,115,107,105,112,0,0,0,0,105,110,118,97,108,105,100,32,98,97,115,101,32,109,97,116,114,105,120,32,105,110,100,101,120,10,0,0,0,0,0,0,104,115,117,98,0,0,0,0,112,97,114,116,105,116,105,111,110,32,111,117,116,32,111,102,32,98,111,117,110,100,115,58,32,116,121,112,101,44,32,98,101,103,105,110,44,32,101,110,100,44,32,115,105,122,101,44,32,98,108,111,99,107,115,105,122,101,58,32,37,117,44,32,37,117,44,32,37,117,44,32,37,117,44,32,37,117,10,0,49,98,0,0,0,0,0,0,69,102,102,101,99,116,58,32,37,100,59,32,112,97,114,97,109,115,58,32,0,0,0,0,77,111,98,111,116,105,120,32,77,120,80,69,71,32,118,105,100,101,111,0,0,0,0,0,97,98,0,0,0,0,0,0,67,104,97,114,97,99,116,101,114,32,101,110,99,111,100,105,110,103,32,105,115,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,115,117,98,116,105,116,108,101,115,32,99,111,100,101,99,115,10,0,0,0,0,0,119,0,0,0,0,0,0,0,118,111,108,0,0,0,0,0,80,114,111,106,70,97,108,115,101,79,114,105,103,105,110,76,97,116,71,101,111,75,101,121,0,0,0,0,0,0,0,0,84,97,103,32,114,101,102,101,114,101,110,99,105,110,103,32,112,111,115,105,116,105,111,110,32,111,117,116,115,105,100,101,32,116,104,101,32,105,109,97,103,101,10,0,0,0,0,0,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,32,45,45,62,32,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,37,42,91,32,93,88,49,58,37,117,32,88,50,58,37,117,32,89,49,58,37,117,32,89,50,58,37,117,0,0,0,0,0,0,0,100,97,114,107,101,110,0,0,118,101,114,58,37,88,32,118,101,114,48,58,37,88,10,0,115,116,97,116,105,115,116,105,99,115,32,97,114,101,32,100,97,109,97,103,101,100,32,97,116,32,108,105,110,101,32,37,100,44,32,112,97,114,115,101,114,32,111,117,116,61,37,100,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,70,70,84,32,111,114,100,101,114,32,40,37,100,41,44,32,99,111,110,116,97,99,116,32,116,104,101,32,100,101,118,101,108,111,112,101,114,115,33,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,112,99,109,95,115,56,95,112,108,97,110,97,114,0,0,0,111,118,101,114,115,99,97,110,0,0,0,0,0,0,0,0,60,109,101,116,97,32,110,97,109,101,61,34,99,114,101,97,116,111,114,34,32,99,111,110,116,101,110,116,61,34,37,115,34,32,47,62,10,0,0,0,97,108,108,111,119,32,100,101,99,111,100,101,114,115,32,116,111,32,112,114,111,100,117,99,101,32,117,110,97,108,105,103,110,101,100,32,111,117,116,112,117,116,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,108,105,99,101,32,104,101,105,103,104,116,32,37,100,10,0,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,44,32,103,117,101,115,115,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,105,115,32,39,37,115,39,10,0,0,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,37,100,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,98,105,116,114,97,116,101,32,37,100,10,0,0,100,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,32,110,117,109,98,101,114,46,10,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,110,102,105,103,32,110,117,109,98,101,114,46,10,0,84,66,0,0,0,0,0,0,85,115,101,114,32,68,97,116,97,0,0,0,0,0,0,0,117,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,67,66,80,0,0,0,0,0,0,0,0,99,117,114,114,101,110,116,95,112,105,99,116,117,114,101,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,100,10,0,0,0,0,0,0,0,0,83,117,109,32,111,102,32,99,111,101,102,102,95,98,105,116,115,32,97,110,100,32,99,111,101,102,102,95,115,104,105,102,116,32,102,111,114,32,37,99,73,82,32,102,105,108,116,101,114,32,109,117,115,116,32,98,101,32,49,54,32,111,114,32,108,101,115,115,46,10,0,0,100,101,99,111,100,101,95,115,111,115,58,32,105,110,118,97,108,105,100,32,108,101,110,32,40,37,100,41,10,0,0,0,110,111,110,101,0,0,0,0,78,111,114,109,97,108,32,99,111,109,112,114,101,115,115,105,111,110,46,10,0,0,0,0,99,98,108,107,32,115,105,122,101,32,62,32,54,52,0,0,123,92,105,49,125,0,0,0,82,101,102,101,114,101,110,99,101,32,80,105,99,116,117,114,101,32,83,101,108,101,99,116,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,77,105,115,115,105,110,103,32,115,101,112,97,114,97,116,111,114,32,111,114,32,101,120,116,114,97,110,101,111,117,115,32,100,97,116,97,32,102,111,117,110,100,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,105,110,116,101,114,118,97,108,32,35,37,100,44,32,105,110,32,99,111,109,109,97,110,100,32,35,37,100,10,0,0,109,97,120,95,116,114,97,110,115,102,111,114,109,95,104,105,101,114,97,114,99,104,121,95,100,101,112,116,104,95,105,110,116,114,97,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,84,111,111,32,109,97,110,121,32,114,101,102,115,58,32,37,100,47,37,100,46,10,0,0,105,110,100,101,120,32,60,32,100,101,102,95,108,101,110,0,76,80,65,82,0,0,0,0,80,73,67,84,95,84,89,80,69,95,83,80,0,0,0,0,72,105,103,104,0,0,0,0,32,112,97,114,116,105,116,105,111,110,32,111,114,100,101,114,58,32,37,100,44,32,37,100,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,108,105,99,101,99,114,99,0,0,0,0,0,0,0,0,100,105,115,112,108,97,121,87,105,110,100,111,119,0,0,0,80,114,101,102,101,114,114,101,100,32,83,116,101,114,101,111,32,68,111,119,110,109,105,120,32,77,111,100,101,0,0,0,99,104,101,99,107,32,102,97,105,108,101,100,58,32,37,105,62,37,105,0,0,0,0,0,115,113,118,104,32,86,76,67,32,105,110,105,116,10,0,0,102,114,97,109,101,108,111,103,0,0,0,0,0,0,0,0,112,105,120,101,108,95,97,115,112,101,99,116,0,0,0,0,109,115,109,112,101,103,52,118,50,0,0,0,0,0,0,0,102,97,115,116,100,101,99,111,100,101,0,0,0,0,0,0,67,111,110,102,108,105,99,116,105,110,103,32,97,108,108,95,99,104,97,110,110,101,108,95,99,111,117,110,116,115,32,97,110,100,32,108,105,115,116,32,105,110,32,111,112,116,105,111,110,115,10,0,0,0,0,0,68,97,116,117,109,95,77,101,114,99,104,105,99,104,0,0,100,99,116,95,99,111,101,102,102,0,0,0,0,0,0,0,70,117,115,105,111,110,0,0,115,101,114,118,105,99,101,95,110,97,109,101,0,0,0,0,97,102,105,102,111,0,0,0,109,120,112,101,103,0,0,0,109,111,110,111,0,0,0,0,87,77,47,80,105,99,116,117,114,101,0,0,0,0,0,0,87,114,105,116,101,32,66,69,88,84,32,99,104,117,110,107,46,0,0,0,0,0,0,0,117,109,105,100,0,0,0,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,99,111,100,101,99,32,105,110,32,97,118,95,102,105,110,100,95,115,116,114,101,97,109,95,105,110,102,111,10,0,0,0,0,97,101,118,97,108,115,114,99,0,0,0,0,0,0,0,0,91,0,0,0,0,0,0,0,87,86,67,49,0,0,0,0,102,111,114,99,101,32,97,117,100,105,111,32,116,97,103,47,102,111,117,114,99,99,0,0,60,104,101,97,100,62,10,0,115,116,105,108,108,105,109,97,103,101,0,0,0,0,0,0,68,97,116,117,109,95,77,97,110,111,99,97,0,0,0,0,87,101,98,77,32,80,114,111,106,101,99,116,32,86,80,57,32,69,110,99,111,100,101,114,32,118,49,46,51,46,48,0,109,111,116,105,111,110,32,118,101,99,116,111,114,0,0,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,116,105,111,110,32,86,105,100,101,111,32,67,111,109,112,114,101,115,115,111,114,32,50,0,0,0,0,0,0,105,108,0,0,0,0,0,0,97,116,97,103,0,0,0,0,83,112,108,105,116,116,105,110,103,32,116,104,101,32,99,111,109,109,97,110,100,108,105,110,101,46,10,0,0,0,0,0,69,120,112,101,99,116,101,100,32,105,110,116,32,102,111,114,32,37,115,32,98,117,116,32,102,111,117,110,100,32,37,115,10,0,0,0,0,0,0,0,118,98,44,115,111,110,0,0,101,120,116,0,0,0,0,0,32,100,105,115,112,97,116,99,104,105,110,103,32,37,115,32,102,114,97,109,101,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,97,110,100,32,112,116,115,32,37,108,108,100,10,0,0,0,0,0,0,0,108,97,116,109,0,0,0,0,60,115,109,105,108,32,120,109,108,110,115,61,34,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,83,77,73,76,50,48,47,76,97,110,103,117,97,103,101,34,62,10,0,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,76,0,0,0,0,0,0,99,110,97,109,101,0,0,0,108,105,110,101,97,114,0,0,114,97,119,32,72,46,50,54,49,0,0,0,0,0,0,0,103,114,97,105,110,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,68,97,116,117,109,95,77,97,108,111,110,103,111,95,49,57,56,55,0,0,0,0,0,0,109,118,0,0,0,0,0,0,109,118,99,50,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,87,101,98,77,32,80,114,111,106,101,99,116,32,86,80,56,32,68,101,99,111,100,101,114,32,118,49,46,51,46,48,0,102,111,114,99,101,32,97,117,100,105,111,32,99,111,100,101,99,32,40,39,99,111,112,121,39,32,116,111,32,99,111,112,121,32,115,116,114,101,97,109,41,0,0,0,0,0,0,0,115,101,116,32,122,111,111,109,32,102,97,99,116,111,114,0,110,111,98,117,102,102,101,114,0,0,0,0,0,0,0,0,115,105,122,101,0,0,0,0,102,102,109,112,101,103,0,0,60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,110,99,111,100,105,110,103,61,34,117,116,102,45,56,34,63,62,10,0,83,107,105,112,69,110,100,0,115,116,114,101,97,109,105,110,103,32,115,101,103,109,101,110,116,32,109,117,120,101,114,0,114,97,119,32,118,105,100,101,111,32,105,115,32,117,115,105,110,103,32,117,110,104,97,110,100,108,101,100,32,37,100,98,112,112,10,0,0,0,0,0,85,110,107,110,111,119,110,32,105,110,116,101,103,101,114,32,37,115,10,0,0,0,0,0,110,111,32,115,116,114,101,97,109,115,63,10,0,0,0,0,37,100,0,0,0,0,0,0,112,99,114,32,101,118,101,114,121,32,37,100,32,112,107,116,115,44,32,115,100,116,32,101,118,101,114,121,32,37,100,44,32,112,97,116,47,112,109,116,32,101,118,101,114,121,32,37,100,32,112,107,116,115,10,0,77,97,120,105,109,117,109,32,77,80,52,32,100,101,115,99,114,105,112,116,111,114,32,108,101,118,101,108,32,101,120,99,101,101,100,101,100,10,0,0,97,110,105,109,97,116,105,111,110,0,0,0,0,0,0,0,68,97,116,117,109,95,69,117,114,111,112,101,97,110,95,82,101,102,101,114,101,110,99,101,95,83,121,115,116,101,109,95,49,57,56,57,0,0,0,0,98,117,102,102,101,114,32,117,110,100,101,114,102,108,111,119,32,115,116,61,37,100,32,98,117,102,105,61,37,100,32,115,105,122,101,61,37,100,10,0,112,101,114,45,98,108,111,99,107,32,113,117,97,110,116,105,122,97,116,105,111,110,32,112,97,114,97,109,101,116,101,114,32,40,81,80,41,0,0,0,73,68,88,32,115,116,114,101,97,109,91,37,100,93,32,110,97,109,101,61,37,115,10,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,116,105,111,110,32,86,105,100,101,111,32,67,111,109,112,114,101,115,115,111,114,32,49,0,0,0,0,0,0,65,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,115,32,119,101,114,101,32,114,101,113,117,101,115,116,101,100,44,32,98,117,116,32,116,104,101,32,73,68,51,118,50,32,104,101,97,100,101,114,32,105,115,32,100,105,115,97,98,108,101,100,46,10,0,0,0,0,97,99,111,100,101,99,0,0,116,101,120,116,0,0,0,0,105,100,101,116,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,102,52,118,0,0,0,0,0,97,108,98,117,109,0,0,0,116,105,116,108,101,0,0,0,77,105,120,32,102,101,97,116,117,114,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,58,32,45,109,32,105,115,32,105,103,110,111,114,101,100,32,97,110,100,32,109,105,120,32,99,104,97,110,110,101,108,115,32,119,105,108,108,32,98,101,32,115,105,108,101,110,116,46,10,0,0,0,0,85,110,107,110,111,119,110,32,69,66,77,76,32,100,111,99,116,121,112,101,32,39,37,115,39,10,0,0,0,0,0,0,97,114,116,105,115,116,0,0,115,109,105,44,115,97,109,105,0,0,0,0,0,0,0,0,44,46,47,45,43,0,0,0,68,97,116,117,109,95,77,97,107,97,115,115,97,114,0,0,115,101,116,32,102,114,97,109,101,32,116,105,109,101,115,116,97,109,112,32,102,114,111,109,32,102,105,108,101,39,115,32,111,110,101,0,0,0,0,0,113,112,0,0,0,0,0,0,115,117,110,0,0,0,0,0,109,118,99,49,0,0,0,0,84,111,111,32,115,104,111,114,116,32,74,80,69,71,32,104,101,97,100,101,114,46,32,65,98,111,114,116,101,100,33,10,0,0,0,0,0,0,0,0,78,65,76,32,115,105,122,101,32,37,100,32,62,32,37,100,10,0,0,0,0,0,0,0,100,105,115,97,98,108,101,32,97,117,100,105,111,0,0,0,100,97,116,101,0,0,0,0,35,69,88,84,45,88,45,77,69,68,73,65,45,83,69,81,85,69,78,67,69,58,0,0,72,68,83,32,109,117,120,101,114,0,0,0,0,0,0,0,116,114,97,99,107,32,37,100,58,32,109,117,120,105,110,103,32,109,112,51,32,97,116,32,37,100,104,122,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,111,110,77,101,116,97,68,97,116,97,0,0,0,0,0,0,83,107,105,112,105,110,103,32,100,117,112,108,105,99,97,116,101,32,105,110,100,101,120,10,0,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,115,105,100,101,32,100,97,116,97,10,0,0,0,79,117,116,112,117,116,32,102,105,108,101,32,105,115,32,116,111,111,32,98,105,103,32,40,37,108,108,100,32,98,121,116,101,115,32,62,61,32,54,52,107,66,41,10,0,0,0,0,65,68,80,67,77,32,105,110,32,82,83,79,0,0,0,0,99,111,112,121,0,0,0,0,67,111,100,101,99,32,116,97,103,58,32,37,115,0,0,0,104,105,103,104,52,52,52,0,68,97,116,117,109,95,77,97,104,101,95,49,57,55,49,0,116,105,116,108,101,0,0,0,109,97,99,114,111,98,108,111,99,107,32,40,77,66,41,32,116,121,112,101,0,0,0,0,65,74,65,32,75,111,110,97,32,49,48,45,98,105,116,32,82,71,66,32,67,111,100,101,99,0,0,0,0,0,0,0,97,110,0,0,0,0,0,0,116,105,116,108,101,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,118,110,100,46,114,110,45,114,101,97,108,109,101,100,105,97,0,0,0,0,73,83,70,84,0,0,0,0,112,97,99,107,101,116,95,102,114,97,103,95,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,32,40,37,100,45,37,100,41,10,0,0,0,0,116,114,97,99,107,32,37,100,58,32,99,111,100,101,99,32,98,108,111,99,107,32,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,32,102,111,114,32,97,100,112,99,109,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,78,97,109,101,32,118,97,108,117,101,32,112,114,111,112,101,114,116,121,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,108,105,98,97,118,102,111,114,109,97,116,47,114,105,102,102,101,110,99,46,99,0,0,0,101,118,97,108,0,0,0,0,32,77,0,0,0,0,0,0,10,0,0,0,0,0,0,0,116,111,111,32,98,105,103,32,73,78,70,79,32,115,117,98,99,104,117,110,107,10,0,0,104,105,103,104,52,50,50,0,68,97,116,117,109,95,72,101,114,97,116,95,78,111,114,116,104,0,0,0,0,0,0,0,109,98,95,116,121,112,101,0,115,101,116,32,102,105,108,116,101,114,45,119,105,100,116,104,32,116,121,112,101,0,0,0,114,49,48,107,0,0,0,0,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,73,67,77,84,0,0,0,0,114,115,100,0,0,0,0,0,116,114,97,99,107,32,37,100,58,32,99,111,100,101,99,32,102,114,97,109,101,32,115,105,122,101,32,105,115,32,110,111,116,32,115,101,116,10,0,0,101,120,112,111,110,101,110,116,105,97,108,32,115,105,110,101,32,119,97,118,101,0,0,0,114,116,0,0,0,0,0,0,100,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,121,117,118,44,99,105,102,44,113,99,105,102,44,114,103,98,0,0,0,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,111,110,121,120,99,95,105,110,116,46,104,0,0,0,0,115,101,116,32,109,111,114,112,104,32,97,109,112,108,105,116,117,100,101,0,0,0,0,0,115,101,116,32,116,104,101,32,115,101,101,100,32,102,111,114,32,102,105,108,108,105,110,103,32,116,104,101,32,105,110,105,116,105,97,108,32,103,114,105,100,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,118,111,108,117,109,101,0,0,115,99,114,111,108,108,0,0,104,117,101,0,0,0,0,0,102,114,97,109,101,0,0,0,101,118,97,108,32,101,120,112,114,101,115,115,105,111,110,115,32,111,110,99,101,32,100,117,114,105,110,103,32,105,110,105,116,105,97,108,105,122,97,116,105,111,110,0,0,0,0,0,73,110,118,97,108,105,100,32,101,118,101,110,32,115,105,122,101,32,102,111,114,32,37,115,32,109,97,116,114,105,120,32,115,105,122,101,32,37,100,120,37,100,10,0,0,0,0,0,104,105,103,104,49,48,0,0,68,97,116,117,109,95,72,105,116,111,95,88,86,73,73,73,95,49,57,54,51,0,0,0,87,101,98,77,32,80,114,111,106,101,99,116,32,86,80,56,32,69,110,99,111,100,101,114,32,118,49,46,51,46,48,0,114,97,116,101,32,99,111,110,116,114,111,108,0,0,0,0,48,0,0,0,0,0,0,0,77,117,108,116,105,99,111,108,111,114,32,99,104,97,114,115,101,116,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,44,32,101,120,116,101,110,100,101,100,32,119,105,116,104,32,53,116,104,32,99,111,108,111,114,32,40,99,111,108,114,97,109,41,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,0,0,0,0,97,110,97,103,108,121,112,104,32,103,114,101,101,110,32,109,97,103,101,110,116,97,32,100,117,98,111,105,115,0,0,0,63,0,0,0,0,0,0,0,105,110,95,114,97,110,103,101,0,0,0,0,0,0,0,0,87,65,82,78,73,78,71,32,99,111,100,101,99,32,116,105,109,101,98,97,115,101,32,105,115,32,118,101,114,121,32,104,105,103,104,46,32,73,102,32,100,117,114,97,116,105,111,110,32,105,115,32,116,111,111,32,108,111,110,103,44,10,102,105,108,101,32,109,97,121,32,110,111,116,32,98,101,32,112,108,97,121,97,98,108,101,32,98,121,32,113,117,105,99,107,116,105,109,101,46,32,83,112,101,99,105,102,121,32,97,32,115,104,111,114,116,101,114,32,116,105,109,101,98,97,115,101,10,111,114,32,99,104,111,111,115,101,32,100,105,102,102,101,114,101,110,116,32,99,111,110,116,97,105,110,101,114,46,10,0,69,114,114,111,114,32,111,99,99,117,114,114,101,100,32,112,97,114,115,105,110,103,32,97,110,103,108,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,97,0,0,0,0,0,0,0,115,105,122,101,0,0,0,0,97,117,100,105,111,47,120,45,97,99,51,0,0,0,0,0,82,101,112,101,97,116,32,116,104,101,32,112,114,101,118,105,111,117,115,32,102,114,97,109,101,46,0,0,0,0,0,0,99,109,45,62,102,114,97,109,101,95,99,111,110,116,101,120,116,95,105,100,120,32,60,32,70,82,65,77,69,95,67,79,78,84,69,88,84,83,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,102,108,97,103,115,0,0,82,101,99,101,105,118,101,100,32,99,111,110,116,114,111,108,32,37,100,10,0,0,0,0,104,105,103,104,0,0,0,0,68,97,116,117,109,95,76,117,122,111,110,95,49,57,49,49,0,0,0,0,0,0,0,0,114,99,0,0,0,0,0,0,37,115,58,32,37,115,10,0,97,54,52,95,109,117,108,116,105,53,0,0,0,0,0,0,115,101,116,32,71,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,50,53,0,0,0,0,0,0,116,115,95,116,97,114,103,101,116,95,98,105,116,114,97,116,101,32,101,110,116,114,105,101,115,32,97,114,101,32,110,111,116,32,105,110,99,114,101,97,115,105,110,103,0,0,0,0,97,99,0,0,0,0,0,0,97,114,110,114,95,115,116,114,101,110,103,116,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,54,93,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,0,99,111,117,108,100,32,110,111,116,32,115,101,101,107,32,116,111,32,102,114,97,109,101,32,37,100,10,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,114,101,100,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,68,97,116,97,32,99,104,117,110,107,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,97,45,62,108,48,46,109,101,49,54,120,49,54,46,109,118,91,49,93,32,60,61,32,104,45,62,109,98,46,109,118,95,109,97,120,95,115,112,101,108,91,49,93,32,124,124,32,104,45,62,105,95,116,104,114,101,97,100,95,102,114,97,109,101,115,32,61,61,32,49,0,0,68,45,49,48,47,73,77,88,32,109,117,115,116,32,117,115,101,32,55,50,48,120,54,48,56,32,111,114,32,55,50,48,120,53,49,50,32,118,105,100,101,111,32,114,101,115,111,108,117,116,105,111,110,10,0,0,37,100,32,37,100,32,37,100,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,121,110,99,119,111,114,100,10,0,0,0,0,0,0,0,112,99,0,0,0,0,0,0,79,112,101,110,67,76,58,32,85,110,97,98,108,101,32,116,111,32,113,117,101,114,121,32,105,110,115,116,97,108,108,101,100,32,112,108,97,116,102,111,114,109,115,10,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,115,32,37,100,32,37,100,32,37,100,10,0,0,0,0,99,0,0,0,0,0,0,0,97,98,103,114,0,0,0,0,67,104,97,114,116,114,101,117,115,101,0,0,0,0,0,0,105,115,110,97,110,0,0,0,78,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,32,105,110,32,70,70,109,112,101,103,44,32,112,97,116,99,104,101,115,32,119,101,108,99,111,109,101,0,0,84,70,76,0,0,0,0,0,78,111,32,97,117,100,105,111,32,112,97,99,107,101,116,115,46,10,0,0,0,0,0,0,118,115,117,98,0,0,0,0,97,45,62,99,104,95,99,111,117,110,116,0,0,0,0,0,118,49,0,0,0,0,0,0,115,101,116,32,99,111,110,116,114,97,115,116,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,98,108,111,99,107,115,0,0,0,0,0,0,0,104,113,100,110,51,100,0,0,13,10,0,0,0,0,0,0,83,99,114,105,112,116,84,121,112,101,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,69,65,67,83,0,0,98,102,114,97,109,101,115,61,0,0,0,0,0,0,0,0,111,110,0,0,0,0,0,0,111,110,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,112,101,99,116,114,97,108,32,101,120,116,101,110,115,105,111,110,32,99,111,112,121,32,115,116,97,114,116,32,98,105,110,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,48,0,0,0,0,0,0,0,67,111,110,115,116,97,110,116,32,113,117,97,110,116,105,122,101,114,0,0,0,0,0,0,76,84,80,32,105,110,32,69,82,32,65,65,67,32,76,68,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,46,10,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,48,46,53,48,47,48,46,52,56,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,109,97,105,110,0,0,0,0,68,97,116,117,109,95,76,111,109,101,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,32,99,111,100,101,100,32,105,110,32,97,32,112,97,99,107,101,116,46,10,0,0,0,112,105,99,116,117,114,101,32,105,110,102,111,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,98,97,115,101,32,109,97,116,114,105,120,101,115,10,0,0,0,0,0,0,0,0,100,97,114,0,0,0,0,0,109,97,112,112,105,110,103,95,115,101,116,117,112,45,62,115,117,98,109,97,112,95,114,101,115,105,100,117,101,91,106,93,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,37,100,46,37,100,0,0,0,73,110,116,101,110,115,105,116,121,32,99,111,109,112,101,110,115,97,116,105,111,110,32,115,101,116,32,102,111,114,32,66,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,77,117,108,116,105,99,111,108,111,114,32,99,104,97,114,115,101,116,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,0,0,0,0,0,115,101,116,32,116,104,101,32,103,114,101,101,110,32,103,97,105,110,32,102,111,114,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,119,105,116,104,32,37,100,32,99,104,97,110,110,101,108,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,115,112,101,99,105,102,105,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,100,58,32,105,103,110,111,114,105,110,103,32,115,112,101,99,105,102,105,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,10,0,73,110,118,97,108,105,100,32,97,108,112,104,97,32,114,97,100,105,117,115,32,118,97,108,117,101,32,37,100,44,32,109,117,115,116,32,98,101,32,62,61,32,48,32,97,110,100,32,60,61,32,37,100,10,0,0,115,101,116,32,97,117,100,105,111,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,40,105,110,32,72,122,41,0,80,114,111,106,70,97,108,115,101,79,114,105,103,105,110,76,111,110,103,71,101,111,75,101,121,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,118,97,108,117,101,32,111,102,32,114,111,119,115,32,112,101,114,32,115,116,114,105,112,10,0,0,0,0,0,0,34,32,62,0,0,0,0,0,98,117,114,110,0,0,0,0,82,86,49,47,50,32,118,101,114,115,105,111,110,0,0,0,32,105,110,58,37,42,100,32,111,117,116,58,37,42,100,32,116,121,112,101,58,37,100,32,113,58,37,102,32,105,116,101,120,58,37,100,32,112,116,101,120,58,37,100,32,109,118,58,37,100,32,109,105,115,99,58,37,100,32,102,99,111,100,101,58,37,100,32,98,99,111,100,101,58,37,100,32,109,99,45,118,97,114,58,37,108,108,100,32,118,97,114,58,37,108,108,100,32,105,99,111,117,110,116,58,37,100,32,115,107,105,112,99,111,117,110,116,58,37,100,32,104,98,105,116,115,58,37,100,0,0,0,0,0,0,0,100,97,116,97,32,98,108,111,99,107,32,115,105,122,101,32,116,111,111,32,108,97,114,103,101,32,40,37,117,41,10,0,97,117,116,111,0,0,0,0,37,100,47,37,100,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,116,97,103,32,102,111,114,32,99,111,100,101,99,32,37,115,32,105,110,32,115,116,114,101,97,109,32,35,37,100,44,32,99,111,100,101,99,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,32,105,110,32,99,111,110,116,97,105,110,101,114,10,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,100,114,111,112,112,101,100,32,97,103,97,105,110,0,0,117,110,97,108,105,103,110,101,100,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,113,115,99,97,108,101,10,0,67,104,97,110,110,101,108,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2371744);
/* memory initializer */ allocate([108,97,121,111,117,116,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,115,116,114,101,97,109,32,37,100,44,32,97,110,100,32,99,111,117,108,100,32,110,111,116,32,98,101,32,103,117,101,115,115,101,100,32,102,114,111,109,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,40,37,100,41,10,0,0,0,0,0,0,86,66,86,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,98,105,116,114,97,116,101,10,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,67,111,100,101,99,32,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,32,111,114,32,116,111,111,32,115,104,111,114,116,46,10,0,0,99,108,67,114,101,97,116,101,73,109,97,103,101,50,68,32,101,114,114,111,114,32,39,37,100,39,10,0,0,0,0,0,67,111,100,101,99,32,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,32,111,114,32,116,111,111,32,115,104,111,114,116,46,10,0,0,84,0,0,0,0,0,0,0,86,105,115,117,97,108,32,79,98,106,101,99,116,32,83,101,113,32,69,110,100,0,0,0,99,98,112,95,114,100,0,0,77,105,115,115,105,110,103,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,0,0,0,0,37,99,73,82,32,102,105,108,116,101,114,32,99,111,101,102,102,95,98,105,116,115,32,109,117,115,116,32,98,101,32,98,101,116,119,101,101,110,32,49,32,97,110,100,32,49,54,46,10,0,0,0,0,0,0,0,100,101,99,111,100,101,95,115,111,115,58,32,110,98,95,99,111,109,112,111,110,101,110,116,115,32,40,37,100,41,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,97,113,95,109,111,100,101,0,86,80,56,69,95,83,69,84,95,78,79,73,83,69,95,83,69,78,83,73,84,73,86,73,84,89,0,0,0,0,0,0,72,105,103,104,32,99,111,109,112,114,101,115,115,105,111,110,46,10,0,0,0,0,0,0,99,98,108,107,32,115,105,122,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,92,73,0,0,0,0,0,0,83,121,110,116,97,120,45,98,97,115,101,100,32,65,114,105,116,104,109,101,116,105,99,32,67,111,100,105,110,103,32,40,83,65,67,41,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,102,54,52,108,101,0,0,0,66,97,100,32,98,108,111,99,107,115,32,98,105,116,115,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,67,111,117,108,100,32,110,111,116,32,40,114,101,41,97,108,108,111,99,97,116,101,32,99,111,109,109,97,110,100,32,97,114,114,97,121,10,0,0,0,109,97,120,95,116,114,97,110,115,102,111,114,109,95,104,105,101,114,97,114,99,104,121,95,100,101,112,116,104,95,105,110,116,101,114,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,73,110,118,97,108,105,100,32,108,111,110,103,32,116,101,114,109,32,82,80,83,46,10,0,115,104,111,114,116,32,116,101,114,109,32,108,105,115,116,58,10,0,0,0,0,0,0,0,119,101,105,103,104,116,101,100,0,0,0,0,0,0,0,0,80,73,67,84,95,84,89,80,69,95,83,73,0,0,0,0,69,120,116,101,110,100,101,100,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,115,101,32,86,76,67,115,10,0,108,111,103,32,115,101,97,114,99,104,0,0,0,0,0,0,32,32,66,105,116,115,58,32,37,100,10,0,0,0,0,0,102,102,118,49,32,101,110,99,111,100,101,114,0,0,0,0,98,111,120,50,105,0,0,0,100,109,105,120,95,109,111,100,101,0,0,0,0,0,0,0,68,67,65,45,88,88,67,72,58,32,100,109,105,120,32,116,111,32,76,70,69,49,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,77,68,67,84,32,105,110,105,116,105,97,108,105,122,101,100,44,32,111,114,100,101,114,32,61,32,37,100,46,10,0,0,115,101,116,32,115,99,97,108,101,32,109,101,116,101,114,32,40,43,57,32,116,111,32,43,49,56,41,0,0,0,0,0,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,32,77,105,99,114,111,115,111,102,116,32,118,97,114,105,97,110,116,32,118,101,114,115,105,111,110,32,49,0,0,0,0,0,0,0,98,97,115,101,108,105,110,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,99,104,97,110,110,101,108,95,99,111,117,110,116,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,0,68,97,116,117,109,95,76,105,98,101,114,105,97,95,49,57,54,52,0,0,0,0,0,0,112,105,99,116,0,0,0,0,74,97,122,122,43,70,117,110,107,0,0,0,0,0,0,0,87,77,47,77,101,100,105,97,83,116,97,116,105,111,110,78,97,109,101,0,0,0,0,0,102,105,102,111,0,0,0,0,97,54,52,95,109,117,108,116,105,0,0,0,0,0,0,0,109,111,110,111,49,54,0,0,37,48,56,120,45,37,48,52,120,45,37,48,52,120,45,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,0,119,114,105,116,101,95,98,101,120,116,0,0,0,0,0,0,48,120,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,0,0,0,0,0,0,77,85,83,67,0,0,0,0,49,0,0,0,0,0,0,0,112,112,0,0,0,0,0,0,93,0,0,0,0,0,0,0,72,50,54,52,0,0,0,0,97,114,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,102,54,52,108,101,0,0,0,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,86,49,46,48,10,40,99,41,32,49,57,57,50,45,57,54,32,65,109,97,122,105,110,103,32,83,116,117,100,105,111,10,26,0,121,101,115,0,0,0,0,0,68,97,116,117,109,95,76,101,105,103,111,110,0,0,0,0,112,114,105,110,116,32,115,112,101,99,105,102,105,99,32,100,101,98,117,103,32,105,110,102,111,0,0,0,0,0,0,0,65,83,67,73,73,47,65,78,83,73,32,97,114,116,0,0,113,117,97,108,105,116,121,0,69,114,114,111,114,32,115,101,116,116,105,110,103,32,111,112,116,105,111,110,32,37,115,46,10,0,0,0,0,0,0,0,99,115,118,32,102,111,114,109,97,116,0,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,77,80,52,86,45,69,83,47,57,48,48,48,48,13,10,97,61,102,109,116,112,58,37,100,32,112,114,111,102,105,108,101,45,108,101,118,101,108,45,105,100,61,49,37,115,13,10,0,0,0,0,0,89,111,117,32,114,101,113,117,101,115,116,101,100,32,97,32,99,111,112,121,32,111,102,32,116,104,101,32,111,114,105,103,105,110,97,108,32,116,105,109,101,99,111,100,101,32,116,114,97,99,107,32,115,111,32,116,105,109,101,99,111,100,101,32,109,101,116,97,100,97,116,97,32,97,114,101,32,110,111,119,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,32,102,111,114,32,111,112,116,105,111,110,32,45,70,0,0,0,0,0,0,83,116,114,101,97,109,32,105,100,101,110,116,105,102,105,101,114,0,0,0,0,0,0,0,108,105,110,0,0,0,0,0,85,110,107,110,111,119,110,32,105,110,116,101,114,108,101,97,118,101,114,32,37,88,10,0,104,50,54,49,0,0,0,0,100,105,114,101,99,116,0,0,49,0,0,0,0,0,0,0,117,50,52,98,101,0,0,0,68,97,116,117,109,95,76,97,107,101,0,0,0,0,0,0,100,101,98,117,103,0,0,0,97,117,100,105,111,47,120,45,111,109,97,0,0,0,0,0,97,110,115,105,0,0,0,0,117,50,52,98,101,0,0,0,115,101,116,32,97,117,100,105,111,32,113,117,97,108,105,116,121,32,40,99,111,100,101,99,45,115,112,101,99,105,102,105,99,41,0,0,0,0,0,0,122,111,111,109,0,0,0,0,101,110,97,98,108,101,32,82,84,80,32,77,80,52,65,45,76,65,84,77,32,112,97,121,108,111,97,100,0,0,0,0,111,109,97,44,111,109,103,44,97,97,51,0,0,0,0,0,116,104,101,111,114,97,32,107,102,103,115,104,105,102,116,32,37,100,44,32,118,114,101,118,32,37,100,10,0,0,0,0,85,110,107,110,111,119,110,32,79,103,103,86,80,56,32,118,101,114,115,105,111,110,32,37,100,46,37,100,10,0,0,0,80,83,80,32,109,111,100,101,32,110,101,101,100,32,111,110,101,32,118,105,100,101,111,32,97,110,100,32,111,110,101,32,97,117,100,105,111,32,115,116,114,101,97,109,10,0,0,0,83,107,105,112,83,116,97,114,116,0,0,0,0,0,0,0,72,101,105,103,104,116,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,99,111,118,101,114,32,97,114,116,32,98,108,111,99,107,46,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,109,101,32,98,97,115,101,32,105,110,32,116,104,101,111,114,97,32,115,116,114,101,97,109,44,32,97,115,115,117,109,105,110,103,32,50,53,32,70,80,83,10,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,105,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,46,32,83,112,101,101,120,32,109,117,115,116,32,98,101,32,109,111,110,111,32,111,114,32,115,116,101,114,101,111,46,10,0,0,0,73,110,100,101,120,83,73,68,32,37,105,32,115,101,103,109,101,110,116,32,37,105,32,104,97,115,32,122,101,114,111,32,73,110,100,101,120,68,117,114,97,116,105,111,110,32,97,110,100,32,116,104,101,114,101,39,115,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,115,101,103,109,101,110,116,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,115,107,101,108,101,116,111,110,32,118,101,114,115,105,111,110,32,37,100,46,37,100,10,0,80,65,67,75,73,78,71,0,76,97,115,116,32,112,97,99,107,101,116,32,119,97,115,32,116,114,117,110,99,97,116,101,100,32,116,111,32,37,100,32,100,117,101,32,116,111,32,101,110,100,32,116,114,105,109,109,105,110,103,46,10,0,0,0,104,105,115,116,111,103,114,97,109,0,0,0,0,0,0,0,109,117,120,114,97,116,101,32,37,100,44,32,0,0,0,0,1,116,101,120,116,0,0,0,84,97,103,32,37,120,32,108,101,110,103,116,104,32,118,105,111,108,97,116,105,111,110,32,110,101,119,32,108,101,110,103,116,104,32,37,100,32,98,121,116,101,115,32,114,101,109,97,105,110,105,110,103,32,37,100,10,0,0,0,0,0,0,0,99,114,111,112,0,0,0,0,68,97,116,117,109,95,80,114,111,118,105,115,105,111,110,97,108,95,83,95,65,109,101,114,105,99,97,110,95,68,97,116,117,109,95,49,57,53,54,0,112,97,121,108,111,97,100,95,115,105,122,101,32,45,32,115,116,117,102,102,105,110,103,95,115,105,122,101,32,60,61,32,97,118,95,102,105,102,111,95,115,105,122,101,40,115,116,114,101,97,109,45,62,102,105,102,111,41,0,0,0,0,0,0,115,97,109,112,108,101,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,116,105,116,108,101,0,0,0,80,105,99,116,111,114,47,80,67,32,80,97,105,110,116,0,78,111,32,97,117,100,105,111,32,115,116,114,101,97,109,32,112,114,101,115,101,110,116,46,10,0,0,0,0,0,0,0,97,113,0,0,0,0,0,0,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,111,110,32,115,101,101,107,97,98,108,101,32,111,117,116,112,117,116,10,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,111,103,103,0,99,111,109,109,101,110,116,0,116,114,97,99,107,110,117,109,62,61,48,32,38,38,32,116,114,97,99,107,110,117,109,60,110,117,109,95,116,114,97,99,107,115,0,0,0,0,0,0,66,114,111,107,101,110,32,102,105,108,101,44,32,37,115,107,101,121,102,114,97,109,101,32,110,111,116,32,99,111,114,114,101,99,116,108,121,32,109,97,114,107,101,100,46,10,0,0,69,66,77,76,32,104,101,97,100,101,114,32,117,115,105,110,103,32,117,110,115,117,112,112,111,114,116,101,100,32,102,101,97,116,117,114,101,115,10,40,69,66,77,76,32,118,101,114,115,105,111,110,32,37,108,108,117,44,32,100,111,99,116,121,112,101,32,37,115,44,32,100,111,99,32,118,101,114,115,105,111,110,32,37,108,108,117,41,10,0,0,0,0,0,0,0,86,105,100,101,111,32,112,97,99,107,101,116,32,105,110,32,102,105,108,101,32,119,105,116,104,111,117,116,32,118,105,100,101,111,32,115,116,114,101,97,109,33,10,0,0,0,0,0,115,104,111,119,0,0,0,0,68,97,116,117,109,95,76,97,95,67,97,110,111,97,0,0,116,115,95,102,114,111,109,95,102,105,108,101,0,0,0,0,97,115,112,101,99,116,0,0,112,105,120,0,0,0,0,0,112,105,99,116,111,114,0,0,109,111,100,101,0,0,0,0,118,105,100,101,111,47,120,45,110,117,116,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,102,114,97,109,101,115,32,116,111,32,114,101,99,111,114,100,0,0,0,0,0,0,0,0,84,68,82,76,0,0,0,0,35,69,88,84,45,88,45,84,65,82,71,69,84,68,85,82,65,84,73,79,78,58,0,0,70,76,86,0,0,0,0,0,84,104,101,32,102,97,115,116,115,116,97,114,116,32,102,108,97,103,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,102,114,97,103,109,101,110,116,97,116,105,111,110,32,97,110,100,32,99,117,115,116,111,109,32,73,79,44,32,100,105,115,97,98,108,105,110,103,32,102,97,115,116,115,116,97,114,116,10,0,0,0,0,0,0,0,70,76,86,0,0,0,0,0,37,46,102,0,0,0,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,97,117,100,105,111,32,99,111,109,112,114,101,115,115,105,111,110,95,116,121,112,101,61,37,105,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,37,115,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,119,105,116,104,32,99,111,100,101,99,32,37,115,0,0,109,97,99,0,0,0,0,0,68,97,116,117,109,95,75,117,119,97,105,116,95,79,105,108,95,67,111,109,112,97,110,121,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,109,101,100,105,97,110,0,0,37,108,108,117,45,37,108,108,117,32,37,108,108,100,45,37,108,108,100,10,0,0,0,0,71,111,111,103,108,101,32,86,80,57,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,117,100,105,111,46,99,0,0,0,0,0,67,104,97,110,110,101,108,115,32,105,115,32,48,10,0,0,104,105,115,116,101,113,0,0,97,102,114,97,109,101,115,0,63,0,0,0,0,0,0,0,83,111,109,101,116,104,105,110,103,32,119,101,110,116,32,119,114,111,110,103,32,100,117,114,105,110,103,32,104,101,97,100,101,114,32,112,97,114,115,105,110,103,44,32,73,32,119,105,108,108,32,105,103,110,111,114,101,32,105,116,32,97,110,100,32,116,114,121,32,116,111,32,99,111,110,116,105,110,117,101,32,97,110,121,119,97,121,46,10,0,0,0,0,0,0,0,112,97,99,107,101,116,95,114,101,112,108,105,99,95,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,110,105,115,116,44,115,112,104,0,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,70,111,117,110,100,32,69,79,73,32,98,101,102,111,114,101,32,83,79,73,44,32,115,107,105,112,112,105,110,103,10,0,115,101,108,101,99,116,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,109,120,102,0,80,117,114,101,32,99,104,97,110,110,101,108,32,109,97,112,112,105,110,103,32,100,101,116,101,99,116,101,100,58,0,0,37,100,46,37,115,32,61,62,32,37,115,32,0,0,0,0,37,100,58,32,120,61,37,102,32,121,61,37,102,10,0,0,115,101,99,97,109,0,0,0,68,97,116,117,109,95,75,101,114,116,97,117,0,0,0,0,112,108,97,110,101,0,0,0,119,105,100,116,104,95,116,121,112,101,0,0,0,0,0,0,118,112,57,0,0,0,0,0,104,102,108,105,112,0,0,0,115,101,108,101,99,116,32,97,32,100,101,118,105,99,101,32,102,111,114,32,72,87,32,97,99,99,101,108,101,114,97,116,105,111,110,100,101,118,105,99,101,110,97,109,101,0,0,0,101,115,105,110,0,0,0,0,115,101,116,32,97,117,100,105,111,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,98,95,119,105,100,116,104,95,108,111,103,50,40,98,115,105,122,101,41,32,61,61,32,98,95,104,101,105,103,104,116,95,108,111,103,50,40,98,115,105,122,101,41,0,0,0,0,0,115,101,101,107,105,110,103,32,100,101,116,101,99,116,101,100,32,111,110,32,115,116,114,101,97,109,32,35,37,100,32,119,105,116,104,32,116,105,109,101,32,98,97,115,101,32,40,37,100,47,37,100,41,32,97,110,100,32,115,97,109,112,108,101,32,114,97,116,101,32,40,37,100,47,37,100,41,44,32,97,117,100,105,111,32,112,116,115,32,119,111,110,39,116,32,98,101,32,97,99,99,117,114,97,116,101,46,10,0,0,0,0,109,111,114,112,104,97,109,112,0,0,0,0,0,0,0,0,114,97,110,100,111,109,95,115,101,101,100,0,0,0,0,0,117,110,104,97,110,100,108,101,100,32,118,101,114,115,105,111,110,32,40,37,100,44,37,100,41,10,0,0,0,0,0,0,45,118,111,108,32,105,115,32,102,111,114,119,97,114,100,101,100,32,116,111,32,108,97,118,102,105,32,115,105,109,105,108,97,114,108,121,32,116,111,32,45,97,102,32,118,111,108,117,109,101,61,37,115,46,10,0,115,101,101,100,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,105,116,0,0,0,0,115,104,97,114,112,101,110,0,110,116,115,99,0,0,0,0,68,97,116,117,109,95,75,97,110,100,97,119,97,108,97,0,108,101,102,116,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,79,110,50,32,86,80,56,0,102,114,101,113,117,101,110,99,121,0,0,0,0,0,0,0,104,119,97,99,99,101,108,95,100,101,118,105,99,101,0,0,97,103,109,100,0,0,0,0,118,105,100,101,111,32,99,111,109,112,114,101,115,115,105,111,110,32,37,105,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,89,67,98,67,114,32,116,121,112,101,0,0,0,116,111,112,105,99,0,0,0,85,110,97,98,108,101,32,116,111,32,114,101,45,111,112,101,110,32,37,115,32,111,117,116,112,117,116,32,102,105,108,101,32,102,111,114,32,116,104,101,32,115,101,99,111,110,100,32,112,97,115,115,32,40,102,97,115,116,115,116,97,114,116,41,10,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,79,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,111,104,0,0,0,0,0,0,72,101,97,100,101,114,32,99,108,97,105,109,115,32,37,100,98,112,112,32,40,33,61,32,49,54,41,46,32,73,103,110,111,114,105,110,103,10,0,0,103,114,97,100,102,117,110,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,118,97,108,105,100,32,115,116,97,114,116,46,10,0,0,0,0,114,101,112,101,97,116,0,0,48,0,0,0,0,0,0,0,99,49,95,102,108,97,103,115,0,0,0,0,0,0,0,0,115,117,98,0,0,0,0,0,119,105,100,116,104,62,48,32,38,38,32,104,101,105,103,104,116,62,48,0,0,0,0,0,116,120,116,44,109,112,108,50,0,0,0,0,0,0,0,0,112,97,108,0,0,0,0,0,68,97,116,117,109,95,75,97,108,105,97,110,112,117,114,0,112,114,101,100,105,99,116,105,111,110,32,109,101,116,104,111,100,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,118,112,56,0,0,0,0,0,109,117,108,116,105,112,97,114,116,47,120,45,109,105,120,101,100,45,114,101,112,108,97,99,101,59,98,111,117,110,100,97,114,121,61,102,102,115,101,114,118,101,114,0,0,0,0,0,103,0,0,0,0,0,0,0,109,112,101,103,118,105,100,101,111,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,116,115,95,110,117,109,98,101,114,95,108,97,121,101,114,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,86,80,88,95,84,83,95,77,65,88,95,76,65,89,69,82,83,93,0,0,0,0,104,119,97,99,99,101,108,32,110,97,109,101,0,0,0,0,97,114,110,114,95,109,97,120,95,102,114,97,109,101,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,48,46,46,49,53,93,0,0,0,0,112,97,114,97,100,101,0,0,99,114,95,101,120,112,114,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,10,0,115,101,116,32,116,104,101,32,109,97,116,99,104,105,110,103,32,109,111,100,101,32,111,114,32,115,116,114,97,116,101,103,121,32,116,111,32,117,115,101,0,0,0,0,0,0,0,0,99,108,83,101,116,75,101,114,110,101,108,65,114,103,0,0,98,108,97,99,107,0,0,0,114,103,98,97,0,0,0,0,67,97,100,101,116,66,108,117,101,0,0,0,0,0,0,0,118,105,100,101,111,47,120,45,109,112,101,103,116,115,0,0,108,100,0,0,0,0,0,0,80,65,84,67,72,87,69,76,67,79,77,69,0,0,0,0,116,111,112,32,99,101,110,116,101,114,0,0,0,0,0,0,104,115,117,98,0,0,0,0,99,104,114,32,115,114,99,87,61,37,100,32,115,114,99,72,61,37,100,32,100,115,116,87,61,37,100,32,100,115,116,72,61,37,100,32,120,73,110,99,61,37,100,32,121,73,110,99,61,37,100,10,0,0,0,0,98,105,116,101,120,97,99,116,0,0,0,0,0,0,0,0,97,45,62,98,112,115,0,0,120,49,104,100,101,98,108,111,99,107,0,0,0,0,0,0,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,0,70,80,83,58,32,37,100,47,37,100,32,45,62,32,37,100,47,37,100,10,0,0,0,0,83,99,114,105,112,116,32,73,110,102,111,0,0,0,0,0,97,100,112,99,109,95,105,109,97,95,101,97,95,101,97,99,115,0,0,0,0,0,0,0,100,105,102,102,101,114,101,110,116,32,119,101,105,103,104,116,112,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,77,111,100,101,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,77,111,100,101,0,0,0,0,0,105,110,118,97,108,105,100,32,115,112,101,99,116,114,97,108,32,101,120,116,101,110,115,105,111,110,32,114,97,110,103,101,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,97,115,116,0,0,0,0,80,114,101,100,105,99,116,105,111,110,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,65,65,67,45,76,67,46,10,0,0,0,48,0,0,0,0,0,0,0,48,47,48,46,49,49,32,48,46,52,50,47,48,46,53,49,32,49,47,48,46,57,53,0,109,105,110,95,115,97,109,112,108,101,115,95,112,101,114,95,115,117,98,102,114,97,109,101,32,111,102,32,37,100,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,99,111,109,112,111,110,101,110,116,0,0,0,0,0,0,0,68,97,116,117,109,95,74,97,109,97,105,99,97,95,49,57,54,57,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,67,117,115,116,111,109,32,115,97,109,112,108,101,32,114,97,116,101,32,109,105,115,115,105,110,103,46,10,0,0,0,0,112,114,101,100,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,112,51,46,99,0,0,0,0,0,0,0,0,115,97,114,0,0,0,0,0,109,97,112,112,105,110,103,95,115,101,116,117,112,45,62,115,117,98,109,97,112,95,102,108,111,111,114,91,106,93,0,0,32,37,100,46,37,46,51,100,0,0,0,0,0,0,0,0,72,105,103,104,32,52,58,52,58,52,32,80,114,101,100,105,99,116,105,118,101,0,0,0,77,66,32,70,111,114,119,97,114,100,32,84,121,112,101,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,80,115,121,103,110,111,115,105,115,32,89,79,80,32,86,105,100,101,111,0,0,0,0,0,109,112,101,103,116,115,0,0,97,103,0,0,0,0,0,0,66,105,116,114,97,116,101,32,37,100,32,105,115,32,101,120,116,114,101,109,101,108,121,32,108,111,119,44,32,109,97,121,98,101,32,121,111,117,32,109,101,97,110,32,37,100,107,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,114,111,109,97,32,114,97,100,105,117,115,32,118,97,108,117,101,32,37,100,44,32,109,117,115,116,32,98,101,32,62,61,32,48,32,97,110,100,32,60,61,32,37,100,10,0,117,115,101,32,72,87,32,97,99,99,101,108,101,114,97,116,101,100,32,100,101,99,111,100,105,110,103,0,0,0,0,0,80,114,111,106,70,97,108,115,101,78,111,114,116,104,105,110,103,71,101,111,75,101,121,0,85,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,37,105,10,0,0,13,10,0,0,0,0,0,0,97,118,101,114,97,103,101,0,110,111,116,32,101,110,111,117,103,104,32,101,120,116,114,97,100,97,116,97,10,0,0,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,37,88,10,0,0,0,0,0,0,112,105,99,116,117,114,101,95,110,117,109,98,101,114,32,60,32,114,99,99,45,62,110,117,109,95,101,110,116,114,105,101,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,113,117,97,110,116,105,115,101,114,32,109,97,116,114,105,120,0,0,0,0,0,0,0,0,37,100,58,37,100,0,0,0,101,110,100,95,102,114,97,109,101,0,0,0,0,0,0,0,83,101,116,32,118,105,100,101,111,32,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,40,105,110,32,98,105,116,115,47,115,41,46,32,73,110,32,49,45,112,97,115,115,32,109,111,100,101,44,32,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,115,112,101,99,105,102,105,101,115,32,104,111,119,32,102,97,114,32,114,97,116,101,99,111,110,116,114,111,108,32,105,115,32,119,105,108,108,105,110,103,32,116,111,32,100,101,118,105,97,116,101,32,102,114,111,109,32,116,104,101,32,116,97,114,103,101,116,32,97,118,101,114,97,103,101,32,98,105,116,114,97,116,101,32,118,97,108,117,101,46,32,84,104,105,115,32,105,115,32,110,111,116,32,114,101,108,97,116,101,100,32,116,111,32,109,105,110,105,109,117,109,47,109,97,120,105,109,117,109,32,98,105,116,114,97,116,101,46,32,76,111,119,101,114,105,110,103,32,116,111,108,101,114,97,110,99,101,32,116,111,111,32,109,117,99,104,32,104,97,115,32,97,110,32,97,100,118,101,114,115,101,32,101,102,102,101,99,116,32,111,110,32,113,117,97,108,105,116,121,46,0,0,0,0,0,105,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,116,121,112,101,10,0,0,0,105,109,112,111,115,115,105,98,108,101,32,98,105,116,114,97,116,101,32,99,111,110,115,116,114,97,105,110,116,115,44,32,116,104,105,115,32,119,105,108,108,32,102,97,105,108,10,0,115,101,101,107,95,112,111,105,110,116,58,37,108,108,105,32,102,111,114,109,97,116,95,110,97,109,101,58,37,115,32,102,105,108,101,95,110,97,109,101,58,37,115,32,115,116,114,101,97,109,95,105,110,100,101,120,58,37,100,10,0,0,0,0,105,0,0,0,0,0,0,0,115,119,105,116,99,104,32,112,111,105,110,116,32,105,110,32,56,107,104,122,0,0,0,0,100,101,102,97,117,108,116,0,115,119,105,116,99,104,32,112,111,105,110,116,32,105,110,32,56,107,104,122,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,86,105,115,117,97,108,32,79,98,106,101,99,116,32,83,101,113,32,83,116,97,114,116,0,83,84,65,82,84,84,0,0,85,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,113,112,32,115,101,108,101,99,116,105,111,110,0,0,0,0,0,0,0,115,108,105,99,101,32,98,101,108,111,119,32,105,109,97,103,101,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,37,99,73,82,32,102,105,108,116,101,114,32,111,114,100,101,114,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,109,97,120,105,109,117,109,32,37,100,46,10,0,0,0,0,0,0,0,115,45,62,112,105,99,116,117,114,101,95,112,116,114,45,62,100,97,116,97,91,48,93,0,118,105,100,101,111,47,109,112,101,103,0,0,0,0,0,0,65,81,32,109,101,116,104,111,100,0,0,0,0,0,0,0,86,80,56,69,95,83,69,84,95,69,78,65,66,76,69,65,85,84,79,65,76,84,82,69,70,0,0,0,0,0,0,0,72,105,103,104,32,115,112,101,101,100,32,99,111,109,112,114,101,115,115,105,111,110,46,10,0,0,0,0,0,0,0,0,114,101,100,117,99,116,105,111,110,95,102,97,99,116,111,114,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,116,104,105,115,32,98,105,116,115,116,114,101,97,109,44,32,109,97,120,32,105,115,32,37,100,10,0,0,0,0,0,0,0,123,92,114,125,0,0,0,0,72,50,54,51,32,83,65,67,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,67,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,105,110,116,101,114,110,97,108,32,115,116,114,117,99,116,117,114,101,115,33,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,78,111,32,105,110,116,101,114,118,97,108,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,105,110,116,101,114,118,97,108,32,35,37,100,10,0,67,84,66,32,115,105,122,101,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,50,94,37,100,10,0,0,0,0,78,111,32,114,101,102,32,108,105,115,116,115,32,105,110,32,116,104,101,32,83,80,83,46,10,0,0,0,0,0,0,0,37,100,32,102,110,58,37,100,32,112,111,99,58,37,100,32,37,112,10,0,0,0,0,0,67,65,86,76,67,0,0,0,80,73,67,84,95,84,89,80,69,95,83,0,0,0,0,0,77,97,105,110,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,102,117,108,108,32,115,101,97,114,99,104,0,0,0,0,0,32,32,67,104,97,110,110,101,108,115,58,32,37,100,10,0,45,49,0,0,0,0,0,0,100,97,116,97,87,105,110,100,111,119,0,0,0,0,0,0,79,114,105,103,105,110,97,108,32,66,105,116,32,83,116,114,101,97,109,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,68,84,83,45,88,88,67,72,32,101,120,116,101,110,115,105,111,110,10,0,0,0,0,0,0,115,97,109,112,108,101,115,95,112,101,114,95,99,104,97,110,110,101,108,32,61,32,37,100,0,0,0,0,0,0,0,0,109,101,116,101,114,0,0,0,115,97,114,0,0,0,0,0,109,115,109,112,101,103,52,118,49,0,0,0,0,0,0,0,118,111,98,115,117,98,0,0,111,110,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,68,97,116,117,109,95,74,97,109,97,105,99,97,95,49,56,55,53,0,0,0,0,0,0,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,0,0,0,86,111,99,97,108,0,0,0,115,101,114,118,105,99,101,95,112,114,111,118,105,100,101,114,0,0,0,0,0,0,0,0,65,108,108,32,99,111,117,110,116,115,32,119,105,116,104,111,117,116,32,97,108,108,32,108,97,121,111,117,116,115,10,0,121,111,112,0,0,0,0,0,52,52,52,0,0,0,0,0,37,117,0,0,0,0,0,0,78,111,32,115,116,114,101,97,109,32,97,100,100,101,100,32,98,101,102,111,114,101,32,112,97,114,115,105,110,103,32,115,101,101,107,32,116,97,98,108,101,10,0,0,0,0,0,0,87,65,86,32,109,117,120,101,114,0,0,0,0,0,0,0,48,120,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,37,48,49,54,108,108,88,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,116,104,114,101,97,100,115,0,112,97,110,0,0,0,0,0,58,93,0,0,0,0,0,0,118,105,100,101,111,0,0,0,104,119,97,99,99,101,108,0,78,111,116,32,97,32,77,117,115,101,112,97,99,107,32,102,105,108,101,10,0,0,0,0,114,111,116,97,116,101,0,0,97,117,100,105,111,47,120,45,109,112,101,103,0,0,0,0,109,112,50,44,109,112,51,44,109,50,97,44,109,112,97,0,111,102,102,0,0,0,0,0,68,97,116,117,109,95,73,110,100,105,97,110,95,49,57,55,53,0,0,0,0,0,0,0,117,115,101,32,115,116,114,111,110,103,32,100,101,98,108,111,99,107,32,102,105,108,116,101,114,32,102,111,114,32,100,97,109,97,103,101,100,32,77,66,115,0,0,0,0,0,0,0,75,101,103,97,32,71,97,109,101,32,86,105,100,101,111,0,98,105,116,114,97,116,101,0,82,111,117,116,105,110,103,32,111,112,116,105,111,110,32,37,115,32,116,111,32,98,111,116,104,32,99,111,100,101,99,32,97,110,100,32,109,117,120,101,114,32,108,97,121,101,114,10,0,0,0,0,0,0,0,0,99,115,118,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,72,50,54,51,45,50,48,48,48,47,57,48,48,48,48,13,10,97,61,102,114,97,109,101,115,105,122,101,58,37,100,32,37,100,45,37,100,13,10,0,0,0,0,0,119,97,118,101,102,111,114,109,32,100,101,102,105,110,105,116,105,111,110,115,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,0,0,0,0,0,0,0,0,115,115,114,99,0,0,0,0,108,111,103,97,114,105,116,104,109,105,99,0,0,0,0,0,109,105,115,109,97,116,99,104,105,110,103,32,105,110,116,101,114,108,101,97,118,101,114,32,112,97,114,97,109,101,116,101,114,115,0,0,0,0,0,0,116,99,111,44,114,99,111,0,98,116,50,48,50,48,0,0,68,97,116,117,109,95,73,110,100,105,97,110,95,49,57,53,52,0,0,0,0,0,0,0,103,101,113,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,100,101,98,108,111,99,107,0,107,103,118,49,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,118,105,100,101,111,32,98,105,116,114,97,116,101,32,40,112,108,101,97,115,101,32,117,115,101,32,45,98,58,118,41,0,115,101,116,32,98,108,117,101,32,102,97,100,101,0,0,0,108,97,116,109,0,0,0,0,69,65,51,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,101,100,10,0,0,0,0,97,118,95,114,101,115,99,97,108,101,95,114,110,100,40,116,114,97,99,107,45,62,99,108,117,115,116,101,114,91,48,93,46,100,116,115,44,32,49,48,48,48,44,32,116,114,97,99,107,45,62,116,105,109,101,115,99,97,108,101,44,32,65,86,95,82,79,85,78,68,95,68,79,87,78,41,32,60,61,32,48,0,0,0,0,0,0,0,72,101,105,103,104,116,0,0,87,105,100,116,104,0,0,0,116,114,97,99,107,32,37,100,58,32,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,101,115,115,101,110,99,101,32,99,111,110,116,97,105,110,101,114,32,117,108,44,32,99,111,100,101,99,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,32,105,110,32,99,111,110,116,97,105,110,101,114,10,0,0,0,0,0,0,73,110,100,101,120,83,73,68,32,37,105,32,115,116,97,114,116,115,32,97,116,32,69,100,105,116,85,110,105,116,32,37,108,108,100,32,45,32,115,101,101,107,105,110,103,32,109,97,121,32,110,111,116,32,119,111,114,107,32,97,115,32,101,120,112,101,99,116,101,100,10,0,73,78,84,69,82,76,65,67,73,78,71,0,0,0,0,0,104,45,62,109,98,46,99,97,99,104,101,46,112,115,107,105,112,95,109,118,91,49,93,32,60,61,32,104,45,62,109,98,46,109,118,95,109,97,120,95,115,112,101,108,91,49,93,32,124,124,32,104,45,62,105,95,116,104,114,101,97,100,95,102,114,97,109,101,115,32,61,61,32,49,0,0,0,0,0,0,109,117,120,114,97,116,101,32,86,66,82,44,32,0,0,0,102,105,108,109,0,0,0,0,68,97,116,117,109,95,73,110,100,111,110,101,115,105,97,110,95,68,97,116,117,109,95,49,57,55,52,0,0,0,0,0,102,114,97,109,101,115,116,101,112,0,0,0,0,0,0,0,97,118,95,102,105,102,111,95,115,105,122,101,40,115,116,114,101,97,109,45,62,102,105,102,111,41,32,61,61,32,116,114,97,105,108,101,114,95,115,105,122,101,0,0,0,0,0,0,105,116,101,114,97,116,105,118,101,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,40,77,86,41,32,115,101,97,114,99,104,32,40,115,108,111,119,41,0,0,0,0,0,0,97,108,116,58,0,0,0,0,73,70,70,32,66,121,116,101,82,117,110,49,0,0,0,0,79,110,108,121,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,97,110,100,32,112,105,99,116,117,114,101,115,32,97,114,101,32,97,108,108,111,119,101,100,32,105,110,32,77,80,51,46,10,0,0,0,0,98,0,0,0,0,0,0,0,105,115,109,118,44,105,115,109,97,0,0,0,0,0,0,0,108,121,114,105,99,115,0,0,77,97,108,102,111,114,109,101,100,32,65,65,67,32,98,105,116,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,58,32,117,115,101,32,97,117,100,105,111,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,39,97,97,99,95,97,100,116,115,116,111,97,115,99,39,32,116,111,32,102,105,120,32,105,116,32,40,39,45,98,115,102,58,97,32,97,97,99,95,97,100,116,115,116,111,97,115,99,39,32,111,112,116,105,111,110,32,119,105,116,104,32,102,102,109,112,101,103,41,10,0,0,0,0,0,115,105,122,101,32,62,61,32,50,0,0,0,0,0,0,0,101,110,103,0,0,0,0,0,98,116,50,48,50,48,45,49,50,0,0,0,0,0,0,0,68,97,116,117,109,95,72,117,110,103,97,114,105,97,110,95,68,97,116,117,109,95,49,57,55,50,0,0,0,0,0,0,102,111,114,99,101,32,102,114,97,109,101,32,115,105,122,101,32,105,110,32,98,121,116,101,115,0,0,0,0,0,0,0,103,117,101,115,115,95,109,118,115,0,0,0,0,0,0,0,112,99,120,0,0,0,0,0,105,102,102,95,98,121,116,101,114,117,110,49,0,0,0,0,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,101,110,99,111,100,101,114,0,48,88,0,0,0,0,0,0,78,111,32,118,105,100,101,111,32,115,116,114,101,97,109,32,105,110,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,37,100,32,97,110,100,32,110,111,32,109,105,110,32,102,114,97,103,32,100,117,114,97,116,105,111,110,32,115,101,116,10,0,0,0,0,0,0,0,67,111,100,101,99,32,116,121,112,101,32,39,37,115,39,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,109,111,118,44,109,112,52,44,109,52,97,44,51,103,112,44,51,103,50,44,109,106,50,0,115,116,114,101,97,109,32,116,121,112,101,59,32,99,111,109,112,114,101,115,115,105,111,110,95,116,121,112,101,61,37,105,0,0,0,0,0,0,0,0,116,121,112,101,61,32,37,99,10,0,0,0,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,118,110,100,46,115,109,97,102,0,0,0,0,98,116,50,48,50,48,45,49,48,0,0,0,0,0,0,0,68,97,116,117,109,95,72,117,95,84,122,117,95,83,104,97,110,0,0,0,0,0,0,0,115,101,116,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,32,115,116,114,97,116,101,103,121,0,0,117,110,107,110,111,119,110,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2381984);
/* memory initializer */ allocate([99,104,117,110,107,32,116,121,112,101,32,48,120,37,120,10,0,0,0,0,0,0,0,0,73,70,70,32,73,76,66,77,0,0,0,0,0,0,0,0,77,111,114,101,32,116,104,97,110,32,111,110,101,32,115,116,114,101,97,109,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,102,111,114,99,101,32,107,101,121,32,102,114,97,109,101,115,32,97,116,32,115,112,101,99,105,102,105,101,100,32,116,105,109,101,115,116,97,109,112,115,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,114,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,116,121,112,101,32,39,37,115,39,32,102,111,117,110,100,32,105,110,32,116,104,101,32,105,110,112,117,116,10,0,0,0,0,116,101,120,116,47,120,45,109,105,99,114,111,100,118,100,0,111,118,101,114,114,105,100,105,110,103,32,115,97,109,112,108,101,95,115,105,122,101,10,0,13,10,0,0,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,112,97,99,107,101,116,95,114,101,112,108,105,99,95,115,105,122,101,32,111,102,32,37,100,10,0,0,0,0,102,114,97,109,101,112,97,99,107,0,0,0,0,0,0,0,102,114,97,109,101,109,100,53,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,51,50,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,0,0,0,0,111,37,100,32,61,32,37,115,10,0,0,0,0,0,0,0,109,97,112,112,105,110,103,115,58,32,0,0,0,0,0,0,84,114,97,110,115,102,101,114,32,102,117,110,99,116,105,111,110,32,105,110,112,117,116,32,118,97,108,117,101,115,32,109,117,115,116,32,98,101,32,105,110,99,114,101,97,115,105,110,103,46,10,0,0,0,0,0,105,101,99,54,49,57,54,54,45,50,45,49,0,0,0,0,68,97,116,117,109,95,71,117,121,97,110,101,95,70,114,97,110,99,97,105,115,101,0,0,101,99,0,0,0,0,0,0,105,102,102,95,105,108,98,109,0,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,102,111,114,99,101,95,107,101,121,95,102,114,97,109,101,115,0,0,0,0,0,0,0,0,70,65,84,65,76,32,101,114,114,111,114,44,32,102,105,108,101,32,100,117,114,97,116,105,111,110,32,116,111,111,32,108,111,110,103,32,102,111,114,32,116,105,109,101,98,97,115,101,44,32,116,104,105,115,32,102,105,108,101,32,119,105,108,108,32,110,111,116,32,98,101,10,112,108,97,121,97,98,108,101,32,119,105,116,104,32,113,117,105,99,107,116,105,109,101,46,32,67,104,111,111,115,101,32,97,32,100,105,102,102,101,114,101,110,116,32,116,105,109,101,98,97,115,101,32,111,114,32,97,32,100,105,102,102,101,114,101,110,116,10,99,111,110,116,97,105,110,101,114,32,102,111,114,109,97,116,10,0,0,0,113,117,97,114,116,101,114,32,111,102,32,115,105,110,101,32,119,97,118,101,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,118,105,100,101,111,47,120,45,109,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,115,117,98,115,105,122,101,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,115,101,116,32,109,111,114,112,104,32,121,32,102,114,101,113,117,101,110,99,121,0,0,0,114,97,116,105,111,0,0,0,37,102,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,101,101,100,32,102,111,114,32,102,105,108,108,105,110,103,32,116,104,101,32,105,110,105,116,105,97,108,32,103,114,105,100,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,86,105,100,101,111,32,111,102,32,108,101,115,115,32,116,104,97,110,32,51,32,99,111,108,117,109,110,115,32,111,114,32,108,105,110,101,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,73,109,112,111,115,115,105,98,108,101,32,81,80,32,99,111,110,115,116,114,97,105,110,116,115,32,102,111,114,32,67,81,77,32,40,109,105,110,61,37,100,44,32,109,97,120,61,37,100,41,10,0,0,0,0,0,115,112,101,99,105,102,121,32,119,104,101,110,32,116,111,32,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,98,108,117,114,0,0,0,0,98,116,49,51,54,49,101,0,68,97,116,117,109,95,71,97,114,111,117,97,0,0,0,0,115,108,105,99,101,95,99,111,117,110,116,0,0,0,0,0,111,102,102,0,0,0,0,0,66,105,110,107,32,118,105,100,101,111,0,0,0,0,0,0,115,116,114,101,97,109,73,110,100,101,120,58,118,97,108,117,101,0,0,0,0,0,0,0,97,110,97,103,108,121,112,104,32,103,114,101,101,110,32,109,97,103,101,110,116,97,32,99,111,108,111,114,0,0,0,0,69,66,77,76,32,98,108,111,99,107,32,100,97,116,97,32,101,114,114,111,114,10,0,0,109,52,118,32,100,101,109,117,120,101,114,0,0,0,0,0,111,117,116,95,99,111,108,111,114,95,109,97,116,114,105,120,0,0,0,0,0,0,0,0,117,115,101,32,98,105,108,105,110,101,97,114,32,105,110,116,101,114,112,111,108,97,116,105,111,110,0,0,0,0,0,0,103,111,116,32,112,97,99,107,101,116,32,119,105,116,104,32,105,108,108,101,103,97,108,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,117,10,0,0,0,0,0,0,0,0,115,104,111,119,32,104,101,108,112,0,0,0,0,0,0,0,37,100,32,115,116,114,101,97,109,115,0,0,0,0,0,0,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,95,116,121,112,101,10,0,0,0,0,0,0,111,117,116,95,104,0,0,0,65,99,116,105,111,110,32,116,111,32,116,97,107,101,32,119,104,101,110,32,101,110,99,111,117,110,116,101,114,105,110,103,32,69,79,70,32,102,114,111,109,32,115,101,99,111,110,100,97,114,121,32,105,110,112,117,116,32,0,0,0,0,0,0,97,45,62,121,95,99,114,111,112,95,104,101,105,103,104,116,32,61,61,32,98,45,62,121,95,99,114,111,112,95,104,101,105,103,104,116,0,0,0,0,97,117,100,105,111,47,77,80,52,65,45,76,65,84,77,0,99,49,115,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,97,117,100,105,111,32,99,111,100,101,99,10,0,0,0,0,0,0,0,0,102,102,95,118,102,95,110,101,120,116,95,112,117,116,95,105,109,97,103,101,10,0,0,0,46,47,118,112,56,47,99,111,109,109,111,110,47,111,110,121,120,46,104,0,0,0,0,0,116,101,120,116,47,120,45,106,97,99,111,115,117,98,0,0,105,101,99,54,49,57,54,54,45,50,45,52,0,0,0,0,68,97,116,117,109,95,71,97,110,100,97,106,105,107,97,95,49,57,55,48,0,0,0,0,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,65,65,78,32,73,68,67,84,0,48,0,0,0,0,0,0,0,98,105,110,107,118,105,100,101,111,0,0,0,0,0,0,0,115,101,116,32,82,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,115,115,95,110,117,109,98,101,114,95,108,97,121,101,114,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,86,80,88,95,83,83,95,77,65,88,95,76,65,89,69,82,83,93,0,0,0,0,92,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,118,97,108,117,101,32,111,102,32,97,110,32,111,117,116,102,105,108,101,32,115,116,114,101,97,109,105,100,0,0,0,0,83,104,97,114,112,110,101,115,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,55,93,0,0,0,0,70,111,114,109,97,116,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,101,120,97,99,116,108,121,32,111,110,101,32,118,105,100,101,111,32,115,116,114,101,97,109,10,0,0,115,101,116,32,100,105,115,112,108,97,121,32,109,111,100,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,114,97,116,101,10,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,98,108,117,101,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,48,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,104,108,100,114,95,116,121,112,101,32,102,111,114,32,37,115,32,47,32,48,120,37,48,52,88,44,32,119,114,105,116,105,110,103,32,100,117,109,109,121,32,118,97,108,117,101,115,10,0,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,103,114,111,119,32,112,97,99,107,101,116,10,0,0,37,100,0,0,0,0,0,0,109,111,100,101,0,0,0,0,99,108,82,101,108,101,97,115,101,80,114,111,103,114,97,109,0,0,0,0,0,0,0,0,115,101,116,32,99,111,108,111,114,0,0,0,0,0,0,0,97,114,103,98,0,0,0,0,66,117,114,108,121,87,111,111,100,0,0,0,0,0,0,0,115,102,44,105,114,99,97,109,0,0,0,0,0,0,0,0,108,116,0,0,0,0,0,0,79,112,116,105,111,110,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,0,84,67,0,0,0,0,0,0,100,97,114,0,0,0,0,0,108,117,109,32,115,114,99,87,61,37,100,32,115,114,99,72,61,37,100,32,100,115,116,87,61,37,100,32,100,115,116,72,61,37,100,32,120,73,110,99,61,37,100,32,121,73,110,99,61,37,100,10,0,0,0,0,102,117,108,108,32,99,104,114,111,109,97,32,105,110,112,117,116,0,0,0,0,0,0,0,115,102,44,105,114,99,97,109,0,0,0,0,0,0,0,0,115,45,62,111,117,116,46,99,104,95,99,111,117,110,116,0,104,49,0,0,0,0,0,0,115,101,116,32,109,111,116,105,111,110,32,115,101,97,114,99,104,32,98,108,111,99,107,115,105,122,101,0,0,0,0,0,67,97,110,32,110,111,116,32,114,101,97,100,32,97,117,100,105,111,32,112,97,99,107,101,116,32,98,101,102,111,114,101,97,117,100,105,111,32,99,111,100,101,99,32,105,115,32,107,110,111,119,110,10,0,0,0,102,112,115,0,0,0,0,0,68,101,102,97,117,108,116,0,84,104,101,32,105,110,112,117,116,32,110,101,101,100,115,32,97,32,99,111,110,115,116,97,110,116,32,102,114,97,109,101,32,114,97,116,101,59,32,99,117,114,114,101,110,116,32,114,97,116,101,32,111,102,32,37,100,47,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,99,103,105,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,68,117,99,107,32,68,75,52,0,0,0,0,0,0,119,101,105,103,104,116,112,61,37,100,0,0,0,0,0,0,100,115,117,114,95,109,111,100,101,0,0,0,0,0,0,0,100,115,117,114,95,109,111,100,101,0,0,0,0,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,116,104,101,32,97,117,100,105,111,32,98,108,111,99,107,10,0,73,110,118,97,108,105,100,32,98,115,95,115,116,111,112,95,102,114,101,113,58,32,37,100,10,0,0,0,0,0,0,0,84,119,111,32,108,111,111,112,32,115,101,97,114,99,104,105,110,103,32,109,101,116,104,111,100,0,0,0,0,0,0,0,65,65,67,32,76,68,32,105,115,32,111,110,108,121,32,100,101,102,105,110,101,100,32,102,111,114,32,79,78,76,89,95,76,79,78,71,95,83,69,81,85,69,78,67,69,32,98,117,116,32,119,105,110,100,111,119,32,115,101,113,117,101,110,99,101,32,37,100,32,102,111,117,110,100,46,10,0,0,0,0,109,118,32,111,117,116,32,111,102,32,112,105,99,10,0,0,48,46,51,48,49,47,48,46,49,57,54,32,48,46,53,57,50,47,48,46,54,32,48,46,54,56,54,47,48,46,55,51,55,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,117,98,102,114,97,109,101,115,32,37,105,10,0,108,111,103,51,49,54,0,0,68,97,116,117,109,95,70,97,104,117,100,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,84,111,111,32,115,109,97,108,108,32,69,88,84,82,65,66,73,84,83,10,0,0,0,0,102,97,97,110,105,0,0,0,102,105,108,116,101,114,95,108,105,109,105,116,32,60,32,49,50,56,85,0,0,0,0,0,97,0,0,0,0,0,0,0,37,117,46,32,109,97,112,112,105,110,103,32,115,101,116,117,112,32,100,97,116,97,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,83,49,58,0,0,0,0,0,72,105,103,104,32,52,58,52,58,52,32,73,110,116,114,97,0,0,0,0,0,0,0,0,66,32,70,105,101,108,100,115,10,0,0,0,0,0,0,0,68,101,108,117,120,101,32,80,97,105,110,116,32,65,110,105,109,97,116,105,111,110,0,0,115,101,116,32,116,104,101,32,114,101,100,32,103,97,105,110,32,102,111,114,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,0,0,100,105,109,101,110,115,105,111,110,115,32,110,111,116,32,115,101,116,10,0,0,0,0,0,98,109,112,44,100,112,120,44,106,108,115,44,106,112,101,103,44,106,112,103,44,108,106,112,103,44,112,97,109,44,112,98,109,44,112,99,120,44,112,103,109,44,112,103,109,121,117,118,44,112,110,103,44,112,112,109,44,115,103,105,44,116,103,97,44,116,105,102,44,116,105,102,102,44,106,112,50,44,106,50,99,44,106,50,107,44,120,119,100,44,115,117,110,44,114,97,115,44,114,115,44,105,109,49,44,105,109,56,44,105,109,50,52,44,115,117,110,114,97,115,44,119,101,98,112,44,120,98,109,44,120,102,97,99,101,0,73,110,118,97,108,105,100,32,108,117,109,97,32,114,97,100,105,117,115,32,118,97,108,117,101,32,37,100,44,32,109,117,115,116,32,98,101,32,62,61,32,48,32,97,110,100,32,60,61,32,37,100,10,0,0,0,115,116,114,101,97,109,105,100,0,0,0,0,0,0,0,0,80,114,111,106,70,97,108,115,101,69,97,115,116,105,110,103,71,101,111,75,101,121,0,0,74,80,69,71,32,99,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,60,117,62,0,0,0,0,0,60,47,37,115,62,0,0,0,97,110,100,0,0,0,0,0,101,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,115,10,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,114,97,116,101,99,111,110,116,114,111,108,46,99,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,44,32,101,120,112,101,99,116,105,110,103,32,81,68,67,65,10,0,0,0,0,0,0,113,117,97,110,116,95,109,97,116,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,0,0,115,97,114,0,0,0,0,0,84,105,109,101,67,111,100,101,72,97,110,100,108,101,114,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,112,97,115,115,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,0,0,0,98,116,0,0,0,0,0,0,98,105,116,114,97,116,101,32,97,98,111,118,101,32,109,97,120,32,98,105,116,114,97,116,101,10,0,0,0,0,0,0,111,117,116,37,100,0,0,0,65,0,0,0,0,0,0,0,98,105,116,115,95,108,101,102,116,61,37,100,10,0,0,0,98,105,116,115,95,108,101,102,116,61,37,100,10,0,0,0,83,105,109,117,108,97,116,101,32,101,114,114,111,114,115,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,32,116,111,32,116,101,115,116,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,46,0,0,0,0,0,70,71,83,32,98,112,32,115,116,97,114,116,0,0,0,0,83,84,65,82,84,80,84,83,0,0,0,0,0,0,0,0,113,112,95,114,100,0,0,0,115,108,105,99,101,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,0,70,105,108,116,101,114,115,32,109,97,121,32,99,104,97,110,103,101,32,111,110,108,121,32,111,110,99,101,32,112,101,114,32,97,99,99,101,115,115,32,117,110,105,116,46,10,0,0,67,97,110,32,110,111,116,32,112,114,111,99,101,115,115,32,83,79,83,32,98,101,102,111,114,101,32,83,79,70,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,105,109,97,103,101,50,112,105,112,101,0,0,0,0,0,0,97,113,45,109,111,100,101,0,86,80,56,69,95,83,69,84,95,67,80,85,85,83,69,68,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,102,111,114,109,97,116,32,102,111,114,32,77,83,90,72,32,40,37,100,41,46,10,0,0,110,114,101,115,108,101,118,101,108,115,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,37,72,58,37,77,0,0,0,66,97,100,32,72,50,54,51,32,105,100,10,0,0,0,0,67,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,99,111,108,111,114,32,112,108,97,110,101,115,33,10,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,73,110,118,97,108,105,100,32,101,110,100,32,116,105,109,101,32,39,37,115,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,58,32,99,97,110,110,111,116,32,98,101,32,108,101,115,115,101,114,32,116,104,97,110,32,115,116,97,114,116,32,116,105,109,101,32,39,37,115,39,10,0,0,0,73,110,118,97,108,105,100,32,99,111,100,101,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,46,10,0,0,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,80,79,67,32,99,104,97,110,103,101,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,58,32,37,100,32,45,62,32,37,100,10,0,0,0,108,111,110,103,32,116,101,114,109,32,108,105,115,116,58,10,0,0,0,0,0,0,0,0,67,65,66,65,67,0,0,0,80,73,67,84,95,84,89,80,69,95,66,0,0,0,0,0,67,111,110,115,116,114,97,105,110,101,100,32,66,97,115,101,108,105,110,101,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,56,45,108,101,118,101,108,0,32,32,83,97,109,112,108,101,114,97,116,101,58,32,37,100,10,0,0,0,0,0,0,0,99,111,100,101,114,0,0,0,77,105,115,115,105,110,103,32,98,108,117,101,32,99,104,97,110,110,101,108,10,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,112,105,99,116,117,114,101,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,10,0,0,0,0,0,0,0,0,68,84,83,32,101,120,116,101,110,115,105,111,110,115,32,100,101,116,101,99,116,105,111,110,32,109,105,115,109,97,116,99,104,32,40,37,100,44,32,37,100,41,10,0,0,0,0,0,115,117,98,112,97,99,107,101,116,115,32,62,32,37,100,0,54,52,48,120,52,56,48,0,115,97,114,95,100,101,110,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,108,111,103,49,48,48,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,115,97,109,112,108,101,95,114,97,116,101,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,0,0,0,68,97,116,117,109,95,69,117,114,111,112,101,97,110,95,68,97,116,117,109,95,49,57,56,55,0,0,0,0,0,0,0,120,118,105,100,109,109,120,0,84,114,105,112,45,72,111,112,0,0,0,0,0,0,0,0,87,77,47,77,101,100,105,97,83,116,97,116,105,111,110,67,97,108,108,83,105,103,110,0,97,110,109,0,0,0,0,0,65,108,108,32,108,97,121,111,117,116,115,32,115,101,116,32,111,110,32,110,111,110,45,101,109,112,116,121,32,108,105,115,116,10,0,0,0,0,0,0,67,97,110,110,111,116,32,104,97,110,100,108,101,32,52,58,52,58,52,58,52,32,89,85,86,52,77,80,69,71,32,115,116,114,101,97,109,46,10,0,37,108,108,105,0,0,0,0,99,111,100,105,110,103,95,104,105,115,116,111,114,121,0,0,116,105,109,101,95,114,101,102,101,114,101,110,99,101,0,0,76,65,66,76,0,0,0,0,106,112,115,0,0,0,0,0,112,97,114,115,101,114,32,110,111,116,32,102,111,117,110,100,32,102,111,114,32,99,111,100,101,99,32,37,115,44,32,112,97,99,107,101,116,115,32,111,114,32,116,105,109,101,115,32,109,97,121,32,98,101,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,111,99,118,0,0,0,0,0,78,111,32,111,112,116,105,111,110,32,102,111,117,110,100,32,110,101,97,114,32,34,37,115,34,10,0,0,0,0,0,0,102,114,97,103,95,99,117,115,116,111,109,0,0,0,0,0,102,111,114,109,97,116,0,0,102,111,114,99,101,32,116,104,101,32,115,101,108,101,99,116,101,100,32,102,114,97,109,101,114,97,116,101,44,32,100,105,115,97,98,108,101,32,116,104,101,32,98,101,115,116,32,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,114,97,116,101,32,115,101,108,101,99,116,105,111,110,0,0,0,0,97,117,100,105,111,47,105,76,66,67,0,0,0,0,0,0,72,105,110,116,72,97,110,100,108,101,114,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,114,97,109,101,32,114,97,116,101,32,109,117,115,116,32,98,101,32,105,110,116,101,103,101,114,10,0,0,0,0,0,32,32,117,110,107,110,111,119,110,32,82,111,81,32,99,104,117,110,107,32,40,37,48,52,88,41,10,0,0,0,0,0,105,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,10,0,0,0,0,0,0,108,105,110,101,97,114,0,0,68,97,116,117,109,95,69,117,114,111,112,101,97,110,95,68,97,116,117,109,95,49,57,53,48,0,0,0,0,0,0,0,105,112,112,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,32,49,48,45,98,105,116,0,102,111,114,99,101,95,102,112,115,0,0,0,0,0,0,0,102,100,101,98,117,103,0,0,102,108,97,116,32,102,111,114,109,97,116,0,0,0,0,0,114,102,99,50,49,57,48,0,104,105,110,116,0,0,0,0,112,105,110,107,0,0,0,0,83,112,101,99,105,102,121,32,82,84,80,32,112,97,121,108,111,97,100,32,116,121,112,101,0,0,0,0,0,0,0,0,115,117,98,95,112,97,99,107,101,116,95,115,105,122,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,108,111,103,0,0,0,0,0,97,117,100,105,111,47,103,55,50,51,0,0,0,0,0,0,84,67,79,77,0,0,0,0,102,105,101,108,100,111,114,100,101,114,0,0,0,0,0,0,98,116,52,55,48,109,0,0,68,97,116,117,109,95,69,103,121,112,116,95,49,57,48,55,0,0,0,0,0,0,0,0,117,51,50,108,101,0,0,0,105,109,97,103,101,47,118,110,100,46,109,105,99,114,111,115,111,102,116,46,105,99,111,110,0,0,0,0,0,0,0,0,115,105,109,112,108,101,97,108,112,104,97,0,0,0,0,0,114,50,49,48,0,0,0,0,99,111,100,101,99,32,37,100,0,0,0,0,0,0,0,0,117,51,50,108,101,0,0,0,105,110,118,97,108,105,100,32,99,104,117,110,107,32,115,105,122,101,58,32,37,117,44,32,111,102,102,115,101,116,58,32,37,117,10,0,0,0,0,0,115,104,111,119,32,81,80,32,104,105,115,116,111,103,114,97,109,0,0,0,0,0,0,0,98,102,0,0,0,0,0,0,100,111,110,39,116,32,109,101,114,103,101,32,115,105,100,101,32,100,97,116,97,0,0,0,37,115,58,32,37,115,10,0,116,104,101,111,114,97,0,0,83,117,98,116,105,116,108,101,72,97,110,100,108,101,114,0,109,51,117,56,0,0,0,0,87,105,100,116,104,0,0,0,83,97,109,112,108,101,82,97,116,101,0,0,0,0,0,0,77,88,70,32,68,45,49,48,32,111,110,108,121,32,115,117,112,112,111,114,116,32,49,54,32,111,114,32,50,52,32,98,105,116,115,32,108,101,32,97,117,100,105,111,10,0,0,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,73,110,100,101,120,84,97,98,108,101,83,101,103,109,101,110,116,32,112,111,105,110,116,101,114,32,97,114,114,97,121,10,0,0,0,0,0,81,95,84,69,77,80,79,82,65,76,0,0,0,0,0,0,78,111,119,32,114,101,99,101,105,118,105,110,103,32,112,108,97,121,108,105,115,116,32,37,100,10,0,0,0,0,0,0,104,101,118,99,44,104,50,54,53,44,50,54,53,0,0,0,102,114,97,109,101,32,115,105,122,101,32,110,111,116,32,115,101,116,10,0,0,0,0,0,98,116,50,48,50,48,99,0,68,97,116,117,109,95,68,111,117,97,108,97,0,0,0,0,97,118,97,105,108,95,115,112,97,99,101,32,62,61,32,115,45,62,112,97,99,107,101,116,95,115,105,122,101,32,124,124,32,105,103,110,111,114,101,95,99,111,110,115,116,114,97,105,110,116,115,0,0,0,0,0,115,105,109,112,108,101,110,101,111,110,0,0,0,0,0,0,67,68,32,71,114,97,112,104,105,99,115,32,118,105,100,101,111,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,97,117,100,105,111,32,115,116,114,101,97,109,46,32,69,120,97,99,116,108,121,32,111,110,101,32,77,80,51,32,97,117,100,105,111,32,115,116,114,101,97,109,32,105,115,32,114,101,113,117,105,114,101,100,46,10,0,0,0,0,0,0,0,0,113,112,104,105,115,116,0,0,37,115,47,105,110,100,101,120,46,102,52,109,0,0,0,0,104,50,54,108,44,104,50,54,52,44,50,54,52,44,97,118,99,0,0,0,0,0,0,0,115,98,116,108,0,0,0,0,73,83,77,86,47,73,83,77,65,32,40,83,109,111,111,116,104,32,83,116,114,101,97,109,105,110,103,41,0,0,0,0,104,50,54,51,32,100,101,109,117,120,101,114,0,0,0,0,103,114,111,117,112,105,110,103,0,0,0,0,0,0,0,0,69,88,84,58,47,80,68,82,47,100,101,102,97,117,108,116,47,69,83,46,0,0,0,0,98,121,116,101,115,32,60,61,32,56,0,0,0,0,0,0,117,110,100,0,0,0,0,0,115,121,110,99,32,108,111,115,116,10,0,0,0,0,0,0,98,116,50,48,50,48,110,99,0,0,0,0,0,0,0,0,68,97,116,117,109,95,68,101,105,114,95,101,122,95,90,111,114,0,0,0,0,0,0,0,102,114,97,109,101,95,115,105,122,101,0,0,0,0,0,0,103,115,109,32,100,101,109,117,120,101,114,0,0,0,0,0,115,105,109,112,108,101,97,114,109,118,54,0,0,0,0,0,112,116,120,0,0,0,0,0,99,100,103,114,97,112,104,105,99,115,0,0,0,0,0,0,108,122,119,32,109,105,110,105,109,117,109,32,99,111,100,101,32,115,105,122,101,32,109,117,115,116,32,98,101,32,62,61,32,49,10,0,0,0,0,0,102,111,114,99,101,32,118,105,100,101,111,32,116,97,103,47,102,111,117,114,99,99,0,0,84,83,83,69,0,0,0,0,48,120,0,0,0,0,0,0,37,115,47,115,116,114,101,97,109,37,100,95,116,101,109,112,0,0,0,0,0,0,0,0,105,109,97,103,101,47,103,105,102,0,0,0,0,0,0,0,67,108,111,115,101,100,67,97,112,116,105,111,110,72,97,110,100,108,101,114,0,0,0,0,78,111,32,98,105,116,114,97,116,101,32,115,112,101,99,105,102,105,101,100,46,32,65,115,115,117,109,105,110,103,32,56,48,48,48,32,98,47,115,10,0,0,0,0,0,0,0,0,116,99,111,44,114,99,111,44,103,55,50,51,95,49,0,0,68,97,116,97,32,99,111,100,101,99,32,39,37,115,39,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,0,0,0,103,55,50,50,44,55,50,50,0,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,35,116,98,32,37,100,58,32,37,100,47,37,100,10,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,114,101,118,105,115,105,111,110,50,61,37,105,0,0,0,0,0,0,0,37,100,44,32,37,49,48,108,108,100,44,32,37,49,48,108,108,100,44,32,37,56,100,44,32,37,56,100,44,32,48,120,37,48,56,120,0,0,0,0,115,95,115,105,122,101,61,32,37,56,46,48,102,107,66,32,116,105,109,101,61,32,37,48,46,51,102,32,98,114,61,32,37,55,46,49,102,107,98,105,116,115,47,115,32,97,118,103,95,98,114,61,32,37,55,46,49,102,107,98,105,116,115,47,115,32,0,0,0,0,0,0,115,115,101,103,109,101,110,116,0,0,0,0,0,0,0,0,89,67,103,67,111,0,0,0,68,97,116,117,109,95,67,111,116,101,95,100,95,73,118,111,105,114,101,0,0,0,0,0,115,105,109,112,108,101,97,114,109,118,53,116,101,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,118,50,0,0,0,118,116,97,103,0,0,0,0,115,116,114,102,0,0,0,0,111,118,101,114,114,105,100,105,110,103,32,105,110,118,97,108,105,100,32,100,115,104,111,119,95,98,108,111,99,107,95,97,108,105,103,110,32,111,102,32,37,100,10,0,0,0,0,0,116,111,111,32,108,111,110,103,32,112,97,121,108,111,97,100,10,0,0,0,0,0,0,0,99,108,99,112,0,0,0,0,118,105,100,101,111,47,120,45,102,108,118,0,0,0,0,0,115,101,108,101,99,116,32,56,45,98,105,116,32,102,105,120,101,100,45,112,111,105,110,116,0,0,0,0,0,0,0,0,115,107,105,112,112,105,110,103,32,102,108,118,32,112,97,99,107,101,116,58,32,116,121,112,101,32,37,100,44,32,115,105,122,101,32,37,100,44,32,102,108,97,103,115,32,37,100,10,0,0,0,0,0,0,0,0,70,105,108,101,32,119,105,116,104,32,110,111,32,115,112,101,99,105,102,105,101,100,32,119,105,100,116,104,47,104,101,105,103,104,116,46,32,84,114,121,105,110,103,32,54,52,48,120,52,56,48,46,10,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,99,104,97,110,110,101,108,32,102,111,114,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,39,37,115,39,46,10,0,0,73,110,118,97,108,105,100,32,97,110,100,47,111,114,32,109,105,115,115,105,110,103,32,105,110,112,117,116,47,111,117,116,112,117,116,32,118,97,108,117,101,46,10,0,0,0,0,0,115,109,112,116,101,50,52,48,109,0,0,0,0,0,0,0,68,97,116,117,109,95,67,111,114,114,101,103,111,95,65,108,101,103,114,101,0,0,0,0,115,105,109,112,108,101,97,114,109,0,0,0,0,0,0,0,102,108,97,115,104,115,118,50,0,0,0,0,0,0,0,0,115,101,116,32,99,101,110,116,114,97,108,32,102,114,101,113,117,101,110,99,121,0,0,0,97,117,100,105,111,47,120,45,102,108,97,99,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,46,10,0,0,0,0,0,0,0,0,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,0,102,108,109,0,0,0,0,0,102,108,109,0,0,0,0,0,83,111,117,110,100,72,97,110,100,108,101,114,0,0,0,0,116,114,117,110,99,97,116,101,0,0,0,0,0,0,0,0,113,115,105,110,0,0,0,0,52,52,49,48,48,0,0,0,102,102,109,101,116,97,0,0,114,0,0,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,104,0,0,0,0,0,0,0,109,111,114,112,104,121,102,0,91,83,84,82,69,65,77,93,0,0,0,0,0,0,0,0,115,101,116,32,102,105,108,108,32,114,97,116,105,111,32,102,111,114,32,102,105,108,108,105,110,103,32,105,110,105,116,105,97,108,32,103,114,105,100,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,0,0,45,118,111,108,32,104,97,115,32,98,101,101,110,32,100,101,112,114,101,99,97,116,101,100,46,32,85,115,101,32,116,104,101,32,118,111,108,117,109,101,32,97,117,100,105,111,32,102,105,108,116,101,114,32,105,110,115,116,101,97,100,46,10,0,114,97,110,100,111,109,95,115,101,101,100,0,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,100,101,102,97,117,108,116,0,105,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,10,0,0,0,0,0,0,0,0,101,118,97,108,0,0,0,0,112,97,102,44,102,97,112,0,110,111,110,101,0,0,0,0,115,109,112,116,101,49,55,48,109,0,0,0,0,0,0,0,68,97,116,117,109,95,67,104,117,97,0,0,0,0,0,0,115,104,52,0,0,0,0,0,111,110,0,0,0,0,0,0,70,111,114,119,97,114,100,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,105,110,116,114,97,95,100,99,95,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,97,103,109,99,0,0,0,0,118,105,100,101,111,32,104,101,97,100,101,114,32,102,111,108,108,111,119,101,100,32,98,121,32,97,117,100,105,111,32,112,97,99,107,101,116,0,0,0,99,100,97,116,97,0,0,0,97,117,116,111,0,0,0,0,102,97,105,108,101,100,32,114,101,97,100,105,110,103,32,99,104,117,110,107,32,116,121,112,101,10,0,0,0,0,0,0,115,111,117,110,0,0,0,0,98,105,108,105,110,101,97,114,0,0,0,0,0,0,0,0,67,97,110,39,116,32,112,114,111,99,101,115,115,32,68,86,32,102,114,97,109,101,32,35,37,100,46,32,73,110,115,117,102,102,105,99,105,101,110,116,32,97,117,100,105,111,32,100,97,116,97,32,111,114,32,115,101,118,101,114,101,32,115,121,110,99,32,112,114,111,98,108,101,109,46,10,0,0,0,0,104,0,0,0,0,0,0,0,109,111,100,101,61,37,99,32,116,100,105,102,102,61,37,102,32,98,100,105,102,102,61,37,102,32,112,100,105,102,102,61,37,102,10,0,0,0,0,0,100,101,102,97,117,108,116,0,111,119,0,0,0,0,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,101,111,102,95,97,99,116,105,111,110,0,0,0,0,0,0,97,45,62,121,95,99,114,111,112,95,119,105,100,116,104,32,61,61,32,98,45,62,121,95,99,114,111,112,95,119,105,100,116,104,0,0,0,0,0,0,99,104,117,110,107,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,10,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,118,102,45,62,110,101,120,116,0,0,0,0,0,0,0,0,100,110,120,104,100,32,100,101,109,117,120,101,114,0,0,0,100,105,114,97,99,32,100,101,109,117,120,101,114,0,0,0,48,0,0,0,0,0,0,0,98,116,52,55,48,98,103,0,68,97,116,117,109,95,67,97,114,116,104,97,103,101,0,0,97,114,109,0,0,0,0,0,84,111,111,32,108,97,114,103,101,32,72,97,108,100,32,67,76,85,84,32,40,109,97,120,105,109,117,109,32,108,101,118,101,108,32,105,115,32,37,100,44,32,111,114,32,37,100,120,37,100,32,67,76,85,84,41,10,0,0,0,0,0,0,0,84,111,111,32,108,97,114,103,101,32,99,104,117,110,107,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,102,114,119,117,0,0,0,0,114,0,0,0,0,0,0,0,51,48,50,44,100,97,117,100,0,0,0,0,0,0,0,0,114,99,95,115,99,97,108,101,100,95,104,101,105,103,104,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,99,102,103,45,62,103,95,104,93,0,0,0,0,0,67,82,67,61,48,120,37,48,56,120,10,0,0,0,0,0,100,99,0,0,0,0,0,0,116,111,107,101,110,95,112,97,114,116,105,116,105,111,110,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,86,80,56,95,79,78,69,95,84,79,75,69,78,80,65,82,84,73,84,73,79,78,46,46,86,80,56,95,69,73,71,72,84,95,84,79,75,69,78,80,65,82,84,73,84,73,79,78,93,0,0,0,0,0,0,0,0,100,105,115,112,108,97,121,95,109,111,100,101,0,0,0,0,99,98,95,101,120,112,114,0,86,105,100,101,111,72,97,110,100,108,101,114,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,111,112,101,110,32,39,37,115,39,10,0,0,0,0,0,0,0,0,99,100,120,108,44,120,108,0,97,115,115,117,109,101,32,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,0,99,108,82,101,108,101,97,115,101,77,101,109,79,98,106,101,99,116,0,0,0,0,0,0,99,111,108,111,114,0,0,0,110,118,50,49,0,0,0,0,99,97,118,115,118,105,100,101,111,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,66,114,111,119,110,0,0,0,108,116,101,0,0,0,0,0,79,80,84,73,79,78,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,0,115,105,100,101,32,114,105,103,104,116,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,46,10,0,0,0,0,0,37,100,120,37,100,32,45,62,32,37,100,120,37,100,10,0,102,117,108,108,95,99,104,114,111,109,97,95,105,110,112,0,115,45,62,117,115,101,100,95,99,104,95,99,111,117,110,116,0,0,0,0,0,0,0,0,118,100,101,98,108,111,99,107,0,0,0,0,0,0,0,0,98,108,111,99,107,115,105,122,101,0,0,0,0,0,0,0,97,117,100,105,111,47,120,45,99,97,102,0,0,0,0,0,92,125,0,0,0,0,0,0,100,101,102,97,117,108,116,0,97,100,112,99,109,95,105,109,97,95,100,107,52,0,0,0,119,101,105,103,104,116,112,61,0,0,0,0,0,0,0,0,68,105,97,108,111,103,117,101,32,76,101,118,101,108,32,40,100,66,41,0,0,0,0,0,68,105,97,108,111,103,117,101,32,76,101,118,101,108,32,40,100,66,41,0,0,0,0,0,117,110,97,98,108,101,32,116,111,32,100,101,116,101,114,109,105,110,101,32,99,104,97,110,110,101,108,32,109,111,100,101,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,102,111,114,32,83,66,82,58,32,37,100,10,0,0,0,0,116,119,111,108,111,111,112,0,100,101,115,99,32,99,104,117,110,107,32,110,111,116,32,112,114,101,115,101,110,116,10,0,82,101,115,101,114,118,101,100,32,98,105,116,32,115,101,116,46,10,0,0,0,0,0,0,115,116,97,114,116,32,60,61,32,115,114,99,32,38,38,32,115,114,99,32,60,61,32,101,110,100,0,0,0,0,0,0,48,47,49,32,49,47,48,0,49,52,45,98,105,116,32,98,108,111,99,107,32,115,105,122,101,115,0,0,0,0,0,0,77,111,114,101,32,116,104,97,110,32,37,100,32,99,104,97,110,110,101,108,115,0,0,0,102,99,99,0,0,0,0,0,68,97,116,117,109,95,67,97,112,101,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,108,111,97,116,32,105,110,102,111,114,109,97,116,105,111,110,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,115,105,109,112,108,101,109,109,120,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,111,104,0,0,0,0,0,0,109,97,112,112,105,110,103,95,115,101,116,117,112,45,62,97,110,103,108,101,91,106,93,0,105,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,115,105,122,101,32,37,117,10,0,0,0,0,0,0,0,0,83,50,58,0,0,0,0,0,72,105,103,104,32,52,58,50,58,50,0,0,0,0,0,0,83,75,73,80,77,66,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,97,100,99,111,119,32,86,105,100,101,111,0,0,0,0,97,114,0,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,119,105,116,104,32,37,100,32,99,104,97,110,110,101,108,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,110,117,109,98,101,114,32,111,102,32,115,112,101,99,105,102,105,101,100,32,99,104,97,110,110,101,108,115,32,37,100,10,0,0,0,0,105,110,118,97,108,105,100,32,98,121,116,101,32,111,114,100,101,114,58,32,37,88,10,0,108,117,109,97,95,114,97,100,105,117,115,58,37,100,32,108,117,109,97,95,112,111,119,101,114,58,37,100,32,99,104,114,111,109,97,95,114,97,100,105,117,115,58,37,100,32,99,104,114,111,109,97,95,112,111,119,101,114,58,37,100,32,97,108,112,104,97,95,114,97,100,105,117,115,58,37,100,32,97,108,112,104,97,95,112,111,119,101,114,58,37,100,32,119,58,37,100,32,99,104,114,111,109,97,95,119,58,37,100,32,104,58,37,100,32,99,104,114,111,109,97,95,104,58,37,100,10,0,116,111,112,61,49,47,98,111,116,116,111,109,61,48,47,97,117,116,111,61,45,49,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,80,114,111,106,78,97,116,79,114,105,103,105,110,76,97,116,71,101,111,75,101,121,0,0,83,97,109,112,108,101,115,32,112,101,114,32,112,105,120,101,108,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2392224);
/* memory initializer */ allocate([115,118,113,51,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,60,105,62,0,0,0,0,0,123,92,37,99,37,100,125,0,115,45,62,98,108,111,99,107,115,105,122,101,32,43,32,115,45,62,110,119,114,97,112,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,112,98,32,102,114,97,109,101,0,0,0,0,0,0,0,0,82,101,112,111,114,116,101,100,32,97,117,100,105,111,32,115,105,122,101,32,37,100,32,105,115,32,98,105,103,103,101,114,32,116,104,97,110,32,112,97,99,107,101,116,32,115,105,122,101,32,40,37,100,41,10,0,112,105,99,116,117,114,101,95,110,117,109,98,101,114,32,62,61,32,48,0,0,0,0,0,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,100,101,115,105,114,101,100,32,98,105,116,115,32,112,101,114,32,109,97,99,114,111,98,108,111,99,107,0,0,0,0,0,112,99,109,95,115,56,0,0,119,58,37,100,32,104,58,37,100,32,100,97,114,58,37,100,47,37,100,32,115,97,114,58,37,100,47,37,100,32,45,62,32,100,97,114,58,37,100,47,37,100,32,115,97,114,58,37,100,47,37,100,10,0,0,0,97,118,99,105,110,116,114,97,45,99,108,97,115,115,0,0,118,105,100,101,0,0,0,0,97,117,100,105,111,47,98,105,116,0,0,0,0,0,0,0,115,116,97,114,116,95,102,114,97,109,101,0,0,0,0,0,97,98,0,0,0,0,0,0,98,105,116,114,97,116,101,32,98,101,108,111,119,32,109,105,110,32,98,105,116,114,97,116,101,10,0,0,0,0,0,0,43,0,0,0,0,0,0,0,80,0,0,0,0,0,0,0,111,118,101,114,114,101,97,100,44,32,115,107,105,112,32,37,100,32,101,110,100,100,105,115,116,115,58,32,37,100,32,37,100,10,0,0,0,0,0,0,111,118,101,114,114,101,97,100,44,32,115,107,105,112,32,37,100,32,101,110,100,100,105,115,116,115,58,32,37,100,32,37,100,10,0,0,0,0,0,0,101,114,114,111,114,95,114,97,116,101,0,0,0,0,0,0,82,101,115,101,114,118,101,100,0,0,0,0,0,0,0,0,83,65,77,80,76,69,95,82,65,84,69,0,0,0,0,0,83,116,114,105,99,116,108,121,32,101,110,102,111,114,99,101,32,103,111,112,32,115,105,122,101,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,95,112,114,101,100,95,102,114,97,109,101,95,100,99,116,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,108,112,100,101,99,46,99,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,105,110,103,32,97,110,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,99,111,109,98,105,110,97,116,105,111,110,10,0,0,0,0,0,0,0,0,67,111,110,115,116,97,110,116,32,113,117,97,110,116,105,122,97,116,105,111,110,32,112,97,114,97,109,101,116,101,114,32,114,97,116,101,32,99,111,110,116,114,111,108,32,109,101,116,104,111,100,0,0,0,0,0,78,111,32,99,111,109,112,114,101,115,115,105,111,110,46,10,0,0,0,0,0,0,0,0,77,67,84,32,37,100,32,119,105,116,104,32,116,111,111,32,102,101,119,32,99,111,109,112,111,110,101,110,116,115,32,40,37,100,41,10,0,0,0,0,92,84,0,0,0,0,0,0,66,97,100,32,109,97,114,107,101,114,10,0,0,0,0,0,83,99,97,108,97,98,105,108,105,116,121,58,32,117,110,115,117,112,112,111,114,116,101,100,32,115,117,98,100,105,118,105,115,105,111,110,33,32,76,117,109,97,32,98,97,110,100,115,58,32,37,100,44,32,99,104,114,111,109,97,32,98,97,110,100,115,58,32,37,100,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,118,97,108,105,100,32,101,110,100,32,116,105,109,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,39,37,115,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,10,0,0,0,0,68,105,115,112,108,97,121,105,110,103,32,116,104,101,32,119,104,111,108,101,32,118,105,100,101,111,32,115,117,114,102,97,99,101,46,10,0,0,0,0,73,110,116,101,114,32,115,108,105,99,101,115,32,105,110,32,97,110,32,73,82,65,80,32,102,114,97,109,101,46,10,0,77,77,67,79,32,111,112,99,111,100,101,32,91,37,100,44,32,37,100,93,32,97,116,32,37,100,32,109,105,115,109,97,116,99,104,101,115,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,10,0,0,0,112,112,115,58,37,117,32,115,112,115,58,37,117,32,37,115,32,115,108,105,99,101,95,103,114,111,117,112,115,58,37,100,32,114,101,102,58,37,100,47,37,100,32,37,115,32,113,112,58,37,100,47,37,100,47,37,100,47,37,100,32,37,115,32,37,115,32,37,115,32,37,115,10,0,0,0,0,0,0,0,80,73,67,84,95,84,89,80,69,95,80,0,0,0,0,0,66,97,115,101,108,105,110,101,0,0,0,0,0,0,0,0,66,105,110,97,114,121,32,116,101,120,116,32,100,101,109,117,120,101,114,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,49,46,50,46,53,0,0,0,52,45,108,101,118,101,108,0,32,32,77,97,120,32,70,114,97,109,101,115,105,122,101,58,32,37,100,10,0,0,0,0,33,115,102,45,62,114,99,95,115,116,97,116,50,91,105,93,0,0,0,0,0,0,0,0,103,108,111,98,97,108,58,32,118,101,114,58,37,100,46,37,100,44,32,99,111,100,101,114,58,37,100,44,32,99,111,108,111,114,115,112,97,99,101,58,32,37,100,32,98,112,114,58,37,100,32,99,104,114,111,109,97,58,37,100,40,37,100,58,37,100,41,44,32,97,108,112,104,97,58,37,100,32,115,108,105,99,101,115,58,37,100,120,37,100,32,113,116,97,98,115,58,37,100,32,101,99,58,37,100,32,105,110,116,114,97,58,37,100,10,0,0,0,0,0,77,105,115,115,105,110,103,32,103,114,101,101,110,32,99,104,97,110,110,101,108,10,0,0,78,111,116,32,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,0,0,0,0,77,86,32,112,114,101,99,105,115,105,111,110,32,102,105,110,101,114,32,116,104,97,110,32,101,105,103,104,116,104,45,112,101,108,10,0,0,0,0,0,68,84,83,32,99,111,114,101,32,100,101,116,101,99,116,105,111,110,32,109,105,115,109,97,116,99,104,46,10,0,0,0,84,111,111,32,109,97,110,121,32,115,117,98,112,97,99,107,101,116,115,32,37,100,32,102,111,114,32,99,104,97,110,110,101,108,115,32,37,100,10,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,105,110,100,101,120,32,101,110,116,114,121,32,102,111,114,32,102,114,97,109,101,32,37,108,108,100,10,0,0,0,0,0,0,115,97,114,95,110,117,109,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,97,117,100,105,111,47,118,105,100,101,111,32,111,102,102,115,101,116,115,32,111,114,32,99,104,117,110,107,32,115,105,122,101,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,105,122,101,32,102,111,114,32,115,97,109,112,108,101,95,102,109,116,115,58,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,37,100,10,0,0,0,0,0,68,97,116,117,109,95,67,97,109,112,111,95,73,110,99,104,97,117,115,112,101,0,0,0,115,105,109,112,108,101,0,0,100,105,115,99,97,114,100,105,110,103,32,117,110,117,115,101,100,32,112,97,108,101,116,116,101,10,0,0,0,0,0,0,65,109,98,105,101,110,116,0,116,114,97,99,107,0,0,0,83,101,108,101,99,116,32,73,68,51,118,50,32,118,101,114,115,105,111,110,32,116,111,32,119,114,105,116,101,46,32,67,117,114,114,101,110,116,108,121,32,51,32,97,110,100,32,52,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,0,109,97,100,0,0,0,0,0,81,117,101,114,121,32,102,111,114,109,97,116,32,102,97,105,108,101,100,32,102,111,114,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,0,52,52,52,97,108,112,104,97,0,0,0,0,0,0,0,0,84,104,105,115,32,97,118,115,32,112,114,101,116,101,110,100,32,116,111,32,98,101,32,37,100,120,37,100,32,119,104,101,110,32,116,104,101,32,97,118,115,32,102,111,114,109,97,116,32,105,115,32,115,117,112,112,111,115,101,100,32,116,111,32,98,101,32,51,49,56,120,49,57,56,32,111,110,108,121,46,10,0,0,0,0,0,0,0,37,102,0,0,0,0,0,0,117,109,105,100,0,0,0,0,37,108,108,117,0,0,0,0,103,101,110,114,101,0,0,0,66,101,102,111,114,101,32,97,118,102,111,114,109,97,116,95,102,105,110,100,95,115,116,114,101,97,109,95,105,110,102,111,40,41,32,112,111,115,58,32,37,108,108,100,32,98,121,116,101,115,32,114,101,97,100,58,37,108,108,100,32,115,101,101,107,115,58,37,100,10,0,0,99,104,97,110,32,37,100,0,102,114,101,105,48,114,95,115,114,99,0,0,0,0,0,0,61,0,0,0,0,0,0,0,109,111,118,102,108,97,103,115,0,0,0,0,0,0,0,0,116,111,112,0,0,0,0,0,117,110,100,101,102,0,0,0,68,97,116,117,109,95,67,97,109,97,99,117,112,97,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,108,101,99,116,32,73,68,67,84,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,0,0,0,0,0,0,68,80,88,32,40,68,105,103,105,116,97,108,32,80,105,99,116,117,114,101,32,69,120,99,104,97,110,103,101,41,32,105,109,97,103,101,0,0,0,0,102,105,101,108,100,109,97,116,99,104,0,0,0,0,0,0,78,111,32,85,82,76,32,80,114,111,116,111,99,111,108,115,32,97,114,101,32,114,101,103,105,115,116,101,114,101,100,46,32,77,105,115,115,105,110,103,32,99,97,108,108,32,116,111,32,97,118,95,114,101,103,105,115,116,101,114,95,97,108,108,40,41,63,10,0,0,0,0,99,104,114,111,109,97,95,105,110,116,114,97,95,109,97,116,114,105,120,0,0,0,0,0,100,101,98,117,103,0,0,0,108,105,98,79,112,101,110,67,76,46,115,111,0,0,0,0,102,108,97,116,0,0,0,0,109,104,108,114,0,0,0,0,98,101,108,108,0,0,0,0,118,105,100,101,111,47,120,45,109,115,118,105,100,101,111,0,112,97,121,108,111,97,100,95,116,121,112,101,0,0,0,0,98,97,100,32,83,73,80,82,32,102,105,108,101,32,102,108,97,118,111,114,32,37,100,10,0,0,0,0,0,0,0,0,99,117,98,105,99,32,114,111,111,116,0,0,0,0,0,0,114,97,119,32,71,46,55,50,51,46,49,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,98,116,55,48,57,0,0,0,68,97,116,117,109,95,66,117,107,105,116,95,82,105,109,112,97,104,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,105,100,99,116,0,0,0,0,100,112,120,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,97,117,100,105,111,47,98,97,115,105,99,0,0,0,0,0,115,112,101,99,105,102,121,32,105,110,116,101,114,32,109,97,116,114,105,120,32,99,111,101,102,102,115,0,0,0,0,0,115,101,116,32,103,114,101,101,110,32,102,97,100,101,0,0,107,101,101,112,115,105,100,101,0,0,0,0,0,0,0,0,77,105,115,109,97,116,99,104,105,110,103,32,82,73,68,10,0,0,0,0,0,0,0,0,116,111,116,97,108,32,115,97,109,112,108,101,115,58,32,37,108,108,100,10,0,0,0,0,117,110,107,110,111,119,110,32,99,104,117,110,107,32,37,120,10,0,0,0,0,0,0,0,118,111,114,98,105,115,0,0,68,97,116,97,72,97,110,100,108,101,114,0,0,0,0,0,37,115,37,48,50,100,58,37,48,50,100,58,37,48,50,100,37,99,37,48,50,100,0,0,83,97,109,112,108,101,82,97,116,101,0,0,0,0,0,0,102,105,101,108,100,0,0,0,116,101,120,116,47,120,45,115,115,97,0,0,0,0,0,0,67,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,39,37,115,39,32,97,115,32,109,101,116,97,100,97,116,97,10,0,0,0,0,0,0,0,91,69,118,101,110,116,115,93,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,77,88,70,32,68,45,49,48,32,111,110,108,121,32,115,117,112,112,111,114,116,32,111,110,101,32,97,117,100,105,111,32,116,114,97,99,107,10,0,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,105,110,100,101,120,32,116,97,98,108,101,115,10,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,81,95,83,80,65,84,73,65,76,0,0,0,0,0,0,0,118,105,100,101,111,47,120,45,109,115,45,97,115,102,0,0,97,100,116,115,0,0,0,0,115,116,114,101,97,109,61,37,100,32,115,116,114,101,97,109,95,116,121,112,101,61,37,120,32,112,105,100,61,37,120,32,112,114,111,103,95,114,101,103,95,100,101,115,99,61,37,46,52,115,10,0,0,0,0,0,71,66,82,0,0,0,0,0,68,97,116,117,109,95,66,111,103,111,116,97,0,0,0,0,112,114,101,118,95,102,111,114,99,101,100,95,110,0,0,0,97,118,95,102,105,102,111,95,115,105,122,101,40,115,116,114,101,97,109,45,62,102,105,102,111,41,32,62,32,48,0,0,110,97,109,101,32,32,32,100,101,112,116,104,0,0,0,0,99,111,109,112,114,101,115,115,101,115,32,100,97,114,107,32,97,114,101,97,115,32,115,116,114,111,110,103,101,114,32,116,104,97,110,32,109,101,100,105,117,109,32,111,110,101,115,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,116,105,109,101,115,116,97,109,112,32,108,105,110,101,32,39,37,115,39,44,32,97,98,111,114,116,32,112,97,114,115,105,110,103,10,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,73,68,51,118,50,32,118,101,114,115,105,111,110,32,114,101,113,117,101,115,116,101,100,58,32,37,100,46,32,79,110,108,121,32,51,44,32,52,32,111,114,32,48,32,40,100,105,115,97,98,108,101,100,41,32,97,114,101,32,97,108,108,111,119,101,100,46,10,0,0,0,0,128,0,0,0,0,0,0,0,105,110,116,101,114,95,109,97,116,114,105,120,0,0,0,0,47,100,101,118,47,117,114,97,110,100,111,109,0,0,0,0,100,104,108,114,0,0,0,0,105,115,109,118,0,0,0,0,97,115,102,95,114,101,97,100,95,112,116,115,32,102,97,105,108,101,100,10,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,97,113,116,0,0,0,0,0,98,121,116,101,115,32,62,61,32,110,101,101,100,101,100,95,98,121,116,101,115,0,0,0,84,97,103,32,115,105,122,101,32,105,115,32,119,97,121,32,116,111,111,32,98,105,103,10,0,0,0,0,0,0,0,0,77,97,120,32,69,66,77,76,32,101,108,101,109,101,110,116,32,100,101,112,116,104,32,40,37,100,41,32,114,101,97,99,104,101,100,44,32,99,97,110,110,111,116,32,112,97,114,115,101,32,102,117,114,116,104,101,114,46,10,0,0,0,0,0,97,112,101,44,97,112,108,44,109,97,99,0,0,0,0,0,67,82,89,79,95,65,80,67,0,0,0,0,0,0,0,0,109,97,120,95,112,97,103,101,115,32,33,61,32,50,53,54,0,0,0,0,0,0,0,0,110,111,114,109,97,108,0,0,68,97,116,117,109,95,66,101,114,110,95,49,56,57,56,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,100,97,114,107,95,109,97,115,107,0,0,0,0,0,0,0,97,117,100,105,111,47,97,109,114,0,0,0,0,0,0,0,115,103,105,0,0,0,0,0,118,50,49,48,0,0,0,0,109,97,116,114,105,120,0,0,116,114,97,99,107,0,0,0,65,69,83,45,49,50,56,0,85,110,115,117,112,112,111,114,116,101,100,32,115,116,114,101,97,109,32,116,121,112,101,32,105,110,32,115,116,114,101,97,109,32,37,100,10,0,0,0,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,97,117,100,105,111,32,105,110,32,102,108,118,32,105,115,32,118,97,108,105,100,32,98,117,116,32,109,111,115,116,32,108,105,107,101,108,121,32,117,110,112,108,97,121,97,98,108,101,32,40,104,97,114,100,119,97,114,101,32,100,101,112,101,110,100,101,110,116,41,59,32,117,115,101,32,115,49,54,108,101,10,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,114,101,118,105,115,105,111,110,61,37,105,44,32,114,101,118,105,115,105,111,110,50,61,37,105,0,0,102,95,115,105,122,101,61,32,37,54,100,32,0,0,0,0,115,116,114,105,99,116,0,0,68,97,116,117,109,95,66,101,114,109,117,100,97,95,49,57,53,55,0,0,0,0,0,0,105,110,116,101,114,32,109,97,115,107,105,110,103,0,0,0,50,53,0,0,0,0,0,0,56,48,56,56,102,108,101,120,32,84,77,86,0,0,0,0,115,112,101,99,105,102,121,32,105,110,116,114,97,32,109,97,116,114,105,120,32,99,111,101,102,102,115,0,0,0,0,0,121,117,118,52,50,48,112,0,112,97,99,107,101,116,95,111,98,106,95,115,105,122,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,77,105,99,104,97,101,108,32,78,105,101,100,101,114,109,97,121,101,114,0,0,0,0,0,84,111,98,105,97,115,32,68,105,101,100,114,105,99,104,32,60,114,97,110,109,97,43,109,112,108,97,121,101,114,64,116,100,105,101,100,114,105,99,104,46,100,101,62,0,0,0,0,100,105,115,116,95,115,99,97,108,101,95,102,97,99,116,111,114,32,62,61,32,45,54,51,32,38,38,32,100,105,115,116,95,115,99,97,108,101,95,102,97,99,116,111,114,32,60,61,32,49,50,55,0,0,0,0,77,105,99,104,97,101,108,32,78,105,101,100,101,114,109,97,121,101,114,0,0,0,0,0,115,101,108,101,99,116,32,109,97,116,104,101,109,97,116,105,99,97,108,32,112,114,101,99,105,115,105,111,110,0,0,0,82,105,99,104,97,114,100,32,70,101,108,107,101,114,0,0,32,43,32,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,99,104,97,110,110,101,108,32,37,115,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,105,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,46,10,0,0,0,0,0,0,0,37,108,102,47,37,108,102,0,116,101,109,112,111,114,97,108,0,0,0,0,0,0,0,0,68,97,116,117,109,95,82,101,115,101,97,117,95,78,97,116,105,111,110,97,108,95,66,101,108,103,101,95,49,57,53,48,0,0,0,0,0,0,0,0,77,105,99,104,97,101,108,32,78,105,101,100,101,114,109,97,121,101,114,44,32,78,105,107,111,108,97,106,32,80,111,114,111,115,104,105,110,0,0,0,112,95,109,97,115,107,0,0,116,109,118,0,0,0,0,0,102,114,101,113,117,101,110,99,121,0,0,0,0,0,0,0,72,97,109,112,97,32,72,117,103,44,32,68,97,110,105,101,108,32,77,111,114,101,110,111,44,32,82,105,99,104,97,114,100,32,70,101,108,107,101,114,0,0,0,0,0,0,0,0,105,110,116,114,97,95,109,97,116,114,105,120,0,0,0,0,82,105,99,104,97,114,100,32,70,101,108,107,101,114,0,0,108,105,110,101,97,114,32,115,108,111,112,101,0,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,99,111,100,101,99,10,0,0,0,98,115,105,122,101,32,62,61,32,66,76,79,67,75,95,56,88,56,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,0,0,0,0,0,50,53,0,0,0,0,0,0,102,97,100,101,0,0,0,0,100,101,102,97,117,108,116,0,98,115,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,0,0,0,0,0,115,101,116,32,109,111,114,112,104,32,120,32,102,114,101,113,117,101,110,99,121,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,97,110,100,111,109,95,102,105,108,108,95,114,97,116,105,111,0,0,0,0,0,0,0,114,97,116,105,111,0,0,0,97,114,101,115,97,109,112,108,101,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,100,117,97,108,105,110,112,117,116,46,99,0,111,110,108,121,32,100,101,105,110,116,101,114,108,97,99,101,32,102,114,97,109,101,115,32,109,97,114,107,101,100,32,97,115,32,105,110,116,101,114,108,97,99,101,100,0,0,0,0,98,97,99,107,119,97,114,100,0,0,0,0,0,0,0,0,99,104,114,111,109,97,0,0,115,112,97,116,105,97,108,0,99,111,117,110,116,101,114,99,108,111,99,107,119,105,115,101,0,0,0,0,0,0,0,0,68,97,116,117,109,95,66,101,105,106,105,110,103,95,49,57,53,52,0,0,0,0,0,0,115,112,97,116,105,97,108,32,99,111,109,112,108,101,120,105,116,121,32,109,97,115,107,105,110,103,0,0,0,0,0,0,109,111,100,101,58,37,100,32,102,105,108,116,101,114,58,37,115,32,104,58,37,100,32,45,62,32,104,58,37,100,10,0,118,50,49,48,120,0,0,0,115,114,99,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,102,105,108,116,101,114,115,0,0,0,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,102,111,114,109,97,116,0,0,0,0,0,0,0,110,95,115,97,109,112,108,101,115,58,32,37,108,108,100,10,0,0,0,0,0,0,0,0,115,101,116,32,105,110,112,117,116,32,89,67,98,67,114,32,116,121,112,101,0,0,0,0,76,117,99,105,100,97,32,71,114,97,110,100,101,0,0,0,99,0,0,0,0,0,0,0,37,100,58,37,100,37,99,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,112,104,97,115,101,46,99,0,0,99,117,98,105,99,0,0,0,111,117,116,95,119,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,78,97,78,32,102,111,114,32,118,111,108,117,109,101,10,0,0,0,115,104,111,119,32,108,105,99,101,110,115,101,0,0,0,0,115,101,116,32,116,104,101,32,121,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,87,97,114,110,105,110,103,58,32,68,101,115,105,114,101,100,32,104,101,105,103,104,116,32,116,111,111,32,108,97,114,103,101,44,32,99,104,97,110,103,101,100,32,116,111,32,37,100,10,0,0,0,0,0,0,0,99,49,95,115,116,114,101,110,103,116,104,0,0,0,0,0,110,0,0,0,0,0,0,0,40,105,109,103,102,109,116,58,32,37,120,44,32,112,108,97,110,101,115,58,32,37,112,44,37,112,44,37,112,32,115,116,114,105,100,101,115,58,32,37,100,44,37,100,44,37,100,44,32,99,104,114,111,109,97,58,32,37,100,120,37,100,44,32,115,104,105,102,116,58,32,104,58,37,100,44,118,58,37,100,41,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,97,108,116,114,101,102,32,98,117,102,102,101,114,0,0,0,0,0,0,0,0,116,101,115,97,0,0,0,0,68,97,116,117,109,95,66,101,100,117,97,114,97,109,0,0,115,99,112,108,120,95,109,97,115,107,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,108,117,116,51,100,46,99,0,0,116,114,97,99,107,95,103,97,105,110,32,61,32,37,43,46,50,102,32,100,66,10,0,0,65,117,114,97,118,105,115,105,111,110,32,65,117,114,97,32,50,0,0,0,0,0,0,0,115,101,116,32,86,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,114,99,95,115,99,97,108,101,100,95,119,105,100,116,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,49,46,46,99,102,103,45,62,103,95,119,93,0,0,0,0,0,0,118,102,0,0,0,0,0,0,110,111,105,115,101,95,115,101,110,115,105,116,105,118,105,116,121,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,54,93,0,0,0,0,115,101,116,32,119,97,118,101,102,111,114,109,32,109,105,114,114,111,114,105,110,103,0,0,115,101,116,32,108,117,109,105,110,97,110,99,101,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,116,101,120,116,0,0,0,0,112,97,110,32,102,105,108,116,101,114,32,110,101,101,100,115,32,97,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,97,110,100,32,97,32,115,101,116,32,111,102,32,99,104,97,110,110,101,108,115,32,100,101,102,105,110,105,116,105,111,110,115,32,97,115,32,112,97,114,97,109,101,116,101,114,10,0,0,0,0,0,0,0,116,102,102,0,0,0,0,0,99,108,82,101,108,101,97,115,101,75,101,114,110,101,108,0,100,0,0,0,0,0,0,0,110,118,49,50,0,0,0,0,66,108,117,101,86,105,111,108,101,116,0,0,0,0,0,0,65,86,79,112,116,105,111,110,32,116,121,112,101,32,37,100,32,111,102,32,111,112,116,105,111,110,32,37,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,10,0,0,0,0,0,0,103,116,0,0,0,0,0,0,77,117,120,101,114,32,110,111,116,32,102,111,117,110,100,0,83,82,0,0,0,0,0,0,120,58,37,100,32,121,58,37,100,32,119,58,37,100,32,104,58,37,100,32,99,111,108,111,114,58,48,120,37,48,50,88,37,48,50,88,37,48,50,88,37,48,50,88,10,0,0,0,117,115,105,110,103,32,37,115,10,0,0,0,0,0,0,0,102,117,108,108,32,99,104,114,111,109,97,32,105,110,116,101,114,112,111,108,97,116,105,111,110,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,46,10,0,0,0,0,0,82,101,109,97,116,114,105,120,32,105,115,32,110,101,101,100,101,100,32,98,101,116,119,101,101,110,32,37,115,32,97,110,100,32,37,115,32,98,117,116,32,116,104,101,114,101,32,105,115,32,110,111,116,32,101,110,111,117,103,104,32,105,110,102,111,114,109,97,116,105,111,110,32,116,111,32,100,111,32,105,116,10,0,0,0,0,0,0,118,98,0,0,0,0,0,0,109,105,114,114,111,114,101,100,32,101,100,103,101,32,97,116,32,98,108,97,110,107,32,108,111,99,97,116,105,111,110,115,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,92,111,114,103,40,37,100,44,37,100,41,37,49,91,92,125,93,37,110,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,100,117,114,97,116,105,111,110,10,0,0,115,101,116,32,119,104,101,116,104,101,114,32,111,114,32,110,111,116,32,99,104,114,111,109,97,32,105,115,32,99,111,110,115,105,100,101,114,101,100,32,105,110,32,116,104,101,32,109,101,116,114,105,99,32,99,97,108,99,117,108,97,116,105,111,110,115,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,68,117,99,107,32,68,75,51,0,0,0,0,0,0,100,105,102,102,101,114,101,110,116,32,98,105,116,100,101,112,116,104,32,115,101,116,116,105,110,103,32,116,104,97,110,32,102,105,114,115,116,32,112,97,115,115,32,40,37,100,32,118,115,32,37,100,41,10,0,0,100,105,97,108,110,111,114,109,0,0,0,0,0,0,0,0,100,105,97,108,110,111,114,109,0,0,0,0,0,0,0,0,102,114,97,109,101,32,67,82,67,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,84,111,111,32,109,97,110,121,32,112,97,116,99,104,101,115,58,32,37,100,10,0,0,0,65,78,77,82,32,109,101,116,104,111,100,0,0,0,0,0,109,115,95,112,114,101,115,101,110,116,32,61,32,51,32,105,115,32,114,101,115,101,114,118,101,100,46,10,0,0,0,0,98,121,116,101,115,116,114,101,97,109,32,111,118,101,114,114,101,97,100,10,0,0,0,0,48,46,50,56,54,47,48,46,50,49,57,32,48,46,54,51,57,47,48,46,54,52,51,0,76,97,114,103,101,32,98,108,111,99,107,32,97,108,105,103,110,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,100,10,0,0,101,115,97,0,0,0,0,0,68,97,116,117,109,95,66,97,114,98,97,100,111,115,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,104,117,110,107,32,115,105,122,101,10,0,80,97,99,107,101,100,32,115,97,109,112,108,101,115,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,116,101,109,112,111,114,97,108,32,99,111,109,112,108,101,120,105,116,121,32,109,97,115,107,105,110,103,0,0,0,0,0,73,110,118,97,108,105,100,32,102,117,108,108,121,32,99,111,100,101,100,32,115,117,112,101,114,98,108,111,99,107,32,114,117,110,32,108,101,110,103,116,104,10,0,0,0,0,0,0,111,119,0,0,0,0,0,0,109,97,112,112,105,110,103,95,115,101,116,117,112,45,62,109,97,103,110,105,116,117,100,101,91,106,93,0,0,0,0,0,78,111,110,45,122,101,114,111,32,114,111,116,97,116,105,111,110,32,99,111,101,102,102,105,99,105,101,110,116,115,0,0,72,105,103,104,32,52,58,50,58,50,32,73,110,116,114,97,0,0,0,0,0,0,0,0,67,79,78,68,79,86,69,82,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,97,117,114,97,50,0,0,0,115,101,116,32,116,104,101,32,97,108,112,104,97,32,103,97,105,110,32,102,111,114,32,116,104,101,32,98,108,117,101,32,99,104,97,110,110,101,108,0,83,112,101,99,105,102,105,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,87,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,97,108,112,104,97,32,114,97,100,105,117,115,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,102,105,108,101,0,0,0,0,80,114,111,106,78,97,116,79,114,105,103,105,110,76,111,110,103,71,101,111,75,101,121,0,97,116,116,97,99,107,115,0,83,97,109,112,108,101,115,32,112,101,114,32,112,105,120,101,108,32,114,101,113,117,105,114,101,115,32,97,32,115,105,110,103,108,101,32,118,97,108,117,101,44,32,109,97,110,121,32,112,114,111,118,105,100,101,100,10,0,0,0,0,0,0,0,119,97,116,101,114,109,97,114,107,32,107,101,121,32,37,35,120,10,0,0,0,0,0,0,60,98,62,0,0,0,0,0,98,105,115,117,0,0,0,0,72,117,102,102,109,97,110,32,99,111,100,101,115,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,0,110,109,101,97,110,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,97,100,100,105,116,105,111,110,0,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,109,97,114,107,101,114,32,109,105,115,115,105,110,103,10,0,32,105,110,58,37,100,32,0,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,44,32,37,105,32,60,32,37,105,10,0,0,0,0,0,0,98,105,116,115,95,112,101,114,95,109,98,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,39,37,115,39,46,10,0,0,0,0,0,100,97,114,95,100,101,110,0,98,108,117,114,97,121,45,99,111,109,112,97,116,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,116,114,105,109,46,99,0,0,0,0,0,0,128,0,0,0,0,0,0,0,115,101,116,32,98,105,116,114,97,116,101,32,40,105,110,32,98,105,116,115,47,115,41,0,87,97,114,110,105,110,103,32,109,105,110,95,114,97,116,101,32,62,32,48,32,98,117,116,32,109,105,110,95,114,97,116,101,32,33,61,32,109,97,120,95,114,97,116,101,32,105,115,110,39,116,32,114,101,99,111,109,109,101,110,100,101,100,33,10,0,0,0,0,0,0,0,37,115,58,32,99,111,117,108,100,32,110,111,116,32,115,101,101,107,32,116,111,32,112,111,115,105,116,105,111,110,32,37,108,108,100,10,0,0,0,0,37,50,100,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,116,121,112,101,10,0,0,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,116,121,112,101,10,0,0,0,0,0,113,117,97,110,116,105,122,101,114,95,110,111,105,115,101,95,115,104,97,112,105,110,103,0,86,105,100,101,111,32,79,98,106,101,99,116,32,76,97,121,101,114,32,83,116,97,114,116,0,0,0,0,0,0,0,0,84,104,105,115,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,39,124,39,32,116,111,32,115,101,112,97,114,97,116,101,32,116,104,101,32,109,97,112,112,105,110,103,115,46,10,0,0,0,80,82,69,86,95,79,85,84,84,0,0,0,0,0,0,0,115,116,114,105,99,116,95,103,111,112,0,0,0,0,0,0,112,105,99,116,117,114,101,95,115,116,114,117,99,116,117,114,101,32,37,100,32,105,110,118,97,108,105,100,44,32,105,103,110,111,114,105,110,103,10,0,102,105,108,116,101,114,32,60,32,50,0,0,0,0,0,0,100,101,99,111,100,101,95,115,111,102,48,58,32,101,114,114,111,114,44,32,108,101,110,40,37,100,41,32,109,105,115,109,97,116,99,104,10,0,0,0,113,112,0,0,0,0,0,0,67,111,109,112,114,101,115,115,105,111,110,32,101,110,97,98,108,101,100,46,10,0,0,0,73,110,118,97,108,105,100,32,99,111,109,112,110,111,32,37,100,46,32,84,104,101,114,101,32,97,114,101,32,37,100,32,99,111,109,112,111,110,101,110,116,115,32,105,110,32,116,104,101,32,105,109,97,103,101,46,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,37,100,32,37,98,32,37,89,0,0,0,0,0,0,0,0,66,97,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,79,110,108,121,32,89,86,85,57,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,32,105,115,32,115,117,112,112,111,114,116,101,100,33,10,0,72,97,108,102,112,101,108,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,0,0,73,110,118,97,108,105,100,32,115,116,97,114,116,32,116,105,109,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,39,37,115,39,32,105,110,32,105,110,116,101,114,118,97,108,32,35,37,100,10,0,0,73,110,118,97,108,105,100,32,118,105,115,105,98,108,101,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,58,32,37,100,120,37,100,46,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,115,108,105,99,101,32,116,121,112,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,37,100,32,37,100,32,37,112,10,0,0,0,0,0,0,0,114,101,102,101,114,101,110,99,101,32,111,118,101,114,102,108,111,119,32,40,112,112,115,41,10,0,0,0,0,0,0,0,115,116,101,114,101,111,95,109,111,100,101,0,0,0,0,0,80,73,67,84,95,84,89,80,69,95,73,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,99,117,114,115,111,114,32,98,117,102,102,101,114,10,0,0,100,101,99,111,100,101,95,104,121,98,114,105,100,32,102,97,105,108,101,100,10,0,0,0,50,45,108,101,118,101,108,0,32,32,77,97,120,32,66,108,111,99,107,115,105,122,101,58,32,37,100,10,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,37,100,32,111,102,32,115,108,105,99,101,115,32,114,101,113,117,101,115,116,101,100,44,32,112,108,101,97,115,101,32,115,112,101,99,105,102,121,32,97,32,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,119,105,116,104,32,45,115,108,105,99,101,115,32,40,101,120,58,52,44,54,44,57,44,49,50,44,49,54,44,32,46,46,46,41,10,0,0,0,0,0,0,0,0,67,82,67,32,109,105,115,109,97,116,99,104,32,37,88,33,10,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,100,32,99,104,97,110,110,101,108,10,0,0,0,0,111,102,102,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,108,97,114,103,101,32,98,108,111,99,107,32,115,105,122,101,10,0,0,0,65,115,115,101,116,32,104,101,97,100,101,114,32,115,105,122,101,32,109,105,115,109,97,116,99,104,46,10,0,0,0,0,115,117,98,98,97,110,100,115,32,61,32,48,0,0,0,0,115,105,122,101,0,0,0,0,116,105,109,101,95,98,97,115,101,95,100,101,110,0,0,0,77,80,69,71,45,52,32,112,97,114,116,32,50,0,0,0,117,109,104,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,105,102,111,10,0,0,0,0,0,0,0,0,68,97,116,117,109,95,66,97,116,97,118,105,97,0,0,0,101,120,116,114,97,99,116,112,108,97,110,101,115,0,0,0,116,99,112,108,120,95,109,97,115,107,0,0,0,0,0,0,69,117,114,111,45,84,101,99,104,110,111,0,0,0,0,0,87,77,47,84,114,97,99,107,78,117,109,98,101,114,0,0,37,115,37,115,37,115,0,0,105,100,51,118,50,95,118,101,114,115,105,111,110,0,0,0,65,117,114,97,118,105,115,105,111,110,32,65,85,82,65,0,84,104,101,32,102,111,108,108,111,119,105,110,103,32,102,105,108,116,101,114,115,32,99,111,117,108,100,32,110,111,116,32,99,104,111,111,115,101,32,116,104,101,105,114,32,102,111,114,109,97,116,115,58,32,37,115,10,67,111,110,115,105,100,101,114,32,105,110,115,101,114,116,105,110,103,32,116,104,101,32,40,97,41,102,111,114,109,97,116,32,102,105,108,116,101,114,32,110,101,97,114,32,116,104,101,105,114,32,105,110,112,117,116,32,111,114,32,111,117,116,112,117,116,46,10,0,0,0,52,50,50,0,0,0,0,0,87,77,47,87,77,82,86,66,105,116,114,97,116,101,0,0,116,105,109,101,95,114,101,102,101,114,101,110,99,101,0,0,111,114,105,103,105,110,97,116,111,114,95,114,101,102,101,114,101,110,99,101,0,0,0,0,71,69,78,82,0,0,0,0,114,102,112,115,58,32,37,102,32,37,102,10,0,0,0,0,102,114,101,105,48,114,0,0,47,0,0,0,0,0,0,0,109,105,110,32,115,101,99,115,32,116,111,32,115,116,114,105,112,32,72,68,32,102,111,114,32,97,102,116,101,114,32,97,110,32,111,118,101,114,102,108,111,119,32,40,45,49,58,32,116,105,108,108,32,116,104,101,32,101,110,100,44,32,100,101,102,97,117,108,116,32,54,48,41,0,0,0,0,0,0,0,105,115,109,95,108,111,111,107,97,104,101,97,100,0,0,0,118,115,116,97,116,115,95,102,105,108,101,0,0,0,0,0,98,97,115,115,0,0,0,0,80,105,99,116,117,114,101,32,115,105,122,101,32,37,117,120,37,117,32,105,115,32,105,110,118,97,108,105,100,10,0,0,116,101,109,112,111,0,0,0,77,68,53,0,0,0,0,0,105,110,118,97,108,105,100,32,108,105,116,101,114,97,108,47,108,101,110,103,116,104,32,99,111,100,101,0,0,0,0,0,69,114,114,111,114,32,105,110,32,101,120,112,114,101,115,115,105,111,110,32,34,37,115,34,10,0,0,0,0,0,0,0,104,101,120,0,0,0,0,0,68,97,116,117,109,95,65,114,99,95,49,57,54,48,0,0,99,111,109,112,114,101,115,115,101,115,32,98,114,105,103,104,116,32,97,114,101,97,115,32,115,116,114,111,110,103,101,114,32,116,104,97,110,32,109,101,100,105,117,109,32,111,110,101,115,0,0,0,0,0,0,0,97,117,114,97,0,0,0,0,67,104,97,110,110,101,108,58,32,37,100,10,0,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,99,111,108,111,114,115,112,97,99,101,10,0,0,0,0,0,0,0,100,117,109,112,32,118,105,100,101,111,32,99,111,100,105,110,103,32,115,116,97,116,105,115,116,105,99,115,32,116,111,32,102,105,108,101,0,0,0,0,104,105,100,101,95,98,97,110,110,101,114,0,0,0,0,0,100,101,102,97,117,108,116,0,108,105,115,116,95,116,121,112,101,0,0,0,0,0,0,0,97,61,114,116,112,109,97,112,58,37,100,32,72,50,54,52,47,57,48,48,48,48,13,10,97,61,102,109,116,112,58,37,100,32,112,97,99,107,101,116,105,122,97,116,105,111,110,45,109,111,100,101,61,37,100,37,115,13,10,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,109,105,120,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,0,0,0,0,0,0,83,101,110,100,32,82,84,67,80,32,66,89,69,32,112,97,99,107,101,116,115,32,119,104], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2402464);
/* memory initializer */ allocate([101,110,32,102,105,110,105,115,104,105,110,103,0,0,0,0,71,66,82,0,0,0,0,0,99,111,100,101,99,100,97,116,97,95,108,101,110,103,116,104,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,110,98,95,111,117,116,95,115,97,109,112,108,101,115,58,37,100,32,112,97,100,58,37,100,10,0,0,0,0,0,0,0,99,98,114,116,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,99,108,111,115,101,32,111,110,32,101,120,101,99,10,0,0,0,0,101,110,99,111,100,101,100,95,98,121,0,0,0,0,0,0,67,97,110,110,111,116,32,114,101,97,100,32,102,105,108,101,32,39,37,115,39,58,32,37,115,10,0,0,0,0,0,0,103,55,50,51,95,49,0,0,111,115,114,0,0,0,0,0,100,105,97,0,0,0,0,0,68,97,116,117,109,95,65,114,99,95,49,57,53,48,0,0,101,108,98,103,0,0,0,0,117,51,50,98,101,0,0,0,108,117,109,105,95,109,97,115,107,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,81,73,32,118,105,100,101,111,0,0,0,0,0,0,0,117,51,50,98,101,0,0,0,105,110,95,103,97,105,110,32,109,97,121,32,99,97,117,115,101,32,99,108,105,112,112,105,110,103,10,0,0,0,0,0,118,115,116,97,116,115,0,0,116,114,121,32,116,111,32,105,110,116,101,114,108,101,97,118,101,32,111,117,116,112,117,116,116,101,100,32,112,97,99,107,101,116,115,32,98,121,32,100,116,115,0,0,0,0,0,0,103,102,0,0,0,0,0,0,69,75,66,32,0,0,0,0,66,111,116,104,32,119,104,111,108,101,32,97,110,100,32,112,97,100,32,108,101,110,103,116,104,32,97,114,101,32,115,101,116,44,32,116,104,105,115,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,79,112,117,115,32,104,101,97,100,101,114,115,10,0,0,0,0,0,100,101,102,97,117,108,116,0,117,54,52,0,0,0,0,0,83,107,105,112,69,110,100,0,37,51,49,115,32,37,42,115,32,37,51,49,115,0,0,0,73,110,118,97,108,105,100,32,99,104,97,114,115,32,39,37,115,39,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,111,110,108,121,32,52,56,107,104,122,32,105,115,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,102,111,117,110,100,32,105,110,99,111,110,115,105,115,116,101,110,116,32,66,111,100,121,83,73,68,10,0,0,0,0,0,105,110,112,117,116,37,100,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,108,97,116,109,0,0,0,0,99,97,110,110,111,116,32,115,101,116,32,115,116,114,101,97,109,32,105,110,102,111,44,32,99,111,100,101,99,32,105,115,32,111,112,101,110,10,0,0,118,98,114,0,0,0,0,0,68,97,116,117,109,95,65,114,97,116,117,0,0,0,0,0,69,114,114,111,114,32,110,117,109,98,101,114,32,37,100,32,111,99,99,117,114,114,101,100,0,0,0,0,0,0,0,0,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,65,65,78,32,68,67,84,0,0,78,111,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,102,111,114,32,105,110,112,117,116,32,37,100,10,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,58,37,48,51,100,44,32,102,105,108,101,112,111,115,58,32,37,108,108,120,0,0,0,0,0,0,116,113,105,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,97,114,102,95,110,111,116,95,122,122,0,0,0,71,111,116,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,112,105,99,116,117,114,101,32,105,110,32,115,116,114,101,97,109,32,37,100,44,32,105,103,110,111,114,105,110,103,46,10,0,0,0,0,0,0,99,97,108,99,117,108,97,116,101,32,80,83,78,82,32,111,102,32,99,111,109,112,114,101,115,115,101,100,32,102,114,97,109,101,115,0,0,0,0,0,84,104,105,115,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,39,124,39,32,116,111,32,115,101,112,97,114,97,116,101,32,37,115,46,10,0,0,0,0,0,102,108,97,103,115,0,0,0,117,114,108,32,0,0,0,0,101,100,103,101,100,101,116,101,99,116,0,0,0,0,0,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,97,116,114,111,115,107,97,101,110,99,46,99,0,0,0,0,0,0,0,116,121,112,101,0,0,0,0,87,111,114,107,105,110,103,32,97,114,111,117,110,100,32,98,114,111,107,101,110,32,105,110,100,101,120,46,10,0,0,0,110,32,60,61,32,51,50,0,120,50,54,52,32,91,37,115,93,58,32,0,0,0,0,0,68,97,116,117,109,95,76,105,115,98,111,110,0,0,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,102,97,97,110,0,0,0,0,116,105,102,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,71,81,32,118,105,100,101,111,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,100,101,108,97,121,115,32,97,110,100,47,111,114,32,100,101,99,97,121,115,46,10,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,116,114,97,110,115,102,111,114,109,32,115,105,122,101,34,0,0,0,112,115,110,114,0,0,0,0,84,82,67,75,0,0,0,0,100,101,108,97,121,115,0,0,115,101,116,32,110,117,109,98,101,114,32,97,102,116,101,114,32,119,104,105,99,104,32,116,104,101,32,105,110,100,101,120,32,119,114,97,112,115,0,0,35,69,88,84,45,88,45,75,69,89,58,0,0,0,0,0,37,115,0,0,0,0,0,0,78,111,32,98,105,116,32,114,97,116,101,32,115,101,116,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,84,104,105,115,32,102,105,108,116,101,114,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,97,102,111,114,109,97,116,32,105,110,115,116,101,97,100,10,0,40,114,111,119,56,120,56,95,114,101,109,97,105,110,105,110,103,32,62,32,48,41,32,38,38,32,40,99,111,108,56,120,56,95,114,101,109,97,105,110,105,110,103,32,62,32,48,41,0,0,0,0,0,0,0,0,97,116,32,109,111,115,116,32,111,110,101,32,97,117,100,105,111,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,32,105,110,32,102,108,118,10,0,0,0,80,111,111,108,32,114,97,99,101,32,100,101,99,116,101,99,116,101,100,44,32,115,112,105,110,105,110,103,32,116,111,32,97,118,111,105,100,32,111,118,101,114,97,108,108,111,99,97,116,105,111,110,32,97,110,100,32,101,118,101,110,116,117,97,108,32,79,79,77,10,0,0,73,78,84,49,54,95,77,73,78,32,60,61,32,114,118,32,38,38,32,114,118,32,60,61,32,73,78,84,49,54,95,77,65,88,0,0,0,0,0,0,102,105,108,101,115,105,122,101,0,0,0,0,0,0,0,0,115,116,114,101,97,109,32,116,121,112,101,59,32,114,101,118,105,115,105,111,110,61,37,105,0,0,0,0,0,0,0,0,97,101,118,97,108,0,0,0,80,83,78,82,61,32,37,54,46,50,102,32,0,0,0,0,117,110,107,110,111,119,110,0,68,97,116,117,109,95,65,103,97,100,101,122,0,0,0,0,97,108,116,105,118,101,99,0,115,101,116,32,102,114,97,109,101,114,97,116,101,32,40,102,114,97,109,101,115,32,112,101,114,32,115,101,99,111,110,100,41,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,116,103,113,0,0,0,0,0,109,105,95,114,111,119,32,62,61,32,48,32,38,38,32,109,105,95,114,111,119,32,60,32,99,109,45,62,109,105,95,114,111,119,115,0,0,0,0,0,116,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,116,104,101,32,121,97,100,105,102,32,102,105,108,116,101,114,32,105,110,115,116,101,97,100,0,115,97,109,112,108,101,32,115,105,122,101,32,40,37,100,41,32,33,61,32,98,108,111,99,107,32,97,108,105,103,110,32,40,37,100,41,10,0,0,0,112,97,99,107,101,116,95,114,101,112,108,105,99,95,115,105,122,101,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,104,97,108,100,99,108,117,116,115,114,99,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,98,97,121,101,114,32,99,111,110,118,101,114,115,105,111,110,10,0,0,0,118,112,57,47,100,101,99,111,100,101,114,47,118,112,57,95,100,101,99,111,100,101,109,118,46,99,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,114,97,116,101,58,37,100,47,37,100,32,100,117,114,97,116,105,111,110,58,37,102,10,0,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,37,115,37,46,51,103,32,105,37,100,0,0,0,0,0,0,78,111,32,97,99,99,101,108,101,114,97,116,101,100,32,99,111,108,111,114,115,112,97,99,101,32,99,111,110,118,101,114,115,105,111,110,32,102,111,117,110,100,32,102,114,111,109,32,37,115,32,116,111,32,37,115,46,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,78,117,109,98,101,114,32,111,102,32,97,116,116,97,99,107,115,32,37,100,32,100,105,102,102,101,114,115,32,102,114,111,109,32,110,117,109,98,101,114,32,111,102,32,100,101,99,97,121,115,32,37,100,46,10,0,100,101,98,117,103,0,0,0,68,97,116,117,109,95,65,102,103,111,111,121,101,0,0,0,109,109,120,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,71,86,32,118,105,100,101,111,0,0,0,0,0,0,0,98,50,0,0,0,0,0,0,76,111,111,112,32,102,105,108,116,101,114,32,116,104,114,101,97,100,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,0,0,0,0,0,0,100,101,105,110,116,101,114,108,97,99,101,0,0,0,0,0,99,104,97,110,110,101,108,115,32,62,32,48,0,0,0,0,115,101,103,95,102,101,97,116,117,114,101,95,100,97,116,97,95,115,105,103,110,101,100,91,102,101,97,116,117,114,101,95,105,100,93,0,0,0,0,0,115,105,122,101,0,0,0,0,116,105,109,101,99,111,100,101,58,32,116,98,99,61,37,100,47,37,100,32,105,110,118,97,108,105,100,44,32,102,97,108,108,98,97,99,107,32,111,110,32,37,100,47,37,100,10,0,105,115,99,97,110,91,110,101,105,103,104,98,111,114,115,91,77,65,88,95,78,69,73,71,72,66,79,82,83,32,42,32,110,32,43,32,48,93,93,32,60,32,110,0,0,0,0,0,116,114,105,0,0,0,0,0,46,47,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,98,108,111,99,107,46,104,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,97,108,108,0,0,0,0,0,73,110,118,97,108,105,100,32,115,99,97,108,101,32,102,97,99,116,111,114,115,0,0,0,109,111,114,112,104,120,102,0,66,51,47,83,50,51,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,115,101,116,32,102,105,108,108,32,114,97,116,105,111,32,102,111,114,32,102,105,108,108,105,110,103,32,105,110,105,116,105,97,108,32,103,114,105,100,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,0,0,103,114,97,112,104,32,37,100,32,37,115,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,0,115,115,95,121,32,60,61,32,49,0,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,100,0,0,0,0,0,0,255,255,255,0,0,0,0,0,102,111,114,119,97,114,100,0,108,117,109,97,0,0,0,0,79,110,101,32,111,102,32,116,104,101,32,105,110,112,117,116,32,112,97,114,97,109,101,116,101,114,115,32,116,111,32,115,119,115,95,115,99,97,108,101,40,41,32,105,115,32,78,85,76,76,44,32,112,108,101,97,115,101,32,99,104,101,99,107,32,116,104,101,32,99,97,108,108,105,110,103,32,99,111,100,101,10,0,0,0,0,0,0,105,110,102,111,0,0,0,0,68,97,116,117,109,95,65,105,110,95,101,108,95,65,98,100,95,49,57,55,48,0,0,0,99,108,111,99,107,119,105,115,101,0,0,0,0,0,0,0,97,99,99,117,114,97,116,101,32,105,110,116,101,103,101,114,0,0,0,0,0,0,0,0,108,111,119,95,112,97,115,115,95,102,105,108,116,101,114,32,102,108,97,103,32,105,103,110,111,114,101,100,32,119,105,116,104,32,109,111,100,101,32,37,100,10,0,0,0,0,0,0,116,103,118,0,0,0,0,0,112,114,101,100,95,99,111,110,116,101,120,116,32,62,61,32,48,32,38,38,32,112,114,101,100,95,99,111,110,116,101,120,116,32,60,32,82,69,70,95,67,79,78,84,69,88,84,83,0,0,0,0,0,0,0,0,112,114,101,102,105,120,0,0,111,117,116,0,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,109,118,114,101,102,95,99,111,109,109,111,110,46,99,0,0,0,115,105,122,101,0,0,0,0,105,110,95,99,111,108,111,114,95,109,97,116,114,105,120,0,100,101,102,97,117,108,116,0,37,100,0,0,0,0,0,0,98,108,97,99,107,0,0,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,98,117,102,102,101,114,33,10,0,0,48,0,0,0,0,0,0,0,99,91,116,93,91,105,93,91,106,93,91,107,93,91,48,93,91,108,93,91,69,79,66,95,84,79,75,69,78,93,32,61,61,32,99,91,116,93,91,105,93,91,106,93,91,107,93,91,49,93,91,108,93,91,69,79,66,95,84,79,75,69,78,93,0,0,0,0,0,0,0,0,105,110,95,104,0,0,0,0,83,87,83,99,97,108,101,114,0,0,0,0,0,0,0,0,33,40,108,102,109,45,62,108,101,102,116,95,121,91,84,88,95,49,54,88,49,54,93,32,38,32,108,102,109,45,62,108,101,102,116,95,121,91,84,88,95,52,88,52,93,41,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,116,104,101,32,120,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,87,97,114,110,105,110,103,58,32,68,101,115,105,114,101,100,32,104,101,105,103,104,116,32,116,111,111,32,115,109,97,108,108,44,32,99,104,97,110,103,101,100,32,116,111,32,37,100,10,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,110,111,105,115,101,32,115,101,101,100,0,0,0,0,0,109,111,100,101,0,0,0,0,112,97,99,107,101,100,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,108,97,103,32,98,117,102,102,101,114,115,0,0,119,97,114,110,105,110,103,0,68,97,116,117,109,95,65,117,115,116,114,97,108,105,97,110,95,71,101,111,100,101,116,105,99,95,68,97,116,117,109,95,49,57,56,52,0,0,0,0,105,110,116,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,111,116,105,111,110,32,80,105,120,101,108,115,32,118,105,100,101,111,0,0,0,0,0,118,0,0,0,0,0,0,0,102,105,108,116,101,114,0,0,97,115,0,0,0,0,0,0,103,95,112,97,115,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,86,80,88,95,82,67,95,79,78,69,95,80,65,83,83,46,46,86,80,88,95,82,67,95,76,65,83,84,95,80,65,83,83,93,0,115,101,108,101,99,116,32,116,119,111,32,112,97,115,115,32,108,111,103,32,102,105,108,101,32,110,97,109,101,32,112,114,101,102,105,120,0,0,0,0,99,112,117,95,117,115,101,100,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,45,49,54,46,46,49,54,93,0,119,97,118,101,102,111,114,109,95,109,105,114,114,111,114,0,104,32,60,61,32,54,52,0,108,117,109,95,101,120,112,114,0,0,0,0,0,0,0,0,114,101,99,111,118,101,114,105,110,103,32,98,121,32,117,115,105,110,103,32,105,110,116,114,97,32,109,111,100,101,10,0,32,37,100,37,99,0,0,0,68,117,112,108,105,99,97,116,105,110,103,32,102,114,97,109,101,46,10,0,0,0,0,0,120,50,54,52,32,45,32,99,111,114,101,32,37,100,37,115,32,45,32,72,46,50,54,52,47,77,80,69,71,45,52,32,65,86,67,32,99,111,100,101,99,32,45,32,67,111,112,121,37,115,32,50,48,48,51,45,50,48,49,52,32,45,32,104,116,116,112,58,47,47,119,119,119,46,118,105,100,101,111,108,97,110,46,111,114,103,47,120,50,54,52,46,104,116,109,108,32,45,32,111,112,116,105,111,110,115,58,32,37,115,0,0,97,115,115,117,109,101,32,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,0,99,108,82,101,108,101,97,115,101,67,111,110,116,101,120,116,0,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,39,97,110,103,108,101,39,10,0,68,117,114,97,116,105,111,110,32,111,102,32,116,104,101,32,101,102,102,101,99,116,32,105,110,32,115,101,99,111,110,100,115,46,0,0,0,0,0,0,114,103,98,52,95,98,121,116,101,0,0,0,0,0,0,0,66,108,117,101,0,0,0,0,37,115,32,65,86,79,112,116,105,111,110,115,58,10,0,0,100,101,102,97,117,108,116,0,103,116,101,0,0,0,0,0,77,85,88,69,82,95,78,79,84,95,70,79,85,78,68,0,115,105,100,101,32,108,101,102,116,0,0,0,0,0,0,0,83,105,122,101,32,118,97,108,117,101,115,32,108,101,115,115,32,116,104,97,110,32,48,32,97,114,101,32,110,111,116,32,97,99,99,101,112,116,97,98,108,101,46,10,0,0,0,0,67,0,0,0,0,0,0,0,98,32,61,61,32,50,32,124,124,32,98,32,61,61,32,51,0,0,0,0,0,0,0,0,102,117,108,108,95,99,104,114,111,109,97,95,105,110,116,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,97,110,100,32,108,97,121,111,117,116,32,97,114,101,32,117,110,115,101,116,10,0,0,0,0,0,0,0,104,100,101,98,108,111,99,107,0,0,0,0,0,0,0,0,109,105,114,114,111,114,0,0,100,114,97,119,98,111,120,0,92,112,111,115,40,37,100,44,37,100,41,37,49,91,92,125,93,37,110,0,0,0,0,0,99,104,114,111,109,97,0,0,97,100,112,99,109,95,105,109,97,95,100,107,51,0,0,0,98,105,116,100,101,112,116,104,61,37,100,0,0,0,0,0,67,111,112,121,114,105,103,104,116,32,66,105,116,0,0,0,67,111,112,121,114,105,103,104,116,32,66,105,116,0,0,0,105,110,99,111,109,112,108,101,116,101,32,102,114,97,109,101,10,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,110,111,105,115,101,32,102,108,111,111,114,32,115,99,97,108,101,32,102,97,99,116,111,114,115,58,32,37,100,10,0,97,110,109,114,0,0,0,0,115,107,105,112,95,100,97,116,97,95,115,116,114,101,97,109,95,101,108,101,109,101,110,116,58,32,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,0,0,119,111,114,100,115,116,114,101,97,109,32,111,118,101,114,114,101,97,100,10,0,0,0,0,48,46,51,48,53,47,48,46,50,56,54,32,48,46,54,57,52,47,48,46,55,49,51,0,85,110,107,110,111,119,110,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,117,98,102,114,97,109,101,115,32,37,105,10,0,101,114,114,111,114,0,0,0,68,97,116,117,109,95,65,117,115,116,114,97,108,105,97,110,95,71,101,111,100,101,116,105,99,95,68,97,116,117,109,95,49,57,54,54,0,0,0,0,105,110,118,97,108,105,100,32,115,121,109,98,111,108,32,37,100,32,43,32,114,101,112,101,97,116,32,37,100,32,62,32,97,108,112,104,97,98,101,116,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,72,121,98,114,105,100,32,99,111,110,102,105,103,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,102,97,115,116,32,105,110,116,101,103,101,114,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,116,105,97,108,108,121,32,99,111,100,101,100,32,115,117,112,101,114,98,108,111,99,107,32,114,117,110,32,108,101,110,103,116,104,10,0,0,79,116,104,101,114,32,109,97,112,112,105,110,103,115,32,116,104,97,110,32,116,121,112,101,32,48,32,97,114,101,32,110,111,116,32,99,111,109,112,108,105,97,110,116,32,119,105,116,104,32,116,104,101,32,86,111,114,98,105,115,32,73,32,115,112,101,99,105,102,105,99,97,116,105,111,110,46,32,10,0,105,110,95,104,0,0,0,0,78,101,101,100,32,116,119,111,32,115,112,114,105,116,101,115,44,32,111,110,108,121,32,103,111,116,32,111,110,101,10,0,72,105,103,104,32,49,48,0,65,67,80,82,69,68,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,0,109,111,116,105,111,110,112,105,120,101,108,115,0,0,0,0,79,112,101,110,67,76,32,115,117,112,112,111,114,116,32,119,97,115,32,110,111,116,32,101,110,97,98,108,101,100,32,105,110,32,116,104,105,115,32,98,117,105,108,100,44,32,99,97,110,110,111,116,32,98,101,32,115,101,108,101,99,116,101,100,10,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,110,111,116,32,115,112,101,99,105,102,105,101,100,10,0,0,0,98,97,0,0,0,0,0,0,78,111,116,32,97,32,84,77,50,32,104,101,97,100,101,114,58,32,48,120,37,48,56,88,10,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,99,104,114,111,109,97,32,114,97,100,105,117,115,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,112,97,115,115,108,111,103,102,105,108,101,0,0,0,0,0,80,114,111,106,83,116,100,80,97,114,97,108,108,101,108,50,71,101,111,75,101,121,0,0,84,104,105,115,32,102,111,114,109,97,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,98,112,112,61,37,100,44,32,37,100,32,99,111,109,112,111,110,101,110,116,115,41,10,0,0,0,99,111,117,108,100,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,32,119,97,116,101,114,109,97,114,107,32,108,111,103,111,10,0,0,0,0,62,0,0,0,0,0,0,0,105,110,100,101,120,32,61,61,32,49,0,0,0,0,0,0,123,92,102,110,37,115,125,0,83,107,105,112,112,105,110,103,32,104,105,103,104,32,98,121,116,101,115,32,116,114,101,101,10,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,97,117,100,105,111,32,116,121,112,101,10,0,0,0,0,0,115,101,116,32,98,108,101,110,100,32,109,111,100,101,32,102,111,114,32,97,108,108,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,114,118,49,48,46,99,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,114,99,95,101,113,32,34,37,115,34,10,0,0,0,0,0,0,0,115,116,114,101,97,109,32,105,115,32,81,68,77,67,32,118,101,114,115,105,111,110,32,49,44,32,119,104,105,99,104,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,76,97,118,99,0,0,0,0,115,101,116,32,100,105,115,112,108,97,121,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,0,0,0,49,98,0,0,0,0,0,0,73,110,99,111,109,112,97,116,105,98,108,101,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,39,37,115,39,32,102,111,114,32,99,111,100,101,99,32,39,37,115,39,44,32,97,117,116,111,45,115,101,108,101,99,116,105,110,103,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,32,69,88,0,0,0,0,0,100,105,114,0,0,0,0,0,115,116,97,114,116,95,115,97,109,112,108,101,32,60,32,101,110,100,95,115,97,109,112,108,101,32,124,124,32,40,115,116,97,114,116,95,115,97,109,112,108,101,32,61,61,32,101,110,100,95,115,97,109,112,108,101,32,38,38,32,33,102,114,97,109,101,45,62,110,98,95,115,97,109,112,108,101,115,41,0,98,0,0,0,0,0,0,0,69,105,116,104,101,114,32,98,111,116,104,32,98,117,102,102,101,114,32,115,105,122,101,32,97,110,100,32,109,97,120,32,114,97,116,101,32,111,114,32,110,101,105,116,104,101,114,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,37,115,58,32,115,101,101,107,32,118,97,108,117,101,32,111,118,101,114,102,108,111,119,32,119,105,116,104,32,115,116,97,114,116,95,116,105,109,101,58,37,108,108,100,32,115,101,101,107,95,112,111,105,110,116,58,37,108,108,100,10,0,0,0,37,49,100,0,0,0,0,0,98,105,103,95,118,97,108,117,101,115,32,116,111,111,32,98,105,103,10,0,0,0,0,0,98,105,103,95,118,97,108,117,101,115,32,116,111,111,32,98,105,103,10,0,0,0,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,99,104,114,111,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,86,105,100,101,111,32,79,98,106,101,99,116,32,83,116,97,114,116,0,0,0,0,0,0,80,82,69,86,95,79,85,84,80,84,83,0,0,0,0,0,82,68,32,111,112,116,105,109,97,108,32,77,66,32,108,101,118,101,108,32,114,101,115,105,100,117,97,108,32,115,107,105,112,112,105,110,103,0,0,0,105,110,116,101,114,108,97,99,101,100,32,102,114,97,109,101,32,105,110,32,112,114,111,103,114,101,115,115,105,118,101,32,115,101,113,117,101,110,99,101,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,111,117,108,100,32,110,111,116,32,103,101,116,32,97,32,112,105,120,101,108,32,102,111,114,109,97,116,32,100,101,115,99,114,105,112,116,111,114,46,10,0,0,0,0,0,0,0,73,110,32,67,82,70,32,109,111,100,101,44,32,112,114,101,118,101,110,116,115,32,86,66,86,32,102,114,111,109,32,108,111,119,101,114,105,110,103,32,113,117,97,108,105,116,121,32,98,101,121,111,110,100,32,116,104,105,115,32,112,111,105,110,116,46,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,105,109,97,103,101,32,102,111,114,109,97,116,32,37,100,46,10,0,0,0,83,117,112,112,111,114,116,32,102,111,114,32,37,100,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,0,0,0,92,68,0,0,0,0,0,0,114,101,102,95,116,105,108,101,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,72,101,97,100,101,114,32,108,111,111,107,115,32,108,105,107,101,32,82,84,80,32,105,110,115,116,101,97,100,32,111,102,32,72,46,50,54,51,10,0,83,121,110,99,32,98,105,116,32,105,115,32,115,101,116,33,10,0,0,0,0,0,0,0,56,45,98,105,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,0,0,45,0,0,0,0,0,0,0,82,101,100,117,99,105,110,103,32,108,101,102,116,32,111,117,116,112,117,116,32,119,105,110,100,111,119,32,116,111,32,37,100,32,99,104,114,111,109,97,32,115,97,109,112,108,101,115,32,116,111,32,112,114,101,115,101,114,118,101,32,97,108,105,103,110,109,101,110,116,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,108,105,99,101,32,115,101,103,109,101,110,116,32,97,100,100,114,101,115,115,58,32,37,117,46,10,0,0,0,0,0,114,101,109,111,118,101,32,115,104,111,114,116,32,37,100,32,99,111,117,110,116,32,37,100,10,0,0,0,0,0,0,0,70,77,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,66,73,0,0,0,0,0,0,67,117,114,115,111,114,32,102,111,114,109,97,116,32,37,100,0,0,0,0,0,0,0,0,109,111,100,101,0,0,0,0,114,97,110,100,111,109,32,115,101,101,100,58,32,48,120,37,48,56,120,10,0,0,0,0,90,108,105,98,32,114,101,115,121,110,99,32,111,99,99,117,114,114,101,100,10,0,0,0,101,115,116,105,109,97,116,101,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,112,114,101,100,32,111,114,100,101,114,32,37,100,10,0,0,50,80,97,115,115,32,102,105,108,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,115,108,105,99,101,32,99,111,117,110,116,32,105,110,118,97,108,105,100,10,0,0,0,0,82,71,66,32,99,104,97,110,110,101,108,115,32,110,111,116,32,111,102,32,116,104,101,32,115,97,109,101,32,100,101,112,116,104,10,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,69,110,99,111,100,101,100,0,0,66,108,111,99,107,32,115,101,112,97,114,97,116,105,111,110,32,103,114,101,97,116,101,114,32,116,104,97,110,32,115,105,122,101,10,0,0,0,0,0,68,84,83,45,88,66,82,58,32,101,110,100,32,111,102,32,99,104,97,110,110,101,108,32,115,101,116,44,32,115,107,105,112,112,105,110,103,32,102,117,114,116,104,101,114,32,116,104,97,110,32,101,120,112,101,99,116,101,100,32,40,37,100,32,98,105,116,115,41,10,0,0,115,117,98,98,97,110,100,115,32,62,32,53,48,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,115,101,116,32,118,105,100,101,111,32,111,117,116,112,117,116,0,0,0,0,0,0,0,0,100,101,112,114,101,99,97,116,101,100,44,32,100,111,32,110,111,116,32,117,115,101,0,0,109,112,101,103,52,0,0,0,32,122,111,110,101,115,0,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,0,68,97,116,117,109,95,65,100,105,110,100,97,110,0,0,0,110,111,32,109,97,120,105,109,117,109,46,32,100,101,99,111,100,101,32,97,108,108,32,115,97,109,112,108,101,115,32,102,111,114,32,101,97,99,104,32,112,97,99,107,101,116,32,97,116,32,111,110,99,101,0,0,102,97,115,116,105,110,116,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,111,117,110,100,116,114,97,99,107,0,0,0,0,0,0,87,77,47,84,111,111,108,0,84,105,108,101,32,115,105,122,101,32,37,117,120,37,117,32,105,115,32,105,110,115,97,110,101,46,10,0,0,0,0,0,69,110,97,98,108,101,32,73,68,51,32,116,97,103,115,32,119,114,105,116,105,110,103,46,0,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,67,77,86,32,118,105,100,101,111,0,0,0,0,0,0,0,52,49,49,0,0,0,0,0,87,77,47,87,77,82,86,69,120,112,105,114,97,116,105,111,110,68,97,116,101,0,0,0,111,114,105,103,105,110,97,116,105,111,110,95,116,105,109,101,0,0,0,0,0,0,0,0,110,111,32,39,100,97,116,97,39,32,116,97,103,32,102,111,117,110,100,10,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,101,120,116,114,97,100,97,116,97,32,111,102,32,115,105,122,101,32,37,100,10,0,0,0,0,110,111,102,111,114,109,97,116,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,119,105,116,104,32,110,97,109,101,32,39,37,115,39,44,32,117,110,107,110,111,119,110,32,102,105,108,116,101,114,32,111,114,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,104,97,112,112,101,110,101,100,10,0,0,0,100,116,115,104,100,95,102,97,108,108,98,97,99,107,95,116,105,109,101,0,0,0,0,0,37,100,0,0,0,0,0,0,115,101,108,101,99,116,32,116,104,101,32,112,97,115,115,32,110,117,109,98,101,114,32,40,49,32,116,111,32,51,41,0,65,108,108,111,99,97,116,105,111,110,32,102,97,105,108,117,114,101,44,32,116,114,121,32,116,111,32,108,111,119,101,114,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,10,0,0,112,114,111,98,95,105,110,116,114,97,32,60,61,32,50,53,53,0,0,0,0,0,0,0,32,72,68,0,0,0,0,0,78,111,32,112,97,116,116,101,114,110,32,112,114,111,118,105,100,101,100,46,10,0,0,0,100,101,102,97,117,108,116,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,121,110,99,32,99,111,100,101,0,100,101,102,97,117,108,116,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2412704);
/* memory initializer */ allocate([115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,32,122,111,110,101,115,61,37,115,0,0,0,0,0,0,0,71,67,83,69,95,83,112,104,101,114,101,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,97,117,116,111,115,101,108,101,99,116,32,97,32,103,111,111,100,32,111,110,101,32,40,100,101,102,97,117,108,116,41,0,99,109,118,0,0,0,0,0,112,97,115,115,0,0,0,0,67,111,109,109,97,110,100,32,108,105,110,101,58,10,0,0,115,101,116,32,116,104,101,32,115,101,103,109,101,110,116,32,108,105,115,116,32,116,121,112,101,0,0,0,0,0,0,0,51,71,80,80,32,84,83,32,50,54,46,52,48,51,45,105,110,115,112,105,114,101,100,32,109,111,100,101,108,0,0,0,104,50,54,52,95,109,111,100,101,48,0,0,0,0,0,0,32,72,68,52,50,50,0,0,115,112,105,110,58,0,0,0,105,110,0,0,0,0,0,0,115,101,110,100,95,98,121,101,0,0,0,0,0,0,0,0,105,105,100,95,109,111,100,101,32,37,100,32,105,115,32,114,101,115,101,114,118,101,100,46,10,0,0,0,0,0,0,0,111,117,116,115,105,100,101,32,118,105,100,101,111,98,117,102,115,105,122,101,10,0,0,0,115,113,117,97,114,101,32,114,111,111,116,0,0,0,0,0,73,84,67,72,0,0,0,0,108,101,118,101,108,0,0,0,97,117,100,105,111,47,71,55,50,50,0,0,0,0,0,0,68,117,112,108,105,99,97,116,101,32,118,97,108,117,101,32,102,111,117,110,100,32,105,110,32,102,108,111,111,114,32,49,32,88,32,99,111,111,114,100,105,110,97,116,101,115,10,0,58,37,46,50,102,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,0,115,98,0,0,0,0,0,0,97,117,116,111,0,0,0,0,66,114,117,116,101,32,70,111,114,99,101,32,38,32,73,103,110,111,114,97,110,99,101,0,108,117,109,97,95,114,97,100,105,117,115,58,37,102,32,108,117,109,97,95,115,116,114,101,110,103,116,104,58,37,102,32,108,117,109,97,95,116,104,114,101,115,104,111,108,100,58,37,100,32,99,104,114,111,109,97,95,114,97,100,105,117,115,58,37,102,32,99,104,114,111,109,97,95,115,116,114,101,110,103,116,104,58,37,102,32,99,104,114,111,109,97,95,116,104,114,101,115,104,111,108,100,58,37,100,10,0,0,0,0,0,0,115,98,0,0,0,0,0,0,104,104,58,109,109,58,115,115,91,58,59,46,93,102,102,0,100,101,102,97,117,108,116,0,115,111,114,116,100,116,115,0,115,101,116,32,114,101,100,32,102,97,100,101,0,0,0,0,69,75,0,0,0,0,0,0,109,111,100,101,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,83,112,101,101,120,32,104,101,97,100,101,114,115,10,0,0,0,0,88,68,67,65,77,0,0,0,100,101,102,97,117,108,116,0,67,104,97,110,110,101,108,76,97,121,111,117,116,0,0,0,121,98,102,45,62,121,95,119,105,100,116,104,32,45,32,121,98,102,45,62,121,95,99,114,111,112,95,119,105,100,116,104,32,60,32,49,54,0,0,0,83,107,105,112,83,116,97,114,116,0,0,0,0,0,0,0,115,97,109,112,108,101,95,115,105,103,95,98,105,116,115,0,109,111,116,105,111,110,32,118,101,99,116,111,114,32,111,117,116,32,111,102,32,98,111,117,110,100,115,58,32,77,86,32,61,32,40,37,100,44,32,37,100,41,44,32,98,111,117,110,100,97,114,105,101,115,32,61,32,40,48,44,32,48,44,32,37,100,44,32,37,100,41,10,0,0,0,0,0,0,0,0,101,114,114,111,114,32,77,88,70,32,68,45,49,48,32,111,110,108,121,32,115,117,112,112,111,114,116,32,51,48,47,52,48,47,53,48,32,109,98,105,116,47,115,10,0,0,0,0,98,114,111,107,101,110,32,111,114,32,101,109,112,116,121,32,105,110,100,101,120,10,0,0,79,82,73,69,78,84,65,84,73,79,78,0,0,0,0,0,101,110,99,111,100,101,114,0,79,118,101,114,102,108,111,119,46,32,66,114,111,107,101,110,32,115,97,109,112,108,101,63,10,0,0,0,0,0,0,0,68,117,112,108,105,99,97,116,101,32,115,116,114,101,97,109,32,105,100,32,37,100,10,0,65,108,108,32,112,114,111,103,114,97,109,115,32,104,97,118,101,32,112,109,116,44,32,104,101,97,100,101,114,115,32,102,111,117,110,100,10,0,0,0,32,97,113,61,37,100,0,0,71,67,83,69,95,79,83,85,57,49,65,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,108,97,114,103,101,44,32,105,103,110,111,114,105,110,103,32,98,117,102,102,101,114,32,108,105,109,105,116,115,32,116,111,32,109,117,120,32,105,116,10,0,0,0,0,0,68,67,84,32,97,108,103,111,114,105,116,104,109,0,0,0,84,105,109,101,115,116,97,109,112,32,100,101,99,108,97,114,101,100,32,98,101,102,111,114,101,32,97,110,121,32,115,116,114,101,97,109,10,0,0,0,98,102,105,0,0,0,0,0,115,101,116,32,105,110,105,116,105,97,108,32,84,105,109,101,67,111,100,101,32,118,97,108,117,101,46,0,0,0,0,0,87,73,68,84,72,0,0,0,83,105,122,101,32,97,110,100,32,119,105,100,116,104,47,104,101,105,103,104,116,32,101,120,112,114,101,115,115,105,111,110,115,32,99,97,110,110,111,116,32,98,101,32,115,101,116,32,97,116,32,116,104,101,32,115,97,109,101,32,116,105,109,101,46,10,0,0,0,0,0,0,109,52,118,44,109,52,97,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,108,117,109,97,95,114,97,100,105,117,115,58,37,102,32,108,117,109,97,95,112,114,101,95,102,105,108,116,101,114,95,114,97,100,105,117,115,58,58,37,102,32,108,117,109,97,95,115,116,114,101,110,103,116,104,58,37,102,32,99,104,114,111,109,97,95,114,97,100,105,117,115,58,37,102,32,99,104,114,111,109,97,95,112,114,101,95,102,105,108,116,101,114,95,114,97,100,105,117,115,58,37,102,32,99,104,114,111,109,97,95,115,116,114,101,110,103,116,104,58,37,102,10,0,0,0,0,0,110,117,109,32,60,32,40,49,85,76,76,60,60,53,54,41,45,49,0,0,0,0,0,0,70,105,108,101,32,109,111,118,101,115,32,98,101,121,111,110,100,32,109,97,120,46,32,97,108,108,111,119,101,100,32,100,101,112,116,104,32,40,37,100,41,10,0,0,0,0,0,0,98,115,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,0,0,0,0,0,100,101,115,104,97,107,101,0,32,112,98,95,114,97,116,105,111,61,37,46,50,102,0,0,71,67,83,69,95,79,83,85,56,54,70,0,0,0,0,0,115,101,116,32,114,97,110,103,101,32,102,111,114,32,108,111,111,107,105,110,103,32,97,116,32,116,104,101,32,102,105,114,115,116,32,115,101,113,117,101,110,99,101,32,110,117,109,98,101,114,0,0,0,0,0,0,100,99,116,0,0,0,0,0,116,105,102,102,0,0,0,0,68,105,114,97,99,0,0,0,97,110,103,108,101,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,104,108,115,95,119,114,97,112,0,0,0,0,0,0,0,0,84,104,101,32,98,105,116,109,97,112,32,102,105,108,101,32,110,97,109,101,32,105,115,32,109,97,110,100,97,116,111,114,121,10,0,0,0,0,0,0,35,69,88,84,45,88,45,83,84,82,69,65,77,45,73,78,70,58,0,0,0,0,0,0,102,108,118,0,0,0,0,0,77,69,95,77,65,80,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,83,65,66,32,100,105,97,109,111,110,100,10,0,0,0,0,0,0,0,86,105,100,101,111,32,99,111,100,101,99,32,39,37,115,39,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,0,0,104,101,105,103,104,116,0,0,106,108,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,104,101,97,100,101,114,32,101,108,101,109,101,110,116,32,48,120,37,48,50,120,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,0,0,102,114,97,109,101,61,32,37,53,100,32,113,61,32,37,50,46,49,102,32,0,0,0,0,80,83,78,82,32,97,118,101,114,97,103,101,58,37,48,46,50,102,32,109,105,110,58,37,48,46,50,102,32,109,97,120,58,37,48,46,50,102,10,0,32,105,112,95,114,97,116,105,111,61,37,46,50,102,0,0,71,67,83,69,95,71,69,77,49,48,67,0,0,0,0,0,105,110,105,116,105,97,108,32,99,111,109,112,108,101,120,105,116,121,32,102,111,114,32,49,45,112,97,115,115,32,101,110,99,111,100,105,110,103,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,100,105,114,97,99,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,113,117,97,108,105,116,121,0,100,101,102,97,117,108,116,0,69,114,114,111,114,32,103,101,110,101,114,97,116,105,110,103,32,104,117,102,102,109,97,110,32,116,97,98,108,101,10,0,115,97,109,101,95,113,117,97,110,116,0,0,0,0,0,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,105,100,120,32,43,32,49,32,60,61,32,97,115,102,95,115,116,45,62,112,107,116,46,115,105,122,101,32,47,32,97,115,102,95,115,116,45,62,100,115,95,99,104,117,110,107,95,115,105,122,101,0,0,0,0,0,109,111,100,101,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,117,110,32,111,118,101,114,114,117,110,10,0,0,0,0,99,112,105,45,62,114,101,102,95,102,114,97,109,101,95,102,108,97,103,115,32,38,32,86,80,57,95,76,65,83,84,95,70,76,65,71,0,0,0,0,48,120,37,48,52,88,0,0,49,46,48,0,0,0,0,0,120,48,0,0,0,0,0,0,111,99,108,0,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,99,104,97,110,110,101,108,115,32,109,97,112,115,32,105,110,32,116,104,101,32,102,111,114,109,97,116,32,39,105,110,112,117,116,95,115,116,114,101,97,109,46,105,110,112,117,116,95,99,104,97,110,110,101,108,45,111,117,116,112,117,116,95,99,104,97,110,110,101,108,46,0,0,0,0,0,0,0,37,108,102,0,0,0,0,0,32,102,114,97,109,101,45,112,97,99,107,105,110,103,61,37,100,0,0,0,0,0,0,0,71,67,83,69,95,87,71,83,56,52,0,0,0,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,108,105,99,101,32,101,110,100,32,98,101,102,111,114,101,32,115,116,97,114,116,10,0,114,99,95,105,110,105,116,95,99,112,108,120,0,0,0,0,69,115,99,97,112,101,32,49,50,52,0,0,0,0,0,0,98,49,0,0,0,0,0,0,71,65,81,32,103,97,105,110,32,103,114,111,117,112,32,99,111,100,101,32,111,117,116,45,111,102,45,114,97,110,103,101,10,0,0,0,0,0,0,0,82,101,109,111,118,101,100,0,42,98,111,116,116,111,109,95,105,110,100,101,120,32,60,61,32,114,99,45,62,119,111,114,115,116,95,113,117,97,108,105,116,121,32,38,38,32,42,98,111,116,116,111,109,95,105,110,100,101,120,32,62,61,32,114,99,45,62,98,101,115,116,95,113,117,97,108,105,116,121,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,112,104,97,115,101,114,46,99,0,0,0,0,0,0,0,0,100,101,108,111,103,111,0,0,119,105,100,116,104,0,0,0,115,45,62,110,98,95,105,110,112,117,116,115,32,62,32,49,0,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,100,101,112,116,104,0,0,0,33,40,109,105,95,99,111,108,32,38,32,40,109,105,95,119,105,100,116,104,32,45,32,49,41,41,32,38,38,32,33,40,109,105,95,114,111,119,32,38,32,40,109,105,95,104,101,105,103,104,116,32,45,32,49,41,41,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,119,97,118,101,108,101,116,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,114,101,113,117,101,115,116,101,100,32,102,114,97,109,101,0,0,0,114,97,116,101,0,0,0,0,114,105,110,103,50,0,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,116,114,97,110,115,102,111,114,109,32,115,105,122,101,34,0,0,0,115,101,116,32,116,104,101,32,98,97,105,108,111,117,116,32,118,97,108,117,101,0,0,0,115,101,116,32,114,117,108,101,0,0,0,0,0,0,0,0,114,97,110,100,111,109,95,102,105,108,108,95,114,97,116,105,111,0,0,0,0,0,0,0,45,97,115,121,110,99,32,105,115,32,102,111,114,119,97,114,100,101,100,32,116,111,32,108,97,118,102,105,32,115,105,109,105,108,97,114,108,121,32,116,111,32,45,97,102,32,97,114,101,115,97,109,112,108,101,61,37,115,46,10,0,0,0,0,100,101,105,110,116,101,114,108,97,99,101,32,97,108,108,32,102,114,97,109,101,115,0,0,115,101,116,32,102,111,114,119,97,114,100,47,98,97,99,107,119,97,114,100,32,109,111,100,101,0,0,0,0,0,0,0,73,108,108,101,103,97,108,32,105,110,116,114,97,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,10,0,0,100,101,102,97,117,108,116,0,32,99,114,111,112,95,114,101,99,116,61,37,117,44,37,117,44,37,117,44,37,117,0,0,71,67,83,69,95,87,97,114,79,102,102,105,99,101,0,0,119,58,37,100,32,104,58,37,100,32,100,105,114,58,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,114,111,116,97,116,105,111,110,58,37,115,32,118,102,108,105,112,58,37,100,10,0,0,0,0,0,81,80,32,111,102,102,115,101,116,32,98,101,116,119,101,101,110,32,80,45,32,97,110,100,32,73,45,102,114,97,109,101,115,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,101,115,99,97,112,101,49,50,52,0,0,0,0,0,0,0,37,100,32,102,114,97,109,101,115,32,108,101,102,116,32,105,110,32,116,104,101,32,113,117,101,117,101,32,111,110,32,99,108,111,115,105,110,103,10,0,120,0,0,0,0,0,0,0,115,97,109,101,113,0,0,0,115,105,100,101,32,98,121,32,115,105,100,101,32,114,105,103,104,116,32,102,105,114,115,116,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,113,117,97,110,116,105,122,97,116,105,111,110,32,117,110,105,116,115,58,32,37,100,33,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,115,99,97,108,101,100,32,115,111,117,114,99,101,32,98,117,102,102,101,114,0,115,0,0,0,0,0,0,0,100,101,106,117,100,100,101,114,0,0,0,0,0,0,0,0,115,101,116,32,98,97,99,107,103,114,111,117,110,100,32,102,105,108,108,32,99,111,108,111,114,0,0,0,0,0,0,0,33,111,107,32,124,124,32,40,119,111,114,107,101,114,45,62,115,116,97,116,117,115,95,32,61,61,32,79,75,41,0,0,111,102,102,115,101,116,58,32,37,100,32,108,101,110,103,116,104,58,32,37,100,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,104,0,0,0,0,0,0,0,108,105,110,101,97,114,0,0,105,110,95,119,0,0,0,0,97,108,108,95,115,101,101,100,0,0,0,0,0,0,0,0,110,58,37,102,32,116,58,37,102,32,112,111,115,58,37,102,32,120,58,37,102,32,120,105,58,37,100,32,121,58,37,102,32,121,105,58,37,100,10,0,87,97,114,110,105,110,103,58,32,68,101,115,105,114,101,100,32,119,105,100,116,104,32,116,111,111,32,108,97,114,103,101,44,32,99,104,97,110,103,101,100,32,116,111,32,37,100,10,0,0,0,0,0,0,0,0,99,49,95,115,101,101,100,0,105,32,60,32,70,82,65,77,69,95,66,85,70,70,69,82,83,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,112,108,97,110,97,114,0,0,111,120,99,102,45,62,110,117,109,98,101,114,95,111,102,95,108,97,121,101,114,115,32,60,61,32,86,80,88,95,84,83,95,77,65,88,95,76,65,89,69,82,83,0,0,0,0,0,32,110,97,108,95,104,114,100,61,37,115,32,102,105,108,108,101,114,61,37,100,0,0,0,71,67,83,69,95,83,116,114,117,118,101,49,56,54,48,0,105,95,113,111,102,102,115,101,116,0,0,0,0,0,0,0,109,97,120,95,100,114,111,112,95,99,111,117,110,116,58,37,100,32,104,105,58,37,100,32,108,111,58,37,100,32,102,114,97,99,58,37,102,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,76,50,32,118,105,100,101,111,0,0,0,0,0,0,0,115,101,116,32,85,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,115,119,97,112,32,97,108,112,104,97,32,102,105,101,108,100,115,0,0,0,0,0,0,0,114,99,95,114,101,115,105,122,101,95,100,111,119,110,95,116,104,114,101,115,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,93,0,0,0,0,0,0,102,111,114,99,101,32,118,105,100,101,111,32,99,111,100,101,99,32,40,39,99,111,112,121,39,32,116,111,32,99,111,112,121,32,115,116,114,101,97,109,41,0,0,0,0,0,0,0,72,58,37,48,46,49,102,42,80,73,32,104,58,37,48,46,49,102,32,115,58,37,48,46,49,102,32,98,58,37,48,46,102,32,116,58,37,48,46,49,102,32,110,58,37,100,10,0,101,110,97,98,108,101,95,97,117,116,111,95,97,108,116,95,114,101,102,32,101,120,112,101,99,116,101,100,32,98,111,111,108,101,97,110,0,0,0,0,101,111,98,32,60,61,32,49,54,0,0,0,0,0,0,0,99,111,108,117,109,110,0,0,69,118,101,110,116,115,0,0,84,0,0,0,0,0,0,0,99,111,109,112,108,101,116,101,100,58,32,37,100,32,10,0,68,114,111,112,112,105,110,103,32,37,100,32,102,114,97,109,101,40,115,41,46,10,0,0,91,83,99,114,105,112,116,32,73,110,102,111,93,13,10,83,99,114,105,112,116,84,121,112,101,58,32,118,52,46,48,48,43,13,10,13,10,91,86,52,43,32,83,116,121,108,101,115,93,13,10,70,111,114,109,97,116,58,32,78,97,109,101,44,32,70,111,110,116,110,97,109,101,44,32,70,111,110,116,115,105,122,101,44,32,80,114,105,109,97,114,121,67,111,108,111,117,114,44,32,83,101,99,111,110,100,97,114,121,67,111,108,111,117,114,44,32,79,117,116,108,105,110,101,67,111,108,111,117,114,44,32,66,97,99,107,67,111,108,111,117,114,44,32,66,111,108,100,44,32,73,116,97,108,105,99,44,32,85,110,100,101,114,108,105,110,101,44,32,66,111,114,100,101,114,83,116,121,108,101,44,32,79,117,116,108,105,110,101,44,32,83,104,97,100,111,119,44,32,65,108,105,103,110,109,101,110,116,44,32,77,97,114,103,105,110,76,44,32,77,97,114,103,105,110,82,44,32,77,97,114,103,105,110,86,44,32,65,108,112,104,97,76,101,118,101,108,44,32,69,110,99,111,100,105,110,103,13,10,83,116,121,108,101,58,32,68,101,102,97,117,108,116,44,37,115,44,37,100,44,38,72,37,120,44,38,72,37,120,44,38,72,37,120,44,38,72,37,120,44,37,100,44,37,100,44,37,100,44,49,44,49,44,48,44,37,100,44,49,48,44,49,48,44,49,48,44,48,44,48,13,10,13,10,91,69,118,101,110,116,115,93,13,10,70,111,114,109,97,116,58,32,76,97,121,101,114,44,32,83,116,97,114,116,44,32,69,110,100,44,32,83,116,121,108,101,44,32,84,101,120,116,13,10,0,0,0,0,0,0,0,0,98,102,102,0,0,0,0,0,99,108,82,101,108,101,97,115,101,67,111,109,109,97,110,100,81,117,101,117,101,0,0,0,97,108,97,99,0,0,0,0,118,102,45,62,110,101,120,116,32,61,61,32,48,76,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,114,103,98,52,0,0,0,0,66,108,97,110,99,104,101,100,65,108,109,111,110,100,0,0,82,101,113,117,101,115,116,101,100,32,112,108,97,110,101,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,46,10,0,0,0,0,0,0,0,0,101,113,0,0,0,0,0,0,73,110,118,97,108,105,100,32,100,97,116,97,32,102,111,117,110,100,32,119,104,101,110,32,112,114,111,99,101,115,115,105,110,103,32,105,110,112,117,116,0,0,0,0,0,0,0,0,83,76,0,0,0,0,0,0,100,101,102,97,117,108,116,0,97,99,99,117,114,97,116,101,32,114,111,117,110,100,105,110,103,0,0,0,0,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,115,119,114,101,115,97,109,112,108,101,46,99,0,0,0,0,0,0,104,98,0,0,0,0,0,0,101,120,116,114,117,100,101,100,32,101,100,103,101,32,118,97,108,117,101,32,97,116,32,98,108,97,110,107,32,108,111,99,97,116,105,111,110,115,0,0,79,110,108,121,32,112,108,97,110,97,114,32,102,111,114,109,97,116,115,32,119,105,116,104,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,99,111,109,112,111,110,101,110,116,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,92,109,111,118,101,40,37,100,44,37,100,44,37,100,44,37,100,44,37,100,44,37,100,41,37,49,91,92,125,93,37,110,0,0,0,0,0,0,0,0,97,108,97,99,0,0,0,0,109,97,114,107,32,109,97,105,110,32,105,110,112,117,116,32,97,115,32,97,32,112,114,101,45,112,114,111,99,101,115,115,101,100,32,105,110,112,117,116,32,97,110,100,32,97,99,116,105,118,97,116,101,32,99,108,101,97,110,32,115,111,117,114,99,101,32,105,110,112,117,116,32,115,116,114,101,97,109,0,65,68,80,67,77,32,73,77,65,32,67,82,89,79,32,65,80,67,0,0,0,0,0,0,98,105,116,100,101,112,116,104,61,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,10,0,0,0,0,0,83,116,97,114,116,32,102,114,101,113,117,101,110,99,121,32,98,111,114,100,101,114,32,116,111,111,32,104,105,103,104,58,32,37,100,10,0,0,0,0,70,65,65,67,45,105,110,115,112,105,114,101,100,32,109,101,116,104,111,100,0,0,0,0,99,111,100,101,32,62,61,32,48,32,38,38,32,99,111,100,101,32,60,61,32,54,32,38,38,32,108,111,103,50,119,32,62,61,32,48,0,0,0,0,48,46,52,47,48,46,53,0,98,108,111,99,107,95,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,10,0,108,105,98,97,118,99,111,100,101,99,47,119,109,97,108,111,115,115,108,101,115,115,100,101,99,46,99,0,0,0,0,0,32,113,112,61,37,100,0,0,71,67,83,69,95,80,108,101,115,115,105,115,49,56,49,55,0,0,0,0,0,0,0,0,109,97,120,32,115,121,109,98,111,108,32,37,100,32,62,32,97,108,112,104,97,98,101,116,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,97,105,99,0,0,0,0,0,78,111,32,98,108,111,99,107,32,119,105,116,104,32,101,110,116,114,111,112,121,32,105,110,102,111,10,0,0,0,0,0,81,80,32,102,97,99,116,111,114,32,98,101,116,119,101,101,110,32,80,45,32,97,110,100,32,73,45,102,114,97,109,101,115,0,0,0,0,0,0,0,77,111,114,101,32,98,108,111,99,107,115,32,101,110,100,101,100,32,116,104,97,110,32,99,111,100,101,100,33,10,0,0,109,111,100,101,95,115,101,116,117,112,45,62,109,97,112,112,105,110,103,0,0,0,0,0,105,110,95,119,0,0,0,0,71,111,116,32,110,111,32,115,112,114,105,116,101,115,10,0,72,105,103,104,32,49,48,32,73,110,116,114,97,0,0,0,70,73,69,76,68,84,88,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,114,108,50,0,0,0,0,0,97,100,112,99,109,95,97,100,120,0,0,0,0,0,0,0,109,111,100,101,0,0,0,0,83,112,101,99,105,102,105,101,100,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,98,108,117,101,32,103,97,105,110,32,102,111,114,32,116,104,101,32,98,108,117,101,32,99,104,97,110,110,101,108,0,0,79,108,100,32,84,77,50,32,104,101,97,100,101,114,0,0,97,100,112,99,109,95,97,100,120,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,108,117,109,97,32,114,97,100,105,117,115,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,118,99,111,100,101,99,0,0,80,114,111,106,83,116,100,80,97,114,97,108,108,101,108,49,71,101,111,75,101,121,0,0,84,104,105,115,32,102,111,114,109,97,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,98,112,112,61,37,100,44,32,98,112,112,99,111,117,110,116,61,37,100,41,10,0,0,0,0,0,117,49,58,32,37,120,32,117,50,58,32,37,120,32,117,51,58,32,37,120,32,99,111,109,112,114,101,115,115,101,100,32,100,97,116,97,32,115,105,122,101,58,32,37,100,32,111,102,102,115,101,116,58,32,37,100,10,0,0,0,0,0,0,0,32,99,111,108,111,114,61,34,35,37,48,54,120,34,0,0,32,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,108,111,119,32,98,121,116,101,115,32,116,114,101,101,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,97,108,108,95,109,111,100,101,0,0,0,0,0,0,0,0,115,117,98,99,111,100,101,99,32,51,55,32,99,111,109,112,114,101,115,115,105,111,110,32,37,100,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,108,97,115,116,32,102,114,97,109,101,32,98,117,102,102,101,114,0,0,0,0,115,45,62,112,105,99,116,95,116,121,112,101,32,33,61,32,65,86,95,80,73,67,84,85,82,69,95,84,89,80,69,95,66,32,124,124,32,33,115,45,62,108,111,119,95,100,101,108,97,121,0,0,0,0,0,0,116,101,120,94,113,67,111,109,112,0,0,0,0,0,0,0,118,101,110,100,111,114,32,73,68,0,0,0,0,0,0,0,80,67,77,32,109,117,45,108,97,119,32,47,32,71,46,55,49,49,32,109,117,45,108,97,119,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,114,97,116,105,111,32,110,117,109,101,114,97,116,111,114,32,34,37,115,34,10,0,0,0,97,100,112,99,109,95,105,109,97,95,113,116,0,0,0,0,108,101,118,101,108,45,105,100,99,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,86,67,111,100,101,99,67,111,110,116,101,120,116,0,0,65,117,116,111,109,97,116,105,99,97,108,108,121,32,99,104,111,111,115,105,110,103,32,86,66,86,32,98,117,102,102,101,114,32,115,105,122,101,32,111,102,32,37,100,32,107,98,121,116,101,10,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,115,116,114,101,97,109,32,105,110,102,111,10,0,0,0,0,0,105,32,60,32,78,85,77,95,89,86,49,50,95,66,85,70,70,69,82,83,0,0,0,0,78,101,119,32,102,114,97,109,101,44,32,116,121,112,101,58,32,37,99,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,97,117,100,105,111,100,101,99,95,116,101,109,112,108,97,116,101,46,99,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,97,117,100,105,111,100,101,99,95,116,101,109,112,108,97,116,101,46,99,0,0,0,0,0,0,99,104,114,111,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,115,116,97,114,116,99,111,100,101,58,32,37,51,88,32,0,80,82,69,86,95,73,78,84,0,0,0,0,0,0,0,0,115,107,105,112,95,114,100,0,105,103,110,111,114,105,110,103,32,71,79,80,95,83,84,65,82,84,95,67,79,68,69,32,97,102,116,101,114,32,37,88,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,117,102,102,95,108,115,98,115,46,10,0,0,0,0,0,115,119,115,95,102,108,97,103,115,32,110,111,116,32,116,101,114,109,105,110,97,116,101,100,32,119,105,116,104,32,39,59,39,46,10,0,0,0,0,0,108,111,119,114,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,119,101,105,114,100,32,115,117,98,115,97,109,112,108,105,110,103,10,0,0,0,0,0,99,114,102,95,109,97,120,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,52,58,50,58,48,46,10,0,0,0,0,0,0,0,80,115,111,116,32,37,100,32,116,111,111,32,98,105,103,10,0,0,0,0,0,0,0,0,92,78,0,0,0,0,0,0,77,86,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,73,32,99,98,112,121,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,116,121,112,101,58,32,37,100,10,0,83,121,110,99,32,102,114,97,109,101,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,0,32,12,9,10,13,44,59,0,84,111,111,32,109,97,110,121,32,115,104,111,114,116,32,116,101,114,109,32,82,80,83,58,32,37,100,46,10,0,0,0,80,80,83,32,99,104,97,110,103,101,100,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,46,10,0,0,0,0,104,97,108,100,99,108,117,116,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,109,101,109,111,114,121,32,109,97,110,97,103,101,109,101,110,116,32,99,111,110,116,114,111,108,32,111,112,101,114,97,116,105,111,110,32,37,100,10,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,108,117,109,97,32,98,105,116,32,100,101,112,116,104,61,37,100,10,0,0,0,0,0,0,0,0,111,111,111,0,0,0,0,0,83,80,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,100,97,116,97,32,115,105,122,101,32,37,100,47,37,100,10,0,82,87,0,0,0,0,0,0,73,110,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,32,111,114,100,101,114,32,109,101,116,104,111,100,58,32,37,115,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,112,114,101,100,105,99,116,111,114,32,111,114,100,101,114,58,32,37,105,32,62,32,37,105,10,0,0,0,0,0,0,0,50,80,97,115,115,32,102,105,108,101,32,105,110,118,97,108,105,100,32,97,116,32,37,100,32,37,100,32,37,100,32,37,100,32,91,37,115,93,10,0,73,110,118,97,108,105,100,32,118,101,114,115,105,111,110,32,105,110,32,103,108,111,98,97,108,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,83,117,98,115,97,109,112,108,105,110,103,32,37,100,120,37,100,0,0,0,0,0,0,0,111,110,0,0,0,0,0,0,66,108,111,99,107,32,115,101,112,97,114,97,116,105,111,110,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,68,84,83,45,88,66,82,58,32,68,105,100,110,39,116,32,103,101,116,32,115,117,98,102,114,97,109,101,32,68,83,89,78,67,10,0,0,0,0,0,106,115,95,118,108,99,95,98,105,116,115,32,61,32,37,100,44,32,111,110,108,121,32,62,61,32,37,100,32,97,110,100,32,60,61,32,54,32,97,108,108,111,119,101,100,33,10,0,118,105,100,101,111,0,0,0,116,105,109,101,95,98,97,115,101,95,110,117,109,0,0,0,74,80,69,71,45,76,83,0,32,99,114,102,95,109,97,120,61,37,46,49,102,0,0,0,112,105,120,95,102,109,116,115,0,0,0,0,0,0,0,0,71,67,83,69,95,78,87,76,49,48,68,0,0,0,0,0,97,108,108,0,0,0,0,0,105,95,113,102,97,99,116,111,114,0,0,0,0,0,0,0,80,114,97,110,107,115,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,119,114,105,116,101,95,105,100,51,118,50,0,0,0,0,0,77,105,109,105,99,0,0,0,44,32,0,0,0,0,0,0,52,50,48,0,0,0,0,0,87,77,47,87,77,82,86,69,110,100,84,105,109,101,0,0,111,114,105,103,105,110,97,116,105,111,110,95,100,97,116,101,0,0,0,0,0,0,0,0,116,111,111,32,115,104,111,114,116,32,76,73,83,84,32,116,97,103,10,0,0,0,0,0,70,73,76,69,0,0,0,0,114,101,97,100,95,116,105,109,101,115,116,97,109,112,40,41,32,102,97,105,108,101,100,32,105,110,32,116,104,101,32,109,105,100,100,108,101,10,0,0,102,111,114,109,97,116,0,0,85,110,107,110,111,119,110,32,111,112,116,105,111,110,32,39,37,115,39,10,0,0,0,0,109,117,120,32,99,111,109,112,108,101,116,101,32,68,84,83,32,102,114,97,109,101,115,32,105,110,32,72,68,32,109,111,100,101,32,97,116,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,73,69,67,57,53,56,32,114,97,116,101,32,40,105,110,32,72,122,44,32,100,101,102,97,117,108,116,32,48,61,100,105,115,97,98,108,101,100,41,0,0,0,0,0,37,115,47,81,117,97,108,105,116,121,76,101,118,101,108,115,40,37,100,41,0,0,0,0,111,118,101,114,114,105,100,101,0,0,0,0,0,0,0,0,108,117,116,121,117,118,0,0,100,97,116,97,95,115,116,97,114,116,32,62,61,32,100,97,116,97,0,0,0,0,0,0,116,104,114,101,115,104,0,0,115,99,97,110,0,0,0,0,97,100,112,99,109,95,52,120,109,0,0,0,0,0,0,0,32,118,98,118,95,109,97,120,114,97,116,101,61,37,100,32,118,98,118,95,98,117,102,115,105,122,101,61,37,100,0,0,71,67,83,69,95,78,87,76,57,68,0,0,0,0,0,0,99,117,114,114,101,110,116,108,121,32,117,115,101,108,101,115,115,0,0,0,0,0,0,0,109,105,109,105,99,0,0,0,100,101,99,105,109,97,116,101,0,0,0,0,0,0,0,0,108,117,109,97,95,109,111,100,101,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,99,114,101,97,115,101,32,108,97,103,95,105,110,95,102,114,97,109,101,115,0,0,0,114,97,116,101,32,99,111,110,116,114,111,108,32,111,118,101,114,114,105,100,101,32,102,111,114,32,115,112,101,99,105,102,105,99,32,105,110,116,101,114,118,97,108,115,0,0,0,0,70,70,82,69,80,79,82,84,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,105,103,104,116,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,95,116,121,112,101,0,0,0,0,0,0,0,83,105,110,103,108,101,32,102,114,97,109,101,32,100,101,116,101,99,116,105,111,110,58,32,84,70,70,58,37,100,32,66,70,70,58,37,100,32,80,114,111,103,114,101,115,115,105,118,101,58,37,100,32,85,110,100,101,116,101,114,109,105,110,101,100,58,37,100,10,0,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,37,103,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,85,115,101,32,109,111,100,101,32,48,32,102,111,114,32,72,50,54,52,32,105,110,32,82,84,80,0,0,0,0,0,0,111,118,101,114,102,108,111,119,32,116,104,97,116,32,119,111,117,108,100,32,110,101,101,100,32,99,108,105,112,105,110,103,32,105,110,32,102,102,95,97,99,101,108,112,95,105,110,116,101,114,112,111,108,97,116,101,40,41,10,0,0,0,0,0,99,117,114,32,115,108,105,99,101,32,37,100,44,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,115,113,114,116,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,99,114,101,97,115,101,32,108,97,103,95,105,110,95,102,114,97,109,101,115,0,0,0,114,97,119,32,71,46,55,50,50,0,0,0,0,0,0,0,108,115,58,37,102,32,99,115,58,37,102,32,108,116,58,37,102,32,99,116,58,37,102,10,0,0,0,0,0,0,0,0,32,99,112,108,120,98,108,117,114,61,37,46,49,102,32,113,98,108,117,114,61,37,46,49,102,0,0,0,0,0,0,0,71,67,83,69,95,75,114,97,115,115,111,119,115,107,121,49,57,52,48,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,0,0,99,108,69,110,113,117,101,117,101,87,114,105,116,101,66,117,102,102,101,114,32,101,114,114,111,114,32,39,37,100,39,10,0,0,0,0,0,0,0,0,114,99,95,98,117,102,95,97,103,103,114,101,115,115,105,118,105,116,121,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,86,105,100,101,111,32,73,110,116,101,114,97,99,116,105,118,101,32,53,0,80,67,77,32,115,105,103,110,101,100,32,56,45,98,105,116,0,0,0,0,0,0,0,0,114,99,95,111,118,101,114,114,105,100,101,0,0,0,0,0,100,105,115,99,97,114,100,32,99,111,114,114,117,112,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,114,102,0,0,0,0,0,0,73,110,118,97,108,105,100,32,107,101,121,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,114,114,111,114,32,119,114,105,116,105,110,103,32,70,76,65,67,32,104,101,97,100,101,114,115,10,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,67,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,115,116,114,101,110,103,116,104,58,37,48,46,51,102,32,105,110,116,101,110,115,105,116,121,58,37,48,46,51,102,32,97,110,116,105,98,97,110,100,105,110,103,58,37,100,10,0,0,85,110,107,110,111,119,110,32,100,97,116,97,32,37,115,32,47,32,37,115,10,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,102,114,97,109,101,32,114,97,116,101,32,37,100,47,37,100,10,0,0,0,0,0,100,101,102,97,117,108,116,0,99,97,110,110,111,116,32,100,101,109,117,120,32,79,80,65,116,111,109,32,119,105,116,104,111,117,116,32,97,110,32,105,110,100,101,120,10,0,0,0,87,73,68,84,72,0,0,0,116,104,114,101,115,104,111,108,100,58,37,46,50,102,32,114,97,100,105,117,115,58,37,100,10,0,0,0,0,0,0,0,67,111,100,101,99,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,100,111,101,115,32,110,111,116,32,117,115,101,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,32,98,117,116,32,99,111,110,116,97,105,110,101,114,32,102,111,114,109,97,116,32,114,101,113,117,105,114,101,115,32,103,108,111,98,97,108,32,104,101,97,100,101,114,115,10,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,100,32,37,100,44,32,109,117,115,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,56,49,57,49,10,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,112,101,103,116,115,46,99,0,0,0,0,32,113,99,111,109,112,61,37,46,50,102,32,113,112,109,105,110,61,37,100,32,113,112,109,97,120,61,37,100,32,113,112,115,116,101,112,61,37,100,0,71,67,83,69,95,73,110,116,101,114,110,97,116,105,111,110], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2422944);
/* memory initializer */ allocate([97,108,49,57,54,55,0,0,97,118,97,105,108,95,100,97,116,97,62,48,0,0,0,0,115,101,116,32,114,97,116,101,99,111,110,116,114,111,108,32,98,117,102,102,101,114,32,115,105,122,101,32,40,105,110,32,98,105,116,115,41,0,0,0,116,105,109,101,115,116,97,109,112,58,0,0,0,0,0,0,105,110,100,101,111,53,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,112,51,101,110,99,46,99,0,0,0,0,100,105,115,99,97,114,100,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,65,32,108,117,109,105,110,97,110,99,101,32,111,114,32,82,71,66,32,101,120,112,114,101,115,115,105,111,110,32,105,115,32,109,97,110,100,97,116,111,114,121,10,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,115,116,101,112,0,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,40,33,56,120,56,32,38,38,32,33,52,120,52,41,10,0,0,100,99,116,100,110,111,105,122,0,0,0,0,0,0,0,0,105,80,111,100,32,72,46,50,54,52,32,77,80,52,32,40,77,80,69,71,45,52,32,80,97,114,116,32,49,52,41,0,99,101,110,116,101,114,95,109,105,120,95,108,101,118,101,108,0,0,0,0,0,0,0,0,97,114,116,105,115,116,0,0,102,111,114,109,97,116,0,0,77,66,45,116,114,101,101,32,102,114,97,109,101,116,121,112,101,32,37,100,32,100,111,101,115,110,39,116,32,109,97,116,99,104,32,97,99,116,117,97,108,32,102,114,97,109,101,116,121,112,101,32,37,100,46,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,10,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,82,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,37,100,32,102,114,97,109,101,115,32,105,110,44,32,37,100,32,102,114,97,109,101,115,32,111,117,116,59,32,37,100,32,102,114,97,109,101,115,32,100,114,111,112,112,101,100,44,32,37,100,32,102,114,97,109,101,115,32,100,117,112,108,105,99,97,116,101,100,46,10,0,0,32,98,105,116,114,97,116,101,61,37,100,32,114,97,116,101,116,111,108,61,37,46,49,102,0,0,0,0,0,0,0,0,71,67,83,69,95,73,110,116,101,114,110,97,116,105,111,110,97,108,49,57,50,52,0,0,115,116,97,114,116,95,110,117,109,98,101,114,95,114,97,110,103,101,0,0,0,0,0,0,98,117,102,115,105,122,101,0,110,111,102,111,114,109,97,116,0,0,0,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,86,105,100,101,111,32,73,110,116,101,114,97,99,116,105,118,101,32,52,0,116,103,97,0,0,0,0,0,97,99,51,0,0,0,0,0,118,100,116,0,0,0,0,0,97,97,115,99,0,0,0,0,111,114,100,101,114,0,0,0,84,80,85,66,0,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,112,108,97,121,108,105,115,116,32,101,110,116,114,105,101,115,0,0,35,69,88,84,77,51,85,0,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,100,105,114,101,99,116,111,114,121,32,37,115,10,0,0,97,116,32,109,111,115,116,32,111,110,101,32,118,105,100,101,111,32,115,116,114,101,97,109,32,105,115,32,115,117,112,112,111,114,116,101,100,32,105,110,32,102,108,118,10,0,0,0,119,105,100,116,104,0,0,0,101,110,100,32,111,102,32,104,101,97,100,101,114,32,98,108,111,99,107,32,114,101,97,99,104,101,100,10,0,0,0,0,102,111,112,101,110,0,0,0,32,99,114,102,61,37,46,49,102,0,0,0,0,0,0,0,71,67,83,69,95,73,110,100,111,110,101,115,105,97,110,78,97,116,105,111,110,97,108,83,112,104,101,114,111,105,100,0,83,101,116,32,109,105,110,105,109,117,109,32,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,40,105,110,32,98,105,116,115,47,115,41,46,32,77,111,115,116,32,117,115,101,102,117,108,32,105,110,32,115,101,116,116,105,110,103,32,117,112,32,97,32,67,66,82,32,101,110,99,111,100,101,46,32,73,116,32,105,115,32,111,102,32,108,105,116,116,108,101,32,117,115,101,32,111,116,104,101,114,119,105,115,101,46,0,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,44,32,115,117,99,104,32,97,115,32,54,52,48,120,52,56,48,32,111,114,32,104,100,55,50,48,46,0,0,0,0,0,0,0,105,110,100,101,111,52,0,0,69,120,112,101,99,116,101,100,32,116,111,32,114,101,97,100,32,37,100,32,83,66,82,32,98,121,116,101,115,32,97,99,116,117,97,108,108,121,32,114,101,97,100,32,37,100,46,10,0,0,0,0,0,0,0,0,109,97,105,110,0,0,0,0,99,108,67,114,101,97,116,101,66,117,102,102,101,114,0,0,100,105,115,97,98,108,101,32,118,105,100,101,111,0,0,0,83,117,98,116,105,116,108,101,32,115,116,114,101,97,109,115,32,111,116,104,101,114,32,116,104,97,110,32,68,105,118,88,32,88,83,85,66,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,65,86,73,32,109,117,120,101,114,46,10,0,0,0,0,0,0,70,105,108,101,32,105,115,32,116,114,117,110,99,97,116,101,100,32,97,100,106,117,115,116,105,110,103,32,100,117,114,97,116,105,111,110,10,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,116,121,112,101,0,0,0,0,111,102,102,115,101,116,32,43,32,97,115,102,95,115,116,45,62,100,115,95,99,104,117,110,107,95,115,105,122,101,32,60,61,32,97,115,102,95,115,116,45,62,112,107,116,46,115,105,122,101,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,97,99,0,0,0,0,0,100,115,116,45,62,105,95,115,105,122,101,32,60,32,100,115,116,45,62,105,95,109,97,120,95,115,105,122,101,0,0,0,114,103,98,50,52,0,0,0,116,121,112,101,58,37,115,32,115,116,97,114,116,95,102,114,97,109,101,58,37,100,32,110,98,95,102,114,97,109,101,115,58,37,100,32,97,108,112,104,97,58,37,100,10,0,0,0,115,101,116,32,118,111,108,117,109,101,32,97,100,106,117,115,116,109,101,110,116,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,114,97,110,100,111,109,0,0,68,101,103,101,110,101,114,97,116,101,32,99,111,101,102,102,105,99,105,101,110,116,115,32,119,104,105,108,101,32,114,101,110,111,114,109,97,108,105,122,105,110,103,10,0,0,0,0,109,97,112,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,111,112,116,105,111,110,32,118,97,108,117,101,32,34,37,115,34,32,97,115,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,10,0,0,0,0,32,124,0,0,0,0,0,0,99,113,112,0,0,0,0,0,71,67,83,69,95,72,101,108,109,101,114,116,49,57,48,54,0,0,0,0,0,0,0,0,109,105,110,114,97,116,101,0,97,108,112,104,97,101,120,116,114,97,99,116,0,0,0,0,108,105,98,97,118,117,116,105,108,47,109,97,116,104,101,109,97,116,105,99,115,46,99,0,83,117,110,32,82,97,115,116,101,114,102,105,108,101,32,105,109,97,103,101,0,0,0,0,98,48,0,0,0,0,0,0,32,32,32,32,76,97,115,116,32,109,101,115,115,97,103,101,32,114,101,112,101,97,116,101,100,32,37,100,32,116,105,109,101,115,10,0,0,0,0,0,97,98,115,40,115,114,99,95,108,105,110,101,115,105,122,101,41,32,62,61,32,98,121,116,101,119,105,100,116,104,0,0,82,73,80,69,77,68,49,50,56,0,0,0,0,0,0,0,118,50,49,48,32,105,110,112,117,116,32,105,115,32,111,110,108,121,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,98,105,116,45,100,101,112,116,104,32,111,102,32,49,48,32,98,105,116,115,10,0,0,0,0,0,0,0,0,118,110,0,0,0,0,0,0,97,97,99,0,0,0,0,0,99,111,100,101,98,111,111,107,95,108,101,110,103,116,104,0,102,99,99,0,0,0,0,0,48,0,0,0,0,0,0,0,105,110,102,111,32,33,61,32,48,76,0,0,0,0,0,0,85,110,100,101,102,105,110,101,100,32,99,111,110,115,116,97,110,116,32,111,114,32,109,105,115,115,105,110,103,32,39,40,39,32,105,110,32,39,37,115,39,10,0,0,0,0,0,0,66,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,104,105,103,104,0,0,0,0,97,54,52,109,117,108,116,105,0,0,0,0,0,0,0,0,115,101,116,32,102,97,100,101,32,99,117,114,118,101,32,116,121,112,101,0,0,0,0,0,111,117,116,95,103,97,105,110,32,37,102,32,99,97,110,32,99,97,117,115,101,32,115,97,116,117,114,97,116,105,111,110,32,111,102,32,111,117,116,112,117,116,10,0,0,0,0,0,99,104,111,115,101,110,95,114,97,116,101,32,60,32,73,78,84,95,77,65,88,32,38,38,32,99,104,111,115,101,110,95,100,105,115,116,32,60,32,73,78,84,54,52,95,77,65,88,0,0,0,0,0,0,0,0,32,40,0,0,0,0,0,0,56,115,118,120,95,102,105,98,0,0,0,0,0,0,0,0,110,98,95,115,97,109,112,108,101,115,0,0,0,0,0,0,112,114,111,102,105,108,101,32,60,32,77,65,88,95,80,82,79,70,73,76,69,83,0,0,32,10,9,0,0,0,0,0,115,0,0,0,0,0,0,0,56,98,112,115,0,0,0,0,48,0,0,0,0,0,0,0,114,105,110,103,49,0,0,0,108,105,98,115,119,115,99,97,108,101,47,111,117,116,112,117,116,46,99,0,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,95,105,110,116,101,114,110,97,108,46,104,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,112,97,114,116,105,116,105,111,110,32,116,121,112,101,34,0,0,0,98,97,105,108,111,117,116,0,114,117,108,101,0,0,0,0,98,97,100,32,100,115,116,32,105,109,97,103,101,32,112,111,105,110,116,101,114,115,10,0,115,101,116,32,114,117,108,101,0,0,0,0,0,0,0,0,58,102,105,114,115,116,95,112,116,115,61,48,0,0,0,0,115,99,97,108,101,114,32,102,108,97,103,115,0,0,0,0,97,108,108,0,0,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,114,101,115,97,109,112,108,101,46,99,0,0,0,0,0,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,100,105,116,104,101,114,46,99,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,97,117,100,105,111,99,111,110,118,101,114,116,46,99,0,0,0,0,114,105,103,104,116,0,0,0,109,111,100,101,0,0,0,0,100,114,97,119,103,114,105,100,0,0,0,0,0,0,0,0,117,115,101,32,79,112,101,110,67,76,32,102,105,108,116,101,114,105,110,103,32,99,97,112,97,98,105,108,105,116,105,101,115,0,0,0,0,0,0,0,97,98,114,0,0,0,0,0,71,67,83,69,95,71,82,83,49,57,56,48,0,0,0,0,119,58,37,100,32,104,58,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,40,112,97,115,115,116,104,114,111,117,103,104,32,109,111,100,101,41,10,0,0,0,0,0,0,83,101,116,32,109,97,120,105,109,117,109,32,98,105,116,114,97,116,101,32,116,111,108,101,114,97,110,99,101,32,40,105,110,32,98,105,116,115,47,115,41,46,32,82,101,113,117,105,114,101,115,32,98,117,102,115,105,122,101,32,116,111,32,98,101,32,115,101,116,46,0,0,118,108,112,102,0,0,0,0,111,99,108,0,0,0,0,0,115,117,110,114,97,115,116,0,108,105,98,115,119,114,101,115,97,109,112,108,101,47,114,101,109,97,116,114,105,120,46,99,0,0,0,0,0,0,0,0,52,120,109,0,0,0,0,0,112,112,58,32,77,105,115,115,105,110,103,32,97,114,103,117,109,101,110,116,10,0,0,0,48,49,50,118,0,0,0,0,66,105,113,117,97,100,32,102,105,108,116,101,114,32,99,117,114,114,101,110,116,108,121,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,104,105,103,104,45,112,97,115,115,32,97,110,100,32,108,111,119,45,112,97,115,115,32,102,105,108,116,101,114,32,109,111,100,101,115,10,0,0,0,0,0,0,100,101,112,114,101,99,97,116,101,100,32,117,115,101,32,45,103,32,49,0,0,0,0,0,115,98,115,114,0,0,0,0,112,115,32,101,120,116,101,110,115,105,111,110,32,111,118,101,114,102,108,111,119,32,37,100,10,0,0,0,0,0,0,0,78,111,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,10,0,0,0,0,122,109,98,118,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,68,69,80,84,72,0,0,0,114,120,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,49,54,10,0,0,0,0,102,105,108,108,99,111,108,111,114,0,0,0,0,0,0,0,119,58,32,37,100,32,104,58,32,37,100,10,0,0,0,0,77,69,95,77,65,80,32,115,105,122,101,32,109,97,121,32,98,101,32,97,32,108,105,116,116,108,101,32,115,109,97,108,108,32,102,111,114,32,116,104,101,32,115,101,108,101,99,116,101,100,32,100,105,97,109,111,110,100,32,115,105,122,101,10,0,0,0,0,0,0,0,0,122,109,98,118,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,107,98,100,119,105,110,46,99,0,0,0,0,0,73,110,112,117,116,115,32,109,117,115,116,32,98,101,32,111,102,32,115,97,109,101,32,112,105,120,101,108,32,102,111,114,109,97,116,46,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,105,110,116,114,97,120,56,46,99,0,0,0,0,100,101,102,97,117,108,116,0,122,101,114,111,99,111,100,101,99,0,0,0,0,0,0,0,98,115,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,102,118,49,46,99,0,0,0,0,0,0,0,115,101,116,32,105,110,116,101,114,112,111,108,97,116,105,111,110,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,99,111,100,101,10,0,79,112,116,105,111,110,32,37,115,32,119,97,115,32,110,111,116,32,115,101,116,46,10,0,67,97,110,110,111,116,32,117,115,101,32,112,114,101,118,105,111,117,115,32,112,105,99,116,117,114,101,32,105,110,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,10,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,121,117,118,52,0,0,0,0,82,101,115,101,114,118,101,100,32,102,114,97,109,101,32,116,121,112,101,10,0,0,0,0,121,117,118,52,0,0,0,0,84,104,101,32,114,103,98,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,32,97,110,100,32,105,115,32,111,118,101,114,114,105,100,105,110,103,32,116,104,101,32,102,111,114,109,97,116,32,111,112,116,105,111,110,44,32,117,115,101,32,102,111,114,109,97,116,32,105,110,115,116,101,97,100,10,0,0,0,99,121,99,108,101,0,0,0,84,114,121,105,110,103,32,116,111,32,114,101,109,111,118,101,32,37,100,32,115,97,109,112,108,101,115,44,32,98,117,116,32,116,104,101,32,113,117,101,117,101,32,105,115,32,101,109,112,116,121,10,0,0,0,0,87,97,114,110,105,110,103,58,32,68,101,115,105,114,101,100,32,119,105,100,116,104,32,116,111,111,32,115,109,97,108,108,44,32,99,104,97,110,103,101,100,32,116,111,32,37,100,10,0,0,0,0,0,0,0,0,71,72,65,32,80,104,97,115,101,32,115,104,105,102,116,105,110,103,0,0,0,0,0,0,99,48,102,0,0,0,0,0,121,111,112,0,0,0,0,0,123,92,0,0,0,0,0,0,121,52,49,112,0,0,0,0,82,71,66,0,0,0,0,0,68,105,97,108,111,103,117,101,58,32,37,108,100,44,0,0,101,110,99,111,100,105,110,103,32,97,115,32,50,52,32,98,105,116,115,45,112,101,114,45,115,97,109,112,108,101,10,0,115,121,110,116,97,120,32,101,108,101,109,101,110,116,32,117,110,115,117,112,112,111,114,116,101,100,58,32,37,100,10,0,121,52,49,112,0,0,0,0,84,111,111,32,115,109,97,108,108,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,105,32,60,32,109,98,115,95,105,110,95,102,114,97,109,101,0,0,0,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,65,68,88,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,99,98,114,0,0,0,0,0,71,67,83,69,95,69,118,101,114,101,115,116,49,56,51,48,77,111,100,105,102,105,101,100,0,0,0,0,0,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,111,117,116,112,117,116,32,102,105,108,101,115,58,32,0,0,0,0,97,100,112,99,109,95,105,109,97,95,119,97,118,0,0,0,109,97,120,114,97,116,101,0,84,104,101,32,72,97,108,100,32,67,76,85,84,32,119,105,100,116,104,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,108,101,118,101,108,10,0,0,0,80,67,32,80,97,105,110,116,98,114,117,115,104,32,80,67,88,32,105,109,97,103,101,0,117,0,0,0,0,0,0,0,109,97,105,110,0,0,0,0,120,97,110,95,119,99,52,0,97,100,112,99,109,95,97,102,99,0,0,0,0,0,0,0,97,108,112,104,97,95,115,119,97,112,0,0,0,0,0,0,114,99,95,114,101,115,105,122,101,95,117,112,95,116,104,114,101,115,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,93,0,0,0,0,0,0,0,0,105,110,116,114,97,0,0,0,120,119,100,0,0,0,0,0,66,114,105,103,104,116,110,101,115,115,32,118,97,108,117,101,32,110,111,116,32,105,110,32,114,97,110,103,101,32,91,37,100,44,37,100,93,58,32,99,108,105,112,112,105,110,103,32,118,97,108,117,101,32,116,111,32,37,48,46,49,102,10,0,107,102,95,109,105,110,95,100,105,115,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,97,117,116,111,32,109,111,100,101,44,32,117,115,101,32,48,32,111,114,32,107,102,95,109,97,120,95,100,105,115,116,32,105,110,115,116,101,97,100,46,0,0,0,114,111,119,0,0,0,0,0,97,99,51,0,0,0,0,0,99,0,0,0,0,0,0,0,83,72,0,0,0,0,0,0,109,98,95,120,121,58,32,37,100,44,37,100,32,10,0,0,97,99,51,95,102,105,120,101,100,0,0,0,0,0,0,0,108,116,114,116,95,99,101,110,116,101,114,95,109,105,120,95,108,101,118,101,108,0,0,0,86,66,86,32,98,117,102,102,101,114,32,115,105,122,101,32,99,97,110,110,111,116,32,98,101,32,115,109,97,108,108,101,114,32,116,104,97,110,32,111,110,101,32,102,114,97,109,101,44,32,117,115,105,110,103,32,37,100,32,107,98,105,116,10,0,0,0,0,0,0,0,0,120,119,100,0,0,0,0,0,68,105,115,99,97,114,100,105,110,103,32,105,110,105,116,105,97,108,32,102,114,97,109,101,40,115,41,32,119,105,116,104,32,110,111,32,116,105,109,101,115,116,97,109,112,46,10,0,101,97,99,51,0,0,0,0,102,114,97,109,101,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,0,0,120,115,117,98,0,0,0,0,97,117,116,111,32,100,101,116,101,99,116,32,112,97,114,105,116,121,0,0,0,0,0,0,99,108,71,101,116,83,117,112,112,111,114,116,101,100,73,109,97,103,101,70,111,114,109,97,116,115,0,0,0,0,0,0,115,114,99,45,62,105,95,115,105,122,101,0,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,115,116,0,0,0,0,0,0,114,103,98,56,0,0,0,0,120,115,117,98,0,0,0,0,66,108,97,99,107,0,0,0,100,101,102,97,117,108,116,0,97,97,99,95,108,97,116,109,0,0,0,0,0,0,0,0,109,105,110,0,0,0,0,0,97,54,52,109,117,108,116,105,53,0,0,0,0,0,0,0,73,78,86,65,76,73,68,68,65,84,65,0,0,0,0,0,56,115,118,120,95,101,120,112,0,0,0,0,0,0,0,0,98,97,99,107,32,99,101,110,116,101,114,0,0,0,0,0,120,108,0,0,0,0,0,0,69,114,114,111,114,58,32,85,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,32,100,101,112,116,104,58,32,37,117,46,10,0,0,0,0,116,0,0,0,0,0,0,0,100,105,116,104,101,114,101,100,32,0,0,0,0,0,0,0,97,99,99,117,114,97,116,101,95,114,110,100,0,0,0,0,33,115,45,62,105,110,95,99,104,95,108,97,121,111,117,116,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,87,105,100,116,104,32,49,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,112,111,115,116,112,114,111,99,0,0,0,0,0,0,0,0,99,108,97,109,112,0,0,0,69,114,114,111,114,32,99,111,109,112,114,101,115,115,105,110,103,32,100,97,116,97,10,0,120,102,97,99,101,0,0,0,70,108,97,103,115,61,37,88,32,118,101,114,61,37,105,46,37,105,32,99,111,109,112,61,37,105,32,102,109,116,61,37,105,32,98,108,107,61,37,105,120,37,105,10,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,121,52,49,112,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,100,105,118,105,115,105,98,108,101,32,98,121,32,56,46,10,0,0,0,0,0,0,92,109,111,118,101,40,37,100,44,37,100,44,37,100,44,37,100,41,37,49,91,92,125,93,37,110,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,112,112,115,114,99,0,0,0,85,110,107,110,111,119,110,32,102,114,97,109,101,32,116,121,112,101,32,37,100,10,0,0,97,100,112,99,109,95,105,109,97,95,97,112,99,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,120,102,97,99,101,0,0,0,116,105,109,101,98,97,115,101,32,109,105,115,109,97,116,99,104,32,119,105,116,104,32,49,115,116,32,112,97,115,115,32,40,37,117,47,37,117,32,118,115,32,37,117,47,37,117,41,10,0,0,0,0,0,0,0,83,109,97,108,108,32,82,111,111,109,0,0,0,0,0,0,83,109,97,108,108,32,82,111,111,109,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,10,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,32,116,121,112,101,32,58,32,115,107,105,112,112,105,110,103,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,88,83,85,66,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,83,116,111,112,32,102,114,101,113,117,101,110,99,121,32,98,111,114,100,101,114,32,116,111,111,32,104,105,103,104,58,32,37,100,10,0,0,0,0,0,102,97,97,99,0,0,0,0,99,111,100,101,100,32,102,114,97,109,101,32,115,105,122,101,32,37,100,32,116,111,111,32,115,109,97,108,108,10,0,0,119,105,100,116,104,32,105,115,32,110,111,116,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,10,0,0,0,83,105,122,101,32,118,97,108,117,101,32,37,100,120,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,111,110,108,121,32,97,99,99,101,112,116,115,32,97,32,115,105,122,101,32,111,102,32,37,100,120,37,100,10,0,0,0,108,101,110,103,116,104,115,32,37,100,32,37,100,32,37,100,32,37,100,10,0,0,0,0,66,117,102,102,101,114,32,105,115,32,108,111,110,103,101,114,32,116,104,97,110,32,101,120,112,101,99,116,101,100,44,32,116,114,117,110,99,97,116,105,110,103,32,97,116,32,98,121,116,101,32,37,100,10,0,0,48,46,49,52,57,47,48,46,48,54,54,32,48,46,56,51,49,47,48,46,57,48,53,32,48,46,57,48,53,47,48,46,57,56,0,0,0,0,0,0,35,100,101,102,105,110,101,32,105,109,97,103,101,95,119,105,100,116,104,32,37,117,10,0,35,0,0,0,0,0,0,0,108,101,110,32,60,61,32,112,117,116,95,98,105,116,115,95,108,101,102,116,40,38,115,45,62,112,98,41,0,0,0,0,115,45,62,115,97,109,112,108,101,115,95,112,101,114,95,102,114,97,109,101,32,60,61,32,40,49,32,60,60,32,49,52,41,0,0,0,0,0,0,0,50,112,97,115,115,0,0,0,71,67,83,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,55,53,68,101,102,105,110,105,116,105,111,110,0,73,110,118,97,108,105,100,32,116,97,103,32,115,105,122,101,32,37,100,10,0,0,0,0,99,111,108,111,114,32,99,97,99,104,101,32,105,110,100,101,120,32,111,117,116,45,111,102,45,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,120,98,109,0,0,0,0,0,112,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,78,111,32,98,108,111,99,107,32,119,105,116,104,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,115,97,109,112,108,101,115,10,0,0,0,0,73,109,97,103,101,32,115,105,122,101,32,110,111,116,32,109,117,108,116,105,112,108,101,32,111,102,32,98,108,111,99,107,32,115,105,122,101,10,0,0,80,97,99,107,101,116,32,115,105,122,101,32,37,100,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,83,101,116,32,114,97,116,101,32,99,111,110,116,114,111,108,32,101,113,117,97,116,105,111,110,46,32,87,104,101,110,32,99,111,109,112,117,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,44,32,98,101,115,105,100,101,115,32,116,104,101,32,115,116,97,110,100,97,114,100,32,102,117,110,99,116,105,111,110,115,32,100,101,102,105,110,101,100,32,105,110,32,116,104,101,32,115,101,99,116,105,111,110,32,39,69,120,112,114,101,115,115,105,111,110,32,69,118,97,108,117,97,116,105,111,110,39,44,32,116,104,101,32,102,111,108,108,111,119,105,110,103,32,102,117,110,99,116,105,111,110,115,32,97,114,101,32,97,118,97,105,108,97,98,108,101,58,32,98,105,116,115,50,113,112,40,98,105,116,115,41,44,32,113,112,50,98,105,116,115,40,113,112,41,46,32,65,108,115,111,32,116,104,101,32,102,111,108,108,111,119,105,110,103,32,99,111,110,115,116,97,110,116,115,32,97,114,101,32,97,118,97,105,108,97,98,108,101,58,32,105,84,101,120,32,112,84,101,120,32,116,101,120,32,109,118,32,102,67,111,100,101,32,105,67,111,117,110,116,32,109,99,86,97,114,32,118,97,114,32,105,115,73,32,105,115,80,32,105,115,66,32,97,118,103,81,80,32,113,67,111,109,112,32,97,118,103,73,73,84,101,120,32,97,118,103,80,73,84,101,120,32,97,118,103,80,80,84,101,120,32,97,118,103,66,80,84,101,120,32,97,118,103,84,101,120,46,0,0,0,0,0,73,110,118,97,108,105,100,32,116,111,107,101,110,32,37,100,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,119,109,118,50,101,110,99,46,99,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,102,114,97,109,105,110,103,32,102,108,97,103,41,46,32,10,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,109,105,115,115,105,110,103,32,99,98,112,99,121,95,118,108,99,10,0,0,0,0,0,0,72,105,103,104,0,0,0,0,80,97,110,45,115,99,97,110,0,0,0,0,0,0,0,0,112,99,120,0,0,0,0,0,87,77,65,80,114,111,45,105,110,45,87,77,65,86,111,105,99,101,0,0,0,0,0,0,35,37,100,32,112,111,105,110,116,115,58,0,0,0,0,0,83,112,101,99,105,102,105,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,37,115,32,105,115,32,105,110,118,97,108,105,100,32,111,114,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,98,98,0,0,0,0,0,0,73,110,112,117,116,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,60,32,37,100,41,10,0,0,0,0,0,0,0,120,98,109,0,0,0,0,0,98,117,102,32,115,105,122,101,32,37,100,32,105,110,118,97,108,105,100,10,0,0,0,0,119,109,97,118,50,0,0,0,100,101,102,97,117,108,116,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,112,101,114,32,114,97,119,32,115,97,109,112,108,101,0,0,0,119,109,97,118,50,0,0,0,80,114,111,106,76,105,110,101,97,114,85,110,105,116,83,105,122,101,71,101,111,75,101,121,0,0,0,0,0,0,0,0,111,118,101,114,102,108,111,119,32,105,110,32,115,112,101,99,116,114,97,108,32,82,76,69,44,32,105,103,110,111,114,105,110,103,10,0,0,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,119,97,116,101,114,109,97,114,107,32,115,105,122,101,58,32,37,100,120,37,100,10,0,0,37,115,0,0,0,0,0,0,32,115,105,122,101,61,34,37,100,34,0,0,0,0,0,0,34,0,0,0,0,0,0,0,115,105,122,101,32,116,111,111,32,108,97,114,103,101,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,109,105,115,115,105,110,103,32,82,73,70,70,32,116,97,103,10,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,98,108,101,110,100,32,109,111,100,101,0,0,0,0,0,105,110,118,97,108,105,100,32,109,111,116,105,111,110,32,98,97,115,101,32,118,97,108,117,101,32,37,100,10,0,0,0,120,97,110,95,119,99,51,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,113,112,50,98,105,116,115,0,110,111,116,32,101,110,111,117,103,104,32,101,120,116,114,97,100,97,116,97,32,40,37,105,41,10,0,0,0,0,0,0,118,101,110,100,111,114,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,58,32,37,100,10,0,0,119,115,95,115,110,100,49,0,70,111,117,110,100,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,116,121,112,101,58,32,37,99,37,99,37,99,37,99,32,40,37,48,56,88,41,10,0,0,0,0,0,0,112,99,109,95,109,117,108,97,119,0,0,0,0,0,0,0,110,117,109,58,100,101,110,32,115,121,110,116,97,120,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,112,108,101,97,115,101,32,117,115,101,32,110,117,109,47,100,101,110,32,111,114,32,110,97,109,101,100,32,111,112,116,105,111,110,115,32,105,110,115,116,101,97,100,10,0,0,0,0,0,0,108,105,109,105,116,58,37,100,32,114,111,117,110,100,58,37,100,32,114,101,115,101,116,95,99,111,117,110,116,58,37,100,10,0,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,114,101,102,101,114,101,110,99,101,32,37,100,32,110,111,116,32,97,118,97,105,108,97,98,108,101,10,0,0,0,108,101,118,101,108,0,0,0,118,112,56,0,0,0,0,0,118,112,54,102,0,0,0,0,100,101,102,97,117,108,116,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,119,110,118,49,0,0,0,0,84,111,111,32,109,97,110,121,32,66,45,102,114,97,109,101,115,32,114,101,113,117,101,115,116,101,100,44,32,109,97,120,105,109,117,109,32,105,115,32,37,100,46,10,0,0,0,0,105,110,116,101,114,108,97,99,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,118,102,111,114,109,97,116,95,111,112,101,110,95,105,110,112,117,116,32,39,37,115,39,10,0,0,0,0,0,115,45,62,112,105,99,116,95,116,121,112,101,32,61,61,32,65,86,95,80,73,67,84,85,82,69,95,84,89,80,69,95,73,32,124,124,32,40,115,45,62,108,97,115,116,95,112,105,99,116,117,114,101,95,112,116,114,32,38,38,32,115,45,62,108,97,115,116,95,112,105,99,116,117,114,101,95,112,116,114,45,62,102,46,98,117,102,91,48,93,41,0,0,0,0,0,115,45,62,102,114,97,109,101,32,33,61,32,48,76,0,0,115,45,62,102,114,97,109,101,32,33,61,32,48,76,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,108,117,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,0,0,118,112,51,0,0,0,0,0,102,114,97,109,101,32,115,107,105,112,32,37,100,10,0,0,70,108,97,103,115,32,99,111,109,109,111,110,32,102,111,114,32,97,108,108,32,109,112,101,103,118,105,100,101,111,45,98,97,115,101,100,32,101,110,99,111,100,101,114,115,46,0,0,80,82,69,86,95,73,78,80,84,83,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,112,105,99,32,99,111,100,32,101,120,116,32,97,102,116,101,114,32,37,88,10,0,0,111,117,116,112,117,116,32,98,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,70,73,82,32,97,110,100,32,73,73,82,32,102,105,108,116,101,114,115,32,109,117,115,116,32,117,115,101,32,116,104,101,32,115,97,109,101,32,112,114,101,99,105,115,105,111,110,46,10,0,0,0,0,0,0,0,115,119,115,95,102,108,97,103,115,61,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,85,110,104,97,110,100,108,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,48,120,37,120,10,0,0,0,0,73,100,32,104,101,97,100,101,114,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,83,101,108,101,99,116,32,116,104,101,32,113,117,97,108,105,116,121,32,102,111,114,32,99,111,110,115,116,97,110,116,32,113,117,97,108,105,116,121,32,109,111,100,101,0,0,0,0,73,110,118,97,108,105,100,32,109,111,100,101,32,105,110,32,112,97,99,107,101,116,10,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,50,58,49,58,49,46,10,0,0,0,0,0,0,0,101,114,114,111,114,32,100,117,114,105,110,103,32,112,114,111,99,101,115,115,105,110,103,32,109,97,114,107,101,114,32,115,101,103,109,101,110,116,32,37,46,52,120,10,0,0,0,0,80,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,100,97,116,97,33,10,0,92,110,0,0,0,0,0,0,65,108,108,111,99,97,116,101,100,32,116,105,108,101,32,115,105,122,101,32,37,100,32,109,105,115,109,97,116,99,104,101,115,32,112,97,114,97,109,101,116,101,114,115,32,37,100,32,105,110,32,105,118,105,95,112,114,111,99,101,115,115,95,101,109,112,116,121,95,116,105,108,101,40,41,10,0,0,0,0,73,32,99,98,112,99,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,118,109,100,97,117,100,105,111,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,33,10,0,0,0,0,79,110,101,32,111,102,32,116,104,101,32,121,47,117,47,118,32,111,102,102,115,101,116,115,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,32,37,100,32,60,32,37,100,10,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,40,114,101,41,97,108,108,111,99,97,116,101,32,105,110,116,101,114,118,97,108,115,32,97,114,114,97,121,10,0,80,67,77,32,98,105,116,32,100,101,112,116,104,32,40,37,100,41,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,110,111,114,109,97,108,32,98,105,116,32,100,101,112,116,104,32,40,37,100,41,10,0,0,0,0,0,0,0,80,80,83,32,105,100,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,0,99,116,95,116,121,112,101,58,37,88,32,112,105,99,95,115,116,114,117,99,116,58,37,100,10,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,108,111,110,103,32,114,101,102,32,105,110,32,109,101,109,111,114,121,32,109,97,110,97,103,101,109,101,110,116,32,99,111,110,116,114,111,108,32,111,112,101,114,97,116,105,111,110,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,108,117,109,97,32,98,105,116,32,100,101,112,116,104,61,37,100,10,0,0,0,0,0,0,73,55,58,37,88,47,10,0,110,111,32,112,105,99,116,117,114,101,32,37,115,10,0,0,83,73,0,0,0,0,0,0,119,109,118,51,0,0,0,0,73,110,118,97,108,105,100,32,104,111,116,115,112,111,116,32,112,111,115,105,116,105,111,110,32,37,100,44,37,100,10,0,82,79,0,0,0,0,0,0,98,117,102,102,101,114,32,110,111,116,32,102,117,108,108,121,32,99,111,110,115,117,109,101,100,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,105,110,32,87,77,86,50,32,97,98,116,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2433184);
/* memory initializer */ allocate([32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,44,32,37,100,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,114,105,99,101,32,111,114,100,101,114,58,32,37,105,32,98,108,111,99,107,115,105,122,101,32,37,105,10,0,0,0,0,111,117,116,95,119,0,0,0,50,80,97,115,115,32,102,105,108,101,32,105,110,118,97,108,105,100,32,97,116,32,37,100,32,37,100,32,91,37,115,93,10,0,0,0,0,0,0,0,99,111,110,116,101,120,116,95,99,111,117,110,116,32,62,61,32,48,0,0,0,0,0,0,85,110,107,110,111,119,110,32,112,105,120,101,108,32,116,121,112,101,10,0,0,0,0,0,68,111,108,98,121,32,83,117,114,114,111,117,110,100,32,77,111,100,101,0,0,0,0,0,66,108,111,99,107,32,112,114,101,100,105,99,116,105,111,110,32,105,110,100,101,120,32,116,111,111,32,104,105,103,104,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,69,82,82,79,82,58,32,68,84,83,45,88,66,82,58,32,98,108,111,99,107,32,99,111,100,101,32,108,111,111,107,45,117,112,32,102,97,105,108,101,100,10,0,0,0,0,0,0,116,111,116,97,108,95,115,117,98,98,97,110,100,115,32,62,32,53,51,0,0,0,0,0,79,108,100,32,105,110,116,101,114,108,97,99,101,100,32,109,111,100,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,112,105,120,95,102,109,116,0,106,112,101,103,108,115,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,118,52,49,48,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,46,10,0,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,119,109,97,118,111,105,99,101,0,0,0,0,0,0,0,0,118,52,48,56,0,0,0,0,32,114,99,61,37,115,32,109,98,116,114,101,101,61,37,100,0,0,0,0,0,0,0,0,71,67,83,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,54,55,68,101,102,105,110,105,116,105,111,110,0,67,97,110,110,111,116,32,98,117,102,102,101,114,32,109,111,114,101,32,102,114,97,109,101,115,46,32,67,111,110,115,117,109,101,32,115,111,109,101,32,97,118,97,105,108,97,98,108,101,32,102,114,97,109,101,115,32,98,101,102,111,114,101,32,97,100,100,105,110,103,32,110,101,119,32,111,110,101,115,46,10,0,0,0,0,0,0,0,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,100,101,99,111,100,101,100,32,112,101,114,32,99,97,108,108,0,0,0,0,0,0,118,52,48,56,0,0,0,0,118,51,48,56,32,114,101,113,117,105,114,101,115,32,119,105,100,116,104,32,116,111,32,98,101,32,101,118,101,110,46,10,0,0,0,0,0,0,0,0,83,83,69,0,0,0,0,0,114,99,95,101,113,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,68,101,97,116,104,32,77,101,116,97,108,0,0,0,0,0,66,114,111,107,101,110,32,118,50,49,48,32,119,105,116,104,32,116,111,111,32,115,109,97,108,108,32,112,97,100,100,105,110,103,32,40,54,52,32,98,121,116,101,41,32,100,101,116,101,99,116,101,100,10,0,0,87,77,47,80,117,98,108,105,115,104,101,114,0,0,0,0,65,73,70,70,32,109,117,120,101,114,0,0,0,0,0,0,66,101,97,109,32,83,111,102,116,119,97,114,101,32,86,66,0,0,0,0,0,0,0,0,37,115,37,115,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,32,50,46,10,0,0,0,0,52,52,52,112,57,0,0,0,87,77,47,87,77,82,86,69,110,99,111,100,101,84,105,109,101,0,0,0,0,0,0,0,87,101,98,86,84,84,32,109,101,116,97,100,97,116,97,32,107,105,110,100,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,32,102,111,114,32,97,32,112,108,97,110,101,10,0,0,111,114,105,103,105,110,97,116,111,114,95,114,101,102,101,114,101,110,99,101,0,0,0,0,116,111,111,32,109,97,110,121,32,102,114,97,109,101,115,32,112,101,114,32,106,112,101,103,10,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,85,110,115,112,101,99,105,102,105,101,100,32,100,101,115,116,105,110,97,116,105,111,110,32,99,111,108,111,114,32,115,112,97,99,101,10,0,0,0,0,116,109,112,95,112,111,115,32,62,32,112,111,115,95,109,97,120,0,0,0,0,0,0,0,84,104,105,115,32,102,105,108,116,101,114,32,100,111,101,115,32,110,111,116,32,116,97,107,101,32,97,110,121,32,111,112,116,105,111,110,115,44,32,98,117,116,32,111,112,116,105,111,110,115,32,119,101,114,101,32,112,114,111,118,105,100,101,100,58,32,37,115,46,10,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,115,101,113,117,101,110,99,101,32,39,37,115,39,32,97,115,115,111,99,105,97,116,101,100,32,116,111,32,115,116,114,101,97,109,32,37,100,32,111,102,32,115,108,97,118,101,32,111,117,116,112,117,116,32,39,37,115,39,10,0,0,0,0,0,0,100,116,115,104,100,95,114,97,116,101,0,0,0,0,0,0,78,111,32,98,105,116,32,114,97,116,101,32,115,101,116,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,0,0,0,0,0,100,101,115,99,45,62,102,108,97,103,115,32,38,32,40,49,32,60,60,32,52,41,0,0,119,97,114,110,105,110,103,58,32,109,111,100,105,102,105,101,114,32,109,117,115,116,32,98,101,32,48,32,111,114,32,49,44,32,103,111,116,32,37,105,10,0,0,0,0,0,0,0,116,101,120,116,117,114,101,32,100,97,116,97,32,118,101,114,115,105,111,110,32,37,105,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,77,105,115,115,105,110,103,32,111,114,32,105,110,99,111,109,112,108,101,116,101,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,102,114,97,109,101,115,32,112,101,114,32,112,97,99,107,101,116,32,40,37,100,41,10,0,0,0,0,0,0,0,0,101,110,99,111,100,105,110,103,32,97,115,32,50,52,32,98,105,116,115,45,112,101,114,45,115,97,109,112,108,101,10,0,67,82,67,32,101,114,114,111,114,10,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,102,114,97,109,101,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,73,110,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,84,111,111,32,115,109,97,108,108,32,105,110,112,117,116,32,98,117,102,102,101,114,32,40,37,100,32,98,121,116,101,115,41,44,32,110,101,101,100,32,97,116,32,108,101,97,115,116,32,51,50,32,98,121,116,101,115,10,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,32,104,101,108,112,33,32,116,114,117,101,109,111,116,105,111,110,49,32,100,101,99,111,100,101,114,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,73,110,112,117,116,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,44,32,116,114,117,110,99,97,116,101,100,32,115,97,109,112,108,101,63,10,0,0,0,0,0,0,119,109,97,112,114,111,0,0,114,114,0,0,0,0,0,0,84,104,105,115,32,99,111,108,111,114,115,32,102,111,114,109,97,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,99,117,114,118,101,115,0,0,114,115,0,0,0,0,0,0,119,109,97,108,111,115,115,108,101,115,115,0,0,0,0,0,71,67,83,69,95,69,118,101,114,101,115,116,49,56,51,48,95,49,57,51,55,65,100,106,117,115,116,109,101,110,116,0,32,114,99,95,108,111,111,107,97,104,101,97,100,61,37,100,0,0,0,0,0,0,0,0,114,99,95,111,118,101,114,114,105,100,101,95,99,111,117,110,116,0,0,0,0,0,0,0,118,98,0,0,0,0,0,0,119,109,97,118,49,0,0,0,102,111,114,109,97,116,0,0,114,101,112,111,114,116,0,0,76,117,109,97,32,114,97,100,105,117,115,32,101,120,112,114,101,115,115,105,111,110,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,115,101,116,32,112,114,101,102,105,120,32,116,111,32,112,114,101,112,101,110,100,32,116,111,32,101,97,99,104,32,108,105,115,116,32,101,110,116,114,121,32,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,119,109,97,118,49,0,0,0,116,116,108,0,0,0,0,0,71,84,67,105,116,97,116,105,111,110,71,101,111,75,101,121,0,0,0,0,0,0,0,0,37,115,37,46,49,53,103,0,98,121,116,101,95,111,102,102,115,101,116,95,98,105,116,115,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,119,97,118,101,0,0,0,0,73,110,118,97,108,105,100,32,84,73,70,70,32,104,101,97,100,101,114,10,0,0,0,0,118,112,108,97,121,101,114,0,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,104,50,54,52,95,109,111,100,101,48,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,105,110,112,117,116,32,100,97,116,97,46,10,0,0,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,116,111,32,114,101,97,100,32,104,101,97,100,101,114,10,0,67,82,67,32,101,114,114,111,114,10,0,0,0,0,0,0,65,116,32,109,111,115,116,32,50,32,115,116,114,101,97,109,115,32,97,114,101,32,99,117,114,114,101,110,116,108,121,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,109,117,120,105,110,103,32,105,110,32,82,77,10,0,0,0,0,0,77,105,115,115,105,110,103,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,121,32,115,105,122,101,100,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,0,82,68,58,32,37,102,10,0,69,114,114,111,114,32,105,110,32,115,118,113,49,95,100,101,99,111,100,101,95,98,108,111,99,107,32,37,105,32,40,107,101,121,102,114,97,109,101,41,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,104,105,115,32,105,115,32,110,111,116,32,115,117,110,114,97,115,32,101,110,99,111,100,101,100,32,100,97,116,97,10,0,0,0,0,0,0,0,0,115,101,116,32,100,105,115,112,108,97,121,32,115,99,97,108,101,0,0,0,0,0,0,0,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,44,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,37,99,0,0,0,0,0,0,0,119,101,98,118,116,116,0,0,73,83,77,80,0,0,0,0,115,117,98,114,105,112,0,0,115,117,98,114,105,112,0,0,97,109,118,0,0,0,0,0,115,111,110,105,99,108,115,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,107,101,121,102,114,97,109,101,58,37,100,32,113,108,111,103,58,37,100,10,0,0,0,0,103,55,50,50,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,115,110,111,119,95,100,119,116,46,99,0,0,0,73,110,118,97,108,105,100,32,104,101,105,103,104,116,10,0,119,97,114,110,105,110,103,58,32,77,79,86,32,99,104,117,110,107,32,115,105,122,101,32,33,61,32,101,110,99,111,100,101,100,32,99,104,117,110,107,32,115,105,122,101,32,40,37,100,32,33,61,32,37,100,41,59,32,117,115,105,110,103,32,77,79,86,32,99,104,117,110,107,32,115,105,122,101,10,0,115,109,97,99,107,97,117,100,0,0,0,0,0,0,0,0,69,114,114,111,114,32,112,114,111,99,101,115,115,105,110,103,32,112,97,99,107,101,116,58,32,112,97,99,107,101,116,32,115,105,122,101,32,40,37,100,41,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,101,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,98,105,116,115,116,114,101,97,109,32,98,117,102,102,101,114,10,0,0,0,0,0,0,111,112,99,111,100,101,32,37,100,0,0,0,0,0,0,0,83,71,73,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,54,53,53,51,53,120,54,53,53,51,53,10,0,0,0,0,0,98,117,102,95,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,41,10,0,0,0,0,0,0,0,0,119,101,98,112,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,83,71,65,49,57,50,50,0,32,107,101,121,105,110,116,95,109,105,110,61,37,100,32,115,99,101,110,101,99,117,116,61,37,100,32,105,110,116,114,97,95,114,101,102,114,101,115,104,61,37,100,0,0,0,0,0,115,56,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,99,104,117,110,107,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,0,114,99,95,113,109,111,100,95,102,114,101,113,0,0,0,0,60,80,0,0,0,0,0,0,102,114,97,109,101,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,68,113,117,97,110,116,32,102,111,114,32,80,45,102,114,97,109,101,10,0,0,0,0,0,73,110,118,97,108,105,100,32,100,101,99,111,100,101,114,32,115,116,97,116,101,58,32,66,45,102,114,97,109,101,32,119,105,116,104,111,117,116,32,114,101,102,101,114,101,110,99,101,32,100,97,116,97,46,10,0,65,77,86,32,86,105,100,101,111,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,114,118,50,48,101,110,99,46,99,0,0,0,0,114,118,49,48,32,101,110,99,111,100,101,114,0,0,0,0,115,56,0,0,0,0,0,0,82,101,97,108,86,105,100,101,111,32,49,46,48,0,0,0,70,105,114,115,116,32,99,104,117,110,107,32,98,121,116,101,32,105,115,32,48,120,37,48,50,120,32,105,110,115,116,101,97,100,32,111,102,32,48,120,101,49,10,0,0,0,0,0,87,97,114,110,105,110,103,44,32,103,101,110,101,114,97,116,101,100,32,97,32,102,114,97,109,101,32,116,111,111,32,98,105,103,32,102,111,114,32,81,117,97,107,101,32,40,37,100,32,62,32,54,53,53,51,53,41,44,32,110,111,119,32,115,119,105,116,99,104,105,110,103,32,116,111,32,97,32,98,105,103,103,101,114,32,113,115,99,97,108,101,32,118,97,108,117,101,46,10,0,0,0,0,0,67,104,117,110,107,32,100,111,101,115,32,110,111,116,32,102,105,116,32,105,110,32,105,110,112,117,116,32,98,117,102,102,101,114,10,0,0,0,0,0,65,117,100,105,111,32,109,117,115,116,32,98,101,32,109,111,110,111,32,111,114,32,115,116,101,114,101,111,10,0,0,0,88,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,10,0,60,98,114,47,62,0,0,0,115,101,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,119,97,118,112,97,99,107,0,100,105,115,99,97,114,100,99,111,114,114,117,112,116,0,0,115,101,116,32,98,108,117,101,32,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,69,0,0,0,0,0,0,0,67,66,67,45,77,65,67,0,87,114,111,110,103,32,112,97,99,107,101,116,39,115,32,98,114,101,97,116,104,32,115,109,101,108,108,115,32,111,102,32,119,114,111,110,103,32,100,97,116,97,33,10,0,0,0,0,69,114,114,111,114,33,32,73,110,112,117,116,32,98,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,32,91,37,100,60,37,100,93,10,0,0,0,0,0,0,0,70,114,97,109,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,98,121,116,101,115,41,46,32,84,114,117,110,99,97,116,101,100,32,102,105,108,101,63,10,0,0,0,0,97,109,111,117,110,116,0,0,114,49,48,107,0,0,0,0,114,49,48,107,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,115,112,97,99,101,46,10,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,115,112,97,99,101,58,32,37,100,32,98,105,116,115,47,115,97,109,112,108,101,63,10,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,69,114,114,111,114,32,99,111,108,111,114,32,99,111,117,110,116,32,45,32,37,105,40,48,120,37,88,41,10,0,0,0,78,111,32,101,120,116,114,97,100,97,116,97,32,112,114,101,115,101,110,116,10,0,0,0,83,117,112,101,114,98,108,111,99,107,32,102,111,108,108,111,119,115,10,0,0,0,0,0,66,105,116,114,97,116,101,32,99,97,110,110,111,116,32,98,101,32,100,101,116,101,114,109,105,110,101,100,46,0,0,0,73,109,97,103,101,32,102,111,114,109,97,116,32,110,111,116,32,82,71,66,49,53,0,0,98,105,110,0,0,0,0,0,116,104,101,114,101,32,115,104,111,117,108,100,32,98,101,32,97,110,32,105,110,116,101,103,101,114,32,112,111,119,101,114,32,111,102,32,116,119,111,32,77,66,115,32,112,101,114,32,115,108,105,99,101,10,0,0,112,114,111,114,101,115,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,10,0,0,67,104,97,110,110,101,108,76,97,121,111,117,116,0,0,0,100,0,0,0,0,0,0,0,112,103,109,121,117,118,0,0,115,97,109,112,108,101,95,110,95,98,121,116,101,115,0,0,112,103,109,121,117,118,0,0,119,97,118,112,97,99,107,0,49,46,50,46,53,0,0,0,116,104,101,114,101,32,109,117,115,116,32,98,101,32,101,120,97,99,116,108,121,32,111,110,101,32,118,105,100,101,111,32,115,116,114,101,97,109,32,97,110,100,32,105,116,32,109,117,115,116,32,98,101,32,116,104,101,32,102,105,114,115,116,32,111,110,101,10,0,0,0,0,77,105,115,115,105,110,103,32,112,110,103,32,115,105,103,110,97,116,117,114,101,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,0,0,0,85,110,107,110,111,119,110,32,115,117,98,116,105,116,108,101,32,115,101,103,109,101,110,116,32,116,121,112,101,32,48,120,37,120,44,32,108,101,110,103,116,104,32,37,100,10,0,0,105,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,32,100,111,32,110,111,116,32,102,105,116,32,105,110,32,49,54,32,98,105,116,115,10,0,116,104,105,115,32,105,115,32,110,111,116,32,80,67,88,32,101,110,99,111,100,101,100,32,100,97,116,97,10,0,0,0,103,111,116,32,37,105,32,105,110,100,101,120,32,116,97,98,108,101,115,32,45,32,111,110,108,121,32,116,104,101,32,102,105,114,115,116,32,111,110,101,32,40,73,110,100,101,120,83,73,68,32,37,105,41,32,119,105,108,108,32,98,101,32,117,115,101,100,10,0,0,0,0,80,73,88,69,76,95,65,83,80,69,67,84,0,0,0,0,109,105,110,95,118,97,108,0,84,97,103,32,37,115,47,48,120,37,48,56,120,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,111,117,116,112,117,116,32,99,111,100,101,99,32,105,100,32,39,37,100,39,32,40,37,115,41,10,0,0,0,0,0,0,118,113,97,118,105,100,101,111,0,0,0,0,0,0,0,0,80,67,77,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,80,67,77,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,70,70,109,112,101,103,0,0,66,76,65,67,75,65,78,68,87,72,73,84,69,0,0,0,112,97,102,95,97,117,100,105,111,0,0,0,0,0,0,0,112,111,115,32,62,61,32,49,56,56,0,0,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,65,114,99,0,0,0,0,0,32,107,101,121,105,110,116,61,37,100,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,120,112,101,114,105,109,101,110,116,97,108,32,113,117,97,110,116,105,122,101,114,32,109,111,100,117,108,97,116,105,111,110,0,0,0,0,0,0,0,73,68,88,32,115,116,114,101,97,109,91,37,100,93,32,105,100,61,37,115,10,0,0,0,97,109,118,0,0,0,0,0,118,112,57,0,0,0,0,0,98,101,115,116,95,98,105,116,114,97,116,101,95,105,100,120,32,62,61,32,48,0,0,0,115,101,116,115,97,114,0,0,112,105,120,95,102,109,116,0,82,97,110,32,111,117,116,32,111,102,32,102,114,101,101,32,102,114,97,109,101,115,33,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,37,115,32,112,114,111,102,105,108,101,32,100,111,101,115,110,39,116,32,115,117,112,112,111,114,116,32,108,111,115,115,108,101,115,115,10,0,0,0,0,105,112,111,100,0,0,0,0,118,112,54,0,0,0,0,0,99,114,111,112,100,101,116,101,99,116,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,111,112,116,105,111,110,115,46,99,0,0,0,0,116,105,116,108,101,0,0,0,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,115,109,97,108,108,10,0,0,78,101,108,108,121,109,111,115,101,114,32,115,117,112,112,111,114,116,115,32,111,110,108,121,32,49,32,99,104,97,110,110,101,108,10,0,0,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,113,117,97,110,116,105,122,97,116,105,111,110,32,116,97,98,108,101,32,100,101,99,111,100,101,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,109,118,99,50,0,0,0,0,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,109,117,115,116,32,98,101,32,109,117,108,116,105,112,108,105,101,115,32,111,102,32,52,10,0,0,0,0,0,0,0,32,77,83,32,86,105,100,101,111,45,49,32,119,97,114,110,105,110,103,58,32,115,116,114,101,97,109,95,112,116,114,32,111,117,116,32,111,102,32,98,111,117,110,100,115,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,0,0,0,0,70,114,97,109,101,32,115,104,111,117,108,100,32,104,97,118,101,32,97,116,32,108,101,97,115,116,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,32,105,110,115,116,101,97,100,10,0,0,0,0,70,114,97,109,101,32,115,104,111,117,108,100,32,104,97,118,101,32,97,116,32,108,101,97,115,116,32,37,100,32,98,121,116,101,115,44,32,103,111,116,32,37,100,32,105,110,115,116,101,97,100,10,0,0,0,0,105,109,112,108,105,99,105,116,95,114,101,99,116,32,38,38,32,117,115,101,100,95,114,101,99,116,115,32,62,32,48,10,0,0,0,0,0,0,0,0,70,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,32,116,111,111,32,108,97,114,103,101,0,0,0,0,0,0,0,0,97,116,114,105,109,0,0,0,83,107,105,112,32,98,101,121,111,110,100,32,112,105,99,116,117,114,101,32,98,111,117,110,100,115,10,0,0,0,0,0,101,110,100,32,100,117,114,97,116,105,111,110,32,61,32,37,108,108,117,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,115,109,112,101,103,52,101,110,99,46,99,0,73,110,118,97,108,105,100,32,101,108,101,109,101,110,116,10,0,0,0,0,0,0,0,0,47,92,95,0,0,0,0,0,65,108,112,104,97,32,114,101,99,111,110,102,105,103,117,114,97,116,105,111,110,10,0,0,115,107,105,112,95,114,100,0,117,115,101,32,115,116,114,102,116,105,109,101,32,102,111,114,32,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,118,112,53,0,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,82,71,83,0,0,0,0,0,32,107,101,121,105,110,116,61,105,110,102,105,110,105,116,101,0,0,0,0,0,0,0,0,115,101,116,32,102,105,114,115,116,32,110,117,109,98,101,114,32,105,110,32,116,104,101,32,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,114,99,95,113,109,111,100,95,97,109,112,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,118,105,100,101,111,46,99,0,0,79,110,50,32,86,80,54,32,40,70,108,97,115,104,32,118,101,114,115,105,111,110,44,32,119,105,116,104,32,97,108,112,104,97,32,99,104,97,110,110,101,108,41,0,0,0,0,0,98,109,112,0,0,0,0,0,97,109,111,118,105,101,0,0,115,101,116,32,97,115,112,101,99,116,32,114,97,116,105,111,32,40,52,58,51,44,32,49,54,58,57,32,111,114,32,49,46,51,51,51,51,44,32,49,46,55,55,55,55,41,0,0,109,112,50,102,108,111,97,116,0,0,0,0,0,0,0,0,100,105,115,99,0,0,0,0,109,112,50,0,0,0,0,0,104,108,115,95,108,105,115,116,95,115,105,122,101,0,0,0,97,115,112,108,105,116,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,52,118,105,100,101,111,101,110,99,46,99,0,0,0,0,0,0,108,111,99,97,116,105,111,110,0,0,0,0,0,0,0,0,37,115,47,115,116,114,101,97,109,37,100,46,97,98,115,116,46,116,109,112,0,0,0,0,37,48,50,100,58,37,48,50,100,58,37,48,50,100,37,99,37,48,50,100,0,0,0,0,116,104,101,111,114,97,0,0,98,101,102,111,114,101,32,116,105,109,101,95,105,110,99,114,101,109,101,110,116,32,105,110,32,118,105,100,101,111,32,112,97,99,107,101,100,32,104,101,97,100,101,114,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,109,112,101,103,49,50,101,110,99,46,99,0,0,65,117,100,105,111,32,99,111,100,101,99,32,39,37,115,39,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,70,76,86,10,0,0,0,0,0,0,0,115,116,101,114,101,111,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,109,97,120,98,97,110,100,32,37,100,32,116,111,111,32,108,97,114,103,101,10,0,0,0,112,97,99,107,101,116,32,115,105,122,101,32,105,115,32,116,111,111,32,115,109,97,108,108,32,40,37,105,32,98,121,116,101,115,41,10,0,0,0,0,118,111,114,98,105,115,0,0,79,110,108,121,32,83,85,66,84,73,84,76,69,95,65,83,83,32,116,121,112,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,92,78,0,0,0,0,0,0,116,111,111,32,102,101,119,32,99,111,100,101,115,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,115,101,116,112,116,115,0,101,110,100,32,111,102,32,104,101,97,100,101,114,32,98,108,111,99,107,32,114,101,97,99,104,101,100,32,40,119,105,116,104,105,110,32,97,117,100,105,111,32,115,117,98,104,101,97,100,101,114,41,10,0,0,0,116,114,117,101,104,100,0,0,102,102,95,99,111,109,98,105,110,101,95,102,114,97,109,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,10,0,0,0,0,0,110,111,116,32,109,106,112,101,103,45,98,32,40,98,97,100,32,102,111,117,114,99,99,41,10,0,0,0,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,73,71,78,0,0,0,0,0,32,119,101,105,103,104,116,112,61,37,100,0,0,0,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,10,0,0,0,0,0,0,104,111,119,32,116,111,32,107,101,101,112,32,113,117,97,110,116,105,122,101,114,32,98,101,116,119,101,101,110,32,113,109,105,110,32,97,110,100,32,113,109,97,120,32,40,48,32,61,32,99,108,105,112,44,32,49,32,61,32,117,115,101,32,100,105,102,102,101,114,101,110,116,105,97,98,108,101,32,102,117,110,99,116,105,111,110,41,0,123,37,42,100,125,123,37,42,91,48,49,50,51,52,53,54,55,56,57,93,125,37,99,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,77,105,115,115,105,110,103,32,111,114,32,105,110,99,111,109,112,108,101,116,101,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,0,0,0,0,118,112,54,97,0,0,0,0,97,99,45,116,101,120,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,109,97,99,101,54,0,0,0,108,105,98,97,118,99,111,100,101,99,47,108,122,119,101,110,99,46,99,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,108,105,98,97,118,99,111,100,101,99,47,108,112,99,46,99,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,97,115,112,101,99,116,0,0,115,116,114,104,0,0,0,0,117,110,107,110,111,119,110,32,115,116,114,101,97,109,32,116,121,112,101,32,37,88,10,0,108,105,98,120,50,54,52,114,103,98,0,0,0,0,0,0,118,111,114,98,105,115,0,0,110,111,116,32,119,114,105,116,105,110,103,32,39,99,104,97,110,39,32,116,97,103,32,100,117,101,32,116,111,32,108,97,99,107,32,111,102,32,99,104,97,110,110,101,108,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,112,107,116,46,115,105,122,101,32,33,61,32,100,115,95,112,97,99,107,101,116,95,115,105,122,101,32,42,32,100,115,95,115,112,97,110,32,40,37,100,32,37,100,32,37,100,41,10,0,0,0,0,0,0,0,0,108,105,98,118,112,120,45,118,112,57,0,0,0,0,0,0,108,105,98,118,112,120,45,118,112,57,0,0,0,0,0,0,70,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,0,69,120,116,114,97,100,97,116,97,32,99,111,114,114,117,112,116,46,10,0,0,0,0,0,122,108,105,98,0,0,0,0,99,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,0,66,108,111,99,107,32,115,105,122,101,32,61,32,37,105,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,70,114,97,109,101,32,114,101,102,101,114,101,110,99,101,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,10,0,118,105,100,101,111,32,115,105,122,101,32,37,100,32,105,110,118,97,108,105,100,10,0,0,79,110,108,121,32,103,114,97,121,115,99,97,108,101,32,97,110,100,32,82,71,66,50,52,47,66,71,82,50,52,32,105,109,97,103,101,115,32,97,114,101,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,105,110,118,97,108,105,100,32,105,100,32,37,100,10,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,74,112,101,103,50,48,48,48,32,99,111,100,101,115,116,114,101,97,109,32,97,116,111,109,46,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,118,109,110,99,0,0,0,0,97,102,105,102,111,0,0,0,86,66,0,0,0,0,0,0,101,110,100,10,0,0,0,0,116,98,0,0,0,0,0,0,117,99,104,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,112,105,99,116,117,114,101,32,104,101,97,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,0,115,116,101,114,101,111,0,0,100,101,99,111,100,101,32,112,114,111,98,108,101,109,32,111,110,32,102,114,97,109,101,32,37,100,44,32,64,32,98,108,111,99,107,32,40,37,100,44,32,37,100,41,10,0,0,0,78,117,109,98,101,114,32,111,102,32,97,116,116,97,99,107,115,47,100,101,99,97,121,115,32,98,105,103,103,101,114,32,116,104,97,110,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,46,10,0,0,0,0,0,0,0,97,115,101,116,116,98,0,0,66,97,100,32,72,50,54,51,32,105,100,10,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,56,48,95,66,101,110,111,105,116,0,0,32,98,95,112,121,114,97,109,105,100,61,37,100,32,98,95,97,100,97,112,116,61,37,100,32,98,95,98,105,97,115,61,37,100,32,100,105,114,101,99,116,61,37,100,32,119,101,105,103,104,116,98,61,37,100,32,111,112,101,110,95,103,111,112,61,37,100,0,0,0,0,0,113,115,113,117,105,115,104,0,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,99,111,108,111,114,32,112,108,97,110,101,115,33,10,0,0,0,0,0,0,0,0,118,109,100,118,105,100,101,111,0,0,0,0,0,0,0,0,110,117,109,95,77,66,115,32,109,105,115,109,97,116,99,104,32,37,100,32,37,100,32,37,100,32,37,100,10,0,0,0,82,101,110,100,101,114,119,97,114,101,32,84,88,68,32,40,84,101,88,116,117,114,101,32,68,105,99,116,105,111,110,97,114,121,41,32,105,109,97,103,101,0,0,0,0,0,0,0,97,50,0,0,0,0,0,0,82,101,97,100,32,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,109,111,116,105,111,110,32,118,101,99,116,111,114,115,32,37,100,10,0,0,0,0,0,0,0,105,110,112,117,116,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,41,10,0,0,0,0,0,0,0,118,105,109,97,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,105,109,103,99,111,110,118,101,114,116,46,99,0,105,97,99,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,72,117,102,102,109,97,110,32,100,101,99,111,100,101,32,101,114,114,111,114,46,10,0,0,102,102,118,104,117,102,102,0,115,105,122,101,0,0,0,0,102,102,118,104,117,102,102,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,118,99,114,49,0,0,0,0,83,107,105,112,112,101,100,32,83,85,70,70,73,88,32,83,69,73,32,37,100,10,0,0,90,101,114,111,32,114,101,102,115,32,105,110,32,116,104,101,32,102,114,97,109,101,32,82,80,83,46,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,45,62,102,114,97,109,101,95,108,105,115,116,45,62,110,98,95,102,114,97,109,101,115,32,62,32,48,0,0,0,0,68,101,99,111,100,105,110,103,32,86,80,83,10,0,0,0,99,117,114,118,101,0,0,0,78,111,116,104,105,110,103,32,116,111,32,101,99,104,111,32,45,32,109,105,115,115,105,110,103,32,100,101,108,97,121,32,115,97,109,112,108,101,115,46,10,0,0,0,0,0,0,0,97,115,101,110,100,99,109,100,0,0,0,0,0,0,0,0,68,101,99,111,100,101,100,32,102,114,97,109,101,32,119,105,116,104,32,80,79,67,32,37,100,46,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,52,112,114,101,100,46,99,0,0,0,110,117,109,95,52,120,52,95,98,108,111,99,107,115,95,119,105,100,101,95,108,111,111,107,117,112,91,98,115,105,122,101,93,32,61,61,32,110,117,109,95,52,120,52,95,98,108,111,99,107,115,95,104,105,103,104,95,108,111,111,107,117,112,91,98,115,105,122,101,93,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,39,37,100,39,32,112,114,111,118,105,100,101,100,10,0,0,0,0,0,0,0,99,109,45,62,98,105,116,95,100,101,112,116,104,32,62,32,66,73,84,83,95,56,0,0,51,50,48,120,50,52,48,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,52,100,115,112,46,99,0,0,0,0,109,118,0,0,0,0,0,0,117,110,107,110,111,119,110,32,83,69,73,32,116,121,112,101,32,37,100,10,0,0,0,0,116,105,108,101,95,99,111,108,115,32,60,61,32,40,49,32,60,60,32,54,41,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,52,95,114,101,102,115,46,99,0,0,115,101,116,32,116,104,101,32,116,101,114,109,105,110,97,108,32,112,116,115,32,118,97,108,117,101,0,0,0,0,0,0,115,101,112,97,114,97,116,101,32,99,111,108,111,114,32,112,108,97,110,101,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,112,112,115,95,105,100,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,114,0,0,0,0,0,0,0,114,117,108,101,0,0,0,0,99,97,98,97,99,32,100,101,99,111,100,101,32,111,102,32,113,115,99,97,108,101,32,100,105,102,102,32,102,97,105,108,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,58,109,105,110,95,104,97,114,100,95,99,111,109,112,61,37,102,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,119,104,105,99,104,32,102,114,97,109,101,115,32,116,111,32,100,101,105,110,116,101,114,108,97,99,101,0,0,0,0,0,104,47,50,0,0,0,0,0,111,117,116,32,111,102,32,114,97,110,103,101,32,105,110,116,114,97,32,99,104,114,111,109,97,32,112,114,101,100,32,109,111,100,101,32,97,116,32,37,100,32,37,100,10,0,0,0,116,104,105,115,32,99,111,100,101,99,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,114,117,110,99,97,116,101,100,32,98,105,116,115,116,114,101,97,109,115,10,0,0,0,0,0,0,0,104,50,54,49,32,101,110,99,111,100,101,114,0,0,0,0,111,112,101,110,99,108,0,0,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,103,115,109,95,109,115,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,54,54,77,105,99,104,105,103,97,110,0,32,98,102,114,97,109,101,115,61,37,100,0,0,0,0,0,100,105,114,32,118,97,108,117,101,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,51,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,116,104,101,32,112,97,115,115,116,104,114,111,117,103,104,32,111,112,116,105,111,110,32,105,110,115,116,101,97,100,10,0,0,0,118,99,49,0,0,0,0,0,99,97,110,110,111,116,32,100,101,99,111,100,101,32,102,114,97,109,101,32,119,105,116,104,111,117,116,32,107,101,121,102,114,97,109,101,10,0,0,0,117,115,101,32,77,80,69,71,32,113,117,97,110,116,105,122,101,114,115,32,105,110,115,116,101,97,100,32,111,102,32,72,46,50,54,51,0,0,0,0,101,110,97,98,108,101,32,118,101,114,116,105,99,97,108,32,108,111,119,45,112,97,115,115,32,102,105,108,116,101,114,0,37,100,120,37,100,32,105,109,97,103,101,32,97,116,32,112,111,115,32,40,37,100,59,37,100,41,32,91,97,114,101,97,58,37,100,120,37,100,93,10,0,0,0,0,0,0,0,0,80,97,99,107,101,116,32,116,121,112,101,58,32,37,115,10,0,0,0,0,0,0,0,0,116,120,100,0,0,0,0,0,103,55,50,54,108,101,0,0,79,110,108,121,32,56,48,48,48,72,122,32,115,97,109,112,108,101,32,114,97,116,101,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,79,110,108,121,32,109,111,110,111,32,116,114,97,99,107,115,32,97,114,101,32,97,108,108,111,119,101,100,46,10,0,0,103,55,50,50,32,100,101,99,111,100,101,114,0,0,0,0,70,114,97,109,101,32,115,104,111,117,108,100,32,104,97,118,101,32,97,116,32,108,101,97,115,116,32,49,50,32,98,121,116,101,115,44,32,103,111,116,32,37,100,32,105,110,115,116,101,97,100,10,0,0,0,0,115,101,108,101,99,116,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,80,97,99,107,101,116,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,102,108,118,32,101,110,99,111,100,101,114,0,0,0,0,0,37,99,32,101,115,99,95,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2443424);
/* memory initializer */ allocate([121,112,101,58,37,100,44,32,113,112,58,37,100,32,110,117,109,58,37,100,10,0,0,0,115,101,116,32,102,114,97,109,101,32,115,105,122,101,32,40,87,120,72,32,111,114,32,97,98,98,114,101,118,105,97,116,105,111,110,41,0,0,0,0,115,105,100,101,32,98,121,32,115,105,100,101,32,108,101,102,116,32,102,105,114,115,116,0,85,110,107,110,111,119,110,32,70,76,67,32,102,111,114,109,97,116,44,32,109,121,32,115,99,105,101,110,99,101,32,99,97,110,110,111,116,32,101,120,112,108,97,105,110,32,104,111,119,32,116,104,105,115,32,104,97,112,112,101,110,101,100,46,10,0,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,102,108,97,115,104,115,118,50,0,0,0,0,0,0,0,0,66,97,100,32,102,114,97,109,101,32,99,111,117,110,116,10,0,0,0,0,0,0,0,0,127,70,76,65,67,0,0,0,102,105,110,100,95,110,101,119,95,104,101,97,100,101,114,115,32,99,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,70,76,65,67,32,104,101,97,100,101,114,10,0,115,105,122,101,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,115,105,122,101,32,99,111,100,101,32,40,37,100,41,10,0,0,114,101,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,10,0,0,100,101,102,97,117,108,116,0,84,104,105,115,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,105,115,32,108,105,109,105,116,101,100,32,116,111,32,37,100,32,99,104,97,110,110,101,108,115,46,10,0,37,108,108,117,32,37,108,108,117,32,0,0,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,104,101,105,103,104,116,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,112,101,114,109,115,0,0,0,67,97,110,110,111,116,32,100,101,99,111,100,101,32,110,111,110,45,107,101,121,102,114,97,109,101,32,119,105,116,104,111,117,116,32,118,97,108,105,100,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,0,105,110,112,117,116,32,102,111,114,109,97,116,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,115,117,99,104,32,112,108,97,110,101,10,0,0,87,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,32,111,102,32,105,110,112,117,116,32,118,105,100,101,111,115,32,109,117,115,116,32,98,101,32,115,97,109,101,46,10,0,84,111,111,32,115,104,111,114,116,32,104,101,97,100,101,114,32,116,111,32,112,97,114,115,101,10,0,0,0,0,0,0,98,105,116,114,97,116,101,32,99,97,110,110,111,116,32,98,101,32,100,101,116,101,114,109,105,110,101,100,46,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,102,114,97,109,101,32,100,97,116,97,10,0,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,102,114,97,109,101,10,0,97,117,116,111,32,97,110,97,108,121,122,101,0,0,0,0,116,114,117,110,99,97,116,101,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,116,114,117,110,99,97,116,101,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,105,98,32,60,32,52,0,0,73,110,112,117,116,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,105,110,116,101,114,112,111,108,97,116,105,111,110,0,0,0,116,114,117,110,99,97,116,101,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,73,110,112,117,116,32,97,114,101,97,32,37,100,58,37,100,58,37,100,58,37,100,32,110,111,116,32,119,105,116,104,105,110,32,116,104,101,32,112,97,100,100,101,100,32,97,114,101,97,32,48,58,48,58,37,100,58,37,100,32,111,114,32,122,101,114,111,45,115,105,122,101,100,10,0,0,0,0,0,0,98,0,0,0,0,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,32,102,97,105,108,101,100,33,10,0,0,0,0,0,97,99,32,98,105,116,115,116,114,101,97,109,32,111,118,101,114,102,108,111,119,10,0,0,97,105,110,116,101,114,108,101,97,118,101,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,111,118,101,114,108,97,121,46,99,0,0,0,0,0,0,0,0,66,105,116,109,97,112,32,115,117,98,116,105,116,108,101,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,109,109,97,110,100,32,111,102,102,115,101,116,10,0,102,114,97,109,101,115,95,116,111,95,97,114,102,32,60,61,32,114,99,45,62,102,114,97,109,101,115,95,116,111,95,107,101,121,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,100,118,32,102,114,97,109,101,32,112,114,111,102,105,108,101,10,0,0,0,0,0,0,0,0,99,114,111,112,0,0,0,0,70,105,101,108,100,32,100,97,116,97,32,115,105,122,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,99,48,95,102,108,97,103,115,0,0,0,0,0,0,0,0,100,115,105,99,105,110,97,117,100,105,111,0,0,0,0,0,80,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,68,80,88,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,0,66,71,82,0,0,0,0,0,114,111,113,95,100,112,99,109,0,0,0,0,0,0,0,0,112,105,99,116,117,114,101,32,99,111,117,108,100,32,110,111,116,32,102,105,116,32,114,97,116,101,99,111,110,116,114,111,108,32,99,111,110,115,116,114,97,105,110,116,115,44,32,105,110,99,114,101,97,115,101,32,113,109,97,120,10,0,0,0,102,114,97,109,101,32,115,105,122,101,32,99,104,97,110,103,101,100,58,32,37,100,120,37,100,32,45,62,32,37,100,120,37,100,10,0,0,0,0,0,121,117,118,52,50,50,112,0,33,99,109,45,62,99,111,112,121,95,98,117,102,102,101,114,95,116,111,95,103,102,0,0,68,97,116,97,32,117,110,105,116,32,119,105,116,104,32,115,105,122,101,32,37,100,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,105,110,112,117,116,32,98,117,102,102,101,114,44,32,100,105,115,99,97,114,100,105,110,103,10,0,71,67,83,69,95,67,108,97,114,107,101,49,56,54,54,0,32,99,111,110,115,116,114,97,105,110,101,100,95,105,110,116,114,97,61,37,100,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,112,105,99,116,117,114,101,32,99,111,100,105,110,103,32,109,111,100,101,32,37,100,10,0,0,0,0,0,109,112,101,103,95,113,117,97,110,116,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,37,115,32,99,104,117,110,107,10,0,0,0,0,0,0,0,0,80,97,100,100,105,110,103,32,97,116,32,116,104,101,32,98,111,116,116,111,109,32,40,37,100,112,120,41,32,111,102,32,116,104,101,32,72,97,108,100,32,67,76,85,84,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,86,46,70,108,97,115,104,32,80,84,88,32,105,109,97,103,101,0,0,0,0,0,0,0,115,101,116,32,89,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,0,0,111,117,116,112,117,116,0,0,78,111,116,32,97,32,118,97,108,105,100,32,68,67,65,32,102,114,97,109,101,10,0,0,99,121,117,118,0,0,0,0,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,115,109,97,108,108,10,0,0,73,110,118,97,108,105,100,32,104,101,97,100,101,114,33,10,0,0,0,0,0,0,0,0,99,115,0,0,0,0,0,0,114,99,95,100,114,111,112,102,114,97,109,101,95,116,104,114,101,115,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,93,0,0,0,0,0,0,0,0,68,101,97,108,108,111,99,97,116,105,110,103,32,109,101,109,111,114,121,46,10,0,0,0,115,0,0,0,0,0,0,0,83,97,116,117,114,97,116,105,111,110,32,118,97,108,117,101,32,110,111,116,32,105,110,32,114,97,110,103,101,32,91,37,100,44,37,100,93,58,32,99,108,105,112,112,105,110,103,32,118,97,108,117,101,32,116,111,32,37,48,46,49,102,10,0,103,95,112,97,115,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,86,80,88,95,82,67,95,79,78,69,95,80,65,83,83,46,46,86,80,88,95,82,67,95,76,65,83,84,95,80,65,83,83,93,0,115,101,116,32,119,97,118,101,102,111,114,109,32,109,111,100,101,0,0,0,0,0,0,0,83,87,0,0,0,0,0,0,108,105,109,105,116,58,32,37,100,32,10,0,0,0,0,0,99,111,112,121,0,0,0,0,83,101,116,32,102,105,114,115,116,32,112,116,115,32,116,111,32,40,105,110,58,37,108,108,100,32,111,117,116,58,37,108,108,100,41,10,0,0,0,0,83,117,109,109,97,114,121,58,10,10,32,32,73,110,116,101,103,114,97,116,101,100,32,108,111,117,100,110,101,115,115,58,10,32,32,32,32,73,58,32,32,32,32,32,32,32,32,32,37,53,46,49,102,32,76,85,70,83,10,32,32,32,32,84,104,114,101,115,104,111,108,100,58,32,37,53,46,49,102,32,76,85,70,83,10,10,32,32,76,111,117,100,110,101,115,115,32,114,97,110,103,101,58,10,32,32,32,32,76,82,65,58,32,32,32,32,32,32,32,37,53,46,49,102,32,76,85,10,32,32,32,32,84,104,114,101,115,104,111,108,100,58,32,37,53,46,49,102,32,76,85,70,83,10,32,32,32,32,76,82,65,32,108,111,119,58,32,32,32,37,53,46,49,102,32,76,85,70,83,10,32,32,32,32,76,82,65,32,104,105,103,104,58,32,32,37,53,46,49,102,32,76,85,70,83,0,0,0,97,117,116,111,0,0,0,0,99,108,71,101,116,80,114,111,103,114,97,109,73,110,102,111,0,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,115,101,99,111,110,100,115,32,111,102,32,116,104,101,32,98,101,103,105,110,110,105,110,103,32,111,102,32,116,104,101,32,101,102,102,101,99,116,46,0,0,0,0,0,0,0,98,103,114,52,95,98,121,116,101,0,0,0,0,0,0,0,66,105,115,113,117,101,0,0,115,101,116,32,97,108,112,104,97,32,112,108,97,110,101,0,48,120,37,108,108,120,0,0,109,97,120,0,0,0,0,0,70,105,108,116,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,0,66,67,0,0,0,0,0,0,49,0,0,0,0,0,0,0,37,115,32,115,99,97,108,101,114,44,32,102,114,111,109,32,37,115,32,116,111,32,37,115,37,115,32,0,0,0,0,0,72,101,97,100,101,114,58,32,37,48,88,10,0,0,0,0,112,114,105,110,116,32,105,110,102,111,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,69,114,114,111,114,32,103,101,116,116,105,110,103,32,111,117,116,112,117,116,32,112,97,99,107,101,116,10,0,0,0,0,80,111,115,116,112,114,111,99,0,0,0,0,0,0,0,0,111,114,105,103,105,110,97,108,32,105,109,97,103,101,32,97,116,32,98,108,97,110,107,32,108,111,99,97,116,105,111,110,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,73,78,70,79,32,104,101,97,100,101,114,32,111,102,102,115,101,116,58,32,48,120,37,48,56,88,32,105,115,32,116,111,111,32,108,97,114,103,101,46,10,0,0,0,0,0,0,0,99,108,106,114,32,101,110,99,111,100,101,114,0,0,0,0,118,98,108,101,0,0,0,0,115,107,105,112,112,105,110,103,32,122,101,114,111,32,104,101,105,103,104,116,32,115,116,114,105,112,32,37,105,32,111,102,32,37,105,10,0,0,0,0,99,105,110,101,112,97,107,95,100,101,99,111,100,101,32,102,97,105,108,101,100,10,0,0,92,114,37,49,50,55,91,94,92,125,93,37,49,91,92,125,93,37,110,0,0,0,0,0,80,105,120,101,108,32,102,111,114,109,97,116,32,48,120,37,48,120,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,121,45,97,120,105,115,32,98,108,111,99,107,115,32,117,115,101,100,32,100,117,114,105,110,103,32,109,101,116,114,105,99,32,99,97,108,99,117,108,97,116,105,111,110,115,0,0,0,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,100,101,99,111,100,101,114,10,0,0,0,65,68,80,67,77,32,73,77,65,32,65,77,86,0,0,0,110,111,32,102,114,97,109,101,32,100,101,99,111,100,101,100,10,0,0,0,0,0,0,0,116,105,109,101,98,97,115,101,32,115,112,101,99,105,102,105,101,100,32,105,110,32,115,116,97,116,115,32,102,105,108,101,32,110,111,116,32,118,97,108,105,100,10,0,0,0,0,0,115,109,97,108,108,0,0,0,98,108,111,99,107,32,111,118,101,114,108,97,112,32,37,100,32,37,100,32,37,100,32,37,100,10,0,0,0,0,0,0,115,109,97,108,108,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,10,0,0,0,0,0,78,111,116,32,97,32,66,82,101,110,100,101,114,32,80,73,88,32,102,105,108,101,10,0,83,66,82,32,114,101,115,101,116,32,102,97,105,108,101,100,46,32,83,119,105,116,99,104,105,110,103,32,83,66,82,32,116,111,32,112,117,114,101,32,117,112,115,97,109,112,108,105,110,103,32,109,111,100,101,46,10,0,0,0,0,0,0,0,98,109,118,95,97,117,100,105,111,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,108,101,110,103,116,104,58,37,100,10,0,0,0,0,0,0,0,48,46,53,47,48,46,52,0,98,117,102,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,41,10,0,0,0,0,0,0,0,0,118,98,0,0,0,0,0,0,84,111,111,32,115,109,97,108,108,32,105,110,112,117,116,32,98,117,102,102,101,114,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,111,116,97,108,58,37,100,10,0,0,0,0,0,0,0,71,67,83,69,95,67,108,97,114,107,101,49,56,53,56,0,66,117,102,102,101,114,32,118,105,100,101,111,32,102,114,97,109,101,115,44,32,97,110,100,32,109,97,107,101,32,116,104,101,109,32,97,99,99,101,115,115,105,98,108,101,32,116,111,32,116,104,101,32,102,105,108,116,101,114,99,104,97,105,110,46,0,0,0,0,0,0,0,32,115,116,105,116,99,104,97,98,108,101,61,37,100,0,0,114,97,116,101,0,0,0,0,99,111,108,111,114,32,99,97,99,104,101,32,110,111,116,32,102,111,117,110,100,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,105,116,115,116,114,101,97,109,46,99,0,0,78,111,32,98,108,111,99,107,32,119,105,116,104,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,119,101,105,103,104,116,115,10,0,0,0,0,86,81,65,32,86,101,114,115,105,111,110,32,37,105,0,0,98,108,111,99,107,95,97,108,105,103,110,0,0,0,0,0,120,98,105,110,0,0,0,0,73,110,118,97,108,105,100,32,122,101,114,111,32,114,117,110,32,111,102,32,37,100,32,119,105,116,104,32,37,100,32,99,111,101,102,102,115,32,108,101,102,116,10,0,0,0,0,0,98,105,110,107,97,117,100,105,111,95,100,99,116,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,109,111,100,101,115,41,46,32,10,0,0,73,110,118,97,108,105,100,32,116,111,111,32,98,105,103,32,111,114,32,110,111,110,32,112,111,115,105,116,105,118,101,32,115,105,122,101,32,102,111,114,32,119,105,100,116,104,32,39,37,100,39,32,111,114,32,104,101,105,103,104,116,32,39,37,100,39,10,0,0,0,0,0,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,111,102,32,37,100,10,0,0,101,110,100,32,109,98,32,121,32,37,100,32,37,100,32,105,110,118,97,108,105,100,10,0,82,117,110,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,118,52,49,48,0,0,0,0,77,97,105,110,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,99,49,46,99,0,0,0,0,0,0,0,0,112,116,120,0,0,0,0,0,80,97,108,101,116,116,101,32,105,115,32,116,111,111,32,108,97,114,103,101,46,10,0,0,85,110,107,110,111,119,110,32,85,116,32,86,105,100,101,111,32,70,79,85,82,67,67,32,112,114,111,118,105,100,101,100,32,40,37,48,56,88,41,10,0,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,112,97,108,101,116,116,101,10,0,0,79,110,108,121,32,55,50,48,120,52,56,54,32,97,110,100,32,55,50,48,120,53,55,54,32,97,114,101,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,65,80,82,71,65,80,82,71,48,48,48,49,0,0,0,0,83,112,101,99,105,102,105,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,37,115,32,105,115,32,105,110,118,97,108,105,100,32,111,114,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,103,114,101,101,110,32,103,97,105,110,32,102,111,114,32,116,104,101,32,98,108,117,101,32,99,104,97,110,110,101,108,0,118,52,49,48,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,118,112,97,99,107,101,116,46,99,0,0,0,103,111,116,32,97,32,98,117,102,102,101,114,32,119,105,116,104,32,37,100,32,98,121,116,101,115,32,119,104,101,110,32,37,100,32,119,101,114,101,32,101,120,112,101,99,116,101,100,10,0,0,0,0,0,0,0,97,112,0,0,0,0,0,0,85,110,107,110,111,119,110,32,104,101,108,112,32,111,112,116,105,111,110,32,39,37,115,39,46,10,0,0,0,0,0,0,103,101,116,95,98,117,102,102,101,114,40,41,32,102,97,105,108,101,100,10,0,0,0,0,80,114,111,106,76,105,110,101,97,114,85,110,105,116,115,71,101,111,75,101,121,0,0,0,70,114,97,109,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,98,121,116,101,115,41,46,32,84,114,117,110,99,97,116,101,100,32,102,105,108,101,63,10,0,0,0,0,49,46,50,46,53,0,0,0,78,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,116,111,32,100,101,99,111,100,101,33,10,0,0,0,0,0,83,69,81,72,0,0,0,0,97,115,118,50,0,0,0,0,32,102,97,99,101,61,34,37,115,34,0,0,0,0,0,0,97,121,117,118,0,0,0,0,102,97,99,101,61,0,0,0,97,115,118,50,0,0,0,0,83,107,105,112,112,105,110,103,32,84,89,80,69,32,116,114,101,101,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,115,115,0,0,0,0,0,77,86,32,105,115,32,105,110,118,97,108,105,100,32,10,0,99,51,95,109,111,100,101,0,97,115,115,0,0,0,0,0,110,117,109,58,37,53,100,32,120,58,37,50,100,32,121,58,37,50,100,32,116,121,112,101,58,37,100,32,113,115,99,97,108,101,58,37,50,100,32,114,110,100,58,37,100,10,0,0,98,105,116,115,50,113,112,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,114,109,97,81,68,77,0,97,114,103,115,32,111,118,101,114,102,108,111,119,32,40,37,105,41,10,0,0,0,0,0,104,113,0,0,0,0,0,0,85,110,107,110,111,119,110,32,114,101,99,111,114,100,32,116,121,112,101,0,0,0,0,0,97,121,117,118,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,118,97,108,105,100,32,109,111,100,101,32,37,100,10,0,0,0,0,0,0,0,0,67,111,114,114,117,112,116,32,98,105,116,115,116,114,101,97,109,10,0,0,0,0,0,0,118,115,117,98,0,0,0,0,82,101,97,100,105,110,103,32,102,114,97,109,101,32,100,97,116,97,32,102,97,105,108,101,100,46,32,83,107,105,112,112,105,110,103,32,82,65,32,117,110,105,116,46,10,0,0,0,99,112,117,45,105,110,100,101,112,101,110,100,101,110,116,0,116,109,99,100,0,0,0,0,118,51,48,56,0,0,0,0,77,97,120,105,109,117,109,32,100,117,114,97,116,105,111,110,32,111,102,32,116,104,101,32,111,117,116,112,117,116,32,105,110,32,115,101,99,111,110,100,115,0,0,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,118,51,48,56,0,0,0,0,107,101,121,102,114,97,109,101,32,105,110,116,101,114,118,97,108,32,116,111,111,32,108,97,114,103,101,33,44,32,114,101,100,117,99,105,110,103,32,105,116,32,102,114,111,109,32,37,100,32,116,111,32,37,100,10,0,0,0,0,0,0,0,0,76,111,111,112,32,119,105,116,104,32,115,101,118,101,114,97,108,32,115,116,114,101,97,109,115,32,105,115,32,99,117,114,114,101,110,116,108,121,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,114,102,99,50,49,57,48,0,102,102,98,117,102,102,101,114,115,105,110,107,0,0,0,0,97,108,108,111,99,97,116,101,32,100,117,109,109,121,32,108,97,115,116,32,112,105,99,116,117,114,101,32,102,111,114,32,102,105,101,108,100,32,98,97,115,101,100,32,102,105,114,115,116,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,117,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,46,99,0,0,0,0,88,45,67,114,101,97,116,105,111,110,84,105,109,101,0,0,109,112,118,95,102,108,97,103,115,0,0,0,0,0,0,0,80,79,83,0,0,0,0,0,105,103,110,111,114,105,110,103,32,115,101,113,32,101,120,116,32,97,102,116,101,114,32,37,88,10,0,0,0,0,0,0,84,111,116,97,108,32,102,105,108,116,101,114,32,111,114,100,101,114,115,32,116,111,111,32,104,105,103,104,46,10,0,0,118,50,49,48,120,0,0,0,10,0,0,0,0,0,0,0,115,45,62,110,98,95,99,111,109,112,111,110,101,110,116,115,32,61,61,32,52,0,0,0,80,65,82,84,95,78,85,77,66,69,82,0,0,0,0,0,69,102,102,101,99,116,105,118,101,32,116,105,109,101,98,97,115,101,32,100,101,110,111,109,105,110,97,116,111,114,32,37,117,32,101,120,99,101,101,100,115,32,72,46,50,54,52,32,109,97,120,105,109,117,109,10,0,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,99,114,102,0,0,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,52,58,49,58,49,46,10,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,109,97,114,107,101,114,32,48,120,37,46,52,88,32,97,116,32,112,111,115,32,48,120,37,88,10,0,0,123,92,104,125,0,0,0,0,84,111,111,32,108,97,114,103,101,32,116,114,97,110,115,102,111,114,109,10,0,0,0,0,98,32,99,98,112,121,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,65,108,105,103,110,109,101,110,116,32,98,105,116,115,32,97,114,101,32,110,111,116,32,122,101,114,111,33,10,0,0,0,98,97,110,100,45,62,115,99,97,110,32,110,111,116,32,115,101,116,10,0,0,0,0,0,73,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,115,58,32,37,100,32,120,32,37,100,33,10,0,0,0,118,50,49,48,0,0,0,0,77,105,115,115,105,110,103,32,116,101,114,109,105,110,97,116,111,114,32,111,114,32,101,120,116,114,97,110,101,111,117,115,32,100,97,116,97,32,102,111,117,110,100,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,105,110,116,101,114,118,97,108,32,35,37,100,10,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,102,111,114,32,108,111,103,50,95,109,105,110,95,116,98,95,115,105,122,101,0,0,0,0,0,0,69,114,114,111,114,32,99,111,110,115,116,114,117,99,116,105,110,103,32,116,104,101,32,102,114,97,109,101,32,82,80,83,46,10,0,0,0,0,0,0,117,115,101,114,32,100,97,116,97,58,34,37,115,34,10,0,110,117,109,98,101,114,32,111,102,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,32,40,37,100,43,37,100,41,32,101,120,99,101,101,100,115,32,109,97,120,32,40,37,100,59,32,112,114,111,98,97,98,108,121,32,99,111,114,114,117,112,116,32,105,110,112,117,116,41,44,32,100,105,115,99,97,114,100,105,110,103,32,111,110,101,10,0,0,0,0,112,112,115,95,105,100,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,67,111,117,110,116,114,121,0,112,105,99,115,32,60,61,32,49,54,0,0,0,0,0,0,83,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,70,76,67,47,70,76,88,32,100,101,112,116,104,32,111,102,32,37,100,32,66,112,112,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,105,109,97,103,101,32,100,97,116,97,10,0,0,0,0,0,101,115,0,0,0,0,0,0,105,108,108,101,103,97,108,32,114,101,115,105,100,117,97,108,32,99,111,100,105,110,103,32,109,101,116,104,111,100,32,37,100,10,0,0,0,0,0,0,118,50,49,48,0,0,0,0,115,45,62,118,101,114,115,105,111,110,32,62,61,32,50,0,115,108,105,99,101,32,99,111,117,110,116,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,104,101,97,100,101,114,10,0,0,0,0,0,0,87,77,47,65,108,98,117,109,84,105,116,108,101,0,0,0,100,115,117,114,95,109,111,100,101,0,0,0,0,0,0,0,77,97,110,100,97,116,111,114,121,32,99,117,115,116,111,109,32,108,111,119,32,100,101,108,97,121,32,109,97,116,114,105,120,32,109,105,115,115,105,110,103,32,102,111,114,32,100,101,112,116,104,32,37,100,10,0,68,84,83,45,88,66,82,58,32,83,89,78,67,32,69,82,82,79,82,10,0,0,0,0,100,105,102,102,101,114,101,110,116,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,99,104,97,110,110,101,108,33,10,0,0,0,0,0,0,0,0,255,0,0,0,0,0,0,97,117,100,105,111,47,97,105,102,102,0,0,0,0,0,0,73,68,51,0,0,0,0,0,67,104,97,110,110,101,108,115,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,33,10,0,0,0,0,0,83,117,110,112,108,117,115,32,74,80,69,71,32,40,83,80,53,88,41,0,0,0,0,0,104,101,105,103,104,116,0,0,97,117,100,105,111,47,97,97,99,0,0,0,0,0,0,0,97,100,112,44,100,116,107,0,83,97,109,112,108,101,32,114,97,116,101,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,101,97,99,51,0,0,0,0,71,67,83,69,95,66,101,115,115,101,108,78,97,109,105,98,105,97,0,0,0,0,0,0,32,98,108,117,114,97,121,95,99,111,109,112,97,116,61,37,100,0,0,0,0,0,0,0,37,100,32,98,117,102,102,101,114,115,32,113,117,101,117,101,100,32,105,110,32,37,115,44,32,115,111,109,101,116,104,105,110,103,32,109,97,121,32,98,101,32,119,114,111,110,103,46,10,0,0,0,0,0,0,0,97,54,52,44,32,65,54,52,0,0,0,0,0,0,0,0,109,97,120,95,115,97,109,112,108,101,115,0,0,0,0,0,99,104,117,110,107,32,108,97,114,103,101,114,32,116,104,97,110,32,97,114,114,97,121,32,37,100,62,37,100,10,0,0,104,97,115,95,98,95,102,114,97,109,101,115,0,0,0,0,98,97,99,107,103,114,111,117,110,100,0,0,0,0,0,0,117,116,118,105,100,101,111,0,83,107,97,0,0,0,0,0,100,105,115,99,0,0,0,0,66,101,116,104,101,115,100,97,32,86,73,68,32,118,105,100,101,111,0,0,0,0,0,0,113,117,101,114,121,95,102,111,114,109,97,116,115,58,32,37,100,32,113,117,101,114,105,101,100,44,32,37,100,32,109,101,114,103,101,100,44,32,37,100,32,97,108,114,101,97,100,121,32,100,111,110,101,44,32,37,100,32,100,101,108,97,121,101,100,10,0,0,0,0,0,0,52,50,50,112,57,0,0,0,87,77,47,77,101,100,105,97,79,114,105,103,105,110,97,108,66,114,111,97,100,99,97,115,116,68,97,116,101,84,105,109,101,0,0,0,0,0,0,0,109,101,116,97,100,97,116,97,0,0,0,0,0,0,0,0,121,52,109,0,0,0,0,0,89,79,80,32,104,97,115,32,105,110,118,97,108,105,100,32,104,101,97,100,101,114,10,0,111,114,105,103,105,110,97,116,111,114,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,101,120,116,114,97,100,97,116,97,46,10,0,0,67,79,77,84,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,99,111,100,101,99,32,40,116,97,103,32,48,120,48,52,37,120,59,32,105,100,32,37,100,41,0,0,0,0,13,10,86,101,114,115,105,111,110,58,86,105,118,111,47,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,117,100,105,111,47,120,45,119,97,118,112,97,99,107,0,105,110,100,101,120,32,60,32,115,116,45,62,110,98,95,105,110,100,101,120,95,101,110,116,114,105,101,115,0,0,0,0,84,111,111,32,109,97,110,121,32,115,97,109,112,108,101,115,32,105,110,32,98,108,111,99,107,58,32,37,117,10,0,0,69,114,114,111,114,32,97,112,112,108,121,105,110,103,32,111,112,116,105,111,110,115,32,116,111,32,116,104,101,32,102,105,108,116,101,114,46,10,0,0,68,117,112,108,105,99,97,116,101,32,98,115,102,115,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,97,115,115,111,99,105,97,116,101,100,32,116,111,32,115,116,114,101,97,109,32,37,100,32,111,102,32,115,108,97,118,101,32,111,117,116,112,117,116,32,39,37,115,39,44,32,102,105,108,116,101,114,115,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,0,0,111,117,116,112,117,116,32,105,110,32,98,105,103,45,101,110,100,105,97,110,32,102,111,114,109,97,116,32,40,102,111,114,32,117,115,101,32,97,115,32,115,49,54,98,101,41,0,0,69,79,70,32,111,110,32,115,105,110,107,32,108,105,110,107,32,37,115,58,37,115,46,10,0,0,0,0,0,0,0,0,105,115,109,118,0,0,0,0,115,101,116,32,102,114,97,109,101,32,114,97,116,101,32,40,72,122,32,118,97,108,117,101,44,32,102,114,97,99,116,105,111,110,32,111,114,32,97,98,98,114,101,118,105,97,116,105,111,110,41,0,0,0,0,0,68,86,66,32,115,99,114,97,109,98,108,101,100,32,115,116,114,101,97,109,32,100,101,116,101,99,116,101,100,32,40,115,116,58,37,100,41,44,32,100,101,99,111,100,105,110,103,32,119,105,108,108,32,108,105,107,101,108,121,32,102,97,105,108,10,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,32,48,120,37,48,56,88,10,0,0,83,116,101,114,101,111,32,87,83,45,83,78,68,49,0,0,116,101,120,116,47,118,116,116,0,0,0,0,0,0,0,0,118,116,116,0,0,0,0,0,83,117,98,116,105,116,108,101,32,116,105,109,101,33,10,0,117,116,118,105,100,101,111,0,97,117,100,105,111,47,120,45,119,97,118,0,0,0,0,0,119,54,52,0,0,0,0,0,102,112,115,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,118,113,102,44,118,113,108,44,118,113,101,0,0,0,0,0,116,120,116,0,0,0,0,0,84,82,65,67,75,78,85,77,66,69,82,0,0,0,0,0,97,117,100,105,111,47,120,45,118,111,99,0,0,0,0,0,118,111,99,0,0,0,0,0,118,105,118,0,0,0,0,0,114,99,118,0,0,0,0,0,90,101,114,111,32,70,80,83,32,115,112,101,99,105,102,105,101,100,44,32,100,101,102,97,117,108,116,105,110,103,32,116,111,32,49,32,70,80,83,10,0,0,0,0,0,0,0,0,84,114,117,110,99,97,116,105,110,103,32,112,97,99,107,101,116,32,111,102,32,115,105,122,101,32,37,100,32,116,111,32,37,108,108,100,10,0,0,0,37,100,44,32,37,49,48,108,108,100,0,0,0,0,0,0,109,97,114,107,101,114,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,10,0,0,97,110,115,44,97,114,116,44,97,115,99,44,100,105,122,44,105,99,101,44,110,102,111,44,116,120,116,44,118,116,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,70,97,105,108,101,100,32,116,111,32,102,105,108,116,101,114,32,98,105,116,115,116,114,101,97,109,32,119,105,116,104,32,102,105,108,116,101,114,32,37,115,32,102,111,114,32,115,116,114,101,97,109,32,37,100,32,105,110,32,102,105,108,101,32,39,37,115,39,32,119,105,116,104,32,99,111,100,101,99,32,37,115,10,0,0,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,32,110,101,97,114,32,111,102,102,115,101,116,32,37,108,108,100,46,10,0,37,100,32,109,101,116,97,100,97,116,97,32,98,108,111,99,107,32,67,82,67,32,101,114,114,111,114,46,10,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,115,104,111,99,107,119,97,118,101,45,102,108,97,115,104,0,0,0,105,110,118,97,108,105,100,32,116,97,103,32,108,101,110,103,116,104,58,32,37,100,10,0,71,67,83,69,95,66,101,115,115,101,108,77,111,100,105,102,105,101,100,0,0,0,0,0,48,0,0,0,0,0,0,0,115,117,98,0,0,0,0,0,115,117,98,0,0,0,0,0,99,111,110,115,105,100,101,114,32,116,104,105,110,103,115,32,116,104,97,116,32,97,32,115,97,110,101,32,101,110,99,111,100,101,114,32,115,104,111,117,108,100,32,110,111,116,32,100,111,32,97,115,32,97,110,32,101,114,114,111,114,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,120,45,115,117,98,114,105,112,0,0,0,0,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,32,45,45,62,32,37,100,58,37,50,100,58,37,50,100,37,42,49,91,44,46,93,37,51,100,37,42,91,32,93,88,49,58,37,117,32,88,50,58,37,117,32,89,49,58,37,117,32,89,50,58,37,117,0,0,0,0,0,0,0,77,101,100,105,97,32,116,121,112,101,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,116,104,101,32,39,37,115,39,32,102,105,108,116,101,114,32,111,117,116,112,117,116,32,112,97,100,32,37,100,32,40,37,115,41,32,97,110,100,32,116,104,101,32,39,37,115,39,32,102,105,108,116,101,114,32,105,110,112,117,116,32,112,97,100,32,37,100,32,40,37,115,41,10,0,0,0,98,101,116,104,115,111,102,116,118,105,100,0,0,0,0,0,98,105,116,114,97,116,101,32,105,115,32,116,111,111,32,104,105,103,104,10,0,0,0,0,115,112,100,105,102,0,0,0,99,111,109,109,101,110,116,0,105,110,118,97,108,105,100,32,99,111,109,109,101,110,116,32,115,105,122,101,32,40,37,117,41,10,0,0,0,0,0,0,87,114,111,110,103,32,109,97,103,105,99,10,0,0,0,0,37,115,47,77,97,110,105,102,101,115,116,0,0,0,0,0,109,111,114,101,32,116,104,97,110,32,62,50,32,115,116,114,101,97,109,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,109,106,112,103,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,117,112,100,97,116,101,44,32,111,102,102,115,101,116,61,37,100,32,108,101,110,103,116,104,61,37,100,32,101,120,116,101,110,100,115,32,98,101,121,111,110,100,32,112,97,108,101,116,116,101,32,115,105,122,101,10,0,0,0,0,0,0,0,0,99,111,108,111,114,109,97,116,114,105,120,0,0,0,0,0,114,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,95,101,110,116,114,121,95,112,114,101,102,105,120,0,0,0,0,0,0,0,115,114,116,112,0,0,0,0,78,79,87,0,0,0,0,0,68,111,110,39,116,32,115,101,110,100,32,82,84,67,80,32,115,101,110,100,101,114,32,114,101,112,111,114,116,115,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,0,0,0,115,99,97,108,101,0,0,0,101,110,99,111,100,101,114,0,97,117,100,105,111,47,120,45,101,97,99,51,0,0,0,0,109,106,112,101,103,32,100,101,109,117,120,101,114,0,0,0,101,110,97,98,108,101,32,117,110,115,97,102,101,32,109,111,100,101,0,0,0,0,0,0,71,67,83,69,95,66,101,115,115,101,108,49,56,52,49,0,102,97,107,101,0,0,0,0,115,119,0,0,0,0,0,0,97,103,103,114,101,115,115,105,118,101,0,0,0,0,0,0,73,110,116,101,114,112,108,97,121,32,67,57,51,0,0,0,115,119,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,118,105,100,101,111,32,102,114,97,109,101,115,32,116,111,32,114,101,99,111,114,100,0,0,0,0,0,0,0,0,105,103,110,111,114,101,32,100,116,115,0,0,0,0,0,0,73,86,0,0,0,0,0,0,98,99,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,105,100,32,105,110,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,67,111,100,101,99,83,112,101,99,105,102,105,99,83,105,100,101,37,108,108,100,0,0,0,37,42,115,32,37,42,115,32,37,108,108,100,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,110,111,32,101,115,115,101,110,99,101,10,0,0,0,0,0,72,69,73,71,72,84,0,0,65,115,112,101,99,116,32,114,97,116,105,111,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,109,117,120,101,114,32,40,37,100,47,37,100,41,32,97,110,100,32,101,110,99,111,100,101,114,32,108,97,121,101,114,32,40,37,100,47,37,100,41,10,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,109,101,110,115,105,111,110,115,32,37,100,32,37,100,10,0,115,101,114,118,105,99,101,95,112,114,111,118,105,100,101,114,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,117,108,116,105,109,111,116,105,111,110,0,0,0,0,0,0,71,67,83,69,95,65,117,115,116,114,97,108,105,97,110,78,97,116,105,111,110,97,108,83,112,104,101,114,111,105,100,0,32,105,110,116,101,114,108,97,99,101,100,61,37,115,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,112,101,103,101,110,99,46,99,0,0,0,99,111,110,115,105,100,101,114,32,97,108,108,32,115,112,101,99,32,110,111,110,32,99,111,109,112,108,105,97,110,99,105,101,115,32,97,115,32,101,114,114,111,114,115,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,116,120,100,0,0,0,0,0,99,57,51,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,118,102,114,97,109,101,115,0,116,119,105,110,118,113,0,0,115,116,112,115,0,0,0,0,70,114,97,109,101,32,116,111,111,32,115,109,97,108,108,32,40,37,100,32,98,121,116,101,115,41,46,32,84,114,117,110,99,97,116,101,100,32,102,105,108,101,63,10,0,0,0,0,116,116,97,0,0,0,0,0,111,118,101,114,114,101,97,100,32,101,110,100,32,111,102,32,97,116,111,109,32,39,37,46,52,115,39,32,98,121,32,37,108,108,100,32,98,121,116,101,115,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,115,112,97,99,101,32,114,101,115,101,114,118,101,100,32,102,111,114,32,99,117,101,115,58,32,37,100,32,40,110,101,101,100,101,100,58,32,37,108,108,100,41,46,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,108,101,110,103,116,104,32,48,120,37,108,108,120,32,62,32,48,120,37,108,108,120,32,102,111,114,32,115,121,110,116,97,120,32,101,108,101,109,101,110,116,32,37,105,10,0,0,0,116,116,97,0,0,0,0,0,13,10,0,0,0,0,0,0,115,116,114,102,116,105,109,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2453664);
/* memory initializer */ allocate([71,67,83,69,95,65,105,114,121,77,111,100,105,102,105,101,100,49,56,52,57,0,0,0,32,100,101,99,105,109,97,116,101,61,37,100,0,0,0,0,116,115,99,99,50,0,0,0,115,116,97,114,116,95,110,117,109,98,101,114,0,0,0,0,99,111,109,112,108,105,97,110,116,0,0,0,0,0,0,0,83,71,73,32,82,76,69,32,56,45,98,105,116,0,0,0,114,97,119,0,0,0,0,0,99,97,109,116,97,115,105,97,0,0,0,0,0,0,0,0,114,97,116,105,111,32,111,102,32,101,114,114,111,114,115,32,40,48,46,48,58,32,110,111,32,101,114,114,111,114,115,44,32,49,46,48,58,32,49,48,48,37,32,101,114,114,111,114,115,41,32,97,98,111,118,101,32,119,104,105,99,104,32,102,102,109,112,101,103,32,114,101,116,117,114,110,115,32,97,110,32,101,114,114,111,114,32,105,110,115,116,101,97,100,32,111,102,32,115,117,99,99,101,115,115,46,0,0,0,0,0,0,116,114,117,101,115,112,101,101,99,104,0,0,0,0,0,0,84,80,79,83,0,0,0,0,115,101,116,32,115,101,103,109,101,110,116,32,108,101,110,103,116,104,32,105,110,32,115,101,99,111,110,100,115,0,0,0,105,118,0,0,0,0,0,0,37,115,47,115,116,114,101,97,109,37,100,83,101,103,49,45,70,114,97,103,37,100,0,0,115,116,115,115,0,0,0,0,117,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,116,105,109,101,99,111,100,101,44,32,115,121,110,116,97,120,58,32,104,104,58,109,109,58,115,115,91,58,59,46,93,102,102,10,0,0,0,0,0,0,85,77,70,32,112,97,99,107,101,116,32,109,105,115,115,105,110,103,10,0,0,0,0,0,116,114,117,101,109,111,116,105,111,110,50,0,0,0,0,0,70,76,86,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,44,32,99,104,111,111,115,101,32,102,114,111,109,32,40,52,52,49,48,48,44,32,50,50,48,53,48,44,32,49,49,48,50,53,41,10,0,97,117,100,105,111,115,97,109,112,108,101,115,105,122,101,0,116,114,117,101,109,111,116,105,111,110,49,0,0,0,0,0,116,109,118,0,0,0,0,0,114,101,118,105,115,105,111,110,50,32,40,101,108,101,109,101,110,116,32,48,120,65,48,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,37,115,32,101,110,99,111,100,105,110,103,32,102,97,105,108,101,100,10,0,0,0,0,0,71,67,83,69,95,65,105,114,121,49,56,51,48,0,0,0,32,110,114,61,37,100,0,0,99,111,110,115,105,100,101,114,32,116,104,105,110,103,115,32,116,104,97,116,32,118,105,111,108,97,116,101,32,116,104,101,32,115,112,101,99,44,32,97,114,101,32,102,97,115,116,32,116,111,32,99,104,101,99,107,32,97,110,100,32,104,97,118,101,32,110,111,116,32,98,101,101,110,32,115,101,101,110,32,105,110,32,116,104,101,32,119,105,108,100,32,97,115,32,101,114,114,111,114,115,0,0,0,115,101,116,32,115,105,109,117,108,97,116,101,100,32,108,105,110,101,32,115,112,101,101,100,32,40,98,121,116,101,115,32,112,101,114,32,115,101,99,111,110,100,41,0,0,0,0,0,116,105,102,102,0,0,0,0,115,103,105,114,108,101,0,0,109,97,120,105,109,117,109,32,101,114,114,111,114,32,114,97,116,101,0,0,0,0,0,0,99,114,97,122,121,32,115,116,97,114,116,32,116,105,109,101,44,32,105,97,109,32,115,99,97,114,101,100,44,32,103,105,118,105,110,103,32,117,112,10,0,0,0,0,0,0,0,0,99,111,108,111,114,99,104,97,110,110,101,108,109,105,120,101,114,0,0,0,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,109,115,32,102,97,114,116,10,0,0,0,0,0,116,0,0,0,0,0,0,0,105,99,108,0,0,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,111,102,32,116,104,101,32,111,117,116,112,117,116,32,115,116,114,101,97,109,46,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,71,67,83,95,78,68,71,95,80,97,114,105,115,0,0,0,32,115,108,105,99,101,95,109,105,110,95,109,98,115,61,37,100,0,0,0,0,0,0,0,109,97,120,95,101,114,114,111,114,95,114,97,116,101,0,0,99,97,114,101,102,117,108,0,83,71,73,32,105,109,97,103,101,0,0,0,0,0,0,0,97,49,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,118,97,108,117,101,32,39,37,115,39,32,102,111,114,32,111,112,116,105,111,110,32,39,37,115,39,58,32,37,115,10,0,0,0,100,101,102,97,117,108,116,0,105,110,112,117,116,115,58,37,100,32,102,109,116,58,37,115,32,115,114,97,116,101,58,37,100,32,99,108,58,37,115,10,0,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,98,108,111,99,107,95,104,101,105,103,104,116,32,61,61,32,98,108,111,99,107,95,119,105,100,116,104,0,0,0,0,0,115,97,109,101,0,0,0,0,110,32,60,61,32,51,50,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,99,98,112,0,0,0,0,0,116,105,108,101,95,114,111,119,115,32,60,61,32,52,0,0,101,110,100,95,112,116,115,0,50,53,0,0,0,0,0,0,115,0,0,0,0,0,0,0,97,115,121,110,99,61,37,100,0,0,0,0,0,0,0,0,100,101,105,110,116,0,0,0,115,101,116,32,99,105,114,99,108,101,32,99,101,110,116,101,114,32,112,111,115,105,116,105,111,110,32,111,110,32,121,45,97,120,105,115,0,0,0,0,99,97,0,0,0,0,0,0,71,67,83,95,65,84,70,95,80,97,114,105,115,0,0,0,32,115,108,105,99,101,95,109,97,120,95,109,98,115,61,37,100,0,0,0,0,0,0,0,112,114,105,110,116,32,116,105,109,101,115,116,97,109,112,32,100,101,98,117,103,103,105,110,103,32,105,110,102,111,0,0,100,101,102,97,117,108,116,0,97,98,111,114,116,32,100,101,99,111,100,105,110,103,32,111,110,32,109,105,110,111,114,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,0,108,111,119,95,112,97,115,115,95,102,105,108,116,101,114,0,115,103,105,0,0,0,0,0,84,66,58,32,37,100,47,37,100,32,45,62,32,37,100,47,37,100,10,0,0,0,0,0,92,120,37,48,50,120,0,0,115,98,115,108,0,0,0,0,99,116,0,0,0,0,0,0,115,101,116,32,105,110,116,101,114,108,97,99,105,110,103,0,99,115,0,0,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,119,105,100,116,104,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,100,101,102,97,117,108,116,0,114,101,102,101,114,101,110,99,101,0,0,0,0,0,0,0,65,0,0,0,0,0,0,0,116,104,105,115,95,109,111,100,101,32,61,61,32,90,69,82,79,77,86,0,0,0,0,0,115,101,116,32,98,111,116,116,111,109,32,114,105,103,104,116,32,121,32,99,111,111,114,100,105,110,97,116,101,0,0,0,119,58,37,100,32,104,58,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,120,58,37,100,32,121,58,37,100,32,99,111,108,111,114,58,48,120,37,48,50,88,37,48,50,88,37,48,50,88,37,48,50,88,10,0,0,0,0,0,0,48,0,0,0,0,0,0,0,78,111,110,45,52,58,50,58,48,32,99,111,108,111,114,32,115,112,97,99,101,32,114,101,113,117,105,114,101,115,32,112,114,111,102,105,108,101,32,62,61,32,49,0,0,0,0,0,99,48,115,0,0,0,0,0,89,85,86,0,0,0,0,0,113,104,100,0,0,0,0,0,33,40,99,109,45,62,99,111,112,121,95,98,117,102,102,101,114,95,116,111,95,97,114,102,32,38,32,126,48,120,51,41,0,0,0,0,0,0,0,0,71,67,83,95,66,97,116,97,118,105,97,95,74,97,107,97,114,116,97,0,0,0,0,0,32,115,108,105,99,101,95,109,97,120,95,115,105,122,101,61,37,100,0,0,0,0,0,0,100,101,98,117,103,95,116,115,0,0,0,0,0,0,0,0,101,120,112,108,111,100,101,0,80,97,100,100,105,110,103,32,111,110,32,116,104,101,32,114,105,103,104,116,32,40,37,100,112,120,41,32,111,102,32,116,104,101,32,72,97,108,100,32,67,76,85,84,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,10,0,0,0,78,105,110,116,101,110,100,111,32,71,97,109,101,99,117,98,101,32,84,72,80,32,118,105,100,101,111,0,0,0,0,0,121,0,0,0,0,0,0,0,99,111,108,111,114,98,97,108,97,110,99,101,0,0,0,0,115,119,97,112,32,99,104,114,111,109,97,32,102,105,101,108,100,115,0,0,0,0,0,0,114,99,95,114,101,115,105,122,101,95,97,108,108,111,119,101,100,32,101,120,112,101,99,116,101,100,32,98,111,111,108,101,97,110,0,0,0,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,105,110,112,117,116,32,102,105,108,101,115,58,32,0,0,0,0,0,92,37,99,0,0,0,0,0,100,101,102,97,117,108,116,0,114,99,95,114,101,115,105,122,101,95,100,111,119,110,95,116,104,114,101,115,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,93,0,0,0,0,0,0,119,97,118,101,102,111,114,109,95,109,111,100,101,0,0,0,78,0,0,0,0,0,0,0,109,118,58,32,108,37,100,114,37,100,32,40,37,100,44,37,100,41,32,10,0,0,0,0,100,101,102,97,117,108,116,0,115,112,101,99,105,102,121,32,116,104,101,32,97,115,115,117,109,101,100,32,102,105,101,108,100,32,111,114,100,101,114,0,99,108,71,101,116,80,114,111,103,114,97,109,66,117,105,108,100,73,110,102,111,0,0,0,115,116,97,114,116,95,116,105,109,101,0,0,0,0,0,0,98,103,114,52,0,0,0,0,66,101,105,103,101,0,0,0,97,0,0,0,0,0,0,0,48,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,0,0,0,0,0,0,109,111,100,0,0,0,0,0,70,73,76,84,69,82,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,0,102,114,111,110,116,32,114,105,103,104,116,45,111,102,45,99,101,110,116,101,114,0,0,0,115,101,116,32,103,114,105,100,32,108,105,110,101,32,116,104,105,99,107,110,101,115,115,0,101,104,104,32,102,108,97,103,115,32,105,110,118,97,108,105,100,63,33,0,0,0,0,0,112,114,105,110,116,95,105,110,102,111,0,0,0,0,0,0,82,101,115,97,109,112,108,105,110,103,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,105,110,116,101,114,110,97,108,32,115,49,54,47,115,51,50,47,102,108,116,47,100,98,108,10,0,0,0,0,0,0,0,0,117,115,105,110,103,32,110,112,112,32,102,105,108,116,101,114,115,32,48,120,37,88,47,48,120,37,88,10,0,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,92,114,37,49,91,92,125,93,37,110,0,0,0,0,0,0,98,108,111,99,107,121,0,0,97,100,112,99,109,95,105,109,97,95,97,109,118,0,0,0,116,105,109,101,98,97,115,101,61,37,117,47,37,117,0,0,76,97,114,103,101,32,82,111,111,109,0,0,0,0,0,0,76,97,114,103,101,32,82,111,111,109,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,78,111,110,32,109,111,110,111,116,111,110,101,32,116,105,109,101,32,98,111,114,100,101,114,115,10,0,0,0,0,0,0,97,97,99,95,99,111,100,101,114,0,0,0,0,0,0,0,104,118,103,97,0,0,0,0,100,101,99,111,100,101,95,112,99,101,58,32,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,105,103,110,111,114,105,110,103,32,115,110,100,95,32,99,104,117,110,107,32,108,101,110,103,116,104,58,37,100,10,0,0,85,110,107,110,111,119,110,32,102,105,108,101,58,32,98,112,112,32,37,100,44,32,112,105,120,100,101,112,116,104,32,37,100,44,32,118,99,108,97,115,115,32,37,100,0,0,0,0,48,46,50,51,49,47,48,46,48,57,52,32,48,46,55,48,57,47,48,46,56,55,52,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,115,117,98,102,114,97,109,101,95,108,101,110,32,37,105,10,0,0,85,110,115,117,112,112,111,114,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,0,0,0,0,0,0,71,67,83,95,86,111,105,114,111,108,95,85,110,105,102,105,101,95,80,97,114,105,115,0,120,49,58,37,100,32,120,50,58,37,100,32,121,49,58,37,100,32,121,50,58,37,100,32,119,58,37,100,32,104,58,37,100,32,120,58,37,100,32,121,58,37,100,32,112,116,115,58,37,108,108,100,32,116,58,37,102,32,99,114,111,112,61,37,100,58,37,100,58,37,100,58,37,100,10,0,0,0,0,0,32,115,108,105,99,101,115,95,109,97,120,61,37,100,0,0,92,125,0,0,0,0,0,0,101,120,116,114,97,99,116,32,97,110,32,97,116,116,97,99,104,109,101,110,116,32,105,110,116,111,32,97,32,102,105,108,101,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,108,111,114,32,99,97,99,104,101,32,98,105,116,115,58,32,37,100,10,0,0,0,78,111,32,98,108,111,99,107,32,119,105,116,104,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,116,101,114,109,115,10,0,0,0,0,0,0,86,81,65,32,86,101,114,115,105,111,110,32,37,100,0,0,100,101,116,101,99,116,32,105,109,112,114,111,112,101,114,32,98,105,116,115,116,114,101,97,109,32,108,101,110,103,116,104,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,111,101,102,102,105,99,101,110,116,115,32,97,116,32,108,101,118,101,108,32,37,100,10,0,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,109,97,112,112,105,110,103,115,41,46,32,10,0,0,0,0,0,0,0,119,58,37,100,32,104,58,37,100,32,115,97,114,58,37,100,47,37,100,32,45,62,32,119,58,37,100,32,104,58,37,100,32,115,97,114,58,37,100,47,37,100,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,102,105,114,115,116,32,102,105,101,108,100,32,115,108,105,99,101,32,99,111,117,110,116,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,67,111,110,115,116,114,97,105,110,101,100,32,66,97,115,101,108,105,110,101,0,0,0,0,118,45,62,115,46,109,98,95,104,101,105,103,104,116,32,61,61,32,118,45,62,115,46,104,101,105,103,104,116,32,43,32,49,53,32,62,62,32,52,32,124,124,32,118,45,62,115,46,109,98,95,104,101,105,103,104,116,32,61,61,32,40,40,40,118,45,62,115,46,104,101,105,103,104,116,32,43,32,49,53,32,62,62,32,52,41,43,40,50,41,45,49,41,38,126,40,40,50,41,45,49,41,41,0,116,104,112,0,0,0,0,0,101,114,114,111,114,32,99,97,108,99,117,108,97,116,105,110,103,32,99,111,110,118,101,114,115,105,111,110,32,99,111,101,102,102,105,99,105,101,110,116,115,10,0,0,0,0,0,0,69,110,99,111,100,105,110,103,32,112,97,114,97,109,101,116,101,114,115,32,37,48,56,88,10,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,98,103,0,0,0,0,0,0,100,101,102,97,117,108,116,0,72,111,119,32,109,97,110,121,32,116,105,109,101,115,32,115,104,111,117,108,100,32,116,104,101,32,98,111,120,98,108,117,114,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,97,108,112,104,97,0,0,0,103,108,111,98,97,108,0,0,80,114,111,106,67,111,111,114,100,84,114,97,110,115,71,101,111,75,101,121,0,0,0,0,85,110,99,111,109,112,114,101,115,115,105,110,103,32,102,97,105,108,101,100,32,40,37,108,117,32,111,102,32,37,108,117,41,32,119,105,116,104,32,101,114,114,111,114,32,37,100,10,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,115,108,105,99,101,32,116,121,112,101,32,37,100,32,10,0,60,102,111,110,116,0,0,0,123,92,99,38,72,37,88,38,125,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,70,85,76,76,32,116,114,101,101,10,0,0,0,0,0,37,100,32,104,101,97,100,101,114,32,98,121,116,101,115,32,117,110,112,97,114,115,101,100,10,0,0,0,0,0,0,0,115,117,98,99,111,100,101,99,32,52,55,32,99,111,109,112,114,101,115,115,105,111,110,32,37,100,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,98,108,101,110,100,32,109,111,100,101,0,0,0,0,0,109,101,115,115,101,100,32,117,112,32,111,114,100,101,114,44,32,112,111,115,115,105,98,108,101,32,102,114,111,109,32,115,101,101,107,105,110,103,63,32,115,107,105,112,112,105,110,103,32,99,117,114,114,101,110,116,32,98,32,102,114,97,109,101,10,0,0,0,0,0,0,0,97,118,103,84,101,120,0,0,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,32,111,114,32,116,114,117,110,99,97,116,101,100,10,0,108,116,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,48,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,32,112,108,97,110,97,114,0,0,104,115,117,98,0,0,0,0,110,45,100,101,116,101,114,109,105,110,105,115,116,105,99,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,102,111,114,109,97,116,0,0,111,110,108,121,32,89,85,86,52,50,48,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,100,37,99,37,100,0,0,0,119,97,114,110,105,110,103,58,32,102,105,114,115,116,32,102,114,97,109,101,32,105,115,32,110,111,32,107,101,121,102,114,97,109,101,10,0,0,0,0,105,110,118,97,108,105,100,32,110,101,119,32,98,97,99,107,115,116,101,112,32,37,100,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,110,101,119,32,98,97,99,107,115,116,101,112,32,37,100,10,0,0,0,0,0,0,0,0,117,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,67,66,80,0,0,0,0,0,0,0,0,69,110,97,98,108,101,32,97,108,116,101,114,110,97,116,101,32,115,99,97,110,116,97,98,108,101,46,0,0,0,0,0,78,66,95,83,65,77,80,76,69,83,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,112,105,99,32,97,102,116,101,114,32,37,88,10,0,0,73,110,118,97,108,105,100,32,98,108,111,99,107,115,105,122,101,46,10,0,0,0,0,0,32,119,105,116,104,32,97,114,103,115,32,39,37,115,39,0,108,105,98,97,118,99,111,100,101,99,47,109,106,112,101,103,100,101,99,46,99,0,0,0,37,46,42,115,0,0,0,0,120,50,54,52,32,111,112,116,105,111,110,115,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,37,115,32,99,111,100,101,99,32,99,111,110,116,114,111,108,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,82,71,66,32,50,52,46,10,0,0,73,110,118,97,108,105,100,32,116,112,101,110,100,10,0,0,126,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,121,109,32,101,110,99,111,117,110,116,101,114,101,100,58,32,37,100,46,10,0,0,0,98,32,109,98,95,116,121,112,101,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,67,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,105,110,116,101,114,110,97,108,32,115,116,114,117,99,116,117,114,101,115,33,10,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,99,111,114,114,101,99,116,105,111,110,115,58,32,37,100,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,118,101,114,115,105,111,110,33,10,0,0,0,0,0,69,114,114,111,114,58,32,82,71,66,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,109,101,100,105,97,110,32,112,114,101,100,105,99,116,111,114,10,0,0,0,0,0,0,0,32,12,9,10,13,0,0,0,115,112,115,95,109,97,120,95,110,117,109,95,114,101,111,114,100,101,114,95,112,105,99,115,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,84,104,101,32,99,117,95,113,112,95,100,101,108,116,97,32,37,100,32,105,115,32,111,117,116,115,105,100,101,32,116,104,101,32,118,97,108,105,100,32,114,97,110,103,101,32,91,37,100,44,32,37,100,93,46,10,0,0,0,0,0,0,0,0,120,50,54,52,32,45,32,99,111,114,101,32,48,48,48,48,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,115,104,111,114,116,32,116,101,114,109,32,98,117,102,102,101,114,32,115,116,97,116,101,32,100,101,116,101,99,116,101,100,10,0,0,0,0,0,0,0,86,85,73,0,0,0,0,0,73,110,99,114,101,97,115,105,110,103,32,114,101,111,114,100,101,114,32,98,117,102,102,101,114,32,116,111,32,37,100,10,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,99,104,117,110,107,32,116,121,112,101,32,37,48,50,88,10,0,0,0,0,0,0,0,50,52,66,112,112,32,70,76,67,47,70,76,88,0,0,0,101,114,114,111,114,32,105,110,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,111,102,32,98,108,111,99,107,32,37,100,120,37,100,10,0,0,32,40,110,111,45,111,112,41,0,0,0,0,0,0,0,0,113,108,101,118,101,108,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,109,97,121,98,101,32,98,117,103,103,121,32,115,116,114,101,97,109,10,0,0,0,0,73,110,118,97,108,105,100,32,99,111,110,116,101,120,116,32,109,111,100,101,108,32,37,100,44,32,118,97,108,105,100,32,118,97,108,117,101,115,32,97,114,101,32,48,32,97,110,100,32,49,10,0,0,0,0,0,114,101,97,100,95,113,117,97,110,116,95,116,97,98,108,101,32,101,114,114,111,114,10,0,85,110,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,37,46,50,53,54,115,10,0,0,0,0,0,68,105,97,108,111,103,117,101,32,76,101,118,101,108,32,40,100,66,41,0,0,0,0,0,76,111,119,32,68,101,108,97,121,58,32,72,97,115,32,67,117,115,116,111,109,32,81,117,97,110,116,105,122,97,116,105,111,110,32,77,97,116,114,105,120,33,10,0,0,0,0,0,68,84,83,45,88,66,82,58,32,100,101,99,111,100,105,110,103,32,88,66,82,32,101,120,116,101,110,115,105,111,110,10,0,0,0,0,0,0,0,0,67,111,111,107,32,118,101,114,115,105,111,110,32,37,100,0,37,99,37,100,0,0,0,0,102,119,113,118,103,97,0,0,115,112,53,120,0,0,0,0,118,105,100,101,111,95,115,105,122,101,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,71,67,83,95,86,111,105,114,111,108,95,49,56,55,53,95,80,97,114,105,115,0,0,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,77,68,67,84,10,0,0,0,0,0,0,0,0,32,115,108,105,99,101,115,61,37,100,0,0,0,0,0,0,100,101,102,97,117,108,116,0,100,117,109,112,95,97,116,116,97,99,104,109,101,110,116,0,65,80,69,32,100,101,99,111,100,101,114,0,0,0,0,0,98,117,102,102,101,114,0,0,114,105,103,104,116,0,0,0,65,108,116,101,114,110,97,116,105,118,101,0,0,0,0,0,87,77,47,80,97,114,116,79,102,83,101,116,0,0,0,0,86,67,51,47,68,78,120,72,68,0,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,116,111,32,99,111,110,118,101,114,116,32,98,101,116,119,101,101,110,32,116,104,101,32,102,111,114,109,97,116,115,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,102,105,108,116,101,114,32,39,37,115,39,32,97,110,100,32,116,104,101,32,102,105,108,116,101,114,32,39,37,115,39,10,0,0,0,0,0,52,50,48,112,57,0,0,0,87,77,47,69,110,99,111,100,105,110,103,84,105,109,101,0,87,101,98,86,84,84,32,100,101,115,99,114,105,112,116,105,111,110,115,32,107,105,110,100,0,0,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,70,111,117,110,100,32,83,77,86,32,100,97,116,97,10,0,99,111,110,100,117,99,116,111,114,0,0,0,0,0,0,0,70,80,83,0,0,0,0,0,105,110,100,101,120,32,61,61,32,48,32,124,124,32,105,101,91,45,49,93,46,116,105,109,101,115,116,97,109,112,32,60,32,116,105,109,101,115,116,97,109,112,0,0,0,0,0,0,69,114,114,111,114,32,97,112,112,108,121,105,110,103,32,103,101,110,101,114,105,99,32,102,105,108,116,101,114,32,111,112,116,105,111,110,115,46,10,0,115,112,101,99,58,37,115,32,98,115,102,115,58,37,115,32,109,97,116,99,104,101,115,32,115,116,114,101,97,109,32,37,100,32,111,102,32,115,108,97,118,101,32,111,117,116,112,117,116,32,39,37,115,39,10,0,98,101,0,0,0,0,0,0,109,107,100,105,114,32,102,97,105,108,101,100,10,0,0,0,37,48,52,100,37,48,50,100,37,48,50,100,45,37,48,50,100,37,48,50,100,37,48,50,100,0,0,0,0,0,0,0,119,113,118,103,97,0,0,0,71,67,83,95,84,97,110,97,110,97,114,105,118,101,95,80,97,114,105,115,0,0,0,0,32,115,108,105,99,101,100,95,116,104,114,101,97,100,115,61,37,100,0,0,0,0,0,0,97,100,100,32,97,110,32,97,116,116,97,99,104,109,101,110,116,32,116,111,32,116,104,101,32,111,117,116,112,117,116,32,102,105,108,101,0,0,0,0,100,101,116,101,99,116,32,98,105,116,115,116,114,101,97,109,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,100,101,118,105,97,116,105,111,110,115,0,0,0,0,0,0,0,100,110,120,104,100,0,0,0,37,115,0,0,0,0,0,0,108,111,103,108,101,118,101,108,0,0,0,0,0,0,0,0,69,120,112,101,99,116,101,100,32,105,110,116,54,52,32,102,111,114,32,37,115,32,98,117,116,32,102,111,117,110,100,32,37,115,10,0,0,0,0,0,66,101,97,109,32,83,111,102,116,119,97,114,101,32,83,73,70,70,0,0,0,0,0,0,115,101,116,32,116,104,101,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,112,108,97,121,108,105,115,116,32,101,110,116,114,105,101,115,0,0,0,0,0,0,114,116,112,0,0,0,0,0,83,105,101,114,114,97,32,86,77,68,0,0,0,0,0,0,45,62,0,0,0,0,0,0,115,107,105,112,95,114,116,99,112,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,114,101,109,97,105,110,105,110,103,32,108,101,110,10,0,0,0,0,0,105,110,116,101,110,115,105,116,121,32,98,97,115,101,100,32,99,111,108,111,114,105,110,103,0,0,0,0,0,0,0,0,73,83,70,84,0,0,0,0,114,97,119,32,69,45,65,67,45,51,0,0,0,0,0,0,118,99,49,32,100,101,109,117,120,101,114,0,0,0,0,0,104,113,118,103,97,0,0,0,71,67,83,95,66,101,108,103,101,95,49,57,53,48,95,66,114,117,115,115,101,108,115,0,117,110,115,97,102,101,0,0,32,108,111,111,107,97,104,101,97,100,95,116,104,114,101,97,100,115,61,37,100,0,0,0,97,116,116,97,99,104,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,98,105,116,115,116,114,101,97,109,0,0,0,0,0,0,0,70,101,101,98,108,101,32,70,105,108,101,115,47,83,99,117,109,109,86,77,32,68,88,65,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,37,115,32,115,116,97,114,116,101,100,32,111,110,32,37,48,52,100,45,37,48,50,100,45,37,48,50,100,32,97,116,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,10,82,101,112,111,114,116,32,119,114,105,116,116,101,110,32,116,111,32,34,37,115,34,10,0,0,105,103,110,100,116,115,0,0,82,73,68,58,32,37,46,56,120,10,0,0,0,0,0,0,115,101,116,32,103,114,101,101,110,32,99,111,110,116,114,97,115,116,0,0,0,0,0,0,84,104,101,32,112,97,103,101,115,105,122,101,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,10,0,0,0,0,0,0,76,97,118,102,0,0,0,0,115,116,114,101,97,109,95,115,101,103,109,101,110,116,44,115,115,101,103,109,101,110,116,0,69,120,116,114,97,100,97,116,97,0,0,0,0,0,0,0,83,101,103,97,32,70,73,76,77,32,47,32,67,80,75,0,115,97,109,112,108,101,95,99,111,117,110,116,0,0,0,0,83,68,82,50,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,109,112,101,103,50,32,102,114,97,109,101,10,0,0,0,0,0,0,98,111,120,98,108,117,114,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,104,101,97,100,101,114,32,109,101,116,97,100,97,116,97,10,0,0,70,80,83,0,0,0,0,0,67,111,110,118,101,114,116,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,97,32,118,105,100,101,111,32,111,117,116,112,117,116,46,0,0,100,105,109,101,110,115,105,111,110,115,32,110,111,116,32,115,101,116,10,0,0,0,0,0,83,101,114,118,105,99,101,48,49,0,0,0,0,0,0,0,110,104,100,0,0,0,0,0,67,111,110,116,105,110,117,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,32,102,111,114,32,112,105,100,32,37,100,32,101,120,112,101,99,116,101,100,32,37,100,32,103,111,116,32,37,100,10,0,0,71,67,83,95,80,97,100,97,110,103,95,74,97,107,97,114,116,97,0,0,0,0,0,0,32,116,104,114,101,97,100,115,61,37,100,0,0,0,0,0,112,114,105,110,116,32,112,114,111,103,114,101,115,115,32,114,101,112,111,114,116,32,100,117,114,105,110,103,32,101,110,99,111,100,105,110,103,0,0,0,97,118,95,102,105,102,111,95,115,105,122,101,40,115,116,114,101,97,109,45,62,102,105,102,111,41,32,61,61,32,48,0,118,101,114,105,102,121,32,101,109,98,101,100,100,101,100,32,67,82,67,115,0,0,0,0,77,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,115,117,98,116,105,116,108,101,115,32,115,116,114,101,97,109,115,32,114,101,97,99,104,101,100,10,0,0,0,0,100,120,97,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,44,32,110,111,116,32,119,114,105,116,105,110,103,32,88,105,110,103,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,71,84,77,111,100,101,108,84,121,112,101,71,101,111,75,101,121,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,114,101,112,111,114,116,32,34,37,115,34,58,32,37,115,10,0,97,117,100,105,111,0,0,0,51,71,80,50,32,40,51,71,80,80,50,32,102,105,108,101,32,102,111,114,109,97,116,41,0,0,0,0,0,0,0,0,37,115,37,55,105,58,37,45,55,105,0,0,0,0,0,0,66,114,111,107,101,110,32,102,105,108,101,44,32,116,114,97,107,47,109,100,97,116,32,110,111,116,32,97,116,32,116,111,112,45,108,101,118,101,108,10,0,0,0,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,83,77,65,70,32,99,104,117,110,107,32,37,48,56,120,10,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,119,114,105,116,101,32,99,97,99,104,101,100,32,97,117,100,105,111,32,112,97,99,107,101,116,32,114,101,116,58,37,100,10,0,0,0,0,0,85,110,107,110,111,119,110,32,101,110,116,114,121,32,48,120,37,88,10,0,0,0,0,0,83,66,97,71,101,110,32,98,105,110,97,117,114,97,108,32,98,101,97,116,115,32,115,99,114,105,112,116,0,0,0,0,64,37,117,32,64,37,117,32,37,99,0,0,0,0,0,0,116,105,116,108,101,0,0,0,52,107,115,99,111,112,101,0,115,101,116,32,102,105,114,115,116,32,110,117,109,98,101,114,32,105,110,32,116,104,101,32,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,83,65,77,73,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,71,67,83,95,78,84,70,95,80,97,114,105,115,0,0,0,32,99,104,114,111,109,97,95,113,112,95,111,102,102,115,101,116,61,37,100,0,0,0,0,115,116,97,116,115,0,0,0,99,114,99,99,104,101,99,107,0,0,0,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,71,73,70,32,40,71,114,97,112,104,105,99,115,32,73,110,116,101,114,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,116,105,102,102,0,0,0,0,79,110,108,121,32,56,45,98,105,116,32,112,114,101,99,105,115,105,111,110,32,105,115,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,116,105,101,114,116,101,120,115,101,113,118,105,100,101,111,0,78,65,76,32,115,105,122,101,32,37,100,32,62,32,37,100,44,32,116,114,121,32,45,115,108,105,99,101,45,109,97,120,45,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,115,112,108,105,116,32,72,50,54,51,32,112,97,99,107,101,116,44,32,117,115,101,32,45,109,98,95,105,110,102,111,32,37,100,32,111,114,32,45,112,115,32,49,46,10,0,112,101,114,102,111,114,109,101,114,0,0,0,0,0,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,104,108,115,95,116,105,109,101,0,0,0,0,0,0,0,0,107,101,121,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,114,101,110,97,109,101,32,102,105,108,101,32,37,115,32,116,111,32,37,115,10,0,116,101,120,116,0,0,0,0,37,100,58,37,100,58,37,100,37,99,37,100,0,0,0,0,85,77,70,32,112,97,99,107,101,116,32,116,111,111,32,115,104,111,114,116,10,0,0,0,116,97,114,103,97,0,0,0,116,97,114,103,97,95,121,50,49,54,0,0,0,0,0,0,70,76,86,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,109,111,110,111,32,83,112,101,101,120,32,97,117,100,105,111,10,0,0,0,0,0,97,117,100,105,111,115,97,109,112,108,101,114,97,116,101,0,82,84,80,32,111,117,116,112,117,116,0,0,0,0,0,0,116,97,114,103,97,0,0,0,76,101,103,111,32,77,105,110,100,115,116,111,114,109,115,32,82,83,79,0,0,0,0,0,101,120,105,116,101,100,32,97,117,100,105,111,32,115,117,98,104,101,97,100,101,114,10,0,76,101,103,111,32,77,105,110,100,115,116,111,114,109,115,32,82,83,79,0,0,0,0,0,116,97,107,0,0,0,0,0,109,105,115,115,105,110,103,32,115,121,110,99,32,105,100,10,0,0,0,0,0,0,0,0,71,97,109,101,67,117,98,101,32,82,83,68,0,0,0,0,52,107,102,108,97,116,0,0,102,108,117,115,104,32,37,115,32,37,100,46,37,100,0,0,71,67,83,95,77,111,110,116,101,95,77,97,114,105,111,95,82,111,109,101,0,0,0,0,32,102,97,115,116,95,112,115,107,105,112,61,37,100,0,0,114,101,97,100,32,99,111,109,112,108,101,120,32,102,105,108,116,101,114,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,102,114,111,109,32,97,32,102,105,108,101,0,0,0,0,0,0,0,0,115,101,116,32,101,114,114,111,114,32,100,101,116,101,99,116,105,111,110,32,102,108,97,103,115,0,0,0,0,0,0,0,108,105,110,101,115,112,101,101,100,0,0,0,0,0,0,0,82,80,76,32,47,32,65,82,77,111,118,105,101,0,0,0,103,105,102,0,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,32,98,117,105,108,100,105,110,103,32,114,101,112,111,114,116,32,102,105,108,101,32,110,97,109,101,10,0,0,0,0,0,0,0,0,82,101,97,108,77,101,100,105,97,0,0,0,0,0,0,0,115,99,97,108,101,47,114,97,116,101,32,105,115,32,37,117,47,37,117,32,119,104,105,99,104,32,105,115,32,105,110,118,97,108,105,100,46,32,40,84,104,105,115,32,102,105,108,101,32,104,97,115,32,98,101,101,110,32,103,101,110,101,114,97,116,101,100,32,98,121,32,98,114,111,107,101,110,32,115,111,102,116,119,97,114,101,46,41,10,0,0,0,0,0,0,0,115,118,113,51,0,0,0,0,97,61,99,111,110,116,114,111,108,58,115,116,114,101,97,109,105,100,61,37,100,13,10,0,112,97,99,107,101,116,32,102,114,97,103,109,101,110,116,32,112,111,115,105,116,105,111,110,32,105,110,118,97,108,105,100,32,37,117,44,37,117,32,110,111,116,32,105,110,32,37,117,10,0,0,0,0,0,0,0,115,118,113,49,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,10,0,0,0,0,115,118,113,49,0,0,0,0,82,76,50,0,0,0,0,0,115,117,110,114,97,115,116,0,40,115,116,97,114,116,38,49,41,32,61,61,32,48,0,0,115,117,110,114,97,115,116,0,115,116,97,114,116,116,0,0,115,117,98,118,105,101,119,101,114,0,0,0,0,0,0,0,111,99,104,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,52,107,0,0,0,0,0,0,73,78,70,79,32,115,117,98,99,104,117,110,107,32,116,114,117,110,99,97,116,101,100,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,71,67,83,95,77,71,73,95,70,101,114,114,111,0,0,0,32,100,101,97,100,122,111,110,101,61,37,100,44,37,100,0,102,105,108,116,101,114,95,99,111,109,112,108,101,120,95,115,99,114,105,112,116,0,0,0,101,114,114,95,100,101,116,101,99,116,0,0,0,0,0,0,84,73,70,70,32,105,109,97,103,101,0,0,0,0,0,0,97,48,0,0,0,0,0,0,37,112,45,37,116,46,108,111,103,0,0,0,0,0,0,0,115,114,116,0,0,0,0,0,97,114,116,105,115,116,0,0,115,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,82,101,100,83,112,97,114,107,0,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,115,101,116,32,102,97,100,101,32,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,48,46,53,0,0,0,0,0,82,101,97,108,84,101,120,116,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,98,115,108,32,62,61,32,48,0,0,0,0,0,0,0,0,118,97,108,0,0,0,0,0,104,101,97,100,101,114,95,98,99,46,112,111,115,32,60,61,32,48,120,102,102,102,102,0,115,114,116,0,0,0,0,0,115,105,122,101,0,0,0,0,97,109,112,95,99,104,114,111,109,97,0,0,0,0,0,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,115,112,53,120,0,0,0,0,33,109,101,109,99,109,112,40,38,99,109,45,62,99,111,117,110,116,115,46,109,118,44,32,38,122,101,114,111,95,99,111,117,110,116,115,46,109,118,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,109,118,41,41,0,115,101,116,32,116,104,101,32,116,101,114,109,105,110,97,108,32,115,99,97,108,101,32,118,97,108,117,101,0,0,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,103,114,97,112,104,32,37,100,32,105,110,112,117,116,32,102,114,111,109,32,115,116,114,101,97,109,32,37,100,58,37,100,0,0,0,0,0,0,0,0,97,117,116,111,32,100,101,116,101,99,116,32,112,97,114,105,116,121,0,0,0,0,0,0,115,111,110,105,99,0,0,0,121,48,0,0,0,0,0,0,50,107,115,99,111,112,101,0,115,101,116,32,99,104,114,111,109,97,32,101,102,102,101,99,116,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,71,67,83,95,77,97,107,97,115,115,97,114,95,74,97,107,97,114,116,97,0,0,0,0,32,99,113,109,61,37,100,0,112,114,101,115,101,114,118,101,32,108,97,110,100,115,99,97,112,101,32,103,101,111,109,101,116,114,121,0,0,0,0,0,108,97,118,102,105,0,0,0,81,80,32,111,102,102,115,101,116,32,98,101,116,119,101,101,110,32,80,45,32,97,110,100,32,66,45,102,114,97,109,101,115,0,0,0,0,0,0,0,115,101,116,32,102,108,97,103,115,0,0,0,0,0,0,0,116,105,102,102,0,0,0,0,70,80,83,58,32,37,100,47,37,100,32,45,62,32,37,100,47,37,100,10,0,0,0,0,115,110,111,119,0,0,0,0,85,110,107,110,111,119,110,32,107,101,121,32,39,37,115,39,32,105,110,32,70,70,82,69,80,79,82,84,10,0,0,0,115,105,100,101,32,98,121,32,115,105,100,101,32,104,97,108,102,32,119,105,100,116,104,32,114,105,103,104,116,32,102,105,114,115,116,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,115,112,112,46,99,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,116,104,114,101,115,104,111,108,100,0,0,0,0,115,110,111,119,0,0,0,0,105,110,116,101,114,108], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2463904);
/* memory initializer */ allocate([65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,99,104,114,111,109,97,32,115,116,114,101,110,103,116,104,0,0,0,0,0,48,0,0,0,0,0,0,0,99,104,114,111,109,97,32,114,101,100,0,0,0,0,0,0,115,109,118,106,112,101,103,0,109,97,105,110,0,0,0,0,97,117,116,111,0,0,0,0,48,0,0,0,0,0,0,0,121,51,0,0,0,0,0,0,115,109,99,0,0,0,0,0,78,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,114,101,32,110,111,116,32,97,99,99,101,112,116,97,98,108,101,46,10,0,0,0,0,114,97,119,32,65,67,45,51,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,108,99,45,62,114,99,95,116,119,111,112,97,115,115,95,115,116,97,116,115,95,105,110,46,98,117,102,0,0,99,48,95,115,116,114,101,110,103,116,104,0,0,0,0,0,50,107,102,108,97,116,0,0,49,0,0,0,0,0,0,0,33,99,109,45,62,99,111,112,121,95,98,117,102,102,101,114,95,116,111,95,97,114,102,0,71,67,83,95,76,105,115,98,111,110,95,76,105,115,98,111,110,0,0,0,0,0,0,0,115,109,97,99,107,118,105,100,0,0,0,0,0,0,0,0,32,56,120,56,100,99,116,61,37,100,0,0,0,0,0,0,103,114,97,112,104,95,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,0,0,98,95,113,111,102,102,115,101,116,0,0,0,0,0,0,0,99,108,117,116,0,0,0,0,84,105,101,114,116,101,120,32,76,105,109,105,116,101,100,32,83,69,81,32,118,105,100,101,111,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,51,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,115,105,112,114,0,0,0,0,99,104,114,111,109,97,95,115,119,97,112,0,0,0,0,0,107,102,95,109,111,100,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,86,80,88,95,75,70,95,68,73,83,65,66,76,69,68,46,46,86,80,88,95,75,70,95,65,85,84,79,93,0,0,0,0,0,67,111,110,118,101,114,116,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,97,32,115,112,101,99,116,114,117,109,32,118,105,100,101,111,32,111,117,116,112,117,116,46,0,102,105,108,101,0,0,0,0,48,0,0,0,0,0,0,0,114,99,95,114,101,115,105,122,101,95,117,112,95,116,104,114,101,115,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,93,0,0,0,0,0,0,0,0,115,101,116,32,119,97,118,101,102,111,114,109,32,115,116,101,112,32,118,97,108,117,101,0,105,110,112,117,116,0,0,0,82,69,68,67,79,68,69,32,82,51,68,0,0,0,0,0,72,0,0,0,0,0,0,0,109,98,32,116,121,112,101,58,32,37,100,32,10,0,0,0,81,67,80,0,0,0,0,0,114,105,103,104,116,0,0,0,114,111,117,110,100,32,116,111,32,110,101,97,114,101,115,116,0,0,0,0,0,0,0,0,80,86,70,32,40,80,111,114,116,97,98,108,101,32,86,111,105,99,101,32,70,111,114,109,97,116,41,0,0,0,0,0,111,114,100,101,114,0,0,0,84,101,99,104,110,111,84,114,101,110,100,32,80,86,65,0,99,108,71,101,116,80,108,97,116,102,111,114,109,73,68,115,0,0,0,0,0,0,0,0,102,97,100,101,32,97,108,112,104,97,32,105,102,32,105,116,32,105,115,32,97,118,97,105,108,97,98,108,101,32,111,110,32,116,104,101,32,105,110,112,117,116,0,0,0,0,0,0,98,103,114,56,0,0,0,0,83,111,110,121,32,80,108,97,121,115,116,97,116,105,111,110,32,83,84,82,0,0,0,0,65,122,117,114,101,0,0,0,115,101,116,32,98,108,117,101,32,112,108,97,110,101,0,0,37,108,108,105,100,58,37,48,50,100,58,37,48,50,100,46,37,48,54,100,0,0,0,0,103,97,117,115,115,0,0,0,71,101,110,101,114,105,99,32,101,114,114,111,114,32,105,110,32,97,110,32,101,120,116,101,114,110,97,108,32,108,105,98,114,97,114,121,0,0,0,0,70,82,67,0,0,0,0,0,116,104,105,99,107,110,101,115,115,0,0,0,0,0,0,0,99,45,62,99,104,114,68,115,116,72,32,60,61,32,100,115,116,72,0,0,0,0,0,0,115,104,111,114,116,101,110,0,110,97,116,117,114,97,108,32,98,105,99,117,98,105,99,32,115,112,108,105,110,101,0,0,80,108,97,121,115,116,97,116,105,111,110,32,80,111,114,116,97,98,108,101,32,80,77,80,0,0,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,37,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,116,101,114,110,97,108,108,121,44,32,83,49,54,47,83,51,50,47,70,76,84,47,68,66,76,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,37,100,32,101,114,114,111,114,115,32,105,110,32,112,111,115,116,112,114,111,99,101,115,115,32,115,116,114,105,110,103,32,34,37,115,34,10,0,0,0,102,105,108,108,32,122,101,114,111,101,115,32,97,116,32,98,108,97,110,107,32,108,111,99,97,116,105,111,110,115,0,0,115,103,105,114,108,101,0,0,80,74,83,32,40,80,104,111,101,110,105,120,32,74,97,112,97,110,105,109,97,116,105,111,110,32,83,111,99,105,101,116,121,41,32,115,117,98,116,105,116,108,101,115,0,0,0,0,92,97,110,37,49,117,37,49,91,92,125,93,37,110,0,0,109,97,120,32,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,32,105,110,118,97,108,105,100,58,32,37,117,10,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,105,122,101,32,111,102,32,116,104,101,32,120,45,97,120,105,115,32,98,108,111,99,107,115,32,117,115,101,100,32,100,117,114,105,110,103,32,109,101,116,114,105,99,32,99,97,108,99,117,108,97,116,105,111,110,115,0,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,88,65,83,0,0,0,0,0,0,0,116,105,109,101,98,97,115,101,61,0,0,0,0,0,0,0,115,103,105,0,0,0,0,0,108,97,114,103,101,0,0,0,108,97,114,103,101,0,0,0,105,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,32,105,100,10,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,98,115,95,112,111,105,110,116,101,114,32,112,111,105,110,116,115,32,116,111,32,97,32,109,105,100,100,108,101,32,110,111,105,115,101,32,98,111,114,100,101,114,32,111,117,116,115,105,100,101,32,116,104,101,32,116,105,109,101,32,98,111,114,100,101,114,115,32,116,97,98,108,101,58,32,37,100,10,0,0,0,0,0,0,0,70,111,114,99,101,32,77,105,100,47,83,105,100,101,32,102,111,114,32,116,104,101,32,119,104,111,108,101,32,102,114,97,109,101,32,105,102,32,112,111,115,115,105,98,108,101,0,0,50,107,0,0,0,0,0,0,83,97,109,112,108,101,32,114,97,116,101,32,105,110,100,101,120,32,105,110,32,112,114,111,103,114,97,109,32,99,111,110,102,105,103,32,101,108,101,109,101,110,116,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,32,105,110,100,101,120,32,99,111,110,102,105,103,117,114,101,100,32,98,121,32,116,104,101,32,99,111,110,116,97,105,110,101,114,46,10,0,0,105,110,118,97,108,105,100,32,118,105,115,117,97,108,32,99,108,97,115,115,10,0,0,0,48,46,50,53,47,48,46,49,56,56,32,48,46,51,56,47,48,46,53,48,49,32,48,46,55,52,53,47,48,46,56,49,53,32,49,47,48,46,56,49,53,0,0,0,0,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,99,104,97,110,110,101,108,32,108,101,110,32,62,32,115,97,109,112,108,101,115,95,112,101,114,95,102,114,97,109,101,10,0,0,85,110,107,110,111,119,110,32,98,105,116,45,100,101,112,116,104,58,32,37,100,10,0,0,68,105,115,97,98,108,105,110,103,32,117,115,101,95,118,97,114,105,97,98,108,101,95,98,108,111,99,107,95,108,101,110,44,32,105,102,32,116,104,105,115,32,102,97,105,108,115,32,99,111,110,116,97,99,116,32,116,104,101,32,102,102,109,112,101,103,32,100,101,118,101,108,111,112,101,114,115,32,97,110,100,32,115,101,110,100,32,117,115,32,116,104,101,32,102,105,108,101,10,0,0,0,0,0,71,67,83,95,66,111,103,111,116,97,95,66,111,103,111,116,97,0,0,0,0,0,0,0,108,97,118,102,105,46,99,114,111,112,100,101,116,101,99,116,46,121,0,0,0,0,0,0,32,116,114,101,108,108,105,115,61,37,100,0,0,0,0,0,125,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,112,114,101,100,105,99,116,111,114,32,109,111,100,101,58,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,99,117,115,116,111,109,32,115,97,109,112,108,101,32,114,97,116,101,46,10,0,0,0,0,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,111,102,32,37,100,10,0,0,99,114,101,97,116,101,32,97,32,99,111,109,112,108,101,120,32,102,105,108,116,101,114,103,114,97,112,104,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,32,98,117,102,102,101,114,32,37,100,10,0,0,0,0,0,97,108,108,111,119,32,110,111,110,45,115,116,97,110,100,97,114,100,105,122,101,100,32,101,120,112,101,114,105,109,101,110,116,97,108,32,116,104,105,110,103,115,0,0,0,0,0,0,67,111,101,102,102,105,99,105,101,110,116,32,105,110,100,101,120,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,114,101,115,105,100,117,101,115,41,46,32,10,0,0,0,0,0,0,0,84,111,111,32,98,105,103,32,118,97,108,117,101,32,111,114,32,105,110,118,97,108,105,100,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,111,117,116,95,119,47,111,119,32,111,114,32,111,117,116,95,104,47,111,104,46,32,77,97,121,98,101,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,111,117,116,95,119,58,39,37,115,39,32,111,114,32,102,111,114,32,111,117,116,95,104,58,39,37,115,39,32,105,115,32,115,101,108,102,45,114,101,102,101,114,101,110,99,105,110,103,46,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,115,103,105,0,0,0,0,0,83,108,105,99,101,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,0,0,100,117,109,112,95,121,117,118,58,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,110,111,110,45,114,101,103,117,108,97,114,32,102,105,108,101,32,37,115,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,105,101,114,116,101,120,115,101,113,118,105,100,101,111,0,73,110,112,117,116,32,102,114,97,109,101,32,100,111,101,115,32,110,111,116,32,115,112,101,99,105,102,121,32,97,32,115,117,112,112,111,114,116,101,100,32,99,111,108,111,114,115,112,97,99,101,44,32,97,110,100,32,110,111,110,101,32,104,97,115,32,98,101,101,110,32,115,112,101,99,105,102,105,101,100,32,97,115,32,115,111,117,114,99,101,32,101,105,116,104,101,114,10,0,0,0,0,0,0,70,114,97,109,101,32,105,110,102,111,32,110,111,116,32,52,32,98,121,116,101,115,0,0,84,104,101,32,109,97,120,105,109,117,109,32,118,97,108,117,101,32,102,111,114,32,108,111,119,114,101,115,32,115,117,112,112,111,114,116,101,100,32,98,121,32,116,104,101,32,100,101,99,111,100,101,114,32,105,115,32,37,100,10,0,0,0,0,115,101,116,32,116,104,101,32,114,101,100,32,103,97,105,110,32,102,111,114,32,116,104,101,32,98,108,117,101,32,99,104,97,110,110,101,108,0,0,0,73,110,99,111,114,114,101,99,116,32,100,101,108,116,97,32,116,97,98,108,101,58,32,37,105,32,100,101,108,116,97,115,32,120,32,37,105,32,98,105,116,115,10,0,0,0,0,0,115,101,116,32,98,108,117,101,32,104,105,103,104,108,105,103,104,116,115,0,0,0,0,0,97,108,112,104,97,95,112,111,119,101,114,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,70,70,82,69,80,79,82,84,32,101,110,118,105,114,111,110,109,101,110,116,32,118,97,114,105,97,98,108,101,58,32,37,115,10,0,0,0,0,0,0,80,114,111,106,101,99,116,105,111,110,71,101,111,75,101,121,0,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,102,97,120,32,109,111,100,101,0,0,0,115,108,105,99,101,32,97,102,116,101,114,32,98,105,116,115,116,114,101,97,109,32,101,110,100,10,0,0,0,0,0,0,65,114,105,97,108,0,0,0,99,111,108,111,114,61,0,0,83,107,105,112,32,102,105,110,97,108,32,98,105,116,115,116,114,101,97,109,32,119,114,105,116,101,111,117,116,46,0,0,83,107,105,112,112,105,110,103,32,77,67,76,82,32,116,114,101,101,10,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,110,117,109,98,101,114,32,111,102,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,58,32,37,100,10,0,0,0,0,0,0,100,101,99,111,100,101,100,32,115,105,122,101,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,99,50,95,109,111,100,101,0,70,32,37,100,47,37,100,47,37,100,10,0,0,0,0,0,97,118,103,66,80,84,101,120,0,0,0,0,0,0,0,0,83,117,98,112,97,99,107,101,116,58,32,116,121,112,101,61,37,100,32,115,105,122,101,61,37,100,32,115,116,97,114,116,95,111,102,102,115,61,37,120,10,0,0,0,0,0,0,0,112,114,111,102,105,108,101,0,72,101,97,100,101,114,32,116,114,117,110,99,97,116,101,100,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,99,109,95,108,120,102,0,100,97,114,0,0,0,0,0,115,97,110,109,0,0,0,0,100,101,116,101,114,109,105,110,105,115,116,105,99,0,0,0,104,101,105,103,104,116,0,0,84,105,109,101,115,116,97,109,112,32,105,110,32,115,101,99,111,110,100,115,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,100,114,111,112,112,101,100,32,97,103,97,105,110,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,97,115,107,32,112,108,97,110,101,10,0,0,0,0,0,99,111,108,111,114,115,112,97,99,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,106,112,101,103,10,0,0,0,0,0,0,0,78,111,32,102,105,108,101,110,97,109,101,32,112,114,111,118,105,100,101,100,33,10,0,0,97,108,108,111,99,97,116,105,110,103,32,100,117,109,109,121,32,108,97,115,116,32,112,105,99,116,117,114,101,32,102,111,114,32,66,32,102,114,97,109,101,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,111,108,100,32,98,97,99,107,115,116,101,112,32,37,100,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,111,108,100,32,98,97,99,107,115,116,101,112,32,37,100,10,0,0,0,0,0,0,0,0,115,97,109,105,0,0,0,0,99,98,112,95,114,100,0,0,97,108,116,101,114,110,97,116,101,95,115,99,97,110,0,0,78,66,95,67,79,78,83,85,77,69,68,95,83,65,77,80,76,69,83,0,0,0,0,0,109,112,101,103,95,100,101,99,111,100,101,95,112,111,115,116,105,110,105,116,40,41,32,102,97,105,108,117,114,101,10,0,98,108,111,99,107,32,100,97,116,97,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,102,105,108,116,101,114,32,39,37,115,39,0,0,115,45,62,110,98,95,99,111,109,112,111,110,101,110,116,115,32,61,61,32,51,0,0,0,65,114,105,97,108,0,0,0,115,51,48,50,109,0,0,0,120,50,54,52,111,112,116,115,0,0,0,0,0,0,0,0,32,32,37,42,115,37,100,10,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,100,105,109,101,110,115,105,111,110,115,10,0,115,51,48,50,109,0,0,0,77,105,115,115,105,110,103,32,83,79,84,10,0,0,0,0,92,126,0,0,0,0,0,0,83,99,97,110,32,112,97,116,116,101,114,110,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,0,0,99,98,112,99,32,100,97,109,97,103,101,100,32,97,116,32,37,100,32,37,100,10,0,0,69,110,100,32,109,97,114,107,101,114,32,109,105,115,115,105,110,103,33,10,0,0,0,0,109,105,115,109,97,116,99,104,105,110,103,32,116,114,97,110,115,102,111,114,109,95,115,105,122,101,33,10,0,0,0,0,79,83,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,33,10,0,0,0,86,101,114,32,62,32,50,32,105,115,32,117,110,100,101,114,32,100,101,118,101,108,111,112,109,101,110,116,44,32,102,105,108,101,115,32,101,110,99,111,100,101,100,32,119,105,116,104,32,105,116,32,109,97,121,32,110,111,116,32,98,101,32,100,101,99,111,100,97,98,108,101,32,119,105,116,104,32,102,117,116,117,114,101,32,118,101,114,115,105,111,110,115,33,33,33,10,85,115,101,32,118,115,116,114,105,99,116,61,45,50,32,47,32,45,115,116,114,105,99,116,32,45,50,32,116,111,32,117,115,101,32,105,116,32,97,110,121,119,97,121,46,10,0,32,32,32,32,91,37,115,93,32,116,97,114,103,101,116,58,37,115,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,32,105,110,100,101,120,58,37,100,10,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,115,112,115,95,109,97,120,95,100,101,99,95,112,105,99,95,98,117,102,102,101,114,105,110,103,95,109,105,110,117,115,49,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,115,108,105,99,101,32,115,101,103,109,101,110,116,32,109,105,115,115,105,110,103,10,0,114,118,52,48,0,0,0,0,120,50,54,52,32,45,32,99,111,114,101,32,37,100,0,0,105,108,108,101,103,97,108,32,115,104,111,114,116,32,116,101,114,109,32,114,101,102,101,114,101,110,99,101,32,97,115,115,105,103,110,109,101,110,116,32,102,111,114,32,115,101,99,111,110,100,32,102,105,101,108,100,32,105,110,32,99,111,109,112,108,101,109,101,110,116,97,114,121,32,102,105,101,108,100,32,112,97,105,114,32,40,102,105,114,115,116,32,102,105,101,108,100,32,105,115,32,108,111,110,103,32,116,101,114,109,41,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,80,79,67,32,37,100,60,37,100,10,0,0,0,0,0,0,80,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,100,97,116,97,32,115,105,122,101,32,37,100,10,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,10,0,0,0,110,111,32,100,97,116,97,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,122,108,105,98,32,112,114,105,109,105,110,103,10,0,0,0,0,0,37,115,32,45,62,32,37,115,37,115,10,0,0,0,0,0,32,108,112,99,32,116,121,112,101,58,32,67,104,111,108,101,115,107,121,32,102,97,99,116,111,114,105,122,97,116,105,111,110,44,32,37,100,32,112,97,115,115,37,115,10,0,0,0,105,110,118,97,108,105,100,32,99,111,101,102,102,32,112,114,101,99,105,115,105,111,110,10,0,0,0,0,0,0,0,0,83,116,111,114,105,110,103,32,97,108,112,104,97,32,112,108,97,110,101,44,32,116,104,105,115,32,119,105,108,108,32,114,101,113,117,105,114,101,32,97,32,114,101,99,101,110,116,32,70,70,86,49,32,100,101,99,111,100,101,114,32,116,111,32,112,108,97,121,98,97,99,107,33,10,0,0,0,0,0,0,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,65,0,0,0,0,0,0,0,100,105,97,108,110,111,114,109,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,108,111,119,100,101,108,97,121,46,98,121,116,101,115,46,100,101,110,10,0,0,0,0,0,68,84,83,45,69,120,83,83,58,32,117,110,107,110,111,119,110,32,109,97,114,107,101,114,32,61,32,48,120,37,48,56,120,10,0,0,0,0,0,0,77,85,76,84,73,95,67,72,65,78,78,69,76,10,0,0,32,76,85,0,0,0,0,0,83,108,105,99,101,32,111,102,102,115,101,116,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,104,100,49,48,56,48,0,0,76,111,115,115,108,101,115,115,32,74,80,69,71,0,0,0,119,105,100,116,104,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,71,67,83,95,66,101,114,110,95,49,56,57,56,95,66,101,114,110,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,104,97,110,110,101,108,32,99,111,100,105,110,103,32,109,111,100,101,32,37,120,33,10,0,0,0,0,0,0,0,0,32,99,104,114,111,109,97,95,109,101,61,37,100,0,0,0,97,99,99,101,112,116,32,97,108,108,32,99,104,97,110,110,101,108,32,99,111,117,110,116,115,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,98,105,116,115,58,32,37,100,10,0,0,0,0,0,0,102,105,108,116,101,114,95,99,111,109,112,108,101,120,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,114,101,111,114,100,101,114,105,110,103,46,10,0,0,0,0,101,120,112,101,114,105,109,101,110,116,97,108,0,0,0,0,108,101,102,116,0,0,0,0,114,118,51,48,0,0,0,0,73,110,100,117,115,116,114,105,97,108,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,99,111,109,112,117,116,101,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,10,0,0,0,0,0,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,32,118,105,100,101,111,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,52,52,52,112,49,48,0,0,102,97,108,115,101,0,0,0,100,101,115,99,114,105,112,116,105,111,110,115,0,0,0,0,98,101,120,116,0,0,0,0,85,110,107,110,111,119,110,32,83,77,86,32,118,101,114,115,105,111,110,32,102,111,117,110,100,10,0,0,0,0,0,0,67,68,67,84,0,0,0,0,86,105,118,111,47,37,100,46,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,10,0,0,0,0,0,0,0,0,33,105,110,112,117,116,45,62,102,105,108,116,101,114,95,102,114,97,109,101,32,124,124,32,40,33,105,110,112,117,116,45,62,115,116,97,114,116,95,102,114,97,109,101,32,38,38,32,33,105,110,112,117,116,45,62,101,110,100,95,102,114,97,109,101,41,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,39,37,115,39,32,105,110,32,98,115,102,115,32,111,112,116,105,111,110,32,39,37,115,39,32,102,111,114,32,115,108,97,118,101,32,111,117,116,112,117,116,32,39,37,115,39,10,0,0,0,0,0,0,0,0,73,69,67,32,54,49,57,51,55,32,101,110,99,97,112,115,117,108,97,116,105,111,110,32,102,108,97,103,115,0,0,0,115,58,37,100,120,37,100,32,114,58,37,102,32,110,58,37,100,10,0,0,0,0,0,0,60,99,32,110,61,34,37,100,34,32,100,61,34,37,108,108,117,34,32,47,62,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,58,0,0,0,0,0,0,0,114,118,49,48,0,0,0,0,99,104,114,111,109,97,32,100,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,114,112,122,97,0,0,0,0,67,111,110,99,97,116,101,110,97,116,101,32,97,117,100,105,111,32,97,110,100,32,118,105,100,101,111,32,115,116,114,101,97,109,115,46,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,114,111,113,118,105,100,101,111,0,0,0,0,0,0,0,0,104,100,55,50,48,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,0,0,0,0,71,67,83,95,87,71,83,95,56,52,0,0,0,0,0,0,32,109,101,95,114,97,110,103,101,61,37,100,0,0,0,0,114,101,105,110,105,116,32,102,105,108,116,101,114,103,114,97,112,104,32,111,110,32,105,110,112,117,116,32,112,97,114,97,109,101,116,101,114,32,99,104,97,110,103,101,115,0,0,0,114,111,113,118,105,100,101,111,0,0,0,0,0,0,0,0,97,108,108,111,119,32,117,110,111,102,102,105,99,105,97,108,32,101,120,116,101,110,115,105,111,110,115,0,0,0,0,0,100,115,105,99,105,110,118,105,100,101,111,0,0,0,0,0,114,111,113,95,100,112,99,109,0,0,0,0,0,0,0,0,114,108,50,0,0,0,0,0,61,0,0,0,0,0,0,0,83,117,99,99,101,115,115,102,117,108,108,121,32,112,97,114,115,101,100,32,97,32,103,114,111,117,112,32,111,102,32,111,112,116,105,111,110,115,46,10,0,0,0,0,0,0,0,0,114,101,97,108,116,101,120,116,0,0,0,0,0,0,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,95,115,105,122,101,0,0,0,0,0,0,0,116,61,37,100,32,37,100,13,10,97,61,116,111,111,108,58,108,105,98,97,118,102,111,114,109,97,116,32,53,53,46,51,51,46,49,48,48,13,10,0,114,101,108,97,116,105,118,101,32,116,105,109,101,32,119,105,116,104,111,117,116,32,112,114,101,118,105,111,117,115,32,97,98,115,111,108,117,116,101,32,116,105,109,101,0,0,0,0,114,97,119,118,105,100,101,111,0,0,0,0,0,0,0,0,85,115,101,32,82,70,67,32,50,49,57,48,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,105,110,115,116,101,97,100,32,111,102,32,82,70,67,32,52,54,50,57,32,102,111,114,32,72,46,50,54,51,0,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,10,0,0,0,0,0,0,73,84,82,75,0,0,0,0,105,110,116,101,110,115,105,116,121,0,0,0,0,0,0,0,98,108,101,110,100,0,0,0,101,97,99,51,0,0,0,0,114,97,119,32,86,67,45,49,0,0,0,0,0,0,0,0,104,100,52,56,48,0,0,0,97,118,105,111,102,108,97,103,115,0,0,0,0,0,0,0,71,67,83,95,87,71,83,95,55,50,66,69,0,0,0,0,32,109,105,120,101,100,95,114,101,102,61,37,100,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,115,116,114,101,97,109,115,0,0,0,0,0,115,49,54,108,101,0,0,0,114,101,105,110,105,116,95,102,105,108,116,101,114,0,0,0,117,110,111,102,102,105,99,105,97,108,0,0,0,0,0,0,83,111,110,121,32,79,112,101,110,77,71,32,97,117,100,105,111,0,0,0,0,0,0,0,84,114,117,101,118,105,115,105,111,110,32,84,97,114,103,97,32,105,109,97,103,101,0,0,115,49,54,108,101,0,0,0,105,110,58,37,100,32,111,117,116,58,37,100,32,116,121,112,101,58,37,100,32,113,58,37,100,32,105,116,101,120,58,37,100,32,112,116,101,120,58,37,100,32,109,118,58,37,100,32,109,105,115,99,58,37,100,32,102,99,111,100,101,58,37,100,32,98,99,111,100,101,58,37,100,32,109,99,45,118,97,114,58,37,108,108,100,32,118,97,114,58,37,108,108,100,32,105,99,111,117,110,116,58,37,100,32,115,107,105,112,99,111,117,110,116,58,37,100,32,104,98,105,116,115,58,37,100,59,10,0,0,0,0,0,0,0,0,37,115,99,111,110,102,105,103,117,114,97,116,105,111,110,58,32,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,10,0,0,0,0,0,0,0,100,105,115,97,98,108,101,32,65,86,80,97,114,115,101,114,115,44,32,116,104,105,115,32,110,101,101,100,115,32,110,111,102,105,108,108,105,110,32,116,111,111,0,0,0,0,0,0,84,111,111,32,108,105,116,116,108,101,32,71,69,79,66,32,100,97,116,97,10,0,0,0,103,99,0,0,0,0,0,0,83,111,110,121,32,79,112,101,110,77,71,32,97,117,100,105,111,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,79,103,103,86,80,56,32,104,101,97,100,101,114,32,112,97,99,107,101,116,0,0,0,0,114,97,108,102,0,0,0,0,79,103,103,83,0,0,0,0,85,115,101,114,68,97,116,97,37,115,45,83,68,45,37,100,0,0,0,0,0,0,0,0,114,101,97,108,95,50,56,56,0,0,0,0,0,0,0,0,80,97,108,101,116,116,101,0,114,101,97,108,95,49,52,52,0,0,0,0,0,0,0,0,111,117,116,45,111,102,45,109,101,109,111,114,121,32,101,114,114,111,114,46,32,83,107,105,112,112,105,110,103,32,99,111,118,101,114,32,97,114,116,32,98,108,111,99,107,46,10,0,115,97,109,112,108,101,95,99,111,100,105,110,103,0,0,0,114,101,97,108,95,49,52,52,0,0,0,0,0,0,0,0,84,111,111,32,111,108,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,84,104,101,111,114,97,32,40,37,120,41,10,0,0,0,0,0,115,111,117,114,99,101,32,109,97,114,107,101,100,32,97,115,32,105,110,116,101,114,108,97,99,101,100,32,98,117,116,32,99,111,100,101,99,32,112,114,111,102,105,108,101,32,105,115,32,112,114,111,103,114,101,115,115,105,118,101,10,0,0,0,115,112,101,101,120,32,112,97,99,107,101,116,32,116,111,111,32,115,109,97,108,108,10,0,114,101,97,100,32,112,97,115,116,32,101,110,100,32,111,102,32,75,76,86,32,64,32,37,35,108,108,120,10,0,0,0,115,107,101,108,101,116,111,110,0,0,0,0,0,0,0,0,118,105,100,101,111,32,99,111,109,112,114,101,115,115,105,111,110,32,37,115,0,0,0,0,114,50,49,48,0,0,0,0,116,105,109,101,32,98,97,115,101,32,110,111,116,32,115,101,116,10,0,0,0,0,0,0,79,112,117,115,0,0,0,0,116,105,116,108,101,0,0,0,101,103,97,0,0,0,0,0,114,50,49,48,0,0,0,0,84,114,121,32,116,111,32,102,105,120,32,112,116,115,32,118,97,108,117,101,115,32,111,102,32,100,118,98,32,116,101,108,101,116,101,120,116,32,115,116,114,101,97,109,115,46,0,0,1,97,117,100,105,111,0,0,71,67,83,95,87,71,83,95,55,50,0,0,0,0,0,0,32,112,115,121,95,114,100,61,37,46,50,102,58,37,46,50,102,0,0,0,0,0,0,0,118,99,100,32,109,117,120,101,114,0,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,110,111,114,109,97,108,0,0,113,116,114,108,101,0,0,0,102,76,97,67,0,0,0,0,116,97,114,103,97,0,0,0,75,87,45,68,73,82,65,67,0,0,0,0,0,0,0,0,98,108,97,99,107,102,114,97,109,101,0,0,0,0,0,0,113,116,114,108,101,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,44,32,110,111,116,32,119,114,105,116,105,110,103,32,88,105,110,103,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,101,109,99,99,32,40,69,109,115,99,114,105,112,116,101,110,32,71,67,67,45,108,105,107,101,32,114,101,112,108,97,99,101,109,101,110,116,41,32,49,46,49,50,46,48,32,40,99,111,109,109,105,116,32,54,57,54,48,100,50,50,57,54,50,57,57,101,57,54,100,52,51,101,54,57,52,56,48,54,102,53,100,51,53,55,57,57,101,102,56,100,51,57,99,41,0,113,112,101,103,0,0,0,0,113,100,114,97,119,0,0,0,50,48,48,54,47,48,52,47,48,49,32,49,49,58,49,49,58,49,49,0,0,0,0,0,51,103,50,0,0,0,0,0,79,103,103,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,113,100,109,50,0,0,0,0,119,101,98,109,32,109,117,120,101,114,0,0,0,0,0,0,79,103,103,0,0,0,0,0,73,110,118,97,108,105,100,32,69,66,77,76,32,110,117,109,98,101,114,32,115,105,122,101,32,116,97,103,32,48,120,37,48,50,120,32,97,116,32,112,111,115,32,37,108,108,117,32,40,48,120,37,108,108,120,41,10,0,0,0,0,0,0,0,113,99,101,108,112,0,0,0,78,117,112,112,101,108,86,105,100,101,111,0,0,0,0,0,112,116,120,0,0,0,0,0,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,32,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,32,37,99,0,0,0,0,0,0,99,103,97,0,0,0,0,0,115,116,97,114,116,95,110,117,109,98,101,114,0,0,0,0,71,67,83,95,67,111,110,97,107,114,121,95,49,57,48,53,0,0,0,0,0,0,0,0,32,112,115,121,61,37,100,0,114,101,97,100,32,115,116,114,101,97,109,32,102,105,108,116,101,114,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,102,114,111,109,32,97,32,102,105,108,101,0,115,116,114,105,99,116,108,121,32,99,111,110,102,111,114,109,32,116,111,32,97,108,108,32,116,104,101,32,116,104,105,110,103,115,32,105,110,32,116,104,101,32,115,112,101,99,32,110,111,32,109,97,116,116,101,114,32,119,104,97,116,32,116,104,101,32,99,111,110,115,101,113,117,101,110,99,101,115,0,0,112,105,120,101,108,95,102,111,114,109,97,116,0,0,0,0,79,110,50,32,86,80,54,32,40,70,108,97,115,104,32,118,101,114,115,105,111,110,41,0,102,102,118,49,45,105,109,103,0,0,0,0,0,0,0,0,78,85,84,0,0,0,0,0,50,48,58,50,52,58,51,50,0,0,0,0,0,0,0,0,84,80,69,51,0,0,0,0,112,114,111,114,101,115,95,107,115,0,0,0,0,0,0,0,115,101,116,32,102,105,114,115,116,32,110,117,109,98,101,114,32,105,110,32,116,104,101,32,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,99,114,121,112,116,111,58,37,115,0,0,0,0,0,0,0,60,47,109,97,110,105,102,101,115,116,62,10,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,82,101,99,101,105,118,101,100,32,115,105,103,110,97,108,32,37,100,58,32,116,101,114,109,105,110,97,116,105,110,103,46,10,0,0,0,0,0,0,0,118,105,100,101,111,32,99,111,100,101,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,116,105,109,101,99,111,100,101,95,97,116,95,109,97,114,107,95,111,117,116,0,0,0,0,112,114,111,114,101,115,95,97,119,0,0,0,0,0,0,0,67,111,110,118,101,114,116,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,118,101,99,116,111,114,115,99,111,112,101,32,118,105,100,101,111,32,111,117,116,112,117,116,46,0,0,0,0,0,0,0,0,70,76,86,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,119,105,100,101,98,97,110,100,32,40,49,54,107,72,122,41,32,83,112,101,101,120,32,97,117,100,105,111,10,0,97,117,100,105,111,99,111,100,101,99,105,100,0,0,0,0,112,114,111,114,101,115,95,108,103,112,108,0,0,0,0,0,101,108,101,109,101,110,116,32,48,120,37,48,50,120,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,0,101,110,97,98,108,101,32,115,97,102,101,32,109,111,100,101,0,0,0,0,0,0,0,0,119,104,117,120,103,97,0,0,86,105,100,101,111,0,0,0,71,67,83,95,68,72,68,78,0,0,0,0,0,0,0,0,112,114,111,114,101,115,0,0,32,115,117,98,109,101,61,37,100,0,0,0,0,0,0,0,102,105,108,116,101,114,95,115,99,114,105,112,116,0,0,0,115,116,114,105,99,116,108,121,32,99,111,110,102,111,114,109,32,116,111,32,97,32,111,108,100,101,114,32,109,111,114,101,32,115,116,114,105,99,116,32,118,101,114,115,105,111,110,32,111,102,32,116,104,101,32,115,112,101,99,32,111,114,32,114,101,102,101,114,101,110,99,101,32,115,111,102,116,119,97,114,101,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,78,85,84,0,0,0,0,0,118,112,54,102,0,0,0,0,114,97,119,32,110,117,108,108,32,118,105,100,101,111,0,0,78,117,108,108,115,111,102,116,32,83,116,114,101,97,109,105,110,103,32,86,105,100,101,111,0,0,0,0,0,0,0,0,99,104,97,110,110,101,108,115,32,61,61,32,97,118,95,103,101,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,95,110,98,95,99,104,97,110,110,101,108,115,40,108,105,110,107,45,62,99,104,97,110,110,101,108,95,108,97,121,111,117,116,41,32,124,124,32,33,97,118,95,103,101,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,95,110,98,95,99,104,97,110,110,101,108,115,40,108,105,110,107,45,62,99,104,97,110,110,101,108,95,108,97,121,111,117,116,41,0,74,117,110,32,32,57,32,50,48,49,52,0,0,0,0,0,104,100,114,108,0,0,0,0,112,103,109,0,0,0,0,0,115,116,114,101,97,109,95,105,110,100,101,120,32,60,32,115,45,62,110,98,95,115,116,114,101,97,109,115,0,0,0,0,112,116,115,32,33,61,32,40,40,105,110,116,54,52,95,116,41,48,120,56,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,85,76,76,41,0,67,97,110,110,111,116,32,97,112,112,101,110,100,32,112,97,108,101,116,116,101,32,116,111,32,112,97,99,107,101,116,10,0,0,0,0,0,0,0,0,98,101,110,99,104,58,32,109,97,120,114,115,115,61,37,105,107,66,10,0,0,0,0,0,112,103,109,0,0,0,0,0,78,73,83,84,32,83,80,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2474144);
/* memory initializer */ allocate([101,99,104,32,72,69,97,100,101,114,32,82,69,115,111,117,114,99,101,115,0,0,0,0,78,67,32,99,97,109,101,114,97,32,102,101,101,100,0,0,77,120,80,69,71,32,99,108,105,112,0,0,0,0,0,0,98,108,97,99,107,100,101,116,101,99,116,0,0,0,0,0,112,110,103,0,0,0,0,0,115,116,97,114,116,112,116,115,0,0,0,0,0,0,0,0,77,88,70,32,40,77,97,116,101,114,105,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,112,110,103,0,0,0,0,0,105,99,104,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,105,110,112,117,116,32,115,116,114,101,97,109,115,46,0,0,0,0,0,0,0,0,119,104,115,120,103,97,0,0,112,105,99,116,111,114,0,0,115,101,116,32,100,101,108,97,121,32,102,111,114,32,115,97,109,112,108,101,115,32,98,101,102,111,114,101,32,115,101,110,100,105,110,103,32,116,104,101,109,32,116,111,32,118,111,108,117,109,101,32,97,100,106,117,115,116,101,114,0,0,0,0,71,67,83,95,66,101,108,103,101,95,49,57,55,50,0,0,32,109,101,61,37,115,0,0,118,101,114,121,0,0,0,0,102,105,108,116,101,114,95,103,114,97,112,104,0,0,0,0,79,110,50,32,86,80,54,0,73,110,118,97,108,105,100,32,102,114,101,113,117,101,110,99,121,32,37,102,32,97,110,100,47,111,114,32,119,105,100,116,104,32,37,102,32,60,61,32,48,10,0,0,0,0,0,0,112,103,115,115,117,98,0,0,100,101,102,97,117,108,116,0,37,115,98,117,105,108,116,32,111,110,32,37,115,32,37,115,32,119,105,116,104,32,37,115,10,0,0,0,0,0,0,0,112,99,120,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,108,101,110,103,116,104,32,99,104,101,99,107,0,0,115,105,110,117,115,111,105,100,97,108,0,0,0,0,0,0,112,99,120,0,0,0,0,0,84,114,97,110,115,105,116,105,111,110,32,116,105,109,101,44,32,105,110,32,115,101,99,111,110,100,115,44,32,102,111,114,32,118,111,108,117,109,101,32,114,101,110,111,114,109,97,108,105,122,97,116,105,111,110,32,119,104,101,110,32,97,110,32,105,110,112,117,116,32,115,116,114,101,97,109,32,101,110,100,115,46,0,0,0,0,0,0,32,45,62,32,111,117,116,58,0,0,0,0,0,0,0,0,105,110,100,101,120,32,61,61,32,115,105,122,101,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,115,101,116,32,108,105,115,116,32,111,102,32,115,105,103,110,97,108,32,100,101,99,97,121,115,0,0,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,111,110,121,120,99,95,105,110,116,46,104,0,0,0,0,115,0,0,0,0,0,0,0,98,115,108,32,62,61,32,48,0,0,0,0,0,0,0,0,121,32,43,32,104,32,60,61,32,116,101,115,116,45,62,104,0,0,0,0,0,0,0,0,97,109,112,95,108,117,109,97,0,0,0,0,0,0,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,115,107,105,112,44,32,122,101,114,111,95,99,111,117,110,116,115,46,115,107,105,112,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,115,107,105,112,41,41,0,0,0,0,0,77,88,70,32,40,77,97,116,101,114,105,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,101,110,100,95,115,99,97,108,101,0,0,0,0,0,0,0,114,97,116,101,0,0,0,0,77,111,116,105,111,110,32,80,105,120,101,108,115,32,77,86,73,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,58,99,104,97,110,110,101,108,115,61,37,100,0,0,0,0,119,47,50,0,0,0,0,0,119,113,117,120,103,97,0,0,99,104,114,111,109,97,95,97,109,111,117,110,116,0,0,0,71,67,83,95,77,71,73,0,32,97,110,97,108,121,115,101,61,37,35,120,58,37,35,120,0,0,0,0,0,0,0,0,108,97,110,100,115,99,97,112,101,0,0,0,0,0,0,0,104,111,119,32,115,116,114,105,99,116,108,121,32,116,111,32,102,111,108,108,111,119,32,116,104,101,32,115,116,97,110,100,97,114,100,115,0,0,0,0,115,101,116,32,115,116,114,101,97,109,32,102,105,108,116,101,114,103,114,97,112,104,0,0,102,108,97,103,115,0,0,0,84,111,116,97,108,32,104,101,105,103,104,116,32,37,117,120,37,117,32,105,115,32,116,111,111,32,109,117,99,104,46,10,0,0,0,0,0,0,0,0,118,112,54,0,0,0,0,0,84,104,101,32,105,110,112,117,116,32,110,101,101,100,115,32,97,32,99,111,110,115,116,97,110,116,32,102,114,97,109,101,32,114,97,116,101,59,32,99,117,114,114,101,110,116,32,114,97,116,101,32,111,102,32,37,100,47,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,32,67,111,112,121,114,105,103,104,116,32,40,99,41,32,37,100,45,37,100,32,116,104,101,32,70,70,109,112,101,103,32,100,101,118,101,108,111,112,101,114,115,0,0,0,0,0,0,115,98,115,50,114,0,0,0,119,32,42,32,104,32,60,61,32,115,112,112,45,62,110,111,110,95,98,95,113,112,95,97,108,108,111,99,95,115,105,122,101,0,0,0,0,0,0,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,118,105,101,0,0,99,104,114,111,109,97,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,0,98,105,108,105,110,101,97,114,0,0,0,0,0,0,0,0,101,110,103,0,0,0,0,0,102,111,114,99,101,95,107,101,121,95,102,114,97,109,101,115,0,0,0,0,0,0,0,0,99,104,114,111,109,97,95,115,116,114,101,110,103,116,104,0,115,101,116,32,97,110,103,108,101,32,40,105,110,32,114,97,100,105,97,110,115,41,0,0,71,101,110,101,114,97,116,101,32,115,105,110,101,32,119,97,118,101,32,97,117,100,105,111,32,115,105,103,110,97,108,46,0,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,97,0,0,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,112,114,101,100,95,99,111,109,109,111,110,46,104,0,0,85,110,97,98,108,101,32,116,111,32,102,105,110,100,32,97,32,115,117,105,116,97,98,108,101,32,111,117,116,112,117,116,32,102,111,114,109,97,116,32,102,111,114,32,39,37,115,39,10,0,0,0,0,0,0,0,115,101,116,32,98,111,116,116,111,109,32,114,105,103,104,116,32,120,32,99,111,111,114,100,105,110,97,116,101,0,0,0,100,101,102,97,117,108,116,0,77,84,86,0,0,0,0,0,116,0,0,0,0,0,0,0,77,83,78,32,84,67,80,32,87,101,98,99,97,109,32,115,116,114,101,97,109,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,109,98,103,114,97,112,104,95,115,116,97,116,115,91,105,93,46,109,98,95,115,116,97,116,115,0,0,0,0,0,0,0,99,48,95,115,101,101,100,0,77,80,108,97,121,101,114,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,0,98,98,111,120,0,0,0,0,32,40,115,108,105,99,101,115,41,0,0,0,0,0,0,0,119,113,115,120,103,97,0,0,109,101,109,99,95,111,110,108,121,0,0,0,0,0,0,0,77,80,76,50,32,115,117,98,116,105,116,108,101,115,0,0,105,32,60,32,78,85,77,95,89,86,49,50,95,66,85,70,70,69,82,83,0,0,0,0,71,67,83,95,90,97,110,100,101,114,105,106,0,0,0,0,32,100,101,98,108,111,99,107,61,37,100,58,37,100,58,37,100,0,0,0,0,0,0,0,115,116,114,105,99,116,0,0,102,105,108,116,101,114,0,0,109,97,105,110,0,0,0,0,79,110,50,32,86,80,53,0,77,73,77,69,32,109,117,108,116,105,112,97,114,116,32,74,80,69,71,0,0,0,0,0,99,51,0,0,0,0,0,0,114,97,119,32,77,80,69,71,32,118,105,100,101,111,0,0,112,99,109,95,97,108,97,119,0,0,0,0,0,0,0,0,108,115,0,0,0,0,0,0,114,99,95,50,112,97,115,115,95,118,98,114,95,98,105,97,115,95,112,99,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,93,0,0,0,0,0,0,37,115,32,118,101,114,115,105,111,110,32,50,46,50,46,49,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,98,114,105,103,104,116,110,101,115,115,32,101,120,112,114,101,115,115,105,111,110,0,0,0,114,99,95,100,114,111,112,102,114,97,109,101,95,116,104,114,101,115,104,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,93,0,0,0,0,0,0,0,0,112,99,109,95,100,118,100,0,115,116,101,112,0,0,0,0,112,99,109,95,98,108,117,114,97,121,0,0,0,0,0,0,87,0,0,0,0,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,40,77,86,32,111,117,116,32,111,102,32,116,104,114,101,97,100,32,114,97,110,103,101,41,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,103,108,111,98,97,108,32,111,112,116,105,111,110,115,58,32,0,0,37,115,45,0,0,0,0,0,99,104,97,112,116,101,114,115,0,0,0,0,0,0,0,0,108,101,102,116,0,0,0,0,110,101,97,114,0,0,0,0,37,46,54,103,0,0,0,0,99,108,71,101,116,75,101,114,110,101,108,87,111,114,107,71,114,111,117,112,73,110,102,111,0,0,0,0,0,0,0,0,97,108,112,104,97,0,0,0,117,121,121,118,121,121,52,49,49,0,0,0,0,0,0,0,65,113,117,97,109,97,114,105,110,101,0,0,0,0,0,0,98,0,0,0,0,0,0,0,112,97,109,0,0,0,0,0,37,115,0,0,0,0,0,0,115,113,117,105,115,104,0,0,69,88,84,69,82,78,65,76,0,0,0,0,0,0,0,0,77,80,69,71,45,84,83,32,40,77,80,69,71,45,50,32,84,114,97,110,115,112,111,114,116,32,83,116,114,101,97,109,41,0,0,0,0,0,0,0,102,114,111,110,116,32,108,101,102,116,45,111,102,45,99,101,110,116,101,114,0,0,0,0,99,0,0,0,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,117,116,105,108,115,46,99,0,0,0,0,0,0,115,112,108,105,110,101,0,0,85,115,105,110,103,32,100,111,117,98,108,101,32,112,114,101,99,105,115,105,111,110,32,109,111,100,101,10,0,0,0,0,112,112,58,32,108,117,109,77,111,100,101,61,37,88,44,32,99,104,114,111,109,77,111,100,101,61,37,88,10,0,0,0,98,108,97,110,107,0,0,0,112,97,102,95,118,105,100,101,111,0,0,0,0,0,0,0,92,97,110,37,49,91,92,125,93,37,110,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,98,108,111,99,107,120,0,0,97,100,112,99,109,95,101,97,95,120,97,115,0,0,0,0,114,101,115,111,108,117,116,105,111,110,32,115,112,101,99,105,102,105,101,100,32,105,110,32,115,116,97,116,115,32,102,105,108,101,32,110,111,116,32,118,97,108,105,100,10,0,0,0,78,111,116,32,73,110,100,105,99,97,116,101,100,32,40,100,101,102,97,117,108,116,41,0,78,111,116,32,73,110,100,105,99,97,116,101,100,32,40,100,101,102,97,117,108,116,41,0,102,114,97,109,101,32,115,121,110,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,116,111,111,32,109,97,110,121,32,83,66,82,32,101,110,118,101,108,111,112,101,115,32,105,110,32,86,65,82,86,65,82,32,116,121,112,101,32,83,66,82,32,102,114,97,109,101,58,32,37,100,10,0,109,115,95,102,111,114,99,101,0,0,0,0,0,0,0,0,119,111,120,103,97,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,100,101,99,111,100,101,32,112,32,102,114,97,109,101,32,102,97,105,108,101,100,10,0,0,80,105,120,109,97,112,32,102,111,114,109,97,116,32,37,100,0,0,0,0,0,0,0,0,48,46,50,53,47,48,46,49,53,54,32,48,46,53,48,49,47,48,46,53,48,49,32,48,46,54,56,54,47,48,46,55,52,53,0,0,0,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,110,117,109,32,115,117,98,102,114,97,109,101,115,32,62,32,51,49,10,0,0,0,0,0,0,0,66,105,116,45,100,101,112,116,104,32,104,105,103,104,101,114,32,116,104,97,110,32,49,54,0,0,0,0,0,0,0,0,98,108,111,99,107,95,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,10,0,71,67,83,95,89,111,102,102,0,0,0,0,0,0,0,0,108,97,118,102,105,46,99,114,111,112,100,101,116,101,99,116,46,120,0,0,0,0,0,0,92,123,0,0,0,0,0,0,32,114,101,102,61,37,100,0,105,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,105,110,100,101,120,32,37,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,105,110,102,111,32,115,105,122,101,32,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,119,32,62,32,48,32,38,38,32,104,32,62,32,48,0,0,116,114,117,110,99,97,116,101,100,32,102,114,97,109,101,115,0,0,0,0,0,0,0,0,115,101,116,32,112,114,111,102,105,108,101,0,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,100,99,116,95,99,111,101,102,102,115,10,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,102,108,111,111,114,115,41,46,32,10,0,100,101,102,97,117,108,116,0,111,102,102,115,101,116,32,62,32,119,105,100,116,104,32,40,37,100,32,62,32,37,100,41,10,0,0,0,0,0,0,0,70,105,101,108,100,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,10,0,0,0,100,117,109,112,95,121,117,118,58,32,99,97,110,39,116,32,119,114,105,116,101,32,116,111,32,37,115,10,0,0,0,0,77,66,32,68,105,114,101,99,116,32,84,121,112,101,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,0,118,112,53,0,0,0,0,0,37,115,32,45,62,32,37,115,10,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,32,49,46,10,0,0,0,0,79,114,105,103,105,110,97,108,32,102,111,114,109,97,116,32,37,88,10,0,0,0,0,0,68,86,66,32,115,117,98,116,105,116,108,101,115,32,119,105,116,104,32,109,117,108,116,105,112,108,101,32,108,97,110,103,117,97,103,101,115,0,0,0,87,97,114,110,105,110,103,58,32,110,111,116,32,99,111,109,112,105,108,101,100,32,119,105,116,104,32,116,104,114,101,97,100,32,115,117,112,112,111,114,116,44,32,117,115,105,110,103,32,116,104,114,101,97,100,32,101,109,117,108,97,116,105,111,110,10,0,0,0,0,0,0,98,114,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,108,105,116,101,114,97,108,115,10,0,0,0,0,0,0,100,101,102,108,97,116,101,0,98,104,0,0,0,0,0,0,97,114,0,0,0,0,0,0,78,117,108,108,32,97,117,100,105,111,32,115,111,117,114,99,101,44,32,114,101,116,117,114,110,32,101,109,112,116,121,32,97,117,100,105,111,32,102,114,97,109,101,115,46,0,0,0,112,111,115,116,112,114,111,99,0,0,0,0,0,0,0,0,80,67,83,67,105,116,97,116,105,111,110,71,101,111,75,101,121,0,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,116,101,109,112,111,114,97,114,121,32,98,117,102,102,101,114,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,115,108,105,99,101,32,104,101,97,100,101,114,32,40,37,48,50,88,41,10,0,0,0,0,0,0,0,0,13,10,0,0,0,0,0,0,123,92,102,115,37,117,125,0,110,111,95,98,105,116,115,116,114,101,97,109,0,0,0,0,83,107,105,112,112,105,110,103,32,77,77,65,80,32,116,114,101,101,10,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,119,97,118,101,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,115,117,98,99,111,100,101,99,32,37,100,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,98,108,101,110,100,32,109,111,100,101,0,0,0,0,0,97,116,116,101,109,112,116,105,110,103,32,116,111,32,99,104,97,110,103,101,32,114,101,115,111,108,117,116,105,111,110,32,116,111,32,37,100,120,37,100,10,0,0,0,0,0,0,0,97,118,103,80,80,84,101,120,0,0,0,0,0,0,0,0,33,115,117,112,101,114,98,108,111,99,107,116,121,112,101,95,50,95,51,0,0,0,0,0,109,97,99,114,111,98,108,111,99,107,115,32,112,101,114,32,115,108,105,99,101,0,0,0,73,110,118,97,108,105,100,32,97,108,112,104,97,32,109,111,100,101,32,37,100,10,0,0,37,100,32,117,110,100,101,99,111,109,112,114,101,115,115,101,100,32,98,121,116,101,115,32,108,101,102,116,32,105,110,32,98,117,102,102,101,114,10,0,97,0,0,0,0,0,0,0,115,121,110,99,45,108,111,111,107,97,104,101,97,100,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,111,114,99,101,100,32,107,101,121,32,102,114,97,109,101,115,32,97,114,114,97,121,46,10,0,0,0,0,119,105,100,116,104,0,0,0,101,110,100,0,0,0,0,0,85,115,101,100,32,99,111,108,111,117,114,115,32,37,100,10,0,0,0,0,0,0,0,0,111,110,108,121,32,89,85,86,52,50,48,32,97,110,100,32,89,85,86,52,50,50,32,97,114,101,32,115,117,112,112,111,114,116,101,100,10,0,0,0,115,101,116,32,108,111,111,112,32,99,111,117,110,116,0,0,110,111,32,102,114,97,109,101,32,98,117,102,102,101,114,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,97,108,108,32,99,104,97,110,110,101,108,115,10,0,0,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,97,108,108,32,99,104,97,110,110,101,108,115,10,0,0,85,115,101,32,114,97,116,101,32,100,105,115,116,111,114,116,105,111,110,32,111,112,116,105,109,105,122,97,116,105,111,110,32,102,111,114,32,113,112,32,115,101,108,101,99,116,105,111,110,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,85,115,101,32,110,111,110,108,105,110,101,97,114,32,113,117,97,110,116,105,122,101,114,46,0,0,0,0,0,0,0,0,78,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,46,10,0,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,97,117,100,105,111,32,115,97,109,112,108,101,115,32,105,110,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,37,115,58,37,115,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,37,115,0,0,0,0,0,0,77,80,69,71,45,49,32,83,121,115,116,101,109,115,32,47,32,77,80,69,71,32,112,114,111,103,114,97,109,32,115,116,114,101,97,109,0,0,0,0,87,101,105,103,104,116,101,100,32,112,114,101,100,105,99,116,105,111,110,32,102,111,114,32,80,45,102,114,97,109,101,115,0,0,0,0,0,0,0,0,37,115,58,0,0,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,52,58,50,58,50,46,10,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,83,73,90,10,0,0,0,0,13,10,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,45,32,109,105,110,95,115,105,122,101,32,45,32,114,101,102,95,115,105,122,101,32,62,61,32,114,101,102,95,111,102,102,115,0,0,0,0,0,0,113,117,97,110,116,95,109,97,116,32,37,100,32,116,111,111,32,108,97,114,103,101,33,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,113,117,97,110,116,32,109,97,116,114,105,120,32,102,111,114,32,52,120,52,32,98,108,111,99,107,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,0,77,111,100,101,32,37,100,58,32,97,116,116,101,109,112,116,32,116,111,32,114,101,97,100,32,112,97,115,116,32,101,110,100,32,111,102,32,98,117,102,102,101,114,10,0,0,0,0,117,115,105,110,103,32,104,117,102,102,121,117,118,32,50,46,50,46,48,32,111,114,32,110,101,119,101,114,32,105,110,116,101,114,108,97,99,105,110,103,32,102,108,97,103,10,0,0,115,116,97,114,116,95,116,105,109,101,58,37,102,32,101,110,100,95,116,105,109,101,58,37,102,32,105,110,100,101,120,58,37,100,10,0,0,0,0,0,108,111,103,50,95,109,97,120,95,112,105,99,95,111,114,100,101,114,95,99,110,116,95,108,115,98,95,109,105,110,117,115,52,32,111,117,116,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,32,105,110,105,116,105,97,108,32,116,105,108,101,46,10,0,0,0,0,0,0,0,115,101,105,95,114,101,99,111,118,101,114,121,95,102,114,97,109,101,95,99,110,116,58,32,37,100,10,0,0,0,0,0,33,104,45,62,99,117,114,95,112,105,99,95,112,116,114,45,62,108,111,110,103,95,114,101,102,0,0,0,0,0,0,0,56,66,56,0,0,0,0,0,104,97,114,100,119,97,114,101,32,97,99,99,101,108,101,114,97,116,111,114,32,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,112,105,99,116,117,114,101,10,0,0,73,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,117,114,115,111,114,32,112,111,115,32,115,105,122,101,32,37,100,10,0,0,0,0,0,68,111,32,97,98,115,111,108,117,116,101,108,121,32,110,111,116,104,105,110,103,32,119,105,116,104,32,116,104,101,32,105,110,112,117,116,32,97,117,100,105,111,46,0,0,0,0,0,73,110,32,99,104,117,110,107,32,70,76,73,95,67,79,80,89,32,58,32,115,111,117,114,99,101,32,100,97,116,97,32,40,37,100,32,98,121,116,101,115,41,32,104,97,115,32,105,110,99,111,114,114,101,99,116,32,115,105,122,101,44,32,115,107,105,112,112,105,110,103,32,99,104,117,110,107,10,0,0,122,108,105,98,112,114,105,109,101,95,99,117,114,114,0,0,100,101,102,97,117,108,116,0,32,108,112,99,32,116,121,112,101,58,32,76,101,118,105,110,115,111,110,45,68,117,114,98,105,110,32,114,101,99,117,114,115,105,111,110,32,119,105,116,104,32,87,101,108,99,104,32,119,105,110,100,111,119,10,0,105,110,118,97,108,105,100,32,99,111,100,105,110,103,32,116,121,112,101,10,0,0,0,0,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,99,111,108,111,114,115,112,97,99,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,87,0,0,0,0,0,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,67,111,112,121,114,105,103,104,116,32,66,105,116,0,0,0,117,110,107,110,111,119,110,32,99,111,100,101,98,108,111,99,107,32,109,111,100,101,10,0,77,117,108,116,105,112,108,101,32,68,84,83,45,72,68,32,97,117,100,105,111,32,97,115,115,101,116,115,0,0,0,0,74,79,73,78,84,95,83,84,69,82,69,79,10,0,0,0,119,117,120,103,97,0,0,0,108,106,112,101,103,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,71,67,83,95,89,97,99,97,114,101,0,0,0,0,0,0,74,111,105,110,116,32,115,116,101,114,101,111,32,100,101,116,101,99,116,101,100,46,10,0,99,97,98,97,99,61,37,100,0,0,0,0,0,0,0,0,97,108,108,95,99,104,97,110,110,101,108,95,99,111,117,110,116,115,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,65,100,97,112,116,105,118,101,32,82,76,83,45,76,77,83,32,112,114,101,100,105,99,116,105,111,110,0,0,0,0,0,77,80,69,71,45,80,83,32,40,77,80,69,71,45,50,32,80,114,111,103,114,97,109,32,83,116,114,101,97,109,41,0,116,114,117,110,99,0,0,0,112,114,111,102,105,108,101,0,117,115,101,115,102,111,110,116,0,0,0,0,0,0,0,0,98,108,111,99,107,95,114,108,0,0,0,0,0,0,0,0,84,101,99,104,110,111,0,0,87,77,47,79,114,105,103,105,110,97,108,70,105,108,101,110,97,109,101,0,0,0,0,0,86,77,119,97,114,101,32,83,99,114,101,101,110,32,67,111,100,101,99,32,47,32,86,77,119,97,114,101,32,86,105,100,101,111,0,0,0,0,0,0,97,117,116,111,45,105,110,115,101,114,116,101,100,32,114,101,115,97,109,112,108,101,114,32,37,100,0,0,0,0,0,0,52,50,50,112,49,48,0,0,116,114,117,101,0,0,0,0,87,101,98,86,84,84,32,99,97,112,116,105,111,110,115,32,107,105,110,100,0,0,0,0,100,97,116,97,0,0,0,0,102,111,117,110,100,32,110,111,32,39,102,109,116,32,39,32,116,97,103,32,98,101,102,111,114,101,32,116,104,101,32,39,83,77,86,48,39,32,116,97,103,10,0,0,0,0,0,0,98,97,110,100,0,0,0,0,86,101,114,115,105,111,110,0,77,117,115,101,112,97,99,107,32,83,86,56,0,0,0,0,68,114,111,112,112,101,100,32,99,111,114,114,117,112,116,101,100,32,112,97,99,107,101,116,32,40,115,116,114,101,97,109,32,61,32,37,100,41,10,0,83,112,101,99,105,102,105,101,114,32,115,101,112,97,114,97,116,111,114,32,105,110,32,39,37,115,39,32,105,115,32,39,37,99,39,44,32,98,117,116,32,111,110,108,121,32,99,104,97,114,97,99,116,101,114,115,32,39,37,115,39,32,97,114,101,32,97,108,108,111,119,101,100,10,0,0,0,0,0,0,40,102,105,108,116,101,114,45,62,102,108,97,103,115,32,38,32,40,40,49,32,60,60,32,49,54,41,32,124,32,40,49,32,60,60,32,49,55,41,41,41,32,33,61,32,40,40,49,32,60,60,32,49,54,41,32,124,32,40,49,32,60,60,32,49,55,41,41,0,0,0,0,115,101,116,32,116,104,101,32,115,116,97,114,116,32,116,105,109,101,32,40,111,102,102,115,101,116,41,32,111,102,32,116,104,101,32,115,117,98,116,105,116,108,101,115,44,32,105,110,32,109,115,0,0,0,0,0,115,112,100,105,102,95,102,108,97,103,115,0,0,0,0,0,60,99,32,116,61,34,37,108,108,117,34,32,100,61,34,37,108,108,117,34,32,47,62,10,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,115,119,114,101,115,97,109,112,108,101,0,0,0,0,0,0,77,117,115,101,112,97,99,107,0,0,0,0,0,0,0,0,37,115,32,104,119,97,99,99,101,108,32,114,101,113,117,101,115,116,101,100,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,44,32,98,117,116,32,99,97,110,110,111,116,32,98,101,32,105,110,105,116,105,97,108,105,122,101,100,46,10,0,0,0,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,77,80,50,47,51,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,47,51,41,0,0,0,0,114,116,112,111,0,0,0,0,119,115,120,103,97,0,0,0,71,67,83,95,83,116,111,99,107,104,111,108,109,95,49,57,51,56,0,0,0,0,0,0,111,112,101,110,99,108,61,37,100,32,0,0,0,0,0,0,119,111,114,107,32,97,114,111,117,110,100,32,118,97,114,105,111,117,115,32,98,117,103,115,32,105,110,32,77,105,99,114,111,115,111,102,116,39,115,32,98,114,111,107,101,110,32,100,101,99,111,100,101,114,115,0,113,115,99,97,108,101,0,0,118,109,110,99,0,0,0,0,115,119,115,99,97,108,101,0,65,112,112,108,121,105,110,103,32,111,112,116,105,111,110,32,37,115,32,40,37,115,41,32,119,105,116,104,32,97,114,103,117,109,101,110,116,32,37,115,46,10,0,0,0,0,0,0,115,101,116,100,97,114,0,0,101,110,97,98,108,101,32,108,105,118,101,45,102,114,105,101,110,100,108,121,32,108,105,115,116,32,103,101,110,101,114,97,116,105,111,110,32,40,117,115,101,102,117,108,32,102,111,114,32,72,76,83,41,0,0,0,118,61,37,100,13,10,111,61,45,32,37,100,32,37,100,32,73,78,32,37,115,32,37,115,13,10,115,61,37,115,13,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,111,112,101,110,105,110,103,32,100,101,99,111,100,101,114,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,58,32,37,115,0,0,0,0,0,0,0,0,69,114,114,111,114,32,108,105,110,101,32,37,100,58,32,37,115,32,110,101,97,114,32,37,115,37,46,42,115,37,115,46,10,0,0,0,0,0,0,0,114,102,99,50,49,57,48,0,70,97,105,108,101,100,32,116,111,32,102,117,108,108,121,32,114,101,97,100,32,98,108,111,99,107,10,0,0,0,0,0,116,114,97,99,107,0,0,0,115,101,112,97,114,97,116,101,32,99,111,108,111,114,32,102,111,114,32,101,97,99,104,32,99,104,97,110,110,101,108,0,97,117,100,105,111,47,120,45,100,99,97,0,0,0,0,0,118,99,49,0,0,0,0,0,119,120,103,97,0,0,0,0,71,67,83,95,78,111,114,100,95,83,97,104,97,114,97,95,49,57,53,57,0,0,0,0,98,105,116,100,101,112,116,104,61,37,100,32,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,97,0,0,0,0,0,0,0,109,115,0,0,0,0,0,0,117,115,101,32,102,105,120,101,100,32,113,117,97,108,105,116,121,32,115,99,97,108,101,32,40,86,66,82,41,0,0,0,74,80,69,71,32,50,48,48,48,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,97,118,102,105,108,116,101,114,0,0,0,0,0,0,0,0,110,111,112,97,114,115,101,0,73,110,118,97,108,105,100,32,101,110,99,114,121,112,116,105,111,110,32,104,101,97,100,101,114,10,0,0,0,0,0,0,115,101,116,32,114,101,100,32,99,111,110,116,114,97,115,116,0,0,0,0,0,0,0,0,117,110,100,0,0,0,0,0,83,112,101,101,120,32,109,117,120,101,114,0,0,0,0,0,114,101,102,99,111,117,110,116,101,100,95,102,114,97,109,101,115,0,0,0,0,0,0,0,72,101,97,100,101,114,115,32,109,105,115,109,97,116,99,104,32,102,111,114,32,115,116,114,101,97,109,32,37,100,58,32,101,120,112,101,99,116,101,100,32,37,100,32,114,101,99,101,105,118,101,100,32,37,100,46,10,0,0,0,0,0,0,0,67,111,100,101,99,83,112,101,99,105,102,105,99,83,105,100,101,37,108,108,100,0,0,0,85,110,107,110,111,119,110,32,115,116,114,105,110,103,32,37,115,32,47,32,37,115,10,0,115,97,109,112,108,101,32,98,121,116,101,32,102,111,114,109,97,116,32,37,115,0,0,0,99,97,110,110,111,116,32,102,105,108,108,32,100,45,49,48,32,118,105,100,101,111,32,112,97,99,107,101,116,10,0,0,102,111,117,110,100,32,101,115,115,101,110,99,101,32,112,114,105,111,114,32,116,111,32,102,105,114,115,116,32,80,97,114,116,105,116,105,111,110,80,97,99,107,10,0,0,0,0,0,77,86,67,50,0,0,0,0,115,97,109,112,108,101,32,114,97,116,101,32,110,111,116,32,115,101,116,10,0,0,0,0,120,50,54,52,95,50,112,97,115,115,46,108,111,103,0,0,115,101,114,118,105,99,101,95,110,97,109,101,0,0,0,0,119,118,103,97,0,0,0,0,102,105,120,95,116,101,108,101,116,101,120,116,95,112,116,115,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,67,97,115,112,105,97,110,95,83,101,97,0,0,0,0,0,0,97,108,112,104,97,109,101,114,103,101,0,0,0,0,0,0,71,67,83,95,66,101,114,110,95,49,57,51,56,0,0,0,116,105,109,101,98,97,115,101,61,37,117,47,37,117,32,0,118,111,98,32,109,117,120,101,114,0,0,0,0,0,0,0,100,99,95,99,108,105,112,0,113,0,0,0,0,0,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,105,110,100,101,120,32,108,105,110,101,32,39,37,115,39,44,32,97,115,115,117,109,105,110,103,32,39,105,100,58,32,117,110,100,44,32,105,110,100,101,120,58,32,48,39,10,0,0,106,112,101,103,50,48,48,48,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,66,97,108,116,105,99,95,83,101,97,0,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,86,101,114,116,67,83,95,89,101,108,108,111,119,95,83,101,97,95,49,57,53,54,0,0,97,118,100,101,118,105,99,101,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,78,111,114,116,104,95,65,109,101,114,105,99,97,110,95,86,101,114,116,105,99,97,108,95,68,97,116,117,109,95,49,57,56,56,0,0,0,0,0,0,0,86,101,114,116,67,83,95,78,111,114,116,104,95,65,109,101,114,105,99,97,110,95,86,101,114,116,105,99,97,108,95,68,97,116,117,109,95,49,57,50,57,0,0,0,0,0,0,0,116,114,107,110,0,0,0,0,68,101,99,111,100,101,114,32,40,99,111,100,101,99,32,37,115,41,32,110,111,116,32,102,111,117,110,100,32,102,111,114,32,105,110,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,0,0,0,0,86,101,114,116,67,83,95,78,101,119,108,121,110,0,0,0,105,103,110,111,114,101,95,101,100,105,116,108,105,115,116,0,85,110,115,117,112,112,111,114,116,101,100,32,83,77,65,70,32,99,104,117,110,107,32,37,48,56,120,10,0,0,0,0,86,101,114,116,67,83,95,79,83,85,57,49,65,95,101,108,108,105,112,115,111,105,100,0,102,97,116,97,108,32,101,114,114,111,114,44,32,105,110,112,117,116,32,105,115,32,110,111,116,32,97,32,115,105,110,103,108,101,32,112,97,99,107,101,116,44,32,105,109,112,108,101,109,101,110,116,32,97,32,65,86,80,97,114,115,101,114,32,102,111,114,32,105,116,10,0,104,97,115,104,32,101,110,99,111,100,101,114,32,99,108,97,115,115,0,0,0,0,0,0,86,101,114,116,67,83,95,79,83,85,56,54,70,95,101,108,108,105,112,115,111,105,100,0,83,116,111,114,101,32,97,116,32,109,111,115,116,32,116,104,101,32,112,114,111,118,105,100,101,100,32,110,117,109,98,101,114,32,111,102,32,109,105,108,108,105,115,101,99,111,110,100,115,32,105,110,32,97,32,99,108,117,115,116,101,114,46,0,82,101,97,100,32,101,114,114,111,114,32,97,116,32,112,111,115,46,32,37,108,108,117,32,40,48,120,37,108,108,120,41,10,0,0,0,0,0,0,0,86,101,114,116,67,83,95,71,69,77,95,49,48,67,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,84,73,77,69,82,69,83,0,86,101,114,116,67,83,95,87,71,83,95,56,52,95,101,108,108,105,112,115,111,105,100,0,104,115,120,103,97,0,0,0,117,112,100,97,116,101,0,0,86,101,114,116,67,83,95,87,97,114,95,79,102,102,105,99,101,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,71,67,83,95,86,111,105,114,111,108,95,85,110,105,102,105,101,0,0,0,0,0,0,0,102,112,115,61,37,117,47,37,117,32,0,0,0,0,0,0,104,112,101,108,95,99,104,114,111,109,97,0,0,0,0,0,115,101,108,101,99,116,32,115,101,113,117,101,110,99,101,32,112,97,116,116,101,114,110,32,116,121,112,101,0,0,0,0,102,111,117,114,99,99,47,116,97,103,0,0,0,0,0,0,67,104,105,110,101,115,101,32,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,40,65,86,83,49,45,80,50,44,32,74,105,90,104,117,110,32,112,114,111,102,105,108,101,41,0,0,0,0,109,112,103,52,45,105,109,103,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,83,116,114,117,118,101,95,49,56,54,48,95,101,108,108,105,112,115,111,105,100,0,0,0,0,86,101,114,116,67,83,95,80,108,101,115,115,105,115,95,49,56,49,55,95,101,108,108,105,112,115,111,105,100,0,0,0,97,118,102,111,114,109,97,116,0,0,0,0,0,0,0,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,86,101,114,116,67,83,95,78,87,76,95,49,48,68,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,115,116,97,114,116,95,110,117,109,98,101,114,0,0,0,0,99,114,121,112,116,111,43,37,115,0,0,0,0,0,0,0,9,60,47,109,101,100,105,97,62,10,0,0,0,0,0,0,86,101,114,116,67,83,95,78,87,76,95,57,68,95,101,108,108,105,112,115,111,105,100,0,100,105,115,107,0,0,0,0,83,68,80,58,10,37,115,10,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,118,105,100,101,111,32,114,101,115,111,108,117,116,105,111,110,44,32,103,120,102,32,109,117,120,101,114,32,111,110,108,121,32,97,99,99,101,112,116,115,32,80,65,76,32,111,114,32,78,84,83,67,32,114,101,115,111,108,117,116,105,111,110,115,32,99,117,114,114,101,110,116,108,121,10,0,116,105,109,101,99,111,100,101,95,97,116,95,109,97,114,107,95,105,110,0,0,0,0,0,86,101,114,116,67,83,95,75,114,97,115,115,111,119,115,107,121,95,49,57,52,48,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,86,101,114,116,67,83,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,49,57,54,55,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,118,105,100,101,111,99,111,100,101,99,105,100,0,0,0,0,110,117,118,0,0,0,0,0,86,101,114,116,67,83,95,73,110,116,101,114,110,97,116,105,111,110,97,108,95,49,57,50,52,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,105,110,118,97,108,105,100,32,115,105,122,101,32,37,108,108,100,32,105,110,32,115,116,115,100,10,0,0,0,0,0,0,110,117,109,95,115,97,109,112,108,101,115,32,40,101,108,101,109,101,110,116,32,48,120,56,53,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,0,0,0,0,0,110,101,108,108,121,109,111,115,101,114,0,0,0,0,0,0,86,101,114,116,67,83,95,73,78,83,95,101,108,108,105,112,115,111,105,100,0,0,0,0,110,101,108,108,121,109,111,115,101,114,0,0,0,0,0,0,86,101,114,116,67,83,95,72,101,108,109,101,114,116,95,49,57,48,54,95,101,108,108,105,112,115,111,105,100,0,0,0,115,97,102,101,0,0,0,0,113,115,120,103,97,0,0,0,89,97,109,97,104,97,32,83,77,65,70,0,0,0,0,0,65,117,100,105,111,0,0,0,86,101,114,116,67,83,95,71,82,83,95,49,57,56,48,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,71,67,83,95,86,111,105,114,111,108,95,49,56,55,53,0,37,100,120,37,100,32,0,0,101,100,103,101,32,112,97,100,100,105,110,103,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,112,101,114,32,70,79,85,82,67,67,47,118,101,114,115,105,111,110,41,0,0,0,0,0,0,102,111,114,99,101,32,99,111,100,101,99,32,116,97,103,47,102,111,117,114,99,99,0,0,112,117,98,108,105,115,104,101,114,0,0,0,0,0,0,0,109,120,112,101,103,0,0,0,65,109,101,114,105,99,97,110,32,76,97,115,101,114,32,71,97,109,101,115,32,77,77,0,99,97,118,115,0,0,0,0,86,101,114,116,67,83,95,69,118,101,114,101,115,116,95,49,56,51,48,95,77,111,100,105,102,105,101,100,95,101,108,108,105,112,115,111,105,100,0,0,101,120,116,114,97,99,116,32,112,116,115,32,97,115,32,116,105,109,101,99,111,100,101,32,118,50,32,102,111,114,109,97,116,44,32,97,115,32,100,101,102,105,110,101,100,32,98,121,32,109,107,118,116,111,111,108,110,105,120,0,0,0,0,0,86,101,114,116,67,83,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,55,53,95,68,101,102,105,110,105,116,105,111,110,95,101,108,108,105,112,115,111,105,100,0,0,0,97,118,99,111,100,101,99,0,109,118,99,49,0,0,0,0,65,86,73,32,0,0,0,0,77,105,99,114,111,68,86,68,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,117,115,101,32,111,100,109,108,58,37,100,10,0,0,0,0,76,111,111,112,101,110,100,32,112,111,115,105,116,105,111,110,32,105,110,32,109,105,108,108,105,115,101,99,111,110,100,115,46,0,0,0,0,0,0,0,109,115,118,105,100,101,111,49,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,54,55,95,68,101,102,105,110,105,116,105,111,110,95,101,108,108,105,112,115,111,105,100,0,0,0,112,97,100,115,105,122,101,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2484384);
/* memory initializer */ allocate([62,61,32,48,0,0,0,0,109,115,118,105,100,101,111,49,0,0,0,0,0,0,0,0,77,105,99,114,111,68,86,68,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,86,101,114,116,67,83,95,69,118,101,114,101,115,116,95,49,56,51,48,95,49,57,51,55,95,65,100,106,117,115,116,109,101,110,116,95,101,108,108,105,112,115,111,105,100,0,0,0,116,114,97,99,107,0,0,0,102,114,101,101,105,110,103,32,105,110,99,111,109,112,108,101,116,101,32,112,97,99,107,101,116,32,115,105,122,101,32,37,100,44,32,110,101,119,32,37,100,10,0,0,0,0,0,0,37,115,10,0,0,0,0,0,77,101,116,97,108,32,71,101,97,114,32,83,111,108,105,100,58,32,84,104,101,32,84,119,105,110,32,83,110,97,107,101,115,0,0,0,0,0,0,0,109,116,115,50,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,83,71,65,95,49,57,50,50,95,101,108,108,105,112,115,111,105,100,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,65,114,99,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,109,115,97,49,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,82,71,83,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,77,68,53,32,116,101,115,116,105,110,103,0,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,73,71,78,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,109,115,115,50,0,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,56,48,95,66,101,110,111,105,116,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,108,105,98,115,119,114,101,115,97,109,112,108,101,32,115,117,112,112,111,114,116,32,97,32,109,97,120,105,109,117,109,32,111,102,32,37,100,32,99,104,97,110,110,101,108,115,46,32,70,101,101,108,32,102,114,101,101,32,116,111,32,97,115,107,32,102,111,114,32,97,32,104,105,103,104,101,114,32,108,105,109,105,116,46,10,0,0,0,105,110,112,117,116,115,0,0,115,120,103,97,0,0,0,0,100,101,108,97,121,0,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,54,54,95,101,108,108,105,112,115,111,105,100,0,0,0,0,71,67,83,95,84,67,95,49,57,52,56,0,0,0,0,0,114,98,0,0,0,0,0,0,101,100,103,101,0,0,0,0,116,97,103,0,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,118,49,0,0,0,65,112,112,108,121,32,97,32,98,105,113,117,97,100,32,73,73,82,32,102,105,108,116,101,114,32,119,105,116,104,32,116,104,101,32,103,105,118,101,110,32,99,111,101,102,102,105,99,105,101,110,116,115,46,0,0,86,101,114,116,67,83,95,67,108,97,114,107,101,95,49,56,53,56,95,101,108,108,105,112,115,111,105,100,0,0,0,0,115,101,116,32,116,104,101,32,119,105,110,100,111,119,32,108,101,110,103,116,104,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,10,0,86,101,114,116,67,83,95,66,101,115,115,101,108,95,78,97,109,105,98,105,97,95,101,108,108,105,112,115,111,105,100,0,37,115,37,45,49,49,115,32,99,111,110,102,105,103,117,114,97,116,105,111,110,58,32,37,115,10,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,100,97,116,97,32,99,104,101,99,107,0,0,0,0,109,115,115,49,0,0,0,0,116,0,0,0,0,0,0,0,86,101,114,116,67,83,95,66,101,115,115,101,108,95,77,111,100,105,102,105,101,100,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,0,0,100,114,111,112,111,117,116,95,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,85,110,107,110,111,119,110,32,100,101,112,116,104,32,37,100,10,0,0,0,0,0,0,0,86,101,114,116,67,83,95,66,101,115,115,101,108,95,49,56,52,49,95,101,108,108,105,112,115,111,105,100,0,0,0,0,100,105,115,99,0,0,0,0,32,40,37,115,32,45,62,32,37,115,41,0,0,0,0,0,109,115,114,108,101,0,0,0,115,116,0,0,0,0,0,0,100,101,99,97,121,115,0,0,86,101,114,116,67,83,95,65,78,83,95,101,108,108,105,112,115,111,105,100,0,0,0,0,98,95,119,105,100,116,104,95,108,111,103,50,40,98,115,105,122,101,41,32,61,61,32,98,95,104,101,105,103,104,116,95,108,111,103,50,40,98,115,105,122,101,41,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,0,0,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,111,110,121,120,99,95,105,110,116,46,104,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,115,114,99,95,116,101,115,116,115,114,99,46,99,0,0,0,0,0,0,86,101,114,116,67,83,95,65,105,114,121,95,77,111,100,105,102,105,101,100,95,49,56,52,57,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,77,97,116,114,111,115,107,97,0,0,0,0,0,0,0,0,102,114,101,113,95,99,104,114,111,109,97,0,0,0,0,0,86,101,114,116,67,83,95,65,105,114,121,95,49,56,51,48,95,101,108,108,105,112,115,111,105,100,0,0,0,0,0,0,33,109,101,109,99,109,112,40,38,99,109,45,62,99,111,117,110,116,115,46,116,120,44,32,38,122,101,114,111,95,99,111,117,110,116,115,46,116,120,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,116,120,41,41,0,116,114,105,109,0,0,0,0,115,101,116,32,116,104,101,32,105,110,105,116,105,97,108,32,115,99,97,108,101,32,118,97,108,117,101,0,0,0,0,0,115,0,0,0,0,0,0,0,50,53,0,0,0,0,0,0,67,84,95,84,114,97,110,115,118,77,101,114,99,97,116,111,114,95,83,111,117,116,104,79,114,105,101,110,116,101,100,0,97,115,115,117,109,101,32,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,0,58,99,104,97,110,110,101,108,95,108,97,121,111,117,116,61,48,120,37,108,108,120,0,0,67,84,95,78,101,119,90,101,97,108,97,110,100,77,97,112,71,114,105,100,0,0,0,0,115,101,116,32,99,105,114,99,108,101,32,99,101,110,116,101,114,32,112,111,115,105,116,105,111,110,32,111,110,32,120,45,97,120,105,115,0,0,0,0,105,110,118,97,108,105,100,32,115,116,97,114,116,99,111,100,101,10,0,0,0,0,0,0,113,120,103,97,0,0,0,0,99,121,0,0,0,0,0,0,67,84,95,86,97,110,68,101,114,71,114,105,110,116,101,110,0,0,0,0,0,0,0,0,71,67,83,95,84,114,105,110,105,100,97,100,95,49,57,48,51,0,0,0,0,0,0,0,109,97,108,108,111,99,32,111,102,32,115,105,122,101,32,37,100,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,112,114,101,115,101,114,118,101,32,112,111,114,116,114,97,105,116,32,103,101,111,109,101,116,114,121,0,0,0,0,0,0,100,105,114,101,99,116,45,113,112,101,108,45,98,108,111,99,107,115,105,122,101,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,112,101,114,32,70,79,85,82,67,67,47,118,101,114,115,105,111,110,41,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,116,111,32,114,101,99,111,114,100,0,0,0,0,0,0,105,110,116,101,114,108,97,99,101,32,102,105,101,108,100,115,32,102,114,111,109,32,116,119,111,32,99,111,110,115,101,99,117,116,105,118,101,32,102,114,97,109,101,115,0,0,0,0,84,111,116,97,108,32,119,105,100,116,104,32,37,117,120,37,117,32,105,115,32,116,111,111,32,109,117,99,104,46,10,0,102,108,97,115,104,115,118,0,67,84,95,83,105,110,117,115,111,105,100,97,108,0,0,0,100,101,102,97,117,108,116,0,67,84,95,82,111,98,105,110,115,111,110,0,0,0,0,0,37,115,87,65,82,78,73,78,71,58,32,108,105,98,114,97,114,121,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,115,105,100,101,32,98,121,32,115,105,100,101,32,104,97,108,102,32,119,105,100,116,104,32,108,101,102,116,32,102,105,114,115,116,0,0,0,0,0,0,109,112,108,50,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,80,69,71,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,111,117,116,32,111,102,32,98,111,117,110,100,97,114,121,32,40,37,100,32,37,100,41,10,0,0,0,0,0,99,115,0,0,0,0,0,0,77,97,116,114,111,115,107,97,32,47,32,87,101,98,77,0,67,84,95,80,111,108,121,99,111,110,105,99,0,0,0,0,114,97,119,32,77,80,69,71,45,52,32,118,105,100,101,111,0,0,0,0,0,0,0,0,67,84,95,79,114,116,104,111,103,114,97,112,104,105,99,0,70,108,97,103,115,32,116,111,32,112,97,115,115,32,116,111,32,108,105,98,115,119,115,99,97,108,101,0,0,0,0,0,32,40,99,111,112,121,41,0,99,112,102,114,0,0,0,0,110,111,110,101,0,0,0,0,67,84,95,77,105,108,108,101,114,67,121,108,105,110,100,114,105,99,97,108,0,0,0,0,99,104,114,111,109,97,32,98,108,117,101,0,0,0,0,0,86,82,32,110,97,116,105,118,101,32,115,116,114,101,97,109,32,40,76,88,70,41,0,0,102,0,0,0,0,0,0,0,76,86,70,0,0,0,0,0,67,84,95,71,110,111,109,111,110,105,99,0,0,0,0,0,102,117,108,108,32,97,110,97,108,121,122,101,0,0,0,0,76,79,65,83,32,65,117,100,105,111,83,121,110,99,83,116,114,101,97,109,0,0,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,109,97,120,95,116,120,95,115,105,122,101,46,34,0,0,0,0,0,120,51,0,0,0,0,0,0,114,97,119,32,108,109,108,109,52,0,0,0,0,0,0,0,98,108,97,99,107,0,0,0,67,84,95,67,97,115,115,105,110,105,83,111,108,100,110,101,114,0,0,0,0,0,0,0,112,111,115,0,0,0,0,0,67,84,95,69,113,117,105,114,101,99,116,97,110,103,117,108,97,114,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,97,99,116,105,118,101,95,109,97,112,0,0,0,0,0,0,76,79,65,83,47,76,65,84,77,0,0,0,0,0,0,0,117,110,105,102,111,114,109,32,110,111,105,115,101,0,0,0,37,108,108,100,0,0,0,0,67,84,95,79,98,108,105,113,117,101,83,116,101,114,101,111,103,114,97,112,104,105,99,0,65,108,108,111,99,97,116,105,110,103,0,0,0,0,0,0,66,105,116,109,97,112,32,66,114,111,116,104,101,114,115,32,74,86,0,0,0,0,0,0,98,101,0,0,0,0,0,0,117,120,103,97,0,0,0,0,111,117,116,112,117,116,32,112,108,97,110,101,32,37,100,32,104,101,105,103,104,116,32,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,105,110,112,117,116,32,37,100,32,112,108,97,110,101,32,37,100,32,104,101,105,103,104,116,32,37,100,10,0,0,0,83,110,111,119,32,101,110,99,111,100,101,114,32,105,115,32,110,111,116,32,101,110,97,98,108,101,100,32,105,110,32,108,105,98,97,118,99,111,100,101,99,10,0,0,0,0,0,0,99,112,105,45,62,111,120,99,102,46,110,117,109,98,101,114,95,111,102,95,108,97,121,101,114,115,32,60,61,32,86,80,88,95,84,83,95,77,65,88,95,76,65,89,69,82,83,0,74,65,67,79,115,117,98,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,67,84,95,80,111,108,97,114,83,116,101,114,101,111,103,114,97,112,104,105,99,0,0,0,71,67,83,95,84,111,107,121,111,0,0,0,0,0,0,0,111,112,101,110,99,108,45,100,101,118,105,99,101,0,0,0,100,105,114,101,99,116,95,98,108,111,99,107,115,105,122,101,0,0,0,0,0,0,0,0,102,114,97,109,101,115,0,0,100,101,102,97,117,108,116,0,75,97,114,108,32,77,111,114,116,111,110,39,115,32,118,105,100,101,111,32,99,111,100,101,99,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,50,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,67,84,95,83,116,101,114,101,111,103,114,97,112,104,105,99,0,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,118,102,95,105,110,116,101,114,108,97,99,101,46,99,0,0,0,0,0,0,115,119,97,112,32,108,117,109,97,32,102,105,101,108,100,115,0,0,0,0,0,0,0,0,114,99,95,111,118,101,114,115,104,111,111,116,95,112,99,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,48,93,0,0,67,84,95,69,113,117,105,100,105,115,116,97,110,116,67,111,110,105,99,0,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,74,65,67,79,115,117,98,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,115,101,116,32,116,104,101,32,104,117,101,32,97,110,103,108,101,32,114,97,100,105,97,110,115,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,114,99,95,114,101,115,105,122,101,95,97,108,108,111,119,101,100,32,101,120,112,101,99,116,101,100,32,98,111,111,108,101,97,110,0,0,0,0,0,0,115,101,116,32,115,99,97,108,101,32,104,101,105,103,104,116,0,0,0,0,0,0,0,0,79,110,50,32,73,86,70,0,67,84,95,65,122,105,109,117,116,104,97,108,69,113,117,105,100,105,115,116,97,110,116,0,89,0,0,0,0,0,0,0,79,110,50,32,73,86,70,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,40,105,110,118,97,108,105,100,32,77,66,32,116,121,112,101,41,10,0,0,0,0,0,0,0,67,84,95,65,108,98,101,114,115,69,113,117,97,108,65,114,101,97,0,0,0,0,0,0,116,109,112,111,0,0,0,0,85,110,107,110,111,119,110,32,112,97,99,107,105,110,103,32,109,111,100,101,46,0,0,0,32,91,115,121,110,99,32,35,37,100,58,37,100,93,0,0,114,111,117,110,100,32,116,111,119,97,114,100,115,32,43,105,110,102,116,121,0,0,0,0,67,84,95,76,97,109,98,101,114,116,65,122,105,109,69,113,117,97,108,65,114,101,97,0,73,110,100,105,103,111,86,105,115,105,111,110,32,56,48,48,48,32,118,105,100,101,111,0,69,114,114,111,114,32,115,112,108,105,116,116,105,110,103,32,116,104,101,32,97,114,103,117,109,101,110,116,32,108,105,115,116,58,32,0,0,0,0,0,78,79,80,84,83,0,0,0,70,117,110,99,111,109,32,73,83,83,0,0,0,0,0,0,99,108,71,101,116,68,101,118,105,99,101,73,110,102,111,0,109,112,118,95,102,108,97,103,115,0,0,0,0,0,0,0,67,84,95,76,97,109,98,101,114,116,67,111,110,102,67,111,110,105,99,95,72,101,108,109,101,114,116,0,0,0,0,0,110,0,0,0,0,0,0,0,117,121,118,121,52,50,50,0,99,111,100,101,99,32,111,112,101,110,32,105,110,32,114,101,97,100,95,100,101,99,95,99,111,110,102,105,103,95,100,101,115,99,114,10,0,0,0,0,65,113,117,97,0,0,0,0,115,101,116,32,103,114,101,101,110,32,112,108,97,110,101,0,37,100,120,37,100,0,0,0,67,84,95,76,97,109,98,101,114,116,67,111,110,102,67,111,110,105,99,95,50,83,80,0,116,105,109,101,0,0,0,0,73,109,109,101,100,105,97,116,101,32,101,120,105,116,32,114,101,113,117,101,115,116,101,100,0,0,0,0,0,0,0,0,66,101,114,107,101,108,101,121,47,73,82,67,65,77,47,67,65,82,76,32,83,111,117,110,100,32,70,111,114,109,97,116,0,0,0,0,0,0,0,0,70,76,67,0,0,0,0,0,99,45,62,100,115,116,66,112,99,32,62,32,49,52,0,0,98,108,97,99,107,0,0,0,108,97,115,116,73,110,67,104,114,66,117,102,32,43,32,49,32,45,32,99,104,114,83,114,99,83,108,105,99,101,89,32,62,61,32,48,0,0,0,0,108,97,110,99,122,111,115,0,66,101,114,107,101,108,101,121,47,73,82,67,65,77,47,67,65,82,76,32,83,111,117,110,100,32,70,111,114,109,97,116,0,0,0,0,0,0,0,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,104,97,115,32,97,32,100,105,102,102,101,114,101,110,116,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,116,104,97,110,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,117,115,101,100,32,99,104,97,110,110,101,108,115,44,32,105,103,110,111,114,105,110,103,32,108,97,121,111,117,116,10,0,0,0,0,0,0,102,0,0,0,0,0,0,0,67,84,95,77,101,114,99,97,116,111,114,0,0,0,0,0,105,108,108,101,103,97,108,32,105,105,100,10,0,0,0,0,115,101,116,32,101,100,103,101,32,109,111,100,101,0,0,0,73,110,116,101,114,112,108,97,121,32,77,86,69,0,0,0,100,101,102,97,117,108,116,0,92,97,37,50,117,37,49,91,92,125,93,37,110,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,115,10,0,0,0,0,0,0,0,115,101,116,32,115,99,101,110,101,32,99,104,97,110,103,101,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,51,0,0,0,0,0,0,0,0,114,97,119,32,73,110,103,101,110,105,101,110,116,32,77,74,80,69,71,0,0,0,0,0,67,84,95,79,98,108,105,113,117,101,77,101,114,99,97,116,111,114,95,83,112,104,101,114,105,99,97,108,0,0,0,0,35,111,112,116,105,111,110,115,58,32,37,100,120,37,100,0,110,111,116,105,110,100,105,99,97,116,101,100,0,0,0,0,110,111,116,105,110,100,105,99,97,116,101,100,0,0,0,0,76,111,47,82,111,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,44,32,116,111,111,32,109,97,110,121,32,83,66,82,32,101,110,118,101,108,111,112,101,115,32,105,110,32,70,73,88,70,73,88,32,116,121,112,101,32,83,66,82,32,102,114,97,109,101,58,32,37,100,10,0,68,105,115,97,98,108,101,32,77,105,100,47,83,105,100,101,32,99,111,100,105,110,103,0,120,103,97,0,0,0,0,0,108,105,98,102,97,97,99,32,37,100,46,37,100,0,0,0,105,110,112,117,116,32,98,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,48,47,49,32,48,46,48,57,56,47,49,32,48,46,50,51,53,47,48,46,52,57,56,32,48,46,52,50,51,47,48,32,49,47,48,0,0,0,0,0,67,111,117,112,108,101,100,32,99,104,97,110,110,101,108,115,32,62,32,54,0,0,0,0,98,108,111,99,107,95,97,108,105,103,110,32,105,115,32,110,111,116,32,115,101,116,10,0,69,120,112,111,110,101,110,116,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,67,84,95,79,98,108,105,113,117,101,77,101,114,99,97,116,111,114,95,82,111,115,101,110,109,117,110,100,0,0,0,0,71,67,83,95,84,77,55,53,0,0,0,0,0,0,0,0,123,0,0,0,0,0,0,0,108,97,118,102,105,46,99,114,111,112,100,101,116,101,99,116,46,104,0,0,0,0,0,0,111,112,101,110,99,108,45,99,108,98,105,110,0,0,0,0,73,110,118,97,108,105,100,32,87,101,98,80,32,76,111,115,115,108,101,115,115,32,118,101,114,115,105,111,110,10,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,99,104,97,110,110,101,108,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,77,97,114,107,101,114,32,98,105,116,32,119,97,115,32,115,101,116,10,0,0,0,0,0,113,112,101,108,95,99,104,114,111,109,97,50,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,98,108,111,99,107,95,113,112,105,115,10,0,0,0,0,0,99,111,112,121,32,111,114,32,100,105,115,99,97,114,100,32,102,114,97,109,101,115,32,98,101,102,111,114,101,32,115,116,97,114,116,32,116,105,109,101,0,0,0,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,116,105,109,101,32,100,111,109,97,105,110,32,116,114,97,110,115,102,111,114,109,115,41,46,32,10,0,84,114,121,105,110,103,32,116,111,32,117,110,112,97,99,107,32,76,90,45,99,111,109,112,114,101,115,115,101,100,32,102,114,97,109,101,32,119,105,116,104,32,110,111,32,76,90,32,98,117,102,102,101,114,10,0,107,101,101,112,32,97,115,112,101,99,116,32,114,97,116,105,111,0,0,0,0,0,0,0,40,115,45,62,109,98,95,104,101,105,103,104,116,32,38,32,49,41,32,61,61,32,48,0,119,0,0,0,0,0,0,0,86,79,80,32,68,81,117,97,110,116,32,105,110,102,111,10,0,0,0,0,0,0,0,0,107,109,118,99,0,0,0,0,100,101,102,97,117,108,116,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,101,120,116,114,97,100,97,116,97,46,10,0,0,69,110,99,111,100,101,114,32,118,101,114,115,105,111,110,32,37,100,46,37,100,46,37,100,46,37,100,10,0,0,0,0,67,84,95,79,98,108,105,113,117,101,77,101,114,99,97,116,111,114,95,76,97,98,111,114,100,101,0,0,0,0,0,0,65,108,116,101,114,110,97,116,105,118,101,108,121,32,117,115,101,32,116,104,101,32,110,111,110,32,101,120,112,101,114,105,109,101,110,116,97,108,32,37,115,32,39,37,115,39,46,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,97,108,112,104,97,32,103,97,105,110,32,102,111,114,32,116,104,101,32,103,114,101,101,110,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,84,114,101,101,32,101,120,99,101,101,100,101,100,32,105,116,115,32,103,105,118,101,110,32,100,101,112,116,104,32,40,37,105,41,10,0,0,0,0,0,108,122,119,0,0,0,0,0,115,101,116,32,103,114,101,101,110,32,104,105,103,104,108,105,103,104,116,115,0,0,0,0,105,109,97,103,101,50,32,115,101,113,117,101,110,99,101,0,82,97,100,105,117,115,32,111,102,32,116,104,101,32,97,108,112,104,97,32,98,108,117,114,114,105,110,103,32,98,111,120,0,0,0,0,0,0,0,0,67,84,95,79,98,108,105,113,117,101,77,101,114,99,97,116,111,114,0,0,0,0,0,0,97,118,117,116,105,108,0,0,80,114,111,106,101,99,116,101,100,67,83,84,121,112,101,71,101,111,75,101,121,0,0,0,68,101,99,111,100,101,100,32,111,110,108,121,32,37,105,32,98,121,116,101,115,32,111,102,32,37,105,10,0,0,0,0,105,110,118,97,108,105,100,32,77,86,32,118,108,99,10,0,60,37,99,62,0,0,0,0,37,117,0,0,0,0,0,0,79,110,108,121,32,100,111,32,77,69,47,77,67,32,40,73,32,102,114,97,109,101,115,32,45,62,32,114,101,102,44,32,80,32,102,114,97,109,101,32,45,62,32,77,69,43,77,67,41,46,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,33,10,0,0,0,0,0,102,109,116,32,99,104,117,110,107,32,119,97,115,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,115,105,122,105,110,103,32,98,117,102,102,101,114,115,10,0,99,49,95,109,111,100,101,0,69,120,116,114,97,100,97,116,97,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,67,84,95,84,114,97,110,115,118,77,101,114,99,97,116,111,114,95,77,111,100,105,102,105,101,100,95,65,108,97,115,107,97,0,0,0,0,0,0,0,97,118,103,80,73,84,101,120,0,0,0,0,0,0,0,0,84,104,105,115,32,102,105,108,101,32,116,114,105,103,103,101,114,115,32,115,111,109,101,32,117,110,116,101,115,116,101,100,32,99,111,100,101,46,32,80,108,101,97,115,101,32,99,111,110,116,97,99,116,32,116,104,101,32,100,101,118,101,108,111,112,101,114,115,46,10,0,0,37,108,108,100,0,0,0,0,109,98,115,95,112,101,114,95,115,108,105,99,101,0,0,0,104,101,97,100,101,114,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,0,112,105,99,116,117,114,101,32,114,101,115,111,108,117,116,105,111,110,32,99,104,97,110,103,101,58,32,37,100,120,37,100,32,45,62,32,37,100,120,37,100,10,0,0,0,0,0,0,105,110,102,108,97,116,101,32,114,101,116,117,114,110,101,100,32,101,114,114,111,114,32,37,100,10,0,0,0,0,0,0,37,108,108,100,0,0,0,0,104,0,0,0,0,0,0,0,115,108,105,99,101,100,45,116,104,114,101,97,100,115,0,0,67,84,95,84,114,97,110,115,118,101,114,115,101,77,101,114,99,97,116,111,114,0,0,0,103,97,112,108,101,115,115,95,112,108,97,121,98,97,99,107,0,0,0,0,0,0,0,0,32,32,83,116,114,101,97,109,32,35,37,100,58,37,100,32,45,62,32,35,37,100,58,37,100,0,0,0,0,0,0,0,115,97,109,112,108,101,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,84,105,109,101,115,116,97,109,112,32,105,110,32,115,101,99,111,110,100,115,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,112,97,115,115,101,100,0,0,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,117,115,101,100,32,99,111,108,111,117,114,115,32,37,100,10,0,0,0,0,87,97,114,110,105,110,103,44,32,81,77,65,84,95,83,72,73,70,84,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,37,100,44,32,111,118,101,114,102,108,111,119,115,32,112,111,115,115,105,98,108,101,10,0,0,0,0,0,0,114,101,108,101,97,115,105,110,103,32,122,111,109,98,105,101,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,108,111,111,112,0,0,0,0,80,114,111,106,95,82,83,79,95,66,111,114,110,101,111,0,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,99,104,97,110,110,101,108,32,37,100,10,0,0,0,0,102,97,105,108,101,100,32,116,111,32,100,101,99,111,100,101,32,99,104,97,110,110,101,108,32,37,100,10,0,0,0,0,113,112,95,114,100,0,0,0,98,117,103,115,58,32,37,88,32,108,97,118,99,95,98,117,105,108,100,58,37,100,32,120,118,105,100,95,98,117,105,108,100,58,37,100,32,100,105,118,120,95,118,101,114,115,105,111,110,58,37,100,32,100,105,118,120,95,98,117,105,108,100,58,37,100,32,37,115,10,0,0,110,111,110,95,108,105,110,101,97,114,95,113,117,97,110,116,0,0,0,0,0,0,0,0,73,78,84,69,82,76,65,67,69,68,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,101,120,116,114,97,32,112,105,99,116,117,114,101,32,102,111,108,108,111,119,105,110,103,32,97,32,102,114,97,109,101,45,112,105,99,116,117,114,101,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,117,98,115,116,114,101,97,109,115,32,119,105,116,104,32,86,76,67,32,98,108,111,99,107,32,115,105,122,101,32,99,104,101,99,107,32,105,110,102,111,0,0,0,0,0,0,0,112,105,120,32,102,109,116,32,105,100,32,37,120,10,0,0,102,108,97,103,115,0,0,0,99,102,115,104,121,89,112,111,0,0,0,0,0,0,0,0,80,114,111,106,95,78,101,116,104,101,114,108,97,110,100,115,95,69,95,73,110,100,105,101,115,95,69,113,117,97,116,111,114,105,97,108,0,0,0,0,119,112,114,101,100,112,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,99,111,100,101,100,32,102,114,97,109,101,10,0,0,0,73,109,97,103,101,32,116,121,112,101,32,105,115,32,89,85,86,32,49,58,49,58,49,46,10,0,0,0,0,0,0,0,105,109,97,103,101,50,32,115,101,113,117,101,110,99,101,0,77,105,115,115,105,110,103,32,69,79,67,10,0,0,0,0,37,99,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,45,32,109,105,110,95,115,105,122,101,32,62,61,32,111,102,102,115,0,0,0,0,0,116,114,97,110,115,102,111,114,109,32,97,110,100,32,98,108,111,99,107,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,84,104,101,32,98,97,110,100,32,98,108,111,99,107,32,115,105,122,101,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,105,110,104,101,114,105,116,101,100,10,0,77,111,100,101,32,37,100,58,32,117,110,115,117,112,112,111,114,116,101,100,32,82,76,69,32,99,111,100,101,58,32,37,88,10,0,0,0,0,0,0,69,114,114,111,114,58,32,118,101,114,62,50,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,104,117,102,102,121,117,118,59,32,117,115,101,32,118,99,111,100,101,99,61,102,102,118,104,117,102,102,10,0,0,0,80,114,111,106,95,66,97,104,114,97,105,110,95,71,114,105,100,0,0,0,0,0,0,0,80,97,114,115,101,100,32,99,111,109,109,97,110,100,115,58,10,0,0,0,0,0,0,0,110,111,110,45,52,58,50,58,48,32,115,117,112,112,111,114,116,32,105,115,32,99,117,114,114,101,110,116,108,121,32,117,110,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,83,107,105,112,112,105,110,103,32,78,65,76,32,117,110,105,116,32,37,100,10,0,0,0,110,111,110,45,101,120,105,115,116,105,110,103,32,83,80,83,32,37,100,32,114,101,102,101,114,101,110,99,101,100,32,105,110,32,98,117,102,102,101,114,105,110,103,32,112,101,114,105,111,100,10,0,0,0,0,0,109,109,99,111,58,32,99,97,110,110,111,116,32,97,115,115,105,103,110,32,99,117,114,114,101,110,116,32,112,105,99,116,117,114,101,32,116,111,32,50,32,108,111,110,103,32,116,101,114,109,32,114,101,102,101,114,101,110,99,101,115,10,0,0,80,73,67,45,65,70,70,0,110,111,32,102,114,97,109,101,33,10,0,0,0,0,0,0,112,105,99,116,95,116,121,112,101,0,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,116,105,108,101,32,37,100,44,37,100,10,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,90,101,97,108,97,110,100,95,83,111,117,116,104,95,73,115,108,97,110,100,95,78,97,116,95,71,114,105,100,0,0,73,110,118,97,108,105,100,32,98,121,116,101,32,114,117,110,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,37,100,120,37,100,32,122,108,105,98,112,114,105,109,101,95,99,117,114,114,32,37,100,120,37,100,10,0,0,0,0,0,115,101,116,32,116,104,101,32,115,101,101,100,32,102,111,114,32,116,104,101,32,114,97,110,100,111,109,32,109,111,100,101,0,0,0,0,0,0,0,0,32,108,112,99,32,116,121,112,101,58,32,70,105,120,101,100,32,112,114,101,45,100,101,102,105,110,101,100,32,99,111,101,102,102,105,99,105,101,110,116,115,10,0,0,0,0,0,0,68,101,99,111,114,114,101,108,97,116,101,100,32,98,105,116,32,100,101,112,116,104,32,62,32,51,50,0,0,0,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,32,111,102,32,109,111,114,101,32,116,104,97,110,32,56,32,110,101,101,100,115,32,45,99,111,100,101,114,32,49,32,99,117,114,114,101,110,116,108,121,10,0,0,0,0,99,104,114,111,109,97,32,115,117,98,115,97,109,112,108,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,116,104,105,115,32,99,111,108,111,114,115,112,97,99,101,10,0,0,0,0,90,0,0,0,0,0,0,0,102,114,97,109,101,32,112,116,115,58,37,102,32,45,62,32,113,117,101,117,101,32,105,100,120,58,37,100,32,97,118,97,105,108,97,98,108,101,58,37,100,10,0,0,0,0,0,0,109,112,50,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,101,110,99,111,100,101,32,119,105,116,104,32,65,118,105,100,32,78,105,116,114,105,115,32,99,111,109,112,97,116,105,98,105,108,105,116,121,0,0,0,99,111,100,101,98,108,111,99,107,32,104,101,105,103,104,116,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,68,84,83,45,72,68,32,97,117,100,105,111,32,112,114,101,115,101,110,116,97,116,105,111,110,115,0,0,0,0,0,67,111,110,116,97,105,110,101,114,32,99,104,97,110,110,101,108,115,32,33,61,32,50,0,80,114,111,106,95,78,101,119,95,90,101,97,108,97,110,100,95,78,111,114,116,104,95,73,115,108,97,110,100,95,78,97,116,95,71,114,105,100,0,0,115,118,103,97,0,0,0,0,65,112,112,108,101,32,77,74,80,69,71,45,66,0,0,0,119,58,37,100,32,104,58,37,100,32,112,105,120,102,109,116,58,37,115,32,116,98,58,37,100,47,37,100,32,102,114,58,37,100,47,37,100,32,115,97,114,58,37,100,47,37,100,32,115,119,115,95,112,97,114,97,109,58,37,115,10,0,0,0,72,111,119,32,102,97,115,116,32,116,104,101,32,115,116,114,105,112,32,110,117,109,98,101,114,32,97,100,97,112,116,115,44,32,109,111,114,101,32,105,115,32,115,108,105,103,104,116,108,121,32,98,101,116,116,101,114,44,32,109,117,99,104,32,115,108,111,119,101,114,0,0,66,77,80,32,100,101,99,111,100,101,114,32,105,115,32,98,114,111,107,101,110,10,0,0,109,112,50,102,105,120,101,100,0,0,0,0,0,0,0,0,80,114,111,106,95,69,120,116,101,110,100,101,100,95,80,117,114,112,108,101,95,66,101,108,116,0,0,0,0,0,0,0,71,67,83,95,84,77,54,53,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,100,105,110,103,32,109,111,100,101,10,0,0,0,0,111,112,101,110,99,108,0,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,115,0,0,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,99,111,109,112,114,101,115,115,105,111,110,32,108,101,118,101,108,32,37,100,10,0,70,108,111,97,116,105,110,103,32,112,111,105,110,116,32,100,101,99,111,100,105,110,103,0,111,108,100,32,115,116,97,110,100,97,114,100,32,113,112,101,108,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,112,101,114,32,70,79,85,82,67,67,47,118,101,114,115,105,111,110,41,0,0,0,0,0,88,45,85,115,101,115,70,111,110,116,0,0,0,0,0,0,99,111,112,121,112,114,105,111,114,115,115,0,0,0,0,0,98,108,111,99,107,95,108,114,0,0,0,0,0,0,0,0,82,111,99,107,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,78,117,112,112,101,108,86,105,100,101,111,47,82,84,74,80,69,71,0,0,0,0,0,0,39,97,114,101,115,97,109,112,108,101,39,32,102,105,108,116,101,114,32,110,111,116,32,112,114,101,115,101,110,116,44,32,99,97,110,110,111,116,32,99,111,110,118,101,114,116,32,97,117,100,105,111,32,102,111,114,109,97,116,115,46,10,0,0,52,50,48,112,49,48,0,0,80,114,111,106,95,69,103,121,112,116,95,80,117,114,112,108,101,95,66,101,108,116,0,0,37,105,0,0,0,0,0,0,99,97,112,116,105,111,110,115,0,0,0,0,0,0,0,0,102,97,99,116,0,0,0,0,102,111,117,110,100,32,110,111,32,39,102,109,116,32,39,32,116,97,103,32,98,101,102,111,114,101,32,116,104,101,32,39,100,97,116,97,39,32,116,97,103,10,0,0,0,0,0,0,66,65,78,68,0,0,0,0,76,101,110,103,116,104,0,0,106,112,103,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,117,116,105,108,115,46,99,0,0,0,0,0,98,115,102,115,0,0,0,0,101,110,97,98,108,101,0,0,115,116,97,114,116,95,116,105,109,101,0,0,0,0,0,0,115,119,102,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,97,116,32,115,97,109,112,108,101,32,114,97,116,101,44,32,99,104,111,111,115,101,32,102,114,111,109,32,40,52,52,49,48,48,44,32,50,50,48,53,48,44,32,49,49,48,50,53,41,46,10,0,0,0,0,0,0,118,101,114,115,105,111,110,58,32,37,105,32,108,97,121,101,114,58,32,37,105,32,101,120,116,101,110,115,105,111,110,58,32,37,105,10,0,0,0,0,60,47,83,109,111,111,116,104,83,116,114,101,97,109,105,110,103,77,101,100,105,97,62,10,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,80,114,111,106,95,69,103,121,112,116,95,82,101,100,95,66,101,108,116,0,0,0,0,0,37,115,108,105,98,37,45,49,49,115,32,37,50,100,46,37,51,100,46,37,51,100,32,47,32,37,50,100,46,37,51,100,46,37,51,100,10,0,0,0,105,76,66,67,32,115,116,111,114,97,103,101,0,0,0,0,80,114,111,106,95,67,111,108,111,109,98,105,97,95,54,69,0,0,0,0,0,0,0,0,80,114,111,106,95,67,111,108,111,109,98,105,97,95,51,69,0,0,0,0,0,0,0,0,112,103,97,112,0,0,0,0,32,45,62,32,83,116,114,101,97,109,32,35,37,100,58,37,100,32,40,37,115,41,10,0,73,70,70,32,40,73,110,116,101,114,99,104,97,110,103,101,32,70,105,108,101,32,70,111,114,109,97,116,41,0,0,0,80,114,111,106,95,67,111,108,111,109,98,105,97,95,66,111,103,111,116,97,0,0,0,0,114,97,119,32,105,100,32,82,111,81,0,0,0,0,0,0,105,100,32,82,111,81,0,0,80,114,111,106,95,67,111,108,111,109,98,105,97,95,51,87,0,0,0,0,0,0,0,0,105,100,32,67,105,110,101,109,97,116,105,99,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,55,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,54,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,53,0,0,0,0,0,0,0,0,118,103,97,0,0,0,0,0,80,114,111,106,95,65,114,103], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2494624);
/* memory initializer */ allocate([101,110,116,105,110,97,95,52,0,0,0,0,0,0,0,0,71,67,83,95,84,105,109,98,97,108,97,105,95,49,57,52,56,0,0,0,0,0,0,0,115,116,105,116,99,104,97,98,108,101,0,0,0,0,0,0,115,116,100,95,113,112,101,108,0,0,0,0,0,0,0,0,99,111,112,121,32,105,110,105,116,105,97,108,32,110,111,110,45,107,101,121,102,114,97,109,101,115,0,0,0,0,0,0,110,117,118,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,51,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,50,0,0,0,0,0,0,0,0,37,115,37,115,37,115,10,0,79,112,116,105,111,110,32,37,115,32,40,37,115,41,32,99,97,110,110,111,116,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,37,115,32,37,115,32,45,45,32,121,111,117,32,97,114,101,32,116,114,121,105,110,103,32,116,111,32,97,112,112,108,121,32,97,110,32,105,110,112,117,116,32,111,112,116,105,111,110,32,116,111,32,97,110,32,111,117,116,112,117,116,32,102,105,108,101,32,111,114,32,118,105,99,101,32,118,101,114,115,97,46,32,77,111,118,101,32,116,104,105,115,32,111,112,116,105,111,110,32,98,101,102,111,114,101,32,116,104,101,32,102,105,108,101,32,105,116,32,98,101,108,111,110,103,115,32,116,111,46,10,0,0,80,114,111,106,95,65,114,103,101,110,116,105,110,97,95,49,0,0,0,0,0,0,0,0,108,105,118,101,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,56,0,0,0,0,0,97,61,99,114,121,112,116,111,58,49,32,37,115,32,105,110,108,105,110,101,58,37,115,13,10,0,0,0,0,0,0,0,104,100,95,118,105,100,101,111,0,0,0,0,0,0,0,0,32,32,37,115,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,55,0,0,0,0,0,109,111,118,105,101,0,0,0,85,115,101,32,77,80,52,65,45,76,65,84,77,32,112,97,99,107,101,116,105,122,97,116,105,111,110,32,105,110,115,116,101,97,100,32,111,102,32,77,80,69,71,52,45,71,69,78,69,82,73,67,32,102,111,114,32,65,65,67,0,0,0,0,73,110,118,97,108,105,100,32,99,111,100,101,99,32,116,97,103,10,0,0,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,54,0,0,0,0,0,109,112,49,102,108,111,97,116,0,0,0,0,0,0,0,0,78,111,110,45,108,105,110,101,97,114,32,105,110,100,101,120,32,100,101,116,101,99,116,101,100,44,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,73,80,82,84,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,53,0,0,0,0,0,99,104,97,110,110,101,108,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,52,0,0,0,0,0,114,97,119,32,68,84,83,0,114,97,119,32,83,104,111,114,116,101,110,0,0,0,0,0,97,108,98,117,109,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,51,0,0,0,0,0,113,118,103,97,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,50,0,0,0,0,0,71,67,83,95,84,97,110,97,110,97,114,105,118,101,0,0,102,114,97,109,101,45,112,97,99,107,105,110,103,0,0,0,115,49,54,98,101,0,0,0,77,105,99,114,111,115,111,102,116,32,87,105,110,100,111,119,115,32,73,67,79,0,0,0,113,112,101,108,95,99,104,114,111,109,97,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,118,105,100,101,111,32,115,116,114,101,97,109,115,0,0,0,0,0,99,111,112,121,105,110,107,102,0,0,0,0,0,0,0,0,83,109,97,99,107,101,114,32,118,105,100,101,111,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,49,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,87,105,110,100,111,119,115,32,73,67,79,0,0,0,115,49,54,98,101,0,0,0,109,112,49,0,0,0,0,0,67,114,121,111,32,72,78,77,32,118,52,0,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,53,48,0,0,0,0,0,10,37,115,99,111,110,102,105,103,117,114,97,116,105,111,110,58,10,0,0,0,0,0,0,100,111,32,110,111,116,32,102,105,108,108,32,105,110,32,109,105,115,115,105,110,103,32,118,97,108,117,101,115,32,116,104,97,116,32,99,97,110,32,98,101,32,101,120,97,99,116,108,121,32,99,97,108,99,117,108,97,116,101,100,0,0,0,0,75,69,89,82,73,78,71,32,32,32,32,32,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,52,57,0,0,0,0,0,114,99,0,0,0,0,0,0,80,114,111,106,95,65,117,115,116,114,97,108,105,97,110,95,77,97,112,95,71,114,105,100,95,52,56,0,0,0,0,0,104,100,118,100,0,0,0,0,112,114,101,102,101,114,114,101,100,32,112,97,103,101,32,100,117,114,97,116,105,111,110,44,32,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,0,0,0,0,0,0,0,0,32,32,70,105,108,101,32,37,115,32,45,62,32,83,116,114,101,97,109,32,35,37,100,58,37,100,10,0,0,0,0,0,72,101,97,100,101,114,32,112,97,114,115,105,110,103,32,102,97,105,108,101,100,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,65,112,112,108,101,32,72,84,84,80,32,76,105,118,101,32,83,116,114,101,97,109,105,110,103,0,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,0,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,56,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,121,110,99,10,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,55,0,0,0,49,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,54,0,0,0,77,88,70,32,115,116,114,117,99,116,117,114,101,32,108,111,111,112,32,100,101,116,101,99,116,101,100,10,0,0,0,0,49,48,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,53,0,0,0,78,111,32,115,116,114,101,97,109,115,32,116,111,32,109,117,120,32,119,101,114,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,0,65,112,112,108,101,32,72,84,84,80,32,76,105,118,101,32,83,116,114,101,97,109,105,110,103,0,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,52,0,0,0,115,112,108,105,116,0,0,0,114,97,119,32,72,69,86,67,32,118,105,100,101,111,0,0,33,116,115,95,115,116,45,62,112,97,121,108,111,97,100,95,115,105,122,101,0,0,0,0,113,113,118,103,97,0,0,0,109,112,101,103,116,115,32,100,101,109,117,120,101,114,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,51,0,0,0,71,67,83,95,83,117,100,97,110,0,0,0,0,0,0,0,102,97,107,101,45,105,110,116,101,114,108,97,99,101,100,0,115,118,99,100,32,109,117,120,101,114,0,0,0,0,0,0,105,108,108,101,103,97,108,32,86,76,67,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,112,101,114,32,70,79,85,82,67,67,41,0,0,0,0,0,0,0,101,114,114,111,114,0,0,0,105,100,58,32,37,54,51,91,94,44,93,44,32,105,110,100,101,120,58,32,37,117,0,0,115,109,97,99,107,118,105,100,101,111,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,50,0,0,0,76,97,118,102,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,49,0,0,0,126,0,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,53,48,0,0,0,72,68,83,32,77,117,120,101,114,0,0,0,0,0,0,0,114,97,119,32,72,46,50,54,52,32,118,105,100,101,111,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,52,57,0,0,0,109,101,100,105,97,95,116,121,112,101,0,0,0,0,0,0,109,112,52,44,112,115,112,0,32,40,103,114,97,112,104,32,37,100,41,0,0,0,0,0,114,97,119,32,72,46,50,54,51,0,0,0,0,0,0,0,114,97,119,32,72,46,50,54,49,0,0,0,0,0,0,0,80,114,111,106,95,77,97,112,95,71,114,105,100,95,111,102,95,65,117,115,116,114,97,108,105,97,95,52,56,0,0,0,97,108,108,111,119,32,117,115,105,110,103,32,97,98,115,111,108,117,116,101,32,112,97,116,104,32,119,104,101,110,32,111,112,101,110,105,110,103,32,97,108,105,97,115,44,32,116,104,105,115,32,105,115,32,97,32,112,111,115,115,105,98,108,101,32,115,101,99,117,114,105,116,121,32,105,115,115,117,101,0,77,73,68,73,32,108,105,107,101,32,102,111,114,109,97,116,32,102,111,117,110,100,44,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,0,80,114,111,106,95,66,76,77,95,49,55,78,95,102,101,101,116,0,0,0,0,0,0,0,61,0,0,0,0,0,0,0,80,114,111,106,95,66,76,77,95,49,54,78,95,102,101,101,116,0,0,0,0,0,0,0,99,108,117,115,116,101,114,95,116,105,109,101,95,108,105,109,105,116,0,0,0,0,0,0,71,88,70,32,40,71,101,110,101,114,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,73,110,118,97,108,105,100,32,116,114,97,99,107,32,110,117,109,98,101,114,32,37,100,10,0,0,0,0,0,0,0,0,80,114,111,106,95,66,76,77,95,49,53,78,95,102,101,101,116,0,0,0,0,0,0,0,83,72,73,70,84,0,0,0,80,114,111,106,95,66,76,77,95,49,52,78,95,102,101,101,116,0,0,0,0,0,0,0,49,54,99,105,102,0,0,0,71,88,70,32,40,71,101,110,101,114,97,108,32,101,88,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,99,111,110,116,105,110,117,111,117,115,108,121,32,111,118,101,114,119,114,105,116,101,32,111,110,101,32,102,105,108,101,0,80,114,111,106,95,80,117,101,114,116,111,95,82,105,99,111,95,86,105,114,103,105,110,95,73,115,0,0,0,0,0,0,71,67,83,95,83,101,114,105,110,100,117,110,103,0,0,0,112,105,99,45,115,116,114,117,99,116,0,0,0,0,0,0,97,99,95,118,108,99,0,0,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,101,120,105,116,32,111,110,32,101,114,114,111,114,0,0,0,114,97,119,32,71,83,77,0,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,118,105,100,101,111,0,0,0,0,0,0,0,0,109,112,103,50,45,105,109,103,0,0,0,0,0,0,0,0,80,114,111,106,95,83,116,95,67,114,111,105,120,0,0,0,109,97,114,107,101,114,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,102,95,99,111,100,101,10,0,0,0,80,114,111,106,95,80,117,101,114,116,111,95,82,105,99,111,95,67,83,50,55,0,0,0,112,107,103,45,99,111,110,102,105,103,32,0,0,0,0,0,67,111,109,112,117,83,101,114,118,101,32,71,114,97,112,104,105,99,115,32,73,110,116,101,114,99,104,97,110,103,101,32,70,111,114,109,97,116,32,40,71,73,70,41,0,0,0,0,84,80,69,50,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,53,0,0,0,0,0,0,104,108,115,32,109,117,120,101,114,0,0,0,0,0,0,0,58,47,47,0,0,0,0,0,9,9,60,109,101,116,97,100,97,116,97,62,37,115,60,47,109,101,116,97,100,97,116,97,62,10,0,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,52,0,0,0,0,0,0,115,116,105,107,0,0,0,0,71,73,70,32,65,110,105,109,97,116,105,111,110,0,0,0,63,0,0,0,0,0,0,0,118,105,100,101,111,32,115,116,114,101,97,109,32,109,117,115,116,32,98,101,32,116,104,101,32,102,105,114,115,116,32,116,114,97,99,107,10,0,0,0,78,111,32,70,80,83,32,116,114,97,99,107,32,116,97,103,44,32,117,115,105,110,103,32,85,77,70,32,102,112,115,32,116,97,103,46,32,84,104,105,115,32,109,105,103,104,116,32,103,105,118,101,32,119,114,111,110,103,32,114,101,115,117,108,116,115,46,10,0,0,0,0,71,46,55,50,57,32,114,97,119,32,102,111,114,109,97,116,32,100,101,109,117,120,101,114,0,0,0,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,51,0,0,0,0,0,0,71,46,55,50,51,46,49,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,50,0,0,0,0,0,0,116,101,120,116,0,0,0,0,114,97,119,32,71,46,55,50,50,0,0,0,0,0,0,0,100,97,116,97,115,116,114,101,97,109,0,0,0,0,0,0,77,101,103,97,108,117,120,32,70,114,97,109,101,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,56,51,95,49,0,0,0,0,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,115,97,109,112,108,101,95,114,97,116,101,32,40,101,108,101,109,101,110,116,32,48,120,56,52,41,32,115,101,116,32,116,111,32,37,105,10,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,53,0,0,0,0,0,0,102,114,97,109,101,99,114,99,32,116,101,115,116,105,110,103,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,52,0,0,0,0,0,0,99,111,110,99,97,116,32,100,101,109,117,120,101,114,0,0,52,99,105,102,0,0,0,0,115,101,103,109,101,110,116,0,69,114,114,111,114,32,119,104,105,108,101,32,102,105,108,116,101,114,105,110,103,46,10,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,51,0,0,0,0,0,0,71,67,83,95,83,101,103,111,114,97,0,0,0,0,0,0,102,105,108,108,101,114,0,0,97,109,118,0,0,0,0,0,97,117,116,104,111,114,0,0,120,101,114,114,111,114,0,0,97,118,115,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,50,0,0,0,0,0,0,80,114,111,106,95,72,97,119,97,105,105,95,67,83,50,55,95,49,0,0,0,0,0,0,112,107,103,45,99,111,110,102,105,103,126,0,0,0,0,0,65,86,73,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,62,37,100,32,115,116,114,101,97,109,115,10,0,0,0,0,0,0,0,108,111,111,112,101,110,100,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,49,48,0,0,0,0,0,112,97,99,107,101,116,95,104,100,114,95,115,105,122,101,32,60,61,32,97,115,102,45,62,112,97,99,107,101,116,95,115,105,122,101,95,108,101,102,116,0,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,57,0,0,0,0,0,0,115,101,97,115,111,110,95,110,117,109,98,101,114,0,0,0,97,115,102,95,115,116,0,0,32,32,83,116,114,101,97,109,32,35,37,100,58,37,100,32,40,37,115,41,32,45,62,32,37,115,0,0,0,0,0,0,70,76,86,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,56,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,55,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,54,0,0,0,0,0,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,53,0,0,0,0,0,0,112,116,115,0,0,0,0,0,70,76,86,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,52,0,0,0,0,0,0,100,101,102,97,117,108,116,0,67,104,97,110,110,101,108,32,109,97,112,32,100,101,115,99,114,105,98,101,115,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,105,110,112,117,116,32,99,104,97,110,110,101,108,46,10,0,0,0,0,0,99,105,102,0,0,0,0,0,70,76,73,47,70,76,67,47,70,76,88,32,97,110,105,109,97,116,105,111,110,0,0,0,115,101,116,32,105,110,105,116,105,97,108,32,118,111,108,117,109,101,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,51,0,0,0,0,0,0,71,67,83,95,83,99,104,119,97,114,122,101,99,107,0,0,110,97,108,45,104,114,100,0,112,97,100,100,105,110,103,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,41,0,0,0,0,0,0,116,105,109,101,115,116,97,109,112,32,101,114,114,111,114,32,100,101,108,116,97,32,116,104,114,101,115,104,111,108,100,0,90,105,112,32,77,111,116,105,111,110,32,66,108,111,99,107,115,32,86,105,100,101,111,0,98,105,113,117,97,100,0,0,114,97,119,32,70,76,65,67,0,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,50,0,0,0,0,0,0,109,112,99,56,0,0,0,0,105,110,50,0,0,0,0,0,114,97,119,32,70,76,65,67,0,0,0,0,0,0,0,0,108,101,110,103,116,104,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,56,51,95,49,0,0,0,0,0,0,126,45,45,0,0,0,0,0,105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,116,111,111,32,102,97,114,32,98,97,99,107,0,0,0,65,100,111,98,101,32,70,105,108,109,115,116,114,105,112,0,116,114,105,97,110,103,117,108,97,114,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,49,48,0,0,0,0,0,109,112,99,55,0,0,0,0,68,117,114,97,116,105,111,110,32,111,102,32,102,105,114,115,116,32,105,110,112,117,116,46,0,0,0,0,0,0,0,0,65,100,111,98,101,32,70,105,108,109,115,116,114,105,112,0,32,43,32,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,57,0,0,0,0,0,0,116,118,115,110,0,0,0,0,102,105,108,101,58,0,0,0,109,111,118,95,116,101,120,116,0,0,0,0,0,0,0,0,83,116,114,101,97,109,32,109,97,112,112,105,110,103,58,10,0,0,0,0,0,0,0,0,115,101,116,32,116,105,109,101,32,116,111,32,115,116,97,114,116,32,102,97,100,105,110,103,0,0,0,0,0,0,0,0,49,48,48,48,0,0,0,0,109,111,118,95,116,101,120,116,0,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,56,0,0,0,0,0,0,115,117,98,115,105,122,101,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,110,98,95,111,117,116,95,99,104,97,110,110,101,108,115,0,98,95,119,105,100,116,104,95,108,111,103,50,40,98,115,105,122,101,41,32,61,61,32,98,95,104,101,105,103,104,116,95,108,111,103,50,40,98,115,105,122,101,41,0,0,0,0,0,109,111,116,105,111,110,112,105,120,101,108,115,0,0,0,0,70,70,109,112,101,103,32,109,101,116,97,100,97,116,97,32,105,110,32,116,101,120,116,0,120,32,43,32,119,32,60,61,32,116,101,115,116,45,62,119,0,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,55,0,0,0,0,0,0,109,109,118,105,100,101,111,0,102,114,101,113,95,108,117,109,97,0,0,0,0,0,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,99,111,109,112,95,114,101,102,44,32,122,101,114,111,95,99,111,117,110,116,115,46,99,111,109,112,95,114,101,102,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,99,111,109,112,95,114,101,102,41,41,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,54,0,0,0,0,0,0,115,116,97,114,116,95,115,99,97,108,101,0,0,0,0,0,70,70,109,112,101,103,32,109,101,116,97,100,97,116,97,32,105,110,32,116,101,120,116,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,53,0,0,0,0,0,0,70,70,77,32,40,70,70,115,101,114,118,101,114,32,108,105,118,101,32,102,101,101,100,41,0,0,0,0,0,0,0,0,33,40,108,102,109,45,62,105,110,116,95,52,120,52,95,117,118,32,38,32,108,102,109,45,62,97,98,111,118,101,95,117,118,91,84,88,95,49,54,88,49,54,93,41,0,0,0,0,98,102,102,0,0,0,0,0,116,105,109,101,95,98,97,115,101,61,37,100,47,37,100,58,115,97,109,112,108,101,95,114,97,116,101,61,37,100,58,115,97,109,112,108,101,95,102,109,116,61,37,115,0,0,0,0,70,70,77,32,40,70,70,115,101,114,118,101,114,32,108,105,118,101,32,102,101,101,100,41,0,0,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,52,0,0,0,0,0,0,120,48,0,0,0,0,0,0,113,99,105,102,0,0,0,0,69,110,115,111,110,105,113,32,80,97,114,105,115,32,65,117,100,105,111,32,70,105,108,101,0,0,0,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,109,97,116,114,105,120,32,118,101,114,116,105,99,97,108,32,115,105,122,101,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,51,0,0,0,0,0,0,71,67,83,95,83,97,112,112,101,114,95,72,105,108,108,95,49,57,52,51,0,0,0,0,102,111,114,99,101,45,99,102,114,0,0,0,0,0,0,0,112,111,114,116,114,97,105,116,0,0,0,0,0,0,0,0,110,111,95,112,97,100,100,105,110,103,0,0,0,0,0,0,77,97,114,107,101,114,32,98,105,116,32,109,105,115,115,105,110,103,32,37,115,10,0,0,100,116,115,95,101,114,114,111,114,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,105,110,116,101,114,108,97,99,101,120,50,0,0,0,0,0,100,101,102,97,117,108,116,0,122,109,98,118,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,50,0,0,0,0,0,0,50,51,0,0,0,0,0,0,80,114,111,106,95,65,108,97,115,107,97,95,67,83,50,55,95,49,0,0,0,0,0,0,32,45,45,0,0,0,0,0,115,98,115,50,108,0,0,0,100,101,102,97,117,108,116,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,117,108,116,105,109,101,100,105,97,0,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,115,116,114,101,110,103,116,104,0,0,0,0,0,109,108,112,0,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,56,51,95,87,101,115,116,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,99,100,97,116,97,0,0,0,112,97,99,107,101,116,32,116,111,111,32,115,104,111,114,116,44,32,117,110,97,98,108,101,32,116,111,32,114,101,97,100,32,109,97,106,111,114,32,115,121,110,99,10,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,56,51,95,87,101,115,116,95,67,101,110,116,114,97,108,0,0,115,101,116,112,116,115,0,0,102,108,97,103,115,0,0,0,101,112,105,115,111,100,101,95,115,111,114,116,0,0,0,0,68,88,65,0,0,0,0,0,114,116,112,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,112,114,101,45,102,105,108,116,101,114,32,114,97,100,105,117,115,0,0,0,0,116,0,0,0,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,56,51,95,69,97,115,116,95,67,101,110,116,114,97,108,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,117,0,0,0,0,0,0,0,83,101,116,32,102,105,108,101,32,119,104,101,114,101,32,116,111,32,115,116,111,114,101,32,112,101,114,45,102,114,97,109,101,32,100,105,102,102,101,114,101,110,99,101,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,56,51,95,69,97,115,116,0,0,85,0,0,0,0,0,0,0,74,80,69,71,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,114,101,115,111,108,117,116,105,111,110,115,32,97,98,111,118,101,32,54,53,53,48,48,120,54,53,53,48,48,10,0,0,0,0,115,107,105,112,95,112,114,111,98,32,62,32,48,0,0,0,72,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,99,111,108,111,114,32,111,102,32,116,104,101,32,112,97,100,100,101,100,32,97,114,101,97,32,98,111,114,100,101,114,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,50,55,95,87,101,115,116,0,0,100,118,0,0,0,0,0,0,110,0,0,0,0,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,50,55,95,87,101,115,116,95,67,101,110,116,114,97,108,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,99,111,100,105,110,103,95,99,111,110,116,101,120,116,46,108,97,115,116,95,102,114,97,109,101,95,115,101,103,95,109,97,112,95,99,111,112,121,0,0,114,97,119,32,68,84,83,45,72,68,0,0,0,0,0,0,117,0,0,0,0,0,0,0,37,46,54,103,0,0,0,0,114,97,119,32,68,84,83,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,50,55,95,69,97,115,116,95,67,101,110,116,114,97,108,0,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,0,0,0,0,0,68,105,114,101,99,116,32,82,101,110,100,101,114,105,110,103,0,0,0,0,0,0,0,0,115,113,99,105,102,0,0,0,111,117,116,112,117,116,32,112,108,97,110,101,32,37,100,32,119,105,100,116,104,32,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,105,110,112,117,116,32,37,100,32,112,108,97,110,101,32,37,100,32,119,105,100,116,104,32,37,100,10,0,0,0,0,0,114,97,119,32,68,78,120,72,68,32,40,83,77,80,84,69,32,86,67,45,51,41,0,0,100,101,102,97,117,108,116,0,118,112,56,47,101,110,99,111,100,101,114,47,111,110,121,120,95,105,102,46,99,0,0,0,80,114,111,106,95,87,121,111,109,105,110,103,95,67,83,50,55,95,69,97,115,116,0,0,71,67,83,95,83,65,68,54,57,0,0,0,0,0,0,0,97,110,110,101,120,98,0,0,114,97,119,32,68,105,114,97,99,0,0,0,0,0,0,0,40,97,117,116,111,100,101,116,101,99,116,101,100,32,105,102,32,70,79,85,82,67,67,32,61,61,32,85,77,80,52,41,0,0,0,0,0,0,0,0,97,102,116,101,114,32,110,101,119,95,112,114,101,100,0,0,105,110,116,101,114,112,111,108,97,116,101,32,118,97,108,117,101,115,32,117,115,105,110,103,32,97,32,116,101,116,114,97,104,101,100,114,111,110,0,0,116,105,109,101,115,116,97,109,112,32,100,105,115,99,111,110,116,105,110,117,105,116,121,32,100,101,108,116,97,32,116,104,114,101,115,104,111,108,100,0,65,109,101,114,105,99,97,110,32,76,97,115,101,114,32,71,97,109,101,115,32,77,77,32,86,105,100,101,111,0,0,0,67,104,114,111,110,111,109,97,115,116,101,114,32,68,70,65,0,0,0,0,0,0,0,0,99,50,0,0,0,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,108,105,110,101,115,105,122,101,32,62,61,32,48,0,0,0,108,117,109,97,95,115,119,97,112,0,0,0,0,0,0,0,68,45,67,105,110,101,109,97,32,97,117,100,105,111,0,0,114,99,95,117,110,100,101,114,115,104,111,111,116,95,112,99,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,48,93,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,32,32,0,0,0,0,0,0,67,82,67,32,116,101,115,116,105,110,103,0,0,0,0,0,49,0,0,0,0,0,0,0,107,102,95,109,111,100,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,86,80,88,95,75,70,95,68,73,83,65,66,76,69,68,46,46,86,80,88,95,75,70,95,65,85,84,79,93,0,0,0,0,0,115,99,97,108,101,95,104,101,105,103,104,116,0,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,80,95,76,48,32,97,110,100,32,112,97,114,116,105,116,105,111,110,61,37,100,10,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,116,118,101,115,0,0,0,0,76,101,102,116,32,97,110,100,32,114,105,103,104,116,32,102,114,97,109,101,114,97,116,101,115,32,100,105,102,102,101,114,32,40,37,100,47,37,100,32,118,115,32,37,100,47,37,100,41,46,10,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,119,114,105,116,101,32,104,101,97,100,101,114,32,102,111,114,32,111,117,116,112,117,116,32,102,105,108,101,32,35,37,100,32,40,105,110,99,111,114,114,101,99,116,32,99,111,100,101,99,32,112,97,114,97,109,101,116,101,114,115,32,63,41,58,32,37,115,0,0,0,110,111,116,32,101,110,111,117,103,104,32,99,111,101,102,102,105,99,105,101,110,116,115,32,105,110,32,108,105,115,116,32,39,37,115,39,10,0,0,0,117,112,0,0,0,0,0,0,86,105,114,116,117,97,108,32,99,111,110,99,97,116,101,110,97,116,105,111,110,32,115,99,114,105,112,116,0,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,67,111,109,109,111,100,111,114,101,32,67,68,88,76,32,118,105,100,101,111,0,0,0,0,80,114,111,106,95,87,105,115,99,111,110,115,105,110,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,78,79,0,0,0,0,0,0,99,108,71,101,116,68,101,118,105,99,101,73,68,115,0,0,117,115,97,103,101,58,32,37,115,32,91,111,112,116,105,111,110,115,93,32,91,91,105,110,102,105,108,101,32,111,112,116,105,111,110,115,93,32,45,105,32,105,110,102,105,108,101,93,46,46,46,32,123,91,111,117,116,102,105,108,101,32,111,112,116,105,111,110,115,93,32,111,117,116,102,105,108,101,125,46,46,46,10,0,0,0,0,0,67,68,32,71,114,97,112,104,105,99,115,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,102,114,97,109,101,115,32,116,111,32,119,104,105,99,104,32,116,104,101,32,101,102,102,101,99,116,32,115,104,111,117,108,100,32,98,101,32,97,112,112,108,105,101,100,46,0,120,118,109,99,105,100,99,116,0,0,0,0,0,0,0,0,65,110,116,105,113,117,101,87,104,105,116,101,0,0,0,0,103,0,0,0,0,0,0,0,114,97,119,32,67,104,105,110,101,115,101,32,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,0,0,80,114,111,106,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,97,98,115,0,0,0,0,0,69,88,73,84,0,0,0,0,98,97,99,107,32,114,105,103,104,116,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,99,111,108,111,114,32,111,102,32,116,104,101,32,103,114,105,100,0,0,0,108,97,115,116,73,110,67,104,114,66,117,102,32,43,32,49,32,45,32,99,104,114,83,114,99,83,108,105,99,101,89,32,60,32,40,99,104,114,83,114,99,83,108,105,99,101,72,41,0,0,0,0,0,0,0,0,115,105,110,99,0,0,0,0,82,101,113,117,101,115,116,101,100,32,114,101,115,97,109,112,108,105,110,103,32,101,110,103,105,110,101,32,105,115,32,117,110,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,102,117,108,108,121,114,97,110,103,101,0,0,0,0,0,0,80,114,111,106,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,105,108,108,101,103,97,108,32,105,99,99,10,0,0,0,0,101,100,103,101,0,0,0,0,117,115,105,110,103,32,101,120,116,101,114,110,97,108,32,104,117,102,102,109,97,110,32,116,97,98,108,101,10,0,0,0,65,112,112,108,101,32,67,65,70,32,40,67,111,114,101,32,65,117,100,105,111,32,70,111,114,109,97,116,41,0,0,0,115,104,111,119,32,100,101,108,111,103,111,32,97,114,101,97,0,0,0,0,0,0,0,0,92,97,37,49,91,92,125,93,37,110,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,58,32,37,100,10,0,0,115,99,116,104,114,101,115,104,0,0,0,0,0,0,0,0,97,100,112,99,109,95,101,97,95,114,51,0,0,0,0,0,80,114,111,106,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,111,112,116,105,111,110,115,32,108,105,115,116,32,105,110,32,115,116,97,116,115,32,102,105,108,101,32,110,111,116,32,118,97,108,105,100,10,0,0,0,82,111,111,109,32,84,121,112,101,0,0,0,0,0,0,0,82,111,111,109,32,84,121,112,101,0,0,0,0,0,0,0,114,101,113,117,101,115,116,101,100,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,46,32,117,115,105,110,103,32,100,101,102,97,117,108,116,32,118,97,108,117,101,58,32,37,48,46,51,102,10,0,0,108,111,114,111,95,115,117,114,109,105,120,108,101,118,0,0,82,101,115,101,114,118,101,100,32,83,66,82,32,101,120,116,101,110,115,105,111,110,115,0,109,115,95,111,102,102,0,0,110,116,115,99,45,102,105,108,109,0,0,0,0,0,0,0,70,73,76,76,58,37,115,10,0,0,0,0,0,0,0,0,100,101,99,111,100,101,32,105,32,102,114,97,109,101,32,102,97,105,108,101,100,10,0,0,105,110,118,97,108,105,100,32,98,121,116,101,115,32,112,101,114,32,115,99,97,110,45,108,105,110,101,10,0,0,0,0,48,47,49,32,48,46,49,48,57,47,49,32,48,46,51,48,49,47,48,46,52,57,56,32,48,46,53,49,55,47,48,32,49,47,48,0,0,0,0,0,65,112,112,108,101,32,67,65,70,32,40,67,111,114,101,32,65,117,100,105,111,32,70,111,114,109,97,116,41,0,0,0,85,110,107,110,111,119,110,32,99,104,97,110,110,101,108,32,116,114,97,110,115,102,111,114,109,32,116,121,112,101,0,0,84,111,111,32,115,109,97,108,108,32,105,110,112,117,116,32,98,117,102,102,101,114,0,0,69,120,112,111,110,101,110,116,32,118,108,99,32,105,110,118,97,108,105,100,10,0,0,0,109,106,112,101,103,98,0,0,80,114,111,106,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,71,67,83,95,82,84,51,56,0,0,0,0,0,0,0,0,123,92,117,48,125,0,0,0,108,97,118,102,105,46,99,114,111,112,100,101,116,101,99,116,46,119,0,0,0,0,0,0,114,101,112,101,97,116,45,104,101,97,100,101,114,115,0,0,72,101,105,103,104,116,32,109,105,115,109,97,116,99,104,46,32,37,100,32,33,61,32,37,100,10,0,0,0,0,0,0,111,112,116,95,109,111,110,111,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,69,88,84,82,65,66,73,84,83,44,32,115,105,122,101,32,61,32,37,105,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,118,97,108,105,100,32,99,111,109,112,114,101,115,115,101,100,32,104,101,97,100,101,114,32,115,105,122,101,10,0,117,109,112,52,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,118,101,99,116,111,114,115,10,0,0,0,0,0,0,0,0,99,98,112,99,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,99,111,100,101,98,111,111,107,115,41,46,32,10,0,0,0,0,0,0,100,116,115,95,100,101,108,116,97,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,112,97,108,101,116,116,101,10,0,0,0,0,0,107,101,101,112,95,97,115,112,101,99,116,0,0,0,0,0,83,108,105,99,101,32,37,100,32,115,116,97,114,116,115,32,98,101,121,111,110,100,32,112,105,99,116,117,114,101,32,98,111,117,110,100,97,114,121,32,40,37,100,32,62,61,32,37,100,41,10,0,0,0,0,0,67,80,66,32,115,105,122,101,58,32,37,105,32,98,105,116,115,10,0,0,0,0,0,0,73,110,116,101,114,112,108,97,121,32,67,57,51,0,0,0,77,66,32,83,107,105,112,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,109,109,118,105,100,101,111,0,115,101,116,32,83,77,80,84,69,45,50,52,48,77,32,99,111,108,111,114,115,112,97,99,101,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,114,97,109,101,46,10,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,44,32,115,104,111,117,108,100,32,98,101,32,97,116,32,108,101,97,115,116,32,49,54,10,0,0,80,114,111,106,95,87,97,115,104,105,110,103,116,111,110,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,84,104,101,32,37,115,32,39,37,115,39,32,105,115,32,101,120,112,101,114,105,109,101,110,116,97,108,32,98,117,116,32,101,120,112,101,114,105,109,101,110,116,97,108,32,99,111,100,101,99,115,32,97,114,101,32,110,111,116,32,101,110,97,98,108,101,100,44,32,97,100,100,32,39,45,115,116,114,105,99,116,32,37,100,39,32,105,102,32,121,111,117,32,119,97,110,116,32,116,111,32,117,115,101,32,105,116,46,10,0,0,0,103,97,0,0,0,0,0,0,83,101,116,32,100,101,99,111,100,105,110,103,32,112,97,115,115,119,111,114,100,0,0,0,67,97,110,110,111,116,32,98,117,105,108,100,32,86,76,67,32,116,97,98,108,101,10,0,32,73,78,84,69,82,80,79,76,0,0,0,0,0,0,0,114,97,119,0,0,0,0,0,103,104,0,0,0,0,0,0,97,108,112,104,97,95,114,97,100,105,117,115,0,0,0,0,80,114,111,106,95,87,97,115,104,105,110,103,116,111,110,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,99,109,100,117,116,105,108,115,46,99,0,0,0,0,0,0,66,82,83,84,77,32,40,66,105,110,97,114,121,32,82,101,118,111,108,117,116,105,111,110,32,83,116,114,101,97,109,41,0,0,0,0,0,0,0,0,71,101,111,103,80,114,105,109,101,77,101,114,105,100,105,97,110,76,111,110,103,71,101,111,75,101,121,0,0,0,0,0,82,117,110,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,99,104,114,111,109,97,32,97,99,32,98,108,111,99,107,10,0,0,0,60,102,111,110,116,32,99,111,108,111,114,61,34,35,37,48,54,120,34,62,0,0,0,0,115,105,122,101,61,0,0,0,109,101,109,99,95,111,110,108,121,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,109,105,109,105,99,0,0,0,110,111,32,102,109,116,32,99,104,117,110,107,32,102,111,117,110,100,10,0,0,0,0,0,66,108,97,99,107,32,79,112,115,32,65,117,100,105,111,0,100,105,109,101,110,115,105,111,110,115,32,97,114,101,32,105,110,118,97,108,105,100,10,0,109,111,100,101,0,0,0,0,73,110,118,97,108,105,100,32,113,115,99,97,108,101,32,118], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2504864);
/* memory initializer */ allocate([97,108,117,101,58,32,48,10,0,0,0,0,0,0,0,0,80,114,111,106,95,87,97,115,104,105,110,103,116,111,110,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,97,118,103,73,73,84,101,120,0,0,0,0,0,0,0,0,105,110,100,101,120,32,37,100,32,111,117,116,32,111,102,32,116,121,112,101,51,52,95,100,101,108,116,97,32,97,114,114,97,121,10,0,0,0,0,0,102,114,97,109,101,58,37,108,108,100,32,112,105,99,116,117,114,101,95,98,108,97,99,107,95,114,97,116,105,111,58,37,102,32,112,116,115,58,37,115,32,116,58,37,115,32,116,121,112,101,58,37,99,10,0,0,80,114,111,82,101,115,32,101,110,99,111,100,101,114,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,58,32,37,100,10,0,117,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,58,32,37,100,10,0,0,0,0,0,0,0,0,37,46,54,103,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,119,0,0,0,0,0,0,0,80,114,111,106,95,87,97,115,104,105,110,103,116,111,110,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,108,111,111,107,97,104,101,97,100,45,116,104,114,101,97,100,115,0,0,0,0,0,0,0,110,101,116,119,111,114,107,0,112,107,116,95,115,105,122,101,0,0,0,0,0,0,0,0,115,116,97,114,116,0,0,0,84,104,101,32,98,105,116,114,97,116,101,32,112,97,114,97,109,101,116,101,114,32,105,115,32,115,101,116,32,116,111,111,32,108,111,119,46,32,73,116,32,116,97,107,101,115,32,98,105,116,115,47,115,32,97,115,32,97,114,103,117,109,101,110,116,44,32,110,111,116,32,107,98,105,116,115,47,115,10,0,83,108,105,99,101,32,115,112,108,105,116,32,37,100,10,0,71,46,55,50,57,32,66,73,84,32,102,105,108,101,32,102,111,114,109,97,116,0,0,0,83,105,109,117,108,97,116,101,32,101,114,114,111,114,115,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,32,116,111,32,116,101,115,116,32,101,114,114,111,114,32,99,111,110,99,101,97,108,109,101,110,116,46,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,115,116,97,114,116,32,97,32,102,114,97,109,101,32,111,117,116,115,105,100,101,32,83,69,84,85,80,32,115,116,97,116,101,10,0,0,0,115,0,0,0,0,0,0,0,80,114,111,106,95,86,105,114,103,105,110,105,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,102,114,97,109,101,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,101,120,99,101,101,100,115,32,99,111,100,101,99,32,99,104,97,110,110,101,108,32,99,111,117,110,116,10,0,0,0,0,0,0,0,0,102,114,97,109,101,32,99,104,97,110,110,101,108,32,99,111,117,110,116,32,101,120,99,101,101,100,115,32,99,111,100,101,99,32,99,104,97,110,110,101,108,32,99,111,117,110,116,10,0,0,0,0,0,0,0,0,109,105,99,114,111,100,118,100,0,0,0,0,0,0,0,0,83,116,114,105,99,116,108,121,32,101,110,102,111,114,99,101,32,103,111,112,32,115,105,122,101,0,0,0,0,0,0,0,82,101,115,101,114,118,101,32,115,112,97,99,101,32,102,111,114,32,83,86,67,68,32,115,99,97,110,32,111,102,102,115,101,116,32,117,115,101,114,32,100,97,116,97,46,0,0,0,70,82,65,77,69,95,82,65,84,69,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,83,69,81,95,83,84,65,82,84,95,67,79,68,69,32,97,102,116,101,114,32,37,88,10,0,0,0,0,0,0,0,78,111,32,115,97,109,112,108,101,115,32,116,111,32,111,117,116,112,117,116,46,10,0,0,112,114,111,103,114,101,115,115,105,118,101,108,121,32,99,111,100,101,100,32,105,110,116,101,114,108,97,99,101,100,32,112,105,99,116,117,114,101,0,0,115,99,97,108,101,0,0,0,81,80,58,32,37,100,10,0,123,92,112,111,115,40,37,100,44,37,100,41,125,0,0,0,80,114,111,106,95,86,105,114,103,105,110,105,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,70,105,108,101,110,97,109,101,32,102,111,114,32,50,32,112,97,115,115,32,115,116,97,116,115,0,0,0,0,0,0,0,85,115,105,110,103,32,100,101,97,100,108,105,110,101,58,32,37,100,10,0,0,0,0,0,67,111,100,101,99,32,105,100,32,97,110,100,32,99,111,100,101,99,32,116,121,112,101,32,109,105,115,109,97,116,99,104,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,0,0,66,108,111,99,107,32,108,101,110,103,116,104,32,37,100,32,111,114,32,108,101,110,103,116,104,105,110,99,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,123,92,97,110,57,125,0,0,108,105,98,97,118,99,111,100,101,99,47,105,118,105,95,99,111,109,109,111,110,46,99,0,69,120,116,101,110,100,101,100,32,116,114,97,110,115,102,111,114,109,32,105,110,102,111,0,81,117,97,110,116,105,122,97,116,105,111,110,32,109,97,116,114,105,120,32,37,100,0,0,77,111,100,101,32,37,100,58,32,82,76,69,45,70,66,32,105,110,118,97,108,105,100,32,99,111,117,110,116,101,114,58,32,37,100,10,0,0,0,0,117,110,107,110,111,119,110,32,98,105,116,115,95,112,101,114,95,99,111,100,101,100,95,115,97,109,112,108,101,0,0,0,69,114,114,111,114,58,32,112,101,114,45,102,114,97,109,101,32,104,117,102,102,109,97,110,32,116,97,98,108,101,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,104,117,102,102,121,117,118,59,32,117,115,101,32,118,99,111,100,101,99,61,102,102,118,104,117,102,102,10,0,0,0,0,0,0,0,80,114,111,106,95,86,105,114,103,105,110,105,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,79,110,108,121,32,111,110,101,32,111,102,32,116,104,101,32,102,105,108,101,110,97,109,101,32,111,114,32,99,111,109,109,97,110,100,115,32,111,112,116,105,111,110,115,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,58,32,37,100,10,0,0,0,0,0,0,69,114,114,111,114,32,99,111,110,115,116,114,117,99,116,105,110,103,32,116,104,101,32,114,101,102,101,114,101,110,99,101,32,108,105,115,116,115,32,102,111,114,32,116,104,101,32,99,117,114,114,101,110,116,32,115,108,105,99,101,46,10,0,0,83,69,73,32,70,80,65,32,37,100,32,37,100,32,37,100,32,37,100,32,37,100,32,37,100,10,0,0,0,0,0,0,109,109,99,111,58,32,99,97,110,110,111,116,32,97,115,115,105,103,110,32,99,117,114,114,101,110,116,32,112,105,99,116,117,114,101,32,116,111,32,115,104,111,114,116,32,97,110,100,32,108,111,110,103,32,97,116,32,116,104,101,32,115,97,109,101,32,116,105,109,101,10,0,77,66,45,65,70,70,0,0,81,50,54,52,0,0,0,0,112,114,101,118,95,115,101,108,101,99,116,101,100,95,116,0,66,105,110,97,114,121,32,116,101,120,116,0,0,0,0,0,101,80,73,67,32,106,45,98,32,99,111,109,112,114,101,115,115,105,111,110,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,32,121,101,116,10,0,0,0,0,80,114,111,106,95,86,105,114,103,105,110,105,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,85,110,100,101,102,105,110,101,100,32,111,112,99,111,100,101,32,40,37,120,41,32,105,110,32,68,69,76,84,65,95,70,76,73,10,0,0,0,0,0,37,100,120,37,100,32,122,108,105,98,112,114,105,109,101,95,112,114,101,118,10,0,0,0,115,101,101,100,0,0,0,0,32,108,112,99,32,116,121,112,101,58,32,78,111,110,101,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,119,97,115,116,101,100,32,98,105,116,115,32,62,32,97,118,97,105,108,97,98,108,101,32,98,105,116,115,32,40,37,100,41,32,45,32,108,101,102,116,61,37,100,10,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,32,62,32,56,44,32,102,111,114,99,105,110,103,32,99,111,100,101,114,32,49,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,103,101,32,111,102,32,103,108,111,98,97,108,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,66,0,0,0,0,0,0,0,78,79,80,84,83,32,118,97,108,117,101,32,102,111,114,32,105,110,112,117,116,32,102,114,97,109,101,32,99,97,110,110,111,116,32,98,101,32,97,99,99,101,112,116,101,100,44,32,102,114,97,109,101,32,100,105,115,99,97,114,100,101,100,10,0,0,0,0,0,0,0,0,83,109,97,108,108,32,82,111,111,109,0,0,0,0,0,0,110,105,116,114,105,115,95,99,111,109,112,97,116,0,0,0,99,111,100,101,98,108,111,99,107,32,119,105,100,116,104,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,100,102,97,46,99,0,0,0,0,0,0,0,0,78,111,116,32,105,109,112,108,101,109,101,110,116,101,100,33,10,0,0,0,0,0,0,0,83,84,69,82,69,79,10,0,80,114,111,106,95,86,101,114,109,111,110,116,95,67,83,56,51,0,0,0,0,0,0,0,109,101,116,97,115,111,117,110,100,0,0,0,0,0,0,0,66,105,110,107,0,0,0,0,102,105,108,109,0,0,0,0,109,106,112,101,103,98,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,115,32,112,114,111,118,105,100,101,100,46,10,0,0,0,115,116,114,105,112,95,110,117,109,98,101,114,95,97,100,97,112,116,105,118,105,116,121,0,68,105,109,101,110,115,105,111,110,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,112,97,108,101,116,116,101,32,100,111,101,115,110,39,116,32,102,105,116,32,105,110,32,112,97,99,107,101,116,10,0,0,66,114,117,116,101,32,70,111,114,99,101,32,38,32,73,103,110,111,114,97,110,99,101,0,80,114,111,106,95,86,101,114,109,111,110,116,95,67,83,50,55,0,0,0,0,0,0,0,71,67,83,95,65,109,101,114,115,102,111,111,114,116,0,0,78,111,114,109,97,108,32,115,116,101,114,101,111,32,100,101,116,101,99,116,101,100,46,10,0,0,0,0,0,0,0,0,103,108,111,98,97,108,45,104,101,97,100,101,114,0,0,0,99,104,97,110,110,101,108,95,99,111,117,110,116,115,0,0,67,111,109,112,114,101,115,115,105,111,110,32,76,101,118,101,108,58,32,37,100,32,45,32,70,108,97,103,115,58,32,37,100,10,0,0,0,0,0,0,65,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,32,109,101,109,111,114,121,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,0,88,118,105,100,32,105,110,116,101,114,108,97,99,105,110,103,32,98,117,103,32,40,97,117,116,111,100,101,116,101,99,116,101,100,32,105,102,32,70,79,85,82,67,67,32,61,61,32,88,86,73,88,41,0,0,0,109,100,101,99,0,0,0,0,80,32,99,98,112,121,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,117,115,101,115,0,0,0,0,97,110,97,103,108,121,112,104,95,103,114,101,101,110,95,109,97,103,101,110,116,97,0,0,97,117,100,105,111,32,112,97,100,0,0,0,0,0,0,0,82,101,103,103,97,101,0,0,87,77,47,76,97,110,103,117,97,103,101,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,67,97,109,83,116,117,100,105,111,0,0,0,0,0,0,0,66,101,116,104,101,115,100,97,32,83,111,102,116,119,111,114,107,115,32,86,73,68,0,0,97,114,101,115,97,109,112,108,101,0,0,0,0,0,0,0,52,52,52,112,49,50,0,0,67,117,115,116,111,109,32,65,86,73,79,67,111,110,116,101,120,116,32,109,97,107,101,115,32,110,111,32,115,101,110,115,101,32,97,110,100,32,119,105,108,108,32,98,101,32,105,103,110,111,114,101,100,32,119,105,116,104,32,65,86,70,77,84,95,78,79,70,73,76,69,32,102,111,114,109,97,116,46,10,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,95,105,100,32,40,48,120,37,120,41,10,0,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,87,77,47,77,101,100,105,97,84,104,117,109,98,84,121,112,101,0,0,0,0,0,0,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,115,32,107,105,110,100,0,0,0,37,115,32,99,111,100,101,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,87,65,86,69,32,102,111,114,109,97,116,10,0,0,102,111,117,110,100,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,39,102,109,116,32,39,32,116,97,103,10,0,97,117,116,104,111,114,0,0,78,111,109,105,110,97,108,66,105,116,114,97,116,101,0,0,65,86,83,0,0,0,0,0,115,116,45,62,114,101,113,117,101,115,116,95,112,114,111,98,101,32,60,61,32,48,0,0,83,108,97,118,101,32,39,37,115,39,58,32,101,114,114,111,114,32,119,114,105,116,105,110,103,32,104,101,97,100,101,114,58,32,37,115,10,0,0,0,116,101,100,99,97,112,116,105,111,110,115,95,100,101,109,117,120,101,114,0,0,0,0,0,37,115,0,0,0,0,0,0,70,87,83,0,0,0,0,0,87,114,111,110,103,32,77,80,69,71,32,102,105,108,101,32,102,111,114,109,97,116,10,0,65,86,82,32,40,65,117,100,105,111,32,86,105,115,117,97,108,32,82,101,115,101,97,114,99,104,41,0,0,0,0,0,60,81,117,97,108,105,116,121,76,101,118,101,108,32,73,110,100,101,120,61,34,37,100,34,32,66,105,116,114,97,116,101,61,34,37,100,34,32,70,111,117,114,67,67,61,34,37,115,34,32,83,97,109,112,108,105,110,103,82,97,116,101,61,34,37,100,34,32,67,104,97,110,110,101,108,115,61,34,37,100,34,32,66,105,116,115,80,101,114,83,97,109,112,108,101,61,34,49,54,34,32,80,97,99,107,101,116,83,105,122,101,61,34,37,100,34,32,65,117,100,105,111,84,97,103,61,34,37,100,34,32,67,111,100,101,99,80,114,105,118,97,116,101,68,97,116,97,61,34,37,115,34,32,47,62,10,0,0,0,0,50,53,0,0,0,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,105,32,61,61,32,110,98,95,99,111,100,101,99,115,0,0,80,114,111,106,95,85,116,97,104,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,109,97,99,101,51,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,32,10,9,0,0,0,0,0,116,118,110,110,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,111,112,101,110,105,110,103,32,101,110,99,111,100,101,114,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,32,45,32,109,97,121,98,101,32,105,110,99,111,114,114,101,99,116,32,112,97,114,97,109,101,116,101,114,115,32,115,117,99,104,32,97,115,32,98,105,116,95,114,97,116,101,44,32,114,97,116,101,44,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,0,0,0,0,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,85,116,97,104,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,83,111,117,116,104,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,83,111,117,116,104,95,67,101,110,116,114,97,108,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,67,101,110,116,114,97,108,0,115,112,97,108,0,0,0,0,108,111,99,111,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,78,111,114,116,104,95,67,101,110,116,114,97,108,0,0,0,71,67,83,95,76,111,109,97,95,81,117,105,110,116,97,110,97,0,0,0,0,0,0,0,115,112,115,45,105,100,0,0,73,110,118,97,105,100,32,85,84,70,56,32,115,101,113,117,101,110,99,101,32,105,110,32,97,118,105,111,95,112,117,116,95,115,116,114,49,54,108,101,10,0,0,0,0,0,0,0,120,118,105,100,95,105,108,97,99,101,0,0,0,0,0,0,68,67,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,114,99,95,105,110,105,116,95,111,99,99,117,112,97,110,99,121,0,0,0,0,0,0,0,97,112,97,100,0,0,0,0,108,106,112,101,103,0,0,0,99,115,99,100,0,0,0,0,80,114,111,98,101,32,119,105,116,104,32,115,105,122,101,61,37,100,44,32,112,97,99,107,101,116,115,61,37,100,32,100,101,116,101,99,116,101,100,32,37,115,32,119,105,116,104,32,115,99,111,114,101,61,37,100,10,0,0,0,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,56,51,95,78,111,114,116,104,0,0,0,102,105,108,101,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,83,111,117,116,104,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,97,114,115,105,110,103,32,97,32,103,114,111,117,112,32,111,102,32,111,112,116,105,111,110,115,58,32,37,115,32,37,115,46,10,0,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,83,111,117,116,104,95,67,101,110,116,114,97,108,0,0,0,97,108,108,111,119,32,108,105,115,116,32,99,97,99,104,105,110,103,0,0,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,67,101,110,116,114,97,108,0,115,114,116,112,95,111,117,116,95,112,97,114,97,109,115,0,101,112,105,115,111,100,101,95,105,100,0,0,0,0,0,0,97,117,116,111,0,0,0,0,116,104,101,32,101,110,100,32,111,102,32,108,105,110,101,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,78,111,114,116,104,95,67,101,110,116,114,97,108,0,0,0,65,86,73,32,40,65,117,100,105,111,32,86,105,100,101,111,32,73,110,116,101,114,108,101,97,118,101,100,41,0,0,0,108,97,116,109,0,0,0,0,80,114,111,106,95,84,101,120,97,115,95,67,83,50,55,95,78,111,114,116,104,0,0,0,78,114,46,32,111,102,32,112,97,99,107,101,116,115,32,105,110,32,112,97,99,107,101,116,32,105,110,100,101,120,32,102,111,114,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,32,101,120,99,101,101,100,115,32,102,105,108,101,115,105,122,101,32,40,37,108,108,100,32,97,116,32,37,108,108,100,32,61,32,37,108,108,100,41,10,0,0,0,0,0,0,97,108,98,117,109,0,0,0,80,114,111,106,95,84,101,110,110,101,115,115,101,101,95,67,83,56,51,0,0,0,0,0,115,101,116,32,99,104,97,110,110,101,108,32,99,111,108,111,114,105,110,103,0,0,0,0,80,114,111,106,95,84,101,110,110,101,115,115,101,101,95,67,83,50,55,0,0,0,0,0,100,116,115,0,0,0,0,0,115,104,110,0,0,0,0,0,80,114,111,106,95,83,111,117,116,104,95,68,97,107,111,116,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,115,110,116,115,99,0,0,0,83,87,82,0,0,0,0,0,65,86,73,32,40,65,117,100,105,111,32,86,105,100,101,111,32,73,110,116,101,114,108,101,97,118,101,100,41,0,0,0,80,114,111,106,95,83,111,117,116,104,95,68,97,107,111,116,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,71,67,83,95,81,111,114,110,111,113,0,0,0,0,0,0,97,117,100,0,0,0,0,0,115,111,109,101,32,111,108,100,32,108,97,118,99,45,103,101,110,101,114,97,116,101,100,32,77,83,77,80,69,71,52,118,51,32,102,105,108,101,115,32,40,110,111,32,97,117,116,111,100,101,116,101,99,116,105,111,110,41,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,73,32,99,98,112,121,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,43,99,103,111,112,0,0,0,118,0,0,0,0,0,0,0,102,105,110,105,115,104,32,101,110,99,111,100,105,110,103,32,119,105,116,104,105,110,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,0,0,0,66,77,80,32,40,87,105,110,100,111,119,115,32,97,110,100,32,79,83,47,50,32,98,105,116,109,97,112,41,0,0,0,109,112,101,103,118,105,100,101,111,0,0,0,0,0,0,0,80,114,111,106,95,83,111,117,116,104,95,68,97,107,111,116,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,83,117,110,32,65,85,0,0,80,114,111,106,95,83,111,117,116,104,95,68,97,107,111,116,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,110,111,102,105,108,108,105,110,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,105,110,32,101,110,99,114,121,112,116,105,111,110,32,104,101,97,100,101,114,10,0,0,0,80,114,111,106,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,67,83,56,51,0,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,65,83,84,32,40,65,117,100,105,111,32,83,116,114,101,97,109,41,0,0,0,0,0,0,80,114,111,106,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,67,83,50,55,95,83,111,117,116,104,0,0,116,118,101,110,0,0,0,0,112,97,103,101,95,100,117,114,97,116,105,111,110,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,111,103,103,100,101,99,46,99,0,0,0,0,116,104,114,101,97,100,115,0,65,83,84,32,40,65,117,100,105,111,32,83,116,114,101,97,109,41,0,0,0,0,0,0,80,97,108,101,116,116,101,0,80,114,111,106,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,95,67,83,50,55,95,78,111,114,116,104,0,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,115,121,110,99,105,110,103,32,102,114,111,109,32,37,108,108,100,10,0,0,0,0,0,0,80,114,111,106,95,82,104,111,100,101,95,73,115,108,97,110,100,95,67,83,56,51,0,0,49,48,0,0,0,0,0,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,0,0,0,0,0,80,114,111,106,95,82,104,111,100,101,95,73,115,108,97,110,100,95,67,83,50,55,0,0,108,105,98,120,50,54,52,0,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,104,101,97,100,101,114,32,112,97,114,116,105,116,105,111,110,32,112,97,99,107,32,107,101,121,10,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,80,114,111,106,95,80,101,110,110,115,121,108,118,97,110,105,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,82,101,99,101,105,118,101,100,32,97,32,112,97,99,107,101,116,32,102,111,114,32,97,110,32,97,116,116,97,99,104,109,101,110,116,32,115,116,114,101,97,109,46,10,0,0,0,0,65,83,70,32,40,65,100,118,97,110,99,101,100,32,47,32,65,99,116,105,118,101,32,83,116,114,101,97,109,105,110,103,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,0,80,114,111,106,95,80,101,110,110,115,121,108,118,97,110,105,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,65,65,67,32,98,105,116,115,116,114,101,97,109,32,110,111,116,32,105,110,32,65,68,84,83,32,102,111,114,109,97,116,32,97,110,100,32,101,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,10,0,108,101,0,0,0,0,0,0,113,112,97,108,0,0,0,0,115,101,116,32,115,119,114,32,110,117,109,98,101,114,32,111,102,32,111,117,116,112,117,116,32,115,97,109,112,108,101,32,98,105,116,115,0,0,0,0,85,110,97,98,108,101,32,116,111,32,115,101,101,107,32,98,97,99,107,32,116,111,32,116,104,101,32,115,116,97,114,116,10,0,0,0,0,0,0,0,80,114,111,106,95,80,101,110,110,115,121,108,118,97,110,105,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,71,67,83,95,81,97,116,97,114,95,49,57,52,56,0,0,115,115,105,109,0,0,0,0,73,110,105,116,105,97,108,32,100,101,109,117,120,45,100,101,99,111,100,101,32,100,101,108,97,121,32,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,46,0,0,0,0,0,111,108,100,95,109,115,109,112,101,103,52,0,0,0,0,0,99,98,112,121,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,102,108,97,103,115,0,0,0,105,100,58,0,0,0,0,0,98,109,112,0,0,0,0,0,80,114,111,106,95,80,101,110,110,115,121,108,118,97,110,105,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,109,52,118,0,0,0,0,0,110,95,102,111,114,99,101,100,0,0,0,0,0,0,0,0,65,117,100,105,111,32,112,97,99,107,101,116,32,111,102,32,115,105,122,101,32,37,100,32,40,115,116,97,114,116,105,110,103,32,119,105,116,104,32,37,48,56,88,46,46,46,41,32,105,115,32,105,110,118,97,108,105,100,44,32,119,114,105,116,105,110,103,32,105,116,32,97,110,121,119,97,121,46,10,0,80,114,111,106,95,79,114,101,103,111,110,95,67,83,56,51,95,83,111,117,116,104,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,80,114,111,106,95,79,114,101,103,111,110,95,67,83,56,51,95,78,111,114,116,104,0,0,80,114,111,106,95,79,114,101,103,111,110,95,67,83,50,55,95,83,111,117,116,104,0,0,115,104,111,119,0,0,0,0,80,83,80,32,77,80,52,32,40,77,80,69,71,45,52,32,80,97,114,116,32,49,52,41,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,119,114,105,116,101,32,108,111,103,32,102,105,108,101,32,39,37,115,39,32,102,111,114,32,112,97,115,115,45,49,32,101,110,99,111,100,105,110,103,58,32,37,115,10,0,0,0,0,0,80,114,111,106,95,79,114,101,103,111,110,95,67,83,50,55,95,78,111,114,116,104,0,0,65,83,70,32,40,65,100,118,97,110,99,101,100,32,47,32,65,99,116,105,118,101,32,83,116,114,101,97,109,105,110,103,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,0,117,115,101,95,97,98,115,111,108,117,116,101,95,112,97,116,104,0,0,0,0,0,0,0,65,119,97,1,0,0,0,0,80,114,111,106,95,79,107,108,97,104,111,109,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,65,81,84,105,116,108,101,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,0,115,101,116,32,104,97,115,104,32,116,111,32,117,115,101,0,80,114,111,106,95,79,107,108,97,104,111,109,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,83,116,111,114,101,32,97,116,32,109,111,115,116,32,116,104,101,32,112,114,111,118,105,100,101,100,32,97,109,111,117,110,116,32,111,102,32,98,121,116,101,115,32,105,110,32,97,32,99,108,117,115,116,101,114,46,32,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,116,97,103,32,118,101,114,115,105,111,110,46,32,40,62,61,37,100,41,10,0,0,0,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,97,116,114,111,115,107,97,100,101,99,46,99,0,0,0,0,0,0,0,80,114,111,106,95,79,107,108,97,104,111,109,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,86,66,73,32,100,97,116,97,32,110,111,116,32,121,101,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,77,111,110,107,101,121,39,115,32,65,117,100,105,111,0,0,82,65,77,80,0,0,0,0,80,114,111,106,95,79,107,108,97,104,111,109,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,67,82,89,79,32,65,80,67,0,0,0,0,0,0,0,0,37,115,37,115,0,0,0,0,113,110,116,115,99,0,0,0,111,117,116,112,117,116,95,115,97,109,112,108,101,95,98,105,116,115,0,0,0,0,0,0,117,112,100,97,116,101,102,105,114,115,116,0,0,0,0,0,68,101,108,117,120,101,32,80,97,105,110,116,32,65,110,105,109,97,116,105,111,110,0,0,80,114,111,106,95,79,104,105,111,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,71,67,83,95,81,97,116,97,114,0,0,0,0,0,0,0,112,115,110,114,0,0,0,0,97,117,116,111,100,101,116,101,99,116,0,0,0,0,0,0,115,101,108,101,99,116,32,103,108,111,98,32,112,97,116,116,101,114,110,32,116,121,112,101,0,0,0,0,0,0,0,0,114,118,108,99,32,0,0,0,116,104,114,101,97,100,95,116,121,112,101,0,0,0,0,0,109,111,100,101,0,0,0,0,51,71,80,80,32,65,77,82,0,0,0,0,0,0,0,0,68,117,99,107,32,84,114,117,101,77,111,116,105,111,110,32,50,46,48,0,0,0,0,0,109,112,103,49,45,105,109,103,0,0,0,0,0,0,0,0,108,111,97,115,0,0,0,0,80,114,111,106,95,79,104,105,111,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,80,114,111,106,95,79,104,105,111,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,37,115,32,0,0,0,0,0,108,105,98,118,112,120,0,0,97,114,116,105,115,116,0,0,80,114,111,106,95,79,104,105,111,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,109,112,101,103,116,115,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,107,101,121,32,102,105,108,101,32,37,115,10,0,0,0,0,0,108,105,98,118,112,120,0,0,9,60,109,101,100,105,97,32,98,105,116,114,97,116,101,61,34,37,100,34,32,117,114,108,61,34,115,116,114,101,97,109,37,100,34,32,98,111,111,116,115,116,114,97,112,73,110,102,111,73,100,61,34,98,111,111,116,115,116,114,97,112,37,100,34,62,10,0,0,0,0,0,80,114,111,106,95,78,111,114,116,104,95,68,97,107,111,116,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,116,118,115,104,0,0,0,0,111,110,108,121,32,109,111,110,111,32,116,114,97,99,107,115,32,97,114,101,32,97,108,108,111,119,101,100,10,0,0,0,119,98,0,0,0,0,0,0,115,121,110,99,32,108,111,115,116,32,105,110,32,104,101,97,100,101,114,10,0,0,0,0,80,114,111,106,95,78,111,114,116,104,95,68,97,107,111,116,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,70,111,114,99,101,32,100,101,108,97,121,32,40,105,110,32,99,101,110,116,105,115,101,99,111,110,100,115,41,32,97,102,116,101,114,32,116,104,101,32,108,97,115,116,32,102,114,97,109,101,0,0,0,0,0,0,122,108,105,98,0,0,0,0,80,114,111,106,95,78,111,114,116,104,95,68,97,107,111,116,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,84,101,120,116,0,0,0,0,97,117,100,105,111,100,97,116,97,114,97,116,101,0,0,0,80,114,111,106,95,78,111,114,116,104,95,68,97,107,111,116,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,95,116,121,112,101,32,40,101,108,101,109,101,110,116,32,48,120,56,51,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,80,114,111,106,95,78,111,114,116,104,95,67,97,114,111,108,105,110,97,95,67,83,56,51,0,0,0,0,0,0,0,0,80,114,111,106,95,78,111,114,116,104,95,67,97,114,111,108,105,110,97,95,67,83,50,55,0,0,0,0,0,0,0,0,102,102,99,111,110,99,97,116,32,118,101,114,115,105,111,110,32,49,46,48,0,0,0,0,98,103,114,51,50,0,0,0,112,97,108,0,0,0,0,0,115,101,116,32,115,119,114,32,75,97,105,115,101,114,32,87,105,110,100,111,119,32,66,101,116,97,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,56,51,95,76,111,110,103,95,73,115,108,97,110,100,0,0,71,67,83,95,80,117,108,107,111,118,111,95,49,57,52,50,0,0,0,0,0,0,0,0,37,117,44,37,117,44,37,117,44,37,117,0,0,0,0,0,78,111,32,109,111,114,101,32,111,117,116,112,117,116,32,115,116,114,101,97,109,115,32,116,111,32,119,114,105,116,101,32,116,111,44,32,102,105,110,105,115,104,105,110,103,46,10,0,119,111,114,107,32,97,114,111,117,110,100,32,110,111,116,32,97,117,116,111,100,101,116,101,99,116,101,100,32,101,110,99,111,100,101,114,32,98,117,103,115,0,0,0,0,0,0,0,112,97,114,116,105,116,105,111,110,32,0,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,116,104,114,101,97,100,115,0,109,115,122,104,0,0,0,0,99,111,112,121,32,105,110,112,117,116,32,115,116,114,101,97,109,32,116,105,109,101,32,98,97,115,101,32,119,104,101,110,32,115,116,114,101,97,109,32,99,111,112,121,105,110,103,0,116,114,117,101,109,111,116,105,111,110,50,0,0,0,0,0,104,101,118,99,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,56,51,95,87,101,115,116,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,32,40,37,115,58,32,0,0,82,73,70,70,0,0,0,0,108,97,103,97,114,105,116,104,0,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,56,51,95,69,97,115,116,0,76,111,111,112,115,116,97,114,116,32,112,111,115,105,116,105,111,110,32,105,110,32,109,105,108,108,105,115,101,99,111,110,100,115,46,0,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,115,102,101,110,99,46,99,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,50,55,95,76,111,110,103,95,73,115,108,97,110,100,0,0,115,121,110,111,112,115,105,115,0,0,0,0,0,0,0,0,107,109,118,99,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,108,111,103,32,102,105,108,101,32,39,37,115,39,32,102,111,114,32,112,97,115,115,45,50,32,101,110,99,111,100,105,110,103,10,0,0,0,0,0,0,0,0,117,115,112,112,0,0,0,0,107,103,118,49,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,50,55,95,87,101,115,116,0,115,111,102,116,112,117,108,108,100,111,119,110,0,0,0,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,106,118,0,0,0,0,0,0,68,117,112,108,105,99,97,116,101,32,102,111,114,109,97,116,115,32,105,110,32,97,118,102,105,108,116,101,114,95,109,101,114,103,101,95,102,111,114,109,97,116,115,40,41,32,100,101,116,101,99,116,101,100,10,0,80,114,111,106,95,78,101,119,95,89,111,114,107,95,67,83,50,55,95,69,97,115,116,0,106,112,101,103,108,115,0,0,112,112,55,0,0,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,56,51,95,87,101,115,116,0,0,0,0,0,0,0,112,111,115,0,0,0,0,0,112,97,108,101,116,116,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,37,46,54,103,0,0,0,0,105,108,112,97,99,107,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,97,114,103,115,0,0,0,0,114,103,98,51,50,0,0,0,110,116,115,99,0,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,99,104,97,110,110,101,108,58,32,37,115,46,10,0,0,0,0,0,107,97,105,115,101,114,95,98,101,116,97,0,0,0,0,0,118,111,108,117,109,101,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,56,51,95,69,97,115,116,0,0,0,0,0,0,0,71,67,83,95,71,68,65,57,52,0,0,0,0,0,0,0,99,114,111,112,45,114,101,99,116,0,0,0,0,0,0,0,105,110,112,117,116,32,99,104,97,110,110,101,108,32,35,37,100,32,110,111,116,32,97,118,97,105,108,97,98,108,101,32,102,114,111,109,32,105,110,112,117,116,32,108,97,121,111,117,116,32,39,37,115,39,10,0,102,115,112,112,0,0,0,0,98,117,103,0,0,0,0,0,113,112,101,108,32,0,0,0,99,109,112,0,0,0,0,0,99,111,112,121,116,98,0,0,70,114,97,112,115,0,0,0,103,101,110,114,101,0,0,0,65,112,112,108,121,32,97,32,116,119,111,45,112,111,108,101,32,97,108,108,45,112,97,115,115,32,102,105,108,116,101,114,46,0,0,0,0,0,0,0,104,50,54,52,0,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,50,55,95,87,101,115,116,0,0,0,0,0,0,0,112,111,116,32,60,61,32,97,116,101,109,112,111,45,62,119,105,110,100,111,119,0,0,0,105,110,49,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,58,32,37,108,108,100,10,0,0,0,0,0,0,0,0,101,113,50,0,0,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,32,40,99,111,100,101,99,32,37,115,41,0,0,0,0,0,105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,99,111,100,101,0,0,0,99,104,58,37,100,32,99,104,108,58,37,115,32,102,109,116,58,37,115,32,114,58,37,100,72,122,32,45,62,32,99,104,58,37,100,32,99,104,108,58,37,115,32,102,109,116,58,37,115,32,114,58,37,100,72,122,10,0,0,0,0,0,0,0,115,101,116,32,109,111,100,117,108,97,116,105,111,110,32,116,121,112,101,0,0,0,0,0,101,113,0,0,0,0,0,0,80,114,111,106,95,78,101,119,95,77,101,120,105,99,111,95,67,83,50,55,95,69,97,115,116,0,0,0,0,0,0,0,102,105,114,115,116,0,0,0,37,115,105,110,37,100,58,0,100,101,102,97,117,108,116,0,80,114,111,106,95,78,101,119,95,74,101,114,115,101,121,95,67,83,56,51,0,0,0,0,108,100,101,115,0,0,0,0,115,116,97,114,116,95,116,105,109,101,0,0,0,0,0,0,115,116,97,116,115,0,0,0,115,101,116,32,108,105,115,116,32,111,102,32,115,105,103,110,97,108,32,100,101,108,97,121,115,0,0,0,0,0,0,0,106,112,101,103,50,48,48,48,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,105,110,112,117,116,32,102,105,108,101,32,39,37,115,39,10,0,80,114,111,106,95,78,101,119,95,74,101,114,115,101,121,95,67,83,50,55,0,0,0,0,48,0,0,0,0,0,0,0,110,98,95,105,110,95,99,104,97,110,110,101,108,115,0,0,112,32,61,61,32,80,65,82,84,73,84,73,79,78,95,83,80,76,73,84,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,114,111,106,95,78,101,119,95,72,97,109,112,115,104,105,114,101,95,67,83,56,51,0,100,99,95,99,104,114,111,109,97,0,0,0,0,0,0,0,110,114,101,115,108,101,118,101,108,115,50,100,101,99,111,100,101,32,37,100,32,105,110,118,97,108,105,100,32,111,114,32,117,110,105,110,105,116,105,97,108,105,122,101,100,10,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,115,105,110,103,108,101,95,114,101,102,44,32,122,101,114,111,95,99,111,117,110,116,115,46,115,105,110,103,108,101,95,114,101,102,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,115,105,110,103,108,101,95,114,101,102,41,41,0,0,0,80,114,111,106,95,78,101,119,95,72,97,109,112,115,104,105,114,101,95,67,83,50,55,0,115,101,116,32,116,104,101,32,105,110,105,116,105,97,108,32,121,32,112,111,115,105,116,105,111,110,0,0,0,0,0,0,83,101,108,101,99,116,101,100,32,37,100,47,37,100,32,116,105,109,101,32,98,97,115,101,10,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,114,97,116,101,0,0,0,0,80,114,111,106,95,78,101,118], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2515104);
/* memory initializer */ allocate([97,100,97,95,67,83,56,51,95,87,101,115,116,0,0,0,33,40,108,102,109,45,62,97,98,111,118,101,95,117,118,91,84,88,95,56,88,56,93,32,38,32,108,102,109,45,62,97,98,111,118,101,95,117,118,91,84,88,95,52,88,52,93,41,0,0,0,0,0,0,0,0,109,97,105,110,112,105,99,0,97,115,115,117,109,101,32,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,0,67,97,110,110,111,116,32,99,111,110,110,101,99,116,32,97,117,100,105,111,32,102,105,108,116,101,114,32,116,111,32,110,111,110,32,97,117,100,105,111,32,105,110,112,117,116,10,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,98,97,121,101,114,95,103,114,98,103,49,54,98,101,0,0,89,101,108,108,111,119,71,114,101,101,110,0,0,0,0,0,115,101,108,101,99,116,32,75,97,105,115,101,114,32,87,105,110,100,111,119,101,100,32,83,105,110,99,0,0,0,0,0,99,104,114,111,109,97,95,109,115,105,122,101,95,121,0,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,56,51,95,69,97,115,116,0,0,0,71,67,83,95,80,111,105,110,116,101,95,78,111,105,114,101,0,0,0,0,0,0,0,0,122,111,110,101,115,0,0,0,97,108,119,97,121,115,32,97,112,112,108,121,32,116,114,97,110,115,112,111,115,105,116,105,111,110,0,0,0,0,0,0,99,111,100,101,99,95,116,97,103,0,0,0,0,0,0,0,115,99,97,108,97,98,105,108,105,116,121,32,0,0,0,0,99,111,100,101,114,0,0,0,105,110,116,101,114,108,101,97,118,101,32,98,111,116,116,111,109,32,97,110,100,32,116,111,112,32,102,105,101,108,100,115,0,0,0,0,0,0,0,0,99,111,112,121,32,116,105,109,101,115,116,97,109,112,115,0,98,108,97,99,107,0,0,0,102,114,97,112,115,0,0,0,116,114,97,99,107,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,97,99,51,0,0,0,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,50,55,95,87,101,115,116,0,0,0,112,97,116,116,101,114,110,32,116,104,97,116,32,100,101,115,99,114,105,98,101,32,102,111,114,32,104,111,119,32,109,97,110,121,32,102,105,101,108,100,115,32,97,32,102,114,97,109,101,32,105,115,32,116,111,32,98,101,32,100,105,115,112,108,97,121,101,100,0,0,0,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,97,108,116,101,114,110,97,116,105,110,103,32,102,114,97,109,101,115,32,114,105,103,104,116,32,102,105,114,115,116,0,0,117,115,101,32,66,45,102,114,97,109,101,115,39,32,81,80,0,0,0,0,0,0,0,0,68,101,116,101,99,116,32,97,117,100,105,111,32,118,111,108,117,109,101,46,0,0,0,0,99,104,114,111,109,97,95,115,116,114,101,110,103,116,104,0,106,97,99,111,115,117,98,0,80,114,111,106,95,78,101,118,97,100,97,95,67,83,50,55,95,69,97,115,116,0,0,0,80,114,111,106,95,78,101,98,114,97,115,107,97,95,67,83,56,51,0,0,0,0,0,0,102,105,102,111,0,0,0,0,104,101,105,103,104,116,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,99,104,114,111,109,97,95,112,114,101,95,102,105,108,116,101,114,95,114,97,100,105,117,115,0,0,0,0,0,0,0,0,102,102,109,112,101,103,50,112,97,115,115,0,0,0,0,0,106,112,101,103,50,48,48,48,0,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,80,114,111,106,95,78,101,98,114,97,115,107,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,108,117,109,97,0,0,0,0,115,116,97,116,115,95,102,105,108,101,0,0,0,0,0,0,80,114,111,106,95,78,101,98,114,97,115,107,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,97,110,97,108,121,122,101,0,98,115,32,61,61,32,109,98,109,105,45,62,115,98,95,116,121,112,101,0,0,0,0,0,115,101,116,32,98,111,116,116,111,109,32,108,101,102,116,32,121,32,99,111,111,114,100,105,110,97,116,101,0,0,0,0,99,111,108,111,114,0,0,0,80,114,111,106,95,77,111,110,116,97,110,97,95,67,83,56,51,0,0,0,0,0,0,0,67,104,97,110,103,101,32,105,110,112,117,116,32,118,111,108,117,109,101,46,0,0,0,0,118,115,117,98,0,0,0,0,80,114,111,106,95,77,111,110,116,97,110,97,95,67,83,50,55,95,83,111,117,116,104,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,99,121,99,108,105,99,95,114,101,102,114,101,115,104,0,0,116,101,109,112,111,114,97,108,32,110,111,105,115,101,0,0,78,79,80,84,83,0,0,0,80,114,111,106,95,77,111,110,116,97,110,97,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,69,120,112,111,114,116,105,110,103,0,0,0,0,0,0,0,68,101,116,101,99,116,32,115,105,108,101,110,99,101,46,0,98,97,121,101,114,95,103,114,98,103,49,54,108,101,0,0,89,101,108,108,111,119,0,0,111,117,116,112,117,116,32,112,108,97,110,101,32,37,100,32,100,101,112,116,104,32,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,105,110,112,117,116,32,37,100,32,112,108,97,110,101,32,37,100,32,100,101,112,116,104,32,37,100,10,0,0,0,0,0,107,97,105,115,101,114,0,0,115,101,116,32,113,112,0,0,99,112,105,45,62,111,120,99,102,46,108,97,103,95,105,110,95,102,114,97,109,101,115,32,60,32,50,0,0,0,0,0,80,114,111,106,95,77,111,110,116,97,110,97,95,67,83,50,55,95,78,111,114,116,104,0,71,67,83,95,80,97,108,101,115,116,105,110,101,95,49,57,50,51,0,0,0,0,0,0,99,112,108,120,45,98,108,117,114,0,0,0,0,0,0,0,102,114,97,109,101,95,98,105,116,115,0,0,0,0,0,0,116,98,32,37,100,47,37,100,44,32,116,105,110,99,114,98,105,116,115,58,37,100,44,32,113,112,95,112,114,101,99,58,37,100,44,32,112,115,58,37,100,44,32,32,37,115,37,115,37,115,37,115,10,0,0,0,116,101,116,114,97,104,101,100,114,97,108,0,0,0,0,0,107,101,121,105,110,116,95,109,105,110,0,0,0,0,0,0,99,111,112,121,116,115,0,0,73,110,116,101,108,32,73,110,100,101,111,32,50,0,0,0,82,101,112,108,97,121,71,97,105,110,32,115,99,97,110,110,101,114,46,0,0,0,0,0,37,100,0,0,0,0,0,0,100,116,115,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,49,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,56,51,95,87,101,115,116,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,0,0,0,0,0,0,0,114,99,95,101,110,100,95,117,115,97,103,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,86,80,88,95,86,66,82,46,46,86,80,88,95,81,93,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,88,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,97,116,117,114,97,116,105,111,110,32,101,120,112,114,101,115,115,105,111,110,0,0,0,114,99,95,50,112,97,115,115,95,118,98,114,95,98,105,97,115,95,112,99,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,93,0,0,0,0,0,0,115,101,116,32,108,101,118,101,108,32,104,101,105,103,104,116,0,0,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,56,51,95,69,97,115,116,0,100,101,102,97,117,108,116,0,69,109,112,116,121,32,99,117,115,116,111,109,32,72,117,102,102,109,97,110,32,116,97,98,108,101,33,10,0,0,0,0,114,0,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,50,55,95,87,101,115,116,0,115,99,101,110,101,32,99,117,116,32,97,116,32,37,100,32,73,99,111,115,116,58,37,100,32,80,99,111,115,116,58,37,100,32,114,97,116,105,111,58,37,46,52,102,32,98,105,97,115,58,37,46,52,102,32,103,111,112,58,37,100,32,40,105,109,98,58,37,100,32,112,109,98,58,37,100,41,10,0,0,100,101,115,99,0,0,0,0,76,101,102,116,32,97,110,100,32,114,105,103,104,116,32,115,105,122,101,115,32,100,105,102,102,101,114,32,40,37,100,120,37,100,32,118,115,32,37,100,120,37,100,41,46,10,0,0,98,97,100,32,99,111,101,102,102,105,99,105,101,110,116,32,105,110,32,108,105,115,116,32,39,37,115,39,10,0,0,0,37,115,45,37,100,46,108,111,103,0,0,0,0,0,0,0,114,111,117,110,100,32,116,111,119,97,114,100,115,32,45,105,110,102,116,121,0,0,0,0,82,101,109,105,120,32,99,104,97,110,110,101,108,115,32,119,105,116,104,32,99,111,101,102,102,105,99,105,101,110,116,115,32,40,112,97,110,110,105,110,103,41,46,0,0,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,89,69,83,0,0,0,0,0,99,108,71,101,116,67,111,109,109,97,110,100,81,117,101,117,101,73,110,102,111,0,0,0,80,114,111,106,95,77,105,115,115,111,117,114,105,95,67,83,50,55,95,69,97,115,116,0,110,98,95,102,114,97,109,101,115,0,0,0,0,0,0,0,120,118,109,99,109,99,0,0,65,108,105,99,101,66,108,117,101,0,0,0,0,0,0,0,115,101,116,32,114,101,100,32,112,108,97,110,101,0,0,0,37,48,50,88,0,0,0,0,80,114,111,106,95,77,105,115,115,105,115,115,105,112,112,105,95,67,83,56,51,95,87,101,115,116,0,0,0,0,0,0,72,121,112,101,114,32,102,97,115,116,32,65,117,100,105,111,32,97,110,100,32,86,105,100,101,111,32,101,110,99,111,100,101,114,10,0,0,0,0,0,108,111,103,0,0,0,0,0,69,110,100,32,111,102,32,102,105,108,101,0,0,0,0,0,66,82,0,0,0,0,0,0,117,115,105,110,103,32,117,110,115,99,97,108,101,100,32,37,115,32,45,62,32,37,115,32,115,112,101,99,105,97,108,32,99,111,110,118,101,114,116,101,114,10,0,0,0,0,0,0,99,104,114,66,117,102,73,110,100,101,120,32,60,32,50,32,42,32,118,67,104,114,66,117,102,83,105,122,101,0,0,0,99,111,108,111,114,0,0,0,103,97,117,115,115,105,97,110,0,0,0,0,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,48,120,37,108,108,120,32,105,115,32,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,105,115,115,105,112,112,105,95,67,83,56,51,95,69,97,115,116,0,0,0,0,0,0,114,121,0,0,0,0,0,0,74,111,105,110,32,109,117,108,116,105,112,108,101,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,105,110,116,111,32,109,117,108,116,105,45,99,104,97,110,110,101,108,32,111,117,116,112,117,116,46,0,0,115,104,111,119,0,0,0,0,113,112,58,37,100,32,37,99,32,115,105,122,101,58,37,100,32,114,110,100,58,37,100,37,115,37,115,37,115,37,115,37,115,37,115,37,115,37,115,37,115,32,37,100,47,37,100,10,0,0,0,0,0,0,0,0,92,102,115,37,117,37,49,91,92,125,93,37,110,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,99,111,117,110,116,10,0,0,87,105,100,101,110,32,116,104,101,32,115,116,101,114,101,111,32,105,109,97,103,101,46,0,115,101,116,32,100,117,112,108,105,99,97,116,101,32,116,104,114,101,115,104,111,108,100,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,50,0,0,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,105,115,115,105,112,112,105,95,67,83,50,55,95,87,101,115,116,0,0,0,0,0,0,114,111,111,109,95,116,121,112,101,0,0,0,0,0,0,0,35,111,112,116,105,111,110,115,58,0,0,0,0,0,0,0,114,111,111,109,95,116,121,112,101,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,117,116,111,102,102,32,102,114,101,113,117,101,110,99,121,10,0,0,0,0,0,0,0,76,111,47,82,111,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,80,97,114,97,109,101,116,114,105,99,32,83,116,101,114,101,111,32,115,105,103,110,97,108,101,100,32,116,111,32,98,101,32,110,111,116,45,112,114,101,115,101,110,116,32,98,117,116,32,119,97,115,32,102,111,117,110,100,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,46,10,0,0,0,83,101,108,101,99,116,101,100,32,98,121,32,116,104,101,32,69,110,99,111,100,101,114,0,98,97,121,101,114,95,103,98,114,103,49,54,98,101,0,0,87,104,105,116,101,83,109,111,107,101,0,0,0,0,0,0,73,109,112,108,105,99,105,116,32,83,66,82,32,119,97,115,32,102,111,117,110,100,32,119,105,116,104,32,97,32,102,105,114,115,116,32,111,99,99,117,114,114,101,110,99,101,32,97,102,116,101,114,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,46,10,0,0,115,101,108,101,99,116,32,66,108,97,99,107,109,97,110,32,78,117,116,116,97,108,108,32,87,105,110,100,111,119,101,100,32,83,105,110,99,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,101,110,116,114,105,101,115,32,105,110,32,99,111,108,111,114,109,97,112,10,0,0,48,47,49,32,48,46,49,50,57,47,49,32,48,46,52,54,54,47,48,46,52,57,56,32,48,46,55,50,53,47,48,32,49,47,48,0,0,0,0,0,67,104,97,110,110,101,108,32,116,114,97,110,115,102,111,114,109,32,98,105,116,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,115,117,98,102,114,97,109,101,95,108,101,110,32,37,105,10,0,0,98,105,116,114,97,116,101,32,116,111,111,32,108,111,119,58,32,103,111,116,32,37,105,44,32,110,101,101,100,32,50,52,48,48,48,32,111,114,32,104,105,103,104,101,114,10,0,0,104,103,97,105,110,32,118,108,99,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,80,114,111,106,95,77,105,115,115,105,115,115,105,112,112,105,95,67,83,50,55,95,69,97,115,116,0,0,0,0,0,0,71,67,83,95,80,97,100,97,110,103,0,0,0,0,0,0,60,47,117,62,0,0,0,0,108,97,118,102,105,46,99,114,111,112,100,101,116,101,99,116,46,121,50,0,0,0,0,0,87,105,100,116,104,32,109,105,115,109,97,116,99,104,46,32,37,100,32,33,61,32,37,100,10,0,0,0,0,0,0,0,99,112,108,120,98,108,117,114,0,0,0,0,0,0,0,0,111,112,116,105,109,105,122,101,95,109,111,110,111,0,0,0,73,110,118,97,108,105,100,32,70,76,79,65,84,73,78,70,79,44,32,115,105,122,101,32,61,32,37,105,10,0,0,0,100,101,99,111,100,101,95,102,111,114,109,97,116,56,48,32,112,114,111,98,108,101,109,58,32,100,101,99,111,100,101,32,102,105,110,105,115,104,101,100,32,119,105,116,104,32,100,101,115,116,95,105,110,100,101,120,32,40,37,100,41,32,60,32,100,101,115,116,95,115,105,122,101,32,40,37,100,41,10,0,82,97,110,32,111,117,116,32,111,102,32,109,101,109,111,114,121,32,100,117,114,105,110,103,32,114,97,110,103,101,32,99,111,100,101,114,32,105,110,105,116,10,0,0,0,0,0,0,109,105,115,99,95,98,105,116,115,0,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,109,111,100,101,115,10,0,0,115,99,97,108,97,98,105,108,105,116,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,99,98,45,62,108,111,111,107,117,112,0,0,0,0,0,0,32,86,111,114,98,105,115,32,115,101,116,117,112,32,104,101,97,100,101,114,32,112,97,99,107,101,116,32,99,111,114,114,117,112,116,32,40,110,111,32,118,111,114,98,105,115,32,115,105,103,110,97,116,117,114,101,41,46,32,10,0,0,0,0,98,95,115,116,114,97,116,101,103,121,0,0,0,0,0,0,105,110,116,101,114,112,108,97,121,118,105,100,101,111,0,0,73,110,118,97,108,105,100,32,118,101,114,116,105,99,97,108,32,114,97,110,103,101,32,37,100,45,37,100,10,0,0,0,40,105,110,95,104,45,111,117,116,95,104,41,47,50,0,0,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,118,99,49,100,101,99,46,99,0,0,0,0,0,72,82,68,32,98,105,116,114,97,116,101,58,32,37,105,32,98,105,116,115,47,115,101,99,10,0,0,0,0,0,0,0,77,66,32,77,86,32,84,121,112,101,32,112,108,97,110,101,32,101,110,99,111,100,105,110,103,58,32,73,109,111,100,101,58,32,37,105,44,32,73,110,118,101,114,116,58,32,37,105,10,0,0,0,0,0,0,0,105,110,100,101,111,50,0,0,115,109,112,116,101,50,52,48,109,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,83,108,105,99,101,32,99,111,117,110,116,32,37,100,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,116,104,101,32,115,117,98,115,97,109,112,108,105,110,103,45,97,112,112,108,105,101,100,32,104,101,105,103,104,116,32,37,100,46,10,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,97,99,51,0,0,0,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,100,101,99,111,100,101,114,0,115,101,116,32,116,104,101,32,98,108,117,101,32,103,97,105,110,32,102,111,114,32,116,104,101,32,103,114,101,101,110,32,99,104,97,110,110,101,108,0,112,97,115,115,119,111,114,100,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,115,108,105,99,101,32,105,110,102,111,114,109,97,116,105,111,110,10,0,0,0,0,0,0,71,111,116,32,108,101,115,115,32,99,111,100,101,115,32,116,104,97,110,32,101,120,112,101,99,116,101,100,58,32,37,105,32,111,102,32,37,105,10,0,32,83,80,82,73,84,69,0,112,97,99,107,98,105,116,115,0,0,0,0,0,0,0,0,115,101,116,32,114,101,100,32,104,105,103,104,108,105,103,104,116,115,0,0,0,0,0,0,66,97,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,99,112,0,0,0,0,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,70,0,0,0,0,0,0,0,71,101,111,103,65,122,105,109,117,116,104,85,110,105,116,115,71,101,111,75,101,121,0,0,67,111,112,121,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,99,104,114,111,109,97,32,100,99,32,98,108,111,99,107,10,0,0,0,60,102,111,110,116,32,102,97,99,101,61,34,37,115,34,62,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,115,110,111,119,32,101,110,99,111,100,101,114,0,0,0,0,67,111,109,112,114,101,115,115,32,111,114,32,101,120,112,97,110,100,32,97,117,100,105,111,32,100,121,110,97,109,105,99,32,114,97,110,103,101,46,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,109,105,115,115,105,110,103,32,87,65,86,69,32,116,97,103,10,0,0,0,0,0,0,0,118,97,114,105,97,98,108,101,32,115,105,122,101,32,102,114,97,109,101,115,32,97,114,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,98,108,101,110,100,32,109,111,100,101,0,0,0,0,0,114,101,115,101,114,118,101,100,32,98,105,116,32,115,101,116,10,0,0,0,0,0,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,113,67,111,109,112,0,0,0,105,110,100,101,120,32,37,100,32,111,117,116,32,111,102,32,116,121,112,101,51,48,95,100,101,113,117,97,110,116,32,97,114,114,97,121,10,0,0,0,98,108,97,99,107,95,109,105,110,95,100,117,114,97,116,105,111,110,58,37,115,32,112,105,120,101,108,95,98,108,97,99,107,95,116,104,58,37,102,32,112,105,120,101,108,95,98,108,97,99,107,95,116,104,95,105,58,37,100,32,112,105,99,116,117,114,101,95,98,108,97,99,107,95,114,97,116,105,111,95,116,104,58,37,102,10,0,0,52,52,52,52,0,0,0,0,73,110,118,97,108,105,100,32,97,108,112,104,97,32,109,111,100,101,32,37,100,10,0,0,101,114,114,111,114,44,32,119,114,111,110,103,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,0,0,0,73,69,78,68,32,119,105,116,104,111,117,116,32,97,108,108,32,105,109,97,103,101,10,0,78,79,80,84,83,0,0,0,112,99,109,95,102,54,52,108,101,0,0,0,0,0,0,0,83,112,108,105,116,32,97,117,100,105,111,32,105,110,116,111,32,112,101,114,45,99,104,97,110,110,101,108,32,115,116,114,101,97,109,115,46,0,0,0,73,110,118,97,108,105,100,32,115,116,114,105,110,103,32,39,37,115,39,32,102,111,114,32,97,115,112,101,99,116,32,114,97,116,105,111,10,0,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,116,104,114,101,97,100,115,0,108,121,114,105,99,115,0,0,112,107,116,95,112,111,115,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,97,117,100,105,111,32,115,97,109,112,108,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,100,114,111,112,112,101,100,32,97,103,97,105,110,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,118,97,108,105,100,32,102,111,114,99,101,95,107,101,121,95,102,114,97,109,101,115,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,32,102,111,114,32,118,50,10,0,0,101,114,114,111,114,95,114,97,116,101,0,0,0,0,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,115,101,116,32,115,116,114,101,97,109,115,0,0,0,0,0,105,110,100,101,111,53,0,0,115,101,116,116,98,0,0,0,66,97,100,32,104,101,97,100,101,114,44,32,100,105,115,99,97,114,100,32,98,108,111,99,107,10,0,0,0,0,0,0,66,97,100,32,104,101,97,100,101,114,44,32,100,105,115,99,97,114,100,32,98,108,111,99,107,10,0,0,0,0,0,0,115,116,114,105,99,116,95,103,111,112,0,0,0,0,0,0,115,99,97,110,95,111,102,102,115,101,116,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,112,97,114,115,105,110,103,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,37,51,88,32,97,116,32,37,116,100,32,108,101,102,116,32,37,100,10,0,0,0,0,0,99,104,97,110,110,101,108,32,99,111,117,110,116,32,109,105,115,109,97,116,99,104,10,0,82,101,109,97,112,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,46,0,0,0,83,117,98,115,97,109,112,108,105,110,103,32,105,110,32,74,80,69,71,45,76,83,0,0,110,111,32,112,105,99,116,117,114,101,10,0,0,0,0,0,69,114,114,111,114,32,99,114,101,97,116,105,110,103,32,102,105,108,116,101,114,32,39,37,115,39,10,0,0,0,0,0,123,92,97,110,56,125,0,0,80,114,111,106,95,77,105,110,110,101,115,111,116,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,112,97,115,115,108,111,103,102,105,108,101,0,0,0,0,0,118,112,120,95,99,111,100,101,99,95,99,111,110,116,114,111,108,10,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,69,80,72,32,109,97,114,107,101,114,32,110,111,116,32,102,111,117,110,100,46,10,0,0,123,92,97,110,56,125,0,0,111,102,102,115,32,62,61,32,48,32,38,38,32,114,101,102,95,111,102,102,115,32,62,61,32,48,32,38,38,32,98,97,110,100,45,62,114,101,102,95,98,117,102,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,52,120,52,32,108,117,109,97,32,98,108,111,99,107,115,32,97,114,101,32,117,110,115,117,112,112,111,114,116,101,100,33,10,0,0,0,0,0,0,0,67,117,115,116,111,109,32,113,117,97,110,116,32,109,97,116,114,105,120,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,77,111,100,101,32,37,100,58,32,105,110,118,97,108,105,100,32,86,81,32,100,97,116,97,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,104,111,108,100,32,98,105,116,115,32,102,111,114,32,72,65,77,58,32,37,117,10,0,0,0,0,0,0,0,0,69,114,114,111,114,58,32,89,86,49,50,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,104,117,102,102,121,117,118,59,32,117,115,101,32,118,99,111,100,101,99,61,102,102,118,104,117,102,102,32,111,114,32,102,111,114,109,97,116,61,52,50,50,112,10,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,76,117,109,97,32,98,105,116,32,100,101,112,116,104,32,40,37,100,41,32,105,115,32,100,105,102,102,101,114,101,110,116,32,102,114,111,109,32,99,104,114,111,109,97,32,98,105,116,32,100,101,112,116,104,32,40,37,100,41,44,32,116,104,105,115,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,78,111,110,45,109,97,116,99,104,105,110,103,32,78,65,76,32,116,121,112,101,115,32,111,102,32,116,104,101,32,86,67,76,32,78,65,76,85,115,58,32,37,100,32,37,100,10,0,109,111,110,111,0,0,0,0,109,109,99,111,58,32,117,110,114,101,102,32,108,111,110,103,32,102,97,105,108,117,114,101,10,0,0,0,0,0,0,0,70,82,77,0,0,0,0,0,98,117,102,95,105,110,100,101,120,32,60,61,32,98,117,102,95,115,105,122,101,0,0,0,115,108,105,99,101,32,101,110,100,32,110,111,116,32,114,101,97,99,104,101,100,32,98,117,116,32,115,99,114,101,101,110,115,112,97,99,101,32,101,110,100,32,40,37,100,32,108,101,102,116,32,37,48,54,88,44,32,115,99,111,114,101,61,32,37,100,41,10,0,0,0,0,66,97,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,112,114,101,118,95,116,0,0,101,110,97,98,108,101,32,116,114,97,110,115,112,97,114,101,110,99,121,32,100,101,116,101,99,116,105,111,110,32,98,101,116,119,101,101,110,32,102,114,97,109,101,115,0,0,0,0,66,105,116,115,32,112,101,114,32,99,111,100,101,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,112,111,115,32,37,100,44,37,100,32,40,105,110,32,37,100,120,37,100,32,103,114,105,100,41,10,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,37,100,120,37,100,32,100,105,102,102,32,115,116,97,114,116,32,37,100,32,104,101,105,103,104,116,32,37,100,10,0,0,115,101,116,32,112,101,114,109,105,115,115,105,111,110,115,32,114,97,110,100,111,109,108,121,0,0,0,0,0,0,0,0,32,99,111,109,112,114,101,115,115,105,111,110,58,32,37,100,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,117,98,102,114,97,109,101,32,112,97,100,100,105,110,103,10,0,0,0,0,0,0,0,105,110,100,101,111,52,0,0,98,105,116,115,95,112,101,114,95,114,97,119,95,115,97,109,112,108,101,32,105,110,118,97,108,105,100,10,0,0,0,0,105,110,118,97,108,105,100,32,118,101,114,115,105,111,110,32,37,100,32,105,110,32,118,101,114,48,49,32,104,101,97,100,101,114,10,0,0,0,0,0,86,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,102,95,105,110,116,101,114,108,101,97,118,101,46,99,0,0,0,0,0,0,115,109,97,108,108,0,0,0,49,48,50,52,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,68,87,84,32,100,101,99,111,109,112,111,115,105,116,105,111,110,115,10,0,0,0,97,118,95,105,109,97,103,101,95,99,104,101,99,107,95,115,105,122,101,40,97,118,99,116,120,45,62,119,105,100,116,104,44,32,97,118,99,116,120,45,62,104,101,105,103,104,116,44,32,48,44,32,97,118,99,116,120,41,32,62,61,32,48,0,78,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,99,104,97,110,103,101,100,32,105,110,32,68,67,65,32,100,101,99,111,100,101,114,32,40,37,100,32,45,62,32,37,100,41,10,0,0,0,77,79,78,79,10,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,86,105,100,101,111,32,115,105,122,101,32,37,100,120,37,100,32,105,115,32,116,111,111,32,115,109,97,108,108,44,32,109,105,110,105,109,117,109,32,115,105,122,101,32,105,115,32,54,52,48,120,52,56,48,10,0,98,97,121,101,114,95,103,98,114,103,49,54,108,101,0,0,87,104,105,116,101,0,0,0,98,108,97,99,107,109,97,110,95,110,117,116,116,97,108,108,0,0,0,0,0,0,0,0,77,111,116,105,111,110,32,74,80,69,71,0,0,0,0,0,100,101,102,97,117,108,116,0,69,110,102,111,114,99,101,32,109,105,110,32,115,116,114,105,112,115,47,102,114,97,109,101,44,32,109,111,114,101,32,105,115,32,119,111,114,115,101,32,97,110,100,32,102,97,115,116,101,114,44,32,109,117,115,116,32,98,101,32,60,61,32,109,97,120,95,115,116,114,105,112,115,0,0,0,0,0,0,0,87,105,100,116,104,47,104,101,105,103,104,116,32,99,104,97,110,103,105,110,103,32,105,110,32,67,65,86,83,0,0,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,99,111,108,111,114,115,32,45,32,37,88,32,102,111,114,32,98,105,116,100,101,112,116,104,32,37,100,10,0,0,0,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,67,83,95,79,83,95,83,78,56,48,0,0,0,0,0,85,110,107,110,111,119,110,32,97,109,111,117,110,116,32,111,102,32,100,101,108,97,121,32,37,120,32,33,61,32,48,120,56,56,69,46,10,0,0,0,113,98,108,117,114,0,0,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,0,0,0,0,0,0,0,37,100,32,98,105,116,115,32,112,101,114,32,99,111,100,101,100,32,115,97,109,112,108,101,0,0,0,0,0,0,0,0,82,101,97,100,105,110,103,32,65,76,83,83,112,101,99,105,102,105,99,67,111,110,102,105,103,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,115,107,105,112,95,99,111,117,110,116,0,0,0,0,0,0,114,101,100,117,99,101,100,32,114,101,115,111,108,117,116,105,111,110,32,86,79,80,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,88,45,85,115,101,115,0,0,114,105,103,104,116,95,108,101,102,116,0,0,0,0,0,0,115,117,98,113,0,0,0,0,108,105,98,118,112,120,45,118,112,56,32,101,110,99,111,100,101,114,0,0,0,0,0,0,97,117,100,105,111,32,100,114,105,102,116,32,116,104,114,101,115,104,111,108,100,0,0,0,82,97,112,0,0,0,0,0,103,101,110,114,101,0,0,0,97,117,116,104,111,114,0,0,65,117,116,111,100,101,115,107,32,82,76,69,0,0,0,0,100,97,116,101,0,0,0,0,97,117,116,111,45,105,110,115,101,114,116,101,100,32,115,99,97,108,101,114,32,37,100,0,52,50,50,112,49,50,0,0,112,114,111,98,101,100,32,115,116,114,101,97,109,32,37,100,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,100,101,99,95,116,121,112,101,32,40,48,120,37,120,41,10,0,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,117,110,107,110,111,119,110,32,103,117,105,100,32,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,44,32,101,120,112,101,99,116,101,100,32,109,101,116,97,100,97,116,97,95,103,117,105,100,59,32,114,101,109,97,105,110,105,110,103,32,109,101,116,97,100,97,116,97,32,101,110,116,114,105,101,115,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,0,102,109,116,32,0,0,0,0,110,101,103,97,116,105,118,101,32,100,97,116,97,95,115,105,122,101,32,97,110,100,47,111,114,32,115,97,109,112,108,101,95,99,111,117,110,116,32,105,110,32,100,115,54,52,58,32,100,97,116,97,95,115,105,122,101,32,61,32,37,108,108,100,44,32,115,97,109,112,108,101,95,99,111,117,110,116,32,61,32,37,108,108,100,10,0,0,65,85,84,72,0,0,0,0,83,97,109,112,108,105,110,103,70,114,101,113,117,101,110,99,121,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,83,108,97,118,101,32,39,37,115,39,58,32,101,114,114,111,114,32,111,112,101,110,105,110,103,58,32,37,115,10,0,0,32,9,13,10,0,0,0,0,112,111,110,103,32,102,114,111,109,58,37,115,32,37,115,10,0,0,0,0,0,0,0,0,83,87,70,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,86,80,54,44,32,70,76,86,49,32,97,110,100,32,77,74,80,69,71,10,0,0,0,0,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,44,37,42,117,58,37,42,117,58,37,42,117,46,37,42,117,37,99,0,0,0,0,0,0,0,68,84,83,45,72,68,32,98,105,116,114,97,116,101,32,116,111,111,32,104,105,103,104,44,32,116,101,109,112,111,114,97,114,105,108,121,32,115,101,110,100,105,110,103,32,99,111,114,101,32,111,110,108,121,10,0,105,110,100,101,111,51,0,0,60,83,116,114,101,97,109,73,110,100,101,120,32,84,121,112,101,61,34,97,117,100,105,111,34,32,81,117,97,108,105,116,121,76,101,118,101,108,115,61,34,37,100,34,32,67,104,117,110,107,115,61,34,37,100,34,32,85,114,108,61,34,81,117,97,108,105,116,121,76,101,118,101,108,115,40,123,98,105,116,114,97,116,101,125,41,47,70,114,97,103,109,101,110,116,115,40,97,117,100,105,111,61,123,115,116,97,114,116,32,116,105,109,101,125,41,34,62,10,0,115,101,116,32,118,105,100,101,111,32,114,97,116,101,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,32,37,99,0,0,0,0,0,105,110,100,101,111,50,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,83,116,97,116,101,95,80,108,97,110,101,95,87,101,115,116,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,112,112,108,121,32,116,119,111,45,112,111,108,101,32,112,101,97,107,105,110,103,32,101,113,117,97,108,105,122,97,116,105,111,110,32,40,69,81,41,32,102,105,108,116,101,114,46,0,0,0,0,0,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,83,116,97,116,101,95,80,108,97,110,101,95,79,108,100,95,67,101,110,116,114,97,108,0,0,0,169,108,121,114,0,0,0,0,101,120,112,114,58,0,0,0,80,114,111,106,95,77,105,99,104,105,103,97,110,95,83,116,97,116,101,95,80,108,97,110,101,95,69,97,115,116,0,0,105,109,99,0,0,0,0,0,80,114,111,106,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,67,83,56,51,95,73,115,108,97,110,100,0,0,65,100,106,117,115,116,32,97,117,100,105,111,32,116,101,109,112,111,46,0,0,0,0,0,80,114,111,106,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,67,83,56,51,95,77,97,105,110,108,97,110,100,0,0,0,0,0,0,0,0,80,114,111,106,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,67,83,50,55,95,73,115,108,97,110,100,0,0,105,102,102,0,0,0,0,0,105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,99,111,100,101,0,0,0,105,100,99,105,110,118,105,100,101,111,0,0,0,0,0,0,80,114,111,106,95,77,97,115,115,97,99,104,117,115,101,116,116,115,95,67,83,50,55,95,77,97,105,110,108,97,110,100,0,0,0,0,0,0,0,0,67,111,112,121,32,116,119,111,32,115,116,114,101,97,109,115,32,111,102,32,97,117,100,105,111,32,100,97,116,97,32,105,110,32,97,32,99,111,110,102,105,103,117,114,97,98,108,101,32,111,114,100,101,114,46,0,98,97,121,101,114,95,114,103,103,98,49,54,98,101,0,0,87,104,101,97,116,0,0,0,115,101,108,101,99,116,32,99,117,98,105,99,0,0,0,0,80,114,111,106,95,77,97,114,121,108,97,110,100,95,67,83,56,51,0,0,0,0,0,0,71,67,83,95,79,83,71,66,55,48,0,0,0,0,0,0,109,98,116,114,101,101,0,0,112,95,99,111,117,110,116,0,115,116,114,101,97,109,32,101,110,100,0,0,0,0,0,0,110,101,119,32,112,114,101,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,109,101,95,109,101,116,104,111,100,0,0,0,0,0,0,0,107,101,121,105,110,116,95,109,105,110,0,0,0,0,0,0,97,100,114,105,102,116,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,0,0,97,97,115,99,0,0,0,0,97,108,98,117,109,0,0,0,112,114,111,98,101,100,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,0,80,114,111,106,95,77,97,114,121,108,97,110,100,95,67,83,50,55,0,0,0,0,0,0,104,117,102,102,121,117,118,0,83,104,111,119,32,116,105,109,101,32,100,111,109,97,105,110,32,115,116,97,116,105,115,116,105,99,115,32,97,98,111,117,116,32,97,117,100,105,111,32,102,114,97,109,101,115,46,0,80,114,111,106,95,77,97,105,110,101,95,67,83,56,51,95,87,101,115,116,0,0,0,0,68,101,99,111,100,101,114,115,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,97,114,103,117,109,101,110,116,32,102,111,114,32,111,112,116,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,80,114,111,106,95,77,97,105,110,101,95,67,83,56,51,95,69,97,115,116,0,0,0,0,99,97,99,104,101,0,0,0,83,104,111,119,32,116,101,120,116,117,97,108,32,105,110,102,111,114,109,97,116,105,111,110,32,102,111,114,32,101,97,99,104,32,97,117,100,105,111,32,102,114,97,109,101,46,0,0,104,117,102,102,121,117,118,0,80,114,111,106,95,77,97,105,110,101,95,67,83,50,55,95,87,101,115,116,0,0,0,0,115,114,116,112,95,111,117,116,95,115,117,105,116,101,0,0,103,114,111,117,112,105,110,103,0,0,0,0,0,0,0,0,84,111,111,32,104,105,103,104,32,115,121,109,98,111,108,32,102,114,101,113,117,101,110,99,105,101,115,46,32,84,114,101,101,32,99,111,110,115,116,114,117,99,116,105,111,110,32,105,115,32,110,111,116,32,112,111,115,115,105,98,108,101,10,0,34,0,0,0,0,0,0,0,78,111,32,112,105,120,101,108,32,102,111,114,109,97,116,32,115,112,101,99,105,102,105,101,100,44,32,37,115,32,102,111,114,32,77,80,69,71,45,50,32,101,110,99,111,100,105,110,103,32,99,104,111,115,101,110,46,10,85,115,101,32,45,112,105,120,95,102,109,116,32,121,117,118,52,50,48,112,32,102,111,114,32,99,111,109,112,97,116,105,98,105,108,105,116,121,32,119,105,116,104,32,111,117,116,100,97,116,101,100,32,109,101,100,105,97,32,112,108,97,121,101,114,115,46,10,0,0,67,104,97,110,103,101,32,116,104,101,32,115,97,109,112,108,101,32,114,97,116,101,32,119], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2525344);
/* memory initializer */ allocate([105,116,104,111,117,116,32,97,108,116,101,114,105,110,103,32,116,104,101,32,100,97,116,97,46,0,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,104,101,97,100,101,114,32,99,104,101,99,107,0,0,80,114,111,106,95,77,97,105,110,101,95,67,83,50,55,95,69,97,115,116,0,0,0,0,82,84,80,32,109,117,120,101,114,32,102,108,97,103,115,0,104,110,109,52,118,105,100,101,111,0,0,0,0,0,0,0,80,114,111,106,95,76,111,117,105,115,105,97,110,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,32,102,111,114,32,105,110,100,101,120,32,97,116,32,112,111,115,32,37,108,108,100,10,0,0,83,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,102,111,114,32,101,97,99,104,32,111,117,116,112,117,116,32,97,117,100,105,111,32,102,114,97,109,101,115,46,0,73,80,82,68,0,0,0,0,80,114,111,106,95,76,111,117,105,115,105,97,110,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,99,111,108,111,114,0,0,0,68,101,99,111,100,105,110,103,32,83,69,73,10,0,0,0,80,114,111,106,95,76,111,117,105,115,105,97,110,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,114,97,119,32,68,78,120,72,68,32,40,83,77,80,84,69,32,86,67,45,51,41,0,0,116,104,100,0,0,0,0,0,82,101,115,97,109,112,108,101,32,97,117,100,105,111,32,100,97,116,97,46,0,0,0,0,80,114,111,106,95,76,111,117,105,115,105,97,110,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,98,97,121,101,114,95,114,103,103,98,49,54,108,101,0,0,86,105,111,108,101,116,0,0,99,117,98,105,99,0,0,0,68,117,112,108,105,99,97,116,101,32,80,79,67,32,105,110,32,97,32,115,101,113,117,101,110,99,101,58,32,37,100,46,10,0,0,0,0,0,0,0,80,114,111,106,95,75,101,110,116,117,99,107,121,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,67,83,95,79,83,71,66,95,49,57,51,54,0,0,0,113,99,111,109,112,0,0,0,105,95,99,111,117,110,116,0,115,50,52,108,101,0,0,0,73,110,118,97,108,105,100,32,67,111,109,112,108,101,120,105,116,121,32,101,115,116,105,109,97,116,105,111,110,32,109,101,116,104,111,100,32,37,100,10,0,0,0,0,0,0,0,0,109,101,95,114,97,110,103,101,0,0,0,0,0,0,0,0,103,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,101,103,109,101,110,116,115,0,0,97,117,100,105,111,32,115,121,110,99,32,109,101,116,104,111,100,0,0,0,0,0,0,0,87,105,110,110,111,118,32,87,78,86,49,0,0,0,0,0,97,114,116,105,115,116,0,0,110,111,116,104,105,110,103,32,116,111,32,112,114,111,98,101,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,80,114,111,106,95,75,101,110,116,117,99,107,121,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,115,50,52,108,101,0,0,0,80,114,111,106,95,75,101,110,116,117,99,107,121,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,69,110,99,111,100,101,114,115,0,0,0,0,0,0,0,0,65,100,100,32,97,32,112,104,97,115,105,110,103,32,101,102,102,101,99,116,32,116,111,32,116,104,101,32,97,117,100,105,111,46,0,0,0,0,0,0,103,101,110,101,114,97,116,101,32,112,116,115,0,0,0,0,80,114,111,106,95,75,101,110,116,117,99,107,121,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,71,69,79,66,32,100,97,116,97,32,115,105,122,101,58,32,37,117,10,0,0,0,0,0,52,48,48,120,52,48,48,0,80,114,111,106,95,75,97,110,115,97,115,95,67,83,56,51,95,83,111,117,116,104,0,0,169,103,114,112,0,0,0,0,112,114,101,102,101,114,114,101,100,32,112,97,103,101,32,115,105,122,101,32,105,110,32,98,121,116,101,115,32,40,100,101,112,114,101,99,97,116,101,100,41,0,0,0,0,0,0,0,80,97,100,32,97,117,100,105,111,32,119,105,116,104,32,115,105,108,101,110,99,101,46,0,115,116,114,101,97,109,95,105,110,100,101,120,32,60,32,111,103,103,45,62,110,115,116,114,101,97,109,115,0,0,0,0,109,112,101,103,50,118,105,100,101,111,0,0,0,0,0,0,80,97,115,115,32,116,104,101,32,115,111,117,114,99,101,32,117,110,99,104,97,110,103,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,46,0,0,0,0,0,0,0,0,102,114,97,109,101,95,99,111,100,101,32,33,61,32,45,49,0,0,0,0,0,0,0,0,80,114,111,106,95,75,97,110,115,97,115,95,67,83,56,51,95,78,111,114,116,104,0,0,115,121,110,99,32,112,111,105,110,116,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,10,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,115,117,98,101,120,112,46,99,0,0,0,0,0,0,0,0,80,114,111,106,95,75,97,110,115,97,115,95,67,83,50,55,95,83,111,117,116,104,0,0,48,49,0,0,0,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,111,102,32,100,101,108,116,97,95,105,100,120,32,105,110,32,115,108,105,99,101,32,104,101,97,100,101,114,32,82,80,83,58,32,37,100,32,62,32,37,100,46,10,0,0,0,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,112,105,99,107,109,111,100,101,46,99,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,103,101,116,32,109,112,101,103,50,32,112,114,111,102,105,108,101,32,97,110,100,32,108,101,118,101,108,10,0,0,115,97,109,112,108,101,115,95,112,101,114,95,102,114,97,109,101,0,0,0,0,0,0,0,80,114,111,106,95,75,97,110,115,97,115,95,67,83,50,55,95,78,111,114,116,104,0,0,112,114,111,98,97,98,108,121,32,105,110,99,111,114,114,101,99,116,32,100,101,99,114,121,112,116,105,111,110,32,107,101,121,10,0,0,0,0,0,0,50,0,0,0,0,0,0,0,65,117,100,105,111,32,109,105,120,105,110,103,46,0,0,0,80,114,111,106,95,73,111,119,97,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,116,114,101,97,109,32,105,110,100,101,120,58,32,37,100,10,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,58,37,100,32,99,104,97,110,110,101,108,95,108,97,121,111,117,116,58,39,37,115,39,32,110,98,95,115,97,109,112,108,101,115,58,37,100,10,0,0,0,0,0,0,0,80,114,111,106,95,73,111,119,97,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,65,65,67,32,112,97,99,107,101,116,32,116,111,111,32,115,104,111,114,116,10,0,0,0,98,97,121,101,114,95,98,103,103,114,49,54,98,101,0,0,84,117,114,113,117,111,105,115,101,0,0,0,0,0,0,0,115,101,108,101,99,116,32,115,119,114,32,102,105,108,116,101,114,32,116,121,112,101,0,0,67,111,117,108,100,32,110,111,116,32,100,101,116,101,99,116,32,84,83,32,112,97,99,107,101,116,32,115,105,122,101,44,32,100,101,102,97,117,108,116,105,110,103,32,116,111,32,110,111,110,45,70,69,67,47,68,86,72,83,10,0,0,0,0,80,114,111,106,95,73,111,119,97,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,71,67,83,95,78,83,87,67,95,57,90,95,50,0,0,0,115,116,97,116,115,0,0,0,112,114,101,108,111,97,100,0,112,95,116,101,120,95,98,105,116,115,0,0,0,0,0,0,105,110,32,99,111,109,112,108,101,120,105,116,121,32,101,115,116,105,109,97,116,105,111,110,32,112,97,114,116,32,50,0,110,114,0,0,0,0,0,0,113,109,97,120,0,0,0,0,97,115,121,110,99,0,0,0,13,10,0,0,0,0,0,0,77,101,114,103,101,32,116,119,111,32,111,114,32,109,111,114,101,32,97,117,100,105,111,32,115,116,114,101,97,109,115,32,105,110,116,111,32,97,32,115,105,110,103,108,101,32,109,117,108,116,105,45,99,104,97,110,110,101,108,32,115,116,114,101,97,109,46,0,0,0,0,0,119,110,118,49,0,0,0,0,116,105,116,108,101,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,108,108,111,99,97,116,101,32,112,114,111,98,101,32,98,117,102,102,101,114,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,109,98,103,114,97,112,104,46,99,0,0,0,0,0,0,0,80,114,111,106,95,73,111,119,97,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,84,67,79,78,0,0,0,0,80,114,111,106,95,73,110,100,105,97,110,97,95,67,83,56,51,95,87,101,115,116,0,0,37,115,58,10,32,86,46,46,46,46,46,32,61,32,86,105,100,101,111,10,32,65,46,46,46,46,46,32,61,32,65,117,100,105,111,10,32,83,46,46,46,46,46,32,61,32,83,117,98,116,105,116,108,101,10,32,46,70,46,46,46,46,32,61,32,70,114,97,109,101,45,108,101,118,101,108,32,109,117,108,116,105,116,104,114,101,97,100,105,110,103,10,32,46,46,83,46,46,46,32,61,32,83,108,105,99,101,45,108,101,118,101,108,32,109,117,108,116,105,116,104,114,101,97,100,105,110,103,10,32,46,46,46,88,46,46,32,61,32,67,111,100,101,99,32,105,115,32,101,120,112,101,114,105,109,101,110,116,97,108,10,32,46,46,46,46,66,46,32,61,32,83,117,112,112,111,114,116,115,32,100,114,97,119,95,104,111,114,105,122,95,98,97,110,100,10,32,46,46,46,46,46,68,32,61,32,83,117,112,112,111,114,116,115,32,100,105,114,101,99,116,32,114,101,110,100,101,114,105,110,103,32,109,101,116,104,111,100,32,49,10,32,45,45,45,45,45,45,10,0,0,0,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,108,111,111,107,97,104,101,97,100,46,99,0,0,0,0,0,67,111,110,118,101,114,116,32,116,104,101,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,111,110,101,32,111,102,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,102,111,114,109,97,116,115,46,0,0,0,0,0,0,0,0,80,114,111,106,95,73,110,100,105,97,110,97,95,67,83,56,51,95,69,97,115,116,0,0,80,114,111,106,95,73,110,100,105,97,110,97,95,67,83,50,55,95,87,101,115,116,0,0,76,97,118,102,53,53,46,51,51,46,49,48,48,0,0,0,67,65,66,65,67,95,77,65,88,95,66,73,78,32,58,32,37,100,10,0,0,0,0,0,112,115,112,0,0,0,0,0,78,111,32,112,105,120,101,108,32,102,111,114,109,97,116,32,115,112,101,99,105,102,105,101,100,44,32,37,115,32,102,111,114,32,72,46,50,54,52,32,101,110,99,111,100,105,110,103,32,99,104,111,115,101,110,46,10,85,115,101,32,45,112,105,120,95,102,109,116,32,121,117,118,52,50,48,112,32,102,111,114,32,99,111,109,112,97,116,105,98,105,108,105,116,121,32,119,105,116,104,32,111,117,116,100,97,116,101,100,32,109,101,100,105,97,32,112,108,97,121,101,114,115,46,10,0,0,0,80,114,111,106,95,73,110,100,105,97,110,97,95,67,83,50,55,95,69,97,115,116,0,0,70,111,117,110,100,32,109,101,100,105,97,32,100,97,116,97,32,116,97,103,32,77,80,69,71,32,105,110,100,105,99,97,116,105,110,103,32,116,104,105,115,32,105,115,32,97,32,77,79,86,45,112,97,99,107,101,100,32,77,80,69,71,45,80,83,46,10,0,0,0,0,0,80,114,111,106,95,73,108,108,105,110,111,105,115,95,67,83,56,51,95,87,101,115,116,0,104,97,115,104,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,102,105,114,115,116,112,97,115,115,46,99,0,0,0,0,0,80,114,111,106,95,73,108,108,105,110,111,105,115,95,67,83,56,51,95,69,97,115,116,0,99,108,117,115,116,101,114,95,115,105,122,101,95,108,105,109,105,116,0,0,0,0,0,0,115,105,122,101,32,62,32,48,0,0,0,0,0,0,0,0,70,97,100,101,32,105,110,47,111,117,116,32,105,110,112,117,116,32,97,117,100,105,111,46,0,0,0,0,0,0,0,0,80,114,111,106,95,73,108,108,105,110,111,105,115,95,67,83,50,55,95,87,101,115,116,0,101,120,112,105,114,101,58,32,37,120,32,61,32,37,105,45,37,48,50,105,45,37,48,50,105,10,0,0,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,101,110,99,111,100,101,109,118,46,99,0,0,0,0,0,0,81,85,65,78,84,73,90,69,0,0,0,0,0,0,0,0,80,114,111,106,95,73,108,108,105,110,111,105,115,95,67,83,50,55,95,69,97,115,116,0,98,97,121,101,114,95,98,103,103,114,49,54,108,101,0,0,84,111,109,97,116,111,0,0,102,105,108,116,101,114,95,116,121,112,101,0,0,0,0,0,105,109,97,103,101,50,32,109,117,120,101,114,0,0,0,0,104,101,118,99,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,56,51,95,87,101,115,116,0,0,0,0,71,67,83,95,78,84,70,0,112,97,115,115,0,0,0,0,105,95,116,101,120,95,98,105,116,115,0,0,0,0,0,0,103,108,111,98,0,0,0,0,105,110,32,99,111,109,112,108,101,120,105,116,121,32,101,115,116,105,109,97,116,105,111,110,32,112,97,114,116,32,49,0,116,114,101,108,108,105,115,0,45,49,0,0,0,0,0,0,118,105,100,101,111,32,115,121,110,99,32,109,101,116,104,111,100,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,76,79,67,79,0,0,0,0,112,97,109,0,0,0,0,0,83,121,110,116,104,80,111,112,0,0,0,0,0,0,0,0,112,114,111,98,105,110,103,32,115,116,114,101,97,109,32,37,100,32,112,112,58,37,100,10,0,0,0,0,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,56,51,95,67,101,110,116,114,97,108,0,115,116,45,62,99,111,100,101,99,45,62,101,120,116,114,97,100,97,116,97,95,115,105,122,101,32,62,61,32,52,49,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,101,110,99,111,100,101,109,98,46,99,0,0,0,0,0,0,65,100,100,32,101,99,104,111,105,110,103,32,116,111,32,116,104,101,32,97,117,100,105,111,46,0,0,0,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,56,51,95,69,97,115,116,0,0,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,58,0,0,84,80,69,49,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,50,55,95,87,101,115,116,0,0,0,0,68,101,108,97,121,32,111,110,101,32,111,114,32,109,111,114,101,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,46,0,0,0,0,0,0,0,115,101,110,100,99,109,100,0,77,111,114,101,32,116,104,97,110,32,97,32,115,105,110,103,108,101,32,118,105,100,101,111,32,115,116,114,101,97,109,32,112,114,101,115,101,110,116,44,32,101,120,112,101,99,116,32,105,115,115,117,101,115,32,100,101,99,111,100,105,110,103,32,105,116,46,10,0,0,0,0,85,110,97,98,108,101,32,116,111,32,114,101,97,100,32,107,101,121,32,102,105,108,101,32,37,115,10,0,0,0,0,0,9,60,98,111,111,116,115,116,114,97,112,73,110,102,111,32,112,114,111,102,105,108,101,61,34,110,97,109,101,100,34,32,117,114,108,61,34,115,116,114,101,97,109,37,100,46,97,98,115,116,34,32,105,100,61,34,98,111,111,116,115,116,114,97,112,37,100,34,32,47,62,10,0,0,0,0,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,50,55,95,67,101,110,116,114,97,108,0,101,110,99,111,100,105,110,103,95,116,111,111,108,0,0,0,111,110,108,121,32,52,56,48,48,48,104,122,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,105,115,32,97,108,108,111,119,101,100,10,0,0,67,111,110,118,101,114,116,32,116,104,101,32,105,110,112,117,116,32,97,117,100,105,111,32,116,111,32,115,97,109,112,108,101,95,102,109,116,58,99,104,97,110,110,101,108,95,108,97,121,111,117,116,46,0,0,0,108,105,98,120,50,54,52,0,105,110,118,97,108,105,100,32,116,114,97,99,107,32,100,101,115,99,114,105,112,116,105,111,110,32,108,101,110,103,116,104,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,80,114,111,106,95,73,100,97,104,111,95,67,83,50,55,95,69,97,115,116,0,0,0,0,102,105,110,97,108,95,100,101,108,97,121,0,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,101,110,99,111,100,101,102,114,97,109,101,46,99,0,0,0,80,114,111,106,95,71,101,111,114,103,105,97,95,67,83,56,51,95,87,101,115,116,0,0,116,121,112,101,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,100,99,116,46,99,0,0,0,118,105,100,101,111,100,97,116,97,114,97,116,101,0,0,0,80,114,111,106,95,71,101,111,114,103,105,97,95,67,83,56,51,95,69,97,115,116,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,99,111,115,116,46,99,0,0,110,117,109,95,99,104,97,110,110,101,108,115,32,40,101,108,101,109,101,110,116,32,48,120,56,50,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,0,0,0,0,80,114,111,106,95,71,101,111,114,103,105,97,95,67,83,50,55,95,87,101,115,116,0,0,71,101,110,101,114,97,116,101,32,97,110,32,97,117,100,105,111,32,115,105,103,110,97,108,32,103,101,110,101,114,97,116,101,100,32,98,121,32,97,110,32,101,120,112,114,101,115,115,105,111,110,46,0,0,0,0,80,114,111,106,95,71,101,111,114,103,105,97,95,67,83,50,55,95,69,97,115,116,0,0,85,110,115,97,102,101,32,102,105,108,101,32,110,97,109,101,32,39,37,115,39,10,0,0,98,97,121,101,114,95,103,114,98,103,56,0,0,0,0,0,84,104,105,115,116,108,101,0,115,97,109,114,70,70,77,80,0,0,0,0,0,0,0,0,115,101,108,101,99,116,32,68,111,108,98,121,32,80,114,111,32,76,111,103,105,99,32,73,73,0,0,0,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,56,51,95,78,111,114,116,104,0,71,67,83,95,68,97,116,117,109,95,55,51,0,0,0,0,97,113,45,115,116,114,101,110,103,116,104,0,0,0,0,0,80,114,101,115,115,32,91,113,93,32,116,111,32,115,116,111,112,44,32,91,63,93,32,102,111,114,32,104,101,108,112,10,0,0,0,0,0,0,0,0,104,101,97,100,101,114,95,98,105,116,115,0,0,0,0,0,86,79,76,32,72,101,97,100,101,114,32,116,114,117,110,99,97,116,101,100,10,0,0,0,115,99,95,116,104,114,101,115,104,111,108,100,0,0,0,0,113,109,105,110,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,98,105,116,115,116,114,101,97,109,46,99,0,0,0,0,0,118,115,121,110,99,0,0,0,108,111,99,111,0,0,0,0,74,80,111,112,0,0,0,0,42,112,107,116,95,98,117,102,102,101,114,0,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,56,51,95,87,101,115,116,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,97,113,95,118,97,114,105,97,110,99,101,46,99,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,56,51,95,69,97,115,116,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,115,58,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,97,113,95,99,121,99,108,105,99,114,101,102,114,101,115,104,46,99,0,0,0,0,0,0,109,111,118,105,0,0,0,0,71,65,66,50,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,58,32,37,117,10,0,0,0,0,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,50,55,95,78,111,114,116,104,0,108,111,111,112,115,116,97,114,116,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,115,102,45,62,112,97,99,107,101,116,95,116,105,109,101,115,116,97,109,112,95,101,110,100,32,62,61,32,97,115,102,45,62,112,97,99,107,101,116,95,116,105,109,101,115,116,97,109,112,95,115,116,97,114,116,0,0,0,0,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,50,55,95,87,101,115,116,0,0,169,116,111,111,0,0,0,0,102,102,32,97,115,102,32,115,107,105,112,32,37,100,32,40,117,110,107,110,111,119,110,32,115,116,114,101,97,109,41,10,0,0,0,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,101,110,116,114,111,112,121,46,104,0,0,0,0,0,0,70,114,97,109,101,32,114,97,116,101,32,118,101,114,121,32,104,105,103,104,32,102,111,114,32,97,32,109,117,120,101,114,32,110,111,116,32,101,102,102,105,99,105,101,110,116,108,121,32,115,117,112,112,111,114,116,105,110,103,32,105,116,46,10,80,108,101,97,115,101,32,99,111,110,115,105,100,101,114,32,115,112,101,99,105,102,121,105,110,103,32,97,32,108,111,119,101,114,32,102,114,97,109,101,114,97,116,101,44,32,97,32,100,105,102,102,101,114,101,110,116,32,109,117,120,101,114,32,111,114,32,45,118,115,121,110,99,32,50,10,0,0,0,0,80,114,111,118,105,100,101,32,97,110,32,117,110,105,102,111,114,109,108,121,32,99,111,108,111,114,101,100,32,105,110,112,117,116,46,0,0,0,0,0,80,114,111,106,95,70,108,111,114,105,100,97,95,67,83,50,55,95,69,97,115,116,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,112,114,101,100,105,99,116,105,111,110,32,109,111,100,101,46,34,0,80,114,111,106,95,68,101,108,97,119,97,114,101,95,67,83,56,51,0,0,0,0,0,0,83,69,73,32,37,100,32,108,101,110,58,37,100,10,0,0,80,114,111,106,95,68,101,108,97,119,97,114,101,95,67,83,50,55,0,0,0,0,0,0,80,114,111,106,95,67,111,110,110,101,99,116,105,99,117,116,95,67,83,56,51,0,0,0,71,101,110,101,114,97,116,101,32,118,97,114,105,111,117,115,32,116,101,115,116,32,112,97,116,116,101,114,110,46,0,0,110,98,95,115,97,109,112,108,101,115,0,0,0,0,0,0,78,79,80,84,83,0,0,0,80,114,111,106,95,67,111,110,110,101,99,116,105,99,117,116,95,67,83,50,55,0,0,0,99,37,100,37,110,0,0,0,98,97,121,101,114,95,103,98,114,103,56,0,0,0,0,0,84,101,97,108,0,0,0,0,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,116,114,101,97,109,32,105,110,100,101,120,58,32,37,100,46,10,0,0,0,0,0,0,0,0,100,112,108,105,105,0,0,0,115,101,116,32,111,117,116,112,117,116,32,103,97,105,110,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,71,67,83,95,78,71,79,95,49,57,52,56,0,0,0,0,97,113,45,109,111,100,101,0,105,110,112,117,116,32,99,104,97,110,110,101,108,32,39,37,115,39,32,110,111,116,32,97,118,97,105,108,97,98,108,101,32,102,114,111,109,32,105,110,112,117,116,32,108,97,121,111,117,116,32,39,37,115,39,10,0,0,0,0,0,0,0,0,109,118,95,98,105,116,115,0,113,117,97,110,116,32,112,114,101,99,105,115,105,111,110,32,37,100,10,0,0,0,0,0,114,101,102,115,0,0,0,0,33,99,116,120,45,62,104,97,118,101,95,115,115,101,0,0,116,121,112,101,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,57,0,0,0,65,110,105,109,101,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,97,108,108,112,97,115,115,0,37,108,108,100,0,0,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,97,116,101,109,112,111,45,62,112,111,115,105,116,105,111,110,91,48,93,32,60,61,32,115,116,111,112,95,104,101,114,101,0,0,0,0,0,0,0,0,111,117,116,50,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,112,98,105,45,62,108,102,95,119,111,114,107,101,114,46,100,97,116,97,49,0,80,101,97,107,32,99,111,117,110,116,58,32,37,102,10,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,105,110,118,97,108,105,100,32,108,105,116,101,114,97,108,47,108,101,110,103,116,104,32,99,111,100,101,0,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,116,105,108,101,95,99,111,109,109,111,110,46,99,0,0,0,0,111,117,116,108,105,110,107,45,62,102,111,114,109,97,116,32,61,61,32,111,117,116,95,102,111,114,109,97,116,0,0,0,116,121,112,101,0,0,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,68,117,114,97,116,105,111,110,32,111,102,32,115,104,111,114,116,101,115,116,32,105,110,112,117,116,46,0,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,115,101,103,95,99,111,109,109,111,110,46,99,0,0,0,0,0,73,110,112,117,116,115,32,109,117,115,116,32,104,97,118,101,32,116,104,101,32,115,97,109,101,32,115,97,109,112,108,101,32,114,97,116,101,32,37,100,32,102,111,114,32,105,110,37,100,32,118,115,32,37,100,10,0,0,0,0,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,46,0,0,0,0,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,50,55,95,67,101,110,116,114,97,108,0,0,0,0,0,0,82,101,110,100,101,114,32,97,32,77,97,110,100,101,108,98,114,111,116,32,102,114,97,99,116,97,108,46,0,0,0,0,99,111,109,112,111,115,101,114,0,0,0,0,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,115,99,97,110,46,99,0,0,0,110,115,0,0,0,0,0,0,78,111,32,105,110,102,111,114,109,97,116,105,111,110,32,97,98,111,117,116,32,116,104,101,32,105,110,112,117,116,32,102,114,97,109,101,114,97,116,101,32,105,115,32,97,118,97,105,108,97,98,108,101,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,97,32,100,101,102,97,117,108,116,32,118,97,108,117,101,32,111,102,32,50,53,102,112,115,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,46,32,85,115,101,32,116,104,101,32,45,114,32,111,112,116,105,111,110,32,105,102,32,121,111,117,32,119,97,110,116,32,97,32,100,105,102,102,101,114,101,110,116,32,102,114,97,109,101,114,97,116,101,46,10,0,100,101,108,97,121,115,0,0,80,114,111,106,95,67,111,108,111,114,97,100,111,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,109,105,45,62,109,98,109,105,46,115,98,95,116,121,112,101,32,61,61,32,98,115,105,122,101,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,115,112,115,95,105,100,32,37,117,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,112,32,61,61,32,80,65,82,84,73,84,73,79,78,95,83,80,76,73,84,32,124,124,32,112,32,61,61,32,80,65,82,84,73,84,73,79,78,95,86,69,82,84,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,54,0,0,115,105,122,101,58,37,100,120,37,100,32,114,97,116,101,58,37,100,47,37,100,32,100,117,114,97,116,105,111,110,58,37,102,32,115,97,114,58,37,100,47,37,100,10,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,114,101,99,111,110,105,110,116,114,97,46,99,0,0,0,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,99,111,109,112,95,105,110,116,101,114,44,32,122,101,114,111,95,99,111,117,110,116,115,46,99,111,109,112,95,105,110,116,101,114,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,99,111,109,112,95,105,110,116,101,114,41,41,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,53,0,0,115,116,97,114,116,95,121,0,81,50,54,52,0,0,0,0,115,101,116,32,115,111,117,114,99,101,32,102,105,108,101,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,52,0,0,112,0,0,0,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,114,101,99,111,110,105,110,116,101,114,46,99,0,0,0,0,0,33,40,108,102,109,45,62,97,98,111,118,101,95,117,118,91,84,88,95,49,54,88,49,54,93,32,38,32,108,102,109,45,62,97,98,111,118,101,95,117,118,91,84,88,95,52,88,52,93,41,0,0,0,0,0,0,116,102,102,0,0,0,0,0,97,98,117,102,102,101,114,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,51,0,0,67,114,101,97,116,101,32,108,105,102,101,46,0,0,0,0,80,73,47,53,0,0,0,0,98,97,121,101,114,95,114,103,103,98,56,0,0,0,0,0,84,97,110,0,0,0,0,0,115,101,108,101,99,116,32,68,111,108,98,121,0,0,0,0,99,120,0,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,50,0,0,71,67,83,95,71,68,52,57,0,0,0,0,0,0,0,0,112,98,45,102,97,99,116,111,114,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,82,84,80,32,112,97,121,108,111,97,100,32,115,105,122,101,32,105,110,32,98,121,116,101,115,0,0,0,0,0,0,0,78,45,98,105,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,113,99,111,109,112,0,0,0,83,116,97,116,32,98,117,102,102,101,114,32,114,101,97,108,108,111,99,32,102,97,105,108,101,100,10,0,0,0,0,0,105,110,116,101,114,108,101,97,118,101,95,98,111,116,116,111,109,0,0,0,0,0,0,0,115,112,101,99,105,102,121,32,116,97,114,103,101,116,32,102,105,108,101,32,116,121,112,101,32,40,34,118,99,100,34,44,32,34,115,118,99,100,34,44,32,34,100,118,100,34,44,32,34,100,118,34,44,32,34,100,118,53,48,34,44,32,34,112,97,108,45,118,99,100,34,44,32,34,110,116,115,99,45,115,118,99,100,34,44,32,46,46,46,41,0,0,0,0,0,0,119,109,118,51,0,0,0,0,115,101,116,32,116,104,101,32,99,111,108,111,114,32,111,102,32,116,104,101,32,117,110,117,115,101,100,32,97,114,101,97,0,0,0,0,0,0,0,0,84,104,114,97,115,104,32,77,101,116,97,108,0,0,0,0,78,79,80,84,83,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,56,51,95,49,0,0,112,97,116,116,101,114,110,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,112,114,101,100,95,99,111,109,109,111,110,46,99,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,86,73,73,0,0,0,0,0,0,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,115,58,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,37,100,32,62,61,32,37,100,10,0,0,0,0,0,97,114,0,0,0,0,0,0,34,73,110,118,97,108,105,100,32,98,108,111,99,107,32,105,110,100,101,120,46,34,0,0,117,115,101,95,98,102,114,97,109,101,95,113,112,0,0,0,99,114,0,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,86,73,0,67,114,101,97,116,101,32,112,97,116,116,101,114,110,32,103,101,110,101,114,97,116,101,100,32,98,121,32,97,110,32,101,108,101,109,101,110,116,97,114,121,32,99,101,108,108,117,108,97,114,32,97,117,116,111,109,97,116,111,110,46,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,86,0,0,79,117,116,112,117,116,32,118,105,100,101,111,32,104,101,105,103,104,116,0,0,0,0,0,169,119,114,116,0,0,0,0,68,111,32,97,98,115,111,108,117,116,101,108,121,32,110,111,116,104,105,110,103,32,119,105,116,104,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,99,114,0,0,0,0,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,102,105,108,116,101,114,115,33,10,0,118,115,117,98,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,73,86,0,121,0,0,0,0,0,0,0,37,115,37,99,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,73,73,73,0,0,0,0,0,0,0,0,117,0,0,0,0,0,0,0,40,40,105,110,116,112,116,114,95,116,41,112,100,45,62,112,114,101,91,48,93,46,98,117,102,32,38,32,48,120,55,41,32,61,61,32,48,0,0,0,121,50,0,0,0,0,0,0,115,101,116,32,116,104,101,32,121,32,111,102,102,115,101,116,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,116,104,101,32,105,110,112,117,116,32,105,109,97,103,101,32,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,73,73,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,108,111,111,112,102,105,108,116,101,114,46,99,0,0,0,0,0,104,115,117,98,0,0,0,0,80,114,111,106,95,67,97,108,105,102,111,114,110,105,97,95,67,83,50,55,95,73,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,99,111,109,112,108,101,120,105,116,121,95,109,97,112,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,102,105,108,116,101,114,46,99,0,116,0,0,0,0,0,0,0,107,101,101,112,0,0,0,0,80,114,111,106,95,65,114,107,97,110,115,97,115,95,67,83,56,51,95,83,111,117,116,104,0,0,0,0,0,0,0,0,78,85,76,76,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,101,110,116,114,111,112,121,109,118,46,99,0,0,0,0,0,0,98,97,121,101,114,95,98,103,103,114,56,0,0,0,0,0,83,116,101,101,108,66,108,117,101,0,0,0,0,0,0,0,68,101,105,110,116,101,114,108,97,99,101,32,116,104,101,32,105,110,112,117,116,32,105,109,97,103,101,46,0,0,0,0,105,110,112,117,116,32,37,100,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,37,100,32,112,108,97,110,101,10,0,0,0,0,0,0,0,0,100,111,108,98,121,0,0,0,113,112,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,99,121,99,108,105,99,95,114,101,102,114,101,115,104,95,109,97,112,0,0,0,0,0,0,80,114,111,106,95,65,114,107,97,110,115,97,115,95,67,83,56,51,95,78,111,114,116,104,0,0,0,0,0,0,0,0,71,67,83,95,78,97,112,97,114,105,109,97,95,49,57,55,50,0,0,0,0,0,0,0,112,98,114,97,116,105,111,0,112,115,0,0,0,0,0,0,37,100,32,115,112,114,105,116,101,95,119,97,114,112,105,110,103,95,112,111,105,110,116,115,10,0,0,0,0,0,0,0,105,110,116,101,114,112,111,108,97,116,101,32,118,97,108,117,101,115,32,117,115,105,110,103,32,116,104,101,32,56,32,112,111,105,110,116,115,32,100,101,102,105,110,105,110,103,32,97,32,99,117,98,101,0,0,0,113,98,108,117,114,0,0,0,68,97,116,97,32,98,117,102,102,101,114,32,97,108,108,111,99,32,40,37,122,117,32,98,121,116,101,115,41,32,102,97,105,108,101,100,10,0,0,0,116,97,114,103,101,116,0,0,83,77,80,84,69,32,86,67,45,49,0,0,0,0,0,0,83,97,108,115,97,0,0,0,102,105,114,115,116,95,100,116,115,32,37,115,32,98,117,116,32,110,111,32,112,97,99,107,101,116,32,119,105,116,104,32,100,116,115,32,105,110,32,116,104,101,32,113,117,101,117,101,10,0,0,0,0,0,0,0,99,49,0,0,0,0,0,0,80,114,111,106,95,65,114,107,97,110,115,97,115,95,67,83,50,55,95,83,111,117,116,104,0,0,0,0,0,0,0,0,118,105,100,101,111,32,105,115,32,97,108,114,101,97,100,121,32,105,110,116,101,114,108,97,99,101,100,44,32,97,100,106,117,115,116,105,110,103,32,102,114,97,109,101,114,97,116,101,32,111,110,108,121,10,0,0,65,112,112,108,121,32,77,97,114,116,105,110,32,87,101,115,116,111,110,32,116,104,114,101,101,32,102,105,101,108,100,32,100,101,105,110,116,101,114,108,97,99,101,46,0,0,0,0,115,101,108,101,99,116,32,97,108,112,104,97,32,109,111,100,101,0,0,0,0,0,0,0,103,95,108,97,103,95,105,110,95,102,114,97,109,101,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,77,65,88,95,76,65,71,95,66,85,70,70,69,82,83,93,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,107,97,110,115,97,115,95,67,83,50,55,95,78,111,114,116,104,0,0,0,0,0,0,0,0,32,37,115,0,0,0,0,0,115,101,116,32,116,104,101,32,104,117,101,32,97,110,103,108,101,32,100,101,103,114,101,101,115,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,114,99,95,111,118,101,114,115,104,111,111,116,95,112,99,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,48,93,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,83,56,51,95,119,101,115,116,0,0,108,101,118,101,108,95,104,101,105,103,104,116,0,0,0,0,97,112,112,108,121,32,115,116,114,111,110,103,32,97,110,116,105,98,97,110,100,105,110,103,0,0,0,0,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,99,111,110,118,111,108,118,101,46,99,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,83,56,51,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,112,97,99,107,101,100,0,0,37,100,0,0,0,0,0,0,116,111,112,32,98,108,111,99,107,32,117,110,97,118,97,105,108,97,98,108,101,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,105,110,116,114,97,52,120,52,32,109,111,100,101,32,37,100,32,97,116,32,37,100,32,37,100,10,0,0,69,110,99,111,100,101,114,32,40,99,111,100,101,99,32,37,115,41,32,110,111,116,32,102,111,117,110,100,32,102,111,114,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,35,37,100,58,37,100,0,0,0,100,111,119,110,0,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,83,56,51,95,101,97,115,116,0,0,83,67,58,37,100,32,124,32,67,79,77,66,83,58,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,40,99,111,109,98,112,101,108,61,37,100,41,32,109,97,116,99,104,61,37,100,32,99,111,109,98,101,100,61,37,115,10,0,0,0,0,0,99,108,70,105,110,105,115,104,0,0,0,0,0,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,111,111,114,100,105,110,97,116,101,95,83,121,115,116,101,109,95,119,101,115,116,0,0,0,0,0,115,0,0,0,0,0,0,0,121,117,118,106,52,52,52,112,0,0,0,0,0,0,0,0,77,97,107,101,32,111,114,32,114,101,118,101,114,115,101,32,97,32,118,105,103,110,101,116,116,101,32,101,102,102,101,99,116,46,0,0,0,0,0,0,37,77,58,37,83,0,0,0,114,0,0,0,0,0,0,0,37,100,47,37,100,0,0,0,97,100,108,101,114,51,50,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,101,99,32,37,100,10,0,0,0,80,114,111,106,95,65,114,105,122,111,110,97,95,67,111,111,114,100,105,110,97,116,101,95,83,121,115,116,101,109,95,67,101,110,116,114,97,108,0,0,101,120,112,0,0,0,0,0,69,79,70,0,0,0,0,0,70,108,105,112,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,118,101,114,116,105,99,97,108,108,121,46,0,0,0,0,0,0,0,0,98,97,99,107,32,108,101,102,116,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,108,97,115,116,73,110,76,117,109,66,117,102,32,43,32,49,32,45,32,115,114,99,83,108,105,99,101,89,32,62,61,32,48,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,103,97,117,115,115,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,99,0,80,114,111,106,95,65,114,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2535584);
/* memory initializer */ allocate([122,111,110,97,95,67,111,111,114,100,105,110,97,116,101,95,83,121,115,116,101,109,95,101,97,115,116,0,0,0,0,0,73,110,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,48,120,37,108,108,120,32,105,115,32,105,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,46,10,0,110,111,108,117,109,97,0,0,104,50,54,49,0,0,0,0,10,0,0,0,0,0,0,0,114,120,0,0,0,0,0,0,116,0,0,0,0,0,0,0,92,102,115,37,49,91,92,125,93,37,110,0,0,0,0,0,83,97,109,112,108,101,32,100,101,112,116,104,32,37,100,0,100,117,112,116,104,114,101,115,104,0,0,0,0,0,0,0,97,100,112,99,109,95,101,97,95,114,50,0,0,0,0,0,80,114,111,106,95,65,108,97,98,97,109,97,95,67,83,56,51,95,87,101,115,116,0,0,77,105,120,105,110,103,32,76,101,118,101,108,0,0,0,0,114,97,116,101,99,111,110,116,114,111,108,95,105,110,105,116,58,32,99,97,110,39,116,32,111,112,101,110,32,109,98,116,114,101,101,32,115,116,97,116,115,32,102,105,108,101,10,0,77,105,120,105,110,103,32,76,101,118,101,108,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,32,114,97,116,101,46,32,109,117,115,116,32,98,101,32,37,100,32,116,111,32,37,100,32,102,111,114,32,116,104,105,115,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,0,0,0,0,108,111,114,111,95,99,109,105,120,108,101,118,0,0,0,0,83,66,82,32,69,120,116,101,110,115,105,111,110,32,111,118,101,114,32,114,101,97,100,46,10,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,121,117,118,106,52,49,49,112,0,0,0,0,0,0,0,0,83,112,114,105,110,103,71,114,101,101,110,0,0,0,0,0,83,66,82,32,115,105,103,110,97,108,101,100,32,116,111,32,98,101,32,110,111,116,45,112,114,101,115,101,110,116,32,98,117,116,32,119,97,115,32,102,111,117,110,100,32,105,110,32,116,104,101,32,98,105,116,115,116,114,101,97,109,46,10,0,115,101,108,101,99,116,32,110,111,110,101,0,0,0,0,0,100,101,99,111,100,101,32,105,50,32,102,114,97,109,101,32,102,97,105,108,101,100,10,0,49,46,50,46,53,0,0,0,105,110,118,97,108,105,100,32,98,105,116,115,32,112,101,114,32,112,105,120,101,108,10,0,108,97,115,116,0,0,0,0,104,50,54,49,0,0,0,0,73,110,118,97,108,105,100,32,100,101,108,116,97,32,112,105,116,99,104,32,104,114,97,110,103,101,59,32,98,114,111,107,101,110,32,101,120,116,114,97,100,97,116,97,63,10,0,0,105,110,118,97,108,105,100,32,115,99,97,108,101,32,102,97,99,116,111,114,32,99,111,100,105,110,103,10,0,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,99,104,97,110,110,101,108,32,108,101,110,40,37,100,41,32,62,32,115,97,109,112,108,101,115,95,112,101,114,95,102,114,97,109,101,40,37,100,41,10,0,0,115,97,109,112,108,101,32,114,97,116,101,32,105,115,32,116,111,111,32,104,105,103,104,58,32,37,100,32,62,32,52,56,107,72,122,10,0,0,0,0,116,111,116,97,108,95,103,97,105,110,32,111,118,101,114,114,101,97,100,10,0,0,0,0,80,114,111,106,95,65,108,97,98,97,109,97,95,67,83,56,51,95,69,97,115,116,0,0,71,67,83,95,78,97,104,114,119,97,110,95,49,57,54,55,0,0,0,0,0,0,0,0,123,92,117,49,125,0,0,0,108,97,118,102,105,46,99,114,111,112,100,101,116,101,99,116,46,121,49,0,0,0,0,0,73,110,118,97,108,105,100,32,87,101,98,80,32,76,111,115,115,108,101,115,115,32,115,105,103,110,97,116,117,114,101,10,0,0,0,0,0,0,0,0,105,112,45,102,97,99,116,111,114,0,0,0,0,0,0,0,97,117,116,111,0,0,0,0,73,110,118,97,108,105,100,32,73,78,84,51,50,73,78,70,79,44,32,115,105,122,101,32,61,32,37,105,10,0,0,0,99,117,114,114,101,110,116,32,115,114,99,95,112,111,115,32,61,32,37,100,44,32,99,111,117,110,116,32,61,32,37,100,44,32,100,101,115,116,95,115,105,122,101,32,61,32,37,100,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,100,101,99,111,100,101,114,32,102,111,114,32,37,100,120,37,100,10,0,115,116,114,97,116,101,103,121,32,116,111,32,99,104,111,111,115,101,32,98,101,116,119,101,101,110,32,73,47,80,47,66,45,102,114,97,109,101,115,0,101,114,114,111,114,32,105,110,32,117,110,112,97,99,107,95,115,117,112,101,114,98,108,111,99,107,115,10,0,0,0,0,83,116,97,116,105,99,32,83,112,114,105,116,101,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,99,98,45,62,110,100,105,109,101,110,115,105,111,110,115,32,62,61,32,50,0,0,0,0,118,114,45,62,99,108,97,115,115,105,102,105,99,97,116,105,111,110,115,32,62,32,49,0,113,100,105,102,102,0,0,0,70,114,97,109,101,32,113,117,101,117,101,32,101,108,101,109,101,110,116,32,97,108,108,111,99,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,105,110,103,32,98,105,116,32,105,110,32,73,100,32,104,101,97,100,101,114,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,100,101,112,116,104,32,37,105,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,104,111,114,105,122,111,110,116,97,108,32,114,97,110,103,101,32,37,100,45,37,100,10,0,115,101,116,32,116,104,101,32,121,32,99,114,111,112,32,97,114,101,97,32,101,120,112,114,101,115,115,105,111,110,0,0,109,98,95,104,101,105,103,104,116,32,62,32,48,0,0,0,102,97,105,108,101,100,32,116,111,32,108,111,97,100,32,79,112,101,110,67,76,10,0,0,69,110,116,114,121,32,112,111,105,110,116,32,105,110,102,111,58,10,66,114,111,107,101,110,76,105,110,107,61,37,105,44,32,67,108,111,115,101,100,69,110,116,114,121,61,37,105,44,32,80,97,110,115,99,97,110,70,108,97,103,61,37,105,10,82,101,102,68,105,115,116,61,37,105,44,32,80,111,115,116,112,114,111,99,61,37,105,44,32,70,97,115,116,85,86,77,67,61,37,105,44,32,69,120,116,77,86,61,37,105,10,68,81,117,97,110,116,61,37,105,44,32,86,83,84,114,97,110,115,102,111,114,109,61,37,105,44,32,79,118,101,114,108,97,112,61,37,105,44,32,81,109,111,100,101,61,37,105,10,0,118,99,49,0,0,0,0,0,115,101,116,32,66,84,46,54,48,49,32,99,111,108,111,114,115,112,97,99,101,0,0,0,77,101,114,101,110,103,117,101,0,0,0,0,0,0,0,0,83,108,105,99,101,32,99,111,117,110,116,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,85,116,32,86,105,100,101,111,32,40,116,104,101,111,114,101,116,105,99,97,108,32,114,97,110,103,101,32,105,115,32,48,45,50,53,54,41,46,10,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,102,105,114,115,116,95,100,116,115,32,37,115,32,110,111,116,32,109,97,116,99,104,105,110,103,32,102,105,114,115,116,32,100,116,115,32,37,115,32,40,112,116,115,32,37,115,44,32,100,117,114,97,116,105,111,110,32,37,100,41,32,105,110,32,116,104,101,32,113,117,101,117,101,10,0,0,0,0,0,0,80,114,111,106,95,65,108,97,98,97,109,97,95,67,83,50,55,95,87,101,115,116,0,0,101,110,99,111,100,101,114,0,83,104,97,114,112,101,110,32,111,114,32,98,108,117,114,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,0,84,84,65,32,68,101,99,111,100,101,114,0,0,0,0,0,103,98,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,115,101,32,86,76,67,115,10,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,72,117,102,102,109,97,110,32,116,114,101,101,32,110,111,100,101,115,58,32,37,105,10,0,0,0,0,0,32,73,78,84,69,82,0,0,99,111,109,112,114,101,115,115,105,111,110,95,97,108,103,111,0,0,0,0,0,0,0,0,103,115,109,0,0,0,0,0,114,104,0,0,0,0,0,0,72,111,119,32,109,97,110,121,32,116,105,109,101,115,32,115,104,111,117,108,100,32,116,104,101,32,98,111,120,98,108,117,114,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,99,104,114,111,109,97,0,0,80,114,111,106,95,65,108,97,98,97,109,97,95,67,83,50,55,95,69,97,115,116,0,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,58,0,0,0,0,71,101,111,103,73,110,118,70,108,97,116,116,101,110,105,110,103,71,101,111,75,101,121,0,82,101,97,100,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,0,0,116,101,120,116,32,100,101,99,111,100,101,114,0,0,0,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,98,108,111,99,107,10,0,0,0,0,0,60,102,111,110,116,32,115,105,122,101,61,34,37,100,34,62,0,0,0,0,0,0,0,0,102,111,110,116,0,0,0,0,112,105,120,101,108,32,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,118,112,56,47,101,110,99,111,100,101,114,47,108,111,111,107,97,104,101,97,100,46,99,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,109,105,115,115,105,110,103,32,82,73,70,70,32,116,97,103,10,0,0,0,0,0,0,0,116,111,111,32,115,104,111,114,116,32,105,110,112,117,116,32,102,114,97,109,101,32,40,37,100,32,98,121,116,101,115,41,10,0,0,0,0,0,0,0,99,48,95,109,111,100,101,0,101,97,114,108,121,32,66,45,102,114,97,109,101,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,54,48,83,0,0,97,118,103,81,80,0,0,0,73,110,118,97,108,105,100,32,55,98,105,116,32,99,111,100,101,119,111,114,100,10,0,0,37,46,54,103,0,0,0,0,104,105,103,104,32,113,117,97,108,105,116,121,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,114,97,109,101,32,116,121,112,101,58,32,37,100,10,0,0,0,0,0,101,114,114,111,114,32,119,114,111,110,103,32,109,98,32,99,111,117,110,116,32,121,32,37,100,32,104,32,37,100,10,0,66,114,111,107,101,110,32,122,84,88,116,32,99,104,117,110,107,10,0,0,0,0,0,0,10,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,57,83,0,0,44,0,0,0,0,0,0,0,97,65,82,84,0,0,0,0,46,47,118,112,56,47,99,111,109,109,111,110,47,111,110,121,120,46,104,0,0,0,0,0,98,101,115,116,95,101,102,102,111,114,116,95,116,105,109,101,115,116,97,109,112,0,0,0,67,111,109,112,108,101,116,105,111,110,32,98,105,116,109,97,115,107,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,101,114,114,111,114,10,0,0,0,0,0,101,110,100,95,115,97,109,112,108,101,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,77,97,120,46,32,115,101,101,107,32,116,105,109,101,32,37,103,32,109,115,10,0,0,0,84,114,97,110,115,112,111,115,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,79,118,101,114,114,105,100,105,110,103,32,97,115,112,101,99,116,32,114,97,116,105,111,32,119,105,116,104,32,115,116,114,101,97,109,32,99,111,112,121,32,109,97,121,32,112,114,111,100,117,99,101,32,105,110,118,97,108,105,100,32,102,105,108,101,115,10,0,0,0,0,0,103,105,102,0,0,0,0,0,113,117,97,110,116,105,122,101,114,95,110,111,105,115,101,95,115,104,97,112,105,110,103,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,56,83,0,0,116,111,111,32,109,97,110,121,32,116,104,114,101,97,100,115,47,115,108,105,99,101,115,32,40,37,100,41,44,32,114,101,100,117,99,105,110,103,32,116,111,32,37,100,10,0,0,0,115,116,114,101,97,109,115,0,67,111,110,118,101,114,115,105,111,110,32,119,105,108,108,32,110,111,116,32,98,101,32,108,111,115,115,108,101,115,115,46,10,0,0,0,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,115,109,97,108,108,101,114,32,116,104,97,110,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,70,114,97,109,101,32,115,105,122,101,32,115,109,97,108,108,101,114,32,116,104,97,110,32,104,101,97,100,101,114,32,115,105,122,101,10,0,0,0,0,82,68,32,111,112,116,105,109,97,108,32,77,66,32,108,101,118,101,108,32,114,101,115,105,100,117,97,108,32,115,107,105,112,112,105,110,103,0,0,0,84,105,109,101,99,111,100,101,32,105,115,32,105,110,32,100,114,111,112,32,102,114,97,109,101,32,102,111,114,109,97,116,46,0,0,0,0,0,0,0,37,108,108,100,0,0,0,0,112,105,99,116,117,114,101,32,105,110,32,101,120,116,114,97,100,97,116,97,10,0,0,0,67,97,110,110,111,116,32,105,110,105,116,32,81,85,65,78,84,32,86,76,67,32,37,105,44,37,105,10,0,0,0,0,115,117,98,115,116,114,101,97,109,32,37,100,32,108,101,110,103,116,104,32,109,105,115,109,97,116,99,104,10,0,0,0,99,111,109,112,111,110,101,110,116,32,37,100,32,37,100,58,37,100,32,105,100,58,32,37,100,32,113,117,97,110,116,58,37,100,10,0,0,0,0,0,115,111,100,32,111,102,102,115,58,32,48,120,37,120,10,0,78,111,32,115,117,99,104,32,102,105,108,116,101,114,58,32,39,37,115,39,10,0,0,0,123,92,102,115,37,100,125,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,55,83,0,0,83,112,101,99,105,102,121,32,108,101,118,101,108,32,40,97,115,32,100,101,102,105,110,101,100,32,98,121,32,65,110,110,101,120,32,65,41,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,97,108,112,104,97,32,101,110,99,111,100,101,114,0,0,0,0,0,0,68,101,99,111,100,101,100,32,115,105,122,101,32,100,105,102,102,101,114,115,32,40,37,100,32,33,61,32,37,108,117,41,10,0,0,0,0,0,0,0,83,99,97,108,101,100,32,112,114,111,98,97,98,105,108,105,116,105,101,115,32,97,114,101,32,108,97,114,103,101,114,32,116,104,97,110,32,116,97,114,103,101,116,33,10,0,0,0,66,108,111,99,107,32,119,105,116,104,32,108,101,110,103,116,104,105,110,99,32,103,114,101,97,116,101,114,32,116,104,97,110,32,37,122,117,0,0,0,123,92,97,110,55,125,0,0,116,98,58,37,100,47,37,100,32,112,116,115,58,37,108,108,100,32,45,62,32,116,98,58,37,100,47,37,100,32,112,116,115,58,37,108,108,100,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,103,105,102,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,67,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,99,111,108,111,114,32,112,108,97,110,101,115,33,10,0,0,0,0,0,0,109,105,115,109,97,116,99,104,105,110,103,32,115,99,97,110,32,116,97,98,108,101,33,10,0,0,0,0,0,0,0,0,77,111,100,101,32,37,100,58,32,82,76,69,32,99,111,100,101,32,37,88,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,97,116,32,116,104,101,32,99,117,114,114,101,110,116,32,108,105,110,101,10,0,0,0,0,0,0,0,0,70,70,84,32,105,110,105,116,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,98,105,116,112,108,97,110,101,115,58,32,37,117,10,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,61,49,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,50,32,112,97,115,115,32,104,117,102,102,121,117,118,32,101,110,99,111,100,105,110,103,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,54,83,0,0,108,101,97,118,101,0,0,0,100,105,115,99,97,114,100,105,110,103,32,115,112,115,32,99,111,110,102,111,114,109,97,110,99,101,32,119,105,110,100,111,119,44,32,111,114,105,103,105,110,97,108,32,118,97,108,117,101,115,32,97,114,101,32,108,58,37,117,32,114,58,37,117,32,116,58,37,117,32,98,58,37,117,10,0,0,0,0,0,70,105,114,115,116,32,115,108,105,99,101,32,105,110,32,97,32,102,114,97,109,101,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,0,0,0,98,108,111,99,107,95,108,114,0,0,0,0,0,0,0,0,109,109,99,111,58,32,117,110,114,101,102,32,115,104,111,114,116,32,37,100,32,99,111,117,110,116,32,37,100,10,0,0,115,112,115,58,37,117,32,112,114,111,102,105,108,101,58,37,100,47,37,100,32,112,111,99,58,37,100,32,114,101,102,58,37,100,32,37,100,120,37,100,32,37,115,32,37,115,32,99,114,111,112,58,37,100,47,37,100,47,37,100,47,37,100,32,37,115,32,37,115,32,37,100,47,37,100,32,98,37,100,32,114,101,111,58,37,100,10,0,72,46,50,54,52,32,47,32,65,86,67,32,47,32,77,80,69,71,45,52,32,65,86,67,32,47,32,77,80,69,71,45,52,32,112,97,114,116,32,49,48,0,0,0,0,0,0,0,111,118,101,114,114,101,97,100,105,110,103,32,37,100,32,98,105,116,115,10,0,0,0,0,113,115,99,97,108,101,32,104,97,115,32,102,111,114,98,105,100,100,101,110,32,48,32,118,97,108,117,101,10,0,0,0,99,111,108,111,114,32,118,97,108,117,101,32,40,65,82,71,66,41,32,116,104,97,116,32,105,115,32,117,115,101,100,32,105,110,115,116,101,97,100,32,111,102,32,116,114,97,110,115,112,97,114,101,110,116,32,99,111,108,111,114,0,0,0,0,115,116,97,114,116,95,116,0,116,114,97,110,115,100,105,102,102,0,0,0,0,0,0,0,99,111,100,101,95,115,105,122,101,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,108,101,32,100,97,116,97,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,53,83,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,66,108,111,99,107,32,112,97,114,97,109,101,116,101,114,115,32,105,110,118,97,108,105,100,58,32,37,100,32,43,32,37,100,32,62,32,37,100,10,0,114,97,110,100,111,109,0,0,78,111,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,115,112,101,99,105,102,105,101,100,46,32,84,104,101,32,101,110,99,111,100,101,114,32,119,105,108,108,32,117,115,101,32,70,108,97,99,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,102,111,114,32,37,100,32,99,104,97,110,110,101,108,115,46,10,0,115,97,109,112,108,101,32,114,97,116,101,32,110,111,116,32,102,111,117,110,100,32,105,110,32,83,84,82,69,65,77,73,78,70,79,32,111,114,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,0,86,101,114,115,105,111,110,32,50,32,110,101,101,100,101,100,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,102,101,97,116,117,114,101,115,32,98,117,116,32,118,101,114,115,105,111,110,32,50,32,105,115,32,101,120,112,101,114,105,109,101,110,116,97,108,32,97,110,100,32,110,111,116,32,101,110,97,98,108,101,100,10,0,0,115,108,105,99,101,95,114,99,116,95,121,95,99,111,101,102,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,103,55,50,57,0,0,0,0,89,0,0,0,0,0,0,0,80,101,114,102,111,114,109,32,116,101,109,112,111,114,97,108,32,102,105,101,108,100,32,105,110,116,101,114,108,97,99,105,110,103,46,0,0,0,0,0,48,0,0,0,0,0,0,0,76,97,114,103,101,32,82,111,111,109,0,0,0,0,0,0,85,110,107,110,111,119,110,32,83,79,76,32,115,117,98,99,111,100,101,99,10,0,0,0,113,109,97,120,0,0,0,0,119,97,118,101,108,101,116,95,105,100,120,32,105,115,32,116,111,111,32,98,105,103,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,68,84,83,45,88,88,67,72,58,32,73,110,99,111,110,115,105,115,116,97,110,116,32,97,118,99,111,100,101,99,47,100,116,115,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,10,0,0,0,0,0,67,111,110,116,97,105,110,101,114,32,99,104,97,110,110,101,108,115,32,33,61,32,49,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,52,83,0,0,111,117,116,95,115,97,109,112,108,101,95,102,109,116,0,0,103,98,114,97,112,49,54,108,101,0,0,0,0,0,0,0,83,110,111,119,0,0,0,0,110,111,110,101,0,0,0,0,109,106,112,101,103,0,0,0,109,105,110,95,115,116,114,105,112,115,0,0,0,0,0,0,99,104,97,110,110,101,108,115,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,105,110,116,114,97,32,99,98,112,10,0,0,0,0,0,0,110,111,116,32,101,110,111,117,103,104,32,100,97,116,97,32,40,37,100,32,60,32,37,100,41,10,0,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,32,111,114,32,116,111,111,32,115,104,111,114,116,10,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,51,83,0,0,71,67,83,95,78,65,68,56,51,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,97,109,111,117,110,116,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,102,114,97,109,101,32,37,100,46,10,0,0,0,0,0,0,0,0,105,112,114,97,116,105,111,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,0,79,110,108,121,32,109,111,110,111,32,97,110,100,32,115,116,101,114,101,111,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,118,112,56,47,101,110,99,111,100,101,114,47,100,101,110,111,105,115,105,110,103,46,99,0,77,105,115,115,105,110,103,32,114,101,113,117,105,114,101,100,32,65,76,83,32,101,120,116,114,97,100,97,116,97,46,10,0,0,0,0,0,0,0,0,98,95,115,116,114,97,116,101,103,121,0,0,0,0,0,0,77,80,69,71,52,32,79,66,77,67,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,118,101,114,121,32,108,105,107,101,108,121,32,98,117,103,103,121,32,101,110,99,111,100,101,114,41,10,0,0,0,100,101,112,101,110,100,115,0,97,110,97,103,108,121,112,104,95,99,121,97,110,95,114,101,100,0,0,0,0,0,0,0,113,109,97,120,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,108,105,98,118,112,120,101,110,99,46,99,0,0,82,38,66,0,0,0,0,0,87,77,47,71,101,110,114,101,0,0,0,0,0,0,0,0,114,101,97,100,32,105,110,112,117,116,32,97,116,32,110,97,116,105,118,101,32,102,114,97,109,101,32,114,97,116,101,0,116,105,116,108,101,0,0,0,82,101,97,108,86,105,100,101,111,32,52,46,48,0,0,0,67,104,114,105,115,116,105,97,110,32,82,111,99,107,0,0,39,115,99,97,108,101,39,32,102,105,108,116,101,114,32,110,111,116,32,112,114,101,115,101,110,116,44,32,99,97,110,110,111,116,32,99,111,110,118,101,114,116,32,112,105,120,101,108,32,102,111,114,109,97,116,115,46,10,0,0,0,0,0,0,52,50,48,112,49,50,0,0,103,55,50,54,0,0,0,0,102,108,118,0,0,0,0,0,119,114,105,116,101,32,115,116,114,101,97,109,32,99,111,100,101,99,32,105,110,102,111,32,102,97,105,108,101,100,32,99,111,100,101,99,95,116,121,112,101,40,48,120,37,120,41,10,0,0,0,0,0,0,0,0,84,105,108,101,32,115,101,118,101,114,97,108,32,115,117,99,99,101,115,115,105,118,101,32,102,114,97,109,101,115,32,116,111,103,101,116,104,101,114,46,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,50,83,0,0,116,105,109,101,108,105,110,101,32,100,97,116,97,32,109,105,115,115,105,110,103,10,0,0,119,101,98,118,116,116,95,107,105,110,100,0,0,0,0,0,74,85,78,75,0,0,0,0,99,114,101,97,116,105,111,110,95,116,105,109,101,0,0,0,97,114,114,97,110,103,101,114,0,0,0,0,0,0,0,0,84,105,109,101,85,110,105,116,68,101,110,111,109,105,110,97,116,111,114,0,0,0,0,0,100,101,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,97,100,100,105,116,105,111,110,97,108,32,105,100,51,32,100,97,116,97,44,32,115,107,105,112,112,105,110,103,10,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,32,39,37,115,39,32,102,111,114,32,111,117,116,112,117,116,32,39,37,115,39,10,0,0,34,115,116,97,114,116,84,105,109,101,34,0,0,0,0,0,112,105,110,103,0,0,0,0,83,87,70,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,49,32,118,105,100,101,111,32,115,116,114,101,97,109,10,0,37,117,58,37,117,58,37,117,46,37,117,44,37,117,58,37,117,58,37,117,46,37,117,0,83,112,101,99,105,102,105,101,100,32,72,68,32,114,97,116,101,32,111,102,32,37,100,32,72,122,32,119,111,117,108,100,32,114,101,113,117,105,114,101,32,97,110,32,105,109,112,111,115,115,105,98,108,101,32,114,101,112,101,116,105,116,105,111,110,32,112,101,114,105,111,100,32,111,102,32,37,100,32,102,111,114,32,116,104,101,32,99,117,114,114,101,110,116,32,68,84,83,32,115,116,114,101,97,109,32,40,98,108,111,99,107,115,32,61,32,37,100,44,32,115,97,109,112,108,101,32,114,97,116,101,32,61,32,37,100,41,10,0,0,0,0,0,0,60,47,83,116,114,101,97,109,73,110,100,101,120,62,10,0,114,97,116,101,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,49,83,0,0,32,37,100,47,37,100,0,0,103,55,50,51,95,49,0,0,83,101,108,101,99,116,32,116,104,101,32,109,111,115,116,32,114,101,112,114,101,115,101,110,116,97,116,105,118,101,32,102,114,97,109,101,32,105,110,32,97,32,103,105,118,101,110,32,115,101,113,117,101,110,99,101,32,111,102,32,99,111,110,115,101,99,117,116,105,118,101,32,102,114,97,109,101,115,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,103,55,50,50,0,0,0,0,118,112,56,47,101,110,99,111,100,101,114,47,98,105,116,115,116,114,101,97,109,46,99,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,103,55,50,50,0,0,0,0,45,97,99,111,100,101,99,32,99,111,112,121,32,97,110,100,32,45,118,111,108,32,97,114,101,32,105,110,99,111,109,112,97,116,105,98,108,101,32,40,102,114,97,109,101,115,32,97,114,101,32,110,111,116,32,100,101,99,111,100,101,100,41,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,65,112,112,108,121,32,97,32,116,101,108,101,99,105,110,101,32,112,97,116,116,101,114,110,46,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,55,83,0,0,83,119,97,112,32,85,32,97,110,100,32,86,32,99,111,109,112,111,110,101,110,116,115,46,0,0,0,0,0,0,0,0,84,114,117,110,99,97,116,101,100,32,112,97,99,107,101,116,32,111,114,32,99,111,114,114,117,112,116,32,112,97,114,116,105,116,105,111,110,32,48,32,108,101,110,103,116,104,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,54,83,0,0,103,50,109,0,0,0,0,0,83,99,97,108,101,32,116,104,101,32,105,110,112,117,116,32,98,121,32,50,120,32,117,115,105,110,103,32,116,104,101,32,83,117,112,101,114,50,120,83,97,73,32,112,105,120,101,108,32,97,114,116,32,97,108,103,111,114,105,116,104,109,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,53,83,0,0,102,114,119,117,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,52,83,0,0,103,98,114,97,112,49,54,98,101,0,0,0,0,0,0,0,83,108,97,116,101,71,114,97,121,0,0,0,0,0,0,0,115,101,116,32,109,97,116,114,105,120,101,100,32,115,116,101,114,101,111,32,101,110,99,111,100,105,110,103,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,51,83,0,0,71,67,83,95,78,65,68,95,77,105,99,104,105,103,97,110,0,0,0,0,0,0,0,0,118,98,118,45,105,110,105,116,0,0,0,0,0,0,0,0,114,97,116,101,99,111,110,116,114,111,108,32,109,101,116,104,111,100,0,0,0,0,0,0,102,114,97,112,115,0,0,0,113,109,105,110,0,0,0,0,33,99,116,120,45,62,99,111,100,101,100,95,102,114,97,109,101,95,108,105,115,116,0,0,114,101,0,0,0,0,0,0,114,118,52,48,0,0,0,0,67,111,110,116,101,109,112,111,114,97,114,121,32,67,104,114,105,115,116,105,97,110,0,0,109,111,118,44,109,112,52,44,109,52,97,44,51,103,112,44,51,103,50,44,109,106,50,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,50,83,0,0,102,108,118,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,49,83,0,0,66,97,100,32,112,105,99,116,117,114,101,32,115,116,97,114,116,32,99,111,100,101,10,0,97,115,101,108,101,99,116,0,32,32,32,32,83,117,112,112,111,114,116,101,100,32,102,114,97,109,101,114,97,116,101,115,58,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,111,112,116,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,48,83,0,0,108,105,115,116,95,102,108,97,103,115,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,57,83,0,0,97,61,99,111,110,116,114,111,108,58,115,116,114,101,97,109,105,100,61,37,100,13,10,0,102,108,105,99,0,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,56,83,0,0,102,108,97,115,104,115,118,0,67,111,110,118,101,114,116,32,118,105,100,101,111,32,115,116,101,114,101,111,115,99,111,112,105,99,32,51,68,32,118,105,101,119,46,0,0,0,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,46,114,97,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,55,83,0,0,68,65,84,65,32,116,97,103,32,105,110,32,109,105,100,100,108,101,32,111,102,32,99,104,117,110,107,44,32,102,105,108,101,32,109,97,121,32,98,101,32,98,114,111,107,101,110,46,10,0,0,0,0,0,0,0,102,108,97,115,104,115,118,50,0,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,54,83,0,0,37,117,46,37,117,0,0,0,115,101,112,97,114,97,116,101,32,109,111,100,101,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,53,83,0,0,65,112,112,108,121,32,97,32,115,105,109,112,108,101,32,112,111,115,116,32,112,114,111,99,101,115,115,105,110,103,32,102,105,108,116,101,114,46,0,0,100,110,120,104,100,0,0,0,114,97,119,32,84,114,117,101,72,68,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,52,83,0,0,103,98,114,97,112,0,0,0,83,108,97,116,101,66,108,117,101,0,0,0,0,0,0,0,109,97,116,114,105,120,95,101,110,99,111,100,105,110,103,0,102,108,97,115,104,115,118,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,51,83,0,0,71,67,83,95,78,65,68,50,55,0,0,0,0,0,0,0,118,98,118,45,98,117,102,115,105,122,101,0,0,0,0,0,114,99,95,115,116,114,97,116,101,103,121,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,97,102,116,101,114,32,104,101,105,103,104,116,0,0,0,0,105,95,113,102,97,99,116,111,114,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,110,0,0,0,0,0,0,0,119,104,101,110,32,100,117,109,112,105,110,103,32,112,97,99,107,101,116,115,44,32,97,108,115,111,32,100,117,109,112,32,116,104,101,32,112,97,121,108,111,97,100,0,0,0,0,0,82,101,97,108,86,105,100,101,111,32,51,46,48,0,0,0,67,114,111,115,115,111,118,101,114,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,116,115,47,112,116,115,32,99,111,109,98,105,110,97,116,105,111,110,32,37,108,108,105,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,50,83,0,0,66,108,117,114,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,119,105,116,104,111,117,116,32,105,109,112,97,99,116,105,110,103,32,116,104,101,32,111,117,116,108,105,110,101,115,46,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,49,83,0,0,110,111,0,0,0,0,0,0,83,104,111,119,32,116,101,120,116,117,97,108,32,105,110,102,111,114,109,97,116,105,111,110,32,102,111,114,32,101,97,99,104,32,118,105,100,101,111,32,102,114,97,109,101,46,0,0,103,101,110,112,116,115,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,48,83,0,0,78,111,32,101,110,99,114,121,112,116,105,111,110,32,104,101,97,100,101,114,32,102,111,117,110,100,10,0,0,0,0,0,115,101,116,32,118,105,100,101,111,32,115,105,122,101,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,57,83,0,0,70,111,114,99,101,32,102,105,101,108,100,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,118,105,100,101,111,32,102,114,97,109,101,46,0,112,97,103,101,115,105,122,101,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,102,52,118,0,0,0,0,0,110,117,115,45,62,108,97,115,116,95,112,116,115,32,33,61,32,40,40,105,110,116,54,52,95,116,41,48,120,56,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,85,76,76,41,0,0,0,0,0,0,0,83,112,108,105,116,32,105,110,112,117,116,32,118,105,100,101,111,32,102,114,97,109,101,115,32,105,110,116,111,32,102,105,101,108,100,115,46,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,56,83,0,0,118,112,120,95,115,99,97,108,101,47,103,101,110,101,114,105,99,47,121,118,49,50,101,120,116,101,110,100,46,99,0,0,115,116,114,101,97,109,95,105,110,100,101,120,32,61,61,32,45,49,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,55,83,0,0,37,42,115,32,37,42,115,32,37,51,49,115,0,0,0,0,99,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,105,110,100,101,120,32,101,110,116,114,105,101,115,10,0,0,0,0,0,0,0,118,112,120,95,115,99,97,108,101,47,103,101,110,101,114,105,99,47,121,118,49,50,99,111,110,102,105,103,46,99,0,0,102,108,97,99,0,0,0,0,100,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,54,83,0,0,110,101,120,116,95,111,102,115,32,100,105,100,110,39,116,32,99,104,97,110,103,101,46,32,110,111,116,32,100,101,114,105,118,105,110,103,32,112,97,99,107,101,116,32,116,105,109,101,115,116,97,109,112,115,10,0,49,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,53,83,0,0,37,108,108,100,0,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,72,46,50,54,52,32,98,105,116,115,116,114,101,97,109,32,101,114,114,111,114,44,32,115,116,97,114,116,99,111,100,101,32,109,105,115,115,105,110,103,10,0,0,0,0,0,0,0,103,98,114,112,49,52,108,101,0,0,0,0,0,0,0,0,83,107,121,66,108,117,101,0,65,115,115,117,109,101,32,116,104,101,32,102,105,114,115,116,32,112,116,115,32,115,104,111,117,108,100,32,98,101,32,116,104,105,115,32,118,97,108,117,101,32,40,105,110,32,115,97,109,112,108,101,115,41,46,0,80,69,83,32,112,97,99,107,101,116,32,115,105,122,101,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,71,67,83,95,77,95,112,111,114,97,108,111,107,111,0,0,118,98,118,45,109,97,120,114,97,116,101,0,0,0,0,0,109,117,120,114,97,116,101,0,81,80,32,102,97,99,116,111,114,32,98,101,116,119,101,101,110,32,80,45,32,97,110,100,32,66,45,102,114,97,109,101,115,0,0,0,0,0,0,0,98,101,102,111,114,101,32,104,101,105,103,104,116,0,0,0,103,0,0,0,0,0,0,0,83,116,97,116,32,98,117,102,102,101,114,32,97,108,108,111,99,32,40,37,100,32,98,121,116,101,115,41,32,102,97,105,108,101,100,10,0,0,0,0,102,108,97,99,0,0,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,37,115,32,97,115,32,77,80,69,71,32,115,117,98,116,105,116,108,101,115,10,0,0,0,0,104,101,120,0,0,0,0,0,114,118,51,48,0,0,0,0,66,108,97,99,107,32,77,101,116,97,108,0,0,0,0,0,68,84,83,32,37,108,108,105,32,60,32,37,108,108,105,32,111,117,116,32,111,102,32,111,114,100,101,114,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,84,82,67,75,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,49,83,0,0,115,108,105,99,101,0,0,0,100,114,111,112,112,105,110,103,32,108,111,119,32,115,99,111,114,101,32,37,105,32,102,114,97,109,101,32,104,101,97,100,101,114,32,102,114,111,109,32,111,102,102,115,101,116,32,37,105,32,116,111,32,37,105,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,48,83,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,57,83,0,0,105,110,118,97,108,105,100,32,115,121,110,99,32,99,111,100,101,10,0,0,0,0,0,0,83,99,97,108,101,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,115,105,122,101,32,97,110,100,47,111,114,32,99,111,110,118,101,114,116,32,116,104,101,32,105,109,97,103,101,32,102,111,114,109,97,116,46,0,0,0,0,0,105,112,111,100,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,56,83,0,0,102,105,99,0,0,0,0,0,67,104,97,112,116,101,114,32,37,100,32,110,111,116,32,102,111,117,110,100,32,105,110,32,102,105,108,101,10,0,0,0,119,97,118,101,115,121,110,116,104,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,55,83,0,0,102,114,97,109,101,32,104,97,115,104,32,101,110,99,111,100,101,114,32,99,108,97,115,115,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,54,83,0,0,82,101,115,101,114,118,101,32,97,32,103,105,118,101,110,32,97,109,111,117,110,116,32,111,102,32,115,112,97,99,101,32,40,105,110,32,98,121,116,101,115,41,32,97,116,32,116,104,101,32,98,101,103,105,110,110,105,110,103,32,111,102,32,116,104,101,32,102,105,108,101,32,102,111,114,32,116,104,101,32,105,110,100,101,120,32,40,99,117,101,115,41,46,0,0,0,65,112,112,108,121,32,115,104,97,112,101,32,97,100,97,112,116,105,118,101,32,98,108,117,114,46,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2545824);
/* memory initializer */ allocate([115,58,37,100,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,53,83,0,0,114,101,99,111,114,100,58,32,37,120,32,61,32,37,105,45,37,48,50,105,45,37,48,50,105,10,0,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,101,110,116,114,111,112,121,46,104,0,0,0,0,0,0,80,65,76,69,84,84,69,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,52,83,0,0,103,98,114,112,49,52,98,101,0,0,0,0,0,0,0,0,83,105,108,118,101,114,0,0,102,105,114,115,116,95,112,116,115,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,102,102,118,49,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,51,83,0,0,71,67,83,95,77,111,110,116,101,95,77,97,114,105,111,0,105,110,102,0,0,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,116,101,109,112,111,114,97,108,95,102,105,108,116,101,114,46,99,0,0,0,0,0,0,0,98,95,113,102,97,99,116,111,114,0,0,0,0,0,0,0,115,101,108,101,99,116,32,103,108,111,98,47,115,101,113,117,101,110,99,101,32,112,97,116,116,101,114,110,32,116,121,112,101,0,0,0,0,0,0,0,98,101,102,111,114,101,32,119,105,100,116,104,0,0,0,0,102,108,97,103,115,50,0,0,69,114,114,111,114,32,101,110,99,111,100,105,110,103,32,97,108,112,104,97,32,102,114,97,109,101,0,0,0,0,0,0,100,117,109,112,32,101,97,99,104,32,105,110,112,117,116,32,112,97,99,107,101,116,0,0,72,117,102,102,121,117,118,32,70,70,109,112,101,103,32,118,97,114,105,97,110,116,0,0,112,98,109,0,0,0,0,0,72,101,97,118,121,32,77,101,116,97,108,0,0,0,0,0,114,101,97,100,95,102,114,97,109,101,95,105,110,116,101,114,110,97,108,32,115,116,114,101,97,109,61,37,100,44,32,112,116,115,61,37,115,44,32,100,116,115,61,37,115,44,32,115,105,122,101,61,37,100,44,32,100,117,114,97,116,105,111,110,61,37,100,44,32,102,108,97,103,115,61,37,100,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,50,83,0,0,85,110,107,110,111,119,110,32,83,86,88,56,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,32,39,37,100,39,10,0,0,0,82,111,116,97,116,101,32,116,104,101,32,105,110,112,117,116,32,105,109,97,103,101,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,49,83,0,0,102,114,97,109,101,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,48,83,0,0,102,102,118,49,0,0,0,0,37,100,46,116,115,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,115,101,103,109,101,110,116,97,116,105,111,110,46,99,0,0,48,0,0,0,0,0,0,0,82,101,109,111,118,101,32,97,32,84,86,32,108,111,103,111,32,98,97,115,101,100,32,111,110,32,97,32,109,97,115,107,32,105,109,97,103,101,46,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,57,83,0,0,0,9,60,100,117,114,97,116,105,111,110,62,37,102,60,47,100,117,114,97,116,105,111,110,62,10,0,0,0,0,0,0,0,97,112,101,114,109,115,0,0,169,99,112,121,0,0,0,0,111,110,108,121,32,49,54,32,66,73,84,32,80,67,77,32,76,69,32,97,108,108,111,119,101,100,32,102,111,114,32,110,111,119,10,0,0,0,0,0,112,115,112,0,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,56,83,0,0,0,78,117,109,98,101,114,32,111,102,32,116,105,109,101,115,32,116,111,32,108,111,111,112,32,116,104,101,32,111,117,116,112,117,116,58,32,45,49,32,45,32,110,111,32,108,111,111,112,44,32,48,32,45,32,105,110,102,105,110,105,116,101,32,108,111,111,112,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,55,83,0,0,0,111,110,84,101,120,116,68,97,116,97,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,80,117,108,108,117,112,32,102,114,111,109,32,102,105,101,108,100,32,115,101,113,117,101,110,99,101,32,116,111,32,102,114,97,109,101,115,46,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,54,83,0,0,0,114,101,118,105,115,105,111,110,32,40,101,108,101,109,101,110,116,32,48,120,56,48,41,32,115,101,116,32,116,111,32,48,120,37,48,56,120,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,83,0,0,0,115,116,121,112,101,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,83,0,0,0,76,105,110,101,32,37,100,58,32,117,110,107,110,111,119,110,32,107,101,121,119,111,114,100,32,39,37,115,39,10,0,0,103,98,114,112,49,50,108,101,0,0,0,0,0,0,0,0,83,105,101,110,110,97,0,0,0,0,0,12,102,114,109,97,115,97,109,114,0,0,0,0,115,105,109,112,108,105,102,105,101,100,32,49,32,112,97,114,97,109,101,116,101,114,32,97,117,100,105,111,32,116,105,109,101,115,116,97,109,112,32,109,97,116,99,104,105,110,103,44,32,48,40,100,105,115,97,98,108,101,100,41,44,32,49,40,102,105,108,108,105,110,103,32,97,110,100,32,116,114,105,109,109,105,110,103,41,44,32,62,49,40,109,97,120,105,109,117,109,32,115,116,114,101,116,99,104,47,115,113,117,101,101,122,101,32,105,110,32,115,97,109,112,108,101,115,32,112,101,114,32,115,101,99,111,110,100,41,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,83,0,0,0,71,67,83,95,77,104,97,115,116,0,0,0,0,0,0,0,114,97,116,101,116,111,108,0,67,97,108,99,117,108,97,116,101,32,116,104,101,32,80,83,78,82,32,98,101,116,119,101,101,110,32,116,119,111,32,118,105,100,101,111,32,115,116,114,101,97,109,115,46,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,110,117,109,98,101,114,32,111,102,32,66,32,102,114,97,109,101,115,32,98,101,116,119,101,101,110,32,110,111,110,45,66,45,102,114,97,109,101,115,0,0,0,0,0,98,101,102,111,114,101,32,102,105,120,101,100,95,118,111,112,95,114,97,116,101,0,0,0,45,49,0,0,0,0,0,0,69,114,114,111,114,32,101,110,99,111,100,105,110,103,32,102,114,97,109,101,0,0,0,0,105,67,69,32,68,114,97,119,32,70,105,108,101,32,100,101,109,117,120,101,114,0,0,0,101,120,114,0,0,0,0,0,100,117,109,112,0,0,0,0,37,108,108,117,32,102,114,97,109,101,115,32,115,117,99,99,101,115,115,102,117,108,108,121,32,100,101,99,111,100,101,100,44,32,37,108,108,117,32,100,101,99,111,100,105,110,103,32,101,114,114,111,114,115,10,0,102,102,118,104,117,102,102,0,67,104,114,105,115,116,105,97,110,32,71,97,110,103,115,116,97,0,0,0,0,0,0,0,100,101,109,117,120,101,114,32,105,110,106,101,99,116,105,110,103,32,115,107,105,112,32,37,100,10,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,83,0,0,0,70,105,108,116,101,114,32,118,105,100,101,111,32,117,115,105,110,103,32,108,105,98,112,111,115,116,112,114,111,99,46,0,101,118,114,99,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,83,0,0,0,102,114,97,109,101,32,97,110,100,32,115,108,105,99,101,0,84,101,115,116,32,112,105,120,101,108,32,102,111,114,109,97,116,32,100,101,102,105,110,105,116,105,111,110,115,46,0,0,65,86,73,88,0,0,0,0,101,115,99,97,112,101,49,51,48,0,0,0,0,0,0,0,83,119,105,116,99,104,105,110,103,32,116,111,32,78,73,32,109,111,100,101,44,32,100,117,101,32,116,111,32,112,111,111,114,32,105,110,116,101,114,108,101,97,118,105,110,103,10,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,117,10,0,0,101,115,99,97,112,101,49,50,52,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,54,48,78,0,0,65,83,84,32,109,117,120,101,114,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,101,97,116,113,105,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,57,78,0,0,169,103,101,110,0,0,0,0,114,101,116,32,62,61,32,48,0,0,0,0,0,0,0,0,51,103,50,0,0,0,0,0,101,97,116,103,118,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,56,78,0,0,80,104,97,115,101,32,115,104,105,102,116,32,102,105,101,108,100,115,46,0,0,0,0,0,101,97,116,103,113,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,55,78,0,0,101,97,109,97,100,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,54,78,0,0,101,97,99,109,118,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,53,78,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,114,100,111,112,116,46,99,0,110,98,95,99,111,110,115,117,109,101,100,95,115,97,109,112,108,101,115,0,0,0,0,0,115,105,108,101,110,99,101,95,101,110,100,58,32,37,115,32,124,32,115,105,108,101,110,99,101,95,100,117,114,97,116,105,111,110,58,32,37,115,10,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,52,78,0,0,67,111,114,114,101,99,116,32,116,104,101,32,112,101,114,115,112,101,99,116,105,118,101,32,111,102,32,118,105,100,101,111,46,0,0,0,0,0,0,0,37,55,91,65,45,90,93,37,110,0,0,0,0,0,0,0,103,98,114,112,49,50,98,101,0,0,0,0,0,0,0,0,83,101,97,83,104,101,108,108,0,0,0,0,0,0,0,0,77,117,108,116,105,112,108,101,32,109,97,112,115,32,102,111,114,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,32,39,37,115,39,46,10,0,97,115,121,110,99,0,0,0,103,97,105,110,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,51,78,0,0,71,67,83,95,77,105,110,110,97,0,0,0,0,0,0,0,113,112,45,115,116,101,112,0,98,102,0,0,0,0,0,0,100,101,102,97,117,108,116,0,116,105,109,101,95,98,97,115,101,46,100,101,110,61,61,48,10,0,0,0,0,0,0,0,98,102,0,0,0,0,0,0,114,99,95,108,111,111,107,97,104,101,97,100,0,0,0,0,108,105,109,105,116,0,0,0,80,65,77,32,40,80,111,114,116,97,98,108,101,32,65,110,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,66,101,97,116,0,0,0,0,65,112,112,108,121,32,97,32,104,105,103,104,45,112,97,115,115,32,102,105,108,116,101,114,32,119,105,116,104,32,51,100,66,32,112,111,105,110,116,32,102,114,101,113,117,101,110,99,121,46,0,0,0,0,0,0,102,102,95,114,101,97,100,95,112,97,99,107,101,116,32,115,116,114,101,97,109,61,37,100,44,32,112,116,115,61,37,115,44,32,100,116,115,61,37,115,44,32,115,105,122,101,61,37,100,44,32,100,117,114,97,116,105,111,110,61,37,100,44,32,102,108,97,103,115,61,37,100,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,50,78,0,0,114,101,97,100,95,115,105,122,101,32,60,61,32,97,116,101,109,112,111,45,62,114,105,110,103,0,0,0,0,0,0,0,111,117,116,49,0,0,0,0,79,118,101,114,97,108,108,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,49,78,0,0,32,32,32,32,84,104,114,101,97,100,105,110,103,32,99,97,112,97,98,105,108,105,116,105,101,115,58,32,0,0,0,0,105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,115,32,115,101,116,0,0,0,118,112,57,47,101,110,99,111,100,101,114,47,118,112,57,95,114,97,116,101,99,116,114,108,46,99,0,0,0,0,0,0,111,117,116,108,105,110,107,45,62,99,104,97,110,110,101,108,95,108,97,121,111,117,116,32,61,61,32,111,117,116,95,108,97,121,111,117,116,32,124,124,32,33,111,117,116,108,105,110,107,45,62,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,0,115,101,116,32,109,111,100,117,108,97,116,105,111,110,32,115,112,101,101,100,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,48,78,0,0,111,117,116,115,97,109,112,108,101,115,114,101,102,45,62,110,98,95,115,97,109,112,108,101,115,32,61,61,32,110,95,111,117,116,0,0,0,0,0,0,80,97,100,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,115,104,111,114,116,101,115,116,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,57,78,0,0,101,97,99,51,0,0,0,0,169,99,109,116,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,102,111,114,32,102,97,100,101,32,100,117,114,97,116,105,111,110,0,51,103,112,0,0,0,0,0,115,101,116,32,115,105,103,110,97,108,32,111,117,116,112,117,116,32,103,97,105,110,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,56,78,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,104,0,0,0,0,0,0,0,68,101,110,111,105,115,101,32,117,115,105,110,103,32,119,97,118,101,108,101,116,115,46,0,99,104,0,0,0,0,0,0,100,120,116,111,114,121,0,0,112,32,61,61,32,80,65,82,84,73,84,73,79,78,95,83,80,76,73,84,32,124,124,32,112,32,61,61,32,80,65,82,84,73,84,73,79,78,95,72,79,82,90,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,55,78,0,0,71,101,110,101,114,97,116,101,32,83,77,80,84,69,32,72,68,32,99,111,108,111,114,32,98,97,114,115,46,0,0,0,100,99,95,108,117,109,97,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,105,110,116,114,97,95,105,110,116,101,114,44,32,122,101,114,111,95,99,111,117,110,116,115,46,105,110,116,114,97,95,105,110,116,101,114,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,105,110,116,114,97,95,105,110,116,101,114,41,41,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,54,78,0,0,115,101,116,32,116,104,101,32,105,110,105,116,105,97,108,32,120,32,112,111,115,105,116,105,111,110,0,0,0,0,0,0,100,120,97,0,0,0,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,53,78,0,0,115,101,116,32,105,110,105,116,105,97,108,32,112,97,116,116,101,114,110,0,0,0,0,0,33,40,108,102,109,45,62,97,98,111,118,101,95,117,118,91,84,88,95,49,54,88,49,54,93,32,38,32,108,102,109,45,62,97,98,111,118,101,95,117,118,91,84,88,95,56,88,56,93,41,0,0,0,0,0,0,100,118,118,105,100,101,111,0,115,112,101,99,105,102,121,32,116,104,101,32,97,115,115,117,109,101,100,32,112,105,99,116,117,114,101,32,102,105,101,108,100,32,112,97,114,105,116,121,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,52,78,0,0,83,105,109,112,108,101,32,102,105,108,116,101,114,103,114,97,112,104,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,101,120,97,99,116,108,121,32,111,110,101,32,105,110,112,117,116,32,97,110,100,32,111,117,116,112,117,116,46,10,0,0,0,0,115,101,116,32,108,101,110,115,32,97,110,103,108,101,0,0,121,117,118,52,52,52,112,49,52,108,101,0,0,0,0,0,83,101,97,71,114,101,101,110,0,0,0,0,0,0,0,0,115,101,116,32,109,97,120,105,109,117,109,32,102,97,99,116,111,114,32,98,121,32,119,104,105,99,104,32,100,97,116,97,32,105,115,32,115,116,114,101,116,99,104,101,100,47,115,113,117,101,101,122,101,100,32,116,111,32,109,97,107,101,32,105,116,32,109,97,116,99,104,32,116,104,101,32,116,105,109,101,115,116,97,109,112,115,46,0,115,101,116,32,99,104,114,111,109,97,32,109,97,116,114,105,120,32,104,111,114,105,122,111,110,116,97,108,32,115,105,122,101,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,51,78,0,0,71,67,83,95,77,97,115,115,97,119,97,0,0,0,0,0,113,112,115,116,101,112,0,0,100,118,100,115,117,98,0,0,100,111,32,110,111,116,32,97,112,112,108,121,32,116,114,97,110,115,112,111,115,105,116,105,111,110,32,105,102,32,116,104,101,32,105,110,112,117,116,32,109,97,116,99,104,101,115,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,103,101,111,109,101,116,114,121,0,0,109,97,120,105,109,117,109,32,100,105,102,102,101,114,101,110,99,101,32,98,101,116,119,101,101,110,32,116,104,101,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,115,32,40,86,66,82,41,0,0,0,98,101,102,111,114,101,32,116,105,109,101,95,105,110,99,114,101,109,101,110,116,95,114,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,97,114,110,114,95,115,116,114,101,110,103,116,104,0,0,0,105,110,116,101,114,108,101,97,118,101,32,116,111,112,32,97,110,100,32,98,111,116,116,111,109,32,102,105,101,108,100,115,0,0,0,0,0,0,0,0,115,101,116,32,109,97,120,32,114,117,110,116,105,109,101,32,105,110,32,115,101,99,111,110,100,115,0,0,0,0,0,0,112,97,109,0,0,0,0,0,99,111,108,111,114,0,0,0,80,111,108,115,107,32,80,117,110,107,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,109,101,115,116,97,109,112,115,32,115,116,114,101,97,109,61,37,100,44,32,112,116,115,61,37,115,44,32,100,116,115,61,37,115,44,32,115,105,122,101,61,37,100,10,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,50,78,0,0,98,0,0,0,0,0,0,0,100,118,100,115,117,98,0,0,79,118,101,114,108,97,121,32,97,32,118,105,100,101,111,32,115,111,117,114,99,101,32,111,110,32,116,111,112,32,111,102,32,116,104,101,32,105,110,112,117,116,46,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,49,78,0,0,68,101,99,111,100,101,114,0,97,108,116,101,114,110,97,116,105,110,103,32,102,114,97,109,101,115,32,108,101,102,116,32,102,105,114,115,116,0,0,0,100,118,118,105,100,101,111,0,80,97,115,115,32,116,104,101,32,115,111,117,114,99,101,32,117,110,99,104,97,110,103,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,46,0,0,0,0,0,0,0,0,115,111,102,116,32,116,104,114,101,115,104,111,108,100,105,110,103,0,0,0,0,0,0,0,115,101,116,32,99,104,114,111,109,97,32,114,97,100,105,117,115,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,105,110,116,101,114,108,101,97,118,101,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,108,97,115,116,32,102,114,97,109,101,32,98,117,102,102,101,114,0,0,0,0,100,118,98,115,117,98,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,119,105,100,116,104,0,0,0,169,100,101,115,0,0,0,0,100,118,98,115,117,98,0,0,115,101,116,32,99,104,114,111,109,97,32,114,97,100,105,117,115,0,0,0,0,0,0,0,109,112,52,0,0,0,0,0,104,115,117,98,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,118,112,57,47,100,101,99,111,100,101,114,47,118,112,57,95,116,104,114,101,97,100,46,99,0,0,0,0,0,0,0,0,115,101,116,32,109,101,116,114,105,99,32,112,108,97,110,101,0,0,0,0,0,0,0,0,37,48,46,50,102,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,98,111,116,116,111,109,32,102,105,114,115,116,32,97,110,97,108,121,122,101,0,0,0,0,105,115,95,105,110,116,101,114,95,109,111,100,101,40,109,111,100,101,41,0,0,0,0,0,115,101,116,32,98,111,116,116,111,109,32,108,101,102,116,32,120,32,99,111,111,114,100,105,110,97,116,101,0,0,0,0,121,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,104,0,0,0,0,0,0,0,65,100,100,32,110,111,105,115,101,46,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,115,101,103,109,101,110,116,97,116,105,111,110,95,109,97,112,0,0,0,0,0,0,0,0,40,115,101,109,105,41,114,101,103,117,108,97,114,32,112,97,116,116,101,114,110,0,0,0,73,110,118,97,108,105,100,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,0,100,114,111,112,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,52,78,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,73,68,67,84,32,112,101,114,109,117,116,97,116,105,111,110,32,110,111,116,32,115,101,116,10,0,0,0,0,0,0,0,42,42,42,32,91,37,115,93,32,37,115,37,115,32,109,112,95,105,109,97,103,101,95,116,44,32,37,100,120,37,100,120,37,100,98,112,112,32,37,115,32,37,115,44,32,37,100,32,98,121,116,101,115,10,0,0,121,117,118,52,52,52,112,49,52,98,101,0,0,0,0,0,83,97,110,100,121,66,114,111,119,110,0,0,0,0,0,0,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,102,114,97,109,101,95,98,117,102,102,101,114,115,46,99,0,0,105,110,112,117,116,32,35,37,100,32,108,105,110,107,32,37,115,32,83,65,82,32,37,100,58,37,100,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,111,117,116,112,117,116,32,108,105,110,107,32,37,115,32,83,65,82,32,37,100,58,37,100,10,0,0,0,0,109,97,120,95,115,111,102,116,95,99,111,109,112,0,0,0,97,115,115,117,109,101,32,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,109,98,46,115,115,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,51,78,0,0,71,67,83,95,77,101,114,99,104,105,99,104,0,0,0,0,113,112,45,109,97,120,0,0,118,112,56,47,101,110,99,111,100,101,114,47,116,111,107,101,110,105,122,101,46,99,0,0,100,115,105,99,105,110,118,105,100,101,111,0,0,0,0,0,113,100,105,102,102,0,0,0,71,114,97,121,32,115,104,97,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,116,114,105,108,105,110,101,97,114,0,0,0,0,0,0,0,97,114,110,114,95,109,97,120,95,102,114,97,109,101,115,0,82,101,109,111,118,101,32,110,101,97,114,45,100,117,112,108,105,99,97,116,101,32,102,114,97,109,101,115,46,0,0,0,116,105,109,101,108,105,109,105,116,0,0,0,0,0,0,0,80,71,77,89,85,86,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,32,89,85,86,41,32,105,109,97,103,101,0,0,0,0,0,78,101,103,101,114,112,117,110,107,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,101,114,114,111,114,32,99,111,100,101,0,115,101,101,107,95,102,114,97,109,101,95,103,101,110,101,114,105,99,32,102,97,105,108,101,100,32,97,115,32,116,104,105,115,32,115,116,114,101,97,109,32,115,101,101,109,115,32,116,111,32,99,111,110,116,97,105,110,32,110,111,32,107,101,121,102,114,97,109,101,115,32,97,102,116,101,114,32,116,104,101,32,116,97,114,103,101,116,32,116,105,109,101,115,116,97,109,112,44,32,37,100,32,110,111,110,32,107,101,121,102,114,97,109,101,115,32,102,111,117,110,100,10,0,0,0,0,0,0,115,101,116,32,99,111,109,112,111,110,101,110,116,32,35,48,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,100,112,120,0,0,0,0,0,37,115,32,105,110,116,101,114,108,97,99,105,110,103,10,0,97,108,112,104,97,95,109,111,100,101,0,0,0,0,0,0,103,95,116,104,114,101,97,100,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,54,52,93,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,69,110,99,111,100,101,114,0,85,110,100,101,116,101,114,109,105,110,101,100,32,32,32,32,32,32,0,0,0,0,0,0,72,95,101,120,112,114,58,37,115,32,104,95,100,101,103,95,101,120,112,114,58,37,115,32,115,95,101,120,112,114,58,37,115,32,98,95,101,120,112,114,58,37,115,10,0,0,0,0,114,99,95,117,110,100,101,114,115,104,111,111,116,95,112,99,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,49,48,48,48,93,0,118,112,56,47,101,110,99,111,100,101,114,47,114,100,111,112,116,46,99,0,0,0,0,0,100,112,120,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,48,78,0,0,99,111,108,111,114,50,0,0,115,116,114,111,110,103,0,0,103,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,110,111,114,109,97,108,0,0,101,110,99,111,100,101,114,0,86,105,101,119,115,32,97,114,101,32,105,110,116,101,114,108,101,97,118,101,100,32,98,121,32,99,111,108,117,109,110,115,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,0,114,111,117,110,100,32,97,119,97,121,32,102,114,111,109,32,48,0,0,0,0,0,0,0,109,111,118,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,105,110,116,101,114,112,108,97,121,95,100,112,99,109,0,0,70,114,97,109,101,32,35,37,108,108,100,32,97,116,32,37,115,32,105,115,32,115,116,105,108,108,32,105,110,116,101,114,108,97,99,101,100,10,0,0,99,108,69,110,113,117,101,117,101,87,114,105,116,101,66,117,102,102,101,114,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,55,78,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,102,114,97,109,101,32,116,111,32,119,104,105,99,104,32,116,111,32,97,112,112,108,121,32,116,104,101,32,101,102,102,101,99,116,46,0,121,117,118,106,52,50,50,112,0,0,0,0,0,0,0,0,37,74,58,37,77,58,37,83,0,0,0,0,0,0,0,0,115,101,116,32,118,32,112,108,97,110,101,0,0,0,0,0,37,102,0,0,0,0,0,0,67,82,67,51,50,0,0,0,195,138,204,132,195,138,204,140,195,170,204,132,195,170,204,140,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,54,78,0,0,97,99,111,115,0,0,0,0,69,110,99,111,100,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,100,110,120,104,100,0,0,0,66,76,0,0,0,0,0,0,102,117,108,108,32,99,104,114,111,109,97,32,105,110,116,101,114,112,111,108,97,116,105,111,110,32,102,111,114,32,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,32,39,37,115,39,32,110,111,116,32,121,101,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,108,97,115,116,73,110,76,117,109,66,117,102,32,43,32,49,32,45,32,115,114,99,83,108,105,99,101,89,32,60,32,115,114,99,83,108,105,99,101,72,0,0,0,0,0,0,0,0,77,66,32,114,97,116,101,32,40,37,108,108,100,41,32,62,32,108,101,118,101,108,32,108,105,109,105,116,32,40,37,100,41,10,0,0,0,0,0,0,115,101,116,32,104,101,105,103,104,116,32,111,102,32,103,114,105,100,32,99,101,108,108,0,108,117,109,97,32,98,105,99,117,98,105,99,44,32,99,104,114,111,109,97,32,98,105,108,105,110,101,97,114,0,0,0,82,101,113,117,101,115,116,101,100,32,111,117,116,112,117,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,99,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,53,78,0,0,115,101,116,32,104,101,105,103,104,116,32,102,111,114,32,116,104,101,32,114,101,99,116,97,110,103,117,108,97,114,32,115,101,97,114,99,104,32,97,114,101,97,0,0,0,0,0,0,115,101,116,32,100,101,108,111,103,111,32,97,114,101,97,32,98,97,110,100,32,115,105,122,101,0,0,0,0,0,0,0,100,110,120,104,100,0,0,0,108,105,98,97,118,99,111,100,101,99,47,97,116,114,97,99,51,112,108,117,115,46,99,0,92,102,110,37,49,50,55,91,94,92,125,93,37,49,91,92,125,93,37,110,0,0,0,0,115,101,116,95,105,110,102,111,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,52,78,0,0,83,97,109,112,108,101,32,114,97,116,101,32,109,117,115,116,32,98,101,32,49,49,48,50,53,44,32,50,50,48,53,48,32,111,114,32,52,52,49,48,48,10,0,0,0,0,0,0,77,101,114,103,101,32,112,108,97,110,101,115,46,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,102,114,97,109,101,32,102,114,111,109,32,119,104,105,99,104,32,111,110,101,32,119,105,108,108,32,98,101,32,100,114,111,112,112,101,100,0,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,82,49,0,0,0,0,0,0,0,0,83,117,98,116,105,116,108,101,32,111,112,116,105,111,110,115,58,0,0,0,0,0,0,0,84,104,101,32,108,97,115,116,32,37,100,32,118,101,114,116,105,99,97,108,32,112,105,120,101,108,115,32,119,111,110,39,116,32,98,101,32,100,101,110,111,105,115,101,100,10,0,0,70,114,97,109,101,32,115,105,122,101,58,32,37,100,120,37,100,37,99,59,32,98,105,116,114,97,116,101,58,32,37,100,77,98,112,115,59,32,112,105,120,101,108,32,102,111,114,109,97,116,58,32,37,115,59,32,102,114,97,109,101,114,97,116,101,58,32,37,100,47,37,100,10,0,0,0,0,0,0,0,109,105,120,105,110,103,95,108,101,118,101,108,0,0,0,0,114,98,0,0,0,0,0,0,109,105,120,105,110,103,95,108,101,118,101,108,0,0,0,0,105,110,118,97,108,105,100,32,115,97,109,112,108,101,32,114,97,116,101,10,0,0,0,0,76,116,47,82,116,32,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,98,105,116,115,116,114,101,97,109,32,45,32,99,97,110,110,111,116,32,97,112,112,108,121,32,83,66,82,32,116,111,32,101,108,101,109,101,110,116,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,83,116,101,114,101,111,32,99,111,100,105,110,103,32,109,101,116,104,111,100,0,0,0,0,121,117,118,52,52,52,112,49,50,108,101,0,0,0,0,0,83,97,108,109,111,110,0,0,83,66,82,32,119,97,115,32,102,111,117,110,100,32,98,101,102,111,114,101,32,116,104,101,32,102,105,114,115,116,32,99,104,97,110,110,101,108,32,101,108,101,109,101,110,116,46,10,0,0,0,0,0,0,0,0,115,101,116,32,100,117,114,97,116,105,111,110,32,40,105,110,32,115,101,99,111,110,100,115,41,32,111,118,101,114,32,119,104,105,99,104,32,100,97,116,97,32,105,115,32,115,116,114,101,116,99,104,101,100,47,115,113,117,101,101,122,101,100,32,116,111,32,109,97,107,101,32,105,116,32,109,97,116,99,104,32,116,104,101,32,116,105,109,101,115,116,97,109,112,115,46,0,0,0,0,0,0,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,105,110,118,97,108,105,100,32,98,105,116,109,97,112,32,115,99,97,110,45,108,105,110,101,32,112,97,100,10,0,0,0,75,101,121,32,112,111,105,110,116,32,99,111,111,114,100,105,110,97,116,101,115,32,40,37,102,59,37,102,41,32,97,110,100,32,40,37,102,59,37,102,41,32,97,114,101,32,116,111,111,32,99,108,111,115,101,32,102,114,111,109,32,101,97,99,104,32,111,116,104,101,114,32,111,114,32,110,111,116,32,115,116,114,105,99,116,108,121,32,105,110,99,114,101,97,115,105,110,103,32,111,110,32,116,104,101,32,120,45,97,120,105,115,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,114,97,116,101,32,37,100,32,40,109,105,110,61,37,100,44,32,109,97,120,61,37,100,41,10,0,0,0,0,0,98,114,111,107,101,110,32,115,117,98,102,114,97,109,101,10,0,0,0,0,0,0,0,0,98,114,111,107,101,110,32,102,114,97,109,101,58,32,110,117,109,32,115,117,98,102,114,97,109,101,115,32,62,32,51,49,10,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,58,32,103,111,116,32,37,105,44,32,110,101,101,100,32,37,105,32,111,114,32,102,101,119,101,114,10,0,0,0,0,102,114,97,109,101,95,108,101,110,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,51,78,0,0,71,67,83,95,77,97,110,111,99,97,0,0,0,0,0,0,60,117,62,0,0,0,0,0,105,109,97,103,101,32,100,97,116,97,32,110,111,116,32,102,111,117,110,100,10,0,0,0,108,97,118,102,105,46,99,114,111,112,100,101,116,101,99,116,46,120,50,0,0,0,0,0,108,101,102,116,47,114,105,103,104,116,0,0,0,0,0,0,113,112,109,97,120,0,0,0,69,110,116,114,111,112,121,32,118,97,114,115,32,115,105,122,101,32,115,104,111,117,108,100,32,98,101,32,37,105,44,32,103,111,116,32,37,105,46,10,0,0,0,0,0,0,0,0,99,117,114,114,101,110,116,32,100,101,115,116,95,105,110,100,101,120,32,61,32,37,100,44,32,99,111,117,110,116,32,61,32,37,100,44,32,100,101,115,116,95,115,105,122,101,32,61,32,37,100,10,0,0,0,0,82,101,102,101,114,101,110,99,101,32,115,101,103,109,97,112,32,40,116,101,109,112,61,37,100,44,117,112,100,97,116,101,61,37,100,41,32,101,110,97,98,108,101,100,32,111,110,32,115,105,122,101,45,99,104,97,110,103,101,33,10,0,0,0,109,97,120,105,109,117,109,32,118,105,100,101,111,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,32,40,86,66,82,41,0,0,0,0,0,118,112,51,58,32,102,105,114,115,116,32,102,114,97,109,101,32,110,111,116,32,97,32,107,101,121,102,114,97,109,101,10,0,0,0,0,0,0,0,0,111,110,108,121,32,114,101,99,116,97,110,103,117,108,97,114,32,118,111,108,32,115,117,112,112,111,114,116,101,100,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,112,108,97,99,101,98,111,0,101,110,97,98,108,101,32,117,115,101,32,111,102,32,97,108,116,101,114,110,97,116,101,32,114,101,102,101,114,101,110,99,101,32,102,114,97,109,101,115,32,40,86,80,56,47,50,45,112,97,115,115,32,111,110,108,121,41,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,32,115,105,103,110,97,116,117,114,101,32,105,110,32,73,100,32,104,101,97,100,101,114,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,37,100,32,99,104,97,110,110,101,108,115,44,32,37,100,32,98,105,116,115,47,115,97,109,112,108,101,44,32,98,108,111,99,107,32,97,108,105,103,110,32,61,32,37,100,44,32,115,97,109,112,108,101,32,114,97,116,101,32,61,32,37,100,10,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,111,101,115,110,39,116,32,115,117,112,112,111,114,116,32,105,116,63,10,0,0,0,0,101,110,97,98,108,101,32,111,114,32,100,105,115,97,98,108,101,32,105,110,116,101,114,97,99,116,105,111,110,32,111,110,32,115,116,97,110,100,97,114,100,32,105,110,112,117,116,0,67,104,114,111,109,97,32,115,99,97,108,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,101,120,112,101,99,116,32,119,114,111,110,103,32,112,105,99,116,117,114,101,10,0,0,112,103,109,121,117,118,0,0,98,116,54,48,49,0,0,0,66,114,105,116,80,111,112,0,71,114,97,100,105,101,110,116,32,112,114,101,100,105,99,116,105,111,110,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,116,45,62,105,110,100,101,120,95,101,110,116,114,105,101,115,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,67,111,100,101,99,32,116,121,112,101,32,111,114,32,105,100,32,109,105,115,109,97,116,99,104,101,115,10,0,0,0,0,87,114,111,110,103,32,101,120,116,114,97,100,97,116,97,32,112,114,101,115,101,110,116,10,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,103,114,101,101,110,32,103,97,105,110,32,102,111,114,32,116,104,101,32,103,114,101,101,110,32,99,104,97,110,110,101,108,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,73,110,99,111,114,114,101,99,116,32,116,114,101,101,32,112,97,114,97,109,101,116,101,114,115,32,45,32,108,105,116,101,114,97,108,32,108,101,110,103,116,104,58,32,37,105,44,32,109,97,120,32,99,111,100,101,32,108,101,110,103,116,104,58,32,37,105,10,0,0,0,0,115,101,116,32,116,104,101,32,105,109,97,103,101,32,114,101,115,111,108,117,116,105,111,110,32,40,105,110,32,100,112,105,41,0,0,0,0,0,0,0,65,112,112,108,121,32,109,111,116,105,111,110,32,99,111,109,112,101,110,115,97,116,105,110,103,32,100,101,105,110,116,101,114,108,97,99,105,110,103,46,0,0,0,0,0,0,0,0,115,101,116,32,98,108,117,101,32,109,105,100,116,111,110,101,115,0,0,0,0,0,0,0,99,104,114,111,109,97,95,112,111,119,101,114,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,37,115,32,37,115,32,91,37,115,93,58,10,0,0,0,0,71,101,111,103,83,101,109,105,77,105,110,111,114,65,120,105,115,71,101,111,75,101,121,0,83,111,117,114,99,101,32,100,97,116,97,32,111,118,101,114,114,101,97,100,10,0,0,0,118,112,108,97,121,101,114,32,100,101,99,111,100,101,114,0,100,105,114,97,99,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,101,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,105,110,116,114,97,32,108,117,109,97,32,100,99,10,0,0,0,0,0,123,92,97,110,37,100,125,0,37,49,50,55,91,94,62,93,62,37,110,0,0,0,0,0,67,117,115,116,111,109,32,113,117,97,110,116,32,116,97,98,108,101,10,0,0,0,0,0,84,104,101,32,57,47,55,32,119,97,118,101,108,101,116,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,108,111,115,115,108,101,115,115,32,109,111,100,101,46,10,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2556064);
/* memory initializer */ allocate([102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,104,101,97,100,101,114,32,105,115,32,119,114,111,110,103,32,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,100,97,116,97,32,102,111,114,32,114,97,119,32,102,114,97,109,101,10,0,0,0,0,0,0,0,0,66,79,84,84,79,77,0,0,108,111,119,32,100,101,108,97,121,32,66,10,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,112,97,114,116,105,116,105,111,110,32,100,97,116,97,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,105,115,66,0,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,32,37,100,10,0,0,73,110,118,97,108,105,100,32,56,98,105,116,32,99,111,100,101,119,111,114,100,10,0,0,78,79,80,84,83,0,0,0,115,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,83,116,114,101,97,109,32,105,115,32,111,108,100,32,97,110,100,32,109,97,121,32,110,111,116,32,119,111,114,107,10,0,97,112,99,104,0,0,0,0,112,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,32,99,104,97,110,103,101,100,58,32,111,108,100,58,32,37,100,32,120,32,37,100,44,32,110,101,119,58,32,37,100,32,120,32,37,100,10,0,0,101,114,114,111,114,44,32,115,108,105,99,101,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,37,100,10,0,0,0,0,0,66,114,111,107,101,110,32,116,69,88,116,32,99,104,117,110,107,10,0,0,0,0,0,0,32,120,49,58,37,100,32,120,50,58,37,100,32,121,49,58,37,100,32,121,50,58,37,100,32,119,58,37,100,32,104,58,37,100,32,99,114,111,112,61,37,100,58,37,100,58,37,100,58,37,100,32,100,114,97,119,98,111,120,61,37,100,58,37,100,58,37,100,58,37,100,0,119,58,37,100,32,104,58,37,100,32,115,97,114,58,37,100,47,37,100,32,100,97,114,58,37,100,47,37,100,32,45,62,32,115,97,114,58,37,100,47,37,100,32,100,97,114,58,37,100,47,37,100,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,97,117,116,111,0,0,0,0,169,115,119,114,0,0,0,0,65,86,70,114,97,109,101,0,77,88,77,32,98,105,116,109,97,115,107,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,101,114,114,111,114,10,0,0,0,0,78,117,109,98,101,114,32,111,102,32,116,104,101,32,102,105,114,115,116,32,97,117,100,105,111,32,115,97,109,112,108,101,32,116,104,97,116,32,115,104,111,117,108,100,32,98,101,32,112,97,115,115,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,115,101,32,86,76,67,115,10,0,102,45,62,108,105,110,101,115,105,122,101,91,49,93,32,61,61,32,102,45,62,108,105,110,101,115,105,122,101,91,50,93,0,0,0,0,0,0,0,0,77,97,120,46,32,108,97,103,32,116,105,109,101,32,37,103,32,109,115,10,0,0,0,0,105,115,116,32,38,38,32,33,111,115,116,45,62,102,105,108,116,101,114,0,0,0,0,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,99,104,114,111,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,100,101,99,111,100,105,110,103,32,116,111,32,65,86,95,80,73,88,95,70,77,84,95,78,79,78,69,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,115,112,0,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,98,117,102,102,101,114,32,100,105,109,101,110,115,105,111,110,115,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,115,107,105,112,95,114,100,0,100,102,97,0,0,0,0,0,100,114,111,112,95,102,114,97,109,101,95,116,105,109,101,99,111,100,101,0,0,0,0,0,110,97,110,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,32,72,68,82,32,86,76,67,10,0,0,0,0,78,111,32,114,101,115,116,97,114,116,32,104,101,97,100,101,114,32,112,114,101,115,101,110,116,32,105,110,32,115,117,98,115,116,114,101,97,109,32,37,100,46,10,0,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,105,110,103,32,102,97,99,116,111,114,32,105,110,32,99,111,109,112,111,110,101,110,116,32,37,100,32,37,100,58,37,100,10,0,0,115,111,115,32,111,102,102,115,58,32,48,120,37,120,10,0,80,97,114,115,101,100,95,37,115,95,37,100,0,0,0,0,123,92,102,110,37,46,42,115,125,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,108,101,118,101,108,0,0,0,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,101,110,99,111,100,101,114,0,0,0,0,73,110,102,108,97,116,101,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,83,99,97,108,101,100,32,112,114,111,98,97,98,105,108,105,116,105,101,115,32,105,110,118,97,108,105,100,10,0,0,0,110,111,110,122,101,114,111,98,105,116,115,32,37,100,32,105,110,118,97,108,105,100,10,0,123,92,97,110,54,125,0,0,115,114,0,0,0,0,0,0,84,105,108,101,32,100,97,116,97,95,115,105,122,101,32,109,105,115,109,97,116,99,104,33,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,89,86,49,50,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,0,0,0,0,0,67,117,115,116,111,109,32,115,99,97,110,32,112,97,116,116,101,114,110,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,111,100,105,110,103,32,109,111,100,101,58,32,37,100,10,0,0,0,0,78,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,62,32,50,0,0,77,97,115,107,105,110,103,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,102,111,114,109,97,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,119,105,100,116,104,32,109,117,115,116,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,52,32,116,104,105,115,32,99,111,108,111,114,115,112,97,99,101,32,97,110,100,32,112,114,101,100,105,99,116,111,114,10,0,0,0,0,99,104,114,111,109,97,95,102,111,114,109,97,116,95,105,100,99,32,33,61,32,49,10,0,101,110,116,101,114,0,0,0,73,110,118,97,108,105,100,32,78,65,76,32,117,110,105,116,32,37,100,44,32,115,107,105,112,112,105,110,103,46,10,0,98,108,111,99,107,95,114,108,0,0,0,0,0,0,0,0,109,109,99,111,58,32,117,110,114,101,102,32,115,104,111,114,116,32,102,97,105,108,117,114,101,10,0,0,0,0,0,0,99,114,111,112,32,118,97,108,117,101,115,32,105,110,118,97,108,105,100,32,37,100,32,37,100,32,37,100,32,37,100,32,47,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,110,101,103,97,116,105,118,101,32,110,117,109,98,101,114,32,111,102,32,122,101,114,111,32,99,111,101,102,102,115,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,0,0,65,100,106,117,115,116,32,99,111,108,111,114,115,32,117,115,105,110,103,32,97,32,51,68,32,76,85,84,46,0,0,0,104,50,54,52,0,0,0,0,100,105,115,99,97,114,100,105,110,103,32,37,100,32,106,117,110,107,32,98,105,116,115,32,97,116,32,101,110,100,44,32,110,101,120,116,32,119,111,117,108,100,32,98,101,32,37,88,10,0,0,0,0,0,0,0,114,117,110,32,111,118,101,114,102,108,111,119,32,97,116,32,37,100,120,37,100,10,0,0,116,114,97,110,115,95,99,111,108,111,114,0,0,0,0,0,116,0,0,0,0,0,0,0,101,110,97,98,108,101,32,112,105,99,116,117,114,101,32,111,102,102,115,101,116,116,105,110,103,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,78,111,32,100,105,115,112,108,97,121,32,105,110,102,111,32,45,32,115,107,105,112,112,105,110,103,32,116,105,108,101,10,0,0,0,0,0,0,0,0,100,99,97,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,110,116,101,114,32,102,114,97,109,101,32,119,105,116,104,111,117,116,32,107,101,121,102,114,97,109,101,10,0,0,0,67,104,97,110,110,101,108,32,108,97,121,111,117,116,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,70,108,97,99,44,32,111,117,116,112,117,116,32,115,116,114,101,97,109,32,119,105,108,108,32,104,97,118,101,32,105,110,99,111,114,114,101,99,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,46,10,0,0,0,0,0,0,0,0,115,119,105,116,99,104,32,112,101,114,109,105,115,115,105,111,110,115,0,0,0,0,0,0,98,108,111,99,107,115,105,122,101,32,37,100,32,62,32,37,100,10,0,0,0,0,0,0,102,45,62,112,108,97,110,101,91,106,93,46,113,117,97,110,116,95,116,97,98,108,101,95,105,110,100,101,120,32,61,61,32,102,45,62,97,118,99,116,120,45,62,99,111,110,116,101,120,116,95,109,111,100,101,108,0,0,0,0,0,0,0,0,113,117,97,110,116,95,116,97,98,108,101,95,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,71,0,0,0,0,0,0,0,105,110,112,117,116,37,100,0,108,97,114,103,101,0,0,0,32,37,48,54,120,37,99,0,79,118,101,114,114,101,97,100,32,98,117,102,102,101,114,46,32,73,110,118,97,108,105,100,32,104,101,97,100,101,114,63,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,114,117,110,32,60,32,54,51,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,102,114,97,109,101,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,49,52,49,49,50,48,48,0,78,111,110,32,115,116,97,110,100,97,114,100,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,37,100,32,33,10,0,0,0,0,0,0,0,0,115,117,98,112,97,99,107,101,116,91,37,105,93,46,99,111,111,107,118,101,114,115,105,111,110,61,37,120,10,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,111,117,116,95,115,97,109,112,108,101,95,114,97,116,101,0,121,117,118,52,52,52,112,49,50,98,101,0,0,0,0,0,83,97,100,100,108,101,66,114,111,119,110,0,0,0,0,0,99,111,109,112,95,100,117,114,97,116,105,111,110,0,0,0,82,101,97,108,86,105,100,101,111,32,50,46,48,0,0,0,76,105,109,105,116,32,115,116,114,105,112,115,47,102,114,97,109,101,44,32,118,105,110,116,97,103,101,32,99,111,109,112,97,116,105,98,108,101,32,105,115,32,49,46,46,51,44,32,111,116,104,101,114,119,105,115,101,32,116,104,101,32,109,111,114,101,32,116,104,101,32,98,101,116,116,101,114,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,105,108,108,101,103,97,108,32,105,110,116,114,97,32,99,104,114,111,109,97,32,112,114,101,100,32,109,111,100,101,10,0,73,110,118,97,108,105,100,32,100,105,109,101,110,115,105,111,110,32,37,100,120,37,100,10,0,0,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,10,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,98,108,111,99,107,32,116,121,112,101,32,118,97,108,117,101,115,10,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,71,67,83,95,77,97,108,111,110,103,111,95,49,57,56,55,0,0,0,0,0,0,0,0,86,101,114,115,105,111,110,32,37,100,32,33,61,32,52,46,10,0,0,0,0,0,0,0,113,112,45,109,105,110,0,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,114,97,116,101,115,0,0,73,110,99,111,114,114,101,99,116,32,101,120,116,114,97,100,97,116,97,10,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,112,97,105,114,46,10,0,0,113,109,97,120,0,0,0,0,105,108,108,101,103,97,108,32,99,104,114,111,109,97,32,102,111,114,109,97,116,10,0,0,88,45,68,101,112,101,110,100,115,0,0,0,0,0,0,0,99,111,108,95,105,110,116,101,114,108,101,97,118,101,100,95,108,114,0,0,0,0,0,0,118,101,114,121,115,108,111,119,0,0,0,0,0,0,0,0,97,108,116,114,101,102,0,0,80,111,112,0,0,0,0,0,101,110,99,111,100,101,114,0,80,71,77,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,115,116,100,105,110,0,0,0,73,110,100,105,101,0,0,0,115,99,97,108,101,0,0,0,52,52,52,112,49,52,0,0,119,114,105,116,101,32,115,116,114,101,97,109,32,100,97,116,97,32,102,97,105,108,101,100,32,99,111,100,101,99,95,116,121,112,101,40,48,120,37,120,41,10,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,114,111,111,116,32,100,105,114,101,99,116,111,114,121,32,115,105,122,101,32,101,120,99,101,101,100,115,32,115,101,99,116,111,114,32,115,105,122,101,10,0,0,0,0,0,0,0,0,83,101,116,32,107,105,110,100,32,111,102,32,87,101,98,86,84,84,32,116,114,97,99,107,0,0,0,0,0,0,0,0,111,114,105,103,105,110,97,116,105,111,110,95,116,105,109,101,0,0,0,0,0,0,0,0,65,82,78,71,0,0,0,0,84,105,109,101,85,110,105,116,78,117,109,101,114,97,116,111,114,0,0,0,0,0,0,0,116,116,97,0,0,0,0,0,115,101,108,101,99,116,0,0,34,115,116,97,114,116,79,102,80,97,114,97,103,114,97,112,104,34,0,0,0,0,0,0,33,108,105,110,107,45,62,102,114,97,109,101,95,114,101,113,117,101,115,116,101,100,32,124,124,32,108,105,110,107,45,62,102,108,97,103,115,32,38,32,70,70,95,76,73,78,75,95,70,76,65,71,95,82,69,81,85,69,83,84,95,76,79,79,80,0,0,0,0,0,0,0,83,87,70,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,77,80,51,10,0,0,0,0,85,110,97,98,108,101,32,116,111,32,105,110,105,116,32,122,108,105,98,32,99,111,110,116,101,120,116,10,0,0,0,0,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,68,84,83,32,115,97,109,112,108,101,32,114,97,116,101,32,102,111,114,32,72,68,10,0,60,81,117,97,108,105,116,121,76,101,118,101,108,32,73,110,100,101,120,61,34,37,100,34,32,66,105,116,114,97,116,101,61,34,37,100,34,32,70,111,117,114,67,67,61,34,37,115,34,32,77,97,120,87,105,100,116,104,61,34,37,100,34,32,77,97,120,72,101,105,103,104,116,61,34,37,100,34,32,67,111,100,101,99,80,114,105,118,97,116,101,68,97,116,97,61,34,37,115,34,32,47,62,10,0,0,0,0,0,0,0,0,115,101,116,32,104,111,119,32,109,97,110,121,32,115,97,109,112,108,101,115,32,116,111,32,115,104,111,119,32,105,110,32,116,104,101,32,115,97,109,101,32,112,111,105,110,116,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,67,111,100,101,99,32,39,37,115,39,32,105,115,32,110,111,116,32,114,101,99,111,103,110,105,122,101,100,32,98,121,32,70,70,109,112,101,103,46,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,115,105,122,101,32,105,110,32,105,110,100,101,120,0,0,0,0,0,100,99,97,0,0,0,0,0,67,111,109,112,117,116,101,32,97,110,100,32,97,112,112,108,121,32,97,32,108,111,111,107,117,112,32,116,97,98,108,101,32,116,111,32,116,104,101,32,82,71,66,47,89,85,86,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,57,78,0,0,0,169,100,97,121,0,0,0,0,79,117,116,112,117,116,32,102,105,108,101,32,35,37,100,32,100,111,101,115,32,110,111,116,32,99,111,110,116,97,105,110,32,97,110,121,32,115,116,114,101,97,109,10,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,56,78,0,0,0,97,117,114,97,0,0,0,0,65,112,112,108,121,32,107,101,114,110,101,108,32,100,101,105,110,116,101,114,108,97,99,105,110,103,32,116,111,32,116,104,101,32,105,110,112,117,116,46,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,55,78,0,0,0,99,97,109,115,116,117,100,105,111,0,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,54,78,0,0,0,99,112,105,97,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,53,78,0,0,0,67,111,110,118,101,114,116,32,112,114,111,103,114,101,115,115,105,118,101,32,118,105,100,101,111,32,105,110,116,111,32,105,110,116,101,114,108,97,99,101,100,46,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,52,78,0,0,0,121,117,118,52,50,50,112,49,52,108,101,0,0,0,0,0,82,111,121,97,108,66,108,117,101,0,0,0,0,0,0,0,115,101,116,32,109,105,110,105,109,117,109,32,100,105,102,102,101,114,101,110,99,101,32,98,101,116,119,101,101,110,32,116,105,109,101,115,116,97,109,112,115,32,97,110,100,32,97,117,100,105,111,32,100,97,116,97,32,40,105,110,32,115,101,99,111,110,100,115,41,32,116,111,32,116,114,105,103,103,101,114,32,112,97,100,100,105,110,103,47,116,114,105,109,109,105,110,103,32,116,104,101,32,100,97,116,97,46,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,51,78,0,0,0,71,67,83,95,69,85,82,69,70,56,57,0,0,0,0,0,113,112,109,105,110,0,0,0,109,105,110,105,109,117,109,32,118,105,100,101,111,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,32,40,86,66,82,41,0,0,0,0,0,88,118,105,68,37,100,0,0,115,108,111,119,101,114,0,0,101,110,97,98,108,101,32,101,114,114,111,114,32,114,101,115,105,108,105,101,110,99,101,0,112,103,109,0,0,0,0,0,117,114,108,0,0,0,0,0,84,101,114,114,111,114,0,0,117,110,107,110,111,119,110,32,99,111,100,101,99,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,50,78,0,0,0,99,111,111,107,0,0,0,0,67,97,110,110,111,116,32,99,104,97,110,103,101,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,32,97,102,116,101,114,32,105,110,105,116,105,97,108,105,122,97,116,105,111,110,0,0,0,0,0,0,68,101,105,110,116,101,114,108,101,97,118,101,32,111,114,32,105,110,116,101,114,108,101,97,118,101,32,102,105,101,108,100,115,46,0,0,0,0,0,0,80,67,83,95,87,71,83,56,52,95,85,84,77,95,122,111,110,101,95,49,78,0,0,0,100,101,99,111,100,101,114,115,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,110,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,119,105,100,116,104,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,54,48,83,0,0,0,0,0,0,0,0,115,101,116,32,102,108,97,103,115,32,97,102,102,101,99,116,105,110,103,32,115,101,103,109,101,110,116,32,108,105,115,116,32,103,101,110,101,114,97,116,105,111,110,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,57,83,0,0,0,0,0,0,0,0,58,58,49,0,0,0,0,0,73,110,116,101,114,108,97,99,101,32,100,101,116,101,99,116,32,70,105,108,116,101,114,46,0,0,0,0,0,0,0,0,169,97,108,98,0,0,0,0,107,101,121,32,32,32,32,102,117,110,99,116,105,111,110,10,63,32,32,32,32,32,32,115,104,111,119,32,116,104,105,115,32,104,101,108,112,10,43,32,32,32,32,32,32,105,110,99,114,101,97,115,101,32,118,101,114,98,111,115,105,116,121,10,45,32,32,32,32,32,32,100,101,99,114,101,97,115,101,32,118,101,114,98,111,115,105,116,121,10,99,32,32,32,32,32,32,83,101,110,100,32,99,111,109,109,97,110,100,32,116,111,32,102,105,114,115,116,32,109,97,116,99,104,105,110,103,32,102,105,108,116,101,114,32,115,117,112,112,111,114,116,105,110,103,32,105,116,10,67,32,32,32,32,32,32,83,101,110,100,47,81,117,101,32,99,111,109,109,97,110,100,32,116,111,32,97,108,108,32,109,97,116,99,104,105,110,103,32,102,105,108,116,101,114,115,10,68,32,32,32,32,32,32,99,121,99,108,101,32,116,104,114,111,117,103,104,32,97,118,97,105,108,97,98,108,101,32,100,101,98,117,103,32,109,111,100,101,115,10,104,32,32,32,32,32,32,100,117,109,112,32,112,97,99,107,101,116,115,47,104,101,120,32,112,114,101,115,115,32,116,111,32,99,121,99,108,101,32,116,104,114,111,117,103,104,32,116,104,101,32,51,32,115,116,97,116,101,115,10,113,32,32,32,32,32,32,113,117,105,116,10,115,32,32,32,32,32,32,83,104,111,119,32,81,80,32,104,105,115,116,111,103,114,97,109,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,56,83,0,0,0,0,0,0,0,0,82,84,80,32,109,117,120,101,114,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,55,83,0,0,0,0,0,0,0,0,73,110,100,101,120,32,115,105,122,101,32,37,100,32,40,37,100,32,112,107,116,115,41,32,105,115,32,119,114,111,110,103,44,32,115,104,111,117,108,100,32,98,101,32,37,100,46,10,0,0,0,0,0,0,0,0,73,78,65,77,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,54,83,0,0,0,0,0,0,0,0,37,117,58,37,117,0,0,0,50,53,0,0,0,0,0,0,65,100,106,117,115,116,32,116,104,101,32,104,117,101,32,97,110,100,32,115,97,116,117,114,97,116,105,111,110,32,111,102,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,115,101,112,97,114,97,116,101,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,99,104,97,110,103,101,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,32,97,102,116,101,114,32,105,110,105,116,105,97,108,105,122,97,116,105,111,110,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,53,83,0,0,0,0,0,0,0,0,100,114,99,0,0,0,0,0,116,114,117,101,104,100,0,0,102,105,108,101,110,97,109,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,52,83,0,0,0,0,0,0,0,0,121,117,118,52,50,50,112,49,52,98,101,0,0,0,0,0,82,111,115,121,66,114,111,119,110,0,0,0,0,0,0,0,65,112,112,108,121,32,97,32,72,105,103,104,32,81,117,97,108,105,116,121,32,51,68,32,68,101,110,111,105,115,101,114,46,0,0,0,0,0,0,0,109,105,110,95,104,97,114,100,95,99,111,109,112,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,51,83,0,0,0,0,0,0,0,0,71,67,83,95,77,97,107,97,115,115,97,114,0,0,0,0,114,99,45,108,111,111,107,97,104,101,97,100,0,0,0,0,99,108,67,114,101,97,116,101,66,117,102,102,101,114,32,101,114,114,111,114,32,39,37,100,39,10,0,0,0,0,0,0,113,109,105,110,0,0,0,0,115,50,52,98,101,0,0,0,102,102,109,112,101,103,0,0,115,108,111,119,0,0,0,0,101,114,114,111,114,95,114,101,115,105,108,105,101,110,116,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,80,66,77,32,40,80,111,114,116,97,98,108,101,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,119,114,105,116,101,32,112,114,111,103,114,97,109,45,114,101,97,100,97,98,108,101,32,112,114,111,103,114,101,115,115,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,72,97,114,100,99,111,114,101,0,0,0,0,0,0,0,0,110,111,32,102,114,97,109,101,32,105,110,32,114,118,51,48,47,52,48,32,97,110,100,32,110,111,32,115,97,114,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,50,83,0,0,0,0,0,0,0,0,115,50,52,98,101,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,49,83,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,115,0,0,0,0,0,0,0,0,105,103,110,111,114,101,32,105,110,100,101,120,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,0,0,0,0,0,0,79,77,71,95,66,75,76,83,73,0,0,0,0,0,0,0,67,111,109,112,117,116,101,32,97,110,100,32,100,114,97,119,32,97,32,104,105,115,116,111,103,114,97,109,46,0,0,0,115,105,122,101,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,0,0,0,0,0,0,169,97,117,116,0,0,0,0,83,101,116,32,112,114,101,102,101,114,114,101,100,32,79,103,103,32,112,97,103,101,32,115,105,122,101,46,0,0,0,0,67,104,97,110,103,105,110,103,32,115,116,114,101,97,109,32,112,97,114,97,109,101,116,101,114,115,32,105,110,32,109,117,108,116,105,115,116,114,101,97,109,32,111,103,103,0,0,0,100,101,98,117,103,61,37,100,10,0,0,0,0,0,0,0,78,101,103,97,116,105,118,101,32,112,116,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,115,116,114,101,97,109,32,37,100,44,32,112,116,115,32,37,108,108,100,10,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,47,99,97,98,97,99,46,99,0,114,101,116,117,114,110,32,37,108,108,100,32,37,108,108,100,10,0,0,0,0,0,0,0,65,112,112,108,121,32,103,108,111,98,97,108,32,99,111,108,111,114,32,104,105,115,116,111,103,114,97,109,32,101,113,117,97,108,105,122,97,116,105,111,110,46,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,55,83,0,0,0,0,0,0,0,0,115,97,109,112,108,101,95,98,121,116,101,95,102,111,114,109,97,116,0,0,0,0,0,0,101,115,115,101,110,99,101,32,99,111,110,116,97,105,110,101,114,32,99,111,117,110,116,58,37,100,10,0,0,0,0,0,72,111,114,105,122,111,110,116,97,108,108,121,32,102,108,105,112,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,115,101,116,32,116,104,101,32,97,117,100,105,111,32,100,117,114,97,116,105,111,110,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,54,83,0,0,0,0,0,0,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,68,45,49,48,32,97,101,115,51,32,102,114,97,109,101,10,0,0,67,79,77,80,82,69,83,83,73,79,78,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,53,83,0,0,0,0,0,0,0,0,78,79,80,84,83,0,0,0,68,101,98,97,110,100,115,32,118,105,100,101,111,32,113,117,105,99,107,108,121,32,117,115,105,110,103,32,103,114,97,100,105,101,110,116,115,46,0,0,110,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,52,83,0,0,0,0,0,0,0,0,72,46,50,54,52,32,98,105,116,115,116,114,101,97,109,32,109,97,108,102,111,114,109,101,100,44,32,110,111,32,115,116,97,114,116,99,111,100,101,32,102,111,117,110,100,44,32,117,115,101,32,116,104,101,32,104,50,54,52,95,109,112,52,116,111,97,110,110,101,120,98,32,98,105,116,115,116,114,101,97,109,32,102,105,108,116,101,114,32,40,45,98,115,102,32,104,50,54,52,95,109,112,52,116,111,97,110,110,101,120,98,41,10,0,0,0,0,0,0,0,121,117,118,52,50,50,112,49,50,108,101,0,0,0,0,0,82,101,100,0,0,0,0,0,115,101,116,32,109,105,110,105,109,117,109,32,100,105,102,102,101,114,101,110,99,101,32,98,101,116,119,101,101,110,32,116,105,109,101,115,116,97,109,112,115,32,97,110,100,32,97,117,100,105,111,32,100,97,116,97,32,40,105,110,32,115,101,99,111,110,100,115,41,32,98,101,108,111,119,32,119,104,105,99,104,32,110,111,32,116,105,109,101,115,116,97,109,112,32,99,111,109,112,101,110,115,97,116,105,111,110,32,111,102,32,101,105,116,104,101,114,32,107,105,110,100,32,105,115,32,97,112,112,108,105,101,100,0,0,0,67,66,82,32,72,82,68,32,114,101,113,117,105,114,101,115,32,99,111,110,115,116,97,110,116,32,98,105,116,114,97,116,101,10,0,0,0,0,0,0,79,117,116,112,117,116,32,111,112,116,105,111,110,32,99,97,114,114,121,105,110,103,32,116,104,101,32,114,97,119,32,112,97,99,107,101,116,32,115,105,122,101,46,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,51,83,0,0,0,0,0,0,0,0,71,67,83,95,77,97,104,101,95,49,57,55,49,0,0,0,99,114,102,45,109,97,120,0,100,118,100,32,109,117,120,101,114,0,0,0,0,0,0,0,118,105,100,101,111,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,32,98,108,117,114,32,40,86,66,82,41,0,0,0,0,0,0,0,0,76,97,118,99,37,100,46,37,100,46,37,100,0,0,0,0,102,97,115,116,0,0,0,0,102,108,97,103,115,0,0,0,73,68,88,47,83,85,66,58,32,37,115,32,45,62,32,37,115,10,0,0,0,0,0,0,112,98,109,0,0,0,0,0,112,114,111,103,114,101,115,115,0,0,0,0,0,0,0,0,67,108,117,98,45,72,111,117,115,101,0,0,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,50,83,0,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,49,83,0,0,0,0,0,0,0,0,67,111,100,101,99,32,39,37,115,39,32,105,115,32,107,110,111,119,110,32,116,111,32,70,70,109,112,101,103,44,32,98,117,116,32,110,111,32,37,115,32,102,111,114,32,105,116,32,97,114,101,32,97,118,97,105,108,97,98,108,101,46,32,70,70,109,112,101,103,32,109,105,103,104,116,32,110,101,101,100,32,116,111,32,98,101,32,114,101,99,111,109,112,105,108,101,100,32,119,105,116,104,32,97,100,100,105,116,105,111,110,97,108,32,101,120,116,101,114,110,97,108,32,108,105,98,114,97,114,105,101,115,46,10,0,0,65,112,112,108,121,32,103,101,110,101,114,105,99,32,101,113,117,97,116,105,111,110,32,116,111,32,101,97,99,104,32,112,105,120,101,108,46,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,48,83,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,47,97,110,97,108,121,115,101,46,99,0,0,0,0,0,0,0,83,101,108,101,99,116,32,111,110,101,32,102,114,97,109,101,32,101,118,101,114,121,32,78,32,102,114,97,109,101,115,46,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,57,83,0,0,0,0,0,0,0,0,169,110,97,109,0,0,0,0,97,112,112,108,105,99,97,116,105,111,110,47,109,112,52,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,100,101,98,117,103,32,118,97,108,117,101,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,56,83,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,100,32,81,84,32,99,104,97,112,116,101,114,32,116,114,97,99,107,32,110,111,116,32,102,111,117,110,100,10,0,0,65,84,82,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,55,83,0,0,0,0,0,0,0,0,71,101,110,101,114,97,116,101,32,97,32,102,114,97,109,101,32,112,97,99,107,101,100,32,115,116,101,114,101,111,115,99,111,112,105,99,32,118,105,100,101,111,46,0,0,0,0,0,35,115,116,114,101,97,109,35,44,32,100,116,115,44,32,32,32,32,32,32,32,32,112,116,115,44,32,100,117,114,97,116,105,111,110,44,32,32,32,32,32,115,105,122,101,44,32,104,97,115,104,10,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,54,83,0,0,0,0,0,0,0,0,114,101,115,101,114,118,101,95,105,110,100,101,120,95,115,112,97,99,101,0,0,0,0,0,99,97,110,39,116,32,111,112,101,110,32,102,105,108,101,32,39,37,115,39,10,0,0,0,99,111,109,109,111,110,47,114,101,99,116,97,110,103,108,101,46,104,0,0,0,0,0,0,67,111,114,114,117,112,116,32,103,101,110,101,114,105,99,32,82,77,45,115,116,121,108,101,32,97,117,100,105,111,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,53,83,0,0,0,0,0,0,0,0,101,120,112,101,99,116,101,100,32,37,100,32,66,32,115,105,122,101,32,104,101,97,100,101,114,44,32,103,111,116,32,37,100,10,0,0,0,0,0,0,73,78,67,76,85,68,69,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,52,83,0,0,0,0,0,0,0,0,121,117,118,52,50,50,112,49,50,98,101,0,0,0,0,0,80,117,114,112,108,101,0,0,70,111,114,99,101,32,99,111,110,115,116,97,110,116,32,102,114,97,109,101,114,97,116,101,46,0,0,0,0,0,0,0,109,105,110,95,99,111,109,112,0,0,0,0,0,0,0,0,78,65,76,32,72,82,68,32,112,97,114,97,109,101,116,101,114,115,32,114,101,113,117,105,114,101,32,86,66,86,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,0,0,103,105,102,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,51,83,0,0,0,0,0,0,0,0,71,67,83,95,72,101,114,97,116,95,78,111,114,116,104,0,99,114,102,0,0,0,0,0,113,98,108,117,114,0,0,0,103,108,111,98,95,115,101,113,117,101,110,99,101,0,0,0,70,70,109,112,101,103,32,118,37,100,46,37,100,46,37,100,32,47,32,108,105,98,97,118,99,111,100,101,99,32,98,117,105,108,100,58,32,37,100,0,102,97,115,116,101,114,0,0,118,112,56,102,108,97,103,115,0,0,0,0,0,0,0,0,80,80,77,32,40,80,111,114,116,97,98,108,101,32,80,105,120,101,108,77,97,112,41,32,105,109,97,103,101,0,0,0,97,100,100,32,116,105,109,105,110,103,115,32,102,111,114,32,101,97,99,104,32,116,97,115,107,0,0,0,0,0,0,0,112,103,109,121,117,118,0,0,68,114,117,109,32,38,32,66,97,115,115,0,0,0,0,0,67,111,110,118,101,114,116,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,116,111,32,111,110,101,32,111,102,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,112,105,120,101,108,32,102,111,114,109,97,116,115,46,0,0,117,110,115,112,101,99,105,102,105,101,100,32,115,105,122,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,50,83,0,0,0,0,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,32,37,100,32,97,110,100,32,98,105,116,32,100,101,112,116,104,32,37,100,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,49,83,0,0,0,0,0,0,0,0,78,111,32,99,111,100,101,99,32,110,97,109,101,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,0,0,0,84,76,65,78,0,0,0,0,83,101,116,32,116,104,101,32,102,105,101,108,100,32,111,114,100,101,114,46,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,48,83,0,0,0,0,0,0,0,0,114,101,115,101,110,100,95,104,101,97,100,101,114,115,0,0,115,101,101,107,97,98,108,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,57,83,0,0,0,0,0,0,0,0,9,60,100,101,108,105,118,101,114,121,84,121,112,101,62,115,116,114,101,97,109,105,110,103,60,47,100,101,108,105,118,101,114,121,84,121,112,101,62,10,0,0,0,0,0,0,0,0,101,98,117,114,49,50,56,0,169,65,82,84,0,0,0,0,103,120,102,32,109,117,120,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,116,114,101,97,109,101,100,32,111,117,116,112,117,116,44,32,112,97,116,99,104,32,119,101,108,99,111,109,101,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,116,114,97,99,107,32,105,100,32,37,120,10,0,0,0,0,37,100,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,56,83,0,0,0,0,0,0,0,0,108,111,111,112,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,55,83,0,0,0,0,0,0,0,0,87,97,114,110,105,110,103,58,32,83,112,101,101,120,32,115,116,114,101,97,109,32,104,97,115,32,109,111,114,101,32,116,104,97,110,32,56,32,102,114,97,109,101,115,32,112,101,114,32,112,97,99,107,101,116,46,32,65,100,111,98,101,32,70,108,97,115,104,32,80,108,97,121,101,114,32,99,97,110,110,111,116,32,104,97,110,100,108,101,32,116,104,105,115,33,10,0,0,0,0,0,0,0,0,75,101,121,102,114,97,109,101,32,105,110,100,101,120,32,112,97,114,115,105,110,103,32,102,97,105,108,101,100,10,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,54,83,0,0,0,0,0,0,0,0,101,110,116,101,114,101,100,32,97,117,100,105,111,32,115,117,98,104,101,97,100,101,114,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,53,83,0,0,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,97,117,100,105,111,32,115,97,109,112,108,101,32,114,97,116,101,32,105,110,100,101,120,32,40,37,100,41,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,0,0,0,0,0,0,76,105,110,101,32,37,100,58,32,105,110,118,97,108,105,100,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,0,121,117,118,52,50,48,112,49,52,108,101,0,0,0,0,0,80,111,119,100,101,114,66,108,117,101,0,0,0,0,0,0,0,0,0,12,102,114,109,97,97,108,97,99,0,0,0,0,101,110,97,98,108,101,32,115,111,120,114,32,67,104,101,98,121,115,104,101,118,32,112,97,115,115,98,97,110,100,32,38,32,104,105,103,104,101,114,45,112,114,101,99,105,115,105,111,110,32,105,114,114,97,116,105,111,110,97,108,32,114,97,116,105,111,32,97,112,112,114,111,120,105,109,97,116,105,111,110,0,0,0,0,0,0,0,0,117,115,105,110,103,32,109,118,95,114,97,110,103,101,95,116,104,114,101,97,100,32,61,32,37,100,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,0,0,0,0,0,0,71,67,83,95,72,105,116,111,95,88,86,73,73,73,95,49], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2566304);
/* memory initializer */ allocate([57,54,51,0,0,0,0,0,113,112,95,99,111,110,115,116,97,110,116,0,0,0,0,0,118,105,100,101,111,32,113,117,97,110,116,105,122,101,114,32,115,99,97,108,101,32,99,111,109,112,114,101,115,115,105,111,110,32,40,86,66,82,41,46,32,67,111,110,115,116,97,110,116,32,111,102,32,114,97,116,101,99,111,110,116,114,111,108,32,101,113,117,97,116,105,111,110,46,32,82,101,99,111,109,109,101,110,100,101,100,32,114,97,110,103,101,32,102,111,114,32,100,101,102,97,117,108,116,32,114,99,95,101,113,58,32,48,46,48,45,49,46,48,0,70,70,109,112,101,37,42,91,94,98,93,98,37,100,0,0,118,101,114,121,102,97,115,116,0,0,0,0,0,0,0,0,105,67,69,32,68,114,97,119,32,70,105,108,101,0,0,0,112,112,109,0,0,0,0,0,98,101,110,99,104,109,97,114,107,95,97,108,108,0,0,0,98,101,110,99,104,58,32,117,116,105,109,101,61,37,48,46,51,102,115,10,0,0,0,0,71,111,97,0,0,0,0,0,110,111,32,100,101,99,111,100,97,98,108,101,32,68,84,83,32,102,114,97,109,101,115,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,0,0,0,0,0,0,70,105,101,108,100,32,109,97,116,99,104,105,110,103,32,102,111,114,32,105,110,118,101,114,115,101,32,116,101,108,101,99,105,110,101,46,0,0,0,0,99,108,66,117,105,108,100,80,114,111,103,114,97,109,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,49,83,0,0,0,0,0,0,0,0,68,101,109,117,120,101,114,32,37,115,32,91,37,115,93,58,10,0,0,0,0,0,0,0,84,111,111,32,108,97,114,103,101,32,110,117,109,98,101,114,32,111,102,32,115,107,105,112,112,101,100,32,102,114,97,109,101,115,32,37,108,108,100,32,62,32,54,48,48,48,48,10,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,97,116,97,32,102,111,114,32,112,97,108,101,116,116,101,10,0,0,0,0,85,110,107,110,111,119,110,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,0,76,105,98,97,118,117,116,105,108,32,104,97,115,32,98,101,101,110,32,108,105,110,107,101,100,32,116,111,32,97,32,98,114,111,107,101,110,32,108,108,114,105,110,116,40,41,10,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,48,83,0,0,0,0,0,0,0,0,69,120,116,114,97,99,116,32,97,32,102,105,101,108,100,32,102,114,111,109,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,45,0,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,86,56,0,0,37,45,54,115,32,32,32,37,50,100,32,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,57,83,0,0,0,0,0,0,0,0,100,97,116,101,0,0,0,0,47,100,101,118,47,114,97,110,100,111,109,0,0,0,0,0,105,110,118,97,108,105,100,32,112,97,99,107,101,116,32,104,101,97,100,101,114,32,108,101,110,103,116,104,32,37,100,32,102,111,114,32,112,107,116,108,101,110,32,37,100,45,37,100,32,97,116,32,37,108,108,100,10,0,0,0,0,0,0,0,80,97,114,115,101,32,101,114,114,111,114,44,32,97,116,32,108,101,97,115,116,32,51,32,97,114,103,117,109,101,110,116,115,32,119,101,114,101,32,101,120,112,101,99,116,101,100,44,32,111,110,108,121,32,37,100,32,103,105,118,101,110,32,105,110,32,115,116,114,105,110,103,32,39,37,115,39,10,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,56,83,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,55,83,0,0,0,0,0,0,0,0,121,117,121,118,52,50,50,0,99,111,109,109,111,110,47,109,97,99,114,111,98,108,111,99,107,46,99,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,54,83,0,0,0,0,0,0,0,0,70,97,100,101,32,105,110,47,111,117,116,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,0,0,0,0,0,102,114,97,109,101,115,121,110,99,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,53,83,0,0,0,0,0,0,0,0,48,120,0,0,0,0,0,0,110,98,95,99,104,97,110,110,101,108,115,0,0,0,0,0,108,97,118,102,105,46,115,105,108,101,110,99,101,95,100,117,114,97,116,105,111,110,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,52,83,0,0,0,0,0,0,0,0,32,37,110,0,0,0,0,0,121,117,118,52,50,48,112,49,52,98,101,0,0,0,0,0,80,108,117,109,0,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,39,37,115,39,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,114,101,113,117,101,115,116,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,46,10,0,0,0,0,0,0,0,0,99,104,101,98,121,0,0,0,110,111,110,101,0,0,0,0,105,110,116,101,114,108,97,99,101,32,43,32,119,101,105,103,104,116,112,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,115,101,116,32,115,111,102,116,45,107,110,101,101,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,51,83,0,0,0,0,0,0,0,0,71,67,83,95,76,117,122,111,110,95,49,57,49,49,0,0,113,112,0,0,0,0,0,0,113,99,111,109,112,0,0,0,79,117,116,112,117,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,46,0,0,86,105,100,101,111,32,117,115,101,115,32,97,32,110,111,110,45,115,116,97,110,100,97,114,100,32,97,110,100,32,119,97,115,116,101,102,117,108,32,119,97,121,32,116,111,32,115,116,111,114,101,32,66,45,102,114,97,109,101,115,32,40,39,112,97,99,107,101,100,32,66,45,102,114,97,109,101,115,39,41,46,32,67,111,110,115,105,100,101,114,32,117,115,105,110,103,32,97,32,116,111,111,108,32,108,105,107,101,32,86,105,114,116,117,97,108,68,117,98,32,111,114,32,97,118,105,100,101,109,117,120,32,116,111,32,102,105,120,32,105,116,46,10,0,115,117,112,101,114,102,97,115,116,0,0,0,0,0,0,0,115,112,101,101,100,0,0,0,105,110,95,116,115,32,33,61,32,40,40,105,110,116,54,52,95,116,41,48,120,56,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,85,76,76,41,0,0,0,0,0,0,0,69,120,116,114,97,99,116,32,112,108,97,110,101,115,32,97,115,32,103,114,97,121,115,99,97,108,101,32,102,114,97,109,101,115,46,0,0,0,0,0,80,78,71,32,40,80,111,114,116,97,98,108,101,32,78,101,116,119,111,114,107,32,71,114,97,112,104,105,99,115,41,32,105,109,97,103,101,0,0,0,97,100,100,32,116,105,109,105,110,103,115,32,102,111,114,32,98,101,110,99,104,109,97,114,107,105,110,103,0,0,0,0,68,97,110,99,101,32,72,97,108,108,0,0,0,0,0,0,32,32,32,32,76,97,115,116,32,109,101,115,115,97,103,101,32,114,101,112,101,97,116,101,100,32,37,100,32,116,105,109,101,115,13,0,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,0,0,104,105,103,104,112,97,115,115,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,50,83,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,110,115,97,109,112,108,101,115,32,60,61,32,122,101,114,111,115,32,43,32,110,97,32,43,32,110,98,0,0,0,0,0,109,117,114,109,117,114,51,0,101,0,0,0,0,0,0,0,80,101,97,107,32,99,111,117,110,116,58,32,37,108,108,100,10,0,0,0,0,0,0,0,84,104,105,115,32,98,117,105,108,100,32,111,102,32,120,50,54,52,32,114,101,113,117,105,114,101,115,32,56,45,98,105,116,32,105,110,112,117,116,46,32,82,101,98,117,105,108,100,32,116,111,32,115,117,112,112,111,114,116,32,104,105,103,104,32,100,101,112,116,104,32,105,110,112,117,116,46,10,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,49,83,0,0,0,0,0,0,0,0,32,32,32,32,68,101,102,97,117,108,116,32,115,117,98,116,105,116,108,101,32,99,111,100,101,99,58,32,37,115,46,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,108,105,116,101,114,97,108,47,108,101,110,103,116,104,115,32,115,101,116,0,0,0,0,0,98,116,55,48,57,0,0,0,69,114,114,111,114,32,111,99,99,117,114,114,101,100,32,105,110,32,102,115,116,97,116,40,41,58,32,37,115,10,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,114,101,115,97,109,112,108,101,46,99,0,0,0,0,0,0,65,112,112,108,121,32,112,111,115,116,101,114,105,122,101,32,101,102,102,101,99,116,44,32,117,115,105,110,103,32,116,104,101,32,69,76,66,71,32,97,108,103,111,114,105,116,104,109,46,0,0,0,0,0,0,0,115,112,101,101,100,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,48,83,0,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,102,95,97,112,97,100,46,99,0,0,0,37,102,10,0,0,0,0,0,68,117,114,97,116,105,111,110,32,111,102,32,108,111,110,103,101,115,116,32,105,110,112,117,116,46,0,0,0,0,0,0,115,112,101,99,105,102,121,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,105,110,112,117,116,115,0,0,0,0,66,83,70,95,78,79,84,95,70,79,85,78,68,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,115,97,109,112,108,101,32,114,97,116,101,115,46,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,57,83,0,121,114,114,99,0,0,0,0,99,112,117,102,108,97,103,115,0,0,0,0,0,0,0,0,68,101,116,101,99,116,32,97,110,100,32,100,114,97,119,32,101,100,103,101,46,0,0,0,110,98,95,115,97,109,112,108,101,115,0,0,0,0,0,0,81,117,101,105,110,103,32,99,111,109,109,97,110,100,115,32,111,110,108,121,32,111,110,32,102,105,108,116,101,114,115,32,115,117,112,112,111,114,116,105,110,103,32,116,104,101,32,115,112,101,99,105,102,105,99,32,99,111,109,109,97,110,100,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,111,117,116,95,103,97,105,110,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,56,83,0,37,100,32,99,104,97,110,110,101,108,115,0,0,0,0,0,98,115,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,0,0,0,0,0,77,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,32,101,120,112,114,101,115,115,105,111,110,115,32,39,37,100,39,32,97,110,100,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,101,120,112,101,99,116,101,100,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,115,32,39,37,100,39,32,102,111,114,32,116,104,101,32,115,112,101,99,105,102,105,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,10,0,0,0,0,0,39,92,39,39,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,98,108,111,99,107,100,46,104,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,55,83,0,32,10,9,0,0,0,0,0,115,109,112,116,101,104,100,98,97,114,115,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,48,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,100,101,115,99,0,0,0,0,37,105,98,112,112,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,121,117,118,50,114,103,98,10,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,105,110,116,101,114,95,109,111,100,101,44,32,122,101,114,111,95,99,111,117,110,116,115,46,105,110,116,101,114,95,109,111,100,101,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,105,110,116,101,114,95,109,111,100,101,41,41,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,54,83,0,115,116,97,114,116,95,120,0,73,110,118,97,108,105,100,32,114,117,108,101,32,99,111,100,101,32,39,37,115,39,32,112,114,111,118,105,100,101,100,10,0,0,0,0,0,0,0,0,98,97,100,32,115,114,99,32,105,109,97,103,101,32,112,111,105,110,116,101,114,115,10,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,83,0,112,97,116,116,101,114,110,0,33,40,108,102,109,45,62,105,110,116,95,52,120,52,95,121,32,38,32,108,102,109,45,62,97,98,111,118,101,95,121,91,84,88,95,49,54,88,49,54,93,41,0,0,0,0,0,0,115,119,115,95,102,108,97,103,115,0,0,0,0,0,0,0,97,45,62,112,108,97,110,97,114,0,0,0,0,0,0,0,112,97,114,105,116,121,0,0,115,45,62,100,105,116,104,101,114,46,109,101,116,104,111,100,32,60,32,83,87,82,95,68,73,84,72,69,82,95,78,66,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,99,116,120,45,62,99,104,97,110,110,101,108,115,32,61,61,32,111,117,116,45,62,99,104,95,99,111,117,110,116,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,83,0,116,104,114,101,97,100,115,0,97,110,103,108,101,0,0,0,121,117,118,52,50,48,112,49,50,108,101,0,0,0,0,0,80,105,110,107,0,0,0,0,68,114,97,119,32,97,32,99,111,108,111,114,101,100,32,98,111,120,32,111,110,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,115,101,116,32,115,111,120,114,32,114,101,115,97,109,112,108,105,110,103,32,112,114,101,99,105,115,105,111,110,32,40,105,110,32,98,105,116,115,41,0,105,110,116,101,114,108,97,99,101,32,43,32,109,101,61,101,115,97,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,99,104,114,111,109,97,95,109,115,105,122,101,95,120,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,83,0,71,67,83,95,76,111,109,101,0,0,0,0,0,0,0,0,98,105,116,114,97,116,101,0,112,97,115,115,116,104,114,111,117,103,104,0,0,0,0,0,100,101,108,97,121,0,0,0,68,105,118,88,37,100,98,37,100,37,99,0,0,0,0,0,117,108,116,114,97,102,97,115,116,0,0,0,0,0,0,0,69,110,97,98,108,101,32,102,114,97,109,101,32,112,97,114,97,108,108,101,108,32,100,101,99,111,100,97,98,105,108,105,116,121,32,102,101,97,116,117,114,101,115,0,0,0,0,0,105,110,116,101,114,108,101,97,118,101,95,116,111,112,0,0,112,110,103,0,0,0,0,0,115,101,116,32,105,110,110,101,114,32,98,111,114,100,101,114,32,116,104,105,99,107,110,101,115,115,32,105,110,32,112,105,120,101,108,115,0,0,0,0,48,0,0,0,0,0,0,0,98,101,110,99,104,109,97,114,107,0,0,0,0,0,0,0,69,117,114,111,45,72,111,117,115,101,0,0,0,0,0,0,109,112,101,103,49,118,105,100,101,111,0,0,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,115,97,109,112,108,101,32,114,97,116,101,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,83,0,115,101,108,101,99,116,32,98,111,116,116,111,109,32,102,105,101,108,100,32,102,105,114,115,116,0,0,0,0,0,0,0,99,111,109,102,111,114,116,110,111,105,115,101,0,0,0,0,102,105,108,116,101,114,32,116,121,112,101,32,105,115,32,110,111,116,32,99,117,114,114,101,110,116,108,121,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,83,0,32,32,32,32,68,101,102,97,117,108,116,32,97,117,100,105,111,32,99,111,100,101,99,58,32,37,115,46,10,0,0,0,99,111,109,102,111,114,116,110,111,105,115,101,0,0,0,0,97,108,0,0,0,0,0,0,105,99,99,95,109,111,100,101,32,37,100,32,105,115,32,114,101,115,101,114,118,101,100,46,10,0,0,0,0,0,0,0,115,111,102,116,0,0,0,0,99,104,114,111,109,97,95,114,97,100,105,117,115,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,54,48,78,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,112,105,120,101,108,32,102,111,114,109,97,116,32,99,104,97,110,103,101,100,10,0,0,0,99,108,108,99,0,0,0,0,73,110,118,97,108,105,100,32,100,101,99,111,100,101,32,116,121,112,101,46,32,73,110,118,97,108,105,100,32,104,101,97,100,101,114,63,10,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,57,78,0,0,0,0,0,0,0,0,79,117,116,112,117,116,32,118,105,100,101,111,32,119,105,100,116,104,0,0,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,72,69,73,71,72,84,0,0,99,104,114,111,109,97,95,114,97,100,105,117,115,0,0,0,83,116,97,98,105,108,105,122,101,32,115,104,97,107,121,32,118,105,100,101,111,46,0,0,67,111,109,109,97,110,100,32,114,101,112,108,121,32,102,111,114,32,115,116,114,101,97,109,32,37,100,58,32,114,101,116,58,37,100,32,114,101,115,58,10,37,115,0,0,0,0,0,111,104,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,56,78,0,0,0,0,0,0,0,0,99,108,106,114,0,0,0,0,109,101,95,109,101,116,104,111,100,32,105,115,32,111,110,108,121,32,97,108,108,111,119,101,100,32,116,111,32,98,101,32,115,101,116,32,116,111,32,122,101,114,111,32,97,110,100,32,101,112,122,115,59,32,102,111,114,32,104,101,120,44,117,109,104,44,102,117,108,108,32,97,110,100,32,111,116,104,101,114,115,32,115,101,101,32,100,105,97,95,115,105,122,101,10,0,109,112,0,0,0,0,0,0,110,32,60,61,32,49,48,50,52,0,0,0,0,0,0,0,115,45,62,109,98,95,119,105,100,116,104,62,48,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,55,78,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,102,45,62,115,108,105,99,101,95,99,111,117,110,116,32,62,32,48,0,0,0,0,0,0,116,121,112,101,32,61,61,32,80,76,65,78,69,95,84,89,80,69,95,89,32,63,32,109,98,109,105,45,62,116,120,95,115,105,122,101,32,61,61,32,116,120,95,115,105,122,101,32,58,32,103,101,116,95,117,118,95,116,120,95,115,105,122,101,40,109,98,109,105,41,32,61,61,32,116,120,95,115,105,122,101,0,0,0,0,0,0,0,82,117,110,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,120,50,0,0,0,0,0,0,84,73,70,70,32,116,97,103,32,116,121,112,101,32,40,37,117,41,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,108,97,115,116,32,109,105,115,115,105,110,103,32,115,108,105,99,101,10,0,0,0,0,68,101,112,101,110,100,101,110,116,32,115,117,98,115,116,114,101,97,109,32,100,101,99,111,100,105,110,103,0,0,0,0,82,101,109,111,118,101,32,108,111,103,111,32,102,114,111,109,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,54,78,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,99,105,110,101,112,97,107,0,111,118,101,114,108,97,121,95,104,0,0,0,0,0,0,0,99,105,110,101,112,97,107,0,81,117,101,117,101,32,105,110,112,117,116,32,105,115,32,98,97,99,107,119,97,114,100,32,105,110,32,116,105,109,101,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,53,78,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,109,98,46,115,115,0,0,0,82,101,109,111,118,101,32,106,117,100,100,101,114,32,112,114,111,100,117,99,101,100,32,98,121,32,112,117,108,108,117,112,46,0,0,0,0,0,0,0,71,72,65,32,97,109,112,108,105,116,117,100,101,32,109,111,100,101,32,48,0,0,0,0,112,0,0,0,0,0,0,0,37,115,32,112,116,115,58,37,115,32,112,116,115,95,116,105,109,101,58,37,115,32,100,114,111,112,95,99,111,117,110,116,58,37,100,10,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,52,78,0,0,0,0,0,0,0,0,92,37,49,91,110,78,93,0,65,114,105,97,108,0,0,0,33,118,102,45,62,115,116,97,114,116,95,115,108,105,99,101,0,0,0,0,0,0,0,0,65,76,65,67,32,40,65,112,112,108,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,121,117,118,52,50,48,112,49,50,98,101,0,0,0,0,0,80,101,114,117,0,0,0,0,99,100,120,108,0,0,0,0,100,101,102,97,117,108,116,0,112,114,101,99,105,115,105,111,110,0,0,0,0,0,0,0,65,76,65,67,32,40,65,112,112,108,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,108,101,118,101,108,95,105,100,99,58,32,37,100,10,0,0,65,112,112,108,101,32,73,110,116,101,114,109,101,100,105,97,116,101,32,67,111,100,101,99,0,0,0,0,0,0,0,0,98,102,102,0,0,0,0,0,83,69,71,65,32,67,82,73,32,65,68,88,32,65,68,80,67,77,0,0,0,0,0,0,83,69,71,65,32,67,82,73,32,65,68,88,32,65,68,80,67,77,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,116,112,108,105,115,116,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,51,78,0,0,0,0,0,0,0,0,71,67,83,95,76,105,98,101,114,105,97,95,49,57,54,52,0,0,0,0,0,0,0,0,110,114,0,0,0,0,0,0,65,68,80,67,77,32,73,77,65,32,81,117,105,99,107,84,105,109,101,0,0,0,0,0,102,114,97,109,101,95,110,117,109,98,101,114,0,0,0,0,68,105,118,88,37,100,66,117,105,108,100,37,100,37,99,0,122,101,114,111,108,97,116,101,110,99,121,0,0,0,0,0,102,114,97,109,101,45,112,97,114,97,108,108,101,108,0,0,117,115,101,32,118,97,108,117,101,115,32,102,114,111,109,32,116,104,101,32,110,101,97,114,101,115,116,32,100,101,102,105,110,101,100,32,112,111,105,110,116,115,0,0,0,0,0,0,99,100,103,114,97,112,104,105,99,115,0,0,0,0,0,0,81,45,116,101,97,109,32,81,80,69,71,0,0,0,0,0,110,117,109,98,101,114,0,0,65,32,99,97,112,101,108,108,97,0,0,0,0,0,0,0,69,110,100,32,111,102,32,105,116,101,114,97,116,101,100,32,108,105,115,116,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,99,48,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,50,78,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,105,110,112,117,116,32,118,105,100,101,111,32,104,101,105,103,104,116,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,0,65,68,80,67,77,32,52,88,32,77,111,118,105,101,0,0,68,101,99,105,109,97,116,101,32,102,114,97,109,101,115,32,40,112,111,115,116,32,102,105,101,108,100,32,109,97,116,99,104,105,110,103,32,102,105,108,116,101,114,41,46,0,0,0,99,0,0,0,0,0,0,0,102,114,97,109,101,95,112,101,114,105,111,100,105,99,95,98,111,111,115,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,48,46,46,49,93,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,49,78,0,0,0,0,0,0,0,0,32,32,32,32,68,101,102,97,117,108,116,32,118,105,100,101,111,32,99,111,100,101,99,58,32,37,115,46,10,0,0,0,80,114,111,103,114,101,115,115,105,118,101,32,32,32,32,32,32,32,0,0,0,0,0,0,72,32,97,110,100,32,104,32,111,112,116,105,111,110,115,32,97,114,101,32,105,110,99,111,109,112,97,116,105,98,108,101,32,97,110,100,32,99,97,110,110,111,116,32,98,101,32,115,112,101,99,105,102,105,101,100,32,97,116,32,116,104,101,32,115,97,109,101,32,116,105,109,101,10,0,0,0,0,0,0,114,99,95,101,110,100,95,117,115,97,103,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,86,80,88,95,86,66,82,46,46,86,80,88,95,81,93,0,0,0,0,0,0,99,97,118,115,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,48,78,0,0,0,0,0,0,0,0,99,104,114,111,109,97,32,118,97,108,117,101,115,32,105,110,32,118,101,99,116,111,114,115,99,111,112,101,0,0,0,0,66,105,116,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,46,32,84,114,121,32,105,110,99,114,101,97,115,105,110,103,32,116,104,101,32,98,105,116,114,97,116,101,46,10,0,0,0,0,0,97,112,112,108,121,32,119,101,97,107,32,97,110,116,105,98,97,110,100,105,110,103,0,0,99,57,51,0,0,0,0,0,112,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,57,78,0,0,0,0,0,0,0,0,115,116,114,105,99,116,0,0,66,105,116,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,46,32,84,114,121,32,105,110,99,114,101,97,115,105,110,103,32,116,104,101,32,98,105,116,114,97,116,101,46,10,0,0,0,0,0,68,101,110,111,105,115,101,32,102,114,97,109,101,115,32,117,115,105,110,103,32,50,68,32,68,67,84,46,0,0,0,0,99,112,114,116,0,0,0,0,115,117,114,114,111,117,110,100,95,109,105,120,95,108,101,118,101,108,0,0,0,0,0,0,99,111,108,117,109,110,115,0,73,110,99,111,109,112,108,101,116,101,32,77,66,45,116,114,101,101,32,115,116,97,116,115,32,102,105,108,101,46,10,0,32,9,10,44,0,0,0,0,105,110,102,0,0,0,0,0,80,114,111,99,101,115,115,105,110,103,32,99,111,109,109,97,110,100,32,116,97,114,103,101,116,58,37,115,32,116,105,109,101,58,37,102,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,0,0,65,84,83,67,32,65,47,53,50,65,32,40,65,67,45,51,41,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,56,78,0,0,0,0,0,0,0,0,65,117,116,111,100,101,115,107,32,82,76,69,0,0,0,0,98,114,101,110,100,101,114,95,112,105,120,0,0,0,0,0,48,0,0,0,0,0,0,0,99,108,69,110,113,117,101,117,101,82,101,97,100,66,117,102,102,101,114,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,55,78,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,47,108,111,111,107,97,104,101,97,100,46,99,0,0,0,0,0,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,0,115,116,97,114,116,95,102,114,97,109,101,0,0,0,0,0,121,117,118,106,52,50,48,112,0,0,0,0,0,0,0,0,110,111,119,0,0,0,0,0,118,0,0,0,0,0,0,0,37,108,108,100,0,0,0,0,91,37,115,32,64,32,37,112,93,32,0,0,0,0,0,0,83,72,65,53,49,50,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,54,78,0,0,0,0,0,0,0,0,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,0,97,115,105,110,0,0,0,0,69,78,67,79,68,69,82,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,77,117,108,116,105,99,111,108,111,114,32,99,104,97,114,115,101,116,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,0,0,0,0,0,98,109,118,95,118,105,100,101,111,0,0,0,0,0,0,0,108,111,119,32,102,114,101,113,117,101,110,99,121,0,0,0,56,83,86,88,32,102,105,98,111,110,97,99,99,105,0,0,81,117,105,99,107,84,105,109,101,32,56,66,80,83,32,118,105,100,101,111,0,0,0,0,37,115,32,111,117,116,112,117,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,119,105,116,104,32,104,97,108,102,32,99,104,114,111,109,97,32,114,101,115,111,108,117,116,105,111,110,44,32,115,119,105,116,99,104,105,110,103,32,116,111,32,102,117,108,108,10,0,0,0,0,0,0,108,117,109,66,117,102,73,110,100,101,120,32,60,32,50,32,42,32,118,76,117,109,66,117,102,83,105,122,101,0,0,0,102,97,107,101,32,105,110,116,101,114,108,97,99,101,100,32,40,37,108,108,100,41,32,62,32,108,101,118,101,108,32,108,105,109,105,116,32,40,37,100,41,10,0,0,0,0,0,0,104,101,105,103,104,116,0,0,98,105,99,117,98,108,105,110,0,0,0,0,0,0,0,0,82,101,113,117,101,115,116,101,100,32,105,110,112,117,116,32,115,97,109,112,108,101,32,102,111,114,109,97,116,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,52,88,32,77,111,118,105,101,0,0,0,0,0,0,0,0,98,109,112,0,0,0,0,0,99,104,114,111,109,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,53,78,0,0,0,0,0,0,0,0,90,105,112,32,77,111,116,105,111,110,32,66,108,111,99,107,115,32,86,105,100,101,111,0,104,0,0,0,0,0,0,0,90,105,112,32,77,111,116,105,111,110,32,66,108,111,99,107,115,32,86,105,100,101,111,0,98,97,110,100,0,0,0,0,90,101,114,111,67,111,100,101,99,32,76,111,115,115,108,101,115,115,32,86,105,100,101,111,0,0,0,0,0,0,0,0,103,117,101,115,115,95,100,99,40,41,32,105,115,32,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,50,58,48,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,50,58,48,0,0,0,0,0,0,0,105,110,100,101,120,32,60,32,50,53,54,0,0,0,0,0,80,115,121,103,110,111,115,105,115,32,89,79,80,32,86,105,100,101,111,0,0,0,0,0,92,102,110,37,49,91,92,125,93,37,110,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,89,85,86,32,52,58,49,58,49,32,49,50,45,98,105,116,0,0,0,101,120,116,114,97,100,97,116,97,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,85,110,99,111,109,112,114,101,115,115,101,100,32,89,85,86,32,52,58,49,58,49,32,49,50,45,98,105,116,0,0,0,105,110,118,97,108,105,100,32,116,114,101,108,108,105,115,32,115,105,122,101,10,0,0,0,99,121,99,108,101,0,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,86,32,47,32,88,120,97,110,0,0,0,0,0,0,0,0,97,100,112,99,109,95,101,97,95,114,49,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,52,78,0,0,0,0,0,0,0,0,88,87,68,32,40,88,32,87,105,110,100,111,119,32,68,117,109,112,41,32,105,109,97,103,101,0,0,0,0,0,0,0,84,104,101,32,108,97,115,116,32,37,100,32,104,111,114,105,122,111,110,116,97,108,32,112,105,120,101,108,115,32,119,111,110,39,116,32,98,101,32,100,101,110,111,105,115,101,100,10,0,0,0,0,0,0,0,0,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,83,117,114,114,111,117,110,100,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,10,0,88,87,68,32,40,88,32,87,105,110,100,111,119,32,68,117,109,112,41,32,105,109,97,103,101,0,0,0,0,0,0,0,108,116,114,116,95,115,117,114,109,105,120,108,101,118,0,0,68,105,118,88,32,115,117,98,116,105,116,108,101,115,32,40,88,83,85,66,41,0,0,0,101,110,118,101,108,111,112,101,32,115,99,97,108,101,102,97,99,116,111,114,32,111,118,101,114,102,108,111,119,32,105,110,32,100,101,113,117,97,110,116,10,0,0,0,0,0,0,0,115,116,101,114,101,111,95,109,111,100,101,0,0,0,0,0,121,117,118,97,52,50,50,112,0,0,0,0,0,0,0,0,88,83,85,66,0,0,0,0,80,101,97,99,104,80,117,102,102,0,0,0,0,0,0,0,68,101,112,101,110,100,101,110,116,32,99,111,117,112,108,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,116,111,103,101,116,104,101,114,32,119,105,116,104,32,76,84,80,10,0,0,77,105,114,111,32,86,105,100,101,111,88,76,0,0,0,0,115,101,108,101,99,116,32,83,111,88,32,82,101,115,97,109,112,108,101,114,0,0,0,0,88,45,102,97,99,101,32,105,109,97,103,101,0,0,0,0,85,115,101,100,32,37,116,105,32,111,102,32,37,105,32,98,121,116,101,115,10,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,119,105,100,116,104,58,32,37,100,46,10,0,0,0,0,0,0,0,88,45,102,97,99,101,32,105,109,97,103,101,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,109,97,112,32,117,110,105,116,10,0,0,0,0,45,45,116,117,110,101,32,37,115,32,115,104,111,117,108,100,32,98,101,32,117,115,101,100,32,105,102,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,98,101,110,99,104,109,97,114,107,32,37,115,33,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,107,101,121,32,112,111,105,110,116,32,99,111,111,114,100,105,110,97,116,101,115,32,40,37,102,59,37,102,41,44,32,120,32,97,110,100,32,121,32,109,117,115,116,32,98,101,32,105,110,32,116,104,101,32,91,48,59,49,93,32,114,97,110,103,101,46,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,51,78,0,0,0,0,0,0,0,0,88,66,77,32,40,88,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,73,110,118,97,108,105,100,32,112,105,116,99,104,32,114,97,110,103,101,59,32,98,114,111,107,101,110,32,101,120,116,114,97,100,97,116,97,63,10,0,110,101,103,97,116,105,118,101,32,113,117,97,110,116,32,115,116,101,112,10,0,0,0,0,88,66,77,32,40,88,32,66,105,116,77,97,112,41,32,105,109,97,103,101,0,0,0,0,70,111,117,110,100,32,101,109,112,116,121,32,115,117,98,102,114,97,109,101,10,0,0,0,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,111,112,116,105,111,110,115,58,0,98,108,111,99,107,95,108,101,110,95,98,105,116,115,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,100,32,116,111,32,97,32,118,97,108,105,100,32,118,97,108,117,101,10,0,0,0,0,0,0,0,0,71,67,83,95,76,101,105,103,111,110,0,0,0,0,0,0,123,92,98,48,125,0,0,0,115,107,105,112,112,105,110,103,32,117,110,107,110,111,119,110,32,99,104,117,110,107,58,32,37,115,10,0,0,0,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,73,73,32,47,32,88,97,110,0,0,0,0,0,0,0,0,108,97,118,102,105,46,99,114,111,112,100,101,116,101,99,116,46,120,49,0,0,0,0,0,111,102,102,0,0,0,0,0,100,101,97,100,122,111,110,101,45,105,110,116,114,97,0,0,84,111,111,32,109,97,110,121,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,119,101,105,103,104,116,115,10,0,87,101,115,116,119,111,111,100,32,65,117,100,105,111,32,40,83,78,68,49,41,0,0,0,100,101,99,111,100,101,95,102,111,114,109,97,116,56,48,32,112,114,111,98,108,101,109,58,32,110,101,120,116,32,111,112,32,119,111,117,108,100,32,111,118,101,114,102,108,111,119,32,100,101,115,116,95,105,110,100,101,120,10,0,0,0,0,0,78,111,116,32,97,108,108,32,114,101,102,101,114,101,110,99,101,115,32,97,114,101,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,0,0,98,109,112,0,0,0,0,0,102,114,97,109,101,95,115,105,122,101,0,0,0,0,0,0,87,105,110,110,111,118,32,87,78,86,49,0,0,0,0,0,87,97,114,110,105,110,103,44,32,117,110,115,117,112,112,111,114,116,101,100,32,107,101,121,102,114,97,109,101,32,99,111,100,105,110,103,32,116,121,112,101,63,33,10,0,0,0,0,71,79,80,32,104,101,97,100,101,114,32,105,110,118,97,108,105,100,10,0,0,0,0,0,115,45,62,102,108,105,112,102,108,111,112,95,114,111,117,110,100,105,110,103,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,111,117,116,112,117,116,32,98,117,102,102,101,114,10,0,0,0,0,0,102,97,115,116,100,101,99,111,100,101,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,116,105,108,101,32,114,111,119,115,32,116,111,32,117,115,101,44,32,108,111,103,50,0,0,0,0,0,0,0,0,87,114,111,110,103,32,112,97,99,107,101,116,32,116,121,112,101,32,105,110,32,73,100,32,104,101,97,100,101,114,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,97,108,105,103,110,10,0,0,0,0,40,105,110,95,119,45,111,117,116,95,119,41,47,50,0,0,113,115,99,97,108,101,58,37,100,32,114,108,99,58,37,100,32,114,108,58,37,100,32,100,99,58,37,100,32,109,98,114,108,58,37,100,32,106,95,116,121,112,101,58,37,100,32,10,0,0,0,0,0,0,0,0,112,97,114,115,105,110,103,32,104,101,97,100,101,114,32,102,111,114,32,115,101,99,111,110,100,32,102,105,101,108,100,32,102,97,105,108,101,100,0,0,65,114,101,32,121,111,117,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,114,117,110,32,97,110,32,83,83,69,52,97,47,76,90,67,78,84,45,116,97,114,103,101,116,101,100,32,98,117,105,108,100,32,111,110,32,97,32,67,80,85,32,116,104,97,116,10,0,0,76,117,109,97,32,115,99,97,108,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,101,120,112,101,99,116,32,119,114,111,110,103,32,112,105,99,116,117,114,101,10,0,0,0,0,113,112,101,103,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,86,111,105,99,101,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,100,97,116,97,32,102,114,97,109,101,115,32,116,111,32,114,101,99,111,114,100,0,68,114,117,109,32,83,111,108,111,0,0,0,0,0,0,0,115,101,116,32,70,67,67,32,99,111,108,111,114,115,112,97,99,101,32,32,32,0,0,0,80,108,97,110,101,32,112,114,101,100,105,99,116,105,111,110,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,85,116,32,86,105,100,101,111,46,10,0,37,100,32,98,105,116,115,32,108,101,102,116,32,97,102,116,101,114,32,100,101,99,111,100,105,110,103,32,115,108,105,99,101,10,0,0,0,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,102,114,97,109,101,32,115,105,122,101,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,50,78,0,0,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,105,110,118,97,108,105,100,32,119,105,100,116,104,47,104,101,105,103,104,116,32,118,97,108,117,101,115,10,0,0,0,102,114,97,109,101,95,108,101,110,103,116,104,32,116,111,111,32,108,97,114,103,101,10,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,103,103,0,0,0,0,0,0,65,100,106,117,115,116,32,99,111,109,112,111,110,101,110,116,115,32,99,117,114,118,101,115], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2576544);
/* memory initializer */ allocate([46,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,100,101,108,116,97,32,116,111,107,101,110,32,105,110,100,101,120,32,37,100,32,102,111,114,32,116,121,112,101,32,37,100,44,32,110,61,37,100,10,0,32,75,69,89,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,57,32,80,114,111,102,101,115,115,105,111,110,97,108,0,0,0,0,0,0,100,112,105,0,0,0,0,0,98,109,0,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,76,111,115,115,108,101,115,115,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,49,0,0,0,99,114,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,49,78,0,0,0,0,0,0,0,0,32,32,32,32,77,105,109,101,32,116,121,112,101,58,32,37,115,46,10,0,0,0,0,0,87,105,110,100,111,119,115,32,77,101,100,105,97,32,65,117,100,105,111,32,49,0,0,0,71,101,111,103,83,101,109,105,77,97,106,111,114,65,120,105,115,71,101,111,75,101,121,0,98,114,111,107,101,110,32,101,115,99,97,112,101,32,115,101,113,117,101,110,99,101,10,0,69,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,76,90,87,32,100,101,99,111,100,101,114,10,0,124,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,113,115,99,97,108,101,58,37,100,10,0,0,0,0,0,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,0,32,32,88,49,58,37,48,51,117,32,88,50,58,37,48,51,117,32,89,49,58,37,48,51,117,32,89,50,58,37,48,51,117,0,0,0,0,0,0,0,123,37,42,49,91,67,99,70,102,111,80,83,115,89,121,93,58,37,42,91,94,125,93,125,37,110,0,0,0,0,0,0,105,110,118,97,108,105,100,32,100,111,119,110,115,97,109,112,108,105,110,103,32,118,97,108,117,101,10,0,0,0,0,0,84,104,105,115,32,99,111,100,101,99,32,105,115,32,117,110,100,101,114,32,100,101,118,101,108,111,112,109,101,110,116,44,32,102,105,108,101,115,32,101,110,99,111,100,101,100,32,119,105,116,104,32,105,116,32,109,97,121,32,110,111,116,32,98,101,32,100,101,99,111,100,97,98,108,101,32,119,105,116,104,32,102,117,116,117,114,101,32,118,101,114,115,105,111,110,115,33,33,33,10,85,115,101,32,118,115,116,114,105,99,116,61,45,50,32,47,32,45,115,116,114,105,99,116,32,45,50,32,116,111,32,117,115,101,32,105,116,32,97,110,121,119,97,121,46,10,0,0,0,0,0,0,98,108,111,99,107,95,109,97,120,95,100,101,112,116,104,61,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,84,114,101,101,32,115,105,122,101,32,101,120,99,101,101,100,101,100,33,10,0,0,0,0,109,105,115,115,105,110,103,32,118,101,114,98,97,116,105,109,32,115,101,99,116,105,111,110,32,97,116,32,98,101,103,105,110,110,105,110,103,32,111,102,32,115,116,114,101,97,109,10,0,0,0,0,0,0,0,0,87,101,98,80,32,105,109,97,103,101,0,0,0,0,0,0,117,110,107,110,111,119,110,47,117,110,115,117,112,112,111,114,116,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,116,121,112,101,0,0,0,0,84,79,80,0,0,0,0,0,117,110,107,110,111,119,110,32,102,114,97,109,101,32,116,121,112,101,10,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,0,0,0,0,0,0,116,111,112,0,0,0,0,0,87,97,118,80,97,99,107,0,105,115,80,0,0,0,0,0,73,110,118,97,108,105,100,32,99,111,100,105,110,103,32,112,97,114,97,109,101,116,101,114,115,32,37,100,32,72,122,32,37,100,32,99,104,10,0,0,99,111,100,105,110,103,32,109,101,116,104,111,100,32,105,110,118,97,108,105,100,10,0,0,66,108,97,110,107,32,102,114,97,109,101,32,104,97,110,100,108,105,110,103,0,0,0,0,98,108,97,99,107,95,115,116,97,114,116,58,37,115,32,98,108,97,99,107,95,101,110,100,58,37,115,32,98,108,97,99,107,95,100,117,114,97,116,105,111,110,58,37,115,10,0,0,76,84,0,0,0,0,0,0,97,112,99,110,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,104,101,97,100,101,114,32,118,101,114,115,105,111,110,58,32,37,100,10,0,101,114,114,111,114,44,32,119,114,111,110,103,32,115,108,105,99,101,32,100,97,116,97,32,115,105,122,101,10,0,0,0,80,37,99,10,37,100,32,37,100,10,0,0,0,0,0,0,87,97,118,80,97,99,107,0,117,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,32,37,100,32,97,110,100,32,99,111,108,111,114,32,116,121,112,101,32,37,100,10,0,0,0,0,0,108,97,118,102,105,46,98,98,111,120,46,104,0,0,0,0,80,67,77,32,54,52,45,98,105,116,32,102,108,111,97,116,105,110,103,32,112,111,105,110,116,32,98,105,103,45,101,110,100,105,97,110,0,0,0,0,87,101,115,116,119,111,111,100,32,83,116,117,100,105,111,115,32,86,81,65,32,40,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,100,32,65,110,105,109,97,116,105,111,110,41,32,118,105,100,101,111,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,71,111,111,103,108,101,32,86,80,57,0,0,0,0,0,0,76,97,121,111,117,116,32,105,110,100,105,99,97,116,101,115,32,97,32,100,105,102,102,101,114,101,110,116,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,116,104,97,110,32,97,99,116,117,97,108,108,121,32,112,114,101,115,101,110,116,10,0,0,97,115,109,0,0,0,0,0,68,105,115,99,97,114,100,105,110,103,32,105,110,116,101,114,102,114,97,109,101,32,119,105,116,104,111,117,116,32,97,32,112,114,105,111,114,32,107,101,121,102,114,97,109,101,33,10,0,0,0,0,0,0,0,0,97,108,98,117,109,0,0,0,65,117,116,111,45,100,101,116,101,99,116,32,99,114,111,112,32,115,105,122,101,46,0,0,79,110,50,32,86,80,54,0,77,88,77,32,98,105,116,109,97,115,107,32,105,115,32,110,111,116,32,99,111,109,112,108,101,116,101,10,0,0,0,0,115,116,97,114,116,95,115,97,109,112,108,101,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,10,0,65,115,121,109,109,101,116,114,105,99,32,87,77,86,57,32,114,101,99,116,97,110,103,108,101,32,115,117,98,115,97,109,112,108,105,110,103,0,0,0,77,97,120,46,32,108,101,97,100,32,116,105,109,101,32,37,103,32,109,115,10,0,0,0,98,105,110,116,101,120,116,0,112,105,99,116,117,114,101,32,116,111,111,32,98,105,103,10,0,0,0,0,0,0,0,0,99,104,114,111,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,37,54,51,91,94,32,93,32,37,108,102,32,37,50,53,53,91,94,32,93,32,37,50,53,53,91,94,10,93,0,0,0,79,110,50,32,86,80,53,0,115,101,116,32,115,101,101,107,112,111,105,110,116,32,40,115,101,99,111,110,100,115,41,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,0,0,0,0,0,0,77,80,51,111,110,77,80,52,0,0,0,0,0,0,0,0,77,80,51,111,110,77,80,52,0,0,0,0,0,0,0,0,70,108,97,103,115,32,99,111,109,109,111,110,32,102,111,114,32,97,108,108,32,109,112,101,103,118,105,100,101,111,45,98,97,115,101,100,32,101,110,99,111,100,101,114,115,46,0,0,84,104,101,111,114,97,0,0,85,115,101,32,77,80,69,71,45,50,32,105,110,116,114,97,32,86,76,67,32,116,97,98,108,101,46,0,0,0,0,0,32,45,62,32,80,84,83,58,37,115,32,84,58,37,102,10,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,32,68,83,67,70,32,86,76,67,10,0,0,0,86,111,114,98,105,115,0,0,83,117,98,115,116,114,101,97,109,32,37,100,32,99,104,101,99,107,115,117,109,32,102,97,105,108,101,100,46,10,0,0,67,83,61,73,84,85,54,48,49,0,0,0,0,0,0,0,113,117,97,110,116,95,105,110,100,101,120,32,105,115,32,105,110,118,97,108,105,100,10,0,115,111,115,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,0,0,0,0,0,0,91,93,44,59,10,0,0,0,123,92,99,38,72,37,48,54,88,38,125,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,0,0,0,0,0,0,85,115,101,32,102,97,115,116,32,115,101,116,116,105,110,103,115,32,119,104,101,110,32,101,110,99,111,100,105,110,103,32,102,105,114,115,116,32,112,97,115,115,0,0,0,0,0,0,86,111,114,98,105,115,0,0,83,116,97,116,32,98,117,102,102,101,114,32,100,101,99,111,100,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,98,105,110,107,97,117,100,105,111,95,114,100,102,116,0,0,73,110,118,97,108,105,100,32,112,97,99,107,101,116,10,0,73,110,102,108,97,116,101,32,114,101,115,101,116,32,101,114,114,111,114,58,32,37,100,10,0,0,0,0,0,0,0,0,65,108,108,32,112,114,111,98,97,98,105,108,105,116,105,101,115,32,97,114,101,32,48,33,10,0,0,0,0,0,0,0,80,114,111,103,114,101,115,115,105,111,110,32,111,114,100,101,114,32,80,67,82,76,0,0,86,77,119,97,114,101,32,83,99,114,101,101,110,32,67,111,100,101,99,32,47,32,86,77,119,97,114,101,32,86,105,100,101,111,0,0,0,0,0,0,123,92,97,110,53,125,0,0,65,86,84,66,0,0,0,0,67,111,114,114,117,112,116,101,100,32,116,105,108,101,32,100,97,116,97,32,101,110,99,111,117,110,116,101,114,101,100,33,10,0,0,0,0,0,0,0,72,101,108,112,33,32,77,121,115,116,101,114,121,32,111,112,99,111,100,101,32,48,120,54,32,115,101,101,110,10,0,0,83,99,97,108,97,98,105,108,105,116,121,58,32,117,110,115,117,112,112,111,114,116,101,100,32,115,117,98,100,105,118,105,115,105,111,110,33,32,76,117,109,97,32,98,97,110,100,115,58,32,37,100,44,32,99,104,114,111,109,97,32,98,97,110,100,115,58,32,37,100,10,0,83,105,101,114,114,97,32,86,77,68,32,118,105,100,101,111,0,0,0,0,0,0,0,0,116,114,97,110,115,102,111,114,109,32,97,110,100,32,98,108,111,99,107,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,40,37,100,32,33,61,32,37,100,41,10,0,0,0,65,116,116,101,109,112,116,32,116,111,32,117,115,101,32,77,111,100,101,32,49,49,32,102,111,114,32,97,110,32,73,78,84,82,65,32,99,101,108,108,33,10,0,0,0,0,0,0,76,117,99,97,115,65,114,116,115,32,86,73,77,65,32,97,117,100,105,111,0,0,0,0,102,108,99,111,101,102,102,115,53,32,37,102,32,105,110,118,97,108,105,100,10,0,0,0,98,112,112,32,37,100,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,112,97,108,101,116,116,101,10,0,0,0,87,105,100,116,104,32,109,117,115,116,32,98,101,32,101,118,101,110,32,102,111,114,32,116,104,105,115,32,99,111,108,111,114,115,112,97,99,101,46,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,0,0,0,0,0,0,119,105,100,116,104,32,109,117,115,116,32,98,101,32,101,118,101,110,32,102,111,114,32,116,104,105,115,32,99,111,108,111,114,115,112,97,99,101,10,0,65,84,73,32,86,67,82,49,0,0,0,0,0,0,0,0,83,80,83,32,105,100,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,0,0,0,0,67,111,109,109,97,110,100,32,114,101,112,108,121,32,102,111,114,32,99,111,109,109,97,110,100,32,35,37,100,58,32,114,101,116,58,37,115,32,114,101,115,58,37,115,10,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,78,65,76,32,117,110,105,116,32,35,37,100,46,10,0,0,0,0,116,111,112,95,98,111,116,116,111,109,0,0,0,0,0,0,109,109,99,111,58,37,100,32,37,100,32,37,100,10,0,0,82,101,100,117,99,105,110,103,32,108,101,102,116,32,99,114,111,112,112,105,110,103,32,116,111,32,37,100,32,99,104,114,111,109,97,32,115,97,109,112,108,101,115,32,116,111,32,112,114,101,115,101,114,118,101,32,97,108,105,103,110,109,101,110,116,46,10,0,0,0,0,0,73,110,118,97,108,105,100,32,108,101,118,101,108,32,112,114,101,102,105,120,10,0,0,0,114,101,102,101,114,101,110,99,101,32,111,118,101,114,102,108,111,119,32,37,117,32,62,32,37,117,32,111,114,32,37,117,32,62,32,37,117,10,0,0,69,114,114,111,114,32,97,116,32,77,66,58,32,37,100,10,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,97,99,32,118,108,99,32,99,111,100,101,32,97,116,32,37,100,120,37,100,10,0,0,0,83,77,80,84,69,32,86,67,45,49,0,0,0,0,0,0,103,105,102,32,100,101,99,111,100,101,114,0,0,0,0,0,112,114,101,118,95,115,101,108,101,99,116,101,100,95,112,116,115,0,0,0,0,0,0,0,111,102,102,115,101,116,116,105,110,103,0,0,0,0,0,0,98,0,0,0,0,0,0,0,98,112,112,61,37,100,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,0,0,0,0,0,0,80,114,111,99,101,115,115,101,100,32,70,76,73,32,99,104,117,110,107,32,119,104,101,114,101,32,99,104,117,110,107,32,115,105,122,101,32,61,32,37,100,32,97,110,100,32,102,105,110,97,108,32,99,104,117,110,107,32,112,116,114,32,61,32,37,100,10,0,0,0,0,0,37,100,120,37,100,32,105,110,118,97,108,105,100,32,99,111,108,111,114,32,100,101,112,116,104,32,37,100,10,0,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,115,105,122,101,58,32,37,100,10,0,116,111,103,103,108,101,0,0,115,119,105,116,99,104,105,110,103,32,98,112,115,32,109,105,100,45,115,116,114,101,97,109,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,102,102,118,49,100,101,99,46,99,0,0,0,0,85,0,0,0,0,0,0,0,98,105,110,107,118,105,100,101,111,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,98,117,102,102,101,114,113,117,101,117,101,46,104,0,0,0,0,0,0,0,67,114,111,112,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,46,0,0,0,78,111,116,32,73,110,100,105,99,97,116,101,100,32,40,100,101,102,97,117,108,116,41,0,70,114,97,109,101,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,0,0,67,97,110,39,116,32,97,108,108,111,99,97,116,101,32,100,101,99,111,109,112,114,101,115,115,105,111,110,32,98,117,102,102,101,114,46,10,0,0,0,112,97,108,101,116,116,101,58,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,103,108,111,98,97,108,32,112,97,108,101,116,116,101,0,0,68,101,99,111,100,105,110,103,32,102,105,114,115,116,32,68,86,66,32,115,117,98,116,105,116,108,101,115,32,115,117,98,45,115,116,114,101,97,109,10,0,0,0,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,102,111,114,109,97,116,10,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,33,97,108,101,118,101,108,32,124,124,32,106,32,60,32,50,53,55,0,0,0,0,0,0,70,114,97,109,101,32,116,111,32,114,101,116,105,114,101,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,98,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,37,100,32,109,105,115,109,97,116,99,104,101,115,32,108,97,121,111,117,116,32,37,100,10,0,0,0,0,0,106,115,95,115,117,98,98,97,110,100,95,115,116,97,114,116,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,52,78,0,0,0,0,0,0,0,0,67,111,112,121,32,116,104,101,32,105,110,112,117,116,32,118,105,100,101,111,32,117,110,99,104,97,110,103,101,100,32,116,111,32,116,104,101,32,111,117,116,112,117,116,46,0,0,0,111,117,116,95,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,0,0,0,0,121,117,118,97,52,52,52,112,0,0,0,0,0,0,0,0,80,97,112,97,121,97,87,104,105,112,0,0,0,0,0,0,65,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,32,109,101,109,111,114,121,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,0,87,77,86,51,32,67,111,109,112,108,101,120,32,80,114,111,102,105,108,101,32,105,115,32,110,111,116,32,102,117,108,108,121,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,115,111,120,114,0,0,0,0,114,118,50,48,0,0,0,0,86,66,76,69,32,76,111,115,115,108,101,115,115,32,67,111,100,101,99,0,0,0,0,0,109,97,120,95,115,116,114,105,112,115,0,0,0,0,0,0,115,97,109,112,108,101,95,102,109,116,0,0,0,0,0,0,103,101,116,95,117,101,95,99,111,100,101,58,32,118,97,108,117,101,32,116,111,111,32,108,97,114,103,101,114,10,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,108,105,98,97,118,99,111,100,101,99,47,98,109,118,46,99,0,0,0,0,0,0,0,0,45,45,112,115,110,114,32,117,115,101,100,32,119,105,116,104,32,65,81,32,111,110,58,32,114,101,115,117,108,116,115,32,119,105,108,108,32,98,101,32,105,110,118,97,108,105,100,33,10,0,0,0,0,0,0,0,100,101,112,116,104,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,66,101,97,109,32,83,111,102,116,119,97,114,101,32,86,66,0,0,0,0,0,0,0,0,116,97,98,108,101,91,106,93,91,48,93,32,61,61,32,105,110,100,101,120,0,0,0,0,84,111,111,32,109,97,110,121,32,99,111,108,111,114,32,118,97,108,117,101,115,10,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,52,58,52,32,49,48,45,98,105,116,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,52,58,52,32,49,48,45,98,105,116,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,51,78,0,0,0,0,0,0,0,0,71,67,83,95,76,97,107,101,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,32,37,100,46,10,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,77,83,32,52,58,52,58,52,58,52,0,0,100,101,97,100,122,111,110,101,45,105,110,116,101,114,0,0,115,97,109,112,108,101,95,114,97,116,101,115,0,0,0,0,112,117,114,101,32,115,105,108,101,110,99,101,32,109,111,110,111,10,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,77,83,32,52,58,52,58,52,58,52,0,0,113,117,97,110,116,95,99,111,102,32,37,100,32,105,115,32,111,117,116,32,111,102,32,114,97,110,103,101,46,10,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,52,58,52,0,0,0,0,0,0,0,115,101,116,32,99,117,116,111,102,102,32,98,97,110,100,119,105,100,116,104,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,112,97,99,107,101,100,32,52,58,52,58,52,0,0,0,0,0,0,0,117,115,105,110,103,32,99,112,117,32,99,97,112,97,98,105,108,105,116,105,101,115,58,0,116,101,120,116,117,114,101,32,99,111,114,114,117,112,116,101,100,32,97,116,32,37,100,32,37,100,32,37,100,10,0,0,114,101,112,108,97,99,101,115,0,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,99,111,108,95,105,110,116,101,114,108,101,97,118,101,100,95,114,108,0,0,0,0,0,0,112,115,110,114,0,0,0,0,116,105,108,101,45,114,111,119,115,0,0,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,98,102,105,0,0,0,0,0,79,116,104,101,114,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,52,58,50,58,50,32,49,48,45,98,105,116,0,0,0,0,0,0,0,87,77,47,69,110,99,111,100,105,110,103,83,101,116,116,105,110,103,115,0,0,0,0,0,77,105,114,111,32,86,105,100,101,111,88,76,0,0,0,0,69,110,97,98,108,101,32,65,80,69,32,116,97,103,32,119,114,105,116,105,110,103,0,0,85,116,32,86,105,100,101,111,0,0,0,0,0,0,0,0,80,117,110,107,32,82,111,99,107,0,0,0,0,0,0,0,100,102,114,97,109,101,115,0,98,101,115,116,95,105,100,120,32,62,61,32,48,0,0,0,52,50,50,112,49,52,0,0,115,116,97,114,116,32,116,105,109,101,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,101,115,116,105,109,97,116,101,95,116,105,109,105,110,103,115,95,102,114,111,109,95,112,116,115,10,0,0,0,0,0,119,114,105,116,101,32,115,116,114,101,97,109,32,99,111,100,101,99,32,102,97,105,108,101,100,32,99,111,100,101,99,95,116,121,112,101,40,48,120,37,120,41,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,109,101,100,105,97,32,116,121,112,101,44,32,109,101,100,105,97,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,44,32,115,117,98,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,44,32,102,111,114,109,97,116,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,107,105,110,100,0,0,0,0,85,116,32,86,105,100,101,111,0,0,0,0,0,0,0,0,100,97,116,101,0,0,0,0,99,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,72,101,105,103,104,116,0,0,98,101,116,104,115,111,102,116,118,105,100,0,0,0,0,0,109,112,51,0,0,0,0,0,102,0,0,0,0,0,0,0,34,99,111,110,116,101,110,116,34,0,0,0,0,0,0,0,97,117,100,105,111,32,102,114,97,109,101,32,115,105,122,101,32,110,111,116,32,115,101,116,10,0,0,0,0,0,0,0,108,105,98,97,118,102,105,108,116,101,114,47,97,118,102,105,108,116,101,114,46,99,0,0,49,46,50,46,53,0,0,0,91,73,78,70,79,82,77,65,84,73,79,78,93,0,0,0,72,68,32,109,111,100,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,116,104,105,115,32,102,111,114,109,97,116,10,0,0,67,111,110,118,101,114,116,32,99,111,108,111,114,32,109,97,116,114,105,120,46,0,0,0,60,83,116,114,101,97,109,73,110,100,101,120,32,84,121,112,101,61,34,118,105,100,101,111,34,32,81,117,97,108,105,116,121,76,101,118,101,108,115,61,34,37,100,34,32,67,104,117,110,107,115,61,34,37,100,34,32,85,114,108,61,34,81,117,97,108,105,116,121,76,101,118,101,108,115,40,123,98,105,116,114,97,116,101,125,41,47,70,114,97,103,109,101,110,116,115,40,118,105,100,101,111,61,123,115,116,97,114,116,32,116,105,109,101,125,41,34,62,10,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,0,0,0,0,0,0,32,32,32,32,67,111,109,109,111,110,32,101,120,116,101,110,115,105,111,110,115,58,32,37,115,46,10,0,0,0,0,0,97,118,117,105,0,0,0,0,97,118,117,105,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,48,78,0,0,0,0,0,0,0,0,97,118,115,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,73,66,77,32,85,108,116,105,77,111,116,105,111,110,0,0,82,101,110,100,101,114,119,97,114,101,32,84,88,68,32,40,84,101,88,116,117,114,101,32,68,105,99,116,105,111,110,97,114,121,41,32,105,109,97,103,101,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,0,0,0,0,0,0,97,118,114,110,0,0,0,0,97,108,98,109,0,0,0,0,86,81,70,32,84,119,105,110,86,81,0,0,0,0,0,0,66,108,111,99,107,32,97,108,105,103,110,32,105,115,32,37,100,32,98,105,116,115,44,32,101,120,112,101,99,116,101,100,32,37,100,10,0,0,0,0,84,84,65,32,40,84,114,117,101,32,65,117,100,105,111,41,0,0,0,0,0,0,0,0,84,84,65,32,40,84,114,117,101,32,65,117,100,105,111,41,0,0,0,0,0,0,0,0,10,69,110,116,101,114,32,99,111,109,109,97,110,100,58,32,60,116,97,114,103,101,116,62,124,97,108,108,32,60,116,105,109,101,62,124,45,49,32,60,99,111,109,109,97,110,100,62,91,32,60,97,114,103,117,109,101,110,116,62,93,10,0,0,84,101,99,104,83,109,105,116,104,32,83,99,114,101,101,110,32,67,111,100,101,99,32,50,0,0,0,0,0,0,0,0,84,101,99,104,83,109,105,116,104,32,83,99,114,101,101,110,32,67,97,112,116,117,114,101,32,67,111,100,101,99,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,0,0,0,0,0,0,68,83,80,32,71,114,111,117,112,32,84,114,117,101,83,112,101,101,99,104,0,0,0,0,68,117,99,107,32,84,114,117,101,77,111,116,105,111,110,32,50,46,48,0,0,0,0,0,68,117,99,107,32,84,114,117,101,77,111,116,105,111,110,32,49,46,48,0,0,0,0,0,56,48,56,56,102,108,101,120,32,84,77,86,0,0,0,0,84,73,70,70,32,105,109,97,103,101,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,55,78,0,0,0,0,0,0,0,0,65,100,106,117,115,116,32,99,111,108,111,114,115,32,98,121,32,109,105,120,105,110,103,32,99,111,108,111,114,32,99,104,97,110,110,101,108,115,46,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,54,78,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,53,78,0,0,0,0,0,0,0,0,65,100,106,117,115,116,32,116,104,101,32,99,111,108,111,114,32,98,97,108,97,110,99,101,46,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,52,78,0,0,0,0,0,0,0,0,98,103,114,48,0,0,0,0,80,97,108,101,86,105,111,108,101,116,82,101,100,0,0,0,115,101,108,101,99,116,32,83,87,32,82,101,115,97,109,112,108,101,114,0,0,0,0,0,97,117,114,97,50,0,0,0,45,45,115,115,105,109,32,117,115,101,100,32,119,105,116,104,32,65,81,32,111,102,102,58,32,114,101,115,117,108,116,115,32,119,105,108,108,32,98,101,32,105,110,118,97,108,105,100,33,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,51,78,0,0,0,0,0,0,0,0,71,67,83,95,80,83,65,68,53,54,0,0,0,0,0,0,100,99,116,45,100,101,99,105,109,97,116,101,0,0,0,0,99,117,116,111,102,102,0,0,108,111,111,107,115,32,108,105,107,101,32,116,104,105,115,32,102,105,108,101,32,119,97,115,32,101,110,99,111,100,101,100,32,119,105,116,104,32,40,100,105,118,120,52,47,40,111,108,100,41,120,118,105,100,47,111,112,101,110,100,105,118,120,41,32,45,62,32,102,111,114,99,105,110,103,32,108,111,119,95,100,101,108,97,121,32,102,108,97,103,10,0,0,0,0,0,115,116,105,108,108,105,109,97,103,101,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,116,105,108,101,32,99,111,108,117,109,110,115,32,116,111,32,117,115,101,44,32,108,111,103,50,0,0,0,0,0,118,105,120,108,0,0,0,0,68,117,101,116,0,0,0,0,115,116,114,105,110,103,61,115,116,114,105,110,103,0,0,0,69,115,116,105,109,97,116,105,110,103,32,100,117,114,97,116,105,111,110,32,102,114,111,109,32,98,105,116,114,97,116,101,44,32,116,104,105,115,32,109,97,121,32,98,101,32,105,110,97,99,99,117,114,97,116,101,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,0,0,0,0,0,0,77,117,120,101,114,32,37,115,32,91,37,115,93,58,10,0,49,0,0,0,0,0,0,0,100,114,97,119,32,97,32,108,105,110,101,32,102,111,114,32,101,97,99,104,32,115,97,109,112,108,101,0,0,0,0,0,97,116,114,97,99,51,112,108,117,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,0,0,0,0,0,0,115,101,103,109,101,110,116,95,108,105,115,116,95,102,108,97,103,115,0,0,0,0,0,0,66,108,117,114,32,116,104,101,32,105,110,112,117,116,46,0,71,84,82,97,115,116,101,114,84,121,112,101,71,101,111,75,101,121,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,0,0,0,0,0,0,73,80,54,0,0,0,0,0,99,111,109,109,101,110,116,0,37,115,37,55,105,0,0,0,85,115,105,110,103,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,32,97,115,32,78,79,87,46,10,0,0,0,78,101,119,32,37,115,32,115,116,114,101,97,109,32,37,100,58,37,100,32,97,116,32,112,111,115,58,37,108,108,100,32,97,110,100,32,68,84,83,58,37,115,115,10,0,0,0,0,84,73,70,70,32,105,109,97,103,101,0,0,0,0,0,0,97,116,114,97,99,51,0,0,84,105,101,114,116,101,120,32,76,105,109,105,116,101,100,32,83,69,81,32,118,105,100,101,111,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,0,0,0,0,0,0,82,97,119,32,116,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,84,114,117,101,118,105,115,105,111,110,32,84,97,114,103,97,32,105,109,97,103,101,0,0,80,105,110,110,97,99,108,101,32,84,65,82,71,65,32,67,105,110,101,87,97,118,101,32,89,85,86,49,54,0,0,0,79,110,108,121,32,109,111,110,111,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,84,114,117,101,118,105,115,105,111,110,32,84,97,114,103,97,32,105,109,97,103,101,0,0,84,65,75,32,40,84,111,109,39,115,32,108,111,115,115,108,101,115,115,32,65,117,100,105,111,32,75,111,109,112,114,101,115,115,111,114,41,0,0,0,97,116,114,97,99,49,0,0,118,105,100,101,111,47,120,45,112,110,45,114,101,97,108,118,105,100,101,111,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,0,0,0,0,0,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,51,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,51,32,47,32,83,86,81,51,0,0,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,49,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,49,32,47,32,83,86,81,49,0,0,0,83,111,114,101,110,115,111,110,32,86,101,99,116,111,114,32,81,117,97,110,116,105,122,101,114,32,49,32,47,32,83,111,114,101,110,115,111,110,32,86,105,100,101,111,32,49,32,47,32,83,86,81,49,0,0,0,83,117,110,32,82,97,115,116,101,114,102,105,108,101,32,105,109,97,103,101,0,0,0,0,83,117,110,32,82,97,115,116,101,114,102,105,108,101,32,105,109,97,103,101,0,0,0,0,83,117,98,86,105,101,119,101,114,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,97,115,118,49,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,0,0,0,0,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,32,119,105,116,104,32,101,109,98,101,100,100,101,100,32,116,105,109,105,110,103,0,0,0,0,37,117,58,37,117,46,37,117,0,0,0,0,0,0,0,0,115,101,116,32,102,114,97,109,101,32,114,97,116,101,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,32,119,105,116,104,32,101,109,98,101,100,100,101,100,32,116,105,109,105,110,103,0,0,0,0,83,117,110,112,108,117,115,32,74,80,69,71,32,40,83,80,53,88,41,0,0,0,0,0,99,111,109,98,105,110,101,100,32,109,111,100,101,0,0,0,83,111,110,105,99,0,0,0,83,110,111,119,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,0,0,0,0,0,0,83,110,111,119,0,0,0,0,98,117,102,45,62,100,97,116,97,95,115,116,97,99,107,95,116,111,112,32,62,61,32,48,0,0,0,0,0,0,0,0,97,115,118,49,0,0,0,0,83,77,86,32,74,80,69,71,0,0,0,0,0,0,0,0,114,97,119,32,68,105,114,97,99,0,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,71,114,97,112,104,105,99,115,32,40,83,77,67,41,0,0,0,0,0,0,0,0,83,109,97,99,107,101,114,32,118,105,100,101,111,0,0,0,114,97,119,32,77,76,80,0,82,101,97,108,65,117,100,105,111,32,83,73,80,82,32,47,32,65,67,69,76,80,46,78,69,84,0,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,39,114,100,118,111,39,32,97,116,111,109,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,0,0,0,0,0,0,48,98,103,114,0,0,0,0,80,97,108,101,84,117,114,113,117,111,105,115,101,0,0,0,83,104,111,114,116,101,110,0,115,119,114,0,0,0,0,0,83,71,73,32,82,76,69,32,56,45,98,105,116,0,0,0,83,71,73,32,105,109,97,103,101,0,0,0,0,0,0,0,45,45,37,115,32,117,115,101,100,32,119,105,116,104,32,112,115,121,32,111,110,58,32,114,101,115,117,108,116,115,32,119,105,108,108,32,98,101,32,105,110,118,97,108,105,100,33,10,0,0,0,0,0,0,0,0,115,115,97,0,0,0,0,0,83,71,73,32,105,109,97,103,101,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,0,0,0,0,0,0,71,67,83,95,76,97,95,67,97,110,111,97,0,0,0,0,102,97,115,116,45,112,115,107,105,112,0,0,0,0,0,0,76,117,99,97,115,65,114,116,115,32,83,77,85,83,72,32,118,105,100,101,111,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,97,117,100,105,111,32,99,104,97,110,110,101,108,115,0,0,0,0,83,65,77,73,32,115,117,98,116,105,116,108,101,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,108,111,97,100,32,98,97,99,107,119,97,114,100,32,115,104,97,112,101,32,105,115,110,39,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,83,77,80,84,69,32,51,48,50,77,0,0,0,0,0,0,103,114,97,105,110,0,0,0,116,105,108,101,45,99,111,108,117,109,110,115,0,0,0,0,83,77,80,84,69,32,51,48,50,77,0,0,0,0,0,0,82,101,97,108,86,105,100,101,111,32,52,46,48,0,0,0,115,115,97,0,0,0,0,0,70,105,114,115,116,32,115,108,105,99,101,32,104,101,97,100,101,114,32,105,115,32,105,110,99,111,114,114,101,99,116,10,0,0,0,0,0,0,0,0,65,112,112,108,101,32,81,117,105,99,107,68,114,97,119,0,70,114,97,109,101,32,97,102,116,101,114,32,69,79,70,32,111,110,32,105,110,112,117,116,32,37,115,10,0,0,0,0,82,101,97,108,86,105,100,101,111,32,51,46,48,0,0,0,70,114,101,101,115,116,121,108,101,0,0,0,0,0,0,0,97,100,100,32,109,101,116,97,100,97,116,97,0,0,0,0,73,103,110,111,114,105,110,103,32,111,117,116,108,105,101,114,32,110,111,110,32,112,114,105,109,97,114,121,32,115,116,114,101,97,109,32,115,116,97,114,116,116,105,109,101,32,37,102,10,0,0,0,0,0,0,0,115,45,62,102,95,99,111,100,101,32,61,61,32,49,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,0,0,0,0,0,0,82,101,97,108,86,105,100,101,111,32,49,46,48,0,0,0,80,67,77,32,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,114,118,49,48,0,0,0,0,81,117,105,99,107,84,105,109,101,32,118,105,100,101,111,32,40,82,80,90,65,41,0,0,105,100,32,82,111,81,32,118,105,100,101,111,0,0,0,0,105,100,32,82,111,81,32,118,105,100,101,111,0,0,0,0,105,100,32,82,111,81,32,68,80,67,77,0,0,0,0,0,82,76,50,32,118,105,100,101,111,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,102,111,114,109,97,116,32,39,37,115,39,46,10,0,0,0,82,101,97,108,84,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,114,97,119,32,118,105,100,101,111,0,0,0,0,0,0,0,66,108,101,110,100,32,116,119,111,32,118,105,100,101,111,32,102,114,97,109,101,115,32,105,110,116,111,32,101,97,99,104,32,111,116,104,101,114,46,0,105,103,110,105,100,120,0,0,80,73,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,0,0,0,0,0,0,79,77,71,95,76,83,73,0,82,101,97,108,65,117,100,105,111,32,76,111,115,115,108,101,115,115,0,0,0,0,0,0,116,105,116,108,101,0,0,0,82,101,97,108,65,117,100,105,111,32,50,46,48,32,40,50,56,46,56,75,41,0,0,0,82,101,97,108,65,117,100,105,111,32,49,46,48,32,40,49,52,46,52,75,41,0,0,0,82,101,97,108,65,117,100,105,111,32,49,46,48,32,40,49,52,46,52,75,41,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,32,49,48,45,98,105,116,0,97,112,101,0,0,0,0,0,85,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,32,49,48,45,98,105,116,0,68,101,116,101,99,116,32,102,114,97,109,101,115,32,116,104,97,116,32,97,114,101,32,40,97,108,109,111,115,116,41,32,98,108,97,99,107,46,0,0,81,117,105,99,107,84,105,109,101,32,65,110,105,109,97,116,105,111,110,32,40,82,76,69,41,32,118,105,100,101,111,0,114,0,0,0,0,0,0,0,81,117,105,99,107,84,105,109,101,32,65,110,105,109,97,116,105,111,110,32,40,82,76,69,41,32,118,105,100,101,111,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,57,78,0,81,45,116,101,97,109,32,81,80,69,71,0,0,0,0,0,65,112,112,108,101,32,81,117,105,99,107,68,114,97,119,0,100,115,99,112], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2586784);
/* memory initializer */ allocate([111,103,103,112,97,103,101,115,105,122,101,0,0,0,0,0,67,97,110,110,111,116,32,105,100,101,110,116,105,102,121,32,110,101,119,32,115,116,114,101,97,109,10,0,0,0,0,0,81,68,101,115,105,103,110,32,77,117,115,105,99,32,67,111,100,101,99,32,50,0,0,0,81,67,69,76,80,32,47,32,80,117,114,101,86,111,105,99,101,0,0,0,0,0,0,0,86,46,70,108,97,115,104,32,80,84,88,32,105,109,97,103,101,0,0,0,0,0,0,0,97,110,115,105,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,100,101,99,111,100,105,110,103,32,115,116,114,101,97,109,32,35,37,100,58,37,100,58,32,37,115,10,0,78,111,32,99,111,100,101,99,32,116,97,103,32,100,101,102,105,110,101,100,32,102,111,114,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,56,78,0,65,112,112,108,101,32,80,114,111,82,101,115,32,40,105,67,111,100,101,99,32,80,114,111,41,0,0,0,0,0,0,0,65,112,112,108,101,32,80,114,111,82,101,115,0,0,0,0,65,112,112,108,101,32,80,114,111,82,101,115,32,40,105,67,111,100,101,99,32,80,114,111,41,0,0,0,0,0,0,0,110,117,116,45,62,108,97,115,116,95,115,121,110,99,112,111,105,110,116,95,112,111,115,32,61,61,32,42,112,111,115,95,97,114,103,0,0,0,0,0,80,114,111,82,101,115,0,0,97,110,109,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,55,78,0,80,71,77,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,37,42,115,32,37,42,115,32,37,100,0,0,0,0,0,0,80,71,77,32,40,80,111,114,116,97,98,108,101,32,71,114,97,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,68,101,116,101,99,116,32,118,105,100,101,111,32,105,110,116,101,114,118,97,108,115,32,116,104,97,116,32,97,114,101,32,40,97,108,109,111,115,116,41,32,98,108,97,99,107,46,0,80,78,71,32,40,80,111,114,116,97,98,108,101,32,78,101,116,119,111,114,107,32,71,114,97,112,104,105,99,115,41,32,105,109,97,103,101,0,0,0,53,53,46,51,51,46,49,48,48,0,0,0,0,0,0,0,80,78,71,32,40,80,111,114,116,97,98,108,101,32,78,101,116,119,111,114,107,32,71,114,97,112,104,105,99,115,41,32,105,109,97,103,101,0,0,0,80,105,99,116,111,114,47,80,67,32,80,97,105,110,116,0,72,68,77,86,32,80,114,101,115,101,110,116,97,116,105,111,110,32,71,114,97,112,104,105,99,32,83,116,114,101,97,109,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,80,67,32,80,97,105,110,116,98,114,117,115,104,32,80,67,88,32,105,109,97,103,101,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,54,78,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,80,67,32,80,97,105,110,116,98,114,117,115,104,32,80,67,88,32,105,109,97,103,101,0,97,109,114,119,98,0,0,0,79,80,65,116,111,109,32,109,105,115,105,110,116,101,114,112,114,101,116,101,100,32,97,115,32,79,80,49,97,63,75,76,86,32,102,111,114,32,101,100,105,116,32,117,110,105,116,32,37,105,32,101,120,116,101,110,100,105,110,103,32,105,110,116,111,32,110,101,120,116,32,101,100,105,116,32,117,110,105,116,0,0,0,0,0,0,0,0,95,95,68,73,82,95,67,79,85,78,84,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,53,78,0,97,109,114,110,98,0,0,0,112,116,115,32,40,37,115,41,32,60,32,100,116,115,32,40,37,115,41,32,105,110,32,115,116,114,101,97,109,32,37,100,10,0,0,0,0,0,0,0,67,111,109,112,117,116,101,32,98,111,117,110,100,105,110,103,32,98,111,120,32,102,111,114,32,101,97,99,104,32,102,114,97,109,101,46,0,0,0,0,115,101,116,32,116,104,101,32,110,117,109,98,101,114,32,111,102,32,115,97,109,112,108,101,115,32,112,101,114,32,114,101,113,117,101,115,116,101,100,32,102,114,97,109,101,0,0,0,80,67,77,32,65,45,108,97,119,32,47,32,71,46,55,49,49,32,65,45,108,97,119,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,52,78,0,80,67,77,32,115,105,103,110,101,100,32,49,54,124,50,48,124,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,102,111,114,32,68,86,68,32,109,101,100,105,97,0,0,0,0,0,0,0,0,80,67,77,32,115,105,103,110,101,100,32,49,54,124,50,48,124,50,52,45,98,105,116,32,98,105,103,45,101,110,100,105,97,110,32,102,111,114,32,66,108,117,45,114,97,121,32,109,101,100,105,97,0,0,0,0,102,105,114,115,116,32,112,116,115,32,118,97,108,117,101,32,109,117,115,116,32,98,101,32,115,101,116,10,0,0,0,0,114,103,98,48,0,0,0,0,80,97,108,101,71,114,101,101,110,0,0,0,0,0,0,0,80,65,77,32,40,80,111,114,116,97,98,108,101,32,65,110,121,77,97,112,41,32,105,109,97,103,101,0,0,0,0,0,115,101,116,32,114,101,115,97,109,112,108,105,110,103,32,69,110,103,105,110,101,0,0,0,65,109,97,122,105,110,103,32,83,116,117,100,105,111,32,80,97,99,107,101,100,32,65,110,105,109,97,116,105,111,110,32,70,105,108,101,32,86,105,100,101,111,0,0,0,0,0,0,115,115,105,109,0,0,0,0,116,115,95,112,97,99,107,101,116,115,105,122,101,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,51,78,0,71,67,83,95,75,79,67,0,116,114,101,108,108,105,115,0,77,80,69,71,45,50,32,80,83,32,40,68,86,68,32,86,79,66,41,0,0,0,0,0,97,99,0,0,0,0,0,0,32,0,0,0,0,0,0,0,97,108,115,0,0,0,0,0,97,110,105,109,97,116,105,111,110,0,0,0,0,0,0,0,76,111,115,115,108,101,115,115,32,109,111,100,101,0,0,0,115,117,98,0,0,0,0,0,113,100,114,97,119,0,0,0,82,104,121,116,104,109,105,99,32,83,111,117,108,0,0,0,109,112,101,103,116,115,0,0,40,99,41,67,82,73,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,50,78,0,84,68,82,76,0,0,0,0,83,101,116,32,116,104,101,32,102,114,97,109,101,32,100,105,115,112,108,97,121,32,97,115,112,101,99,116,32,114,97,116,105,111,46,0,0,0,0,0,80,67,83,95,87,71,83,55,50,66,69,95,85,84,77,95,122,111,110,101,95,49,78,0,109,101,116,97,100,97,116,97,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,54,48,83,0,0,105,110,118,97,108,105,100,32,112,114,111,102,105,108,101,58,32,37,115,10,0,0,0,0,67,111,112,121,32,116,104,101,32,108,117,109,97,32,118,97,108,117,101,32,111,102,32,116,104,101,32,115,101,99,111,110,100,32,105,110,112,117,116,32,105,110,116,111,32,116,104,101,32,97,108,112,104,97,32,99,104,97,110,110,101,108,32,111,102,32,116,104,101,32,102,105,114,115,116,32,105,110,112,117,116,46,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,57,83,0,0,103,101,110,114,101,0,0,0,77,80,52,32,40,77,80,69,71,45,52,32,80,97,114,116,32,49,52,41,0,0,0,0,100,101,109,117,120,101,114,43,102,102,109,112,101,103,32,45,62,32,105,115,116,95,105,110,100,101,120,58,37,100,32,116,121,112,101,58,37,115,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,32,111,102,102,58,37,115,32,111,102,102,95,116,105,109,101,58,37,115,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,56,83,0,0,114,101,116,32,62,61,32,48,0,0,0,0,0,0,0,0,115,116,114,101,97,109,32,37,100,44,32,116,105,109,101,115,99,97,108,101,32,110,111,116,32,115,101,116,10,0,0,0,78,117,112,112,101,108,86,105,100,101,111,47,82,84,74,80,69,71,0,0,0,0,0,0,78,101,108,108,121,109,111,115,101,114,32,65,115,97,111,0,79,80,68,65,0,0,0,0,78,101,108,108,121,109,111,115,101,114,32,65,115,97,111,0,77,111,98,111,116,105,120,32,77,120,80,69,71,32,118,105,100,101,111,0,0,0,0,0,83,105,108,105,99,111,110,32,71,114,97,112,104,105,99,115,32,77,111,116,105,111,110,32,86,105,100,101,111,32,67,111,109,112,114,101,115,115,111,114,32,49,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,55,83,0,0,77,105,99,114,111,115,111,102,116,32,86,105,100,101,111,45,49,0,0,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,86,105,100,101,111,32,49,0,0,0,0,0,0,0,77,83,32,69,120,112,114,101,115,115,105,111,110,32,69,110,99,111,100,101,114,32,83,99,114,101,101,110,0,0,0,0,35,104,97,115,104,58,32,37,115,10,0,0,0,0,0,0,77,83,32,65,84,67,32,83,99,114,101,101,110,0,0,0,77,83,32,87,105,110,100,111,119,115,32,77,101,100,105,97,32,86,105,100,101,111,32,86,57,32,83,99,114,101,101,110,0,0,0,0,0,0,0,0,73,110,115,117,102,102,105,99,105,101,110,116,32,101,120,116,114,97,100,97,116,97,32,115,105,122,101,58,32,101,120,112,101,99,116,101,100,32,37,100,32,103,111,116,32,37,100,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,54,83,0,0,77,83,32,83,99,114,101,101,110,32,49,0,0,0,0,0,78,101,120,116,32,108,105,110,101,32,105,115,32,98,101,121,111,110,100,32,112,105,99,116,117,114,101,32,98,111,117,110,100,115,32,40,37,100,32,98,121,116,101,115,32,108,101,102,116,41,10,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,82,76,69,0,0,0,109,97,116,114,111,115,107,97,32,97,117,100,105,111,32,109,117,120,101,114,0,0,0,0,115,45,62,102,108,105,112,102,108,111,112,95,114,111,117,110,100,105,110,103,61,61,48,0,80,105,99,107,32,111,110,101,32,99,111,110,116,105,110,117,111,117,115,32,115,101,99,116,105,111,110,32,102,114,111,109,32,116,104,101,32,105,110,112,117,116,44,32,100,114,111,112,32,116,104,101,32,114,101,115,116,46,0,0,0,0,0,0,67,111,114,114,117,112,116,32,115,105,112,114,32,82,77,45,115,116,121,108,101,32,97,117,100,105,111,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,53,83,0,0,77,80,76,50,32,115,117,98,116,105,116,108,101,0,0,0,76,69,73,84,67,72,0,0,83,116,114,101,97,109,77,117,120,67,111,110,102,105,103,32,105,110,116,101,114,118,97,108,46,0,0,0,0,0,0,0,72,82,69,83,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,52,83,0,0,70,108,97,103,115,32,99,111,109,109,111,110,32,102,111,114,32,97,108,108,32,109,112,101,103,118,105,100,101,111,45,98,97,115,101,100,32,101,110,99,111,100,101,114,115,46,0,0,48,114,103,98,0,0,0,0,80,97,108,101,71,111,108,100,101,110,82,111,100,0,0,0,114,101,115,97,109,112,108,101,114,0,0,0,0,0,0,0,112,115,110,114,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,105,109,103,50,101,110,99,46,99,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,51,83,0,0,71,67,83,95,75,101,114,116,97,117,0,0,0,0,0,0,109,105,120,101,100,45,114,101,102,115,0,0,0,0,0,0,112,97,121,108,111,97,100,95,116,121,112,101,0,0,0,0,115,101,116,32,97,117,100,105,111,32,115,97,109,112,108,105,110,103,32,114,97,116,101,32,40,105,110,32,72,122,41,0,115,101,116,32,112,97,116,116,101,114,110,32,116,121,112,101,0,0,0,0,0,0,0,0,32,86,79,76,67,0,0,0,112,105,99,45,62,102,46,100,97,116,97,91,48,93,0,0,102,105,108,109,0,0,0,0,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,0,77,80,50,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,0,0,0,0,73,66,77,32,85,108,116,105,77,111,116,105,111,110,0,0,77,80,50,32,102,105,120,101,100,32,112,111,105,110,116,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,50,41,0,0,0,0,80,111,119,101,114,32,66,97,108,108,97,100,0,0,0,0,112,103,109,0,0,0,0,0,109,112,101,103,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,50,83,0,0,99,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,116,97,100,97,116,97,32,116,97,103,32,37,115,33,10,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,49,83,0,0,98,117,102,102,101,114,115,105,110,107,0,0,0,0,0,0,116,105,109,101,0,0,0,0,82,101,97,100,32,102,114,111,109,32,97,32,109,111,118,105,101,32,115,111,117,114,99,101,46,0,0,0,0,0,0,0,77,80,49,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,49,41,0,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,77,80,49,32,40,77,80,69,71,32,97,117,100,105,111,32,108,97,121,101,114,32,49,41,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,48,83,0,0,109,112,101,103,116,115,95,102,108,97,103,115,0,0,0,0,116,105,109,101,95,105,110,99,114,32,62,61,32,48,0,0,115,107,105,112,112,105,110,103,32,37,100,32,115,101,103,109,101,110,116,115,32,97,104,101,97,100,44,32,101,120,112,105,114,101,100,32,102,114,111,109,32,112,108,97,121,108,105,115,116,115,10,0,0,0,0,0,80,97,115,115,32,111,110,32,116,104,101,32,105,110,112,117,116,32,116,111,32,78,32,118,105,100,101,111,32,111,117,116,112,117,116,115,46,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,57,83,0,0,108,105,118,101,0,0,0,0,103,110,114,101,0,0,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,116,114,97,99,107,32,116,121,112,101,32,37,120,10,0,0,80,84,83,32,37,108,108,100,44,32,110,101,120,116,58,37,108,108,100,32,105,110,118,97,108,105,100,32,100,114,111,112,112,105,110,103,32,115,116,58,37,100,10,0,0,0,0,0,105,103,110,111,114,101,32,108,111,111,112,32,115,101,116,116,105,110,103,32,40,110,101,116,115,99,97,112,101,32,101,120,116,101,110,115,105,111,110,41,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,109,98,95,110,117,109,32,105,110,32,118,105,100,101,111,32,112,97,99,107,101,116,32,40,37,100,32,37,100,41,32,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,56,83,0,0,71,73,70,32,109,117,120,101,114,0,0,0,0,0,0,0,65,117,116,104,111,114,0,0,115,45,62,112,105,99,116,117,114,101,95,115,116,114,117,99,116,117,114,101,32,61,61,32,51,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,55,83,0,0,80,97,99,107,101,116,115,32,97,114,101,32,110,111,116,32,105,110,32,116,104,101,32,112,114,111,112,101,114,32,111,114,100,101,114,32,119,105,116,104,32,114,101,115,112,101,99,116,32,116,111,32,68,84,83,10,0,0,0,0,0,0,0,0,77,80,69,71,45,49,32,118,105,100,101,111,0,0,0,0,107,101,121,102,114,97,109,101,115,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,54,83,0,0,77,117,115,101,112,97,99,107,32,83,86,56,0,0,0,0,37,100,47,37,100,32,105,110,112,117,116,32,116,105,109,101,32,98,97,115,101,32,109,97,116,99,104,101,100,32,37,100,47,37,100,32,99,111,110,116,97,105,110,101,114,32,116,105,109,101,32,98,97,115,101,10,0,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,77,117,115,101,112,97,99,107,32,83,86,55,0,0,0,0,51,71,80,80,32,84,105,109,101,100,32,84,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,51,71,80,80,32,84,105,109,101,100,32,84,101,120,116,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,77,111,116,105,111,110,32,80,105,120,101,108,115,32,118,105,100,101,111,0,0,0,0,0,65,109,101,114,105,99,97,110,32,76,97,115,101,114,32,71,97,109,101,115,32,77,77,32,86,105,100,101,111,0,0,0,84,105,109,101,98,97,115,101,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,53,83,0,0,77,76,80,32,40,77,101,114,105,100,105,97,110,32,76,111,115,115,108,101,115,115,32,80,97,99,107,105,110,103,41,0,83,101,116,32,80,84,83,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,118,105,100,101,111,32,102,114,97,109,101,46,0,0,0,0,0,109,97,106,111,114,32,115,121,110,99,32,105,110,102,111,32,104,101,97,100,101,114,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,100,118,46,99,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,52,83,0,0,49,46,48,0,0,0,0,0,98,103,114,97,54,52,108,101,0,0,0,0,0,0,0,0,79,114,99,104,105,100,0,0,114,101,115,97,109,112,108,101,95,99,117,116,111,102,102,0,101,114,114,111,114,32,117,115,105,110,103,32,101,120,116,101,114,110,97,108,32,104,117,102,102,109,97,110,32,116,97,98,108,101,44,32,115,119,105,116,99,104,105,110,103,32,98,97,99,107,32,116,111,32,105,110,116,101,114,110,97,108,10,0,108,111,111,107,97,104,101,97,100,108,101,115,115,32,109,98,45,116,114,101,101,32,114,101,113,117,105,114,101,115,32,105,110,116,114,97,32,114,101,102,114,101,115,104,32,111,114,32,105,110,102,105,110,105,116,101,32,107,101,121,105,110,116,10,0,0,0,0,0,0,0,0,65,112,112,108,101,32,77,74,80,69,71,45,66,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,51,83,0,0,71,67,83,95,75,97,110,100,97,119,97,108,97,0,0,0,77,105,109,105,99,0,0,0,99,104,114,111,109,97,45,109,101,0,0,0,0,0,0,0,97,114,0,0,0,0,0,0,77,105,99,114,111,68,86,68,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,76,69,65,68,95,80,69,82,70,79,82,77,69,82,0,0,37,115,10,0,0,0,0,0,83,101,108,101,99,116,32,116,104,101,32,113,117,97,108,105,116,121,32,102,111,114,32,99,111,110,115,116,97,110,116,32,113,117,97,108,105,116,121,32,109,111,100,101,0,0,0,0,105,100,102,0,0,0,0,0,86,111,120,119,97,114,101,32,77,101,116,97,83,111,117,110,100,0,0,0,0,0,0,0,117,108,116,105,0,0,0,0,83,111,110,121,32,80,108,97,121,83,116,97,116,105,111,110,32,77,68,69,67,32,40,77,111,116,105,111,110,32,68,69,67,111,100,101,114,41,0,0,66,97,108,108,97,100,0,0,65,116,32,108,101,97,115,116,32,111,110,101,32,111,117,116,112,117,116,32,102,105,108,101,32,109,117,115,116,32,98,101,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,10,37,115,32,32,37,45,49,54,115,58,32,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,50,83,0,0,85,110,97,98,108,101,32,116,111,32,112,97,114,115,101,32,103,114,97,112,104,32,100,101,115,99,114,105,112,116,105,111,110,32,115,117,98,115,116,114,105,110,103,58,32,34,37,115,34,10,0,0,0,0,0,0,77,65,67,69,32,40,77,97,99,105,110,116,111,115,104,32,65,117,100,105,111,32,67,111,109,112,114,101,115,115,105,111,110,47,69,120,112,97,110,115,105,111,110,41,32,51,58,49,0,0,0,0,0,0,0,0,115,45,62,109,97,120,98,105,116,115,32,62,61,32,57,32,38,38,32,115,45,62,109,97,120,98,105,116,115,32,60,61,32,49,50,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,112,99,95,116,121,112,101,32,61,61,32,70,70,95,76,80,67,95,84,89,80,69,95,67,72,79,76,69,83,75,89,32,124,124,32,108,112,99,95,116,121,112,101,32,61,61,32,70,70,95,76,80,67,95,84,89,80,69,95,76,69,86,73,78,83,79,78,0,0,0,0,76,79,67,79,0,0,0,0,76,111,115,115,108,101,115,115,32,74,80,69,71,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,49,83,0,0,115,101,116,32,116,104,101,32,114,101,99,111,114,100,105,110,103,32,116,105,109,101,115,116,97,109,112,32,40,39,110,111,119,39,32,116,111,32,115,101,116,32,116,104,101,32,99,117,114,114,101,110,116,32,116,105,109,101,41,0,0,0,0,0,105,100,120,49,0,0,0,0,98,101,115,116,95,97,115,116,45,62,114,101,109,97,105,110,105,110,103,32,60,61,32,98,101,115,116,95,97,115,116,45,62,112,97,99,107,101,116,95,115,105,122,101,0,0,0,0,108,105,98,97,118,102,111,114,109,97,116,47,97,117,46,99,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,48,83,0,0,73,110,118,97,108,105,100,32,108,111,111,112,101,110,100,32,118,97,108,117,101,10,0,0,108,105,98,120,50,54,52,32,72,46,50,54,52,32,47,32,65,86,67,32,47,32,77,80,69,71,45,52,32,65,86,67,32,47,32,77,80,69,71,45,52,32,112,97,114,116,32,49,48,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,57,83,0,0,97,117,116,104,111,114,0,0,105,110,118,97,108,105,100,32,112,97,100,115,105,122,101,32,37,100,32,97,116,58,37,108,108,100,10,0,0,0,0,0,68,84,83,32,37,108,108,100,44,32,110,101,120,116,58,37,108,108,100,32,115,116,58,37,100,32,105,110,118,97,108,105,100,32,100,114,111,112,112,105,110,103,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,56,83,0,0,108,105,98,118,112,120,32,86,80,56,0,0,0,0,0,0,108,105,98,118,112,120,32,86,80,56,0,0,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,90,76,73,66,0,0,0,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,77,83,90,72,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,55,83,0,0,76,97,103,97,114,105,116,104,32,108,111,115,115,108,101,115,115,0,0,0,0,0,0,0,75,97,114,108,32,77,111,114,116,111,110,39,115,32,118,105,100,101,111,32,99,111,100,101,99,0,0,0,0,0,0,0,75,101,103,97,32,71,97,109,101,32,86,105,100,101,111,0,73,110,118,97,108,105,100,32,112,105,120,101,108,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,0,66,105,116,109,97,112,32,66,114,111,116,104,101,114,115,32,74,86,32,118,105,100,101,111,0,0,0,0,0,0,0,0,74,80,69,71,45,76,83,0,111,118,101,114,115,105,122,101,32,105,109,97,103,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,54,83,0,0,74,80,69,71,32,50,48,48,48,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,113,117,97,110,116,105,122,97,116,105,111,110,32,102,111,114,109,97,116,10,0,0,0,0,83,121,110,99,32,108,101,118,101,108,32,37,117,10,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,53,83,0,0,74,65,67,79,115,117,98,32,115,117,98,116,105,116,108,101,0,0,0,0,0,0,0,0,66,117,102,102,101,114,32,105,110,112,117,116,32,105,109,97,103,101,115,32,97,110,100,32,115,101,110,100,32,116,104,101,109,32,119,104,101,110,32,116,104,101,121,32,97,114,101,32,114,101,113,117,101,115,116,101,100,46,0,0,0,0,0,0,74,80,69,71,32,50,48,48,48,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,108,97,118,102,105,46,115,105,108,101,110,99,101,95,101,110,100,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,52,83,0,0,83,121,110,116,97,120,32,101,114,114,111,114,32,110,101,97,114,32,34,37,46,56,115,34,10,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,105,108,101,32,105,110,105,116,105,97,108,105,122,105,110,103,32,99,117,115,116,111,109,32,118,108,99,32,116,97,98,108,101,33,10,0,0,0,0,0,98,103,114,97,54,52,98,101,0,0,0,0,0,0,0,0,79,114,97,110,103,101,82,101,100,0,0,0,0,0,0,0,67,104,97,110,110,101,108,32,109,97,112,32,100,101,115,99,114,105,98,101,115,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,46,10,0,0,0,0,115,101,116,32,99,117,116,111,102,102,32,102,114,101,113,117,101,110,99,121,32,114,97,116,105,111,0,0,0,0,0,0,105,110,118,97,108,105,100,32,122,111,110,101,32,112,97,114,97,109,58,32,37,115,32,61,32,37,115,10,0,0,0,0,32,65,80,0,0,0,0,0,105,110,116,114,97,45,114,101,102,114,101,115,104,32,105,115,32,110,111,116,32,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,111,112,101,110,45,103,111,112,10,0,0,73,110,116,101,114,112,108,97,121,32,77,86,69,32,118,105,100,101,111,0,0,0,0,0,115,111,102,116,45,107,110,101,101,0,0,0,0,0,0,0,66,97,100,32,109,97,114,107,101,114,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,51,83,0,0,71,67,83,95,75,97,108,105,97,110,112,117,114,0,0,0,112,115,121,0,0,0,0,0,83,101,116,32,116,105,109,101,98,97,115,101,32,102,111,114,32,116,104,101,32,118,105,100,101,111,32,111,117,116,112,117,116,32,108,105,110,107,46,0,115,101,116,32,116,104,101,32,103,114,111,117,112,32,111,102,32,112,105,99,116,117,114,101,32,40,71,79,80,41,32,115,105,122,101,0,0,0,0,0,99,104,97,110,110,101,108,95,108,97,121,111,117,116,0,0,73,110,116,101,108,32,73,110,100,101,111,32,86,105,100,101,111,32,73,110,116,101,114,97,99,116,105,118,101,32,53,0,113,0,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,112,116,105,111,110,32,39,37,115,32,61,32,37,115,39,46,10,0,0,0,0,0,0,0,0,99,114,102,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,86,105,100,101,111,32,73,110,116,101,114,97,99,116,105,118,101,32,52,0,84,101,99,104,83,109,105,116,104,32,83,99,114,101,101,110,32,67,97,112,116,117,114,101,32,67,111,100,101,99,0,0,70,111,108,107,108,111,114,101,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,73,110,116,101,108,32,73,110,100,101,111,32,51,0,0,0,65,112,112,108,121,32,97,32,108,111,119,45,112,97,115,115,32,102,105,108,116,101,114,32,119,105,116,104,32,51,100,66,32,112,111,105,110,116,32,102,114,101,113,117,101,110,99,121,46,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,50,83,0,0,73,110,116,101,108,32,73,110,100,101,111,32,50,0,0,0,100,101,115,99,0,0,0,0,122,101,114,111,115,32,33,61,32,110,115,97,109,112,108,101,115,0,0,0,0,0,0,0,73,77,67,32,40,73,110,116,101,108,32,77,117,115,105,99,32,67,111,100,101,114,41,0,116,49,45,116,50,0,0,0,73,70,70,0,0,0,0,0,105,100,32,81,117,97,107,101,32,73,73,32,67,73,78,32,118,105,100,101,111,0,0,0,70,108,97,116,32,102,97,99,116,111,114,58,32,37,102,10,0,0,0,0,0,0,0,0,72,117,102,102,121,117,118,32,47,32,72,117,102,102,89,85,86,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,49,83,0,0,116,105,109,101,115,116,97,109,112,0,0,0,0,0,0,0,72,117,102,102,121,117,118,32,47,32,72,117,102,102,89,85,86,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,32,45,45,32,109,105,115,115,105,110,103,32,101,110,100,45,111,102,45,98,108,111,99,107,0,0,0,0,69,114,114,111,114,32,98,117,105,108,100,105,110,103,32,116,114,101,101,10,0,0,0,0,83,116,114,101,116,99,104,105,110,103,32,97,117,100,105,111,32,102,105,102,111,32,102,97,105,108,101,100,44,32,100,105,115,99,97,114,100,101,100,32,37,100,32,115,97,109,112,108,101,115,10,0,0,0,0,0,72,78,77,32,52,32,118,105,100,101,111,0,0,0,0,0,83,107,105,112,112,101,100,32,80,82,69,70,73,88,32,83,69,73,32,37,100,10,0,0,111,117,116,108,105,110,107,45,62,115,97,109,112,108,101,95,114,97,116,101,32,61,61,32,111,117,116,95,114,97,116,101,0,0,0,0,0,0,0,0,79,117,116,112,117,116,32,102,114,97,109,101,32,119,105,116,104,32,80,79,67,32,37,100,46,10,0,0,0,0,0,0,115,101,116,32,100,101,99,97,121,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,48,83,0,0,111,117,116,115,97,109,112,108,101,115,114,101,102,45,62,115,97,109,112,108,101,95,114,97,116,101,32,61,61,32,111,117,116,108,105,110,107,45,62,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,114,101,102,115,32,105,110,32,97,32,115,104,111,114,116,32,116,101,114,109,32,82,80,83,46,10,0,0,0,0,0,108,111,110,103,101,115,116,0,105,110,112,117,116,115,0,0,115,97,109,112,108,101,95,114,97,116,101,115,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,57,83,0,0,97,117,116,104,0,0,0,0,115,115,0,0,0,0,0,0,72,69,86,67,32,40,72,105,103,104,32,69,102,102,105,99,105,101,110,99,121,32,86,105,100,101,111,32,67,111,100,105,110,103,41,0,0,0,0,0,115,101,116,32,115,105,103,110,97,108,32,105,110,112,117,116,32,103,97,105,110,0,0,0,116,105,109,101,115,116,97,109,112,32,100,105,115,99,111,110,116,105,110,117,105,116,121,32,37,108,108,100,44,32,110,101,119,32,111,102,102,115,101,116,61,32,37,108,108,100,10,0,98,105,116,95,100,101,112,116,104,60,61,56,0,0,0,0,73,68,51,118,50,46,37,100,32,116,97,103,32,115,107,105,112,112,101,100,44,32,99,97,110,110,111,116,32,104,97,110,100,108,101,32,37,115,10,0,83,101,110,100,32,99,111,109,109,97,110,100,115,32,116,111,32,102,105,108,116,101,114,115,46,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,56,83,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,112,114,101,100,95,99,111,109,109,111,110,46,104,0,0,124,0,0,0,0,0,0,0,115,117,98,115,105,122,101,32,60,32,66,76,79,67,75,95,83,73,90,69,83,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,55,83,0,0,71,101,110,101,114,97,116,101,32,83,77,80,84,69,32,99,111,108,111,114,32,98,97,114,115,46,0,0,0,0,0,0,98,105,116,95,100,101,112,116,104,60,61,56,0,0,0,0,83,69,73,32,116,121,112,101,32,37,100,32,115,105,122,101,32,37,100,32,116,114,117,110,99,97,116,101,100,32,97,116,32,37,100,10,0,0,0,0,115,101,116,32,116,101,115,116,32,116,111,32,112,101,114,102,111,114,109,0,0,0,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,115,119,105,116,99,104,97,98,108,101,95,105,110,116,101,114,112,44,32,122,101,114,111,95,99,111,117,110,116,115,46,115,119,105,116,99,104,97,98,108,101,95,105,110,116,101,114,112,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,115,119,105,116,99,104,97,98,108,101,95,105,110,116,101,114,112,41,41,0,0,0,0,0,0,108,101,110,32,60,61,32,51,50,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,54,83,0,0,115,101,116,32,109,97,120,32,105,116,101,114,97,116,105,111,110,115,32,110,117,109,98,101,114,0,0,0,0,0,0,0,99,104,114,111,109,97,95,102,111,114,109,97,116,95,105,100,99,32,37,117,0,0,0,0,65,86,67,58,32,110,97,108,32,115,105,122,101,32,37,100,10,0,0,0,0,0,0,0,98,66,115,83,0,0,0,0,103,114,97,121,32,99,104,114,111,109,97,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,53,83,0,0,102,0,0,0,0,0,0,0,33,40,108,102,109,45,62,97,98,111,118,101,95,121,91,84,88,95,56,88,56,93,32,38,32,108,102,109,45,62,97,98,111,118,101,95,121,91,84,88,95,52,88,52,93,41,0,0,115,101,110,100,32,111,110,101,32,102,114,97,109,101,32,102,111,114,32,101,97,99,104,32,102,105,101,108,100,44,32,98,117,116,32,115,107,105,112,32,115,112,97,116,105,97,108,32,105,110,116,101,114,108,97,99,105,110,103,32,99,104,101,99,107,0,0,0,0,0,0,0,111,110,108,121,32,100,101,105,110,116,101,114,108,97,99,101,32,102,114,97,109,101,115,32,109,97,114,107,101,100,32,97,115,32,105,110,116,101,114,108,97,99,101,100,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,52,83,0,0,66,108,117,101,115,0,0,0,108,101,102,116,32,98,108,111,99,107,32,117,110,97,118,97,105,108,97,98,108,101,32,102,111,114,32,114,101,113,117,101,115,116,101,100,32,105,110,116,114,97,52,120,52,32,109,111,100,101,32,37,100,32,97,116,32,37,100,32,37,100,10,0,97,114,101,115,97,109,112,108,101,95,115,119,114,95,111,112,116,115,0,0,0,0,0,0,116,98,0,0,0,0,0,0,114,103,98,97,54,52,108,101,0,0,0,0,0,0,0,0,79,114,97,110,103,101,0,0,99,117,116,111,102,102,0,0,72,46,50,54,49,0,0,0,44,0,0,0,0,0,0,0,114,101,102,32,62,32,49,32,43,32,105,110,116,114,97,45,114,101,102,114,101,115,104,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,72,46,50,54,49,0,0,0,108,97,0,0,0,0,0,0,71,83,77,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,51,83,0,0,71,67,83,95,74,65,68,54,57,0,0,0,0,0,0,0,37,102,0,0,0,0,0,0,114,111,116,97,116,101,32,99,108,111,99,107,119,105,115,101,32,119,105,116,104,32,118,101,114,116,105,99,97,108,32,102,108,105,112,0,0,0,0,0,103,0,0,0,0,0,0,0,71,73,70,32,40,71,114,97,112,104,105,99,115,32,73,110,116,101,114,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,83,0,0,0,0,0,0,0,84,104,101,32,102,114,97,109,101,32,112,97,114,116,105,116,105,111,110,115,32,97,114,101,32,105,110,100,101,112,101,110,100,101,110,116,108,121,32,100,101,99,111,100,97,98,108,101,32,98,121,32,116,104,101,32,98,111,111,108,32,100,101,99,111,100,101,114,44,32,109,101,97,110,105,110,103,32,116,104,97,116,32,112,97,114,116,105,116,105,111,110,115,32,99,97,110,32,98,101,32,100,101,99,111,100,101,100,32,101,118,101,110,32,116,104,111,117,103,104,32,101,97,114,108,105,101,114,32,112,97,114,116,105,116,105,111,110,115,32,104,97,118,101,32,98,101,101,110,32,108,111,115,116,46,32,78,111,116,101,32,116,104,97,116,32,105,110,116,114,97,32,112,114,101,100,105,99,105,116,105,111,110,32,105,115,32,115,116,105,108,108,32,100,111,110,101,32,111,118,101,114,32,116,104,101,32,112,97,114,116,105,116,105,111,110,32,98,111,117,110,100,97,114,121,46,0,0,0,0,0,0,71,73,70,32,40,71,114,97,112,104,105,99,115,32,73,110,116,101,114,99,104,97,110,103,101,32,70,111,114,109,97,116,41,0,0,0,0,0,0,0,112,97,100,32,97,108,116,101,114,110,97,116,101,32,108,105,110,101,115,32,119,105,116,104,32,98,108,97,99,107,0,0,71,46,55,50,57,0,0,0,116,115,99,99,0,0,0,0,112,97,100,100,105,110,103,0,83,97,109,98,97,0,0,0,71,46,55,50,54,32,65,68,80,67,77,0,0,0,0,0,8,10,11,12,13,0,0,0,73,110,118,97,108,105,100,32,112,105,99,116,117,114,101,32,116,121,112,101,58,32,37,100,46,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,50,83,0,0,71,46,55,50,51,46,49,0,71,46,55,50,50,32,65,68,80,67,77,0,0,0,0,0,71,46,55,50,50,32,65,68,80,67,77,0,0,0,0,0,98,111,116,116,111,109,0,0,71,111,50,77,101,101,116,105,110,103,0,0,0,0,0,0,70,111,114,119,97,114,100,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,70,114,97,112,115,0,0,0,83,101,108,101,99,116,32,97,117,100,105,111,32,102,114,97,109,101,115,32,116,111,32,112,97,115,115,32,105,110,32,111,117,116,112,117,116,46,0,0,70,76,86,32,47,32,83,111,114,101,110,115,111,110,32,83,112,97,114,107,32,47,32,83,111,114,101,110,115,111,110,32,72,46,50,54,51,32,40,70,108,97,115,104,32,86,105,100,101,111,41,0,0,0,0,0,66,97,100,32,112,105,99,116,117,114,101,32,102,111,114,109,97,116,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,49,83,0,0,115,99,97,108,101,0,0,0,97,98,111,118,101,32,98,101,108,111,119,32,114,105,103,104,116,32,102,105,114,115,116,0,65,117,116,111,100,101,115,107,32,65,110,105,109,97,116,111,114,32,70,108,105,99,32,118,105,100,101,111,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,0,0,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,86,101,114,115,105,111,110,32,50,0,0,0,0,104,97,114,100,32,116,104,114,101,115,104,111,108,100,105,110,103,0,0,0,0,0,0,0,70,108,97,115,104,32,83,99,114,101,101,110,32,86,105,100,101,111,32,118,49,0,0,0,108,116,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,48,83,0,0,109,97,114,107,32,97,115,32,112,114,111,103,114,101,115,115,105,118,101,0,0,0,0,0,116,105,109,101,98,97,115,101,32,110,111,116,32,115,101,116,32,102,111,114,32,97,117,100,105,111,32,105,110,116,101,114,108,101,97,118,101,10,0,0,70,76,65,67,32,40,70,114,101,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,0,70,76,65,67,32,40,70,114,101,101,32,76,111,115,115,108,101,115,115,32,65,117,100,105,111,32,67,111,100,101,99,41,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,57,83,0,0,99,111,117,108,100,110,39,116,32,114,101,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,32,111,102,32,115,105,122,101,32,37,116,100,10,0,115,119,115,95,102,108,97,103,115,0,0,0,0,0,0,0,116,105,116,108,101,0,0,0,105,110,118,97,108,105,100,32,99,104,97,110,110,101,108,32,109,111,100,101,58,32,37,100,10,0,0,0,0,0,0,0,77,105,114,105,108,108,105,115,32,70,73,67,0,0,0,0,87,97,118,101,32,115,121,110,116,104,101,115,105,115,32,112,115,101,117,100,111,45,99,111,100,101,99,0,0,0,0,0,108,115,0,0,0,0,0,0,70,70,109,112,101,103,32,118,105,100,101,111,32,99,111,100,101,99,32,35,49,0,0,0,73,110,116,101,114,32,115,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2597024);
/* memory initializer */ allocate([114,101,97,109,32,116,105,109,101,115,116,97,109,112,32,100,105,115,99,111,110,116,105,110,117,105,116,121,32,37,108,108,100,44,32,110,101,119,32,111,102,102,115,101,116,61,32,37,108,108,100,10,0,0,0,0,111,117,116,95,104,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,105,100,44,32,97,115,115,117,109,105,110,103,32,112,97,100,100,105,110,103,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,56,83,0,0,70,70,109,112,101,103,32,118,105,100,101,111,32,99,111,100,101,99,32,35,49,0,0,0,83,101,116,32,112,101,114,109,105,115,115,105,111,110,115,32,102,111,114,32,116,104,101,32,111,117,116,112,117,116,32,97,117,100,105,111,32,102,114,97,109,101,46,0,0,0,0,0,115,101,116,32,115,116,114,105,99,116,32,98,114,101,97,107,115,0,0,0,0,0,0,0,112,115,110,114,95,37,99,58,37,48,46,50,102,32,0,0,79,112,101,110,69,88,82,32,105,109,97,103,101,0,0,0,69,86,82,67,32,40,69,110,104,97,110,99,101,100,32,86,97,114,105,97,98,108,101,32,82,97,116,101,32,67,111,100,101,99,41,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,55,83,0,0,69,115,99,97,112,101,32,49,51,48,0,0,0,0,0,0,69,115,99,97,112,101,32,49,50,52,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,81,73,32,86,105,100,101,111,0,0,0,0,0,0,0,116,111,112,32,102,105,114,115,116,32,97,110,97,108,121,122,101,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,71,86,32,118,105,100,101,111,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,84,71,81,32,118,105,100,101,111,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,97,100,99,111,119,32,86,105,100,101,111,0,0,0,0,109,98,109,105,45,62,109,111,100,101,32,61,61,32,109,98,109,105,45,62,117,118,95,109,111,100,101,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,67,77,86,32,118,105,100,101,111,0,0,0,0,0,0,0,115,101,116,32,116,111,112,32,114,105,103,104,116,32,121,32,99,111,111,114,100,105,110,97,116,101,0,0,0,0,0,0,87,77,47,65,108,98,117,109,65,114,116,105,115,116,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,54,83,0,0,115,101,116,32,116,104,101,32,120,32,111,102,102,115,101,116,32,101,120,112,114,101,115,115,105,111,110,32,102,111,114,32,116,104,101,32,105,110,112,117,116,32,105,109,97,103,101,32,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,0,65,84,83,67,32,65,47,53,50,32,69,45,65,67,45,51,0,0,0,0,0,0,0,0,68,120,116,111,114,121,0,0,70,101,101,98,108,101,32,70,105,108,101,115,47,83,99,117,109,109,86,77,32,68,88,65,0,0,0,0,0,0,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,68,86,68,32,115,117,98,116,105,116,108,101,115,0,0,0,119,0,0,0,0,0,0,0,68,86,68,32,115,117,98,116,105,116,108,101,115,0,0,0,84,101,109,112,111,114,97,108,108,121,32,105,110,116,101,114,108,101,97,118,101,32,118,105,100,101,111,32,105,110,112,117,116,115,46,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,53,83,0,0,68,86,32,40,68,105,103,105,116,97,108,32,86,105,100,101,111,41,0,0,0,0,0,0,99,109,45,62,104,101,105,103,104,116,32,60,61,32,99,112,105,45,62,105,110,105,116,105,97,108,95,104,101,105,103,104,116,0,0,0,0,0,0,0,68,86,66,32,115,117,98,116,105,116,108,101,115,0,0,0,68,86,66,32,115,117,98,116,105,116,108,101,115,0,0,0,97,118,101,114,97,103,101,100,32,110,111,105,115,101,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,105,110,32,99,109,112,32,102,117,110,99,116,105,111,110,32,115,101,108,101,99,116,105,111,110,10,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,68,101,108,112,104,105,110,101,32,83,111,102,116,119,97,114,101,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,67,73,78,32,118,105,100,101,111,0,0,0,0,0,0,0,68,80,88,32,40,68,105,103,105,116,97,108,32,80,105,99,116,117,114,101,32,69,120,99,104,97,110,103,101,41,32,105,109,97,103,101,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,52,83,0,0,68,80,88,32,40,68,105,103,105,116,97,108,32,80,105,99,116,117,114,101,32,69,120,99,104,97,110,103,101,41,32,105,109,97,103,101,0,0,0,0,68,80,67,77,32,73,110,116,101,114,112,108,97,121,0,0,102,102,95,118,102,95,103,101,116,95,105,109,97,103,101,58,32,84,114,105,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,97,32,102,111,114,109,97,116,32,116,104,97,116,32,99,97,110,32,110,111,116,32,98,101,32,97,108,108,111,99,97,116,101,100,33,10,0,114,103,98,97,54,52,98,101,0,0,0,0,0,0,0,0,79,108,105,118,101,68,114,97,98,0,0,0,0,0,0,0,86,67,51,47,68,78,120,72,68,0,0,0,0,0,0,0,115,101,116,32,111,117,116,112,117,116,32,112,105,120,101,108,32,102,111,114,109,97,116,0,101,110,97,98,108,101,32,108,105,110,101,97,114,32,105,110,116,101,114,112,111,108,97,116,105,111,110,0,0,0,0,0,105,110,118,97,108,105,100,32,122,111,110,101,58,32,34,37,115,34,10,0,0,0,0,0,86,67,51,47,68,78,120,72,68,0,0,0,0,0,0,0,121,117,118,52,50,50,112,49,48,0,0,0,0,0,0,0,98,45,112,121,114,97,109,105,100,32,110,111,114,109,97,108,32,43,32,105,110,116,114,97,45,114,101,102,114,101,115,104,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,97,115,115,117,109,101,32,116,111,112,32,102,105,101,108,100,32,102,105,114,115,116,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,97,99,116,105,118,101,95,109,97,112,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,51,83,0,0,71,67,83,95,74,97,109,97,105,99,97,95,49,56,55,53,0,0,0,0,0,0,0,0,66,66,67,32,68,105,114,97,99,32,86,67,45,50,0,0,37,102,124,37,102,0,0,0,83,116,114,101,97,109,32,109,97,121,32,104,97,118,101,32,117,110,104,97,110,100,108,101,100,32,102,101,97,116,117,114,101,115,10,0,0,0,0,0,80,67,77,32,99,104,97,110,110,101,108,115,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,116,105,109,101,95,98,97,115,101,0,0,0,0,0,0,0,67,104,114,111,110,111,109,97,115,116,101,114,32,68,70,65,0,0,0,0,0,0,0,0,66,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,112,97,114,116,105,116,105,111,110,115,0,0,0,0,0,0,110,101,97,114,101,115,116,0,86,68,80,65,85,32,100,101,99,111,100,105,110,103,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,118,105,100,101,111,32,99,111,108,111,114,115,112,97,99,101,46,10,0,0,0,0,0,0,68,67,65,32,40,68,84,83,32,67,111,104,101,114,101,110,116,32,65,99,111,117,115,116,105,99,115,41,0,0,0,0,83,110,111,119,0,0,0,0,84,97,110,103,111,0,0,0,115,101,116,32,116,104,101,32,105,110,112,117,116,32,116,115,32,115,99,97,108,101,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,0,0,0,0,0,0,0,37,115,32,32,37,45,49,54,115,58,32,0,0,0,0,0,110,101,103,97,116,101,95,97,108,112,104,97,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,50,83,0,0,68,67,65,32,40,68,84,83,32,67,111,104,101,114,101,110,116,32,65,99,111,117,115,116,105,99,115,41,0,0,0,0,101,110,97,98,108,101,32,116,119,111,119,97,121,0,0,0,65,117,114,97,118,105,115,105,111,110,32,65,85,82,65,0,67,97,109,83,116,117,100,105,111,0,0,0,0,0,0,0,84,104,105,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,32,97,110,100,32,97,108,119,97,121,115,32,115,101,116,46,10,0,0,0,0,0,0,67,80,105,65,32,118,105,100,101,111,32,102,111,114,109,97,116,0,0,0,0,0,0,0,115,101,108,101,99,116,32,99,104,114,111,109,97,32,109,111,100,101,0,0,0,0,0,0,97,113,95,109,111,100,101,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,48,46,46,65,81,95,77,79,68,69,95,67,79,85,78,84,32,45,32,49,93,0,0,0,0,0,67,111,111,107,32,47,32,67,111,111,107,101,114,32,47,32,71,101,99,107,111,32,40,82,101,97,108,65,117,100,105,111,32,71,50,41,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,49,83,0,0,32,32,32,32,32,32,32,35,37,100,58,32,37,115,32,40,37,115,41,10,0,0,0,0,66,111,116,116,111,109,32,70,105,101,108,100,32,70,105,114,115,116,0,0,0,0,0,0,116,98,0,0,0,0,0,0,103,95,108,97,103,95,105,110,95,102,114,97,109,101,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,50,53,93,0,0,0,0,0,100,101,102,97,117,108,116,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,48,83,0,0,99,111,108,111,114,0,0,0,119,101,97,107,0,0,0,0,97,108,112,104,97,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,57,83,0,0,0,110,111,110,101,0,0,0,0,116,105,116,108,0,0,0,0,67,111,110,99,97,116,101,110,97,116,101,100,32,72,46,50,54,52,32,111,114,32,72,46,50,54,53,32,109,105,103,104,116,32,110,111,116,32,112,108,97,121,32,99,111,114,114,101,99,116,108,121,46,10,0,0,86,105,101,119,115,32,97,114,101,32,105,110,116,101,114,108,101,97,118,101,100,32,98,121,32,108,105,110,101,115,0,0,73,78,84,0,0,0,0,0,114,111,117,110,100,32,116,111,119,97,114,100,115,32,48,0,67,111,114,114,101,99,116,105,110,103,32,115,116,97,114,116,32,116,105,109,101,32,98,121,32,37,108,108,100,10,0,0,112,114,111,103,114,101,115,115,105,118,101,32,102,114,97,109,101,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,117,110,99,111,109,112,114,101,115,115,32,116,97,103,58,32,37,100,10,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,56,83,0,0,0,69,66,85,32,82,49,50,56,32,115,99,97,110,110,101,114,46,0,0,0,0,0,0,0,97,105,102,102,0,0,0,0,67,79,77,66,83,58,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,32,37,51,100,10,0,0,0,0,0,99,108,69,110,113,117,101,117,101,78,68,82,97,110,103,101,75,101,114,110,101,108,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,55,83,0,0,0,108,105,98,97,118,117,116,105,108,47,117,116,105,108,115,46,99,0,0,0,0,0,0,0,112,97,108,56,0,0,0,0,102,97,100,101,45,111,117,116,0,0,0,0,0,0,0,0,97,105,102,102,0,0,0,0,37,72,37,77,37,83,0,0,115,101,116,32,117,32,112,108,97,110,101,0,0,0,0,0,37,100,0,0,0,0,0,0,27,91,52,56,59,53,59,37,100,109,27,91,51,56,59,53,59,37,100,109,37,115,27,91,48,109,0,0,0,0,0,0,97,102,99,0,0,0,0,0,100,101,102,97,117,108,116,0,83,72,65,51,56,52,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,54,83,0,0,0,97,116,97,110,0,0,0,0,68,101,109,117,120,101,114,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,76,70,69,0,0,0,0,0,97,101,97,0,0,0,0,0,79,114,100,101,114,101,100,32,100,105,116,104,101,114,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,102,117,108,108,32,99,104,114,111,109,97,32,105,110,116,101,114,112,111,108,97,116,105,111,110,32,102,111,114,32,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,0,0,102,105,114,115,116,67,104,114,83,114,99,89,32,62,61,32,108,97,115,116,73,110,67,104,114,66,117,102,32,45,32,118,67,104,114,66,117,102,83,105,122,101,32,43,32,49,0,0,105,110,116,101,114,108,97,99,101,100,32,40,37,108,108,100,41,32,62,32,108,101,118,101,108,32,108,105,109,105,116,32,40,37,100,41,10,0,0,0,119,0,0,0,0,0,0,0,97,118,101,114,97,103,105,110,103,32,97,114,101,97,0,0,97,100,120,0,0,0,0,0,117,99,104,0,0,0,0,0,77,80,69,71,45,49,32,118,105,100,101,111,0,0,0,0,82,70,67,32,51,51,56,57,32,99,111,109,102,111,114,116,32,110,111,105,115,101,32,103,101,110,101,114,97,116,111,114,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,82,70,67,32,51,51,56,57,32,99,111,109,102,111,114,116,32,110,111,105,115,101,32,103,101,110,101,114,97,116,111,114,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,83,0,0,0,67,97,110,111,112,117,115,32,76,111,115,115,108,101,115,115,32,67,111,100,101,99,0,0,115,101,116,32,119,105,100,116,104,32,102,111,114,32,116,104,101,32,114,101,99,116,97,110,103,117,108,97,114,32,115,101,97,114,99,104,32,97,114,101,97,0,0,0,0,0,0,0,67,105,114,114,117,115,32,76,111,103,105,99,32,65,99,99,117,80,97,107,0,0,0,0,115,101,116,32,108,111,103,111,32,104,101,105,103,104,116,0,115,45,62,113,117,97,114,116,101,114,95,115,97,109,112,108,101,0,0,0,0,0,0,0,67,105,110,101,112,97,107,32,47,32,67,86,73,68,0,0,67,105,110,101,112,97,107,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,92,37,49,91,49,50,51,52,93,97,38,72,37,50,88,38,37,49,91,92,125,93,37,110,0,0,0,0,0,0,0,0,37,100,58,37,48,50,100,58,37,48,50,100,46,37,48,50,100,44,0,0,0,0,0,0,67,111,109,109,111,100,111,114,101,32,67,68,88,76,32,118,105,100,101,111,0,0,0,0,105,110,118,97,108,105,100,32,122,101,114,111,32,98,108,111,99,107,32,115,105,122,101,32,111,102,32,37,100,32,37,100,32,37,100,10,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,115,108,105,99,101,32,98,117,102,102,101,114,10,0,0,111,110,108,121,32,115,116,101,114,101,111,32,111,114,32,109,111,110,111,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,67,68,32,71,114,97,112,104,105,99,115,32,118,105,100,101,111,0,0,0,0,0,0,0,32,91,68,82,79,80,93,0,65,68,80,67,77,32,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,77,97,120,105,115,32,67,68,82,79,77,32,88,65,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,83,0,0,0,67,104,105,110,101,115,101,32,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,40,65,86,83,49,45,80,50,44,32,74,105,90,104,117,110,32,112,114,111,102,105,108,101,41,0,0,0,0,100,101,102,97,117,108,116,0,115,117,114,114,111,117,110,100,95,109,105,120,108,101,118,0,114,97,116,101,99,111,110,116,114,111,108,95,105,110,105,116,58,32,99,97,110,39,116,32,111,112,101,110,32,115,116,97,116,115,32,102,105,108,101,10,0,0,0,0,0,0,0,0,73,110,116,101,114,112,108,97,121,32,67,57,51,0,0,0,115,117,114,114,111,117,110,100,95,109,105,120,108,101,118,0,78,111,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,115,112,101,99,105,102,105,101,100,46,32,84,104,101,32,101,110,99,111,100,101,114,32,119,105,108,108,32,103,117,101,115,115,32,116,104,101,32,108,97,121,111,117,116,44,32,98,117,116,32,105,116,32,109,105,103,104,116,32,98,101,32,105,110,99,111,114,114,101,99,116,46,10,0,0,0,0,0,76,116,47,82,116,32,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,66,82,101,110,100,101,114,32,80,73,88,32,105,109,97,103,101,0,0,0,0,0,0,0,69,82,82,79,82,32,58,32,110,111,32,115,117,98,98,97,110,100,32,102,111,117,110,100,32,102,111,114,32,102,114,101,113,117,101,110,99,121,32,37,100,10,0,0,0,0,0,0,97,100,116,115,0,0,0,0,65,65,67,32,101,110,99,111,100,101,114,0,0,0,0,0,110,118,50,48,98,101,0,0,79,108,105,118,101,0,0,0,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,68,105,115,99,119,111,114,108,100,32,73,73,32,66,77,86,32,118,105,100,101,111,0,0,108,105,110,101,97,114,95,105,110,116,101,114,112,0,0,0,99,102,114,97,109,101,32,105,100,32,109,105,115,109,97,116,99,104,32,37,100,32,37,100,10,0,0,0,0,0,0,0,66,77,80,32,40,87,105,110,100,111,119,115,32,97,110,100,32,79,83,47,50,32,98,105,116,109,97,112,41,0,0,0,37,100,44,37,100,37,110,0,67,97,110,110,111,116,32,104,97,110,100,108,101,32,102,111,114,109,97,116,32,37,105,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,105,103,104,116,58,32,37,100,46,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,109,97,112,32,98,105,116,32,111,114,100,101,114,10,0,0,0,0,0,0,0,115,117,98,109,101,61,48,32,43,32,100,105,114,101,99,116,61,116,101,109,112,111,114,97,108,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,100,97,116,97,32,97,116,32,39,37,46,56,115,39,10,0,0,0,0,0,0,102,40,37,102,41,61,37,102,32,45,62,32,121,91,37,100,93,61,37,100,10,0,0,0,66,77,80,32,40,87,105,110,100,111,119,115,32,97,110,100,32,79,83,47,50,32,98,105,116,109,97,112,41,0,0,0,73,110,118,97,108,105,100,32,86,66,77,32,116,114,101,101,59,32,98,114,111,107,101,110,32,101,120,116,114,97,100,97,116,97,63,10,0,0,0,0,97,100,112,0,0,0,0,0,110,117,109,95,118,101,99,95,99,111,101,102,102,115,32,43,32,111,102,102,115,101,116,32,60,61,32,40,115,105,122,101,111,102,40,115,45,62,99,104,97,110,110,101,108,91,99,93,46,111,117,116,41,32,47,32,115,105,122,101,111,102,40,40,115,45,62,99,104,97,110,110,101,108,91,99,93,46,111,117,116,41,91,48,93,41,41,0,79,114,100,101,114,91,37,100,93,91,37,100,93,32,37,100,32,62,32,109,97,120,32,40,37,100,41,44,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,48,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,83,0,0,0,110,101,120,116,95,98,108,111,99,107,95,108,101,110,95,98,105,116,115,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,0,71,67,83,95,73,110,100,105,97,110,95,49,57,55,53,0,60,47,98,62,0,0,0,0,115,107,105,112,112,105,110,103,32,117,110,115,117,112,112,111,114,116,101,100,32,99,104,117,110,107,58,32,37,115,10,0,118,108,99,45,62,116,97,98,108,101,95,115,105,122,101,32,38,38,32,118,108,99,45,62,116,97,98,108,101,95,115,105,122,101,32,61,61,32,118,108,99,45,62,116,97,98,108,101,95,97,108,108,111,99,97,116,101,100,0,0,0,0,0,0,109,105,100,47,115,105,100,101,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,98,117,102,102,101,114,0,0,37,102,44,37,102,0,0,0,78,111,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,116,101,114,109,115,32,109,101,116,10,0,0,0,0,0,73,110,118,97,108,105,100,32,80,67,77,32,112,97,99,107,101,116,44,32,100,97,116,97,32,104,97,115,32,115,105,122,101,32,37,100,32,98,117,116,32,97,116,32,108,101,97,115,116,32,97,32,115,105,122,101,32,111,102,32,37,100,32,119,97,115,32,101,120,112,101,99,116,101,100,10,0,0,0,0,100,101,99,111,100,101,95,102,111,114,109,97,116,56,48,32,112,114,111,98,108,101,109,58,32,100,101,115,116,95,105,110,100,101,120,32,40,37,100,41,32,101,120,99,101,101,100,101,100,32,100,101,115,116,95,115,105,122,101,32,40,37,100,41,10,0,0,0,0,0,0,0,82,71,66,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,112,114,111,102,105,108,101,32,48,10,0,101,120,116,114,97,100,97,116,97,95,115,105,122,101,0,0,66,105,110,97,114,121,32,116,101,120,116,0,0,0,0,0,86,80,32,118,101,114,115,105,111,110,58,32,37,100,10,0,80,0,0,0,0,0,0,0,67,117,114,114,101,110,116,32,70,70,109,112,101,103,32,86,111,114,98,105,115,32,101,110,99,111,100,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,50,32,99,104,97,110,110,101,108,115,46,10,0,0,0,0,0,0,0,0,32,73,110,118,97,108,105,100,32,114,101,115,105,100,117,101,32,116,121,112,101,32,119,104,105,108,101,32,114,101,115,105,100,117,101,32,100,101,99,111,100,101,63,33,32,10,0,0,61,0,0,0,0,0,0,0,73,109,112,114,111,118,101,32,114,101,115,105,108,105,101,110,99,121,32,97,103,97,105,110,115,116,32,108,111,115,115,101,115,32,111,102,32,119,104,111,108,101,32,102,114,97,109,101,115,0,0,0,0,0,0,0,66,105,110,107,32,65,117,100,105,111,32,40,82,68,70,84,41,0,0,0,0,0,0,0,73,100,32,104,101,97,100,101,114,32,105,115,32,116,111,111,32,115,104,111,114,116,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,105,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,115,101,116,32,116,104,101,32,120,32,99,114,111,112,32,97,114,101,97,32,101,120,112,114,101,115,115,105,111,110,0,0,68,101,108,97,121,101,100,32,102,114,97,109,101,115,32,115,101,101,110,46,32,82,101,101,110,97,98,108,105,110,103,32,108,111,119,32,100,101,108,97,121,32,114,101,113,117,105,114,101,115,32,97,32,99,111,100,101,99,32,102,108,117,115,104,46,10,0,0,0,0,0,0,105,109,97,103,101,32,116,111,111,32,115,104,111,114,116,10,0,0,0,0,0,0,0,0,66,105,110,107,32,118,105,100,101,111,0,0,0,0,0,0,97,99,116,0,0,0,0,0,67,76,90,32,116,101,115,116,32,102,97,105,108,101,100,58,32,120,50,54,52,32,104,97,115,32,98,101,101,110,32,109,105,115,99,111,109,112,105,108,101,100,33,10,0,0,0,0,69,110,116,114,121,32,112,111,105,110,116,58,32,37,48,56,88,10,0,0,0,0,0,0,115,110,111,119,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,83,0,0,0,66,114,117,116,101,32,70,111,114,99,101,32,38,32,73,103,110,111,114,97,110,99,101,0,67,108,117,98,0,0,0,0,102,99,99,0,0,0,0,0,80,114,101,100,105,99,116,105,111,110,32,109,101,116,104,111,100,32,37,100,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,105,110,32,85,116,32,86,105,100,101,111,46,10,0,0,0,0,0,68,101,99,111,100,105,110,103,32,101,114,114,111,114,10,0,66,101,116,104,101,115,100,97,32,86,73,68,32,118,105,100,101,111,0,0,0,0,0,0,37,115,77,101,116,97,100,97,116,97,58,10,0,0,0,0,65,118,105,100,32,77,101,114,105,100,105,101,110,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,0,0,65,117,100,105,111,32,111,112,116,105,111,110,115,58,0,0,65,118,105,100,32,77,101,114,105,100,105,101,110,32,85,110,99,111,109,112,114,101,115,115,101,100,0,0,0,0,0,0,65,86,83,32,40,65,117,100,105,111,32,86,105,100,101,111,32,83,116,97,110,100,97,114,100,41,32,118,105,100,101,111,0,0,0,0,0,0,0,0,84,104,105,115,32,65,86,67,111,100,101,99,67,111,110,116,101,120,116,32,119,97,115,32,97,108,108,111,99,97,116,101,100,32,102,111,114,32,37,115,44,32,98,117,116,32,37,115,32,112,97,115,115,101,100,32,116,111,32,97,118,99,111,100,101,99,95,111,112,101,110,50,40,41,10,0,0,0,0,0,65,118,105,100,32,65,86,73,32,67,111,100,101,99,0,0,100,97,116,97,95,108,101,110,103,116,104,58,32,37,100,32,102,114,97,109,101,95,108,101,110,103,116,104,58,32,37,100,32,108,97,115,116,58,32,37,100,32,116,111,116,97,108,58,32,37,100,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,115,101,116,32,116,104,101,32,114,101,100,32,103,97,105,110,32,102,111,114,32,116,104,101,32,103,114,101,101,110,32,99,104,97,110,110,101,108,0,0,73,110,99,111,114,114,101,99,116,32,110,117,109,98,101,114,32,111,102,32,116,111,107,101,110,115,58,32,37,105,10,0,116,97,98,108,101,115,58,32,37,100,32,47,32,37,100,32,99,58,37,100,32,37,100,120,37,100,32,116,58,37,100,32,37,115,37,115,37,115,37,115,10,0,0,0,0,0,0,0,84,73,70,70,32,101,110,99,111,100,101,114,0,0,0,0,115,101,116,32,103,114,101,101,110,32,109,105,100,116,111,110,101,115,0,0,0,0,0,0,40,117,110,115,105,103,110,101,100,41,112,107,116,45,62,115,105,122,101,32,60,61,32,48,120,55,102,102,102,102,102,102,102,32,45,32,49,54,0,0,65,117,114,97,118,105,115,105,111,110,32,65,117,114,97,32,50,0,0,0,0,0,0,0,97,99,51,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,83,0,0,0,105,116,115,115,99,97,108,101,0,0,0,0,0,0,0,0,82,97,100,105,117,115,32,111,102,32,116,104,101,32,99,104,114,111,109,97,32,98,108,117,114,114,105,110,103,32,98,111,120,0,0,0,0,0,0,0,65,84,82,65,67,51,43,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,32,51,43,41,0,71,101,111,103,69,108,108,105,112,115,111,105,100,71,101,111,75,101,121,0,0,0,0,0,79,108,100,32,115,116,121,108,101,32,76,90,87,32,105,115,32,117,110,115,117,112,112,111,114,116,101,100,10,0,0,0,65,84,82,65,67,51,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,32,51,41,0,0,0,112,106,115,32,100,101,99,111,100,101,114,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,84,82,65,67,49,32,40,65,100,97,112,116,105,118,101,32,84,82,97,110,115,102,111,114,109,32,65,99,111,117,115,116,105,99,32,67,111,100,105,110,103,41,0,0,0,0,0,99,98,112,95,118,108,99,61,37,100,10,0,0,0,0,0,65,83,85,83,32,86,49,0,97,97,99,0,0,0,0,0,123,92,37,42,91,94,125,93,125,37,110,0,0,0,0,0,105,110,118,97,108,105,100,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,37,100,10,0,0,0,0,0,0,0,112,97,115,115,58,52,109,118,32,99,104,97,110,103,101,100,58,37,100,10,0,0,0,0,115,112,97,116,105,97,108,95,100,101,99,111,109,112,111,115,105,116,105,111,110,95,99,111,117,110,116,32,37,100,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,115,105,122,101,10,0,0,0,0,0,0,65,83,85,83,32,86,49,0,108,101,110,103,116,104,32,116,111,111,32,108,111,110,103,10,0,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,58,32,37,100,10,0,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,105,103,110,111,114,105,110,103,32,105,110,118,97,108,105,100,32,109,111,116,105,111,110,32,118,101,99,116,111,114,32,40,37,105,44,32,37,105,41,45,62,40,37,117,44,32,37,117,41,44,32,98,108,111,99,107,32,115,105,122,101,32,61,32,37,117,10,0,0,0,0,0,83,83,65,32,40,83,117,98,83,116,97,116,105,111,110,32,65,108,112,104,97,41,32,115,117,98,116,105,116,108,101,0,66,0,0,0,0,0,0,0,69,82,82,79,82,32,97,116,32,77,66,32,37,100,32,37,100,10,0,0,0,0,0,0,97,54,52,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,54,48,78,0,0,114,97,119,100,101,99,0,0,105,115,73,0,0,0,0,0,85,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,37,88,0,0,0,0,0,0,77,111,110,107,101,121,39,115,32,65,117,100,105,111,0,0,112,97,99,107,101,116,32,116,121,112,101,32,49,53,0,0,66,105,116,114,97,116,101,32,98,121,116,101,32,109,105,115,115,105,110,103,44,32,103,117,101,115,115,105,110,103,32,98,105,116,114,97,116,101,32,102,114,111,109,32,112,97,99,107,101,116,32,115,105,122,101,46,10,0,0,0,0,0,0,0,65,83,67,73,73,47,65,78,83,73,32,97,114,116,0,0,112,114,111,120,121,0,0,0,100,101,102,97,117,108,116,0,97,112,99,115,0,0,0,0,102,114,97,109,101,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,10,0,0,0,101,114,114,111,114,44,32,119,114,111,110,103,32,115,108,105,99,101,32,99,111,117,110,116,10,0,0,0,0,0,0,0,112,103,109,121,117,118,32,110,101,101,100,115,32,101,118,101,110,32,119,105,100,116,104,32,97,110,100,32,104,101,105,103,104,116,10,0,0,0,0,0,68,101,108,117,120,101,32,80,97,105,110,116,32,65,110,105,109,97,116,105,111,110,0,0,83,101,116,32,105,109,97,103,101,32,114,101,115,111,108,117,116,105,111,110,32,40,105,110,32,100,111,116,115,32,112,101,114,32,109,101,116,101,114,41,0,0,0,0,0,0,0,0,73,68,65,84,32,119,105,116,104,111,117,116,32,73,72,68,82,10,0,0,0,0,0,0,79,110,108,121,32,115,104,111,119,32,102,111,114,99,101,100,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,65,77,82,45,87,66,32,40,65,100,97,112,116,105,118,101,32,77,117,108,116,105,45,82,97,116,101,32,87,105,100,101,66,97,110,100,41,0,0,0,108,97,118,102,105,46,98,98,111,120,46,119,0,0,0,0,65,77,82,45,78,66,32,40,65,100,97,112,116,105,118,101,32,77,117,108,116,105,45,82,97,116,101,32,78,97,114,114,111,119,66,97,110,100,41,0,112,99,109,95,102,54,52,98,101,0,0,0,0,0,0,0,77,80,69,71,45,52,32,65,117,100,105,111,32,76,111,115,115,108,101,115,115,32,67,111,100,105,110,103,32,40,65,76,83,41,0,0,0,0,0,0,115,101,116,32,109,97,120,32,118,97,108,117,101,32,102,111,114,32,110,111,109,105,110,97,116,111,114,32,111,114,32,100,101,110,111,109,105,110,97,116,111,114,32,105,110,32,116,104,101,32,114,97,116,105,111,0,83,117,112,112,111,114,116,32,102,111,114,32,116,104,105,115,32,65,68,88,32,102,111,114,109,97,116,0,0,0,0,0,52,120,109,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,57,78,0,0,102,97,108,115,101,0,0,0,97,114,116,105,115,116,0,0,102,108,97,103,115,0,0,0,77,88,77,0,0,0,0,0,77,97,120,105,109,117,109,32,100,117,114,97,116,105,111,110,32,111,102,32,116,104,101,32,111,117,116,112,117,116,0,0,73,109,97,103,101,32,100,105,109,101,110,115,105,111,110,115,32,115,104,111,117,108,100,32,98,101,32,97,32,109,117,108,116,105,112,108,101,32,111,102,32,49,54,46,10,0,0,0,102,102,95,77,80,86,95,102,114,97,109,101,95,115,116,97,114,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,66,105,116,114,97,116,101,32,37,100,32,98,112,115,10,0,115,105,110,103,108,101,32,99,111,101,102,102,105,99,105,101,110,116,32,101,108,105,109,105,110,97,116,105,111,110,32,116,104,114,101,115,104,111,108,100,32,102,111,114,32,108,117,109,105,110,97,110,99,101,32,40,110,101,103,97,116,105,118,101,32,118,97,108,117,101,115,32,97,108,115,111,32,99,111,110,115,105,100,101,114,32,100,99,32,99,111,101,102,102,105,99,105,101,110,116,41,0,0,0,114,116,112,102,108,97,103,115,0,0,0,0,0,0,0,0,49,50,56,107,0,0,0,0,100,101,109,117,120,101,114,32,45,62,32,105,115,116,95,105,110,100,101,120,58,37,100,32,116,121,112,101,58,37,115,32,110,101,120,116,95,100,116,115,58,37,115,32,110,101,120,116,95,100,116,115,95,116,105,109,101,58,37,115,32,110,101,120,116,95,112,116,115,58,37,115,32,110,101,120,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,32,111,102,102,58,37,115,32,111,102,102,95,116,105,109,101,58,37,115,10,0,0,0,0,0,49,50,56,107,0,0,0,0,115,101,101,107,95,112,111,105,110,116,0,0,0,0,0,0,97,98,117,102,102,101,114,115,105,110,107,0,0,0,0,0,97,117,116,104,111,114,0,0,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,99,111,109,112,114,101,115,115,101,100,32,116,97,103,10,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,56,78,0,0,109,112,51,111,110,52,102,108,111,97,116,0,0,0,0,0,109,112,51,111,110,52,0,0,109,112,118,95,102,108,97,103,115,0,0,0,0,0,0,0,97,114,116,105,115,116,0,0,105,110,116,114,97,95,118,108,99,0,0,0,0,0,0,0,114,101,102,45,62,98,117,102,45,62,114,101,102,99,111,117,110,116,32,62,32,48,0,0,82,101,115,101,114,118,101,100,0,0,0,0,0,0,0,0,32,78,66,95,83,65,77,80,76,69,83,58,37,108,108,100,32,78,66,95,67,79,78,83,85,77,69,68,95,83,65,77,80,76,69,83,58,37,108,108,100,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,32,83,67,70,73,32,86,76,67,10,0,0,0,83,117,98,115,116,114,101,97,109,32,37,100,32,112,97,114,105,116,121,32,99,104,101,99,107,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,76,97,118,99,53,53,46,53,50,46,49,48,50,0,0,0,74,80,69,71,45,76,83,32,116,104,97,116,32,105,115,32,110,111,116,32,60,61,32,56,32,98,105,116,115,47,99,111,109,112,111,110,101,110,116,32,111,114,32,49,54,45,98,105,116,32,103,114,97,121,0,0,115,111,102,32,111,102,102,115,58,32,48,120,37,120,10,0,101,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,118,108,99,32,116,97,98,108,101,10,0,0,0,61,44,59,91,10,0,0,0,123,92,37,99,49,125,0,0,112,101,114,102,111,114,109,101,114,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,55,78,0,0,78,111,32,109,105,109,101,116,121,112,101,32,105,115,32,107,110,111,119,110,32,102,111,114,32,115,116,114,101,97,109,32,37,100,44,32,99,97,110,110,111,116,32,119,114,105,116,101,32,97,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,46,10,0,0,102,97,115,116,102,105,114,115,116,112,97,115,115,0,0,0,83,116,97,116,32,98,117,102,102,101,114,32,97,108,108,111,99,32,40,37,122,117,32,98,121,116,101,115,41,32,102,97,105,108,101,100,10,0,0,0,66,85,71,33,32,85,110,107,110,111,119,110,32,105,109,97,103,101,116,121,112,101,32,105,110,32,105,109,97,103,101,32,100,101,99,111,100,101,114,46,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,114,111,98,97,98,105,108,105,116,121,32,114,117,110,32,101,110,99,111,117,110,116,101,114,101,100,46,10,0,0,0,75,77,86,67,32,112,97,108,101,116,116,101,32,116,111,111,32,108,97,114,103,101,10,0,80,114,111,103,114,101,115,115,105,111,110,32,111,114,100,101,114,32,82,80,67,76,0,0,123,92,97,110,52,125,0,0,97,102,116,101,114,32,105,110,105,116,10,0,0,0,0,0,116,98,58,37,100,47,37,100,32,45,62,32,116,98,58,37,100,47,37,100,10,0,0,0,84,105,108,101,32,100,97,116,97,32,115,105,122,101,32,105,115,32,122,101,114,111,33,10,0,0,0,0,0,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,55,10,0,73,110,118,97,108,105,100,32,116,105,108,101,32,115,105,122,101,58,32,37,100,10,0,0,119,114,111,110,103,32,116,114,97,110,115,102,111,114,109,32,115,105,122,101,33,10,0,0,65,116,116,101,109,112,116,32,116,111,32,97,112,112,108,121,32,77,111,100,101,32,51,47,52,32,116,111,32,97,110,32,73,78,84,69,82,32,99,101,108,108,33,10,0,0,0,0,73,110,118,101,114,115,101,32,113,117,97,110,116,105,122,97,116,105,111,110,32,111,102,32,99,111,101,102,102,105,99,105,101,110,116,115,32,102,97,105,108,101,100,10,0,0,0,0,73,110,118,97,108,105,100,32,112,97,108,101,116,116,101,32,115,105,122,101,32,114,101,99,101,105,118,101,100,58,32,37,117,32,45,62,32,112,97,108,101,116,116,101,32,100,97,116,97,32,111,102,102,115,101,116,58,32,37,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,117,102,102,121,117,118,101,110,99,46,99,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,54,78,0,0,115,45,62,98,103,114,51,50,0,0,0,0,0,0,0,0,97,118,95,109,97,108,108,111,99,122,40,41,32,102,97,105,108,101,100,10,0,0,0,0,115,112,115,95,109,97,120,95,115,117,98,95,108,97,121,101,114,115,32,111,117,116,32,111,102,32,114,97,110,103,101,58,32,37,100,10,0,0,0,0,80,114,111,99,101,115,115,105,110,103,32,99,111,109,109,97,110,100,32,35,37,100,32,116,97,114,103,101,116,58,37,115,32,99,111,109,109,97,110,100,58,37,115,32,97,114,103,58,37,115,10,0,0,0,0,0,78,111,32,115,116,97,114,116,32,99,111,100,101,32,105,115,32,102,111,117,110,100,46,10,0,0,0,0,0,0,0,0,98,111,116,116,111,109,95,116,111,112,0,0,0,0,0,0,110,111,32,109,109,99,111,32,104,101,114,101,10,0,0,0,100,105,115,99,97,114,100,105,110,103,32,115,112,115,32,99,114,111,112,112,105,110,103,44,32,111,114,105,103,105,110,97,108,32,118,97,108,117,101,115,32,97,114,101,32,108,58,37,117,32,114,58,37,117,32,116,58,37,117,32,98,58,37,117,10,0,0,0,0,0,0,0,99,111,114,114,117,112,116,101,100,32,109,97,99,114,111,98,108,111,99,107,32,37,100,32,37,100,32,40,116,111,116,97,108,95,99,111,101,102,102,61,37,100,41,10,0,0,0,0,67,108,97,115,115,105,99,32,82,111,99,107,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,104,50,54,52,46,99,0,0,0,0,0,0,0,83,108,105,99,101,32,109,105,115,109,97,116,99,104,32,97,116,32,77,66,58,32,37,100,10,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,100,99,32,37,100,32,97,116,32,37,100,32,37,100,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,102,108,97,103,115,0,0,0,112,114,101,118,95,112,116,115,0,0,0,0,0,0,0,0,79,110,108,121,32,109,111,110,111,32,105,115,32,115,117,112,112,111,114,116,101,100,10,0,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,109,105,109,101,116,121,112,101,32,102,114,111,109,32,97,110,32,97,116,116,97,99,104,101,100,32,112,105,99,116,117,114,101,46,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,111,114,32,117,110,115,117,112,112,111,114,116,101,100,32,98,105,116,109,97,115,107,115,58,32,82,61,37,88,44,32,71,61,37,88,44,32,66,61,37,88,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,53,78,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,99,104,117], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2607264);
/* memory initializer */ allocate([110,107,32,116,121,112,101,58,32,37,100,10,0,0,0,0,73,110,112,117,116,32,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,115,109,97,108,108,44,32,105,110,112,117,116,32,109,117,115,116,32,98,101,32,97,116,32,108,101,97,115,116,32,49,54,120,49,54,32,33,10,0,0,0,0,0,102,104,32,61,32,37,100,44,32,102,118,32,37,100,32,32,118,115,32,32,99,104,32,61,32,37,100,44,32,99,118,32,61,32,37,100,10,0,0,0,99,111,117,108,100,32,110,111,116,32,99,111,109,112,117,116,101,32,115,97,109,112,108,101,32,115,105,122,101,10,0,0,105,110,118,97,108,105,100,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,115,58,32,109,105,110,61,37,100,32,109,97,120,61,37,100,10,0,0,0,0,0,0,0,115,101,116,32,97,108,108,32,111,117,116,112,117,116,32,102,114,97,109,101,115,32,119,114,105,116,97,98,108,101,0,0,98,112,115,32,110,111,116,32,102,111,117,110,100,32,105,110,32,83,84,82,69,65,77,73,78,70,79,32,111,114,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,0,99,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,70,76,65,67,72,101,97,100,101,114,77,97,114,107,101,114,10,0,0,0,0,0,105,110,118,97,108,105,100,32,109,97,120,32,98,108,111,99,107,115,105,122,101,58,32,37,100,10,0,0,0,0,0,0,67,111,100,105,110,103,32,115,108,105,99,101,32,97,115,32,80,67,77,10,0,0,0,0,102,45,62,118,101,114,115,105,111,110,32,62,32,50,0,0,88,0,0,0,0,0,0,0,113,117,101,117,101,45,62,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,0,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,110,111,116,105,110,100,105,99,97,116,101,100,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,115,105,122,101,58,32,37,100,120,37,100,10,0,0,0,0,112,97,108,101,116,116,101,0,73,110,118,97,108,105,100,32,68,86,66,32,115,117,98,116,105,116,108,101,115,32,115,116,114,101,97,109,32,101,120,116,114,97,100,97,116,97,33,10,0,0,0,0,0,0,0,0,68,101,112,116,104,32,37,100,0,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,113,109,97,120,32,109,117,115,116,32,98,101,32,97,116,32,108,101,97,115,116,32,50,10,0,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,68,68,83,49,0,0,0,0,66,105,116,32,114,97,116,101,32,37,105,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,0,0,0,0,0,0,82,69,86,78,79,32,61,32,37,100,10,0,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,52,78,0,0,105,110,95,115,97,109,112,108,101,95,102,109,116,0,0,0,65,117,100,105,111,32,73,70,70,0,0,0,0,0,0,0,110,118,50,48,108,101,0,0,65,117,100,105,111,32,73,70,70,0,0,0,0,0,0,0,79,108,100,76,97,99,101,0,65,70,67,0,0,0,0,0,77,68,32,83,84,85,68,73,79,32,97,117,100,105,111,0,67,82,73,32,65,68,88,0,115,101,116,32,115,119,114,32,114,101,115,97,109,112,108,105,110,103,32,112,104,97,115,101,32,115,104,105,102,116,0,0,82,101,97,108,86,105,100,101,111,32,49,46,48,0,0,0,37,100,44,37,100,44,98,61,37,102,37,110,0,0,0,0,65,118,111,105,100,32,119,97,115,116,105,110,103,32,98,121,116,101,115,44,32,105,103,110,111,114,101,32,118,105,110,116,97,103,101,32,77,97,99,79,83,32,100,101,99,111,100,101,114,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,112,111,115,105,116,105,111,110,32,111,117,116,32,111,102,32,98,108,111,99,107,32,98,111,117,110,100,115,32,97,116,32,112,105,99,32,37,100,32,77,66,40,37,100,44,37,100,41,10,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,65,68,84,83,32,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,0,0,0,0,108,101,110,62,48,0,0,0,85,110,107,110,111,119,110,32,112,97,108,101,116,116,101,32,102,111,114,32,37,100,45,99,111,108,111,117,114,32,66,77,80,10,0,0,0,0,0,0,115,108,105,99,101,45,109,105,110,45,109,98,115,32,62,32,114,111,119,32,109,98,32,115,105,122,101,32,40,37,100,41,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,0,0,0,0,65,68,80,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,99,111,100,101,115,10,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,112,97,116,116,101,114,110,32,118,97,108,117,101,115,10,0,0,0,0,0,0,0,0,65,67,84,32,86,111,105,99,101,32,102,105,108,101,32,102,111,114,109,97,116,0,0,0,114,97,119,32,65,67,45,51,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,51,78,0,0,71,67,83,95,73,110,100,105,97,110,95,49,57,53,52,0,85,110,107,110,111,119,110,32,102,114,97,109,101,47,99,104,97,110,110,101,108,47,102,114,97,109,101,95,102,97,99,116,111,114,32,99,111,110,102,105,103,117,114,97,116,105,111,110,32,37,100,47,37,100,47,37,100,10,0,0,0,0,0,0,114,97,119,32,65,68,84,83,32,65,65,67,32,40,65,100,118,97,110,99,101,100,32,65,117,100,105,111,32,67,111,100,105,110,103,41,0,0,0,0,97,54,52,32,45,32,118,105,100,101,111,32,102,111,114,32,67,111,109,109,111,100,111,114,101,32,54,52,0,0,0,0,112,117,114,101,32,115,105,108,101,110,99,101,32,115,116,101,114,101,111,10,0,0,0,0,37,102,58,37,102,0,0,0,115,101,116,32,116,104,101,32,115,117,112,112,111,114,116,101,100,32,115,97,109,112,108,101,32,102,111,114,109,97,116,115,0,0,0,0,0,0,0,0,99,111,100,101,99,32,105,100,115,32,109,105,115,109,97,116,99,104,10,0,0,0,0,0,80,114,101,100,105,99,116,111,114,32,111,114,100,101,114,32,116,111,111,32,108,97,114,103,101,46,10,0,0,0,0,0,52,88,32,84,101,99,104,110,111,108,111,103,105,101,115,0,105,116,101,114,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,73,0,0,0,0,0,0,0,88,45,82,101,112,108,97,99,101,115,0,0,0,0,0,0,114,111,119,95,105,110,116,101,114,108,101,97,118,101,100,95,108,114,0,0,0,0,0,0,49,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,79,108,100,105,101,115,0,0,85,110,115,117,112,112,111,114,116,101,100,32,98,105,116,32,100,101,112,116,104,32,37,100,10,0,0,0,0,0,0,0,101,110,99,111,100,101,100,95,98,121,0,0,0,0,0,0,98,108,111,99,107,32,97,108,105,103,110,32,110,111,116,32,115,101,116,10,0,0,0,0,81,117,105,99,107,84,105,109,101,32,65,110,105,109,97,116,105,111,110,32,40,82,76,69,41,32,118,105,100,101,111,0,119,114,105,116,101,95,97,112,101,116,97,103,0,0,0,0,83,108,111,119,32,74,97,109,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,105,110,112,117,116,32,116,115,32,111,102,102,115,101,116,0,52,50,48,112,49,52,0,0,85,110,107,110,111,119,110,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,44,32,116,114,121,32,115,112,101,99,105,102,121,105,110,103,32,97,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,117,115,105,110,103,32,39,97,102,111,114,109,97,116,61,99,104,97,110,110,101,108,95,108,97,121,111,117,116,115,61,115,111,109,101,116,104,105,110,103,39,46,10,0,0,0,0,0,0,88,87,77,65,0,0,0,0,44,32,37,49,46,48,102,107,32,37,115,0,0,0,0,0,83,97,109,112,108,105,110,103,32,114,97,116,101,32,100,105,102,102,101,114,44,32,116,104,105,115,32,98,108,111,99,107,58,32,37,105,44,32,104,101,97,100,101,114,32,98,108,111,99,107,58,32,37,105,10,0,119,99,116,120,45,62,110,98,95,105,110,100,101,120,32,60,32,49,48,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,50,78,0,0,117,110,107,110,111,119,110,32,115,117,98,116,121,112,101,58,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,37,48,50,120,10,0,0,0,0,0,0,0,87,101,98,86,84,84,32,100,101,109,117,120,101,114,0,0,89,85,86,52,77,80,69,71,32,112,105,112,101,0,0,0,87,65,86,69,32,102,105,108,101,115,32,104,97,118,101,32,101,120,97,99,116,108,121,32,111,110,101,32,115,116,114,101,97,109,10,0,0,0,0,0,80,115,121,103,110,111,115,105,115,32,89,79,80,0,0,0,111,114,105,103,105,110,97,116,105,111,110,95,100,97,116,101,0,0,0,0,0,0,0,0,40,99,41,32,0,0,0,0,77,105,99,114,111,115,111,102,116,32,120,87,77,65,0,0,87,105,100,116,104,0,0,0,77,105,99,114,111,115,111,102,116,32,88,77,86,0,0,0,77,97,120,105,115,32,88,65,0,0,0,0,0,0,0,0,114,97,119,32,87,97,118,80,97,99,107,0,0,0,0,0,73,110,112,117,116,32,99,111,110,116,101,120,116,32,104,97,115,32,110,111,116,32,98,101,101,110,32,112,114,111,112,101,114,108,121,32,97,108,108,111,99,97,116,101,100,32,98,121,32,97,118,102,111,114,109,97,116,95,97,108,108,111,99,95,99,111,110,116,101,120,116,40,41,32,97,110,100,32,105,115,32,110,111,116,32,78,85,76,76,32,101,105,116,104,101,114,10,0,0,0,0,0,0,0,44,32,117,110,107,110,111,119,110,0,0,0,0,0,0,0,50,53,0,0,0,0,0,0,87,97,118,80,97,99,107,0,10,0,0,0,0,0,0,0,34,100,117,114,97,116,105,111,110,34,0,0,0,0,0,0,83,87,70,32,109,117,120,101,114,32,111,110,108,121,32,115,117,112,112,111,114,116,115,32,49,32,97,117,100,105,111,32,115,116,114,101,97,109,10,0,33,108,105,110,107,45,62,102,114,97,109,101,95,114,101,113,117,101,115,116,101,100,0,0,83,87,70,32,99,111,109,112,114,101,115,115,101,100,32,102,105,108,101,32,100,101,116,101,99,116,101,100,10,0,0,0,91,83,85,66,84,73,84,76,69,93,0,0,0,0,0,0,85,110,114,101,99,111,103,110,105,122,101,100,32,108,97,114,103,101,32,68,84,83,32,102,114,97,109,101,0,0,0,0,87,105,110,100,111,119,115,32,84,101,108,101,118,105,115,105,111,110,32,40,87,84,86,41,0,0,0,0,0,0,0,0,62,10,0,0,0,0,0,0,97,108,108,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,49,78,0,0,102,117,108,108,0,0,0,0,87,105,110,100,111,119,115,32,84,101,108,101,118,105,115,105,111,110,32,40,87,84,86,41,0,0,0,0,0,0,0,0,87,101,115,116,119,111,111,100,32,83,116,117,100,105,111,115,32,86,81,65,0,0,0,0,87,101,115,116,119,111,111,100,32,83,116,117,100,105,111,115,32,97,117,100,105,111,0,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,0,87,101,98,86,84,84,32,115,117,98,116,105,116,108,101,0,121,117,118,52,109,112,101,103,112,105,112,101,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,48,78,0,0,87,105,110,103,32,67,111,109,109,97,110,100,101,114,32,73,73,73,32,109,111,118,105,101,0,0,0,0,0,0,0,0,87,65,86,32,47,32,87,65,86,69,32,40,87,97,118,101,102,111,114,109,32,65,117,100,105,111,41,0,0,0,0,0,121,111,112,0,0,0,0,0,87,65,86,32,47,32,87,65,86,69,32,40,87,97,118,101,102,111,114,109,32,65,117,100,105,111,41,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,57,78,0,0,112,101,114,102,0,0,0,0,78,105,112,112,111,110,32,84,101,108,101,103,114,97,112,104,32,97,110,100,32,84,101,108,101,112,104,111,110,101,32,67,111,114,112,111,114,97,116,105,111,110,32,40,78,84,84,41,32,84,119,105,110,86,81,0,86,80,108,97,121,101,114,32,115,117,98,116,105,116,108,101,115,0,0,0,0,0,0,0,97,108,98,117,109,95,97,114,116,105,115,116,0,0,0,0,67,114,101,97,116,105,118,101,32,86,111,105,99,101,0,0,117,110,107,110,111,119,110,32,99,111,100,101,99,32,116,97,103,10,0,0,0,0,0,0,101,110,99,111,100,101,114,32,45,62,32,116,121,112,101,58,118,105,100,101,111,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,10,0,0,0,0,120,119,109,97,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,32,37,108,100,32,98,121,116,101,115,10,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,56,78,0,0,86,105,118,111,0,0,0,0,86,67,45,49,32,116,101,115,116,32,98,105,116,115,116,114,101,97,109,0,0,0,0,0,86,67,45,49,32,116,101,115,116,32,98,105,116,115,116,114,101,97,109,0,0,0,0,0,120,109,118,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,55,78,0,0,120,97,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,54,78,0,0,119,118,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,53,78,0,0,117,110,99,111,100,101,100,32,102,114,97,109,101,99,114,99,32,116,101,115,116,105,110,103,0,0,0,0,0,0,0,0,82,101,110,100,101,114,119,97,114,101,32,84,101,88,116,117,114,101,32,68,105,99,116,105,111,110,97,114,121,0,0,0,84,101,108,101,45,116,121,112,101,119,114,105,116,101,114,0,119,118,0,0,0,0,0,0,84,84,65,32,40,84,114,117,101,32,65,117,100,105,111,41,0,0,0,0,0,0,0,0,56,48,56,56,102,108,101,120,32,84,77,86,0,0,0,0,84,105,101,114,116,101,120,32,76,105,109,105,116,101,100,32,83,69,81,0,0,0,0,0,84,72,80,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,52,78,0,0,77,117,108,116,105,112,108,101,32,109,117,120,101,114,32,116,101,101,0,0,0,0,0,0,84,69,68,32,84,97,108,107,115,32,99,97,112,116,105,111,110,115,0,0,0,0,0,0,110,118,49,54,0,0,0,0,78,97,118,121,0,0,0,0,114,97,119,32,84,65,75,0,112,104,97,115,101,95,115,104,105,102,116,0,0,0,0,0,37,100,44,37,100,44,113,61,37,100,37,110,0,0,0,0,83,87,70,32,40,83,104,111,99,107,87,97,118,101,32,70,108,97,115,104,41,0,0,0,105,110,116,101,114,108,97,99,101,32,43,32,115,108,105,99,101,45,109,105,110,45,109,98,115,32,105,115,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,10,0,0,0,83,87,70,32,40,83,104,111,99,107,87,97,118,101,32,70,108,97,115,104,41,0,0,0,100,101,102,97,117,108,116,95,103,101,116,95,98,117,102,102,101,114,32,99,97,108,108,101,100,32,111,110,32,112,105,99,32,37,112,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,51,78,0,0,71,67,83,95,73,68,55,52,0,0,0,0,0,0,0,0,83,117,98,86,105,101,119,101,114,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,0,0,0,112,115,121,45,114,100,0,0,83,117,98,86,105,101,119,101,114,32,118,49,32,115,117,98,116,105,116,108,101,32,102,111,114,109,97,116,0,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,105,116,101,114,0,0,0,0,113,112,58,37,100,32,102,99,58,37,100,44,37,100,32,37,115,32,115,105,122,101,58,37,100,32,112,114,111,58,37,100,32,97,108,116,58,37,100,32,116,111,112,58,37,100,32,37,115,112,101,108,32,112,97,114,116,58,37,100,32,114,101,115,121,110,99,58,37,100,32,119,58,37,100,32,97,58,37,100,32,114,110,100,58,37,100,32,118,111,116,58,37,100,37,115,32,100,99,58,37,100,32,99,101,58,37,100,47,37,100,47,37,100,32,116,105,109,101,58,37,108,108,100,32,116,105,110,99,114,58,37,100,10,0,0,37,50,53,53,91,94,58,61,93,61,37,50,53,53,91,94,58,93,0,0,0,0,0,0,77,97,120,105,109,117,109,32,73,45,102,114,97,109,101,32,98,105,116,114,97,116,101,32,40,112,99,116,41,32,48,61,117,110,108,105,109,105,116,101,100,0,0,0,0,0,0,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,83,117,98,82,105,112,32,115,117,98,116,105,116,108,101,0,68,101,116,101,99,116,101,100,32,117,110,115,117,112,112,111,114,116,101,100,32,89,67,103,67,111,32,99,111,108,111,114,115,112,97,99,101,46,10,0,113,116,114,108,101,0,0,0,73,69,67,32,54,49,57,51,55,32,40,117,115,101,100,32,111,110,32,83,47,80,68,73,70,32,45,32,73,69,67,57,53,56,41,0,0,0,0,0,83,97,116,105,114,101,0,0,67,111,100,101,99,32,99,104,97,110,103,101,32,105,110,32,73,69,67,32,54,49,57,51,55,0,0,0,0,0,0,0,105,116,115,111,102,102,115,101,116,0,0,0,0,0,0,0,83,111,88,32,110,97,116,105,118,101,0,0,0,0,0,0,44,32,37,49,46,48,102,32,37,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,50,78,0,0,83,111,88,32,110,97,116,105,118,101,0,0,0,0,0,0,83,105,101,114,114,97,32,83,79,76,0,0,0,0,0,0,76,117,99,97,115,65,114,116,115,32,83,109,117,115,104,0,119,116,118,0,0,0,0,0,83,109,111,111,116,104,32,83,116,114,101,97,109,105,110,103,32,77,117,120,101,114,0,0,76,111,107,105,32,83,68,76,32,77,74,80,69,71,0,0,76,111,107,105,32,83,68,76,32,77,74,80,69,71,0,0,83,109,97,99,107,101,114,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,49,78,0,0,32,32,37,115,10,0,0,0,48,0,0,0,0,0,0,0,108,105,110,101,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,48,78,0,0,115,101,116,32,116,104,101,32,115,101,103,109,101,110,116,32,108,105,115,116,32,102,105,108,101,110,97,109,101,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,57,78,0,0,78,111,32,78,97,109,101,0,83,99,114,105,112,116,115,32,119,105,116,104,32,109,105,120,101,100,32,97,98,115,111,108,117,116,101,32,97,110,100,32,114,101,108,97,116,105,118,101,32,116,105,109,101,115,116,97,109,112,115,32,99,97,110,32,103,105,118,101,32,117,110,101,120,112,101,99,116,101,100,32,114,101,115,117,108,116,115,32,40,112,97,117,115,101,44,32,115,101,101,107,105,110,103,44,32,116,105,109,101,32,122,111,110,101,32,99,104,97,110,103,101,41,46,10,0,0,0,0,86,105,100,101,111,32,101,110,99,111,100,105,110,103,32,102,97,105,108,101,100,10,0,0,67,111,109,112,114,101,115,115,115,101,100,32,102,114,97,109,101,32,37,115,32,116,108,101,110,61,37,100,32,100,108,101,110,61,37,108,100,10,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,56,78,0,0,82,84,80,32,109,97,120,32,112,97,121,108,111,97,100,32,115,105,122,101,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,65,77,82,10,0,119,116,118,0,0,0,0,0,84,104,101,32,86,105,100,101,111,32,83,116,114,101,97,109,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,55,78,0,0,119,115,118,113,97,0,0,0,73,76,78,71,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,54,78,0,0,37,117,58,37,117,58,37,117,0,0,0,0,0,0,0,0,119,115,97,117,100,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,99,111,109,98,105,110,101,100,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,53,78,0,0,100,105,114,97,99,0,0,0,119,101,98,118,116,116,0,0,109,108,112,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,52,78,0,0,101,114,114,111,114,32,114,101,97,100,105,110,103,32,39,114,100,118,111,39,32,97,116,111,109,10,0,0,0,0,0,0,120,121,122,49,50,98,101,0,78,97,118,97,106,111,87,104,105,116,101,0,0,0,0,0,115,101,116,32,115,119,114,32,114,101,115,97,109,112,108,105,110,103,32,102,105,108,116,101,114,32,115,105,122,101,0,0,105,110,118,97,108,105,100,32,122,111,110,101,58,32,98,105,116,114,97,116,101,95,102,97,99,116,111,114,61,37,102,10,0,0,0,0,0,0,0,0,86,66,86,32,109,97,120,114,97,116,101,32,115,112,101,99,105,102,105,101,100,44,32,98,117,116,32,110,111,32,98,117,102,115,105,122,101,44,32,105,103,110,111,114,101,100,10,0,112,105,99,45,62,100,97,116,97,91,48,93,33,61,78,85,76,76,32,105,110,32,97,118,99,111,100,101,99,95,100,101,102,97,117,108,116,95,103,101,116,95,98,117,102,102,101,114,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,51,78,0,0,71,67,83,95,72,68,55,50,0,0,0,0,0,0,0,0,115,117,98,113,0,0,0,0,73,110,118,97,108,105,100,32,115,97,109,112,108,101,95,115,105,122,101,10,0,0,0,0,117,109,104,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,87,97,114,110,105,110,103,58,32,65,86,70,114,97,109,101,46,112,116,115,61,63,32,116,114,121,105,110,103,32,116,111,32,103,117,101,115,115,32,40,37,108,108,100,41,10,0,0,115,51,50,108,101,0,0,0,69,114,114,111,114,44,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,111,114,32,110,111,116,32,77,80,69,71,52,32,104,101,97,100,101,114,32,40,98,95,99,111,100,101,61,48,41,10,0,0,0,65,86,73,68,58,32,108,101,110,58,37,100,32,37,100,10,0,0,0,0,0,0,0,0,80,111,115,115,105,98,108,101,32,112,114,111,102,105,108,101,115,58,0,0,0,0,0,0,109,97,120,45,105,110,116,114,97,45,114,97,116,101,0,0,68,101,116,101,99,116,101,100,32,71,66,82,32,99,111,108,111,114,115,112,97,99,101,46,10,0,0,0,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,90,76,73,66,0,0,0,0,0,0,0,80,111,114,110,32,71,114,111,111,118,101,0,0,0,0,0,69,79,70,32,111,110,32,37,115,44,32,37,100,32,115,116,114,101,97,109,115,32,108,101,102,116,32,105,110,32,115,101,103,109,101,110,116,46,10,0,101,110,97,98,108,101,47,100,105,115,97,98,108,101,32,97,99,99,117,114,97,116,101,32,115,101,101,107,105,110,103,32,119,105,116,104,32,45,115,115,0,0,0,0,0,0,0,0,44,32,37,51,46,50,102,32,37,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,50,78,0,0,119,101,98,118,116,116,0,0,115,51,50,108,101,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,49,78,0,0,70,105,108,116,101,114,32,37,115,10,0,0,0,0,0,0,119,99,51,109,111,118,105,101,0,0,0,0,0,0,0,0,114,101,100,117,99,101,32,116,104,101,32,108,97,116,101,110,99,121,32,98,121,32,102,108,117,115,104,105,110,103,32,111,117,116,32,112,97,99,107,101,116,115,32,105,109,109,101,100,105,97,116,101,108,121,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,48,78,0,0,71,69,79,66,0,0,0,0,78,65,77,69,0,0,0,0,50,53,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,57,78,0,0,79,112,117,115,32,109,117,120,101,114,0,0,0,0,0,0,109,117,108,116,105,112,108,101,32,102,111,117,114,99,99,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,78,101,119,32,115,116,114,101,97,109,115,32,97,114,101,32,110,111,116,32,115,117,112,112,111,115,101,100,32,116,111,32,98,101,32,97,100,100,101,100,32,105,110,32,98,101,116,119,101,101,110,32,79,103,103,32,99,111,110,116,101,120,116,32,115,97,118,101,47,114,101,115,116,111,114,101,32,111,112,101,114,97,116,105,111,110,115,46,10,0,0,0,0,0,0,0,114,95,102,114,97,109,101,95,114,97,116,101,0,0,0,0,101,110,99,111,100,101,95,118,105,100,101,111,32,37,100,46,37,100,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,37,115,32,73,68,51,118,50,32,102,114,97,109,101,32,37,115,46,10,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,56,78,0,0,114,101,97,100,95,116,105,109,101,115,116,97,109,112,32,102,97,105,108,101,100,46,10,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,55,78,0,0,99,104,97,110,110,101,108,95,99,111,117,110,116,0,0,0,119,97,118,0,0,0,0,0,48,46,48,46,48,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,54,78,0,0,114,0,0,0,0,0,0,0,101,114,114,111,114,32,103,101,116,116,105,110,103,32,115,116,114,101,97,109,32,105,110,100,101,120,32,37,100,10,0,0,118,101,114,115,105,111,110,32,37,105,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,53,78,0,0,65,112,112,108,105,99,97,116,105,111,110,32,112,114,111,118,105,100,101,100,32,105,110,118,97,108,105,100,44,32,110,111,110,32,109,111,110,111,116,111,110,105,99,97,108,108,121,32,105,110,99,114,101,97,115,105,110,103,32,100,116,115,32,116,111,32,109,117,120,101,114,32,105,110,32,115,116,114,101,97,109,32,37,100,58,32,37,115,32,62,61,32,37,115,10,0,110,98,95,115,97,109,112,108,101,115,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,52,78,0,0,114,101,115,101,110,100,95,104,101,97,100,101,114,115,32,111,112,116,105,111,110,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,117,115,101,32,45,109,112,101,103,116,115,95,102,108,97,103,115,32,114,101,115,101,110,100,95,104,101,97,100,101,114,115,10,0,0,120,121,122,49,50,108,101,0,77,111,99,99,97,115,105,110,0,0,0,0,0,0,0,0,102,105,108,116,101,114,95,115,105,122,101,0,0,0,0,0,105,110,118,97,108,105,100,32,122,111,110,101,58,32,115,116,97,114,116,61,37,100,32,101,110,100,61,37,100,10,0,0,109,97,120,32,98,105,116,114,97,116,101,32,108,101,115,115,32,116,104,97,110,32,97,118,101,114,97,103,101,32,98,105,116,114,97,116,101,44,32,97,115,115,117,109,105,110,103,32,67,66,82,10,0,0,0,0,67,111,109,112,117,116,101,32,101,120,97,99,116,32,80,67,82,32,102,111,114,32,101,97,99,104,32,116,114,97,110,115,112,111,114,116,32,115,116,114,101,97,109,32,112,97,99,107,101,116,46,0,0,0,0,0,100,101,102,97,117,108,116,95,103,101,116,95,98,117,102,102,101,114,32,99,97,108,108,101,100,32,111,110,32,102,114,97,109,101,32,37,112,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,51,78,0,0,71,67,83,95,72,117,95,84,122,117,95,83,104,97,110,0,115,117,98,109,101,0,0,0,117,109,104,0,0,0,0,0,100,118,100,0,0,0,0,0,73,110,118,97,108,105,100,32,112,116,115,32,40,37,108,108,100,41,32,60,61,32,108,97,115,116,32,40,37,108,108,100,41,10,0,0,0,0,0,0,69,114,114,111,114,44,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,111,114,32,110,111,116,32,77,80,69,71,52,32,104,101,97,100,101,114,32,40,102,95,99,111,100,101,61,48,41,10,0,0,0,110,98,95,99,111,100,101,115,32,60,61,32,50,53,54,0,69,114,114,111,114,32,115,101,116,116,105,110,103,32,112,114,111,102,105,108,101,32,37,115,46,10,0,0,0,0,0,0,101,114,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,99,114,111,112,112,105,110,103,32,105,110,102,111,114,109,97,116,105,111,110,46,10,0,83,85,66,0,0,0,0,0,119,97,118,0,0,0,0,0,122,108,105,98,0,0,0,0,80,114,105,109,117,115,0,0,97,99,99,117,114,97,116,101,95,115,101,101,107,0,0,0,32,40,99,108,101,97,110,32,101,102,102,101,99,116,115,41,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,50,78,0,0,84,65,76,66,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,49,78,0,0,85,110,107,110,111,119,110,32,102,105,108,116,101,114,32,39,37,115,39,46,10,0,0,0,115,101,103,109,101,110,116,32,109,117,120,101,114,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,48,78,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,57,78,0,0,83,111,114,101,110,115,111,110,32,72,50,54,51,0,0,0,109,112,52,0,0,0,0,0,101,110,99,111,100,101,114,32,60,45,32,116,121,112,101,58,118,105,100,101,111,32,102,114,97,109,101,95,112,116,115,58,37,115,32,102,114,97,109,101,95,112,116,115,95,116,105,109,101,58,37,115,32,116,105,109,101,95,98,97,115,101,58,37,100,47,37,100,10,0,0,0,101,110,99,114,121,112,116,101,100,32,97,110,100,32,99,111,109,112,114,101,115,115,101,100,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,56,78,0,0,116,105,109,101,99,111,100,101,0,0,0,0,0,0,0,0,67,78,84,73,0,0,0,0,118,113,102,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,55,78,0,0,123,37,42,100,125,123,37,42,100,125,37,99,0,0,0,0,35,118,101,114,115,105,111,110,58,32,49,10,0,0,0,0,118,112,108,97,121,101,114,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,54,78,0,0,67,111,114,114,117,112,116,32,105,110,116,52,32,82,77,45,115,116,121,108,101,32,97,117,100,105,111,32,112,97,99,107,101,116,32,115,105,122,101,10,0,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,53,78,0,0,65,76,66,85,77,65,82,84,73,83,84,0,0,0,0,0,118,105,100,101,111,32,100,111,101,115,110,39,116,32,115,101,101,109,32,116,111,32,98,101,32,80,65,76,32,111,114,32,78,84,83,67,46,32,103,117,101,115,115,105,110,103,32,80,65,76,10,0,0,0,0,0,115,109,99,45,105,110,116,101,114,118,97,108,0,0,0,0,118,111,99,0,0,0,0,0,70,79,78,84,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,52,78,0,0,118,100,112,97,117,0,0,0,77,105,115,116,121,82,111,115,101,0,0,0,0,0,0,0,115,101,108,101,99,116,32,105,109,112,114,111,118,101,100,45,101,45,119,101,105,103,104,116,101,100,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,47,0,0,0,0,0,0,0,86,66,86,32,98,117,102,115,105,122,101,32,115,101,116,32,98,117,116,32,109,97,120,114,97,116,101,32,117,110,115,112,101,99,105,102,105,101,100,44,32,105,103,110,111,114,101,100,10,0,0,0,0,0,0,0,33,105,109,103,45,62,115,112,108,105,116,95,112,108,97,110,101,115,0,0,0,0,0,0,73,103,110,111,114,105,110,103,32,109,105,100,45,115,116,114,101,97,109,32,99,104,97,110,103,101,32,105,110,32,97,117,100,105,111,32,99,111,100,101,99,10,0,0,0,0,0,0,102,114,97,109,101,45,62,110,98,95,101,120,116,101,110,100,101,100,95,98,117,102,32,61,61,32,48,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,51,78,0,0,71,67,83,95,71,117,121,97,110,101,95,70,114,97,110,99,97,105,115,101,0,0,0,0,109,118,45,114,97,110,103,101,45,116,104,114,101,97,100,0,80,67,77,32,90,111,114,107,0,0,0,0,0,0,0,0,104,101,120,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,115,99,97,108,101,32,62,61,32,48,32,38,38,32,115,99,97,108,101,32,60,61,32,51,0,0,0,0,0,0,0,0,112,97,116,116,101,114,110,95,116,121,112,101,0,0,0,0,69,114,114,111,114,44,32,104,101,97,100,101,114,32,100,97,109,97,103,101,100,32,111,114,32,110,111,116,32,77,80,69,71,52,32,104,101,97,100,101,114,32,40,113,115,99,97,108,101,61,48,41,10,0,0,0,110,98,95,99,111,109,112,111,110,101,110,116,115,62,61,49,32,38,38,32,110,98,95,99,111,109,112,111,110,101,110,116,115,60,61,52,0,0,0,0,109,97,105,110,0,0,0,0,69,114,114,111,114,32,114,101,115,105,108,105,101,110,99,101,32,99,111,110,102,105,103,117,114,97,116,105,111,110,0,0,73,110,118,97,108,105,100,32,99,114,111,112,112,101,100,32,100,105,109,101,110,115,105,111,110,115,58,32,37,100,120,37,100,46,10,0,0,0,0,0,76,67,76,32,40,76,111,115,115,76,101,115,115,32,67,111,100,101,99,32,76,105,98,114,97,114,121,41,32,77,83,90,72,0,0,0,0,0,0,0,66,111,111,116,121,32,66,97,115,115,0,0,0,0,0,0,112,110,109,0,0,0,0,0,116,105,109,101,95,111,102,102,0,0,0,0,0,0,0,0,32,40,118,105,115,117,97,108,32,105,109,112,97,105,114,101,100,41,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,50,78,0,0,116,105,116,108,101,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,49,78,0,0,78,111,32,102,105,108,116,101,114,32,110,97,109,101,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,0,0,0,83,112,101,99,105,102,105,101,100,32,116,105,109,101,32,37,102,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,102,111,108,108,111,119,105,110,103,32,116,105,109,101,32,37,102,10,0,0,0,0,0,0,0,0,118,105,118,111,0,0,0,0,84,73,84,50,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,100,105,109,101,110,115,105,111,110,115,32,37,100,120,37,100,32,40,100,105,109,101,110,115,105,111,110,115,32,99,97,110,110,111,116,32,101,120,99,101,101,100,32,50,53,54,120,50,53,54,41,10,0,0,0,0,0,0,0,0,118,99,49,116,101,115,116,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,48,78,0,0,73,110,118,97,108,105,100,32,115,101,103,109,101,110,116,32,102,105,108,101,110,97,109,101,32,116,101,109,112,108,97,116,101,32,39,37,115,39,10,0,118,99,49,116,101,115,116,0,118,97,114,105,97,110,116,95,98,105,116,114,97,116,101,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,57,78,0,0,0,114,101,99,111,114,100,101,100,0,0,0,0,0,0,0,0,110,101,120,116,95,100,116,115,32,60,61,32,48,120,55,102,102,102,102,102,102,102,0,0,80,108,97,110,97,114,32,89,39,67,98,67,114,32,56,45,98,105,116,32,52,58,50,58,48,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,114,101,97,108,108,111,99,97,116,101,32,102,108,116,32,101,110,116,114,105,101,115,10,0,0,0,0,0,0,0,116,114,97,99,107,32,100,101,115,99,114,105,112,116,105,111,110,32,108,111,110,103,101,114,32,116,104,97,110,32,109,97,112,32,100,97,116,97,10,0,105,103,110,111,114,101,95,108,111,111,112,0,0,0,0,0,70,111,114,99,101,100,32,107,101,121,102,114,97,109,101,32,97,116,32,116,105,109,101,32,37,102,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,56,78,0,0,0,78,69,84,83,67,65,80,69,50,46,48,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,55,78,0,0,0,97,97,99,32,98,105,116,115,116,114,101,97,109,32,101,114,114,111,114,10,0,0,0,0,111,110,77,101,116,97,68,97,116,97,0,0,0,0,0,0,87,114,105,116,101,32,116,104,101,32,102,105,108,101,32,104,101,97,100,101,114,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,54,78,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,104,101,97,100,101,114,58,32,37,105,10,0,0,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,53,78,0,0,0,105,112,99,109,60,52,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,52,78,0,0,0,118,101,114,115,105,111,110,0,121,117,118,97,52,52,52,112,49,54,108,101,0,0,0,0,77,105,110,116,67,114,101,97,109,0,0,0,0,0,0,0,105,109,112,114,111,118,101,100,95,101,95,119,101,105,103,104,116,101,100,0,0,0,0,0,86,66,86,32,117,110,100,101,114,102,108,111,119,32,40,102,114,97,109,101,32,37,100,44,32,37,46,48,102,32,98,105,116,115,41,10,0,0,0,0,86,66,86,32,109,97,120,114,97,116,101,32,117,110,115,112,101,99,105,102,105,101,100,44,32,97,115,115,117,109,105,110,103,32,67,66,82,10,0,0,118,105,100,101,111,95,103,101,116,95,98,117,102,102,101,114,58,32,105,109,97,103,101,32,112,97,114,97,109,101,116,101,114,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,51,78,0,0,0,71,67,83,95,71,97,114,111,117,97,0,0,0,0,0,0,109,118,114,97,110,103,101,45,116,104,114,101,97,100,0,0,112,99,109,95,122,111,114,107,0,0,0,0,0,0,0,0,104,101,120,0,0,0,0,0,119,97,114,110,105,110,103,44,32,116,111,111,32,109,97,110,121,32,98,32,102,114,97,109,101,115,32,105,110,32,97,32,114,111,119,10,0,0,0,0,115,116,97,116,105,99,32,115,112,114,105,116,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,90,82,76,32,111,118,101,114,102,108,111,119,58,32,37,100,10,0,0,0,0,0,0,0,104,105,103,104,52,52,52,0,101,114,114,111,114,45,114,101,115,105,108,105,101,110,116,0,104,45,62,115,112,115,46,99,114,111,112,95,116,111,112,32,43,32,104,45,62,115,112,115,46,99,114,111,112,95,98,111,116,116,111,109,32,60,32,40,117,110,115,105,103,110,101,100,41,104,45,62,104,101,105,103,104,116,0,0,0,0,0,0,109,115,122,104,0,0,0,0,83,121,109,112,104,111,110,121,0,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,115,116,97,114,116,32,116,105,109,101,32,111,102,102,115,101,116,0,0,0,0,0,0,0,32,40,104,101,97,114,105,110,103,32,105,109,112,97,105,114,101,100,41,0,0,0,0,0,85,115,101,32,45,104,32,116,111,32,103,101,116,32,102,117,108,108,32,104,101,108,112,32,111,114,44,32,101,118,101,110,32,98,101,116,116,101,114,44,32,114,117,110,32,39,109,97,110,32,37,115,39,10,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,50,78,0,0,0,78,85,76,76,0,0,0,0,80,67,83,95,87,71,83,55,50,95,85,84,77,95,122,111,110,101,95,49,78,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,105,109,101,32,100,117,114,97,116,105,111,110,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,39,37,115,39,32,105,110,32,116,105,109,101,115,32,108,105,115,116,32,37,115,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,43,32,112,114,101,102,105,120,32], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2617504);
/* memory initializer */ allocate([99,111,109,98,105,110,97,116,105,111,110,44,32,97,115,115,117,109,105,110,103,32,97,117,100,105,111,46,10,0,0,0,105,100,32,62,61,32,50,51,32,38,38,32,105,100,32,60,32,50,51,32,43,32,52,0,80,67,83,95,78,65,68,56,51,95,80,117,101,114,116,111,95,82,105,99,111,95,86,105,114,103,105,110,95,73,115,0,73,110,118,97,108,105,100,32,108,111,111,112,115,116,97,114,116,32,118,97,108,117,101,10,0,0,0,0,0,0,0,0,114,97,116,105,110,103,0,0,80,67,83,95,78,65,68,56,51,95,87,121,111,109,105,110,103,95,87,101,115,116,0,0,108,105,98,97,118,102,111,114,109,97,116,47,109,111,118,101,110,99,46,99,0,0,0,0,105,110,118,97,108,105,100,32,112,97,99,107,101,116,95,108,101,110,103,116,104,32,37,100,32,97,116,58,37,108,108,100,10,0,0,0,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,99,111,118,101,114,32,97,114,116,46,10,0,0,0,0,0,0,0,42,42,42,32,37,100,32,100,117,112,33,10,0,0,0,0,101,110,99,114,121,112,116,101,100,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,121,111,109,105,110,103,95,87,95,67,101,110,0,80,67,83,95,78,65,68,56,51,95,87,121,111,109,105,110,103,95,69,95,67,101,110,0,80,67,83,95,78,65,68,56,51,95,87,121,111,109,105,110,103,95,69,97,115,116,0,0,108,101,118,101,108,32,60,61,32,102,115,45,62,115,121,110,99,95,108,101,118,101,108,0,80,67,83,95,78,65,68,56,51,95,87,105,115,99,111,110,115,105,110,95,83,111,117,116,104,0,0,0,0,0,0,0,69,114,114,111,114,32,119,104,101,110,32,101,118,97,108,117,97,116,105,110,103,32,116,104,101,32,118,111,108,117,109,101,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,115,105,108,101,110,99,101,95,115,116,97,114,116,58,32,37,115,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,105,115,99,111,110,115,105,110,95,67,101,110,0,67,97,110,32,110,111,116,32,109,105,120,32,110,97,109,101,100,32,97,110,100,32,110,117,109,98,101,114,101,100,32,99,104,97,110,110,101,108,115,10,0,0,0,0,0,0,0,0,121,117,118,97,52,52,52,112,49,54,98,101,0,0,0,0,77,105,100,110,105,103,104,116,66,108,117,101,0,0,0,0,73,110,118,97,108,105,100,32,111,117,116,112,117,116,32,99,104,97,110,110,101,108,58,32,37,115,46,10,0,0,0,0,115,101,108,101,99,116,32,109,111,100,105,102,105,101,100,45,101,45,119,101,105,103,104,116,101,100,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,86,66,86,32,117,110,100,101,114,102,108,111,119,32,100,117,101,32,116,111,32,67,82,70,45,109,97,120,32,40,102,114,97,109,101,32,37,100,44,32,37,46,48,102,32,98,105,116,115,41,10,0,0,0,0,0,86,66,86,32,105,115,32,105,110,99,111,109,112,97,116,105,98,108,101,32,119,105,116,104,32,99,111,110,115,116,97,110,116,32,81,80,44,32,105,103,110,111,114,101,100,46,10,0,80,105,99,116,117,114,101,32,99,104,97,110,103,101,100,32,102,114,111,109,32,115,105,122,101,58,37,100,120,37,100,32,102,109,116,58,37,115,32,116,111,32,115,105,122,101,58,37,100,120,37,100,32,102,109,116,58,37,115,32,105,110,32,114,101,103,101,116,32,98,117,102,102,101,114,40,41,10,0,0,45,55,48,47,45,55,48,124,45,54,48,47,45,50,48,0,80,67,83,95,78,65,68,56,51,95,87,105,115,99,111,110,115,105,110,95,78,111,114,116,104,0,0,0,0,0,0,0,71,67,83,95,71,97,110,100,97,106,105,107,97,95,49,57,55,48,0,0,0,0,0,0,109,118,45,114,97,110,103,101,0,0,0,0,0,0,0,0,88,49,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,105,110,112,117,116,32,99,104,97,110,110,101,108,32,110,117,109,98,101,114,115,32,105,110,32,111,117,116,112,117,116,32,111,114,100,101,114,46,0,0,0,0,0,0,0,0,105,108,108,101,103,97,108,32,98,32,102,114,97,109,101,32,115,116,114,97,116,101,103,121,10,0,0,0,0,0,0,0,115,112,114,105,116,101,95,98,114,105,103,104,116,110,101,115,115,95,99,104,97,110,103,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,83,83,47,83,69,32,37,100,47,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,104,105,103,104,52,50,50,0,114,101,97,108,116,105,109,101,0,0,0,0,0,0,0,0,104,45,62,115,112,115,46,99,114,111,112,95,114,105,103,104,116,32,43,32,104,45,62,115,112,115,46,99,114,111,112,95,108,101,102,116,32,60,32,40,117,110,115,105,103,110,101,100,41,104,45,62,119,105,100,116,104,0,0,0,0,0,0,0,83,105,101,114,114,97,32,86,77,68,32,118,105,100,101,111,0,0,0,0,0,0,0,0,83,111,110,97,116,97,0,0,115,115,0,0,0,0,0,0,32,40,102,111,114,99,101,100,41,0,0,0,0,0,0,0,108,111,119,112,97,115,115,0,80,67,83,95,78,65,68,56,51,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,83,0,0,0,0,0,0,0,115,116,97,114,116,95,104,101,114,101,32,60,61,32,115,116,111,112,95,104,101,114,101,32,38,38,32,102,114,97,103,45,62,112,111,115,105,116,105,111,110,91,49,93,32,60,61,32,115,116,97,114,116,95,104,101,114,101,32,38,38,32,111,118,101,114,108,97,112,32,60,61,32,102,114,97,103,45,62,110,115,97,109,112,108,101,115,0,115,101,116,32,115,116,114,101,97,109,32,115,101,108,101,99,116,105,111,110,32,101,120,112,114,101,115,115,105,111,110,0,67,114,101,115,116,32,102,97,99,116,111,114,58,32,37,102,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,101,115,116,95,86,105,114,103,105,110,105,97,95,78,0,0,0,0,0,0,0,65,114,114,97,121,32,116,111,111,32,98,105,103,46,10,0,69,109,112,116,121,32,116,105,109,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,105,110,32,116,105,109,101,115,32,108,105,115,116,32,37,115,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,98,105,116,32,108,101,110,103,116,104,32,114,101,112,101,97,116,0,0,0,0,0,0,0,78,111,32,115,112,97,99,101,32,102,111,114,32,37,100,32,115,97,109,112,108,101,115,44,32,115,116,114,101,116,99,104,105,110,103,32,97,117,100,105,111,32,102,105,102,111,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,100,101,99,97,121,0,0,0,80,67,83,95,78,65,68,56,51,95,87,97,115,104,105,110,103,116,111,110,95,83,111,117,116,104,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,72,111,119,32,116,111,32,100,101,116,101,114,109,105,110,101,32,116,104,101,32,101,110,100,45,111,102,45,115,116,114,101,97,109,46,0,0,0,0,0,66,117,102,102,101,114,32,113,117,101,117,101,32,111,118,101,114,102,108,111,119,44,32,100,114,111,112,112,105,110,103,46,10,0,0,0,0,0,0,0,65,32,99,111,109,109,97,45,115,101,112,97,114,97,116,101,100,32,108,105,115,116,32,111,102,32,115,97,109,112,108,101,32,102,111,114,109,97,116,115,46,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,87,97,115,104,105,110,103,116,111,110,95,78,111,114,116,104,0,0,0,0,0,0,110,101,120,116,95,100,116,115,32,62,61,32,48,0,0,0,100,118,32,100,101,109,117,120,32,99,111,110,116,101,120,116,32,105,110,105,116,32,101,114,114,111,114,10,0,0,0,0,115,101,116,32,110,117,109,98,101,114,32,111,102,32,102,105,114,115,116,32,115,97,109,112,108,101,32,116,111,32,115,116,97,114,116,32,102,97,100,105,110,103,0,0,0,0,0,0,105,110,95,103,97,105,110,0,37,100,32,102,114,97,109,101,32,100,117,112,108,105,99,97,116,105,111,110,32,116,111,111,32,108,97,114,103,101,44,32,115,107,105,112,112,105,110,103,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,101,109,112,116,121,32,102,114,97,109,101,32,37,115,44,32,115,107,105,112,112,105,110,103,46,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,86,105,114,103,105,110,105,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,48,32,38,38,32,34,73,110,118,97,108,105,100,32,109,97,120,95,116,120,95,115,105,122,101,46,34,0,0,0,0,0,67,104,97,110,110,101,108,115,32,101,120,112,114,101,115,115,105,111,110,115,32,108,105,115,116,32,105,115,32,101,109,112,116,121,10,0,0,0,0,0,46,47,118,112,57,47,99,111,109,109,111,110,47,118,112,57,95,112,114,101,100,95,99,111,109,109,111,110,46,104,0,0,80,67,83,95,78,65,68,56,51,95,86,105,114,103,105,110,105,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,115,109,112,116,101,98,97,114,115,0,0,0,0,0,0,0,116,101,115,116,0,0,0,0,33,109,101,109,99,109,112,40,99,109,45,62,99,111,117,110,116,115,46,101,111,98,95,98,114,97,110,99,104,44,32,122,101,114,111,95,99,111,117,110,116,115,46,101,111,98,95,98,114,97,110,99,104,44,32,115,105,122,101,111,102,40,99,109,45,62,99,111,117,110,116,115,46,101,111,98,95,98,114,97,110,99,104,41,41,0,0,0,80,67,83,95,78,65,68,56,51,95,86,101,114,109,111,110,116,0,0,0,0,0,0,0,109,97,120,105,116,101,114,0,37,100,58,37,100,32,37,99,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,116,97,104,95,83,111,117,116,104,0,0,0,0,114,101,97,100,32,105,110,105,116,105,97,108,32,112,97,116,116,101,114,110,32,102,114,111,109,32,102,105,108,101,0,0,33,40,108,102,109,45,62,97,98,111,118,101,95,121,91,84,88,95,49,54,88,49,54,93,32,38,32,108,102,109,45,62,97,98,111,118,101,95,121,91,84,88,95,52,88,52,93,41,0,0,0,0,0,0,0,0,115,101,110,100,95,102,105,101,108,100,95,110,111,115,112,97,116,105,97,108,0,0,0,0,105,110,116,101,114,108,97,99,101,100,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,85,116,97,104,95,67,101,110,116,114,97,108,0,0,116,0,0,0,0,0,0,0,37,115,61,37,115,58,0,0,121,117,118,97,52,50,50,112,49,54,108,101,0,0,0,0,77,101,100,105,117,109,86,105,111,108,101,116,82,101,100,0,109,111,100,105,102,105,101,100,95,101,95,119,101,105,103,104,116,101,100,0,0,0,0,0,115,108,105,99,101,61,37,99,32,98,117,116,32,50,112,97,115,115,32,115,116,97,116,115,32,115,97,121,32,37,99,10,0,0,0,0,0,0,0,0,98,105,116,114,97,116,101,32,110,111,116,32,115,112,101,99,105,102,105,101,100,10,0,0,115,101,116,32,108,117,109,97,32,101,102,102,101,99,116,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,0,97,118,99,116,120,45,62,99,111,100,101,99,95,116,121,112,101,32,61,61,32,65,86,77,69,68,73,65,95,84,89,80,69,95,86,73,68,69,79,0,80,67,83,95,78,65,68,56,51,95,85,116,97,104,95,78,111,114,116,104,0,0,0,0,71,67,83,95,70,97,104,117,100,0,0,0,0,0,0,0,109,118,114,97,110,103,101,0,99,108,111,99,107,95,102,108,105,112,0,0,0,0,0,0,120,49,0,0,0,0,0,0,119,97,114,110,105,110,103,44,32,99,108,105,112,112,105,110,103,32,37,100,32,100,99,116,32,99,111,101,102,102,105,99,105,101,110,116,115,32,116,111,32,37,100,46,46,37,100,10,0,0,0,0,0,0,0,0,72,101,97,100,101,114,32,116,114,117,110,99,97,116,101,100,10,0,0,0,0,0,0,0,104,105,103,104,49,48,0,0,103,111,111,100,0,0,0,0,112,97,100,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,105,110,118,97,108,105,100,10,0,0,0,0,0,0,118,109,100,118,105,100,101,111,0,0,0,0,0,0,0,0,115,101,116,32,111,117,116,101,114,32,98,111,114,100,101,114,32,109,97,114,103,105,110,32,105,110,32,112,105,120,101,108,115,0,0,0,0,0,0,0,67,104,97,109,98,101,114,32,77,117,115,105,99,0,0,0,32,40,107,97,114,97,111,107,101,41,0,0,0,0,0,0,108,105,109,105,116,95,115,105,122,101,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,83,111,117,116,104,0,0,0,116,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,83,111,117,116,104,95,67,101,110,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,32,109,101,109,111,114,121,32,102,111,114,32,115,116,114,101,97,109,32,111,112,116,105,111,110,115,46,10,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,102,111,114,99,101,100,32,116,105,109,101,115,32,97,114,114,97,121,10,0,0,97,98,114,0,0,0,0,0,104,97,114,100,0,0,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,115,101,116,32,108,117,109,97,32,116,104,114,101,115,104,111,108,100,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,67,101,110,116,114,97,108,0,112,114,111,103,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,78,111,114,116,104,95,67,101,110,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,67,84,84,83,32,105,110,118,97,108,105,100,10,0,0,0,115,101,116,32,108,117,109,97,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,111,119,0,0,0,0,0,0,42,42,42,32,100,114,111,112,33,10,0,0,0,0,0,0,101,120,116,101,110,100,101,100,32,104,101,97,100,101,114,32,116,111,111,32,108,111,110,103,46,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,120,97,115,95,78,111,114,116,104,0,0,0,117,110,99,111,100,101,100,102,114,97,109,101,99,114,99,0,115,98,0,0,0,0,0,0,109,115,101,95,37,99,58,37,48,46,50,102,32,0,0,0,116,120,100,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,84,101,110,110,101,115,115,101,101,0,0,0,0,0,84,0,0,0,0,0,0,0,102,114,97,109,101,95,109,118,91,109,98,109,105,45,62,109,111,100,101,93,91,76,65,83,84,95,70,82,65,77,69,93,46,97,115,95,105,110,116,32,61,61,32,48,0,0,0,0,121,49,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,83,111,117,116,104,95,68,97,107,111,116,97,95,83,0,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,116,116,121,0,0,0,0,0,111,118,101,114,108,97,121,95,119,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,83,111,117,116,104,95,68,97,107,111,116,97,95,78,0,0,0,0,0,0,0,0,99,109,45,62,119,105,100,116,104,32,60,61,32,99,112,105,45,62,105,110,105,116,105,97,108,95,119,105,100,116,104,0,116,116,97,0,0,0,0,0,97,0,0,0,0,0,0,0,115,101,116,32,102,114,97,99,116,105,111,110,32,100,114,111,112,112,105,110,103,32,116,104,114,101,115,104,111,108,100,0,80,67,83,95,78,65,68,56,51,95,83,111,117,116,104,95,67,97,114,111,108,105,110,97,0,0,0,0,0,0,0,0,116,109,118,0,0,0,0,0,33,118,102,45,62,103,101,116,95,105,109,97,103,101,0,0,121,117,118,97,52,50,50,112,49,54,98,101,0,0,0,0,77,101,100,105,117,109,84,117,114,113,117,111,105,115,101,0,102,111,114,109,97,116,0,0,115,101,108,101,99,116,32,102,45,119,101,105,103,104,116,101,100,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,0,116,105,101,114,116,101,120,115,101,113,0,0,0,0,0,0,118,98,118,45,109,97,120,114,97,116,101,32,105,115,115,117,101,44,32,113,112,109,97,120,32,111,114,32,118,98,118,45,109,97,120,114,97,116,101,32,116,111,111,32,108,111,119,10,0,0,0,0,0,0,0,0,49,48,45,98,105,116,32,120,50,54,52,32,105,115,32,114,101,113,117,105,114,101,100,32,116,111,32,101,110,99,111,100,101,32,65,86,67,45,73,110,116,114,97,10,0,0,0,0,116,102,102,0,0,0,0,0,80,65,82,65,77,95,67,72,65,78,71,69,32,115,105,100,101,32,100,97,116,97,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,0,0,0,116,104,112,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,82,104,111,100,101,95,73,115,108,97,110,100,0,0,71,67,83,95,69,68,56,55,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,99,112,105,45,62,115,101,103,109,101,110,116,97,116,105,111,110,95,109,97,112,0,0,0,0,0,0,0,0,109,101,45,114,97,110,103,101,0,0,0,0,0,0,0,0,80,67,77,32,117,110,115,105,103,110,101,100,32,51,50,45,98,105,116,32,108,105,116,116,108,101,45,101,110,100,105,97,110,0,0,0,0,0,0,0,112,104,111,100,115,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,105,108,108,101,103,97,108,32,77,66,32,116,121,112,101,10,0,0,0,0,0,0,0,0,118,111,112,32,110,111,116,32,99,111,100,101,100,10,0,0,101,114,114,111,114,32,99,111,117,110,116,58,32,37,100,10,0,0,0,0,0,0,0,0,104,105,103,104,0,0,0,0,98,101,115,116,0,0,0,0,105,110,116,101,114,112,95,109,111,100,101,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,110,111,116,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,101,114,114,111,114,32,99,111,110,99,101,97,108,105,110,103,10,0,0,0,68,117,99,107,32,84,114,117,101,77,111,116,105,111,110,32,49,46,48,0,0,0,0,0,79,112,101,114,97,0,0,0,67,111,114,114,117,112,116,32,102,114,97,109,101,32,100,101,116,101,99,116,101,100,0,0,32,40,108,121,114,105,99,115,41,0,0,0,0,0,0,0,115,101,116,32,116,104,101,32,108,105,109,105,116,32,102,105,108,101,32,115,105,122,101,32,105,110,32,98,121,116,101,115,0,0,0,0,0,0,0,0,110,101,103,118,97,108,0,0,80,67,83,95,78,65,68,56,51,95,80,101,110,110,115,121,108,118,97,110,105,97,95,83,0,0,0,0,0,0,0,0,116,119,111,119,97,121,0,0,100,101,102,97,117,108,116,0,99,104,114,111,109,97,95,109,111,100,101,0,0,0,0,0,108,111,115,115,108,101,115,115,32,101,120,112,101,99,116,101,100,32,98,111,111,108,101,97,110,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,80,101,110,110,115,121,108,118,97,110,105,97,95,78,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,112,101,99,105,102,105,101,114,58,32,37,115,46,10,0,0,83,112,101,99,105,102,105,101,100,32,102,114,97,109,101,32,37,100,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,102,111,108,108,111,119,105,110,103,32,102,114,97,109,101,32,37,100,10,0,0,0,0,0,0,84,111,112,32,70,105,101,108,100,32,70,105,114,115,116,32,32,32,0,0,0,0,0,0,116,0,0,0,0,0,0,0,103,95,116,104,114,101,97,100,115,32,111,117,116,32,111,102,32,114,97,110,103,101,32,91,46,46,54,52,93,0,0,0,116,101,109,112,111,114,97,108,32,99,104,114,111,109,97,32,115,116,114,101,110,103,116,104,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,114,101,103,111,110,95,83,111,117,116,104,0,0,112,101,114,32,114,111,119,47,99,111,108,117,109,110,32,108,117,109,105,110,97,110,99,101,32,103,114,97,112,104,0,0,97,112,112,108,121,32,110,111,32,97,110,116,105,98,97,110,100,105,110,103,0,0,0,0,116,101,101,0,0,0,0,0,99,114,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,114,101,103,111,110,95,78,111,114,116,104,0,0,99,111,115,116,32,62,61,32,48,0,0,0,0,0,0,0,100,105,114,32,37,115,10,0,108,105,110,101,115,0,0,0,73,78,84,69,82,56,88,56,95,67,72,82,79,77,65,0,122,101,114,111,0,0,0,0,78,111,116,32,100,117,112,108,105,99,97,116,105,110,103,32,37,100,32,105,110,105,116,105,97,108,32,102,114,97,109,101,115,10,0,0,0,0,0,0,102,114,97,109,101,32,119,105,116,104,32,115,97,109,101,32,102,105,101,108,100,32,111,114,100,101,114,0,0,0,0,0,105,110,118,97,108,105,100,32,101,120,116,101,110,100,101,100,32,104,101,97,100,101,114,32,108,101,110,103,116,104,0,0,80,67,83,95,78,65,68,56,51,95,79,107,108,97,104,111,109,97,95,83,111,117,116,104,0,0,0,0,0,0,0,0,116,101,100,99,97,112,116,105,111,110,115,0,0,0,0,0,111,114,100,101,114,32,61,61,32,48,32,124,124,32,111,114,100,101,114,32,61,61,32,49,32,124,124,32,102,105,101,108,100,32,61,61,32,48,32,124,124,32,102,105,101,108,100,32,61,61,32,49,0,0,0,0,99,108,69,110,113,117,101,117,101,77,97,112,66,117,102,102,101,114,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,107,108,97,104,111,109,97,95,78,111,114,116,104,0,0,0,0,0,0,0,0,119,58,37,100,32,104,58,37,100,32,116,121,112,101,58,37,115,32,45,62,32,119,58,37,100,32,104,58,37,100,10,0,33,34,118,97,108,105,100,32,101,108,101,109,101,110,116,32,115,105,122,101,34,0,0,0,109,111,110,111,98,0,0,0,102,97,100,101,45,105,110,0,37,72,58,37,77,58,37,83,0,0,0,0,0,0,0,0,117,0,0,0,0,0,0,0,48,120,37,48,56,88,0,0,116,97,107,0,0,0,0,0,27,91,37,100,59,51,37,100,109,37,115,27,91,48,109,0,83,72,65,53,49,50,47,50,53,54,0,0,0,0,0,0,115,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,79,104,105,111,95,83,111,117,116,104,0,0,0,0,116,97,110,0,0,0,0,0,68,69,77,85,88,69,82,95,78,79,84,95,70,79,85,78,68,0,0,0,0,0,0,0,102,114,111,110,116,32,99,101,110,116,101,114,0,0,0,0,68,101,115,105,114,101,100,32,100,105,116,104,101,114,105,110,103,32,111,110,108,121,32,115,117,112,112,111,114,116,101,100,32,105,110,32,102,117,108,108,32,99,104,114,111,109,97,32,105,110,116,101,114,112,111,108,97,116,105,111,110,32,102,111,114,32,100,101,115,116,105,110,97,116,105,111,110,32,102,111,114,109,97,116,32,39,37,115,39,10,0,0,0,0,0,0,108,105,98,115,119,115,99,97,108,101,47,115,119,115,99,97,108,101,46,99,0,0,0,0,77,86,32,114,97,110,103,101,32,40,37,108,108,100,41,32,62,32,108,101,118,101,108,32,108,105,109,105,116,32,40,37,100,41,10,0,0,0,0,0,115,101,116,32,119,105,100,116,104,32,111,102,32,103,114,105,100,32,99,101,108,108,0,0,97,114,101,97,0,0,0,0,111,99,104,0,0,0,0,0,110,111,99,104,114,111,109,0,80,67,83,95,78,65,68,56,51,95,79,104,105,111,95,78,111,114,116,104,0,0,0,0,115,101,116,32,121,32,102,111,114,32,116,104,101,32,114,101,99,116,97,110,103,117,108,97,114,32,115,101,97,114,99,104,32,97,114,101,97,0,0,0,114,97,110,103,101,32,60,61,50,53,54,32,124,124,32,33,40,115,45,62,99,111,100,101,99,95,105,100,32,61,61,32,65,86,95,67,79,68,69,67,95,73,68,95,77,80,69,71,50,86,73,68,69,79,32,38,38,32,115,45,62,97,118,99,116,120,45,62,115,116,114,105,99,116,95,115,116,100,95,99,111,109,112,108,105,97,110,99,101,32,62,61,32,48,41,0,115,101,116,32,108,111,103,111,32,119,105,100,116,104,0,0,108,105,98,97,118,99,111,100,101,99,47,101,114,114,111,114,95,114,101,115,105,108,105,101,110,99,101,46,99,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,116,114,97,110,115,109,105,116,116,101,100,32,117,110,105,116,115,33,10,0,0,0,92,37,49,91,49,50,51,52,93,97,37,49,91,92,125,93,37,110,0,0,0,0,0,0,57,58,53,57,58,53,57,46,57,57,44,0,0,0,0,0,117,110,107,110,111,119,110,32,112,114,101,100,105,99,116,105,111,110,32,116,121,112,101,58,32,37,105,10,0,0,0,0,80,105,99,116,117,114,101,32,100,105,109,101,110,115,105,111,110,32,99,104,97,110,103,101,100,58,32,111,108,100,58,32,37,100,32,120,32,37,100,44,32,110,101,119,58,32,37,100,32,120,32,37,100,10,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,32,108,111,119,101,115,116,0,97,100,112,99,109,95,101,97,95,109,97,120,105,115,95,120,97,0,0,0,0,0,0,0,115,119,102,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,111,114,116,104,95,68,97,107,111,116,97,95,83,0,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,47,114,97,116,101,99,111,110,116,114,111,108,46,99,0,0,0,67,101,110,116,101,114,32,77,105,120,32,76,101,118,101,108,0,0,0,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,108,116,114,116,95,99,109,105,120,108,101,118,0,0,0,0,107,120,32,33,61,32,102,95,116,97,98,108,101,123,104,105,103,104,44,108,111,119,125,91,48,93,46,32,68,101,114,105,118,101,100,32,102,114,101,113,117,101,110,99,121,32,116,97,98,108,101,115,32,119,101,114,101,32,110,111,116,32,114,101,103,101,110,101,114,97,116,101,100,46,10,0,0,0,0,0,67,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,121,117,118,97,52,50,48,112,49,54,108,101,0,0,0,0,77,101,100,105,117,109,83,112,114,105,110,103,71,114,101,101,110,0,0,0,0,0,0,0,84,89,80,69,95,70,73,76,58,32,73,110,112,117,116,32,98,117,102,102,101,114,32,101,120,104,97,117,115,116,101,100,32,98,101,102,111,114,101,32,69,78,68,32,101,108,101,109,101,110,116,32,102,111,117,110,100,10,0,0,0,0,0,0,102,95,119,101,105,103,104,116,101,100,0,0,0,0,0,0,114,101,97,108,108,111,99,32,102,97,105,108,117,114,101,10,0,0,0,0,0,0,0,0,105,110,102,108,97,116,101,32,101,114,114,111,114,32,37,100,10,0,0,0,0,0,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,10,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,110,118,97,108,105,100,32,98,121,116,101,32,111,114,100,101,114,10,0,0,0,0,0,37,50,100,45,98,105,116,32,65,86,67,45,73,110,116,114,97,32,105,115,32,110,111,116,32,119,105,100,101,108,121,32,99,111,109,112,97,116,105,98,108,101,10,0,0,0,0,0,120,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,120,95,115,116,97,114,116,32,62,61,32,48,32,38,38,32,120,95,115,116,97,114,116,32,60,61,32,50,53,53,32,38,38,32,120,95,101,110,100,32,62,61,32,48,32,38,38,32,120,95,101,110,100,32,60,61,32,50,53,53,0,0,0,0,102,112,115,58,37,100,44,32,98,114,58,37,100,44,32,113,112,98,105,116,58,37,100,44,32,97,98,116,95,102,108,97,103,58,37,100,44,32,106,95,116,121,112,101,95,98,105,116,58,37,100,44,32,116,108,95,109,118,95,102,108,97,103,58,37,100,44,32,109,98,114,108,95,98,105,116,58,37,100,44,32,99,111,100,101,58,37,100,44,32,108,111,111,112,95,102,105,108,116,101,114,58,37,100,44,32,115,108,105,99,101,115,58,37,100,10,0,0,0,0,73,110,118,97,108,105,100,32,100,101,110,111,105,115,101,32,102,105,108,116,101,114,32,115,116,114,101,110,103,116,104,32,37,100,32,40,109,97,120,61,49,49,41,10,0,0,0,0,84,104,105,115,32,100,101,99,111,100,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,112,97,114,97,109,101,116,101,114,32,99,104,97,110,103,101,115,44,32,98,117,116,32,80,65,82,65,77,95,67,72,65,78,71,69,32,115,105,100,101,32,100,97,116,97,32,119,97,115,32,115,101,110,116,32,116,111,32,105,116,46,10,0,0,0,0,110,117,109,95,118,101,99,95,99,111,101,102,102,115,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,98,114,111,107,101,110,32,115,117,98,102,114,97,109,101,10,0,0,0,0,0,0,0,0,112,117,116,95,98,105,116,115,95,112,116,114,40,38,115,45,62,112,98,41,32,45,32,115,45,62,112,98,46,98,117,102,32,61,61,32,97,118,99,116,120,45,62,98,108,111,99,107,95,97,108,105,103,110,0,0,80,67,83,95,78,65,68,56,51,95,78,111,114,116,104,95,68,97,107,111,116,97,95,78,0,0,0,0,0,0,0,0,98,108,111,99,107,95,108,101,110,95,98,105,116,115,32,37,100,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,71,67,83,95,69,68,53,48,0,0,0,0,0,0,0,0,123,92,98,49,125,0,0,0,101,114,114,111,114,32,100,101,99,111,100,105,110,103,32,69,120,105,102,32,100,97,116,97,10,0,0,0,0,0,0,0,111,110,0,0,0,0,0,0,100,101,102,97,117,108,116,0,109,101,114,97,110,103,101,0,84,111,111,32,109,97,110,121,32,100,101,99,111,114,114,101,108,97,116,105,111,110,32,116,101,114,109,115,10,0,0,0,112,99,109,95,117,51,50,108,101,0,0,0,0,0,0,0,99,98,112,122,32,99,104,117,110,107,32,116,111,111,32,108,97,114,103,101,32,40,37,117,32,98,121,116,101,115,41,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,121,110,99,32,99,111,100,101,10,0,0,0,0,0,0,112,104,111,100,115,0,0,0,101,110,99,111,100,101,100,32,112,97,114,116,105,116,105,111,110,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,98,101,102,111,114,101,32,118,111,112,95,99,111,100,101,100,0,0,0,0,0,0,0,0,108,32,33,61,32,99,115,117,98,0,0,0,0,0,0,0,109,106,112,101,103,95,100,101,99,111,100,101,95,100,99,58,32,98,97,100,32,118,108,99,58,32,37,100,58,37,100,32,40,37,112,41,10,0,0,0,84,111,111,32,109,97,110,121,32,99,104,97,110,110,101,108,115,32,105,110,32,118,111,114,98,105,115,95,102,108,111,111,114,95,100,101,99,111,100,101,46,10,0,0,0,0,0,0,98,97,115,101,108,105,110,101,0,0,0,0,0,0,0,0,113,117,97,108,105,116,121,0,85,110,115,117,112,112,111,114,116,101,100,32,109,111,100,101,32,99,111,117,110,116,58,32,37,100,10,0,0,0,0,0,82,101,99,116,97,110,103,108,101,32,111,117,116,115,105,100,101,32,112,105,99,116,117,114,101,10,0,0,0,0,0,0,40,98,117,102,95,115,105,122,101,32,38,32,40,97,118,99,116,120,45,62,99,104,97,110,110,101,108,115,32,62,32,49,41,41,32,61,61,32,48,0,120,0,0,0,0,0,0,0,99,111,110,116,101,120,116,95,105,110,105,116,40,41,32,102,97,105,108,101,100,46,10,0,83,112,114,105,116,101,32,100,101,99,111,100,101,114,58,32,101,120,112,101,99,116,101,100,32,73,45,102,114,97,109,101,10,0,0,0,0,0,0,0,115,119,102,0,0,0,0,0,77,86,32,99,111,115,116,32,116,101,115,116,32,102,97,105,108,101,100,58,32,120,50,54,52,32,104,97,115,32,98,101,101,110,32,109,105,115,99,111,109,112,105,108,101,100,33,10,0,0,0,0,0,0,0,0,80,114,111,102,105,108,101,32,37,105,58,10,102,114,109,114,116,113,95,112,111,115,116,112,114,111,99,61,37,105,44,32,98,105,116,114,116,113,95,112,111,115,116,112,114,111,99,61,37,105,10,76,111,111,112,70,105,108,116,101,114,61,37,105,44,32,77,117,108,116,105,82,101,115,61,37,105,44,32,70,97,115,116,85,86,77,67,61,37,105,44,32,69,120,116,101,110,100,101,100,32,77,86,61,37,105,10,82,97,110,103,101,114,101,100,61,37,105,44,32,86,83,84,114,97,110,115,102,111,114,109,61,37,105,44,32,79,118,101,114,108,97,112,61,37,105,44,32,83,121,110,99,77,97,114,107,101,114,61,37,105,10,68,81,117,97,110,116,61,37,105,44,32,81,117,97,110,116,105,122,101,114,32,109,111,100,101,61,37,105,44,32,77,97,120,32,66,32,102,114,97,109,101,115,61,37,105,10,0,0,0,0,0,0,0,0,116,114,117,101,109,111,116,105,111,110,49,0,0,0,0,0,67,104,97,110,115,111,110,0,115,101,116,32,66,84,46,55,48,57,32,99,111,108,111,114,115,112,97,99,101,0,0,0,52,58,50,58,50,32,118,105,100,101,111,32,114,101,113,117,105,114,101,115,32,101,118,101,110,32,119,105,100,116,104,46,10,0,0,0,0,0,0,0,83,108,105,99,101,32,100,101,99,111,100,105,110,103,32,114,97,110,32,111,117,116,32,111,102,32,98,105,116,115,10,0,32,40,99,111,109,109,101,110,116,41,0,0,0,0,0,0,102,115,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,111,114,116,104,95,67,97,114,111,108,105,110,97,0,0,0,0,0,0,0,0,78,111,32,99,111,100,101,99,32,112,114,111,118,105,100,101,100,32,116,111,32,97,118,99,111,100,101,99,95,111,112,101,110,50,40,41,10,0,0,0,102,111,114,109,97,116,58,32,37,100,32,99,104,97,110,115,58,32,37,100,32,98,112,115,58,32,37,100,32,114,97,116,101,58,32,37,100,32,98,108,111,99,107,58,32,37,100,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,115,108,105,99,101,32,37,100,10,0,0,0,0,0,0,0,0,73,110,102,108,97,116,101,32,105,110,105,116,32,101,114,114,111,114,58,32,37,100,10,0,103,114,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,116,114,101,97,109,32,115,105,122,101,10,0,0,0,0,105,110,118,97,108,105,100,32,118,101,99,116,111,114,32,116,97,98,108,101,32,105,100,32,40,37,100,41,10,0,0,0,66,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,103,109,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,89,111,114,107,95,76,111,110,103,95,73,115,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,86,105,100,101,111,32,111,112,116,105,111,110,115,58,0,37,115,37,115,47,37,115,45,37,115,46,102,102,112,114,101,115,101,116,0,0,0,0,0,99,104,114,111,109,97,95,114,97,100,105,117,115,0,0,0,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,39,37,115,39,44,32,109,117,115,116,32,98,101,32,97,32,112,111,115,105,116,105,118,101,32,105,110,116,101,103,101,114,32,60,61,32,73,78,84,54,52,95,77,65,88,10,0,71,101,111,103,65,110,103,117,108,97,114,85,110,105,116,83,105,122,101,71,101,111,75,101,121,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,115,116,114,105,112,32,115,105,122,101,47,111,102,102,115,101,116,10,0,0,0,0,0,0,83,101,116,32,105,102,32,65,83,83,32,116,97,103,115,32,109,117,115,116,32,98,101,32,101,115,99,97,112,101,100,0,80,97,99,107,101,116,32,119,101,110,116,32,111,117,116,32,111,102,32,98,111,117,110,100,115,10,0,0,0,0,0,0,105,110,118,97,108,105,100,47,117,110,115,117,112,112,111,114,116,101,100,32,98,105,116,115,32,112,101,114,32,115,97,109,112,108,101,58,32,37,100,10,0,0,0,0,0,0,0,0,115,117,98,118,105,101,119,101,114,0,0,0,0,0,0,0,102,102,95,104,50,54,52,95,99,104,101,99,107,95,105,110,116,114,97,95,112,114,101,100,95,109,111,100,101,32,60,32,48,10,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,108,111,114,109,97,112,32,108,101,110,103,116,104,10,0,0,0,0,0,0,0,0,111,110,116,0,0,0,0,0,123,92,97,110,37,42,49,117,125,37,110,0,0,0,0,0,83,111,110,105,99,118,50,32,99,104,97,110,115,58,32,37,100,32,115,97,109,112,114,97,116,101,58,32,37,100,10,0,112,97,115,115,58,37,100,32,99,104,97,110,103,101,100,58,37,100,10,0,0,0,0,0,115,112,97,116,105,97,108,95,100,101,99,111,109,112,111,115,105,116,105,111,110,95,116,121,112,101,32,37,100,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,105,110,118,97,108,105,100,32,118,108,99,10,0,0,0,0,78,111,32,99,104,97,110,110,101,108,115,32,114,101,112,111,114,116,101,100,10,0,0,0,108,105,98,97,118,99,111,100,101,99,47,98,121,116,101,115,116,114,101,97,109,46,104,0,37,115,13,10,0,0,0,0,78,101,101,100,32,68,81,85,65,78,84,10,0,0,0,0,114,118,50,48,32,101,110,99,111,100,101,114,0,0,0,0,65,0,0,0,0,0,0,0,117,112,100,97,116,101,32,115,105,122,101,32,102,114,111,109,32,37,100,32,116,111,32,37,100,10,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,89,111,114,107,95,87,101,115,116,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,118,97,114,0,0,0,0,0,69,120,116,114,97,100,97,116,97,32,105,115,32,110,111,116,32,103,114,111,111,118,121,44,32,100,117,100,101,10,0,0,112,97,99,107,101,116,32,116,121,112,101,32,56,0,0,0,66,117,102,102,101,114,32,105,115,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,116,104,101,32,99,108,97,105,109,101,100,32,98,105,116,114,97,116,101,46,10,0,0,0,102,114,97,109,101,32,115,105,122,101,32,117,112,112,101,114,32,98,111,117,110,100,58,32,37,100,10,0,0,0,0,0,112,105,120,95,116,104,0,0,97,112,99,111], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2627744);
/* memory initializer */ allocate([111,117,116,32,111,102,32,115,108,105,99,101,32,100,97,116,97,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,115,108,105,99,101,32,114,101,115,111,108,117,116,105,111,110,58,32,37,100,120,37,100,10,0,0,0,0,115,117,98,118,105,101,119,101,114,49,0,0,0,0,0,0,100,112,109,0,0,0,0,0,112,72,89,115,32,97,102,116,101,114,32,73,68,65,84,10,0,0,0,0,0,0,0,0,102,111,114,99,101,100,95,115,117,98,115,95,111,110,108,121,0,0,0,0,0,0,0,0,108,97,118,102,105,46,98,98,111,120,46,121,50,0,0,0,109,97,120,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,89,111,114,107,95,67,101,110,116,114,97,108,0,0,0,0,0,0,110,111,0,0,0,0,0,0,112,97,116,104,32,37,115,10,0,0,0,0,0,0,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,114,116,106,112,101,103,32,113,117,97,110,116,32,100,97,116,97,10,0,68,105,109,101,110,115,105,111,110,115,32,111,102,32,99,117,114,114,101,110,116,32,97,110,100,32,114,101,102,101,114,101,110,99,101,32,112,105,99,116,117,114,101,32,109,105,115,109,97,116,99,104,10,0,0,0,66,111,116,116,111,109,85,112,0,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,105,0,0,0,0,0,0,0,101,120,112,101,99,116,101,100,32,73,45,102,114,97,109,101,10,0,0,0,0,0,0,0,37,103,32,102,114,97,109,101,115,32,112,101,114,32,115,101,99,111,110,100,10,0,0,0,108,117,109,97,95,101,108,105,109,95,116,104,114,101,115,104,111,108,100,0,0,0,0,0,98,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,115,105,0,0,0,0,0,0,97,118,105,0,0,0,0,0,118,101,114,115,105,111,110,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,89,111,114,107,95,69,97,115,116,0,37,115,0,0,0,0,0,0,69,110,97,98,108,101,32,97,108,116,101,114,110,97,116,101,32,115,99,97,110,116,97,98,108,101,46,0,0,0,0,0,77,80,69,71,32,71,79,80,32,84,105,109,101,99,111,100,101,32,105,110,32,104,104,58,109,109,58,115,115,91,58,59,46,93,102,102,32,102,111,114,109,97,116,0,0,0,0,0,83,105,109,112,108,101,0,0,32,73,78,84,69,82,76,65,67,69,68,58,37,108,108,100,0,0,0,0,0,0,0,0,73,110,105,116,105,110,103,32,86,76,67,10,0,0,0,0,69,110,100,32,111,102,32,115,116,114,101,97,109,32,105,110,100,105,99,97,116,101,100,46,10,0,0,0,0,0,0,0,74,70,73,70,0,0,0,0,110,98,95,99,111,109,112,111,110,101,110,116,115,32,99,104,97,110,103,105,110,103,32,105,110,32,105,110,116,101,114,108,97,99,101,100,32,112,105,99,116,117,114,101,10,0,0,0,115,111,102,32,105,115,32,37,100,32,97,110,100,32,115,105,122,101,32,105,115,32,37,100,10,0,0,0,0,0,0,0,123,92,102,115,125,0,0,0,84,111,111,32,109,97,110,121,32,105,110,112,117,116,115,32,115,112,101,99,105,102,105,101,100,32,102,111,114,32,116,104,101,32,34,37,115,34,32,102,105,108,116,101,114,46,10,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,77,101,120,105,99,111,95,87,101,115,116,0,0,0,0,0,0,0,83,101,116,32,112,114,111,102,105,108,101,32,114,101,115,116,114,105,99,116,105,111,110,115,32,40,99,102,46,32,120,50,54,52,32,45,45,102,117,108,108,104,101,108,112,41,32,0,78,111,32,115,116,97,116,115,32,102,105,108,101,32,102,111,114,32,115,101,99,111,110,100,32,112,97,115,115,10,0,0,115,114,116,0,0,0,0,0,66,85,71,33,32,85,110,107,110,111,119,110,32,105,109,97,103,101,116,121,112,101,32,105,110,32,112,110,103,102,105,108,116,101,114,32,115,119,105,116,99,104,46,10,0,0,0,0,73,110,116,101,103,101,114,32,111,118,101,114,102,108,111,119,32,101,110,99,111,117,110,116,101,114,101,100,32,105,110,32,99,117,109,117,108,97,116,105,118,101,32,112,114,111,98,97,98,105,108,105,116,121,32,99,97,108,99,117,108,97,116,105,111,110,46,10,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,44,32,100,101,99,111,100,105,110,103,32,109,97,121,32,110,111,116,32,119,111,114,107,32,112,114,111,112,101,114,108,121,46,46,46,10,0,0,0,102,114,97,109,101,45,62,110,98,95,115,97,109,112,108,101,115,32,62,32,111,102,102,115,101,116,0,0,0,0,0,0,80,114,111,103,114,101,115,115,105,111,110,32,111,114,100,101,114,32,82,76,67,80,0,0,123,92,97,110,51,125,0,0,105,110,105,116,10,0,0,0,73,110,118,97,108,105,100,32,110,111,110,45,112,111,115,105,116,105,118,101,32,118,97,108,117,101,115,32,102,111,114,32,116,104,101,32,116,105,109,101,98,97,115,101,32,110,117,109,58,37,100,32,111,114,32,100,101,110,58,37,100,46,10,0,77,66,32,115,105,122,101,115,32,109,105,115,109,97,116,99,104,58,32,37,100,32,118,115,46,32,37,100,10,0,0,0,32,83,83,0,0,0,0,0,116,111,111,32,108,105,116,116,108,101,32,100,97,116,97,32,102,111,114,32,111,112,99,111,100,101,32,48,120,56,10,0,73,110,116,101,108,32,72,46,50,54,51,0,0,0,0,0,83,99,97,108,97,98,108,101,32,105,110,116,101,114,32,102,114,97,109,101,32,105,110,32,110,111,110,32,115,99,97,108,101,97,98,108,101,32,115,116,114,101,97,109,10,0,0,0,68,67,84,32,116,114,97,110,115,102,111,114,109,0,0,0,73,110,118,97,108,105,100,32,86,81,32,116,97,98,108,101,32,105,110,100,101,120,101,115,33,32,80,114,105,109,97,114,121,58,32,37,100,44,32,115,101,99,111,110,100,97,114,121,58,32,37,100,33,10,0,0,82,101,97,100,32,99,111,101,102,102,105,99,105,101,110,116,115,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,105,109,97,103,101,32,115,105,122,101,32,114,101,99,101,105,118,101,100,58,32,37,117,32,45,62,32,105,109,97,103,101,32,100,97,116,97,32,111,102,102,115,101,116,58,32,37,100,10,0,0,0,0,0,0,0,118,97,108,32,60,32,51,50,32,38,38,32,118,97,108,32,62,48,32,38,38,32,114,101,112,101,97,116,32,60,32,50,53,54,32,38,38,32,114,101,112,101,97,116,62,48,0,0,115,114,116,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,77,101,120,105,99,111,95,67,101,110,116,0,0,0,0,0,0,0,69,114,114,111,114,32,114,101,97,100,105,110,103,32,104,117,102,102,109,97,110,32,116,97,98,108,101,10,0,0,0,0,69,120,116,114,97,100,97,116,97,32,109,105,115,115,105,110,103,44,32,100,101,99,111,100,101,114,32,114,101,113,117,105,114,101,115,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,10,0,0,0,0,0,86,80,83,32,37,100,32,100,111,101,115,32,110,111,116,32,101,120,105,115,116,10,0,0,91,37,115,93,32,105,110,116,101,114,118,97,108,32,35,37,100,32,115,116,97,114,116,95,116,115,58,37,102,32,101,110,100,95,116,115,58,37,102,32,116,115,58,37,102,10,0,0,73,110,118,97,108,105,100,32,78,65,76,32,117,110,105,116,32,115,105,122,101,46,10,0,108,101,102,116,95,114,105,103,104,116,0,0,0,0,0,0,73,110,99,111,110,115,105,115,116,101,110,116,32,77,77,67,79,32,115,116,97,116,101,32,98,101,116,119,101,101,110,32,115,108,105,99,101,115,32,91,37,100,44,32,37,100,93,10,0,0,0,0,0,0,0,0,109,98,95,119,105,100,116,104,47,104,101,105,103,104,116,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,65,86,67,45,112,97,114,115,101,114,58,32,110,97,108,32,115,105,122,101,32,37,100,32,114,101,109,97,105,110,105,110,103,32,37,100,10,0,0,0,100,113,117,97,110,116,32,111,117,116,32,111,102,32,114,97,110,103,101,32,40,37,100,41,32,97,116,32,37,100,32,37,100,10,0,0,0,0,0,0,104,45,62,115,112,115,46,98,105,116,95,100,101,112,116,104,95,99,104,114,111,109,97,32,61,61,32,48,0,0,0,0,104,50,54,51,112,0,0,0,104,45,62,109,116,121,112,101,32,60,32,40,115,105,122,101,111,102,40,102,102,95,104,50,54,49,95,109,116,121,112,101,95,109,97,112,41,32,47,32,115,105,122,101,111,102,40,40,102,102,95,104,50,54,49,95,109,116,121,112,101,95,109,97,112,41,91,48,93,41,41,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,115,101,116,32,71,73,70,32,102,108,97,103,115,0,0,0,115,116,97,114,116,95,112,116,115,0,0,0,0,0,0,0,108,105,98,97,118,99,111,100,101,99,47,103,55,50,54,46,99,0,0,0,0,0,0,0,68,105,115,112,108,97,121,32,105,110,102,111,58,32,109,105,115,115,105,110,103,32,98,105,116,109,97,115,107,115,33,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,77,101,120,105,99,111,95,69,97,115,116,0,0,0,0,0,0,0,73,110,32,99,104,117,110,107,32,70,76,73,95,67,79,80,89,32,58,32,115,111,117,114,99,101,32,100,97,116,97,32,40,37,100,32,98,121,116,101,115,41,32,98,105,103,103,101,114,32,116,104,97,110,32,105,109,97,103,101,44,32,115,107,105,112,112,105,110,103,32,99,104,117,110,107,10,0,0,0,73,110,112,117,116,32,100,105,109,101,110,115,105,111,110,115,32,116,111,111,32,108,97,114,103,101,44,32,105,110,112,117,116,32,109,117,115,116,32,98,101,32,109,97,120,32,52,48,57,54,120,52,48,57,54,32,33,10,0,0,0,0,0,0,70,114,97,109,101,32,119,105,100,116,104,32,111,114,32,104,101,105,103,104,116,32,100,105,102,102,101,114,115,32,102,114,111,109,32,102,105,114,115,116,32,102,114,97,109,101,33,10,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,109,97,120,32,112,114,101,100,105,99,116,105,111,110,32,111,114,100,101,114,58,32,37,100,10,0,0,0,0,0,0,0,114,119,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,114,97,109,101,32,104,101,97,100,101,114,10,0,0,0,110,117,109,98,101,114,32,111,102,32,99,104,97,110,110,101,108,115,32,99,104,97,110,103,101,32,100,101,116,101,99,116,101,100,32,105,110,32,97,100,106,97,99,101,110,116,32,102,114,97,109,101,115,10,0,0,101,120,116,114,97,100,97,116,97,32,116,111,111,32,115,109,97,108,108,46,10,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,10,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,0,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,82,111,111,109,32,84,121,112,101,0,0,0,0,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,98,117,102,95,115,105,122,101,32,62,61,32,48,0,0,0,108,105,98,97,118,99,111,100,101,99,47,100,118,100,115,117,98,101,110,99,46,99,0,0,100,118,100,115,117,98,100,101,99,0,0,0,0,0,0,0,114,101,103,105,111,110,32,100,101,112,116,104,32,37,100,32,105,115,32,105,110,118,97,108,105,100,10,0,0,0,0,0,80,97,99,107,105,110,103,32,116,111,32,49,54,98,105,116,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,116,111,111,32,109,97,110,121,32,116,104,114,101,97,100,115,10,0,0,0,0,0,0,0,97,99,32,116,101,120,32,100,97,109,97,103,101,100,32,37,100,44,32,37,100,10,0,0,80,73,67,84,85,82,69,95,78,85,77,58,32,37,100,10,0,0,0,0,0,0,0,0,66,76,67,75,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,33,10,0,0,0,0,70,83,73,90,69,57,54,32,61,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,99,111,100,101,99,100,97,116,97,95,108,101,110,103,116,104,61,37,100,10,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,74,101,114,115,101,121,0,0,0,0,105,110,95,115,97,109,112,108,101,95,114,97,116,101,0,0,121,117,118,97,52,50,48,112,49,54,98,101,0,0,0,0,77,101,100,105,117,109,83,108,97,116,101,66,108,117,101,0,115,101,108,101,99,116,32,104,105,103,104,32,115,104,105,98,97,116,97,32,110,111,105,115,101,32,115,104,97,112,105,110,103,32,100,105,116,104,101,114,0,0,0,0,0,0,0,0,114,118,49,48,0,0,0,0,116,114,121,32,105,110,99,114,101,97,115,105,110,103,32,116,97,114,103,101,116,32,98,105,116,114,97,116,101,10,0,0,115,107,105,112,95,101,109,112,116,121,95,99,98,0,0,0,116,105,109,101,95,98,97,115,101,0,0,0,0,0,0,0,114,117,110,32,37,100,32,105,115,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,85,110,107,110,111,119,110,32,98,105,116,102,105,101,108,100,115,32,37,48,88,32,37,48,88,32,37,48,88,10,0,0,110,111,32,114,97,116,101,99,111,110,116,114,111,108,32,109,101,116,104,111,100,32,115,112,101,99,105,102,105,101,100,10,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,119,95,72,97,109,112,115,104,105,114,101,0,114,101,116,32,62,61,32,48,0,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,109,111,116,105,111,110,32,118,97,108,117,101,115,10,0,115,112,100,105,102,0,0,0,85,110,97,98,108,101,32,116,111,32,114,101,99,111,100,101,32,115,117,98,116,105,116,108,101,32,101,118,101,110,116,32,34,37,115,34,32,102,114,111,109,32,37,115,32,116,111,32,85,84,70,45,56,10,0,0,45,45,99,99,61,101,109,99,99,32,45,45,112,114,101,102,105,120,61,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,32,45,45,101,120,116,114,97,45,99,102,108,97,103,115,61,39,45,73,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,105,110,99,108,117,100,101,32,45,118,39,32,45,45,101,110,97,98,108,101,45,99,114,111,115,115,45,99,111,109,112,105,108,101,32,45,45,116,97,114,103,101,116,45,111,115,61,110,111,110,101,32,45,45,97,114,99,104,61,120,56,54,95,51,50,32,45,45,99,112,117,61,103,101,110,101,114,105,99,32,45,45,100,105,115,97,98,108,101,45,102,102,112,108,97,121,32,45,45,100,105,115,97,98,108,101,45,102,102,112,114,111,98,101,32,45,45,100,105,115,97,98,108,101,45,102,102,115,101,114,118,101,114,32,45,45,100,105,115,97,98,108,101,45,97,115,109,32,45,45,100,105,115,97,98,108,101,45,100,111,99,32,45,45,100,105,115,97,98,108,101,45,100,101,118,105,99,101,115,32,45,45,100,105,115,97,98,108,101,45,112,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,119,51,50,116,104,114,101,97,100,115,32,45,45,100,105,115,97,98,108,101,45,110,101,116,119,111,114,107,32,45,45,100,105,115,97,98,108,101,45,104,119,97,99,99,101,108,115,32,45,45,100,105,115,97,98,108,101,45,112,97,114,115,101,114,115,32,45,45,100,105,115,97,98,108,101,45,98,115,102,115,32,45,45,100,105,115,97,98,108,101,45,100,101,98,117,103,32,45,45,100,105,115,97,98,108,101,45,112,114,111,116,111,99,111,108,115,32,45,45,100,105,115,97,98,108,101,45,105,110,100,101,118,115,32,45,45,100,105,115,97,98,108,101,45,111,117,116,100,101,118,115,32,45,45,101,110,97,98,108,101,45,112,114,111,116,111,99,111,108,61,102,105,108,101,32,45,45,101,110,97,98,108,101,45,108,105,98,118,112,120,32,45,45,101,110,97,98,108,101,45,103,112,108,32,45,45,101,120,116,114,97,45,108,105,98,115,61,39,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,120,50,54,52,46,97,32,47,85,115,101,114,115,47,98,103,114,105,110,115,116,101,97,100,47,83,105,116,101,115,47,118,105,100,101,111,99,111,110,118,101,114,116,101,114,46,106,115,47,98,117,105,108,100,47,102,102,109,112,101,103,47,46,46,47,100,105,115,116,47,108,105,98,47,108,105,98,118,112,120,46,97,39,0,71,67,83,95,69,103,121,112,116,95,49,57,48,55,0,0,91,49,50,45,49,51,93,32,37,100,10,0,0,0,0,0,66,117,102,102,101,114,32,116,111,111,32,115,109,97,108,108,32,102,111,114,32,65,83,83,32,101,118,101,110,116,46,10,0,0,0,0,0,0,0,0,69,114,114,111,114,32,100,101,99,111,100,105,110,103,32,102,114,97,109,101,10,0,0,0,109,101,0,0,0,0,0,0,115,97,109,112,108,101,95,102,109,116,115,0,0,0,0,0,107,32,105,110,118,97,108,105,100,32,102,111,114,32,114,105,99,101,32,99,111,100,101,46,10,0,0,0,0,0,0,0,108,111,103,32,109,111,116,105,111,110,32,101,115,116,105,109,97,116,105,111,110,0,0,0,101,110,99,111,100,101,100,32,102,114,97,109,101,32,116,111,111,32,108,97,114,103,101,10,0,0,0,0,0,0,0,0,77,80,69,71,52,32,80,84,83,58,32,37,108,108,100,10,0,0,0,0,0,0,0,0,100,105,115,112,111,115,105,116,105,111,110,0,0,0,0,0,101,114,114,111,114,32,100,99,10,0,0,0,0,0,0,0,114,111,119,95,105,110,116,101,114,108,101,97,118,101,100,95,114,108,0,0,0,0,0,0,69,114,114,111,114,32,112,97,114,115,105,110,103,32,111,112,116,105,111,110,32,39,37,115,39,32,119,105,116,104,32,118,97,108,117,101,32,39,37,115,39,46,10,0,0,0,0,0,84,105,109,101,32,116,111,32,115,112,101,110,100,32,101,110,99,111,100,105,110,103,44,32,105,110,32,109,105,99,114,111,115,101,99,111,110,100,115,46,0,0,0,0,0,0,0,0,78,101,119,32,65,103,101,0,116,111,111,32,109,97,110,121,32,116,104,114,101,97,100,115,47,115,108,105,99,101,115,32,37,100,44,32,114,101,100,117,99,105,110,103,32,116,111,32,37,100,10,0,0,0,0,0,116,105,116,108,101,0,0,0,87,77,47,69,110,99,111,100,101,100,66,121,0,0,0,0,80,97,99,107,101,116,32,110,111,116,32,101,110,100,105,110,103,32,97,116,32,97,32,49,54,45,98,105,116,32,98,111,117,110,100,97,114,121,0,0,65,73,70,70,0,0,0,0,65,117,116,111,100,101,115,107,32,65,110,105,109,97,116,111,114,32,70,108,105,99,32,118,105,100,101,111,0,0,0,0,65,68,84,83,32,109,117,120,101,114,0,0,0,0,0,0,83,112,101,101,99,104,0,0,52,52,52,112,49,54,0,0,67,97,110,110,111,116,32,115,101,108,101,99,116,32,99,104,97,110,110,101,108,32,108,97,121,111,117,116,32,102,111,114,32,116,104,101,32,108,105,110,107,32,98,101,116,119,101,101,110,32,102,105,108,116,101,114,115,32,37,115,32,97,110,100,32,37,115,46,10,0,0,0,82,73,70,70,0,0,0,0,32,40,111,114,105,103,105,110,97,108,41,0,0,0,0,0,67,104,97,110,110,101,108,115,32,100,105,102,102,101,114,44,32,116,104,105,115,32,98,108,111,99,107,58,32,37,105,44,32,104,101,97,100,101,114,32,98,108,111,99,107,58,32,37,105,10,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,102,105,108,101,32,97,108,108,111,99,97,116,105,111,110,32,116,97,98,108,101,32,100,101,112,116,104,32,40,37,108,108,105,32,98,121,116,101,115,41,10,0,0,0,116,105,109,101,95,115,116,111,112,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,118,97,100,97,95,87,101,115,116,0,0,0,77,80,69,71,49,87,65,86,69,70,79,82,77,65,84,69,88,32,117,110,100,101,114,102,108,111,119,10,0,0,0,0,87,69,66,86,84,84,10,0,10,13,9,32,0,0,0,0,119,97,118,95,119,114,105,116,101,95,112,97,99,107,101,116,58,32,78,79,80,84,83,10,0,0,0,0,0,0,0,0,101,110,99,111,100,101,100,95,98,121,0,0,0,0,0,0,77,111,100,101,32,110,111,116,32,115,117,112,111,114,116,101,100,58,32,37,100,32,72,122,44,32,37,100,32,107,98,47,115,46,10,0,0,0,0,0,68,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,115,111,120,0,0,0,0,0,70,111,114,109,97,116,32,37,115,32,112,114,111,98,101,100,32,119,105,116,104,32,115,105,122,101,61,37,100,32,97,110,100,32,115,99,111,114,101,61,37,100,10,0,0,0,0,0,44,32,37,100,32,120,32,37,100,0,0,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,34,99,97,112,116,105,111,110,115,34,0,0,0,0,0,0,97,117,100,105,111,32,102,105,102,111,32,116,111,111,32,115,109,97,108,108,32,116,111,32,109,117,120,32,97,117,100,105,111,32,101,115,115,101,110,99,101,10,0,0,0,0,0,0,67,108,105,112,105,110,103,32,108,101,110,32,37,100,10,0,65,115,115,101,114,116,105,111,110,32,37,115,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,10,0,0,0,91,69,78,68,32,73,78,70,79,82,77,65,84,73,79,78,93,0,0,0,0,0,0,0,37,105,32,115,97,109,112,108,101,115,32,105,110,32,68,84,83,32,102,114,97,109,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,32,73,115,76,105,118,101,61,34,116,114,117,101,34,32,76,111,111,107,65,104,101,97,100,70,114,97,103,109,101,110,116,67,111,117,110,116,61,34,37,100,34,32,68,86,82,87,105,110,100,111,119,76,101,110,103,116,104,61,34,48,34,0,0,0,10,83,77,74,80,69,71,0,0,0,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,118,97,100,97,95,67,101,110,116,114,97,108,0,0,0,0,0,0,0,0,47,46,102,102,109,112,101,103,0,0,0,0,0,0,0,0,69,109,112,116,121,32,102,114,97,109,101,32,115,112,101,99,105,102,105,99,97,116,105,111,110,32,105,110,32,102,114,97,109,101,32,108,105,115,116,32,37,115,10,0,0,0,0,0,115,111,120,0,0,0,0,0,115,111,108,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,118,97,100,97,95,69,97,115,116,0,0,0,115,109,117,115,104,0,0,0,80,67,83,95,78,65,68,56,51,95,78,101,98,114,97,115,107,97,0,0,0,0,0,0,116,121,112,101,32,37,100,44,32,108,101,110,32,37,100,10,0,0,0,0,0,0,0,0,101,110,99,111,100,101,114,32,45,62,32,116,121,112,101,58,97,117,100,105,111,32,112,107,116,95,112,116,115,58,37,115,32,112,107,116,95,112,116,115,95,116,105,109,101,58,37,115,32,112,107,116,95,100,116,115,58,37,115,32,112,107,116,95,100,116,115,95,116,105,109,101,58,37,115,10,0,0,0,0,99,111,109,112,114,101,115,115,105,111,110,0,0,0,0,0,80,67,83,95,78,65,68,56,51,95,77,111,110,116,97,110,97,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,83,116,95,67,114,111,105,120,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,80,117,101,114,116,111,95,82,105,99,111,0,0,0,80,67,83,95,78,65,68,50,55,95,87,121,111,109,105,110,103,95,87,101,115,116,0,0,115,109,111,111,116,104,115,116,114,101,97,109,105,110,103,0,80,67,83,95,78,65,68,50,55,95,87,121,111,109,105,110,103,95,87,95,67,101,110,0,121,117,118,97,52,52,52,112,49,48,108,101,0,0,0,0,77,101,100,105,117,109,83,101,97,71,114,101,101,110,0,0,104,105,103,104,95,115,104,105,98,97,116,97,0,0,0,0,116,114,121,32,105,110,99,114,101,97,115,105,110,103,32,116,97,114,103,101,116,32,98,105,116,114,97,116,101,32,111,114,32,105,110,99,114,101,97,115,105,110,103,32,113,112,95,109,97,120,32,40,99,117,114,114,101,110,116,108,121,32,37,100,41,10,0,0,0,0,0,0,112,114,111,102,105,108,101,32,105,115,32,111,112,116,105,111,110,97,108,59,32,120,50,54,52,32,100,101,102,97,117,108,116,115,32,116,111,32,104,105,103,104,10,0,0,0,0,0,115,109,106,112,101,103,0,0,83,117,98,116,105,116,108,101,115,32,112,97,99,107,101,116,32,105,115,32,116,111,111,32,98,105,103,32,102,111,114,32,114,101,99,111,100,105,110,103,10,0,0,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,121,111,109,105,110,103,95,69,95,67,101,110,0,71,67,83,95,68,111,117,97,108,97,0,0,0,0,0,0,99,104,114,111,109,97,45,113,112,45,111,102,102,115,101,116,0,0,0,0,0,0,0,0,108,111,103,0,0,0,0,0,48,0,0,0,0,0,0,0,109,121,32,103,117,101,115,115,32,105,115,32,37,100,32,98,105,116,115,32,59,41,10,0,101,114,114,111,114,32,121,61,37,100,32,120,61,37,100,10,0,0,0,0,0,0,0,0,98,97,100,32,118,97,108,117,101,32,102,111,114,32,39,37,115,39,58,32,39,37,115,39,10,0,0,0,0,0,0,0,100,101,97,100,108,105,110,101,0,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,10,0,0,0,0,0,0,102,108,105,99,0,0,0,0,72,117,109,111,117,114,0,0,32,40,100,117,98,41,0,0,114,101,99,111,114,100,32,111,114,32,116,114,97,110,115,99,111,100,101,32,115,116,111,112,32,116,105,109,101,0,0,0,80,67,83,95,78,65,68,50,55,95,87,121,111,109,105,110,103,95,69,97,115,116,0,0,115,109,106,112,101,103,0,0,115,109,107,0,0,0,0,0,80,67,83,95,78,65,68,50,55,95,87,105,115,99,111,110,115,105,110,95,83,111,117,116,104,0,0,0,0,0,0,0,37,115,37,115,47,37,115,46,102,102,112,114,101,115,101,116,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,102,111,114,32,37,115,32,119,97,115,32,37,115,32,119,104,105,99,104,32,105,115,32,110,111,116,32,119,105,116,104,105,110,32,37,102,32,45,32,37,102,10,0,0,0,0,69,120,112,101,99,116,101,100,32,110,117,109,98,101,114,32,102,111,114,32,37,115,32,98,117,116,32,102,111,117,110,100,58,32,37,115,10,0,0,0,0,1,2,3,4,5,6,7,8,8,9,9,10,10,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28,0,1,2,3,4,4,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,0,0,16,17,18,18,19,19,20,20,20,20,21,21,21,21,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,2,0,0,0,255,255,255,255,72,120,21,0,0,0,0,0,72,120,21,0,0,0,0,0,88,87,10,0,0,0,0,0,88,14,20,0,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,12,0,0,0,13,0,0,0,255,255,255,255,0,0,0,0,144,199,25,0,0,0,0,0,0,94,20,0,0,0,0,0,1,0,0,0,255,255,255,255,0,94,20,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,96,120,21,0,168,125,21,0,0,0,0,0,0,0,0,0,7,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,128,128,21,0,200,117,21,0,136,136,31,0,88,136,31,0,0,0,0,0,0,0,0,0,200,212,12,0,0,0,0,0,2,0,0,0,255,255,255,255,128,128,21,0,0,0,0,0,64,127,21,0,0,0,0,0,2,0,0,0,255,255,255,255,42,0,0,0,255,255,255,255,2,0,0,0,41,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,4,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,80,127,18,0,16,128,18,0,0,0,0,0,0,0,0,0,7,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,208,127,21,0,0,0,0,0,208,127,21,0,0,0,0,0,3,0,0,0,255,255,255,255,136,173,36,0,112,0,0,0,208,132,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,168,236,33,0,112,0,0,0,208,132,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,128,21,0,200,117,21,0,0,0,0,0,0,0,0,0,0,199,25,0,0,0,0,0,8,138,21,0,0,0,0,0,8,138,21,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,200,117,21,0,0,0,0,0,112,199,25,0,128,128,21,0,200,117,21,0,0,0,0,0,6,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,43,1,0,0,255,255,255,255,1,0,0,0,255,255,255,255,42,0,0,0,255,255,255,255,0,0,0,0,55,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,6,0,0,0,33,0,0,0,82,0,0,0,84,0,0,0,86,0,0,0,58,1,0,0,60,1,0,0,8,0,0,0,32,0,0,0,35,0,0,0,44,1,0,0,43,1,0,0,61,1,0,0,66,0,0,0,70,0,0,0,72,0,0,0,46,1,0,0,48,1,0,0,54,0,0,0,80,0,0,0,74,0,0,0,50,1,0,0,52,1,0,0,56,0,0,0,76,0,0,0,78,0,0,0,54,1,0,0,56,1,0,0,58,0,0,0,92,0,0,0,98,0,0,0,104,0,0,0,94,0,0,0,100,0,0,0,106,0,0,0,96,0,0,0,102,0,0,0,108,0,0,0,2,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,200,117,21,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,208,169,25,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,0,0,0,255,255,255,255,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,199,25,0,0,0,0,0,0,0,0,0,255,255,255,255,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,16,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,224,151,20,0,0,0,0,0,7,6,8,5,9,4,10,3,11,2,12,1,13,0,14,0,6,5,7,4,8,3,9,2,10,1,11,0,12,0,0,0,2,1,3,0,4,0,0,0,1,0,0,0,255,255,255,255,6,5,7,4,8,3,9,2,10,1,11,0,12,0,0,0,1,0,0,0,255,255,255,255,144,169,25,0,0,0,0,0,7,0,0,0,6,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,5,4,6,3,7,2,8,1,9,0,10,0,0,0,0,0,8,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,11,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,30,0,0,0,28,0,0,0,27,0,0,0,29,0,0,0,2,0,0,0,3,0,0,0,43,0,0,0,44,0,0,0,47,0,0,0,48,0,0,0,45,0,0,0,46,0,0,0,49,0,0,0,50,0,0,0,22,0,0,0,19,0,0,0,24,0,0,0,21,0,0,0,11,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,8,0,0,0,255,255,255,255,1,0,2,0,0,0,0,0,8,0,0,0,255,255,255,255,2,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,16,0,0,0,0,0,0,0,78,0,0,0,255,255,255,255,43,1,0,0,255,255,255,255,5,0,0,0,255,255,255,255,74,0,0,0,255,255,255,255,2,0,0,0,28,0,0,0,4,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,7,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,11,0,0,0,8,0,0,0,66,0,0,0,32,0,0,0,10,0,0,0,9,0,0,0,0,0,0,0,4,0,0,0,33,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,42,0,0,0,28,0,0,0,36,1,0,0,255,255,255,255,0,0,0,0,4,3,5,2,6,1,7,0,8,0,0,0,0,0,0,0,144,199,25,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,6,0,0,0,0,0,0,7,6,0,0,0,0,0,0,15,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,30,0,0,0,46,0,0,0,8,0,0,0,11,0,0,0,255,255,255,255,5,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,12,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,3,0,0,0,11,0,0,0,8,0,0,0,9,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,5,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,5,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,28,0,0,0,42,0,0,0,41,0,0,0,36,1,0,0,35,1,0,0,32,0,0,0,31,0,0,0,8,0,0,0,255,255,255,255,128,187,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,4,3,5,2,6,1,7,0,8,0,0,0,0,0,0,0,6,0,0,0,255,255,255,255,64,31,0,0,0,0,0,0,42,0,0,0,255,255,255,255,2,0,0,0,45,0,0,0,27,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,74,0,0,0,78,0,0,0,102,0,0,0,255,255,255,255,74,0,0,0,255,255,255,255,8,0,0,0,31,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,28,0,0,0,41,0,0,0,35,1,0,0,11,0,0,0,8,0,0,0,66,0,0,0,31,0,0,0,10,0,0,0,255,255,255,255,2,0,0,0,22,0,0,0,19,0,0,0,24,0,0,0,21,0,0,0,8,0,0,0,11,0,0,0,10,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,28,0,0,0,41,0,0,0,35,1,0,0,8,0,0,0,66,0,0,0,31,0,0,0,10,0,0,0,255,255,255,255,0,0,0,0,2,1,3,0,4,0,0,0,4,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,46,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,2,1,3,0,4,0,0,0,4,0,0,0,255,255,255,255,68,172,0,0,128,187,0,0,0,125,0,0,34,86,0,0,192,93,0,0,128,62,0,0,0,0,0,0,0,0,0,0,68,172,0,0,128,187,0,0,0,125,0,0,34,86,0,0,192,93,0,0,128,62,0,0,0,0,0,0,0,0,0,0,224,151,20,0,0,0,0,0,8,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,12,0,0,0,13,0,0,0,14,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,3,0,0,0,30,0,0,0,42,1,0,0,12,0,0,0,14,0,0,0,13,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,255,255,255,255,1,0,2,0,0,0,0,0,0,0,0,0,35,0,0,0,255,255,255,255,0,0,0,0,3,0,0,0,255,255,255,255,3,0,0,0,2,0,0,0,8,0,0,0,32,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,5,0,0,0,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,4,0,0,0,2,0,0,0,30,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2637984);
/* memory initializer */ allocate([4,0,0,0,255,255,255,255,22,0,0,0,19,0,0,0,24,0,0,0,21,0,0,0,8,0,0,0,11,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,56,7,39,0,112,0,0,0,208,132,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,1,0,0,0,2,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,35,0,0,0,44,1,0,0,5,0,0,0,43,1,0,0,33,0,0,0,4,0,0,0,7,0,0,0,6,0,0,0,42,1,0,0,30,0,0,0,54,0,0,0,56,0,0,0,58,0,0,0,76,0,0,0,80,0,0,0,70,0,0,0,72,0,0,0,74,0,0,0,78,0,0,0,108,0,0,0,106,0,0,0,104,0,0,0,102,0,0,0,100,0,0,0,98,0,0,0,96,0,0,0,94,0,0,0,92,0,0,0,32,0,0,0,8,0,0,0,84,0,0,0,86,0,0,0,58,1,0,0,60,1,0,0,255,255,255,255,8,0,0,0,255,255,255,255,7,0,0,0,4,0,0,0,0,0,0,0,255,255,255,255,8,0,0,0,2,0,0,0,28,0,0,0,29,0,0,0,32,0,0,0,31,0,0,0,42,0,0,0,41,0,0,0,36,1,0,0,35,1,0,0,86,0,0,0,85,0,0,0,58,1,0,0,57,1,0,0,255,255,255,255,0,0,0,0,4,0,0,0,74,0,0,0,255,255,255,255,0,0,0,0,4,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,224,151,20,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,2,0,0,0,8,0,0,0,255,255,255,255,0,0,0,0,30,0,0,0,3,0,0,0,44,0,0,0,46,0,0,0,62,0,0,0,22,0,0,0,19,0,0,0,24,0,0,0,21,0,0,0,8,0,0,0,11,0,0,0,10,0,0,0,255,255,255,255,0,0,0,0,17,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,5,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,32,138,21,0,0,0,0,0,208,138,21,0,0,0,0,0,128,128,21,0,200,117,21,0,0,0,0,0,0,0,0,0,200,117,21,0,0,0,0,0,200,117,21,0,0,0,0,0,0,0,0,0,255,255,255,255,200,117,21,0,136,136,31,0,0,0,0,0,0,0,0,0,112,39,19,0,0,0,0,0,112,39,19,0,0,0,0,0,2,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,8,0,0,0,3,0,0,0,255,255,255,255,0,0,0,0,6,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,255,255,255,255,224,151,20,0,0,0,0,0,32,120,21,0,48,120,21,0,0,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,112,48,32,0,112,0,0,0,208,132,11,0,100,66,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,199,25,0,128,128,21,0,200,117,21,0,0,0,0,0,120,50,54,52,95,119,101,105,103,104,116,101,100,95,112,114,101,100,95,105,110,105,116,0,120,50,54,52,95,115,108,105,99,101,116,121,112,101,95,97,110,97,108,121,115,101,0,0,120,50,54,52,95,115,108,105,99,101,95,104,101,97,100,101,114,95,119,114,105,116,101,0,120,50,54,52,95,114,101,102,101,114,101,110,99,101,95,98,117,105,108,100,95,108,105,115,116,0,0,0,0,0,0,0,120,50,54,52,95,114,99,95,97,110,97,108,121,115,101,95,115,108,105,99,101,0,0,0,120,50,54,52,95,114,97,116,101,99,111,110,116,114,111,108,95,115,116,97,114,116,0,0,120,50,54,52,95,114,97,116,101,99,111,110,116,114,111,108,95,110,101,119,0,0,0,0,120,50,54,52,95,111,112,101,110,99,108,95,97,108,108,111,99,95,108,111,99,107,101,100,0,0,0,0,0,0,0,0,120,50,54,52,95,109,98,95,97,110,97,108,121,115,101,95,105,110,116,101,114,95,112,49,54,120,49,54,0,0,0,0,120,50,54,52,95,109,97,99,114,111,98,108,111,99,107,95,99,97,99,104,101,95,114,101,99,116,0,0,0,0,0,0,120,50,54,52,95,109,97,99,114,111,98,108,111,99,107,95,98,105,112,114,101,100,95,105,110,105,116,0,0,0,0,0,120,50,54,52,95,109,97,99,114,111,98,108,111,99,107,95,97,110,97,108,121,115,101,0,120,50,54,52,95,108,111,111,107,97,104,101,97,100,95,115,104,105,102,116,0,0,0,0,120,50,54,52,95,102,114,97,109,101,95,115,104,105,102,116,0,0,0,0,0,0,0,0,120,50,54,52,95,102,114,97,109,101,95,112,117,115,104,95,117,110,117,115,101,100,0,0,120,50,54,52,95,102,114,97,109,101,95,112,117,115,104,95,98,108,97,110,107,95,117,110,117,115,101,100,0,0,0,0,120,50,54,52,95,102,114,97,109,101,95,112,111,112,0,0,120,50,54,52,95,101,110,99,111,100,101,114,95,99,108,111,115,101,0,0,0,0,0,0,120,50,54,52,95,99,97,98,97,99,95,56,120,56,95,109,118,100,0,0,0,0,0,0,120,50,54,52,95,99,97,98,97,99,95,56,120,56,95,109,118,100,0,0,0,0,0,0,119,114,105,116,101,95,117,110,99,111,109,112,114,101,115,115,101,100,95,104,101,97,100,101,114,0,0,0,0,0,0,0,119,114,105,116,101,95,115,117,112,101,114,102,114,97,109,101,95,105,110,100,101,120,0,0,119,114,105,116,101,95,114,101,102,95,102,114,97,109,101,115,0,0,0,0,0,0,0,0,119,114,105,116,101,95,112,114,111,102,105,108,101,0,0,0,119,114,105,116,101,95,112,97,114,116,105,116,105,111,110,0,119,114,105,116,101,95,109,118,95,117,112,100,97,116,101,0,119,114,105,116,101,95,109,111,100,101,115,95,115,98,0,0,119,114,105,116,101,95,109,111,100,101,115,95,98,0,0,0,119,114,105,116,101,95,105,110,116,101,114,95,109,111,100,101,0,0,0,0,0,0,0,0,119,114,105,116,101,95,99,111,109,112,114,101,115,115,101,100,95,104,101,97,100,101,114,0,118,112,57,95,120,102,111,114,109,95,113,117,97,110,116,0,118,112,57,95,119,111,114,107,101,114,95,115,121,110,99,0,118,112,57,95,119,111,114,107,101,114,95,114,101,115,101,116,0,0,0,0,0,0,0,0,118,112,57,95,119,111,114,107,101,114,95,101,110,100,0,0,118,112,57,95,118,97,113,95,115,101,103,109,101,110,116,95,105,100,0,0,0,0,0,0,118,112,57,95,118,97,113,95,114,100,109,117,108,116,95,114,97,116,105,111,0,0,0,0,118,112,57,95,118,97,113,95,105,110,118,95,113,95,114,97,116,105,111,0,0,0,0,0,118,112,57,95,117,112,100,97,116,101,95,109,98,103,114,97,112,104,95,115,116,97,116,115,0,0,0,0,0,0,0,0,118,112,57,95,115,101,116,117,112,95,109,97,115,107,0,0,118,112,57,95,115,101,116,95,115,105,122,101,95,108,105,116,101,114,97,108,0,0,0,0,118,112,57,95,115,101,116,95,115,101,103,100,97,116,97,0,118,112,57,95,115,101,116,95,105,110,116,101,114,110,97,108,95,115,105,122,101,0,0,0,118,112,57,95,114,101,97,108,108,111,99,95,102,114,97,109,101,95,98,117,102,102,101,114,0,0,0,0,0,0,0,0,118,112,57,95,114,100,95,112,105,99,107,95,105,110,116,101,114,95,109,111,100,101,95,115,117,98,56,120,56,0,0,0,118,112,57,95,114,100,95,112,105,99,107,95,105,110,116,101,114,95,109,111,100,101,95,115,98,0,0,0,0,0,0,0,118,112,57,95,112,114,101,100,105,99,116,95,105,110,116,114,97,95,98,108,111,99,107,0,118,112,57,95,108,101,102,116,95,98,108,111,99,107,95,109,111,100,101,0,0,0,0,0,118,112,57,95,103,101,116,95,121,95,115,115,101,0,0,0,118,112,57,95,103,101,116,95,116,105,108,101,95,110,95,98,105,116,115,0,0,0,0,0,118,112,57,95,103,101,116,95,115,101,103,109,101,110,116,95,105,100,0,0,0,0,0,0,118,112,57,95,103,101,116,95,114,101,102,101,114,101,110,99,101,95,109,111,100,101,95,99,111,110,116,101,120,116,0,0,118,112,57,95,103,101,116,95,112,114,101,100,95,99,111,110,116,101,120,116,95,115,105,110,103,108,101,95,114,101,102,95,112,50,0,0,0,0,0,0,118,112,57,95,103,101,116,95,112,114,101,100,95,99,111,110,116,101,120,116,95,115,105,110,103,108,101,95,114,101,102,95,112,49,0,0,0,0,0,0,118,112,57,95,103,101,116,95,112,114,101,100,95,99,111,110,116,101,120,116,95,99,111,109,112,95,114,101,102,95,112,0,118,112,57,95,103,101,116,95,105,110,116,101,114,112,95,107,101,114,110,101,108,0,0,0,118,112,57,95,103,101,116,95,101,110,116,114,111,112,121,95,99,111,110,116,101,120,116,115,0,0,0,0,0,0,0,0,118,112,57,95,103,101,116,95,99,111,109,112,114,101,115,115,101,100,95,100,97,116,97,0,118,112,57,95,102,114,101,101,95,105,110,116,101,114,110,97,108,95,102,114,97,109,101,95,98,117,102,102,101,114,115,0,118,112,57,95,100,101,99,95,98,117,105,108,100,95,105,110,116,101,114,95,112,114,101,100,105,99,116,111,114,115,95,115,98,0,0,0,0,0,0,0,118,112,57,95,99,121,99,108,105,99,95,114,101,102,114,101,115,104,95,115,101,116,117,112,0,0,0,0,0,0,0,0,118,112,57,95,99,111,115,116,95,116,111,107,101,110,115,95,115,107,105,112,0,0,0,0,118,112,57,95,99,111,110,118,111,108,118,101,56,95,97,118,103,95,99,0,0,0,0,0,118,112,57,95,99,111,110,100,95,112,114,111,98,95,100,105,102,102,95,117,112,100,97,116,101,0,0,0,0,0,0,0,118,112,57,95,99,104,97,110,103,101,95,99,111,110,102,105,103,0,0,0,0,0,0,0,118,112,57,95,97,112,112,101,110,100,95,115,117,98,56,120,56,95,109,118,115,95,102,111,114,95,105,100,120,0,0,0,118,112,57,95,97,108,108,111,99,95,105,110,116,101,114,110,97,108,95,102,114,97,109,101,95,98,117,102,102,101,114,115,0,0,0,0,0,0,0,0,118,112,57,95,97,98,111,118,101,95,98,108,111,99,107,95,109,111,100,101,0,0,0,0,118,112,56,95,121,118,49,50,95,101,120,116,101,110,100,95,102,114,97,109,101,95,98,111,114,100,101,114,115,95,99,0,118,112,56,95,114,101,99,101,105,118,101,95,114,97,119,95,102,114,97,109,101,0,0,0,118,112,56,95,108,111,111,107,97,104,101,97,100,95,112,101,101,107,0,0,0,0,0,0,118,112,56,95,103,101,116,95,99,111,109,112,114,101,115,115,101,100,95,100,97,116,97,0,118,112,56,95,100,101,110,111,105,115,101,114,95,102,114,101,101,0,0,0,0,0,0,0,118,112,56,95,100,101,110,111,105,115,101,114,95,97,108,108,111,99,97,116,101,0,0,0,118,112,56,95,99,111,115,116,95,109,118,95,114,101,102,0,118,112,56,95,99,97,108,99,95,114,101,102,95,102,114,97,109,101,95,99,111,115,116,115,0,0,0,0,0,0,0,0,117,112,100,97,116,101,95,115,116,97,116,101,0,0,0,0,117,112,100,97,116,101,95,114,101,102,101,114,101,110,99,101,95,102,114,97,109,101,115,0,117,112,100,97,116,101,95,108,97,121,101,114,95,99,111,110,116,101,120,116,115,0,0,0,117,112,100,97,116,101,95,99,111,101,102,95,112,114,111,98,115,95,99,111,109,109,111,110,0,0,0,0,0,0,0,0,116,114,101,101,95,116,111,95,110,111,100,101,0,0,0,0,116,111,107,101,110,105,122,101,49,115,116,95,111,114,100,101,114,95,98,0,0,0,0,0,116,101,109,112,111,114,97,108,95,102,105,108,116,101,114,95,105,116,101,114,97,116,101,95,99,0,0,0,0,0,0,0,115,101,116,117,112,95,116,111,107,101,110,95,100,101,99,111,100,101,114,0,0,0,0,0,115,101,116,117,112,95,105,110,116,101,114,95,102,114,97,109,101,0,0,0,0,0,0,0,115,101,116,95,118,116,95,112,97,114,116,105,116,105,111,110,105,110,103,0,0,0,0,0,115,101,116,95,115,111,117,114,99,101,95,118,97,114,95,98,97,115,101,100,95,112,97,114,116,105,116,105,111,110,0,0,115,101,116,95,115,101,103,109,101,110,116,95,105,100,0,0,115,101,116,95,111,102,102,115,101,116,115,0,0,0,0,0,115,101,116,95,102,105,120,101,100,95,112,97,114,116,105,116,105,111,110,105,110,103,0,0,114,101,115,105,100,117,101,95,101,110,99,111,100,101,0,0,114,101,102,95,102,114,97,109,101,95,116,111,95,118,112,57,95,114,101,102,114,97,109,101,0,0,0,0,0,0,0,0,114,101,97,100,121,95,114,101,115,105,100,117,101,0,0,0,114,101,97,100,95,114,101,102,95,102,114,97,109,101,115,0,114,100,95,117,115,101,95,112,97,114,116,105,116,105,111,110,0,0,0,0,0,0,0,0,114,100,95,112,105,99,107,95,112,97,114,116,105,116,105,111,110,0,0,0,0,0,0,0,114,100,95,112,105,99,107,95,105,110,116,114,97,52,120,52,98,108,111,99,107,0,0,0,114,99,95,112,105,99,107,95,113,95,97,110,100,95,98,111,117,110,100,115,95,116,119,111,95,112,97,115,115,0,0,0,114,99,95,112,105,99,107,95,113,95,97,110,100,95,98,111,117,110,100,115,95,111,110,101,95,112,97,115,115,95,118,98,114,0,0,0,0,0,0,0,114,99,95,112,105,99,107,95,113,95,97,110,100,95,98,111,117,110,100,115,95,111,110,101,95,112,97,115,115,95,99,98,114,0,0,0,0,0,0,0,112,117,116,95,118,101,99,116,111,114,0,0,0,0,0,0,112,114,111,98,95,100,105,102,102,95,117,112,100,97,116,101,0,0,0,0,0,0,0,0,112,111,112,0,0,0,0,0,112,111,112,0,0,0,0,0,112,97,114,116,105,116,105,111,110,95,112,108,97,110,101,95,99,111,110,116,101,120,116,0,112,97,114,116,105,116,105,111,110,95,112,108,97,110,101,95,99,111,110,116,101,120,116,0,112,97,114,116,105,116,105,111,110,95,112,108,97,110,101,95,99,111,110,116,101,120,116,0,112,97,114,115,101,95,115,117,112,101,114,102,114,97,109,101,95,105,110,100,101,120,0,0,112,97,99,107,95,105,110,116,101,114,95,109,111,100,101,95,109,118,115,0,0,0,0,0,111,117,116,112,117,116,95,112,97,99,107,101,116,0,0,0,111,112,116,105,109,105,122,101,95,98,0,0,0,0,0,0,110,111,110,114,100,95,117,115,101,95,112,97,114,116,105,116,105,111,110,0,0,0,0,0,110,111,110,114,100,95,112,105,99,107,95,112,97,114,116,105,116,105,111,110,0,0,0,0,109,112,101,103,95,109,117,120,95,101,110,100,0,0,0,0,109,111,100,101,108,95,114,100,95,102,111,114,95,115,98,95,121,95,116,120,0,0,0,0,109,105,95,98,117,102,95,115,104,105,102,116,0,0,0,0,105,110,118,101,114,115,101,95,116,114,97,110,115,102,111,114,109,95,98,108,111,99,107,0,105,110,116,114,97,95,115,117,112,101,114,95,98,108,111,99,107,95,121,114,100,0,0,0,105,110,116,101,114,95,115,117,112,101,114,95,98,108,111,99,107,95,121,114,100,0,0,0,105,110,105,116,95,115,99,97,110,95,110,101,105,103,104,98,111,114,115,0,0,0,0,0,105,110,105,116,95,112,97,115,115,50,0,0,0,0,0,0,105,110,105,116,95,112,97,115,115,50,0,0,0,0,0,0,105,110,99,95,109,118,95,99,111,109,112,111,110,101,110,116,0,0,0,0,0,0,0,0,103,101,116,95,116,120,95,112,114,111,98,115,0,0,0,0,103,101,116,95,116,120,95,112,114,111,98,115,0,0,0,0,103,101,116,95,116,120,95,112,114,111,98,115,0,0,0,0,103,101,116,95,116,120,95,99,111,117,110,116,115,0,0,0,103,101,116,95,116,120,95,99,111,117,110,116,115,0,0,0,103,101,116,95,115,117,98,115,105,122,101,0,0,0,0,0,103,101,116,95,115,117,98,115,105,122,101,0,0,0,0,0,103,101,116,95,115,117,98,115,105,122,101,0,0,0,0,0,103,101,116,95,115,98,95,112,97,114,116,105,116,105,111,110,105,110,103,0,0,0,0,0,103,101,116,95,115,98,95,105,110,100,101,120,0,0,0,0,103,101,116,95,113,109,105,110,109,97,120,0,0,0,0,0,103,101,116,95,112,108,97,110,101,95,98,108,111,99,107,95,115,105,122,101,0,0,0,0,103,101,116,95,112,108,97,110,101,95,98,108,111,99,107,95,115,105,122,101,0,0,0,0,103,101,116,95,112,108,97,110,101,95,98,108,111,99,107,95,115,105,122,101,0,0,0,0,103,101,116,95,112,108,97,110,101,95,98,108,111,99,107,95,115,105,122,101,0,0,0,0,103,101,116,95,112,108,97,110,101,95,98,108,111,99,107,95,115,105,122,101,0,0,0,0,103,101,116,95,112,108,97,110,101,95,98,108,111,99,107,95,115,105,122,101,0,0,0,0,103,101,116,95,112,108,97,110,101,95,98,108,111,99,107,95,115,105,122,101,0,0,0,0,103,101,116,95,102,114,101,101,95,102,98,0,0,0,0,0,103,101,116,95,102,114,101,101,95,102,98,0,0,0,0,0,103,101,116,95,102,114,101,101,95,102,98,0,0,0,0,0,103,101,116,95,101,110,116,114,111,112,121,95,99,111,110,116,101,120,116,0,0,0,0,0,103,101,116,95,101,110,116,114,111,112,121,95,99,111,110,116,101,120,116,0,0,0,0,0,103,101,116,95,98,108,111,99,107,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,103,101,116,95,98,108,111,99,107,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,102,117,108,108,95,112,105,120,101,108,95,109,111,116,105,111,110,95,115,101,97,114,99,104,0,0,0,0,0,0,0,0,102,108,117,115,104,95,112,97,99,107,101,116,0,0,0,0,102,108,111,111,114,95,101,110,99,111,100,101,0,0,0,0,102,105,110,100,95,105,110,95,115,99,97,110,0,0,0,0,102,105,108,108,95,116,111,107,101,110,95,99,111,115,116,115,0,0,0,0,0,0,0,0,102,105,108,108,95,109,111,100,101,95,105,110,102,111,95,115,98,0,0,0,0,0,0,0,102,102,95,114,97,116,101,95,101,115,116,105,109,97,116,101,95,113,115,99,97,108,101,0,102,102,95,114,97,116,101,95,99,111,110,116,114,111,108,95,105,110,105,116,0,0,0,0,102,100,99,116,95,114,111,117,110,100,95,115,104,105,102,116,0,0,0,0,0,0,0,0,101,120,116,101,110,100,95,102,114,97,109,101,0,0,0,0,101,110,99,111,100,101,95,116,105,108,101,115,0,0,0,0,101,110,99,111,100,101,95,115,98,95,114,116,0,0,0,0,101,110,99,111,100,101,95,115,98,0,0,0,0,0,0,0,101,110,99,111,100,101,95,110,111,110,114,100,95,115,98,95,114,111,119,0,0,0,0,0,101,110,99,111,100,101,95,109,118,95,99,111,109,112,111,110,101,110,116,0,0,0,0,0,101,110,99,111,100,101,95,102,114,97,109,101,95,105,110,116,101,114,110,97,108,0,0,0,101,110,99,111,100,101,95,98,108,111,99,107,95,105,110,116,114,97,0,0,0,0,0,0,101,110,99,111,100,101,95,98,108,111,99,107,0,0,0,0,100,101,99,111,100,101,114,95,100,101,99,111,100,101,0,0,100,101,99,111,100,101,95,116,105,108,101,115,95,109,116,0,100,101,99,111,100,101,95,116,105,108,101,115,0,0,0,0,100,101,99,111,100,101,95,112,97,114,116,105,116,105,111,110,0,0,0,0,0,0,0,0,100,101,98,117,103,95,99,104,101,99,107,95,102,114,97,109,101,95,99,111,117,110,116,115,0,0,0,0,0,0,0,0,100,99,116,95,51,50,95,114,111,117,110,100,0,0,0,0,99,121,99,108,105,99,95,98,97,99,107,103,114,111,117,110,100,95,114,101,102,114,101,115,104,0,0,0,0,0,0,0,99,111,117,110,116,95,115,101,103,115,95,115,98,0,0,0,99,111,115,116,95,109,118,95,114,101,102,0,0,0,0,0,99,111,115,116,95,99,111,101,102,102,115,0,0,0,0,0,99,111,115,116,95,99,111,101,102,102,115,0,0,0,0,0,99,111,110,118,111,108,118,101,0,0,0,0,0,0,0,0,99,111,110,115,116,114,97,105,110,95,99,111,112,121,95,112,97,114,116,105,116,105,111,110,105,110,103,0,0,0,0,0,99,108,97,109,112,95,109,118,95,116,111,95,117,109,118,95,98,111,114,100,101,114,95,115,98,0,0,0,0,0,0,0,99,104,111,111,115,101,95,116,120,102,109,95,115,105,122,101,95,102,114,111,109,95,114,100,0,0,0,0,0,0,0,0,99,104,111,111,115,101,95,116,120,102,109,95,115,105,122,101,95,102,114,111,109,95,109,111,100,101,108,114,100,0,0,0,99,104,101,99,107,95,98,101,115,116,95,122,101,114,111,95,109,118,0,0,0,0,0,0,99,97,108,99,95,99,111,114,114,101,99,116,105,111,110,95,102,97,99,116,111,114,0,0,98,117,105,108,100,95,105,110,116,101,114,95,112,114,101,100,105,99,116,111,114,115,95,102,111,114,95,112,108,97,110,101,115,0,0,0,0,0,0,0,97,115,102,95,114,101,97,100,95,112,97,99,107,101,116,0,97,115,102,95,112,97,114,115,101,95,112,97,99,107,101,116,0,0,0,0,0,0,0,0,83,99,97,108,101,50,82,97,116,105,111,0,0,0,0,0,83,99,97,108,101,50,82,97,116,105,111,0,0,0,0,0,83,99,97,108,101,50,82,97,116,105,111,0,0,0,0,0,2,0,0,192,3,0,0,192,4,0,0,192,5,0,0,192,6,0,0,192,7,0,0,192,8,0,0,192,9,0,0,192,10,0,0,192,11,0,0,192,12,0,0,192,13,0,0,192,14,0,0,192,15,0,0,192,16,0,0,192,17,0,0,192,18,0,0,192,19,0,0,192,20,0,0,192,21,0,0,192,22,0,0,192,23,0,0,192,24,0,0,192,25,0,0,192,26,0,0,192,27,0,0,192,28,0,0,192,29,0,0,192,30,0,0,192,31,0,0,192,0,0,0,179,1,0,0,195,2,0,0,195,3,0,0,195,4,0,0,195,5,0,0,195,6,0,0,195,7,0,0,195,8,0,0,195,9,0,0,195,10,0,0,195,11,0,0,195,12,0,0,195,13,0,0,211,14,0,0,195,15,0,0,195,0,0,12,187,1,0,12,195,2,0,12,195,3,0,12,195,4,0,12,211,0,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,14,0,14,0,24,0,39,0,40,0,41,0,58,0,100,0,141,0,179,0,219,0,24,1,102,1,184,1,17,2,184,2,184,2,17,2,184,1,102,1,24,1,219,0,179,0,141,0,100,0,58,0,41,0,40,0,39,0,24,0,14,0,14,0,244,255,18,0,41,0,64,0,112,0,198,0,99,1,98,4,98,4,99,1,198,0,112,0,64,0,41,0,18,0,244,255,252,255,30,0,137,0,70,2,70,2,137,0,30,0,252,255,234,255,183,1,183,1,234,255,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,0,130,128,0,0,0,0,0,0,128,0,0,2,130,128,0,2,128,128,0,2,130,0,0,2,0,0,0,0,128,0,0,0,2,0,0,0,130,128,0,2,130,128,0,0,2,0,0,2,2,128,0,2,128,128,0,0,0,128,0,2,0,0,0,2,2,0,0,0,2,128,0,0,2,128,0,0,130,0,0,0,130,0,0,0,128,128,0,0,128,128,0,2,2,128,0,2,128,0,0,2,0,128,0,2,0,128,0,2,128,0,0,0,0,0,0,2,2,0,0,2,130,0,0,0,0,128,0,0,128,0,0,2,130,128,0,2,0,0,0,0,128,128,0,0,130,128,0,0,0,128,0,0,0,128,0,0,2,0,0,2,128,128,0,0,128,0,0,0,130,0,0,2,0,128,0,0,2,0,0,2,0,0,0,2,2,128,0,2,130,0,0,2,130,128,0,2,128,0,0,0,128,128,0,2,2,128,0,2,0,128,0,2,2,0,0,2,130,0,0,0,130,128,0,2,2,0,0,0,2,128,0,0,2,128,0,0,0,0,0,2,128,0,0,0,130,0,0,0,0,0,0,2,128,128,0,16,64,8,64,0,64,0,64,0,64,0,0,16,64,8,0,0,0,8,0,16,0,0,0,16,0,8,64,16,64,0,64,16,0,0,64,16,64,8,64,0,64,8,64,0,0,0,64,0,64,0,64,0,0,8,0,16,0,0,0,16,0,8,64,0,64,8,0,16,0,8,0,16,64,0,64,0,0,0,0,0,0,0,64,0,64,0,0,16,64,8,0,0,0,8,64,16,0,8,0,16,0,0,64,0,0,0,0,0,64,8,0,16,64,0,0,0,64,8,64,0,0,8,64,16,64,0,0,0,0,0,0,16,64,8,0,16,0,8,64,0,0,8,0,16,64,0,64,0,0,8,64,0,64,8,64,0,64,0,0,0,0,8,64,0,64,0,64,16,0,0,0,16,64,8,64,16,64,8,0,16,0,0,0,0,64,0,0,0,0,0,64,16,64,0,0,0,64,8,64,0,0,8,0,16,0,0,64,16,0,8,0,16,64,0,64,16,0,0,64,16,0,8,0,0,64,8,0,0,0,0,0,0,64,0,64,16,64,0,0,0,0,0,64,16,0,8,64,16,64,8,64,0,64,8,0,4,1,0,0,0,1,1,4,0,0,0,0,4,0,1,4,0,1,0,4,0,0,0,0,4,1,1,0,0,1,0,4,4,0,1,0,4,0,0,4,4,0,0,4,0,0,1,0,4,1,1,4,4,0,1,0,0,0,1,4,4,1,0,0,0,0,0,4,4,0,0,0,0,1,1,4,0,1,0,0,0,1,1,0,0,0,1,4,4,0,1,4,4,1,1,0,4,1,0,4,0,1,1,0,0,0,1,0,4,1,0,4,4,0,0,0,4,1,1,4,0,1,0,0,0,0,0,4,0,1,1,4,0,0,0,4,4,0,1,0,4,1,0,0,0,0,1,0,0,1,1,4,0,1,0,4,0,0,0,0,0,1,0,0,4,0,1,0,4,1,1,4,0,1,0,4,4,0,0,4,0,1,0,0,0,0,0,0,4,0,1,4,4,1,0,4,0,0,1,0,0,0,0,4,4,1,1,4,4,0,0,0,4,1,1,0,0,1,1,0,4,0,0,4,0,0,1,4,4,1,0,4,4,1,0,0,0,0,1,4,4,1,1,0,4,0,0,0,4,0,1,4,0,1,1,0,0,16,64,128,64,16,0,128,64,16,0,128,64,0,0,0,64,16,64,0,64,0,64,128,0,0,64,128,0,16,0,128,0,0,0,0,0,16,64,0,0,16,64,0,64,16,64,128,64,0,0,128,0,0,0,0,64,0,64,0,0,0,64,128,0,0,0,128,0,16,0,0,0,0,64,0,0,16,64,128,64,0,0,0,0,0,64,0,0,16,0,128,64,16,0,0,64,0,64,128,0,0,0,128,64,16,0,0,64,0,64,0,0,16,0,0,64,16,64,0,64,16,64,128,64,0,0,128,64,0,64,0,0,0,64,128,0,16,64,0,64,16,64,128,64,0,0,128,0,0,0,0,0,0,0,0,0,16,64,0,64,16,0,0,64,0,64,0,64,0,64,128,0,0,0,128,0,16,64,128,64,16,0,128,64,16,0,128,64,0,0,0,64,16,64,128,64,0,0,128,0,0,0,128,0,16,0,0,0,0,64,128,0,16,0,128,64,16,64,0,64,0,64,128,0,16,0,128,64,16,0,0,0,0,64,0,0,16,64,128,64,0,0,0,0,0,64,0,0,16,0,0,64,16,64,0,128,0,0,0,128,0,4,1,0,0,4,1,128,0,0,33,0,0,4,0,128,0,0,0,0,0,0,32,0,0,4,1,128,0,4,32,0,0,4,0,128,0,0,1,128,0,4,32,128,0,0,33,0,0,4,33,128,0,4,0,0,0,0,32,0,0,0,1,0,0,4,32,0,0,4,32,0,0,0,0,128,0,0,32,128,0,4,33,128,0,4,33,128,0,0,1,0,0,4,33,128,0,0,32,0,0,0,0,0,0,0,33,128,0,4,1,0,0,0,1,0,0,0,33,128,0,4,0,0,0,4,0,128,0,0,33,128,0,0,0,0,0,0,1,0,0,0,32,0,0,4,1,128,0,0,33,128,0,4,32,128,0,0,1,0,0,0,32,0,0,4,33,128,0,4,1,128,0,4,32,128,0,0,0,0,0,0,1,0,0,4,33,128,0,4,33,128,0,4,0,0,0,0,33,128,0,4,33,0,0,4,1,0,0,0,0,0,0,4,32,0,0,0,33,128,0,4,0,128,0,0,1,128,0,0,32,0,0,4,0,0,0,0,0,0,0,4,32,128,0,4,1,128,0,0,32,8,0,0,16,0,0,32,16,0,32,0,0,8,32,32,16,0,0,32,16,8,0,0,0,8,32,32,16,0,0,32,0,0,32,0,16,8,32,32,0,0,0,32,0,8,0,0,16,8,0,32,0,0,32,0,16,0,0,0,16,8,32,0,0,0,0,0,0,8,0,32,0,8,32,0,16,0,32,0,0,0,32,32,0,8,32,0,16,8,0,0,0,8,0,32,16,8,0,32,16,0,0,0,0,8,32,32,0,0,32,32,16,8,32,0,0,0,32,32,0,0,32,32,16,0,0,0,16,0,32,0,16,8,0,0,0,8,0,32,16,0,32,32,0,8,32,32,16,0,0,32,0,8,32,0,0,8,0,0,16,0,0,32,0,0,32,0,16,0,0,0,16,8,32,0,0,8,0,0,16,8,32,32,16,0,32,32,0,0,0,32,16,8,32,32,0,0,32,32,16,0,0,0,0,8,0,32,16,8,0,0,0,0,32,0,0,0,0,32,16,8,32,32,0,0,32,0,0,8,0,32,0,8,32,0,16,0,0,0,0,0,32,32,16,0,0,0,16,8,0,32,0,8,32,0,16,0,0,16,0,1,0,16,2,1,4,0,2,0,0,0,0,0,4,0,0,1,4,0,2,1,4,16,0,0,4,16,2,1,4,16,2,0,0,16,0,0,0,0,0,1,0,0,2,1,0,0,0,0,0,0,2,1,0,16,2,1,4,0,0,0,4,0,2,1,4,16,0,1,0,16,0,0,4,0,2,1,0,0,2,0,0,16,2,0,4,16,2,1,0,16,0,0,0,16,2,0,4,0,0,1,4,0,0,1,4,16,2,0,4,16,0,1,0,0,0,0,0,0,2,0,4,16,0,0,0,0,2,0,4,16,0,0,0,16,0,1,4,0,2,1,4,0,2,1,0,16,2,1,0,16,2,1,0,0,0,1,0,16,0,0,0,0,2,0,4,0,2,0,0,16,0,0,4,16,2,1,4,0,0,1,4,16,0,0,4,16,2,1,4,0,0,1,0,0,2,1,4,16,2,0,0,16,2,0,4,16,0,0,0,0,0,1,0,0,0,1,4,16,2,0,0,0,0,1,4,16,0,0,0,16,2,0,4,0,0,1,0,0,2,0,4,0,2,0,4,0,0,1,0,16,0,32,8,0,8,0,8,0,0,0,0,2,0,32,8,2,8,0,0,0,8,32,8,0,8,32,0,0,0,0,0,0,8,32,0,2,0,0,0,2,8,32,8,2,8,0,8,2,0,0,8,2,8,32,8,2,0,0,8,0,0,32,0,0,0,0,0,2,8,32,0,0,8,0,8,0,8,32,8,0,0,0,8,2,0,32,0,2,0,32,0,2,8,0,8,2,8,32,8,0,0,0,0,0,0,0,0,0,0,32,0,2,8,32,0,0,8,0,8,0,8,32,8,2,0,0,0,2,0,32,8,2,0,0,0,2,0,0,8,2,8,0,8,0,0,32,0,0,0,32,0,2,8,0,8,0,0,32,8,2,0,0,8,0,8,32,0,0,0,32,0,0,8,0,0,2,8,32,0,2,8,0,0,0,8,0,0,2,0,32,8,0,8,0,0,0,0,32,8,2,8,32,0,2,0,32,0,0,8,0,0,2,8,0,8,0,8,32,8,0,8,0,0,0,0,32,8,2,8,0,8,2,0,0,8,2,0,32,8,0,0,32,8,0,0,32,0,2,0,0,0,0,8,0,8,2,8,42,0,0,0,62,0,0,0,100,114,97,99,0,0,0,0,117,0,0,0,65,67,45,51,1,0,0,0,3,80,1,0,66,83,83,68,1,0,0,0,26,0,1,0,68,84,83,49,1,0,0,0,4,80,1,0,68,84,83,50,1,0,0,0,4,80,1,0,68,84,83,51,1,0,0,0,4,80,1,0,72,69,86,67,0,0,0,0,53,54,50,72,75,76,86,65,2,0,0,0,65,86,76,75,86,67,45,49,0,0,0,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,9,11,13,14,15,63,7,7,11,12,14,15,63,63,9,11,13,14,15,63,63,63,11,11,13,14,63,63,63,63,11,13,14,63,63,63,63,63,13,14,63,63,63,63,63,63,13,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,4,5,6,7,9,11,13,15,5,5,7,8,11,13,15,17,6,7,9,11,13,15,15,17,7,7,9,11,13,15,17,19,7,9,11,13,14,16,19,23,9,11,13,14,16,19,23,29,9,11,13,15,17,21,28,35,11,13,16,17,21,28,35,41,4,4,5,5,6,7,7,9,4,4,5,6,7,7,9,9,5,5,6,7,7,9,9,10,5,5,6,7,7,9,9,10,5,6,7,7,8,9,10,12,6,7,7,8,9,10,12,15,6,7,7,9,10,11,14,17,7,7,9,10,11,14,17,21,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,4,4,4,4,4,4,5,5,4,4,4,4,4,5,5,6,4,4,4,4,5,5,6,7,4,4,4,4,5,6,7,7,4,7,9,11,13,14,63,63,7,7,11,12,14,63,63,63,9,11,13,14,63,63,63,63,11,11,13,14,63,63,63,63,11,13,14,63,63,63,63,63,13,14,63,63,63,63,63,63,13,63,63,63,63,63,63,63,63,63,63,63,63,63,63,63,4,5,6,7,9,11,13,15,5,5,7,8,11,13,15,17,6,7,9,11,13,15,15,17,7,7,9,11,13,15,17,19,7,9,11,13,14,16,19,23,9,11,13,14,16,19,23,29,9,11,13,15,17,21,28,35,11,13,16,17,21,28,35,41,4,4,5,5,6,7,7,9,4,4,5,6,7,7,9,9,5,5,6,7,7,9,9,10,5,5,6,7,7,9,9,10,5,6,7,7,8,9,10,12,6,7,7,8,9,10,12,15,6,7,7,9,10,11,14,17,7,7,9,10,11,14,17,21,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,4,4,4,4,4,4,5,5,4,4,4,4,4,5,5,6,4,4,4,4,5,5,6,7,4,4,4,4,5,6,7,7,254,254,243,230,196,177,153,140,133,130,129,0,0,0,0,0,254,254,254,252,249,243,230,196,177,153,140,133,130,129,0,0,180,157,141,134,130,0,0,0,180,157,141,134,130,0,0,0,176,155,140,135,0,0,0,0,176,155,140,135,0,0,0,0,173,148,140,0,0,0,0,0,173,148,140,0,0,0,0,0,165,145,0,0,0,0,0,0,165,145,0,0,0,0,0,0,159,0,0,0,0,0,0,0,159,0,0,0,0,0,0,0,42,39,45,32,55,51,53,28,41,50,35,46,33,37,44,52,30,48,40,49,29,36,43,54,15,4,25,19,9,1,26,16,5,11,23,8,12,7,17,0,22,3,10,14,6,20,27,24,7,15,23,31,39,47,55,63,6,14,22,30,38,46,54,62,5,13,21,29,37,45,53,61,4,12,20,28,1,9,17,25,33,41,49,57,2,10,18,26,34,42,50,58,3,11,19,27,35,43,51,59,36,44,52,60,20,0,0,0,34,0,0,0,11,0,0,0,17,0,0,0,71,0,0,0,91,0,0,0,30,0,0,0,50,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,1,0,0,0,6,0,0,0,7,0,0,0,129,0,0,0,1,0,0,0,3,80,1,0,138,0,0,0,1,0,0,0,4,80,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,76,86,65,2,0,0,0,65,86,76,75,73,68,51,32,2,0,0,0,51,68,73,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,216,0,67,0,226,0,70,0,236,0,74,0,246,0,77,0,1,1,80,0,12,1,84,0,24,1,88,0,38,1,92,0,51,1,96,0,65,1,100,0,78,1,104,0,94,1,109,0,109,1,114,0,126,1,119,0,143,1,124,0,160,1,130,0,178,1,136,0,198,1,142,0,219,1,148,0,239,1,155,0,7,2,162,0,29,2,169,0,52,2,176,0,78,2,185,0,105,2,193,0,132,2,201,0,161,2,210,0,191,2,220,0,223,2,230,0,255,2,240,0,33,3,251,0,70,3,6,1,108,3,18,1,146,3,30,1,187,3,43,1,229,3,56,1,17,4,70,1,65,4,85,1,114,4,100,1,164,4,116,1,217,4,132,1,17,5,150,1,74,5,168,1,135,5,187,1,198,5,206,1,8,6,227,1,77,6,249,1,148,6,15,2,224,6,39,2,46,7,64,2,129,7,89,2,215,7,116,2,49,8,144,2,142,8,174,2,240,8,204,2,85,9,236,2,192,9,13,3,47,10,48,3,164,10,85,3,30,11,123,3,157,11,162,3,32,12,204,3,171,12,248,3,61,13,37,4,211,13,84,4,114,14,134,4,22,15,185,4,195,15,240,4,120,16,40,5,51,17,99,5,247,17,161,5,198,18,225,5,155,19,36,6,124,20,106,6,101,21,179,6,90,22,0,7,90,23,80,7,101,24,163,7,122,25,251,7,157,26,86,8,206,27,181,8,12,29,25,9,87,30,128,9,178,31,237,9,29,33,95,10,150,34,213,10,34,36,81,11,191,37,210,11,110,39,90,12,50,41,231,12,8,43,122,13,244,44,20,14,244,46,181,14,12,49,93,15,62,51,12,16,135,53,196,16,235,55,131,17,105,58,75,18,5,61,28,19,190,63,247,19,150,66,219,20,143,69,201,21,170,72,194,22,233,75,198,23,76,79,214,24,213,82,242,25,136,86,26,27,101,90,80,28,109,94,147,29,164,98,229,30,12,103,70,32,165,107,183,33,114,112,56,35,120,117,203,36,181,122,111,38,255,127,38,40,255,127,241,41,255,127,208,43,255,127,197,45,255,127,208,47,255,127,242,49,255,127,44,52,255,127,129,54,255,127,240,56,255,127,122,59,255,127,34,62,255,127,231,64,255,127,238,255,140,0,140,0,238,255,37,0,116,0,206,0,74,1,39,0,121,0,216,0,90,1,41,0,127,0,225,0,105,1,42,0,132,0,235,0,121,1,44,0,137,0,245,0,136,1,46,0,144,0,0,1,154,1,48,0,150,0,11,1,172,1,51,0,157,0,24,1,193,1,53,0,165,0,37,1,214,1,55,0,172,0,50,1,234,1,58,0,179,0,63,1,255,1,60,0,187,0,77,1,22,2,63,0,195,0,92,1,45,2,66,0,205,0,108,1,71,2,69,0,214,0,124,1,97,2,72,0,223,0,140,1,123,2,75,0,233,0,158,1,151,2,79,0,244,0,177,1,182,2,82,0,254,0,197,1,213,2,86,0,9,1,216,1,244,2,90,0,22,1,239,1,24,3,94,0,34,1,4,2,58,3,98,0,47,1,26,2,94,3,102,0,60,1,50,2,133,3,107,0,75,1,76,2,174,3,112,0,89,1,102,2,215,3,117,0,105,1,129,2,3,4,122,0,121,1,158,2,50,4,127,0,138,1,189,2,99,4,133,0,155,1,220,2,148,4,139,0,174,1,252,2,200,4,145,0,193,1,31,3,0,5,152,0,213,1,67,3,57,5,159,0,234,1,104,3,117,5,166,0,0,2,143,3,179,5,173,0,23,2,183,3,243,5,181,0,46,2,225,3,54,6,189,0,72,2,14,4,127,6,197,0,98,2,61,4,202,6,206,0,125,2,109,4,23,7,215,0,153,2,159,4,103,7,225,0,183,2,213,4,188,7,235,0,214,2,11,5,20,8,246,0,247,2,69,5,113,8,1,1,24,3,129,5,209,8,12,1,60,3,192,5,53,9,24,1,97,3,2,6,159,9,37,1,135,3,70,6,12,10,50,1,176,3,142,6,128,10,63,1,218,3,217,6,247,10,78,1,6,4,40,7,117,11,93,1,52,4,122,7,249,11,108,1,100,4,207,7,130,12,124,1,150,4,40,8,16,13,142,1,203,4,134,8,166,13,159,1,1,5,230,8,65,14,178,1,59,5,76,9,227,14,197,1,118,5,182,9,142,15,217,1,181,5,38,10,64,16,239,1,246,5,154,10,250,16,5,2,58,6,19,11,188,17,28,2,129,6,145,11,133,18,52,2,204,6,21,12,89,19,77,2,26,7,160,12,55,20,103,2,106,7,47,13,29,21,131,2,192,7,199,13,15,22,159,2,24,8,99,14,10,23,189,2,116,8,8,15,17,24,221,2,213,8,180,15,38,25,254,2,58,9,103,16,68,26,32,3,163,9,34,17,112,27,68,3,18,10,231,17,171,28,105,3,132,10,178,18,240,29,144,3,253,10,137,19,72,31,184,3,122,11,103,20,172,32,227,3,254,11,81,21,35,34,15,4,135,12,69,22,169,35,62,4,22,13,68,23,65,37,110,4,171,13,76,24,232,38,161,4,71,14,97,25,164,40,214,4,234,14,132,26,117,42,13,5,149,15,179,27,91,44,71,5,70,16,239,28,85,46,131,5,0,17,58,30,102,48,194,5,195,17,148,31,146,50,4,6,142,18,252,32,210,52,73,6,98,19,117,34,46,55,144,6,63,20,255,35,164,57,220,6,39,21,154,37,55,60,42,7,25,22,73,39,232,62,124,7,21,23,9,41,182,65,209,7,29,24,223,42,166,68,43,8,48,25,199,44,180,71,136,8,80,26,198,46,231,74,234,8,125,27,222,48,64,78,79,9,183,28,12,51,190,81,186,9,255,29,84,53,101,85,41,10,85,31,180,55,50,89,157,10,188,32,49,58,46,93,22,11,49,34,201,60,86,97,149,11,184,35,128,63,175,101,25,12,81,37,86,66,57,106], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2648224);
/* memory initializer */ allocate([164,12,251,38,76,69,247,110,52,13,184,40,100,72,235,115,203,13,138,42,159,75,24,121,104,14,111,44,254,78,126,126,13,15,107,46,133,82,255,127,185,15,126,48,53,86,255,127,109,16,167,50,13,90,255,127,40,17,234,52,18,94,255,127,237,17,71,55,69,98,255,127,185,18,191,57,168,102,255,127,143,19,82,60,60,107,255,127,111,20,4,63,6,112,255,127,88,21,211,65,5,117,255,127,76,22,195,68,62,122,255,127,75,23,213,71,179,127,255,127,85,24,10,75,255,127,255,127,107,25,99,78,255,127,255,127,141,26,227,81,255,127,255,127,189,27,139,85,255,127,255,127,250,28,92,89,255,127,255,127,69,30,89,93,255,127,255,127,159,31,132,97,255,127,255,127,8,33,222,101,255,127,255,127,129,34,106,106,255,127,255,127,12,36,41,111,255,127,255,127,167,37,31,116,255,127,255,127,243,255,8,0,76,0,222,0,222,0,76,0,8,0,243,255,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,1,80,1,0,4,0,0,0,1,0,0,0,1,80,1,0,15,0,0,0,1,0,0,0,2,80,1,0,16,0,0,0,0,0,0,0,13,0,0,0,27,0,0,0,0,0,0,0,28,0,0,0,36,0,0,0,0,0,0,0,53,54,50,72,66,0,0,0,0,0,0,0,88,0,0,0,209,0,0,0,0,0,0,0,117,0,0,0,234,0,0,0,0,0,0,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,14,22,30,38,46,54,62,4,12,20,28,36,44,52,60,2,10,18,26,34,42,50,58,0,8,16,24,32,40,48,56,7,15,23,31,39,47,55,63,5,13,21,29,37,45,53,61,3,11,19,27,35,43,51,59,1,9,17,25,33,41,49,57,120,1,0,0,120,1,0,0,208,0,0,0,120,1,0,0,120,1,0,0,208,0,0,0,208,0,0,0,208,0,0,0,14,0,0,0,14,0,0,0,92,2,0,0,14,0,0,0,14,0,0,0,92,2,0,0,92,2,0,0,92,2,0,0,128,0,0,0,1,0,0,0,24,0,1,0,129,0,0,0,1,0,0,0,3,80,1,0,130,0,0,0,1,0,0,0,4,80,1,0,131,0,0,0,1,0,0,0,45,80,1,0,132,0,0,0,1,0,0,0,41,80,1,0,133,0,0,0,1,0,0,0,4,80,1,0,134,0,0,0,1,0,0,0,4,80,1,0,161,0,0,0,1,0,0,0,41,80,1,0,162,0,0,0,1,0,0,0,4,80,1,0,144,0,0,0,3,0,0,0,6,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,126,10,0,144,44,16,0,160,126,40,0,160,147,40,0,240,125,10,0,128,44,16,0,144,126,40,0,152,147,40,0,208,125,10,0,96,44,16,0,112,126,40,0,136,147,40,0,144,125,10,0,32,44,16,0,48,126,40,0,104,147,40,0,0,0,0,0,0,1,1,1,1,1,2,3,4,5,6,6,6,6,5,4,3,2,1,1,1,1,1,0,0,0,0,0,0,0,0,1,1,1,3,7,7,3,1,1,1,0,0,0,0,1,2,7,7,2,1,0,0,7,7,0,0,0,0,0,2,0,0,0,2,0,0,0,68,2,0,0,2,0,0,0,2,0,0,0,68,2,0,0,68,2,0,0,68,2,0,0,200,1,0,0,200,1,0,0,70,2,0,0,200,1,0,0,200,1,0,0,70,2,0,0,70,2,0,0,70,2,0,0,40,1,0,0,40,1,0,0,216,0,0,0,40,1,0,0,40,1,0,0,216,0,0,0,216,0,0,0,216,0,0,0,80,217,153,149,51,95,23,70,175,124,30,84,181,16,218,163,72,192,206,93,185,208,99,65,135,44,79,50,34,59,232,138,104,171,241,202,83,225,65,77,166,179,167,201,152,219,117,238,109,102,146,226,2,156,141,68,170,141,120,26,147,253,195,149,196,225,212,75,161,144,9,65,130,54,39,240,14,125,204,91,230,162,180,58,71,66,52,75,137,108,48,175,165,210,28,36,217,121,231,239,240,151,134,71,128,13,149,207,80,93,220,102,190,191,28,80,73,184,206,66,155,233,61,184,105,251,130,179,28,212,123,16,218,166,145,70,131,105,17,178,205,170,40,142,106,0,0,0,1,0,0,0,3,80,1,0,122,0,0,0,1,0,0,0,41,80,1,0,123,0,0,0,1,0,0,0,4,80,1,0,86,0,0,0,3,0,0,0,7,112,1,0,89,0,0,0,3,0,0,0,1,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,32,0,0,0,35,33,65,77,82,10,0,0,35,33,65,77,82,45,87,66,10,0,0,0,0,0,0,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+2658464);



var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}


  
  
  
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value;
      return value;
    }
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  
  var MEMFS={ops_table:null,CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            },
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            if (canOwn && offset === 0) {
              node.contents = buffer; // this could be a subarray of Emscripten HEAP, or allocated from some other source.
              node.contentMode = (buffer.buffer === HEAP8.buffer) ? MEMFS.CONTENT_OWNING : MEMFS.CONTENT_FIXED;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          fileStore.createIndex('timestamp', 'timestamp', { unique: false });
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function() {
          callback(this.error);
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function() { callback(this.error); };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function() { callback(this.error); };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function() { done(this.error); };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so 
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          stream.position = position;
          return position;
        }}};
  
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); },
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); },
            },
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        if (stream.__proto__) {
          // reuse the object
          stream.__proto__ = FS.FSStream.prototype;
        } else {
          var newStream = new FS.FSStream();
          for (var p in stream) {
            newStream[p] = stream[p];
          }
          stream = newStream;
        }
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getStreamFromPtr:function (ptr) {
        return FS.streams[ptr - 1];
      },getPtrForStream:function (stream) {
        return stream ? stream.fd + 1 : 0;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            callback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = '';
          var utf8 = new Runtime.UTF8Processor();
          for (var i = 0; i < length; i++) {
            ret += utf8.processCChar(buf[i]);
          }
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var utf8 = new Runtime.UTF8Processor();
          var buf = new Uint8Array(utf8.processJSString(data));
          FS.write(stream, buf, 0, buf.length, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=FS.getPtrForStream(stdin);
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=FS.getPtrForStream(stdout);
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=FS.getPtrForStream(stderr);
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          function LazyUint8Array() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
  
              if (!hasByteServing) chunkSize = datalength;
  
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
  
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
  
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
  
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};
  
  
  
  
  function _mkport() { throw 'TODO' }var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {headers: {'websocket-protocol': ['binary']}} : ['binary'];
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      return FS.getStreamFromPtr(stream).fd;
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var fd = _fileno(stream);
      var bytesWritten = _write(fd, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  
  
   
  Module["_strlen"] = _strlen;
  
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
  
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }

  
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }

  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  
  
  
  
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
  
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr;
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
  
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
  
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        writeAsciiToMemory(line, poolPtr);
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
  
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }


  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr;
      var fd = _fileno(stream);
      var ret = _write(fd, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }


  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }


  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }

  
  
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
  
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
  
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
  
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
  
      // Apply sign.
      ret *= multiplier;
  
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str;
      }
  
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
  
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
  
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)),ret>>>0)|0);
      }
  
      return ret;
    }function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }

  function _setrlimit(resource, rlp) {
      // int setrlimit(int resource, const struct rlimit *rlp)
      return 0;
    }

  
  
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      var fd = _fileno(stream);
      return _write(fd, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  
  
  function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          writeAsciiToMemory(msg, strerrbuf);
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }
  
  function ___errno_location() {
      return ___errno_state;
    }function _perror(s) {
      // void perror(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/perror.html
      var stdout = HEAP32[((_stdout)>>2)];
      if (s) {
        _fputs(s, stdout);
        _fputc(58, stdout);
        _fputc(32, stdout);
      }
      var errnum = HEAP32[((___errno_location())>>2)];
      _puts(_strerror(errnum));
    }


  
  
  
  
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop();
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(streamObj.fd, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _getchar() {
      // int getchar(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getchar.html
      return _fgetc(HEAP32[((_stdin)>>2)]);
    }


  
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var fd = _fileno(stream);
      var ret = _lseek(fd, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStreamFromPtr(stream);
      stream.eof = false;
      return 0;
    }

  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }

  
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      var fd = _fileno(stream);
      _fsync(fd);
      return _close(fd);
    }


  function _ferror(stream) {
      // int ferror(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ferror.html
      stream = FS.getStreamFromPtr(stream);
      return Number(stream && stream.error);
    }

  
  function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 512;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 1024;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var fd = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd));
    }

  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }

  
   
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;

  function _abort() {
      Module['abort']();
    }

  
  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }

  var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;

  
  var ___strtok_state=0;
  
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
  
  
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
  
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
  
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
  
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }function _strtok(s, delim) {
      return _strtok_r(s, delim, ___strtok_state);
    }

  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  
  var ___tm_current=allocate(44, "i8", ALLOC_STATIC);
  
  
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  
  
  var _tzname=allocate(8, "i32*", ALLOC_STATIC);
  
  var _daylight=allocate(1, "i32*", ALLOC_STATIC);
  
  var _timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
  
      HEAP32[((_timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60;
  
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((_daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());
  
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((_tzname)>>2)]=winterNamePtr;
      HEAP32[(((_tzname)+(4))>>2)]=summerNamePtr;
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
  
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(36))>>2)]=start.getTimezoneOffset() * 60;
  
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(32))>>2)]=dst;
  
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }

  var _llvm_memset_p0i8_i64=_memset;

  function _llvm_va_copy(ppdest, ppsrc) {
      // copy the list start
      HEAP8[(ppdest)]=HEAP8[(ppsrc)];HEAP8[(((ppdest)+(1))|0)]=HEAP8[(((ppsrc)+(1))|0)];HEAP8[(((ppdest)+(2))|0)]=HEAP8[(((ppsrc)+(2))|0)];HEAP8[(((ppdest)+(3))|0)]=HEAP8[(((ppsrc)+(3))|0)];
      
      // copy the list's current offset (will be advanced with each call to va_arg)
      HEAP8[((ppdest+4)|0)]=HEAP8[((ppsrc+4)|0)];HEAP8[(((ppdest+4)+(1))|0)]=HEAP8[(((ppsrc+4)+(1))|0)];HEAP8[(((ppdest+4)+(2))|0)]=HEAP8[(((ppsrc+4)+(2))|0)];HEAP8[(((ppdest+4)+(3))|0)]=HEAP8[(((ppsrc+4)+(3))|0)];
    }

  function _llvm_va_end() {}



  function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    }

  function _llvm_lifetime_start() {}

  function _llvm_lifetime_end() {}


  function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_;
      }
      HEAP8[(((s)+(i))|0)]=0;
      return s;
    }

  function _strcspn(pstr, pset) {
      var str = pstr, set, strcurr, setcurr;
      while (1) {
        strcurr = HEAP8[(str)];
        if (!strcurr) return str - pstr;
        set = pset;
        while (1) {
          setcurr = HEAP8[(set)];
          if (!setcurr || setcurr == strcurr) break;
          set++;
        }
        if (setcurr) return str - pstr;
        str++;
      }
    }

  
  function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getUTCSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getUTCMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getUTCHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getUTCDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getUTCMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getUTCFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getUTCDay();
      HEAP32[(((tmPtr)+(36))>>2)]=0;
      HEAP32[(((tmPtr)+(32))>>2)]=0;
      var start = new Date(date); // define date using UTC, start from Jan 01 00:00:00 UTC
      start.setUTCDate(1);
      start.setUTCMonth(0);
      start.setUTCHours(0);
      start.setUTCMinutes(0);
      start.setUTCSeconds(0);
      start.setUTCMilliseconds(0);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }

  
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  
  
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
  
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
  
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      
      var date = {
        tm_sec: HEAP32[((tm)>>2)],
        tm_min: HEAP32[(((tm)+(4))>>2)],
        tm_hour: HEAP32[(((tm)+(8))>>2)],
        tm_mday: HEAP32[(((tm)+(12))>>2)],
        tm_mon: HEAP32[(((tm)+(16))>>2)],
        tm_year: HEAP32[(((tm)+(20))>>2)],
        tm_wday: HEAP32[(((tm)+(24))>>2)],
        tm_yday: HEAP32[(((tm)+(28))>>2)],
        tm_isdst: HEAP32[(((tm)+(32))>>2)]
      };
  
      var pattern = Pointer_stringify(format);
  
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
  
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
  
      function leadingSomething(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
  
      function leadingNulls(value, digits) {
        return leadingSomething(value, digits, '0');
      };
  
      function compareByDay(date1, date2) {
        function sgn(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
  
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
  
      function getFirstWeekStartDate(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
  
      function getWeekBasedYear(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
  
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
  
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
  
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
  
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
  
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
  
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
  
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }

  
  
  function __getFloat(text) {
      return /^[+-]?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?/.exec(text);
    }function __scanString(format, get, unget, varargs) {
      if (!__scanString.whiteSpace) {
        __scanString.whiteSpace = {};
        __scanString.whiteSpace[32] = 1;
        __scanString.whiteSpace[9] = 1;
        __scanString.whiteSpace[10] = 1;
        __scanString.whiteSpace[11] = 1;
        __scanString.whiteSpace[12] = 1;
        __scanString.whiteSpace[13] = 1;
      }
      // Supports %x, %4x, %d.%d, %lld, %s, %f, %lf.
      // TODO: Support all format specifiers.
      format = Pointer_stringify(format);
      var soFar = 0;
      if (format.indexOf('%n') >= 0) {
        // need to track soFar
        var _get = get;
        get = function get() {
          soFar++;
          return _get();
        }
        var _unget = unget;
        unget = function unget() {
          soFar--;
          return _unget();
        }
      }
      var formatIndex = 0;
      var argsi = 0;
      var fields = 0;
      var argIndex = 0;
      var next;
  
      mainLoop:
      for (var formatIndex = 0; formatIndex < format.length;) {
        if (format[formatIndex] === '%' && format[formatIndex+1] == 'n') {
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          HEAP32[((argPtr)>>2)]=soFar;
          formatIndex += 2;
          continue;
        }
  
        if (format[formatIndex] === '%') {
          var nextC = format.indexOf('c', formatIndex+1);
          if (nextC > 0) {
            var maxx = 1;
            if (nextC > formatIndex+1) {
              var sub = format.substring(formatIndex+1, nextC);
              maxx = parseInt(sub);
              if (maxx != sub) maxx = 0;
            }
            if (maxx) {
              var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
              argIndex += Runtime.getAlignSize('void*', null, true);
              fields++;
              for (var i = 0; i < maxx; i++) {
                next = get();
                HEAP8[((argPtr++)|0)]=next;
                if (next === 0) return i > 0 ? fields : fields-1; // we failed to read the full length of this field
              }
              formatIndex += nextC - formatIndex + 1;
              continue;
            }
          }
        }
  
        // handle %[...]
        if (format[formatIndex] === '%' && format.indexOf('[', formatIndex+1) > 0) {
          var match = /\%([0-9]*)\[(\^)?(\]?[^\]]*)\]/.exec(format.substring(formatIndex));
          if (match) {
            var maxNumCharacters = parseInt(match[1]) || Infinity;
            var negateScanList = (match[2] === '^');
            var scanList = match[3];
  
            // expand "middle" dashs into character sets
            var middleDashMatch;
            while ((middleDashMatch = /([^\-])\-([^\-])/.exec(scanList))) {
              var rangeStartCharCode = middleDashMatch[1].charCodeAt(0);
              var rangeEndCharCode = middleDashMatch[2].charCodeAt(0);
              for (var expanded = ''; rangeStartCharCode <= rangeEndCharCode; expanded += String.fromCharCode(rangeStartCharCode++));
              scanList = scanList.replace(middleDashMatch[1] + '-' + middleDashMatch[2], expanded);
            }
  
            var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
            argIndex += Runtime.getAlignSize('void*', null, true);
            fields++;
  
            for (var i = 0; i < maxNumCharacters; i++) {
              next = get();
              if (negateScanList) {
                if (scanList.indexOf(String.fromCharCode(next)) < 0) {
                  HEAP8[((argPtr++)|0)]=next;
                } else {
                  unget();
                  break;
                }
              } else {
                if (scanList.indexOf(String.fromCharCode(next)) >= 0) {
                  HEAP8[((argPtr++)|0)]=next;
                } else {
                  unget();
                  break;
                }
              }
            }
  
            // write out null-terminating character
            HEAP8[((argPtr++)|0)]=0;
            formatIndex += match[0].length;
            
            continue;
          }
        }      
        // remove whitespace
        while (1) {
          next = get();
          if (next == 0) return fields;
          if (!(next in __scanString.whiteSpace)) break;
        }
        unget();
  
        if (format[formatIndex] === '%') {
          formatIndex++;
          var suppressAssignment = false;
          if (format[formatIndex] == '*') {
            suppressAssignment = true;
            formatIndex++;
          }
          var maxSpecifierStart = formatIndex;
          while (format[formatIndex].charCodeAt(0) >= 48 &&
                 format[formatIndex].charCodeAt(0) <= 57) {
            formatIndex++;
          }
          var max_;
          if (formatIndex != maxSpecifierStart) {
            max_ = parseInt(format.slice(maxSpecifierStart, formatIndex), 10);
          }
          var long_ = false;
          var half = false;
          var longLong = false;
          if (format[formatIndex] == 'l') {
            long_ = true;
            formatIndex++;
            if (format[formatIndex] == 'l') {
              longLong = true;
              formatIndex++;
            }
          } else if (format[formatIndex] == 'h') {
            half = true;
            formatIndex++;
          }
          var type = format[formatIndex];
          formatIndex++;
          var curr = 0;
          var buffer = [];
          // Read characters according to the format. floats are trickier, they may be in an unfloat state in the middle, then be a valid float later
          if (type == 'f' || type == 'e' || type == 'g' ||
              type == 'F' || type == 'E' || type == 'G') {
            next = get();
            while (next > 0 && (!(next in __scanString.whiteSpace)))  {
              buffer.push(String.fromCharCode(next));
              next = get();
            }
            var m = __getFloat(buffer.join(''));
            var last = m ? m[0].length : 0;
            for (var i = 0; i < buffer.length - last + 1; i++) {
              unget();
            }
            buffer.length = last;
          } else {
            next = get();
            var first = true;
            
            // Strip the optional 0x prefix for %x.
            if ((type == 'x' || type == 'X') && (next == 48)) {
              var peek = get();
              if (peek == 120 || peek == 88) {
                next = get();
              } else {
                unget();
              }
            }
            
            while ((curr < max_ || isNaN(max_)) && next > 0) {
              if (!(next in __scanString.whiteSpace) && // stop on whitespace
                  (type == 's' ||
                   ((type === 'd' || type == 'u' || type == 'i') && ((next >= 48 && next <= 57) ||
                                                                     (first && next == 45))) ||
                   ((type === 'x' || type === 'X') && (next >= 48 && next <= 57 ||
                                     next >= 97 && next <= 102 ||
                                     next >= 65 && next <= 70))) &&
                  (formatIndex >= format.length || next !== format[formatIndex].charCodeAt(0))) { // Stop when we read something that is coming up
                buffer.push(String.fromCharCode(next));
                next = get();
                curr++;
                first = false;
              } else {
                break;
              }
            }
            unget();
          }
          if (buffer.length === 0) return 0;  // Failure.
          if (suppressAssignment) continue;
  
          var text = buffer.join('');
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          switch (type) {
            case 'd': case 'u': case 'i':
              if (half) {
                HEAP16[((argPtr)>>1)]=parseInt(text, 10);
              } else if (longLong) {
                (tempI64 = [parseInt(text, 10)>>>0,(tempDouble=parseInt(text, 10),(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[((argPtr)>>2)]=tempI64[0],HEAP32[(((argPtr)+(4))>>2)]=tempI64[1]);
              } else {
                HEAP32[((argPtr)>>2)]=parseInt(text, 10);
              }
              break;
            case 'X':
            case 'x':
              HEAP32[((argPtr)>>2)]=parseInt(text, 16);
              break;
            case 'F':
            case 'f':
            case 'E':
            case 'e':
            case 'G':
            case 'g':
            case 'E':
              // fallthrough intended
              if (long_) {
                HEAPF64[((argPtr)>>3)]=parseFloat(text);
              } else {
                HEAPF32[((argPtr)>>2)]=parseFloat(text);
              }
              break;
            case 's':
              var array = intArrayFromString(text);
              for (var j = 0; j < array.length; j++) {
                HEAP8[(((argPtr)+(j))|0)]=array[j];
              }
              break;
          }
          fields++;
        } else if (format[formatIndex].charCodeAt(0) in __scanString.whiteSpace) {
          next = get();
          while (next in __scanString.whiteSpace) {
            if (next <= 0) break mainLoop;  // End of input.
            next = get();
          }
          unget(next);
          formatIndex++;
        } else {
          // Not a specifier.
          next = get();
          if (format[formatIndex].charCodeAt(0) !== next) {
            unget(next);
            break mainLoop;
          }
          formatIndex++;
        }
      }
      return fields;
    }function _sscanf(s, format, varargs) {
      // int sscanf(const char *restrict s, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var index = 0;
      function get() { return HEAP8[(((s)+(index++))|0)]; };
      function unget() { index--; };
      return __scanString(format, get, unget, varargs);
    }

  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }

  function _signal(sig, func) {
      // TODO
      return 0;
    }

  function _atoi(ptr) {
      return _strtol(ptr, null, 10);
    }

  function _tcsetattr(fildes, optional_actions, termios_p) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/tcsetattr.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return -1;
      }
      return 0;
    }

  function _isatty(fildes) {
      // int isatty(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/isatty.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // HACK - implement tcgetattr
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return 0;
      }
      return 1;
    }

  function _tcgetattr(fildes, termios_p) {
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/tcgetattr.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return -1;
      }
      return 0;
    }

  function _setvbuf(stream, buf, type, size) {
      // int setvbuf(FILE *restrict stream, char *restrict buf, int type, size_t size);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/setvbuf.html
      // TODO: Implement custom buffering.
      return 0;
    }

  var _log=Math_log;

  var _llvm_va_start=undefined;

  function _vsnprintf(s, n, format, va_arg) {
      return _snprintf(s, n, format, HEAP32[((va_arg)>>2)]);
    }

  
  function _rint(x) {
      if (Math.abs(x % 1) !== 0.5) return Math.round(x);
      return x + x % 2 + ((x < 0) ? 1 : -1);
    }var _lrintf=_rint;

  function _log2(x) {
      return Math.log(x) / Math.LN2;
    }

  var _lrint=_rint;

  
  
  function _ungetc(c, stream) {
      // int ungetc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ungetc.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        return -1;
      }
      if (c === -1) {
        // do nothing for EOF character
        return c;
      }
      c = unSign(c & 0xFF);
      stream.ungotten.push(c);
      stream.eof = false;
      return c;
    }function _fscanf(stream, format, varargs) {
      // int fscanf(FILE *restrict stream, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) {
        return -1;
      }
      var buffer = [];
      function get() {
        var c = _fgetc(stream);
        buffer.push(c);
        return c;
      };
      function unget() {
        _ungetc(buffer.pop(), stream);
      };
      return __scanString(format, get, unget, varargs);
    }function _scanf(format, varargs) {
      // int scanf(const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var stdin = HEAP32[((_stdin)>>2)];
      return _fscanf(stdin, format, varargs);
    }

  
  var ___DEFAULT_POLLMASK=5;function _select(nfds, readfds, writefds, exceptfds, timeout) {
      // readfds are supported,
      // writefds checks socket open status
      // exceptfds not supported
      // timeout is always 0 - fully async
      assert(nfds <= 64, 'nfds must be less than or equal to 64');  // fd sets have 64 bits
      assert(!exceptfds, 'exceptfds not supported');
  
      var total = 0;
      
      var srcReadLow = (readfds ? HEAP32[((readfds)>>2)] : 0),
          srcReadHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0);
      var srcWriteLow = (writefds ? HEAP32[((writefds)>>2)] : 0),
          srcWriteHigh = (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0);
      var srcExceptLow = (exceptfds ? HEAP32[((exceptfds)>>2)] : 0),
          srcExceptHigh = (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);
  
      var dstReadLow = 0,
          dstReadHigh = 0;
      var dstWriteLow = 0,
          dstWriteHigh = 0;
      var dstExceptLow = 0,
          dstExceptHigh = 0;
  
      var allLow = (readfds ? HEAP32[((readfds)>>2)] : 0) |
                   (writefds ? HEAP32[((writefds)>>2)] : 0) |
                   (exceptfds ? HEAP32[((exceptfds)>>2)] : 0);
      var allHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0) |
                    (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0) |
                    (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);
  
      function get(fd, low, high, val) {
        return (fd < 32 ? (low & val) : (high & val));
      }
  
      for (var fd = 0; fd < nfds; fd++) {
        var mask = 1 << (fd % 32);
        if (!(get(fd, allLow, allHigh, mask))) {
          continue;  // index isn't in the set
        }
  
        var stream = FS.getStream(fd);
        if (!stream) {
          ___setErrNo(ERRNO_CODES.EBADF);
          return -1;
        }
  
        var flags = ___DEFAULT_POLLMASK;
  
        if (stream.stream_ops.poll) {
          flags = stream.stream_ops.poll(stream);
        }
  
        if ((flags & 1) && get(fd, srcReadLow, srcReadHigh, mask)) {
          fd < 32 ? (dstReadLow = dstReadLow | mask) : (dstReadHigh = dstReadHigh | mask);
          total++;
        }
        if ((flags & 4) && get(fd, srcWriteLow, srcWriteHigh, mask)) {
          fd < 32 ? (dstWriteLow = dstWriteLow | mask) : (dstWriteHigh = dstWriteHigh | mask);
          total++;
        }
        if ((flags & 2) && get(fd, srcExceptLow, srcExceptHigh, mask)) {
          fd < 32 ? (dstExceptLow = dstExceptLow | mask) : (dstExceptHigh = dstExceptHigh | mask);
          total++;
        }
      }
  
      if (readfds) {
        HEAP32[((readfds)>>2)]=dstReadLow;
        HEAP32[(((readfds)+(4))>>2)]=dstReadHigh;
      }
      if (writefds) {
        HEAP32[((writefds)>>2)]=dstWriteLow;
        HEAP32[(((writefds)+(4))>>2)]=dstWriteHigh;
      }
      if (exceptfds) {
        HEAP32[((exceptfds)>>2)]=dstExceptLow;
        HEAP32[(((exceptfds)+(4))>>2)]=dstExceptHigh;
      }
      
      return total;
    }


  function _getrusage(resource, rlp) {
      // int getrusage(int resource, struct rusage *rlp);
      HEAP32[((rlp)>>2)]=1;
      HEAP32[(((rlp)+(4))>>2)]=2;
      HEAP32[(((rlp)+(8))>>2)]=3;
      HEAP32[(((rlp)+(12))>>2)]=4;
      return 0;
    }

  var _cos=Math_cos;

  var _sqrt=Math_sqrt;

  var _sin=Math_sin;

  function _hypot(a, b) {
       return Math.sqrt(a*a + b*b);
    }

  function _cbrt(x) {
      return Math.pow(x, 1/3);
    }

  
   
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;


  var _sqrtf=Math_sqrt;

  var _fabs=Math_abs;

  function _log10(x) {
      return Math.log(x) / Math.LN10;
    }

  var _llvm_pow_f64=Math_pow;

  var _ceilf=Math_ceil;

  function _strspn(pstr, pset) {
      var str = pstr, set, strcurr, setcurr;
      while (1) {
        strcurr = HEAP8[(str)];
        if (!strcurr) return str - pstr;
        set = pset;
        while (1) {
          setcurr = HEAP8[(set)];
          if (!setcurr || setcurr == strcurr) break;
          set++;
        }
        if (!setcurr) return str - pstr;
        str++;
      }
    }

  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }

  function _llvm_bswap_i16(x) {
      return ((x&0xff)<<8) | ((x>>8)&0xff);
    }

  var _atan2=Math_atan2;

  var _floor=Math_floor;

  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }

  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }

  var _exp=Math_exp;

  var _fabsf=Math_abs;

  function _sinh(x) {
      var p = Math.pow(Math.E, x);
      return (p - (1 / p)) / 2;
    }

  function ___assert_fail(condition, filename, line, func) {
      ABORT = true;
      throw 'Assertion failed: ' + Pointer_stringify(condition) + ', at: ' + [filename ? Pointer_stringify(filename) : 'unknown filename', line, func ? Pointer_stringify(func) : 'unknown function'] + ' at ' + stackTrace();
    }

   
  Module["_strcpy"] = _strcpy;

  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }

  function _bsearch(key, base, num, size, compar) {
      function cmp(x, y) {
        return Module['dynCall_iii'](compar, x, y);
      };
      var left = 0;
      var right = num;
      var mid, test, addr;
  
      while (left < right) {
        mid = (left + right) >>> 1;
        addr = base + (mid * size);
        test = cmp(key, addr);
        if (test < 0) {
          right = mid;
        } else if (test > 0) {
          left = mid + 1;
        } else {
          return addr;
        }
      }
  
      return 0;
    }

  function _access(path, amode) {
      // int access(const char *path, int amode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/access.html
      path = Pointer_stringify(path);
      if (amode & ~7) {
        // need a valid mode
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      var perms = '';
      if (amode & 4) perms += 'r';
      if (amode & 2) perms += 'w';
      if (amode & 1) perms += 'x';
      if (perms /* otherwise, they've just passed F_OK */ && FS.nodePermissions(node, perms)) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      }
      return 0;
    }


  
  function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[((buf)>>2)]=stat.dev;
        HEAP32[(((buf)+(4))>>2)]=0;
        HEAP32[(((buf)+(8))>>2)]=stat.ino;
        HEAP32[(((buf)+(12))>>2)]=stat.mode;
        HEAP32[(((buf)+(16))>>2)]=stat.nlink;
        HEAP32[(((buf)+(20))>>2)]=stat.uid;
        HEAP32[(((buf)+(24))>>2)]=stat.gid;
        HEAP32[(((buf)+(28))>>2)]=stat.rdev;
        HEAP32[(((buf)+(32))>>2)]=0;
        HEAP32[(((buf)+(36))>>2)]=stat.size;
        HEAP32[(((buf)+(40))>>2)]=4096;
        HEAP32[(((buf)+(44))>>2)]=stat.blocks;
        HEAP32[(((buf)+(48))>>2)]=Math.floor(stat.atime.getTime() / 1000);
        HEAP32[(((buf)+(52))>>2)]=0;
        HEAP32[(((buf)+(56))>>2)]=Math.floor(stat.mtime.getTime() / 1000);
        HEAP32[(((buf)+(60))>>2)]=0;
        HEAP32[(((buf)+(64))>>2)]=Math.floor(stat.ctime.getTime() / 1000);
        HEAP32[(((buf)+(68))>>2)]=0;
        HEAP32[(((buf)+(72))>>2)]=stat.ino;
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fstat(fildes, buf) {
      // int fstat(int fildes, struct stat *buf);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/fstat.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      return _stat(stream.path, buf);
    }



  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _rename(old_path, new_path) {
      // int rename(const char *old, const char *new);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rename.html
      old_path = Pointer_stringify(old_path);
      new_path = Pointer_stringify(new_path);
      try {
        FS.rename(old_path, new_path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  
  function _mknod(path, mode, dev) {
      // int mknod(const char *path, mode_t mode, dev_t dev);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mknod.html
      path = Pointer_stringify(path);
      // we don't want this in the JS API as the JS API
      // uses mknod to create all nodes.
      switch (mode & 61440) {
        case 32768:
        case 8192:
        case 24576:
        case 4096:
        case 49152:
          break;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      try {
        FS.mknod(path, mode, dev);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _mkdir(path, mode) {
      // int mkdir(const char *path, mode_t mode);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mkdir.html
      path = Pointer_stringify(path);
      try {
        FS.mkdir(path, mode, 0);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _globfree() {
  Module['printErr']('missing function: globfree'); abort(-1);
  }


  function _glob() {
  Module['printErr']('missing function: glob'); abort(-1);
  }

  var _ceil=Math_ceil;

  function _llrint(x) {
      x = (x < 0) ? -Math.round(-x) : Math.round(x);
      return ((asm["setTempRet0"]((tempDouble=x,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)),x>>>0)|0);
    }

  
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
  
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
  
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      var start = str;
  
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
  
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
  
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str;
      }
  
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
  
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoll(str, endptr, base) {
      return __parseInt64(str, endptr, base, '-9223372036854775808', '9223372036854775807');  // LLONG_MIN, LLONG_MAX.
    }

  
  function _trunc(x) {
      return (x < 0) ? Math.ceil(x) : Math.floor(x);
    }var _truncf=_trunc;

  function _exp2(x) {
      return Math.pow(2, x);
    }

  var _expf=Math_exp;

  function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }

  var _log2f=_log2;

  var _llvm_pow_f32=Math_pow;

  var _atan=Math_atan;


  var _roundf=_round;

  var _exp2f=_exp2;

  var _llvm_memcpy_p0i8_p0i8_i64=_memcpy;

  var _tan=Math_tan;

  function _frexp(x, exp_addr) {
      var sig = 0, exp_ = 0;
      if (x !== 0) {
        var sign = 1;
        if (x < 0) {
          x = -x;
          sign = -1;
        }
        var raw_exp = Math.log(x)/Math.log(2);
        exp_ = Math.ceil(raw_exp);
        if (exp_ === raw_exp) exp_ += 1;
        sig = sign*x/Math.pow(2, exp_);
      }
      HEAP32[((exp_addr)>>2)]=exp_;
      return sig;
    }

  var _floorf=Math_floor;

  var _sinf=Math_sin;

  var _log10f=_log10;

  var _cosf=Math_cos;

  var _cbrtf=_cbrt;

  var _atan2f=Math_atan2;

  var _atanf=Math_atan;

  var _llrintf=_llrint;

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 79:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }



  function _cosh(x) {
      var p = Math.pow(Math.E, x);
      return (p + (1 / p)) / 2;
    }

  function _tanh(x) {
      return _sinh(x) / _cosh(x);
    }

  var _asin=Math_asin;

  var _acos=Math_acos;

  function _mmap(start, num, prot, flags, fd, offset) {
      /* FIXME: Since mmap is normally implemented at the kernel level,
       * this implementation simply uses malloc underneath the call to
       * mmap.
       */
      var MAP_PRIVATE = 2;
      var ptr;
      var allocated = false;
  
      if (!_mmap.mappings) _mmap.mappings = {};
  
      if (fd == -1) {
        ptr = _malloc(num);
        if (!ptr) return -1;
        _memset(ptr, 0, num);
        allocated = true;
      } else {
        var info = FS.getStream(fd);
        if (!info) return -1;
        try {
          var res = FS.mmap(info, HEAPU8, start, num, offset, prot, flags);
          ptr = res.ptr;
          allocated = res.allocated;
        } catch (e) {
          FS.handleFSError(e);
          return -1;
        }
      }
  
      _mmap.mappings[ptr] = { malloc: ptr, num: num, allocated: allocated };
      return ptr;
    }

  function _munmap(start, num) {
      if (!_mmap.mappings) _mmap.mappings = {};
      // TODO: support unmmap'ing parts of allocations
      var info = _mmap.mappings[start];
      if (!info) return 0;
      if (num == info.num) {
        _mmap.mappings[start] = null;
        if (info.allocated) {
          _free(info.malloc);
        }
      }
      return 0;
    }


  function _fcntl(fildes, cmd, varargs, dup2) {
      // int fcntl(int fildes, int cmd, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/fcntl.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      switch (cmd) {
        case 0:
          var arg = HEAP32[((varargs)>>2)];
          if (arg < 0) {
            ___setErrNo(ERRNO_CODES.EINVAL);
            return -1;
          }
          var newStream;
          try {
            newStream = FS.open(stream.path, stream.flags, 0, arg);
          } catch (e) {
            FS.handleFSError(e);
            return -1;
          }
          return newStream.fd;
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          return stream.flags;
        case 4:
          var arg = HEAP32[((varargs)>>2)];
          stream.flags |= arg;
          return 0;
        case 12:
        case 12:
          var arg = HEAP32[((varargs)>>2)];
          var offset = 0;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=2;
          return 0;
        case 13:
        case 14:
        case 13:
        case 14:
          // Pretend that the locking is successful.
          return 0;
        case 8:
        case 9:
          // These are for sockets. We don't have them fully implemented yet.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      // Should never be reached. Only to silence strict warnings.
      return -1;
    }

  function _fdopen(fildes, mode) {
      // FILE *fdopen(int fildes, const char *mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fdopen.html
      mode = Pointer_stringify(mode);
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      if ((mode.indexOf('w') != -1 && !stream.isWrite) ||
          (mode.indexOf('r') != -1 && !stream.isRead) ||
          (mode.indexOf('a') != -1 && !stream.isAppend) ||
          (mode.indexOf('+') != -1 && (!stream.isRead || !stream.isWrite))) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      } else {
        stream.error = false;
        stream.eof = false;
        return FS.getPtrForStream(stream);
      }
    }

   
  Module["_llvm_uadd_with_overflow_i64"] = _llvm_uadd_with_overflow_i64;

  function _mktime(tmPtr) {
      _tzset();
      var year = HEAP32[(((tmPtr)+(20))>>2)];
      var timestamp = new Date(year >= 1900 ? year : year + 1900,
                               HEAP32[(((tmPtr)+(16))>>2)],
                               HEAP32[(((tmPtr)+(12))>>2)],
                               HEAP32[(((tmPtr)+(8))>>2)],
                               HEAP32[(((tmPtr)+(4))>>2)],
                               HEAP32[((tmPtr)>>2)],
                               0).getTime() / 1000;
      HEAP32[(((tmPtr)+(24))>>2)]=new Date(timestamp).getDay();
      var yday = Math.round((timestamp - (new Date(year, 0, 1)).getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      return timestamp;
    }

  function _clock() {
      if (_clock.start === undefined) _clock.start = Date.now();
      return Math.floor((Date.now() - _clock.start) * (1000000/1000));
    }

  function _gettimeofday(ptr) {
      var now = Date.now();
      HEAP32[((ptr)>>2)]=Math.floor(now/1000); // seconds
      HEAP32[(((ptr)+(4))>>2)]=Math.floor((now-1000*Math.floor(now/1000))*1000); // microseconds
      return 0;
    }

  
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[((rqtp)>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(4))>>2)];
      if (rmtp !== 0) {
        HEAP32[((rmtp)>>2)]=0;
        HEAP32[(((rmtp)+(4))>>2)]=0;
      }
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }

  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }


  function _madvise() {
  Module['printErr']('missing function: madvise'); abort(-1);
  }

  function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }

  var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC); 
  Module["_llvm_ctlz_i32"] = _llvm_ctlz_i32;


  var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_STATIC); 
  Module["_llvm_cttz_i32"] = _llvm_cttz_i32;

  function _llvm_prefetch(){}


  
  var DLFCN={error:null,errorMsg:null,loadedLibs:{},loadedLibNames:{}};function _dlopen(filename, flag) {
      // void *dlopen(const char *file, int mode);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlopen.html
      filename = filename === 0 ? '__self__' : (ENV['LD_LIBRARY_PATH'] || '/') + Pointer_stringify(filename);
  
      abort('need to build with DLOPEN_SUPPORT=1 to get dlopen support in asm.js');
  
      if (DLFCN.loadedLibNames[filename]) {
        // Already loaded; increment ref count and return.
        var handle = DLFCN.loadedLibNames[filename];
        DLFCN.loadedLibs[handle].refcount++;
        return handle;
      }
  
      if (filename === '__self__') {
        var handle = -1;
        var lib_module = Module;
        var cached_functions = SYMBOL_TABLE;
      } else {
        var target = FS.findObject(filename);
        if (!target || target.isFolder || target.isDevice) {
          DLFCN.errorMsg = 'Could not find dynamic lib: ' + filename;
          return 0;
        } else {
          FS.forceLoadFile(target);
          var lib_data = intArrayToString(target.contents);
        }
  
        try {
          var lib_module = eval(lib_data)(
            DLFCN.functionTable.length,
            Module
          );
        } catch (e) {
          DLFCN.errorMsg = 'Could not evaluate dynamic lib: ' + filename;
          return 0;
        }
  
        // Not all browsers support Object.keys().
        var handle = 1;
        for (var key in DLFCN.loadedLibs) {
          if (DLFCN.loadedLibs.hasOwnProperty(key)) handle++;
        }
  
        // We don't care about RTLD_NOW and RTLD_LAZY.
        if (flag & 256) { // RTLD_GLOBAL
          for (var ident in lib_module) {
            if (lib_module.hasOwnProperty(ident)) {
              Module[ident] = lib_module[ident];
            }
          }
        }
  
        var cached_functions = {};
      }
      DLFCN.loadedLibs[handle] = {
        refcount: 1,
        name: filename,
        module: lib_module,
        cached_functions: cached_functions
      };
      DLFCN.loadedLibNames[filename] = handle;
  
      return handle;
    }

  function _dlsym(handle, symbol) {
      // void *dlsym(void *restrict handle, const char *restrict name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlsym.html
      symbol = '_' + Pointer_stringify(symbol);
  
      if (!DLFCN.loadedLibs[handle]) {
        DLFCN.errorMsg = 'Tried to dlsym() from an unopened handle: ' + handle;
        return 0;
      } else {
        var lib = DLFCN.loadedLibs[handle];
        // self-dlopen means that lib.module is not a superset of
        // cached_functions, so check the latter first
        if (lib.cached_functions.hasOwnProperty(symbol)) {
          return lib.cached_functions[symbol];
        } else {
          if (!lib.module.hasOwnProperty(symbol)) {
            DLFCN.errorMsg = ('Tried to lookup unknown symbol "' + symbol +
                                   '" in dynamic lib: ' + lib.name);
            return 0;
          } else {
            var result = lib.module[symbol];
            if (typeof result == 'function') {
              result = lib.module.SYMBOL_TABLE[symbol];
              assert(result);
              lib.cached_functions = result;
            }
            return result;
          }
        }
      }
    }

  function _dlclose(handle) {
      // int dlclose(void *handle);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/dlclose.html
      if (!DLFCN.loadedLibs[handle]) {
        DLFCN.errorMsg = 'Tried to dlclose() unopened handle: ' + handle;
        return 1;
      } else {
        var lib_record = DLFCN.loadedLibs[handle];
        if (--lib_record.refcount == 0) {
          if (lib_record.module.cleanups) {
            lib_record.module.cleanups.forEach(function(cleanup) { cleanup() });
          }
          delete DLFCN.loadedLibNames[lib_record.name];
          delete DLFCN.loadedLibs[handle];
        }
        return 0;
      }
    }

  function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      var streamObj = FS.getStreamFromPtr(stream);
      if (streamObj) streamObj.error = false;
    }

  function _strpbrk(ptr1, ptr2) {
      var curr;
      var searchSet = {};
      while (1) {
        var curr = HEAP8[((ptr2++)|0)];
        if (!curr) break;
        searchSet[curr] = 1;
      }
      while (1) {
        curr = HEAP8[(ptr1)];
        if (!curr) break;
        if (curr in searchSet) return ptr1;
        ptr1++;
      }
      return 0;
    }

  
   
  Module["_saveSetjmp"] = _saveSetjmp;
  
   
  Module["_testSetjmp"] = _testSetjmp;var _setjmp=undefined;

  function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }

  var _abs=Math_abs;


  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }

  
  function _copysign(a, b) {
      return __reallyNegative(a) === __reallyNegative(b) ? a : -a;
    }var _copysignl=_copysign;

  
  function _fmod(x, y) {
      return x % y;
    }var _fmodl=_fmod;

   
  Module["_tolower"] = _tolower;






  var Browser={mainLoop:{scheduler:null,method:"",shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
  
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
  
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        var ctx;
        var errorInfo = '?';
        function onContextCreationError(event) {
          errorInfo = event.statusMessage || errorInfo;
        }
        try {
          if (useWebGL) {
            var contextAttributes = {
              antialias: false,
              alpha: false
            };
  
            if (webGLContextAttributes) {
              for (var attribute in webGLContextAttributes) {
                contextAttributes[attribute] = webGLContextAttributes[attribute];
              }
            }
  
  
            canvas.addEventListener('webglcontextcreationerror', onContextCreationError, false);
            try {
              ['experimental-webgl', 'webgl'].some(function(webglId) {
                return ctx = canvas.getContext(webglId, contextAttributes);
              });
            } finally {
              canvas.removeEventListener('webglcontextcreationerror', onContextCreationError, false);
            }
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas: ' + [errorInfo, e]);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
  
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          GLctx = Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
  
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
  
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
  
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          setTimeout(func, 1000/60);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           window['setTimeout'];
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        return Math.max(-1, Math.min(1, event.type === 'DOMMouseScroll' ? event.detail : -event.wheelDelta));
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (scrollX + rect.left);
              y = t.pageY - (scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (scrollX + rect.left);
            y = event.pageY - (scrollY + rect.top);
          }
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); NODEFS.staticInit(); }
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
___buildEnvironment(ENV);
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___strtok_state = Runtime.staticAlloc(4);
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + 5242880;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");


var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiifi(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiifi"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vid(index,a1,a2) {
  try {
    Module["dynCall_vid"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiif(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiif"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiffiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiffiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viifi(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viifi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viidi(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viidi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_fiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    return Module["dynCall_iiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiiiiiiiffi(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    return Module["dynCall_fiiiiiiiffi"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iffiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iffiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiid(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiid"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    return Module["dynCall_iiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
  try {
    return Module["dynCall_iiiiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiffi(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiffi"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    return Module["dynCall_iiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_dd(index,a1) {
  try {
    return Module["dynCall_dd"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14) {
  try {
    Module["dynCall_viiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    return Module["dynCall_iiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiifi(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiifi"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiif(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiif"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    Module["dynCall_viiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_diii(index,a1,a2,a3) {
  try {
    return Module["dynCall_diii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_didd(index,a1,a2,a3) {
  try {
    return Module["dynCall_didd"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiidiiidi(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    return Module["dynCall_iiiiiiidiiidi"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    Module["dynCall_viiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiif(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiif"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_did(index,a1,a2) {
  try {
    return Module["dynCall_did"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiifii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiifii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viif(index,a1,a2,a3) {
  try {
    Module["dynCall_viif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiffi(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiffi"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiddddd(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    Module["dynCall_viiiiiiiddddd"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._vp8_mode_contexts|0;var p=env._stdout|0;var q=env._stderr|0;var r=+env.NaN;var s=+env.Infinity;var t=0;var u=0;var v=0;var w=0;var x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0.0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=0;var Q=global.Math.floor;var R=global.Math.abs;var S=global.Math.sqrt;var T=global.Math.pow;var U=global.Math.cos;var V=global.Math.sin;var W=global.Math.tan;var X=global.Math.acos;var Y=global.Math.asin;var Z=global.Math.atan;var _=global.Math.atan2;var $=global.Math.exp;var aa=global.Math.log;var ba=global.Math.ceil;var ca=global.Math.imul;var da=env.abort;var ea=env.assert;var fa=env.asmPrintInt;var ga=env.asmPrintFloat;var ha=env.min;var ia=env.invoke_iiiiiiii;var ja=env.invoke_viiiiiifi;var ka=env.invoke_vid;var la=env.invoke_viiiii;var ma=env.invoke_vi;var na=env.invoke_vii;var oa=env.invoke_iiiiiii;var pa=env.invoke_viiiif;var qa=env.invoke_viiiffiii;var ra=env.invoke_ii;var sa=env.invoke_viiiiiiiiiii;var ta=env.invoke_viifi;var ua=env.invoke_viidi;var va=env.invoke_viiiiiiiiiif;var wa=env.invoke_fiii;var xa=env.invoke_iiiiiiiiiiii;var ya=env.invoke_i;var za=env.invoke_fiiiiiiiffi;var Aa=env.invoke_iiii;var Ba=env.invoke_iffiiiii;var Ca=env.invoke_viiiiiiii;var Da=env.invoke_viiiiiiif;var Ea=env.invoke_fii;var Fa=env.invoke_iiid;var Ga=env.invoke_iiiiiiiiii;var Ha=env.invoke_iiiiiiiiiiiiiiii;var Ia=env.invoke_viiiffi;var Ja=env.invoke_iiiiiiiiiii;var Ka=env.invoke_dd;var La=env.invoke_viiiiiiiiiiiiii;var Ma=env.invoke_iiiiiiiiiiiii;var Na=env.invoke_viiiiifi;var Oa=env.invoke_viiiiiii;var Pa=env.invoke_viiiiiiiii;var Qa=env.invoke_viiiiiif;var Ra=env.invoke_viiiiiiiiii;var Sa=env.invoke_iii;var Ta=env.invoke_iiiiii;var Ua=env.invoke_diii;var Va=env.invoke_didd;var Wa=env.invoke_viiiiii;var Xa=env.invoke_iiiiiiidiiidi;var Ya=env.invoke_viiiiiiiiiiii;var Za=env.invoke_viiif;var _a=env.invoke_did;var $a=env.invoke_viiiifii;var ab=env.invoke_viii;var bb=env.invoke_v;var cb=env.invoke_iiiiiiiii;var db=env.invoke_iiiii;var eb=env.invoke_viif;var fb=env.invoke_viiffi;var gb=env.invoke_viiiiiiiddddd;var hb=env.invoke_viiii;var ib=env._llvm_lifetime_end;var jb=env._lseek;var kb=env._sysconf;var lb=env.__scanString;var mb=env._llvm_prefetch;var nb=env._fclose;var ob=env._mkdir;var pb=env._strtoul;var qb=env._fflush;var rb=env._strtol;var sb=env._fputc;var tb=env._strtok;var ub=env._fwrite;var vb=env._send;var wb=env._llvm_pow_f32;var xb=env._fputs;var yb=env._cbrt;var zb=env._isspace;var Ab=env._localtime;var Bb=env._read;var Cb=env._ceil;var Db=env._strstr;var Eb=env._dlclose;var Fb=env._fileno;var Gb=env._perror;var Hb=env._sbrk;var Ib=env._fsync;var Jb=env._munmap;var Kb=env._signal;var Lb=env._tanh;var Mb=env._fmod;var Nb=env._round;var Ob=env._memchr;var Pb=env._llvm_va_end;var Qb=env._cosf;var Rb=env._snprintf;var Sb=env._fgetc;var Tb=env._stat;var Ub=env._cosh;var Vb=env.__getFloat;var Wb=env._mknod;var Xb=env._hypot;var Yb=env._fgets;var Zb=env._close;var _b=env._strchr;var $b=env._tcgetattr;var ac=env._clock;var bc=env.___setErrNo;var cc=env._access;var dc=env._ftell;var ec=env._abs;var fc=env._exit;var gc=env._sprintf;var hc=env._strrchr;var ic=env._atan2f;var jc=env._setrlimit;var kc=env._fcntl;var lc=env._log2;var mc=env._strcspn;var nc=env.__isLeapYear;var oc=env._copysign;var pc=env._ferror;var qc=env._llvm_uadd_with_overflow_i32;var rc=env._gmtime;var sc=env._localtime_r;var tc=env._sinh;var uc=env._emscripten_memcpy_big;var vc=env._recv;var wc=env.__parseInt64;var xc=env._trunc;var yc=env._cos;var zc=env._putchar;var Ac=env._mkport;var Bc=env._bsearch;var Cc=env._mmap;var Dc=env.__exit;var Ec=env._nanosleep;var Fc=env._strftime;var Gc=env._rename;var Hc=env._tzset;var Ic=env._fabsf;var Jc=env._floorf;var Kc=env._llvm_va_copy;var Lc=env._rint;var Mc=env._dlopen;var Nc=env._sinf;var Oc=env._printf;var Pc=env._pread;var Qc=env._fopen;var Rc=env._open;var Sc=env._sqrtf;var Tc=env._select;var Uc=env._getchar;var Vc=env._usleep;var Wc=env._frexp;var Xc=env.__arraySum;var Yc=env._log;var Zc=env._puts;var _c=env._mktime;var $c=env._fdopen;var ad=env._exp2;var bd=env._scanf;var cd=env._qsort;var dd=env._rmdir;var ed=env._strdup;var fd=env._log10;var gd=env._isatty;var hd=env.__formatString;var id=env._getenv;var jd=env._gettimeofday;var kd=env._atoi;var ld=env._vfprintf;var md=env._llvm_pow_f64;var nd=env._madvise;var od=env._fscanf;var pd=env.___errno_location;var qd=env._strerror;var rd=env._getrusage;var sd=env._fstat;var td=env._llvm_lifetime_start;var ud=env._strspn;var vd=env.__parseInt;var wd=env._ungetc;var xd=env._exp;var yd=env._expf;var zd=env._gmtime_r;var Ad=env._vsnprintf;var Bd=env._sscanf;var Cd=env.___assert_fail;var Dd=env._dlsym;var Ed=env._fread;var Fd=env._strtok_r;var Gd=env._globfree;var Hd=env._abort;var Id=env._fprintf;var Jd=env._strtoll;var Kd=env._tan;var Ld=env.___buildEnvironment;var Md=env.__reallyNegative;var Nd=env.__addDays;var Od=env._atanf;var Pd=env._fabs;var Qd=env._floor;var Rd=env._fseek;var Sd=env._sqrt;var Td=env._write;var Ud=env._rewind;var Vd=env._sin;var Wd=env._ceilf;var Xd=env._longjmp;var Yd=env._tcsetattr;var Zd=env._atan;var _d=env._asin;var $d=env._glob;var ae=env._strpbrk;var be=env._unlink;var ce=env._acos;var de=env._pwrite;var ee=env._strerror_r;var fe=env._atan2;var ge=env._llrint;var he=env._llvm_bswap_i16;var ie=env._time;var je=env._llvm_bswap_i32;var ke=env._setvbuf;var le=0.0;
// EMSCRIPTEN_START_FUNCS
function sR(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;h=i;i=i+72|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=h+64|0;s=f+g|0;if((g|0)<8){t=-1094995529;i=h;return t|0}g=f;u=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=s;if((-4-(f+4)+g|0)<(u|0)|(u|0)<0){t=-1094995529;i=h;return t|0}v=f+(u+8)|0;w=f+(u+4)|0;u=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=(u|0)==0;a:do{if((g-v|0)<4|w){x=v;y=u;z=w}else{f=b;A=p;B=q;C=r;D=(e|0)==0;E=o|0;F=o+4|0;G=b+1132|0;H=b+1136|0;I=v;J=u;b:while(1){K=I+4|0;L=I;M=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;L=K;if((g-L|0)<(M|0)|(M|0)<0){x=K;y=J;z=0;break a}N=I+(M+4)|0;O=J-1|0;P=Ob(K|0,61,M|0)|0;c:do{if((P|0)!=0){Q=P-L|0;R=M-Q|0;S=R-1|0;T=P+1|0;if((P|0)==(K|0)|(S|0)==0){break}U=hJb(Q+1|0)|0;c[p>>2]=U;V=hJb(R)|0;c[q>>2]=V;if((U|0)==0|(V|0)==0){break b}else{W=0;X=U}do{U=a[I+(W+4)|0]|0;a[X+W|0]=((U<<24>>24)-97|0)>>>0<26>>>0?U^32:U;W=W+1|0;X=c[p>>2]|0}while(W>>>0<Q>>>0);a[X+Q|0]=0;nrc(c[q>>2]|0,T|0,S)|0;a[(c[q>>2]|0)+S|0]=0;U=c[p>>2]|0;if((irc(U,2129e3)|0)==0){V=hJb(S)|0;c[r>>2]=V;if((V|0)==0){KIb(f,24,2482224,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;mJb(A);mJb(B);break}R=QFb(V,c[q>>2]|0,S)|0;if((R|0)>0){Z=t$(b,V,R)|0}else{Z=R}mJb(A);mJb(B);mJb(C);if((Z|0)>=0){break}KIb(f,24,2384216,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;break}R=c[q>>2]|0;V=lrc(U|0)|0;d:do{if((V|0)>=9){_=Bd(U|0,2128728,(Y=i,i=i+8|0,c[Y>>2]=j,Y)|0)|0;i=Y;if((_|0)!=1){break}if((V|0)<11){_=Bd(R|0,2105664,(Y=i,i=i+32|0,c[Y>>2]=k,c[Y+8>>2]=l,c[Y+16>>2]=m,c[Y+24>>2]=n,Y)|0)|0;i=Y;if((_|0)<4){break}_=c[j>>2]|0;c[E>>2]=1;c[F>>2]=1e3;$=((((((c[k>>2]|0)*60|0)+(c[l>>2]|0)|0)*60|0)+(c[m>>2]|0)|0)*1e3|0)+(c[n>>2]|0)|0;aY(b,_,o,$,($|0)<0|0?-1:0,0,-2147483648,0)|0;kJb(R)}else{if((irc(U+(V-4)|0,2623680)|0)!=0){break}$=c[G>>2]|0;_=c[j>>2]|0;aa=0;while(1){if(!(aa>>>0<$>>>0)){break d}ba=c[(c[H>>2]|0)+(aa<<2)>>2]|0;if((c[ba>>2]|0)==(_|0)){break}else{aa=aa+1|0}}if((ba|0)==0){break}MGb(ba+32|0,2596720,R,8)|0}kJb(U);break c}}while(0);do{if(!D){if((LGb(c[e>>2]|0,c[p>>2]|0,0,0)|0)==0){break}MGb(e,c[p>>2]|0,2314128,32)|0}}while(0);MGb(e,c[p>>2]|0,c[q>>2]|0,36)|0;mJb(B)}}while(0);K=(O|0)==0;if((g-N|0)<4|K){x=N;y=O;z=K;break a}else{I=N;J=O}}mJb(A);mJb(B);t=-12;i=h;return t|0}}while(0);if((x|0)!=(s|0)){KIb(b,32,2261408,(Y=i,i=i+8|0,c[Y>>2]=g-x,Y)|0);i=Y}if(!z){KIb(b,32,2214568,(Y=i,i=i+8|0,c[Y>>2]=y,Y)|0);i=Y}cL(e,0,1253608);t=0;i=h;return t|0}function tR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;h=c[c[b+12>>2]>>2]|0;j=h+(e*400|0)+12|0;k=h+(e*400|0)|0;l=a[(c[k>>2]|0)+(c[j>>2]|0)|0]|0;m=l&255;n=h+(e*400|0)+392|0;o=c[n>>2]|0;do{if((o|0)==0){p=pJb(336)|0;c[n>>2]=p;if((p|0)==0){q=-12}else{r=p;break}i=f;return q|0}else{r=o}}while(0);if((m&1|0)==0){q=0;i=f;return q|0}o=h+(e*400|0)+16|0;h=c[o>>2]|0;if((h|0)==0|(l&255)>>>0>5>>>0){q=-1094995529;i=f;return q|0}n=m>>>1;m=r+12|0;p=m+(n<<2)|0;if((c[p>>2]|0)!=0){q=-1094995529;i=f;return q|0}do{if((l&255)>>>0>1>>>0){if((c[m>>2]|0)==0){q=-1094995529;i=f;return q|0}if(!((l&255)>>>0>3>>>0)){break}if((c[r+16>>2]|0)==0){q=-1094995529}else{break}i=f;return q|0}}while(0);c[r+(n<<2)>>2]=h;h=pJb(c[o>>2]|0)|0;c[p>>2]=h;if((h|0)==0){q=-12;i=f;return q|0}nrc(h|0,(c[k>>2]|0)+(c[j>>2]|0)|0,c[o>>2]|0)|0;h=c[j>>2]|0;j=c[k>>2]|0;k=a[j+h|0]|0;if((k<<24>>24|0)==3){if(!((wR(b,e)|0)>-1)){q=1;i=f;return q|0}e=r+16|0;p=c[e>>2]|0;n=p+7|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+16|0;if(!(l>>>0<4294967280>>>0)){q=1;i=f;return q|0}if(!(n>>>0<(c[o>>2]|0)>>>0)){q=1;i=f;return q|0}s=p+(l+11)|0;y=0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;a[(c[e>>2]|0)+(l+15)|0]=1;c[r+4>>2]=n;q=1;i=f;return q|0}else if((k<<24>>24|0)==1){if((c[o>>2]|0)!=30){q=-1094995529;i=f;return q|0}o=j+(h+7)|0;if((d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)!=0){q=-1094995529;i=f;return q|0}o=d[j+(h+11)|0]|0;k=c[g+8>>2]|0;n=k+416|0;l=c[n>>2]|0;if(!((l|0)==0|(o|0)==(l|0))){KIb(b,16,2153360,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;q=-1163346256;i=f;return q|0}c[n>>2]=o;o=j+(h+12)|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(h+20)|0;c[k+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=a[j+(h+28)|0]|0;b=o&255;l=b&15;if(l>>>0>b>>>4>>>0){q=-1094995529;i=f;return q|0}if(l>>>0<6>>>0|(o&255)>>>0>223>>>0){q=-1094995529;i=f;return q|0}if((a[j+(h+29)|0]|0)!=1){q=-1094995529;i=f;return q|0}c[k+8>>2]=1;c[k+48>>2]=86021;if((n|0)<=0){q=1;i=f;return q|0}c[k+412>>2]=n;_X(g,64,1,n);q=1;i=f;return q|0}else{n=g+8|0;g=(c[n>>2]|0)+96|0;k=r;h=r+4|0;j=r+8|0;o=(c[h>>2]|0)+(c[k>>2]|0)+(c[j>>2]|0)|0;l=((o|0)/255|0)+64+o|0;o=iJb(0,l)|0;c[g>>2]=o;do{if((o|0)==0){t=-12;u=(c[n>>2]|0)+100|0}else{mrc(o|0,0,l|0)|0;a[o]=2;b=(C5a(o+1|0,c[k>>2]|0)|0)+1|0;e=(C5a(o+b|0,c[h>>2]|0)|0)+b|0;nrc(o+e|0,c[m>>2]|0,c[k>>2]|0)|0;b=(c[k>>2]|0)+e|0;mJb(m);e=r+16|0;nrc(o+b|0,c[e>>2]|0,c[h>>2]|0)|0;s=(c[h>>2]|0)+b|0;mJb(e);e=r+20|0;nrc(o+s|0,c[e>>2]|0,c[j>>2]|0)|0;b=(c[j>>2]|0)+s|0;mJb(e);e=lJb(g,b+16|0)|0;s=(e|0)<0?e:b;b=c[n>>2]|0;e=b+100|0;if((s|0)<0){t=s;u=e;break}c[e>>2]=s;s=S8a(b,r+24|0)|0;if((s|0)==0){q=1;i=f;return q|0}mJb((c[n>>2]|0)+96|0);c[(c[n>>2]|0)+100>>2]=0;q=s;i=f;return q|0}}while(0);c[u>>2]=0;q=t;i=f;return q|0}return 0}function uR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+8|0;f=e|0;g=c[c[b+12>>2]>>2]|0;h=g+(d*400|0)|0;j=c[g+(d*400|0)+392>>2]|0;c[f>>2]=0;k=g+(d*400|0)+48|0;l=c[k>>2]|0;m=c[k+4>>2]|0;do{if((l|0)==0&(m|0)==0|(l|0)==0&(m|0)==(-2147483648|0)){if((c[g+(d*400|0)+80>>2]&4|0)!=0){break}n=g+(d*400|0)+32|0;o=c[n+4>>2]|0;p=-1;if(!((o|0)>(p|0)|(o|0)==(p|0)&(c[n>>2]|0)>>>0>-1>>>0)){break}p=c[h>>2]|0;o=c[g+(d*400|0)+12>>2]|0;q=j+24|0;U8a(q);r=c[g+(d*400|0)+96>>2]|0;s=T8a(q,p+o|0,1,f)|0;if((s|0)<0){t=g+(d*400|0)+20|0;c[t>>2]=c[t>>2]|2;i=e;return 0}if((c[f>>2]&2|0)!=0){wR(b,d)|0;c[f>>2]=0}t=p+((c[g+(d*400|0)+16>>2]|0)+o)|0;o=g+(d*400|0)+92|0;p=c[o>>2]|0;a:do{if((r|0)<(p|0)){u=r;v=s;w=t;x=t;y=p;while(1){z=g+(d*400|0)+100+u|0;if((a[z]|0)==-1){A=w;B=v;C=255;D=y}else{E=T8a(q,w,1,f)|0;if((E|0)<0){break}if((c[f>>2]&2|0)!=0){wR(b,d)|0;c[f>>2]=0}F=a[z]|0;A=x+(F&255)|0;B=E+v|0;C=F&255;D=c[o>>2]|0}F=u+1|0;if((F|0)<(D|0)){u=F;v=B;w=A;x=x+C|0;y=D}else{H=B;I=16;break a}}y=c[n>>2]|0;J=y;K=c[n+4>>2]|0;L=y}else{H=s;I=16}}while(0);if((I|0)==16){J=H;K=c[n+4>>2]|0;L=c[n>>2]|0}s=xrc(L,K,J,(J|0)<0|0?-1:0)|0;o=G;p=g+(d*400|0)+56|0;c[p>>2]=s;c[p+4>>2]=o;c[k>>2]=s;c[k+4>>2]=o;p=c[(c[b+28>>2]|0)+(d<<2)>>2]|0;t=p+48|0;do{if((c[t>>2]|0)==0&(c[t+4>>2]|0)==(-2147483648|0)){r=0;y=(o|0)>(r|0)|(o|0)==(r|0)&s>>>0>0>>>0;r=y?s:0;x=y?o:0;c[t>>2]=r;c[t+4>>2]=x;y=p+56|0;w=c[y>>2]|0;v=c[y+4>>2]|0;if((w|0)==0&(v|0)==(-2147483648|0)){break}u=xrc(w,v,r,x)|0;c[y>>2]=u;c[y+4>>2]=G}}while(0);p=j+320|0;c[p>>2]=0;c[p+4>>2]=-2147483648;U8a(q)}}while(0);if((c[g+(d*400|0)+16>>2]|0)!=0){J=T8a(j+24|0,(c[h>>2]|0)+(c[g+(d*400|0)+12>>2]|0)|0,1,f)|0;if((J|0)<0){h=g+(d*400|0)+20|0;c[h>>2]=c[h>>2]|2;i=e;return 0}if((c[f>>2]&2|0)!=0){wR(b,d)|0;c[f>>2]=0}c[g+(d*400|0)+24>>2]=J}if((c[g+(d*400|0)+80>>2]&4|0)==0){i=e;return 0}J=c[k>>2]|0;f=c[k+4>>2]|0;if(!((J|0)==0&(f|0)==(-2147483648|0))){k=j+320|0;c[k>>2]=J;c[k+4>>2]=f;c[j+328>>2]=0}if((c[g+(d*400|0)+96>>2]|0)==(c[g+(d*400|0)+92>>2]|0)){f=g+(d*400|0)+32|0;k=j+320|0;J=xrc(c[f>>2]|0,c[f+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;k=j+328|0;f=xrc(J,G,c[k>>2]|0,0)|0;J=f;c[g+(d*400|0)+24>>2]=J;M=J;N=k}else{M=c[g+(d*400|0)+24>>2]|0;N=j+328|0}c[N>>2]=(c[N>>2]|0)+M;i=e;return 0}function vR(a,b){a=a|0;b=b|0;var d=0;d=c[(c[c[a+12>>2]>>2]|0)+(b*400|0)+392>>2]|0;if((d|0)==0){return}mJb(d+12|0);mJb(d+16|0);mJb(d+20|0);return}function wR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[c[a+12>>2]>>2]|0;e=d+(b*400|0)+16|0;if((c[e>>2]|0)>>>0<9>>>0){f=0;return f|0}g=(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+88|0;OGb(g);h=sR(a,g,(c[d+(b*400|0)>>2]|0)+((c[d+(b*400|0)+12>>2]|0)+7)|0,(c[e>>2]|0)-8|0)|0;if((h|0)<0){f=h;return f|0}e=d+(b*400|0)+384|0;mJb(e);a=c[g>>2]|0;if((a|0)==0){c[e>>2]=hJb(1)|0;c[d+(b*400|0)+388>>2]=0;f=h;return f|0}else{c[e>>2]=Y1(a,d+(b*400|0)+388|0)|0;f=h;return f|0}return 0}function xR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=c[c[b+12>>2]>>2]|0;h=c[g+(e*400|0)>>2]|0;j=c[g+(e*400|0)+12>>2]|0;k=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;l=c[g+(e*400|0)+16>>2]|0;if(l>>>0<7>>>0){m=0;i=f;return m|0}if((a[h+j|0]|0)!=79){m=0;i=f;return m|0}e=d[h+(j+5)|0]|0;if((e|0)==2){if((a[h+(j+6)|0]|0)!=32){m=-1094995529;i=f;return m|0}sR(b,k+88|0,h+(j+7)|0,l-7|0)|0;m=1;i=f;return m|0}else if((e|0)==1){if(l>>>0<26>>>0){KIb(b,16,2482112,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=f;return m|0}l=a[h+(j+6)|0]|0;if(l<<24>>24==1){g=h+(j+8)|0;o=(he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;g=k+8|0;p=c[g>>2]|0;c[p+120>>2]=o;o=h+(j+10)|0;c[p+124>>2]=(he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;c[k+80>>2]=d[h+(j+13)|0]<<8|d[h+(j+12)|0]<<16|d[h+(j+14)|0];c[k+84>>2]=d[h+(j+16)|0]<<8|d[h+(j+15)|0]<<16|d[h+(j+17)|0];o=h+(j+18)|0;p=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=h+(j+22)|0;_X(k,64,je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0,p);p=c[g>>2]|0;c[p+8>>2]=0;c[p+48>>2]=141;c[k+236>>2]=2;m=1;i=f;return m|0}else{k=d[h+(j+7)|0]|0;KIb(b,24,2384112,(n=i,i=i+16|0,c[n>>2]=l&255,c[n+8>>2]=k,n)|0);i=n;m=-1094995529;i=f;return m|0}}else{KIb(b,16,2314088,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;m=-1094995529;i=f;return m|0}return 0}function yR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=c[c[b+12>>2]>>2]|0;g=c[f+(e*400|0)>>2]|0;h=c[f+(e*400|0)+12>>2]|0;i=g+h|0;j=f+(e*400|0)+48|0;k=c[j>>2]|0;l=c[j+4>>2]|0;do{if((k|0)==0&(l|0)==0|(k|0)==0&(l|0)==(-2147483648|0)){if((c[f+(e*400|0)+80>>2]&4|0)!=0){break}m=c[f+(e*400|0)+96>>2]|0;n=(d[i]|0)>>>4&1;o=g+((c[f+(e*400|0)+16>>2]|0)+h)|0;p=c[f+(e*400|0)+92>>2]|0;if((m|0)<(p|0)){q=m;m=n;r=o;s=o;while(1){o=a[f+(e*400|0)+100+q|0]|0;t=o&255;if(o<<24>>24==-1){u=r;v=m;w=s+t|0}else{o=s+t|0;u=o;v=((d[r]|0)>>>4&1)+m|0;w=o}o=q+1|0;if((o|0)<(p|0)){q=o;m=v;r=u;s=w}else{x=v;break}}}else{x=n}s=f+(e*400|0)+32|0;r=c[s+4>>2]|0;if((c[s>>2]&1073741816|0)==0&(r&0|0)==0){s=f+(e*400|0)+20|0;c[s>>2]=c[s>>2]|1}s=xrc(r,0,x,(x|0)<0|0?-1:0)|0;r=G;m=f+(e*400|0)+56|0;c[m>>2]=s;c[m+4>>2]=r;c[j>>2]=s;c[j+4>>2]=r;m=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;q=m+48|0;if(!((c[q>>2]|0)==0&(c[q+4>>2]|0)==(-2147483648|0))){break}c[q>>2]=s;c[q+4>>2]=r;q=m+56|0;m=c[q>>2]|0;p=c[q+4>>2]|0;if((m|0)==0&(p|0)==0){break}o=xrc(m,p,s,r)|0;c[q>>2]=o;c[q+4>>2]=G}}while(0);if((c[f+(e*400|0)+16>>2]|0)==0){return 0}c[f+(e*400|0)+24>>2]=(d[i]|0)>>>4&1;return 0}function zR(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=e;h=0;if((d&1073741816|0)==0&(e&0|0)==0){e=(c[c[a+12>>2]>>2]|0)+(b*400|0)+20|0;c[e>>2]=c[e>>2]|1}if((f|0)==0){return(G=h,g)|0}c[f>>2]=g;c[f+4>>2]=h;return(G=h,g)|0}function AR(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[b+4>>2]|0;e=b+8|0;do{if((c[e>>2]|0)>9){if((JI(d,2314080)|0)==0){f=0;break}f=KI(d)|0}else{f=0}}while(0);b=f+5|0;if((c[e>>2]|0)>>>0<b>>>0){g=(f|0)!=0?25:0;return g|0}do{if((grc(d+f|0,2390912,3)|0)==0){if((a[d+(f+4)|0]|0)!=0){break}if((a[d+b|0]|0)==96){g=100}else{break}return g|0}}while(0);g=0;return g|0}function BR(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;g=i;i=i+176|0;h=g|0;j=g+40|0;k=g+48|0;l=g+64|0;m=g+160|0;n=g+168|0;c[m>>2]=0;o=f+12|0;p=c[o>>2]|0;MI(f,2314080,m);q=f+16|0;r=l|0;if((AD(c[q>>2]|0,r,96)|0)<96){s=-1;i=g;return s|0}t=n|0;a[t]=69;a[n+1|0]=65;a[n+2|0]=51;do{if((grc(r,t,3)|0)==0){if((a[l+4|0]|0)!=0){break}if((a[l+5|0]|0)!=96){break}n=fD(c[q>>2]|0,0,0,1)|0;u=p;c[u>>2]=n;c[u+4>>2]=G;u=l+6|0;n=he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;a:do{if(!((n<<16>>16|0)==(-1|0)|(n<<16>>16|0)==(-128|0))){u=c[m>>2]|0;v=j;w=k;x=k|0;z=c[o>>2]|0;c[z+8>>2]=1;A=f;KIb(A,32,2105640,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;b:do{if((u|0)==0){C=13}else{D=u;c:while(1){do{if((irc(c[D>>2]|0,2623672)|0)==0){E=c[D+4>>2]|0;if((E|0)==0){break}F=c[E+12>>2]|0;if((irc(F,2596688)|0)==0){break c}if((irc(F,2572824)|0)==0){break c}}}while(0);F=c[D+8>>2]|0;if((F|0)==0){C=13;break b}else{D=F}}D=E;F=c[D>>2]|0;if(F>>>0<64>>>0){KIb(A,16,2536528,(B=i,i=i+8|0,c[B>>2]=F,B)|0);i=B;break}F=c[E+16>>2]|0;H=F;if(!((d[H]|d[H+1|0]<<8)<<16>>16<<16>>16==256)){KIb(A,24,2520520,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}H=F+2|0;I=he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0;H=z+12|0;b[H>>1]=I;J=F+4|0;K=he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0;J=z+14|0;b[J>>1]=K;L=F+6|0;M=he((d[L]|d[L+1|0]<<8)<<16>>16|0)|0;L=z+16|0;b[L>>1]=M;N=F+8|0;b[z+18>>1]=he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0;if((grc(F+16|0,2506096,12)|0)!=0){KIb(A,16,2491936,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}N=c[D>>2]|0;if(((I&65535)+24+(K&65535)+(M&65535)|0)>>>0>N>>>0|N>>>0<64>>>0){KIb(A,16,2482056,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}N=F+44|0;M=je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0;c[z+20>>2]=M;KIb(A,48,2470936,(B=i,i=i+8|0,c[B>>2]=M,B)|0);i=B;M=z+104|0;N=l+88|0;K=M;I=N|0;O=N+4|0;N=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=K|0;y=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;O=K+4|0;y=N;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;O=h|0;if((MIb()|0)>=48){lY(O,M,8,1)|0;a[h+16|0]=0;KIb(A,48,2398080,(B=i,i=i+16|0,c[B>>2]=2463120,c[B+8>>2]=O,B)|0);i=B}M=b[H>>1]|0;H=b[J>>1]|0;J=b[L>>1]|0;if((MIb()|0)>=48){lY(O,F+((M&65535)+16+(H&65535)+(J&65535))|0,8,1)|0;a[h+16|0]=0;KIb(A,48,2398080,(B=i,i=i+16|0,c[B>>2]=2447480,c[B+8>>2]=O,B)|0);i=B}J=c[f+1100>>2]|0;do{if((J|0)>0){H=c[f+1096>>2]|0;M=c[o>>2]|0;L=(H|0)!=0;N=(H|0)==0;if(N&(L^1)){break}K=(J|0)>16?16:J;if(L){L=M+24|0;if((L|0)!=(H|0)){mrc(L|0,0,24)|0;nrc(L|0,H|0,K)|0}L=H;I=M+40|0;P=L|0;Q=L+4|0;L=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=I|0;y=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=I+4|0;y=L;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y}if(N){break}N=M+48|0;if((N|0)!=(H|0)){mrc(N|0,0,24)|0;nrc(N|0,H|0,K)|0}K=H;H=M+64|0;M=K|0;N=K+4|0;K=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;N=H|0;y=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;N=H+4|0;y=K;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y}}while(0);J=z+24|0;c[j>>2]=0;c[j+4>>2]=0;do{if((grc(J,v,8)|0)==0){R=z+48|0;C=40}else{if((ER(c[o>>2]|0,F,c[D>>2]|0,J)|0)>=0){break}N=z+48|0;if((FR(f,F,c[D>>2]|0,N)|0)<0){R=N;C=40}}}while(0);do{if((C|0)==40){N=k+8|0;K=0;while(1){if(!(K>>>0<6>>>0)){break}H=1012736+(K<<3)|0;M=c[H>>2]|0;Q=c[H+4>>2]|0;c[x>>2]=M;c[x+4>>2]=Q;H=1012736+((K|1)<<3)|0;L=c[H+4>>2]|0;c[N>>2]=c[H>>2];c[N+4>>2]=L;L=c[o>>2]|0;H=L+24|0;if((H|0)==(w|0)){S=Q;T=M}else{mrc(H|0,0,24)|0;nrc(H|0,w|0,16)|0;S=c[x+4>>2]|0;T=c[x>>2]|0}H=L+40|0;M=H|0;y=T;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;M=H+4|0;y=S;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;M=L+48|0;if((M|0)!=(w|0)){mrc(M|0,0,24)|0;nrc(M|0,w|0,16)|0}M=L+64|0;L=c[x+4>>2]|0;H=M|0;y=c[x>>2]|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=M+4|0;y=L;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;if((ER(c[o>>2]|0,F,c[D>>2]|0,J)|0)==0){C=48;break}if((FR(f,F,c[D>>2]|0,R)|0)==0){C=48;break}else{K=K+2|0}}if((C|0)==48){if(!(K>>>0>5>>>0)){break}}KIb(A,16,2432624,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}}while(0);D=z+112|0;FGb(D,z+72|0,64,0)|0;J=z+96|0;GGb(D,J,F+56|0,1,0,0);if((MIb()|0)>=48){lY(O,J,8,1)|0;a[h+16|0]=0;KIb(A,48,2398080,(B=i,i=i+16|0,c[B>>2]=2423904,c[B+8>>2]=O,B)|0);i=B}FGb(D,J,64,1)|0;break a}}while(0);if((C|0)==13){KIb(A,16,2554424,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}NI(m);s=-1;i=g;return s|0}}while(0);NI(m);n=a[l+33|0]|0;z=d[l+34|0]|0;x=z<<8|(n&255)<<16|d[l+35|0];w=ZX(f,0)|0;if((w|0)==0){s=-12;i=g;return s|0}v=w+48|0;c[v>>2]=0;c[v+4>>2]=0;v=w+8|0;u=c[v>>2]|0;c[u+8>>2]=1;J=l+32|0;D=d[J]|0;c[u+52>>2]=D;u=JX(1334784,D)|0;D=c[v>>2]|0;c[D+48>>2]=u;N=d[J]|0;do{if((N|0)==0){J=(e[1334600+(z>>>5<<1)>>1]|0)*100|0;if((J|0)==0){KIb(f,16,2214504,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;s=-1094995529;i=g;return s|0}else if((J|0)==44100){U=D}else{QIb(f,2181560,(B=i,i=i+8|0,c[B>>2]=J,B)|0);i=B;U=c[v>>2]|0}H=x<<3&8184;c[U+416>>2]=2;L=U+448|0;c[L>>2]=3;c[L+4>>2]=0;c[U+412>>2]=J;c[U+72>>2]=(ca(H<<3,J)|0)/1024|0;if((PX(U,14)|0)==0){L=c[(c[v>>2]|0)+96>>2]|0;M=L;y=1;a[M]=y;y=y>>8;a[M+1|0]=y;M=L+2|0;y=J;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;M=(n&255)>>>1&1;J=L+6|0;y=M;a[J]=y;y=y>>8;a[J+1|0]=y;J=L+8|0;y=M;a[J]=y;y=y>>8;a[J+1|0]=y;J=L+10|0;y=1;a[J]=y;y=y>>8;a[J+1|0]=y;_X(w,64,1,c[(c[v>>2]|0)+412>>2]|0);V=H;break}else{s=-12;i=g;return s|0}}else if((N|0)==1){H=z>>>2&7;if((H|0)==0){KIb(f,16,2153288,(B=i,i=i+8|0,c[B>>2]=0,B)|0);i=B;s=-1094995529;i=g;return s|0}J=H-1|0;H=1334856+(J<<3)|0;L=c[H+4>>2]|0;M=D+448|0;c[M>>2]=c[H>>2];c[M+4>>2]=L;c[D+416>>2]=c[1334824+(J<<2)>>2];J=(x<<3&8184)+8|0;L=(e[1334600+(z>>>5<<1)>>1]|0)*100|0;if((L|0)!=0){c[D+412>>2]=L;c[D+72>>2]=(ca(J<<3,L)|0)/2048|0;_X(w,64,1,L);V=J;break}KIb(f,16,2214504,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;s=-1094995529;i=g;return s|0}else if((N|0)==3){c[w+236>>2]=1463898624;V=1024}else if((N|0)==4){c[D+416>>2]=2;J=D+448|0;c[J>>2]=3;c[J+4>>2]=0;c[D+412>>2]=44100;c[D+72>>2]=1411200;J=g5a(u)|0;L=c[v>>2]|0;c[L+792>>2]=J;_X(w,64,1,c[L+412>>2]|0);V=1024}else{KIb(f,16,2128624,(B=i,i=i+8|0,c[B>>2]=N,B)|0);i=B;s=-38;i=g;return s|0}}while(0);c[(c[v>>2]|0)+432>>2]=V;s=0;i=g;return s|0}}while(0);KIb(f,16,2261344,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;s=-1094995529;i=g;return s|0}function CR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[b+12>>2]|0;f=c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+432>>2]|0;g=fX(c[b+16>>2]|0,d,f)|0;if((g|0)<(f|0)){b=d+36|0;c[b>>2]=c[b>>2]|2}if((g|0)<0){h=g;return h|0}if((g|0)==0){h=-541478725;return h|0}c[d+32>>2]=0;if((c[e+8>>2]|0)==0){h=g;return h|0}if((g|0)==(f|0)){b=c[d+24>>2]|0;GGb(e+112|0,b,b,f>>3,e+104|0,1);h=f;return h|0}else{f=e+104|0;e=f|0;y=0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=f+4|0;y=0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;h=g;return h|0}return 0}function DR(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c[b+12>>2]|0;i=SR(b,d,e,f,g)|0;if((c[h+8>>2]|0)==0){j=i;return j|0}do{if((i|0)==0){g=b+16|0;f=fD(c[g>>2]|0,0,0,1)|0;e=G;d=h;k=c[d+4>>2]|0;if(e>>>0<k>>>0|e>>>0==k>>>0&f>>>0<(c[d>>2]|0)>>>0){l=0;break}d=fD(c[g>>2]|0,-8,-1,1)|0;f=d;if((f|0)<0){l=f;break}f=AD(c[g>>2]|0,h+104|0,8)|0;if((f|0)<8){l=(f|0)>-1?-541478725:f;break}else{j=0;return j|0}}else{l=i}}while(0);i=h+104|0;h=i|0;y=0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=i+4|0;y=0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;j=l;return j|0}function ER(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+392|0;g=f|0;if((b|0)==0|(d|0)==0){h=-1;i=f;return h|0}j=a+12|0;k=a+14|0;l=a+16|0;if(((e[j>>1]|0)+16+(e[k>>1]|0)+(e[l>>1]|0)|0)>>>0>c>>>0|c>>>0<49>>>0){h=-1;i=f;return h|0}FGb(g,d,192,1)|0;d=a+72|0;GGb(g,d,b+48|0,1,0,1);FGb(g,d,64,0)|0;d=a+80|0;GGb(g,d,0,1,0,0);c=(e[j>>1]|0)+16+(e[k>>1]|0)|0;FGb(g,d,64,0)|0;d=a+88|0;IGb(g,d,b+c|0,(e[l>>1]|0)>>>3);h=((grc(b+((e[l>>1]|0)+c)|0,d,8)|0)!=0)<<31>>31;i=f;return h|0}function FR(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0;j=i;i=i+392|0;k=j|0;l=b+12|0;m=c[l>>2]|0;if((f|0)==0|(h|0)==0){n=-1;i=j;return n|0}o=e[m+12>>1]|0;if((o+20|0)>>>0>g>>>0){n=-1;i=j;return n|0}p=o+16|0;o=p;q=0;r=(grc(f+p|0,2413096,4)|0)==0;p=wrc(o,q,32,0)|0;s=r?p:o;o=r?G:q;q=g;r=0;p=wrc(s,o,44,0)|0;t=G;if(r>>>0<t>>>0|r>>>0==t>>>0&q>>>0<p>>>0){n=-1;i=j;return n|0}p=f+s|0;t=je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if((t|0)!=(c[m+20>>2]|0)){KIb(b,48,2405392,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b}b=wrc(s,o,32,0)|0;t=f+b|0;b=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=wrc(s,o,36,0)|0;p=f+t|0;t=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)>>>4;p=wrc(b+44|0,0,s,o)|0;o=G;s=t;b=wrc(s<<4|0>>>28,0<<4|s>>>28,p,o)|0;s=G;if(s>>>0>r>>>0|s>>>0==r>>>0&b>>>0>q>>>0){n=-1;i=j;return n|0}FGb(k,h,192,1)|0;h=m+24|0;q=h;if((h|0)==0){b=t;r=o;s=p;while(1){if((b|0)==0){n=-1;u=14;break}GGb(k,0,f+s|0,2,0,1);v=(ER(c[l>>2]|0,f,g,0)|0)==0;w=wrc(s,r,16,0)|0;if(v){n=0;u=14;break}else{b=b-1|0;r=G;s=w}}if((u|0)==14){i=j;return n|0}}else{x=t;z=o;A=p}while(1){if((x|0)==0){n=-1;u=14;break}GGb(k,h,f+A|0,2,0,1);p=c[l>>2]|0;o=p+24|0;if((p|0)!=(m|0)){mrc(o|0,0,24)|0;nrc(o|0,h|0,16)|0}o=p+40|0;p=q|0;t=q+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=o+4|0;y=s;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(ER(c[l>>2]|0,f,g,h)|0)==0;s=wrc(A,z,16,0)|0;if(t){n=0;u=14;break}else{x=x-1|0;z=G;A=s}}if((u|0)==14){i=j;return n|0}return 0}function GR(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[(c[c[d+28>>2]>>2]|0)+8>>2]|0;g=f+412|0;h=0;while(1){j=b[1334600+(h<<1)>>1]|0;if(j<<16>>16==0){k=3;break}if(((j&65535)*100|0|0)==(c[g>>2]|0)){break}else{h=h+1|0}}if((k|0)==3){KIb(d,16,2313872,(l=i,i=i+8|0,c[l>>2]=c[g>>2],l)|0);i=l;m=-22;i=e;return m|0}G$(d,3,2261216)|0;g=d+16|0;kD(c[g>>2]|0,3359045);bD(c[g>>2]|0,0);bD(c[g>>2]|0,96);oD(c[g>>2]|0,65535);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);k=c[f+52>>2]|0;if((k|0)==1){lD(c[g>>2]|0,h<<13|c[f+416>>2]<<10|((c[f+432>>2]|0)/8|0)-1|16777216)}else if((k|0)==0){if((c[f+416>>2]|0)!=2){KIb(d,16,2181424,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=e;return m|0}j=c[f+100>>2]|0;if((j|0)==14){n=(a[(c[f+96>>2]|0)+6|0]|0)!=0}else if((j|0)==10){n=(a[(c[f+96>>2]|0)+8|0]|0)==18}else{KIb(d,16,2153208,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=e;return m|0}lD(c[g>>2]|0,(n&1)<<17|h<<13|((c[f+432>>2]|0)/8|0))}else{KIb(d,16,2128536,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;m=-22;i=e;return m|0}kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);kD(c[g>>2]|0,0);m=0;i=e;return m|0}function HR(){var a=0,b=0,d=0,e=0;a=hJb(1336)|0;b=a;if((a|0)==0){d=b;return d|0}mrc(a|0,0,1336)|0;c[a>>2]=2004056;SJb(a);e=pJb(4)|0;c[a+1296>>2]=e;if((e|0)!=0){d=b;return d|0}pX(b);d=0;return d|0}function IR(){return 2004056}function JR(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((b|0)!=0){d=c[b>>2]|0;return d|0}b=c[a+8>>2]|0;if((b|0)==0){d=2111720;return d|0}d=c[b>>2]|0;return d|0}function KR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if((b|0)==0){d=c[a+12>>2]|0;if((d|0)==0){break}e=c[a+4>>2]|0;do{if((e|0)!=0){if((c[e+20>>2]|0)==0){break}else{f=d}return f|0}}while(0);e=c[a+8>>2]|0;if((e|0)==0){break}if((c[e+36>>2]|0)==0){break}else{f=d}return f|0}}while(0);e=c[a+16>>2]|0;do{if((e|0)!=0){if((c[e>>2]|0)==0){break}a=e;if((a|0)==(b|0)){break}else{f=a}return f|0}}while(0);f=0;return f|0}function LR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)==0){b=1241280;return b|0}else{d=0}while(1){e=bH(d)|0;if((e|0)==0){f=0;g=4;break}if((c[e+20>>2]|0)==(a|0)){h=e;g=6;break}else{d=e}}a:do{if((g|0)==4){while(1){g=0;d=cH(f)|0;if((d|0)==0){h=0;g=6;break a}if((c[d+36>>2]|0)==(a|0)){i=d;break}else{f=d;g=4}}}}while(0);b:do{if((g|0)==6){while(1){g=0;f=bH(h)|0;if((f|0)==0){i=0;break b}a=c[f+20>>2]|0;if((a|0)==0){h=f;g=6}else{b=a;break}}return b|0}}while(0);while(1){h=cH(i)|0;if((h|0)==0){b=0;g=10;break}a=c[h+36>>2]|0;if((a|0)==0){i=h}else{b=a;g=10;break}}if((g|0)==10){return b|0}return 0}function MR(a){a=a|0;return((c[a+4>>2]|0)==0?3:4)|0}function NR(a){a=a|0;var b=0;do{if((c[a+8>>2]|0)>>>0>54>>>0){if((grc(c[a+4>>2]|0,2383464,55)|0)==0){b=100}else{break}return b|0}}while(0);b=0;return b|0}function OR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;hD(f,132,0)|0;g=ZX(a,0)|0;if((g|0)==0){h=-12;return h|0}i=g+48|0;c[i>>2]=0;c[i+4>>2]=0;i=FD(f)|0;j=d+8|0;c[j>>2]=i;k=i;i=0;l=g+56|0;c[l>>2]=k;c[l+4>>2]=i;l=g+64|0;c[l>>2]=k;c[l+4>>2]=i;hD(f,4,0)|0;i=FD(f)|0;l=g+8|0;c[(c[l>>2]|0)+120>>2]=i;i=FD(f)|0;c[(c[l>>2]|0)+124>>2]=i;hD(f,4,0)|0;i=c[l>>2]|0;c[i+8>>2]=0;c[i+52>>2]=0;c[i+48>>2]=1346455126;_X(g,64,1,10);g=ZX(a,0)|0;if((g|0)==0){h=-12;return h|0}a=g+48|0;c[a>>2]=0;c[a+4>>2]=0;a=c[g+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=0;c[a+48>>2]=1346455105;c[a+416>>2]=2;i=a+448|0;c[i>>2]=3;c[i+4>>2]=0;c[a+412>>2]=22050;_X(g,64,1,22050);g=d;c[g>>2]=FD(f)|0;a=d+16|0;c[a>>2]=FD(f)|0;i=d+4|0;c[i>>2]=FD(f)|0;l=d+12|0;c[l>>2]=FD(f)|0;k=d+20|0;c[k>>2]=FD(f)|0;m=FD(f)|0;n=d+24|0;c[n>>2]=m;o=c[g>>2]|0;if(o>>>0<175>>>0|m>>>0<2>>>0){h=-1094995529;return h|0}p=c[k>>2]|0;if((p|0)==0){h=-1094995529;return h|0}q=c[i>>2]|0;if((q|0)==0){h=-1094995529;return h|0}r=c[j>>2]|0;if((r|0)==0){h=-1094995529;return h|0}if((c[a>>2]|0)==0|o>>>0>2048>>>0|p>>>0>2048>>>0|m>>>0>2048>>>0|r>>>0>536870911>>>0|q>>>0>536870911>>>0){h=-1094995529;return h|0}q=d+40|0;c[q>>2]=pJb(r<<2)|0;r=d+44|0;c[r>>2]=pJb(c[j>>2]<<2)|0;m=d+48|0;c[m>>2]=pJb(c[i>>2]<<2)|0;p=ca(c[g>>2]|0,c[k>>2]|0)|0;c[d+56>>2]=p;k=d+52|0;c[k>>2]=pJb(p)|0;p=ca(c[g>>2]|0,c[n>>2]|0)|0;n=d+68|0;c[n>>2]=p;o=d+60|0;c[o>>2]=pJb(p)|0;p=pJb(c[n>>2]|0)|0;c[d+64>>2]=p;do{if((c[q>>2]|0)!=0){if((c[r>>2]|0)==0){break}if((c[m>>2]|0)==0){break}if((c[k>>2]|0)==0){break}if((c[o>>2]|0)==0|(p|0)==0){break}fD(f,c[g>>2]|0,0,0)|0;n=c[q>>2]|0;a=c[j>>2]|0;s=c[e>>2]|0;if((a|0)==0){t=s}else{u=0;v=s;while(1){c[n+(u<<2)>>2]=FD(v)|0;s=u+1|0;w=c[e>>2]|0;if(s>>>0<a>>>0){u=s;v=w}else{t=w;break}}}hD(t,(a+511&1073741312)-a<<2,0)|0;v=c[r>>2]|0;u=c[j>>2]|0;n=c[e>>2]|0;if((u|0)==0){x=n}else{w=0;s=n;while(1){c[v+(w<<2)>>2]=FD(s)|0;n=w+1|0;y=c[e>>2]|0;if(n>>>0<u>>>0){w=n;s=y}else{x=y;break}}}hD(x,(u+511&1073741312)-u<<2,0)|0;s=c[m>>2]|0;w=c[i>>2]|0;v=c[e>>2]|0;if((w|0)==0){z=v}else{a=0;y=v;while(1){c[s+(a<<2)>>2]=FD(y)|0;v=a+1|0;n=c[e>>2]|0;if(v>>>0<w>>>0){a=v;y=n}else{z=n;break}}}hD(z,(w+511&1073741312)-w<<2,0)|0;c[d+72>>2]=0;c[d+28>>2]=0;c[d+36>>2]=0;fD(f,c[l>>2]|0,0,0)|0;h=0;return h|0}}while(0);l=c[b>>2]|0;mJb(l+40|0);mJb(l+44|0);mJb(l+48|0);mJb(l+52|0);mJb(l+60|0);mJb(l+64|0);h=-12;return h|0}function PR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;b=e+28|0;if(!((c[b>>2]|0)>>>0<(c[e+8>>2]|0)>>>0)){g=-541478725;return g|0}if((jD(f)|0)!=0){g=-541478725;return g|0}h=e+72|0;if((c[h>>2]|0)!=0){i=e+68|0;if((K1(d,c[i>>2]|0)|0)<0){g=-12;return g|0}nrc(c[d+24>>2]|0,c[e+64>>2]|0,c[i>>2]|0)|0;c[d+48>>2]=((c[i>>2]|0)/4922|0)*2205|0;i=d+36|0;c[i>>2]=c[i>>2]|1;c[d+32>>2]=1;c[h>>2]=0;g=c[d+28>>2]|0;return g|0}i=c[b>>2]|0;if((i|0)==0){j=e+16|0}else{j=(c[e+40>>2]|0)+(i-1<<2)|0}k=c[j>>2]|0;do{if((k|0)==0){l=i;m=e+56|0}else{j=e+36|0;n=e+4|0;o=e+48|0;p=e+68|0;q=e;r=e+60|0;s=e+24|0;t=e+64|0;u=e+56|0;v=e+52|0;w=0;x=c[j>>2]|0;a:while(1){if(!(x>>>0<(c[n>>2]|0)>>>0)){g=-1094995529;y=26;break}z=c[(c[o>>2]|0)+(x<<2)>>2]|0;A=z&2147483647;do{if((z|0)<0){B=c[q>>2]|0;if(A>>>0>((c[p>>2]|0)-B|0)>>>0){g=-1094995529;y=26;break a}AD(f,(c[r>>2]|0)+A|0,B)|0;if((A|0)!=(ca((c[s>>2]|0)-2|0,c[q>>2]|0)|0)){break}nrc(c[t>>2]|0,c[r>>2]|0,c[p>>2]|0)|0;c[h>>2]=1}else{B=c[q>>2]|0;if(A>>>0>((c[u>>2]|0)-B|0)>>>0){g=-1094995529;y=26;break a}AD(f,(c[v>>2]|0)+A|0,B)|0}}while(0);A=(c[j>>2]|0)+1|0;c[j>>2]=A;z=w+1|0;if(z>>>0<k>>>0){w=z;x=A}else{y=20;break}}if((y|0)==20){l=c[b>>2]|0;m=u;break}else if((y|0)==26){return g|0}}}while(0);y=e+44|0;k=c[(c[y>>2]|0)+(l<<2)>>2]|0;l=c[m>>2]|0;if(!(k>>>0<l>>>0)){g=-1094995529;return g|0}m=l-k|0;if((K1(d,m)|0)<0){g=-12;return g|0}c[d+32>>2]=0;c[d+48>>2]=1;k=d+24|0;nrc(c[k>>2]|0,(c[e+52>>2]|0)+(c[(c[y>>2]|0)+(c[b>>2]<<2)>>2]|0)|0,m)|0;if(!((a[c[k>>2]|0]&32)==0)){k=d+36|0;c[k>>2]=c[k>>2]|1}c[b>>2]=(c[b>>2]|0)+1;g=c[d+28>>2]|0;return g|0}function QR(a){a=a|0;var b=0;b=c[a+12>>2]|0;mJb(b+40|0);mJb(b+44|0);mJb(b+48|0);mJb(b+52|0);mJb(b+60|0);mJb(b+64|0);return 0}function RR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+432>>2]<<10;if((d|0)<1){e=-22;return e|0}f=fX(c[a+16>>2]|0,b,d)|0;d=b+36|0;c[d>>2]=c[d>>2]&-3;c[b+32>>2]=0;e=f;return e|0}function SR(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[c[a+28>>2]>>2]|0;g=b+8|0;h=c[g>>2]|0;i=c[h+432>>2]|0;if((i|0)==0){j=g5a(c[h+48>>2]|0)|0;k=c[g>>2]|0;l=(ca(c[k+416>>2]|0,j)|0)>>3;m=k}else{l=i;m=h}h=c[m+72>>2]|0;if((h|0)==0){n=ca(c[m+412>>2]|0,l)|0}else{n=h>>3}if((l|0)<1|(n|0)<1){return-1|0}else{h=0;m=(e|0)<(h|0)|(e|0)==(h|0)&d>>>0<0>>>0;h=n;i=(n|0)<0|0?-1:0;n=Erc(h,i,m?0:d,m?0:e)|0;e=G;m=c[b+40>>2]|0;d=m;k=(m|0)<0|0?-1:0;m=c[b+44>>2]|0;j=m;g=(m|0)<0|0?-1:0;m=l;o=(l|0)<0|0?-1:0;l=Erc(j,g,m,o)|0;p=UIb(n,e,d,k,l,G,f&1^3)|0;f=Erc(p,G,m,o)|0;o=G;m=Erc(d,k,h,i)|0;i=VIb(f,o,j,g,m,G)|0;m=b+208|0;c[m>>2]=i;c[m+4>>2]=G;m=c[a+16>>2]|0;i=a+1248|0;a=wrc(c[i>>2]|0,c[i+4>>2]|0,f,o)|0;o=fD(m,a,G,0)|0;a=G;m=0;return((a|0)<(m|0)|(a|0)==(m|0)&o>>>0<0>>>0?o:0)|0}return 0}function TR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+12>>2]|0;e=ZX(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=e+8|0;h=c[g>>2]|0;c[h+8>>2]=1;j=c[(c[a+4>>2]|0)+28>>2]|0;c[h+48>>2]=j;c[h+412>>2]=c[d+4>>2];c[h+416>>2]=c[d+8>>2];d=g5a(j)|0;j=c[g>>2]|0;c[j+792>>2]=d;if((d|0)<=0){KIb(0,0,2181504,(g=i,i=i+24|0,c[g>>2]=2179264,c[g+8>>2]=2177600,c[g+16>>2]=53,g)|0);i=g;Hd();return 0}c[j+432>>2]=(ca(c[j+416>>2]|0,d)|0)/8|0;_X(e,64,1,c[j+412>>2]|0);f=0;i=b;return f|0}function UR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+24|0;d=c[a+4>>2]|0;a=Bd(d|0,2213328,(e=i,i=i+24|0,c[e>>2]=b+8,c[e+8>>2]=b+16,c[e+16>>2]=b,e)|0)|0;i=e;do{if((a|0)==3){e=(mc(d|0,2311928)|0)+1|0;f=e+(mc(d+e|0,2311928)|0)|0;if((mc(d|0,2380712)|0)>>>0>f>>>0){g=100}else{break}i=b;return g|0}}while(0);g=0;i=b;return g|0}function VR(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+4112|0;e=d|0;f=d+8|0;g=d+16|0;h=c[b+12>>2]|0;j=ZX(b,0)|0;if((j|0)==0){k=-12;i=d;return k|0}_X(j,64,1,10);l=c[j+8>>2]|0;c[l+8>>2]=3;c[l+48>>2]=1349012051;l=b+16|0;a:do{if((jD(c[l>>2]|0)|0)==0){b=g|0;j=h;b:while(1){m=fD(c[l>>2]|0,0,0,1)|0;n=G;if((KD(c[l>>2]|0,b,4096)|0)==0){o=j;break a}a[g+(mc(b|0,2380712)|0)|0]=0;p=Bd(b|0,2259512,(q=i,i=i+16|0,c[q>>2]=e,c[q+8>>2]=f,q)|0)|0;i=q;do{if((p|0)==2){q=mc(b|0,2311928)|0;r=((a[g+q|0]|0)!=0)+q|0;q=g+r|0;s=c[e>>2]|0;t=c[e+4>>2]|0;u=xrc(c[f>>2]|0,c[f+4>>2]|0,s,t)|0;if((s|0)==0&(t|0)==(-2147483648|0)){break}a[g+((mc(q|0,2311928)|0)+r)|0]=0;r=IV(j,q,lrc(q|0)|0,0)|0;if((r|0)==0){k=-12;break b}q=r+64|0;c[q>>2]=m;c[q+4>>2]=n;q=r+8|0;c[q>>2]=s;c[q+4>>2]=t;c[r+48>>2]=u}}while(0);if((jD(c[l>>2]|0)|0)!=0){o=j;break a}}i=d;return k|0}else{o=h}}while(0);JV(o);k=0;i=d;return k|0}function WR(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function XR(a){a=a|0;OV(c[a+12>>2]|0);return 0}function YR(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function ZR(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1836084592){e=b+4|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==1){f=100}else{break}return f|0}}while(0);f=0;return f|0}function _R(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=iD(e)|0;g=G;h=ZX(a,0)|0;if((h|0)==0){j=-12;i=b;return j|0}k=h+8|0;c[(c[k>>2]|0)+8>>2]=0;hD(e,8,0)|0;l=FD(e)|0;if((l|0)==0){c[(c[k>>2]|0)+48>>2]=13}else if((l|0)==1){c[(c[k>>2]|0)+48>>2]=28}else{KIb(a,16,2259400,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}l=FD(e)|0;n=FD(e)|0;c[(c[k>>2]|0)+120>>2]=n;n=FD(e)|0;c[(c[k>>2]|0)+124>>2]=n;n=FD(e)|0;_X(h,32,n,FD(e)|0);n=l;k=0;o=h+64|0;c[o>>2]=n;c[o+4>>2]=k;o=h+56|0;c[o>>2]=n;c[o+4>>2]=k;o=FD(e)|0;if((o|0)==1){KIb(a,16,2213192,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;p=86018}else if((o|0)==0){p=86017}else{KIb(a,16,2180536,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;p=0}o=d+4|0;c[o>>2]=(DD(e)|0)+1;hD(e,10,0)|0;d=FD(e)|0;q=(FD(e)|0)+1|0;r=fD(e,0,0,1)|0;s=wrc(r,G,n<<2|0>>>30,k<<2|n>>>30)|0;n=G;k=0;a:do{if((g|0)>(k|0)|(g|0)==(k|0)&f>>>0>0>>>0){r=0;t=n;u=s;while(1){if(!(r>>>0<l>>>0)){v=15;break a}w=FD(e)|0;if((jD(e)|0)!=0){v=17;break a}x=w>>>1;if(x>>>0<((c[o>>2]<<2)+9|0)>>>0){v=19;break a}xX(h,u,t,r,0,x,0,w&1)|0;w=wrc(x,0,u,t)|0;x=G;if((r|0)==0&(x>>>0>g>>>0|x>>>0==g>>>0&w>>>0>f>>>0)){break}else{r=r+1|0;t=x;u=w}}KIb(a,16,2104728,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;j=-1094995529;i=b;return j|0}else{u=0;t=n;r=s;while(1){if(!(u>>>0<l>>>0)){v=15;break a}w=FD(e)|0;if((jD(e)|0)!=0){v=17;break a}x=w>>>1;if(x>>>0<((c[o>>2]<<2)+9|0)>>>0){v=19;break a}xX(h,r,t,u,0,x,0,w&1)|0;w=wrc(x,0,r,t)|0;u=u+1|0;t=G;r=w}}}while(0);if((v|0)==15){if((c[o>>2]|0)>>>0>1>>>0){y=1}else{j=0;i=b;return j|0}while(1){h=ZX(a,0)|0;if((h|0)==0){j=-12;v=24;break}e=c[h+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=p;c[e+416>>2]=q;c[e+412>>2]=d;_X(h,32,1,d);h=y+1|0;if(h>>>0<(c[o>>2]|0)>>>0){y=h}else{j=0;v=24;break}}if((v|0)==24){i=b;return j|0}}else if((v|0)==17){KIb(a,8,2152464,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;j=-1094995529;i=b;return j|0}else if((v|0)==19){KIb(a,16,2127800,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;j=-1094995529;i=b;return j|0}return 0}function $R(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;if((jD(f)|0)!=0){g=-541478725;i=d;return g|0}h=e;do{if((c[h>>2]|0)==0){j=zD(f)|0;c[e+8>>2]=j;if((j|0)==0){KIb(a,16,2380608,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;g=-1094995529;i=d;return g|0}l=(ca((c[e+4>>2]|0)-1|0,j)|0)+1|0;hD(f,8,0)|0;j=e+12|0;c[j>>2]=0;m=e+16|0;n=m;o=e+20|0;xJb(m,o,l<<2);if((c[o>>2]|0)==0){KIb(a,16,2311752,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;g=-12;i=d;return g|0}else{if((l|0)>0){p=0}else{q=j;r=n;break}while(1){o=FD(f)|0;c[(c[n>>2]|0)+(p<<2)>>2]=o;o=p+1|0;if((o|0)<(l|0)){p=o}else{q=j;r=n;break}}}}else{q=e+12|0;r=e+16|0}}while(0);p=fX(f,b,c[(c[r>>2]|0)+(c[q>>2]<<2)>>2]|0)|0;if((p|0)>-1){r=c[h>>2]|0;if((r|0)==0){f=(c[c[a+28>>2]>>2]|0)+208|0;a=c[f>>2]|0;k=c[f+4>>2]|0;n=wrc(a,k,1,0)|0;c[f>>2]=n;c[f+4>>2]=G;f=b+16|0;c[f>>2]=a;c[f+4>>2]=k}c[b+32>>2]=r;s=0}else{s=p}p=c[q>>2]|0;if(((p|0)%(c[e+8>>2]|0)|0|0)==0){c[h>>2]=((c[h>>2]|0)+1|0)%(c[e+4>>2]|0)|0}c[q>>2]=p+1;g=s;i=d;return g|0}function aS(a){a=a|0;mJb((c[a+12>>2]|0)+16|0);return 0}function bS(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[c[a+12>>2]>>2]=0;return-1|0}function cS(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[b+4>>2]|0;f=c[b+8>>2]|0;if((f|0)<2352){g=0;return g|0}b=e;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==1179011410){b=e+8|0;h=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==1096303683?e+44|0:e}else{h=e}b=e+f|0;a:do{if((b-h|0)>2351){f=0;e=0;i=h;while(1){if((grc(i,522464,12)|0)!=0){g=0;j=17;break}if((d[i+17|0]|0)>>>0>31>>>0){g=0;j=17;break}k=a[i+18|0]&14;if((k|0)==0){l=e;m=f}else if((k|0)==4){if(!((a[i+19|0]&42)==0)){g=0;j=17;break}l=e+1|0;m=f}else if((k|0)==8|(k|0)==2){k=i+30|0;n=(d[k]|d[k+1|0]<<8)<<16>>16;k=i+36|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;if(!((o|0)>-1)){g=0;j=17;break}k=i+28|0;if(!(((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>0<(n&65535)>>>0)){g=0;j=17;break}if(((n&65535)*2016|0|0)<(o|0)){g=0;j=17;break}l=e;m=f+1|0}else{g=0;j=17;break}o=i+2352|0;if((b-o|0)>2351){f=m;e=l;i=o}else{p=m;q=l;break a}}if((j|0)==17){return g|0}}else{p=0;q=0}}while(0);j=q+p|0;if((j|0)>3){g=50;return g|0}g=(j|0)!=0|0;return g|0}function dS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+2352|0;d=b|0;e=c[a+16>>2]|0;f=c[a+12>>2]|0;if((AD(e,d,44)|0)!=44){g=-5;i=b;return g|0}h=(c[d>>2]|0)==1179011410;fD(e,h?44:0,h?0:0,0)|0;h=f;f=0;do{c[h+(f*96|0)+88>>2]=-1;c[h+(f*96|0)>>2]=-1;f=f+1|0;}while((f|0)<32);f=a+20|0;c[f>>2]=c[f>>2]|1;g=0;i=b;return g|0}function eS(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+2352|0;g=f|0;h=c[b+16>>2]|0;j=g|0;k=g+17|0;l=g+18|0;m=b;n=g+28|0;o=g+30|0;p=g+36|0;q=c[b+12>>2]|0;r=g+40|0;s=g+42|0;t=g+56|0;a:while(1){if((AD(h,j,2352)|0)!=2352){u=-5;v=28;break}w=a[k]|0;x=w&255;if((w&255)>>>0>31>>>0){u=-1094995529;v=28;break}w=d[l]|0;y=w&14;b:do{if((y|0)==4){v=18;break a}else if((y|0)==8|(y|0)==2){z=(d[n]|d[n+1|0]<<8)<<16>>16;A=z&65535;B=(d[o]|d[o+1|0]<<8)<<16>>16;C=B&65535;D=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;do{if((D|0)>-1&(z&65535)>>>0<(B&65535)>>>0){E=C*2016|0;if((E|0)<(D|0)){break}F=q+(x*96|0)|0;if((c[F>>2]|0)<0){H=ZX(b,0)|0;if((H|0)==0){u=-12;v=28;break a}_X(H,64,1,15);c[F>>2]=c[H>>2];I=c[H+8>>2]|0;c[I+8>>2]=0;c[I+48>>2]=38;c[I+52>>2]=0;c[I+120>>2]=(d[r]|d[r+1|0]<<8)<<16>>16&65535;c[I+124>>2]=(d[s]|d[s+1|0]<<8)<<16>>16&65535}J=q+(x*96|0)+8|0;K=q+(x*96|0)+36|0;L=q+(x*96|0)+32|0;if((c[K>>2]|0)!=(E|0)){if((c[L>>2]|0)!=0){KIb(m,16,2311664,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M}P1(J);if((K1(J,E)|0)!=0){u=-5;v=28;break a}mrc(c[L>>2]|0,0,E|0)|0;E=fD(h,0,0,1)|0;I=wrc(E,G,-2352,-1)|0;E=q+(x*96|0)+72|0;c[E>>2]=I;c[E+4>>2]=G;c[q+(x*96|0)+40>>2]=c[F>>2]}nrc((c[L>>2]|0)+(A*2016|0)|0,t|0,2016)|0;if((A|0)==(C-1|0)){v=17;break a}else{break b}}}while(0);KIb(m,16,2380480,(M=i,i=i+24|0,c[M>>2]=A,c[M+8>>2]=C,c[M+16>>2]=D,M)|0);i=M}else{KIb(m,24,2259312,(M=i,i=i+8|0,c[M>>2]=w,M)|0);i=M}}while(0);if((jD(h)|0)!=0){u=-5;v=28;break}}if((v|0)==17){c[K>>2]=D;nrc(e|0,J|0,80)|0;c[L>>2]=0;c[K>>2]=-1;c[J>>2]=0;c[q+(x*96|0)+60>>2]=0;u=0;i=f;return u|0}else if((v|0)==18){J=q+(x*96|0)+88|0;if((c[J>>2]|0)<0){x=d[g+19|0]|0;q=ZX(b,0)|0;if((q|0)==0){u=-12;i=f;return u|0}c[J>>2]=c[q>>2];b=c[q+8>>2]|0;c[b+8>>2]=1;c[b+48>>2]=69640;c[b+52>>2]=0;K=b+416|0;if((x&1|0)==0){c[K>>2]=1;L=b+448|0;c[L>>2]=4;c[L+4>>2]=0;N=1}else{c[K>>2]=2;K=b+448|0;c[K>>2]=3;c[K+4>>2]=0;N=2}K=(x&4|0)!=0?18900:37800;c[b+412>>2]=K;c[b+432>>2]=128;_X(q,64,4032/(N>>>0)|0,K);K=q+48|0;c[K>>2]=0;c[K+4>>2]=0}if((K1(e,2304)|0)!=0){u=-5;i=f;return u|0}nrc(c[e+24>>2]|0,g+24|0,2304)|0;c[e+32>>2]=c[J>>2];c[e+48>>2]=1;u=0;i=f;return u|0}else if((v|0)==28){i=f;return u|0}return 0}function fS(a){a=a|0;var b=0;b=c[a+12>>2]|0;a=0;do{if((c[b+(a*96|0)+32>>2]|0)!=0){P1(b+(a*96|0)+8|0)}a=a+1|0;}while((a|0)<32);return 0}function gS(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[b+4>>2]|0;f=e+6|0;g=he((d[f]|d[f+1|0]<<8)<<16>>16|0)|0;f=e;if(!((d[f]|d[f+1|0]<<8)<<16>>16<<16>>16==22081)){h=0;return h|0}f=a[e+2|0]|0;if(f<<24>>24==0|(f&255)>>>0>2>>>0){h=0;return h|0}if((a[e+4|0]|0)!=85){h=0;return h|0}f=(d[e+5|0]|0)>>>0>31>>>0|(g&65535)>>>0>6136>>>0;i=f?-1:(g&65535)+8|0;if(f){h=0;return h|0}do{if((c[b+8>>2]|0)>=(i+8|0)){f=e+(i+6)|0;g=he((d[f]|d[f+1|0]<<8)<<16>>16|0)|0;f=e+i|0;if(!((d[f]|d[f+1|0]<<8)<<16>>16<<16>>16==22081)){break}f=a[e+(i+2)|0]|0;if(f<<24>>24==0|(f&255)>>>0>2>>>0){break}if((a[e+(i+4)|0]|0)!=85){break}if((g&65535)>>>0<6137>>>0&(d[e+(i+5)|0]|0)>>>0<32>>>0){h=50}else{break}return h|0}}while(0);h=25;return h|0}function hS(a){a=a|0;var b=0,d=0,e=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=0;c[e+48>>2]=2;c[b+236>>2]=1;_X(b,32,1,9e4);xX(b,0,0,0,0,0,0,1)|0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86016;c[b+236>>2]=1;_X(b,33,1,9e4);xX(b,0,0,0,0,0,0,1)|0;d=0;return d|0}function iS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[a+16>>2]|0;if((kS(a,e,f,g,1)|0)<0){j=-5;i=d;return j|0}a=fX(h,b,c[f>>2]|0)|0;if((a|0)<1){j=-5;i=d;return j|0}c[b+32>>2]=(c[g>>2]|0)-1;g=c[e+4>>2]|0;f=b+8|0;c[f>>2]=c[e>>2];c[f+4>>2]=g;j=a;i=d;return j|0}function jS(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=c[a+16>>2]|0;m=c[a+12>>2]|0;c[k>>2]=0;c[k+4>>2]=-2147483648;n=c[d>>2]|0;o=c[d+4>>2]|0;p=wrc(n,o,49088,0)|0;q=G;r=wrc(n,o,e,f)|0;f=G;e=q>>>0>f>>>0|q>>>0==f>>>0&p>>>0>r>>>0;s=e?r:p;p=e?f:q;q=m;if((o|0)<(p|0)|(o|0)==(p|0)&n>>>0<s>>>0){t=o;u=n}else{v=-2147483648;w=0;c[q>>2]=0;i=g;return(G=v,w)|0}while(1){c[k>>2]=0;c[k+4>>2]=-2147483648;fD(l,u,t,0)|0;c[q>>2]=0;if((kS(a,k,h,j,0)|0)==0){if(((c[j>>2]|0)-1|0)==(b|0)){n=c[k>>2]|0;o=c[k+4>>2]|0;if(!((n|0)==0&(o|0)==(-2147483648|0))){v=o;w=n;x=9;break}}n=fD(l,0,0,1)|0;o=c[h>>2]|0;m=wrc(o,(o|0)<0|0?-1:0,n,G)|0;y=G;z=m}else{m=wrc(c[d>>2]|0,c[d+4>>2]|0,1,0)|0;y=G;z=m}c[d>>2]=z;c[d+4>>2]=y;if((y|0)<(p|0)|(y|0)==(p|0)&z>>>0<s>>>0){t=y;u=z}else{break}}if((x|0)==9){c[q>>2]=0;i=g;return(G=v,w)|0}v=c[k+4>>2]|0;w=c[k>>2]|0;c[q>>2]=0;i=g;return(G=v,w)|0}function kS(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;j=i;i=i+256|0;k=j|0;l=c[b+16>>2]|0;m=(h|0)==0;h=c[b+12>>2]|0;n=b;a:do{if(m){o=fD(l,0,0,1)|0;p=G;q=HD(l)|0;r=zD(l)|0;zD(l)|0;zD(l)|0;s=zD(l)|0;t=HD(l)|0;if((q|0)!=16726){u=-5;i=j;return u|0}if((r-1|0)>>>0>1>>>0|(t|0)>6136){u=-5;i=j;return u|0}if(!((r|0)!=1|(s&16|0)==0)){v=p;w=o;x=t;y=20;break}if((r|0)!=2){z=-2147483648;A=0;B=t;C=r;break}r=c[h>>2]|0;if((r|0)!=0){D=t;E=-2147483648;F=0;H=p;I=o;J=r;y=35;break}r=ID(l)|0;zD(l)|0;s=HD(l)|0;q=HD(l)|0;K=zD(l)|0;if(!((r|0)!=1|(K|0)==0)){L=p;M=o;N=t;O=s;P=q;Q=K;y=26;break}K=t-9|0;hD(l,K,(K|0)<0|0?-1:0)|0;u=-5;i=j;return u|0}else{while(1){K=fD(l,0,0,1)|0;t=G;q=HD(l)|0;s=zD(l)|0;zD(l)|0;o=zD(l)|0;p=zD(l)|0;R=HD(l)|0;if((q|0)!=16726){y=9;break}if((s-1|0)>>>0>1>>>0){y=12;break}if((o|0)!=85){KIb(n,24,2259224,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}if((R|0)>6136){y=17;break}if(!((s|0)!=1|(p&16|0)==0)){v=t;w=K;x=R;y=20;break a}if((s|0)!=2){z=-2147483648;A=0;B=R;C=s;break a}s=c[h>>2]|0;if((s|0)!=0){D=R;E=-2147483648;F=0;H=t;I=K;J=s;y=35;break a}s=ID(l)|0;zD(l)|0;p=HD(l)|0;o=HD(l)|0;q=zD(l)|0;if(!((s|0)!=1|(q|0)==0)){L=t;M=K;N=R;O=p;P=o;Q=q;y=26;break a}KIb(n,24,2180400,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;q=R-9|0;hD(l,q,(q|0)<0|0?-1:0)|0;}if((y|0)==9){if(m){u=-5;i=j;return u|0}KIb(n,16,2380400,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;u=-5;i=j;return u|0}else if((y|0)==12){if(m){u=-5;i=j;return u|0}KIb(n,16,2311616,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;u=-5;i=j;return u|0}else if((y|0)==17){if(m){u=-5;i=j;return u|0}KIb(n,16,2213048,(S=i,i=i+8|0,c[S>>2]=R,S)|0);i=S;u=-5;i=j;return u|0}}}while(0);do{if((y|0)==20){T=0;U=JD(l)|0;V=x-4|0;W=v;X=w;Y=1;y=40}else if((y|0)==26){R=k|0;q=AD(l,R,Q)|0;if((q|0)!=(Q|0)){u=(q|0)<0?q:-1094995529;i=j;return u|0}q=N-9-Q|0;o=O-3-Q|0;c[h>>2]=o;if((P&128|0)==0){D=q;E=-2147483648;F=0;H=L;I=M;J=o;y=35;break}p=a[R]|0;if(!((p&-16)<<24>>24==32)){D=q;E=-2147483648;F=0;H=L;I=M;J=o;y=35;break}if((Q|0)>=5){R=p&14;p=k+1|0;K=((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(R<<29|0>>>3);p=k+3|0;D=q;E=0<<29|R>>>3|0;F=K|((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;H=L;I=M;J=o;y=35;break}if(!m){KIb(n,16,2152400,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}hD(l,q,(q|0)<0|0?-1:0)|0;u=-1094995529;i=j;return u|0}}while(0);if((y|0)==35){l=J-D|0;c[h>>2]=l;if((l|0)<0){if(!m){KIb(n,24,2127736,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}c[h>>2]=0}if((F|0)==0&(E|0)==(-2147483648|0)){z=-2147483648;A=0;B=D;C=2}else{T=E;U=F;V=D;W=H;X=I;Y=2;y=40}}if((y|0)==40){xX(c[(c[b+28>>2]|0)+(Y-1<<2)>>2]|0,X,W,U,T,0,0,1)|0;z=T;A=U;B=V;C=Y}c[e>>2]=A;c[e+4>>2]=z;c[f>>2]=B;c[g>>2]=C;u=0;i=j;return u|0}function lS(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,2311608,5)|0)==0;return(b?100:0)|0}function mS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+56|0;d=b+32|0;e=b+40|0;f=b+48|0;g=a+16|0;hD(c[g>>2]|0,5,0)|0;h=b|0;KD(c[g>>2]|0,h,32)|0;g=Bd(h|0,2380384,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=f,c[h+16>>2]=d,h)|0)|0;i=h;if((g|0)!=3|(c[e>>2]|0)<1|(c[d>>2]|0)<1){j=-1094995529;i=b;return j|0}if((c[f>>2]|0)<1){j=-1094995529;i=b;return j|0}g=ZX(a,0)|0;if((g|0)==0){j=-12;i=b;return j|0}a=g+8|0;h=c[a>>2]|0;c[h+8>>2]=1;c[h+416>>2]=c[e>>2];c[h+412>>2]=c[f>>2];f=KX(c[d>>2]|0,0,1,65535)|0;h=c[a>>2]|0;c[h+48>>2]=f;c[h+792>>2]=c[d>>2];c[h+432>>2]=(ca(c[h+416>>2]|0,c[d>>2]|0)|0)/8|0;_X(g,64,1,c[h+412>>2]|0);j=0;i=b;return j|0}function nS(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1179011410){e=b+8|0;f=e|0;g=e+4|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)==1296256081&(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)==544501094){h=100}else{break}return h|0}}while(0);h=0;return h|0}function oS(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;g=c[d+16>>2]|0;h=c[d+12>>2]|0;j=ZX(d,0)|0;if((j|0)==0){k=-12;i=e;return k|0}JD(g)|0;hD(g,18,0)|0;l=j+8|0;j=c[l>>2]|0;c[j+8>>2]=1;c[j+416>>2]=1;m=j+448|0;c[m>>2]=4;c[m+4>>2]=0;m=f|0;AD(g,m,16)|0;do{if(((a[m]|0)-65&255)>>>0<2>>>0){if((grc(f+1|0,1146800,15)|0)!=0){n=5;break}c[(c[l>>2]|0)+48>>2]=86040}else{n=5}}while(0);do{if((n|0)==5){if((grc(m,1146816,16)|0)==0){c[(c[l>>2]|0)+48>>2]=1936029283;break}if((grc(m,1146784,16)|0)==0){c[(c[l>>2]|0)+48>>2]=1936944502;break}KIb(d,16,2213024,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;k=-1094995529;i=e;return k|0}}while(0);hD(g,82,0)|0;m=DD(g)|0;c[(c[l>>2]|0)+72>>2]=m;c[d+1076>>2]=DD(g)|0;hD(g,2,0)|0;m=DD(g)|0;c[(c[l>>2]|0)+412>>2]=m;hD(g,2,0)|0;m=h+4|0;h=m;mrc(m|0,-1|0,10)|0;m=FD(g)|0;l=(m|0)>8?8:m;if((l|0)>0){m=d;d=0;do{n=zD(g)|0;f=zD(g)|0;if((f|0)>4){KIb(m,24,2180352,(o=i,i=i+16|0,c[o>>2]=f,c[o+8>>2]=n,o)|0);i=o}else{b[h+(f<<1)>>1]=n}d=d+1|0;}while((d|0)<(l|0))}d=36-(l<<1)|0;hD(g,d,(d|0)<0|0?-1:0)|0;k=0;i=e;return k|0}function pS(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=c[a+16>>2]|0;g=c[a+12>>2]|0;if((jD(f)|0)!=0){h=-541478725;i=e;return h|0}j=g;k=a+1076|0;l=a;a=g+4|0;a:while(1){do{if((c[j>>2]|0)==0){g=fD(f,0,0,1)|0;do{if(!((g&1|0)==0&(G&0|0)==0)){if((zD(f)|0)==0){break}KIb(l,24,2259200,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);g=FD(f)|0;n=FD(f)|0;if((g|0)==1952543350){if((FD(f)|0)!=0){c[k>>2]=0}hD(f,4,0)|0;break}else if((g|0)==1635017060){c[j>>2]=n;break}else{hD(f,n,0)|0;break}}else{n=zD(f)|0;o=c[k>>2]|0;if((o|0)!=0){p=5;break a}if((n|0)<=4){q=b[a+(n<<1)>>1]|0;if(!(q<<16>>16<0)){p=10;break a}}c[j>>2]=(c[j>>2]|0)-1}}while(0);if((jD(f)|0)!=0){h=-541478725;p=26;break}}if((p|0)==5){r=o-1|0}else if((p|0)==10){r=q<<16>>16}else if((p|0)==26){i=e;return h|0}if((c[j>>2]|0)>>>0>r>>>0){s=r}else{KIb(l,24,2380224,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;s=(c[j>>2]|0)-1|0}r=fX(f,d,s)|0;if(!((r|0)>-1)){h=r;i=e;return h|0}if((s|0)!=(r|0)){KIb(l,16,2311576,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}c[j>>2]=(c[j>>2]|0)+~s;h=r;i=e;return h|0}function qS(a){a=a|0;var b=0;b=(c[a+4>>2]|0)+4|0;return((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==826557778?100:0)|0}function rS(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+272|0;e=d|0;f=d+8|0;g=b+12|0;h=c[g>>2]|0;j=b+16|0;fD(c[j>>2]|0,0,0,1)|0;k=JD(c[j>>2]|0)|0;do{if(!(k>>>0<8>>>0)){l=FD(c[j>>2]|0)|0;if((k|0)<0){break}if((l|0)!=826557778){KIb(b,16,2127704,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=d;return n|0}l=f|0;o=ZX(b,0)|0;do{if((o|0)!=0){p=o+8|0;q=c[p>>2]|0;c[q+8>>2]=0;c[q+48>>2]=89;zD(c[j>>2]|0)|0;zD(c[j>>2]|0)|0;HD(c[j>>2]|0)|0;_X(o,32,1,JD(c[j>>2]|0)|0);JD(c[j>>2]|0)|0;hD(c[j>>2]|0,32,0)|0;q=JD(c[j>>2]|0)|0;c[(c[p>>2]|0)+120>>2]=q;q=JD(c[j>>2]|0)|0;c[(c[p>>2]|0)+124>>2]=q;HD(c[j>>2]|0)|0;q=HD(c[j>>2]|0)|0;p=HD(c[j>>2]|0)|0;if((q|0)>0&(p|0)>0){c[o+92>>2]=q;c[o+96>>2]=p;p=o+92|0;q=o+412|0;r=c[p+4>>2]|0;c[q>>2]=c[p>>2];c[q+4>>2]=r}r=zD(c[j>>2]|0)|0;if((r|0)>0){q=ZX(b,0)|0;if((q|0)==0){break}p=c[q+8>>2]|0;c[p+8>>2]=1;c[p+48>>2]=65545;c[p+416>>2]=r;_X(q,32,1,c[o+44>>2]|0)}AD(c[j>>2]|0,l,257)|0;a[f+257|0]=0;MGb(o+88|0,2572240,l,0)|0;q=fD(c[j>>2]|0,0,0,1)|0;r=b+1248|0;c[r>>2]=q;c[r+4>>2]=G;q=c[j>>2]|0;if((c[q+88>>2]|0)==0){n=0;i=d;return n|0}p=iD(q)|0;s=wrc(p,G,-56,-1)|0;fD(q,s,G,0)|0;fD(c[j>>2]|0,0,0,1)|0;s=JD(c[j>>2]|0)|0;if(s>>>0<8>>>0){t=826557778;u=16}else{q=FD(c[j>>2]|0)|0;if((s|0)<0){t=q;u=16}else{v=q}}if((u|0)==16){KIb(b,16,2104672,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;v=t}do{if((v|0)==1112491346|(v|0)==1179600210|(v|0)==1397704018){q=c[g>>2]|0;c[q+8>>2]=JD(c[j>>2]|0)|0;JD(c[j>>2]|0)|0;JD(c[j>>2]|0)|0;JD(c[j>>2]|0)|0;JD(c[j>>2]|0)|0;JD(c[j>>2]|0)|0;hD(c[j>>2]|0,24,0)|0;q=c[h+8>>2]|0;if((q|0)==0){break}fD(c[j>>2]|0,q,0,0)|0;fD(c[j>>2]|0,0,0,1)|0;q=JD(c[j>>2]|0)|0;if(q>>>0<8>>>0){w=v;u=21}else{s=FD(c[j>>2]|0)|0;if((q|0)<0){w=s;u=21}else{x=s}}if((u|0)==21){KIb(b,16,2622800,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;x=w}if((x|0)!=1331053650){break}s=c[g>>2]|0;p=c[c[b+28>>2]>>2]|0;y=s;c[y>>2]=(q-8|0)>>>2;z=hJb(q)|0;q=s+4|0;c[q>>2]=z;if((z|0)==0){KIb(b,16,2595600,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;break}else{A=0}while(1){z=c[y>>2]|0;if(!(A>>>0<z>>>0)){B=z;break}z=JD(c[j>>2]|0)|0;c[(c[q>>2]|0)+(A<<2)>>2]=z;if((z|0)==0){u=26;break}else{A=A+1|0}}if((u|0)==26){c[y>>2]=A;B=A}q=c[p+92>>2]|0;if((q|0)==0){break}c[e>>2]=c[p+96>>2];c[e+4>>2]=q;q=XIb(B,0,e,p+40|0)|0;z=p+56|0;c[z>>2]=q;c[z+4>>2]=G}}while(0);fD(c[j>>2]|0,c[r>>2]|0,c[r+4>>2]|0,0)|0;n=0;i=d;return n|0}}while(0);KIb(b,16,2152368,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-12;i=d;return n|0}}while(0);KIb(b,16,2180320,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=d;return n|0}function sS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=a+16|0;f=a+28|0;g=a+24|0;h=a;while(1){fD(c[e>>2]|0,0,0,1)|0;j=JD(c[e>>2]|0)|0;if(j>>>0<8>>>0){k=-1;l=23;break}a=FD(c[e>>2]|0)|0;if((j|0)<0){k=-1;l=23;break}if((a|0)==1094993234){if((c[g>>2]|0)>>>0<2>>>0){k=-1;l=23;break}m=c[(c[f>>2]|0)+4>>2]|0;if((c[m+76>>2]|0)!=48){l=17;break}}else if((a|0)==1447314770){n=c[c[f>>2]>>2]|0;if((c[n+76>>2]|0)!=48){l=9;break}}hD(c[e>>2]|0,j-8|0,0)|0;}if((l|0)==9){f=fD(c[e>>2]|0,0,0,1)|0;g=G;a=JD(c[e>>2]|0)|0;JD(c[e>>2]|0)|0;zD(c[e>>2]|0)|0;zD(c[e>>2]|0)|0;if((HD(c[e>>2]|0)|0)>4){HD(c[e>>2]|0)|0;HD(c[e>>2]|0)|0;JD(c[e>>2]|0)|0;JD(c[e>>2]|0)|0;JD(c[e>>2]|0)|0}o=fD(c[e>>2]|0,0,0,1)|0;p=G;q=wrc(f,g,j-8|0,0)|0;g=xrc(q,G,o,p)|0;p=g;if((p|0)<0){k=-1;i=d;return k|0}if((fX(c[e>>2]|0,b,p)|0)<0){KIb(h,16,2212992,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=-1;i=d;return k|0}c[b+32>>2]=0;p=b+16|0;c[p>>2]=a;c[p+4>>2]=0;p=c[n+92>>2]|0;if((p|0)==0){k=0;i=d;return k|0}a=c[n+44>>2]|0;g=c[n+96>>2]|0;n=Erc(g,(g|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=Frc(n,G,p,(p|0)<0|0?-1:0)|0;c[b+48>>2]=a;k=0;i=d;return k|0}else if((l|0)==17){a=fD(c[e>>2]|0,0,0,1)|0;p=G;n=JD(c[e>>2]|0)|0;g=JD(c[e>>2]|0)|0;o=m+8|0;c[(c[o>>2]|0)+412>>2]=g;if((g|0)<1){KIb(h,16,2311544,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=-1094995529;i=d;return k|0}g=JD(c[e>>2]|0)|0;JD(c[e>>2]|0)|0;HD(c[e>>2]|0)|0;zD(c[e>>2]|0)|0;zD(c[e>>2]|0)|0;JD(c[e>>2]|0)|0;q=fD(c[e>>2]|0,0,0,1)|0;f=G;s=wrc(a,p,j-8|0,0)|0;j=xrc(s,G,q,f)|0;f=j;if((f|0)<0){k=-1;i=d;return k|0}j=fX(c[e>>2]|0,b,f)|0;if((j|0)<0){KIb(h,16,2259152,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=j;i=d;return k|0}c[b+32>>2]=1;j=b+16|0;c[j>>2]=n;c[j+4>>2]=0;j=c[(c[o>>2]|0)+412>>2]|0;if((j|0)==0){k=0;i=d;return k|0}o=c[m+44>>2]|0;m=VIb(g,(g|0)<0|0?-1:0,o,(o|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;c[b+48>>2]=m;k=0;i=d;return k|0}else if((l|0)==23){i=d;return k|0}return 0}function tS(a){a=a|0;mJb((c[a+12>>2]|0)+4|0);return 0}function uS(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;i=i+8|0;b=f|0;g=c[c[a+28>>2]>>2]|0;h=c[g+92>>2]|0;if((h|0)==0){j=-1;i=f;return j|0}k=c[a+12>>2]|0;c[b>>2]=c[g+96>>2];c[b+4>>2]=h;h=XIb(d,e,g+40|0,b)|0;b=h;h=c[k>>2]|0;if(b>>>0<h>>>0){fD(c[a+16>>2]|0,h,0,0)|0;h=G;((h|0)<0|0?-1:0)>>31|((h|0)<0|0?-1:0)<<1;j=h>>31|((h|0)<0|0?-1:0)<<1;i=f;return j|0}else{KIb(a,16,2380160,(a=i,i=i+8|0,c[a>>2]=b,a)|0);i=a;j=-1;i=f;return j|0}return 0}function vS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((K1(b,1024)|0)<0){d=-12;return d|0}e=a+16|0;a=fD(c[e>>2]|0,0,0,1)|0;f=b+64|0;c[f>>2]=a;c[f+4>>2]=G;c[b+32>>2]=0;f=CD(c[e>>2]|0,c[b+24>>2]|0,1024)|0;if((f|0)<0){P1(b);d=f;return d|0}else{M1(b,f);d=f;return d|0}return 0}function wS(a){a=a|0;var b=0,d=0,e=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[b+236>>2]=1463898624;a=b+48|0;c[a>>2]=0;c[a+4>>2]=0;d=0;return d|0}function xS(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[d+8>>2]|0;c[f+8>>2]=0;c[f+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[d+236>>2]=1463898624;a=f+104|0;f=c[b+12>>2]|0;c[a>>2]=c[b+16>>2];c[a+4>>2]=f;_X(d,64,1,12e5);e=0;return e|0}function yS(a){a=a|0;var b=0,d=0,e=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=2;c[e+48>>2]=c[(c[a+4>>2]|0)+28>>2];a=b+48|0;c[a>>2]=0;c[a+4>>2]=0;d=0;return d|0}function zS(a,b){a=a|0;b=b|0;dD(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function AS(a){a=a|0;var b=0,d=0,e=0;b=i;if((c[a+24>>2]|0)==1){d=0;i=b;return d|0}KIb(a,16,2201688,(e=i,i=i+8|0,c[e>>2]=c[c[a+8>>2]>>2],e)|0);i=e;d=-22;i=b;return d|0}function BS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[a+12>>2]|0;f=ZX(a,0)|0;if((f|0)==0){g=-12;i=b;return g|0}h=f+8|0;j=c[h>>2]|0;c[j+8>>2]=0;c[j+48>>2]=c[(c[a+4>>2]|0)+28>>2];j=e+12|0;k=nKb(c[j>>2]|0)|0;if((k|0)==-1){KIb(a,16,2310840,(a=i,i=i+8|0,c[a>>2]=c[j>>2],a)|0);i=a;g=-22;i=b;return g|0}else{_X(f,64,c[e+20>>2]|0,c[e+16>>2]|0);a=e+4|0;j=c[h>>2]|0;c[j+120>>2]=c[a>>2];l=e+8|0;c[j+124>>2]=c[l>>2];c[j+140>>2]=k;j=c2(k,c[a>>2]|0,c[l>>2]|0)|0;c[d>>2]=8;c[d+4>>2]=1;l=XIb(j,(j|0)<0|0?-1:0,d,f+40|0)|0;c[(c[h>>2]|0)+72>>2]=l;g=0;i=b;return g|0}return 0}function CS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;e=c2(c[d+140>>2]|0,c[d+120>>2]|0,c[d+124>>2]|0)|0;if((e|0)<0){f=-1;return f|0}d=fX(c[a+16>>2]|0,b,e)|0;a=b+64|0;g=Crc(c[a>>2]|0,c[a+4>>2]|0,e,(e|0)<0|0?-1:0)|0;e=G;a=b+16|0;c[a>>2]=g;c[a+4>>2]=e;a=b+8|0;c[a>>2]=g;c[a+4>>2]=e;c[b+32>>2]=0;f=(d|0)<0?d:0;return f|0}function DS(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=(JFb(((d[b+1|0]|0)<<8|(d[b]|0)<<16|(d[b+2|0]|0)|0)==15711167?b+3|0:b,2258504,7)|0)==0;return(a?50:0)|0}function ES(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;d=i;i=i+1032|0;e=d|0;f=d+1024|0;g=c[b+12>>2]|0;h=ZX(b,0)|0;a[f]=0;j=IS(2310824)|0;if((h|0)==0){k=-12;i=d;return k|0}_X(h,64,1,100);l=h+8|0;h=c[l>>2]|0;c[h+8>>2]=3;c[h+48>>2]=1381259348;SFb(e,0,-1);h=b+16|0;a:do{if((jD(c[h>>2]|0)|0)==0){b=e|0;m=e+4|0;n=g;o=j;p=0;q=0;while(1){r=fD(c[h>>2]|0,0,0,1)|0;s=xrc(r,G,q,p)|0;r=G;if((PV(c[h>>2]|0,e,f)|0)==0){t=n;u=20;break a}v=(JFb(c[b>>2]|0,2258504,7)|0)==0;w=c[b>>2]|0;do{if(v){x=QV(w,2212808)|0;if((x|0)==0){y=o}else{y=IS(x)|0}x=rJb(c[b>>2]|0)|0;c[(c[l>>2]|0)+96>>2]=x;x=c[l>>2]|0;if((c[x+96>>2]|0)==0){z=-12;break a}c[x+100>>2]=(c[m>>2]|0)+1;A=y}else{x=(JFb(w,2180112,5)|0)!=0;B=IV(n,c[b>>2]|0,c[m>>2]|0,x&1)|0;if((B|0)==0){z=-12;break a}if(x){A=o;break}x=QV(c[b>>2]|0,2152232)|0;C=QV(c[b>>2]|0,2127592)|0;D=B+64|0;c[D>>2]=s;c[D+4>>2]=r;if((x|0)==0){E=0;F=0}else{D=IS(x)|0;E=(D|0)<0|0?-1:0;F=D}D=B+8|0;c[D>>2]=F;c[D+4>>2]=E;if((C|0)==0){H=o}else{x=IS(C)|0;C=xrc(x,0,c[D>>2]|0,c[D+4>>2]|0)|0;H=C}c[B+48>>2]=H;A=o}}while(0);ZFb(e);if((jD(c[h>>2]|0)|0)!=0){t=n;u=20;break a}o=A;p=0;q=(a[f]|0)!=0|0}}else{t=g;u=20}}while(0);if((u|0)==20){JV(t);z=0}_Fb(e,0)|0;k=z;i=d;return k|0}function FS(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function GS(a){a=a|0;OV(c[a+12>>2]|0);return 0}function HS(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function IS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=Bd(a|0,2104520,(j=i,i=i+32|0,c[j>>2]=d,c[j+8>>2]=e,c[j+16>>2]=f,c[j+24>>2]=g,j)|0)|0;i=j;if((h|0)==4){k=((((c[e>>2]|0)*60|0)+((c[d>>2]|0)*3600|0)+(c[f>>2]|0)|0)*100|0)+(c[g>>2]|0)|0;i=b;return k|0}h=Bd(a|0,2622672,(j=i,i=i+24|0,c[j>>2]=d,c[j+8>>2]=e,c[j+16>>2]=f,j)|0)|0;i=j;if((h|0)==3){k=(((c[e>>2]|0)*60|0)+((c[d>>2]|0)*3600|0)+(c[f>>2]|0)|0)*100|0;i=b;return k|0}d=Bd(a|0,2595272,(j=i,i=i+24|0,c[j>>2]=e,c[j+8>>2]=f,c[j+16>>2]=g,j)|0)|0;i=j;if((d|0)==3){k=((((c[e>>2]|0)*60|0)+(c[f>>2]|0)|0)*100|0)+(c[g>>2]|0)|0;i=b;return k|0}d=Bd(a|0,2572048,(j=i,i=i+16|0,c[j>>2]=e,c[j+8>>2]=f,j)|0)|0;i=j;if((d|0)==2){k=(((c[e>>2]|0)*60|0)+(c[f>>2]|0)|0)*100|0;i=b;return k|0}e=Bd(a|0,2553720,(j=i,i=i+16|0,c[j>>2]=f,c[j+8>>2]=g,j)|0)|0;i=j;if((e|0)==2){k=((c[f>>2]|0)*100|0)+(c[g>>2]|0)|0;i=b;return k|0}else{k=(rb(a|0,0,10)|0)*100|0;i=b;return k|0}return 0}function JS(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;e=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)^1382376531;a=e<<11|e>>>21;f=b+4|0;b=((a<<3|e>>>18&7)+a^(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)|0)==1885434475&1382376531==1382376531;return(b?100:0)|0}function KS(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=c[b+16>>2]|0;g=c[b+12>>2]|0;h=ZX(b,0)|0;if((h|0)==0){j=-12;i=e;return j|0}k=c[h+8>>2]|0;l=hJb(4112)|0;if((l|0)==0){j=-12;i=e;return j|0}m=(JD(f)|0)^1382376531;n=l;y=1399088466;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m<<11|m>>>21;m=4;o=l;do{o=o+4|0;n=(n<<3|n>>>29)+n|0;p=o;y=je((JD(f)|0)^n|0)|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;m=m+4|0;}while((m|0)<4096);c[k+48>>2]=69650;c[k+8>>2]=1;m=l+60|0;n=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;m=k+412|0;c[m>>2]=n;do{if((n-1|0)>>>0>95999>>>0){KIb(b,16,2310760,(f=i,i=i+8|0,c[f>>2]=n,f)|0);i=f;q=-1094995529}else{f=l+64|0;o=h+56|0;c[o>>2]=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)*14|0;c[o+4>>2]=0;c[g>>2]=0;o=a[l+78|0]|0;f=o&255;p=k+416|0;c[p>>2]=f;if(o<<24>>24==0){q=-1094995529;break}o=((a[l+79|0]|0)==0?84:100)+(f<<3)|0;if((o+(f*46|0)|0)>4096){q=-1094995529;break}if((PX(k,f<<5)|0)!=0){q=-12;break}if((c[p>>2]|0)>0){f=k+96|0;r=l+((o|0)>4096?4096:o)|0;o=0;while(1){nrc((c[f>>2]|0)+(o<<5)|0,r|0,32)|0;s=o+1|0;if((s|0)<(c[p>>2]|0)){r=r+46|0;o=s}else{break}}}_X(h,64,1,c[m>>2]|0);q=0}}while(0);kJb(l);j=q;i=e;return j|0}function LS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+28|0;e=c[a+12>>2]|0;f=c[(c[(c[c[d>>2]>>2]|0)+8>>2]|0)+416>>2]<<3;g=a+16|0;if((jD(c[g>>2]|0)|0)!=0){h=-541478725;return h|0}a=e;e=c[a>>2]|0;i=(c[c[d>>2]>>2]|0)+56|0;if((e|0)==(c[i>>2]|0)&(((e|0)<0|0?-1:0)|0)==(c[i+4>>2]|0)){h=-541478725;return h|0}if((fX(c[g>>2]|0,b,f)|0)==(f|0)){c[b+48>>2]=14;c[a>>2]=(c[a>>2]|0)+14;c[b+32>>2]=0;h=f;return h|0}else{P1(b);h=-5;return h|0}return 0}function MS(a,b){a=a|0;b=b|0;var c=0,d=0;c=b|0;if((AD(a,c,16)|0)>=16){d=0;return d|0}mrc(c|0,0,16)|0;d=-1094995529;return d|0}function NS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=0;while(1){e=c[a+(d*20|0)>>2]|0;if((e|0)==0){f=0;g=4;break}if((grc(a+(d*20|0)+4|0,b,16)|0)==0){f=e;g=4;break}else{d=d+1|0}}if((g|0)==4){return f|0}return 0}function OS(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=DD(b)|0;c[e+8>>2]=1;l=e+416|0;c[l>>2]=DD(b)|0;m=e+412|0;c[m>>2]=FD(b)|0;n=e+72|0;c[n>>2]=(FD(b)|0)<<3;c[e+432>>2]=DD(b)|0;if((f|0)==14){c[e+792>>2]=8;o=8}else{p=DD(b)|0;c[e+792>>2]=p;o=p}p=(k|0)==65534;q=e+52|0;if(p){c[q>>2]=0}else{c[q>>2]=k;r=JX(1406408,k)|0;if((r|0)==65557){s=KX(o,1,0,0)|0;t=9}else if((r|0)==0){u=0}else if((r|0)==65536){s=KX(o,0,0,-2)|0;t=9}else{s=r;t=9}if((t|0)==9){u=(s|0)==69633&(o|0)==8?65553:s}c[e+48>>2]=u}do{if((f|0)>17){u=DD(b)|0;s=f-18|0;o=(s|0)>(u|0)?u:s;if((o|0)<22|p^1){v=o;w=s}else{s=h;u=j|0;r=h;k=DD(b)|0;if((k|0)!=0){c[e+792>>2]=k}k=e+448|0;c[k>>2]=FD(b)|0;c[k+4>>2]=0;if((AD(b,s,16)|0)<16){mrc(s|0,0,16)|0}k=h+4|0;a[u]=0;a[j+1|0]=0;a[j+2|0]=16;a[j+3|0]=0;a[j+4|0]=-128;a[j+5|0]=0;a[j+6|0]=0;a[j+7|0]=-86;a[j+8|0]=0;a[j+9|0]=56;a[j+10|0]=-101;a[j+11|0]=113;do{if((grc(k,u,12)|0)==0){x=c[h>>2]|0;c[q>>2]=x;y=c[e+792>>2]|0;z=JX(1406408,x)|0;if((z|0)==65536){A=KX(y,0,0,-2)|0;t=21}else if((z|0)==65557){A=KX(y,1,0,0)|0;t=21}else if((z|0)==0){B=0}else{A=z;t=21}if((t|0)==21){B=(A|0)==69633&(y|0)==8?65553:A}c[e+48>>2]=B}else{y=0;while(1){C=c[1406904+(y*20|0)>>2]|0;if((C|0)==0){t=26;break}if((grc(1406908+(y*20|0)|0,s,16)|0)==0){t=25;break}else{y=y+1|0}}if((t|0)==25){c[e+48>>2]=C;break}else if((t|0)==26){c[e+48>>2]=0;y=d[r+1|0]|0;z=d[r+2|0]|0;x=d[r+3|0]|0;D=d[k]|0;E=d[r+5|0]|0;F=d[r+6|0]|0;G=d[r+7|0]|0;H=d[h+8|0]|0;I=d[r+9|0]|0;J=d[r+10|0]|0;K=d[r+11|0]|0;L=d[h+12|0]|0;M=d[r+13|0]|0;N=d[r+14|0]|0;O=d[r+15|0]|0;KIb(e,24,2179960,(P=i,i=i+128|0,c[P>>2]=d[s]|0,c[P+8>>2]=y,c[P+16>>2]=z,c[P+24>>2]=x,c[P+32>>2]=D,c[P+40>>2]=E,c[P+48>>2]=F,c[P+56>>2]=G,c[P+64>>2]=H,c[P+72>>2]=I,c[P+80>>2]=J,c[P+88>>2]=K,c[P+96>>2]=L,c[P+104>>2]=M,c[P+112>>2]=N,c[P+120>>2]=O,P)|0);i=P;break}}}while(0);v=o-22|0;w=f-40|0}do{if((v|0)>0){kJb(c[e+96>>2]|0);if((QX(e,b,v)|0)<0){Q=-12;i=g;return Q|0}else{R=w-v|0;break}}else{R=w}}while(0);if((R|0)<=0){break}hD(b,R,(R|0)<0|0?-1:0)|0;}}while(0);R=c[m>>2]|0;if((R|0)<1){KIb(0,16,2110840,(P=i,i=i+8|0,c[P>>2]=R,P)|0);i=P;Q=-1094995529;i=g;return Q|0}P=c[e+48>>2]|0;if((P|0)==86066){c[l>>2]=0;c[m>>2]=0;Q=0;i=g;return Q|0}else if((P|0)==69643){c[e+792>>2]=(c[n>>2]|0)/(R|0)|0;Q=0;i=g;return Q|0}else{Q=0;i=g;return Q|0}return 0}function PS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=JX(1406408,a)|0;if((c|0)==65536){d=KX(b,0,0,-2)|0}else if((c|0)==0){e=0;return e|0}else if((c|0)==65557){d=KX(b,1,0,0)|0}else{d=c}e=(d|0)==69633&(b|0)==8?65553:d;return e|0}function QS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=FD(a)|0;if((d|0)!=0){c[d>>2]=e}e=FD(a)|0;d=b+8|0;c[(c[d>>2]|0)+120>>2]=e;e=FD(a)|0;c[(c[d>>2]|0)+124>>2]=e;DD(a)|0;e=DD(a)|0;c[(c[d>>2]|0)+792>>2]=e;e=FD(a)|0;FD(a)|0;FD(a)|0;FD(a)|0;FD(a)|0;FD(a)|0;return e|0}function RS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+8|0;f=e|0;g=c[a+16>>2]|0;h=fD(g,0,0,1)|0;j=wrc(h,G,b,d)|0;d=G;b=fD(g,0,0,1)|0;h=G;k=-1;if(!((h|0)>(k|0)|(h|0)==(k|0)&b>>>0>-1>>>0)){l=0;i=e;return l|0}k=wrc(j,d,-8,-1)|0;m=G;n=f|0;o=g+52|0;p=f;f=a+1140|0;q=a;a=h;h=b;a:while(1){if((a|0)>(m|0)|(a|0)==(m|0)&h>>>0>k>>>0){l=0;r=23;break}mrc(n|0,0,5)|0;s=FD(g)|0;t=FD(g)|0;b=t;u=0;if((jD(g)|0)!=0){r=5;break}if((u|0)>(d|0)|(u|0)==(d|0)&b>>>0>j>>>0){r=9}else{v=xrc(j,d,b,u)|0;w=G;if((w|0)<(a|0)|(w|0)==(a|0)&v>>>0<h>>>0|(t|0)==-1){r=9}else{x=u;y=b;z=s}}if((r|0)==9){r=0;fD(g,-9,-1,1)|0;b=FD(g)|0;u=FD(g)|0;v=u;w=0;if((w|0)>(d|0)|(w|0)==(d|0)&v>>>0>j>>>0){r=11;break}A=xrc(j,d,v,w)|0;B=G;if((B|0)<(a|0)|(B|0)==(a|0)&A>>>0<h>>>0|(u|0)==-1){r=11;break}else{x=w;y=v;z=b}}b=wrc(y&1,x&0,y,x)|0;v=G;do{if((z|0)==0){if((b|0)==0&(v|0)==0){if((c[o>>2]|0)==0){break}else{r=16;break a}}else{hD(g,b,v)|0;break}}else{w=wrc(b,v,1,0)|0;u=pJb(w)|0;if((u|0)==0){r=18;break a}c[p>>2]=z;w=AD(g,u,b)|0;if(!((w|0)==(b|0)&(((w|0)<0|0?-1:0)|0)==(v|0))){KIb(q,24,2212704,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C}MGb(f,n,u,8)|0}}while(0);v=fD(g,0,0,1)|0;b=G;u=-1;if((b|0)>(u|0)|(b|0)==(u|0)&v>>>0>-1>>>0){a=b;h=v}else{l=0;r=23;break}}if((r|0)==5){if((t|s|0)==0){l=-541478725;i=e;return l|0}KIb(q,24,2473224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;l=-1094995529;i=e;return l|0}else if((r|0)==11){KIb(q,24,2378872,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;l=-1094995529;i=e;return l|0}else if((r|0)==16){KIb(q,24,2310600,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;l=-541478725;i=e;return l|0}else if((r|0)==18){KIb(q,16,2258248,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;l=-12;i=e;return l|0}else if((r|0)==23){i=e;return l|0}return 0}function SS(a,b){a=a|0;b=b|0;kD(a,(d[b+1|0]|0)<<8|(d[b]|0)|(d[b+2|0]|0)<<16|(d[b+3|0]|0)<<24);kD(a,0);b=fD(a,0,0,1)|0;return(G=G,b)|0}function TS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if(!((b&1|0)==0&(d&0|0)==0)){KIb(0,0,2110488,(f=i,i=i+24|0,c[f>>2]=2473144,c[f+8>>2]=2378824,c[f+16>>2]=42,f)|0);i=f;Hd()}f=fD(a,0,0,1)|0;g=G;if(!((f&1|0)==0&(g&0|0)==0)){bD(a,0)}h=wrc(b,d,-4,-1)|0;fD(a,h,G,0)|0;h=xrc(f,g,b,d)|0;kD(a,h);h=wrc(f,g,1,0)|0;fD(a,h&-2,G|0,0)|0;i=e;return}function US(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;e=i;i=i+256|0;f=e|0;g=f|0;h=f;j=f;k=f;l=d+52|0;m=c[l>>2]|0;if((m|0)==0|m>>>0>65535>>>0){n=-1;i=e;return n|0}m=B5a(d,0)|0;if((m|0)==0){o=c[d+424>>2]|0}else{o=m}m=d+416|0;do{if((c[m>>2]|0)>2){p=d+448|0;if((c[p>>2]|0)==0&(c[p+4>>2]|0)==0){q=7;break}r=d+412|0;q=10}else{q=7}}while(0);do{if((q|0)==7){p=d+412|0;if((c[p>>2]|0)>48e3){r=p;q=10;break}s=d+48|0;t=c[s>>2]|0;if((t|0)==86057){r=p;q=10;break}if((g5a(t)|0)>16){r=p;q=10;break}oD(a,c[l>>2]|0);u=0;v=p;w=s}}while(0);if((q|0)==10){oD(a,65534);u=1;v=r;w=d+48|0}oD(a,c[m>>2]|0);kD(a,c[v>>2]|0);r=c[w>>2]|0;a:do{switch(r|0){case 86047:case 86069:case 86016:case 86017:case 86046:{x=0;break};default:{s=g5a(r)|0;if((s|0)!=0){x=s;break a}s=c[d+792>>2]|0;x=(s|0)==0?16:s}}}while(0);r=c[d+792>>2]|0;if(!((x|0)==(r|0)|(r|0)==0)){KIb(d,24,2310528,(s=i,i=i+16|0,c[s>>2]=r,c[s+8>>2]=x,s)|0);i=s}s=c[w>>2]|0;b:do{switch(s|0){case 86018:{z=(c[m>>2]|0)*768|0;q=22;break};case 86069:{z=24;q=22;break};case 86019:{z=3840;q=22;break};case 86016:case 86017:{A=o;break};default:{r=c[d+432>>2]|0;if((r|0)!=0){z=r;q=22;break b}r=ca(c[m>>2]|0,x)|0;p=TIb(8,0,x,(x|0)<0|0?-1:0)|0;z=Crc(r,(r|0)<0|0?-1:0,p,G)|0;q=22}}}while(0);if((q|0)==22){A=z}if((s|0)==86069){B=800}else if((s|0)==65541|(s|0)==65548|(s|0)==65544|(s|0)==65557|(s|0)==65559|(s|0)==65536){B=ca(c[v>>2]|0,A)|0}else{B=(c[d+72>>2]|0)/8|0}kD(a,B);oD(a,A);oD(a,x);A=c[w>>2]|0;do{if((A|0)==86017){b[j>>1]=1;B=k+2|0;y=2;b[B>>1]=y;b[B+2>>1]=y>>16;b[k+6>>1]=1152;B=f+8|0;b[B>>1]=1;b[B+2>>1]=1393;C=k;D=30;E=f+12|0}else if((A|0)==86016){b[j>>1]=2;B=k+2|0;y=c[d+72>>2]|0;b[B>>1]=y;b[B+2>>1]=y>>16;b[k+6>>1]=(c[m>>2]|0)==2?1:8;B=f+8|0;b[B>>1]=0;b[B+2>>1]=1;B=f+12|0;v=B;b[B>>1]=16;B=v+2|0;y=0;b[B>>1]=y;b[B+2>>1]=y>>16;B=v+6|0;y=0;b[B>>1]=y;b[B+2>>1]=y>>16;C=k;D=40;E=v+10|0}else if((A|0)==86069){c[g>>2]=-1697775614;c[f+4>>2]=-1365051598;v=f+8|0;b[v>>1]=-21282;C=k;D=38;E=v+2|0}else if((A|0)==86046|(A|0)==69633){b[j>>1]=o;C=k;D=20;E=h+2|0}else{v=c[d+100>>2]|0;if((v|0)==0){C=k;D=18;E=k;break}B=c[d+96>>2]|0;C=B;D=v+18|0;E=B+v|0}}while(0);do{if(u){k=D+22|0;oD(a,E+22-C|0);oD(a,x);kD(a,c[d+448>>2]|0);if((c[w>>2]|0)==86057){F=0}else{kD(a,c[l>>2]|0);kD(a,1048576);kD(a,-1442840448);kD(a,1905997824);H=k;break}while(1){h=c[1406904+(F*20|0)>>2]|0;if((h|0)==0){I=0;break}if((h|0)==86057){q=37;break}else{F=F+1|0}}if((q|0)==37){I=1406908+(F*20|0)|0}dD(a,I|0,16);H=k}else{oD(a,E-C|0);H=D}}while(0);dD(a,C,E-C|0);if((H&1|0)==0){n=H;i=e;return n|0}bD(a,0);n=H+1|0;i=e;return n|0}function VS(a,b){a=a|0;b=b|0;dD(a,b|0,16);return}function WS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=0;while(1){e=c[b+(d*20|0)>>2]|0;if((e|0)==0){f=0;g=5;break}if((e|0)==(a|0)){break}else{d=d+1|0}}if((g|0)==5){return f|0}f=b+(d*20|0)+4|0;return f|0}function XS(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;d=(f|0)!=0;if(d){g=40}else{g=(c[b+100>>2]|0)+40|0}kD(a,g);g=b+120|0;kD(a,c[g>>2]|0);f=b+52|0;h=b+124|0;i=c[h>>2]|0;kD(a,(c[f>>2]|0)!=0?i:-i|0);oD(a,1);i=b+792|0;j=c[i>>2]|0;oD(a,(j|0)==0?24:j);kD(a,c[f>>2]|0);f=ca(c[h>>2]|0,c[g>>2]|0)|0;g=c[i>>2]|0;kD(a,((ca(f,(g|0)==0?24:g)|0)+7|0)/8|0);kD(a,0);kD(a,0);kD(a,0);kD(a,0);if(d){return}d=b+100|0;dD(a,c[b+96>>2]|0,c[d>>2]|0);if((e|0)!=0){return}if((c[d>>2]&1|0)==0){return}bD(a,0);return}function YS(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=B5a(a,0)|0;if((f|0)==0){g=c[a+424>>2]|0;h=a+432|0;c[d>>2]=c[h>>2];if((g|0)==0){i=h;j=6}else{k=g;l=h;j=4}}else{h=a+432|0;c[d>>2]=c[h>>2];k=f;l=h;j=4}do{if((j|0)==4){h=a+412|0;if((c[h>>2]|0)==0){i=l;j=6;break}c[e>>2]=k;f=c[h>>2]|0;c[b>>2]=f;m=f}}while(0);do{if((j|0)==6){k=c[a+8>>2]|0;if((k|0)==0|(k|0)==2|(k|0)==3){c[e>>2]=c[a+104>>2];k=c[a+108>>2]|0;c[b>>2]=k;m=k;break}k=c[i>>2]|0;c[e>>2]=(k|0)==0?8:k<<3;k=c[a+72>>2]|0;if((k|0)==0){n=c[a+412>>2]<<3}else{n=k}c[b>>2]=n;m=n}}while(0);n=c[e>>2]|0;a=TIb(n,(n|0)<0|0?-1:0,m,(m|0)<0|0?-1:0)|0;m=a;c[e>>2]=(n|0)/(m|0)|0;c[b>>2]=(c[b>>2]|0)/(m|0)|0;return}function ZS(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0;e=lrc(c|0)|0;if((e|0)<=0){return}f=e+1|0;kD(a,(d[b+1|0]|0)<<8|(d[b]|0)|(d[b+2|0]|0)<<16|(d[b+3|0]|0)<<24);kD(a,f);mD(a,c)|0;if((f&1|0)==0){return}bD(a,0);return}function _S(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+16|0;d=c[b>>2]|0;e=a+1140|0;cL(e,1316424,0);a=0;while(1){if((a|0)==27){f=9;break}if((LGb(c[e>>2]|0,679264+(a*5|0)|0,0,1)|0)==0){a=a+1|0}else{break}}if((f|0)==9){return}kD(d,1414744396);kD(d,0);f=fD(d,0,0,1)|0;a=G;kD(d,1330007625);g=0;do{h=LGb(c[e>>2]|0,679264+(g*5|0)|0,0,1)|0;if((h|0)!=0){ZS(c[b>>2]|0,c[h>>2]|0,c[h+4>>2]|0)}g=g+1|0;}while((g|0)!=27);TS(d,f,a);return}function $S(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297239878){a=b+8|0;b=((je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)-1380734514|0)>>>0<2>>>0;return(b?100:0)|0}else{return 0}return 0}function aT(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;d=c[a+16>>2]|0;hD(d,4,0)|0;e=FD(d)|0;f=JD(d)|0;hD(d,4,0)|0;g=FD(d)|0;if(e>>>0>1073741823>>>0|g>>>0>536870911>>>0){h=-1094995529;i=b;return h|0}hD(d,2,0)|0;j=DD(d)|0;k=DD(d)|0;l=DD(d)|0;m=DD(d)|0;n=ZX(a,0)|0;if((n|0)==0){h=-12;i=b;return h|0}o=c[n+8>>2]|0;c[o+8>>2]=0;c[o+48>>2]=115;c[o+52>>2]=0;c[o+120>>2]=320;c[o+124>>2]=200;n=(f|0)!=1380734515|(e|0)==0?774:e+774|0;c[o+100>>2]=n;if((QX(o,d,n)|0)<0){h=-12;i=b;return h|0}do{if((j&65535)<<16>>16==0){p=1103;q=11025}else{n=l&65535;if((l&65535)<<16>>16==0|n>>>0>42>>>0){KIb(a,16,2378792,(o=i,i=i+8|0,c[o>>2]=n,o)|0);i=o;h=-1094995529;i=b;return h|0}o=k&65535;e=ZX(a,0)|0;if((e|0)==0){h=-12;i=b;return h|0}else{f=c[e+8>>2]|0;c[f+8>>2]=1;c[f+48>>2]=65541;c[f+52>>2]=1;c[f+416>>2]=n;c[f+792>>2]=8;c[f+412>>2]=o;c[f+72>>2]=(ca(o,n)|0)<<3;c[f+432>>2]=n;_X(e,32,1,o);p=m&65535;q=o;break}}}while(0);m=a+28|0;_X(c[c[m>>2]>>2]|0,32,p,q);q=g<<2;p=hJb(q)|0;a=p;k=hJb(q)|0;o=k;e=hJb(q)|0;q=e;if((p|0)==0|(k|0)==0|(e|0)==0){kJb(p);kJb(k);kJb(e);h=-12;i=b;return h|0}n=(g|0)==0;a:do{if(n){r=0}else{f=0;do{c[a+(f<<2)>>2]=FD(d)|0;f=f+1|0;}while(f>>>0<g>>>0);if(n){r=0;break}else{s=0}do{c[q+(s<<2)>>2]=FD(d)|0;s=s+1|0;}while(s>>>0<g>>>0);if(n){r=0;break}else{t=0}do{c[o+(t<<2)>>2]=(FD(d)|0)&65535;t=t+1|0;}while(t>>>0<g>>>0);if(n){r=0;break}f=l&65535;if((j&65535|0)==0){u=0;while(1){v=c[a+(u<<2)>>2]|0;if((v|0)<0){r=-1094995529;break a}w=c[o+(u<<2)>>2]|0;if((w|0)>(v|0)){r=-1094995529;break a}xX(c[c[m>>2]>>2]|0,w+(c[q+(u<<2)>>2]|0)|0,0,u,0,v-w|0,0,1)|0;w=u+1|0;if(w>>>0<g>>>0){u=w}else{r=0;break a}}}else{x=0;y=0}while(1){u=a+(y<<2)|0;w=c[u>>2]|0;if((w|0)<0){r=-1094995529;break a}v=o+(y<<2)|0;z=c[v>>2]|0;if((z|0)>(w|0)){r=-1094995529;break a}if((z|0)==0){A=x;B=0;C=w;D=q+(y<<2)|0}else{w=q+(y<<2)|0;xX(c[(c[m>>2]|0)+4>>2]|0,c[w>>2]|0,0,x,0,z,0,1)|0;z=c[v>>2]|0;A=((z|0)/(f|0)|0)+x|0;B=z;C=c[u>>2]|0;D=w}xX(c[c[m>>2]>>2]|0,B+(c[D>>2]|0)|0,0,y,0,C-B|0,0,1)|0;w=y+1|0;if(w>>>0<g>>>0){x=A;y=w}else{r=0;break}}}}while(0);kJb(p);kJb(k);kJb(e);h=r;i=b;return h|0}function bT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=c[a+24>>2]|0;if((f|0)==0){g=-541478725;return g|0}h=d;i=c[a+28>>2]|0;a=0;j=0;k=-1;l=2147483647;m=-1;while(1){n=c[h+(j<<2)>>2]|0;o=c[i+(j<<2)>>2]|0;if(n>>>0<(c[o+404>>2]|0)>>>0){p=(c[o+400>>2]|0)+(n*24|0)|0;n=p|0;o=c[n>>2]|0;q=c[n+4>>2]|0;n=(q|0)<(l|0)|(q|0)==(l|0)&o>>>0<m>>>0;r=n?q:l;s=n?o:m;t=n?j:k;u=n?p:a}else{r=l;s=m;t=k;u=a}p=j+1|0;if(p>>>0<f>>>0){a=u;j=p;k=t;l=r;m=s}else{break}}if((t|0)==-1){g=-541478725;return g|0}s=d+(t<<2)|0;c[s>>2]=(c[s>>2]|0)+1;s=u|0;fD(e,c[s>>2]|0,c[s+4>>2]|0,0)|0;s=u+16|0;d=fX(e,b,c[s>>2]>>2)|0;if((d|0)==(c[s>>2]>>2|0)){c[b+32>>2]=t;t=u+8|0;u=c[t+4>>2]|0;s=b+8|0;c[s>>2]=c[t>>2];c[s+4>>2]=u;g=d;return g|0}else{P1(b);g=-5;return g|0}return 0}function cT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a+28|0;h=c[(c[g>>2]|0)+(b<<2)>>2]|0;i=c[a+12>>2]|0;j=CX(h,d,e,f)|0;if((j|0)<0){k=-1;return k|0}e=i;c[e+(b<<2)>>2]=j;b=(c[h+400>>2]|0)+(j*24|0)+8|0;j=c[b>>2]|0;i=c[b+4>>2]|0;b=a+24|0;if((c[b>>2]|0)==0){k=0;return k|0}a=h+40|0;h=f|1;f=0;while(1){d=c[(c[g>>2]|0)+(f<<2)>>2]|0;l=XIb(j,i,a,d+40|0)|0;m=CX(d,l,G,h)|0;c[e+(f<<2)>>2]=(m|0)<0?0:m;m=f+1|0;if(m>>>0<(c[b>>2]|0)>>>0){f=m}else{k=0;break}}return k|0}function dT(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;k=i;i=i+256|0;l=k|0;m=k+128|0;_X(f,64,1,1e3);n=fD(e,0,0,1)|0;o=G;p=JD(e)|0;a:do{if((p|0)==1280525370){fD(e,-4,-1,1)|0;q=f+8|0;if(h>>>0>16777215>>>0){r=-1;i=k;return r|0}s=(QX(c[q>>2]|0,e,h)|0)>>31&-12;if((s|0)<0){r=s;i=k;return r|0}else{s=c[q>>2]|0;c[s+8>>2]=1;t=c[s+96>>2]|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[s+52>>2]=u;s=JX(1314392,u)|0;c[(c[q>>2]|0)+48>>2]=s;break}}else if((p|0)==779248125){if((eT(b,e,f,g,0)|0)==0){break}else{r=-1}i=k;return r|0}else{do{if((j|0)!=0){if((irc(j,2110328)|0)!=0){break}XX(b,f);if((HD(e)|0)!=0){KIb(b,24,2473096,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;break a}s=(HD(e)|0)*6|0;hD(e,s,(s|0)<0|0?-1:0)|0;s=(HD(e)|0)<<1;hD(e,s,(s|0)<0|0?-1:0)|0;s=HD(e)|0;if((s|0)<=0){break a}q=l|0;u=m|0;t=b+1140|0;w=0;while(1){JD(e)|0;if((HD(e)|0)!=0){break}x=zD(e)|0;if((x|0)>0){y=q;z=0;while(1){A=zD(e)|0;if((z|0)<127){a[y]=A;B=y+1|0}else{B=y}A=z+1|0;if((A|0)<(x|0)){y=B;z=A}else{C=B;break}}}else{C=q}a[C]=0;z=(JD(e)|0)==2;y=HD(e)|0;if(z){if((y|0)>0){z=u;x=0;while(1){A=zD(e)|0;if((x|0)<127){a[z]=A;D=z+1|0}else{D=z}A=x+1|0;if((A|0)<(y|0)){z=D;x=A}else{E=D;break}}}else{E=u}a[E]=0;MGb(t,q,u,0)|0}else{hD(e,y,0)|0;}w=w+1|0;if((w|0)>=(s|0)){break a}}KIb(b,24,2378744,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;break a}}while(0);do{if((FD(e)|0)==1329875286){s=FD(e)|0;w=f+8|0;c[(c[w>>2]|0)+52>>2]=s;u=JX(1314392,s)|0;c[(c[w>>2]|0)+48>>2]=u;if((u|0)==0){break}u=HD(e)|0;c[(c[w>>2]|0)+120>>2]=u;u=HD(e)|0;c[(c[w>>2]|0)+124>>2]=u;hD(e,2,0)|0;hD(e,4,0)|0;c[(c[w>>2]|0)+8>>2]=0;c[f+236>>2]=3;u=JD(e)|0;s=c[w>>2]|0;w=fD(e,0,0,1)|0;q=G;t=wrc(n,o,h,0)|0;x=xrc(t,G,w,q)|0;q=x;if(q>>>0>16777215>>>0){r=-1;i=k;return r|0}x=(QX(s,e,q)|0)>>31&-12;if((x|0)<0){r=x;i=k;return r|0}if((u|0)>0){x=f+92|0;xKb(f+96|0,x|0,65536,0,u,(u|0)<0|0?-1:0,1073741823,0)|0;u=x;x=f+412|0;q=c[u+4>>2]|0;c[x>>2]=c[u>>2];c[x+4>>2]=q;break a}if((c[b+1156>>2]&8|0)==0){break a}KIb(b,16,2258208,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;r=-1094995529;i=k;return r|0}}while(0);KIb(b,24,2310496,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v}}while(0);v=fD(e,0,0,1)|0;p=xrc(v,G,n,o)|0;o=h-p|0;hD(e,o,(o|0)<0|0?-1:0)|0;r=0;i=k;return r|0}function eT(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;j=i;i=i+256|0;k=j|0;l=k|0;m=HD(e)|0;if((m|0)==3){n=HD(e)|0;o=fD(e,0,0,1)|0;p=G;hD(e,8,0)|0;q=HD(e)|0;hD(e,4,0)|0;oT(b,e,0);r=wrc(o,p,n,(n|0)<0|0?-1:0)|0;n=G;p=fD(e,0,0,1)|0;o=wrc(p,G,2,0)|0;p=G;if(!((n|0)<(p|0)|(n|0)==(p|0)&r>>>0<o>>>0)){zD(e)|0;o=k;p=zD(e)|0;if((p|0)>0){s=o;t=0;while(1){u=zD(e)|0;if((t|0)<255){a[s]=u;v=s+1|0}else{v=s}u=t+1|0;if((u|0)<(p|0)){s=v;t=u}else{w=v;break}}}else{w=o}a[w]=0}w=fD(e,0,0,1)|0;o=G;if((n|0)>(o|0)|(n|0)==(o|0)&r>>>0>w>>>0){w=fD(e,0,0,1)|0;o=xrc(r,n,w,G)|0;hD(e,o,G)|0;}if((q|0)==0){x=c[f+8>>2]|0}else{o=q;q=Frc(o<<3|0>>>29,0<<3|o>>>29,60,0)|0;o=c[f+8>>2]|0;c[o+72>>2]=q;x=o}c[x+412>>2]=8e3;c[x+416>>2]=1;o=x+448|0;c[o>>2]=4;c[o+4>>2]=0;c[x+8>>2]=1;c[x+48>>2]=77824;c[g+204>>2]=812936777;y=0;i=j;return y|0}hD(e,2,0)|0;JD(e)|0;JD(e)|0;HD(e)|0;JD(e)|0;x=HD(e)|0;o=JD(e)|0;q=g+132|0;c[q>>2]=o;JD(e)|0;w=JD(e)|0;if((m|0)!=4|(w|0)==0){z=f+8|0}else{n=w;w=Frc(n<<3|0>>>29,0<<3|n>>>29,60,0)|0;n=f+8|0;c[(c[n>>2]|0)+72>>2]=w;z=n}JD(e)|0;n=HD(e)|0;c[g+128>>2]=n;w=HD(e)|0;c[(c[z>>2]|0)+432>>2]=w;w=HD(e)|0;r=g+124|0;c[r>>2]=w;HD(e)|0;v=(m|0)==5;m=HD(e)|0;if(v){HD(e)|0;HD(e)|0;t=HD(e)|0;c[(c[z>>2]|0)+412>>2]=t;JD(e)|0;t=HD(e)|0;c[(c[z>>2]|0)+416>>2]=t;c[g+204>>2]=FD(e)|0;AD(e,k,4)|0;a[k+4|0]=0}else{c[(c[z>>2]|0)+412>>2]=m;JD(e)|0;m=HD(e)|0;c[(c[z>>2]|0)+416>>2]=m;m=k;c[l>>2]=0;t=zD(e)|0;if((t|0)>0){s=m;p=0;while(1){u=zD(e)|0;if((p|0)<255){a[s]=u;A=s+1|0}else{A=s}u=p+1|0;if((u|0)<(t|0)){s=A;p=u}else{B=A;break}}}else{B=m}a[B]=0;c[g+204>>2]=c[l>>2];B=zD(e)|0;if((B|0)>0){A=m;p=0;while(1){s=zD(e)|0;if((p|0)<255){a[A]=s;C=A+1|0}else{C=A}s=p+1|0;if((s|0)<(B|0)){A=C;p=s}else{D=C;break}}}else{D=m}a[D]=0}D=c[z>>2]|0;c[D+8>>2]=1;m=c[l>>2]|0;c[D+52>>2]=m;D=JX(1314392,m)|0;m=c[z>>2]|0;c[m+48>>2]=D;do{if((D|0)==86018){HD(e)|0;zD(e)|0;if(v){zD(e)|0}l=JD(e)|0;if(l>>>0>4294967279>>>0){KIb(b,16,2412736,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;y=-1;i=j;return y|0}if((l|0)<=0){break}zD(e)|0;C=l-1|0;if(C>>>0>16777215>>>0){y=-1;i=j;return y|0}l=(QX(c[z>>2]|0,e,C)|0)>>31&-12;if((l|0)<0){y=l}else{break}i=j;return y|0}else if((D|0)==86036){c[f+236>>2]=2;F=32}else if((D|0)==86019){c[f+236>>2]=1}else if((D|0)==77825){c[m+100>>2]=0;l=m+432|0;c[g+136>>2]=c[l>>2];c[l>>2]=o}else if((D|0)==86047|(D|0)==86058){F=32}else{CFb(m+16|0,k,32)|0}}while(0);do{if((F|0)==32){do{if((h|0)==0){HD(e)|0;zD(e)|0;if(v){zD(e)|0}k=JD(e)|0;if(!(k>>>0>4294967279>>>0)){o=c[z>>2]|0;H=k;I=o;J=c[o+48>>2]|0;break}KIb(b,16,2412736,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;y=-1;i=j;return y|0}else{H=0;I=m;J=D}}while(0);o=I+432|0;c[g+136>>2]=c[o>>2];do{if((J|0)==86058){if((x|0)<=3){K=d[1305784+x|0]|0;break}KIb(b,16,2405104,(E=i,i=i+8|0,c[E>>2]=x,E)|0);i=E;y=-1;i=j;return y|0}else{if((w|0)>=1){K=c[r>>2]|0;break}KIb(b,16,2397784,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;y=-1;i=j;return y|0}}while(0);c[o>>2]=K;if(H>>>0>16777215>>>0){y=-1;i=j;return y|0}k=(QX(I,e,H)|0)>>31&-12;if((k|0)<0){y=k}else{break}i=j;return y|0}}while(0);H=c[g+204>>2]|0;do{if((H|0)==880045641){I=c[q>>2]|0;K=c[g+136>>2]|0;if((I|0)>(K|0)|(n|0)<2){y=-1094995529;i=j;return y|0}w=ca(I,n)|0;if((w|0)>(ca(K,n&1|2)|0)){y=-1094995529;i=j;return y|0}if((w|0)==(K<<1|0)){F=64;break}QIb(b,2390672,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;y=-1094995529;i=j;return y|0}else if((H|0)==1919837543){K=c[r>>2]|0;if((K|0)<1){y=-1094995529;i=j;return y|0}w=c[g+136>>2]|0;if((K|0)>(w|0)){y=-1094995529;i=j;return y|0}if(((w|0)%(K|0)|0|0)==0){F=64;break}else{y=-1094995529}i=j;return y|0}else if((H|0)==1919969651){F=65}else if(!((H|0)==812936777|(H|0)==1718772342|(H|0)==1936876150)){KIb(b,16,2383872,(E=i,i=i+8|0,c[E>>2]=H,E)|0);i=E;y=-1094995529;i=j;return y|0}}while(0);if((F|0)==64){if((H|0)==880045641|(H|0)==1919837543|(H|0)==1919969651){F=65}}do{if((F|0)==65){H=c[(c[z>>2]|0)+432>>2]|0;if((H|0)<1){y=-1094995529;i=j;return y|0}E=ca(c[g+136>>2]|0,n)|0;if((E|0)<0|(E|0)<(H|0)){y=-1094995529;i=j;return y|0}if((K1(g|0,E)|0)<0){y=-12}else{break}i=j;return y|0}}while(0);if((h|0)==0){y=0;i=j;return y|0}zD(e)|0;zD(e)|0;zD(e)|0;oT(b,e,0);y=0;i=j;return y|0}function fT(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;n=i;o=c[b+12>>2]|0;p=e+8|0;q=c[(c[p>>2]|0)+8>>2]|0;a:do{if((q|0)==1){r=f+204|0;s=c[r>>2]|0;if((s|0)==1919837543|(s|0)==880045641|(s|0)==1919969651){t=c[f+124>>2]|0;u=c[f+132>>2]|0;v=c[f+128>>2]|0;w=f+120|0;x=c[w>>2]|0;z=c[f+136>>2]|0;if((k&2|0)==0){if((x|0)==0){A=43}else{B=x}}else{c[w>>2]=0;A=43}if((A|0)==43){x=f+112|0;c[x>>2]=l;c[x+4>>2]=m;B=0}do{if((s|0)==1919969651){x=c[f+24>>2]|0;C=ca(B,z)|0;D=x+C|0;E=AD(d,D,z)|0;if((E|0)==(z|0)){break}if((E|0)>-1){mrc(x+(E+C)|0,0,z-E|0)|0}else{mrc(D|0,0,z|0)|0}KIb(b,16,2491640,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}else if((s|0)==880045641){D=(v|0)/2|0;if((v|0)<=1){break}E=f+24|0;C=z<<1;x=ca(B,u)|0;H=b;I=0;do{J=c[E>>2]|0;K=(ca(C,I)|0)+x|0;L=J+K|0;M=AD(d,L,u)|0;if((M|0)!=(u|0)){if((M|0)>-1){mrc(J+(M+K)|0,0,u-M|0)|0}else{mrc(L|0,0,u|0)|0}KIb(H,16,2491640,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}I=I+1|0;}while((I|0)<(D|0))}else if((s|0)==1919837543){D=(z|0)/(t|0)|0;if((D|0)<=0){break}I=f+24|0;H=((v+1|0)/2|0)&-(B&1);x=B>>1;C=b;E=0;do{L=c[I>>2]|0;M=ca((ca(E,v)|0)+x+H|0,t)|0;K=L+M|0;J=AD(d,K,t)|0;if((J|0)!=(t|0)){if((J|0)>-1){mrc(L+(M+J)|0,0,t-J|0)|0}else{mrc(K|0,0,t|0)|0}KIb(C,16,2491640,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}E=E+1|0;}while((E|0)<(D|0))}}while(0);t=(c[w>>2]|0)+1|0;c[w>>2]=t;if((t|0)<(v|0)){N=-1;i=n;return N|0}if((c[r>>2]|0)==1919969651){uT(c[f+24>>2]|0,v,z)}c[w>>2]=0;c[o+16>>2]=c[e>>2];t=ca(z,v)|0;c[o+20>>2]=(t|0)/(c[(c[p>>2]|0)+432>>2]|0)|0;O=m;P=l;break}else if((s|0)==1718772342|(s|0)==1936876150){c[o+16>>2]=c[e>>2];t=(HD(d)|0)>>>4&15;u=f+120|0;c[u>>2]=t;if((t|0)==0){N=-1;i=n;return N|0}else{Q=0}do{c[f+140+(Q<<2)>>2]=HD(d)|0;Q=Q+1|0;R=c[u>>2]|0;}while((Q|0)<(R|0));c[o+20>>2]=R;u=f+112|0;c[u>>2]=l;c[u+4>>2]=m;O=m;P=l;break}else{fX(d,h,g)|0;if((c[(c[p>>2]|0)+48>>2]|0)!=86019){O=m;P=l;break}u=h+28|0;if((c[u>>2]|0)<=0){O=m;P=l;break}s=0;v=c[h+24>>2]|0;while(1){z=v+1|0;w=a[z]|0;a[z]=a[v]|0;a[v]=w;w=s+2|0;if((w|0)<(c[u>>2]|0)){s=w;v=v+2|0}else{O=m;P=l;break}}}}else if((q|0)==0){c[o+8>>2]=c[e+4>>2];v=zD(d)|0;s=v>>6;u=(s|0)==3;if(u){S=g-1|0;T=0;A=4}else{w=zD(d)|0;z=g-2|0;if((s|0)==1){U=0;V=0;W=0;X=z;Y=w}else{S=z;T=w;A=4}}if((A|0)==4){w=(HD(d)|0)&32767;if(w>>>0>16383>>>0){Z=w-16384|0;_=S-2|0}else{Z=HD(d)|0|w<<16;_=S-4|0}w=(HD(d)|0)&32767;if(w>>>0>16383>>>0){$=w-16384|0;aa=_-2|0}else{$=HD(d)|0|w<<16;aa=_-4|0}U=$;V=Z;W=zD(d)|0;X=aa-1|0;Y=T}do{if((X|0)<0){KIb(b,16,2480832,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;ba=-1}else{w=o+12|0;c[w>>2]=X;if((s&1|0)!=0){z=u?U:l;r=u?(U|0)<0|0?-1:0:m;t=u?V:X;if((X|0)<(t|0)){KIb(b,16,2470568,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;ba=-1;break}c[w>>2]=X-t;if((K1(h,t+9|0)|0)<0){ba=-5;break}D=h+24|0;a[c[D>>2]|0]=0;E=(c[D>>2]|0)+1|0;y=1;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;E=(c[D>>2]|0)+5|0;y=0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;E=AD(d,(c[D>>2]|0)+9|0,t)|0;if((E|0)==(t|0)){O=r;P=z;break a}P1(h);KIb(b,16,2462880,(F=i,i=i+8|0,c[F>>2]=t,F)|0);i=F;t=(E|0)<0?E:-5;if((t|0)==0){O=r;P=z;break a}else{ba=t;break}}c[j>>2]=Y;if((Y&127|0)==1){A=20}else{if((c[f+88>>2]|0)!=(W|0)){A=20}}if((A|0)==20){if((V|0)>(eX(d,V)|0)){KIb(b,16,2446072,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;ba=-1094995529;break}t=v<<1&126|1;z=f+96|0;c[z>>2]=t;r=f+80|0;c[r>>2]=V+(t<<3|1);t=f|0;P1(t);if((K1(t,c[r>>2]|0)|0)<0){ba=-12;break}mrc(c[f+24>>2]|0,0,c[f+28>>2]|0)|0;c[f+84>>2]=c[z>>2]<<3|1;c[f+92>>2]=0;c[f+88>>2]=W;z=fD(d,0,0,1)|0;r=f+104|0;c[r>>2]=z;c[r+4>>2]=G}r=(s|0)==2;if(r){da=(X|0)>(U|0)?U:X}else{da=X}z=f+92|0;t=(c[z>>2]|0)+1|0;c[z>>2]=t;E=f+96|0;if((t|0)>(c[E>>2]|0)){KIb(b,16,2432224,(F=i,i=i+8|0,c[F>>2]=t,F)|0);i=F;ba=1;break}D=f+24|0;C=c[D>>2]|0;if((C|0)==0){ba=-12;break}H=C+((t<<3)-7)|0;y=1;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=f+84|0;t=(c[D>>2]|0)+((c[z>>2]<<3)-3)|0;y=(c[H>>2]|0)-1-(c[E>>2]<<3)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=c[H>>2]|0;C=f+80|0;if((t+da|0)>(c[C>>2]|0)){KIb(b,16,2423552,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;ba=1;break}if((AD(d,(c[D>>2]|0)+t|0,da)|0)!=(da|0)){ba=-5;break}c[H>>2]=(c[H>>2]|0)+da;c[w>>2]=(c[w>>2]|0)-da;if(!r){if((c[H>>2]|0)!=(c[C>>2]|0)){ba=1;break}}a[c[D>>2]|0]=(c[z>>2]|0)+255;nrc(h|0,f|0,80)|0;c[D>>2]=0;c[f+28>>2]=0;c[f>>2]=0;c[f+52>>2]=0;D=c[E>>2]|0;C=c[z>>2]|0;if((D|0)==(C|0)){ea=D;fa=D}else{r=c[h+24>>2]|0;w=D<<3;orc(r+(C<<3|1)|0,r+(w|1)|0,(c[H>>2]|0)+~w|0)|0;ea=c[z>>2]|0;fa=c[E>>2]|0}c[h+28>>2]=(ea-fa<<3)+(c[H>>2]|0);H=h+8|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=f+104|0;z=c[H+4>>2]|0;w=h+64|0;c[w>>2]=c[H>>2];c[w+4>>2]=z;c[E>>2]=0;O=m;P=l;break a}}while(0);N=(ba|0)>-1?-1:ba;i=n;return N|0}else{fX(d,h,g)|0;O=m;P=l}}while(0);c[h+32>>2]=c[e>>2];e=h+8|0;c[e>>2]=P;c[e+4>>2]=O;if((k&2|0)!=0){k=h+36|0;c[k>>2]=c[k>>2]|1}if((c[(c[p>>2]|0)+8>>2]|0)!=1){N=0;i=n;return N|0}N=c[o+20>>2]|0;i=n;return N|0}function gT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=(c[a+12>>2]|0)+20|0;a=c[h>>2]|0;if((a|0)<=0){KIb(0,0,2212672,(j=i,i=i+24|0,c[j>>2]=2179936,c[j+8>>2]=2152176,c[j+16>>2]=900,j)|0);i=j;Hd();return 0}j=c[e+204>>2]|0;do{if((j|0)==1718772342|(j|0)==1936876150){fX(b,f,c[e+140+((c[e+120>>2]|0)-a<<2)>>2]|0)|0}else{k=d+8|0;if((K1(f,c[(c[k>>2]|0)+432>>2]|0)|0)<0){l=-12;i=g;return l|0}else{m=c[(c[k>>2]|0)+432>>2]|0;k=(ca(c[e+136>>2]|0,c[e+128>>2]|0)|0)/(m|0)|0;nrc(c[f+24>>2]|0,(c[e+24>>2]|0)+(ca(k-(c[h>>2]|0)|0,m)|0)|0,m)|0;break}}}while(0);c[h>>2]=(c[h>>2]|0)-1;a=e+112|0;e=c[a>>2]|0;b=c[a+4>>2]|0;j=f+8|0;c[j>>2]=e;c[j+4>>2]=b;if((e|0)==0&(b|0)==(-2147483648|0)){c[f+36>>2]=0}else{c[a>>2]=0;c[a+4>>2]=-2147483648;c[f+36>>2]=1}c[f+32>>2]=c[d>>2];l=c[h>>2]|0;i=g;return l|0}function hT(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;b=(a[d]|0)==46;do{if(b){if((a[d+1|0]|0)==82){do{if((a[d+2|0]|0)==77){if((a[d+3|0]|0)!=70){break}if((a[d+4|0]|0)!=0){break}if((a[d+5|0]|0)==0){e=100}else{break}return e|0}}while(0);if(!b){break}}if((a[d+1|0]|0)!=114){break}if((a[d+2|0]|0)!=97){break}if((a[d+3|0]|0)==-3){e=100}else{break}return e|0}}while(0);e=0;return e|0}function iT(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;i=i+256|0;e=d|0;f=d+128|0;g=b+12|0;h=c[g>>2]|0;j=b+16|0;k=c[j>>2]|0;l=FD(k)|0;if((l|0)==(-43945426|0)){c[(c[g>>2]|0)+4>>2]=1;g=ZX(b,0)|0;if((g|0)==0){m=-1;i=d;return m|0}n=pJb(208)|0;c[n+88>>2]=-1;c[g+12>>2]=n;m=eT(b,c[j>>2]|0,g,n,1)|0;i=d;return m|0}else if((l|0)==1179472430){l=(JD(k)|0)-8|0;hD(k,l,(l|0)<0|0?-1:0)|0;if((jD(k)|0)!=0){m=-1;i=d;return m|0}l=e|0;e=f|0;f=b+1064|0;n=0;g=0;o=0;a:while(1){while(1){p=FD(k)|0;q=JD(k)|0;HD(k)|0;if(!((q|0)>9|(p|0)==1096040772)){m=-1;r=52;break a}if((p|0)==1096040772){r=25;break a}else if((p|0)==1380992077){s=ZX(b,0)|0;if((s|0)==0){m=-12;r=52;break a}c[s+4>>2]=HD(k)|0;JD(k)|0;t=JD(k)|0;u=s+8|0;c[(c[u>>2]|0)+72>>2]=t;JD(k)|0;JD(k)|0;t=JD(k)|0;JD(k)|0;v=JD(k)|0;w=s+48|0;c[w>>2]=t;c[w+4>>2]=0;w=s+56|0;c[w>>2]=v;c[w+4>>2]=0;if((v|0)!=0){c[f>>2]=0;c[f+4>>2]=-2147483648}v=zD(k)|0;if((v|0)>0){w=l;t=0;while(1){x=zD(k)|0;if((t|0)<127){a[w]=x;y=w+1|0}else{y=w}x=t+1|0;if((x|0)<(v|0)){w=y;t=x}else{z=y;break}}}else{z=l}a[z]=0;t=zD(k)|0;if((t|0)>0){w=e;v=0;while(1){x=zD(k)|0;if((v|0)<127){a[w]=x;A=w+1|0}else{A=w}x=v+1|0;if((x|0)<(t|0)){w=A;v=x}else{B=A;break}}}else{B=e}a[B]=0;c[(c[u>>2]|0)+8>>2]=2;v=pJb(208)|0;c[v+88>>2]=-1;c[s+12>>2]=v;w=c[j>>2]|0;if((dT(b,w,s,v,JD(k)|0,e)|0)<0){m=-1;r=52;break a}}else if((p|0)==1347375696){break}else if((p|0)==1414418243){oT(b,k,1)}else{v=q-10|0;hD(k,v,(v|0)<0|0?-1:0)|0;}if((jD(k)|0)!=0){m=-1;r=52;break a}}JD(k)|0;JD(k)|0;JD(k)|0;JD(k)|0;JD(k)|0;v=VIb(JD(k)|0,0,1e6,0,1e3,0)|0;c[f>>2]=v;c[f+4>>2]=G;JD(k)|0;v=JD(k)|0;w=JD(k)|0;HD(k)|0;t=HD(k)|0;if((jD(k)|0)==0){n=w;g=v;o=t}else{m=-1;r=52;break}}if((r|0)==25){f=JD(k)|0;e=h;c[e>>2]=f;do{if((f|0)==0){if((o&4|0)==0){break}c[e>>2]=9e4}}while(0);JD(k)|0;if((n|0)==0){e=fD(k,0,0,1)|0;o=wrc(e,G,-18,0)|0;C=o}else{C=n}if((g|0)==0){m=0;i=d;return m|0}if((c[k+88>>2]|0)==0){m=0;i=d;return m|0}if((c[b+1084>>2]&2|0)!=0){m=0;i=d;return m|0}n=fD(k,g,0,0)|0;g=G;o=-1;if(!((g|0)>(o|0)|(g|0)==(o|0)&n>>>0>-1>>>0)){m=0;i=d;return m|0}n=c[j>>2]|0;b:do{if((FD(n)|0)==1480871497){j=b+28|0;o=b+24|0;g=b;e=0;while(1){if((JD(n)|0)>>>0<20>>>0){break b}hD(n,2,0)|0;f=JD(n)|0;h=HD(n)|0;B=JD(n)|0;A=c[o>>2]|0;z=0;while(1){if(!(z>>>0<A>>>0)){D=e;break}l=c[(c[j>>2]|0)+(z<<2)>>2]|0;if((c[l+4>>2]|0)==(h|0)){D=l;break}else{z=z+1|0}}do{if((z|0)==(A|0)){q=fD(n,0,0,1)|0;p=G;KIb(g,16,2535736,(E=i,i=i+24|0,c[E>>2]=h,c[E+8>>2]=q,c[E+16>>2]=p,E)|0);i=E}else{p=iD(n)|0;q=G;s=fD(n,0,0,1)|0;u=xrc(p,q,s,G)|0;s=Crc(u,G,14,0)|0;u=G;q=0;if((u|0)<(q|0)|(u|0)==(q|0)&s>>>0<f>>>0){s=iD(n)|0;q=G;u=fD(n,0,0,1)|0;p=G;l=iD(n)|0;y=G;t=fD(n,0,0,1)|0;v=xrc(l,y,t,G)|0;t=Crc(v,G,14,0)|0;v=G;KIb(g,16,2519824,(E=i,i=i+56|0,c[E>>2]=h,c[E+8>>2]=s,c[E+16>>2]=q,c[E+24>>2]=u,c[E+32>>2]=p,c[E+40>>2]=t,c[E+48>>2]=v,E)|0);i=E;break}if((f|0)==0){break}else{F=0}do{hD(n,2,0)|0;v=JD(n)|0;t=JD(n)|0;hD(n,4,0)|0;xX(D,t,0,v,0,0,0,1)|0;F=F+1|0;}while(F>>>0<f>>>0)}}while(0);if((B|0)==0){break b}f=fD(n,0,0,1)|0;h=G;A=B;z=0;if((h|0)<(z|0)|(h|0)==(z|0)&f>>>0<A>>>0){f=fD(n,A,z,0)|0;z=G;A=0;if((z|0)<(A|0)|(z|0)==(A|0)&f>>>0<0>>>0){break}}if((FD(n)|0)==1480871497){e=D}else{break b}}KIb(g,16,2505504,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E}}while(0);fD(k,C+18|0,0,0)|0;m=0;i=d;return m|0}else if((r|0)==52){i=d;return m|0}}else{m=-5;i=d;return m|0}return 0}function jT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+40|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=c[a+12>>2]|0;c[f>>2]=1;l=k+16|0;m=k+20|0;n=k+4|0;k=a+28|0;o=a+16|0;p=0;while(1){if((c[m>>2]|0)==0){do{if((c[n>>2]|0)==0){q=nT(a,g,j,e,h)|0;if((q|0)<=0){r=q;s=p;t=11;break}u=c[(c[k>>2]|0)+(c[e>>2]<<2)>>2]|0;v=q}else{q=c[c[k>>2]>>2]|0;w=c[q+12>>2]|0;c[g>>2]=0;c[g+4>>2]=-2147483648;if((c[w+136>>2]|0)==0){x=1e3}else{x=(ca(c[w+128>>2]|0,c[w+132>>2]|0)|0)/2|0}w=c[f>>2]|0;c[f>>2]=w+1;c[j>>2]=(w|0)==1?2:0;w=fD(c[o>>2]|0,0,0,1)|0;c[h>>2]=w;c[h+4>>2]=G;r=x;s=q;t=11}}while(0);if((t|0)==11){t=0;if((r|0)<0){y=-5;t=21;break}else{u=s;v=r}}if((jD(c[o>>2]|0)|0)!=0){y=-5;t=21;break}q=fT(a,c[o>>2]|0,u,c[u+12>>2]|0,v,b,f,c[j>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;if((q|0)<-1){y=q;t=21;break}w=c[j>>2]|0;do{if((w&2|0)!=0){if((c[f>>2]&127|0)!=1){break}xX(u,c[h>>2]|0,c[h+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0,0,0,1)|0}}while(0);if((q|0)==0){z=u;A=w}else{p=u;continue}}else{B=c[(c[k>>2]|0)+(c[l>>2]<<2)>>2]|0;C=gT(a,c[o>>2]|0,B,c[B+12>>2]|0,b)|0;if((C|0)<0){y=C;t=21;break}c[j>>2]=0;z=B;A=0}B=c[z+76>>2]|0;if((B|0)<=31){y=0;t=21;break}if(!((A&2|0)==0|(B|0)>47)){y=0;t=21;break}P1(b);p=z}if((t|0)==21){i=d;return y|0}return 0}function kT(a){a=a|0;var b=0,d=0;b=a+24|0;if((c[b>>2]|0)==0){return 0}d=a+28|0;a=0;do{P1(c[(c[(c[d>>2]|0)+(a<<2)>>2]|0)+12>>2]|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return 0}function lT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=c[a+12>>2]|0;if((DX(a,b,d,e,f)|0)<0){h=-1;return h|0}c[g+20>>2]=0;h=0;return h|0}function mT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+32|0;e=f|0;g=f+8|0;h=f+16|0;j=f+24|0;k=c[a+12>>2]|0;l=c[d>>2]|0;m=c[d+4>>2]|0;c[e>>2]=l;c[e+4>>2]=m;if((c[k+4>>2]|0)!=0){n=-2147483648;o=0;i=f;return(G=n,o)|0}p=a+16|0;q=fD(c[p>>2]|0,l,m,0)|0;m=G;l=0;if((m|0)<(l|0)|(m|0)==(l|0)&q>>>0<0>>>0){n=-2147483648;o=0;i=f;return(G=n,o)|0}c[k+12>>2]=0;k=nT(a,g,j,h,e)|0;if((k|0)<0){n=-2147483648;o=0;i=f;return(G=n,o)|0}q=a+28|0;l=k;while(1){k=c[h>>2]|0;m=c[(c[q>>2]|0)+(k<<2)>>2]|0;do{if((c[(c[m+8>>2]|0)+8>>2]|0)==0){if(((zD(c[p>>2]|0)|0)&64|0)!=0){r=1;s=l-1|0;break}r=((zD(c[p>>2]|0)|0)&127|0)==1;s=l-2|0}else{r=1;s=l}}while(0);if((c[j>>2]&2|0)!=0&r){t=c[e>>2]|0;u=c[e+4>>2]|0;v=c[g>>2]|0;w=c[g+4>>2]|0;xX(m,t,u,v,w,0,0,1)|0;if((k|0)==(b|0)){break}}hD(c[p>>2]|0,s,(s|0)<0|0?-1:0)|0;x=nT(a,g,j,h,e)|0;if((x|0)<0){n=-2147483648;o=0;y=12;break}else{l=x}}if((y|0)==12){i=f;return(G=n,o)|0}c[d>>2]=t;c[d+4>>2]=u;n=w;o=v;i=f;return(G=n,o)|0}function nT(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;h=c[a+12>>2]|0;j=c[a+16>>2]|0;if((jD(j)|0)!=0){k=-1;i=g;return k|0}l=h+12|0;m=h+8|0;h=a+28|0;n=a+24|0;o=a;a=-1;while(1){p=fD(j,0,0,1)|0;q=wrc(p,G,-3,-1)|0;c[f>>2]=q;c[f+4>>2]=G;q=c[l>>2]|0;do{if((q|0)>0){p=c[m>>2]|0;c[b>>2]=0;c[b+4>>2]=-2147483648;r=a;s=p;t=q;u=0;v=13}else{p=(zD(j)|0)+(a<<8)|0;if((p|0)==1145132097){KIb(o,24,2553616,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=1145132097;break}else if((p|0)==1229866072){y=JD(j)|0;hD(j,2,0)|0;z=JD(j)|0;A=(z*14|0)+20|0;do{if((y|0)==20){B=A}else{if((y|0)==(A|0)){B=y;break}KIb(o,24,2571952,(w=i,i=i+24|0,c[w>>2]=y,c[w+8>>2]=z,c[w+16>>2]=A,w)|0);i=w;B=y}}while(0);y=B-14|0;if((y|0)<0){x=1229866072;break}else{C=1229866072;D=y;v=17;break}}else{if((p-13|0)>>>0>65522>>>0){x=p;break}y=HD(j)|0;c[b>>2]=JD(j)|0;c[b+4>>2]=0;zD(j)|0;r=-1;s=y;t=p-12|0;u=zD(j)|0;v=13;break}}}while(0);if((v|0)==13){v=0;c[d>>2]=u;q=c[n>>2]|0;E=0;while(1){if(!(E>>>0<q>>>0)){break}if((s|0)==(c[(c[(c[h>>2]|0)+(E<<2)>>2]|0)+4>>2]|0)){break}else{E=E+1|0}}if((E|0)==(q|0)){C=r;D=t;v=17}else{break}}if((v|0)==17){v=0;hD(j,D,(D|0)<0|0?-1:0)|0;c[l>>2]=0;x=C}if((jD(j)|0)==0){a=x}else{k=-1;v=20;break}}if((v|0)==20){i=g;return k|0}c[e>>2]=E;k=t;i=g;return k|0}function oT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+1024|0;g=f|0;h=b+1140|0;if((e|0)==0){e=zD(d)|0;if((e|0)>0){b=g;j=0;while(1){k=zD(d)|0;if((j|0)<1023){a[b]=k;l=b+1|0}else{l=b}k=j+1|0;if((k|0)<(e|0)){b=l;j=k}else{m=l;break}}}else{m=g}a[m]=0;MGb(h,c[328574]|0,g,0)|0;m=zD(d)|0;if((m|0)>0){l=g;j=0;while(1){b=zD(d)|0;if((j|0)<1023){a[l]=b;n=l+1|0}else{n=l}b=j+1|0;if((b|0)<(m|0)){l=n;j=b}else{o=n;break}}}else{o=g}a[o]=0;MGb(h,c[328575]|0,g,0)|0;o=zD(d)|0;if((o|0)>0){n=g;j=0;while(1){l=zD(d)|0;if((j|0)<1023){a[n]=l;p=n+1|0}else{p=n}l=j+1|0;if((l|0)<(o|0)){n=p;j=l}else{q=p;break}}}else{q=g}a[q]=0;MGb(h,c[328576]|0,g,0)|0;q=zD(d)|0;if((q|0)>0){p=g;j=0;while(1){n=zD(d)|0;if((j|0)<1023){a[p]=n;r=p+1|0}else{r=p}n=j+1|0;if((n|0)<(q|0)){p=r;j=n}else{s=r;break}}}else{s=g}a[s]=0;MGb(h,c[328577]|0,g,0)|0;i=f;return}else{s=HD(d)|0;if((s|0)>0){r=g;j=0;while(1){p=zD(d)|0;if((j|0)<1023){a[r]=p;t=r+1|0}else{t=r}p=j+1|0;if((p|0)<(s|0)){r=t;j=p}else{u=t;break}}}else{u=g}a[u]=0;MGb(h,c[328574]|0,g,0)|0;u=HD(d)|0;if((u|0)>0){t=g;j=0;while(1){r=zD(d)|0;if((j|0)<1023){a[t]=r;v=t+1|0}else{v=t}r=j+1|0;if((r|0)<(u|0)){t=v;j=r}else{w=v;break}}}else{w=g}a[w]=0;MGb(h,c[328575]|0,g,0)|0;w=HD(d)|0;if((w|0)>0){v=g;j=0;while(1){t=zD(d)|0;if((j|0)<1023){a[v]=t;x=v+1|0}else{x=v}t=j+1|0;if((t|0)<(w|0)){v=x;j=t}else{y=x;break}}}else{y=g}a[y]=0;MGb(h,c[328576]|0,g,0)|0;y=HD(d)|0;if((y|0)>0){x=g;j=0;while(1){v=zD(d)|0;if((j|0)<1023){a[x]=v;z=x+1|0}else{z=x}v=j+1|0;if((v|0)<(y|0)){x=z;j=v}else{A=z;break}}}else{A=g}a[A]=0;MGb(h,c[328577]|0,g,0)|0;i=f;return}}function pT(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+12>>2]|0;e=a+24|0;f=c[e>>2]|0;if(f>>>0>2>>>0){KIb(a,16,2445976,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=b;return j|0}a:do{if((f|0)!=0){h=a+28|0;k=d;l=d+72|0;m=d+76|0;n=0;while(1){o=c[(c[h>>2]|0)+(n<<2)>>2]|0;c[o+4>>2]=n;p=c[o+8>>2]|0;o=k+(n*36|0)|0;mrc(o|0,0,36)|0;c[k+(n*36|0)+28>>2]=n;c[k+(n*36|0)+12>>2]=c[p+72>>2];c[k+(n*36|0)+32>>2]=p;q=c[p+8>>2]|0;if((q|0)==1){c[l>>2]=o;g[k+(n*36|0)+16>>2]=+(c[p+412>>2]|0)/+(c[p+424>>2]|0);c[k+(n*36|0)+8>>2]=1024;c[o>>2]=0;c[k+(n*36|0)+24>>2]=0}else if((q|0)==0){c[m>>2]=o;g[k+(n*36|0)+16>>2]=+(c[p+108>>2]|0)/+(c[p+104>>2]|0);c[k+(n*36|0)+8>>2]=4096;c[o>>2]=0;c[k+(n*36|0)+24>>2]=0}else{j=-1;break}n=n+1|0;if(!(n>>>0<(c[e>>2]|0)>>>0)){break a}}i=b;return j|0}}while(0);if((sT(a,0)|0)!=0){j=-1094995529;i=b;return j|0}eD(c[a+16>>2]|0);j=0;i=b;return j|0}function qT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[d+24>>2]|0;f=c[d+28>>2]|0;g=c[d+36>>2]|0;h=c[b+12>>2]|0;i=b+16|0;j=c[i>>2]|0;if((c[(c[(c[(c[b+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==1){d=c[h+72>>2]|0;b=hJb(f)|0;tT(c[i>>2]|0,d,f,g&1);if((c[(c[d+32>>2]|0)+48>>2]|0)==86019){if((f|0)>0){i=0;do{k=i|1;a[b+i|0]=a[e+k|0]|0;a[b+k|0]=a[e+i|0]|0;i=i+2|0;}while((i|0)<(f|0))}dD(j,b,f)}else{dD(j,e,f)}i=d+20|0;c[i>>2]=(c[i>>2]|0)+1;kJb(b);return 0}b=c[h+76>>2]|0;h=g&1;g=(f|0)>16383;tT(j,b,f+7+((g&1)<<2)|0,h);bD(j,129);if((h|0)==0){bD(j,1)}else{bD(j,129)}if(g){lD(j,f);lD(j,f)}else{g=f|16384;tD(j,g);tD(j,g)}g=b+20|0;bD(j,c[g>>2]&255);dD(j,e,f);c[g>>2]=(c[g>>2]|0)+1;return 0}function rT(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;if((c[d+88>>2]|0)==0){lD(d,0);lD(d,0);return 0}e=fD(d,0,0,1)|0;f=e-(c[b+80>>2]|0)|0;lD(d,0);lD(d,0);fD(d,0,0,0)|0;d=a+24|0;if((c[d>>2]|0)!=0){e=b;b=0;do{c[e+(b*36|0)+24>>2]=c[e+(b*36|0)+20>>2];b=b+1|0;}while(b>>>0<(c[d>>2]|0)>>>0)}sT(a,f)|0;return 0}function sT(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;f=c[b+12>>2]|0;h=c[b+16>>2]|0;j=h+12|0;k=c[j>>2]|0;kD(h,1179472430);lD(h,18);tD(h,0);lD(h,0);l=b+24|0;lD(h,(c[l>>2]|0)+4|0);kD(h,1347375696);lD(h,50);tD(h,0);m=c[l>>2]|0;if((m|0)==0){n=0;o=0;p=0;q=0;r=0}else{s=f;t=0;u=0;v=0;w=0;x=0;y=0;while(1){z=(c[s+(v*36|0)+12>>2]|0)+w|0;A=c[s+(v*36|0)+8>>2]|0;B=(A|0)>(u|0)?A:u;A=(c[s+(v*36|0)>>2]|0)+x|0;C=(c[s+(v*36|0)+4>>2]|0)+t|0;D=~~(+(c[s+(v*36|0)+24>>2]|0)*1.0e3/+g[s+(v*36|0)+16>>2]);E=(D|0)>(y|0)?D:y;D=v+1|0;if(D>>>0<m>>>0){t=C;u=B;v=D;w=z;x=A;y=E}else{n=C;o=B;p=z;q=A;r=E;break}}}lD(h,p);lD(h,p);lD(h,o);if((q|0)>0){F=(n|0)/(q|0)|0}else{F=0}lD(h,F);lD(h,q);lD(h,r);lD(h,0);lD(h,0);r=c[j>>2]|0;lD(h,0);tD(h,c[l>>2]|0);F=h+88|0;tD(h,(c[F>>2]|0)==0?7:3);kD(h,1414418243);n=b+1140|0;o=c[328574]|0;p=LGb(c[n>>2]|0,o,0,0)|0;if((p|0)==0){G=18}else{G=(lrc(c[p+4>>2]|0)|0)+18|0}p=c[328575]|0;y=LGb(c[n>>2]|0,p,0,0)|0;if((y|0)==0){H=G}else{H=(lrc(c[y+4>>2]|0)|0)+G|0}G=c[328576]|0;y=LGb(c[n>>2]|0,G,0,0)|0;if((y|0)==0){I=H}else{I=(lrc(c[y+4>>2]|0)|0)+H|0}H=c[328577]|0;y=LGb(c[n>>2]|0,H,0,0)|0;if((y|0)==0){J=I}else{J=(lrc(c[y+4>>2]|0)|0)+I|0}lD(h,J);tD(h,0);J=LGb(c[n>>2]|0,o,0,0)|0;if((J|0)==0){K=10230040}else{K=c[J+4>>2]|0}tD(h,lrc(K|0)|0);J=a[K]|0;if(!(J<<24>>24==0)){o=K;K=J;do{o=o+1|0;bD(h,K<<24>>24);K=a[o]|0;}while(!(K<<24>>24==0))}K=LGb(c[n>>2]|0,p,0,0)|0;if((K|0)==0){L=10230040}else{L=c[K+4>>2]|0}tD(h,lrc(L|0)|0);K=a[L]|0;if(!(K<<24>>24==0)){p=L;L=K;do{p=p+1|0;bD(h,L<<24>>24);L=a[p]|0;}while(!(L<<24>>24==0))}L=LGb(c[n>>2]|0,G,0,0)|0;if((L|0)==0){M=10230040}else{M=c[L+4>>2]|0}tD(h,lrc(M|0)|0);L=a[M]|0;if(!(L<<24>>24==0)){G=M;M=L;do{G=G+1|0;bD(h,M<<24>>24);M=a[G]|0;}while(!(M<<24>>24==0))}M=LGb(c[n>>2]|0,H,0,0)|0;if((M|0)==0){N=10230040}else{N=c[M+4>>2]|0}tD(h,lrc(N|0)|0);M=a[N]|0;if(!(M<<24>>24==0)){H=N;N=M;do{H=H+1|0;bD(h,N<<24>>24);N=a[H]|0;}while(!(N<<24>>24==0))}a:do{if((c[l>>2]|0)!=0){N=f;H=0;b:while(1){M=N+(H*36|0)+32|0;n=(c[(c[M>>2]|0)+8>>2]|0)==1;G=n?2104408:2594880;L=n?2127504:2622584;p=n?73:34;kD(h,1380992077);lD(h,p+82|0);tD(h,0);tD(h,H);n=N+(H*36|0)+12|0;lD(h,c[n>>2]|0);lD(h,c[n>>2]|0);lD(h,c[N+(H*36|0)+8>>2]|0);n=c[N+(H*36|0)>>2]|0;if((n|0)>0){O=(c[N+(H*36|0)+4>>2]|0)/(n|0)|0}else{O=0}lD(h,O);lD(h,0);lD(h,0);do{if((c[F>>2]|0)==0){P=18}else{n=c[N+(H*36|0)+24>>2]|0;if((n|0)==0){P=18;break}lD(h,~~(+(n*1e3|0|0)/+g[N+(H*36|0)+16>>2]))}}while(0);if((P|0)==18){P=0;lD(h,36e5)}bD(h,16);n=a[L]|0;if(!(n<<24>>24==0)){K=L;o=n;do{K=K+1|0;bD(h,o<<24>>24);o=a[K]|0;}while(!(o<<24>>24==0))}bD(h,20);o=a[G]|0;if(!(o<<24>>24==0)){K=G;L=o;do{K=K+1|0;bD(h,L<<24>>24);L=a[K]|0;}while(!(L<<24>>24==0))}lD(h,p);L=c[M>>2]|0;do{if((c[L+8>>2]|0)==1){K=c[L+412>>2]|0;G=(ca(c[L+424>>2]|0,c[L+72>>2]|0)|0)/(K<<3|0)|0;dD(h,2553584,3);bD(h,253);lD(h,262144);kD(h,878801454);lD(h,28652848);tD(h,4);lD(h,57);if((K|0)==48e3|(K|0)==24e3|(K|0)==12e3){Q=1}else if((K|0)==8e3|(K|0)==16e3|(K|0)==32e3){Q=3}else{Q=2}tD(h,Q);K=(((G|0)==557)<<31>>31)+G|0;lD(h,K);lD(h,333120);lD(h,((c[(c[M>>2]|0)+72>>2]|0)/8|0)*60|0);lD(h,((c[(c[M>>2]|0)+72>>2]|0)/8|0)*60|0);tD(h,1);tD(h,K);lD(h,0);tD(h,c[(c[M>>2]|0)+412>>2]|0);lD(h,16);tD(h,c[(c[M>>2]|0)+416>>2]|0);bD(h,4);bD(h,73);bD(h,110);bD(h,116);bD(h,48);if((c[(c[M>>2]|0)+52>>2]|0)==0){break b}bD(h,4);kD(h,c[(c[M>>2]|0)+52>>2]|0);tD(h,0);tD(h,0);tD(h,0);bD(h,0)}else{lD(h,34);kD(h,1329875286);if((c[(c[M>>2]|0)+48>>2]|0)==6){kD(h,808539730)}else{kD(h,808605266)}tD(h,c[(c[M>>2]|0)+120>>2]|0);tD(h,c[(c[M>>2]|0)+124>>2]|0);K=N+(H*36|0)+16|0;tD(h,~~+g[K>>2]);lD(h,0);tD(h,~~+g[K>>2]);lD(h,0);tD(h,8);if((c[(c[M>>2]|0)+48>>2]|0)==6){lD(h,268435456);break}else{lD(h,537931777);break}}}while(0);H=H+1|0;if(!(H>>>0<(c[l>>2]|0)>>>0)){break a}}KIb(b,16,2505432,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;R=-1;i=e;return R|0}}while(0);b=(c[j>>2]|0)-k|0;c[f+80>>2]=b;a[r]=b>>>24;a[r+1|0]=b>>>16;a[r+2|0]=b>>>8;a[r+3|0]=b;kD(h,1096040772);lD(h,d+18|0);tD(h,0);lD(h,q);lD(h,0);R=0;i=e;return R|0}function tT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=b|0;c[f>>2]=(c[f>>2]|0)+1;f=b+4|0;c[f>>2]=(c[f>>2]|0)+d;f=b+8|0;if((c[f>>2]|0)<(d|0)){c[f>>2]=d}tD(a,0);tD(a,d+12|0);tD(a,c[b+28>>2]|0);lD(a,~~(+(c[b+20>>2]|0)*1.0e3/+g[b+16>>2]));bD(a,0);bD(a,(e|0)!=0?2:0);return}function uT(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=ca(c<<1,e)|0;e=(f|0)/96|0;if((f|0)>95){g=0}else{return}do{f=ca(d[564888+(g<<1)|0]|0,e)|0;c=ca(d[564889+(g<<1)|0]|0,e)|0;h=0;while(1){i=b+(f>>1)|0;j=f<<2&4;k=b+(c>>1)|0;l=d[k]|0;m=c<<2&4;a[k]=((d[i]|0)>>>(j>>>0)&15)<<m|l&15<<(m^4);a[i]=(l>>>(m>>>0)&15)<<j|(d[i]|0)&15<<(j^4);j=h+1|0;if((j|0)<(e|0)){f=f+1|0;c=c+1|0;h=j}else{break}}g=g+1|0;}while((g|0)<38);return}function vT(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,2104392,8)|0)==0;return(b?100:0)|0}function wT(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0;d=i;i=i+544|0;e=d|0;f=d+8|0;g=d+264|0;h=d+520|0;j=d+528|0;k=d+536|0;l=c[b+16>>2]|0;m=c[b+12>>2]|0;n=g|0;o=0;while(1){p=zD(l)|0;if((p|0)==10){q=3;break}else if((p|0)==0){r=o;q=5;break}a[g+o|0]=p;p=o+1|0;if((p|0)<255){o=p}else{r=p;q=5;break}}if((q|0)==3){a[g+o|0]=0;s=((jD(l)|0)!=0)<<31>>31}else if((q|0)==5){a[g+r|0]=0;s=-1}r=0;while(1){o=zD(l)|0;if((o|0)==0){t=r;q=10;break}else if((o|0)==10){q=8;break}a[g+r|0]=o;o=r+1|0;if((o|0)<255){r=o}else{t=o;q=10;break}}if((q|0)==8){a[g+r|0]=0;u=((jD(l)|0)!=0)<<31>>31}else if((q|0)==10){a[g+t|0]=0;u=-1}t=u|s;s=b+1140|0;MGb(s,2378528,n,0)|0;u=0;while(1){r=zD(l)|0;if((r|0)==0){v=u;q=15;break}else if((r|0)==10){q=13;break}a[g+u|0]=r;r=u+1|0;if((r|0)<255){u=r}else{v=r;q=15;break}}if((q|0)==13){a[g+u|0]=0;w=((jD(l)|0)!=0)<<31>>31}else if((q|0)==15){a[g+v|0]=0;w=-1}v=t|w;MGb(s,2310368,n,0)|0;w=0;while(1){t=zD(l)|0;if((t|0)==10){q=18;break}else if((t|0)==0){x=w;q=20;break}a[g+w|0]=t;t=w+1|0;if((t|0)<255){w=t}else{x=t;q=20;break}}if((q|0)==18){a[g+w|0]=0;y=((jD(l)|0)!=0)<<31>>31}else if((q|0)==20){a[g+x|0]=0;y=-1}x=v|y;MGb(s,2257800,n,0)|0;s=ZX(b,0)|0;if((s|0)==0){z=-12;i=d;return z|0}y=s+8|0;c[(c[y>>2]|0)+8>>2]=0;v=f|0;w=0;while(1){t=zD(l)|0;if((t|0)==10){q=24;break}else if((t|0)==0){A=w;q=26;break}a[f+w|0]=t;t=w+1|0;if((t|0)<255){w=t}else{A=t;q=26;break}}if((q|0)==24){a[f+w|0]=0;B=((jD(l)|0)!=0)<<31>>31}else if((q|0)==26){a[f+A|0]=0;B=-1}A=x|B;B=a[v]|0;if((B-48&255)>>>0<10>>>0){x=v;w=0;t=B;B=A;while(1){u=w>>>0>214748363>>>0?-1:B;r=(w*10|0)-48+(t<<24>>24)|0;o=x+1|0;p=a[o]|0;if((p-48&255)>>>0<10>>>0){x=o;w=r;t=p;B=u}else{C=r;D=u;break}}}else{C=0;D=A}c[(c[y>>2]|0)+52>>2]=C;C=0;while(1){A=zD(l)|0;if((A|0)==0){E=C;q=33;break}else if((A|0)==10){q=31;break}a[f+C|0]=A;A=C+1|0;if((A|0)<255){C=A}else{E=A;q=33;break}}if((q|0)==31){a[f+C|0]=0;F=((jD(l)|0)!=0)<<31>>31}else if((q|0)==33){a[f+E|0]=0;F=-1}E=F|D;D=a[v]|0;if((D-48&255)>>>0<10>>>0){F=v;C=0;A=D;D=E;while(1){B=C>>>0>214748363>>>0?-1:D;t=(C*10|0)-48+(A<<24>>24)|0;w=F+1|0;x=a[w]|0;if((x-48&255)>>>0<10>>>0){F=w;C=t;A=x;D=B}else{H=t;I=B;break}}}else{H=0;I=E}c[(c[y>>2]|0)+120>>2]=H;H=0;while(1){E=zD(l)|0;if((E|0)==0){J=H;q=40;break}else if((E|0)==10){q=38;break}a[f+H|0]=E;E=H+1|0;if((E|0)<255){H=E}else{J=E;q=40;break}}if((q|0)==38){a[f+H|0]=0;K=((jD(l)|0)!=0)<<31>>31}else if((q|0)==40){a[f+J|0]=0;K=-1}J=K|I;I=a[v]|0;if((I-48&255)>>>0<10>>>0){K=v;H=0;E=I;I=J;while(1){D=H>>>0>214748363>>>0?-1:I;A=(H*10|0)-48+(E<<24>>24)|0;C=K+1|0;F=a[C]|0;if((F-48&255)>>>0<10>>>0){K=C;H=A;E=F;I=D}else{L=A;M=D;break}}}else{L=0;M=J}c[(c[y>>2]|0)+124>>2]=L;L=0;while(1){J=zD(l)|0;if((J|0)==10){q=45;break}else if((J|0)==0){N=L;q=47;break}a[f+L|0]=J;J=L+1|0;if((J|0)<255){L=J}else{N=J;q=47;break}}if((q|0)==45){a[f+L|0]=0;O=((jD(l)|0)!=0)<<31>>31}else if((q|0)==47){a[f+N|0]=0;O=-1}N=O|M;M=a[v]|0;if((M-48&255)>>>0<10>>>0){O=v;L=0;J=M;M=N;while(1){I=L>>>0>214748363>>>0?-1:M;E=(L*10|0)-48+(J<<24>>24)|0;H=O+1|0;K=a[H]|0;if((K-48&255)>>>0<10>>>0){O=H;L=E;J=K;M=I}else{P=E;Q=I;break}}}else{P=0;Q=N}c[(c[y>>2]|0)+792>>2]=P;P=0;while(1){N=zD(l)|0;if((N|0)==0){R=P;q=54;break}else if((N|0)==10){q=52;break}a[g+P|0]=N;N=P+1|0;if((N|0)<255){P=N}else{R=N;q=54;break}}if((q|0)==52){a[g+P|0]=0;S=((jD(l)|0)!=0)<<31>>31}else if((q|0)==54){a[g+R|0]=0;S=-1}R=S|Q;Q=e;S=a[n]|0;if((S-48&255)>>>0<10>>>0){P=n;N=0;M=S;J=R;do{J=N>>>0>214748363>>>0?-1:J;N=(N*10|0)-48+(M<<24>>24)|0;P=P+1|0;M=a[P]|0;}while((M-48&255)>>>0<10>>>0);T=P;U=(N|0)<0|0?-1:0;V=N;W=M;X=J}else{T=n;U=0;V=0;W=S;X=R}R=W<<24>>24==46?T+1|0:T;T=a[R]|0;if((T-48&255)>>>0>9>>>0){Y=U;Z=V;_=0;$=1}else{W=R;R=U;U=V;V=0;S=1;J=T;while(1){T=Erc(U,R,10,0)|0;M=G;N=wrc(J<<24>>24,J<<24>>24<0|0?-1:0,-48,-1)|0;P=wrc(N,G,T,M)|0;M=G;T=Erc(S,V,10,0)|0;N=G;L=W+1|0;O=a[L]|0;I=214748364;E=214748364;if((O-48&255)>>>0>9>>>0|((M|0)>(I|0)|(M|0)==(I|0)&P>>>0>-858993461>>>0)|((N|0)>(E|0)|(N|0)==(E|0)&T>>>0>-858993460>>>0)){Y=M;Z=P;_=N;$=T;break}else{W=L;R=M;U=P;V=N;S=T;J=O}}}J=(Z|0)==0&(Y|0)==0?-1:X;xKb(e,Q+4|0,Z,Y,$,_,2147483647,0)|0;_X(s,32,c[e+4>>2]|0,c[e>>2]|0);e=c[y>>2]|0;_=c[e+52>>2]|0;if((_|0)==130){c[e+48>>2]=1160852272;aa=0}else if((_|0)==124){c[e+48>>2]=116;c[e+792>>2]=16;aa=0}else{RIb(b,2212600,(ba=i,i=i+8|0,c[ba>>2]=_,ba)|0);i=ba;c[(c[y>>2]|0)+48>>2]=0;aa=0}while(1){_=zD(l)|0;if((_|0)==0){da=aa;q=67;break}else if((_|0)==10){q=65;break}a[f+aa|0]=_;_=aa+1|0;if((_|0)<255){aa=_}else{da=_;q=67;break}}if((q|0)==65){a[f+aa|0]=0;ea=((jD(l)|0)!=0)<<31>>31}else if((q|0)==67){a[f+da|0]=0;ea=-1}da=ea|J;J=a[v]|0;do{if((J-48&255)>>>0<10>>>0){ea=v;aa=0;_=J;e=da;do{e=aa>>>0>214748363>>>0?-1:e;aa=(aa*10|0)-48+(_<<24>>24)|0;ea=ea+1|0;_=a[ea]|0;}while((_-48&255)>>>0<10>>>0);if((aa|0)==0){fa=e;q=69;break}_=ZX(b,0)|0;if((_|0)==0){z=-12;i=d;return z|0}ea=_+8|0;$=c[ea>>2]|0;c[$+8>>2]=1;c[$+52>>2]=aa;$=0;while(1){Y=zD(l)|0;if((Y|0)==0){ga=$;q=77;break}else if((Y|0)==10){q=75;break}a[f+$|0]=Y;Y=$+1|0;if((Y|0)<255){$=Y}else{ga=Y;q=77;break}}if((q|0)==75){a[f+$|0]=0;ha=((jD(l)|0)!=0)<<31>>31}else if((q|0)==77){a[f+ga|0]=0;ha=-1}Y=ha|e;Z=a[v]|0;if((Z-48&255)>>>0<10>>>0){Q=v;X=0;S=Z;Z=Y;while(1){V=X>>>0>214748363>>>0?-1:Z;U=(X*10|0)-48+(S<<24>>24)|0;R=Q+1|0;W=a[R]|0;if((W-48&255)>>>0<10>>>0){Q=R;X=U;S=W;Z=V}else{ia=U;ja=V;break}}}else{ia=0;ja=Y}c[(c[ea>>2]|0)+412>>2]=ia;Z=0;while(1){S=zD(l)|0;if((S|0)==10){q=82;break}else if((S|0)==0){ka=Z;q=84;break}a[f+Z|0]=S;S=Z+1|0;if((S|0)<255){Z=S}else{ka=S;q=84;break}}if((q|0)==82){a[f+Z|0]=0;la=((jD(l)|0)!=0)<<31>>31}else if((q|0)==84){a[f+ka|0]=0;la=-1}Y=la|ja;S=a[v]|0;if((S-48&255)>>>0<10>>>0){X=v;Q=0;e=S;S=Y;while(1){$=Q>>>0>214748363>>>0?-1:S;V=(Q*10|0)-48+(e<<24>>24)|0;U=X+1|0;W=a[U]|0;if((W-48&255)>>>0<10>>>0){X=U;Q=V;e=W;S=$}else{ma=V;na=$;break}}}else{ma=0;na=Y}c[(c[ea>>2]|0)+416>>2]=ma;S=0;while(1){e=zD(l)|0;if((e|0)==0){oa=S;q=91;break}else if((e|0)==10){q=89;break}a[f+S|0]=e;e=S+1|0;if((e|0)<255){S=e}else{oa=e;q=91;break}}if((q|0)==89){a[f+S|0]=0;pa=((jD(l)|0)!=0)<<31>>31}else if((q|0)==91){a[f+oa|0]=0;pa=-1}Y=pa|na;e=a[v]|0;if((e-48&255)>>>0<10>>>0){Q=v;X=0;Z=e;e=Y;do{e=X>>>0>214748363>>>0?-1:e;X=(X*10|0)-48+(Z<<24>>24)|0;Q=Q+1|0;Z=a[Q]|0;}while((Z-48&255)>>>0<10>>>0);Z=c[ea>>2]|0;Q=Z+792|0;if((X|0)==0){qa=e;ra=Z;sa=Q;q=96}else{ta=X;ua=e;va=Z;wa=Q}}else{Q=c[ea>>2]|0;qa=Y;ra=Q;sa=Q+792|0;q=96}if((q|0)==96){ta=4;ua=qa;va=ra;wa=sa}c[wa>>2]=ta;Q=ca(ta,c[va+412>>2]|0)|0;Z=ca(Q,c[va+416>>2]|0)|0;c[va+72>>2]=Z;Q=va+48|0;c[Q>>2]=0;do{if((aa|0)==101){if((ta|0)==8){c[Q>>2]=65541;xa=Z;break}else if((ta|0)==4){c[Q>>2]=69655;xa=Z;break}else{q=103;break}}else if((aa|0)==1){if((ta|0)!=16){q=103;break}c[Q>>2]=65536;xa=Z}else{q=103}}while(0);if((q|0)==103){QIb(b,2179872,(ba=i,i=i+8|0,c[ba>>2]=aa,ba)|0);i=ba;xa=c[(c[ea>>2]|0)+72>>2]|0}_X(_,32,1,xa);ya=_;za=ua}else{fa=da;q=69}}while(0);if((q|0)==69){da=0;while(1){ua=zD(l)|0;if((ua|0)==10){q=106;break}else if((ua|0)==0){Aa=da;q=108;break}a[g+da|0]=ua;ua=da+1|0;if((ua|0)<255){da=ua}else{Aa=ua;q=108;break}}if((q|0)==106){a[g+da|0]=0;Ba=((jD(l)|0)!=0)<<31>>31}else if((q|0)==108){a[g+Aa|0]=0;Ba=-1}Aa=Ba|fa;fa=0;while(1){Ba=zD(l)|0;if((Ba|0)==10){q=181;break}else if((Ba|0)==0){Ca=fa;q=183;break}a[g+fa|0]=Ba;Ba=fa+1|0;if((Ba|0)<255){fa=Ba}else{Ca=Ba;q=183;break}}if((q|0)==181){a[g+fa|0]=0;Da=((jD(l)|0)!=0)<<31>>31}else if((q|0)==183){a[g+Ca|0]=0;Da=-1}Ca=Da|Aa;Aa=0;while(1){Da=zD(l)|0;if((Da|0)==10){q=186;break}else if((Da|0)==0){Ea=Aa;q=188;break}a[g+Aa|0]=Da;Da=Aa+1|0;if((Da|0)<255){Aa=Da}else{Ea=Da;q=188;break}}if((q|0)==186){a[g+Aa|0]=0;Fa=((jD(l)|0)!=0)<<31>>31}else if((q|0)==188){a[g+Ea|0]=0;Fa=-1}ya=0;za=Fa|Ca}Ca=0;while(1){Fa=zD(l)|0;if((Fa|0)==10){q=112;break}else if((Fa|0)==0){Ga=Ca;q=114;break}a[f+Ca|0]=Fa;Fa=Ca+1|0;if((Fa|0)<255){Ca=Fa}else{Ga=Fa;q=114;break}}if((q|0)==112){a[f+Ca|0]=0;Ha=((jD(l)|0)!=0)<<31>>31}else if((q|0)==114){a[f+Ga|0]=0;Ha=-1}Ga=Ha|za;za=a[v]|0;do{if((za-48&255)>>>0<10>>>0){Ha=v;Ca=0;Fa=za;Ea=Ga;do{Ea=Ca>>>0>214748363>>>0?-1:Ea;Ca=(Ca*10|0)-48+(Fa<<24>>24)|0;Ha=Ha+1|0;Fa=a[Ha]|0;}while((Fa-48&255)>>>0<10>>>0);Fa=m;c[Fa>>2]=Ca;if((Ca|0)<=1){Ia=Ea;Ja=Fa;break}Ha=c[(c[y>>2]|0)+52>>2]|0;if((Ha|0)==124){Ia=Ea;Ja=Fa;break}KIb(b,24,2152064,(ba=i,i=i+8|0,c[ba>>2]=Ha,ba)|0);i=ba;Ia=Ea;Ja=Fa}else{Fa=m;c[Fa>>2]=0;Ia=Ga;Ja=Fa}}while(0);Ga=0;while(1){m=zD(l)|0;if((m|0)==0){Ka=Ga;q=125;break}else if((m|0)==10){q=123;break}a[f+Ga|0]=m;m=Ga+1|0;if((m|0)<255){Ga=m}else{Ka=m;q=125;break}}if((q|0)==123){a[f+Ga|0]=0;La=((jD(l)|0)!=0)<<31>>31}else if((q|0)==125){a[f+Ka|0]=0;La=-1}Ka=La|Ia;Ia=a[v]|0;if((Ia-48&255)>>>0<10>>>0){La=v;Ga=0;m=Ia;Ia=Ka;do{Ia=Ga>>>0>214748363>>>0?-1:Ia;Ga=(Ga*10|0)-48+(m<<24>>24)|0;La=La+1|0;m=a[La]|0;}while((m-48&255)>>>0<10>>>0);Ma=Ga+1|0;Na=Ia}else{Ma=1;Na=Ka}Ka=0;while(1){Ia=zD(l)|0;if((Ia|0)==10){q=131;break}else if((Ia|0)==0){Oa=Ka;q=133;break}a[g+Ka|0]=Ia;Ia=Ka+1|0;if((Ia|0)<255){Ka=Ia}else{Oa=Ia;q=133;break}}if((q|0)==131){a[g+Ka|0]=0;Pa=((jD(l)|0)!=0)<<31>>31}else if((q|0)==133){a[g+Oa|0]=0;Pa=-1}Oa=Pa|Na;Na=0;while(1){Pa=zD(l)|0;if((Pa|0)==10){q=136;break}else if((Pa|0)==0){Qa=Na;q=138;break}a[g+Na|0]=Pa;Pa=Na+1|0;if((Pa|0)<255){Na=Pa}else{Qa=Pa;q=138;break}}if((q|0)==136){a[g+Na|0]=0;Ra=((jD(l)|0)!=0)<<31>>31}else if((q|0)==138){a[g+Qa|0]=0;Ra=-1}Qa=Oa|Ra;Ra=0;while(1){Oa=zD(l)|0;if((Oa|0)==10){q=141;break}else if((Oa|0)==0){Sa=Ra;q=143;break}a[f+Ra|0]=Oa;Oa=Ra+1|0;if((Oa|0)<255){Ra=Oa}else{Sa=Oa;q=143;break}}if((q|0)==141){a[f+Ra|0]=0;Ta=((jD(l)|0)!=0)<<31>>31}else if((q|0)==143){a[f+Sa|0]=0;Ta=-1}Sa=Qa|Ta;Ta=a[v]|0;if((Ta-48&255)>>>0<10>>>0){Qa=v;v=0;f=Ta;Ta=Sa;do{Ta=v>>>0>214748363>>>0?-1:Ta;v=(v*10|0)-48+(f<<24>>24)|0;Qa=Qa+1|0;f=a[Qa]|0;}while((f-48&255)>>>0<10>>>0);Ua=(v|0)<0|0?-1:0;Va=v;Wa=Ta}else{Ua=0;Va=0;Wa=Sa}Sa=0;while(1){Ta=zD(l)|0;if((Ta|0)==10){q=149;break}else if((Ta|0)==0){Xa=Sa;q=151;break}a[g+Sa|0]=Ta;Ta=Sa+1|0;if((Ta|0)<255){Sa=Ta}else{Xa=Ta;q=151;break}}if((q|0)==149){a[g+Sa|0]=0;Ya=((jD(l)|0)!=0)<<31>>31}else if((q|0)==151){a[g+Xa|0]=0;Ya=-1}Xa=Ya|Wa;Wa=0;while(1){Ya=zD(l)|0;if((Ya|0)==0){Za=Wa;q=156;break}else if((Ya|0)==10){q=154;break}a[g+Wa|0]=Ya;Ya=Wa+1|0;if((Ya|0)<255){Wa=Ya}else{Za=Ya;q=156;break}}if((q|0)==154){a[g+Wa|0]=0;_a=((jD(l)|0)!=0)<<31>>31}else if((q|0)==156){a[g+Za|0]=0;_a=-1}Za=Xa|_a;_a=0;while(1){Xa=zD(l)|0;if((Xa|0)==10){q=159;break}else if((Xa|0)==0){$a=_a;q=161;break}a[g+_a|0]=Xa;Xa=_a+1|0;if((Xa|0)<255){_a=Xa}else{$a=Xa;q=161;break}}if((q|0)==159){a[g+_a|0]=0;ab=((jD(l)|0)!=0)<<31>>31}else if((q|0)==161){a[g+$a|0]=0;ab=-1}fD(l,Va,Ua,0)|0;Ua=(Za|ab|0)==0;a:do{if(Ua&(Ma|0)!=0){if((ya|0)==0){ab=0;while(1){Za=0;while(1){Va=zD(l)|0;if((Va|0)==0){bb=Za;q=168;break}else if((Va|0)==10){q=166;break}a[g+Za|0]=Va;Va=Za+1|0;if((Va|0)<255){Za=Va}else{bb=Va;q=168;break}}if((q|0)==166){q=0;a[g+Za|0]=0;cb=((jD(l)|0)!=0)<<31>>31}else if((q|0)==168){q=0;a[g+bb|0]=0;cb=-1}Va=Bd(n|0,2127480,(ba=i,i=i+24|0,c[ba>>2]=h,c[ba+8>>2]=j,c[ba+16>>2]=k,ba)|0)|0;i=ba;if((Va|0)!=3){db=0;break a}Va=c[Ja>>2]|0;$a=ca(Va,ab)|0;xX(s,c[h>>2]|0,c[h+4>>2]|0,$a,0,c[j>>2]|0,Va,0)|0;Va=ab+1|0;$a=(cb|0)==0;if($a&Va>>>0<Ma>>>0){ab=Va}else{db=$a;break}}}else{ab=0;Ea=0;while(1){Ca=0;while(1){$a=zD(l)|0;if(($a|0)==10){q=173;break}else if(($a|0)==0){eb=Ca;q=175;break}a[g+Ca|0]=$a;$a=Ca+1|0;if(($a|0)<255){Ca=$a}else{eb=$a;q=175;break}}if((q|0)==173){q=0;a[g+Ca|0]=0;fb=((jD(l)|0)!=0)<<31>>31}else if((q|0)==175){q=0;a[g+eb|0]=0;fb=-1}Za=Bd(n|0,2127480,(ba=i,i=i+24|0,c[ba>>2]=h,c[ba+8>>2]=j,c[ba+16>>2]=k,ba)|0)|0;i=ba;if((Za|0)!=3){db=0;break a}Za=c[Ja>>2]|0;$a=ca(Za,ab)|0;xX(s,c[h>>2]|0,c[h+4>>2]|0,$a,0,c[j>>2]|0,Za,0)|0;Za=wrc(c[j>>2]|0,c[j+4>>2]|0,c[h>>2]|0,c[h+4>>2]|0)|0;$a=c[k>>2]|0;xX(ya,Za,G,Ea,(Ea|0)<0|0?-1:0,$a,$a<<3|0>>>29,0)|0;$a=c[k>>2]|0;Za=wrc($a<<3|0>>>29,c[k+4>>2]<<3|$a>>>29,Ea,0)|0;$a=ab+1|0;Va=(fb|0)==0;if(Va&$a>>>0<Ma>>>0){ab=$a;Ea=Za}else{db=Va;break}}}}else{db=Ua}}while(0);z=db?0:-5;i=d;return z|0}function xT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=d+8|0;g=c[f>>2]|0;h=d+4|0;i=c[h>>2]|0;if((g|0)==(c[a+24>>2]|0)){j=i+1|0;c[h>>2]=j;c[f>>2]=0;k=0;l=j}else{k=g;l=i}i=c[(c[a+28>>2]|0)+(k<<2)>>2]|0;k=d+4|0;if(!(l>>>0<(c[i+404>>2]|0)>>>0)){m=-541478725;return m|0}a=c[i+400>>2]|0;g=d+12|0;do{if((c[g>>2]|0)==0){j=a+(l*24|0)|0;h=fD(e,c[j>>2]|0,c[j+4>>2]|0,0)|0;j=G;n=0;if((j|0)<(n|0)|(j|0)==(n|0)&h>>>0<0>>>0){m=-5}else{break}return m|0}}while(0);h=i+8|0;i=c[h>>2]|0;do{if((c[i+8>>2]|0)==0){if((c[i+52>>2]|0)!=124){o=13;break}hD(e,4,0)|0;n=FD(e)|0;j=fD(e,-8,-1,1)|0;p=G;q=0;if((p|0)<(q|0)|(p|0)==(q|0)&j>>>0<0>>>0){m=-5;return m|0}if((fX(e,b,n)|0)==(n|0)){c[b+48>>2]=1;j=a+(l*24|0)+8|0;q=wrc(c[g>>2]|0,0,c[j>>2]|0,c[j+4>>2]|0)|0;j=b+8|0;c[j>>2]=q;c[j+4>>2]=G;c[b+32>>2]=c[f>>2];j=(c[g>>2]|0)+1|0;c[g>>2]=j;if((j|0)!=(c[d>>2]|0)){r=n;break}c[g>>2]=0;c[f>>2]=(c[f>>2]|0)+1;r=n;break}else{P1(b);m=-5;return m|0}}else{o=13}}while(0);if((o|0)==13){o=a+(l*24|0)+16|0;i=fX(e,b,c[o>>2]>>2)|0;if((i|0)!=(c[o>>2]>>2|0)){P1(b);m=-5;return m|0}if((c[(c[h>>2]|0)+8>>2]|0)==0){c[b+48>>2]=c[d>>2]}else{c[b+48>>2]=i<<3}d=a+(l*24|0)+8|0;l=c[d+4>>2]|0;a=b+8|0;c[a>>2]=c[d>>2];c[a+4>>2]=l;c[b+32>>2]=c[f>>2];c[f>>2]=(c[f>>2]|0)+1;r=i}if((c[k>>2]|0)!=0){m=r;return m|0}if((c[g>>2]|0)!=0){m=r;return m|0}g=b+36|0;c[g>>2]=c[g>>2]|1;m=r;return m|0}function yT(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;if((grc(b,2257792,3)|0)!=0){e=0;return e|0}if(((d[b+3|0]|0)-50|0)>>>0>4>>>0){e=0;return e|0}a=b+8|0;f=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(f>>>0>256>>>0|(f|0)==0){e=12;return e|0}else{e=b+16|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;return(b>>>0>384e3>>>0|(b|0)==0?12:100)|0}return 0}function zT(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=b+16|0;g=c[f>>2]|0;h=ZX(b,0)|0;if((h|0)==0){j=-12;i=e;return j|0}hD(g,3,0)|0;k=zD(g)|0;l=c[h+8>>2]|0;c[l+8>>2]=1;m=FD(g)|0;n=l+52|0;c[n>>2]=m;o=JX(677720,m)|0;m=l+48|0;c[m>>2]=o;if((o|0)==0){o=e|0;v5a(o,5,c[n>>2]|0)|0;p=0;while(1){if(!(p>>>0<5>>>0)){q=7;break}if((c[n>>2]|0)==(c[677696+(p<<2)>>2]|0)){q=6;break}else{p=p+1|0}}if((q|0)==6){QIb(b,2378488,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r;j=-1163346256;i=e;return j|0}else if((q|0)==7){KIb(b,16,2310320,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r;j=-1094995529;i=e;return j|0}}r=FD(g)|0;o=l+416|0;c[o>>2]=r;if((r|0)==0){j=-1094995529;i=e;return j|0}hD(g,4,0)|0;r=FD(g)|0;b=l+412|0;c[b>>2]=r;if((r|0)==0){j=-1094995529;i=e;return j|0}hD(g,4,0)|0;r=c[m>>2]|0;do{if((r|0)==65536|(r|0)==65537){if((k|0)==52){s=2048}else{s=FD(g)|0}if((c[g+88>>2]|0)==0){t=s;break}m=iD(g)|0;q=xrc(m,G,s,(s|0)<0|0?-1:0)|0;m=Crc(q,G,2,0)|0;q=c[o>>2]|0;p=Crc(m,G,q,(q|0)<0|0?-1:0)|0;q=h+56|0;c[q>>2]=p;c[q+4>>2]=G;t=s}else if((r|0)==69650){q=FD(g)|0;if((QX(l,c[f>>2]|0,32)|0)<0){j=-12;i=e;return j|0}p=l+96|0;m=c[p>>2]|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+2|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+4|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+6|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+8|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+10|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+12|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+14|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+16|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+18|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+20|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+22|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+24|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+26|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+28|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+30|0;y=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;if((c[g+88>>2]|0)==0){t=q;break}m=iD(g)|0;p=xrc(m,G,q,(q|0)<0|0?-1:0)|0;m=Crc(p,G,8,0)|0;p=Erc(m,G,14,0)|0;m=h+56|0;c[m>>2]=p;c[m+4>>2]=G;t=q}else if((r|0)==1380008992){c[l+432>>2]=(c[o>>2]|0)*20|0;if((c[g+88>>2]|0)==0){t=2048;break}q=iD(g)|0;m=wrc(q,G,-2048,0)|0;q=B5a(l,m)|0;m=h+56|0;c[m>>2]=q;c[m+4>>2]=(q|0)<0|0?-1:0;t=2048}else{t=2048}}while(0);l=fD(g,0,0,1)|0;o=xrc(t,(t|0)<0|0?-1:0,l,G)|0;hD(g,o,G)|0;_X(h,64,1,c[b>>2]|0);j=0;i=e;return j|0}function AT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;e=a+16|0;if((jD(c[e>>2]|0)|0)!=0){f=-541478725;return f|0}a=c[e>>2]|0;if((c[d+48>>2]|0)==1380008992){g=fX(a,b,c[d+432>>2]|0)|0}else{g=fX(a,b,1024)|0}do{if((g|0)!=1024){if((g|0)>=0){M1(b,g);break}P1(b);f=g;return f|0}}while(0);c[b+32>>2]=0;f=g;return f|0}function BT(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+16>>2]|0;e=HD(d)|0;f=HD(d)|0;g=HD(d)|0;HD(d)|0;d=JX(1407048,e)|0;if((d|0)==69633){RIb(a,2378464,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=b;return j|0}k=g5a(d)|0;if((k|0)==0){QIb(a,2310296,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=b;return j|0}h=ZX(a,0)|0;if((h|0)==0){j=-12;i=b;return j|0}a=h+56|0;c[a>>2]=(f<<3>>>0)/(k>>>0)|0;c[a+4>>2]=0;a=c[h+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=e;c[a+48>>2]=d;c[a+416>>2]=1;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;c[a+412>>2]=g;c[a+432>>2]=1;_X(h,64,1,g);j=0;i=b;return j|0}function CT(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;f=c[e+52>>2]|0;if((f|0)==0){g=-1094995529;i=b;return g|0}if((c[e+416>>2]|0)!=1){KIb(a,16,2310224,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1094995529;i=b;return g|0}if((c[d+88>>2]|0)==0){KIb(a,16,2257744,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1094995529;i=b;return g|0}j=e+412|0;if((c[j>>2]|0)>>>0>65535>>>0){KIb(a,16,2212568,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1094995529;i=b;return g|0}if((c[e+48>>2]|0)==69633){KIb(a,16,2179840,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1163346256;i=b;return g|0}else{tD(d,f);tD(d,0);tD(d,c[j>>2]|0);tD(d,0);eD(d);g=0;i=b;return g|0}return 0}function DT(a,b){a=a|0;b=b|0;dD(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function ET(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+16>>2]|0;e=fD(d,0,0,1)|0;f=G;g=0;if((f|0)<(g|0)|(f|0)==(g|0)&e>>>0<0>>>0){h=e;i=b;return h|0}g=0;if((f|0)>(g|0)|(f|0)==(g|0)&e>>>0>65543>>>0){KIb(a,24,2378416,(a=i,i=i+16|0,c[a>>2]=e,c[a+8>>2]=f,a)|0);i=a;j=65535}else{a=wrc(e,f,65528,0)|0;j=a&65535}fD(d,2,0,0)|0;tD(d,j);fD(d,e,f,0)|0;h=0;i=b;return h|0}function FT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[a+12>>2]|0;g=a+16|0;bD(c[g>>2]|0,128);bD(c[g>>2]|0,c[f+12>>2]&127|e<<7&128);e=f+24|0;tD(c[g>>2]|0,c[e>>2]|0);lD(c[g>>2]|0,c[f+28>>2]|0);lD(c[g>>2]|0,c[f+16>>2]|0);dD(c[g>>2]|0,b,d);eD(c[g>>2]|0);c[e>>2]=(c[e>>2]|0)+1&65535;e=f+68|0;c[e>>2]=(c[e>>2]|0)+d;d=f+64|0;c[d>>2]=(c[d>>2]|0)+1;return}function GT(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[b+12>>2]|0;if((c[b+24>>2]|0)!=1){KIb(b,16,2257616,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=d;return k|0}l=c[c[b+28>>2]>>2]|0;m=l+8|0;n=c[m>>2]|0;o=c[n+48>>2]|0;if(!((o|0)==5|(o|0)==20|(o|0)==28|(o|0)==1|(o|0)==2|(o|0)==13|(o|0)==86018|(o|0)==86016|(o|0)==86017|(o|0)==65543|(o|0)==65542|(o|0)==65540|(o|0)==65537|(o|0)==65536|(o|0)==65539|(o|0)==65538|(o|0)==65541|(o|0)==131072|(o|0)==73728|(o|0)==73729|(o|0)==86021|(o|0)==31|(o|0)==141|(o|0)==69660|(o|0)==69643|(o|0)==86076|(o|0)==8|(o|0)==86052|(o|0)==1330664787)){p=u5a(o)|0;KIb(b,16,2212544,(j=i,i=i+8|0,c[j>>2]=p,j)|0);i=j;k=-1;i=d;return k|0}p=h+12|0;o=c[p>>2]|0;q=l+4|0;if((o|0)<0){r=c[q>>2]|0;if((r|0)<96){s=R$(b,n,-1)|0;c[q>>2]=s;t=s}else{t=r}c[p>>2]=t}else{c[q>>2]=o}o=wKb()|0;c[h+32>>2]=o;c[h+28>>2]=o;c[h+36>>2]=0;o=h+16|0;if((c[o>>2]|0)==0){c[o>>2]=wKb()|0}c[h+76>>2]=1;o=fY()|0;q=h+56|0;c[q>>2]=o;c[q+4>>2]=G;o=b+1144|0;t=c[o>>2]|0;p=c[o+4>>2]|0;if(!((t|0)==0&(p|0)==0)){o=Drc(t,p,1e3,0)|0;r=G;s=wrc(t,p,1220321280,514320)|0;p=xrc(s,G,o,r)|0;c[q>>2]=p;c[q+4>>2]=G}q=h+24|0;p=c[q>>2]|0;do{if((p|0)<0){if((c[(c[m>>2]|0)+88>>2]&8388608|0)==0){c[q>>2]=(wKb()|0)&4095;break}else{c[q>>2]=0;break}}else{c[q>>2]=p&65535}}while(0);p=b+1076|0;q=c[p>>2]|0;r=c[(c[b+16>>2]|0)+60>>2]|0;do{if((q|0)==0){c[p>>2]=r;u=r}else{if((r|0)==0){u=q;break}o=q>>>0>r>>>0?r:q;c[p>>2]=o;u=o}}while(0);if(u>>>0<13>>>0){KIb(b,16,2179808,(j=i,i=i+8|0,c[j>>2]=u,j)|0);i=j;k=-5;i=d;return k|0}q=hJb(u)|0;u=h+80|0;r=u;c[r>>2]=q;if((q|0)==0){k=-12;i=d;return k|0}q=h+40|0;c[q>>2]=(c[p>>2]|0)-12;p=h+88|0;c[p>>2]=0;o=b+1080|0;do{if((c[o>>2]|0)>0){s=c[m>>2]|0;a:do{if((c[s+8>>2]|0)==1){t=B5a(s,0)|0;n=c[m>>2]|0;do{if((t|0)==0){v=c[n+424>>2]|0;if((v|0)!=0){w=v;break}KIb(b,16,2152016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;break a}else{w=t}}while(0);t=c[o>>2]|0;c[e>>2]=1;c[e+4>>2]=1e6;c[f>>2]=w;c[f+4>>2]=c[n+412>>2];v=WIb(t,(t|0)<0|0?-1:0,e,f,2)|0;c[p>>2]=v}}while(0);s=c[m>>2]|0;if((c[s+8>>2]|0)!=0){break}v=c[o>>2]|0;c[g>>2]=1;c[g+4>>2]=1e6;t=XIb(v,(v|0)<0|0?-1:0,g,s+104|0)|0;c[p>>2]=t}}while(0);_X(l,32,1,9e4);g=c[m>>2]|0;m=c[g+48>>2]|0;do{if((m|0)==131072){o=c[q>>2]|0;c[q>>2]=(o|0)<188?188:o-((o|0)%188|0)|0;c[h+84>>2]=c[r>>2];k=0;i=d;return k|0}else if((m|0)==28){if((c[g+100>>2]|0)<=4){k=0;i=d;return k|0}o=c[g+96>>2]|0;if((a[o]|0)!=1){k=0;i=d;return k|0}c[h+92>>2]=(a[o+4|0]&3)+1;k=0;i=d;return k|0}else if((m|0)==86018){x=60}else if((m|0)==86076){o=g+432|0;f=c[o>>2]|0;if(!((f|0)==38|(f|0)==50)){KIb(b,16,2104352,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;x=64;break}e=c[p>>2]|0;if((e|0)==0){c[p>>2]=1;y=1;z=c[o>>2]|0}else{y=e;z=f}f=(c[q>>2]|0)/(z|0)|0;c[p>>2]=(y|0)>(f|0)?f:y}else if((m|0)==73728|(m|0)==73729){f=c[p>>2]|0;if((f|0)==0){c[p>>2]=12;A=12}else{A=f}if((A+1+((m|0)==73728?31:61)|0)>(c[q>>2]|0)){KIb(b,16,2622536,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;x=64;break}if((c[g+416>>2]|0)==1){x=60;break}KIb(b,16,2594784,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;x=64}else if((m|0)==86016|(m|0)==86017){c[h+84>>2]=(c[r>>2]|0)+4;k=0;i=d;return k|0}else if((m|0)==86021|(m|0)==31){f=c[p>>2]|0;if((f|0)==0){c[p>>2]=15;B=15;x=43}else{if((f|0)<1){C=1}else{B=f;x=43}}if((x|0)==43){C=(B|0)>15?15:B}c[p>>2]=C;c[q>>2]=(c[q>>2]|0)-6;c[h+44>>2]=0}else if((m|0)==69660){_X(l,32,1,8e3);k=0;i=d;return k|0}else if((m|0)==1330664787){if((c[g+416>>2]|0)>2){KIb(b,16,2127440,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;x=64;break}_X(l,32,1,48e3);k=0;i=d;return k|0}else if((m|0)==1|(m|0)==2){k=0;i=d;return k|0}}while(0);if((x|0)==60){c[h+44>>2]=0}else if((x|0)==64){mJb(u);k=-22;i=d;return k|0}if((c[g+8>>2]|0)==1){_X(l,32,1,c[g+412>>2]|0)}c[h+84>>2]=c[r>>2];k=0;i=d;return k|0}function HT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+8|0;f=e|0;g=b+12|0;h=c[g>>2]|0;j=b+28|0;k=c[c[j>>2]>>2]|0;l=c[d+28>>2]|0;m=h+68|0;n=h+72|0;o=h+76|0;do{if((c[o>>2]|0)==0){if(!((((c[m>>2]|0)-(c[n>>2]|0)|0)*5|0)>>>0>27999>>>0)){break}p=fY()|0;q=h+48|0;r=xrc(p,G,c[q>>2]|0,c[q+4>>2]|0)|0;q=G;p=0;if(q>>>0>p>>>0|q>>>0==p>>>0&r>>>0>5e6>>>0){s=4}}else{s=4}}while(0);do{if((s|0)==4){if((c[h+96>>2]&4|0)!=0){break}r=fY()|0;JT(b,r,G,0);c[n>>2]=c[m>>2];c[o>>2]=0}}while(0);o=d+8|0;m=wrc(c[h+32>>2]|0,0,c[o>>2]|0,c[o+4>>2]|0)|0;c[h+36>>2]=m;m=c[k+8>>2]|0;k=c[m+48>>2]|0;do{if((k|0)==69660){t=KT(b,c[d+24>>2]|0,l,c[m+416>>2]<<3)|0;i=e;return t|0}else if((k|0)==1330664787){o=c[h+40>>2]|0;if((l|0)<=(o|0)){break}KIb(b,16,2310168,(u=i,i=i+16|0,c[u>>2]=l,c[u+8>>2]=o,u)|0);i=u;t=-22;i=e;return t|0}else if((k|0)==86016|(k|0)==86017){o=c[d+24>>2]|0;n=c[g>>2]|0;r=c[n+40>>2]|0;p=n+84|0;q=c[p>>2]|0;v=n+80|0;w=c[v>>2]|0;x=q-w|0;if((x+l|0)>(r|0)&(x|0)>4){y=b+16|0;bD(c[y>>2]|0,128);bD(c[y>>2]|0,c[n+12>>2]&127);z=n+24|0;tD(c[y>>2]|0,c[z>>2]|0);lD(c[y>>2]|0,c[n+28>>2]|0);lD(c[y>>2]|0,c[n+16>>2]|0);dD(c[y>>2]|0,w,x);eD(c[y>>2]|0);c[z>>2]=(c[z>>2]|0)+1&65535;z=n+68|0;c[z>>2]=(c[z>>2]|0)+x;x=n+64|0;c[x>>2]=(c[x>>2]|0)+1;x=c[v>>2]|0;z=x+4|0;c[p>>2]=z;A=z;B=x}else{A=q;B=w}w=(A|0)==(B+4|0);if(w){c[n+28>>2]=c[n+36>>2]}if((r|0)>=(l|0)){if(w){a[B]=0;a[(c[v>>2]|0)+1|0]=0;a[(c[v>>2]|0)+2|0]=0;a[(c[v>>2]|0)+3|0]=0;C=c[p>>2]|0}else{C=A}nrc(C|0,o|0,l)|0;c[p>>2]=(c[p>>2]|0)+l;t=0;i=e;return t|0}if((l|0)<=0){t=0;i=e;return t|0}p=r-4|0;r=b+16|0;w=l;n=0;q=o;o=B;while(1){x=(p|0)>(w|0)?w:p;a[o]=0;a[(c[v>>2]|0)+1|0]=0;a[(c[v>>2]|0)+2|0]=n>>>8;a[(c[v>>2]|0)+3|0]=n;nrc((c[v>>2]|0)+4|0,q|0,x)|0;z=c[v>>2]|0;y=x+4|0;D=c[g>>2]|0;bD(c[r>>2]|0,128);bD(c[r>>2]|0,c[D+12>>2]&127);E=D+24|0;tD(c[r>>2]|0,c[E>>2]|0);lD(c[r>>2]|0,c[D+28>>2]|0);lD(c[r>>2]|0,c[D+16>>2]|0);dD(c[r>>2]|0,z,y);eD(c[r>>2]|0);c[E>>2]=(c[E>>2]|0)+1&65535;E=D+68|0;c[E>>2]=(c[E>>2]|0)+y;y=D+64|0;c[y>>2]=(c[y>>2]|0)+1;y=w-x|0;if((y|0)<=0){t=0;break}w=y;n=x+n|0;q=q+x|0;o=c[v>>2]|0}i=e;return t|0}else if((k|0)==65539|(k|0)==65538|(k|0)==65537|(k|0)==65536){t=KT(b,c[d+24>>2]|0,l,c[m+416>>2]<<4)|0;i=e;return t|0}else if((k|0)==131072){v=c[g>>2]|0;if((l|0)<=187){t=0;i=e;return t|0}o=v+40|0;q=v+84|0;n=v+80|0;v=b+16|0;w=l;r=c[d+24>>2]|0;p=c[q>>2]|0;x=c[n>>2]|0;while(1){y=(c[o>>2]|0)+(x-p)|0;D=(y|0)>(w|0)?w:y;nrc(p|0,r|0,D)|0;y=w-D|0;E=(c[q>>2]|0)+D|0;c[q>>2]=E;z=c[n>>2]|0;F=E-z|0;if((F|0)<(c[o>>2]|0)){H=E;I=z}else{E=c[g>>2]|0;bD(c[v>>2]|0,128);bD(c[v>>2]|0,c[E+12>>2]&127);J=E+24|0;tD(c[v>>2]|0,c[J>>2]|0);lD(c[v>>2]|0,c[E+28>>2]|0);lD(c[v>>2]|0,c[E+16>>2]|0);dD(c[v>>2]|0,z,F);eD(c[v>>2]|0);c[J>>2]=(c[J>>2]|0)+1&65535;J=E+68|0;c[J>>2]=(c[J>>2]|0)+F;F=E+64|0;c[F>>2]=(c[F>>2]|0)+1;F=c[n>>2]|0;c[q>>2]=F;H=F;I=F}if((y|0)>187){w=y;r=r+D|0;p=H;x=I}else{t=0;break}}i=e;return t|0}else if((k|0)==1|(k|0)==2){UT(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==28){RT(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==8){ST(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==73728|(k|0)==73729){MT(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==65542|(k|0)==65543|(k|0)==65541|(k|0)==65540){t=KT(b,c[d+24>>2]|0,l,c[m+416>>2]<<3)|0;i=e;return t|0}else if((k|0)==141){VT(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==86076){x=c[d+24>>2]|0;p=c[g>>2]|0;r=(c[c[j>>2]>>2]|0)+8|0;w=B5a(c[r>>2]|0,0)|0;q=c[(c[r>>2]|0)+432>>2]|0;r=(l|0)/(q|0)|0;if((r|0)<=0){t=0;i=e;return t|0}n=p+88|0;v=p+44|0;o=p+80|0;D=p+84|0;y=p+36|0;F=p+28|0;p=b+16|0;E=r;r=x;x=c[v>>2]|0;while(1){J=(c[n>>2]|0)-x|0;z=(J|0)>(E|0)?E:J;if((x|0)==0){J=c[o>>2]|0;c[D>>2]=J;c[F>>2]=c[y>>2];K=J}else{K=c[D>>2]|0}J=ca(z,q)|0;nrc(K|0,r|0,J)|0;L=E-z|0;M=(c[v>>2]|0)+z|0;c[v>>2]=M;N=(c[D>>2]|0)+J|0;c[D>>2]=N;O=ca(z,w)|0;c[y>>2]=(c[y>>2]|0)+O;if((M|0)==(c[n>>2]|0)){O=c[o>>2]|0;z=N-O|0;N=c[g>>2]|0;bD(c[p>>2]|0,128);bD(c[p>>2]|0,c[N+12>>2]&127|128);P=N+24|0;tD(c[p>>2]|0,c[P>>2]|0);lD(c[p>>2]|0,c[N+28>>2]|0);lD(c[p>>2]|0,c[N+16>>2]|0);dD(c[p>>2]|0,O,z);eD(c[p>>2]|0);c[P>>2]=(c[P>>2]|0)+1&65535;P=N+68|0;c[P>>2]=(c[P>>2]|0)+z;z=N+64|0;c[z>>2]=(c[z>>2]|0)+1;c[v>>2]=0;Q=0}else{Q=M}if((L|0)>0){E=L;r=r+J|0;x=Q}else{t=0;break}}i=e;return t|0}else if((k|0)==86018){x=c[d+24>>2]|0;if((c[h+96>>2]&1|0)==0){LT(b,x,l);t=0;i=e;return t|0}else{TT(b,x,l);t=0;i=e;return t|0}}else if((k|0)==20){s=38}else if((k|0)==86021|(k|0)==31){WT(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}else if((k|0)==69643){t=KT(b,c[d+24>>2]|0,l,ca(c[m+416>>2]|0,c[m+792>>2]|0)|0)|0;i=e;return t|0}else if((k|0)==5){if((c[h+96>>2]&2|0)==0){s=38;break}c[f>>2]=0;x=V1(d,3,f)|0;if((x|0)==0){KIb(b,16,2378384,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;t=-12;i=e;return t|0}else{QT(b,c[d+24>>2]|0,l,x,c[f>>2]|0);t=0;i=e;return t|0}}}while(0);if((s|0)==38){PT(b,c[d+24>>2]|0,l);t=0;i=e;return t|0}s=c[g>>2]|0;f=c[s+40>>2]|0;if((l|0)<=0){t=0;i=e;return t|0}u=s+36|0;h=s+28|0;k=b+16|0;b=l;l=c[d+24>>2]|0;d=s;while(1){s=(f|0)>(b|0)?b:f;c[h>>2]=c[u>>2];bD(c[k>>2]|0,128);bD(c[k>>2]|0,c[d+12>>2]&127|((s|0)==(b|0))<<7);m=d+24|0;tD(c[k>>2]|0,c[m>>2]|0);lD(c[k>>2]|0,c[d+28>>2]|0);lD(c[k>>2]|0,c[d+16>>2]|0);dD(c[k>>2]|0,l,s);eD(c[k>>2]|0);c[m>>2]=(c[m>>2]|0)+1&65535;m=d+68|0;c[m>>2]=(c[m>>2]|0)+s;m=d+64|0;c[m>>2]=(c[m>>2]|0)+1;m=b-s|0;if((m|0)<=0){t=0;break}b=m;l=l+s|0;d=c[g>>2]|0}i=e;return t|0}function IT(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;do{if((c[a+16>>2]|0)!=0){if((c[b+96>>2]&16|0)==0){break}d=fY()|0;JT(a,d,G,1)}}while(0);mJb(b+80|0);return 0}function JT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+8|0;g=f|0;h=c[a+12>>2]|0;j=h+48|0;c[j>>2]=b;c[j+4>>2]=d;j=h+56|0;k=xrc(b,d,c[j>>2]|0,c[j+4>>2]|0)|0;c[g>>2]=1;c[g+4>>2]=1e6;j=XIb(k,G,g,(c[c[a+28>>2]>>2]|0)+40|0)|0;g=wrc(c[h+32>>2]|0,0,j,G)|0;j=a+16|0;bD(c[j>>2]|0,128);bD(c[j>>2]|0,200);tD(c[j>>2]|0,6);a=h+16|0;lD(c[j>>2]|0,c[a>>2]|0);k=c[j>>2]|0;l=VIb(b,d,0,1,1e6,0)|0;sD(k,l,G);lD(c[j>>2]|0,g);lD(c[j>>2]|0,c[h+64>>2]|0);lD(c[j>>2]|0,c[h+68>>2]|0);g=h+20|0;h=c[g>>2]|0;do{if((h|0)!=0){l=lrc(h|0)|0;k=l>>>0>255>>>0?255:l;bD(c[j>>2]|0,129);bD(c[j>>2]|0,202);tD(c[j>>2]|0,(k+10|0)/4|0);lD(c[j>>2]|0,c[a>>2]|0);bD(c[j>>2]|0,1);bD(c[j>>2]|0,k);dD(c[j>>2]|0,c[g>>2]|0,k);bD(c[j>>2]|0,0);l=(k+7|0)%4|0;if((l&3|0)==0){break}else{m=l}do{bD(c[j>>2]|0,0);m=m+1|0;}while((m&3|0)!=0)}}while(0);if((e|0)==0){n=c[j>>2]|0;eD(n);i=f;return}bD(c[j>>2]|0,129);bD(c[j>>2]|0,203);tD(c[j>>2]|0,1);lD(c[j>>2]|0,c[a>>2]|0);n=c[j>>2]|0;eD(n);i=f;return}function KT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=a+12|0;g=c[f>>2]|0;h=e;i=(e|0)<0|0?-1:0;j=TIb(h,i,8,0)|0;k=Crc(h,i,j,G)|0;j=c[g+40>>2]|0;i=j-((j|0)%(k|0)|0)|0;do{if((e&7|0)==0){if(((d<<3|0)%(e|0)|0|0)==0){break}else{l=-22}return l|0}}while(0);if((d|0)<=0){l=0;return l|0}k=g+80|0;j=g+84|0;h=g+36|0;m=g+28|0;g=a+16|0;a=d;d=b;b=0;n=c[k>>2]|0;while(1){c[j>>2]=n;o=(i|0)>(a|0)?a:i;nrc(n|0,d|0,o)|0;p=(c[j>>2]|0)+o|0;c[j>>2]=p;q=a-o|0;c[m>>2]=((b<<3|0)/(e|0)|0)+(c[h>>2]|0);r=c[k>>2]|0;s=p-r|0;p=c[f>>2]|0;bD(c[g>>2]|0,128);bD(c[g>>2]|0,c[p+12>>2]&127);t=p+24|0;tD(c[g>>2]|0,c[t>>2]|0);lD(c[g>>2]|0,c[p+28>>2]|0);lD(c[g>>2]|0,c[p+16>>2]|0);dD(c[g>>2]|0,r,s);eD(c[g>>2]|0);c[t>>2]=(c[t>>2]|0)+1&65535;t=p+68|0;c[t>>2]=(c[t>>2]|0)+s;s=p+64|0;c[s>>2]=(c[s>>2]|0)+1;s=c[k>>2]|0;if((q|0)>0){a=q;d=d+o|0;b=(c[j>>2]|0)+b-s|0;n=s}else{l=0;break}}return l|0}function LT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[b+12>>2]|0;g=c[f+88>>2]|0;h=(g|0)==0?5:g;g=(h<<1)+2|0;if((c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+100>>2]|0)==0){i=d+7|0;j=e-7|0}else{i=d;j=e}e=f+40|0;d=c[e>>2]|0;k=d-g|0;l=f+84|0;m=c[l>>2]|0;n=f+80|0;o=c[n>>2]|0;p=m;q=o;r=f+44|0;s=c[r>>2]|0;do{if((s|0)==(h|0)){t=6}else{if((m|0)!=(o|0)){if((p+j-q|0)>(d|0)){t=6;break}}if((s|0)==0){u=o;t=10}else{v=o;w=s}}}while(0);if((t|0)==6){d=s<<1;q=g-d|0;p=q-2|0;m=o+p|0;if((p|0)!=0){orc(o+q|0,o+2|0,d|0)|0}a[m]=s>>>4;a[o+(q-1)|0]=s<<4;FT(b,m,(c[l>>2]|0)-m|0,1);c[r>>2]=0;u=c[n>>2]|0;t=10}if((t|0)==10){c[l>>2]=u+g;c[f+28>>2]=c[f+36>>2];v=u;w=0}if((j|0)<=(k|0)){c[r>>2]=w+1;r=w<<1;a[v+(r+2)|0]=j>>>5;a[v+(r+3)|0]=j<<3;nrc(c[l>>2]|0,i|0,j)|0;c[l>>2]=(c[l>>2]|0)+j;return}l=(c[e>>2]|0)-4|0;a[v]=0;a[v+1|0]=16;if((j|0)<=0){return}e=j>>>5&255;r=v+2|0;w=j<<3&255;k=v+3|0;u=v+4|0;f=j;j=i;while(1){i=(f|0)>(l|0)?l:f;a[r]=e;a[k]=w;nrc(u|0,j|0,i)|0;FT(b,v,i+4|0,(i|0)==(f|0)|0);g=f-i|0;if((g|0)>0){f=g;j=j+i|0}else{break}}return}function MT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[b+12>>2]|0;g=c[f+88>>2]|0;h=g+1|0;i=f+84|0;j=c[i>>2]|0;k=f+80|0;l=c[k>>2]|0;m=j;n=l;o=f+44|0;p=c[o>>2]|0;do{if((p|0)==(g|0)){q=4}else{if((j|0)!=(l|0)){if((e-1+m-n|0)>(c[f+40>>2]|0)){q=4;break}}if((p|0)==0){r=l;q=8;break}s=l+p|0;a[s]=a[s]|-128;t=c[k>>2]|0}}while(0);if((q|0)==4){n=h+~p|0;m=l+n|0;if((n|0)==0){u=j}else{orc(m|0,l|0,p+1|0)|0;u=c[i>>2]|0}FT(b,m,u-m|0,1);c[o>>2]=0;r=c[k>>2]|0;q=8}if((q|0)==8){a[r]=-16;r=c[k>>2]|0;c[i>>2]=r+h;c[f+28>>2]=c[f+36>>2];t=r}r=a[d]&124;f=(c[o>>2]|0)+1|0;c[o>>2]=f;a[t+f|0]=r;r=e-1|0;nrc(c[i>>2]|0,d+1|0,r)|0;c[i>>2]=(c[i>>2]|0)+r;return}function NT(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=gH(2108352,0,0)|0;c[k>>2]=0;do{if((m|0)==0){n=-38;o=0}else{p=HR()|0;if((p|0)==0){n=-12;o=0;break}c[p+8>>2]=m;if((ZX(p,0)|0)==0){n=-12;o=p;break}q=b+1160|0;r=p+1160|0;s=c[q+4>>2]|0;c[r>>2]=c[q>>2];c[r+4>>2]=s;c[p+1080>>2]=c[b+1080>>2];s=p+28|0;r=d+80|0;q=(c[c[s>>2]>>2]|0)+80|0;t=c[r+4>>2]|0;c[q>>2]=c[r>>2];c[q+4>>2]=t;t=p+1084|0;c[t>>2]=c[t>>2]|c[b+1084>>2]&32768;t=c[d+4>>2]|0;if((t|0)<96){q=R$(b,c[d+8>>2]|0,g)|0;c[(c[c[s>>2]>>2]|0)+4>>2]=q}else{c[(c[c[s>>2]>>2]|0)+4>>2]=t}if((MJb(b,2472304,1,j)|0)>-1){MGb(k,2472304,c[j>>2]|0,8)|0}t=b+1144|0;q=c[t+4>>2]|0;r=p+1144|0;c[r>>2]=c[t>>2];c[r+4>>2]=q;nWa(c[(c[c[s>>2]>>2]|0)+8>>2]|0,c[d+8>>2]|0)|0;s=(e|0)!=0;q=p+16|0;do{if(s){r=QD(q,e)|0;if((r|0)>=0){u=r;v=13;break}SC(e)|0;w=r;v=14}else{u=$D(q,f)|0;v=13}}while(0);do{if((v|0)==13){if((u|0)!=0){w=u;v=14;break}r=TO(p,k)|0;OGb(k);if((r|0)!=0){x=r;break}c[a>>2]=p;y=0;i=h;return y|0}}while(0);if((v|0)==14){OGb(k);x=w}r=c[q>>2]|0;t=(r|0)==0;do{if(s){if(t){break}WD(r)|0}else{if(t){break}aE(r,l)|0;kJb(c[l>>2]|0)}}while(0);pX(p);y=x;i=h;return y|0}}while(0);kJb(o);if((e|0)==0){y=n;i=h;return y|0}SC(e)|0;y=n;i=h;return y|0}function OT(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=c-1|0;e=b+1|0;if(d>>>0>e>>>0){f=d}else{g=c;return g|0}while(1){if((a[f]|0)==0){d=(a[f+1|0]|0)==0;if(d){if((a[f+2|0]|0)!=0){g=f;h=7;break}}b=f-1|0;if(!((a[b]|0)!=0|d)){g=b;h=7;break}}b=f-2|0;if(b>>>0>e>>>0){f=b}else{g=c;h=7;break}}if((h|0)==7){return g|0}return 0}function PT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[b+12>>2]|0;if((e|0)<=0){return}g=f+80|0;h=(c[f+40>>2]|0)-2|0;i=f+36|0;j=f+28|0;f=e;e=d;while(1){d=c[g>>2]|0;do{if((f|0)>1){if((a[e]|0)!=0){k=7;break}if((a[e+1|0]|0)!=0){k=7;break}a[d]=4;l=e+2|0;m=f-2|0}else{k=7}}while(0);if((k|0)==7){k=0;a[d]=0;l=e;m=f}n=d+2|0;a[d+1|0]=0;o=(h|0)>(m|0)?m:h;if((o|0)<(m|0)){p=l+o|0;q=o-1|0;r=l+1|0;a:do{if((q|0)>1){s=l+q|0;while(1){do{if((a[s]|0)==0){if((a[s+1|0]|0)==0){if((a[s+2|0]|0)==0){break}else{t=s;break a}}else{u=s-1|0;if((a[u]|0)==0){t=u;break a}else{break}}}}while(0);u=s-2|0;if(u>>>0>r>>>0){s=u}else{t=p;break}}}else{t=p}}while(0);v=t-l|0}else{v=o}nrc(n|0,l|0,v)|0;c[j>>2]=c[i>>2];p=c[g>>2]|0;FT(b,p,d+(v+2)-p|0,(v|0)==(m|0)|0);p=m-v|0;if((p|0)>0){f=p;e=l+v|0}else{break}}return}function QT(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;j=i;k=b+12|0;l=c[k>>2]|0;m=(h|0)/12|0;c[l+28>>2]=c[l+36>>2];h=f<<3;n=h>>>0>2147483639>>>0|(e|0)==0;o=n?0:e;p=n?8:h+8|0;h=o;n=je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;h=p>>>0>22>>>0?22:p;if((n&-1024|0)==32768){n=o+(h>>>3)|0;q=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&6)>>>24;n=h+8|0;h=(p>>>0>n>>>0?n:p)+2|0;n=(p>>>0>h>>>0?h:p)+3|0;h=p>>>0>n>>>0?n:p;n=o+(h>>>3)|0;r=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>29;n=h+3|0;h=p>>>0>n>>>0?n:p;n=o+(h>>>3)|0;s=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>31;n=h+1|0;h=p>>>0>n>>>0?n:p;n=o+(h>>>3)|0;t=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>31;n=h+1|0;h=p>>>0>n>>>0?n:p;n=o+(h>>>3)|0;u=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>31;n=h+1|0;h=p>>>0>n>>>0?n:p;p=o+(h>>>3)|0;v=r;w=s;x=t;z=u;A=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(h&7)>>>31;B=q}else{v=0;w=0;x=0;z=0;A=0;B=0}if((f|0)<=0){i=j;return}q=l+40|0;l=e;h=b;p=(((w<<1|x)<<1|z)<<1|A)<<7;u=0;t=0;s=0;r=0;o=0;n=0;C=0;D=0;E=0;F=f;f=e;while(1){e=(c[q>>2]|0)-8|0;G=(e|0)>(F|0)?F:e;do{if((G|0)<(F|0)){e=OT(f,f+G|0)|0;H=f;I=e-H|0;if((I|0)!=((c[q>>2]|0)-8|0)){J=I;K=0;L=D;M=C;N=n;O=o;P=r;Q=s;R=t;S=u;break}T=H-l|0;U=o;while(1){if((U|0)>=(m|0)){break}V=g+(U*12|0)|0;if((d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>3>>>0<T>>>0){U=U+1|0}else{break}}T=e-l|0;V=U;while(1){W=V+1|0;if((W|0)>=(m|0)){break}X=g+(W*12|0)|0;if((d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)>>>3>>>0<T>>>0){V=W}else{break}}if((V|0)>=(m|0)){KIb(h,16,2472232,(Y=i,i=i+8|0,c[Y>>2]=I,Y)|0);i=Y;J=I;K=0;L=D;M=C;N=n;O=V;P=r;Q=s;R=t;S=u;break}U=V*12|0;e=g+U|0;X=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=(X+7|0)>>>3;if(e>>>0>T>>>0){KIb(h,16,2108248,(Y=i,i=i+8|0,c[Y>>2]=I,Y)|0);i=Y;J=I;K=0;L=D;M=C;N=n;O=V;P=r;Q=s;R=t;S=u;break}else{Z=g+(U+6)|0;J=l-H+e|0;K=(e<<3)-X|0;L=d[g+(U+4)|0]|0;M=a[g+(U+11)|0]|0;N=a[g+(U+10)|0]|0;O=W;P=d[g+(U+5)|0]|0;Q=(d[Z]|d[Z+1|0]<<8)<<16>>16&65535;R=a[g+(U+8)|0]|0;S=a[g+(U+9)|0]|0;break}}else{J=G;K=0;L=D;M=C;N=n;O=o;P=r;Q=s;R=t;S=u}}while(0);do{if((F|0)>2){if((a[f]|0)!=0){_=22;break}if((a[f+1|0]|0)!=0){_=22;break}G=(c[k>>2]|0)+80|0;U=c[G>>2]|0;Z=U;y=je((((((K<<3|v)<<1|w)<<1|x)<<1|z)<<1|A)<<17|B|0)|0;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;nrc((c[G>>2]|0)+4|0,f|0,J)|0;FT(b,c[G>>2]|0,J+4|0,(J|0)==(F|0)|0)}else{_=22}}while(0);if((_|0)==22){_=0;G=(c[k>>2]|0)+80|0;Z=c[G>>2]|0;U=Z;y=je(((((v|(K|E<<3)<<3)<<5|D)<<5|r)<<9|s)<<2|-2147483648|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=Z+4|0;y=je((((p|t)<<7|u)<<7|n)<<7|C|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;nrc((c[G>>2]|0)+8|0,f|0,J)|0;FT(b,c[G>>2]|0,J+8|0,(J|0)==(F|0)|0)}if((K|0)==0){$=J;aa=0}else{$=J-1|0;aa=8-K|0}G=F-$|0;if((G|0)>0){u=S;t=R;s=Q;r=P;o=O;n=N;C=M;D=L;E=aa;F=G;f=f+$|0}else{break}}i=j;return}function RT(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;h=e+f|0;j=b+12|0;k=c[j>>2]|0;c[k+28>>2]=c[k+36>>2];l=k+92|0;k=c[l>>2]|0;do{if((k|0)==0){m=n$(e,h)|0}else{n=h;if((k|0)>(f|0)){i=g;return}else{o=e;p=k;q=0}while(1){r=p-1|0;s=d[o]|q<<8;if((r|0)==0){break}else{o=o+1|0;p=r;q=s}}if(s>>>0>(n-(e+k)|0)>>>0){i=g;return}else{m=(e+(s+k)|0)!=0?e:h;break}}}while(0);if(!(m>>>0<h>>>0)){i=g;return}e=b;k=h;s=m;while(1){m=c[l>>2]|0;if((m|0)==0){q=s;while(1){t=q+1|0;if((a[q]|0)==0){q=t}else{break}}u=n$(t,h)|0;v=t}else{do{if((k-s|0)<(m|0)){w=0;x=s+m|0}else{q=s;n=m;p=0;while(1){o=n-1|0;y=d[q]|p<<8;if((o|0)==0){break}else{q=q+1|0;n=o;p=y}}p=s+m|0;if(y>>>0>(k-p|0)>>>0){w=0;x=p;break}w=s+(y+m)|0;x=p}}while(0);u=(w|0)==0?h:w;v=x}m=u-v|0;p=(u|0)==(h|0)|0;n=c[j>>2]|0;KIb(e,48,2108152,(q=i,i=i+24|0,c[q>>2]=a[v]&31,c[q+8>>2]=m,c[q+16>>2]=p,q)|0);i=q;o=n+40|0;f=c[o>>2]|0;do{if((f|0)<(m|0)){r=a[v]|0;if((c[n+96>>2]&8|0)!=0){KIb(e,16,2472176,(q=i,i=i+24|0,c[q>>2]=m,c[q+8>>2]=f,c[q+16>>2]=f,q)|0);i=q;break}KIb(e,48,2378200,(q=i,i=i+16|0,c[q>>2]=m,c[q+8>>2]=f,q)|0);i=q;z=n+80|0;a[c[z>>2]|0]=28;A=c[z>>2]|0;a[A]=a[A]|r&96;a[(c[z>>2]|0)+1|0]=r&31;r=(c[z>>2]|0)+1|0;a[r]=a[r]|-128;r=v+1|0;A=m-1|0;B=m+1|0;C=c[o>>2]|0;D=c[z>>2]|0;if((B|0)>(C|0)){E=A;F=r;G=C;C=D;while(1){nrc(C+2|0,F|0,G-2|0)|0;FT(b,c[z>>2]|0,c[o>>2]|0,0);H=(c[o>>2]|0)-2|0;I=F+H|0;J=E-H|0;H=(c[z>>2]|0)+1|0;a[H]=a[H]&127;H=J+2|0;K=c[o>>2]|0;L=c[z>>2]|0;if((H|0)>(K|0)){E=J;F=I;G=K;C=L}else{M=J;N=I;O=H;P=L;break}}}else{M=A;N=r;O=B;P=D}C=P+1|0;a[C]=a[C]|64;nrc((c[z>>2]|0)+2|0,N|0,M)|0;FT(b,c[z>>2]|0,O,p)}else{FT(b,v,m,p)}}while(0);if(u>>>0<h>>>0){s=u}else{break}}i=g;return}function ST(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;h=c[b+12>>2]|0;j=h+80|0;k=h+84|0;c[k>>2]=c[j>>2];c[h+28>>2]=c[h+36>>2];l=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;m=(c[l+120>>2]|0)>>>3;n=(c[l+124>>2]|0)>>>3;o=c[l+140>>2]|0;if((o|0)==13){p=0}else if((o|0)==12){p=1}else{KIb(b,16,2108120,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;i=g;return}a:do{if((f|0)>0){o=b;l=0;r=0;s=0;b:while(1){t=s+1|0;do{if((a[e+s|0]|0)==-1){u=a[e+t|0]|0;if((u<<24>>24|0)==(-64|0)){if((a[e+(s+14)|0]|0)!=17){v=14;break b}if((a[e+(s+17)|0]|0)==17){w=r;x=l;break}else{v=14;break b}}else if((u<<24>>24|0)==(-38|0)){v=15;break b}else if((u<<24>>24|0)!=(-37|0)){w=r;x=l;break}u=s+4|0;z=e+u|0;if((a[z]|0)!=0){KIb(o,24,2472120,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}A=e+(s+2)|0;B=(((he((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535)/65|0)&65535;if(((B*65|0)+u|0)>(f|0)){v=11;break b}else{w=z;x=B}}else{w=r;x=l}}while(0);if((t|0)<(f|0)){l=x;r=w;s=t}else{C=t;D=x;E=w;break a}}if((v|0)==11){KIb(o,16,2378160,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;i=g;return}else if((v|0)==14){KIb(o,16,2310080,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;i=g;return}else if((v|0)==15){B=s+2|0;z=e+B|0;C=B+((he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)|0;D=l;E=r;break}}else{C=0;D=0;E=0}}while(0);v=e+C|0;q=f-C|0;f=q-2|0;w=C+1|0;c:do{if((f|0)>-1){x=f;while(1){if((a[e+(x+C)|0]|0)==-1){if((a[e+(w+x)|0]|0)==-39){F=x;break c}}if((x|0)>0){x=x-1|0}else{F=q;break}}}else{F=q}}while(0);q=c[k>>2]|0;if((F|0)<=0){i=g;return}k=h+40|0;h=m&255;m=n&255;n=D<<6;w=he(n&65535|0)|0;e=n|12;if((D|0)==0){n=F;C=0;f=v;x=q;while(1){r=(c[k>>2]|0)-8|0;l=(n|0)>(r|0)?r:n;a[x]=0;a[x+3|0]=C;a[x+2|0]=C>>>8;a[x+1|0]=C>>>16;a[x+4|0]=p;a[x+5|0]=-1;a[x+6|0]=h;a[x+7|0]=m;nrc(x+8|0,f|0,l)|0;FT(b,c[j>>2]|0,l+8|0,(n|0)==(l|0)|0);r=n-l|0;if((r|0)>0){n=r;C=l+C|0;f=f+l|0;x=c[j>>2]|0}else{break}}i=g;return}if((D|0)<=0){x=F;f=0;C=v;n=q;while(1){l=(f|0)!=0;r=l?8:e;s=(c[k>>2]|0)-r|0;o=(x|0)>(s|0)?s:x;a[n]=0;a[n+3|0]=f;a[n+2|0]=f>>>8;a[n+1|0]=f>>>16;a[n+4|0]=p;a[n+5|0]=-1;a[n+6|0]=h;a[n+7|0]=m;s=n+8|0;if(l){G=s}else{a[s]=0;a[n+9|0]=0;s=n+10|0;y=w;a[s]=y;y=y>>8;a[s+1|0]=y;G=n+12|0}nrc(G|0,C|0,o)|0;FT(b,c[j>>2]|0,o+r|0,(x|0)==(o|0)|0);r=x-o|0;if((r|0)>0){x=r;f=o+f|0;C=C+o|0;n=c[j>>2]|0}else{break}}i=g;return}n=D<<6|12;C=F;F=0;f=v;v=q;while(1){q=(F|0)!=0;x=q?8:e;G=(c[k>>2]|0)-x|0;o=(C|0)>(G|0)?G:C;a[v]=0;a[v+3|0]=F;a[v+2|0]=F>>>8;a[v+1|0]=F>>>16;a[v+4|0]=p;a[v+5|0]=-1;a[v+6|0]=h;a[v+7|0]=m;G=v+8|0;if(q){H=G}else{a[G]=0;a[v+9|0]=0;G=v+10|0;y=w;a[G]=y;y=y>>8;a[G+1|0]=y;G=v+12|0;q=0;while(1){nrc(G|0,E+((q*65|0)+1)|0,64)|0;r=q+1|0;if((r|0)<(D|0)){G=G+64|0;q=r}else{break}}H=v+n|0}nrc(H|0,f|0,o)|0;FT(b,c[j>>2]|0,o+x|0,(C|0)==(o|0)|0);q=C-o|0;if((q|0)>0){C=q;F=o+F|0;f=f+o|0;v=c[j>>2]|0}else{break}}i=g;return}function TT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[b+12>>2]|0;if((c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+100>>2]|0)==0){g=d+7|0;h=e-7|0}else{g=d;h=e}e=(h|0)/255|0;d=e+1|0;i=f+80|0;mrc(c[i>>2]|0,-1|0,e|0)|0;a[(c[i>>2]|0)+e|0]=(h|0)%255|0;c[f+28>>2]=c[f+36>>2];if((h|0)<=0){return}e=f+40|0;f=h;h=0;while(1){j=(h|0)!=0;k=(c[e>>2]|0)-(j?0:d)|0;l=(f|0)>(k|0)?k:f;k=f-l|0;if(j){FT(b,g+h|0,l,(f|0)==(l|0)|0)}else{nrc((c[i>>2]|0)+d|0,g|0,l)|0;FT(b,c[i>>2]|0,l+d|0,(f|0)==(l|0)|0)}if((k|0)>0){f=k;h=l+h|0}else{break}}return}function UT(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;i=i+8|0;h=g|0;j=c[b+12>>2]|0;k=e+f|0;l=c[j+40>>2]|0;if((f|0)<=0){i=g;return}m=l-4|0;n=j+80|0;o=j+36|0;p=j+28|0;j=f;f=1;q=0;r=0;s=e;while(1){a:do{if((m|0)<(j|0)){e=s;if((f|0)==0){c[h>>2]=-1;t=U5a(s,k,h)|0;u=c[h>>2]|0;if((u&-256|0)!=256){v=0;w=r;x=q;y=0;z=m;break}if((u|0)==256){A=d[t+1|0]|0;B=(d[t]|0)<<2|A>>>6;C=A>>>3&7}else{B=r;C=q}A=(u|0)==440|0;u=t;t=u-e-4|0;if((t|0)>(m|0)){D=s;E=C;F=B;G=A;H=u}else{v=A;w=B;x=C;y=1;z=t;break}}else{t=s;A=0;u=r;I=q;while(1){c[h>>2]=-1;J=U5a(t,k,h)|0;K=c[h>>2]|0;if((K&-256|0)!=256){v=A;w=u;x=I;y=0;z=m;break a}if((K|0)==256){L=d[J+1|0]|0;M=(d[J]|0)<<2|L>>>6;N=L>>>3&7}else{M=u;N=I}L=(K|0)==440?1:A;K=J;if((K-e-4|0)>(m|0)){D=t;E=N;F=M;G=L;H=K;break}else{t=J;A=L;u=M;I=N}}}I=D;u=I-e|0;if((u|0)<=4){v=G;w=F;x=E;y=0;z=m;break}A=(H-I|0)<(l|0);v=G;w=F;x=E;y=A&1;z=A?u-4|0:m}else{v=0;w=r;x=q;y=1;z=j}}while(0);u=y<<11|f<<12|x<<8|w<<16|v<<13;A=c[n>>2]|0;a[A]=u>>>24;a[A+1|0]=u>>>16;a[A+2|0]=u>>>8;a[A+3|0]=0;nrc(A+4|0,s|0,z)|0;c[p>>2]=c[o>>2];u=c[n>>2]|0;FT(b,u,A+(z+4)-u|0,(z|0)==(j|0)|0);u=j-z|0;if((u|0)>0){j=u;f=y;q=x;r=w;s=s+z|0}else{break}}i=g;return}function VT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[b+12>>2]|0;g=f+80|0;h=c[g>>2]|0;i=f+84|0;c[f+28>>2]=c[f+36>>2];c[i>>2]=h+1;a[h]=-112;h=c[i>>2]|0;c[i>>2]=h+1;a[h]=-128;h=f+100|0;j=c[h>>2]|0;c[h>>2]=j+1;h=c[i>>2]|0;c[i>>2]=h+1;a[h]=j&127;j=c[i>>2]|0;h=j-(c[g>>2]|0)|0;k=(c[f+40>>2]|0)-h|0;if((e|0)>0){l=e;m=d;n=j}else{return}while(1){j=(l|0)>(k|0)?k:l;nrc(n|0,m|0,j)|0;FT(b,c[g>>2]|0,j+h|0,(l|0)==(j|0)|0);d=l-j|0;e=c[g>>2]|0;a[e]=a[e]&-17;if((d|0)<=0){break}l=d;m=m+j|0;n=c[i>>2]|0}return}function WT(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=c[b+12>>2]|0;h=c[g+40>>2]|0;switch(d[e]|0|0){case 1:case 5:case 128:case 130:{i=1;break};case 3:case 129:{i=2;break};default:{i=0}}j=g+80|0;k=c[j>>2]|0;a[k]=-2;a[k+1|0]=-51;l=k+3|0;a[k+2|0]=-70;m=(h|0)<(f|0);n=m&1;if(!((i|0)==0&(m^1))){m=g+44|0;if((c[m>>2]|0)==0){o=g+84|0}else{p=c[j>>2]|0;q=g+84|0;FT(b,p,(c[q>>2]|0)-p|0,0);o=q}c[g+28>>2]=c[g+36>>2];c[m>>2]=0;c[o>>2]=l;if((f|0)<=0){return}m=i<<4;i=n;n=f;q=e;p=l;while(1){r=(i|0)==0|(i|0)==3?n:h;a[p]=i<<6|m;a[p+1|0]=r>>>8;a[p+2|0]=r;nrc(p+3|0,q|0,r)|0;s=n-r|0;t=c[j>>2]|0;FT(b,t,p+(r+3)-t|0,0);if((s|0)<=0){break}i=(s|0)<=(h|0)?3:2;n=s;q=q+r|0;p=c[o>>2]|0}return}o=g+84|0;p=g+44|0;q=c[p>>2]|0;if((q|0)>0){n=c[o>>2]|0;i=c[j>>2]|0;if((i+(h+6)-(n+(f+2))|0)<0){u=i;v=n;w=9}else{w=7}}else{w=7}do{if((w|0)==7){if((q|0)==(c[g+88>>2]|0)){u=c[j>>2]|0;v=c[o>>2]|0;w=9;break}else{if((q|0)==0){w=11;break}else{x=q;break}}}}while(0);if((w|0)==9){FT(b,u,v-u|0,0);c[p>>2]=0;w=11}if((w|0)==11){c[g+28>>2]=c[g+36>>2];x=0}g=x+1|0;c[p>>2]=g;a[l]=g;if((c[p>>2]|0)>1){y=c[o>>2]|0}else{y=k+4|0}a[y]=f>>>8;a[y+1|0]=f;nrc(y+2|0,e|0,f)|0;c[o>>2]=y+(f+2);return}function XT(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=(krc(((d[b+1|0]|0)<<8|(d[b]|0)<<16|(d[b+2|0]|0)|0)==15711167?b+3|0:b,2179688,6)|0)==0;return(a?100:0)|0}function YT(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+2056|0;e=d|0;f=d+1024|0;g=d+2048|0;h=c[b+12>>2]|0;j=ZX(b,0)|0;a[g]=0;if((j|0)==0){k=-12;i=d;return k|0}_X(j,64,1,1e3);l=j+8|0;j=c[l>>2]|0;c[j+8>>2]=3;c[j+48>>2]=1396788553;SFb(e,0,-1);SFb(f,0,-1);j=b+16|0;a:do{if((jD(c[j>>2]|0)|0)==0){b=e|0;m=h;n=e+4|0;o=0;p=0;q=0;while(1){r=fD(c[j>>2]|0,0,0,1)|0;s=xrc(r,G,q,p)|0;r=G;if((PV(c[j>>2]|0,e,g)|0)==0){t=14;break a}u=(JFb(c[b>>2]|0,2309976,5)|0)!=0;v=u?o:1;w=c[b>>2]|0;do{if((v|0)==0){UFb(f,2257464,(x=i,i=i+8|0,c[x>>2]=w,x)|0);i=x}else{x=IV(m,w,c[n>>2]|0,u&1)|0;if((x|0)==0){y=-12;break a}if(u){break}z=QV(c[b>>2]|0,2212408)|0;A=x+64|0;c[A>>2]=s;c[A+4>>2]=r;if((z|0)==0){B=0;C=0}else{A=rb(z|0,0,10)|0;B=(A|0)<0|0?-1:0;C=A}A=x+8|0;c[A>>2]=C;c[A+4>>2]=B;c[x+48>>2]=-1}}while(0);ZFb(e);if((jD(c[j>>2]|0)|0)!=0){t=14;break a}o=v;p=0;q=(a[g]|0)!=0|0}}else{t=14}}while(0);do{if((t|0)==14){g=T5a(c[l>>2]|0,f)|0;if((g|0)<0){y=g;break}JV(h);y=g}}while(0);_Fb(e,0)|0;k=y;i=d;return k|0}function ZT(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function _T(a){a=a|0;OV(c[a+12>>2]|0);return 0}function $T(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function aU(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+40|0;h=g|0;j=c[b+16>>2]|0;k=iD(j)|0;l=G;m=wrc(k,l,-128,-1)|0;fD(j,m,G,0)|0;m=h|0;if((AD(j,m,7)|0)!=7){n=-1;i=g;return n|0}if((grc(m,2107488,7)|0)!=0){n=-1;i=g;return n|0}o=(AD(j,m,35)|0)!=35;if(!(o|(a[m]|0)==0)){a[h+35|0]=0;MGb(b+1140|0,2471896,m,0)|0}o=(AD(j,m,20)|0)!=20;if(!(o|(a[m]|0)==0)){a[h+20|0]=0;MGb(b+1140|0,2378048,m,0)|0}o=(AD(j,m,20)|0)!=20;if(!(o|(a[m]|0)==0)){a[h+20|0]=0;MGb(b+1140|0,2309960,m,0)|0}o=(AD(j,m,8)|0)!=8;if(!(o|(a[m]|0)==0)){a[h+8|0]=0;MGb(b+1140|0,2257440,m,0)|0}hD(j,4,0)|0;o=zD(j)|0;p=zD(j)|0;q=DD(j)|0;r=DD(j)|0;s=zD(j)|0;hD(j,1,0)|0;hD(j,4,0)|0;t=(AD(j,m,22)|0)!=22;if(!(t|(a[m]|0)==0)){a[h+22|0]=0;MGb(b+1140|0,2212400,m,0)|0}a:do{if(!((e|0)==0|(o|0)==0|(p|0)==0)){do{if(!((o|0)==1&(p|0)<3)){h=(o|0)==5;if(h&(p|0)==255|(o|0)==6){break}if(!h){break a}c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+120>>2]=((p|0)==1?q:p)<<4;c[e>>2]=1;if((f|0)==0|(r|0)==0){break a}c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+124>>2]=r<<4;break a}}while(0);if((q|0)!=0){c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+120>>2]=q<<3;c[e>>2]=1}if((f|0)==0|(r|0)==0){break}c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+124>>2]=r<<4}}while(0);r=wrc(c[d>>2]|0,c[d+4>>2]|0,-128,-1)|0;c[d>>2]=r;c[d+4>>2]=G;if((s|0)<=0){n=0;i=g;return n|0}r=s<<6;f=wrc(k,l,-133,-1)|0;l=xrc(f,G,r,(r|0)<0|0?-1:0)|0;fD(j,l,G,0)|0;if((AD(j,m,5)|0)!=5){n=0;i=g;return n|0}if((grc(m,2179680,5)|0)!=0){n=0;i=g;return n|0}m=hJb((s*65|0)+1|0)|0;l=r|5;r=xrc(c[d>>2]|0,c[d+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[d>>2]=r;c[d+4>>2]=G;if((m|0)==0){n=0;i=g;return n|0}else{u=0}while(1){d=u*65|0;if((AD(j,m+d|0,64)|0)!=64){v=u;break}a[m+(d+64)|0]=10;d=u+1|0;if((d|0)<(s|0)){u=d}else{v=d;break}}a[m+(v*65|0)|0]=0;MGb(b+1140|0,2151928,m,8)|0;n=0;i=g;return n|0}function bU(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+88|0;d=b|0;e=d;mrc(e|0,0,88)|0;do{if((gU(0,c[a+4>>2]|0,c[a+8>>2]|0,d)|0)<0){f=0}else{if((c[d+20>>2]|0)==0){f=0;break}f=(c[d+24>>2]|0)!=0?33:0}}while(0);mJb(e);mJb(d+4|0);mJb(d+8|0);mJb(d+12|0);mJb(d+16|0);mJb(d+72|0);i=b;return f|0}function cU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;d=i;i=i+248|0;e=d|0;f=d+24|0;g=d+48|0;h=d+72|0;j=d+120|0;k=d+128|0;l=d+136|0;m=d+144|0;n=d+232|0;o=c[b+12>>2]|0;c[l>>2]=0;p=m;mrc(p|0,0,88)|0;mrc(n|0,0,12)|0;q=c[b+16>>2]|0;r=c[o+12>>2]|0;s=0;t=0;u=0;while(1){if((s-t|0)<1024){v=s<<1;w=(v|0)>8192?v:8192;v=(w|0)>(r|0)?r:w;if((v-t|0)<2){x=-27;z=u;A=8;break}w=jJb(u,v,1)|0;if((w|0)==0){x=-12;z=0;A=8;break}else{B=v;C=w}}else{B=s;C=u}w=AD(q,C,B+~t|0)|0;if((w|0)==-541478725){A=7;break}if((w|0)<0){x=t;z=C;A=8;break}else{s=B;t=w+t|0;u=C}}if((A|0)==7){a[C+t|0]=0;c[l>>2]=C;D=t}else if((A|0)==8){kJb(z);D=x}a:do{if((D|0)<0){E=D}else{x=b;z=gU(x,c[l>>2]|0,D,m)|0;if((z|0)<0){E=z;break}z=o+4|0;t=c[z>>2]|0;C=m+76|0;if((t|0)==0){c[z>>2]=c[C>>2]}else{c[C>>2]=t}t=o+8|0;if((c[t>>2]|0)==0){C=c[z>>2]|0;if((C|0)<10){F=1}else{F=(C|0)/10|0}c[t>>2]=F}C=m+72|0;if((c[C>>2]|0)!=0){KIb(x,24,2377936,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}c[k>>2]=0;u=m+24|0;B=c[u>>2]|0;if((B|0)>0){s=c[m+8>>2]|0;q=0;r=0;while(1){w=((a[s+(r<<5)+8|0]|0)==78)+q|0;v=r+1|0;if((v|0)<(B|0)){q=w;r=v}else{I=w;break}}}else{I=0}do{if((I|0)==(B|0)){r=m+40|0;if((c[r>>2]|0)==0&(c[r+4>>2]|0)==(-2147483648|0)){J=0;K=0;L=r;break}KIb(x,24,2104208,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;J=0;K=0;L=r}else{if((I|0)==0){r=m+40|0;q=c[r>>2]|0;s=c[r+4>>2]|0;if(!((q|0)==0&(s|0)==(-2147483648|0))){J=s;K=q;L=r;break}}if((a[m+80|0]|0)!=0){r=m+40|0;q=c[r>>2]|0;s=c[r+4>>2]|0;if(!((q|0)==0&(s|0)==(-2147483648|0))){J=s;K=q;L=r;break}q=c[m+8>>2]|0;s=c[q>>2]|0;w=c[q+4>>2]|0;c[r>>2]=s;c[r+4>>2]=w;J=w;K=s;L=r;break}KIb(x,24,2622328,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ie(j|0)|0;r=Ab(j|0)|0;if((r|0)==0){M=(c[j>>2]|0)%86400|0}else{M=((c[r+4>>2]|0)*60|0)+((c[r+8>>2]|0)*3600|0)+(c[r>>2]|0)|0}r=M;s=(M|0)<0|0?-1:0;w=Crc(r,s,3600,0)|0;q=Crc(r,s,60,0)|0;KIb(x,32,2594536,(H=i,i=i+24|0,c[H>>2]=w,c[H+8>>2]=(q|0)%60|0,c[H+16>>2]=(M|0)%60|0,H)|0);i=H;q=Erc(r,s,1e6,0)|0;s=G;r=c[u>>2]|0;if((r|0)>0){w=m+8|0;v=0;N=r;while(1){r=c[w>>2]|0;O=r+(v<<5)+8|0;if((a[O]|0)==78){P=r+(v<<5)|0;r=wrc(c[P>>2]|0,c[P+4>>2]|0,q,s)|0;c[P>>2]=r;c[P+4>>2]=G;a[O]=84;Q=c[u>>2]|0}else{Q=N}O=v+1|0;if((O|0)<(Q|0)){v=O;N=Q}else{break}}}J=s;K=q;L=m+40|0}}while(0);B=c[L>>2]|0;N=c[L+4>>2]|0;if((B|0)==0&(N|0)==(-2147483648|0)){if((a[m+80|0]|0)==0){R=J;S=K}else{v=c[m+8>>2]|0;R=c[v+4>>2]|0;S=c[v>>2]|0}c[L>>2]=S;c[L+4>>2]=R;T=R;U=S}else{T=N;U=B}B=m+64|0;N=c[B>>2]|0;v=c[B+4>>2]|0;B=(N|0)==0&(v|0)==0;w=wrc(N,v,U,T)|0;v=m+48|0;c[v>>2]=B?0:w;c[v+4>>2]=B?-2147483648:G;B=c[u>>2]|0;w=(B|0)>0;N=m+8|0;do{if(w){O=c[N>>2]|0;P=J;r=K;V=0;W=0;X=0;do{Y=O+(X<<5)|0;Z=c[Y>>2]|0;_=c[Y+4>>2]|0;$=wrc(Z,_,W,V)|0;aa=G;ba=(aa|0)<(P|0)|(aa|0)==(P|0)&$>>>0<r>>>0;$=wrc(W,V,500654080,20)|0;W=ba?$:W;V=ba?G:V;r=wrc(W,V,Z,_)|0;P=G;c[Y>>2]=r;c[Y+4>>2]=P;X=X+1|0;}while((X|0)<(B|0));if(w){ca=0}else{break}do{X=jU(x,m,k,0,0,(c[N>>2]|0)+(ca<<5)|0)|0;if((X|0)<0){E=X;break a}ca=ca+1|0;}while((ca|0)<(c[u>>2]|0))}}while(0);u=m+28|0;w=c[u>>2]|0;if((w|0)==0){KIb(x,16,2179656,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;E=-1094995529;break}if((a[m+81|0]|0)==0){da=m+16|0}else{B=m+16|0;X=(c[B>>2]|0)+((w-1|0)*48|0)|0;w=c[X+4>>2]|0;c[v>>2]=c[X>>2];c[v+4>>2]=w;da=B}mJb(l);B=c[z>>2]|0;w=h;X=m+56|0;P=Crc(c[X>>2]|0,c[X+4>>2]|0,2,0)|0;X=G;r=c[u>>2]|0;V=r-1|0;W=c[da>>2]|0;O=W+(V*48|0)|0;q=W|0;s=c[q>>2]|0;Y=c[q+4>>2]|0;q=xrc(c[O>>2]|0,c[O+4>>2]|0,s,Y)|0;O=wrc(q,G,500654079,20)|0;q=G;_=Drc(O,q,500654080,20)|0;Z=xrc(O,q,_,G)|0;_=G;q=20;O=(_|0)>(q|0)|(_|0)==(q|0)&Z>>>0>500654080>>>0;q=O?Z:500654080;Z=O?_:20;if((r|0)>0){_=0;O=Y;Y=s;while(1){s=_+1|0;ba=(s|0)%(r|0)|0;$=W+(_*48|0)+8|0;c[$>>2]=Y;c[$+4>>2]=O;if((a[W+(_*48|0)+42|0]|0)==0){$=W+(ba*48|0)|0;aa=(_|0)<(ba|0);ba=wrc(c[$>>2]|0,c[$+4>>2]|0,aa?0:q,aa?0:Z)|0;ea=G;fa=ba}else{ea=O;fa=Y}ba=W+(_*48|0)+16|0;c[ba>>2]=fa;c[ba+4>>2]=ea;if((s|0)>=(r|0)){ga=0;break}ba=W+(s*48|0)|0;_=s;O=c[ba+4>>2]|0;Y=c[ba>>2]|0}while(1){Y=ga+1|0;O=(Y|0)==(r|0)?0:Y;if((a[W+(ga*48|0)+42|0]|0)==0){_=W+(ga*48|0)+8|0;ba=c[_>>2]|0;s=c[_+4>>2]|0;_=W+(ga*48|0)+16|0;aa=xrc(c[_>>2]|0,c[_+4>>2]|0,P,X)|0;$=G;ha=(s|0)>($|0)|(s|0)==($|0)&ba>>>0>aa>>>0;c[_>>2]=ha?ba:aa;c[_+4>>2]=ha?s:$;$=W+(O*48|0)+16|0;s=c[$>>2]|0;ha=c[$+4>>2]|0;$=W+(O*48|0)+8|0;_=wrc(c[$>>2]|0,c[$+4>>2]|0,P,X)|0;aa=G;ba=(ha|0)>(aa|0)|(ha|0)==(aa|0)&s>>>0>_>>>0;ia=ba?_:s;s=ba?aa:ha;c[$>>2]=ia;c[$+4>>2]=s;ja=s;ka=ia}else{ia=W+(O*48|0)+8|0;ja=c[ia+4>>2]|0;ka=c[ia>>2]|0}ia=(ga|0)<(O|0);O=wrc(ka,ja,ia?0:q,ia?0:Z)|0;ia=W+(ga*48|0)+24|0;c[ia>>2]=O;c[ia+4>>2]=G;if((Y|0)<(r|0)){ga=Y}else{break}}}X=W+(V*48|0)|0;c[w>>2]=c[X>>2];c[w+4>>2]=c[X+4>>2];c[w+8>>2]=c[X+8>>2];c[w+12>>2]=c[X+12>>2];c[w+16>>2]=c[X+16>>2];c[w+20>>2]=c[X+20>>2];c[w+24>>2]=c[X+24>>2];c[w+28>>2]=c[X+28>>2];c[w+32>>2]=c[X+32>>2];c[w+36>>2]=c[X+36>>2];c[w+40>>2]=c[X+40>>2];c[w+44>>2]=c[X+44>>2];X=h+8|0;P=xrc(c[X>>2]|0,c[X+4>>2]|0,q,Z)|0;c[X>>2]=P;c[X+4>>2]=G;X=h+16|0;P=xrc(c[X>>2]|0,c[X+4>>2]|0,q,Z)|0;c[X>>2]=P;c[X+4>>2]=G;X=h+24|0;P=xrc(c[X>>2]|0,c[X+4>>2]|0,q,Z)|0;c[X>>2]=P;c[X+4>>2]=G;if((r|0)>-1){X=B;P=(B|0)<0|0?-1:0;Y=-1;do{if((Y|0)<0){la=h}else{la=W+(Y*48|0)|0}ia=la+8|0;O=VIb(c[ia>>2]|0,c[ia+4>>2]|0,X,P,1e6,0)|0;c[ia>>2]=O;c[ia+4>>2]=G;ia=la+16|0;O=VIb(c[ia>>2]|0,c[ia+4>>2]|0,X,P,1e6,0)|0;c[ia>>2]=O;c[ia+4>>2]=G;ia=la+24|0;O=VIb(c[ia>>2]|0,c[ia+4>>2]|0,X,P,1e6,0)|0;c[ia>>2]=O;c[ia+4>>2]=G;Y=Y+1|0;}while((Y|0)<(r|0))}r=m+32|0;Y=m+4|0;if((c[r>>2]|0)>0){P=c[Y>>2]|0;X=0;do{c[P+(X*24|0)+20>>2]=-1;c[P+(X*24|0)+16>>2]=-1;X=X+1|0;}while((X|0)<(c[r>>2]|0))}r=e;X=f;P=g;W=e+12|0;B=f+12|0;Z=g+8|0;q=f+16|0;w=e|0;V=f|0;ia=e+4|0;O=f+4|0;s=e+8|0;$=f+8|0;ha=-1;while(1){aa=c[u>>2]|0;if((ha|0)>=(aa|0)){break}ba=c[da>>2]|0;if((ha|0)<0){ma=h}else{ma=ba+(ha*48|0)|0}_=ha+1|0;na=ma+8|0;oa=c[na>>2]|0;pa=c[na+4>>2]|0;na=ma+16|0;qa=c[na>>2]|0;ra=c[na+4>>2]|0;sa=ma+32|0;ta=ma+36|0;ua=0;while(1){va=c[ta>>2]|0;if((ua|0)>=(va|0)){break}wa=(c[Y>>2]|0)+(((c[sa>>2]|0)+ua|0)*24|0)|0;xa=hU(x,m,n,oa,pa,qa,ra,wa,wa,0)|0;if((xa|0)<0){E=xa;break a}else{ua=ua+1|0}}ua=(_|0)%(aa|0)|0;ra=c[na>>2]|0;qa=c[na+4>>2]|0;pa=ma+24|0;oa=c[pa>>2]|0;xa=c[pa+4>>2]|0;pa=wrc(oa>>>1|xa<<31,xa>>1|((xa|0)<0|0?-1:0)<<31,ra>>>1|qa<<31,qa>>1|((qa|0)<0|0?-1:0)<<31)|0;wa=wrc(pa,G,ra&1&oa,qa&0&xa)|0;pa=G;ya=ma+42|0;za=ba+(ua*48|0)+36|0;Aa=c[za>>2]|0;Ba=(va|0)>(Aa|0)?va:Aa;Aa=(Ba|0)>0;Ca=ba+(ua*48|0)+32|0;Da=(a[ba+(ua*48|0)+40|0]&a[ma+41|0]|a[ya])<<24>>24==3;ua=0;b:while(1){if(Aa){Ea=(ua|0)==0;Fa=0;do{if((Fa|0)<(c[ta>>2]|0)){Ga=(c[Y>>2]|0)+(((c[sa>>2]|0)+Fa|0)*24|0)|0}else{Ga=e}if((Fa|0)<(c[za>>2]|0)){Ha=(c[Y>>2]|0)+(((c[Ca>>2]|0)+Fa|0)*24|0)|0}else{Ha=f}if((Ga|0)==(e|0)){mrc(r|0,0,24)|0}else{Ia=Ga;c[r>>2]=c[Ia>>2];c[r+4>>2]=c[Ia+4>>2];c[r+8>>2]=c[Ia+8>>2];c[r+12>>2]=c[Ia+12>>2];c[r+16>>2]=c[Ia+16>>2];c[r+20>>2]=c[Ia+20>>2]}if((Ha|0)==(f|0)){mrc(X|0,0,24)|0}else{Ia=Ha;c[X>>2]=c[Ia>>2];c[X+4>>2]=c[Ia+4>>2];c[X+8>>2]=c[Ia+8>>2];c[X+12>>2]=c[Ia+12>>2];c[X+16>>2]=c[Ia+16>>2];c[X+20>>2]=c[Ia+20>>2]}do{if((a[ya]|0)!=0){if((c[W>>2]|0)==0){c[r>>2]=c[X>>2];c[r+4>>2]=c[X+4>>2];c[r+8>>2]=c[X+8>>2];c[r+12>>2]=c[X+12>>2];c[r+16>>2]=c[X+16>>2];c[r+20>>2]=c[X+20>>2];c[s>>2]=0;break}if((c[B>>2]|0)!=0){break}c[X>>2]=c[r>>2];c[X+4>>2]=c[r+4>>2];c[X+8>>2]=c[r+8>>2];c[X+12>>2]=c[r+12>>2];c[X+16>>2]=c[r+16>>2];c[X+20>>2]=c[r+20>>2];c[$>>2]=0}}while(0);Ia=c[W>>2]|0;do{if((Ia|0)!=(c[B>>2]|0)|(Ia|0)==3){A=104}else{if(!Da){if((c[w>>2]|0)!=(c[V>>2]|0)){A=104;break}if((c[ia>>2]|0)!=(c[O>>2]|0)){A=104;break}}if(!Ea){break}Ja=hU(x,m,n,ra,qa,oa,xa,e,f,3)|0;if((Ja|0)<0){Ka=Ja;break b}Ja=Ha+16|0;La=c[q+4>>2]|0;c[Ja>>2]=c[q>>2];c[Ja+4>>2]=La}}while(0);do{if((A|0)==104){A=0;if(Ea){c[P>>2]=c[r>>2];c[P+4>>2]=c[r+4>>2];c[P+8>>2]=c[r+8>>2];c[P+12>>2]=c[r+12>>2];c[P+16>>2]=c[r+16>>2];c[P+20>>2]=c[r+20>>2];c[Z>>2]=0;Ia=hU(x,m,n,ra,qa,wa,pa,e,g,1)|0;if((Ia|0)<0){Ka=Ia;break b}else{break}}c[P>>2]=c[X>>2];c[P+4>>2]=c[X+4>>2];c[P+8>>2]=c[X+8>>2];c[P+12>>2]=c[X+12>>2];c[P+16>>2]=c[X+16>>2];c[P+20>>2]=c[X+20>>2];c[Z>>2]=0;Ia=hU(x,m,n,wa,pa,oa,xa,g,f,2)|0;if((Ia|0)<0){Ka=Ia;break b}Ia=Ha+16|0;La=c[q+4>>2]|0;c[Ia>>2]=c[q>>2];c[Ia+4>>2]=La}}while(0);Fa=Fa+1|0;}while((Fa|0)<(Ba|0))}Fa=ua+1|0;if((Fa|0)<2){ua=Fa}else{Ka=0;break}}if((Ka|0)<0){E=Ka;break a}else{ha=_}}ha=n+4|0;q=c[ha>>2]|0;if((q|0)==0){KIb(x,24,2309912,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}Z=ZX(b,0)|0;if((Z|0)==0){Ma=-12;i=d;return Ma|0}X=Z+8|0;P=c[X>>2]|0;c[P+8>>2]=1;c[P+48>>2]=1179014995;c[P+416>>2]=2;r=P+448|0;c[r>>2]=3;c[r+4>>2]=0;r=c[z>>2]|0;c[P+412>>2]=r;c[P+424>>2]=c[t>>2];_X(Z,64,1,r);c[Z+228>>2]=0;r=m+40|0;P=c[z>>2]|0;O=P;ia=(P|0)<0|0?-1:0;P=VIb(c[r>>2]|0,c[r+4>>2]|0,O,ia,1e6,0)|0;V=G;w=Z+48|0;c[w>>2]=P;c[w+4>>2]=V;w=c[v>>2]|0;B=c[v+4>>2]|0;if((w|0)==0&(B|0)==(-2147483648|0)){Na=-2147483648;Oa=0}else{W=xrc(w,B,c[r>>2]|0,c[r+4>>2]|0)|0;r=VIb(W,G,O,ia,1e6,0)|0;Na=G;Oa=r}r=Z+56|0;c[r>>2]=Oa;c[r+4>>2]=Na;r=Z+208|0;c[r>>2]=P;c[r+4>>2]=V;V=c[X>>2]|0;X=n|0;r=c[X>>2]|0;P=4;Z=0;while(1){if((Z|0)>=(q|0)){break}ia=c[r+(Z*48|0)+16>>2]|0;if((ia|0)==1162758483){Pa=44}else{Pa=(ia|0)==1397313358?32:0}ia=Pa+P|0;if((ia|0)<0){E=-12;break a}else{P=ia;Z=Z+1|0}}if((PX(V,P)|0)!=0){E=-12;break}Z=V+96|0;v=c[Z>>2]|0;z=v;y=q;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;z=v+4|0;c:do{if((q|0)>0){v=0;t=z;x=r;while(1){ia=x+(v*48|0)|0;O=c[ia+4>>2]|0;W=t;B=W|0;y=c[ia>>2]|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;B=W+4|0;y=O;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;B=(c[X>>2]|0)+(v*48|0)+8|0;O=c[B+4>>2]|0;W=t+8|0;ia=W|0;y=c[B>>2]|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=W+4|0;y=O;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=t+16|0;y=c[(c[X>>2]|0)+(v*48|0)+16>>2]|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=t+20|0;y=c[(c[X>>2]|0)+(v*48|0)+20>>2]|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=t+24|0;O=c[X>>2]|0;W=c[O+(v*48|0)+16>>2]|0;if((W|0)==1162758483){B=ia;y=c[O+(v*48|0)+24>>2]|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;B=t+28|0;y=c[(c[X>>2]|0)+(v*48|0)+28>>2]|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;B=t+32|0;y=c[(c[X>>2]|0)+(v*48|0)+32>>2]|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;B=t+36|0;y=c[(c[X>>2]|0)+(v*48|0)+36>>2]|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;B=t+40|0;y=c[(c[X>>2]|0)+(v*48|0)+40>>2]|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;Qa=t+44|0}else if((W|0)==1397313358){W=ia;y=c[O+(v*48|0)+32>>2]|0;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;W=t+28|0;y=c[(c[X>>2]|0)+(v*48|0)+36>>2]|0;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;Qa=t+32|0}else{Qa=ia}ia=v+1|0;if((ia|0)>=(c[ha>>2]|0)){Ra=Qa;break c}v=ia;t=Qa;x=c[X>>2]|0}}else{Ra=z}}while(0);if((Ra|0)!=((c[Z>>2]|0)+P|0)){E=-558323010;break}kJb(c[X>>2]|0);mJb(p);mJb(Y);mJb(N);mJb(m+12|0);mJb(da);mJb(C);Ma=0;i=d;return Ma|0}}while(0);kJb(c[n>>2]|0);mJb(p);mJb(m+4|0);mJb(m+8|0);mJb(m+12|0);mJb(m+16|0);mJb(m+72|0);kJb(c[l>>2]|0);Ma=E;i=d;return Ma|0}function dU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[c[b+28>>2]>>2]|0;b=e+208|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=c[(c[e+8>>2]|0)+424>>2]|0;h=wrc(b,(b|0)<0|0?-1:0,f,g)|0;b=G;i=e+56|0;j=c[i>>2]|0;k=c[i+4>>2]|0;if((j|0)==0&(k|0)==(-2147483648|0)){l=b;m=h}else{i=e+48|0;e=wrc(c[i>>2]|0,c[i+4>>2]|0,j,k)|0;k=G;j=(k|0)>(b|0)|(k|0)==(b|0)&e>>>0>h>>>0;l=j?b:k;m=j?h:e}if(!((l|0)>(g|0)|(l|0)==(g|0)&m>>>0>f>>>0)){n=-541478725;return n|0}if((K1(d,12)|0)<0){n=-12;return n|0}e=d+8|0;c[e>>2]=f;c[e+4>>2]=g;e=d+16|0;c[e>>2]=f;c[e+4>>2]=g;e=xrc(m,l,f,g)|0;l=d+48|0;c[l>>2]=e;e=d+24|0;m=c[e>>2]|0;h=m|0;y=f;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=m+4|0;y=g;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=(c[e>>2]|0)+8|0;y=c[l>>2]|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;n=c[d+28>>2]|0;return n|0}function eU(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;if((b|0)>0){h=-22;i=f;return h|0}if((b|0)<0){c[g>>2]=1;c[g+4>>2]=1e6;b=a+28|0;j=XIb(d,e,g,(c[c[b>>2]>>2]|0)+40|0)|0;k=G;l=j;m=b}else{k=e;l=d;m=a+28|0}a=(c[c[m>>2]>>2]|0)+208|0;c[a>>2]=l;c[a+4>>2]=k;h=0;i=f;return h|0}function fU(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;j=i;i=i+8|0;h=j|0;if((k|0)!=0|(b|0)>0){l=-22;i=j;return l|0}if((b|0)<0){c[h>>2]=1;c[h+4>>2]=1e6;b=a+28|0;k=XIb(f,g,h,(c[c[b>>2]>>2]|0)+40|0)|0;m=G;n=k;o=b}else{m=g;n=f;o=a+28|0}a=(c[c[o>>2]>>2]|0)+208|0;c[a>>2]=n;c[a+4>>2]=m;l=0;i=j;return l|0}function gU(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0.0,oa=0.0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0.0,hb=0,ib=0.0,jb=0,kb=0.0,lb=0,mb=0,nb=0.0,ob=0,pb=0.0,qb=0.0,sb=0,tb=0.0,ub=0,vb=0.0,wb=0,xb=0,yb=0,zb=0.0,Ab=0,Bb=0.0,Cb=0,Db=0,Eb=0.0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Pb=0,Qb=0,Sb=0,Tb=0,Ub=0;g=i;i=i+360|0;j=g|0;k=g+8|0;l=g+16|0;m=g+24|0;n=g+32|0;o=g+40|0;p=g+48|0;q=g+56|0;r=g+64|0;s=g+72|0;t=g+80|0;u=g+88|0;v=u|0;c[v>>2]=b;c[u+4>>2]=d;w=u+8|0;x=d+e|0;c[w>>2]=x;y=u+12|0;c[y>>2]=d;z=u+16|0;A=z;mrc(A|0,0,88)|0;B=u+56|0;c[B>>2]=0;c[B+4>>2]=-2147483648;C=u+72|0;c[C>>2]=6e7;c[C+4>>2]=0;D=u+92|0;c[D>>2]=44100;E=u+120|0;G=u+124|0;H=u+128|0;I=u+140|0;mrc(u+104|0,0,36)|0;c[I>>2]=1;J=u+144|0;mrc(J|0,0,128)|0;a:do{if((e|0)>0){K=d;while(1){L=a[K]|0;if(!((L<<24>>24|0)==32|(L<<24>>24|0)==9|(L<<24>>24|0)==13)){M=K;break a}L=K+1|0;c[y>>2]=L;if(L>>>0<x>>>0){K=L}else{M=L;break}}}else{M=d}}while(0);b:do{if(M>>>0<x>>>0){d=u+96|0;e=u+97|0;K=u+80|0;L=u+88|0;N=M;O=x;c:while(1){d:do{if((N|0)==(O|0)){P=119}else{if((a[N]|0)!=45){P=119;break}e:do{if(N>>>0<O>>>0){S=N+1|0;c[y>>2]=S;if((S|0)==(O|0)){T=0;U=O;V=O;break}else{W=O;X=0;Y=S}while(1){S=a[Y]|0;if(S<<24>>24==10){T=X;U=W;V=Y;break e}f:do{if(Y>>>0<W>>>0){Z=Y;_=S;while(1){if((_<<24>>24|0)==10|(_<<24>>24|0)==32|(_<<24>>24|0)==9|(_<<24>>24|0)==13){$=Z;break f}aa=Z+1|0;if(!(aa>>>0<W>>>0)){$=aa;break f}Z=aa;_=a[aa]|0}}else{$=Y}}while(0);c[y>>2]=$;g:do{if($>>>0<W>>>0){S=$;while(1){_=a[S]|0;if(!((_<<24>>24|0)==32|(_<<24>>24|0)==9|(_<<24>>24|0)==13)){ca=S;break g}_=S+1|0;c[y>>2]=_;if(_>>>0<W>>>0){S=_}else{ca=_;break}}}else{ca=$}}while(0);if(Y>>>0<$>>>0){S=Y;_=X;while(1){da=a[S]|0;switch(da|0){case 105:{ea=105;break};case 114:{Z=c[y>>2]|0;aa=c[w>>2]|0;if((Z|0)==(aa|0)){P=99;break c}fa=a[Z]|0;if(fa<<24>>24==10){P=99;break c}h:do{if(Z>>>0<aa>>>0){ga=Z;ia=fa;while(1){if((ia<<24>>24|0)==10|(ia<<24>>24|0)==32|(ia<<24>>24|0)==9|(ia<<24>>24|0)==13){ja=ga;break h}ka=ga+1|0;if(!(ka>>>0<aa>>>0)){ja=ka;break h}ga=ka;ia=a[ka]|0}}else{ja=Z}}while(0);c[y>>2]=ja;i:do{if(ja>>>0<aa>>>0){fa=ja;do{ia=a[fa]|0;if(!((ia<<24>>24|0)==32|(ia<<24>>24|0)==9|(ia<<24>>24|0)==13)){break i}fa=fa+1|0;c[y>>2]=fa;}while(fa>>>0<aa>>>0)}}while(0);aa=rb(Z|0,t|0,10)|0;if((ja|0)!=(c[t>>2]|0)){P=101;break c}if((aa|0)<40){P=103;break c}c[D>>2]=aa;ea=_;break};case 83:{a[d]=1;ea=_;break};case 69:{a[e]=1;ea=_;break};case 112:{ea=112;break};case 70:{aa=c[y>>2]|0;fa=c[w>>2]|0;if((aa|0)==(fa|0)){P=36;break c}ia=a[aa]|0;if(ia<<24>>24==10){P=36;break c}j:do{if(aa>>>0<fa>>>0){ga=aa;ka=ia;while(1){if((ka<<24>>24|0)==10|(ka<<24>>24|0)==32|(ka<<24>>24|0)==9|(ka<<24>>24|0)==13){la=ga;break j}ma=ga+1|0;if(!(ma>>>0<fa>>>0)){la=ma;break j}ga=ma;ka=a[ma]|0}}else{la=aa}}while(0);c[y>>2]=la;k:do{if(la>>>0<fa>>>0){ia=la;do{Z=a[ia]|0;if(!((Z<<24>>24|0)==32|(Z<<24>>24|0)==9|(Z<<24>>24|0)==13)){break k}ia=ia+1|0;c[y>>2]=ia;}while(ia>>>0<fa>>>0)}}while(0);na=+frc(aa,t);if((la|0)!=(c[t>>2]|0)){P=38;break c}oa=na*1.0e6/1.0e3;fa=(F=+oa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[C>>2]=~~+oa>>>0;c[C+4>>2]=fa;ea=_;break};case 76:{fa=c[y>>2]|0;ia=c[w>>2]|0;if((fa|0)==(ia|0)){P=49;break c}Z=a[fa]|0;if(Z<<24>>24==10){P=49;break c}l:do{if(fa>>>0<ia>>>0){ka=fa;ga=Z;while(1){if((ga<<24>>24|0)==10|(ga<<24>>24|0)==32|(ga<<24>>24|0)==9|(ga<<24>>24|0)==13){pa=ka;break l}ma=ka+1|0;if(!(ma>>>0<ia>>>0)){pa=ma;break l}ka=ma;ga=a[ma]|0}}else{pa=fa}}while(0);c[y>>2]=pa;m:do{if(pa>>>0<ia>>>0){Z=pa;do{aa=a[Z]|0;if(!((aa<<24>>24|0)==32|(aa<<24>>24|0)==9|(aa<<24>>24|0)==13)){break m}Z=Z+1|0;c[y>>2]=Z;}while(Z>>>0<ia>>>0)}}while(0);if((pa|0)==(fa+(lU(fa,K)|0)|0)){ea=_}else{P=51;break c}break};case 84:{ia=c[y>>2]|0;Z=c[w>>2]|0;if((ia|0)==(Z|0)){P=61;break c}aa=a[ia]|0;if(aa<<24>>24==10){P=61;break c}n:do{if(ia>>>0<Z>>>0){ga=ia;ka=aa;while(1){if((ka<<24>>24|0)==10|(ka<<24>>24|0)==32|(ka<<24>>24|0)==9|(ka<<24>>24|0)==13){qa=ga;break n}ma=ga+1|0;if(!(ma>>>0<Z>>>0)){qa=ma;break n}ga=ma;ka=a[ma]|0}}else{qa=ia}}while(0);c[y>>2]=qa;o:do{if(qa>>>0<Z>>>0){aa=qa;do{fa=a[aa]|0;if(!((fa<<24>>24|0)==32|(fa<<24>>24|0)==9|(fa<<24>>24|0)==13)){break o}aa=aa+1|0;c[y>>2]=aa;}while(aa>>>0<Z>>>0)}}while(0);if((qa|0)==(ia+(lU(ia,B)|0)|0)){ea=_}else{P=63;break c}break};case 109:{Z=c[y>>2]|0;aa=c[w>>2]|0;if((Z|0)==(aa|0)){P=73;break c}fa=a[Z]|0;if(fa<<24>>24==10){P=73;break c}p:do{if(Z>>>0<aa>>>0){ka=Z;ga=fa;while(1){if((ga<<24>>24|0)==10|(ga<<24>>24|0)==32|(ga<<24>>24|0)==9|(ga<<24>>24|0)==13){ra=ka;break p}ma=ka+1|0;if(!(ma>>>0<aa>>>0)){ra=ma;break p}ka=ma;ga=a[ma]|0}}else{ra=Z}}while(0);c[y>>2]=ra;q:do{if(ra>>>0<aa>>>0){fa=ra;do{ia=a[fa]|0;if(!((ia<<24>>24|0)==32|(ia<<24>>24|0)==9|(ia<<24>>24|0)==13)){break q}fa=fa+1|0;c[y>>2]=fa;}while(fa>>>0<aa>>>0)}}while(0);aa=ra-Z|0;fa=hJb(aa+1|0)|0;c[t>>2]=fa;if((fa|0)==0){sa=-12;break b}nrc(fa|0,Z|0,aa)|0;a[fa+aa|0]=0;kJb(c[L>>2]|0);c[L>>2]=fa;ea=_;break};case 113:{fa=c[y>>2]|0;aa=c[w>>2]|0;if((fa|0)==(aa|0)){P=85;break c}ia=a[fa]|0;if(ia<<24>>24==10){P=85;break c}r:do{if(fa>>>0<aa>>>0){ga=fa;ka=ia;while(1){if((ka<<24>>24|0)==10|(ka<<24>>24|0)==32|(ka<<24>>24|0)==9|(ka<<24>>24|0)==13){ta=ga;break r}ma=ga+1|0;if(!(ma>>>0<aa>>>0)){ta=ma;break r}ga=ma;ka=a[ma]|0}}else{ta=fa}}while(0);c[y>>2]=ta;s:do{if(ta>>>0<aa>>>0){ia=ta;do{Z=a[ia]|0;if(!((Z<<24>>24|0)==32|(Z<<24>>24|0)==9|(Z<<24>>24|0)==13)){break s}ia=ia+1|0;c[y>>2]=ia;}while(ia>>>0<aa>>>0)}}while(0);oa=+frc(fa,t);if((ta|0)!=(c[t>>2]|0)){P=87;break c}if(oa!=1.0){P=89;break c}else{ea=_}break};default:{P=105;break c}}aa=S+1|0;if(aa>>>0<$>>>0){S=aa;_=ea}else{break}}ua=ea;va=c[y>>2]|0;wa=c[w>>2]|0}else{ua=X;va=ca;wa=W}if(!(va>>>0<wa>>>0)){xa=ua;ya=va;za=wa;P=13;break e}_=(a[va]|0)==45;S=va+(_&1)|0;c[y>>2]=S;if((S|0)==(wa|0)|_^1){T=ua;U=wa;V=S;break}else{W=wa;X=ua;Y=S}}}else{xa=0;ya=N;za=O;P=13}}while(0);if((P|0)==13){P=0;c[y>>2]=ya;T=xa;U=za;V=ya}S=T<<24>>24;if((S|0)==105){P=108;break c}else if((S|0)==112){P=109;break c}else if((S|0)!=0){sa=-558323010;break b}t:do{if(V>>>0<U>>>0){if((a[V]|0)==35){Aa=V}else{Ba=V;break}while(1){S=Aa+1|0;c[y>>2]=S;if(!(S>>>0<U>>>0)){Ba=S;break t}if((a[S]|0)==10){Ba=S;break}else{Aa=S}}}else{Ba=V}}while(0);if((Ba|0)==(U|0)){Ca=Ba;Da=U;break}if((a[Ba]|0)!=10){sa=-1094995529;break b}S=Ba+1|0;c[y>>2]=S;c[I>>2]=(c[I>>2]|0)+1;if(S>>>0<U>>>0){Ea=S}else{Ca=S;Da=U;break}while(1){S=a[Ea]|0;if(!((S<<24>>24|0)==32|(S<<24>>24|0)==9|(S<<24>>24|0)==13)){Ca=Ea;Da=U;break d}S=Ea+1|0;c[y>>2]=S;if(S>>>0<U>>>0){Ea=S}else{Ca=S;Da=U;break}}}}while(0);u:do{if((P|0)==119){P=0;v:do{if(N>>>0<O>>>0){if((a[N]|0)==35){Fa=N}else{Ga=N;break}while(1){S=Fa+1|0;c[y>>2]=S;if(!(S>>>0<O>>>0)){Ga=S;break v}if((a[S]|0)==10){Ga=S;break}else{Fa=S}}}else{Ga=N}}while(0);if((Ga|0)==(O|0)){Ca=Ga;Da=O;break}if((a[Ga]|0)!=10){Ha=Ga;Ia=O;P=126;break b}S=Ga+1|0;c[y>>2]=S;c[I>>2]=(c[I>>2]|0)+1;if(S>>>0<O>>>0){Ja=S}else{Ca=S;Da=O;break}while(1){S=a[Ja]|0;if(!((S<<24>>24|0)==32|(S<<24>>24|0)==9|(S<<24>>24|0)==13)){Ca=Ja;Da=O;break u}S=Ja+1|0;c[y>>2]=S;if(S>>>0<O>>>0){Ja=S}else{Ca=S;Da=O;break}}}}while(0);if(Ca>>>0<Da>>>0){N=Ca;O=Da}else{Ha=Ca;Ia=Da;P=126;break b}}if((P|0)==36){Rb(J|0,128,2313720,(Ka=i,i=i+8|0,c[Ka>>2]=70,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==38){Rb(J|0,128,2383808,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==49){Rb(J|0,128,2313720,(Ka=i,i=i+8|0,c[Ka>>2]=76,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==51){Rb(J|0,128,2377032,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==61){Rb(J|0,128,2313720,(Ka=i,i=i+8|0,c[Ka>>2]=84,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==63){Rb(J|0,128,2371536,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==73){Rb(J|0,128,2313720,(Ka=i,i=i+8|0,c[Ka>>2]=109,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==85){Rb(J|0,128,2313720,(Ka=i,i=i+8|0,c[Ka>>2]=113,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==87){Rb(J|0,128,2356488,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==89){Rb(J|0,128,2347096,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1163346256;break}else if((P|0)==99){Rb(J|0,128,2313720,(Ka=i,i=i+8|0,c[Ka>>2]=114,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==101){Rb(J|0,128,2340680,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==103){Rb(J|0,128,2335032,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1163346256;break}else if((P|0)==105){Rb(J|0,128,2329792,(Ka=i,i=i+8|0,c[Ka>>2]=da,Ka)|0)|0;i=Ka;sa=-1094995529;break}else if((P|0)==108){Rb(J|0,128,2318800,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1163346256;break}else if((P|0)==109){Rb(J|0,128,2323808,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1163346256;break}}else{Ha=M;Ia=x;P=126}}while(0);w:do{if((P|0)==126){x:do{if(Ha>>>0<Ia>>>0){x=z;M=u+36|0;da=z|0;Da=u+48|0;Ca=u+20|0;Ja=Ha;Ga=Ia;y:while(1){Fa=Ja;while(1){U=a[Fa]|0;if(!((U-97&255)>>>0<26>>>0|(U-65&255)>>>0<26>>>0|(U-48&255)>>>0<10>>>0)){if(!((U<<24>>24|0)==95|(U<<24>>24|0)==45)){La=Fa;break}}U=Fa+1|0;if(U>>>0<Ga>>>0){Fa=U}else{La=U;break}}z:do{if((La|0)==(Ja|0)){P=313}else{c[y>>2]=La;if(!(La>>>0<Ga>>>0)){c[y>>2]=La;P=313;break}Fa=(a[La]|0)==58;U=La+(Fa&1)|0;c[y>>2]=U;if(Fa&U>>>0<Ga>>>0){Ma=U}else{P=313;break}while(1){Fa=a[Ma]|0;if(!((Fa<<24>>24|0)==32|(Fa<<24>>24|0)==9|(Fa<<24>>24|0)==13)){Na=Ma;break}Fa=Ma+1|0;c[y>>2]=Fa;if(Fa>>>0<Ga>>>0){Ma=Fa}else{Na=Fa;break}}if(!(Na>>>0>U>>>0)){P=313;break}Fa=La-Ja|0;do{if((Fa|0)==6){if((grc(Ja,2445808,4)|0)!=0){break}if(!(((a[Ja+4|0]|0)-48&255)>>>0<10>>>0)){break}if(((a[Ja+5|0]|0)-48&255)>>>0<10>>>0){P=146;break y}}}while(0);U=c[M>>2]|0;if((U|0)==(c[G>>2]|0)){Ea=U<<1;if((U|0)<1073741824&(Ea|0)<32){Oa=32}else{Oa=(U|0)>1073741823?2147483646:Ea}if((U|0)>=(Oa|0)){sa=-12;break w}Ea=jJb(c[x>>2]|0,Oa,20)|0;c[da>>2]=Ea;if((Ea|0)==0){sa=-12;break w}c[G>>2]=Oa;Pa=c[M>>2]|0;Qa=Ea}else{Pa=U;Qa=c[x>>2]|0}U=Pa*20|0;Ea=Qa+U|0;mrc(Ea|0,0,20)|0;c[M>>2]=(c[M>>2]|0)+1;if((Ea|0)==0){sa=-12;break w}c[Ea>>2]=Ja;c[Qa+(U+4)>>2]=Fa;Ea=c[y>>2]|0;Ba=c[w>>2]|0;do{if(Ea>>>0<Ba>>>0){V=(a[Ea]|0)==123;Aa=Ea+(V&1)|0;c[y>>2]=Aa;if(!V){break}A:do{if(Aa>>>0<Ba>>>0){V=Aa;while(1){T=a[V]|0;if(!((T<<24>>24|0)==32|(T<<24>>24|0)==9|(T<<24>>24|0)==13)){Ra=V;break A}T=V+1|0;c[y>>2]=T;if(T>>>0<Ba>>>0){V=T}else{Ra=T;break}}}else{Ra=Aa}}while(0);B:do{if(Ra>>>0<Ba>>>0){if((a[Ra]|0)==35){Sa=Ra}else{Ta=Ra;break}while(1){Aa=Sa+1|0;c[y>>2]=Aa;if(!(Aa>>>0<Ba>>>0)){Ta=Aa;break B}if((a[Aa]|0)==10){Ta=Aa;break}else{Sa=Aa}}}else{Ta=Ra}}while(0);C:do{if((Ta|0)!=(Ba|0)){if((a[Ta]|0)!=10){sa=-1094995529;break w}Aa=Ta+1|0;c[y>>2]=Aa;c[I>>2]=(c[I>>2]|0)+1;if(Aa>>>0<Ba>>>0){Ua=Aa}else{break}do{Aa=a[Ua]|0;if(!((Aa<<24>>24|0)==32|(Aa<<24>>24|0)==9|(Aa<<24>>24|0)==13)){break C}Ua=Ua+1|0;c[y>>2]=Ua;}while(Ua>>>0<Ba>>>0)}}while(0);Aa=c[E>>2]|0;do{V=kU(u,1)|0;if((V|0)<0){sa=V;break w}}while((V|0)!=0);Va=c[y>>2]|0;V=c[w>>2]|0;if(!(Va>>>0<V>>>0)){P=174;break y}fa=(a[Va]|0)==125;T=Va+(fa&1)|0;c[y>>2]=T;if(!fa){sa=-1094995529;break w}D:do{if(T>>>0<V>>>0){fa=T;while(1){ya=a[fa]|0;if(!((ya<<24>>24|0)==32|(ya<<24>>24|0)==9|(ya<<24>>24|0)==13)){Wa=fa;break D}ya=fa+1|0;c[y>>2]=ya;if(ya>>>0<V>>>0){fa=ya}else{Wa=ya;break}}}else{Wa=T}}while(0);E:do{if(Wa>>>0<V>>>0){if((a[Wa]|0)==35){Xa=Wa}else{Ya=Wa;break}while(1){T=Xa+1|0;c[y>>2]=T;if(!(T>>>0<V>>>0)){Ya=T;break E}if((a[T]|0)==10){Ya=T;break}else{Xa=T}}}else{Ya=Wa}}while(0);F:do{if((Ya|0)!=(V|0)){if((a[Ya]|0)!=10){sa=-1094995529;break w}T=Ya+1|0;c[y>>2]=T;c[I>>2]=(c[I>>2]|0)+1;if(T>>>0<V>>>0){Za=T}else{break}do{T=a[Za]|0;if(!((T<<24>>24|0)==32|(T<<24>>24|0)==9|(T<<24>>24|0)==13)){break F}Za=Za+1|0;c[y>>2]=Za;}while(Za>>>0<V>>>0)}}while(0);a[Qa+(U+16)|0]=66;c[Qa+(U+8)>>2]=Aa;V=c[E>>2]|0;c[Qa+(U+12)>>2]=V-Aa;_a=(V|0)==(Aa|0)?-1094995529:1;P=323;break z}else{c[y>>2]=Ea}}while(0);Ea=c[Da>>2]|0;Ba=Ea;G:while(1){if((Ba|0)==(c[H>>2]|0)){Fa=Ba<<1;if((Ba|0)<1073741824&(Fa|0)<32){$a=32}else{$a=(Ba|0)>1073741823?2147483646:Fa}if((Ba|0)>=($a|0)){sa=-12;break w}Fa=jJb(c[Ca>>2]|0,$a,24)|0;c[Ca>>2]=Fa;if((Fa|0)==0){sa=-12;break w}c[H>>2]=$a;ab=c[Da>>2]|0;bb=Fa}else{ab=Ba;bb=c[Ca>>2]|0}Fa=ab*24|0;V=bb+Fa|0;mrc(V|0,0,24)|0;T=(c[Da>>2]|0)+1|0;c[Da>>2]=T;if((V|0)==0){sa=-12;break w}fa=c[y>>2]|0;ya=c[w>>2]|0;if(fa>>>0<ya>>>0){za=(a[fa]|0)==45;xa=fa+(za&1)|0;c[y>>2]=xa;if(za){cb=xa}else{db=xa;P=201}}else{c[y>>2]=fa;db=fa;P=201}H:do{if((P|0)==201){P=0;fa=ya-db|0;do{if((fa|0)<4){if((fa|0)>=3){P=231}}else{if((grc(db,2397744,4)|0)==0){eb=db+4|0;c[y>>2]=eb;if(!(eb>>>0<ya>>>0)){P=204;break y}xa=(a[eb]|0)==47;za=db+(xa&1|4)|0;c[y>>2]=za;if(!xa){fb=-1094995529;P=290;break y}if((za|0)==(ya|0)){fb=-1094995529;P=290;break y}xa=a[za]|0;if((xa<<24>>24|0)==32|(xa<<24>>24|0)==9|(xa<<24>>24|0)==13|(xa<<24>>24|0)==10){fb=-1094995529;P=290;break y}gb=+frc(za,p);za=c[p>>2]|0;if(!(za>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;P=290;break y}c[y>>2]=za;hb=c[v>>2]|0;oa=gb*65536.0*.01;if(oa<-2147483648.0|oa>=2147483647.0){P=210;break y}c[bb+(Fa+12)>>2]=2;c[bb+(Fa+8)>>2]=~~oa;cb=za;break H}if((grc(db,2405064,4)|0)!=0){P=231;break}za=db+4|0;c[y>>2]=za;if((za|0)==(ya|0)){fb=-1094995529;P=290;break y}xa=a[za]|0;if((xa<<24>>24|0)==32|(xa<<24>>24|0)==9|(xa<<24>>24|0)==13|(xa<<24>>24|0)==10){fb=-1094995529;P=290;break y}ib=+frc(za,o);jb=c[o>>2]|0;if(!(jb>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;P=290;break y}c[y>>2]=jb;za=c[w>>2]|0;if(!(jb>>>0<za>>>0)){P=218;break y}xa=(a[jb]|0)==47;Y=jb+(xa&1)|0;c[y>>2]=Y;if(!xa){fb=-1094995529;P=290;break y}if((Y|0)==(za|0)){fb=-1094995529;P=290;break y}za=a[Y]|0;if((za<<24>>24|0)==32|(za<<24>>24|0)==9|(za<<24>>24|0)==13|(za<<24>>24|0)==10){fb=-1094995529;P=290;break y}kb=+frc(Y,n);Y=c[n>>2]|0;if(!(Y>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;P=290;break y}c[y>>2]=Y;lb=c[v>>2]|0;oa=kb*65536.0*.01;if(oa<-2147483648.0|oa>=2147483647.0){P=224;break y}na=ib*65536.0;if(na<-2147483648.0|na>=2147483647.0){P=227;break y}c[bb+(Fa+12)>>2]=3;c[V>>2]=~~na;c[bb+(Fa+8)>>2]=~~oa;cb=Y;break H}}while(0);do{if((P|0)==231){P=0;if((grc(db,2412648,3)|0)==0){mb=db+3|0;c[y>>2]=mb;if(!(mb>>>0<ya>>>0)){P=233;break y}Y=(a[mb]|0)==47;za=db+(Y?4:3)|0;c[y>>2]=za;if(!Y){fb=-1094995529;P=290;break y}if((za|0)==(ya|0)){fb=-1094995529;P=290;break y}Y=a[za]|0;if((Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==13|(Y<<24>>24|0)==10){fb=-1094995529;P=290;break y}nb=+frc(za,m);za=c[m>>2]|0;if(!(za>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;P=290;break y}c[y>>2]=za;ob=c[v>>2]|0;oa=nb*65536.0*.01;if(oa<-2147483648.0|oa>=2147483647.0){P=239;break y}c[bb+(Fa+12)>>2]=4;c[bb+(Fa+8)>>2]=~~oa;cb=za;break H}if((fa|0)<5){break}if((grc(db,2423488,5)|0)!=0){break}za=db+5|0;c[y>>2]=za;if((za|0)==(ya|0)){fb=-1094995529;P=290;break y}Y=a[za]|0;if((Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==13|(Y<<24>>24|0)==10){fb=-1094995529;P=290;break y}pb=+frc(za,l);za=c[l>>2]|0;if(!(za>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;P=290;break y}c[y>>2]=za;if((za|0)==(c[w>>2]|0)){fb=-1094995529;P=290;break y}Y=a[za]|0;if((Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==13|(Y<<24>>24|0)==10){fb=-1094995529;P=290;break y}qb=+frc(za,k);sb=c[k>>2]|0;if(!(sb>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;P=290;break y}c[y>>2]=sb;za=c[w>>2]|0;if(!(sb>>>0<za>>>0)){P=251;break y}Y=(a[sb]|0)==47;xa=sb+(Y&1)|0;c[y>>2]=xa;if(!Y){fb=-1094995529;P=290;break y}if((xa|0)==(za|0)){fb=-1094995529;P=290;break y}za=a[xa]|0;if((za<<24>>24|0)==32|(za<<24>>24|0)==9|(za<<24>>24|0)==13|(za<<24>>24|0)==10){fb=-1094995529;P=290;break y}tb=+frc(xa,j);xa=c[j>>2]|0;if(!(xa>>>0>(c[y>>2]|0)>>>0)){fb=-1094995529;P=290;break y}c[y>>2]=xa;ub=c[v>>2]|0;oa=tb*65536.0*.01;if(oa<-2147483648.0|oa>=2147483647.0){P=257;break y}na=pb*65536.0;if(na<-2147483648.0|na>=2147483647.0){P=260;break y}vb=qb*65536.0;if(vb<-2147483648.0|vb>=2147483647.0){P=263;break y}c[bb+(Fa+12)>>2]=5;c[V>>2]=~~na;c[bb+(Fa|4)>>2]=~~vb;c[bb+(Fa+8)>>2]=~~oa;cb=xa;break H}}while(0);if((db|0)==(ya|0)){wb=ya;xb=T;yb=ya;P=291;break G}fa=a[db]|0;if((fa<<24>>24|0)==32|(fa<<24>>24|0)==9|(fa<<24>>24|0)==13|(fa<<24>>24|0)==10){wb=db;xb=T;yb=ya;P=291;break G}zb=+frc(db,s);fa=c[s>>2]|0;Ab=c[y>>2]|0;if(!(fa>>>0>Ab>>>0)){P=269;break G}c[y>>2]=fa;do{if((fa|0)==(c[w>>2]|0)){Bb=0.0;Cb=fa}else{xa=a[fa]|0;if((xa<<24>>24|0)==32|(xa<<24>>24|0)==9|(xa<<24>>24|0)==13|(xa<<24>>24|0)==10){Bb=0.0;Cb=fa;break}oa=+frc(fa,r);xa=c[r>>2]|0;za=c[y>>2]|0;if(!(xa>>>0>za>>>0)){Bb=0.0;Cb=za;break}c[y>>2]=xa;Bb=oa;Cb=xa}}while(0);fa=c[w>>2]|0;if(!(Cb>>>0<fa>>>0)){P=275;break y}xa=(a[Cb]|0)==47;za=Cb+(xa&1)|0;c[y>>2]=za;if(!xa){P=292;break y}if((za|0)==(fa|0)){Db=-1094995529;P=293;break y}fa=a[za]|0;if((fa<<24>>24|0)==32|(fa<<24>>24|0)==9|(fa<<24>>24|0)==13|(fa<<24>>24|0)==10){Db=-1094995529;P=293;break y}Eb=+frc(za,q);za=c[q>>2]|0;if(!(za>>>0>(c[y>>2]|0)>>>0)){Db=-1094995529;P=293;break y}c[y>>2]=za;Fb=c[v>>2]|0;oa=Eb*65536.0*.01;if(oa<-2147483648.0|oa>=2147483647.0){P=281;break y}vb=zb*65536.0;if(vb<-2147483648.0|vb>=2147483647.0){P=284;break y}na=Bb*65536.0;if(na<-2147483648.0|na>=2147483647.0){P=287;break y}c[bb+(Fa+12)>>2]=1;c[V>>2]=~~vb;c[bb+(Fa|4)>>2]=~~na;c[bb+(Fa+8)>>2]=~~oa;cb=za}}while(0);Fa=c[w>>2]|0;if(cb>>>0<Fa>>>0){Gb=cb}else{Hb=cb;Ib=Fa;break}while(1){V=a[Gb]|0;if(!((V<<24>>24|0)==32|(V<<24>>24|0)==9|(V<<24>>24|0)==13)){Jb=Gb;break}V=Gb+1|0;c[y>>2]=V;if(V>>>0<Fa>>>0){Gb=V}else{Jb=V;break}}if(!(Jb>>>0>cb>>>0)){Hb=Jb;Ib=Fa;break}Ba=c[Da>>2]|0}if((P|0)==269){P=0;wb=Ab;xb=c[Da>>2]|0;yb=c[w>>2]|0;P=291}if((P|0)==291){P=0;c[Da>>2]=xb-1;Hb=wb;Ib=yb}I:do{if(Hb>>>0<Ib>>>0){Ba=Hb;while(1){V=a[Ba]|0;if(!((V<<24>>24|0)==32|(V<<24>>24|0)==9|(V<<24>>24|0)==13)){Kb=Ba;break I}V=Ba+1|0;c[y>>2]=V;if(V>>>0<Ib>>>0){Ba=V}else{Kb=V;break}}}else{Kb=Hb}}while(0);if((Ea|0)==(c[Da>>2]|0)){sa=-1094995529;break w}J:do{if(Kb>>>0<Ib>>>0){if((a[Kb]|0)==35){Lb=Kb}else{Mb=Kb;break}while(1){Ba=Lb+1|0;c[y>>2]=Ba;if(!(Ba>>>0<Ib>>>0)){Mb=Ba;break J}if((a[Ba]|0)==10){Mb=Ba;break}else{Lb=Ba}}}else{Mb=Kb}}while(0);K:do{if((Mb|0)!=(Ib|0)){if((a[Mb]|0)!=10){sa=-1094995529;break w}Ba=Mb+1|0;c[y>>2]=Ba;c[I>>2]=(c[I>>2]|0)+1;if(Ba>>>0<Ib>>>0){Nb=Ba}else{break}do{Ba=a[Nb]|0;if(!((Ba<<24>>24|0)==32|(Ba<<24>>24|0)==9|(Ba<<24>>24|0)==13)){break K}Nb=Nb+1|0;c[y>>2]=Nb;}while(Nb>>>0<Ib>>>0)}}while(0);a[Qa+(U+16)|0]=83;c[Qa+(U+8)>>2]=Ea;c[Qa+(U+12)>>2]=(c[Da>>2]|0)-Ea}}while(0);L:do{if((P|0)==313){P=0;c[y>>2]=Ja;Ba=kU(u,0)|0;if((Ba|0)!=0){_a=Ba;P=323;break}Ba=c[y>>2]|0;Fa=c[w>>2]|0;M:do{if(Ba>>>0<Fa>>>0){if((a[Ba]|0)==35){Pb=Ba}else{Qb=Ba;break}while(1){V=Pb+1|0;c[y>>2]=V;if(!(V>>>0<Fa>>>0)){Qb=V;break M}if((a[V]|0)==10){Qb=V;break}else{Pb=V}}}else{Qb=Ba}}while(0);if((Qb|0)==(Fa|0)){break}if((a[Qb]|0)!=10){sa=-1094995529;break w}Ba=Qb+1|0;c[y>>2]=Ba;c[I>>2]=(c[I>>2]|0)+1;if(Ba>>>0<Fa>>>0){Sb=Ba}else{break}do{Ba=a[Sb]|0;if(!((Ba<<24>>24|0)==32|(Ba<<24>>24|0)==9|(Ba<<24>>24|0)==13)){break L}Sb=Sb+1|0;c[y>>2]=Sb;}while(Sb>>>0<Fa>>>0)}}while(0);if((P|0)==323){P=0;if((_a|0)<0){sa=_a;break w}}Ja=c[y>>2]|0;Ga=c[w>>2]|0;if(!(Ja>>>0<Ga>>>0)){break x}}do{if((P|0)==146){Rb(J|0,128,2390600,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka;sa=-1163346256;break w}else if((P|0)==174){c[y>>2]=Va;sa=-1094995529;break w}else if((P|0)==204){c[y>>2]=eb;fb=-1094995529;P=290}else if((P|0)==210){if((hb|0)==0){fb=-34;P=290;break}KIb(hb,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=gb,Ka)|0);i=Ka;fb=-34;P=290}else if((P|0)==218){c[y>>2]=jb;fb=-1094995529;P=290}else if((P|0)==224){if((lb|0)==0){fb=-34;P=290;break}KIb(lb,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=kb,Ka)|0);i=Ka;fb=-34;P=290}else if((P|0)==227){if((lb|0)==0){fb=-33;P=290;break}KIb(lb,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=ib,Ka)|0);i=Ka;fb=-33;P=290}else if((P|0)==233){c[y>>2]=mb;fb=-1094995529;P=290}else if((P|0)==239){if((ob|0)==0){fb=-34;P=290;break}KIb(ob,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=nb,Ka)|0);i=Ka;fb=-34;P=290}else if((P|0)==251){c[y>>2]=sb;fb=-1094995529;P=290}else if((P|0)==257){if((ub|0)==0){fb=-34;P=290;break}KIb(ub,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=tb,Ka)|0);i=Ka;fb=-34;P=290}else if((P|0)==260){if((ub|0)==0){fb=-33;P=290;break}KIb(ub,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=pb,Ka)|0);i=Ka;fb=-33;P=290}else if((P|0)==263){if((ub|0)==0){fb=-33;P=290;break}KIb(ub,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=qb,Ka)|0);i=Ka;fb=-33;P=290}else if((P|0)==275){c[y>>2]=Cb;P=292}else if((P|0)==281){if((Fb|0)==0){Db=-34;P=293;break}KIb(Fb,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=Eb,Ka)|0);i=Ka;Db=-34;P=293}else if((P|0)==284){if((Fb|0)==0){fb=-33;P=290;break}KIb(Fb,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=zb,Ka)|0);i=Ka;fb=-33;P=290}else if((P|0)==287){if((Fb|0)==0){fb=-33;P=290;break}KIb(Fb,16,2432104,(Ka=i,i=i+8|0,h[Ka>>3]=Bb,Ka)|0);i=Ka;fb=-33;P=290}}while(0);if((P|0)==290){c[Da>>2]=(c[Da>>2]|0)-1;sa=fb;break w}else if((P|0)==292){c[Da>>2]=(c[Da>>2]|0)-1;sa=-1094995529;break w}else if((P|0)==293){c[Da>>2]=(c[Da>>2]|0)-1;sa=Db;break w}}}while(0);nrc(f|0,A|0,88)|0;Tb=1;i=g;return Tb|0}}while(0);mJb(A);mJb(u+20|0);mJb(u+24|0);mJb(u+28|0);mJb(u+32|0);mJb(u+88|0);if((a[J]|0)==0&(sa|0)==-1094995529){Rb(J|0,128,2553480,(Ka=i,i=i+1|0,i=i+7&-8,c[Ka>>2]=0,Ka)|0)|0;i=Ka}if((b|0)==0){Tb=sa;i=g;return Tb|0}if((a[J]|0)==0){Tb=sa;i=g;return Tb|0}u=c[y>>2]|0;y=c[w>>2]|0;w=u;A=Ob(u|0,10,y-w|0)|0;f=((A|0)!=0?A:y)-w|0;if((f|0)>0){w=f-1|0;Ub=(a[u+w|0]|0)==13?w:f}else{Ub=f}f=(Ub|0)==0;w=f?10230584:2535432;KIb(b,16,2491592,(Ka=i,i=i+48|0,c[Ka>>2]=c[I>>2],c[Ka+8>>2]=J,c[Ka+16>>2]=w,c[Ka+24>>2]=f?15:Ub,c[Ka+32>>2]=f?2519712:u,c[Ka+40>>2]=w,Ka)|0);i=Ka;Tb=sa;i=g;return Tb|0}function hU(a,b,d,e,f,g,h,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;m=i;i=i+56|0;n=m|0;if(!((h|0)>(f|0)|(h|0)==(f|0)&g>>>0>e>>>0)){o=0;i=m;return o|0}p=j+8|0;q=c[p>>2]|0;do{if((q|0)==0){if((c[k+8>>2]|0)==0){o=0}else{break}i=m;return o|0}}while(0);r=c[j+12>>2]|0;switch(r|0){case 2:{s=q;break};case 5:{KIb(a,24,2257368,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=c[p>>2]|0;break};case 1:{u=j+4|0;v=c[u>>2]|0;w=c[k+4>>2]|0;x=c[j+16>>2]|0;y=j|0;z=c[y>>2]|0;if((v|w|0)==0){A=iU(d,1162758483,3,x,e,f,z,q,g,h,c[k>>2]|0,c[k+8>>2]|0)|0;if((A|0)<0){o=A;i=m;return o|0}c[k+20>>2]=A;c[k+16>>2]=A;o=0;i=m;return o|0}A=k|0;B=k+8|0;C=iU(d,1162758483,1,x,e,f,((v|0)/2|0)+z|0,q,g,h,((w|0)/2|0)+(c[A>>2]|0)|0,c[B>>2]|0)|0;if((C|0)<0){o=C;i=m;return o|0}c[k+16>>2]=C;C=iU(d,1162758483,2,c[j+20>>2]|0,e,f,(c[y>>2]|0)-((c[u>>2]|0)/2|0)|0,c[p>>2]|0,g,h,(c[A>>2]|0)-((c[k+4>>2]|0)/2|0)|0,c[B>>2]|0)|0;if((C|0)<0){o=C;i=m;return o|0}c[k+20>>2]=C;o=0;i=m;return o|0};case 0:{o=0;i=m;return o|0};case 3:{if((l|0)!=2){o=0;i=m;return o|0}l=c[j>>2]|0;C=c[k+8>>2]|0;B=c[b+76>>2]|0;c[n>>2]=2;c[n+4>>2]=C;c[n+8>>2]=4;b=(C|0)/4|0;c[n+12>>2]=C-b;c[n+16>>2]=8;c[n+20>>2]=(C|0)/2|0;c[n+24>>2]=16;c[n+28>>2]=b;c[n+32>>2]=25;c[n+36>>2]=(C|0)/10|0;c[n+40>>2]=50;c[n+44>>2]=(C|0)/80|0;c[n+48>>2]=75;c[n+52>>2]=0;b=(B|0)/20|0;B=b;A=(b|0)<0|0?-1:0;b=1;p=C;u=f;y=e;w=0;q=2;z=C;while(1){C=Erc(q,w,B,A)|0;v=wrc(C,G,e,f)|0;C=G;x=(C|0)<(h|0)|(C|0)==(h|0)&v>>>0<g>>>0;D=x?v:g;v=x?C:h;C=iU(d,1162758483,3,-1,y,u,l,p,D,v,l,z)|0;if((C|0)<0){o=C;E=20;break}if(!(b>>>0<7>>>0)){o=0;E=20;break}C=c[n+(b<<3)>>2]|0;x=c[n+(b<<3)+4>>2]|0;b=b+1|0;p=z;u=v;y=D;w=(C|0)<0|0?-1:0;q=C;z=x}if((E|0)==20){i=m;return o|0}break};default:{KIb(a,16,2212360,(t=i,i=i+8|0,c[t>>2]=r,t)|0);i=t;o=-1163346256;i=m;return o|0}}t=c[k+8>>2]|0;r=iU(d,1397313358,3,c[j+16>>2]|0,e,f,0,s-((s|0)/4|0)|0,g,h,0,t-((t|0)/4|0)|0)|0;if((r|0)<0){o=r;i=m;return o|0}c[k+20>>2]=r;c[k+16>>2]=r;o=0;i=m;return o|0}function iU(a,b,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=(e|0)>-1;o=a|0;do{if(n){p=c[o>>2]|0;if((c[p+(e*48|0)+16>>2]|0)!=(b|0)){break}if((c[p+(e*48|0)+20>>2]|0)!=(d|0)){break}q=c[p+(e*48|0)+28>>2]|0;if(!((c[p+(e*48|0)+24>>2]|0)==(q|0)&(q|0)==(h|0)&(h|0)==(l|0))){break}q=c[p+(e*48|0)+36>>2]|0;if(!((c[p+(e*48|0)+32>>2]|0)==(q|0)&(q|0)==(i|0)&(i|0)==(m|0))){break}q=p+(e*48|0)+8|0;if(!((c[q>>2]|0)==(f|0)&(c[q+4>>2]|0)==(g|0))){break}c[q>>2]=j;c[q+4>>2]=k;r=e;return r|0}}while(0);q=a;p=a+4|0;s=a+8|0;a=c[p>>2]|0;do{if((a|0)==(c[s>>2]|0)){t=a<<1;if((a|0)<1073741824&(t|0)<32){u=32}else{u=(a|0)>1073741823?2147483646:t}if((a|0)>=(u|0)){r=-12;return r|0}t=jJb(c[q>>2]|0,u,48)|0;c[o>>2]=t;if((t|0)==0){r=-12;return r|0}else{c[s>>2]=u;v=c[p>>2]|0;w=t;break}}else{v=a;w=c[q>>2]|0}}while(0);q=v*48|0;v=w+q|0;mrc(v|0,0,48)|0;c[p>>2]=(c[p>>2]|0)+1;if((v|0)==0){r=-12;return r|0}p=v;c[p>>2]=f;c[p+4>>2]=g;g=w+(q|8)|0;c[g>>2]=j;c[g+4>>2]=k;c[w+(q+16)>>2]=b;c[w+(q+20)>>2]=d;c[w+(q+24)>>2]=h;c[w+(q+28)>>2]=l;c[w+(q+32)>>2]=i;c[w+(q+36)>>2]=m;c[w+(q+40)>>2]=n?e|-2147483648:0;r=(v-(c[o>>2]|0)|0)/48|0;return r|0}function jU(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;k=h+24|0;l=c[k>>2]|0;c[k>>2]=l+1;if((l|0)!=0){l=c[h+16>>2]|0;KIb(b,16,2151896,(m=i,i=i+16|0,c[m>>2]=c[h+20>>2],c[m+8>>2]=l,m)|0);i=m;n=-22;i=j;return n|0}l=h|0;o=wrc(c[l>>2]|0,c[l+4>>2]|0,f,g)|0;g=G;f=c[d+20>>2]|0;a:do{if((f|0)>0){p=c[d>>2]|0;q=c[h+20>>2]|0;r=h+16|0;s=0;while(1){if((c[p+(s*20|0)+4>>2]|0)==(q|0)){if((grc(c[p+(s*20|0)>>2]|0,c[r>>2]|0,q)|0)==0){t=s;break a}}u=s+1|0;if((u|0)<(f|0)){s=u}else{t=u;break}}}else{t=0}}while(0);if((t|0)>=(f|0)){f=c[h+16>>2]|0;KIb(b,16,2127344,(m=i,i=i+16|0,c[m>>2]=c[h+20>>2],c[m+8>>2]=f,m)|0);i=m;n=-22;i=j;return n|0}m=c[d>>2]|0;b:do{if((a[m+(t*20|0)+16|0]|0)==66){f=c[d+12>>2]|0;s=c[m+(t*20|0)+8>>2]|0;q=m+(t*20|0)+12|0;r=0;while(1){if((r|0)>=(c[q>>2]|0)){break b}p=jU(b,d,e,o,g,f+(r+s<<5)|0)|0;if((p|0)<0){n=p;break}else{r=r+1|0}}i=j;return n|0}else{r=d+16|0;s=d+28|0;f=c[s>>2]|0;if((f|0)==(c[e>>2]|0)){q=f<<1;if((f|0)<1073741824&(q|0)<32){v=32}else{v=(f|0)>1073741823?2147483646:q}q=jJb(c[r>>2]|0,v,48)|0;c[r>>2]=q;c[e>>2]=v;w=c[s>>2]|0;x=q}else{w=f;x=c[r>>2]|0}r=w*48|0;f=x+r|0;mrc(f|0,0,48)|0;c[s>>2]=(c[s>>2]|0)+1;s=c[l+4>>2]|0;q=f;c[q>>2]=c[l>>2];c[q+4>>2]=s;c[x+(r+32)>>2]=c[m+(t*20|0)+8>>2];c[x+(r+36)>>2]=c[m+(t*20|0)+12>>2];s=x+(r+40)|0;r=h+28|0;a[s]=a[r]|0;a[s+1|0]=a[r+1|0]|0;a[s+2|0]=a[r+2|0]|0}}while(0);c[k>>2]=(c[k>>2]|0)-1;n=0;i=j;return n|0}function kU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;c[f>>2]=0;c[f+4>>2]=0;j=b+8|0;k=c[j>>2]|0;l=b+12|0;m=c[l>>2]|0;do{if((k-m|0)<3){n=4}else{if((grc(m,2462840,3)|0)!=0){n=4;break}o=m+3|0;c[l>>2]=o;p=1;q=78;r=o;s=k}}while(0);if((n|0)==4){k=lU(m,f)|0;m=(c[l>>2]|0)+k|0;c[l>>2]=m;o=(k|0)>0;p=o&1;q=o?84:0;r=m;s=c[j>>2]|0}a:do{if(r>>>0<s>>>0){m=0;o=0;k=p;t=r;u=s;while(1){v=(a[t]|0)==43;w=t+(v&1)|0;c[l>>2]=w;if(!v){x=m;y=o;z=k;A=w;B=u;break a}v=lU(w,g)|0;w=(c[l>>2]|0)+v|0;c[l>>2]=w;if((v|0)<=0){C=-1094995529;break}v=wrc(c[g>>2]|0,c[g+4>>2]|0,o,m)|0;D=G;E=c[j>>2]|0;if(w>>>0<E>>>0){m=D;o=v;k=1;t=w;u=E}else{F=D;H=v;I=1;J=w;K=E;n=6;break a}}i=e;return C|0}else{F=0;H=0;I=p;J=r;K=s;n=6}}while(0);if((n|0)==6){c[l>>2]=J;x=F;y=H;z=I;A=J;B=K}if((z|0)==0){C=0;i=e;return C|0}if(A>>>0<B>>>0){L=A}else{C=-1094995529;i=e;return C|0}while(1){z=a[L]|0;if(!((z<<24>>24|0)==32|(z<<24>>24|0)==9|(z<<24>>24|0)==13)){M=L;break}z=L+1|0;c[l>>2]=z;if(z>>>0<B>>>0){L=z}else{M=z;break}}if(!(M>>>0>A>>>0)){C=-1094995529;i=e;return C|0}A=c[f>>2]|0;L=c[f+4>>2]|0;f=(d|0)!=0;do{if(q<<24>>24==0){d=a[b+112|0]|0;if(!(d<<24>>24==0&(f^1))){N=d;break}Rb(b+144|0,128,2480704,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0)|0;i=d;C=-1094995529;i=e;return C|0}else{if(f){C=-1094995529;i=e;return C|0}else{a[b+112|0]=q;d=b+104|0;c[d>>2]=A;c[d+4>>2]=L;N=q;break}}}while(0);q=b+104|0;L=wrc(c[q>>2]|0,c[q+4>>2]|0,y,x)|0;x=G;if(M>>>0<B>>>0){y=(a[M]|0)==60;q=M+(y&1)|0;c[l>>2]=q;if(y){O=0;P=q;n=29}else{Q=q;n=23}}else{c[l>>2]=M;Q=M;n=23}do{if((n|0)==23){if(Q>>>0<B>>>0){M=(a[Q]|0)==45;q=Q+(M&1)|0;c[l>>2]=q;if(M){O=1;P=q;n=29;break}else{R=q}}else{c[l>>2]=Q;R=Q}if(R>>>0<B>>>0){q=(a[R]|0)==61;M=R+(q&1)|0;c[l>>2]=M;if(q){O=3;P=M;n=29;break}else{S=1;T=1;U=M;break}}else{c[l>>2]=R;S=1;T=1;U=R;break}}}while(0);do{if((n|0)==29){if(P>>>0<B>>>0){R=(a[P]|0)==62;Q=P+(R&1)|0;c[l>>2]=Q;if(R){S=O;T=0;U=Q;break}else{V=Q}}else{c[l>>2]=P;V=P}if(V>>>0<B>>>0){Q=(a[V]|0)==45;R=V+(Q&1)|0;c[l>>2]=R;if(Q){S=O;T=1;U=R;break}else{W=R}}else{c[l>>2]=V;W=V}if(W>>>0<B>>>0){R=(a[W]|0)==61;Q=W+(R&1)|0;c[l>>2]=Q;if(R){S=O;T=3;U=Q;break}else{C=-1094995529}i=e;return C|0}else{c[l>>2]=W;C=-1094995529;i=e;return C|0}}}while(0);b:do{if(U>>>0<B>>>0){W=U;while(1){O=a[W]|0;if(!((O<<24>>24|0)==32|(O<<24>>24|0)==9|(O<<24>>24|0)==13)){X=W;break b}O=W+1|0;c[l>>2]=O;if(O>>>0<B>>>0){W=O}else{X=O;break}}}else{X=U}}while(0);if(X>>>0<B>>>0){Y=X}else{C=-1094995529;i=e;return C|0}while(1){U=a[Y]|0;if(!((U-97&255)>>>0<26>>>0|(U-65&255)>>>0<26>>>0|(U-48&255)>>>0<10>>>0)){if(!((U<<24>>24|0)==95|(U<<24>>24|0)==45)){Z=Y;break}}U=Y+1|0;if(U>>>0<B>>>0){Y=U}else{Z=U;break}}if((Z|0)==(X|0)){C=-1094995529;i=e;return C|0}c[l>>2]=Z;c:do{if(Z>>>0<B>>>0){Y=Z;while(1){U=a[Y]|0;if(!((U<<24>>24|0)==32|(U<<24>>24|0)==9|(U<<24>>24|0)==13)){_=Y;break c}U=Y+1|0;c[l>>2]=U;if(U>>>0<B>>>0){Y=U}else{_=U;break}}}else{_=Z}}while(0);d:do{if((B-_|0)<2){$=0;aa=_}else{if((grc(_,2470544,2)|0)!=0){$=0;aa=_;break}Y=_+2|0;c[l>>2]=Y;if(Y>>>0<B>>>0){ba=Y}else{$=3;aa=Y;break}while(1){Y=a[ba]|0;if(!((Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==13)){$=3;aa=ba;break d}Y=ba+1|0;c[l>>2]=Y;if(Y>>>0<B>>>0){ba=Y}else{$=3;aa=Y;break}}}}while(0);e:do{if(aa>>>0<B>>>0){if((a[aa]|0)==35){ca=aa}else{da=aa;break}while(1){ba=ca+1|0;c[l>>2]=ba;if(!(ba>>>0<B>>>0)){da=ba;break e}if((a[ba]|0)==10){da=ba;break}else{ca=ba}}}else{da=aa}}while(0);f:do{if((da|0)!=(B|0)){if((a[da]|0)!=10){C=-1094995529;i=e;return C|0}aa=da+1|0;c[l>>2]=aa;ca=b+140|0;c[ca>>2]=(c[ca>>2]|0)+1;if(aa>>>0<B>>>0){ea=aa}else{break}do{aa=a[ea]|0;if(!((aa<<24>>24|0)==32|(aa<<24>>24|0)==9|(aa<<24>>24|0)==13)){break f}ea=ea+1|0;c[l>>2]=ea;}while(ea>>>0<B>>>0)}}while(0);if(f){f=b+28|0;B=b+120|0;ea=b+136|0;l=c[B>>2]|0;do{if((l|0)==(c[ea>>2]|0)){da=l<<1;if((l|0)<1073741824&(da|0)<32){fa=32}else{fa=(l|0)>1073741823?2147483646:da}if((l|0)>=(fa|0)){C=-12;i=e;return C|0}da=jJb(c[f>>2]|0,fa,32)|0;c[f>>2]=da;if((da|0)==0){C=-12;i=e;return C|0}else{c[ea>>2]=fa;ga=c[B>>2]|0;ha=da;break}}else{ga=l;ha=c[f>>2]|0}}while(0);f=ha+(ga<<5)|0;mrc(f|0,0,32)|0;c[B>>2]=(c[B>>2]|0)+1;ia=f}else{f=b+24|0;B=b+40|0;ga=b+132|0;b=c[B>>2]|0;do{if((b|0)==(c[ga>>2]|0)){ha=b<<1;if((b|0)<1073741824&(ha|0)<32){ja=32}else{ja=(b|0)>1073741823?2147483646:ha}if((b|0)>=(ja|0)){C=-12;i=e;return C|0}ha=jJb(c[f>>2]|0,ja,32)|0;c[f>>2]=ha;if((ha|0)==0){C=-12;i=e;return C|0}else{c[ga>>2]=ja;ka=c[B>>2]|0;la=ha;break}}else{ka=b;la=c[f>>2]|0}}while(0);f=la+(ka<<5)|0;mrc(f|0,0,32)|0;c[B>>2]=(c[B>>2]|0)+1;ia=f}if((ia|0)==0){C=-12;i=e;return C|0}f=ia;c[f>>2]=L;c[f+4>>2]=x;a[ia+8|0]=N;N=ia+9|0;x=h|0;a[N]=a[x]|0;a[N+1|0]=a[x+1|0]|0;a[N+2|0]=a[x+2|0]|0;a[N+3|0]=a[x+3|0]|0;a[N+4|0]=a[x+4|0]|0;a[N+5|0]=a[x+5|0]|0;a[N+6|0]=a[x+6|0]|0;c[ia+16>>2]=X;c[ia+20>>2]=Z-X;a[ia+28|0]=S;a[ia+29|0]=T;a[ia+30|0]=$;C=1;i=e;return C|0}function lU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0,p=0;e=i;i=i+8|0;f=e|0;if(((a[b]|0)-48&255)>>>0>9>>>0){g=0;i=e;return g|0}h=rb(b|0,f|0,10)|0;j=c[f>>2]|0;if((j|0)==(b|0)){g=0;i=e;return g|0}if((a[j]|0)!=58){g=0;i=e;return g|0}k=j+1|0;if(((a[k]|0)-48&255)>>>0>9>>>0){g=0;i=e;return g|0}j=rb(k|0,f|0,10)|0;l=c[f>>2]|0;if((l|0)==(k|0)){g=0;i=e;return g|0}if((a[l]|0)==58){k=l+1|0;m=+frc(k,f);n=c[f>>2]|0;o=m;p=n>>>0>k>>>0?n:l}else{o=0.0;p=l}m=(+((j*60|0)+(h*3600|0)|0)+o)*1.0e6;h=(F=+m,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[d>>2]=~~+m>>>0;c[d+4>>2]=h;g=p-b|0;i=e;return g|0}function mU(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=i;i=i+32|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;r=c[e+8>>2]|0;e=R$(l,r,f)|0;f=c[r+8>>2]|0;if((f|0)==1){s=2471640}else if((f|0)==3){s=2377880}else if((f|0)==0){s=2107072}else{s=2309760}EFb(b,d,2257232,(f=i,i=i+24|0,c[f>>2]=s,c[f+8>>2]=j,c[f+16>>2]=e,f)|0)|0;i=f;a:do{if((g|0)!=0){j=(h|0)==0?2104160:h;do{if((k|0)>0){if((irc(j,2104160)|0)!=0){break}EFb(b,d,2181392,(f=i,i=i+24|0,c[f>>2]=j,c[f+8>>2]=g,c[f+16>>2]=k,f)|0)|0;i=f;break a}}while(0);EFb(b,d,2179208,(f=i,i=i+16|0,c[f>>2]=j,c[f+8>>2]=g,f)|0)|0;i=f}}while(0);g=c[r+72>>2]|0;if((g|0)!=0){EFb(b,d,2212248,(f=i,i=i+8|0,c[f>>2]=(g|0)/1e3|0,f)|0)|0;i=f}g=r+48|0;k=c[g>>2]|0;b:do{if((k|0)==86076){h=c[r+412>>2]|0;s=(c[r+432>>2]|0)==38?20:30;EFb(b,d,2253408,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=h,c[f+16>>2]=e,c[f+24>>2]=s,f)|0)|0;i=f;t=0}else if((k|0)==86052){s=c[r+412>>2]|0;EFb(b,d,2242624,(f=i,i=i+16|0,c[f>>2]=e,c[f+8>>2]=s,f)|0)|0;i=f;if((c[r+12>>2]|0)==0){t=0;break}if((c[r+88>>2]&2|0)==0){s=(OJb(r,2232616,1,q)|0)==0;u=s&((c[q>>2]|0)!=0|(c[q+4>>2]|0)!=0)?2232616:2228632}else{u=2236312}EFb(b,d,2224696,(f=i,i=i+16|0,c[f>>2]=e,c[f+8>>2]=u,f)|0)|0;i=f;t=0}else if((k|0)==65542){if((e|0)<=95){t=0;break}s=c[r+412>>2]|0;h=c[r+416>>2]|0;EFb(b,d,2334976,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=s,c[f+16>>2]=h,f)|0)|0;i=f;t=0}else if((k|0)==1330664787){EFb(b,d,2220512,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==28){do{if((l|0)==0){v=1}else{h=c[l+8>>2]|0;if((h|0)==0){v=1;break}if((c[h+36>>2]|0)==0){v=1;break}v=(PJb(c[l+12>>2]|0,2432088,2423464)|0)==0|0}}while(0);j=r+100|0;h=c[j>>2]|0;c:do{if((h|0)==0){w=0}else{if((h|0)>1073741818){KIb(r,16,2196136,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;w=0;break}s=r+96|0;do{if((a[c[s>>2]|0]|0)==1){x=e3(2191e3)|0;if((x|0)==0){KIb(r,16,2188536,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;w=0;break c}y=c[j>>2]|0;z=pJb(y+16|0)|0;if((z|0)==0){f3(x);w=0;break c}else{nrc(z|0,c[s>>2]|0,y)|0;g3(x,r,0,o,p,0,0,0)|0;f3(x);A=y;B=z;break}}else{A=0;B=0}}while(0);z=pJb(1024)|0;if((z|0)==0){KIb(r,16,2185848,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;kJb(B);w=0;break}nrc(z|0,1488472,23)|0;y=z+23|0;x=c[s>>2]|0;C=z;D=y;E=n$(x,x+(c[j>>2]|0)|0)|0;x=0;F=0;d:while(1){G=E;do{H=(c[s>>2]|0)+(c[j>>2]|0)|0;if(G>>>0<H>>>0){I=G}else{break d}while(1){J=I+1|0;if((a[I]|0)==0){I=J}else{break}}K=a[J]&31;G=n$(J,H)|0;}while(!((K-7&255)>>>0<2>>>0));if((D|0)==(y|0)){L=y}else{a[D]=44;L=D+1|0}K=(F|0)==0;M=C-L+1024|0;N=G-J|0;if((RFb(L,M,J,N)|0)==0){O=36;break}D=L+(lrc(L|0)|0)|0;E=G;x=K?G:x;F=K?J:F}if((O|0)==36){KIb(r,16,2183672,(f=i,i=i+16|0,c[f>>2]=M,c[f+8>>2]=N,f)|0);i=f;kJb(z);w=0;break}do{if((F|0)!=0){if((x-F|0)<=3){break}nrc(D|0,1488496,19)|0;E=lrc(D|0)|0;lY(D+E|0,F+1|0,3,0)|0;a[D+(E+6)|0]=0}}while(0);if((B|0)==0){w=z;break}kJb(c[s>>2]|0);c[s>>2]=B;c[j>>2]=A;w=z}}while(0);EFb(b,d,2412568,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=e,c[f+16>>2]=v,c[f+24>>2]=(w|0)!=0?w:10230416,f)|0)|0;i=f;t=w}else if((k|0)==141){EFb(b,d,2268808,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==8){if((e|0)<=95){t=0;break}EFb(b,d,2264880,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==65537){if((e|0)<=95){t=0;break}j=c[r+412>>2]|0;h=c[r+416>>2]|0;EFb(b,d,2340656,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=j,c[f+16>>2]=h,f)|0)|0;i=f;t=0}else if((k|0)==5|(k|0)==20){do{if((l|0)!=0){if((c[(c[l+8>>2]|0)+36>>2]|0)==0){break}if((PJb(c[l+12>>2]|0,2432088,2397728)|0)==0){break}if((c[g>>2]|0)!=20){t=0;break b}}}while(0);h=c[r+120>>2]|0;j=c[r+124>>2]|0;EFb(b,d,2390544,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=e,c[f+16>>2]=h,c[f+24>>2]=j,f)|0)|0;i=f;t=0}else if((k|0)==86018){do{if((l|0)!=0){j=c[l+8>>2]|0;if((j|0)==0){break}if((c[j+36>>2]|0)==0){break}if((PJb(c[l+12>>2]|0,2432088,2376968)|0)==0){break}j=n|0;h=r+412|0;D=0;while(1){if((D|0)>=16){break}if((c[1965112+(D<<2)>>2]|0)==(c[h>>2]|0)){break}else{D=D+1|0}}if((D|0)==16){KIb(r,16,2210328,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}a[j]=64;a[n+1|0]=0;a[n+2|0]=D|32;z=r+416|0;a[n+3|0]=c[z>>2]<<4;a[n+4|0]=63;a[n+5|0]=-64;s=hJb(13)|0;if((s|0)==0){KIb(r,16,2201296,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}lY(s,j,6,1)|0;a[s+12|0]=0;F=c[h>>2]|0;x=c[z>>2]|0;do{if((F|0)<24001){P=(x|0)<3?40:43}else{if((F|0)>=48001){P=43;break}if((x|0)<3){P=41;break}P=(x|0)<6?42:43}}while(0);EFb(b,d,2371440,(f=i,i=i+48|0,c[f>>2]=e,c[f+8>>2]=F,c[f+16>>2]=x,c[f+24>>2]=e,c[f+32>>2]=P,c[f+40>>2]=s,f)|0)|0;i=f;t=s;break b}}while(0);h=r+100|0;j=c[h>>2]|0;if((j|0)==0){KIb(r,16,2356392,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}if((j|0)>1073741818){KIb(r,16,2196136,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}D=hJb((j<<1)+10|0)|0;if((D|0)!=0){nrc(D|0,2193592,9)|0;lY(D+9|0,c[r+96>>2]|0,c[h>>2]|0,0)|0;a[D+((c[h>>2]<<1)+9)|0]=0;h=c[r+412>>2]|0;j=c[r+416>>2]|0;EFb(b,d,2346920,(f=i,i=i+40|0,c[f>>2]=e,c[f+8>>2]=h,c[f+16>>2]=j,c[f+24>>2]=e,c[f+32>>2]=D,f)|0)|0;i=f;t=D;break}KIb(r,16,2201296,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}else if((k|0)==13){D=r+100|0;j=c[D>>2]|0;do{if((j|0)==0){Q=0}else{if((j|0)>1073741818){KIb(r,16,2196136,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;Q=0;break}h=hJb((j<<1)+10|0)|0;if((h|0)==0){KIb(r,16,2201296,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;Q=0;break}else{nrc(h|0,2193592,9)|0;lY(h+9|0,c[r+96>>2]|0,c[D>>2]|0,0)|0;a[h+((c[D>>2]<<1)+9)|0]=0;Q=h;break}}}while(0);EFb(b,d,2383648,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=e,c[f+16>>2]=(Q|0)!=0?Q:10230416,f)|0)|0;i=f;t=Q}else if((k|0)==69660){if((e|0)<=95){t=0;break}D=c[r+416>>2]|0;EFb(b,d,2261112,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=8e3,c[f+16>>2]=D,f)|0)|0;i=f;t=0}else if((k|0)==69643){if((e|0)<=95){t=0;break}D=c[r+792>>2]<<3;j=c[r+412>>2]|0;EFb(b,d,2256712,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=D,c[f+16>>2]=j,f)|0)|0;i=f;t=0}else if((k|0)==31){j=c[r+140>>2]|0;if((j|0)==0){R=2305440}else if((j|0)==4){R=2293616}else if((j|0)==5){R=2286072}else{KIb(r,16,2282024,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}if((c[r+100>>2]|0)==0){KIb(r,16,2277960,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}j=pU(r)|0;if((j|0)==0){i=m;return}else{D=c[r+120>>2]|0;h=c[r+124>>2]|0;EFb(b,d,2273704,(f=i,i=i+48|0,c[f>>2]=e,c[f+8>>2]=e,c[f+16>>2]=D,c[f+24>>2]=h,c[f+32>>2]=R,c[f+40>>2]=j,f)|0)|0;i=f;t=j;break}}else if((k|0)==73729){j=c[r+412>>2]|0;h=c[r+416>>2]|0;EFb(b,d,2318744,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=j,c[f+16>>2]=h,c[f+24>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==65543){if((e|0)<=95){t=0;break}h=c[r+412>>2]|0;j=c[r+416>>2]|0;EFb(b,d,2329744,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=h,c[f+16>>2]=j,f)|0)|0;i=f;t=0}else if((k|0)==73728){j=c[r+412>>2]|0;h=c[r+416>>2]|0;EFb(b,d,2323752,(f=i,i=i+32|0,c[f>>2]=e,c[f+8>>2]=j,c[f+16>>2]=h,c[f+24>>2]=e,f)|0)|0;i=f;t=0}else if((k|0)==86021){if((c[r+100>>2]|0)==0){KIb(r,16,2313680,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=m;return}h=pU(r)|0;if((h|0)==0){i=m;return}else{j=c[r+412>>2]|0;D=c[r+416>>2]|0;EFb(b,d,2309288,(f=i,i=i+40|0,c[f>>2]=e,c[f+8>>2]=j,c[f+16>>2]=D,c[f+24>>2]=e,c[f+32>>2]=h,f)|0)|0;i=f;t=h;break}}else{t=0}}while(0);kJb(t);i=m;return}function nU(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;i=i+64|0;h=g|0;j=g+40|0;k=g+48|0;l=g+56|0;m=LGb(c[(c[b>>2]|0)+1140>>2]|0,2179480,0,0)|0;mrc(e|0,0,f|0)|0;if((m|0)==0){n=2622320}else{n=c[m+4>>2]|0}c[h>>2]=0;m=(d|0)==1;o=g+8|0;do{if(m){p=oU(o,h,(c[b>>2]|0)+32|0)|0;q=j|0;c[h>>2]=0;if((a[o]|0)==0){r=p;s=6;break}t=(irc(q,2594512)|0)==0;EFb(e,f,2491488,(u=i,i=i+48|0,c[u>>2]=0,c[u+8>>2]=0,c[u+16>>2]=0,c[u+24>>2]=t?2594512:2104160,c[u+32>>2]=t?2571480:2127296,c[u+40>>2]=n,u)|0)|0;i=u;EFb(e,f,2179208,(u=i,i=i+16|0,c[u>>2]=q,c[u+8>>2]=o,u)|0)|0;i=u;EFb(e,f,2480664,(u=i,i=i+16|0,c[u>>2]=0,c[u+8>>2]=0,u)|0)|0;i=u;a[o]=0;v=p}else{r=0;s=6}}while(0);do{if((s|0)==6){EFb(e,f,2491488,(u=i,i=i+48|0,c[u>>2]=0,c[u+8>>2]=0,c[u+16>>2]=0,c[u+24>>2]=2104160,c[u+32>>2]=2127296,c[u+40>>2]=n,u)|0)|0;i=u;EFb(e,f,2480664,(u=i,i=i+16|0,c[u>>2]=0,c[u+8>>2]=0,u)|0)|0;i=u;a[o]=0;if((d|0)>0){v=r;break}i=g;return 0}}while(0);r=j|0;j=0;n=v;v=0;while(1){s=b+(j<<2)|0;if(m){w=n}else{p=oU(o,h,(c[s>>2]|0)+32|0)|0;c[h>>2]=0;w=p}p=c[s>>2]|0;if((c[p+24>>2]|0)==0){x=v}else{q=(w|0)<1;if((w|0)>0){t=0;y=v;z=p;while(1){A=y+1|0;mU(e,f,c[(c[z+28>>2]|0)+(t<<2)>>2]|0,y,(a[o]|0)!=0?o:0,r,(t<<1)+w|0,0,z);if(q){EFb(e,f,2553448,(u=i,i=i+8|0,c[u>>2]=t+j,u)|0)|0;i=u}B=c[s>>2]|0;C=B+16|0;D=c[C>>2]|0;do{if((D|0)==0){E=B}else{if((c[D>>2]|0)==0){E=B;break}c[k>>2]=0;c[l>>2]=0;MJb(c[C>>2]|0,2535336,1,k)|0;MJb(c[(c[s>>2]|0)+16>>2]|0,2519672,1,l)|0;F=c[k>>2]|0;do{if((F|0)==0){G=0}else{if((a[F]|0)==0){G=F;break}H=c[l>>2]|0;EFb(e,f,2505272,(u=i,i=i+16|0,c[u>>2]=F,c[u+8>>2]=H,u)|0)|0;i=u;G=c[k>>2]|0}}while(0);kJb(G);kJb(c[l>>2]|0);E=c[s>>2]|0}}while(0);C=t+1|0;if(C>>>0<(c[E+24>>2]|0)>>>0){t=C;y=A;z=E}else{x=A;break}}}else{z=0;y=v;t=p;while(1){C=y+1|0;mU(e,f,c[(c[t+28>>2]|0)+(z<<2)>>2]|0,y,(a[o]|0)!=0?o:0,r,0,0,t);if(q){EFb(e,f,2553448,(u=i,i=i+8|0,c[u>>2]=z+j,u)|0)|0;i=u}B=c[s>>2]|0;D=B+16|0;F=c[D>>2]|0;do{if((F|0)==0){I=B}else{if((c[F>>2]|0)==0){I=B;break}c[k>>2]=0;c[l>>2]=0;MJb(c[D>>2]|0,2535336,1,k)|0;MJb(c[(c[s>>2]|0)+16>>2]|0,2519672,1,l)|0;H=c[k>>2]|0;do{if((H|0)==0){J=0}else{if((a[H]|0)==0){J=H;break}K=c[l>>2]|0;EFb(e,f,2505272,(u=i,i=i+16|0,c[u>>2]=H,c[u+8>>2]=K,u)|0)|0;i=u;J=c[k>>2]|0}}while(0);kJb(J);kJb(c[l>>2]|0);I=c[s>>2]|0}}while(0);D=z+1|0;if(D>>>0<(c[I+24>>2]|0)>>>0){z=D;y=C;t=I}else{x=C;break}}}}t=j+1|0;if((t|0)<(d|0)){j=t;n=w;v=x}else{break}}i=g;return 0}function oU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+104|0;f=e|0;g=e+40|0;h=e+8|0;kY(h,32,0,0,a,32,f,0,0,d);c[b>>2]=0;do{if((irc(h,2470520)|0)!=0){if((irc(h,2462832)|0)==0){break}else{j=0}i=e;return j|0}}while(0);h=_b(d|0,63)|0;do{if((h|0)!=0){d=g|0;if((jKb(d,64,2445728,h)|0)==0){c[b>>2]=5;break}else{c[b>>2]=rb(d|0,0,10)|0;break}}}while(0);j=c[f>>2]|0;i=e;return j|0}function pU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=c[b+48>>2]|0;if((g|0)==31){h=42}else if((g|0)==86021){h=30}else{KIb(b,16,2217264,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=0;i=d;return k|0}g=e|0;l=f|0;if((oib(c[b+96>>2]|0,c[b+100>>2]|0,h,g,l)|0)<0){KIb(b,16,2214376,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=0;i=d;return k|0}h=f+8|0;f=(c[h>>2]|0)+(c[l>>2]|0)|0;m=f+12|0;n=hJb(m)|0;do{if((n|0)!=0){o=((f+14|0)/3|0)<<2|1;p=hJb(o)|0;if((p|0)==0){kJb(n);break}a[n+2|0]=0;a[n+1|0]=0;a[n]=0;a[n+3|0]=1;a[n+4|0]=-2;a[n+5|0]=-51;a[n+6|0]=-70;a[n+7|0]=f>>>8;a[n+8|0]=f;a[n+9|0]=2;q=c[l>>2]|0;a[n+10|0]=q;a[n+11|0]=0;nrc(n+12|0,c[g>>2]|0,q)|0;nrc(n+(q+12)|0,c[e+8>>2]|0,c[h>>2]|0)|0;RFb(p,o,n,m)|0;kJb(n);k=p;i=d;return k|0}}while(0);KIb(b,16,2211960,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=0;i=d;return k|0}function qU(a){a=a|0;var b=0;b=c[a+4>>2]|0;return((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==21058131?50:0)|0}function rU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=ZX(a,0)|0;if((e|0)==0){d=-12;return d|0}f=a+16|0;hD(c[f>>2]|0,20,0)|0;_X(e,64,1,FD(c[f>>2]|0)|0);a=e+8|0;c[(c[a>>2]|0)+8>>2]=0;g=FD(c[f>>2]|0)|0;c[(c[a>>2]|0)+120>>2]=g;g=FD(c[f>>2]|0)|0;h=c[a>>2]|0;c[h+124>>2]=g;c[h+48>>2]=28;c[e+236>>2]=1;e=c[b+8>>2]|0;c[e+8>>2]=1;c[e+416>>2]=1;c[e+412>>2]=8e3;c[e+48>>2]=65536;_X(b,64,1,8e3);fD(c[f>>2]|0,168,0,0)|0;d=0;return d|0}function sU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a+16|0;a=fD(c[d>>2]|0,0,0,1)|0;e=G;f=FD(c[d>>2]|0)|0;hD(c[d>>2]|0,4,0)|0;g=FD(c[d>>2]|0)|0;if(g>>>0<53>>>0){h=-1094995529;return h|0}hD(c[d>>2]|0,6,0)|0;i=FD(c[d>>2]|0)|0;hD(c[d>>2]|0,30,0)|0;do{if((a|0)==168&(e|0)==0){if((K1(b,g-28|0)|0)<0){h=-12;return h|0}j=b+24|0;nrc(c[j>>2]|0,1142272,24)|0;k=AD(c[d>>2]|0,(c[j>>2]|0)+24|0,g-52|0)|0;if((k|0)>=0){M1(b,k+24|0);l=k;break}P1(b);h=k;return h|0}else{l=fX(c[d>>2]|0,b,g-52|0)|0}}while(0);c[b+32>>2]=(i|0)!=0;i=b+64|0;c[i>>2]=a;c[i+4>>2]=e;if((f&4096|0)==0){h=l;return h|0}f=b+36|0;c[f>>2]=c[f>>2]|1;h=l;return h|0}function tU(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1296845126){e=0;return e|0}a=b+16|0;e=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1129530438?100:0;return e|0}function uU(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+256|0;g=f|0;h=g|0;j=g;k=e+12|0;l=c[k>>2]|0;m=c[e+16>>2]|0;n=l+32|0;c[n>>2]=0;o=g;if((AD(m,o,16)|0)!=16){p=-5;i=f;return p|0}q=g+4|0;r=je(c[q>>2]|0)|0;s=g+8|0;t=s;u=c[s>>2]|0;c[l+44>>2]=je(u|0)|0;a:do{if((u|0)==0){if((AD(m,o,20)|0)==20){c[l+8>>2]=65540;c[l+12>>2]=22050;c[l+20>>2]=1;c[l+16>>2]=8;break}else{p=-5;i=f;return p|0}}else{if((AD(m,o,32)|0)!=32){p=-5;i=f;return p|0}c[l+12>>2]=(he(b[g+24>>1]|0)|0)&65535;v=a[j+21|0]|0;c[l+20>>2]=v&255;w=a[j+22|0]|0;c[l+16>>2]=w&255;x=v<<24>>24==0;do{if((a[j+23|0]|0)==2){if(x){break}c[l+8>>2]=69641;break a}else{if(x){break}if(w<<24>>24==8){c[l+8>>2]=65563;break a}v=l+8|0;if(w<<24>>24==16){c[v>>2]=1347637264;break a}else{c[v>>2]=0;break a}}}while(0);c[l+8>>2]=0}}while(0);if((c[h>>2]|0)!=1129530438){p=-1094995529;i=f;return p|0}j=c[s>>2]|0;do{if((j|0)==1684633187){c[l+24>>2]=44;y=22}else{u=l+24|0;if((j|0)==544694642){c[u>>2]=14;y=22;break}else{c[u>>2]=0;break}}}while(0);do{if((y|0)==22){j=l+24|0;u=ZX(e,0)|0;if((u|0)==0){p=-12;i=f;return p|0}c[l>>2]=c[u>>2];w=c[u+8>>2]|0;c[w+8>>2]=0;c[w+48>>2]=c[j>>2];c[w+52>>2]=0;c[w+120>>2]=je(c[g+16>>2]|0)|0;c[w+124>>2]=je(c[g+12>>2]|0)|0;if((c[j>>2]|0)!=14){break}j=a[g+20|0]|0;if(j<<24>>24==24){c[w+140>>2]=2;break}KIb(e,16,2377408,(w=i,i=i+8|0,c[w>>2]=j&255,w)|0);i=w;p=-1;i=f;return p|0}}while(0);y=l+8|0;if((c[y>>2]|0)!=0){w=ZX(e,0)|0;if((w|0)==0){p=-12;i=f;return p|0}c[l+4>>2]=c[w>>2];j=c[w+8>>2]|0;c[j+8>>2]=1;c[j+48>>2]=c[y>>2];c[j+52>>2]=1;u=c[l+20>>2]|0;c[j+416>>2]=u;x=c[l+12>>2]|0;c[j+412>>2]=x;if((c[y>>2]|0)==69641){c[j+792>>2]=4;c[j+432>>2]=u*18|0;c[w+236>>2]=1;z=4}else{w=c[l+16>>2]|0;c[j+792>>2]=w;c[j+432>>2]=(ca(w,u)|0)/8|0;z=w}c[j+72>>2]=ca(ca(x,u)|0,z)|0}if((AD(m,o,16)|0)!=16){p=-5;i=f;return p|0}if((c[h>>2]|0)!=1111577683){p=-1094995529;i=f;return p|0}z=l+40|0;c[z>>2]=je(c[s>>2]|0)|0;u=je(c[g+12>>2]|0)|0;g=l+28|0;c[g>>2]=u;if(u>>>0>107374181>>>0){p=-1;i=f;return p|0}x=hJb(u*40|0)|0;c[n>>2]=x;if((x|0)==0){p=-12;i=f;return p|0}x=e+24|0;if((c[x>>2]|0)!=0){u=e+28|0;e=l+12|0;j=0;do{w=c[(c[u>>2]|0)+(j<<2)>>2]|0;if((c[(c[w+8>>2]|0)+8>>2]|0)==0){_X(w,33,1,c[z>>2]|0)}else{_X(w,64,1,c[e>>2]|0)}j=j+1|0;}while(j>>>0<(c[x>>2]|0)>>>0)}b:do{if((c[g>>2]|0)!=0){x=l+4|0;j=l+20|0;e=l+16|0;z=l;u=0;w=0;while(1){if((AD(m,o,16)|0)!=16){A=-5;break}v=(je(c[h>>2]|0)|0)+r|0;B=c[n>>2]|0;C=B+(u*40|0)+8|0;c[C>>2]=v;c[C+4>>2]=0;C=je(c[q>>2]|0)|0;c[B+(u*40|0)+16>>2]=C;v=B+(u*40|0)|0;if(C>>>0>536870911>>>0){A=-1094995529;break}do{if((c[s>>2]|0)==-1){c[v>>2]=c[x>>2];D=B+(u*40|0)+24|0;c[D>>2]=w;c[D+4>>2]=0;D=c[y>>2]|0;if((D|0)==0){E=w;break}else if((D|0)==69641){E=((C<<5>>>0)/(((c[j>>2]|0)*18|0)>>>0)|0)+w|0;break}else{E=((C>>>0)/((ca(c[e>>2]|0,c[j>>2]|0)|0)>>>3>>>0)|0)+w|0;break}}else{c[v>>2]=c[z>>2];D=B+(u*40|0)+24|0;c[D>>2]=(je(c[s>>2]|0)|0)&2147483647;c[D+4>>2]=0;c[B+(u*40|0)+32>>2]=(d[t]|0)>>>7&255^1;E=w}}while(0);B=u+1|0;if(B>>>0<(c[g>>2]|0)>>>0){u=B;w=E}else{break b}}mJb((c[k>>2]|0)+32|0);p=A;i=f;return p|0}}while(0);c[l+36>>2]=0;p=0;i=f;return p|0}function vU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;a=d+36|0;f=c[a>>2]|0;if(!(f>>>0<(c[d+28>>2]|0)>>>0)){g=-541478725;return g|0}h=c[d+32>>2]|0;d=h+(f*40|0)+8|0;fD(e,c[d>>2]|0,c[d+4>>2]|0,0)|0;d=h+(f*40|0)+16|0;i=fX(e,b,c[d>>2]|0)|0;e=(i|0)==(c[d>>2]|0)?i:-5;c[b+32>>2]=c[h+(f*40|0)>>2];i=h+(f*40|0)+24|0;f=c[i+4>>2]|0;h=b+8|0;c[h>>2]=c[i>>2];c[h+4>>2]=f;c[a>>2]=(c[a>>2]|0)+1;g=e;return g|0}function wU(a){a=a|0;mJb((c[a+12>>2]|0)+32|0);return 0}function xU(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=i;i=i+56|0;e=d|0;f=d+24|0;g=d+32|0;j=d+40|0;k=d+48|0;l=b+12|0;m=c[l>>2]|0;c[m+12>>2]=0;n=m+108|0;if((c[n>>2]|0)==0){c[m+104>>2]=0}o=m+52|0;p=c[o>>2]|0;q=(p|0)!=0;r=c[m+64>>2]|0;s=(r|0)!=0;t=c[m+76>>2]|0;u=(t|0)!=0;if(((s&1)+(q&1)+(u&1)|0)>1){KIb(b,16,2125520,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=d;return w|0}do{if(s){x=b;y=m+68|0;z=m+72|0;A=rJb(r)|0;c[j>>2]=0;if((A|0)==0){w=-12;i=d;return w|0}c[z>>2]=1;B=A;C=1;while(1){D=a[B]|0;if((D<<24>>24|0)==0){break}else if((D<<24>>24|0)==44){D=C+1|0;c[z>>2]=D;E=D}else{E=C}B=B+1|0;C=E}B=hJb(C<<3)|0;c[y>>2]=B;a:do{if((B|0)==0){KIb(x,16,2630976,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;F=-12}else{if((c[z>>2]|0)>0){G=0;H=A}else{F=0;break}while(1){I=HFb(H,2104032,j)|0;if((I|0)==0){J=16;break}if((a[I]|0)==0){J=16;break}D=iKb(k,I,1)|0;if((D|0)<0){J=18;break}K=c[k>>2]|0;L=c[k+4>>2]|0;M=c[y>>2]|0;N=M+(G<<3)|0;c[N>>2]=K;c[N+4>>2]=L;if((G|0)!=0){N=M+(G-1<<3)|0;O=c[N>>2]|0;P=c[N+4>>2]|0;if((P|0)>(L|0)|(P|0)==(L|0)&O>>>0>K>>>0){J=21;break}}N=G+1|0;if((N|0)<(c[z>>2]|0)){G=N;H=0}else{F=D;break a}}if((J|0)==16){KIb(x,16,2629264,(v=i,i=i+8|0,c[v>>2]=r,v)|0);i=v;F=-22;break}else if((J|0)==18){KIb(x,16,2627664,(v=i,i=i+16|0,c[v>>2]=I,c[v+8>>2]=r,v)|0);i=v;F=-22;break}else if((J|0)==21){KIb(x,16,2626272,(v=i,i=i+16|0,h[v>>3]=(+(K>>>0)+ +(L|0)*4294967296.0)/1.0e6,h[v+8>>3]=(+(O>>>0)+ +(P|0)*4294967296.0)/1.0e6,v)|0);i=v;F=-22;break}}}while(0);kJb(A);if((F|0)<0){w=F}else{break}i=d;return w|0}else{if(!u){if(q){Q=p}else{x=rJb(2119016)|0;c[o>>2]=x;Q=x}x=iKb(m+56|0,Q,1)|0;if((x|0)>=0){break}KIb(b,16,2115216,(v=i,i=i+8|0,c[v>>2]=c[o>>2],v)|0);i=v;w=x;i=d;return w|0}x=b;z=m+80|0;y=m+84|0;B=rJb(t)|0;c[f>>2]=0;if((B|0)==0){w=-12;i=d;return w|0}c[y>>2]=1;C=B;D=1;while(1){N=a[C]|0;if((N<<24>>24|0)==0){break}else if((N<<24>>24|0)==44){N=D+1|0;c[y>>2]=N;R=N}else{R=D}C=C+1|0;D=R}C=hJb(D<<2)|0;c[z>>2]=C;b:do{if((C|0)==0){KIb(x,16,2105544,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;S=-12}else{if((c[y>>2]|0)>0){T=0;U=B}else{S=0;break}while(1){V=HFb(U,2104032,f)|0;if((V|0)==0){J=34;break}W=rb(V|0,g|0,10)|0;if((a[c[g>>2]|0]|0)!=0){J=37;break}if((W|0)<1|(W|0)==2147483647){J=37;break}A=c[z>>2]|0;c[A+(T<<2)>>2]=W;if((T|0)!=0){X=c[A+(T-1<<2)>>2]|0;if((X|0)>(W|0)){J=40;break}}A=T+1|0;if((A|0)<(c[y>>2]|0)){T=A;U=0}else{S=0;break b}}if((J|0)==34){KIb(x,16,2643608,(v=i,i=i+8|0,c[v>>2]=t,v)|0);i=v;S=-22;break}else if((J|0)==37){KIb(x,16,2637176,(v=i,i=i+8|0,c[v>>2]=V,v)|0);i=v;S=-22;break}else if((J|0)==40){KIb(x,16,2633240,(v=i,i=i+16|0,c[v>>2]=W,c[v+8>>2]=X,v)|0);i=v;S=-22;break}}}while(0);kJb(B);if((S|0)<0){w=S}else{break}i=d;return w|0}}while(0);S=m+28|0;X=c[S>>2]|0;W=m+44|0;if((X|0)==0){J=59}else{do{if((c[W>>2]|0)==-1){if((fH(X,2390536)|0)!=0){c[W>>2]=1;break}if((fH(c[S>>2]|0,2376904)|0)!=0){c[W>>2]=3;break}if((fH(c[S>>2]|0,2340648)|0)!=0){c[W>>2]=2;break}if((fH(c[S>>2]|0,2113392)|0)==0){c[W>>2]=0;break}else{c[W>>2]=4;break}}}while(0);X=BU(b)|0;if((X|0)<0){Y=X}else{J=59}}c:do{if((J|0)==59){if((c[W>>2]|0)==3){KIb(b,24,2111552,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v}X=c[l>>2]|0;V=X+132|0;c[V>>2]=-1;t=X+128|0;X=c[t>>2]|0;d:do{if((irc(X,2179368)|0)==0){mrc(e|0,-1|0,20)|0;U=c[b+24>>2]|0;if((U|0)==0){Z=0}else{T=c[b+28>>2]|0;g=0;while(1){f=c[T+(g<<2)>>2]|0;R=c[(c[f+8>>2]|0)+8>>2]|0;do{if(R>>>0<5>>>0){o=e+(R<<2)|0;if(!((c[o>>2]|0)==-1)){break}if((c[f+72>>2]&1024|0)!=0){break}c[o>>2]=g}}while(0);f=g+1|0;if(f>>>0<U>>>0){g=f}else{Z=0;break}}}while(1){if(!(Z>>>0<5>>>0)){_=X;J=79;break d}g=c[e+(c[601496+(Z<<2)>>2]<<2)>>2]|0;c[V>>2]=g;if((g|0)>-1){break}else{Z=Z+1|0}}$=b+28|0}else{g=b+24|0;U=b+28|0;T=0;while(1){if(!(T>>>0<(c[g>>2]|0)>>>0)){J=76;break}f=vY(b,c[(c[U>>2]|0)+(T<<2)>>2]|0,c[t>>2]|0)|0;if((f|0)<0){Y=f;break c}if((f|0)>0){J=75;break}else{T=T+1|0}}if((J|0)==75){c[V>>2]=T;aa=T}else if((J|0)==76){aa=c[V>>2]|0}if((aa|0)>=0){$=U;break}_=c[t>>2]|0;J=79}}while(0);if((J|0)==79){KIb(b,16,2106928,(v=i,i=i+8|0,c[v>>2]=_,v)|0);i=v;Y=-22;break}t=b;V=c[m+132>>2]|0;X=ALb(c[(c[(c[(c[$>>2]|0)+(V<<2)>>2]|0)+8>>2]|0)+8>>2]|0)|0;KIb(t,40,2109832,(v=i,i=i+16|0,c[v>>2]=V,c[v+8>>2]=X,v)|0);i=v;X=gH(c[m+24>>2]|0,b+32|0,0)|0;c[m+16>>2]=X;if((X|0)==0){Y=-1481985528;break}if((c[X+28>>2]&1|0)!=0){KIb(t,16,2108216,(v=i,i=i+8|0,c[v>>2]=c[X>>2],v)|0);i=v;Y=-22;break}X=DU(b)|0;if((X|0)<0){Y=X;break}X=c[m+20>>2]|0;V=EU(b)|0;if((V|0)<0){Y=V;break}V=X+16|0;do{if((c[n>>2]|0)==0){B=hJb(32768)|0;if((B|0)==0){Y=-12;break c}g=aD(B,32768,2,0,0,0,0)|0;c[V>>2]=g;if((g|0)!=0){break}kJb(B);Y=-12;break c}else{B=X+32|0;g=VD(V,B,2,b+1160|0,0)|0;if((g|0)>=0){break}KIb(t,16,2134920,(v=i,i=i+8|0,c[v>>2]=B,v)|0);i=v;Y=g;break c}}while(0);t=TO(X,0)|0;if((t|0)<0){WD(c[V>>2]|0)|0;Y=t;break}c[m+192>>2]=1;do{if((c[X+1204>>2]|0)>0){g=b+1204|0;if((c[g>>2]|0)>=0){break}c[g>>2]=1}}while(0);if((c[n>>2]|0)==0){g=c[V>>2]|0;kJb(c[g+4>>2]|0);kJb(g);ba=VD(V,X+32|0,2,b+1160|0,0)|0}else{ba=t}if((ba|0)==0){w=0}else{Y=ba;break}i=d;return w|0}}while(0);if((c[S>>2]|0)!=0){WD(c[m+48>>2]|0)|0}S=c[m+20>>2]|0;if((S|0)==0){w=Y;i=d;return w|0}pX(S);w=Y;i=d;return w|0}function yU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,R=0,S=0,T=0,U=0;e=i;i=i+376|0;f=e|0;g=e+8|0;j=e+16|0;k=e+48|0;l=e+80|0;m=e+112|0;n=e+144|0;o=e+176|0;p=e+208|0;q=e+240|0;r=e+248|0;s=e+280|0;t=e+312|0;u=e+344|0;v=b+12|0;w=c[v>>2]|0;x=d+32|0;y=c[x>>2]|0;z=c[(c[b+28>>2]|0)+(y<<2)>>2]|0;A=c[w+68>>2]|0;do{if((A|0)==0){B=c[w+80>>2]|0;if((B|0)==0){C=w+56|0;D=(c[w+12>>2]|0)+1|0;E=Erc(D,(D|0)<0|0?-1:0,c[C>>2]|0,c[C+4>>2]|0)|0;F=2147483647;H=G;I=E;break}E=c[w+12>>2]|0;if((E|0)>(c[w+84>>2]|0)){F=2147483647;H=2147483647;I=-1;break}F=c[B+(E<<2)>>2]|0;H=2147483647;I=-1}else{E=c[w+12>>2]|0;if((E|0)>=(c[w+72>>2]|0)){F=2147483647;H=2147483647;I=-1;break}B=A+(E<<3)|0;F=2147483647;H=c[B+4>>2]|0;I=c[B>>2]|0}}while(0);A=w+132|0;do{if((y|0)==(c[A>>2]|0)){if((c[d+36>>2]&1|0)==0){J=26;break}if((c[w+88>>2]|0)<(F|0)){B=d+8|0;E=c[B>>2]|0;C=c[B+4>>2]|0;if((E|0)==0&(C|0)==(-2147483648|0)){J=26;break}B=w+96|0;D=xrc(I,H,c[B>>2]|0,c[B+4>>2]|0)|0;c[f>>2]=1;c[f+4>>2]=1e6;if(!((YIb(E,C,z+40|0,D,G,f)|0)>-1)){J=26;break}}D=w+104|0;C=AU(b,c[D>>2]|0,0)|0;if((C|0)<0){K=C;break}C=c[v>>2]|0;E=C+20|0;B=c[E>>2]|0;L=(c[D>>2]|0)!=0;if(L){pX(B);c[E>>2]=0;D=DU(b)|0;if((D|0)<0){K=D;break}M=c[E>>2]|0}else{M=B}B=C+4|0;c[B>>2]=(c[B>>2]|0)+1;B=EU(b)|0;if((B|0)<0){K=B;break}B=M+32|0;E=VD(M+16|0,B,2,b+1160|0,0)|0;if((E|0)<0){KIb(b,16,2134920,(N=i,i=i+8|0,c[N>>2]=B,N)|0);i=N;K=E;break}do{if((c[(c[M+8>>2]|0)+36>>2]|0)!=0){E=c[M+12>>2]|0;if((E|0)==0){break}EJb(E,2133304,2131312,0)|0}}while(0);if(L){E=TO(M,0)|0;if((E|0)<0){K=E;break}}c[C+192>>2]=1;c[w+136>>2]=c[w+4>>2];E=d+8|0;B=c[E>>2]|0;D=c[E+4>>2]|0;E=z+40|0;h[w+144>>3]=(+(B>>>0)+ +(D|0)*4294967296.0)*(+(c[E>>2]|0)/+(c[z+44>>2]|0));c[g>>2]=1;c[g+4>>2]=1e6;O=XIb(B,D,E,g)|0;E=w+160|0;c[E>>2]=O;c[E+4>>2]=G;J=28}else{J=26}}while(0);do{if((J|0)==26){g=d+8|0;M=c[g>>2]|0;v=c[g+4>>2]|0;if((M|0)==0&(v|0)==(-2147483648|0)){J=28;break}g=w+152|0;P=+h[g>>3];f=c[d+48>>2]|0;H=wrc(f,(f|0)<0|0?-1:0,M,v)|0;Q=(+(H>>>0)+ +(G|0)*4294967296.0)*(+(c[z+40>>2]|0)/+(c[z+44>>2]|0));h[g>>3]=P>Q?P:Q;J=28}}while(0);if((J|0)==28){J=w+192|0;g=b;if((c[J>>2]|0)!=0){H=(c[w+20>>2]|0)+32|0;v=c[x>>2]|0;M=j|0;mrc(M|0,0,32)|0;a[M]=0;j=d+8|0;f=c[j>>2]|0;I=c[j+4>>2]|0;if((f|0)==0&(I|0)==(-2147483648|0)){Rb(M|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(M|0,32,2136840,(N=i,i=i+16|0,c[N>>2]=f,c[N+8>>2]=I,N)|0)|0;i=N}I=k|0;mrc(I|0,0,32)|0;a[I]=0;k=c[j>>2]|0;f=c[j+4>>2]|0;if((k|0)==0&(f|0)==(-2147483648|0)){Rb(I|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(I|0,32,2138632,(N=i,i=i+8|0,h[N>>3]=(+(k>>>0)+ +(f|0)*4294967296.0)*(+(c[z+40>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}f=c[w+88>>2]|0;KIb(g,40,2153120,(N=i,i=i+40|0,c[N>>2]=H,c[N+8>>2]=v,c[N+16>>2]=M,c[N+24>>2]=I,c[N+32>>2]=f,N)|0);i=N;c[J>>2]=0}J=c[x>>2]|0;f=l|0;mrc(f|0,0,32)|0;a[f]=0;l=w+160|0;I=c[l>>2]|0;M=c[l+4>>2]|0;if((I|0)==0&(M|0)==(-2147483648|0)){Rb(f|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(f|0,32,2138632,(N=i,i=i+8|0,h[N>>3]=(+(I>>>0)+ +(M|0)*4294967296.0)*1.0e-6,N)|0)|0;i=N}M=m|0;mrc(M|0,0,32)|0;a[M]=0;m=d+8|0;I=c[m>>2]|0;v=c[m+4>>2]|0;if((I|0)==0&(v|0)==(-2147483648|0)){Rb(M|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(M|0,32,2136840,(N=i,i=i+16|0,c[N>>2]=I,c[N+8>>2]=v,N)|0)|0;i=N}v=n|0;mrc(v|0,0,32)|0;a[v]=0;n=c[m>>2]|0;I=c[m+4>>2]|0;H=z+40|0;if((n|0)==0&(I|0)==(-2147483648|0)){Rb(v|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(v|0,32,2138632,(N=i,i=i+8|0,h[N>>3]=(+(n>>>0)+ +(I|0)*4294967296.0)*(+(c[H>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}I=o|0;mrc(I|0,0,32)|0;a[I]=0;o=d+16|0;n=c[o>>2]|0;k=c[o+4>>2]|0;if((n|0)==0&(k|0)==(-2147483648|0)){Rb(I|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(I|0,32,2136840,(N=i,i=i+16|0,c[N>>2]=n,c[N+8>>2]=k,N)|0)|0;i=N}k=p|0;mrc(k|0,0,32)|0;a[k]=0;p=c[o>>2]|0;n=c[o+4>>2]|0;if((p|0)==0&(n|0)==(-2147483648|0)){Rb(k|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(k|0,32,2138632,(N=i,i=i+8|0,h[N>>3]=(+(p>>>0)+ +(n|0)*4294967296.0)*(+(c[H>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}KIb(g,48,2151488,(N=i,i=i+48|0,c[N>>2]=J,c[N+8>>2]=f,c[N+16>>2]=M,c[N+24>>2]=v,c[N+32>>2]=I,c[N+40>>2]=k,N)|0);i=N;k=w+120|0;if((c[w+112>>2]|0)==0){R=0;S=0}else{R=c[l+4>>2]|0;S=c[l>>2]|0}l=xrc(c[k>>2]|0,c[k+4>>2]|0,S,R)|0;c[q>>2]=1;c[q+4>>2]=1e6;R=XIb(l,G,q,H)|0;q=G;l=c[m>>2]|0;S=c[m+4>>2]|0;if((l|0)==0&(S|0)==(-2147483648|0)){T=-2147483648;U=0}else{k=wrc(l,S,R,q)|0;S=G;c[m>>2]=k;c[m+4>>2]=S;T=S;U=k}k=c[o>>2]|0;S=c[o+4>>2]|0;if(!((k|0)==0&(S|0)==(-2147483648|0))){l=wrc(k,S,R,q)|0;c[o>>2]=l;c[o+4>>2]=G}l=r|0;mrc(l|0,0,32)|0;a[l]=0;if((U|0)==0&(T|0)==(-2147483648|0)){Rb(l|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(l|0,32,2136840,(N=i,i=i+16|0,c[N>>2]=U,c[N+8>>2]=T,N)|0)|0;i=N}T=s|0;mrc(T|0,0,32)|0;a[T]=0;s=c[m>>2]|0;U=c[m+4>>2]|0;if((s|0)==0&(U|0)==(-2147483648|0)){Rb(T|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(T|0,32,2138632,(N=i,i=i+8|0,h[N>>3]=(+(s>>>0)+ +(U|0)*4294967296.0)*(+(c[H>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}U=t|0;mrc(U|0,0,32)|0;a[U]=0;t=c[o>>2]|0;s=c[o+4>>2]|0;if((t|0)==0&(s|0)==(-2147483648|0)){Rb(U|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(U|0,32,2136840,(N=i,i=i+16|0,c[N>>2]=t,c[N+8>>2]=s,N)|0)|0;i=N}s=u|0;mrc(s|0,0,32)|0;a[s]=0;u=c[o>>2]|0;t=c[o+4>>2]|0;if((u|0)==0&(t|0)==(-2147483648|0)){Rb(s|0,32,2142568,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0)|0;i=N}else{Rb(s|0,32,2138632,(N=i,i=i+8|0,h[N>>3]=(+(u>>>0)+ +(t|0)*4294967296.0)*(+(c[H>>2]|0)/+(c[z+44>>2]|0)),N)|0)|0;i=N}KIb(g,48,2149440,(N=i,i=i+32|0,c[N>>2]=l,c[N+8>>2]=T,c[N+16>>2]=U,c[N+24>>2]=s,N)|0);i=N;K=aP(c[w+20>>2]|0,c[x>>2]|0,d,b)|0}if((c[x>>2]|0)!=(c[A>>2]|0)){i=e;return K|0}A=w+88|0;c[A>>2]=(c[A>>2]|0)+1;i=e;return K|0}function zU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=c[b+20>>2]|0;do{if((c[b+108>>2]|0)==0){e=AU(a,0,1)|0;if((e|0)<0){f=e;break}e=d+16|0;g=hJb(32768)|0;do{if((g|0)!=0){h=aD(g,32768,2,0,0,0,0)|0;c[e>>2]=h;if((h|0)!=0){break}kJb(g)}}while(0);g=$O(d)|0;h=c[e>>2]|0;kJb(c[h+4>>2]|0);kJb(h);f=g}else{f=AU(a,1,1)|0}}while(0);if((c[b+28>>2]|0)!=0){WD(c[b+48>>2]|0)|0}WJb(b);mJb(b+68|0);mJb(b+80|0);a=c[b+184>>2]|0;if((a|0)==0){pX(d);return f|0}else{i=a}while(1){a=c[i+44>>2]|0;kJb(c[i+40>>2]|0);kJb(i);if((a|0)==0){break}else{i=a}}pX(d);return f|0}function AU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+8|0;f=e|0;g=c[a+12>>2]|0;h=g+20|0;j=c[h>>2]|0;UO(j,0)|0;do{if((b|0)==0){k=0}else{l=$O(j)|0;if((l|0)>=0){k=l;break}KIb(a,16,2217216,(m=i,i=i+8|0,c[m>>2]=j+32,m)|0);i=m;k=l}}while(0);if((c[g+28>>2]|0)==0){n=k}else{b=g+36|0;do{if((c[b>>2]|0)==0){l=c[g+44>>2]|0;if((l|0)==2){o=7;break}CU(c[g+48>>2]|0,l,g+136|0,a);p=k}else{o=7}}while(0);do{if((o|0)==7){k=pJb(48)|0;l=k;c[f>>2]=l;if((k|0)==0){q=-12;r=j+16|0;s=c[r>>2]|0;t=WD(s)|0;i=e;return q|0}u=g+136|0;c[k>>2]=c[u>>2];c[k+4>>2]=c[u+4>>2];c[k+8>>2]=c[u+8>>2];c[k+12>>2]=c[u+12>>2];c[k+16>>2]=c[u+16>>2];c[k+20>>2]=c[u+20>>2];c[k+24>>2]=c[u+24>>2];c[k+28>>2]=c[u+28>>2];c[k+32>>2]=c[u+32>>2];c[k+36>>2]=c[u+36>>2];c[k+40>>2]=c[u+40>>2];c[k+44>>2]=c[u+44>>2];u=g+184|0;k=g+188|0;if((c[u>>2]|0)==0){c[k>>2]=l;c[u>>2]=l}else{c[(c[k>>2]|0)+44>>2]=l}c[k>>2]=c[f>>2];k=c[b>>2]|0;do{if((k|0)!=0){if((c[g+12>>2]|0)<=(k|0)){break}c[f>>2]=c[u>>2];c[u>>2]=c[(c[u>>2]|0)+44>>2];kJb(c[(c[f>>2]|0)+40>>2]|0);mJb(f)}}while(0);k=g+48|0;WD(c[k>>2]|0)|0;l=BU(a)|0;if((l|0)<0){q=l;r=j+16|0;s=c[r>>2]|0;t=WD(s)|0;i=e;return q|0}v=c[u>>2]|0;c[f>>2]=v;w=g+44|0;if((v|0)!=0){x=a;y=v;do{CU(c[k>>2]|0,c[w>>2]|0,y,x);y=c[(c[f>>2]|0)+44>>2]|0;c[f>>2]=y;}while((y|0)!=0)}if((c[w>>2]|0)!=2|(d|0)==0){p=l;break}YD(c[k>>2]|0,2214360,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;p=l}}while(0);eD(c[g+48>>2]|0);n=p}p=g+12|0;g=c[p>>2]|0;KIb(a,40,2211872,(m=i,i=i+16|0,c[m>>2]=(c[h>>2]|0)+32,c[m+8>>2]=g,m)|0);i=m;c[p>>2]=(c[p>>2]|0)+1;q=n;r=j+16|0;s=c[r>>2]|0;t=WD(s)|0;i=e;return q|0}function BU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0.0,l=0.0,m=0.0,n=0.0;b=i;d=c[a+12>>2]|0;e=d+48|0;f=d+28|0;g=VD(e,c[f>>2]|0,2,a+1160|0,0)|0;if((g|0)<0){KIb(a,16,2179136,(j=i,i=i+8|0,c[j>>2]=c[f>>2],j)|0);i=j;i=b;return g|0}f=c[d+44>>2]|0;if((f|0)==4){YD(c[e>>2]|0,2155032,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;i=b;return g|0}else if((f|0)==2){f=d+184|0;if((c[f>>2]|0)==0){i=b;return g|0}YD(c[e>>2]|0,2177544,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;YD(c[e>>2]|0,2169520,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;YD(c[e>>2]|0,2164528,(j=i,i=i+8|0,c[j>>2]=c[c[f>>2]>>2],j)|0)|0;i=j;YD(c[e>>2]|0,2162472,(j=i,i=i+8|0,c[j>>2]=(c[d+32>>2]&1|0)!=0?2160384:2158496,j)|0)|0;i=j;d=c[f>>2]|0;if((d|0)==0){k=0.0}else{l=0.0;f=d;while(1){m=+h[f+16>>3]- +h[f+8>>3];n=l>m?l:m;d=c[f+44>>2]|0;if((d|0)==0){k=n;break}else{l=n;f=d}}}l=+ba(k);f=(F=+l,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);YD(c[e>>2]|0,2156584,(j=i,i=i+16|0,c[j>>2]=~~+l>>>0,c[j+8>>2]=f,j)|0)|0;i=j;i=b;return g|0}else{i=b;return g|0}return 0}function CU(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0.0;g=i;i=i+8|0;j=g|0;switch(d|0){case 4:{d=e+40|0;if((LFb(j,c[d>>2]|0,0,0,1)|0)<0){KIb(f,24,2193544,(k=i,i=i+8|0,c[k>>2]=c[d>>2],k)|0);i=k;i=g;return}else{YD(b,2190984,(k=i,i=i+8|0,c[k>>2]=c[j>>2],k)|0)|0;i=k;kJb(c[j>>2]|0);i=g;return}break};case 2:{j=c[e+40>>2]|0;YD(b,2196104,(k=i,i=i+16|0,h[k>>3]=+h[e+16>>3]- +h[e+8>>3],c[k+8>>2]=j,k)|0)|0;i=k;i=g;return};case 0:{YD(b,2210320,(k=i,i=i+8|0,c[k>>2]=c[e+40>>2],k)|0)|0;i=k;i=g;return};case 1:case 3:{j=c[e+40>>2]|0;d=(a[j+(mc(j|0,2181384)|0)|0]|0)!=0;if(d){bD(b,34);l=j}else{l=j}while(1){j=a[l]|0;if((j<<24>>24|0)==34){bD(b,34);m=a[l]|0}else if((j<<24>>24|0)==0){break}else{m=j}bD(b,m<<24>>24);l=l+1|0}if(d){bD(b,34)}n=+h[e+16>>3];YD(b,2201288,(k=i,i=i+16|0,h[k>>3]=+h[e+8>>3],h[k+8>>3]=n,k)|0)|0;i=k;i=g;return};default:{KIb(0,0,2188504,(k=i,i=i+24|0,c[k>>2]=2185824,c[k+8>>2]=2183648,c[k+16>>2]=286,k)|0);i=k;Hd()}}}function DU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[a+12>>2]|0;d=HR()|0;c[b+20>>2]=d;if((d|0)==0){e=-12;return e|0}f=d+8|0;c[f>>2]=c[b+16>>2];b=a+1160|0;g=d+1160|0;h=c[b+4>>2]|0;c[g>>2]=c[b>>2];c[g+4>>2]=h;PGb(d+1140|0,c[a+1140>>2]|0,0);h=a+24|0;if((c[h>>2]|0)==0){e=0;return e|0}g=a+28|0;a=0;while(1){b=ZX(d,0)|0;if((b|0)==0){e=-12;i=11;break}j=c[(c[(c[g>>2]|0)+(a<<2)>>2]|0)+8>>2]|0;k=c[b+8>>2]|0;nWa(k,j)|0;l=c[(c[f>>2]|0)+32>>2]|0;m=j+52|0;do{if((l|0)==0){i=8}else{n=NX(l,c[m>>2]|0)|0;if((n|0)==(c[k+48>>2]|0)){i=8;break}if((LX(c[(c[f>>2]|0)+32>>2]|0,c[j+48>>2]|0)|0)==0){i=8;break}c[k+52>>2]=0}}while(0);if((i|0)==8){i=0;c[k+52>>2]=c[m>>2]}j=(c[(c[g>>2]|0)+(a<<2)>>2]|0)+80|0;l=b+80|0;n=c[j+4>>2]|0;c[l>>2]=c[j>>2];c[l+4>>2]=n;n=a+1|0;if(n>>>0<(c[h>>2]|0)>>>0){a=n}else{e=0;i=11;break}}if((i|0)==11){return e|0}return 0}function EU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+12>>2]|0;e=c[d+20>>2]|0;f=c[d+8>>2]|0;g=d+4|0;h=c[g>>2]|0;if((f|0)==0){j=h}else{k=(h|0)%(f|0)|0;c[g>>2]=k;j=k}k=e+32|0;g=a+32|0;if((jX(k,1024,g,j)|0)<0){KIb(e,16,2129968,(l=i,i=i+8|0,c[l>>2]=g,l)|0);i=l;m=-22;i=b;return m|0}g=(lrc(KFb(k)|0)|0)+1|0;e=d+40|0;j=c[e>>2]|0;if((j|0)==0){n=g}else{n=(lrc(j|0)|0)+g|0}g=pJb(n)|0;c[d+176>>2]=g;if((g|0)==0){m=-12;i=b;return m|0}d=c[e>>2]|0;e=KFb(k)|0;Rb(g|0,n|0,2128520,(l=i,i=i+16|0,c[l>>2]=(d|0)==0?10229992:d,c[l+8>>2]=e,l)|0)|0;i=l;m=0;i=b;return m|0}function FU(a){a=a|0;var b=0,e=0,f=0,g=0;if((c[a+8>>2]|0)<806){b=0;return b|0}e=c[a+4>>2]|0;a=e;if(!((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==814)){b=0;return b|0}a=e+12|0;f=(d[a]|d[a+1|0]<<8)<<16>>16;a=e+14|0;g=(d[a]|d[a+1|0]<<8)<<16>>16;a=e+804|0;e=(d[a]|d[a+1|0]<<8)<<16>>16;do{if(f<<16>>16==0|(f&65535)>>>0>2048>>>0){if(e<<16>>16==22050){break}else{b=0}return b|0}else{if((g&65535)>>>0<2049>>>0&g<<16>>16!=0|e<<16>>16==22050){break}else{b=0}return b|0}}while(0);b=50;return b|0}function GU(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;e=i;i=i+40|0;f=e|0;g=e+8|0;h=e+24|0;j=e+32|0;k=c[b+12>>2]|0;l=c[b+16>>2]|0;fD(l,0,0,0)|0;m=k+44|0;if((AD(l,m,816)|0)!=816){n=-5;i=e;return n|0}o=k+56|0;p=(d[o]|d[o+1|0]<<8)<<16>>16;o=p&65535;q=k+58|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;q=r&65535;do{if(p<<16>>16==0|r<<16>>16==0){s=0}else{do{if((a[k+68|0]|0)==105){if((a[k+69|0]|0)!=118){t=7;break}if((a[k+70|0]|0)!=51){t=7;break}c[k+24>>2]=1}else{t=7}}while(0);if((t|0)==7){c[k+24>>2]=0}u=ZX(b,0)|0;if((u|0)==0){n=-12;i=e;return n|0}_X(u,33,1,10);c[k>>2]=c[u>>2];v=u+8|0;w=c[v>>2]|0;c[w+8>>2]=0;x=k+24|0;c[w+48>>2]=(c[x>>2]|0)!=0?29:53;c[w+52>>2]=0;y=w+120|0;c[y>>2]=o;z=w+124|0;c[z>>2]=q;if((c[x>>2]|0)!=0&(p&65535)>>>0>320>>>0){c[y>>2]=o>>>1;c[z>>2]=q>>>1}if((PX(w,816)|0)==0){nrc(c[(c[v>>2]|0)+96>>2]|0,m|0,816)|0;s=u;break}else{n=-12;i=e;return n|0}}}while(0);m=k+848|0;q=(d[m]|d[m+1|0]<<8)<<16>>16;m=k+28|0;c[m>>2]=q&65535;if(q<<16>>16==0){A=0}else{q=ZX(b,0)|0;if((q|0)==0){n=-12;i=e;return n|0}c[k+4>>2]=c[q>>2];o=c[q+8>>2]|0;c[o+8>>2]=1;c[o+48>>2]=86027;c[o+52>>2]=0;p=o+416|0;if((a[k+855|0]|0)<0){c[p>>2]=2;r=o+448|0;c[r>>2]=3;c[r+4>>2]=0;B=2}else{c[p>>2]=1;r=o+448|0;c[r>>2]=4;c[r+4>>2]=0;B=1}r=c[m>>2]|0;m=o+412|0;c[m>>2]=r;u=k+850|0;v=(d[u]|d[u+1|0]<<8)<<16>>16&65535;u=o+432|0;c[u>>2]=v;w=o+792|0;if((v&32768|0)==0){c[w>>2]=8;C=8;D=v}else{c[w>>2]=16;w=65536-v|0;c[u>>2]=w;C=16;D=w}c[o+72>>2]=ca(ca(C,r)|0,B)|0;c[h>>2]=D;B=ca(c[p>>2]|0,c[m>>2]|0)|0;c[j>>2]=B;xKb(h,j,D,(D|0)<0|0?-1:0,B,(B|0)<0|0?-1:0,2147483647,0)|0;if((s|0)!=0){_X(s,33,c[h>>2]|0,c[j>>2]|0)}_X(q,33,c[h>>2]|0,c[j>>2]|0);A=q}q=k+856|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+50|0;h=k+8|0;c[h>>2]=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=k+62|0;s=k+12|0;c[s>>2]=(d[q]|d[q+1|0]<<8)<<16>>16&65535;fD(l,j,0,0)|0;c[f>>2]=0;j=k+16|0;q=j;c[q>>2]=0;B=k+852|0;D=(d[B]|d[B+1|0]<<8)<<16>>16&65535;B=c[h>>2]|0;m=B*6|0;if(!((ca(c[s>>2]|0,B)|0)>>>0<(76695844-D|0)>>>0)){KIb(b,16,2211904,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;n=-1;i=e;return n|0}c[f>>2]=hJb(m)|0;B=hJb(((ca(c[s>>2]|0,c[h>>2]|0)|0)+D|0)*56|0)|0;c[q>>2]=B;p=c[f>>2]|0;a:do{if((p|0)==0|(B|0)==0){F=-12}else{if((AD(l,p,m)|0)!=(m|0)){F=-5;break}r=c[h>>2]|0;b:do{if((r|0)==0){H=0}else{C=g|0;o=g+2|0;w=(A|0)==0;u=k+4|0;v=D-1|0;z=v;y=(v|0)<0|0?-1:0;v=k;x=0;I=0;J=0;K=0;L=c[s>>2]|0;M=r;c:while(1){N=(c[f>>2]|0)+((x*6|0)+2)|0;O=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;N=0;if((L|0)==0){P=I;Q=J;R=K;S=0;T=M}else{U=x;V=(x|0)<0|0?-1:0;if(w){W=0;X=N;Y=O;Z=I;while(1){_=AD(l,C,16)|0;if((_|0)!=16){$=_;t=40;break c}_=a[C]|0;aa=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;if(aa>>>0>1073741823>>>0){t=42;break c}if((aa|0)!=0|_<<24>>24==1){if(_<<24>>24==2){_=c[q>>2]|0;ba=_+(Z*56|0)+8|0;c[ba>>2]=Y;c[ba+4>>2]=X;c[_+(Z*56|0)>>2]=c[v>>2];c[_+(Z*56|0)+16>>2]=aa;nrc(_+(Z*56|0)+36|0,C|0,16)|0;_=(c[q>>2]|0)+(Z*56|0)+24|0;c[_>>2]=U;c[_+4>>2]=V;da=Z+1|0}else{da=Z}_=wrc(aa,0,Y,X)|0;ea=da;fa=G;ga=_}else{ea=Z;fa=X;ga=Y}_=W+1|0;aa=c[s>>2]|0;if(_>>>0<aa>>>0){W=_;X=fa;Y=ga;Z=ea}else{ha=ea;ia=J;ja=K;ka=aa;break}}}else{Z=0;Y=N;X=O;W=I;aa=J;_=K;while(1){ba=AD(l,C,16)|0;if((ba|0)!=16){$=ba;t=40;break c}ba=a[C]|0;la=ba&255;ma=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;if(ma>>>0>1073741823>>>0){t=42;break c}if((ma|0)!=0|ba<<24>>24==1){if((la|0)==1){ba=c[q>>2]|0;na=ba+(W*56|0)+8|0;c[na>>2]=X;c[na+4>>2]=Y;c[ba+(W*56|0)>>2]=c[u>>2];c[ba+(W*56|0)+16>>2]=ma;nrc(ba+(W*56|0)+36|0,C|0,16)|0;ba=(c[q>>2]|0)+(W*56|0)+24|0;c[ba>>2]=_;c[ba+4>>2]=aa;ba=(_|0)==0&(aa|0)==0;na=wrc(_,aa,1,0)|0;oa=ba?y:G;pa=ba?z:na;qa=W+1|0}else if((la|0)==2){la=c[q>>2]|0;na=la+(W*56|0)+8|0;c[na>>2]=X;c[na+4>>2]=Y;c[la+(W*56|0)>>2]=c[v>>2];c[la+(W*56|0)+16>>2]=ma;nrc(la+(W*56|0)+36|0,C|0,16)|0;la=(c[q>>2]|0)+(W*56|0)+24|0;c[la>>2]=U;c[la+4>>2]=V;oa=aa;pa=_;qa=W+1|0}else{oa=aa;pa=_;qa=W}la=wrc(ma,0,X,Y)|0;ra=oa;sa=pa;ta=qa;ua=G;va=la}else{ra=aa;sa=_;ta=W;ua=Y;va=X}la=Z+1|0;ma=c[s>>2]|0;if(la>>>0<ma>>>0){Z=la;Y=ua;X=va;W=ta;aa=ra;_=sa}else{ha=ta;ia=ra;ja=sa;ka=ma;break}}}P=ha;Q=ia;R=ja;S=ka;T=c[h>>2]|0}_=x+1|0;if(_>>>0<T>>>0){x=_;I=P;J=Q;K=R;L=S;M=T}else{H=P;break b}}if((t|0)==40){KIb(b,16,2179176,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=($|0)>-1?-1094995529:$;break a}else if((t|0)==42){KIb(b,16,2151560,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;break a}}}while(0);kJb(c[f>>2]|0);c[k+20>>2]=0;c[h>>2]=H;n=0;i=e;return n|0}}while(0);mJb(f);mJb(j);n=F;i=e;return n|0}function HU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=c[b+12>>2]|0;g=c[b+16>>2]|0;h=f+20|0;j=c[h>>2]|0;if(!(j>>>0<(c[f+8>>2]|0)>>>0)){k=-541478725;i=e;return k|0}l=c[f+16>>2]|0;m=l+(j*56|0)+8|0;fD(g,c[m>>2]|0,c[m+4>>2]|0,0)|0;m=l+(j*56|0)+16|0;n=eX(g,c[m>>2]|0)|0;if((n|0)!=(c[m>>2]|0)){k=-5;i=e;return k|0}if((K1(d,n+16|0)|0)!=0){k=-12;i=e;return k|0}n=fD(g,0,0,1)|0;o=d+64|0;c[o>>2]=n;c[o+4>>2]=G;o=d+24|0;n=l+(j*56|0)+36|0;nrc(c[o>>2]|0,n|0,16)|0;do{if((c[f+24>>2]|0)==0){p=7}else{if((a[n]|0)!=2){p=7;break}q=AD(g,c[o>>2]|0,c[m>>2]|0)|0}}while(0);if((p|0)==7){q=AD(g,(c[o>>2]|0)+16|0,c[m>>2]|0)|0}if((q|0)==(c[m>>2]|0)){r=q}else{P1(d);r=-5}c[d+32>>2]=c[l+(j*56|0)>>2];q=l+(j*56|0)+24|0;j=c[q>>2]|0;l=c[q+4>>2]|0;q=d+8|0;c[q>>2]=j;c[q+4>>2]=l;q=(c[m>>2]|0)+16|0;KIb(b,48,2376912,(b=i,i=i+32|0,c[b>>2]=(a[n]|0)==2?2309280:2256704,c[b+8>>2]=q,c[b+16>>2]=j,c[b+24>>2]=l,b)|0);i=b;c[h>>2]=(c[h>>2]|0)+1;k=r;i=e;return k|0}function IU(a){a=a|0;mJb((c[a+12>>2]|0)+16|0);return 0}function JU(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1179011411){e=0;return e|0}a=b+8|0;b=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((b|0)==1314213715|(b|0)==827736662)){e=0;return e|0}e=100;return e|0}function KU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+16>>2]|0;e=c[a+12>>2]|0;if((FD(d)|0)!=1179011411){f=-1094995529;i=b;return f|0}hD(d,4,0)|0;g=FD(d)|0;do{if((g|0)==1314213715){if((FD(d)|0)!=1380206675){KIb(a,16,2211840,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}if((JD(d)|0)!=8){KIb(a,16,2179104,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}hD(d,4,0)|0;j=e+8|0;c[j>>2]=DD(d)|0;k=DD(d)|0;c[e+12>>2]=k;c[e+16>>2]=ca(c[j>>2]|0,k>>3)|0;k=ZX(a,0)|0;if((k|0)==0){f=-12;i=b;return f|0}else{l=c[k+8>>2]|0;c[l+8>>2]=1;c[l+48>>2]=65541;c[l+416>>2]=1;m=l+448|0;c[m>>2]=4;c[m+4>>2]=0;c[l+792>>2]=8;c[l+412>>2]=c[j>>2];_X(k,16,1,c[j>>2]|0);j=k+48|0;c[j>>2]=0;c[j+4>>2]=0;break}}else if((g|0)==827736662){if((FD(d)|0)!=1145586262){KIb(a,16,2211840,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}if((JD(d)|0)!=32){KIb(a,16,2179104,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}if((DD(d)|0)!=1){KIb(a,16,2151456,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}j=DD(d)|0;k=DD(d)|0;hD(d,4,0)|0;l=DD(d)|0;m=e;c[m>>2]=l;if((l|0)==0){KIb(a,16,2127040,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}l=e+12|0;c[l>>2]=DD(d)|0;n=DD(d)|0;o=e+8|0;c[o>>2]=n;c[e+16>>2]=ca(c[l>>2]>>3,n)|0;hD(d,16,0)|0;n=ZX(a,0)|0;if((n|0)==0){f=-12;i=b;return f|0}l=c[n+8>>2]|0;c[l+8>>2]=0;c[l+48>>2]=109;c[l+52>>2]=827736662;c[l+120>>2]=j;c[l+124>>2]=k;c[l+140>>2]=11;l=c[m>>2]|0;m=l;k=(l|0)<0|0?-1:0;l=n+56|0;c[l>>2]=m;c[l+4>>2]=k;l=n+64|0;c[l>>2]=m;c[l+4>>2]=k;_X(n,16,1,12);c[e+4>>2]=0;c[e+20>>2]=1;n=(c[o>>2]|0)!=0;c[e+24>>2]=n&1;c[e+28>>2]=-1;if(!n){break}n=ZX(a,0)|0;if((n|0)==0){f=-12;i=b;return f|0}else{k=c[n+8>>2]|0;c[k+8>>2]=1;c[k+48>>2]=65541;c[k+416>>2]=1;l=k+448|0;c[l>>2]=4;c[l+4>>2]=0;c[k+792>>2]=8;c[k+412>>2]=c[o>>2];_X(n,16,1,c[o>>2]|0);o=n+48|0;c[o>>2]=0;c[o+4>>2]=0;break}}else{KIb(a,16,2309240,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}}while(0);if((FD(d)|0)==1497648962){hD(d,4,0)|0;f=0;i=b;return f|0}else{KIb(a,16,2256640,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;f=-1094995529;i=b;return f|0}return 0}function LU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[b+12>>2]|0;a:do{if((c[e+20>>2]|0)==0){f=fX(c[b+16>>2]|0,d,c[e+16>>2]|0)|0;if((f|0)==0){g=-541478725;return g|0}if((f|0)<0){g=-5;return g|0}else{c[d+48>>2]=f;break}}else{f=e+4|0;if((c[f>>2]|0)>=(c[e>>2]|0)){g=-541478725;return g|0}h=e+28|0;i=c[h>>2]|0;if((i|0)==-1){j=b+16|0;c[e+32>>2]=(FD(c[j>>2]|0)|0)-4;k=DD(c[j>>2]|0)|0;l=e+44|0;c[l>>2]=k;m=k&1;n=m<<2;c[e+36>>2]=n;if((m|0)==0){o=k}else{AD(c[j>>2]|0,e+48|0,n)|0;o=c[l>>2]|0}if((o&4|0)==0){p=0;q=o}else{n=FD(c[j>>2]|0)|0;p=n;q=c[l>>2]|0}c[e+40>>2]=p;l=q>>>2&1;c[h>>2]=l;r=l}else{r=i}do{if((r|0)==0){i=e+32|0;l=e+40|0;n=e+36|0;j=b+16|0;k=eX(c[j>>2]|0,(c[i>>2]|0)-2-(c[l>>2]|0)-(c[n>>2]|0)|0)|0;if((k|0)<0){g=-1094995529;return g|0}if((c[i>>2]|0)<(c[l>>2]|0)){g=-1094995529;return g|0}if((K1(d,k+2+(c[n>>2]|0)|0)|0)<0){g=-12;return g|0}l=d+24|0;i=c[l>>2]|0;y=c[e+44>>2]&65535;a[i]=y;y=y>>8;a[i+1|0]=y;i=c[n>>2]|0;if((i|0)==0){s=2}else{nrc((c[l>>2]|0)+2|0,e+48|0,i)|0;s=(c[n>>2]|0)+2|0}if((AD(c[j>>2]|0,(c[l>>2]|0)+s|0,k)|0)==(k|0)){c[d+32>>2]=0;c[h>>2]=-1;break}P1(d);g=-1094995529;return g|0}else{k=fX(c[b+16>>2]|0,d,(c[e+40>>2]|0)-4|0)|0;if((k|0)<0){g=-5;return g|0}else{c[d+32>>2]=1;c[d+48>>2]=k;c[h>>2]=0;if((c[f>>2]|0)==0){break}else{break a}}}}while(0);k=d+36|0;c[k>>2]=c[k>>2]|1;if(!((c[h>>2]|0)==-1)){break}c[f>>2]=(c[f>>2]|0)+1}}while(0);g=c[d+28>>2]|0;return g|0}function MU(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((e|0)==843795795|(e|0)==877350227)){f=0;return f|0}e=b+4|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>0>32768>>>0){f=25;return f|0}else{f=b+8|0;return((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)>>>0>32768>>>0?25:100)|0}return 0}function NU(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;e=i;i=i+8|0;f=e|0;g=c[b+16>>2]|0;h=c[b+12>>2]|0;j=FD(g)|0;k=h;c[k>>2]=j;if(!((j|0)==843795795|(j|0)==877350227)){l=-1094995529;i=e;return l|0}j=h+4|0;c[j>>2]=FD(g)|0;m=h+8|0;c[m>>2]=FD(g)|0;n=h+12|0;c[n>>2]=FD(g)|0;o=h+16|0;c[o>>2]=FD(g)|0;p=FD(g)|0;c[h+20>>2]=p;if((p&1|0)!=0){c[n>>2]=(c[n>>2]|0)+1}c[h+24>>2]=FD(g)|0;c[h+28>>2]=FD(g)|0;c[h+32>>2]=FD(g)|0;c[h+36>>2]=FD(g)|0;c[h+40>>2]=FD(g)|0;c[h+44>>2]=FD(g)|0;c[h+48>>2]=FD(g)|0;p=FD(g)|0;q=h+52|0;c[q>>2]=p;if(p>>>0>1073741822>>>0){KIb(b,16,2305256,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;l=-1094995529;i=e;return l|0}p=h+56|0;c[p>>2]=FD(g)|0;s=h+60|0;c[s>>2]=FD(g)|0;t=h+64|0;c[t>>2]=FD(g)|0;u=h+68|0;c[u>>2]=FD(g)|0;v=h+80|0;w=v;c[v>>2]=ED(g)|0;a[h+72|0]=zD(g)|0;c[h+84>>2]=ED(g)|0;a[h+73|0]=zD(g)|0;c[h+88>>2]=ED(g)|0;a[h+74|0]=zD(g)|0;c[h+92>>2]=ED(g)|0;a[h+75|0]=zD(g)|0;c[h+96>>2]=ED(g)|0;a[h+76|0]=zD(g)|0;c[h+100>>2]=ED(g)|0;a[h+77|0]=zD(g)|0;c[h+104>>2]=ED(g)|0;a[h+78|0]=zD(g)|0;c[h+108>>2]=FD(g)|0;v=c[n>>2]|0;if(v>>>0>16777215>>>0){KIb(b,16,2253320,(r=i,i=i+8|0,c[r>>2]=v,r)|0);i=r;l=-1094995529;i=e;return l|0}x=h+112|0;y=x;c[y>>2]=hJb(v<<2)|0;v=hJb(c[n>>2]|0)|0;z=h+116|0;A=z;c[A>>2]=v;if((c[y>>2]|0)==0|(v|0)==0){mJb(x);mJb(z);l=-12;i=e;return l|0}c[h+124>>2]=(c[k>>2]|0)!=843795795;do{if((c[n>>2]|0)!=0){v=0;do{B=FD(g)|0;c[(c[y>>2]|0)+(v<<2)>>2]=B;v=v+1|0;C=c[n>>2]|0;}while(v>>>0<C>>>0);if((C|0)==0){break}else{D=0}do{v=(zD(g)|0)&255;a[(c[A>>2]|0)+D|0]=v;D=D+1|0;}while(D>>>0<(c[n>>2]|0)>>>0)}}while(0);D=ZX(b,0)|0;if((D|0)==0){l=-12;i=e;return l|0}c[h+932>>2]=c[D>>2];A=D+8|0;C=c[A>>2]|0;c[C+120>>2]=c[j>>2];c[C+124>>2]=c[m>>2];c[C+140>>2]=11;c[C+8>>2]=0;c[C+48>>2]=84;c[C+52>>2]=c[k>>2];k=c[o>>2]|0;if((k|0)<0){E=-k|0}else{E=k*100|0}c[o>>2]=E;c[f>>2]=1e5;E=c[o>>2]|0;xKb(f,o,1e5,0,E,(E|0)<0|0?-1:0,2147483647,0)|0;_X(D,33,c[o>>2]|0,c[f>>2]|0);f=D+56|0;c[f>>2]=c[n>>2];c[f+4>>2]=0;f=h+904|0;n=0;do{D=f+(n<<2)|0;c[D>>2]=-1;o=w+(n<<2)|0;if((c[o>>2]|0)!=0){E=ZX(b,0)|0;if((E|0)==0){l=-12;F=40;break}c[D>>2]=c[E>>2];D=c[E+8>>2]|0;c[D+8>>2]=1;k=h+(n+72)|0;C=d[k]|0;do{if((C&8|0)==0){if((C&4|0)!=0){c[D+48>>2]=86065;H=86065;break}m=D+48|0;if((C&128|0)==0){c[m>>2]=65541;H=65541;break}else{c[m>>2]=86039;c[D+52>>2]=1095454035;H=86039;break}}else{c[D+48>>2]=86064;H=86064}}while(0);C=D+416|0;if((a[k]&16)==0){c[C>>2]=1;m=D+448|0;c[m>>2]=4;c[m+4>>2]=0;I=1}else{c[C>>2]=2;C=D+448|0;c[C>>2]=3;c[C+4>>2]=0;I=2}C=c[o>>2]|0;c[D+412>>2]=C;m=(a[k]&32)!=0;j=m?16:8;c[D+792>>2]=j;if(m&(H|0)==65541){c[D+48>>2]=65536}_X(E,64,1,(ca(ca(I,C)|0,j)|0)/8|0)}n=n+1|0;}while((n|0)<7);if((F|0)==40){i=e;return l|0}if((PX(c[A>>2]|0,(c[q>>2]|0)+16|0)|0)!=0){KIb(b,16,2210248,(r=i,i=i+8|0,c[r>>2]=(c[q>>2]|0)+16,r)|0);i=r;mJb(x);mJb(z);l=-12;i=e;return l|0}r=c[A>>2]|0;q=AD(g,(c[r+96>>2]|0)+16|0,(c[r+100>>2]|0)-16|0)|0;r=c[A>>2]|0;if((q|0)==((c[r+100>>2]|0)-16|0)){q=c[r+96>>2]|0;c[q>>2]=c[p>>2];c[q+4>>2]=c[s>>2];c[q+8>>2]=c[t>>2];c[q+12>>2]=c[u>>2];c[h+1020>>2]=-1;u=fD(g,0,0,1)|0;g=h+1024|0;c[g>>2]=u;c[g+4>>2]=G;l=0;i=e;return l|0}else{mJb(x);mJb(z);l=-5;i=e;return l|0}return 0}function OU(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;f=i;i=i+768|0;g=f|0;h=c[b+12>>2]|0;j=b+16|0;if((jD(c[j>>2]|0)|0)!=0){k=-541478725;i=f;return k|0}l=h+120|0;if(!((c[l>>2]|0)>>>0<(c[h+12>>2]|0)>>>0)){k=-541478725;i=f;return k|0}m=h+1020|0;n=c[m>>2]|0;if((n|0)>=0){o=h+992|0;if((c[o+(n<<2)>>2]|0)<0){k=-1094995529;i=f;return k|0}p=h+936|0;if((c[p+(n<<2)>>2]|0)==0){k=-1094995529;i=f;return k|0}q=h+964|0;if((K1(e,c[q+(n<<2)>>2]|0)|0)!=0){k=-12;i=f;return k|0}n=e+24|0;r=c[m>>2]|0;nrc(c[n>>2]|0,c[p+(r<<2)>>2]|0,c[q+(r<<2)>>2]|0)|0;c[e+28>>2]=c[q+(c[m>>2]<<2)>>2];c[e+32>>2]=c[o+(c[m>>2]<<2)>>2];o=h+1032+(c[m>>2]<<3)|0;q=c[o+4>>2]|0;r=e+8|0;c[r>>2]=c[o>>2];c[r+4>>2]=q;q=c[n>>2]|0;n=wrc(c[o>>2]|0,c[o+4>>2]|0,d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0,0)|0;c[o>>2]=n;c[o+4>>2]=G;c[m>>2]=(c[m>>2]|0)-1;k=0;i=f;return k|0}o=h+1024|0;fD(c[j>>2]|0,c[o>>2]|0,c[o+4>>2]|0,0)|0;n=c[l>>2]|0;q=h+112|0;r=c[(c[q>>2]|0)+(n<<2)>>2]&-4;p=d[(c[h+116>>2]|0)+n|0]|0;if((p&1|0)==0){s=0;t=r}else{n=h+136|0;nrc(g|0,n|0,768)|0;u=(zD(c[j>>2]|0)|0)<<2;if((u|0)>(r|0)){k=-1094995529;i=f;return k|0}v=r-1+(1-u)|0;r=fD(c[j>>2]|0,0,0,1)|0;w=wrc(r,G,u-1|0,0)|0;u=0;r=n;n=c[j>>2]|0;a:while(1){x=zD(n)|0;do{if((x&128|0)==0){if((x&64|0)==0){a[r]=a[563432+x|0]|0;a[r+1|0]=a[563432+((zD(c[j>>2]|0)|0)&63)|0]|0;a[r+2|0]=a[563432+((zD(c[j>>2]|0)|0)&63)|0]|0;y=r+3|0;z=u+1|0;break}A=zD(c[j>>2]|0)|0;B=(x&63)+1|0;if((A+B|0)>256){C=12;break a}if((u|0)>=256){C=14;break a}D=(x|-64)^63;E=u-256|0;F=D>>>0>E>>>0?D:E;E=F*-3|0;D=u;H=A*3|0;I=B;J=r;while(1){K=I-1|0;a[J]=a[g+H|0]|0;a[J+1|0]=a[g+(H+1)|0]|0;a[J+2|0]=a[g+(H+2)|0]|0;L=D+1|0;if((K|0)!=0&(L|0)<256){D=L;H=H+3|0;I=K;J=J+3|0}else{break}}y=r+E|0;z=u-F|0}else{J=(x&127)+1|0;y=r+(J*3|0)|0;z=J+u|0}}while(0);x=c[j>>2]|0;if((z|0)<256){u=z;r=y;n=x}else{M=x;break}}if((C|0)==12){KIb(b,16,2462688,(N=i,i=i+16|0,c[N>>2]=A,c[N+8>>2]=B,N)|0);i=N;k=-1094995529;i=f;return k|0}else if((C|0)==14){M=c[j>>2]|0}B=w;fD(M,B,(B|0)<0|0?-1:0,0)|0;s=1;t=v}c[m>>2]=-1;v=h+936|0;B=h+964|0;M=h+904|0;w=h+992|0;A=t;t=0;n=p>>>1;while(1){if((n&1|0)==0){O=A}else{p=FD(c[j>>2]|0)|0;y=p-4|0;if((y|0)==0|p>>>0>A>>>0){C=23;break}r=(c[m>>2]|0)+1|0;c[m>>2]=r;P=lJb(v+(r<<2)|0,y)|0;Q=B+(c[m>>2]<<2)|0;if((P|0)<0){C=25;break}c[Q>>2]=y;if((AD(c[j>>2]|0,c[v+(c[m>>2]<<2)>>2]|0,y)|0)!=(y|0)){k=-5;C=39;break}c[w+(c[m>>2]<<2)>>2]=c[M+(t<<2)>>2];O=A-4+(4-p)|0}p=t+1|0;if((p|0)<7){A=O;t=p;n=n>>1}else{C=29;break}}if((C|0)==23){KIb(b,16,2371352,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;k=-1094995529;i=f;return k|0}else if((C|0)==25){c[Q>>2]=0;k=P;i=f;return k|0}else if((C|0)==29){if(O>>>0>1073741822>>>0){k=-1094995529;i=f;return k|0}P=O+769|0;if((K1(e,P)|0)!=0){k=-12;i=f;return k|0}if((c[(c[q>>2]|0)+(c[l>>2]<<2)>>2]&1|0)==0){R=s&255}else{R=(s|2)&255}s=e+24|0;a[c[s>>2]|0]=R;nrc((c[s>>2]|0)+1|0,h+136|0,768)|0;if((AD(c[j>>2]|0,(c[s>>2]|0)+769|0,O)|0)!=(O|0)){k=-5;i=f;return k|0}c[e+32>>2]=c[h+932>>2];h=c[l>>2]|0;O=e+8|0;c[O>>2]=h;c[O+4>>2]=(h|0)<0|0?-1:0;c[e+28>>2]=P;c[l>>2]=(c[l>>2]|0)+1;l=fD(c[j>>2]|0,0,0,1)|0;c[o>>2]=l;c[o+4>>2]=G;k=0;i=f;return k|0}else if((C|0)==39){i=f;return k|0}return 0}function PU(a){a=a|0;var b=0;b=c[a+12>>2]|0;mJb(b+936|0);mJb(b+940|0);mJb(b+944|0);mJb(b+948|0);mJb(b+952|0);mJb(b+956|0);mJb(b+960|0);mJb(b+112|0);mJb(b+116|0);return 0}function QU(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,2643544,8)|0)==0;return(b?100:0)|0}function RU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+8|0;e=d|0;f=c[b+12>>2]|0;g=c[b+16>>2]|0;hD(g,8,0)|0;h=JD(g)|0;if((h|0)!=0){QIb(b,2305232,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j}h=JD(g)|0;if((jD(g)|0)!=0){k=-541478725;i=d;return k|0}l=b+1140|0;m=h;h=0;n=f;o=f+4|0;f=0;p=0;a:while(1){q=p;b:while(1){while(1){r=FD(g)|0;if((r|0)==1145983839){break}else if((r|0)==1145656927){break b}else if((r|0)==1145980232){k=0;s=24;break a}else if((r|0)!=1415074911){s=23;break a}t=JD(g)|0;if((t|0)==0|t>>>0>512>>>0){k=-1094995529;s=24;break a}u=hJb(t+1|0)|0;c[e>>2]=u;if((u|0)==0){k=-12;s=24;break a}if((AD(g,u,t)|0)!=(t|0)){s=11;break a}a[u+t|0]=0;MGb(l,2210240,u,8)|0;if((jD(g)|0)!=0){k=-541478725;s=24;break a}}if((q|0)!=0){s=14;break a}u=JD(g)|0;if(u>>>0<8>>>0){k=-1094995529;s=24;break a}t=ZX(b,0)|0;if((t|0)==0){k=-12;s=24;break a}v=t+8|0;c[(c[v>>2]|0)+8>>2]=1;w=HD(g)|0;c[(c[v>>2]|0)+412>>2]=w;w=zD(g)|0;c[(c[v>>2]|0)+792>>2]=w;w=zD(g)|0;c[(c[v>>2]|0)+416>>2]=w;w=FD(g)|0;c[(c[v>>2]|0)+52>>2]=w;x=JX(1407024,w)|0;c[(c[v>>2]|0)+48>>2]=x;x=t+56|0;c[x>>2]=m;c[x+4>>2]=h;c[n>>2]=c[t>>2];_X(t,32,1,1e3);hD(g,u-8|0,0)|0;if((jD(g)|0)==0){q=t}else{k=-541478725;s=24;break a}}if((f|0)!=0){s=19;break}t=JD(g)|0;if(t>>>0<12>>>0){k=-1094995529;s=24;break}u=ZX(b,0)|0;if((u|0)==0){k=-12;s=24;break}x=u+64|0;c[x>>2]=JD(g)|0;c[x+4>>2]=0;x=u+8|0;c[(c[x>>2]|0)+8>>2]=0;v=HD(g)|0;c[(c[x>>2]|0)+120>>2]=v;v=HD(g)|0;c[(c[x>>2]|0)+124>>2]=v;v=FD(g)|0;c[(c[x>>2]|0)+52>>2]=v;w=JX(1407008,v)|0;c[(c[x>>2]|0)+48>>2]=w;w=u+56|0;c[w>>2]=m;c[w+4>>2]=h;c[o>>2]=c[u>>2];_X(u,32,1,1e3);hD(g,t-12|0,0)|0;if((jD(g)|0)==0){f=u;p=q}else{k=-541478725;s=24;break}}if((s|0)==11){mJb(e);KIb(b,16,2253288,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=d;return k|0}else if((s|0)==14){QIb(b,2177504,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1163346256;i=d;return k|0}else if((s|0)==19){QIb(b,2149376,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=d;return k|0}else if((s|0)==23){KIb(b,16,2125464,(j=i,i=i+8|0,c[j>>2]=r,j)|0);i=j;k=-1094995529;i=d;return k|0}else if((s|0)==24){i=d;return k|0}return 0}function SU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+12>>2]|0;f=a+16|0;if((jD(c[f>>2]|0)|0)!=0){g=-541478725;i=d;return g|0}h=fD(c[f>>2]|0,0,0,1)|0;j=G;k=FD(c[f>>2]|0)|0;if((k|0)==1147431286){l=JD(c[f>>2]|0)|0;m=JD(c[f>>2]|0)|0;n=fX(c[f>>2]|0,b,m)|0;c[b+32>>2]=c[e+4>>2];m=b+8|0;c[m>>2]=l;c[m+4>>2]=0;m=b+64|0;c[m>>2]=h;c[m+4>>2]=j;g=n;i=d;return g|0}else if((k|0)==1147432563){n=JD(c[f>>2]|0)|0;m=JD(c[f>>2]|0)|0;l=fX(c[f>>2]|0,b,m)|0;c[b+32>>2]=c[e>>2];e=b+8|0;c[e>>2]=n;c[e+4>>2]=0;e=b+64|0;c[e>>2]=h;c[e+4>>2]=j;g=l;i=d;return g|0}else if((k|0)==1162760004){g=-541478725;i=d;return g|0}else{KIb(a,16,2371328,(a=i,i=i+8|0,c[a>>2]=k,a)|0);i=a;g=-1094995529;i=d;return g|0}return 0}function TU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+16>>2]|0;e=a+24|0;if((c[e>>2]|0)>>>0>2>>>0){KIb(a,16,2462640,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}dD(d,2371312,8);lD(d,0);lD(d,0);h=a+1140|0;j=LGb(c[h>>2]|0,10230272,0,2)|0;if((j|0)!=0){k=j;do{kD(d,1415074911);j=k|0;l=lrc(c[j>>2]|0)|0;m=k+4|0;lD(d,l+3+(lrc(c[m>>2]|0)|0)|0);l=c[j>>2]|0;dD(d,l,lrc(l|0)|0);dD(d,2253280,3);l=c[m>>2]|0;dD(d,l,lrc(l|0)|0);k=LGb(c[h>>2]|0,10230272,k,2)|0;}while((k|0)!=0)}a:do{if((c[e>>2]|0)!=0){k=a+28|0;h=0;while(1){l=c[(c[k>>2]|0)+(h<<2)>>2]|0;m=c[l+8>>2]|0;j=c[m+8>>2]|0;if((j|0)==1){n=IX(1407024,c[m+48>>2]|0)|0;if((n|0)==0){o=9;break}kD(d,1145983839);lD(d,8);tD(d,c[m+412>>2]|0);bD(d,c[m+792>>2]|0);bD(d,c[m+416>>2]|0);kD(d,n);_X(l,32,1,1e3)}else if((j|0)==0){j=IX(1407008,c[m+48>>2]|0)|0;if((j|0)==0){o=12;break}kD(d,1145656927);lD(d,12);lD(d,0);tD(d,c[m+120>>2]|0);tD(d,c[m+124>>2]|0);kD(d,j);_X(l,32,1,1e3)}h=h+1|0;if(!(h>>>0<(c[e>>2]|0)>>>0)){break a}}if((o|0)==9){KIb(a,16,2210208,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else if((o|0)==12){KIb(a,16,2177472,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}}}while(0);kD(d,1145980232);eD(d);g=0;i=b;return g|0}function UU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=c[(c[(c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0)+8>>2]|0)+8>>2]|0;if((f|0)==1){kD(e,1147432563)}else if((f|0)==0){kD(e,1147431286)}else{return 0}f=b+8|0;lD(e,c[f>>2]|0);a=b+28|0;lD(e,c[a>>2]|0);dD(e,c[b+24>>2]|0,c[a>>2]|0);a=d;d=c[a>>2]|0;e=0;g=c[b+48>>2]|0;b=wrc(g,(g|0)<0|0?-1:0,c[f>>2]|0,c[f+4>>2]|0)|0;f=G;c[a>>2]=(e|0)>(f|0)|(e|0)==(f|0)&d>>>0>b>>>0?d:b;return 0}function VU(a){a=a|0;var b=0,d=0,e=0;b=c[a+16>>2]|0;if((c[b+88>>2]|0)==0){kD(b,1162760004);return 0}d=c[a+12>>2]|0;a=fD(b,0,0,1)|0;e=G;fD(b,12,0,0)|0;lD(b,c[d>>2]|0);fD(b,a,e,0)|0;kD(b,1162760004);return 0}function WU(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;b=i;i=i+40|0;e=b|0;f=b+8|0;g=b+16|0;h=b+24|0;j=c[a+12>>2]|0;k=a+32|0;a:do{if((ob(k|0,511)|0)<0){KIb(a,16,2470184,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-(c[(pd()|0)>>2]|0)|0;n=41}else{o=gH(2461448,0,0)|0;if((o|0)==0){p=-1481985528;break}q=a+24|0;r=pJb((c[q>>2]|0)*33880|0)|0;s=r;t=j+24|0;c[t>>2]=s;if((r|0)==0){p=-12;break}b:do{if((c[q>>2]|0)==0){u=j+28|0}else{r=a+28|0;v=a+1160|0;w=h|0;x=j+12|0;y=j+28|0;z=j+32|0;A=0;B=s;c:while(1){C=B+(A*33880|0)|0;c[g>>2]=0;D=c[(c[(c[(c[r>>2]|0)+(A<<2)>>2]|0)+8>>2]|0)+72>>2]|0;if((D|0)==0){n=9;break}E=B+(A*33880|0)+8|0;Rb(E|0,1024,2431656,(l=i,i=i+16|0,c[l>>2]=k,c[l+8>>2]=D,l)|0)|0;i=l;if((ob(E|0,511)|0)<0){n=11;break}E=HR()|0;if((E|0)==0){p=-12;break a}D=C|0;c[D>>2]=E;c[E+8>>2]=o;F=E+1160|0;G=c[v+4>>2]|0;c[F>>2]=c[v>>2];c[F+4>>2]=G;G=ZX(E,0)|0;if((G|0)==0){p=-12;break a}F=G+8|0;nWa(c[F>>2]|0,c[(c[(c[r>>2]|0)+(A<<2)>>2]|0)+8>>2]|0)|0;H=(c[(c[r>>2]|0)+(A<<2)>>2]|0)+80|0;I=G+80|0;J=c[H+4>>2]|0;c[I>>2]=c[H>>2];c[I+4>>2]=J;J=aD(B+(A*33880|0)+1032|0,32768,2,C,0,132,664)|0;C=E+16|0;c[C>>2]=J;if((J|0)==0){p=-12;break a}Rb(w|0,10,2422336,(l=i,i=i+8|0,c[l>>2]=c[x>>2],l)|0)|0;i=l;MGb(g,2412200,w,0)|0;MGb(g,2404760,2397360,0)|0;J=TO(E,g)|0;if((J|0)<0){p=J;break a}c[B+(A*33880|0)+4>>2]=1;eD(c[C>>2]|0);OGb(g);C=G+40|0;G=(c[(c[r>>2]|0)+(A<<2)>>2]|0)+40|0;J=c[C+4>>2]|0;c[G>>2]=c[C>>2];c[G+4>>2]=J;do{if((c[(c[F>>2]|0)+8>>2]|0)==0){c[y>>2]=1;c[B+(A*33880|0)+33844>>2]=2390296;J=c[(c[F>>2]|0)+48>>2]|0;if((J|0)==28){c[B+(A*33880|0)+33864>>2]=2383424;break}else if((J|0)==71){c[B+(A*33880|0)+33864>>2]=2376640;break}else{n=20;break c}}else{c[z>>2]=1;c[B+(A*33880|0)+33844>>2]=2355832;J=c[(c[F>>2]|0)+48>>2]|0;if((J|0)==86054){c[B+(A*33880|0)+33864>>2]=2340272;c[B+(A*33880|0)+33876>>2]=354}else if((J|0)==86018){c[B+(A*33880|0)+33864>>2]=2346384;c[B+(A*33880|0)+33876>>2]=255}else{n=24;break c}J=c[(c[F>>2]|0)+432>>2]|0;c[B+(A*33880|0)+33872>>2]=(J|0)==0?4:J}}while(0);F=c[(c[c[(c[D>>2]|0)+28>>2]>>2]|0)+8>>2]|0;J=F+96|0;G=c[J>>2]|0;c[e>>2]=G;c[f>>2]=c[F+100>>2];do{if((c[F+48>>2]|0)==28){r$(G,e,f)|0;if((c[e>>2]|0)!=0){n=30;break}C=c[J>>2]|0;c[e>>2]=C;K=C;n=29}else{K=G;n=29}}while(0);if((n|0)==29){n=0;if((K|0)!=0){n=30}}do{if((n|0)==30){n=0;G=pJb(c[f>>2]<<1|1)|0;F=B+(A*33880|0)+33868|0;c[F>>2]=G;do{if((c[f>>2]|0)>0){Rb(G|0,3,2323456,(l=i,i=i+8|0,c[l>>2]=d[c[e>>2]|0]|0,l)|0)|0;i=l;if((c[f>>2]|0)>1){L=1}else{break}do{Rb((c[F>>2]|0)+(L<<1)|0,3,2323456,(l=i,i=i+8|0,c[l>>2]=d[(c[e>>2]|0)+L|0]|0,l)|0)|0;i=l;L=L+1|0;}while((L|0)<(c[f>>2]|0))}}while(0);F=c[e>>2]|0;if((F|0)==(c[J>>2]|0)){break}kJb(F)}}while(0);J=A+1|0;if(!(J>>>0<(c[q>>2]|0)>>>0)){u=y;break b}A=J;B=c[t>>2]|0}if((n|0)==9){KIb(a,16,2444864,(l=i,i=i+8|0,c[l>>2]=A,l)|0);i=l;p=-22;break a}else if((n|0)==11){B=-(c[(pd()|0)>>2]|0)|0;KIb(a,16,2470184,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=B;n=41;break a}else if((n|0)==20){KIb(a,16,2370464,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;p=-22;break a}else if((n|0)==24){KIb(a,16,2334520,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;p=-22;break a}}}while(0);do{if((c[u>>2]|0)==0){if((c[j+16>>2]|0)>=1){break}KIb(a,24,2329496,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}}while(0);m=$U(a,0)|0;n=41}}while(0);do{if((n|0)==41){if((m|0)==0){M=0}else{p=m;break}i=b;return M|0}}while(0);_U(a);M=p;i=b;return M|0}function XU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=c[b+32>>2]|0;h=c[(c[a+28>>2]|0)+(g<<2)>>2]|0;j=c[f+24>>2]|0;k=f+36|0;l=c[k>>2]|0;m=wrc(l,(l|0)<0|0?-1:0,1,0)|0;l=c[f+16>>2]|0;n=Erc(m,G,l,(l|0)<0|0?-1:0)|0;l=G;m=h+200|0;o=c[m>>2]|0;p=c[m+4>>2]|0;if((o|0)==0&(p|0)==(-2147483648|0)){q=b+16|0;r=c[q>>2]|0;s=c[q+4>>2]|0;c[m>>2]=r;c[m+4>>2]=s;t=s;u=r}else{t=p;u=o}if((c[f+28>>2]|0)==0){v=5}else{if((c[(c[h+8>>2]|0)+8>>2]|0)==0){v=5}}do{if((v|0)==5){f=b+16|0;o=xrc(c[f>>2]|0,c[f+4>>2]|0,u,t)|0;c[e>>2]=1;c[e+4>>2]=1e6;if(!((YIb(o,G,h+40|0,n,l,e)|0)>-1)){break}if((c[b+36>>2]&1|0)==0){break}if((c[j+(g*33880|0)+33840>>2]|0)==0){break}o=ZU(a,0)|0;if((o|0)<0){w=o;i=d;return w|0}else{c[k>>2]=(c[k>>2]|0)+1;break}}}while(0);k=j+(g*33880|0)+33840|0;c[k>>2]=(c[k>>2]|0)+1;w=aP(c[j+(g*33880|0)>>2]|0,0,b,a)|0;i=d;return w|0}function YU(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+1024|0;d=c[a+12>>2]|0;ZU(a,1)|0;if((c[d+20>>2]|0)==0){_U(a);i=b;return 0}d=b|0;e=a+32|0;Rb(d|0,1024,2462624,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;be(d|0)|0;dd(e|0)|0;_U(a);i=b;return 0}function ZU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;d=i;i=i+11304|0;e=d|0;f=d+8|0;g=d+8208|0;h=c[a+12>>2]|0;j=a+24|0;a:do{if((c[j>>2]|0)==0){k=0}else{l=h+24|0;m=d+8232|0;n=a+1160|0;o=d+8216|0;p=d+10280|0;q=d+9256|0;r=d+16|0;s=0;t=0;u=0;v=0;w=0;x=0;b:while(1){y=c[l>>2]|0;z=y+(x*33880|0)+33816|0;A=c[z>>2]|0;B=c[z+4>>2]|0;C=y+(x*33880|0)+33840|0;c:do{if((c[C>>2]|0)==0){D=w;E=u;F=v;H=s;I=t}else{J=y+(x*33880|0)+8|0;Rb(m|0,1024,2371304,(K=i,i=i+8|0,c[K>>2]=J,K)|0)|0;i=K;L=y+(x*33880|0)+33800|0;M=RC(L,m,2,n,0)|0;if((M|0)<0){k=M;break a}M=c[z+4>>2]|0;N=y+(x*33880|0)+33832|0;c[N>>2]=c[z>>2];c[N+4>>2]=M;M=y+(x*33880|0)|0;UO(c[M>>2]|0,0)|0;eD(c[(c[M>>2]|0)+16>>2]|0);c[C>>2]=0;M=c[L>>2]|0;if((M|0)==0){O=-5;P=54;break b}if((c[y+(x*33880|0)+33808>>2]|0)!=0){O=-5;P=54;break b}SC(M)|0;c[L>>2]=0;L=xrc(c[z>>2]|0,c[z+4>>2]|0,A,B)|0;M=G;N=VD(g,m,1,n,0)|0;if((N|0)<0){k=N;break a}N=JD(c[g>>2]|0)|0;Q=N;R=0;d:do{if(N>>>0<8>>>0|((R|0)>(M|0)|(R|0)==(M|0)&Q>>>0>L>>>0)){S=-5;T=u;U=v;V=s;W=t}else{if((FD(c[g>>2]|0)|0)!=1718579053){S=-5;T=u;U=v;V=s;W=t;break}X=JD(c[g>>2]|0)|0;if(X>>>0>N>>>0){S=-5;T=u;U=v;V=s;W=t;break}if((FD(c[g>>2]|0)|0)!=1684563565){S=-5;T=u;U=v;V=s;W=t;break}fD(c[g>>2]|0,X-8|0,0,1)|0;JD(c[g>>2]|0)|0;if((FD(c[g>>2]|0)|0)!=1717662324){S=-5;T=u;U=v;V=s;W=t;break}X=fD(c[g>>2]|0,0,0,1)|0;Y=G;if(!((Y|0)<(R|0)|(Y|0)==(R|0)&X>>>0<Q>>>0)){S=-5;T=u;U=v;V=s;W=t;break}while(1){X=JD(c[g>>2]|0)|0;Y=FD(c[g>>2]|0)|0;Z=fD(c[g>>2]|0,0,0,1)|0;_=G;$=wrc(X,0,-8,-1)|0;aa=wrc($,G,Z,_)|0;_=G;if(!(X>>>0>7>>>0&X>>>0<N>>>0)){S=-5;T=u;U=v;V=s;W=t;break d}if((Y|0)==1684632949){AD(c[g>>2]|0,o,16)|0;if((grc(o,735296,16)|0)==0&X>>>0>43>>>0){break}}fD(c[g>>2]|0,aa,_,0)|0;_=fD(c[g>>2]|0,0,0,1)|0;aa=G;if(!((aa|0)<(R|0)|(aa|0)==(R|0)&_>>>0<Q>>>0)){S=-5;T=u;U=v;V=s;W=t;break d}}fD(c[g>>2]|0,4,0,1)|0;_=OD(c[g>>2]|0)|0;aa=G;X=OD(c[g>>2]|0)|0;S=0;T=G;U=X;V=aa;W=_}}while(0);WD(c[g>>2]|0)|0;if((S|0)<0){k=S;break a}_=y+(x*33880|0)+33844|0;aa=c[_>>2]|0;Rb(p|0,1024,2305200,(K=i,i=i+32|0,c[K>>2]=J,c[K+8>>2]=aa,c[K+16>>2]=W,c[K+24>>2]=V,K)|0)|0;i=K;aa=c[_>>2]|0;Rb(q|0,1024,2253256,(K=i,i=i+32|0,c[K>>2]=J,c[K+8>>2]=aa,c[K+16>>2]=W,c[K+24>>2]=V,K)|0)|0;i=K;do{if((VD(e,m,1,n,0)|0)>=0){if((VD(f,p,2,n,0)|0)<0){WD(c[e>>2]|0)|0;break}e:do{if((N|0)!=0){aa=R;_=Q;do{X=0;Y=AD(c[e>>2]|0,r,(aa|0)>(X|0)|(aa|0)==(X|0)&_>>>0>8192>>>0?8192:_)|0;if((Y|0)<1){break e}dD(c[f>>2]|0,r,Y);_=xrc(_,aa,Y,(Y|0)<0|0?-1:0)|0;aa=G;Y=0;}while((aa|0)>(Y|0)|(aa|0)==(Y|0)&_>>>0>0>>>0)}}while(0);eD(c[f>>2]|0);WD(c[f>>2]|0)|0;WD(c[e>>2]|0)|0}}while(0);Gc(m|0,q|0)|0;Q=y+(x*33880|0)+33848|0;R=y+(x*33880|0)+33852|0;N=c[R>>2]|0;do{if((c[Q>>2]|0)>=(N|0)){K=(N<<1)+2|0;c[R>>2]=K;if((lJb(y+(x*33880|0)+33860|0,K<<2)|0)>=0){break}c[R>>2]=0;c[Q>>2]=0;D=S;E=T;F=U;H=V;I=W;break c}}while(0);R=pJb(2088)|0;if((R|0)==0){D=S;E=T;F=U;H=V;I=W;break}CFb(R,q,1024)|0;CFb(R+1024|0,p,1024)|0;N=R+2048|0;c[N>>2]=W;c[N+4>>2]=V;N=R+2056|0;c[N>>2]=U;c[N+4>>2]=T;N=R+2072|0;c[N>>2]=A;c[N+4>>2]=B;N=R+2080|0;c[N>>2]=L;c[N+4>>2]=M;N=y+(x*33880|0)+33856|0;K=c[N>>2]|0;c[R+2064>>2]=K;J=c[Q>>2]|0;c[Q>>2]=J+1;c[(c[y+(x*33880|0)+33860>>2]|0)+(J<<2)>>2]=R;c[N>>2]=K+1;D=S;E=T;F=U;H=V;I=W}}while(0);y=x+1|0;if(y>>>0<(c[j>>2]|0)>>>0){s=H;t=I;u=E;v=F;w=D;x=y}else{k=D;break a}}if((P|0)==54){i=d;return O|0}}}while(0);D=h+4|0;F=c[D>>2]|0;do{if((F|0)==0){if((b|0)==0){break}if((c[h+20>>2]|0)!=0){P=36}}else{P=36}}while(0);f:do{if((P|0)==36){if((c[j>>2]|0)==0){break}E=h+24|0;I=h+8|0;H=h+12|0;W=h+20|0;if((b|0)==0){V=0;U=F;while(1){T=c[E>>2]|0;S=T+(V*33880|0)+33848|0;e=(c[S>>2]|0)-U-(c[I>>2]|0)-(c[H>>2]|0)|0;if((e|0)>0){f=T+(V*33880|0)+33860|0;T=0;do{be(c[(c[f>>2]|0)+(T<<2)>>2]|0)|0;be((c[(c[f>>2]|0)+(T<<2)>>2]|0)+1024|0)|0;kJb(c[(c[f>>2]|0)+(T<<2)>>2]|0);T=T+1|0;}while((T|0)<(e|0));T=(c[S>>2]|0)-e|0;c[S>>2]=T;g=c[f>>2]|0;orc(g|0,g+(e<<2)|0,T<<2|0)|0}T=V+1|0;if(!(T>>>0<(c[j>>2]|0)>>>0)){break f}V=T;U=c[D>>2]|0}}else{ba=0;ca=F}while(1){U=c[E>>2]|0;V=U+(ba*33880|0)+33848|0;T=c[V>>2]|0;g=c[W>>2]|0;x=(g|0)==0?T-ca-(c[I>>2]|0)-(c[H>>2]|0)|0:T;if((x|0)>0){T=U+(ba*33880|0)+33860|0;w=0;do{be(c[(c[T>>2]|0)+(w<<2)>>2]|0)|0;be((c[(c[T>>2]|0)+(w<<2)>>2]|0)+1024|0)|0;kJb(c[(c[T>>2]|0)+(w<<2)>>2]|0);w=w+1|0;}while((w|0)<(x|0));w=(c[V>>2]|0)-x|0;c[V>>2]=w;e=c[T>>2]|0;orc(e|0,e+(x<<2)|0,w<<2|0)|0;da=c[W>>2]|0}else{da=g}if((da|0)!=0){dd(U+(ba*33880|0)+8|0)|0}w=ba+1|0;if(!(w>>>0<(c[j>>2]|0)>>>0)){break f}ba=w;ca=c[D>>2]|0}}}while(0);if(!((k|0)>-1)){O=k;i=d;return O|0}O=$U(a,b)|0;i=d;return O|0}function _U(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(c[a+12>>2]|0)+24|0;d=b;e=c[d>>2]|0;if((e|0)==0){return}f=a+24|0;a:do{if((c[f>>2]|0)!=0){a=0;g=e;while(1){h=g+(a*33880|0)+33800|0;SC(c[h>>2]|0)|0;i=g+(a*33880|0)+33804|0;SC(c[i>>2]|0)|0;j=g+(a*33880|0)+33808|0;SC(c[j>>2]|0)|0;c[j>>2]=0;c[i>>2]=0;c[h>>2]=0;h=g+(a*33880|0)|0;i=c[h>>2]|0;do{if((i|0)!=0){if((c[g+(a*33880|0)+4>>2]|0)==0){k=i}else{$O(i)|0;j=c[h>>2]|0;if((j|0)==0){break}else{k=j}}j=c[k+16>>2]|0;if((j|0)==0){l=k}else{kJb(j);l=c[h>>2]|0}if((l|0)==0){break}pX(l)}}while(0);kJb(c[g+(a*33880|0)+33868>>2]|0);h=g+(a*33880|0)+33848|0;i=g+(a*33880|0)+33860|0;j=c[i>>2]|0;if((c[h>>2]|0)>0){m=0;n=j;while(1){kJb(c[n+(m<<2)>>2]|0);o=m+1|0;p=c[i>>2]|0;if((o|0)<(c[h>>2]|0)){m=o;n=p}else{q=p;break}}}else{q=j}kJb(q);n=a+1|0;if(!(n>>>0<(c[f>>2]|0)>>>0)){break a}a=n;g=c[d>>2]|0}}}while(0);mJb(b);return}function $U(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;i=i+2056|0;e=d|0;f=c[a+12>>2]|0;g=d+8|0;h=a+32|0;Rb(g|0,1024,2462624,(j=i,i=i+8|0,c[j>>2]=h,j)|0)|0;i=j;k=d+1032|0;Rb(k|0,1024,2210192,(j=i,i=i+8|0,c[j>>2]=h,j)|0)|0;i=j;h=VD(e,k,2,a+1160|0,0)|0;if((h|0)<0){KIb(a,16,2177440,(j=i,i=i+8|0,c[j>>2]=k,j)|0);i=j;l=h;i=d;return l|0}YD(c[e>>2]|0,2149336,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;h=a+24|0;m=c[h>>2]|0;if((m|0)==0){n=0;o=0;p=0;q=0;r=0;s=0}else{t=c[f+24>>2]|0;u=c[a+28>>2]|0;v=0;w=0;x=0;y=0;z=0;A=0;B=0;while(1){C=c[t+(B*33880|0)+33848>>2]|0;if((C|0)>0){D=c[(c[t+(B*33880|0)+33860>>2]|0)+(C-1<<2)>>2]|0;E=D+2048|0;F=D+2056|0;D=wrc(c[F>>2]|0,c[F+4>>2]|0,c[E>>2]|0,c[E+4>>2]|0)|0;H=G;I=D}else{H=x;I=y}if((c[(c[(c[u+(B<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==0){J=C;K=z;L=w;M=v+1|0}else{J=A;K=C;L=w+1|0;M=v}C=B+1|0;if(C>>>0<m>>>0){v=M;w=L;x=H;y=I;z=K;A=J;B=C}else{n=M;o=L;p=H;q=I;r=K;s=J;break}}}J=(b|0)!=0;K=J?r:0;r=J?s:0;s=f+4|0;I=c[s>>2]|0;if((I|0)==0){N=r;O=K}else{N=(r|0)>(I|0)?I:r;O=(K|0)>(I|0)?I:K}YD(c[e>>2]|0,2125392,(j=i,i=i+16|0,c[j>>2]=J?q:0,c[j+8>>2]=J?p:0,j)|0)|0;i=j;if(!J){YD(c[e>>2]|0,2643480,(j=i,i=i+8|0,c[j>>2]=c[f+12>>2],j)|0)|0;i=j}YD(c[e>>2]|0,2620288,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;if((c[f+28>>2]|0)!=0){YD(c[e>>2]|0,2592832,(j=i,i=i+16|0,c[j>>2]=n,c[j+8>>2]=N,j)|0)|0;i=j;N=c[h>>2]|0;n=f+24|0;J=c[n>>2]|0;if((N|0)==0){P=-1;Q=J}else{p=a+28|0;q=-1;K=0;I=0;r=J;J=N;while(1){N=c[(c[(c[p>>2]|0)+(I<<2)>>2]|0)+8>>2]|0;if((c[N+8>>2]|0)==0){H=c[N+72>>2]|0;L=c[r+(I*33880|0)+33864>>2]|0;M=c[N+120>>2]|0;B=c[N+124>>2]|0;N=c[r+(I*33880|0)+33868>>2]|0;YD(c[e>>2]|0,2570160,(j=i,i=i+48|0,c[j>>2]=K,c[j+8>>2]=H,c[j+16>>2]=L,c[j+24>>2]=M,c[j+32>>2]=B,c[j+40>>2]=N,j)|0)|0;i=j;R=K+1|0;S=I;T=c[h>>2]|0;U=c[n>>2]|0}else{R=K;S=q;T=J;U=r}N=I+1|0;if(N>>>0<T>>>0){q=S;K=R;I=N;r=U;J=T}else{P=S;Q=U;break}}}aV(Q+(P*33880|0)|0,c[e>>2]|0,b,c[f+12>>2]|0,c[s>>2]|0);YD(c[e>>2]|0,2552360,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}if((c[f+32>>2]|0)!=0){YD(c[e>>2]|0,2534160,(j=i,i=i+16|0,c[j>>2]=o,c[j+8>>2]=O,j)|0)|0;i=j;O=c[h>>2]|0;o=f+24|0;P=c[o>>2]|0;if((O|0)==0){V=-1;W=P}else{Q=a+28|0;a=0;U=-1;S=0;T=P;P=O;while(1){O=c[(c[(c[Q>>2]|0)+(a<<2)>>2]|0)+8>>2]|0;if((c[O+8>>2]|0)==1){J=c[O+72>>2]|0;r=c[T+(a*33880|0)+33864>>2]|0;I=c[O+412>>2]|0;R=c[O+416>>2]|0;O=c[T+(a*33880|0)+33872>>2]|0;K=c[T+(a*33880|0)+33876>>2]|0;q=c[T+(a*33880|0)+33868>>2]|0;YD(c[e>>2]|0,2518552,(j=i,i=i+64|0,c[j>>2]=S,c[j+8>>2]=J,c[j+16>>2]=r,c[j+24>>2]=I,c[j+32>>2]=R,c[j+40>>2]=O,c[j+48>>2]=K,c[j+56>>2]=q,j)|0)|0;i=j;X=S+1|0;Y=a;Z=c[h>>2]|0;_=c[o>>2]|0}else{X=S;Y=U;Z=P;_=T}q=a+1|0;if(q>>>0<Z>>>0){a=q;U=Y;S=X;T=_;P=Z}else{V=Y;W=_;break}}}aV(W+(V*33880|0)|0,c[e>>2]|0,b,c[f+12>>2]|0,c[s>>2]|0);YD(c[e>>2]|0,2552360,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}YD(c[e>>2]|0,2504464,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;eD(c[e>>2]|0);WD(c[e>>2]|0)|0;Gc(k|0,g|0)|0;l=0;i=d;return l|0}function aV(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=a+33848|0;j=c[h>>2]|0;if((j|0)<1){i=g;return}k=a+33860|0;a=c[k>>2]|0;l=(d|0)!=0;d=l?0:e;e=j-d|0;if((f|0)==0){m=0}else{j=e-f|0;m=(j|0)>0?j:0}if((m|0)>=(e|0)){i=g;return}if(l&(c[(c[a>>2]|0)+2064>>2]|0)<1){l=m;e=a;while(1){j=c[e+(l<<2)>>2]|0;f=j+2056|0;n=c[f>>2]|0;o=c[f+4>>2]|0;YD(b,2480136,(p=i,i=i+24|0,c[p>>2]=c[j+2064>>2],c[p+8>>2]=n,c[p+16>>2]=o,p)|0)|0;i=p;o=l+1|0;if((o|0)>=((c[h>>2]|0)-d|0)){break}l=o;e=c[k>>2]|0}i=g;return}else{e=m;m=a;while(1){a=c[m+(e<<2)>>2]|0;l=a+2048|0;o=c[l+4>>2]|0;n=a+2056|0;a=c[n>>2]|0;j=c[n+4>>2]|0;YD(b,2491024,(p=i,i=i+32|0,c[p>>2]=c[l>>2],c[p+8>>2]=o,c[p+16>>2]=a,c[p+24>>2]=j,p)|0)|0;i=p;j=e+1|0;if((j|0)>=((c[h>>2]|0)-d|0)){break}e=j;m=c[k>>2]|0}i=g;return}}function bV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=c[a+33800>>2]|0;if((e|0)!=0){VC(e,b,d)|0}e=c[a+33804>>2]|0;if((e|0)!=0){VC(e,b,d)|0}b=a+33824|0;e=wrc(c[b>>2]|0,c[b+4>>2]|0,d,(d|0)<0|0?-1:0)|0;f=G;c[b>>2]=e;c[b+4>>2]=f;b=a+33816|0;a=c[b+4>>2]|0;if((f|0)<(a|0)|(f|0)==(a|0)&e>>>0<(c[b>>2]|0)>>>0){return d|0}c[b>>2]=e;c[b+4>>2]=f;return d|0}function cV(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+8|0;g=f|0;if((e|0)!=0){h=-1;j=-38;i=f;return(G=h,j)|0}e=a+33808|0;if((c[e>>2]|0)!=0){k=a+33800|0;l=c[k>>2]|0;if((l|0)!=0){SC(l)|0}l=a+33804|0;m=c[l>>2]|0;if((m|0)!=0){SC(m)|0}c[k>>2]=c[e>>2];c[l>>2]=0;c[e>>2]=0}l=a+33832|0;k=c[l>>2]|0;m=c[l+4>>2]|0;if(!((m|0)>(d|0)|(m|0)==(d|0)&k>>>0>b>>>0)){l=c[a+33800>>2]|0;if((l|0)!=0){n=xrc(b,d,k,m)|0;OC(l,n,G,0)|0;}n=a+33824|0;c[n>>2]=b;c[n+4>>2]=d;h=d;j=b;i=f;return(G=h,j)|0}n=c[a+33848>>2]|0;if((n|0)<=0){h=-1;j=-5;i=f;return(G=h,j)|0}l=c[a+33860>>2]|0;m=n;while(1){n=m-1|0;o=c[l+(n<<2)>>2]|0;p=o+2072|0;k=c[p>>2]|0;q=c[p+4>>2]|0;if(!((q|0)>(d|0)|(q|0)==(d|0)&k>>>0>b>>>0)){r=o+2080|0;s=wrc(c[r>>2]|0,c[r+4>>2]|0,k,q)|0;q=G;if((q|0)>(d|0)|(q|0)==(d|0)&s>>>0>b>>>0){break}}if((n|0)>0){m=n}else{h=-1;j=-5;t=22;break}}if((t|0)==22){i=f;return(G=h,j)|0}c[g>>2]=0;t=a+33800|0;c[e>>2]=c[t>>2];MGb(g,2318472,2313488,0)|0;m=a;l=RC(t,o|0,3,(c[m>>2]|0)+1160|0,g)|0;OGb(g);if((l|0)<0){c[t>>2]=c[e>>2];c[e>>2]=0;h=(l|0)<0|0?-1:0;j=l;i=f;return(G=h,j)|0}MGb(g,2318472,2313488,0)|0;l=a+33804|0;RC(l,o+1024|0,3,(c[m>>2]|0)+1160|0,g)|0;OGb(g);g=c[t>>2]|0;t=xrc(b,d,c[p>>2]|0,c[p+4>>2]|0)|0;OC(g,t,G,0)|0;t=c[l>>2]|0;if((t|0)!=0){l=xrc(b,d,c[p>>2]|0,c[p+4>>2]|0)|0;OC(t,l,G,0)|0;}l=a+33824|0;c[l>>2]=b;c[l+4>>2]=d;h=d;j=b;i=f;return(G=h,j)|0}function dV(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;do{if((e|0)==1296649793){a=b+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1380206657){f=100}else{break}return f|0}else if((e|0)==1296974163){a=b+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1380206675){f=100}else{break}return f|0}}while(0);f=0;return f|0}function eV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;i=i+1024|0;e=d|0;f=c[b+12>>2]|0;g=c[b+16>>2]|0;h=JD(g)|0;hD(g,4,0)|0;if((h|0)==1396788813){if((JD(g)|0)!=1397245010){j=-1094995529;i=d;return j|0}k=JD(g)|0;if(k>>>0<14>>>0){j=-1094995529;i=d;return j|0}c[f>>2]=1;l=DD(g)|0;m=FD(g)|0;hD(g,2,0)|0;n=DD(g)|0;o=DD(g)|0;hD(g,2,0)|0;hD(g,k-14|0,0)|0;if((JD(g)|0)!=1179404356){j=-1094995529;i=d;return j|0}k=JD(g)|0;p=0;while(1){q=p+8|0;if(!(q>>>0<k>>>0)){r=p;s=0;t=0;u=0;break}if((jD(g)|0)!=0){j=-541478725;v=26;break}w=JD(g)|0;x=JD(g)|0;if((w|0)==1466005093){v=15;break}else if(!((w|0)==1114386742|(w|0)==1095650895)){j=-1094995529;v=26;break}hD(g,x,0)|0;p=x+q|0}if((v|0)==15){p=FD(g)|0;w=FD(g)|0;hD(g,x-8|0,0)|0;r=x+q|0;s=1;t=p;u=w}else if((v|0)==26){i=d;return j|0}hD(g,k-r|0,0)|0;z=m;A=u;B=t;C=s;D=o;E=n;F=l&65535}else if((h|0)==1095649613){if((JD(g)|0)!=1095255122){j=-1094995529;i=d;return j|0}h=JD(g)|0;if(h>>>0<774>>>0){j=-1094995529;i=d;return j|0}c[f>>2]=0;l=DD(g)|0;n=DD(g)|0;hD(g,2,0)|0;o=0;do{c[e+(o<<2)>>2]=ID(g)|0;o=o+1|0;}while(o>>>0<256>>>0);hD(g,h-774|0,0)|0;z=n;A=0;B=0;C=0;D=0;E=0;F=l&65535}else{KIb(b,16,2462608,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=-1094995529;i=d;return j|0}l=ZX(b,0)|0;if((l|0)==0){j=-12;i=d;return j|0}c[f+8>>2]=c[l>>2];n=l+48|0;c[n>>2]=0;c[n+4>>2]=0;n=z;z=0;h=l+64|0;c[h>>2]=n;c[h+4>>2]=z;h=l+56|0;c[h>>2]=n;c[h+4>>2]=z;z=l+8|0;h=c[z>>2]|0;c[h+8>>2]=0;c[h+48>>2]=1396788813;c[h+52>>2]=0;c[h+120>>2]=E;c[h+124>>2]=D;_X(l,64,66667,1e6);if((c[f>>2]|0)==0){if((PX(c[z>>2]|0,1026)|0)!=0){j=-12;i=d;return j|0}l=c[(c[z>>2]|0)+96>>2]|0;y=F;a[l]=y;y=y>>8;a[l+1|0]=y;l=0;do{F=(c[(c[z>>2]|0)+96>>2]|0)+(l<<2|2)|0;y=c[e+(l<<2)>>2]|0;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;l=l+1|0;}while(l>>>0<256>>>0)}if((C|0)==0){j=0;i=d;return j|0}C=ZX(b,0)|0;if((C|0)==0){j=-12;i=d;return j|0}c[f+4>>2]=c[C>>2];f=C+48|0;c[f>>2]=0;c[f+4>>2]=0;f=c[C+8>>2]|0;c[f+8>>2]=1;c[f+48>>2]=1447644481;c[f+52>>2]=0;c[f+412>>2]=B;c[f+416>>2]=A;_X(C,64,1,B);j=0;i=d;return j|0}function fV(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[a+12>>2]|0;f=c[a+16>>2]|0;a=e;g=e+8|0;h=b+32|0;i=b+48|0;j=e+4|0;e=b+36|0;k=b+24|0;while(1){if((jD(f)|0)!=0){l=-541478725;m=14;break}n=JD(f)|0;o=JD(f)|0;if((n|0)==1179798853){if((c[a>>2]|0)==0){m=6;break}else{continue}}else if((n|0)==1114386742){m=8;break}else if((n|0)==1466005093){m=10;break}else{hD(f,o,0)|0;continue}}if((m|0)==6){if((fX(f,b,o)|0)<0){l=-5;return l|0}c[h>>2]=c[g>>2];l=0;return l|0}else if((m|0)==8){if((fX(f,b,o)|0)<0){l=-5;return l|0}c[h>>2]=c[g>>2];c[i>>2]=1;l=0;return l|0}else if((m|0)==10){if(o>>>0<13>>>0){l=-1094995529;return l|0}if((fX(f,b,o)|0)<13){l=-5;return l|0}c[h>>2]=c[j>>2];c[e>>2]=c[e>>2]|1;e=c[k>>2]|0;k=e;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[i>>2]=je(j|0)|0;if(!((j|0)==-1)){l=0;return l|0}j=e+8|0;c[i>>2]=je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;l=0;return l|0}else if((m|0)==14){return l|0}return 0}function gV(b){b=b|0;var e=0,f=0,g=0;e=c[b+4>>2]|0;b=e;f=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24)&65535;do{if((f|0)==2957|(f|0)==3085|(f|0)==3213){if((a[e+2|0]|0)!=83){break}if((a[e+3|0]|0)!=79){break}if((a[e+4|0]|0)!=76){break}if((a[e+5|0]|0)==0){g=100}else{break}return g|0}}while(0);g=0;return g|0}function hV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a+16>>2]|0;d=DD(b)|0;if((FD(b)|0)!=5001043){e=-1;return e|0}f=DD(b)|0;g=zD(b)|0;hD(b,4,0)|0;h=(d|0)==2957;do{if(h){i=g&1;j=i;k=(i|0)!=0?81923:65541;l=1}else{zD(b)|0;i=g&1;if((i|0)==0){m=(g&4|0)==0?65541:65536}else{m=81923}n=(g>>>4&1)+1|0;o=(m|0)!=81923;if(o|h){j=o&1^1;k=m;l=n;break}if((i|0)==0){j=-1;k=m;l=n;break}if((g&4|0)!=0){j=3;k=m;l=n;break}j=(d|0)==3213?1:2;k=m;l=n}}while(0);m=ZX(a,0)|0;if((m|0)==0){e=-1;return e|0}a=c[m+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=j;c[a+48>>2]=k;c[a+416>>2]=l;k=(l|0)==1;l=a+448|0;c[l>>2]=k?4:3;c[l+4>>2]=k?0:0;c[a+412>>2]=f;_X(m,64,1,f);e=0;return e|0}function iV(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+16|0;if((jD(c[d>>2]|0)|0)!=0){e=-5;return e|0}a=fX(c[d>>2]|0,b,4096)|0;if((a|0)<0){e=a;return e|0}a=b+36|0;c[a>>2]=c[a>>2]&-3;c[b+32>>2]=0;e=0;return e|0}function jV(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;if((a|0)==1483690798){return 100}else{return((a|0)==777219928?100:0)|0}return 0}function kV(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0.0;d=i;i=i+8|0;e=d|0;f=c[b+16>>2]|0;g=ZX(b,0)|0;if((g|0)==0){j=-12;i=d;return j|0}l=g+8|0;c[(c[l>>2]|0)+8>>2]=1;m=(FD(f)|0)==1483690798;n=(c[l>>2]|0)+48|0;if(m){c[n>>2]=65544;m=FD(f)|0;hD(f,8,0)|0;o=GD(f)|0;p=G;q=FD(f)|0;c[(c[l>>2]|0)+416>>2]=q;r=m;s=p;t=o;u=FD(f)|0}else{c[n>>2]=65545;n=JD(f)|0;hD(f,8,0)|0;o=OD(f)|0;p=G;m=JD(f)|0;c[(c[l>>2]|0)+416>>2]=m;r=n;s=p;t=o;u=JD(f)|0}v=(c[k>>2]=t,c[k+4>>2]=s,+h[k>>3]);if(u>>>0>4294967263>>>0){KIb(b,16,2462576,(w=i,i=i+8|0,c[w>>2]=u,w)|0);i=w;j=-1094995529;i=d;return j|0}if(v<=0.0|v>2147483647.0){KIb(b,16,2371272,(w=i,i=i+8|0,h[w>>3]=v,w)|0);i=w;j=-1094995529;i=d;return j|0}x=v- +Q(v);if(x!=0.0){KIb(b,24,2305152,(w=i,i=i+8|0,h[w>>3]=x,w)|0);i=w}do{if((r+4&7|0)==0){if(r>>>0<(u+28|0)>>>0){break}if((c[(c[l>>2]|0)+416>>2]|0)>65535){break}do{if(!((u|0)==(-1|0)|(u|0)==0)){s=hJb(u+1|0)|0;c[e>>2]=s;if((s|0)==0){j=-12;i=d;return j|0}if((AD(f,s,u)|0)==(u|0)){a[s+u|0]=0;MGb(b+1140|0,2210184,s,8)|0;break}mJb(e);j=-5;i=d;return j|0}}while(0);hD(f,-28-u+r|0,0)|0;s=~~v;t=c[l>>2]|0;c[t+412>>2]=s;c[t+792>>2]=32;o=c[t+416>>2]|0;c[t+72>>2]=ca(s<<5,o)|0;c[t+432>>2]=(o<<5|0)/8|0;_X(g,64,1,s);j=0;i=d;return j|0}}while(0);KIb(b,16,2253240,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;j=-1094995529;i=d;return j|0}function lV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;g=LGb(c[a+1140>>2]|0,2462568,0,0)|0;if((g|0)==0){j=0}else{j=lrc(c[g+4>>2]|0)|0}l=j+7&-8;m=d;c[m>>2]=l+28;c[m+4>>2]=0;d=c[f+48>>2]|0;if((d|0)==65545){kD(e,777219928);lD(e,c[m>>2]|0);sD(e,0,0);h[k>>3]=+(c[f+412>>2]|0);sD(e,c[k>>2]|0,c[k+4>>2]|0);lD(e,c[f+416>>2]|0);lD(e,l)}else if((d|0)==65544){kD(e,1483690798);kD(e,c[m>>2]|0);rD(e,0,0);h[k>>3]=+(c[f+412>>2]|0);rD(e,c[k>>2]|0,c[k+4>>2]|0);kD(e,c[f+416>>2]|0);kD(e,l)}else{KIb(a,16,2253192,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;n=-1;i=b;return n|0}if((j|0)!=0){dD(e,c[g+4>>2]|0,j)}cD(e,0,l-j|0);eD(e);n=0;i=b;return n|0}function mV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+16>>2]|0;if((c[b+88>>2]|0)==0){return 0}d=c[a+12>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;a=fD(b,0,0,1)|0;f=G;g=d;d=c[g>>2]|0;h=c[g+4>>2]|0;g=wrc(a,f,-4,-1)|0;i=xrc(g,G,d,h)|0;h=G;d=i>>>2|h<<30;i=h>>2|((h|0)<0|0?-1:0)<<30;fD(b,8,0,0)|0;if((c[e+48>>2]|0)==65544){rD(b,d,i)}else{sD(b,d,i)}fD(b,a,f,0)|0;eD(b);return 0}function nV(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+8|0;h=g|0;j=e-1|0;k=(j|0)<32768?j:32768;if((k|0)<=0){l=0;i=g;return l|0}m=b+e|0;e=b+j|0;j=b;n=b+k|0;k=b+7|0;b=0;o=0;p=0;a:while(1){q=d[j]|0|b;do{if((q|0)==1928863566){r=a[j+1|0]|0;if(!((r&255)>>>0<55>>>0)){s=p;t=o;u=k;v=n;w=j;break}x=o+1|0;if((j|0)==(k|0)){if((p|0)>0){l=100;y=15;break a}else{z=p+1|0}}else{z=0}if((j+11|0)>>>0>m>>>0){A=x;break a}B=j+16384|0;C=B>>>0>e>>>0?e:B;if((oV(0,(d[j+2|0]|0)<<8|r&255,j+5|0,h,f)|0)!=0){s=z;t=x;u=k;v=C;w=j;break}r=c[h>>2]|0;B=j+r|0;if(!(B>>>0<m>>>0)){A=x;break a}s=z;t=x;u=B;v=C;w=j+(r-7)|0}else{s=p;t=o;u=k;v=n;w=j}}while(0);r=w+1|0;if(!(r>>>0<v>>>0)){A=t;break}j=r;n=v;k=u;b=q<<8;o=t;p=s}if((y|0)==15){i=g;return l|0}if((A|0)==0){l=0;i=g;return l|0}l=(A|0)>5?50:12;i=g;return l|0}function oV(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+48|0;h=g|0;j=g+24|0;a:do{switch(b&255|0){case 7:{k=(d|0)==0?0:56;c[j>>2]=d;c[j+12>>2]=k;c[j+16>>2]=k+8;c[j+4>>2]=d+(k>>>3);c[j+8>>2]=0;if((T$(j,h)|0)>=0){c[e>>2]=c[h+4>>2]<<2;c[f>>2]=86018;l=0;break a}if((a|0)==0){l=-1094995529;break a}KIb(a,16,2305112,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;l=-1094995529;break};case 11:{c[e>>2]=2048;c[f>>2]=86020;l=0;break};case 8:{c[e>>2]=3072;c[f>>2]=86059;l=0;break};case 5:{c[e>>2]=1536;c[f>>2]=86017;l=0;break};case 6:{c[e>>2]=4608;c[f>>2]=86017;l=0;break};case 12:{c[e>>2]=4096;c[f>>2]=86020;l=0;break};case 9:{c[e>>2]=9216;c[f>>2]=86016;l=0;break};case 1:{c[e>>2]=6144;c[f>>2]=86019;l=0;break};case 13:{c[e>>2]=8192;c[f>>2]=86020;l=0;break};case 10:{c[e>>2]=4608;c[f>>2]=86017;l=0;break};case 4:{c[e>>2]=1536;c[f>>2]=86059;l=0;break};default:{if((a|0)==0){l=-1163346256;break a}QIb(a,2253160,(m=i,i=i+8|0,c[m>>2]=b,m)|0);i=m;l=-1163346256}}}while(0);i=g;return l|0}function pV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[a+16>>2]|0;h=0;while(1){if((h|0)==1928863566){break}j=zD(g)|0|h<<8;if((jD(g)|0)==0){h=j}else{k=-541478725;l=20;break}}if((l|0)==20){i=d;return k|0}l=DD(g)|0;h=DD(g)|0;if((h&15|0)!=0){QIb(a,2642704,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}j=K1(b,h+15>>3&-2)|0;if((j|0)!=0){k=j;i=d;return k|0}j=fD(g,0,0,1)|0;h=wrc(j,G,-8,-1)|0;j=b+64|0;c[j>>2]=h;c[j+4>>2]=G;j=b+24|0;h=b+28|0;n=AD(g,c[j>>2]|0,c[h>>2]|0)|0;o=c[h>>2]|0;if((n|0)<(o|0)){P1(b);k=-541478725;i=d;return k|0}n=c[j>>2]|0;S$(n,n,o>>1);o=oV(a,l,c[j>>2]|0,f,e)|0;if((o|0)!=0){P1(b);k=o;i=d;return k|0}o=(c[f>>2]|0)-8-(c[h>>2]|0)|0;hD(g,o,(o|0)<0|0?-1:0)|0;do{if((c[a+24>>2]|0)==0){o=ZX(a,0)|0;if((o|0)!=0){g=c[o+8>>2]|0;c[g+8>>2]=1;c[g+48>>2]=c[e>>2];break}P1(b);k=-12;i=d;return k|0}else{if((c[e>>2]|0)==(c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+48>>2]|0)){break}RIb(a,2621968,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;k=-1163346256;i=d;return k|0}}while(0);m=a+1072|0;if((c[m>>2]|0)!=0){k=0;i=d;return k|0}e=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+412>>2]|0;if((e|0)==0){k=0;i=d;return k|0}c[m>>2]=e<<5;k=0;i=d;return k|0}function qV(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=nV(c[a+4>>2]|0,c[a+8>>2]|0,b|0)|0;i=b;return d|0}function rV(a){a=a|0;var b=0;b=a+20|0;c[b>>2]=c[b>>2]|1;return 0}function sV(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+12>>2]|0;a:do{switch(c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+48>>2]|0){case 86020:{c[d+72>>2]=80;break};case 86061:{c[d+72>>2]=626;e=hJb(61424)|0;c[d+40>>2]=e;if((e|0)==0){f=-12}else{break a}i=b;return f|0};case 86019:{c[d+72>>2]=614;break};case 86018:{c[d+72>>2]=634;break};case 86057:{c[d+72>>2]=226;break};case 86059:case 86016:case 86017:{c[d+72>>2]=528;break};default:{KIb(a,16,2305088,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1163346256;i=b;return f|0}}}while(0);f=0;i=b;return f|0}function tV(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[a+12>>2]|0;g=f+24|0;c[g>>2]=c[b+24>>2];h=b+28|0;j=f+28|0;c[j>>2]=c[h>>2];k=f+8|0;c[k>>2]=(c[h>>2]<<3)+8&-16;h=f+32|0;c[h>>2]=1;l=f+36|0;c[l>>2]=0;m=We[c[f+72>>2]&2047](a,b)|0;if((m|0)<0){n=m;i=e;return n|0}m=f+12|0;b=c[m>>2]|0;if((b|0)==0){n=0;i=e;return n|0}o=c[h>>2]|0;h=b-(o<<3)-(c[j>>2]|0)&-2;if((h|0)<0){KIb(a,16,2462536,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=-22;i=e;return n|0}do{if((o|0)==0){q=f+68|0}else{b=a+16|0;r=c[b>>2]|0;s=f+68|0;if((c[s>>2]&1|0)==0){oD(r,63602)}else{tD(r,63602)}r=c[b>>2]|0;if((c[s>>2]&1|0)==0){oD(r,19999)}else{tD(r,19999)}r=c[b>>2]|0;t=c[f+4>>2]|0;if((c[s>>2]&1|0)==0){oD(r,t)}else{tD(r,t)}t=c[b>>2]|0;b=c[k>>2]|0;if((c[s>>2]&1|0)==0){oD(t,b);q=s;break}else{tD(t,b);q=s;break}}}while(0);do{if((c[l>>2]|0)==(c[q>>2]&1|0)){k=f+16|0;o=k;xJb(k,f+20|0,(c[j>>2]|0)+16|0);k=c[o>>2]|0;if((k|0)==0){n=-12;i=e;return n|0}else{S$(k,c[g>>2]|0,c[j>>2]>>1);dD(c[a+16>>2]|0,c[o>>2]|0,c[j>>2]&-2);break}}else{dD(c[a+16>>2]|0,c[g>>2]|0,c[j>>2]&-2)}}while(0);l=c[j>>2]|0;o=a+16|0;do{if((l&1|0)!=0){k=c[o>>2]|0;s=(d[(c[g>>2]|0)+(l-1)|0]|0)<<8;if((c[q>>2]&1|0)==0){oD(k,s);break}else{tD(k,s);break}}}while(0);cD(c[o>>2]|0,0,h);h=c[j>>2]|0;j=c[m>>2]|0;KIb(a,48,2371200,(p=i,i=i+24|0,c[p>>2]=c[f+4>>2],c[p+8>>2]=h,c[p+16>>2]=j,p)|0);i=p;n=0;i=e;return n|0}function uV(a){a=a|0;var b=0;b=c[a+12>>2]|0;mJb(b+16|0);mJb(b+40|0);return 0}function vV(a,b){a=a|0;b=b|0;var e=0;e=c[a+12>>2]|0;c[e+4>>2]=(d[(c[b+24>>2]|0)+5|0]|0)<<8&1792|1;c[e+12>>2]=6144;return 0}function wV(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+12>>2]|0;a=b+24|0;f=d[(c[a>>2]|0)+4|0]|0;if((f&192|0)==192){g=1}else{g=d[559552+(f>>>4&3)|0]|0}f=e+40|0;h=e+52|0;i=b+28|0;b=wJb(c[f>>2]|0,e+44|0,(c[i>>2]|0)+(c[h>>2]|0)|0)|0;c[f>>2]=b;if((b|0)==0){j=-12;return j|0}nrc(b+(c[h>>2]|0)|0,c[a>>2]|0,c[i>>2]|0)|0;a=(c[h>>2]|0)+(c[i>>2]|0)|0;c[h>>2]=a;i=e+48|0;b=(c[i>>2]|0)+1|0;c[i>>2]=b;if((b|0)<(g|0)){c[e+12>>2]=0;j=0;return j|0}else{c[e+4>>2]=21;c[e+12>>2]=24576;c[e+24>>2]=c[f>>2];c[e+28>>2]=a;c[e+8>>2]=a;c[i>>2]=0;c[h>>2]=0;j=0;return j|0}return 0}function xV(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=c[b+12>>2]|0;j=c[f+24>>2]|0;f=d[j+1|0]|0;k=f>>>3;l=k&3;m=f>>>1&3;f=m^3;n=a[j+2|0]&1;j=b;if((m|0)==0|(l|0)==1){KIb(j,16,2518496,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=g;return p|0}KIb(j,48,2504424,(o=i,i=i+24|0,c[o>>2]=l,c[o+8>>2]=f,c[o+16>>2]=n,o)|0);i=o;if((l|0)!=2|(n|0)==0){n=k&1;c[h+4>>2]=c[794792+(n*12|0)+(f<<2)>>2];c[h+12>>2]=e[559480+(n*6|0)+(f<<1)>>1]|0;p=0;i=g;return p|0}else{c[h+4>>2]=6;c[h+12>>2]=4608;p=0;i=g;return p|0}return 0}function yV(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;g=c[b+12>>2]|0;h=e+24|0;j=c[h>>2]|0;k=j;l=je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;k=e+28|0;if((c[k>>2]|0)<9){m=-1094995529;i=f;return m|0}if((l|0)==(-25230976|0)){e=j+4|0;n=((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>2&127;c[g+36>>2]=1;o=0;p=0;q=n}else if((l|0)==1683496997){KIb(b,16,2149312,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=-1094995529;i=f;return m|0}else if((l|0)==536864768){o=0;p=0;q=(d[j+6|0]|0)>>>2&15|(d[j+5|0]|0)<<4&112}else if((l|0)==(-14745368|0)){n=(d[j+7|0]|0)>>>2&15|(d[j+4|0]|0)<<4&112;c[g+36>>2]=1;o=0;p=0;q=n}else if((l|0)==2147385345){n=j+4|0;e=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)>>>2&127;o=(((d[j+6|0]|0)<<8|(d[j+5|0]|0)<<16|(d[j+7|0]|0))>>>4&16383)+1|0;p=c[1965816+(((d[j+8|0]|0)>>>2&15)<<2)>>2]|0;q=e}else{KIb(b,16,2125368,(r=i,i=i+8|0,c[r>>2]=l,r)|0);i=r;m=-1094995529;i=f;return m|0}l=q+1|0;e=c[g+60>>2]|0;if((e|0)==0){if((q|0)==31){c[g+4>>2]=12}else if((q|0)==63){c[g+4>>2]=13}else if((q|0)==15){c[g+4>>2]=11}else{KIb(b,16,2643440,(r=i,i=i+8|0,c[r>>2]=l<<5,r)|0);i=r;m=-38;i=f;return m|0}do{if((o|0)!=0){if((o|0)>=(c[k>>2]|0)){break}c[g+28>>2]=o;c[g+8>>2]=o<<3}}while(0);q=l<<7;c[g+12>>2]=q;j=c[g+28>>2]|0;if((j|0)==(q|0)){c[g+32>>2]=0;m=0;i=f;return m|0}if((j|0)<=(q-8|0)){m=0;i=f;return m|0}QIb(b,2620224,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=0;i=f;return m|0}q=c[k>>2]|0;if((o|0)==0){KIb(b,16,2592768,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=-22;i=f;return m|0}if((p|0)==0){KIb(b,16,2570128,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=-1094995529;i=f;return m|0}k=l<<5;l=(ca(e,k)|0)/(p|0)|0;if((l|0)==2048){s=529}else if((l|0)==512){s=17}else if((l|0)==4096){s=785}else if((l|0)==1024){s=273}else if((l|0)==8192){s=1041}else if((l|0)==16384){s=1297}else{KIb(b,16,2552216,(r=i,i=i+32|0,c[r>>2]=e,c[r+8>>2]=l,c[r+16>>2]=k,c[r+24>>2]=p,r)|0);i=r;m=-22;i=f;return m|0}e=l<<2;c[g+12>>2]=e;c[g+4>>2]=s;s=g+56|0;l=c[s>>2]|0;do{if((q+12|0)>>>0>(e-8|0)>>>0){if((l|0)==0){KIb(b,24,2534096,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}j=c[g+64>>2]|0;if((j|0)>0){n=(ca(j,p)|0)/(k|0)|0;c[s>>2]=n;t=n;u=27;break}else{c[s>>2]=1;v=1;w=j;u=29;break}}else{t=l;u=27}}while(0);do{if((u|0)==27){if((t|0)==0){x=q;break}v=t;w=c[g+64>>2]|0;u=29}}while(0);do{if((u|0)==29){if(!((w|0)>-1)){x=o;break}c[s>>2]=v-1;x=o}}while(0);o=x+12|0;c[g+28>>2]=o;c[g+8>>2]=(x+35&-16)-8;v=g+40|0;s=v;xJb(v,g+44|0,o);o=c[s>>2]|0;if((o|0)==0){m=-12;i=f;return m|0}c[g+24>>2]=o;nrc(o|0,559560,10)|0;o=he(x&65535|0)|0;g=(c[s>>2]|0)+10|0;y=o;a[g]=y;y=y>>8;a[g+1|0]=y;nrc((c[s>>2]|0)+12|0,c[h>>2]|0,x)|0;m=0;i=f;return m|0}function zV(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+48|0;f=e|0;g=e+24|0;h=c[a+12>>2]|0;j=c[b+24>>2]|0;b=(j|0)==0?0:56;c[g>>2]=j;c[g+12>>2]=b;c[g+16>>2]=b+8;c[g+4>>2]=j+(b>>>3);c[g+8>>2]=0;if((T$(g,f)|0)<0){KIb(a,16,2210160,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=e;return l|0}g=f+4|0;c[h+12>>2]=c[g>>2]<<2;b=d[f+16|0]|0;if((b|0)==2){c[h+4>>2]=19;l=0;i=e;return l|0}else if((b|0)==1){c[h+4>>2]=7;l=0;i=e;return l|0}else if((b|0)==4){c[h+4>>2]=51;l=0;i=e;return l|0}else{KIb(a,16,2177400,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0);i=k;l=-22;i=e;return l|0}return 0}function AV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=c[a+12>>2]|0;f=e+48|0;g=c[f>>2]|0;if((g|0)==12){nrc((c[e+40>>2]|0)+30708|0,559520,12)|0;h=8}else if((g|0)==0){nrc(c[e+40>>2]|0,559496,20)|0;h=28}else{h=0}g=b+28|0;j=c[g>>2]|0;k=2560-h|0;if((j|0)>(k|0)){QIb(a,2253120,(a=i,i=i+8|0,c[a>>2]=j,a)|0);i=a;l=-1163346256;i=d;return l|0}a=h-8|0;h=e+40|0;nrc((c[h>>2]|0)+(a+((c[f>>2]|0)*2560|0))|0,c[b+24>>2]|0,j)|0;j=c[g>>2]|0;mrc((c[h>>2]|0)+(a+((c[f>>2]|0)*2560|0)+j)|0,0,k-j|0)|0;j=(c[f>>2]|0)+1|0;c[f>>2]=j;if((j|0)<24){c[e+12>>2]=0;l=0;i=d;return l|0}else{nrc((c[h>>2]|0)+61408|0,559536,16)|0;c[f>>2]=0;c[e+4>>2]=22;c[e+12>>2]=61440;c[e+24>>2]=c[h>>2];c[e+28>>2]=61424;c[e+8>>2]=61424;l=0;i=d;return l|0}return 0}function BV(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+8|0;f=e|0;g=c[b+4>>2]|0;b=((d[g+1|0]|0)<<8|(d[g]|0)<<16|(d[g+2|0]|0)|0)==15711167?g+3|0:g;while(1){g=a[b]|0;if(!((g<<24>>24|0)==13|(g<<24>>24|0)==10)){break}b=b+1|0}g=Bd(b|0,2305016,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((g|0)==1){j=100;i=e;return j|0}g=kd(b|0)|0;k=mc(b|0,2371160)|0;l=a[b+k|0]|0;if(l<<24>>24==13){m=k+1|0;n=m;o=a[b+m|0]|0}else{n=k;o=l}do{if(g>>>0<2>>>0){l=Bd(b+((o<<24>>24==10)+n)|0,2305016,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((l|0)==1){j=100}else{break}i=e;return j|0}}while(0);j=0;i=e;return j|0}function CV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=i;i=i+1120|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+1088|0;p=d+1096|0;q=d+1104|0;r=d+1112|0;s=c[b+12>>2]|0;t=ZX(b,0)|0;if((t|0)==0){u=-12;i=d;return u|0}_X(t,64,1,1e3);v=c[t+8>>2]|0;c[v+8>>2]=3;c[v+48>>2]=1397909872;SFb(n,0,-1);v=b+16|0;b=n+4|0;t=n|0;w=s;s=0;a:while(1){do{if((jD(c[v>>2]|0)|0)!=0){x=22;break a}RV(c[v>>2]|0,n);}while((c[b>>2]|0)==0);z=fD(c[v>>2]|0,0,0,1)|0;A=G;B=c[t>>2]|0;c[o>>2]=-1;c[p>>2]=-1;c[q>>2]=-1;c[r>>2]=-1;C=Bd(B|0,2462336,(D=i,i=i+96|0,c[D>>2]=e,c[D+8>>2]=f,c[D+16>>2]=g,c[D+24>>2]=h,c[D+32>>2]=j,c[D+40>>2]=k,c[D+48>>2]=l,c[D+56>>2]=m,c[D+64>>2]=o,c[D+72>>2]=q,c[D+80>>2]=p,c[D+88>>2]=r,D)|0)|0;i=D;do{if((C|0)>7){E=B;x=7}else{F=mc(B|0,2371160)|0;H=a[B+F|0]|0;if(H<<24>>24==13){I=F+1|0;J=I;K=a[B+I|0]|0}else{J=F;K=H}H=(K<<24>>24==10)+J|0;F=B+H|0;I=Bd(F|0,2462336,(D=i,i=i+96|0,c[D>>2]=e,c[D+8>>2]=f,c[D+16>>2]=g,c[D+24>>2]=h,c[D+32>>2]=j,c[D+40>>2]=k,c[D+48>>2]=l,c[D+56>>2]=m,c[D+64>>2]=o,c[D+72>>2]=q,c[D+80>>2]=p,c[D+88>>2]=r,D)|0)|0;i=D;if((I|0)>7){E=F;x=7;break}I=mc(F|0,2371160)|0;F=a[B+(I+H)|0]|0;if(F<<24>>24==13){L=I+1|0;M=L;N=a[B+(L+H)|0]|0}else{M=I;N=F}O=-2147483648;P=0;Q=B+(M+H+(N<<24>>24==10))|0;R=s}}while(0);if((x|0)==7){x=0;B=c[e>>2]|0;D=Erc(B,(B|0)<0|0?-1:0,3600,0)|0;B=G;C=c[f>>2]|0;H=Erc(C,(C|0)<0|0?-1:0,60,0)|0;C=wrc(H,G,D,B)|0;B=c[g>>2]|0;D=wrc(C,G,B,(B|0)<0|0?-1:0)|0;B=Erc(D,G,1e3,0)|0;D=c[h>>2]|0;C=wrc(B,G,D,(D|0)<0|0?-1:0)|0;D=G;B=c[j>>2]|0;H=Erc(B,(B|0)<0|0?-1:0,3600,0)|0;B=G;F=c[k>>2]|0;I=Erc(F,(F|0)<0|0?-1:0,60,0)|0;F=wrc(I,G,H,B)|0;B=c[l>>2]|0;H=wrc(F,G,B,(B|0)<0|0?-1:0)|0;B=Erc(H,G,1e3,0)|0;H=G;F=xrc(c[m>>2]|0,0,C,D)|0;I=wrc(F,G,B,H)|0;H=mc(E|0,2371160)|0;B=a[E+H|0]|0;if(B<<24>>24==13){F=H+1|0;S=F;T=a[E+F|0]|0}else{S=H;T=B}O=D;P=C;Q=E+((T<<24>>24==10)+S)|0;R=I}if((P|0)==0&(O|0)==(-2147483648|0)){s=R;continue}I=(c[t>>2]|0)-Q+(c[b>>2]|0)|0;if((I|0)<1){s=R;continue}C=IV(w,Q,I,0)|0;if((C|0)==0){U=-12;break}I=C+64|0;c[I>>2]=z;c[I+4>>2]=A;I=C+8|0;c[I>>2]=P;c[I+4>>2]=O;c[C+48>>2]=R;if((c[o>>2]|0)==-1){s=R;continue}I=U1(C,73,16)|0;if((I|0)==0){s=R;continue}C=I;y=c[o>>2]|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=I+4|0;y=c[p>>2]|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=I+8|0;y=c[q>>2]|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=I+12|0;y=c[r>>2]|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;s=R}if((x|0)==22){JV(w);U=0}_Fb(n,0)|0;u=U;i=d;return u|0}function DV(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function EV(a){a=a|0;OV(c[a+12>>2]|0);return 0}function FV(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function GV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+12>>2]|0;do{if((c[a+24>>2]|0)==1){e=c[c[a+28>>2]>>2]|0;f=c[e+8>>2]|0;if((c[f+8>>2]|0)!=3){break}g=c[f+48>>2]|0;if((g|0)==94210|(g|0)==1397909872|(g|0)==94216){_X(e,64,1,1e3);c[d>>2]=1;h=0;i=b;return h|0}else{e=u5a(g)|0;KIb(a,16,2125328,(j=i,i=i+8|0,c[j>>2]=e,j)|0);i=j;h=-22;i=b;return h|0}}}while(0);KIb(a,16,2149264,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-22;i=b;return h|0}function HV(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+8|0;f=e|0;g=c[a+12>>2]|0;h=(c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+48>>2]|0)!=94216;if(h){j=b+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=c[b+48>>2]|0;m=V1(b,73,f)|0;n=(m|0)!=0;if(n&(c[f>>2]|0)==16){f=m;o=m+4|0;p=m+8|0;q=m+12|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;u=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0}else{r=-1;s=-1;t=-1;u=-1}if((j|0)<1){f=b+72|0;v=c[f+4>>2]|0;w=c[f>>2]|0}else{v=(j|0)<0|0?-1:0;w=j}j=0;if((k|0)==0&(l|0)==(-2147483648|0)|((v|0)<(j|0)|(v|0)==(j|0)&w>>>0<0>>>0)){KIb(a,24,2371112,(x=i,i=i+8|0,c[x>>2]=c[g>>2],x)|0);i=x;i=e;return 0}j=wrc(w,v,k,l)|0;v=G;w=a+16|0;f=c[w>>2]|0;o=c[g>>2]|0;p=Crc(k,l,36e5,0)|0;q=Crc(k,l,6e4,0)|0;m=Crc(k,l,1e3,0)|0;y=Drc(k,l,1e3,0)|0;l=Crc(j,v,36e5,0)|0;k=Crc(j,v,6e4,0)|0;z=Crc(j,v,1e3,0)|0;A=Drc(j,v,1e3,0)|0;YD(f,2304896,(x=i,i=i+72|0,c[x>>2]=o,c[x+8>>2]=p,c[x+16>>2]=(q|0)%60|0,c[x+24>>2]=(m|0)%60|0,c[x+32>>2]=y,c[x+40>>2]=l,c[x+48>>2]=(k|0)%60|0,c[x+56>>2]=(z|0)%60|0,c[x+64>>2]=A,x)|0)|0;i=x;if(n){YD(c[w>>2]|0,2253064,(x=i,i=i+32|0,c[x>>2]=u,c[x+8>>2]=s,c[x+16>>2]=t,c[x+24>>2]=r,x)|0)|0;i=x}YD(c[w>>2]|0,2210152,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0)|0;i=x;B=w}else{B=a+16|0}dD(c[B>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);if(h){dD(c[B>>2]|0,2177392,2)}B=g;c[B>>2]=(c[B>>2]|0)+1;i=e;return 0}function IV(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=c[a+4>>2]|0;if((e|0)!=0&(f|0)>0){e=f-1|0;g=c[a>>2]|0;h=g+(e*80|0)|0;i=c[g+(e*80|0)+28>>2]|0;if((N1(h,d)|0)<0){j=0;return j|0}nrc((c[g+(e*80|0)+24>>2]|0)+i|0,b|0,d)|0;j=h;return j|0}h=a+4|0;if(f>>>0>26843543>>>0){j=0;return j|0}i=a|0;e=wJb(c[i>>2]|0,a+8|0,(f*80|0)+80|0)|0;f=e;if((e|0)==0){j=0;return j|0}c[i>>2]=f;i=c[h>>2]|0;c[h>>2]=i+1;h=f+(i*80|0)|0;if((K1(h,d)|0)<0){j=0;return j|0}e=f+(i*80|0)+36|0;c[e>>2]=c[e>>2]|1;mrc(f+(i*80|0)+8|0,0,16)|0;nrc(c[f+(i*80|0)+24>>2]|0,b|0,d)|0;j=h;return j|0}function JV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a|0;d=a+4|0;cd(c[b>>2]|0,c[d>>2]|0,80,((c[a+16>>2]|0)==0?282:518)|0);a=c[d>>2]|0;if((a|0)<=0){return}e=c[b>>2]|0;b=0;f=a;while(1){a=e+(b*80|0)+48|0;do{if((c[a>>2]|0)==-1){if((b|0)>=(f-1|0)){g=f;break}h=e+((b+1|0)*80|0)+8|0;i=e+(b*80|0)+8|0;j=xrc(c[h>>2]|0,c[h+4>>2]|0,c[i>>2]|0,c[i+4>>2]|0)|0;c[a>>2]=j;g=c[d>>2]|0}else{g=f}}while(0);a=b+1|0;if((a|0)<(g|0)){b=a;f=g}else{break}}return}function KV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+8|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=b+8|0;g=c[d>>2]|0;h=c[d+4>>2]|0;if(!((e|0)==(g|0)&(f|0)==(h|0))){i=(f|0)>(h|0)|(f|0)==(h|0)&e>>>0>g>>>0?1:-1;return i|0}g=a+64|0;a=c[g>>2]|0;e=c[g+4>>2]|0;g=b+64|0;b=c[g>>2]|0;h=c[g+4>>2]|0;if((a|0)==(b|0)&(e|0)==(h|0)){i=0;return i|0}i=(e|0)>(h|0)|(e|0)==(h|0)&a>>>0>b>>>0?1:-1;return i|0}function LV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+64|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=b+64|0;g=c[d>>2]|0;h=c[d+4>>2]|0;if(!((e|0)==(g|0)&(f|0)==(h|0))){i=(f|0)>(h|0)|(f|0)==(h|0)&e>>>0>g>>>0?1:-1;return i|0}g=a+8|0;a=c[g>>2]|0;e=c[g+4>>2]|0;g=b+8|0;b=c[g>>2]|0;h=c[g+4>>2]|0;if((a|0)==(b|0)&(e|0)==(h|0)){i=0;return i|0}i=(e|0)>(h|0)|(e|0)==(h|0)&a>>>0>b>>>0?1:-1;return i|0}function MV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+12|0;e=c[d>>2]|0;if((e|0)==(c[a+4>>2]|0)){f=-541478725;return f|0}if((S1(b,(c[a>>2]|0)+(e*80|0)|0)|0)<0){f=-12;return f|0}e=b+8|0;a=c[e+4>>2]|0;g=b+16|0;c[g>>2]=c[e>>2];c[g+4>>2]=a;c[d>>2]=(c[d>>2]|0)+1;f=0;return f|0}function NV(a,b,d,e,f,g,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((k&2|0)!=0){l=-38;return l|0}if((k&8|0)!=0){k=0;if((h|0)<(k|0)|(h|0)==(k|0)&g>>>0<0>>>0){l=-34;return l|0}k=c[a+4>>2]|0;b=(k|0)<0|0?-1:0;if(!((b|0)>(h|0)|(b|0)==(h|0)&k>>>0>g>>>0)){l=-34;return l|0}c[a+12>>2]=g;l=0;return l|0}k=c[a+4>>2]|0;b=k-1|0;if((b|0)<0){l=-34;return l|0}do{if((b|0)==0){m=0}else{n=a|0;o=0;p=b;while(1){if((o|0)==(p-1|0)){q=10;break}r=(o+p|0)/2|0;s=(c[n>>2]|0)+(r*80|0)+8|0;t=c[s+4>>2]|0;u=(t|0)>(h|0)|(t|0)==(h|0)&(c[s>>2]|0)>>>0>g>>>0;s=u?o:r;t=u?r:p;if((s|0)==(t|0)){v=s;break}else{o=s;p=t}}if((q|0)==10){t=c[n>>2]|0;s=t+(o*80|0)+8|0;r=c[s+4>>2]|0;u=t+(p*80|0)+8|0;t=c[u+4>>2]|0;v=(r|0)<=(t|0)&((r|0)<(t|0)|(c[s>>2]|0)>>>0<=(c[u>>2]|0)>>>0)?o:p}if((v|0)<0){l=v}else{m=v;break}return l|0}}while(0);a:do{if((m|0)<(k|0)){v=c[a>>2]|0;if((d|0)==-1){q=m;g=m;while(1){h=v+(g*80|0)+8|0;b=c[h+4>>2]|0;if(!((b|0)<(f|0)|(b|0)==(f|0)&(c[h>>2]|0)>>>0<e>>>0)){w=q;break a}h=g+1|0;if((h|0)<(k|0)){q=g;g=h}else{w=g;break}}}else{g=m;q=m;while(1){p=v+(q*80|0)+8|0;o=c[p+4>>2]|0;if(!((o|0)<(f|0)|(o|0)==(f|0)&(c[p>>2]|0)>>>0<e>>>0)){w=g;break a}p=(c[v+(q*80|0)+32>>2]|0)==(d|0)?q:g;o=q+1|0;if((o|0)<(k|0)){g=p;q=o}else{w=p;break}}}}else{w=m}}while(0);m=c[a>>2]|0;b:do{if((w|0)>0){if((d|0)==-1){k=w;q=w;while(1){g=m+(q*80|0)+8|0;v=c[g+4>>2]|0;if(!((v|0)>(j|0)|(v|0)==(j|0)&(c[g>>2]|0)>>>0>i>>>0)){x=k;break b}g=q-1|0;if((g|0)>0){k=q;q=g}else{x=q;break}}}else{q=w;k=w;while(1){g=m+(k*80|0)+8|0;v=c[g+4>>2]|0;if(!((v|0)>(j|0)|(v|0)==(j|0)&(c[g>>2]|0)>>>0>i>>>0)){x=q;break b}g=(c[m+(k*80|0)+32>>2]|0)==(d|0)?k:q;v=k-1|0;if((v|0)>0){q=g;k=v}else{x=g;break}}}}else{x=w}}while(0);w=m+(x*80|0)+8|0;k=c[w>>2]|0;q=c[w+4>>2]|0;if((q|0)<(f|0)|(q|0)==(f|0)&k>>>0<e>>>0|((q|0)>(j|0)|(q|0)==(j|0)&k>>>0>i>>>0)){l=-34;return l|0}i=(d|0)==-1;j=x;c:while(1){x=j-1|0;if((j|0)<=0){break}d:do{if(i){w=x;while(1){g=c[m+(w*80|0)+48>>2]|0;if((g|0)>=1){y=w;z=w;A=g;break d}if((w|0)>0){w=w-1|0}else{break c}}}else{w=x;while(1){g=c[m+(w*80|0)+48>>2]|0;if((g|0)>=1){if((c[m+(w*80|0)+32>>2]|0)==(d|0)){y=w;z=w;A=g;break d}}if((w|0)>0){w=w-1|0}else{break c}}}}while(0);x=m+(z*80|0)+8|0;w=c[x>>2]|0;g=c[x+4>>2]|0;if((g|0)<(f|0)|(g|0)==(f|0)&w>>>0<e>>>0){break}x=xrc(k,q,A,(A|0)<0|0?-1:0)|0;v=G;if((g|0)>(v|0)|(g|0)==(v|0)&w>>>0>x>>>0){j=y}else{break}}e:do{if(i){y=j;while(1){if((y|0)<=0){B=y;break e}A=y-1|0;q=m+(A*80|0)+8|0;k=m+(y*80|0)+8|0;if((c[q>>2]|0)==(c[k>>2]|0)&(c[q+4>>2]|0)==(c[k+4>>2]|0)){y=A}else{B=y;break}}}else{B=j}}while(0);c[a+12>>2]=B;l=0;return l|0}function OV(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;if((c[b>>2]|0)>0){d=a|0;e=0;do{P1((c[d>>2]|0)+(e*80|0)|0);e=e+1|0;}while((e|0)<(c[b>>2]|0))}mJb(a);c[a+12>>2]=0;c[a+8>>2]=0;c[b>>2]=0;return}function PV(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=a[d]|0;do{if(e<<24>>24==0){f=(zD(b)|0)&255;a[d]=f;if(f<<24>>24==0){g=0}else{h=f;break}return g|0}else{h=e}}while(0);e=h<<24>>24==60;f=e?62:60;i=0;j=h;do{WFb(c,j,1);j=(zD(b)|0)&255;a[d]=j;i=i+1|0;}while(!((j<<24>>24|0)==(f|0)|j<<24>>24==0));if(!e){g=i;return g|0}WFb(c,62,1);a[d]=0;g=i;return g|0}function QV(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=lrc(c|0)|0;e=a[b]|0;if(e<<24>>24==0){f=0;return f|0}else{g=b;h=0;i=e}while(1){a:do{if(i<<24>>24==0){j=g;k=h}else{e=g;b=h;l=i;while(1){if((b|0)==0){if((OFb(l<<24>>24)|0)!=0){j=e;k=0;break a}m=a[e]|0}else{m=l}n=m<<24>>24==34^b;o=e+1|0;p=a[o]|0;if(p<<24>>24==0){j=o;k=n;break}else{e=o;b=n;l=p}}}}while(0);q=j;while(1){if((OFb(a[q]|0)|0)==0){break}q=q+1|0}if((JFb(q,c,d)|0)==0){if((a[q+d|0]|0)==61){break}}l=a[q]|0;if(l<<24>>24==0){f=0;r=14;break}else{g=q;h=k;i=l}}if((r|0)==14){return f|0}r=d+1|0;f=q+(r+((a[q+r|0]|0)==34))|0;return f|0}function RV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+8|0;f=e|0;ZFb(d);g=f|0;h=0;j=0;k=0;a:while(1){b:do{if((k|0)==0){while(1){l=(zD(b)|0)&255;if((l<<24>>24|0)==13){h=h;j=j;k=0;continue a}else if((l<<24>>24|0)==0){m=11;break a}else if((l<<24>>24|0)!=10){n=0;o=j;p=h;q=l;break}}}else{l=h;r=j;s=0;while(1){t=(zD(b)|0)&255;if(t<<24>>24==0){m=11;break a}if(!((t<<24>>24|0)==13|(t<<24>>24|0)==10)){n=s;o=r;p=l;q=t;break b}u=(t<<24>>24==10?1:l&255)+r|0;if((u|0)==2){m=11;break a}v=s+1|0;a[f+s|0]=t;if((v|0)==4){m=11;break a}else{l=t<<24>>24==13|0;r=u;s=v}}}}while(0);if((n|0)==0){w=o}else{a[f+n|0]=0;UFb(d,2638464,(s=i,i=i+8|0,c[s>>2]=g,s)|0);i=s;w=0}WFb(d,q,1);h=p;j=w;k=k+1|0}if((m|0)==11){i=e;return}}function SV(a){a=a|0;var b=0;b=(Db(c[a+4>>2]|0,2177320)|0)==0;return(b?0:50)|0}function TV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;d=i;i=i+4128|0;e=d|0;f=d+8|0;g=d+4104|0;h=d+4112|0;j=d+4120|0;c[e>>2]=0;k=c[b+12>>2]|0;l=ZX(b,0)|0;if((l|0)==0){m=-12;i=d;return m|0}_X(l,64,1,1);n=c[l+8>>2]|0;c[n+8>>2]=3;c[n+48>>2]=1398953521;n=b+16|0;a:do{if((jD(c[n>>2]|0)|0)==0){b=f|0;l=k;o=0;while(1){p=o+8|0;q=o+48|0;b:do{if((o|0)==0){while(1){if((KD(c[n>>2]|0,b,4096)|0)==0){r=l;break a}if((krc(b,2371096,7)|0)==0){KD(c[n>>2]|0,b,4096)|0;Bd(b|0,2304808,(s=i,i=i+8|0,c[s>>2]=e,s)|0)|0;i=s}t=Bd(b|0,2253e3,(s=i,i=i+24|0,c[s>>2]=g,c[s+8>>2]=h,c[s+16>>2]=j,s)|0)|0;i=s;u=c[n>>2]|0;if((t|0)==3){break}if((jD(u)|0)!=0){r=l;break a}}t=fD(u,0,0,1)|0;v=G;w=c[g>>2]|0;x=c[h>>2]|0;y=c[j>>2]|0;z=c[e>>2]|0;A=KD(c[n>>2]|0,b,4096)|0;a[f+(mc(b|0,2210040)|0)|0]=0;if((a[b]|0)==0){B=0;break}C=Erc(x,(x|0)<0|0?-1:0,60,0)|0;x=G;D=Erc(w,(w|0)<0|0?-1:0,3600,0)|0;w=wrc(C,x,D,G)|0;D=wrc(w,G,y,(y|0)<0|0?-1:0)|0;y=wrc(D,G,z,(z|0)<0|0?-1:0)|0;E=v;F=t;H=G;I=y;J=A;K=20}else{while(1){if((KD(c[n>>2]|0,b,4096)|0)==0){r=l;break a}if((krc(b,2371096,7)|0)==0){KD(c[n>>2]|0,b,4096)|0;Bd(b|0,2304808,(s=i,i=i+8|0,c[s>>2]=e,s)|0)|0;i=s}A=Bd(b|0,2253e3,(s=i,i=i+24|0,c[s>>2]=g,c[s+8>>2]=h,c[s+16>>2]=j,s)|0)|0;i=s;if((A|0)==3){A=fD(c[n>>2]|0,0,0,1)|0;y=G;t=c[g>>2]|0;v=Erc(t,(t|0)<0|0?-1:0,3600,0)|0;t=G;z=c[h>>2]|0;D=Erc(z,(z|0)<0|0?-1:0,60,0)|0;z=wrc(D,G,v,t)|0;t=c[j>>2]|0;v=wrc(z,G,t,(t|0)<0|0?-1:0)|0;t=c[e>>2]|0;z=wrc(v,G,t,(t|0)<0|0?-1:0)|0;t=G;v=KD(c[n>>2]|0,b,4096)|0;a[f+(mc(b|0,2210040)|0)|0]=0;if((a[b]|0)!=0){E=y;F=A;H=t;I=z;J=v;K=20;break b}v=xrc(z,t,c[p>>2]|0,c[p+4>>2]|0)|0;c[q>>2]=v}if((jD(c[n>>2]|0)|0)!=0){r=l;break a}}}}while(0);if((K|0)==20){K=0;q=IV(l,b,J,0)|0;if((q|0)==0){m=-12;break}p=q+64|0;c[p>>2]=F;c[p+4>>2]=E;p=q+8|0;c[p>>2]=I;c[p+4>>2]=H;c[q+48>>2]=-1;B=q}if((jD(c[n>>2]|0)|0)==0){o=B}else{r=l;break a}}i=d;return m|0}else{r=k}}while(0);JV(r);m=0;i=d;return m|0}function UV(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function VV(a){a=a|0;OV(c[a+12>>2]|0);return 0}function WV(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function XV(a){a=a|0;var b=0,e=0,f=0,g=0;b=i;i=i+8|0;e=c[a+4>>2]|0;a=((d[e+1|0]|0)<<8|(d[e]|0)<<16|(d[e+2|0]|0)|0)==15711167?e+3|0:e;e=Bd(a|0,2534056,(f=i,i=i+8|0,c[f>>2]=b,f)|0)|0;i=f;if((e|0)==1){g=50;i=b;return g|0}e=(krc(a,2592752,13)|0)==0;g=e?33:0;i=b;return g|0}function YV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;d=i;i=i+3296|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+1088|0;p=d+3136|0;q=d+3168|0;r=c[b+12>>2]|0;s=ZX(b,0)|0;if((s|0)==0){t=-12;i=d;return t|0}_X(s,64,1,100);u=s+8|0;s=c[u>>2]|0;c[s+8>>2]=3;c[s+48>>2]=1400201814;SFb(n,0,-1);s=b+16|0;a:do{if((jD(c[s>>2]|0)|0)==0){v=o|0;w=b+1140|0;x=p|0;y=q|0;z=r;A=-2147483648;B=0;C=-1;D=0;E=1;while(1){if((KD(c[s>>2]|0,v,2048)|0)==0){F=D;H=z;I=37;break a}a[o+(mc(v|0,2371088)|0)|0]=0;b:do{if((a[v]|0)==91){if((krc(v,2304760,4)|0)==0){I=26;break}if((Db(v|0,2252992)|0)!=0){J=E;K=D;L=C;M=A;N=B;break}if((Db(v|0,2210032)|0)!=0){J=E;K=D;L=C;M=A;N=B;break}if((Db(v|0,2177312)|0)!=0){J=E;K=D;L=C;M=A;N=B;break}if((Db(v|0,2149184)|0)!=0){J=E;K=D;L=C;M=A;N=B;break}if((c[(c[u>>2]|0)+96>>2]|0)!=0){J=E;K=D;L=C;M=A;N=B;break}UFb(n,2125320,(O=i,i=i+8|0,c[O>>2]=v,O)|0);i=O;do{if((krc(v,2643416,17)|0)!=0){if((krc(v,2620208,10)|0)==0){break}if((krc(v,2592752,13)|0)==0){J=E;K=D;L=C;M=A;N=B;break b}else{P=1}while(1){Q=a[o+P|0]|0;if((Q<<24>>24|0)==93|(Q<<24>>24|0)==0){R=P;S=Q;break}a[p+(P-1)|0]=((Q<<24>>24)-65|0)>>>0<26>>>0?Q^32:Q;T=P+1|0;if(T>>>0<31>>>0){P=T}else{I=19;break}}if((I|0)==19){I=0;R=T;S=a[o+T|0]|0}a[p+(R-1)|0]=0;Q=(S<<24>>24==93)+R|0;while(1){U=a[o+Q|0]|0;if(U<<24>>24==32){Q=Q+1|0}else{V=Q;W=0;X=U;break}}while(1){if((X<<24>>24|0)==0|(X<<24>>24|0)==93){Y=W;break}Q=V+1|0;U=W+1|0;a[q+W|0]=X;if(!(U>>>0<127>>>0)){Y=U;break}V=Q;W=U;X=a[o+Q|0]|0}a[q+Y|0]=0;MGb(w,x,y,0)|0;J=E;K=D;L=C;M=A;N=B;break b}}while(0);Q=T5a(c[u>>2]|0,n)|0;if((Q|0)<0){Z=Q;break a}else{J=E;K=Q;L=C;M=A;N=B}}else{I=26}}while(0);do{if((I|0)==26){I=0;Q=Bd(v|0,2552192,(O=i,i=i+64|0,c[O>>2]=e,c[O+8>>2]=f,c[O+16>>2]=g,c[O+24>>2]=h,c[O+32>>2]=j,c[O+40>>2]=k,c[O+48>>2]=l,c[O+56>>2]=m,O)|0)|0;i=O;if((Q|0)==8){Q=c[j>>2]|0;U=Erc(Q,(Q|0)<0|0?-1:0,3600,0)|0;Q=G;_=c[k>>2]|0;$=Erc(_,(_|0)<0|0?-1:0,60,0)|0;_=wrc($,G,U,Q)|0;Q=c[l>>2]|0;U=wrc(_,G,Q,(Q|0)<0|0?-1:0)|0;Q=Erc(U,G,100,0)|0;U=wrc(Q,G,c[m>>2]|0,0)|0;Q=G;_=c[e>>2]|0;$=Erc(_,(_|0)<0|0?-1:0,3600,0)|0;_=G;aa=c[f>>2]|0;ba=Erc(aa,(aa|0)<0|0?-1:0,60,0)|0;aa=wrc(ba,G,$,_)|0;_=c[g>>2]|0;$=wrc(aa,G,_,(_|0)<0|0?-1:0)|0;_=Erc($,G,100,0)|0;$=c[h>>2]|0;aa=wrc(_,G,$,($|0)<0|0?-1:0)|0;$=G;_=xrc(U,Q,aa,$)|0;ca=1;da=_;ea=$;fa=aa}else{ca=0;da=C;ea=A;fa=B}if(ca){fD(c[s>>2]|0,0,0,1)|0;J=1;K=D;L=da;M=ea;N=fa;break}if((a[v]|0)==0){J=E;K=D;L=da;M=ea;N=fa;break}aa=(E|0)!=0;if(!aa){if((IV(z,2570120,1,1)|0)==0){Z=-12;break a}}$=IV(z,v,lrc(v|0)|0,E^1)|0;if(($|0)==0){Z=-12;break a}if(!aa){J=0;K=D;L=da;M=ea;N=fa;break}aa=$+64|0;c[aa>>2]=0;c[aa+4>>2]=0;aa=$+8|0;c[aa>>2]=fa;c[aa+4>>2]=ea;c[$+48>>2]=da;J=0;K=D;L=da;M=ea;N=fa}}while(0);if((jD(c[s>>2]|0)|0)==0){A=M;B=N;C=L;D=K;E=J}else{F=K;H=z;I=37;break}}}else{F=0;H=r;I=37}}while(0);if((I|0)==37){JV(H);Z=F}_Fb(n,0)|0;t=Z;i=d;return t|0}function ZV(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function _V(a){a=a|0;OV(c[a+12>>2]|0);return 0}function $V(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function aW(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<15){b=0;return b|0}e=c[a+4>>2]|0;a=(d[e+1|0]|0)<<8|(d[e]|0)<<16|(d[e+2|0]|0);if(!((a|0)==4413267|(a|0)==4609875)){b=0;return b|0}b=(d[e+3|0]|0)>>>0>19>>>0?25:100;return b|0}function bW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=(JD(e)|0)&-256;FD(e)|0;if((f|0)==1180128e3){g=e}else if((f|0)==1129796352){h=2}else{j=-5;i=b;return j|0}do{if((h|0)==2){f=a;KIb(f,32,2620176,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;k=d+64|0;c[k>>2]=hJb(4096)|0;l=hJb(4096)|0;m=d+68|0;c[m>>2]=l;n=aD(l,4096,0,f,212,0,0)|0;l=d+60|0;c[l>>2]=n;if((c[k>>2]|0)==0){j=-12;i=b;return j|0}if((c[m>>2]|0)==0|(n|0)==0){j=-12;i=b;return j|0}c[n+88>>2]=0;if((_pc(d+72|0,2592744,56)|0)==0){g=c[l>>2]|0;break}KIb(f,16,2570088,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;j=-22;i=b;return j|0}}while(0);h=(((zD(g)|0)>>3<<2)+4|0)/8|0;hD(g,h,(h|0)<0|0?-1:0)|0;c[d+40>>2]=DD(g)|0;DD(g)|0;c[d+24>>2]=0;d=a+20|0;c[d>>2]=c[d>>2]|1;j=0;i=b;return j|0}function cW(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;f=i;i=i+1048|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=c[b+12>>2]|0;m=c[l+60>>2]|0;n=(m|0)==0?c[b+16>>2]|0:m;m=fD(n,0,0,1)|0;o=G;if((jD(n)|0)!=0){p=-541478725;i=f;return p|0}q=b;r=k;s=j;t=h;u=b+24|0;v=l+40|0;w=b+28|0;x=l+24|0;l=o;o=m;a:while(1){m=DD(n)|0;z=m&63;A=m>>6;if((z|0)==63){B=FD(n)|0}else{B=z}if((A|0)<0){p=A;C=113;break}if((B|0)<0){C=7;break}b:do{switch(A|0){case 60:{z=DD(n)|0;m=B-2|0;D=c[u>>2]|0;if((D|0)!=0){E=c[w>>2]|0;F=0;do{H=c[E+(F<<2)>>2]|0;if((c[(c[H+8>>2]|0)+8>>2]|0)==0){if((c[H+4>>2]|0)==(z|0)){I=m;break b}}F=F+1|0;}while(F>>>0<D>>>0)}DD(n)|0;DD(n)|0;DD(n)|0;zD(n)|0;D=ZX(b,0)|0;if((D|0)==0){p=-12;C=113;break a}c[D+4>>2]=z;F=D+8|0;c[(c[F>>2]|0)+8>>2]=0;m=JX(1297888,zD(n)|0)|0;c[(c[F>>2]|0)+48>>2]=m;_X(D,16,256,c[v>>2]|0);I=B-10|0;break};case 14:{J=DD(n)|0;D=c[u>>2]|0;if((D|0)==0){C=28;break a}m=c[w>>2]|0;F=0;while(1){E=c[m+(F<<2)>>2]|0;if((c[(c[E+8>>2]|0)+8>>2]|0)==1){if((c[E+4>>2]|0)==(J|0)){I=B;break b}}E=F+1|0;if(E>>>0<D>>>0){F=E}else{C=28;break a}}break};case 61:{F=DD(n)|0;D=B-2|0;m=c[u>>2]|0;if((m|0)==0){I=D;break b}z=c[w>>2]|0;E=0;while(1){K=c[z+(E<<2)>>2]|0;if((c[(c[K+8>>2]|0)+8>>2]|0)==0){if((c[K+4>>2]|0)==(F|0)){break}}H=E+1|0;if(H>>>0<m>>>0){E=H}else{I=D;break b}}L=DD(n)|0;M=B-4|0;if((M|0)<1){I=M}else{C=38;break a}break};case 45:case 18:{D=c[u>>2]|0;if((D|0)!=0){E=c[w>>2]|0;m=0;do{F=c[E+(m<<2)>>2]|0;if((c[(c[F+8>>2]|0)+8>>2]|0)==1){if((c[F+4>>2]|0)==-1){I=B;break b}}m=m+1|0;}while(m>>>0<D>>>0)}zD(n)|0;D=zD(n)|0;c[x>>2]=DD(n)|0;if((eW(b,-1,D)|0)==0){p=-12;C=113;break a}I=B-4|0;break};default:{N=(A|0)==36;if((A|0)==19){D=c[u>>2]|0;if((D|0)==0){I=B;break b}m=c[w>>2]|0;E=0;while(1){O=c[m+(E<<2)>>2]|0;P=c[O+8>>2]|0;if((c[P+8>>2]|0)==1){if((c[O+4>>2]|0)==-1){break}}F=E+1|0;if(F>>>0<D>>>0){E=F}else{I=B;break b}}if((c[P+48>>2]|0)==86017){hD(n,4,0)|0;Q=B-4|0;if((Q|0)<1){I=Q;break b}else{C=86;break a}}else{if((B|0)<1){I=B;break b}else{C=88;break a}}}else if((A|0)==21){E=c[u>>2]|0;if((E|0)==0){C=95}else{D=c[w>>2]|0;m=0;while(1){R=c[D+(m<<2)>>2]|0;if((c[(c[R+8>>2]|0)+48>>2]|0)==8){if((c[R+4>>2]|0)==-2){S=m;break}}F=m+1|0;if(F>>>0<E>>>0){m=F}else{S=F;break}}if((S|0)==(E|0)){C=95}else{T=R}}if((C|0)==95){C=0;m=ZX(b,0)|0;if((m|0)==0){p=-12;C=113;break a}c[m+4>>2]=-2;D=c[m+8>>2]|0;c[D+8>>2]=0;c[D+48>>2]=8;_X(m,64,256,c[v>>2]|0);T=m}DD(n)|0;U=B-2|0;if((U|0)<4){I=U;break b}else{C=98;break a}}else if((A|0)==36|(A|0)==20){c[h>>2]=0;c[j>>2]=0;mrc(r|0,0,1024)|0;m=N?4:3;DD(n)|0;V=zD(n)|0;W=DD(n)|0;X=DD(n)|0;D=B-7|0;if((V|0)==3){Y=(zD(n)|0)+1|0;Z=W;_=B-8|0;C=51}else if((V|0)==4){Y=0;Z=W<<1;_=D;C=51}else if((V|0)==5){Y=0;Z=W<<2;_=D;C=51}else{KIb(q,16,2371016,($=i,i=i+8|0,c[$>>2]=V,$)|0);i=$;aa=D}c:do{if((C|0)==51){C=0;D=Z+3&-4;do{if((tIb(W,X,0,q)|0)>=0){if((D|0)>=(2147483647/(X|0)|0|0)){break}ba=ca(D,X)|0;da=ca(Y,m)|0;if((ba|0)>=(2147483647-da|0)){break}F=ba+da|0;c[g>>2]=F;c[j>>2]=hJb(_)|0;z=hJb(F)|0;c[h>>2]=z;F=c[j>>2]|0;if((F|0)==0|(z|0)==0){ea=-12;C=80;break a}z=AD(n,F,_)|0;if((z|0)>=0){if((Aqc(c[h>>2]|0,g,c[j>>2]|0,z)|0)==0){C=58;break a}}KIb(q,24,2252928,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;aa=z;break c}}while(0);KIb(q,16,2304688,($=i,i=i+16|0,c[$>>2]=W,c[$+8>>2]=X,$)|0);i=$;aa=_}}while(0);mJb(s);mJb(t);I=aa;break b}else{KIb(q,48,2125256,($=i,i=i+8|0,c[$>>2]=A,$)|0);i=$;I=B;break b}}}}while(0);A=(I|0)<0;if(A){KIb(q,24,2643368,($=i,i=i+8|0,c[$>>2]=I,$)|0);i=$}hD(n,A?0:I,A?0:(I|0)<0|0?-1:0)|0;A=fD(n,0,0,1)|0;m=G;if((jD(n)|0)==0){l=m;o=A}else{p=-541478725;C=113;break}}do{if((C|0)==7){KIb(q,16,2462176,($=i,i=i+8|0,c[$>>2]=B,$)|0);i=$;p=-1094995529;i=f;return p|0}else if((C|0)==28){I=zD(n)|0;aa=eW(b,J,I)|0;if((aa|0)==0){p=-12;i=f;return p|0}_=aa+56|0;c[_>>2]=FD(n)|0;c[_+4>>2]=0;if((I&240|0)==32){c[aa+448>>2]=DD(n)|0;fa=B-2|0}else{fa=B}I=fX(n,e,fa-7|0)|0;if((I|0)<0){p=I;i=f;return p|0}I=e+64|0;c[I>>2]=o;c[I+4>>2]=l;c[e+32>>2]=c[aa>>2];p=c[e+28>>2]|0;i=f;return p|0}else if((C|0)==38){aa=fX(n,e,M)|0;if((aa|0)<0){p=aa;i=f;return p|0}aa=e+64|0;c[aa>>2]=o;c[aa+4>>2]=l;aa=e+8|0;c[aa>>2]=L;c[aa+4>>2]=(L|0)<0|0?-1:0;c[e+32>>2]=c[K>>2];p=c[e+28>>2]|0;i=f;return p|0}else if((C|0)==58){aa=c[u>>2]|0;if((aa|0)==0){C=65}else{I=c[w>>2]|0;_=0;while(1){ga=c[I+(_<<2)>>2]|0;if((c[(c[ga+8>>2]|0)+48>>2]|0)==14){if((c[ga+4>>2]|0)==-3){ha=_;break}}j=_+1|0;if(j>>>0<aa>>>0){_=j}else{ha=j;break}}if((ha|0)==(aa|0)){C=65}else{ia=ga}}if((C|0)==65){_=ZX(b,0)|0;if((_|0)==0){ea=-12;C=80;break}c[_+4>>2]=-3;I=c[_+8>>2]|0;c[I+8>>2]=0;c[I+48>>2]=14;_X(_,64,256,c[v>>2]|0);ia=_}_=ia+8|0;I=c[_>>2]|0;c[I+120>>2]=W;c[I+124>>2]=X;I=K1(e,(c[g>>2]|0)-da|0)|0;if((I|0)<0){ea=I;C=80;break}I=e+64|0;c[I>>2]=o;c[I+4>>2]=l;c[e+32>>2]=c[ia>>2];if((V|0)==3){c[(c[_>>2]|0)+140>>2]=11;if((Y|0)>0){I=c[h>>2]|0;j=I+3|0;if(N){Z=0;do{R=Z<<2;c[k+(Z<<2)>>2]=(d[I+R|0]|0)<<16|(d[j]|0)<<24|(d[I+(R|1)|0]|0)<<8|(d[I+(R|2)|0]|0);Z=Z+1|0;}while((Z|0)<(Y|0))}else{Z=0;do{j=Z*3|0;c[k+(Z<<2)>>2]=(d[I+j|0]|0)<<16|(d[I+(j+1)|0]|0)<<8|(d[I+(j+2)|0]|0)|-16777216;Z=Z+1|0;}while((Z|0)<(Y|0))}}Z=U1(e,0,1024)|0;if((Z|0)==0){ea=-12;C=80;break}nrc(Z|0,r|0,1024)|0}else if((V|0)==4){c[(c[_>>2]|0)+140>>2]=46}else if((V|0)==5){c[(c[_>>2]|0)+140>>2]=N?27:295}else{KIb(0,0,2209976,($=i,i=i+24|0,c[$>>2]=2177272,c[$+8>>2]=2149160,c[$+16>>2]=384,$)|0);i=$;Hd();return 0}Z=e+28|0;if((ba|0)>(c[Z>>2]|0)){ea=-1094995529;C=80;break}nrc(c[e+24>>2]|0,(c[h>>2]|0)+da|0,ba)|0;ea=c[Z>>2]|0;C=80}else if((C|0)==86){Z=fX(n,e,Q)|0;if((Z|0)<0){p=Z}else{C=89;break}i=f;return p|0}else if((C|0)==88){Z=fX(n,e,B)|0;if((Z|0)<0){p=Z}else{C=89;break}i=f;return p|0}else if((C|0)==98){Z=K1(e,U)|0;if((Z|0)<0){p=Z;i=f;return p|0}Z=e+24|0;if((AD(n,c[Z>>2]|0,4)|0)!=4){P1(e);p=-1094995529;i=f;return p|0}I=c[Z>>2]|0;j=I;aa=je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;if((aa|0)==(-2555943|0)|(aa|0)==(-2490408|0)){aa=e+28|0;j=(c[aa>>2]|0)-4|0;c[aa>>2]=j;R=I+j|0;y=0;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;ja=AD(n,c[Z>>2]|0,c[aa>>2]|0)|0}else{aa=AD(n,I+4|0,(c[e+28>>2]|0)-4|0)|0;ja=(aa|0)>-1?aa+4|0:aa}aa=e+28|0;do{if((ja|0)==(c[aa>>2]|0)){ka=ja}else{if((ja|0)>=0){M1(e,ja);ka=c[aa>>2]|0;break}P1(e);p=ja;i=f;return p|0}}while(0);aa=e+64|0;c[aa>>2]=o;c[aa+4>>2]=l;c[e+32>>2]=c[T>>2];p=ka;i=f;return p|0}else if((C|0)==113){i=f;return p|0}}while(0);if((C|0)==80){mJb(s);mJb(t);p=ea;i=f;return p|0}else if((C|0)==89){C=e+64|0;c[C>>2]=o;c[C+4>>2]=l;c[e+32>>2]=c[O>>2];p=c[e+28>>2]|0;i=f;return p|0}return 0}function dW(a){a=a|0;var b=0;b=c[a+12>>2]|0;cqc(b+72|0)|0;mJb(b+64|0);mJb(b+68|0);mJb(b+60|0);return 0}function eW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=ZX(a,0)|0;if((e|0)==0){f=0;return f|0}c[e+4>>2]=b;b=e+8|0;a=c[b>>2]|0;g=a+416|0;if((d&1|0)==0){c[g>>2]=1;h=a+448|0;c[h>>2]=4;c[h+4>>2]=0}else{c[g>>2]=2;g=a+448|0;c[g>>2]=3;c[g+4>>2]=0}c[a+8>>2]=1;a=JX(525752,d>>>4&15)|0;g=c[b>>2]|0;b=g+48|0;c[b>>2]=a;c[e+236>>2]=1;if((d&2|0)==0&(a|0)==65536){c[b>>2]=65541}b=44100>>>((d>>>2&3^3)>>>0);c[g+412>>2]=b;_X(e,64,1,b);f=e;return f|0}function fW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[a+12>>2]|0;f=e+72|0;g=f;h=e+76|0;i=a+16|0;a=e+64|0;j=f;f=e+84|0;k=e+88|0;while(1){if((c[h>>2]|0)==0){e=AD(c[i>>2]|0,c[a>>2]|0,4096)|0;if((e|0)<0){l=e;m=9;break}c[j>>2]=c[a>>2];c[h>>2]=e}c[f>>2]=b;c[k>>2]=d;e=$pc(g,0)|0;if((e|0)<0){l=-22;m=9;break}if((e|0)==1){l=-541478725;m=9;break}n=c[k>>2]|0;if((n|0)!=(d|0)){m=8;break}}if((m|0)==8){l=d-n|0;return l|0}else if((m|0)==9){return l|0}return 0}function gW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+280|0;e=d|0;f=d+24|0;g=b+12|0;h=c[g>>2]|0;j=b+16|0;k=c[j>>2]|0;c[h+28>>2]=0;c[h+32>>2]=0;c[h+36>>2]=0;l=b+24|0;m=c[l>>2]|0;a:do{if((m|0)==0){n=h+56|0}else{o=b+28|0;p=h+52|0;q=h+48|0;r=h+56|0;s=0;t=m;while(1){u=c[(c[(c[o>>2]|0)+(s<<2)>>2]|0)+8>>2]|0;if((c[u+8>>2]|0)==1){if((c[p>>2]|0)!=0){v=6;break}if((c[u+48>>2]|0)!=86017){v=12;break}if((c[u+424>>2]|0)==0){v=9;break}c[p>>2]=u;w=dHb(65536)|0;c[q>>2]=w;if((w|0)==0){x=-12;v=52;break}z=c[l>>2]|0}else{if((c[r>>2]|0)!=0){v=14;break}w=c[u+48>>2]|0;if(!((w|0)==93|(w|0)==22|(w|0)==8)){v=17;break}c[r>>2]=u;z=t}u=s+1|0;if(u>>>0<z>>>0){s=u;t=z}else{n=r;break a}}if((v|0)==6){KIb(b,16,2620112,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;x=-1094995529;i=d;return x|0}else if((v|0)==9){KIb(b,16,2592688,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;x=-1;i=d;return x|0}else if((v|0)==12){KIb(b,16,2570056,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;x=-1;i=d;return x|0}else if((v|0)==14){KIb(b,16,2552152,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;x=-1094995529;i=d;return x|0}else if((v|0)==17){KIb(b,16,2534008,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;x=-1;i=d;return x|0}else if((v|0)==52){i=d;return x|0}}}while(0);v=c[n>>2]|0;if((v|0)==0){B=1;C=10;D=200;E=320}else{B=c[v+104>>2]|0;C=c[v+108>>2]|0;D=c[v+124>>2]|0;E=c[v+120>>2]|0}v=h+52|0;z=c[v>>2]|0;if((z|0)==0){c[h+24>>2]=~~(+(B|0)*44100.0/+(C|0))}else{c[h+24>>2]=(ca(c[z+412>>2]|0,B)|0)/(C|0)|0}dD(k,2518488,3);do{if((irc(2371008,c[c[b+8>>2]>>2]|0)|0)==0){F=9}else{z=c[n>>2]|0;if((z|0)!=0){l=c[z+48>>2]|0;if((l|0)==93){F=8;break}if((l|0)==22){F=6;break}}F=4}}while(0);bD(k,F);kD(k,104857600);mW(k,E*20|0,D*20|0);oD(k,(C<<8|0)/(B|0)|0);l=fD(k,0,0,1)|0;z=h;c[z>>2]=l;c[z+4>>2]=G;z=Erc(C,(C|0)<0|0?-1:0,600,0)|0;C=Crc(z,G,B,(B|0)<0|0?-1:0)|0;oD(k,C&65535);if((F|0)==9){F=c[g>>2]|0;C=c[j>>2]|0;B=fD(C,0,0,1)|0;z=F+8|0;c[z>>2]=B;c[z+4>>2]=G;c[F+44>>2]=69;oD(C,0);kD(k,8);jW(c[g>>2]|0,c[j>>2]|0)}C=c[n>>2]|0;do{if((C|0)!=0){if((c[C+48>>2]|0)!=8){break}n=c[g>>2]|0;F=c[j>>2]|0;z=fD(F,0,0,1)|0;B=n+8|0;c[B>>2]=z;c[B+4>>2]=G;c[n+44>>2]=2;oD(F,0);oD(k,1);mW(k,E,D);bD(k,1);bD(k,65);oD(k,0);lW(k,65536,65536);bD(k,0);F=f|0;c[e+20>>2]=2048;n=e+8|0;c[n>>2]=F;c[e+16>>2]=f+256;B=e+12|0;c[B>>2]=F;z=e+4|0;l=e|0;c[l>>2]=262921;c[z>>2]=10;nW(e,E,0);nW(e,0,D);nW(e,-E|0,0);nW(e,0,-D|0);m=c[l>>2]|0;r=c[z>>2]|0;if((r|0)>1){H=r-1|0;I=m<<1}else{t=je(m<<r|0)|0;m=c[B>>2]|0;y=t;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;H=r+31|0;I=0}c[l>>2]=I;c[z>>2]=H;if((H|0)>5){J=H-5|0;K=I<<5}else{r=je(I<<H|0)|0;m=c[B>>2]|0;y=r;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;J=H+27|0;K=0}c[l>>2]=K;c[z>>2]=J;b:do{if((J|0)<32){m=K<<J;c[l>>2]=m;r=m>>>24&255;while(1){m=c[B>>2]|0;c[B>>2]=m+1;a[m]=r;m=c[l>>2]|0;c[l>>2]=m<<8;t=(c[z>>2]|0)+8|0;c[z>>2]=t;if((t|0)>=32){break b}r=m>>>16&255}}}while(0);c[z>>2]=32;c[l>>2]=0;dD(k,F,(c[B>>2]|0)-(c[n>>2]|0)|0);jW(c[g>>2]|0,c[j>>2]|0)}}while(0);k=c[v>>2]|0;do{if((k|0)!=0){if((c[k+48>>2]|0)!=86017){break}J=c[g>>2]|0;K=c[j>>2]|0;H=fD(K,0,0,1)|0;I=J+8|0;c[I>>2]=H;c[I+4>>2]=G;c[J+44>>2]=45;oD(K,0);K=c[v>>2]|0;J=c[K+412>>2]|0;if((J|0)==11025){L=6}else if((J|0)==22050){L=10}else if((J|0)==44100){L=14}else{KIb(b,16,2504344,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;x=-1;i=d;return x|0}J=(c[K+416>>2]|0)==2|L;bD(c[j>>2]|0,J);bD(c[j>>2]|0,J|32);oD(c[j>>2]|0,c[h+24>>2]|0);oD(c[j>>2]|0,0);jW(c[g>>2]|0,c[j>>2]|0)}}while(0);eD(c[j>>2]|0);x=0;i=d;return x|0}function hW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[(c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0)+8>>2]|0;f=c[b+24>>2]|0;g=c[b+28>>2]|0;if((c[e+8>>2]|0)!=1){kW(a,e,f,g);h=0;i=d;return h|0}b=c[a+12>>2]|0;if((c[b+32>>2]|0)==16e3){KIb(e,32,2149104,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}k=b+48|0;if(((fHb(c[k>>2]|0)|0)+g|0)>65536){KIb(a,16,2643320,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-1;i=d;return h|0}jHb(c[k>>2]|0,f,g,0)|0;g=b+28|0;c[g>>2]=(c[g>>2]|0)+(c[e+424>>2]|0);if((c[b+56>>2]|0)!=0){h=0;i=d;return h|0}kW(a,e,0,0);h=0;i=d;return h|0}function iW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;g=a+24|0;h=c[g>>2]|0;if((h|0)==0){i=0;j=d;k=f}else{l=a+28|0;a=d+48|0;m=0;n=0;o=h;while(1){h=c[(c[(c[l>>2]|0)+(n<<2)>>2]|0)+8>>2]|0;if((c[h+8>>2]|0)==0){p=h;q=o}else{eHb(c[a>>2]|0);c[a>>2]=0;p=m;q=c[g>>2]|0}h=n+1|0;if(h>>>0<q>>>0){m=p;n=h;o=q}else{break}}i=p;j=c[b>>2]|0;k=c[e>>2]|0}p=fD(k,0,0,1)|0;q=j+8|0;c[q>>2]=p;c[q+4>>2]=G;c[j+44>>2]=0;oD(k,0);jW(c[b>>2]|0,c[e>>2]|0);if((c[(c[e>>2]|0)+88>>2]|0)==0|(i|0)==0){return 0}i=fD(f,0,0,1)|0;e=i;fD(f,4,0,0)|0;kD(f,e);i=d;fD(f,c[i>>2]|0,c[i+4>>2]|0,0)|0;i=d+36|0;oD(f,c[i>>2]|0);b=d+16|0;d=c[b>>2]|0;k=c[b+4>>2]|0;if(!((d|0)==0&(k|0)==0)){fD(f,d,k,0)|0;oD(f,c[i>>2]|0)}fD(f,e,(e|0)<0|0?-1:0,0)|0;return 0}function jW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=fD(b,0,0,1)|0;f=G;g=a+8|0;h=c[g>>2]|0;j=c[g+4>>2]|0;g=wrc(e,f,-2,0)|0;k=xrc(g,G,h,j)|0;g=k;k=c[a+44>>2]|0;fD(b,h,j,0)|0;if((k&256|0)!=0){oD(b,k<<6&-16448|63);kD(b,g-4|0);l=fD(b,e,f,0)|0;m=G;i=d;return}if((g|0)>=63){KIb(0,0,2252896,(j=i,i=i+24|0,c[j>>2]=2209960,c[j+8>>2]=2177248,c[j+16>>2]=60,j)|0);i=j;Hd()}oD(b,k<<6|g);l=fD(b,e,f,0)|0;m=G;i=d;return}function kW(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;g=a+12|0;h=c[g>>2]|0;j=a+16|0;a=c[j>>2]|0;k=h+32|0;if((c[k>>2]|0)==16e3){KIb(b,32,2149104,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}l=b+48|0;m=c[l>>2]|0;if((m|0)==8){if((c[k>>2]|0)>0){n=c[g>>2]|0;o=c[j>>2]|0;p=fD(o,0,0,1)|0;q=n+8|0;c[q>>2]=p;c[q+4>>2]=G;c[n+44>>2]=5;oD(o,0);oD(a,1);oD(a,1);jW(c[g>>2]|0,c[j>>2]|0);o=c[g>>2]|0;n=c[j>>2]|0;q=fD(n,0,0,1)|0;p=o+8|0;c[p>>2]=q;c[p+4>>2]=G;c[o+44>>2]=3;oD(n,0);oD(a,0);jW(c[g>>2]|0,c[j>>2]|0)}n=c[g>>2]|0;o=c[j>>2]|0;p=fD(o,0,0,1)|0;q=n+8|0;c[q>>2]=p;c[q+4>>2]=G;c[n+44>>2]=277;oD(o,0);kD(o,0);oD(a,0);lD(a,-2555943);dD(a,d,e);jW(c[g>>2]|0,c[j>>2]|0);o=c[g>>2]|0;n=c[j>>2]|0;q=fD(n,0,0,1)|0;p=o+8|0;c[p>>2]=q;c[p+4>>2]=G;c[o+44>>2]=4;oD(n,0);oD(a,1);oD(a,1);lW(a,1310720,1310720);jW(c[g>>2]|0,c[j>>2]|0)}else if((m|0)==93|(m|0)==22){m=h+36|0;n=(c[m>>2]|0)==0;o=c[g>>2]|0;p=c[j>>2]|0;q=fD(p,0,0,1)|0;r=o+8|0;c[r>>2]=q;c[r+4>>2]=G;r=o+44|0;if(n){c[r>>2]=60;oD(p,0);oD(a,0);n=fD(a,0,0,1)|0;o=h+16|0;c[o>>2]=n;c[o+4>>2]=G;oD(a,15e3);oD(a,c[b+120>>2]|0);oD(a,c[b+124>>2]|0);bD(a,0);bD(a,IX(1297888,c[l>>2]|0)|0);jW(c[g>>2]|0,c[j>>2]|0);l=c[g>>2]|0;b=c[j>>2]|0;o=fD(b,0,0,1)|0;n=l+8|0;c[n>>2]=o;c[n+4>>2]=G;c[l+44>>2]=26;oD(b,0);bD(a,54);oD(a,1);oD(a,0);lW(a,65536,65536);oD(a,c[m>>2]|0);dD(a,2125248,5);bD(a,0);jW(c[g>>2]|0,c[j>>2]|0)}else{c[r>>2]=26;oD(p,0);bD(a,17);oD(a,1);oD(a,c[m>>2]|0);jW(c[g>>2]|0,c[j>>2]|0)}p=c[g>>2]|0;r=c[j>>2]|0;b=fD(r,0,0,1)|0;l=p+8|0;c[l>>2]=b;c[l+4>>2]=G;c[p+44>>2]=317;oD(r,0);kD(r,0);oD(a,0);r=c[m>>2]|0;c[m>>2]=r+1;oD(a,r);dD(a,d,e);jW(c[g>>2]|0,c[j>>2]|0)}c[k>>2]=(c[k>>2]|0)+1;if((c[h+52>>2]|0)==0){s=c[g>>2]|0;t=c[j>>2]|0;u=0;v=0;w=fD(t,u,v,1)|0;x=G;y=s+8|0;z=y;A=z|0;c[A>>2]=w;B=z+4|0;c[B>>2]=x;C=s+44|0;D=C;c[D>>2]=1;oD(t,0);E=c[g>>2]|0;F=c[j>>2]|0;jW(E,F);i=f;return}k=h+48|0;if((fHb(c[k>>2]|0)|0)==0){s=c[g>>2]|0;t=c[j>>2]|0;u=0;v=0;w=fD(t,u,v,1)|0;x=G;y=s+8|0;z=y;A=z|0;c[A>>2]=w;B=z+4|0;c[B>>2]=x;C=s+44|0;D=C;c[D>>2]=1;oD(t,0);E=c[g>>2]|0;F=c[j>>2]|0;jW(E,F);i=f;return}e=fHb(c[k>>2]|0)|0;d=c[g>>2]|0;r=c[j>>2]|0;m=fD(r,0,0,1)|0;p=d+8|0;c[p>>2]=m;c[p+4>>2]=G;c[d+44>>2]=275;oD(r,0);kD(r,0);r=h+28|0;oD(a,c[r>>2]|0);oD(a,0);iHb(c[k>>2]|0,a,e,1946)|0;jW(c[g>>2]|0,c[j>>2]|0);c[r>>2]=0;s=c[g>>2]|0;t=c[j>>2]|0;u=0;v=0;w=fD(t,u,v,1)|0;x=G;y=s+8|0;z=y;A=z|0;c[A>>2]=w;B=z+4|0;c[B>>2]=x;C=s+44|0;D=C;c[D>>2]=1;oD(t,0);E=c[g>>2]|0;F=c[j>>2]|0;jW(E,F);i=f;return}function lW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;i=i+256|0;g=f|0;h=g|0;j=g;k=1;do{if((d|0)==0){l=1}else{m=(d|0)>-1?d:-d|0;if((m|0)==0){l=1;break}else{n=m;o=1}do{o=o+1|0;n=n>>1;}while((n|0)!=0);l=(o|0)>1?o:1}}while(0);if((e|0)==0){p=l}else{o=(e|0)>-1?e:-e|0;if((o|0)==0){q=1}else{n=o;o=1;while(1){m=o+1|0;r=n>>1;if((r|0)==0){q=m;break}else{n=r;o=m}}}p=(q|0)>(l|0)?q:l}l=p|32;k=l;if((p|0)<26){s=26;t=l<<p|d;u=j}else{c[h>>2]=je(l<<26|d>>>((p-26|0)>>>0)|0)|0;s=58;t=d;u=g+4|0}d=s-p|0;k=t;if((d|0)>(p|0)){v=d-p|0;w=t<<p|e;x=u}else{s=u;y=je(e>>>((p-d|0)>>>0)|t<<d|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;v=32-p+d|0;w=e;x=u+4|0}k=w;if((v|0)>1){z=v-1|0;A=w<<1|1;B=x}else{u=x;y=je(1>>>((1-v|0)>>>0)|w<<v|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;z=v+31|0;A=1;B=x+4|0}k=A;if((z|0)>5){C=z-5|0;D=A<<5|1;E=B}else{x=B;y=je(1>>>((5-z|0)>>>0)|A<<z|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;C=z+27|0;D=1;E=B+4|0}k=D;if((C|0)>1){F=C-1|0;G=D<<1;H=E}else{B=E;y=je(D<<C|0)|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;F=C+31|0;G=0;H=E+4|0}k=G;if((F|0)>1){I=F-1|0;J=G<<1;K=H}else{E=H;y=je(G<<F|0)|0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;I=F+31|0;J=0;K=H+4|0}k=J;if((I|0)>5){L=I-5|0;M=J<<5|1;N=K}else{H=K;y=je(1>>>((5-I|0)>>>0)|J<<I|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;L=I+27|0;M=1;N=K+4|0}k=M;if((L|0)>1){O=L-1|0;P=M<<1;Q=N}else{K=N;y=je(M<<L|0)|0;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;O=L+31|0;P=0;Q=N+4|0}k=P;if((O|0)>1){R=O-1|0;S=P<<1;T=Q}else{N=Q;y=je(P<<O|0)|0;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;R=O+31|0;S=0;T=Q+4|0}k=S;if((R|0)>=32){U=T;V=U;W=g;X=V-W|0;dD(b,j,X);i=f;return}Q=S<<R;k=Q;S=((31-R|0)>>>3)+1|0;O=Q>>>24&255;Q=R;R=T;while(1){a[R]=O;N=k;k=N<<8;P=Q+8|0;if((P|0)<32){O=N>>>16&255;Q=P;R=R+1|0}else{break}}U=T+S|0;V=U;W=g;X=V-W|0;dD(b,j,X);i=f;return}function mW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=i;i=i+256|0;g=f|0;h=g|0;j=g;k=0;do{if((d|0)==0){l=0}else{m=(d|0)>-1?d:-d|0;if((m|0)==0){n=1}else{o=m;m=1;do{m=m+1|0;o=o>>1;}while((o|0)!=0);if((m|0)>0){n=m}else{l=0;break}}l=n}}while(0);if((e|0)==0){p=l}else{n=(e|0)>-1?e:-e|0;if((n|0)==0){q=1}else{o=n;n=1;while(1){r=n+1|0;s=o>>1;if((s|0)==0){q=r;break}else{o=s;n=r}}}p=(q|0)>(l|0)?q:l}l=(1<<p)-1|0;k=p;if((p|0)<27){t=27;u=p<<p;v=j}else{c[h>>2]=je(p<<27|0)|0;t=59;u=0;v=g+4|0}h=t-p|0;k=u;t=l&d;if((h|0)>(p|0)){w=h-p|0;x=u<<p|t;z=v}else{d=v;y=je(t>>>((p-h|0)>>>0)|u<<h|0)|0;a[d]=y;y=y>>8;a[d+1|0]=y;y=y>>8;a[d+2|0]=y;y=y>>8;a[d+3|0]=y;w=32-p+h|0;x=t;z=v+4|0}k=x;if((w|0)>(p|0)){A=w-p|0;B=x<<p;C=z}else{v=z;y=je(x<<w|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;A=32-p+w|0;B=0;C=z+4|0}k=B;z=l&e;if((A|0)>(p|0)){D=A-p|0;E=B<<p|z;F=C}else{e=C;y=je(z>>>((p-A|0)>>>0)|B<<A|0)|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;D=32-p+A|0;E=z;F=C+4|0}k=E;if((D|0)>=32){G=F;H=G;I=g;J=H-I|0;dD(b,j,J);i=f;return}C=E<<D;k=C;E=((31-D|0)>>>3)+1|0;z=C>>>24&255;C=D;D=F;while(1){a[D]=z;A=k;k=A<<8;p=C+8|0;if((p|0)<32){z=A>>>16&255;C=p;D=D+1|0}else{break}}G=F+E|0;H=G;I=g;J=H-I|0;dD(b,j,J);i=f;return}function nW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=b|0;g=c[f>>2]|0;h=b+4|0;i=c[h>>2]|0;if((i|0)>1){j=i-1|0;k=g<<1|1}else{l=je(1>>>((1-i|0)>>>0)|g<<i|0)|0;g=b+12|0;m=c[g>>2]|0;y=l;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;j=i+31|0;k=1}c[f>>2]=k;c[h>>2]=j;if((j|0)>1){n=j-1|0;o=k<<1|1}else{i=je(1>>>((1-j|0)>>>0)|k<<j|0)|0;k=b+12|0;g=c[k>>2]|0;y=i;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;n=j+31|0;o=1}c[f>>2]=o;c[h>>2]=n;j=(d|0)==0;do{if(j){p=2}else{k=(d|0)>-1?d:-d|0;if((k|0)==0){p=2;break}else{q=k;r=1}do{r=r+1|0;q=q>>1;}while((q|0)!=0);p=(r|0)>2?r:2}}while(0);r=(e|0)==0;if(r){s=p}else{q=(e|0)>-1?e:-e|0;if((q|0)==0){t=1}else{k=q;q=1;while(1){g=q+1|0;i=k>>1;if((i|0)==0){t=g;break}else{k=i;q=g}}}s=(t|0)>(p|0)?t:p}p=(1<<s)-1|0;t=s-2|0;if((n|0)>4){u=n-4|0;v=o<<4|t}else{q=je(t>>>((4-n|0)>>>0)|o<<n|0)|0;o=b+12|0;k=c[o>>2]|0;y=q;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;u=n+28|0;v=t}c[f>>2]=v;c[h>>2]=u;t=(u|0)>1;if(j){if(t){w=u-1|0;x=v<<1}else{j=je(v<<u|0)|0;n=b+12|0;o=c[n>>2]|0;y=j;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;w=u+31|0;x=0}c[f>>2]=x;c[h>>2]=w;if((w|0)>1){z=w-1|0;A=x<<1|1}else{n=je(1>>>((1-w|0)>>>0)|x<<w|0)|0;x=b+12|0;o=c[x>>2]|0;y=n;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;z=w+31|0;A=1}c[f>>2]=A;c[h>>2]=z;w=p&e;if((z|0)>(s|0)){B=z-s|0;C=A<<s|w}else{x=je(w>>>((s-z|0)>>>0)|A<<z|0)|0;A=b+12|0;o=c[A>>2]|0;y=x;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;B=32-s+z|0;C=w}c[f>>2]=C;c[h>>2]=B;return}if(r){if(t){D=u-1|0;E=v<<1}else{r=je(v<<u|0)|0;B=b+12|0;C=c[B>>2]|0;y=r;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;D=u+31|0;E=0}c[f>>2]=E;c[h>>2]=D;if((D|0)>1){F=D-1|0;G=E<<1}else{B=je(E<<D|0)|0;E=b+12|0;C=c[E>>2]|0;y=B;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;F=D+31|0;G=0}c[f>>2]=G;c[h>>2]=F;D=p&d;if((F|0)>(s|0)){H=F-s|0;I=G<<s|D}else{E=je(D>>>((s-F|0)>>>0)|G<<F|0)|0;G=b+12|0;C=c[G>>2]|0;y=E;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;H=32-s+F|0;I=D}c[f>>2]=I;c[h>>2]=H;return}else{if(t){J=u-1|0;K=v<<1|1}else{t=je(1>>>((1-u|0)>>>0)|v<<u|0)|0;v=b+12|0;H=c[v>>2]|0;y=t;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;J=u+31|0;K=1}c[f>>2]=K;c[h>>2]=J;u=p&d;if((J|0)>(s|0)){L=J-s|0;M=K<<s|u}else{d=je(u>>>((s-J|0)>>>0)|K<<J|0)|0;K=b+12|0;v=c[K>>2]|0;y=d;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[K>>2]=(c[K>>2]|0)+4;L=32-s+J|0;M=u}c[f>>2]=M;c[h>>2]=L;u=p&e;if((L|0)>(s|0)){N=L-s|0;O=M<<s|u}else{e=je(u>>>((s-L|0)>>>0)|M<<L|0)|0;M=b+12|0;b=c[M>>2]|0;y=e;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[M>>2]=(c[M>>2]|0)+4;N=32-s+L|0;O=u}c[f>>2]=O;c[h>>2]=N;return}}function oW(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,2149096,4)|0)==0;return(b?50:0)|0}function pW(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;b=i;i=i+104|0;e=b|0;f=b+24|0;g=b+32|0;h=b+48|0;j=c[a+12>>2]|0;k=a+16|0;l=c[k>>2]|0;c[f>>2]=0;m=ZX(a,0)|0;if((m|0)==0){n=-12;i=b;return n|0}o=m+8|0;p=c[o>>2]|0;c[p+8>>2]=1;c[p+48>>2]=1950507339;c[m+236>>2]=1463898624;p=j;c[p>>2]=0;if((FD(l)|0)!=1264665204){fD(l,-4,-1,1)|0;n=0;i=b;return n|0}if((jD(l)|0)!=0){n=-541478725;i=b;return n|0}q=h+48|0;r=m+56|0;s=h+20|0;t=h+40|0;u=h+12|0;v=h+16|0;w=m+48|0;x=e+8|0;y=e+16|0;z=e|0;A=j+8|0;j=f;B=a;C=e+12|0;D=e+4|0;E=a+1156|0;F=g|0;a:while(1){H=(zD(l)|0)&127;I=ED(l)|0;switch(H|0){case 0:{J=21;break a;break};case 6:{if((I|0)!=19){n=-1094995529;J=35;break a}yD(l,404,13501623);AD(l,F,16)|0;if((xD(c[k>>2]|0)|0)!=(ID(l)|0)){KIb(B,16,2370976,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;if((c[E>>2]&8|0)!=0){n=-1094995529;J=35;break a}}KIb(B,40,2304648,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;L=0;do{KIb(B,40,2252888,(K=i,i=i+8|0,c[K>>2]=d[g+L|0]|0,K)|0);i=K;L=L+1|0;}while((L|0)<16);KIb(B,40,2209952,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break};case 1:case 7:case 4:{if((I|0)<4){n=-1094995529;J=35;break a}L=I-3|0;M=hJb(I+13|0)|0;c[f>>2]=M;if((M|0)==0){n=-12;J=35;break a}mrc(M+L|0,0,16)|0;yD(l,404,13501623);if((AD(l,c[f>>2]|0,L)|0)!=(L|0)){J=10;break a}M=xD(c[k>>2]|0)|0;if((M|0)!=(ID(l)|0)){KIb(B,16,2462112,(K=i,i=i+8|0,c[K>>2]=H,K)|0);i=K;if((c[E>>2]&8|0)!=0){J=13;break a}}M=c[f>>2]|0;N=L>>>0>268435455>>>0?-8:L<<3;L=N>>>0>2147483639>>>0|(M|0)==0;O=L?0:M;M=L?0:N;c[z>>2]=O;c[C>>2]=M;c[y>>2]=M+8;c[D>>2]=O+(M>>3);c[x>>2]=0;break};default:{M=hD(l,I,(I|0)<0|0?-1:0)|0;O=M;if((O|0)<0){n=O;J=35;break a}}}if((H|0)==7){if((I|0)!=11){n=-1094995529;J=35;break}c[p>>2]=1;O=c[x>>2]|0;M=c[y>>2]|0;N=c[z>>2]|0;L=N+(O>>>3)|0;P=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((O&7)>>>0)&65535;L=O+16|0;O=M>>>0>L>>>0?L:M;c[x>>2]=O;L=N+(O>>>3)|0;Q=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((O&7)>>>0);L=O+16|0;O=M>>>0>L>>>0?L:M;c[x>>2]=O;L=N+(O>>>3)|0;R=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((O&7)>>>0)&255;L=O+8|0;O=M>>>0>L>>>0?L:M;c[x>>2]=O;L=N+(O>>>3)|0;N=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((O&7)>>>0)&16777215;L=O+24|0;c[x>>2]=M>>>0>L>>>0?L:M;M=wrc(N,0,Q<<16|P|0,R|0)|0;c[A>>2]=M;c[A+4>>2]=G;mJb(j)}else if((H|0)==1){Q2a(e,h);M=c[q>>2]|0;R=c[q+4>>2]|0;P=0;if((R|0)>(P|0)|(R|0)==(P|0)&M>>>0>0>>>0){c[r>>2]=M;c[r+4>>2]=R}R=c[o>>2]|0;c[R+792>>2]=c[s>>2];M=c[t>>2]|0;P=c[t+4>>2]|0;if(!((M|0)==0&(P|0)==0)){Q=R+448|0;c[Q>>2]=M;c[Q+4>>2]=P}P=c[u>>2]|0;c[R+412>>2]=P;c[R+416>>2]=c[v>>2];c[w>>2]=0;c[w+4>>2]=0;_X(m,64,1,P);c[(c[o>>2]|0)+96>>2]=c[f>>2];c[(c[o>>2]|0)+100>>2]=I-3;c[f>>2]=0}else if((H|0)==4){P=c[x>>2]|0;R=c[y>>2]|0;Q=(c[z>>2]|0)+(P>>>3)|0;M=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((P&7)>>>0)&16777215;Q=P+24|0;c[x>>2]=R>>>0>Q>>>0?Q:R;KIb(B,40,2177224,(K=i,i=i+8|0,c[K>>2]=M,K)|0);i=K;mJb(j)}if((jD(l)|0)!=0){n=-541478725;J=35;break}}if((J|0)==10){mJb(j);n=-5;i=b;return n|0}else if((J|0)==13){mJb(j);n=-1094995529;i=b;return n|0}else if((J|0)==21){j=fD(l,0,0,1)|0;K=G;if((c[l+88>>2]|0)!=0){HB(a)|0;fD(l,j,K,0)|0;}l=wrc(c[A>>2]|0,c[A+4>>2]|0,j,K)|0;c[A>>2]=l;c[A+4>>2]=G;n=0;i=b;return n|0}else if((J|0)==35){i=b;return n|0}return 0}function qW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;if((c[d>>2]|0)==0){e=vS(a,b)|0;return e|0}f=c[a+16>>2]|0;a=d+8|0;d=c[a>>2]|0;g=c[a+4>>2]|0;a=fD(f,0,0,1)|0;h=xrc(d,g,a,G)|0;a=G;g=0;d=(a|0)>(g|0)|(a|0)==(g|0)&h>>>0>1024>>>0;g=d?1024:h;h=d?0:a;a=0;if((h|0)<(a|0)|(h|0)==(a|0)&g>>>0<1>>>0){e=-541478725;return e|0}a=fX(f,b,g)|0;if((a|0)<0){e=a;return e|0}c[b+32>>2]=0;e=a;return e|0}function rW(a,b,c){a=a|0;b=b|0;c=c|0;return EGb(DGb(12)|0,a,b,c)|0}function sW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[b+4>>2]|0;if((a[d+(ud(d|0,2533976)|0)|0]|0)!=123){e=0;return e|0}b=Db(d|0,2643304)|0;if((b|0)==0){f=0}else{f=(a[b+((ud(b+10|0,2533976)|0)+10)|0]|0)==58|0}b=Db(d|0,2620096)|0;if((b|0)==0){g=f}else{g=((a[b+((ud(b+10|0,2533976)|0)+10)|0]|0)==58)+f|0}f=Db(d|0,2592672)|0;if((f|0)==0){h=g}else{h=((a[f+((ud(f+9|0,2533976)|0)+9)|0]|0)==58)+g|0}g=Db(d|0,2569960)|0;if((g|0)==0){i=h}else{i=((a[g+((ud(g+18|0,2533976)|0)+18)|0]|0)==58)+h|0}h=Db(d|0,2552128)|0;if((h|0)==0){j=i}else{j=((a[h+((ud(h+11|0,2533976)|0)+11)|0]|0)==58)+i|0}if((j|0)==5){e=100;return e|0}e=(j|0)!=0?50:0;return e|0}function tW(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;e=i;i=i+2280|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=e+112|0;v=e+120|0;w=e+128|0;x=e+136|0;y=e+144|0;z=e+152|0;A=e+160|0;B=e+168|0;C=e+176|0;D=e+184|0;E=e+192|0;F=e+200|0;H=e+208|0;I=e+216|0;J=e+224|0;K=e+232|0;L=e+1256|0;M=c[b+12>>2]|0;N=b+16|0;O=c[N>>2]|0;P=M+16|0;Q=P;R=AD(O,I,1)|0;if((R|0)>0){S=d[I]|0}else{S=(R|0)==0?-541478725:R}c[J>>2]=S;R=S;a:while(1){switch(R|0){case 123:{T=10;break a;break};case 32:case 9:case 10:case 13:{break};default:{U=-1094995529;break a}}S=AD(O,H,1)|0;if((S|0)>0){V=d[H]|0}else{V=(S|0)==0?-541478725:S}c[J>>2]=V;R=V}b:do{if((T|0)==10){V=AD(O,F,1)|0;if((V|0)>0){W=d[F]|0}else{W=(V|0)==0?-541478725:V}c[J>>2]=W;if((xW(O,J,K,0)|0)<0){U=-1094995529;break}V=c[J>>2]|0;c:while(1){switch(V|0){case 32:case 9:case 10:case 13:{break};case 58:{break c;break};default:{U=-1094995529;break b}}R=AD(O,E,1)|0;if((R|0)>0){X=d[E]|0}else{X=(R|0)==0?-541478725:R}c[J>>2]=X;V=X}V=AD(O,D,1)|0;if((V|0)>0){Y=d[D]|0}else{Y=(V|0)==0?-541478725:V}c[J>>2]=Y;V=K|0;if((irc(c[V>>2]|0,2370960)|0)==0){Z=Y}else{U=-1094995529;break}d:while(1){switch(Z|0){case 91:{break d;break};case 32:case 9:case 10:case 13:{break};default:{U=-1094995529;break b}}R=AD(O,C,1)|0;if((R|0)>0){_=d[C]|0}else{_=(R|0)==0?-541478725:R}c[J>>2]=_;Z=_}R=AD(O,B,1)|0;if((R|0)>0){$=d[B]|0}else{$=(R|0)==0?-541478725:R}c[J>>2]=$;R=L+8|0;H=L|0;S=L+4|0;I=$;e:while(1){c[R>>2]=0;aa=I;f:while(1){switch(aa|0){case 123:{break f;break};case 32:case 9:case 10:case 13:{break};default:{T=39;break e}}ba=AD(O,A,1)|0;if((ba|0)>0){ca=d[A]|0}else{ca=(ba|0)==0?-541478725:ba}c[J>>2]=ca;aa=ca}ba=AD(O,z,1)|0;if((ba|0)>0){da=d[z]|0}else{da=(ba|0)==0?-541478725:ba}c[J>>2]=da;ba=fD(O,0,0,1)|0;ea=wrc(ba,G,-1,-1)|0;ba=G;fa=xW(O,J,K,0)|0;if((fa|0)<0){U=fa;break b}else{ga=-2147483648;ha=0;ia=-2147483648;ja=0}g:while(1){ka=c[J>>2]|0;h:while(1){switch(ka|0){case 32:case 9:case 10:case 13:{break};case 58:{break h;break};default:{T=54;break e}}fa=AD(O,y,1)|0;if((fa|0)>0){la=d[y]|0}else{la=(fa|0)==0?-541478725:fa}c[J>>2]=la;ka=la}fa=AD(O,x,1)|0;if((fa|0)>0){ma=d[x]|0}else{ma=(fa|0)==0?-541478725:fa}c[J>>2]=ma;fa=c[V>>2]|0;i:do{if((irc(fa,2304624)|0)==0){na=ma;while(1){if(!((na|0)==32|(na|0)==9|(na|0)==10|(na|0)==13)){oa=0;break}pa=AD(O,w,1)|0;if((pa|0)>0){qa=d[w]|0}else{qa=(pa|0)==0?-541478725:pa}c[J>>2]=qa;na=qa}while(1){if((oa|0)>=2){U=-1094995529;break b}ra=c[735328+(oa<<2)>>2]|0;sa=a[ra]|0;if((na|0)==(sa<<24>>24|0)){break}else{oa=oa+1|0}}if(sa<<24>>24==0){ta=na}else{pa=ra;ua=sa;va=na;while(1){if((va|0)!=(ua<<24>>24|0)){U=-1094995529;break b}wa=pa+1|0;xa=AD(O,v,1)|0;if((xa|0)>0){ya=d[v]|0}else{ya=(xa|0)==0?-541478725:xa}c[J>>2]=ya;xa=a[wa]|0;if(xa<<24>>24==0){ta=ya;break}else{pa=wa;ua=xa;va=ya}}}if(((ta|32)-97|0)>>>0<26>>>0){U=-1094995529;break b}else{za=ia;Aa=ja;Ba=ga;Ca=ha;Da=ta}}else{if((irc(fa,2252880)|0)==0){va=xW(O,J,L,1)|0;if((va|0)<0){U=va;break b}za=ia;Aa=ja;Ba=ga;Ca=ha;Da=c[J>>2]|0;break}if((irc(fa,2209936)|0)==0){va=ma;while(1){if(!((va|0)==32|(va|0)==9|(va|0)==10|(va|0)==13)){break}ua=AD(O,u,1)|0;if((ua|0)>0){Ea=d[u]|0}else{Ea=(ua|0)==0?-541478725:ua}c[J>>2]=Ea;va=Ea}ua=va-48|0;if(ua>>>0>9>>>0){U=-1094995529;break b}else{Fa=0;Ga=0;Ha=ua}while(1){ua=Erc(Ga,Fa,10,0)|0;pa=wrc(ua,G,Ha,(Ha|0)<0|0?-1:0)|0;ua=G;na=AD(O,t,1)|0;if((na|0)>0){Ia=d[t]|0}else{Ia=(na|0)==0?-541478725:na}c[J>>2]=Ia;na=Ia-48|0;if(na>>>0<10>>>0){Fa=ua;Ga=pa;Ha=na}else{za=ia;Aa=ja;Ba=ua;Ca=pa;Da=Ia;break i}}}if((irc(fa,2177208)|0)==0){Ja=ma}else{U=-1094995529;break b}while(1){if(!((Ja|0)==32|(Ja|0)==9|(Ja|0)==10|(Ja|0)==13)){break}va=AD(O,s,1)|0;if((va|0)>0){Ka=d[s]|0}else{Ka=(va|0)==0?-541478725:va}c[J>>2]=Ka;Ja=Ka}va=Ja-48|0;if(va>>>0>9>>>0){U=-1094995529;break b}else{La=0;Ma=0;Na=va}while(1){va=Erc(Ma,La,10,0)|0;pa=wrc(va,G,Na,(Na|0)<0|0?-1:0)|0;va=G;ua=AD(O,r,1)|0;if((ua|0)>0){Oa=d[r]|0}else{Oa=(ua|0)==0?-541478725:ua}c[J>>2]=Oa;ua=Oa-48|0;if(ua>>>0<10>>>0){La=va;Ma=pa;Na=ua}else{za=va;Aa=pa;Ba=ga;Ca=ha;Da=Oa;break}}}}while(0);fa=Da;j:while(1){switch(fa|0){case 44:{break j;break};case 32:case 9:case 10:case 13:{break};default:{Pa=fa;break g}}pa=AD(O,q,1)|0;if((pa|0)>0){Qa=d[q]|0}else{Qa=(pa|0)==0?-541478725:pa}c[J>>2]=Qa;fa=Qa}fa=AD(O,p,1)|0;if((fa|0)>0){Ra=d[p]|0}else{Ra=(fa|0)==0?-541478725:fa}c[J>>2]=Ra;fa=xW(O,J,K,0)|0;if((fa|0)<0){U=fa;break b}else{ga=Ba;ha=Ca;ia=za;ja=Aa}}k:while(1){switch(Pa|0){case 125:{break k;break};case 32:case 9:case 10:case 13:{break};default:{T=109;break e}}fa=AD(O,o,1)|0;if((fa|0)>0){Sa=d[o]|0}else{Sa=(fa|0)==0?-541478725:fa}c[J>>2]=Sa;Pa=Sa}fa=AD(O,n,1)|0;if((fa|0)>0){Ta=d[n]|0}else{Ta=(fa|0)==0?-541478725:fa}c[J>>2]=Ta;if((c[R>>2]|0)==0|(Ca|0)==0&(Ba|0)==(-2147483648|0)|(Aa|0)==0&(za|0)==(-2147483648|0)){U=-1094995529;break b}fa=IV(Q,c[H>>2]|0,c[S>>2]|0,0)|0;if((fa|0)==0){U=-12;break b}pa=fa+64|0;c[pa>>2]=ea;c[pa+4>>2]=ba;pa=fa+8|0;c[pa>>2]=Ca;c[pa+4>>2]=Ba;c[fa+48>>2]=Aa;_Fb(L,0)|0;fa=c[J>>2]|0;l:while(1){switch(fa|0){case 44:{break l;break};case 32:case 9:case 10:case 13:{break};default:{Ua=fa;T=125;break e}}pa=AD(O,m,1)|0;if((pa|0)>0){Va=d[m]|0}else{Va=(pa|0)==0?-541478725:pa}c[J>>2]=Va;fa=Va}fa=AD(O,l,1)|0;if((fa|0)>0){Wa=d[l]|0}else{Wa=(fa|0)==0?-541478725:fa}c[J>>2]=Wa;I=Wa}if((T|0)==39){U=(aa|0)<0?aa:-1094995529;break}else if((T|0)==54){U=(ka|0)<0?ka:-1094995529;break}else if((T|0)==109){U=(Pa|0)<0?Pa:-1094995529;break}else if((T|0)==125){m:while(1){T=0;switch(Ua|0){case 32:case 9:case 10:case 13:{break};case 93:{break m;break};default:{T=130;break m}}I=AD(O,k,1)|0;if((I|0)>0){Xa=d[k]|0}else{Xa=(I|0)==0?-541478725:I}c[J>>2]=Xa;Ua=Xa;T=125}if((T|0)==130){U=(Ua|0)<0?Ua:-1094995529;break}I=AD(O,j,1)|0;if((I|0)>0){Ya=d[j]|0}else{Ya=(I|0)==0?-541478725:I}c[J>>2]=Ya;I=Ya;n:while(1){switch(I|0){case 125:{break n;break};case 32:case 9:case 10:case 13:{break};default:{T=140;break n}}S=AD(O,h,1)|0;if((S|0)>0){Za=d[h]|0}else{Za=(S|0)==0?-541478725:S}c[J>>2]=Za;I=Za}if((T|0)==140){U=(I|0)<0?I:-1094995529;break}S=AD(O,g,1)|0;if((S|0)>0){_a=d[g]|0}else{_a=(S|0)==0?-541478725:S}c[J>>2]=_a;S=_a;while(1){if((S|0)==(-541478725|0)){U=0;break b}else if(!((S|0)==32|(S|0)==9|(S|0)==10|(S|0)==13)){break}H=AD(O,f,1)|0;if((H|0)>0){$a=d[f]|0}else{$a=(H|0)==0?-541478725:H}c[J>>2]=$a;S=$a}U=(S|0)<0?S:-1094995529;break}}}while(0);if((U|0)<0){if((U|0)==-1094995529){$a=fD(c[N>>2]|0,0,0,1)|0;N=G;KIb(b,16,2462080,(J=i,i=i+16|0,c[J>>2]=$a,c[J+8>>2]=N,J)|0);i=J}OV(Q);ab=U;i=e;return ab|0}JV(Q);Q=c[M+20>>2]|0;if((Q|0)>0){U=M+8|0;M=c[P>>2]|0;J=0;while(1){N=M+(J*80|0)+8|0;$a=wrc(c[N>>2]|0,c[N+4>>2]|0,c[U>>2]|0,c[U+4>>2]|0)|0;c[N>>2]=$a;c[N+4>>2]=G;N=J+1|0;if((N|0)<(Q|0)){J=N}else{bb=M;break}}}else{bb=c[P>>2]|0}P=Q-1|0;Q=ZX(b,0)|0;if((Q|0)==0){ab=-12;i=e;return ab|0}b=c[Q+8>>2]|0;c[b+8>>2]=3;c[b+48>>2]=94210;_X(Q,64,1,1e3);c[Q+228>>2]=0;b=Q+48|0;c[b>>2]=0;c[b+4>>2]=0;b=bb+(P*80|0)+8|0;M=c[bb+(P*80|0)+48>>2]|0;P=wrc(M,(M|0)<0|0?-1:0,c[b>>2]|0,c[b+4>>2]|0)|0;b=Q+56|0;c[b>>2]=P;c[b+4>>2]=G;b=Q+208|0;c[b>>2]=0;c[b+4>>2]=0;ab=0;i=e;return ab|0}function uW(a,b){a=a|0;b=b|0;return MV((c[a+12>>2]|0)+16|0,b)|0}function vW(a){a=a|0;OV((c[a+12>>2]|0)+16|0);return 0}function wW(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV((c[a+12>>2]|0)+16|0,a,b,d,e,f,g,h,i,j)|0}function xW(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+56|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=g+40|0;o=g+48|0;p=(f|0)!=0;SFb(e,0,p?-1:1);f=c[b>>2]|0;a:while(1){switch(f|0){case 34:{q=8;break a;break};case 32:case 9:case 10:case 13:{break};default:{q=7;break a}}r=AD(a,o,1)|0;if((r|0)>0){s=d[o]|0}else{s=(r|0)==0?-541478725:r}c[b>>2]=s;f=s}b:do{if((q|0)==7){t=(f|0)<0?f:-1094995529}else if((q|0)==8){s=AD(a,n,1)|0;if((s|0)>0){u=d[n]|0}else{u=(s|0)==0?-541478725:s}c[b>>2]=u;c:do{if((u|0)<1|(u|0)==34){v=u}else{s=u;d:while(1){do{if((s|0)==92){o=AD(a,m,1)|0;if((o|0)>0){r=d[m]|0;c[b>>2]=r;w=r}else{r=(o|0)==0?-541478725:o;c[b>>2]=r;if((r|0)<0){t=-1094995529;break b}else{w=r}}if((w|32|0)!=117){WFb(e,w&255,1);break}r=AD(a,l,1)|0;if((r|0)>0){x=d[l]|0}else{x=(r|0)==0?-541478725:r}c[b>>2]=x;r=x-48|0;if(r>>>0<10>>>0){y=r}else{o=x|32;if(!((o-97|0)>>>0<26>>>0)){z=x;break d}y=(x|0)<58?r:o-87|0}o=AD(a,l,1)|0;if((o|0)>0){A=d[l]|0}else{A=(o|0)==0?-541478725:o}c[b>>2]=A;o=A-48|0;if(o>>>0<10>>>0){B=o}else{r=A|32;if(!((r-97|0)>>>0<26>>>0)){z=A;break d}B=(A|0)<58?o:r-87|0}r=B+(y<<4)|0;o=AD(a,l,1)|0;if((o|0)>0){C=d[l]|0}else{C=(o|0)==0?-541478725:o}c[b>>2]=C;o=C-48|0;if(o>>>0<10>>>0){D=o}else{E=C|32;if(!((E-97|0)>>>0<26>>>0)){z=C;break d}D=(C|0)<58?o:E-87|0}E=D+(r<<4)|0;r=AD(a,l,1)|0;if((r|0)>0){F=d[l]|0}else{F=(r|0)==0?-541478725:r}c[b>>2]=F;r=F-48|0;if(r>>>0<10>>>0){G=r}else{o=F|32;if(!((o-97|0)>>>0<26>>>0)){z=F;break d}G=(F|0)<58?r:o-87|0}o=G+(E<<4)|0;if(o>>>0<128>>>0){WFb(e,o&255,1);break}E=o>>>0>65535>>>0;r=E?o>>>16:o;H=E?16:0;if((r&65280|0)==0){I=H;J=r}else{I=H|8;J=r>>>8}r=I-2+(d[1359664+J|0]|0)|0;H=(r|0)/5|0;WFb(e,(o>>>((H*6|0)>>>0)|65408>>>(H>>>0))&255,1);if((r|0)>4){K=H}else{break}do{K=K-1|0;WFb(e,(o>>>((K*6|0)>>>0)&63|128)&255,1);}while((K|0)>0)}else{WFb(e,s&255,1)}}while(0);o=AD(a,k,1)|0;if((o|0)>0){L=d[k]|0}else{L=(o|0)==0?-541478725:o}c[b>>2]=L;if((L|0)<1|(L|0)==34){v=L;break c}else{s=L}}t=(z|0)<0?z:-1094995529;break b}}while(0);e:while(1){switch(v|0){case 34:{break e;break};case 32:case 9:case 10:case 13:{break};default:{q=41;break e}}s=AD(a,j,1)|0;if((s|0)>0){M=d[j]|0}else{M=(s|0)==0?-541478725:s}c[b>>2]=M;v=M}if((q|0)==41){t=(v|0)<0?v:-1094995529;break}s=AD(a,h,1)|0;if((s|0)>0){N=d[h]|0}else{N=(s|0)==0?-541478725:s}c[b>>2]=N;if(!p){O=0;i=g;return O|0}if((c[e+4>>2]|0)>>>0<(c[e+8>>2]|0)>>>0){O=0}else{t=-12;break}i=g;return O|0}}while(0);_Fb(e,0)|0;O=t;i=g;return O|0}function yW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;d=i;i=i+248|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+112|0;n=d+176|0;o=d+184|0;p=b+12|0;q=c[p>>2]|0;r=b+32|0;c[n>>2]=r;a:do{if((a[r]|0)==0){s=3}else{t=0;while(1){if((t|0)==16){s=6;break}u=GFb(n,2370432)|0;v=t+1|0;c[o+(t<<2)>>2]=u;if((u|0)==0){w=-12;s=89;break}u=c[n>>2]|0;if((ud(u|0,2370432)|0)==0){x=u}else{y=u+1|0;c[n>>2]=y;x=y}if((a[x]|0)==0){s=2;break}else{t=v}}b:do{if((s|0)==2){if((v|0)==0){s=3;break a}t=q+8|0;y=l|0;u=m|0;z=b;A=b+1140|0;B=b+24|0;C=b+28|0;D=0;while(1){E=o+(D<<2)|0;F=c[E>>2]|0;G=t+(D*12|0)|0;c[j>>2]=0;c[k>>2]=0;c:do{if((ud(F|0,2376632)|0)==0){H=0;I=F}else{J=F+1|0;c[f>>2]=J;if((ud(J|0,2383416)|0)!=0){H=0;I=F+2|0;break}J=VJb(f,2404752,2390288,0,g,h)|0;d:do{if((J|0)<0){K=J;s=15}else{while(1){L=MGb(j,c[g>>2]|0,c[h>>2]|0,12)|0;if((L|0)<0){M=L;break d}L=c[f>>2]|0;N=L+1|0;if((ud(L|0,2383416)|0)!=0){H=0;I=N;break c}c[f>>2]=N;N=VJb(f,2404752,2390288,0,g,h)|0;if((N|0)<0){K=N;s=15;break}}}}while(0);if((s|0)==15){s=0;KIb(z,16,2397328,(O=i,i=i+8|0,c[O>>2]=c[f>>2],O)|0);i=O;M=K}OGb(j);H=M;I=0}}while(0);e:do{if((H|0)<0){P=H}else{J=LGb(c[j>>2]|0,2592664,0,0)|0;if((J|0)==0){Q=0}else{N=J+4|0;J=c[N>>2]|0;c[N>>2]=0;MGb(j,2592664,0,0)|0;Q=J}J=LGb(c[j>>2]|0,2569952,0,0)|0;if((J|0)==0){R=0}else{N=J+4|0;J=c[N>>2]|0;c[N>>2]=0;MGb(j,2569952,0,0)|0;R=J}J=SO(k,0,Q,I)|0;f:do{if((J|0)<0){S=J}else{PGb((c[k>>2]|0)+1140|0,c[A>>2]|0,0);N=qJb(c[B>>2]|0,4)|0;L=N;T=t+(D*12|0)+8|0;c[T>>2]=L;if((N|0)==0){S=-12;break}g:do{if((c[B>>2]|0)!=0){if((R|0)==0){N=0;U=L;while(1){V=c[(c[C>>2]|0)+(N<<2)>>2]|0;c[U+(N<<2)>>2]=N;W=ZX(c[k>>2]|0,0)|0;if((W|0)==0){S=-12;break f}c[W+4>>2]=c[V+4>>2];X=V+412|0;Y=W+412|0;Z=c[X+4>>2]|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=Z;Z=V+40|0;Y=W+40|0;X=c[Z+4>>2]|0;c[Y>>2]=c[Z>>2];c[Y+4>>2]=X;X=V+48|0;Y=c[X+4>>2]|0;Z=W+48|0;c[Z>>2]=c[X>>2];c[Z+4>>2]=Y;Y=V+56|0;Z=c[Y+4>>2]|0;X=W+56|0;c[X>>2]=c[Y>>2];c[X+4>>2]=Z;Z=V+64|0;X=c[Z+4>>2]|0;Y=W+64|0;c[Y>>2]=c[Z>>2];c[Y+4>>2]=X;c[W+72>>2]=c[V+72>>2];X=V+80|0;Y=W+80|0;Z=c[X+4>>2]|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=Z;Z=V+92|0;Y=W+92|0;X=c[Z+4>>2]|0;c[Y>>2]=c[Z>>2];c[Y+4>>2]=X;PGb(W+88|0,c[V+88>>2]|0,0);X=nWa(c[W+8>>2]|0,c[V+8>>2]|0)|0;if((X|0)<0){S=X;break f}X=N+1|0;if(!(X>>>0<(c[B>>2]|0)>>>0)){break g}N=X;U=c[T>>2]|0}}else{_=0;$=0}while(1){U=c[(c[C>>2]|0)+(_<<2)>>2]|0;aa=vY(b,U,R)|0;if((aa|0)<0){break}N=(c[T>>2]|0)+(_<<2)|0;if((aa|0)==0){c[N>>2]=-1;ba=$}else{c[N>>2]=$;N=ZX(c[k>>2]|0,0)|0;if((N|0)==0){S=-12;break f}c[N+4>>2]=c[U+4>>2];X=U+412|0;V=N+412|0;W=c[X+4>>2]|0;c[V>>2]=c[X>>2];c[V+4>>2]=W;W=U+40|0;V=N+40|0;X=c[W+4>>2]|0;c[V>>2]=c[W>>2];c[V+4>>2]=X;X=U+48|0;V=c[X+4>>2]|0;W=N+48|0;c[W>>2]=c[X>>2];c[W+4>>2]=V;V=U+56|0;W=c[V+4>>2]|0;X=N+56|0;c[X>>2]=c[V>>2];c[X+4>>2]=W;W=U+64|0;X=c[W+4>>2]|0;V=N+64|0;c[V>>2]=c[W>>2];c[V+4>>2]=X;c[N+72>>2]=c[U+72>>2];X=U+80|0;V=N+80|0;W=c[X+4>>2]|0;c[V>>2]=c[X>>2];c[V+4>>2]=W;W=U+92|0;V=N+92|0;X=c[W+4>>2]|0;c[V>>2]=c[W>>2];c[V+4>>2]=X;PGb(N+88|0,c[U+88>>2]|0,0);X=nWa(c[N+8>>2]|0,c[U+8>>2]|0)|0;if((X|0)<0){S=X;break f}else{ba=$+1|0}}X=_+1|0;if(X>>>0<(c[B>>2]|0)>>>0){_=X;$=ba}else{break g}}KIb(z,16,2552080,(O=i,i=i+16|0,c[O>>2]=R,c[O+8>>2]=F,O)|0);i=O;S=aa;break f}}while(0);T=c[k>>2]|0;do{if((c[(c[T+8>>2]|0)+28>>2]&1|0)==0){L=UD(T+16|0,I,2)|0;if((L|0)<0){mrc(y|0,0,64)|0;a[y]=0;RGb(L,y,64)|0;KIb(z,16,2533944,(O=i,i=i+16|0,c[O>>2]=F,c[O+8>>2]=y,O)|0);i=O;S=L;break f}else{ca=c[k>>2]|0;break}}else{ca=T}}while(0);T=TO(ca,j)|0;if((T|0)<0){mrc(u|0,0,64)|0;a[u]=0;RGb(T,u,64)|0;KIb(z,16,2518416,(O=i,i=i+16|0,c[O>>2]=F,c[O+8>>2]=u,O)|0);i=O;S=T;break}L=c[k>>2]|0;c[G>>2]=L;X=qJb(c[L+24>>2]|0,12)|0;L=t+(D*12|0)+4|0;c[L>>2]=X;if((X|0)==0){S=-12;break}X=LGb(c[j>>2]|0,2504312,0,2)|0;h:do{if((X|0)==0){da=T}else{U=T;N=X;i:while(1){ea=N|0;fa=c[ea>>2]|0;V=fa+4|0;ga=a[V]|0;if(ga<<24>>24==0){ha=V}else{if((ud(V|0,2412112)|0)!=1){s=50;break}ha=fa+5|0}V=c[k>>2]|0;if((c[V+24>>2]|0)==0){ia=U;ja=fa}else{ka=N+4|0;la=0;W=V;while(1){ma=vY(W,c[(c[W+28>>2]|0)+(la<<2)>>2]|0,ha)|0;if((ma|0)<0){s=55;break i}do{if((ma|0)>0){V=c[ka>>2]|0;KIb(z,48,2470120,(O=i,i=i+32|0,c[O>>2]=ha,c[O+8>>2]=V,c[O+16>>2]=la,c[O+24>>2]=I,O)|0);i=O;V=(c[L>>2]|0)+(la<<2)|0;if((c[V>>2]|0)!=0){KIb(z,24,2461264,(O=i,i=i+16|0,c[O>>2]=la,c[O+8>>2]=I,O)|0);i=O;na=ma;break}Y=rJb(c[ka>>2]|0)|0;if((Y|0)==0){oa=-12;s=65;break i}Z=HFb(Y,2125232,e)|0;j:do{if((Z|0)==0){pa=0}else{qa=V;ra=Z;while(1){sa=e3(ra)|0;if((sa|0)==0){break}c[qa>>2]=sa;ta=HFb(0,2125232,e)|0;if((ta|0)==0){pa=0;break j}else{qa=sa+12|0;ra=ta}}KIb(z,16,2422216,(O=i,i=i+8|0,c[O>>2]=ra,O)|0);i=O;pa=-1313558101}}while(0);kJb(Y);if((pa|0)<0){oa=pa;s=65;break i}else{na=0}}else{na=0}}while(0);Z=la+1|0;V=c[k>>2]|0;if(Z>>>0<(c[V+24>>2]|0)>>>0){la=Z;W=V}else{break}}ia=na;ja=c[ea>>2]|0}MGb(j,ja,0,0)|0;W=LGb(c[j>>2]|0,2504312,0,2)|0;if((W|0)==0){da=ia;break h}else{U=ia;N=W}}if((s|0)==50){s=0;KIb(z,16,2490800,(O=i,i=i+24|0,c[O>>2]=fa,c[O+8>>2]=ga<<24>>24,c[O+16>>2]=2412112,O)|0);i=O;P=-22;break e}else if((s|0)==55){s=0;N=c[ea>>2]|0;KIb(z,16,248e4,(O=i,i=i+24|0,c[O>>2]=ha,c[O+8>>2]=N,c[O+16>>2]=I,O)|0);i=O;S=ma;break f}else if((s|0)==65){s=0;KIb(z,16,2444752,(O=i,i=i+24|0,c[O>>2]=c[ka>>2],c[O+8>>2]=la,c[O+16>>2]=I,O)|0);i=O;S=oa;break f}}}while(0);L=c[j>>2]|0;if((L|0)==0){S=da;break}X=LGb(L,10230768,0,2)|0;if((X|0)==0){S=-1414549496;break}else{ua=X}while(1){KIb(c[k>>2]|0,16,2431536,(O=i,i=i+8|0,c[O>>2]=c[ua>>2],O)|0);i=O;X=LGb(c[j>>2]|0,10230768,ua,2)|0;if((X|0)==0){S=-1414549496;break}else{ua=X}}}}while(0);kJb(Q);kJb(R);OGb(j);P=S}}while(0);if((P|0)<0){w=P;s=89;break b}F=G|0;J=c[F>>2]|0;X=c[c[J+8>>2]>>2]|0;KIb(z,40,2252848,(O=i,i=i+16|0,c[O>>2]=J+32,c[O+8>>2]=X,O)|0);i=O;X=c[F>>2]|0;if((c[X+24>>2]|0)!=0){J=t+(D*12|0)+4|0;L=0;T=X;do{X=c[(c[J>>2]|0)+(L<<2)>>2]|0;N=(c[(c[T+28>>2]|0)+(L<<2)>>2]|0)+8|0;U=u5a(c[(c[N>>2]|0)+48>>2]|0)|0;W=ALb(c[(c[N>>2]|0)+8>>2]|0)|0;KIb(z,40,2209904,(O=i,i=i+24|0,c[O>>2]=L,c[O+8>>2]=U,c[O+16>>2]=W,O)|0);i=O;if((X|0)!=0){KIb(z,40,2177200,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;W=X;do{X=W+12|0;U=(c[X>>2]|0)!=0?2125232:10230768;KIb(z,40,2149080,(O=i,i=i+16|0,c[O>>2]=c[c[W+4>>2]>>2],c[O+8>>2]=U,O)|0);i=O;W=c[X>>2]|0;}while((W|0)!=0)}KIb(z,40,2620088,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;L=L+1|0;T=c[F>>2]|0;}while(L>>>0<(c[T+24>>2]|0)>>>0)}mJb(E);T=D+1|0;if(T>>>0<v>>>0){D=T}else{va=B;wa=v;break a}}}else if((s|0)==6){KIb(b,16,2370920,(O=i,i=i+8|0,c[O>>2]=16,O)|0);i=O;xa=16;ya=-1163346256;s=90}}while(0);if((s|0)==89){if((v|0)==0){za=w}else{xa=v;ya=w;s=90}}if((s|0)==90){B=0;while(1){mJb(o+(B<<2)|0);D=B+1|0;if(D>>>0<xa>>>0){B=D}else{za=ya;break}}}BW(c[p>>2]|0);Aa=za;i=d;return Aa|0}}while(0);if((s|0)==3){va=b+24|0;wa=0}za=q+4|0;c[za>>2]=wa;p=c[va>>2]|0;if((p|0)==0){Aa=0;i=d;return Aa|0}ya=b;b=q+8|0;q=0;xa=p;p=wa;while(1){if((p|0)==0){s=86}else{wa=0;o=0;do{o=((c[(c[b+(wa*12|0)+8>>2]|0)+(q<<2)>>2]|0)>>>31^1)+o|0;wa=wa+1|0;}while(wa>>>0<p>>>0);if((o|0)==0){s=86}else{Ba=xa}}if((s|0)==86){s=0;KIb(ya,24,2304576,(O=i,i=i+8|0,c[O>>2]=q,O)|0);i=O;Ba=c[va>>2]|0}wa=q+1|0;if(!(wa>>>0<Ba>>>0)){Aa=0;break}q=wa;xa=Ba;p=c[za>>2]|0}i=d;return Aa|0}function zW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;i=i+168|0;e=d|0;f=d+80|0;g=d+160|0;h=g;j=i;i=i+8|0;k=j;l=c[a+12>>2]|0;m=l+4|0;if((c[m>>2]|0)==0){n=0;i=d;return n|0}o=l+8|0;l=b+32|0;p=a+28|0;a=b+8|0;q=f+8|0;r=b+16|0;s=f+16|0;t=b+48|0;u=f+48|0;v=f+32|0;w=e;x=f;y=e+24|0;z=e+28|0;A=f+24|0;B=f+28|0;C=f+36|0;D=e+52|0;E=e|0;F=0;H=0;while(1){I=c[o+(F*12|0)>>2]|0;J=c[l>>2]|0;K=c[(c[o+(F*12|0)+8>>2]|0)+(J<<2)>>2]|0;do{if((K|0)<0){L=H}else{if((S1(f,b)|0)<0){if((H|0)==0){L=0;break}}else{if((Q1(f)|0)<0&(H|0)==0){L=0;break}}M=(c[(c[p>>2]|0)+(J<<2)>>2]|0)+40|0;N=c[M+4>>2]|0;c[g>>2]=c[M>>2];c[g+4>>2]=N;N=I+28|0;M=(c[(c[N>>2]|0)+(K<<2)>>2]|0)+40|0;O=c[M+4>>2]|0;c[j>>2]=c[M>>2];c[j+4>>2]=O;O=XIb(c[a>>2]|0,c[a+4>>2]|0,h,k)|0;c[q>>2]=O;c[q+4>>2]=G;O=XIb(c[r>>2]|0,c[r+4>>2]|0,h,k)|0;c[s>>2]=O;c[s+4>>2]=G;O=c[t>>2]|0;M=XIb(O,(O|0)<0|0?-1:0,h,k)|0;c[u>>2]=M;c[v>>2]=K;M=I;O=c[(c[o+(F*12|0)+4>>2]|0)+(K<<2)>>2]|0;P=c[(c[(c[N>>2]|0)+(K<<2)>>2]|0)+8>>2]|0;do{if((O|0)!=0){N=O;a:while(1){nrc(w|0,x|0,80)|0;Q=g3(N,P,0,y,z,c[A>>2]|0,c[B>>2]|0,c[C>>2]&1)|0;do{if((Q|0)==0){if((c[y>>2]|0)==(c[A>>2]|0)){R=0;break}if((c[D>>2]|0)==0){S=12;break}if((S1(e,f)|0)<0){T=N;break a}else{U=1;S=13}}else{S=12}}while(0);if((S|0)==12){S=0;if((Q|0)>0){U=Q;S=13}else{R=Q}}if((S|0)==13){S=0;P1(f);V=aGb(c[y>>2]|0,c[z>>2]|0,116,0,0)|0;c[E>>2]=V;if((V|0)==0){W=U;X=N;S=15;break}else{R=U}}nrc(x|0,w|0,80)|0;V=c[N+12>>2]|0;if((V|0)==0){W=R;X=0;S=15;break}else{N=V}}if((S|0)==15){S=0;if((W|0)<0){T=X}else{break}}N=c[c[T+4>>2]>>2]|0;V=c[v>>2]|0;Y=u5a(c[P+48>>2]|0)|0;KIb(M,16,2461992,(Z=i,i=i+32|0,c[Z>>2]=N,c[Z+8>>2]=V,c[Z+16>>2]=I+32,c[Z+24>>2]=Y,Z)|0);i=Z}}while(0);M=_O(I,f)|0;L=(M|0)<0&(H|0)==0?M:H}}while(0);I=F+1|0;if(I>>>0<(c[m>>2]|0)>>>0){F=I;H=L}else{n=L;break}}i=d;return n|0}function AW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+12|0;a=c[b>>2]|0;d=a+4|0;if((c[d>>2]|0)==0){e=0;f=a;BW(f);return e|0}g=a+8|0;a=0;h=0;while(1){i=c[g+(h*12|0)>>2]|0;j=$O(i)|0;k=(j|0)<0&(a|0)==0?j:a;if((c[(c[i+8>>2]|0)+28>>2]&1|0)==0){j=i+16|0;i=WD(c[j>>2]|0)|0;c[j>>2]=0;l=(i|0)<0&(k|0)==0?i:k}else{l=k}k=h+1|0;if(k>>>0<(c[d>>2]|0)>>>0){a=l;h=k}else{break}}e=l;f=c[b>>2]|0;BW(f);return e|0}function BW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a+4|0;if((c[b>>2]|0)==0){return}d=a+8|0;a=0;do{e=d+(a*12|0)|0;f=c[e>>2]|0;g=f+24|0;h=c[g>>2]|0;i=d+(a*12|0)+4|0;if((h|0)!=0){j=0;k=h;while(1){h=c[(c[i>>2]|0)+(j<<2)>>2]|0;if((h|0)==0){l=k}else{m=h;while(1){h=c[m+12>>2]|0;f3(m);if((h|0)==0){break}else{m=h}}l=c[g>>2]|0}m=j+1|0;if(m>>>0<l>>>0){j=m;k=l}else{break}}}mJb(d+(a*12|0)+8|0);mJb(i);k=f+16|0;WD(c[k>>2]|0)|0;c[k>>2]=0;pX(f);c[e>>2]=0;a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function CW(a){a=a|0;var b=0,e=0,f=0.0,i=0.0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=5261396){e=0;return e|0}a=b+16|0;b=je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0;f=(c[k>>2]=b,+g[k>>2]);i=f;if(i<.1|f>1.0e3){e=25;return e|0}else{h[k>>3]=i;e=c[k+4>>2]&2147483647;b=2146435072;return(e>>>0>b>>>0|e>>>0==b>>>0&(c[k>>2]|0)>>>0>0>>>0?25:100)|0}return 0}function DW(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;i=i+8|0;e=d|0;f=c[b+12>>2]|0;h=c[b+16>>2]|0;j=iD(h)|0;l=G;JD(h)|0;m=f;c[m>>2]=JD(h)|0;JD(h)|0;JD(h)|0;n=f+24|0;o=JD(h)|0;AKb(e,(c[k>>2]=o,+g[k>>2]),2147483647);o=n;p=c[e+4>>2]|0;c[o>>2]=c[e>>2];c[o+4>>2]=p;p=f+20|0;c[p>>2]=JD(h)|0;o=f+8|0;c[o>>2]=JD(h)|0;e=JD(h)|0;q=e;r=0;s=h+96|0;c[s>>2]=q;c[s+4>>2]=r;t=0;do{if((l|0)>(t|0)|(l|0)==(t|0)&j>>>0>0>>>0){if(!((e|0)==0|((l|0)<(r|0)|(l|0)==(r|0)&j>>>0<q>>>0))){break}c[s>>2]=j;c[s+4>>2]=l}}while(0);l=f+16|0;c[l>>2]=JD(h)|0;JD(h)|0;s=f+4|0;c[s>>2]=JD(h)|0;c[f+12>>2]=JD(h)|0;c[f+48>>2]=c[o>>2];o=f+40|0;c[o>>2]=c[s>>2];c[o+4>>2]=0;o=c[l>>2]|0;fD(h,o,(o|0)<0|0?-1:0,0)|0;o=f+60|0;c[o>>2]=JD(h)|0;AD(h,f+64|0,16)|0;l=f+84|0;s=f+80|0;if((c[o>>2]|0)<=0){u=0;i=d;return u|0}j=f+28|0;q=n;n=f+52|0;r=f+56|0;e=0;a:while(1){t=a[f+(e+64)|0]|0;do{if((t<<24>>24|0)==0){if((c[s>>2]|0)!=0){u=0;v=15;break a}w=ZX(b,0)|0;if((w|0)==0){u=-12;v=15;break a}_X(w,64,c[j>>2]|0,c[q>>2]|0);x=w+8|0;y=c[x>>2]|0;c[y+8>>2]=0;c[y+48>>2]=101;c[y+52>>2]=0;y=JD(h)|0;c[(c[x>>2]|0)+120>>2]=y;y=JD(h)|0;c[(c[x>>2]|0)+124>>2]=y;y=c[p>>2]|0;x=0;z=w+56|0;c[z>>2]=y;c[z+4>>2]=x;z=w+64|0;c[z>>2]=y;c[z+4>>2]=x;c[s>>2]=w;c[n>>2]=c[w>>2];if((c[m>>2]|0)!=69632){break}JD(h)|0}else if((t<<24>>24|0)==1){if((c[l>>2]|0)!=0){u=0;v=15;break a}w=ZX(b,0)|0;if((w|0)==0){u=-12;v=15;break a}x=w+8|0;z=c[x>>2]|0;c[z+8>>2]=1;c[z+48>>2]=69650;c[z+52>>2]=0;z=JD(h)|0;c[(c[x>>2]|0)+416>>2]=z;z=JD(h)|0;c[(c[x>>2]|0)+412>>2]=z;_X(w,64,1,z);c[r>>2]=c[w>>2];c[l>>2]=1}}while(0);t=e+1|0;if((t|0)<(c[o>>2]|0)){e=t}else{u=0;v=15;break}}if((v|0)==15){i=d;return u|0}return 0}function EW(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[a+12>>2]|0;f=c[a+16>>2]|0;a=e+88|0;g=c[a>>2]|0;if((g|0)!=0){h=fX(f,b,g)|0;if((h|0)!=(c[a>>2]|0)){P1(b);i=-5;return i|0}c[b+32>>2]=c[e+56>>2];if((c[a>>2]|0)>>>0>7>>>0){h=(c[b+24>>2]|0)+4|0;c[b+48>>2]=je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0}c[a>>2]=0;h=e+32|0;c[h>>2]=(c[h>>2]|0)+1;i=0;return i|0}h=e+32|0;if(!((c[h>>2]|0)>>>0<(c[e+20>>2]|0)>>>0)){i=-541478725;return i|0}g=e+40|0;fD(f,c[g>>2]|0,c[g+4>>2]|0,0)|0;j=e+48|0;k=c[j>>2]|0;l=k>>>0>1>>>0;m=wrc(l?k:1,l?0:0,c[g>>2]|0,c[g+4>>2]|0)|0;c[g>>2]=m;c[g+4>>2]=G;c[j>>2]=JD(f)|0;JD(f)|0;j=JD(f)|0;if((c[e+84>>2]|0)==0){c[h>>2]=(c[h>>2]|0)+1}else{c[a>>2]=JD(f)|0}if((fX(f,b,j)|0)==(j|0)){c[b+32>>2]=c[e+52>>2];i=0;return i|0}else{P1(b);i=-5;return i|0}return 0}function FW(b){b=b|0;var d=0,e=0,f=0;if((c[b+8>>2]|0)<258){d=0;return d|0}e=c[b+4>>2]|0;b=0;while(1){if((b|0)>=256){break}if((a[e+b|0]|0)==0){b=b+1|0}else{d=0;f=8;break}}if((f|0)==8){return d|0}do{if((a[e+256|0]|0)==0){if((a[e+257|0]|0)==0){d=0}else{break}return d|0}}while(0);d=25;return d|0}function GW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;d=b;e=c[a+16>>2]|0;fD(e,256,0,0)|0;f=0;while(1){if((f|0)>=30){break}g=DD(e)|0;if((g|0)==0){break}c[d+16+(f*12|0)>>2]=0;c[d+16+(f*12|0)+4>>2]=g;h=hJb(g)|0;c[d+16+(f*12|0)+8>>2]=h;if((h|0)==0){i=-12;j=11;break}else{f=f+1|0}}if((j|0)==11){return i|0}c[b+376>>2]=f;c[b+12>>2]=0;f=1;while(1){if((f|0)>=101){break}h=JW(d,e)|0;if((h|0)==0){f=f+1|0}else{i=h;j=11;break}}if((j|0)==11){return i|0}c[b+8>>2]=0;c[b+404>>2]=0;j=ZX(a,0)|0;if((j|0)==0){i=-12;return i|0}_X(j,32,1,25);c[b+4>>2]=c[j>>2];f=c[j+8>>2]|0;c[f+8>>2]=0;c[f+48>>2]=96;c[f+52>>2]=0;c[f+120>>2]=256;c[f+124>>2]=128;f=ZX(a,0)|0;if((f|0)==0){i=-12;return i|0}a=f+48|0;c[a>>2]=0;c[a+4>>2]=0;_X(f,32,1,22050);c[b>>2]=c[f>>2];b=c[f+8>>2]|0;c[b+8>>2]=1;c[b+48>>2]=65537;c[b+52>>2]=0;c[b+416>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;c[b+412>>2]=22050;c[b+792>>2]=16;c[b+72>>2]=352800;c[b+432>>2]=2;i=0;return i|0}function HW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;b=e+404|0;do{if((c[b>>2]|0)==0){g=JW(e,f)|0;if((g|0)!=0){h=g;return h|0}g=e+388|0;i=c[g>>2]|0;j=e+396|0;k=c[j>>2]|0;if((i|0)==(-k|0)){break}if((K1(d,i+1+k|0)|0)!=0){h=-12;return h|0}k=d+24|0;a[c[k>>2]|0]=0;do{if((c[g>>2]|0)!=0){i=c[k>>2]|0;a[i]=a[i]|1;fD(f,(c[e+392>>2]|0)+(c[e+12>>2]|0)|0,0,0)|0;i=AD(f,(c[k>>2]|0)+1|0,c[g>>2]|0)|0;if((i|0)==(c[g>>2]|0)){break}else{h=-5}return h|0}}while(0);if((c[j>>2]|0)!=0){i=c[k>>2]|0;a[i]=a[i]|2;nrc((c[k>>2]|0)+((c[g>>2]|0)+1)|0,c[e+400>>2]|0,c[j>>2]|0)|0}c[d+32>>2]=c[e+4>>2];i=c[e+8>>2]|0;l=d+8|0;c[l>>2]=i;c[l+4>>2]=(i|0)<0|0?-1:0;c[b>>2]=1;h=0;return h|0}}while(0);i=c[e+384>>2]|0;if((i|0)==0){h=-5;return h|0}fD(f,(c[e+12>>2]|0)+i|0,0,0)|0;i=fX(f,d,c[e+380>>2]|0)|0;if((i|0)<0){h=i;return h|0}c[d+32>>2]=c[e>>2];d=e+8|0;c[d>>2]=(c[d>>2]|0)+1;c[b>>2]=0;h=0;return h|0}function IW(a){a=a|0;var b=0;b=(c[a+12>>2]|0)+16|0;a=0;do{kJb(c[b+(a*12|0)+8>>2]|0);a=a+1|0;}while((a|0)<30);return 0}function JW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=a+12|0;h=(c[g>>2]|0)+6144|0;c[g>>2]=h;fD(b,h,(h|0)<0|0?-1:0,0)|0;h=DD(b)|0;c[a+384>>2]=h;c[a+380>>2]=(h|0)==0?0:1764;h=DD(b)|0;c[a+392>>2]=h;c[a+388>>2]=(h|0)==0?0:768;h=zD(b)|0;c[f>>2]=h;c[f+4>>2]=zD(b)|0;c[f+8>>2]=zD(b)|0;c[f+12>>2]=zD(b)|0;j=DD(b)|0;c[e>>2]=j;c[e+4>>2]=DD(b)|0;c[e+8>>2]=DD(b)|0;c[e+12>>2]=DD(b)|0;k=1;l=j;while(1){if((l|0)!=0){j=k;while(1){m=c[e+(j<<2)>>2]|0;if((j|0)>=3){break}if((m|0)==0){j=j+1|0}else{break}}j=c[f+(k<<2)>>2]|0;n=m-l|0;if((j|0)>29){o=-1094995529;p=15;break}q=a+16+(j*12|0)|0;if(((c[q>>2]|0)+n|0)>(c[a+16+(j*12|0)+4>>2]|0)|(n|0)<1){o=-1094995529;p=15;break}fD(b,(c[g>>2]|0)+l|0,0,0)|0;if((AD(b,(c[a+16+(j*12|0)+8>>2]|0)+(c[q>>2]|0)|0,n)|0)!=(n|0)){o=-5;p=15;break}c[q>>2]=(c[q>>2]|0)+n}if((k|0)>=3){p=11;break}n=c[e+(k<<2)>>2]|0;k=k+1|0;l=n}if((p|0)==11){if((h|0)==255){c[a+396>>2]=0;c[a+400>>2]=0;o=0;i=d;return o|0}if(h>>>0>29>>>0){o=-1094995529;i=d;return o|0}l=a+16+(h*12|0)|0;c[a+396>>2]=c[l>>2];c[a+400>>2]=c[a+16+(h*12|0)+8>>2];c[l>>2]=0;o=0;i=d;return o|0}else if((p|0)==15){i=d;return o|0}return 0}function KW(b){b=b|0;var e=0,f=0,g=0,h=0;e=c[b+4>>2]|0;b=e;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)!=1447120212){f=0;return f|0}b=e+4|0;if(!(((d[b]|d[b+1|0]<<8)<<16>>16&65535)>>>0>4999>>>0)){f=0;return f|0}b=e+6|0;if(!(((d[b]|d[b+1|0]<<8)<<16>>16&65535)>>>0>40>>>0)){f=0;return f|0}if((a[e+8|0]|0)!=0){f=0;return f|0}b=a[e+9|0]|0;if(b<<24>>24==0){f=0;return f|0}g=a[e+10|0]|0;if(g<<24>>24==0){f=0;return f|0}if(b<<24>>24==40){h=g<<24>>24==25?1:4}else{h=4}f=100/(h>>>0)|0;return f|0}function LW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+8|0;d=b|0;e=c[a+12>>2]|0;f=c[a+16>>2]|0;if((FD(f)|0)!=1447120212){g=-1;i=b;return g|0}h=ZX(a,0)|0;if((h|0)==0){g=-12;i=b;return g|0}j=ZX(a,0)|0;if((j|0)==0){g=-12;i=b;return g|0}k=DD(f)|0;l=j+8|0;c[(c[l>>2]|0)+412>>2]=k;if((k|0)==0){KIb(a,16,2461968,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;g=-1;i=b;return g|0}k=DD(f)|0;n=e;c[n>>2]=k;if((k|0)==0){KIb(a,16,2370888,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;g=-1;i=b;return g|0}k=zD(f)|0;if((k|0)!=0){KIb(a,16,2304536,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;g=-1;i=b;return g|0}k=zD(f)|0;o=zD(f)|0;p=e+4|0;c[p>>2]=ca(k<<1,o)|0;q=zD(f)|0;f=q&-4;if((f|0)!=0){KIb(a,16,2252816,(m=i,i=i+8|0,c[m>>2]=f,m)|0);i=m;g=-1;i=b;return g|0}m=c[l>>2]|0;c[m+8>>2]=1;c[m+48>>2]=65541;f=m+416|0;if((q&2|0)==0){c[f>>2]=1;a=m+448|0;c[a>>2]=4;c[a+4>>2]=0}else{c[f>>2]=2;f=m+448|0;c[f>>2]=3;c[f+4>>2]=0}c[m+792>>2]=8;f=c[m+412>>2]|0;c[m+72>>2]=f<<3;_X(j,32,1,f);f=c[l>>2]|0;l=ca(c[f+416>>2]|0,c[f+412>>2]|0)|0;f=d|0;c[f>>2]=l;j=c[n>>2]|0;m=d+4|0;c[m>>2]=j;xKb(f,m,l,(l|0)<0|0?-1:0,j,(j|0)<0|0?-1:0,-1,0)|0;j=h+8|0;l=c[j>>2]|0;c[l+8>>2]=0;c[l+48>>2]=127;c[l+140>>2]=11;c[l+120>>2]=k<<3;c[l+124>>2]=o<<3;_X(h,32,c[m>>2]|0,c[f>>2]|0);h=c[p>>2]|0;if((q&1|0)==0){r=c[e+8>>2]|0}else{q=(c[n>>2]|0)+h|0;n=(q+511&-512)-q|0;c[e+8>>2]=n;r=n}n=ca(c[f>>2]<<3,r+h|0)|0;c[(c[j>>2]|0)+72>>2]=(n>>>0)/((c[m>>2]|0)>>>0)|0;g=0;i=b;return g|0}function MW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;a=d+12|0;f=c[((c[a>>2]|0)==0?d+4|0:d)>>2]|0;if((jD(e)|0)!=0){g=-541478725;return g|0}h=fX(e,b,f)|0;if((c[a>>2]|0)==0){i=0}else{hD(e,c[d+8>>2]|0,0)|0;i=c[a>>2]|0}c[b+32>>2]=i;c[a>>2]=c[a>>2]^1;a=b+36|0;c[a>>2]=c[a>>2]|1;g=h;return g|0}function NW(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;f=c[a+12>>2]|0;if((b|0)!=0){g=-1;return g|0}b=Erc((c[f+4>>2]|0)+(c[f>>2]|0)+(c[f+8>>2]|0)|0,0,d,e)|0;e=c[a+16>>2]|0;a=wrc(b,G,12,0)|0;b=fD(e,a,G,0)|0;a=G;e=0;if((a|0)<(e|0)|(a|0)==(e|0)&b>>>0<0>>>0){g=-1;return g|0}c[f+12>>2]=0;g=0;return g|0}function OW(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==826365012){e=b+4|0;if(!((((d[e]|d[e+1|0]<<8)<<16>>16)-1&65535)>>>0<2>>>0)){break}e=b+6|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}e=b+8|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}e=b+10|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==0){break}else{f=80}return f|0}}while(0);f=0;return f|0}function PW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;d=c[a+12>>2]|0;A$(a);e=a+16|0;f=fD(c[e>>2]|0,0,0,1)|0;g=G;yD(c[e>>2]|0,278,-1);if((FD(c[e>>2]|0)|0)!=826365012){h=-1094995529;i=b;return h|0}hD(c[e>>2]|0,2,0)|0;j=DD(c[e>>2]|0)|0;k=DD(c[e>>2]|0)|0;l=FD(c[e>>2]|0)|0;if((l-1|0)>>>0>999999>>>0){KIb(a,16,2370864,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}n=FD(c[e>>2]|0)|0;if((n|0)==0){KIb(a,16,2304504,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}o=~(xD(c[e>>2]|0)|0);if((FD(c[e>>2]|0)|0)!=(o|0)){KIb(a,16,2252792,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}o=(l<<8|0)/245|0;p=d+8|0;c[p>>2]=o;q=(n>>>0)%(o>>>0)|0;r=(q|0)==0?o:q;c[d+12>>2]=r;q=((r|0)<(o|0))+((n>>>0)/(o>>>0)|0)|0;o=d;c[o>>2]=q;c[d+4>>2]=0;if(q>>>0>1073741822>>>0|(q|0)<1){KIb(a,16,2209880,(m=i,i=i+8|0,c[m>>2]=q,m)|0);i=m;h=-1094995529;i=b;return h|0}q=ZX(a,0)|0;if((q|0)==0){h=-12;i=b;return h|0}_X(q,64,1,l);d=q+48|0;c[d>>2]=0;c[d+4>>2]=0;d=q+56|0;c[d>>2]=n;c[d+4>>2]=0;d=fD(c[e>>2]|0,0,0,1)|0;n=G;r=c[o>>2]|0;s=q+8|0;t=c[s>>2]|0;u=fD(c[e>>2]|0,0,0,1)|0;v=xrc(u,G,f,g)|0;if((PX(t,v)|0)!=0){h=-12;i=b;return h|0}fD(c[e>>2]|0,f,g,0)|0;g=c[s>>2]|0;AD(c[e>>2]|0,c[g+96>>2]|0,c[g+100>>2]|0)|0;yD(c[e>>2]|0,278,-1);g=c[e>>2]|0;if((c[o>>2]|0)>0){f=r<<2;r=wrc(d,n,4,0)|0;n=wrc(r,G,f,(f|0)<0|0?-1:0)|0;f=G;r=n;n=0;d=g;while(1){v=FD(d)|0;t=ca(c[p>>2]|0,n)|0;xX(q,r,f,t,(t|0)<0|0?-1:0,v,0,1)|0;t=wrc(v,0,r,f)|0;v=n+1|0;u=c[e>>2]|0;if((v|0)<(c[o>>2]|0)){f=G;r=t;n=v;d=u}else{w=u;break}}}else{w=g}g=~(xD(w)|0);if((FD(c[e>>2]|0)|0)!=(g|0)){KIb(a,16,2177176,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}m=c[s>>2]|0;c[m+8>>2]=1;c[m+48>>2]=86038;c[m+416>>2]=j;c[m+412>>2]=l;c[m+792>>2]=k;k=c[e>>2]|0;if((c[k+88>>2]|0)==0){h=0;i=b;return h|0}m=fD(k,0,0,1)|0;k=G;HB(a)|0;fD(c[e>>2]|0,m,k,0)|0;h=0;i=b;return h|0}function QW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[a+12>>2]|0;e=d+4|0;f=c[e>>2]|0;g=d;if((f|0)>=(c[g>>2]|0)){h=-541478725;return h|0}i=(c[c[a+28>>2]>>2]|0)+400|0;j=fX(c[a+16>>2]|0,b,c[(c[i>>2]|0)+(f*24|0)+16>>2]>>2)|0;f=c[e>>2]|0;a=f+1|0;c[e>>2]=a;e=(c[i>>2]|0)+(f*24|0)+8|0;f=c[e+4>>2]|0;i=b+16|0;c[i>>2]=c[e>>2];c[i+4>>2]=f;c[b+48>>2]=c[((a|0)==(c[g>>2]|0)?d+12|0:d+8|0)>>2];h=j;return h|0}function RW(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[a+12>>2]|0;h=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=CX(h,d,e,f)|0;if((b|0)<0){i=-1;return i|0}f=(c[h+400>>2]|0)+(b*24|0)|0;h=fD(c[a+16>>2]|0,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=G;a=0;if((f|0)<(a|0)|(f|0)==(a|0)&h>>>0<0>>>0){i=-1;return i|0}c[g+4>>2]=b;i=0;return i|0}function SW(a,b,c){a=a|0;b=b|0;c=c|0;return EGb(DGb(4)|0,a,b,c)|0}function TW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0;d=i;i=i+40|0;e=d|0;f=b+12|0;g=c[f>>2]|0;h=ZX(b,0)|0;if((h|0)==0){j=-12;i=d;return j|0}k=c[h+8>>2]|0;c[k+52>>2]=0;c[k+8>>2]=0;c[k+48>>2]=143;c[k+120>>2]=c[g+16>>2];c[k+124>>2]=c[g+20>>2];k=g+24|0;_X(h,60,c[g+28>>2]|0,c[k>>2]|0);l=k;k=h+92|0;m=c[l+4>>2]|0;c[k>>2]=c[l>>2];c[k+4>>2]=m;m=g+4|0;n=+(c[h+40>>2]|0)/+(c[h+44>>2]|0)*+(c[m>>2]|0);if(n>1.0){o=~~n}else{o=1}c[m>>2]=o;o=b+16|0;k=c[o>>2]|0;if((c[k+88>>2]|0)==0){j=0;i=d;return j|0}l=iD(k)|0;k=G;p=g+8|0;c[p>>2]=l;c[p+4>>2]=k;g=c[m>>2]|0;m=g;q=(g|0)<0|0?-1:0;g=wrc(l,k,-1,-1)|0;k=wrc(g,G,m,q)|0;g=Frc(k,G,m,q)|0;q=h+56|0;c[q>>2]=g;c[q+4>>2]=G;do{if((aU(b,p,0,0)|0)<0){q=wrc(c[p>>2]|0,c[p+4>>2]|0,-51,-1)|0;g=G;h=e|0;m=c[f>>2]|0;k=c[o>>2]|0;fD(k,q,g,0)|0;if((zD(k)|0)!=26){break}l=zD(k)|0;if((l-1|0)>>>0>11>>>0){break}if((AD(k,h,12)|0)==12){a[e+l|0]=0;MGb(b+1140|0,2370848,h,0)|0}l=zD(k)|0;if((l-1|0)>>>0>35>>>0){break}if((AD(k,h,36)|0)==36){a[e+l|0]=0;MGb(b+1140|0,2304496,h,0)|0}h=m+8|0;c[h>>2]=q;c[h+4>>2]=g}}while(0);fD(c[o>>2]|0,0,0,0)|0;j=0;i=d;return j|0}function UW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[a+12>>2]|0;e=a+16|0;if((jD(c[e>>2]|0)|0)!=0){f=-541478725;return f|0}a=d+4|0;g=c[a>>2]|0;h=d+8|0;do{if((c[h>>2]|0)==0&(c[h+4>>2]|0)==0){i=g}else{d=fD(c[e>>2]|0,0,0,1)|0;j=G;k=c[h>>2]|0;l=c[h+4>>2]|0;if((d|0)==(k|0)&(j|0)==(l|0)){f=-541478725;return f|0}m=c[a>>2]|0;n=wrc(m,(m|0)<0|0?-1:0,d,j)|0;m=G;if(!(m>>>0>l>>>0|m>>>0==l>>>0&n>>>0>k>>>0)){i=g;break}n=xrc(k,l,d,j)|0;i=n}}while(0);g=fX(c[e>>2]|0,b,i)|0;c[b+28>>2]=g;if((g|0)<0){f=g;return f|0}g=b+36|0;c[g>>2]=c[g>>2]|1;f=0;return f|0}function VW(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==22){e=b+8|0;f=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if((f|0)==402915327|(f|0)==268697599){g=100}else{break}return g|0}}while(0);g=0;return g|0}function WW(a){a=a|0;var b=0,d=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=106;c[a+108>>2]=5;c[a+104>>2]=1;d=0;return d|0}function XW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=a+16|0;f=c[e>>2]|0;g=FD(f)|0;h=FD(f)|0;j=FD(f)|0;if((jD(c[e>>2]|0)|0)==0){k=g;l=h;m=j}else{n=-541478725;i=d;return n|0}while(1){if(!((m|0)==402915327|(m|0)==268697599)){o=3;break}if((k|0)==3){o=6}else if((k|0)==1){if(l>>>0>100>>>0){o=9;break}else{o=6}}else if(!((k|0)==22|(k|0)==21)){o=8;break}if((o|0)==6){o=0;hD(c[e>>2]|0,l,0)|0;}j=FD(f)|0;h=FD(f)|0;g=FD(f)|0;if((jD(c[e>>2]|0)|0)==0){k=j;l=h;m=g}else{n=-541478725;o=11;break}}if((o|0)==3){KIb(a,16,2461912,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=-1094995529;i=d;return n|0}else if((o|0)==8){KIb(a,16,2370824,(p=i,i=i+8|0,c[p>>2]=k,p)|0);i=p;n=-1094995529;i=d;return n|0}else if((o|0)==9){p=fX(c[e>>2]|0,b,l)|0;if((p|0)<0){n=p;i=d;return n|0}c[b+32>>2]=0;n=0;i=d;return n|0}else if((o|0)==11){i=d;return n|0}return 0}function YW(a,b){a=a|0;b=b|0;return-38|0}function ZW(a,e,f,j){a=a|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=i;i=i+1048|0;l=k|0;m=k+24|0;if((j&1|0)!=0){n=0;i=k;return n|0}SFb(m,0,-1);j=(c[f>>2]|0)+136|0;o=c[j>>2]|0;p=c[j+4>>2]|0;UFb(m,2461896,(j=i,i=i+24|0,c[j>>2]=e,c[j+8>>2]=o,c[j+16>>2]=p,j)|0);i=j;p=c[(c[(c[(c[a+28>>2]|0)+(e<<2)>>2]|0)+8>>2]|0)+8>>2]|0;e=ALb(p)|0;UFb(m,2370816,(j=i,i=i+8|0,c[j>>2]=(e|0)!=0?e:2304488,j)|0);i=j;a:do{if((p|0)==0){e=c[f>>2]|0;o=e+80|0;q=qKb(c[o>>2]|0)|0;mrc(l|0,0,20)|0;r=e+68|0;s=e+72|0;t=c[s>>2]|0;UFb(m,2643272,(j=i,i=i+16|0,c[j>>2]=c[r>>2],c[j+8>>2]=t,j)|0);i=j;if((q|0)==0){UFb(m,2620056,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;break}t=l|0;if((pIb(t,c[o>>2]|0,c[r>>2]|0)|0)<0){break}UFb(m,2370816,(j=i,i=i+8|0,c[j>>2]=c[q>>2],j)|0);i=j;r=c[t>>2]|0;if((r|0)==0){break}t=q+4|0;o=q+6|0;q=0;u=r;do{r=c[s>>2]|0;do{if((q-1|0)>>>0<2>>>0){if(!((d[t]|0)>>>0>2>>>0)){v=r;break}v=-(-r>>d[o])|0}else{v=r}}while(0);if((v|0)>0){r=c[e+32+(q<<2)>>2]|0;w=0;x=c[e+(q<<2)>>2]|0;y=0;while(1){z=oFb(y,x,u)|0;A=w+1|0;if((A|0)<(v|0)){w=A;x=x+r|0;y=z}else{B=z;break}}}else{B=0}UFb(m,2125152,(j=i,i=i+8|0,c[j>>2]=B,j)|0);i=j;q=q+1|0;u=c[l+(q<<2)>>2]|0;}while((u|0)!=0)}else if((p|0)==1){u=c[f>>2]|0;q=GHb(u)|0;e=u+76|0;o=c[e>>2]|0;t=u+80|0;if((RKb(c[t>>2]|0)|0)==0){C=1;D=ca(o,q)|0}else{C=q;D=o}o=LKb(c[t>>2]|0)|0;UFb(m,2252760,(j=i,i=i+8|0,c[j>>2]=c[e>>2],j)|0);i=j;UFb(m,2370816,(j=i,i=i+8|0,c[j>>2]=(o|0)!=0?o:2304488,j)|0);i=j;if((C|0)<=0){break}o=u+64|0;if((D|0)==0){u=0;while(1){if(!((c[t>>2]|0)>>>0<10>>>0)){break}UFb(m,2125152,(j=i,i=i+8|0,c[j>>2]=0,j)|0);i=j;u=u+1|0;if((u|0)>=(C|0)){break a}}KIb(0,0,2209832,(j=i,i=i+24|0,c[j>>2]=2177160,c[j+8>>2]=2149024,c[j+16>>2]=116,j)|0);i=j;Hd();return 0}else{E=0}b:while(1){u=c[(c[o>>2]|0)+(E<<2)>>2]|0;switch(c[t>>2]|0){case 4:case 9:{e=D;q=u;s=0;y=0;while(1){F=((~~(+h[q>>3]*2147483648.0+2147483648.0)+s|0)>>>0)%65521|0;G=((F+y|0)>>>0)%65521|0;r=e-1|0;if((r|0)==0){break}else{e=r;q=q+8|0;s=F;y=G}}H=G<<16|F;break};case 3:case 8:{y=D;s=u;q=0;e=0;while(1){I=((~~(+g[s>>2]*2147483648.0+2147483648.0)+q|0)>>>0)%65521|0;J=((I+e|0)>>>0)%65521|0;r=y-1|0;if((r|0)==0){break}else{y=r;s=s+4|0;q=I;e=J}}H=J<<16|I;break};case 0:case 5:{e=D;q=u;s=0;y=0;while(1){K=(((d[q]|0)+s|0)>>>0)%65521|0;L=((K+y|0)>>>0)%65521|0;r=e-1|0;if((r|0)==0){break}else{e=r;q=q+1|0;s=K;y=L}}H=L<<16|K;break};case 1:case 6:{y=D;s=u;q=0;e=0;while(1){M=((q+32768+(b[s>>1]|0)|0)>>>0)%65521|0;N=((M+e|0)>>>0)%65521|0;r=y-1|0;if((r|0)==0){break}else{y=r;s=s+2|0;q=M;e=N}}H=N<<16|M;break};case 2:case 7:{e=D;q=u;s=0;y=0;while(1){O=(((c[q>>2]^-2147483648)+s|0)>>>0)%65521|0;P=((O+y|0)>>>0)%65521|0;r=e-1|0;if((r|0)==0){break}else{e=r;q=q+4|0;s=O;y=P}}H=P<<16|O;break};default:{break b}}UFb(m,2125152,(j=i,i=i+8|0,c[j>>2]=H,j)|0);i=j;E=E+1|0;if((E|0)>=(C|0)){break a}}KIb(0,0,2209832,(j=i,i=i+24|0,c[j>>2]=2177160,c[j+8>>2]=2149024,c[j+16>>2]=116,j)|0);i=j;Hd();return 0}}while(0);WFb(m,10,1);j=c[m+4>>2]|0;if(j>>>0<(c[m+8>>2]|0)>>>0){dD(c[a+16>>2]|0,c[m>>2]|0,j);Q=0}else{Q=-12}_Fb(m,0)|0;n=Q;i=k;return n|0}function _W(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((d|0)!=0){do{if((Db(d|0,2370808)|0)!=0){if((a[e]|0)!=47){break}if((d|0)!=(b|0)){CFb(b,d,c)|0}f=Db(b|0,2370808)|0;do{if((f|0)!=0){if((a[e+1|0]|0)==47){a[f+1|0]=0;break}g=_b(f+3|0,47)|0;if((g|0)==0){break}a[g]=0}}while(0);DFb(b,e,c)|0;return}}while(0);if((Db(e|0,2370808)|0)!=0){break}if((a[e]|0)==47){break}if((d|0)!=(b|0)){CFb(b,d,c)|0}f=_b(b|0,63)|0;if((f|0)!=0){a[f]=0}if((a[e]|0)==63){DFb(b,e,c)|0;return}f=hc(b|0,47)|0;if((f|0)==0){a[b]=0;h=0}else{a[f+1|0]=0;h=f}a:do{if((AFb(e,2304480,0)|0)==0|(h|0)==0){i=e}else{f=h;g=e;while(1){a[f]=0;j=hc(b|0,47)|0;k=(j|0)!=0;l=j+1|0;if((irc(k?l:b,2252752)|0)==0){break}if(k){a[l]=0}else{a[b]=0}l=g+3|0;if((AFb(l,2304480,0)|0)==0|(j|0)==0){i=l;break a}else{f=j;g=l}}DFb(b,2209824,c)|0;i=g}}while(0);DFb(b,i,c)|0;return}}while(0);CFb(b,e,c)|0;return}function $W(){return 3613028}function aX(){return 2631032}function bX(a,b){a=a|0;b=b|0;c[a+1304>>2]=b;return}function cX(a,b){a=a|0;b=b|0;c[a+1308>>2]=b;return}function dX(a,b){a=a|0;b=b|0;c[a+1312>>2]=b;return}function eX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=a+96|0;f=c[e>>2]|0;g=c[e+4>>2]|0;h=-1;if(!((g|0)>(h|0)|(g|0)==(h|0)&f>>>0>-1>>>0)){j=b;i=d;return j|0}h=fD(a,0,0,1)|0;k=xrc(f,g,h,G)|0;h=G;g=b;f=(b|0)<0|0?-1:0;if((h|0)<(f|0)|(h|0)==(f|0)&k>>>0<g>>>0){l=iD(a)|0;m=G;n=c[e>>2]|0;o=c[e+4>>2]|0;if((n|0)==0&(o|0)==0|((o|0)<(m|0)|(o|0)==(m|0)&n>>>0<l>>>0)){p=xrc(l,m,(l|0)==0&(m|0)==0&1,0)|0;m=G;c[e>>2]=p;c[e+4>>2]=m;q=m;r=p}else{q=o;r=n}n=fD(a,0,0,1)|0;a=xrc(r,q,n,G)|0;n=G;q=0;r=(n|0)>(q|0)|(n|0)==(q|0)&a>>>0>0>>>0;s=r?n:0;t=r?a:0}else{s=h;t=k}k=c[e+4>>2]|0;h=-1;if(!((k|0)>(h|0)|(k|0)==(h|0)&(c[e>>2]|0)>>>0>-1>>>0)){j=b;i=d;return j|0}e=wrc(t,s,1,0)|0;h=G;if(!((h|0)<(f|0)|(h|0)==(f|0)&e>>>0<g>>>0)){j=b;i=d;return j|0}KIb(0,(t|0)!=0|(s|0)!=0?16:48,2461856,(s=i,i=i+24|0,c[s>>2]=b,c[s+8>>2]=e,c[s+16>>2]=h,s)|0);i=s;j=e;i=d;return j|0}function fX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;J1(b);c[b+24>>2]=0;c[b+28>>2]=0;e=fD(a,0,0,1)|0;f=b+64|0;c[f>>2]=e;c[f+4>>2]=G;return gX(a,b,d)|0}function gX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=b+64|0;f=c[e>>2]|0;g=c[e+4>>2]|0;h=b+28|0;i=c[h>>2]|0;j=a+96|0;k=b+24|0;l=d;d=i;while(1){do{if((l|0)>5e6){m=eX(a,l)|0;n=c[j+4>>2]|0;o=0;if(!((n|0)<(o|0)|(n|0)==(o|0)&(c[j>>2]|0)>>>0<0>>>0)){p=m;break}p=(m|0)>5e7?5e7:m}else{p=l}}while(0);m=N1(b,p)|0;if((m|0)<0){q=m;r=10;break}s=AD(a,(c[k>>2]|0)+d|0,p)|0;if((s|0)!=(p|0)){r=7;break}m=l-p|0;if((m|0)<=0){t=p;break}l=m;d=c[h>>2]|0}if((r|0)==7){M1(b,((s|0)>0?s:0)+d|0);q=s;r=10}do{if((r|0)==10){if((l|0)<=0){t=q;break}s=b+36|0;c[s>>2]=c[s>>2]|2;t=q}}while(0);c[e>>2]=f;c[e+4>>2]=g;g=c[h>>2]|0;if((g|0)!=0){u=g;v=(u|0)>(i|0);w=u-i|0;x=v?w:t;return x|0}P1(b);u=c[h>>2]|0;v=(u|0)>(i|0);w=u-i|0;x=v?w:t;return x|0}function hX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=b+28|0;if((c[e>>2]|0)==0){J1(b);c[b+24>>2]=0;c[e>>2]=0;e=fD(a,0,0,1)|0;f=b+64|0;c[f>>2]=e;c[f+4>>2]=G;g=gX(a,b,d)|0;return g|0}else{g=gX(a,b,d)|0;return g|0}return 0}function iX(a){a=a|0;var b=0,c=0;b=i;i=i+1024|0;if((a|0)==0){c=0;i=b;return c|0}c=(jX(b|0,1024,a,1)|0)>>>31^1;i=b;return c|0}function jX(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+24|0;h=b;j=d-1|0;d=g|0;k=0;l=b;b=e;a:while(1){m=l;e=b;while(1){n=m-h|0;if((n|0)>=(j|0)){o=e;p=9;break}q=e+1|0;r=a[e]|0;if((r<<24>>24|0)==37){s=0;t=q;while(1){if((MFb(a[t]|0)|0)==0){u=t+1|0;v=a[t]|0;w=v<<24>>24;if((MFb(w)|0)==0){break}else{s=0;t=u;continue}}else{s=(s*10|0)-48+(a[t]|0)|0;t=t+1|0;continue}}if((w|0)==100){x=u;y=s;break}else if((w|0)==37){z=u;A=v}else{break a}}else if((r<<24>>24|0)==0){p=18;break a}else{z=q;A=r}a[m]=A;m=m+1|0;e=z}if((p|0)==9){while(1){p=0;e=o+1|0;t=a[o]|0;if((t<<24>>24|0)==37){B=0;C=e}else if((t<<24>>24|0)==0){p=18;break a}else{o=e;p=9;continue}while(1){if((MFb(a[C]|0)|0)==0){D=C+1|0;E=a[C]|0;if((MFb(E)|0)==0){break}else{B=0;C=D;continue}}else{B=(B*10|0)-48+(a[C]|0)|0;C=C+1|0;continue}}if((E|0)==100){x=D;y=B;break}else if((E|0)==37){o=D;p=9}else{break a}}}if((k|0)!=0){break}Rb(d|0,20,2185640,(r=i,i=i+16|0,c[r>>2]=y,c[r+8>>2]=f,r)|0)|0;i=r;r=lrc(d|0)|0;if((n+r|0)>(j|0)){break}nrc(m|0,d|0,r)|0;k=1;l=m+r|0;b=x}do{if((p|0)==18){if((k|0)==0){break}else{F=0}a[m]=0;i=g;return F|0}}while(0);F=-1;a[m]=0;i=g;return F|0}function kX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+16|0;f=e|0;g=f;h=a;c[g>>2]=c[h>>2];c[g+4>>2]=c[h+4>>2];c[g+8>>2]=c[h+8>>2];h=f+4|0;g=c[h>>2]|0;if((g|0)==0){c[h>>2]=9907040;j=9907040}else{j=g}g=f+8|0;do{if((c[g>>2]|0)>10){if((JI(j,2370800)|0)==0){k=0;break}a=KI(c[h>>2]|0)|0;l=c[g>>2]|0;if((l|0)<=(a+16|0)){k=1;break}c[h>>2]=(c[h>>2]|0)+a;c[g>>2]=l-a;k=0}else{k=0}}while(0);g=(b|0)==0|0;b=f|0;h=(k|0)!=0?24:1;j=0;a=0;a:while(1){l=a;m=a;while(1){n=l;do{n=bH(n)|0;if((n|0)==0){break a}}while((g|0)==(c[n+8>>2]&1^1|0));o=c[n+36>>2]|0;do{if((o|0)==0){p=c[n+12>>2]|0;if((p|0)==0){q=0;break}r=(fH(c[b>>2]|0,p)|0)==0;q=r?0:50}else{r=ve[o&4095](f)|0;p=c[n+12>>2]|0;if((p|0)==0){q=r;break}if((fH(c[b>>2]|0,p)|0)==0){q=r;break}q=(r|0)>(h|0)?r:h}}while(0);if((q|0)>(j|0)){j=q;a=n;continue a}l=n;m=(q|0)==(j|0)?0:m}}if((k|0)==0){s=j;c[d>>2]=s;i=e;return m|0}s=(j|0)<24?j:24;c[d>>2]=s;i=e;return m|0}function lX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=kX(a,b,f)|0;b=c[f>>2]|0;if((b|0)<=(c[d>>2]|0)){h=0;i=e;return h|0}c[d>>2]=b;h=g;i=e;return h|0}function mX(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;i=i+40|0;j=h|0;k=h+8|0;l=h+24|0;m=h+32|0;c[k>>2]=(d|0)!=0?d:10230264;d=k+4|0;c[d>>2]=0;n=k+8|0;c[n>>2]=0;c[l>>2]=0;do{if((g|0)==0|g>>>0>1048576>>>0){o=1048576}else{if(!(g>>>0<2048>>>0)){o=g;break}KIb(e,16,2252704,(p=i,i=i+16|0,c[p>>2]=g,c[p+8>>2]=2048,p)|0);i=p;q=-22;i=h;return q|0}}while(0);if(!(o>>>0>f>>>0)){q=-22;i=h;return q|0}do{if((c[b>>2]|0)==0){if((c[a>>2]|0)==0){break}g=(MJb(a,2209808,1,m)|0)>-1;r=c[m>>2]|0;if(!(g&(r|0)!=0)){break}if((IFb(r,2177136)|0)==0){c[b>>2]=iH(2149016)|0}mJb(m)}}while(0);m=(c[b>>2]|0)==0;a:do{if(o>>>0<2048>>>0){s=0;t=0;u=m;v=26}else{r=l;g=0;w=2048;x=0;y=m;while(1){if(!y){z=g;A=x;break a}B=lJb(r,w+32|0)|0;if((B|0)<0){q=B;v=29;break}B=w>>>0<o>>>0?25:0;C=AD(a,(c[l>>2]|0)+x|0,w-x|0)|0;if((C|0)<0){if((C|0)==-541478725){D=0;E=0}else{break}}else{D=C;E=B}B=D+x|0;do{if(B>>>0<f>>>0){F=E}else{c[n>>2]=B-f;G=c[l>>2]|0;c[d>>2]=G+f;mrc(G+B|0,0,32)|0;G=kX(k,1,j)|0;H=c[j>>2]|0;if((H|0)<=(E|0)){c[b>>2]=0;F=E;break}c[b>>2]=G;if((G|0)==0){F=H;break}I=c[G>>2]|0;if((H|0)<26){KIb(e,24,2125080,(p=i,i=i+16|0,c[p>>2]=I,c[p+8>>2]=H,p)|0);i=p;F=H;break}else{KIb(e,48,2643224,(p=i,i=i+24|0,c[p>>2]=I,c[p+8>>2]=w,c[p+16>>2]=H,p)|0);i=p;F=H;break}}}while(0);H=w<<1;I=w+1|0;G=o>>>0>I>>>0?o:I;I=H>>>0>G>>>0?G:H;H=(c[b>>2]|0)==0;if(I>>>0>o>>>0){s=F;t=B;u=H;v=26;break a}else{g=F;w=I;x=B;y=H}}if((v|0)==29){i=h;return q|0}kJb(c[l>>2]|0);q=C;i=h;return q|0}}while(0);do{if((v|0)==26){if(!u){z=s;A=t;break}kJb(c[l>>2]|0);q=-1094995529;i=h;return q|0}}while(0);t=TD(a,l,A)|0;q=(t|0)<0?t:z;i=h;return q|0}function nX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=mX(a,b,c,d,e,f)|0;return((g|0)<0?g:0)|0}function oX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;f=i;i=i+1144|0;g=f|0;h=f+80|0;j=f+1104|0;k=f+1112|0;l=f+1128|0;m=f+1136|0;n=c[a>>2]|0;c[l>>2]=0;c[m>>2]=0;do{if((n|0)==0){o=HR()|0;if((o|0)==0){p=-12}else{q=o;break}i=f;return p|0}else{q=n}}while(0);if((c[q>>2]|0)==0){KIb(0,16,2619952,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=-22;i=f;return p|0}if((d|0)!=0){c[q+4>>2]=d}d=(e|0)!=0;if(d){PGb(l,c[e>>2]|0,0)}n=q;o=XJb(n,l)|0;a:do{if((o|0)<0){s=o;t=q+16|0}else{c[k>>2]=b;c[k+4>>2]=0;c[k+8>>2]=0;u=q+16|0;v=c[u>>2]|0;b:do{if((v|0)==0){w=q+4|0;x=c[w>>2]|0;do{if((x|0)==0){y=kX(k,0,j)|0;z=c[j>>2]|0;if((z|0)>25){c[w>>2]=y;if((y|0)==0){break}else{A=z;B=w;break b}}else{c[w>>2]=0;break}}else{if((c[x+8>>2]&1|0)!=0){A=25;B=w;break b}}}while(0);x=VD(u,b,c[q+1208>>2]|1,q+1160|0,l)|0;if((x|0)<0){s=x;t=u;break a}if((c[w>>2]|0)!=0){A=0;B=w;break}C=mX(c[u>>2]|0,w,b,n,0,c[q+1088>>2]|0)|0;D=24}else{x=q+1084|0;c[x>>2]=c[x>>2]|128;x=q+4|0;z=c[x>>2]|0;if((z|0)==0){C=mX(v,x,b,n,0,c[q+1088>>2]|0)|0;D=24;break}if((c[z+8>>2]&1|0)==0){A=0;B=x;break}KIb(n,24,2518096,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;A=0;B=x}}while(0);if((D|0)==24){if((C|0)<0){s=C;t=u;break}A=C;B=q+4|0}c[q+1232>>2]=A;hD(c[u>>2]|0,c[q+1216>>2]|0,0)|0;if((c[(c[B>>2]|0)+8>>2]&2|0)!=0){if((b|0)==0){s=-22;t=u;break}if((jX(h|0,1024,b,1)|0)<0){s=-22;t=u;break}}v=q+1056|0;c[v>>2]=0;c[v+4>>2]=-2147483648;v=q+1064|0;c[v>>2]=0;c[v+4>>2]=-2147483648;CFb(q+32|0,(b|0)!=0?b:10230264,1024)|0;v=c[(c[B>>2]|0)+32>>2]|0;do{if((v|0)>0){x=pJb(v)|0;z=q+12|0;c[z>>2]=x;if((x|0)==0){s=-12;t=u;break a}y=c[(c[B>>2]|0)+20>>2]|0;if((y|0)==0){break}c[x>>2]=y;SJb(c[z>>2]|0);y=XJb(c[z>>2]|0,l)|0;if((y|0)<0){s=y;t=u;break a}}}while(0);if((c[u>>2]|0)!=0){MI(q,2370800,m)}v=q+1084|0;do{if((c[v>>2]&131072|0)==0){y=c[(c[B>>2]|0)+40>>2]|0;if((y|0)==0){break}z=ve[y&4095](q)|0;if((z|0)<0){s=z;t=u;break a}}}while(0);c:do{if((c[m>>2]|0)!=0){z=c[c[B>>2]>>2]|0;do{if((irc(z,2592656)|0)!=0){if((irc(z,2149016)|0)==0){break}if((irc(z,2569944)|0)==0){break}KIb(n,48,2552024,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break c}}while(0);z=PI(q,m)|0;if((z|0)<0){s=z;t=u;break a}}}while(0);NI(m);z=g|0;w=q+24|0;if((c[w>>2]|0)!=0){y=q+28|0;x=q+1256|0;E=q+1260|0;F=0;do{H=c[(c[y>>2]|0)+(F<<2)>>2]|0;do{if((c[H+72>>2]&1024|0)!=0){if((c[H+76>>2]|0)>=48){break}I=c[H+104>>2]|0;nrc(z|0,H+108|0,76)|0;J=eGb(I)|0;if((J|0)==0){s=-12;t=u;break a}I=pJb(88)|0;K=I;if((I|0)==0){break}if((c[x>>2]|0)==0){c[x>>2]=K}else{c[(c[E>>2]|0)+80>>2]=K}c[E>>2]=K;c[I>>2]=J;nrc(I+4|0,z|0,76)|0}}while(0);F=F+1|0;}while(F>>>0<(c[w>>2]|0)>>>0)}do{if((c[v>>2]&131072|0)==0){w=c[u>>2]|0;if((w|0)==0){break}F=q+1248|0;if(!((c[F>>2]|0)==0&(c[F+4>>2]|0)==0)){break}z=fD(w,0,0,1)|0;c[F>>2]=z;c[F+4>>2]=G}}while(0);c[q+1272>>2]=25e5;if(d){OGb(e);c[e>>2]=c[l>>2]}c[a>>2]=q;p=0;i=f;return p|0}}while(0);NI(m);OGb(l);l=c[t>>2]|0;do{if((l|0)!=0){if((c[q+1084>>2]&128|0)!=0){break}WD(l)|0}}while(0);pX(q);c[a>>2]=0;p=s;i=f;return p|0}function pX(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((a|0)==0){return}b=a;WJb(b);d=c[a+4>>2]|0;do{if((d|0)!=0){if((c[d+20>>2]|0)==0){break}e=c[a+12>>2]|0;if((e|0)==0){break}WJb(e)}}while(0);d=(c[a+24>>2]|0)-1|0;if((d|0)>-1){e=a+28|0;f=d;do{XX(a,c[(c[e>>2]|0)+(f<<2)>>2]|0);f=f-1|0;}while((f|0)>-1)}f=(c[a+1104>>2]|0)-1|0;e=a+1108|0;if((f|0)>-1){d=f;do{OGb((c[(c[e>>2]|0)+(d<<2)>>2]|0)+20|0);mJb((c[(c[e>>2]|0)+(d<<2)>>2]|0)+12|0);mJb((c[e>>2]|0)+(d<<2)|0);d=d-1|0;}while((d|0)>-1)}mJb(e);mJb(a+12|0);e=a+1132|0;d=c[e>>2]|0;f=d-1|0;c[e>>2]=f;g=a+1136|0;if((d|0)!=0){d=f;do{OGb((c[(c[g>>2]|0)+(d<<2)>>2]|0)+32|0);mJb((c[g>>2]|0)+(c[e>>2]<<2)|0);f=c[e>>2]|0;d=f-1|0;c[e>>2]=d;}while((f|0)!=0)}mJb(g);OGb(a+1140|0);mJb(a+28|0);mJb(a+1296|0);kJb(b);return}function qX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;d=i;i=i+8|0;e=d|0;f=a+1256|0;g=b;h=b+32|0;j=a+28|0;k=a+1272|0;l=b+24|0;m=b+28|0;n=a+4|0;o=a+24|0;p=a+1084|0;q=b+16|0;r=b+8|0;s=a+1220|0;t=a+1104|0;u=a+1108|0;v=a+1200|0;w=a+1260|0;x=e|0;y=e+4|0;z=a+1112|0;A=a+1116|0;B=a+1120|0;C=a;D=b+36|0;a:while(1){E=c[f>>2]|0;F=(E|0)!=0;if(F){H=E;nrc(g|0,H|0,80)|0;I=c[(c[j>>2]|0)+(c[h>>2]<<2)>>2]|0;if((c[k>>2]|0)<1){rX(a,I,0)}if((c[I+440>>2]|0)<1){J=6;break}}c[l>>2]=0;c[m>>2]=0;J1(b);I=We[c[(c[n>>2]|0)+44>>2]&2047](a,b)|0;if((I|0)<0){if((I|0)==-11|F^1){K=I;J=109;break}else{L=0}while(1){if(!(L>>>0<(c[o>>2]|0)>>>0)){continue a}M=c[(c[j>>2]|0)+(L<<2)>>2]|0;if((c[M+228>>2]|0)!=0){rX(a,M,0)}if((c[M+440>>2]|0)>=1){J=14;break a}L=L+1|0}}do{if((c[p>>2]&256|0)!=0){if((c[D>>2]&2|0)==0){break}KIb(C,24,2490760,(N=i,i=i+8|0,c[N>>2]=c[h>>2],N)|0);i=N;P1(b);continue a}}while(0);M=c[h>>2]|0;O=c[o>>2]|0;if(!(M>>>0<O>>>0)){KIb(C,16,2479896,(N=i,i=i+8|0,c[N>>2]=M,N)|0);i=N;continue}P=c[j>>2]|0;Q=c[P+(M<<2)>>2]|0;R=c[q>>2]|0;S=c[q+4>>2]|0;if((R|0)==0&(S|0)==(-2147483648|0)){T=c[r+4>>2]|0;U=c[r>>2]|0}else{T=S;U=R}R=Q+464|0;do{if((c[R>>2]|0)==0&(c[R+4>>2]|0)==(-2147483648|0)){S=Q+188|0;V=c[S>>2]|0;if((V|0)>62|(U|0)==0&(T|0)==(-2147483648|0)){break}if((c[s>>2]|0)==0){break}W=yrc(1,0,V|0)|0;X=G;Y=wrc(W,X,-1,-1)|0;Z=Y&U;Y=G&T;_=c[Q+44>>2]|0;$=c[Q+40>>2]|0;aa=VIb(60,0,_,(_|0)<0|0?-1:0,$,($|0)<0|0?-1:0)|0;$=G;_=xrc(Z,Y,aa,$)|0;ba=G;ca=yrc(1,0,V-3|0)|0;V=xrc(W,X,ca,G)|0;ca=G;if((Y|0)<(ca|0)|(Y|0)==(ca|0)&Z>>>0<V>>>0){da=1}else{V=xrc(W,X,aa,$)|0;$=G;da=(Y|0)<($|0)|(Y|0)==($|0)&Z>>>0<V>>>0?1:-1}V=c[t>>2]|0;b:do{if((V|0)==0){J=34}else{Z=c[u>>2]|0;$=0;c:while(1){ea=c[Z+($<<2)>>2]|0;d:do{if((ea|0)!=0){fa=c[ea+16>>2]|0;Y=ea+12|0;aa=0;while(1){if(!(aa>>>0<fa>>>0)){break d}ga=c[Y>>2]|0;if((c[ga+(aa<<2)>>2]|0)==(M|0)){ha=ea;break c}else{aa=aa+1|0}}}}while(0);aa=$+1|0;if(aa>>>0<V>>>0){$=aa}else{J=34;break b}}e:while(1){$=ha+56|0;ia=c[$>>2]|0;ja=c[$+4>>2]|0;if((ia|0)==0&(ja|0)==(-2147483648|0)){ka=ha;la=0}else{J=46;break}f:while(1){ma=c[Z+(la<<2)>>2]|0;g:do{if((ma|0)==(ka|0)){na=0}else{if((ka|0)!=0){na=ka;break}$=c[ma+16>>2]|0;aa=ma+12|0;Y=0;while(1){if(!(Y>>>0<$>>>0)){na=0;break g}if((c[(c[aa>>2]|0)+(Y<<2)>>2]|0)==(M|0)){break f}else{Y=Y+1|0}}}}while(0);Y=la+1|0;if(Y>>>0<V>>>0){ka=na;la=Y}else{oa=ba;pa=_;qa=da;break e}}if((ma|0)==0){oa=ba;pa=_;qa=da;break}else{ha=ma}}if((J|0)==46){J=0;oa=ja;pa=ia;qa=c[ha+64>>2]|0}Y=ea;aa=V;$=fa;X=ga;while(1){W=Y+56|0;if((c[W>>2]|0)==(pa|0)&(c[W+4>>2]|0)==(oa|0)){ra=aa}else{ca=Y+16|0;if(($|0)!=0){sa=0;do{ta=c[P+(c[X+(sa<<2)>>2]<<2)>>2]|0;ua=ta+464|0;c[ua>>2]=pa;c[ua+4>>2]=oa;c[ta+472>>2]=qa;sa=sa+1|0;}while(sa>>>0<(c[ca>>2]|0)>>>0)}c[W>>2]=pa;c[W+4>>2]=oa;c[Y+64>>2]=qa;ra=c[t>>2]|0}if((ra|0)==0){break b}else{va=Y;wa=0}h:while(1){xa=c[Z+(wa<<2)>>2]|0;i:do{if((xa|0)==(va|0)){ya=0}else{if((va|0)!=0){ya=va;break}za=c[xa+16>>2]|0;ca=xa+12|0;sa=0;while(1){if(!(sa>>>0<za>>>0)){ya=0;break i}Aa=c[ca>>2]|0;if((c[Aa+(sa<<2)>>2]|0)==(M|0)){break h}else{sa=sa+1|0}}}}while(0);sa=wa+1|0;if(sa>>>0<ra>>>0){va=ya;wa=sa}else{break b}}if((xa|0)==0){break}else{Y=xa;aa=ra;$=za;X=Aa}}}}while(0);do{if((J|0)==34){J=0;V=(O|0)==0;j:do{if(V){Ba=-1}else{X=-1;$=0;while(1){aa=c[P+($<<2)>>2]|0;Y=c[(c[aa+8>>2]|0)+8>>2]|0;if((Y|0)==0){if((c[aa+72>>2]&1024|0)==0){Ba=$;break j}}if((X|0)<0){Ca=(Y|0)==1?$:X}else{Ca=X}Y=$+1|0;if(Y>>>0<O>>>0){X=Ca;$=Y}else{break}}Ba=(Ca|0)<0?0:Ca}}while(0);$=c[P+(Ba<<2)>>2]|0;X=$+464|0;Y=c[X>>2]|0;aa=c[X+4>>2]|0;if(!((Y|0)==0&(aa|0)==(-2147483648|0))){c[R>>2]=Y;c[R+4>>2]=aa;c[Q+472>>2]=c[$+472>>2];break}if(V){break}else{Da=0}do{$=c[P+(Da<<2)>>2]|0;aa=$+464|0;c[aa>>2]=_;c[aa+4>>2]=ba;c[$+472>>2]=da;Da=Da+1|0;}while(Da>>>0<(c[o>>2]|0)>>>0)}}while(0);if(!((c[Q+472>>2]|0)==-1)){break}ba=Q+200|0;_=c[ba>>2]|0;V=c[ba+4>>2]|0;$=2147352575;if(!((V|0)>($|0)|(V|0)==($|0)&_>>>0>-1>>>0)){$=c[R>>2]|0;aa=c[R+4>>2]|0;if(($|0)==0&(aa|0)==(-2147483648|0)|(_|0)==0&(V|0)==(-2147483648|0)|((aa|0)>(V|0)|(aa|0)==(V|0)&$>>>0>_>>>0)){Ea=V;Fa=_}else{$=yrc(1,0,c[S>>2]|0)|0;aa=xrc(_,V,$,G)|0;Ea=G;Fa=aa}c[ba>>2]=Fa;c[ba+4>>2]=Ea}ba=Q+48|0;aa=c[ba>>2]|0;$=c[ba+4>>2]|0;V=2147352575;if(!(($|0)>(V|0)|($|0)==(V|0)&aa>>>0>-1>>>0)){V=c[R>>2]|0;_=c[R+4>>2]|0;if((V|0)==0&(_|0)==(-2147483648|0)|(aa|0)==0&($|0)==(-2147483648|0)|((_|0)>($|0)|(_|0)==($|0)&V>>>0>aa>>>0)){Ga=$;Ha=aa}else{V=yrc(1,0,c[S>>2]|0)|0;_=xrc(aa,$,V,G)|0;Ga=G;Ha=_}c[ba>>2]=Ha;c[ba+4>>2]=Ga}ba=Q+208|0;_=c[ba>>2]|0;V=c[ba+4>>2]|0;$=2147352575;if((V|0)>($|0)|(V|0)==($|0)&_>>>0>-1>>>0){break}$=c[R>>2]|0;aa=c[R+4>>2]|0;if(($|0)==0&(aa|0)==(-2147483648|0)|(_|0)==0&(V|0)==(-2147483648|0)|((aa|0)>(V|0)|(aa|0)==(V|0)&$>>>0>_>>>0)){Ia=V;Ja=_}else{$=yrc(1,0,c[S>>2]|0)|0;aa=xrc(_,V,$,G)|0;Ia=G;Ja=aa}c[ba>>2]=Ja;c[ba+4>>2]=Ia}}while(0);P=c[q>>2]|0;O=c[q+4>>2]|0;M=c[Q+472>>2]|0;do{if((M|0)==0){c[q>>2]=P;c[q+4>>2]=O;Ka=c[r+4>>2]|0;La=c[r>>2]|0}else{ba=c[R>>2]|0;aa=c[R+4>>2]|0;do{if((ba|0)==0&(aa|0)==(-2147483648|0)|(P|0)==0&(O|0)==(-2147483648|0)){Ma=O;Na=P}else{$=(aa|0)>(O|0)|(aa|0)==(O|0)&ba>>>0>P>>>0;if((M|0)==1&$){V=yrc(1,0,c[Q+188>>2]|0)|0;_=wrc(V,G,P,O)|0;Ma=G;Na=_;break}if((M|0)!=-1|$){Ma=O;Na=P;break}$=yrc(1,0,c[Q+188>>2]|0)|0;_=xrc(P,O,$,G)|0;Ma=G;Na=_}}while(0);c[q>>2]=Na;c[q+4>>2]=Ma;ba=c[r>>2]|0;aa=c[r+4>>2]|0;S=c[R>>2]|0;_=c[R+4>>2]|0;if((S|0)==0&(_|0)==(-2147483648|0)|(ba|0)==0&(aa|0)==(-2147483648|0)){Ka=aa;La=ba;break}$=(_|0)>(aa|0)|(_|0)==(aa|0)&S>>>0>ba>>>0;if((M|0)==1&$){S=yrc(1,0,c[Q+188>>2]|0)|0;_=wrc(S,G,ba,aa)|0;Ka=G;La=_;break}if((M|0)!=-1|$){Ka=aa;La=ba;break}$=yrc(1,0,c[Q+188>>2]|0)|0;_=xrc(ba,aa,$,G)|0;Ka=G;La=_}}while(0);c[r>>2]=La;c[r+4>>2]=Ka;M=c[Q+8>>2]|0;R=c[M+8>>2]|0;do{if((R|0)==3){O=c[B>>2]|0;if((O|0)==0){break}c[M+48>>2]=O}else if((R|0)==0){O=c[z>>2]|0;if((O|0)==0){break}c[M+48>>2]=O}else if((R|0)==1){O=c[A>>2]|0;if((O|0)==0){break}c[M+48>>2]=O}}while(0);if((c[v>>2]|0)!=0){M=jLb()|0;c[x>>2]=1;c[y>>2]=1e6;R=XIb(M,G,e,Q+40|0)|0;M=G;c[r>>2]=R;c[r+4>>2]=M;c[q>>2]=R;c[q+4>>2]=M}if(!F){if((c[Q+440>>2]|0)<1){K=I;J=109;break}}M=pJb(88)|0;R=M;if((M|0)!=0){if((c[f>>2]|0)==0){c[f>>2]=R}else{c[(c[w>>2]|0)+80>>2]=R}c[w>>2]=R;nrc(M|0,g|0,80)|0}c[k>>2]=(c[k>>2]|0)-(c[m>>2]|0);rX(a,Q,b)}if((J|0)==6){c[f>>2]=c[E+80>>2];c[k>>2]=(c[k>>2]|0)+(c[m>>2]|0);kJb(H);K=0;i=d;return K|0}else if((J|0)==14){KIb(0,0,2533912,(N=i,i=i+24|0,c[N>>2]=2518392,c[N+8>>2]=2504288,c[N+16>>2]=776,N)|0);i=N;Hd();return 0}else if((J|0)==109){i=d;return K|0}return 0}function rX(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+8|0;g=f|0;h=b+440|0;if((c[h>>2]|0)<=0){i=f;return}j=b+248|0;k=a;l=b|0;m=b+228|0;n=c[m>>2]|0;KIb(k,48,2539040,(o=i,i=i+16|0,c[o>>2]=c[l>>2],c[o+8>>2]=n,o)|0);i=o;c[m>>2]=(c[m>>2]|0)-1;do{if((e|0)==0){p=b+256|0;q=7}else{n=b+252|0;r=b+256|0;s=e+28|0;t=iJb(c[n>>2]|0,(c[r>>2]|0)+32+(c[s>>2]|0)|0)|0;if((t|0)==0){KIb(k,24,2537672,(o=i,i=i+8|0,c[o>>2]=c[l>>2],o)|0);i=o;p=r;q=7;break}else{c[n>>2]=t;nrc(t+(c[r>>2]|0)|0,c[e+24>>2]|0,c[s>>2]|0)|0;t=(c[r>>2]|0)+(c[s>>2]|0)|0;c[r>>2]=t;mrc((c[n>>2]|0)+t|0,0,32)|0;break}}}while(0);do{if((q|0)==7){c[m>>2]=0;if((c[p>>2]|0)!=0){break}KIb(k,24,2536320,(o=i,i=i+8|0,c[o>>2]=c[l>>2],o)|0);i=o}}while(0);do{if((c[a+1272>>2]|0)<1){u=1}else{if((c[m>>2]|0)<1){u=1;break}p=c[b+256>>2]|0;q=p>>>0>65535>>>0;t=q?p>>>16:p;n=q?16:0;if((t&65280|0)==0){v=n;w=t}else{v=n|8;w=t>>>8}t=p-(c[e+28>>2]|0)|0;p=t>>>0>65535>>>0;n=p?t>>>16:t;t=p?16:0;if((n&65280|0)==0){x=t;y=n}else{x=t|8;y=n>>>8}if(((d[1359664+w|0]|0)+v|0)!=((d[1359664+y|0]|0)+x|0)){u=0;break}i=f;return}}while(0);x=kX(j,1,g)|0;a:do{if((x|0)==0){z=c[g>>2]|0}else{j=c[g>>2]|0;if((c[h>>2]|0)>(j|0)){z=j;break}y=2500-(c[m>>2]|0)|0;v=x|0;w=c[v>>2]|0;KIb(k,48,2519400,(o=i,i=i+32|0,c[o>>2]=c[b+256>>2],c[o+8>>2]=y,c[o+16>>2]=w,c[o+24>>2]=j,o)|0);i=o;w=0;while(1){if((w|0)==10){z=j;break a}if((irc(c[v>>2]|0,c[600832+(w*12|0)>>2]|0)|0)==0){break}else{w=w+1|0}}v=c[b+8>>2]|0;c[v+48>>2]=c[600836+(w*12|0)>>2];c[v+8>>2]=c[600840+(w*12|0)>>2];z=j}}while(0);x=b+8|0;do{if((c[(c[x>>2]|0)+48>>2]|0)!=0&(z|0)>24|u){c[b+256>>2]=0;mJb(b+252|0);c[h>>2]=-1;m=c[l>>2]|0;if((c[(c[x>>2]|0)+48>>2]|0)==0){KIb(k,24,2533528,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;break}else{KIb(k,48,2535040,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;break}}}while(0);o=c[x>>2]|0;x=c[o+8>>2]|0;if((x|0)==0){k=c[a+1112>>2]|0;if((k|0)==0){i=f;return}c[o+48>>2]=k;i=f;return}else if((x|0)==1){k=c[a+1116>>2]|0;if((k|0)==0){i=f;return}c[o+48>>2]=k;i=f;return}else if((x|0)==3){x=c[a+1120>>2]|0;if((x|0)==0){i=f;return}c[o+48>>2]=x;i=f;return}else{i=f;return}}function sX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=(d|0)!=0;do{if(!e){d=c[a+424>>2]|0;if((d|0)>1){f=d}else{break}return f|0}}while(0);d=B5a(a,b)|0;if((d|0)>0){f=d;return f|0}d=c[a+424>>2]|0;g=(d|0)>1;if(g|e){f=g?d:-1;return f|0}d=c[a+72>>2]|0;if(!((d|0)>0&(b|0)>0)){f=-1;return f|0}g=c[a+412>>2]|0;if((g|0)<=0){f=-1;return f|0}if((c[a+432>>2]|0)<=1){f=-1;return f|0}if(!(((c[a+48>>2]|0)-86023|0)>>>0<2>>>0)){f=-1;return f|0}a=b;e=Erc(a<<3|0>>>29,((b|0)<0|0?-1:0)<<3|a>>>29,g,(g|0)<0|0?-1:0)|0;g=Crc(e,G,d,(d|0)<0|0?-1:0)|0;f=g;return f|0}function tX(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[a>>2]=0;c[b>>2]=0;g=d+8|0;h=c[g>>2]|0;i=c[h+8>>2]|0;if((i|0)==1){j=c[f+28>>2]|0;f=h+424|0;k=c[f>>2]|0;do{if((k|0)>1){l=k}else{m=B5a(h,j)|0;if((m|0)>0){l=m;break}m=c[f>>2]|0;n=(m|0)>1;do{if(n){o=n?m:-1}else{p=c[h+72>>2]|0;if(!((p|0)>0&(j|0)>0)){return}q=c[h+412>>2]|0;if((q|0)<=0){return}if((c[h+432>>2]|0)<=1){return}if(((c[h+48>>2]|0)-86023|0)>>>0<2>>>0){r=j;s=Erc(r<<3|0>>>29,((j|0)<0|0?-1:0)<<3|r>>>29,q,(q|0)<0|0?-1:0)|0;q=Crc(s,G,p,(p|0)<0|0?-1:0)|0;o=q;break}else{return}}}while(0);if((o|0)>=1){l=o;break}return}}while(0);o=(c[g>>2]|0)+412|0;if((c[o>>2]|0)<1){return}c[a>>2]=l;c[b>>2]=c[o>>2];return}else if((i|0)==0){i=d+412|0;if((c[i>>2]|0)!=0&(e|0)==0){c[a>>2]=c[d+416>>2];c[b>>2]=c[i>>2];return}i=c[d+40>>2]|0;o=Erc(i,(i|0)<0|0?-1:0,1e3,0)|0;l=G;g=d+44|0;d=c[g>>2]|0;j=(d|0)<0|0?-1:0;if((l|0)>(j|0)|(l|0)==(j|0)&o>>>0>d>>>0){c[a>>2]=i;c[b>>2]=c[g>>2];return}g=c[h+104>>2]|0;i=Erc(g,(g|0)<0|0?-1:0,1e3,0)|0;d=G;o=h+108|0;j=c[o>>2]|0;l=(j|0)<0|0?-1:0;if(!((d|0)>(l|0)|(d|0)==(l|0)&i>>>0>j>>>0)){return}c[a>>2]=g;g=c[o>>2]|0;c[b>>2]=g;o=(e|0)!=0;do{if(o){j=c[e+36>>2]|0;if((j|0)==0){return}i=c[a>>2]|0;l=j+1|0;if((i|0)>(2147483647/(l|0)|0|0)){c[b>>2]=(g|0)/(l|0)|0;break}c[a>>2]=ca(i,l)|0;return}}while(0);if((c[h+112>>2]|0)<2|o){return}c[b>>2]=0;c[a>>2]=0;return}else{return}}function uX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a+1236|0;do{if((c[a+1084>>2]&1|0)==0){h=c[g>>2]|0;if((h|0)==0){j=vX(a,b)|0;if((j|0)<0){k=j}else{l=j;break}i=d;return k|0}c[f>>2]=h;nrc(b|0,h|0,80)|0;j=h+80|0;c[g>>2]=c[j>>2];if((c[j>>2]|0)==0){c[a+1240>>2]=0}mJb(f);l=0}else{j=a+1240|0;h=b;m=a+28|0;n=1;a:while(1){while(1){o=c[g>>2]|0;if((o|0)==0){p=0}else{q=o+16|0;r=c[q>>2]|0;s=c[q+4>>2]|0;if((r|0)==0&(s|0)==(-2147483648|0)){t=o;u=o+8|0}else{v=o+32|0;w=o+8|0;x=yrc(2,0,(c[(c[(c[m>>2]|0)+(c[v>>2]<<2)>>2]|0)+188>>2]|0)-1|0)|0;y=G;z=o;A=s;s=r;while(1){if(!((c[w>>2]|0)==0&(c[w+4>>2]|0)==(-2147483648|0))){B=A;C=s;break}do{if((c[z+32>>2]|0)==(c[v>>2]|0)){r=z+16|0;D=ZIb(c[q>>2]|0,c[q+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0,x,y)|0;E=G;F=0;if(!((E|0)<(F|0)|(E|0)==(F|0)&D>>>0<0>>>0)){H=A;I=s;break}D=z+8|0;F=ZIb(c[D>>2]|0,c[D+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0,x,y)|0;if(!((F|0)==0&(G|0)==0)){F=c[r+4>>2]|0;c[w>>2]=c[r>>2];c[w+4>>2]=F}if((s|0)==0&(A|0)==(-2147483648|0)){H=-2147483648;I=0;break}H=c[r+4>>2]|0;I=c[r>>2]|0}else{H=A;I=s}}while(0);r=c[z+80>>2]|0;if((r|0)==0){B=H;C=I;break}else{z=r;A=H;s=I}}do{if(!n){if((c[w>>2]|0)!=0|(c[w+4>>2]|0)!=(-2147483648|0)|(C|0)==0&(B|0)==(-2147483648|0)){break}s=c[o+48>>2]|0;A=wrc(s,(s|0)<0|0?-1:0,C,B)|0;c[w>>2]=A;c[w+4>>2]=G}}while(0);t=c[g>>2]|0;u=w}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==(-2147483648|0))){J=26;break a}if(((c[q>>2]|0)!=0|(c[q+4>>2]|0)!=(-2147483648|0))&n){p=t}else{J=26;break a}}K=vX(a,b)|0;if((K|0)<0){break}o=pJb(88)|0;A=o;if((o|0)==0){L=0}else{if((c[g>>2]|0)==0){c[g>>2]=A}else{c[(c[j>>2]|0)+80>>2]=A}c[j>>2]=A;nrc(o|0,h|0,80)|0;L=o}if((Q1(L)|0)<0){k=-12;J=58;break a}}if((p|0)==0|(K|0)==-11){k=K;J=58;break}else{n=0}}if((J|0)==26){if((t|0)==0){KIb(0,0,2533912,(n=i,i=i+24|0,c[n>>2]=2540360,c[n+8>>2]=2504288,c[n+16>>2]=1415,n)|0);i=n;Hd();return 0}c[e>>2]=t;nrc(h|0,t|0,80)|0;n=t+80|0;c[g>>2]=c[n>>2];if((c[n>>2]|0)==0){c[j>>2]=0}mJb(e);l=0;break}else if((J|0)==58){i=d;return k|0}}}while(0);J=c[a+28>>2]|0;e=c[J+(c[b+32>>2]<<2)>>2]|0;do{if((c[(c[a+4>>2]|0)+8>>2]&256|0)!=0){if((c[b+36>>2]&1|0)==0){break}g=c[J+(c[e>>2]<<2)>>2]|0;t=g+404|0;K=c[t>>2]|0;if(!(K>>>0<(((c[a+1124>>2]|0)>>>0)/24|0)>>>0)){if((K|0)>0){K=g+400|0;g=0;p=0;while(1){L=c[K>>2]|0;u=L+(g*24|0)|0;B=L+(p*24|0)|0;c[u>>2]=c[B>>2];c[u+4>>2]=c[B+4>>2];c[u+8>>2]=c[B+8>>2];c[u+12>>2]=c[B+12>>2];c[u+16>>2]=c[B+16>>2];c[u+20>>2]=c[B+20>>2];B=g+1|0;u=B<<1;if((u|0)<(c[t>>2]|0)){g=B;p=u}else{M=B;break}}}else{M=0}c[t>>2]=M}p=b+64|0;g=c[p>>2]|0;K=c[p+4>>2]|0;p=b+16|0;j=c[p>>2]|0;h=c[p+4>>2]|0;p=c[e+472>>2]|0;do{if((p|0)==0){N=h;O=j}else{B=e+464|0;u=c[B>>2]|0;L=c[B+4>>2]|0;if((u|0)==0&(L|0)==(-2147483648|0)|(j|0)==0&(h|0)==(-2147483648|0)){N=h;O=j;break}B=(L|0)>(h|0)|(L|0)==(h|0)&u>>>0>j>>>0;if((p|0)==1&B){u=yrc(1,0,c[e+188>>2]|0)|0;L=wrc(u,G,j,h)|0;N=G;O=L;break}if((p|0)!=-1|B){N=h;O=j;break}B=yrc(1,0,c[e+188>>2]|0)|0;L=xrc(j,h,B,G)|0;N=G;O=L}}while(0);AX(e+400|0,e+404|0,e+408|0,g,K,O,N,0,0,1)|0}}while(0);N=b+16|0;O=c[N>>2]|0;e=c[N+4>>2]|0;M=2147352575;if((e|0)>(M|0)|(e|0)==(M|0)&O>>>0>-1>>>0){M=wrc(O,e,1,-2147418112)|0;c[N>>2]=M;c[N+4>>2]=G}N=b+8|0;b=c[N>>2]|0;M=c[N+4>>2]|0;e=2147352575;if(!((M|0)>(e|0)|(M|0)==(e|0)&b>>>0>-1>>>0)){k=l;i=d;return k|0}e=wrc(b,M,1,-2147418112)|0;c[N>>2]=e;c[N+4>>2]=G;k=l;i=d;return k|0}function vX(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;e=i;i=i+280|0;f=e|0;g=e+8|0;h=e+216|0;j=e+248|0;J1(d);k=b+1264|0;l=g+32|0;m=b+28|0;n=g+8|0;o=b+1168|0;p=d;q=g;r=b+4|0;s=d+36|0;t=d+16|0;u=b+1124|0;v=d+64|0;w=b+1084|0;x=b;z=e+152|0;A=e+184|0;B=g+16|0;C=g+28|0;D=g+48|0;E=g+36|0;F=e+88|0;H=e+120|0;a:while(1){I=c[k>>2]|0;if((I|0)!=0){J=I;K=59;break}L=qX(b,g)|0;if((L|0)<0){K=4;break}I=c[l>>2]|0;M=c[(c[m>>2]|0)+(I<<2)>>2]|0;N=c[n>>2]|0;O=c[n+4>>2]|0;do{if(!((N|0)==0&(O|0)==(-2147483648|0))){P=c[B>>2]|0;Q=c[B+4>>2]|0;if(!(((P|0)!=0|(Q|0)!=(-2147483648|0))&((O|0)<(Q|0)|(O|0)==(Q|0)&N>>>0<P>>>0))){break}mrc(F|0,0,32)|0;a[F]=0;Rb(F|0,32,2541576,(R=i,i=i+16|0,c[R>>2]=N,c[R+8>>2]=O,R)|0)|0;i=R;mrc(H|0,0,32)|0;a[H]=0;P=c[B>>2]|0;Q=c[B+4>>2]|0;if((P|0)==0&(Q|0)==(-2147483648|0)){Rb(H|0,32,2543336,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Rb(H|0,32,2541576,(R=i,i=i+16|0,c[R>>2]=P,c[R+8>>2]=Q,R)|0)|0;i=R}Q=c[C>>2]|0;KIb(x,24,2560704,(R=i,i=i+32|0,c[R>>2]=I,c[R+8>>2]=F,c[R+16>>2]=H,c[R+24>>2]=Q,R)|0);i=R}}while(0);if((c[o>>2]&1|0)!=0){I=c[l>>2]|0;mrc(z|0,0,32)|0;a[z]=0;O=c[n>>2]|0;N=c[n+4>>2]|0;if((O|0)==0&(N|0)==(-2147483648|0)){Rb(z|0,32,2543336,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Rb(z|0,32,2541576,(R=i,i=i+16|0,c[R>>2]=O,c[R+8>>2]=N,R)|0)|0;i=R}mrc(A|0,0,32)|0;a[A]=0;N=c[B>>2]|0;O=c[B+4>>2]|0;if((N|0)==0&(O|0)==(-2147483648|0)){Rb(A|0,32,2543336,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Rb(A|0,32,2541576,(R=i,i=i+16|0,c[R>>2]=N,c[R+8>>2]=O,R)|0)|0;i=R}O=c[C>>2]|0;N=c[D>>2]|0;Q=c[E>>2]|0;KIb(x,48,2558928,(R=i,i=i+48|0,c[R>>2]=I,c[R+8>>2]=z,c[R+16>>2]=A,c[R+24>>2]=O,c[R+32>>2]=N,c[R+40>>2]=Q,R)|0);i=R}Q=M+236|0;b:do{if((c[Q>>2]|0)==0){K=33}else{N=M+240|0;do{if((c[N>>2]|0)==0){if((c[w>>2]&32|0)!=0){K=33;break b}O=M+8|0;I=DWa(c[(c[O>>2]|0)+48>>2]|0)|0;c[N>>2]=I;if((I|0)==0){P=u5a(c[(c[O>>2]|0)+48>>2]|0)|0;KIb(x,40,2397248,(R=i,i=i+8|0,c[R>>2]=P,R)|0);i=R;c[Q>>2]=0;K=33;break b}P=c[Q>>2]|0;if((P|0)==0){K=33;break b}else if((P|0)==1463898624){O=I+176|0;c[O>>2]=c[O>>2]|4096;break}else if((P|0)==4){O=I+176|0;c[O>>2]=c[O>>2]|2;break}else if((P|0)==2){P=I+176|0;c[P>>2]=c[P>>2]|1;break}else{break}}}while(0);if((c[M+76>>2]|0)<48){N=yY(b,g,c[l>>2]|0)|0;if((N|0)<0){S=N;K=77;break a}else{T=N;U=0;break}}else{P1(g);T=0;U=0;break}}}while(0);do{if((K|0)==33){K=0;nrc(p|0,q|0,80)|0;zY(b,M,0,d);if((c[(c[r>>2]|0)+8>>2]&256|0)==0){T=0;U=1;break}if((c[s>>2]&1|0)==0){T=0;U=1;break}Q=c[t>>2]|0;N=c[t+4>>2]|0;if((Q|0)==0&(N|0)==(-2147483648|0)){T=0;U=1;break}P=c[(c[m>>2]|0)+(c[M>>2]<<2)>>2]|0;I=P+404|0;O=c[I>>2]|0;if(O>>>0<(((c[u>>2]|0)>>>0)/24|0)>>>0){V=N;W=Q}else{if((O|0)>0){O=P+400|0;P=0;X=0;do{Y=c[O>>2]|0;Z=Y+(P*24|0)|0;_=Y+(X*24|0)|0;c[Z>>2]=c[_>>2];c[Z+4>>2]=c[_+4>>2];c[Z+8>>2]=c[_+8>>2];c[Z+12>>2]=c[_+12>>2];c[Z+16>>2]=c[_+16>>2];c[Z+20>>2]=c[_+20>>2];P=P+1|0;X=P<<1;}while((X|0)<(c[I>>2]|0));$=P;aa=c[t+4>>2]|0;ba=c[t>>2]|0}else{$=0;aa=N;ba=Q}c[I>>2]=$;V=aa;W=ba}X=c[v>>2]|0;O=c[v+4>>2]|0;_=c[M+472>>2]|0;do{if((_|0)==0){ca=V;da=W}else{Z=M+464|0;Y=c[Z>>2]|0;ea=c[Z+4>>2]|0;if((Y|0)==0&(ea|0)==(-2147483648|0)|(W|0)==0&(V|0)==(-2147483648|0)){ca=V;da=W;break}Z=(ea|0)>(V|0)|(ea|0)==(V|0)&Y>>>0>W>>>0;if((_|0)==1&Z){Y=yrc(1,0,c[M+188>>2]|0)|0;ea=wrc(Y,G,W,V)|0;ca=G;da=ea;break}if((_|0)!=-1|Z){ca=V;da=W;break}Z=yrc(1,0,c[M+188>>2]|0)|0;ea=xrc(W,V,Z,G)|0;ca=G;da=ea}}while(0);AX(M+400|0,M+404|0,M+408|0,X,O,da,ca,0,0,1)|0;T=0;U=1}}while(0);_=M+444|0;do{if((c[s>>2]&1|0)==0){if((c[_>>2]|0)==0){break}P1(g);if((U|0)==0){continue a}nrc(p|0,q|0,80)|0;continue a}else{c[_>>2]=0}}while(0);if((U|0)!=0){fa=T;K=62;break}}if((K|0)==77){i=e;return S|0}if((K|0)==4){if((L|0)==-11){S=-11;i=e;return S|0}T=b+24|0;U=c[T>>2]|0;if((U|0)!=0){q=0;g=U;while(1){U=c[(c[m>>2]|0)+(q<<2)>>2]|0;do{if((c[U+240>>2]|0)==0){ga=g}else{if((c[U+236>>2]|0)==0){ga=g;break}yY(b,0,c[U>>2]|0)|0;ga=c[T>>2]|0}}while(0);U=q+1|0;if(U>>>0<ga>>>0){q=U;g=ga}else{break}}}ga=c[k>>2]|0;if((ga|0)==0){fa=L;K=62}else{J=ga;K=59}}if((K|0)==59){c[f>>2]=J;nrc(p|0,J|0,80)|0;p=J+80|0;c[k>>2]=c[p>>2];if((c[p>>2]|0)==0){c[b+1268>>2]=0}mJb(f);ha=0;K=63}else if((K|0)==62){if((fa|0)>-1){ha=fa;K=63}else{ia=fa}}do{if((K|0)==63){fa=(c[(c[m>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+448|0;do{if((c[fa>>2]|0)!=0){f=U1(d,70,10)|0;if((f|0)==0){c[fa>>2]=0;break}else{b=f;y=c[fa>>2]|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;KIb(x,48,2557880,(R=i,i=i+8|0,c[R>>2]=c[fa>>2],R)|0);i=R;c[fa>>2]=0;break}}}while(0);if((c[w>>2]&262144|0)!=0){ia=ha;break}W1(d)|0;ia=ha}}while(0);if((c[o>>2]&1|0)==0){S=ia;i=e;return S|0}o=c[d+32>>2]|0;ha=h|0;mrc(ha|0,0,32)|0;a[ha]=0;h=d+8|0;w=c[h>>2]|0;m=c[h+4>>2]|0;if((w|0)==0&(m|0)==(-2147483648|0)){Rb(ha|0,32,2543336,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Rb(ha|0,32,2541576,(R=i,i=i+16|0,c[R>>2]=w,c[R+8>>2]=m,R)|0)|0;i=R}m=j|0;mrc(m|0,0,32)|0;a[m]=0;j=c[t>>2]|0;w=c[t+4>>2]|0;if((j|0)==0&(w|0)==(-2147483648|0)){Rb(m|0,32,2543336,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0)|0;i=R}else{Rb(m|0,32,2541576,(R=i,i=i+16|0,c[R>>2]=j,c[R+8>>2]=w,R)|0)|0;i=R}w=c[d+28>>2]|0;j=c[d+48>>2]|0;d=c[s>>2]|0;KIb(x,48,2556528,(R=i,i=i+48|0,c[R>>2]=o,c[R+8>>2]=ha,c[R+16>>2]=m,c[R+24>>2]=w,c[R+32>>2]=j,c[R+40>>2]=d,R)|0);i=R;S=ia;i=e;return S|0}function wX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=d+404|0;e=c[b>>2]|0;if(e>>>0<(((c[a+1124>>2]|0)>>>0)/24|0)>>>0){return}if((e|0)>0){e=d+400|0;d=0;a=0;while(1){f=c[e>>2]|0;g=f+(d*24|0)|0;h=f+(a*24|0)|0;c[g>>2]=c[h>>2];c[g+4>>2]=c[h+4>>2];c[g+8>>2]=c[h+8>>2];c[g+12>>2]=c[h+12>>2];c[g+16>>2]=c[h+16>>2];c[g+20>>2]=c[h+20>>2];h=d+1|0;g=h<<1;if((g|0)<(c[b>>2]|0)){d=h;a=g}else{i=h;break}}}else{i=0}c[b>>2]=i;return}function xX(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=c[a+472>>2]|0;do{if((j|0)==0){k=f;l=e}else{m=a+464|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((n|0)==0&(o|0)==(-2147483648|0)|(e|0)==0&(f|0)==(-2147483648|0)){k=f;l=e;break}m=(o|0)>(f|0)|(o|0)==(f|0)&n>>>0>e>>>0;if((j|0)==1&m){n=yrc(1,0,c[a+188>>2]|0)|0;o=wrc(n,G,e,f)|0;k=G;l=o;break}if((j|0)!=-1|m){k=f;l=e;break}m=yrc(1,0,c[a+188>>2]|0)|0;o=xrc(e,f,m,G)|0;k=G;l=o}}while(0);return AX(a+400|0,a+404|0,a+408|0,b,d,l,k,g,h,i)|0}function yX(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=a+1264|0;h=a+1268|0;j=f;k=c[g>>2]|0;if((k|0)!=0){l=k;do{c[f>>2]=l;c[g>>2]=c[l+80>>2];P1(l|0);mJb(j);l=c[g>>2]|0;}while((l|0)!=0)}c[h>>2]=0;h=a+1236|0;l=a+1240|0;g=e;j=c[h>>2]|0;if((j|0)!=0){f=j;do{c[e>>2]=f;c[h>>2]=c[f+80>>2];P1(f|0);mJb(g);f=c[h>>2]|0;}while((f|0)!=0)}c[l>>2]=0;l=a+1256|0;f=a+1260|0;h=d;g=c[l>>2]|0;if((g|0)!=0){e=g;do{c[d>>2]=e;c[l>>2]=c[e+80>>2];P1(e|0);mJb(h);e=c[l>>2]|0;}while((e|0)!=0)}c[f>>2]=0;c[a+1272>>2]=25e5;f=a+24|0;if((c[f>>2]|0)==0){i=b;return}e=a+28|0;a=0;do{l=c[(c[e>>2]|0)+(a<<2)>>2]|0;h=l+240|0;d=c[h>>2]|0;if((d|0)!=0){HWa(d);c[h>>2]=0}h=l+216|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=l+640|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=l+200|0;d=(c[h>>2]|0)==0&(c[h+4>>2]|0)==(-2147483648|0);h=l+208|0;c[h>>2]=d?-1:0;c[h+4>>2]=d?2147418111:-2147483648;c[l+228>>2]=2500;d=l+264|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+272|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+280|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+288|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+296|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+304|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+312|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+320|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+328|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+336|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+344|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+352|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+360|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+368|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+376|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+384|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=l+392|0;c[d>>2]=0;c[d+4>>2]=-2147483648;a=a+1|0;}while(a>>>0<(c[f>>2]|0)>>>0);i=b;return}function zX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c[a+24>>2]|0;if((f|0)==0){return}g=c[a+28>>2]|0;a=c[b+40>>2]|0;h=a;i=(a|0)<0|0?-1:0;a=c[b+44>>2]|0;b=a;j=(a|0)<0|0?-1:0;a=0;do{k=c[g+(a<<2)>>2]|0;l=c[k+44>>2]|0;m=Erc(h,i,l,(l|0)<0|0?-1:0)|0;l=G;n=c[k+40>>2]|0;o=Erc(b,j,n,(n|0)<0|0?-1:0)|0;n=VIb(d,e,m,l,o,G)|0;o=k+208|0;c[o>>2]=n;c[o+4>>2]=G;a=a+1|0;}while(a>>>0<f>>>0);return}function AX(a,b,d,e,f,g,h,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=i;n=c[b>>2]|0;if((n+1|0)>>>0>178956969>>>0){o=-1;i=m;return o|0}if((g|0)==0&(h|0)==(-2147483648|0)|j>>>0>1073741823>>>0){o=-22;i=m;return o|0}p=2147352575;q=(h|0)>(p|0)|(h|0)==(p|0)&g>>>0>-1>>>0;p=wrc(g,h,1,-2147418112)|0;r=q?p:g;g=q?G:h;h=wJb(c[a>>2]|0,d,(n*24|0)+24|0)|0;n=h;if((h|0)==0){o=-1;i=m;return o|0}c[a>>2]=n;a=c[b>>2]|0;h=(a|0)==0;if(h){s=0;t=-1}else{d=a-1|0;q=n+(d*24|0)+8|0;p=c[q+4>>2]|0;s=a;t=(p|0)<(g|0)|(p|0)==(g|0)&(c[q>>2]|0)>>>0<r>>>0?d:-1}if((s-t|0)>1){d=t;t=s;while(1){q=d+t>>1;p=n+(q*24|0)+8|0;u=c[p>>2]|0;v=c[p+4>>2]|0;p=(v|0)<(g|0)|(v|0)==(g|0)&u>>>0<r>>>0?t:q;w=(v|0)>(g|0)|(v|0)==(g|0)&u>>>0>r>>>0?d:q;if((p-w|0)>1){d=w;t=p}else{x=p;break}}}else{x=s}s=(x|0)==(a|0)?-1:x;do{if((s|0)<0){c[b>>2]=a+1;x=n+(a*24|0)|0;if(h){y=0;z=x;A=k;break}t=n+((a-1|0)*24|0)+8|0;d=c[t+4>>2]|0;if((d|0)<(g|0)|(d|0)==(g|0)&(c[t>>2]|0)>>>0<r>>>0){y=a;z=x;A=k;break}KIb(0,0,2533912,(x=i,i=i+24|0,c[x>>2]=2470032,c[x+8>>2]=2504288,c[x+16>>2]=1766,x)|0);i=x;Hd();return 0}else{x=n+(s*24|0)|0;t=n+(s*24|0)+8|0;d=c[t>>2]|0;p=c[t+4>>2]|0;if((d|0)==(r|0)&(p|0)==(g|0)){t=x|0;if(!((c[t>>2]|0)==(e|0)&(c[t+4>>2]|0)==(f|0))){y=s;z=x;A=k;break}t=c[n+(s*24|0)+20>>2]|0;y=s;z=x;A=(t|0)>(k|0)?t:k;break}if((p|0)>(g|0)|(p|0)==(g|0)&d>>>0>r>>>0){orc(n+((s+1|0)*24|0)|0,x|0,(a-s|0)*24|0|0)|0;c[b>>2]=(c[b>>2]|0)+1;y=s;z=x;A=k;break}else{o=-1;i=m;return o|0}}}while(0);k=z|0;c[k>>2]=e;c[k+4>>2]=f;f=z+8|0;c[f>>2]=r;c[f+4>>2]=g;c[z+20>>2]=A;c[z+16>>2]=l&3|j<<2;o=y;i=m;return o|0}function BX(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((b|0)==0){g=0;h=-1}else{i=b-1|0;j=a+(i*24|0)+8|0;k=c[j+4>>2]|0;g=b;h=(k|0)<(e|0)|(k|0)==(e|0)&(c[j>>2]|0)>>>0<d>>>0?i:-1}if((g-h|0)>1){i=h;j=g;while(1){k=j+i>>1;l=a+(k*24|0)+8|0;m=c[l>>2]|0;n=c[l+4>>2]|0;l=(n|0)<(e|0)|(n|0)==(e|0)&m>>>0<d>>>0?j:k;o=(n|0)>(e|0)|(n|0)==(e|0)&m>>>0>d>>>0?i:k;if((l-o|0)>1){i=o;j=l}else{p=o;q=l;break}}}else{p=h;q=g}g=f&1;h=(g|0)!=0?p:q;if((f&4|0)!=0){r=h;s=(r|0)==(b|0);t=s?-1:r;return t|0}if(!((h|0)>-1&(h|0)<(b|0))){r=h;s=(r|0)==(b|0);t=s?-1:r;return t|0}f=(g<<1^2)-1|0;g=h;while(1){if((c[a+(g*24|0)+16>>2]&1|0)!=0){r=g;u=10;break}h=f+g|0;if((h|0)>-1&(h|0)<(b|0)){g=h}else{r=h;u=10;break}}if((u|0)==10){s=(r|0)==(b|0);t=s?-1:r;return t|0}return 0}function CX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[a+400>>2]|0;g=c[a+404>>2]|0;if((g|0)==0){h=0;i=-1}else{a=g-1|0;j=f+(a*24|0)+8|0;k=c[j+4>>2]|0;h=g;i=(k|0)<(d|0)|(k|0)==(d|0)&(c[j>>2]|0)>>>0<b>>>0?a:-1}if((h-i|0)>1){a=i;j=h;while(1){k=a+j>>1;l=f+(k*24|0)+8|0;m=c[l>>2]|0;n=c[l+4>>2]|0;l=(n|0)<(d|0)|(n|0)==(d|0)&m>>>0<b>>>0?j:k;o=(n|0)>(d|0)|(n|0)==(d|0)&m>>>0>b>>>0?a:k;if((l-o|0)>1){a=o;j=l}else{p=o;q=l;break}}}else{p=i;q=h}h=e&1;i=(h|0)!=0?p:q;if((e&4|0)!=0){r=i;s=(r|0)==(g|0);t=s?-1:r;return t|0}if(!((i|0)>-1&(i|0)<(g|0))){r=i;s=(r|0)==(g|0);t=s?-1:r;return t|0}e=(h<<1^2)-1|0;h=i;while(1){if((c[f+(h*24|0)+16>>2]&1|0)!=0){r=h;u=10;break}i=e+h|0;if((i|0)>-1&(i|0)<(g|0)){h=i}else{r=i;u=10;break}}if((u|0)==10){s=(r|0)==(g|0);t=s?-1:r;return t|0}return 0}function DX(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;g=i;i=i+8|0;h=g|0;j=c[a+4>>2]|0;if((b|0)<0){k=-1;i=g;return k|0}l=a+28|0;m=c[(c[l>>2]|0)+(b<<2)>>2]|0;n=c[m+400>>2]|0;do{if((n|0)==0){o=0;p=0;q=-2147483648;r=0;s=-2147483648;t=0;u=-1;v=-1;w=0;x=0}else{y=c[m+404>>2]|0;z=(y|0)==0;if(z){A=0;B=-1}else{C=y-1|0;D=n+(C*24|0)+8|0;E=c[D+4>>2]|0;A=y;B=(E|0)<(e|0)|(E|0)==(e|0)&(c[D>>2]|0)>>>0<d>>>0?C:-1}if((A-B|0)>1){C=B;D=A;while(1){E=C+D>>1;F=n+(E*24|0)+8|0;H=c[F>>2]|0;I=c[F+4>>2]|0;F=(I|0)<(e|0)|(I|0)==(e|0)&H>>>0<d>>>0?D:E;J=(I|0)>(e|0)|(I|0)==(e|0)&H>>>0>d>>>0?C:E;if((F-J|0)>1){C=J;D=F}else{K=J;break}}}else{K=B}D=(f&4|0)==0;a:do{if(D){if((K|0)>-1&(K|0)<(y|0)){L=K}else{M=K;break}while(1){if((c[n+(L*24|0)+16>>2]&1|0)!=0){M=L;break a}C=L-1|0;if((L|0)>0&(C|0)<(y|0)){L=C}else{M=C;break}}}else{M=K}}while(0);C=(M|0)==(y|0)?-1:M;J=(C|0)>0?C:0;C=n+(J*24|0)+8|0;F=c[C>>2]|0;E=c[C+4>>2]|0;C=n+(J*24|0)|0;H=c[C>>2]|0;I=c[C+4>>2]|0;if((E|0)>(e|0)|(E|0)==(e|0)&F>>>0>d>>>0){C=c[n+(J*24|0)+20>>2]|0;if((H|0)==(C|0)&(I|0)==(((C|0)<0|0?-1:0)|0)){N=13}else{O=0;P=0;Q=-2147483648;R=0}}else{N=13}if((N|0)==13){O=I;P=H;Q=E;R=F}if(z){S=0;T=-1}else{F=y-1|0;E=n+(F*24|0)+8|0;H=c[E+4>>2]|0;S=y;T=(H|0)<(e|0)|(H|0)==(e|0)&(c[E>>2]|0)>>>0<d>>>0?F:-1}if((S-T|0)>1){F=T;E=S;while(1){H=F+E>>1;I=n+(H*24|0)+8|0;C=c[I>>2]|0;J=c[I+4>>2]|0;I=(J|0)<(e|0)|(J|0)==(e|0)&C>>>0<d>>>0?E:H;U=(J|0)>(e|0)|(J|0)==(e|0)&C>>>0>d>>>0?F:H;if((I-U|0)>1){F=U;E=I}else{V=I;break}}}else{V=S}b:do{if(D){if((V|0)>-1&(V|0)<(y|0)){W=V}else{X=V;break}while(1){if((c[n+(W*24|0)+16>>2]&1|0)!=0){X=W;break b}E=W+1|0;if((E|0)>-1&(E|0)<(y|0)){W=E}else{X=E;break}}}else{X=V}}while(0);D=(X|0)==(y|0)?-1:X;if((D|0)>=(y|0)){KIb(0,0,2533912,(E=i,i=i+24|0,c[E>>2]=2461160,c[E+8>>2]=2504288,c[E+16>>2]=1887,E)|0);i=E;Hd();return 0}if(!((D|0)>-1)){o=O;p=P;q=-2147483648;r=0;s=Q;t=R;u=-1;v=-1;w=0;x=0;break}E=n+(D*24|0)|0;F=c[E>>2]|0;z=c[E+4>>2]|0;E=n+(D*24|0)+8|0;I=c[E>>2]|0;U=c[E+4>>2]|0;E=c[n+(D*24|0)+20>>2]|0;D=xrc(F,z,E,(E|0)<0|0?-1:0)|0;o=O;p=P;q=U;r=I;s=Q;t=R;u=G;v=D;w=z;x=F}}while(0);R=EX(a,b,d,e,p,o,x,w,v,u,t,s,r,q,f,h,c[j+56>>2]|0)|0;j=G;f=0;if((j|0)<(f|0)|(j|0)==(f|0)&R>>>0<0>>>0){k=-1;i=g;return k|0}f=fD(c[a+16>>2]|0,R,j,0)|0;j=G;R=0;if((j|0)<(R|0)|(j|0)==(R|0)&f>>>0<0>>>0){k=f;i=g;return k|0}yX(a);f=c[h>>2]|0;R=c[h+4>>2]|0;h=c[a+24>>2]|0;if((h|0)==0){k=0;i=g;return k|0}a=c[l>>2]|0;l=c[m+40>>2]|0;j=l;q=(l|0)<0|0?-1:0;l=c[m+44>>2]|0;m=l;r=(l|0)<0|0?-1:0;l=0;while(1){s=c[a+(l<<2)>>2]|0;t=c[s+44>>2]|0;u=Erc(t,(t|0)<0|0?-1:0,j,q)|0;t=G;v=c[s+40>>2]|0;w=Erc(v,(v|0)<0|0?-1:0,m,r)|0;v=VIb(f,R,u,t,w,G)|0;w=s+208|0;c[w>>2]=v;c[w+4>>2]=G;w=l+1|0;if(w>>>0<h>>>0){l=w}else{k=0;break}}i=g;return k|0}function EX(a,b,d,e,f,g,h,j,k,l,m,n,o,p,q,r,s){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;var t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;t=i;i=i+32|0;u=t|0;v=t+8|0;w=t+16|0;x=t+24|0;c[u>>2]=f;c[u+4>>2]=g;c[v>>2]=h;c[v+4>>2]=j;c[w>>2]=o;c[w+4>>2]=p;do{if((m|0)==0&(n|0)==(-2147483648|0)){p=a+1248|0;o=c[p+4>>2]|0;c[u>>2]=c[p>>2];c[u+4>>2]=o;o=Xe[s&511](a,b,u,-1,2147483647)|0;p=G;do{if((b|0)>-1){j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;h=c[j+472>>2]|0;if((h|0)==0){y=p;z=o;break}g=j+464|0;f=c[g>>2]|0;A=c[g+4>>2]|0;if((f|0)==0&(A|0)==(-2147483648|0)|(o|0)==0&(p|0)==(-2147483648|0)){y=p;z=o;break}g=(A|0)>(p|0)|(A|0)==(p|0)&f>>>0>o>>>0;if((h|0)==1&g){f=yrc(1,0,c[j+188>>2]|0)|0;A=wrc(f,G,o,p)|0;y=G;z=A;break}if((h|0)!=-1|g){y=p;z=o;break}g=yrc(1,0,c[j+188>>2]|0)|0;j=xrc(o,p,g,G)|0;y=G;z=j}else{y=p;z=o}}while(0);if((z|0)==0&(y|0)==(-2147483648|0)){B=-1;C=-1}else{D=y;E=z;break}i=t;return(G=B,C)|0}else{D=n;E=m}}while(0);if(!((D|0)<(e|0)|(D|0)==(e|0)&E>>>0<d>>>0)){c[r>>2]=E;c[r+4>>2]=D;B=c[u+4>>2]|0;C=c[u>>2]|0;i=t;return(G=B,C)|0}m=c[w>>2]|0;n=c[w+4>>2]|0;do{if((m|0)==0&(n|0)==(-2147483648|0)){z=FX(a,b,w,v,s)|0;if((z|0)>=0){F=c[v+4>>2]|0;H=c[v>>2]|0;I=c[w+4>>2]|0;J=c[w>>2]|0;break}B=(z|0)<0|0?-1:0;C=z;i=t;return(G=B,C)|0}else{F=l;H=k;I=n;J=m}}while(0);if(!((I|0)>(e|0)|(I|0)==(e|0)&J>>>0>d>>>0)){c[r>>2]=J;c[r+4>>2]=I;B=c[v+4>>2]|0;C=c[v>>2]|0;i=t;return(G=B,C)|0}if((D|0)>(I|0)|(D|0)==(I|0)&E>>>0>J>>>0){B=-1;C=-1;i=t;return(G=B,C)|0}m=(E|0)==(J|0)&(D|0)==(I|0);I=c[u>>2]|0;J=c[u+4>>2]|0;n=(b|0)>-1;k=a+28|0;l=m?J:F;F=m?I:H;H=0;m=D;D=E;E=J;J=I;a:while(1){I=xrc(d,e,D,m)|0;z=G;y=l;o=F;p=H;K=E;L=J;while(1){if(!((K|0)<(y|0)|(K|0)==(y|0)&L>>>0<o>>>0)){M=44;break a}if((p|0)==1){j=wrc(L,K,o,y)|0;g=G;h=j>>>1|g<<31;j=g>>1|((g|0)<0|0?-1:0)<<31;N=j;O=h;P=j;Q=h;M=26}else if((p|0)==0){h=c[v>>2]|0;j=c[v+4>>2]|0;g=xrc(h,j,L,K)|0;A=G;f=xrc(c[w>>2]|0,c[w+4>>2]|0,D,m)|0;R=VIb(I,z,g,A,f,G)|0;f=G;A=wrc(L,K,o,y)|0;g=xrc(A,G,h,j)|0;j=wrc(g,G,R,f)|0;f=G;N=f;O=j;P=f;Q=j;M=26}else{c[x>>2]=L;c[x+4>>2]=K;M=27}do{if((M|0)==26){M=0;c[x>>2]=Q;c[x+4>>2]=P;if(!((N|0)>(K|0)|(N|0)==(K|0)&O>>>0>L>>>0)){M=27;break}if(!((N|0)>(y|0)|(N|0)==(y|0)&O>>>0>o>>>0)){S=N;T=O;break}c[x>>2]=o;c[x+4>>2]=y;S=y;T=o}}while(0);if((M|0)==27){M=0;j=wrc(L,K,1,0)|0;f=G;c[x>>2]=j;c[x+4>>2]=f;S=f;T=j}j=Xe[s&511](a,b,x,-1,2147483647)|0;f=G;do{if(n){R=c[(c[k>>2]|0)+(b<<2)>>2]|0;g=c[R+472>>2]|0;if((g|0)==0){U=f;V=j;break}h=R+464|0;A=c[h>>2]|0;W=c[h+4>>2]|0;if((A|0)==0&(W|0)==(-2147483648|0)|(j|0)==0&(f|0)==(-2147483648|0)){U=f;V=j;break}h=(W|0)>(f|0)|(W|0)==(f|0)&A>>>0>j>>>0;if((g|0)==1&h){A=yrc(1,0,c[R+188>>2]|0)|0;W=wrc(A,G,j,f)|0;U=G;V=W;break}if((g|0)!=-1|h){U=f;V=j;break}h=yrc(1,0,c[R+188>>2]|0)|0;R=xrc(j,f,h,G)|0;U=G;V=R}else{U=f;V=j}}while(0);X=c[x>>2]|0;Y=c[x+4>>2]|0;Z=(X|0)==(c[v>>2]|0)&(Y|0)==(c[v+4>>2]|0)?p+1|0:0;if((V|0)==0&(U|0)==(-2147483648|0)){M=38;break a}if((U|0)<(e|0)|(U|0)==(e|0)&V>>>0<d>>>0){_=y;$=o}else{j=wrc(T,S,-1,-1)|0;c[v>>2]=X;c[v+4>>2]=Y;c[w>>2]=V;c[w+4>>2]=U;_=G;$=j}if(!((U|0)>(e|0)|(U|0)==(e|0)&V>>>0>d>>>0)){break}y=_;o=$;p=Z;K=c[u+4>>2]|0;L=c[u>>2]|0}c[u>>2]=X;c[u+4>>2]=Y;l=_;F=$;H=Z;m=U;D=V;E=Y;J=X}if((M|0)==38){KIb(a,16,2431488,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;B=-1;C=-1;i=t;return(G=B,C)|0}else if((M|0)==44){M=(q&1|0)!=0;q=M?L:c[v>>2]|0;L=M?K:c[v+4>>2]|0;c[x>>2]=q;c[x+4>>2]=L;x=M?m:c[w+4>>2]|0;c[r>>2]=M?D:c[w>>2]|0;c[r+4>>2]=x;B=L;C=q;i=t;return(G=B,C)|0}return 0}function FX(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=iD(c[a+16>>2]|0)|0;l=G;m=wrc(k,l,-1,-1)|0;n=G;c[h>>2]=m;c[h+4>>2]=n;o=(b|0)>-1;p=a+28|0;q=0;r=1024;s=n;n=m;while(1){m=xrc(n,s,r,q)|0;t=G;u=0;v=(t|0)<(u|0)|(t|0)==(u|0)&m>>>0<0>>>0;c[h>>2]=v?0:m;c[h+4>>2]=v?0:t;t=Xe[f&511](a,b,h,n,s)|0;v=G;do{if(o){m=c[(c[p>>2]|0)+(b<<2)>>2]|0;u=c[m+472>>2]|0;if((u|0)==0){w=v;x=t;break}y=m+464|0;z=c[y>>2]|0;A=c[y+4>>2]|0;if((z|0)==0&(A|0)==(-2147483648|0)|(t|0)==0&(v|0)==(-2147483648|0)){w=v;x=t;break}y=(A|0)>(v|0)|(A|0)==(v|0)&z>>>0>t>>>0;if((u|0)==1&y){z=yrc(1,0,c[m+188>>2]|0)|0;A=wrc(z,G,t,v)|0;w=G;x=A;break}if((u|0)!=-1|y){w=v;x=t;break}y=yrc(1,0,c[m+188>>2]|0)|0;m=xrc(t,v,y,G)|0;w=G;x=m}else{w=v;x=t}}while(0);t=r<<1|0>>>31;v=q<<1|r>>>31;B=(x|0)==0&(w|0)==(-2147483648|0);m=s<<1|n>>>31;if(!(B&((m|0)>(v|0)|(m|0)==(v|0)&(n<<1|0>>>31)>>>0>t>>>0))){break}q=v;r=t;s=c[h+4>>2]|0;n=c[h>>2]|0}if(B){C=-1;i=g;return C|0}B=c[h>>2]|0;n=c[h+4>>2]|0;a:do{if(o){s=w;r=x;q=n;t=B;while(1){v=wrc(t,q,1,0)|0;c[j>>2]=v;c[j+4>>2]=G;v=Xe[f&511](a,b,j,-1,2147483647)|0;m=G;y=c[(c[p>>2]|0)+(b<<2)>>2]|0;u=c[y+472>>2]|0;do{if((u|0)==0){D=m;E=v}else{A=y+464|0;z=c[A>>2]|0;F=c[A+4>>2]|0;if((z|0)==0&(F|0)==(-2147483648|0)|(v|0)==0&(m|0)==(-2147483648|0)){D=m;E=v;break}A=(F|0)>(m|0)|(F|0)==(m|0)&z>>>0>v>>>0;if((u|0)==1&A){z=yrc(1,0,c[y+188>>2]|0)|0;F=wrc(z,G,v,m)|0;D=G;E=F;break}if((u|0)!=-1|A){D=m;E=v;break}A=yrc(1,0,c[y+188>>2]|0)|0;F=xrc(v,m,A,G)|0;D=G;E=F}}while(0);if((E|0)==0&(D|0)==(-2147483648|0)){H=s;I=r;break a}m=c[j>>2]|0;v=c[j+4>>2]|0;y=c[h+4>>2]|0;if(!((v|0)>(y|0)|(v|0)==(y|0)&m>>>0>(c[h>>2]|0)>>>0)){break}c[h>>2]=m;c[h+4>>2]=v;if((v|0)<(l|0)|(v|0)==(l|0)&m>>>0<k>>>0){s=D;r=E;q=v;t=m}else{H=D;I=E;break a}}KIb(0,0,2533912,(J=i,i=i+24|0,c[J>>2]=2444656,c[J+8>>2]=2504288,c[J+16>>2]=1937,J)|0);i=J;Hd();return 0}else{t=w;q=x;r=n;s=B;while(1){m=wrc(s,r,1,0)|0;c[j>>2]=m;c[j+4>>2]=G;m=Xe[f&511](a,b,j,-1,2147483647)|0;v=G;if((m|0)==0&(v|0)==(-2147483648|0)){H=t;I=q;break a}y=c[j>>2]|0;u=c[j+4>>2]|0;F=c[h+4>>2]|0;if(!((u|0)>(F|0)|(u|0)==(F|0)&y>>>0>(c[h>>2]|0)>>>0)){break}c[h>>2]=y;c[h+4>>2]=u;if((u|0)<(l|0)|(u|0)==(l|0)&y>>>0<k>>>0){t=v;q=m;r=u;s=y}else{H=v;I=m;break a}}KIb(0,0,2533912,(J=i,i=i+24|0,c[J>>2]=2444656,c[J+8>>2]=2504288,c[J+16>>2]=1937,J)|0);i=J;Hd();return 0}}while(0);if((d|0)!=0){c[d>>2]=I;c[d+4>>2]=H}if((e|0)==0){C=0;i=g;return C|0}H=c[h+4>>2]|0;c[e>>2]=c[h>>2];c[e+4>>2]=H;C=0;i=g;return C|0}function GX(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;g=i;i=i+160|0;h=g|0;j=g+80|0;k=a+4|0;l=c[k>>2]|0;do{if((c[l+68>>2]|0)!=0){if((c[l+52>>2]|0)!=0){break}m=(f&1|0)==0;n=HX(a,b,m?d:0,m?e:-2147483648,d,e,m?-1:d,m?2147483647:e,f&-2)|0;i=g;return n|0}}while(0);a:do{if((f&2|0)==0){if((b|0)<0){m=c[a+24>>2]|0;if((m|0)==0){n=-1;i=g;return n|0}o=c[a+28>>2]|0;p=-1;q=0;while(1){r=c[o+(q<<2)>>2]|0;s=c[(c[r+8>>2]|0)+8>>2]|0;if((s|0)==0){if((c[r+72>>2]&1024|0)==0){t=18;break}}if((p|0)<0){u=(s|0)==1?q:p}else{u=p}s=q+1|0;if(s>>>0<m>>>0){p=u;q=s}else{t=17;break}}do{if((t|0)==17){p=(u|0)<0?0:u;v=p;w=c[o+(p<<2)>>2]|0}else if((t|0)==18){if((q|0)<0){n=-1}else{v=q;w=r;break}i=g;return n|0}}while(0);q=c[w+44>>2]|0;o=c[w+40>>2]|0;p=Erc(o,(o|0)<0|0?-1:0,1e6,0)|0;o=VIb(d,e,q,(q|0)<0|0?-1:0,p,G)|0;x=v;y=G;z=o}else{x=b;y=e;z=d}if((c[l+52>>2]|0)==0){A=l}else{yX(a);if((Xe[c[(c[k>>2]|0)+52>>2]&511](a,x,z,y,f)|0)>-1){break}A=c[k>>2]|0}o=c[A+8>>2]|0;do{if((c[A+56>>2]|0)==0){t=26}else{if((o&8192|0)!=0){t=26;break}yX(a);B=DX(a,x,z,y,f)|0}}while(0);b:do{if((t|0)==26){if((o&16384|0)!=0){n=-1;i=g;return n|0}yX(a);p=a+28|0;q=c[(c[p>>2]|0)+(x<<2)>>2]|0;m=q+400|0;s=c[m>>2]|0;C=q+404|0;D=c[C>>2]|0;E=(D|0)==0;if(E){F=0;H=-1}else{I=D-1|0;J=s+(I*24|0)+8|0;K=c[J+4>>2]|0;F=D;H=(K|0)<(y|0)|(K|0)==(y|0)&(c[J>>2]|0)>>>0<z>>>0?I:-1}if((F-H|0)>1){I=H;J=F;while(1){K=I+J>>1;L=s+(K*24|0)+8|0;M=c[L>>2]|0;N=c[L+4>>2]|0;L=(N|0)<(y|0)|(N|0)==(y|0)&M>>>0<z>>>0?J:K;O=(N|0)>(y|0)|(N|0)==(y|0)&M>>>0>z>>>0?I:K;if((L-O|0)>1){I=O;J=L}else{P=O;Q=L;break}}}else{P=H;Q=F}J=f&1;I=(J|0)!=0;L=I?P:Q;O=(f&4|0)==0;c:do{if(O){if(!((L|0)>-1&(L|0)<(D|0))){R=L;break}K=(J<<1^2)-1|0;M=L;while(1){if((c[s+(M*24|0)+16>>2]&1|0)!=0){R=M;break c}N=K+M|0;if((N|0)>-1&(N|0)<(D|0)){M=N}else{R=N;break}}}else{R=L}}while(0);L=(R|0)==(D|0)?-1:R;do{if((L|0)<0){if(E){t=49;break}M=s+8|0;K=c[M+4>>2]|0;if((K|0)>(y|0)|(K|0)==(y|0)&(c[M>>2]|0)>>>0>z>>>0){n=-1}else{t=41;break}i=g;return n|0}else{if((L|0)!=(D-1|0)){S=L;break}if(E){t=49}else{t=41}}}while(0);do{if((t|0)==41){if((s|0)==0){KIb(0,0,2533912,(T=i,i=i+24|0,c[T>>2]=2565632,c[T+8>>2]=2504288,c[T+16>>2]=2103,T)|0);i=T;Hd();return 0}E=D-1|0;L=s+(E*24|0)|0;M=fD(c[a+16>>2]|0,c[L>>2]|0,c[L+4>>2]|0,0)|0;L=G;K=0;if((L|0)<(K|0)|(L|0)==(K|0)&M>>>0<0>>>0){B=M;break b}M=s+(E*24|0)+8|0;E=c[M>>2]|0;K=c[M+4>>2]|0;M=c[a+24>>2]|0;if((M|0)==0){t=48;break}L=c[p>>2]|0;N=c[q+40>>2]|0;U=N;V=(N|0)<0|0?-1:0;N=c[q+44>>2]|0;W=N;X=(N|0)<0|0?-1:0;N=0;while(1){Y=c[L+(N<<2)>>2]|0;Z=c[Y+44>>2]|0;_=Erc(Z,(Z|0)<0|0?-1:0,U,V)|0;Z=G;$=c[Y+40>>2]|0;aa=Erc($,($|0)<0|0?-1:0,W,X)|0;$=VIb(E,K,_,Z,aa,G)|0;aa=Y+208|0;c[aa>>2]=$;c[aa+4>>2]=G;aa=N+1|0;if(aa>>>0<M>>>0){N=aa}else{t=48;break}}}else if((t|0)==49){N=a+1248|0;M=fD(c[a+16>>2]|0,c[N>>2]|0,c[N+4>>2]|0,0)|0;N=G;K=0;if(!((N|0)<(K|0)|(N|0)==(K|0)&M>>>0<0>>>0)){t=48;break}B=M;break b}}while(0);do{if((t|0)==48){s=h+32|0;D=h+16|0;M=h+36|0;K=q+8|0;N=0;d:while(1){while(1){E=uX(a,h)|0;if((E|0)==-11){continue}if((E|0)<0){break d}P1(h);if((c[s>>2]|0)!=(x|0)){continue}E=c[D+4>>2]|0;if((E|0)>(y|0)|(E|0)==(y|0)&(c[D>>2]|0)>>>0>z>>>0){break}}if((c[M>>2]&1|0)!=0){break}ba=N+1|0;if((N|0)<=1e3){N=ba;continue}if((c[(c[K>>2]|0)+48>>2]|0)==133){N=ba}else{t=59;break}}if((t|0)==59){KIb(a,16,2562208,(T=i,i=i+8|0,c[T>>2]=ba,T)|0);i=T}N=c[m>>2]|0;K=c[C>>2]|0;if((K|0)==0){ca=0;da=-1}else{M=K-1|0;D=N+(M*24|0)+8|0;s=c[D+4>>2]|0;ca=K;da=(s|0)<(y|0)|(s|0)==(y|0)&(c[D>>2]|0)>>>0<z>>>0?M:-1}if((ca-da|0)>1){M=da;D=ca;while(1){s=M+D>>1;E=N+(s*24|0)+8|0;X=c[E>>2]|0;W=c[E+4>>2]|0;E=(W|0)<(y|0)|(W|0)==(y|0)&X>>>0<z>>>0?D:s;V=(W|0)>(y|0)|(W|0)==(y|0)&X>>>0>z>>>0?M:s;if((E-V|0)>1){M=V;D=E}else{ea=V;fa=E;break}}}else{ea=da;fa=ca}D=I?ea:fa;e:do{if(O){if(!((D|0)>-1&(D|0)<(K|0))){ga=D;break}M=(J<<1^2)-1|0;E=D;while(1){if((c[N+(E*24|0)+16>>2]&1|0)!=0){ga=E;break e}V=M+E|0;if((V|0)>-1&(V|0)<(K|0)){E=V}else{ga=V;break}}}else{ga=D}}while(0);D=(ga|0)==(K|0)?-1:ga;if((D|0)<0){n=-1}else{S=D;break}i=g;return n|0}}while(0);yX(a);J=c[(c[k>>2]|0)+52>>2]|0;if((J|0)!=0){if((Xe[J&511](a,x,z,y,f)|0)>-1){break a}}J=c[m>>2]|0;O=J+(S*24|0)|0;I=fD(c[a+16>>2]|0,c[O>>2]|0,c[O+4>>2]|0,0)|0;O=G;C=0;if((O|0)<(C|0)|(O|0)==(C|0)&I>>>0<0>>>0){B=I;break}I=J+(S*24|0)+8|0;J=c[I>>2]|0;C=c[I+4>>2]|0;I=c[a+24>>2]|0;if((I|0)==0){break a}O=c[p>>2]|0;D=c[q+40>>2]|0;N=D;E=(D|0)<0|0?-1:0;D=c[q+44>>2]|0;M=D;V=(D|0)<0|0?-1:0;D=0;while(1){s=c[O+(D<<2)>>2]|0;X=c[s+44>>2]|0;W=Erc(X,(X|0)<0|0?-1:0,N,E)|0;X=G;U=c[s+40>>2]|0;L=Erc(U,(U|0)<0|0?-1:0,M,V)|0;U=VIb(J,C,W,X,L,G)|0;L=s+208|0;c[L>>2]=U;c[L+4>>2]=G;D=D+1|0;if(!(D>>>0<I>>>0)){break a}}}}while(0);if((B|0)>-1){break}else{n=B}i=g;return n|0}else{if((c[l+8>>2]&32768|0)!=0){n=-1;i=g;return n|0}yX(a);o=a+1248|0;I=c[o>>2]|0;D=c[o+4>>2]|0;o=a+16|0;C=iD(c[o>>2]|0)|0;J=wrc(C,G,-1,-1)|0;C=G;if((D|0)>(e|0)|(D|0)==(e|0)&I>>>0>d>>>0){ha=D;ia=I}else{I=(C|0)<(e|0)|(C|0)==(e|0)&J>>>0<d>>>0;ha=I?C:e;ia=I?J:d}fD(c[o>>2]|0,ia,ha,0)|0;c[a+1300>>2]=1}}while(0);ha=j|0;j=a+24|0;if((c[j>>2]|0)==0){n=0;i=g;return n|0}ia=a+28|0;d=a+1256|0;e=a+1260|0;a=0;f:while(1){l=c[(c[ia>>2]|0)+(a<<2)>>2]|0;do{if((c[l+72>>2]&1024|0)!=0){if((c[l+76>>2]|0)>=48){break}B=c[l+104>>2]|0;nrc(ha|0,l+108|0,76)|0;S=eGb(B)|0;if((S|0)==0){n=-12;t=89;break f}B=pJb(88)|0;f=B;if((B|0)==0){break}if((c[d>>2]|0)==0){c[d>>2]=f}else{c[(c[e>>2]|0)+80>>2]=f}c[e>>2]=f;c[B>>2]=S;nrc(B+4|0,ha|0,76)|0}}while(0);l=a+1|0;if(l>>>0<(c[j>>2]|0)>>>0){a=l}else{n=0;t=89;break}}if((t|0)==89){i=g;return n|0}return 0}function HX(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;l=i;i=i+88|0;m=l|0;n=l+80|0;o=n;p=i;i=i+8|0;if((e|0)>(g|0)|(e|0)==(g|0)&d>>>0>f>>>0|((j|0)<(g|0)|(j|0)==(g|0)&h>>>0<f>>>0)){q=-1;i=l;return q|0}if((b|0)<-1){q=-22;i=l;return q|0}r=a+24|0;if((c[r>>2]|0)<=(b|0)){q=-22;i=l;return q|0}s=((c[a+1224>>2]|0)>0?k|4:k)&-2;k=a+4|0;if((c[(c[k>>2]|0)+68>>2]|0)==0){t=xrc(f,g,d,e)|0;u=G;v=xrc(h,j,f,g)|0;w=G;x=u>>>0>w>>>0|u>>>0==w>>>0&t>>>0>v>>>0;v=s|x&1;t=GX(a,b,f,g,v)|0;if((t|0)>-1|(f|0)==(d|0)&(g|0)==(e|0)|(h|0)==(f|0)&(j|0)==(g|0)){q=t;i=l;return q|0}t=GX(a,b,x?h:d,x?j:e,v)|0;if(!((t|0)>-1)){q=t;i=l;return q|0}q=GX(a,b,f,g,v^1)|0;i=l;return q|0}yX(a);do{if((b|0)==-1){if((c[r>>2]|0)!=1){y=j;z=h;A=g;B=f;C=e;D=d;break}v=(c[c[a+28>>2]>>2]|0)+40|0;t=c[v+4>>2]|0;c[n>>2]=c[v>>2];c[n+4>>2]=t;c[p>>2]=1;c[p+4>>2]=1e6;t=XIb(f,g,p,o)|0;v=G;x=c[o+4>>2]|0;w=x;u=(x|0)<0|0?-1:0;x=c[n>>2]|0;E=Erc(x,(x|0)<0|0?-1:0,1e6,0)|0;x=G;F=UIb(d,e,w,u,E,x,8195)|0;H=G;I=UIb(h,j,w,u,E,x,8194)|0;y=G;z=I;A=v;B=t;C=H;D=F}else{y=j;z=h;A=g;B=f;C=e;D=d}}while(0);d=Ke[c[(c[k>>2]|0)+68>>2]&63](a,b,D,C,B,A,z,y,s)|0;if(!((d|0)>-1)){q=d;i=l;return q|0}d=m|0;if((c[r>>2]|0)==0){q=0;i=l;return q|0}m=a+28|0;s=a+1256|0;y=a+1260|0;a=0;a:while(1){z=c[(c[m>>2]|0)+(a<<2)>>2]|0;do{if((c[z+72>>2]&1024|0)!=0){if((c[z+76>>2]|0)>=48){break}A=c[z+104>>2]|0;nrc(d|0,z+108|0,76)|0;B=eGb(A)|0;if((B|0)==0){q=-12;J=23;break a}A=pJb(88)|0;C=A;if((A|0)==0){break}if((c[s>>2]|0)==0){c[s>>2]=C}else{c[(c[y>>2]|0)+80>>2]=C}c[y>>2]=C;c[A>>2]=B;nrc(A+4|0,d|0,76)|0}}while(0);z=a+1|0;if(z>>>0<(c[r>>2]|0)>>>0){a=z}else{q=0;J=23;break}}if((J|0)==23){i=l;return q|0}return 0}function IX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a;while(1){a=c[d>>2]|0;if((a|0)==0){e=0;f=5;break}if((a|0)==(b|0)){break}else{d=d+8|0}}if((f|0)==5){return e|0}e=c[d+4>>2]|0;return e|0}function JX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=0;while(1){e=c[a+(d<<3)>>2]|0;if((e|0)==0){f=0;break}if((c[a+(d<<3)+4>>2]|0)==(b|0)){g=e;h=7;break}else{d=d+1|0}}if((h|0)==7){return g|0}while(1){i=a+(f<<3)|0;if((c[i>>2]|0)==0){g=0;h=7;break}d=F5a(b)|0;if((d|0)==(F5a(c[a+(f<<3)+4>>2]|0)|0)){break}else{f=f+1|0}}if((h|0)==7){return g|0}g=c[i>>2]|0;return g|0}function KX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;do{if((b|0)==0){e=a+7>>3;if((1<<e-1&d|0)==0){if((e|0)==2){f=(c|0)!=0?65539:65538;break}else if((e|0)==3){f=(c|0)!=0?65551:65550;break}else if((e|0)==4){f=(c|0)!=0?65547:65546;break}else if((e|0)==1){f=65541;break}else{f=0;break}}else{if((e|0)==3){f=(c|0)!=0?65549:65548;break}else if((e|0)==2){f=(c|0)!=0?65537:65536;break}else if((e|0)==4){f=(c|0)!=0?65545:65544;break}else if((e|0)==1){f=65540;break}else{f=0;break}}}else{if((a|0)==32){f=(c|0)!=0?65556:65557;break}else if((a|0)==64){f=(c|0)!=0?65558:65559;break}else{f=0;break}}}while(0);return f|0}function LX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)==0){d=0;return d|0}e=c[a>>2]|0;if((e|0)==0){d=0;return d|0}else{f=0;g=e}a:while(1){h=g;while(1){e=c[h>>2]|0;if((e|0)==0){break}if((e|0)==(b|0)){break a}else{h=h+8|0}}e=f+1|0;i=c[a+(e<<2)>>2]|0;if((i|0)==0){d=0;j=8;break}else{f=e;g=i}}if((j|0)==8){return d|0}d=c[h+4>>2]|0;return d|0}function MX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a|0)==0){e=0;return e|0}else{f=0}a:while(1){g=c[a+(f<<2)>>2]|0;if((g|0)==0){e=0;h=7;break}else{i=g}while(1){g=c[i>>2]|0;if((g|0)==0){break}if((g|0)==(b|0)){break a}else{i=i+8|0}}f=f+1|0}if((h|0)==7){return e|0}c[d>>2]=c[i+4>>2];e=1;return e|0}function NX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){d=0;return d|0}else{e=0}while(1){f=c[a+(e<<2)>>2]|0;if((f|0)==0){d=0;g=10;break}else{h=0}while(1){i=c[f+(h<<3)>>2]|0;if((i|0)==0){j=0;g=5;break}if((c[f+(h<<3)+4>>2]|0)==(b|0)){k=i;g=8;break}else{h=h+1|0}}a:do{if((g|0)==5){while(1){g=0;l=f+(j<<3)|0;if((c[l>>2]|0)==0){break a}i=F5a(b)|0;if((i|0)==(F5a(c[f+(j<<3)+4>>2]|0)|0)){break}else{j=j+1|0;g=5}}k=c[l>>2]|0;g=8}}while(0);if((g|0)==8){g=0;if((k|0)!=0){d=k;g=10;break}}e=e+1|0}if((g|0)==10){return d|0}return 0}function OX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0.0,qb=0.0,rb=0,sb=0.0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0;d=i;i=i+664|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+136|0;o=d+160|0;p=d+168|0;q=d+176|0;r=d+256|0;s=d+264|0;t=d+272|0;u=d+280|0;v=d+288|0;w=d+296|0;x=d+304|0;y=d+312|0;z=d+320|0;A=d+400|0;B=d+408|0;C=a+16|0;D=fD(c[C>>2]|0,0,0,1)|0;E=G;F=a+24|0;H=c[F>>2]|0;I=a+1088|0;J=(c[I>>2]|0)==0;K=c[C>>2]|0;if((K|0)==0){L=H}else{M=fD(K,0,0,1)|0;K=G;N=c[C>>2]|0;O=N+112|0;P=c[O>>2]|0;Q=c[O+4>>2]|0;O=c[N+120>>2]|0;KIb(a,48,2404656,(S=i,i=i+40|0,c[S>>2]=M,c[S+8>>2]=K,c[S+16>>2]=P,c[S+24>>2]=Q,c[S+32>>2]=O,S)|0);i=S;L=c[F>>2]|0}do{if((L|0)==0){T=6}else{O=a+28|0;Q=a+1084|0;P=a;K=a+1304|0;M=a+1308|0;N=a+1312|0;U=(b|0)!=0;V=0;do{c[r>>2]=0;W=c[(c[O>>2]|0)+(V<<2)>>2]|0;X=W+8|0;Y=c[X>>2]|0;Z=c[Y+8>>2]|0;do{if((Z|0)==0|(Z|0)==3){_=Y+104|0;if((c[_>>2]|0)!=0){break}$=W+40|0;aa=_;_=c[$+4>>2]|0;c[aa>>2]=c[$>>2];c[aa+4>>2]=_}}while(0);Y=W+240|0;do{if((c[Y>>2]|0)==0){if((c[Q>>2]&32|0)!=0){break}Z=DWa(c[(c[X>>2]|0)+48>>2]|0)|0;c[Y>>2]=Z;_=c[W+236>>2]|0;if((Z|0)==0){if((_|0)==0){break}aa=u5a(c[(c[X>>2]|0)+48>>2]|0)|0;KIb(P,40,2397248,(S=i,i=i+8|0,c[S>>2]=aa,S)|0);i=S;break}if((_|0)==1463898624){aa=Z+176|0;c[aa>>2]=c[aa>>2]|4096;break}else if((_|0)==2){_=Z+176|0;c[_>>2]=c[_>>2]|1;break}else{break}}}while(0);Y=c[X>>2]|0;_=c[Y+48>>2]|0;Z=c[Y+12>>2]|0;do{if((Z|0)==0){aa=c[Y+8>>2]|0;if((aa|0)==1){$=c[M>>2]|0;if(($|0)!=0){ba=$;break}}else if((aa|0)==0){$=c[K>>2]|0;if(($|0)!=0){ba=$;break}}else if((aa|0)==3){aa=c[N>>2]|0;if((aa|0)!=0){ba=aa;break}}ba=c5a(_)|0}else{ba=Z}}while(0);if(U){da=b+(V<<2)|0}else{da=r}MGb(da,2390272,2383400,0)|0;Z=c[X>>2]|0;_=(ba|0)==0;do{if(!((c[Z+8>>2]|0)!=3|_)){if((c[Z+12>>2]|0)!=0){break}if(U){ea=b+(V<<2)|0}else{ea=r}if((_4a(Z,ba,ea)|0)>=0){break}KIb(P,24,2376568,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);do{if((TX(W,0)|0)==0){if((c[W+440>>2]|0)>0|_){break}Z=c[X>>2]|0;if((c[Z+12>>2]|0)!=0){break}if(U){fa=b+(V<<2)|0}else{fa=r}if((_4a(Z,ba,fa)|0)>=0){break}KIb(P,24,2376568,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);if(!U){OGb(r)}V=V+1|0;ga=c[F>>2]|0;}while(V>>>0<ga>>>0);if((ga|0)==0){T=6;break}V=a+28|0;U=c[V>>2]|0;P=0;while(1){N=c[(c[U+(P<<2)>>2]|0)+184>>2]|0;K=N|0;c[K>>2]=0;c[K+4>>2]=-2147483648;K=N+72|0;c[K>>2]=0;c[K+4>>2]=-2147483648;K=N+88|0;c[K>>2]=0;c[K+4>>2]=-2147483648;K=P+1|0;if(K>>>0<ga>>>0){P=K}else{ha=V;break}}}}while(0);if((T|0)==6){ha=a+28|0}ga=a+1160|0;r=a+20|0;fa=a+1152|0;ba=a+1084|0;ea=a+1236|0;da=a+1240|0;L=q;V=s|0;P=s+4|0;U=t|0;K=t+4|0;N=u|0;M=u+4|0;Q=v|0;O=v+4|0;X=w|0;_=w+4|0;W=x|0;Z=x+4|0;Y=y|0;aa=y+4|0;$=a+1092|0;ia=(b|0)!=0;ja=a;ka=o;la=0;ma=0;na=0;a:while(1){do{if((YC(ga)|0)!=0){T=47;break a}if((c[F>>2]|0)==0){oa=0;T=64}else{pa=0;b:while(1){qa=c[(c[ha>>2]|0)+(pa<<2)>>2]|0;if((TX(qa,0)|0)==0){T=62;break}ra=c[fa>>2]|0;sa=(c[qa+72>>2]&1024|0)==0?(ra|0)>-1?ra:+(c[qa+40>>2]|0)/+(c[qa+44>>2]|0)>5.0e-4?40:20:0;ra=c[qa+8>>2]|0;ta=c[ra+108>>2]|0;ua=c[ra+104>>2]|0;do{if((ta|0)>=(ua*101|0|0)|(ta|0)<(ua*5|0|0)){T=52}else{if((c[ra+52>>2]|0)==1983148141){T=52;break}va=c[ra+48>>2]|0;if((va|0)==2|(va|0)==28){T=52}}}while(0);do{if((T|0)==52){T=0;if((c[qa+412>>2]|0)!=0){if((c[qa+92>>2]|0)!=0){break}}if((c[(c[qa+184>>2]|0)+16>>2]|0)>=(sa|0)){break}if((c[ra+8>>2]|0)==0){T=62;break b}}}while(0);sa=c[qa+240>>2]|0;do{if((sa|0)!=0){if((c[(c[sa+4>>2]|0)+36>>2]|0)==0){break}if((c[ra+96>>2]|0)==0){T=62;break b}}}while(0);sa=qa+200|0;if((c[sa>>2]|0)==0&(c[sa+4>>2]|0)==(-2147483648|0)){if((c[ra+8>>2]|0)>>>0<2>>>0){T=62;break}}sa=pa+1|0;ua=c[F>>2]|0;if(sa>>>0<ua>>>0){pa=sa}else{wa=sa;xa=ua;break}}if((T|0)==62){T=0;wa=pa;xa=c[F>>2]|0}if((wa|0)==(xa|0)){oa=wa;T=64}else{ya=wa}}if((T|0)==64){T=0;if((c[r>>2]&1|0)==0){T=65;break a}else{ya=oa}}za=c[I>>2]|0;ua=0;if(!((ma|0)<(ua|0)|(ma|0)==(ua|0)&na>>>0<za>>>0)){T=67;break a}Aa=vX(a,q)|0;}while((Aa|0)==-11);if((Aa|0)<0){Ba=Aa;T=130;break}if((c[ba>>2]&64|0)!=0){ua=c[ea>>2]|0;if((ua|0)!=0){sa=ua;do{c[o>>2]=sa;c[ea>>2]=c[sa+80>>2];P1(sa|0);mJb(ka);sa=c[ea>>2]|0;}while((sa|0)!=0)}c[da>>2]=0}sa=pJb(88)|0;ua=sa;if((sa|0)==0){Ca=-12;break}if((c[ea>>2]|0)==0){c[ea>>2]=ua}else{c[(c[da>>2]|0)+80>>2]=ua}c[da>>2]=ua;ua=sa;nrc(sa|0,L|0,80)|0;Da=Q1(ua)|0;if((Da|0)<0){Ca=Da;break}ta=c[(c[ha>>2]|0)+(c[sa+32>>2]<<2)>>2]|0;if((c[ta+72>>2]&1024|0)==0){va=c[sa+28>>2]|0;Ea=wrc(va,(va|0)<0|0?-1:0,na,ma)|0;Fa=G;Ga=Ea}else{Fa=ma;Ga=na}Ea=sa+16|0;va=c[Ea>>2]|0;Ha=c[Ea+4>>2]|0;Ia=ta+232|0;do{if(!((va|0)==0&(Ha|0)==(-2147483648|0))){Ja=c[Ia>>2]|0;if((Ja|0)<=1){break}Ka=ta+184|0;La=c[Ka>>2]|0;Ma=La+88|0;Na=c[Ma>>2]|0;Oa=c[Ma+4>>2]|0;do{if((Na|0)==0&(Oa|0)==(-2147483648|0)|((Oa|0)<(Ha|0)|(Oa|0)==(Ha|0)&Na>>>0<va>>>0)){if((Na|0)==0&(Oa|0)==(-2147483648|0)){Pa=La;break}Ma=c[La+96>>2]|0;Qa=c[La+80>>2]|0;if((Ma|0)<=(Qa|0)){Pa=La;break}Ra=c[Ea>>2]|0;Sa=c[Ea+4>>2]|0;Ta=xrc(Ra,Sa,Na,Oa)|0;Ua=Crc(Ta,G,1e3,0)|0;Ta=G;Va=La+72|0;Wa=xrc(Na,Oa,c[Va>>2]|0,c[Va+4>>2]|0)|0;Va=Ma-Qa|0;Qa=Crc(Wa,G,Va,(Va|0)<0|0?-1:0)|0;Va=G;if(!((Ta|0)>(Va|0)|(Ta|0)==(Va|0)&Ua>>>0>Qa>>>0)){Pa=La;break}Qa=c[Ia>>2]|0;KIb(ja,24,2323368,(S=i,i=i+56|0,c[S>>2]=c[ta>>2],c[S+8>>2]=Ma,c[S+16>>2]=Na,c[S+24>>2]=Oa,c[S+32>>2]=Qa,c[S+40>>2]=Ra,c[S+48>>2]=Sa,S)|0);i=S;Sa=c[Ka>>2]|0;Ra=Sa+88|0;c[Ra>>2]=0;c[Ra+4>>2]=-2147483648;Ra=Sa+72|0;c[Ra>>2]=0;c[Ra+4>>2]=-2147483648;Pa=Sa}else{Sa=c[La+96>>2]|0;KIb(ja,48,2329408,(S=i,i=i+56|0,c[S>>2]=c[ta>>2],c[S+8>>2]=Sa,c[S+16>>2]=Na,c[S+24>>2]=Oa,c[S+32>>2]=Ja,c[S+40>>2]=va,c[S+48>>2]=Ha,S)|0);i=S;Sa=c[Ka>>2]|0;Ra=Sa+88|0;c[Ra>>2]=0;c[Ra+4>>2]=-2147483648;Ra=Sa+72|0;c[Ra>>2]=0;c[Ra+4>>2]=-2147483648;Pa=Sa}}while(0);Ka=Pa+72|0;if((c[Ka>>2]|0)==0&(c[Ka+4>>2]|0)==(-2147483648|0)){Ja=c[Ea+4>>2]|0;c[Ka>>2]=c[Ea>>2];c[Ka+4>>2]=Ja;c[Pa+80>>2]=c[Ia>>2]}Ja=c[Ea+4>>2]|0;Ka=Pa+88|0;c[Ka>>2]=c[Ea>>2];c[Ka+4>>2]=Ja;c[Pa+96>>2]=c[Ia>>2]}}while(0);do{if((c[Ia>>2]|0)>1){Ha=ta+40|0;if((c[ta+44>>2]|0)>0){va=(c[ta+184>>2]|0)+40|0;Ja=c[va>>2]|0;Ka=c[va+4>>2]|0;c[V>>2]=1;c[P>>2]=1e6;va=XIb(Ja,Ka,Ha,s)|0;Xa=G;Ya=va}else{Xa=0;Ya=0}va=ta+92|0;Ka=c[va>>2]|0;do{if((Ka|0)>0){Ja=c[Ia>>2]|0;Oa=ta+96|0;c[U>>2]=c[Oa>>2];c[K>>2]=Ka;c[N>>2]=1;c[M>>2]=1e6;Na=XIb(Ja,(Ja|0)<0|0?-1:0,t,u)|0;Ja=G;if((Xa|0)>(Ja|0)|(Xa|0)==(Ja|0)&Ya>>>0>Na>>>0){Za=Xa;_a=Ya;break}Na=c[Ia>>2]|0;Ja=c[va>>2]|0;c[Q>>2]=c[Oa>>2];c[O>>2]=Ja;c[X>>2]=1;c[_>>2]=1e6;Ja=XIb(Na,(Na|0)<0|0?-1:0,v,w)|0;Za=G;_a=Ja}else{Za=Xa;_a=Ya}}while(0);do{if((_a|0)==0&(Za|0)==0){if((c[Ia>>2]|0)<=30){$a=0;ab=0;break}va=ta+184|0;Ka=c[va>>2]|0;Ja=Ka+72|0;Na=c[Ja>>2]|0;Oa=c[Ja+4>>2]|0;if((Na|0)==0&(Oa|0)==(-2147483648|0)){$a=0;ab=0;break}Ja=Ka+88|0;Ka=c[Ja>>2]|0;La=c[Ja+4>>2]|0;if((Ka|0)==0&(La|0)==(-2147483648|0)){$a=0;ab=0;break}Ja=xrc(Ka,La,Na,Oa)|0;c[W>>2]=1;c[Z>>2]=1e6;Oa=XIb(Ja,G,Ha,x)|0;Ja=G;Na=0;if((Ja|0)<(Na|0)|(Ja|0)==(Na|0)&Oa>>>0<0>>>0){$a=0;ab=0;break}Oa=c[va>>2]|0;va=Oa+88|0;Na=Oa+72|0;Oa=xrc(c[va>>2]|0,c[va+4>>2]|0,c[Na>>2]|0,c[Na+4>>2]|0)|0;c[Y>>2]=1;c[aa>>2]=1e6;Na=XIb(Oa,G,Ha,y)|0;$a=G;ab=Na}else{$a=Za;ab=_a}}while(0);bb=c[$>>2]|0;Ha=(bb|0)<0|0?-1:0;if(!(($a|0)<(Ha|0)|($a|0)==(Ha|0)&ab>>>0<bb>>>0)){T=112;break a}Ha=c[sa+48>>2]|0;if((Ha|0)==0){break}Na=c[ta+184>>2]|0;Oa=Na+40|0;va=wrc(c[Oa>>2]|0,c[Oa+4>>2]|0,Ha,(Ha|0)<0|0?-1:0)|0;c[Oa>>2]=va;c[Oa+4>>2]=G;Oa=c[ta+240>>2]|0;do{if((Oa|0)==0){cb=0;db=2}else{if((c[ta+236>>2]|0)==0){cb=0;db=2;break}if((c[(c[ta+8>>2]|0)+112>>2]|0)!=2){cb=0;db=2;break}va=(c[Oa+36>>2]|0)+1|0;cb=(va|0)<0|0?-1:0;db=va}}while(0);Oa=Na+48|0;va=wrc(c[Oa>>2]|0,c[Oa+4>>2]|0,db,cb)|0;c[Oa>>2]=va;c[Oa+4>>2]=G}}while(0);RX(0,ta,c[Ea>>2]|0,c[Ea+4>>2]|0)|0;Oa=c[ta+240>>2]|0;do{if((Oa|0)!=0){va=c[(c[Oa+4>>2]|0)+36>>2]|0;if((va|0)==0){break}Ha=ta+8|0;Ja=c[Ha>>2]|0;if((c[Ja+96>>2]|0)!=0){break}La=sa+24|0;Ka=Ee[va&511](Ja,c[La>>2]|0,c[sa+28>>2]|0)|0;if(!((Ka-1|0)>>>0<268435439>>>0)){break}eb=c[Ha>>2]|0;Ja=hJb(Ka+16|0)|0;c[eb+96>>2]=Ja;if((Ja|0)==0){T=124;break a}mrc(Ja+Ka|0,0,16)|0;c[eb+100>>2]=Ka;Ka=c[Ha>>2]|0;nrc(c[Ka+96>>2]|0,c[La>>2]|0,c[Ka+100>>2]|0)|0}}while(0);if(ia&(ya|0)<(H|0)){fb=b+(ya<<2)|0}else{fb=0}UX(a,ta,ua,fb)|0;c[Ia>>2]=(c[Ia>>2]|0)+1;la=la+1|0;ma=Fa;na=Ga}do{if((T|0)==47){KIb(ja,48,2370392,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;Ba=-1414092869;T=130}else if((T|0)==65){KIb(ja,48,2355800,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;gb=la;T=131}else if((T|0)==67){KIb(ja,48,2346328,(S=i,i=i+8|0,c[S>>2]=za,S)|0);i=S;Ga=c[F>>2]|0;if((Ga|0)==0){Ba=la;T=130;break}na=a+4|0;Fa=0;ma=Ga;while(1){Ga=c[(c[ha>>2]|0)+(Fa<<2)>>2]|0;do{if((c[Ga+412>>2]|0)==0){if((c[(c[Ga+184>>2]|0)+16>>2]|0)>=2){hb=ma;break}if((c[(c[Ga+8>>2]|0)+8>>2]|0)!=0){hb=ma;break}if((irc(c[c[na>>2]>>2]|0,2340264)|0)==0){hb=ma;break}KIb(ja,24,2334440,(S=i,i=i+8|0,c[S>>2]=Fa,S)|0);i=S;hb=c[F>>2]|0}else{hb=ma}}while(0);Ga=Fa+1|0;if(Ga>>>0<hb>>>0){Fa=Ga;ma=hb}else{Ba=la;T=130;break}}}else if((T|0)==112){KIb(ja,40,2318416,(S=i,i=i+24|0,c[S>>2]=bb,c[S+8>>2]=ab,c[S+16>>2]=$a,S)|0);i=S;Ba=Da;T=130}else if((T|0)==124){c[eb+100>>2]=0;ib=-12;i=d;return ib|0}}while(0);do{if((T|0)==130){if(J){gb=Ba;T=131;break}mrc(z|0,0,80)|0;J1(z);if((c[F>>2]|0)==0){jb=Ba;T=142;break}else{kb=0}while(1){eb=c[(c[ha>>2]|0)+(kb<<2)>>2]|0;c:do{if((c[(c[eb+184>>2]|0)+56>>2]|0)==1){Da=ia&(kb|0)<(H|0);$a=b+(kb<<2)|0;while(1){lb=UX(a,eb,z,Da?$a:0)|0;if((lb|0)<=0){break}if((TX(eb,0)|0)!=0){break c}}if((lb|0)>=0){break}KIb(ja,32,2313456,(S=i,i=i+8|0,c[S>>2]=c[eb>>2],S)|0);i=S}}while(0);eb=kb+1|0;$a=c[F>>2]|0;if(eb>>>0<$a>>>0){kb=eb}else{mb=Ba;nb=$a;T=132;break}}}}while(0);if((T|0)==131){mb=gb;nb=c[F>>2]|0;T=132}do{if((T|0)==132){if((nb|0)==0){jb=mb;T=142;break}else{ob=0}while(1){r5a(c[(c[(c[ha>>2]|0)+(ob<<2)>>2]|0)+8>>2]|0)|0;gb=ob+1|0;if(gb>>>0<(c[F>>2]|0)>>>0){ob=gb}else{jb=mb;T=142;break}}}}while(0);do{if((T|0)==142){SX(a);if((c[F>>2]|0)!=0){mb=n|0;ob=n+4|0;nb=n+8|0;gb=n+12|0;Ba=n+16|0;kb=n+20|0;lb=0;do{z=c[(c[ha>>2]|0)+(lb<<2)>>2]|0;b=z+8|0;H=c[b>>2]|0;ia=c[H+8>>2]|0;d:do{if((ia|0)==0){do{if((c[H+48>>2]|0)==14){if((c[H+52>>2]|0)!=0){break}if((c[H+792>>2]|0)!=0){break}J=hZa(c[H+140>>2]|0)|0;$a=Q4a(1317528,J)|0;eb=c[b>>2]|0;if(($a|0)!=(c[eb+140>>2]|0)){break}c[eb+52>>2]=J}}while(0);J=c[z+184>>2]|0;eb=J+48|0;$a=c[eb>>2]|0;Da=c[eb+4>>2]|0;do{if(!(($a|0)==0&(Da|0)==0)){eb=z+92|0;if((c[eb>>2]|0)!=0){break}ra=J+40|0;qa=c[ra>>2]|0;ab=c[ra+4>>2]|0;if((qa|0)==0&(ab|0)==0){break}ra=c[z+40>>2]|0;bb=ra;hb=(ra|0)<0|0?-1:0;ra=Crc(-1,2147483647,bb,hb)|0;za=Crc(ra,G,2,0)|0;ra=G;if(!((ab|0)<(ra|0)|(ab|0)==(ra|0)&qa>>>0<za>>>0)){break d}za=c[z+44>>2]|0;ra=za;ma=(za|0)<0|0?-1:0;za=Crc(-1,2147483647,ra,ma)|0;Fa=G;na=0;if((Da|0)>=(Fa|0)&((Da|0)>(Fa|0)|$a>>>0>=za>>>0)|((ab|0)<(na|0)|(ab|0)==(na|0)&qa>>>0<0>>>0)){break d}na=z+96|0;za=Erc(ra,ma,$a,Da)|0;ma=G;ra=Erc(qa<<1|0>>>31,ab<<1|qa>>>31,bb,hb)|0;xKb(eb,na,za,ma,ra,G,6e4,0)|0;pb=+(c[eb>>2]|0)/+(c[na>>2]|0);ra=0;ma=0;qb=.01;while(1){if((ra|0)<720){rb=(ra*1001|0)+1001|0}else{c[mb>>2]=24;c[ob>>2]=30;c[nb>>2]=60;c[gb>>2]=12;c[Ba>>2]=15;c[kb>>2]=48;rb=(c[n+(ra-720<<2)>>2]|0)*12e3|0}sb=+R(+(pb/(+(rb|0)/12012.0)+-1.0));za=sb<qb;tb=za?rb:ma;hb=ra+1|0;if((hb|0)<726){ra=hb;ma=tb;qb=za?sb:qb}else{break}}if((tb|0)==0){break}xKb(eb,na,tb,(tb|0)<0|0?-1:0,12012,0,2147483647,0)|0}}while(0);Da=z+412|0;if((c[Da>>2]|0)!=0){break}$a=c[b>>2]|0;J=c[$a+108>>2]|0;ma=c[z+40>>2]|0;ra=Erc(ma,(ma|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;za=G;hb=$a+104|0;bb=$a+112|0;$a=ca(c[bb>>2]|0,c[hb>>2]|0)|0;qa=c[z+44>>2]|0;ab=Erc($a,($a|0)<0|0?-1:0,qa,(qa|0)<0|0?-1:0)|0;$a=G;if((za|0)>($a|0)|(za|0)==($a|0)&ra>>>0>ab>>>0){c[Da>>2]=qa;c[z+416>>2]=ma;break}else{c[Da>>2]=J;c[z+416>>2]=ca(c[bb>>2]|0,c[hb>>2]|0)|0;break}}else if((ia|0)==1){if((c[H+792>>2]|0)==0){hb=g5a(c[H+48>>2]|0)|0;bb=c[b>>2]|0;c[bb+792>>2]=hb;ub=bb}else{ub=H}switch(c[ub+464>>2]|0){case 1:{c[z+72>>2]=512;break d;break};case 2:{c[z+72>>2]=256;break d;break};case 3:{c[z+72>>2]=128;break d;break};case 5:{c[z+72>>2]=8;break d;break};case 8:{c[z+72>>2]=32;break d;break};default:{break d}}}}while(0);lb=lb+1|0;}while(lb>>>0<(c[F>>2]|0)>>>0)}if((c[I>>2]|0)!=0){lb=a+4|0;kb=c[lb>>2]|0;if((c[kb+8>>2]&1|0)==0){Ba=iD(c[C>>2]|0)|0;gb=G;nb=0;ob=(gb|0)<(nb|0)|(gb|0)==(nb|0)&Ba>>>0<0>>>0;vb=ob?0:gb;wb=ob?0:Ba;xb=c[lb>>2]|0}else{vb=0;wb=0;xb=kb}kb=c[xb>>2]|0;if((irc(kb,2600240)|0)==0){if((wb|0)==0&(vb|0)==0){T=227}else{T=181}}else{if((irc(kb,2598568)|0)!=0|(wb|0)==0&(vb|0)==0){T=227}else{T=181}}do{if((T|0)==181){if((c[(c[C>>2]|0)+88>>2]|0)==0){T=227;break}kb=a+1264|0;lb=a+1268|0;Ba=l;ob=c[kb>>2]|0;if((ob|0)!=0){gb=ob;do{c[l>>2]=gb;c[kb>>2]=c[gb+80>>2];P1(gb|0);mJb(Ba);gb=c[kb>>2]|0;}while((gb|0)!=0)}c[lb>>2]=0;gb=h;kb=c[ea>>2]|0;if((kb|0)!=0){Ba=kb;do{c[h>>2]=Ba;c[ea>>2]=c[Ba+80>>2];P1(Ba|0);mJb(gb);Ba=c[ea>>2]|0;}while((Ba|0)!=0)}c[da>>2]=0;Ba=a+1256|0;gb=a+1260|0;lb=g;kb=c[Ba>>2]|0;if((kb|0)!=0){ob=kb;do{c[g>>2]=ob;c[Ba>>2]=c[ob+80>>2];P1(ob|0);mJb(lb);ob=c[Ba>>2]|0;}while((ob|0)!=0)}c[gb>>2]=0;c[a+1272>>2]=25e5;if((c[F>>2]|0)!=0){ob=0;do{Ba=c[(c[ha>>2]|0)+(ob<<2)>>2]|0;lb=Ba+48|0;do{if((c[lb>>2]|0)==0&(c[lb+4>>2]|0)==(-2147483648|0)){kb=Ba+200|0;if(!((c[kb>>2]|0)==0&(c[kb+4>>2]|0)==(-2147483648|0))){break}kb=c[Ba+8>>2]|0;if((c[kb+8>>2]|0)==-1){break}KIb(kb,24,2592200,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);lb=Ba+240|0;kb=c[lb>>2]|0;if((kb|0)!=0){HWa(kb);c[lb>>2]=0}ob=ob+1|0;}while(ob>>>0<(c[F>>2]|0)>>>0)}ob=c[C>>2]|0;if((ob|0)==0){yb=0;zb=0}else{gb=iD(ob)|0;yb=G;zb=gb}gb=m+28|0;ob=m+32|0;lb=m+8|0;kb=0;do{nb=yrc(25e4,0,kb|0)|0;mb=G;z=xrc(zb,yb,nb,mb)|0;H=G;b=0;ia=(H|0)<(b|0)|(H|0)==(b|0)&z>>>0<0>>>0;fD(c[C>>2]|0,ia?0:z,ia?0:H,0)|0;H=kb-1|0;ia=(H|0)>0;z=yrc(25e4,0,H|0)|0;H=ia?z:25e4;z=ia?G:0;ia=0;e:do{if((z|0)>(ia|0)|(z|0)==(ia|0)&H>>>0>0>>>0){b=0;bb=-2147483648;hb=0;while(1){while(1){J=qX(a,m)|0;if((J|0)==0){break}else if((J|0)!=(-11|0)){Ab=bb;Bb=hb;break e}}J=(c[gb>>2]|0)+b|0;Da=c[(c[ha>>2]|0)+(c[ob>>2]<<2)>>2]|0;ma=c[lb>>2]|0;qa=c[lb+4>>2]|0;do{if((ma|0)==0&(qa|0)==(-2147483648|0)){Cb=bb;Db=hb}else{ab=Da+48|0;ra=c[ab>>2]|0;$a=c[ab+4>>2]|0;if((ra|0)==0&($a|0)==(-2147483648|0)){ab=Da+200|0;za=c[ab>>2]|0;Fa=c[ab+4>>2]|0;if((za|0)==0&(Fa|0)==(-2147483648|0)){Cb=bb;Db=hb;break}else{Eb=Fa;Fb=za}}else{Eb=$a;Fb=ra}ra=xrc(ma,qa,Fb,Eb)|0;$a=G;za=0;if(!(($a|0)>(za|0)|($a|0)==(za|0)&ra>>>0>0>>>0)){Cb=qa;Db=ma;break}za=Da+56|0;Fa=c[za>>2]|0;ab=c[za+4>>2]|0;Ia=(c[Da+184>>2]|0)+64|0;do{if((Fa|0)==0&(ab|0)==(-2147483648|0)){T=210}else{ua=c[Ia>>2]|0;ta=c[Ia+4>>2]|0;Ga=0;if((ta|0)<(Ga|0)|(ta|0)==(Ga|0)&ua>>>0<1>>>0){T=210;break}if(!((ab|0)<($a|0)|(ab|0)==($a|0)&Fa>>>0<ra>>>0)){break}Ga=xrc(ra,$a,ua,ta)|0;ta=G;ua=-1;Na=(ta|0)>(ua|0)|(ta|0)==(ua|0)&Ga>>>0>-1>>>0;ua=xrc(0,0,Ga,ta)|0;fb=Na?ta:G;ta=c[Da+44>>2]|0;ya=Erc(ta,(ta|0)<0|0?-1:0,60,0)|0;ta=c[Da+40>>2]|0;cb=Crc(ya,G,ta,(ta|0)<0|0?-1:0)|0;ta=G;if((fb|0)<(ta|0)|(fb|0)==(ta|0)&(Na?Ga:ua)>>>0<cb>>>0){T=210}}}while(0);if((T|0)==210){T=0;c[za>>2]=ra;c[za+4>>2]=$a}c[Ia>>2]=ra;c[Ia+4>>2]=$a;Cb=qa;Db=ma}}while(0);P1(m);ma=(J|0)<0|0?-1:0;if((ma|0)<(z|0)|(ma|0)==(z|0)&J>>>0<H>>>0){b=J;bb=Cb;hb=Db}else{Ab=Cb;Bb=Db;break}}}else{Ab=-2147483648;Bb=0}}while(0);if(!((Bb|0)==0&(Ab|0)==(-2147483648|0)&((yb|0)>(mb|0)|(yb|0)==(mb|0)&zb>>>0>nb>>>0))){break}kb=kb+1|0;}while((kb|0)<5);xY(a);if((c[F>>2]|0)!=0){kb=a+1056|0;lb=a+1064|0;ob=k|0;gb=k+4|0;H=j|0;z=j+4|0;ia=0;do{Ba=c[(c[ha>>2]|0)+(ia<<2)>>2]|0;hb=Ba+48|0;do{if((c[hb>>2]|0)==0&(c[hb+4>>2]|0)==(-2147483648|0)){bb=c[kb>>2]|0;b=c[kb+4>>2]|0;if(!((bb|0)==0&(b|0)==(-2147483648|0))){c[H>>2]=1;c[z>>2]=1e6;na=XIb(bb,b,j,Ba+40|0)|0;c[hb>>2]=na;c[hb+4>>2]=G}na=c[lb>>2]|0;b=c[lb+4>>2]|0;if((na|0)==0&(b|0)==(-2147483648|0)){break}c[ob>>2]=1;c[gb>>2]=1e6;bb=XIb(na,b,k,Ba+40|0)|0;b=Ba+56|0;c[b>>2]=bb;c[b+4>>2]=G}}while(0);ia=ia+1|0;}while(ia>>>0<(c[F>>2]|0)>>>0)}fD(c[C>>2]|0,D,E,0)|0;ia=c[F>>2]|0;if((ia|0)!=0){gb=c[ha>>2]|0;ob=0;do{lb=c[gb+(ob<<2)>>2]|0;z=lb+200|0;H=c[z+4>>2]|0;kb=lb+208|0;c[kb>>2]=c[z>>2];c[kb+4>>2]=H;H=lb+216|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+640|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+264|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+272|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+280|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+288|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+296|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+304|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+312|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+320|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+328|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+336|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+344|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+352|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+360|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+368|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+376|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+384|0;c[H>>2]=0;c[H+4>>2]=-2147483648;H=lb+392|0;c[H>>2]=0;c[H+4>>2]=-2147483648;ob=ob+1|0;}while(ob>>>0<ia>>>0)}c[a+1212>>2]=0}}while(0);f:do{if((T|0)==227){ia=c[F>>2]|0;ob=0;while(1){if(!(ob>>>0<ia>>>0)){T=230;break}gb=(c[(c[ha>>2]|0)+(ob<<2)>>2]|0)+56|0;if((c[gb>>2]|0)==0&(c[gb+4>>2]|0)==(-2147483648|0)){ob=ob+1|0}else{break}}do{if((T|0)==230){ob=a+1064|0;if(!((c[ob>>2]|0)==0&(c[ob+4>>2]|0)==(-2147483648|0))){break}ob=a+1072|0;g:do{if((c[ob>>2]|0)<1){h:do{if((ia|0)!=0){gb=c[ha>>2]|0;H=0;lb=0;while(1){kb=c[(c[(c[gb+(H<<2)>>2]|0)+8>>2]|0)+72>>2]|0;if((kb|0)>0){if((2147483647-kb|0)<(lb|0)){break h}Gb=kb+lb|0}else{Gb=lb}kb=H+1|0;if(kb>>>0<ia>>>0){H=kb;lb=Gb}else{break}}c[ob>>2]=Gb;if((Gb|0)==0){break g}else{T=249;break g}}}while(0);c[ob>>2]=0}else{T=249}}while(0);do{if((T|0)==249){lb=c[C>>2]|0;if((lb|0)==0){break}H=iD(lb)|0;lb=G;gb=0;if(!((lb|0)>(gb|0)|(lb|0)==(gb|0)&H>>>0>0>>>0)){break}gb=c[F>>2]|0;if((gb|0)==0){break}J=c[ha>>2]|0;kb=c[ob>>2]|0;z=kb;Ba=(kb|0)<0|0?-1:0;kb=Crc(-1,2147483647,z,Ba)|0;hb=G;nb=H<<3|0>>>29;mb=lb<<3|H>>>29;H=0;lb=0;while(1){b=c[J+(H<<2)>>2]|0;bb=c[b+40>>2]|0;na=bb;eb=(bb|0)<0|0?-1:0;do{if((eb|0)>(hb|0)|(eb|0)==(hb|0)&na>>>0>kb>>>0){Hb=lb}else{bb=b+56|0;if(!((c[bb>>2]|0)==0&(c[bb+4>>2]|0)==(-2147483648|0))){Hb=lb;break}ma=c[b+44>>2]|0;qa=Erc(na,eb,z,Ba)|0;Da=VIb(nb,mb,ma,(ma|0)<0|0?-1:0,qa,G)|0;c[bb>>2]=Da;c[bb+4>>2]=G;Hb=1}}while(0);eb=H+1|0;if(eb>>>0<gb>>>0){H=eb;lb=Hb}else{break}}if((Hb|0)==0){break}KIb(ja,24,2594184,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);c[a+1212>>2]=2;break f}}while(0);xY(a);if((c[F>>2]|0)!=0){ia=a+1056|0;ob=a+1064|0;lb=f|0;H=f+4|0;gb=e|0;mb=e+4|0;nb=0;do{Ba=c[(c[ha>>2]|0)+(nb<<2)>>2]|0;z=Ba+48|0;do{if((c[z>>2]|0)==0&(c[z+4>>2]|0)==(-2147483648|0)){kb=c[ia>>2]|0;hb=c[ia+4>>2]|0;if(!((kb|0)==0&(hb|0)==(-2147483648|0))){c[gb>>2]=1;c[mb>>2]=1e6;J=XIb(kb,hb,e,Ba+40|0)|0;c[z>>2]=J;c[z+4>>2]=G}J=c[ob>>2]|0;hb=c[ob+4>>2]|0;if((J|0)==0&(hb|0)==(-2147483648|0)){break}c[lb>>2]=1;c[H>>2]=1e6;kb=XIb(J,hb,f,Ba+40|0)|0;hb=Ba+56|0;c[hb>>2]=kb;c[hb+4>>2]=G}}while(0);nb=nb+1|0;}while(nb>>>0<(c[F>>2]|0)>>>0)}c[a+1212>>2]=1}}while(0);xY(a)}nb=c[F>>2]|0;if((jb|0)>-1){Ib=(nb|0)==0?jb:-1}else{Ib=jb}if((nb|0)==0){Jb=Ib}else{nb=B|0;H=Ib;lb=0;while(1){ob=c[(c[ha>>2]|0)+(lb<<2)>>2]|0;if((TX(ob,A)|0)==0){w5a(nb,256,c[ob+8>>2]|0,0);ob=c[A>>2]|0;KIb(ja,24,2308912,(S=i,i=i+24|0,c[S>>2]=lb,c[S+8>>2]=nb,c[S+16>>2]=ob,S)|0);i=S;Kb=H}else{Kb=0}ob=lb+1|0;if(ob>>>0<(c[F>>2]|0)>>>0){H=Kb;lb=ob}else{Jb=Kb;break}}}lb=a+1064|0;H=a+1056|0;nb=c[H>>2]|0;ob=c[H+4>>2]|0;H=(nb|0)==0&(ob|0)==(-2147483648|0);mb=wrc(H?0:nb,H?0:ob,c[lb>>2]|0,c[lb+4>>2]|0)|0;lb=G;ob=a+1132|0;H=c[ob>>2]|0;if((H|0)==0){Ca=Jb;break}nb=a+1136|0;gb=(mb|0)==0&(lb|0)==0;ia=p|0;Ba=p+4|0;z=0;hb=H;while(1){H=c[(c[nb>>2]|0)+(z<<2)>>2]|0;kb=H+24|0;if((c[kb>>2]|0)==0&(c[kb+4>>2]|0)==(-2147483648|0)){if(gb){Lb=2147483647;Mb=-1;Nb=hb}else{c[ia>>2]=1;c[Ba>>2]=1e6;J=XIb(mb,lb,p,H+4|0)|0;Lb=G;Mb=J;Nb=c[ob>>2]|0}if((Nb|0)==0){Ob=Lb;Pb=Mb;Qb=0}else{J=H+4|0;eb=H+16|0;na=Lb;b=Mb;bb=0;while(1){Da=c[(c[nb>>2]|0)+(bb<<2)>>2]|0;qa=Da+16|0;ma=XIb(c[qa>>2]|0,c[qa+4>>2]|0,Da+4|0,J)|0;Da=G;if((bb|0)==(z|0)){Rb=na;Sb=b}else{qa=c[eb+4>>2]|0;Fa=((Da|0)>(qa|0)|(Da|0)==(qa|0)&ma>>>0>(c[eb>>2]|0)>>>0)&((Da|0)<(na|0)|(Da|0)==(na|0)&ma>>>0<b>>>0);Rb=Fa?Da:na;Sb=Fa?ma:b}ma=bb+1|0;Fa=c[ob>>2]|0;if(ma>>>0<Fa>>>0){na=Rb;b=Sb;bb=ma}else{Ob=Rb;Pb=Sb;Qb=Fa;break}}}if((Pb|0)==(-1|0)&(Ob|0)==2147483647){bb=H+16|0;Tb=c[bb+4>>2]|0;Ub=c[bb>>2]|0}else{Tb=Ob;Ub=Pb}c[kb>>2]=Ub;c[kb+4>>2]=Tb;Vb=Qb}else{Vb=hb}bb=z+1|0;if(bb>>>0<Vb>>>0){z=bb;hb=Vb}else{Ca=Jb;break}}}}while(0);if((c[F>>2]|0)!=0){Jb=0;do{Vb=c[(c[ha>>2]|0)+(Jb<<2)>>2]|0;Qb=c[Vb+8>>2]|0;if((c[Qb+8>>2]|0)!=1){c[Qb+808>>2]=0}Qb=c[Vb+184>>2]|0;if((Qb|0)==0){Wb=Vb}else{mJb(Qb+32|0);Wb=c[(c[ha>>2]|0)+(Jb<<2)>>2]|0}mJb(Wb+184|0);Jb=Jb+1|0;}while(Jb>>>0<(c[F>>2]|0)>>>0)}F=c[C>>2]|0;if((F|0)==0){ib=Ca;i=d;return ib|0}Jb=fD(F,0,0,1)|0;F=G;Wb=c[C>>2]|0;C=Wb+112|0;ha=c[C>>2]|0;Qb=c[C+4>>2]|0;C=c[Wb+120>>2]|0;KIb(ja,48,2304016,(S=i,i=i+48|0,c[S>>2]=Jb,c[S+8>>2]=F,c[S+16>>2]=ha,c[S+24>>2]=Qb,c[S+32>>2]=C,c[S+40>>2]=la,S)|0);i=S;ib=Ca;i=d;return ib|0}function PX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>2147483630>>>0){c[a+100>>2]=0;d=-22;return d|0}e=hJb(b+16|0)|0;c[a+96>>2]=e;if((e|0)==0){c[a+100>>2]=0;d=-12;return d|0}else{mrc(e+b|0,0,16)|0;c[a+100>>2]=b;d=0;return d|0}return 0}function QX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;if(d>>>0>2147483630>>>0){c[a+100>>2]=0;f=-22;i=e;return f|0}g=hJb(d+16|0)|0;h=a+96|0;c[h>>2]=g;if((g|0)==0){c[a+100>>2]=0;f=-12;i=e;return f|0}mrc(g+d|0,0,16)|0;j=a+100|0;c[j>>2]=d;k=AD(b,g,d)|0;if((k|0)==(d|0)){f=d;i=e;return f|0}mJb(h);c[j>>2]=0;KIb(a,16,2422160,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;f=(k|0)<0?k:-1094995529;i=e;return f|0}function RX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,H=0,I=0.0,J=0,K=0,L=0,M=0,N=0.0,O=0;a=i;i=i+24|0;f=a|0;g=b+184|0;j=c[g>>2]|0;k=j|0;l=c[k>>2]|0;m=c[k+4>>2]|0;k=(d|0)!=0|(e|0)!=(-2147483648|0);n=xrc(d,e,l,m)|0;o=G;p=2147483647;do{if(k&((l|0)!=0|(m|0)!=(-2147483648|0))&((m|0)<(e|0)|(m|0)==(e|0)&l>>>0<d>>>0)&(o>>>0<p>>>0|o>>>0==p>>>0&n>>>0<-1>>>0)){q=2147352575;r=(e|0)>(q|0)|(e|0)==(q|0)&d>>>0>-1>>>0;q=wrc(d,e,1,-2147418112)|0;s=(+((r?q:d)>>>0)+ +((r?G:e)|0)*4294967296.0)*(+(c[b+40>>2]|0)/+(c[b+44>>2]|0));q=c[j+32>>2]|0;do{if((q|0)==0){t=pJb(23232)|0;c[(c[g>>2]|0)+32>>2]=t;t=c[g>>2]|0;u=c[t+32>>2]|0;if((u|0)==0){v=-12}else{w=u;x=t;break}i=a;return v|0}else{w=q;x=j}}while(0);q=f|0;t=f+4|0;u=f+8|0;y=f+12|0;z=f+16|0;A=f+20|0;B=0;C=x;D=w;while(1){if(+h[D+5808+(B<<3)>>3]<1.0e10){if((B|0)<720){E=(B*1001|0)+1001|0}else{c[q>>2]=24;c[t>>2]=30;c[u>>2]=60;c[y>>2]=12;c[z>>2]=15;c[A>>2]=48;E=(c[f+(B-720<<2)>>2]|0)*12e3|0}F=s*+(E|0)/12012.0;H=ge(+(F+0.0))|0;I=F-(+(H>>>0)+ +(G|0)*4294967296.0)+0.0;H=c[(c[g>>2]|0)+32>>2]|0;J=H+(B<<3)|0;h[J>>3]=+h[J>>3]+I;J=H+5808+(B<<3)|0;h[J>>3]=I*I+ +h[J>>3];J=ge(+(F+.5))|0;I=F-(+(J>>>0)+ +(G|0)*4294967296.0)+.5;J=c[g>>2]|0;H=c[J+32>>2]|0;K=H+11616+(B<<3)|0;h[K>>3]=+h[K>>3]+I;K=H+17424+(B<<3)|0;h[K>>3]=I*I+ +h[K>>3];L=J;M=H}else{L=C;M=D}H=B+1|0;if((H|0)<726){B=H;C=L;D=M}else{break}}D=L+16|0;C=(c[D>>2]|0)+1|0;c[D>>2]=C;D=L+24|0;B=wrc(c[D>>2]|0,c[D+4>>2]|0,n,o)|0;c[D>>2]=B;c[D+4>>2]=G;if(((C|0)%10|0|0)==0){s=+(C|0);D=0;do{B=M+5808+(D<<3)|0;I=+h[B>>3];do{if(I<1.0e10){F=+h[M+(D<<3)>>3]/s;N=+h[M+11616+(D<<3)>>3]/s;if(!(I/s-F*F>.04)){break}A=M+17424+(D<<3)|0;if(!(+h[A>>3]/s-N*N>.04)){break}h[B>>3]=2.0e10;h[A>>3]=2.0e10}}while(0);D=D+1|0;}while((D|0)<726)}if((C|0)<=3){O=L;break}D=2147352575;if(r^((m|0)>(D|0)|(m|0)==(D|0)&l>>>0>-1>>>0)){O=L;break}D=L+8|0;B=TIb(c[D>>2]|0,c[D+4>>2]|0,n,o)|0;c[D>>2]=B;c[D+4>>2]=G;O=L}else{O=j}}while(0);if(!k){v=0;i=a;return v|0}k=O|0;c[k>>2]=d;c[k+4>>2]=e;v=0;i=a;return v|0}function SX(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0.0,H=0,I=0,J=0.0,K=0,L=0.0,M=0,N=0,O=0.0,P=0,Q=0.0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0.0,Z=0,_=0,$=0;b=i;i=i+24|0;d=b|0;e=a+24|0;f=c[e>>2]|0;if((f|0)==0){i=b;return}g=a+28|0;a=d|0;j=d+4|0;k=d+8|0;l=d+12|0;m=d+16|0;n=d+20|0;o=0;p=f;while(1){f=c[(c[g>>2]|0)+(o<<2)>>2]|0;q=f+8|0;r=c[q>>2]|0;if((c[r+8>>2]|0)==0){s=c[r+108>>2]|0;t=c[r+104>>2]|0;do{if((s|0)>=(t*101|0|0)|(s|0)<(t*5|0|0)){u=8}else{if((c[r+52>>2]|0)==1983148141){u=8;break}v=c[r+48>>2]|0;if((v|0)==2|(v|0)==28){u=8;break}w=f+184|0}}while(0);do{if((u|0)==8){u=0;r=f+184|0;t=c[r>>2]|0;if((c[t+16>>2]|0)<=15){w=r;break}s=t+8|0;t=c[s>>2]|0;v=c[s+4>>2]|0;s=c[f+44>>2]|0;x=s;y=(s|0)<0|0?-1:0;s=c[f+40>>2]|0;z=s;A=(s|0)<0|0?-1:0;s=Erc(z,A,500,0)|0;B=Crc(x,y,s,G)|0;s=G;C=0;D=(s|0)<(C|0)|(s|0)==(C|0)&B>>>0<1>>>0;C=D?0:s;if(!((v|0)>(C|0)|(v|0)==(C|0)&t>>>0>(D?1:B)>>>0)){w=r;break}B=f+412|0;if((c[B>>2]|0)!=0){w=r;break}D=Erc(z,A,t,v)|0;xKb(B,f+416|0,x,y,D,G,2147483647,0)|0;w=r}}while(0);r=c[w>>2]|0;a:do{if((c[r+16>>2]|0)>1){D=f+412|0;if((c[D>>2]|0)!=0){break}y=c[q>>2]|0;x=c[y+108>>2]|0;B=c[y+104>>2]|0;do{if(!((x|0)>=(B*101|0|0)|(x|0)<(B*5|0|0))){if((c[y+52>>2]|0)==1983148141){break}v=c[y+48>>2]|0;if(!((v|0)==2|(v|0)==28)){break a}}}while(0);y=f+40|0;B=f+44|0;E=.01;x=0;v=0;t=r;while(1){A=t+40|0;z=c[A>>2]|0;C=c[A+4>>2]|0;A=(z|0)==0&(C|0)==0;do{if(A){u=24}else{F=(+(z>>>0)+ +(C|0)*4294967296.0)*(+(c[y>>2]|0)/+(c[B>>2]|0));if((v|0)<720){H=(v*1001|0)+1001|0}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;H=(c[d+(v-720<<2)>>2]|0)*12e3|0}if(F<12012.0/+(H|0)){I=x;J=E;break}if(A){u=24}else{u=28}}}while(0);if((u|0)==24){u=0;if((v|0)<720){K=(v*1001|0)+1001|0}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;K=(c[d+(v-720<<2)>>2]|0)*12e3|0}if(12012.0/+(K|0)>1.0){I=x;J=E}else{u=28}}do{if((u|0)==28){u=0;A=t+24|0;C=c[t+16>>2]|0;F=+(C|0);L=+(c[y>>2]|0)/+(c[B>>2]|0)*(+((c[A>>2]|0)>>>0)+ +(c[A+4>>2]|0)*4294967296.0)/F;A=(v|0)<720;if(A){M=(v*1001|0)+1001|0}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;M=(c[d+(v-720<<2)>>2]|0)*12e3|0}if(L<9609.6/+(M|0)){I=x;J=E;break}z=(v*1001|0)+1001|0;s=d+(v-720<<2)|0;N=c[t+32>>2]|0;L=+h[N+(v<<3)>>3]/F;O=+h[N+5808+(v<<3)>>3]/F-L*L;do{if(O<E&E>1.0e-9){if(A){P=z;Q=O;break}c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;P=(c[s>>2]|0)*12e3|0;Q=O}else{P=x;Q=E}}while(0);if(O<.02){if(A){R=z}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;R=(c[s>>2]|0)*12e3|0}KIb(0,48,2412088,(S=i,i=i+16|0,h[S>>3]=+(R|0)/12.0/1001.0,h[S+8>>3]=O,S)|0);i=S;T=c[w>>2]|0;U=c[T+16>>2]|0;V=c[T+32>>2]|0}else{U=C;V=N}L=+(U|0);F=+h[V+11616+(v<<3)>>3]/L;W=+h[V+17424+(v<<3)>>3]/L-F*F;do{if(W<Q&Q>1.0e-9){if(A){X=z;Y=W;break}c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;X=(c[s>>2]|0)*12e3|0;Y=W}else{X=P;Y=Q}}while(0);if(!(W<.02)){I=X;J=Y;break}if(A){Z=z}else{c[a>>2]=24;c[j>>2]=30;c[k>>2]=60;c[l>>2]=12;c[m>>2]=15;c[n>>2]=48;Z=(c[s>>2]|0)*12e3|0}KIb(0,48,2412088,(S=i,i=i+16|0,h[S>>3]=+(Z|0)/12.0/1001.0,h[S+8>>3]=W,S)|0);i=S;I=X;J=Y}}while(0);N=v+1|0;if((N|0)>=726){break}E=J;x=I;v=N;t=c[w>>2]|0}if((I|0)==0){break}t=c[D>>2]|0;if((t|0)==0){_=f+416|0}else{v=f+416|0;if(+(I|0)/12012.0<+(t|0)/+(c[v>>2]|0)*1.01){_=v}else{break}}xKb(D,_,I,(I|0)<0|0?-1:0,12012,0,2147483647,0)|0}}while(0);mJb((c[w>>2]|0)+32|0);f=c[w>>2]|0;r=f|0;c[r>>2]=0;c[r+4>>2]=-2147483648;c[f+16>>2]=0;r=f+24|0;c[r>>2]=0;c[r+4>>2]=0;$=c[e>>2]|0}else{$=p}r=o+1|0;if(r>>>0<$>>>0){o=r;p=$}else{break}}i=b;return}function TX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[a+8>>2]|0;e=c[d+8>>2]|0;do{if((e|0)==2){if((c[d+48>>2]|0)==0){f=1}else{break}return f|0}else if((e|0)==1){do{if((c[d+424>>2]|0)==0){g=c[d+48>>2]|0;if(!((g|0)==86059|(g|0)==86016|(g|0)==86017)){break}if((b|0)==0){f=0;return f|0}c[b>>2]=2586624;f=0;return f|0}}while(0);g=(c[(c[a+184>>2]|0)+56>>2]|0)>-1;do{if(g){if(!((c[d+420>>2]|0)==-1)){break}if((b|0)==0){f=0;return f|0}c[b>>2]=2582480;f=0;return f|0}}while(0);if((c[d+412>>2]|0)==0){if((b|0)==0){f=0;return f|0}c[b>>2]=2580512;f=0;return f|0}if((c[d+416>>2]|0)==0){if((b|0)==0){f=0;return f|0}c[b>>2]=2578392;f=0;return f|0}if(!g){break}if((c[a+452>>2]|0)!=0){break}if((c[d+48>>2]|0)!=86020){break}if((b|0)==0){f=0;return f|0}c[b>>2]=2576800;f=0;return f|0}else if((e|0)==0){if((c[d+120>>2]|0)==0){if((b|0)==0){f=0;return f|0}c[b>>2]=2575480;f=0;return f|0}do{if((c[(c[a+184>>2]|0)+56>>2]|0)>-1){if(!((c[d+140>>2]|0)==-1)){break}if((b|0)==0){f=0;return f|0}c[b>>2]=2574112;f=0;return f|0}}while(0);if(!(((c[d+48>>2]|0)-69|0)>>>0<2>>>0)){break}if((c[a+80>>2]|0)!=0){break}if((c[d+224>>2]|0)!=0){break}if((c[a+232>>2]|0)!=0){break}if((b|0)==0){f=0;return f|0}c[b>>2]=2572656;f=0;return f|0}else if((e|0)==3){if((c[d+48>>2]|0)!=94214){break}if((c[d+120>>2]|0)!=0){break}if((b|0)==0){f=0;return f|0}c[b>>2]=2575480;f=0;return f|0}}while(0);if((c[d+48>>2]|0)!=0){f=1;return f|0}if((b|0)==0){f=0;return f|0}c[b>>2]=2571144;f=0;return f|0}function UX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+136|0;g=f|0;h=f+8|0;j=f+16|0;k=f+48|0;l=f+128|0;c[g>>2]=1;m=UHb()|0;c[h>>2]=m;nrc(k|0,d|0,80)|0;if((m|0)==0){n=-12;i=f;return n|0}m=b+8|0;d=(a5a(c[m>>2]|0)|0)==0;o=b+184|0;p=c[o>>2]|0;q=c[p+56>>2]|0;r=(q|0)==0;a:do{if(d){if(!r){s=19;break}c[l>>2]=0;t=c[m>>2]|0;u=c[t+48>>2]|0;v=c[t+12>>2]|0;do{if((v|0)==0){w=c[t+8>>2]|0;if((w|0)==1){x=c[a+1308>>2]|0;if((x|0)!=0){y=x;break}}else if((w|0)==3){x=c[a+1312>>2]|0;if((x|0)!=0){y=x;break}}else if((w|0)==0){w=c[a+1304>>2]|0;if((w|0)!=0){y=w;break}}w=c5a(u)|0;if((w|0)!=0){y=w;break}c[(c[o>>2]|0)+56>>2]=-1;z=-1;break a}else{y=v}}while(0);v=(e|0)!=0;u=v?e:l;MGb(u,2390272,2383400,0)|0;t=_4a(c[m>>2]|0,y,u)|0;if(!v){OGb(l)}v=(c[o>>2]|0)+56|0;if((t|0)<0){c[v>>2]=-1;z=t;break}else{c[v>>2]=1;A=t;s=18;break}}else{if(!r){s=19;break}c[p+56>>2]=1;A=0;s=18}}while(0);if((s|0)==18){B=A;s=20}else if((s|0)==19){if((q|0)<0){z=-1}else{B=0;s=20}}b:do{if((s|0)==20){q=b+184|0;A=k+24|0;p=k+28|0;r=b+452|0;o=b+232|0;l=B;c:while(1){C=l;y=c[p>>2]|0;while(1){if((y|0)>0){if(!((C|0)>-1)){break c}}else{if((c[A>>2]|0)!=0){z=C;break b}if(!((c[g>>2]|0)!=0&(C|0)>-1)){break c}}e=(TX(b,0)|0)==0;a=c[m>>2]|0;d:do{if(e){D=a}else{e:do{if((c[a+48>>2]|0)==28){if((c[q>>2]|0)==0){E=a;break}do{if((c[a+176>>2]|0)==0){F=a}else{d=aha(a)|0;t=c[m>>2]|0;v=c[t+176>>2]|0;if((d|0)==(v|0)){E=t;break e}if((v|0)<3){F=t;break}d=c[r>>2]|0;if((v|0)<4){if((d|0)>17){E=t;break e}else{D=t;break d}}else{if((d|0)>19){E=t;break e}else{D=t;break d}}}}while(0);if((c[r>>2]|0)>6){E=F}else{D=F;break d}}else{E=a}}while(0);if((c[o>>2]|0)!=0){break c}if((c[(c[E+12>>2]|0)+16>>2]&1024|0)==0){break c}else{D=E}}}while(0);c[g>>2]=0;a=c[D+8>>2]|0;if((a|0)==3){o5a(D,j,g,k)|0;G=c[p>>2]|0}else if((a|0)==0){G=k5a(D,c[h>>2]|0,g,k)|0}else if((a|0)==1){G=n5a(D,c[h>>2]|0,g,k)|0}else{G=C}if(!((G|0)>-1)){l=G;continue c}a=c[g>>2]|0;if((a|0)!=0){c[r>>2]=(c[r>>2]|0)+1}c[A>>2]=(c[A>>2]|0)+G;e=(c[p>>2]|0)-G|0;c[p>>2]=e;C=a;y=e}}if((c[A>>2]|0)!=0){z=C;break}z=(c[g>>2]|0)==0?-1:C}}while(0);VHb(h);n=z;i=f;return n|0}function VX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[a+1104>>2]|0;if((e|0)==0){f=0;return f|0}g=c[a+1108>>2]|0;a=b;b=0;a:while(1){h=c[g+(b<<2)>>2]|0;b:do{if((h|0)==(a|0)){i=0}else{if((a|0)!=0){i=a;break}j=c[h+16>>2]|0;k=h+12|0;l=0;while(1){if(!(l>>>0<j>>>0)){i=0;break b}if((c[(c[k>>2]|0)+(l<<2)>>2]|0)==(d|0)){f=h;m=9;break a}else{l=l+1|0}}}}while(0);h=b+1|0;if(h>>>0<e>>>0){a=i;b=h}else{f=0;m=9;break}}if((m|0)==9){return f|0}return 0}function WX(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=a+24|0;h=c[g>>2]|0;i=(d|0)<0;a:do{if((e|0)>-1&i){j=c[a+1104>>2]|0;if((j|0)==0){k=h;l=0;break}m=c[a+1108>>2]|0;n=0;while(1){o=c[m+(n<<2)>>2]|0;b:do{if((o|0)!=0){p=c[o+16>>2]|0;q=o+12|0;r=0;while(1){if(!(r>>>0<p>>>0)){break b}s=c[q>>2]|0;if((c[s+(r<<2)>>2]|0)==(e|0)){k=p;l=s;break a}else{r=r+1|0}}}}while(0);o=n+1|0;if(o>>>0<j>>>0){n=o}else{k=h;l=0;break}}}else{k=h;l=0}}while(0);if((k|0)>0){h=a+28|0;e=(b|0)==1;n=(f|0)==0;j=a+1304|0;m=a+1308|0;o=a+1312|0;a=-1;r=-1;p=l;l=0;q=0;s=-1;t=-1381258232;u=k;k=0;while(1){v=(p|0)!=0;if(v){w=c[p+(k<<2)>>2]|0}else{w=k}x=c[(c[h>>2]|0)+(w<<2)>>2]|0;y=c[x+8>>2]|0;c:do{if((c[y+8>>2]|0)==(b|0)){z=(w|0)==(d|0);if(!(i|z)){A=k;B=u;C=t;D=s;E=q;F=l;G=p;H=r;I=a;break}if(!z){if((c[x+72>>2]&384|0)!=0){A=k;B=u;C=t;D=s;E=q;F=l;G=p;H=r;I=a;break}}if(e){if((c[y+416>>2]|0)==0){A=k;B=u;C=t;D=s;E=q;F=l;G=p;H=r;I=a;break}}do{if(n){J=l}else{z=c[y+48>>2]|0;K=c[y+12>>2]|0;if((K|0)!=0){J=K;break}if((b|0)==0){K=c[j>>2]|0;if((K|0)!=0){J=K;break}}else if((b|0)==3){K=c[o>>2]|0;if((K|0)!=0){J=K;break}}else if((b|0)==1){K=c[m>>2]|0;if((K|0)!=0){J=K;break}}K=c5a(z)|0;if((K|0)!=0){J=K;break}A=k;B=u;C=(t|0)<0?-1128613112:t;D=s;E=q;F=0;G=p;H=r;I=a;break c}}while(0);K=c[x+232>>2]|0;z=c[y+72>>2]|0;L=(K|0)<5?K:5;if((a|0)>(L|0)){A=k;B=u;C=t;D=s;E=q;F=J;G=p;H=r;I=a;break}M=(a|0)==(L|0);if(M&(r|0)>(z|0)){A=k;B=u;C=t;D=s;E=q;F=J;G=p;H=r;I=a;break}if(!((s|0)<(K|0)|M&(r|0)==(z|0)^1)){A=k;B=u;C=t;D=s;E=q;F=J;G=p;H=r;I=a;break}if(!v){A=k;B=u;C=w;D=K;E=J;F=J;G=0;H=z;I=L;break}if(!((k|0)==(u-1|0)&(w|0)<0)){A=k;B=u;C=w;D=K;E=J;F=J;G=p;H=z;I=L;break}A=0;B=c[g>>2]|0;C=w;D=K;E=J;F=J;G=0;H=z;I=L}else{A=k;B=u;C=t;D=s;E=q;F=l;G=p;H=r;I=a}}while(0);v=A+1|0;if((v|0)<(B|0)){a=I;r=H;p=G;l=F;q=E;s=D;t=C;u=B;k=v}else{N=E;O=C;break}}}else{N=0;O=-1381258232}if((f|0)==0){return O|0}c[f>>2]=N;return O|0}function XX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=a+24|0;f=c[e>>2]|0;if((f|0)==0){KIb(0,0,2533912,(g=i,i=i+24|0,c[g>>2]=2293080,c[g+8>>2]=2504288,c[g+16>>2]=3510,g)|0);i=g;Hd()}h=a+28|0;if((c[(c[h>>2]|0)+(f-1<<2)>>2]|0)!=(b|0)){KIb(0,0,2533912,(g=i,i=i+24|0,c[g>>2]=2285760,c[g+8>>2]=2504288,c[g+16>>2]=3511,g)|0);i=g;Hd()}g=c[b+240>>2]|0;if((g|0)!=0){HWa(g)}if((c[b+128>>2]|0)!=0){P1(b+104|0)}OGb(b+88|0);mJb(b+252|0);mJb(b+400|0);g=b+8|0;mJb((c[g>>2]|0)+96|0);mJb((c[g>>2]|0)+860|0);mJb(g);mJb(b+12|0);g=b+184|0;b=c[g>>2]|0;if((b|0)==0){j=g;mJb(j);k=c[e>>2]|0;l=k-1|0;c[e>>2]=l;m=c[h>>2]|0;n=m+(l<<2)|0;o=n;mJb(o);i=d;return}mJb(b+32|0);j=g;mJb(j);k=c[e>>2]|0;l=k-1|0;c[e>>2]=l;m=c[h>>2]|0;n=m+(l<<2)|0;o=n;mJb(o);i=d;return}function YX(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a|0)==0){i=b;return}g=c[a>>2]|0;if((g|0)==0){i=b;return}h=c[g+16>>2]|0;j=g+4|0;k=c[j>>2]|0;if((k|0)==0){l=5}else{if((c[k+8>>2]&1|0)==0){l=5}else{l=6}}if((l|0)==5){if((c[g+1084>>2]&128|0)==0){m=h}else{l=6}}if((l|0)==6){m=0}l=g+1264|0;h=g+1268|0;k=f;n=c[l>>2]|0;if((n|0)!=0){o=n;do{c[f>>2]=o;c[l>>2]=c[o+80>>2];P1(o|0);mJb(k);o=c[l>>2]|0;}while((o|0)!=0)}c[h>>2]=0;h=g+1236|0;o=g+1240|0;l=e;k=c[h>>2]|0;if((k|0)!=0){f=k;do{c[e>>2]=f;c[h>>2]=c[f+80>>2];P1(f|0);mJb(l);f=c[h>>2]|0;}while((f|0)!=0)}c[o>>2]=0;o=g+1256|0;f=g+1260|0;h=d;l=c[o>>2]|0;if((l|0)!=0){e=l;do{c[d>>2]=e;c[o>>2]=c[e+80>>2];P1(e|0);mJb(h);e=c[o>>2]|0;}while((e|0)!=0)}c[f>>2]=0;c[g+1272>>2]=25e5;f=c[j>>2]|0;do{if((f|0)!=0){j=c[f+48>>2]|0;if((j|0)==0){break}ve[j&4095](g)|0}}while(0);pX(g);c[a>>2]=0;WD(m)|0;i=b;return}function ZX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a+24|0;e=c[d>>2]|0;if(e>>>0>536870910>>>0){f=0;return f|0}g=a+28|0;h=nJb(c[g>>2]|0,e+1|0,4)|0;if((h|0)==0){f=0;return f|0}c[g>>2]=h;h=pJb(656)|0;e=h;if((h|0)==0){f=0;return f|0}i=pJb(104)|0;j=h+184|0;c[j>>2]=i;if((i|0)==0){kJb(h);f=0;return f|0}k=i;c[k>>2]=0;c[k+4>>2]=-2147483648;k=mWa(b)|0;c[h+8>>2]=k;b=c[a+4>>2]|0;if((b|0)!=0){c[k+72>>2]=0}c[h>>2]=c[d>>2];k=h+48|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+56|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=(b|0)!=0;b=h+208|0;c[b>>2]=k?-1:0;c[b+4>>2]=k?2147418111:0;k=h+200|0;c[k>>2]=0;c[k+4>>2]=-2147483648;c[h+228>>2]=2500;k=h+464|0;c[k>>2]=0;c[k+4>>2]=-2147483648;c[h+472>>2]=0;_X(e,33,1,9e4);k=h+216|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+640|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+264|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+272|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+280|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+288|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+296|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+304|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+312|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+320|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+328|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+336|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+344|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+352|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+360|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+368|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+376|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+384|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=h+392|0;c[k>>2]=0;c[k+4>>2]=-2147483648;c[h+80>>2]=0;c[h+84>>2]=1;h=c[j>>2]|0;j=h|0;c[j>>2]=0;c[j+4>>2]=-2147483648;j=h+72|0;c[j>>2]=0;c[j+4>>2]=-2147483648;j=h+88|0;c[j>>2]=0;c[j+4>>2]=-2147483648;j=c[d>>2]|0;c[d>>2]=j+1;c[(c[g>>2]|0)+(j<<2)>>2]=e;f=e;return f|0}function _X(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+8|0;g=f|0;h=g;j=g;k=h+4|0;do{if((xKb(j,k,d,0,e,0,2147483647,0)|0)==0){KIb(0,24,2178944,(l=i,i=i+8|0,c[l>>2]=c[a>>2],l)|0);i=l;m=5}else{n=c[j>>2]|0;if((n|0)==(d|0)){o=d;break}KIb(0,48,2181248,(l=i,i=i+16|0,c[l>>2]=c[a>>2],c[l+8>>2]=(d>>>0)/(n>>>0)|0,l)|0);i=l;m=5}}while(0);if((m|0)==5){o=c[j>>2]|0}j=c[k>>2]|0;if((o|0)<1|(j|0)<1){k=c[a>>2]|0;KIb(0,16,2176776,(l=i,i=i+24|0,c[l>>2]=o,c[l+8>>2]=j,c[l+16>>2]=k,l)|0);i=l;i=f;return}else{l=a+40|0;k=c[g+4>>2]|0;c[l>>2]=c[g>>2];c[l+4>>2]=k;T4a(c[a+8>>2]|0,h);c[a+188>>2]=b;i=f;return}}function $X(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a+1104|0;e=c[d>>2]|0;if((e|0)==0){f=5}else{g=c[a+1108>>2]|0;h=0;i=0;do{j=c[g+(h<<2)>>2]|0;i=(c[j>>2]|0)==(b|0)?j:i;h=h+1|0;}while(h>>>0<e>>>0);if((i|0)==0){f=5}else{k=i}}do{if((f|0)==5){i=pJb(72)|0;if((i|0)==0){l=0;return l|0}else{tJb(a+1108|0,d,i);c[i+8>>2]=-16;k=i;break}}}while(0);c[k>>2]=b;b=k+56|0;c[b>>2]=0;c[b+4>>2]=-2147483648;c[k+64>>2]=0;b=k+48|0;c[b>>2]=0;c[b+4>>2]=-2147483648;b=k+40|0;c[b>>2]=0;c[b+4>>2]=-2147483648;l=k;return l|0}function aY(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=i;l=d;d=i;i=i+8|0;c[d>>2]=c[l>>2];c[d+4>>2]=c[l+4>>2];l=a+1132|0;m=c[l>>2]|0;if((m|0)==0){n=5}else{o=c[a+1136>>2]|0;p=0;q=0;do{r=c[o+(p<<2)>>2]|0;q=(c[r>>2]|0)==(b|0)?r:q;p=p+1|0;}while(p>>>0<m>>>0);if((q|0)==0){n=5}else{s=q}}do{if((n|0)==5){q=pJb(40)|0;if((q|0)==0){t=0;i=k;return t|0}else{tJb(a+1136|0,l,q);s=q;break}}}while(0);MGb(s+32|0,2281640,j,0)|0;c[s>>2]=b;b=d;d=s+4|0;j=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=j;j=s+16|0;c[j>>2]=e;c[j+4>>2]=f;f=s+24|0;c[f>>2]=g;c[f+4>>2]=h;t=s;i=k;return t|0}function bY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;if(!((c[a+24>>2]|0)>>>0>d>>>0)){KIb(a,16,2277640,(f=i,i=i+8|0,c[f>>2]=d,f)|0);i=f;i=e;return}f=c[a+1104>>2]|0;g=a+1108|0;a=0;while(1){if(!(a>>>0<f>>>0)){h=11;break}j=c[(c[g>>2]|0)+(a<<2)>>2]|0;if((c[j>>2]|0)==(b|0)){break}else{a=a+1|0}}if((h|0)==11){i=e;return}a=j+16|0;b=c[a>>2]|0;g=j+12|0;j=c[g>>2]|0;f=0;while(1){if(!(f>>>0<b>>>0)){break}if((c[j+(f<<2)>>2]|0)==(d|0)){h=11;break}else{f=f+1|0}}if((h|0)==11){i=e;return}h=nJb(j,b+1|0,4)|0;if((h|0)==0){i=e;return}b=h;c[g>>2]=b;g=c[a>>2]|0;c[a>>2]=g+1;c[b+(g<<2)>>2]=d;i=e;return}function cY(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;j=b+24|0;k=c[j>>2]|0;do{if((k|0)==0){l=0}else{m=pJb(k)|0;if(!((c[j>>2]|0)!=0&(m|0)==0)){l=m;break}i=g;return}}while(0);k=(f|0)!=0;if(k){n=c[b+8>>2]|0}else{n=c[b+4>>2]|0}m=c[n>>2]|0;KIb(0,32,2273392,(n=i,i=i+40|0,c[n>>2]=k?2268392:2264584,c[n+8>>2]=d,c[n+16>>2]=m,c[n+24>>2]=k?2260792:2256360,c[n+32>>2]=e,n)|0);i=n;dY(c[b+1140>>2]|0,2252408);if(!k){KIb(0,32,2242024,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=b+1064|0;e=c[k>>2]|0;m=c[k+4>>2]|0;if((e|0)==0&(m|0)==(-2147483648|0)){KIb(0,32,2232248,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}else{k=wrc(e,m,5e3,0)|0;m=G;e=Crc(k,m,1e6,0)|0;o=e;e=Drc(k,m,1e6,0)|0;KIb(0,32,2235848,(n=i,i=i+32|0,c[n>>2]=(o|0)/3600|0,c[n+8>>2]=((o|0)/60|0|0)%60|0,c[n+16>>2]=(o|0)%60|0,c[n+24>>2]=(e*100|0|0)/1e6|0,n)|0);i=n}e=b+1056|0;if(!((c[e>>2]|0)==0&(c[e+4>>2]|0)==(-2147483648|0))){KIb(0,32,2228336,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=c[e>>2]|0;m=c[e+4>>2]|0;e=Crc(o,m,1e6,0)|0;k=Drc(o,m,1e6,0)|0;m=k;k=(m|0)>-1?m:-m|0;m=VIb(k,(k|0)<0|0?-1:0,1e6,0,1e6,0)|0;KIb(0,32,2223760,(n=i,i=i+16|0,c[n>>2]=e,c[n+8>>2]=m,n)|0);i=n}KIb(0,32,2219952,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=c[b+1072>>2]|0;if((m|0)==0){KIb(0,32,2232248,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}else{KIb(0,32,2217008,(n=i,i=i+8|0,c[n>>2]=(m|0)/1e3|0,n)|0);i=n}KIb(0,32,2214224,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}m=b+1132|0;if((c[m>>2]|0)!=0){e=b+1136|0;k=0;do{o=c[(c[e>>2]|0)+(k<<2)>>2]|0;KIb(0,32,2211736,(n=i,i=i+16|0,c[n>>2]=d,c[n+8>>2]=k,n)|0);i=n;p=o+16|0;q=o+4|0;r=o+8|0;KIb(0,32,2209432,(n=i,i=i+8|0,h[n>>3]=(+((c[p>>2]|0)>>>0)+ +(c[p+4>>2]|0)*4294967296.0)*(+(c[q>>2]|0)/+(c[r>>2]|0)),n)|0);i=n;p=o+24|0;KIb(0,32,2200856,(n=i,i=i+8|0,h[n>>3]=(+((c[p>>2]|0)>>>0)+ +(c[p+4>>2]|0)*4294967296.0)*(+(c[q>>2]|0)/+(c[r>>2]|0)),n)|0);i=n;dY(c[o+32>>2]|0,2195928);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+1104|0;do{if((c[m>>2]|0)==0){s=28}else{k=b+1108|0;e=0;o=0;r=c[k>>2]|0;while(1){q=LGb(c[(c[r+(e<<2)>>2]|0)+20>>2]|0,2193320,0,0)|0;if((q|0)==0){t=10230264}else{t=c[q+4>>2]|0}KIb(0,32,2190784,(n=i,i=i+16|0,c[n>>2]=c[c[(c[k>>2]|0)+(e<<2)>>2]>>2],c[n+8>>2]=t,n)|0);i=n;dY(c[(c[(c[k>>2]|0)+(e<<2)>>2]|0)+20>>2]|0,2195928);q=c[k>>2]|0;p=c[q+(e<<2)>>2]|0;if((c[p+16>>2]|0)==0){u=0;v=q}else{q=0;w=p;while(1){eY(b,c[(c[w+12>>2]|0)+(q<<2)>>2]|0,d,f);p=c[k>>2]|0;x=p+(e<<2)|0;a[l+(c[(c[(c[x>>2]|0)+12>>2]|0)+(q<<2)>>2]|0)|0]=1;y=q+1|0;z=c[x>>2]|0;x=c[z+16>>2]|0;if(y>>>0<x>>>0){q=y;w=z}else{u=x;v=p;break}}}A=u+o|0;w=e+1|0;if(w>>>0<(c[m>>2]|0)>>>0){e=w;o=A;r=v}else{break}}r=c[j>>2]|0;if(!(A>>>0<r>>>0)){B=r;break}KIb(0,32,2188312,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;s=28}}while(0);if((s|0)==28){B=c[j>>2]|0}if((B|0)!=0){s=0;n=B;while(1){if((a[l+s|0]|0)==0){eY(b,s,d,f);C=c[j>>2]|0}else{C=n}B=s+1|0;if(B>>>0<C>>>0){s=B;n=C}else{break}}}kJb(l);i=g;return}function dY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+256|0;f=e|0;if((b|0)==0){i=e;return}do{if((KGb(b)|0)==1){if((LGb(b,2129856,0,0)|0)==0){break}i=e;return}}while(0);KIb(0,32,2613320,(g=i,i=i+8|0,c[g>>2]=d,g)|0);i=g;h=LGb(b,10230264,0,2)|0;if((h|0)==0){i=e;return}j=f|0;f=h;do{h=c[f>>2]|0;if((irc(2129856,h)|0)!=0){k=c[f+4>>2]|0;KIb(0,32,2609232,(g=i,i=i+16|0,c[g>>2]=d,c[g+8>>2]=h,g)|0);i=g;a:do{if((a[k]|0)!=0){h=k;do{l=mc(h|0,2606416)|0;m=l+1|0;CFb(j,h,m>>>0<256>>>0?m:256)|0;KIb(0,32,2604024,(g=i,i=i+8|0,c[g>>2]=j,g)|0);i=g;n=h+l|0;l=a[n]|0;if(l<<24>>24==13){KIb(0,32,2133112,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;o=a[n]|0}else{o=l}if(o<<24>>24==10){KIb(0,32,2602072,(g=i,i=i+16|0,c[g>>2]=d,c[g+8>>2]=10230264,g)|0);i=g;p=a[n]|0}else{p=o}if(p<<24>>24==0){break a}h=h+m|0;}while((a[h]|0)!=0)}}while(0);KIb(0,32,2214224,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}f=LGb(b,10230264,f,2)|0;}while((f|0)!=0);i=e;return}function eY(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+264|0;g=f+256|0;if((e|0)==0){j=(c[a+4>>2]|0)+8|0}else{j=(c[a+8>>2]|0)+28|0}k=c[j>>2]|0;j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;a=j+40|0;l=c[a>>2]|0;m=j+44|0;n=c[m>>2]|0;o=TIb(l,(l|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=o;o=j+88|0;l=LGb(c[o>>2]|0,2129856,0,0)|0;p=f|0;q=j+8|0;w5a(p,256,c[q>>2]|0,e);KIb(0,32,2128304,(e=i,i=i+16|0,c[e>>2]=d,c[e+8>>2]=b,e)|0);i=e;if((k&8|0)!=0){KIb(0,32,2126960,(e=i,i=i+8|0,c[e>>2]=c[j+4>>2],e)|0);i=e}if((l|0)!=0){KIb(0,32,2124744,(e=i,i=i+8|0,c[e>>2]=c[l+4>>2],e)|0);i=e}l=(c[a>>2]|0)/(n|0)|0;k=(c[m>>2]|0)/(n|0)|0;KIb(0,48,2118688,(e=i,i=i+24|0,c[e>>2]=c[j+232>>2],c[e+8>>2]=l,c[e+16>>2]=k,e)|0);i=e;KIb(0,32,2114976,(e=i,i=i+8|0,c[e>>2]=p,e)|0);i=e;p=j+80|0;k=c[p>>2]|0;a:do{if((k|0)!=0){l=c[q>>2]|0;n=j+84|0;b=c[n>>2]|0;d=c[l+224>>2]|0;r=c[l+228>>2]|0;s=Erc(r,(r|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;t=G;u=Erc(d,(d|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;do{if((s|0)==(u|0)&(t|0)==(G|0)){if(!((r|0)==0|(b|0)==0)){break a}if((d|0)==0){break}if((k>>31|0)==(d>>31|0)){break a}}}while(0);d=g|0;r=g+4|0;t=ca(k,c[l+120>>2]|0)|0;u=ca(b,c[l+124>>2]|0)|0;xKb(d,r,t,(t|0)<0|0?-1:0,u,(u|0)<0|0?-1:0,1048576,0)|0;u=c[n>>2]|0;t=c[d>>2]|0;d=c[r>>2]|0;KIb(0,32,2113216,(e=i,i=i+32|0,c[e>>2]=c[p>>2],c[e+8>>2]=u,c[e+16>>2]=t,c[e+24>>2]=d,e)|0);i=e}}while(0);do{if((c[(c[q>>2]|0)+8>>2]|0)==0){p=c[j+96>>2]|0;do{if((p|0)!=0){k=c[j+92>>2]|0;if((k|0)==0){break}v=+(k|0)/+(p|0);k=Lc(+(v*100.0))|0;g=k;d=(k|0)<0|0?-1:0;k=Grc(g,d,100,0)|0;if(!((k|0)==0&(G|0)==0)){KIb(0,32,2623480,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=2111328,e)|0);i=e;break}k=Grc(g,d,1e5,0)|0;if((k|0)==0&(G|0)==0){KIb(0,32,2619552,(e=i,i=i+16|0,h[e>>3]=v/1.0e3,c[e+8>>2]=2111328,e)|0);i=e;break}else{KIb(0,32,2622032,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=2111328,e)|0);i=e;break}}}while(0);p=c[j+416>>2]|0;do{if((p|0)!=0){n=c[j+412>>2]|0;if((n|0)==0){break}v=+(n|0)/+(p|0);n=Lc(+(v*100.0))|0;l=n;b=(n|0)<0|0?-1:0;n=Grc(l,b,100,0)|0;if(!((n|0)==0&(G|0)==0)){KIb(0,32,2623480,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=2109664,e)|0);i=e;break}n=Grc(l,b,1e5,0)|0;if((n|0)==0&(G|0)==0){KIb(0,32,2619552,(e=i,i=i+16|0,h[e>>3]=v/1.0e3,c[e+8>>2]=2109664,e)|0);i=e;break}else{KIb(0,32,2622032,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=2109664,e)|0);i=e;break}}}while(0);p=c[m>>2]|0;do{if((p|0)!=0){n=c[a>>2]|0;if((n|0)==0){break}v=1.0/(+(n|0)/+(p|0));n=Lc(+(v*100.0))|0;b=n;l=(n|0)<0|0?-1:0;n=Grc(b,l,100,0)|0;if(!((n|0)==0&(G|0)==0)){KIb(0,32,2623480,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=2108064,e)|0);i=e;break}n=Grc(b,l,1e5,0)|0;if((n|0)==0&(G|0)==0){KIb(0,32,2619552,(e=i,i=i+16|0,h[e>>3]=v/1.0e3,c[e+8>>2]=2108064,e)|0);i=e;break}else{KIb(0,32,2622032,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=2108064,e)|0);i=e;break}}}while(0);p=c[q>>2]|0;n=c[p+108>>2]|0;if((n|0)==0){break}l=c[p+104>>2]|0;if((l|0)==0){break}v=1.0/(+(l|0)/+(n|0));n=Lc(+(v*100.0))|0;l=n;p=(n|0)<0|0?-1:0;n=Grc(l,p,100,0)|0;if(!((n|0)==0&(G|0)==0)){KIb(0,32,2623480,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=2106744,e)|0);i=e;break}n=Grc(l,p,1e5,0)|0;if((n|0)==0&(G|0)==0){KIb(0,32,2619552,(e=i,i=i+16|0,h[e>>3]=v/1.0e3,c[e+8>>2]=2106744,e)|0);i=e;break}else{KIb(0,32,2622032,(e=i,i=i+16|0,h[e>>3]=v,c[e+8>>2]=2106744,e)|0);i=e;break}}}while(0);q=j+72|0;j=c[q>>2]|0;if((j&1|0)==0){w=j}else{KIb(0,32,2105408,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;w=c[q>>2]|0}if((w&2|0)==0){x=w}else{KIb(0,32,2644432,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;x=c[q>>2]|0}if((x&4|0)==0){y=x}else{KIb(0,32,2642896,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;y=c[q>>2]|0}if((y&8|0)==0){z=y}else{KIb(0,32,2636776,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;z=c[q>>2]|0}if((z&16|0)==0){A=z}else{KIb(0,32,2633016,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;A=c[q>>2]|0}if((A&32|0)==0){B=A}else{KIb(0,32,2630832,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;B=c[q>>2]|0}if((B&64|0)==0){C=B}else{KIb(0,32,2629016,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;C=c[q>>2]|0}if((C&128|0)==0){D=C}else{KIb(0,32,2627496,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;D=c[q>>2]|0}if((D&256|0)==0){E=D}else{KIb(0,32,2626160,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;E=c[q>>2]|0}if((E&512|0)==0){KIb(0,32,2214224,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;F=c[o>>2]|0;dY(F,2195928);i=f;return}KIb(0,32,2624872,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;KIb(0,32,2214224,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;F=c[o>>2]|0;dY(F,2195928);i=f;return}function fY(){var a=0,b=0,c=0,d=0,e=0;a=jLb()|0;b=G;c=Drc(a,b,1e3,0)|0;d=G;e=wrc(a,b,1220321280,514320)|0;b=xrc(e,G,c,d)|0;return(G=G,b)|0}function gY(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=i;if((h|0)<=0){i=j;return}k=(e|0)!=0;l=0;do{m=h-l|0;n=(m|0)>16?16:m;if(k){Id(e|0,2138448,(o=i,i=i+8|0,c[o>>2]=l,o)|0)|0;i=o;p=0}else{KIb(b,f,2138448,(o=i,i=i+8|0,c[o>>2]=l,o)|0);i=o;p=0}do{do{if((p|0)<(n|0)){m=d[g+(p+l)|0]|0;if(k){Id(e|0,2136720,(o=i,i=i+8|0,c[o>>2]=m,o)|0)|0;i=o;break}else{KIb(b,f,2136720,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;break}}else{if(k){ub(2134696,3,1,e|0)|0;break}else{KIb(b,f,2134696,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);p=p+1|0;}while((p|0)<16);if(k){sb(32,e|0)|0}else{KIb(b,f,2133112,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}if((n|0)>0){m=0;do{q=a[g+(m+l)|0]|0;r=(q-32&255)>>>0>94>>>0?46:q&255;if(k){sb(r|0,e|0)|0}else{KIb(b,f,2131232,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o}m=m+1|0;}while((m|0)<(n|0))}if(k){sb(10,e|0)|0}else{KIb(b,f,2214224,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}l=l+16|0;}while((l|0)<(h|0));i=j;return}function hY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gY(a,0,b,c,d);return}function iY(a,b,d,e,f,g,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0,r=0;k=i;l=(b|0)!=0;m=c[e+32>>2]|0;if(l){Id(b|0,2158328,(n=i,i=i+8|0,c[n>>2]=m,n)|0)|0;i=n;Id(b|0,2156432,(n=i,i=i+8|0,c[n>>2]=c[e+36>>2]&1,n)|0)|0;i=n}else{KIb(a,d,2158328,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;KIb(a,d,2156432,(n=i,i=i+8|0,c[n>>2]=c[e+36>>2]&1,n)|0);i=n}o=+(g|0)/+(j|0);p=+(c[e+48>>2]|0)*o;if(l){Id(b|0,2154944,(n=i,i=i+8|0,h[n>>3]=p,n)|0)|0;i=n;ub(2152952,6,1,b|0)|0}else{KIb(a,d,2154944,(n=i,i=i+8|0,h[n>>3]=p,n)|0);i=n;KIb(a,d,2152952,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}j=e+16|0;g=c[j>>2]|0;m=c[j+4>>2]|0;do{if((g|0)==0&(m|0)==(-2147483648|0)){if(l){ub(2232248,3,1,b|0)|0;q=15;break}else{KIb(a,d,2232248,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=14;break}}else{p=o*(+(g>>>0)+ +(m|0)*4294967296.0);if(l){Id(b|0,2150624,(n=i,i=i+8|0,h[n>>3]=p,n)|0)|0;i=n;q=15;break}else{KIb(a,d,2150624,(n=i,i=i+8|0,h[n>>3]=p,n)|0);i=n;q=14;break}}}while(0);if((q|0)==14){KIb(a,d,2148792,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}else if((q|0)==15){ub(2148792,6,1,b|0)|0}m=e+8|0;g=c[m>>2]|0;j=c[m+4>>2]|0;do{if((g|0)==0&(j|0)==(-2147483648|0)){if(l){ub(2232248,3,1,b|0)|0;q=24;break}else{KIb(a,d,2232248,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=23;break}}else{p=o*(+(g>>>0)+ +(j|0)*4294967296.0);if(l){Id(b|0,2150624,(n=i,i=i+8|0,h[n>>3]=p,n)|0)|0;i=n;q=24;break}else{KIb(a,d,2150624,(n=i,i=i+8|0,h[n>>3]=p,n)|0);i=n;q=23;break}}}while(0);if((q|0)==23){KIb(a,d,2214224,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=e+28|0;KIb(a,d,2142176,(n=i,i=i+8|0,c[n>>2]=c[l>>2],n)|0);i=n;r=l}else if((q|0)==24){sb(10,b|0)|0;q=e+28|0;Id(b|0,2142176,(n=i,i=i+8|0,c[n>>2]=c[q>>2],n)|0)|0;i=n;r=q}if((f|0)==0){i=k;return}gY(0,b,0,c[e+24>>2]|0,c[r>>2]|0);i=k;return}function jY(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;iY(a,0,b,d,e,c[f+40>>2]|0,c[f+44>>2]|0);return}function kY(b,d,e,f,g,h,i,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;m=(i|0)!=0;if(m){c[i>>2]=-1}if((d|0)>0){a[b]=0}if((f|0)>0){a[e]=0}if((h|0)>0){a[g]=0}if((k|0)>0){a[j]=0}n=_b(l|0,58)|0;if((n|0)==0){CFb(j,l,k)|0;return}o=n+1|0;p=o-l|0;CFb(b,l,(p|0)<(d|0)?p:d)|0;d=(a[o]|0)==47?n+2|0:o;o=(a[d]|0)==47?d+1|0:d;d=_b(o|0,47)|0;n=_b(o|0,63)|0;do{if((d|0)==0){q=n;r=16}else{if((n|0)==0){s=d;r=17;break}q=d>>>0>n>>>0?n:d;r=16}}while(0);do{if((r|0)==16){if((q|0)!=0){s=q;r=17;break}t=o+(lrc(o|0)|0)|0}}while(0);if((r|0)==17){CFb(j,s,k)|0;t=s}if((t|0)==(o|0)){return}s=_b(o|0,64)|0;if((s|0)!=0&s>>>0<t>>>0){k=o;j=s;while(1){s=j+1|0;r=s-k|0;CFb(e,o,(r|0)<(f|0)?r:f)|0;r=_b(s|0,64)|0;if((r|0)!=0&r>>>0<t>>>0){j=r}else{u=s;break}}}else{u=o}do{if((a[u]|0)==91){o=_b(u|0,93)|0;if(!((o|0)!=0&o>>>0<t>>>0)){break}j=o-u|0;CFb(g,u+1|0,(j|0)<(h|0)?j:h)|0;if((a[o+1|0]|0)!=58|m^1){return}c[i>>2]=kd(o+2|0)|0;return}}while(0);o=_b(u|0,58)|0;if(!((o|0)!=0&o>>>0<t>>>0)){j=t+1-u|0;CFb(g,u,(j|0)>(h|0)?h:j)|0;return}j=o+1|0;o=j-u|0;CFb(g,u,(o|0)>(h|0)?h:o)|0;if(!m){return}c[i>>2]=kd(j|0)|0;return}function lY(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=(f|0)!=0?1402968:1402952;if((e|0)>0){h=0}else{return b|0}do{f=c+h|0;i=h<<1;a[b+i|0]=a[g+((d[f]|0)>>>4)|0]|0;a[b+(i|1)|0]=a[g+(a[f]&15)|0]|0;h=h+1|0;}while((h|0)<(e|0));return b|0}function mY(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(b|0)==0;e=0;f=c;a:while(1){c=1;g=f;do{h=ud(g|0,2183376)|0;i=a[g+h|0]|0;if(i<<24>>24==0){j=11;break a}g=g+(h+1)|0;h=i&255;i=(h-97|0)>>>0<26>>>0?h^32:h;h=i-48|0;if(h>>>0<10>>>0){k=h}else{if(!((i-65|0)>>>0<6>>>0)){j=11;break a}k=i-55|0}c=k|c<<4;}while((c&256|0)==0);if(!d){a[b+e|0]=c}e=e+1|0;f=g}if((j|0)==11){return e|0}return 0}function nY(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+16|0;g=f|0;h=f+8|0;c[g>>2]=0;c[h>>2]=0;j=a[b]|0;if(j<<24>>24==0){i=f;return}else{k=b;l=j}a:while(1){do{if((OFb(l<<24>>24)|0)==0){j=a[k]|0;if((j<<24>>24|0)==44){break}else if((j<<24>>24|0)==0){m=25;break a}j=_b(k|0,61)|0;if((j|0)==0){m=25;break a}b=j+1|0;pe[d&1023](e,k,b-k|0,g,h);n=(c[g>>2]|0)+((c[h>>2]|0)-1)|0;o=a[b]|0;b:do{if((o<<24>>24|0)==0){p=b}else if((o<<24>>24|0)==34){q=j+2|0;while(1){r=a[q]|0;if((r<<24>>24|0)==0|(r<<24>>24|0)==34){break}else if((r<<24>>24|0)!=92){s=c[g>>2]|0;if((s|0)!=0&s>>>0<n>>>0){c[g>>2]=s+1;a[s]=r}q=q+1|0;continue}s=a[q+1|0]|0;if(s<<24>>24==0){break}t=c[g>>2]|0;if((t|0)!=0&t>>>0<n>>>0){c[g>>2]=t+1;a[t]=s}q=q+2|0}p=r<<24>>24==34?q+1|0:q}else{s=b;t=o;while(1){if((OFb(t<<24>>24)|0)!=0){p=s;break b}u=a[s]|0;if(u<<24>>24==44){p=s;break b}v=c[g>>2]|0;if((v|0)!=0&v>>>0<n>>>0){c[g>>2]=v+1;a[v]=u}u=s+1|0;v=a[u]|0;if(v<<24>>24==0){p=u;break}else{s=u;t=v}}}}while(0);n=c[g>>2]|0;if((n|0)!=0){a[n]=0}c[g>>2]=0;c[h>>2]=0;n=a[p]|0;if(n<<24>>24==0){m=25;break a}else{k=p;l=n;continue a}}}while(0);n=k+1|0;o=a[n]|0;if(o<<24>>24==0){m=25;break}else{k=n;l=o}}if((m|0)==25){i=f;return}}function oY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+28|0;e=c[a+24>>2]|0;a=0;while(1){if(!(a>>>0<e>>>0)){f=-1;g=4;break}if((c[(c[(c[d>>2]|0)+(a<<2)>>2]|0)+4>>2]|0)==(b|0)){f=a;g=4;break}else{a=a+1|0}}if((g|0)==4){return f|0}return 0}function pY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=i;i=i+96|0;c=b|0;d=b+48|0;mrc(c|0,0,44)|0;mrc(d|0,0,44)|0;e=gKb(a,2168984,c)|0;if((gKb(a,2164344,d)|0)!=0&(e|0)==0){f=hKb(d)|0}else{f=hKb(c)|0}i=b;return(G=(f|0)<0|0?-1:0,f)|0}function qY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((a|0)!=0){e=c[a+64>>2]|0;if((e|0)!=0){f=We[e&2047](b,d)|0;return f|0}e=c[a+32>>2]|0;if((e|0)==0){if((c[a+20>>2]|0)==(b|0)){f=1;return f|0}if((c[a+16>>2]|0)==(b|0)){f=1;return f|0}if((c[a+24>>2]|0)==(b|0)){f=1}else{break}return f|0}g=c[e>>2]|0;if((g|0)==0){f=0;return f|0}else{h=0;i=g}a:while(1){j=i;while(1){g=c[j>>2]|0;if((g|0)==0){break}if((g|0)==(b|0)){break a}else{j=j+8|0}}g=h+1|0;k=c[e+(g<<2)>>2]|0;if((k|0)==0){f=0;l=15;break}else{h=g;i=k}}if((l|0)==15){return f|0}f=(c[j+4>>2]|0)!=0|0;return f|0}}while(0);f=-1163346256;return f|0}function rY(){return 0}function sY(){return 0}function tY(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((b|0)==0){i=-22;return i|0}j=(c|0)!=0;k=j&1;l=j?8:4;m=(d|0)!=0|(e|0)!=0;if(m){n=l+8|0;o=k|2}else{n=l;o=k}k=(f|0)!=0;if(k){p=n+4|0;q=o|4}else{p=n;q=o}o=(h|g|0)==0;if(o){r=p;s=q}else{r=p+8|0;s=q|8}q=U1(b,2,r)|0;if((q|0)==0){i=-12;return i|0}r=q;y=s;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;if(j){j=r;y=c;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;t=q+8|0}else{t=r}if(m){m=t;r=m|0;y=d;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+4|0;y=e;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;u=t+8|0}else{u=t}if(k){k=u;y=f;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;v=u+4|0}else{v=u}if(o){i=0;return i|0}o=v;y=g;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=v+4|0;y=h;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;i=0;return i|0}function uY(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+8|0;b=e|0;f=b;g=i;i=i+8|0;h=g;j=i;i=i+8|0;k=d+412|0;l=c[k>>2]|0;m=c[k+4>>2]|0;c[b>>2]=l;c[b+4>>2]=m;k=c[d+8>>2]|0;n=c[k+104>>2]|0;o=c[k+108>>2]|0;p=d+92|0;d=c[p>>2]|0;q=c[p+4>>2]|0;c[g>>2]=d;c[g+4>>2]=q;g=d;p=q;r=l;s=m;do{if((g|0)>0&(p|0)>0&(r|0)>0&(s|0)>0){if(!(+(g|0)/+(p|0)<70.0)){t=r;u=s;v=m;w=l;break}if(!(+(r|0)/+(s|0)>210.0)){t=r;u=s;v=m;w=l;break}c[b>>2]=d;c[b+4>>2]=q;t=g;u=p;v=q;w=d}else{t=r;u=s;v=m;w=l}}while(0);l=c[k+112>>2]|0;do{if((l|0)>1){k=ca(l,n)|0;if(!((o|0)>0&(k|0)>0)){x=v;y=w;break}if(!(+(o|0)/+(k|0)<+(t|0)/+(u|0)*.7)){x=v;y=w;break}zKb(j,h,f);if(+R(+(1.0- +(c[j>>2]|0)/+(c[j+4>>2]|0)))>.1){m=o|0;s=k|0;c[b>>2]=m;c[b+4>>2]=s;x=s;y=m;break}else{x=c[b+4>>2]|0;y=c[b>>2]|0;break}}else{x=v;y=w}}while(0);w=a;c[w>>2]=y;c[w+4>>2]=x;i=e;return}function vY(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=a[e]|0;if((j-48&255)>>>0<10>>>0){k=rb(e|0,0,0)|0;l=(k|0)==(c[d>>2]|0)|0;i=f;return l|0}a:do{switch(j<<24>>24){case 112:{if((a[e+1|0]|0)!=58){break a}k=rb(e+2|0,g|0,0)|0;m=c[b+1104>>2]|0;if((m|0)==0){l=0;i=f;return l|0}n=b+1108|0;o=c[n>>2]|0;p=d|0;q=0;b:while(1){r=c[o+(q<<2)>>2]|0;c:do{if((c[r>>2]|0)==(k|0)){s=c[g>>2]|0;t=s+1|0;c[g>>2]=t;if((a[s]|0)==58){u=24;break b}s=c[r+16>>2]|0;v=r+12|0;w=0;while(1){if(!(w>>>0<s>>>0)){break c}if((c[p>>2]|0)==(c[(c[v>>2]|0)+(w<<2)>>2]|0)){l=1;u=33;break b}else{w=w+1|0}}}}while(0);r=q+1|0;if(r>>>0<m>>>0){q=r}else{l=0;u=33;break}}if((u|0)==24){m=rb(t|0,0,0)|0;if(!((m|0)>-1)){l=0;i=f;return l|0}k=c[(c[n>>2]|0)+(q<<2)>>2]|0;if(!(m>>>0<(c[k+16>>2]|0)>>>0)){l=0;i=f;return l|0}l=(c[p>>2]|0)==(c[(c[k+12>>2]|0)+(m<<2)>>2]|0)|0;i=f;return l|0}else if((u|0)==33){i=f;return l|0}break};case 0:{l=1;i=f;return l|0};case 118:case 97:case 115:case 100:case 116:{switch(j<<24>>24|0){case 118:{x=0;break};case 116:{x=4;break};case 97:{x=1;break};case 100:{x=2;break};case 115:{x=3;break};default:{KIb(0,0,2533912,(y=i,i=i+24|0,c[y>>2]=2162240,c[y+8>>2]=2504288,c[y+16>>2]=4436,y)|0);i=y;Hd();return 0}}if((x|0)!=(c[(c[d+8>>2]|0)+8>>2]|0)){l=0;i=f;return l|0}if((a[e+1|0]|0)!=58){l=1;i=f;return l|0}m=rb(e+2|0,0,0)|0;k=c[b+24>>2]|0;if((k|0)==0){l=0;i=f;return l|0}o=c[b+28>>2]|0;r=0;w=m;while(1){if((c[(c[(c[o+(r<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==(x|0)){if((w|0)==0){break}else{z=w-1|0}}else{z=w}m=r+1|0;if(m>>>0<k>>>0){r=m;w=z}else{l=0;u=33;break}}if((u|0)==33){i=f;return l|0}l=(r|0)==(c[d>>2]|0)|0;i=f;return l|0};case 35:{w=rb(e+1|0,h|0,0)|0;if((a[c[h>>2]|0]|0)!=0){break a}l=(c[d+4>>2]|0)==(w|0)|0;i=f;return l|0};default:{}}}while(0);KIb(b,16,2160152,(y=i,i=i+8|0,c[y>>2]=e,y)|0);i=y;l=-22;i=f;return l|0}function wY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+8|0;a=c[b>>2]|0;d=c[a+120>>2]|0;do{if((d|0)==1920){e=(c[a+408>>2]|0)==1;f=e?1383176:1383264;g=e?81:97}else if((d|0)==1440){f=1382976;g=97}else{e=(d|0)==1280;if(e){f=e?1383080:0;g=e?89:0;break}else{h=0}return h|0}}while(0);mJb(a+96|0);a=c[b>>2]|0;d=hJb(g+16|0)|0;c[a+96>>2]=d;if((d|0)==0){c[a+100>>2]=0;h=-12;return h|0}else{mrc(d+g|0,0,16)|0;c[a+100>>2]=g;nrc(c[(c[b>>2]|0)+96>>2]|0,f|0,g)|0;h=0;return h|0}return 0}function xY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=a+24|0;do{if((c[g>>2]|0)!=0){j=a+28|0;k=f|0;l=f+4|0;m=d|0;n=d+4|0;o=a+1104|0;p=a+1108|0;q=e|0;r=e+4|0;s=-2147483648;t=0;u=-2147483648;v=0;w=0;x=2147483647;y=-1;z=2147483647;A=-1;while(1){B=c[(c[j>>2]|0)+(w<<2)>>2]|0;C=B+48|0;D=c[C>>2]|0;E=c[C+4>>2]|0;a:do{if((D|0)==0&(E|0)==(-2147483648|0)){F=z;H=A;I=x;J=y;K=u;L=v}else{C=B+40|0;if((c[B+44>>2]|0)==0){F=z;H=A;I=x;J=y;K=u;L=v;break}c[m>>2]=1;c[n>>2]=1e6;M=XIb(D,E,C,d)|0;N=G;if(((c[(c[B+8>>2]|0)+8>>2]|0)-2|0)>>>0<2>>>0){O=(N|0)<(x|0)|(N|0)==(x|0)&M>>>0<y>>>0;P=z;Q=A;R=O?N:x;S=O?M:y}else{O=(z|0)>(N|0)|(z|0)==(N|0)&A>>>0>M>>>0;P=O?N:z;Q=O?M:A;R=x;S=y}O=B+56|0;T=c[O>>2]|0;U=c[O+4>>2]|0;if((T|0)==0&(U|0)==(-2147483648|0)){V=u;W=v;X=-2147483648;Y=0}else{c[q>>2]=1;c[r>>2]=1e6;O=XIb(T,U,C,e)|0;C=wrc(O,G,M,N)|0;O=G;U=(u|0)>(O|0)|(u|0)==(O|0)&v>>>0>C>>>0;V=U?u:O;W=U?v:C;X=O;Y=C}C=c[o>>2]|0;if((C|0)==0){F=P;H=Q;I=R;J=S;K=V;L=W;break}O=c[p>>2]|0;U=0;T=0;b:while(1){Z=c[O+(T<<2)>>2]|0;c:do{if((Z|0)==(U|0)){_=0}else{if((U|0)!=0){_=U;break}$=c[Z+16>>2]|0;aa=Z+12|0;ba=0;while(1){if(!(ba>>>0<$>>>0)){_=0;break c}if((c[(c[aa>>2]|0)+(ba<<2)>>2]|0)==(w|0)){break}else{ba=ba+1|0}}if((Z|0)==0){F=P;H=Q;I=R;J=S;K=V;L=W;break a}ba=Z+40|0;aa=c[ba>>2]|0;$=c[ba+4>>2]|0;if((aa|0)==0&($|0)==(-2147483648|0)|(($|0)>(N|0)|($|0)==(N|0)&aa>>>0>M>>>0)){c[ba>>2]=M;c[ba+4>>2]=N}ba=Z+48|0;aa=c[ba+4>>2]|0;if(!((aa|0)<(X|0)|(aa|0)==(X|0)&(c[ba>>2]|0)>>>0<Y>>>0)){U=Z;T=0;continue b}c[ba>>2]=Y;c[ba+4>>2]=X;U=Z;T=0;continue b}}while(0);Z=T+1|0;if(Z>>>0<C>>>0){U=_;T=Z}else{F=P;H=Q;I=R;J=S;K=V;L=W;break}}}}while(0);E=B+56|0;D=c[E>>2]|0;T=c[E+4>>2]|0;if((D|0)==0&(T|0)==(-2147483648|0)){ca=s;da=t}else{c[k>>2]=1;c[l>>2]=1e6;E=XIb(D,T,B+40|0,f)|0;T=G;D=(s|0)>(T|0)|(s|0)==(T|0)&t>>>0>E>>>0;ca=D?s:T;da=D?t:E}E=w+1|0;if(E>>>0<(c[g>>2]|0)>>>0){s=ca;t=da;u=K;v=L;w=E;x=I;y=J;z=F;A=H}else{break}}do{if((H|0)==(-1|0)&(F|0)==2147483647){ea=I;fa=J}else{A=(F|0)>(I|0)|(F|0)==(I|0)&H>>>0>J>>>0;z=xrc(H,F,J,I)|0;y=G;x=0;w=A&((y|0)<(x|0)|(y|0)==(x|0)&z>>>0<1e6>>>0);if(w|A^1){ea=w?I:F;fa=w?J:H;break}KIb(a,40,2596240,(w=i,i=i+8|0,h[w>>3]=(+(J>>>0)+ +(I|0)*4294967296.0)/1.0e6,w)|0);i=w;ea=F;fa=H}}while(0);do{if((fa|0)==(-1|0)&(ea|0)==2147483647){ga=ca;ha=da}else{w=a+1056|0;c[w>>2]=fa;c[w+4>>2]=ea;if((L|0)==0&(K|0)==(-2147483648|0)){ga=ca;ha=da;break}w=c[a+1104>>2]|0;if((w|0)==0){A=xrc(L,K,fa,ea)|0;z=G;x=(ca|0)>(z|0)|(ca|0)==(z|0)&da>>>0>A>>>0;ga=x?ca:z;ha=x?da:A;break}A=c[a+1108>>2]|0;x=ca;z=da;y=0;while(1){v=c[A+(y<<2)>>2]|0;u=v+40|0;t=c[u>>2]|0;s=c[u+4>>2]|0;do{if((t|0)==0&(s|0)==(-2147483648|0)){ia=x;ja=z}else{u=v+48|0;l=c[u>>2]|0;k=c[u+4>>2]|0;if(!((k|0)>(s|0)|(k|0)==(s|0)&l>>>0>t>>>0)){ia=x;ja=z;break}u=xrc(l,k,t,s)|0;k=G;l=(x|0)>(k|0)|(x|0)==(k|0)&z>>>0>u>>>0;ia=l?x:k;ja=l?z:u}}while(0);s=y+1|0;if(s>>>0<w>>>0){x=ia;z=ja;y=s}else{ga=ia;ha=ja;break}}}}while(0);y=0;if(!((ga|0)>(y|0)|(ga|0)==(y|0)&ha>>>0>0>>>0)){break}y=a+1064|0;if(!((c[y>>2]|0)==0&(c[y+4>>2]|0)==(-2147483648|0))){break}c[y>>2]=ha;c[y+4>>2]=ga}}while(0);ga=c[a+16>>2]|0;if((ga|0)==0){i=b;return}ha=iD(ga)|0;ga=G;ja=0;if(!((ga|0)>(ja|0)|(ga|0)==(ja|0)&ha>>>0>0>>>0)){i=b;return}ja=a+1064|0;ia=c[ja>>2]|0;da=c[ja+4>>2]|0;if((ia|0)==0&(da|0)==(-2147483648|0)){i=b;return}ka=(+(ha>>>0)+ +(ga|0)*4294967296.0)*8.0*1.0e6/(+(ia>>>0)+ +(da|0)*4294967296.0);if(!(ka>=0.0&ka<=2147483647.0)){i=b;return}c[a+1072>>2]=~~ka;i=b;return}function yY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;e=i;i=i+168|0;f=e|0;g=e+80|0;h=e+160|0;j=f;mrc(j|0,0,80)|0;mrc(g|0,0,80)|0;k=c[(c[a+28>>2]|0)+(d<<2)>>2]|0;do{if((b|0)==0){J1(g);l=g;m=1;n=0;o=0}else{d=c[b+24>>2]|0;p=c[b+28>>2]|0;if((p|0)!=0){l=b;m=0;n=p;o=d;break}p=c[k+240>>2]|0;if((c[p+176>>2]&1|0)==0){l=b;m=0;n=0;o=d;break}zY(a,k,p,b);l=b;m=0;n=0;o=d}}while(0);b=k+240|0;d=k+8|0;p=f+24|0;q=f+28|0;r=l+8|0;s=l+16|0;t=l+64|0;u=(l|0)==(g|0);g=l+40|0;v=f+48|0;w=h|0;x=h+4|0;y=k+40|0;z=k|0;A=f+32|0;B=f+8|0;C=f+16|0;D=f+64|0;E=k+236|0;F=l+36|0;G=f+36|0;H=l+24|0;I=l+28|0;J=l|0;K=f|0;L=l+52|0;M=f+52|0;N=a+1264|0;O=a+1268|0;P=f+40|0;Q=l+44|0;R=f+44|0;S=m;m=0;T=n;n=o;a:while(1){if(u){o=S;U=T;V=n;while(1){if((U|0)<1&(o|0)==0){W=38;break a}J1(f);X=FWa(c[b>>2]|0,c[d>>2]|0,p,q,V,U,c[r>>2]|0,c[r+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;c[s>>2]=0;c[s+4>>2]=-2147483648;c[r>>2]=0;c[r+4>>2]=-2147483648;c[t>>2]=-1;c[t+4>>2]=-1;Y=V+X|0;Z=U-X|0;X=(c[q>>2]|0)!=0;_=X&1;if(X){$=Y;aa=Z;ba=_;break}else{o=_;U=Z;V=Y}}}else{V=T;U=n;while(1){if((V|0)<=0){W=38;break a}J1(f);o=FWa(c[b>>2]|0,c[d>>2]|0,p,q,U,V,c[r>>2]|0,c[r+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;c[s>>2]=0;c[s+4>>2]=-2147483648;c[r>>2]=0;c[r+4>>2]=-2147483648;c[t>>2]=-1;c[t+4>>2]=-1;Y=U+o|0;Z=V-o|0;if((c[q>>2]|0)==0){V=Z;U=Y}else{$=Y;aa=Z;ba=1;break}}}U=c[g>>2]|0;if((U|0)!=0){c[P>>2]=U;c[R>>2]=c[Q>>2];c[g>>2]=0;c[Q>>2]=0}c[v>>2]=0;U=c[d>>2]|0;do{if((c[U+8>>2]|0)==1){V=U+412|0;if((c[V>>2]|0)<=0){break}Z=c[(c[b>>2]|0)+304>>2]|0;c[w>>2]=1;c[x>>2]=c[V>>2];V=WIb(Z,(Z|0)<0|0?-1:0,h,y,2)|0;c[v>>2]=V}else{V=U+104|0;if((c[V>>2]|0)==0){break}if((c[U+108>>2]|0)==0){break}Z=c[(c[b>>2]|0)+304>>2]|0;Y=WIb(Z,(Z|0)<0|0?-1:0,V,y,2)|0;c[v>>2]=Y}}while(0);c[A>>2]=c[z>>2];U=c[b>>2]|0;Y=U+40|0;V=c[Y+4>>2]|0;c[B>>2]=c[Y>>2];c[B+4>>2]=V;V=U+48|0;Y=c[V+4>>2]|0;c[C>>2]=c[V>>2];c[C+4>>2]=Y;Y=U+288|0;V=c[Y+4>>2]|0;c[D>>2]=c[Y>>2];c[D+4>>2]=V;if((c[E>>2]|0)==1463898624){V=U+8|0;Y=c[V+4>>2]|0;c[D>>2]=c[V>>2];c[D+4>>2]=Y}Y=U+224|0;V=c[Y>>2]|0;if((V|0)==(-1|0)){if((c[U+32>>2]|0)==1){W=24}else{W=25}}else if((V|0)==1){W=24}if((W|0)==24){W=0;c[G>>2]=c[G>>2]|1;if((c[Y>>2]|0)==-1){W=25}}do{if((W|0)==25){W=0;if((c[U+32>>2]|0)!=0){break}if((c[F>>2]&1|0)==0){break}c[G>>2]=c[G>>2]|1}}while(0);zY(a,k,U,f);do{if((c[p>>2]|0)==(c[H>>2]|0)){if((c[q>>2]|0)!=(c[I>>2]|0)){break}c[K>>2]=c[J>>2];c[J>>2]=0;c[M>>2]=c[L>>2];c[L>>2]=0}}while(0);U=Q1(f)|0;if((U|0)<0){ca=U;W=40;break}Y=pJb(88)|0;V=Y;if((Y|0)==0){W=37;break}if((c[N>>2]|0)==0){c[N>>2]=V}else{c[(c[O>>2]|0)+80>>2]=V}c[O>>2]=V;nrc(Y|0,j|0,80)|0;S=ba;m=U;T=aa;n=$}if((W|0)==37){P1(f);ca=-12;P1(l);i=e;return ca|0}else if((W|0)==38){if(!u){ca=m;P1(l);i=e;return ca|0}HWa(c[b>>2]|0);c[b>>2]=0;ca=m;P1(l);i=e;return ca|0}else if((W|0)==40){P1(l);i=e;return ca|0}return 0}function zY(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;h=i;i=i+152|0;j=h|0;k=h+32|0;l=h+64|0;m=h+96|0;n=h+128|0;o=h+136|0;p=h+144|0;q=p;r=i;i=i+8|0;s=e+8|0;t=c[s>>2]|0;u=c[t+48>>2]|0;v=b+1084|0;if((c[v>>2]&16|0)!=0){i=h;return}do{if((c[t+8>>2]|0)==0){w=g+16|0;x=c[w>>2]|0;y=c[w+4>>2]|0;if((x|0)==0&(y|0)==(-2147483648|0)){break}z=g+8|0;A=e+640|0;do{if((x|0)==(c[z>>2]|0)&(y|0)==(c[z+4>>2]|0)){B=c[A>>2]|0;C=c[A+4>>2]|0;if((B|0)==0&(C|0)==(-2147483648|0)){break}if((C|0)>(y|0)|(C|0)==(y|0)&B>>>0>x>>>0){D=e+649|0;KIb(b,(a[D]|0)!=0?48:24,2555456,(E=i,i=i+32|0,c[E>>2]=x,c[E+8>>2]=y,c[E+16>>2]=B,c[E+24>>2]=C,E)|0);i=E;C=(a[D]|0)+1&255;a[D]=C;F=a[e+648|0]|0;H=C}else{C=e+648|0;D=(a[C]|0)+1&255;a[C]=D;F=D;H=a[e+649|0]|0}D=e+649|0;if(((H&255)+(F&255)|0)<=250){break}a[e+648|0]=(F&255)>>>1;a[D]=(d[D]|0)>>>1}}while(0);y=c[w+4>>2]|0;c[A>>2]=c[w>>2];c[A+4>>2]=y;if(!((d[e+648|0]|0)>>>0<d[e+649|0]<<3>>>0)){break}if(!((c[w>>2]|0)==(c[z>>2]|0)&(c[w+4>>2]|0)==(c[z+4>>2]|0))){break}c[w>>2]=0;c[w+4>>2]=-2147483648}}while(0);do{if((c[v>>2]&8|0)!=0){F=g+8|0;if((c[F>>2]|0)==0&(c[F+4>>2]|0)==(-2147483648|0)){break}F=g+16|0;c[F>>2]=0;c[F+4>>2]=-2147483648}}while(0);v=(f|0)!=0;a:do{if(v){F=f+32|0;H=(c[s>>2]|0)+176|0;t=c[H>>2]|0;y=(t|0)==0;do{if((c[F>>2]|0)==3){if(!y){I=t;break}c[H>>2]=1;I=1}else{if(y){J=0;K=0;L=1;M=0;break a}else{I=t}}}while(0);J=(c[F>>2]|0)!=3|0;K=I;L=0;M=0}else{t=c[(c[s>>2]|0)+176>>2]|0;J=0;K=t;L=(t|0)==0;M=1}}while(0);I=g+8|0;t=c[I>>2]|0;y=c[I+4>>2]|0;do{if((t|0)==0&(y|0)==(-2147483648|0)){N=-2147483648;O=0}else{H=g+16|0;w=c[H>>2]|0;z=c[H+4>>2]|0;if((w|0)==0&(z|0)==(-2147483648|0)){N=y;O=t;break}A=c[e+188>>2]|0;if((A|0)>=63){N=y;O=t;break}x=yrc(1,0,A-1|0)|0;D=xrc(w,z,x,G)|0;x=G;if(!((x|0)>(y|0)|(x|0)==(y|0)&D>>>0>t>>>0)){N=y;O=t;break}C=e+208|0;B=c[C>>2]|0;P=c[C+4>>2]|0;C=2147352575;Q=yrc(1,0,A|0)|0;A=G;if((P|0)>(C|0)|(P|0)==(C|0)&B>>>0>-1>>>0|((x|0)>(P|0)|(x|0)==(P|0)&D>>>0>B>>>0)){B=xrc(w,z,Q,A)|0;c[H>>2]=B;c[H+4>>2]=G;N=y;O=t;break}else{H=wrc(Q,A,t,y)|0;A=G;c[I>>2]=H;c[I+4>>2]=A;N=A;O=H;break}}}while(0);y=(K|0)==1;do{if(y){t=g+16|0;H=c[t>>2]|0;A=c[t+4>>2]|0;if((H|0)!=(O|0)|(A|0)!=(N|0)|(H|0)==0&(A|0)==(-2147483648|0)|(J|0)==0){break}KIb(b,48,2554160,(E=i,i=i+16|0,c[E>>2]=O,c[E+8>>2]=N,E)|0);i=E;A=c[c[b+4>>2]>>2]|0;if((irc(A,2553208)|0)==0){break}if((irc(A,2551784)|0)==0){break}c[t>>2]=0;c[t+4>>2]=-2147483648}}while(0);N=g+48|0;c[r>>2]=c[N>>2];c[r+4>>2]=1;O=e+40|0;yKb(p,r,O);r=c[N>>2]|0;if((r|0)==0){tX(n,o,e,f,g);t=c[o>>2]|0;do{if((t|0)==0){R=40}else{o=c[n>>2]|0;if((o|0)==0){R=40;break}c[p>>2]=o;c[q+4>>2]=t;A=c[e+44>>2]|0;H=Erc(A,(A|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;o=G;A=c[O>>2]|0;Q=Erc(A,(A|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;A=UIb(1,0,H,o,Q,G,2)|0;Q=A;c[N>>2]=Q;S=Q}}while(0);if((R|0)==40){S=c[N>>2]|0}if((S|0)!=0){T=S;R=42}}else{T=r;R=42}b:do{if((R|0)==42){r=c[b+1236>>2]|0;S=(r|0)==0;if(S){if((c[b+1264>>2]|0)==0){break}}t=c[g+32>>2]|0;p=j|0;n=k|0;Q=l|0;A=m|0;if(S){U=c[b+1264>>2]|0}else{U=r}o=e+200|0;H=c[o>>2]|0;B=c[o+4>>2]|0;c:do{if((H|0)==0&(B|0)==(-2147483648|0)){z=e+208|0;if((c[z>>2]|0)==(-1|0)&(c[z+4>>2]|0)==2147418111){V=2147418111;W=-1;X=U}else{break b}}else{z=e+476|0;if((c[z>>2]|0)!=0){break b}c[z>>2]=1;d:do{if((U|0)!=0){z=T;w=(T|0)<0|0?-1:0;D=b+1240|0;P=b+1264|0;x=U;C=B;Y=H;while(1){if((c[x+32>>2]|0)==(t|0)){Z=x+8|0;_=x+16|0;$=c[_>>2]|0;aa=c[_+4>>2]|0;if(!((c[Z>>2]|0)==($|0)&(c[Z+4>>2]|0)==(aa|0)&(($|0)==0&(aa|0)==(-2147483648|0)))){ba=aa;ca=$;break}if((c[x+48>>2]|0)!=0){ba=-2147483648;ca=0;break}$=xrc(Y,C,z,w)|0;da=G;ea=$}else{da=C;ea=Y}$=c[x+80>>2]|0;if(($|0)!=0){x=$;C=da;Y=ea;continue}if((c[D>>2]|0)!=(x|0)){break d}$=c[P>>2]|0;if(($|0)==0){break d}else{x=$;C=da;Y=ea}}if((ca|0)==(H|0)&(ba|0)==(B|0)){if(S){fa=c[P>>2]|0}else{fa=r}c[o>>2]=Y;c[o+4>>2]=C;V=C;W=Y;X=fa;break c}mrc(p|0,0,32)|0;a[p]=0;Rb(p|0,32,2541576,(E=i,i=i+16|0,c[E>>2]=H,c[E+8>>2]=B,E)|0)|0;i=E;mrc(n|0,0,32)|0;a[n]=0;D=c[_>>2]|0;w=c[_+4>>2]|0;if((D|0)==0&(w|0)==(-2147483648|0)){Rb(n|0,32,2543336,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0)|0;i=E}else{Rb(n|0,32,2541576,(E=i,i=i+16|0,c[E>>2]=D,c[E+8>>2]=w,E)|0)|0;i=E}mrc(Q|0,0,32)|0;a[Q]=0;w=c[Z>>2]|0;D=c[Z+4>>2]|0;if((w|0)==0&(D|0)==(-2147483648|0)){Rb(Q|0,32,2543336,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0)|0;i=E}else{Rb(Q|0,32,2541576,(E=i,i=i+16|0,c[E>>2]=w,c[E+8>>2]=D,E)|0)|0;i=E}D=c[x+48>>2]|0;KIb(b,48,2547584,(E=i,i=i+32|0,c[E>>2]=p,c[E+8>>2]=n,c[E+16>>2]=Q,c[E+24>>2]=D,E)|0);i=E;break b}}while(0);mrc(A|0,0,32)|0;a[A]=0;Rb(A|0,32,2541576,(E=i,i=i+16|0,c[E>>2]=H,c[E+8>>2]=B,E)|0)|0;i=E;KIb(b,48,2544624,(E=i,i=i+8|0,c[E>>2]=A,E)|0);i=E;break b}}while(0);e:do{if((X|0)==0){ga=V;ha=W}else{A=T;B=(T|0)<0|0?-1:0;H=b+1240|0;Q=b+1264|0;n=X;p=V;r=W;while(1){if((c[n+32>>2]|0)==(t|0)){S=n+8|0;F=c[S>>2]|0;D=c[S+4>>2]|0;w=n+16|0;if(!((F|0)==(c[w>>2]|0)&(D|0)==(c[w+4>>2]|0))){break b}if(!((F|0)==0&(D|0)==(-2147483648|0))){if(!((F|0)==(c[o>>2]|0)&(D|0)==(c[o+4>>2]|0))){break b}}D=n+48|0;if((c[D>>2]|0)!=0){break b}c[w>>2]=r;c[w+4>>2]=p;if((c[(c[s>>2]|0)+176>>2]|0)==0){c[S>>2]=r;c[S+4>>2]=p}c[D>>2]=T;D=wrc(r,p,A,B)|0;ia=G;ja=D}else{ia=p;ja=r}D=c[n+80>>2]|0;if((D|0)!=0){n=D;p=ia;r=ja;continue}if((c[H>>2]|0)!=(n|0)){ga=ia;ha=ja;break e}D=c[Q>>2]|0;if((D|0)==0){ga=ia;ha=ja;break}else{n=D;p=ia;r=ja}}}}while(0);o=e+208|0;c[o>>2]=ha;c[o+4>>2]=ga}}while(0);do{if(v){if((c[e+236>>2]|0)!=3){break}ga=c[g+28>>2]|0;if((ga|0)==0){break}ha=f+184|0;ja=c[N>>2]|0;ia=VIb(c[ha>>2]|0,c[ha+4>>2]|0,ja,(ja|0)<0|0?-1:0,ga,(ga|0)<0|0?-1:0)|0;ga=G;ja=c[I>>2]|0;ha=c[I+4>>2]|0;if(!((ja|0)==0&(ha|0)==(-2147483648|0))){T=wrc(ja,ha,ia,ga)|0;c[I>>2]=T;c[I+4>>2]=G}T=g+16|0;ha=c[T>>2]|0;ja=c[T+4>>2]|0;if((ha|0)==0&(ja|0)==(-2147483648|0)){break}W=wrc(ha,ja,ia,ga)|0;c[T>>2]=W;c[T+4>>2]=G}}while(0);T=g+16|0;W=c[T>>2]|0;ga=c[T+4>>2]|0;ia=(W|0)==0&(ga|0)==(-2147483648|0);if(ia){ka=J}else{ja=c[I>>2]|0;ha=c[I+4>>2]|0;ka=((ja|0)!=0|(ha|0)!=(-2147483648|0))&((ha|0)>(ga|0)|(ha|0)==(ga|0)&ja>>>0>W>>>0)?1:J}do{if(L){if(!((u|0)==1211250229|(u|0)==28)){R=97}}else{if(M|y^1){break}if(!((u|0)==1211250229|(u|0)==28)){R=97}}}while(0);do{if((R|0)==97){if((ka|0)==0){y=c[I>>2]|0;M=c[I+4>>2]|0;if((y|0)==0&(M|0)==(-2147483648|0)){if(ia){if((c[N>>2]|0)==0){break}}c[I>>2]=W;c[I+4>>2]=ga;la=ga;ma=W}else{la=M;ma=y}AY(b,c[g+32>>2]|0,ma,la,ma,la);y=c[I>>2]|0;M=c[I+4>>2]|0;if((y|0)==0&(M|0)==(-2147483648|0)){L=e+208|0;J=c[L>>2]|0;ja=c[L+4>>2]|0;c[I>>2]=J;c[I+4>>2]=ja;c[T>>2]=J;c[T+4>>2]=ja;if((J|0)==0&(ja|0)==(-2147483648|0)){break}else{na=ja;oa=J}}else{c[T>>2]=y;c[T+4>>2]=M;na=M;oa=y}y=$Ib(O,oa,na,q,1,0)|0;M=e+208|0;c[M>>2]=y;c[M+4>>2]=G;break}if(ia){M=e+216|0;y=c[M>>2]|0;J=c[M+4>>2]|0;c[T>>2]=y;c[T+4>>2]=J;pa=J;qa=y}else{pa=ga;qa=W}AY(b,c[g+32>>2]|0,qa,pa,c[I>>2]|0,c[I+4>>2]|0);y=c[T>>2]|0;J=c[T+4>>2]|0;if((y|0)==0&(J|0)==(-2147483648|0)){M=e+208|0;ja=c[M>>2]|0;L=c[M+4>>2]|0;c[T>>2]=ja;c[T+4>>2]=L;ra=L;sa=ja}else{ra=J;sa=y}y=e+224|0;J=c[y>>2]|0;if((J|0)==0){ja=c[N>>2]|0;c[y>>2]=ja;ta=ja}else{ta=J}if(!((sa|0)==0&(ra|0)==(-2147483648|0))){J=wrc(ta,(ta|0)<0|0?-1:0,sa,ra)|0;ja=e+208|0;c[ja>>2]=J;c[ja+4>>2]=G}c[y>>2]=c[N>>2];y=c[I+4>>2]|0;ja=e+216|0;c[ja>>2]=c[I>>2];c[ja+4>>2]=y}}while(0);f:do{if(((c[I>>2]|0)!=0|(c[I+4>>2]|0)!=(-2147483648|0))&(K|0)<17){N=c[s>>2]|0;g:do{if((c[N+48>>2]|0)==28){if((c[e+184>>2]|0)==0){break}do{if((c[N+176>>2]|0)!=0){ra=aha(N)|0;sa=c[(c[s>>2]|0)+176>>2]|0;if((ra|0)==(sa|0)){break g}if((sa|0)<3){break}ra=c[e+452>>2]|0;if((sa|0)<4){if((ra|0)>17){break g}else{break f}}else{if((ra|0)>19){break g}else{break f}}}}while(0);if((c[e+452>>2]|0)<=6){break f}}}while(0);N=c[I>>2]|0;ra=c[I+4>>2]|0;sa=e+264|0;c[sa>>2]=N;c[sa+4>>2]=ra;h:do{if((K|0)>0){ta=0;while(1){pa=ta+1|0;qa=e+264+(pa<<3)|0;W=c[qa>>2]|0;ga=c[qa+4>>2]|0;if(!((ra|0)>(ga|0)|(ra|0)==(ga|0)&N>>>0>W>>>0)){break h}ia=e+264+(ta<<3)|0;c[qa>>2]=N;c[qa+4>>2]=ra;c[ia>>2]=W;c[ia+4>>2]=ga;if((pa|0)<(K|0)){ta=pa}else{break}}}}while(0);ra=BY(e,sa,c[T>>2]|0,c[T+4>>2]|0)|0;c[T>>2]=ra;c[T+4>>2]=G}}while(0);if((u|0)==1211250229|(u|0)==28){AY(b,c[g+32>>2]|0,c[T>>2]|0,c[T+4>>2]|0,c[I>>2]|0,c[I+4>>2]|0)}I=c[T>>2]|0;b=c[T+4>>2]|0;T=e+208|0;e=c[T+4>>2]|0;if((b|0)>(e|0)|(b|0)==(e|0)&I>>>0>(c[T>>2]|0)>>>0){c[T>>2]=I;c[T+4>>2]=b}b=c[s>>2]|0;do{if((c[b+8>>2]|0)==0){s=U4a(b)|0;if((s|0)==0){T=u4(c[b+48>>2]|0)|0;V4a(b,T);if((T|0)==0){break}else{ua=T}}else{ua=s}if((c[ua+16>>2]&1|0)!=0){R=137}}else{R=137}}while(0);if((R|0)==137){R=g+36|0;c[R>>2]=c[R>>2]|1}if(!v){i=h;return}v=f+232|0;f=c[v+4>>2]|0;R=g+72|0;c[R>>2]=c[v>>2];c[R+4>>2]=f;i=h;return}function AY(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+136|0;j=h|0;k=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;l=c[a+1236>>2]|0;if((l|0)==0){m=c[a+1264>>2]|0}else{m=l}l=k+200|0;if((c[l>>2]|0)!=0|(c[l+4>>2]|0)!=(-2147483648|0)|(d|0)==0&(e|0)==(-2147483648|0)){i=h;return}n=k+208|0;o=c[n>>2]|0;p=c[n+4>>2]|0;q=2147352575;if((o|0)==0&(p|0)==(-2147483648|0)|((e|0)>(q|0)|(e|0)==(q|0)&d>>>0>-1>>>0)){i=h;return}q=k+8|0;r=c[(c[q>>2]|0)+176>>2]|0;s=wrc(d,e,-1,2147418111)|0;t=xrc(s,G,o,p)|0;p=G;c[l>>2]=t;c[l+4>>2]=p;c[n>>2]=d;c[n+4>>2]=e;e=j|0;c[e>>2]=0;c[e+4>>2]=-2147483648;n=j+8|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+16|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+24|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+32|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+40|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+48|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+56|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+64|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+72|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+80|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+88|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+96|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+104|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+112|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+120|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=j+128|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=wrc(t,p,1,-2147418112)|0;p=G;t=2147352576;d=(g|0)<(t|0)|(g|0)==(t|0)&f>>>0<0>>>0;t=wrc(d?0:n,d?0:p,f,g)|0;g=G;f=k+48|0;a:do{if((m|0)!=0){d=(r|0)<17;l=k+184|0;o=k+452|0;s=(r|0)>0;u=a+1240|0;v=a+1264|0;w=m;while(1){b:do{if((c[w+32>>2]|0)==(b|0)){x=w+8|0;y=c[x>>2]|0;z=c[x+4>>2]|0;A=2147352575;if((z|0)>(A|0)|(z|0)==(A|0)&y>>>0>-1>>>0){A=wrc(y,z,n,p)|0;B=G;c[x>>2]=A;c[x+4>>2]=B;C=B;D=A}else{C=z;D=y}y=w+16|0;z=c[y>>2]|0;A=c[y+4>>2]|0;B=2147352575;if((A|0)>(B|0)|(A|0)==(B|0)&z>>>0>-1>>>0){B=wrc(z,A,n,p)|0;c[y>>2]=B;c[y+4>>2]=G}if((c[f>>2]|0)==0&(c[f+4>>2]|0)==(-2147483648|0)){if((D|0)==0&(C|0)==(-2147483648|0)){break}c[f>>2]=D;c[f+4>>2]=C;E=c[x+4>>2]|0;F=c[x>>2]|0}else{E=C;F=D}if(!(((F|0)!=0|(E|0)!=(-2147483648|0))&d)){break}B=c[q>>2]|0;c:do{if((c[B+48>>2]|0)==28){if((c[l>>2]|0)==0){break}do{if((c[B+176>>2]|0)!=0){A=aha(B)|0;z=c[(c[q>>2]|0)+176>>2]|0;if((A|0)==(z|0)){break c}if((z|0)<3){break}A=c[o>>2]|0;if((z|0)<4){if((A|0)>17){break c}else{break b}}else{if((A|0)>19){break c}else{break b}}}}while(0);if((c[o>>2]|0)<=6){break b}}}while(0);B=c[x>>2]|0;A=c[x+4>>2]|0;c[e>>2]=B;c[e+4>>2]=A;d:do{if(s){z=0;while(1){H=z+1|0;I=j+(H<<3)|0;J=c[I>>2]|0;K=c[I+4>>2]|0;if(!((A|0)>(K|0)|(A|0)==(K|0)&B>>>0>J>>>0)){break d}L=j+(z<<3)|0;c[I>>2]=B;c[I+4>>2]=A;c[L>>2]=J;c[L+4>>2]=K;if((H|0)<(r|0)){z=H}else{break}}}}while(0);A=BY(k,e,c[y>>2]|0,c[y+4>>2]|0)|0;c[y>>2]=A;c[y+4>>2]=G}}while(0);A=c[w+80>>2]|0;if((A|0)!=0){w=A;continue}if((c[u>>2]|0)!=(w|0)){break a}w=c[v>>2]|0;if((w|0)==0){break}}}}while(0);if(!((c[f>>2]|0)==0&(c[f+4>>2]|0)==(-2147483648|0))){i=h;return}c[f>>2]=t;c[f+4>>2]=g;i=h;return}function BY(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;h=c[b+8>>2]|0;i=c[h+48>>2]|0;do{if((i|0)==1211250229|(i|0)==28){j=c[h+176>>2]|0;k=(j|0)>0;if((f|0)==0&(g|0)==(-2147483648|0)){if(k){l=0;m=2147483647;n=-1;o=-2147483648;p=0}else{break}while(1){q=a[b+616+l|0]|0;do{if(q<<24>>24==0){r=o;s=p;t=m;u=n}else{v=b+480+(l<<3)|0;w=Crc(c[v>>2]|0,c[v+4>>2]|0,q&255,0)|0;v=G;if(!((v|0)<(m|0)|(v|0)==(m|0)&w>>>0<n>>>0)){r=o;s=p;t=m;u=n;break}x=e+(l<<3)|0;r=c[x+4>>2]|0;s=c[x>>2]|0;t=v;u=w}}while(0);q=l+1|0;if((q|0)<(j|0)){l=q;m=t;n=u;o=r;p=s}else{y=r;z=s;A=13;break}}}else{if(k){B=0}else{y=g;z=f;A=13;break}while(1){q=e+(B<<3)|0;w=c[q>>2]|0;v=c[q+4>>2]|0;do{if(!((w|0)==0&(v|0)==(-2147483648|0))){q=xrc(w,v,f,g)|0;x=G;C=-1;D=(x|0)>(C|0)|(x|0)==(C|0)&q>>>0>-1>>>0;C=xrc(0,0,q,x)|0;E=b+480+(B<<3)|0;F=c[E>>2]|0;H=c[E+4>>2]|0;I=wrc(F,H,D?q:C,D?x:G)|0;x=G;D=(x|0)>(H|0)|(x|0)==(H|0)&I>>>0>F>>>0;c[E>>2]=D?I:F;c[E+4>>2]=D?x:H;H=b+616+B|0;x=(a[H]|0)+1&255;a[H]=x;if(!((x&255)>>>0>250>>>0)){break}x=c[E+4>>2]|0;c[E>>2]=(c[E>>2]|0)>>>1|x<<31;c[E+4>>2]=x>>1|((x|0)<0|0?-1:0)<<31;a[H]=(d[H]|0)>>>1}}while(0);v=B+1|0;if((v|0)<(j|0)){B=v}else{y=g;z=f;A=13;break}}}}else{y=g;z=f;A=13}}while(0);do{if((A|0)==13){if((z|0)==0&(y|0)==(-2147483648|0)){break}else{J=y;K=z}return(G=J,K)|0}}while(0);J=c[e+4>>2]|0;K=c[e>>2]|0;return(G=J,K)|0}function CY(b){b=b|0;var e=0;if((c[b+8>>2]|0)<24){return 0}e=c[b+4>>2]|0;if(!((a[e+3|0]|0)==-59)){return 0}b=e+4|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==4){b=e+20|0;return((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==12?50:0)|0}else{return 0}return 0}function DY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+16>>2]|0;e=ED(d)|0;if((zD(d)|0)!=197){f=-1;i=b;return f|0}if((FD(d)|0)!=4){f=-1;i=b;return f|0}g=ZX(a,0)|0;if((g|0)==0){f=-1;i=b;return f|0}h=g+8|0;j=c[h>>2]|0;c[j+8>>2]=0;c[j+48>>2]=72;if((QX(j,d,4)|0)<0){f=-12;i=b;return f|0}j=FD(d)|0;c[(c[h>>2]|0)+124>>2]=j;j=FD(d)|0;c[(c[h>>2]|0)+120>>2]=j;if((FD(d)|0)!=12){f=-1;i=b;return f|0}hD(d,8,0)|0;j=FD(d)|0;if((j|0)==(-1|0)){_X(g,32,1,1e3);f=0;i=b;return f|0}else if((j|0)==0){KIb(a,16,2461808,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=1}else{k=j}_X(g,24,1,k);k=g+56|0;c[k>>2]=e;c[k+4>>2]=(e|0)<0|0?-1:0;f=0;i=b;return f|0}function EY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+16>>2]|0;if((jD(d)|0)!=0){e=-5;return e|0}f=ED(d)|0;g=(zD(d)|0)>>>7&1;h=FD(d)|0;if((fX(d,b,f)|0)<0){e=-5;return e|0}if((c[(c[c[a+28>>2]>>2]|0)+44>>2]|0)==1e3){a=b+8|0;c[a>>2]=h;c[a+4>>2]=0}a=b+36|0;c[a>>2]=c[a>>2]|g;g=b+64|0;a=wrc(c[g>>2]|0,c[g+4>>2]|0,-8,-1)|0;c[g>>2]=a;c[g+4>>2]=G;e=c[b+28>>2]|0;return e|0}function FY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+28|0;e=c[(c[c[d>>2]>>2]|0)+8>>2]|0;f=c[a+16>>2]|0;if((c[e+48>>2]|0)!=72){KIb(a,16,2370776,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-1;i=b;return g|0}uD(f,0);bD(f,197);kD(f,4);dD(f,c[e+96>>2]|0,4);kD(f,c[e+124>>2]|0);kD(f,c[e+120>>2]|0);kD(f,12);uD(f,0);bD(f,128);kD(f,0);e=c[c[d>>2]>>2]|0;a=c[e+96>>2]|0;do{if((a|0)==0){h=6}else{if((c[e+92>>2]|0)!=1){h=6;break}kD(f,a)}}while(0);if((h|0)==6){kD(f,-1)}_X(c[c[d>>2]>>2]|0,32,1,1e3);g=0;i=b;return g|0}function GY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[a+16>>2]|0;e=b+28|0;f=c[e>>2]|0;if((f|0)==0){return 0}g=c[a+12>>2]|0;kD(d,c[b+36>>2]<<31|f);kD(d,c[b+8>>2]|0);dD(d,c[b+24>>2]|0,c[e>>2]|0);e=g;c[e>>2]=(c[e>>2]|0)+1;return 0}function HY(a){a=a|0;var b=0,d=0;b=c[a+16>>2]|0;if((c[b+88>>2]|0)==0){return 0}d=c[a+12>>2]|0;fD(b,0,0,0)|0;uD(b,c[d>>2]|0);eD(b);return 0}function IY(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[b+4>>2]|0;do{if((a[e]|0)==0){b=e+2|0;f=d[e+1|0]|0;g=f&127;if((f&128|0)==0){h=g;i=f;j=b}else{f=d[b]|0;h=f&127|g<<7;i=f;j=e+3|0}if((i&128|0)!=0){break}if((h-21|0)>>>0>1003>>>0){break}if((grc(j,2461096,15)|0)==0){k=100}else{break}return k|0}}while(0);k=0;return k|0}function JY(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[b+12>>2]|0;h=ZX(b,0)|0;j=ZX(b,0)|0;if((j|0)==0|(h|0)==0){k=-12;i=d;return k|0}l=j+8|0;c[(c[l>>2]|0)+412>>2]=8e3;m=LY(b)|0;if((m|0)<0){k=m;i=d;return k|0}m=g+8|0;n=g+4|0;o=g+12|0;p=b;q=b+16|0;r=g+16|0;s=h+8|0;t=f|0;u=f+4|0;v=b+1140|0;w=1;x=25;y=0;z=0;a:while(1){while(1){if((c[m>>2]|0)!=0){A=39;break a}if((c[n>>2]|0)!=0){A=39;break a}B=c[o>>2]|0;if((B|0)<1025){break}KIb(p,24,2252672,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;D=c[o>>2]|0;hD(c[q>>2]|0,D,(D|0)<0|0?-1:0)|0;D=LY(b)|0;if((D|0)<0){k=D;A=45;break a}}AD(c[q>>2]|0,r,B)|0;a[g+((c[o>>2]|0)+16)|0]=0;b:do{if((a[r]|0)==0){E=w;F=x;H=y;I=z}else{D=r;J=w;K=x;L=y;M=z;while(1){N=D;while(1){O=Db(N|0,2209792)|0;if((O|0)==0){E=J;F=K;H=L;I=M;break b}a[O]=0;P=O+2|0;if((O|0)!=(N|0)){Q=_b(N|0,58)|0;if((Q|0)!=0){break}KIb(p,24,2177096,(C=i,i=i+8|0,c[C>>2]=0,C)|0);i=C}if((a[P]|0)==0){E=J;F=K;H=L;I=M;break b}else{N=P}}O=Q+1|0;a[Q]=0;KIb(p,48,2148984,(C=i,i=i+16|0,c[C>>2]=N,c[C+8>>2]=O,C)|0);i=C;R=rb(O|0,e|0,10)|0;do{if((a[c[e>>2]|0]|0)==0){KIb(p,48,2125048,(C=i,i=i+8|0,c[C>>2]=R,C)|0);i=C;if((irc(N,2643200)|0)==0){S=(R|0)<0|0?-1:0;T=R;U=1;V=K;W=J;break}if((irc(N,2619896)|0)==0){c[(c[s>>2]|0)+120>>2]=R;S=L;T=M;U=1;V=K;W=J;break}if((irc(N,2592632)|0)==0){c[(c[s>>2]|0)+124>>2]=R;S=L;T=M;U=1;V=K;W=J;break}if((irc(N,2569920)|0)==0){S=L;T=M;U=1;V=K;W=(R|0)/1e3|0;break}if((irc(N,2552e3)|0)==0){S=L;T=M;U=1;V=R;W=J;break}if((irc(N,2533888)|0)==0){c[(c[l>>2]|0)+412>>2]=R;S=L;T=M;U=1;V=K;W=J;break}if((irc(N,2518368)|0)==0){S=L;T=M;U=1;V=K;W=J;break}S=L;T=M;U=(irc(N,2504272)|0)==0|0;V=K;W=J}else{S=L;T=M;U=0;V=K;W=J}}while(0);do{if((irc(N,2490736)|0)==0){R=Bd(O|0,2479880,(C=i,i=i+8|0,c[C>>2]=g,C)|0)|0;i=C;if((R|0)==1){X=V;Y=W}else{k=-1094995529;A=45;break a}}else{if((irc(N,2470024)|0)==0){if((aKb(f,O,1e4,24,p)|0)!=0){X=V;Y=W;break}X=c[t>>2]|0;Y=c[u>>2]|0;break}else{if((U|0)!=0){X=V;Y=W;break}MGb(v,N,O,0)|0;X=V;Y=W;break}}}while(0);if((a[P]|0)==0){E=Y;F=X;H=S;I=T;break}else{D=P;J=Y;K=X;L=S;M=T}}}}while(0);M=LY(b)|0;if((M|0)<0){k=M;A=45;break}else{w=E;x=F;y=H;z=I}}if((A|0)==39){_X(j,64,1,c[(c[l>>2]|0)+412>>2]|0);_X(h,64,w,x);if(!((z|0)==0&(y|0)==0)){x=VIb(z,y,1e3,0,1,0)|0;y=b+1064|0;c[y>>2]=x;c[y+4>>2]=G}y=h+48|0;c[y>>2]=0;c[y+4>>2]=0;y=c[s>>2]|0;c[y+52>>2]=0;c[y+8>>2]=0;if((c[g>>2]|0)==1){c[y+48>>2]=5;y=c[l>>2]|0;c[y+48>>2]=86069;c[y+792>>2]=8;c[y+432>>2]=24;c[y+72>>2]=6400;Z=y}else{Z=c[l>>2]|0}l=j+48|0;c[l>>2]=0;c[l+4>>2]=0;c[Z+52>>2]=0;c[Z+8>>2]=1;c[Z+416>>2]=1;k=0;i=d;return k|0}else if((A|0)==45){i=d;return k|0}return 0}function KY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=e+8|0;h=c[g>>2]|0;j=e+4|0;k=c[j>>2]|0;l=e+12|0;a:while(1){if((jD(f)|0)!=0){m=-541478725;n=18;break}o=c[j>>2]|0;switch(o|0){case 1:case 2:{n=6;break a;break};case 0:{break};case 3:case 4:{p=1;break a;break};default:{n=5;break a}}e=c[l>>2]|0;hD(f,e,(e|0)<0|0?-1:0)|0;e=LY(a)|0;if((e|0)<0){m=e;n=18;break}}if((n|0)==5){KIb(a,16,2370752,(e=i,i=i+8|0,c[e>>2]=o,e)|0);i=e;m=-1094995529;i=d;return m|0}else if((n|0)==6){p=0}else if((n|0)==18){i=d;return m|0}e=fX(f,b,c[l>>2]|0)|0;do{if((e|0)<0){q=e}else{o=LY(a)|0;if((o|0)<0){q=o;break}r=(k-1|0)>>>1;s=o;while(1){if((c[g>>2]|0)!=(h|0)){break}if(((c[j>>2]|0)-1>>1|0)!=(r|0)){break}if((jD(f)|0)!=0){t=-541478725;n=15;break}o=hX(f,b,c[l>>2]|0)|0;if((o|0)<0){t=o;n=15;break}o=LY(a)|0;if((o|0)<0){t=o;n=15;break}else{s=o}}if((n|0)==15){c[b+32>>2]=p;q=t;break}c[b+32>>2]=p;m=s;i=d;return m|0}}while(0);P1(b);m=q;i=d;return m|0}function LY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((jD(e)|0)!=0){f=-541478725;i=b;return f|0}g=zD(e)|0;if((g|0)==130){h=1;j=zD(e)|0}else{h=0;j=g}g=j>>>4;c[d+4>>2]=g;c[d+8>>2]=j&15;switch(g|0){case 0:case 2:{break};case 1:{c[d+12>>2]=128;k=9;break};case 3:{c[d+12>>2]=40;k=9;break};case 4:{c[d+12>>2]=24;k=9;break};default:{KIb(a,16,2370752,(l=i,i=i+8|0,c[l>>2]=g,l)|0);i=l;f=-1094995529;i=b;return f|0}}do{if((k|0)==9){if((h|0)==0){f=0}else{break}i=b;return f|0}}while(0);h=zD(e)|0;k=d+12|0;c[k>>2]=h&127;if((h&128|0)==0){f=0;i=b;return f|0}h=zD(e)|0;c[k>>2]=c[k>>2]<<7|h&127;if((h&128|0)==0){f=0;i=b;return f|0}KIb(a,16,2304440,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;f=-1094995529;i=b;return f|0}function MY(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;g=c[d+8>>2]|0;h=a+16|0;j=c[h>>2]|0;k=c[a+12>>2]|0;do{if((c[k>>2]|0)==0&(c[k+4>>2]|0)==0){l=g+412|0;m=g+416|0;n=g+48|0;o=g+792|0;p=e;q=-1;r=0;s=1;a:while(1){t=p;u=r;v=s;b:while(1){w=t;while(1){x=zD(j)|0;if((x|0)==0){y=-541478725;z=32;break a}A=ED(j)|0;B=A;C=0;c[k>>2]=B;c[k+4>>2]=C;if((A|0)==0){if((c[(c[h>>2]|0)+88>>2]|0)==0){y=-5;z=32;break a}A=iD(j)|0;D=G;E=fD(j,0,0,1)|0;F=xrc(A,D,E,G)|0;E=G;c[k>>2]=F;c[k+4>>2]=E;H=E;I=F}else{H=C;I=B}B=w-4|0;if((x|0)==9){z=15;break b}else if((x|0)==8){break}else if((x|0)==1){z=10;break b}else if((x|0)==2){if((I|0)==0&(H|0)==0){w=B;continue}else{J=B;K=q;z=22;break a}}else{hD(j,I,H)|0;x=xrc(B,0,c[k>>2]|0,c[k+4>>2]|0)|0;c[k>>2]=0;c[k+4>>2]=0;w=x;continue}}x=DD(j)|0;zD(j)|0;B=(zD(j)|0)+1|0;C=256e6/(ca(B,65536-x|0)|0)|0;c[k>>2]=0;c[k+4>>2]=0;t=w-8|0;u=C;v=B}if((z|0)==10){z=0;if((c[l>>2]|0)==0){t=1e6/(256-(zD(j)|0)|0)|0;B=(u|0)==0?t:u;c[l>>2]=B;_X(d,64,1,B);c[m>>2]=v;c[o>>2]=g5a(c[n>>2]|0)|0}else{hD(j,1,0)|0;}B=zD(j)|0;t=wrc(c[k>>2]|0,c[k+4>>2]|0,-2,-1)|0;C=G;c[k>>2]=t;c[k+4>>2]=C;L=1;M=B;N=w-6|0;O=C;P=t}else if((z|0)==15){z=0;if((c[l>>2]|0)==0){t=FD(j)|0;c[l>>2]=t;_X(d,64,1,t);c[o>>2]=zD(j)|0;c[m>>2]=zD(j)|0}else{hD(j,6,0)|0;}t=DD(j)|0;hD(j,4,0)|0;C=wrc(c[k>>2]|0,c[k+4>>2]|0,-12,-1)|0;B=G;c[k>>2]=C;c[k+4>>2]=B;L=v;M=t;N=w-16|0;O=B;P=C}if((P|0)==0&(O|0)==0){p=N;q=M;r=u;s=L}else{J=N;K=M;z=22;break}}if((z|0)==22){if(!((K|0)>-1)){Q=J;break}s=JX(1255280,K)|0;r=g+48|0;q=c[r>>2]|0;do{if((q|0)==0){c[r>>2]=s;R=s}else{if((q|0)==(s|0)){R=s;break}KIb(a,24,2625672,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;R=c[r>>2]|0}}while(0);if((R|0)!=0){Q=J;break}r=a;if((c[a+1116>>2]|0)!=0){KIb(r,24,2620736,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;Q=J;break}KIb(r,16,2620736,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;y=-22;i=f;return y|0}else if((z|0)==32){i=f;return y|0}}else{Q=e}}while(0);e=ca(c[g+416>>2]|0,c[g+412>>2]|0)|0;c[g+72>>2]=ca(e,c[g+792>>2]|0)|0;g=(Q|0)<1?2048:Q;Q=c[k>>2]|0;e=c[k+4>>2]|0;z=(g|0)<0|0?-1:0;S=(e|0)>(z|0)|(e|0)==(z|0)&Q>>>0>g>>>0?g:Q;g=xrc(Q,e,S,(S|0)<0|0?-1:0)|0;c[k>>2]=g;c[k+4>>2]=G;y=fX(j,b,S)|0;i=f;return y|0}function NY(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;if((grc(b,1255176,20)|0)!=0){e=0;return e|0}a=b+22|0;f=b+24|0;e=(4659-((d[a]|d[a+1|0]<<8)<<16>>16&65535)|0)==((d[f]|d[f+1|0]<<8)<<16>>16&65535|0)?100:10;return e|0}function OY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;hD(e,20,0)|0;f=(DD(e)|0)-22|0;if((f|0)!=4){KIb(a,16,2304408,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-38;i=b;return h|0}hD(e,4,0)|0;e=ZX(a,0)|0;if((e|0)==0){h=-12;i=b;return h|0}c[(c[e+8>>2]|0)+8>>2]=1;e=d;c[e>>2]=0;c[e+4>>2]=0;h=0;i=b;return h|0}function PY(a,b){a=a|0;b=b|0;return MY(a,b,c[c[a+28>>2]>>2]|0,0)|0}function QY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[a+24>>2]|0)!=1){f=-1163346256;i=b;return f|0}if((c[e+8>>2]|0)!=1){f=-1163346256;i=b;return f|0}do{if((c[e+52>>2]|0)==0){if((c[e+48>>2]|0)==65541){break}KIb(a,16,2370712,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;f=-22;i=b;return f|0}}while(0);dD(d,1255176,20);oD(d,26);oD(d,276);oD(d,4383);f=0;i=b;return f|0}function RY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;e=c[a+16>>2]|0;f=c[a+12>>2]|0;if((c[f>>2]|0)!=0){bD(e,2);a=b+28|0;uD(e,c[a>>2]|0);g=a;h=b+24|0;i=c[h>>2]|0;j=c[g>>2]|0;dD(e,i,j);return 0}a=d+52|0;if((c[a>>2]|0)>>>0>3>>>0){bD(e,9);uD(e,(c[b+28>>2]|0)+12|0);kD(e,c[d+412>>2]|0);bD(e,c[d+792>>2]|0);bD(e,c[d+416>>2]|0);oD(e,c[a>>2]|0);kD(e,0)}else{k=d+416|0;if((c[k>>2]|0)>1){bD(e,8);uD(e,4);l=d+412|0;m=ca(c[k>>2]|0,c[l>>2]|0)|0;oD(e,65536-((((m|0)/2|0)+256e6|0)/(m|0)|0)|0);bD(e,c[a>>2]|0);bD(e,(c[k>>2]|0)-1|0);n=l}else{n=d+412|0}bD(e,1);uD(e,(c[b+28>>2]|0)+2|0);d=c[n>>2]|0;bD(e,256-((((d|0)/2|0)+1e6|0)/(d|0)|0)|0);bD(e,c[a>>2]|0)}c[f>>2]=1;g=b+28|0;h=b+24|0;i=c[h>>2]|0;j=c[g>>2]|0;dD(e,i,j);return 0}function SY(a){a=a|0;bD(c[a+16>>2]|0,0);return 0}function TY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=(lrc(b|0)|0)+8|0;c[d>>2]=0;if((a|0)==0){f=e;return f|0}b=LGb(a,10230032,0,2)|0;if((b|0)==0){f=e;return f|0}else{g=e;h=b}while(1){b=lrc(c[h>>2]|0)|0;e=g+5+b+(lrc(c[h+4>>2]|0)|0)|0;c[d>>2]=(c[d>>2]|0)+1;b=LGb(a,10230032,h,2)|0;if((b|0)==0){f=e;break}else{g=e;h=b}}return f|0}function UY(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=lrc(e|0)|0;h=c[b>>2]|0;y=g;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=(c[b>>2]|0)+4|0;c[b>>2]=h;g=lrc(e|0)|0;nrc(h|0,e|0,g)|0;e=(c[b>>2]|0)+g|0;c[b>>2]=e;g=e;if((c[d>>2]|0)==0){y=0;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[b>>2]=(c[b>>2]|0)+4;return 0}y=f;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[b>>2]=(c[b>>2]|0)+4;g=LGb(c[d>>2]|0,10230032,0,2)|0;if((g|0)==0){return 0}else{i=g}do{g=i|0;f=lrc(c[g>>2]|0)|0;e=i+4|0;h=lrc(c[e>>2]|0)|0;j=c[b>>2]|0;y=f+1+h|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[b>>2]|0)+4|0;c[b>>2]=j;nrc(j|0,c[g>>2]|0,f)|0;g=(c[b>>2]|0)+f|0;c[b>>2]=g;a[g]=61;g=(c[b>>2]|0)+1|0;c[b>>2]=g;nrc(g|0,c[e>>2]|0,h)|0;c[b>>2]=(c[b>>2]|0)+h;i=LGb(c[d>>2]|0,10230032,i,2)|0;}while((i|0)!=0);return 0}function VY(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=Bd(c[b+4>>2]|0,2252640,(b=i,i=i+8|0,c[b>>2]=e,b)|0)|0;i=b;do{if((f|0)==1){if((Ob(2209768,a[e]|0,4)|0)==0){break}else{g=100}i=d;return g|0}}while(0);g=0;i=d;return g|0}function WY(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+4144|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=c[b+12>>2]|0;n=ZX(b,0)|0;if((n|0)==0){o=-12;i=d;return o|0}_X(n,64,1,100);p=c[n+8>>2]|0;c[p+8>>2]=3;c[p+48>>2]=1448111218;p=b+16|0;a:do{if((jD(c[p>>2]|0)|0)==0){b=l|0;n=m;while(1){q=fD(c[p>>2]|0,0,0,1)|0;r=G;if((KD(c[p>>2]|0,b,4096)|0)==0){s=n;break a}a[l+(mc(b|0,2370696)|0)|0]=0;t=Bd(b|0,2304376,(u=i,i=i+48|0,c[u>>2]=f,c[u+8>>2]=g,c[u+16>>2]=h,c[u+24>>2]=j,c[u+32>>2]=e,c[u+40>>2]=k,u)|0)|0;i=u;if((t|0)>4){t=l+(c[k>>2]|0)|0;u=c[f>>2]|0;v=Erc(u,(u|0)<0|0?-1:0,3600,0)|0;u=G;w=c[g>>2]|0;x=Erc(w,(w|0)<0|0?-1:0,60,0)|0;w=wrc(x,G,v,u)|0;u=c[h>>2]|0;v=wrc(w,G,u,(u|0)<0|0?-1:0)|0;u=Erc(v,G,100,0)|0;v=c[j>>2]|0;w=wrc(u,G,v,(v|0)<0|0?-1:0)|0;y=G;z=w;A=t}else{y=-2147483648;z=0;A=b}if(!((z|0)==0&(y|0)==(-2147483648|0))){t=IV(n,A,lrc(A|0)|0,0)|0;if((t|0)==0){o=-12;break}w=t+64|0;c[w>>2]=q;c[w+4>>2]=r;r=t+8|0;c[r>>2]=z;c[r+4>>2]=y;c[t+48>>2]=-1}if((jD(c[p>>2]|0)|0)!=0){s=n;break a}}i=d;return o|0}else{s=m}}while(0);JV(s);o=0;i=d;return o|0}function XY(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function YY(a){a=a|0;OV(c[a+12>>2]|0);return 0}function ZY(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function _Y(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1313429332){e=0;return e|0}a=b+4|0;if((grc(a,2268336,8)|0)==0){e=100;return e|0}if((grc(a,2264544,8)|0)==0){e=100;return e|0}a=b+12|0;e=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>0>134217728>>>0?25:50;return e|0}function $Y(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+24|0;h=f|0;j=c[b+12>>2]|0;k=ZX(b,0)|0;if((k|0)==0){l=-12;i=d;return l|0}m=b+16|0;hD(c[m>>2]|0,12,0)|0;n=JD(c[m>>2]|0)|0;o=k+8|0;p=c[o>>2]|0;c[p+8>>2]=1;c[p+48>>2]=86060;p=k+48|0;c[p>>2]=0;c[p+4>>2]=0;p=e|0;q=e;e=b+1140|0;r=f;s=f+4|0;t=f+8|0;f=g;u=-1;v=0;w=n;a:while(1){n=FD(c[m>>2]|0)|0;if((n|0)==1096040772){x=u;y=v;z=17;break}A=JD(c[m>>2]|0)|0;if(A>>>0>1073741823>>>0){z=5;break}B=w-8|0;do{if((n|0)==1380009305|(n|0)==1145261637|(n|0)==1381259333|(n|0)==1213028703|(n|0)==1414811231|(n|0)==860113247){C=(A|0)>(B|0)?B:A;hD(c[m>>2]|0,C,(C|0)<0|0?-1:0)|0;D=u;E=v}else if((n|0)==1514754884){c[g>>2]=0;c[g+4>>2]=0;C=JD(c[m>>2]|0)|0;Rb(f|0,8,2252632,(F=i,i=i+8|0,c[F>>2]=C,F)|0)|0;i=F;MGb(e,2209760,f,0)|0;D=u;E=v}else if((n|0)==1296912195){AD(c[m>>2]|0,r,12)|0;C=(je(c[h>>2]|0)|0)+1|0;c[(c[o>>2]|0)+416>>2]=C;C=je(c[s>>2]|0)|0;G=c[t>>2]|0;H=A-12|0;hD(c[m>>2]|0,H,(H|0)<0|0?-1:0)|0;H=c[o>>2]|0;if((c[H+416>>2]|0)<1){z=8;break a}I=je(G|0)|0;c[H+72>>2]=C*1e3|0;D=I;E=C}else{C=A>>>0>B>>>0?B:A;mrc(p|0,0,5)|0;if((C|0)==-1){D=u;E=v;break}I=hJb(C+1|0)|0;if((I|0)==0){D=u;E=v;break}AD(c[m>>2]|0,I,C)|0;a[I+C|0]=0;c[q>>2]=n;MGb(e,p,I,8)|0;D=u;E=v}}while(0);n=B-A|0;if(!((n|0)>-1)){x=D;y=E;z=17;break}if((jD(c[m>>2]|0)|0)==0){u=D;v=E;w=n}else{x=D;y=E;z=17;break}}if((z|0)==5){KIb(b,16,2370672,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;l=-1;i=d;return l|0}else if((z|0)==8){KIb(b,16,2304344,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;l=-1094995529;i=d;return l|0}else if((z|0)==17){do{if((x|0)==11){z=c[o>>2]|0;c[z+412>>2]=11025;J=z;K=11025}else if((x|0)==22){z=c[o>>2]|0;c[z+412>>2]=22050;J=z;K=22050}else if((x|0)==44){z=c[o>>2]|0;c[z+412>>2]=44100;J=z;K=44100}else if((x|0)==(-1|0)){KIb(b,16,2177064,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;l=-1;i=d;return l|0}else{if(!((x-8|0)>>>0>36>>>0)){z=x*1e3|0;E=c[o>>2]|0;c[E+412>>2]=z;J=E;K=z;break}KIb(b,16,2148960,(F=i,i=i+8|0,c[F>>2]=x,F)|0);i=F;l=-1094995529;i=d;return l|0}}while(0);x=(y|0)/(c[J+416>>2]|0)|0;if((x-8|0)>>>0>40>>>0){KIb(b,16,2125016,(F=i,i=i+8|0,c[F>>2]=x,F)|0);i=F;l=-1094995529;i=d;return l|0}y=J+412|0;z=(((K|0)/1e3|0)<<8)+x|0;if((z|0)==4112|(z|0)==5652|(z|0)==5656){L=1024}else if((z|0)==11304|(z|0)==11312){L=2048}else if((z|0)==2824|(z|0)==2056|(z|0)==2826|(z|0)==5664){L=512}else{z=c[J+72>>2]|0;KIb(b,16,2643160,(F=i,i=i+16|0,c[F>>2]=K,c[F+8>>2]=z,F)|0);i=F;l=-1;i=d;return l|0}c[j>>2]=(ca(c[J+72>>2]|0,L)|0)/(K|0)|0;_X(k,64,L,c[y>>2]|0);if((PX(c[o>>2]|0,12)|0)!=0){l=-12;i=d;return l|0}nrc(c[(c[o>>2]|0)+96>>2]|0,r|0,12)|0;dL(b,0,190368);l=0;i=d;return l|0}return 0}function aZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[b+12>>2]|0;f=e;g=e+8|0;h=(c[f>>2]|0)+7-(c[g>>2]|0)>>3;i=h+2|0;if((K1(d,i)|0)<0){j=-5;return j|0}k=b+16|0;b=fD(c[k>>2]|0,0,0,1)|0;l=d+64|0;c[l>>2]=b;c[l+4>>2]=G;c[d+32>>2]=0;c[d+48>>2]=1;l=d+24|0;a[c[l>>2]|0]=8-(c[g>>2]|0);b=e+4|0;a[(c[l>>2]|0)+1|0]=a[b]|0;if((AD(c[k>>2]|0,(c[l>>2]|0)+2|0,h)|0)==(h|0)){a[b]=a[(c[l>>2]|0)+(h+1)|0]|0;c[g>>2]=(h<<3)-(c[f>>2]|0)+(c[g>>2]|0);j=i;return j|0}else{P1(d);j=-5;return j|0}return 0}function bZ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c[a+12>>2]|0;h=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[(c[h+8>>2]|0)+72>>2]|0;i=b;j=(b|0)<0|0?-1:0;b=Erc(i,j,d,e)|0;e=G;d=c[h+40>>2]|0;k=d;l=(d|0)<0|0?-1:0;d=c[h+44>>2]|0;m=d;n=(d|0)<0|0?-1:0;d=c[g>>2]|0;o=d;p=(d|0)<0|0?-1:0;d=Erc(o,p,m,n)|0;q=UIb(b,e,k,l,d,G,f&1^3)|0;f=Erc(q,G,o,p)|0;p=G;o=Erc(k,l,i,j)|0;j=VIb(f,p,m,n,o,G)|0;o=h+208|0;c[o>>2]=j;c[o+4>>2]=G;o=c[a+16>>2]|0;j=wrc(f,p,-7,-1)|0;p=G;f=a+1248|0;a=wrc(j>>>3|p<<29,p>>3|((p|0)<0|0?-1:0)<<29,c[f>>2]|0,c[f+4>>2]|0)|0;f=fD(o,a,G,0)|0;a=f;if((a|0)<0){r=a;return r|0}a=xrc(-7,-1,j&7,p&0)|0;c[g+8>>2]=a;r=0;return r|0}function cZ(a){a=a|0;var b=0,d=0;if((c[a+8>>2]|0)<33){b=0;return b|0}d=c[a+4>>2]|0;do{if((grc(d+8|0,2334416,4)|0)==0){if((grc(d,2329312,4)|0)==0){b=99;return b|0}if((grc(d,2323344,4)|0)!=0){break}if((grc(d+12|0,2318368,4)|0)==0){b=100}else{break}return b|0}}while(0);b=0;return b|0}function dZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;d=i;i=i+400|0;e=d|0;f=d+264|0;g=b+16|0;h=c[g>>2]|0;j=c[b+12>>2]|0;k=fD(h,0,0,1)|0;l=j+72|0;c[l>>2]=k&1;k=j+24|0;c[k>>2]=-1;c[k+4>>2]=-1;m=FD(h)|0;n=(m|0)==875972178;if(!((m|0)==1179011410|(m|0)==875972178)){o=-1094995529;i=d;return o|0}FD(h)|0;if((FD(h)|0)!=1163280727){o=-1094995529;i=d;return o|0}do{if(n){if((FD(h)|0)!=875983716){o=-1094995529;i=d;return o|0}m=FD(h)|0;if(m>>>0<24>>>0){o=-1094995529;i=d;return o|0}GD(h)|0;p=GD(h)|0;q=G;r=GD(h)|0;s=G;t=s|q;u=0;if(!((t|0)<(u|0)|(t|0)==(u|0)&(r|p)>>>0<0>>>0)){u=wrc(m,0,-24,-1)|0;hD(h,u,G)|0;v=q;w=p;x=s;z=r;break}KIb(b,16,2533792,(A=i,i=i+32|0,c[A>>2]=p,c[A+8>>2]=q,c[A+16>>2]=r,c[A+24>>2]=s,A)|0);i=A;o=-1094995529;i=d;return o|0}else{v=0;w=0;x=0;z=0}}while(0);s=b;r=j+8|0;q=h+88|0;p=n^1;u=f|0;f=e|0;m=e+256|0;t=e+32|0;B=e+10|0;C=e+8|0;e=b+1140|0;D=-1;E=-1;F=0;H=v;v=w;w=x;x=z;z=0;a:while(1){I=FD(h)|0;J=FD(h)|0;K=J;L=0;M=fD(h,0,0,1)|0;N=wrc(M,G,K,L)|0;M=G;if((jD(h)|0)!=0){O=D;P=E;Q=H;R=v;S=w;T=x;U=z;break}do{if((I|0)==810962259){V=57;break a}else if((I|0)==1952670054){if(!((x|0)==0&(w|0)==0)){W=D;X=E;Y=M;Z=N;_=F;$=H;aa=v;ba=w;ca=x;da=z;break}W=D;X=E;Y=M;Z=N;_=F;$=H;aa=v;ba=0;ca=FD(h)|0;da=z}else if((I|0)==1954047330){ea=AD(c[g>>2]|0,f,256)|0;if((ea|0)<0){o=ea;V=87;break a}a[m]=0;if((a[f]|0)!=0){ea=MGb(e,2177048,f,0)|0;if((ea|0)<0){o=ea;V=87;break a}}ea=AD(c[g>>2]|0,f,32)|0;if((ea|0)<0){o=ea;V=87;break a}a[t]=0;if((a[f]|0)!=0){ea=MGb(e,2125e3,f,0)|0;if((ea|0)<0){o=ea;V=87;break a}}ea=AD(c[g>>2]|0,f,32)|0;if((ea|0)<0){o=ea;V=87;break a}a[t]=0;if((a[f]|0)!=0){ea=MGb(e,2412056,f,0)|0;if((ea|0)<0){o=ea;V=87;break a}}ea=AD(c[g>>2]|0,f,10)|0;if((ea|0)<0){o=ea;V=87;break a}a[B]=0;if((a[f]|0)!=0){ea=MGb(e,2619848,f,0)|0;if((ea|0)<0){o=ea;V=87;break a}}ea=AD(c[g>>2]|0,f,8)|0;if((ea|0)<0){o=ea;V=87;break a}a[C]=0;if((a[f]|0)!=0){ea=MGb(e,2569888,f,0)|0;if((ea|0)<0){o=ea;V=87;break a}}ea=GD(c[g>>2]|0)|0;fa=G;Rb(u|0,131,2404640,(A=i,i=i+16|0,c[A>>2]=ea,c[A+8>>2]=fa,A)|0)|0;i=A;fa=MGb(e,2397216,u,0)|0;if((fa|0)<0){o=fa;V=87;break a}fa=(DD(c[g>>2]|0)|0)==0;ea=c[g>>2]|0;if(fa){hD(ea,254,0)|0;}else{fa=OD(ea)|0;ea=G;ga=OD(c[g>>2]|0)|0;ha=G;ia=OD(c[g>>2]|0)|0;ja=G;ka=OD(c[g>>2]|0)|0;la=G;ma=OD(c[g>>2]|0)|0;na=G;oa=OD(c[g>>2]|0)|0;pa=G;qa=OD(c[g>>2]|0)|0;ra=G;sa=OD(c[g>>2]|0)|0;ta=G;if(!((ga|fa|ia|ka|ma|oa|qa|sa|0)==0&(ha|ea|ja|la|na|pa|ra|ta|0)==0)){do{if((oa|ma|0)==0&(pa|na|0)==0){if(!((sa|qa|0)==0&(ta|ra|0)==0)){ua=0;va=0;V=49;break}Rb(u|0,131,2390224,(A=i,i=i+64|0,c[A>>2]=fa,c[A+8>>2]=ea,c[A+16>>2]=ga,c[A+24>>2]=ha,c[A+32>>2]=ia,c[A+40>>2]=ja,c[A+48>>2]=ka,c[A+56>>2]=la,A)|0)|0;i=A}else{ua=pa;va=oa;V=49}}while(0);if((V|0)==49){V=0;Rb(u|0,131,2383328,(A=i,i=i+128|0,c[A>>2]=fa,c[A+8>>2]=ea,c[A+16>>2]=ga,c[A+24>>2]=ha,c[A+32>>2]=ia,c[A+40>>2]=ja,c[A+48>>2]=ka,c[A+56>>2]=la,c[A+64>>2]=ma,c[A+72>>2]=na,c[A+80>>2]=va,c[A+88>>2]=ua,c[A+96>>2]=qa,c[A+104>>2]=ra,c[A+112>>2]=sa,c[A+120>>2]=ta,A)|0)|0;i=A}oa=MGb(e,2376544,u,0)|0;if((oa|0)<0){o=oa;V=87;break a}}hD(c[g>>2]|0,190,0)|0;}if(!(J>>>0>602>>>0)){W=D;X=E;Y=M;Z=N;_=F;$=H;aa=v;ba=w;ca=x;da=z;break}oa=hJb(J-601|0)|0;if((oa|0)==0){o=-12;V=87;break a}pa=J-602|0;wa=AD(c[g>>2]|0,oa,pa)|0;if((wa|0)<0){o=wa;V=87;break a}a[oa+pa|0]=0;pa=MGb(e,2370200,oa,8)|0;if((pa|0)<0){o=pa;V=87;break a}else{W=D;X=E;Y=M;Z=N;_=F;$=H;aa=v;ba=w;ca=x;da=z}}else if((I|0)==1635017060){if((F|0)==0){V=20;break a}if(n){pa=fD(h,0,0,1)|0;oa=wrc(pa,G,v,H)|0;xa=H;ya=v;za=G;Aa=oa}else{oa=(J|0)!=0;xa=L;ya=K;za=oa?M:2147483647;Aa=oa?N:-1}c[r>>2]=Aa;c[r+4>>2]=za;oa=fD(h,0,0,1)|0;pa=G;if((c[q>>2]|0)==0){O=pa;P=oa;Q=xa;R=ya;S=w;T=x;U=z;break a}if((J|0)==0&p){O=pa;P=oa;Q=xa;R=ya;S=w;T=x;U=z;break a}else{W=pa;X=oa;Y=za;Z=Aa;_=F;$=xa;aa=ya;ba=w;ca=x;da=z}}else if((I|0)==1414744396){if(J>>>0<4>>>0){V=68;break a}if((FD(h)|0)!=1330007625){W=D;X=E;Y=M;Z=N;_=F;$=H;aa=v;ba=w;ca=x;da=z;break}oa=wrc(K,L,-4,-1)|0;RS(b,oa,G)|0;W=D;X=E;Y=M;Z=N;_=F;$=H;aa=v;ba=w;ca=x;da=z}else if((I|0)==544501094){if((F|0)!=0){KIb(s,24,2518328,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;W=D;X=E;Y=M;Z=N;_=1;$=H;aa=v;ba=w;ca=x;da=z;break}oa=c[g>>2]|0;pa=ZX(b,0)|0;if((pa|0)==0){o=-12;V=87;break a}wa=pa+8|0;Ba=OS(oa,c[wa>>2]|0,J)|0;if((Ba|0)<0){o=Ba;V=87;break a}Ba=c[wa>>2]|0;if((c[Ba+48>>2]|0)==65536){c[pa+440>>2]=50;wa=pa+228|0;oa=c[wa>>2]|0;c[wa>>2]=(oa|0)>4?4:oa}c[pa+236>>2]=1463898624;_X(pa,64,1,c[Ba+412>>2]|0);W=D;X=E;Y=M;Z=N;_=1;$=H;aa=v;ba=w;ca=x;da=pa}else{W=D;X=E;Y=M;Z=N;_=F;$=H;aa=v;ba=w;ca=x;da=z}}while(0);N=iD(h)|0;M=G;I=0;if((M|0)>(I|0)|(M|0)==(I|0)&N>>>0>0>>>0){N=iD(h)|0;I=G;if(!((Y|0)<(I|0)|(Y|0)==(I|0)&Z>>>0<N>>>0)){O=W;P=X;Q=$;R=aa;S=ba;T=ca;U=da;break}}if((Z|0)==(-1|0)&(Y|0)==2147483647){Ca=0;Da=0}else{N=wrc(c[l>>2]|0,0,Z,Y)|0;Ca=G&0;Da=N&1}N=wrc(Da,Ca,Z,Y)|0;I=fD(h,N,G,0)|0;N=G;M=0;if((N|0)<(M|0)|(N|0)==(M|0)&I>>>0<0>>>0){O=W;P=X;Q=$;R=aa;S=ba;T=ca;U=da;break}else{D=W;E=X;F=_;H=$;v=aa;w=ba;x=ca;z=da}}do{if((V|0)==20){KIb(s,16,2504216,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}else if((V|0)==57){if((F|0)==0){KIb(s,16,2490680,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}if((J|0)!=808464944){KIb(s,16,2479840,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;O=D;P=E;Q=H;R=v;S=w;T=x;U=z;break}KIb(s,48,2469992,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;c[j+68>>2]=0;da=ZX(b,0)|0;if((da|0)==0){o=-12;i=d;return o|0}zD(h)|0;c[da+4>>2]=1;ca=da+8|0;ba=c[ca>>2]|0;c[ba+8>>2]=0;c[ba+48>>2]=1397577290;ba=ED(h)|0;c[(c[ca>>2]|0)+120>>2]=ba;ba=ED(h)|0;aa=c[ca>>2]|0;c[aa+124>>2]=ba;if((PX(aa,4)|0)!=0){KIb(s,16,2461016,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-12;i=d;return o|0}aa=ED(h)|0;ba=fD(h,0,0,1)|0;$=G;_=Erc(aa,0,3,0)|0;aa=G;X=wrc(ba,$,-15,-1)|0;$=wrc(X,G,_,aa)|0;c[k>>2]=$;c[k+4>>2]=G;ED(h)|0;c[j+32>>2]=ED(h)|0;_X(da,32,1,ED(h)|0);$=da+56|0;c[$>>2]=ED(h)|0;c[$+4>>2]=0;ED(h)|0;ED(h)|0;$=ED(h)|0;c[j+36>>2]=$;if(($|0)<=65536){da=c[(c[ca>>2]|0)+96>>2]|0;y=$;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[j+64>>2]=0;O=D;P=E;Q=H;R=v;S=w;T=x;U=z;break}KIb(s,16,2444576,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}else if((V|0)==68){KIb(s,16,2431456,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}else if((V|0)==87){i=d;return o|0}}while(0);z=0;if((O|0)<(z|0)|(O|0)==(z|0)&P>>>0<0>>>0){KIb(s,16,2422120,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;o=-1094995529;i=d;return o|0}fD(h,P,O,0)|0;O=U+8|0;if((T|0)==0&(S|0)==0){V=80}else{if((A5a(c[(c[O>>2]|0)+48>>2]|0)|0)>0){V=80}else{Ea=S;Fa=T}}do{if((V|0)==80){P=c[O>>2]|0;if((c[P+416>>2]|0)==0|(R|0)==0&(Q|0)==0){Ea=S;Fa=T;break}if((g5a(c[P+48>>2]|0)|0)==0){Ea=S;Fa=T;break}P=c[r>>2]|0;A=c[r+4>>2]|0;s=iD(h)|0;z=G;if((A|0)>(z|0)|(A|0)==(z|0)&P>>>0>s>>>0){Ea=S;Fa=T;break}s=c[O>>2]|0;P=c[s+416>>2]|0;z=g5a(c[s+48>>2]|0)|0;s=Erc(z,(z|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;P=Frc(R<<3|0>>>29,Q<<3|R>>>29,s,G)|0;Ea=G;Fa=P}}while(0);if(!((Fa|0)==0&(Ea|0)==0)){R=U+56|0;c[R>>2]=Fa;c[R+4>>2]=Ea}dL(b,0,156584);dL(b,0,1316424);o=0;i=d;return o|0}function eZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+24|0;e=d|0;f=d+16|0;g=c[a+12>>2]|0;h=g+60|0;j=c[h>>2]|0;do{if((j|0)==0){k=a+28|0;if((c[(c[(c[c[k>>2]>>2]|0)+8>>2]|0)+52>>2]|0)!=1){break}l=c[a+16>>2]|0;m=c[l+4>>2]|0;if((nV(m,(c[l+16>>2]|0)-m|0,f)|0)>50){c[(c[(c[c[k>>2]>>2]|0)+8>>2]|0)+48>>2]=c[f>>2];c[h>>2]=1;n=6;break}else{c[h>>2]=-1;break}}else if((j|0)==1){n=6}}while(0);if((n|0)==6){o=pV(a,b)|0;i=d;return o|0}j=g+24|0;h=c[j+4>>2]|0;f=0;k=a+28|0;if((h|0)>(f|0)|(h|0)==(f|0)&(c[j>>2]|0)>>>0>0>>>0){p=g+52|0;q=g+48|0;r=a+16|0}else{s=a+16|0;n=24}a:while(1){if((n|0)==24){n=0;t=c[c[k>>2]>>2]|0;u=g+8|0;a=c[u>>2]|0;f=c[u+4>>2]|0;h=fD(c[s>>2]|0,0,0,1)|0;m=xrc(a,f,h,G)|0;h=(c[g+56>>2]|0)==0;f=h?m:2147483647;m=h?G:0;h=0;if(!((m|0)<(h|0)|(m|0)==(h|0)&f>>>0<1>>>0)){v=m;w=f;break}f=c[s>>2]|0;b:do{if((c[g+16>>2]|0)==0){if((jD(f)|0)!=0){break}m=g+72|0;do{h=FD(f)|0;a=FD(f)|0;l=0;if((h|0)==1635017060){x=l;y=a;n=37;break a}h=wrc(c[m>>2]|0,0,a,l)|0;z=wrc(h&1,G&0,a,l)|0;fD(f,z,G,1)|0;}while((jD(f)|0)==0)}else{m=e|0;if((jD(f)|0)!=0){break}while(1){AD(f,m,16)|0;A=GD(f)|0;B=G;z=0;if((B|0)<(z|0)|(B|0)==(z|0)&A>>>0<25>>>0){break b}if((grc(m,1249728,16)|0)==0){break}z=wrc(A,B,-17,-1)|0;hD(f,z&-8,G|0)|0;if((jD(f)|0)!=0){break b}}m=wrc(A,B,-24,-1)|0;z=G;l=0;if(!((z|0)<(l|0)|(z|0)==(l|0)&m>>>0<0>>>0)){x=z;y=m;n=37;break a}}}while(0);f=g+52|0;c[f>>2]=1;m=c[j+4>>2]|0;z=0;if(!((m|0)>(z|0)|(m|0)==(z|0)&(c[j>>2]|0)>>>0>0>>>0)){o=-541478725;n=42;break}z=g+48|0;if((c[z>>2]|0)==0){p=f;q=z;r=s}else{o=-541478725;n=42;break}}z=g+68|0;f=g+44|0;m=g+40|0;l=g+32|0;a=b+64|0;h=g+36|0;C=g+64|0;D=b+8|0;E=b+32|0;while(1){F=c[k>>2]|0;H=c[F>>2]|0;I=c[F+4>>2]|0;if((c[z>>2]|0)==0){J=1}else{F=c[I+208>>2]|0;K=c[H+208>>2]|0;J=(YIb(F,(F|0)<0|0?-1:0,I+40|0,K,(K|0)<0|0?-1:0,H+40|0)|0)<1|0}c[z>>2]=1;c[f>>2]=J;H=J|c[p>>2];c[f>>2]=H;K=(c[q>>2]|0)==0&H;c[f>>2]=K;if((K|0)==0){s=r;n=24;continue a}K=fD(c[r>>2]|0,0,0,1)|0;H=G;I=ca(c[l>>2]|0,c[m>>2]|0)|0;F=wrc(I,(I|0)<0|0?-1:0,c[j>>2]|0,c[j+4>>2]|0)|0;I=fD(c[r>>2]|0,F,G,0)|0;F=G;L=0;M=c[r>>2]|0;if((F|0)<(L|0)|(F|0)==(L|0)&I>>>0<0>>>0){fD(M,K,H,0)|0;}else{I=ED(M)|0;M=fX(c[r>>2]|0,b,I)|0;if((M|0)>=0){I=wrc(c[a>>2]|0,c[a+4>>2]|0,-3,-1)|0;c[a>>2]=I;c[a+4>>2]=G;I=c[m>>2]|0;L=c[h>>2]|0;F=ca(L,I)|0;N=c[C>>2]|0;O=F+N|0;c[D>>2]=O;c[D+4>>2]=(O|0)<0|0?-1:0;O=N+1|0;if((L|0)>0){P=(O|0)%(L|0)|0}else{P=O}c[C>>2]=P;if((P|0)==0){c[m>>2]=I+1}c[E>>2]=1}fD(c[r>>2]|0,K,H,0)|0;if(!((M|0)==-541478725)){o=M;n=42;break a}}c[q>>2]=1}}if((n|0)==37){q=fD(c[s>>2]|0,0,0,1)|0;r=wrc(q,G,y,x)|0;c[u>>2]=r;c[u+4>>2]=G;v=x;w=y}else if((n|0)==42){i=d;return o|0}n=c[(c[t+8>>2]|0)+432>>2]|0;if((n|0)>1){t=(n|0)>4096?n:4096;y=t-((t|0)%(n|0)|0)|0;Q=(y|0)<0|0?-1:0;R=y}else{Q=0;R=4096}y=(Q|0)>(v|0)|(Q|0)==(v|0)&R>>>0>w>>>0;y?v:Q;Q=fX(c[s>>2]|0,b,y?w:R)|0;if((Q|0)<0){o=Q;i=d;return o|0}c[b+32>>2]=0;o=Q;i=d;return o|0}function fZ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=c[a+12>>2]|0;c[g+48>>2]=0;c[g+52>>2]=0;h=g+24|0;i=c[h+4>>2]|0;j=0;do{if((i|0)>(j|0)|(i|0)==(j|0)&(c[h>>2]|0)>>>0>0>>>0){k=a+28|0;l=c[k>>2]|0;if((b|0)==0){m=XIb(d,e,(c[l>>2]|0)+40|0,(c[l+4>>2]|0)+40|0)|0;n=G;o=m;p=e;q=d}else{m=XIb(d,e,(c[l+4>>2]|0)+40|0,(c[l>>2]|0)+40|0)|0;n=e;o=d;p=G;q=m}m=c[g+36>>2]|0;if((m|0)<=0){r=p;s=q;t=k;break}l=m;u=(m|0)<0|0?-1:0;m=Crc(o,n,l,u)|0;c[g+40>>2]=m;m=Drc(o,n,l,u)|0;c[g+64>>2]=m;r=p;s=q;t=k}else{r=e;s=d;t=a+28|0}}while(0);d=c[(c[(c[c[t>>2]>>2]|0)+8>>2]|0)+48>>2]|0;if((d|0)==86016|(d|0)==86017|(d|0)==86019|(d|0)==86020){v=-1;return v|0}v=SR(a,b,s,r,f)|0;return v|0}function gZ(a){a=a|0;var b=0,d=0;if((c[a+8>>2]|0)<41){b=0;return b|0}d=c[a+4>>2]|0;do{if((grc(d,1249680,16)|0)==0){if((grc(d+24|0,1249648,16)|0)==0){b=100}else{break}return b|0}}while(0);b=0;return b|0}function hZ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;e=i;i=i+24|0;f=e|0;g=e+16|0;h=c[b+16>>2]|0;j=c[b+12>>2]|0;k=f|0;AD(h,k,16)|0;if((grc(k,1249680,16)|0)!=0){l=-1094995529;i=e;return l|0}m=GD(h)|0;n=G;o=0;if(n>>>0<o>>>0|n>>>0==o>>>0&m>>>0<72>>>0){l=-1094995529;i=e;return l|0}AD(h,k,16)|0;if((grc(k,1249648,16)|0)!=0){KIb(b,16,2252600,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;l=-1094995529;i=e;return l|0}c[j+16>>2]=1;m=ZX(b,0)|0;if((m|0)==0){l=-12;i=e;return l|0}if((jD(h)|0)!=0){l=-541478725;i=e;return l|0}o=m+8|0;n=m+56|0;q=g+4|0;r=g|0;g=b+1140|0;s=b;t=f+1|0;u=f+2|0;v=f+3|0;w=f+4|0;x=f+5|0;y=f+6|0;z=f+7|0;A=f+8|0;B=f+9|0;C=f+10|0;D=f+11|0;E=f+12|0;F=f+13|0;H=f+14|0;I=f+15|0;f=j+8|0;j=h+88|0;J=0;K=0;a:while(1){b:while(1){if((AD(h,k,16)|0)!=16){L=J;M=K;N=31;break a}O=GD(h)|0;P=G;Q=0;if((P|0)<(Q|0)|(P|0)==(Q|0)&O>>>0<25>>>0){l=-1094995529;N=35;break a}Q=xrc(-1,2147483647,O,P)|0;R=G;S=fD(h,0,0,1)|0;T=G;if((R|0)<(T|0)|(R|0)==(T|0)&Q>>>0<S>>>0){l=-1094995529;N=35;break a}do{if((grc(k,1249696,16)|0)==0){S=c[o>>2]|0;Q=wrc(O,P,-24,0)|0;T=OS(h,S,Q)|0;if((T|0)<0){l=T;N=35;break a}T=wrc(O,P,7,0)|0;Q=xrc(T&-8,G|0,O,P)|0;hD(h,Q,G)|0;_X(m,64,1,c[(c[o>>2]|0)+412>>2]|0)}else{if((grc(k,1249712,16)|0)==0){Q=GD(h)|0;T=G;S=0;if(!((T|0)>(S|0)|(T|0)==(S|0)&Q>>>0>0>>>0)){break}c[n>>2]=Q;c[n+4>>2]=T;break}if((grc(k,1249728,16)|0)==0){break b}if((grc(k,1249664,16)|0)!=0){T=d[t]|0;Q=d[u]|0;S=d[v]|0;R=d[w]|0;U=d[x]|0;V=d[y]|0;W=d[z]|0;X=d[A]|0;Y=d[B]|0;Z=d[C]|0;_=d[D]|0;$=d[E]|0;aa=d[F]|0;ba=d[H]|0;ca=d[I]|0;KIb(s,48,2209680,(p=i,i=i+128|0,c[p>>2]=d[k]|0,c[p+8>>2]=T,c[p+16>>2]=Q,c[p+24>>2]=S,c[p+32>>2]=R,c[p+40>>2]=U,c[p+48>>2]=V,c[p+56>>2]=W,c[p+64>>2]=X,c[p+72>>2]=Y,c[p+80>>2]=Z,c[p+88>>2]=_,c[p+96>>2]=$,c[p+104>>2]=aa,c[p+112>>2]=ba,c[p+120>>2]=ca,p)|0);i=p;ca=wrc(O,P,-17,-1)|0;hD(h,ca&-8,G|0)|0;break}ca=fD(h,0,0,1)|0;ba=G;aa=wrc(O,P,7,0)|0;$=wrc(ca,ba,aa&-8,G|0)|0;aa=G;ba=wrc($,aa,-24,-1)|0;ca=G;_=FD(h)|0;c:do{if((_|0)!=0){Z=wrc($,aa,-32,-1)|0;Y=G;X=0;do{if((jD(h)|0)!=0){break c}W=fD(h,0,0,1)|0;V=G;U=0;if((V|0)<(U|0)|(V|0)==(U|0)&W>>>0<0>>>0|((V|0)>(Y|0)|(V|0)==(Y|0)&W>>>0>Z>>>0)){break c}a[q]=0;AD(h,r,4)|0;W=FD(h)|0;V=pJb(W+1|0)|0;if((V|0)==0){l=-12;N=35;break a}hD(h,W-(MD(h,W,V,W)|0)|0,0)|0;MGb(g,r,V,8)|0;X=X+1|0;}while(X>>>0<_>>>0)}}while(0);_=fD(h,0,0,1)|0;aa=xrc(ba,ca,_,G)|0;hD(h,aa,G)|0;}}while(0);if((jD(h)|0)!=0){L=J;M=K;N=31;break a}}aa=fD(h,0,0,1)|0;_=G;$=wrc(O,P,-24,-1)|0;X=G;Z=wrc($,X,aa,_)|0;c[f>>2]=Z;c[f+4>>2]=G;Z=fD(h,0,0,1)|0;_=G;if((c[j>>2]|0)==0){L=_;M=Z;N=31;break}hD(h,$,X)|0;if((jD(h)|0)==0){J=_;K=Z}else{L=_;M=Z;N=31;break}}if((N|0)==31){if((M|0)==0&(L|0)==0){l=-541478725;i=e;return l|0}dL(b,0,156584);dL(b,0,1316424);if((c[(c[m+8>>2]|0)+48>>2]|0)==65536){c[m+440>>2]=50;b=m+228|0;K=c[b>>2]|0;c[b>>2]=(K|0)>4?4:K}c[m+236>>2]=1463898624;fD(h,M,L,0)|0;l=0;i=e;return l|0}else if((N|0)==35){i=e;return l|0}return 0}function iZ(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+24|0;e=b|0;f=c[a+12>>2]|0;g=a+16|0;h=c[g>>2]|0;if((c[a+24>>2]|0)!=1){KIb(a,16,2619792,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=b;return k|0}l=f+56|0;if((c[l>>2]|0)==1){kD(h,875972178);kD(h,-1)}else{kD(h,1179011410);kD(h,0)}kD(h,1163280727);m=c[l>>2]|0;if((m|0)!=0){l=(m|0)==1?2124992:2551960;kD(h,(d[l+1|0]|0)<<8|(d[l]|0)|(d[l+2|0]|0)<<16|(d[l+3|0]|0)<<24);kD(h,28);l=fD(h,0,0,1)|0;m=f+24|0;c[m>>2]=l;c[m+4>>2]=G;cD(h,0,28)}m=SS(h,2533784)|0;l=G;n=a+28|0;if((US(h,c[(c[c[n>>2]>>2]|0)+8>>2]|0)|0)<0){o=c[(c[(c[c[n>>2]>>2]|0)+8>>2]|0)+12>>2]|0;if((o|0)==0){p=2177040}else{p=c[o>>2]|0}KIb(a,16,2518288,(j=i,i=i+8|0,c[j>>2]=p,j)|0);i=j;k=-1;i=b;return k|0}TS(h,m,l);do{if((c[(c[(c[c[n>>2]>>2]|0)+8>>2]|0)+52>>2]|0)!=1){if((c[(c[g>>2]|0)+88>>2]|0)==0){break}l=SS(h,2504208)|0;m=f+16|0;c[m>>2]=l;c[m+4>>2]=G;kD(h,0);TS(h,c[m>>2]|0,c[m+4>>2]|0)}}while(0);if((c[f+52>>2]|0)!=0){m=e|0;e=SS(c[g>>2]|0,2479832)|0;l=G;j=a+1140|0;p=LGb(c[j>>2]|0,2469976,0,0)|0;if((p|0)==0){q=0}else{o=c[p+4>>2]|0;p=lrc(o|0)|0;r=(p|0)>256?256:p;dD(c[g>>2]|0,o,r);q=r}cD(c[g>>2]|0,0,256-q|0);q=LGb(c[j>>2]|0,2461e3,0,0)|0;if((q|0)==0){s=0}else{r=c[q+4>>2]|0;q=lrc(r|0)|0;o=(q|0)>32?32:q;dD(c[g>>2]|0,r,o);s=o}cD(c[g>>2]|0,0,32-s|0);s=LGb(c[j>>2]|0,2444552,0,0)|0;if((s|0)==0){t=0}else{o=c[s+4>>2]|0;s=lrc(o|0)|0;r=(s|0)>32?32:s;dD(c[g>>2]|0,o,r);t=r}cD(c[g>>2]|0,0,32-t|0);t=LGb(c[j>>2]|0,2431432,0,0)|0;if((t|0)==0){u=0}else{r=c[t+4>>2]|0;t=lrc(r|0)|0;o=(t|0)>10?10:t;dD(c[g>>2]|0,r,o);u=o}cD(c[g>>2]|0,0,10-u|0);u=LGb(c[j>>2]|0,2422096,0,0)|0;if((u|0)==0){v=0}else{o=c[u+4>>2]|0;u=lrc(o|0)|0;r=(u|0)>8?8:u;dD(c[g>>2]|0,o,r);v=r}cD(c[g>>2]|0,0,8-v|0);v=LGb(c[j>>2]|0,2412040,0,0)|0;if((v|0)==0){w=0;x=0}else{r=Jd(c[v+4>>2]|0,0,10)|0;w=G;x=r}rD(c[g>>2]|0,x,w);oD(c[g>>2]|0,1);w=LGb(c[j>>2]|0,2404632,0,0)|0;if((w|0)==0){cD(c[g>>2]|0,0,64)}else{mrc(m|0,0,17)|0;x=w+4|0;w=(c[x>>2]|0)+2|0;r=lrc(w|0)|0;v=(r|0)/16|0;if((r|0)>15){o=(r|0)>31;nrc(m|0,w|0,16)|0;w=Jd(m|0,0,16)|0;sD(c[g>>2]|0,w,G);if(o){w=1;do{nrc(m|0,(c[x>>2]|0)+(w<<4|2)|0,16)|0;r=Jd(m|0,0,16)|0;sD(c[g>>2]|0,r,G);w=w+1|0;}while((w|0)<(v|0))}y=o?v<<3:8}else{y=0}cD(c[g>>2]|0,0,64-y|0)}cD(c[g>>2]|0,0,190);y=LGb(c[j>>2]|0,2397200,0,0)|0;if((y|0)!=0){mD(c[g>>2]|0,c[y+4>>2]|0)|0}TS(c[g>>2]|0,e,l)}l=c[c[n>>2]>>2]|0;_X(l,64,1,c[(c[l+8>>2]|0)+412>>2]|0);c[f+48>>2]=0;l=f+40|0;c[l>>2]=0;c[l+4>>2]=0;l=f+32|0;c[l>>2]=-1;c[l+4>>2]=2147483647;_S(a);a=SS(h,2490672)|0;l=f+8|0;c[l>>2]=a;c[l+4>>2]=G;eD(h);k=0;i=b;return k|0}function jZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=c[a+12>>2]|0;dD(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);f=b+8|0;g=c[f>>2]|0;h=c[f+4>>2]|0;if((g|0)==0&(h|0)==(-2147483648|0)){KIb(a,16,2643112,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=d;return 0}else{a=e+32|0;j=c[a>>2]|0;k=c[a+4>>2]|0;l=(k|0)>(h|0)|(k|0)==(h|0)&j>>>0>g>>>0;c[a>>2]=l?g:j;c[a+4>>2]=l?h:k;k=e+40|0;h=c[k>>2]|0;l=c[k+4>>2]|0;a=c[f>>2]|0;j=c[f+4>>2]|0;f=(l|0)>(j|0)|(l|0)==(j|0)&h>>>0>a>>>0;c[k>>2]=f?h:a;c[k+4>>2]=f?l:j;c[e+48>>2]=c[b+48>>2];i=d;return 0}return 0}function kZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a+16|0;d=c[b>>2]|0;e=c[a+12>>2]|0;eD(d);if((c[(c[b>>2]|0)+88>>2]|0)==0){return 0}b=fD(d,0,0,1)|0;f=G;g=e+8|0;h=xrc(b,f,c[g>>2]|0,c[g+4>>2]|0)|0;i=G;j=e+56|0;k=c[j>>2]|0;if((k|0)==1){l=1}else if((k|0)==(-1|0)){k=wrc(b,f,-8,-1)|0;m=G;n=0;if((m|0)>(n|0)|(m|0)==(n|0)&k>>>0>-1>>>0){l=1}else{o=4}}else{o=4}if((o|0)==4){fD(d,4,0,0)|0;k=wrc(b,f,-8,0)|0;kD(d,k);fD(d,b,f,0)|0;TS(d,c[g>>2]|0,c[g+4>>2]|0);eD(d);l=0}k=e+40|0;n=e+32|0;m=xrc(c[k>>2]|0,c[k+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0)|0;n=c[e+48>>2]|0;k=wrc(m,G,n,(n|0)<0|0?-1:0)|0;n=G;m=c[c[a+28>>2]>>2]|0;a=c[m+8>>2]|0;p=c[a+412>>2]|0;q=c[m+40>>2]|0;r=Erc(q,(q|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;p=c[m+44>>2]|0;m=VIb(k,n,r,G,p,(p|0)<0|0?-1:0)|0;p=G;a:do{if((c[a+52>>2]|0)==1){o=10}else{r=e+16|0;fD(d,c[r>>2]|0,c[r+4>>2]|0,0)|0;do{if((l|0)==0){r=0;if((c[j>>2]|0)==-1&((p|0)>(r|0)|(p|0)==(r|0)&m>>>0>-1>>>0)){break}kD(d,m);fD(d,b,f,0)|0;eD(d);o=10;break a}}while(0);kD(d,-1)}}while(0);do{if((o|0)==10){if((l|0)!=0){break}return 0}}while(0);fD(d,0,0,0)|0;kD(d,875972178);kD(d,-1);l=e+24|0;e=wrc(c[l>>2]|0,c[l+4>>2]|0,-8,-1)|0;fD(d,e,G,0)|0;kD(d,875983716);kD(d,28);e=wrc(b,f,-8,-1)|0;rD(d,e,G);rD(d,h,i);rD(d,m,p);kD(d,0);p=wrc(c[g>>2]|0,c[g+4>>2]|0,-4,-1)|0;fD(d,p,G,0)|0;kD(d,-1);fD(d,b,f,0)|0;eD(d);return 0}function lZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+12>>2]|0;e=a+16|0;f=c[e>>2]|0;dD(f,1249680,16);rD(f,-1,-1);dD(f,1249648,16);g=fD(f,0,0,1)|0;h=G;dD(f,1249696,16);rD(f,-1,2147483647);j=a+28|0;k=US(f,c[(c[c[j>>2]>>2]|0)+8>>2]|0)|0;if((k|0)<0){l=c[(c[(c[c[j>>2]>>2]|0)+8>>2]|0)+12>>2]|0;if((l|0)==0){m=2177040}else{m=c[l>>2]|0}KIb(a,16,2209656,(a=i,i=i+8|0,c[a>>2]=m,a)|0);i=a;n=k;i=b;return n|0}k=fD(f,0,0,1)|0;a=G;m=wrc(k,a,7,0)|0;l=m&-8;m=G|0;o=xrc(l,m,k,a)|0;cD(f,0,o);o=wrc(g,h,16,0)|0;fD(f,o,G,0)|0;o=xrc(l,m,g,h)|0;rD(f,o,G);fD(f,l,m,0)|0;do{if((c[(c[(c[c[j>>2]>>2]|0)+8>>2]|0)+52>>2]|0)!=1){if((c[(c[e>>2]|0)+88>>2]|0)==0){break}m=d+16|0;l=fD(f,0,0,1)|0;c[m>>2]=l;c[m+4>>2]=G;dD(f,1249712,16);rD(f,-1,2147483647);rD(f,0,0);l=c[m>>2]|0;o=c[m+4>>2]|0;m=fD(f,0,0,1)|0;h=G;g=wrc(m,h,7,0)|0;a=g&-8;g=G|0;k=xrc(a,g,m,h)|0;cD(f,0,k);k=wrc(l,o,16,0)|0;fD(f,k,G,0)|0;k=xrc(a,g,l,o)|0;rD(f,k,G);fD(f,a,g,0)|0;}}while(0);e=d+8|0;d=fD(f,0,0,1)|0;c[e>>2]=d;c[e+4>>2]=G;dD(f,1249728,16);rD(f,-1,2147483647);n=0;i=b;return n|0}function mZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+16>>2]|0;d=c[a+12>>2]|0;if((c[b+88>>2]|0)==0){return 0}e=d+8|0;f=c[e>>2]|0;g=c[e+4>>2]|0;e=fD(b,0,0,1)|0;h=G;i=wrc(e,h,7,0)|0;j=i&-8;i=G|0;k=xrc(j,i,e,h)|0;cD(b,0,k);k=wrc(f,g,16,0)|0;fD(b,k,G,0)|0;k=xrc(j,i,f,g)|0;rD(b,k,G);fD(b,j,i,0)|0;i=fD(b,0,0,1)|0;j=G;fD(b,16,0,0)|0;rD(b,i,j);k=c[c[a+28>>2]>>2]|0;a=c[k+8>>2]|0;if((c[a+52>>2]|0)!=1){g=d+40|0;f=d+32|0;h=xrc(c[g>>2]|0,c[g+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=c[d+48>>2]|0;g=wrc(h,G,f,(f|0)<0|0?-1:0)|0;f=G;h=c[a+412>>2]|0;a=c[k+40>>2]|0;e=Erc(a,(a|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=c[k+44>>2]|0;k=VIb(g,f,e,G,h,(h|0)<0|0?-1:0)|0;h=G;e=d+16|0;d=wrc(c[e>>2]|0,c[e+4>>2]|0,24,0)|0;fD(b,d,G,0)|0;rD(b,k,h)}fD(b,i,j,0)|0;eD(b);return 0}function nZ(a){a=a|0;var b=0;if((c[a+8>>2]|0)<12){return 0}b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297239878){a=b+8|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1163284301?100:0)|0}else{return 0}return 0}function oZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=e;c[g>>2]=320;h=e+4|0;c[h>>2]=165;j=e+20|0;k=e+16|0;l=e+24|0;mrc(e+8|0,0,16)|0;J1(l);c[e+48>>2]=0;c[e+52>>2]=0;hD(f,12,0)|0;e=FD(f)|0;m=b+1140|0;n=JD(f)|0;o=e;while(1){e=n+1|0;p=e&-2;if((o|0)==1296125506){q=hJb(e|1)|0;if((q|0)==0){r=-12;s=16;break}if((AD(f,q,p)|0)!=(p|0)){r=-5;s=16;break}a[q+p|0]=0;MGb(m,2177032,q,8)|0}else if((o|0)==1414283600){fD(f,-8,-1,1)|0;hX(f,l,776)|0}else if((o|0)==1145982803|(o|0)==1480871497){hD(f,p,0)|0;}else if((o|0)==1163544915){c[g>>2]=FD(f)|0;c[h>>2]=FD(f)|0}else if((o|0)==1598247007){hD(f,12,0)|0;}else{s=10;break}p=FD(f)|0;q=JD(f)|0;if((jD(f)|0)!=0){r=-5;s=16;break}if((p|0)==1212371522){s=13;break}else{n=q;o=p}}if((s|0)==10){n=o&255;f=o>>>8&255;l=o>>>16&255;m=o>>>24;KIb(b,16,2209592,(o=i,i=i+64|0,c[o>>2]=n,c[o+8>>2]=f,c[o+16>>2]=l,c[o+24>>2]=m,c[o+32>>2]=n,c[o+40>>2]=f,c[o+48>>2]=l,c[o+56>>2]=m,o)|0);i=o;r=-1094995529;i=d;return r|0}else if((s|0)==13){o=ZX(b,0)|0;if((o|0)==0){r=-12;i=d;return r|0}_X(o,33,1,15);c[k>>2]=c[o>>2];k=c[o+8>>2]|0;c[k+8>>2]=0;c[k+48>>2]=41;c[k+52>>2]=0;c[k+120>>2]=c[g>>2];c[k+124>>2]=c[h>>2];h=ZX(b,0)|0;if((h|0)==0){r=-12;i=d;return r|0}_X(h,33,1,15);c[j>>2]=c[h>>2];j=c[h+8>>2]|0;c[j+8>>2]=1;c[j+48>>2]=65536;c[j+52>>2]=1;c[j+416>>2]=1;h=j+448|0;c[h>>2]=4;c[h+4>>2]=0;c[j+792>>2]=16;c[j+412>>2]=22050;c[j+72>>2]=352800;c[j+432>>2]=16;r=0;i=d;return r|0}else if((s|0)==16){i=d;return r|0}return 0}function pZ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;f=i;i=i+1024|0;g=f|0;h=c[b+12>>2]|0;j=c[b+16>>2]|0;k=b;b=h+24|0;l=b;m=h+52|0;n=e;o=h+48|0;p=h+16|0;q=e+32|0;r=h+8|0;s=e+8|0;t=g|0;u=g+1|0;v=h+20|0;a:while(1){w=FD(j)|0;x=(JD(j)|0)+1&-2;if((jD(j)|0)!=0){y=-5;z=23;break}if((w|0)==1212371522){continue}else if((w|0)==1414482003){fD(j,-8,-1,1)|0;hX(j,l,12)|0;continue}else if((w|0)==541149014){z=5;break}else if((w|0)==1229215041){z=21;break}else if((w|0)!=1415071060){z=22;break}if(x>>>0>1024>>>0){continue}if((AD(j,t,x)|0)!=(x|0)){continue}KIb(k,48,2461656,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;if((x|0)==0){y=-1094995529;z=23;break}h=x-1|0;B=0;do{if(!(B>>>0<h>>>0)){y=-1094995529;z=23;break a}B=B+1|0;}while((a[g+B|0]|0)!=0);KIb(k,48,2370608,(A=i,i=i+8|0,c[A>>2]=u,A)|0);i=A;B=d[t]|0;C=B+1|0;if(!(C>>>0<x>>>0)){y=-1094995529;z=23;break}D=B+2|0;E=g+D|0;F=h+~B|0;B=0;while(1){if(!(B>>>0<F>>>0)){y=-1094995529;z=23;break a}if((a[g+(B+D)|0]|0)==0){break}else{B=B+1|0}}KIb(k,48,2304304,(A=i,i=i+8|0,c[A>>2]=E,A)|0);i=A;B=D+(d[g+C|0]|0)|0;if(!(B>>>0<x>>>0)){y=-1094995529;z=23;break}F=B+1|0;H=g+F|0;I=h-B|0;B=0;while(1){if(!(B>>>0<I>>>0)){y=-1094995529;z=23;break a}if((a[g+(B+F)|0]|0)==0){break}else{B=B+1|0}}KIb(k,48,2252584,(A=i,i=i+8|0,c[A>>2]=H,A)|0);i=A}if((z|0)==5){fD(j,-8,-1,1)|0;g=hX(j,l,x+8|0)|0;l=(c[m>>2]|0)>0?0:g;nrc(n|0,b|0,80)|0;c[o>>2]=0;c[m>>2]=0;c[q>>2]=c[p>>2];p=c[r+4>>2]|0;c[s>>2]=c[r>>2];c[s+4>>2]=p;y=l;i=f;return y|0}else if((z|0)==21){l=fX(j,e,x)|0;c[q>>2]=c[v>>2];v=c[r+4>>2]|0;c[s>>2]=c[r>>2];c[s+4>>2]=v;v=wrc(c[r>>2]|0,c[r+4>>2]|0,1,0)|0;c[r>>2]=v;c[r+4>>2]=G;y=l;i=f;return y|0}else if((z|0)==22){l=w&255;r=w>>>8&255;v=w>>>16&255;s=w>>>24;KIb(k,16,2209592,(A=i,i=i+64|0,c[A>>2]=l,c[A+8>>2]=r,c[A+16>>2]=v,c[A+24>>2]=s,c[A+32>>2]=l,c[A+40>>2]=r,c[A+48>>2]=v,c[A+56>>2]=s,A)|0);i=A;y=-1094995529;i=f;return y|0}else if((z|0)==23){i=f;return y|0}return 0}function qZ(a){a=a|0;var b=0;b=c[a+12>>2]|0;if((c[b+52>>2]|0)<=0){return 0}P1(b+24|0);return 0}function rZ(b){b=b|0;var e=0,f=0;e=c[b+4>>2]|0;b=((d[e+1|0]|0)<<8|(d[e]|0)<<16|(d[e+2|0]|0)|0)==15711167?e+3|0:e;do{if((krc(b,2304296,6)|0)==0){e=a[b+6|0]|0;if(e<<24>>24==0){f=100;return f|0}if((Ob(2643104,e&255|0,5)|0)==0){break}else{f=100}return f|0}}while(0);f=0;return f|0}function sZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;d=i;i=i+2048|0;e=d|0;f=d+1024|0;g=c[b+12>>2]|0;h=ZX(b,0)|0;if((h|0)==0){j=-12;i=d;return j|0}_X(h,64,1,1e3);k=c[h+8>>2]|0;c[k+8>>2]=3;c[k+48>>2]=1465275476;k=h+72|0;c[k>>2]=c[k>>2]|c[g+24>>2];SFb(e,0,-1);SFb(f,0,-1);k=b+16|0;RV(c[k>>2]|0,f);b=f+4|0;a:do{if((c[b>>2]|0)==0){l=g+4|0;m=31}else{h=f|0;n=g+4|0;while(1){o=c[h>>2]|0;p=fD(c[k>>2]|0,0,0,1)|0;q=G;do{if((krc(o,2370592,9)|0)!=0){if((krc(o,2304296,6)|0)==0){break}else{r=0}while(1){s=o+r|0;t=a[s]|0;if((t<<24>>24|0)==0|(t<<24>>24|0)==10|(t<<24>>24|0)==13){m=9;break}if((krc(s,2252576,3)|0)==0){u=o;v=0;w=0;break}else{r=r+1|0}}do{if((m|0)==9){m=0;if((o|0)==0){u=0;v=0;w=0;break}s=mc(o|0,2209584)|0;t=o+s|0;x=a[t]|0;if(x<<24>>24==13){y=o+(s+1)|0;z=y;A=a[y]|0}else{z=t;A=x}u=A<<24>>24==10?z+1|0:z;v=s;w=o}}while(0);s=wZ(u)|0;x=G;if((s|0)==0&(x|0)==(-2147483648|0)){l=n;m=31;break a}t=Db(u|0,2252576)|0;if((t|0)==0){l=n;m=31;break a}y=t+2|0;while(1){B=y+1|0;t=a[B]|0;if((t<<24>>24|0)==32|(t<<24>>24|0)==9){y=B}else{break}}t=wZ(B)|0;C=G;if((t|0)==0&(C|0)==(-2147483648|0)){l=n;m=31;break a}D=y+((mc(B|0,2177024)|0)+1)|0;while(1){E=a[D]|0;if(!((E<<24>>24|0)==32|(E<<24>>24|0)==9)){break}D=D+1|0}y=mc(D|0,2209584)|0;E=D+y|0;F=a[E]|0;if(F<<24>>24==13){H=D+(y+1)|0;I=H;J=a[H]|0}else{I=E;J=F}F=J<<24>>24==10?I+1|0:I;E=IV(n,F,lrc(F|0)|0,0)|0;if((E|0)==0){K=-12;break a}F=E+64|0;c[F>>2]=p;c[F+4>>2]=q;F=E+8|0;c[F>>2]=s;c[F+4>>2]=x;F=xrc(t,C,s,x)|0;c[E+48>>2]=F;if((v|0)!=0){F=U1(E,75,v)|0;if((F|0)==0){K=-12;break a}nrc(F|0,w|0,v)|0}if((y|0)==0){break}F=U1(E,76,y)|0;if((F|0)==0){K=-12;break a}nrc(F|0,D|0,y)|0}}while(0);RV(c[k>>2]|0,f);if((c[b>>2]|0)==0){l=n;m=31;break}}}}while(0);if((m|0)==31){JV(l);K=0}_Fb(f,0)|0;_Fb(e,0)|0;j=K;i=d;return j|0}function tZ(a,b){a=a|0;b=b|0;return MV((c[a+12>>2]|0)+4|0,b)|0}function uZ(a){a=a|0;OV((c[a+12>>2]|0)+4|0);return 0}function vZ(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV((c[a+12>>2]|0)+4|0,a,b,d,e,f,g,h,i,j)|0}function wZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=Bd(a|0,2148936,(j=i,i=i+32|0,c[j>>2]=d,c[j+8>>2]=e,c[j+16>>2]=f,c[j+24>>2]=g,j)|0)|0;i=j;if((h|0)==4){h=c[d>>2]|0;d=Erc(h,(h|0)<0|0?-1:0,3600,0)|0;h=G;k=c[e>>2]|0;l=Erc(k,(k|0)<0|0?-1:0,60,0)|0;k=wrc(l,G,d,h)|0;h=c[f>>2]|0;d=wrc(k,G,h,(h|0)<0|0?-1:0)|0;h=Erc(d,G,1e3,0)|0;d=c[g>>2]|0;k=wrc(h,G,d,(d|0)<0|0?-1:0)|0;m=G;n=k;i=b;return(G=m,n)|0}k=Bd(a|0,2124976,(j=i,i=i+24|0,c[j>>2]=e,c[j+8>>2]=f,c[j+16>>2]=g,j)|0)|0;i=j;if((k|0)!=3){m=-2147483648;n=0;i=b;return(G=m,n)|0}k=c[e>>2]|0;e=Erc(k,(k|0)<0|0?-1:0,60,0)|0;k=c[f>>2]|0;f=wrc(e,G,k,(k|0)<0|0?-1:0)|0;k=Erc(f,G,1e3,0)|0;f=c[g>>2]|0;g=wrc(k,G,f,(f|0)<0|0?-1:0)|0;m=G;n=g;i=b;return(G=m,n)|0}function xZ(a){a=a|0;var b=0,d=0;b=i;d=c[a+16>>2]|0;_X(c[c[a+28>>2]>>2]|0,64,1,1e3);YD(d,2643096,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;eD(d);i=b;return 0}function yZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[a+16>>2]|0;YD(g,2304288,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;h=V1(b,75,e)|0;do{if((h|0)!=0){j=c[e>>2]|0;if((j|0)<=0){break}YD(g,2252568,(a=i,i=i+16|0,c[a>>2]=j,c[a+8>>2]=h,a)|0)|0;i=a}}while(0);h=b+8|0;e=c[h>>2]|0;j=c[h+4>>2]|0;k=Crc(e,j,1e3,0)|0;l=G;m=Erc(k,l,-1e3,-1)|0;n=wrc(m,G,e,j)|0;m=G;o=Crc(e,j,6e4,0)|0;p=G;q=Erc(o,p,-60,-1)|0;r=wrc(q,G,k,l)|0;l=G;k=Crc(e,j,36e5,0)|0;q=G;s=Erc(k,q,-60,-1)|0;t=wrc(s,G,o,p)|0;p=G;o=0;if((j|0)>(o|0)|(j|0)==(o|0)&e>>>0>3599999>>>0){YD(g,2148928,(a=i,i=i+16|0,c[a>>2]=k,c[a+8>>2]=q,a)|0)|0;i=a}YD(g,2124952,(a=i,i=i+48|0,c[a>>2]=t,c[a+8>>2]=p,c[a+16>>2]=r,c[a+24>>2]=l,c[a+32>>2]=n,c[a+40>>2]=m,a)|0)|0;i=a;YD(g,2209576,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;m=c[b+48>>2]|0;n=wrc(m,(m|0)<0|0?-1:0,c[h>>2]|0,c[h+4>>2]|0)|0;h=G;m=Crc(n,h,1e3,0)|0;l=G;r=Erc(m,l,-1e3,-1)|0;p=wrc(r,G,n,h)|0;r=G;t=Crc(n,h,6e4,0)|0;q=G;k=Erc(t,q,-60,-1)|0;e=wrc(k,G,m,l)|0;l=G;m=Crc(n,h,36e5,0)|0;k=G;o=Erc(m,k,-60,-1)|0;j=wrc(o,G,t,q)|0;q=G;t=0;if((h|0)>(t|0)|(h|0)==(t|0)&n>>>0>3599999>>>0){YD(g,2148928,(a=i,i=i+16|0,c[a>>2]=m,c[a+8>>2]=k,a)|0)|0;i=a}YD(g,2124952,(a=i,i=i+48|0,c[a>>2]=j,c[a+8>>2]=q,c[a+16>>2]=e,c[a+24>>2]=l,c[a+32>>2]=p,c[a+40>>2]=r,a)|0)|0;i=a;r=V1(b,76,f)|0;do{if((r|0)!=0){p=c[f>>2]|0;if((p|0)<=0){break}YD(g,2177016,(a=i,i=i+16|0,c[a>>2]=p,c[a+8>>2]=r,a)|0)|0;i=a}}while(0);YD(g,2304288,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;dD(g,c[b+24>>2]|0,c[b+28>>2]|0);YD(g,2304288,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0)|0;i=a;i=d;return 0}function zZ(b){b=b|0;var e=0,f=0;if((c[b+8>>2]|0)<20){e=0;return e|0}f=c[b+4>>2]|0;b=f;if((((d[b]|d[b+1|0]<<8)<<16>>16)-8e3&65535)>>>0>4e4>>>0){e=0;return e|0}if((d[f+10|0]|0)>>>0>3>>>0){e=0;return e|0}b=a[f+11|0]|0;if(!((b<<24>>24|0)==99|(b<<24>>24|0)==1)){e=0;return e|0}b=f+16|0;e=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==57007?50:0;return e|0}function AZ(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;if((AD(c[b+16>>2]|0,g,12)|0)!=12){h=-5;i=f;return h|0}j=e[g>>1]|0;k=a[g+10|0]&1;l=k+1|0;m=d[g+11|0]|0;g=ZX(b,0)|0;if((g|0)==0){h=-12;i=f;return h|0}do{if((m|0)==99){n=c[g+8>>2]|0;c[n+48>>2]=69636;c[n+792>>2]=4;c[n+72>>2]=ca(j<<2,l)|0}else if((m|0)==1){if((k|0)==0){c[(c[g+8>>2]|0)+48>>2]=86033;break}QIb(b,2461616,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;h=-1163346256;i=f;return h|0}else{QIb(b,2370560,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;h=-1163346256;i=f;return h|0}}while(0);_X(g,64,1,j);o=c[g+8>>2]|0;c[o+8>>2]=1;c[o+416>>2]=l;l=o+448|0;c[l>>2]=4-k;c[l+4>>2]=0;c[o+412>>2]=j;h=0;i=f;return h|0}function BZ(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+8|0;h=g|0;j=c[d+16>>2]|0;k=c[c[d+28>>2]>>2]|0;if((AD(j,h,8)|0)!=8){l=-5;i=g;return l|0}d=h+4|0;if((e[d>>1]|e[d+2>>1]<<16|0)!=57007){l=-1094995529;i=g;return l|0}d=b[h>>1]|0;m=d&65535;n=k+8|0;do{if((c[(c[n>>2]|0)+48>>2]|0)==86033){o=b[h+2>>1]|0;p=K1(f,m+4|0)|0;if((p|0)!=0){l=p;i=g;return l|0}p=f+24|0;q=AD(j,(c[p>>2]|0)+4|0,m)|0;if((q|0)==(m|0)){r=c[p>>2]|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;r=(c[p>>2]|0)+2|0;y=d;a[r]=y;y=y>>8;a[r+1|0]=y;c[f+48>>2]=o&65535;break}l=(q|0)<0?q:-5;i=g;return l|0}else{if((fX(j,f,m)|0)==(m|0)){c[f+48>>2]=(m<<1>>>0)/((c[(c[n>>2]|0)+416>>2]|0)>>>0)|0;break}else{l=-5;i=g;return l|0}}}while(0);c[f+32>>2]=c[k>>2];l=m;i=g;return l|0}function CZ(a){a=a|0;var b=0;if((c[a+8>>2]|0)<12){return 0}b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297239878){a=b+8|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1095849559?100:0)|0}else{return 0}return 0}function DZ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+8|0;f=e|0;g=f|0;h=f;j=c[b+12>>2]|0;k=c[b+16>>2]|0;l=ZX(b,0)|0;if((l|0)==0){m=-12;i=e;return m|0}n=l+48|0;c[n>>2]=0;c[n+4>>2]=0;c[j+20>>2]=c[l>>2];n=l+8|0;o=c[n>>2]|0;c[o+8>>2]=0;c[o+48>>2]=45;c[o+52>>2]=0;fD(k,20,0,0)|0;if((QX(c[n>>2]|0,k,42)|0)<0){m=-12;i=e;return m|0}o=c[n>>2]|0;n=c[o+96>>2]|0;p=n+6|0;c[o+120>>2]=(d[p]|d[p+1|0]<<8)<<16>>16&65535;p=n+8|0;c[o+124>>2]=(d[p]|d[p+1|0]<<8)<<16>>16&65535;p=a[n+12|0]|0;o=p&255;q=n+4|0;r=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=0;s=l+56|0;c[s>>2]=r;c[s+4>>2]=q;s=l+64|0;c[s>>2]=r;c[s+4>>2]=q;if(p<<24>>24==0|(p&255)>>>0>30>>>0){KIb(b,16,2370536,(t=i,i=i+8|0,c[t>>2]=o,t)|0);i=t;m=-1094995529;i=e;return m|0}_X(l,64,1,o);o=n;c[j>>2]=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=n+24|0;c[j+12>>2]=(d[o]|d[o+1|0]<<8)<<16>>16&65535;c[j+8>>2]=d[n+26|0]|0;c[j+4>>2]=d[n+27|0]|0;c[j+16>>2]=-1;j=b+20|0;c[j>>2]=c[j>>2]|1;j=f;n=f+4|0;f=b;b=h+1|0;o=h+2|0;l=h+3|0;while(1){if((AD(k,j,8)|0)!=8){m=-5;u=10;break}h=c[g>>2]|0;p=je(h|0)|0;q=je(c[n>>2]|0)|0;if(!((p|0)==1128877638|(p|0)==1128877640|(p|0)==1128877636|(p|0)==1346981446|(p|0)==1346981448|(p|0)==1346981444|(p|0)==1179209286|(p|0)==1129137235)){p=d[b]|0;s=d[o]|0;r=d[l]|0;KIb(f,16,2304248,(t=i,i=i+32|0,c[t>>2]=h&255,c[t+8>>2]=p,c[t+16>>2]=s,c[t+24>>2]=r,t)|0);i=t}hD(k,q,0)|0;if((h|0)==1179535686){m=0;u=10;break}}if((u|0)==10){i=e;return m|0}return 0}function EZ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+8|0;g=f|0;h=g|0;j=c[b+12>>2]|0;k=c[b+16>>2]|0;l=g;if((AD(k,l,8)|0)!=8){m=-1;i=f;return m|0}n=g+4|0;g=b;while(1){o=c[h>>2]|0;p=je(o|0)|0;q=je(c[n>>2]|0)|0;r=q&1;if((p-1397638192|0)>>>0<3>>>0|(o|0)==1380340054){break}if((o|0)!=1396985155){KIb(g,32,2461584,(o=i,i=i+8|0,c[o>>2]=p,o)|0);i=o}hD(k,r+q|0,0)|0;if((AD(k,l,8)|0)!=8){m=-1;s=31;break}}if((s|0)==31){i=f;return m|0}l=fX(k,e,q)|0;if((l|0)<0){m=-5;i=f;return m|0}a:do{if((p|0)==1397638192|(p|0)==1397638193|(p|0)==1397638194){g=j+16|0;do{if((c[g>>2]|0)==-1){n=ZX(b,0)|0;if((n|0)==0){m=-12;i=f;return m|0}c[g>>2]=c[n>>2];h=j+12|0;o=c[h>>2]|0;if((o|0)==0){c[h>>2]=22050;t=22050}else{t=o}o=j+8|0;if((c[o>>2]|0)==0){c[o>>2]=1}h=j+4|0;if((c[h>>2]|0)==0){c[h>>2]=8}u=n+8|0;v=c[u>>2]|0;c[v+412>>2]=t;c[v+792>>2]=c[h>>2];c[v+416>>2]=c[o>>2];c[v+8>>2]=1;_X(n,64,1,t);if((p|0)==1397638192){n=(c[u>>2]|0)+48|0;if((c[h>>2]|0)==16){c[n>>2]=65536;c[e+32>>2]=c[g>>2];break a}else{c[n>>2]=65541;s=21;break}}else if((p|0)==1397638194){n=c[u>>2]|0;c[n+48>>2]=69636;if((PX(n,2)|0)==0){n=c[(c[u>>2]|0)+96>>2]|0;y=c[j>>2]&65535;a[n]=y;y=y>>8;a[n+1|0]=y;s=21;break}else{m=-12;i=f;return m|0}}else if((p|0)==1397638193){c[(c[u>>2]|0)+48>>2]=86033;c[e+32>>2]=c[g>>2];break}else{s=21;break}}else{s=21}}while(0);do{if((s|0)==21){c[e+32>>2]=c[g>>2];if((p|0)==1397638193){break}else if((p|0)!=1397638194){break a}c[e+48>>2]=(q<<1>>>0)/((c[j+8>>2]|0)>>>0)|0;break a}}while(0);g=c[e+24>>2]|0;if((g|0)==0){break}u=g;c[e+48>>2]=((d[u]|d[u+1|0]<<8)<<16>>16&65535|0)/(c[j+8>>2]|0)|0}else if((p|0)==1448166994){c[e+32>>2]=c[j+20>>2];c[e+48>>2]=1}}while(0);if((r|0)==0){m=l;i=f;return m|0}hD(k,1,0)|0;m=l;i=f;return m|0}function FZ(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,1245464,16)|0)!=0;return(b?0:100)|0}function GZ(b){b=b|0;var f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;f=i;i=i+7232|0;g=f|0;j=f+1024|0;l=f+2048|0;m=f+2056|0;n=f+2064|0;o=f+2072|0;p=f+2080|0;q=f+2096|0;r=c[b+12>>2]|0;s=r+24|0;c[s>>2]=0;c[s+4>>2]=-2147483648;s=r+16|0;c[s>>2]=0;c[s+4>>2]=-2147483648;s=r+8|0;c[s>>2]=0;c[s+4>>2]=-2147483648;s=b+16|0;hD(c[s>>2]|0,48,0)|0;t=FD(c[s>>2]|0)|0;if(t>>>0>4096>>>0){KIb(b,16,2569808,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1094995529;i=f;return v|0}hD(c[s>>2]|0,4,0)|0;w=FD(c[s>>2]|0)|0;x=w;fD(c[s>>2]|0,x<<12|0>>>20,((w|0)<0|0?-1:0)<<12|x>>>20,0)|0;x=f+3136|0;w=AD(c[s>>2]|0,x,t)|0;if((w|0)<0){v=-1094995529;i=f;return v|0}t=NZ(b,x,w,1278552,16)|0;y=r;c[y>>2]=t;if((t|0)==0){KIb(b,16,2551920,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1094995529;i=f;return v|0}t=KZ(b,0,0,0,0)|0;if((t|0)<0){v=t;i=f;return v|0}fD(c[y>>2]|0,-32,-1,1)|0;y=fD(c[s>>2]|0,0,0,1)|0;t=G;z=NZ(b,x,w,1293800,58)|0;if((z|0)!=0){A=q|0;B=f+2112|0;a:do{if((jD(z)|0)==0){C=o;D=p;E=p|0;F=p;H=b+1140|0;I=b;J=p+4|0;K=D+6|0;L=p+8|0;M=F+9|0;N=F+10|0;O=F+11|0;P=p+12|0;Q=F+13|0;R=F+14|0;S=F+15|0;F=g|0;T=j|0;while(1){MS(z,q)|0;U=FD(z)|0;V=FD(z)|0;if((V|0)==0){W=H;break a}if((grc(A,1358456,16)|0)!=0){break}MD(z,2147483647,B,1024)|0;b:do{if((irc(B,2518240)|0)==0){hD(z,V,(V|0)<0|0?-1:0)|0;}else{X=V<<1;Y=(X|0)>34?X|1:35;X=hJb(Y)|0;c[o>>2]=X;if((X|0)==0){break}Z=(V|0)==4;c:do{if((U|0)==0&Z){_=FD(z)|0;Rb(X|0,Y|0,2504184,(u=i,i=i+8|0,c[u>>2]=_,u)|0)|0;i=u}else{d:do{switch(U|0){case 5:{if((V|0)!=2){break d}_=DD(z)|0;Rb(X|0,Y|0,2390152,(u=i,i=i+8|0,c[u>>2]=_,u)|0)|0;i=u;break c;break};case 4:{if((V|0)!=8){break d}_=GD(z)|0;$=G;do{if((irc(B,2469928)|0)!=0){if((irc(B,2460912)|0)==0){break}do{if((irc(B,2444472)|0)!=0){if((irc(B,2431416)|0)==0){break}if((irc(B,2422072)|0)==0){aa=c[o>>2]|0;c[l>>2]=~~(((c[k>>2]=_,c[k+4>>2]=$,+h[k>>3])+-25569.0)*86400.0);ba=rc(l|0)|0;if((ba|0)==0){kJb(c[o>>2]|0);break b}else{Fc(aa|0,Y|0,2340176,ba|0)|0;break c}}else{ba=(irc(B,2412024)|0)==0;aa=c[o>>2]|0;if(ba){ca=(c[k>>2]=_,c[k+4>>2]=$,+h[k>>3]);Rb(aa|0,Y|0,2404624,(u=i,i=i+8|0,h[u>>3]=ca,u)|0)|0;i=u;break c}else{Rb(aa|0,Y|0,2397192,(u=i,i=i+16|0,c[u>>2]=_,c[u+8>>2]=$,u)|0)|0;i=u;break c}}}}while(0);aa=c[o>>2]|0;ba=Crc(_,$,1e7,0)|0;da=wrc(ba,G,-2006054656,0)|0;c[m>>2]=da;if((rc(m|0)|0)==0){kJb(c[o>>2]|0);break b}else{Fc(aa|0,Y|0,2340176,rc(m|0)|0)|0;break c}}}while(0);aa=c[o>>2]|0;c[n>>2]=wrc(Crc(_,$,1e7,0)|0,G,1240428288,0)|0;if((rc(n|0)|0)==0){kJb(c[o>>2]|0);break b}else{Fc(aa|0,Y|0,2340176,rc(n|0)|0)|0;break c}break};case 6:{if((V|0)!=16){break d}AD(z,D,16)|0;aa=e[J>>1]|0;da=e[K>>1]|0;ba=d[L]|0;ea=d[M]|0;fa=d[N]|0;ga=d[O]|0;ha=d[P]|0;ia=d[Q]|0;ja=d[R]|0;ka=d[S]|0;Rb(c[o>>2]|0,Y|0,2383264,(u=i,i=i+88|0,c[u>>2]=c[E>>2],c[u+8>>2]=aa,c[u+16>>2]=da,c[u+24>>2]=ba,c[u+32>>2]=ea,c[u+40>>2]=fa,c[u+48>>2]=ga,c[u+56>>2]=ha,c[u+64>>2]=ia,c[u+72>>2]=ja,c[u+80>>2]=ka,u)|0)|0;i=u;break c;break};case 3:{if(!Z){break d}ka=(FD(z)|0)!=0;prc(X|0,(ka?2490640:2479808)|0)|0;break c;break};case 1:{MD(z,V,X,Y)|0;ka=c[o>>2]|0;if((a[ka]|0)!=0){break c}kJb(ka);break b;break};case 2:{if((irc(B,2376504)|0)!=0){break d}ka=fD(z,0,0,1)|0;ja=G;MD(z,2147483647,F,1024)|0;do{if((irc(F,2355600)|0)==0){zD(z)|0;MD(z,2147483647,T,1024)|0;ia=FD(z)|0;if((ia|0)==0){break}ha=ZX(b,0)|0;if((ha|0)==0){break}MGb(ha+88|0,2346296,T,0)|0;ga=c[ha+8>>2]|0;c[ga+8>>2]=0;c[ga+48>>2]=8;c[ha+4>>2]=-1;if((fX(z,ha+104|0,ia)|0)<0){break}c[ha+136>>2]=c[ha>>2];ia=ha+140|0;c[ia>>2]=c[ia>>2]|1;ia=ha+72|0;c[ia>>2]=c[ia>>2]|1024}}while(0);fD(z,wrc(ka,ja,V,(V|0)<0|0?-1:0)|0,G,0)|0;mJb(C);break b;break};default:{}}}while(0);mJb(C);KIb(I,24,2370120,(u=i,i=i+24|0,c[u>>2]=B,c[u+8>>2]=U,c[u+16>>2]=V,u)|0);i=u;hD(z,V,(V|0)<0|0?-1:0)|0;break b}}while(0);MGb(H,B,c[o>>2]|0,0)|0;mJb(C)}}while(0);if((jD(z)|0)!=0){W=H;break a}}C=d[q+1|0]|0;T=d[q+2|0]|0;F=d[q+3|0]|0;E=d[q+4|0]|0;S=d[q+5|0]|0;R=d[q+6|0]|0;Q=d[q+7|0]|0;P=d[q+8|0]|0;O=d[q+9|0]|0;N=d[q+10|0]|0;M=d[q+11|0]|0;L=d[q+12|0]|0;K=d[q+13|0]|0;J=d[q+14|0]|0;D=d[q+15|0]|0;KIb(I,24,2533624,(u=i,i=i+128|0,c[u>>2]=d[A]|0,c[u+8>>2]=C,c[u+16>>2]=T,c[u+24>>2]=F,c[u+32>>2]=E,c[u+40>>2]=S,c[u+48>>2]=R,c[u+56>>2]=Q,c[u+64>>2]=P,c[u+72>>2]=O,c[u+80>>2]=N,c[u+88>>2]=M,c[u+96>>2]=L,c[u+104>>2]=K,c[u+112>>2]=J,c[u+120>>2]=D,u)|0);i=u;W=H}else{W=b+1140|0}}while(0);cL(W,0,1431456);W=z+20|0;kJb(c[(c[W>>2]|0)+8>>2]|0);mJb(W);mJb(z+4|0);kJb(z)}do{if((c[b+24>>2]|0)!=0){z=c[c[b+28>>2]>>2]|0;W=NZ(b,x,w,1293760,40)|0;if((W|0)==0){break}u=GD(W)|0;A=G;q=GD(W)|0;if((jD(W)|0)==0){o=r+32|0;B=r+36|0;n=r+40|0;m=A;A=u;u=q;while(1){AX(o,B,n,0,0,A,m,u,0,1)|0;q=GD(W)|0;l=G;j=GD(W)|0;if((jD(W)|0)==0){m=l;A=q;u=j}else{la=B;break}}}else{la=r+36|0}B=W+20|0;kJb(c[(c[B>>2]|0)+8>>2]|0);mJb(B);mJb(W+4|0);kJb(W);if((c[la>>2]|0)==0){break}B=NZ(b,x,w,1278488,62)|0;if((B|0)==0){break}u=GD(B)|0;A=G;m=GD(B)|0;n=G;o=r+32|0;if((jD(B)|0)==0){H=A;A=u;u=n;n=m;do{m=c[la>>2]|0;e:do{if((m|0)>0){I=c[o>>2]|0;j=m;do{j=j-1|0;q=c[I+(j*24|0)+16>>2]>>2;l=(q|0)<0|0?-1:0;if(H>>>0>l>>>0|H>>>0==l>>>0&A>>>0>q>>>0){break e}q=I+(j*24|0)|0;l=c[q+4>>2]|0;if(u>>>0>l>>>0|u>>>0==l>>>0&n>>>0>(c[q>>2]|0)>>>0){c[q>>2]=n;c[q+4>>2]=u}}while((j|0)>0)}}while(0);A=GD(B)|0;H=G;n=GD(B)|0;u=G;}while((jD(B)|0)==0)}u=B+20|0;kJb(c[(c[u>>2]|0)+8>>2]|0);mJb(u);mJb(B+4|0);kJb(B);u=(c[o>>2]|0)+(((c[la>>2]|0)-1|0)*24|0)+8|0;n=c[u+4>>2]|0;H=z+56|0;c[H>>2]=c[u>>2];c[H+4>>2]=n}}while(0);fD(c[s>>2]|0,y,t,0)|0;v=0;i=f;return v|0}function HZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=c[f>>2]|0;h=KZ(a,0,0,0,e)|0;if((h|0)<0){j=h;i=d;return j|0}a=fX(g,b,(c[e>>2]|0)-32|0)|0;if((a|0)<0){j=a;i=d;return j|0}c[b+32>>2]=h;h=f+16|0;f=c[h+4>>2]|0;a=b+8|0;c[a>>2]=c[h>>2];c[a+4>>2]=f;f=c[e>>2]|0;e=(f+7&-8)-f|0;hD(g,e,(e|0)<0|0?-1:0)|0;j=0;i=d;return j|0}function IZ(a){a=a|0;var b=0;b=c[a+12>>2]|0;mJb(b+32|0);a=c[b>>2]|0;b=a+20|0;kJb(c[(c[b>>2]|0)+8>>2]|0);mJb(b);mJb(a+4|0);kJb(a);return 0}function JZ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[a+12>>2]|0;g=c[b>>2]|0;h=c[c[a+28>>2]>>2]|0;if((f&10|0)!=0){i=-38;return i|0}j=b+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;m=(k|0)==0&(l|0)==(-2147483648|0);n=xrc(d,e,m?0:k,m?0:l)|0;l=G;m=b+32|0;k=b+36|0;o=BX(c[m>>2]|0,c[k>>2]|0,n,l,f)|0;if((o|0)>=0){f=(c[m>>2]|0)+(o*24|0)|0;p=fD(g,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=G;q=0;if((f|0)<(q|0)|(f|0)==(q|0)&p>>>0<0>>>0){i=-1;return i|0}p=(c[m>>2]|0)+(o*24|0)+8|0;o=c[p>>2]|0;q=c[p+4>>2]|0;p=b+16|0;c[p>>2]=o;c[p+4>>2]=q;f=c[j>>2]|0;r=c[j+4>>2]|0;if((f|0)==0&(r|0)==(-2147483648|0)){s=q;t=o}else{j=wrc(f,r,o,q)|0;q=G;c[p>>2]=j;c[p+4>>2]=q;s=q;t=j}j=b+24|0;c[j>>2]=t;c[j+4>>2]=s;i=0;return i|0}s=b+24|0;b=c[s>>2]|0;j=c[s+4>>2]|0;do{if((b|0)==0&(j|0)==(-2147483648|0)|((j|0)>(e|0)|(j|0)==(e|0)&b>>>0>d>>>0)){s=fD(g,0,0,0)|0;t=G;q=0;if((t|0)<(q|0)|(t|0)==(q|0)&s>>>0<0>>>0){i=-1}else{break}return i|0}else{s=h+56|0;q=c[s>>2]|0;t=c[s+4>>2]|0;if(!(((q|0)!=0|(t|0)!=(-2147483648|0))&((l|0)>(t|0)|(l|0)==(t|0)&n>>>0>q>>>0))){break}q=c[k>>2]|0;if((q|0)==0){break}t=(c[m>>2]|0)+((q-1|0)*24|0)|0;q=fD(g,c[t>>2]|0,c[t+4>>2]|0,0)|0;t=G;s=0;if((t|0)<(s|0)|(t|0)==(s|0)&q>>>0<0>>>0){i=-1}else{break}return i|0}}while(0);i=(KZ(a,1,d,e,0)|0)>>31&-34;return i|0}function KZ(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0;j=i;i=i+664|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=j+64|0;p=j+80|0;q=j+96|0;r=j+112|0;s=j+376|0;t=j+384|0;u=j+392|0;v=j+408|0;w=j+424|0;x=j+440|0;y=j+456|0;z=j+472|0;A=j+488|0;B=j+504|0;C=j+520|0;D=j+536|0;E=j+552|0;F=j+568|0;H=j+584|0;I=j+600|0;J=j+616|0;K=j+632|0;L=j+648|0;M=c[b+12>>2]|0;N=c[M>>2]|0;if((jD(N)|0)!=0){O=-541478725;i=j;return O|0}P=k|0;Q=l|0;R=m|0;S=n|0;T=b+28|0;U=o|0;V=p|0;W=q|0;X=r|0;Y=b;Z=t|0;_=t+3|0;t=M+16|0;$=M+24|0;aa=M+8|0;M=(e|0)!=1;ba=(e|0)==0;e=u|0;ca=u+1|0;da=u+2|0;ea=u+3|0;fa=u+4|0;ga=u+5|0;ha=u+6|0;ia=u+7|0;ja=u+8|0;ka=u+9|0;la=u+10|0;ma=u+11|0;na=u+12|0;oa=u+13|0;pa=u+14|0;qa=u+15|0;u=v|0;ra=v+1|0;sa=v+2|0;ta=v+3|0;ua=v+4|0;va=v+5|0;wa=v+6|0;xa=v+7|0;ya=v+8|0;za=v+9|0;Aa=v+10|0;Ba=v+11|0;Ca=v+12|0;Da=v+13|0;Ea=v+14|0;Fa=v+15|0;v=w|0;Ga=w+1|0;Ha=w+2|0;Ia=w+3|0;Ja=w+4|0;Ka=w+5|0;La=w+6|0;Ma=w+7|0;Na=w+8|0;Oa=w+9|0;Pa=w+10|0;Qa=w+11|0;Ra=w+12|0;Sa=w+13|0;Ta=w+14|0;Ua=w+15|0;w=x|0;Va=x+1|0;Wa=x+2|0;Xa=x+3|0;Ya=x+4|0;Za=x+5|0;_a=x+6|0;$a=x+7|0;ab=x+8|0;bb=x+9|0;cb=x+10|0;db=x+11|0;eb=x+12|0;fb=x+13|0;gb=x+14|0;hb=x+15|0;x=y|0;ib=y+1|0;jb=y+2|0;kb=y+3|0;lb=y+4|0;mb=y+5|0;nb=y+6|0;ob=y+7|0;pb=y+8|0;qb=y+9|0;rb=y+10|0;sb=y+11|0;tb=y+12|0;ub=y+13|0;vb=y+14|0;wb=y+15|0;y=z|0;xb=z+1|0;yb=z+2|0;zb=z+3|0;Ab=z+4|0;Bb=z+5|0;Cb=z+6|0;Db=z+7|0;Eb=z+8|0;Fb=z+9|0;Gb=z+10|0;Hb=z+11|0;Ib=z+12|0;Jb=z+13|0;Kb=z+14|0;Lb=z+15|0;z=A|0;Mb=A+1|0;Nb=A+2|0;Ob=A+3|0;Pb=A+4|0;Qb=A+5|0;Rb=A+6|0;Sb=A+7|0;Tb=A+8|0;Ub=A+9|0;Vb=A+10|0;Wb=A+11|0;Xb=A+12|0;Yb=A+13|0;Zb=A+14|0;_b=A+15|0;A=B|0;$b=B+1|0;ac=B+2|0;bc=B+3|0;cc=B+4|0;dc=B+5|0;ec=B+6|0;fc=B+7|0;gc=B+8|0;hc=B+9|0;ic=B+10|0;jc=B+11|0;kc=B+12|0;lc=B+13|0;mc=B+14|0;nc=B+15|0;B=C|0;oc=C+1|0;pc=C+2|0;qc=C+3|0;rc=C+4|0;sc=C+5|0;tc=C+6|0;uc=C+7|0;vc=C+8|0;wc=C+9|0;xc=C+10|0;yc=C+11|0;zc=C+12|0;Ac=C+13|0;Bc=C+14|0;Cc=C+15|0;C=D|0;Dc=D+1|0;Ec=D+2|0;Fc=D+3|0;Gc=D+4|0;Hc=D+5|0;Ic=D+6|0;Jc=D+7|0;Kc=D+8|0;Lc=D+9|0;Mc=D+10|0;Nc=D+11|0;Oc=D+12|0;Pc=D+13|0;Qc=D+14|0;Rc=D+15|0;D=E|0;Sc=E+1|0;Tc=E+2|0;Uc=E+3|0;Vc=E+4|0;Wc=E+5|0;Xc=E+6|0;Yc=E+7|0;Zc=E+8|0;_c=E+9|0;$c=E+10|0;ad=E+11|0;bd=E+12|0;cd=E+13|0;dd=E+14|0;ed=E+15|0;E=F|0;fd=F+1|0;gd=F+2|0;hd=F+3|0;id=F+4|0;jd=F+5|0;kd=F+6|0;ld=F+7|0;md=F+8|0;nd=F+9|0;od=F+10|0;pd=F+11|0;qd=F+12|0;rd=F+13|0;sd=F+14|0;td=F+15|0;F=H|0;ud=H+1|0;vd=H+2|0;wd=H+3|0;xd=H+4|0;yd=H+5|0;zd=H+6|0;Ad=H+7|0;Bd=H+8|0;Cd=H+9|0;Dd=H+10|0;Ed=H+11|0;Fd=H+12|0;Gd=H+13|0;Hd=H+14|0;Id=H+15|0;H=I|0;Jd=I+1|0;Kd=I+2|0;Ld=I+3|0;Md=I+4|0;Nd=I+5|0;Od=I+6|0;Pd=I+7|0;Qd=I+8|0;Rd=I+9|0;Sd=I+10|0;Td=I+11|0;Ud=I+12|0;Vd=I+13|0;Wd=I+14|0;Xd=I+15|0;I=J|0;Yd=J+1|0;Zd=J+2|0;_d=J+3|0;$d=J+4|0;ae=J+5|0;be=J+6|0;ce=J+7|0;de=J+8|0;ee=J+9|0;fe=J+10|0;ge=J+11|0;he=J+12|0;ie=J+13|0;je=J+14|0;ke=J+15|0;J=K|0;le=K+1|0;me=K+2|0;ne=K+3|0;oe=K+4|0;pe=K+5|0;qe=K+6|0;re=K+7|0;se=K+8|0;te=K+9|0;ue=K+10|0;ve=K+11|0;we=K+12|0;xe=K+13|0;ye=K+14|0;ze=K+15|0;K=L|0;Ae=L+1|0;Be=L+2|0;Ce=L+3|0;De=L+4|0;Ee=L+5|0;Fe=L+6|0;Ge=L+7|0;He=L+8|0;Ie=L+9|0;Je=L+10|0;Ke=L+11|0;Le=L+12|0;Me=L+13|0;Ne=L+14|0;Oe=L+15|0;L=k+1|0;Pe=k+2|0;Qe=k+3|0;Re=k+4|0;Se=k+5|0;Te=k+6|0;Ue=k+7|0;Ve=k+8|0;We=k+9|0;Xe=k+10|0;Ye=k+11|0;Ze=k+12|0;_e=k+13|0;$e=k+14|0;af=k+15|0;a:while(1){MS(N,k)|0;bf=FD(N)|0;if((bf|0)<32){O=-541478725;cf=76;break}df=(FD(N)|0)&32767;hD(N,8,0)|0;b:do{if((grc(P,1454912,16)|0)==0){if((oY(b,df)|0)>=0){ef=32;break}hD(N,28,0)|0;MS(N,l)|0;MS(N,m)|0;hD(N,12,0)|0;MS(N,n)|0;ff=FD(N)|0;LZ(b,0,df,Q,R,S,ff)|0;ef=ff+124|0}else{if((grc(P,1302624,16)|0)==0){ff=oY(b,df)|0;if(!((ff|0)>-1)){ef=32;break}gf=c[(c[(c[T>>2]|0)+(ff<<2)>>2]|0)+12>>2]|0;if((gf|0)==0){ef=32;break}if((c[gf>>2]|0)!=0){ef=32;break}hD(N,12,0)|0;MS(N,o)|0;MS(N,p)|0;hD(N,12,0)|0;MS(N,q)|0;gf=FD(N)|0;LZ(b,c[(c[T>>2]|0)+(ff<<2)>>2]|0,df,U,V,W,gf)|0;ef=gf+108|0;break}do{if((grc(P,2659464,16)|0)!=0){if((grc(P,2659416,16)|0)==0){break}if((grc(P,2659432,16)|0)==0){break}if((grc(P,2659368,16)|0)==0){break}if((grc(P,2659352,16)|0)==0){break}if((grc(P,2659336,16)|0)==0){break}if((grc(P,2659448,16)|0)==0){gf=oY(b,df)|0;if(!((gf|0)>-1)){ef=32;break b}ff=c[(c[T>>2]|0)+(gf<<2)>>2]|0;hD(N,8,0)|0;gf=zD(N)|0;if((gf|0)==2){hf=ff+72|0;c[hf>>2]=c[hf>>2]|128;ef=41;break b}else if((gf|0)==3){gf=ff+72|0;c[gf>>2]=c[gf>>2]|256;ef=41;break b}else{ef=41;break b}}if((grc(P,2659400,16)|0)==0){gf=oY(b,df)|0;if(!((gf|0)>-1)){ef=32;break b}hD(N,12,0)|0;if((FD(N)|0)==0){ef=48;break b}KIb(Y,24,2461512,(jf=i,i=i+8|0,c[jf>>2]=gf,jf)|0);i=jf;ef=48;break b}if((grc(P,2659384,16)|0)==0){gf=oY(b,df)|0;if(!((gf|0)>-1)){ef=32;break b}ff=c[(c[T>>2]|0)+(gf<<2)>>2]|0;hD(N,12,0)|0;AD(N,Z,3)|0;if((a[Z]|0)==0){ef=47;break b}a[_]=0;MGb(ff+88|0,2370520,Z,0)|0;if((irc(Z,2304240)|0)!=0){if((irc(Z,2252560)|0)!=0){ef=47;break b}}gf=ff+72|0;c[gf>>2]=c[gf>>2]|256;ef=47;break b}if((grc(P,1278472,16)|0)==0){if(!((oY(b,df)|0)>-1)){ef=32;break b}hD(N,8,0)|0;gf=GD(N)|0;ff=G;c[t>>2]=gf;c[t+4>>2]=ff;if((gf|0)==(-1|0)&(ff|0)==(-1|0)){c[t>>2]=0;c[t+4>>2]=-2147483648;ef=48;break b}c[$>>2]=gf;c[$+4>>2]=ff;hf=c[aa>>2]|0;kf=c[aa+4>>2]|0;if((hf|0)==0&(kf|0)==(-2147483648|0)|((ff|0)<(kf|0)|(ff|0)==(kf|0)&gf>>>0<hf>>>0)){c[aa>>2]=gf;c[aa+4>>2]=ff}if(M|((ff|0)<(g|0)|(ff|0)==(g|0)&gf>>>0<f>>>0)){ef=48;break b}else{cf=45;break a}}if((grc(P,1403072,16)|0)==0){lf=oY(b,df)|0;if(!(ba&(lf|0)>-1&(bf|0)>32)){ef=32;break b}mf=c[(c[(c[T>>2]|0)+(lf<<2)>>2]|0)+12>>2]|0;if((mf|0)==0){ef=32;break b}else{cf=49;break a}}a[e]=-125;a[ca]=-107;a[da]=116;a[ea]=64;a[fa]=-99;a[ga]=107;a[ha]=-20;a[ia]=78;a[ja]=-76;a[ka]=60;a[la]=103;a[ma]=-95;a[na]=-128;a[oa]=30;a[pa]=26;a[qa]=-101;if((grc(P,e,16)|0)==0){gf=oY(b,df)|0;if(!((gf|0)>-1)){ef=32;break b}KIb(Y,24,2209512,(jf=i,i=i+8|0,c[jf>>2]=gf,jf)|0);i=jf;ef=32;break b}a[u]=20;a[ra]=86;a[sa]=26;a[ta]=12;a[ua]=-51;a[va]=48;a[wa]=64;a[xa]=79;a[ya]=-68;a[za]=-65;a[Aa]=-48;a[Ba]=62;a[Ca]=82;a[Da]=48;a[Ea]=98;a[Fa]=7;if((grc(P,u,16)|0)==0){ef=32;break b}a[v]=121;a[Ga]=102;a[Ha]=-75;a[Ia]=-32;a[Ja]=-71;a[Ka]=18;a[La]=-52;a[Ma]=67;a[Na]=-73;a[Oa]=-33;a[Pa]=87;a[Qa]=-116;a[Ra]=-86;a[Sa]=90;a[Ta]=123;a[Ua]=99;if((grc(P,v,16)|0)==0){ef=32;break b}a[w]=2;a[Va]=-82;a[Wa]=91;a[Xa]=47;a[Ya]=-113;a[Za]=123;a[_a]=96;a[$a]=79;a[ab]=-126;a[bb]=-42;a[cb]=-28;a[db]=-22;a[eb]=47;a[fb]=31;a[gb]=76;a[hb]=-103;if((grc(P,w,16)|0)==0){ef=32;break b}if((grc(P,1454928,16)|0)==0){ef=32;break b}a[x]=-52;a[ib]=50;a[jb]=100;a[kb]=-35;a[lb]=41;a[mb]=-30;a[nb]=-37;a[ob]=64;a[pb]=-128;a[qb]=-10;a[rb]=-46;a[sb]=99;a[tb]=40;a[ub]=-46;a[vb]=118;a[wb]=31;if((grc(P,x,16)|0)==0){ef=32;break b}a[y]=-27;a[xb]=-59;a[yb]=103;a[zb]=-112;a[Ab]=92;a[Bb]=76;a[Cb]=5;a[Db]=66;a[Eb]=-122;a[Fb]=-56;a[Gb]=122;a[Hb]=-2;a[Ib]=32;a[Jb]=-2;a[Kb]=30;a[Lb]=-6;if((grc(P,y,16)|0)==0){ef=32;break b}a[z]=-128;a[Mb]=109;a[Nb]=-13;a[Ob]=65;a[Pb]=50;a[Qb]=65;a[Rb]=-62;a[Sb]=76;a[Tb]=-79;a[Ub]=33;a[Vb]=1;a[Wb]=-92;a[Xb]=50;a[Yb]=25;a[Zb]=-40;a[_b]=27;if((grc(P,z,16)|0)==0){ef=32;break b}a[A]=81;a[$b]=29;a[ac]=-85;a[bc]=114;a[cc]=-46;a[dc]=-121;a[ec]=-101;a[fc]=72;a[gc]=-70;a[hc]=17;a[ic]=14;a[jc]=8;a[kc]=-36;a[lc]=33;a[mc]=2;a[nc]=67;if((grc(P,A,16)|0)==0){ef=32;break b}a[B]=101;a[oc]=-113;a[pc]=-4;a[qc]=71;a[rc]=-69;a[sc]=-30;a[tc]=52;a[uc]=70;a[vc]=-100;a[wc]=-17;a[xc]=-3;a[yc]=-65;a[zc]=-26;a[Ac]=38;a[Bc]=29;a[Cc]=92;if((grc(P,B,16)|0)==0){ef=32;break b}a[C]=-53;a[Dc]=-59;a[Ec]=104;a[Fc]=-128;a[Gc]=4;a[Hc]=60;a[Ic]=43;a[Jc]=73;a[Kc]=-76;a[Lc]=125;a[Mc]=3;a[Nc]=8;a[Oc]=-126;a[Pc]=13;a[Qc]=-50;a[Rc]=81;if((grc(P,C,16)|0)==0){ef=32;break b}a[D]=-68;a[Sc]=46;a[Tc]=-81;a[Uc]=-126;a[Vc]=-90;a[Wc]=48;a[Xc]=100;a[Yc]=66;a[Zc]=-88;a[_c]=11;a[$c]=-83;a[ad]=46;a[bd]=19;a[cd]=114;a[dd]=-84;a[ed]=96;if((grc(P,D,16)|0)==0){ef=32;break b}a[E]=30;a[fd]=-66;a[gd]=-61;a[hd]=-59;a[id]=67;a[jd]=-110;a[kd]=-36;a[ld]=17;a[md]=-123;a[nd]=-27;a[od]=0;a[pd]=18;a[qd]=63;a[rd]=111;a[sd]=115;a[td]=-71;if((grc(P,E,16)|0)==0){ef=32;break b}a[F]=59;a[ud]=-122;a[vd]=-94;a[wd]=-79;a[xd]=-21;a[yd]=30;a[zd]=-61;a[Ad]=68;a[Bd]=-116;a[Cd]=-120;a[Dd]=28;a[Ed]=-93;a[Fd]=-1;a[Gd]=-29;a[Hd]=-25;a[Id]=106;if((grc(P,F,16)|0)==0){ef=32;break b}a[H]=78;a[Jd]=127;a[Kd]=76;a[Ld]=91;a[Md]=-60;a[Nd]=-48;a[Od]=56;a[Pd]=75;a[Qd]=-88;a[Rd]=62;a[Sd]=33;a[Td]=127;a[Ud]=123;a[Vd]=-65;a[Wd]=82;a[Xd]=-25;if((grc(P,H,16)|0)==0){ef=32;break b}a[I]=99;a[Yd]=54;a[Zd]=-21;a[_d]=-2;a[$d]=-95;a[ae]=126;a[be]=-39;a[ce]=17;a[de]=-125;a[ee]=8;a[fe]=0;a[ge]=7;a[he]=-23;a[ie]=94;a[je]=-83;a[ke]=-115;if((grc(P,I,16)|0)==0){ef=32;break b}a[J]=112;a[le]=-23;a[me]=-15;a[ne]=-8;a[oe]=-119;a[pe]=-92;a[qe]=76;a[re]=77;a[se]=-125;a[te]=115;a[ue]=-72;a[ve]=18;a[we]=-32;a[xe]=-43;a[ye]=-8;a[ze]=30;if((grc(P,J,16)|0)==0){ef=32;break b}if((grc(P,1370952,16)|0)==0){ef=32;break b}if((grc(P,1297704,16)|0)==0){ef=32;break b}if((grc(P,1302640,16)|0)==0){ef=32;break b}a[K]=-9;a[Ae]=16;a[Be]=2;a[Ce]=-71;a[De]=-18;a[Ee]=124;a[Fe]=-19;a[Ge]=78;a[He]=-67;a[Ie]=127;a[Je]=5;a[Ke]=64;a[Le]=53;a[Me]=-122;a[Ne]=24;a[Oe]=-95;if((grc(P,K,16)|0)==0){ef=32;break b}gf=d[L]|0;ff=d[Pe]|0;hf=d[Qe]|0;kf=d[Re]|0;nf=d[Se]|0;of=d[Te]|0;pf=d[Ue]|0;qf=d[Ve]|0;rf=d[We]|0;sf=d[Xe]|0;tf=d[Ye]|0;uf=d[Ze]|0;vf=d[_e]|0;wf=d[$e]|0;xf=d[af]|0;KIb(Y,24,2176928,(jf=i,i=i+128|0,c[jf>>2]=d[P]|0,c[jf+8>>2]=gf,c[jf+16>>2]=ff,c[jf+24>>2]=hf,c[jf+32>>2]=kf,c[jf+40>>2]=nf,c[jf+48>>2]=of,c[jf+56>>2]=pf,c[jf+64>>2]=qf,c[jf+72>>2]=rf,c[jf+80>>2]=sf,c[jf+88>>2]=tf,c[jf+96>>2]=uf,c[jf+104>>2]=vf,c[jf+112>>2]=wf,c[jf+120>>2]=xf,jf)|0);i=jf;ef=32;break b}}while(0);xf=oY(b,df)|0;if(!((xf|0)>-1)){ef=32;break}wf=c[(c[T>>2]|0)+(xf<<2)>>2]|0;c[s>>2]=X;hD(N,8,0)|0;if((grc(P,2659416,16)|0)==0){cf=21}else{if((grc(P,2659432,16)|0)==0){cf=21}else{yf=40}}if((cf|0)==21){cf=0;hD(N,6,0)|0;yf=46}xf=bf-yf|0;vf=xf>>>0>258>>>0?258:xf;AD(N,X,vf)|0;ZN(b,wf,0,s,r+vf|0,0,0,0,0)|0;ef=vf+yf|0}}while(0);df=(bf+7&-8)-ef|0;hD(N,df,(df|0)<0|0?-1:0)|0;if((jD(N)|0)!=0){O=-541478725;cf=76;break}}if((cf|0)==45){ef=bf-41&-8;hD(N,ef,(ef|0)<0|0?-1:0)|0;O=0;i=j;return O|0}else if((cf|0)==49){c[mf>>2]=1;if((h|0)==0){O=lf;i=j;return O|0}c[h>>2]=bf;O=lf;i=j;return O|0}else if((cf|0)==76){i=j;return O|0}return 0}function LZ(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;l=i;i=i+64|0;m=l|0;n=l+16|0;o=l+32|0;p=l+48|0;q=b+12|0;r=c[c[q>>2]>>2]|0;do{if((grc(h,1358504,16)|0)==0){if((grc(j,1387032,16)|0)!=0){break}if((k|0)<32){KIb(b,24,2148896,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;hD(r,k,(k|0)<0|0?-1:0)|0;t=0;i=l;return t|0}else{u=k-32|0;hD(r,u,(u|0)<0|0?-1:0)|0;MS(r,m)|0;MS(r,n)|0;v=-k|0;fD(r,v,(v|0)<0|0?-1:0,1)|0;v=LZ(b,e,f,g,m|0,n|0,u)|0;hD(r,32,0)|0;t=v;i=l;return t|0}}}while(0);if((grc(g,1358488,16)|0)==0){n=MZ(b,e,f,1)|0;if((n|0)==0){t=0;i=l;return t|0}do{if((grc(j,1386968,16)|0)==0){if((OS(r,c[n+8>>2]|0,k)|0)<0){t=0}else{break}i=l;return t|0}else{if((grc(j,1387e3,16)|0)!=0){m=d[j+1|0]|0;v=d[j+2|0]|0;u=d[j+3|0]|0;w=d[j+4|0]|0;x=d[j+5|0]|0;y=d[j+6|0]|0;z=d[j+7|0]|0;A=d[j+8|0]|0;B=d[j+9|0]|0;C=d[j+10|0]|0;D=d[j+11|0]|0;E=d[j+12|0]|0;F=d[j+13|0]|0;G=d[j+14|0]|0;H=d[j+15|0]|0;KIb(b,24,2124864,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=m,c[s+16>>2]=v,c[s+24>>2]=u,c[s+32>>2]=w,c[s+40>>2]=x,c[s+48>>2]=y,c[s+56>>2]=z,c[s+64>>2]=A,c[s+72>>2]=B,c[s+80>>2]=C,c[s+88>>2]=D,c[s+96>>2]=E,c[s+104>>2]=F,c[s+112>>2]=G,c[s+120>>2]=H,s)|0);i=s}hD(r,k,(k|0)<0|0?-1:0)|0;}}while(0);H=h+4|0;G=o|0;a[G]=0;a[o+1|0]=0;a[o+2|0]=16;a[o+3|0]=0;a[o+4|0]=-128;a[o+5|0]=0;a[o+6|0]=0;a[o+7|0]=-86;a[o+8|0]=0;a[o+9|0]=56;a[o+10|0]=-101;a[o+11|0]=113;if((grc(H,G,12)|0)==0){G=h;o=n+8|0;F=PS(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0,c[(c[o>>2]|0)+792>>2]|0)|0;c[(c[o>>2]|0)+48>>2]=F;t=n;i=l;return t|0}if((grc(h,831440,16)|0)!=0){F=NS(1406904,h)|0;c[(c[n+8>>2]|0)+48>>2]=F;if((F|0)!=0){t=n;i=l;return t|0}F=d[h+1|0]|0;o=d[h+2|0]|0;G=d[h+3|0]|0;E=d[H]|0;H=d[h+5|0]|0;D=d[h+6|0]|0;C=d[h+7|0]|0;B=d[h+8|0]|0;A=d[h+9|0]|0;z=d[h+10|0]|0;y=d[h+11|0]|0;x=d[h+12|0]|0;w=d[h+13|0]|0;u=d[h+14|0]|0;v=d[h+15|0]|0;KIb(b,24,2619672,(s=i,i=i+128|0,c[s>>2]=d[h]|0,c[s+8>>2]=F,c[s+16>>2]=o,c[s+24>>2]=G,c[s+32>>2]=E,c[s+40>>2]=H,c[s+48>>2]=D,c[s+56>>2]=C,c[s+64>>2]=B,c[s+72>>2]=A,c[s+80>>2]=z,c[s+88>>2]=y,c[s+96>>2]=x,c[s+104>>2]=w,c[s+112>>2]=u,c[s+120>>2]=v,s)|0);i=s;t=n;i=l;return t|0}v=c[n+8>>2]|0;u=c[v+96>>2]|0;do{if((u|0)!=0){if((c[v+100>>2]|0)<=21){break}w=u;x=(d[w]|d[w+1|0]<<8)<<16>>16&65535;if((x|0)==2){c[v+48>>2]=86016}else if((x|0)==1){c[v+48>>2]=86059}else if((x|0)==4){c[v+48>>2]=86017}x=u+2|0;c[v+72>>2]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;x=u+6|0;w=(d[x]|d[x+1|0]<<8)<<16>>16&65535;if((w|0)==1|(w|0)==2|(w|0)==4){c[v+416>>2]=2;x=v+448|0;c[x>>2]=3;c[x+4>>2]=0;t=n;i=l;return t|0}else if((w|0)==8){c[v+416>>2]=1;w=v+448|0;c[w>>2]=4;c[w+4>>2]=0;t=n;i=l;return t|0}else{t=n;i=l;return t|0}}}while(0);KIb(b,24,2643064,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=n;i=l;return t|0}if((grc(g,1358472,16)|0)==0){n=MZ(b,e,f,0)|0;if((n|0)==0){t=0;i=l;return t|0}do{if((grc(j,1386984,16)|0)==0){v=c[c[q>>2]>>2]|0;hD(v,72,0)|0;QS(v,n,0)|0;v=k-112|0;u=(v|0)>0;hD(r,u?v:0,u?(v|0)<0|0?-1:0:0)|0;}else{if((grc(j,1387016,16)|0)==0){v=c[c[q>>2]>>2]|0;hD(v,72,0)|0;QS(v,n,0)|0;v=k-112|0;u=(v|0)>0;hD(r,u?v:0,u?(v|0)<0|0?-1:0:0)|0;break}if((grc(j,1387e3,16)|0)!=0){v=d[j+1|0]|0;u=d[j+2|0]|0;w=d[j+3|0]|0;x=d[j+4|0]|0;y=d[j+5|0]|0;z=d[j+6|0]|0;A=d[j+7|0]|0;B=d[j+8|0]|0;C=d[j+9|0]|0;D=d[j+10|0]|0;H=d[j+11|0]|0;E=d[j+12|0]|0;G=d[j+13|0]|0;o=d[j+14|0]|0;F=d[j+15|0]|0;KIb(b,24,2124864,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=v,c[s+16>>2]=u,c[s+24>>2]=w,c[s+32>>2]=x,c[s+40>>2]=y,c[s+48>>2]=z,c[s+56>>2]=A,c[s+64>>2]=B,c[s+72>>2]=C,c[s+80>>2]=D,c[s+88>>2]=H,c[s+96>>2]=E,c[s+104>>2]=G,c[s+112>>2]=o,c[s+120>>2]=F,s)|0);i=s}hD(r,k,(k|0)<0|0?-1:0)|0;}}while(0);q=h+4|0;F=p|0;a[F]=0;a[p+1|0]=0;a[p+2|0]=16;a[p+3|0]=0;a[p+4|0]=-128;a[p+5|0]=0;a[p+6|0]=0;a[p+7|0]=-86;a[p+8|0]=0;a[p+9|0]=56;a[p+10|0]=-101;a[p+11|0]=113;if((grc(q,F,12)|0)==0){F=h;p=JX(1409152,d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0;c[(c[n+8>>2]|0)+48>>2]=p;I=p}else{p=NS(1256008,h)|0;c[(c[n+8>>2]|0)+48>>2]=p;I=p}if((I|0)!=0){t=n;i=l;return t|0}I=d[h+1|0]|0;p=d[h+2|0]|0;F=d[h+3|0]|0;o=d[q]|0;q=d[h+5|0]|0;G=d[h+6|0]|0;E=d[h+7|0]|0;H=d[h+8|0]|0;D=d[h+9|0]|0;C=d[h+10|0]|0;B=d[h+11|0]|0;A=d[h+12|0]|0;z=d[h+13|0]|0;y=d[h+14|0]|0;x=d[h+15|0]|0;KIb(b,24,2619672,(s=i,i=i+128|0,c[s>>2]=d[h]|0,c[s+8>>2]=I,c[s+16>>2]=p,c[s+24>>2]=F,c[s+32>>2]=o,c[s+40>>2]=q,c[s+48>>2]=G,c[s+56>>2]=E,c[s+64>>2]=H,c[s+72>>2]=D,c[s+80>>2]=C,c[s+88>>2]=B,c[s+96>>2]=A,c[s+104>>2]=z,c[s+112>>2]=y,c[s+120>>2]=x,s)|0);i=s;t=n;i=l;return t|0}do{if((grc(g,831392,16)|0)==0){if((grc(h,831456,16)|0)!=0){break}n=MZ(b,e,f,3)|0;if((n|0)==0){t=0;i=l;return t|0}if((grc(j,1387e3,16)|0)!=0){x=d[j+1|0]|0;y=d[j+2|0]|0;z=d[j+3|0]|0;A=d[j+4|0]|0;B=d[j+5|0]|0;C=d[j+6|0]|0;D=d[j+7|0]|0;H=d[j+8|0]|0;E=d[j+9|0]|0;G=d[j+10|0]|0;q=d[j+11|0]|0;o=d[j+12|0]|0;F=d[j+13|0]|0;p=d[j+14|0]|0;I=d[j+15|0]|0;KIb(b,24,2124864,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=x,c[s+16>>2]=y,c[s+24>>2]=z,c[s+32>>2]=A,c[s+40>>2]=B,c[s+48>>2]=C,c[s+56>>2]=D,c[s+64>>2]=H,c[s+72>>2]=E,c[s+80>>2]=G,c[s+88>>2]=q,c[s+96>>2]=o,c[s+104>>2]=F,c[s+112>>2]=p,c[s+120>>2]=I,s)|0);i=s}hD(r,k,(k|0)<0|0?-1:0)|0;c[(c[n+8>>2]|0)+48>>2]=94209;t=n;i=l;return t|0}}while(0);do{if((grc(g,831360,16)|0)==0){if((grc(h,831408,16)|0)!=0){if((grc(h,831472,16)|0)!=0){break}}n=MZ(b,e,f,3)|0;if((n|0)==0){t=0;i=l;return t|0}if((grc(j,1387e3,16)|0)!=0){I=d[j+1|0]|0;p=d[j+2|0]|0;F=d[j+3|0]|0;o=d[j+4|0]|0;q=d[j+5|0]|0;G=d[j+6|0]|0;E=d[j+7|0]|0;H=d[j+8|0]|0;D=d[j+9|0]|0;C=d[j+10|0]|0;B=d[j+11|0]|0;A=d[j+12|0]|0;z=d[j+13|0]|0;y=d[j+14|0]|0;x=d[j+15|0]|0;KIb(b,24,2124864,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=I,c[s+16>>2]=p,c[s+24>>2]=F,c[s+32>>2]=o,c[s+40>>2]=q,c[s+48>>2]=G,c[s+56>>2]=E,c[s+64>>2]=H,c[s+72>>2]=D,c[s+80>>2]=C,c[s+88>>2]=B,c[s+96>>2]=A,c[s+104>>2]=z,c[s+112>>2]=y,c[s+120>>2]=x,s)|0);i=s}hD(r,k,(k|0)<0|0?-1:0)|0;x=(grc(h,831408,16)|0)==0;c[(c[n+8>>2]|0)+48>>2]=x?94215:1664495672;t=n;i=l;return t|0}}while(0);do{if((grc(g,831376,16)|0)==0){if((grc(h,831424,16)|0)!=0){break}if((grc(j,1387e3,16)|0)!=0){f=d[j+1|0]|0;e=d[j+2|0]|0;n=d[j+3|0]|0;x=d[j+4|0]|0;y=d[j+5|0]|0;z=d[j+6|0]|0;A=d[j+7|0]|0;B=d[j+8|0]|0;C=d[j+9|0]|0;D=d[j+10|0]|0;H=d[j+11|0]|0;E=d[j+12|0]|0;G=d[j+13|0]|0;q=d[j+14|0]|0;o=d[j+15|0]|0;KIb(b,24,2124864,(s=i,i=i+128|0,c[s>>2]=d[j]|0,c[s+8>>2]=f,c[s+16>>2]=e,c[s+24>>2]=n,c[s+32>>2]=x,c[s+40>>2]=y,c[s+48>>2]=z,c[s+56>>2]=A,c[s+64>>2]=B,c[s+72>>2]=C,c[s+80>>2]=D,c[s+88>>2]=H,c[s+96>>2]=E,c[s+104>>2]=G,c[s+112>>2]=q,c[s+120>>2]=o,s)|0);i=s}hD(r,k,(k|0)<0|0?-1:0)|0;t=0;i=l;return t|0}}while(0);o=d[g+1|0]|0;q=d[g+2|0]|0;G=d[g+3|0]|0;E=d[g+4|0]|0;H=d[g+5|0]|0;D=d[g+6|0]|0;C=d[g+7|0]|0;B=d[g+8|0]|0;A=d[g+9|0]|0;z=d[g+10|0]|0;y=d[g+11|0]|0;x=d[g+12|0]|0;n=d[g+13|0]|0;e=d[g+14|0]|0;f=d[g+15|0]|0;F=d[h]|0;p=d[h+1|0]|0;I=d[h+2|0]|0;w=d[h+3|0]|0;u=d[h+4|0]|0;v=d[h+5|0]|0;m=d[h+6|0]|0;J=d[h+7|0]|0;K=d[h+8|0]|0;L=d[h+9|0]|0;M=d[h+10|0]|0;N=d[h+11|0]|0;O=d[h+12|0]|0;P=d[h+13|0]|0;Q=d[h+14|0]|0;R=d[h+15|0]|0;h=d[j]|0;S=d[j+1|0]|0;T=d[j+2|0]|0;U=d[j+3|0]|0;V=d[j+4|0]|0;W=d[j+5|0]|0;X=d[j+6|0]|0;Y=d[j+7|0]|0;Z=d[j+8|0]|0;_=d[j+9|0]|0;$=d[j+10|0]|0;aa=d[j+11|0]|0;ba=d[j+12|0]|0;ca=d[j+13|0]|0;da=d[j+14|0]|0;ea=d[j+15|0]|0;KIb(b,24,2592336,(s=i,i=i+384|0,c[s>>2]=d[g]|0,c[s+8>>2]=o,c[s+16>>2]=q,c[s+24>>2]=G,c[s+32>>2]=E,c[s+40>>2]=H,c[s+48>>2]=D,c[s+56>>2]=C,c[s+64>>2]=B,c[s+72>>2]=A,c[s+80>>2]=z,c[s+88>>2]=y,c[s+96>>2]=x,c[s+104>>2]=n,c[s+112>>2]=e,c[s+120>>2]=f,c[s+128>>2]=F,c[s+136>>2]=p,c[s+144>>2]=I,c[s+152>>2]=w,c[s+160>>2]=u,c[s+168>>2]=v,c[s+176>>2]=m,c[s+184>>2]=J,c[s+192>>2]=K,c[s+200>>2]=L,c[s+208>>2]=M,c[s+216>>2]=N,c[s+224>>2]=O,c[s+232>>2]=P,c[s+240>>2]=Q,c[s+248>>2]=R,c[s+256>>2]=h,c[s+264>>2]=S,c[s+272>>2]=T,c[s+280>>2]=U,c[s+288>>2]=V,c[s+296>>2]=W,c[s+304>>2]=X,c[s+312>>2]=Y,c[s+320>>2]=Z,c[s+328>>2]=_,c[s+336>>2]=$,c[s+344>>2]=aa,c[s+352>>2]=ba,c[s+360>>2]=ca,c[s+368>>2]=da,c[s+376>>2]=ea,s)|0);i=s;hD(r,k,(k|0)<0|0?-1:0)|0;t=0;i=l;return t|0}function MZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;do{if((b|0)==0){f=pJb(4)|0;if((f|0)==0){g=0;return g|0}h=ZX(a,0)|0;if((h|0)!=0){c[h+4>>2]=d;c[h+12>>2]=f;i=h;j=c[h+8>>2]|0;break}kJb(f);g=0;return g|0}else{f=b+8|0;h=c[f>>2]|0;k=h+96|0;if((c[k>>2]|0)==0){i=b;j=h;break}mJb(k);k=c[f>>2]|0;c[k+100>>2]=0;i=b;j=k}}while(0);c[j+8>>2]=e;c[i+236>>2]=1;_X(i,64,1,1e7);g=i;return g|0}function NZ(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+4096|0;j=h|0;k=b+e|0;if((e|0)<48){l=0;i=h;return l|0}e=k;m=g+2|0;n=g+40|0;o=b;a:while(1){if((grc(o,1402296,16)|0)!=0){p=4;break}b=o+16|0;q=(d[b]|d[b+1|0]<<8)<<16>>16&65535;b=o+24|0;r=b|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=b+4|0;t=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=o+32|0;b=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24)<<1;if((b|0)<0){p=6;break}r=wrc(b,(b|0)<0|0?-1:0,48,0)|0;u=G;v=e-o|0;w=(v|0)<0|0?-1:0;if((u|0)>(w|0)|(u|0)==(w|0)&r>>>0>v>>>0){p=8;break}v=o+(b+40)|0;x=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=o+(b+44)|0;y=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;do{if((b|0)>=(g|0)){if((grc(o+40|0,f,g)|0)!=0){break}if((b|0)<(m|0)){p=13;break a}v=o+n|0;if((d[v]|d[v+1|0]<<8)<<16>>16<<16>>16==0){p=13;break a}}}while(0);if((o+(q+48)|0)>>>0>k>>>0){l=0;p=54;break}else{o=o+q|0}}if((p|0)==4){k=d[o+1|0]|0;n=d[o+2|0]|0;m=d[o+3|0]|0;g=d[o+4|0]|0;f=d[o+5|0]|0;e=d[o+6|0]|0;b=d[o+7|0]|0;v=d[o+8|0]|0;r=d[o+9|0]|0;w=d[o+10|0]|0;u=d[o+11|0]|0;z=d[o+12|0]|0;A=d[o+13|0]|0;B=d[o+14|0]|0;C=d[o+15|0]|0;KIb(a,16,2334264,(D=i,i=i+128|0,c[D>>2]=d[o]|0,c[D+8>>2]=k,c[D+16>>2]=n,c[D+24>>2]=m,c[D+32>>2]=g,c[D+40>>2]=f,c[D+48>>2]=e,c[D+56>>2]=b,c[D+64>>2]=v,c[D+72>>2]=r,c[D+80>>2]=w,c[D+88>>2]=u,c[D+96>>2]=z,c[D+104>>2]=A,c[D+112>>2]=B,c[D+120>>2]=C,D)|0);i=D;l=0;i=h;return l|0}else if((p|0)==6){KIb(a,16,2329192,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;l=0;i=h;return l|0}else if((p|0)==8){KIb(a,16,2323264,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;l=0;i=h;return l|0}else if((p|0)==13){C=a+16|0;B=x;A=fD(c[C>>2]|0,B<<12|0>>>20,((x|0)<0|0?-1:0)<<12|B>>>20,0)|0;B=G;z=0;if((B|0)<(z|0)|(B|0)==(z|0)&A>>>0<0>>>0){l=0;i=h;return l|0}A=pJb(40)|0;if((A|0)==0){l=0;i=h;return l|0}b:do{if((y|0)==1){z=hJb(4096)|0;B=z;c[A+8>>2]=B;if((z|0)==0){kJb(A);l=0;i=h;return l|0}z=c[C>>2]|0;u=0;w=0;do{r=FD(z)|0;c[B+(w<<2)>>2]=r;w=((r|0)!=0)+w|0;u=u+1|0;}while((u|0)<1024);c[A+12>>2]=w;E=w;p=38}else if((y|0)==2){u=c[C>>2]|0;B=0;z=0;do{q=FD(u)|0;c[j+(z<<2)>>2]=q;z=((q|0)!=0)+z|0;B=B+1|0;}while((B|0)<1024);do{if(z>>>0>524286>>>0){c[A+8>>2]=0}else{B=hJb(z<<12)|0;u=B;w=A+8|0;c[w>>2]=u;if((B|0)==0){break}B=A+12|0;c[B>>2]=0;if((z|0)>0){F=0}else{q=0;c[A+4>>2]=(t|0)<(q|0)|(t|0)==(q|0)&s>>>0<0>>>0?12:18;H=u;p=41;break b}while(1){u=c[j+(F<<2)>>2]|0;q=fD(c[C>>2]|0,u<<12|0>>>20,0<<12|u>>>20,0)|0;u=G;r=0;if((u|0)<(r|0)|(u|0)==(r|0)&q>>>0<0>>>0){break}q=c[C>>2]|0;r=c[w>>2]|0;u=(F<<12|0)/4|0;v=0;b=0;do{e=FD(q)|0;c[r+(b+u<<2)>>2]=e;b=((e|0)!=0)+b|0;v=v+1|0;}while((v|0)<1024);v=(c[B>>2]|0)+b|0;c[B>>2]=v;u=F+1|0;if((u|0)<(z|0)){F=u}else{E=v;p=38;break b}}E=c[B>>2]|0;p=38;break b}}while(0);kJb(A);l=0;i=h;return l|0}else if((y|0)==0){z=hJb(4)|0;w=z;c[A+8>>2]=w;if((z|0)!=0){c[w>>2]=x;w=A+12|0;c[w>>2]=1;z=0;v=A+4|0;c[v>>2]=(t|0)<(z|0)|(t|0)==(z|0)&s>>>0<0>>>0?12:18;I=v;J=w;break}kJb(A);l=0;i=h;return l|0}else{KIb(a,16,2318224,(D=i,i=i+8|0,c[D>>2]=y,D)|0);i=D;kJb(A);l=0;i=h;return l|0}}while(0);do{if((p|0)==38){y=0;x=A+4|0;c[x>>2]=(t|0)<(y|0)|(t|0)==(y|0)&s>>>0<0>>>0?12:18;if((E|0)==0){H=c[A+8>>2]|0;p=41;break}else{I=x;J=A+12|0;break}}}while(0);if((p|0)==41){kJb(H);kJb(A);l=0;i=h;return l|0}H=iD(c[C>>2]|0)|0;E=G;x=-1;do{if((E|0)>(x|0)|(E|0)==(x|0)&H>>>0>-1>>>0){y=c[(c[A+8>>2]|0)+((c[J>>2]|0)-1<<2)>>2]|0;F=0<<12|y>>>20;if(!((F|0)>(E|0)|(F|0)==(E|0)&(y<<12|0>>>20)>>>0>H>>>0)){break}KIb(a,24,2313416,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D}}while(0);H=s|0;s=t&65535;t=c[J>>2]|0;E=yrc(t|0,((t|0)<0|0?-1:0)|0,c[I>>2]|0)|0;t=G;if(s>>>0>t>>>0|s>>>0==t>>>0&H>>>0>E>>>0){KIb(a,24,2308752,(D=i,i=i+32|0,c[D>>2]=H,c[D+8>>2]=s,c[D+16>>2]=E,c[D+24>>2]=t,D)|0);i=D;D=c[J>>2]|0;J=yrc(D|0,((D|0)<0|0?-1:0)|0,c[I>>2]|0)|0;K=G;L=J}else{K=s;L=H}H=A+32|0;c[H>>2]=L;c[H+4>>2]=K;K=A+24|0;c[K>>2]=0;c[K+4>>2]=0;K=A+8|0;H=c[c[K>>2]>>2]|0;L=fD(c[C>>2]|0,H<<12|0>>>20,0<<12|H>>>20,0)|0;H=G;s=0;if((H|0)<(s|0)|(H|0)==(s|0)&L>>>0<0>>>0){kJb(c[K>>2]|0);kJb(A);l=0;i=h;return l|0}c[A>>2]=c[C>>2];C=hJb(1<<c[I>>2])|0;if((C|0)==0){kJb(c[K>>2]|0);kJb(A);l=0;i=h;return l|0}L=aD(C,1<<c[I>>2],0,A,28,0,336)|0;if((L|0)!=0){l=L;i=h;return l|0}kJb(C);kJb(c[K>>2]|0);kJb(A);l=0;i=h;return l|0}else if((p|0)==54){i=h;return l|0}return 0}function OZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=c[a>>2]|0;f=a+16|0;if((c[f>>2]|0)!=0){g=-1;return g|0}if((c[e+76>>2]|0)!=0){g=-1;return g|0}h=a+24|0;i=c[h+4>>2]|0;j=a+32|0;k=c[j+4>>2]|0;if(!((i|0)<(k|0)|(i|0)==(k|0)&(c[h>>2]|0)>>>0<(c[j>>2]|0)>>>0)){g=0;return g|0}if((jD(e)|0)!=0){g=0;return g|0}k=(d|0)<0|0?-1:0;i=c[h>>2]|0;l=c[h+4>>2]|0;m=xrc(c[j>>2]|0,c[j+4>>2]|0,i,l)|0;j=G;n=(k|0)>(j|0)|(k|0)==(j|0)&d>>>0>m>>>0?m:d;if((n|0)<=0){g=0;return g|0}d=a+4|0;m=a+12|0;j=a+8|0;a=0;k=b;b=l;l=i;a:while(1){i=1<<c[d>>2];o=xrc(i,0,i-1&l,0&b)|0;i=o;o=n-a|0;p=AD(e,k,(o|0)>(i|0)?i:o)|0;if((p|0)<1){g=a;q=15;break}r=p+a|0;o=k+p|0;s=wrc(c[h>>2]|0,c[h+4>>2]|0,p,(p|0)<0|0?-1:0)|0;t=G;c[h>>2]=s;c[h+4>>2]=t;do{if((p|0)==(i|0)){u=c[d>>2]|0;v=Arc(s|0,t|0,u|0)|0;w=v;if((w|0)>=(c[m>>2]|0)){q=14;break a}v=c[j>>2]|0;x=c[v+(w<<2)>>2]|0;if((x|0)==((c[v+(w-1<<2)>>2]|0)+(1<<u-12)|0)){break}u=x;x=fD(e,u<<12|0>>>20,0<<12|u>>>20,0)|0;u=G;w=0;if((u|0)<(w|0)|(u|0)==(w|0)&x>>>0<0>>>0){q=14;break a}}}while(0);if((r|0)>=(n|0)){g=r;q=15;break}a=r;k=o;b=c[h+4>>2]|0;l=c[h>>2]|0}if((q|0)==14){c[f>>2]=1;g=r;return g|0}else if((q|0)==15){return g|0}return 0}function PZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[a>>2]|0;if((e|0)==65536){g=a+32|0;h=c[g+4>>2]|0;i=c[g>>2]|0;return(G=h,i)|0}else if((e|0)==2){g=a+32|0;j=c[g+4>>2]|0;k=c[g>>2]|0}else if((e|0)==1){e=a+24|0;g=wrc(c[e>>2]|0,c[e+4>>2]|0,b,d)|0;j=G;k=g}else{j=d;k=b}b=0;do{if((j|0)<(b|0)|(j|0)==(b|0)&k>>>0<0>>>0){l=1}else{d=a+32|0;g=c[d+4>>2]|0;if(!((j|0)<(g|0)|(j|0)==(g|0)&k>>>0<(c[d>>2]|0)>>>0)){l=1;break}d=c[a+4>>2]|0;g=Arc(k|0,j|0,d|0)|0;e=c[(c[a+8>>2]|0)+(g<<2)>>2]|0;g=(1<<d)-1|0;d=wrc(e<<12|0>>>20,0<<12|e>>>20,g&k,((g|0)<0|0?-1:0)&j)|0;fD(f,d,G,0)|0;l=G>>>31|0<<1}}while(0);c[a+16>>2]=l;l=a+24|0;c[l>>2]=k;c[l+4>>2]=j;h=j;i=k;return(G=h,i)|0}function QZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;d=a+16|0;e=c[d>>2]|0;f=a+12|0;g=c[f>>2]|0;h=g+208|0;j=h;mrc(h|0,-1|0,16)|0;VS(e,1245464);VS(e,553008);kD(e,1);kD(e,2);kD(e,4096);kD(e,262144);kD(e,0);cD(e,0,4);kD(e,0);cD(e,0,32);kD(e,0);h=fD(e,0,0,1)|0;k=xrc(4096,0,h,G)|0;cD(e,0,k);k=fD(e,0,0,1)|0;e=g;c[e>>2]=k;c[e+4>>2]=G;e=g+200|0;c[e>>2]=1;c[e+4>>2]=0;c[j>>2]=-1;c[j+4>>2]=-1;c[g+476>>2]=1;j=a+24|0;a:do{if((c[j>>2]|0)!=0){e=a+28|0;k=0;b:do{h=c[(c[e>>2]|0)+(k<<2)>>2]|0;l=h+8|0;do{if((c[(c[l>>2]|0)+48>>2]|0)!=8){m=c[d>>2]|0;n=c[f>>2]|0;o=n+208|0;p=c[o>>2]|0;q=c[o+4>>2]|0;YZ(n,m,1302640,0,-2147483647);rD(m,p,q);kD(m,1);cD(m,0,4);cD(m,0,4);if(($Z(a,h)|0)<0){r=7;break b}ZZ(a);if((k|0)!=0){break}XZ(a)}}while(0);k=k+1|0;s=c[j>>2]|0;}while(k>>>0<s>>>0);if((r|0)==7){k=a;KIb(k,16,2551792,(t=i,i=i+8|0,c[t>>2]=c[(c[l>>2]|0)+8>>2],t)|0);i=t;KIb(k,16,2592256,(t=i,i=i+8|0,c[t>>2]=c[(c[l>>2]|0)+8>>2],t)|0);i=t;u=-1;i=b;return u|0}if((s|0)==0){break}k=a+28|0;e=0;h=s;while(1){m=c[(c[k>>2]|0)+(e<<2)>>2]|0;v=m+8|0;if((c[(c[v>>2]|0)+48>>2]|0)==8){w=h}else{q=c[d>>2]|0;p=m|0;n=c[f>>2]|0;o=n+208|0;x=c[o>>2]|0;y=c[o+4>>2]|0;YZ(n,q,1454912,0,(c[p>>2]|0)+2|-2147483648);rD(q,x,y);kD(q,1);kD(q,(c[p>>2]|0)+2|0);kD(q,1);cD(q,0,8);if(($Z(a,m)|0)<0){break}ZZ(a);_X(m,64,1,1e7);w=c[j>>2]|0}m=e+1|0;if(m>>>0<w>>>0){e=m;h=w}else{break a}}h=a;KIb(h,16,2551792,(t=i,i=i+8|0,c[t>>2]=c[(c[v>>2]|0)+8>>2],t)|0);i=t;KIb(h,16,2569736,(t=i,i=i+8|0,c[t>>2]=c[(c[v>>2]|0)+8>>2],t)|0);i=t;u=-1;i=b;return u|0}}while(0);if((c[g+472>>2]|0)==0){u=0;i=b;return u|0}_Z(a);u=0;i=b;return u|0}function RZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=a+16|0;e=c[d>>2]|0;f=a+12|0;g=c[f>>2]|0;h=b+32|0;i=a+28|0;do{if((c[(c[(c[(c[i>>2]|0)+(c[h>>2]<<2)>>2]|0)+8>>2]|0)+48>>2]|0)==8){if((c[g+540>>2]|0)!=0){break}S1(g+512|0,b)|0;return 0}}while(0);j=g+200|0;k=c[g+492>>2]|0;if((k|0)==0){l=0;m=0}else{n=(c[g+488>>2]|0)+(k-1<<4)|0;l=c[n+4>>2]|0;m=c[n>>2]|0}n=xrc(c[j>>2]|0,c[j+4>>2]|0,m,l)|0;l=G;m=0;if((l|0)>(m|0)|(l|0)==(m|0)&n>>>0>49>>>0){XZ(a)}a=b+8|0;n=c[a>>2]|0;m=c[a+4>>2]|0;do{if(!((n|0)==0&(m|0)==(-2147483648|0))){l=g+484|0;k=c[l>>2]|0;if((k|0)==0){o=0;p=0}else{q=(c[g+480>>2]|0)+(k-1<<4)+8|0;o=c[q+4>>2]|0;p=c[q>>2]|0}q=xrc(n,m,p,o)|0;r=G;s=0;do{if((r|0)>(s|0)|(r|0)==(s|0)&q>>>0>4999999>>>0){t=g+480|0;u=c[j>>2]|0;v=c[j+4>>2]|0;w=k+1|0;x=iJb(c[t>>2]|0,w<<4)|0;y=x;if((x|0)==0){break}x=c[l>>2]|0;z=y+(x<<4)|0;c[z>>2]=u;c[z+4>>2]=v;v=y+(x<<4)+8|0;c[v>>2]=n;c[v+4>>2]=m;c[t>>2]=y;c[l>>2]=w}}while(0);l=c[a>>2]|0;k=c[a+4>>2]|0;if((l|0)==0&(k|0)==(-2147483648|0)){break}q=g+496|0;s=c[q+4>>2]|0;if(!((k|0)>(s|0)|(k|0)==(s|0)&l>>>0>(c[q>>2]|0)>>>0)){break}c[q>>2]=l;c[q+4>>2]=k;k=c[j+4>>2]|0;q=g+504|0;c[q>>2]=c[j>>2];c[q+4>>2]=k}}while(0);g=c[f>>2]|0;m=c[d>>2]|0;n=c[h>>2]|0;o=c[(c[(c[i>>2]|0)+(n<<2)>>2]|0)+8>>2]|0;YZ(g,m,1278472,56,n+2|1073741824);cD(m,0,8);n=c[a>>2]|0;i=c[a+4>>2]|0;p=(n|0)==0&(i|0)==(-2147483648|0);rD(m,p?-1:n,p?-1:i);i=c[a>>2]|0;p=c[a+4>>2]|0;n=(i|0)==0&(p|0)==(-2147483648|0);rD(m,n?-1:i,n?-1:p);p=c[a>>2]|0;n=c[a+4>>2]|0;a=(p|0)==0&(n|0)==(-2147483648|0);rD(m,a?-1:p,a?-1:n);rD(m,0,0);if((c[o+8>>2]|0)==0){A=0;B=c[b+36>>2]&1}else{A=0;B=0}rD(m,B,A);rD(m,0,0);m=g+208|0;A=c[m+4>>2]|0;B=g+216|0;c[B>>2]=c[m>>2];c[B+4>>2]=A;A=b+28|0;YZ(c[f>>2]|0,c[d>>2]|0,1403072,c[A>>2]|0,(c[h>>2]|0)+2|0);dD(e,c[b+24>>2]|0,c[A>>2]|0);b=c[A>>2]|0;cD(e,0,(b+7&-8)-b|0);b=wrc(c[j>>2]|0,c[j+4>>2]|0,1,0)|0;c[j>>2]=b;c[j+4>>2]=G;return 0}function SZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;g=d;if((TZ(a,2,c[g>>2]|0,c[g+4>>2]|0)|0)<0){h=-1;return h|0}g=fD(f,0,0,1)|0;i=G;j=c[b>>2]|0;k=c[e>>2]|0;l=j+492|0;if((c[l>>2]|0)>0){m=j+488|0;j=0;do{n=(c[m>>2]|0)+(j<<4)|0;rD(k,c[n>>2]|0,c[n+4>>2]|0);n=(c[m>>2]|0)+(j<<4)+8|0;rD(k,c[n>>2]|0,c[n+4>>2]|0);j=j+1|0;}while((j|0)<(c[l>>2]|0))}if((TZ(a,1,g,i)|0)<0){h=-1;return h|0}i=fD(f,0,0,1)|0;g=G;l=c[b>>2]|0;j=c[e>>2]|0;k=a+1140|0;cL(k,1431456,0);m=LGb(c[k>>2]|0,10230504,0,2)|0;if((m|0)!=0){n=m;do{m=c[n>>2]|0;o=c[n+4>>2]|0;p=((lrc(o|0)|0)<<1)+2|0;VS(j,1358456);kD(j,1);kD(j,p);nD(j,m)|0;nD(j,o)|0;n=LGb(c[k>>2]|0,10230504,n,2)|0;}while((n|0)!=0)}n=l+540|0;if((c[n>>2]|0)!=0){o=LGb(c[(c[(c[a+28>>2]|0)+(c[l+544>>2]<<2)>>2]|0)+88>>2]|0,2304160,0,0)|0;if((o|0)==0){m=(c[n>>2]|0)+29|0;VS(j,1358456);kD(j,2);kD(j,m);nD(j,2370448)|0;nD(j,2209488)|0;bD(j,16);q=10230504}else{m=o+4|0;o=((lrc(c[m>>2]|0)|0)<<1)+29|0;p=o+(c[n>>2]|0)|0;VS(j,1358456);kD(j,2);kD(j,p);nD(j,2370448)|0;nD(j,2209488)|0;bD(j,16);q=c[m>>2]|0}nD(j,q)|0;kD(j,c[n>>2]|0);dD(j,c[l+536>>2]|0,c[n>>2]|0);VS(j,1358456);kD(j,0);kD(j,4);nD(j,2252480)|0;kD(j,2)}if((TZ(a,4,i,g)|0)<0){h=-1;return h|0}g=fD(f,0,0,1)|0;i=G;j=c[b>>2]|0;n=c[e>>2]|0;l=LGb(c[k>>2]|0,10230504,0,2)|0;if((l|0)==0){r=0;s=0}else{q=0;m=0;p=l;while(1){rD(n,m,q);l=lrc(c[p>>2]|0)|0;o=wrc(((lrc(c[p+4>>2]|0)|0)+l<<1)+28|0,0,m,q)|0;l=G;t=LGb(c[k>>2]|0,10230504,p,2)|0;if((t|0)==0){r=l;s=o;break}else{q=l;m=o;p=t}}}p=j+540|0;if((c[p>>2]|0)!=0){m=c[(c[a+28>>2]|0)+(c[j+544>>2]<<2)>>2]|0;rD(n,s,r);j=LGb(c[m+88>>2]|0,2304160,0,0)|0;if((j|0)==0){u=75}else{u=((lrc(c[j+4>>2]|0)|0)<<1)+75|0}j=(c[p>>2]|0)+u|0;u=wrc(j,(j|0)<0|0?-1:0,s,r)|0;rD(n,u,G)}if((TZ(a,5,g,i)|0)<0){h=-1;return h|0}i=fD(f,0,0,1)|0;g=G;u=c[b>>2]|0;n=c[e>>2]|0;r=u+484|0;if((c[r>>2]|0)>0){s=u+480|0;j=0;do{p=(c[s>>2]|0)+(j<<4)+8|0;rD(n,c[p>>2]|0,c[p+4>>2]|0);p=(c[s>>2]|0)+(j<<4)|0;rD(n,c[p>>2]|0,c[p+4>>2]|0);j=j+1|0;}while((j|0)<(c[r>>2]|0))}r=u+496|0;rD(n,c[r>>2]|0,c[r+4>>2]|0);r=u+504|0;rD(n,c[r>>2]|0,c[r+4>>2]|0);if((TZ(a,7,i,g)|0)<0){h=-1;return h|0}g=fD(f,0,0,1)|0;i=G;a=c[e>>2]|0;e=(c[b>>2]|0)+8|0;b=109960;r=0;while(1){n=b+4|0;u=c[n>>2]|0;j=(u+7&-8)-u|0;u=c[b+8>>2]|0;VS(a,1402296);s=fD(a,0,0,1)|0;p=G;oD(a,j+48+(c[n>>2]|0)|0);cD(a,0,6);m=(u|0)!=0;if(m){v=0;w=0}else{q=e+(r*24|0)|0;v=c[q+4>>2]|0;w=c[q>>2]|0}rD(a,w,v);kD(a,(c[n>>2]|0)+j>>1);cD(a,0,4);dD(a,c[b>>2]|0,c[n>>2]|0);cD(a,0,j);if(m){m=ve[u&4095](a)|0;fD(a,s,p,0)|0;p=j+40+m+(c[n>>2]|0)|0;rD(a,p,(p|0)<0|0?-1:0);rD(a,m|0,((m|0)<0|0?-1:0)|1342177280);p=j+8+m+(c[n>>2]|0)|0;fD(a,p,(p|0)<0|0?-1:0,1)|0;}else{kD(a,c[e+(r*24|0)+16>>2]|0);kD(a,c[e+(r*24|0)+12>>2]|0)}p=r+1|0;if(p>>>0<8>>>0){b=b+12|0;r=p}else{break}}r=fD(a,0,0,1)|0;b=xrc(r,G,g,i)|0;r=b;cD(a,0,4096-r|0);a=fD(f,0,0,1)|0;b=G;fD(f,48,0,0)|0;kD(f,r);fD(f,4,0,1)|0;kD(f,g>>>12|i<<20);fD(f,92,0,0)|0;kD(f,a>>>12|b<<20);eD(f);kJb(c[d+488>>2]|0);kJb(c[d+480>>2]|0);P1(d+512|0);h=0;return h|0}function TZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;g=a+16|0;h=c[g>>2]|0;j=(c[a+12>>2]|0)+8|0;k=fD(h,0,0,1)|0;l=G;if(!(b>>>0<8>>>0)){KIb(0,0,2176872,(m=i,i=i+24|0,c[m>>2]=2148840,c[m+8>>2]=2124816,c[m+16>>2]=725,m)|0);i=m;Hd();return 0}n=xrc(k,l,d,e)|0;l=G;k=j+(b*24|0)|0;c[k>>2]=n;c[k+4>>2]=l;o=0;do{if((l|0)<(o|0)|(l|0)==(o|0)&n>>>0<4097>>>0){c[j+(b*24|0)+12>>2]=0;p=12;q=0}else{r=0;if((l|0)<(r|0)|(l|0)==(r|0)&n>>>0<4194305>>>0){c[j+(b*24|0)+12>>2]=1;p=12;q=1;break}r=0;if((l|0)<(r|0)|(l|0)==(r|0)&n>>>0<268435457>>>0){c[j+(b*24|0)+12>>2]=1;p=18;q=1;break}r=1;if((l|0)<(r|0)|(l|0)==(r|0)&n>>>0<1>>>0){c[j+(b*24|0)+12>>2]=2;p=12;q=2;break}r=64;if((l|0)<(r|0)|(l|0)==(r|0)&n>>>0<1>>>0){c[j+(b*24|0)+12>>2]=2;p=18;q=2;break}KIb(a,16,2642968,(m=i,i=i+16|0,c[m>>2]=n,c[m+8>>2]=l,m)|0);i=m;s=-1;i=f;return s|0}}while(0);m=Arc(n|0,l|0,p|0)|0;a=m;m=1<<p;o=m;r=(m|0)<0|0?-1:0;m=Drc(n,l,o,r)|0;l=xrc(o,r,m,G)|0;m=l;if((m|0)==0){t=a;u=q}else{cD(h,0,m);t=a+1|0;u=c[j+(b*24|0)+12>>2]|0}a=d>>>12|e<<20;if((u|0)>0){e=p-12|0;d=fD(c[g>>2]|0,0,0,1)|0;m=G;h=c[g>>2]|0;q=a;if((t|0)>0){l=0;do{kD(h,(l<<e)+q|0);l=l+1|0;}while((l|0)<(t|0))}l=t<<2;cD(h,0,4096-((l|0)%4096|0)|0);h=d>>>12|m<<20;if((u|0)==2){u=(l+4095|0)/4096|0;m=fD(c[g>>2]|0,0,0,1)|0;d=G;t=c[g>>2]|0;if((l|0)>0){l=0;do{kD(t,l+h|0);l=l+1|0;}while((l|0)<(u|0))}cD(t,0,4096-((u<<2|0)%4096|0)|0);v=m>>>12|d<<20}else{v=h}c[j+(b*24|0)+16>>2]=v}else{c[j+(b*24|0)+16>>2]=a}a=(p|0)==12;p=c[k+4>>2]|(a?-1879048192:268435456);c[k>>2]=c[k>>2]|(a?0:0);c[k+4>>2]=p;s=0;i=f;return s|0}function UZ(a){a=a|0;kD(a,16);cD(a,0,84);rD(a,50,0);return 96}function VZ(a){a=a|0;kD(a,-1);cD(a,0,12);dD(a,1012432,26);cD(a,0,6);cD(a,0,32);return 80}function WZ(a){a=a|0;kD(a,16);cD(a,0,76);rD(a,64,0);return 88}function XZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[a+16>>2]|0;d=c[a+12>>2]|0;e=d+208|0;f=c[e>>2]|0;g=c[e+4>>2]|0;h=fD(b,0,0,1)|0;i=d;j=xrc(h,G,c[i>>2]|0,c[i+4>>2]|0)|0;c[e>>2]=j;c[e+4>>2]=G;VS(b,1297704);kD(b,56);kD(b,0);j=d+200|0;rD(b,c[j>>2]|0,c[j+4>>2]|0);i=d+224|0;rD(b,c[i>>2]|0,c[i+4>>2]|0);i=d+216|0;rD(b,c[i>>2]|0,c[i+4>>2]|0);rD(b,0,0);ZZ(a);a=d+488|0;b=d+492|0;d=c[j>>2]|0;i=c[j+4>>2]|0;j=c[e>>2]|0;h=c[e+4>>2]|0;k=(c[b>>2]|0)+1|0;l=iJb(c[a>>2]|0,k<<4)|0;m=l;if((l|0)==0){n=e|0;c[n>>2]=f;o=e+4|0;c[o>>2]=g;return}l=c[b>>2]|0;p=m+(l<<4)|0;c[p>>2]=d;c[p+4>>2]=i;i=m+(l<<4)+8|0;c[i>>2]=j;c[i+4>>2]=h;c[a>>2]=m;c[b>>2]=k;n=e|0;c[n>>2]=f;o=e+4|0;c[o>>2]=g;return}function YZ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=fD(b,0,0,1)|0;j=a;k=xrc(h,G,c[j>>2]|0,c[j+4>>2]|0)|0;j=a+208|0;c[j>>2]=k;c[j+4>>2]=G;VS(b,d);kD(b,e+32|0);kD(b,f);e=a+200|0;rD(b,c[e>>2]|0,c[e+4>>2]|0);if((f|0)>-1|(d|0)==1370952){i=g;return}b=a+232|0;k=a+472|0;a=c[k>>2]|0;if((a|0)>=10){KIb(0,0,2176872,(h=i,i=i+24|0,c[h>>2]=2619624,c[h+8>>2]=2124816,c[h+16>>2]=148,h)|0);i=h;Hd()}h=c[j+4>>2]|0;l=b+(a*24|0)|0;c[l>>2]=c[j>>2];c[l+4>>2]=h;h=c[e+4>>2]|0;l=b+(a*24|0)+8|0;c[l>>2]=c[e>>2];c[l+4>>2]=h;c[b+(a*24|0)+16>>2]=d;c[b+(a*24|0)+20>>2]=f&1073741823;c[k>>2]=(c[k>>2]|0)+1;i=g;return}function ZZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=fD(d,0,0,1)|0;f=b+208|0;g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;g=xrc(e,G,c[f>>2]|0,c[f+4>>2]|0)|0;f=xrc(g,G,h,i)|0;i=G;h=xrc(16,0,f,i)|0;fD(d,h,G,1)|0;kD(d,f);h=wrc(f,i,-20,-1)|0;fD(d,h,G,1)|0;h=wrc(f,i,7,0)|0;g=xrc(h&-8,G&0,f,i)|0;cD(d,0,g);g=b+200|0;d=wrc(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=d;c[g+4>>2]=G;if((c[b+472>>2]|0)!=10){return}_Z(a);return}function _Z(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+16|0;d=c[b>>2]|0;e=a+12|0;a=c[e>>2]|0;f=a+208|0;g=c[f>>2]|0;h=c[f+4>>2]|0;i=fD(d,0,0,1)|0;j=a;k=xrc(i,G,c[j>>2]|0,c[j+4>>2]|0)|0;c[f>>2]=k;c[f+4>>2]=G;VS(d,1370952);kD(d,32);kD(d,-2147483648);k=a+200|0;rD(d,c[k>>2]|0,c[k+4>>2]|0);rD(d,g,h);kD(d,0);kD(d,0);h=a+472|0;if((c[h>>2]|0)>0){g=a+232|0;k=0;do{VS(d,c[g+(k*24|0)+16>>2]|0);j=g+(k*24|0)|0;rD(d,c[j>>2]|0,c[j+4>>2]|0);kD(d,c[g+(k*24|0)+20>>2]|0);kD(d,0);j=g+(k*24|0)+8|0;rD(d,c[j>>2]|0,c[j+4>>2]|0);k=k+1|0;}while((k|0)<(c[h>>2]|0))}c[h>>2]=0;h=c[e>>2]|0;e=c[b>>2]|0;b=fD(e,0,0,1)|0;k=h+208|0;d=h;g=c[d>>2]|0;j=c[d+4>>2]|0;d=xrc(b,G,c[k>>2]|0,c[k+4>>2]|0)|0;k=xrc(d,G,g,j)|0;j=G;g=xrc(16,0,k,j)|0;fD(e,g,G,1)|0;kD(e,k);g=wrc(k,j,-20,-1)|0;fD(e,g,G,1)|0;g=wrc(k,j,7,0)|0;d=xrc(g&-8,G&0,k,j)|0;cD(e,0,d);d=h+200|0;h=wrc(c[d>>2]|0,c[d+4>>2]|0,1,0)|0;c[d>>2]=h;c[d+4>>2]=G;d=a+224|0;if(!((c[d>>2]|0)==0&(c[d+4>>2]|0)==0)){return}a=c[f+4>>2]|0;c[d>>2]=c[f>>2];c[d+4>>2]=a;return}function $Z(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0;e=i;i=i+48|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=c[b+16>>2]|0;m=d+8|0;n=c[m>>2]|0;o=c[n+8>>2]|0;if((o|0)==1){p=WS(c[n+48>>2]|0,1406904)|0;q=1358488;r=1406408;s=1386968}else if((o|0)==0){t=WS(c[n+48>>2]|0,1256008)|0;p=t;q=1358472;r=1409152;s=(c[(c[m>>2]|0)+48>>2]|0)==2?1387016:1386984}else{KIb(b,16,2533560,(u=i,i=i+8|0,c[u>>2]=o,u)|0);i=u;v=-1;i=e;return v|0}VS(l,q);VS(l,1358504);cD(l,0,12);VS(l,1387032);kD(l,0);q=fD(l,0,0,1)|0;o=G;t=c[m>>2]|0;do{if((c[t+8>>2]|0)==0){c[g>>2]=c[t+120>>2];c[g+4>>2]=c[t+124>>2];yKb(f,d+80|0,g);n=c[f>>2]|0;w=c[f+4>>2]|0;xKb(h,j,n,(n|0)<0|0?-1:0,w,(w|0)<0|0?-1:0,-1,0)|0;kD(l,0);kD(l,0);kD(l,c[(c[m>>2]|0)+120>>2]|0);kD(l,c[(c[m>>2]|0)+124>>2]|0);kD(l,0);kD(l,0);kD(l,0);kD(l,0);kD(l,c[(c[m>>2]|0)+72>>2]|0);kD(l,0);w=c[d+92>>2]|0;do{if((w|0)==0){x=0;y=0}else{n=c[d+96>>2]|0;if((n|0)==0){x=0;y=0;break}z=1.0e7/(+(w|0)/+(n|0));x=(F=+z,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);y=~~+z>>>0}}while(0);rD(l,y,x);kD(l,0);kD(l,0);kD(l,c[h>>2]|0);kD(l,c[j>>2]|0);kD(l,0);kD(l,0);XS(l,c[m>>2]|0,1409152,0,1);if((c[(c[m>>2]|0)+48>>2]|0)!=2){A=s;break}kD(l,0);kD(l,c[(c[m>>2]|0)+100>>2]|0);kD(l,-1);kD(l,-1);kD(l,0);w=c[m>>2]|0;dD(l,c[w+96>>2]|0,c[w+100>>2]|0);rD(l,0,0);A=s}else{w=(US(l,t)|0)<0;A=w?1387e3:s}}while(0);s=fD(l,0,0,1)|0;t=xrc(s,G,q,o)|0;o=t;t=-4-o|0;fD(l,t,(t|0)<0|0?-1:0,1)|0;kD(l,o+32|0);fD(l,o,(o|0)<0|0?-1:0,1)|0;do{if((p|0)==0){o=IX(r,c[(c[m>>2]|0)+48>>2]|0)|0;if((o|0)!=0){kD(l,o);o=k|0;a[o]=0;a[k+1|0]=0;a[k+2|0]=16;a[k+3|0]=0;a[k+4|0]=-128;a[k+5|0]=0;a[k+6|0]=0;a[k+7|0]=-86;a[k+8|0]=0;a[k+9|0]=56;a[k+10|0]=-101;a[k+11|0]=113;dD(l,o,12);break}KIb(b,16,2518184,(u=i,i=i+8|0,c[u>>2]=c[(c[m>>2]|0)+48>>2],u)|0);i=u;v=-1;i=e;return v|0}else{VS(l,p)}}while(0);VS(l,A);v=0;i=e;return v|0}function a_(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0;mrc(a|0,0,36)|0;f=e;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=1802532471){g=-1094995529;return g|0}f=e+4|0;h=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a|0;c[f>>2]=h;i=h-24|0;if(i>>>0>1048552>>>0){g=-1094995529;return g|0}c[f>>2]=i;i=e+8|0;b[a+4>>1]=(d[i]|d[i+1|0]<<8)<<16>>16;i=e+12|0;c[a+8>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=e+16|0;c[a+12>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=e+20|0;c[a+16>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=e+24|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+20>>2]=f;i=e+28|0;c[a+24>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[a+28>>2]=f>>>11&1;c[a+32>>2]=f>>>12&1;g=0;return g|0}function b_(a){a=a|0;var b=0,e=0,f=0;if((c[a+8>>2]|0)<33){b=0;return b|0}e=c[a+4>>2]|0;a=e;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1802532471){f=e+4|0;if(!(((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24)-24|0)>>>0<1048553>>>0)){break}f=e+8|0;if((((d[f]|d[f+1|0]<<8)<<16>>16)-1026&65535)>>>0<15>>>0){b=100}else{break}return b|0}}while(0);b=0;return b|0}function c_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+16|0;d=c[b>>2]|0;e=c[a+12>>2]|0;c[e+88>>2]=0;f=f_(a,d)|0;if((f|0)<0){g=f;return g|0}f=e+48|0;h=e+32|0;while(1){if((c[f>>2]|0)!=0){break}hD(d,c[h>>2]|0,0)|0;i=f_(a,d)|0;if((i|0)<0){g=i;j=12;break}}if((j|0)==12){return g|0}j=ZX(a,0)|0;if((j|0)==0){g=-12;return g|0}d=c[j+8>>2]|0;c[d+8>>2]=1;c[d+48>>2]=86041;c[d+416>>2]=c[e+72>>2];h=d+448|0;c[h>>2]=c[e+80>>2];c[h+4>>2]=0;h=e+68|0;c[d+412>>2]=c[h>>2];c[d+792>>2]=c[e+76>>2];_X(j,64,1,c[h>>2]|0);h=j+48|0;c[h>>2]=0;c[h+4>>2]=0;h=c[e+40>>2]|0;if(!((h|0)==-1)){d=j+56|0;c[d>>2]=h;c[d+4>>2]=0}d=c[b>>2]|0;if((c[d+88>>2]|0)==0){g=0;return g|0}h=fD(d,0,0,1)|0;d=G;j=HB(a)|0;f=e+104|0;c[f>>2]=j;c[f+4>>2]=G;if((LGb(c[a+1140>>2]|0,10230712,0,2)|0)==0){A$(a)}fD(c[b>>2]|0,h,d,0)|0;g=0;return g|0}function d_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=c[a+12>>2]|0;f=a+16|0;if((jD(c[f>>2]|0)|0)!=0){g=-541478725;i=d;return g|0}h=e+88|0;do{if((c[h>>2]|0)!=0){j=f_(a,c[f>>2]|0)|0;if((j|0)<0){g=j}else{break}i=d;return g|0}}while(0);j=e+96|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=e+32|0;if((K1(b,(c[j>>2]|0)+32|0)|0)<0){g=-12;i=d;return g|0}m=b+24|0;nrc(c[m>>2]|0,e|0,32)|0;n=AD(c[f>>2]|0,(c[m>>2]|0)+32|0,c[j>>2]|0)|0;if((n|0)!=(c[j>>2]|0)){P1(b);g=-5;i=d;return g|0}n=e+52|0;o=b+28|0;while(1){if((c[n>>2]&4096|0)!=0){p=15;break}q=f_(a,c[f>>2]|0)|0;if((q|0)<0){p=10;break}r=c[o>>2]|0;s=N1(b,(c[j>>2]|0)+32|0)|0;if((s|0)<0){p=12;break}nrc((c[m>>2]|0)+r|0,e|0,32)|0;t=AD(c[f>>2]|0,(c[m>>2]|0)+(r+32)|0,c[j>>2]|0)|0;if((t|0)!=(c[j>>2]|0)){p=14;break}}if((p|0)==10){P1(b);g=q;i=d;return g|0}else if((p|0)==12){P1(b);g=s;i=d;return g|0}else if((p|0)==14){P1(b);g=(t|0)<0?t:-541478725;i=d;return g|0}else if((p|0)==15){c[b+32>>2]=0;c[h>>2]=1;h=c[e+44>>2]|0;p=0;t=b+8|0;c[t>>2]=h;c[t+4>>2]=p;s=c[e+48>>2]|0;if((s|0)<0){KIb(a,24,2461192,(e=i,i=i+8|0,c[e>>2]=s,e)|0);i=e;u=c[t+4>>2]|0;v=c[t>>2]|0}else{c[b+48>>2]=s;u=p;v=h}xX(c[c[a+28>>2]>>2]|0,k,l,v,u,0,0,1)|0;g=0;i=d;return g|0}return 0}function e_(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+80|0;h=g|0;j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[a+12>>2]|0;k=CX(j,d,e,f)|0;do{if((k|0)>-1){f=c[j+400>>2]|0;l=f+(((c[j+404>>2]|0)-1|0)*24|0)+8|0;m=c[l+4>>2]|0;if((m|0)<(e|0)|(m|0)==(e|0)&(c[l>>2]|0)>>>0<d>>>0){break}c[b+88>>2]=1;l=f+(k*24|0)|0;fD(c[a+16>>2]|0,c[l>>2]|0,c[l+4>>2]|0,0)|0;n=0;i=g;return n|0}}while(0);k=0;if((e|0)<(k|0)|(e|0)==(k|0)&d>>>0<0>>>0){n=-22;i=g;return n|0}k=a+1064|0;b=c[k+4>>2]|0;if(!((b|0)>(e|0)|(b|0)==(e|0)&(c[k>>2]|0)>>>0>d>>>0)){n=-22;i=g;return n|0}k=a+16|0;b=fD(c[k>>2]|0,0,0,1)|0;j=G;l=h+8|0;while(1){o=uX(a,h)|0;if((o|0)<0){break}f=c[l>>2]|0;m=c[l+4>>2]|0;P1(h);if(!((m|0)<(e|0)|(m|0)==(e|0)&f>>>0<d>>>0)){n=0;p=10;break}}if((p|0)==10){i=g;return n|0}fD(c[k>>2]|0,b,j,0)|0;n=o;i=g;return n|0}function f_(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;f=c[a+12>>2]|0;g=fD(d,0,0,1)|0;h=G;j=f+96|0;c[j>>2]=g;c[j+4>>2]=h;j=f+104|0;k=c[j>>2]|0;l=c[j+4>>2]|0;if(!((k|0)==0&(l|0)==0|((h|0)<(l|0)|(h|0)==(l|0)&g>>>0<k>>>0))){m=-541478725;i=e;return m|0}k=AD(d,f,32)|0;if((k|0)!=32){m=(k|0)<0?k:-541478725;i=e;return m|0}k=f+32|0;g=a_(k,f)|0;if((g|0)<0){KIb(a,16,2370408,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=g;i=e;return m|0}g=b[f+36>>1]|0;if((g-1026&65535)>>>0>14>>>0){KIb(a,16,2304096,(n=i,i=i+8|0,c[n>>2]=g&65535,n)|0);i=n;m=-1163346256;i=e;return m|0}if((c[f+48>>2]|0)==0){m=0;i=e;return m|0}g=c[f+52>>2]|0;l=(g<<3&24)+8|0;h=g>>>2&1;j=g>>>23&15;o=c[109880+(j<<2)>>2]|0;if((c[f+60>>2]|0)==0){p=f+84|0;c[p>>2]=1;q=p;r=12}else{p=(c[f+64>>2]|0)==0;s=f+84|0;c[s>>2]=p&1;if(p){q=s;r=12}else{t=h+3|0;u=2-h|0;v=s}}if((r|0)==12){t=c[f+80>>2]|0;u=c[f+72>>2]|0;v=q}do{if((j|0)==15|(u|0)==0){if((c[f+88>>2]|0)!=0){w=o;x=t;y=u;break}q=fD(d,0,0,1)|0;s=k;h=wrc(c[s>>2]|0,0,q,G)|0;q=G;if((c[d+88>>2]|0)==0){KIb(a,16,2252416,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=e;return m|0}p=fD(d,0,0,1)|0;z=G;a:do{if((z|0)<(q|0)|(z|0)==(q|0)&p>>>0<h>>>0){A=u;B=t;C=o;b:while(1){D=zD(d)|0;if((D&128|0)==0){E=zD(d)|0}else{E=ED(d)|0}F=(D&64|0)!=0;H=(E<<1)+(F<<31>>31)|0;I=D&63;c:do{if((I|0)==39){J=ED(d)|0;K=B;L=A}else if((I|0)==13){if((H|0)<2){r=23;break b}D=zD(d)|0;switch(H|0){case 2:{J=C;K=zD(d)|0;L=D;break c;break};case 5:{J=C;K=FD(d)|0;L=D;break c;break};case 7:{hD(d,1,0)|0;M=(zD(d)|0)<<8&3840|D;J=C;K=ED(d)|0;L=M;break c;break};case 3:{J=C;K=DD(d)|0;L=D;break c;break};case 4:{J=C;K=ED(d)|0;L=D;break c;break};default:{r=30;break b}}}else{hD(d,H,(H|0)<0|0?-1:0)|0;J=C;K=B;L=A}}while(0);if(F){hD(d,1,0)|0;}I=fD(d,0,0,1)|0;D=G;if((D|0)<(q|0)|(D|0)==(q|0)&I>>>0<h>>>0){A=L;B=K;C=J}else{N=L;O=K;P=J;break a}}if((r|0)==23){KIb(a,16,2209448,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=e;return m|0}else if((r|0)==30){KIb(a,16,2176840,(n=i,i=i+8|0,c[n>>2]=H,n)|0);i=n;m=-1094995529;i=e;return m|0}}else{N=u;O=t;P=o}}while(0);if(!((P|0)==-1)){p=xrc(h,q,c[s>>2]|0,0)|0;fD(d,p,G,0)|0;w=P;x=O;y=N;break}KIb(a,16,2148800,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=e;return m|0}else{w=o;x=t;y=u}}while(0);u=f+76|0;t=c[u>>2]|0;if((t|0)==0){c[u>>2]=l;Q=l}else{Q=t}t=f+72|0;u=c[t>>2]|0;if((u|0)==0){c[t>>2]=y;R=y}else{R=u}u=f+80|0;if((c[u>>2]|0)==0){c[u>>2]=x}x=f+68|0;f=c[x>>2]|0;if((f|0)==0){c[x>>2]=w;S=w}else{S=f}if((g|0)==0){m=0;i=e;return m|0}if((l|0)!=(Q|0)){KIb(a,16,2124752,(n=i,i=i+16|0,c[n>>2]=l,c[n+8>>2]=Q,n)|0);i=n;m=-1094995529;i=e;return m|0}if(!((c[v>>2]|0)!=0|(y|0)==(R|0))){KIb(a,16,2642912,(n=i,i=i+16|0,c[n>>2]=y,c[n+8>>2]=R,n)|0);i=n;m=-1094995529;i=e;return m|0}if((w|0)==-1|(w|0)==(S|0)){m=0;i=e;return m|0}KIb(a,16,2619568,(n=i,i=i+16|0,c[n>>2]=w,c[n+8>>2]=S,n)|0);i=n;m=-1094995529;i=e;return m|0}function g_(a){a=a|0;var b=0,d=0;b=i;do{if(!((c[a+24>>2]|0)>>>0>1>>>0)){if((c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+48>>2]|0)==86041){d=0}else{break}i=b;return d|0}}while(0);KIb(a,16,2303928,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;d=-22;i=b;return d|0}function h_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+40|0;e=d|0;f=c[a+12>>2]|0;g=b+28|0;do{if((c[g>>2]|0)>=32){h=b+24|0;if((a_(e,c[h>>2]|0)|0)<0){break}j=f;k=wrc(c[j>>2]|0,c[j+4>>2]|0,c[e+16>>2]|0,0)|0;c[j>>2]=k;c[j+4>>2]=G;dD(c[a+16>>2]|0,c[h>>2]|0,c[g>>2]|0);l=0;i=d;return l|0}}while(0);KIb(a,16,2370296,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;l=-22;i=d;return l|0}function i_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a+16|0;d=c[b>>2]|0;if((c[d+88>>2]|0)==0){e=IB(a)|0;return 0}f=c[a+12>>2]|0;g=c[f>>2]|0;h=c[f+4>>2]|0;i=0;if(!(((g|0)!=0|(h|0)!=0)&((h|0)<(i|0)|(h|0)==(i|0)&g>>>0<-1>>>0))){e=IB(a)|0;return 0}g=fD(d,0,0,1)|0;d=G;fD(c[b>>2]|0,12,0,0)|0;kD(c[b>>2]|0,c[f>>2]|0);fD(c[b>>2]|0,g,d,0)|0;e=IB(a)|0;return 0}function j_(a){a=a|0;var b=0,e=0,f=0;if((c[a+8>>2]|0)<24){return 0}b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((e|0)==16728|(e|0)==4800856|(e|0)==4866392)){return 0}e=b+10|0;a=(d[e]|d[e+1|0]<<8)<<16>>16;e=b+12|0;f=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+22|0;if(a<<16>>16==0|(a&65535)>>>0>8>>>0){return 0}if((f|0)==0|(f|0)>192e3){return 0}else{return((((d[e]|d[e+1|0]<<8)<<16>>16)-4&65535)>>>0>28>>>0?0:50)|0}return 0}function k_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=ZX(a,0)|0;if((e|0)==0){f=-12;return f|0}a=e+8|0;g=c[a>>2]|0;c[g+8>>2]=1;c[g+48>>2]=69658;hD(d,4,0)|0;c[b>>2]=FD(d)|0;hD(d,2,0)|0;b=DD(d)|0;c[(c[a>>2]|0)+416>>2]=b;b=FD(d)|0;c[(c[a>>2]|0)+412>>2]=b;hD(d,4,0)|0;hD(d,2,0)|0;hD(d,2,0)|0;d=c[a>>2]|0;a=c[d+416>>2]|0;if((a|0)==0){f=-1094995529;return f|0}b=c[d+412>>2]|0;if((b|0)==0){f=-1094995529;return f|0}g=Erc(a,(a|0)<0|0?-1:0,120,0)|0;a=Erc(g,G,b,(b|0)<0|0?-1:0)|0;g=Crc(a,G,28,0)|0;a=g;c[d+72>>2]=(a|0)<0?0:a;_X(e,64,1,b);b=e+48|0;c[b>>2]=0;c[b+4>>2]=0;f=0;return f|0}function l_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=c[c[a+28>>2]>>2]|0;f=d+4|0;if(!((c[f>>2]|0)>>>0<(c[d>>2]|0)>>>0)){g=-541478725;return g|0}d=(c[(c[e+8>>2]|0)+416>>2]|0)*15|0;h=fX(c[a+16>>2]|0,b,d)|0;if((h|0)<0){g=h;return g|0}c[b+32>>2]=c[e>>2];c[f>>2]=(c[f>>2]|0)+d;c[b+48>>2]=28;g=h;return g|0}function m_(a){a=a|0;var b=0,e=0,f=0;if((c[a+8>>2]|0)<36){b=0;return b|0}e=c[a+4>>2]|0;a=e+16|0;f=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((f|0)==0|f>>>0>4>>>0){b=0;return b|0}f=(grc(e+12|0,2148744,4)|0)==0;b=f?100:0;return b|0}function n_(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;f=a+12|0;g=c[f>>2]|0;h=c[a+16>>2]|0;hD(h,4,0)|0;j=FD(h)|0;hD(h,4,0)|0;hD(h,4,0)|0;k=FD(h)|0;if(!((k|0)==4|(k|0)==2)){QIb(a,2252360,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l}k=ZX(a,0)|0;if((k|0)==0){m=-12;i=d;return m|0}_X(k,32,1,1e3);n=k+8|0;o=c[n>>2]|0;c[o+8>>2]=0;c[o+48>>2]=19;c[o+52>>2]=1464686130;o=FD(h)|0;c[(c[n>>2]|0)+120>>2]=o;o=FD(h)|0;c[(c[n>>2]|0)+124>>2]=o;o=k+56|0;c[o>>2]=FD(h)|0;c[o+4>>2]=0;c[g+40>>2]=c[k>>2];k=g;b[k>>1]=DD(h)|0;hD(h,2,0)|0;n=hJb(e[k>>1]<<6)|0;p=n;q=g+88|0;c[q>>2]=p;a:do{if((n|0)==0){r=-12}else{b:do{if((b[k>>1]|0)!=0){s=a;t=1;u=0;v=p;while(1){w=v+(u<<6)+4|0;b[w>>1]=DD(h)|0;x=v+(u<<6)+6|0;b[x>>1]=DD(h)|0;y=v+(u<<6)+8|0;c[y>>2]=FD(h)|0;z=v+(u<<6)+12|0;b[z>>1]=DD(h)|0;A=v+(u<<6)+20|0;b[A>>1]=DD(h)|0;B=e[z>>1]|0;C=ca(B,c[y>>2]|0)|0;D=e[x>>1]|0;E=v+(u<<6)+16|0;c[E>>2]=ca(C,D)|0;c[v+(u<<6)+24>>2]=D*36|0;D=v+(u<<6)+28|0;b[D>>1]=64;C=v+(u<<6)+32|0;c[C>>2]=PS(e[w>>1]|0,B)|0;B=v+(u<<6)|0;c[B>>2]=-1;c[v+(u<<6)+48>>2]=0;F=v+(u<<6)+56|0;c[F>>2]=0;c[F+4>>2]=0;F=e[A>>1]|0;if((F&7|0)!=0){KIb(s,24,2209352,(l=i,i=i+8|0,c[l>>2]=F,l)|0);i=l}F=b[x>>1]|0;if(F<<16>>16==0){break}if((c[y>>2]|0)==0|(F&65535)>>>0>1819>>>0){break}F=ZX(a,0)|0;if((F|0)==0){r=-12;break a}A=c[F+8>>2]|0;c[A+8>>2]=1;c[A+48>>2]=c[C>>2];c[A+52>>2]=e[w>>1]|0;w=e[x>>1]|0;c[A+416>>2]=w;c[A+412>>2]=c[y>>2];c[A+792>>2]=e[z>>1]|0;c[A+72>>2]=c[E>>2];c[A+432>>2]=w*36|0;_X(F,32,e[D>>1]|0,c[y>>2]|0);c[B>>2]=c[F>>2];B=c[o+4>>2]|0;y=F+56|0;c[y>>2]=c[o>>2];c[y+4>>2]=B;if(!((t&65535)>>>0<(e[k>>1]|0)>>>0)){break b}B=t&65535;t=t+1&65535;u=B;v=c[q>>2]|0}KIb(s,16,2176704,(l=i,i=i+8|0,c[l>>2]=u,l)|0);i=l;r=-1094995529;break a}}while(0);v=fD(h,0,0,1)|0;t=G;B=g+24|0;c[B>>2]=v;c[B+4>>2]=t;B=xrc(j,0,v,t)|0;c[g+8>>2]=B;b[g+34>>1]=(b[k>>1]|0)+1;m=0;i=d;return m|0}}while(0);mJb((c[f>>2]|0)+88|0);m=r;i=d;return m|0}function o_(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+8|0;j=h|0;k=f+12|0;l=c[k>>2]|0;m=l+56|0;if((c[m>>2]|0)==(c[l+60>>2]|0)){n=l+16|0;o=l+24|0;p=c[o>>2]|0;q=c[o+4>>2]|0;if((c[n>>2]|0)==(p|0)&(c[n+4>>2]|0)==(q|0)){r=-541478725;i=h;return r|0}s=f+16|0;t=c[s>>2]|0;c[n>>2]=p;c[n+4>>2]=q;u=fD(t,p,q,0)|0;if(!((u|0)==(c[n>>2]|0)&(G|0)==(c[n+4>>2]|0))){r=-5;i=h;return r|0}u=c[l+8>>2]|0;q=l+4|0;c[q>>2]=u;if(u>>>0<(((e[l>>1]|0)<<2)+12|0)>>>0){r=-5;i=h;return r|0}u=j;p=j|0;t=c[k>>2]|0;v=c[s>>2]|0;c[t+8>>2]=FD(v)|0;if((AD(v,u,8)|0)!=8){r=-5;i=h;return r|0}s=c[p>>2]&8388607;w=t+40|0;x=t+44|0;c[x>>2]=s;c[t+56>>2]=0;z=(c[p>>2]|0)>>>23&255;A=t+60|0;c[A>>2]=z;B=t+64|0;c[B>>2]=(d[j+3|0]|0)>>>7&255;j=t;C=b[j>>1]|0;c[x>>2]=s-((C&65535)<<2);s=t+32|0;b[s>>1]=0;if((z|0)==0){c[A>>2]=1;b[s>>1]=(e[t+34>>1]|0)>>>0>1>>>0|0}a:do{if(!(C<<16>>16==0)){s=t+88|0;z=0;D=0;while(1){E=c[s>>2]|0;if((AD(v,u,4)|0)!=4){r=-5;break}F=c[p>>2]&8388607;H=E+(D<<6)+36|0;c[H>>2]=F;if((F|0)!=0|z<<16>>16==0){I=F}else{F=c[(c[s>>2]|0)+(D-1<<6)+36>>2]|0;c[H>>2]=F;I=F}F=(I>>>0)/((c[A>>2]|0)>>>0)|0;c[E+(D<<6)+48>>2]=F-((F>>>0)%((c[E+(D<<6)+24>>2]|0)>>>0)|0);E=z+1&65535;if(!((E&65535)>>>0<(e[j>>1]|0)>>>0)){break a}z=E;D=E&65535}i=h;return r|0}}while(0);A=fD(v,0,0,1)|0;I=G;p=t+48|0;c[p>>2]=A;c[p+4>>2]=I;u=b[j>>1]|0;j=c[x>>2]|0;if(!(u<<16>>16==0)){C=wrc(j,0,A,I)|0;I=c[t+88>>2]|0;A=G;D=C;C=0;z=0;while(1){s=I+(z<<6)+40|0;c[s>>2]=D;c[s+4>>2]=A;s=wrc(c[I+(z<<6)+36>>2]|0,0,D,A)|0;E=C+1&65535;if((E&65535)>>>0<(u&65535)>>>0){A=G;D=s;C=E;z=E&65535}else{break}}}do{if((j|0)!=0){if((c[B>>2]|0)==0){break}z=FD(v)|0;C=je(z>>>1<<14&16384|z<<15&32768|z>>>2<<13&8192|z>>>3<<12&4096|z>>>4<<11&2048|z>>>5<<10&1024|z>>>6<<7&896|0)|0;z=t+68|0;y=C;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[x>>2]=(c[x>>2]|0)-4;D=wrc(c[p>>2]|0,c[p+4>>2]|0,4,0)|0;c[p>>2]=D;c[p+4>>2]=G;D=c[w>>2]|0;if(!((D|0)>-1)){break}if(!(D>>>0<(c[f+24>>2]|0)>>>0)){KIb(0,0,2461112,(A=i,i=i+24|0,c[A>>2]=2370256,c[A+8>>2]=2303904,c[A+16>>2]=381,A)|0);i=A;Hd();return 0}A=(c[(c[f+28>>2]|0)+(D<<2)>>2]|0)+8|0;D=c[A>>2]|0;if((c[D+100>>2]|0)<4){kJb(c[D+96>>2]|0);PX(c[A>>2]|0,4)|0;J=c[A>>2]|0;K=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0}else{J=D;K=C}C=c[J+96>>2]|0;y=K;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y}}while(0);K=wrc(c[q>>2]|0,0,c[n>>2]|0,c[n+4>>2]|0)|0;c[o>>2]=K;c[o+4>>2]=G}o=l+32|0;K=b[o>>1]|0;do{if(K<<16>>16==0){n=c[k>>2]|0;q=c[f+16>>2]|0;J=n+40|0;w=n+48|0;p=fD(q,c[w>>2]|0,c[w+4>>2]|0,0)|0;if(!((p|0)==(c[w>>2]|0)&(G|0)==(c[w+4>>2]|0))){r=-5;i=h;return r|0}p=FD(q)|0;x=p<<2&524284;t=x+4|0;v=p>>>17;p=x+8|0;x=n+44|0;if(p>>>0>(c[x>>2]|0)>>>0){r=-5;i=h;return r|0}B=fX(q,g,t)|0;if((B|0)!=(t|0)){if((B|0)==0){break}else{r=B}i=h;return r|0}B=g+24|0;q=c[B>>2]|0;j=q+t|0;t=q;do{q=t;y=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;t=t+4|0;}while(t>>>0<j>>>0);j=c[B>>2]|0;c[g+32>>2]=c[J>>2];t=v;q=0;C=n+80|0;D=wrc(c[C>>2]|0,c[C+4>>2]|0,t,q)|0;z=G;A=n+72|0;c[A>>2]=D;c[A+4>>2]=z;c[g+48>>2]=0;A=g+8|0;c[A>>2]=D;c[A+4>>2]=z;z=g+16|0;c[z>>2]=0;c[z+4>>2]=-2147483648;z=wrc(c[C>>2]|0,c[C+4>>2]|0,t,q)|0;c[C>>2]=z;c[C+4>>2]=G;c[g+36>>2]=(d[j]|0)>>>7&255^1;c[x>>2]=(c[x>>2]|0)-p;j=wrc(c[w>>2]|0,c[w+4>>2]|0,p,0)|0;c[w>>2]=j;c[w+4>>2]=G}else{j=(K&65535)-1|0;C=c[k>>2]|0;z=c[f+16>>2]|0;q=c[C+88>>2]|0;t=q+(j<<6)+40|0;A=fD(z,c[t>>2]|0,c[t+4>>2]|0,0)|0;if(!((A|0)==(c[t>>2]|0)&(G|0)==(c[t+4>>2]|0))){r=-5;i=h;return r|0}if(((c[C+56>>2]|0)+1|0)>>>0<(c[C+60>>2]|0)>>>0){C=c[q+(j<<6)+48>>2]|0;A=c[q+(j<<6)+36>>2]|0;L=C>>>0>A>>>0?A:C}else{L=c[q+(j<<6)+36>>2]|0}C=fX(z,g,L)|0;if((C|0)>=1){c[g+32>>2]=c[q+(j<<6)>>2];z=(L>>>0)/((c[q+(j<<6)+24>>2]|0)>>>0)|0;c[g+48>>2]=z;A=q+(j<<6)+56|0;D=c[A+4>>2]|0;u=g+8|0;c[u>>2]=c[A>>2];c[u+4>>2]=D;D=g+16|0;c[D>>2]=0;c[D+4>>2]=-2147483648;D=wrc(c[A>>2]|0,c[A+4>>2]|0,z,0)|0;c[A>>2]=D;c[A+4>>2]=G;A=q+(j<<6)+36|0;c[A>>2]=(c[A>>2]|0)-L;A=wrc(c[t>>2]|0,c[t+4>>2]|0,L,0)|0;c[t>>2]=A;c[t+4>>2]=G;break}if((C|0)==0){break}else{r=C}i=h;return r|0}}while(0);L=(b[o>>1]|0)+1&65535;b[o>>1]=L;if((L&65535)>>>0<(e[l+34>>1]|0)>>>0){r=0;i=h;return r|0}b[o>>1]=0;c[m>>2]=(c[m>>2]|0)+1;r=0;i=h;return r|0}function p_(a){a=a|0;mJb((c[a+12>>2]|0)+88|0);return 0}function q_(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;do{if((grc(b,2642888,4)|0)==0){if((grc(b+8|0,2619544,4)|0)==0){d=100}else{break}return d|0}}while(0);d=0;return d|0}function r_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;e=c[b+16>>2]|0;f=c[b+12>>2]|0;if((FD(e)|0)!=1179011410){g=-1;i=d;return g|0}FD(e)|0;if((FD(e)|0)!=1095587672){g=-1;i=d;return g|0}if((FD(e)|0)!=544501094){g=-1;i=d;return g|0}h=FD(e)|0;j=ZX(b,0)|0;if((j|0)==0){g=-12;i=d;return g|0}k=j+8|0;l=OS(e,c[k>>2]|0,h)|0;if((l|0)<0){g=l;i=d;return g|0}c[j+236>>2]=0;l=c[k>>2]|0;h=c[l+48>>2]|0;do{if((h|0)==86024){m=l+100|0;n=c[m>>2]|0;if((n|0)!=0){QIb(b,2370224,(o=i,i=i+8|0,c[o>>2]=n,o)|0);i=o;break}c[m>>2]=6;m=pJb(22)|0;c[(c[k>>2]|0)+96>>2]=m;m=c[(c[k>>2]|0)+96>>2]|0;if((m|0)==0){g=-12;i=d;return g|0}else{a[m+4|0]=31;break}}else{QIb(b,2461056,(o=i,i=i+16|0,c[o>>2]=c[l+52>>2],c[o+8>>2]=h,o)|0);i=o}}while(0);h=c[k>>2]|0;if((c[h+416>>2]|0)==0){KIb(b,24,2303872,(o=i,i=i+8|0,c[o>>2]=0,o)|0);i=o;g=-1094995529;i=d;return g|0}if((c[h+792>>2]|0)==0){KIb(b,24,2252320,(o=i,i=i+8|0,c[o>>2]=0,o)|0);i=o;g=-1094995529;i=d;return g|0}_X(j,64,1,c[h+412>>2]|0);h=e+52|0;if((c[h>>2]|0)!=0){g=-1;i=d;return g|0}l=b;b=0;m=0;while(1){n=FD(e)|0;p=FD(e)|0;q=p;r=0;if((n|0)==1935962212){if((b|0)!=0){s=20;break}if(!((q&3|0)==0&(r&0|0)==0)){KIb(l,24,2176656,(o=i,i=i+16|0,c[o>>2]=q,c[o+8>>2]=r,o)|0);i=o}t=p>>>2;if((t|0)==0|p>>>0>2147483643>>>0){s=24;break}u=hJb(t<<2)|0;v=u;if((u|0)==0){g=-12;s=41;break}u=t-1|0;w=u<<2|0>>>30;x=0<<2|u>>>30;u=0;do{c[v+(u<<2)>>2]=FD(e)|0;u=u+1|0;}while(u>>>0<t>>>0);u=wrc(q,r,-4,-1)|0;y=xrc(u,G,w,x)|0;z=G;A=y;B=t;C=v}else if((n|0)==1635017060){s=30;break}else{z=r;A=q;B=m;C=b}hD(e,A,z)|0;if((c[h>>2]|0)==0){b=C;m=B}else{g=-1;s=41;break}}if((s|0)==20){KIb(l,16,2209320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;g=-1;i=d;return g|0}else if((s|0)==24){KIb(l,16,2148712,(o=i,i=i+16|0,c[o>>2]=q,c[o+8>>2]=r,o)|0);i=o;g=-1;i=d;return g|0}else if((s|0)==30){if((p|0)==0){p=f;c[p>>2]=-1;c[p+4>>2]=2147483647}else{p=fD(e,0,0,1)|0;B=wrc(p,G,q,r)|0;p=f;c[p>>2]=B;c[p+4>>2]=G}p=c[k>>2]|0;do{if((b|0)==0|(m|0)==0){B=c[p+72>>2]|0;if((B|0)==0){break}f=c[p+412>>2]|0;C=Erc(q<<3|0>>>29,r<<3|q>>>29,f,(f|0)<0|0?-1:0)|0;f=Crc(C,G,B,(B|0)<0|0?-1:0)|0;B=j+56|0;c[B>>2]=f;c[B+4>>2]=G}else{B=c[p+416>>2]|0;f=c[p+792>>2]|0;C=(ca(f,B)|0)>>3;if((C|0)==0){KIb(l,16,2124616,(o=i,i=i+16|0,c[o>>2]=f,c[o+8>>2]=B,o)|0);i=o;g=-1094995529;i=d;return g|0}else{B=j+56|0;c[B>>2]=((c[b+(m-1<<2)>>2]|0)>>>0)/(C>>>0)|0;c[B+4>>2]=0;B=fD(e,0,0,1)|0;f=G;h=0;while(1){z=h+1|0;A=c[(c[k>>2]|0)+432>>2]|0;y=ca(A,z)|0;u=wrc(y,(y|0)<0|0?-1:0,B,f)|0;xX(j,u,G,((c[b+(h<<2)>>2]|0)>>>0)/(C>>>0)|0,0,A,0,1)|0;if(z>>>0<m>>>0){h=z}else{break}}}}}while(0);kJb(b);g=0;i=d;return g|0}else if((s|0)==41){i=d;return g|0}return 0}function s_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[c[a+28>>2]>>2]|0;e=c[a+12>>2]|0;f=c[e>>2]|0;g=c[e+4>>2]|0;e=a+16|0;a=fD(c[e>>2]|0,0,0,1)|0;h=xrc(f,g,a,G)|0;a=G;g=0;if((a|0)<(g|0)|(a|0)==(g|0)&h>>>0<1>>>0){i=-541478725;return i|0}g=c[(c[d+8>>2]|0)+432>>2]|0;d=(g|0)>1;f=d?g:2230;j=d?(g|0)<0|0?-1:0:0;g=(j|0)>(a|0)|(j|0)==(a|0)&f>>>0>h>>>0;g?a:j;j=fX(c[e>>2]|0,b,g?h:f)|0;if((j|0)<0){i=j;return i|0}c[b+32>>2]=0;i=j;return i|0}function t_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[b+4>>2]|0;b=e;do{if((d[b]|d[b+1|0]<<8)<<16>>16<<16>>16==20313){if(!((d[e+2|0]|0)>>>0<10>>>0)){break}if(!((d[e+3|0]|0)>>>0<10>>>0)){break}if((a[e+6|0]|0)==0){break}f=a[e+7|0]|0;if(f<<24>>24==0){break}if(!((a[e+8|0]&1)==0)){break}if(!((a[e+10|0]&1)==0)){break}g=e+18|0;h=(d[g]|d[g+1|0]<<8)<<16>>16;if(!((h&65535)>>>0>919>>>0)){break}if((h&65535|0)<(((f&255)<<11|4)+((d[e+12|0]|0)*3|0)|0)){i=75}else{break}return i|0}}while(0);i=0;return i|0}function u_(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=ZX(a,0)|0;h=ZX(a,0)|0;if((g|0)==0|(h|0)==0){j=-12;i=b;return j|0}k=h+8|0;if((PX(c[k>>2]|0,8)|0)!=0){j=-12;i=b;return j|0}l=c[g+8>>2]|0;c[l+8>>2]=1;c[l+48>>2]=69661;c[l+416>>2]=1;g=l+448|0;c[g>>2]=4;c[g+4>>2]=0;c[l+412>>2]=22050;l=c[k>>2]|0;c[l+8>>2]=0;c[l+48>>2]=140;hD(f,6,0)|0;k=zD(f)|0;g=e+84|0;c[g>>2]=(zD(f)|0)<<11;c[l+120>>2]=DD(f)|0;c[l+124>>2]=DD(f)|0;c[h+80>>2]=1;c[h+84>>2]=2;m=l+96|0;n=AD(f,c[m>>2]|0,8)|0;if((n|0)<8){j=(n|0)<0?n:-541478725;i=b;return j|0}n=c[m>>2]|0;m=e+92|0;c[m>>2]=((d[n]|0)*3|0)+4;o=n+6|0;n=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=e+88|0;c[o>>2]=n;c[l+72>>2]=ca(k<<3,(c[g>>2]|0)-n|0)|0;n=c[o>>2]|0;do{if((n|0)>=920){if(((c[m>>2]|0)+n|0)>=(c[g>>2]|0)){break}fD(f,2048,0,0)|0;_X(h,32,1,k);j=0;i=b;return j|0}}while(0);KIb(a,16,2460976,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-1094995529;i=b;return j|0}function v_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;b=e+88|0;g=(c[e+84>>2]|0)-(c[b>>2]|0)|0;h=e+92|0;i=g-(c[h>>2]|0)|0;j=e;c[e+32>>2]=1;k=e+24|0;if((c[k>>2]|0)!=0){nrc(d|0,e|0,80)|0;c[k>>2]=0;c[e>>2]=0;c[e+52>>2]=0;c[e+28>>2]=0;l=e+80|0;a[c[d+24>>2]|0]=c[l>>2];m=d+36|0;c[m>>2]=c[m>>2]|1;c[l>>2]=c[l>>2]^1;n=c[d+28>>2]|0;return n|0}l=K1(j,g)|0;if((l|0)<0){n=l;return n|0}l=fD(f,0,0,1)|0;g=e+64|0;c[g>>2]=l;c[g+4>>2]=G;l=AD(f,c[k>>2]|0,c[h>>2]|0)|0;do{if((l|0)<0){o=l}else{if((l|0)<(c[h>>2]|0)){o=-541478725;break}e=fX(f,d,920)|0;if((e|0)<0){o=e;break}m=c[g+4>>2]|0;p=d+64|0;c[p>>2]=c[g>>2];c[p+4>>2]=m;m=(c[b>>2]|0)-e|0;hD(f,m,(m|0)<0|0?-1:0)|0;m=AD(f,(c[k>>2]|0)+(c[h>>2]|0)|0,i)|0;if((m|0)<0){o=m;break}if((m|0)<(i|0)){M1(j,(c[h>>2]|0)+m|0)}n=c[b>>2]|0;return n|0}}while(0);P1(j);n=o;return n|0}function w_(a){a=a|0;P1(c[a+12>>2]|0);return 0}function x_(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[a+12>>2]|0;if((b|0)==0){g=-1;return g|0}b=a+1248|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a+16|0;a=iD(c[b>>2]|0)|0;j=c[f+84>>2]|0;k=j;l=(j|0)<0|0?-1:0;j=xrc(a,G,h,i)|0;a=xrc(j,G,k,l)|0;j=Crc(a,G,k,l)|0;a=j;j=a;m=(a|0)<0|0?-1:0;a=(m|0)>(e|0)|(m|0)==(e|0)&j>>>0>d>>>0;n=a?d:j;j=a?e:m;m=0;e=(j|0)<(m|0)|(j|0)==(m|0)&n>>>0<0>>>0;m=e?0:n;n=Erc(m,e?0:j,k,l)|0;l=wrc(n,G,h,i)|0;i=fD(c[b>>2]|0,l,G,0)|0;l=G;b=0;if((l|0)<(b|0)|(l|0)==(b|0)&i>>>0<0>>>0){g=-1;return g|0}P1(f);c[f+80>>2]=m&1;g=0;return g|0}function y_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+12>>2]|0;if((c[a+24>>2]|0)!=1){e=-5;i=b;return e|0}f=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[f+48>>2]|0)!=14){KIb(a,16,2142072,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;e=-1094995529;i=b;return e|0}h=c[f+140>>2]|0;a:do{switch(h|0){case 7:{KIb(a,24,2138320,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;break};case 70:case 80:case 76:case 72:case 74:case 78:case 302:case 306:case 310:case 304:case 308:case 312:case 54:case 56:case 58:{j=a;if(!((c[f+680>>2]|0)>-1)){KIb(j,24,2134624,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;break a}k=mKb(h)|0;KIb(j,16,2136616,(g=i,i=i+8|0,c[g>>2]=k,g)|0);i=g;e=-22;i=b;return e|0};case 8:case 32:case 0:case 4:case 5:{break};default:{KIb(a,16,2132776,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;e=-5;i=b;return e|0}}}while(0);c[d>>2]=1;e=0;i=b;return e|0}function z_(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+320|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+296|0;l=c[a+28>>2]|0;m=c[l+(c[b+32>>2]<<2)>>2]|0;n=c[a+16>>2]|0;o=c[a+12>>2]|0;p=c[b+24>>2]|0;b=p;q=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;r=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+8|0;s=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+32|0;t=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+36|0;u=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+40|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;do{if((c[o>>2]|0)!=0){c[o>>2]=0;b=e+32|0;v=c[l>>2]|0;w=v+8|0;x=c[w>>2]|0;y=c[x+120>>2]|0;z=c[x+124>>2]|0;A=c[x+108>>2]|0;B=c[x+104>>2]|0;xKb(f,g,A,(A|0)<0|0?-1:0,B,(B|0)<0|0?-1:0,2147483647,0)|0;B=c[v+80>>2]|0;A=c[v+84>>2]|0;v=(B|0)==0&(A|0)==1?0:A;A=c[w>>2]|0;w=c[A+804>>2]|0;do{if((w|0)==0){C=112}else{if((c[w+296>>2]|0)==0){C=112;break}C=(c[w+300>>2]|0)!=0?116:98}}while(0);w=c[A+408>>2]|0;if((w|0)==5){D=8}else if((w|0)==1){E=112}else if((w|0)==4|(w|0)==2){E=116}else{if((w|0)==3){D=8}else{E=C}}if((D|0)==8){E=98}a:do{switch(c[A+140>>2]|0){case 78:{F=2176616;break};case 7:{F=2211712;break};case 306:{F=2164272;break};case 302:{F=2168912;break};case 70:{F=2188288;break};case 8:{F=2216992;break};case 310:{F=2162216;break};case 80:{F=2185608;break};case 76:{F=2183352;break};case 74:{F=2178920;break};case 32:{F=2214208;break};case 5:{F=2190760;break};case 0:{w=c[A+400>>2]|0;if((w|0)==1){F=2200776;break a}else if((w|0)==3){F=2209256;break a}else{F=2195872;break a}break};case 312:{F=2156400;break};case 54:{F=2154920;break};case 56:{F=2152928;break};case 58:{F=2150600;break};case 304:{F=2160128;break};case 308:{F=2158304;break};case 72:{F=2181224;break};case 4:{F=2193296;break};default:{F=10230152}}}while(0);A=c[f>>2]|0;w=c[g>>2]|0;x=Rb(b|0,256,2148672,(G=i,i=i+72|0,c[G>>2]=2303832,c[G+8>>2]=y,c[G+16>>2]=z,c[G+24>>2]=A,c[G+32>>2]=w,c[G+40>>2]=E<<24>>24,c[G+48>>2]=B,c[G+56>>2]=v,c[G+64>>2]=F,G)|0)|0;i=G;if((x|0)>=0){dD(n,b,lrc(b|0)|0);break}KIb(a,16,2232136,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-5;i=e;return H|0}}while(0);F=k|0;Rb(F|0,20,2228272,(G=i,i=i+8|0,c[G>>2]=2370184,G)|0)|0;i=G;dD(n,F,lrc(F|0)|0);F=m+8|0;m=c[F>>2]|0;k=c[m+120>>2]|0;E=c[m+124>>2]|0;g=c[m+140>>2]|0;switch(g|0){case 8:case 7:case 0:case 4:case 5:{I=k;break};case 32:case 70:case 80:case 76:case 72:case 74:case 78:case 302:case 306:case 310:case 304:case 308:case 312:case 54:case 56:case 58:{I=k<<1;break};default:{k=mKb(g)|0;KIb(a,16,2223704,(G=i,i=i+8|0,c[G>>2]=k,G)|0);i=G;H=-22;i=e;return H|0}}if((E|0)>0){G=0;k=q;while(1){dD(n,k,I);q=G+1|0;if((q|0)<(E|0)){G=q;k=k+t|0}else{break}}J=c[(c[F>>2]|0)+140>>2]|0}else{J=g}if((J|0)==8|(J|0)==32){H=0;i=e;return H|0}tKb(J,h,j)|0;J=-(-I>>c[h>>2])|0;h=-E>>c[j>>2];j=-h|0;E=(h|0)<0;if(E){K=0;L=r}else{H=0;i=e;return H|0}while(1){dD(n,L,J);r=K+1|0;if((r|0)<(j|0)){K=r;L=L+u|0}else{break}}if(E){M=0;N=s}else{H=0;i=e;return H|0}while(1){dD(n,N,J);s=M+1|0;if((s|0)<(j|0)){M=s;N=N+p|0}else{H=0;break}}i=e;return H|0}function A_(a){a=a|0;var b=0;b=(krc(c[a+4>>2]|0,2303832,9)|0)==0;return(b?100:0)|0}function B_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;d=i;i=i+136|0;e=d|0;f=d+96|0;g=d+104|0;h=d+112|0;j=d+120|0;k=d+128|0;l=c[b+16>>2]|0;c[g>>2]=0;c[h>>2]=0;c[j>>2]=0;c[k>>2]=0;m=0;while(1){if((m|0)>=80){n=5;break}o=(zD(l)|0)&255;a[e+m|0]=o;p=m+1|0;if(o<<24>>24==10){n=4;break}else{m=p}}do{if((n|0)==4){a[e+p|0]=32;a[e+(m+2)|0]=0}else if((n|0)==5){if((m|0)==80){q=-1}else{break}i=d;return q|0}}while(0);if((krc(e|0,2303832,9)|0)!=0){q=-1;i=d;return q|0}p=m+1|0;m=e+p|0;do{if((p|0)>10){l=-1;o=-1;r=-1;s=-1;t=0;u=63;v=e+10|0;a:while(1){w=a[v]|0;b:do{if(w<<24>>24==32){x=v;y=u;z=t;A=s;B=r;C=o;D=l}else{E=v+1|0;switch(w<<24>>24|0){case 88:{do{if((krc(2346288,E,6)|0)==0){F=v+7|0;if((krc(2340168,F,7)|0)==0){G=F;H=0;break}if((krc(2334248,F,8)|0)==0){G=F;H=0;break}if((krc(2329176,F,8)|0)==0){G=F;H=0;break}if((krc(2323256,F,5)|0)==0){G=F;H=70;break}if((krc(2318216,F,5)|0)==0){G=F;H=80;break}if((krc(2313408,F,5)|0)==0){G=F;H=76;break}if((krc(2308744,F,6)|0)==0){G=F;H=72;break}if((krc(2303824,F,6)|0)==0){G=F;H=74;break}if((krc(2292968,F,6)|0)==0){G=F;H=78;break}if((krc(2285736,F,6)|0)==0){G=F;H=302;break}if((krc(2281616,F,6)|0)==0){G=F;H=306;break}if((krc(2277592,F,6)|0)==0){G=F;H=310;break}if((krc(2273344,F,6)|0)==0){G=F;H=304;break}if((krc(2268328,F,6)|0)==0){G=F;H=308;break}if((krc(2264512,F,6)|0)==0){G=F;H=312;break}if((krc(2260768,F,6)|0)==0){G=F;H=54;break}if((krc(2256336,F,6)|0)==0){G=F;H=56;break}if((krc(2252304,F,6)|0)==0){G=F;H=58;break}if((krc(2422064,F,3)|0)==0){G=F;H=7;break}if((krc(2412016,F,3)|0)==0){G=F;H=4;break}I=(krc(2390144,F,3)|0)==0;G=F;H=I?5:s}else{G=E;H=s}}while(0);I=G;while(1){if(!(I>>>0<m>>>0)){x=I;y=u;z=t;A=H;B=r;C=o;D=l;break b}if((a[I]|0)==32){x=I;y=u;z=t;A=H;B=r;C=o;D=l;break}else{I=I+1|0}}break};case 72:{I=rb(E|0,f|0,10)|0;x=c[f>>2]|0;y=u;z=t;A=s;B=r;C=I;D=l;break b;break};case 67:{do{if((krc(2252312,E,7)|0)==0){J=2;K=0}else{if((krc(2209288,E,8)|0)==0){J=1;K=0;break}if((krc(2176640,E,8)|0)==0){J=3;K=0;break}if((krc(2148704,E,6)|0)==0){J=t;K=54;break}if((krc(2124608,E,6)|0)==0){J=t;K=56;break}if((krc(2642808,E,6)|0)==0){J=t;K=58;break}if((krc(2619416,E,6)|0)==0){J=t;K=304;break}if((krc(2592192,E,6)|0)==0){J=t;K=308;break}if((krc(2569728,E,6)|0)==0){J=t;K=312;break}if((krc(2551768,E,6)|0)==0){J=t;K=302;break}if((krc(2533520,E,6)|0)==0){J=t;K=306;break}if((krc(2518088,E,6)|0)==0){J=t;K=310;break}if((krc(2504152,E,6)|0)==0){J=t;K=72;break}if((krc(2490632,E,6)|0)==0){J=t;K=74;break}if((krc(2479800,E,6)|0)==0){J=t;K=78;break}if((krc(2469920,E,5)|0)==0){J=t;K=70;break}if((krc(2460904,E,5)|0)==0){J=t;K=80;break}if((krc(2444464,E,5)|0)==0){J=t;K=76;break}if((krc(2431408,E,3)|0)==0){J=2;K=0;break}if((krc(2422064,E,3)|0)==0){J=t;K=7;break}if((krc(2412016,E,3)|0)==0){J=t;K=4;break}if((krc(2404520,E,8)|0)==0){n=35;break a}if((krc(2390144,E,3)|0)==0){J=t;K=5;break}if((krc(2383256,E,6)|0)==0){J=t;K=32;break}if((krc(2376496,E,4)|0)==0){J=t;K=8}else{n=40;break a}}}while(0);I=E;while(1){if(!(I>>>0<m>>>0)){x=I;y=u;z=J;A=s;B=K;C=o;D=l;break b}if((a[I]|0)==32){x=I;y=u;z=J;A=s;B=K;C=o;D=l;break}else{I=I+1|0}}break};case 65:{Bd(E|0,2355592,(L=i,i=i+16|0,c[L>>2]=j,c[L+8>>2]=k,L)|0)|0;i=L;I=E;while(1){if(!(I>>>0<m>>>0)){x=I;y=u;z=t;A=s;B=r;C=o;D=l;break b}if((a[I]|0)==32){x=I;y=u;z=t;A=s;B=r;C=o;D=l;break}else{I=I+1|0}}break};case 87:{I=rb(E|0,f|0,10)|0;x=c[f>>2]|0;y=u;z=t;A=s;B=r;C=o;D=I;break b;break};case 70:{Bd(E|0,2355592,(L=i,i=i+16|0,c[L>>2]=g,c[L+8>>2]=h,L)|0)|0;i=L;I=E;while(1){if(!(I>>>0<m>>>0)){x=I;y=u;z=t;A=s;B=r;C=o;D=l;break b}if((a[I]|0)==32){x=I;y=u;z=t;A=s;B=r;C=o;D=l;break}else{I=I+1|0}}break};case 73:{x=v+2|0;y=a[E]|0;z=t;A=s;B=r;C=o;D=l;break b;break};default:{x=E;y=u;z=t;A=s;B=r;C=o;D=l;break b}}}}while(0);w=x+1|0;if(w>>>0<m>>>0){l=D;o=C;r=B;s=A;t=z;u=y;v=w}else{n=76;break}}if((n|0)==35){KIb(b,16,2397152,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-1;i=d;return q|0}else if((n|0)==40){KIb(b,16,2370064,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-1;i=d;return q|0}else if((n|0)==76){if((D|0)==-1|(C|0)==-1){break}if((B|0)==-1){M=(A|0)==-1?0:A}else{M=B}if((c[g>>2]|0)<1){n=82}else{if((c[h>>2]|0)<1){n=82}}if((n|0)==82){c[g>>2]=25;c[h>>2]=1}do{if((c[j>>2]|0)==0){if((c[k>>2]|0)!=0){break}c[k>>2]=1}}while(0);v=ZX(b,0)|0;if((v|0)==0){q=-12;i=d;return q|0}u=v+8|0;t=c[u>>2]|0;c[t+120>>2]=D;c[t+124>>2]=C;t=c[g>>2]|0;s=c[h>>2]|0;xKb(g,h,t,(t|0)<0|0?-1:0,s,(s|0)<0|0?-1:0,2147483647,0)|0;_X(v,64,c[h>>2]|0,c[g>>2]|0);s=v+92|0;t=c[v+40>>2]|0;c[s>>2]=c[v+44>>2];c[s+4>>2]=t;t=c[u>>2]|0;c[t+140>>2]=M;c[t+8>>2]=0;c[t+48>>2]=14;s=c[k>>2]|0;c[v+80>>2]=c[j>>2];c[v+84>>2]=s;c[t+400>>2]=z;switch(y<<24>>24|0){case 98:{c[t+408>>2]=5;q=0;i=d;return q|0};case 109:{KIb(b,16,2235736,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;N=c[u>>2]|0;break};case 116:{c[t+408>>2]=4;q=0;i=d;return q|0};case 112:{c[t+408>>2]=1;q=0;i=d;return q|0};case 63:{N=t;break};default:{KIb(b,16,2241928,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-22;i=d;return q|0}}c[N+408>>2]=0;q=0;i=d;return q|0}}}while(0);KIb(b,16,2241928,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-1;i=d;return q|0}function C_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+88|0;f=e|0;g=c[c[b+28>>2]>>2]|0;h=b+16|0;b=0;while(1){if((b|0)>=80){break}j=(zD(c[h>>2]|0)|0)&255;a[f+b|0]=j;k=b+1|0;if(j<<24>>24==10){l=4;break}else{b=k}}if((l|0)==4){a[f+k|0]=0}k=c[h>>2]|0;l=c[k+76>>2]|0;if((l|0)!=0){m=l;i=e;return m|0}if((c[k+52>>2]|0)!=0){m=-541478725;i=e;return m|0}if((b|0)==80){m=-1094995529;i=e;return m|0}if((krc(f|0,2370184,5)|0)!=0){m=-1094995529;i=e;return m|0}f=c[g+8>>2]|0;g=c2(c[f+140>>2]|0,c[f+120>>2]|0,c[f+124>>2]|0)|0;if((g|0)<0){m=g;i=e;return m|0}f=fX(c[h>>2]|0,d,g)|0;if((f|0)<0){m=f;i=e;return m|0}if((f|0)==(g|0)){c[d+32>>2]=0;m=0;i=e;return m|0}else{m=(c[(c[h>>2]|0)+52>>2]|0)!=0?-541478725:-5;i=e;return m|0}return 0}function D_(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1179011410){a=b+8|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1447909428?100:0)|0}else{return 0}return 0}function E_(b){b=b|0;var e=0,f=0,h=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;f=c[b+16>>2]|0;h=c[b+12>>2]|0;j=h+4|0;c[j>>2]=0;l=h+8|0;m=l;c[m>>2]=0;n=h+24|0;g[n>>2]=1.0;hD(f,12,0)|0;o=FD(f)|0;p=FD(f)|0;if((o|0)!=1414744396){q=-1094995529;i=e;return q|0}o=p-4|0;if((FD(f)|0)!=1145128264|(o|0)<0){q=-1094995529;i=e;return q|0}r=hJb(o)|0;if((r|0)==0){q=-12;i=e;return q|0}if((AD(f,r,o)|0)!=(o|0)){kJb(r);q=-5;i=e;return q|0}s=p-12|0;a:do{if((s|0)>0){p=h;t=0;b:while(1){u=r+t|0;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=r+(t+4)|0;w=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=o-t|0;x=u-8|0;do{if(w>>>0>x>>>0){if((v|0)==1600418931){z=12}else if((v|0)==1802663030|(v|0)==1802663027){z=10;break b}else{A=t}}else{if((v|0)==1802663030){if((w|0)!=68|(w+8|0)>(u|0)){B=-1094995529;break a}C=ZX(b,0)|0;if((C|0)==0){B=-12;break a}_X(C,60,1,~~+g[n>>2]);c[p>>2]=c[C>>2];D=C+8|0;C=c[D>>2]|0;c[C+8>>2]=0;c[C+48>>2]=35;c[C+100>>2]=4;C=hJb(4)|0;c[(c[D>>2]|0)+96>>2]=C;C=r+(t+16)|0;E=c[(c[D>>2]|0)+96>>2]|0;y=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;E=r+(t+36)|0;C=c[D>>2]|0;c[C+120>>2]=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24;E=r+(t+40)|0;c[C+124>>2]=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24;A=t+76|0;break}else if((v|0)==1600418931){z=12;break}else if((v|0)!=1802663027){A=t;break}if((w|0)!=40|(w+8|0)>(u|0)){B=-1094995529;break a}E=r+(t+8)|0;C=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;if(C>>>0>134217725>>>0){z=20;break b}E=C+1|0;if((E|0)>(c[j>>2]|0)){if((oJb(l,E,32)|0)!=0){B=-12;break a}D=c[j>>2]|0;mrc((c[m>>2]|0)+(D<<5)|0,0,E-D<<5|0)|0;c[j>>2]=E}E=r+(t+12)|0;D=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=c[m>>2]|0;c[E+(C<<5)+16>>2]=D;F=r+(t+36)|0;G=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;c[E+(C<<5)+8>>2]=G;F=r+(t+40)|0;H=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;c[E+(C<<5)>>2]=H;F=r+(t+44)|0;I=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;c[E+(C<<5)+4>>2]=I;F=E+(C<<5)+24|0;c[F>>2]=0;c[F+4>>2]=0;if((G|0)<1|(H|0)<1|(I|0)<1){z=25;break b}if((D|0)==0&(I|0)<8){z=27;break b}I=ZX(b,0)|0;if((I|0)==0){B=-12;break a}c[I+4>>2]=C;_X(I,60,1,c[(c[m>>2]|0)+(C<<5)>>2]|0);D=c[m>>2]|0;c[D+(C<<5)+12>>2]=c[I>>2];H=c[I+8>>2]|0;c[H+8>>2]=1;c[H+52>>2]=0;I=c[D+(C<<5)+8>>2]|0;c[H+416>>2]=I;G=c[D+(C<<5)>>2]|0;c[H+412>>2]=G;F=c[D+(C<<5)+4>>2]|0;c[H+792>>2]=F;c[H+72>>2]=ca(ca(G,I)|0,F)|0;c[H+432>>2]=ca(F,I)|0;do{if((c[D+(C<<5)+16>>2]|0)==0){I=H+48|0;if((F|0)==8){c[I>>2]=65541;break}else{c[I>>2]=65536;break}}else{c[H+48>>2]=69639}}while(0);A=t+48|0}}while(0);if((z|0)==12){z=0;if((u|0)<16){z=13;break}v=r+(t+12)|0;g[n>>2]=(c[k>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24,+g[k>>2]);A=t}v=A+1|0;if((v|0)<(s|0)){t=v}else{z=36;break a}}if((z|0)==10){KIb(b,16,2460720,(J=i,i=i+16|0,c[J>>2]=w,c[J+8>>2]=x,J)|0);i=J;q=-1094995529;i=e;return q|0}else if((z|0)==13){KIb(b,16,2369920,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;B=-1094995529;break}else if((z|0)==20){KIb(b,16,2303712,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;B=-1094995529;break}else if((z|0)==25){KIb(b,16,2252224,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;B=-1094995529;break}else if((z|0)==27){KIb(b,16,2209208,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;B=-1094995529;break}}else{z=36}}while(0);do{if((z|0)==36){J=FD(f)|0;FD(f)|0;if((J|0)!=1414744396){q=-1094995529;i=e;return q|0}if((FD(f)|0)!=1230393165){B=-1094995529;break}kJb(r);J=h+16|0;c[J>>2]=-1;c[J+4>>2]=-1;q=0;i=e;return q|0}}while(0);mJb(l);kJb(r);q=B;i=e;return q|0}function F_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+8|0;f=e|0;g=f;h=c[b+12>>2]|0;j=b+16|0;b=c[j>>2]|0;k=f;l=f+4|0;m=h+16|0;n=h;o=d+32|0;p=d+8|0;q=d+64|0;r=d+24|0;s=h+4|0;t=h+8|0;h=b;while(1){u=AD(h,k,8)|0;if((u|0)<0){v=u;w=21;break}u=c[g>>2]|0;x=c[l>>2]|0;if((jD(b)|0)!=0){v=-5;w=21;break}if((u|0)==1414744396){z=wrc(c[m>>2]|0,c[m+4>>2]|0,1,0)|0;c[m>>2]=z;c[m+4>>2]=G;FD(b)|0}else if((u|0)==1600417395){A=FD(b)|0;hD(b,4,0)|0;B=x-8|0;if(A>>>0<(c[s>>2]|0)>>>0){if((c[(c[t>>2]|0)+(A<<5)+8>>2]|0)>0){w=16;break}}hD(b,B,0)|0;}else if((u|0)==1836213865|(u|0)==1836213872|(u|0)==1836213859|(u|0)==846358121|(u|0)==846358128|(u|0)==846358115){u=qc(x|0,8)|0;if(G){v=-5;w=21;break}if((K1(d,u)|0)!=0){v=-5;w=21;break}c[o>>2]=c[n>>2];u=c[m+4>>2]|0;c[p>>2]=c[m>>2];c[p+4>>2]=u;u=fD(c[j>>2]|0,0,0,1)|0;c[q>>2]=u;c[q+4>>2]=G;u=c[r>>2]|0;z=c[f+4>>2]|0;C=u|0;y=c[f>>2]|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=u+4|0;y=z;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;D=AD(c[j>>2]|0,(c[r>>2]|0)+8|0,x)|0;if((D|0)>=0){w=15;break}P1(d)}else{hD(b,x,0)|0;}h=c[j>>2]|0}if((w|0)==15){M1(d,D+8|0);v=D;i=e;return v|0}else if((w|0)==16){D=fX(c[j>>2]|0,d,B)|0;if((D|0)<0){v=-5;i=e;return v|0}d=c[t>>2]|0;c[o>>2]=c[d+(A<<5)+12>>2];o=d+(A<<5)+24|0;t=c[o+4>>2]|0;c[p>>2]=c[o>>2];c[p+4>>2]=t;t=c[d+(A<<5)+8>>2]|0;if((c[d+(A<<5)+16>>2]|0)==0){E=((B|0)/(t|0)|0|0)/((c[d+(A<<5)+4>>2]|0)/8|0|0)|0}else{E=((B-(t<<1)|0)/(t|0)|0)<<1}t=wrc(c[o>>2]|0,c[o+4>>2]|0,E,(E|0)<0|0?-1:0)|0;c[o>>2]=t;c[o+4>>2]=G;v=D;i=e;return v|0}else if((w|0)==21){i=e;return v|0}return 0}function G_(a){a=a|0;mJb((c[a+12>>2]|0)+8|0);return 0}function H_(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;h=f|0;a[h]=a[2103976]|0;a[h+1|0]=a[2103977]|0;a[h+2|0]=a[2103978]|0;a[h+3|0]=a[2103979]|0;a[h+4|0]=a[2103980]|0;j=c[(c[g+12>>2]|0)+12>>2]|0;if((j|0)==144){a[f+2|0]=0;k=c[g+96>>2]|0;a[f+3|0]=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>24;a[f+4|0]=2}else if((j|0)==145){a[f+2|0]=1;j=c[g+96>>2]|0;a[f+3|0]=(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)>>>24;a[f+4|0]=3}else{l=-22;i=e;return l|0}dD(c[b+16>>2]|0,h,2);l=0;i=e;return l|0}function I_(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+4>>2]|0;e=(c[a+8>>2]|0)-7|0;a=b+e|0;do{if((e|0)>0){f=a;g=0;h=b;i=0;do{a:do{if(h>>>0<a>>>0){j=0;k=h;while(1){l=k;if(!(((he((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&-10)<<16>>16==-16)){m=j;n=k;break a}l=k+3|0;o=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)>>>13&8191;if(o>>>0<7>>>0){m=j;n=k;break a}l=f-k|0;p=k+((o|0)>(l|0)?l:o)|0;o=j+1|0;if(p>>>0<a>>>0){j=o;k=p}else{m=o;n=p;break}}}else{m=0;n=h}}while(0);i=(i|0)>(m|0)?i:m;g=(h|0)==(b|0)?m:g;h=n+1|0;}while(h>>>0<a>>>0);if((g|0)>2){q=51;return q|0}if((i|0)>500){q=50;return q|0}if((i|0)>2){q=25}else{r=i;break}return q|0}else{r=0}}while(0);q=(r|0)>0|0;return q|0}function J_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[b+236>>2]=1463898624;A$(a);e=a+16|0;do{if((c[(c[e>>2]|0)+88>>2]|0)!=0){if((LGb(c[a+1140>>2]|0,10230496,0,2)|0)!=0){break}f=fD(c[e>>2]|0,0,0,1)|0;g=G;HB(a)|0;fD(c[e>>2]|0,f,g,0)|0;}}while(0);_X(b,64,1,28224e3);d=0;return d|0}function K_(a){a=a|0;return M_(a,86019)|0}function L_(a){a=a|0;return M_(a,86057)|0}function M_(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;i=i+4128|0;j=h|0;k=h+8|0;l=h+32|0;c[j>>2]=0;m=f+4|0;n=c[m>>2]|0;o=c[f+8>>2]|0;f=n+o|0;a:do{if((o|0)>0){p=l|0;q=k|0;r=k+12|0;s=k+16|0;t=l+7|0;u=k+4|0;v=k+8|0;w=0;x=0;y=n;z=86019;A=n;b:while(1){do{if(y>>>0>A>>>0){B=a[y]|0;if((B<<24>>24|0)==119){if((a[y+1|0]|0)==11){C=7;break}else{D=z;E=x;F=w;G=A;break}}else if((B<<24>>24|0)==11){if((a[y+1|0]|0)==119){C=7;break}else{D=z;E=x;F=w;G=A;break}}else{D=z;E=x;F=w;G=A;break}}else{C=7}}while(0);if((C|0)==7){C=0;c:do{if(y>>>0<f>>>0){B=y+1|0;H=0;I=y;J=z;while(1){K=(grc(I,2303656,8)|0)==0;L=K?I+16|0:I;do{if((a[y]|0)==119){if((a[B]|0)!=11){C=12;break}a[p]=11;a[l+1|0]=a[y]|0;a[l+2|0]=a[y+3|0]|0;a[l+3|0]=a[y+2|0]|0;a[l+4|0]=a[y+5|0]|0;a[l+5|0]=a[y+4|0]|0;a[l+6|0]=a[y+7|0]|0;a[t]=a[y+6|0]|0;c[q>>2]=p;c[r>>2]=54;c[s>>2]=62;M=t}else{C=12}}while(0);if((C|0)==12){C=0;K=(L|0)==0?0:54;c[q>>2]=L;c[r>>2]=K;c[s>>2]=K|8;M=L+((K+7|0)>>>3)|0}c[u>>2]=M;c[v>>2]=0;if((U$(k,j)|0)<0){N=H;O=J;break c}K=(c[j>>2]|0)+42|0;P=b[K>>1]|0;if((L+(P&65535)|0)>>>0>f>>>0){N=H;O=J;break c}do{if((a[y]|0)==119){if((a[B]|0)!=11){break}if(!((P&65535)>>>0<4097>>>0)){break b}if((P&65535)>>>0>8>>>0){Q=8}else{break}do{R=Q|1;a[l+Q|0]=a[y+R|0]|0;a[l+R|0]=a[y+Q|0]|0;Q=Q+2|0;}while((Q|0)<(e[K>>1]|0))}}while(0);K=DGb(1)|0;P=c[j>>2]|0;R=e[P+42>>1]|0;if((EGb(K,0,(c[q>>2]|0)+2|0,R-2|0)|0)!=0){N=H;O=J;break c}K=(d[P+5|0]|0)>>>0>10>>>0?86057:J;P=L+R|0;R=H+1|0;if(P>>>0<f>>>0){H=R;I=P;J=K}else{N=R;O=K;break}}}else{N=0;O=z}}while(0);J=c[m>>2]|0;D=O;E=(y|0)==(J|0)?N:x;F=(w|0)>(N|0)?w:N;G=J}J=y+1|0;if(J>>>0<f>>>0){w=F;x=E;y=J;z=D;A=G}else{S=F;T=E;U=D;break a}}KIb(0,0,2252168,(A=i,i=i+24|0,c[A>>2]=2209144,c[A+8>>2]=2176552,c[A+16>>2]=63,A)|0);i=A;Hd();return 0}else{S=0;T=0;U=86019}}while(0);mJb(j);if((U|0)!=(g|0)){V=0;i=h;return V|0}if((T|0)>3){V=51;i=h;return V|0}if((S|0)>200){V=50;i=h;return V|0}if((S|0)>3){V=25;i=h;return V|0}V=(S|0)>0|0;i=h;return V|0}function N_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[b+4>>2]|0;f=e;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=1179011410){g=0;return g|0}f=e+8|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=1163280727){g=0;return g|0}f=e+16|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=16){g=0;return g|0}if((c[b+8>>2]|0)<512){g=0;return g|0}else{h=44}while(1){if((h|0)>=256){break}if((a[e+h|0]|0)==0){h=h+1|0}else{g=0;i=10;break}}if((i|0)==10){return g|0}if((a[e+256|0]|0)==-124){j=264}else{g=0;return g|0}while(1){if((j|0)>=512){g=100;i=10;break}if((a[e+j|0]|0)==0){j=j+1|0}else{g=0;i=10;break}}if((i|0)==10){return g|0}return 0}function O_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=ZX(a,0)|0;if((f|0)==0){g=-12;i=b;return g|0}hD(e,16,0)|0;h=FD(e)|0;j=f+8|0;OS(e,c[j>>2]|0,h)|0;h=c[j>>2]|0;k=c[h+412>>2]|0;if((k|0)==8e3){c[h+424>>2]=80;c[h+416>>2]=1;_X(f,64,1,100);c[(c[j>>2]|0)+48>>2]=86070;fD(e,257,0,0)|0;h=DD(e)|0;l=zD(e)|0;m=((((FD(e)|0)*60|0)+l|0)*1e3|0)+h|0;h=c[j>>2]|0;j=c[h+412>>2]|0;l=(c[h+424>>2]|0)*1e3|0;h=VIb(m,(m|0)<0|0?-1:0,j,(j|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=f+56|0;c[l>>2]=h;c[l+4>>2]=G;c[d>>2]=512;fD(e,512,0,0)|0;g=0;i=b;return g|0}else{KIb(a,16,2460536,(a=i,i=i+8|0,c[a>>2]=k,a)|0);i=a;g=-1094995529;i=b;return g|0}return 0}function P_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=b+28|0;b=(c[(c[(c[c[g>>2]>>2]|0)+8>>2]|0)+412>>2]|0)==8e3;h=b?10:22;if(b){i=K1(d,10)|0}else{i=K1(d,11)|0}if((i|0)!=0){j=i;return j|0}do{if((c[(c[(c[c[g>>2]>>2]|0)+8>>2]|0)+412>>2]|0)==4400){i=e+26|0;if((a[i]|0)!=0){b=e+26|0;if((a[b]|0)==0){k=12;break}l=d+24|0;a[c[l>>2]|0]=a[e+9|0]|0;a[(c[l>>2]|0)+1|0]=a[e+21|0]|0;a[(c[l>>2]|0)+2|0]=a[e+10|0]|0;a[(c[l>>2]|0)+3|0]=a[e+22|0]|0;a[(c[l>>2]|0)+4|0]=a[e+11|0]|0;a[(c[l>>2]|0)+5|0]=a[e+23|0]|0;a[(c[l>>2]|0)+6|0]=a[e+12|0]|0;a[(c[l>>2]|0)+7|0]=a[e+24|0]|0;a[(c[l>>2]|0)+8|0]=a[e+13|0]|0;a[(c[l>>2]|0)+9|0]=a[e+25|0]|0;a[(c[l>>2]|0)+10|0]=a[e+14|0]|0;a[b]=0;m=0;break}b=e+4|0;l=AD(f,b,h)|0;if((l|0)<0){j=l;return j|0}if((l|0)==(h|0)){l=d+24|0;a[c[l>>2]|0]=a[e+15|0]|0;a[(c[l>>2]|0)+1|0]=a[b]|0;a[(c[l>>2]|0)+2|0]=a[e+16|0]|0;a[(c[l>>2]|0)+3|0]=a[e+5|0]|0;a[(c[l>>2]|0)+4|0]=a[e+17|0]|0;a[(c[l>>2]|0)+5|0]=a[e+6|0]|0;a[(c[l>>2]|0)+6|0]=a[e+18|0]|0;a[(c[l>>2]|0)+7|0]=a[e+7|0]|0;a[(c[l>>2]|0)+8|0]=a[e+19|0]|0;a[(c[l>>2]|0)+9|0]=a[e+8|0]|0;a[(c[l>>2]|0)+10|0]=a[e+20|0]|0;a[i]=1;m=h;break}else{j=-5;return j|0}}else{k=12}}while(0);do{if((k|0)==12){g=e+4|0;i=AD(f,g,h)|0;if((i|0)<0){j=i;return j|0}if((i|0)==(h|0)){i=d+24|0;a[c[i>>2]|0]=a[e+9|0]|0;a[(c[i>>2]|0)+1|0]=a[g]|0;a[(c[i>>2]|0)+2|0]=a[e+10|0]|0;a[(c[i>>2]|0)+3|0]=a[e+5|0]|0;a[(c[i>>2]|0)+4|0]=a[e+11|0]|0;a[(c[i>>2]|0)+5|0]=a[e+6|0]|0;a[(c[i>>2]|0)+6|0]=a[e+12|0]|0;a[(c[i>>2]|0)+7|0]=a[e+7|0]|0;a[(c[i>>2]|0)+8|0]=a[e+13|0]|0;a[(c[i>>2]|0)+9|0]=a[e+8|0]|0;m=h;break}else{j=-5;return j|0}}}while(0);k=e;e=(c[k>>2]|0)-h|0;c[k>>2]=e;if((e|0)<(h|0)){hD(f,e,(e|0)<0|0?-1:0)|0;c[k>>2]=512}c[d+48>>2]=1;j=m;return j|0}function Q_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[b+8>>2]|0;if((d|0)<32){e=0;return e|0}f=d-3|0;if((f|0)<=0){e=0;return e|0}g=c[b+4>>2]|0;b=0;h=0;i=0;while(1){j=a[g+b|0]|0;if(!(j<<24>>24==(a[g+(b|2)|0]|0))){e=0;k=9;break}if((a[g+(b|1)|0]|0)!=(a[g+(b|3)|0]|0)){e=0;k=9;break}l=((j&255|0)!=(i|0))+h|0;m=b+32|0;if((m|0)<(f|0)){b=m;h=l;i=j<<24>>24}else{k=7;break}}if((k|0)==7){if((l|0)<2){e=0;return e|0}e=(d|0)<260?1:25;return e|0}else if((k|0)==9){return e|0}return 0}function R_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=b+8|0;f=c[e>>2]|0;c[f+8>>2]=1;c[f+48>>2]=1146374944;g=f+448|0;c[g>>2]=3;c[g+4>>2]=0;c[f+416>>2]=2;c[f+412>>2]=48e3;g=b+48|0;c[g>>2]=0;c[g+4>>2]=0;g=c[a+16>>2]|0;if((c[g+88>>2]|0)==0){h=48e3}else{a=iD(g)|0;g=B5a(f,a)|0;a=b+56|0;c[a>>2]=g;c[a+4>>2]=(g|0)<0|0?-1:0;h=c[(c[e>>2]|0)+412>>2]|0}_X(b,64,1,h);d=0;return d|0}function S_(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+16|0;if((jD(c[d>>2]|0)|0)!=0){e=-541478725;return e|0}a=fX(c[d>>2]|0,b,1024)|0;do{if((a|0)!=1024){if((a|0)>=0){M1(b,a);break}P1(b);e=a;return e|0}}while(0);c[b+32>>2]=0;e=a;return e|0}function T_(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+96|0;f=e|0;g=e+24|0;h=e+48|0;j=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;k=c[j+100>>2]|0;do{if((k|0)>0){l=c[b+12>>2]|0;m=c[j+96>>2]|0;n=k<<3;o=n>>>0>2147483639>>>0|(m|0)==0;p=o?0:m;q=o?0:n;c[f>>2]=p;c[f+12>>2]=q;o=q+8|0;c[f+16>>2]=o;c[f+4>>2]=p+(q>>3);q=f+8|0;c[q>>2]=0;r=CRa(h,m,n,1)|0;do{if((r|0)<0){s=r}else{n=(o|0)<(r|0)?o:r;c[q>>2]=n;m=c[h>>2]|0;t=m-1|0;c[l+8>>2]=t;u=c[h+4>>2]|0;c[l+12>>2]=u;v=c[h+12>>2]|0;c[l+16>>2]=v;if(t>>>0>3>>>0){KIb(b,16,2252128,(w=i,i=i+8|0,c[w>>2]=m,w)|0);i=w;s=-1;break}if((u|0)==15){KIb(b,16,2209096,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1;break}u=p+(n>>>3)|0;m=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=n+1|0;t=o>>>0>u>>>0?u:o;c[q>>2]=t;if((m&-2147483648>>>((n&7)>>>0)|0)!=0){KIb(b,16,2176504,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1;break}n=p+(t>>>3)|0;m=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=t+1|0;u=o>>>0>n>>>0?n:o;c[q>>2]=u;if((m&-2147483648>>>((t&7)>>>0)|0)!=0){KIb(b,16,2148600,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1;break}t=p+(u>>>3)|0;m=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=u+1|0;c[q>>2]=o>>>0>t>>>0?t:o;if((m&-2147483648>>>((u&7)>>>0)|0)!=0){KIb(b,16,2124552,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1;break}if((v|0)==0){v=l+28|0;c[g+20>>2]=2432;c[g+8>>2]=v;c[g+16>>2]=l+332;u=g+12|0;c[u>>2]=v;v=g+4|0;m=g|0;c[m>>2]=5;c[v>>2]=29;c[l+20>>2]=((DRa(g,f)|0)+3|0)/8|0;t=c[v>>2]|0;if((t|0)<32){n=c[m>>2]<<t;c[m>>2]=n;t=n>>>24&255;while(1){n=c[u>>2]|0;c[u>>2]=n+1;a[n]=t;n=c[m>>2]|0;c[m>>2]=n<<8;x=(c[v>>2]|0)+8|0;c[v>>2]=x;if((x|0)<32){t=n>>>16&255}else{break}}}c[v>>2]=32;c[m>>2]=0}c[l+4>>2]=1;s=0}}while(0);if((s|0)<0){y=-1}else{break}i=e;return y|0}}while(0);y=0;i=e;return y|0}function U_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+8|0;f=e|0;g=c[b+12>>2]|0;h=c[b+16>>2]|0;b=d+28|0;j=c[b>>2]|0;if((j|0)==0){k=0;i=e;return k|0}do{if((c[g+4>>2]|0)!=0){l=g+20|0;m=j+7+(c[l>>2]|0)|0;if(m>>>0>8191>>>0){KIb(0,16,2303616,(n=i,i=i+16|0,c[n>>2]=m,c[n+8>>2]=8191,n)|0);i=n;k=-1094995529;i=e;return k|0}else{c[f>>2]=je((c[g+16>>2]|(c[g+8>>2]<<4|c[g+12>>2])<<4)<<6|m>>>11|-983040|0)|0;a[f+4|0]=m>>>3;a[f+5|0]=m<<5|31;a[f+6|0]=-4;dD(h,f|0,7);m=c[l>>2]|0;if((m|0)==0){break}dD(h,g+28|0,m);c[l>>2]=0;break}}}while(0);dD(h,c[d+24>>2]|0,c[b>>2]|0);k=0;i=e;return k|0}function V_(a){a=a|0;if((c[(c[a+12>>2]|0)+24>>2]|0)==0){return 0}IB(a)|0;return 0}function W_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+12>>2]|0;d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;g=a+16|0;if((HD(c[g>>2]|0)|0)!=32768){e=-1094995529;return e|0}h=b;c[h>>2]=(HD(c[g>>2]|0)|0)+4;fD(c[g>>2]|0,-4,-1,1)|0;if((QX(f,c[g>>2]|0,c[h>>2]|0)|0)<0){e=-12;return e|0}g=Y$(f,c[f+96>>2]|0,c[f+100>>2]|0,h,0)|0;if((g|0)!=0){e=g;return e|0}g=c[d+8>>2]|0;c[g+8>>2]=1;c[g+48>>2]=c[(c[a+4>>2]|0)+28>>2];_X(d,64,32,c[f+412>>2]|0);e=0;return e|0}function X_(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[a+12>>2]|0;f=(c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+416>>2]|0)*18|0;g=a+16|0;a=fD(c[g>>2]|0,0,0,1)|0;h=b+64|0;c[h>>2]=a;c[h+4>>2]=G;c[b+32>>2]=0;a=fX(c[g>>2]|0,b,f)|0;if((a|0)!=(f|0)){P1(b);i=(a|0)<0?a:-5;return i|0}a=c[b+24>>2]|0;if(((d[a]|d[a+1|0]<<8)<<16>>16&128)==0){c[b+28>>2]=f;c[b+48>>2]=1;a=c[e>>2]|0;e=xrc(c[h>>2]|0,c[h+4>>2]|0,a,(a|0)<0|0?-1:0)|0;a=Crc(e,G,f,(f|0)<0|0?-1:0)|0;f=b+8|0;c[f>>2]=a;c[f+4>>2]=G;i=0;return i|0}else{P1(b);i=-541478725;return i|0}return 0}function Y_(b){b=b|0;var e=0,f=0;if((c[b+8>>2]|0)<2261){e=0;return e|0}f=c[b+4>>2]|0;b=f;do{if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==2048){if(((a[f+264|0]|0)-1&255)>>>0>1>>>0){e=0;return e|0}if((a[f+2048|0]|0)==(a[f+2259|0]|0)&(a[f+2049|0]|0)==(a[f+2258|0]|0)){e=26}else{break}return e|0}}while(0);e=0;return e|0}function Z_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=ZX(a,0)|0;if((d|0)==0){e=-12;i=b;return e|0}f=a+16|0;hD(c[f>>2]|0,264,0)|0;g=zD(c[f>>2]|0)|0;h=d+8|0;c[(c[h>>2]|0)+416>>2]=g;hD(c[f>>2]|0,1783,0)|0;f=c[h>>2]|0;c[f+8>>2]=1;c[f+48>>2]=86063;c[f+412>>2]=44100;c[f+72>>2]=292e3;h=c[f+416>>2]|0;if((h-1|0)>>>0<2>>>0){g=(h|0)==1;d=f+448|0;c[d>>2]=g?4:3;c[d+4>>2]=g?0:0;c[f+432>>2]=h*212|0;e=0;i=b;return e|0}else{KIb(a,16,2460448,(a=i,i=i+8|0,c[a>>2]=h,a)|0);i=a;e=-1;i=b;return e|0}return 0}function __(a,b){a=a|0;b=b|0;var d=0;d=fX(c[a+16>>2]|0,b,c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+432>>2]|0)|0;c[b+32>>2]=0;return((d|0)<1?-5:d)|0}function $_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[b+12>>2]|0;e=ZX(b,0)|0;if((e|0)==0){f=-12;return f|0}g=e+8|0;h=c[g>>2]|0;c[h+8>>2]=1;c[h+48>>2]=1095123744;c[h+416>>2]=2;i=h+448|0;c[i>>2]=3;c[i+4>>2]=0;if((PX(h,1)|0)!=0){f=-12;return f|0}h=c[g>>2]|0;a[c[h+96>>2]|0]=c[h+416>>2]<<3;h=b+16|0;b=wrc(JD(c[h>>2]|0)|0,0,32,0)|0;i=d;c[i>>2]=b;c[i+4>>2]=G;i=e+56|0;c[i>>2]=JD(c[h>>2]|0)|0;c[i+4>>2]=0;i=HD(c[h>>2]|0)|0;c[(c[g>>2]|0)+412>>2]=i;hD(c[h>>2]|0,22,0)|0;_X(e,64,1,c[(c[g>>2]|0)+412>>2]|0);f=0;return f|0}function a$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[a+12>>2]|0;e=c[d>>2]|0;f=c[d+4>>2]|0;g=a+16|0;a=fD(c[g>>2]|0,0,0,1)|0;h=xrc(e,f,a,G)|0;a=G;f=0;do{if((a|0)>(f|0)|(a|0)==(f|0)&h>>>0>2304>>>0){i=2304}else{e=c[d>>2]|0;j=c[d+4>>2]|0;k=fD(c[g>>2]|0,0,0,1)|0;l=xrc(e,j,k,G)|0;k=G;j=0;if((k|0)<(j|0)|(k|0)==(j|0)&l>>>0<1>>>0){m=-541478725}else{i=l;break}return m|0}}while(0);d=fX(c[g>>2]|0,b,i)|0;c[b+32>>2]=0;m=d;return m|0}function b$(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==70){if((a[d+1|0]|0)!=79){break}if((a[d+2|0]|0)!=82){break}if((a[d+3|0]|0)!=77){break}if((a[d+8|0]|0)!=65){break}if((a[d+9|0]|0)!=73){break}if((a[d+10|0]|0)!=70){break}b=a[d+11|0]|0;if((b<<24>>24|0)==70|(b<<24>>24|0)==67){e=100}else{break}return e|0}}while(0);e=0;return e|0}function c$(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;e=i;i=i+8|0;f=e|0;g=b+16|0;h=c[g>>2]|0;j=b+12|0;k=c[j>>2]|0;c[f>>2]=0;if((jD(h)|0)!=0){l=-1094995529;i=e;return l|0}m=FD(h)|0;n=JD(h)|0;o=(n|0)<0?2147483647:n;if(!((o|0)>-1&(m|0)==1297239878)){l=-1094995529;i=e;return l|0}m=FD(h)|0;do{if((m|0)==1179011393){p=0}else{if((m|0)==1128679745){p=-1568648896;break}else{l=-1094995529}i=e;return l|0}}while(0);m=o-4|0;o=ZX(b,0)|0;if((o|0)==0){l=-12;i=e;return l|0}a:do{if((m|0)>0){n=b+28|0;q=o+64|0;r=k;s=o+8|0;t=h+88|0;u=k+8|0;v=0;w=0;x=p;y=m;b:while(1){if((jD(h)|0)!=0){l=-5;z=64;break}A=FD(h)|0;B=JD(h)|0;C=(B|0)<0?2147483647:B;B=y-8-C|0;c:do{if((A|0)==1296912195){D=c[j>>2]|0;E=c[g>>2]|0;F=c[(c[c[n>>2]>>2]|0)+8>>2]|0;H=(C&1)+C|0;c[F+8>>2]=1;I=F+416|0;c[I>>2]=HD(E)|0;J=JD(E)|0;K=F+792|0;c[K>>2]=HD(E)|0;L=HD(E)|0;M=OD(E)|0;N=F+412|0;c[N>>2]=~~+Jqc(+(M>>>0)+ +(G>>>0)*4294967296.0,L-16446|0);L=H-18|0;do{if((x|0)==-1568648896){M=FD(E)|0;c[F+52>>2]=M;O=JX(1411792,M)|0;c[F+48>>2]=O;M=H-22|0;if((O|0)==69632){c[F+432>>2]=(c[I>>2]|0)*34|0}else if((O|0)==65556|(O|0)==65558|(O|0)==65536|(O|0)==65543|(O|0)==65542){c[D+8>>2]=1}else if((O|0)==86025){c[F+432>>2]=c[I>>2]<<1}else if((O|0)==909260615){c[K>>2]=5;z=22}else if((O|0)==69660|(O|0)==86026){z=22}else if((O|0)==86034){c[F+432>>2]=33}else if((O|0)==65537){P=M;z=13;break}else{c[D+8>>2]=1}if((z|0)==22){z=0;c[F+432>>2]=c[I>>2]}O=F+432|0;Q=c[O>>2]|0;if((Q|0)<=0){R=M;S=O;break}c[D+8>>2]=B5a(F,Q)|0;R=M;S=O}else{P=L;z=13}}while(0);if((z|0)==13){z=0;L=c[K>>2]|0;do{if((L|0)<9){T=65540}else{if((L|0)<17){T=65537;break}if((L|0)<25){T=65549;break}T=(L|0)<33?65545:0}}while(0);c[F+48>>2]=T;c[K>>2]=g5a(T)|0;c[D+8>>2]=1;R=P;S=F+432|0}L=c[S>>2]|0;if((L|0)==0){H=g5a(c[F+48>>2]|0)|0;O=(ca(c[I>>2]|0,H)|0)>>3;c[S>>2]=O;U=O}else{U=L}L=c[D+8>>2]|0;if((L|0)!=0){c[F+72>>2]=(ca(U<<3,c[N>>2]|0)|0)/(L|0)|0}if((R|0)!=0){hD(E,R,(R|0)<0|0?-1:0)|0;}c[q>>2]=J;c[q+4>>2]=0;L=0;if((v|0)>(L|0)|(v|0)==(L|0)&w>>>0>0>>>0){V=v;W=w;X=s;break a}else{Y=x;Z=v;_=w}}else if((A|0)==1380275782){Y=JD(h)|0;Z=v;_=w}else if((A|0)==1330531905){e$(b,2209080,C);Y=x;Z=v;_=w}else if((A|0)==1145983827){L=fD(h,0,0,1)|0;O=wrc(L,G,C,(C|0)<0|0?-1:0)|0;c[r>>2]=O;c[r+4>>2]=G;O=JD(h)|0;JD(h)|0;L=fD(h,0,0,1)|0;H=wrc(L,G,O,0)|0;O=G;L=(c[t>>2]|0)==0;if((c[(c[s>>2]|0)+432>>2]|0)==0){if(L){z=47;break b}}else{if(L){V=O;W=H;X=s;break a}}L=C-8|0;hD(h,L,(L|0)<0|0?-1:0)|0;Y=x;Z=O;_=H}else if((A|0)==540230729){H=fD(h,0,0,1)|0;O=G;MI(b,2460440,f);if((c[f>>2]|0)!=0){$=PI(b,f)|0;if(($|0)<0){z=36;break b}}NI(f);L=wrc(H,O,C,(C|0)<0|0?-1:0)|0;O=G;H=fD(h,0,0,1)|0;M=G;if(!((O|0)>(M|0)|(O|0)==(M|0)&L>>>0>H>>>0)){Y=x;Z=v;_=w;break}H=fD(h,0,0,1)|0;M=xrc(L,O,H,G)|0;hD(h,M,G)|0;Y=x;Z=v;_=w}else if((A|0)==1312901187){if((LM(b,h,o,C,(C|0)<0|0?-1:0)|0)<0){l=-1094995529;z=64;break b}else{Y=x;Z=v;_=w}}else if((A|0)==1162690894){e$(b,2369720,C);Y=x;Z=v;_=w}else if((A|0)==1213486401){e$(b,2303592,C);Y=x;Z=v;_=w}else if((A|0)==539583272){e$(b,2252104,C);Y=x;Z=v;_=w}else if((A|0)==1702257015){if(C>>>0>1073741824>>>0){l=-1;z=64;break b}if((QX(c[s>>2]|0,h,C)|0)<0){l=-12;z=64;break b}M=c[s>>2]|0;H=c[M+48>>2]|0;do{if((H|0)==86035&(C|0)>47){O=M+432|0;if((c[O>>2]|0)!=0){break}L=c[M+96>>2]|0;Q=L+44|0;c[O>>2]=je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Q=L+36|0;c[u>>2]=je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Y=x;Z=v;_=w;break c}}while(0);if((H|0)!=86040){Y=x;Z=v;_=w;break}if((C|0)>24){aa=(a[(c[M+96>>2]|0)+24|0]|0)==72?17:35}else{aa=35}c[M+432>>2]=aa;c[u>>2]=160;J=c[s>>2]|0;c[J+72>>2]=(ca(c[J+412>>2]<<3,c[J+432>>2]|0)|0)/160|0;Y=x;Z=v;_=w}else{J=(C&1)+C|0;hD(h,J,(J|0)<0|0?-1:0)|0;Y=x;Z=v;_=w}}while(0);if((B|0)>0){v=Z;w=_;x=Y;y=B}else{V=Z;W=_;X=s;break a}}if((z|0)==36){NI(f);l=$;i=e;return l|0}else if((z|0)==47){KIb(b,16,2176464,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;l=-1;i=e;return l|0}else if((z|0)==64){i=e;return l|0}}else{V=0;W=0;X=o+8|0}}while(0);z=c[X>>2]|0;if((c[z+432>>2]|0)==0){KIb(b,16,2148512,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;l=-1;i=e;return l|0}else{_X(o,64,1,c[z+412>>2]|0);z=o+48|0;c[z>>2]=0;c[z+4>>2]=0;z=o+64|0;ba=c[k+8>>2]|0;k=Erc(ba,(ba|0)<0|0?-1:0,c[z>>2]|0,c[z+4>>2]|0)|0;z=o+56|0;c[z>>2]=k;c[z+4>>2]=G;fD(h,W,V,0)|0;l=0;i=e;return l|0}return 0}function d$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[c[a+28>>2]>>2]|0;e=c[a+12>>2]|0;f=e;g=c[f>>2]|0;h=c[f+4>>2]|0;f=a+16|0;a=fD(c[f>>2]|0,0,0,1)|0;i=xrc(g,h,a,G)|0;a=G;h=0;if((a|0)<(h|0)|(a|0)==(h|0)&i>>>0<1>>>0){j=-541478725;return j|0}h=d+8|0;d=c[(c[h>>2]|0)+432>>2]|0;if((d|0)>16){k=d}else{k=4096-(4096%(d|0)|0)|0}d=(k|0)<0|0?-1:0;g=(a|0)>(d|0)|(a|0)==(d|0)&i>>>0>k>>>0?k:i;i=fX(c[f>>2]|0,b,g)|0;if((i|0)<0){j=i;return j|0}f=(c[h>>2]|0)+432|0;if((g|0)>=(c[f>>2]|0)){g=b+36|0;c[g>>2]=c[g>>2]&-3}c[b+32>>2]=0;c[b+48>>2]=ca(c[e+8>>2]|0,(i|0)/(c[f>>2]|0)|0)|0;j=0;return j|0}function e$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=hJb(e+1|0)|0;do{if((f|0)==0){g=e&1;h=b+16|0}else{i=b+16|0;j=AD(c[i>>2]|0,f,e)|0;if((j|0)>=0){a[f+j|0]=0;MGb(b+1140|0,d,f,8)|0;g=(e&1)-j|0;h=i;break}kJb(f);return}}while(0);f=g+e|0;hD(c[h>>2]|0,f,(f|0)<0|0?-1:0)|0;return}function f$(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;e=c[a+12>>2]|0;f=a+16|0;g=c[f>>2]|0;j=e+32|0;c[j>>2]=-1;l=a+24|0;m=c[l>>2]|0;do{if((m|0)!=0){n=c[a+28>>2]|0;o=0;p=-1;q=m;while(1){r=c[(c[(c[n+(o<<2)>>2]|0)+8>>2]|0)+8>>2]|0;if((p|0)<0&(r|0)==1){c[j>>2]=o;s=o;t=c[l>>2]|0}else{if((r|0)==0){s=p;t=q}else{u=6;break}}r=o+1|0;if(r>>>0<t>>>0){o=r;p=s;q=t}else{break}}if((u|0)==6){KIb(a,16,2209024,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=b;return w|0}if((s|0)<0){break}q=a+28|0;p=c[(c[(c[q>>2]|0)+(s<<2)>>2]|0)+8>>2]|0;o=p+52|0;n=c[o>>2]|0;if((n|0)==0){w=-1;i=b;return w|0}else if((n|0)==1162760014){x=0}else{x=1}kD(g,1297239878);n=fD(g,0,0,1)|0;r=e+8|0;c[r>>2]=n;c[r+4>>2]=G;lD(g,0);r=x?2124528:2642744;kD(g,(d[r+1|0]|0)<<8|(d[r]|0)|(d[r+2|0]|0)<<16|(d[r+3|0]|0)<<24);do{if(x){if((c[p+432>>2]|0)!=0){kD(g,1380275782);lD(g,4);lD(g,-1568648896);break}KIb(a,16,2619304,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=b;return w|0}}while(0);r=p+416|0;do{if((c[r>>2]|0)>2){n=p+448|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){break}kD(g,1312901187);lD(g,12);KJ(g,c[n>>2]|0,c[n+4>>2]|0)}}while(0);n=a+1140|0;i$(c[f>>2]|0,c[n>>2]|0,2551664,1162690894);i$(c[f>>2]|0,c[n>>2]|0,2533464,1213486401);i$(c[f>>2]|0,c[n>>2]|0,2518016,539583272);i$(c[f>>2]|0,c[n>>2]|0,2504056,1330531905);kD(g,1296912195);lD(g,x?24:18);tD(g,c[r>>2]|0);n=fD(g,0,0,1)|0;y=e+16|0;c[y>>2]=n;c[y+4>>2]=G;lD(g,0);y=p+792|0;n=c[y>>2]|0;do{if((n|0)==0){z=g5a(c[p+48>>2]|0)|0;c[y>>2]=z;if((z|0)!=0){A=z;break}KIb(a,16,2479704,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=b;return w|0}else{A=n}}while(0);n=p+432|0;if((c[n>>2]|0)==0){c[n>>2]=(ca(c[r>>2]|0,A)|0)>>3}tD(g,A);h[k>>3]=+(c[p+412>>2]|0);n=c[k>>2]|0;y=c[k+4>>2]|0;z=wrc(y>>>20|0<<12,0>>>20|0<<12,15360,0)|0;tD(g,z);sD(g,n<<11|0>>>21|0,y<<11|n>>>21|-2147483648);if(x){kD(g,c[o>>2]|0);tD(g,0)}do{if((c[o>>2]|0)==843924561){n=p+100|0;if((c[n>>2]|0)==0){break}kD(g,1702257015);lD(g,c[n>>2]|0);dD(g,c[p+96>>2]|0,c[n>>2]|0)}}while(0);kD(g,1145983827);p=fD(g,0,0,1)|0;o=e+24|0;c[o>>2]=p;c[o+4>>2]=G;lD(g,0);lD(g,0);lD(g,0);o=c[(c[q>>2]|0)+(c[j>>2]<<2)>>2]|0;_X(o,64,1,c[(c[o+8>>2]|0)+412>>2]|0);eD(g);w=0;i=b;return w|0}}while(0);KIb(a,16,2176432,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=b;return w|0}function g$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=b+32|0;h=c[g>>2]|0;if((h|0)==(c[f+32>>2]|0)){dD(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);j=0;i=d;return j|0}k=a+28|0;l=c[(c[k>>2]|0)+(h<<2)>>2]|0;if((c[(c[l+8>>2]|0)+8>>2]|0)!=0){j=0;i=d;return j|0}m=l+64|0;l=c[m>>2]|0;n=c[m+4>>2]|0;if((l|0)==1&(n|0)==0){KIb(a,24,2252048,(a=i,i=i+8|0,c[a>>2]=h,a)|0);i=a;a=(c[(c[k>>2]|0)+(c[g>>2]<<2)>>2]|0)+64|0;o=c[a+4>>2]|0;p=c[a>>2]|0}else{o=n;p=l}l=0;if((o|0)>(l|0)|(o|0)==(l|0)&p>>>0>0>>>0){j=0;i=d;return j|0}p=pJb(88)|0;l=p;c[e>>2]=l;if((p|0)==0){j=-12;i=d;return j|0}o=S1(p,b)|0;if((o|0)<0){mJb(e);j=o;i=d;return j|0}o=f+36|0;f=c[o>>2]|0;if((f|0)==0){c[o>>2]=l;j=0;i=d;return j|0}else{q=f}do{r=q+80|0;q=c[r>>2]|0;}while((q|0)!=0);c[r>>2]=l;j=0;i=d;return j|0}function h$(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+32|0;d=b|0;e=b+24|0;f=a+16|0;g=c[f>>2]|0;h=c[a+12>>2]|0;j=h+36|0;c[e>>2]=c[j>>2];k=c[(c[(c[a+28>>2]|0)+(c[h+32>>2]<<2)>>2]|0)+8>>2]|0;l=fD(g,0,0,1)|0;m=G;if((l&1|0)==0&(m&0|0)==0){n=m;o=l}else{bD(g,0);p=wrc(l,m,1,0)|0;n=G;o=p}if((c[(c[f>>2]|0)+88>>2]|0)!=0){p=h+16|0;fD(g,c[p>>2]|0,c[p+4>>2]|0,0)|0;p=h+24|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=wrc(l,m,-12,-1)|0;t=xrc(s,G,q,r)|0;r=c[k+432>>2]|0;k=Crc(t,G,r,(r|0)<0|0?-1:0)|0;lD(g,k);fD(g,c[p>>2]|0,c[p+4>>2]|0,0)|0;k=c[p>>2]|0;r=c[p+4>>2]|0;p=wrc(l,m,-4,0)|0;m=xrc(p,G,k,r)|0;lD(g,m);fD(g,o,n,0)|0;do{if((c[h+40>>2]|0)!=0){n=d;c[n>>2]=c[174120];c[n+4>>2]=c[174121];c[n+8>>2]=c[174122];c[n+12>>2]=c[174123];c[n+16>>2]=c[174124];c[n+20>>2]=c[174125];n=c[f>>2]|0;o=c[j>>2]|0;if((c[n+88>>2]|0)==0){break}m=(o|0)==0;if((c[a+1140>>2]|0)==0&m){break}kD(n,540230729);lD(n,0);r=fD(n,0,0,1)|0;k=G;B$(d,n,c[h+44>>2]|0,2303584);C$(a,d)|0;a:do{if(!m){p=o;while(1){l=E$(a,d,p|0)|0;if((l|0)<0){u=l;break}p=c[p+80>>2]|0;if((p|0)==0){break a}}i=b;return u|0}}while(0);F$(d,n,c[a+1316>>2]|0);o=fD(n,0,0,1)|0;m=G;p=xrc(o,m,r,k)|0;l=G;t=wrc(r,k,-4,-1)|0;fD(n,t,G,0)|0;lD(n,p);fD(n,o,m,0)|0;if((p&1|0)==0&(l&0|0)==0){break}bD(n,0)}}while(0);a=fD(g,0,0,1)|0;d=G;j=h+8|0;fD(g,c[j>>2]|0,c[j+4>>2]|0,0)|0;h=c[j>>2]|0;f=c[j+4>>2]|0;j=wrc(a,d,-4,0)|0;d=xrc(j,G,h,f)|0;lD(g,d);eD(g)}g=c[e>>2]|0;if((g|0)==0){u=0;i=b;return u|0}d=e;f=g;while(1){g=c[f+80>>2]|0;P1(f|0);mJb(d);c[e>>2]=g;if((g|0)==0){u=0;break}else{f=g}}i=b;return u|0}function i$(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=LGb(b,d,0,0)|0;if((f|0)==0){return}d=f+4|0;f=lrc(c[d>>2]|0)|0;kD(a,e);lD(a,f+1&-2);dD(a,c[d>>2]|0,f);if((f&1|0)==0){return}bD(a,0);return}function j$(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;g=i;i=i+728|0;h=g|0;j=g+392|0;k=g+656|0;l=g+720|0;m=f>>3;n=k;mrc(n|0,0,64)|0;if((f|0)<16){if((f|0)>0){o=0}else{i=g;return}do{p=e+o|0;a[p]=a[p]^a[b+o|0];o=o+1|0;}while((o|0)<(f|0));i=g;return}DKb(j,b,96,1)|0;EKb(j,n,0,64,0,1);o=c[k>>2]|1;p=c[n+4>>2]|1;q=c[k+8>>2]|1;r=c[n+12>>2]|1;s=c[k+16>>2]|1;t=c[n+20>>2]|1;u=c[k+24>>2]|1;v=c[n+28>>2]|1;w=c[k+32>>2]|1;x=c[n+36>>2]|1;z=c[k+40>>2]|1;A=c[n+44>>2]|1;n=e+((m<<3)-8)|0;B=n|0;C=n+4|0;n=k+56|0;D=c[n+4>>2]^(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24);c[l>>2]=c[n>>2]^(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24);c[l+4>>2]=D;FGb(h,b+12|0,64,1)|0;b=l;GGb(h,b,b,1,0,1);h=k+48|0;k=c[l+4>>2]^c[h+4>>2];c[l>>2]=c[l>>2]^c[h>>2];c[l+4>>2]=k;DKb(j,b,64,1)|0;EKb(j,e,e,f,0,1);f=m-1|0;if((f|0)>0){j=(m<<3)-8|0;m=e;b=0;k=0;h=0;while(1){D=m;B=D|0;n=D+4|0;D=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=wrc(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0,D,k,b)|0;B=ca(n,o)|0;n=ca(B>>>16|B<<16,p)|0;B=ca(n>>>16|n<<16,q)|0;n=ca(B>>>16|B<<16,r)|0;B=(ca(n>>>16|n<<16,s)|0)+t|0;n=wrc(B,0,b,0)|0;C=ca(B+D|0,u)|0;D=ca(C>>>16|C<<16,v)|0;C=ca(D>>>16|D<<16,w)|0;D=ca(C>>>16|C<<16,x)|0;C=(ca(D>>>16|D<<16,z)|0)+A|0;E=C|0;F=C+n|0;n=h+1|0;if((n|0)<(f|0)){m=m+8|0;b=F;k=E;h=n}else{break}}H=e+j|0;I=F;J=E}else{H=e;I=0;J=0}e=ca(ca(o,o)|0,o)|0;E=ca(2-(ca(e,o)|0)|0,e)|0;e=ca(2-(ca(E,o)|0)|0,E)|0;E=ca(2-(ca(e,o)|0)|0,e)|0;e=ca(ca(p,p)|0,p)|0;o=ca(2-(ca(e,p)|0)|0,e)|0;e=ca(2-(ca(o,p)|0)|0,o)|0;o=ca(2-(ca(e,p)|0)|0,e)|0;e=ca(ca(q,q)|0,q)|0;p=ca(2-(ca(e,q)|0)|0,e)|0;e=ca(2-(ca(p,q)|0)|0,p)|0;p=ca(2-(ca(e,q)|0)|0,e)|0;e=ca(ca(r,r)|0,r)|0;q=ca(2-(ca(e,r)|0)|0,e)|0;e=ca(2-(ca(q,r)|0)|0,q)|0;q=ca(2-(ca(e,r)|0)|0,e)|0;e=ca(ca(s,s)|0,s)|0;r=ca(2-(ca(e,s)|0)|0,e)|0;e=ca(2-(ca(r,s)|0)|0,r)|0;r=ca(2-(ca(e,s)|0)|0,e)|0;e=ca(ca(u,u)|0,u)|0;s=ca(2-(ca(e,u)|0)|0,e)|0;e=ca(2-(ca(s,u)|0)|0,s)|0;s=ca(2-(ca(e,u)|0)|0,e)|0;e=ca(ca(v,v)|0,v)|0;u=ca(2-(ca(e,v)|0)|0,e)|0;e=ca(2-(ca(u,v)|0)|0,u)|0;u=ca(2-(ca(e,v)|0)|0,e)|0;e=ca(ca(w,w)|0,w)|0;v=ca(2-(ca(e,w)|0)|0,e)|0;e=ca(2-(ca(v,w)|0)|0,v)|0;v=ca(2-(ca(e,w)|0)|0,e)|0;e=ca(ca(x,x)|0,x)|0;w=ca(2-(ca(e,x)|0)|0,e)|0;e=ca(2-(ca(w,x)|0)|0,w)|0;w=ca(2-(ca(e,x)|0)|0,e)|0;e=ca(ca(z,z)|0,z)|0;x=ca(2-(ca(e,z)|0)|0,e)|0;e=ca(2-(ca(x,z)|0)|0,x)|0;x=ca(2-(ca(e,z)|0)|0,e)|0;e=c[l+4>>2]|0;z=ca(x,e-A|0)|0;A=ca(w,z>>>16|z<<16)|0;z=ca(v,A>>>16|A<<16)|0;A=ca(u,z>>>16|z<<16)|0;z=ca(s,A>>>16|A<<16)|0;A=xrc((c[l>>2]|0)-e|0,0,I,0)|0;e=A;A=ca(r,e-t|0)|0;t=ca(q,A>>>16|A<<16)|0;A=ca(p,t>>>16|t<<16)|0;t=ca(o,A>>>16|A<<16)|0;A=xrc(ca(E,t>>>16|t<<16)|0,0,J,I)|0;I=A|0|0;A=G&0|z-e;c[l>>2]=I;c[l+4>>2]=A;l=H;H=l|0;y=I;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=l+4|0;y=A;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;i=g;return}function k$(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+24|0;d=c[b>>2]|0;if((d|0)==0){return}e=a+28|0;a=0;f=d;while(1){d=c[(c[e>>2]|0)+(a<<2)>>2]|0;if((c[(c[d+8>>2]|0)+8>>2]|0)==1){eHb(c[c[d+12>>2]>>2]|0);g=c[b>>2]|0}else{g=f}d=a+1|0;if(d>>>0<g>>>0){a=d;f=g}else{break}}return}function l$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=d;d=i;i=i+8|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];if((b|0)==0){g=-1;i=e;return g|0}if((c[d>>2]|0)==0){KIb(a,16,2606944,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1;i=e;return g|0}f=a+24|0;j=c[f>>2]|0;if((j|0)==0){g=0;i=e;return g|0}k=a+28|0;l=d;d=0;m=j;while(1){j=c[(c[k>>2]|0)+(d<<2)>>2]|0;n=c[j+12>>2]|0;o=c[j+8>>2]|0;if((c[o+8>>2]|0)==1){j=c[o+416>>2]|0;p=ca(g5a(c[o+48>>2]|0)|0,j)|0;c[n+16>>2]=(p|0)/8|0;if(!((p+7|0)>>>0>14>>>0)){break}c[n+20>>2]=b;c[n+24>>2]=b;p=n+28|0;j=c[l+4>>2]|0;c[p>>2]=c[l>>2];c[p+4>>2]=j;c[n+4>>2]=(c[b>>2]|0)*100|0;c[n>>2]=dHb((c[b>>2]|0)*100|0)|0;q=c[f>>2]|0}else{q=m}n=d+1|0;if(n>>>0<q>>>0){d=n;m=q}else{g=0;r=11;break}}if((r|0)==11){i=e;return g|0}KIb(a,16,2617632,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1;i=e;return g|0}function m$(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;i=i+80|0;j=h|0;do{if((d|0)!=0){k=c[(c[a+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0;l=c[k+12>>2]|0;if((c[(c[k+8>>2]|0)+8>>2]|0)!=1){k=l+8|0;m=c[k>>2]|0;n=c[k+4>>2]|0;o=d+16|0;c[o>>2]=m;c[o+4>>2]=n;o=d+8|0;c[o>>2]=m;c[o+4>>2]=n;n=c[d+48>>2]|0;o=wrc(c[k>>2]|0,c[k+4>>2]|0,n,(n|0)<0|0?-1:0)|0;c[k>>2]=o;c[k+4>>2]=G;k=XO(a,d,g)|0;if((k|0)<0){p=k}else{break}i=h;return p|0}k=l;o=fHb(c[k>>2]|0)|0;n=d+28|0;m=c[n>>2]|0;q=m+o|0;o=l+4|0;do{if(q>>>0>(c[o>>2]|0)>>>0){if((hHb(c[k>>2]|0,q)|0)<0){p=-1;i=h;return p|0}else{c[o>>2]=q;r=c[n>>2]|0;break}}else{r=m}}while(0);jHb(c[k>>2]|0,c[d+24>>2]|0,r,0)|0}}while(0);r=a+24|0;a:do{if((c[r>>2]|0)!=0){d=a+28|0;m=(e|0)==0;n=j+24|0;q=j+8|0;o=j+16|0;l=j+48|0;s=j+32|0;t=0;b:while(1){u=c[(c[d>>2]|0)+(t<<2)>>2]|0;c:do{if((c[(c[u+8>>2]|0)+8>>2]|0)==1){d:do{if(m){v=u;while(1){w=c[v+12>>2]|0;x=w;y=fHb(c[x>>2]|0)|0;z=w+24|0;A=ca(c[w+16>>2]|0,c[c[z>>2]>>2]|0)|0;if((y|0)>(A|0)){B=A}else{B=fHb(c[x>>2]|0)|0}if((B|0)==0){break c}if((B|0)==(fHb(c[x>>2]|0)|0)){break c}if((K1(j,B)|0)<0){p=-12;C=34;break b}iHb(c[x>>2]|0,c[n>>2]|0,B,0)|0;x=w+8|0;A=c[x>>2]|0;y=c[x+4>>2]|0;c[q>>2]=A;c[q+4>>2]=y;c[o>>2]=A;c[o+4>>2]=y;y=c[c[z>>2]>>2]|0;A=XIb(y,(y|0)<0|0?-1:0,v+40|0,w+28|0)|0;y=A;c[l>>2]=y;c[s>>2]=t;A=wrc(y,(y|0)<0|0?-1:0,c[x>>2]|0,c[x+4>>2]|0)|0;c[x>>2]=A;c[x+4>>2]=G;x=(c[z>>2]|0)+4|0;c[z>>2]=x;if((c[x>>2]|0)==0){c[z>>2]=c[w+20>>2]}if((B|0)<=0){D=B;break d}w=XO(a,j,g)|0;if((w|0)<0){p=w;C=34;break b}v=c[(c[d>>2]|0)+(t<<2)>>2]|0}}else{v=u;while(1){w=c[v+12>>2]|0;z=w;x=fHb(c[z>>2]|0)|0;A=w+24|0;y=ca(c[w+16>>2]|0,c[c[A>>2]>>2]|0)|0;if((x|0)>(y|0)){E=y}else{E=fHb(c[z>>2]|0)|0}if((E|0)==0){break c}if((K1(j,E)|0)<0){p=-12;C=34;break b}iHb(c[z>>2]|0,c[n>>2]|0,E,0)|0;z=w+8|0;y=c[z>>2]|0;x=c[z+4>>2]|0;c[q>>2]=y;c[q+4>>2]=x;c[o>>2]=y;c[o+4>>2]=x;x=c[c[A>>2]>>2]|0;y=XIb(x,(x|0)<0|0?-1:0,v+40|0,w+28|0)|0;x=y;c[l>>2]=x;c[s>>2]=t;y=wrc(x,(x|0)<0|0?-1:0,c[z>>2]|0,c[z+4>>2]|0)|0;c[z>>2]=y;c[z+4>>2]=G;z=(c[A>>2]|0)+4|0;c[A>>2]=z;if((c[z>>2]|0)==0){c[A>>2]=c[w+20>>2]}if((E|0)<=0){D=E;break d}w=XO(a,j,g)|0;if((w|0)<0){p=w;C=34;break b}v=c[(c[d>>2]|0)+(t<<2)>>2]|0}}}while(0);if((D|0)<0){p=D;C=34;break b}}}while(0);t=t+1|0;if(!(t>>>0<(c[r>>2]|0)>>>0)){break a}}if((C|0)==34){i=h;return p|0}}}while(0);p=hf[f&1023](a,b,0,e)|0;i=h;return p|0}function n$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+(4-(b&3))|0;f=d-3|0;a:do{if(f>>>0>b>>>0){g=b;while(1){h=g+1|0;do{if((a[g]|0)==0){if((a[h]|0)!=0){break}if((a[g+2|0]|0)==1){i=g;break a}}}while(0);if(h>>>0<e>>>0&h>>>0<f>>>0){g=h}else{j=h;k=6;break}}}else{j=b;k=6}}while(0);b:do{if((k|0)==6){e=d-6|0;if(j>>>0<e>>>0){g=j;while(1){l=c[g>>2]|0;m=l&255;do{if(((l&-2139062144^-2139062144)&l-16843009|0)!=0){n=g+1|0;do{if((a[n]|0)==0){o=a[g+2|0]|0;if(m<<24>>24==0&o<<24>>24==1){i=g;break b}if(!(o<<24>>24==0)){break}if((a[g+3|0]|0)==1){i=n;break b}}}while(0);n=g+3|0;if((a[n]|0)!=0){break}o=g+2|0;p=a[g+4|0]|0;if((a[o]|0)==0&p<<24>>24==1){i=o;break b}if(!(p<<24>>24==0)){break}if((a[g+5|0]|0)==1){i=n;break b}}}while(0);m=g+4|0;if(m>>>0<e>>>0){g=m}else{q=m;break}}}else{q=j}if(q>>>0<f>>>0){r=q}else{s=d;return s|0}while(1){g=r+1|0;do{if((a[r]|0)==0){if((a[g]|0)!=0){break}if((a[r+2|0]|0)==1){i=r;break b}}}while(0);if(g>>>0<f>>>0){r=g}else{s=d;break}}return s|0}}while(0);if(i>>>0>b>>>0&i>>>0<d>>>0){d=i-1|0;return((a[d]|0)==0?d:i)|0}else{s=i;return s|0}return 0}function o$(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c+d|0;d=0;f=n$(c,e)|0;while(1){c=f;while(1){if(!(c>>>0<e>>>0)){g=c;break}h=c+1|0;if((a[c]|0)==0){c=h}else{g=h;break}}if((g|0)==(e|0)){break}c=n$(g,e)|0;h=g;i=c-h|0;lD(b,i);dD(b,g,i);d=d-h+(c+4)|0;f=c}return d|0}function p$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+8|0;g=f|0;h=_D(g)|0;if((h|0)<0){j=h;i=f;return j|0}h=c[g>>2]|0;k=b+(c[e>>2]|0)|0;l=n$(b,k)|0;while(1){if(l>>>0<k>>>0){b=l+1|0;if((a[l]|0)==0){l=b;continue}else{m=b}}else{m=l}if((m|0)==(k|0)){break}b=n$(m,k)|0;n=b-m|0;lD(h,n);dD(h,m,n);l=b}mJb(d);c[e>>2]=aE(c[g>>2]|0,d)|0;j=0;i=f;return j|0}function q$(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+16|0;h=g|0;j=g+8|0;c[h>>2]=f;if((f|0)<=6){k=0;i=g;return k|0}l=e;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;do{if((m|0)!=16777216){if(((d[e+1|0]|0)<<8|m<<16&16711680|(d[e+2|0]|0)|0)==1){break}dD(b,e,f);k=0;i=g;return k|0}}while(0);c[j>>2]=0;f=p$(e,j,h)|0;if((f|0)<0){k=f;i=g;return k|0}f=c[j>>2]|0;e=c[h>>2]|0;h=f+e|0;if((e|0)>4){n=0;o=0;p=0;q=0;r=f;s=e}else{k=-1094995529;i=g;return k|0}while(1){e=r;m=je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;e=s-4|0;l=m>>>0>e>>>0?e:m;m=r+4|0;c[j>>2]=m;e=a[m]&31;if(e<<24>>24==7){t=l;u=p;v=o;w=m}else{x=e<<24>>24==8;t=q;u=x?l:p;v=x?m:o;w=n}m=r+(l+4)|0;c[j>>2]=m;l=h-m|0;if((l|0)>4){n=w;o=v;p=u;q=t;r=m;s=l}else{break}}if((w|0)==0|(v|0)==0){k=-1094995529;i=g;return k|0}if((t-4|0)>>>0>65531>>>0|u>>>0>65535>>>0){k=-1094995529;i=g;return k|0}bD(b,1);bD(b,d[w+1|0]|0);bD(b,d[w+2|0]|0);bD(b,d[w+3|0]|0);bD(b,255);bD(b,225);tD(b,t);dD(b,w,t);bD(b,1);tD(b,u);dD(b,v,u);kJb(f);k=0;i=g;return k|0}function r$(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[e>>2]=0;g=c[f>>2]|0;if((g|0)<=3){h=-1094995529;return h|0}i=b;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;if((j|0)==16777216){h=0;return h|0}if(((d[b+1|0]|0)<<8|j<<16&16711680|(d[b+2|0]|0)|0)==1){h=0;return h|0}if(!((g|0)>10&(j&255)<<24>>24==1)){h=-1094995529;return h|0}j=b+6|0;i=(he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;j=i+11|0;if((j|0)>(g|0)){h=-1094995529;return h|0}k=b+(i+9)|0;l=(he((d[k]|d[k+1|0]<<8)<<16>>16|0)|0)&65535;if((l+j|0)>(g|0)){h=-1094995529;return h|0}g=i+8|0;k=g+l|0;m=pJb(k)|0;if((m|0)==0){h=-12;return h|0}n=m;y=16777216;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;nrc(m+4|0,b+8|0,i)|0;n=m+(i+4)|0;y=16777216;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;nrc(m+g|0,b+j|0,l)|0;c[e>>2]=m;c[f>>2]=k;h=0;return h|0}function s$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+48|0;e=d|0;nrc(e|0,1424480,48)|0;f=(a|0)/86400|0;g=(a|0)%86400|0;c[b+8>>2]=(g|0)/3600|0;c[b+4>>2]=((g|0)%3600|0|0)/60|0;c[b>>2]=(g|0)%60|0;if((a|0)>31622399){a=1970;g=f;while(1){h=(g|0)/366|0;j=h+a|0;k=j-1|0;l=a-1|0;m=((k|0)/-4|0)+g+(h*-365|0)+((k|0)/100|0)+((k|0)/-400|0)+((l|0)/4|0)+((l|0)/-100|0)+((l|0)/400|0)|0;if((m|0)>365){a=j;g=m}else{n=j;o=m;break}}}else{n=1970;o=f}do{if((o|0)==365){if((n&3|0)==0){if(((n|0)%100|0|0)!=0|((n|0)%400|0|0)==0){p=365;q=n;break}}p=0;q=n+1|0}else{p=o;q=n}}while(0);do{if((q&3|0)==0){if(((q|0)%100|0|0)!=0){r=29;break}r=((q|0)%400|0|0)==0?29:28}else{r=28}}while(0);c[e+4>>2]=r;if((p|0)<31){s=p;t=1;u=b+20|0;c[u>>2]=q;v=b+16|0;c[v>>2]=t;w=s+1|0;x=b+12|0;c[x>>2]=w;i=d;return b|0}else{y=p;z=0;A=31}while(1){B=y-A|0;p=z+1|0;r=c[e+(p<<2)>>2]|0;if((B|0)<(r|0)){break}else{y=B;z=p;A=r}}s=B;t=z+2|0;u=b+20|0;c[u>>2]=q;v=b+16|0;c[v>>2]=t;w=s+1|0;x=b+12|0;c[x>>2]=w;i=d;return b|0}function t$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+88|0;g=f|0;h=f+8|0;j=f+72|0;k=f+80|0;c[g>>2]=0;c[j>>2]=0;l=aD(d,e,0,0,0,0,0)|0;c[k>>2]=l;if((l|0)==0){m=-12;i=f;return m|0}e=JD(l)|0;do{if(e>>>0>20>>>0|(e|0)<0){KIb(b,16,2606424,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;if((c[b+1156>>2]&8|0)!=0){o=-1094995529;break}p=0;q=c[k>>2]|0;r=5}else{p=e;q=l;r=5}}while(0);a:do{if((r|0)==5){l=JD(q)|0;do{if((l|0)>=1){e=h|0;if((AD(c[k>>2]|0,e,l>>>0>63>>>0?63:l)|0)!=(l|0)){break}if(!(l>>>0<64>>>0)){KIb(0,0,2459968,(n=i,i=i+24|0,c[n>>2]=2369464,c[n+8>>2]=2303448,c[n+16>>2]=63,n)|0);i=n;Hd();return 0}a[h+l|0]=0;d=1372896;while(1){s=c[d+32>>2]|0;if((s|0)==0){r=13;break}if((krc(d|0,e,64)|0)==0){break}else{d=d+36|0}}if((r|0)==13){KIb(b,16,2251920,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-1094995529;break a}d=JD(c[k>>2]|0)|0;do{if((d|0)>0){t=hJb(d+1|0)|0;c[j>>2]=t;if((t|0)==0){o=-12;break a}if((AD(c[k>>2]|0,t,d)|0)==(d|0)){a[(c[j>>2]|0)+d|0]=0;break}else{KIb(b,16,2208936,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-5;break a}}}while(0);d=JD(c[k>>2]|0)|0;e=JD(c[k>>2]|0)|0;hD(c[k>>2]|0,8,0)|0;t=JD(c[k>>2]|0)|0;if((t|0)<1){KIb(b,16,2176384,(n=i,i=i+8|0,c[n>>2]=t,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-1094995529;break a}u=cGb(t+16|0)|0;c[g>>2]=u;if((u|0)==0){o=-12;break a}v=u+4|0;mrc((c[v>>2]|0)+t|0,0,16)|0;if((AD(c[k>>2]|0,c[v>>2]|0,t)|0)!=(t|0)){KIb(b,16,2148456,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-5;break a}v=ZX(b,0)|0;if((v|0)==0){o=-12;break a}u=v+104|0;J1(u);c[u>>2]=c[g>>2];c[v+128>>2]=c[(c[g>>2]|0)+4>>2];c[v+132>>2]=t;c[v+136>>2]=c[v>>2];t=v+140|0;c[t>>2]=c[t>>2]|1;t=v+72|0;c[t>>2]=c[t>>2]|1024;t=c[v+8>>2]|0;c[t+8>>2]=0;c[t+48>>2]=s;c[t+120>>2]=d;c[t+124>>2]=e;e=v+88|0;MGb(e,2124504,c[1372808+(p<<2)>>2]|0,0)|0;v=c[j>>2]|0;if((v|0)!=0){MGb(e,2642680,v,8)|0}mJb(k);m=0;i=f;return m|0}}while(0);KIb(b,16,2617360,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=(c[b+1156>>2]&8|0)==0?0:-1094995529}}while(0);fGb(g);mJb(j);mJb(k);m=o;i=f;return m|0}function u$(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;i=i+16|0;j=h|0;k=h+8|0;c[j>>2]=e;c[k>>2]=0;do{if((f|0)==0){l=0;m=o$(a,b,e)|0}else{n=p$(b,k,j)|0;if((n|0)<0){l=0;m=n;break}n=c[k>>2]|0;o=c[j>>2]|0;p=n+o|0;if((o|0)>4){q=n;r=0;s=0;t=o}else{l=0;m=0;break}while(1){o=q;n=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=t-4|0;u=n>>>0>o>>>0?o:n;n=q+4|0;if((((d[n]|0)>>>1&63)-32|0)>>>0<3>>>0){v=s+1|0;w=r}else{lD(a,u);dD(a,n,u);v=s;w=r+4+u|0}n=q+(u+4)|0;u=p-n|0;if((u|0)>4){q=n;r=w;s=v;t=u}else{l=v;m=w;break}}}}while(0);kJb(c[k>>2]|0);if((g|0)==0){i=h;return m|0}c[g>>2]=l;i=h;return m|0}function v$(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+8|0;h=g|0;j=_D(h)|0;if((j|0)<0){k=j;i=g;return k|0}j=u$(c[h>>2]|0,a,c[d>>2]|0,e,f)|0;c[d>>2]=aE(c[h>>2]|0,b)|0;k=j;i=g;return k|0}function w$(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0;k=i;i=i+336|0;l=k|0;m=k+256|0;n=k+280|0;o=k+288|0;p=k+296|0;c[n>>2]=h;c[o>>2]=0;q=p|0;mrc(q|0,0,40)|0;a[q]=1;r=p+29|0;a[r]=3;s=p+4|0;c[s>>2]=-1;t=p+8|0;c[t>>2]=-1;c[t+4>>2]=65535;u=p+18|0;b[u>>1]=4097;a:do{if((h|0)<6){v=-1094995529}else{w=a[g]|0;if(w<<24>>24==1){dD(f,g,h);v=0;break}if((d[g+1|0]<<8|(w&255)<<16|d[g+2|0]|0)!=1){w=g;if((d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)!=16777216){v=-1094995529;break}}w=p$(g,o,n)|0;if((w|0)<0){v=w;break}w=c[o>>2]|0;x=c[n>>2]|0;y=w+x|0;b:do{if((x|0)>4){z=m|0;A=m+12|0;B=m+16|0;C=m+4|0;D=m+8|0;E=p+32|0;F=p+30|0;G=j&255;H=p+27|0;I=p+28|0;J=p+21|0;K=p+22|0;L=p+23|0;M=p+20|0;N=E;O=w;P=x;while(1){Q=O;R=je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Q=P-4|0;S=R>>>0>Q>>>0?Q:R;R=O+4|0;switch((d[R]|0)>>>1&63|0){case 32:case 33:case 34:case 39:case 40:{Q=hJb(S)|0;c:do{if((Q|0)==0){T=-12;U=0}else{if((S|0)==0){V=0}else{W=(S|0)==1?1:2;nrc(Q|0,R|0,W)|0;V=W}W=V+2|0;if(W>>>0<S>>>0){X=V;Y=V;Z=W;while(1){W=a[O+(X+4)|0]|0;_=X+1|0;do{if(W<<24>>24==0){if((a[O+(X+5)|0]|0)!=0){$=20;break}if((a[O+(Z+4)|0]|0)!=3){$=20;break}a[Q+Y|0]=0;a[Q+(Y+1)|0]=0;aa=Y+2|0;ba=X+3|0}else{$=20}}while(0);if(($|0)==20){$=0;a[Q+Y|0]=W;aa=Y+1|0;ba=_}ca=ba+2|0;if(ca>>>0<S>>>0){X=ba;Y=aa;Z=ca}else{da=ba;ea=aa;break}}}else{da=V;ea=V}if(da>>>0<S>>>0){nrc(Q+ea|0,O+(da+4)|0,S-da|0)|0;fa=ea+S-da|0}else{fa=ea}Z=fa>>>0>268435455>>>0?-8:fa<<3;Y=Z>>>0>2147483639>>>0;X=Y?0:Q;ca=Y?0:Z;c[z>>2]=X;c[A>>2]=ca;Z=ca+8|0;c[B>>2]=Z;c[C>>2]=X+(ca>>3);c[D>>2]=0;if(Y){T=Y?-1094995529:0;U=Q;break}Y=Z>>>0>1>>>0?1:Z;ca=X+(Y>>>3)|0;X=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(Y&1)>>>26;ca=Y|6;Y=X&255;ga=(Z>>>0>ca>>>0?ca:Z)+9|0;c[D>>2]=Z>>>0>ga>>>0?ga:Z;switch(X|0){case 32:case 33:case 34:case 39:case 40:{break};default:{T=-1094995529;U=Q;break c}}X=a[F]|0;Z=c[E>>2]|0;ga=0;while(1){ha=ga&255;if(!((ga&255)>>>0<(X&255)>>>0)){$=27;break}if((a[Z+(ha*12|0)+1|0]|0)==Y<<24>>24){ia=Z;break}else{ga=ga+1&255}}if(($|0)==27){$=0;Z=ha+1|0;X=oJb(N,Z,12)|0;if((X|0)<0){T=X;U=Q;break}X=a[F]|0;if(!((X&255)>>>0>(ga&255)>>>0)){ca=X;do{mrc((c[E>>2]|0)+((ca&255)*12|0)|0,0,12)|0;ca=ca+1&255;}while(!((ca&255)>>>0>(ga&255)>>>0))}a[F]=Z;ia=c[E>>2]|0}ga=ia+(ha*12|0)+2|0;ca=ia+(ha*12|0)+8|0;X=e[ga>>1]|0;ja=X+1|0;ka=oJb(ca,ja,4)|0;if((ka|0)<0){T=ka;U=Q;break}ka=ia+(ha*12|0)+4|0;la=oJb(ka,ja,2)|0;if((la|0)<0){T=la;U=Q;break}c[(c[ca>>2]|0)+(X<<2)>>2]=R;b[(c[ka>>2]|0)+(X<<1)>>1]=S;a[ia+(ha*12|0)+1|0]=Y;b[ga>>1]=(b[ga>>1]|0)+1;if((Y-32&255)>>>0<3>>>0){a[ia+(ha*12|0)|0]=G}if((Y<<24>>24|0)==34){x$(m)|0;x$(m)|0;ga=c[B>>2]|0;X=(c[D>>2]|0)+7|0;c[D>>2]=ga>>>0>X>>>0?X:ga;x$(m)|0;x$(m)|0;x$(m)|0;ga=c[B>>2]|0;X=(c[D>>2]|0)+2|0;ka=ga>>>0>X>>>0?X:ga;c[D>>2]=ka;X=d[(c[z>>2]|0)+(ka>>>3)|0]|0;c[D>>2]=((ka|0)<(ga|0))+ka;if((128>>>((ka&7)>>>0)&X|0)!=0){x$(m)|0}x$(m)|0;x$(m)|0;X=c[B>>2]|0;ka=(c[D>>2]|0)+3|0;ga=X>>>0>ka>>>0?ka:X;c[D>>2]=ga;ka=c[z>>2]|0;ca=d[ka+(ga>>>3)|0]<<(ga&7)>>>7;la=((ga|0)<(X|0))+ga|0;c[D>>2]=la;ga=ca&1;ca=d[ka+(la>>>3)|0]<<(la&7)>>>7;c[D>>2]=((la|0)<(X|0))+la;if((ca&ga|0)!=0){a[M]=0;T=0;U=Q;break}if((ca&1|0)!=0){a[M]=3;T=0;U=Q;break}if((ga|0)==0){a[M]=1;T=0;U=Q;break}else{a[M]=2;T=0;U=Q;break}}else if((Y<<24>>24|0)==32){ga=c[B>>2]|0;ca=(c[D>>2]|0)+12|0;la=ga>>>0>ca>>>0?ca:ga;c[D>>2]=la;ca=(c[z>>2]|0)+(la>>>3)|0;X=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(la&7)>>>29;ca=la+3|0;la=a[H]|0;ka=X+1|0;a[H]=(la&255)>>>0>ka>>>0?la:ka&255;ka=(ga>>>0>ca>>>0?ca:ga)+17|0;c[D>>2]=ga>>>0>ka>>>0?ka:ga;y$(m,p,X);T=0;U=Q;break}else if((Y<<24>>24|0)==33){X=c[B>>2]|0;ga=(c[D>>2]|0)+4|0;ka=X>>>0>ga>>>0?ga:X;c[D>>2]=ka;ga=c[z>>2]|0;ca=ga+(ka>>>3)|0;la=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(ka&7)>>>29;ca=ka+3|0;ka=X>>>0>ca>>>0?ca:X;c[D>>2]=ka;ca=a[H]|0;ja=la+1|0;a[H]=(ca&255)>>>0>ja>>>0?ca:ja&255;ja=d[ga+(ka>>>3)|0]<<(ka&7)>>>7;c[D>>2]=((ka|0)<(X|0))+ka;a[I]=ja&1;y$(m,p,la);x$(m)|0;ja=x$(m)|0;a[J]=ja;if((ja&255|0)==3){ja=c[B>>2]|0;ka=(c[D>>2]|0)+1|0;c[D>>2]=ja>>>0>ka>>>0?ka:ja}x$(m)|0;x$(m)|0;ja=c[D>>2]|0;ka=d[(c[z>>2]|0)+(ja>>>3)|0]|0;c[D>>2]=((ja|0)<(c[B>>2]|0))+ja;if((ka&128>>>((ja&7)>>>0)|0)!=0){x$(m)|0;x$(m)|0;x$(m)|0;x$(m)|0}a[K]=x$(m)|0;a[L]=x$(m)|0;ja=x$(m)|0;ka=c[D>>2]|0;X=d[(c[z>>2]|0)+(ka>>>3)|0]|0;c[D>>2]=((ka|0)<(c[B>>2]|0))+ka;ga=(X&128>>>((ka&7)>>>0)|0)!=0?0:la;do{x$(m)|0;x$(m)|0;x$(m)|0;ga=ga+1|0;}while(!(ga>>>0>la>>>0));x$(m)|0;x$(m)|0;x$(m)|0;x$(m)|0;x$(m)|0;x$(m)|0;ga=c[D>>2]|0;Y=c[z>>2]|0;Z=d[Y+(ga>>>3)|0]|0;ka=c[B>>2]|0;X=((ga|0)<(ka|0))+ga|0;c[D>>2]=X;do{if((Z&128>>>((ga&7)>>>0)|0)==0){ma=X;na=ka;oa=Y}else{ca=d[Y+(X>>>3)|0]|0;pa=((X|0)<(ka|0))+X|0;c[D>>2]=pa;if((ca&128>>>((X&7)>>>0)|0)==0){ma=pa;na=ka;oa=Y;break}else{qa=0}do{pa=(qa|0)==3?2:6;ca=1<<(qa<<1)+4;ra=(ca|0)<64?ca:64;ca=(ra|0)>0;d:do{if((qa|0)>1){sa=ca^1;ta=1;while(1){ua=c[D>>2]|0;va=d[(c[z>>2]|0)+(ua>>>3)|0]|0;c[D>>2]=((ua|0)<(c[B>>2]|0))+ua;x$(m)|0;if(!((va&128>>>((ua&7)>>>0)|0)==0|sa)){ua=0;do{x$(m)|0;ua=ua+1|0;}while((ua|0)<(ra|0))}if((ta|0)>=(pa|0)){break d}ta=ta+1|0}}else{if(ca){wa=1}else{ta=1;while(1){sa=c[D>>2]|0;ua=d[(c[z>>2]|0)+(sa>>>3)|0]|0;c[D>>2]=((sa|0)<(c[B>>2]|0))+sa;if((ua&128>>>((sa&7)>>>0)|0)==0){x$(m)|0}if((ta|0)>=(pa|0)){break d}ta=ta+1|0}}while(1){ta=c[D>>2]|0;sa=d[(c[z>>2]|0)+(ta>>>3)|0]|0;c[D>>2]=((ta|0)<(c[B>>2]|0))+ta;if((sa&128>>>((ta&7)>>>0)|0)==0){x$(m)|0}else{ta=0;do{x$(m)|0;ta=ta+1|0;}while((ta|0)<(ra|0))}if((wa|0)>=(pa|0)){break d}wa=wa+1|0}}}while(0);qa=qa+1|0;}while((qa|0)<4);ma=c[D>>2]|0;na=c[B>>2]|0;oa=c[z>>2]|0}}while(0);Y=ma+1|0;ka=(na>>>0>Y>>>0?Y:na)+1|0;Y=na>>>0>ka>>>0?ka:na;c[D>>2]=Y;ka=d[oa+(Y>>>3)|0]|0;X=((Y|0)<(na|0))+Y|0;c[D>>2]=X;if((128>>>((Y&7)>>>0)&ka|0)!=0){ka=X+4|0;X=(na>>>0>ka>>>0?ka:na)+4|0;c[D>>2]=na>>>0>X>>>0?X:na;x$(m)|0;x$(m)|0;X=c[B>>2]|0;ka=(c[D>>2]|0)+1|0;c[D>>2]=X>>>0>ka>>>0?ka:X}X=x$(m)|0;if(X>>>0>64>>>0){T=-1094995529;U=Q;break}if((X|0)!=0){ka=0;do{do{if((ka|0)==0){$=75}else{Y=c[D>>2]|0;ga=d[(c[z>>2]|0)+(Y>>>3)|0]|0;Z=c[B>>2]|0;_=((Y|0)<(Z|0))+Y|0;c[D>>2]=_;if((ga&128>>>((Y&7)>>>0)|0)==0){$=75;break}Y=_+1|0;c[D>>2]=Z>>>0>Y>>>0?Y:Z;x$(m)|0;Z=l+(ka<<2)|0;c[Z>>2]=0;Y=c[l+(ka-1<<2)>>2]|0;if((Y|0)==0){break}_=c[z>>2]|0;ga=c[B>>2]|0;W=1;pa=c[D>>2]|0;ra=0;while(1){ca=d[_+(pa>>>3)|0]|0;ta=((pa|0)<(ga|0))+pa|0;c[D>>2]=ta;if((ca&128>>>((pa&7)>>>0)|0)==0){ca=d[_+(ta>>>3)|0]|0;sa=((ta|0)<(ga|0))+ta|0;c[D>>2]=sa;if((ca&128>>>((ta&7)>>>0)|0)==0){xa=sa;ya=ra}else{za=sa;$=73}}else{za=ta;$=73}if(($|0)==73){$=0;ta=ra+1|0;c[Z>>2]=ta;xa=za;ya=ta}if(W>>>0<Y>>>0){W=W+1|0;pa=xa;ra=ya}else{break}}}}while(0);do{if(($|0)==75){$=0;ra=x$(m)|0;pa=x$(m)|0;c[l+(ka<<2)>>2]=pa+ra;if((ra|0)!=0){W=0;do{x$(m)|0;Y=c[B>>2]|0;Z=(c[D>>2]|0)+1|0;c[D>>2]=Y>>>0>Z>>>0?Z:Y;W=W+1|0;}while(W>>>0<ra>>>0)}if((pa|0)==0){break}else{Aa=0}do{x$(m)|0;ra=c[B>>2]|0;W=(c[D>>2]|0)+1|0;c[D>>2]=ra>>>0>W>>>0?W:ra;Aa=Aa+1|0;}while(Aa>>>0<pa>>>0)}}while(0);ka=ka+1|0;}while(ka>>>0<X>>>0)}X=c[D>>2]|0;ka=c[z>>2]|0;pa=d[ka+(X>>>3)|0]|0;ra=c[B>>2]|0;W=((X|0)<(ra|0))+X|0;c[D>>2]=W;if((pa&128>>>((X&7)>>>0)|0)==0){Ba=W;Ca=ra;Da=ka}else{if((x$(m)|0)!=0){ka=ja+4|0;ra=ka>>>0>16>>>0?16:ka;ka=0;do{W=c[B>>2]|0;X=(c[D>>2]|0)+ra|0;pa=(W>>>0>X>>>0?X:W)+1|0;c[D>>2]=W>>>0>pa>>>0?pa:W;ka=ka+1|0;}while(ka>>>0<(x$(m)|0)>>>0)}Ba=c[D>>2]|0;Ca=c[B>>2]|0;Da=c[z>>2]|0}ka=Ba+1|0;ra=(Ca>>>0>ka>>>0?ka:Ca)+1|0;ka=Ca>>>0>ra>>>0?ra:Ca;c[D>>2]=ka;ra=d[Da+(ka>>>3)|0]|0;ja=((ka|0)<(Ca|0))+ka|0;c[D>>2]=ja;if((128>>>((ka&7)>>>0)&ra|0)==0){T=0;U=Q;break}ra=d[Da+(ja>>>3)|0]|0;ka=((ja|0)<(Ca|0))+ja|0;c[D>>2]=ka;do{if((ra&128>>>((ja&7)>>>0)|0)==0){Ea=ka}else{W=Da+(ka>>>3)|0;pa=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ka&7);W=ka+8|0;X=Ca>>>0>W>>>0?W:Ca;c[D>>2]=X;if(!((pa&-16777216|0)==-16777216)){Ea=X;break}pa=-X|0;W=Ca-X|0;if((pa|0)>32){Fa=pa}else{Fa=(W|0)<32?W:32}W=Fa+X|0;c[D>>2]=W;Ea=W}}while(0);ka=((Ea|0)<(Ca|0))+Ea|0;if((d[Da+(Ea>>>3)|0]&128>>>((Ea&7)>>>0)|0)==0){Ga=ka}else{ja=ka+1|0;Ga=Ca>>>0>ja>>>0?ja:Ca}c[D>>2]=Ga;ja=d[Da+(Ga>>>3)|0]|0;ka=((Ga|0)<(Ca|0))+Ga|0;c[D>>2]=ka;do{if((ja&128>>>((Ga&7)>>>0)|0)==0){Ha=ka}else{ra=ka+4|0;W=Ca>>>0>ra>>>0?ra:Ca;c[D>>2]=W;ra=d[Da+(W>>>3)|0]|0;X=((W|0)<(Ca|0))+W|0;c[D>>2]=X;if((ra&128>>>((W&7)>>>0)|0)==0){Ha=X;break}W=X+24|0;X=Ca>>>0>W>>>0?W:Ca;c[D>>2]=X;Ha=X}}while(0);ka=d[Da+(Ha>>>3)|0]|0;ja=((Ha|0)<(Ca|0))+Ha|0;c[D>>2]=ja;if((ka&128>>>((Ha&7)>>>0)|0)==0){Ia=ja;Ja=Ca;Ka=Da}else{x$(m)|0;x$(m)|0;Ia=c[D>>2]|0;Ja=c[B>>2]|0;Ka=c[z>>2]|0}ja=Ia+3|0;ka=Ja>>>0>ja>>>0?ja:Ja;c[D>>2]=ka;ja=d[Ka+(ka>>>3)|0]|0;X=((ka|0)<(Ja|0))+ka|0;c[D>>2]=X;if((128>>>((ka&7)>>>0)&ja|0)==0){La=X;Ma=Ka;Na=Ja}else{x$(m)|0;x$(m)|0;x$(m)|0;x$(m)|0;La=c[D>>2]|0;Ma=c[z>>2]|0;Na=c[B>>2]|0}X=d[Ma+(La>>>3)|0]|0;ja=((La|0)<(Na|0))+La|0;c[D>>2]=ja;do{if((X&128>>>((La&7)>>>0)|0)==0){Oa=ja;Pa=Ma;Qa=Na}else{ka=-ja|0;W=Na-ja|0;if((ka|0)>32){Ra=ka}else{Ra=(W|0)<32?W:32}W=Ra+ja|0;c[D>>2]=W;ka=-W|0;ra=Na-W|0;if((ka|0)>32){Sa=ka}else{Sa=(ra|0)<32?ra:32}ra=Sa+W|0;c[D>>2]=ra;W=d[Ma+(ra>>>3)|0]|0;ka=((ra|0)<(Na|0))+ra|0;c[D>>2]=ka;if((128>>>((ra&7)>>>0)&W|0)==0){Ta=ka;Ua=Ma;Va=Na}else{x$(m)|0;Ta=c[D>>2]|0;Ua=c[z>>2]|0;Va=c[B>>2]|0}ka=d[Ua+(Ta>>>3)|0]|0;W=((Ta|0)<(Va|0))+Ta|0;c[D>>2]=W;if((ka&128>>>((Ta&7)>>>0)|0)==0){Oa=W;Pa=Ua;Qa=Va;break}ka=d[Ua+(W>>>3)|0]<<(W&7)>>>7;ra=((W|0)<(Va|0))+W|0;c[D>>2]=ra;W=ka&1;pa=d[Ua+(ra>>>3)|0]<<(ra&7)>>>7;Y=((ra|0)<(Va|0))+ra|0;c[D>>2]=Y;ra=pa&1;if(((pa|ka)&1|0)==0){Wa=0;Xa=Y}else{ka=d[Ua+(Y>>>3)|0]<<(Y&7)>>>7;pa=((Y|0)<(Va|0))+Y|0;c[D>>2]=pa;Y=ka&1;if(Y<<24>>24==0){ka=pa+8|0;Ya=Va>>>0>ka>>>0?ka:Va}else{ka=pa+19|0;pa=(Va>>>0>ka>>>0?ka:Va)+8|0;ka=Va>>>0>pa>>>0?pa:Va;c[D>>2]=ka;pa=ka+4|0;Ya=Va>>>0>pa>>>0?pa:Va}pa=Ya+15|0;ka=Va>>>0>pa>>>0?pa:Va;c[D>>2]=ka;Wa=Y;Xa=ka}ka=(W|0)==0;W=(ra|0)==0;ra=1;Y=Xa;pa=Ua;Z=Va;while(1){ga=d[pa+(Y>>>3)|0]|0;_=((Y|0)<(Z|0))+Y|0;c[D>>2]=_;do{if((ga&128>>>((Y&7)>>>0)|0)==0){ta=d[pa+(_>>>3)|0]|0;sa=((_|0)<(Z|0))+_|0;c[D>>2]=sa;if((ta&128>>>((_&7)>>>0)|0)==0){Za=sa;$=117;break}x$(m)|0;$=118}else{Za=_;$=117}}while(0);if(($|0)==117){$=0;_=d[pa+(Za>>>3)|0]|0;c[D>>2]=((Za|0)<(Z|0))+Za;if((_&128>>>((Za&7)>>>0)|0)==0){$=118}else{_a=0}}if(($|0)==118){$=0;_a=x$(m)|0}if(!ka){z$(m,_a,Wa)}if(!W){z$(m,_a,Wa)}_=c[D>>2]|0;ga=c[z>>2]|0;sa=c[B>>2]|0;if(ra>>>0>la>>>0){Oa=_;Pa=ga;Qa=sa;break}else{ra=ra+1|0;Y=_;pa=ga;Z=sa}}}}while(0);la=d[Pa+(Oa>>>3)|0]|0;ja=((Oa|0)<(Qa|0))+Oa|0;c[D>>2]=ja;if((la&128>>>((Oa&7)>>>0)|0)==0){T=0;U=Q;break}la=ja+3|0;c[D>>2]=Qa>>>0>la>>>0?la:Qa;la=x$(m)|0;ja=b[u>>1]|0;b[u>>1]=(ja&65535)>>>0>la>>>0?la&65535:ja;x$(m)|0;x$(m)|0;x$(m)|0;x$(m)|0;T=0;U=Q;break}else{T=0;U=Q;break}}}while(0);kJb(U);if((T|0)<0){v=T;break a}break};default:{}}O=O+(S+4)|0;P=y-O|0;if((P|0)<=4){break b}}}}while(0);a[q]=1;y=b[u>>1]|0;if((y&65535)>>>0>4096>>>0){b[u>>1]=0;$=140}else{if(y<<16>>16==0){$=140}}if(($|0)==140){a[p+20|0]=0}y=p+24|0;b[y>>1]=0;x=p+26|0;a[x]=0;w=p+30|0;P=a[w]|0;if(P<<24>>24==0){$a=0;ab=0;bb=0}else{O=c[p+32>>2]|0;D=0;B=0;z=0;L=0;while(1){K=D&255;J=d[O+(K*12|0)+1|0]|0;if((J|0)==32){cb=L;db=z;eb=(b[O+(K*12|0)+2>>1]|0)+B&65535}else if((J|0)==33){cb=L;db=(b[O+(K*12|0)+2>>1]|0)+z&65535;eb=B}else if((J|0)==34){cb=(b[O+(K*12|0)+2>>1]|0)+L&65535;db=z;eb=B}else{cb=L;db=z;eb=B}K=D+1&255;if((K&255)>>>0<(P&255)>>>0){D=K;B=eb;z=db;L=cb}else{$a=eb;ab=db;bb=cb;break}}}if($a<<16>>16==0|($a&65535)>>>0>16>>>0|ab<<16>>16==0|(ab&65535)>>>0>32>>>0|bb<<16>>16==0|(bb&65535)>>>0>256>>>0){v=-1094995529;break}bD(f,1);bD(f,d[p+2|0]<<5|d[p+1|0]<<6|d[p+3|0]);lD(f,c[s>>2]|0);lD(f,(c[t>>2]|0)>>>16|c[t+4>>2]<<16);tD(f,c[t>>2]|0);bD(f,d[p+16|0]|0);tD(f,e[u>>1]|61440);bD(f,d[p+20|0]|252);bD(f,d[p+21|0]|252);bD(f,d[p+22|0]|248);bD(f,d[p+23|0]|248);tD(f,e[y>>1]|0);bD(f,d[p+27|0]<<3|d[x]<<6|d[p+28|0]<<2|d[r]);bD(f,d[w]|0);if((a[w]|0)==0){v=0;break}L=p+32|0;z=0;B=0;D=c[L>>2]|0;while(1){bD(f,a[D+(B*12|0)+1|0]&63|d[D+(B*12|0)|0]<<7);tD(f,e[(c[L>>2]|0)+(B*12|0)+2>>1]|0);P=c[L>>2]|0;if((b[P+(B*12|0)+2>>1]|0)==0){fb=P}else{O=0;K=0;J=P;while(1){tD(f,e[(c[J+(B*12|0)+4>>2]|0)+(K<<1)>>1]|0);P=c[L>>2]|0;dD(f,c[(c[P+(B*12|0)+8>>2]|0)+(K<<2)>>2]|0,e[(c[P+(B*12|0)+4>>2]|0)+(K<<1)>>1]|0);P=O+1&65535;I=c[L>>2]|0;if((P&65535)>>>0<(e[I+(B*12|0)+2>>1]|0)>>>0){O=P;K=P&65535;J=I}else{fb=I;break}}}J=z+1&255;if((J&255)>>>0<(d[w]|0)>>>0){z=J;B=J&255;D=fb}else{v=0;break}}}}while(0);fb=p+30|0;f=p+32|0;if((a[fb]|0)==0){a[fb]=0;gb=f;mJb(gb);hb=c[o>>2]|0;kJb(hb);i=k;return v|0}else{ib=1;jb=0}while(1){p=c[f>>2]|0;b[p+(jb*12|0)+2>>1]=0;mJb(p+(jb*12|0)+8|0);mJb((c[f>>2]|0)+(jb*12|0)+4|0);if(!((ib&255)>>>0<(d[fb]|0)>>>0)){break}p=ib&255;ib=ib+1&255;jb=p}a[fb]=0;gb=f;mJb(gb);hb=c[o>>2]|0;kJb(hb);i=k;return v|0}function x$(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a>>2]|0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;a=b+(f>>>3)|0;h=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7);a=f+16|0;i=g>>>0>a>>>0?a:g;a=b+(i>>>3)|0;j=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>16|h&-65536;i=j>>>0>65535>>>0;a=i?h>>>16:j;j=i?16:0;if((a&65280|0)==0){k=j;l=a}else{k=j|8;l=a>>>8}a=(d[1359664+l|0]|0)+k|0;k=31-a|0;l=-f|0;j=g-f|0;if((k|0)<(l|0)){m=l}else{m=(j|0)<(k|0)?j:k}j=m+f|0;c[e>>2]=j;f=k+1|0;if((f|0)==0){n=0;o=n-1|0;return o|0}m=b+(j>>>3)|0;l=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7);if((f|0)<26){m=j+f|0;c[e>>2]=g>>>0>m>>>0?m:g;n=l>>>(a>>>0);o=n-1|0;return o|0}else{a=j+16|0;j=g>>>0>a>>>0?a:g;c[e>>2]=j;a=k-15|0;m=b+(j>>>3)|0;b=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>((47-k|0)>>>0);k=j+a|0;c[e>>2]=g>>>0>k>>>0?k:g;n=b|l>>>16<<a;o=n-1|0;return o|0}return 0}function y$(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=b+8|0;l=c[k>>2]|0;m=b+16|0;n=c[m>>2]|0;o=b|0;b=c[o>>2]|0;p=b+(l>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(l&7)>>>30;p=l+2|0;l=n>>>0>p>>>0?p:n;c[k>>2]=l;p=d[b+(l>>>3)|0]<<(l&7)>>>7;r=((l|0)<(n|0))+l|0;c[k>>2]=r;l=p&1;p=b+(r>>>3)|0;s=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>27;p=r+5|0;r=n>>>0>p>>>0?p:n;c[k>>2]=r;p=s&255;s=b+(r>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)&-65536;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;u=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>16;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;v=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>16;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;w=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)&-65536;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;x=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>16;s=r+16|0;r=n>>>0>s>>>0?s:n;c[k>>2]=r;s=b+(r>>>3)|0;b=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>24;s=r+8|0;c[k>>2]=n>>>0>s>>>0?s:n;n=b&255;a[e+1|0]=q;q=e+2|0;b=a[q]|0;s=e+16|0;if((b&255)>>>0<(l&255)>>>0){y=n}else{r=a[s]|0;y=(r&255)>>>0>(n&255)>>>0?r:n}a[s]=y;a[q]=(b&255)>>>0>(l&255)>>>0?b:l;l=e+3|0;b=a[l]|0;a[l]=(b&255)>>>0>(p&255)>>>0?b:p;p=e+4|0;c[p>>2]=c[p>>2]&(u|t);t=e+8|0;e=c[t+4>>2]&v;c[t>>2]=c[t>>2]&(x|w);c[t+4>>2]=e;e=(f|0)==0;if(e){i=g;return}t=c[o>>2]|0;o=c[m>>2]|0;w=0;x=c[k>>2]|0;do{v=d[t+(x>>>3)|0]<<(x&7)>>>7;u=((x|0)<(o|0))+x|0;c[k>>2]=u;a[h+w|0]=v&1;v=d[t+(u>>>3)|0]<<(u&7)>>>7;x=((u|0)<(o|0))+u|0;c[k>>2]=x;a[j+w|0]=v&1;w=w+1|0;}while(w>>>0<f>>>0);if(e){i=g;return}do{if(f>>>0<8>>>0){w=c[m>>2]|0;x=f;o=c[k>>2]|0;do{t=o+2|0;o=w>>>0>t>>>0?t:w;x=x+1|0;}while(x>>>0<8>>>0);c[k>>2]=o;if(!e){z=0;break}i=g;return}else{z=0}}while(0);do{if((a[h+z|0]|0)!=0){e=c[k>>2]|0;x=-e|0;w=c[m>>2]|0;t=w-e|0;if((x|0)>32){A=x}else{A=(t|0)<32?t:32}t=A+e|0;c[k>>2]=t;e=-t|0;x=w-t|0;if((e|0)>32){B=e}else{B=(x|0)<32?x:32}x=B+t+24|0;c[k>>2]=w>>>0>x>>>0?x:w}if((a[j+z|0]|0)!=0){w=c[m>>2]|0;x=(c[k>>2]|0)+8|0;c[k>>2]=w>>>0>x>>>0?x:w}z=z+1|0;}while(z>>>0<f>>>0);i=g;return}function z$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+8|0;f=a+16|0;if(d<<24>>24==0){d=0;do{x$(a)|0;x$(a)|0;g=c[f>>2]|0;h=(c[e>>2]|0)+1|0;c[e>>2]=g>>>0>h>>>0?h:g;d=d+1|0;}while(!(d>>>0>b>>>0));return}else{d=0;do{x$(a)|0;x$(a)|0;x$(a)|0;x$(a)|0;g=c[f>>2]|0;h=(c[e>>2]|0)+1|0;c[e>>2]=g>>>0>h>>>0?h:g;d=d+1|0;}while(!(d>>>0>b>>>0));return}}function A$(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+648|0;e=d|0;f=d+520|0;g=b+16|0;h=fD(c[g>>2]|0,0,0,1)|0;j=G;k=c[g>>2]|0;if((c[k+88>>2]|0)==0){i=d;return}l=iD(k)|0;k=G;m=0;if(!((k|0)>(m|0)|(k|0)==(m|0)&l>>>0>128>>>0)){i=d;return}m=c[g>>2]|0;n=wrc(l,k,-128,-1)|0;fD(m,n,G,0)|0;n=f|0;do{if((AD(c[g>>2]|0,n,128)|0)==128){m=d+512|0;if((a[n]|0)!=84){break}if((a[f+1|0]|0)!=65){break}if((a[f+2|0]|0)!=71){break}k=e|0;l=e;o=0;p=k;while(1){q=a[f+(o+3)|0]|0;if(q<<24>>24==0){r=p;break}if((p-l|0)>>>0>510>>>0){r=p;break}s=p+1|0;a[p]=q;q=o+1|0;if((q|0)<30){o=q;p=s}else{r=s;break}}a[r]=0;if((a[k]|0)==0){t=0;u=k}else{MGb(b+1140|0,2537664,k,0)|0;t=0;u=k}while(1){p=a[f+(t+33)|0]|0;if(p<<24>>24==0){v=u;break}if((u-l|0)>>>0>510>>>0){v=u;break}o=u+1|0;a[u]=p;p=t+1|0;if((p|0)<30){t=p;u=o}else{v=o;break}}a[v]=0;if((a[k]|0)==0){w=0;x=k}else{MGb(b+1140|0,2536312,k,0)|0;w=0;x=k}while(1){o=a[f+(w+63)|0]|0;if(o<<24>>24==0){y=x;break}if((x-l|0)>>>0>510>>>0){y=x;break}p=x+1|0;a[x]=o;o=w+1|0;if((o|0)<30){w=o;x=p}else{y=p;break}}a[y]=0;if((a[k]|0)!=0){MGb(b+1140|0,2535032,k,0)|0}p=a[f+93|0]|0;do{if(p<<24>>24==0){z=k}else{o=e+1|0;a[k]=p;s=a[f+94|0]|0;if(s<<24>>24==0){z=o;break}q=e+2|0;a[o]=s;s=a[f+95|0]|0;if(s<<24>>24==0){z=q;break}o=e+3|0;a[q]=s;s=a[f+96|0]|0;if(s<<24>>24==0){z=o;break}a[o]=s;z=e+4|0}}while(0);a[z]=0;if((a[k]|0)==0){A=0;B=k}else{MGb(b+1140|0,2533488,k,0)|0;A=0;B=k}while(1){p=a[f+(A+97)|0]|0;if(p<<24>>24==0){C=B;break}if((B-l|0)>>>0>510>>>0){C=B;break}s=B+1|0;a[B]=p;p=A+1|0;if((p|0)<30){A=p;B=s}else{C=s;break}}a[C]=0;if((a[k]|0)!=0){MGb(b+1140|0,2529664,k,0)|0}do{if((a[f+125|0]|0)==0){l=a[f+126|0]|0;if(l<<24>>24==0){break}Rb(m|0,5,2526992,(s=i,i=i+8|0,c[s>>2]=l&255,s)|0)|0;i=s;MGb(b+1140|0,2525824,m,0)|0}}while(0);m=a[f+127|0]|0;if(!((m&255)>>>0<148>>>0)){break}MGb(b+1140|0,2524440,c[1373488+((m&255)<<2)>>2]|0,0)|0}}while(0);fD(c[g>>2]|0,h,j,0)|0;i=d;return}function B$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;c[b>>2]=f;lD(e,a[g+2|0]<<8|f|a[g+1|0]<<16|d[g]<<24);bD(e,0);bD(e,0);g=fD(e,0,0,1)|0;f=b+8|0;c[f>>2]=g;c[f+4>>2]=G;lD(e,0);return}function C$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+144|0;e=d|0;f=d+8|0;g=(c[b>>2]|0)==3?1:3;h=a+16|0;j=D$(c[h>>2]|0,a+1140|0,b,g)|0;if((j|0)<0){k=j;i=d;return k|0}j=a+1132|0;l=e;m=d+16|0;n=a+1136|0;a=b+16|0;o=0;while(1){if(!(o>>>0<(c[j>>2]|0)>>>0)){k=0;p=11;break}q=c[(c[n>>2]|0)+(o<<2)>>2]|0;c[e>>2]=0;c[f>>2]=0;r=_D(f)|0;do{if((r|0)<0){s=r}else{t=q+16|0;u=q+4|0;v=XIb(c[t>>2]|0,c[t+4>>2]|0,u,110192)|0;t=q+24|0;w=XIb(c[t>>2]|0,c[t+4>>2]|0,u,110192)|0;Rb(m|0,122,2303256,(u=i,i=i+8|0,c[u>>2]=o,u)|0)|0;i=u;u=mD(c[f>>2]|0,m)|0;c[a>>2]=(c[a>>2]|0)+u;lD(c[f>>2]|0,v);lD(c[f>>2]|0,w);lD(c[f>>2]|0,-1);lD(c[f>>2]|0,-1);w=D$(c[f>>2]|0,q+32|0,b,g)|0;if((w|0)<0){s=w;break}v=aE(c[f>>2]|0,e)|0;c[a>>2]=(c[a>>2]|0)+26;lD(c[h>>2]|0,1128808784);lD(c[h>>2]|0,v);tD(c[h>>2]|0,0);dD(c[h>>2]|0,c[e>>2]|0,v);s=w}}while(0);q=c[f>>2]|0;do{if((q|0)!=0){if((c[e>>2]|0)!=0){break}aE(q,e)|0}}while(0);mJb(l);if((s|0)<0){k=s;p=11;break}else{o=o+1|0}}if((p|0)==11){i=d;return k|0}return 0}function D$(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=i;i=i+24|0;j=h|0;cL(e,1373368,0);k=f|0;l=c[k>>2]|0;if((l|0)==3){m=h+8|0;n=h+16|0;c[j>>2]=0;mrc(m|0,0,5)|0;mrc(n|0,0,5)|0;o=LGb(c[e>>2]|0,10230720,0,2)|0;if((o|0)!=0){p=o;do{o=c[p>>2]|0;q=(IFb(o,2251736)|0)==0;r=c[p+4>>2]|0;do{if(q){s=0;while(1){t=r+s|0;u=a[t]|0;v=s+1|0;if((u-48&255)>>>0<10>>>0){s=v}else{break}}if(!((u<<24>>24|0)==0|(u<<24>>24|0)==45)){MGb(j,o,r,0)|0;break}CFb(m,r,5)|0;MGb(j,2208832,m,0)|0;if((a[t]|0)!=45){break}w=r+v|0;if(!(((a[w]|0)-48&255)>>>0<2>>>0)){break}if(!(((a[r+(s+2)|0]|0)-48&255)>>>0<10>>>0)){break}if((a[r+(s+3)|0]|0)!=45){break}x=r+(s+4)|0;if(!(((a[x]|0)-48&255)>>>0<4>>>0)){break}if(!(((a[r+(s+5)|0]|0)-48&255)>>>0<10>>>0)){break}y=a[r+(s+6)|0]|0;if(!((y<<24>>24|0)==0|(y<<24>>24|0)==32)){break}Rb(n|0,5,2176272,(y=i,i=i+16|0,c[y>>2]=x,c[y+8>>2]=w,y)|0)|0;i=y;MGb(j,2148336,n,0)|0}else{MGb(j,o,r,0)|0}}while(0);p=LGb(c[e>>2]|0,10230720,p,2)|0;}while((p|0)!=0)}OGb(e);c[e>>2]=c[j>>2]}else if((l|0)==4){cL(e,1373280,0)}l=LGb(c[e>>2]|0,10230720,0,2)|0;if((l|0)==0){z=0;i=h;return z|0}j=f+16|0;p=l;while(1){l=p|0;n=c[l>>2]|0;a:do{if((a[n]|0)==84){if((lrc(n|0)|0)==4){v=n;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=je(t|0)|0;m=t&255;t=0;while(1){u=1372672+(t<<2)|0;if((a[u]|0)==0){A=n;B=m;break}r=u;if((v|0)==(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)){C=27;break}else{t=t+1|0}}do{if((C|0)==27){C=0;t=H$(f,b,c[p+4>>2]|0,0,v,g)|0;if((t|0)>0){c[j>>2]=(c[j>>2]|0)+t;break a}else{t=c[l>>2]|0;A=t;B=a[t]|0;break}}}while(0);if(B<<24>>24==84){D=A;E=(c[k>>2]|0)==3?1373336:1373224}else{F=A;C=39;break}}else{D=n;E=(c[k>>2]|0)==3?1373336:1373224}if((lrc(D|0)|0)!=4){F=D;C=39;break}v=D;t=je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=0;while(1){m=E+(v<<2)|0;if((a[m]|0)==0){F=D;C=39;break a}s=m;if((t|0)==(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)){break}else{v=v+1|0}}v=H$(f,b,c[p+4>>2]|0,0,t,g)|0;if((v|0)>0){c[j>>2]=(c[j>>2]|0)+v;break}else{F=c[l>>2]|0;C=39;break}}else{F=n;C=39}}while(0);if((C|0)==39){C=0;n=H$(f,b,F,c[p+4>>2]|0,1415075928,g)|0;if((n|0)<0){z=n;C=41;break}c[j>>2]=(c[j>>2]|0)+n}n=LGb(c[e>>2]|0,10230720,p,2)|0;if((n|0)==0){z=0;C=41;break}else{p=n}}if((C|0)==41){i=h;return z|0}return 0}function E$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[(c[b+28>>2]|0)+(c[e+32>>2]<<2)>>2]|0;k=d|0;l=(c[k>>2]|0)==3;m=l?1:3;n=j+8|0;o=1372896;while(1){p=c[o+32>>2]|0;if((p|0)==0){break}if((p|0)==(c[(c[n>>2]|0)+48>>2]|0)){q=4;break}else{o=o+36|0}}do{if((q|0)==4){n=o|0;if((o|0)==0){break}p=j+88|0;r=LGb(c[p>>2]|0,2459392,0,0)|0;s=r+4|0;a:do{if((r|0)==0){t=0}else{u=0;while(1){if(!(u>>>0<21>>>0)){t=0;break a}v=c[1372808+(u<<2)>>2]|0;w=c[s>>2]|0;if((krc(v,w,lrc(w|0)|0)|0)==0){t=u;break}else{u=u+1|0}}}}while(0);s=LGb(c[p>>2]|0,2369080,0,0)|0;if((s|0)==0){x=10230720}else{x=c[s+4>>2]|0}if(l){s=x;while(1){r=a[s]|0;y=r<<24>>24==0;if(r<<24>>24>-1&(y^1)){s=s+1|0}else{break}}z=y?0:m}else{z=m}if((_D(g)|0)<0){A=-12;i=f;return A|0}bD(c[g>>2]|0,z);mD(c[g>>2]|0,n)|0;bD(c[g>>2]|0,t);s=c[g>>2]|0;if((z|0)==1){oD(s,65279);B=506}else{B=74}We[B&2047](s,x)|0;dD(c[g>>2]|0,c[e+24>>2]|0,c[e+28>>2]|0);s=aE(c[g>>2]|0,h)|0;p=b+16|0;lD(c[p>>2]|0,1095780675);r=c[p>>2]|0;if((c[k>>2]|0)==3){lD(r,s)}else{bD(r,s>>>21&127);bD(r,s>>>14&127);bD(r,s>>>7&127);bD(r,s&127)}tD(c[p>>2]|0,0);dD(c[p>>2]|0,c[h>>2]|0,s);mJb(h);p=d+16|0;c[p>>2]=s+10+(c[p>>2]|0);A=0;i=f;return A|0}}while(0);KIb(b,16,2616240,(b=i,i=i+8|0,c[b>>2]=c[j>>2],b)|0);i=b;A=-22;i=f;return A|0}function F$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=(d|0)<0?10:d;d=a+16|0;f=268435455-(c[d>>2]|0)|0;if((e|0)<10){g=10}else{g=(e|0)>(f|0)?f:e}cD(b,0,g);c[d>>2]=(c[d>>2]|0)+g;g=fD(b,0,0,1)|0;e=G;f=a+8|0;fD(b,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=c[d>>2]|0;bD(b,f>>>21&127);bD(b,f>>>14&127);bD(b,f>>>7&127);bD(b,f&127);fD(b,g,e,0)|0;return}function G$(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+24|0;h=g|0;j=h;c[j>>2]=c[343162];c[j+4>>2]=c[343163];c[j+8>>2]=c[343164];c[j+12>>2]=c[343165];c[j+16>>2]=c[343166];c[j+20>>2]=c[343167];j=b+16|0;k=c[j>>2]|0;c[h>>2]=e;lD(k,a[f+2|0]<<8|e|a[f+1|0]<<16|d[f]<<24);bD(k,0);bD(k,0);f=fD(k,0,0,1)|0;e=h+8|0;c[e>>2]=f;c[e+4>>2]=G;lD(k,0);k=C$(b,h)|0;if((k|0)<0){l=k;i=g;return l|0}F$(h,c[j>>2]|0,c[b+1316>>2]|0);l=0;i=g;return l|0}function H$(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=j|0;l=j+8|0;if((_D(l)|0)<0){m=-12;i=j;return m|0}do{if((h|0)==1){n=e;while(1){o=a[n]|0;p=o<<24>>24==0;if(o<<24>>24>-1&(p^1)){n=n+1|0}else{break}}if(!p){q=1;break}if((f|0)!=0){n=f;while(1){o=a[n]|0;r=o<<24>>24==0;if(o<<24>>24>-1&(r^1)){n=n+1|0}else{break}}if(!r){q=1;break}}q=0}else{q=h}}while(0);bD(c[l>>2]|0,q);h=c[l>>2]|0;r=(q|0)==1;if(r){oD(h,65279);s=506}else{s=74}We[s&2047](h,e)|0;if((f|0)!=0){e=c[l>>2]|0;if(r){oD(e,65279);t=506}else{t=74}We[t&2047](e,f)|0}f=aE(c[l>>2]|0,k)|0;lD(d,g);if((c[b>>2]|0)==3){lD(d,f)}else{bD(d,f>>>21&127);bD(d,f>>>14&127);bD(d,f>>>7&127);bD(d,f&127)}tD(d,0);dD(d,c[k>>2]|0,f);mJb(k);m=f+10|0;i=j;return m|0}function I$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=0;while(1){if((d|0)>=13){e=-1;f=5;break}if((grc(a,1338668+(d*20|0)|0,16)|0)==0){break}else{d=d+1|0}}if((f|0)==5){return e|0}c[b>>2]=c[1338664+(d*20|0)>>2];e=0;return e|0}function J$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0;d=i;e=b;b=i;i=i+8|0;c[b>>2]=c[e>>2];c[b+4>>2]=c[e+4>>2];e=c[b>>2]|0;f=c[b+4>>2]|0;b=f;g=(f|0)<0|0?-1:0;h=e;j=(e|0)<0|0?-1:0;k=(e|0)==0;l=e>>31;do{if((f|0)==0){if(k){break}m=Erc(b,g,1001,0)|0;n=G;o=Erc(h,j,24e3,0)|0;if((m|0)==(o|0)&(n|0)==(G|0)&(l|0)==0){p=786064;i=d;return p|0}o=Erc(h,j,24,0)|0;if((b|0)==(o|0)&(g|0)==(G|0)&(l|0)==0){p=786096;i=d;return p|0}o=Erc(h,j,3e4,0)|0;if((m|0)==(o|0)&(n|0)==(G|0)&(l|0)==0){p=786128;i=d;return p|0}o=Erc(h,j,6e4,0)|0;if((m|0)==(o|0)&(n|0)==(G|0)&(l|0)==0){p=786160;i=d;return p|0}n=Erc(h,j,25,0)|0;if((b|0)==(n|0)&(g|0)==(G|0)&(l|0)==0){p=786192;i=d;return p|0}n=Erc(h,j,50,0)|0;if((b|0)==(n|0)&(g|0)==(G|0)&(l|0)==0){p=786224}else{break}i=d;return p|0}else{n=Erc(b,g,1001,0)|0;o=G;m=Erc(h,j,24e3,0)|0;q=(n|0)==(m|0)&(o|0)==(G|0);if(k){if(q){p=786064;i=d;return p|0}m=Erc(h,j,24,0)|0;if((b|0)==(m|0)&(g|0)==(G|0)){p=786096;i=d;return p|0}m=Erc(h,j,3e4,0)|0;if((n|0)==(m|0)&(o|0)==(G|0)){p=786128;i=d;return p|0}m=Erc(h,j,6e4,0)|0;if((n|0)==(m|0)&(o|0)==(G|0)){p=786160;i=d;return p|0}m=Erc(h,j,25,0)|0;if((b|0)==(m|0)&(g|0)==(G|0)){p=786192;i=d;return p|0}m=Erc(h,j,50,0)|0;if((b|0)==(m|0)&(g|0)==(G|0)){p=786224}else{break}i=d;return p|0}else{if(q){p=786064;i=d;return p|0}q=Erc(h,j,24,0)|0;if((b|0)==(q|0)&(g|0)==(G|0)){p=786096;i=d;return p|0}q=Erc(h,j,3e4,0)|0;if((n|0)==(q|0)&(o|0)==(G|0)){p=786128;i=d;return p|0}q=Erc(h,j,6e4,0)|0;if((n|0)==(q|0)&(o|0)==(G|0)){p=786160;i=d;return p|0}o=Erc(h,j,25,0)|0;if((b|0)==(o|0)&(g|0)==(G|0)){p=786192;i=d;return p|0}o=Erc(h,j,50,0)|0;if((b|0)==(o|0)&(g|0)==(G|0)){p=786224}else{break}i=d;return p|0}}}while(0);r=+(e|0)/+(f|0);g=0;while(1){if(!(g>>>0<6>>>0)){p=0;s=14;break}t=786064+(g<<5)|0;u=c[t>>2]|0;v=c[786068+(g<<5)>>2]|0;if(+R(+(+(u|0)/+(v|0)-r))<1.0e-4){break}else{g=g+1|0}}if((s|0)==14){i=d;return p|0}KIb(a,24,2601088,(a=i,i=i+32|0,c[a>>2]=e,c[a+8>>2]=f,c[a+16>>2]=u,c[a+24>>2]=v,a)|0);i=a;p=t;i=d;return p|0}function K$(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b;b=i;i=i+8|0;c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];g=c[(c[a>>2]|0)+24>>2]|0;if((g|0)==0){i=f;return}h=c[b>>2]|0;j=h;k=(h|0)<0|0?-1:0;h=c[a+3728>>2]|0;a=c[b+4>>2]|0;b=a;l=(a|0)<0|0?-1:0;a=0;do{m=c[h+(a*40|0)+20>>2]|0;n=c[m+4>>2]|0;o=Erc(n,(n|0)<0|0?-1:0,j,k)|0;n=G;p=c[m>>2]|0;m=Erc(p,(p|0)<0|0?-1:0,b,l)|0;p=UIb(d,e,o,n,m,G,2)|0;m=h+(a*40|0)+8|0;c[m>>2]=p;c[m+4>>2]=G;a=a+1|0;}while(a>>>0<g>>>0);i=f;return}function L$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=yrc(1,0,c[a+24>>2]|0)|0;f=wrc(e,G,-1,-1)|0;e=G;g=a+8|0;a=c[g>>2]|0;h=c[g+4>>2]|0;g=Crc(f,e,2,0)|0;i=xrc(a,h,g,G)|0;g=G;h=xrc(b,d,i,g)|0;d=wrc(h&f,G&e,i,g)|0;return(G=G,d)|0}function M$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a|0;a=c[d>>2]|0;e=c[d+4>>2]|0;d=b|0;b=c[d>>2]|0;f=c[d+4>>2]|0;xrc(a,e,b,f)|0;d=G;xrc(b,f,a,e)|0;e=xrc(d,0,G,0)|0;return e|0}function N$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+16|0;a=c[d>>2]|0;e=c[d+4>>2]|0;d=b+16|0;b=c[d>>2]|0;f=c[d+4>>2]|0;xrc(a,e,b,f)|0;d=G;xrc(b,f,a,e)|0;e=xrc(d,0,G,0)|0;return e|0}function O$(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=pJb(24)|0;c[k>>2]=m;n=tLb()|0;c[l>>2]=n;if((m|0)==0|(n|0)==0){mJb(k);mJb(l);o=-12;i=j;return o|0}n=a+3764|0;c[n>>2]=(c[n>>2]|0)+1;n=m;c[n>>2]=b;c[n+4>>2]=d;d=m+8|0;c[d>>2]=e;c[d+4>>2]=f;f=m+16|0;c[f>>2]=g;c[f+4>>2]=h;vLb(a+3760|0,m,738,l)|0;if((c[l>>2]|0)==0){o=0;i=j;return o|0}kJb(c[k>>2]|0);kJb(c[l>>2]|0);o=0;i=j;return o|0}function P$(a){a=a|0;var b=0;b=a+3760|0;xLb(c[b>>2]|0,0,0,980);wLb(c[b>>2]|0);return}function Q$(a,b){a=a|0;b=b|0;kJb(b);return 0}function R$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=i;i=i+8|0;f=e|0;g=(a|0)!=0;a:do{if(g){h=a+8|0;j=c[h>>2]|0;if((j|0)==0){k=b+48|0;l=b+412|0;m=b+416|0;n=b+8|0}else{do{if((c[j+36>>2]|0)!=0){o=c[a+12>>2]|0;if((o|0)==0){break}p=(OJb(o,2600008,0,f)|0)>-1;o=c[f>>2]|0;q=c[f+4>>2]|0;r=-1;if(!(p&((q|0)>(r|0)|(q|0)==(r|0)&o>>>0>-1>>>0))){break}s=o;i=e;return s|0}}while(0);j=b+48|0;o=b+412|0;r=b+416|0;q=b+8|0;if(g){k=j;l=o;m=r;n=q}else{t=j;u=o;v=r;w=q;x=4;break}}q=a+12|0;r=0;o=676888;while(1){j=c[676904+(r*28|0)>>2]|0;do{if((j|0)==(c[k>>2]|0)){if((r|0)==25){p=c[h>>2]|0;if((p|0)==0){y=n;x=42;break a}if((c[p+36>>2]|0)==0){y=n;x=42;break a}p=c[q>>2]|0;if((p|0)==0){y=n;x=42;break a}if((PJb(p,2615552,2458952)|0)==0){y=n;x=42;break a}z=c[k>>2]|0}else{z=j}do{if((z|0)==69660){if((c[l>>2]|0)!=16e3){break}if((c[m>>2]|0)==1){A=o;x=34;break a}}}while(0);if((c[n>>2]|0)!=1){B=o;x=40;break a}if((67096575>>>(r>>>0)&1|0)!=0){if((c[l>>2]|0)!=(c[676908+(r*28|0)>>2]|0)){break}}if((249855>>>(r>>>0)&1|0)==0){B=o;x=40;break a}if((c[m>>2]|0)==(c[676912+(r*28|0)>>2]|0)){B=o;x=40;break a}}}while(0);j=r+1|0;if((j|0)==26){y=n;x=42;break a}r=j;o=676888+(j*28|0)|0}}else{t=b+48|0;u=b+412|0;v=b+416|0;w=b+8|0;x=4}}while(0);b:do{if((x|0)==4){b=c[t>>2]|0;n=0;m=676888;l=b;while(1){do{if((c[676904+(n*28|0)>>2]|0)==(l|0)){if((l|0)==5){C=5;break}do{if((b|0)==69660){if((c[u>>2]|0)!=16e3){break}if((c[v>>2]|0)==1){A=m;x=34;break b}}}while(0);if((c[w>>2]|0)!=1){B=m;x=40;break b}if((67096575>>>(n>>>0)&1|0)!=0){if((c[u>>2]|0)!=(c[676908+(n*28|0)>>2]|0)){C=b;break}}if((249855>>>(n>>>0)&1|0)==0){B=m;x=40;break b}if((c[v>>2]|0)==(c[676912+(n*28|0)>>2]|0)){B=m;x=40;break b}else{C=b}}else{C=l}}while(0);z=n+1|0;if((z|0)==26){y=w;x=42;break}else{n=z;m=676888+(z*28|0)|0;l=C}}}}while(0);if((x|0)==34){s=c[A>>2]|0;i=e;return s|0}else if((x|0)==40){s=c[B>>2]|0;i=e;return s|0}else if((x|0)==42){if((d|0)<0){D=(c[y>>2]|0)==1|0}else{D=d}s=D+96|0;i=e;return s|0}return 0}function S$(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)<8){e=0}else{f=0;g=8;while(1){b[a+(f<<1)>>1]=he(b[c+(f<<1)>>1]|0)|0;h=f|1;b[a+(h<<1)>>1]=he(b[c+(h<<1)>>1]|0)|0;h=f|2;b[a+(h<<1)>>1]=he(b[c+(h<<1)>>1]|0)|0;h=f|3;b[a+(h<<1)>>1]=he(b[c+(h<<1)>>1]|0)|0;h=f|4;b[a+(h<<1)>>1]=he(b[c+(h<<1)>>1]|0)|0;h=f|5;b[a+(h<<1)>>1]=he(b[c+(h<<1)>>1]|0)|0;h=f|6;b[a+(h<<1)>>1]=he(b[c+(h<<1)>>1]|0)|0;h=f|7;b[a+(h<<1)>>1]=he(b[c+(h<<1)>>1]|0)|0;h=g+8|0;if((h|0)>(d|0)){e=g;break}else{f=g;g=h}}}if((e|0)<(d|0)){i=e}else{return}do{b[a+(i<<1)>>1]=he(b[c+(i<<1)>>1]|0)|0;i=i+1|0;}while((i|0)<(d|0));return}function T$(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=b+8|0;g=c[f>>2]|0;h=c[b+16>>2]|0;i=c[b>>2]|0;b=i+(g>>>3)|0;j=(je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(g&7);b=g+12|0;g=h>>>0>b>>>0?b:h;c[f>>2]=g;if(!((j&-1048576|0)==-1048576)){k=-16976906;return k|0}j=g+1|0;g=(h>>>0>j>>>0?j:h)+2|0;j=h>>>0>g>>>0?g:h;c[f>>2]=j;g=(d[i+(j>>>3)|0]|0)<<(j&7)>>>7;b=((j|0)<(h|0))+j|0;c[f>>2]=b;j=i+(b>>>3)|0;l=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(b&7)>>>30;j=b+2|0;b=h>>>0>j>>>0?j:h;c[f>>2]=b;j=i+(b>>>3)|0;m=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(b&7)>>>28;j=b+4|0;b=h>>>0>j>>>0?j:h;c[f>>2]=b;j=c[1965112+(m<<2)>>2]|0;if((j|0)==0){k=-50531338;return k|0}n=b+1|0;b=h>>>0>n>>>0?n:h;c[f>>2]=b;n=i+(b>>>3)|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+3|0;p=(h>>>0>n>>>0?n:h)+1|0;n=(h>>>0>p>>>0?p:h)+1|0;p=(h>>>0>n>>>0?n:h)+1|0;n=(h>>>0>p>>>0?p:h)+1|0;p=h>>>0>n>>>0?n:h;c[f>>2]=p;n=i+(p>>>3)|0;q=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(p&7);n=q>>>19;r=p+13|0;p=h>>>0>r>>>0?r:h;c[f>>2]=p;if(q>>>0<3670016>>>0){k=-67308554;return k|0}q=(je(o|0)|0)<<(b&7)>>>29;b=p+11|0;p=h>>>0>b>>>0?b:h;c[f>>2]=p;b=i+(p>>>3)|0;i=(je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(p&7)>>>30;b=p+2|0;c[f>>2]=h>>>0>b>>>0?b:h;a[e+13|0]=l+1;a[e+15|0]=q;a[e+12|0]=g&1;g=i+1|0;a[e+16|0]=g;a[e+14|0]=m;c[e>>2]=j;m=g<<10;c[e+4>>2]=m;c[e+8>>2]=((ca(n<<3,j)|0)>>>0)/(m>>>0)|0;k=n;return k|0}function U$(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[g>>2]|0;do{if((h|0)==0){i=pJb(64)|0;j=i;c[g>>2]=j;if((i|0)==0){k=-12}else{l=j;break}return k|0}else{l=h}}while(0);mrc(l|0,0,64)|0;h=f+8|0;g=c[h>>2]|0;j=f+16|0;i=c[j>>2]|0;m=f|0;f=(c[m>>2]|0)+(g>>>3)|0;n=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(g&7)>>>16;f=g+16|0;c[h>>2]=i>>>0>f>>>0?f:i;b[l>>1]=n;if((n|0)!=2935){k=-16976906;return k|0}n=c[j>>2]|0;i=(c[h>>2]|0)+16|0;f=n>>>0>i>>>0?i:n;n=(c[m>>2]|0)+(f>>>3)|0;i=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(f&7)>>>19&31;f=l+5|0;a[f]=i;if((i&255)>>>0>16>>>0){k=-33754122;return k|0}n=l+28|0;c[n>>2]=6;g=l+16|0;c[g>>2]=5;o=l+20|0;c[o>>2]=6;p=l+56|0;c[p>>2]=0;if((i&255)>>>0<11>>>0){i=c[h>>2]|0;q=c[j>>2]|0;r=c[m>>2]|0;s=r+(i>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(i&7)>>>16;s=i+16|0;i=q>>>0>s>>>0?s:q;c[h>>2]=i;b[l+2>>1]=t;t=r+(i>>>3)|0;r=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(i&7)>>>30;t=i+2|0;c[h>>2]=q>>>0>t>>>0?t:q;q=l+4|0;a[q]=r;if((r|0)==3){k=-50531338;return k|0}r=c[h>>2]|0;t=c[j>>2]|0;i=c[m>>2]|0;s=i+(r>>>3)|0;u=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7);s=u>>>26;v=r+6|0;r=t>>>0>v>>>0?v:t;c[h>>2]=r;if(u>>>0>2550136831>>>0){k=-67308554;return k|0}v=r+5|0;r=t>>>0>v>>>0?v:t;c[h>>2]=r;v=i+(r>>>3)|0;i=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(r&7)>>>29;v=r+3|0;c[h>>2]=t>>>0>v>>>0?v:t;a[l+6|0]=i;i=c[h>>2]|0;t=c[j>>2]|0;v=(c[m>>2]|0)+(i>>>3)|0;r=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(i&7)>>>29;v=i+3|0;c[h>>2]=t>>>0>v>>>0?v:t;t=r&255;v=l+7|0;a[v]=t;do{if((r|0)==2){i=c[h>>2]|0;w=c[j>>2]|0;x=(c[m>>2]|0)+(i>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(i&7)>>>30;x=i+2|0;c[h>>2]=w>>>0>x>>>0?x:w;c[p>>2]=y}else{if((r&1|0)==0|(r|0)==1){z=t}else{y=c[h>>2]|0;w=c[j>>2]|0;x=(c[m>>2]|0)+(y>>>3)|0;i=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7)>>>30;x=y+2|0;c[h>>2]=w>>>0>x>>>0?x:w;c[g>>2]=d[1719640+i|0]|0;z=a[v]|0}if((z&4)==0){break}i=c[h>>2]|0;w=c[j>>2]|0;x=(c[m>>2]|0)+(i>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(i&7)>>>30;x=i+2|0;c[h>>2]=w>>>0>x>>>0?x:w;c[o>>2]=d[551952+y|0]|0}}while(0);o=c[h>>2]|0;z=(d[(c[m>>2]|0)+(o>>>3)|0]|0)<<(o&7)>>>7;c[h>>2]=((o|0)<(c[j>>2]|0))+o;o=z&1;a[l+8|0]=o;z=a[f]|0;f=(z&255)>>>0>8>>>0?z-8&255:0;a[l+32|0]=f;z=d[q]|0;q=f&255;b[l+34>>1]=(e[1443280+(z<<1)>>1]|0)>>>(q>>>0);c[l+36>>2]=((e[1445024+(u>>>27<<1)>>1]|0)*1e3|0)>>>(q>>>0);q=a[v]|0;a[l+40|0]=o+(a[1444864+(q&255)|0]|0);b[l+42>>1]=b[1444e3+(s*6|0)+(z<<1)>>1]<<1;a[l+9|0]=2;c[l+12>>2]=0;A=q;B=o}else{b[l+2>>1]=0;o=c[h>>2]|0;q=c[j>>2]|0;z=(c[m>>2]|0)+(o>>>3)|0;s=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(o&7)>>>30;z=o+2|0;c[h>>2]=q>>>0>z>>>0?z:q;a[l+9|0]=s;if((s|0)==3){k=-84085770;return k|0}s=c[h>>2]|0;q=c[j>>2]|0;z=c[m>>2]|0;o=z+(s>>>3)|0;v=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(s&7)>>>29;o=s+3|0;c[h>>2]=q>>>0>o>>>0?o:q;c[l+12>>2]=v;v=c[h>>2]|0;q=c[j>>2]|0;o=z+(v>>>3)|0;z=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(v&7)>>>21;o=v+11|0;c[h>>2]=q>>>0>o>>>0?o:q;q=(z<<1)+2|0;b[l+42>>1]=q;if((q&65534)>>>0<7>>>0){k=-67308554;return k|0}z=c[h>>2]|0;o=c[j>>2]|0;v=(c[m>>2]|0)+(z>>>3)|0;s=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(z&7)>>>30;v=z+2|0;c[h>>2]=o>>>0>v>>>0?v:o;o=l+4|0;a[o]=s;v=c[h>>2]|0;z=c[j>>2]|0;u=(c[m>>2]|0)+(v>>>3)|0;f=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7)>>>30;u=v+2|0;c[h>>2]=z>>>0>u>>>0?u:z;do{if((s|0)==3){if((f|0)==3){k=-50531338;return k|0}else{z=(e[1443280+(f<<1)>>1]|0)>>>1;b[l+34>>1]=z;a[l+32|0]=1;C=z;break}}else{c[n>>2]=d[1515320+f|0]|0;z=b[1443280+((d[o]|0)<<1)>>1]|0;b[l+34>>1]=z;a[l+32|0]=0;C=z}}while(0);o=c[h>>2]|0;f=c[j>>2]|0;s=(c[m>>2]|0)+(o>>>3)|0;z=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(o&7)>>>29;s=o+3|0;c[h>>2]=f>>>0>s>>>0?s:f;f=l+7|0;a[f]=z;z=c[h>>2]|0;s=(d[(c[m>>2]|0)+(z>>>3)|0]|0)<<(z&7)>>>7;c[h>>2]=((z|0)<(c[j>>2]|0))+z;z=s&1;a[l+8|0]=z;c[l+36>>2]=~~(+(q&65534|0)*8.0*+(C&65535|0)/(+(c[n>>2]|0)*256.0));n=a[f]|0;a[l+40|0]=z+(a[1444864+(n&255)|0]|0);A=n;B=z}z=e[1967928+((A&255)<<1)>>1]|0;A=0;n=l+48|0;c[n>>2]=z;c[n+4>>2]=A;if(B<<24>>24==0){k=0;return k|0}c[n>>2]=z|8;c[n+4>>2]=A;k=0;return k|0}function V$(a){a=a|0;var b=0;b=c[a>>2]|0;c[b+44>>2]=7;c[b+48>>2]=228;return 0}function W$(b,f,g,h,j){b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+104|0;l=k|0;m=k+8|0;n=k+72|0;o=k+80|0;p=l|0;q=je(b|0)|0;c[p>>2]=je(f|0)|0;c[p+4>>2]=q;c[n>>2]=m;q=l+8|0;c[o>>2]=q-7;c[o+12>>2]=54;c[o+16>>2]=62;c[o+4>>2]=q;c[o+8>>2]=0;if((U$(o,n)|0)<0){r=0;i=k;return r|0}c[g+56>>2]=e[m+34>>1]|0;c[g+60>>2]=c[m+36>>2];n=a[m+40|0]|0;c[g+52>>2]=n&255;o=m+48|0;q=c[o+4>>2]|0;l=g+72|0;c[l>>2]=c[o>>2];c[l+4>>2]=q;c[g+64>>2]=c[m+28>>2]<<8;q=a[m+6|0]|0;if(q<<24>>24==7&(n&255)>>>0>1>>>0){s=8}else{s=q&255}c[g+80>>2]=s;s=g+100|0;do{if((d[m+5|0]|0)>>>0>10>>>0){c[s>>2]=86057}else{if((c[s>>2]|0)!=0){break}c[s>>2]=86019}}while(0);s=a[m+9|0]|0;c[h>>2]=s<<24>>24!=2;c[j>>2]=s<<24>>24!=1;r=e[m+42>>1]|0;i=k;return r|0}function X$(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0.0,g=0.0;f=1.4142135623730951- +U(+(a|0)*6.283185307179586/+(b|0));g=(f- +S((f+.41421356237309515)*(f+-.41421356237309515)))/.41421356237309515;f=+(1<<d|0);c[e>>2]=Lc(+(f*g*2.0))|0;c[e+4>>2]=Lc(+(f*(-0.0-g*g)))|0;return}function Y$(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0;j=i;if((f|0)<24){k=-1094995529;i=j;return k|0}l=e;if(!((d[l]|d[l+1|0]<<8)<<16>>16<<16>>16==128)){k=-1094995529;i=j;return k|0}l=e+2|0;m=(he((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&65535;l=m+4|0;do{if((l|0)<=(f|0)&l>>>0>5>>>0){if((grc(e+(m-2)|0,2598576,6)|0)==0){break}else{k=-1094995529}i=j;return k|0}}while(0);do{if((a[e+4|0]|0)==3){if((a[e+5|0]|0)!=18){break}if((a[e+6|0]|0)!=4){break}m=a[e+7|0]|0;f=m&255;c[b+416>>2]=f;if(m<<24>>24==0|(m&255)>>>0>2>>>0){k=-1094995529;i=j;return k|0}m=e+8|0;n=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;c[b+412>>2]=n;if((n|0)<1){k=-1094995529;i=j;return k|0}if((n|0)>(2147483647/((f*144|0)>>>0)|0|0)){k=-1094995529;i=j;return k|0}c[b+72>>2]=(ca(n*144|0,f)|0)/32|0;if((h|0)!=0){f=e+16|0;o=1.4142135623730951- +U(+((he((d[f]|d[f+1|0]<<8)<<16>>16|0)|0)&65535|0)*6.283185307179586/+(n|0));p=(o- +S((o+.41421356237309515)*(o+-.41421356237309515)))/.41421356237309515;c[h>>2]=Lc(+(p*2.0*4096.0))|0;c[h+4>>2]=Lc(+(p*p*-4096.0))|0}c[g>>2]=l;k=0;i=j;return k|0}}while(0);QIb(b,2615224,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;k=-1163346256;i=j;return k|0}function Z$(){if(a[1982104]|0){return}a[1982104]=1;F4a(1454616);F4a(1454720);F4a(1445184);F4a(1434128);F4a(1432640);F4a(1432744);F4a(1432536);F4a(1432352);F4a(1430024);F4a(1430128);F4a(1429816);F4a(1429920);F4a(1428152);F4a(1428256);F4a(1427280);F4a(1427384);F4a(1427488);F4a(1427176);F4a(1426776);F4a(1426880);F4a(1426568);F4a(1426672);F4a(1426216);F4a(1426032);F4a(1425848);F4a(1425e3);F4a(1425104);F4a(1424712);F4a(1424528);F4a(1424296);F4a(1423944);F4a(1412776);F4a(1412672);F4a(1412280);F4a(1412384);F4a(1412072);F4a(1412176);F4a(1411968);F4a(1406200);F4a(1406304);F4a(1405768);F4a(1403272);F4a(1403168);F4a(1402392);F4a(1402152);F4a(1399192);F4a(1399376);F4a(1398896);F4a(1399e3);F4a(1398608);F4a(1393864);F4a(1393968);F4a(1393752);F4a(1393568);F4a(1392056);F4a(1391952);F4a(1391848);F4a(1391744);F4a(1391640);F4a(1391280);F4a(1391176);F4a(1391072);F4a(1390824);F4a(1390720);F4a(1390512);F4a(1389784);F4a(1389888);F4a(1389576);F4a(1389680);F4a(1389368);F4a(1387608);F4a(1387712);F4a(1387816);F4a(1388432);F4a(1387504);F4a(1387136);F4a(1387320);F4a(1386864);F4a(1386504);F4a(1386320);F4a(1386216);F4a(1382688);F4a(1382872);F4a(1380032);F4a(1380216);F4a(1379200);F4a(1379392);F4a(1378376);F4a(1378168);F4a(1378272);F4a(1376024);F4a(1375568);F4a(1374640);F4a(1374352);F4a(1374456);F4a(1372544);F4a(1372176);F4a(1371992);F4a(1371280);F4a(1371176);F4a(1371072);F4a(1370968);F4a(1369008);F4a(1361832);F4a(1361936);F4a(1361624);F4a(1361728);F4a(1361520);F4a(1361336);F4a(1361232);F4a(1361128);F4a(1360232);F4a(1359968);F4a(1358520);F4a(1355976);F4a(1355688);F4a(1355872);F4a(1355496);F4a(1352024);F4a(1351856);F4a(1346328);F4a(1346432);F4a(1345208);F4a(1345312);F4a(1344432);F4a(1344824);F4a(1343024);F4a(1342008);F4a(1341640);F4a(1341432);F4a(1341536);F4a(1341224);F4a(1341328);F4a(1341040);F4a(1340936);F4a(1340832);F4a(1340624);F4a(1340728);F4a(1340520);F4a(1340416);F4a(1340064);F4a(1339960);F4a(1338480);F4a(1335448);F4a(1334160);F4a(1333952);F4a(1334056);F4a(1333744);F4a(1333848);F4a(1324352);F4a(1324456);F4a(1324144);F4a(1324248);F4a(1323936);F4a(1324040);F4a(1323728);F4a(1323248);F4a(1323352);F4a(1322832);F4a(1322936);F4a(1322504);F4a(1322608);F4a(1322720);F4a(1322336);F4a(1322216);F4a(1321944);F4a(1321392);F4a(1321288);F4a(1320248);F4a(1320352);F4a(1319784);F4a(1319888);F4a(1319576);F4a(1319680);F4a(1317240);F4a(1317424);F4a(1316320);F4a(1313712);F4a(1314104);F4a(1313440);F4a(1312896);F4a(1313e3);F4a(1312688);F4a(1312792);F4a(1312584);F4a(1312480);F4a(1311888);F4a(1311992);F4a(1311600);F4a(1306392);F4a(1306496);F4a(1306288);F4a(1305536);F4a(1305352);F4a(1304912);F4a(1304704);F4a(1304808);F4a(1303936);F4a(1301752);F4a(1301856);F4a(1301536);F4a(1301640);F4a(1298088);F4a(1292288);F4a(1292392);F4a(1292184);F4a(1291592);F4a(1291488);F4a(1291224);F4a(1290704);F4a(1290952);F4a(1278368);F4a(1277864);F4a(1277760);F4a(1277448);F4a(1277552);F4a(1276656);F4a(1275960);F4a(1275624);F4a(1275728);F4a(1275416);F4a(1275520);F4a(1275312);F4a(1275080);F4a(1275184);F4a(1274872);F4a(1274976);F4a(1274664);F4a(1274768);F4a(1274560);F4a(1274456);F4a(1266552);F4a(1261976);F4a(1261704);F4a(1255536);F4a(1255432);F4a(1253504);F4a(1251608);F4a(1251504);F4a(1251400);F4a(1251296);F4a(1251136);F4a(1251032);F4a(1250744);F4a(1248912);F4a(1246856);F4a(1246960);F4a(1246312);F4a(1246416);F4a(1246032);F4a(1245928);F4a(1245824);F4a(1244920);F4a(1244816);F4a(1244424);F4a(1244528);F4a(1244216);F4a(1244320);F4a(1243888);F4a(1243392);F4a(1243496);F4a(1243104);F4a(1243208);F4a(1243e3);F4a(1242584);F4a(1242688);F4a(1242312);F4a(1242208);F4a(1241872);F4a(1241976);F4a(1241664);F4a(1241768);F4a(1446440);F4a(1454304);F4a(1446336);F4a(1444376);F4a(1444656);F4a(1444248);F4a(1433456);F4a(1433560);F4a(1433352);F4a(1432952);F4a(1432848);F4a(1432168);F4a(1429416);F4a(1429312);F4a(1429208);F4a(1425664);F4a(1425560);F4a(1424896);F4a(1406016);F4a(1402576);F4a(1402680);F4a(1398712);F4a(1393024);F4a(1393256);F4a(1390616);F4a(1389472);F4a(1388736);F4a(1388920);F4a(1385592);F4a(1385776);F4a(1385400);F4a(1381840);F4a(1380624);F4a(1374248);F4a(1371384);F4a(1359184);F4a(1359080);F4a(1358352);F4a(1352960);F4a(1351344);F4a(1351240);F4a(1351032);F4a(1351136);F4a(1350736);F4a(1350840);F4a(1350632);F4a(1350152);F4a(1350360);F4a(1350256);F4a(1350048);F4a(1349944);F4a(1348272);F4a(1348168);F4a(1337464);F4a(1337568);F4a(1334344);F4a(1321680);F4a(1321496);F4a(1319288);F4a(1319392);F4a(1319184);F4a(1319080);F4a(1306184);F4a(1305792);F4a(1305640);F4a(1304312);F4a(1304416);F4a(1304208);F4a(1292624);F4a(1278136);F4a(1277656);F4a(1277160);F4a(1277344);F4a(1276800);F4a(1255640);F4a(1254704);F4a(1254808);F4a(1249184);F4a(1249288);F4a(1247720);F4a(1247616);F4a(1247408);F4a(1247512);F4a(1247200);F4a(1247304);F4a(1247096);F4a(1245720);F4a(1333456);F4a(1333640);F4a(1333264);F4a(1333160);F4a(1332872);F4a(1333056);F4a(1332496);F4a(1332680);F4a(1332120);F4a(1332304);F4a(1331744);F4a(1331928);F4a(1331552);F4a(1331264);F4a(1331448);F4a(1327592);F4a(1327776);F4a(1327296);F4a(1327400);F4a(1330888);F4a(1331072);F4a(1330592);F4a(1330696);F4a(1330304);F4a(1330488);F4a(1330008);F4a(1330112);F4a(1329720);F4a(1329904);F4a(1329424);F4a(1329528);F4a(1329136);F4a(1329320);F4a(1328840);F4a(1328944);F4a(1328552);F4a(1328736);F4a(1328176);F4a(1328360);F4a(1327880);F4a(1327984);F4a(1324752);F4a(1324936);F4a(1327008);F4a(1327192);F4a(1326632);F4a(1326816);F4a(1326256);F4a(1326440);F4a(1325880);F4a(1326064);F4a(1325504);F4a(1325688);F4a(1325128);F4a(1325312);F4a(1324560);F4a(1369112);F4a(1313816);F4a(1313920);F4a(1304520);F4a(1245024);F4a(1442176);F4a(1441920);F4a(1442024);F4a(1441752);F4a(1441648);F4a(1441544);F4a(1441440);F4a(1441336);F4a(1441232);F4a(1441128);F4a(1441024);F4a(1440920);F4a(1440712);F4a(1440816);F4a(1440504);F4a(1440608);F4a(1440400);F4a(1440296);F4a(1440192);F4a(1440072);F4a(1439968);F4a(1439864);F4a(1439760);F4a(1439656);F4a(1439552);F4a(1439344);F4a(1439448);F4a(1439240);F4a(1439136);F4a(1438928);F4a(1439032);F4a(1438824);F4a(1438584);F4a(1438688);F4a(1438376);F4a(1438272);F4a(1438168);F4a(1437776);F4a(1437880);F4a(1437672);F4a(1437568);F4a(1437344);F4a(1437464);F4a(1255904);F4a(1302736);F4a(1302840);F4a(1430488);F4a(1430672);F4a(1394280);F4a(1394384);F4a(1394072);F4a(1394176);F4a(1362208);F4a(1356248);F4a(1351448);F4a(1351552);F4a(1342752);F4a(1323832);F4a(1323616);F4a(1316952);F4a(1311784);F4a(1303032);F4a(1303216);F4a(1302328);F4a(1302432);F4a(1302040);F4a(1302224);F4a(1291912);F4a(1250928);F4a(1248808);F4a(1243600);F4a(1243704);F4a(1360752);F4a(1360856);F4a(1360544);F4a(1360648);F4a(1360440);F4a(1360336);F4a(1425456);F4a(1244712);F4a(1372360);CWa(1446192);CWa(1446288);CWa(1443296);CWa(1402528);CWa(1401912);CWa(1388600);CWa(1378864);CWa(1375760);CWa(1352376);CWa(1343512);CWa(1343456);CWa(1292496);return}function _$(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;b=i;i=i+48|0;e=b|0;f=c[a+60>>2]|0;g=f;c[g>>2]=a;h=c[a+96>>2]|0;if((h|0)==0){KIb(a,16,2551432,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}l=c[a+100>>2]|0;m=l<<3;n=l>>>0>268435455>>>0?-8:m;l=n>>>0>2147483639>>>0;o=l?0:h;p=l?0:n;n=p+8|0;a:do{if(l){q=-1094995529;r=33}else{s=CRa(e,h,m,1)|0;if((s|0)<0){q=-1094995529;r=33;break}t=(n|0)<(s|0)?n:s;if((p-t|0)<240){q=-1094995529;r=33;break}s=o+(t>>>3)|0;u=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(t&7)&-65536;s=t+16|0;t=n>>>0>s>>>0?s:n;s=o+(t>>>3)|0;v=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(t&7)>>>16;s=t+16|0;t=n>>>0>s>>>0?s:n;s=a+412|0;c[s>>2]=c[e+8>>2];w=-t|0;x=n-t|0;if((w|0)>32){y=w}else{y=(x|0)<32?x:32}x=y+t|0;t=o+(x>>>3)|0;w=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7)&-65536;t=x+16|0;x=n>>>0>t>>>0?t:n;t=o+(x>>>3)|0;z=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7)>>>16;t=x+16|0;c[f+4>>2]=z|w;w=a+416|0;c[w>>2]=c[e+36>>2];z=(n>>>0>t>>>0?t:n)+16|0;t=(n>>>0>z>>>0?z:n)+3|0;z=n>>>0>t>>>0?t:n;t=o+(z>>>3)|0;x=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(z&7)>>>29;t=z+3|0;z=n>>>0>t>>>0?t:n;t=f+8|0;c[t>>2]=x;x=((z|0)<(n|0))+z|0;A=f+12|0;c[A>>2]=(d[o+(z>>>3)|0]|0)<<(z&7)>>>7&1;z=((x|0)<(n|0))+x|0;B=f+16|0;c[B>>2]=(d[o+(x>>>3)|0]|0)<<(x&7)>>>7&1;x=o+(z>>>3)|0;C=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7)>>>16;x=z+16|0;z=n>>>0>x>>>0?x:n;x=C+1|0;C=f+20|0;c[C>>2]=x;D=o+(z>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(z&7)>>>24;D=z+8|0;z=n>>>0>D>>>0?D:n;c[f+24>>2]=E;E=o+(z>>>3)|0;D=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(z&7)>>>30;E=z+2|0;z=n>>>0>E>>>0?E:n;c[f+28>>2]=D;D=((z|0)<(n|0))+z|0;c[f+32>>2]=(d[o+(z>>>3)|0]|0)<<(z&7)>>>7&1;z=o+(D>>>3)|0;E=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(D&7)>>>30;z=D+2|0;D=n>>>0>z>>>0?z:n;c[f+36>>2]=E;E=((D|0)<(n|0))+D|0;c[f+40>>2]=(d[o+(D>>>3)|0]|0)<<(D&7)>>>7&1;D=o+(E>>>3)|0;z=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>22;D=E+10|0;E=n>>>0>D>>>0?D:n;D=f+44|0;c[D>>2]=z;z=o+(E>>>3)|0;F=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(E&7)>>>30;z=E+2|0;E=n>>>0>z>>>0?z:n;c[f+48>>2]=F;F=((E|0)<(n|0))+E|0;z=f+52|0;c[z>>2]=(d[o+(E>>>3)|0]|0)<<(E&7)>>>7&1;E=((F|0)<(n|0))+F|0;c[f+56>>2]=(d[o+(F>>>3)|0]|0)<<(F&7)>>>7&1;F=((E|0)<(n|0))+E|0;c[f+60>>2]=(d[o+(E>>>3)|0]|0)<<(E&7)>>>7&1;E=((F|0)<(n|0))+F|0;H=f+64|0;c[H>>2]=(d[o+(F>>>3)|0]|0)<<(F&7)>>>7&1;F=((E|0)<(n|0))+E|0;I=(d[o+(E>>>3)|0]|0)<<(E&7)>>>7&1;c[f+68>>2]=I;E=((F|0)<(n|0))+F|0;J=(d[o+(F>>>3)|0]|0)<<(F&7)>>>7&1;c[f+72>>2]=J;F=((E|0)<(n|0))+E|0;K=f+88|0;c[K>>2]=(d[o+(E>>>3)|0]|0)<<(E&7)>>>7&1;E=f+76|0;c[E>>2]=(d[o+(F>>>3)|0]|0)<<(F&7)>>>7&1;L=F+5+((F|0)<(n|0))|0;F=(n>>>0>L>>>0?L:n)+1|0;L=n>>>0>F>>>0?F:n;if((v|u|0)!=1095521024){q=-1094995529;r=33;break}u=f+1368|0;c[u>>2]=x;if((I|0)==0){M=L}else{I=o+(L>>>3)|0;x=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>16;I=L+16|0;c[f+80>>2]=x;M=n>>>0>I>>>0?I:n}do{if((J|0)==0){N=M}else{I=c[w>>2]|0;if((I|0)<=1){N=M;break}x=(I<<1)-2|0;L=x>>>0>65535>>>0;v=L?x>>>16:x;x=L?16:0;if((v&65280|0)==0){O=x;P=v}else{O=x|8;P=v>>>8}v=(d[1359664+P|0]|0)+O|0;if((p-M|0)<((ca(v,I)|0)+7|0)){q=-1094995529;r=33;break a}x=hJb(I<<2)|0;I=x;c[f+84>>2]=I;if((x|0)==0){q=-12;r=33;break a}x=f+1380|0;c[x>>2]=1;L=c[w>>2]|0;b:do{if((L|0)>0){F=32-v|0;Q=M;R=0;while(1){S=o+(Q>>>3)|0;T=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Q&7)>>>(F>>>0);S=Q+v|0;U=n>>>0>S>>>0?S:n;if((T|0)>=(L|0)){break}c[I+(T<<2)>>2]=R;T=R+1|0;if((T|0)<(L|0)){Q=U;R=T}else{V=U;break b}}KIb(a,24,2479608,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;c[x>>2]=0;V=U}else{V=M}}while(0);x=-V&7;if((x|0)==0){N=V;break}L=x+V|0;N=n>>>0>L>>>0?L:n}}while(0);if((p-N|0)<64){q=-1094995529;r=33;break}J=o+(N>>>3)|0;L=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(N&7)&-65536;J=N+16|0;x=n>>>0>J>>>0?J:n;J=o+(x>>>3)|0;I=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(x&7)>>>16;J=x+16|0;x=n>>>0>J>>>0?J:n;J=I|L;L=o+(x>>>3)|0;I=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(x&7)&-65536;L=x+16|0;x=n>>>0>L>>>0?L:n;L=o+(x>>>3)|0;v=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(x&7)>>>16;L=x+16|0;x=n>>>0>L>>>0?L:n;L=v|I;I=(J|0)==-1;v=(L|0)==-1;R=wrc(v?0:L,v?0:0,I?0:J,I?0:0)|0;I=R<<3|0>>>29;J=G<<3|R>>>29;R=p-x|0;v=(R|0)<0|0?-1:0;if(v>>>0<J>>>0|v>>>0==J>>>0&R>>>0<I>>>0){q=-1094995529;r=33;break}R=0;if(J>>>0>R>>>0|J>>>0==R>>>0&I>>>0>2147483647>>>0){q=-1163346256;r=33;break}R=I;I=-x|0;J=n-x|0;if((R|0)<(I|0)){W=I}else{W=(J|0)<(R|0)?J:R}R=W+x|0;do{if((c[K>>2]|0)!=0){if((p-R|0)<32){q=-1094995529;r=33;break a}if((c[a+696>>2]&65537|0)==0){break}c[f+1356>>2]=DGb(4)|0;c[f+1364>>2]=-1;x=o+(R>>>3)|0;J=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(R&7)&-65536;x=R+16|0;I=n>>>0>x>>>0?x:n;x=o+(I>>>3)|0;c[f+1360>>2]=~((je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(I&7)>>>16|J)}}while(0);if((c[A>>2]|0)==0){X=0}else{RIb(c[g>>2]|0,2503904,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;X=-1163346256}if((c[E>>2]|0)!=0){RIb(c[g>>2]|0,2490416,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-1163346256;break}if((X|0)<0){Y=X;break}if((c[z>>2]|0)!=0){R=x2(a,f+1392|0,f+1396|0)|0;if((R|0)<0){Y=R;break}}if((c[A>>2]|0)==0){R=c[t>>2]|0;c[a+420>>2]=(R|0)>1?2:1;c[a+796>>2]=(R<<3)+8}else{c[a+420>>2]=3;c[a+796>>2]=32}c[f+1388>>2]=(c[t>>2]|0)>1?31:15;R=c[s>>2]|0;c[f+1400>>2]=((R|0)>95999|8)+((R|0)>191999);if((c[H>>2]|0)==0){Z=1}else{Z=c[w>>2]|0}R=Z<<2;J=f+1436|0;c[J>>2]=hJb(R)|0;I=f+1444|0;c[I>>2]=hJb(R)|0;x=f+1440|0;c[x>>2]=hJb(ca(c[D>>2]|0,R)|0)|0;v=f+1448|0;c[v>>2]=hJb(ca(c[D>>2]|0,R)|0)|0;L=hJb(c[D>>2]<<2)|0;c[f+1452>>2]=L;Q=c[J>>2]|0;do{if((Q|0)!=0){if((c[I>>2]|0)==0){break}F=c[x>>2]|0;if((F|0)==0){break}if((c[v>>2]|0)==0|(L|0)==0){break}T=(Z|0)==0;c:do{if(!T){S=c[D>>2]|0;_=0;$=F;aa=Q;while(1){ba=ca(S,_)|0;c[aa+(_<<2)>>2]=$+(ba<<2);c[(c[I>>2]|0)+(_<<2)>>2]=(c[v>>2]|0)+(ba<<2);ba=_+1|0;if(!(ba>>>0<Z>>>0)){break c}_=ba;$=c[x>>2]|0;aa=c[J>>2]|0}}}while(0);F=f+1404|0;c[F>>2]=hJb(R)|0;aa=f+1408|0;c[aa>>2]=hJb(R)|0;$=f+1412|0;c[$>>2]=hJb(R)|0;_=f+1416|0;c[_>>2]=hJb(R)|0;S=f+1420|0;c[S>>2]=pJb(R)|0;ba=f+1424|0;c[ba>>2]=hJb(R)|0;da=f+1428|0;c[da>>2]=hJb(R)|0;ea=hJb(Z*20|0)|0;fa=ea;ga=f+1432|0;c[ga>>2]=fa;do{if((c[F>>2]|0)!=0){if((c[aa>>2]|0)==0){break}if((c[$>>2]|0)==0){break}if((c[_>>2]|0)==0){break}if((c[S>>2]|0)==0){break}if((c[ba>>2]|0)==0){break}ha=c[da>>2]|0;if((ha|0)==0|(ea|0)==0){break}d:do{if(!T){ia=0;ja=fa;ka=ha;while(1){c[ka+(ia<<2)>>2]=ja+((ia*5|0)<<2);la=ia+1|0;if(!(la>>>0<Z>>>0)){break d}ia=la;ja=c[ga>>2]|0;ka=c[da>>2]|0}}}while(0);e:do{if((c[H>>2]|0)==0){c[f+1456>>2]=0;c[f+1460>>2]=0;c[f+1464>>2]=0}else{ha=f+1460|0;c[ha>>2]=hJb(ca(Z*44|0,Z)|0)|0;ka=f+1456|0;c[ka>>2]=hJb(R)|0;ja=hJb(R)|0;c[f+1464>>2]=ja;ia=c[ha>>2]|0;do{if((ia|0)!=0){la=c[ka>>2]|0;if((la|0)==0|(ja|0)==0){break}if(T){break e}else{ma=0;na=ia;oa=la}while(1){c[oa+(ma<<2)>>2]=na+((ca(ma,Z)|0)*44|0);la=ma+1|0;if(!(la>>>0<Z>>>0)){break e}ma=la;na=c[ha>>2]|0;oa=c[ka>>2]|0}}}while(0);KIb(a,16,2517808,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12;break a}}while(0);ka=c[D>>2]|0;ha=ka+(c[C>>2]|0)|0;ia=f+1468|0;c[ia>>2]=hJb(ka<<2)|0;ka=f+1476|0;c[ka>>2]=pJb(ca(ha<<2,c[w>>2]|0)|0)|0;ja=hJb(c[w>>2]<<2)|0;la=ja;pa=f+1472|0;c[pa>>2]=la;do{if((c[ia>>2]|0)!=0){qa=c[ka>>2]|0;if((qa|0)==0|(ja|0)==0){break}c[la>>2]=qa+(c[D>>2]<<2);qa=c[w>>2]|0;if(qa>>>0>1>>>0){ra=1;do{sa=c[pa>>2]|0;c[sa+(ra<<2)>>2]=(c[sa+(ra-1<<2)>>2]|0)+(ha<<2);ra=ra+1|0;}while(ra>>>0<qa>>>0)}do{if((c[B>>2]|0)!=0){if((c[K>>2]|0)==0){break}if((c[a+696>>2]&65537|0)==0){break}ra=ca(c[u>>2]|0,qa)|0;sa=hJb(ca(ra,QKb(c[a+420>>2]|0)|0)|0)|0;c[f+1480>>2]=sa;if((sa|0)!=0){break}KIb(a,16,2517808,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12;break a}}while(0);l8(f+112|0,a);k=0;i=b;return k|0}}while(0);KIb(a,16,2517808,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12;break a}}while(0);KIb(a,16,2517808,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12;break a}}while(0);KIb(a,16,2517808,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=-12}}while(0);if((r|0)==33){KIb(a,16,2533272,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;Y=q}a0(a)|0;k=Y;i=b;return k|0}function $$(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0;h=i;i=i+392|0;j=h|0;k=h+120|0;l=h+184|0;m=h+312|0;n=h+320|0;o=h+384|0;p=c[a+60>>2]|0;q=p;r=e;s=c[g+24>>2]|0;t=c[g+28>>2]|0;g=t<<3;u=g>>>0>2147483639>>>0|(s|0)==0;v=u?0:s;s=u?0:g;g=p+92|0;c[g>>2]=v;u=p+104|0;c[u>>2]=s;w=s+8|0;x=p+108|0;c[x>>2]=w;c[p+96>>2]=v+(s>>3);s=p+100|0;c[s>>2]=0;y=c[p+24>>2]|0;if((y|0)==0){z=0}else{z=(((c[p+1372>>2]|0)>>>0)%(y>>>0)|0|0)==0|0}y=c[p+4>>2]|0;if((y|0)==-1){c[p+1368>>2]=c[p+20>>2]}else{A=c[p+20>>2]|0;B=A;C=(A|0)<0|0?-1:0;D=Erc(B,C,c[p+1372>>2]|0,0)|0;E=xrc(y,0,D,G)|0;D=G;c[p+1368>>2]=D>>>0>C>>>0|D>>>0==C>>>0&E>>>0>B>>>0?A:E}E=n;A=p;B=c[A>>2]|0;c[m>>2]=0;if((c[p+28>>2]|0)!=1|(z|0)==0){F=0}else{C=(w|0)<32?w:32;c[s>>2]=C;F=C}C=p+60|0;a:do{if((c[p+64>>2]|0)==0){H=14}else{do{if((c[C>>2]|0)==0){I=c[p+1376>>2]|0}else{D=d[v+(F>>>3)|0]<<(F&7)>>>7;y=((F|0)<(w|0))+F|0;c[s>>2]=y;J=D&1;c[p+1376>>2]=J;D=-y&7;if((D|0)==0){I=J;break}K=D+y|0;c[s>>2]=w>>>0>K>>>0?K:w;I=J}}while(0);if((I|0)!=0){H=14;break}mrc(E|0,0,60)|0;J=c[p+1464>>2]|0;K=B+416|0;y=c[K>>2]|0;D=p+1456|0;L=p+1460|0;M=0;while(1){if(!(M>>>0<y>>>0)){break}if((c[(c[D>>2]|0)+(M<<2)>>2]|0)>>>0<(c[L>>2]|0)>>>0){H=56;break}else{M=M+1|0}}if((H|0)==56){KIb(B,16,2302816,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;O=-1094995529;break}M=J;mrc(M|0,0,y<<2|0)|0;L=n+4|0;c[L>>2]=z;c[n+52>>2]=c[p+1468>>2];c0(q,l|0,m);P=p+1384|0;b:do{if((c[P>>2]|0)!=0){Q=n|0;R=p+1404|0;S=n+8|0;T=p+1408|0;U=n+16|0;V=p+1412|0;W=n+20|0;X=p+1416|0;Y=n+24|0;Z=p+1420|0;_=n+28|0;$=p+1424|0;aa=n+32|0;ba=p+1428|0;da=n+36|0;ea=p+1444|0;fa=n+44|0;ga=p+1436|0;ha=n+40|0;ia=p+1472|0;ja=n+48|0;ka=n+56|0;la=p+1400|0;ma=0;na=0;c:while(1){oa=l+(ma<<2)|0;pa=c[oa>>2]|0;c[Q>>2]=pa;if((pa|0)==0){KIb(c[A>>2]|0,24,2251352,(N=i,i=i+8|0,c[N>>2]=0,N)|0);i=N;qa=na}else{do{if((c[K>>2]|0)==0){ra=0}else{pa=0;do{c[S>>2]=(c[R>>2]|0)+(pa<<2);c[U>>2]=(c[T>>2]|0)+(pa<<2);c[W>>2]=(c[V>>2]|0)+(pa<<2);c[Y>>2]=(c[X>>2]|0)+(pa<<2);c[_>>2]=(c[Z>>2]|0)+(pa<<2);c[aa>>2]=(c[$>>2]|0)+(pa<<2);c[da>>2]=c[(c[ba>>2]|0)+(pa<<2)>>2];c[fa>>2]=c[(c[ea>>2]|0)+(pa<<2)>>2];c[ha>>2]=c[(c[ga>>2]|0)+(pa<<2)>>2];c[ja>>2]=(c[(c[ia>>2]|0)+(pa<<2)>>2]|0)+(na<<2);c[ka>>2]=0;sa=d0(q,n)|0;if((sa|0)<0){O=sa;break a}ta=c[A>>2]|0;sa=c[ta+416>>2]|0;d:do{if((sa|0)==0){ua=0}else{va=(sa<<1)-2|0;wa=va>>>0>65535>>>0;xa=wa?va>>>16:va;va=wa?16:0;wa=(xa&65280|0)==0;ya=c[g>>2]|0;za=wa?va:va|8;va=1359664+(wa?xa:xa>>>8)|0;xa=c[(c[D>>2]|0)+(pa<<2)>>2]|0;wa=0;while(1){Aa=c[s>>2]|0;Ba=d[ya+(Aa>>>3)|0]<<(Aa&7)>>>7;c[s>>2]=((Aa|0)<(c[x>>2]|0))+Aa;Aa=Ba&1;c[xa>>2]=Aa;if((Aa|0)!=0){ua=wa;break d}Aa=(d[va]|0)+za|0;do{if((Aa|0)==0){Ca=0}else{Ba=c[s>>2]|0;Da=c[x>>2]|0;Ea=ya+(Ba>>>3)|0;Fa=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ba&7);if((Aa|0)<26){Ea=Ba+Aa|0;c[s>>2]=Da>>>0>Ea>>>0?Ea:Da;Ca=Fa>>>((32-Aa|0)>>>0);break}else{Ea=Ba+16|0;Ba=Da>>>0>Ea>>>0?Ea:Da;c[s>>2]=Ba;Ea=Aa-16|0;Ga=ya+(Ba>>>3)|0;Ha=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ba&7)>>>((48-Aa|0)>>>0);Ga=Ba+Ea|0;c[s>>2]=Da>>>0>Ga>>>0?Ga:Da;Ca=Ha|Fa>>>16<<Ea;break}}}while(0);c[xa+4>>2]=Ca;if(!(Ca>>>0<sa>>>0)){H=73;break c}do{if((Ca|0)!=(pa|0)){Aa=c[s>>2]|0;Ea=d[ya+(Aa>>>3)|0]<<(Aa&7)>>>7;c[s>>2]=((Aa|0)<(c[x>>2]|0))+Aa;Aa=xa+8|0;c[Aa>>2]=Ea&1;Ea=c[s>>2]|0;Fa=(c[u>>2]|0)+~Ea|0;Ha=0;Da=Ea;while(1){if((Ha|0)>=(Fa|0)){H=77;break}Ea=d[ya+(Da>>>3)|0]|0;Ga=c[x>>2]|0;Ba=((Da|0)<(Ga|0))+Da|0;c[s>>2]=Ba;if((Ea&128>>>((Da&7)>>>0)|0)==0){Ia=Ba;Ja=Ga;break}else{Ha=Ha+1|0;Da=Ba}}if((H|0)==77){H=0;Ia=Da;Ja=c[x>>2]|0}Fa=d[ya+(Ia>>>3)|0]<<(Ia&7);c[s>>2]=((Ia|0)<(Ja|0))+Ia;Ba=((Fa>>>7&1)-1^Ha)+16|0;if((Ba|0)<0){Ka=0}else{Ka=(Ba|0)>31?31:Ba}c[xa+20>>2]=b[832416+(Ka<<1)>>1]|0;Ba=c[s>>2]|0;Fa=-2-Ba+(c[u>>2]|0)|0;Ga=0;Ea=Ba;while(1){if((Ga|0)>=(Fa|0)){H=83;break}Ba=d[ya+(Ea>>>3)|0]|0;La=c[x>>2]|0;Ma=((Ea|0)<(La|0))+Ea|0;c[s>>2]=Ma;if((Ba&128>>>((Ea&7)>>>0)|0)==0){Na=Ma;Oa=La;break}else{Ga=Ga+1|0;Ea=Ma}}if((H|0)==83){H=0;Na=Ea;Oa=c[x>>2]|0}Fa=d[ya+(Na>>>3)|0]<<(Na&7);Ha=((Na|0)<(Oa|0))+Na|0;c[s>>2]=Ha;Da=ya+(Ha>>>3)|0;Ma=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Ha&7)>>>31;Da=Ha+1|0;c[s>>2]=Oa>>>0>Da>>>0?Da:Oa;Da=((Ma|Ga<<1)^(Fa>>>7&1)-1)+14|0;if((Da|0)<0){Pa=0}else{Pa=(Da|0)>31?31:Da}c[xa+24>>2]=b[832416+(Pa<<1)>>1]|0;Da=c[s>>2]|0;Fa=(c[u>>2]|0)+~Da|0;Ma=0;Ha=Da;while(1){if((Ma|0)>=(Fa|0)){H=89;break}Da=d[ya+(Ha>>>3)|0]|0;La=c[x>>2]|0;Ba=((Ha|0)<(La|0))+Ha|0;c[s>>2]=Ba;if((Da&128>>>((Ha&7)>>>0)|0)==0){Qa=Ba;Ra=La;break}else{Ma=Ma+1|0;Ha=Ba}}if((H|0)==89){H=0;Qa=Ha;Ra=c[x>>2]|0}Fa=d[ya+(Qa>>>3)|0]<<(Qa&7);c[s>>2]=((Qa|0)<(Ra|0))+Qa;Ga=((Fa>>>7&1)-1^Ma)+16|0;if((Ga|0)<0){Sa=0}else{Sa=(Ga|0)>31?31:Ga}c[xa+28>>2]=b[832416+(Sa<<1)>>1]|0;if((c[Aa>>2]|0)==0){break}Ga=c[s>>2]|0;Fa=(c[u>>2]|0)+~Ga|0;Ea=0;Ba=Ga;while(1){if((Ea|0)>=(Fa|0)){H=96;break}Ga=d[ya+(Ba>>>3)|0]|0;La=c[x>>2]|0;Da=((Ba|0)<(La|0))+Ba|0;c[s>>2]=Da;if((Ga&128>>>((Ba&7)>>>0)|0)==0){Ta=Da;Ua=La;break}else{Ea=Ea+1|0;Ba=Da}}if((H|0)==96){H=0;Ta=Ba;Ua=c[x>>2]|0}Fa=d[ya+(Ta>>>3)|0]<<(Ta&7);c[s>>2]=((Ta|0)<(Ua|0))+Ta;Aa=((Fa>>>7&1)-1^Ea)+16|0;if((Aa|0)<0){Va=0}else{Va=(Aa|0)>31?31:Aa}c[xa+32>>2]=b[832416+(Va<<1)>>1]|0;Aa=c[s>>2]|0;Fa=(c[u>>2]|0)+~Aa|0;Ma=0;Ha=Aa;while(1){if((Ma|0)>=(Fa|0)){H=102;break}Aa=d[ya+(Ha>>>3)|0]|0;Da=c[x>>2]|0;La=((Ha|0)<(Da|0))+Ha|0;c[s>>2]=La;if((Aa&128>>>((Ha&7)>>>0)|0)==0){Wa=La;Xa=Da;break}else{Ma=Ma+1|0;Ha=La}}if((H|0)==102){H=0;Wa=Ha;Xa=c[x>>2]|0}Fa=d[ya+(Wa>>>3)|0]<<(Wa&7);c[s>>2]=((Wa|0)<(Xa|0))+Wa;Ea=((Fa>>>7&1)-1^Ma)+16|0;if((Ea|0)<0){Ya=0}else{Ya=(Ea|0)>31?31:Ea}c[xa+36>>2]=b[832416+(Ya<<1)>>1]|0;Ea=c[s>>2]|0;Fa=(c[u>>2]|0)+~Ea|0;Ba=0;La=Ea;while(1){if((Ba|0)>=(Fa|0)){H=108;break}Ea=d[ya+(La>>>3)|0]|0;Da=c[x>>2]|0;Aa=((La|0)<(Da|0))+La|0;c[s>>2]=Aa;if((Ea&128>>>((La&7)>>>0)|0)==0){Za=Aa;_a=Da;break}else{Ba=Ba+1|0;La=Aa}}if((H|0)==108){H=0;Za=La;_a=c[x>>2]|0}Fa=d[ya+(Za>>>3)|0]<<(Za&7);c[s>>2]=((Za|0)<(_a|0))+Za;Ma=((Fa>>>7&1)-1^Ba)+16|0;if((Ma|0)<0){$a=0}else{$a=(Ma|0)>31?31:Ma}c[xa+40>>2]=b[832416+($a<<1)>>1]|0;Ma=c[s>>2]|0;Fa=d[ya+(Ma>>>3)|0]<<(Ma&7)>>>7;c[s>>2]=((Ma|0)<(c[x>>2]|0))+Ma;c[xa+12>>2]=Fa&1;Fa=c[la>>2]|0;Ma=c[s>>2]|0;Ha=c[x>>2]|0;Aa=ya+(Ma>>>3)|0;Da=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Ma&7)>>>((35-Fa|0)>>>0);Aa=Fa-3+Ma|0;c[s>>2]=Ha>>>0>Aa>>>0?Aa:Ha;c[xa+16>>2]=Da+3}}while(0);Da=wa+1|0;if(Da>>>0<sa>>>0){xa=xa+44|0;wa=Da}else{ua=Da;break}}}}while(0);if((ua|0)==(sa|0)){H=115;break c}wa=c[s>>2]|0;xa=-wa&7;if((xa|0)!=0){ya=c[x>>2]|0;za=xa+wa|0;c[s>>2]=ya>>>0>za>>>0?za:ya}pa=pa+1|0;ab=c[K>>2]|0;}while(pa>>>0<ab>>>0);if((ab|0)==0){ra=0;break}else{bb=0}do{pa=e0(q,n,c[D>>2]|0,J,na,bb)|0;if((pa|0)<0){O=pa;break a}bb=bb+1|0;cb=c[K>>2]|0;}while(bb>>>0<cb>>>0);if((cb|0)==0){ra=0;break}else{db=0}do{c[S>>2]=(c[R>>2]|0)+(db<<2);c[U>>2]=(c[T>>2]|0)+(db<<2);c[W>>2]=(c[V>>2]|0)+(db<<2);c[Y>>2]=(c[X>>2]|0)+(db<<2);c[_>>2]=(c[Z>>2]|0)+(db<<2);c[aa>>2]=(c[$>>2]|0)+(db<<2);c[da>>2]=c[(c[ba>>2]|0)+(db<<2)>>2];c[fa>>2]=c[(c[ea>>2]|0)+(db<<2)>>2];c[ha>>2]=c[(c[ga>>2]|0)+(db<<2)>>2];c[ja>>2]=(c[(c[ia>>2]|0)+(db<<2)>>2]|0)+(na<<2);f0(q,n);db=db+1|0;eb=c[K>>2]|0;}while(db>>>0<eb>>>0);ra=eb<<2}}while(0);mrc(M|0,0,ra|0)|0;pa=(c[oa>>2]|0)+na|0;c[L>>2]=0;qa=pa}pa=ma+1|0;if(pa>>>0<(c[P>>2]|0)>>>0){ma=pa;na=qa}else{break b}}if((H|0)==73){KIb(ta,16,2175984,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;O=-1094995529;break a}else if((H|0)==115){KIb(ta,16,2148096,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;O=-1094995529;break a}}}while(0);if((c[K>>2]|0)==0){O=0;break}P=p+1472|0;L=p+44|0;M=p+20|0;J=0;while(1){D=c[(c[P>>2]|0)+(J<<2)>>2]|0;y=c[L>>2]|0;orc(D+(-y<<2)|0,D+((c[M>>2]|0)-y<<2)|0,y<<2|0)|0;y=J+1|0;if(y>>>0<(c[K>>2]|0)>>>0){J=y}else{O=0;break}}}}while(0);e:do{if((H|0)==14){ta=B+416|0;if((c[ta>>2]|0)==0){O=0;break}qa=l|0;ra=j;eb=j|0;db=j+4|0;n=p+1404|0;cb=j+8|0;bb=p+1408|0;ab=j+16|0;x=p+1412|0;ua=j+20|0;$a=p+1416|0;Za=j+24|0;_a=p+1420|0;u=j+28|0;Ya=p+1424|0;Wa=j+32|0;Xa=p+1428|0;Va=j+36|0;Ta=p+1436|0;Ua=j+40|0;Sa=p+1444|0;Qa=j+44|0;Ra=p+1468|0;Pa=j+52|0;Oa=j+12|0;Na=j+60|0;Ka=j+64|0;Ia=j+68|0;Ja=j+76|0;Ca=j+80|0;g=j+84|0;E=j+88|0;I=j+92|0;w=j+96|0;F=j+100|0;v=j+104|0;J=j+112|0;K=j+72|0;M=p+1384|0;L=p+1472|0;P=p+44|0;y=p+20|0;D=j|0;na=Na|0;ma=j+48|0;ia=j+108|0;ja=j+56|0;ga=j+116|0;ha=k;ea=k+4|0;fa=k+8|0;ba=k+16|0;da=k+20|0;$=k+24|0;aa=k+28|0;Z=k+32|0;_=k+36|0;X=k+40|0;Y=k+44|0;V=k+52|0;W=k+48|0;T=k|0;U=p+48|0;R=0;S=(c[C>>2]|0)==0|0;f:while(1){c0(q,qa,m);do{if((c[C>>2]|0)==0){fb=S}else{if((c[U>>2]|0)==0){fb=S;break}fb=(c[m>>2]|0)<0?2:S}}while(0);la=(R|0)==((c[ta>>2]|0)-1|0)?1:fb;g:do{if((la|0)==0){mrc(ra|0,0,120)|0;c[db>>2]=z;ka=c[n>>2]|0;c[cb>>2]=ka;Q=c[bb>>2]|0;c[ab>>2]=Q;pa=c[x>>2]|0;c[ua>>2]=pa;ya=c[$a>>2]|0;c[Za>>2]=ya;za=c[_a>>2]|0;c[u>>2]=za;wa=c[Ya>>2]|0;c[Wa>>2]=wa;xa=c[Xa>>2]|0;c[Va>>2]=c[xa>>2];va=c[Ta>>2]|0;c[Ua>>2]=c[va>>2];Da=c[Sa>>2]|0;c[Qa>>2]=c[Da>>2];Ha=c[Ra>>2]|0;c[Pa>>2]=Ha;c[Oa>>2]=0;c[Ka>>2]=z;c[Ia>>2]=ka;c[Ja>>2]=Q;c[Ca>>2]=pa;c[g>>2]=ya;c[E>>2]=za;c[I>>2]=wa;c[w>>2]=c[xa>>2];c[F>>2]=c[va>>2];c[v>>2]=c[Da>>2];c[J>>2]=Ha;c[K>>2]=0;Ha=R+1|0;h:do{if((c[M>>2]|0)!=0){Da=0;va=0;while(1){xa=l+(va<<2)|0;wa=c[xa>>2]|0;c[D>>2]=wa;c[na>>2]=wa;wa=c[L>>2]|0;za=(c[wa+(R<<2)>>2]|0)+(Da<<2)|0;c[ma>>2]=za;ya=(c[wa+(Ha<<2)>>2]|0)+(Da<<2)|0;c[ia>>2]=ya;c[ja>>2]=ya;c[ga>>2]=za;za=d0(q,eb)|0;if((za|0)<0){gb=za;break}f0(q,eb);za=d0(q,Na)|0;if((za|0)<0){gb=za;break}f0(q,Na);za=(c[K>>2]|0)!=0;do{if((c[Oa>>2]|0)==0){ya=c[xa>>2]|0;if(!za){hb=ya;break}if((ya|0)==0){hb=0;break}ya=c[ia>>2]|0;wa=c[ma>>2]|0;pa=0;while(1){Q=ya+(pa<<2)|0;c[Q>>2]=(c[wa+(pa<<2)>>2]|0)+(c[Q>>2]|0);Q=pa+1|0;ka=c[xa>>2]|0;if(Q>>>0<ka>>>0){pa=Q}else{hb=ka;break}}}else{if(za){KIb(c[A>>2]|0,24,2569536,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N}if((c[xa>>2]|0)==0){hb=0;break}pa=c[ia>>2]|0;wa=c[ma>>2]|0;ya=0;while(1){ka=wa+(ya<<2)|0;c[ka>>2]=(c[pa+(ya<<2)>>2]|0)-(c[ka>>2]|0);ka=ya+1|0;Q=c[xa>>2]|0;if(ka>>>0<Q>>>0){ya=ka}else{hb=Q;break}}}}while(0);c[db>>2]=0;c[Ka>>2]=0;xa=va+1|0;if(xa>>>0<(c[M>>2]|0)>>>0){Da=hb+Da|0;va=xa}else{break h}}Da=c[M>>2]|0;xa=c[ma>>2]|0;do{if(va>>>0<Da>>>0){za=va;sa=0;while(1){ya=za+1|0;ib=(c[l+(za<<2)>>2]|0)+sa|0;if(ya>>>0<Da>>>0){za=ya;sa=ib}else{break}}if((ib|0)==0){jb=Da;break}mrc(xa|0,0,ib<<2|0)|0;jb=c[M>>2]|0}else{jb=Da}}while(0);Da=c[ia>>2]|0;do{if(va>>>0<jb>>>0){xa=va;sa=0;while(1){za=xa+1|0;kb=(c[l+(xa<<2)>>2]|0)+sa|0;if(za>>>0<jb>>>0){xa=za;sa=kb}else{break}}if((kb|0)==0){break}mrc(Da|0,0,kb<<2|0)|0}}while(0);if((gb|0)<0){O=gb;break e}else{lb=0;mb=Ha;break g}}}while(0);oa=c[(c[L>>2]|0)+(R<<2)>>2]|0;Da=c[P>>2]|0;orc(oa+(-Da<<2)|0,oa+((c[y>>2]|0)-Da<<2)|0,Da<<2|0)|0;lb=0;mb=Ha}else{mrc(ha|0,0,60)|0;c[ea>>2]=z;c[fa>>2]=c[n>>2];c[ba>>2]=c[bb>>2];c[da>>2]=c[x>>2];c[$>>2]=c[$a>>2];c[aa>>2]=c[_a>>2];c[Z>>2]=c[Ya>>2];c[_>>2]=c[c[Xa>>2]>>2];c[X>>2]=c[c[Ta>>2]>>2];c[Y>>2]=c[c[Sa>>2]>>2];c[V>>2]=c[Ra>>2];c[W>>2]=c[(c[L>>2]|0)+(R<<2)>>2];if((c[M>>2]|0)!=0){nb=0;while(1){Da=l+(nb<<2)|0;c[T>>2]=c[Da>>2];ob=d0(q,k)|0;if((ob|0)<0){break f}f0(q,k);c[W>>2]=(c[W>>2]|0)+(c[Da>>2]<<2);c[ea>>2]=0;Da=nb+1|0;if(Da>>>0<(c[M>>2]|0)>>>0){nb=Da}else{break}}}lb=la-1|0;mb=R}}while(0);la=c[(c[L>>2]|0)+(mb<<2)>>2]|0;Ha=c[P>>2]|0;orc(la+(-Ha<<2)|0,la+((c[y>>2]|0)-Ha<<2)|0,Ha<<2|0)|0;Ha=mb+1|0;if(Ha>>>0<(c[ta>>2]|0)>>>0){R=Ha;S=lb}else{O=0;break e}}S=c[M>>2]|0;R=c[W>>2]|0;if(nb>>>0<S>>>0){pb=nb;qb=0}else{O=ob;break}while(1){ta=pb+1|0;rb=(c[l+(pb<<2)>>2]|0)+qb|0;if(ta>>>0<S>>>0){pb=ta;qb=rb}else{break}}if((rb|0)==0){O=ob;break}mrc(R|0,0,rb<<2|0)|0;O=ob}}while(0);if((O|0)<0){KIb(c[A>>2]|0,24,2458680,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N}ob=p+1372|0;c[ob>>2]=(c[ob>>2]|0)+1;ob=p+1368|0;c[e+76>>2]=c[ob>>2];rb=M4a(a,r,0)|0;if((rb|0)<0){sb=rb;i=h;return sb|0}rb=(c[A>>2]|0)+796|0;A=c[rb>>2]|0;r=e;e=c[r>>2]|0;i:do{if((A|0)<17){qb=e;pb=16-A|0;l=c[ob>>2]|0;nb=(l|0)==0;if((c[p+1380>>2]|0)==0){if(nb){tb=0;break}lb=c[a+416>>2]|0;mb=p+1472|0;if((lb|0)==0){tb=l;break}else{ub=qb;vb=0}while(1){k=c[mb>>2]|0;q=lb>>>0>1>>>0?lb:1;z=ub;gb=0;while(1){b[z>>1]=c[(c[k+(gb<<2)>>2]|0)+(vb<<2)>>2]<<pb;kb=gb+1|0;if(kb>>>0<lb>>>0){z=z+2|0;gb=kb}else{break}}gb=vb+1|0;if(gb>>>0<l>>>0){ub=ub+(q<<1)|0;vb=gb}else{tb=l;break i}}}if(nb){tb=0;break}lb=c[a+416>>2]|0;mb=(lb|0)==0;R=p+84|0;gb=p+1472|0;z=qb;k=0;while(1){if(mb){wb=z}else{kb=c[R>>2]|0;jb=c[gb>>2]|0;ib=lb>>>0>1>>>0?lb:1;hb=z;fb=0;while(1){b[hb>>1]=c[(c[jb+(c[kb+(fb<<2)>>2]<<2)>>2]|0)+(k<<2)>>2]<<pb;m=fb+1|0;if(m>>>0<lb>>>0){hb=hb+2|0;fb=m}else{break}}wb=z+(ib<<1)|0}fb=k+1|0;if(fb>>>0<l>>>0){z=wb;k=fb}else{tb=l;break}}}else{l=e;k=32-A|0;z=c[ob>>2]|0;lb=(z|0)==0;if((c[p+1380>>2]|0)==0){if(lb){tb=0;break}pb=a+416|0;gb=p+1472|0;R=l;mb=0;qb=c[pb>>2]|0;nb=z;while(1){if((qb|0)==0){xb=R;yb=0;zb=nb}else{fb=c[gb>>2]|0;hb=R;kb=0;while(1){Ab=hb+4|0;c[hb>>2]=c[(c[fb+(kb<<2)>>2]|0)+(mb<<2)>>2]<<k;jb=kb+1|0;Bb=c[pb>>2]|0;if(jb>>>0<Bb>>>0){hb=Ab;kb=jb}else{break}}xb=Ab;yb=Bb;zb=c[ob>>2]|0}kb=mb+1|0;if(kb>>>0<zb>>>0){R=xb;mb=kb;qb=yb;nb=zb}else{tb=zb;break}}}else{if(lb){tb=0;break}nb=a+416|0;qb=p+84|0;mb=p+1472|0;R=l;pb=0;gb=c[nb>>2]|0;kb=z;while(1){if((gb|0)==0){Cb=R;Db=0;Eb=kb}else{hb=c[qb>>2]|0;fb=c[mb>>2]|0;ib=R;jb=0;while(1){Fb=ib+4|0;c[ib>>2]=c[(c[fb+(c[hb+(jb<<2)>>2]<<2)>>2]|0)+(pb<<2)>>2]<<k;q=jb+1|0;Gb=c[nb>>2]|0;if(q>>>0<Gb>>>0){ib=Fb;jb=q}else{break}}Cb=Fb;Db=Gb;Eb=c[ob>>2]|0}jb=pb+1|0;if(jb>>>0<Eb>>>0){R=Cb;pb=jb;gb=Db;kb=Eb}else{tb=Eb;break}}}}}while(0);do{if((c[p+88>>2]|0)!=0){Eb=a+696|0;if((c[Eb>>2]&65537|0)==0){break}Db=(c[p+16>>2]|0)!=0;Cb=c[rb>>2]|0;do{if((Cb|0)==24){Gb=e;Fb=a+416|0;if((ca(c[Fb>>2]|0,tb)|0)==0){Hb=tb;break}zb=p+1356|0;yb=p+1364|0;xb=o;if(Db){Bb=0;while(1){c[o>>2]=(je(c[Gb+(Bb<<2)>>2]|0)|0)>>8;c[yb>>2]=EGb(c[zb>>2]|0,c[yb>>2]|0,xb,3)|0;Ab=Bb+1|0;A=c[ob>>2]|0;if(Ab>>>0<(ca(c[Fb>>2]|0,A)|0)>>>0){Bb=Ab}else{Hb=A;break}}}else{Bb=0;while(1){c[o>>2]=c[Gb+(Bb<<2)>>2]>>8;c[yb>>2]=EGb(c[zb>>2]|0,c[yb>>2]|0,xb,3)|0;A=Bb+1|0;Ab=c[ob>>2]|0;if(A>>>0<(ca(c[Fb>>2]|0,Ab)|0)>>>0){Bb=A}else{Hb=Ab;break}}}}else{do{if(Db){if((Cb|0)>=17){Bb=p+1480|0;Fb=ca(c[a+416>>2]|0,tb)|0;ef[c[p+1208>>2]&4095](c[Bb>>2]|0,e,Fb);Ib=Bb;Jb=c[ob>>2]|0;break}Bb=e;Fb=ca(c[a+416>>2]|0,tb)|0;xb=p+1480|0;if((Fb|0)==0){Ib=xb;Jb=tb;break}yb=0;zb=c[xb>>2]|0;while(1){b[zb>>1]=he(b[Bb+(yb<<1)>>1]|0)|0;Gb=yb+1|0;if(Gb>>>0<Fb>>>0){yb=Gb;zb=zb+2|0}else{Ib=xb;Jb=tb;break}}}else{Ib=r;Jb=tb}}while(0);xb=c[Ib>>2]|0;zb=c[p+1356>>2]|0;yb=p+1364|0;Fb=c[yb>>2]|0;Bb=ca(c[a+416>>2]|0,Jb)|0;c[yb>>2]=EGb(zb,Fb,xb,ca(Bb,QKb(c[a+420>>2]|0)|0)|0)|0;Hb=c[ob>>2]|0}}while(0);if((Hb|0)==(c[p+20>>2]|0)){break}if((c[p+1360>>2]|0)==(c[p+1364>>2]|0)){break}KIb(a,16,2368616,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;if((c[Eb>>2]&8|0)==0){break}else{sb=-1094995529}i=h;return sb|0}}while(0);c[f>>2]=1;if((O|0)!=0){sb=t;i=h;return sb|0}sb=(c[s>>2]|0)+7>>3;i=h;return sb|0}function a0(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+84|0);y2(b+1392|0,b+1396|0);mJb(b+1404|0);mJb(b+1408|0);mJb(b+1412|0);mJb(b+1416|0);mJb(b+1420|0);mJb(b+1424|0);mJb(b+1428|0);mJb(b+1432|0);mJb(b+1436|0);mJb(b+1444|0);mJb(b+1440|0);mJb(b+1448|0);mJb(b+1452|0);mJb(b+1468|0);mJb(b+1472|0);mJb(b+1476|0);mJb(b+1456|0);mJb(b+1460|0);mJb(b+1464|0);mJb(b+1480|0);return 0}function b0(a){a=a|0;c[(c[a+60>>2]|0)+1372>>2]=0;return}function c0(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+8|0;g=f|0;c[g>>2]=b;h=c[a+48>>2]|0;if((h|0)!=0){j=1<<h+2;h=a+100|0;k=c[h>>2]|0;l=c[a+108>>2]|0;m=c[a+92>>2]|0;n=m+(k>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7);if((j|0)<26){n=32-j|0;p=k+j|0;c[h>>2]=l>>>0>p>>>0?p:l;q=o>>>(n>>>0);r=n}else{n=k+16|0;k=l>>>0>n>>>0?n:l;c[h>>2]=k;n=j-16|0;p=m+(k>>>3)|0;m=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(k&7)>>>((48-j|0)>>>0);p=k+n|0;c[h>>2]=l>>>0>p>>>0?p:l;q=m|o>>>16<<n;r=32-j|0}c[e>>2]=q<<r}r=a+1384|0;c[r>>2]=0;g0(c[e>>2]|0,0,0,g,r);g=a+20|0;if((c[r>>2]|0)==0){s=0}else{e=0;while(1){q=b+(e<<2)|0;c[q>>2]=c[g>>2]>>c[q>>2];q=e+1|0;j=c[r>>2]|0;if(q>>>0<j>>>0){e=q}else{s=j;break}}}e=c[a+1368>>2]|0;if((e|0)==(c[g>>2]|0)|(s|0)==0){i=f;return}else{t=0;u=e}while(1){v=b+(t<<2)|0;e=c[v>>2]|0;if(!(u>>>0>e>>>0)){break}g=t+1|0;if(g>>>0<s>>>0){t=g;u=u-e|0}else{w=12;break}}if((w|0)==12){i=f;return}c[v>>2]=u;c[r>>2]=t+1;i=f;return}function d0(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0;g=i;i=i+152|0;h=g|0;j=g+32|0;k=g+64|0;l=g+96|0;m=g+128|0;n=g+136|0;o=g+144|0;p=e+92|0;q=c[f+16>>2]|0;c[q>>2]=0;r=e+100|0;s=c[r>>2]|0;t=p|0;u=c[t>>2]|0;v=d[u+(s>>>3)|0]|0;w=e+108|0;c[r>>2]=((s|0)<(c[w>>2]|0))+s;if((v&128>>>((s&7)>>>0)|0)==0){s=c[e>>2]|0;if((c[f>>2]|0)==0){x=-1094995529;i=g;return x|0}v=c[f+48>>2]|0;c[v>>2]=0;y=c[r>>2]|0;z=d[u+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[w>>2]|0))+y;y=c[f+8>>2]|0;c[y>>2]=z&1;z=c[r>>2]|0;A=d[u+(z>>>3)|0]<<(z&7)>>>7;c[r>>2]=((z|0)<(c[w>>2]|0))+z;c[f+12>>2]=A&1;A=c[w>>2]|0;z=(c[r>>2]|0)+5|0;B=A>>>0>z>>>0?z:A;c[r>>2]=B;if((c[y>>2]|0)!=0){if((c[e+12>>2]|0)==0){z=c[s+796>>2]|0;if((z|0)==0){C=0;D=0}else{E=z;F=209}}else{E=24;F=209}do{if((F|0)==209){z=u+(B>>>3)|0;s=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7);if((E|0)<26){z=E+B|0;c[r>>2]=A>>>0>z>>>0?z:A;C=s>>>((32-E|0)>>>0);D=E;break}else{z=B+16|0;G=A>>>0>z>>>0?z:A;c[r>>2]=G;z=E-16|0;H=u+(G>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7)>>>((48-E|0)>>>0);H=z+G|0;c[r>>2]=A>>>0>H>>>0?H:A;C=I|s>>>16<<z;D=E;break}}}while(0);E=32-D|0;c[v>>2]=C<<E>>E}c[y>>2]=1;x=0;i=g;return x|0}y=c[e>>2]|0;E=c[f+40>>2]|0;c[c[f+8>>2]>>2]=0;C=c[f+20>>2]|0;c[C>>2]=1;v=c[r>>2]|0;D=d[u+(v>>>3)|0]<<(v&7)>>>7;c[r>>2]=((v|0)<(c[w>>2]|0))+v;v=f+12|0;c[v>>2]=D&1;D=c[C>>2]|0;A=e+52|0;B=(c[A>>2]|0)==0;z=(c[e+56>>2]|0)==0;do{if(B){if(z){J=0}else{F=6}}else{if(z){F=6;break}s=c[r>>2]|0;I=c[w>>2]|0;H=u+(s>>>3)|0;G=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(s&7)>>>30;H=s+2|0;c[r>>2]=I>>>0>H>>>0?H:I;J=G}}while(0);if((F|0)==6){z=c[r>>2]|0;G=d[u+(z>>>3)|0]<<(z&7)>>>7;c[r>>2]=((z|0)<(c[w>>2]|0))+z;J=G<<1&2}G=1<<J;z=f|0;I=c[z>>2]|0;if((G-1&I|0)!=0){KIb(y,24,2124128,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;x=-1094995529;i=g;return x|0}H=I>>>(J>>>0);J=(c[e+8>>2]|0)>1|0;do{if(B){I=J|4;s=c[r>>2]|0;L=c[w>>2]|0;M=u+(s>>>3)|0;N=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(s&7)>>>((32-I|0)>>>0);M=s+I|0;I=L>>>0>M>>>0?M:L;c[r>>2]=I;c[h>>2]=N;if(!(G>>>0>1>>>0)){O=I;P=L;break}M=c[e+104>>2]|0;s=1;Q=N;N=I;while(1){I=M-N|0;R=0;S=N;while(1){if((R|0)>=(I|0)){T=S;break}U=d[u+(S>>>3)|0]|0;V=((S|0)<(L|0))+S|0;c[r>>2]=V;if((U&128>>>((S&7)>>>0)|0)==0){T=V;break}else{R=R+1|0;S=V}}S=(R<<31>>31^R>>1)+Q|0;c[h+(s<<2)>>2]=S;I=s+1|0;if(I>>>0<G>>>0){s=I;Q=S;N=T}else{O=T;P=L;break}}}else{L=J|8;N=c[r>>2]|0;Q=c[w>>2]|0;s=u+(N>>>3)|0;M=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(N&7)>>>((32-L|0)>>>0);s=N+L|0;L=Q>>>0>s>>>0?s:Q;c[r>>2]=L;c[h>>2]=M;if(G>>>0>1>>>0){s=(c[e+104>>2]|0)-2|0;N=1;S=M;M=L;while(1){I=s-M|0;V=0;U=M;while(1){if((V|0)>=(I|0)){W=U;break}X=d[u+(U>>>3)|0]|0;Y=((U|0)<(Q|0))+U|0;c[r>>2]=Y;if((X&128>>>((U&7)>>>0)|0)==0){W=Y;break}else{V=V+1|0;U=Y}}U=d[u+(W>>>3)|0]<<(W&7);I=((W|0)<(Q|0))+W|0;c[r>>2]=I;R=u+(I>>>3)|0;Y=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(I&7)>>>31;R=I+1|0;I=Q>>>0>R>>>0?R:Q;c[r>>2]=I;R=((Y|V<<1)^(U>>>7&1)-1)+S|0;c[h+(N<<2)>>2]=R;U=N+1|0;if(U>>>0<G>>>0){N=U;S=R;M=I}else{Z=I;break}}}else{Z=L}M=0;while(1){S=h+(M<<2)|0;N=c[S>>2]|0;c[j+(M<<2)>>2]=N&15;c[S>>2]=N>>>4;N=M+1|0;if(N>>>0<G>>>0){M=N}else{O=Z;P=Q;break}}}}while(0);Z=1;while(1){if(!(Z>>>0<G>>>0)){break}if((c[h+(Z<<2)>>2]|0)>>>0>32>>>0){F=27;break}else{Z=Z+1|0}}if((F|0)==27){KIb(y,16,2642360,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;x=-1094995529;i=g;return x|0}Z=d[u+(O>>>3)|0]|0;W=((O|0)<(P|0))+O|0;c[r>>2]=W;if((Z&128>>>((O&7)>>>0)|0)!=0){O=u+(W>>>3)|0;Z=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(W&7)>>>28;O=W+4|0;c[r>>2]=P>>>0>O>>>0?O:P;c[q>>2]=Z+1}if((c[v>>2]|0)==0){F=32}else{if((c[f+56>>2]|0)==0){F=32}else{_=1}}if((F|0)==32){_=(c[q>>2]|0)!=0|0}c[c[f+24>>2]>>2]=_;do{if((c[e+76>>2]|0)==0){do{if((c[e+32>>2]|0)==0){_=c[e+44>>2]|0;c[C>>2]=_;$=_}else{_=((c[z>>2]|0)>>>3)-1|0;q=e+44|0;v=(c[q>>2]|0)+1|0;if((_|0)<2){aa=2}else{aa=(((_|0)>(v|0)?v:_)<<1)-2|0}_=aa>>>0>65535>>>0;v=_?aa>>>16:aa;Z=_?16:0;if((v&65280|0)==0){ba=Z;ca=v}else{ba=Z|8;ca=v>>>8}v=(d[1359664+ca|0]|0)+ba|0;Z=c[r>>2]|0;_=c[w>>2]|0;P=u+(Z>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Z&7)>>>((32-v|0)>>>0);P=v+Z|0;c[r>>2]=_>>>0>P>>>0?P:_;c[C>>2]=O;_=c[q>>2]|0;if(!(O>>>0>_>>>0)){$=O;break}c[C>>2]=_;KIb(y,16,2619112,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;x=-1094995529;i=g;return x|0}}while(0);_=c[z>>2]|0;if($>>>0>_>>>0){c[C>>2]=_;KIb(y,16,2619112,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;x=-1094995529;i=g;return x|0}if(($|0)==0){da=0;break}_=e+36|0;if((c[_>>2]|0)==3){O=c[r>>2]|0;q=c[w>>2]|0;P=u+(O>>>3)|0;Z=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(O&7)>>>25;P=O+7|0;c[r>>2]=q>>>0>P>>>0?P:q;c[E>>2]=b[735336+(Z<<1)>>1]<<5;if(!($>>>0>1>>>0)){da=$;break}Z=c[r>>2]|0;q=c[w>>2]|0;P=u+(Z>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Z&7)>>>25;P=Z+7|0;c[r>>2]=q>>>0>P>>>0?P:q;c[E+4>>2]=(b[735336+(O<<1)>>1]|0)*-32|0;if($>>>0>2>>>0){ea=2}else{da=2;break}while(1){O=c[r>>2]|0;q=c[w>>2]|0;P=u+(O>>>3)|0;Z=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(O&7)>>>25;P=O+7|0;c[r>>2]=q>>>0>P>>>0?P:q;c[E+(ea<<2)>>2]=Z;Z=ea+1|0;if(Z>>>0<$>>>0){ea=Z}else{fa=1040384;break}}}else{Z=$>>>0>20>>>0?20:$;q=e+104|0;P=0;while(1){if(!(P>>>0<Z>>>0)){break}O=c[_>>2]|0;v=a[735592+(O*40|0)+(P<<1)+1|0]|0;W=v<<24>>24;J=a[735592+(O*40|0)+(P<<1)|0]|0;O=c[r>>2]|0;T=(c[q>>2]|0)-(O+W)|0;B=0;Q=O;while(1){if((B|0)>=(T|0)){ga=Q;break}O=d[u+(Q>>>3)|0]|0;M=((Q|0)<(c[w>>2]|0))+Q|0;c[r>>2]=M;if((O&128>>>((Q&7)>>>0)|0)==0){ga=M;break}else{B=B+1|0;Q=M}}Q=v<<24>>24!=0;do{if(Q){T=d[u+(ga>>>3)|0]<<(ga&7)>>>7;V=c[w>>2]|0;M=((ga|0)<(V|0))+ga|0;c[r>>2]=M;O=T&1;if(!((v&255)>>>0>1>>>0)){ha=O;F=62;break}T=W-1|0;L=B<<T;do{if((T|0)==0){ia=0}else{N=u+(M>>>3)|0;S=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(M&7);if((T|0)<26){N=M+T|0;c[r>>2]=V>>>0>N>>>0?N:V;ia=S>>>((33-W|0)>>>0);break}else{N=M+16|0;s=V>>>0>N>>>0?N:V;c[r>>2]=s;N=W-17|0;I=u+(s>>>3)|0;R=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(s&7)>>>((49-W|0)>>>0);I=s+N|0;c[r>>2]=V>>>0>I>>>0?I:V;ia=R|S>>>16<<N;break}}}while(0);ja=ia+L|0;ka=O}else{ha=B&1^1;F=62}}while(0);if((F|0)==62){F=0;ja=B>>(Q&1^1);ka=ha}la=(((ka|0)==0)<<31>>31^ja)+J|0;c[E+(P<<2)>>2]=la;if((la+64|0)>>>0>127>>>0){F=64;break}else{P=P+1|0}}if((F|0)==64){KIb(y,16,2591720,(K=i,i=i+8|0,c[K>>2]=la,K)|0);i=K;x=-1094995529;i=g;return x|0}_=$>>>0>127>>>0?127:$;if(P>>>0<_>>>0){Z=P;do{W=c[r>>2]|0;v=-2-W+(c[q>>2]|0)|0;V=0;M=W;while(1){if((V|0)>=(v|0)){F=70;break}W=d[u+(M>>>3)|0]|0;T=c[w>>2]|0;N=((M|0)<(T|0))+M|0;c[r>>2]=N;if((W&128>>>((M&7)>>>0)|0)==0){ma=N;na=T;break}else{V=V+1|0;M=N}}if((F|0)==70){F=0;ma=M;na=c[w>>2]|0}v=d[u+(ma>>>3)|0]<<(ma&7);J=((ma|0)<(na|0))+ma|0;c[r>>2]=J;Q=u+(J>>>3)|0;B=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(J&7)>>>31;Q=J+1|0;c[r>>2]=na>>>0>Q>>>0?Q:na;c[E+(Z<<2)>>2]=((B|V<<1)^(v>>>7&1)-1)+(Z&1);Z=Z+1|0;}while(Z>>>0<_>>>0);oa=$>>>0<127>>>0?$:127}else{oa=P}if(oa>>>0<$>>>0){_=oa;do{Z=c[r>>2]|0;v=(c[q>>2]|0)+~Z|0;B=0;Q=Z;while(1){if((B|0)>=(v|0)){F=75;break}Z=d[u+(Q>>>3)|0]|0;J=c[w>>2]|0;N=((Q|0)<(J|0))+Q|0;c[r>>2]=N;if((Z&128>>>((Q&7)>>>0)|0)==0){pa=N;qa=J;break}else{B=B+1|0;Q=N}}if((F|0)==75){F=0;pa=Q;qa=c[w>>2]|0}v=d[u+(pa>>>3)|0]<<(pa&7);c[r>>2]=((pa|0)<(qa|0))+pa;c[E+(_<<2)>>2]=(v>>>7&1)-1^B;_=_+1|0;}while(_>>>0<$>>>0)}c[E>>2]=b[735336+((c[E>>2]|0)+64<<1)>>1]<<5;if(!($>>>0>1>>>0)){da=$;break}_=E+4|0;c[_>>2]=(b[735336+((c[_>>2]|0)+64<<1)>>1]|0)*-32|0;fa=8192}if($>>>0>2>>>0){ra=2}else{da=$;break}while(1){_=E+(ra<<2)|0;c[_>>2]=(c[_>>2]<<14)+fa;_=ra+1|0;if(_>>>0<$>>>0){ra=_}else{da=$;break}}}else{da=D}}while(0);do{if((c[e+40>>2]|0)!=0){D=c[r>>2]|0;$=d[u+(D>>>3)|0]<<(D&7)>>>7;c[r>>2]=((D|0)<(c[w>>2]|0))+D;D=$&1;c[c[f+28>>2]>>2]=D;if((D|0)==0){break}D=c[r>>2]|0;$=e+104|0;ra=(c[$>>2]|0)+~D|0;fa=0;E=D;while(1){if((fa|0)>=(ra|0)){F=86;break}D=d[u+(E>>>3)|0]|0;pa=c[w>>2]|0;qa=((E|0)<(pa|0))+E|0;c[r>>2]=qa;if((D&128>>>((E&7)>>>0)|0)==0){sa=qa;ta=pa;break}else{fa=fa+1|0;E=qa}}if((F|0)==86){sa=E;ta=c[w>>2]|0}ra=d[u+(sa>>>3)|0]<<(sa&7);c[r>>2]=((sa|0)<(ta|0))+sa;qa=c[f+36>>2]|0;c[qa>>2]=((ra>>>7&1)+536870911^fa)<<3;ra=c[r>>2]|0;pa=-2-ra+(c[$>>2]|0)|0;D=0;oa=ra;while(1){if((D|0)>=(pa|0)){F=90;break}ra=d[u+(oa>>>3)|0]|0;na=c[w>>2]|0;ma=((oa|0)<(na|0))+oa|0;c[r>>2]=ma;if((ra&128>>>((oa&7)>>>0)|0)==0){ua=ma;va=na;break}else{D=D+1|0;oa=ma}}if((F|0)==90){ua=oa;va=c[w>>2]|0}pa=d[u+(ua>>>3)|0]<<(ua&7);fa=((ua|0)<(va|0))+ua|0;c[r>>2]=fa;E=u+(fa>>>3)|0;ma=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(fa&7)>>>31;E=fa+1|0;c[r>>2]=va>>>0>E>>>0?E:va;c[qa+4>>2]=((ma|D<<1)^(pa>>>7&1)+536870911)<<3;pa=0;ma=c[r>>2]|0;while(1){if((pa|0)>=3){F=94;break}E=d[u+(ma>>>3)|0]|0;fa=c[w>>2]|0;na=((ma|0)<(fa|0))+ma|0;c[r>>2]=na;if((E&128>>>((ma&7)>>>0)|0)==0){wa=na;xa=fa;break}else{pa=pa+1|0;ma=na}}if((F|0)==94){wa=ma;xa=c[w>>2]|0}D=u+(wa>>>3)|0;oa=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(wa&7)>>>30;D=wa+2|0;c[r>>2]=xa>>>0>D>>>0?D:xa;c[qa+8>>2]=d[841872+(pa<<2)+oa|0]|0;oa=c[r>>2]|0;D=-2-oa+(c[$>>2]|0)|0;na=0;fa=oa;while(1){if((na|0)>=(D|0)){F=98;break}oa=d[u+(fa>>>3)|0]|0;E=c[w>>2]|0;ra=((fa|0)<(E|0))+fa|0;c[r>>2]=ra;if((oa&128>>>((fa&7)>>>0)|0)==0){ya=ra;za=E;break}else{na=na+1|0;fa=ra}}if((F|0)==98){ya=fa;za=c[w>>2]|0}D=d[u+(ya>>>3)|0]<<(ya&7);pa=((ya|0)<(za|0))+ya|0;c[r>>2]=pa;ma=u+(pa>>>3)|0;ra=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(pa&7)>>>31;ma=pa+1|0;c[r>>2]=za>>>0>ma>>>0?ma:za;c[qa+12>>2]=((ra|na<<1)^(D>>>7&1)+536870911)<<3;D=c[r>>2]|0;ra=(c[$>>2]|0)+~D|0;ma=0;pa=D;while(1){if((ma|0)>=(ra|0)){F=102;break}D=d[u+(pa>>>3)|0]|0;E=c[w>>2]|0;oa=((pa|0)<(E|0))+pa|0;c[r>>2]=oa;if((D&128>>>((pa&7)>>>0)|0)==0){Aa=oa;Ba=E;break}else{ma=ma+1|0;pa=oa}}if((F|0)==102){Aa=pa;Ba=c[w>>2]|0}ra=d[u+(Aa>>>3)|0]<<(Aa&7);c[r>>2]=((Aa|0)<(Ba|0))+Aa;c[qa+16>>2]=((ra>>>7&1)+536870911^ma)<<3;ra=c[e+1400>>2]|0;$=c[r>>2]|0;na=c[w>>2]|0;fa=u+($>>>3)|0;oa=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<($&7)>>>((32-ra|0)>>>0);fa=$+ra|0;c[r>>2]=na>>>0>fa>>>0?fa:na;na=da+1|0;c[c[f+32>>2]>>2]=oa+(na>>>0<4>>>0?4:na)}}while(0);if((c[f+4>>2]|0)==0){Ca=0}else{do{if((da|0)!=0){Aa=c[y+796>>2]|0;Ba=Aa-4|0;za=c[r>>2]|0;ya=e+104|0;xa=4-Aa-za+(c[ya>>2]|0)|0;wa=0;va=za;while(1){if((wa|0)>=(xa|0)){Da=va;break}za=d[u+(va>>>3)|0]|0;ua=((va|0)<(c[w>>2]|0))+va|0;c[r>>2]=ua;if((za&128>>>((va&7)>>>0)|0)==0){Da=ua;break}else{wa=wa+1|0;va=ua}}va=(Ba|0)!=0;do{if(va){xa=d[u+(Da>>>3)|0]<<(Da&7)>>>7;ma=c[w>>2]|0;qa=((Da|0)<(ma|0))+Da|0;c[r>>2]=qa;pa=xa&1;if(!(Ba>>>0>1>>>0)){Ea=pa;F=118;break}xa=Aa-5|0;ua=wa<<xa;do{if((xa|0)==0){Fa=0}else{za=u+(qa>>>3)|0;sa=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(qa&7);if((xa|0)<26){za=qa+xa|0;c[r>>2]=ma>>>0>za>>>0?za:ma;Fa=sa>>>((37-Aa|0)>>>0);break}else{za=qa+16|0;ta=ma>>>0>za>>>0?za:ma;c[r>>2]=ta;za=Aa-21|0;na=u+(ta>>>3)|0;oa=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ta&7)>>>((53-Aa|0)>>>0);na=ta+za|0;c[r>>2]=ma>>>0>na>>>0?na:ma;Fa=oa|sa>>>16<<za;break}}}while(0);Ga=Fa+ua|0;Ha=pa}else{Ea=wa&1^1;F=118}}while(0);if((F|0)==118){Ga=wa>>(va&1^1);Ha=Ea}Aa=c[f+48>>2]|0;c[Aa>>2]=((Ha|0)==0)<<31>>31^Ga;if(!(da>>>0>1>>>0)){break}Ba=c[h>>2]|0;ma=Ba+3|0;qa=e+1388|0;xa=c[qa>>2]|0;B=ma>>>0>xa>>>0?xa:ma;ma=c[r>>2]|0;xa=(c[ya>>2]|0)-(B+ma)|0;Q=0;za=ma;while(1){if((Q|0)>=(xa|0)){Ia=za;break}ma=d[u+(za>>>3)|0]|0;sa=((za|0)<(c[w>>2]|0))+za|0;c[r>>2]=sa;if((ma&128>>>((za&7)>>>0)|0)==0){Ia=sa;break}else{Q=Q+1|0;za=sa}}za=(B|0)!=0;do{if(za){xa=d[u+(Ia>>>3)|0]<<(Ia&7)>>>7;va=c[w>>2]|0;wa=((Ia|0)<(va|0))+Ia|0;c[r>>2]=wa;sa=xa&1;if(!(B>>>0>1>>>0)){Ja=sa;F=131;break}xa=B-1|0;ma=Q<<xa;do{if((xa|0)==0){Ka=0}else{oa=u+(wa>>>3)|0;na=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(wa&7);if((xa|0)<26){oa=wa+xa|0;c[r>>2]=va>>>0>oa>>>0?oa:va;Ka=na>>>((33-B|0)>>>0);break}else{oa=wa+16|0;ta=va>>>0>oa>>>0?oa:va;c[r>>2]=ta;oa=B-17|0;fa=u+(ta>>>3)|0;ra=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ta&7)>>>((49-B|0)>>>0);fa=ta+oa|0;c[r>>2]=va>>>0>fa>>>0?fa:va;Ka=ra|na>>>16<<oa;break}}}while(0);La=Ka+ma|0;Ma=sa}else{Ja=Q&1^1;F=131}}while(0);if((F|0)==131){La=Q>>(za&1^1);Ma=Ja}c[Aa+4>>2]=((Ma|0)==0)<<31>>31^La;if(!(da>>>0>2>>>0)){break}B=Ba+1|0;va=c[qa>>2]|0;wa=B>>>0>va>>>0?va:B;B=c[r>>2]|0;va=(c[ya>>2]|0)-(wa+B)|0;xa=0;pa=B;while(1){if((xa|0)>=(va|0)){Na=pa;break}B=d[u+(pa>>>3)|0]|0;ua=((pa|0)<(c[w>>2]|0))+pa|0;c[r>>2]=ua;if((B&128>>>((pa&7)>>>0)|0)==0){Na=ua;break}else{xa=xa+1|0;pa=ua}}pa=(wa|0)!=0;do{if(pa){va=d[u+(Na>>>3)|0]<<(Na&7)>>>7;ya=c[w>>2]|0;qa=((Na|0)<(ya|0))+Na|0;c[r>>2]=qa;Ba=va&1;if(!(wa>>>0>1>>>0)){Oa=Ba;F=144;break}va=wa-1|0;za=xa<<va;do{if((va|0)==0){Pa=0}else{Q=u+(qa>>>3)|0;ua=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(qa&7);if((va|0)<26){Q=qa+va|0;c[r>>2]=ya>>>0>Q>>>0?Q:ya;Pa=ua>>>((33-wa|0)>>>0);break}else{Q=qa+16|0;B=ya>>>0>Q>>>0?Q:ya;c[r>>2]=B;Q=wa-17|0;oa=u+(B>>>3)|0;na=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(B&7)>>>((49-wa|0)>>>0);oa=B+Q|0;c[r>>2]=ya>>>0>oa>>>0?oa:ya;Pa=na|ua>>>16<<Q;break}}}while(0);Qa=Pa+za|0;Ra=Ba}else{Oa=xa&1^1;F=144}}while(0);if((F|0)==144){Qa=xa>>(pa&1^1);Ra=Oa}c[Aa+8>>2]=((Ra|0)==0)<<31>>31^Qa}}while(0);Ca=da>>>0>3>>>0?3:da}if((c[A>>2]|0)==0){A=e+104|0;da=(c[f+48>>2]|0)+(Ca<<2)|0;Qa=0;Ra=Ca;while(1){if(Ra>>>0<H>>>0){Oa=h+(Qa<<2)|0;Pa=da;Na=Ra;while(1){La=c[Oa>>2]|0;Ma=c[r>>2]|0;Ja=(c[A>>2]|0)-(Ma+La)|0;Ka=0;Ia=Ma;while(1){if((Ka|0)>=(Ja|0)){Sa=Ia;break}Ma=d[u+(Ia>>>3)|0]|0;Ga=((Ia|0)<(c[w>>2]|0))+Ia|0;c[r>>2]=Ga;if((Ma&128>>>((Ia&7)>>>0)|0)==0){Sa=Ga;break}else{Ka=Ka+1|0;Ia=Ga}}Ia=(La|0)!=0;do{if(Ia){Ja=d[u+(Sa>>>3)|0]<<(Sa&7)>>>7;Ba=c[w>>2]|0;za=((Sa|0)<(Ba|0))+Sa|0;c[r>>2]=za;Ga=Ja&1;if(!(La>>>0>1>>>0)){Ta=Ga;F=196;break}Ja=La-1|0;Ma=Ka<<Ja;do{if((Ja|0)==0){Ua=0}else{Ha=u+(za>>>3)|0;Ea=(je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(za&7);if((Ja|0)<26){Ha=za+Ja|0;c[r>>2]=Ba>>>0>Ha>>>0?Ha:Ba;Ua=Ea>>>((33-La|0)>>>0);break}else{Ha=za+16|0;Fa=Ba>>>0>Ha>>>0?Ha:Ba;c[r>>2]=Fa;Ha=La-17|0;Da=u+(Fa>>>3)|0;y=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Fa&7)>>>((49-La|0)>>>0);Da=Fa+Ha|0;c[r>>2]=Ba>>>0>Da>>>0?Da:Ba;Ua=y|Ea>>>16<<Ha;break}}}while(0);Va=Ua+Ma|0;Wa=Ga}else{Ta=Ka&1^1;F=196}}while(0);if((F|0)==196){F=0;Va=Ka>>(Ia&1^1);Wa=Ta}c[Pa>>2]=((Wa|0)==0)<<31>>31^Va;La=Na+1|0;if(!(La>>>0<H>>>0)){break}Pa=Pa+4|0;Na=La}Xa=da+(H-Ra<<2)|0}else{Xa=da}Na=Qa+1|0;if(Na>>>0<G>>>0){da=Xa;Qa=Na;Ra=0}else{break}}}else{Ra=(c[z>>2]<<1)-2|0;z=Ra>>>0>65535>>>0;Qa=z?Ra>>>16:Ra;Ra=z?16:0;if((Qa&65280|0)==0){Ya=Ra;Za=Qa}else{Ya=Ra|8;Za=Qa>>>8}Qa=Ya-3+(d[1359664+Za|0]|0)>>1;if((Qa|0)<0){_a=0}else{_a=(Qa|0)>5?5:Qa}z2(p,m,n,o);Qa=f+48|0;f=e+1392|0;Za=e+1396|0;Ya=(c[Qa>>2]|0)+(Ca<<2)|0;Ra=0;while(1){z=H-((Ra|0)!=0?0:Ca)|0;Xa=c[h+(Ra<<2)>>2]|0;da=Xa>>>0>_a>>>0?Xa-_a|0:0;c[l+(Ra<<2)>>2]=da;Va=da+(5-Xa)|0;c[k+(Ra<<2)>>2]=Va;B2(p,z,Ya,Va,c[j+(Ra<<2)>>2]|0,m,n,o,c[f>>2]|0,c[Za>>2]|0);Va=Ra+1|0;if(!(Va>>>0<G>>>0)){break}Ya=Ya+(z<<2)|0;Ra=Va}A2(p);p=e+104|0;Ra=(c[Qa>>2]|0)+(Ca<<2)|0;Qa=0;Ya=Ca;while(1){Ca=k+(Qa<<2)|0;Za=j+(Qa<<2)|0;f=d[(c[Ca>>2]|0)+(312656+((c[Za>>2]|0)*6|0))|0]|0;o=c[l+(Qa<<2)>>2]|0;n=c[h+(Qa<<2)>>2]|0;if(Ya>>>0<H>>>0){m=(n|0)!=0;_a=n>>>0>1>>>0;Va=n-1|0;z=(Va|0)==0;Xa=(Va|0)<26;da=33-n|0;Wa=n-17|0;Ta=49-n|0;Ua=m&1^1;u=(o|0)==0;Sa=(o|0)<26;A=32-o|0;Na=o-16|0;Pa=48-o|0;Oa=Ra;Aa=Ya;while(1){pa=c[Oa>>2]|0;do{if((pa|0)==(f|0)){xa=c[Za>>2]|0;La=(xa>>>0>2>>>0|2)+(xa>>>0>10>>>0)<<5-(c[Ca>>2]|0);xa=c[r>>2]|0;Ba=(c[p>>2]|0)-(xa+n)|0;za=0;Ja=xa;while(1){if((za|0)>=(Ba|0)){$a=Ja;break}xa=d[(c[t>>2]|0)+(Ja>>>3)|0]|0;O=((Ja|0)<(c[w>>2]|0))+Ja|0;c[r>>2]=O;if((xa&128>>>((Ja&7)>>>0)|0)==0){$a=O;break}else{za=za+1|0;Ja=O}}do{if(m){Ja=c[t>>2]|0;Ba=d[Ja+($a>>>3)|0]<<($a&7)>>>7;Ga=c[w>>2]|0;Ma=(($a|0)<(Ga|0))+$a|0;c[r>>2]=Ma;O=Ba&1;if(!_a){ab=O;F=170;break}Ba=za<<Va;do{if(z){bb=0}else{xa=Ja+(Ma>>>3)|0;L=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ma&7);if(Xa){xa=Ma+Va|0;c[r>>2]=Ga>>>0>xa>>>0?xa:Ga;bb=L>>>(da>>>0);break}else{xa=Ma+16|0;Ha=Ga>>>0>xa>>>0?xa:Ga;c[r>>2]=Ha;xa=Ja+(Ha>>>3)|0;Ea=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ha&7)>>>(Ta>>>0);xa=Ha+Wa|0;c[r>>2]=Ga>>>0>xa>>>0?xa:Ga;bb=Ea|L>>>16<<Wa;break}}}while(0);cb=bb+Ba|0;db=O}else{ab=za&1^1;F=170}}while(0);if((F|0)==170){F=0;cb=za>>Ua;db=ab}Ga=((db|0)==0)<<31>>31^cb;if((Ga|0)>-1){eb=Ga+(La<<o)|0;break}else{eb=Ga-(La-1<<o)|0;break}}else{Ga=((pa>>>0>f>>>0)<<31>>31)+pa|0;Ja=((Ga&1|0)==0?Ga:-Ga|0)>>1;if(u){eb=Ja;break}Ga=c[r>>2]|0;Ma=c[w>>2]|0;L=c[t>>2]|0;Ea=L+(Ga>>>3)|0;xa=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ga&7);if(Sa){Ea=Ga+o|0;c[r>>2]=Ma>>>0>Ea>>>0?Ea:Ma;fb=xa>>>(A>>>0)}else{Ea=Ga+16|0;Ga=Ma>>>0>Ea>>>0?Ea:Ma;c[r>>2]=Ga;Ea=L+(Ga>>>3)|0;L=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ga&7)>>>(Pa>>>0);Ea=Ga+Na|0;c[r>>2]=Ma>>>0>Ea>>>0?Ea:Ma;fb=L|xa>>>16<<Na}eb=fb|Ja<<o}}while(0);c[Oa>>2]=eb;pa=Aa+1|0;if(pa>>>0<H>>>0){Oa=Oa+4|0;Aa=pa}else{break}}gb=Ra+(H-Ya<<2)|0}else{gb=Ra}Aa=Qa+1|0;if(Aa>>>0<G>>>0){Ra=gb;Qa=Aa;Ya=0}else{break}}}do{if((c[e+64>>2]|0)!=0){if((c[e+1376>>2]|0)==0){x=0}else{break}i=g;return x|0}}while(0);e=c[r>>2]|0;Ya=-e&7;if((Ya|0)==0){x=0;i=g;return x|0}Qa=c[w>>2]|0;w=Ya+e|0;c[r>>2]=Qa>>>0>w>>>0?w:Qa;x=0;i=g;return x|0}function e0(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;h=i;j=c[d+(g<<2)>>2]|0;k=a|0;l=c[(c[k>>2]|0)+416>>2]|0;m=e+(g<<2)|0;if((c[m>>2]|0)!=0){n=0;i=h;return n|0}c[m>>2]=1;a:do{if((l|0)==0){o=0}else{m=0;while(1){if((c[j+(m*44|0)>>2]|0)!=0){o=m;break a}e0(a,b,d,e,f,c[j+(m*44|0)+4>>2]|0)|0;p=m+1|0;if(p>>>0<l>>>0){m=p}else{o=p;break}}}}while(0);if((o|0)==(l|0)){KIb(c[k>>2]|0,24,2208544,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;n=-1094995529;i=h;return n|0}c[b+8>>2]=(c[a+1404>>2]|0)+(g<<2);c[b+16>>2]=(c[a+1408>>2]|0)+(g<<2);c[b+20>>2]=(c[a+1412>>2]|0)+(g<<2);c[b+24>>2]=(c[a+1416>>2]|0)+(g<<2);c[b+28>>2]=(c[a+1420>>2]|0)+(g<<2);c[b+32>>2]=(c[a+1424>>2]|0)+(g<<2);c[b+36>>2]=c[(c[a+1428>>2]|0)+(g<<2)>>2];c[b+44>>2]=c[(c[a+1444>>2]|0)+(g<<2)>>2];c[b+40>>2]=c[(c[a+1436>>2]|0)+(g<<2)>>2];k=a+1472|0;a=c[(c[k>>2]|0)+(g<<2)>>2]|0;c[b+48>>2]=a+(f<<2);if((c[j>>2]|0)!=0){n=0;i=h;return n|0}l=b|0;b=c[k>>2]|0;k=f-1|0;o=0;while(1){e=(c[l>>2]|0)-1|0;d=c[j+(o*44|0)+4>>2]|0;m=c[b+(d<<2)>>2]|0;b:do{if((d|0)!=(g|0)){if((c[j+(o*44|0)+8>>2]|0)==0){if(!(e>>>0>1>>>0)){break}p=j+(o*44|0)+20|0;q=j+(o*44|0)+24|0;r=j+(o*44|0)+28|0;s=1;while(1){t=c[p>>2]|0;u=c[m+(k+s<<2)>>2]|0;v=Erc(u,(u|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;t=wrc(v,G,64,0)|0;v=G;u=c[q>>2]|0;w=c[m+(s+f<<2)>>2]|0;x=Erc(w,(w|0)<0|0?-1:0,u,(u|0)<0|0?-1:0)|0;u=wrc(t,v,x,G)|0;x=G;v=c[r>>2]|0;t=s+1|0;w=c[m+(t+f<<2)>>2]|0;y=Erc(w,(w|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=wrc(u,x,y,G)|0;y=G;x=a+(s+f<<2)|0;u=wrc(v>>>7|y<<25,y>>>7|0<<25,c[x>>2]|0,0)|0;c[x>>2]=u;if(t>>>0<e>>>0){s=t}else{break b}}}s=c[j+(o*44|0)+16>>2]|0;if((c[j+(o*44|0)+12>>2]|0)==0){z=s;A=e-s|0;B=1}else{z=-s|0;A=e;B=s+1|0}if(!(B>>>0<A>>>0)){break}s=j+(o*44|0)+20|0;r=j+(o*44|0)+24|0;q=j+(o*44|0)+28|0;p=j+(o*44|0)+32|0;t=z+f|0;u=j+(o*44|0)+36|0;x=j+(o*44|0)+40|0;y=B;while(1){v=c[s>>2]|0;w=y-1|0;C=c[m+(w+f<<2)>>2]|0;D=Erc(C,(C|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=wrc(D,G,64,0)|0;D=G;C=c[r>>2]|0;E=c[m+(y+f<<2)>>2]|0;F=Erc(E,(E|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;C=wrc(v,D,F,G)|0;F=G;D=c[q>>2]|0;v=y+1|0;E=c[m+(v+f<<2)>>2]|0;H=Erc(E,(E|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;D=wrc(C,F,H,G)|0;H=G;F=c[p>>2]|0;C=c[m+(t+w<<2)>>2]|0;w=Erc(C,(C|0)<0|0?-1:0,F,(F|0)<0|0?-1:0)|0;F=wrc(D,H,w,G)|0;w=G;H=c[u>>2]|0;D=c[m+(t+y<<2)>>2]|0;C=Erc(D,(D|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;H=wrc(F,w,C,G)|0;C=G;w=c[x>>2]|0;F=c[m+(t+v<<2)>>2]|0;D=Erc(F,(F|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=wrc(H,C,D,G)|0;D=G;C=a+(y+f<<2)|0;H=wrc(w>>>7|D<<25,D>>>7|0<<25,c[C>>2]|0,0)|0;c[C>>2]=H;if(v>>>0<A>>>0){y=v}else{break}}}}while(0);m=o+1|0;if((c[j+(m*44|0)>>2]|0)==0){o=m}else{n=0;break}}i=h;return n|0}function f0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=b|0;e=c[d>>2]|0;do{if((c[c[b+8>>2]>>2]|0)==0){f=c[c[b+20>>2]>>2]|0;g=c[b+40>>2]|0;h=c[b+44>>2]|0;i=b+48|0;j=c[i>>2]|0;k=j+(e<<2)|0;l=c[a+1452>>2]|0;a:do{if((c[c[b+28>>2]>>2]|0)!=0){m=c[b+32>>2]|0;n=c[m>>2]|0;o=n-2|0;p=(o|0)>0?o:0;if(!(p>>>0<e>>>0)){break}o=b+36|0;q=p;p=n;while(1){n=q-p|0;r=n-2|0;s=(r|0)<0?0:r;r=n+3|0;if((s|0)<(r|0)){t=c[o>>2]|0;u=0;v=64;w=2-n+s|0;n=s;while(1){s=c[t+(w<<2)>>2]|0;x=c[j+(n<<2)>>2]|0;y=Erc(x,(x|0)<0|0?-1:0,s,(s|0)<0|0?-1:0)|0;z=wrc(y,G,v,u)|0;A=G;y=n+1|0;if((y|0)<(r|0)){u=A;v=z;w=w+1|0;n=y}else{break}}B=A>>>7|0<<25;C=z>>>7|A<<25}else{B=0;C=0}n=j+(q<<2)|0;w=wrc(c[n>>2]|0,0,C,B)|0;c[n>>2]=w;w=q+1|0;if(!(w>>>0<e>>>0)){break a}q=w;p=c[m>>2]|0}}}while(0);m=(f|0)==0;do{if((c[b+4>>2]|0)==0){if(!m){p=0;do{q=p-1|0;o=g+(p<<2)|0;if((q|0)>0){w=0;n=q;while(1){v=c[o>>2]|0;u=v;r=(v|0)<0|0?-1:0;v=h+(n<<2)|0;t=c[v>>2]|0;y=t;s=(t|0)<0|0?-1:0;t=Erc(y,s,u,r)|0;x=wrc(t,G,524288,0)|0;t=x>>>20|G<<12;x=h+(w<<2)|0;D=c[x>>2]|0;E=Erc(D,(D|0)<0|0?-1:0,u,r)|0;r=wrc(E,G,524288,0)|0;E=G;u=wrc(r>>>20|E<<12,E>>>20|0<<12,y,s)|0;c[v>>2]=u;c[x>>2]=t+(c[x>>2]|0);x=w+1|0;t=n-1|0;if((x|0)<(t|0)){w=x;n=t}else{F=x;H=t;break}}}else{F=0;H=q}if((F|0)==(H|0)){n=c[o>>2]|0;w=h+(H<<2)|0;t=c[w>>2]|0;x=Erc(t,(t|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=wrc(x,G,524288,0)|0;x=G;u=wrc(n>>>20|x<<12,x>>>20|0<<12,t,0)|0;c[w>>2]=u}c[h+(p<<2)>>2]=c[o>>2];p=p+1|0;}while(p>>>0<f>>>0)}if((c[c[b+24>>2]>>2]|0)!=0){p=c[a+44>>2]|0;nrc(c[b+52>>2]|0,j+(-p<<2)|0,p<<2)|0}do{if((c[b+12>>2]|0)!=0){p=c[b+56>>2]|0;if((p|0)==0){break}u=p>>>0>j>>>0;w=u?j:p;t=u?p:j;p=a+44|0;if((-(c[p>>2]|0)|0)>-1){break}else{I=-1}do{c[j+(I<<2)>>2]=(c[t+(I<<2)>>2]|0)-(c[w+(I<<2)>>2]|0);I=I-1|0;}while((I|0)>=(-(c[p>>2]|0)|0))}}while(0);p=c[b+16>>2]|0;w=c[p>>2]|0;if((w|0)==0){J=0;K=39;break}t=a+44|0;if((-(c[t>>2]|0)|0)>-1){J=0;K=39;break}o=j-4|0;c[o>>2]=c[o>>2]>>w;if((-(c[t>>2]|0)|0)>-2){J=0;K=39;break}else{L=-2}while(1){w=j+(L<<2)|0;c[w>>2]=c[w>>2]>>c[p>>2];w=L-1|0;if((w|0)<(-(c[t>>2]|0)|0)){J=0;K=39;break}else{L=w}}}else{if(m){M=0;N=0;break}else{O=j;P=0}while(1){if((P|0)==0){Q=0;R=0}else{t=0;p=524288;w=0;while(1){o=c[h+(w<<2)>>2]|0;q=w+1|0;u=c[O+(~w<<2)>>2]|0;x=Erc(u,(u|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;S=wrc(x,G,p,t)|0;T=G;if(q>>>0<P>>>0){t=T;p=S;w=q}else{break}}Q=T>>>20|0<<12;R=S>>>20|T<<12}w=O+4|0;p=xrc(c[O>>2]|0,0,R,Q)|0;c[O>>2]=p;p=P-1|0;t=g+(P<<2)|0;if((p|0)>0){q=0;x=p;while(1){o=c[t>>2]|0;u=o;n=(o|0)<0|0?-1:0;o=h+(x<<2)|0;v=c[o>>2]|0;s=v;y=(v|0)<0|0?-1:0;v=Erc(s,y,u,n)|0;E=wrc(v,G,524288,0)|0;v=E>>>20|G<<12;E=h+(q<<2)|0;r=c[E>>2]|0;D=Erc(r,(r|0)<0|0?-1:0,u,n)|0;n=wrc(D,G,524288,0)|0;D=G;u=wrc(n>>>20|D<<12,D>>>20|0<<12,s,y)|0;c[o>>2]=u;c[E>>2]=v+(c[E>>2]|0);E=q+1|0;v=x-1|0;if((E|0)<(v|0)){q=E;x=v}else{U=E;V=v;break}}}else{U=0;V=p}if((U|0)==(V|0)){x=c[t>>2]|0;q=h+(V<<2)|0;v=c[q>>2]|0;E=Erc(v,(v|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=wrc(E,G,524288,0)|0;E=G;u=wrc(x>>>20|E<<12,E>>>20|0<<12,v,0)|0;c[q>>2]=u}c[h+(P<<2)>>2]=c[t>>2];u=P+1|0;if(u>>>0<f>>>0){O=w;P=u}else{J=f;K=39;break}}}}while(0);do{if((K|0)==39){if((f|0)>0){W=0}else{M=J;N=0;break}while(1){g=W+1|0;c[l+(W<<2)>>2]=c[h+(f+~W<<2)>>2];if((g|0)<(f|0)){W=g}else{M=J;N=1;break}}}}while(0);h=c[i>>2]|0;g=h+(M<<2)|0;b:do{if(g>>>0<k>>>0){j=-f|0;if(N){X=g}else{m=g;while(1){m=m+4|0;if(!(m>>>0<k>>>0)){break b}}}do{m=0;u=524288;q=j;do{v=c[l+(q+f<<2)>>2]|0;E=c[X+(q<<2)>>2]|0;x=Erc(E,(E|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;u=wrc(x,G,u,m)|0;m=G;q=q+1|0;}while((q|0)<0);q=xrc(c[X>>2]|0,0,u>>>20|m<<12,m>>>20|0<<12)|0;c[X>>2]=q;X=X+4|0;}while(X>>>0<k>>>0)}}while(0);if((c[c[b+24>>2]>>2]|0)==0){break}k=c[a+44>>2]|0;nrc(h+(-k<<2)|0,c[b+52>>2]|0,k<<2)|0}else{k=c[b+48>>2]|0;f=c[k>>2]|0;l=e-1|0;if((l|0)==0){break}else{Y=k;Z=l}do{Y=Y+4|0;c[Y>>2]=f;Z=Z-1|0;}while((Z|0)!=0)}}while(0);Z=c[b+16>>2]|0;Y=c[Z>>2]|0;if((Y|0)==0){return}if((c[d>>2]|0)==0){return}e=c[b+48>>2]|0;b=0;a=Y;while(1){Y=e+(b<<2)|0;c[Y>>2]=c[Y>>2]<<a;Y=b+1|0;if(!(Y>>>0<(c[d>>2]|0)>>>0)){break}b=Y;a=c[Z>>2]|0}return}function g0(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a:do{if(b>>>0<31>>>0){g=b;h=d;while(1){if((1073741824>>>(g>>>0)&a|0)==0){i=h;break a}j=g<<1;k=h+1|0;g0(a,j|1,k,e,f);l=j+2|0;if(l>>>0<31>>>0){g=l;h=k}else{i=k;break}}}else{i=d}}while(0);d=c[e>>2]|0;c[d>>2]=i;c[e>>2]=d+4;c[f>>2]=(c[f>>2]|0)+1;return}function h0(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0.0;e=i;f=c[d+60>>2]|0;j=d+416|0;if((c[j>>2]|0)>1){RIb(d,2208512,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=e;return l|0}c[j>>2]=1;j=d+448|0;c[j>>2]=4;c[j+4>>2]=0;j=d+412|0;if((c[j>>2]|0)==0){c[j>>2]=8e3}c[d+420>>2]=3;c[f+1684>>2]=f+1524;d=f+464|0;j=f+664|0;k=f+704|0;m=0;do{h[d+(m<<3)>>3]=+((a[841920+m|0]|0)*1e3|0|0)*30517578125.0e-15;n=+(b[847080+(m<<1)>>1]|0)*30517578125.0e-15;g[j+(m<<2)>>2]=n;g[k+(m<<2)>>2]=n;m=m+1|0;}while((m|0)<10);g[f+2008>>2]=-14.0;g[f+2012>>2]=-14.0;g[f+2016>>2]=-14.0;g[f+2020>>2]=-14.0;olb(f+2336|0);Elb(f+2344|0);O3(f+2348|0);S3(f+2356|0);l=0;i=e;return l|0}function i0(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0.0,$=0.0,aa=0.0,ba=0.0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0.0,gc=0.0,hc=0.0,ic=0.0,jc=0,kc=0.0,lc=0.0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0.0,sc=0,tc=0.0,uc=0.0,vc=0,wc=0,yc=0,zc=0,Ac=0.0,Bc=0,Cc=0.0;m=i;i=i+1048|0;n=m|0;o=m+128|0;p=m+328|0;q=m+368|0;r=m+528|0;s=m+688|0;t=m+696|0;u=m+704|0;v=m+728|0;w=m+768|0;x=m+792|0;z=m+888|0;A=c[f+60>>2]|0;B=A;C=c[l+24>>2]|0;D=c[l+28>>2]|0;mrc(x|0,0,96)|0;c[j+76>>2]=160;l=M4a(f,j,0)|0;if((l|0)<0){E=l;i=m;return E|0}l=c[j>>2]|0;j=a[C]|0;F=(j&255)>>>3&15;a[A+114|0]=(j&255)>>>2&1^1;do{if(F>>>0>8>>>0){G=11}else{if(((d[1209896+F|0]|0)+1|0)>(D|0)){G=11;break}do{if(F>>>0<8>>>0){j=c[2019784+(F<<2)>>2]|0;mrc(A|0,0,114)|0;H=a[j]|0;if(H<<24>>24==0){break}else{I=j;J=H}while(1){H=I+2|0;j=d[I+1|0]|0;if(J<<24>>24==0){K=0;L=H}else{M=J&255;N=0;O=M;P=H;while(1){H=O-1|0;Q=d[P]|0;S=(d[C+((Q>>>3)+1)|0]|0)>>>((Q&7)>>>0)&1|N<<1;if((H|0)==0){break}else{N=S;O=H;P=P+1|0}}K=S&65535;L=I+(M+2)|0}b[B+(j>>>1<<1)>>1]=K;P=a[L]|0;if(P<<24>>24==0){break}else{I=L;J=P}}}}while(0);P=A+116|0;c[P>>2]=F;if((F|0)==7){O=w|0;c[O>>2]=904736+(e[A>>1]<<3);c[w+4>>2]=902688+(e[A+2>>1]<<3);N=A+4|0;H=e[N>>1]|0;c[w+8>>2]=900640+(H>>>1<<3);c[w+12>>2]=898592+(e[A+6>>1]<<3);c[w+16>>2]=898080+(e[A+8>>1]<<3);Q=v|0;g[Q>>2]=+(b[A+120>>1]|0)*.244140625*.65+337.8909912109375;g[v+4>>2]=+(b[A+122>>1]|0)*.244140625*.65+507.0799865722656;g[v+8>>2]=+(b[A+124>>1]|0)*.244140625*.65+834.9609985351562;g[v+12>>2]=+(b[A+126>>1]|0)*.244140625*.65+1247.0699462890625;g[v+16>>2]=+(b[A+128>>1]|0)*.244140625*.65+1646.0;g[v+20>>2]=+(b[A+130>>1]|0)*.244140625*.65+1982.9100341796875;g[v+24>>2]=+(b[A+132>>1]|0)*.244140625*.65+2407.9599609375;g[v+28>>2]=+(b[A+134>>1]|0)*.244140625*.65+2708.010009765625;g[v+32>>2]=+(b[A+136>>1]|0)*.244140625*.65+3104.0;g[v+36>>2]=+(b[A+138>>1]|0)*.244140625*.65+3344.969970703125;T=A+224|0;j0(B,T,Q,O,0,H&1,0);H=A+384|0;j0(B,H,Q,O,2,b[N>>1]&1,1);N=A+144|0;U=+h[T>>3]*.5;h[N>>3]=+h[A+464>>3]*.5+U;V=+h[A+232>>3]*.5;h[A+152>>3]=+h[A+472>>3]*.5+V;W=+h[A+240>>3]*.5;h[A+160>>3]=+h[A+480>>3]*.5+W;X=+h[A+248>>3]*.5;h[A+168>>3]=+h[A+488>>3]*.5+X;Y=+h[A+256>>3]*.5;h[A+176>>3]=+h[A+496>>3]*.5+Y;Z=+h[A+264>>3]*.5;h[A+184>>3]=+h[A+504>>3]*.5+Z;_=+h[A+272>>3]*.5;h[A+192>>3]=+h[A+512>>3]*.5+_;$=+h[A+280>>3]*.5;h[A+200>>3]=+h[A+520>>3]*.5+$;aa=+h[A+288>>3]*.5;h[A+208>>3]=+h[A+528>>3]*.5+aa;ba=+h[A+296>>3]*.5;h[A+216>>3]=+h[A+536>>3]*.5+ba;h[A+304>>3]=U+ +h[H>>3]*.5;h[A+312>>3]=V+ +h[A+392>>3]*.5;h[A+320>>3]=W+ +h[A+400>>3]*.5;h[A+328>>3]=X+ +h[A+408>>3]*.5;h[A+336>>3]=Y+ +h[A+416>>3]*.5;h[A+344>>3]=Z+ +h[A+424>>3]*.5;h[A+352>>3]=_+ +h[A+432>>3]*.5;h[A+360>>3]=$+ +h[A+440>>3]*.5;h[A+368>>3]=aa+ +h[A+448>>3]*.5;h[A+376>>3]=ba+ +h[A+456>>3]*.5;ca=N;da=A+544|0;ea=A+2344|0}else if((F|0)==15){break}else if((F|0)==8){N=f;RIb(N,2368576,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;KIb(N,32,2302760,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;E=-1163346256;i=m;return E|0}else{N=u;H=((F|0)==5?913992:917064)+((e[A>>1]|0)*6|0)|0;b[N>>1]=b[H>>1]|0;b[N+2>>1]=b[H+2>>1]|0;b[N+4>>1]=b[H+4>>1]|0;H=F>>>0<2>>>0;T=u+6|0;O=910920+((e[A+2>>1]<<(H&1))*6|0)|0;b[T>>1]=b[O>>1]|0;b[T+2>>1]=b[O+2>>1]|0;b[T+4>>1]=b[O+4>>1]|0;O=(H?905800:906824)+(e[A+4>>1]<<3)|0;H=u+12|0;T=O|0;Q=O+4|0;O=e[Q>>1]|e[Q+2>>1]<<16;Q=H|0;y=e[T>>1]|e[T+2>>1]<<16;b[Q>>1]=y;b[Q+2>>1]=y>>16;Q=H+4|0;y=O;b[Q>>1]=y;b[Q+2>>1]=y>>16;Q=0;do{g[v+(Q<<2)>>2]=+g[905760+(Q<<2)>>2]*125.0e-6+(+(b[u+(Q<<1)>>1]|0)+ +(b[B+120+(Q<<1)>>1]|0)*+g[699904+(Q<<2)>>2])*30517578125.0e-15;Q=Q+1|0;}while((Q|0)<10);Q=v|0;wPa(Q,.0062561,10);O=A+2344|0;H=A+664|0;T=A+544|0;Me[c[O>>2]&3](T,H,Q,.75,.25,10);Me[c[O>>2]&3](A+584|0,H,Q,.5,.5,10);Me[c[O>>2]&3](A+624|0,H,Q,.25,.75,10);Me[c[O>>2]&3](H,H,Q,0.0,1.0,10);nrc(A+120|0,N|0,20)|0;H=A+384|0;yPa(H,Q,10);Q=A+464|0;ga=A+472|0;ha=A+392|0;ia=A+480|0;ja=A+400|0;ka=A+488|0;la=A+408|0;ma=A+496|0;na=A+416|0;oa=A+504|0;pa=A+424|0;qa=A+512|0;ra=A+432|0;sa=A+520|0;ta=A+440|0;ua=A+528|0;va=A+448|0;wa=A+536|0;xa=A+456|0;ya=1;do{ba=+(ya|0);za=ya-1|0;aa=+h[Q>>3];h[B+144+(za*80|0)>>3]=aa+ba*(+h[H>>3]-aa)*.25;aa=+h[ga>>3];h[B+144+(za*80|0)+8>>3]=aa+ba*(+h[ha>>3]-aa)*.25;aa=+h[ia>>3];h[B+144+(za*80|0)+16>>3]=aa+ba*(+h[ja>>3]-aa)*.25;aa=+h[ka>>3];h[B+144+(za*80|0)+24>>3]=aa+ba*(+h[la>>3]-aa)*.25;aa=+h[ma>>3];h[B+144+(za*80|0)+32>>3]=aa+ba*(+h[na>>3]-aa)*.25;aa=+h[oa>>3];h[B+144+(za*80|0)+40>>3]=aa+ba*(+h[pa>>3]-aa)*.25;aa=+h[qa>>3];h[B+144+(za*80|0)+48>>3]=aa+ba*(+h[ra>>3]-aa)*.25;aa=+h[sa>>3];h[B+144+(za*80|0)+56>>3]=aa+ba*(+h[ta>>3]-aa)*.25;aa=+h[ua>>3];h[B+144+(za*80|0)+64>>3]=aa+ba*(+h[va>>3]-aa)*.25;aa=+h[wa>>3];h[B+144+(za*80|0)+72>>3]=aa+ba*(+h[xa>>3]-aa)*.25;ya=ya+1|0;}while((ya|0)<4);ca=A+144|0;da=T;ea=O}ya=A+744|0;xa=ya;CPa(ca,ya,5);CPa(ca+80|0,A+784|0,5);CPa(ca+160|0,A+824|0,5);CPa(ca+240|0,A+864|0,5);ya=A+10|0;wa=A+904|0;va=A+2336|0;ua=A+1684|0;ta=A+1688|0;sa=x+4|0;ra=x+8|0;qa=x|0;pa=x+12|0;oa=x+16|0;na=A+2040|0;ma=A+2064|0;la=x+88|0;ka=x+92|0;ja=A+1848|0;ia=A+2356|0;ha=A+2008|0;ga=A+2060|0;H=da;Q=A+704|0;N=A+708|0;za=A+712|0;Aa=A+716|0;Ba=A+720|0;Ca=A+724|0;Da=A+728|0;Ea=A+732|0;Fa=A+736|0;Ga=A+740|0;Ha=A+2068|0;Ia=A+2069|0;Ja=z|0;Ka=A+2072|0;La=A+2077|0;Ma=q|0;Na=r|0;Oa=z;Pa=A+2076|0;Qa=A+2176|0;Ra=ta;Sa=A+2348|0;Ta=o;Ua=v;Va=A+2080|0;Wa=o+40|0;Xa=p|0;Ya=o+160|0;Za=A+2352|0;_a=v|0;$a=A+2120|0;ab=n;bb=n+40|0;cb=n+44|0;db=cb;eb=A+2124|0;fb=A+464|0;gb=A+384|0;hb=A+908|0;ib=A+1068|0;jb=A+2024|0;kb=A+2028|0;lb=A+2044|0;mb=A+2048|0;nb=A+2136|0;ob=A+2296|0;pb=jb;qb=kb;rb=A+2032|0;sb=A+2036|0;tb=lb;ub=mb;vb=A+2052|0;wb=A+2056|0;xb=x+20|0;yb=x+44|0;zb=x+60|0;Ab=x+24|0;Bb=x+48|0;Cb=x+64|0;Db=x+28|0;Eb=x+52|0;Fb=x+68|0;Gb=x+32|0;Hb=x+56|0;Ib=x+72|0;Jb=0;while(1){Kb=b[ya+(Jb*26|0)>>1]|0;Lb=c[P>>2]|0;Mb=Kb&65535;Nb=d[wa]|0;do{if((Lb|0)==7){if((Jb|0)==2|(Jb|0)==0){if((Kb&65535)>>>0<463>>>0){Ob=((Mb*10923|0)+1168761|0)>>>16;c[s>>2]=Ob;Pb=Mb+105+(Ob*-6|0)|0;c[t>>2]=Pb;Qb=Ob;Rb=0;Sb=Pb;break}else{Pb=Mb-368|0;c[s>>2]=Pb;c[t>>2]=0;Qb=Pb;Rb=0;Sb=0;break}}else{Pb=(((Mb*10923|0)+54615|0)>>>16)-1|0;c[s>>2]=Pb;Ob=Mb-3+(Pb*-6|0)|0;c[t>>2]=Ob;Tb=Nb-5|0;if((Tb|0)<18){Ub=18}else{Ub=(Tb|0)>134?134:Tb}Tb=Ub+Pb|0;c[s>>2]=Tb;Qb=Tb;Rb=0;Sb=Ob;break}}else if((Lb|0)==0){Vb=4;Wb=0;G=32}else{Ob=(Lb|0)!=1|0;if(Lb>>>0<4>>>0){Vb=4;Wb=Ob;G=32;break}Vb=(Lb|0)==5?5:6;Wb=Ob;G=32}}while(0);if((G|0)==32){G=0;vlb(s,t,Mb,Nb,Jb,Wb,Vb);Qb=c[s>>2]|0;Rb=(c[P>>2]|0)!=7|0;Sb=c[t>>2]|0}a[wa]=Qb;Lb=Sb<<Rb;c[t>>2]=Lb;Kb=(Lb|0)>0|0;Ob=Kb+Qb|0;c[s>>2]=Ob;Tb=c[ua>>2]|0;Se[c[va>>2]&1023](Tb,Tb+(1-Ob<<2)|0,1426320,6,Lb+6-(-Kb&6)|0,10,40);nrc(ta|0,c[ua>>2]|0,160)|0;Kb=ya+(Jb*26|0)+6|0;Lb=c[P>>2]|0;if((Lb|0)==7){xlb(Kb,x,1146936,5,3);Xb=c[P>>2]|0;G=53}else if((Lb|0)==6){Ob=b[ya+(Jb*26|0)+14>>1]|0;Tb=Ob>>3;Pb=d[1956050+(Tb*3|0)|0]<<1|Ob&1;Yb=d[1956049+(Tb*3|0)|0]<<1|Ob>>>1&1;Zb=d[1956048+(Tb*3|0)|0]<<3;Tb=b[ya+(Jb*26|0)+16>>1]|0;_b=Tb>>3;$b=d[1956050+(_b*3|0)|0]<<1|Tb&1;ac=d[1956049+(_b*3|0)|0]<<1|Tb>>>1&1;bc=d[1956048+(_b*3|0)|0]<<3;_b=b[ya+(Jb*26|0)+18>>1]|0;cc=((_b<<16>>16>>2)*25|0)+12>>5;dc=(cc|0)%5|0;ec=(cc|0)/5|0;cc=_b&65535;c[qa>>2]=8;_b=Pb<<2;Pb=Yb<<2;aa=(b[Kb>>1]|0)!=0?-1.0:1.0;c[sa>>2]=_b;c[xb>>2]=Pb;g[yb>>2]=aa;if(Pb>>>0<_b>>>0){fc=-0.0-aa}else{fc=aa}g[zb>>2]=fc;_b=Ob&4|Zb|1;Zb=Tb&4|bc|1;aa=(b[ya+(Jb*26|0)+8>>1]|0)!=0?-1.0:1.0;c[ra>>2]=_b;c[Ab>>2]=Zb;g[Bb>>2]=aa;if(Zb>>>0<_b>>>0){gc=-0.0-aa}else{gc=aa}g[Cb>>2]=gc;_b=$b<<2|2;$b=ac<<2|2;aa=(b[ya+(Jb*26|0)+10>>1]|0)!=0?-1.0:1.0;c[pa>>2]=_b;c[Db>>2]=$b;g[Eb>>2]=aa;if($b>>>0<_b>>>0){hc=-0.0-aa}else{hc=aa}g[Fb>>2]=hc;_b=(((ec&1|0)==0?dc:4-dc|0)<<1|cc&1)<<2|3;dc=(cc>>>1&1|ec<<1)<<2|3;aa=(b[ya+(Jb*26|0)+12>>1]|0)!=0?-1.0:1.0;c[oa>>2]=_b;c[Gb>>2]=dc;g[Hb>>2]=aa;if((dc|0)<(_b|0)){ic=-0.0-aa}else{ic=aa}g[Ib>>2]=ic;jc=6;G=56}else{_b=e[Kb>>1]|0;do{if(Lb>>>0<2>>>0){Kb=_b>>>3;dc=(Kb&8)+(Jb<<1)|0;c[sa>>2]=(d[306912+dc|0]|0)+((_b&7)*5|0);c[ra>>2]=(d[306912+(dc|1)|0]|0)+((Kb&7)*5|0);c[qa>>2]=2}else{if((Lb|0)==2){Kb=((_b>>>1&7)*5|0)+(_b<<1&2|1)|0;c[sa>>2]=Kb;dc=_b>>>4&3;ec=((_b>>>6&7)*5|0)+dc+((dc|0)==3)|0;c[ra>>2]=ec;c[qa>>2]=(Kb|0)==(ec|0)?1:2;break}ec=_b&7;if((Lb|0)==3){c[sa>>2]=ec*5|0;c[ra>>2]=(_b>>>2&2|1)+((_b>>>4&7)*5|0);c[pa>>2]=(_b>>>6&2)+2+((_b>>>8&7)*5|0);c[qa>>2]=3;break}else{c[sa>>2]=d[1146936+ec|0]|0;c[ra>>2]=(d[1146936+(_b>>>3&7)|0]|0)+1;c[pa>>2]=(d[1146936+(_b>>>6&7)|0]|0)+2;c[oa>>2]=(_b>>>9&1)+3+(d[1146936+(_b>>>10&7)|0]|0);c[qa>>2]=4;break}}}while(0);_b=e[ya+(Jb*26|0)+8>>1]|0;Nb=0;while(1){g[x+44+(Nb<<2)>>2]=(1<<Nb&_b|0)!=0?1.0:-1.0;Mb=Nb+1|0;if((Mb|0)<(c[qa>>2]|0)){Nb=Mb}else{Xb=Lb;G=53;break}}}do{if((G|0)==53){G=0;if((Xb|0)==7|(Xb|0)==5){aa=+(e[689904+(e[ya+(Jb*26|0)+2>>1]<<1)>>1]|0)*6103515625.0e-14;g[na>>2]=aa;kc=+(e[689936+(e[ya+(Jb*26|0)+4>>1]<<1)>>1]|0)*.00048828125;lc=aa;mc=Xb;break}if(Xb>>>0>2>>>0){jc=Xb;G=56;break}if((Xb|0)==0){nc=1199232+((e[B+10+((Jb&2)*26|0)+2>>1]<<1|Jb&1)<<2)|0;oc=0;G=60;break}else{nc=1198464+(e[ya+(Jb*26|0)+2>>1]<<2)|0;oc=Xb;G=60;break}}}while(0);if((G|0)==56){G=0;nc=1198720+(e[ya+(Jb*26|0)+2>>1]<<2)|0;oc=jc;G=60}if((G|0)==60){G=0;aa=+(e[nc>>1]|0)*6103515625.0e-14;g[na>>2]=aa;kc=+(e[nc+2>>1]|0)*.000244140625;lc=aa;mc=oc}aa=kc;do{if((mc|0)==7){ba=lc>1.0?1.0:lc;g[ma>>2]=ba;Lb=a[wa]|0;c[la>>2]=Lb&255;g[ka>>2]=ba;pc=Lb;G=65}else{ba=+g[ma>>2];Lb=a[wa]|0;c[la>>2]=Lb&255;g[ka>>2]=ba;if((mc|0)!=0){pc=Lb;G=65;break}if((Jb&1|0)==0){qc=Lb}else{pc=Lb;G=65}}}while(0);if((G|0)==65){G=0;ba=+g[na>>2];if(ba<0.0){rc=0.0}else{rc=ba>.79449462890625?.79449462890625:ba}g[ma>>2]=rc;qc=pc}if(qc<<24>>24==0){G=69;break}Clb(ja,x,1.0,40);ba=+Ae[c[ia>>2]&7](ja,ja,40)/40.0;g[ga>>2]=+ulb(aa,ba,ha,+g[1511768+(c[P>>2]<<2)>>2],1511752);Lb=c[ua>>2]|0;Nb=0;do{_b=Lb+(Nb<<2)|0;g[_b>>2]=+g[na>>2]*+g[_b>>2];Nb=Nb+1|0;}while((Nb|0)<40);Clb(Lb,x,+g[ga>>2],40);Nb=c[ua>>2]|0;_b=0;do{Mb=Nb+(_b<<2)|0;g[Mb>>2]=+xc(+(+g[Mb>>2]));_b=_b+1|0;}while((_b|0)<40);_b=c[P>>2]|0;aa=+g[Q>>2];ba=+R(+(aa- +g[H+(Jb*40|0)>>2]))/aa+0.0;aa=+g[N>>2];$=ba+ +R(+(aa- +g[H+(Jb*40|0)+4>>2]))/aa;aa=+g[za>>2];ba=$+ +R(+(aa- +g[H+(Jb*40|0)+8>>2]))/aa;aa=+g[Aa>>2];$=ba+ +R(+(aa- +g[H+(Jb*40|0)+12>>2]))/aa;aa=+g[Ba>>2];ba=$+ +R(+(aa- +g[H+(Jb*40|0)+16>>2]))/aa;aa=+g[Ca>>2];$=ba+ +R(+(aa- +g[H+(Jb*40|0)+20>>2]))/aa;aa=+g[Da>>2];ba=$+ +R(+(aa- +g[H+(Jb*40|0)+24>>2]))/aa;aa=+g[Ea>>2];$=ba+ +R(+(aa- +g[H+(Jb*40|0)+28>>2]))/aa;aa=+g[Fa>>2];ba=$+ +R(+(aa- +g[H+(Jb*40|0)+32>>2]))/aa;aa=+g[Ga>>2];$=ba+ +R(+(aa- +g[H+(Jb*40|0)+36>>2]))/aa;Nb=$>.65?(a[Ha]|0)+1&255:0;a[Ha]=Nb;a:do{if((Nb&255)>>>0>10>>>0){a[Ia]=0;a[Ha]=Nb-1;sc=0;G=77}else{Lb=a[Ia]|0;if((Lb&255)>>>0<40>>>0){sc=Lb;G=77;break}switch(_b|0){case 6:case 3:case 2:case 1:case 0:{break};default:{G=82;break a}}aa=$*4.0+ -1.6;if(aa<0.0){tc=0.0}else{tc=aa>1.0?1.0:aa}aa=+g[ga>>2];uc=tc*aa+(1.0-tc)*(+g[tb>>2]+ +g[ub>>2]+ +g[vb>>2]+ +g[wb>>2]+aa)*.2}}while(0);if((G|0)==77){G=0;a[Ia]=sc+1;G=82}if((G|0)==82){G=0;uc=+g[ga>>2]}$=+g[na>>2];Nb=$<.6;if(Nb){vc=0}else{vc=$<.9?1:2}do{if(uc>+g[Ka>>2]*2.0){a[La]=2;G=91}else{Lb=a[La]|0;if(!(Lb<<24>>24==0)){Mb=Lb-1&255;a[La]=Mb;if(!(Mb<<24>>24==0)){G=91;break}}Mb=((+g[pb>>2]<.6)+(Nb&1)+(+g[qb>>2]<.6)+(+g[rb>>2]<.6)+(+g[sb>>2]<.6)|0)>2?0:vc;if(!(Mb>>>0>((d[Pa]|0)+1|0)>>>0)){wc=Mb;break}wc=Mb-1|0}}while(0);if((G|0)==91){G=0;wc=(vc>>>0<2>>>0)+vc|0}Nb=uc<5.0?2:wc;do{if((_b|0)!=4&_b>>>0<6>>>0&(Nb|0)<2){Mb=c[((_b|0)==5?1058024:1058040)+(Nb<<2)>>2]|0;Lb=c[la>>2]|0;$=+g[ka>>2];do{if((Lb|0)<40){K3(Ma,Mb,Mb,Lb,$,40);if((Lb|0)>=20){break}K3(Na,Mb,Ma,Lb,$,40)}}while(0);mrc(Oa|0,0,160)|0;if((c[qa>>2]|0)<=0){yc=Ja;break}j=40-Lb|0;M=40-(Lb<<1)|0;ec=0;while(1){Kb=c[x+4+(ec<<2)>>2]|0;if((Kb|0)<(j|0)){zc=(Kb|0)<(M|0)?Na:Ma}else{zc=Mb}K3(Ja,Ja,zc,Kb,+g[x+44+(ec<<2)>>2],40);Kb=ec+1|0;if((Kb|0)<(c[qa>>2]|0)){ec=Kb}else{yc=Ja;break}}}else{yc=ja}}while(0);a[Pa]=Nb;g[Ka>>2]=uc;_b=xa+(Jb*40|0)|0;Me[c[ea>>2]&3](Ma,Ra,yc,+g[na>>2],uc,40);if(!(+g[na>>2]<=.5)){$=+Ae[c[ia>>2]&7](Ma,Ma,40);aa=+g[na>>2];ba=aa;do{if((c[P>>2]|0)==7){if(aa>1.0){Ac=.25;break}Ac=ba*.25}else{if(aa>.79449462890625){Ac=.397247314453125;break}Ac=ba*.5}}while(0);aa=ba*Ac;Nb=0;do{ec=q+(Nb<<2)|0;g[ec>>2]=+g[ec>>2]+aa*+g[B+1688+(Nb<<2)>>2];Nb=Nb+1|0;}while((Nb|0)<40);Blb(Ma,Ma,$,40)}pe[c[Sa>>2]&1023](Qa,_b,Ma,40,10);Nb=0;while(1){if((Nb|0)>=40){break}if(+R(+(+g[Qa+(Nb<<2)>>2]))>32768.0){Bc=0;G=113;break}else{Nb=Nb+1|0}}if((G|0)==113){while(1){G=0;Nb=B+1688+(Bc<<2)|0;g[Nb>>2]=+g[Nb>>2]*.25;Nb=Bc+1|0;if((Nb|0)<40){Bc=Nb;G=113}else{break}}Me[c[ea>>2]&3](Ma,Ra,yc,+g[na>>2],uc,40);pe[c[Sa>>2]&1023](Qa,_b,Ma,40,10)}$=+Ae[c[ia>>2]&7](Qa,Qa,40);Nb=((c[P>>2]|0)-6|0)>>>0<2>>>0;ec=Nb?1323080:1323120;Mb=Nb?1323040:1323080;aa=+g[_b>>2];g[_a>>2]=aa*+g[ec>>2];g[Xa>>2]=aa*+g[Mb>>2];aa=+g[xa+(Jb*40|0)+4>>2];g[v+4>>2]=aa*+g[ec+4>>2];g[p+4>>2]=aa*+g[Mb+4>>2];aa=+g[xa+(Jb*40|0)+8>>2];g[v+8>>2]=aa*+g[ec+8>>2];g[p+8>>2]=aa*+g[Mb+8>>2];aa=+g[xa+(Jb*40|0)+12>>2];g[v+12>>2]=aa*+g[ec+12>>2];g[p+12>>2]=aa*+g[Mb+12>>2];aa=+g[xa+(Jb*40|0)+16>>2];g[v+16>>2]=aa*+g[ec+16>>2];g[p+16>>2]=aa*+g[Mb+16>>2];aa=+g[xa+(Jb*40|0)+20>>2];g[v+20>>2]=aa*+g[ec+20>>2];g[p+20>>2]=aa*+g[Mb+20>>2];aa=+g[xa+(Jb*40|0)+24>>2];g[v+24>>2]=aa*+g[ec+24>>2];g[p+24>>2]=aa*+g[Mb+24>>2];aa=+g[xa+(Jb*40|0)+28>>2];g[v+28>>2]=aa*+g[ec+28>>2];g[p+28>>2]=aa*+g[Mb+28>>2];aa=+g[xa+(Jb*40|0)+32>>2];g[v+32>>2]=aa*+g[ec+32>>2];g[p+32>>2]=aa*+g[Mb+32>>2];aa=+g[xa+(Jb*40|0)+36>>2];g[v+36>>2]=aa*+g[ec+36>>2];g[p+36>>2]=aa*+g[Mb+36>>2];Mb=l+((Jb*40|0)<<2)|0;nrc(Ta|0,Va|0,40)|0;pe[c[Sa>>2]&1023](Wa,Xa,Qa,40,10);nrc(Va|0,Ya|0,40)|0;pe[c[Za>>2]&1023](Mb,_a,Wa,40,10);mrc(ab|0,0,128)|0;g[bb>>2]=1.0;nrc(db|0,Ua|0,40)|0;pe[c[Sa>>2]&1023](bb,Xa,bb,22,10);aa=+Ae[c[ia>>2]&7](bb,bb,22);ba=+Ae[c[ia>>2]&7](bb,cb,21);if(ba<0.0){Cc=0.0}else{Cc=ba/aa*.8}nlb($a,Cc,Mb,40);Alb(Mb,Mb,$,40,.8999999761581421,eb);Dlb(ja,x,40);nrc(fb|0,gb|0,80)|0;orc(hb|0,ib|0,616)|0;orc(jb|0,kb|0,16)|0;orc(lb|0,mb|0,16)|0;nrc(nb|0,ob|0,40)|0;Mb=Jb+1|0;if((Mb|0)<4){Jb=Mb}else{G=118;break}}if((G|0)==69){KIb(f,16,2251248,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;E=-1094995529;i=m;return E|0}else if((G|0)==118){df[c[A+2340>>2]&7](l,l,1103832,1103840,5736202001571655.0e-20,A+2128|0,160);Me[c[ea>>2]&3](Q,Q,A+664|0,.8399999737739563,.1599999964237213,10);c[k>>2]=1;E=(d[1209896+(c[P>>2]|0)|0]|0)+1|0;i=m;return E|0}}}while(0);if((G|0)==11){c[A+116>>2]=15}KIb(f,16,2458648,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;E=-1094995529;i=m;return E|0}function j0(a,d,f,h,j,k,l){a=a|0;d=d|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;m=i;i=i+24|0;n=m|0;o=i;i=i+40|0;p=(c[h>>2]|0)+(j<<1)|0;q=e[p>>1]|e[p+2>>1]<<16;c[n>>2]=q;p=(c[h+4>>2]|0)+(j<<1)|0;r=e[p>>1]|e[p+2>>1]<<16;c[n+4>>2]=r;p=n+8|0;s=(c[h+8>>2]|0)+(j<<1)|0;t=e[s>>1]|e[s+2>>1]<<16;c[p>>2]=t;s=(c[h+12>>2]|0)+(j<<1)|0;u=e[s>>1]|e[s+2>>1]<<16;c[n+12>>2]=u;s=(c[h+16>>2]|0)+(j<<1)|0;j=e[s>>1]|e[s+2>>1]<<16;c[n+16>>2]=j;s=t&65535;h=t>>>16&65535;if((k|0)==0){v=s;w=h}else{k=-s&65535;b[p>>1]=k;p=-h&65535;b[n+10>>1]=p;v=k;w=p}p=(l|0)!=0;if(p){nrc(a+120|0,n|0,20)|0}n=o|0;g[n>>2]=+((q&65535)<<16>>16|0)*30517578125.0e-15+ +g[f>>2]*125.0e-6;g[o+4>>2]=+((q>>>16&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+4>>2]*125.0e-6;g[o+8>>2]=+((r&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+8>>2]*125.0e-6;g[o+12>>2]=+((r>>>16&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+12>>2]*125.0e-6;g[o+16>>2]=+(v<<16>>16|0)*30517578125.0e-15+ +g[f+16>>2]*125.0e-6;g[o+20>>2]=+(w<<16>>16|0)*30517578125.0e-15+ +g[f+20>>2]*125.0e-6;g[o+24>>2]=+((u&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+24>>2]*125.0e-6;g[o+28>>2]=+((u>>>16&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+28>>2]*125.0e-6;g[o+32>>2]=+((j&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+32>>2]*125.0e-6;g[o+36>>2]=+((j>>>16&65535)<<16>>16|0)*30517578125.0e-15+ +g[f+36>>2]*125.0e-6;wPa(n,.0062561,10);if(!p){yPa(d,n,10);i=m;return}p=a+2344|0;f=a+664|0;Me[c[p>>2]&3](a+544|0,f,n,.75,.25,10);Me[c[p>>2]&3](a+584|0,f,n,.5,.5,10);Me[c[p>>2]&3](a+624|0,f,n,.25,.75,10);Me[c[p>>2]&3](f,f,n,0.0,1.0,10);yPa(d,n,10);i=m;return}function k0(b){b=b|0;var d=0,e=0,f=0,h=0,j=0;d=i;e=c[b+60>>2]|0;f=b+416|0;if((c[f>>2]|0)>1){RIb(b,2208488,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=d;return j|0}c[f>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;f=b+412|0;if((c[f>>2]|0)==0){c[f>>2]=16e3}c[b+420>>2]=3;AIb(e+4376|0,1);c[e+2464>>2]=e+2204;a[e+4636|0]=1;g[e+248>>2]=.03125;g[e+252>>2]=.0625;g[e+256>>2]=.09375;g[e+260>>2]=.125;g[e+264>>2]=.15625;g[e+268>>2]=.1875;g[e+272>>2]=.21875;g[e+276>>2]=.25;g[e+280>>2]=.28125;g[e+284>>2]=.3125;g[e+288>>2]=.34375;g[e+292>>2]=.375;g[e+296>>2]=.40625;g[e+300>>2]=.4375;g[e+304>>2]=.46875;g[e+308>>2]=.1171875;g[e+2980>>2]=-14.0;g[e+2984>>2]=-14.0;g[e+2988>>2]=-14.0;g[e+2992>>2]=-14.0;olb(e+4640|0);Elb(e+4648|0);O3(e+4652|0);S3(e+4660|0);j=0;i=d;return j|0}function l0(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0.0,$=0.0,aa=0.0,ba=0.0,da=0.0,ea=0.0,fa=0,ga=0.0,ha=0,ia=0.0,ja=0,ka=0.0,la=0,ma=0.0,na=0.0,oa=0,pa=0.0,qa=0.0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0.0,Wc=0,Xc=0,Yc=0,Zc=0.0,_c=0.0,$c=0.0,ad=0.0,bd=0.0,cd=0.0,dd=0.0,ed=0.0,fd=0.0,gd=0.0,hd=0.0,id=0.0,jd=0.0,kd=0.0,ld=0;m=i;i=i+2080|0;n=m|0;o=m+96|0;p=m+152|0;q=m+168|0;r=m+248|0;s=m+328|0;t=m+488|0;u=m+928|0;v=m+1184|0;w=m+1440|0;x=m+1760|0;y=x;z=c[f+60>>2]|0;A=z;B=c[l+24>>2]|0;C=c[l+28>>2]|0;c[j+76>>2]=320;l=M4a(f,j,0)|0;if((l|0)<0){D=l;i=m;return D|0}l=c[j>>2]|0;j=(d[B]|0)>>>3&15;E=z+112|0;c[E>>2]=j;F=(d[B]|0)>>>2&1;a[z+116|0]=F;if(j>>>0>9>>>0){KIb(f,16,2458624,(G=i,i=i+8|0,c[G>>2]=j,G)|0);i=G;D=-1094995529;i=m;return D|0}H=(((e[1719616+(j<<1)>>1]|0)+7|0)>>>3)+1|0;if((C|0)<(H|0)){KIb(f,16,2368528,(G=i,i=i+8|0,c[G>>2]=C,G)|0);i=G;c[k>>2]=0;D=-1094995529;i=m;return D|0}if(F<<24>>24==0){KIb(f,16,2302720,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;I=c[E>>2]|0}else{I=j}if((I|0)==9){QIb(f,2251232,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;D=-1163346256;i=m;return D|0}G=z;f=c[2019856+(I<<2)>>2]|0;mrc(z|0,0,112)|0;j=b[f>>1]|0;if(j<<16>>16==0){J=I;K=0;L=0;M=0}else{I=f;f=j;while(1){j=I+4|0;F=e[I+2>>1]|0;if(f<<16>>16==0){N=0;O=j}else{C=f&65535;P=0;Q=C;R=j;while(1){j=Q-1|0;S=e[R>>1]|0;T=(d[B+((S>>>3)+1)|0]|0)>>>((S&7)>>>0)&1|P<<1;if((j|0)==0){break}else{P=T;Q=j;R=R+2|0}}N=T&65535;O=I+(C+2<<1)|0}b[G+(F>>>1<<1)>>1]=N;R=b[O>>1]|0;if(R<<16>>16==0){break}else{I=O;f=R}}J=c[E>>2]|0;K=e[z+2>>1]|0;L=e[z+4>>1]|0;M=e[z+6>>1]|0}f=z+120|0;O=f;U=+(b[1542320+(K*18|0)>>1]|0)*30517578125.0e-15;V=+(b[1542322+(K*18|0)>>1]|0)*30517578125.0e-15;I=z+124|0;W=+(b[1542324+(K*18|0)>>1]|0)*30517578125.0e-15;N=z+128|0;X=+(b[1542326+(K*18|0)>>1]|0)*30517578125.0e-15;T=z+132|0;Y=+(b[1542328+(K*18|0)>>1]|0)*30517578125.0e-15;B=z+136|0;Z=+(b[1542330+(K*18|0)>>1]|0)*30517578125.0e-15;R=z+140|0;_=+(b[1542332+(K*18|0)>>1]|0)*30517578125.0e-15;Q=z+144|0;$=+(b[1542334+(K*18|0)>>1]|0)*30517578125.0e-15;P=z+148|0;aa=+(b[1542336+(K*18|0)>>1]|0)*30517578125.0e-15;K=z+152|0;ba=+(b[1533168+(L*14|0)>>1]|0)*30517578125.0e-15;j=z+156|0;da=+(b[1533170+(L*14|0)>>1]|0)*30517578125.0e-15;S=z+160|0;ea=+(b[1533172+(L*14|0)>>1]|0)*30517578125.0e-15;fa=z+164|0;ga=+(b[1533174+(L*14|0)>>1]|0)*30517578125.0e-15;ha=z+168|0;ia=+(b[1533176+(L*14|0)>>1]|0)*30517578125.0e-15;ja=z+172|0;ka=+(b[1533178+(L*14|0)>>1]|0)*30517578125.0e-15;la=z+176|0;ma=+(b[1533180+(L*14|0)>>1]|0)*30517578125.0e-15;L=z+180|0;if((J|0)==0){na=U+ +(b[1540656+(M*10|0)>>1]|0)*30517578125.0e-15;g[O>>2]=na;g[I>>2]=V+ +(b[1540658+(M*10|0)>>1]|0)*30517578125.0e-15;g[N>>2]=W+ +(b[1540660+(M*10|0)>>1]|0)*30517578125.0e-15;g[T>>2]=X+ +(b[1540662+(M*10|0)>>1]|0)*30517578125.0e-15;g[B>>2]=Y+ +(b[1540664+(M*10|0)>>1]|0)*30517578125.0e-15;J=e[z+8>>1]|0;g[R>>2]=Z+ +(b[1538864+(J<<3)>>1]|0)*30517578125.0e-15;g[Q>>2]=_+ +(b[1538866+(J<<3)>>1]|0)*30517578125.0e-15;g[P>>2]=$+ +(b[1538868+(J<<3)>>1]|0)*30517578125.0e-15;g[K>>2]=aa+ +(b[1538870+(J<<3)>>1]|0)*30517578125.0e-15;J=e[z+10>>1]|0;g[j>>2]=ba+ +(b[1537200+(J*14|0)>>1]|0)*30517578125.0e-15;g[S>>2]=da+ +(b[1537202+(J*14|0)>>1]|0)*30517578125.0e-15;g[fa>>2]=ea+ +(b[1537204+(J*14|0)>>1]|0)*30517578125.0e-15;g[ha>>2]=ga+ +(b[1537206+(J*14|0)>>1]|0)*30517578125.0e-15;g[ja>>2]=ia+ +(b[1537208+(J*14|0)>>1]|0)*30517578125.0e-15;g[la>>2]=ka+ +(b[1537210+(J*14|0)>>1]|0)*30517578125.0e-15;oa=1537212+(J*14|0)|0;pa=na}else{na=U+ +(b[1541936+(M*6|0)>>1]|0)*30517578125.0e-15;g[O>>2]=na;g[I>>2]=V+ +(b[1541938+(M*6|0)>>1]|0)*30517578125.0e-15;g[N>>2]=W+ +(b[1541940+(M*6|0)>>1]|0)*30517578125.0e-15;M=e[z+8>>1]|0;g[T>>2]=X+ +(b[1539888+(M*6|0)>>1]|0)*30517578125.0e-15;g[B>>2]=Y+ +(b[1539890+(M*6|0)>>1]|0)*30517578125.0e-15;g[R>>2]=Z+ +(b[1539892+(M*6|0)>>1]|0)*30517578125.0e-15;M=e[z+10>>1]|0;g[Q>>2]=_+ +(b[1538096+(M*6|0)>>1]|0)*30517578125.0e-15;g[P>>2]=$+ +(b[1538098+(M*6|0)>>1]|0)*30517578125.0e-15;g[K>>2]=aa+ +(b[1538100+(M*6|0)>>1]|0)*30517578125.0e-15;M=e[z+12>>1]|0;g[j>>2]=ba+ +(b[1537008+(M*6|0)>>1]|0)*30517578125.0e-15;g[S>>2]=da+ +(b[1537010+(M*6|0)>>1]|0)*30517578125.0e-15;g[fa>>2]=ea+ +(b[1537012+(M*6|0)>>1]|0)*30517578125.0e-15;M=e[z+14>>1]|0;g[ha>>2]=ga+ +(b[1536752+(M<<3)>>1]|0)*30517578125.0e-15;g[ja>>2]=ia+ +(b[1536754+(M<<3)>>1]|0)*30517578125.0e-15;g[la>>2]=ka+ +(b[1536756+(M<<3)>>1]|0)*30517578125.0e-15;oa=1536758+(M<<3)|0;pa=na}g[L>>2]=ma+ +(b[oa>>1]|0)*30517578125.0e-15;oa=z+184|0;M=0;ma=pa;while(1){J=oa+(M<<2)|0;g[O+(M<<2)>>2]=+g[J>>2]*.3333333333333333+(ma+ +(b[1057992+(M<<1)>>1]|0)*30517578125.0e-15);g[J>>2]=ma;J=M+1|0;if((J|0)>=16){break}M=J;ma=+g[O+(J<<2)>>2]}wPa(O,.00390625,15);M=z+248|0;oa=M;ma=+g[O>>2]- +g[oa>>2];pa=+g[I>>2]- +g[z+252>>2];na=+g[N>>2]- +g[z+256>>2];ka=+g[T>>2]- +g[z+260>>2];ia=+g[B>>2]- +g[z+264>>2];ga=+g[R>>2]- +g[z+268>>2];ea=+g[Q>>2]- +g[z+272>>2];da=+g[P>>2]- +g[z+276>>2];ba=+g[K>>2]- +g[z+280>>2];aa=+g[j>>2]- +g[z+284>>2];$=+g[S>>2]- +g[z+288>>2];_=+g[fa>>2]- +g[z+292>>2];Z=+g[ha>>2]- +g[z+296>>2];Y=+g[ja>>2]- +g[z+300>>2];X=+g[la>>2]- +g[z+304>>2];W=1.25-(ma*ma+0.0+pa*pa+na*na+ka*ka+ia*ia+ga*ga+ea*ea+da*da+ba*ba+aa*aa+$*$+_*_+Z*Z+Y*Y+X*X)*.8*512.0;if(W<0.0){qa=0.0}else{qa=W}g[L>>2]=+g[L>>2]*2.0;L=z+312|0;la=z+696|0;yPa(la,O,16);ja=z+4636|0;if((a[ja]|0)==0){ra=z+824|0}else{a[ja]=0;ja=z+824|0;nrc(ja|0,la|0,128)|0;ra=ja}ja=L;ha=ra;fa=0;while(1){h[ja+(fa<<3)>>3]=+h[ha+(fa<<3)>>3]*.550000011920929+ +h[ja+384+(fa<<3)>>3]*.44999998807907104;S=fa+1|0;if((S|0)<16){fa=S}else{sa=0;break}}while(1){h[ja+128+(sa<<3)>>3]=+h[ha+(sa<<3)>>3]*.19999998807907104+ +h[ja+384+(sa<<3)>>3]*.800000011920929;fa=sa+1|0;if((fa|0)<16){sa=fa}else{ta=0;break}}do{h[ja+256+(ta<<3)>>3]=+h[ha+(ta<<3)>>3]*.04000002145767212+ +h[ja+384+(ta<<3)>>3]*.9599999785423279;ta=ta+1|0;}while((ta|0)<16);ta=z+952|0;ja=ta;APa(L,ta,16);APa(z+440|0,z+1016|0,16);APa(z+568|0,z+1080|0,16);APa(z+696|0,z+1144|0,16);ta=z+16|0;L=z+2464|0;ha=z+1208|0;sa=z+1209|0;fa=z+4640|0;S=z+2724|0;j=S;K=S;P=z+3028|0;Q=z+2976|0;R=z+2996|0;B=R;T=z+4660|0;N=z+2980|0;I=z+3020|0;J=z+2468|0;ua=J;va=z+3040|0;wa=u|0;xa=v|0;ya=z+3108|0;za=z+4648|0;Aa=z+4652|0;Ba=z+3460|0;Ca=z+4132|0;Da=z+3712|0;Ea=z+4644|0;Fa=z+4116|0;Ga=z+3412|0;Ha=x|0;Ia=z+4124|0;Ja=w|0;Ka=z+4632|0;La=z+3796|0;Ma=La;Na=r|0;Oa=r+60|0;Pa=r+76|0;Qa=r+4|0;Ra=o|0;Sa=r+8|0;Ta=o+4|0;Ua=r+12|0;Va=o+8|0;Wa=r+16|0;Xa=o+12|0;Ya=r+20|0;Za=o+16|0;_a=r+24|0;$a=o+20|0;ab=r+28|0;bb=o+24|0;cb=r+32|0;db=o+28|0;eb=r+36|0;fb=o+32|0;gb=r+40|0;hb=o+36|0;ib=r+44|0;jb=o+40|0;kb=r+48|0;lb=o+44|0;mb=r+52|0;nb=o+48|0;ob=r+56|0;pb=o+52|0;qb=r+64|0;rb=r+68|0;sb=r+72|0;tb=s|0;s=q|0;ub=z+4136|0;vb=t;wb=t+120|0;xb=t+320|0;yb=z+4256|0;zb=z+1212|0;Ab=z+1468|0;Bb=z+3e3|0;Cb=z+3024|0;Db=z+3044|0;Eb=z+3300|0;Fb=z+3364|0;Gb=z+3620|0;Hb=z+3716|0;Ib=z+4036|0;Jb=q+4|0;Kb=q+8|0;Lb=q+12|0;Mb=q+16|0;Nb=q+20|0;Ob=q+24|0;Pb=q+28|0;Qb=q+32|0;Rb=q+36|0;Sb=q+40|0;Tb=q+44|0;Ub=q+48|0;Vb=q+52|0;Wb=q+56|0;Xb=q+60|0;Yb=x+4|0;Zb=z+3036|0;_b=u;u=Bb;$b=z+3004|0;ac=z+3008|0;bc=z+3012|0;cc=z+3016|0;z=n|0;dc=n+24|0;ec=n+48|0;fc=n+72|0;gc=n+4|0;hc=n+28|0;ic=n+52|0;jc=n+76|0;kc=n+8|0;lc=n+32|0;mc=n+12|0;nc=n+16|0;oc=n+36|0;pc=n+40|0;qc=0;do{rc=qc*80|0;sc=c[L>>2]|0;tc=c[E>>2]|0;uc=b[ta+(qc*24|0)>>1]|0;vc=uc&65535;do{if(tc>>>0<2>>>0){if((qc|0)==2){if((tc|0)==0){wc=42}}else if((qc|0)!=0){wc=42}if((wc|0)==42){wc=0;yc=(vc+1|0)>>>1;zc=vc-(yc<<1)<<1;Ac=(d[ha]|0)+yc|0;break}if((uc&65535)>>>0<116>>>0){yc=(vc+69|0)>>>1;Bc=(vc-(yc<<1)<<1)+136|0;Cc=yc}else{Bc=0;Cc=vc-24|0}yc=Cc-8+(Bc>>31)|0;if((yc|0)<34){Dc=34}else{Dc=(yc|0)>216?-40:yc&255}a[ha]=Dc;zc=Bc;Ac=Cc}else{if(!((qc|0)==2|(qc|0)==0)){yc=(vc+1|0)>>>2;zc=vc-(yc<<2)|0;Ac=(d[ha]|0)+yc|0;break}do{if((uc&65535)>>>0<376>>>0){yc=(vc+137|0)>>>2;Ec=vc+136-(yc<<2)|0;Fc=yc}else{if((uc&65535)>>>0<440>>>0){yc=vc-119>>1;Ec=(vc-(yc<<1)<<1)-240|0;Fc=yc;break}else{Ec=0;Fc=vc-280|0;break}}}while(0);yc=Fc-8+(Ec>>31)|0;if((yc|0)<34){Gc=34}else{Gc=(yc|0)>216?-40:yc&255}a[ha]=Gc;zc=Ec;Ac=Fc}}while(0);a[sa]=Ac;vc=(zc|0)>0;Se[c[fa>>2]&1023](sc,sc+(1-Ac-(vc&1)<<2)|0,2087120,4,(vc?0:4)+zc|0,16,65);if((b[ta+(qc*24|0)+2>>1]|0)==0){vc=0;while(1){uc=vc+1|0;g[A+2468+(vc<<2)>>2]=+g[sc+(vc-1<<2)>>2]*.18+ +g[sc+(vc<<2)>>2]*.64+ +g[sc+(uc<<2)>>2]*.18;if((uc|0)<64){vc=uc}else{break}}nrc(sc|0,J|0,256)|0}else{nrc(J|0,sc|0,256)|0}vc=ta+(qc*24|0)+8|0;uc=ta+(qc*24|0)+16|0;tc=c[E>>2]|0;F=(tc|0)==0;C=F?2:4;switch(tc|0){case 7:case 8:{yc=0;do{Hc=n+(yc*24|0)|0;Ic=(e[ta+(qc*24|0)+8+(yc<<1)>>1]<<11)+(e[ta+(qc*24|0)+16+(yc<<1)>>1]|0)|0;Jc=Ic>>>19<<3&8;Kc=8-Jc|0;Lc=Ic>>>20&3;if((Lc|0)==1){Mc=(Kc|1)+(Ic&7)|0;c[Hc>>2]=(Ic&8|0)!=0?-Mc|0:Mc;Mc=Ic>>>4;Nc=Jc|1;Oc=Ic>>>11;Pc=Nc|Ic>>>18<<2&4;Qc=Pc|Ic>>>14<<1&2;Rc=Qc+(Ic>>>12&1)|0;Sc=Qc+(Oc&1)|0;Qc=(Oc&4|0)!=0;c[n+(yc*24|0)+4>>2]=Qc?-Rc|0:Rc;Oc=Qc?-Sc|0:Sc;c[n+(yc*24|0)+8>>2]=(Rc|0)>(Sc|0)?-Oc|0:Oc;Oc=Ic>>>15;Sc=Pc+(Oc&3)|0;c[n+(yc*24|0)+12>>2]=(Oc&4|0)!=0?-Sc|0:Sc;Sc=Nc+(Ic>>>7&7)|0;Oc=Nc+(Mc&7)|0;Nc=(Mc&64|0)!=0;c[n+(yc*24|0)+16>>2]=Nc?-Sc|0:Sc;Mc=Nc?-Oc|0:Oc;c[n+(yc*24|0)+20>>2]=(Sc|0)>(Oc|0)?-Mc|0:Mc}else if((Lc|0)==3){Mc=Ic>>>10;Oc=Ic>>>15<<2&4|1;Sc=Oc+(Ic>>>12&3)|0;Nc=Oc+(Mc&3)|0;Oc=(Mc&16|0)!=0;c[Hc>>2]=Oc?-Sc|0:Sc;Mc=Oc?-Nc|0:Nc;c[n+(yc*24|0)+4>>2]=(Sc|0)>(Nc|0)?-Mc|0:Mc;Mc=Ic>>>16;c[n+(yc*24|0)+8>>2]=(Mc&8|0)!=0?(Mc|-8)^7:(Mc&7)+1|0;Mc=Ic>>>5<<2&4|9;Nc=Mc+(Ic>>>2&3)|0;Sc=Mc+(Ic&3)|0;Mc=(Ic&16|0)!=0;c[n+(yc*24|0)+12>>2]=Mc?-Nc|0:Nc;Oc=Mc?-Sc|0:Sc;c[n+(yc*24|0)+16>>2]=(Nc|0)>(Sc|0)?-Oc|0:Oc;Oc=Ic>>>6;Sc=Oc&7;c[n+(yc*24|0)+20>>2]=(Oc&8|0)!=0?-9-Sc|0:Sc+9|0}else if((Lc|0)==2){Sc=Kc|1;Kc=Sc+(Ic>>>3&7)|0;Oc=Sc+(Ic&7)|0;Sc=(Ic&64|0)!=0;c[Hc>>2]=Sc?-Kc|0:Kc;Nc=Sc?-Oc|0:Oc;c[n+(yc*24|0)+4>>2]=(Kc|0)>(Oc|0)?-Nc|0:Nc;m0(n+(yc*24|0)+8|0,Ic>>>7&4095,3,Jc|1)}else if((Lc|0)==0){Lc=Jc|1;Jc=Lc+(Ic&7)|0;c[Hc>>2]=(Ic&8|0)!=0?-Jc|0:Jc;Jc=Ic>>>4;Hc=Ic>>>11;Nc=Lc|Ic>>>18<<2&4;Oc=Nc|Ic>>>14<<1&2;Kc=Oc+(Ic>>>12&1)|0;Sc=Oc+(Hc&1)|0;Oc=(Hc&4|0)!=0;c[n+(yc*24|0)+4>>2]=Oc?-Kc|0:Kc;Hc=Oc?-Sc|0:Sc;c[n+(yc*24|0)+8>>2]=(Kc|0)>(Sc|0)?-Hc|0:Hc;Hc=Ic>>>15;Sc=Nc+(Hc&3)|0;c[n+(yc*24|0)+12>>2]=(Hc&4|0)!=0?-Sc|0:Sc;Sc=Lc+(Ic>>>7&7)|0;Ic=Lc+(Jc&7)|0;Lc=(Jc&64|0)!=0;c[n+(yc*24|0)+16>>2]=Lc?-Sc|0:Sc;Jc=Lc?-Ic|0:Ic;c[n+(yc*24|0)+20>>2]=(Sc|0)>(Ic|0)?-Jc|0:Jc}yc=yc+1|0;}while((yc|0)<4);break};case 3:{yc=e[uc>>1]|0;sc=yc>>>7<<3&8|1;Jc=sc+(yc>>>3&7)|0;Ic=sc+(yc&7)|0;sc=(yc&64|0)!=0;c[z>>2]=sc?-Jc|0:Jc;Sc=sc?-Ic|0:Ic;c[gc>>2]=(Jc|0)>(Ic|0)?-Sc|0:Sc;Sc=yc>>>8;c[kc>>2]=(Sc&16|0)!=0?(Sc|-16)^15:(Sc&15)+1|0;Sc=e[ta+(qc*24|0)+18>>1]|0;yc=Sc>>>7<<3&8|1;Ic=yc+(Sc>>>3&7)|0;Jc=yc+(Sc&7)|0;yc=(Sc&64|0)!=0;c[dc>>2]=yc?-Ic|0:Ic;sc=yc?-Jc|0:Jc;c[hc>>2]=(Ic|0)>(Jc|0)?-sc|0:sc;sc=Sc>>>8;c[lc>>2]=(sc&16|0)!=0?(sc|-16)^15:(sc&15)+1|0;sc=e[ta+(qc*24|0)+20>>1]|0;Sc=sc>>>4;Jc=(Sc&15)+1|0;Ic=(sc&15)+1|0;yc=(sc&256|0)!=0;c[ec>>2]=yc?(Sc|-16)^15:Jc;Sc=yc?(sc|-16)^15:Ic;c[ic>>2]=Jc>>>0>Ic>>>0?-Sc|0:Sc;Sc=e[ta+(qc*24|0)+22>>1]|0;Ic=Sc>>>4;Jc=(Ic&15)+1|0;sc=(Sc&15)+1|0;yc=(Sc&256|0)!=0;c[fc>>2]=yc?(Ic|-16)^15:Jc;Ic=yc?(Sc|-16)^15:sc;c[jc>>2]=Jc>>>0>sc>>>0?-Ic|0:Ic;break};case 2:{Ic=e[uc>>1]|0;sc=Ic>>>4;Jc=(sc&15)+1|0;Sc=(Ic&15)+1|0;yc=(Ic&256|0)!=0;c[z>>2]=yc?(sc|-16)^15:Jc;sc=yc?(Ic|-16)^15:Sc;c[gc>>2]=Jc>>>0>Sc>>>0?-sc|0:sc;sc=e[ta+(qc*24|0)+18>>1]|0;Sc=sc>>>4;Jc=(Sc&15)+1|0;Ic=(sc&15)+1|0;yc=(sc&256|0)!=0;c[dc>>2]=yc?(Sc|-16)^15:Jc;Sc=yc?(sc|-16)^15:Ic;c[hc>>2]=Jc>>>0>Ic>>>0?-Sc|0:Sc;Sc=e[ta+(qc*24|0)+20>>1]|0;Ic=Sc>>>4;Jc=(Ic&15)+1|0;sc=(Sc&15)+1|0;yc=(Sc&256|0)!=0;c[ec>>2]=yc?(Ic|-16)^15:Jc;Ic=yc?(Sc|-16)^15:sc;c[ic>>2]=Jc>>>0>sc>>>0?-Ic|0:Ic;Ic=e[ta+(qc*24|0)+22>>1]|0;sc=Ic>>>4;Jc=(sc&15)+1|0;Sc=(Ic&15)+1|0;yc=(Ic&256|0)!=0;c[fc>>2]=yc?(sc|-16)^15:Jc;sc=yc?(Ic|-16)^15:Sc;c[jc>>2]=Jc>>>0>Sc>>>0?-sc|0:sc;break};case 1:{sc=e[uc>>1]|0;c[z>>2]=(sc&16|0)!=0?(sc|-16)^15:(sc&15)+1|0;sc=e[ta+(qc*24|0)+18>>1]|0;c[dc>>2]=(sc&16|0)!=0?(sc|-16)^15:(sc&15)+1|0;sc=e[ta+(qc*24|0)+20>>1]|0;c[ec>>2]=(sc&16|0)!=0?(sc|-16)^15:(sc&15)+1|0;sc=e[ta+(qc*24|0)+22>>1]|0;c[fc>>2]=(sc&16|0)!=0?(sc|-16)^15:(sc&15)+1|0;break};case 0:{sc=e[uc>>1]|0;c[z>>2]=(sc&32|0)!=0?(sc|-32)^31:(sc&31)+1|0;sc=e[ta+(qc*24|0)+18>>1]|0;c[dc>>2]=(sc&32|0)!=0?(sc|-32)^31:(sc&31)+1|0;break};case 6:{sc=(e[vc>>1]<<10)+(e[uc>>1]|0)|0;Sc=sc>>>9;Jc=sc>>>19<<3&8|1;Ic=Jc|sc>>>14<<2&4;yc=Ic+(sc>>>11&3)|0;Lc=Ic+(Sc&3)|0;Ic=(Sc&16|0)!=0;c[z>>2]=Ic?-yc|0:yc;Sc=Ic?-Lc|0:Lc;c[gc>>2]=(yc|0)>(Lc|0)?-Sc|0:Sc;Sc=sc>>>15;Lc=Jc+(Sc&7)|0;c[kc>>2]=(Sc&8|0)!=0?-Lc|0:Lc;Lc=sc>>>4;Sc=(Lc&15)+1|0;Jc=(sc&15)+1|0;yc=(sc&256|0)!=0;c[mc>>2]=yc?(Lc|-16)^15:Sc;Lc=yc?(sc|-16)^15:Jc;c[nc>>2]=Sc>>>0>Jc>>>0?-Lc|0:Lc;Lc=(e[ta+(qc*24|0)+10>>1]<<10)+(e[ta+(qc*24|0)+18>>1]|0)|0;Jc=Lc>>>9;Sc=Lc>>>19<<3&8|1;sc=Sc|Lc>>>14<<2&4;yc=sc+(Lc>>>11&3)|0;Ic=sc+(Jc&3)|0;sc=(Jc&16|0)!=0;c[dc>>2]=sc?-yc|0:yc;Jc=sc?-Ic|0:Ic;c[hc>>2]=(yc|0)>(Ic|0)?-Jc|0:Jc;Jc=Lc>>>15;Ic=Sc+(Jc&7)|0;c[lc>>2]=(Jc&8|0)!=0?-Ic|0:Ic;Ic=Lc>>>4;Jc=(Ic&15)+1|0;Sc=(Lc&15)+1|0;yc=(Lc&256|0)!=0;c[oc>>2]=yc?(Ic|-16)^15:Jc;Ic=yc?(Lc|-16)^15:Sc;c[pc>>2]=Jc>>>0>Sc>>>0?-Ic|0:Ic;m0(ec,(e[ta+(qc*24|0)+12>>1]<<14)+(e[ta+(qc*24|0)+20>>1]|0)|0,4,1);m0(fc,(e[ta+(qc*24|0)+14>>1]<<14)+(e[ta+(qc*24|0)+22>>1]|0)|0,4,1);break};case 5:{m0(z,(e[vc>>1]<<14)+(e[uc>>1]|0)|0,4,1);m0(dc,(e[ta+(qc*24|0)+10>>1]<<14)+(e[ta+(qc*24|0)+18>>1]|0)|0,4,1);m0(ec,(e[ta+(qc*24|0)+12>>1]<<14)+(e[ta+(qc*24|0)+20>>1]|0)|0,4,1);m0(fc,(e[ta+(qc*24|0)+14>>1]<<14)+(e[ta+(qc*24|0)+22>>1]|0)|0,4,1);break};case 4:{Ic=0;do{Sc=e[ta+(qc*24|0)+16+(Ic<<1)>>1]|0;Jc=Sc>>>7<<3&8|1;Lc=Jc+(Sc>>>3&7)|0;yc=Jc+(Sc&7)|0;Jc=(Sc&64|0)!=0;c[n+(Ic*24|0)>>2]=Jc?-Lc|0:Lc;sc=Jc?-yc|0:yc;c[n+(Ic*24|0)+4>>2]=(Lc|0)>(yc|0)?-sc|0:sc;sc=Sc>>>8;c[n+(Ic*24|0)+8>>2]=(sc&16|0)!=0?(sc|-16)^15:(sc&15)+1|0;Ic=Ic+1|0;}while((Ic|0)<4);break};default:{}}mrc(S|0,0,256)|0;Ic=d[696504+(tc<<2)|0]|0;uc=0;do{vc=c[n+(uc<<2)>>2]|0;sc=ca(((vc|0)>-1?vc:-vc|0)-1|0,C)|0;Sc=K+(sc<<2)|0;g[Sc>>2]=+g[Sc>>2]+((vc|0)<0?-1.0:1.0);uc=uc+1|0;}while((uc|0)<(Ic|0));Ic=d[696505+(tc<<2)|0]|0;uc=0;do{vc=c[n+24+(uc<<2)>>2]|0;Sc=ca(((vc|0)>-1?vc:-vc|0)-1|0,C)|0|1;sc=K+(Sc<<2)|0;g[sc>>2]=+g[sc>>2]+((vc|0)<0?-1.0:1.0);uc=uc+1|0;}while((uc|0)<(Ic|0));if(!F){Ic=d[696506+(tc<<2)|0]|0;uc=0;do{vc=c[n+48+(uc<<2)>>2]|0;sc=(ca(((vc|0)>-1?vc:-vc|0)-1|0,C)|0)+2|0;Sc=K+(sc<<2)|0;g[Sc>>2]=+g[Sc>>2]+((vc|0)<0?-1.0:1.0);uc=uc+1|0;}while((uc|0)<(Ic|0));Ic=d[696507+(tc<<2)|0]|0;uc=0;do{F=c[n+72+(uc<<2)>>2]|0;vc=(ca(((F|0)>-1?F:-F|0)-1|0,C)|0)+3|0;Sc=K+(vc<<2)|0;g[Sc>>2]=+g[Sc>>2]+((F|0)<0?-1.0:1.0);uc=uc+1|0;}while((uc|0)<(Ic|0))}Ic=63;W=+g[Q>>2];while(1){uc=Ic-1|0;X=+g[K+(uc<<2)>>2];g[K+(Ic<<2)>>2]=W-X*+g[P>>2];if((uc|0)==0){break}else{Ic=uc;W=X}}Ic=a[sa]|0;do{if((Ic&255)>>>0<64>>>0){uc=Ic&255;C=K+(uc<<2)|0;g[C>>2]=+g[C>>2]+ +g[K>>2]*.85;C=uc+1|0;if(C>>>0<64>>>0){Tc=C}else{break}do{C=K+(Tc<<2)|0;g[C>>2]=+g[C>>2]+ +g[K+(Tc-(d[sa]|0)<<2)>>2]*.85;Tc=Tc+1|0;}while((Tc|0)<64)}}while(0);Ic=b[ta+(qc*24|0)+4>>1]&255;if((c[E>>2]|0)>>>0<2>>>0){Uc=690512+(Ic<<2)|0}else{Uc=69e4+(Ic<<2)|0}g[B>>2]=+(b[Uc>>1]|0)*6103515625.0e-14;W=+(b[Uc+2>>1]|0)*.00048828125;X=+ulb(W,+Ae[c[T>>2]&7](K,K,64)*.015625,N,30.0,1511736);g[I>>2]=X;W=+g[B>>2];Y=W;W=Y*Y*+Ae[c[T>>2]&7](ua,ua,64);Y=X;X=Y*Y*+Ae[c[T>>2]&7](K,K,64);Y=(W-X)/(W+X);g[P>>2]=Y*.25+.25;Ic=c[L>>2]|0;C=0;do{uc=Ic+(C<<2)|0;X=+g[B>>2]*+g[uc>>2];g[uc>>2]=X;g[uc>>2]=+xc(+(+g[I>>2]*+g[j+(C<<2)>>2]+X));C=C+1|0;}while((C|0)<64);X=+g[I>>2];W=qa*(1.0-Y)*.5;Z=+g[va>>2];if(Z>X){_=X+X*.19000244140625;Vc=Z>_?_:Z}else{_=X*.84033203125;Vc=Z>_?Z:_}g[va>>2]=Vc;_=(1.0-W)*X+W*Vc;C=c[E>>2]|0;do{if(C>>>0>1>>>0){Wc=K}else{W=+g[B>>2];Ic=W<.6;if(Ic){Xc=0}else{Xc=W<.9?1:2}do{if(X>+g[Cb>>2]*3.0){Yc=(Xc>>>0<2>>>0)+Xc|0}else{uc=((+g[u>>2]<.6)+(Ic&1)+(+g[$b>>2]<.6)+(+g[ac>>2]<.6)+(+g[bc>>2]<.6)+(+g[cc>>2]<.6)|0)>2?0:Xc;if(!(uc>>>0>((d[Zb]|0)+1|0)>>>0)){Yc=uc;break}Yc=uc-1|0}}while(0);a[Zb]=Yc;Ic=Yc+((C|0)==1)|0;if((Ic|0)>=2){Wc=K;break}uc=c[1058032+(Ic<<2)>>2]|0;mrc(_b|0,0,256)|0;Ic=0;while(1){W=+g[K+(Ic<<2)>>2];if(W!=0.0){K3(wa,wa,uc,Ic,W,64)}tc=Ic+1|0;if((tc|0)<64){Ic=tc}else{Wc=wa;break}}}}while(0);X=(Y+1.0)*.125;W=+g[Wc>>2];Z=+g[Wc+4>>2];g[Wc>>2]=W-X*Z;$=W;C=1;W=Z;while(1){Ic=C+1|0;Z=+g[Wc+(Ic<<2)>>2];g[Wc+(C<<2)>>2]=W-X*($+Z);if((Ic|0)<63){$=W;C=Ic;W=Z}else{break}}C=Wc+252|0;g[C>>2]=+g[C>>2]-X*W;C=ja+(qc<<6)|0;Me[c[za>>2]&3](xa,ua,Wc,+g[B>>2],_,64);do{if(+g[B>>2]>.5){if(!((c[E>>2]|0)>>>0<2>>>0)){break}$=+Ae[c[T>>2]&7](xa,xa,64);Y=+g[B>>2];Z=Y*Y*.25;Ic=0;do{uc=v+(Ic<<2)|0;g[uc>>2]=+g[uc>>2]+Z*+g[A+2468+(Ic<<2)>>2];Ic=Ic+1|0;}while((Ic|0)<64);Blb(xa,xa,$,64)}}while(0);pe[c[Aa>>2]&1023](ya,C,xa,64,16);_=+g[ya>>2]+ +g[Ca>>2]*.6800000071525574;g[Ba>>2]=_;Ic=1;W=_;do{W=W*.6800000071525574+ +g[ya+(Ic<<2)>>2];g[Ba+(Ic<<2)>>2]=W;Ic=Ic+1|0;}while((Ic|0)<64);g[Ca>>2]=+g[Da>>2];df[c[Ea>>2]&7](Ba,Ba,1091624,1091640,.989501953125,Fa,64);Ic=rc|1;C=rc|2;uc=rc|3;tc=rc|4;F=0;Sc=0;vc=0;while(1){g[l+(F+rc<<2)>>2]=+g[Ga+(vc<<2)>>2];g[l+(Ic+F<<2)>>2]=+Ae[c[T>>2]&7](Ga+(vc-11<<2)|0,282360,24);sc=vc|1;g[l+(C+F<<2)>>2]=+Ae[c[T>>2]&7](Ga+(sc-11<<2)|0,282456,24);g[l+(uc+F<<2)>>2]=+Ae[c[T>>2]&7](Ga+(sc-10<<2)|0,282552,24);g[l+(tc+F<<2)>>2]=+Ae[c[T>>2]&7](Ga+((vc|3)-11<<2)|0,282648,24);sc=Sc+1|0;if((sc|0)<16){F=F+5|0;Sc=sc;vc=vc+4|0}else{break}}df[c[Ea>>2]&7](Ha,Ba,1091624,1091632,.8935546875,Ia,64);vc=(b[G>>1]&255)<<24>>24!=0|0;do{if((c[E>>2]|0)==8){Zc=+(e[689872+(e[ta+(qc*24|0)+6>>1]<<1)>>1]|0)*6103515625.0e-14}else{W=+Ae[c[T>>2]&7](Ha,Yb,63);_=W/+Ae[c[T>>2]&7](Ha,Ha,64);if(_<0.0){_c=0.0}else{_c=_}_=(1.25- +(vc|0)*.25)*(1.0-_c);if(_<.10000000149011612){Zc=.10000000149011612;break}Zc=_>1.0?1.0:_}}while(0);_=+Ae[c[T>>2]&7](xa,xa,64);vc=0;Sc=c[Ka>>2]|0;do{c[A+4376+((Sc&63)<<2)>>2]=(c[A+4376+((Sc+9&63)<<2)>>2]|0)+(c[A+4376+((Sc+40&63)<<2)>>2]|0);F=c[Ka>>2]|0;Sc=F+1|0;c[Ka>>2]=Sc;g[w+(vc<<2)>>2]=32768.0- +(c[A+4376+((F&63)<<2)>>2]&65535|0);vc=vc+1|0;}while((vc|0)<80);Blb(Ja,Ja,Zc*Zc*_,80);vc=(c[E>>2]|0)==0;if(vc){W=+g[1057976+(qc<<2)>>2];Me[c[za>>2]&3](Na,oa,O,W,1.0-W,16);g[Pa>>2]=+g[Oa>>2];W=+g[Qa>>2];X=+g[Na>>2];g[Ra>>2]=W-X;Z=+g[Sa>>2];g[Ta>>2]=Z-W;Y=+g[Ua>>2];aa=Y-Z;g[Va>>2]=aa;ba=+g[Wa>>2];da=ba-Y;g[Xa>>2]=da;ea=+g[Ya>>2];ga=ea-ba;g[Za>>2]=ga;ia=+g[_a>>2];ka=ia-ea;g[$a>>2]=ka;ea=+g[ab>>2];na=ea-ia;g[bb>>2]=na;ia=+g[cb>>2];pa=ia-ea;g[db>>2]=pa;ea=+g[eb>>2];ma=ea-ia;g[fb>>2]=ma;ia=+g[gb>>2];V=ia-ea;g[hb>>2]=V;ea=+g[ib>>2];U=ea-ia;g[jb>>2]=U;ia=+g[kb>>2];$c=ia-ea;g[lb>>2]=$c;ea=+g[mb>>2];ad=ea-ia;g[nb>>2]=ad;ia=+g[ob>>2];bd=ia-ea;g[pb>>2]=bd;ea=aa*.0833333358168602+0.0+da*.0833333358168602+ga*.0833333358168602+ka*.0833333358168602+na*.0833333358168602+pa*.0833333358168602+ma*.0833333358168602+V*.0833333358168602+U*.0833333358168602+$c*.0833333358168602+ad*.0833333358168602+bd*.0833333358168602;na=pa-ea;pa=ma-ea;ma=V-ea;V=U-ea;U=$c-ea;$c=ad-ea;ad=bd-ea;Sc=0;F=0;do{bd=na*(+g[o+(5-Sc<<2)>>2]-ea);ka=pa*(+g[o+(6-Sc<<2)>>2]-ea);ga=ma*(+g[o+(7-Sc<<2)>>2]-ea);da=V*(+g[o+(8-Sc<<2)>>2]-ea);aa=U*(+g[o+(9-Sc<<2)>>2]-ea);cd=$c*(+g[o+(10-Sc<<2)>>2]-ea);dd=ad*(+g[o+(11-Sc<<2)>>2]-ea);ed=bd*bd+0.0+ka*ka+ga*ga+da*da+aa*aa+cd*cd+dd*dd;g[p+(Sc<<2)>>2]=ed;F=ed>+g[p+(F<<2)>>2]?Sc:F;Sc=Sc+1|0;}while((Sc|0)<3);Sc=-3-F|0;ea=ia+ +g[r+(13-F<<2)>>2]- +g[r+(Sc+15<<2)>>2];g[Oa>>2]=ea;ad=ea+ +g[r+(14-F<<2)>>2]- +g[r+(Sc+16<<2)>>2];g[qb>>2]=ad;$c=ad+ +g[r+(15-F<<2)>>2]- +g[r+(Sc+17<<2)>>2];g[rb>>2]=$c;U=$c+ +g[r+(16-F<<2)>>2]- +g[r+(Sc+18<<2)>>2];g[sb>>2]=U;V=(Z-Y-ba)/6.0+7965.0;ma=((V>7600.0?7600.0:V)-ia)*.5/(U-ia);V=(ea-ia)*ma;g[Ra>>2]=V;pa=(ad-ea)*ma;g[Ta>>2]=pa;ea=($c-ad)*ma;g[Va>>2]=ea;ad=(U-$c)*ma;g[Xa>>2]=ad;do{if(pa+V<5.0){if(pa>V){ma=5.0-pa;g[Ra>>2]=ma;fd=pa;gd=ma;break}else{ma=5.0-V;g[Ta>>2]=ma;fd=ma;gd=V;break}}else{fd=pa;gd=V}}while(0);do{if(ea+fd<5.0){if(ea>fd){V=5.0-ea;g[Ta>>2]=V;hd=ea;id=V;break}else{V=5.0-fd;g[Va>>2]=V;hd=V;id=fd;break}}else{hd=ea;id=fd}}while(0);do{if(ad+hd<5.0){if(ad>hd){ea=5.0-ad;g[Va>>2]=ea;jd=ea;kd=ad;break}else{ea=5.0-hd;g[Xa>>2]=ea;jd=hd;kd=ea;break}}else{jd=hd;kd=ad}}while(0);ad=ia+gd*30517578125.0e-15;g[Oa>>2]=ad;ea=ad+id*30517578125.0e-15;g[qb>>2]=ea;ad=ea+jd*30517578125.0e-15;g[rb>>2]=ad;g[sb>>2]=kd*30517578125.0e-15+ad;g[Na>>2]=X*.8;g[Qa>>2]=W*.8;F=2;ad=Z;while(1){g[r+(F<<2)>>2]=ad*.8;Sc=F+1|0;if((Sc|0)>=19){break}F=Sc;ad=+g[r+(Sc<<2)>>2]}g[Pa>>2]=+g[Pa>>2]*2.0;yPa(tb,Na,20);APa(tb,s,20);F=0;ad=.8999999761581421;while(1){Sc=q+(F<<2)|0;g[Sc>>2]=ad*+g[Sc>>2];Sc=F+1|0;if((Sc|0)<20){F=Sc;ad=ad*.8999999761581421}else{break}}}else{g[s>>2]=+g[A+952+(qc<<6)>>2]*.6000000238418579;g[Jb>>2]=+g[A+952+(qc<<6)+4>>2]*.36000001430511475;g[Kb>>2]=+g[A+952+(qc<<6)+8>>2]*.2160000205039978;g[Lb>>2]=+g[A+952+(qc<<6)+12>>2]*.12960001826286316;g[Mb>>2]=+g[A+952+(qc<<6)+16>>2]*.0777600109577179;g[Nb>>2]=+g[A+952+(qc<<6)+20>>2]*.046656008809804916;g[Ob>>2]=+g[A+952+(qc<<6)+24>>2]*.02799360640347004;g[Pb>>2]=+g[A+952+(qc<<6)+28>>2]*.016796164214611053;g[Qb>>2]=+g[A+952+(qc<<6)+32>>2]*.010077699087560177;g[Rb>>2]=+g[A+952+(qc<<6)+36>>2]*.0060466197319328785;g[Sb>>2]=+g[A+952+(qc<<6)+40>>2]*.0036279719788581133;g[Tb>>2]=+g[A+952+(qc<<6)+44>>2]*.0021767832804471254;g[Ub>>2]=+g[A+952+(qc<<6)+48>>2]*.001306070014834404;g[Vb>>2]=+g[A+952+(qc<<6)+52>>2]*.0007836420554667711;g[Wb>>2]=+g[A+952+(qc<<6)+56>>2]*.00047018524492159486;g[Xb>>2]=+g[A+952+(qc<<6)+60>>2]*.0002821111702360213}pe[c[Aa>>2]&1023](Ma,s,Ja,80,vc?20:16);nrc(vb|0,ub|0,120)|0;nrc(wb|0,La|0,320)|0;F=0;do{Sc=x+(F<<2)|0;g[Sc>>2]=0.0;tc=0;ad=0.0;do{ad=ad+ +g[t+(tc+F<<2)>>2]*+g[1899872+(tc<<2)>>2];tc=tc+1|0;}while((tc|0)<31);g[Sc>>2]=ad;F=F+1|0;}while((F|0)<80);nrc(ub|0,xb|0,120)|0;if((c[E>>2]|0)==8){nrc(vb|0,yb|0,120)|0;nrc(wb|0,y|0,320)|0;F=0;do{vc=x+(F<<2)|0;g[vc>>2]=0.0;tc=0;$=0.0;do{$=$+ +g[t+(tc+F<<2)>>2]*+g[918920+(tc<<2)>>2];tc=tc+1|0;}while((tc|0)<31);g[vc>>2]=$;F=F+1|0;}while((F|0)<80);nrc(yb|0,xb|0,120)|0;ld=0}else{ld=0}do{F=l+(ld+rc<<2)|0;g[F>>2]=(+g[F>>2]+ +g[x+(ld<<2)>>2])*30517578125.0e-15;ld=ld+1|0;}while((ld|0)<80);orc(zb|0,Ab|0,992)|0;orc(Bb|0,R|0,20)|0;g[Cb>>2]=+g[I>>2];nrc(Db|0,Eb|0,64)|0;nrc(Fb|0,Gb|0,96)|0;nrc(Hb|0,Ib|0,80)|0;qc=qc+1|0;}while((qc|0)<4);nrc(ra|0,la|0,128)|0;nrc(M|0,f|0,64)|0;c[k>>2]=1;D=H;i=m;return D|0}function m0(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d-1|0;g=1<<f;h=d<<2;i=b>>h-2&3;if((i|0)==3){j=(1<<(d*3|0)-2)-1&b>>d;k=f<<1;l=k-1|0;m=d-2|0;n=(1<<l)-1&j;o=((j>>>(l>>>0)&1)<<m)+e|0;l=(1<<m)-1|0;p=o+(n>>m&l)|0;q=o+(n&l)|0;l=(n&1<<(m<<1)|0)!=0;c[a>>2]=l?-p|0:p;m=l?-q|0:q;c[a+4>>2]=(p|0)>(q|0)?-m|0:m;m=(1<<d)-1|0;q=j>>k&m;k=g-1|0;j=(q&k)+e|0;c[a+8>>2]=(q&g|0)!=0?-j|0:j;j=m&b;m=g+e+(k&j)|0;c[a+12>>2]=(j&g|0)!=0?-m|0:m;return}else if((i|0)==0){m=d<<1;j=m-3|0;k=d-2|0;q=(1<<j)-1&b;p=((b>>>((h-3|0)>>>0)&1)<<f)+e|0;h=p+((b>>>(j>>>0)&1)<<k)|0;j=(1<<k)-1|0;l=(q>>k&j)+h|0;n=h+(q&j)|0;j=(q&1<<(k<<1)|0)!=0;c[a>>2]=j?-l|0:l;k=j?-n|0:n;c[a+4>>2]=(l|0)>(n|0)?-k|0:k;k=(1<<m-1)-1&b>>m-2;m=g-1|0;n=(k>>f&m)+p|0;l=(k&m)+p|0;p=(k&1<<(f<<1)|0)!=0;c[a+8>>2]=p?-n|0:n;k=p?-l|0:l;c[a+12>>2]=(n|0)>(l|0)?-k|0:k;return}else if((i|0)==2){k=(d<<1)-1|0;l=(1<<k)-1|0;n=l&b>>k;k=g-1|0;p=(n>>f&k)+e|0;m=(n&k)+e|0;j=1<<(f<<1);q=(n&j|0)!=0;c[a>>2]=q?-p|0:p;n=q?-m|0:m;c[a+4>>2]=(p|0)>(m|0)?-n|0:n;n=l&b;l=g+e|0;m=(n>>f&k)+l|0;p=(n&k)+l|0;l=(n&j|0)!=0;c[a+8>>2]=l?-m|0:m;j=l?-p|0:p;c[a+12>>2]=(m|0)>(p|0)?-j|0:j;return}else if((i|0)==1){i=(d*3|0)-2|0;j=(1<<d)-1|0;p=b>>i&j;m=g-1|0;l=(p&m)+e|0;c[a>>2]=(p&g|0)!=0?-l|0:l;l=(1<<i)-1&b;b=g+e|0;e=f<<1;f=e-1|0;i=d-2|0;d=(1<<f)-1&l;p=((l>>>(f>>>0)&1)<<i)+b|0;f=(1<<i)-1|0;n=p+(d>>i&f)|0;k=p+(d&f)|0;f=(d&1<<(i<<1)|0)!=0;c[a+4>>2]=f?-n|0:n;i=f?-k|0:k;c[a+8>>2]=(n|0)>(k|0)?-i|0:i;i=l>>e&j;j=(i&m)+b|0;c[a+12>>2]=(i&g|0)!=0?-j|0:j;return}else{return}}function n0(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0;b=i;e=c[a+60>>2]|0;c[a+140>>2]=11;f=UHb()|0;c[e>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}f=c[a+96>>2]|0;h=c[a+100>>2]|0;if(!((h|0)>-1)){KIb(0,0,2251200,(a=i,i=i+24|0,c[a>>2]=2208472,c[a+8>>2]=2175920,c[a+16>>2]=135,a)|0);i=a;Hd();return 0}a=e+1028|0;c[a>>2]=f;c[e+1036>>2]=f;c[e+1032>>2]=f+h;if(h>>>0<1152>>>0){g=-1094995529;i=b;return g|0}h=f+128|0;c[a>>2]=h;f=e+4|0;e=0;j=h;while(1){c[a>>2]=j+4;h=j;c[f+(e<<2)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=e+1|0;if((h|0)>=256){g=0;break}e=h;j=c[a>>2]|0}i=b;return g|0}function o0(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;h=i;j=c[b+60>>2]|0;k=c[g+28>>2]|0;l=j;m=N4a(b,c[l>>2]|0)|0;if((m|0)<0){n=m;i=h;return n|0}m=c[l>>2]|0;o=c[m>>2]|0;p=o+(ca(c[b+124>>2]|0,c[m+32>>2]|0)|0)|0;m=j+1028|0;q=m;r=c[g+24>>2]|0;if(!((k|0)>-1)){KIb(0,0,2251200,(s=i,i=i+24|0,c[s>>2]=2208472,c[s+8>>2]=2175920,c[s+16>>2]=135,s)|0);i=s;Hd();return 0}g=m;c[g>>2]=r;c[j+1036>>2]=r;m=r+k|0;t=j+1032|0;c[t>>2]=m;u=m;do{if((k|0)>=1){v=r+1|0;c[g>>2]=v;if((a[r]|0)!=66){break}do{if((u-v|0)<1){w=v}else{x=r+2|0;c[g>>2]=x;if((a[v]|0)==0){w=x;break}QIb(b,2368512,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-1163346256;i=h;return n|0}}while(0);v=u-w|0;x=w+(v>>>0>2>>>0?2:v)|0;c[g>>2]=x;v=j+1040|0;c[v>>2]=0;y=b+120|0;z=o;A=m;B=x;x=0;a:while(1){C=A;do{if((C-B|0)<1){D=B;E=28}else{F=B+1|0;c[g>>2]=F;G=d[B]|0;H=G&127;I=(G&128|0)==0;if((H|0)!=0){G=I?q:0;J=c[y>>2]|0;K=c[(c[l>>2]|0)+32>>2]|0;L=J-x|0;M=G|0;N=K-J|0;O=(K|0)>0;K=G+4|0;if((G|0)==0){G=H;P=L;Q=z;while(1){R=(G|0)>(P|0)?P:G;S=P-R|0;T=G-R|0;U=(S|0)<1;V=U?J:S;S=Q+((U?N:0)+R)|0;if(O){if(!(S>>>0<p>>>0)){W=V;E=25;break a}}else{if(!(S>>>0>p>>>0)){W=V;E=25;break a}}if((T|0)>0){G=T;P=V;Q=S}else{X=V;Y=S;break}}}else{Q=c[M>>2]|0;if(O){P=H;G=L;S=z;V=Q;while(1){T=(P|0)>(G|0)?G:P;if(((c[K>>2]|0)-V|0)>>>0<T>>>0){W=G;E=25;break a}nrc(S|0,V|0,T)|0;R=(c[M>>2]|0)+T|0;c[M>>2]=R;U=G-T|0;Z=P-T|0;_=(U|0)<1;$=_?J:U;U=S+((_?N:0)+T)|0;if(!(U>>>0<p>>>0)){W=$;E=25;break a}if((Z|0)>0){P=Z;G=$;S=U;V=R}else{X=$;Y=U;break}}}else{V=H;S=L;G=z;P=Q;while(1){O=(V|0)>(S|0)?S:V;if(((c[K>>2]|0)-P|0)>>>0<O>>>0){W=S;E=25;break a}nrc(G|0,P|0,O)|0;U=(c[M>>2]|0)+O|0;c[M>>2]=U;$=S-O|0;R=V-O|0;Z=($|0)<1;T=Z?J:$;$=G+((Z?N:0)+O)|0;if(!($>>>0>p>>>0)){W=T;E=25;break a}if((R|0)>0){V=R;S=T;G=$;P=U}else{X=T;Y=$;break}}}}P=J-X|0;c[v>>2]=P;aa=Y;ba=P;break}if(I){D=F;E=28;break}if((C-F|0)<2){break a}P=B+3|0;c[g>>2]=P;G=F;S=(d[G]|d[G+1|0]<<8)<<16>>16&65535;G=S&16383;V=S>>>14;if((G|0)==0){if((V|0)==0){break a}else if((V|0)==2){E=43;break a}else{aa=z;ba=x;break}}do{if((V|0)==3){if((C-P|0)<1){da=0;break}c[g>>2]=B+4;da=d[P]|0}else{da=-1}}while(0);P=(V|0)==1?G|16384:G;F=(V|0)==2?q:0;ea=c[y>>2]|0;I=c[(c[l>>2]|0)+32>>2]|0;S=ea-x|0;N=F|0;b:do{if((P|0)==0){fa=S;ga=z}else{M=(da|0)>-1;K=da&255;Q=I-ea|0;L=(I|0)>0;H=F+4|0;if((F|0)==0){$=P;T=S;U=z;while(1){R=($|0)>(T|0)?T:$;if(M){mrc(U|0,K|0,R|0)|0}O=T-R|0;Z=$-R|0;_=(O|0)<1;ha=_?ea:O;O=U+((_?Q:0)+R)|0;if(L){if(!(O>>>0<p>>>0)){ia=ha;E=66;break a}}else{if(!(O>>>0>p>>>0)){ia=ha;E=66;break a}}if((Z|0)>0){$=Z;T=ha;U=O}else{fa=ha;ga=O;break b}}}U=c[N>>2]|0;if(M){T=P;$=S;K=z;O=U;while(1){ha=(T|0)>($|0)?$:T;if(((c[H>>2]|0)-O|0)>>>0<ha>>>0){ia=$;E=66;break a}nrc(K|0,O|0,ha)|0;Z=(c[N>>2]|0)+ha|0;c[N>>2]=Z;R=$-ha|0;_=T-ha|0;ja=(R|0)<1;ka=ja?ea:R;R=K+((ja?Q:0)+ha)|0;if(L){if(!(R>>>0<p>>>0)){ia=ka;E=66;break a}}else{if(!(R>>>0>p>>>0)){ia=ka;E=66;break a}}if((_|0)>0){T=_;$=ka;K=R;O=Z}else{fa=ka;ga=R;break}}}else{O=P;K=S;$=z;T=U;while(1){M=(O|0)>(K|0)?K:O;if(((c[H>>2]|0)-T|0)>>>0<M>>>0){ia=K;E=66;break a}nrc($|0,T|0,M)|0;R=(c[N>>2]|0)+M|0;c[N>>2]=R;ka=K-M|0;Z=O-M|0;_=(ka|0)<1;ha=_?ea:ka;ka=$+((_?Q:0)+M)|0;if(L){if(!(ka>>>0<p>>>0)){ia=ha;E=66;break a}}else{if(!(ka>>>0>p>>>0)){ia=ha;E=66;break a}}if((Z|0)>0){O=Z;K=ha;$=ka;T=R}else{fa=ha;ga=ka;break}}}}}while(0);N=ea-fa|0;c[v>>2]=N;aa=ga;ba=N}}while(0);if((E|0)==28){E=0;if((C-D|0)<1){la=0;ma=D}else{N=D+1|0;c[g>>2]=N;la=d[D]|0;ma=N}if((C-ma|0)<1){na=0}else{c[g>>2]=ma+1;na=a[ma]|0}oa=c[y>>2]|0;N=c[(c[l>>2]|0)+32>>2]|0;S=oa-x|0;if((la|0)==0){pa=S;qa=z}else{P=N-oa|0;F=(N|0)>0;N=la;I=S;S=z;while(1){V=(N|0)>(I|0)?I:N;mrc(S|0,na|0,V|0)|0;G=I-V|0;T=N-V|0;$=(G|0)<1;ra=$?oa:G;G=S+(($?P:0)+V)|0;if(F){if(!(G>>>0<p>>>0)){E=39;break a}}else{if(!(G>>>0>p>>>0)){E=39;break a}}if((T|0)>0){N=T;I=ra;S=G}else{pa=ra;qa=G;break}}}S=oa-pa|0;c[v>>2]=S;aa=qa;ba=S}S=c[g>>2]|0;I=c[t>>2]|0;if((I|0)==(S|0)){break}else{z=aa;A=I;B=S;x=ba}}if((E|0)==25){c[v>>2]=J-W}else if((E|0)==39){c[v>>2]=oa-ra}else if((E|0)==43){QIb(b,2302704,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-1163346256;i=h;return n|0}else if((E|0)==66){c[v>>2]=ea-ia}nrc(c[(c[l>>2]|0)+4>>2]|0,j+4|0,1024)|0;c[f>>2]=1;x=YHb(e,c[l>>2]|0)|0;n=(x|0)<0?x:k;i=h;return n|0}}while(0);QIb(b,2458568,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-1094995529;i=h;return n|0}function p0(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function q0(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[a+140>>2]=11;d=UHb()|0;c[b>>2]=d;if((d|0)==0){e=-12;return e|0}c[b+20>>2]=1961016;c[b+24>>2]=16;c[b+32>>2]=7;c[b+36>>2]=0;do{if((c[a+120>>2]|0)!=0){if((c[a+124>>2]|0)==0){break}else{e=0}return e|0}}while(0);H4a(a,640,400)|0;e=0;return e|0}function r0(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;h=i;j=b+60|0;k=c[j>>2]|0;l=c[g+24>>2]|0;m=c[g+28>>2]|0;g=l+m|0;n=k;o=N4a(b,c[n>>2]|0)|0;if((o|0)<0){p=o;i=h;return p|0}if((c[b+428>>2]|0)==0){o=b+124|0;q=c[n>>2]|0;if((c[o>>2]|0)>0){r=b+120|0;s=0;t=q;while(1){u=(c[t>>2]|0)+(ca(c[t+32>>2]|0,s)|0)|0;mrc(u|0,0,c[r>>2]|0)|0;u=s+1|0;v=c[n>>2]|0;if((u|0)<(c[o>>2]|0)){s=u;t=v}else{w=v;break}}}else{w=q}mrc(c[w+4>>2]|0,0,1024)|0}w=c[n>>2]|0;c[w+88>>2]=1;c[w+304>>2]=1;t0(c[w+4>>2]|0);w=k+40|0;if((c[w>>2]|0)==0){q=c[j>>2]|0;t=b+124|0;if((c[t>>2]|0)>0){s=q;o=b+120|0;r=0;do{v=c[s>>2]|0;u=(c[v>>2]|0)+(ca(c[v+32>>2]|0,r)|0)|0;mrc(u|0,0,c[o>>2]|0)|0;r=r+1|0;}while((r|0)<(c[t>>2]|0))}c[q+8>>2]=0;c[q+4>>2]=0;c[w>>2]=1}a:do{if((m|0)>0){w=k+44|0;q=k+4|0;t=b+124|0;r=b+120|0;o=k+64|0;s=k+48|0;u=s;v=b;x=s;s=l;b:while(1){while(1){y=c[w>>2]|0;if((y|0)==3){z=187;break}else if((y|0)==0){z=18;break}else if((y|0)==2){z=38;break}else if((y|0)!=1){break}if((a[s]|0)==91){z=37;break}c[w>>2]=0;u0(b,27)}c:do{if((z|0)==18){z=0;y=d[s]|0;d:do{switch(y|0){case 9:{A=(c[q>>2]|0)/8|0;B=(A+8&-8)-A|0;if((B|0)>0){C=0}else{break c}while(1){u0(b,32);C=C+1|0;if((C|0)>=(B|0)){break c}}break};case 13:{break};case 12:{B=c[j>>2]|0;if((c[t>>2]|0)>0){A=B;D=0;do{E=c[A>>2]|0;F=(c[E>>2]|0)+(ca(c[E+32>>2]|0,D)|0)|0;mrc(F|0,0,c[r>>2]|0)|0;D=D+1|0;}while((D|0)<(c[t>>2]|0))}c[B+8>>2]=0;c[B+4>>2]=0;break c;break};case 10:{D=c[j>>2]|0;A=D+8|0;F=c[A>>2]|0;E=c[t>>2]|0;G=D+24|0;H=c[G>>2]|0;if((F|0)<=(E-(H<<1)|0)){c[A>>2]=H+F;break d}if((E-H|0)>0){F=D;A=0;I=H;while(1){H=c[F>>2]|0;J=c[H>>2]|0;K=c[H+32>>2]|0;H=J+(ca(K,A)|0)|0;L=J+(ca(K,A+I|0)|0)|0;nrc(H|0,L|0,c[r>>2]|0)|0;L=A+1|0;H=c[t>>2]|0;K=c[G>>2]|0;if((L|0)<(H-K|0)){A=L;I=K}else{M=L;N=H;break}}}else{M=0;N=E}if((M|0)>=(N|0)){break d}I=D;A=M;do{G=c[I>>2]|0;F=(c[G>>2]|0)+(ca(c[G+32>>2]|0,A)|0)|0;mrc(F|0,0,c[r>>2]|0)|0;A=A+1|0;}while((A|0)<(c[t>>2]|0));break};case 0:case 7:case 26:{break c;break};case 8:{A=(c[q>>2]|0)-1|0;c[q>>2]=(A|0)>0?A:0;break c;break};case 27:{c[w>>2]=1;break c;break};default:{u0(b,y);break c}}}while(0);c[q>>2]=0}else if((z|0)==37){z=0;c[w>>2]=2;c[o>>2]=0;c[u>>2]=-1}else if((z|0)==38){z=0;y=d[s]|0;switch(y|0){case 77:{c[w>>2]=3;break c;break};case 59:{A=(c[o>>2]|0)+1|0;c[o>>2]=A;if((A|0)>=4){break c}c[x+(A<<2)>>2]=0;break c;break};case 61:case 63:{break c;break};case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:{A=c[o>>2]|0;if((A|0)>=4){break c}I=x+(A<<2)|0;A=c[I>>2]|0;if((A|0)>=6553){break c}if((A|0)>0){O=(A*10|0)-48|0}else{O=-48}c[I>>2]=O+y;break c;break};default:{y=c[o>>2]|0;if((y|0)>4){KIb(v,24,2458536,(P=i,i=i+8|0,c[P>>2]=y,P)|0);i=P;Q=c[o>>2]|0}else{Q=y}do{if((Q|0)<4){if(!((c[x+(Q<<2)>>2]|0)>-1)){break}c[o>>2]=Q+1}}while(0);y=a[s]|0;I=c[j>>2]|0;A=c[r>>2]|0;D=c[t>>2]|0;e:do{switch(y&255|0){case 67:{E=I+4|0;F=c[E>>2]|0;G=(c[I+64>>2]|0)>0;if(G){R=c[I+48>>2]<<3}else{R=8}B=A-8|0;if((R+F|0)>(B|0)){S=B}else{if(G){T=c[I+48>>2]<<3}else{T=8}S=T+F|0}c[E>>2]=S;break};case 68:{E=I+4|0;F=c[E>>2]|0;G=(c[I+64>>2]|0)>0;if(G){U=c[I+48>>2]<<3}else{U=8}if((F-U|0)>0){if(G){V=c[I+48>>2]<<3}else{V=8}W=F-V|0}else{W=0}c[E>>2]=W;break};case 66:{E=I+8|0;F=c[E>>2]|0;G=(c[I+64>>2]|0)>0;if(G){B=c[I+24>>2]|0;X=ca(B,c[I+48>>2]|0)|0;Y=B}else{B=c[I+24>>2]|0;X=B;Y=B}B=D-Y|0;if((X+F|0)>(B|0)){Z=B}else{if(G){_=ca(c[I+48>>2]|0,Y)|0}else{_=Y}Z=_+F|0}c[E>>2]=Z;break};case 75:{E=c[I+48>>2]|0;if((E|0)==0){F=c[I+4>>2]|0;G=A-F|0;B=I+24|0;if((c[B>>2]|0)<=0){break e}H=I;L=I+8|0;K=0;do{J=c[H>>2]|0;mrc((c[J>>2]|0)+((ca((c[L>>2]|0)+K|0,c[J+32>>2]|0)|0)+F)|0,0,G|0)|0;K=K+1|0;}while((K|0)<(c[B>>2]|0))}else if((E|0)==1){B=c[I+4>>2]|0;K=I+24|0;if((c[K>>2]|0)<=0){break e}G=I;F=I+8|0;L=0;do{H=c[G>>2]|0;mrc((c[H>>2]|0)+(ca((c[F>>2]|0)+L|0,c[H+32>>2]|0)|0)|0,0,B|0)|0;L=L+1|0;}while((L|0)<(c[K>>2]|0))}else if((E|0)==2){K=I+24|0;if((c[K>>2]|0)<=0){break e}L=I;B=I+8|0;F=0;do{G=c[L>>2]|0;mrc((c[G>>2]|0)+(ca((c[B>>2]|0)+F|0,c[G+32>>2]|0)|0)|0,0,A|0)|0;F=F+1|0;}while((F|0)<(c[K>>2]|0))}else{break e}break};case 72:case 102:{K=c[I+64>>2]|0;do{if((K|0)>0){F=c[I+24>>2]|0;B=ca((c[I+48>>2]|0)-1|0,F)|0;L=D-F|0;if((B|0)<0){$=0}else{$=(B|0)>(L|0)?L:B}c[I+8>>2]=$;if((K|0)<=1){aa=0;break}B=(c[I+52>>2]<<3)-8|0;L=(c[r>>2]|0)-8|0;if((B|0)<0){aa=0;break}aa=(B|0)>(L|0)?L:B}else{c[I+8>>2]=0;aa=0}}while(0);c[I+4>>2]=aa;break};case 115:{c[I+12>>2]=c[I+4>>2];c[I+16>>2]=c[I+8>>2];break};case 117:{K=c[I+12>>2]|0;B=A-8|0;if((K|0)<0){ba=0}else{ba=(K|0)>(B|0)?B:K}c[I+4>>2]=ba;K=c[I+16>>2]|0;B=(c[t>>2]|0)-(c[I+24>>2]|0)|0;if((K|0)<0){da=0}else{da=(K|0)>(B|0)?B:K}c[I+8>>2]=da;break};case 110:case 82:{break};case 65:{K=I+8|0;B=c[K>>2]|0;L=(c[I+64>>2]|0)>0;if(L){F=c[I+24>>2]|0;ea=ca(F,c[I+48>>2]|0)|0;fa=F}else{F=c[I+24>>2]|0;ea=F;fa=F}if((B-ea|0)>0){if(L){ga=ca(c[I+48>>2]|0,fa)|0}else{ga=fa}ha=B-ga|0}else{ha=0}c[K>>2]=ha;break};case 109:{K=I+64|0;B=c[K>>2]|0;if((B|0)==0){c[K>>2]=1;c[I+48>>2]=0;ia=1}else{ia=B}B=(ia|0)>4?4:ia;if((B|0)<=0){break e}L=I+48|0;F=I+28|0;E=I+32|0;G=I+36|0;H=0;J=B;B=ia;while(1){ja=c[L+(H<<2)>>2]|0;f:do{if((ja|0)==0){c[F>>2]=0;c[E>>2]=7;c[G>>2]=0;ka=H;la=B}else{ma=ja-1|0;if(ma>>>0<2>>>0|(ja|0)==4|(ja|0)==5|(ja|0)==7|(ja|0)==8){c[F>>2]=c[F>>2]|1<<ma;ka=H;la=B;break}ma=ja-30|0;if(ma>>>0<8>>>0){c[E>>2]=d[2018728+ma|0]|0;ka=H;la=B;break}if((ja|0)==38){z=156}else if((ja|0)==39){c[E>>2]=7;ka=H;la=B;break}else{z=163}do{if((z|0)==156){z=0;ma=H+2|0;if((ma|0)>=(J|0)){break}if((c[L+(H+1<<2)>>2]|0)!=5){z=163;break}na=c[L+(ma<<2)>>2]|0;if((na|0)>=256){z=163;break}if((na|0)<16){oa=d[2018728+na|0]|0}else{oa=na}c[E>>2]=oa;ka=ma;la=B;break f}}while(0);do{if((z|0)==163){z=0;ma=ja-40|0;if(ma>>>0<8>>>0){c[G>>2]=d[2018728+ma|0]|0;ka=H;la=B;break f}if((ja|0)==49){c[E>>2]=0;ka=H;la=B;break f}else if((ja|0)!=48){break}ma=H+2|0;if((ma|0)>=(((B|0)>4?4:B)|0)){break}if((c[L+(H+1<<2)>>2]|0)!=5){break}na=c[L+(ma<<2)>>2]|0;if((na|0)>=256){break}if((na|0)<16){pa=d[2018728+na|0]|0}else{pa=na}c[G>>2]=pa;ka=ma;la=B;break f}}while(0);QIb(v,2302672,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;ka=H;la=c[K>>2]|0}}while(0);ja=ka+1|0;ma=(la|0)>4?4:la;if((ja|0)<(ma|0)){H=ja;J=ma;B=la}else{break}}break};case 104:case 108:{B=I+48|0;g:do{if((c[I+64>>2]|0)<2){c[B>>2]=3;z=95}else{switch(c[B>>2]|0){case 7:{qa=D;ra=A;break g;break};case 6:case 14:{c[I+20>>2]=1965880;c[I+24>>2]=8;qa=200;ra=640;break g;break};case 0:case 1:case 4:case 5:case 13:case 19:{c[I+20>>2]=1965880;c[I+24>>2]=8;qa=200;ra=320;break g;break};case 2:case 3:{z=95;break g;break};case 15:case 16:{c[I+20>>2]=1965880;c[I+24>>2]=8;qa=344;ra=640;break g;break};case 17:case 18:{c[I+20>>2]=1965880;c[I+24>>2]=8;qa=960;ra=640;break g;break};default:{QIb(v,2368472,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;qa=D;ra=A;break g}}}}while(0);if((z|0)==95){z=0;c[I+20>>2]=1961016;c[I+24>>2]=16;qa=400;ra=640}B=I+4|0;J=c[B>>2]|0;H=ra-8|0;if((J|0)<0){sa=0}else{sa=(J|0)>(H|0)?H:J}c[B>>2]=sa;B=I+8|0;J=c[B>>2]|0;H=qa-(c[I+24>>2]|0)|0;if((J|0)<0){ta=0}else{ta=(J|0)>(H|0)?H:J}c[B>>2]=ta;do{if((ra|0)==(c[r>>2]|0)){if((qa|0)!=(c[t>>2]|0)){break}if(!(y<<24>>24==108)){break e}B=c[j>>2]|0;do{if((qa|0)>0){J=B;mrc(c[c[J>>2]>>2]|0,0,ra|0)|0;if((c[t>>2]|0)>1){ua=1}else{break}do{H=c[J>>2]|0;mrc((c[H>>2]|0)+(ca(c[H+32>>2]|0,ua)|0)|0,0,c[r>>2]|0)|0;ua=ua+1|0;}while((ua|0)<(c[t>>2]|0))}}while(0);c[B+8>>2]=0;c[B+4>>2]=0;break e}}while(0);J=I;WHb(c[J>>2]|0);H=H4a(b,ra,qa)|0;if((H|0)<0){p=H;z=191;break b}H=M4a(b,c[J>>2]|0,1)|0;if((H|0)<0){p=H;z=191;break b}H=c[J>>2]|0;c[H+88>>2]=1;c[H+304>>2]=1;t0(c[H+4>>2]|0);H=c[j>>2]|0;if((c[t>>2]|0)>0){J=H;K=0;do{G=c[J>>2]|0;L=(c[G>>2]|0)+(ca(c[G+32>>2]|0,K)|0)|0;mrc(L|0,0,c[r>>2]|0)|0;K=K+1|0;}while((K|0)<(c[t>>2]|0))}c[H+8>>2]=0;c[H+4>>2]=0;break};case 74:{K=c[I+48>>2]|0;if((K|0)==1){J=c[I+4>>2]|0;L=I+24|0;if((c[L>>2]|0)>0){G=I;E=I+8|0;F=0;while(1){ma=c[G>>2]|0;mrc((c[ma>>2]|0)+(ca((c[E>>2]|0)+F|0,c[ma+32>>2]|0)|0)|0,0,J|0)|0;ma=F+1|0;if((ma|0)<(c[L>>2]|0)){F=ma}else{va=E;break}}}else{va=I+8|0}E=c[va>>2]|0;if((E|0)<=0){break e}F=c[I>>2]|0;mrc(c[F>>2]|0,0,ca(c[F+32>>2]|0,E)|0)|0;break e}else if((K|0)==0){E=c[I+4>>2]|0;F=A-E|0;L=I+24|0;J=c[L>>2]|0;if((J|0)>0){G=I;H=I+8|0;ma=0;do{ja=c[G>>2]|0;mrc((c[ja>>2]|0)+((ca((c[H>>2]|0)+ma|0,c[ja+32>>2]|0)|0)+E)|0,0,F|0)|0;ma=ma+1|0;wa=c[L>>2]|0;}while((ma|0)<(wa|0));xa=c[t>>2]|0;ya=wa;za=H}else{xa=D;ya=J;za=I+8|0}ma=c[za>>2]|0;L=xa-ya|0;if((ma|0)>=(L|0)){break e}F=c[I>>2]|0;E=c[F+32>>2]|0;mrc((c[F>>2]|0)+(ca(E,ma+ya|0)|0)|0,0,ca(E,L-ma|0)|0)|0;break e}else if((K|0)==2){do{if((D|0)>0){ma=I;mrc(c[c[ma>>2]>>2]|0,0,A|0)|0;if((c[t>>2]|0)>1){Aa=1}else{break}do{L=c[ma>>2]|0;mrc((c[L>>2]|0)+(ca(c[L+32>>2]|0,Aa)|0)|0,0,c[r>>2]|0)|0;Aa=Aa+1|0;}while((Aa|0)<(c[t>>2]|0))}}while(0);c[I+8>>2]=0;c[I+4>>2]=0;break e}else{break e}break};default:{QIb(v,2251176,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P}}}while(0);A=I+4|0;D=c[A>>2]|0;y=(c[r>>2]|0)-8|0;if((D|0)<0){Ba=0}else{Ba=(D|0)>(y|0)?y:D}c[A>>2]=Ba;A=I+8|0;D=c[A>>2]|0;y=(c[t>>2]|0)-(c[I+24>>2]|0)|0;if((D|0)<0){Ca=0}else{Ca=(D|0)>(y|0)?y:D}c[A>>2]=Ca;c[w>>2]=0;break c}}}else if((z|0)==187){z=0;A=a[s]|0;if(!((A<<24>>24|0)==14|(A<<24>>24|0)==27)){break}c[w>>2]=0}}while(0);s=s+1|0;if(!(s>>>0<g>>>0)){break a}}if((z|0)==191){i=h;return p|0}}}while(0);c[f>>2]=1;f=YHb(e,c[n>>2]|0)|0;p=(f|0)<0?f:m;i=h;return p|0}function s0(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function t0(a){a=a|0;var b=0,d=0,e=0;nrc(a|0,1412488,64)|0;b=a+64|0;d=0;while(1){e=(ca(d,2621440)|0)+3604480|0;c[b>>2]=e|-16763081;c[b+4>>2]=e|-16763041;c[b+8>>2]=e|-16763001;c[b+12>>2]=e|-16762961;c[b+16>>2]=e|-16762921;c[b+20>>2]=e|-16762881;c[b+24>>2]=e|-16752841;c[b+28>>2]=e|-16752801;c[b+32>>2]=e|-16752761;c[b+36>>2]=e|-16752721;c[b+40>>2]=e|-16752681;c[b+44>>2]=e|-16752641;c[b+48>>2]=e|-16742601;c[b+52>>2]=e|-16742561;c[b+56>>2]=e|-16742521;c[b+60>>2]=e|-16742481;c[b+64>>2]=e|-16742441;c[b+68>>2]=e|-16742401;c[b+72>>2]=e|-16732361;c[b+76>>2]=e|-16732321;c[b+80>>2]=e|-16732281;c[b+84>>2]=e|-16732241;c[b+88>>2]=e|-16732201;c[b+92>>2]=e|-16732161;c[b+96>>2]=e|-16722121;c[b+100>>2]=e|-16722081;c[b+104>>2]=e|-16722041;c[b+108>>2]=e|-16722001;c[b+112>>2]=e|-16721961;c[b+116>>2]=e|-16721921;c[b+120>>2]=e|-16711881;c[b+124>>2]=e|-16711841;c[b+128>>2]=e|-16711801;c[b+132>>2]=e|-16711761;c[b+136>>2]=e|-16711721;c[b+140>>2]=e|-16711681;e=d+1|0;if((e|0)<6){b=b+144|0;d=e}else{break}}d=a+928|0;a=0;while(1){b=(a*10|0)+8|0;c[d>>2]=b|b<<8|b<<16|-16777216;b=a+1|0;if((b|0)<24){d=d+4|0;a=b}else{break}}return}function u0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a+60|0;e=c[d>>2]|0;f=c[e+32>>2]|0;g=c[e+36>>2]|0;h=c[e+28>>2]|0;i=(h&1|0)==0?f:f+8|0;f=(h&16|0)==0?g:g+8|0;g=(h&64|0)==0;j=g?f:i;k=c[e>>2]|0;l=c[k+32>>2]|0;m=ca(l,c[e+8>>2]|0)|0;n=e+4|0;T3((c[k>>2]|0)+(m+(c[n>>2]|0))|0,l,c[e+20>>2]|0,c[e+24>>2]|0,b,(h&128|0)==0?g?i:f:j,j);j=(c[n>>2]|0)+8|0;c[n>>2]=j;f=a+120|0;if((j|0)<=((c[f>>2]|0)-8|0)){return}c[n>>2]=0;n=c[d>>2]|0;d=n+8|0;j=c[d>>2]|0;i=a+124|0;a=c[i>>2]|0;g=n+24|0;h=c[g>>2]|0;if((j|0)<=(a-(h<<1)|0)){c[d>>2]=h+j;return}if((a-h|0)>0){j=n;d=0;b=h;while(1){h=c[j>>2]|0;e=c[h>>2]|0;l=c[h+32>>2]|0;h=e+(ca(l,d)|0)|0;m=e+(ca(l,d+b|0)|0)|0;nrc(h|0,m|0,c[f>>2]|0)|0;m=d+1|0;h=c[i>>2]|0;l=c[g>>2]|0;if((m|0)<(h-l|0)){d=m;b=l}else{o=m;p=h;break}}}else{o=0;p=a}if((o|0)>=(p|0)){return}p=n;n=o;do{o=c[p>>2]|0;a=(c[o>>2]|0)+(ca(c[o+32>>2]|0,n)|0)|0;mrc(a|0,0,c[f>>2]|0)|0;n=n+1|0;}while((n|0)<(c[i>>2]|0));return}function v0(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;f=a+60|0;g=c[f>>2]|0;if((c[a+100>>2]|0)!=6){KIb(a,16,2569512,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=e;return j|0}k=a+416|0;if((c[k>>2]|0)>2){KIb(a,16,2551368,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=e;return j|0}l=c[a+792>>2]|0;c[g+1260>>2]=l;if((l|0)==24){c[a+420>>2]=7}else if((l|0)==16){c[a+420>>2]=6}else if((l|0)==8){c[a+420>>2]=5}else{QIb(a,2533240,(h=i,i=i+8|0,c[h>>2]=l,h)|0);i=h;j=-1163346256;i=e;return j|0}c[g+4>>2]=a;c[g+1252>>2]=c[k>>2];l=c[a+96>>2]|0;m=l;n=g+1264|0;c[n>>2]=(d[m]|d[m+1|0]<<8)<<16>>16&65535;m=l+2|0;o=(d[m]|d[m+1|0]<<8)<<16>>16&65535;m=g+1268|0;c[m>>2]=o;p=l+4|0;l=(d[p]|d[p+1|0]<<8)<<16>>16&65535;c[g+1276>>2]=l;p=a;KIb(p,48,2517768,(h=i,i=i+16|0,c[h>>2]=o,c[h+8>>2]=l,h)|0);i=h;l=c[m>>2]|0;do{if(!(((l|0)%1e3|0|0)!=0|(l|0)>5e3|(l|0)==0)){if((c[n>>2]|0)<3930&(l|0)==5e3){break}m=g+1272|0;c[m>>2]=((l|0)/1e3|0)-1;o=g+3660|0;q=0;while(1){if((q|0)>=3){break}r=b[2017192+((c[m>>2]|0)*6|0)+(q<<1)>>1]|0;if(r<<16>>16==0){break}s=hJb(((r&65535)*12|0)+2048|0)|0;c[o+(q<<2)>>2]=s;if((s|0)==0){t=17;break}else{q=q+1|0}}if((t|0)==17){KIb(p,16,2490384,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;q=c[f>>2]|0;mJb(q+3660|0);mJb(q+3664|0);mJb(q+3668|0);mJb(q+3640|0);mJb(q+3844|0);c[q+3852>>2]=0;c[q+3644>>2]=0;j=-12;i=e;return j|0}q=c[n>>2]|0;a:do{if((q|0)<3860){c[g+3864>>2]=36;c[g+3868>>2]=146;t=26}else{if((q|0)<3900){c[g+3864>>2]=130;c[g+3868>>2]=512;t=26;break}if((q|0)<3930){c[g+3864>>2]=12;c[g+3868>>2]=668;t=26;break}o=g+3864|0;do{if((q|0)<3990){c[o>>2]=12;c[g+3868>>2]=308;m=g+3872|0;if((q|0)>=3950){u=m;break}c[m>>2]=630;c[g+3876>>2]=334;break a}else{c[o>>2]=266;c[g+3868>>2]=218;u=g+3872|0}}while(0);c[u>>2]=642;c[g+3876>>2]=252}}while(0);if((t|0)==26){c[g+3872>>2]=514;c[g+3876>>2]=90}l8(g+8|0,a);q=(c[k>>2]|0)==2;o=a+448|0;c[o>>2]=q?3:4;c[o+4>>2]=q?0:0;j=0;i=e;return j|0}}while(0);KIb(p,16,2503872,(h=i,i=i+8|0,c[h>>2]=l,h)|0);i=h;j=-1094995529;i=e;return j|0}function w0(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;j=i;k=f;l=c[h+24>>2]|0;m=c[e+60>>2]|0;n=m;o=m+1256|0;p=c[o>>2]|0;if(!((p|0)>-1)){KIb(0,0,2458496,(q=i,i=i+24|0,c[q>>2]=2368424,c[q+8>>2]=2302648,c[q+16>>2]=1420,q)|0);i=q;Hd();return 0}a:do{if((p|0)==0){r=c[h+28>>2]|0;if((r|0)==0){c[g>>2]=0;s=0;i=j;return s|0}if((r|0)<8){KIb(e,16,2251152,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=-1094995529;i=j;return s|0}t=r&-4;if((t|0)!=(r|0)){KIb(e,24,2208392,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}r=m+1264|0;u=(c[r>>2]|0)<3950?t|2:t;v=m+3844|0;w=v;A4a(v,m+3852|0,u);v=c[w>>2]|0;if((v|0)==0){s=-12;i=j;return s|0}ef[c[m+1104>>2]&4095](v,l,u>>2);mrc((c[w>>2]|0)+t|0,0,u&2|0)|0;t=c[w>>2]|0;v=m+3856|0;x=t+u|0;c[m+3848>>2]=x;u=t+4|0;c[v>>2]=u;y=t;z=je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=t+8|0;c[v>>2]=y;A=u;u=je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0;A=c[r>>2]|0;r=(A|0)>3899;do{if(r){if(u>>>0>3>>>0){KIb(e,16,2175888,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[w>>2]=0;s=-1094995529;i=j;return s|0}if(!((x-y|0)>>>0<u>>>0)){B=t+(u+8)|0;c[v>>2]=B;C=B;break}KIb(e,16,2251152,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=-1094995529;i=j;return s|0}else{B=x-y|0;D=B>>>0>268435455>>>0?-8:B<<3;B=D>>>0>2147483639>>>0|(y|0)==0;E=B?0:y;F=B?0:D;c[m+3824>>2]=E;c[m+3836>>2]=F;D=F+8|0;c[m+3840>>2]=D;c[m+3828>>2]=E+(F>>3);F=m+3832|0;c[F>>2]=0;if(B){s=B?-1094995529:0;i=j;return s|0}if((A|0)>3800){B=u<<3;if((B|0)<0){G=0}else{G=(D|0)<(B|0)?D:B}c[F>>2]=G;C=y;break}else{if((u|0)<0){H=0}else{H=(D|0)<(u|0)?D:u}c[F>>2]=H;C=y;break}}}while(0);if((z|0)<1){KIb(e,16,2148056,(q=i,i=i+8|0,c[q>>2]=z,q)|0);i=q;s=-1094995529;i=j;return s|0}c[o>>2]=z;do{if(r){if((x-C|0)<6){break}y=C+4|0;c[v>>2]=y;u=C;t=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;c[m+1280>>2]=t;I=t;J=y;K=32}else{y=m+3832|0;t=c[y>>2]|0;u=c[m+3840>>2]|0;F=c[m+3824>>2]|0;D=F+(t>>>3)|0;B=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(t&7)&-65536;D=t+16|0;t=u>>>0>D>>>0?D:u;c[y>>2]=t;D=F+(t>>>3)|0;F=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(t&7)>>>16;D=t+16|0;c[y>>2]=u>>>0>D>>>0?D:u;u=F|B;c[m+1280>>2]=u;I=u;J=C;K=32}}while(0);do{if((K|0)==32){z=m+1284|0;c[z>>2]=0;if((A|0)>3820&(I|0)<0){c[m+1280>>2]=I&2147483647;if((x-J|0)<6){break}u=J+4|0;c[v>>2]=u;B=J;c[z>>2]=je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0;L=u}else{L=J}c[m+3688>>2]=10;c[m+3692>>2]=16384;c[m+3696>>2]=10;c[m+3700>>2]=16384;do{if(r){c[v>>2]=L+2;u=d[L+1|0]|0;c[m+3684>>2]=u;c[m+3672>>2]=u>>>1;c[m+3676>>2]=128;u=m+1388|0;mrc(u|0,0,200)|0;c[m+1288>>2]=u;if((A|0)<3930){K=38;break}u=m+1316|0;c[u>>2]=c[267794];c[u+4>>2]=c[267795];c[u+8>>2]=c[267796];c[u+12>>2]=c[267797];u=m+1332|0;c[u>>2]=c[267794];c[u+4>>2]=c[267795];c[u+8>>2]=c[267796];c[u+12>>2]=c[267797];mrc(m+1348|0,0,40)|0}else{u=m+1388|0;mrc(u|0,0,200)|0;c[m+1288>>2]=u;K=38}}while(0);if((K|0)==38){u=m+1316|0;if((c[m+1268>>2]|0)==1e3){c[u>>2]=375;c[m+1332>>2]=375;B=m+1348|0;mrc(B|0,0,40)|0;M=B}else{c[u>>2]=c[267790];c[u+4>>2]=c[267791];c[u+8>>2]=c[267792];u=m+1332|0;c[u>>2]=c[267790];c[u+4>>2]=c[267791];c[u+8>>2]=c[267792];u=m+1348|0;mrc(u|0,0,40)|0;M=u}u=M;c[u>>2]=740;c[u+4>>2]=0;u=m+1368|0;c[u>>2]=740;c[u+4>>2]=0}c[m+3636>>2]=0;mrc(m+1292|0,0,24)|0;u=m+1272|0;B=0;while(1){z=b[2017192+((c[u>>2]|0)*6|0)+(B<<1)>>1]|0;if(z<<16>>16==0){N=w;break a}F=c[n+3660+(B<<2)>>2]|0;D=z&65535;z=n+3704+(B*40|0)|0;c[z>>2]=F;y=F+(D<<1)|0;c[n+3704+(B*40|0)+8>>2]=y;t=D*3|0;c[n+3704+(B*40|0)+12>>2]=F+(t<<1);E=D<<1;c[n+3704+(B*40|0)+4>>2]=F+(E<<1);O=D<<2;mrc(y|0,0,O|0)|0;mrc(c[z>>2]|0,0,E|0)|0;c[n+3704+(B*40|0)+16>>2]=0;z=t+512|0;y=n+3704+(B*40|0)+20|0;c[y>>2]=F+(z<<1);P=F+(z+D<<1)|0;c[n+3704+(B*40|0)+28>>2]=P;c[n+3704+(B*40|0)+32>>2]=F+(z+t<<1);c[n+3704+(B*40|0)+24>>2]=F+(z+E<<1);mrc(P|0,0,O|0)|0;mrc(c[y>>2]|0,0,E|0)|0;c[n+3704+(B*40|0)+36>>2]=0;E=B+1|0;if((E|0)<3){B=E}else{N=w;break a}}}}while(0);KIb(e,16,2124056,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=-1094995529;i=j;return s|0}else{N=m+3844|0}}while(0);if((c[N>>2]|0)==0){c[g>>2]=0;s=c[h+28>>2]|0;i=j;return s|0}N=c[m+3656>>2]|0;M=c[o>>2]|0;L=(c[m+1264>>2]|0)<3930?M:(N|0)>(M|0)?M:N;N=m+3640|0;M=N;J=m+3644|0;I=L+7&-8;xJb(N,J,I<<3);N=c[M>>2]|0;if((N|0)==0){s=-12;i=j;return s|0}mrc(N|0,0,c[J>>2]|0)|0;J=c[M>>2]|0;M=m+3648|0;N=M;C=M;c[C>>2]=J;M=m+3652|0;c[M>>2]=J+(I<<2);c[f+76>>2]=L;I=M4a(e,k,0)|0;if((I|0)<0){s=I;i=j;return s|0}I=m+3860|0;c[I>>2]=0;k=m+1252|0;J=c[m+1284>>2]|0;do{if((c[k>>2]|0)==1){K=53}else{if((J&4|0)!=0){K=53;break}if((J&3|0)!=0){KIb(c[m+4>>2]|0,48,2619016,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break}H=c[M>>2]|0;G=c[C>>2]|0;re[c[m+3868>>2]&1023](n,L);re[c[m+3876>>2]&1023](n,L);if((L|0)==0){break}else{Q=L;R=G;S=H}while(1){H=Q-1|0;G=c[R>>2]|0;l=(c[S>>2]|0)-((G|0)/2|0)|0;c[R>>2]=l;c[S>>2]=l+G;if((H|0)==0){break}else{Q=H;R=R+4|0;S=S+4|0}}}}while(0);do{if((K|0)==53){if((J&3|0)!=0){KIb(c[m+4>>2]|0,48,2591664,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break}re[c[m+3864>>2]&1023](n,L);re[c[m+3872>>2]&1023](n,L);if((c[k>>2]|0)!=2){break}nrc(c[M>>2]|0,c[C>>2]|0,L<<2)|0}}while(0);if((c[I>>2]|0)!=0){c[o>>2]=0;KIb(e,16,2642312,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=-1094995529;i=j;return s|0}q=c[m+1260>>2]|0;b:do{if((q|0)==16){m=c[k>>2]|0;if((m|0)<=0){break}e=f;if((L|0)>0){T=0}else{break}do{I=c[N+(T<<2)>>2]|0;C=c[e+(T<<2)>>2]|0;M=0;while(1){b[C>>1]=c[I+(M<<2)>>2];n=M+1|0;if((n|0)<(L|0)){C=C+2|0;M=n}else{break}}T=T+1|0;}while((T|0)<(m|0))}else if((q|0)==24){m=c[k>>2]|0;if((m|0)<=0){break}e=f;if((L|0)>0){U=0}else{M=0;while(1){M=M+1|0;if((M|0)>=(m|0)){break b}}}do{m=c[N+(U<<2)>>2]|0;M=c[e+(U<<2)>>2]|0;C=0;while(1){c[M>>2]=c[m+(C<<2)>>2]<<8;I=C+1|0;if((I|0)<(L|0)){M=M+4|0;C=I}else{break}}U=U+1|0;}while((U|0)<(c[k>>2]|0))}else if((q|0)==8){e=c[k>>2]|0;if((e|0)<=0){break}C=f;if((L|0)>0){V=0}else{M=0;while(1){M=M+1|0;if((M|0)>=(e|0)){break b}}}do{e=N+(V<<2)|0;M=0;m=c[C+(V<<2)>>2]|0;while(1){a[m]=(c[(c[e>>2]|0)+(M<<2)>>2]|0)+128;I=M+1|0;if((I|0)<(L|0)){M=I;m=m+1|0}else{break}}V=V+1|0;}while((V|0)<(c[k>>2]|0))}}while(0);c[o>>2]=(c[o>>2]|0)-L;c[g>>2]=1;if((c[o>>2]|0)!=0){s=0;i=j;return s|0}s=c[h+28>>2]|0;i=j;return s|0}function x0(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+3660|0);mJb(b+3664|0);mJb(b+3668|0);mJb(b+3640|0);mJb(b+3844|0);c[b+3852>>2]=0;c[b+3644>>2]=0;return 0}function y0(a){a=a|0;c[(c[a+60>>2]|0)+1256>>2]=0;return}function z0(a,b){a=a|0;b=b|0;V0(a,c[a+3648>>2]|0,a+3696|0,b);return}function A0(a,b){a=a|0;b=b|0;V0(a,c[a+3648>>2]|0,a+3696|0,b);V0(a,c[a+3652>>2]|0,a+3688|0,b);return}function B0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((b|0)==0){return}d=a+3824|0;e=a+3696|0;f=b;b=c[a+3648>>2]|0;while(1){g=f-1|0;c[b>>2]=U0(a,d,e)|0;if((g|0)==0){break}else{f=g;b=b+4|0}}return}function C0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[a+3652>>2]|0;e=(b|0)==0;if(e){return}f=a+3824|0;g=a+3696|0;h=b;i=c[a+3648>>2]|0;while(1){j=h-1|0;c[i>>2]=U0(a,f,g)|0;if((j|0)==0){break}else{h=j;i=i+4|0}}if(e){return}e=a+3824|0;i=a+3688|0;h=d;d=b;while(1){b=d-1|0;c[h>>2]=U0(a,e,i)|0;if((b|0)==0){break}else{h=h+4|0;d=b}}return}function D0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((b|0)==0){return}d=a+3696|0;e=b;b=c[a+3648>>2]|0;while(1){f=e-1|0;c[b>>2]=T0(a,d)|0;if((f|0)==0){break}else{e=f;b=b+4|0}}return}function E0(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[a+3652>>2]|0;f=(b|0)==0;if(!f){g=a+3696|0;h=b;i=c[a+3648>>2]|0;while(1){j=h-1|0;c[i>>2]=T0(a,g)|0;if((j|0)==0){break}else{h=j;i=i+4|0}}}i=a+3676|0;h=c[i>>2]|0;if(h>>>0<8388609>>>0){g=a+3684|0;j=a+3856|0;k=a+3672|0;l=a+3860|0;m=c[a+3848>>2]|0;n=c[g>>2]|0;o=c[j>>2]|0;p=h;while(1){h=n<<8;c[g>>2]=h;if(o>>>0<m>>>0){q=d[o]|0|h;c[g>>2]=q;r=o+1|0;c[j>>2]=r;s=r;t=q}else{c[l>>2]=1;s=o;t=h}c[k>>2]=c[k>>2]<<8|t>>>1&255;h=p<<8;c[i>>2]=h;if(h>>>0<8388609>>>0){n=t;o=s;p=h}else{u=s;v=g;w=k;break}}}else{u=c[a+3856>>2]|0;v=a+3684|0;w=a+3672|0}k=d[u-1|0]|0;c[v>>2]=k;c[w>>2]=k>>>1;c[i>>2]=128;if(f){return}f=a+3688|0;i=e;e=b;while(1){b=e-1|0;c[i>>2]=T0(a,f)|0;if((b|0)==0){break}else{i=i+4|0;e=b}}return}function F0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;if((b|0)==0){return}d=a+3696|0;e=a+3688|0;f=b;b=c[a+3648>>2]|0;g=c[a+3652>>2]|0;while(1){h=f-1|0;c[b>>2]=T0(a,d)|0;c[g>>2]=T0(a,e)|0;if((h|0)==0){break}else{f=h;b=b+4|0;g=g+4|0}}return}function G0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((b|0)==0){return}d=a+3696|0;e=b;b=c[a+3648>>2]|0;while(1){f=e-1|0;c[b>>2]=S0(a,d)|0;if((f|0)==0){break}else{e=f;b=b+4|0}}return}function H0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;if((b|0)==0){return}d=a+3696|0;e=a+3688|0;f=b;b=c[a+3648>>2]|0;g=c[a+3652>>2]|0;while(1){h=f-1|0;c[b>>2]=S0(a,d)|0;c[g>>2]=S0(a,e)|0;if((h|0)==0){break}else{f=h;b=b+4|0;g=g+4|0}}return}function I0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+2048|0;e=d|0;f=d+1024|0;g=c[a+3648>>2]|0;h=a+1268|0;j=c[h>>2]|0;do{if((j|0)==3e3){mrc(e|0,0,64)|0;k=c[g>>2]|0;l=f|0;c[l>>2]=k;m=f+4|0;c[m>>2]=c[g+4>>2];n=f+8|0;c[n>>2]=c[g+8>>2];o=f+12|0;c[o>>2]=c[g+12>>2];p=f+16|0;c[p>>2]=c[g+16>>2];q=f+20|0;c[q>>2]=c[g+20>>2];r=f+24|0;c[r>>2]=c[g+24>>2];s=f+28|0;c[s>>2]=c[g+28>>2];t=f+32|0;c[t>>2]=c[g+32>>2];u=f+36|0;c[u>>2]=c[g+36>>2];v=f+40|0;c[v>>2]=c[g+40>>2];w=f+44|0;c[w>>2]=c[g+44>>2];x=f+48|0;c[x>>2]=c[g+48>>2];y=f+52|0;c[y>>2]=c[g+52>>2];z=f+56|0;c[z>>2]=c[g+56>>2];A=c[g+60>>2]|0;B=f+60|0;c[B>>2]=A;if((b|0)>16){C=16;D=A;E=k}else{F=10;G=16;break}while(1){k=g+(C<<2)|0;A=c[k>>2]|0;H=(A>>>31)-((A|0)>0)|0;I=0;J=0;K=E;while(1){L=e+(I<<2)|0;M=c[L>>2]|0;N=(ca(M,K)|0)+J|0;c[L>>2]=M-(ca((K>>>30&2)-1|0,H)|0);M=I+1|0;if((M|0)>=16){break}I=M;J=N;K=c[f+(M<<2)>>2]|0}K=A-(N>>9)|0;c[k>>2]=K;J=c[m>>2]|0;c[l>>2]=J;c[m>>2]=c[n>>2];c[n>>2]=c[o>>2];c[o>>2]=c[p>>2];c[p>>2]=c[q>>2];c[q>>2]=c[r>>2];c[r>>2]=c[s>>2];c[s>>2]=c[t>>2];c[t>>2]=c[u>>2];c[u>>2]=c[v>>2];c[v>>2]=c[w>>2];c[w>>2]=c[x>>2];c[x>>2]=c[y>>2];c[y>>2]=c[z>>2];c[z>>2]=D;c[B>>2]=K;I=C+1|0;if((I|0)<(b|0)){C=I;D=K;E=J}else{F=10;G=16;break}}}else if((j|0)==4e3){if((c[a+1264>>2]|0)>3829){R0(g+1024|0,b-256|0);O=12;P=256;Q=11}else{O=11;P=128;Q=10}Q0(g,P,O,e|0,f|0,b);F=Q;G=P}else{F=10;G=4}}while(0);if((b|0)==0){i=d;return}P=a+1292|0;Q=a+1288|0;f=a+3636|0;e=a+1300|0;O=a+1316|0;j=a+1388|0;E=a+3436|0;D=j|0;C=j;j=a+1308|0;N=a+1320|0;B=a+1324|0;z=a+1348|0;y=a+1352|0;a=g;g=b;b=c[Q>>2]|0;while(1){x=g-1|0;w=(c[h>>2]|0)==1e3;v=c[a>>2]|0;u=c[P>>2]|0;c[b+200>>2]=u;do{if(w){if((c[f>>2]|0)>>>0<3>>>0){c[P>>2]=v;c[e>>2]=v;R=v;break}else{t=(u<<1)-(c[b+196>>2]|0)|0;s=c[O>>2]|0;r=((ca(t,s)|0)>>9)+v|0;c[P>>2]=r;c[O>>2]=((t^v|0)>0?1:-1)+s;s=(c[e>>2]|0)+r|0;c[e>>2]=s;R=s;break}}else{s=c[j>>2]|0;c[b+168>>2]=s;if((c[f>>2]|0)>>>0<G>>>0){r=(c[e>>2]|0)+v|0;c[P>>2]=v;c[j>>2]=v;c[e>>2]=r;R=r;break}else{r=c[b+196>>2]|0;t=u-r|0;q=((c[b+192>>2]|0)-r<<3)+u|0;r=(s<<1)-(c[b+164>>2]|0)|0;p=c[O>>2]|0;o=ca(q,p)|0;n=c[N>>2]|0;m=(ca(t<<1,n)|0)+o|0;o=c[B>>2]|0;l=m+(ca(o,u)|0)|0;m=(v>>>31)-((v|0)>0)|0;c[O>>2]=(ca((q>>>30&2)-1|0,m)|0)+p;c[N>>2]=(ca((t>>>27&8)-4|0,m)|0)+n;c[B>>2]=o+(ca((u>>>28&8)-4|0,m)|0);m=c[z>>2]|0;o=ca(m,r)|0;n=c[y>>2]|0;t=o-(ca(n,s)|0)|0;o=(l>>11)+v|0;c[P>>2]=o;l=(o>>>31)-((o|0)>0)|0;c[z>>2]=(ca(l,(r>>>29&4)-2|0)|0)+m;c[y>>2]=n-(ca(l,(s>>>30&2)-1|0)|0);s=(t>>F)+o|0;c[j>>2]=s;o=s+(((c[e>>2]|0)*31|0)>>5)|0;c[e>>2]=o;R=o;break}}}while(0);c[a>>2]=R;v=(c[Q>>2]|0)+4|0;c[Q>>2]=v;c[f>>2]=(c[f>>2]|0)+1;if((v|0)==(E|0)){nrc(C|0,E|0,200)|0;c[Q>>2]=D;S=D}else{S=v}if((x|0)==0){break}else{a=a+4|0;g=x;b=S}}i=d;return}function J0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;i=i+2048|0;e=d|0;f=d+1024|0;g=c[a+3648>>2]|0;h=c[a+3652>>2]|0;j=a+1268|0;k=c[j>>2]|0;do{if((k|0)==4e3){if((c[a+1264>>2]|0)>3829){l=b-256|0;R0(g+1024|0,l);R0(h+1024|0,l);m=12;n=256;o=11}else{m=11;n=128;o=10}l=e|0;p=f|0;Q0(g,n,m,l,p,b);Q0(h,n,m,l,p,b);q=o;r=n}else if((k|0)==3e3){p=e;mrc(p|0,0,64)|0;l=c[g>>2]|0;s=f|0;c[s>>2]=l;t=f+4|0;c[t>>2]=c[g+4>>2];u=f+8|0;c[u>>2]=c[g+8>>2];v=f+12|0;c[v>>2]=c[g+12>>2];w=f+16|0;c[w>>2]=c[g+16>>2];x=f+20|0;c[x>>2]=c[g+20>>2];y=f+24|0;c[y>>2]=c[g+24>>2];z=f+28|0;c[z>>2]=c[g+28>>2];A=f+32|0;c[A>>2]=c[g+32>>2];B=f+36|0;c[B>>2]=c[g+36>>2];C=f+40|0;c[C>>2]=c[g+40>>2];D=f+44|0;c[D>>2]=c[g+44>>2];E=f+48|0;c[E>>2]=c[g+48>>2];F=f+52|0;c[F>>2]=c[g+52>>2];G=f+56|0;c[G>>2]=c[g+56>>2];H=f+60|0;c[H>>2]=c[g+60>>2];I=(b|0)>16;if(I){J=16;K=l;do{l=g+(J<<2)|0;L=c[l>>2]|0;M=(L>>>31)-((L|0)>0)|0;N=0;O=0;P=K;while(1){Q=e+(N<<2)|0;R=c[Q>>2]|0;S=(ca(R,P)|0)+O|0;c[Q>>2]=R-(ca((P>>>30&2)-1|0,M)|0);R=N+1|0;if((R|0)>=16){break}N=R;O=S;P=c[f+(R<<2)>>2]|0}c[l>>2]=L-(S>>9);K=c[t>>2]|0;c[s>>2]=K;c[t>>2]=c[u>>2];c[u>>2]=c[v>>2];c[v>>2]=c[w>>2];c[w>>2]=c[x>>2];c[x>>2]=c[y>>2];c[y>>2]=c[z>>2];c[z>>2]=c[A>>2];c[A>>2]=c[B>>2];c[B>>2]=c[C>>2];c[C>>2]=c[D>>2];c[D>>2]=c[E>>2];c[E>>2]=c[F>>2];c[F>>2]=c[G>>2];c[G>>2]=c[H>>2];c[H>>2]=c[l>>2];J=J+1|0;}while((J|0)<(b|0))}mrc(p|0,0,64)|0;J=c[h>>2]|0;c[s>>2]=J;c[t>>2]=c[h+4>>2];c[u>>2]=c[h+8>>2];c[v>>2]=c[h+12>>2];c[w>>2]=c[h+16>>2];c[x>>2]=c[h+20>>2];c[y>>2]=c[h+24>>2];c[z>>2]=c[h+28>>2];c[A>>2]=c[h+32>>2];c[B>>2]=c[h+36>>2];c[C>>2]=c[h+40>>2];c[D>>2]=c[h+44>>2];c[E>>2]=c[h+48>>2];c[F>>2]=c[h+52>>2];c[G>>2]=c[h+56>>2];K=c[h+60>>2]|0;c[H>>2]=K;if(I){T=16;U=K;V=J}else{q=10;r=16;break}while(1){J=h+(T<<2)|0;K=c[J>>2]|0;P=(K>>>31)-((K|0)>0)|0;O=0;N=0;M=V;while(1){R=e+(O<<2)|0;Q=c[R>>2]|0;W=(ca(Q,M)|0)+N|0;c[R>>2]=Q-(ca((M>>>30&2)-1|0,P)|0);Q=O+1|0;if((Q|0)>=16){break}O=Q;N=W;M=c[f+(Q<<2)>>2]|0}M=K-(W>>9)|0;c[J>>2]=M;N=c[t>>2]|0;c[s>>2]=N;c[t>>2]=c[u>>2];c[u>>2]=c[v>>2];c[v>>2]=c[w>>2];c[w>>2]=c[x>>2];c[x>>2]=c[y>>2];c[y>>2]=c[z>>2];c[z>>2]=c[A>>2];c[A>>2]=c[B>>2];c[B>>2]=c[C>>2];c[C>>2]=c[D>>2];c[D>>2]=c[E>>2];c[E>>2]=c[F>>2];c[F>>2]=c[G>>2];c[G>>2]=U;c[H>>2]=M;O=T+1|0;if((O|0)<(b|0)){T=O;U=M;V=N}else{q=10;r=16;break}}}else{q=10;r=4}}while(0);if((b|0)==0){i=d;return}V=a+1292|0;U=a+1288|0;T=a+3636|0;W=a+1300|0;f=a+1296|0;e=a+1304|0;S=a+1332|0;k=a+1316|0;n=a+1388|0;o=a+3436|0;m=n|0;H=n;n=a+1308|0;G=a+1312|0;F=a+1336|0;E=a+1340|0;D=a+1368|0;C=a+1372|0;B=a+1320|0;A=a+1324|0;z=a+1348|0;y=a+1352|0;a=h;h=g;g=b;b=c[U>>2]|0;while(1){x=g-1|0;w=c[h>>2]|0;v=c[a>>2]|0;u=(c[j>>2]|0)==1e3;t=c[V>>2]|0;c[b+200>>2]=t;do{if(u){if((c[T>>2]|0)>>>0<3>>>0){c[V>>2]=v;X=v}else{s=(t<<1)-(c[b+196>>2]|0)|0;I=c[k>>2]|0;p=((ca(s,I)|0)>>9)+v|0;c[V>>2]=p;c[k>>2]=((s^v|0)>0?1:-1)+I;X=(c[W>>2]|0)+p|0}c[W>>2]=X;c[h>>2]=X;p=c[f>>2]|0;c[b+136>>2]=p;if((c[T>>2]|0)>>>0<3>>>0){c[f>>2]=w;c[e>>2]=w;Y=w;break}else{I=(p<<1)-(c[b+132>>2]|0)|0;p=c[S>>2]|0;s=((ca(I,p)|0)>>9)+w|0;c[f>>2]=s;c[S>>2]=((I^w|0)>0?1:-1)+p;p=(c[e>>2]|0)+s|0;c[e>>2]=p;Y=p;break}}else{p=c[n>>2]|0;c[b+168>>2]=p;if((c[T>>2]|0)>>>0<r>>>0){s=(c[W>>2]|0)+v|0;c[V>>2]=v;c[n>>2]=v;Z=s}else{s=c[b+196>>2]|0;I=t-s|0;N=((c[b+192>>2]|0)-s<<3)+t|0;s=(p<<1)-(c[b+164>>2]|0)|0;M=c[k>>2]|0;O=ca(N,M)|0;P=c[B>>2]|0;l=(ca(I<<1,P)|0)+O|0;O=c[A>>2]|0;L=l+(ca(O,t)|0)|0;l=(v>>>31)-((v|0)>0)|0;c[k>>2]=(ca((N>>>30&2)-1|0,l)|0)+M;c[B>>2]=(ca((I>>>27&8)-4|0,l)|0)+P;c[A>>2]=O+(ca((t>>>28&8)-4|0,l)|0);l=c[z>>2]|0;O=ca(l,s)|0;P=c[y>>2]|0;I=O-(ca(P,p)|0)|0;O=(L>>11)+v|0;c[V>>2]=O;L=(O>>>31)-((O|0)>0)|0;c[z>>2]=(ca(L,(s>>>29&4)-2|0)|0)+l;c[y>>2]=P-(ca(L,(p>>>30&2)-1|0)|0);p=(I>>q)+O|0;c[n>>2]=p;Z=p+(((c[W>>2]|0)*31|0)>>5)|0}c[W>>2]=Z;c[h>>2]=Z;p=c[f>>2]|0;c[b+136>>2]=p;O=c[G>>2]|0;c[b+104>>2]=O;if((c[T>>2]|0)>>>0<r>>>0){I=(c[e>>2]|0)+w|0;c[f>>2]=w;c[G>>2]=w;c[e>>2]=I;Y=I;break}else{I=c[b+132>>2]|0;L=p-I|0;P=((c[b+128>>2]|0)-I<<3)+p|0;I=(O<<1)-(c[b+100>>2]|0)|0;l=c[S>>2]|0;s=ca(P,l)|0;M=c[F>>2]|0;N=(ca(L<<1,M)|0)+s|0;s=c[E>>2]|0;Q=N+(ca(s,p)|0)|0;N=(w>>>31)-((w|0)>0)|0;c[S>>2]=(ca((P>>>30&2)-1|0,N)|0)+l;c[F>>2]=(ca((L>>>27&8)-4|0,N)|0)+M;c[E>>2]=s+(ca((p>>>28&8)-4|0,N)|0);N=c[D>>2]|0;p=ca(N,I)|0;s=c[C>>2]|0;M=p-(ca(s,O)|0)|0;p=(Q>>11)+w|0;c[f>>2]=p;Q=(p>>>31)-((p|0)>0)|0;c[D>>2]=(ca(Q,(I>>>29&4)-2|0)|0)+N;c[C>>2]=s-(ca(Q,(O>>>30&2)-1|0)|0);O=(M>>q)+p|0;c[G>>2]=O;p=O+(((c[e>>2]|0)*31|0)>>5)|0;c[e>>2]=p;Y=p;break}}}while(0);c[a>>2]=Y;w=(c[U>>2]|0)+4|0;c[U>>2]=w;c[T>>2]=(c[T>>2]|0)+1;if((w|0)==(o|0)){nrc(H|0,o|0,200)|0;c[U>>2]=m;_=m}else{_=w}if((x|0)==0){break}else{a=a+4|0;h=h+4|0;g=x;b=_}}i=d;return}function K0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[a+3648>>2]|0;O0(a,d,0,b);if((b|0)==0){return}e=a+1292|0;f=a+1288|0;g=a+1316|0;h=a+1320|0;i=a+1324|0;j=a+1328|0;k=a+1300|0;l=a+1388|0;m=a+3436|0;a=l|0;n=l;l=d;d=b;b=c[f>>2]|0;while(1){o=d-1|0;p=c[l>>2]|0;q=c[e>>2]|0;c[b+200>>2]=q;r=c[b+196>>2]|0;s=q-r|0;t=c[b+192>>2]|0;u=r-t|0;r=t-(c[b+188>>2]|0)|0;t=c[g>>2]|0;v=ca(t,q)|0;w=c[h>>2]|0;x=(ca(w,s)|0)+v|0;v=c[i>>2]|0;y=x+(ca(v,u)|0)|0;x=c[j>>2]|0;z=(y+(ca(x,r)|0)>>9)+p|0;c[e>>2]=z;y=z+(((c[k>>2]|0)*31|0)>>5)|0;c[k>>2]=y;z=(p>>>31)-((p|0)>0)|0;c[g>>2]=t+(ca((q>>>31<<1)-1|0,z)|0);c[h>>2]=w+(ca((s>>>31<<1)-1|0,z)|0);c[i>>2]=v+(ca((u>>>31<<1)-1|0,z)|0);c[j>>2]=x+(ca((r>>>31<<1)-1|0,z)|0);c[l>>2]=y;y=b+4|0;c[f>>2]=y;if((y|0)==(m|0)){nrc(n|0,m|0,200)|0;c[f>>2]=a;A=a}else{A=y}if((o|0)==0){break}else{l=l+4|0;d=o;b=A}}return}function L0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=c[a+3648>>2]|0;e=c[a+3652>>2]|0;O0(a,d,e,b);if((b|0)==0){return}f=a+1292|0;g=a+1288|0;h=a+1316|0;i=a+1320|0;j=a+1324|0;k=a+1328|0;l=a+1300|0;m=a+1296|0;n=a+1332|0;o=a+1336|0;p=a+1340|0;q=a+1344|0;r=a+1304|0;s=a+1388|0;t=a+3436|0;a=s|0;u=s;s=e;e=d;d=b;b=c[g>>2]|0;while(1){v=d-1|0;w=c[s>>2]|0;x=c[e>>2]|0;y=c[f>>2]|0;c[b+200>>2]=y;z=c[b+196>>2]|0;A=y-z|0;B=c[b+192>>2]|0;C=z-B|0;z=B-(c[b+188>>2]|0)|0;B=c[h>>2]|0;D=ca(B,y)|0;E=c[i>>2]|0;F=(ca(E,A)|0)+D|0;D=c[j>>2]|0;G=F+(ca(D,C)|0)|0;F=c[k>>2]|0;H=(G+(ca(F,z)|0)>>9)+w|0;c[f>>2]=H;G=H+(((c[l>>2]|0)*31|0)>>5)|0;c[l>>2]=G;H=(w>>>31)-((w|0)>0)|0;c[h>>2]=B+(ca((y>>>31<<1)-1|0,H)|0);c[i>>2]=E+(ca((A>>>31<<1)-1|0,H)|0);c[j>>2]=D+(ca((C>>>31<<1)-1|0,H)|0);c[k>>2]=F+(ca((z>>>31<<1)-1|0,H)|0);c[e>>2]=G;G=c[m>>2]|0;c[b+136>>2]=G;H=c[b+132>>2]|0;z=G-H|0;F=c[b+128>>2]|0;C=H-F|0;H=F-(c[b+124>>2]|0)|0;F=c[n>>2]|0;D=ca(F,G)|0;A=c[o>>2]|0;E=(ca(A,z)|0)+D|0;D=c[p>>2]|0;y=E+(ca(D,C)|0)|0;E=c[q>>2]|0;B=(y+(ca(E,H)|0)>>9)+x|0;c[m>>2]=B;y=B+(((c[r>>2]|0)*31|0)>>5)|0;c[r>>2]=y;B=(x>>>31)-((x|0)>0)|0;c[n>>2]=F+(ca((G>>>31<<1)-1|0,B)|0);c[o>>2]=A+(ca((z>>>31<<1)-1|0,B)|0);c[p>>2]=D+(ca((C>>>31<<1)-1|0,B)|0);c[q>>2]=E+(ca((H>>>31<<1)-1|0,B)|0);c[s>>2]=y;y=b+4|0;c[g>>2]=y;if((y|0)==(t|0)){nrc(u|0,t|0,200)|0;c[g>>2]=a;I=a}else{I=y}if((v|0)==0){break}else{s=s+4|0;e=e+4|0;d=v;b=I}}return}function M0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[a+3648>>2]|0;O0(a,d,0,b);e=a+1292|0;f=c[e>>2]|0;if((b|0)==0){g=f;c[e>>2]=g;return}h=a+1288|0;i=a+1316|0;j=a+1320|0;k=a+1324|0;l=a+1328|0;m=a+1388|0;n=a+3436|0;o=m|0;p=m;m=a+1300|0;a=f;f=d;d=b;b=c[h>>2]|0;while(1){q=d-1|0;r=c[f>>2]|0;c[b+200>>2]=a;s=b+196|0;t=a-(c[s>>2]|0)|0;c[s>>2]=t;s=ca(c[i>>2]|0,a)|0;u=(ca(c[j>>2]|0,t)|0)+s|0;s=u+(ca(c[k>>2]|0,c[b+192>>2]|0)|0)|0;u=(s+(ca(c[l>>2]|0,c[b+188>>2]|0)|0)>>10)+r|0;s=(a>>>31)-((a|0)>0)|0;c[b+72>>2]=s;v=b+68|0;c[v>>2]=(t>>>31)-((t|0)>0);t=(r>>>31)-((r|0)>0)|0;r=ca(s,t)|0;c[i>>2]=(c[i>>2]|0)+r;r=ca(c[v>>2]|0,t)|0;c[j>>2]=(c[j>>2]|0)+r;r=ca(c[b+64>>2]|0,t)|0;c[k>>2]=(c[k>>2]|0)+r;r=ca(c[b+60>>2]|0,t)|0;c[l>>2]=(c[l>>2]|0)+r;r=b+4|0;c[h>>2]=r;if((r|0)==(n|0)){nrc(p|0,n|0,200)|0;c[h>>2]=o;w=o}else{w=r}r=(((c[m>>2]|0)*31|0)>>5)+u|0;c[m>>2]=r;c[f>>2]=r;if((q|0)==0){g=u;break}else{a=u;f=f+4|0;d=q;b=w}}c[e>>2]=g;return}function N0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=c[a+3648>>2]|0;e=c[a+3652>>2]|0;O0(a,d,e,b);if((b|0)==0){return}f=a+1292|0;g=a+1288|0;h=a+1316|0;i=a+1320|0;j=a+1324|0;k=a+1328|0;l=a+1304|0;m=a+1308|0;n=a+1348|0;o=a+1352|0;p=a+1356|0;q=a+1360|0;r=a+1364|0;s=a+1300|0;t=a+1296|0;u=a+1332|0;v=a+1336|0;w=a+1340|0;x=a+1344|0;y=a+1312|0;z=a+1368|0;A=a+1372|0;B=a+1376|0;C=a+1380|0;D=a+1384|0;E=a+1388|0;F=a+3436|0;a=E|0;G=E;E=d;d=e;e=b;b=c[g>>2]|0;while(1){H=e-1|0;I=c[E>>2]|0;J=c[f>>2]|0;c[b+200>>2]=J;K=b+72|0;c[K>>2]=(J>>>31)-((J|0)>0);L=b+196|0;M=J-(c[L>>2]|0)|0;c[L>>2]=M;L=b+68|0;c[L>>2]=(M>>>31)-((M|0)>0);N=ca(c[h>>2]|0,J)|0;J=(ca(c[i>>2]|0,M)|0)+N|0;N=J+(ca(c[j>>2]|0,c[b+192>>2]|0)|0)|0;J=N+(ca(c[k>>2]|0,c[b+188>>2]|0)|0)|0;N=(c[l>>2]|0)-(((c[m>>2]|0)*31|0)>>5)|0;M=b+168|0;c[M>>2]=N;O=b+40|0;c[O>>2]=(N>>>31)-((N|0)>0);P=b+164|0;Q=N-(c[P>>2]|0)|0;c[P>>2]=Q;N=b+36|0;c[N>>2]=(Q>>>31)-((Q|0)>0);c[m>>2]=c[l>>2];Q=c[n>>2]|0;R=ca(Q,c[M>>2]|0)|0;M=c[o>>2]|0;S=(ca(M,c[P>>2]|0)|0)+R|0;R=c[p>>2]|0;P=S+(ca(R,c[b+160>>2]|0)|0)|0;S=c[q>>2]|0;T=P+(ca(S,c[b+156>>2]|0)|0)|0;P=c[r>>2]|0;U=(J+(T+(ca(P,c[b+152>>2]|0)|0)>>1)>>10)+I|0;c[f>>2]=U;T=U+(((c[s>>2]|0)*31|0)>>5)|0;c[s>>2]=T;U=(I>>>31)-((I|0)>0)|0;I=ca(c[K>>2]|0,U)|0;c[h>>2]=(c[h>>2]|0)+I;I=ca(c[L>>2]|0,U)|0;c[i>>2]=(c[i>>2]|0)+I;I=ca(c[b+64>>2]|0,U)|0;c[j>>2]=(c[j>>2]|0)+I;I=ca(c[b+60>>2]|0,U)|0;c[k>>2]=(c[k>>2]|0)+I;c[n>>2]=Q+(ca(c[O>>2]|0,U)|0);c[o>>2]=M+(ca(c[N>>2]|0,U)|0);c[p>>2]=R+(ca(c[b+32>>2]|0,U)|0);c[q>>2]=S+(ca(c[b+28>>2]|0,U)|0);c[r>>2]=P+(ca(c[b+24>>2]|0,U)|0);c[E>>2]=T;T=c[d>>2]|0;U=c[t>>2]|0;c[b+136>>2]=U;P=b+56|0;c[P>>2]=(U>>>31)-((U|0)>0);S=b+132|0;R=U-(c[S>>2]|0)|0;c[S>>2]=R;S=b+52|0;c[S>>2]=(R>>>31)-((R|0)>0);N=ca(c[u>>2]|0,U)|0;U=(ca(c[v>>2]|0,R)|0)+N|0;N=U+(ca(c[w>>2]|0,c[b+128>>2]|0)|0)|0;U=N+(ca(c[x>>2]|0,c[b+124>>2]|0)|0)|0;N=(c[s>>2]|0)-(((c[y>>2]|0)*31|0)>>5)|0;R=b+104|0;c[R>>2]=N;M=b+20|0;c[M>>2]=(N>>>31)-((N|0)>0);O=b+100|0;Q=N-(c[O>>2]|0)|0;c[O>>2]=Q;N=b+16|0;c[N>>2]=(Q>>>31)-((Q|0)>0);c[y>>2]=c[s>>2];Q=c[z>>2]|0;I=ca(Q,c[R>>2]|0)|0;R=c[A>>2]|0;L=(ca(R,c[O>>2]|0)|0)+I|0;I=c[B>>2]|0;O=L+(ca(I,c[b+96>>2]|0)|0)|0;L=c[C>>2]|0;K=O+(ca(L,c[b+92>>2]|0)|0)|0;O=c[D>>2]|0;J=(U+(K+(ca(O,c[b+88>>2]|0)|0)>>1)>>10)+T|0;c[t>>2]=J;K=J+(((c[l>>2]|0)*31|0)>>5)|0;c[l>>2]=K;J=(T>>>31)-((T|0)>0)|0;T=ca(c[P>>2]|0,J)|0;c[u>>2]=(c[u>>2]|0)+T;T=ca(c[S>>2]|0,J)|0;c[v>>2]=(c[v>>2]|0)+T;T=ca(c[b+48>>2]|0,J)|0;c[w>>2]=(c[w>>2]|0)+T;T=ca(c[b+44>>2]|0,J)|0;c[x>>2]=(c[x>>2]|0)+T;c[z>>2]=Q+(ca(c[M>>2]|0,J)|0);c[A>>2]=R+(ca(c[N>>2]|0,J)|0);c[B>>2]=I+(ca(c[b+12>>2]|0,J)|0);c[C>>2]=L+(ca(c[b+8>>2]|0,J)|0);L=b+4|0;c[D>>2]=O+(ca(c[L>>2]|0,J)|0);c[d>>2]=K;c[g>>2]=L;if((L|0)==(F|0)){nrc(G|0,F|0,200)|0;c[g>>2]=a;V=a}else{V=L}if((H|0)==0){break}else{E=E+4|0;d=d+4|0;e=H;b=V}}return}function O0(a,b,f,g){a=a|0;b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=a+1272|0;i=a+1264|0;j=(f|0)==0;k=c[h>>2]|0;if((k|0)==0){return}l=e[2017192+(k*6|0)>>1]|0;m=d[2017224+(k*3|0)|0]|0;P0(a,c[i>>2]|0,a+3704|0,b,g,l,m);if(!j){P0(a,c[i>>2]|0,a+3724|0,f,g,l,m)}m=c[h>>2]|0;if((m-3|0)>>>0>1>>>0){return}l=e[2017194+(m*6|0)>>1]|0;k=d[2017225+(m*3|0)|0]|0;P0(a,c[i>>2]|0,a+3744|0,b,g,l,k);if(!j){P0(a,c[i>>2]|0,a+3764|0,f,g,l,k)}k=c[h>>2]|0;if((k|0)!=4){return}h=e[2017196+(k*6|0)>>1]|0;l=d[2017226+(k*3|0)|0]|0;P0(a,c[i>>2]|0,a+3784|0,b,g,h,l);if(j){return}P0(a,c[i>>2]|0,a+3804|0,f,g,h,l);return}function P0(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((g|0)==0){return}j=a+1236|0;a=e|0;k=e+12|0;l=-h|0;m=e+4|0;n=1<<i-1;o=(d|0)<3980;d=e+8|0;p=h<<1;q=p+512|0;r=-p|0;s=h<<2;t=e+16|0;e=f;f=g;g=c[k>>2]|0;u=c[m>>2]|0;while(1){v=f-1|0;w=c[e>>2]|0;x=(Xe[c[j>>2]&511](c[a>>2]|0,g+(l<<1)|0,u+(l<<1)|0,h,(w>>>31)-((w|0)>0)|0)|0)+n>>i;w=x+(c[e>>2]|0)|0;x=e+4|0;c[e>>2]=w;if((w+32768|0)>>>0>65535>>>0){y=(w>>31^32767)&65535}else{y=w&65535}z=c[k>>2]|0;A=z+2|0;c[k>>2]=A;b[z>>1]=y;if(o){if((w|0)==0){B=0}else{B=(w>>>28&8)+65532&65535}C=c[m>>2]|0;b[C>>1]=B;D=C-8|0;b[D>>1]=(b[D>>1]|0)>>>1;D=C-16|0;b[D>>1]=(b[D>>1]|0)>>>1;E=C}else{C=(w|0)>-1?w:-w|0;if((w|0)==0){D=c[m>>2]|0;b[D>>1]=0;F=c[t>>2]|0;G=D}else{D=c[t>>2]|0;H=c[m>>2]|0;b[H>>1]=(w&-2147483648^-1073741824)>>((C|0)<=(D*3|0|0)?26:25)+((C|0)<=((D<<2|0)/3|0|0));F=D;G=H}c[t>>2]=((C-F|0)/16|0)+F;C=G-2|0;b[C>>1]=(b[C>>1]|0)>>>1;C=G-4|0;b[C>>1]=(b[C>>1]|0)>>>1;C=G-16|0;b[C>>1]=(b[C>>1]|0)>>>1;E=G}C=E+2|0;c[m>>2]=C;H=c[d>>2]|0;if((A|0)==(H+(q<<1)|0)){orc(H|0,z+((r|1)<<1)|0,s|0)|0;z=c[d>>2]|0;H=z+(p<<1)|0;c[k>>2]=H;D=z+(h<<1)|0;c[m>>2]=D;I=H;J=D}else{I=A;J=C}if((v|0)==0){break}else{e=x;f=v;g=I;u=J}}return}function Q0(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;mrc(e|0,0,b<<2|0)|0;h=(b|0)>0;if(h){i=0;do{c[f+(i<<2)>>2]=c[a+(i<<2)>>2];i=i+1|0;}while((i|0)<(b|0))}if((b|0)>=(g|0)){return}i=b-1|0;j=(i|0)>0;if(h){k=b}else{h=b;do{l=a+(h<<2)|0;if(j){m=0;while(1){n=m+1|0;c[f+(m<<2)>>2]=c[f+(n<<2)>>2];if((n|0)<(i|0)){m=n}else{break}}}c[f+(i<<2)>>2]=c[l>>2];h=h+1|0;}while((h|0)<(g|0));return}do{h=a+(k<<2)|0;m=c[h>>2]|0;n=(m>>>31)-((m|0)>0)|0;m=0;o=0;do{p=c[f+(m<<2)>>2]|0;q=e+(m<<2)|0;r=c[q>>2]|0;o=(ca(r,p)|0)+o|0;c[q>>2]=r-(ca((p>>>30&2)-1|0,n)|0);m=m+1|0;}while((m|0)<(b|0));m=(c[h>>2]|0)-(o>>d)|0;c[h>>2]=m;if(j){n=0;while(1){l=n+1|0;c[f+(n<<2)>>2]=c[f+(l<<2)>>2];if((l|0)<(i|0)){n=l}else{break}}s=c[h>>2]|0}else{s=m}c[f+(i<<2)>>2]=s;k=k+1|0;}while((k|0)<(g|0));return}function R0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((b|0)>0){d=0;e=0;f=0;g=0;h=0;i=0;j=0;k=0;l=0;m=0;n=0;o=0;p=0;q=0;r=0;s=0;t=0}else{return}while(1){u=a+(d<<2)|0;v=c[u>>2]|0;w=(v>>>31)-((v|0)>0)|0;x=f-(ca((e>>>30&2)-1|0,w)|0)|0;y=h-(ca((g>>>30&2)-1|0,w)|0)|0;z=j-(ca((i>>>30&2)-1|0,w)|0)|0;A=l-(ca((k>>>30&2)-1|0,w)|0)|0;B=n-(ca((m>>>30&2)-1|0,w)|0)|0;C=p-(ca((o>>>30&2)-1|0,w)|0)|0;D=r-(ca((q>>>30&2)-1|0,w)|0)|0;E=t-(ca((s>>>30&2)-1|0,w)|0)|0;c[u>>2]=v-((ca(t,s)|0)+((ca(r,q)|0)+((ca(p,o)|0)+((ca(n,m)|0)+((ca(l,k)|0)+((ca(j,i)|0)+((ca(h,g)|0)+(ca(f,e)|0)))))))>>9);u=d+1|0;if((u|0)<(b|0)){d=u;e=g;f=x;g=i;h=y;i=k;j=z;k=m;l=A;m=o;n=B;o=q;p=C;q=s;r=D;s=v;t=E}else{break}}return}function S0(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;f=b+4|0;g=(c[f>>2]|0)>>>5;h=(g|0)==0?1:g;g=a+3676|0;i=c[g>>2]|0;if(i>>>0<8388609>>>0){j=a+3684|0;k=a+3856|0;l=a+3672|0;m=a+3860|0;n=c[a+3848>>2]|0;o=c[j>>2]|0;p=c[k>>2]|0;q=i;while(1){r=o<<8;c[j>>2]=r;if(p>>>0<n>>>0){s=d[p]|0|r;c[j>>2]=s;t=p+1|0;c[k>>2]=t;u=t;v=s}else{c[m>>2]=1;u=p;v=r}r=c[l>>2]<<8|v>>>1&255;c[l>>2]=r;s=q<<8;c[g>>2]=s;if(s>>>0<8388609>>>0){o=v;p=u;q=s}else{w=s;x=r;break}}}else{w=i;x=c[a+3672>>2]|0}i=w>>>16;w=a+3680|0;c[w>>2]=i;q=(x>>>0)/(i>>>0)|0;do{if((q|0)>65492){u=q-65472|0;p=x-(ca(i,q)|0)|0;c[a+3672>>2]=p;c[g>>2]=i;if((q|0)<=65535){y=u;z=i;A=p;break}c[a+3860>>2]=1;y=u;z=i;A=p}else{p=0;while(1){u=p+1|0;if((e[1635656+(u<<1)>>1]|0|0)>(q|0)){break}else{p=u}}u=e[1635560+(p<<1)>>1]|0;v=x-(ca(e[1635656+(p<<1)>>1]|0,i)|0)|0;c[a+3672>>2]=v;o=ca(u,i)|0;c[g>>2]=o;y=p;z=o;A=v}}while(0);if((y|0)==63){i=a+3684|0;if(z>>>0<8388609>>>0){x=a+3856|0;q=a+3672|0;v=a+3860|0;o=c[a+3848>>2]|0;u=c[i>>2]|0;l=c[x>>2]|0;m=z;k=A;while(1){j=u<<8;c[i>>2]=j;if(l>>>0<o>>>0){n=d[l]|0|j;c[i>>2]=n;r=l+1|0;c[x>>2]=r;B=r;C=n}else{c[v>>2]=1;B=l;C=j}j=k<<8|C>>>1&255;c[q>>2]=j;n=m<<8;c[g>>2]=n;if(n>>>0<8388609>>>0){u=C;l=B;m=n;k=j}else{D=n;E=j;F=C;G=B;H=o;I=v;break}}}else{D=z;E=A;F=c[i>>2]|0;G=c[a+3856>>2]|0;H=c[a+3848>>2]|0;I=a+3860|0}i=D>>>16;c[w>>2]=i;D=(E>>>0)/(i>>>0)|0;v=a+3672|0;o=E-(ca(i,D)|0)|0;c[v>>2]=o;c[g>>2]=i;E=a+3684|0;B=a+3856|0;C=F;F=G;G=i;i=o;while(1){o=C<<8;c[E>>2]=o;if(F>>>0<H>>>0){k=d[F]|0|o;c[E>>2]=k;m=F+1|0;c[B>>2]=m;J=m;K=k}else{c[I>>2]=1;J=F;K=o}L=i<<8|K>>>1&255;c[v>>2]=L;o=G<<8;c[g>>2]=o;if(o>>>0<8388609>>>0){C=K;F=J;G=o;i=L}else{break}}i=G>>>8&65535;c[w>>2]=i;G=(L>>>0)/(i>>>0)|0;J=L-(ca(G,i)|0)|0;c[v>>2]=J;c[g>>2]=i;M=G|D<<16;N=i;O=J}else{M=y;N=z;O=A}if(h>>>0<65536>>>0){if(N>>>0<8388609>>>0){A=a+3684|0;z=a+3856|0;y=a+3672|0;J=a+3860|0;i=c[a+3848>>2]|0;D=c[A>>2]|0;G=c[z>>2]|0;v=N;L=O;while(1){F=D<<8;c[A>>2]=F;if(G>>>0<i>>>0){K=d[G]|0|F;c[A>>2]=K;C=G+1|0;c[z>>2]=C;P=C;Q=K}else{c[J>>2]=1;P=G;Q=F}F=L<<8|Q>>>1&255;c[y>>2]=F;K=v<<8;c[g>>2]=K;if(K>>>0<8388609>>>0){D=Q;G=P;v=K;L=F}else{R=K;S=F;break}}}else{R=N;S=O}L=(R>>>0)/(h>>>0)|0;c[w>>2]=L;R=(S>>>0)/(L>>>0)|0;c[a+3672>>2]=S-(ca(R,L)|0);c[g>>2]=L;T=R}else{R=h;L=0;do{R=R>>1;L=L+1|0;}while(R>>>0>65535>>>0);S=R+1|0;if(N>>>0<8388609>>>0){R=a+3684|0;v=a+3856|0;P=a+3672|0;G=a+3860|0;Q=c[a+3848>>2]|0;D=c[R>>2]|0;y=c[v>>2]|0;J=N;z=O;while(1){A=D<<8;c[R>>2]=A;if(y>>>0<Q>>>0){i=d[y]|0|A;c[R>>2]=i;F=y+1|0;c[v>>2]=F;U=F;V=i}else{c[G>>2]=1;U=y;V=A}A=z<<8|V>>>1&255;c[P>>2]=A;i=J<<8;c[g>>2]=i;if(i>>>0<8388609>>>0){D=V;y=U;J=i;z=A}else{W=i;X=A;break}}}else{W=N;X=O}O=(W>>>0)/(S>>>0)|0;c[w>>2]=O;S=(X>>>0)/(O>>>0)|0;W=a+3672|0;N=X-(ca(S,O)|0)|0;c[W>>2]=N;c[g>>2]=O;if(O>>>0<8388609>>>0){X=a+3684|0;z=a+3856|0;J=a+3860|0;U=c[a+3848>>2]|0;a=c[X>>2]|0;y=c[z>>2]|0;V=O;D=N;while(1){P=a<<8;c[X>>2]=P;if(y>>>0<U>>>0){G=d[y]|0|P;c[X>>2]=G;v=y+1|0;c[z>>2]=v;Y=v;Z=G}else{c[J>>2]=1;Y=y;Z=P}P=D<<8|Z>>>1&255;c[W>>2]=P;G=V<<8;c[g>>2]=G;if(G>>>0<8388609>>>0){a=Z;y=Y;V=G;D=P}else{_=G;$=P;break}}}else{_=O;$=N}N=_>>>(L>>>0);c[w>>2]=N;w=($>>>0)/(N>>>0)|0;c[W>>2]=$-(ca(N,w)|0);c[g>>2]=N;T=w+(S<<L)|0}L=T+(ca(M,h)|0)|0;h=b|0;b=c[h>>2]|0;if((b|0)==0){aa=0}else{aa=1<<b+4}M=c[f>>2]|0;T=((L+1|0)>>>1)-((M+16|0)>>>5)+M|0;c[f>>2]=T;if(T>>>0<aa>>>0){c[h>>2]=b-1;ba=L&1;da=(ba|0)==0;ea=L>>>1;fa=ea+1|0;ga=-ea|0;ha=da?ga:fa;return ha|0}if(T>>>0<1<<b+5>>>0){ba=L&1;da=(ba|0)==0;ea=L>>>1;fa=ea+1|0;ga=-ea|0;ha=da?ga:fa;return ha|0}c[h>>2]=b+1;ba=L&1;da=(ba|0)==0;ea=L>>>1;fa=ea+1|0;ga=-ea|0;ha=da?ga:fa;return ha|0}function T0(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;f=i;g=a+3676|0;h=c[g>>2]|0;if(h>>>0<8388609>>>0){j=a+3684|0;k=a+3856|0;l=a+3672|0;m=a+3860|0;n=c[a+3848>>2]|0;o=c[j>>2]|0;p=c[k>>2]|0;q=h;while(1){r=o<<8;c[j>>2]=r;if(p>>>0<n>>>0){s=d[p]|0|r;c[j>>2]=s;t=p+1|0;c[k>>2]=t;u=t;v=s}else{c[m>>2]=1;u=p;v=r}r=c[l>>2]<<8|v>>>1&255;c[l>>2]=r;s=q<<8;c[g>>2]=s;if(s>>>0<8388609>>>0){o=v;p=u;q=s}else{w=s;x=r;break}}}else{w=h;x=c[a+3672>>2]|0}h=w>>>16;w=a+3680|0;c[w>>2]=h;q=(x>>>0)/(h>>>0)|0;do{if((q|0)>65492){u=q-65472|0;p=x-(ca(h,q)|0)|0;c[a+3672>>2]=p;c[g>>2]=h;if((q|0)<=65535){y=u;z=h;A=p;break}c[a+3860>>2]=1;y=u;z=h;A=p}else{p=0;while(1){u=p+1|0;if((e[1635704+(u<<1)>>1]|0|0)>(q|0)){break}else{p=u}}u=e[1635608+(p<<1)>>1]|0;v=x-(ca(e[1635704+(p<<1)>>1]|0,h)|0)|0;c[a+3672>>2]=v;o=ca(u,h)|0;c[g>>2]=o;y=p;z=o;A=v}}while(0);if((y|0)==63){if(z>>>0<8388609>>>0){h=a+3684|0;x=a+3856|0;q=a+3672|0;v=a+3860|0;o=c[a+3848>>2]|0;u=c[h>>2]|0;l=c[x>>2]|0;m=z;k=A;while(1){j=u<<8;c[h>>2]=j;if(l>>>0<o>>>0){n=d[l]|0|j;c[h>>2]=n;r=l+1|0;c[x>>2]=r;B=r;C=n}else{c[v>>2]=1;B=l;C=j}j=k<<8|C>>>1&255;c[q>>2]=j;n=m<<8;c[g>>2]=n;if(n>>>0<8388609>>>0){u=C;l=B;m=n;k=j}else{D=n;E=j;break}}}else{D=z;E=A}k=D>>>5;c[w>>2]=k;D=(E>>>0)/(k>>>0)|0;m=E-(ca(k,D)|0)|0;c[a+3672>>2]=m;c[g>>2]=k;F=D;G=0;H=k;I=m}else{m=c[b>>2]|0;F=(m|0)==0?0:m-1|0;G=y;H=z;I=A}do{if((F|0)<17){J=26}else{if((c[a+1264>>2]|0)<3910){if((F|0)<=23){J=26;break}KIb(c[a+4>>2]|0,16,2479568,(K=i,i=i+8|0,c[K>>2]=F,K)|0);i=K;L=-1094995529;i=f;return L|0}if((F|0)>=33){KIb(c[a+4>>2]|0,16,2479568,(K=i,i=i+8|0,c[K>>2]=F,K)|0);i=K;L=-1094995529;i=f;return L|0}A=a+3684|0;if(H>>>0<8388609>>>0){z=a+3856|0;y=a+3672|0;m=a+3860|0;k=c[a+3848>>2]|0;D=c[A>>2]|0;E=c[z>>2]|0;B=H;l=I;while(1){C=D<<8;c[A>>2]=C;if(E>>>0<k>>>0){u=d[E]|0|C;c[A>>2]=u;q=E+1|0;c[z>>2]=q;M=q;N=u}else{c[m>>2]=1;M=E;N=C}C=l<<8|N>>>1&255;c[y>>2]=C;u=B<<8;c[g>>2]=u;if(u>>>0<8388609>>>0){D=N;E=M;B=u;l=C}else{O=u;P=C;Q=N;R=M;S=k;T=m;break}}}else{O=H;P=I;Q=c[A>>2]|0;R=c[a+3856>>2]|0;S=c[a+3848>>2]|0;T=a+3860|0}m=O>>>16;c[w>>2]=m;k=(P>>>0)/(m>>>0)|0;l=a+3672|0;B=P-(ca(m,k)|0)|0;c[l>>2]=B;c[g>>2]=m;E=a+3684|0;D=a+3856|0;y=Q;z=R;p=m;m=B;while(1){B=y<<8;c[E>>2]=B;if(z>>>0<S>>>0){C=d[z]|0|B;c[E>>2]=C;u=z+1|0;c[D>>2]=u;U=u;V=C}else{c[T>>2]=1;U=z;V=B}W=m<<8|V>>>1&255;c[l>>2]=W;X=p<<8;c[g>>2]=X;if(X>>>0<8388609>>>0){y=V;z=U;p=X;m=W}else{break}}m=X>>>((F-16|0)>>>0);c[w>>2]=m;p=(W>>>0)/(m>>>0)|0;c[l>>2]=W-(ca(p,m)|0);c[g>>2]=m;Y=p<<16|k}}while(0);if((J|0)==26){if(H>>>0<8388609>>>0){J=a+3684|0;W=a+3856|0;X=a+3672|0;U=a+3860|0;V=c[a+3848>>2]|0;T=c[J>>2]|0;S=c[W>>2]|0;R=H;Q=I;while(1){P=T<<8;c[J>>2]=P;if(S>>>0<V>>>0){O=d[S]|0|P;c[J>>2]=O;M=S+1|0;c[W>>2]=M;Z=M;_=O}else{c[U>>2]=1;Z=S;_=P}P=Q<<8|_>>>1&255;c[X>>2]=P;O=R<<8;c[g>>2]=O;if(O>>>0<8388609>>>0){T=_;S=Z;R=O;Q=P}else{$=O;aa=P;break}}}else{$=H;aa=I}I=$>>>(F>>>0);c[w>>2]=I;w=(aa>>>0)/(I>>>0)|0;c[a+3672>>2]=aa-(ca(I,w)|0);c[g>>2]=I;Y=w}w=Y+(G<<F)|0;F=b|0;G=c[F>>2]|0;if((G|0)==0){ba=0}else{ba=1<<G+4}Y=b+4|0;b=c[Y>>2]|0;I=((w+1|0)>>>1)-((b+16|0)>>>5)+b|0;c[Y>>2]=I;do{if(I>>>0<ba>>>0){c[F>>2]=G-1}else{if(I>>>0<1<<G+5>>>0){break}c[F>>2]=G+1}}while(0);G=w>>>1;if((w&1|0)==0){L=-G|0;i=f;return L|0}else{L=G+1|0;i=f;return L|0}return 0}function U0(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=b+8|0;h=c[g>>2]|0;j=(c[b+12>>2]|0)-h|0;k=b|0;l=b+16|0;b=0;m=h;while(1){if((b|0)>=(j|0)){break}h=d[(c[k>>2]|0)+(m>>>3)|0]|0;n=((m|0)<(c[l>>2]|0))+m|0;c[g>>2]=n;if((h&128>>>((m&7)>>>0)|0)==0){b=b+1|0;m=n}else{break}}if((c[a+1264>>2]|0)>3880&b>>>0>15>>>0){m=e|0;j=b;n=c[m>>2]|0;do{j=j-16|0;n=n+4|0;}while(j>>>0>15>>>0);c[m>>2]=n;o=j}else{o=b}b=e|0;j=c[b>>2]|0;do{if((j|0)==0){p=o;q=0}else{if(j>>>0<26>>>0){n=c[g>>2]|0;m=c[l>>2]|0;h=(c[k>>2]|0)+(n>>>3)|0;r=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(n&7)>>>((32-j|0)>>>0);h=n+j|0;c[g>>2]=m>>>0>h>>>0?h:m;p=r+(o<<j)|0;q=c[b>>2]|0;break}KIb(c[a+4>>2]|0,16,2479568,(r=i,i=i+8|0,c[r>>2]=j,r)|0);i=r;s=-1094995529;i=f;return s|0}}while(0);j=e+4|0;e=c[j>>2]|0;a=p-((e+8|0)>>>4)+e|0;c[j>>2]=a;if((q|0)==0){t=0}else{t=1<<q+4}do{if(a>>>0<t>>>0){c[b>>2]=q-1}else{if(!(a>>>0>=1<<q+5>>>0&q>>>0<24>>>0)){break}c[b>>2]=q+1}}while(0);q=p>>>1;if((p&1|0)==0){s=-q|0;i=f;return s|0}else{s=q+1|0;i=f;return s|0}return 0}function V0(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=e+4|0;c[g>>2]=0;h=a+3832|0;i=a+3836|0;j=a+3824|0;k=a+3840|0;a=0;do{l=c[h>>2]|0;m=(c[i>>2]|0)-l|0;n=0;o=l;while(1){if((n|0)>=(m|0)){p=4;break}l=c[j>>2]|0;q=d[l+(o>>>3)|0]|0;r=c[k>>2]|0;s=((o|0)<(r|0))+o|0;c[h>>2]=s;if((q&128>>>((o&7)>>>0)|0)==0){n=n+1|0;o=s}else{t=s;u=r;v=l;break}}if((p|0)==4){p=0;t=o;u=c[k>>2]|0;v=c[j>>2]|0}m=v+(t>>>3)|0;l=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(t&7)>>>22;m=t+10|0;c[h>>2]=u>>>0>m>>>0?m:u;m=l|n<<10;c[b+(a<<2)>>2]=m;w=m+(c[g>>2]|0)|0;c[g>>2]=w;a=a+1|0;}while((a|0)<5);a=(w>>>0)/10|0;u=w>>>0>655359>>>0;w=u?a>>>16:a;a=u?16:0;if((w&65280|0)==0){x=a;y=w}else{x=a|8;y=w>>>8}w=x+1+(d[1359664+y|0]|0)|0;y=e|0;c[y>>2]=w;if(w>>>0>23>>>0){return}else{z=5;A=w;B=v}while(1){if((z|0)>=64){break}w=c[h>>2]|0;e=(c[i>>2]|0)-w|0;x=0;a=w;while(1){if((x|0)>=(e|0)){C=a;break}w=d[B+(a>>>3)|0]|0;u=((a|0)<(c[k>>2]|0))+a|0;c[h>>2]=u;if((w&128>>>((a&7)>>>0)|0)==0){x=x+1|0;a=u}else{C=u;break}}if((A|0)==0){D=x;E=B}else{a=c[k>>2]|0;e=v+(C>>>3)|0;n=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(C&7)>>>((32-A|0)>>>0);e=C+A|0;c[h>>2]=a>>>0>e>>>0?e:a;D=n|x<<A;E=v}c[b+(z<<2)>>2]=D;n=(c[g>>2]|0)+D|0;c[g>>2]=n;a=z+1|0;e=(n>>>0)/(a<<1>>>0)|0;n=e>>>0>65535>>>0;o=n?e>>>16:e;e=n?16:0;if((o&65280|0)==0){F=e;G=o}else{F=e|8;G=o>>>8}o=F+1+(d[1359664+G|0]|0)|0;c[y>>2]=o;if(o>>>0>23>>>0){p=41;break}else{z=a;A=o;B=E}}if((p|0)==41){return}if((A|0)==0){H=0}else{H=1<<A+6}a:do{if((z|0)<(f|0)){p=z;E=1<<A+7;B=H;G=A;b:while(1){F=c[h>>2]|0;D=(c[i>>2]|0)-F|0;v=0;C=F;while(1){if((v|0)>=(D|0)){I=C;break}F=d[(c[j>>2]|0)+(C>>>3)|0]|0;o=((C|0)<(c[k>>2]|0))+C|0;c[h>>2]=o;if((F&128>>>((C&7)>>>0)|0)==0){v=v+1|0;C=o}else{I=o;break}}if((G|0)==0){J=v}else{C=c[k>>2]|0;D=(c[j>>2]|0)+(I>>>3)|0;o=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(I&7)>>>((32-G|0)>>>0);D=I+G|0;c[h>>2]=C>>>0>D>>>0?D:C;J=o|v<<G}c[b+(p<<2)>>2]=J;o=J-(c[b+(p-64<<2)>>2]|0)+(c[g>>2]|0)|0;c[g>>2]=o;if(o>>>0<B>>>0){C=E;D=B;F=c[y>>2]|0;do{F=F-1|0;D=(F|0)==0?0:D>>1;C=C>>1;}while(o>>>0<D>>>0);c[y>>2]=F;K=C;L=D}else{K=E;L=B}if(o>>>0<K>>>0){M=K;N=L}else{v=K;a=L;O=c[y>>2]|0;do{O=O+1|0;if(O>>>0>24>>>0){break b}v=v<<1;a=(a|0)==0?128:a<<1;}while(!(o>>>0<v>>>0));c[y>>2]=O;M=v;N=a}o=p+1|0;if((o|0)>=(f|0)){break a}p=o;E=M;B=N;G=c[y>>2]|0}c[y>>2]=O;return}}while(0);if((f|0)>0){P=0}else{return}do{O=b+(P<<2)|0;y=c[O>>2]|0;N=y>>1;c[O>>2]=(y&1|0)==0?-N|0:N+1|0;P=P+1|0;}while((P|0)<(f|0));return}function W0(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+100|0;e=hJb((c[d>>2]|0)+1|0)|0;c[b+860>>2]=e;if((e|0)==0){f=-12;return f|0}g=c[b+96>>2]|0;h=c[d>>2]|0;nrc(e|0,g|0,h)|0;a[e+h|0]=0;c[b+864>>2]=h;h=hmb(g)|0;c[b+60>>2]=h;f=((h|0)==0)<<31>>31;return f|0}function X0(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=e+28|0;g=c[f>>2]|0;do{if((g|0)>0){h=a+60|0;i=b;j=g;k=c[e+24>>2]|0;while(1){l=kmb(c[h>>2]|0,k,0,0)|0;if((l|0)==0){m=-1094995529;n=8;break}o=fmb(i,k,0,(c[l+8>>2]|0)-(c[l+4>>2]|0)|0,1)|0;if((o|0)<0){m=o;n=8;break}l=j-o|0;if((l|0)>0){j=l;k=k+o|0}else{n=6;break}}if((n|0)==6){p=c[f>>2]|0;break}else if((n|0)==8){return m|0}}else{p=g}}while(0);c[d>>2]=(p|0)>0;m=c[f>>2]|0;return m|0}function Y0(a){a=a|0;var b=0;b=a+60|0;jmb(c[b>>2]|0);c[b>>2]=0;return 0}function Z0(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=c[e+24>>2]|0;h=e+8|0;j=a+104|0;k=XIb(c[h>>2]|0,c[h+4>>2]|0,j,2013344)|0;h=c[e+48>>2]|0;l=XIb(h,(h|0)<0|0?-1:0,j,2013344)|0;j=e+28|0;e=c[j>>2]|0;if((e|0)<1){m=e;i=f;return m|0}e=fmb(b,g,k,l,2)|0;if((e|0)>=0){c[d>>2]=(c[j>>2]|0)>0;m=c[j>>2]|0;i=f;return m|0}if(!((e|0)==-1094995529)){m=e;i=f;return m|0}KIb(a,16,2302600,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;m=-1094995529;i=f;return m|0}function _0(b){b=b|0;var d=0,e=0,f=0,g=0;d=b+864|0;e=hJb((c[d>>2]|0)+1|0)|0;c[b+96>>2]=e;if((e|0)==0){f=-12;return f|0}g=c[d>>2]|0;nrc(e|0,c[b+860>>2]|0,g)|0;c[b+100>>2]=g;a[e+g|0]=0;f=0;return f|0}function $0(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;i=i+2056|0;h=g|0;j=g+2048|0;k=f+12|0;if((c[k>>2]|0)==0){l=0;i=g;return l|0}m=f+16|0;f=b+12|0;n=h|0;o=c[b+60>>2]|0;p=0;q=0;while(1){r=c[(c[m>>2]|0)+(q<<2)>>2]|0;s=c[r+92>>2]|0;if((c[r+84>>2]|0)!=3){t=4;break}if((krc(s,2251120,10)|0)!=0){t=6;break}if((c[(c[f>>2]|0)+12>>2]|0)==1095979808){if((q|0)>0){t=9;break}r=rb(s+10|0,j|0,10)|0;u=c[j>>2]|0;v=_b(u|0,44)|0;if((v|0)==0){w=u}else{u=v+1|0;c[j>>2]=u;w=u}u=_b(w|0,44)|0;if((u|0)==0){x=w}else{v=u+1|0;c[j>>2]=v;x=v}v=_b(x|0,44)|0;if((v|0)==0){y=x}else{u=v+1|0;c[j>>2]=u;y=u}u=(c[o>>2]|0)+1|0;c[o>>2]=u;Rb(n|0,2048,2148040,(z=i,i=i+24|0,c[z>>2]=u,c[z+8>>2]=r,c[z+16>>2]=y,z)|0)|0;i=z;a[h+(mc(n|0,2124048)|0)|0]=0;A=n}else{A=s}r=e-p|0;u=CFb(d+p|0,A,r)|0;if((u|0)>(r-1|0)){t=18;break}r=u+p|0;u=q+1|0;if(u>>>0<(c[k>>2]|0)>>>0){p=r;q=u}else{l=r;t=20;break}}if((t|0)==4){KIb(b,16,2302560,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;l=-1;i=g;return l|0}else if((t|0)==6){KIb(b,16,2208328,(z=i,i=i+8|0,c[z>>2]=s,z)|0);i=z;l=-1094995529;i=g;return l|0}else if((t|0)==9){KIb(b,16,2175832,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;l=-1094995529;i=g;return l|0}else if((t|0)==18){KIb(b,16,2642272,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;l=-1;i=g;return l|0}else if((t|0)==20){i=g;return l|0}return 0}function a1(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;h=c[f+60>>2]|0;j=f+48|0;k=(c[j>>2]|0)==32?64:128;l=f+100|0;if((c[l>>2]|0)<1){KIb(f,24,2251096,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}vmb(f);if(!(a[1071192]|0)){a[1071192]=1;c[2458827]=5908896;c[2458829]=64;$2(9835304,6,17,1429617,2,1,1429616,2,1,0,0,0,4)|0;c[2443075]=5903520;c[2443077]=64;$2(9772296,6,8,1429601,2,1,1429600,2,1,0,0,0,4)|0;c[2553181]=5903264;c[2553183]=64;$2(10212720,6,16,1429657,2,1,1429656,2,1,0,0,0,4)|0;c[1456793]=5903008;c[1456795]=64;$2(5827168,6,7,1429585,2,1,1429584,2,1,0,0,0,4)|0;c[2552043]=5904800;c[2552045]=1024;$2(10208168,10,63,1429689,2,1,1429688,2,1,0,0,0,4)|0}L6(h+1132|0,h+1292|0,1429520);c[f+140>>2]=0;if((c[l>>2]|0)<1){n=h+1424|0;o=8}else{l=a[c[f+96>>2]|0]|0;p=l&255;q=h+1424|0;c[q>>2]=p;if(l<<24>>24==0){n=q;o=8}else{r=p}}do{if((o|0)==8){KIb(f,16,2208304,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;if((c[j>>2]|0)==32){c[n>>2]=6;r=6;break}else{c[n>>2]=10;r=10;break}}}while(0);n=h+1424|0;j=h+2224|0;h=0;m=r;while(1){b[j+(h<<1)>>1]=(ca(e[1346848+((d[1429520+h|0]|0)<<1)>>1]|0,k)|0)/(m|0)|0;r=h+1|0;if((r|0)>=64){break}h=r;m=c[n>>2]|0}i=g;return 0}function b1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=c[b+60>>2]|0;i=h;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=M4a(b,e,0)|0;if((g|0)<0){l=g;return l|0}c[e+88>>2]=1;c[e+84>>2]=1;g=h+2608|0;m=g;A4a(g,h+2612|0,k);g=c[m>>2]|0;if((g|0)==0){l=-12;return l|0}a:do{if((c[b+48>>2]|0)==32){ef[c[h+1100>>2]&4095](g,j,(k|0)/4|0)}else{if((k|0)>0){n=0;o=g}else{break}while(1){a[o+n|0]=a[1316536+(d[j+n|0]|0)|0]|0;p=n+1|0;if((p|0)>=(k|0)){break a}n=p;o=c[m>>2]|0}}}while(0);o=c[m>>2]|0;m=k<<3;k=m>>>0>2147483639>>>0|(o|0)==0;n=k?0:o;o=k?0:m;c[h+1272>>2]=n;c[h+1284>>2]=o;c[h+1288>>2]=o+8;c[h+1276>>2]=n+(o>>3);o=h+1280|0;c[o>>2]=0;n=h+1440|0;m=c[n>>2]|0;k=h+1436|0;b:do{if((m|0)>0){j=h+1456|0;g=j;b=e+32|0;p=e;q=e+4|0;r=e+36|0;s=e+8|0;t=e+40|0;u=h+1124|0;v=j;j=h+1584|0;w=h+1712|0;x=h+1840|0;y=h;z=h+1968|0;A=h+2096|0;B=0;C=c[k>>2]|0;D=m;c:while(1){if((C|0)>0){E=B<<4;F=B<<3;G=0;do{H=d1(i,g)|0;if((H|0)<0){l=H;break c}H=c[b>>2]|0;I=c[p>>2]|0;J=(ca(E,H)|0)+(G<<4)|0;K=c[q>>2]|0;L=c[r>>2]|0;M=G<<3;N=c[s>>2]|0;O=c[t>>2]|0;ef[c[u>>2]&4095](I+J|0,H,v);ef[c[u>>2]&4095](I+(J|8)|0,H,j);P=J+(H<<3)|0;ef[c[u>>2]&4095](I+P|0,H,w);ef[c[u>>2]&4095](I+(P+8)|0,H,x);if((c[(c[y>>2]|0)+88>>2]&8192|0)==0){H=N+((ca(O,F)|0)+M)|0;O=K+((ca(L,F)|0)+M)|0;ef[c[u>>2]&4095](O,c[r>>2]|0,z);ef[c[u>>2]&4095](H,c[t>>2]|0,A)}G=G+1|0;Q=c[k>>2]|0;}while((G|0)<(Q|0));R=Q;S=c[n>>2]|0}else{R=C;S=D}G=B+1|0;if((G|0)<(S|0)){B=G;C=R;D=S}else{T=S;U=R;break b}}return l|0}else{T=m;U=c[k>>2]|0}}while(0);k=h+1428|0;d:do{if((U|0)!=(c[k>>2]|0)&(T|0)>0){m=h+1456|0;R=m;S=e+32|0;Q=e;D=U<<4;C=e+4|0;B=e+36|0;A=U<<3;t=e+8|0;u=e+40|0;z=h+1124|0;r=m;m=h+1584|0;y=h+1712|0;x=h+1840|0;w=h;j=h+1968|0;v=h+2096|0;s=0;while(1){q=d1(i,R)|0;if((q|0)<0){l=q;break}q=c[S>>2]|0;p=c[Q>>2]|0;b=(ca(s<<4,q)|0)+D|0;g=c[C>>2]|0;G=s<<3;F=c[B>>2]|0;E=c[t>>2]|0;H=c[u>>2]|0;ef[c[z>>2]&4095](p+b|0,q,r);ef[c[z>>2]&4095](p+(b|8)|0,q,m);O=b+(q<<3)|0;ef[c[z>>2]&4095](p+O|0,q,y);ef[c[z>>2]&4095](p+(O+8)|0,q,x);if((c[(c[w>>2]|0)+88>>2]&8192|0)==0){q=E+((ca(H,G)|0)+A)|0;H=g+((ca(F,G)|0)+A)|0;ef[c[z>>2]&4095](H,c[B>>2]|0,j);ef[c[z>>2]&4095](q,c[u>>2]|0,v)}q=s+1|0;H=c[n>>2]|0;if((q|0)<(H|0)){s=q}else{V=H;break d}}return l|0}else{V=T}}while(0);e:do{if((V|0)!=(c[h+1432>>2]|0)){if((c[k>>2]|0)<=0){break}T=h+1456|0;n=T;U=e+32|0;s=e;v=V<<4;u=e+4|0;z=V<<3;j=e+36|0;B=e+8|0;A=e+40|0;w=h+1124|0;x=T;T=h+1584|0;y=h+1712|0;m=h+1840|0;r=h;t=h+1968|0;C=h+2096|0;D=0;while(1){Q=d1(i,n)|0;if((Q|0)<0){l=Q;break}Q=c[U>>2]|0;S=c[s>>2]|0;R=(ca(v,Q)|0)+(D<<4)|0;H=c[u>>2]|0;q=c[j>>2]|0;G=D<<3;F=c[B>>2]|0;g=c[A>>2]|0;ef[c[w>>2]&4095](S+R|0,Q,x);ef[c[w>>2]&4095](S+(R|8)|0,Q,T);E=R+(Q<<3)|0;ef[c[w>>2]&4095](S+E|0,Q,y);ef[c[w>>2]&4095](S+(E+8)|0,Q,m);if((c[(c[r>>2]|0)+88>>2]&8192|0)==0){Q=F+((ca(g,z)|0)+G)|0;g=H+((ca(q,z)|0)+G)|0;ef[c[w>>2]&4095](g,c[j>>2]|0,t);ef[c[w>>2]&4095](Q,c[A>>2]|0,C)}D=D+1|0;if((D|0)>=(c[k>>2]|0)){break e}}return l|0}}while(0);c[f>>2]=1;l=(((c[o>>2]|0)+31|0)/32|0)<<2;return l|0}function c1(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+2608|0);c[b+2612>>2]=0;return 0}function d1(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;h=i;qe[c[f+44>>2]&1023](g|0);j=c[f>>2]|0;k=f+1280|0;l=f+1288|0;m=f+1272|0;if((c[j+48>>2]|0)==32){n=c[l>>2]|0;o=c[m>>2]|0;p=c[2458827]|0;q=0;r=c[k>>2]|0;a:while(1){s=o+(r>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>24;s=r+8|0;u=n>>>0>s>>>0?s:n;c[k>>2]=u;b[g+(q<<7)>>1]=t<<3;t=0;s=u;b:while(1){u=o+(s>>>3)|0;v=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(s&7)>>>26;u=b[p+(v<<2)>>1]|0;w=u<<16>>16;x=(b[p+(v<<2)+2>>1]|0)+s|0;v=n>>>0>x>>>0?x:n;c[k>>2]=v;do{if((w|0)==16){y=v;break b}else if((w|0)==0){z=v}else{if(u<<16>>16<0|(t|0)>9){break a}if((w&8|0)==0){A=v}else{x=c[1456793]|0;B=o+(v>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7)>>>26;B=b[x+(C<<2)>>1]|0;D=(b[x+(C<<2)+2>>1]|0)+v|0;C=n>>>0>D>>>0?D:n;c[k>>2]=C;if(B<<16>>16==3){D=o+(C>>>3)|0;x=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>24;D=C+8|0;E=n>>>0>D>>>0?D:n;c[k>>2]=E;F=x;G=E}else{F=(B<<16>>16)-3|0;G=C}C=t<<2;B=(ca(e[f+2224+(C<<1)>>1]|0,F)|0)>>>4&65535;b[g+(q<<7)+(d[f+1296+C|0]<<1)>>1]=B;A=G}if((w&4|0)==0){H=A}else{B=c[1456793]|0;C=o+(A>>>3)|0;E=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>>26;C=b[B+(E<<2)>>1]|0;x=(b[B+(E<<2)+2>>1]|0)+A|0;E=n>>>0>x>>>0?x:n;c[k>>2]=E;if(C<<16>>16==3){x=o+(E>>>3)|0;B=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(E&7)>>24;x=E+8|0;D=n>>>0>x>>>0?x:n;c[k>>2]=D;I=B;J=D}else{I=(C<<16>>16)-3|0;J=E}E=t<<2|1;C=(ca(e[f+2224+(E<<1)>>1]|0,I)|0)>>>4&65535;b[g+(q<<7)+(d[f+1296+E|0]<<1)>>1]=C;H=J}if((w&2|0)==0){K=H}else{C=c[1456793]|0;E=o+(H>>>3)|0;D=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(H&7)>>>26;E=b[C+(D<<2)>>1]|0;B=(b[C+(D<<2)+2>>1]|0)+H|0;D=n>>>0>B>>>0?B:n;c[k>>2]=D;if(E<<16>>16==3){B=o+(D>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(D&7)>>24;B=D+8|0;x=n>>>0>B>>>0?B:n;c[k>>2]=x;L=C;M=x}else{L=(E<<16>>16)-3|0;M=D}D=t<<2|2;E=(ca(e[f+2224+(D<<1)>>1]|0,L)|0)>>>4&65535;b[g+(q<<7)+(d[f+1296+D|0]<<1)>>1]=E;K=M}if((w&1|0)==0){z=K;break}E=c[1456793]|0;D=o+(K>>>3)|0;x=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7)>>>26;D=b[E+(x<<2)>>1]|0;C=(b[E+(x<<2)+2>>1]|0)+K|0;x=n>>>0>C>>>0?C:n;c[k>>2]=x;if(D<<16>>16==3){C=o+(x>>>3)|0;E=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(x&7)>>24;C=x+8|0;B=n>>>0>C>>>0?C:n;c[k>>2]=B;N=E;O=B}else{N=(D<<16>>16)-3|0;O=x}x=t<<2|3;D=(ca(e[f+2224+(x<<1)>>1]|0,N)|0)>>>4&65535;b[g+(q<<7)+(d[f+1296+x|0]<<1)>>1]=D;z=O}}while(0);w=t+1|0;if((w|0)<11){t=w;s=z}else{y=z;break}}s=q+1|0;if((s|0)<6){q=s;r=y}else{P=0;Q=71;break}}if((Q|0)==71){i=h;return P|0}KIb(j,16,2302520,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;P=-1;i=h;return P|0}j=f+2230|0;Q=f+1299|0;y=f+2228|0;r=f+1298|0;q=f+2226|0;z=f+1297|0;O=c[l>>2]|0;l=c[m>>2]|0;m=c[2443075]|0;N=0;n=c[k>>2]|0;while(1){o=l+(n>>>3)|0;K=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(n&7)>>>28;o=n+4|0;M=O>>>0>o>>>0?o:O;c[k>>2]=M;o=d[1316536+(K<<4)|0]|0;K=l+(M>>>3)|0;L=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(M&7)>>>24;K=M+8|0;M=O>>>0>K>>>0?K:O;c[k>>2]=M;b[g+(N<<7)>>1]=d[1316536+L|0]<<3;L=l+(M>>>3)|0;K=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>26;L=b[m+(K<<2)>>1]|0;H=L<<16>>16;J=(b[m+(K<<2)+2>>1]|0)+M|0;M=O>>>0>J>>>0?J:O;c[k>>2]=M;do{if(L<<16>>16==0){R=M}else{if((H&4|0)==0){S=M}else{J=c[2552043]|0;K=l+(M>>>3)|0;I=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(M&7)>>>22;K=b[J+(I<<2)>>1]|0;A=(b[J+(I<<2)+2>>1]|0)+M|0;I=O>>>0>A>>>0?A:O;c[k>>2]=I;if(K<<16>>16==31){A=l+(I>>>3)|0;J=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(I&7)>>>24;A=I+8|0;G=O>>>0>A>>>0?A:O;c[k>>2]=G;T=a[1316536+J|0]|0;U=G}else{T=(K<<16>>16)-31|0;U=I}I=(ca(e[q>>1]|0,T)|0)>>>4&65535;b[g+(N<<7)+(d[z]<<1)>>1]=I;S=U}if((H&2|0)==0){V=S}else{I=c[2552043]|0;K=l+(S>>>3)|0;G=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(S&7)>>>22;K=b[I+(G<<2)>>1]|0;J=(b[I+(G<<2)+2>>1]|0)+S|0;G=O>>>0>J>>>0?J:O;c[k>>2]=G;if(K<<16>>16==31){J=l+(G>>>3)|0;I=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(G&7)>>>24;J=G+8|0;A=O>>>0>J>>>0?J:O;c[k>>2]=A;W=a[1316536+I|0]|0;X=A}else{W=(K<<16>>16)-31|0;X=G}G=(ca(e[y>>1]|0,W)|0)>>>4&65535;b[g+(N<<7)+(d[r]<<1)>>1]=G;V=X}if((H&1|0)==0){R=V;break}G=c[2552043]|0;K=l+(V>>>3)|0;A=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(V&7)>>>22;K=b[G+(A<<2)>>1]|0;I=(b[G+(A<<2)+2>>1]|0)+V|0;A=O>>>0>I>>>0?I:O;c[k>>2]=A;if(K<<16>>16==31){I=l+(A>>>3)|0;G=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(A&7)>>>24;I=A+8|0;J=O>>>0>I>>>0?I:O;c[k>>2]=J;Y=a[1316536+G|0]|0;Z=J}else{Y=(K<<16>>16)-31|0;Z=A}A=(ca(e[j>>1]|0,Y)|0)>>>4&65535;b[g+(N<<7)+(d[Q]<<1)>>1]=A;R=Z}}while(0);H=o+1|0;if(H>>>0>1>>>0){M=c[2553181]|0;L=1;A=R;while(1){K=l+(A>>>3)|0;J=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(A&7)>>>26;K=b[M+(J<<2)>>1]|0;G=K<<16>>16;I=(b[M+(J<<2)+2>>1]|0)+A|0;J=O>>>0>I>>>0?I:O;c[k>>2]=J;do{if(K<<16>>16==0){_=J}else{if((G&8|0)==0){$=J}else{I=c[2552043]|0;F=l+(J>>>3)|0;p=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(J&7)>>>22;F=b[I+(p<<2)>>1]|0;s=(b[I+(p<<2)+2>>1]|0)+J|0;p=O>>>0>s>>>0?s:O;c[k>>2]=p;if(F<<16>>16==31){s=l+(p>>>3)|0;I=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(p&7)>>>24;s=p+8|0;t=O>>>0>s>>>0?s:O;c[k>>2]=t;aa=a[1316536+I|0]|0;ba=t}else{aa=(F<<16>>16)-31|0;ba=p}p=L<<2;F=(ca(e[f+2224+(p<<1)>>1]|0,aa)|0)>>>4&65535;b[g+(N<<7)+(d[f+1296+p|0]<<1)>>1]=F;$=ba}if((G&4|0)==0){da=$}else{F=c[2552043]|0;p=l+($>>>3)|0;t=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<($&7)>>>22;p=b[F+(t<<2)>>1]|0;I=(b[F+(t<<2)+2>>1]|0)+$|0;t=O>>>0>I>>>0?I:O;c[k>>2]=t;if(p<<16>>16==31){I=l+(t>>>3)|0;F=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(t&7)>>>24;I=t+8|0;s=O>>>0>I>>>0?I:O;c[k>>2]=s;ea=a[1316536+F|0]|0;fa=s}else{ea=(p<<16>>16)-31|0;fa=t}t=L<<2|1;p=(ca(e[f+2224+(t<<1)>>1]|0,ea)|0)>>>4&65535;b[g+(N<<7)+(d[f+1296+t|0]<<1)>>1]=p;da=fa}if((G&2|0)==0){ga=da}else{p=c[2552043]|0;t=l+(da>>>3)|0;s=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(da&7)>>>22;t=b[p+(s<<2)>>1]|0;F=(b[p+(s<<2)+2>>1]|0)+da|0;s=O>>>0>F>>>0?F:O;c[k>>2]=s;if(t<<16>>16==31){F=l+(s>>>3)|0;p=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(s&7)>>>24;F=s+8|0;I=O>>>0>F>>>0?F:O;c[k>>2]=I;ha=a[1316536+p|0]|0;ia=I}else{ha=(t<<16>>16)-31|0;ia=s}s=L<<2|2;t=(ca(e[f+2224+(s<<1)>>1]|0,ha)|0)>>>4&65535;b[g+(N<<7)+(d[f+1296+s|0]<<1)>>1]=t;ga=ia}if((G&1|0)==0){_=ga;break}t=c[2552043]|0;s=l+(ga>>>3)|0;I=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(ga&7)>>>22;s=b[t+(I<<2)>>1]|0;p=(b[t+(I<<2)+2>>1]|0)+ga|0;I=O>>>0>p>>>0?p:O;c[k>>2]=I;if(s<<16>>16==31){p=l+(I>>>3)|0;t=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(I&7)>>>24;p=I+8|0;F=O>>>0>p>>>0?p:O;c[k>>2]=F;ja=a[1316536+t|0]|0;ka=F}else{ja=(s<<16>>16)-31|0;ka=I}I=L<<2|3;s=(ca(e[f+2224+(I<<1)>>1]|0,ja)|0)>>>4&65535;b[g+(N<<7)+(d[f+1296+I|0]<<1)>>1]=s;_=ka}}while(0);G=L+1|0;if((G|0)<(H|0)){L=G;A=_}else{la=_;break}}}else{la=R}A=N+1|0;if((A|0)<6){N=A;n=la}else{P=0;break}}i=h;return P|0}function e1(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=c[a+60>>2]|0;d=(c[a+48>>2]|0)==32?32:64;vmb(a);f=a+80|0;g=c[f>>2]|0;if((g|0)==0){c[f>>2]=512;h=512}else{h=g}g=b+1424|0;c[g>>2]=(((h|0)/2|0)+(d<<7)|0)/(h|0)|0;h=pJb(8)|0;c[a+96>>2]=h;c[a+100>>2]=8;c[h>>2]=c[g>>2];c[h+4>>2]=1398100801;h=b+2352|0;b=0;do{a=ca(e[1346848+(b<<1)>>1]|0,d)|0;c[h+(b<<2)>>2]=((a>>>1)+(c[g>>2]<<16)|0)/(a|0)|0;b=b+1|0;}while((b|0)<64);return 0}function f1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=c[b+60>>2]|0;i=h;j=h+1432|0;k=h+1428|0;l=(ca((c[j>>2]|0)*1440|0,c[k>>2]|0)|0)+16384|0;m=d5a(b,e,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){n=m;return n|0}m=h+1248|0;l=m;o=e+24|0;p=e+28|0;q=c[p>>2]|0;r=(q|0)<0;s=r?0:c[o>>2]|0;t=r?0:q;c[h+1268>>2]=t<<3;q=h+1256|0;c[q>>2]=s;c[h+1264>>2]=s+t;t=h+1260|0;c[t>>2]=s;s=h+1252|0;c[s>>2]=32;r=m;c[r>>2]=0;m=h+1440|0;u=c[m>>2]|0;v=h+1436|0;if((u|0)>0){w=h+1456|0;x=0;z=c[v>>2]|0;A=u;while(1){if((z|0)>0){B=0;do{g1(i,f,B,x);h1(i,w);B=B+1|0;C=c[v>>2]|0;}while((B|0)<(C|0));D=C;E=c[m>>2]|0}else{D=z;E=A}B=x+1|0;if((B|0)<(E|0)){x=B;z=D;A=E}else{F=E;G=D;break}}}else{F=u;G=c[v>>2]|0}if((G|0)!=(c[k>>2]|0)&(F|0)>0){v=h+1456|0;u=0;while(1){g1(i,f,G,u);h1(i,v);D=u+1|0;E=c[m>>2]|0;if((D|0)<(E|0)){u=D}else{H=E;break}}}else{H=F}do{if((H|0)!=(c[j>>2]|0)){if((c[k>>2]|0)<=0){break}F=h+1456|0;u=0;do{g1(i,f,u,H);h1(i,F);u=u+1|0;}while((u|0)<(c[k>>2]|0))}}while(0);Y2(l);l=c[s>>2]|0;k=c[q>>2]|0;i=c[t>>2]|0;H=(i-k<<3)+(32-l)|0;if((H&31|0)==0){I=H}else{H=c[r>>2]|0;f=l;l=k;k=i;while(1){if((f|0)>8){J=f-8|0;K=H<<8;L=l;M=k}else{i=k;y=je(H<<f|0)|0;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;i=(c[t>>2]|0)+4|0;c[t>>2]=i;J=f+24|0;K=0;L=c[q>>2]|0;M=i}c[r>>2]=K;c[s>>2]=J;i=(M-L<<3)+(32-J)|0;if((i&31|0)==0){I=i;break}else{H=K;f=J;l=L;k=M}}}M=(I|0)/32|0;do{if((c[b+48>>2]|0)==32){I=c[o>>2]|0;ef[c[h+1100>>2]&4095](I,I,M);N=M<<2}else{I=M<<2;if((I|0)>0){O=0}else{N=I;break}while(1){k=(c[o>>2]|0)+O|0;a[k]=a[1316536+(d[k]|0)|0]|0;k=O+1|0;if((k|0)<(I|0)){O=k}else{N=I;break}}}}while(0);c[p>>2]=N;N=e+36|0;c[N>>2]=c[N>>2]|1;c[g>>2]=1;n=0;return n|0}function g1(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[b+32>>2]|0;g=c[b>>2]|0;h=(ca(e<<4,f)|0)+(d<<4)|0;i=c[b+4>>2]|0;j=e<<3;e=b+36|0;k=c[e>>2]|0;l=d<<3;d=c[b+8>>2]|0;m=b+40|0;b=c[m>>2]|0;n=a+4|0;o=a+1456|0;ef[c[n>>2]&4095](o,g+h|0,f);p=a+1584|0;ef[c[n>>2]&4095](p,g+(h|8)|0,f);q=a+1712|0;r=h+(f<<3)|0;ef[c[n>>2]&4095](q,g+r|0,f);h=a+1840|0;ef[c[n>>2]&4095](h,g+(r+8)|0,f);f=a+1112|0;qe[c[f>>2]&1023](o);qe[c[f>>2]&1023](p);qe[c[f>>2]&1023](q);qe[c[f>>2]&1023](h);if((c[(c[a>>2]|0)+88>>2]&8192|0)!=0){return}h=d+((ca(b,j)|0)+l)|0;b=i+((ca(k,j)|0)+l)|0;l=a+1968|0;ef[c[n>>2]&4095](l,b,c[e>>2]|0);e=a+2096|0;ef[c[n>>2]&4095](e,h,c[m>>2]|0);qe[c[f>>2]&1023](l);qe[c[f>>2]&1023](e);return}function h1(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;g=i;h=e+1248|0;j=c[e+1256>>2]|0;k=e+1252|0;l=c[k>>2]|0;m=e+1260|0;n=c[m>>2]|0;o=c[e>>2]|0;if(((c[e+1264>>2]|0)-j-(32-l+(n-j<<3)>>3)|0)<1440){KIb(o,16,2251024,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;i=g;return}if((c[o+48>>2]|0)==32){o=h|0;j=d[1429617]|0;p=d[1429616]|0;q=32-j|0;r=d[1429649]|0;s=d[1429648]|0;t=32-r|0;u=0;v=c[o>>2]|0;w=l;while(1){x=f+(u<<7)|0;z=(b[x>>1]|0)+32>>6;if((w|0)>8){A=w-8|0;B=z|v<<8}else{C=je(z>>>((8-w|0)>>>0)|v<<w|0)|0;D=c[m>>2]|0;y=C;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;A=w+24|0;B=z}c[o>>2]=B;c[k>>2]=A;b[x>>1]=0;x=0;z=0;while(1){D=d[1429520+(z<<2)|0]|0;C=f+(u<<7)+(D<<1)|0;E=((ca(b[C>>1]|0,c[e+2352+(D<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[C>>1]=E;F=E<<16>>16==0?0:8;E=D+8|0;G=f+(u<<7)+(E<<1)|0;H=((ca(b[G>>1]|0,c[e+2352+(E<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[G>>1]=H;E=H<<16>>16==0?F:F|4;F=D+1|0;H=f+(u<<7)+(F<<1)|0;I=((ca(b[H>>1]|0,c[e+2352+(F<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[H>>1]=I;F=I<<16>>16==0?E:E|2;E=D+9|0;D=f+(u<<7)+(E<<1)|0;I=((ca(b[D>>1]|0,c[e+2352+(E<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[D>>1]=I;E=I<<16>>16!=0|F;do{if((E|0)==0){J=x+1|0}else{I=c[o>>2]|0;K=c[k>>2]|0;if((x|0)==0){L=I;M=K}else{N=x;O=I;I=K;while(1){if((I|0)>(j|0)){P=I-j|0;Q=O<<j|p}else{K=je(p>>>((j-I|0)>>>0)|O<<I|0)|0;R=c[m>>2]|0;y=K;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;P=q+I|0;Q=p}c[o>>2]=Q;c[k>>2]=P;R=N-1|0;if((R|0)==0){L=Q;M=P;break}else{N=R;O=Q;I=P}}}I=d[1429617+(E<<1)|0]|0;O=d[1429616+(E<<1)|0]|0;if((M|0)>(I|0)){S=M;T=L<<I|O}else{N=je(O>>>((I-M|0)>>>0)|L<<M|0)|0;R=c[m>>2]|0;y=N;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;S=M+32|0;T=O}c[o>>2]=T;c[k>>2]=S-I;if((F&8|0)!=0){i1(h,b[C>>1]|0)}if((F&4|0)!=0){i1(h,b[G>>1]|0)}if((F&2|0)!=0){i1(h,b[H>>1]|0)}if((E&1|0)==0){J=0;break}i1(h,b[D>>1]|0);J=0}}while(0);D=z+1|0;if((D|0)<10){x=J;z=D}else{break}}z=c[o>>2]|0;x=c[k>>2]|0;if((x|0)>(r|0)){U=x-r|0;V=z<<r|s}else{D=je(s>>>((r-x|0)>>>0)|z<<x|0)|0;z=c[m>>2]|0;y=D;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;U=t+x|0;V=s}c[o>>2]=V;c[k>>2]=U;x=u+1|0;if((x|0)<6){u=x;v=V;w=U}else{break}}i=g;return}U=e+1248|0;w=d[1429751]|0;V=d[1429750]|0;v=32-w|0;u=0;o=l;l=n;while(1){n=f+(u<<7)|0;s=63;while(1){if((s|0)<=3){break}t=d[1429520+s|0]|0;if(((ca(b[f+(u<<7)+(t<<1)>>1]|0,c[e+2352+(t<<2)>>2]|0)|0)+32768|0)>>>0>65535>>>0){break}else{s=s-1|0}}t=s>>2;r=d[1316536+(t<<4)|0]|0;J=c[U>>2]|0;if((o|0)>4){W=o-4|0;X=J<<4|r;Y=l}else{h=l;y=je(r>>>((4-o|0)>>>0)|J<<o|0)|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=(c[m>>2]|0)+4|0;c[m>>2]=h;W=o+28|0;X=r;Y=h}c[U>>2]=X;c[k>>2]=W;h=d[1316536+((b[n>>1]|0)+32>>6)|0]|0;if((W|0)>8){Z=W-8|0;_=h|X<<8;$=Y}else{r=Y;y=je(h>>>((8-W|0)>>>0)|X<<W|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[m>>2]|0)+4|0;c[m>>2]=r;Z=W+24|0;_=h;$=r}c[U>>2]=_;c[k>>2]=Z;b[n>>1]=0;if((t|0)<0){aa=Z;ba=$}else{r=0;h=_;J=Z;S=$;while(1){T=d[1429520+(r<<2)|0]|0;M=f+(u<<7)+(T<<1)|0;L=((ca(b[M>>1]|0,c[e+2352+(T<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[M>>1]=L;P=L<<16>>16==0?0:8;L=T+8|0;Q=f+(u<<7)+(L<<1)|0;p=((ca(b[Q>>1]|0,c[e+2352+(L<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[Q>>1]=p;L=p<<16>>16==0?P:P|4;P=T+1|0;p=f+(u<<7)+(P<<1)|0;q=((ca(b[p>>1]|0,c[e+2352+(P<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[p>>1]=q;P=q<<16>>16==0?L:L|2;L=T+9|0;T=f+(u<<7)+(L<<1)|0;q=((ca(b[T>>1]|0,c[e+2352+(L<<2)>>2]|0)|0)+32768|0)>>>16&65535;b[T>>1]=q;L=q<<16>>16!=0|P;do{if((r|0)==0){q=d[1429601+(L<<1)|0]|0;j=d[1429600+(L<<1)|0]|0;if((J|0)>(q|0)){da=J-q|0;ea=h<<q|j;fa=S;break}else{A=S;y=je(j>>>((q-J|0)>>>0)|h<<J|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;A=(c[m>>2]|0)+4|0;c[m>>2]=A;da=J+32-q|0;ea=j;fa=A;break}}else{A=d[1429657+(L<<1)|0]|0;j=d[1429656+(L<<1)|0]|0;if((J|0)>(A|0)){da=J-A|0;ea=h<<A|j;fa=S;break}else{q=S;y=je(j>>>((A-J|0)>>>0)|h<<J|0)|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=(c[m>>2]|0)+4|0;c[m>>2]=q;da=J+32-A|0;ea=j;fa=q;break}}}while(0);c[U>>2]=ea;c[k>>2]=da;do{if((L|0)==0){ga=ea;ha=da;ia=fa}else{do{if((P&8|0)==0){ja=ea;ka=da;la=fa}else{q=b[M>>1]|0;j=q+31|0;if(j>>>0<63>>>0){A=d[1429689+(j<<1)|0]|0;B=d[1429688+(j<<1)|0]|0;if((da|0)>(A|0)){ma=da;na=ea<<A|B;oa=fa}else{j=fa;y=je(B>>>((A-da|0)>>>0)|ea<<da|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[m>>2]|0)+4|0;c[m>>2]=j;ma=da+32|0;na=B;oa=j}j=ma-A|0;c[U>>2]=na;c[k>>2]=j;ja=na;ka=j;la=oa;break}if((da|0)>(w|0)){pa=da-w|0;qa=ea<<w|V;ra=fa}else{j=fa;y=je(V>>>((w-da|0)>>>0)|ea<<da|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[m>>2]|0)+4|0;c[m>>2]=j;pa=da+v|0;qa=V;ra=j}c[U>>2]=qa;c[k>>2]=pa;j=d[1316536+(q&255)|0]|0;if((pa|0)>8){sa=pa-8|0;ta=j|qa<<8;ua=ra}else{q=ra;y=je(j>>>((8-pa|0)>>>0)|qa<<pa|0)|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=(c[m>>2]|0)+4|0;c[m>>2]=q;sa=pa+24|0;ta=j;ua=q}c[U>>2]=ta;c[k>>2]=sa;ja=ta;ka=sa;la=ua}}while(0);do{if((P&4|0)==0){va=ja;wa=ka;xa=la}else{q=b[Q>>1]|0;j=q+31|0;if(j>>>0<63>>>0){A=d[1429689+(j<<1)|0]|0;B=d[1429688+(j<<1)|0]|0;if((ka|0)>(A|0)){ya=ka;za=ja<<A|B;Aa=la}else{j=la;y=je(B>>>((A-ka|0)>>>0)|ja<<ka|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[m>>2]|0)+4|0;c[m>>2]=j;ya=ka+32|0;za=B;Aa=j}j=ya-A|0;c[U>>2]=za;c[k>>2]=j;va=za;wa=j;xa=Aa;break}if((ka|0)>(w|0)){Ba=ka-w|0;Ca=ja<<w|V;Da=la}else{j=la;y=je(V>>>((w-ka|0)>>>0)|ja<<ka|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Ba=ka+v|0;Ca=V;Da=j}c[U>>2]=Ca;c[k>>2]=Ba;j=d[1316536+(q&255)|0]|0;if((Ba|0)>8){Ea=Ba-8|0;Fa=j|Ca<<8;Ga=Da}else{q=Da;y=je(j>>>((8-Ba|0)>>>0)|Ca<<Ba|0)|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=(c[m>>2]|0)+4|0;c[m>>2]=q;Ea=Ba+24|0;Fa=j;Ga=q}c[U>>2]=Fa;c[k>>2]=Ea;va=Fa;wa=Ea;xa=Ga}}while(0);do{if((P&2|0)==0){Ha=va;Ia=wa;Ja=xa}else{q=b[p>>1]|0;j=q+31|0;if(j>>>0<63>>>0){A=d[1429689+(j<<1)|0]|0;B=d[1429688+(j<<1)|0]|0;if((wa|0)>(A|0)){Ka=wa;La=va<<A|B;Ma=xa}else{j=xa;y=je(B>>>((A-wa|0)>>>0)|va<<wa|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Ka=wa+32|0;La=B;Ma=j}j=Ka-A|0;c[U>>2]=La;c[k>>2]=j;Ha=La;Ia=j;Ja=Ma;break}if((wa|0)>(w|0)){Na=wa-w|0;Oa=va<<w|V;Pa=xa}else{j=xa;y=je(V>>>((w-wa|0)>>>0)|va<<wa|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Na=wa+v|0;Oa=V;Pa=j}c[U>>2]=Oa;c[k>>2]=Na;j=d[1316536+(q&255)|0]|0;if((Na|0)>8){Qa=Na-8|0;Ra=j|Oa<<8;Sa=Pa}else{q=Pa;y=je(j>>>((8-Na|0)>>>0)|Oa<<Na|0)|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=(c[m>>2]|0)+4|0;c[m>>2]=q;Qa=Na+24|0;Ra=j;Sa=q}c[U>>2]=Ra;c[k>>2]=Qa;Ha=Ra;Ia=Qa;Ja=Sa}}while(0);if((L&1|0)==0){ga=Ha;ha=Ia;ia=Ja;break}q=b[T>>1]|0;j=q+31|0;if(j>>>0<63>>>0){A=d[1429689+(j<<1)|0]|0;B=d[1429688+(j<<1)|0]|0;if((Ia|0)>(A|0)){Ta=Ia;Ua=Ha<<A|B;Va=Ja}else{j=Ja;y=je(B>>>((A-Ia|0)>>>0)|Ha<<Ia|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Ta=Ia+32|0;Ua=B;Va=j}j=Ta-A|0;c[U>>2]=Ua;c[k>>2]=j;ga=Ua;ha=j;ia=Va;break}if((Ia|0)>(w|0)){Wa=Ia-w|0;Xa=Ha<<w|V;Ya=Ja}else{j=Ja;y=je(V>>>((w-Ia|0)>>>0)|Ha<<Ia|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=(c[m>>2]|0)+4|0;c[m>>2]=j;Wa=Ia+v|0;Xa=V;Ya=j}c[U>>2]=Xa;c[k>>2]=Wa;j=d[1316536+(q&255)|0]|0;if((Wa|0)>8){Za=Wa-8|0;_a=j|Xa<<8;$a=Ya}else{q=Ya;y=je(j>>>((8-Wa|0)>>>0)|Xa<<Wa|0)|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=(c[m>>2]|0)+4|0;c[m>>2]=q;Za=Wa+24|0;_a=j;$a=q}c[U>>2]=_a;c[k>>2]=Za;ga=_a;ha=Za;ia=$a}}while(0);T=r+1|0;if((T|0)>(t|0)){aa=ha;ba=ia;break}else{r=T;h=ga;J=ha;S=ia}}}S=u+1|0;if((S|0)<6){u=S;o=aa;l=ba}else{break}}i=g;return}function i1(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=e+3|0;if(f>>>0<7>>>0){g=d[1429585+(f<<1)|0]|0;h=d[1429584+(f<<1)|0]|0;f=b|0;i=c[f>>2]|0;j=b+4|0;k=c[j>>2]|0;if((k|0)>(g|0)){l=k-g|0;m=i<<g|h}else{n=je(h>>>((g-k|0)>>>0)|i<<k|0)|0;i=b+12|0;o=c[i>>2]|0;y=n;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=32-g+k|0;m=h}c[f>>2]=m;c[j>>2]=l;return}l=d[1429591]|0;j=d[1429590]|0;m=b|0;f=c[m>>2]|0;h=b+4|0;k=c[h>>2]|0;if((k|0)>(l|0)){p=k-l|0;q=f<<l|j}else{g=je(j>>>((l-k|0)>>>0)|f<<k|0)|0;f=b+12|0;i=c[f>>2]|0;y=g;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;p=32-l+k|0;q=j}c[m>>2]=q;c[h>>2]=p;j=e&255;if((p|0)>8){r=p-8|0;s=q<<8|j}else{e=je(j>>>((8-p|0)>>>0)|q<<p|0)|0;q=b+12|0;b=c[q>>2]|0;y=e;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;r=p+24|0;s=j}c[m>>2]=s;c[h>>2]=r;return}function j1(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+60|0;e=c[d>>2]|0;c[a+420>>2]=8;f=c[a+416>>2]|0;if((f-1|0)>>>0>1>>>0){KIb(a,16,2368176,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-22;i=b;return h|0}if((c[a+432>>2]|0)<1){KIb(a,16,2302488,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1163346256;i=b;return h|0}f=OPa(e+17420|0,6,1,-30517578125.0e-15)|0;do{if((f|0)==0){j=OPa(e+17484|0,8,1,-30517578125.0e-15)|0;if((j|0)!=0){k=j;break}j=OPa(e+17548|0,9,1,-30517578125.0e-15)|0;if((j|0)!=0){k=j;break}H0a(5);wmb();qHb(e+17612|0,c[a+88>>2]&8388608);c[e+17408>>2]=e+13312;c[e+17412>>2]=e+14336;c[e+17416>>2]=e+15360;c[e+16>>2]=e+32;c[e+20>>2]=e+2080;c[e+5648>>2]=e+5664;c[e+5652>>2]=e+7712;h=0;i=b;return h|0}else{k=f}}while(0);KIb(a,16,2250992,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;g=c[d>>2]|0;PPa(g+17420|0);PPa(g+17484|0);PPa(g+17548|0);h=k;i=b;return h|0}function k1(b,f,h,j){b=b|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0,Z=0.0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;k=i;i=i+3368|0;l=k|0;m=k+56|0;n=c[j+24>>2]|0;o=c[b+60>>2]|0;p=o;q=b+416|0;if((c[j+28>>2]|0)<((c[q>>2]|0)*212|0|0)){KIb(b,16,2458256,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;r=-1094995529;i=k;return r|0}c[f+76>>2]=512;j=M4a(b,f,0)|0;if((j|0)<0){r=j;i=k;return r|0}a:do{if((c[q>>2]|0)>0){j=o;s=o+11264|0;t=o+17628|0;u=f+64|0;v=o+17408|0;w=o+17412|0;x=k+112|0;y=k+1136|0;z=o+17416|0;A=0;b:while(1){B=A*212|0;C=n+B|0;D=(C|0)==0?8:1704;E=C;C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>6;if((C&1|0)!=0){r=-1094995529;F=46;break}c[j+(A*5632|0)>>2]=2-(C&3);C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>4;if((C&1|0)!=0){r=-1094995529;F=46;break}c[j+(A*5632|0)+4>>2]=2-(C&3);C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>2&3;if(!((C|0)==3|(C|0)==0)){r=-1094995529;F=46;break}c[j+(A*5632|0)+8>>2]=C^3;C=n+(B|1)|0;E=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>5&7;C=D>>>0>11>>>0?11:D;G=d[1953824+E|0]|0;c[j+(A*5632|0)+12>>2]=G;H=G*10|0;I=n+((C>>>3)+B)|0;J=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(C&3)>>>30;I=C+2|0;C=D>>>0>I>>>0?I:D;I=d[1953816+J|0]|0;J=n+((C>>>3)+B)|0;K=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(C&7)>>>29;J=C+3|0;C=(d[1953808+K|0]|0)<<1;K=0;L=D>>>0>J>>>0?J:D;do{J=n+((L>>>3)+B)|0;M=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7)>>>28;J=L+4|0;L=D>>>0>J>>>0?J:D;a[l+K|0]=M;K=K+1|0;}while((K|0)<(G|0));K=H+32+I+C|0;M=0;J=L;do{N=n+((J>>>3)+B)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(J&7)>>>26;N=J+6|0;J=D>>>0>N>>>0?N:D;a[m+M|0]=O;M=M+1|0;}while((M|0)<(G|0));if((E|0)==7){P=0;Q=K;R=0;S=J}else{M=52-G|0;mrc(m+G|0,0,M|0)|0;mrc(l+G|0,0,M|0)|0;P=0;Q=K;R=0;S=J}while(1){M=P+1|0;L=a[1953800+M|0]|0;if((R&255)>>>0<(L&255)>>>0){C=j+(A*5632|0)+(P<<2)|0;I=L&255;H=R&255;O=Q;N=S;while(1){T=d[559424+H|0]|0;U=a[l+H|0]|0;V=(U<<24>>24!=0)+(U&255)|0;W=+g[8779640+((d[m+H|0]|0)<<2)>>2];U=(ca(V,T)|0)+O|0;if((U|0)>1696){r=-1094995529;F=46;break b}X=e[((c[C>>2]|0)==0?1953696:1953592)+(H<<1)>>1]|0;if((V|0)==0){mrc(s+(X<<2)|0,0,T<<2|0)|0;Y=N}else{Z=1.0/+((1<<V-1)-1|0);_=32-V|0;$=0;aa=N;while(1){ba=n+((aa>>>3)+B)|0;da=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(aa&7)>>_;ba=aa+V|0;ea=D>>>0>ba>>>0?ba:D;g[s+($+X<<2)>>2]=Z*W*+(da|0);da=$+1|0;if((da|0)<(T|0)){$=da;aa=ea}else{Y=ea;break}}}aa=H+1|0;if((aa|0)<(I|0)){H=aa;O=U;N=Y}else{fa=U;ga=Y;break}}}else{fa=Q;ga=S}if((M|0)<3){P=M;Q=fa;R=L;S=ga}else{break}}D=j+(A*5632|0)+20|0;B=j+(A*5632|0)+16|0;J=0;K=0;G=0;while(1){E=e[612024+(J<<1)>>1]|0;N=c[j+(A*5632|0)+(J<<2)>>2]|0;O=1<<N;H=(O|0)==1;do{if(H){I=E>>>(N>>>0);C=(d[831592+J|0]|0)-N|0;if((C|0)==8){ha=C}else if((C|0)==5){ha=5}else if((C|0)==7){ha=C}else{r=-1094995529;F=46;break b}C=E+K|0;ia=ha;ja=I;ka=C;la=(c[D>>2]|0)+(C-16<<2)|0;F=32}else{C=E+K|0;if((O|0)<=0){ma=C;na=G;break}ia=5;ja=32;ka=C;la=(c[D>>2]|0)+(C-16<<2)|0;F=32}}while(0);do{if((F|0)==32){F=0;E=ia-5-(ia>>>0>6>>>0)|0;L=p+17420+(E<<6)|0;M=1<<ia;C=p+17420+(E<<6)+44|0;E=p+17408+(J<<2)|0;I=(M|0)/2|0;aa=(M|0)>1;$=M-1|0;M=c[B>>2]|0;c:do{if((J|0)==0){if(aa){T=0;X=G;V=la;_=0;ea=M;while(1){da=T+K|0;ef[c[C>>2]&4095](L,ea+(da<<2)|0,p+11264+(X<<2)|0);pe[c[t>>2]&1023]((c[E>>2]|0)+(T<<2)|0,V,(c[B>>2]|0)+(da<<2)|0,6272792,16);ba=c[B>>2]|0;oa=_+1|0;if((oa|0)<(O|0)){T=T+ja|0;X=X+ja|0;V=ba+(da+16<<2)|0;_=oa;ea=ba}else{pa=ba;break}}}else{ea=0;_=G;V=la;X=0;T=M;while(1){ba=ea+K|0;ef[c[C>>2]&4095](L,T+(ba<<2)|0,p+11264+(_<<2)|0);pe[c[t>>2]&1023]((c[E>>2]|0)+(ea<<2)|0,V,(c[B>>2]|0)+(ba<<2)|0,6272792,16);oa=c[B>>2]|0;da=X+1|0;if((da|0)<(O|0)){ea=ea+ja|0;_=_+ja|0;V=oa+(ba+16<<2)|0;X=da;T=oa}else{pa=oa;break}}}}else{if(aa){qa=0;ra=G;sa=la;ta=0;ua=M}else{T=0;X=G;V=la;_=0;ea=M;while(1){oa=T+K|0;ef[c[C>>2]&4095](L,ea+(oa<<2)|0,p+11264+(X<<2)|0);pe[c[t>>2]&1023]((c[E>>2]|0)+(T<<2)|0,V,(c[B>>2]|0)+(oa<<2)|0,6272792,16);da=c[B>>2]|0;ba=_+1|0;if((ba|0)<(O|0)){T=T+ja|0;X=X+ja|0;V=da+(oa+16<<2)|0;_=ba;ea=da}else{pa=da;break c}}}while(1){ea=qa+K|0;_=$+ra|0;V=0;do{X=p+11264+(_-V<<2)|0;W=+g[X>>2];T=p+11264+(V+ra<<2)|0;g[X>>2]=+g[T>>2];g[T>>2]=W;V=V+1|0;}while((V|0)<(I|0));ef[c[C>>2]&4095](L,ua+(ea<<2)|0,p+11264+(ra<<2)|0);pe[c[t>>2]&1023]((c[E>>2]|0)+(qa<<2)|0,sa,(c[B>>2]|0)+(ea<<2)|0,6272792,16);V=c[B>>2]|0;_=ta+1|0;if((_|0)<(O|0)){qa=qa+ja|0;ra=ra+ja|0;sa=V+(ea+16<<2)|0;ta=_;ua=V}else{pa=V;break}}}}while(0);L=(ja<<N)+G|0;if(!H){ma=ka;na=L;break}nrc((c[E>>2]|0)+128|0,pa+(K+16<<2)|0,960)|0;ma=ka;na=L}}while(0);H=J+1|0;if((H|0)<3){J=H;K=ma;G=na}else{break}}G=c[D>>2]|0;c[D>>2]=c[B>>2];c[B>>2]=G;G=c[(c[u>>2]|0)+(A<<2)>>2]|0;zmb(c[v>>2]|0,c[w>>2]|0,128,x,j+(A*5632|0)+4128|0,y);K=j+(A*5632|0)+4512|0;nrc(K|0,j+(A*5632|0)+5536|0,92)|0;nrc(j+(A*5632|0)+4604|0,c[z>>2]|0,1024)|0;zmb(x,K|0,256,G,j+(A*5632|0)+4320|0,y);A=A+1|0;if((A|0)>=(c[q>>2]|0)){break a}}if((F|0)==46){i=k;return r|0}}}while(0);c[h>>2]=1;r=c[b+432>>2]|0;i=k;return r|0}function l1(a){a=a|0;var b=0;b=c[a+60>>2]|0;PPa(b+17420|0);PPa(b+17484|0);PPa(b+17548|0);return 0}function m1(b){b=b|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;h=c[b+96>>2]|0;j=b+60|0;k=c[j>>2]|0;l=b+416|0;if(((c[l>>2]|0)-1|0)>>>0>1>>>0){KIb(b,16,2175744,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=f;return n|0}if(!(a[2011384]|0)){o=255;p=0;while(1){q=+V(((+(p|0)+.5)*.00390625+-.5)*3.141592653589793)+1.0;r=+V(((+(o|0)+.5)*.00390625+-.5)*3.141592653589793)+1.0;s=(q*q+r*r)*.5;t=q/s;g[5788208+(511-p<<2)>>2]=t;g[5788208+(p<<2)>>2]=t;t=r/s;g[5788208+(511-o<<2)>>2]=t;g[5788208+(o<<2)>>2]=t;u=p+1|0;if((u|0)<128){o=o-1|0;p=u}else{break}}wmb();p=0;o=0;while(1){c[5093564+(p*20|0)>>2]=10191784+(o<<2);u=p+1|0;v=e[2011360+(u<<1)>>1]|0;c[5093572+(p*20|0)>>2]=v-o;$2(5093560+(p*20|0)|0,9,d[1079832+p|0]|0,c[1080872+(p<<2)>>2]|0,1,1,c[1080840+(p<<2)>>2]|0,1,1,0,0,0,4)|0;if((u|0)<7){p=u;o=v}else{break}}}a[2011384]=1;o=c[b+100>>2]|0;do{if((o|0)==12|(o|0)==10){p=h;v=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+4|0;u=(he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=h+6|0;w=(he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=h+8|0;x=(he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;c[k+20>>2]=x;c[k+4384>>2]=1;if((v|0)==67108864){y=w;z=u;A=x;break}x=je(v|0)|0;KIb(b,16,2569448,(m=i,i=i+8|0,c[m>>2]=x,m)|0);i=m;n=-1094995529;i=f;return n|0}else if((o|0)==14){x=b;v=h;KIb(x,48,2148024,(m=i,i=i+8|0,c[m>>2]=(d[v]|d[v+1|0]<<8)<<16>>16&65535,m)|0);i=m;v=h+6|0;u=k+20|0;c[u>>2]=(d[v]|d[v+1|0]<<8)<<16>>16&65535;v=h+8|0;KIb(x,48,2124032,(m=i,i=i+8|0,c[m>>2]=(d[v]|d[v+1|0]<<8)<<16>>16&65535,m)|0);i=m;v=h+10|0;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;v=h+12|0;KIb(x,48,2642256,(m=i,i=i+8|0,c[m>>2]=(d[v]|d[v+1|0]<<8)<<16>>16&65535,m)|0);i=m;v=c[l>>2]<<10;p=(c[u>>2]|0)!=0?18:2;c[u>>2]=p;c[k+4384>>2]=0;u=c[b+432>>2]|0;B=c[l>>2]|0;if((u|0)==(ca(w*96|0,B)|0)){y=2190;z=v;A=p;break}if((u|0)==(ca(w*152|0,B)|0)){y=2190;z=v;A=p;break}if((u|0)==(ca(w*192|0,B)|0)){y=2190;z=v;A=p;break}KIb(x,16,2618880,(m=i,i=i+24|0,c[m>>2]=u,c[m+8>>2]=B,c[m+16>>2]=w,m)|0);i=m;n=-1094995529;i=f;return n|0}else{KIb(0,16,2591568,(m=i,i=i+8|0,c[m>>2]=o,m)|0);i=m;n=-22;i=f;return n|0}}while(0);if(!((z|0)==2048|(z|0)==1024)){KIb(b,16,2551296,(m=i,i=i+8|0,c[m>>2]=z,m)|0);i=m;n=-1094995529;i=f;return n|0}if((y|0)!=2190){KIb(b,16,2533152,(m=i,i=i+8|0,c[m>>2]=y,m)|0);i=m;n=-1094995529;i=f;return n|0}do{if((A|0)==2){KIb(b,48,2517704,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}else if((A|0)==18){y=b;if((c[l>>2]|0)==2){KIb(y,48,2490320,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;break}KIb(y,16,2503800,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}else{KIb(b,16,2479480,(m=i,i=i+8|0,c[m>>2]=A,m)|0);i=m;n=-1094995529;i=f;return n|0}}while(0);A=c[b+432>>2]|0;if(A>>>0>2147483646>>>0){n=-22;i=f;return n|0}y=pJb(A+19&-4)|0;A=k+100|0;c[A>>2]=y;if((y|0)==0){n=-12;i=f;return n|0}c[b+420>>2]=8;y=OPa(k+4588|0,9,1,30517578125.0e-15)|0;if((y|0)<0){KIb(b,16,2469672,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;mJb(A);n=y;i=f;return n|0}c[k+76>>2]=0;c[k+80>>2]=7;c[k+84>>2]=0;c[k+88>>2]=7;c[k+92>>2]=0;c[k+96>>2]=7;c[k+28>>2]=3;c[k+44>>2]=3;c[k+60>>2]=3;c[k+32>>2]=3;c[k+48>>2]=3;c[k+64>>2]=3;c[k+36>>2]=3;c[k+52>>2]=3;c[k+68>>2]=3;c[k+40>>2]=3;c[k+56>>2]=3;c[k+72>>2]=3;xmb(k+4388|0,4,3);qHb(k+4672|0,c[b+88>>2]&8388608);yfa(k+4652|0,b);b=pJb((c[l>>2]|0)*15936|0)|0;c[k+24>>2]=b;if((b|0)!=0){n=0;i=f;return n|0}b=c[j>>2]|0;kJb(c[b+24>>2]|0);kJb(c[b+100>>2]|0);PPa(b+4588|0);n=-12;i=f;return n|0}function n1(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0.0,T=0.0,U=0,V=0.0,W=0.0,X=0.0,Y=0,Z=0,_=0.0,$=0.0,aa=0,ba=0,da=0,ea=0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=b+60|0;m=c[h>>2]|0;n=b+432|0;if((l|0)<(c[n>>2]|0)){KIb(b,16,2458200,(o=i,i=i+8|0,c[o>>2]=l,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+76>>2]=1024;l=M4a(b,e,0)|0;if((l|0)<0){p=l;i=j;return p|0}do{if((c[m+4384>>2]|0)==0){q=k}else{l=m+100|0;r=c[l>>2]|0;s=c[n>>2]|0;t=r;u=k&3;v=k+(-u|0)|0;w=(u|0)!=0;if(w){x=u<<3;y=je(1400856835<<32-x|1400856835>>>(x>>>0)|0)|0}else{y=56721235}x=u+3+s|0;s=(x|0)/4|0;if((x|0)>3){x=0;do{c[t+(x<<2)>>2]=c[v+(x<<2)>>2]^y;x=x+1|0;}while((x|0)<(s|0))}if(!w){q=r;break}QIb(0,2208240,(o=i,i=i+8|0,c[o>>2]=u,o)|0);i=o;q=c[l>>2]|0}}while(0);y=c[e+64>>2]|0;e=c[h>>2]|0;h=e;k=e+20|0;a:do{if((c[k>>2]|0)==18){m=e;s=c[n>>2]<<3;x=s>>>0>2147483639>>>0|(q|0)==0;v=x?0:q;t=x?0:s;s=e;c[s>>2]=v;x=e+12|0;c[x>>2]=t;z=e+16|0;c[z>>2]=t+8;A=e+4|0;c[A>>2]=v+(t>>3);t=e+8|0;c[t>>2]=0;v=e+24|0;B=p1(h,m,c[v>>2]|0,c[y>>2]|0,0,18)|0;if((B|0)!=0){C=B;D=55;break}B=e+100|0;E=c[B>>2]|0;F=c[n>>2]|0;G=F-1|0;do{if((E|0)==(q|0)){if((F|0)<=1){H=F;break}I=q+G|0;J=q;K=0;while(1){L=a[I]|0;a[I]=a[J]|0;a[J]=L;L=K+1|0;M=c[n>>2]|0;if((L|0)<((M|0)/2|0|0)){I=I-1|0;J=J+1|0;K=L}else{H=M;break}}}else{if((F|0)<=0){H=F;break}K=q+G|0;a[E]=a[K]|0;J=c[n>>2]|0;if((J|0)>1){N=K;O=1}else{H=J;break}while(1){J=N-1|0;a[(c[B>>2]|0)+O|0]=a[J]|0;K=O+1|0;I=c[n>>2]|0;if((K|0)<(I|0)){N=J;O=K}else{H=I;break}}}}while(0);E=c[B>>2]|0;if((a[E]|0)==-8){G=E;F=4;while(1){if((F|0)>=(H|0)){C=-1094995529;D=55;break a}l=G+1|0;if((a[l]|0)==-8){G=l;F=F+1|0}else{P=l;break}}}else{P=E}F=E+H-P|0;G=F>>>0>268435455>>>0?-8:F<<3;F=G>>>0>2147483639>>>0|(P|0)==0;B=F?0:P;l=F?0:G;c[s>>2]=B;c[x>>2]=l;G=l+8|0;c[z>>2]=G;c[A>>2]=B+(l>>3);c[t>>2]=0;l=e+76|0;F=e+84|0;orc(l|0,F|0,16)|0;u=(d[B]|0)>>>7;r=(G|0)>0;w=r&1;c[t>>2]=w;c[e+92>>2]=u;u=B;I=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<w>>>29;w=r?4:3;r=G>>>0>w>>>0?w:G;c[t>>2]=r;c[e+96>>2]=I;I=e+44|0;w=e+28|0;c[w>>2]=c[I>>2];u=e+60|0;c[I>>2]=c[u>>2];K=B+(r>>>3)|0;J=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(r&7)>>>30;K=r+2|0;r=G>>>0>K>>>0?K:G;c[t>>2]=r;c[u>>2]=J;J=e+48|0;c[e+32>>2]=c[J>>2];u=e+64|0;c[J>>2]=c[u>>2];J=B+(r>>>3)|0;K=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(r&7)>>>30;J=r+2|0;r=G>>>0>J>>>0?J:G;c[t>>2]=r;c[u>>2]=K;K=e+52|0;c[e+36>>2]=c[K>>2];u=e+68|0;c[K>>2]=c[u>>2];K=B+(r>>>3)|0;J=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(r&7)>>>30;K=r+2|0;r=G>>>0>K>>>0?K:G;c[t>>2]=r;c[u>>2]=J;J=e+56|0;c[e+40>>2]=c[J>>2];u=e+72|0;c[J>>2]=c[u>>2];J=B+(r>>>3)|0;B=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(r&7)>>>30;J=r+2|0;c[t>>2]=G>>>0>J>>>0?J:G;c[u>>2]=B;B=y+4|0;u=p1(h,m,(c[v>>2]|0)+15936|0,c[B>>2]|0,1,18)|0;if((u|0)!=0){C=u;D=55;break}u=c[y>>2]|0;G=c[B>>2]|0;B=0;J=0;r=8;while(1){K=c[w+(J<<2)>>2]|0;M=c[I+(J<<2)>>2]|0;do{if((K|0)==(M|0)){Q=B}else{L=K<<1;R=+g[838200+(L<<2)>>2];T=+g[838200+((L|1)<<2)>>2];L=M<<1;U=B|8;if((B|0)>=(U|0)){Q=B;break}V=R;W=+g[838200+(L<<2)>>2]-R;R=T;X=+g[838200+((L|1)<<2)>>2]-T;L=B;while(1){Y=u+(L<<2)|0;Z=G+(L<<2)|0;T=+g[Y>>2];_=+(L-B|0)*.125;$=T*(V+W*_)+ +g[Z>>2]*(R+X*_);g[Y>>2]=$;g[Z>>2]=T*2.0-$;Z=L+1|0;if((Z|0)<(U|0)){L=Z}else{Q=r;break}}}}while(0);do{if((M|0)==1){K=B+256|0;if((Q|0)<(K|0)){aa=Q}else{ba=K;break}while(1){L=u+(aa<<2)|0;U=G+(aa<<2)|0;X=+g[U>>2];g[L>>2]=(+g[L>>2]+X)*2.0;g[U>>2]=X*-2.0;U=aa+1|0;if((U|0)<(K|0)){aa=U}else{ba=K;break}}}else if((M|0)==2|(M|0)==3){K=B+256|0;if((Q|0)<(K|0)){da=Q}else{ba=K;break}while(1){U=u+(da<<2)|0;X=+g[U>>2];L=G+(da<<2)|0;R=+g[L>>2];g[U>>2]=X+R;g[L>>2]=X-R;L=da+1|0;if((L|0)<(K|0)){da=L}else{ba=K;break}}}else if((M|0)==0){K=B+256|0;if((Q|0)<(K|0)){ea=Q}else{ba=K;break}while(1){L=u+(ea<<2)|0;R=+g[L>>2];U=G+(ea<<2)|0;X=+g[U>>2];g[L>>2]=X*2.0;g[U>>2]=(R-X)*2.0;U=ea+1|0;if((U|0)<(K|0)){ea=U}else{ba=K;break}}}else{ba=B+256|0}}while(0);if((ba|0)<1024){B=ba;J=J+1|0;r=r+256|0}else{break}}r=c[e+80>>2]|0;J=c[e+88>>2]|0;if((r|0)==7){if((J|0)==7){break}else{fa=1.0;ga=1.0;D=42}}else{X=+(r&7|0)/7.0;R=+S(2.0-X*X);r=(c[l>>2]|0)==0;W=r?R:X;V=r?X:R;if((J|0)==7){ha=1.0;ia=1.0;ja=W;ka=V}else{fa=W;ga=V;D=42}}if((D|0)==42){V=+(J&7|0)/7.0;W=+S(2.0-V*V);J=(c[F>>2]|0)==0;ha=J?V:W;ia=J?W:V;ja=fa;ka=ga}V=ka;W=ja-ka;R=ha;X=ia-ha;J=256;while(1){$=+(J-256|0)*.125;r=u+(J<<2)|0;g[r>>2]=+g[r>>2]*(V+W*$);r=G+(J<<2)|0;g[r>>2]=+g[r>>2]*(R+X*$);r=J+1|0;if((r|0)<264){J=r}else{la=264;break}}while(1){J=u+(la<<2)|0;g[J>>2]=ha*+g[J>>2];J=G+(la<<2)|0;g[J>>2]=ia*+g[J>>2];J=la+1|0;if((J|0)<512){la=J}else{ma=512;break}}while(1){$=+(ma-512|0)*.125;J=u+(ma<<2)|0;g[J>>2]=+g[J>>2]*(V+W*$);J=G+(ma<<2)|0;g[J>>2]=+g[J>>2]*(R+X*$);J=ma+1|0;if((J|0)<520){ma=J}else{na=520;break}}while(1){J=u+(na<<2)|0;g[J>>2]=ha*+g[J>>2];J=G+(na<<2)|0;g[J>>2]=ia*+g[J>>2];J=na+1|0;if((J|0)<768){na=J}else{oa=768;break}}while(1){$=+(oa-768|0)*.125;J=u+(oa<<2)|0;g[J>>2]=+g[J>>2]*(V+W*$);J=G+(oa<<2)|0;g[J>>2]=+g[J>>2]*(R+X*$);J=oa+1|0;if((J|0)<776){oa=J}else{pa=776;break}}do{J=u+(pa<<2)|0;g[J>>2]=ha*+g[J>>2];J=G+(pa<<2)|0;g[J>>2]=ia*+g[J>>2];pa=pa+1|0;}while((pa|0)<1024)}else{G=b+416|0;u=e;J=e;F=e+12|0;l=e+16|0;r=e+4|0;B=e+8|0;I=e+24|0;w=0;while(1){v=c[G>>2]|0;if((w|0)>=(v|0)){break a}m=c[n>>2]|0;t=q+((ca(m,w)|0)/(v|0)|0)|0;A=(m<<3|0)/(v|0)|0;v=A>>>0>2147483639>>>0|(t|0)==0;m=v?0:t;t=v?0:A;c[J>>2]=m;c[F>>2]=t;c[l>>2]=t+8;c[r>>2]=m+(t+7>>3);c[B>>2]=0;t=p1(h,u,(c[I>>2]|0)+(w*15936|0)|0,c[y+(w<<2)>>2]|0,w,c[k>>2]|0)|0;if((t|0)==0){w=w+1|0}else{C=t;D=55;break}}}}while(0);if((D|0)==55){KIb(0,16,2368120,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=C;i=j;return p|0}C=b+416|0;if((c[C>>2]|0)>0){b=e+24|0;o=e+104|0;e=0;do{D=c[y+(e<<2)>>2]|0;k=D;h=D+2048|0;zmb(k,D+1024|0,256,k,(c[b>>2]|0)+(e*15936|0)+15360|0,o);zmb(D+3072|0,h,256,h,(c[b>>2]|0)+(e*15936|0)+15544|0,o);zmb(k,h,512,k,(c[b>>2]|0)+(e*15936|0)+15728|0,o);e=e+1|0;}while((e|0)<(c[C>>2]|0))}c[f>>2]=1;p=c[n>>2]|0;i=j;return p|0}function o1(a){a=a|0;var b=0;b=c[a+60>>2]|0;kJb(c[b+24>>2]|0);kJb(c[b+100>>2]|0);PPa(b+4588|0);return 0}function p1(a,b,f,h,j,k){a=a|0;b=b|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0.0,ca=0,da=0,ea=0,fa=0,ga=0.0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;l=i;i=i+816|0;m=l|0;n=l+16|0;o=l+48|0;p=l+176|0;q=l+304|0;r=f+4104|0;s=c[r>>2]|0;t=1-s|0;u=b+8|0;v=c[u>>2]|0;w=b+16|0;x=c[w>>2]|0;y=b|0;z=c[y>>2]|0;A=z+(v>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(v&7);do{if((k|0)==18&(j|0)==1){A=v+2|0;C=x>>>0>A>>>0?A:x;c[u>>2]=C;if((B&-1073741824|0)==-1073741824){D=C;break}KIb(0,16,2302432,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;i=l;return F|0}else{C=v+6|0;A=x>>>0>C>>>0?C:x;c[u>>2]=A;if((B&-67108864|0)==-1610612736){D=A;break}KIb(0,16,2250952,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;i=l;return F|0}}while(0);E=z+(D>>>3)|0;B=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>30;E=D+2|0;c[u>>2]=x>>>0>E>>>0?E:x;x=f|0;c[x>>2]=B;E=0;a:do{D=c[u>>2]|0;v=c[w>>2]|0;j=z+(D>>>3)|0;k=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(D&7)>>>29;j=D+3|0;c[u>>2]=v>>>0>j>>>0?j:v;v=f+6668+(t*240|0)+(E*60|0)|0;c[v>>2]=k;if((k|0)!=0){k=0;do{j=c[u>>2]|0;D=c[w>>2]|0;A=z+(j>>>3)|0;C=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(j&7)>>>28;A=j+4|0;c[u>>2]=D>>>0>A>>>0?A:D;c[f+6668+(t*240|0)+(E*60|0)+4+(k<<2)>>2]=C;C=c[u>>2]|0;D=c[w>>2]|0;A=z+(C>>>3)|0;j=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(C&7)>>>27;A=C+5|0;c[u>>2]=D>>>0>A>>>0?A:D;c[f+6668+(t*240|0)+(E*60|0)+32+(k<<2)>>2]=j;if((k|0)!=0){if((j|0)<=(c[f+6668+(t*240|0)+(E*60|0)+32+(k-1<<2)>>2]|0)){F=-1094995529;G=66;break a}}k=k+1|0;}while((k|0)<(c[v>>2]|0))}E=E+1|0;}while((E|0)<=(B|0));if((G|0)==66){i=l;return F|0}if((E|0)<4){G=E;do{c[f+6668+(t*240|0)+(G*60|0)>>2]=0;G=G+1|0;}while((G|0)<4)}G=c[x>>2]|0;x=c[u>>2]|0;E=c[w>>2]|0;B=z+(x>>>3)|0;v=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>27;B=x+5|0;x=E>>>0>B>>>0?B:E;c[u>>2]=x;b:do{if((v|0)==0){H=0}else{B=z+(x>>>3)|0;k=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>30;B=x+2|0;j=E>>>0>B>>>0?B:E;c[u>>2]=j;if((k|0)==2){H=-1094995529;break}B=(G|0)<0;D=(k|0)==3;A=(G<<2)+4|0;C=(A|0)>0;I=n|0;J=0;K=k&1;k=1;L=j;while(1){if(B){M=L;N=c[w>>2]|0;O=c[y>>2]|0}else{j=c[y>>2]|0;P=c[w>>2]|0;Q=0;R=L;while(1){S=(d[j+(R>>>3)|0]|0)<<(R&7)>>>7;T=((R|0)<(P|0))+R|0;c[u>>2]=T;c[m+(Q<<2)>>2]=S&1;S=Q+1|0;if((S|0)>(G|0)){M=T;N=P;O=j;break}else{Q=S;R=T}}}R=O+(M>>>3)|0;Q=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(M&7)>>>29;R=M+3|0;j=N>>>0>R>>>0?R:N;c[u>>2]=j;R=O+(j>>>3)|0;P=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(j&7);R=P>>>29;T=j+3|0;j=N>>>0>T>>>0?T:N;c[u>>2]=j;if(P>>>0<1073741824>>>0){H=-1094995529;break b}if(D){P=(d[O+(j>>>3)|0]|0)<<(j&7)>>>7;c[u>>2]=((j|0)<(N|0))+j;U=P&1}else{U=K}if(C){P=Q+1|0;Q=1062824+(R<<2)|0;j=J;T=0;while(1){c:do{if((c[m+(T>>2<<2)>>2]|0)==0){V=j}else{S=c[u>>2]|0;W=c[w>>2]|0;X=c[y>>2]|0;Y=X+(S>>>3)|0;Z=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(S&7)>>>29;Y=S+3|0;S=W>>>0>Y>>>0?Y:W;c[u>>2]=S;if((Z|0)==0){V=j;break}Y=T<<6;_=X+(S>>>3)|0;$=d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0;_=S+6|0;aa=W>>>0>_>>>0?_:W;c[u>>2]=aa;if((j|0)>63){H=-1094995529;break b}ba=+g[Q>>2];_=X;X=W;W=S;S=1;ca=j;da=$;$=aa;while(1){aa=(je(da|0)|0)<<(W&7)>>>26;ea=_+($>>>3)|0;fa=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<($&7)>>>26;ea=$+6|0;c[u>>2]=X>>>0>ea>>>0?ea:X;ea=fa|Y;c[f+4108+(ca*40|0)>>2]=ea;fa=1024-ea|0;ea=(fa|0)>(P|0)?P:fa;ga=+g[8779640+(aa<<2)>>2]*ba;q1(b,R,U,I,ea);c[f+4108+(ca*40|0)+4>>2]=ea;if((ea|0)>0){aa=0;do{g[f+4108+(ca*40|0)+8+(aa<<2)>>2]=ga*+(c[n+(aa<<2)>>2]|0);aa=aa+1|0;}while((aa|0)<(ea|0))}ea=ca+1|0;if((S|0)>=(Z|0)){V=ea;break c}aa=c[u>>2]|0;fa=c[w>>2]|0;ha=c[y>>2]|0;ia=ha+(aa>>>3)|0;ja=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;ia=aa+6|0;ka=fa>>>0>ia>>>0?ia:fa;c[u>>2]=ka;if((ea|0)>63){H=-1094995529;break b}else{_=ha;X=fa;W=aa;S=S+1|0;ca=ea;da=ja;$=ka}}}}while(0);$=T+1|0;if(($|0)<(A|0)){j=V;T=$}else{la=V;break}}}else{la=J}if((k|0)>=(v|0)){H=la;break b}J=la;K=U;k=k+1|0;L=c[u>>2]|0}}}while(0);U=f+4|0;c[U>>2]=H;if((H|0)<0){F=H;i=l;return F|0}H=c[u>>2]|0;la=c[w>>2]|0;w=c[y>>2]|0;y=w+(H>>>3)|0;v=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(H&7)>>>27;y=H+5|0;H=la>>>0>y>>>0?y:la;c[u>>2]=H;y=d[w+(H>>>3)|0]|0;V=((H|0)<(la|0))+H|0;c[u>>2]=V;n=0;m=V;do{V=w+(m>>>3)|0;N=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(m&7)>>>29;V=m+3|0;m=la>>>0>V>>>0?V:la;c[u>>2]=m;c[o+(n<<2)>>2]=N;n=n+1|0;}while((n|0)<=(v|0));n=y<<(H&7)>>>7;H=0;y=m;while(1){if((c[o+(H<<2)>>2]|0)==0){ma=y}else{m=w+(y>>>3)|0;N=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(y&7)>>>26;m=y+6|0;V=la>>>0>m>>>0?m:la;c[u>>2]=V;c[p+(H<<2)>>2]=N;ma=V}V=H+1|0;if((V|0)>(v|0)){break}else{H=V;y=ma}}ma=n&1;n=q|0;y=0;H=0;while(1){u=y+1|0;na=e[552936+(u<<1)>>1]|0;la=na-H|0;w=c[o+(y<<2)>>2]|0;do{if((w|0)==0){mrc(f+7168+(H<<2)|0,0,la<<2|0)|0}else{q1(b,w,ma,n,la);ba=+g[8779640+(c[p+(y<<2)>>2]<<2)>>2]*+g[1062824+(w<<2)>>2];if(H>>>0<na>>>0){oa=H;pa=0}else{break}while(1){g[f+7168+(oa<<2)>>2]=ba*+(c[q+(pa<<2)>>2]|0);V=oa+1|0;if((V|0)<(na|0)){oa=V;pa=pa+1|0}else{break}}}}while(0);if((u|0)>(v|0)){break}else{y=u;H=na}}mrc(f+7168+(na<<2)|0,0,1024-na<<2|0)|0;na=c[U>>2]|0;do{if((na|0)>0){U=-1;H=0;do{y=c[f+4108+(H*40|0)>>2]|0;pa=c[f+4108+(H*40|0)+4>>2]|0;oa=pa+y|0;U=(oa|0)>(U|0)?oa:U;if((pa|0)>0){oa=0;do{q=f+7168+(oa+y<<2)|0;g[q>>2]=+g[f+4108+(H*40|0)+8+(oa<<2)>>2]+ +g[q>>2];oa=oa+1|0;}while((oa|0)<(pa|0))}H=H+1|0;}while((H|0)<(na|0));H=(e[552936+(v<<1)>>1]|0)-1>>8;if(!((U|0)>-1)){qa=H;break}u=U+256>>8;qa=(u|0)>(H|0)?u:H}else{qa=(e[552936+(v<<1)>>1]|0)-1>>8}}while(0);v=f+11264|0;na=a+4388|0;H=f+11264|0;u=a+4588|0;pa=a+4628|0;oa=a+4672|0;a=0;do{if((a|0)>(qa|0)){mrc(v|0,0,2048)|0;ra=a<<8}else{y=a<<8;q=f+7168+(y<<2)|0;if((a&1|0)!=0){p=y|255;n=0;do{ma=f+7168+(p-n<<2)|0;ba=+g[ma>>2];b=f+7168+(n+y<<2)|0;g[ma>>2]=+g[b>>2];g[b>>2]=ba;n=n+1|0;}while((n|0)<128)}ef[c[pa>>2]&4095](u,H,q);mf[c[oa>>2]&2047](H,H,5788208,512);ra=y}ymb(na,H,f+8+(ra<<2)|0,f+6668+(s*240|0)+(a*60|0)|0,f+6668+(t*240|0)+(a*60|0)|0,256,h+(ra<<2)|0);a=a+1|0;}while((a|0)<4);c[r>>2]=c[r>>2]^1;F=0;i=l;return F|0}function q1(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=(f|0)==1;if(j){k=(i|0)/2|0}else{k=i}if((g|0)!=0){g=d[1703568+f|0]|0;i=(k|0)>0;if((f|0)>1){if(!i){return}l=e+8|0;m=e+16|0;n=e|0;o=32-g|0;p=0;do{q=c[l>>2]|0;r=c[m>>2]|0;s=(c[n>>2]|0)+(q>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(q&7)>>o;s=q+g|0;c[l>>2]=r>>>0>s>>>0?s:r;c[h+(p<<2)>>2]=t;p=p+1|0;}while((p|0)<(k|0));return}if(!i){return}i=e+8|0;p=e+16|0;l=e|0;o=32-g|0;if((f|0)==0){n=0;do{m=n<<1;c[h+(m<<2)>>2]=0;c[h+((m|1)<<2)>>2]=0;n=n+1|0;}while((n|0)<(k|0));return}else{n=0;do{m=c[i>>2]|0;t=c[p>>2]|0;r=(c[l>>2]|0)+(m>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(m&7)>>>(o>>>0);r=m+g|0;c[i>>2]=t>>>0>r>>>0?r:t;t=n<<1;c[h+(t<<2)>>2]=a[838712+(s>>2)|0]|0;c[h+((t|1)<<2)>>2]=a[838712+(s&3)|0]|0;n=n+1|0;}while((n|0)<(k|0));return}}n=(k|0)>0;if(j){if(!n){return}j=e+8|0;i=e+16|0;g=c[1273391]|0;o=c[e>>2]|0;l=0;do{p=c[1273390]|0;s=c[j>>2]|0;t=c[i>>2]|0;r=o+(s>>>3)|0;m=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((32-p|0)>>>0);r=b[g+(m<<2)>>1]|0;q=b[g+(m<<2)+2>>1]|0;m=q<<16>>16;do{if(q<<16>>16<0){u=s+p|0;v=t>>>0>u>>>0?u:t;u=o+(v>>>3)|0;w=((je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7)>>>((m+32|0)>>>0))+r|0;u=b[g+(w<<2)>>1]|0;x=b[g+(w<<2)+2>>1]|0;w=x<<16>>16;if(!(x<<16>>16<0)){y=w;z=u;A=v;break}x=v-m|0;v=t>>>0>x>>>0?x:t;x=o+(v>>>3)|0;B=((je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(v&7)>>>((w+32|0)>>>0))+u|0;y=b[g+(B<<2)+2>>1]|0;z=b[g+(B<<2)>>1]|0;A=v}else{y=m;z=r;A=s}}while(0);s=y+A|0;c[j>>2]=t>>>0>s>>>0?s:t;s=z<<1;r=l<<1;c[h+(r<<2)>>2]=a[838688+s|0]|0;c[h+((r|1)<<2)>>2]=a[838688+(s|1)|0]|0;l=l+1|0;}while((l|0)<(k|0));return}else{if(!n){return}n=f-1|0;f=5093560+(n*20|0)|0;l=e+8|0;z=e+16|0;j=c[5093564+(n*20|0)>>2]|0;n=c[e>>2]|0;e=0;do{A=c[f>>2]|0;y=c[l>>2]|0;g=c[z>>2]|0;o=n+(y>>>3)|0;i=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(y&7)>>>((32-A|0)>>>0);o=b[j+(i<<2)>>1]|0;s=b[j+(i<<2)+2>>1]|0;i=s<<16>>16;do{if(s<<16>>16<0){r=y+A|0;m=g>>>0>r>>>0?r:g;r=n+(m>>>3)|0;p=((je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(m&7)>>>((i+32|0)>>>0))+o|0;r=b[j+(p<<2)>>1]|0;q=b[j+(p<<2)+2>>1]|0;p=q<<16>>16;if(!(q<<16>>16<0)){C=p;D=r;E=m;break}q=m-i|0;m=g>>>0>q>>>0?q:g;q=n+(m>>>3)|0;v=((je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(m&7)>>>((p+32|0)>>>0))+r|0;C=b[j+(v<<2)+2>>1]|0;D=b[j+(v<<2)>>1]|0;E=m}else{C=i;D=o;E=y}}while(0);y=C+E|0;c[l>>2]=g>>>0>y>>>0?y:g;y=D+1|0;o=y>>1;c[h+(e<<2)>>2]=(y&1|0)==0?o:-o|0;e=e+1|0;}while((e|0)<(k|0));return}}function r1(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=b+60|0;f=c[e>>2]|0;if((c[b+432>>2]|0)==0){KIb(b,16,2208176,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=d;return h|0}Amb();qHb(f+20|0,c[b+88>>2]&8388608);OPa(f+65864|0,5,1,.0009765625)|0;u1(b,f+65800|0);xmb(f+65600|0,6,2);v1();j=f+65936|0;mrc(j|0,0,5)|0;k=c[b+416>>2]|0;switch(k|0){case 6:{l=b+448|0;c[l>>2]=63;c[l+4>>2]=0;c[f+65932>>2]=4;a[j]=1;a[f+65937|0]=0;a[f+65938|0]=1;a[f+65939|0]=0;m=147200;break};case 1:{l=b+448|0;if(!((c[l>>2]|0)==1&(c[l+4>>2]|0)==0)){c[l>>2]=4;c[l+4>>2]=0}c[f+65932>>2]=1;a[j]=0;m=36800;break};case 4:{l=b+448|0;c[l>>2]=263;c[l+4>>2]=0;c[f+65932>>2]=3;a[j]=1;a[f+65937|0]=0;a[f+65938|0]=0;m=110400;break};case 3:{l=b+448|0;c[l>>2]=7;c[l+4>>2]=0;c[f+65932>>2]=2;a[j]=1;a[f+65937|0]=0;m=73600;break};case 8:{l=b+448|0;c[l>>2]=1599;c[l+4>>2]=0;c[f+65932>>2]=5;a[j]=1;a[f+65937|0]=0;a[f+65938|0]=1;a[f+65939|0]=1;a[f+65940|0]=0;m=184e3;break};case 2:{l=b+448|0;c[l>>2]=3;c[l+4>>2]=0;c[f+65932>>2]=1;a[j]=1;m=36800;break};case 7:{l=b+448|0;c[l>>2]=319;c[l+4>>2]=0;c[f+65932>>2]=5;a[j]=1;a[f+65937|0]=0;a[f+65938|0]=1;a[f+65939|0]=0;a[f+65940|0]=0;m=184e3;break};default:{KIb(b,16,2175688,(g=i,i=i+8|0,c[g>>2]=k,g)|0);i=g;h=-1094995529;i=d;return h|0}}g=b+448|0;k=c[g+4>>2]|0;j=f+65944|0;c[j>>2]=c[g>>2];c[j+4>>2]=k;k=f+65932|0;j=pJb(m)|0;m=j;g=f+65928|0;c[g>>2]=m;if((j|0)==0){kJb(c[(c[e>>2]|0)+65928>>2]|0);h=-12;i=d;return h|0}a:do{if((c[k>>2]|0)>0){e=0;j=m;while(1){c[j+(e*36800|0)+72>>2]=0;c[j+(e*36800|0)+4612>>2]=j+(e*36800|0)+4577;f=c[g>>2]|0;c[f+(e*36800|0)+4616>>2]=f+(e*36800|0)+4593;f=c[g>>2]|0;c[f+(e*36800|0)+6540>>2]=f+(e*36800|0)+4620;f=c[g>>2]|0;c[f+(e*36800|0)+6544>>2]=f+(e*36800|0)+5580;f=c[g>>2]|0;c[f+(e*36800|0)+7832>>2]=f+(e*36800|0)+6552;f=c[g>>2]|0;c[f+(e*36800|0)+7836>>2]=f+(e*36800|0)+7192;f=c[g>>2]|0;c[f+(e*36800|0)+7840>>2]=1;c[f+(e*36800|0)+12380>>2]=f+(e*36800|0)+12345;f=c[g>>2]|0;c[f+(e*36800|0)+12384>>2]=f+(e*36800|0)+12361;f=c[g>>2]|0;c[f+(e*36800|0)+14308>>2]=f+(e*36800|0)+12388;f=c[g>>2]|0;c[f+(e*36800|0)+14312>>2]=f+(e*36800|0)+13348;f=c[g>>2]|0;c[f+(e*36800|0)+15600>>2]=f+(e*36800|0)+14320;f=c[g>>2]|0;c[f+(e*36800|0)+15604>>2]=f+(e*36800|0)+14960;f=c[g>>2]|0;c[f+(e*36800|0)+17272>>2]=f+(e*36800|0)+15608;f=c[g>>2]|0;c[f+(e*36800|0)+17276>>2]=f+(e*36800|0)+16440;f=e+1|0;if((f|0)>=(c[k>>2]|0)){break a}e=f;j=c[g>>2]|0}}}while(0);c[b+420>>2]=8;h=0;i=d;return h|0}function s1(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0.0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;k=i;i=i+64|0;l=k|0;m=c[e+60>>2]|0;n=m;o=c[f+64>>2]|0;c[f+76>>2]=2048;p=M4a(e,f,0)|0;if((p|0)<0){KIb(e,16,2458152,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=p;i=k;return r|0}p=m;f=c[j+24>>2]|0;s=c[j+28>>2]|0;j=s>>>0>268435455>>>0?-8:s<<3;s=j>>>0>2147483639>>>0|(f|0)==0;t=s?0:f;f=s?0:j;j=m;c[j>>2]=t;u=m+12|0;c[u>>2]=f;v=f+8|0;w=m+16|0;c[w>>2]=v;c[m+4>>2]=t+(f>>3);x=m+8|0;c[x>>2]=0;if(s){r=s?-1094995529:0;i=k;return r|0}s=a[t]|0;y=(v|0)>0|0;c[x>>2]=y;if(!(s<<24>>24>-1)){KIb(e,16,2368040,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=k;return r|0}a:do{if((f-y|0)>1){s=m+65932|0;z=m+65928|0;A=m+64|0;B=A;C=l;D=b[714392]|0;E=m+65864|0;F=m+20|0;G=m+65800|0;H=m+65600|0;I=m+49216|0;J=0;K=0;L=y;M=v;N=t;while(1){O=N+(L>>>3)|0;P=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>30;O=L+2|0;c[x>>2]=M>>>0>O>>>0?O:M;if((P|0)==3){break a}else if((P|0)==2){Q=9;break}if((J|0)>=(c[s>>2]|0)){Q=12;break}if((d[m+(J+65936)|0]|0)!=(P|0)){Q=12;break}O=c[z>>2]|0;c[O+(J*36800|0)>>2]=P;R=P+1|0;P=Cmb(p,O+(J*36800|0)|0,R,e)|0;if((P|0)<0){r=P;Q=56;break}P=c[z>>2]|0;O=P+(J*36800|0)|0;mrc(C|0,0,64)|0;do{if((c[P+(J*36800|0)+20>>2]|0)==0){S=P+(J*36800|0)+12|0;T=c[S>>2]|0;if((T|0)>0){U=0;V=0;while(1){W=(c[P+(J*36800|0)+220+(V<<2)>>2]|0)+U+(c[P+(J*36800|0)+7988+(V<<2)>>2]|0)|0;X=V+1|0;if((X|0)<(T|0)){U=W;V=X}else{Y=W;break}}}else{Y=0}V=P+(J*36800|0)+16|0;U=c[V>>2]|0;if((U|0)>0){T=Y;W=0;while(1){c[l+(W<<2)>>2]=T&1020;X=W+1|0;if((X|0)<(U|0)){T=T+128|0;W=X}else{Z=0;break}}}else{Z=0}do{W=B+(Z<<13)|0;mrc(W|0,0,8192)|0;T=c[S>>2]|0;if((T|0)>0){U=0;X=D;while(1){_=X&65535;$=U+1|0;aa=b[1428784+($<<1)>>1]|0;ba=(aa&65535)-_|0;ca=c[P+(J*36800|0)+72+(Z*7768|0)+20+(U<<2)>>2]|0;do{if((ca|0)>0){da=+g[1428528+(c[P+(J*36800|0)+72+(Z*7768|0)+148+(U<<2)>>2]<<2)>>2]*+g[1428856+(ca<<2)>>2];if((ba|0)>0){ea=0}else{break}do{fa=ea+_|0;g[B+(Z<<13)+(fa<<2)>>2]=da*+(b[P+(J*36800|0)+72+(Z*7768|0)+404+(fa<<1)>>1]|0);ea=ea+1|0;}while((ea|0)<(ba|0))}}while(0);if(($|0)<(T|0)){U=$;X=aa}else{break}}}X=c[V>>2]|0;if((X|0)>0){U=W|0;T=0;while(1){y1(O,Z,U,c[l+(T<<2)>>2]|0,T);ba=T+1|0;_=c[V>>2]|0;if((ba|0)<(_|0)){T=ba}else{ga=_;break}}}else{ga=X}Z=Z+1|0;}while((Z|0)<(R|0));if((c[O>>2]|0)==1&(ga|0)>0){ha=0}else{break}do{if((a[P+(J*36800|0)+40+ha|0]|0)!=0){V=ha<<7;S=0;do{T=S+V|0;U=B+8192+(T<<2)|0;da=+g[U>>2];W=B+(T<<2)|0;g[U>>2]=+g[W>>2];g[W>>2]=da;S=S+1|0;}while((S|0)<128)}if((a[P+(J*36800|0)+56+ha|0]|0)!=0){S=ha<<7;V=0;do{X=B+8192+(V+S<<2)|0;g[X>>2]=-0.0- +g[X>>2];V=V+1|0;}while((V|0)<128)}ha=ha+1|0;}while((ha|0)<(ga|0))}else{mrc(A|0,0,R<<13|0)|0}}while(0);P=c[z>>2]|0;O=P+(J*36800|0)|0;V=P+(J*36800|0)+8|0;S=P+(J*36800|0)+17272|0;X=P+(J*36800|0)+17276|0;W=0;while(1){U=c[V>>2]|0;if((U|0)>0){T=P+(J*36800|0)+72+(W*7768|0)+4544|0;_=P+(J*36800|0)+72+(W*7768|0)+4540|0;ba=P+(J*36800|0)+72+(W*7768|0)+6472|0;ca=P+(J*36800|0)+72+(W*7768|0)+6468|0;fa=0;while(1){ia=fa<<7;ja=n+16448+(W<<13)+(ia<<2)|0;z1(F,G,n+64+(W<<13)+(ia<<2)|0,ja,(d[(c[_>>2]|0)+fa|0]|0)+(d[(c[T>>2]|0)+fa|0]<<1)|0,fa);ymb(H,ja,P+(J*36800|0)+20416+(W<<13)+(ia<<2)|0,(c[ba>>2]|0)+(fa*60|0)|0,(c[ca>>2]|0)+(fa*60|0)|0,128,n+32832+(W<<13)+(ia<<2)|0);ia=fa+1|0;ja=c[V>>2]|0;if((ia|0)<(ja|0)){fa=ia}else{ka=ja;break}}}else{ka=U}mrc(P+(J*36800|0)+20416+(W<<13)+(ka<<7<<2)|0,0,16-ka<<9|0)|0;fa=c[V>>2]|0;mrc(n+32832+(W<<13)+(fa<<7<<2)|0,0,16-fa<<9|0)|0;if((c[c[S>>2]>>2]|0)==0){if((c[c[X>>2]>>2]|0)!=0){Q=43}}else{Q=43}do{if((Q|0)==43){Q=0;fa=c[V>>2]|0;if((fa|0)<=0){break}ca=P+(J*36800|0)+72+(W*7768|0)+7760|0;ba=P+(J*36800|0)+72+(W*7768|0)+7764|0;T=0;_=fa;while(1){if((c[(c[ca>>2]|0)+(T*40|0)+32>>2]|0)==0){if((c[(c[ba>>2]|0)+(T*40|0)+32>>2]|0)==0){la=_}else{Q=47}}else{Q=47}if((Q|0)==47){Q=0;w1(O,F,W,T,n+32832+(W<<13)+(T<<7<<2)|0);la=c[V>>2]|0}fa=T+1|0;if((fa|0)<(la|0)){T=fa;_=la}else{break}}}}while(0);A1(E,P+(J*36800|0)+17280+(W*1568|0)|0,n+32832+(W<<13)|0,n+49216+(W<<13)|0);U=W+1|0;if((U|0)<(R|0)){W=U}else{ma=0;break}}do{W=P+(J*36800|0)+72+(ma*7768|0)+4544|0;V=c[W>>2]|0;O=P+(J*36800|0)+72+(ma*7768|0)+4540|0;c[W>>2]=c[O>>2];c[O>>2]=V;V=P+(J*36800|0)+72+(ma*7768|0)+6472|0;O=c[V>>2]|0;W=P+(J*36800|0)+72+(ma*7768|0)+6468|0;c[V>>2]=c[W>>2];c[W>>2]=O;O=P+(J*36800|0)+72+(ma*7768|0)+7764|0;W=c[O>>2]|0;V=P+(J*36800|0)+72+(ma*7768|0)+7760|0;c[O>>2]=c[V>>2];c[V>>2]=W;ma=ma+1|0;}while((ma|0)<(R|0));P=c[X>>2]|0;c[X>>2]=c[S>>2];c[S>>2]=P;P=0;do{nrc(c[o+(P+K<<2)>>2]|0,I+(P<<13)|0,8192)|0;P=P+1|0;}while((P|0)<(R|0));P=c[x>>2]|0;if(((c[u>>2]|0)-P|0)<=1){break a}J=J+1|0;K=R+K|0;L=P;M=c[w>>2]|0;N=c[j>>2]|0}if((Q|0)==9){RIb(e,2302344,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1163346256;i=k;return r|0}else if((Q|0)==12){KIb(e,16,2250832,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=k;return r|0}else if((Q|0)==56){i=k;return r|0}}}while(0);c[h>>2]=1;r=c[e+432>>2]|0;i=k;return r|0}function t1(a){a=a|0;kJb(c[(c[a+60>>2]|0)+65928>>2]|0);return 0}function u1(a,b){a=a|0;b=b|0;H0a(7);H0a(6);OPa(b,8,1,-1.0)|0;return}function v1(){var a=0,b=0,c=0,d=0;a=0;while(1){g[5112184+(a<<2)>>2]=+V(+(a|0)*6.283185307179586*.00048828125);b=a+1|0;if((b|0)<2048){a=b}else{c=0;break}}while(1){g[5949616+(c<<2)>>2]=(1.0- +U(+(c|0)*6.283185307179586*.00390625))*.5;a=c+1|0;if((a|0)<256){c=a}else{d=0;break}}do{g[10208192+(d<<2)>>2]=+ad(+((+(d|0)+-3.0)*.25));d=d+1|0;}while((d|0)<64);return}function w1(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+1024|0;j=h|0;k=h+512|0;mrc(j|0,0,512)|0;mrc(k|0,0,512)|0;l=c[a+72+(d*7768|0)+7764>>2]|0;m=l+(e*40|0)|0;n=c[a+72+(d*7768|0)+7760>>2]|0;d=n+(e*40|0)|0;do{if((c[d>>2]|0)==0){o=4}else{p=c[n+(e*40|0)+8>>2]|0;if((p|0)>=(c[n+(e*40|0)+12>>2]|0)){o=4;break}c[n+(e*40|0)+16>>2]=1;q=p+32|0;c[n+(e*40|0)+24>>2]=q;r=q}}while(0);do{if((o|0)==4){q=n+(e*40|0)+16|0;if((c[m>>2]|0)==0){c[q>>2]=0;c[n+(e*40|0)+24>>2]=0;r=0;break}else{c[q>>2]=1;q=c[l+(e*40|0)+8>>2]|0;c[n+(e*40|0)+24>>2]=q;r=q;break}}}while(0);do{if((c[l+(e*40|0)+4>>2]|0)==0){o=10}else{q=l+(e*40|0)+12|0;if((c[q>>2]|0)<(r|0)){o=10;break}c[n+(e*40|0)+20>>2]=1;c[n+(e*40|0)+28>>2]=c[q>>2]}}while(0);do{if((o|0)==10){q=n+(e*40|0)+20|0;if((c[n+(e*40|0)+4>>2]|0)==0){c[q>>2]=0;c[n+(e*40|0)+28>>2]=64;break}else{c[q>>2]=1;c[n+(e*40|0)+28>>2]=(c[n+(e*40|0)+12>>2]|0)+32;break}}}while(0);q=n+(e*40|0)+16|0;p=l+(e*40|0)+32|0;s=(c[l+(e*40|0)+28>>2]|0)<32;if(!((c[p>>2]|0)==0|s)){x1(c[a+17276>>2]|0,m,l+(e*40|0)+16|0,128,j|0)}m=n+(e*40|0)+32|0;n=(r|0)>31;if(!((c[m>>2]|0)==0|n)){x1(c[a+17272>>2]|0,d,q,0,k|0)}do{if((c[p>>2]|0)==0){o=22}else{if(!((c[m>>2]|0)==0|s|n)){d=b|0;a=j|0;mf[c[d>>2]&2047](a,a,5950128,128);a=k|0;mf[c[d>>2]&2047](a,a,5949616,128);t=0;break}if((c[l+(e*40|0)+20>>2]|0)!=0){o=22;break}a=j|0;mf[c[b>>2]&2047](a,a,5950128,128);o=22}}while(0);do{if((o|0)==22){if((c[m>>2]|0)==0){t=0;break}if((c[q>>2]|0)!=0){t=0;break}e=k|0;mf[c[b>>2]&2047](e,e,5949616,128);t=0}}while(0);do{b=f+(t<<2)|0;g[b>>2]=+g[b>>2]+(+g[j+(t<<2)>>2]+ +g[k+(t<<2)>>2]);t=t+1|0;}while((t|0)<128);i=h;return}function x1(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0;h=a+64+(c[b+36>>2]<<4)|0;i=c[b+32>>2]|0;if((i|0)>0){b=e^128;if((c[a+4>>2]|0)==0){a=0;j=h;while(1){k=+g[10208192+(c[j+4>>2]<<2)>>2]*(+((c[j+8>>2]|0)+1|0)/15.130000114440918);l=c[j>>2]|0;m=0;n=(c[j+12>>2]<<6)-(ca(l,b)|0)|0;while(1){o=n&2047;p=f+(m<<2)|0;g[p>>2]=+g[p>>2]+k*+g[5112184+(o<<2)>>2];p=m+1|0;if((p|0)<128){m=p;n=o+l|0}else{break}}l=a+1|0;if((l|0)<(i|0)){a=l;j=j+16|0}else{break}}}else{j=0;a=h;while(1){k=+g[10208192+(c[a+4>>2]<<2)>>2];h=c[a>>2]|0;l=0;n=(c[a+12>>2]<<6)-(ca(h,b)|0)|0;while(1){m=n&2047;o=f+(l<<2)|0;g[o>>2]=+g[o>>2]+k*+g[5112184+(m<<2)>>2];o=l+1|0;if((o|0)<128){l=o;n=m+h|0}else{break}}h=j+1|0;if((h|0)<(i|0)){j=h;a=a+16|0}else{break}}}}do{if((c[d>>2]|0)!=0){a=d+8|0;j=(c[a>>2]<<2)-e|0;if(!((j-1|0)>>>0<128>>>0)){break}mrc(f|0,0,j<<2|0)|0;if((c[d+4>>2]|0)!=0){if((c[a>>2]|0)==(c[d+12>>2]|0)){break}}a=f+(j<<2)|0;g[a>>2]=+g[1487404]*+g[a>>2];a=f+(j+1<<2)|0;g[a>>2]=+g[1487436]*+g[a>>2];a=f+(j+2<<2)|0;g[a>>2]=+g[1487468]*+g[a>>2];a=f+(j+3<<2)|0;g[a>>2]=+g[1487500]*+g[a>>2]}}while(0);if((c[d+4>>2]|0)==0){return}a=4-e+(c[d+12>>2]<<2)|0;d=a-1|0;if(!(d>>>0<128>>>0)){return}e=f+(a-4<<2)|0;g[e>>2]=+g[1487500]*+g[e>>2];e=f+(a-3<<2)|0;g[e>>2]=+g[1487468]*+g[e>>2];e=f+(a-2<<2)|0;g[e>>2]=+g[1487436]*+g[e>>2];e=f+(d<<2)|0;g[e>>2]=+g[1487404]*+g[e>>2];mrc(f+(a<<2)|0,0,128-a<<2|0)|0;return}function y1(b,d,f,h,j){b=b|0;d=d|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0.0,C=0;k=i;i=i+512|0;l=k|0;if((c[b>>2]|0)==1){m=(a[b+40+j|0]|0)!=0|0}else{m=0}n=m^d;m=a[(c[552872+(j<<2)>>2]|0)+(b+72+(n*7768|0)+4500)|0]|0;if(m<<24>>24==15){i=k;return}else{o=0;p=h}while(1){g[l+(o<<2)>>2]=+g[778568+((p&1023)<<2)>>2];h=o+1|0;if((h|0)<128){o=h;p=p+1|0}else{break}}p=c[b+72+(n*7768|0)+6468>>2]|0;o=c[b+72+(n*7768|0)+6472>>2]|0;n=c[p+(j*60|0)>>2]|0;h=(n|0)>0;if(h){q=6-(c[p+(j*60|0)+4>>2]|0)+6|0}else{q=6}r=c[o+(j*60|0)>>2]|0;if((r|0)>0){s=0;t=0;while(1){u=q-(c[o+(j*60|0)+4+(t<<2)>>2]|0)|0;v=(s|0)>(u|0)?s:u;u=t+1|0;if((u|0)<(r|0)){s=v;t=u}else{w=v;break}}}else{w=0}if(h){h=w;t=0;while(1){s=6-(c[p+(j*60|0)+4+(t<<2)>>2]|0)|0;r=(h|0)>(s|0)?h:s;s=t+1|0;if((s|0)<(n|0)){h=r;t=s}else{x=r;break}}}else{x=w}y=+g[696320+((m&255)<<2)>>2]/+(1<<x|0);x=(c[552800+(j<<2)>>2]|0)+((j|0)==0?2:0)|0;m=c[552800+(j+1<<2)>>2]|0;if((x|0)<(m|0)){z=x}else{i=k;return}while(1){x=c[b+72+(d*7768|0)+20+(z<<2)>>2]|0;do{if((x|0)<1){A=z+1|0}else{B=y*(+g[1428528+(c[b+72+(d*7768|0)+148+(z<<2)>>2]<<2)>>2]*+g[1428856+(x<<2)>>2]/+(1<<x|0));j=e[1428784+(z<<1)>>1]|0;w=z+1|0;t=(e[1428784+(w<<1)>>1]|0)-j|0;if((t|0)>0){C=0}else{A=w;break}while(1){h=f+(C+j<<2)|0;g[h>>2]=+g[h>>2]+B*+g[l+(C<<2)>>2];h=C+1|0;if((h|0)<(t|0)){C=h}else{A=w;break}}}}while(0);if((A|0)<(m|0)){z=A}else{break}}i=k;return}function z1(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0.0,k=0;if((h&1|0)!=0){h=0;do{i=d+(127-h<<2)|0;j=+g[i>>2];k=d+(h<<2)|0;g[i>>2]=+g[k>>2];g[k>>2]=j;h=h+1|0;}while((h|0)<64)}ef[c[b+40>>2]&4095](b,e,d);if((f&2|0)==0){mf[c[a>>2]&2047](e,e,6282136,128)}else{mrc(e|0,0,128)|0;d=e+128|0;mf[c[a>>2]&2047](d,d,6254104,64)}d=c[a+24>>2]|0;if((f&1|0)==0){f=e+512|0;mf[d&2047](f,f,6282136,128);return}else{f=e+640|0;mf[d&2047](f,f,6254104,64);mrc(e+896|0,0,128)|0;return}}function A1(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+128|0;h=f|0;j=f+64|0;mrc(e|0,0,8192)|0;k=a+44|0;l=j|0;m=h|0;n=b+1536|0;o=0;do{g[m>>2]=+g[d+(o<<2)>>2];g[h+4>>2]=+g[d+(o+128<<2)>>2];g[h+8>>2]=+g[d+(o+256<<2)>>2];g[h+12>>2]=+g[d+(o+384<<2)>>2];g[h+16>>2]=+g[d+(o+512<<2)>>2];g[h+20>>2]=+g[d+(o+640<<2)>>2];g[h+24>>2]=+g[d+(o+768<<2)>>2];g[h+28>>2]=+g[d+(o+896<<2)>>2];g[h+32>>2]=+g[d+(o+1024<<2)>>2];g[h+36>>2]=+g[d+(o+1152<<2)>>2];g[h+40>>2]=+g[d+(o+1280<<2)>>2];g[h+44>>2]=+g[d+(o+1408<<2)>>2];g[h+48>>2]=+g[d+(o+1536<<2)>>2];g[h+52>>2]=+g[d+(o+1664<<2)>>2];g[h+56>>2]=+g[d+(o+1792<<2)>>2];g[h+60>>2]=+g[d+(o+1920<<2)>>2];ef[c[k>>2]&4095](a,l,m);g[b+(c[n>>2]<<5)>>2]=+g[j+32>>2];g[b+768+(c[n>>2]<<5)>>2]=+g[j+28>>2];p=c[n>>2]|0;g[b+(p<<5)+4>>2]=+g[j+36>>2];g[b+768+(p<<5)+4>>2]=+g[j+24>>2];g[b+(p<<5)+8>>2]=+g[j+40>>2];g[b+768+(p<<5)+8>>2]=+g[j+20>>2];g[b+(p<<5)+12>>2]=+g[j+44>>2];g[b+768+(p<<5)+12>>2]=+g[j+16>>2];g[b+(p<<5)+16>>2]=+g[j+48>>2];g[b+768+(p<<5)+16>>2]=+g[j+12>>2];g[b+(p<<5)+20>>2]=+g[j+52>>2];g[b+768+(p<<5)+20>>2]=+g[j+8>>2];g[b+(p<<5)+24>>2]=+g[j+56>>2];g[b+768+(p<<5)+24>>2]=+g[j+4>>2];g[b+(p<<5)+28>>2]=+g[j+60>>2];g[b+768+(p<<5)+28>>2]=+g[l>>2];q=o<<4;r=0;s=p;while(1){t=c[830520+(s+2<<2)>>2]|0;u=0;do{v=u+q|0;w=e+(v<<2)|0;g[w>>2]=+g[w>>2]+(+g[b+(s<<5)+(u<<2)>>2]*+g[1060888+(r<<6)+(u<<2)>>2]+ +g[b+768+(t<<5)+(u<<2)>>2]*+g[1060120+(r<<6)+(u<<2)>>2]);w=7-u|0;x=u+8|0;y=e+(v+8<<2)|0;g[y>>2]=+g[y>>2]+(+g[b+(s<<5)+(w<<2)>>2]*+g[1060888+(r<<6)+(x<<2)>>2]+ +g[b+768+(t<<5)+(w<<2)>>2]*+g[1060120+(r<<6)+(x<<2)>>2]);u=u+1|0;}while((u|0)<8);u=r+1|0;if((u|0)<12){r=u;s=c[830520+(t+2<<2)>>2]|0}else{break}}c[n>>2]=c[830520+(p<<2)>>2];o=o+1|0;}while((o|0)<128);i=f;return}function B1(a){a=a|0;var b=0;if((c[a+120>>2]&3|0)!=0){b=-22;return b|0}c[a+140>>2]=4;b=0;return b|0}function C1(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;j=c[g+24>>2]|0;k=g+28|0;g=c[k>>2]|0;l=b+124|0;m=b+120|0;n=(ca(c[m>>2]|0,c[l>>2]|0)|0)+48|0;if((g|0)!=(n|0)){KIb(b,16,2458056,(o=i,i=i+16|0,c[o>>2]=g,c[o+8>>2]=n,o)|0);i=o;p=-1094995529;i=h;return p|0}o=M4a(b,e,0)|0;if((o|0)<0){p=o;i=h;return p|0}if((c[l>>2]|0)>0){o=e+32|0;b=e+36|0;n=e+40|0;g=c[e+4>>2]|0;q=c[e+8>>2]|0;r=0;s=c[e>>2]|0;e=j+48|0;while(1){t=a[e]|0;a[g]=t&-16;a[s]=t<<4;t=a[e+1|0]|0;a[q]=t&-16;a[s+1|0]=(a[j+(t&15|16)|0]|0)+(a[s]|0);t=e+2|0;u=c[m>>2]|0;v=u>>1;if((v|0)>1){w=1;x=e;y=t;z=s;A=q;B=g;while(1){C=z+2|0;D=A+1|0;E=B+1|0;F=d[y]|0;a[E]=(a[j+(F>>>4|16)|0]|0)+(a[B]|0);a[C]=(a[j+(F&15|16)|0]|0)+(a[z+1|0]|0);F=d[x+3|0]|0;a[D]=(a[j+(F>>>4|16)|0]|0)+(a[A]|0);a[z+3|0]=(a[j+(F&15|16)|0]|0)+(a[C]|0);F=w+1|0;G=y+2|0;H=c[m>>2]|0;I=H>>1;if((F|0)<(I|0)){w=F;x=y;y=G;z=C;A=D;B=E}else{J=E;K=D;L=C;M=G;N=H;O=I;break}}}else{J=g;K=q;L=s;M=t;N=u;O=v}B=1-O|0;A=r+1|0;if((A|0)<(c[l>>2]|0)){g=J+(B+(c[b>>2]|0))|0;q=K+(B+(c[n>>2]|0))|0;r=A;s=L+(2-N+(c[o>>2]|0))|0;e=M}else{break}}}c[f>>2]=1;p=c[k>>2]|0;i=h;return p|0}function D1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=hJb(88)|0;g=f;c[e>>2]=g;do{if((f|0)==0){h=g}else{if((nZa(g,a,b)|0)==0){h=g;break}mJb(e);h=c[e>>2]|0}}while(0);i=d;return h|0}function E1(a,b){a=a|0;b=b|0;re[c[a+84>>2]&1023](a,b);return}function F1(a){a=a|0;if((a|0)==0){return}pZa(a);kJb(a);return}function G1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=hJb(112)|0;g=f;c[e>>2]=g;do{if((f|0)==0){h=g}else{if((g5(g,a,b)|0)==0){h=g;break}mJb(e);h=c[e>>2]|0}}while(0);i=d;return h|0}function H1(a,b){a=a|0;b=b|0;re[c[a+104>>2]&1023](a,b);return}function I1(a){a=a|0;if((a|0)==0){return}m5(a);kJb(a);return}function J1(a){a=a|0;var b=0;b=a+8|0;c[b>>2]=0;c[b+4>>2]=-2147483648;b=a+16|0;c[b>>2]=0;c[b+4>>2]=-2147483648;b=a+64|0;c[b>>2]=-1;c[b+4>>2]=-1;b=a+72|0;c[b>>2]=0;c[b+4>>2]=0;c[a>>2]=0;mrc(a+32|0,0,24)|0;return}function K1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;if(b>>>0>4294967279>>>0){f=-22;i=d;return f|0}g=jGb(e,b+16|0)|0;if((g|0)<0){f=g;i=d;return f|0}g=c[e>>2]|0;e=g+4|0;mrc((c[e>>2]|0)+b|0,0,16)|0;h=a+8|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=a+16|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=a+64|0;c[h>>2]=-1;c[h+4>>2]=-1;h=a+72|0;c[h>>2]=0;c[h+4>>2]=0;mrc(a+32|0,0,24)|0;c[a>>2]=g;c[a+24>>2]=c[e>>2];c[a+28>>2]=b;c[a+52>>2]=232;f=0;i=d;return f|0}function L1(a){a=a|0;KIb(0,0,2593688,(a=i,i=i+24|0,c[a>>2]=2208168,c[a+8>>2]=2458032,c[a+16>>2]=45,a)|0);i=a;Hd()}function M1(a,b){a=a|0;b=b|0;var d=0;d=a+28|0;if((c[d>>2]|0)<=(b|0)){return}c[d>>2]=b;mrc((c[a+24>>2]|0)+b|0,0,16)|0;return}function N1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=a+28|0;g=c[f>>2]|0;if(!(g>>>0<2147483632>>>0)){KIb(0,0,2593688,(h=i,i=i+24|0,c[h>>2]=2613800,c[h+8>>2]=2458032,c[h+16>>2]=114,h)|0);i=h;Hd();return 0}if((g|0)==0){c[e>>2]=0;if(b>>>0>4294967279>>>0){j=-22;i=d;return j|0}h=jGb(e,b+16|0)|0;if((h|0)<0){j=h;i=d;return j|0}h=c[e>>2]|0;e=h+4|0;mrc((c[e>>2]|0)+b|0,0,16)|0;k=a+8|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=a+16|0;c[k>>2]=0;c[k+4>>2]=-2147483648;k=a+64|0;c[k>>2]=-1;c[k+4>>2]=-1;k=a+72|0;c[k>>2]=0;c[k+4>>2]=0;mrc(a+32|0,0,24)|0;c[a>>2]=h;c[a+24>>2]=c[e>>2];c[f>>2]=b;c[a+52>>2]=232;j=0;i=d;return j|0}if((2147483631-g|0)>>>0<b>>>0){j=-1;i=d;return j|0}e=b+16+g|0;g=a|0;do{if((c[g>>2]|0)==0){h=cGb(e)|0;c[g>>2]=h;if((h|0)==0){j=-12;i=d;return j|0}else{k=a+24|0;nrc(c[h+4>>2]|0,c[k>>2]|0,(c[f>>2]|0)+((b|0)<0?b:0)|0)|0;c[a+52>>2]=232;l=k;break}}else{k=jGb(g,e)|0;if((k|0)<0){j=k;i=d;return j|0}else{l=a+24|0;break}}}while(0);a=c[(c[g>>2]|0)+4>>2]|0;c[l>>2]=a;l=(c[f>>2]|0)+b|0;c[f>>2]=l;mrc(a+l|0,0,16)|0;j=0;i=d;return j|0}function O1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b+44|0;e=c[d>>2]|0;a:do{if((e|0)==0){f=0}else{g=hJb(e*12|0)|0;b:do{if((g|0)!=0){h=b+40|0;i=c[d>>2]|0;j=i*12|0;nrc(g|0,c[h>>2]|0,j)|0;k=a+40|0;c[k>>2]=g;if((b|0)!=(a|0)){mrc(g|0,0,j|0)|0}if((i|0)<=0){f=i;break a}i=0;j=c[h>>2]|0;while(1){l=c[j+(i*12|0)+4>>2]|0;if(l>>>0>4294967279>>>0){break b}m=hJb(l+16|0)|0;if((m|0)==0){break b}l=c[h>>2]|0;n=l+(i*12|0)+4|0;nrc(m|0,c[l+(i*12|0)>>2]|0,c[n>>2]|0)|0;mrc(m+(c[n>>2]|0)|0,0,16)|0;c[(c[k>>2]|0)+(i*12|0)>>2]=m;m=c[h>>2]|0;n=c[k>>2]|0;c[n+(i*12|0)+4>>2]=c[m+(i*12|0)+4>>2];c[n+(i*12|0)+8>>2]=c[m+(i*12|0)+8>>2];n=i+1|0;l=c[d>>2]|0;if((n|0)<(l|0)){i=n;j=m}else{f=l;break a}}}}while(0);if((a|0)==0){o=-12;return o|0}g=a|0;do{if((c[g>>2]|0)==0){j=a+52|0;i=c[j>>2]|0;if((i|0)==0){p=j;break}qe[i&1023](a);p=j}else{fGb(g);p=a+52|0}}while(0);c[p>>2]=0;c[a+24>>2]=0;c[a+28>>2]=0;g=a+44|0;j=a+40|0;if((c[g>>2]|0)>0){i=0;do{kJb(c[(c[j>>2]|0)+(i*12|0)>>2]|0);i=i+1|0;}while((i|0)<(c[g>>2]|0))}mJb(j);c[g>>2]=0;o=-12;return o|0}}while(0);c[a+44>>2]=f;o=0;return o|0}function P1(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){return}b=a|0;do{if((c[b>>2]|0)==0){d=a+52|0;e=c[d>>2]|0;if((e|0)==0){f=d;break}qe[e&1023](a);f=d}else{fGb(b);f=a+52|0}}while(0);c[f>>2]=0;c[a+24>>2]=0;c[a+28>>2]=0;f=a+44|0;b=a+40|0;if((c[f>>2]|0)>0){a=0;do{kJb(c[(c[b>>2]|0)+(a*12|0)>>2]|0);a=a+1|0;}while((a|0)<(c[f>>2]|0))}mJb(b);c[f>>2]=0;return}function Q1(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+80|0;d=b|0;do{if((c[a>>2]|0)==0){if((c[a+24>>2]|0)==0){e=0;break}if((c[a+52>>2]|0)!=0){e=0;break}nrc(d|0,a|0,80)|0;e=R1(a,d,1)|0}else{e=0}}while(0);i=b;return e|0}function R1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=a+24|0;c[e>>2]=0;f=a+40|0;c[f>>2]=0;g=a|0;a:do{if((c[g>>2]|0)==0){h=a+28|0;i=c[h>>2]|0;do{if(i>>>0>4294967279>>>0){j=0}else{jGb(g,i+16|0)|0;k=c[g>>2]|0;if((k|0)==0){j=0;break}l=c[k+4>>2]|0;if((l|0)==0){j=k;break}nrc(l|0,c[b+24>>2]|0,c[h>>2]|0)|0;mrc(l+(c[h>>2]|0)|0,0,16)|0;m=l;break a}}while(0);if((a|0)==0){n=-12;return n|0}do{if((j|0)==0){i=a+52|0;l=c[i>>2]|0;if((l|0)==0){o=i;break}qe[l&1023](a);o=i}else{fGb(g);o=a+52|0}}while(0);c[o>>2]=0;c[e>>2]=0;c[h>>2]=0;i=a+44|0;if((c[i>>2]|0)>0){l=0;do{kJb(c[(c[f>>2]|0)+(l*12|0)>>2]|0);l=l+1|0;}while((l|0)<(c[i>>2]|0))}mJb(f);c[i>>2]=0;n=-12;return n|0}else{l=eGb(c[b>>2]|0)|0;if((l|0)==0){n=-12;return n|0}else{c[g>>2]=l;m=c[l+4>>2]|0;break}}}while(0);c[e>>2]=m;c[a+52>>2]=232;m=c[a+44>>2]|0;e=(d|0)==0;if(!((m|0)==0|e)){c[f>>2]=c[b+40>>2]}if(!((m|0)!=0&e)){n=0;return n|0}n=O1(a,b)|0;return n|0}function S1(a,b){a=a|0;b=b|0;nrc(a|0,b|0,80)|0;return R1(a,b,0)|0}function T1(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+44|0;d=a+40|0;if((c[b>>2]|0)>0){e=0}else{f=d;mJb(f);c[b>>2]=0;return}do{kJb(c[(c[d>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while((e|0)<(c[b>>2]|0));f=d;mJb(f);c[b>>2]=0;return}function U1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+44|0;f=c[e>>2]|0;if((f+1|0)>>>0>178956970>>>0|d>>>0>2147483631>>>0){g=0;return g|0}h=a+40|0;a=iJb(c[h>>2]|0,(f*12|0)+12|0)|0;c[h>>2]=a;if((a|0)==0){g=0;return g|0}a=pJb(d+16|0)|0;c[(c[h>>2]|0)+(f*12|0)>>2]=a;a=c[h>>2]|0;h=c[a+(f*12|0)>>2]|0;if((h|0)==0){g=0;return g|0}c[a+(f*12|0)+4>>2]=d;c[a+(f*12|0)+8>>2]=b;c[e>>2]=(c[e>>2]|0)+1;g=h;return g|0}function V1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[a+44>>2]|0;f=a+40|0;a=0;while(1){if((a|0)>=(e|0)){g=0;h=7;break}i=c[f>>2]|0;if((c[i+(a*12|0)+8>>2]|0)==(b|0)){break}else{a=a+1|0}}if((h|0)==7){return g|0}if((d|0)!=0){c[d>>2]=c[i+(a*12|0)+4>>2]}g=c[i+(a*12|0)>>2]|0;return g|0}function W1(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+80|0;e=d|0;f=b+44|0;if((c[f>>2]|0)==0){g=0;i=d;return g|0}h=b+28|0;j=c[h>>2]|0;k=wrc(j,(j|0)<0|0?-1:0,24,0)|0;j=G;nrc(e|0,b|0,80)|0;l=e+44|0;m=c[l>>2]|0;if((m|0)>0){n=c[e+40>>2]|0;o=0;p=j;q=k;while(1){r=c[n+(o*12|0)+4>>2]|0;s=wrc(q,p,5,0)|0;t=wrc(s,G,r,(r|0)<0|0?-1:0)|0;r=G;s=o+1|0;if((s|0)<(m|0)){o=s;p=r;q=t}else{u=r;v=t;break}}}else{u=j;v=k}k=0;if(u>>>0>k>>>0|u>>>0==k>>>0&v>>>0>2147483647>>>0){g=-22;i=d;return g|0}k=cGb(v)|0;if((k|0)==0){g=-12;i=d;return g|0}c[b>>2]=k;j=c[k+4>>2]|0;k=b+24|0;c[k>>2]=j;c[b+52>>2]=232;q=wrc(v,u,-16,0)|0;c[h>>2]=q;q=e+24|0;u=e+28|0;v=c[u>>2]|0;nrc(j|0,c[q>>2]|0,v)|0;p=j+v|0;v=c[l>>2]|0;if((v|0)>0){j=e+40|0;o=p;m=v;while(1){v=m-1|0;n=c[j>>2]|0;t=c[n+(v*12|0)+4>>2]|0;nrc(o|0,c[n+(v*12|0)>>2]|0,t)|0;n=o+t|0;y=je(c[(c[j>>2]|0)+(v*12|0)+4>>2]|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+(t+5)|0;a[o+(t+4)|0]=((v|0)==((c[l>>2]|0)-1|0))<<7|c[(c[j>>2]|0)+(v*12|0)+8>>2];if((v|0)>0){o=n;m=v}else{w=n;break}}}else{w=p}p=w;m=p|0;y=278744460;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=p+4|0;y=-18274930;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=w+8|0;if((m-(c[k>>2]|0)|0)!=(c[h>>2]|0)){KIb(0,0,2593688,(h=i,i=i+24|0,c[h>>2]=2368e3,c[h+8>>2]=2458032,c[h+16>>2]=371,h)|0);i=h;Hd();return 0}mrc(m|0,0,16)|0;m=e|0;do{if((c[m>>2]|0)==0){h=e+52|0;k=c[h>>2]|0;if((k|0)==0){x=h;break}qe[k&1023](e);x=h}else{fGb(m);x=e+52|0}}while(0);c[x>>2]=0;c[q>>2]=0;c[u>>2]=0;u=e+40|0;if((c[l>>2]|0)>0){e=0;do{kJb(c[(c[u>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while((e|0)<(c[l>>2]|0))}mJb(u);c[l>>2]=0;c[f>>2]=0;c[b+40>>2]=0;g=1;i=d;return g|0}function X1(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=b+44|0;if((c[f>>2]|0)!=0){g=0;i=e;return g|0}h=b+28|0;j=c[h>>2]|0;if((j|0)<=12){g=0;i=e;return g|0}k=b+24|0;l=c[k>>2]|0;m=l+(j-8)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;if(!((je(m|0)|0)==(-1910117890|0)&(o|0)==(-1941070576|0))){g=0;i=e;return g|0}o=l+(j-13)|0;j=o;m=je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;if((m|0)<0){g=0;i=e;return g|0}j=l;l=1;n=o;o=m;while(1){if((n-j|0)>>>0<o>>>0){g=0;p=18;break}if((a[n+4|0]|0)<0){p=9;break}m=n+(-5-o)|0;q=m;r=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;if((r|0)<0){g=0;p=18;break}else{l=l+1|0;n=m;o=r}}if((p|0)==9){o=hJb(l*12|0)|0;l=b+40|0;c[l>>2]=o;if((o|0)==0){g=-12;i=e;return g|0}o=c[k>>2]|0;b=o+((c[h>>2]|0)-13)|0;n=b;j=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;if((j|0)>-1){s=0;t=b;u=j;v=o}else{KIb(0,0,2593688,(w=i,i=i+24|0,c[w>>2]=2302296,c[w+8>>2]=2458032,c[w+16>>2]=404,w)|0);i=w;Hd();return 0}while(1){if((t-v|0)>>>0<u>>>0){p=12;break}o=pJb(u+16|0)|0;c[(c[l>>2]|0)+(s*12|0)>>2]=o;o=c[l>>2]|0;c[o+(s*12|0)+4>>2]=u;j=t+4|0;c[o+(s*12|0)+8>>2]=a[j]&127;b=c[o+(s*12|0)>>2]|0;if((b|0)==0){g=-12;p=18;break}nrc(b|0,t+(-u|0)|0,u)|0;x=-5-u+(c[h>>2]|0)|0;c[h>>2]=x;if((a[j]|0)<0){p=17;break}j=t+(-5-u)|0;b=j;o=je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;if(!((o|0)>-1)){p=12;break}s=s+1|0;t=j;u=o;v=c[k>>2]|0}if((p|0)==12){KIb(0,0,2593688,(w=i,i=i+24|0,c[w>>2]=2302296,c[w+8>>2]=2458032,c[w+16>>2]=404,w)|0);i=w;Hd();return 0}else if((p|0)==17){c[h>>2]=x-8;c[f>>2]=s+1;g=1;i=e;return g|0}else if((p|0)==18){i=e;return g|0}}else if((p|0)==18){i=e;return g|0}return 0}function Y1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;c[b>>2]=0;if((a|0)==0){f=0;i=d;return f|0}g=LGb(a,10230200,0,2)|0;if((g|0)==0){f=0;i=d;return f|0}else{h=g;j=0}while(1){g=h|0;k=lrc(c[g>>2]|0)|0;l=h+4|0;m=lrc(c[l>>2]|0)|0;n=k+2+m+(c[b>>2]|0)|0;o=iJb(j,n)|0;if((o|0)==0){break}c[e>>2]=o;if((n|0)<0){break}p=k+1|0;nrc(o+(c[b>>2]|0)|0,c[g>>2]|0,p)|0;nrc((c[e>>2]|0)+(p+(c[b>>2]|0))|0,c[l>>2]|0,m+1|0)|0;c[b>>2]=n;n=LGb(a,10230200,h,2)|0;m=c[e>>2]|0;if((n|0)==0){f=m;q=7;break}else{h=n;j=m}}if((q|0)==7){i=d;return f|0}mJb(e);c[b>>2]=0;f=0;i=d;return f|0}function Z1(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+c|0;if(!((b|0)!=0&(d|0)!=0&(c|0)!=0)){f=0;return f|0}if((a[b+(c-1)|0]|0)!=0){f=-1094995529;return f|0}if((c|0)>0){g=b}else{f=0;return f|0}while(1){b=lrc(g|0)|0;c=g+(b+1)|0;if(!(c>>>0<e>>>0)){f=-1094995529;h=7;break}i=MGb(d,g,c,0)|0;if((i|0)<0){f=i;h=7;break}j=g+(b+2+(lrc(c|0)|0))|0;if(j>>>0<e>>>0){g=j}else{f=i;h=7;break}}if((h|0)==7){return f|0}return 0}function _1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[a+44>>2]|0;f=a+40|0;a=0;while(1){if((a|0)>=(e|0)){g=-2;h=6;break}i=c[f>>2]|0;if((c[i+(a*12|0)+8>>2]|0)==(b|0)){break}else{a=a+1|0}}if((h|0)==6){return g|0}h=i+(a*12|0)+4|0;if((c[h>>2]|0)<(d|0)){g=-12;return g|0}c[h>>2]=d;g=0;return g|0}function $1(a){a=a|0;var b=0,d=0,e=0;b=a+44|0;d=a+40|0;if((c[b>>2]|0)>0){e=0;do{kJb(c[(c[d>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while((e|0)<(c[b>>2]|0))}mJb(d);c[b>>2]=0;b=a|0;fGb(b);d=a+8|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+16|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+64|0;c[d>>2]=-1;c[d+4>>2]=-1;d=a+72|0;c[d>>2]=0;c[d+4>>2]=0;c[b>>2]=0;mrc(a+24|0,0,32)|0;return}function a2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return wIb(a|0,a+32|0,b,c,d,e,1)|0}function b2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return yIb(e,f,a|0,a+32|0,b,c,d,1)|0}function c2(a,b,c){a=a|0;b=b|0;c=c|0;return xIb(a,b,c,1)|0}function d2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=sIb(a|0,a+32|0,c,d,b,1)|0;if((e|0)>=0){f=0;return f|0}mrc(a|0,0,64)|0;f=e;return f|0}function e2(a){a=a|0;kJb(c[a>>2]|0);return}function f2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;vIb(a|0,a+32|0,b|0,b+32|0,c,d,e);return}function g2(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[b+60>>2]|0;g=b+100|0;do{if((c[g>>2]|0)<31){c[f+3008>>2]=1}else{h=(grc((c[b+96>>2]|0)+28|0,2367992,3)|0)!=0;c[f+3008>>2]=h&1;do{if(!h){if((c[b+800>>2]|0)==0){break}KIb(b,16,2302256,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=e;return k|0}}while(0);if(h){break}j=tIb(c[b+120>>2]|0,c[b+124>>2]|0,0,b)|0;if((j|0)<0){k=j;i=e;return k|0}c[b+140>>2]=17;j=c[g>>2]|0;if((j|0)<=8){k=0;i=e;return k|0}l=c[b+96>>2]|0;m=d[l+4|0]|0;n=m+28|0;if((n|0)>=(j|0)){k=0;i=e;return k|0}j=(grc(l+(m+4)|0,2250824,4)|0)==0;c[f+3012>>2]=j&1;if(!j){k=0;i=e;return k|0}c[f+3016>>2]=(a[l+n|0]|0)==1;k=0;i=e;return k|0}}while(0);k=gQa(b)|0;i=e;return k|0}function h2(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=c[a+60>>2]|0;h=c[e+24>>2]|0;j=c[e+28>>2]|0;if((c[g+3008>>2]|0)!=0){k=nQa(a,b,d,e)|0;i=f;return k|0}e=a+120|0;l=c[e>>2]<<1;m=(j|0)/(l|0)|0;n=a+124|0;if((j|0)<(ca(c[n>>2]|0,l)|0)){KIb(a,16,2457960,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;k=-1094995529;i=f;return k|0}l=M4a(a,b,0)|0;if((l|0)<0){k=l;i=f;return k|0}c[b+88>>2]=1;c[b+84>>2]=1;l=c[n>>2]|0;a=c[e>>2]|0;o=ca(m-l|0,a)|0;do{if((c[g+3012>>2]|0)==0){if((l|0)<=0){break}p=b;q=b+32|0;r=0;s=h+(o<<1)|0;t=a;while(1){nrc((c[p>>2]|0)+(ca(c[q>>2]|0,r)|0)|0,s|0,t<<1)|0;u=c[e>>2]|0;v=r+1|0;if((v|0)<(c[n>>2]|0)){r=v;s=s+(u<<1)|0;t=u}else{break}}}else{if((l-1|0)<=0){break}t=b;s=g+3016|0;r=b+32|0;q=0;p=h+o|0;u=a;while(1){nrc((c[t>>2]|0)+(ca((c[s>>2]|0)+q|0,c[r>>2]|0)|0)|0,p|0,u<<1)|0;v=(c[t>>2]|0)+(ca((c[s>>2]|0)==0|q,c[r>>2]|0)|0)|0;w=c[e>>2]|0;nrc(v|0,p+((ca(w,m)|0)+4)|0,w<<1)|0;w=c[e>>2]|0;v=q+2|0;if((v|0)<((c[n>>2]|0)-1|0)){q=v;p=p+(w<<1)|0;u=w}else{break}}}}while(0);c[d>>2]=1;k=j;i=f;return k|0}function i2(a){a=a|0;if((c[(c[a+60>>2]|0)+3008>>2]|0)==0){return 0}oQa(a)|0;return 0}function j2(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=UHb()|0;c[b>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+140>>2]=11;H4a(a,318,198)|0;e=0;return e|0}function k2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;h=c[g+24>>2]|0;i=c[g+28>>2]|0;g=e;e=c[c[b+60>>2]>>2]|0;j=N4a(b,e)|0;if((j|0)<0){k=j;return k|0}j=e+88|0;c[j>>2]=2;b=e+84|0;c[b>>2]=0;l=c[e>>2]|0;m=c[e+32>>2]|0;n=h+i|0;if((i|0)<4){k=-1094995529;return k|0}o=d[h]|0;p=a[h+1|0]|0;q=h+4|0;if(p<<24>>24==3){r=c[e+4>>2]|0;s=q;t=(d[s]|d[s+1|0]<<8)<<16>>16;s=t&65535;u=h+6|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;u=v&65535;w=u+s|0;if((t&65535)>>>0>255>>>0|(w|0)>256){k=-1094995529;return k|0}if((i-4|0)<((u*3|0)+8|0)){k=-1094995529;return k|0}u=h+8|0;t=d[u]|0;if(v<<16>>16==0){x=u;y=t}else{v=s+1|0;z=(((w|0)>(v|0)?w:v)*3|0)+8+(s*-3|0)|0;v=s;s=u;u=t;do{t=(d[s+1|0]|0)<<10|u<<18|(d[s+2|0]|0)<<2;c[r+(v<<2)>>2]=t|t>>>6&197379|-16777216;v=v+1|0;s=s+3|0;u=d[s]|0}while((v|0)<(w|0));x=h+z|0;y=u}A=x+4|0;B=a[x+1|0]|0;C=y}else{A=q;B=p;C=o}if(!(B<<24>>24==1)){k=-1094995529;return k|0}if((C|0)==0){c[j>>2]=1;c[b>>2]=1;D=3;E=3}else if((C|0)==3){D=3;E=2}else if((C|0)==2){D=2;E=2}else if((C|0)==1){D=3;E=3}else{k=-1094995529;return k|0}b=ca(E<<8,D)|0;if((n-A|0)<(b|0)){k=-1094995529;return k|0}j=A+b|0;B=(C|0)!=0;do{if(B){o=ca(((318/(E>>>0)|0)+7|0)>>>3,198/(D>>>0)|0)|0;if((n-j|0)<(o|0)){k=-1094995529;return k|0}else{p=o<<3;q=p>>>0>2147483639>>>0|(j|0)==0;F=A+(o+b)|0;G=q?0:j;H=q?8:p+8|0;break}}else{F=j;G=0;H=0}}while(0);j=(C|0)==0;C=ca(D,E)|0;b=(D|0)==3;p=E<<1;q=0;o=0;y=F;a:while(1){F=ca(o,m)|0;x=ca(o+1|0,m)|0;u=ca(o+2|0,m)|0;if(j){z=0;h=y;while(1){if((n-h|0)<1){k=-1094995529;I=39;break a}w=h+1|0;v=ca(C,d[h]|0)|0;s=z+F|0;r=v+E|0;t=z+x|0;J=v+p|0;K=z+u|0;if(b){L=0;do{a[l+(s+L)|0]=a[A+(L+v)|0]|0;a[l+(t+L)|0]=a[A+(r+L)|0]|0;a[l+(K+L)|0]=a[A+(J+L)|0]|0;L=L+1|0;}while((L|0)<(E|0))}else{L=0;do{a[l+(s+L)|0]=a[A+(L+v)|0]|0;a[l+(t+L)|0]=a[A+(r+L)|0]|0;L=L+1|0;}while((L|0)<(E|0))}L=z+E|0;if((L|0)<318){z=L;h=w}else{M=q;N=w;break}}}else{h=q;z=0;L=y;while(1){r=((h|0)<(H|0))+h|0;if(((d[G+(h>>>3)|0]|0)&128>>>((h&7)>>>0)|0)==0){O=L}else{if((n-L|0)<1){k=-1094995529;I=39;break a}t=L+1|0;v=ca(C,d[L]|0)|0;s=z+F|0;J=v+E|0;K=z+x|0;P=v+p|0;Q=z+u|0;if(b){R=0;while(1){a[l+(s+R)|0]=a[A+(R+v)|0]|0;a[l+(K+R)|0]=a[A+(J+R)|0]|0;a[l+(Q+R)|0]=a[A+(P+R)|0]|0;S=R+1|0;if((S|0)<(E|0)){R=S}else{O=t;break}}}else{R=0;while(1){a[l+(s+R)|0]=a[A+(R+v)|0]|0;a[l+(K+R)|0]=a[A+(J+R)|0]|0;P=R+1|0;if((P|0)<(E|0)){R=P}else{O=t;break}}}}t=z+E|0;if((t|0)<318){h=r;z=t;L=O}else{M=r;N=O;break}}}do{if(B){L=-M&7;if((L|0)==0){T=M;break}z=L+M|0;T=H>>>0>z>>>0?z:H}else{T=M}}while(0);z=o+D|0;if((z|0)<198){q=T;o=z;y=N}else{I=37;break}}if((I|0)==37){N=YHb(g,e)|0;if((N|0)<0){k=N;return k|0}c[f>>2]=1;k=i;return k|0}else if((I|0)==39){return k|0}return 0}function l2(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function m2(a){a=a|0;c[a+140>>2]=300;return 0}function n2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;h=i;j=e;k=c[g+24>>2]|0;l=c[b+100>>2]|0;a:do{if(l>>>0>23>>>0){m=c[b+96>>2]|0;n=l;while(1){o=m;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=je(p|0)|0;if((grc(m+4|0,2457888,12)|0)==0){break}if((p|0)==0|o>>>0>n>>>0){q=1;break a}p=n-o|0;if(p>>>0>23>>>0){m=m+o|0;n=p}else{q=1;break a}}q=(a[m+19|0]|0)!=1|0}else{q=1}}while(0);l=b+124|0;n=c[l>>2]|0;p=(n|0)==486?10:16;o=b+120|0;r=(ca(c[o>>2]<<1,p+n|0)|0)+(q<<2)|0;n=g+28|0;g=c[n>>2]|0;if((g|0)<(r|0)){KIb(b,16,2367840,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-22;i=h;return t|0}if((c[b+792>>2]|0)==32){u=(g|0)>=((r<<1)+4|0)}else{u=0}g=r+5|0;r=M4a(b,j,0)|0;if((r|0)<0){t=r;i=h;return t|0}c[e+84>>2]=1;c[e+88>>2]=1;r=(q|0)!=0;j=c[o>>2]|0;if(r){v=k;w=g}else{b=ca(j,p)|0;v=k+b|0;w=b+g|0}g=q+1|0;b=e;s=e+32|0;x=e+4|0;y=e+36|0;z=e+8|0;A=e+40|0;B=e+12|0;C=e+44|0;e=k+w|0;w=v;v=0;k=j;while(1){j=ca(k,p)|0;D=w+j|0;E=e+j|0;j=c[l>>2]|0;if(r&(j|0)==486){F=1-v|0;G=c[s>>2]|0;H=ca(G,F)|0;I=c[y>>2]|0;J=(c[x>>2]|0)+(ca(I,F)|0)|0;K=c[A>>2]|0;L=(c[z>>2]|0)+(ca(K,F)|0)|0;M=c[C>>2]|0;N=(c[B>>2]|0)+(ca(M,F)|0)|0;O=L;P=J;Q=H;R=486;S=G;T=I;U=K;V=M}else{M=c[s>>2]|0;K=ca(M,v)|0;I=c[y>>2]|0;G=(c[x>>2]|0)+(ca(I,v)|0)|0;H=c[A>>2]|0;J=(c[z>>2]|0)+(ca(H,v)|0)|0;L=c[C>>2]|0;N=(c[B>>2]|0)+(ca(L,v)|0)|0;O=J;P=G;Q=K;R=j;S=M;T=I;U=H;V=L}if((R>>q|0)>0){L=E;H=(c[b>>2]|0)+Q|0;I=P;M=O;j=N;K=D;G=0;J=k;F=S;W=T;X=U;Y=V;Z=R;while(1){if((J>>1|0)>0){if(u){_=L;$=K;aa=0;while(1){a[I+aa|0]=a[$]|0;ba=aa<<1;a[H+ba|0]=a[$+1|0]|0;a[j+ba|0]=~a[_];a[M+aa|0]=a[$+2|0]|0;da=$+4|0;ea=ba|1;a[H+ea|0]=a[$+3|0]|0;a[j+ea|0]=~a[_+2|0];ea=_+4|0;ba=aa+1|0;fa=c[o>>2]|0;if((ba|0)<(fa>>1|0)){_=ea;$=da;aa=ba}else{ga=ea;ha=da;ia=fa;break}}}else{aa=L;$=K;_=0;while(1){a[I+_|0]=a[$]|0;fa=_<<1;a[H+fa|0]=a[$+1|0]|0;a[j+fa|0]=-1;a[M+_|0]=a[$+2|0]|0;da=$+4|0;ea=fa|1;a[H+ea|0]=a[$+3|0]|0;a[j+ea|0]=-1;ea=aa+2|0;fa=_+1|0;ba=c[o>>2]|0;if((fa|0)<(ba>>1|0)){aa=ea;$=da;_=fa}else{ga=ea;ha=da;ia=ba;break}}}ja=ga;ka=ha;la=ia;ma=c[s>>2]|0;na=c[y>>2]|0;oa=c[A>>2]|0;pa=c[C>>2]|0;qa=c[l>>2]|0}else{ja=L;ka=K;la=J;ma=F;na=W;oa=X;pa=Y;qa=Z}_=H+(ca(ma,g)|0)|0;$=I+(ca(na,g)|0)|0;aa=M+(ca(oa,g)|0)|0;ba=j+(ca(pa,g)|0)|0;da=G+1|0;if((da|0)<(qa>>q|0)){L=ja;H=_;I=$;M=aa;j=ba;K=ka;G=da;J=la;F=ma;W=na;X=oa;Y=pa;Z=qa}else{ra=ja;sa=ka;ta=la;break}}}else{ra=E;sa=D;ta=k}Z=v+1|0;if((Z|0)<(g|0)){e=ra+4|0;w=sa+4|0;v=Z;k=ta}else{break}}c[f>>2]=1;t=c[n>>2]|0;i=h;return t|0}function o2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=UHb()|0;c[b+804>>2]=e;do{if((c[b+120>>2]|0)==720){f=c[b+124>>2]|0;if(!((f|0)==486|(f|0)==576)){break}if((e|0)==0){KIb(b,16,2367808,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-12;i=d;return h|0}f=pJb(40)|0;c[b+96>>2]=f;if((f|0)==0){h=-12;i=d;return h|0}c[b+100>>2]=24;nrc(f|0,2302176,16)|0;a[f+19|0]=(c[b+408>>2]|0)>>>0>1>>>0?2:1;h=0;i=d;return h|0}}while(0);KIb(b,16,2457840,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=d;return h|0}function p2(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d|0;g=(c[a+408>>2]|0)>>>0>1>>>0;h=g&1;i=a+124|0;j=c[i>>2]|0;k=(j|0)==486?10:16;l=a+120|0;m=(ca(c[l>>2]<<1,k+j|0)|0)+(h<<3)|0;j=d5a(a,b,m,(m|0)<0|0?-1:0)|0;if((j|0)<0){n=j;return n|0}j=c[b+24>>2]|0;if(g){o=j}else{o=j+(ca(c[l>>2]|0,k)|0)|0}j=c[a+804>>2]|0;c[j+84>>2]=1;c[j+88>>2]=1;j=d+32|0;d=g?2:1;if(g){g=0;a=o;while(1){m=c[i>>2]|0;p=c[f>>2]|0;if((m|0)==486){q=p+(ca(c[j>>2]|0,1-g|0)|0)|0;r=c[l>>2]|0;s=0;t=q;u=a+((ca(r,k)|0)+(g<<2))|0;v=r;w=9}else{r=p+(ca(c[j>>2]|0,g)|0)|0;p=c[l>>2]|0;q=a+((ca(p,k)|0)+(g<<2))|0;if((m|0)>0){s=0;t=r;u=q;v=p;w=9}else{x=q}}if((w|0)==9){while(1){w=0;nrc(u|0,t|0,v<<1)|0;q=t+(ca(c[j>>2]|0,d)|0)|0;p=c[l>>2]|0;r=u+(p<<1)|0;m=s+d|0;if((m|0)<(c[i>>2]|0)){s=m;t=q;u=r;v=p;w=9}else{x=r;break}}}r=g+1|0;if((r|0)>(h|0)){break}else{g=r;a=x}}}else{x=0;a=o;while(1){o=(c[f>>2]|0)+(ca(c[j>>2]|0,x)|0)|0;g=c[l>>2]|0;w=a+((ca(g,k)|0)+(x<<2))|0;if((c[i>>2]|0)>0){v=0;u=o;o=w;t=g;while(1){nrc(o|0,u|0,t<<1)|0;g=u+(ca(c[j>>2]|0,d)|0)|0;s=c[l>>2]|0;r=o+(s<<1)|0;p=v+d|0;if((p|0)<(c[i>>2]|0)){v=p;u=g;o=r;t=s}else{y=r;break}}}else{y=w}t=x+1|0;if((t|0)>(h|0)){break}else{x=t;a=y}}}y=b+36|0;c[y>>2]=c[y>>2]|1;c[e>>2]=1;n=0;return n|0}function q2(a){a=a|0;mJb(a+804|0);return 0}function r2(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[a+140>>2]=11;a=UHb()|0;c[b>>2]=a;return((a|0)==0?-12:0)|0}function s2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;h=i;j=c[b+60>>2]|0;k=b+120|0;l=c[k>>2]|0;m=j;n=N4a(b,c[m>>2]|0)|0;if((n|0)<0){o=n;i=h;return o|0}n=c[m>>2]|0;p=n+32|0;q=(c[p>>2]|0)-(c[k>>2]|0)|0;do{if((c[g+44>>2]|0)>0){r=c[g+40>>2]|0;if((c[r+8>>2]|0)!=0){break}s=c[r>>2]|0;t=c[r+4>>2]|0;if(!((t|0)>-1)){KIb(0,0,2367776,(u=i,i=i+24|0,c[u>>2]=2302160,c[u+8>>2]=2250728,c[u+16>>2]=135,u)|0);i=u;Hd();return 0}r=j+4|0;c[r>>2]=s;c[j+12>>2]=s;c[j+8>>2]=s+t;v=c[n+4>>2]|0;if(t>>>0<768>>>0){o=-1094995529;i=h;return o|0}else{w=0;x=s}while(1){s=x+3|0;c[r>>2]=s;t=d[x+1|0]<<8|d[x]<<16|d[x+2|0];c[v+(w<<2)>>2]=t<<2|t>>>4&197379|-16777216;t=w+1|0;if((t|0)<256){w=t;x=s}else{break}}c[n+304>>2]=1}}while(0);x=c[g+24>>2]|0;w=g+28|0;g=c[w>>2]|0;if(!((g|0)>-1)){KIb(0,0,2367776,(u=i,i=i+24|0,c[u>>2]=2302160,c[u+8>>2]=2250728,c[u+16>>2]=135,u)|0);i=u;Hd();return 0}v=j+4|0;c[v>>2]=x;c[j+12>>2]=x;r=x+g|0;s=j+8|0;c[s>>2]=r;j=c[n>>2]|0;t=c[p>>2]|0;p=c[b+124>>2]|0;y=j+(ca(p,t)|0)|0;z=r;r=x;do{if((g|0)<1){A=j;B=0;C=x}else{D=x+1|0;c[v>>2]=D;E=a[x]|0;if((E|0)==4){if((z-D|0)<2){F=0;G=D}else{H=x+3|0;c[v>>2]=H;I=D;F=(d[I]|d[I+1|0]<<8)<<16>>16&65535;G=H}if((F|0)<(p|0)){A=j+(ca(t,F)|0)|0;B=4;C=G;break}else{o=-1094995529;i=h;return o|0}}else if((E|0)!=2){A=j;B=E;C=D;break}c[f>>2]=0;E=c[n+4>>2]|0;if((z-D|0)>>>0<768>>>0){KIb(b,16,2457816,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;o=-1094995529;i=h;return o|0}else{J=0;K=D}while(1){L=K+3|0;c[v>>2]=L;D=d[K+1|0]<<8|d[K]<<16|d[K+2|0];c[E+(J<<2)>>2]=D<<2|D>>>4&197379|-16777216;D=J+1|0;if((D|0)<256){J=D;K=L}else{break}}c[n+304>>2]=1;o=L-r|0;i=h;return o|0}}while(0);a:do{if((z-C|0)>=1){r=(B|0)==3;L=l;n=A;K=C;while(1){J=K+1|0;c[v>>2]=J;u=a[K]|0;if(u<<24>>24==0){break a}b=u&127;j=u<<24>>24>-1;b:do{if(j){if(r){u=b;G=n;F=L;t=J;while(1){if((u|0)<=(F|0)){M=F;N=G;O=u;break b}p=(c[s>>2]|0)-t|0;x=p>>>0>F>>>0?F:p;nrc(G|0,t|0,x)|0;p=(c[v>>2]|0)+x|0;c[v>>2]=p;x=G+(q+F)|0;if((x|0)==(y|0)){break a}else{u=u-F|0;G=x;F=c[k>>2]|0;t=p}}}else{t=b;F=n;G=L;u=J;while(1){if((t|0)<=(G|0)){M=G;N=F;O=t;break b}p=(c[s>>2]|0)-u|0;x=p>>>0>G>>>0?G:p;nrc(F|0,u|0,x)|0;p=(c[v>>2]|0)+x|0;c[v>>2]=p;x=F+(q+G)|0;if((x|0)==(y|0)){break a}else{t=t-G|0;F=x;G=c[k>>2]|0;u=p}}}}else{if(r){P=b;Q=n;R=L}else{u=b;G=n;F=L;while(1){if((u|0)<=(F|0)){M=F;N=G;O=u;break b}t=G+(q+F)|0;if((t|0)==(y|0)){break a}else{u=u-F|0;G=t;F=c[k>>2]|0}}}while(1){if((P|0)<=(R|0)){M=R;N=Q;O=P;break b}F=c[v>>2]|0;if(((c[s>>2]|0)-F|0)<1){S=0}else{S=a[F]|0}mrc(Q|0,S|0,R|0)|0;F=Q+(q+R)|0;if((F|0)==(y|0)){break a}else{P=P-R|0;Q=F;R=c[k>>2]|0}}}}while(0);do{if(j){b=c[v>>2]|0;J=(c[s>>2]|0)-b|0;F=J>>>0>O>>>0?O:J;nrc(N|0,b|0,F)|0;c[v>>2]=(c[v>>2]|0)+F}else{if(!r){break}F=c[v>>2]|0;if(((c[s>>2]|0)-F|0)<1){T=0}else{c[v>>2]=F+1;T=a[F]|0}mrc(N|0,T|0,O|0)|0}}while(0);j=c[v>>2]|0;if(((c[s>>2]|0)-j|0)<1){break}else{L=M-O|0;n=N+O|0;K=j}}}}while(0);O=YHb(e,c[m>>2]|0)|0;if((O|0)<0){o=O;i=h;return o|0}c[f>>2]=1;o=c[w>>2]|0;i=h;return o|0}function t2(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function u2(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[a+140>>2]=11;d=pJb(ca(c[a+124>>2]|0,c[a+120>>2]|0)|0)|0;c[b+4>>2]=d;return((d|0)==0?-12:0)|0}function v2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;h=i;j=c[g+28>>2]|0;k=c[b+60>>2]|0;l=k+4|0;m=c[l>>2]|0;n=b+120|0;o=c[b+124>>2]|0;p=ca(o,c[n>>2]|0)|0;q=m+p|0;r=M4a(b,e,0)|0;if((r|0)<0){s=r;i=h;return s|0}r=c[g+24>>2]|0;if(!((j|0)>-1)){KIb(0,0,2250696,(t=i,i=i+24|0,c[t>>2]=2208096,c[t+8>>2]=2175656,c[t+16>>2]=135,t)|0);i=t;Hd();return 0}g=r+j|0;u=e+88|0;if((c[b+428>>2]|0)==0){c[u>>2]=1;c[e+84>>2]=1;v=b+100|0;w=c[v>>2]|0;if((w|0)>768){KIb(0,16,2457744,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}x=c[e+4>>2]|0;if((w|0)>2){w=c[b+96>>2]|0;y=x;z=0;while(1){c[y>>2]=-16777216;A=z*3|0;B=d[w+A|0]|0;C=((B<<2|B>>>4)<<16)-16777216|0;c[y>>2]=C;B=d[w+(A+1)|0]|0;D=((B<<2|B>>>4)<<8)+C|0;c[y>>2]=D;C=d[w+(A+2)|0]|0;c[y>>2]=(C<<2|C>>>4)+D;D=z+1|0;if((D|0)<((c[v>>2]|0)/3|0|0)){y=y+4|0;z=D}else{break}}}nrc(k+8|0,x|0,1024)|0;c[e+304>>2]=1}else{c[u>>2]=2;c[e+84>>2]=0;c[e+304>>2]=0;nrc(c[e+4>>2]|0,k+8|0,1024)|0}k=g;a:do{if((p|0)!=0){u=r+(j>>>0>4>>>0?4:j)|0;x=m;z=0;b:while(1){y=u;v=z;while(1){if((k-y|0)<1){E=0;F=y}else{E=d[y]|0;F=y+1|0}w=E>>>6;D=E&63;C=k-F|0;if((g|0)==(F|0)){G=20;break b}A=(w|0)==1;do{if((D|0)==0){if(!A){if((C|0)<2){H=0;I=F}else{B=F;H=(d[B]|d[B+1|0]<<8)<<16>>16&65535;I=F+2|0}if((w|0)==2&(H|0)==0){break a}else{J=H;K=v;L=I;break}}if((C|0)<1){M=0;N=F}else{M=d[F]|0;N=F+1|0}if((k-N|0)<2){J=M;K=0;L=N;break}B=N;J=M;K=(d[B]|d[B+1|0]<<8)<<16>>16&65535;L=N+2|0}else{if(!A){J=D;K=v;L=F;break}if((C|0)<1){J=D;K=0;L=F;break}J=D;K=d[F]|0;L=F+1|0}}while(0);if((x+(J<<(d[1953832+w|0]|0))|0)>>>0>q>>>0){break a}if((w|0)==0){G=35;break}else if((w|0)==2){G=42;break}else if((w|0)==3){G=44;break}else if((w|0)!=1){y=L;v=K;continue}O=x+(-K|0)|0;if(O>>>0<(c[l>>2]|0)>>>0){y=L;v=K}else{G=39;break}}do{if((G|0)==35){G=0;if(!(J>>>0<(k-L|0)>>>0)){G=36;break b}nrc(x|0,L|0,J)|0;P=x+J|0;Q=L+J|0}else if((G|0)==39){G=0;v=J<<2;if((v|0)==0){P=x;Q=L;break}y=J<<2;D=O;C=x;A=v;while(1){v=A-1|0;a[C]=a[D]|0;if((v|0)==0){break}else{D=D+1|0;C=C+1|0;A=v}}P=x+y|0;Q=L}else if((G|0)==42){G=0;P=x+J|0;Q=L}else if((G|0)==44){G=0;if((k-L|0)<1){R=0;S=L}else{R=a[L]|0;S=L+1|0}if((k-S|0)<1){T=0;U=S}else{T=a[S]|0;U=S+1|0}if((J|0)==0){P=x;Q=U;break}A=J<<1;C=x;D=J;while(1){w=D-1|0;a[C]=R;a[C+1|0]=T;if((w|0)==0){break}else{C=C+2|0;D=w}}P=x+A|0;Q=U}}while(0);if((P|0)==(q|0)){break a}else{u=Q;x=P;z=K}}if((G|0)==20){KIb(b,16,2367728,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}else if((G|0)==36){KIb(b,16,2302128,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}}}while(0);if((o|0)!=0){t=e+32|0;b=c[l>>2]|0;l=o;o=c[e>>2]|0;e=c[n>>2]|0;while(1){G=l-1|0;nrc(o|0,b|0,e)|0;K=c[n>>2]|0;if((G|0)==0){break}else{b=b+K|0;l=G;o=o+(c[t>>2]|0)|0;e=K}}}c[f>>2]=1;s=j;i=h;return s|0}function w2(a){a=a|0;kJb(c[(c[a+60>>2]|0)+4>>2]|0);return 0}function x2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;c[b>>2]=hJb(4096)|0;f=hJb(16)|0;c[d>>2]=f;if((c[b>>2]|0)==0|(f|0)==0){mJb(b);mJb(d);KIb(a,16,2591064,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-12;i=e;return g|0}else{mrc(f|0,-1|0,16)|0;g=0;i=e;return g|0}return 0}function y2(a,b){a=a|0;b=b|0;mJb(a);mJb(b);return}function z2(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;c[b>>2]=262143;c[e>>2]=0;e=a+8|0;b=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(b>>>3)|0;a=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(b&7)>>>14;h=b+18|0;c[e>>2]=g>>>0>h>>>0?h:g;c[f>>2]=a;return}function A2(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+8|0;d=c[b>>2]|0;e=-d|0;f=(c[a+16>>2]|0)-d|0;if((e|0)>-16){g=e}else{g=(f|0)<-16?f:-16}c[b>>2]=g+d;return}function B2(b,f,g,h,i,j,k,l,m,n){b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if((h|0)<0){o=0}else{o=(h|0)>3?3:h}p=o<<10;q=n+(o<<2)|0;if((c[q>>2]|0)!=(h|0)){o=1<<h;n=0;r=m+p|0;while(1){s=c[1719552+(n<<2)>>2]|0;t=0;u=r;while(1){v=t+1|0;w=v<<8;x=o;while(1){if((e[s+(x<<1)>>1]|0)>>>0>w>>>0){x=x+o|0}else{break}}a[u]=x>>>(h>>>0);if(v>>>0<64>>>0){t=v;u=u+1|0}else{break}}u=n+1|0;if(u>>>0<16>>>0){n=u;r=r+64|0}else{break}}c[q>>2]=h}q=c[j>>2]|0;r=c[k>>2]|0;n=c[l>>2]|0;if((f|0)==0){y=q;z=r;A=n;c[j>>2]=y;c[k>>2]=z;c[l>>2]=A;return}o=p+(i<<6)|0;p=c[1719552+(i<<2)>>2]|0;i=b+8|0;u=b|0;t=b+16|0;b=1<<h;s=q;q=r;r=n;n=0;w=g;while(1){g=s-q+1|0;B=((r-q<<14|16383)>>>0)/(g>>>0)|0;C=(d[m+(o+(B>>>8))|0]|0)<<h;if((e[p+(C<<1)>>1]|0)>>>0>B>>>0){D=C;while(1){E=D+b|0;if((e[p+(E<<1)>>1]|0)>>>0>B>>>0){D=E}else{F=E;break}}}else{F=C}D=F>>>(h>>>0);B=D-1|0;E=(((ca(e[p+(B<<h<<1)>>1]|0,g)|0)-16384|0)>>>14)+q|0;G=r;H=((ca(e[p+(D<<h<<1)>>1]|0,g)|0)>>>14)+q|0;D=E;a:while(1){do{if(D>>>0>131071>>>0){if(H>>>0>131071>>>0){I=G-131072|0;J=H-131072|0;K=D-131072|0;break}if(!(H>>>0>65535>>>0&D>>>0<196608>>>0)){break a}I=G-65536|0;J=H-65536|0;K=D-65536|0}else{I=G;J=H;K=D}}while(0);v=c[i>>2]|0;x=(d[(c[u>>2]|0)+(v>>>3)|0]|0)<<(v&7)>>>7;c[i>>2]=((v|0)<(c[t>>2]|0))+v;G=x&1|I<<1;H=J<<1;D=K<<1|1}c[w>>2]=B;g=n+1|0;if(g>>>0<f>>>0){s=D;q=H;r=G;n=g;w=w+4|0}else{y=D;z=H;A=G;break}}c[j>>2]=y;c[k>>2]=z;c[l>>2]=A;return}function C2(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+64|0;f=e|0;g=c[b+60>>2]|0;h=c[b+52>>2]|0;j=g+1472|0;c[j>>2]=h>>>24;if((c[b+100>>2]|0)<4){KIb(b,16,2551224,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=e;return l|0}k=c[b+96>>2]|0;m=g+1476|0;c[m>>2]=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24)&1048576;c[g+1480>>2]=h>>>0>1744830463>>>0;if((c[2472690]|0)==0){h=0;do{k=d[1915063+(h<<4)|0]|0;c[9890460+(h*20|0)>>2]=9463928+(h<<7<<2);c[9890468+(h*20|0)>>2]=1<<k;$2(9890456+(h*20|0)|0,k,16,1915048+(h<<4)|0,1,1,1915304+(h<<4)|0,1,1,0,0,0,6)|0;h=h+1|0;}while((h|0)<16)}h=g;c[h>>2]=b;k=UHb()|0;c[g+1468>>2]=k;if((k|0)==0){l=-12;i=e;return l|0}k=tIb(c[b+120>>2]|0,c[b+124>>2]|0,0,b)|0;if((k|0)<0){l=k;i=e;return l|0}c[b+140>>2]=(c[m>>2]|0)!=0?35:0;l8(g+4|0,b);YJa(g+1248|0,c[b+88>>2]|0);Q2(g+1456|0);b=c[h>>2]|0;h=ca(((c[b+120>>2]|0)+7|0)>>>3<<6,(c[b+124>>2]|0)+7>>3)|0;b=pJb(h)|0;m=g+1512|0;c[m>>2]=b;do{if((b|0)==0){n=g+1552|0}else{c[g+1516>>2]=b+h;k=pJb(h)|0;o=g+1552|0;c[o>>2]=k;if((k|0)==0){n=o;break}c[g+1556>>2]=k+h;k=pJb(h)|0;c[g+1592>>2]=k;if((k|0)==0){n=o;break}c[g+1596>>2]=k+h;k=pJb(h)|0;c[g+1632>>2]=k;if((k|0)==0){n=o;break}c[g+1636>>2]=k+h;k=pJb(h)|0;c[g+1672>>2]=k;if((k|0)==0){n=o;break}c[g+1676>>2]=k+h;k=pJb(h)|0;c[g+1712>>2]=k;if((k|0)==0){n=o;break}c[g+1716>>2]=k+h;k=pJb(h)|0;c[g+1752>>2]=k;if((k|0)==0){n=o;break}c[g+1756>>2]=k+h;k=pJb(h)|0;c[g+1792>>2]=k;if((k|0)==0){n=o;break}c[g+1796>>2]=k+h;k=pJb(h)|0;c[g+1832>>2]=k;if((k|0)==0){n=o;break}c[g+1836>>2]=k+h;k=pJb(h)|0;c[g+1872>>2]=k;if((k|0)==0){n=o;break}c[g+1876>>2]=k+h;if((c[j>>2]|0)!=98|a[1585176]){l=0;i=e;return l|0}k=0;while(1){a[f+(d[1915560+k|0]|0)|0]=k;o=k+1|0;if((o|0)<64){k=o}else{p=0;break}}do{k=d[1914592+p|0]|0;o=0;q=d[1914736+p|0]|0;r=q<<18|0>>>14;s=0<<18|q>>>14;q=0;do{t=d[f+q|0]|0;u=c[1914752+(q<<2)>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=Erc(d[1914608+q|0]|0,0,k,o)|0;x=Erc(u,G,v,w)|0;u=Crc(x,G,r,s)|0;c[9882264+(p<<8)+(t<<2)>>2]=u;u=d[1914672+q|0]|0;x=Erc(v,w,k,o)|0;w=Erc(x,G,u,0)|0;u=Crc(w,G,r,s)|0;c[9886360+(p<<8)+(t<<2)>>2]=u;q=q+1|0;}while((q|0)<64);p=p+1|0;}while((p|0)<16);a[1585176]=1;l=0;i=e;return l|0}}while(0);mJb(m);mJb(n);mJb(g+1592|0);mJb(g+1632|0);mJb(g+1672|0);mJb(g+1712|0);mJb(g+1752|0);mJb(g+1792|0);mJb(g+1832|0);mJb(g+1872|0);l=-12;i=e;return l|0}function D2(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0;j=i;i=i+672|0;k=j|0;l=j+8|0;m=j+136|0;n=j+392|0;o=j+648|0;p=c[e+60>>2]|0;q=p;r=f;f=h+28|0;s=c[f>>2]<<3;t=p+1472|0;do{if((c[t>>2]|0)>98){u=M4a(e,r,1)|0;if((u|0)<0){v=u}else{break}i=j;return v|0}else{u=p+1468|0;w=N4a(e,c[u>>2]|0)|0;if((w|0)<0){v=w;i=j;return v|0}w=YHb(r,c[u>>2]|0)|0;if((w|0)<0){v=w}else{break}i=j;return v|0}}while(0);e=c[h+24>>2]|0;h=s>>>0>2147483639>>>0|(e|0)==0;w=h?0:e;e=h?0:s;h=o|0;c[h>>2]=w;c[o+12>>2]=e;u=e+8|0;x=o+16|0;c[x>>2]=u;c[o+4>>2]=w+(e>>3);e=o+8|0;c[e>>2]=0;do{if((c[p+1476>>2]|0)!=0){if((c[t>>2]|0)>104){c[e>>2]=(u|0)<32?u:32}w=G2(q,r,o,3,0)|0;if((w|0)<0){v=w}else{break}i=j;return v|0}}while(0);if((c[t>>2]|0)>104){u=c[e>>2]|0;w=-u|0;z=(c[x>>2]|0)-u|0;if((w|0)>32){A=w}else{A=(z|0)<32?z:32}c[e>>2]=A+u}u=p+1484|0;c[u>>2]=(c[u>>2]|0)+1;A=p+1480|0;z=m;w=l|0;l=m|0;m=p;B=p+1512|0;C=p+1524|0;D=p+1520|0;E=p+1488|0;F=p+1552|0;G=p+1564|0;H=p+1560|0;I=p+1528|0;J=p+1592|0;K=p+1604|0;L=p+1600|0;M=p+1568|0;N=p+1632|0;O=p+1644|0;P=p+1640|0;Q=p+1608|0;R=p+1672|0;S=p+1684|0;T=p+1680|0;U=p+1648|0;V=p+1712|0;W=p+1724|0;X=p+1720|0;Y=p+1688|0;Z=p+1752|0;_=p+1764|0;$=p+1760|0;aa=p+1728|0;ba=p+1792|0;da=p+1804|0;ea=p+1800|0;fa=p+1768|0;ga=p+1832|0;ha=p+1844|0;ia=p+1840|0;ja=p+1808|0;ka=p+1872|0;la=p+1884|0;ma=p+1880|0;na=p+1848|0;oa=p+1456|0;pa=p+40|0;qa=p+24|0;ra=p+1264|0;sa=p+1460|0;ta=p+1244|0;ua=k|0;va=k+4|0;wa=0;while(1){if((wa|0)>=3){xa=105;break}ya=(wa|0)!=0;if(ya){za=(c[A>>2]|0)==0?wa:wa^3}else{za=0}if((c[t>>2]|0)>98){Aa=G2(q,r,o,za,ya&1)|0;if((Aa|0)<0){v=Aa;xa=108;break}}else{Aa=(c[u>>2]|0)==1?-15:0;Ba=r+32+(za<<2)|0;Ca=c[Ba>>2]|0;Da=c[m>>2]|0;Ea=c[Da+120>>2]|0;if(ya){Fa=(c[Da+124>>2]|0)+15>>4;Ga=Ea+15>>4}else{Fa=(c[Da+124>>2]|0)+7>>3;Ga=Ea+7>>3}Ea=c[B>>2]|0;c[C>>2]=Ea;c[D>>2]=Ea;c[E>>2]=13;Ea=c[F>>2]|0;c[G>>2]=Ea;c[H>>2]=Ea;c[I>>2]=13;Ea=c[J>>2]|0;c[K>>2]=Ea;c[L>>2]=Ea;c[M>>2]=13;Ea=c[N>>2]|0;c[O>>2]=Ea;c[P>>2]=Ea;c[Q>>2]=13;Ea=c[R>>2]|0;c[S>>2]=Ea;c[T>>2]=Ea;c[U>>2]=13;Ea=c[V>>2]|0;c[W>>2]=Ea;c[X>>2]=Ea;c[Y>>2]=13;Ea=c[Z>>2]|0;c[_>>2]=Ea;c[$>>2]=Ea;c[aa>>2]=13;Ea=c[ba>>2]|0;c[da>>2]=Ea;c[ea>>2]=Ea;c[fa>>2]=13;Ea=c[ga>>2]|0;c[ha>>2]=Ea;c[ia>>2]=Ea;c[ja>>2]=13;Ea=c[ka>>2]|0;c[la>>2]=Ea;c[ma>>2]=Ea;c[na>>2]=13;Ea=r+(za<<2)|0;Da=c[Ea>>2]|0;ya=(ca(c[Ba>>2]|0,Fa)|0)+Ga|0;Ba=0;do{c[n+(Ba<<2)>>2]=(ca(Ba>>3,Ca)|0)+(Ba&7);Ba=Ba+1|0;}while((Ba|0)<64);Ba=Da+(ya<<3)|0;a:do{if((Fa|0)>0){Ha=Ca<<3;Ia=(Ga|0)>0;Ja=Ca<<1;Ka=Ca*3|0;La=Ca<<2;Ma=Ca*5|0;Na=Ca*6|0;Oa=Ca*7|0;Pa=0;b:while(1){Qa=0;do{Ra=c[1915008+(Qa<<2)>>2]|0;Sa=1<<Ra-1;Ta=q+1488+(Qa*40|0)+32|0;Ua=c[Ta>>2]|0;c:do{if((Ua|0)!=0){if(Ua>>>0>(c[q+1488+(Qa*40|0)+36>>2]|0)>>>0){break}Va=c[q+1488+(Qa*40|0)>>2]|0;Wa=c[e>>2]|0;Xa=c[x>>2]|0;Ya=c[h>>2]|0;Za=Ya+(Wa>>>3)|0;_a=32-Va|0;$a=(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)>>>((Wa&7)>>>0)<<_a>>>(_a>>>0);_a=Wa+Va|0;Va=Xa>>>0>_a>>>0?_a:Xa;c[e>>2]=Va;if(($a|0)==0){c[Ta>>2]=0;break}_a=Qa-5|0;if(((c[q+1488+(Qa*40|0)+28>>2]|0)-Ua|0)<(ca($a,_a>>>0<2>>>0?2:1)|0)){ab=-1094995529;break a}if(_a>>>0>1>>>0){_a=($a|0)>0;if((88>>>(Qa>>>0)&1|0)==0){if(!_a){break}Wa=32-Ra|0;Za=Ya+(Va>>>3)|0;bb=(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)>>>((Va&7)>>>0)<<Wa>>>(Wa>>>0);Za=Va+Ra|0;c[e>>2]=Xa>>>0>Za>>>0?Za:Xa;c[Ta>>2]=Ua+1;a[Ua]=bb;if(($a|0)>1){cb=1}else{break}while(1){bb=c[e>>2]|0;Za=c[x>>2]|0;db=c[Ta>>2]|0;cb=cb+1|0;eb=(c[h>>2]|0)+(bb>>>3)|0;fb=(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((bb&7)>>>0)<<Wa>>>(Wa>>>0);eb=bb+Ra|0;c[e>>2]=Za>>>0>eb>>>0?eb:Za;c[Ta>>2]=db+1;a[db]=fb;if((cb|0)>=($a|0)){break c}}}if(!_a){break}Wa=32-Ra|0;fb=1;db=Va;Za=Xa;eb=Ya;bb=Ua;while(1){gb=eb+(db>>>3)|0;hb=(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)>>>((db&7)>>>0)<<Wa>>>(Wa>>>0);gb=db+Ra|0;c[e>>2]=Za>>>0>gb>>>0?gb:Za;c[Ta>>2]=bb+1;a[bb]=hb-Sa;if((fb|0)>=($a|0)){break c}fb=fb+1|0;db=c[e>>2]|0;Za=c[x>>2]|0;eb=c[h>>2]|0;bb=c[Ta>>2]|0}}bb=Ua;eb=($a|0)>0;do{if((88>>>(Qa>>>0)&1|0)==0){if(!eb){ib=bb;break}Za=32-Ra|0;db=0;fb=bb;Wa=Va;while(1){_a=Ya+(Wa>>>3)|0;hb=(d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0)>>>((Wa&7)>>>0)<<Za>>>(Za>>>0);_a=Wa+Ra|0;gb=Xa>>>0>_a>>>0?_a:Xa;c[e>>2]=gb;b[fb>>1]=hb;hb=db+1|0;if((hb|0)<($a|0)){db=hb;fb=fb+2|0;Wa=gb}else{break}}ib=Ua+($a<<1)|0}else{if(!eb){ib=bb;break}Wa=32-Ra|0;fb=0;db=bb;Za=Va;while(1){gb=Ya+(Za>>>3)|0;hb=(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)>>>((Za&7)>>>0)<<Wa>>>(Wa>>>0);gb=Za+Ra|0;_a=Xa>>>0>gb>>>0?gb:Xa;c[e>>2]=_a;b[db>>1]=hb-Sa;hb=fb+1|0;if((hb|0)<($a|0)){fb=hb;db=db+2|0;Za=_a}else{break}}ib=Ua+($a<<1)|0}}while(0);c[Ta>>2]=ib}}while(0);Qa=Qa+1|0;}while((Qa|0)<10);d:do{if(Ia){Qa=ca(Pa,Ha)|0;Ta=(c[Ea>>2]|0)+Qa|0;Qa=1;while(1){Ua=c[C>>2]|0;c[C>>2]=Ua+1;jb=d[Ua]|0;e:do{switch(jb|0){case 3:{Ua=c[O>>2]|0;c[O>>2]=Ua+1;Sa=a[Ua]|0;Ua=c[S>>2]|0;c[S>>2]=Ua+1;Ra=(ca((a[Ua]|0)+Aa|0,Ca)|0)+Sa|0;Sa=Ta+Ra|0;do{if(Sa>>>0<Da>>>0){xa=75}else{Ua=Ra+Ha|0;if((Ta+Ua|0)>>>0>Ba>>>0){xa=75;break}if((Ua|0)>-1&(Ra|0)<(Ha|0)){Ua=Sa;$a=Ua|0;Xa=Ua+4|0;Ua=d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0;Xa=Ta+(Ra+Ca)|0;Ya=Xa|0;Va=d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0;Ya=Xa+4|0;Xa=d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0;Ya=Ta+(Ra+Ja)|0;bb=Ya|0;eb=d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0;bb=Ya+4|0;Ya=d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0;bb=Ta+(Ra+Ka)|0;Za=bb|0;db=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;Za=bb+4|0;bb=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;Za=Ta+(Ra+La)|0;fb=Za|0;Wa=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=Za+4|0;Za=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=Ta+(Ra+Ma)|0;_a=fb|0;hb=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;_a=fb+4|0;fb=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;_a=Ta+(Ra+Na)|0;gb=_a|0;kb=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;gb=_a+4|0;_a=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;gb=Ta+(Ra+Oa)|0;lb=gb|0;mb=d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0;lb=gb+4|0;gb=d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0;lb=Ta;nb=lb|0;y=d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=lb+4|0;y=Ua;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=Ta+Ca|0;Ua=nb|0;y=Va;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=nb+4|0;y=Xa;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=Ta+Ja|0;Xa=Ua|0;y=eb;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;Xa=Ua+4|0;y=Ya;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;Xa=Ta+Ka|0;Ya=Xa|0;y=db;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;Ya=Xa+4|0;y=bb;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;Ya=Ta+La|0;bb=Ya|0;y=Wa;a[bb]=y;y=y>>8;a[bb+1|0]=y;y=y>>8;a[bb+2|0]=y;y=y>>8;a[bb+3|0]=y;bb=Ya+4|0;y=Za;a[bb]=y;y=y>>8;a[bb+1|0]=y;y=y>>8;a[bb+2|0]=y;y=y>>8;a[bb+3|0]=y;bb=Ta+Ma|0;Za=bb|0;y=hb;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;Za=bb+4|0;y=fb;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;Za=Ta+Na|0;fb=Za|0;y=kb;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;fb=Za+4|0;y=_a;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;fb=Ta+Oa|0;_a=fb|0;y=mb;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;_a=fb+4|0;y=gb;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;break}else{mf[c[ra>>2]&2047](Ta,Sa,Ca,8);break}}}while(0);if((xa|0)==75){xa=0;KIb(c[m>>2]|0,24,2367656,(ob=i,i=i+1|0,i=i+7&-8,c[ob>>2]=0,ob)|0);i=ob}qe[c[pa>>2]&1023](w);Sa=c[la>>2]|0;c[la>>2]=Sa+1;I2(o,w,d[Sa]|0);ef[c[qa>>2]&4095](Ta,w,Ca);break};case 4:{Sa=c[O>>2]|0;c[O>>2]=Sa+1;Ra=a[Sa]|0;Sa=c[S>>2]|0;c[S>>2]=Sa+1;_a=(ca((a[Sa]|0)+Aa|0,Ca)|0)+Ra|0;Ra=Ta+_a|0;do{if(Ra>>>0<Da>>>0){xa=82}else{Sa=_a+Ha|0;if((Ta+Sa|0)>>>0>Ba>>>0){xa=82;break}if((Sa|0)>-1&(_a|0)<(Ha|0)){Sa=Ra;gb=Sa|0;fb=Sa+4|0;Sa=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=Ta+(_a+Ca)|0;mb=fb|0;Za=d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0;mb=fb+4|0;fb=d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0;mb=Ta+(_a+Ja)|0;kb=mb|0;bb=d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0;kb=mb+4|0;mb=d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0;kb=Ta+(_a+Ka)|0;hb=kb|0;Ya=d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0;hb=kb+4|0;kb=d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0;hb=Ta+(_a+La)|0;Wa=hb|0;Xa=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;Wa=hb+4|0;hb=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;Wa=Ta+(_a+Ma)|0;db=Wa|0;Ua=d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0;db=Wa+4|0;Wa=d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0;db=Ta+(_a+Na)|0;eb=db|0;nb=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=db+4|0;db=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=Ta+(_a+Oa)|0;Va=eb|0;lb=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;Va=eb+4|0;eb=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;Va=Ta;$a=Va|0;y=d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0;a[$a]=y;y=y>>8;a[$a+1|0]=y;y=y>>8;a[$a+2|0]=y;y=y>>8;a[$a+3|0]=y;$a=Va+4|0;y=Sa;a[$a]=y;y=y>>8;a[$a+1|0]=y;y=y>>8;a[$a+2|0]=y;y=y>>8;a[$a+3|0]=y;$a=Ta+Ca|0;Sa=$a|0;y=Za;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;Sa=$a+4|0;y=fb;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;Sa=Ta+Ja|0;fb=Sa|0;y=bb;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;fb=Sa+4|0;y=mb;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;fb=Ta+Ka|0;mb=fb|0;y=Ya;a[mb]=y;y=y>>8;a[mb+1|0]=y;y=y>>8;a[mb+2|0]=y;y=y>>8;a[mb+3|0]=y;mb=fb+4|0;y=kb;a[mb]=y;y=y>>8;a[mb+1|0]=y;y=y>>8;a[mb+2|0]=y;y=y>>8;a[mb+3|0]=y;mb=Ta+La|0;kb=mb|0;y=Xa;a[kb]=y;y=y>>8;a[kb+1|0]=y;y=y>>8;a[kb+2|0]=y;y=y>>8;a[kb+3|0]=y;kb=mb+4|0;y=hb;a[kb]=y;y=y>>8;a[kb+1|0]=y;y=y>>8;a[kb+2|0]=y;y=y>>8;a[kb+3|0]=y;kb=Ta+Ma|0;hb=kb|0;y=Ua;a[hb]=y;y=y>>8;a[hb+1|0]=y;y=y>>8;a[hb+2|0]=y;y=y>>8;a[hb+3|0]=y;hb=kb+4|0;y=Wa;a[hb]=y;y=y>>8;a[hb+1|0]=y;y=y>>8;a[hb+2|0]=y;y=y>>8;a[hb+3|0]=y;hb=Ta+Na|0;Wa=hb|0;y=nb;a[Wa]=y;y=y>>8;a[Wa+1|0]=y;y=y>>8;a[Wa+2|0]=y;y=y>>8;a[Wa+3|0]=y;Wa=hb+4|0;y=db;a[Wa]=y;y=y>>8;a[Wa+1|0]=y;y=y>>8;a[Wa+2|0]=y;y=y>>8;a[Wa+3|0]=y;Wa=Ta+Oa|0;db=Wa|0;y=lb;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;db=Wa+4|0;y=eb;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;break}else{mf[c[ra>>2]&2047](Ta,Ra,Ca,8);break}}}while(0);if((xa|0)==82){xa=0;KIb(c[m>>2]|0,24,2367656,(ob=i,i=i+1|0,i=i+7&-8,c[ob>>2]=0,ob)|0);i=ob}mrc(z|0,0,256)|0;Ra=c[_>>2]|0;_a=b[Ra>>1]|0;c[_>>2]=Ra+2;c[l>>2]=_a<<16>>16;_a=c[ha>>2]|0;c[ha>>2]=_a+1;H2(o,l,9886360,d[_a]|0);ef[c[sa>>2]&4095](Ta,Ca,l);break};case 2:{mrc(z|0,0,256)|0;_a=c[W>>2]|0;Ra=b[_a>>1]|0;c[W>>2]=_a+2;c[l>>2]=Ra<<16>>16;Ra=c[da>>2]|0;c[da>>2]=Ra+1;H2(o,l,9882264,d[Ra]|0);ef[c[oa>>2]&4095](Ta,Ca,l);break};case 5:{Ra=c[G>>2]|0;c[G>>2]=Ra+1;mf[c[ta>>2]&2047](Ta,a[Ra]|0,Ca,8);break};case 0:{break};case 6:{Ra=c[G>>2]|0;_a=Ra+1|0;c[G>>2]=_a;c[ua>>2]=d[Ra]|0;c[G>>2]=Ra+2;c[va>>2]=d[_a]|0;_a=0;do{Ra=c[K>>2]|0;c[K>>2]=Ra+1;db=d[Ra]|0;Ra=ca(_a,Ca)|0;a[Ta+Ra|0]=c[k+((db&1)<<2)>>2];a[Ta+(Ra+1)|0]=c[k+((db>>>1&1)<<2)>>2];a[Ta+(Ra+2)|0]=c[k+((db>>>2&1)<<2)>>2];a[Ta+(Ra+3)|0]=c[k+((db>>>3&1)<<2)>>2];a[Ta+(Ra+4)|0]=c[k+((db>>>4&1)<<2)>>2];a[Ta+(Ra+5)|0]=c[k+((db>>>5&1)<<2)>>2];a[Ta+(Ra+6)|0]=c[k+((db>>>6&1)<<2)>>2];a[Ta+(Ra+7)|0]=c[k+(db>>>7<<2)>>2];_a=_a+1|0;}while((_a|0)<8);break};case 8:{_a=c[G>>2]|0;db=Ta;Ra=_a|0;eb=_a+4|0;_a=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=db|0;y=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=db+4|0;y=_a;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=(c[G>>2]|0)+8|0;_a=Ta+Ca|0;db=eb|0;Ra=eb+4|0;eb=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;Ra=_a|0;y=d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;Ra=_a+4|0;y=eb;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;Ra=(c[G>>2]|0)+16|0;eb=Ta+Ja|0;_a=Ra|0;db=Ra+4|0;Ra=d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0;db=eb|0;y=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;db=eb+4|0;y=Ra;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;db=(c[G>>2]|0)+24|0;Ra=Ta+Ka|0;eb=db|0;_a=db+4|0;db=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;_a=Ra|0;y=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;_a=Ra+4|0;y=db;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;_a=(c[G>>2]|0)+32|0;db=Ta+La|0;Ra=_a|0;eb=_a+4|0;_a=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=db|0;y=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=db+4|0;y=_a;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=(c[G>>2]|0)+40|0;_a=Ta+Ma|0;db=eb|0;Ra=eb+4|0;eb=d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0;Ra=_a|0;y=d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;Ra=_a+4|0;y=eb;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;Ra=(c[G>>2]|0)+48|0;eb=Ta+Na|0;_a=Ra|0;db=Ra+4|0;Ra=d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0;db=eb|0;y=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;db=eb+4|0;y=Ra;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;db=(c[G>>2]|0)+56|0;Ra=Ta+Oa|0;eb=db|0;_a=db+4|0;db=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;_a=Ra|0;y=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;_a=Ra+4|0;y=db;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;c[G>>2]=(c[G>>2]|0)+64;break};case 1:{_a=c[e>>2]|0;db=c[x>>2]|0;Ra=c[h>>2]|0;eb=Ra+(_a>>>3)|0;Wa=(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((_a&7)>>>0)&15;eb=_a+4|0;_a=db>>>0>eb>>>0?eb:db;c[e>>2]=_a;eb=0;lb=1915632+(Wa<<6)|0;Wa=_a;_a=Ra;Ra=db;while(1){db=a[_a+(Wa>>>3)|0]|0;hb=((Wa|0)<(Ra|0))+Wa|0;c[e>>2]=hb;nb=d[1914528+eb|0]|0;kb=_a+(hb>>>3)|0;Ua=32-nb|0;mb=(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)>>>((hb&7)>>>0)<<Ua>>>(Ua>>>0);Ua=nb+hb|0;c[e>>2]=Ra>>>0>Ua>>>0?Ua:Ra;Ua=mb+1|0;pb=Ua+eb|0;if((pb|0)>64){xa=59;break b}do{if((db&255&1<<(Wa&7)|0)==0){if((Ua|0)<=0){qb=lb;break}mb=c[G>>2]|0;c[G>>2]=mb+1;a[Ta+(c[n+(d[lb]<<2)>>2]|0)|0]=a[mb]|0;if((Ua|0)>1){mb=1;hb=lb;do{hb=hb+1|0;mb=mb+1|0;nb=c[G>>2]|0;c[G>>2]=nb+1;a[Ta+(c[n+(d[hb]<<2)>>2]|0)|0]=a[nb]|0;}while((mb|0)<(Ua|0))}qb=lb+Ua|0}else{mb=c[G>>2]|0;c[G>>2]=mb+1;hb=a[mb]|0;if((Ua|0)>0){rb=lb;sb=0}else{qb=lb;break}while(1){a[Ta+(c[n+(d[rb]<<2)>>2]|0)|0]=hb;mb=sb+1|0;if((mb|0)<(Ua|0)){rb=rb+1|0;sb=mb}else{break}}qb=lb+Ua|0}}while(0);if((pb|0)>=63){break}eb=pb;lb=qb;Wa=c[e>>2]|0;_a=c[h>>2]|0;Ra=c[x>>2]|0}if((pb|0)!=63){break e}Ra=c[G>>2]|0;c[G>>2]=Ra+1;a[Ta+(c[n+(d[qb]<<2)>>2]|0)|0]=a[Ra]|0;break};case 7:{Ra=c[O>>2]|0;c[O>>2]=Ra+1;_a=a[Ra]|0;Ra=c[S>>2]|0;c[S>>2]=Ra+1;Wa=(ca((a[Ra]|0)+Aa|0,Ca)|0)+_a|0;_a=Ta+Wa|0;do{if(!(_a>>>0<Da>>>0)){Ra=Wa+Ha|0;if((Ta+Ra|0)>>>0>Ba>>>0){break}if((Ra|0)>-1&(Wa|0)<(Ha|0)){Ra=_a;lb=Ra|0;eb=Ra+4|0;Ra=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=Ta+(Wa+Ca)|0;Ua=eb|0;db=d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0;Ua=eb+4|0;eb=d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0;Ua=Ta+(Wa+Ja)|0;hb=Ua|0;mb=d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0;hb=Ua+4|0;Ua=d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0;hb=Ta+(Wa+Ka)|0;nb=hb|0;kb=d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0;nb=hb+4|0;hb=d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0;nb=Ta+(Wa+La)|0;Xa=nb|0;fb=d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0;Xa=nb+4|0;nb=d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0;Xa=Ta+(Wa+Ma)|0;Ya=Xa|0;Sa=d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0;Ya=Xa+4|0;Xa=d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0;Ya=Ta+(Wa+Na)|0;bb=Ya|0;$a=d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0;bb=Ya+4|0;Ya=d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0;bb=Ta+(Wa+Oa)|0;Za=bb|0;Va=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;Za=bb+4|0;bb=d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0;Za=Ta;gb=Za|0;y=d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0;a[gb]=y;y=y>>8;a[gb+1|0]=y;y=y>>8;a[gb+2|0]=y;y=y>>8;a[gb+3|0]=y;gb=Za+4|0;y=Ra;a[gb]=y;y=y>>8;a[gb+1|0]=y;y=y>>8;a[gb+2|0]=y;y=y>>8;a[gb+3|0]=y;gb=Ta+Ca|0;Ra=gb|0;y=db;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;Ra=gb+4|0;y=eb;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;Ra=Ta+Ja|0;eb=Ra|0;y=mb;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=Ra+4|0;y=Ua;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=Ta+Ka|0;Ua=eb|0;y=kb;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=eb+4|0;y=hb;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=Ta+La|0;hb=Ua|0;y=fb;a[hb]=y;y=y>>8;a[hb+1|0]=y;y=y>>8;a[hb+2|0]=y;y=y>>8;a[hb+3|0]=y;hb=Ua+4|0;y=nb;a[hb]=y;y=y>>8;a[hb+1|0]=y;y=y>>8;a[hb+2|0]=y;y=y>>8;a[hb+3|0]=y;hb=Ta+Ma|0;nb=hb|0;y=Sa;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=hb+4|0;y=Xa;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=Ta+Na|0;Xa=nb|0;y=$a;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;Xa=nb+4|0;y=Ya;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;Xa=Ta+Oa|0;Ya=Xa|0;y=Va;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;Ya=Xa+4|0;y=bb;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;break e}else{mf[c[ra>>2]&2047](Ta,_a,Ca,8);break e}}}while(0);KIb(c[m>>2]|0,24,2367656,(ob=i,i=i+1|0,i=i+7&-8,c[ob>>2]=0,ob)|0);i=ob;break};default:{xa=95;break b}}}while(0);if((Qa|0)>=(Ga|0)){break d}Ta=Ta+8|0;Qa=Qa+1|0}}}while(0);Qa=Pa+1|0;if((Qa|0)<(Fa|0)){Pa=Qa}else{xa=99;break a}}if((xa|0)==59){xa=0;KIb(c[m>>2]|0,16,2457672,(ob=i,i=i+1|0,i=i+7&-8,c[ob>>2]=0,ob)|0);i=ob;ab=-1094995529;break}else if((xa|0)==95){xa=0;KIb(c[m>>2]|0,16,2302072,(ob=i,i=i+8|0,c[ob>>2]=jb,ob)|0);i=ob;ab=-1094995529;break}}else{xa=99}}while(0);do{if((xa|0)==99){xa=0;Ca=c[e>>2]|0;Ba=Ca&31;if((Ba|0)==0){ab=0;break}Da=32-Ba|0;Ba=-Ca|0;Aa=(c[x>>2]|0)-Ca|0;if((Da|0)<(Ba|0)){tb=Ba}else{tb=(Aa|0)<(Da|0)?Aa:Da}c[e>>2]=tb+Ca;ab=0}}while(0);if((ab|0)<0){v=ab;xa=108;break}}if((c[e>>2]|0)<(s|0)){wa=wa+1|0}else{xa=105;break}}if((xa|0)==105){do{if((c[t>>2]|0)>98){wa=p+1468|0;WHb(c[wa>>2]|0);s=YHb(c[wa>>2]|0,r)|0;if((s|0)<0){v=s}else{break}i=j;return v|0}}while(0);c[g>>2]=1;v=c[f>>2]|0;i=j;return v|0}else if((xa|0)==108){i=j;return v|0}return 0}function E2(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+1468|0);mJb(b+1512|0);mJb(b+1552|0);mJb(b+1592|0);mJb(b+1632|0);mJb(b+1672|0);mJb(b+1712|0);mJb(b+1752|0);mJb(b+1792|0);mJb(b+1832|0);mJb(b+1872|0);return 0}function F2(a){a=a|0;c[(c[a+60>>2]|0)+1484>>2]=0;return}function G2(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0;k=i;i=i+712|0;l=k|0;m=k+136|0;n=k+200|0;o=k+456|0;p=k+8|0;q=m|0;r=n|0;s=c[f+32+(h<<2)>>2]|0;t=e|0;u=c[t>>2]|0;v=c[u+120>>2]|0;if((j|0)==0){w=(c[u+124>>2]|0)+7>>3;x=v+7>>3}else{w=(c[u+124>>2]|0)+15>>4;x=v+15>>4}u=v>>j;j=(u|0)>8?u+7|0:15;u=(j>>3)+511|0;v=u>>>0>65535>>>0;z=v?u>>>16:u;u=v?16:0;if((z&65280|0)==0){A=u;B=z}else{A=u|8;B=z>>>8}z=A+1+(d[1359664+B|0]|0)|0;c[e+1488>>2]=z;B=(j>>4)+511|0;j=B>>>0>65535>>>0;A=j?B>>>16:B;B=j?16:0;if((A&65280|0)==0){C=B;D=A}else{C=B|8;D=A>>>8}c[e+1528>>2]=C+1+(d[1359664+D|0]|0);D=(x<<6)+511|0;C=D>>>0>65535>>>0;A=C?D>>>16:D;D=C?16:0;if((A&65280|0)==0){E=D;F=A}else{E=D|8;F=A>>>8}A=e+1568|0;c[A>>2]=E+1+(d[1359664+F|0]|0);c[e+1688>>2]=z;c[e+1648>>2]=z;c[e+1768>>2]=z;c[e+1728>>2]=z;z=(x<<3)+511|0;F=z>>>0>65535>>>0;E=F?z>>>16:z;z=F?16:0;if((E&65280|0)==0){G=z;H=E}else{G=z|8;H=E>>>8}E=e+1608|0;c[E>>2]=G+1+(d[1359664+H|0]|0);H=(x*48|0)+511|0;G=H>>>0>65535>>>0;z=G?H>>>16:H;H=G?16:0;if((z&65280|0)==0){I=H;J=z}else{I=H|8;J=z>>>8}z=e+1808|0;c[z>>2]=I+1+(d[1359664+J|0]|0);J=e+1888|0;I=e+1908|0;H=e+1928|0;G=e+1948|0;F=e+1968|0;D=e+1988|0;C=e+2008|0;B=e+2028|0;j=e+2048|0;u=e+2068|0;v=e+2088|0;K=e+2108|0;L=e+2128|0;M=e+2148|0;N=e+2168|0;O=e+2188|0;P=e+2208|0;Q=0;do{if((Q|0)==2){M2(g,J);M2(g,I);M2(g,H);M2(g,G);M2(g,F);M2(g,D);M2(g,C);M2(g,B);M2(g,j);M2(g,u);M2(g,v);M2(g,K);M2(g,L);M2(g,M);M2(g,N);M2(g,O);c[P>>2]=0;R=18}else{if((Q-6|0)>>>0>1>>>0){R=18}}if((R|0)==18){R=0;M2(g,e+1488+(Q*40|0)+4|0)}S=c[e+1488+(Q*40|0)+24>>2]|0;c[e+1488+(Q*40|0)+36>>2]=S;c[e+1488+(Q*40|0)+32>>2]=S;Q=Q+1|0;}while((Q|0)<9);Q=e+1468|0;O=c[Q>>2]|0;N=c[O+(h<<2)>>2]|0;if((N|0)==0){T=c[f+(h<<2)>>2]|0}else{T=N}N=x-1+(ca(c[O+32+(h<<2)>>2]|0,w-1|0)|0)<<3;O=0;do{c[o+(O<<2)>>2]=(ca(O>>3,s)|0)+(O&7);O=O+1|0;}while((O|0)<64);O=T+N|0;a:do{if((w|0)>0){N=e+1488|0;M=e+1528|0;L=e+1600|0;K=e+1640|0;v=e+1648|0;u=e+1688|0;j=e+1728|0;B=e+1768|0;C=e+1840|0;D=f+(h<<2)|0;F=(x|0)>0;G=e+1524|0;H=e+1264|0;I=e+1564|0;J=g+8|0;S=g+16|0;U=g|0;V=e+1844|0;W=e+1604|0;X=e+1464|0;Y=n;Z=e+1764|0;_=e+1456|0;$=e+1240|0;aa=e+1644|0;ba=e+1684|0;da=e+1724|0;ea=e+40|0;fa=e+24|0;ga=e+1244|0;ha=e+1804|0;ia=e+1460|0;ja=e+1836|0;ka=e+1812|0;la=e+1636|0;ma=e+1612|0;na=e+1596|0;oa=e+1572|0;pa=e+1472|0;qa=0;b:while(1){ra=J2(c[t>>2]|0,g,N)|0;if((ra|0)<0){sa=ra;R=129;break}ra=J2(c[t>>2]|0,g,M)|0;if((ra|0)<0){sa=ra;R=129;break}ra=c[L>>2]|0;c:do{if((ra|0)!=0){if(ra>>>0>(c[W>>2]|0)>>>0){break}ta=c[A>>2]|0;ua=c[J>>2]|0;va=c[S>>2]|0;wa=c[U>>2]|0;xa=wa+(ua>>>3)|0;ya=32-ta|0;za=(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)>>>((ua&7)>>>0)<<ya>>>(ya>>>0);ya=ua+ta|0;ta=va>>>0>ya>>>0?ya:va;c[J>>2]=ta;if((za|0)==0){c[L>>2]=0;break}ya=ra+za|0;if(ya>>>0>(c[na>>2]|0)>>>0){R=43;break b}ua=d[wa+(ta>>>3)|0]|0;xa=((ta|0)<(va|0))+ta|0;c[J>>2]=xa;if((ua&1<<(ta&7)|0)!=0){ta=c[e+1888+((c[P>>2]|0)*20|0)>>2]|0;ua=c[9890460+(ta*20|0)>>2]|0;Aa=wa+(xa>>>3)|0;Ba=32-(c[9890456+(ta*20|0)>>2]|0)|0;ta=(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)>>>((xa&7)>>>0)<<Ba>>>(Ba>>>0);Ba=b[ua+(ta<<2)>>1]|0;Aa=(b[ua+(ta<<2)+2>>1]|0)+xa|0;c[J>>2]=va>>>0>Aa>>>0?Aa:va;c[P>>2]=d[e+1888+((c[P>>2]|0)*20|0)+4+Ba|0]|0;Ba=c[oa>>2]|0;Aa=c[9890460+(Ba*20|0)>>2]|0;ta=c[J>>2]|0;ua=c[S>>2]|0;Ca=wa+(ta>>>3)|0;Da=32-(c[9890456+(Ba*20|0)>>2]|0)|0;Ba=(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)>>>((ta&7)>>>0)<<Da>>>(Da>>>0);Da=b[Aa+(Ba<<2)>>1]|0;Ca=(b[Aa+(Ba<<2)+2>>1]|0)+ta|0;c[J>>2]=ua>>>0>Ca>>>0?Ca:ua;ua=c[P>>2]<<4|d[e+1576+Da|0];if((c[pa>>2]|0)<105){Ea=(ua>>>7&1|128)+(ua<<24>>31^ua&127)&255}else{Ea=ua&255}mrc(ra|0,Ea|0,za|0)|0;c[L>>2]=(c[L>>2]|0)+za;break}if((za|0)>0){Fa=ra;Ga=xa;Ha=va;Ia=wa}else{break}while(1){wa=c[e+1888+((c[P>>2]|0)*20|0)>>2]|0;va=c[9890460+(wa*20|0)>>2]|0;xa=Ia+(Ga>>>3)|0;za=32-(c[9890456+(wa*20|0)>>2]|0)|0;wa=(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)>>>((Ga&7)>>>0)<<za>>>(za>>>0);za=b[va+(wa<<2)>>1]|0;xa=(b[va+(wa<<2)+2>>1]|0)+Ga|0;c[J>>2]=Ha>>>0>xa>>>0?xa:Ha;c[P>>2]=d[e+1888+((c[P>>2]|0)*20|0)+4+za|0]|0;za=c[oa>>2]|0;xa=c[9890460+(za*20|0)>>2]|0;wa=c[J>>2]|0;va=c[S>>2]|0;ua=Ia+(wa>>>3)|0;Da=32-(c[9890456+(za*20|0)>>2]|0)|0;za=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((wa&7)>>>0)<<Da>>>(Da>>>0);Da=b[xa+(za<<2)>>1]|0;ua=(b[xa+(za<<2)+2>>1]|0)+wa|0;c[J>>2]=va>>>0>ua>>>0?ua:va;va=c[P>>2]<<4|d[e+1576+Da|0];if((c[pa>>2]|0)<105){Ja=(va>>>7&1|128)+(va<<24>>31^va&127)&255}else{Ja=va&255}c[L>>2]=Fa+1;a[Fa]=Ja;va=c[L>>2]|0;if(!(va>>>0<ya>>>0)){break c}Fa=va;Ga=c[J>>2]|0;Ha=c[S>>2]|0;Ia=c[U>>2]|0}}}while(0);Ka=c[t>>2]|0;ra=c[K>>2]|0;do{if((ra|0)==0){La=Ka}else{if(ra>>>0>(c[aa>>2]|0)>>>0){La=Ka;break}ya=c[E>>2]|0;va=c[J>>2]|0;Da=c[S>>2]|0;ua=c[U>>2]|0;wa=ua+(va>>>3)|0;za=32-ya|0;xa=(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)>>>((va&7)>>>0)<<za>>>(za>>>0);za=va+ya|0;ya=Da>>>0>za>>>0?za:Da;c[J>>2]=ya;if((xa|0)==0){c[K>>2]=0;La=Ka;break}za=ra+xa|0;if(za>>>0>(c[la>>2]|0)>>>0){R=52;break b}if((xa|0)>0){Ma=ra;Na=ya;Oa=Da;Pa=ua}else{La=Ka;break}while(1){ua=c[ma>>2]|0;Da=c[9890460+(ua*20|0)>>2]|0;ya=Pa+(Na>>>3)|0;xa=32-(c[9890456+(ua*20|0)>>2]|0)|0;ua=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((Na&7)>>>0)<<xa>>>(xa>>>0);xa=b[Da+(ua<<2)>>1]|0;ya=(b[Da+(ua<<2)+2>>1]|0)+Na|0;ua=Oa>>>0>ya>>>0?ya:Oa;c[J>>2]=ua;ya=a[e+1616+xa|0]|0;xa=c[ma>>2]|0;Da=c[9890460+(xa*20|0)>>2]|0;va=Pa+(ua>>>3)|0;wa=32-(c[9890456+(xa*20|0)>>2]|0)|0;xa=(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)>>>((ua&7)>>>0)<<wa>>>(wa>>>0);wa=b[Da+(xa<<2)>>1]|0;va=(b[Da+(xa<<2)+2>>1]|0)+ua|0;c[J>>2]=Oa>>>0>va>>>0?va:Oa;va=a[e+1616+wa|0]<<4|ya;c[K>>2]=Ma+1;a[Ma]=va;va=c[K>>2]|0;if(!(va>>>0<za>>>0)){break}Ma=va;Na=c[J>>2]|0;Oa=c[S>>2]|0;Pa=c[U>>2]|0}La=c[t>>2]|0}}while(0);ra=K2(La,g,v)|0;if((ra|0)<0){sa=ra;R=129;break}ra=K2(c[t>>2]|0,g,u)|0;if((ra|0)<0){sa=ra;R=129;break}ra=L2(c[t>>2]|0,g,j,0)|0;if((ra|0)<0){sa=ra;R=129;break}ra=L2(c[t>>2]|0,g,B,1)|0;if((ra|0)<0){sa=ra;R=129;break}Qa=c[t>>2]|0;ra=c[C>>2]|0;d:do{if((ra|0)!=0){if(ra>>>0>(c[V>>2]|0)>>>0){break}za=c[z>>2]|0;va=c[J>>2]|0;ya=c[S>>2]|0;wa=c[U>>2]|0;ua=wa+(va>>>3)|0;xa=32-za|0;Da=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((va&7)>>>0)<<xa>>>(xa>>>0);xa=va+za|0;za=ya>>>0>xa>>>0?xa:ya;c[J>>2]=za;if((Da|0)==0){c[C>>2]=0;break}xa=ra+Da|0;if(xa>>>0>(c[ja>>2]|0)>>>0){R=68;break b}va=d[wa+(za>>>3)|0]|0;ua=((za|0)<(ya|0))+za|0;c[J>>2]=ua;if((va&1<<(za&7)|0)!=0){za=wa+(ua>>>3)|0;va=(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)>>>((ua&7)>>>0);za=ua+4|0;c[J>>2]=ya>>>0>za>>>0?za:ya;mrc(ra|0,va&15|0,Da|0)|0;c[C>>2]=(c[C>>2]|0)+Da;break}if((Da|0)>0){Ra=ra;Sa=ua;Ta=ya;Ua=wa}else{break}while(1){wa=c[ka>>2]|0;ya=c[9890460+(wa*20|0)>>2]|0;ua=Ua+(Sa>>>3)|0;Da=32-(c[9890456+(wa*20|0)>>2]|0)|0;wa=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((Sa&7)>>>0)<<Da>>>(Da>>>0);Da=b[ya+(wa<<2)>>1]|0;ua=(b[ya+(wa<<2)+2>>1]|0)+Sa|0;c[J>>2]=Ta>>>0>ua>>>0?ua:Ta;ua=a[e+1816+Da|0]|0;c[C>>2]=Ra+1;a[Ra]=ua;ua=c[C>>2]|0;if(!(ua>>>0<xa>>>0)){break d}Ra=ua;Sa=c[J>>2]|0;Ta=c[S>>2]|0;Ua=c[U>>2]|0}}}while(0);ra=c[D>>2]|0;Va=qa<<3;xa=ca(Va,s)|0;ua=c[(c[Q>>2]|0)+(h<<2)>>2]|0;e:do{if(F){Da=(qa&1|0)!=0;wa=((ua|0)==0?ra:ua)+xa|0;ya=ra+xa|0;Wa=0;while(1){va=c[G>>2]|0;c[G>>2]=va+1;za=a[va]|0;Xa=za&255;f:do{if(Da&za<<24>>24==1){Ya=Wa+1|0;Za=ya+8|0;_a=wa+8|0}else{switch(Xa|0){case 4:{va=c[ba>>2]|0;c[ba>>2]=va+1;$a=a[va]|0;va=c[da>>2]|0;c[da>>2]=va+1;ab=a[va]|0;va=wa+((ca(ab,s)|0)+$a)|0;if(va>>>0<T>>>0|va>>>0>O>>>0){R=113;break b}mf[c[H>>2]&2047](ya,va,s,8);qe[c[ea>>2]&1023](p);va=c[J>>2]|0;Ca=c[S>>2]|0;ta=(c[U>>2]|0)+(va>>>3)|0;Ba=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((va&7)>>>0)&127;ta=va+7|0;c[J>>2]=Ca>>>0>ta>>>0?ta:Ca;I2(g,p,Ba);ef[c[fa>>2]&4095](ya,p,s);Ya=Wa;Za=ya;_a=wa;break f;break};case 5:{mrc(Y|0,0,256)|0;Ba=c[Z>>2]|0;Ca=b[Ba>>1]|0;c[Z>>2]=Ba+2;c[r>>2]=Ca;H2(g,r,1916656,-1);ef[c[_>>2]&4095](ya,s,r);Ya=Wa;Za=ya;_a=wa;break f;break};case 6:{Ca=c[W>>2]|0;c[W>>2]=Ca+1;mf[c[ga>>2]&2047](ya,a[Ca]|0,s,8);Ya=Wa;Za=ya;_a=wa;break f;break};case 7:{Ca=c[ba>>2]|0;c[ba>>2]=Ca+1;bb=a[Ca]|0;Ca=c[da>>2]|0;c[da>>2]=Ca+1;cb=a[Ca]|0;Ca=wa+((ca(cb,s)|0)+bb)|0;if(Ca>>>0<T>>>0|Ca>>>0>O>>>0){R=118;break b}mf[c[H>>2]&2047](ya,Ca,s,8);mrc(Y|0,0,256)|0;Ca=c[ha>>2]|0;Ba=b[Ca>>1]|0;c[ha>>2]=Ca+2;c[r>>2]=Ba;H2(g,r,1920752,-1);ef[c[ia>>2]&4095](ya,s,r);Ya=Wa;Za=ya;_a=wa;break f;break};case 0:{mf[c[H>>2]&2047](ya,wa,s,8);Ya=Wa;Za=ya;_a=wa;break f;break};case 1:{Ba=c[I>>2]|0;c[I>>2]=Ba+1;Ca=a[Ba]|0;db=Ca&255;g:do{switch(db|0){case 5:{mrc(Y|0,0,256)|0;Ba=c[Z>>2]|0;ta=b[Ba>>1]|0;c[Z>>2]=Ba+2;c[r>>2]=ta;H2(g,r,1916656,-1);ef[c[_>>2]&4095](q,8,r);R=96;break};case 6:{ta=c[W>>2]|0;c[W>>2]=ta+1;mf[c[$>>2]&2047](ya,a[ta]|0,s,16);break};case 3:{ta=c[J>>2]|0;Ba=c[S>>2]|0;va=(c[U>>2]|0)+(ta>>>3)|0;Aa=(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)>>>((ta&7)>>>0)&15;va=ta+4|0;ta=Ba>>>0>va>>>0?va:Ba;c[J>>2]=ta;va=0;eb=1915632+(Aa<<6)|0;Aa=c[V>>2]|0;fb=ta;while(1){ta=Aa+1|0;c[V>>2]=ta;gb=d[Aa]|0;hb=gb+1|0;ib=hb+va|0;if((ib|0)>64){R=82;break b}jb=d[(c[U>>2]|0)+(fb>>>3)|0]|0;kb=((fb|0)<(Ba|0))+fb|0;c[J>>2]=kb;lb=c[W>>2]|0;if((jb&1<<(fb&7)|0)==0){jb=eb;mb=0;nb=lb;while(1){ob=nb+1|0;c[W>>2]=ob;a[m+(d[jb]|0)|0]=a[nb]|0;pb=mb+1|0;if((pb|0)<(hb|0)){jb=jb+1|0;mb=pb;nb=ob}else{qb=ob;break}}}else{nb=lb+1|0;c[W>>2]=nb;mb=a[lb]|0;jb=eb;ob=0;while(1){a[m+(d[jb]|0)|0]=mb;pb=ob+1|0;if((pb|0)<(hb|0)){jb=jb+1|0;ob=pb}else{qb=nb;break}}}rb=eb+(gb+1)|0;if((ib|0)<63){va=ib;eb=rb;Aa=ta;fb=kb}else{break}}if((ib|0)!=63){R=95;break g}c[W>>2]=qb+1;a[m+(d[rb]|0)|0]=a[qb]|0;R=95;break};case 8:{fb=c[W>>2]|0;Aa=fb+1|0;c[W>>2]=Aa;c[l>>2]=d[fb]|0;c[W>>2]=fb+2;c[l+4>>2]=d[Aa]|0;Aa=0;fb=c[aa>>2]|0;while(1){eb=fb+1|0;c[aa>>2]=eb;va=d[fb]|0;Ba=Aa<<3;a[m+Ba|0]=c[l+((va&1)<<2)>>2];a[m+(Ba|1)|0]=c[l+((va>>>1&1)<<2)>>2];a[m+(Ba|2)|0]=c[l+((va>>>2&1)<<2)>>2];a[m+(Ba|3)|0]=c[l+((va>>>3&1)<<2)>>2];a[m+(Ba|4)|0]=c[l+((va>>>4&1)<<2)>>2];a[m+(Ba|5)|0]=c[l+((va>>>5&1)<<2)>>2];a[m+(Ba|6)|0]=c[l+((va>>>6&1)<<2)>>2];a[m+(Ba|7)|0]=c[l+(va>>>7<<2)>>2];va=Aa+1|0;if((va|0)<8){Aa=va;fb=eb}else{R=95;break}}break};case 9:{fb=0;Aa=c[W>>2]|0;while(1){eb=fb<<3;va=Aa+1|0;c[W>>2]=va;a[m+eb|0]=a[Aa]|0;Ba=Aa+2|0;c[W>>2]=Ba;a[m+(eb|1)|0]=a[va]|0;va=Aa+3|0;c[W>>2]=va;a[m+(eb|2)|0]=a[Ba]|0;Ba=Aa+4|0;c[W>>2]=Ba;a[m+(eb|3)|0]=a[va]|0;va=Aa+5|0;c[W>>2]=va;a[m+(eb|4)|0]=a[Ba]|0;Ba=Aa+6|0;c[W>>2]=Ba;a[m+(eb|5)|0]=a[va]|0;va=Aa+7|0;c[W>>2]=va;a[m+(eb|6)|0]=a[Ba]|0;Ba=Aa+8|0;c[W>>2]=Ba;a[m+(eb|7)|0]=a[va]|0;va=fb+1|0;if((va|0)<8){fb=va;Aa=Ba}else{R=95;break}}break};default:{R=94;break b}}}while(0);if((R|0)==95){R=0;if(!(Ca<<24>>24==6)){R=96}}if((R|0)==96){R=0;ef[c[X>>2]&4095](q,ya,s)}Ya=Wa+1|0;Za=ya+8|0;_a=wa+8|0;break f;break};case 2:{Aa=c[ba>>2]|0;c[ba>>2]=Aa+1;sb=a[Aa]|0;Aa=c[da>>2]|0;c[da>>2]=Aa+1;tb=a[Aa]|0;Aa=wa+((ca(tb,s)|0)+sb)|0;if(Aa>>>0<T>>>0|Aa>>>0>O>>>0){R=99;break b}mf[c[H>>2]&2047](ya,Aa,s,8);Ya=Wa;Za=ya;_a=wa;break f;break};case 3:{Aa=c[J>>2]|0;fb=c[S>>2]|0;Ba=(c[U>>2]|0)+(Aa>>>3)|0;va=(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)>>>((Aa&7)>>>0)&15;Ba=Aa+4|0;c[J>>2]=fb>>>0>Ba>>>0?Ba:fb;fb=0;Ba=1915632+(va<<6)|0;do{va=c[V>>2]|0;c[V>>2]=va+1;Aa=d[va]|0;va=Aa+1|0;fb=va+fb|0;if((fb|0)>64){R=103;break b}eb=c[J>>2]|0;nb=d[(c[U>>2]|0)+(eb>>>3)|0]|0;c[J>>2]=((eb|0)<(c[S>>2]|0))+eb;h:do{if((nb&1<<(eb&7)|0)==0){ob=Ba;jb=1;while(1){hb=c[W>>2]|0;c[W>>2]=hb+1;a[ya+(c[o+(d[ob]<<2)>>2]|0)|0]=a[hb]|0;if((jb|0)>=(va|0)){break h}ob=ob+1|0;jb=jb+1|0}}else{jb=c[W>>2]|0;c[W>>2]=jb+1;ob=a[jb]|0;jb=Ba;kb=0;while(1){a[ya+(c[o+(d[jb]<<2)>>2]|0)|0]=ob;ta=kb+1|0;if((ta|0)<(va|0)){jb=jb+1|0;kb=ta}else{break}}}}while(0);Ba=Ba+(Aa+1)|0;}while((fb|0)<63);if((fb|0)!=63){Ya=Wa;Za=ya;_a=wa;break f}Ca=c[W>>2]|0;c[W>>2]=Ca+1;a[ya+(c[o+(d[Ba]<<2)>>2]|0)|0]=a[Ca]|0;Ya=Wa;Za=ya;_a=wa;break f;break};case 8:{Ca=c[W>>2]|0;va=Ca+1|0;c[W>>2]=va;c[l>>2]=d[Ca]|0;c[W>>2]=Ca+2;c[l+4>>2]=d[va]|0;va=0;while(1){Ca=c[aa>>2]|0;c[aa>>2]=Ca+1;eb=d[Ca]|0;Ca=ca(va,s)|0;a[ya+Ca|0]=c[l+((eb&1)<<2)>>2];a[ya+(Ca+1)|0]=c[l+((eb>>>1&1)<<2)>>2];a[ya+(Ca+2)|0]=c[l+((eb>>>2&1)<<2)>>2];a[ya+(Ca+3)|0]=c[l+((eb>>>3&1)<<2)>>2];a[ya+(Ca+4)|0]=c[l+((eb>>>4&1)<<2)>>2];a[ya+(Ca+5)|0]=c[l+((eb>>>5&1)<<2)>>2];a[ya+(Ca+6)|0]=c[l+((eb>>>6&1)<<2)>>2];a[ya+(Ca+7)|0]=c[l+(eb>>>7<<2)>>2];eb=va+1|0;if((eb|0)<8){va=eb}else{Ya=Wa;Za=ya;_a=wa;break}}break};case 9:{va=c[W>>2]|0;Ba=ya;fb=va|0;eb=va+4|0;va=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=Ba|0;y=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=Ba+4|0;y=va;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=(c[W>>2]|0)+8|0;va=ya+s|0;Ba=eb|0;fb=eb+4|0;eb=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=va|0;y=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;fb=va+4|0;y=eb;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;fb=(c[W>>2]|0)+16|0;eb=ya+(s<<1)|0;va=fb|0;Ba=fb+4|0;fb=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;Ba=eb|0;y=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=eb+4|0;y=fb;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=(c[W>>2]|0)+24|0;fb=ya+(s*3|0)|0;eb=Ba|0;va=Ba+4|0;Ba=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;va=fb|0;y=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=fb+4|0;y=Ba;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=(c[W>>2]|0)+32|0;Ba=ya+(s<<2)|0;fb=va|0;eb=va+4|0;va=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;eb=Ba|0;y=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=Ba+4|0;y=va;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=(c[W>>2]|0)+40|0;va=ya+(s*5|0)|0;Ba=eb|0;fb=eb+4|0;eb=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=va|0;y=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;fb=va+4|0;y=eb;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;fb=(c[W>>2]|0)+48|0;eb=ya+(s*6|0)|0;va=fb|0;Ba=fb+4|0;fb=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;Ba=eb|0;y=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=eb+4|0;y=fb;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=(c[W>>2]|0)+56|0;fb=ya+(s*7|0)|0;eb=Ba|0;va=Ba+4|0;Ba=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;va=fb|0;y=d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=fb+4|0;y=Ba;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;c[W>>2]=(c[W>>2]|0)+64;Ya=Wa;Za=ya;_a=wa;break f;break};default:{R=121;break b}}}}while(0);za=Ya+1|0;if((za|0)>=(x|0)){break e}wa=_a+8|0;ya=Za+8|0;Wa=za}}}while(0);xa=qa+1|0;if((xa|0)<(w|0)){qa=xa}else{ub=J;break a}}if((R|0)==43){KIb(c[t>>2]|0,16,2591432,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==52){KIb(Ka,16,2618768,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==68){KIb(Qa,16,2147920,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==82){KIb(c[t>>2]|0,16,2457672,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==94){KIb(c[t>>2]|0,16,2208064,(vb=i,i=i+8|0,c[vb>>2]=db,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==99){KIb(c[t>>2]|0,16,2175624,(vb=i,i=i+16|0,c[vb>>2]=sb+(Wa<<3),c[vb+8>>2]=tb+Va,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==103){KIb(c[t>>2]|0,16,2457672,(vb=i,i=i+1|0,i=i+7&-8,c[vb>>2]=0,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==113){KIb(c[t>>2]|0,16,2175624,(vb=i,i=i+16|0,c[vb>>2]=$a+(Wa<<3),c[vb+8>>2]=ab+Va,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==118){KIb(c[t>>2]|0,16,2175624,(vb=i,i=i+16|0,c[vb>>2]=bb+(Wa<<3),c[vb+8>>2]=cb+Va,vb)|0);i=vb;sa=-1;i=k;return sa|0}else if((R|0)==121){KIb(c[t>>2]|0,16,2302072,(vb=i,i=i+8|0,c[vb>>2]=Xa,vb)|0);i=vb;sa=-1094995529;i=k;return sa|0}else if((R|0)==129){i=k;return sa|0}}else{ub=g+8|0}}while(0);R=c[ub>>2]|0;vb=R&31;if((vb|0)==0){sa=0;i=k;return sa|0}Xa=32-vb|0;vb=-R|0;t=(c[g+16>>2]|0)-R|0;if((Xa|0)<(vb|0)){wb=vb}else{wb=(t|0)<(Xa|0)?t:Xa}c[ub>>2]=wb+R;sa=0;i=k;return sa|0}function H2(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;g=i;i=i+1280|0;h=g|0;j=g+512|0;k=g+1024|0;c[h+256>>2]=4;c[j+256>>2]=0;c[h+260>>2]=24;c[j+260>>2]=0;c[h+264>>2]=44;c[j+264>>2]=0;c[h+268>>2]=1;c[j+268>>2]=3;c[h+272>>2]=2;c[j+272>>2]=3;c[h+276>>2]=3;c[j+276>>2]=3;l=a+8|0;m=c[l>>2]|0;n=a+16|0;o=c[n>>2]|0;p=a|0;a=c[p>>2]|0;q=a+(m>>>3)|0;r=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((m&7)>>>0)&15;q=m+4|0;c[l>>2]=o>>>0>q>>>0?q:o;o=r-1|0;if((o|0)>-1){q=r;r=64;m=70;s=0;t=o;o=a;u=a;v=a;w=a;x=a;while(1){a:do{if((r|0)<(m|0)){y=(t|0)==0;z=33-q|0;A=1<<t;B=r;C=m;D=s;E=r;F=o;G=u;H=v;I=w;J=x;while(1){K=C;L=D;M=E;N=F;O=G;P=H;b:while(1){Q=j+(M<<2)|0;R=h+(M<<2)|0;c:do{if(y){S=M;T=L;U=Q;V=R;W=N;while(1){X=S;Y=U;Z=V;d:while(1){while(1){if((c[Z>>2]|c[Y>>2]|0)==0){break}_=c[l>>2]|0;$=d[W+(_>>>3)|0]|0;aa=c[n>>2]|0;ba=((_|0)<(aa|0))+_|0;c[l>>2]=ba;if(($&1<<(_&7)|0)==0){break}da=c[Z>>2]|0;_=c[Y>>2]|0;if((_|0)==3){break d}else if((_|0)==2){ea=Y;fa=Z;ga=da;ha=X;ia=T;ja=22;break b}else if((_|0)==0){ka=Y;la=Z;ma=da;na=X;oa=T;ja=21;break b}else if((_|0)==1){pa=Y;qa=da;ra=X;sa=T;ta=W;ua=O;va=P;break c}}_=X+1|0;if((_|0)<(K|0)){X=_;Y=j+(_<<2)|0;Z=h+(_<<2)|0}else{wa=T;xa=K;ya=B;za=W;Aa=O;Ba=P;Ca=I;Da=J;break a}}_=(d[O+(ba>>>3)|0]|0)>>>((ba&7)>>>0);c[l>>2]=((ba|0)<(aa|0))+ba;c[b+((d[1915560+da|0]|0)<<2)>>2]=1-(_<<1&2);_=T+1|0;c[k+(T<<2)>>2]=da;c[Z>>2]=0;$=X+1|0;c[Y>>2]=0;if(($|0)<(K|0)){S=$;T=_;U=j+($<<2)|0;V=h+($<<2)|0;W=O}else{wa=_;xa=K;ya=B;za=O;Aa=O;Ba=P;Ca=I;Da=J;break a}}}else{W=M;V=L;U=Q;T=R;S=N;_=O;$=P;while(1){Ea=W;Fa=U;Ga=T;Ha=S;Ia=_;e:while(1){Ja=Ha;Ka=Ia;while(1){if((c[Ga>>2]|c[Fa>>2]|0)==0){La=Ja;Ma=Ka;break}Na=c[l>>2]|0;Oa=d[$+(Na>>>3)|0]|0;Pa=c[n>>2]|0;Qa=((Na|0)<(Pa|0))+Na|0;c[l>>2]=Qa;if((Oa&1<<(Na&7)|0)==0){La=$;Ma=$;break}Ra=c[Ga>>2]|0;Na=c[Fa>>2]|0;if((Na|0)==3){break e}else if((Na|0)==2){ea=Fa;fa=Ga;ga=Ra;ha=Ea;ia=V;ja=22;break b}else if((Na|0)==0){ka=Fa;la=Ga;ma=Ra;na=Ea;oa=V;ja=21;break b}else if((Na|0)==1){pa=Fa;qa=Ra;ra=Ea;sa=V;ta=$;ua=$;va=$;break c}else{Ja=$;Ka=$}}Ka=Ea+1|0;if((Ka|0)<(K|0)){Ea=Ka;Fa=j+(Ka<<2)|0;Ga=h+(Ka<<2)|0;Ha=La;Ia=Ma}else{wa=V;xa=K;ya=B;za=La;Aa=Ma;Ba=$;Ca=I;Da=J;break a}}Ia=I+(Qa>>>3)|0;Ha=(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)>>>((Qa&7)>>>0)<<z>>>(z>>>0);Ia=Qa+t|0;Y=Pa>>>0>Ia>>>0?Ia:Pa;c[l>>2]=Y;Ia=(d[I+(Y>>>3)|0]|0)>>>((Y&7)>>>0);c[l>>2]=((Y|0)<(Pa|0))+Y;Y=Ia&1;c[b+((d[1915560+Ra|0]|0)<<2)>>2]=((Ha|A)^-Y)+Y;Y=V+1|0;c[k+(V<<2)>>2]=Ra;c[Ga>>2]=0;Ha=Ea+1|0;c[Fa>>2]=0;if((Ha|0)<(K|0)){W=Ha;V=Y;U=j+(Ha<<2)|0;T=h+(Ha<<2)|0;S=I;_=I;$=I}else{wa=Y;xa=K;ya=B;za=I;Aa=I;Ba=I;Ca=I;Da=J;break a}}}}while(0);c[pa>>2]=2;c[h+(K<<2)>>2]=qa+4;R=K+1|0;c[j+(K<<2)>>2]=2;c[h+(R<<2)>>2]=qa+8;Q=K+2|0;c[j+(R<<2)>>2]=2;c[h+(Q<<2)>>2]=qa+12;c[j+(Q<<2)>>2]=2;Q=K+3|0;if((ra|0)<(Q|0)){K=Q;L=sa;M=ra;N=ta;O=ua;P=va}else{wa=sa;xa=Q;ya=B;za=ta;Aa=ua;Ba=va;Ca=I;Da=J;break a}}if((ja|0)==21){ja=0;c[la>>2]=ma+4;Sa=na;Ta=1;Ua=ka;Va=ma;Wa=oa}else if((ja|0)==22){ja=0;c[fa>>2]=0;Sa=ha+1|0;Ta=0;Ua=ea;Va=ga;Wa=ia}c[Ua>>2]=Ta;P=c[p>>2]|0;f:do{if(y){O=Va;N=B;M=Wa;L=1;while(1){Q=c[l>>2]|0;R=d[P+(Q>>>3)|0]|0;$=c[n>>2]|0;_=((Q|0)<($|0))+Q|0;c[l>>2]=_;if((R&1<<(Q&7)|0)==0){Q=(d[P+(_>>>3)|0]|0)>>>((_&7)>>>0);c[l>>2]=((_|0)<($|0))+_;c[b+((d[1915560+O|0]|0)<<2)>>2]=1-(Q<<1&2);c[k+(M<<2)>>2]=O;Xa=M+1|0;Ya=N}else{Q=N-1|0;c[h+(Q<<2)>>2]=O;c[j+(Q<<2)>>2]=3;Xa=M;Ya=Q}if((L|0)>=4){Za=Ya;_a=Xa;break f}O=O+1|0;N=Ya;M=Xa;L=L+1|0}}else{L=Va;M=B;N=Wa;O=1;while(1){Q=c[l>>2]|0;_=d[P+(Q>>>3)|0]|0;$=c[n>>2]|0;R=((Q|0)<($|0))+Q|0;c[l>>2]=R;if((_&1<<(Q&7)|0)==0){Q=P+(R>>>3)|0;_=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((R&7)>>>0)<<z>>>(z>>>0);Q=R+t|0;R=$>>>0>Q>>>0?Q:$;c[l>>2]=R;Q=(d[P+(R>>>3)|0]|0)>>>((R&7)>>>0);c[l>>2]=((R|0)<($|0))+R;R=Q&1;c[b+((d[1915560+L|0]|0)<<2)>>2]=((_|A)^-R)+R;c[k+(N<<2)>>2]=L;$a=N+1|0;ab=M}else{R=M-1|0;c[h+(R<<2)>>2]=L;c[j+(R<<2)>>2]=3;$a=N;ab=R}if((O|0)>=4){Za=ab;_a=$a;break f}L=L+1|0;M=ab;N=$a;O=O+1|0}}}while(0);if((Sa|0)<(K|0)){B=Za;C=K;D=_a;E=Sa;F=P;G=P;H=P;I=P;J=P}else{wa=_a;xa=K;ya=Za;za=P;Aa=P;Ba=P;Ca=P;Da=P;break}}}else{wa=s;xa=m;ya=r;za=o;Aa=u;Ba=v;Ca=w;Da=x}}while(0);J=t-1|0;if((J|0)>-1){q=t;r=ya;m=xa;s=wa;t=J;o=za;u=Aa;v=Ba;w=Ca;x=Da}else{bb=wa;cb=Da;break}}}else{bb=0;cb=a}do{if((f|0)==-1){a=c[l>>2]|0;Da=c[n>>2]|0;wa=cb+(a>>>3)|0;x=(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)>>>((a&7)>>>0)&15;wa=a+4|0;c[l>>2]=Da>>>0>wa>>>0?wa:Da;db=x}else{if(!(f>>>0>15>>>0)){db=f;break}KIb(0,16,2250648,(x=i,i=i+8|0,c[x>>2]=f,x)|0);i=x;i=g;return}}while(0);c[b>>2]=(ca(c[e+(db<<8)>>2]|0,c[b>>2]|0)|0)>>11;if((bb|0)>0){eb=0}else{i=g;return}do{f=c[k+(eb<<2)>>2]|0;l=b+((d[1915560+f|0]|0)<<2)|0;c[l>>2]=(ca(c[e+(db<<8)+(f<<2)>>2]|0,c[l>>2]|0)|0)>>11;eb=eb+1|0;}while((eb|0)<(bb|0));i=g;return}function I2(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;g=i;i=i+1280|0;h=g|0;j=g+512|0;k=g+1024|0;c[h+256>>2]=4;c[j+256>>2]=0;c[h+260>>2]=24;c[j+260>>2]=0;c[h+264>>2]=44;c[j+264>>2]=0;c[h+268>>2]=0;c[j+268>>2]=2;l=a+8|0;m=c[l>>2]|0;n=a+16|0;o=c[n>>2]|0;p=a|0;a=(c[p>>2]|0)+(m>>>3)|0;q=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>((m&7)>>>0)&7;a=m+3|0;c[l>>2]=o>>>0>a>>>0?a:o;o=f;f=1<<q;q=64;a=68;m=0;a:while(1){if((m|0)>0){r=-f|0;s=o;t=0;while(1){u=c[l>>2]|0;v=d[(c[p>>2]|0)+(u>>>3)|0]|0;c[l>>2]=((u|0)<(c[n>>2]|0))+u;if((v&1<<(u&7)|0)==0){w=s}else{u=e+(c[k+(t<<2)>>2]<<1)|0;v=b[u>>1]|0;b[u>>1]=(v<<16>>16<0?r:f)+(v&65535);v=s-1|0;if((v|0)<0){x=26;break a}else{w=v}}v=t+1|0;if((v|0)<(m|0)){s=w;t=v}else{y=m;z=q;A=a;B=q;C=w;break}}}else{y=m;z=q;A=a;B=q;C=o}b:while(1){D=y;t=z;s=A;E=C;c:while(1){r=t;F=s;d:while(1){G=r;e:while(1){v=(G|0)<(F|0);H=h+(G<<2)|0;I=j+(G<<2)|0;while(1){if(!v){break b}J=c[H>>2]|0;u=c[I>>2]|0;if((u|J|0)==0){break}K=c[l>>2]|0;L=c[p>>2]|0;M=d[L+(K>>>3)|0]|0;N=c[n>>2]|0;O=((K|0)<(N|0))+K|0;c[l>>2]=O;if((M&1<<(K&7)|0)==0){break}if((u|0)==2){x=17;break c}else if((u|0)==0){x=16;break c}else if((u|0)==1){break e}else if((u|0)==3){break d}}G=G+1|0}c[I>>2]=2;c[h+(F<<2)>>2]=J+4;v=F+1|0;c[j+(F<<2)>>2]=2;c[h+(v<<2)>>2]=J+8;u=F+2|0;c[j+(v<<2)>>2]=2;c[h+(u<<2)>>2]=J+12;c[j+(u<<2)>>2]=2;r=G;F=F+3|0}r=d[1915560+J|0]|0;c[k+(D<<2)>>2]=r;u=(d[L+(O>>>3)|0]|0)>>>((O&7)>>>0);c[l>>2]=((O|0)<(N|0))+O;v=u&1;b[e+(r<<1)>>1]=(f^-v)+v;c[H>>2]=0;c[I>>2]=0;v=E-1|0;if((v|0)<0){x=26;break a}else{D=D+1|0;t=G+1|0;s=F;E=v}}if((x|0)==16){x=0;c[H>>2]=J+4;P=G;Q=1}else if((x|0)==17){x=0;c[H>>2]=0;P=G+1|0;Q=0}c[I>>2]=Q;s=E;t=0;v=J;r=B;u=D;K=O;while(1){M=d[L+(K>>>3)|0]|0;R=((K|0)<(N|0))+K|0;c[l>>2]=R;if((M&1<<(K&7)|0)==0){M=d[1915560+v|0]|0;c[k+(u<<2)>>2]=M;S=(d[L+(R>>>3)|0]|0)>>>((R&7)>>>0);T=((R|0)<(N|0))+R|0;c[l>>2]=T;U=S&1;b[e+(M<<1)>>1]=(f^-U)+U;U=s-1|0;if((U|0)<0){x=26;break a}else{V=u+1|0;W=r;X=U;Y=T}}else{T=r-1|0;c[h+(T<<2)>>2]=v;c[j+(T<<2)>>2]=3;V=u;W=T;X=s;Y=R}R=t+1|0;if((R|0)<4){s=X;t=R;v=v+1|0;r=W;u=V;K=Y}else{y=V;z=P;A=F;B=W;C=X;continue b}}}K=f>>1;if((K|0)==0){x=26;break}else{o=E;f=K;q=B;a=F;m=D}}if((x|0)==26){i=g;return}}function J2(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;j=g+32|0;k=c[j>>2]|0;if((k|0)==0){l=0;i=h;return l|0}if(k>>>0>(c[g+36>>2]|0)>>>0){l=0;i=h;return l|0}m=c[g>>2]|0;n=f+8|0;o=c[n>>2]|0;p=f+16|0;q=c[p>>2]|0;r=f|0;f=c[r>>2]|0;s=f+(o>>>3)|0;t=32-m|0;u=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((o&7)>>>0)<<t>>>(t>>>0);t=o+m|0;m=q>>>0>t>>>0?t:q;c[n>>2]=m;if((u|0)==0){c[j>>2]=0;l=0;i=h;return l|0}t=k+u|0;if(t>>>0>(c[g+28>>2]|0)>>>0){KIb(e,16,2569368,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;l=-1094995529;i=h;return l|0}e=d[f+(m>>>3)|0]|0;o=((m|0)<(q|0))+m|0;c[n>>2]=o;if((e&1<<(m&7)|0)!=0){m=f+(o>>>3)|0;f=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((o&7)>>>0);m=o+4|0;c[n>>2]=q>>>0>m>>>0?m:q;mrc(k|0,f&15|0,u|0)|0;c[j>>2]=(c[j>>2]|0)+u;l=0;i=h;return l|0}if((u|0)<=0){l=0;i=h;return l|0}u=g+4|0;f=t;q=0;m=k;a:while(1){k=m;while(1){o=c[u>>2]|0;e=c[9890460+(o*20|0)>>2]|0;s=c[n>>2]|0;v=c[p>>2]|0;w=(c[r>>2]|0)+(s>>>3)|0;x=32-(c[9890456+(o*20|0)>>2]|0)|0;o=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((s&7)>>>0)<<x>>>(x>>>0);x=b[e+(o<<2)>>1]|0;w=(b[e+(o<<2)+2>>1]|0)+s|0;c[n>>2]=v>>>0>w>>>0?w:v;y=a[g+8+x|0]|0;if((y&255)>>>0<12>>>0){break}x=d[1915624+((y&255)-12)|0]|0;if((f-k|0)<(x|0)){l=-1094995529;z=16;break a}mrc(k|0,q|0,x|0)|0;v=(c[j>>2]|0)+x|0;c[j>>2]=v;if(v>>>0<t>>>0){k=v}else{l=0;z=16;break a}}c[j>>2]=k+1;a[k]=y;v=c[j>>2]|0;if(v>>>0<t>>>0){q=y;m=v}else{l=0;z=16;break}}if((z|0)==16){i=h;return l|0}return 0}function K2(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;j=g+32|0;k=c[j>>2]|0;if((k|0)==0){l=0;i=h;return l|0}if(k>>>0>(c[g+36>>2]|0)>>>0){l=0;i=h;return l|0}m=c[g>>2]|0;n=f+8|0;o=c[n>>2]|0;p=f+16|0;q=c[p>>2]|0;r=f|0;f=c[r>>2]|0;s=f+(o>>>3)|0;t=32-m|0;u=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((o&7)>>>0)<<t>>>(t>>>0);t=o+m|0;m=q>>>0>t>>>0?t:q;c[n>>2]=m;if((u|0)==0){c[j>>2]=0;l=0;i=h;return l|0}t=k+u|0;if(t>>>0>(c[g+28>>2]|0)>>>0){KIb(e,16,2641408,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;l=-1094995529;i=h;return l|0}e=d[f+(m>>>3)|0]|0;o=((m|0)<(q|0))+m|0;c[n>>2]=o;if((e&1<<(m&7)|0)!=0){m=f+(o>>>3)|0;e=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((o&7)>>>0)&15;m=o+4|0;s=q>>>0>m>>>0?m:q;c[n>>2]=s;if((e|0)==0){v=e&255}else{m=(d[f+(s>>>3)|0]|0)>>>((s&7)>>>0);c[n>>2]=((s|0)<(q|0))+s;s=m&1;v=(e^-s)+s&255}mrc(k|0,v|0,u|0)|0;c[j>>2]=(c[j>>2]|0)+u;l=0;i=h;return l|0}if((u|0)<=0){l=0;i=h;return l|0}u=g+4|0;v=k;k=o;o=q;q=f;while(1){f=c[u>>2]|0;s=c[9890460+(f*20|0)>>2]|0;e=q+(k>>>3)|0;m=32-(c[9890456+(f*20|0)>>2]|0)|0;f=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>((k&7)>>>0)<<m>>>(m>>>0);m=b[s+(f<<2)>>1]|0;e=(b[s+(f<<2)+2>>1]|0)+k|0;f=o>>>0>e>>>0?e:o;c[n>>2]=f;e=a[g+8+m|0]|0;if(e<<24>>24==0){w=0}else{m=(d[q+(f>>>3)|0]|0)>>>((f&7)>>>0);c[n>>2]=((f|0)<(o|0))+f;f=m&1;w=(e&255^-f)+f&255}c[j>>2]=v+1;a[v]=w;f=c[j>>2]|0;if(!(f>>>0<t>>>0)){l=0;break}v=f;k=c[n>>2]|0;o=c[p>>2]|0;q=c[r>>2]|0}i=h;return l|0}function L2(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;h=i;j=f+32|0;k=c[j>>2]|0;l=c[f+28>>2]|0;if((k|0)==0){m=0;i=h;return m|0}if(k>>>0>(c[f+36>>2]|0)>>>0){m=0;i=h;return m|0}n=c[f>>2]|0;f=e+8|0;o=c[f>>2]|0;p=c[e+16>>2]|0;q=c[e>>2]|0;e=q+(o>>>3)|0;r=32-n|0;s=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>((o&7)>>>0)<<r>>>(r>>>0);r=o+n|0;n=p>>>0>r>>>0?r:p;c[f>>2]=n;if((s|0)==0){c[j>>2]=0;m=0;i=h;return m|0}r=11-g|0;o=q+(n>>>3)|0;e=32-r|0;t=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((n&7)>>>0)<<e>>>(e>>>0);e=n+r|0;r=p>>>0>e>>>0?e:p;c[f>>2]=r;if((t|0)==0|(g|0)==0){u=t;v=r}else{g=(d[q+(r>>>3)|0]|0)>>>((r&7)>>>0);e=((r|0)<(p|0))+r|0;c[f>>2]=e;r=g&1;u=(t^-r)+r|0;v=e}e=l;if((e-k|0)<2){m=-1094995529;i=h;return m|0}l=k+2|0;b[k>>1]=u;k=s-1|0;a:do{if((k|0)>0){r=0;t=u;g=l;n=-s|0;o=v;b:while(1){w=(n|0)>-9;x=k-r|0;y=(x|0)>8?8:x;if((e-g>>1|0)<(y|0)){m=-1094995529;z=25;break}x=q+(o>>>3)|0;A=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((o&7)>>>0)&15;x=o+4|0;B=p>>>0>x>>>0?x:p;c[f>>2]=B;x=(y|0)>0;do{if((A|0)==0){if(!x){C=g;D=t;E=B;break}F=t&65535;G=0;H=g;while(1){b[H>>1]=F;I=G+1|0;if((I|0)<(y|0)){G=I;H=H+2|0}else{break}}C=g+((w?~n:8)<<1)|0;D=t;E=B}else{if(!x){C=g;D=t;E=B;break}H=32-A|0;G=0;F=t;I=g;J=B;while(1){K=q+(J>>>3)|0;L=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((J&7)>>>0)<<H>>>(H>>>0);K=J+A|0;M=p>>>0>K>>>0?K:p;c[f>>2]=M;if((L|0)==0){N=0;O=M}else{K=(d[q+(M>>>3)|0]|0)>>>((M&7)>>>0);P=((M|0)<(p|0))+M|0;c[f>>2]=P;M=K&1;N=(L^-M)+M|0;O=P}Q=N+F|0;b[I>>1]=Q;if((Q+32768|0)>>>0>65535>>>0){break b}P=I+2|0;M=G+1|0;if((M|0)<(y|0)){G=M;F=Q;I=P;J=O}else{C=P;D=Q;E=O;break}}}}while(0);y=r+8|0;if((y|0)<(k|0)){r=y;t=D;g=C;n=n+8|0;o=E}else{R=C;break a}}if((z|0)==25){i=h;return m|0}KIb(a,16,2123944,(o=i,i=i+8|0,c[o>>2]=Q,o)|0);i=o;m=-1094995529;i=h;return m|0}else{R=l}}while(0);c[j>>2]=R;m=0;i=h;return m|0}function M2(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+32|0;g=f|0;h=g|0;mrc(h|0,0,16)|0;j=f+16|0;k=b+8|0;l=c[k>>2]|0;m=b+16|0;n=c[m>>2]|0;o=b|0;b=c[o>>2]|0;p=b+(l>>>3)|0;q=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((l&7)>>>0)&15;p=l+4|0;c[k>>2]=n>>>0>p>>>0?p:n;c[e>>2]=q;if((q|0)==0){a[e+4|0]=0;a[e+5|0]=1;a[e+6|0]=2;a[e+7|0]=3;a[e+8|0]=4;a[e+9|0]=5;a[e+10|0]=6;a[e+11|0]=7;a[e+12|0]=8;a[e+13|0]=9;a[e+14|0]=10;a[e+15|0]=11;a[e+16|0]=12;a[e+17|0]=13;a[e+18|0]=14;a[e+19|0]=15;i=f;return}q=c[k>>2]|0;n=d[b+(q>>>3)|0]|0;p=c[m>>2]|0;l=((q|0)<(p|0))+q|0;c[k>>2]=l;r=b+(l>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((l&7)>>>0);if((n&1<<(q&7)|0)!=0){q=s&7;n=l+3|0;r=p>>>0>n>>>0?n:p;c[k>>2]=r;n=0;t=r;r=p;u=b;while(1){b=u+(t>>>3)|0;v=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((t&7)>>>0);b=t+4|0;c[k>>2]=r>>>0>b>>>0?b:r;a[e+4+n|0]=v&15;a[g+(v&15)|0]=1;v=n+1|0;if((v|0)>(q|0)){w=0;x=q;break}n=v;t=c[k>>2]|0;r=c[m>>2]|0;u=c[o>>2]|0}while(1){if((a[g+w|0]|0)==0){u=x+1|0;a[e+4+u|0]=w;y=u}else{y=x}u=w+1|0;if((u|0)<16&(y|0)<15){w=u;x=y}else{break}}i=f;return}y=l+2|0;c[k>>2]=p>>>0>y>>>0?y:p;a[h]=0;a[g+1|0]=1;a[g+2|0]=2;a[g+3|0]=3;a[g+4|0]=4;a[g+5|0]=5;a[g+6|0]=6;a[g+7|0]=7;a[g+8|0]=8;a[g+9|0]=9;a[g+10|0]=10;a[g+11|0]=11;a[g+12|0]=12;a[g+13|0]=13;a[g+14|0]=14;a[g+15|0]=15;g=s&3;s=0;p=j;j=h;while(1){h=1<<s;y=h<<1;l=0;do{x=h;w=j+(l+h)|0;u=h;r=j+l|0;t=p+l|0;while(1){z=t+1|0;n=c[k>>2]|0;q=d[(c[o>>2]|0)+(n>>>3)|0]|0;c[k>>2]=((n|0)<(c[m>>2]|0))+n;if((q&1<<(n&7)|0)==0){a[t]=a[r]|0;A=x;B=w;C=u-1|0;D=r+1|0}else{a[t]=a[w]|0;A=x-1|0;B=w+1|0;C=u;D=r}E=(C|0)==0;F=(A|0)==0;if(E|F){break}else{x=A;w=B;u=C;r=D;t=z}}if(E){G=z}else{r=z;u=D;w=C;while(1){x=w-1|0;a[r]=a[u]|0;if((x|0)==0){break}else{r=r+1|0;u=u+1|0;w=x}}G=t+(C+1)|0}if(!F){w=G;u=B;r=A;while(1){x=r-1|0;a[w]=a[u]|0;if((x|0)==0){break}else{w=w+1|0;u=u+1|0;r=x}}}l=l+y|0;}while((l|0)<16);l=s+1|0;if((l|0)>(g|0)){break}else{y=p;p=j;s=l;j=y}}nrc(e+4|0,p|0,16)|0;i=f;return}function N2(b){b=b|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0;f=i;h=c[b+60>>2]|0;j=c[b+412>>2]|0;if((j|0)<22050){k=9}else{k=(j|0)<44100?10:11}l=b+416|0;m=c[l>>2]|0;if((m-1|0)>>>0>1>>>0){KIb(b,16,2208032,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-1094995529;i=f;return o|0}n=(m|0)==1;m=b+448|0;c[m>>2]=n?4:3;c[m+4>>2]=n?0:0;if((c[b+100>>2]|0)>3){p=(a[(c[b+96>>2]|0)+3|0]|0)==98|0}else{p=0}c[h+20>>2]=p;n=b+12|0;m=(c[(c[n>>2]|0)+12>>2]|0)==86064;do{if(m){c[b+420>>2]=3;q=ca(c[l>>2]|0,j)|0;c[h+28>>2]=1;if((p|0)!=0){r=k;s=q;t=1;break}u=c[l>>2]|0;v=u>>>0>65535>>>0;w=v?u>>>16:u;u=v?16:0;if((w&65280|0)==0){x=u;y=w}else{x=u|8;y=w>>>8}r=x+k+(d[1359664+y|0]|0)|0;s=q;t=1}else{q=c[l>>2]|0;c[h+28>>2]=q;c[b+420>>2]=8;r=k;s=j;t=q}}while(0);j=1<<r;k=h+32|0;c[k>>2]=j;b=(j|0)/16|0;c[h+36>>2]=b;c[h+40>>2]=ca(j-b|0,t)|0;t=(s+1|0)/2|0;z=+(j|0);A=+S(z)*32768.0;if(m){B=2.0/A;g[h+52>>2]=B;C=B}else{B=z/A;g[h+52>>2]=B;C=B}m=h+52|0;j=0;B=C;while(1){g[5414056+(j<<2)>>2]=+$(+(j|0)*.15289165079593658)*B;s=j+1|0;if((s|0)>=96){break}j=s;B=+g[m>>2]}m=h+44|0;j=1;while(1){c[m>>2]=j;if((j|0)>=25){break}if((t|0)>(e[1248584+(j-1<<1)>>1]|0)){j=j+1|0}else{break}}s=hJb((j<<2)+4|0)|0;j=s;c[h+48>>2]=j;if((s|0)==0){o=-12;i=f;return o|0}c[j>>2]=2;s=c[m>>2]|0;if((s|0)>1){b=1;while(1){c[j+(b<<2)>>2]=((ca(e[1248584+(b-1<<1)>>1]|0,c[k>>2]|0)|0)/(t|0)|0)&-2;l=b+1|0;y=c[m>>2]|0;if((l|0)<(y|0)){b=l}else{D=y;break}}}else{D=s}c[j+(D<<2)>>2]=c[k>>2];c[h+24>>2]=1;k=h+18500|0;if((c[(c[n>>2]|0)+12>>2]|0)==86064){nZa(k,r,3)|0;o=0;i=f;return o|0}else{g5(k,r,1)|0;o=0;i=f;return o|0}return 0}function O2(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var h=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0.0,ea=0,fa=0,ga=0,ha=0.0,ia=0,ja=0,ka=0,la=0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0.0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;h=i;i=i+104|0;j=h|0;l=c[a+60>>2]|0;m=l;n=b;o=l+8|0;p=l+12|0;do{if((c[p>>2]|0)==(c[o>>2]|0)){q=f+28|0;r=c[q>>2]|0;if((r|0)==0){c[e>>2]=0;s=0;i=h;return s|0}if((r|0)<4){KIb(a,16,2301960,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}u=l+18496|0;v=iJb(c[u>>2]|0,r+16|0)|0;if((v|0)==0){s=-12;i=h;return s|0}mrc(v+(c[q>>2]|0)|0,0,16)|0;c[u>>2]=v;nrc(v|0,c[f+24>>2]|0,c[q>>2]|0)|0;v=c[u>>2]|0;u=c[q>>2]|0;r=u>>>0>268435455>>>0?-8:u<<3;u=r>>>0>2147483639>>>0|(v|0)==0;w=u?0:v;v=u?0:r;c[l>>2]=w;c[p>>2]=v;r=v+8|0;c[l+16>>2]=r;c[l+4>>2]=w+(v>>3);c[o>>2]=0;if(u){s=u?-1094995529:0;i=h;return s|0}else{u=c[q>>2]|0;c[o>>2]=(r|0)<32?r:32;x=u;break}}else{x=0}}while(0);f=l+32|0;u=b+76|0;c[u>>2]=c[f>>2];r=M4a(a,n,0)|0;if((r|0)<0){s=r;i=h;return s|0}r=c[b+64>>2]|0;b=(c[(c[a+12>>2]|0)+12>>2]|0)==86065;if(b){n=c[l+16>>2]|0;q=(c[o>>2]|0)+2|0;c[o>>2]=n>>>0>q>>>0?q:n}n=l+28|0;do{if((c[n>>2]|0)>0){q=l+20|0;v=l+16|0;w=l;y=l+52|0;z=l+44|0;A=j|0;B=l+18500|0;C=B;D=l+18604|0;E=B;B=l+18584|0;F=l+48|0;G=0;do{H=c[r+(G<<2)>>2]|0;I=H;J=c[o>>2]|0;K=c[p>>2]|0;L=K-J|0;if((c[q>>2]|0)==0){if((L|0)<58){M=61;break}N=c[v>>2]|0;O=c[w>>2]|0;P=O+(J>>>3)|0;Q=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((J&7)>>>0)&31;P=J+5|0;R=N>>>0>P>>>0?P:N;c[o>>2]=R;P=O+(R>>>3)|0;O=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((R&7)>>>0)&8388607;P=R+23|0;c[o>>2]=N>>>0>P>>>0?P:N;S=+Kqc(+(O>>>0>>>0),Q-23|0);Q=c[o>>2]|0;O=c[w>>2]|0;N=d[O+(Q>>>3)|0]|0;P=c[v>>2]|0;R=((Q|0)<(P|0))+Q|0;c[o>>2]=R;if((N&1<<(Q&7)|0)==0){T=S}else{T=-0.0-S}g[I>>2]=T*+g[y>>2];Q=O+(R>>>3)|0;N=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((R&7)>>>0)&31;Q=R+5|0;R=P>>>0>Q>>>0?Q:P;c[o>>2]=R;Q=O+(R>>>3)|0;O=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((R&7)>>>0)&8388607;Q=R+23|0;c[o>>2]=P>>>0>Q>>>0?Q:P;S=+Kqc(+(O>>>0>>>0),N-23|0);N=c[o>>2]|0;O=c[w>>2]|0;P=d[O+(N>>>3)|0]|0;Q=c[v>>2]|0;R=((N|0)<(Q|0))+N|0;c[o>>2]=R;if((P&1<<(N&7)|0)==0){U=S}else{U=-0.0-S}g[H+4>>2]=U*+g[y>>2];V=R;W=c[p>>2]|0;X=Q;Y=O}else{if((L|0)<64){M=61;break}L=c[v>>2]|0;O=c[w>>2]|0;Q=O+(J>>>3)|0;R=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((J&7)>>>0)&65535;Q=J+16|0;J=L>>>0>Q>>>0?Q:L;c[o>>2]=J;Q=O+(J>>>3)|0;N=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((J&7)>>>0);Q=J+16|0;J=L>>>0>Q>>>0?Q:L;c[o>>2]=J;g[I>>2]=+g[y>>2]*(c[k>>2]=N<<16|R,+g[k>>2]);R=O+(J>>>3)|0;N=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((J&7)>>>0)&65535;R=J+16|0;J=L>>>0>R>>>0?R:L;c[o>>2]=J;R=O+(J>>>3)|0;Q=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((J&7)>>>0);R=J+16|0;J=L>>>0>R>>>0?R:L;c[o>>2]=J;g[H+4>>2]=+g[y>>2]*(c[k>>2]=Q<<16|N,+g[k>>2]);V=J;W=K;X=L;Y=O}O=c[z>>2]|0;if((W-V|0)<(O<<3|0)){M=61;break}if((O|0)>0){L=0;K=V;do{J=Y+(K>>>3)|0;N=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((K&7)>>>0)&255;J=K+8|0;K=X>>>0>J>>>0?J:X;c[o>>2]=K;g[j+(L<<2)>>2]=+g[5414056+((N>>>0>95>>>0?95:N)<<2)>>2];L=L+1|0;}while((L|0)<(O|0))}O=c[f>>2]|0;if((O|0)>2){S=+g[A>>2];L=0;K=2;N=O;while(1){do{if((c[q>>2]|0)==0){O=c[o>>2]|0;J=c[w>>2]|0;Q=d[J+(O>>>3)|0]|0;H=c[v>>2]|0;R=((O|0)<(H|0))+O|0;c[o>>2]=R;if((Q&1<<(O&7)|0)==0){Z=K+8|0;_=R;$=H;aa=J;break}else{O=J+(R>>>3)|0;Q=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((R&7)>>>0)&15;O=R+4|0;R=H>>>0>O>>>0?O:H;c[o>>2]=R;Z=((d[679248+Q|0]|0)<<3)+K|0;_=R;$=H;aa=J;break}}else{Z=K+16|0;_=c[o>>2]|0;$=c[v>>2]|0;aa=c[w>>2]|0}}while(0);J=(Z|0)>(N|0)?N:Z;H=aa+(_>>>3)|0;R=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((_&7)>>>0)&15;H=_+4|0;Q=$>>>0>H>>>0?H:$;c[o>>2]=Q;do{if((R|0)==0){mrc(I+(K<<2)|0,0,J-K<<2|0)|0;H=c[F>>2]|0;if((c[H+(L<<2)>>2]|0)>>>0<J>>>0){O=L;while(1){ba=O+1|0;if((c[H+(ba<<2)>>2]|0)>>>0<J>>>0){O=ba}else{break}}da=+g[j+(O<<2)>>2];ea=ba}else{da=S;ea=L}fa=J;ga=ea;ha=da;ia=c[f>>2]|0}else{if((K|0)>=(J|0)){fa=K;ga=L;ha=S;ia=N;break}H=32-R|0;P=~Z;ja=~N;ka=(P|0)>(ja|0);la=c[F>>2]|0;ma=S;na=L;oa=K;pa=Q;while(1){if((c[la+(na<<2)>>2]|0)==(oa|0)){qa=na+1|0;ra=+g[j+(na<<2)>>2]}else{qa=na;ra=ma}sa=aa+(pa>>>3)|0;ta=(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)>>>((pa&7)>>>0)<<H>>>(H>>>0);sa=pa+R|0;ua=$>>>0>sa>>>0?sa:$;c[o>>2]=ua;do{if((ta|0)==0){g[I+(oa<<2)>>2]=0.0;va=ua}else{sa=d[aa+(ua>>>3)|0]|0;wa=((ua|0)<($|0))+ua|0;c[o>>2]=wa;if((sa&1<<(ua&7)|0)==0){g[I+(oa<<2)>>2]=ra*+(ta|0);va=wa;break}else{g[I+(oa<<2)>>2]=+(ta|0)*(-0.0-ra);va=wa;break}}}while(0);ta=oa+1|0;if((ta|0)<(J|0)){ma=ra;na=qa;oa=ta;pa=va}else{break}}fa=~(ka?P:ja);ga=qa;ha=ra;ia=N}}while(0);if((fa|0)<(ia|0)){S=ha;L=ga;K=fa;N=ia}else{break}}}if(b){g[I>>2]=+g[I>>2]*2.0;re[c[D>>2]&1023](C,I)}else{re[c[B>>2]&1023](E,I)}G=G+1|0;xa=c[n>>2]|0;}while((G|0)<(xa|0));if((M|0)==61){KIb(a,16,2250512,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}if((xa|0)<=0){M=15;break}G=l+36|0;E=l+24|0;B=0;C=xa;while(1){D=c[G>>2]|0;F=ca(D,C)|0;w=r+(B<<2)|0;if((c[E>>2]|0)==0&(D|0)>0){v=c[w>>2]|0;S=+(F|0);q=0;A=B;while(1){z=v+(q<<2)|0;g[z>>2]=(+(F-A|0)*+g[m+16448+(B<<10)+(q<<2)>>2]+ +(A|0)*+g[z>>2])/S;z=q+1|0;if((z|0)<(D|0)){q=z;A=A+C|0}else{break}}}nrc(m+16448+(B<<10)|0,(c[w>>2]|0)+((c[f>>2]|0)-D<<2)|0,D<<2)|0;A=B+1|0;q=c[n>>2]|0;if((A|0)<(q|0)){B=A;C=q}else{ya=E;break}}}else{M=15}}while(0);if((M|0)==15){ya=l+24|0}c[ya>>2]=0;ya=c[o>>2]|0;M=-ya&31;if((M|0)!=0){n=c[l+16>>2]|0;f=M+ya|0;c[o>>2]=n>>>0>f>>>0?f:n}c[u>>2]=(c[l+40>>2]|0)/(c[a+416>>2]|0)|0;c[e>>2]=1;s=x;i=h;return s|0}function P2(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;mJb(b+48|0);mJb(b+18496|0);d=b+18500|0;if((c[(c[a+12>>2]|0)+12>>2]|0)==86064){pZa(d);return 0}else{m5(d);return 0}return 0}function Q2(a){a=a|0;c[a+4>>2]=898;c[a>>2]=856;c[a+8>>2]=2106;return}function R2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;i=i+256|0;h=g|0;U2(h|0,f);U2(h+4|0,f+4|0);U2(h+8|0,f+8|0);U2(h+12|0,f+12|0);U2(h+16|0,f+16|0);U2(h+20|0,f+20|0);U2(h+24|0,f+24|0);U2(h+28|0,f+28|0);j=0;while(1){k=j<<3;l=c[h+(k<<2)>>2]|0;m=k|4;n=c[h+(m<<2)>>2]|0;o=n+l|0;p=k|2;q=c[h+(p<<2)>>2]|0;r=k|6;s=c[h+(r<<2)>>2]|0;t=s+q|0;u=((q-s|0)*2896|0)>>11;s=k|5;q=c[h+(s<<2)>>2]|0;v=k|3;w=c[h+(v<<2)>>2]|0;x=w+q|0;y=q-w|0;w=k|1;q=c[h+(w<<2)>>2]|0;z=k|7;A=c[h+(z<<2)>>2]|0;B=A+q|0;C=q-A|0;A=B+x|0;q=((C+y|0)*3784|0)>>11;D=q+(((y*-5352|0)>>11)-A)|0;y=(((B-x|0)*2896|0)>>11)-D|0;x=y+(((C*2217|0)>>11)-q)|0;q=o+127+t|0;c[f+(k<<2)>>2]=A+q>>8;k=l-n+127|0;n=k-t+u|0;c[f+(w<<2)>>2]=D+n>>8;w=k+t-u|0;c[f+(p<<2)>>2]=y+w>>8;p=o-t+127|0;c[f+(v<<2)>>2]=p-x>>8;c[f+(m<<2)>>2]=x+p>>8;c[f+(s<<2)>>2]=w-y>>8;c[f+(r<<2)>>2]=n-D>>8;c[f+(z<<2)>>2]=q-A>>8;A=j+1|0;if((A|0)<8){j=A}else{E=b;F=f;G=0;break}}while(1){a[E]=(d[E]|0)+(c[F>>2]|0);f=E+1|0;a[f]=(d[f]|0)+(c[F+4>>2]|0);f=E+2|0;a[f]=(d[f]|0)+(c[F+8>>2]|0);f=E+3|0;a[f]=(d[f]|0)+(c[F+12>>2]|0);f=E+4|0;a[f]=(d[f]|0)+(c[F+16>>2]|0);f=E+5|0;a[f]=(d[f]|0)+(c[F+20>>2]|0);f=E+6|0;a[f]=(d[f]|0)+(c[F+24>>2]|0);f=E+7|0;a[f]=(d[f]|0)+(c[F+28>>2]|0);f=G+1|0;if((f|0)<8){E=E+e|0;F=F+32|0;G=f}else{break}}i=g;return}function S2(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+256|0;g=f|0;U2(g|0,e);U2(g+4|0,e+4|0);U2(g+8|0,e+8|0);U2(g+12|0,e+12|0);U2(g+16|0,e+16|0);U2(g+20|0,e+20|0);U2(g+24|0,e+24|0);U2(g+28|0,e+28|0);e=0;do{h=e<<3;j=c[g+(h<<2)>>2]|0;k=c[g+((h|4)<<2)>>2]|0;l=k+j|0;m=j-k|0;k=c[g+((h|2)<<2)>>2]|0;j=c[g+((h|6)<<2)>>2]|0;n=j+k|0;o=((k-j|0)*2896|0)>>11;j=c[g+((h|5)<<2)>>2]|0;k=c[g+((h|3)<<2)>>2]|0;p=k+j|0;q=j-k|0;k=c[g+((h|1)<<2)>>2]|0;j=c[g+((h|7)<<2)>>2]|0;h=j+k|0;r=k-j|0;j=h+p|0;k=((r+q|0)*3784|0)>>11;s=k+(((q*-5352|0)>>11)-j)|0;q=(((h-p|0)*2896|0)>>11)-s|0;p=((r*2217|0)>>11)-k+q|0;k=n+l+127|0;r=ca(e,d)|0;a[b+r|0]=(k+j|0)>>>8;h=m-n+o+127|0;a[b+(r+1)|0]=(h+s|0)>>>8;t=m-o+n+127|0;a[b+(r+2)|0]=(t+q|0)>>>8;o=l-n+127|0;a[b+(r+3)|0]=(o-p|0)>>>8;a[b+(r+4)|0]=(o+p|0)>>>8;a[b+(r+5)|0]=(t-q|0)>>>8;a[b+(r+6)|0]=(h-s|0)>>>8;a[b+(r+7)|0]=(k-j|0)>>>8;e=e+1|0;}while((e|0)<8);i=f;return}function T2(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=a;a=0;g=c;h=c+e|0;while(1){c=(d[f]|0)*257&65535;b[h>>1]=c;b[g>>1]=c;c=(d[f+1|0]|0)*257&65535;b[h+2>>1]=c;b[g+2>>1]=c;c=(d[f+2|0]|0)*257&65535;b[h+4>>1]=c;b[g+4>>1]=c;c=(d[f+3|0]|0)*257&65535;b[h+6>>1]=c;b[g+6>>1]=c;c=(d[f+4|0]|0)*257&65535;b[h+8>>1]=c;b[g+8>>1]=c;c=(d[f+5|0]|0)*257&65535;b[h+10>>1]=c;b[g+10>>1]=c;c=(d[f+6|0]|0)*257&65535;b[h+12>>1]=c;b[g+12>>1]=c;c=(d[f+7|0]|0)*257&65535;b[h+14>>1]=c;b[g+14>>1]=c;c=a+1|0;if((c|0)<8){f=f+8|0;a=c;g=g+(e<<1)|0;h=h+(e<<1)|0}else{break}}return}function U2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[b+32>>2]|0;e=c[b+64>>2]|0;f=c[b+96>>2]|0;g=c[b+128>>2]|0;h=c[b+160>>2]|0;i=c[b+192>>2]|0;j=c[b+224>>2]|0;k=c[b>>2]|0;if((e|d|f|g|h|i|j|0)==0){c[a+224>>2]=k;c[a+192>>2]=k;c[a+160>>2]=k;c[a+128>>2]=k;c[a+96>>2]=k;c[a+64>>2]=k;c[a+32>>2]=k;c[a>>2]=k;return}else{b=k+g|0;l=k-g|0;g=i+e|0;k=((e-i|0)*2896|0)>>11;i=h+f|0;e=h-f|0;f=j+d|0;h=d-j|0;j=f+i|0;d=((h+e|0)*3784|0)>>11;m=d+(((e*-5352|0)>>11)-j)|0;e=(((f-i|0)*2896|0)>>11)-m|0;i=((h*2217|0)>>11)-d+e|0;d=b+g|0;c[a>>2]=d+j;h=k-g+l|0;c[a+32>>2]=m+h;f=l-k+g|0;c[a+64>>2]=e+f;k=b-g|0;c[a+96>>2]=k-i;c[a+128>>2]=i+k;c[a+160>>2]=f-e;c[a+192>>2]=h-m;c[a+224>>2]=d-j;return}}function V2(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;e=c[a+60>>2]|0;c[a+140>>2]=11;f=c[a+96>>2]|0;do{if((f|0)==0){c[e+72>>2]=8;c[e+68>>2]=0;g=0;h=0;j=7}else{k=d[f]|0;c[e+72>>2]=k;l=d[f+1|0]|0;c[e+68>>2]=l;m=f+2|0;if((c[a+100>>2]|0)<(-(l&1)<<4&48|(k&-(l>>>1&1))<<8|2|0)){KIb(a,16,2208e3,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=b;return o|0}k=e+68|0;if((l&1|0)==0){g=l;h=m;j=7;break}l=e+4|0;p=m;m=0;while(1){q=(d[p+1|0]|0)<<8|(d[p]|0)<<16|(d[p+2|0]|0);c[l+(m<<2)>>2]=q<<2|q>>>4&197379|-16777216;q=m+1|0;if((q|0)<16){p=p+3|0;m=q}else{break}}r=f+50|0;s=c[k>>2]|0}}while(0);if((j|0)==7){c[e+4>>2]=c[353122]|-16777216;c[e+8>>2]=c[353123]|-16777216;c[e+12>>2]=c[353124]|-16777216;c[e+16>>2]=c[353125]|-16777216;c[e+20>>2]=c[353126]|-16777216;c[e+24>>2]=c[353127]|-16777216;c[e+28>>2]=c[353128]|-16777216;c[e+32>>2]=c[353129]|-16777216;c[e+36>>2]=c[353130]|-16777216;c[e+40>>2]=c[353131]|-16777216;c[e+44>>2]=c[353132]|-16777216;c[e+48>>2]=c[353133]|-16777216;c[e+52>>2]=c[353134]|-16777216;c[e+56>>2]=c[353135]|-16777216;c[e+60>>2]=c[353136]|-16777216;c[e+64>>2]=c[353137]|-16777216;r=h;s=g}do{if((s&2|0)==0){g=e+72|0;h=c[g>>2]|0;if((h|0)==16){c[e+76>>2]=1961016;break}else if((h|0)!=8){KIb(a,24,2175592,(n=i,i=i+8|0,c[n>>2]=h,n)|0);i=n;c[g>>2]=8}c[e+76>>2]=1965880}else{c[e+76>>2]=r}}while(0);r=UHb()|0;c[e>>2]=r;o=(r|0)==0?-12:0;i=b;return o|0}function W2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=b+60|0;i=c[h>>2]|0;j=c[g+24>>2]|0;k=j;l=c[g+28>>2]|0;g=j+l|0;c[i+84>>2]=0;c[i+80>>2]=0;m=i;n=N4a(b,c[m>>2]|0)|0;if((n|0)<0){o=n;return o|0}n=c[m>>2]|0;c[n+88>>2]=1;c[n+304>>2]=1;nrc(c[n+4>>2]|0,i+4|0,64)|0;i=c[b+48>>2]|0;a:do{if((i|0)==1480739150){if((l|0)<=2){break}n=b+124|0;p=b+120|0;q=(-k|0)-l|0;r=j;s=j+2|0;while(1){t=a[r]|0;u=t&255;v=u>>>6;w=(u&63)+1|0;u=r+1|0;b:do{if((v|0)==0){x=0;y=u;while(1){z=y+1|0;if(!(z>>>0<g>>>0)){A=y;break b}B=d[z]|0;z=c[h>>2]|0;C=z+84|0;D=c[C>>2]|0;E=z+72|0;F=c[E>>2]|0;do{if((D|0)<=((c[n>>2]|0)-F|0)){G=c[z>>2]|0;H=c[G+32>>2]|0;I=ca(H,D)|0;J=z+80|0;T3((c[G>>2]|0)+(I+(c[J>>2]|0))|0,H,c[z+76>>2]|0,F,d[y]|0,B&15,B>>>4);H=(c[J>>2]|0)+8|0;c[J>>2]=H;if((H|0)<=((c[p>>2]|0)-8|0)){break}c[J>>2]=0;c[C>>2]=(c[C>>2]|0)+(c[E>>2]|0)}}while(0);E=y+2|0;C=x+1|0;if((C|0)<(w|0)){x=C;y=E}else{A=E;break}}}else if((v|0)==3){y=d[u]|0;x=r+3|0;E=d[s]|0;if(!(x>>>0<g>>>0)){A=x;break}C=E&15;B=E>>>4;E=1;while(1){F=c[h>>2]|0;z=F+84|0;D=c[z>>2]|0;J=F+72|0;H=c[J>>2]|0;do{if((D|0)<=((c[n>>2]|0)-H|0)){I=c[F>>2]|0;G=c[I+32>>2]|0;K=ca(G,D)|0;L=F+80|0;T3((c[I>>2]|0)+(K+(c[L>>2]|0))|0,G,c[F+76>>2]|0,H,y,C,B);G=(c[L>>2]|0)+8|0;c[L>>2]=G;if((G|0)<=((c[p>>2]|0)-8|0)){break}c[L>>2]=0;c[z>>2]=(c[z>>2]|0)+(c[J>>2]|0)}}while(0);if((E|0)>=(w|0)){A=x;break b}E=E+1|0}}else if((v|0)==2){E=d[u]|0;if(!(s>>>0<g>>>0)){A=s;break}x=E&15;B=E>>>4;E=s+q|0;C=~(t&63);y=-(E>>>0>C>>>0?E:C)|0;C=1;E=s;while(1){J=E+1|0;z=c[h>>2]|0;H=z+84|0;F=c[H>>2]|0;D=z+72|0;L=c[D>>2]|0;do{if((F|0)<=((c[n>>2]|0)-L|0)){G=c[z>>2]|0;K=c[G+32>>2]|0;I=ca(K,F)|0;M=z+80|0;T3((c[G>>2]|0)+(I+(c[M>>2]|0))|0,K,c[z+76>>2]|0,L,d[E]|0,x,B);K=(c[M>>2]|0)+8|0;c[M>>2]=K;if((K|0)<=((c[p>>2]|0)-8|0)){break}c[M>>2]=0;c[H>>2]=(c[H>>2]|0)+(c[D>>2]|0)}}while(0);if(!((C|0)<(w|0)&J>>>0<g>>>0)){break}C=C+1|0;E=J}A=s+y|0}else if((v|0)==1){E=d[u]|0;if(!(s>>>0<g>>>0)){A=s;break}C=s+q|0;B=~(t&63);x=-(C>>>0>B>>>0?C:B)|0;B=1;C=s;while(1){D=C+1|0;H=d[C]|0;L=c[h>>2]|0;z=L+84|0;F=c[z>>2]|0;M=L+72|0;K=c[M>>2]|0;do{if((F|0)<=((c[n>>2]|0)-K|0)){I=c[L>>2]|0;G=c[I+32>>2]|0;N=ca(G,F)|0;O=L+80|0;T3((c[I>>2]|0)+(N+(c[O>>2]|0))|0,G,c[L+76>>2]|0,K,E,H&15,H>>>4);G=(c[O>>2]|0)+8|0;c[O>>2]=G;if((G|0)<=((c[p>>2]|0)-8|0)){break}c[O>>2]=0;c[z>>2]=(c[z>>2]|0)+(c[M>>2]|0)}}while(0);if(!((B|0)<(w|0)&D>>>0<g>>>0)){break}B=B+1|0;C=D}A=s+x|0}else{A=u}}while(0);u=A+2|0;if(u>>>0<g>>>0){r=A;s=u}else{break}}}else if((i|0)==4801606){if((l|0)<=2){break}s=b+124|0;r=b+120|0;p=j;n=j+2|0;while(1){q=p;u=(d[q]|d[q+1|0]<<8)<<16>>16;c:do{if(u<<16>>16==1){q=p+6|0;if(q>>>0>g>>>0){break a}if((a[n]|0)==0){P=q;break}w=p+5|0;t=p+4|0;v=1;while(1){C=d[w]|0;B=c[h>>2]|0;E=B+84|0;y=c[E>>2]|0;M=B+72|0;z=c[M>>2]|0;do{if((y|0)<=((c[s>>2]|0)-z|0)){H=c[B>>2]|0;K=c[H+32>>2]|0;L=ca(K,y)|0;F=B+80|0;T3((c[H>>2]|0)+(L+(c[F>>2]|0))|0,K,c[B+76>>2]|0,z,d[t]|0,C&15,C>>>4);K=(c[F>>2]|0)+8|0;c[F>>2]=K;if((K|0)<=((c[r>>2]|0)-8|0)){break}c[F>>2]=0;c[E>>2]=(c[E>>2]|0)+(c[M>>2]|0)}}while(0);if((v|0)>=(d[n]|0)){P=q;break c}v=v+1|0}}else{v=d[p+1|0]|0;q=c[h>>2]|0;t=q+84|0;w=c[t>>2]|0;x=q+72|0;M=c[x>>2]|0;if((w|0)>((c[s>>2]|0)-M|0)){P=n;break}E=c[q>>2]|0;C=c[E+32>>2]|0;z=ca(C,w)|0;w=q+80|0;T3((c[E>>2]|0)+(z+(c[w>>2]|0))|0,C,c[q+76>>2]|0,M,u&255,v&15,v>>>4);v=(c[w>>2]|0)+8|0;c[w>>2]=v;if((v|0)<=((c[r>>2]|0)-8|0)){P=n;break}c[w>>2]=0;c[t>>2]=(c[t>>2]|0)+(c[x>>2]|0);P=n}}while(0);u=P+2|0;if(u>>>0<g>>>0){p=P;n=u}else{break}}}else{if((l|0)<=1){break}n=b+124|0;p=b+120|0;r=j;s=j+1|0;while(1){u=d[s]|0;x=c[h>>2]|0;t=x+84|0;w=c[t>>2]|0;v=x+72|0;M=c[v>>2]|0;do{if((w|0)<=((c[n>>2]|0)-M|0)){q=c[x>>2]|0;C=c[q+32>>2]|0;z=ca(C,w)|0;E=x+80|0;T3((c[q>>2]|0)+(z+(c[E>>2]|0))|0,C,c[x+76>>2]|0,M,d[r]|0,u&15,u>>>4);C=(c[E>>2]|0)+8|0;c[E>>2]=C;if((C|0)<=((c[p>>2]|0)-8|0)){break}c[E>>2]=0;c[t>>2]=(c[t>>2]|0)+(c[v>>2]|0)}}while(0);v=r+3|0;if(!(v>>>0<g>>>0)){break a}r=r+2|0;s=v}}}while(0);g=YHb(e,c[m>>2]|0)|0;if((g|0)<0){o=g;return o|0}c[f>>2]=1;o=l;return o|0}function X2(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function Y2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b+4|0;e=c[d>>2]|0;f=e&7;g=b|0;h=c[g>>2]|0;if((e|0)>(f|0)){i=e;j=h<<f;k=i-f|0;c[g>>2]=j;c[d>>2]=k;return}else{l=je(h<<e|0)|0;h=b+12|0;b=c[h>>2]|0;y=l;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;i=e+32|0;j=0;k=i-f|0;c[g>>2]=j;c[d>>2]=k;return}}function Z2(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a[d]|0;if(!(f<<24>>24==0)){g=b|0;h=b+4|0;i=b+12|0;j=d;d=f;f=c[g>>2]|0;k=c[h>>2]|0;while(1){l=d<<24>>24;if((k|0)>8){m=k-8|0;n=f<<8|l}else{o=je(l>>>((8-k|0)>>>0)|f<<k|0)|0;p=c[i>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;m=k+24|0;n=l}c[g>>2]=n;c[h>>2]=m;l=j+1|0;p=a[l]|0;if(p<<24>>24==0){break}else{j=l;d=p;f=n;k=m}}}if((e|0)==0){return}e=b|0;m=c[e>>2]|0;k=b+4|0;n=c[k>>2]|0;if((n|0)>8){q=n-8|0;r=m<<8}else{f=je(m<<n|0)|0;m=b+12|0;b=c[m>>2]|0;y=f;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;q=n+24|0;r=0}c[e>>2]=r;c[k>>2]=q;return}function _2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=f>>4;h=f&15;if((f|0)==0){return}do{if((g|0)<16){i=6}else{f=b+4|0;j=c[f>>2]|0;k=b+8|0;l=b+12|0;if((-j&7|0)!=0){i=6;break}m=c[k>>2]|0;n=c[l>>2]|0;o=b|0;if((32-j+(n-m<<3)&31|0)==0){p=0;q=j;r=n}else{s=0;t=c[o>>2]|0;u=j;j=m;m=n;while(1){n=d[e+s|0]|0;if((u|0)>8){v=u-8|0;w=t<<8|n;x=j;z=m}else{A=m;y=je(n>>>((8-u|0)>>>0)|t<<u|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;A=(c[l>>2]|0)+4|0;c[l>>2]=A;v=u+24|0;w=n;x=c[k>>2]|0;z=A}c[o>>2]=w;c[f>>2]=v;A=s+1|0;if((32-v+(z-x<<3)&31|0)==0){p=A;q=v;r=z;break}else{s=A;t=w;u=v;j=x;m=z}}}if((q|0)<32){m=c[o>>2]<<q;c[o>>2]=m;j=m>>>24&255;m=r;while(1){c[l>>2]=m+1;a[m]=j;u=c[o>>2]|0;c[o>>2]=u<<8;t=(c[f>>2]|0)+8|0;c[f>>2]=t;if((t|0)>=32){break}j=u>>>16&255;m=c[l>>2]|0}B=c[l>>2]|0}else{B=r}c[f>>2]=32;c[o>>2]=0;m=g<<1;j=m-p|0;nrc(B|0,e+p|0,j)|0;c[l>>2]=(c[l>>2]|0)+j;C=m;D=o;E=f}}while(0);if((i|0)==6){i=b|0;p=b+4|0;if((g|0)>0){B=b+12|0;r=0;q=c[i>>2]|0;z=c[p>>2]|0;while(1){x=e+(r<<1)|0;v=(he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535;if((z|0)>16){F=z-16|0;G=q<<16|v}else{x=je(v>>>((16-z|0)>>>0)|q<<z|0)|0;w=c[B>>2]|0;y=x;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;F=z+16|0;G=v}c[i>>2]=G;c[p>>2]=F;v=r+1|0;if((v|0)<(g|0)){r=v;q=G;z=F}else{break}}}C=g<<1;D=i;E=p}p=e+C|0;C=((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)>>>((16-h|0)>>>0);p=c[D>>2]|0;e=c[E>>2]|0;if((e|0)>(h|0)){H=e-h|0;I=p<<h|C}else{i=je(C>>>((h-e|0)>>>0)|p<<e|0)|0;p=b+12|0;b=c[p>>2]|0;y=i;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;H=32-h+e|0;I=C}c[D>>2]=I;c[E>>2]=H;return}function $2(f,g,h,j,k,l,m,n,o,p,q,r,s){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;var t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;t=i;i=i+12e3|0;u=t|0;c[f>>2]=g;v=(s&4|0)!=0;do{if(v){w=f+16|0;x=f;y=f+20|0;while(1){z=(E=c[w>>2]|0,(c[w>>2]|0)==0?(c[w>>2]=x)|0:0,E);if((z|0)==0){A=8;break}if((z|0)==(y|0)){A=5;break}}if((A|0)==5){y=c[f+8>>2]|0;if((y|0)==0){KIb(0,0,2587656,(B=i,i=i+24|0,c[B>>2]=2612264,c[B+8>>2]=2457328,c[B+16>>2]=284,B)|0);i=B;Hd();return 0}if((y|0)==(c[f+12>>2]|0)){C=0;i=t;return C|0}else{KIb(0,0,2587656,(B=i,i=i+24|0,c[B>>2]=2612264,c[B+8>>2]=2457328,c[B+16>>2]=284,B)|0);i=B;Hd();return 0}}else if((A|0)==8){if((c[f+8>>2]|0)!=0){KIb(0,0,2587656,(B=i,i=i+24|0,c[B>>2]=2367448,c[B+8>>2]=2457328,c[B+16>>2]=288,B)|0);i=B;Hd();return 0}if((h+1|0)>>>0<1501>>>0){D=u|0;break}else{KIb(0,0,2587656,(B=i,i=i+24|0,c[B>>2]=2301848,c[B+8>>2]=2457328,c[B+16>>2]=289,B)|0);i=B;Hd();return 0}}}else{c[f+4>>2]=0;c[f+12>>2]=0;c[f+8>>2]=0;y=hJb((h<<3)+8|0)|0;if((y|0)==0){C=-12}else{D=y;break}i=t;return C|0}}while(0);u=(p|0)==0;if(!((r|0)<3|u)){KIb(0,0,2587656,(B=i,i=i+24|0,c[B>>2]=2250432,c[B+8>>2]=2457328,c[B+16>>2]=302,B)|0);i=B;Hd();return 0}y=(h|0)>0;a:do{if(y){x=g*3|0;w=(s&2|0)==0;z=0;F=0;while(1){H=j+(ca(F,k)|0)|0;if((l|0)==2){I=b[H>>1]&255;a[D+(z<<3)|0]=I;J=I}else if((l|0)==1){I=a[H]|0;a[D+(z<<3)|0]=I;J=I}else{I=c[H>>2]&255;a[D+(z<<3)|0]=I;J=I}K=J&255;if((K|0)>(g|0)){if((K|0)>(x|0)|(J&255)>>>0>32>>>0){A=25;break}I=m+(ca(F,n)|0)|0;if((o|0)==2){H=e[I>>1]|0;c[D+(z<<3)+4>>2]=H;L=H}else if((o|0)==1){H=d[I]|0;c[D+(z<<3)+4>>2]=H;L=H}else{H=c[I>>2]|0;c[D+(z<<3)+4>>2]=H;L=H}H=0;I=yrc(1,0,J&255|0)|0;M=G;if(!((H|0)<(M|0)|(H|0)==(M|0)&L>>>0<I>>>0)){A=32;break}if(w){N=L<<32-K}else{N=(d[1316536+(L>>>8&255)|0]|0)<<16|(d[1316536+(L&255)|0]|0)<<24|(d[1316536+(L>>>16&255)|0]|0)<<8|(d[1316536+(L>>>24)|0]|0)}c[D+(z<<3)+4>>2]=N;do{if(u){b[D+(z<<3)+2>>1]=F}else{I=p+(ca(F,q)|0)|0;if((r|0)==2){b[D+(z<<3)+2>>1]=b[I>>1]|0;break}else if((r|0)==1){b[D+(z<<3)+2>>1]=d[I]|0;break}else{b[D+(z<<3)+2>>1]=c[I>>2];break}}}while(0);O=z+1|0}else{O=z}I=F+1|0;if((I|0)<(h|0)){z=O;F=I}else{A=45;break}}if((A|0)==25){KIb(0,16,2207968,(B=i,i=i+8|0,c[B>>2]=K,B)|0);i=B;if(v){C=-1;i=t;return C|0}kJb(D|0);C=-1;i=t;return C|0}else if((A|0)==32){KIb(0,16,2175528,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;if(v){C=-1;i=t;return C|0}kJb(D|0);C=-1;i=t;return C|0}else if((A|0)==45){F=D|0;cd(F|0,O|0,8,962);if(!y){P=O;Q=F;break}z=g*3|0;w=(s&2|0)==0;x=O;I=0;while(1){M=j+(ca(I,k)|0)|0;if((l|0)==1){H=a[M]|0;a[D+(x<<3)|0]=H;R=H}else if((l|0)==2){H=b[M>>1]&255;a[D+(x<<3)|0]=H;R=H}else{H=c[M>>2]&255;a[D+(x<<3)|0]=H;R=H}S=R&255;if(R<<24>>24==0|(S|0)>(g|0)){T=x}else{if((S|0)>(z|0)|(R&255)>>>0>32>>>0){A=53;break}H=m+(ca(I,n)|0)|0;if((o|0)==1){M=d[H]|0;c[D+(x<<3)+4>>2]=M;U=M}else if((o|0)==2){M=e[H>>1]|0;c[D+(x<<3)+4>>2]=M;U=M}else{M=c[H>>2]|0;c[D+(x<<3)+4>>2]=M;U=M}M=0;H=yrc(1,0,R&255|0)|0;V=G;if(!((M|0)<(V|0)|(M|0)==(V|0)&U>>>0<H>>>0)){A=60;break}if(w){W=U<<32-S}else{W=(d[1316536+(U>>>8&255)|0]|0)<<16|(d[1316536+(U&255)|0]|0)<<24|(d[1316536+(U>>>16&255)|0]|0)<<8|(d[1316536+(U>>>24)|0]|0)}c[D+(x<<3)+4>>2]=W;do{if(u){b[D+(x<<3)+2>>1]=I}else{H=p+(ca(I,q)|0)|0;if((r|0)==1){b[D+(x<<3)+2>>1]=d[H]|0;break}else if((r|0)==2){b[D+(x<<3)+2>>1]=b[H>>1]|0;break}else{b[D+(x<<3)+2>>1]=c[H>>2];break}}}while(0);T=x+1|0}H=I+1|0;if((H|0)<(h|0)){x=T;I=H}else{P=T;Q=F;break a}}if((A|0)==53){KIb(0,16,2207968,(B=i,i=i+8|0,c[B>>2]=S,B)|0);i=B;if(v){C=-1;i=t;return C|0}kJb(F);C=-1;i=t;return C|0}else if((A|0)==60){KIb(0,16,2175528,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;if(v){C=-1;i=t;return C|0}kJb(F);C=-1;i=t;return C|0}}}else{I=D|0;cd(I|0,0,8,962);P=0;Q=I}}while(0);A=b3(f,g,P,D,s)|0;if(!v){kJb(Q);if((A|0)>=0){C=0;i=t;return C|0}mJb(f+4|0);C=A;i=t;return C|0}Q=c[f+8>>2]|0;v=c[f+12>>2]|0;if((Q|0)!=(v|0)){KIb(0,16,2147872,(B=i,i=i+16|0,c[B>>2]=Q,c[B+8>>2]=v,B)|0);i=B}v=f+16|0;if(((E=c[v>>2]|0,(c[v>>2]|0)==(f|0)?(c[v>>2]=f+20)|0:0,E)|0)!=(f|0)){KIb(0,0,2587656,(B=i,i=i+24|0,c[B>>2]=2123928,c[B+8>>2]=2457328,c[B+16>>2]=344,B)|0);i=B;Hd();return 0}if((A|0)>-1){C=0;i=t;return C|0}else{KIb(0,0,2587656,(B=i,i=i+24|0,c[B>>2]=2641392,c[B+8>>2]=2457328,c[B+16>>2]=345,B)|0);i=B;Hd();return 0}return 0}function a3(a,b){a=a|0;b=b|0;return((c[a+4>>2]|0)>>>1)-((c[b+4>>2]|0)>>>1)|0}function b3(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=i;l=1<<f;if((f|0)>30){m=-1;i=k;return m|0}n=e+8|0;o=c[n>>2]|0;p=o+l|0;c[n>>2]=p;q=e+12|0;r=c[q>>2]|0;do{if((p|0)>(r|0)){if((j&4|0)!=0){Hd();return 0}s=(1<<c[e>>2])+r|0;c[q>>2]=s;t=e+4|0;u=jJb(c[t>>2]|0,s,4)|0;c[t>>2]=u;if((u|0)!=0){break}c[q>>2]=0;c[n>>2]=0;m=-12;i=k;return m|0}}while(0);if((o|0)<0){m=o;i=k;return m|0}n=e+4|0;q=c[n>>2]|0;r=q+(o<<2)|0;if((l|0)>0){p=0;do{u=p+o|0;b[q+(u<<2)+2>>1]=0;b[q+(u<<2)>>1]=-1;p=p+1|0;}while((p|0)<(l|0))}if((g|0)<=0){m=o;i=k;return m|0}l=32-f|0;p=(j&2|0)==0;q=0;u=r;a:while(1){r=h+(q<<3)|0;t=r|0;s=a[t]|0;v=s&255;w=h+(q<<3)+4|0;x=c[w>>2]|0;y=b[h+(q<<3)+2>>1]|0;do{if((v|0)>(f|0)){z=v-f|0;A=x>>>(l>>>0);a[t]=z;c[w>>2]=x<<f;B=q+1|0;b:do{if((B|0)<(g|0)){C=z;D=q;E=B;while(1){F=h+(E<<3)|0;G=(d[F]|0)-f|0;if((G|0)<1){H=C;I=D;J=E;break b}K=h+(E<<3)+4|0;L=c[K>>2]|0;if((L>>>(l>>>0)|0)!=(A|0)){H=C;I=D;J=E;break b}a[F]=G;c[K>>2]=L<<f;L=(C|0)>(G|0)?C:G;G=E+1|0;if((G|0)<(g|0)){C=L;D=E;E=G}else{H=L;I=E;J=G;break}}}else{H=z;I=q;J=B}}while(0);B=(H|0)>(f|0)?f:H;if(p){M=A}else{M=(d[1316536+(A>>>8&255)|0]<<16|d[1316536+(A&255)|0]<<24|d[1316536+(A>>>16&255)|0]<<8|d[1316536+(A>>>24)|0])>>>(l>>>0)}b[u+(M<<2)+2>>1]=-B;z=b3(e,B,J-q|0,r,j)|0;if((z|0)<0){m=z;N=31;break a}B=c[n>>2]|0;E=z&65535;b[B+(M+o<<2)>>1]=E;if((E<<16>>16|0)!=(z|0)){N=28;break a}O=B+(o<<2)|0;P=I}else{B=1<<f-v;if(p){Q=1;R=x>>>(l>>>0)}else{Q=1<<v;R=d[1316536+(x>>>8&255)|0]<<16|d[1316536+(x&255)|0]<<24|d[1316536+(x>>>16&255)|0]<<8|d[1316536+(x>>>24)|0]}if((B|0)<=0){O=u;P=q;break}z=s&255;E=R;D=0;while(1){C=u+(E<<2)+2|0;if((b[C>>1]|0)!=0){N=18;break a}b[C>>1]=z;b[u+(E<<2)>>1]=y;C=D+1|0;if((C|0)<(B|0)){E=E+Q|0;D=C}else{O=u;P=q;break}}}}while(0);y=P+1|0;if((y|0)<(g|0)){q=y;u=O}else{m=o;N=31;break}}if((N|0)==18){KIb(0,16,2618744,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;m=-1094995529;i=k;return m|0}else if((N|0)==28){KIb(0,0,2587656,(S=i,i=i+24|0,c[S>>2]=2591408,c[S+8>>2]=2457328,c[S+16>>2]=235,S)|0);i=S;Hd();return 0}else if((N|0)==31){i=k;return m|0}return 0}function c3(a){a=a|0;mJb(a+4|0);return}function d3(a){a=a|0;return c[((a|0)==0?6041840:a+16|0)>>2]|0}function e3(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=6041840;while(1){d=c[b>>2]|0;if((d|0)==0){e=0;f=7;break}if((irc(a,c[d>>2]|0)|0)==0){break}else{b=d+16|0}}if((f|0)==7){return e|0}f=pJb(16)|0;c[f+4>>2]=d;b=c[d+4>>2]|0;if((b|0)==0){g=0}else{g=pJb(b)|0}c[f>>2]=g;e=f;return e|0}function f3(a){a=a|0;var b=0;if((a|0)==0){return}b=c[(c[a+4>>2]|0)+12>>2]|0;if((b|0)!=0){qe[b&1023](a)}b=a;mJb(b);HWa(c[a+8>>2]|0);kJb(b);return}function g3(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[e>>2]=g;c[f>>2]=h;return gf[c[(c[a+4>>2]|0)+8>>2]&63](a,b,d,e,f,g,h,i)|0}function h3(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;j=i;i=i+16|0;k=j|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;h=f;if((m|0)<14){KIb(e,16,2457080,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-1094995529;i=j;return o|0}do{if((a[l]|0)==66){if((a[l+1|0]|0)!=77){break}p=l+2|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;if(m>>>0<q>>>0){KIb(e,16,2301728,(n=i,i=i+16|0,c[n>>2]=m,c[n+8>>2]=q,n)|0);i=n;r=m}else{r=q}q=l+10|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+18|0;s=l+14|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=t+14|0;if(s>>>0>p>>>0){KIb(e,16,2250384,(n=i,i=i+8|0,c[n>>2]=p,n)|0);i=n;o=-1094995529;i=j;return o|0}u=(r|0)==14|(r|0)==(s|0)?m-2|0:r;if(!(u>>>0>p>>>0)){KIb(e,16,2207888,(n=i,i=i+16|0,c[n>>2]=u,c[n+8>>2]=p,n)|0);i=n;o=-1094995529;i=j;return o|0}switch(t|0){case 40:case 56:case 64:case 108:case 124:{u=q;v=l+22|0;w=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;x=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;y=l+26|0;break};case 12:{v=q;q=l+20|0;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;x=(d[q]|d[q+1|0]<<8)<<16>>16&65535;y=l+22|0;break};default:{KIb(e,16,2175456,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1163346256;i=j;return o|0}}q=y;if(!((d[q]|d[q+1|0]<<8)<<16>>16<<16>>16==1)){KIb(e,16,2147848,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}q=y+2|0;v=(d[q]|d[q+1|0]<<8)<<16>>16&65535;do{if(t>>>0>39>>>0){q=y+4|0;u=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;if(u>>>0<4>>>0){if((u|0)!=3){z=0;A=0;B=0;C=0;D=u;E=0;break}q=y+28|0;F=y+32|0;G=y+36|0;H=y+40|0;z=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;A=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;B=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;C=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;D=3;E=1;break}else{KIb(e,16,2123856,(n=i,i=i+8|0,c[n>>2]=u,n)|0);i=n;o=-1094995529;i=j;return o|0}}else{z=0;A=0;B=0;C=0;D=0;E=0}}while(0);u=e+120|0;c[u>>2]=w;G=(x|0)>0;F=e+124|0;c[F>>2]=G?x:-x|0;q=e+140|0;c[q>>2]=-1;a:do{switch(v|0){case 32:{if(!E){c[q>>2]=30;break a}H=(B|0)==16711680;if((A|0)==-16777216&H&(C|0)==65280){c[q>>2]=(z|0)!=0?29:297;break a}I=(B|0)==65280;if((A|0)==16711680&I&(C|0)==255){c[q>>2]=(z|0)!=0?30:298;break a}if((A|0)==65280&H&(C|0)==-16777216){c[q>>2]=(z|0)!=0?27:295;break a}if((A|0)==255&I&(C|0)==16711680){c[q>>2]=(z|0)!=0?28:296;break a}KIb(e,16,2641296,(n=i,i=i+24|0,c[n>>2]=A,c[n+8>>2]=B,c[n+16>>2]=C,n)|0);i=n;o=-22;i=j;return o|0};case 8:{if((p-t|0)==14){c[q>>2]=8;break a}else{c[q>>2]=11;break a}break};case 16:{if((D|0)==0){c[q>>2]=46;break a}if(!E){KIb(e,16,2569336,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}I=(C|0)==31;if((A|0)==63488&(B|0)==2016&I){c[q>>2]=44;break a}if((A|0)==31744&(B|0)==992&I){c[q>>2]=46;break a}if((A|0)==3840&(B|0)==240&(C|0)==15){c[q>>2]=62;break a}KIb(e,16,2641296,(n=i,i=i+24|0,c[n>>2]=A,c[n+8>>2]=B,c[n+16>>2]=C,n)|0);i=n;o=-22;i=j;return o|0};case 24:{c[q>>2]=3;break};case 1:case 4:{if((p-t|0)!=14){c[q>>2]=11;break a}KIb(e,16,2618640,(n=i,i=i+8|0,c[n>>2]=1<<v,n)|0);i=n;o=-1094995529;i=j;return o|0};default:{KIb(e,16,2591360,(n=i,i=i+8|0,c[n>>2]=v,n)|0);i=n;o=-1094995529;i=j;return o|0}}}while(0);I=M4a(e,h,0)|0;if((I|0)<0){o=I;i=j;return o|0}c[f+88>>2]=1;c[f+84>>2]=1;I=l+p|0;H=m-p|0;J=((ca(c[u>>2]|0,v)|0)+31|0)>>>3&536870908;K=c[F>>2]|0;L=ca(J,K)|0;M=D-1|0;do{if((L|0)>(H|0)){if(!(M>>>0>1>>>0)){N=(D|0)==1;O=61;break}KIb(e,16,2551192,(n=i,i=i+16|0,c[n>>2]=H,c[n+8>>2]=L,n)|0);i=n;o=-1094995529;i=j;return o|0}else{P=(D|0)==1;if(M>>>0<2>>>0){N=P;O=61;break}Q=f;R=P;S=0}}while(0);if((O|0)==61){M=f;mrc(c[M>>2]|0,0,ca(c[f+32>>2]|0,K)|0)|0;Q=M;R=N;S=1}M=c[Q>>2]|0;if(G){L=c[f+32>>2]|0;T=M+(ca((c[F>>2]|0)-1|0,L)|0)|0;U=-L|0}else{T=M;U=c[f+32>>2]|0}b:do{if((c[q>>2]|0)==11){M=1<<v;L=f+4|0;mrc(c[L>>2]|0,0,1024)|0;do{if(t>>>0>35>>>0){P=l+46|0;V=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;if((V|0)<0|(V|0)>(M|0)){KIb(e,16,2533048,(n=i,i=i+16|0,c[n>>2]=V,c[n+8>>2]=v,n)|0);i=n;W=M;break}else{W=(V|0)==0?M:V;break}}else{W=M}}while(0);M=l+s|0;V=p-t-14|0;if(!(V>>>0<W<<2>>>0)){if((W|0)<=0){break}P=c[L>>2]|0;X=M;Y=0;while(1){Z=X;c[P+(Y<<2)>>2]=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|-16777216;Z=Y+1|0;if((Z|0)<(W|0)){X=X+4|0;Y=Z}else{break b}}}if(V>>>0<(W*3|0)>>>0){KIb(e,16,2517608,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}if((W|0)<=0){break}Y=c[L>>2]|0;X=M;P=0;while(1){c[Y+(P<<2)>>2]=d[X+2|0]<<16|d[X+1|0]<<8|d[X]|-16777216;Z=P+1|0;if((Z|0)<(W|0)){X=X+3|0;P=Z}else{break}}}}while(0);c:do{if(S){t=(x|0)<0;if(R&t){p=f+32|0;s=c[p>>2]|0;q=ca((c[F>>2]|0)-1|0,s)|0;c[Q>>2]=(c[Q>>2]|0)+q;c[p>>2]=-s}if(!((H|0)>-1)){KIb(0,0,2490272,(n=i,i=i+24|0,c[n>>2]=2479440,c[n+8>>2]=2469624,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}c[k>>2]=I;c[k+8>>2]=I;c[k+4>>2]=l+m;YUa(e,f,v,k)|0;if(!t){break}t=f+32|0;s=c[t>>2]|0;p=ca((c[F>>2]|0)-1|0,s)|0;c[Q>>2]=(c[Q>>2]|0)+p;c[t>>2]=-s}else{switch(v|0){case 4:{s=c[F>>2]|0;if((s|0)<=0){break c}if((J|0)==0){t=0;while(1){t=t+1|0;if((t|0)>=(s|0)){break c}}}else{_=I;$=0;aa=T}while(1){s=0;do{t=_+s|0;p=s<<1;a[aa+p|0]=(d[t]|0)>>>4;a[aa+(p|1)|0]=a[t]&15;s=s+1|0;}while((s|0)<(J|0));s=$+1|0;if((s|0)<(c[F>>2]|0)){_=_+J|0;$=s;aa=aa+U|0}else{break}}break};case 8:case 24:case 32:{if((c[F>>2]|0)>0){ba=I;da=0;ea=T}else{break c}while(1){nrc(ea|0,ba|0,J)|0;s=da+1|0;if((s|0)<(c[F>>2]|0)){ba=ba+J|0;da=s;ea=ea+U|0}else{break}}break};case 1:{s=c[F>>2]|0;if((s|0)<=0){break c}if((J|0)==0){t=0;while(1){t=t+1|0;if((t|0)>=(s|0)){break c}}}else{fa=I;ga=0;ha=T}while(1){s=0;do{t=fa+s|0;p=s<<3;a[ha+p|0]=(d[t]|0)>>>7;a[ha+(p|1)|0]=(d[t]|0)>>>6&1;a[ha+(p|2)|0]=(d[t]|0)>>>5&1;a[ha+(p|3)|0]=(d[t]|0)>>>4&1;a[ha+(p|4)|0]=(d[t]|0)>>>3&1;a[ha+(p|5)|0]=(d[t]|0)>>>2&1;a[ha+(p|6)|0]=(d[t]|0)>>>1&1;a[ha+(p|7)|0]=a[t]&1;s=s+1|0;}while((s|0)<(J|0));s=ga+1|0;if((s|0)<(c[F>>2]|0)){fa=fa+J|0;ga=s;ha=ha+U|0}else{break}}break};case 16:{s=c[F>>2]|0;if((s|0)<=0){break c}t=c[u>>2]|0;if((t|0)>0){ia=I;ja=0;ka=T}else{break c}while(1){p=0;q=ia;G=ka;while(1){b[G>>1]=b[q>>1]|0;K=p+1|0;if((K|0)<(t|0)){p=K;q=q+2|0;G=G+2|0}else{break}}G=ja+1|0;if((G|0)<(s|0)){ia=ia+J|0;ja=G;ka=ka+U|0}else{break}}break};default:{KIb(e,16,2503712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}}}}while(0);c[g>>2]=1;o=m;i=j;return o|0}}while(0);KIb(e,16,2367352,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}function i3(a){a=a|0;var b=0,d=0,e=0;b=i;switch(c[a+140>>2]|0){case 30:{c[a+792>>2]=32;break};case 10:{c[a+792>>2]=1;break};case 22:case 19:case 24:case 21:case 8:case 11:{c[a+792>>2]=8;break};case 46:case 44:case 62:{c[a+792>>2]=16;break};case 3:{c[a+792>>2]=24;break};default:{KIb(a,32,2457e3,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-22;i=b;return e|0}}d=UHb()|0;c[a+804>>2]=d;e=(d|0)==0?-12:0;i=b;return e|0}function j3(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0;h=i;i=i+1024|0;j=c[d+792>>2]|0;k=c[d+804>>2]|0;c[k+88>>2]=1;c[k+84>>2]=1;k=c[d+140>>2]|0;switch(k|0){case 10:{l=0;m=827408;break};case 22:case 19:case 24:case 21:case 8:{n=h|0;rIb(n,k)|0;l=0;m=n;break};case 11:{l=0;m=c[f+4>>2]|0;break};case 62:{l=3;m=679632;break};case 44:{l=3;m=679616;break};default:{l=0;m=0}}n=(m|0)!=0&(l|0)==0?1<<j:l;k=d+120|0;o=c[k>>2]|0;p=Erc(o,(o|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;o=wrc(p,G,7,0)|0;p=o>>>3|G<<29;o=-p&3;q=d+124|0;r=o+p|0;s=ca(r,c[q>>2]|0)|0;t=(n<<2)+54|0;u=s+t|0;v=d5a(d,e,u,(u|0)<0|0?-1:0)|0;if((v|0)<0){w=v;i=h;return w|0}v=e+24|0;d=c[v>>2]|0;a[d]=66;a[d+1|0]=77;x=d+2|0;y=u;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=d+6|0;y=0;a[x]=y;y=y>>8;a[x+1|0]=y;x=d+8|0;y=0;a[x]=y;y=y>>8;a[x+1|0]=y;x=d+10|0;y=t;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=d+14|0;y=40;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=d+18|0;y=c[k>>2]|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=d+22|0;y=c[q>>2]|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=d+26|0;y=1;a[x]=y;y=y>>8;a[x+1|0]=y;x=d+28|0;y=j&65535;a[x]=y;y=y>>8;a[x+1|0]=y;x=d+30|0;y=l;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=d+34|0;y=s;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;mrc(d+38|0,0,16)|0;if((n|0)>0){x=d+54|0;d=0;while(1){s=x;y=c[m+(d<<2)>>2]&16777215;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=d+1|0;if((s|0)<(n|0)){x=x+4|0;d=s}else{break}}}d=c[q>>2]|0;x=f+32|0;n=(c[f>>2]|0)+(ca(d-1|0,c[x>>2]|0)|0)|0;f=(c[v>>2]|0)+t|0;a:do{if((d|0)>0){if((j|0)==16){z=f;A=n;B=0}else{t=f;v=n;m=0;while(1){nrc(t|0,v|0,p)|0;mrc(t+p|0,0,o|0)|0;s=m+1|0;if((s|0)<(c[q>>2]|0)){t=t+r|0;v=v+(-(c[x>>2]|0)|0)|0;m=s}else{break a}}}while(1){m=A;v=z;if((c[k>>2]|0)>0){t=0;do{s=v+(t<<1)|0;y=b[m+(t<<1)>>1]|0;a[s]=y;y=y>>8;a[s+1|0]=y;t=t+1|0;}while((t|0)<(c[k>>2]|0))}mrc(z+p|0,0,o|0)|0;t=B+1|0;if((t|0)<(c[q>>2]|0)){z=z+r|0;A=A+(-(c[x>>2]|0)|0)|0;B=t}else{break}}}}while(0);B=e+36|0;c[B>>2]=c[B>>2]|1;c[g>>2]=1;w=0;i=h;return w|0}function k3(a){a=a|0;VHb(a+804|0);return 0}function l3(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;c[a+140>>2]=11;e=c[a+120>>2]|0;f=c[a+124>>2]|0;if((e|0)==640&(f|0)==429){c[d+4>>2]=d+648;g=0;i=b;return g|0}else{KIb(a,16,2569304,(a=i,i=i+16|0,c[a>>2]=e,c[a+8>>2]=f,a)|0);i=a;g=-1094995529;i=b;return g|0}return 0}function m3(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;h=i;j=c[b+60>>2]|0;k=e;l=g+24|0;m=c[l>>2]|0;n=j+276232|0;o=m+1|0;c[n>>2]=o;p=d[m]|0;do{if((p&32|0)==0){q=o}else{c[n>>2]=m+2;r=(d[o]|0)*65|0;if((c[g+28>>2]|0)>=(r+2|0)){s=m+(r+2)|0;c[n>>2]=s;q=s;break}KIb(b,16,2250344,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}}while(0);do{if((p&16|0)==0){v=q}else{m=p>>>6&2^10;if((q+m-(c[l>>2]|0)|0)<=(c[g+28>>2]|0)){o=q+m|0;c[n>>2]=o;v=o;break}KIb(b,16,2207808,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}}while(0);q=p&8;a:do{if((q|0)!=0){if((v-(c[l>>2]|0)|0)>((c[g+28>>2]|0)-768|0)){KIb(b,16,2175416,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}o=j+275208|0;m=0;s=v;while(1){c[n>>2]=s+3;c[o+(m<<2)>>2]=(d[s]|0)<<16|(d[s+1|0]|0)<<8|(d[s+2|0]|0)|-16777216;r=m+1|0;if((r|0)>=256){break a}m=r;s=c[n>>2]|0}}}while(0);do{if((p&4|0)==0){w=(p&3|0)==3?-640:0}else{v=c[n>>2]|0;if((v-(c[l>>2]|0)|0)<=((c[g+28>>2]|0)-2|0)){c[n>>2]=v+2;s=v;w=(d[s]|d[s+1|0]<<8)<<16>>16<<16>>16;break}KIb(b,16,2147792,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}}while(0);p=M4a(b,k,0)|0;if((p|0)<0){u=p;i=h;return u|0}p=c[n>>2]|0;n=g+28|0;g=p;k=(c[l>>2]|0)-g+(c[n>>2]|0)|0;l=j+4|0;s=c[l>>2]|0;v=p+k|0;m=s+274560|0;o=w>>>0<4294966657>>>0;b:do{if((k|0)>=1){if(o){x=m;y=s;z=p}else{x=s-1|0;y=s+274559|0;z=p+(k-1)|0}r=x;A=s;B=m;C=v;D=0;E=0;F=k;G=y;H=z;while(1){I=(D|0)!=0;if((F|0)==4|I^1){if(!(H>>>0>=p>>>0&H>>>0<v>>>0)){break b}J=1;K=d[H]|0}else{J=0;K=E}c:do{if((K&12|0)==0){if(o){L=0;M=J;N=K;O=H;while(1){if((L|0)>22){break b}if((M|0)==0){if(!(O>>>0>=p>>>0&O>>>0<v>>>0)){break b}P=L+2|0;Q=d[O]|0;R=Q<<P|N;if((Q&12|0)==0){S=P;T=R}else{U=O;V=R;W=P;X=41;break c}}else{S=L;T=N}P=S+2|0;R=1<<P;Q=R-1&T|T>>>2&-R;R=O+1|0;if((Q&12<<P|0)==0){L=P;M=0;N=Q;O=R}else{Y=Q;Z=E;_=4;$=R;break}}}else{O=0;N=J;M=K;L=H;while(1){if((O|0)>22){break b}if((N|0)==0){if(!(L>>>0>=p>>>0&L>>>0<v>>>0)){break b}R=O+2|0;Q=d[L]|0;P=Q<<R|M;if((Q&12|0)==0){aa=R;ba=P}else{U=L;V=P;W=R;X=41;break c}}else{aa=O;ba=M}R=aa+2|0;P=1<<R;Q=P-1&ba|ba>>>2&-P;P=L-1|0;if((Q&12<<R|0)==0){O=R;N=0;M=Q;L=P}else{Y=Q;Z=E;_=4;$=P;break}}}}else{if(I&(F|0)!=4){Y=K;Z=E;_=4;$=H}else{U=H;V=K;W=0;X=41}}}while(0);if((X|0)==41){X=0;I=W+4|0;Y=(1<<I)-1&V;Z=V>>>(I>>>0);_=0;$=o?U+1|0:U-1|0}I=Y>>>1;L=I-1|0;if((L|0)<=0){X=43;break}M=D+1+(Y&1)|0;N=(M|0)>3?M-3|0:M;M=G;O=r-M|0;if((((O|0)>-1?O:-O|0)|0)<(L|0)){break b}do{if((N|0)==3){O=a[o?G-1|0:G+1|0]|0;if(o){mrc(G|0,O|0,L|0)|0;ca=G+L|0;da=$;break}else{P=G+(1-I)|0;mrc(P|0,O|0,L|0)|0;ca=P;da=$;break}}else if((N|0)==1){if(o){P=M-A+640|0;if((P|0)<(w|0)|(P+w|0)<0){break b}P=B-M|0;if((P|0)<(L+w|0)|(P|0)<(L|0)){break b}else{ea=0}do{a[G+ea|0]=a[G+(ea+w)|0]|0;ea=ea+1|0;}while((ea|0)<(L|0));ca=G+L|0;da=$;break}P=1-I|0;O=G+P|0;Q=O;R=Q-A+640|0;if((R|0)<(w|0)|(R+w|0)<0){break b}R=B-Q|0;if((R|0)<(L+w|0)|(R|0)<(L|0)){break b}R=I-2|0;if(!((R|0)>-1)){ca=O;da=$;break}Q=P+w|0;fa=R;while(1){a[G+(fa+P)|0]=a[G+(Q+fa)|0]|0;if((fa|0)>0){fa=fa-1|0}else{ca=O;da=$;break}}}else if((N|0)==2){O=$;if(o){if((C-O|0)<(L|0)){break b}nrc(G|0,$|0,L)|0;ca=G+L|0;da=$+L|0;break}else{if((O-g|0)<(L|0)){break b}O=1-I|0;fa=G+O|0;Q=$+O|0;nrc(fa|0,Q|0,L)|0;ca=fa;da=Q;break}}else{ca=G;da=$}}while(0);if((ca|0)==(x|0)){break}else{D=N;E=Z;F=_;G=ca;H=da}}if((X|0)==43){KIb(0,0,2641264,(t=i,i=i+24|0,c[t>>2]=2618632,c[t+8>>2]=2591280,c[t+16>>2]=138,t)|0);i=t;Hd();return 0}nrc(c[e+4>>2]|0,j+275208|0,1024)|0;c[e+304>>2]=q;H=b+124|0;if((c[H>>2]|0)>0){G=b+120|0;F=e+32|0;E=0;D=c[l>>2]|0;C=c[e>>2]|0;B=c[G>>2]|0;while(1){nrc(C|0,D|0,B)|0;A=c[G>>2]|0;r=E+1|0;if((r|0)<(c[H>>2]|0)){E=r;D=D+A|0;C=C+(c[F>>2]|0)|0;B=A}else{break}}}c[f>>2]=1;u=c[n>>2]|0;i=h;return u|0}}while(0);KIb(b,16,2123824,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}function n3(a){a=a|0;var b=0;c[a+416>>2]=2;b=a+448|0;c[b>>2]=3;c[b+4>>2]=0;c[a+420>>2]=1;return 0}function o3(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=a[j]|0;l=g&255;m=(l*65|0)+1|0;if((k|0)<(m|0)){KIb(d,16,2301504,(n=i,i=i+16|0,c[n>>2]=m,c[n+8>>2]=k,n)|0);i=n;o=-1094995529;i=h;return o|0}c[e+76>>2]=l<<5;n=M4a(d,e,0)|0;if((n|0)<0){o=n;i=h;return o|0}if(!(g<<24>>24==0)){g=c[e>>2]|0;e=0;n=j+1|0;while(1){j=a[n]|0;d=((j&255)>>>1|j<<7)&255;j=c[1900688+((d&15)<<2)>>2]|0;m=c[1900688+(d>>>4<<2)>>2]|0;d=n+65|0;p=0;q=g;r=n;s=n+1|0;while(1){t=r+2|0;u=ca(a[s]|0,j)|0;v=u>>5;if((v+32768|0)>>>0>65535>>>0){w=(u>>31^32767)&65535}else{w=v&65535}b[q>>1]=w;v=ca(a[t]|0,m)|0;u=v>>5;if((u+32768|0)>>>0>65535>>>0){x=(v>>31^32767)&65535}else{x=u&65535}b[q+2>>1]=x;u=p+1|0;v=r+3|0;if((u|0)<32){p=u;q=q+4|0;r=t;s=v}else{break}}s=e+1|0;if((s|0)<(l|0)){g=g+128|0;e=s;n=d}else{break}}}c[f>>2]=1;o=k;i=h;return o|0}function p3(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=i;h=b;j=f+24|0;k=c[j>>2]|0;l=f+28|0;f=c[l>>2]|0;if(!((f|0)>-1)){KIb(0,0,2641232,(m=i,i=i+24|0,c[m>>2]=2618576,c[m+8>>2]=2591256,c[m+16>>2]=135,m)|0);i=m;Hd();return 0}n=k+f|0;o=k;if((f|0)<4){p=0;q=k}else{f=k;p=je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;q=k+4|0}if((n-q|0)<4){r=0;s=q}else{k=q;r=je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;s=q+4|0}if((n-s|0)<4){t=0;u=s}else{q=s;t=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;u=s+4|0}do{if((n-u|0)>=4){s=u+4|0;q=u;if(!((p|0)==18&(r|0)==8&(t|0)==2&(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)==33554432)){break}do{if((n-s|0)<4){v=0}else{q=u+8|0;k=s;f=je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;if(!((f|0)==61|(f|0)==3)){v=f;break}if((n-q|0)<4){w=0;x=q}else{f=q;w=je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;x=u+12|0}if((n-x|0)<1){y=0;z=x}else{y=d[x]|0;z=x+1|0}f=n-z|0;q=f>>>0>2>>>0?2:f;f=z+q|0;if((n-f|0)<2){A=0;B=f}else{k=f;A=(he((d[k]|d[k+1|0]<<8)<<16>>16|0)|0)&65535;B=z+(q+2)|0}if((n-B|0)<2){C=0;D=B}else{q=B;C=(he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;D=B+2|0}if(w>>>0<11>>>0){KIb(a,16,2301480,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}q=w-7|0;k=n-D|0;f=k>>>0>q>>>0?q:k;k=D+f|0;switch(y|0){case 6:{c[a+140>>2]=2;F=3;break};case 4:{c[a+140>>2]=45;F=2;break};case 5:{c[a+140>>2]=43;F=2;break};case 18:{c[a+140>>2]=66;F=2;break};case 3:{c[a+140>>2]=11;F=1;break};case 7:{c[a+140>>2]=295;F=4;break};default:{KIb(a,16,2250232,(m=i,i=i+8|0,c[m>>2]=y,m)|0);i=m;E=-1163346256;i=g;return E|0}}q=H4a(a,A,C)|0;if((q|0)<0){E=q;i=g;return E|0}q=M4a(a,h,0)|0;if((q|0)<0){E=q;i=g;return E|0}if((n-k|0)<4){G=0;H=k}else{q=k;G=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;H=D+(f+4)|0}a:do{if((c[a+140>>2]|0)==11){if(!((G|0)==61|(G|0)==3)){f=c[b+4>>2]|0;q=0;while(1){c[f>>2]=q*65793|0|-16777216;k=q+1|0;if((k|0)<256){f=f+4|0;q=k}else{break}}c[b+304>>2]=1;I=G;J=H;break}q=c[b+4>>2]|0;if((n-H|0)<4){K=0;L=H}else{f=H;K=je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;L=H+4|0}if((n-L|0)<1){M=0;N=L}else{M=d[L]|0;N=L+1|0}f=n-N|0;k=f>>>0>2>>>0?2:f;f=N+k|0;if((n-f|0)<2){O=f}else{O=N+(k+2)|0}k=(n-O|0)<2?O:O+2|0;if(K>>>0<11>>>0){KIb(a,16,2207768,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}f=K-7|0;P=n-k|0;Q=P>>>0>f>>>0?f:P;P=k+Q|0;if((M|0)!=7){KIb(a,16,2175384,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}if((n-P|0)<4){R=0;S=P}else{f=P;R=je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;S=k+(Q+4)|0}if((n-S|0)<4){T=0;U=S}else{Q=S;T=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)==134479872;U=S+4|0}Q=U;k=n-Q|0;f=U+(k>>>0>8>>>0?8:k)|0;do{if((R|0)==33&T){if((n-f|0)>>>0<1032>>>0){break}k=Q-1-n|0;P=k>>>0>4294967287>>>0?k:-9;k=1023-P|0;V=1019-P|0;P=f;W=q;X=0;while(1){c[W>>2]=(d[P+1|0]|0)<<16|(d[P+2|0]|0)<<8|(d[P+3|0]|0)|-16777216;Y=X+1|0;if((Y|0)<256){P=P+4|0;W=W+4|0;X=Y}else{break}}X=n-(U+k)|0;W=X>>>0>8>>>0?8:X;X=U+(V+(W+4))|0;c[b+304>>2]=1;if((n-X|0)<4){I=0;J=X;break a}P=X;I=je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;J=U+(V+(W+8))|0;break a}}while(0);KIb(a,16,2147768,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}else{I=G;J=H}}while(0);if((n-J|0)<4){Z=0;_=J}else{q=J;Z=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;_=J+4|0}q=n-_|0;f=ca(F,A)|0;Q=_+(q>>>0>8>>>0?8:q)|0;do{if((I|0)==33&(Z|0)==(n-Q|0)){if(((Z>>>0)/(f>>>0)|0)>>>0<C>>>0){break}uIb(c[b>>2]|0,c[b+32>>2]|0,(c[j>>2]|0)+(Q-o)|0,f,f,C);c[e>>2]=1;E=c[l>>2]|0;i=g;return E|0}}while(0);KIb(a,16,2123800,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}}while(0);KIb(a,16,2367184,(m=i,i=i+8|0,c[m>>2]=v,m)|0);i=m;E=-1094995529;i=g;return E|0}}while(0);KIb(a,16,2456896,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=-1094995529;i=g;return E|0}function q3(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+60|0;d=c[b>>2]|0;c[a+140>>2]=11;a=d;c[a>>2]=UHb()|0;e=UHb()|0;c[d+4>>2]=e;if(!((c[a>>2]|0)==0|(e|0)==0)){f=0;return f|0}e=c[b>>2]|0;VHb(e);VHb(e+4|0);f=-12;return f|0}function r3(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[g+24>>2]|0;m=c[g+28>>2]|0;g=c[b+60>>2]|0;n=g+8|0;o=c[n>>2]|0;p=g;g=c[p+(o<<2)>>2]|0;q=c[p+((o^1)<<2)>>2]|0;o=H4a(b,320,192)|0;if((o|0)<0){r=o;i=h;return r|0}c[n>>2]=c[n>>2]^1;n=N4a(b,g)|0;if((n|0)<0){r=n;i=h;return r|0}n=c[g+32>>2]|0;if(!((m|0)>-1)){KIb(0,0,2250168,(s=i,i=i+24|0,c[s>>2]=2207712,c[s+8>>2]=2175296,c[s+16>>2]=135,s)|0);i=s;Hd();return 0}o=l+m|0;do{if((m|0)<1){t=l;u=0;v=g+88|0;w=9}else{p=l+1|0;x=d[l]|0;y=g+88|0;if((x&2|0)==0){t=p;u=x;v=y;w=9;break}c[y>>2]=1;c[g+84>>2]=1;z=p;A=x}}while(0);if((w|0)==9){c[v>>2]=2;c[g+84>>2]=0;z=t;A=u}u=g|0;t=q|0;v=j|0;l=k|0;x=j+1|0;p=z;z=0;y=0;a:while(1){B=p;C=z;D=0;E=(c[u>>2]|0)+(ca(y,n)|0)|0;while(1){F=c[t>>2]|0;if((C|0)==0){if((o-B|0)<1){G=0;w=61;break a}H=d[B]|0;I=B+1|0}else{H=C;I=B}J=H&15;b:do{switch(J|0){case 7:{K=c[u>>2]|0;w=27;break};case 6:{K=F;w=27;break};case 8:{L=o-I|0;M=L>>>0>2>>>0?2:L;nrc(v|0,I|0,M)|0;L=I+M|0;M=0;while(1){if((o-L|0)<1){N=0;O=L}else{N=d[L]|0;O=L+1|0}P=ca(M,n)|0;a[E+P|0]=a[j+(N&1)|0]|0;a[E+(P+1)|0]=a[j+(N>>>1&1)|0]|0;a[E+(P+2)|0]=a[j+(N>>>2&1)|0]|0;a[E+(P+3)|0]=a[j+(N>>>3&1)|0]|0;a[E+(P+4)|0]=a[j+(N>>>4&1)|0]|0;a[E+(P+5)|0]=a[j+(N>>>5&1)|0]|0;a[E+(P+6)|0]=a[j+(N>>>6&1)|0]|0;a[E+(P+7)|0]=a[j+(N>>>7)|0]|0;P=M+1|0;if((P|0)<8){L=O;M=P}else{Q=O;break}}break};case 10:case 13:case 11:{M=I;L=0;while(1){P=M;R=0;while(1){if((J|0)==10){S=o-P|0;T=S>>>0>2>>>0?2:S;nrc(v|0,P|0,T)|0;S=P+T|0;if((o-S|0)<2){U=0;V=S}else{W=S;U=(d[W]|d[W+1|0]<<8)<<16>>16&65535;V=P+(T+2)|0}T=ca(L,n)|0;a[E+(R+T)|0]=a[j+(U&1)|0]|0;W=R|1;a[E+(W+T)|0]=a[j+(U>>>1&1)|0]|0;S=R|2;a[E+(S+T)|0]=a[j+(U>>>2&1)|0]|0;X=R|3;a[E+(X+T)|0]=a[j+(U>>>3&1)|0]|0;T=ca(L|1,n)|0;a[E+(R+T)|0]=a[j+(U>>>4&1)|0]|0;a[E+(W+T)|0]=a[j+(U>>>5&1)|0]|0;a[E+(S+T)|0]=a[j+(U>>>6&1)|0]|0;a[E+(X+T)|0]=a[j+(U>>>7&1)|0]|0;T=ca(L|2,n)|0;a[E+(R+T)|0]=a[j+(U>>>8&1)|0]|0;a[E+(W+T)|0]=a[j+(U>>>9&1)|0]|0;a[E+(S+T)|0]=a[j+(U>>>10&1)|0]|0;a[E+(X+T)|0]=a[j+(U>>>11&1)|0]|0;T=ca(L|3,n)|0;a[E+(R+T)|0]=a[j+(U>>>12&1)|0]|0;a[E+(W+T)|0]=a[j+(U>>>13&1)|0]|0;a[E+(S+T)|0]=a[j+(U>>>14&1)|0]|0;a[E+(X+T)|0]=a[j+(U>>>15)|0]|0;Y=V}else if((J|0)==13){T=o-P|0;X=T>>>0>4>>>0?4:T;nrc(v|0,P|0,X)|0;T=P+X|0;if((o-T|0)<4){Z=0;_=T}else{S=T;Z=d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0;_=P+(X+4)|0}X=ca(L,n)|0;a[E+(R+X)|0]=a[j+(Z&3)|0]|0;S=R|1;a[E+(S+X)|0]=a[j+(Z>>>2&3)|0]|0;T=R|2;a[E+(T+X)|0]=a[j+(Z>>>4&3)|0]|0;W=R|3;a[E+(W+X)|0]=a[j+(Z>>>6&3)|0]|0;X=ca(L|1,n)|0;a[E+(R+X)|0]=a[j+(Z>>>8&3)|0]|0;a[E+(S+X)|0]=a[j+(Z>>>10&3)|0]|0;a[E+(T+X)|0]=a[j+(Z>>>12&3)|0]|0;a[E+(W+X)|0]=a[j+(Z>>>14&3)|0]|0;X=ca(L|2,n)|0;a[E+(R+X)|0]=a[j+(Z>>>16&3)|0]|0;a[E+(S+X)|0]=a[j+(Z>>>18&3)|0]|0;a[E+(T+X)|0]=a[j+(Z>>>20&3)|0]|0;a[E+(W+X)|0]=a[j+(Z>>>22&3)|0]|0;X=ca(L|3,n)|0;a[E+(R+X)|0]=a[j+(Z>>>24&3)|0]|0;a[E+(S+X)|0]=a[j+(Z>>>26&3)|0]|0;a[E+(T+X)|0]=a[j+(Z>>>28&3)|0]|0;a[E+(W+X)|0]=a[j+(Z>>>30)|0]|0;Y=_}else{X=o-P|0;W=X>>>0>4>>>0?4:X;nrc(l|0,P|0,W)|0;X=P+W|0;if((o-X|0)<2){$=0;aa=X}else{T=X;$=(d[T]|d[T+1|0]<<8)<<16>>16&65535;aa=P+(W+2)|0}W=k+1|0;T=$;X=0;while(1){a[v]=a[k+((X>>1)*3|0)|0]|0;S=ca(X+L|0,n)|0;a[x]=a[W]|0;a[E+(R+S)|0]=a[j+(T&1)|0]|0;a[x]=a[W]|0;a[E+((R|1)+S)|0]=a[j+(T>>>1&1)|0]|0;ba=k+2|0;a[x]=a[ba]|0;a[E+((R|2)+S)|0]=a[j+(T>>>2&1)|0]|0;a[x]=a[ba]|0;a[E+((R|3)+S)|0]=a[j+(T>>>3&1)|0]|0;S=X+1|0;if((S|0)<4){T=T>>>4;X=S}else{Y=aa;break}}}X=R+4|0;if((X|0)<8){P=Y;R=X}else{break}}R=L+4|0;if(R>>>0<8>>>0){M=Y;L=R}else{Q=Y;break}}break};case 14:{Q=I;break};case 15:{L=o-I|0;M=L>>>0>8>>>0?8:L;nrc(E|0,I|0,M)|0;L=I+M|0;R=o-L|0;P=R>>>0>8>>>0?8:R;nrc(E+n|0,L|0,P)|0;L=M+P|0;P=I+L|0;M=o-P|0;R=M>>>0>8>>>0?8:M;nrc(E+(n<<1)|0,P|0,R)|0;P=L+R|0;R=I+P|0;L=o-R|0;M=L>>>0>8>>>0?8:L;nrc(E+(n*3|0)|0,R|0,M)|0;R=P+M|0;M=I+R|0;P=o-M|0;L=P>>>0>8>>>0?8:P;nrc(E+(n<<2)|0,M|0,L)|0;M=R+L|0;L=I+M|0;R=o-L|0;P=R>>>0>8>>>0?8:R;nrc(E+(n*5|0)|0,L|0,P)|0;L=M+P|0;P=I+L|0;M=o-P|0;R=M>>>0>8>>>0?8:M;nrc(E+(n*6|0)|0,P|0,R)|0;P=L+R|0;R=I+P|0;L=o-R|0;M=L>>>0>8>>>0?8:L;nrc(E+(n*7|0)|0,R|0,M)|0;Q=I+(P+M)|0;break};case 2:{if((o-I|0)<2){da=0;ea=I}else{M=I;da=(d[M]|d[M+1|0]<<8)<<16>>16&65535;ea=I+2|0}M=(da>>>0)%320|0;P=(da>>>0)/320|0;R=M-312|0;if((F|0)==0){Q=ea;break b}if((P+8|0)>>>0>192>>>0){w=25;break a}if((R|0)>0){L=320-M|0;X=ca(P,n)|0;nrc(E+L|0,F+X|0,R)|0;T=ca(P+1|0,n)|0;nrc(E+(n+L)|0,F+T|0,R)|0;W=n<<1;S=ca(P+2|0,n)|0;nrc(E+(W+L)|0,F+S|0,R)|0;ba=n*3|0;fa=ca(P+3|0,n)|0;nrc(E+(ba+L)|0,F+fa|0,R)|0;ga=n<<2;ha=ca(P+4|0,n)|0;nrc(E+(ga+L)|0,F+ha|0,R)|0;ia=n*5|0;ja=ca(P+5|0,n)|0;nrc(E+(ia+L)|0,F+ja|0,R)|0;ka=n*6|0;la=ca(P+6|0,n)|0;nrc(E+(ka+L)|0,F+la|0,R)|0;ma=n*7|0;na=ca(P+7|0,n)|0;nrc(E+(ma+L)|0,F+na|0,R)|0;oa=L;pa=X;qa=T;ra=W;sa=S;ta=ba;ua=fa;va=ga;wa=ha;xa=ia;ya=ja;za=ka;Aa=la;Ba=ma;Ca=na}else{oa=8;pa=ca(P,n)|0;qa=ca(P+1|0,n)|0;ra=n<<1;sa=ca(P+2|0,n)|0;ta=n*3|0;ua=ca(P+3|0,n)|0;va=n<<2;wa=ca(P+4|0,n)|0;xa=n*5|0;ya=ca(P+5|0,n)|0;za=n*6|0;Aa=ca(P+6|0,n)|0;Ba=n*7|0;Ca=ca(P+7|0,n)|0}nrc(E|0,F+(pa+M)|0,oa)|0;nrc(E+n|0,F+(qa+M)|0,oa)|0;nrc(E+ra|0,F+(sa+M)|0,oa)|0;nrc(E+ta|0,F+(ua+M)|0,oa)|0;nrc(E+va|0,F+(wa+M)|0,oa)|0;nrc(E+xa|0,F+(ya+M)|0,oa)|0;nrc(E+za|0,F+(Aa+M)|0,oa)|0;nrc(E+Ba|0,F+(Ca+M)|0,oa)|0;Q=ea;break};default:{G=J;w=61;break a}}}while(0);if((w|0)==27){w=0;F=(J|0)==7;M=(K|0)==0;P=I;na=0;while(1){Da=na+y|0;ma=ca(na,n)|0;la=P;Ea=0;while(1){if((o-la|0)<2){Fa=0;Ga=la}else{ka=la;Fa=(d[ka]|d[ka+1|0]<<8)<<16>>16&65535;Ga=la+2|0}Ha=(Fa>>>0)%320|0;ka=(Fa>>>0)/320|0;if(F&(ka|0)==(Da|0)){ja=Ha-D-Ea|0;if((((ja|0)>-1?ja:-ja|0)-4|0)>>>0>312>>>0){w=33;break a}}ja=Ea+ma|0;ia=Ha-316|0;if(!M){if((ka+4|0)>>>0>192>>>0){w=40;break a}if((ia|0)>0){ha=320-Ha|0;ga=ha+ja|0;fa=ca(ka,n)|0;nrc(E+ga|0,K+fa|0,ia)|0;ba=ca(ka+1|0,n)|0;nrc(E+(ga+n)|0,K+ba|0,ia)|0;S=n<<1;W=ca(ka+2|0,n)|0;nrc(E+(ga+S)|0,K+W|0,ia)|0;T=n*3|0;X=ca(ka+3|0,n)|0;nrc(E+(ga+T)|0,K+X|0,ia)|0;Ia=ha;Ja=fa;Ka=ba;La=S;Ma=W;Na=T;Oa=X}else{Ia=4;Ja=ca(ka,n)|0;Ka=ca(ka+1|0,n)|0;La=n<<1;Ma=ca(ka+2|0,n)|0;Na=n*3|0;Oa=ca(ka+3|0,n)|0}nrc(E+ja|0,K+(Ja+Ha)|0,Ia)|0;nrc(E+(n+ja)|0,K+(Ka+Ha)|0,Ia)|0;nrc(E+(La+ja)|0,K+(Ma+Ha)|0,Ia)|0;nrc(E+(Na+ja)|0,K+(Oa+Ha)|0,Ia)|0}ja=Ea+4|0;if((ja|0)<8){la=Ga;Ea=ja}else{break}}la=na+4|0;if(la>>>0<8>>>0){P=Ga;na=la}else{Q=Ga;break}}}Pa=H>>4;na=D+8|0;if((na|0)>=320){break}B=Q;C=Pa;D=na;E=E+8|0}E=y+8|0;if((E|0)<192){p=Q;z=Pa;y=E}else{w=65;break}}if((w|0)==25){KIb(b,16,2301384,(s=i,i=i+8|0,c[s>>2]=da,s)|0);i=s;r=-1094995529;i=h;return r|0}else if((w|0)==33){QIb(b,2456832,(s=i,i=i+32|0,c[s>>2]=Ha,c[s+8>>2]=Ea+D,c[s+16>>2]=Da,c[s+24>>2]=Da,s)|0);i=s;r=-1094995529;i=h;return r|0}else if((w|0)==40){KIb(b,16,2301384,(s=i,i=i+8|0,c[s>>2]=Fa,s)|0);i=s;r=-1094995529;i=h;return r|0}else if((w|0)==61){KIb(b,16,2367120,(s=i,i=i+24|0,c[s>>2]=G,c[s+8>>2]=D,c[s+16>>2]=y,s)|0);i=s;r=-1094995529;i=h;return r|0}else if((w|0)==65){do{if((A&1|0)==0){w=c[q+4>>2]|0;if((w|0)==0){break}nrc(c[g+4>>2]|0,w|0,1024)|0}else{w=c[g+4>>2]|0;s=Q;y=0;while(1){if((o-s|0)<3){Qa=-16777216;Ra=s}else{Qa=(d[s]|0)<<16|(d[s+1|0]|0)<<8|(d[s+2|0]|0)|-16777216;Ra=s+3|0}c[w+(y<<2)>>2]=Qa;D=y+1|0;if((D|0)<256){s=Ra;y=D}else{break}}c[g+304>>2]=1}}while(0);Ra=YHb(e,g)|0;if((Ra|0)<0){r=Ra;i=h;return r|0}c[f>>2]=1;r=m;i=h;return r|0}return 0}function s3(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b);VHb(b+4|0);return 0}function t3(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0;h=i;i=i+8|0;j=h|0;k=c[b+60>>2]|0;b=k;l=c[g+24>>2]|0;m=c[g+28>>2]|0;c[j>>2]=-1;if((m|0)==0){if((c[k+1620>>2]|0)!=0){n=0;i=h;return n|0}g=c[k+1596>>2]|0;if((c[g>>2]|0)==0){n=0;i=h;return n|0}c[f>>2]=1;aIb(e,g);n=0;i=h;return n|0}g=k+1700|0;c[g>>2]=0;o=l+m|0;m=U5a(l,o,j)|0;p=c[j>>2]|0;a:do{if(p>>>0>511>>>0|(m|0)==(o|0)){q=m}else{r=o;s=k+1568|0;t=s;u=s;s=k+1580|0;v=k+1584|0;w=k+1572|0;x=k+1576|0;y=k+1624|0;z=k+1628|0;A=k+1644|0;B=k+1648|0;C=k;D=k+1632|0;E=k+1620|0;F=k+1636|0;G=k+1640|0;H=k+1720|0;I=k+2316|0;J=k+1596|0;K=J;L=k+1604|0;M=L;N=k+1588|0;O=N;P=k+2312|0;Q=k+1592|0;R=k+1600|0;S=k+1612|0;T=k+1608|0;U=k+1616|0;V=k+2304|0;W=k+2308|0;X=k+2292|0;Y=k+1656|0;Z=k+1660|0;_=k+2e3|0;$=k+1996|0;aa=k+1680|0;ba=k+1664|0;da=k+1668|0;ea=k+1672|0;fa=k+1676|0;ga=e;ha=L;L=N;N=J;J=k+2296|0;ia=k+2300|0;ja=k+1652|0;ka=m;la=p;b:while(1){ma=r-ka<<3;c:do{switch(la|0){case 435:{if((c[I>>2]|0)!=0){na=22;break c}WHb(c[K>>2]|0);WHb(c[M>>2]|0);c[I>>2]=1;na=22;break};case 438:{na=22;break};case 432:{oa=ma>>>0>2147483639>>>0|(ka|0)==0;pa=oa?0:ka;qa=oa?0:ma;c[u>>2]=pa;c[s>>2]=qa;oa=qa+8|0;c[v>>2]=oa;c[w>>2]=pa+(qa>>3);c[x>>2]=0;qa=pa;ra=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24)&255;qa=oa>>>0>8>>>0?8:oa;c[x>>2]=qa;c[y>>2]=ra;ra=pa+(qa>>>3)|0;sa=qa+8|0;c[z>>2]=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24)&255;ra=(oa>>>0>sa>>>0?sa:oa)|1;sa=oa>>>0>ra>>>0?ra:oa;c[x>>2]=sa;ra=pa+(sa>>>3)|0;qa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>18;ra=sa+14|0;sa=oa>>>0>ra>>>0?ra:oa;c[x>>2]=sa;ra=pa+(sa>>>3)|0;ta=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>18;ra=sa+14|0;sa=oa>>>0>ra>>>0?ra:oa;c[x>>2]=sa;ra=c[A>>2]|0;if((ra|0)==0){if((c[B>>2]|0)!=0){na=13}}else{na=13}do{if((na|0)==13){na=0;if((ra|0)==(qa|0)){if((c[B>>2]|0)==(ta|0)){break}}RIb(c[C>>2]|0,2533016,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;break c}}while(0);if((qa|0)==0|(ta|0)==0){KIb(c[C>>2]|0,16,2517584,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;break c}c[A>>2]=qa;c[B>>2]=ta;ra=sa+2|0;va=(oa>>>0>ra>>>0?ra:oa)+3|0;ra=oa>>>0>va>>>0?va:oa;c[x>>2]=ra;va=pa+(ra>>>3)|0;wa=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(ra&7)>>>28;va=ra+4|0;ra=oa>>>0>va>>>0?va:oa;c[x>>2]=ra;c[D>>2]=wa;wa=pa+(ra>>>3)|0;va=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ra&7)>>>28;wa=ra+4|0;ra=(oa>>>0>wa>>>0?wa:oa)+18|0;wa=(oa>>>0>ra>>>0?ra:oa)+1|0;ra=(oa>>>0>wa>>>0?wa:oa)+12|0;wa=oa>>>0>ra>>>0?ra:oa;c[x>>2]=wa;ra=d[pa+(wa>>>3)|0]<<(wa&7)>>>7;c[x>>2]=((wa|0)<(oa|0))+wa;c[E>>2]=ra&1;c[F>>2]=(qa+15|0)>>>4;c[G>>2]=(ta+15|0)>>>4;ra=c[C>>2]|0;c[ra+108>>2]=c[1347880+(va<<3)>>2];c[ra+104>>2]=c[1347884+(va<<3)>>2];c[ra+120>>2]=c[A>>2];c[ra+124>>2]=c[B>>2];if((c[H>>2]|0)!=0){break c}Tmb(b);break};case 437:case 434:{break};default:{if(!(la>>>0<432>>>0)){break c}ra=ma>>>0>2147483639>>>0|(ka|0)==0;va=ra?0:ka;wa=ra?0:ma;c[u>>2]=va;c[s>>2]=wa;c[v>>2]=wa+8;c[w>>2]=va+(wa>>3);c[x>>2]=0;v3(b,t)}}}while(0);d:do{if((na|0)==22){na=0;c[f>>2]=0;if((c[I>>2]|0)==0){break}wa=ma>>>0>2147483639>>>0|(ka|0)==0;va=wa?0:ka;ra=wa?0:ma;c[u>>2]=va;c[s>>2]=ra;c[v>>2]=ra+8;c[w>>2]=va+(ra>>3);c[x>>2]=0;c[g>>2]=c[j>>2];if((c[H>>2]|0)==0){KIb(c[C>>2]|0,16,2207672,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;break}WHb(c[O>>2]|0);ra=c[v>>2]|0;va=(c[x>>2]|0)+16|0;wa=ra>>>0>va>>>0?va:ra;c[x>>2]=wa;e:do{if((c[g>>2]|0)==438){va=(c[u>>2]|0)+(wa>>>3)|0;xa=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7)>>>30;va=wa+2|0;c[x>>2]=ra>>>0>va>>>0?va:ra;va=xa+1|0;xa=c[O>>2]|0;c[xa+88>>2]=va;if(va>>>0>3>>>0){KIb(c[C>>2]|0,16,2175272,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;break d}if((c[c[K>>2]>>2]|0)==0){break d}if((c[c[M>>2]>>2]|0)==0&(va|0)==3){break d}else{ya=xa;za=va}}else{va=c[O>>2]|0;c[va+88>>2]=1;xa=c[u>>2]|0;Aa=((wa|0)<(ra|0))+wa|0;if((d[xa+(wa>>>3)|0]&128>>>((wa&7)>>>0)|0)==0){Ba=Aa}else{Ca=Aa+24|0;Ba=ra>>>0>Ca>>>0?Ca:ra}c[x>>2]=Ba;do{if((c[E>>2]|0)==0){Ca=xa+(Ba>>>3)|0;Aa=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(Ba&7);if((Aa&8388608|0)==0){na=34;break}if((Aa&6291456|0)==0){if((c[ja>>2]|0)>0){break}else{ya=va;za=1;break e}}else{c[ja>>2]=1;break}}else{na=34}}while(0);if((na|0)==34){na=0;c[ja>>2]=1}xa=Ba+1|0;c[x>>2]=ra>>>0>xa>>>0?xa:ra;ya=va;za=1}}while(0);if((M4a(c[C>>2]|0,ya,(za|0)!=3|0)|0)<0){break}if((c[P>>2]|0)==0){ra=c[(c[O>>2]|0)+32>>2]|0;wa=pJb(((((ra|0)>-1?ra:-ra|0)<<1)+126&-64)*24|0)|0;c[P>>2]=wa;if((wa|0)==0){break}}if((Smb(b)|0)<0){break}wa=c[x>>2]|0;ra=c[v>>2]|0;ta=c[u>>2]|0;qa=ta+(wa>>>3)|0;oa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(wa&7)>>>24;qa=wa+8|0;wa=ra>>>0>qa>>>0?qa:ra;c[x>>2]=wa;qa=oa<<1;c[Q>>2]=qa;oa=c[(c[O>>2]|0)+88>>2]|0;pa=(oa|0)==3;sa=c[R>>2]|0;if(pa){Da=512-qa+sa|0}else{Da=512-sa+qa|0}sa=(Da|0)%512|0;c[S>>2]=sa;xa=((qa|512)-(c[T>>2]|0)|0)%512|0;c[U>>2]=xa;qa=(sa|0)==0;if(qa){Ea=0}else{Ea=512/(sa|0)|0}c[V>>2]=Ea;Aa=(xa|0)==0;if(Aa){Fa=0}else{Fa=512/(xa|0)|0}c[W>>2]=Fa;if(pa){c[X>>2]=ca(Fa,sa)|0}else{if(qa){Ga=0}else{Ga=16384/(sa|0)|0}c[J>>2]=Ga;if(Aa){Ha=0}else{Ha=16384/(xa|0)|0}c[ia>>2]=Ha}do{if((c[E>>2]|0)==0){Ia=wa}else{xa=ta+(wa>>>3)|0;Aa=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(wa&7);if(Aa>>>0>134217727>>>0){xa=(d[1382088+(Aa>>>23)|0]|0)+wa|0;sa=ra>>>0>xa>>>0?xa:ra;c[x>>2]=sa;Ia=sa;break}sa=Aa>>>0>65535>>>0;xa=sa?Aa>>>16:Aa;Aa=sa?16:0;if((xa&65280|0)==0){Ja=Aa;Ka=xa}else{Ja=Aa|8;Ka=xa>>>8}xa=63-((d[1359664+Ka|0]|0)+Ja<<1)+wa|0;Aa=ra>>>0>xa>>>0?xa:ra;c[x>>2]=Aa;Ia=Aa}}while(0);wa=d[ta+(Ia>>>3)|0]<<(Ia&7)>>>7;Aa=((Ia|0)<(ra|0))+Ia|0;c[x>>2]=Aa;xa=wa&1;c[Y>>2]=xa;c[Z>>2]=1;do{if((xa|0)==0){wa=d[ta+(Aa>>>3)|0]<<(Aa&7)>>>7;sa=((Aa|0)<(ra|0))+Aa|0;c[x>>2]=sa;qa=wa&1;c[Z>>2]=qa;if((qa|0)!=0){La=sa;Ma=qa;break}if((c[g>>2]|0)!=438){La=sa;Ma=0;break}qa=sa+1|0;sa=ra>>>0>qa>>>0?qa:ra;c[x>>2]=sa;La=sa;Ma=0}else{La=Aa;Ma=1}}while(0);Aa=La+1|0;sa=(ra>>>0>Aa>>>0?Aa:ra)+1|0;Aa=ra>>>0>sa>>>0?sa:ra;c[x>>2]=Aa;sa=d[ta+(Aa>>>3)|0]<<(Aa&7)>>>7;qa=((Aa|0)<(ra|0))+Aa|0;c[x>>2]=qa;c[_>>2]=sa&1;sa=ta+(qa>>>3)|0;Aa=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(qa&7)>>>26;sa=qa+6|0;qa=ra>>>0>sa>>>0?sa:ra;c[x>>2]=qa;c[$>>2]=Aa;if((oa|0)==3){if((Ma|0)==1){Na=qa;na=73}else{na=72}}else if((oa|0)==1){if((Ma|xa|0)==0){Aa=qa+1|0;sa=ra>>>0>Aa>>>0?Aa:ra;c[x>>2]=sa;Oa=sa}else{Oa=qa}sa=Oa+4|0;Aa=ra>>>0>sa>>>0?sa:ra;c[x>>2]=Aa;Pa=Aa}else{na=72}if((na|0)==72){na=0;Aa=d[ta+(qa>>>3)|0]<<(qa&7)>>>7;sa=((qa|0)<(ra|0))+qa|0;c[x>>2]=sa;c[aa>>2]=Aa&1;Na=sa;na=73}if((na|0)==73){na=0;sa=Na+4|0;Aa=ra>>>0>sa>>>0?sa:ra;c[x>>2]=Aa;sa=d[ta+(Aa>>>3)|0]<<(Aa&7)>>>7;qa=((Aa|0)<(ra|0))+Aa|0;c[x>>2]=qa;c[ba>>2]=sa&1;Pa=qa}qa=d[ta+(Pa>>>3)|0]<<(Pa&7)>>>7;sa=((Pa|0)<(ra|0))+Pa|0;c[x>>2]=sa;Aa=qa&1;c[da>>2]=Aa;do{if((Aa|0)==0){qa=d[ta+(sa>>>3)|0]|0;wa=((sa|0)<(ra|0))+sa|0;c[x>>2]=wa;if((qa&128>>>((sa&7)>>>0)|0)==0){na=87;break}qa=ta+(wa>>>3)|0;pa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(wa&7);if(pa>>>0>134217727>>>0){qa=pa>>>23;Ca=(d[1382088+qa|0]|0)+wa|0;Qa=ra>>>0>Ca>>>0?Ca:ra;c[x>>2]=Qa;Ra=a[1306768+qa|0]|0;Sa=Qa}else{Qa=pa>>>0>65535>>>0;qa=Qa?pa>>>16:pa;pa=Qa?16:0;if((qa&65280|0)==0){Ta=pa;Ua=qa}else{Ta=pa|8;Ua=qa>>>8}qa=(d[1359664+Ua|0]|0)+Ta|0;pa=31-qa+wa|0;wa=ra>>>0>pa>>>0?pa:ra;pa=ta+(wa>>>3)|0;Qa=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(wa&7)>>>(qa>>>0);pa=wa+(32-qa)|0;qa=ra>>>0>pa>>>0?pa:ra;c[x>>2]=qa;pa=Qa>>>1;Ra=(Qa&1|0)==0?pa:-pa|0;Sa=qa}c[ea>>2]=Ra;qa=ta+(Sa>>>3)|0;pa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Sa&7);if(pa>>>0>134217727>>>0){qa=pa>>>23;Qa=(d[1382088+qa|0]|0)+Sa|0;c[x>>2]=ra>>>0>Qa>>>0?Qa:ra;Va=a[1306768+qa|0]|0}else{qa=pa>>>0>65535>>>0;Qa=qa?pa>>>16:pa;pa=qa?16:0;if((Qa&65280|0)==0){Wa=pa;Xa=Qa}else{Wa=pa|8;Xa=Qa>>>8}Qa=(d[1359664+Xa|0]|0)+Wa|0;pa=31-Qa+Sa|0;qa=ra>>>0>pa>>>0?pa:ra;pa=ta+(qa>>>3)|0;wa=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(qa&7)>>>(Qa>>>0);pa=qa+(32-Qa)|0;c[x>>2]=ra>>>0>pa>>>0?pa:ra;pa=wa>>>1;Va=(wa&1|0)==0?pa:-pa|0}c[fa>>2]=Va}else{na=87}}while(0);if((na|0)==87){na=0;c[fa>>2]=0;c[ea>>2]=0}if((oa|0)==2){ra=-1;while(1){ta=(w3(b)|0)==0;sa=ta?ra:-1;ta=c[ba>>2]|0;do{if((ta|0)!=0&(sa|0)<0){Aa=c[x>>2]|0;xa=c[v>>2]|0;pa=(c[u>>2]|0)+(Aa>>>3)|0;wa=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(Aa&7);if(wa>>>0>134217727>>>0){pa=wa>>>23;Qa=(d[1382088+pa|0]|0)+Aa|0;c[x>>2]=xa>>>0>Qa>>>0?Qa:xa;Ya=d[1276064+pa|0]|0;break}pa=wa>>>0>65535>>>0;Qa=pa?wa>>>16:wa;qa=pa?16:0;if((Qa&65280|0)==0){Za=qa;_a=Qa}else{Za=qa|8;_a=Qa>>>8}Qa=(d[1359664+_a|0]|0)+Za<<1;qa=63-Qa+Aa|0;c[x>>2]=xa>>>0>qa>>>0?qa:xa;Ya=(wa>>>((Qa-31|0)>>>0))-1|0}else{Ya=sa}}while(0);do{if((ta|0)==0){$a=Ya;na=99}else{sa=Ya-1|0;if((Ya|0)==0){$a=sa;na=99;break}y3(b,1);ab=sa}}while(0);do{if((na|0)==99){na=0;sa=c[x>>2]|0;va=c[v>>2]|0;Qa=(c[u>>2]|0)+(sa>>>3)|0;wa=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(sa&7);if(wa>>>0>134217727>>>0){Qa=wa>>>23;xa=(d[1382088+Qa|0]|0)+sa|0;c[x>>2]=va>>>0>xa>>>0?xa:va;bb=d[1276064+Qa|0]|0}else{Qa=wa>>>0>65535>>>0;xa=Qa?wa>>>16:wa;qa=Qa?16:0;if((xa&65280|0)==0){cb=qa;db=xa}else{cb=qa|8;db=xa>>>8}xa=(d[1359664+db|0]|0)+cb<<1;qa=63-xa+sa|0;c[x>>2]=va>>>0>qa>>>0?qa:va;bb=(wa>>>((xa-31|0)>>>0))-1|0}xa=ta+1+bb|0;if(xa>>>0>5>>>0){x3(b,xa-6|0);ab=$a;break}else{y3(b,xa);ab=$a;break}}}while(0);if((Rmb(b)|0)==0){break}else{ra=ab}}}else if((oa|0)==1){do{w3(b)|0;x3(b,0);}while((Rmb(b)|0)!=0)}else{oa=-1;while(1){ra=(w3(b)|0)==0;ta=ra?oa:-1;ra=c[ba>>2]|0;do{if((ra|0)!=0&(ta|0)<0){xa=c[x>>2]|0;wa=c[v>>2]|0;va=(c[u>>2]|0)+(xa>>>3)|0;qa=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(xa&7);if(qa>>>0>134217727>>>0){va=qa>>>23;sa=(d[1382088+va|0]|0)+xa|0;c[x>>2]=wa>>>0>sa>>>0?sa:wa;eb=d[1276064+va|0]|0;break}va=qa>>>0>65535>>>0;sa=va?qa>>>16:qa;Qa=va?16:0;if((sa&65280|0)==0){fb=Qa;gb=sa}else{fb=Qa|8;gb=sa>>>8}sa=(d[1359664+gb|0]|0)+fb<<1;Qa=63-sa+xa|0;c[x>>2]=wa>>>0>Qa>>>0?Qa:wa;eb=(qa>>>((sa-31|0)>>>0))-1|0}else{eb=ta}}while(0);do{if((ra|0)==0){hb=eb;na=117}else{ta=eb-1|0;if((eb|0)==0){hb=ta;na=117;break}z3(b,6);ib=ta}}while(0);do{if((na|0)==117){na=0;ta=c[x>>2]|0;sa=c[v>>2]|0;qa=(c[u>>2]|0)+(ta>>>3)|0;wa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ta&7);if(wa>>>0>134217727>>>0){qa=wa>>>23;Qa=(d[1382088+qa|0]|0)+ta|0;c[x>>2]=sa>>>0>Qa>>>0?Qa:sa;jb=d[1276064+qa|0]|0}else{qa=wa>>>0>65535>>>0;Qa=qa?wa>>>16:wa;xa=qa?16:0;if((Qa&65280|0)==0){kb=xa;lb=Qa}else{kb=xa|8;lb=Qa>>>8}Qa=(d[1359664+lb|0]|0)+kb<<1;xa=63-Qa+ta|0;c[x>>2]=sa>>>0>xa>>>0?xa:sa;jb=(wa>>>((Qa-31|0)>>>0))-1|0}Qa=ra+6+jb|0;if(Qa>>>0>29>>>0){x3(b,Qa-30|0);ib=hb;break}else{z3(b,Qa);ib=hb;break}}}while(0);if((Rmb(b)|0)==0){break}else{oa=ib}}}oa=c[O>>2]|0;do{if((c[oa+88>>2]|0)==3){c[f>>2]=1;mb=oa}else{WHb(c[M>>2]|0);ra=c[ha>>2]|0;Qa=c[ha+4>>2]|0;wa=c[L>>2]|0;sa=c[L+4>>2]|0;c[L>>2]=ra;c[L+4>>2]=Qa;Qa=c[N+4>>2]|0;c[ha>>2]=c[N>>2];c[ha+4>>2]=Qa;c[N>>2]=wa;c[N+4>>2]=sa;sa=ra;ra=(c[sa+88>>2]|0)==3;c[f>>2]=1;if(ra){mb=sa;break}sa=c[M>>2]|0;if((c[sa>>2]|0)==0){c[f>>2]=0;break d}else{ra=YHb(ga,sa)|0;if((ra|0)<0){n=ra;break b}else{break d}}}}while(0);aIb(ga,mb)}}while(0);ma=U5a(ka,o,j)|0;oa=c[j>>2]|0;if(oa>>>0>511>>>0|(ma|0)==(o|0)){q=ma;break a}else{ka=ma;la=oa}}i=h;return n|0}}while(0);if((c[g>>2]|0)==0){KIb(c[k>>2]|0,24,2456752,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua}ua=q-l|0;n=(ua|0)<0?0:ua;i=h;return n|0}function u3(a){a=a|0;c[(c[a+60>>2]|0)+2316>>2]=0;return}function v3(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=a+1700|0;g=c[f>>2]|0;if((g|0)>175){KIb(c[a>>2]|0,16,2367080,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h;j=c[f>>2]|0}else{j=g}if((j|0)>=(c[a+1640>>2]|0)){KIb(c[a>>2]|0,16,2301336,(h=i,i=i+8|0,c[h>>2]=j,h)|0);i=h;i=e;return}g=a+1688|0;c[g>>2]=j;f=a+1636|0;c[a+1692>>2]=ca(c[f>>2]|0,j)|0;k=a+1696|0;c[k>>2]=c[k>>2]&-7;do{if((j|0)==0){k=a+2e3|0;if((c[k>>2]|0)!=0){break}l=b+8|0;m=c[l>>2]|0;n=c[b>>2]|0;o=(d[n+(m>>>3)|0]|0)<<(m&7)>>>7;p=b+16|0;c[l>>2]=((m|0)<(c[p>>2]|0))+m;c[k>>2]=o&1;o=c[l>>2]|0;k=c[p>>2]|0;p=n+(o>>>3)|0;n=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(o&7)>>>26;p=o+6|0;c[l>>2]=k>>>0>p>>>0?p:k;c[a+1996>>2]=n}}while(0);do{if((c[(c[a+1588>>2]|0)+88>>2]|0)==1){if((c[a+1660>>2]|0)!=0){i=e;return}if((c[g>>2]|0)>=((c[f>>2]|0)/2|0|0)){break}i=e;return}}while(0);f=b+8|0;g=c[f>>2]|0;j=d[(c[b>>2]|0)+(g>>>3)|0]|0;c[f>>2]=((g|0)<(c[b+16>>2]|0))+g;if((j&128>>>((g&7)>>>0)|0)==0){i=e;return}KIb(c[a>>2]|0,16,2250096,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;i=e;return}function w3(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=a+1568|0;if((c[a+1684>>2]|0)!=0){e=0;return e|0}f=a+1576|0;g=c[f>>2]|0;h=-g|0;i=h&7;j=c[b>>2]|0;if((i|0)==0){k=j+(g>>>3)|0;l=((je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(g&7)&-16777216|0)==-2147483648;m=l?8:0}else{m=i}i=m+24|0;if(i>>>0<26>>>0){l=j+(g>>>3)|0;n=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(g&7)>>>((8-m|0)>>>0)}else{l=c[a+1584>>2]|0;k=j+(g>>>3)|0;o=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(g&7)>>>16;k=g+16|0;p=l>>>0>k>>>0?k:l;l=j+(p>>>3)|0;n=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(p&7)>>>((24-m|0)>>>0)|o<<m+8}if((n&16777215|0)!=1){e=0;return e|0}n=c[a+1584>>2]|0;m=n-g|0;if((i|0)<(h|0)){q=h}else{q=(m|0)<(i|0)?m:i}i=q+g|0;c[f>>2]=i;g=j+(i>>>3)|0;j=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(i&7)>>>24;g=i+8|0;c[f>>2]=n>>>0>g>>>0?g:n;c[a+1700>>2]=j;if((j|0)>=(c[a+1640>>2]|0)){e=0;return e|0}v3(a,b);e=1;return e|0}function x3(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+40|0;g=f|0;h=f+8|0;j=f+32|0;k=b+1568|0;c[j>>2]=0;Qmb(b);l=b+1576|0;m=k|0;n=b+1584|0;o=0;do{p=d[602384+o|0]|0;q=c[b+1932+(p-1<<2)>>2]|0;r=c[b+1932+(p-3<<2)>>2]|0;s=(q|0)>(r|0)?r:q;q=(s|0)==-1?2:s;s=c[l>>2]|0;r=c[m>>2]|0;t=d[r+(s>>>3)|0]|0;u=c[n>>2]|0;v=((s|0)<(u|0))+s|0;c[l>>2]=v;if((t&128>>>((s&7)>>>0)|0)==0){s=r+(v>>>3)|0;r=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(v&7)>>>30;s=v+2|0;c[l>>2]=u>>>0>s>>>0?s:u;w=((r|0)>=(q|0))+r|0}else{w=q}c[b+1932+(p<<2)>>2]=w;o=o+1|0;}while((o|0)<4);o=c[l>>2]|0;w=c[n>>2]|0;p=(c[m>>2]|0)+(o>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(o&7);if(q>>>0>134217727>>>0){p=q>>>23;r=(d[1382088+p|0]|0)+o|0;c[l>>2]=w>>>0>r>>>0?r:w;x=d[1276064+p|0]|0}else{p=q>>>0>65535>>>0;r=p?q>>>16:q;u=p?16:0;if((r&65280|0)==0){y=u;z=r}else{y=u|8;z=r>>>8}r=(d[1359664+z|0]|0)+y<<1;y=63-r+o|0;c[l>>2]=w>>>0>y>>>0?y:w;x=(q>>>((r-31|0)>>>0))-1|0}c[g>>2]=x;if(x>>>0>6>>>0){KIb(c[b>>2]|0,16,2569272,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;i=f;return}Mmb(b,g);x=b+1588|0;do{if((c[(c[x>>2]|0)+88>>2]|0)==1){r=c[l>>2]|0;q=c[n>>2]|0;w=(c[m>>2]|0)+(r>>>3)|0;y=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(r&7);if(y>>>0>134217727>>>0){w=y>>>23;o=(d[1382088+w|0]|0)+r|0;c[l>>2]=q>>>0>o>>>0?o:q;B=d[1276064+w|0]|0;break}w=y>>>0>65535>>>0;o=w?y>>>16:y;z=w?16:0;if((o&65280|0)==0){C=z;D=o}else{C=z|8;D=o>>>8}o=(d[1359664+D|0]|0)+C<<1;z=63-o+r|0;c[l>>2]=q>>>0>z>>>0?z:q;B=(y>>>((o-31|0)>>>0))-1|0}else{B=e}}while(0);if(B>>>0>63>>>0){KIb(c[b>>2]|0,16,2551168,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;i=f;return}A=b+2004|0;c[A>>2]=d[1722432+(B<<1)|0]|0;do{if((B|0)!=4){if((c[b+2e3>>2]|0)!=0){break}e=b+1996|0;C=c[e>>2]|0;D=c[l>>2]|0;o=c[n>>2]|0;y=c[m>>2]|0;q=y+(D>>>3)|0;z=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(D&7);if(z>>>0>134217727>>>0){q=z>>>23;r=(d[1382088+q|0]|0)+D|0;c[l>>2]=o>>>0>r>>>0?r:o;E=a[1306768+q|0]|0}else{q=z>>>0>65535>>>0;r=q?z>>>16:z;z=q?16:0;if((r&65280|0)==0){F=z;G=r}else{F=z|8;G=r>>>8}r=(d[1359664+G|0]|0)+F|0;z=31-r+D|0;D=o>>>0>z>>>0?z:o;z=y+(D>>>3)|0;y=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(D&7)>>>(r>>>0);z=D+(32-r)|0;c[l>>2]=o>>>0>z>>>0?z:o;o=y>>>1;E=(y&1|0)==0?o:-o|0}c[e>>2]=E+C&63}}while(0);E=b+1704|0;l=h|0;h=b+1972|0;F=b+1996|0;G=0;do{m=(c[E>>2]|0)+(c[b+1980+(G<<2)>>2]|0)|0;Kmb(b,l,j,G);mf[c[b+2228+(c[b+1932+((a[602384+G|0]&255)<<2)>>2]<<2)>>2]&2047](m,l,c[j>>2]|0,c[h>>2]|0);if((c[A>>2]&1<<G|0)!=0){B3(b,k,1064640,1,c[F>>2]|0,m,c[h>>2]|0)}G=G+1|0;}while((G|0)<4);Lmb(b);G=b+1708|0;h=b+1684|0;j=b+1976|0;mf[c[b+2260+(c[g>>2]<<2)>>2]&2047](c[G>>2]|0,(c[b+2144>>2]|0)+((c[h>>2]|0)*10|0)|0,b+2178|0,c[j>>2]|0);l=b+1712|0;mf[c[b+2260+(c[g>>2]<<2)>>2]&2047](c[l>>2]|0,(c[b+2148>>2]|0)+((c[h>>2]|0)*10|0)|0,b+2188|0,c[j>>2]|0);h=c[A>>2]|0;if((h&16|0)==0){H=h}else{B3(b,k,1705232,0,d[1888768+(c[F>>2]|0)|0]|0,c[G>>2]|0,c[j>>2]|0);H=c[A>>2]|0}if((H&32|0)!=0){B3(b,k,1705232,0,d[1888768+(c[F>>2]|0)|0]|0,c[l>>2]|0,c[j>>2]|0)}Jmb(b,0);j=b+1768|0;l=1423928;F=c[l>>2]|0;k=c[l+4>>2]|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1800|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1808|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1776|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1864|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1896|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1904|0;c[j>>2]=F;c[j+4>>2]=k;j=b+1872|0;c[j>>2]=F;c[j+4>>2]=k;if((c[(c[x>>2]|0)+88>>2]|0)==3){i=f;return}a[(c[b+2288>>2]|0)+(c[b+1692>>2]|0)|0]=0;i=f;return}function y3(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=b+1568|0;Qmb(b);switch(e|0){case 1:{Pmb(b,5,3,4,0,0);break};case 3:{if((c[b+1680>>2]|0)==0){g=b+1576|0;h=c[g>>2]|0;i=c[f>>2]|0;j=(d[i+(h>>>3)|0]|0)<<(h&7)>>>7;k=c[b+1584>>2]|0;l=((h|0)<(k|0))+h|0;c[g>>2]=l;h=(d[i+(l>>>3)|0]|0)<<(l&7)>>>7;c[g>>2]=((l|0)<(k|0))+l;m=h&1;n=j&1}else{m=0;n=0}Pmb(b,5,3,2,1,n);Pmb(b,9,4,1,1,m);break};case 4:{if((c[b+1680>>2]|0)==0){m=b+1576|0;n=c[m>>2]|0;j=c[f>>2]|0;h=(d[j+(n>>>3)|0]|0)<<(n&7)>>>7;l=c[b+1584>>2]|0;k=((n|0)<(l|0))+n|0;c[m>>2]=k;n=(d[j+(k>>>3)|0]|0)<<(k&7)>>>7;c[m>>2]=((k|0)<(l|0))+k;o=n&1;p=h&1}else{o=0;p=0}Pmb(b,5,2,1,2,p);Pmb(b,6,3,3,2,o);break};case 5:{if((c[b+1680>>2]|0)==0){o=b+1576|0;p=c[o>>2]|0;h=c[f>>2]|0;n=(d[h+(p>>>3)|0]|0)<<(p&7)>>>7;k=c[b+1584>>2]|0;l=((p|0)<(k|0))+p|0;c[o>>2]=l;p=(d[h+(l>>>3)|0]|0)<<(l&7)>>>7;m=((l|0)<(k|0))+l|0;c[o>>2]=m;l=(d[h+(m>>>3)|0]|0)<<(m&7)>>>7;j=((m|0)<(k|0))+m|0;c[o>>2]=j;m=(d[h+(j>>>3)|0]|0)<<(j&7)>>>7;c[o>>2]=((j|0)<(k|0))+j;q=m&1;r=p&1;s=n&1;t=l&1}else{q=0;r=0;s=0;t=0}Pmb(b,5,2,0,3,s);Pmb(b,6,3,0,3,r);Pmb(b,9,6,0,3,t);Pmb(b,10,5,0,3,q);break};case 2:{if((c[b+1680>>2]|0)==0){q=b+1576|0;t=c[q>>2]|0;r=(d[(c[f>>2]|0)+(t>>>3)|0]|0)<<(t&7)>>>7;c[q>>2]=((t|0)<(c[b+1584>>2]|0))+t;u=r&1}else{u=0}Pmb(b,5,3,0,0,u);break};default:{}}Nmb(b,e);u=b+1956|0;if((c[b+1652>>2]|0)>0){c[u>>2]=-1;c[b+1944>>2]=-1;r=b+1684|0;t=c[b+1968>>2]|0;c[t+((c[r>>2]<<1|1)<<2)>>2]=-1;c[t+(c[r>>2]<<1<<2)>>2]=-1}else{c[u>>2]=2;c[b+1944>>2]=2;u=b+1684|0;r=c[b+1968>>2]|0;c[r+((c[u>>2]<<1|1)<<2)>>2]=2;c[r+(c[u>>2]<<1<<2)>>2]=2}u=b+1692|0;r=b+1928|0;t=b+1768|0;q=(c[r>>2]|0)+(c[u>>2]<<2<<3)|0;f=c[t+4>>2]|0;c[q>>2]=c[t>>2];c[q+4>>2]=f;f=b+1776|0;q=(c[r>>2]|0)+((c[u>>2]<<2|1)<<3)|0;t=c[f+4>>2]|0;c[q>>2]=c[f>>2];c[q+4>>2]=t;t=b+1800|0;q=(c[r>>2]|0)+((c[u>>2]<<2|2)<<3)|0;f=c[t+4>>2]|0;c[q>>2]=c[t>>2];c[q+4>>2]=f;f=b+1808|0;q=(c[r>>2]|0)+((c[u>>2]<<2|3)<<3)|0;r=c[f+4>>2]|0;c[q>>2]=c[f>>2];c[q+4>>2]=r;if((e|0)==1){Jmb(b,e);v=e&255;w=c[u>>2]|0;x=b+2288|0;y=c[x>>2]|0;z=y+w|0;a[z]=v;return}A3(b);Jmb(b,e);v=e&255;w=c[u>>2]|0;x=b+2288|0;y=c[x>>2]|0;z=y+w|0;a[z]=v;return}function z3(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+16|0;h=g|0;Qmb(e);j=e+1768|0;k=j;l=1423936;m=c[l>>2]|0;n=c[l+4>>2]|0;c[k>>2]=m;c[k+4>>2]=n;k=e+1800|0;c[k>>2]=m;c[k+4>>2]=n;k=e+1808|0;c[k>>2]=m;c[k+4>>2]=n;k=e+1776|0;c[k>>2]=m;c[k+4>>2]=n;k=e+1864|0;l=k;c[l>>2]=m;c[l+4>>2]=n;o=e+1896|0;p=o;c[p>>2]=m;c[p+4>>2]=n;q=e+1904|0;c[q>>2]=m;c[q+4>>2]=n;r=e+1872|0;s=r;c[s>>2]=m;c[s+4>>2]=n;a:do{switch(f|0){case 6:case 7:{n=e+1692|0;m=c[n>>2]|0;if((a[(c[e+2288>>2]|0)+m|0]|0)==0){Pmb(e,5,3,5,0,1);Pmb(e,17,15,5,0,0);break a}t=e+1928|0;u=e+1616|0;v=e+1612|0;w=0;x=m;while(1){m=d[791e3+w|0]|0;y=(x<<2)+w|0;z=c[t>>2]|0;A=c[e+2296+(b[z+(y<<3)+6>>1]<<2)>>2]|0;B=z+(y<<3)|0;C=b[B>>1]|0;D=C>>31;E=c[u>>2]&65535;b[e+1728+(m<<3)+4>>1]=E;F=c[v>>2]&65535;G=m+12|0;b[e+1728+(G<<3)+4>>1]=F;b[e+1728+(m<<3)+6>>1]=1;b[e+1728+(G<<3)+6>>1]=0;H=ca(E<<16>>16,A)|0;E=A+1073741823|0;I=(C>>>31)+E|0;b[e+1728+(m<<3)>>1]=((((ca(H,b[B>>1]|0)|0)^D)+I|0)>>>14^D)-D;C=ca(F<<16>>16,A)|0;b[e+1728+(G<<3)>>1]=D-((((ca(C,b[B>>1]|0)|0)^D)+I|0)>>>14^D);D=z+(y<<3)+2|0;y=b[D>>1]|0;z=y>>31;I=(y>>>31)+E|0;b[e+1728+(m<<3)+2>>1]=((I+((ca(H,y)|0)^z)|0)>>>14^z)-z;b[e+1728+(G<<3)+2>>1]=z-((((ca(C,b[D>>1]|0)|0)^z)+I|0)>>>14^z);z=w+1|0;if((z|0)>=4){break a}w=z;x=c[n>>2]|0}break};case 29:{n=e+1576|0;x=c[n>>2]|0;w=c[e+1584>>2]|0;v=c[e+1568>>2]|0;u=v+(x>>>3)|0;t=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7)>>>30;u=x+2|0;x=w>>>0>u>>>0?u:w;c[n>>2]=x;c[h>>2]=t;u=v+(x>>>3)|0;z=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7)>>>30;u=x+2|0;x=w>>>0>u>>>0?u:w;c[n>>2]=x;c[h+4>>2]=z;u=v+(x>>>3)|0;I=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7)>>>30;u=x+2|0;x=w>>>0>u>>>0?u:w;c[n>>2]=x;c[h+8>>2]=I;u=v+(x>>>3)|0;v=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7)>>>30;u=x+2|0;c[n>>2]=w>>>0>u>>>0?u:w;c[h+12>>2]=v;w=e+1692|0;u=e+2288|0;n=e+1928|0;x=e+1616|0;D=e+1612|0;C=e+2292|0;G=0;y=t;while(1){do{if((y|0)==1){H=d[791e3+G|0]|0;Pmb(e,H,H-3|0,0,3,1)}else if((y|0)==3){H=d[791e3+G|0]|0;Pmb(e,H,H-3|0,0,3,1);m=c[D>>2]|0;E=c[C>>2]|0;B=H+12|0;b[e+1728+(B<<3)>>1]=-(((ca(b[e+1728+(H<<3)>>1]|0,E)|0)+256|0)>>>9);b[e+1728+(B<<3)+2>>1]=-(((ca(b[e+1728+(H<<3)+2>>1]|0,E)|0)+256|0)>>>9);b[e+1728+(B<<3)+6>>1]=0;b[e+1728+(B<<3)+4>>1]=m}else if((y|0)==0){m=c[w>>2]|0;B=d[791e3+G|0]|0;if((a[(c[u>>2]|0)+m|0]|0)==0){Pmb(e,B,B-3|0,5,3,1);Pmb(e,B+12|0,B+9|0,5,3,0);break}else{E=(m<<2)+G|0;m=c[n>>2]|0;H=c[e+2296+(b[m+(E<<3)+6>>1]<<2)>>2]|0;A=m+(E<<3)|0;F=b[A>>1]|0;J=F>>31;K=c[x>>2]&65535;b[e+1728+(B<<3)+4>>1]=K;L=c[D>>2]&65535;M=B+12|0;b[e+1728+(M<<3)+4>>1]=L;b[e+1728+(B<<3)+6>>1]=1;b[e+1728+(M<<3)+6>>1]=0;N=ca(K<<16>>16,H)|0;K=H+1073741823|0;O=(F>>>31)+K|0;b[e+1728+(B<<3)>>1]=((((ca(N,b[A>>1]|0)|0)^J)+O|0)>>>14^J)-J;F=ca(L<<16>>16,H)|0;b[e+1728+(M<<3)>>1]=J-((((ca(F,b[A>>1]|0)|0)^J)+O|0)>>>14^J);J=m+(E<<3)+2|0;E=b[J>>1]|0;m=E>>31;O=(E>>>31)+K|0;b[e+1728+(B<<3)+2>>1]=((O+((ca(N,E)|0)^m)|0)>>>14^m)-m;b[e+1728+(M<<3)+2>>1]=m-((((ca(F,b[J>>1]|0)|0)^m)+O|0)>>>14^m);break}}}while(0);m=G+1|0;if((m|0)>=4){break}G=m;y=c[h+(m<<2)>>2]|0}if((t|0)==2){Pmb(e,17,14,0,3,0)}if((z|0)==2){Pmb(e,18,15,0,3,0)}if((I|0)==2){Pmb(e,21,18,0,3,0)}if((v|0)!=2){break a}Pmb(e,22,19,0,3,0);break};case 8:{Pmb(e,5,3,0,0,1);break};case 9:{Pmb(e,17,15,0,0,0);break};case 10:{Pmb(e,5,3,0,0,1);y=c[e+1612>>2]|0;G=c[e+2292>>2]|0;b[k>>1]=-(((ca(b[j>>1]|0,G)|0)+256|0)>>>9);b[e+1866>>1]=-(((ca(b[e+1770>>1]|0,G)|0)+256|0)>>>9);b[e+1870>>1]=0;b[e+1868>>1]=y;y=c[l>>2]|0;G=c[l+4>>2]|0;c[p>>2]=y;c[p+4>>2]=G;c[q>>2]=y;c[q+4>>2]=G;c[s>>2]=y;c[s+4>>2]=G;break};default:{if(f>>>0<11>>>0){KIb(c[e>>2]|0,16,2147672,(G=i,i=i+8|0,c[G>>2]=f,G)|0);i=G;i=g;return}G=d[1423896+f|0]|0;y=(G&1|0)!=0;if((f&1|0)==0){if(y){Pmb(e,5,2,1,2,1)}if((G&16|0)!=0){D=c[e+1612>>2]|0;x=c[e+2292>>2]|0;b[k>>1]=-(((ca(b[j>>1]|0,x)|0)+256|0)>>>9);b[e+1866>>1]=-(((ca(b[e+1770>>1]|0,x)|0)+256|0)>>>9);b[e+1870>>1]=0;b[e+1868>>1]=D;D=c[l+4>>2]|0;c[p>>2]=c[l>>2];c[p+4>>2]=D}if((G&2|0)!=0){Pmb(e,6,3,3,2,1)}if((G&32|0)!=0){D=c[e+1612>>2]|0;x=c[e+2292>>2]|0;b[r>>1]=-(((ca(b[e+1776>>1]|0,x)|0)+256|0)>>>9);b[e+1874>>1]=-(((ca(b[e+1778>>1]|0,x)|0)+256|0)>>>9);b[e+1878>>1]=0;b[e+1876>>1]=D;D=c[s+4>>2]|0;c[q>>2]=c[s>>2];c[q+4>>2]=D}if((G&4|0)!=0){Pmb(e,17,14,1,2,0)}if((G&8|0)==0){break a}Pmb(e,18,15,3,2,0);break a}else{if(y){Pmb(e,5,3,2,1,1)}if((G&16|0)!=0){y=c[e+1612>>2]|0;D=c[e+2292>>2]|0;b[k>>1]=-(((ca(b[j>>1]|0,D)|0)+256|0)>>>9);b[e+1866>>1]=-(((ca(b[e+1770>>1]|0,D)|0)+256|0)>>>9);b[e+1870>>1]=0;b[e+1868>>1]=y;y=c[l+4>>2]|0;c[s>>2]=c[l>>2];c[s+4>>2]=y}if((G&2|0)!=0){Pmb(e,9,4,1,1,1)}if((G&32|0)!=0){y=c[e+1612>>2]|0;D=c[e+2292>>2]|0;b[o>>1]=-(((ca(b[e+1800>>1]|0,D)|0)+256|0)>>>9);b[e+1898>>1]=-(((ca(b[e+1802>>1]|0,D)|0)+256|0)>>>9);b[e+1902>>1]=0;b[e+1900>>1]=y;y=c[p+4>>2]|0;c[q>>2]=c[p>>2];c[q+4>>2]=y}if((G&4|0)!=0){Pmb(e,17,15,2,1,0)}if((G&8|0)==0){break a}Pmb(e,21,16,1,1,0);break a}}}}while(0);Nmb(e,f);q=e+1956|0;if((c[e+1652>>2]|0)>0){c[q>>2]=-1;c[e+1944>>2]=-1;p=e+1684|0;o=c[e+1968>>2]|0;c[o+((c[p>>2]<<1|1)<<2)>>2]=-1;c[o+(c[p>>2]<<1<<2)>>2]=-1}else{c[q>>2]=2;c[e+1944>>2]=2;q=e+1684|0;p=c[e+1968>>2]|0;c[p+((c[q>>2]<<1|1)<<2)>>2]=2;c[p+(c[q>>2]<<1<<2)>>2]=2}if((f|0)!=6){A3(e)}Jmb(e,f);i=g;return}function A3(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;f=b+1568|0;g=b+1576|0;h=c[g>>2]|0;j=c[b+1584>>2]|0;k=c[f>>2]|0;l=k+(h>>>3)|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7);if(m>>>0>134217727>>>0){l=m>>>23;n=(d[1382088+l|0]|0)+h|0;o=j>>>0>n>>>0?n:j;c[g>>2]=o;p=d[1276064+l|0]|0;q=o}else{o=m>>>0>65535>>>0;l=o?m>>>16:m;n=o?16:0;if((l&65280|0)==0){r=n;s=l}else{r=n|8;s=l>>>8}l=(d[1359664+s|0]|0)+r<<1;r=63-l+h|0;h=j>>>0>r>>>0?r:j;c[g>>2]=h;p=(m>>>((l-31|0)>>>0))-1|0;q=h}if(p>>>0>63>>>0){KIb(c[b>>2]|0,16,2123776,(h=i,i=i+8|0,c[h>>2]=p,h)|0);i=h;i=e;return}h=d[1722433+(p<<1)|0]|0;l=b+2004|0;c[l>>2]=h;do{if((p|0)!=0){if((c[b+2e3>>2]|0)!=0){break}m=b+1996|0;r=c[m>>2]|0;s=k+(q>>>3)|0;n=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(q&7);if(n>>>0>134217727>>>0){s=n>>>23;o=(d[1382088+s|0]|0)+q|0;c[g>>2]=j>>>0>o>>>0?o:j;t=a[1306768+s|0]|0}else{s=n>>>0>65535>>>0;o=s?n>>>16:n;n=s?16:0;if((o&65280|0)==0){u=n;v=o}else{u=n|8;v=o>>>8}o=(d[1359664+v|0]|0)+u|0;n=31-o+q|0;s=j>>>0>n>>>0?n:j;n=k+(s>>>3)|0;w=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(s&7)>>>(o>>>0);n=s+(32-o)|0;c[g>>2]=j>>>0>n>>>0?n:j;n=w>>>1;t=(w&1|0)==0?n:-n|0}c[m>>2]=t+r&63}}while(0);t=b+1996|0;j=b+1704|0;g=b+1972|0;if((h&1|0)==0){x=h}else{B3(b,f,1068792,0,c[t>>2]|0,(c[j>>2]|0)+(c[b+1980>>2]|0)|0,c[g>>2]|0);x=c[l>>2]|0}if((x&2|0)==0){y=x}else{B3(b,f,1068792,0,c[t>>2]|0,(c[j>>2]|0)+(c[b+1984>>2]|0)|0,c[g>>2]|0);y=c[l>>2]|0}if((y&4|0)==0){z=y}else{B3(b,f,1068792,0,c[t>>2]|0,(c[j>>2]|0)+(c[b+1988>>2]|0)|0,c[g>>2]|0);z=c[l>>2]|0}if((z&8|0)==0){A=z}else{B3(b,f,1068792,0,c[t>>2]|0,(c[j>>2]|0)+(c[b+1992>>2]|0)|0,c[g>>2]|0);A=c[l>>2]|0}if((A&16|0)==0){B=A}else{B3(b,f,1705232,0,d[1888768+(c[t>>2]|0)|0]|0,c[b+1708>>2]|0,c[b+1976>>2]|0);B=c[l>>2]|0}if((B&32|0)==0){i=e;return}B3(b,f,1705232,0,d[1888768+(c[t>>2]|0)|0]|0,c[b+1712>>2]|0,c[b+1976>>2]|0);i=e;return}function B3(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;n=i;i=i+208|0;o=n|0;p=n+136|0;q=c[f+2320>>2]|0;r=g+8|0;s=g+16|0;t=g|0;g=-2147483648>>>(j>>>0);u=(j|0)==0;v=32-j|0;w=0;x=h;while(1){h=a[x+204|0]|0;y=h<<24>>24;z=c[r>>2]|0;A=c[s>>2]|0;B=c[t>>2]|0;C=B+(z>>>3)|0;D=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(z&7);if(D>>>0>134217727>>>0){C=D>>>23;E=(d[1382088+C|0]|0)+z|0;F=A>>>0>E>>>0?E:A;c[r>>2]=F;G=d[1276064+C|0]|0;H=F}else{F=D>>>0>65535>>>0;C=F?D>>>16:D;E=F?16:0;if((C&65280|0)==0){I=E;J=C}else{I=E|8;J=C>>>8}C=(d[1359664+J|0]|0)+I<<1;E=63-C+z|0;z=A>>>0>E>>>0?E:A;c[r>>2]=z;G=(D>>>((C-31|0)>>>0))-1|0;H=z}if(!(G>>>0<-2147483648>>>(y>>>0)>>>0)){K=8;break}if(h<<24>>24==0){L=G;M=H}else{h=B+(H>>>3)|0;z=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(H&7)>>>((32-y|0)>>>0);h=H+y|0;C=A>>>0>h>>>0?h:A;c[r>>2]=C;L=z+(G<<y)|0;M=C}if(L>>>0>58>>>0){C=((L-59|0)>>>1)+1|0;if(C>>>0>64>>>0){N=C;break}y=B+(M>>>3)|0;z=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(M&7);if(z>>>0>134217727>>>0){y=z>>>23;h=(d[1382088+y|0]|0)+M|0;D=A>>>0>h>>>0?h:A;c[r>>2]=D;O=d[1276064+y|0]|0;P=D}else{D=z>>>0>65535>>>0;y=D?z>>>16:z;h=D?16:0;if((y&65280|0)==0){Q=h;R=y}else{Q=h|8;R=y>>>8}y=(d[1359664+R|0]|0)+Q<<1;h=63-y+M|0;D=A>>>0>h>>>0?h:A;c[r>>2]=D;O=(z>>>((y-31|0)>>>0))-1|0;P=D}do{if(O>>>0<g>>>0){if(u){S=O;break}D=B+(P>>>3)|0;y=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(P&7)>>>(v>>>0);D=P+j|0;c[r>>2]=A>>>0>D>>>0?D:A;S=y+(O<<j)|0}else{KIb(0,16,2591224,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;S=-1094995529}}while(0);if(C>>>0>(a[x+212|0]|0)>>>0){U=1}else{U=a[x+177+C|0]|0}A=U+S|0;B=x;while(1){if((A|0)>(c[B+208>>2]|0)){B=B+216|0}else{break}}y=L&1;V=C&255;W=B;X=(A^-y)+y&65535}else{y=a[x+(L*3|0)|0]|0;if(y<<24>>24==0){Y=w;K=31;break}V=a[x+(L*3|0)+1|0]|0;W=x+((a[x+(L*3|0)+2|0]|0)*216|0)|0;X=y<<24>>24}b[o+(w<<1)>>1]=X;a[p+w|0]=V;y=w+1|0;if((y|0)<65){w=y;x=W}else{Y=y;K=31;break}}if((K|0)==8){KIb(0,16,2591224,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;N=1599985855}else if((K|0)==31){K=e[1551952+(k<<1)>>1]|0;W=d[1551888+k|0]|0;k=1<<W-1;a:do{if((Y|0)>0){x=-1;w=Y;while(1){w=w-1|0;x=(d[p+w|0]|0)+x|0;if((x|0)>63){break}V=(ca(b[o+(w<<1)>>1]|0,K)|0)+k>>W&65535;b[q+(d[f+2012+x|0]<<1)>>1]=V;if((w|0)<=0){break a}}w=c[f+1684>>2]|0;x=c[f+1688>>2]|0;KIb(c[f>>2]|0,16,2618520,(T=i,i=i+24|0,c[T>>2]=c[f+1592>>2],c[T+8>>2]=w,c[T+16>>2]=x,T)|0);i=T;i=n;return}}while(0);ef[c[f+1560>>2]&4095](l,q,m);qe[c[f+40>>2]&1023](q);i=n;return}KIb(c[f>>2]|0,16,2641208,(T=i,i=i+8|0,c[T>>2]=N,T)|0);i=T;i=n;return}function C3(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=UHb()|0;c[b>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+120>>2]=300;c[a+124>>2]=216;c[a+140>>2]=11;e=0;return e|0}function D3(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;i=i+16|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=j|0;mrc(g|0,0,16)|0;m=e;n=c[b+60>>2]|0;if((l|0)<6){KIb(b,16,2456704,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}if((l|0)>24){KIb(b,16,2366960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}q=n;r=N4a(b,c[q>>2]|0)|0;if((r|0)<0){p=r;i=h;return p|0}if((c[b+428>>2]|0)==0){r=c[q>>2]|0;mrc(c[r>>2]|0,0,ca(c[b+124>>2]|0,c[r+32>>2]|0)|0)|0;mrc(c[(c[q>>2]|0)+4>>2]|0,0,1024)|0}r=a[k]|0;s=d[k+1|0]|0;if((l|0)>8){nrc(g|0,k+4|0,l-8|0)|0}do{if((r&63)==9){k=s&63;a:do{switch(k|0){case 1:{if(!((a[j+1|0]&15)==0)){break a}t=c[q>>2]|0;mrc(c[t>>2]|0,a[g]&15|0,(c[t+32>>2]|0)*216|0|0)|0;break};case 2:{t=c[q>>2]|0;u=c[t>>2]|0;v=c[t+32>>2]|0;if(!((a[j+1|0]&15)==0)){break a}t=a[g]&15;w=v*12|0;mrc(u|0,t|0,w|0)|0;mrc(u+(v*204|0)|0,t|0,w|0)|0;w=12;do{x=ca(w,v)|0;mrc(u+x|0,t|0,6)|0;mrc(u+(x+294)|0,t|0,6)|0;w=w+1|0;}while((w|0)<204);break};case 20:case 24:{if((l-8|0)<3){KIb(b,16,2175216,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}w=M4a(b,m,1)|0;if((w|0)<0){p=w;i=h;return p|0}w=(k|0)==24;t=c[q>>2]|0;u=c[t+32>>2]|0;v=c[t>>2]|0;x=c[e>>2]|0;y=a[g]&15;z=d[j+1|0]|0;A=z>>>4&3;B=d[j+2|0]|0;C=B>>>4&3;D=z&7;z=D>>>0>5>>>0?5:D;D=B&15;B=D>>>0>11>>>0?11:D;D=n+4|0;E=z-(c[D>>2]|0)|0;F=n+8|0;G=B-(c[F>>2]|0)|0;c[D>>2]=z;c[F>>2]=B;B=(C|0)==2?G-12|0:G;G=(C|0)==1?B+12|0:B;B=-G|0;C=(A|0)==2?E-6|0:E;E=(A|0)==1?C+6|0:C;C=-E|0;b:do{if((G|E|0)!=0){nrc(c[e+4>>2]|0,c[t+4>>2]|0,64)|0;A=(G|0)<0;F=A?0:G;z=G+216|0;D=(G|0)>0;H=D?216:z;if((F|0)<(H|0)){I=(E|0)<0?0:E;J=I-E|0;K=((E|0)>0?0:E)+u|0;L=F;do{nrc(x+((ca(L,u)|0)+I)|0,v+(J+(ca(L-G|0,u)|0))|0,K)|0;L=L+1|0;}while((L|0)<(H|0))}c:do{if(D){if(w){H=216-G|0;L=0;do{nrc(x+(ca(L,u)|0)|0,v+(ca(H+L|0,u)|0)|0,u)|0;L=L+1|0;}while((L|0)<(G|0))}else{L=y&255;H=0;do{mrc(x+(ca(H,u)|0)|0,L|0,u|0)|0;H=H+1|0;}while((H|0)<(G|0))}}else{if(!A){break}H=(B|0)>0;if(w){if(H){M=0}else{break}while(1){nrc(x+(ca(M+z|0,u)|0)|0,v+(ca(M,u)|0)|0,u)|0;M=M+1|0;if((M|0)>=(B|0)){break c}}}if(!H){break}L=y&255;K=z;do{mrc(x+(ca(K,u)|0)|0,L|0,u|0)|0;K=K+1|0;}while((K|0)<216)}}while(0);if((E|0)>0){z=300-E|0;if(w){A=0;while(1){D=ca(A,u)|0;nrc(x+D|0,v+(z+D)|0,E)|0;A=A+1|0;if((A|0)>=216){break b}}}A=y&255;z=0;while(1){mrc(x+(ca(z,u)|0)|0,A|0,E|0)|0;z=z+1|0;if((z|0)>=216){break b}}}if((E|0)>=0){break}z=E+300|0;if(w){A=0;while(1){D=ca(A,u)|0;nrc(x+(D+z)|0,v+D|0,C)|0;A=A+1|0;if((A|0)>=216){break b}}}A=y&255;D=0;do{mrc(x+((ca(D,u)|0)+z)|0,A|0,C|0)|0;D=D+1|0;}while((D|0)<216)}}while(0);WHb(c[q>>2]|0);C=YHb(c[q>>2]|0,m)|0;if((C|0)<0){p=C}else{break a}i=h;return p|0};case 38:case 6:{if((l-8|0)<16){KIb(b,16,2250024,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}C=c[q>>2]|0;u=c[C>>2]|0;x=c[C+32>>2]|0;C=((a[j+2|0]&31)*12|0)+(c[n+8>>2]|0)|0;y=((a[j+3|0]&63)*6|0)+(c[n+4>>2]|0)|0;if(C>>>0>204>>>0|y>>>0>294>>>0){KIb(b,16,2207632,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}v=a[g]|0;w=a[j+1|0]|0;if((k|0)==38){E=0;do{B=(ca(E+C|0,x)|0)+y|0;G=a[j+(E+4)|0]|0;t=u+B|0;a[t]=((G&32)==0?v:w)&15^a[t];t=u+(B+1)|0;a[t]=((G&16)==0?v:w)&15^a[t];t=u+(B+2)|0;a[t]=((G&8)==0?v:w)&15^a[t];t=u+(B+3)|0;a[t]=((G&4)==0?v:w)&15^a[t];t=u+(B+4)|0;a[t]=((G&2)==0?v:w)&15^a[t];t=u+(B+5)|0;a[t]=((G&1)==0?v:w)&15^a[t];E=E+1|0;}while((E|0)<12)}else{E=0;do{t=(ca(E+C|0,x)|0)+y|0;G=a[j+(E+4)|0]|0;a[u+t|0]=((G&32)==0?v:w)&15;a[u+(t+1)|0]=((G&16)==0?v:w)&15;a[u+(t+2)|0]=((G&8)==0?v:w)&15;a[u+(t+3)|0]=((G&4)==0?v:w)&15;a[u+(t+4)|0]=((G&2)==0?v:w)&15;a[u+(t+5)|0]=((G&1)==0?v:w)&15;E=E+1|0;}while((E|0)<12)}break};case 30:case 31:{if((l-8|0)<16){KIb(b,16,2301248,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=h;return p|0}E=c[q>>2]|0;w=(k|0)==30?0:8;v=c[E+4>>2]|0;u=0;do{y=u<<1;x=(a[j+(y|1)|0]&63|(d[j+y|0]|0)<<6)&65535;c[v+(u+w<<2)>>2]=((x&15)*17|0)&255|(ca(x>>>8&15,1114112)|0)|((x>>>4&15)*4352|0)&65280|-16777216;u=u+1|0;}while((u|0)<8);c[E+304>>2]=1;break};default:{}}}while(0);if((c[e>>2]|0)!=0){N=l;O=1;break}k=YHb(m,c[q>>2]|0)|0;if((k|0)<0){p=k}else{N=l;O=1;break}i=h;return p|0}else{N=0;O=0}}while(0);c[f>>2]=O;p=N;i=h;return p|0}function E3(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function F3(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+36>>2]=0;c[b>>2]=a;return 0}function G3(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;h=i;i=i+320|0;j=h|0;k=h+256|0;l=c[b+60>>2]|0;m=l;n=e;o=c[g+28>>2]|0;p=c[g+24>>2]|0;if((o|0)<32){q=-1094995529;i=h;return q|0}g=d[p+1|0]|0;r=g&7;s=g&224;c[l+8>>2]=s;g=p+14|0;t=(he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;g=p+16|0;u=(he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;g=a[p+19|0]|0;v=l+4|0;c[v>>2]=g&255;w=p+20|0;x=he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0;w=x&65535;z=l+20|0;c[z>>2]=w;A=l+16|0;c[A>>2]=p+32;B=w+32|0;c[l+24>>2]=p+B;p=l+28|0;c[p>>2]=o-32-w;if((x&65535)>>>0>512>>>0|(o|0)<(B|0)|g<<24>>24==0){q=-1094995529;i=h;return q|0}if(!((s|0)==0|(s|0)==128)){QIb(b,2456608,(C=i,i=i+8|0,c[C>>2]=s,C)|0);i=C;q=-1163346256;i=h;return q|0}s=H4a(b,t,u)|0;if((s|0)<0){q=s;i=h;return q|0}s=l;g=c[(c[s>>2]|0)+120>>2]|0;B=g+15&-16;c[l+12>>2]=B-g;g=ca(B,c[b+124>>2]|0)|0;B=c[v>>2]|0;if((c[p>>2]|0)<((ca(g,B)|0)/8|0|0)){q=-1094995529;i=h;return q|0}g=(r|0)!=0;do{if(g){if((r|0)!=1){D=14;break}if(!((B|0)==6|(B|0)==8)){D=14;break}if((c[z>>2]|0)==(1<<B-1|0)){c[b+140>>2]=3;break}else{q=-1094995529;i=h;return q|0}}else{if(!((c[z>>2]|0)!=0&(B|0)<9)){D=14;break}c[b+140>>2]=11}}while(0);if((D|0)==14){QIb(b,2366936,(C=i,i=i+16|0,c[C>>2]=r,c[C+8>>2]=B,C)|0);i=C;q=-1163346256;i=h;return q|0}C=M4a(b,n,0)|0;if((C|0)<0){q=C;i=h;return q|0}c[e+88>>2]=1;a:do{if(g){C=l+32|0;A4a(C,l+36|0,(ca(u,t)|0)+16|0);n=c[C>>2]|0;if((n|0)==0){q=-12;i=h;return q|0}if((c[v>>2]|0)==8){C=c[s>>2]|0;b=c[e>>2]|0;B=j|0;r=c[z>>2]|0;if((r|0)>1){D=c[A>>2]|0;p=(r|0)/2|0;r=0;do{x=D+(r<<1)|0;w=(he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535;c[j+(r<<2)>>2]=(w&15)*17|0|((w>>>4&15)*4352|0)|(ca(w>>>8&15,1114112)|0)|-16777216;r=r+1|0;}while((r|0)<(p|0))}p=C+120|0;I3(m,c[p>>2]|0,n);r=C+124|0;D=c[r>>2]|0;if((D|0)<=0){break}w=e+32|0;x=n;E=b;F=1;G=c[p>>2]|0;H=D;while(1){D=c[B>>2]|0;if((G|0)>0){I=D&65280;J=D&255;K=x;L=D&16711680;D=0;while(1){M=K+1|0;N=a[K]|0;O=N&63;P=(N&255)>>>6&255;if((P|0)==3){Q=L;R=J;S=(O&255)<<10|I&768}else if((P|0)==2){Q=(O&255)<<18|L&196608;R=J;S=I}else if((P|0)==0){N=c[j+((O&255)<<2)>>2]|0;Q=N&16711680;R=N&255;S=N&65280}else if((P|0)==1){Q=L;R=(O&255)<<2|J&3;S=I}else{Q=L;R=J;S=I}O=R|S|Q;P=D*3|0;a[E+P|0]=O;a[E+(P+1)|0]=O>>>8;a[E+(P+2)|0]=O>>>16;O=D+1|0;T=c[p>>2]|0;if((O|0)<(T|0)){I=S;J=R;K=M;L=Q;D=O}else{break}}U=M;V=T;W=c[r>>2]|0}else{U=x;V=G;W=H}if((F|0)>=(W|0)){break a}x=U;E=E+(c[w>>2]|0)|0;F=F+1|0;G=V;H=W}}else{H=c[s>>2]|0;G=c[e>>2]|0;F=k|0;w=c[z>>2]|0;if((w|0)>1){E=c[A>>2]|0;x=(w|0)/2|0;w=0;do{r=E+(w<<1)|0;p=(he((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535;c[k+(w<<2)>>2]=(p&15)*17|0|((p>>>4&15)*4352|0)|(ca(p>>>8&15,1114112)|0)|-16777216;w=w+1|0;}while((w|0)<(x|0))}x=H+120|0;I3(m,c[x>>2]|0,n);w=H+124|0;E=c[w>>2]|0;if((E|0)<=0){break}p=e+32|0;r=n;B=G;b=1;C=c[x>>2]|0;D=E;while(1){E=c[F>>2]|0;if((C|0)>0){L=E&65280;K=E&255;J=r;I=E&16711680;E=0;while(1){X=J+1|0;O=a[J]|0;P=O&15;N=(O&255)>>>4&255;if((N|0)==0){O=c[k+((P&255)<<2)>>2]|0;Y=O&16711680;Z=O&255;_=O&65280}else if((N|0)==3){Y=I;Z=K;_=(P&255)*4352|0}else if((N|0)==2){Y=ca(P&255,1114112)|0;Z=K;_=L}else if((N|0)==1){Y=I;Z=(P&255)*17|0;_=L}else{Y=I;Z=K;_=L}P=Z|_|Y;N=E*3|0;a[B+N|0]=P;a[B+(N+1)|0]=P>>>8;a[B+(N+2)|0]=P>>>16;P=E+1|0;$=c[x>>2]|0;if((P|0)<($|0)){L=_;K=Z;J=X;I=Y;E=P}else{break}}aa=X;ba=$;da=c[w>>2]|0}else{aa=r;ba=C;da=D}if((b|0)>=(da|0)){break a}r=aa;B=B+(c[p>>2]|0)|0;b=b+1|0;C=ba;D=da}}}else{D=c[e+4>>2]|0;C=D;mrc(D|0,0,1024)|0;if((c[z>>2]|0)>1){D=0;do{b=(c[A>>2]|0)+(D<<1)|0;p=(he((d[b]|d[b+1|0]<<8)<<16>>16|0)|0)&65535;b=C+(D<<2)|0;y=(p&15)*17|0|((p>>>4&15)*4352|0)|(ca(p>>>8&15,1114112)|0)|-16777216;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;D=D+1|0;}while((D|0)<((c[z>>2]|0)/2|0|0))}I3(m,c[e+32>>2]|0,c[e>>2]|0)}}while(0);c[f>>2]=1;q=o;i=h;return q|0}function H3(a){a=a|0;mJb((c[a+60>>2]|0)+32|0);return 0}function I3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=b|0;mrc(f|0,0,ca(c[(c[g>>2]|0)+124>>2]|0,e)|0)|0;h=c[b+8>>2]|0;if((h|0)==128){i=c[b+24>>2]|0;j=c[b+28>>2]<<3>>>0>2147483639>>>0|(i|0)==0?0:i;i=c[g>>2]|0;if((c[i+124>>2]|0)<=0){return}k=b+4|0;l=b+12|0;m=0;n=0;o=c[k>>2]|0;p=i;while(1){if((o|0)>0){i=ca(n,e)|0;q=m;r=0;s=p;t=o;while(1){if((c[s+120>>2]|0)>0){u=q;v=0;while(1){w=u+1|0;x=f+(v+i)|0;a[x]=((d[j+(u>>>3)|0]|0)<<(u&7)>>>7&1)<<r|(d[x]|0);x=v+1|0;y=c[g>>2]|0;if((x|0)<(c[y+120>>2]|0)){u=w;v=x}else{break}}z=w;A=y;B=c[k>>2]|0}else{z=q;A=s;B=t}v=(c[l>>2]|0)+z|0;u=r+1|0;if((u|0)<(B|0)){q=v;r=u;s=A;t=B}else{C=v;D=B;E=A;break}}}else{C=m;D=o;E=p}t=n+1|0;if((t|0)<(c[E+124>>2]|0)){m=C;n=t;o=D;p=E}else{break}}return}else if((h|0)==0){h=c[b+24>>2]|0;E=c[b+28>>2]<<3>>>0>2147483639>>>0|(h|0)==0?0:h;h=b+4|0;p=c[h>>2]|0;if((p|0)<=0){return}D=b+12|0;b=0;o=0;n=c[g>>2]|0;C=p;while(1){if((c[n+124>>2]|0)>0){p=b;m=0;A=n;while(1){if((c[A+120>>2]|0)>0){B=ca(m,e)|0;z=p;l=0;while(1){k=z+1|0;y=f+(l+B)|0;a[y]=((d[E+(z>>>3)|0]|0)<<(z&7)>>>7&1)<<o|(d[y]|0);y=l+1|0;w=c[g>>2]|0;if((y|0)<(c[w+120>>2]|0)){z=k;l=y}else{F=k;G=w;break}}}else{F=p;G=A}H=(c[D>>2]|0)+F|0;l=m+1|0;if((l|0)<(c[G+124>>2]|0)){p=H;m=l;A=G}else{break}}I=H;J=G;K=c[h>>2]|0}else{I=b;J=n;K=C}A=o+1|0;if((A|0)<(K|0)){b=I;o=A;n=J;C=K}else{break}}return}else{return}}function J3(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;mrc(a|0,0,f<<1|0)|0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;i=b[h>>1]|0;if(!(i<<16>>16==0)){a:do{if((g|0)>0){j=f-g|0;k=0;l=i;while(1){m=(ca(b[d+(j+k<<1)>>1]|0,l<<16>>16)|0)>>>15;n=a+(k<<1)|0;b[n>>1]=m+(e[n>>1]|0);n=k+1|0;if((n|0)>=(g|0)){o=g;break a}k=n;l=b[h>>1]|0}}else{o=g}}while(0);do{i=(ca(b[d+(o-g<<1)>>1]|0,b[h>>1]|0)|0)>>>15;l=a+(o<<1)|0;b[l>>1]=i+(e[l>>1]|0);o=o+1|0;}while((o|0)<(f|0))}g=g+1|0;}while((g|0)<(f|0));return}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=f|0;var h=0,i=0,j=0,k=0,l=0;if((d|0)>0){h=f-d|0;i=0;while(1){g[a+(i<<2)>>2]=+g[b+(i<<2)>>2]+ +g[c+(h+i<<2)>>2]*e;j=i+1|0;if((j|0)<(d|0)){i=j}else{k=d;break}}}else{k=0}if((k|0)<(f|0)){l=k}else{return}do{g[a+(l<<2)>>2]=+g[b+(l<<2)>>2]+ +g[c+(l-d<<2)>>2]*e;l=l+1|0;}while((l|0)<(f|0));return}function L3(a,c,d,e,f,g,h,i){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((e|0)<=0){j=0;return j|0}k=-i|0;l=(g|0)==0;if((f|0)<1){g=0;while(1){m=(b[d+(g<<1)>>1]|0)+(i>>12)>>h;if((m+32768|0)>>>0>65535>>>0){n=(m>>31^32767)&65535}else{n=m&65535}if(!l){if((n<<16>>16|0)!=(m|0)){j=1;o=20;break}}b[a+(g<<1)>>1]=n;m=g+1|0;if((m|0)<(e|0)){g=m}else{j=0;o=20;break}}if((o|0)==20){return j|0}}if(l){l=0;while(1){g=1;n=k;do{n=(ca(b[a+(l-g<<1)>>1]|0,b[c+(g-1<<1)>>1]|0)|0)+n|0;g=g+1|0;}while((g|0)<=(f|0));g=(b[d+(l<<1)>>1]|0)+(-n>>12)>>h;if((g+32768|0)>>>0>65535>>>0){p=(g>>31^32767)&65535}else{p=g&65535}b[a+(l<<1)>>1]=p;g=l+1|0;if((g|0)<(e|0)){l=g}else{j=0;break}}return j|0}else{q=0}while(1){l=1;p=k;do{p=(ca(b[a+(q-l<<1)>>1]|0,b[c+(l-1<<1)>>1]|0)|0)+p|0;l=l+1|0;}while((l|0)<=(f|0));l=(b[d+(q<<1)>>1]|0)+(-p>>12)>>h;if((l+32768|0)>>>0>65535>>>0){r=(l>>31^32767)&65535}else{r=l&65535}if((r<<16>>16|0)!=(l|0)){j=1;o=20;break}b[a+(q<<1)>>1]=r;l=q+1|0;if((l|0)<(e|0)){q=l}else{j=0;o=20;break}}if((o|0)==20){return j|0}return 0}function M3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,h=0,i=0.0,j=0,k=0.0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0,U=0.0,V=0.0,W=0.0,X=0,Y=0.0,Z=0.0,_=0.0,$=0.0;f=+g[b>>2];h=b+4|0;i=+g[h>>2];j=b+8|0;k=+g[j>>2];l=i-f*f;m=k-f*i-f*l;n=d-4|0;a:do{if((n|0)<0){o=0;p=c;q=a}else{r=b+12|0;s=(e|0)>5;t=+g[a-16>>2];u=+g[a-12>>2];v=+g[a-8>>2];w=+g[a-4>>2];x=4;y=c;z=a;A=k;B=i;C=f;while(1){D=+g[r>>2];E=+g[y>>2]-u*A-v*B-w*C-t*D;F=+g[y+4>>2]-v*A-w*B-u*D;G=+g[y+8>>2]-w*A-v*D;H=+g[y+12>>2]-w*D;if(s){D=F;I=G;J=H;K=t;L=u;M=v;N=E;O=5;while(1){P=+g[z+(-O<<2)>>2];Q=+g[b+(O-1<<2)>>2];R=+g[z+(~O<<2)>>2];S=+g[b+(O<<2)>>2];T=N-P*Q-R*S;U=D-K*Q-P*S;V=I-L*Q-K*S;W=J-M*Q-L*S;X=O+2|0;if((X|0)<(e|0)){D=U;I=V;J=W;M=K;K=R;L=P;N=T;O=X}else{Y=U;Z=V;_=W;$=T;break}}}else{Y=F;Z=G;_=H;$=E}N=Y-f*$;L=Z-f*Y-l*$;K=_-f*Z-l*Y-m*$;g[z>>2]=$;g[z+4>>2]=N;g[z+8>>2]=L;g[z+12>>2]=K;O=z+16|0;X=y+16|0;if((x|0)>(n|0)){o=x;p=X;q=O;break a}t=$;u=N;v=L;w=K;x=x+4|0;y=X;z=O;A=+g[j>>2];B=+g[h>>2];C=+g[b>>2]}}}while(0);if((o|0)>=(d|0)){return}h=(e|0)<1;j=o;do{n=j-o|0;$=+g[p+(n<<2)>>2];a=q+(n<<2)|0;g[a>>2]=$;if(!h){c=1;m=$;do{m=m- +g[b+(c-1<<2)>>2]*+g[q+(n-c<<2)>>2];g[a>>2]=m;c=c+1|0;}while((c|0)<=(e|0))}j=j+1|0;}while((j|0)<(d|0));return}function N3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0.0,j=0,k=0,l=0.0;if((d|0)<=0){return}f=(e|0)<1;h=0;do{i=+g[c+(h<<2)>>2];j=a+(h<<2)|0;g[j>>2]=i;if(!f){k=1;l=i;do{l=l+ +g[b+(k-1<<2)>>2]*+g[c+(h-k<<2)>>2];g[j>>2]=l;k=k+1|0;}while((k|0)<=(e|0))}h=h+1|0;}while((h|0)<(d|0));return}function O3(a){a=a|0;c[a>>2]=524;c[a+4>>2]=62;return}function P3(a){a=a|0;var b=0,c=0,f=0,g=0,h=0;b=a>>>0>65535>>>0;c=b?a>>>16:a;f=b?16:0;if((c&65280|0)==0){g=f;h=c}else{g=f|8;h=c>>>8}c=(d[1359664+h|0]|0)+g&255;g=a<<31-c;a=g>>>26&31;h=e[335840+(a<<1)>>1]|0;return(c<<15)+h+((ca(g>>>11&32767,(e[335840+(a+1<<1)>>1]|0)-h|0)|0)>>15)|0}function Q3(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)>0){e=0;f=0;g=0}else{h=0;i=0;return(G=h,i)|0}while(1){j=ca(b[c+(e<<1)>>1]|0,b[a+(e<<1)>>1]|0)|0;k=wrc(j,(j|0)<0|0?-1:0,g,f)|0;j=G;l=e+1|0;if((l|0)<(d|0)){e=l;f=j;g=k}else{h=j;i=k;break}}return(G=h,i)|0}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0.0,e=0,f=0.0,h=0.0,i=0;if((c|0)>0){d=0.0;e=0}else{f=0.0;return+f}while(1){h=d+ +g[a+(e<<2)>>2]*+g[b+(e<<2)>>2];i=e+1|0;if((i|0)<(c|0)){d=h;e=i}else{f=h;break}}return+f}function S3(a){a=a|0;c[a>>2]=2;return}function T3(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((e|0)<=0){return}i=ca(f,e)|0;f=b;b=0;while(1){j=d+(b+i)|0;a[f]=(a[j]|0)<0?g:h;a[f+1|0]=(a[j]&64)!=0?g:h;a[f+2|0]=(a[j]&32)!=0?g:h;a[f+3|0]=(a[j]&16)!=0?g:h;a[f+4|0]=(a[j]&8)!=0?g:h;a[f+5|0]=(a[j]&4)!=0?g:h;a[f+6|0]=(a[j]&2)!=0?g:h;a[f+7|0]=(a[j]&1)!=0?g:h;j=b+1|0;if((j|0)<(e|0)){f=f+c|0;b=j}else{break}}return}function U3(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+16>>2]=(c[a+120>>2]|0)+3&-4;c[b+20>>2]=(c[a+124>>2]|0)+3&-4;c[b+196956>>2]=-1;d=b+24|0;if((c[a+792>>2]|0)==8){c[d>>2]=1;c[a+140>>2]=11;e=UHb()|0;f=b+4|0;g=f;c[g>>2]=e;h=(e|0)==0;i=h?-12:0;return i|0}else{c[d>>2]=0;c[a+140>>2]=2;e=UHb()|0;f=b+4|0;g=f;c[g>>2]=e;h=(e|0)==0;i=h?-12:0;return i|0}return 0}function V3(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0;k=i;l=c[j+28>>2]|0;m=c[f+60>>2]|0;n=m;o=m+8|0;c[o>>2]=c[j+24>>2];p=m+12|0;c[p>>2]=l;q=m+4|0;r=N4a(f,c[q>>2]|0)|0;if((r|0)<0){s=r;i=k;return s|0}r=m+24|0;do{if((c[r>>2]|0)!=0){t=V1(j,0,0)|0;if((t|0)==0){break}c[(c[q>>2]|0)+304>>2]=1;nrc(m+196960|0,t|0,1024)|0}}while(0);j=c[o>>2]|0;t=c[p>>2]|0;p=j+t|0;a:do{if((t|0)<10){u=82}else{v=a[j]|0;w=j+8|0;x=(he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535;w=d[j+2|0]<<8|d[j+1|0]<<16|d[j+3|0];y=m+196956|0;z=c[y>>2]|0;b:do{if((z|0)==-1){if((w|0)==0){QIb(c[m>>2]|0,2366896,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;u=82;break a}do{if((w|0)!=(t|0)){if(((t|0)%(w|0)|0|0)==0){break}do{if((t|0)>15){if(!((a[j+10|0]|0)==-2)){break}if((a[j+11|0]|0)!=0){break}if((a[j+12|0]|0)!=0){break}if((a[j+13|0]|0)!=6){break}if((a[j+14|0]|0)!=0){break}if((a[j+15|0]|0)!=0){break}c[y>>2]=6;B=16;break b}}while(0);c[y>>2]=2;B=12;break b}}while(0);c[y>>2]=0;B=10}else{B=z+10|0}}while(0);z=j+B|0;c[o>>2]=z;y=x>>>0>32>>>0?32:x;c[(c[q>>2]|0)+84>>2]=0;if((y|0)==0){break}w=p;C=m+16|0;D=m+20|0;E=m;F=(v&1)!=0;G=0;H=0;I=z;while(1){if((I+12|0)>>>0>p>>>0){u=82;break a}z=a[I]|0;b[n+28+(G*6154|0)>>1]=z&255;J=(c[o>>2]|0)+4|0;K=(d[J]|d[J+1|0]<<8)<<16>>16;J=n+28+(G*6154|0)+4|0;b[J>>1]=he(K|0)|0;if(K<<16>>16==0){b[J>>1]=H;K=(c[o>>2]|0)+8|0;b[n+28+(G*6154|0)+8>>1]=(he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)+H}else{K=(c[o>>2]|0)+8|0;b[n+28+(G*6154|0)+8>>1]=he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0}K=(c[o>>2]|0)+6|0;L=n+28+(G*6154|0)+2|0;b[L>>1]=he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;K=(c[o>>2]|0)+10|0;M=n+28+(G*6154|0)+6|0;b[M>>1]=he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0;if(z<<24>>24==16){c[(c[q>>2]|0)+84>>2]=1}z=c[o>>2]|0;K=d[z+2|0]<<8|d[z+1|0]<<16|d[z+3|0];N=K-12|0;if((N|0)<0){u=82;break a}O=z+12|0;c[o>>2]=O;if((z+K|0)>>>0>p>>>0){P=w-O|0}else{P=N}if((G|0)<1|F){Q=O}else{O=G-1|0;nrc(n+28+(G*6154|0)+10|0,n+28+(O*6154|0)+10|0,3072)|0;nrc(n+28+(G*6154|0)+3082|0,n+28+(O*6154|0)+3082|0,3072)|0;Q=c[o>>2]|0}O=Q+P|0;N=b[M>>1]|0;if((N&65535|0)>(c[C>>2]|0)){u=82;break a}K=n+28+(G*6154|0)+8|0;z=b[K>>1]|0;if((z&65535|0)>(c[D>>2]|0)){u=82;break a}if(!((e[L>>1]|0)>>>0<(N&65535)>>>0)){u=82;break a}if((e[J>>1]|0)>>>0>=(z&65535)>>>0|(P|0)<4){u=82;break a}z=O;N=n+28+(G*6154|0)+10|0;R=n+28+(G*6154|0)+3082|0;S=Q;T=Q+4|0;c:while(1){U=d[S]|0;V=d[S+2|0]<<8|d[S+1|0]<<16|d[S+3|0];W=V-4|0;if((W|0)<0){u=82;break a}if((S+V|0)>>>0>O>>>0){X=z-T|0}else{X=W}switch(U|0){case 48:case 49:case 50:{break c;break};case 32:case 33:case 36:case 37:{X3(N,U,X,T);break};case 34:case 35:case 38:case 39:{X3(R,U,X,T);break};default:{}}W=S+(X+8)|0;if(W>>>0>O>>>0){u=82;break a}else{S=S+(X+4)|0;T=W}}O=S+(X+4)|0;R=b[J>>1]|0;N=b[K>>1]|0;if((R&65535)>>>0<(N&65535)>>>0){z=(U&1|0)==0;W=(U&2|0)==0;V=0;Y=0;Z=T;_=R&65535;R=c[r>>2]|0;$=N;while(1){N=c[q>>2]|0;aa=c[N>>2]|0;ba=b[L>>1]|0;da=ba&65535;if((R|0)==0){ea=da*3|0}else{ea=da}fa=c[N+32>>2]|0;N=(ca(fa,_)|0)+ea|0;ga=aa+N|0;ha=(c[(c[E>>2]|0)+124>>2]|0)-_|0;do{if(ha>>>0>1>>>0){ia=N+fa|0;ja=aa+ia|0;if(!(ha>>>0>2>>>0)){ka=ga;la=ga;ma=ja;break}na=ia+fa|0;ia=aa+na|0;if(!(ha>>>0>3>>>0)){ka=ga;la=ia;ma=ja;break}ka=aa+(na+fa)|0;la=ia;ma=ja}else{ka=ga;la=ga;ma=ga}}while(0);if((ba&65535)>>>0<(e[M>>1]|0)>>>0){fa=V;aa=Y;ha=Z;N=da;ja=ga;ia=ma;na=la;oa=ka;pa=R;while(1){if(z){qa=fa;ra=aa;sa=ha;u=60}else{ta=fa>>>1;if((ta|0)==0){ua=ha+4|0;if(ua>>>0>O>>>0){u=82;break a}va=ha;wa=-2147483648;xa=je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0;ya=ua}else{wa=ta;xa=aa;ya=ha}if((wa&xa|0)==0){za=ya;Aa=xa;Ba=wa}else{qa=wa;ra=xa;sa=ya;u=60}}d:do{if((u|0)==60){u=0;do{if(W){ta=qa>>>1;if((ta|0)==0){ua=sa+4|0;if(ua>>>0>O>>>0){u=82;break a}va=sa;Ca=-2147483648;Da=je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0;Ea=ua}else{Ca=ta;Da=ra;Ea=sa}if((Ca&~Da|0)!=0){Fa=Ca;Ga=Da;Ha=Ea;break}if((Ca&Da|0)==0){za=Ea;Aa=Da;Ba=Ca;break d}ta=Ea+4|0;if(ta>>>0>O>>>0){u=82;break a}ua=d[Ea]|0;va=n+28+(G*6154|0)+10+(ua*12|0)|0;Ia=d[Ea+1|0]|0;Ja=n+28+(G*6154|0)+10+(Ia*12|0)|0;Ka=d[Ea+2|0]|0;La=n+28+(G*6154|0)+10+(Ka*12|0)|0;Ma=d[Ea+3|0]|0;Na=n+28+(G*6154|0)+10+(Ma*12|0)|0;Oa=n+28+(G*6154|0)+10+(Ka*12|0)+6|0;if((pa|0)==0){a[oa]=a[Oa]|0;a[oa+1|0]=a[Oa+1|0]|0;a[oa+2|0]=a[Oa+2|0]|0;a[oa+3|0]=a[Oa+3|0]|0;a[oa+4|0]=a[Oa+4|0]|0;a[oa+5|0]=a[Oa+5|0]|0;Pa=oa+6|0;Qa=n+28+(G*6154|0)+10+(Ma*12|0)+6|0;a[Pa]=a[Qa]|0;a[Pa+1|0]=a[Qa+1|0]|0;a[Pa+2|0]=a[Qa+2|0]|0;a[Pa+3|0]=a[Qa+3|0]|0;a[Pa+4|0]=a[Qa+4|0]|0;a[Pa+5|0]=a[Qa+5|0]|0;a[na]=a[La]|0;a[na+1|0]=a[La+1|0]|0;a[na+2|0]=a[La+2|0]|0;a[na+3|0]=a[La+3|0]|0;a[na+4|0]=a[La+4|0]|0;a[na+5|0]=a[La+5|0]|0;Qa=na+6|0;a[Qa]=a[Na]|0;a[Qa+1|0]=a[Na+1|0]|0;a[Qa+2|0]=a[Na+2|0]|0;a[Qa+3|0]=a[Na+3|0]|0;a[Qa+4|0]=a[Na+4|0]|0;a[Qa+5|0]=a[Na+5|0]|0;Qa=n+28+(G*6154|0)+10+(ua*12|0)+6|0;a[ia]=a[Qa]|0;a[ia+1|0]=a[Qa+1|0]|0;a[ia+2|0]=a[Qa+2|0]|0;a[ia+3|0]=a[Qa+3|0]|0;a[ia+4|0]=a[Qa+4|0]|0;a[ia+5|0]=a[Qa+5|0]|0;Qa=ia+6|0;Pa=n+28+(G*6154|0)+10+(Ia*12|0)+6|0;a[Qa]=a[Pa]|0;a[Qa+1|0]=a[Pa+1|0]|0;a[Qa+2|0]=a[Pa+2|0]|0;a[Qa+3|0]=a[Pa+3|0]|0;a[Qa+4|0]=a[Pa+4|0]|0;a[Qa+5|0]=a[Pa+5|0]|0;a[ja]=a[va]|0;a[ja+1|0]=a[va+1|0]|0;a[ja+2|0]=a[va+2|0]|0;a[ja+3|0]=a[va+3|0]|0;a[ja+4|0]=a[va+4|0]|0;a[ja+5|0]=a[va+5|0]|0;Pa=ja+6|0;a[Pa]=a[Ja]|0;a[Pa+1|0]=a[Ja+1|0]|0;a[Pa+2|0]=a[Ja+2|0]|0;a[Pa+3|0]=a[Ja+3|0]|0;a[Pa+4|0]=a[Ja+4|0]|0;a[Pa+5|0]=a[Ja+5|0]|0;za=ta;Aa=Da;Ba=Ca;break d}else{a[oa]=a[Oa]|0;a[oa+1|0]=a[n+28+(G*6154|0)+10+(Ka*12|0)+9|0]|0;a[oa+2|0]=a[n+28+(G*6154|0)+10+(Ma*12|0)+6|0]|0;a[oa+3|0]=a[n+28+(G*6154|0)+10+(Ma*12|0)+9|0]|0;a[na]=a[La]|0;a[na+1|0]=a[n+28+(G*6154|0)+10+(Ka*12|0)+3|0]|0;a[na+2|0]=a[Na]|0;a[na+3|0]=a[n+28+(G*6154|0)+10+(Ma*12|0)+3|0]|0;a[ia]=a[n+28+(G*6154|0)+10+(ua*12|0)+6|0]|0;a[ia+1|0]=a[n+28+(G*6154|0)+10+(ua*12|0)+9|0]|0;a[ia+2|0]=a[n+28+(G*6154|0)+10+(Ia*12|0)+6|0]|0;a[ia+3|0]=a[n+28+(G*6154|0)+10+(Ia*12|0)+9|0]|0;a[ja]=a[va]|0;a[ja+1|0]=a[n+28+(G*6154|0)+10+(ua*12|0)+3|0]|0;a[ja+2|0]=a[Ja]|0;a[ja+3|0]=a[n+28+(G*6154|0)+10+(Ia*12|0)+3|0]|0;za=ta;Aa=Da;Ba=Ca;break d}}else{Fa=qa;Ga=ra;Ha=sa}}while(0);if(!(Ha>>>0<O>>>0)){u=82;break a}ta=Ha+1|0;Ia=d[Ha]|0;Ja=n+28+(G*6154|0)+3082+(Ia*12|0)+6|0;if((pa|0)==0){a[oa]=a[Ja]|0;a[oa+1|0]=a[Ja+1|0]|0;a[oa+2|0]=a[Ja+2|0]|0;ua=oa+3|0;a[ua]=a[Ja]|0;a[ua+1|0]=a[Ja+1|0]|0;a[ua+2|0]=a[Ja+2|0]|0;a[na]=a[Ja]|0;a[na+1|0]=a[Ja+1|0]|0;a[na+2|0]=a[Ja+2|0]|0;ua=na+3|0;a[ua]=a[Ja]|0;a[ua+1|0]=a[Ja+1|0]|0;a[ua+2|0]=a[Ja+2|0]|0;ua=n+28+(G*6154|0)+3082+(Ia*12|0)+9|0;va=oa+6|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=oa+9|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=na+6|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=na+9|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;ua=n+28+(G*6154|0)+3082+(Ia*12|0)|0;a[ia]=a[ua]|0;a[ia+1|0]=a[ua+1|0]|0;a[ia+2|0]=a[ua+2|0]|0;va=ia+3|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;a[ja]=a[ua]|0;a[ja+1|0]=a[ua+1|0]|0;a[ja+2|0]=a[ua+2|0]|0;va=ja+3|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;ua=n+28+(G*6154|0)+3082+(Ia*12|0)+3|0;va=ia+6|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=ia+9|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=ja+6|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;va=ja+9|0;a[va]=a[ua]|0;a[va+1|0]=a[ua+1|0]|0;a[va+2|0]=a[ua+2|0]|0;za=ta;Aa=Ga;Ba=Fa;break}else{ua=a[Ja]|0;a[na+1|0]=ua;a[na]=ua;a[oa+1|0]=ua;a[oa]=ua;ua=a[n+28+(G*6154|0)+3082+(Ia*12|0)+9|0]|0;a[na+3|0]=ua;a[na+2|0]=ua;a[oa+3|0]=ua;a[oa+2|0]=ua;ua=a[n+28+(G*6154|0)+3082+(Ia*12|0)|0]|0;a[ja+1|0]=ua;a[ja]=ua;a[ia+1|0]=ua;a[ia]=ua;ua=a[n+28+(G*6154|0)+3082+(Ia*12|0)+3|0]|0;a[ja+3|0]=ua;a[ja+2|0]=ua;a[ia+3|0]=ua;a[ia+2|0]=ua;za=ta;Aa=Ga;Ba=Fa;break}}}while(0);Ra=c[r>>2]|0;if((Ra|0)==0){Sa=oa+12|0;Ta=na+12|0;Ua=ia+12|0;Va=ja+12|0}else{Sa=oa+4|0;Ta=na+4|0;Ua=ia+4|0;Va=ja+4|0}ta=N+4|0;if(ta>>>0<(e[M>>1]|0)>>>0){fa=Ba;aa=Aa;ha=za;N=ta;ja=Va;ia=Ua;na=Ta;oa=Sa;pa=Ra}else{break}}Wa=Ba;Xa=Aa;Ya=za;Za=Ra;_a=b[K>>1]|0}else{Wa=V;Xa=Y;Ya=Z;Za=R;_a=$}pa=_+4|0;if(pa>>>0<(_a&65535)>>>0){V=Wa;Y=Xa;Z=Ya;_=pa;R=Za;$=_a}else{break}}}$=(c[o>>2]|0)+P|0;c[o>>2]=$;R=G+1|0;if((R|0)<(y|0)){G=R;H=b[K>>1]|0;I=$}else{break}}}}while(0);if((u|0)==82){KIb(f,16,2456560,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A}if((c[r>>2]|0)!=0){nrc(c[(c[q>>2]|0)+4>>2]|0,m+196960|0,1024)|0}m=YHb(g,c[q>>2]|0)|0;if((m|0)<0){s=m;i=k;return s|0}c[h>>2]=1;s=l;i=k;return s|0}function W3(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function X3(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;g=f+e|0;e=c>>>1&2;h=e^6;i=b|0;b=(e|0)==0;if((c&1|0)==0){c=i;e=0;j=f;while(1){if((j+h|0)>>>0>g>>>0){k=27;break}l=c+12|0;m=a[j]|0;mrc(c|0,m|0,3)|0;n=a[j+1|0]|0;mrc(c+3|0,n|0,3)|0;o=a[j+2|0]|0;mrc(c+6|0,o|0,3)|0;p=a[j+3|0]|0;mrc(c+9|0,p|0,3)|0;q=j+4|0;if(b){r=a[q]|0;s=a[j+5|0]|0;t=s<<1;u=(r|0)/2|0;v=r<<1;r=m&255;m=r+t|0;w=r-u-s|0;x=r+v|0;if(m>>>0>255>>>0){y=-m>>31&255}else{y=m&255}a[c]=y;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[c+1|0]=z;if(x>>>0>255>>>0){A=-x>>31&255}else{A=x&255}a[c+2|0]=A;x=n&255;n=x+t|0;w=x-u-s|0;m=x+v|0;if(n>>>0>255>>>0){B=-n>>31&255}else{B=n&255}a[c+3|0]=B;if(w>>>0>255>>>0){C=-w>>31&255}else{C=w&255}a[c+4|0]=C;if(m>>>0>255>>>0){D=-m>>31&255}else{D=m&255}a[c+5|0]=D;m=o&255;o=m+t|0;w=m-u-s|0;n=m+v|0;if(o>>>0>255>>>0){E=-o>>31&255}else{E=o&255}a[c+6|0]=E;if(w>>>0>255>>>0){F=-w>>31&255}else{F=w&255}a[c+7|0]=F;if(n>>>0>255>>>0){G=-n>>31&255}else{G=n&255}a[c+8|0]=G;n=p&255;p=n+t|0;t=n-u-s|0;s=n+v|0;if(p>>>0>255>>>0){H=-p>>31&255}else{H=p&255}a[c+9|0]=H;if(t>>>0>255>>>0){I=-t>>31&255}else{I=t&255}a[c+10|0]=I;if(s>>>0>255>>>0){J=-s>>31&255}else{J=s&255}a[c+11|0]=J;K=j+6|0}else{K=q}q=e+1|0;if((q|0)<256){c=l;e=q;j=K}else{k=27;break}}if((k|0)==27){return}}else{L=i;M=0;N=0;O=0;P=f}a:while(1){f=N>>>1;if((f|0)==0){i=P+4|0;if(i>>>0>g>>>0){k=27;break}K=P;Q=-2147483648;R=je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0;S=i}else{Q=f;R=O;S=P}do{if((Q&R|0)==0){T=S;U=L+12|0}else{if((S+h|0)>>>0>g>>>0){k=27;break a}f=L+12|0;i=a[S]|0;mrc(L|0,i|0,3)|0;K=a[S+1|0]|0;mrc(L+3|0,K|0,3)|0;j=a[S+2|0]|0;mrc(L+6|0,j|0,3)|0;e=a[S+3|0]|0;mrc(L+9|0,e|0,3)|0;c=S+4|0;if(!b){T=c;U=f;break}J=a[c]|0;c=a[S+5|0]|0;I=c<<1;H=(J|0)/2|0;G=J<<1;J=i&255;i=J+I|0;F=J-H-c|0;E=J+G|0;if(i>>>0>255>>>0){V=-i>>31&255}else{V=i&255}a[L]=V;if(F>>>0>255>>>0){W=-F>>31&255}else{W=F&255}a[L+1|0]=W;if(E>>>0>255>>>0){X=-E>>31&255}else{X=E&255}a[L+2|0]=X;E=K&255;K=E+I|0;F=E-H-c|0;i=E+G|0;if(K>>>0>255>>>0){Y=-K>>31&255}else{Y=K&255}a[L+3|0]=Y;if(F>>>0>255>>>0){Z=-F>>31&255}else{Z=F&255}a[L+4|0]=Z;if(i>>>0>255>>>0){_=-i>>31&255}else{_=i&255}a[L+5|0]=_;i=j&255;j=i+I|0;F=i-H-c|0;K=i+G|0;if(j>>>0>255>>>0){$=-j>>31&255}else{$=j&255}a[L+6|0]=$;if(F>>>0>255>>>0){aa=-F>>31&255}else{aa=F&255}a[L+7|0]=aa;if(K>>>0>255>>>0){ba=-K>>31&255}else{ba=K&255}a[L+8|0]=ba;K=e&255;e=K+I|0;I=K-H-c|0;c=K+G|0;if(e>>>0>255>>>0){ca=-e>>31&255}else{ca=e&255}a[L+9|0]=ca;if(I>>>0>255>>>0){da=-I>>31&255}else{da=I&255}a[L+10|0]=da;if(c>>>0>255>>>0){ea=-c>>31&255}else{ea=c&255}a[L+11|0]=ea;T=S+6|0;U=f}}while(0);f=M+1|0;if((f|0)<256){L=U;M=f;N=Q;O=R;P=T}else{k=27;break}}if((k|0)==27){return}}function Y3(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;d=c[a+60>>2]|0;e=a+120|0;f=c[e>>2]|0;g=a+124|0;h=c[g>>2]|0;do{if((f&3|0)==0){if((h&3|0)!=0){break}j=d+372|0;k=c[j>>2]|0;l=d+376|0;m=c[l>>2]|0;if((k|0)>(m|0)){KIb(a,16,2175136,(n=i,i=i+16|0,c[n>>2]=k,c[n+8>>2]=m,n)|0);i=n;o=-22;i=b;return o|0}m=UHb()|0;k=d+32|0;c[k>>2]=m;if((m|0)==0){o=-12;i=b;return o|0}m=UHb()|0;p=d+36|0;c[p>>2]=m;a:do{if((m|0)==0){q=d+40|0}else{r=UHb()|0;s=d+40|0;c[s>>2]=r;if((r|0)==0){q=s;break}r=a+140|0;t=c[r>>2]|0;if((t|0)==2){u=UHb()|0;c[d+44>>2]=u;if((u|0)==0){q=s;break}v=c[r>>2]|0}else{v=t}t=hJb((ca(ca(c[g>>2]|0,c[e>>2]|0)|0,(v|0)==2?24:16)|0)>>>2)|0;c[d+344>>2]=t;if((t|0)==0){q=s;break}t=hJb((ca(c[g>>2]|0,c[e>>2]|0)|0)&1073741823)|0;c[d+348>>2]=t;if((t|0)==0){q=s;break}t=d+8|0;u=t;w=0;while(1){x=(c[r>>2]|0)==2;if((w|0)>=((x?4:3)|0)){break}y=hJb((ca(ca(c[e>>2]|0,x?6:4)|0,c[g>>2]|0)|0)>>2)|0;c[u+(w<<2)>>2]=y;if((y|0)==0){q=s;break a}else{w=w+1|0}}w=(ca(c[g>>2]|0,c[e>>2]|0)|0)/16|0;u=(((w+15|0)/16|0)+w<<2)+3160|0;y=(ca(u,c[l>>2]|0)|0)+10|0;x=hJb(u)|0;c[d+24>>2]=x;if((x|0)==0){q=s;break}x=hJb(y)|0;c[d+28>>2]=x;if((x|0)==0){q=s;break}x=hJb(w*36|0)|0;c[d+352>>2]=x;if((x|0)==0){q=s;break}AIb(d+72|0,1);c[d+4>>2]=a;x=c[e>>2]|0;w=d+52|0;c[w>>2]=x;u=d+56|0;c[u>>2]=c[g>>2];c[d+60>>2]=y;c[d+64>>2]=0;c[d+68>>2]=c[a+360>>2];y=c[r>>2]|0;c[d+48>>2]=y;c[c[k>>2]>>2]=c[t>>2];c[(c[k>>2]|0)+32>>2]=x;c[c[p>>2]>>2]=c[d+12>>2];c[(c[p>>2]|0)+32>>2]=c[w>>2];c[c[s>>2]>>2]=c[d+16>>2];c[(c[s>>2]|0)+32>>2]=c[w>>2];if((y|0)==2){y=c[k>>2]|0;x=c[w>>2]|0;z=ca(c[u>>2]|0,x)|0;c[y+4>>2]=(c[y>>2]|0)+z;y=c[k>>2]|0;c[y+8>>2]=(c[y+4>>2]|0)+(z>>2);z=x>>1;x=c[k>>2]|0;c[x+40>>2]=z;c[x+36>>2]=z;z=c[p>>2]|0;x=c[w>>2]|0;y=ca(c[u>>2]|0,x)|0;c[z+4>>2]=(c[z>>2]|0)+y;z=c[p>>2]|0;c[z+8>>2]=(c[z+4>>2]|0)+(y>>2);y=x>>1;x=c[p>>2]|0;c[x+40>>2]=y;c[x+36>>2]=y;y=c[s>>2]|0;x=c[w>>2]|0;z=ca(c[u>>2]|0,x)|0;c[y+4>>2]=(c[y>>2]|0)+z;y=c[s>>2]|0;c[y+8>>2]=(c[y+4>>2]|0)+(z>>2);z=x>>1;x=c[s>>2]|0;c[x+40>>2]=z;c[x+36>>2]=z;z=d+44|0;c[c[z>>2]>>2]=c[d+20>>2];x=c[z>>2]|0;c[x+32>>2]=c[w>>2];y=c[w>>2]|0;w=ca(c[u>>2]|0,y)|0;c[x+4>>2]=(c[x>>2]|0)+w;x=c[z>>2]|0;c[x+8>>2]=(c[x+4>>2]|0)+(w>>2);w=y>>1;y=c[z>>2]|0;c[y+40>>2]=w;c[y+36>>2]=w}c[d+356>>2]=c[j>>2];c[d+360>>2]=c[l>>2];o=0;i=b;return o|0}}while(0);VHb(k);VHb(p);VHb(q);l=a+140|0;if((c[l>>2]|0)==2){VHb(d+44|0)}mJb(d+344|0);mJb(d+348|0);mJb(d+24|0);mJb(d+28|0);mJb(d+352|0);j=d+8|0;m=0;while(1){mJb(j+(m<<2)|0);w=m+1|0;if((w|0)<(((c[l>>2]|0)==2?4:3)|0)){m=w}else{o=-12;break}}i=b;return o|0}}while(0);KIb(a,16,2207512,(n=i,i=i+16|0,c[n>>2]=f,c[n+8>>2]=h,n)|0);i=n;o=-22;i=b;return o|0}function Z3(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0;h=i;i=i+12640|0;j=h|0;k=h+64|0;l=h+128|0;m=h+192|0;n=h+256|0;o=h+12560|0;p=h+12568|0;q=h+12576|0;r=c[b+60>>2]|0;s=r;t=c[f+168>>2]|0;if((t|0)==0){u=0;v=256}else{w=t-1|0;u=(w|0)<0|0?-1:0;v=w}w=r+336|0;c[w>>2]=v;c[w+4>>2]=u;u=c[r+60>>2]|0;v=d5a(b,e,u,(u|0)<0|0?-1:0)|0;if((v|0)<0){x=v;i=h;return x|0}v=r+64|0;u=(c[v>>2]|0)==0;t=c[e+24>>2]|0;z=r+48|0;A=r+56|0;do{if((c[z>>2]|0)==2){B=c[A>>2]|0;if((B|0)<=0){C=0;D=0;E=0;F=0;break}H=r+52|0;I=f|0;J=f+32|0;K=r+44|0;L=0;M=0;N=0;O=0;P=0;Q=c[H>>2]|0;R=B;while(1){if((Q|0)>0){B=P>>1;S=L;T=M;U=N;V=O;W=0;while(1){X=c[I>>2]|0;Y=c[J>>2]|0;Z=(ca(Y,P)|0)+(W*3|0)|0;_=Z+Y|0;Y=c[K>>2]|0;$=c[Y>>2]|0;aa=c[Y+32>>2]|0;ba=ca(aa,P)|0;if((c[z>>2]|0)==2){da=W>>1;ea=c[Y+36>>2]|0;fa=(c[Y+4>>2]|0)+((ca(ea,B)|0)+da)|0;ga=c[Y+40>>2]|0;ha=fa;ia=(c[Y+8>>2]|0)+((ca(ga,B)|0)+da)|0;ja=ea;ka=ga}else{ha=V;ia=U;ja=T;ka=S}ga=ba+W|0;ba=d[X+Z|0]|0;ea=d[X+(Z|1)|0]|0;da=d[X+(Z+2)|0]|0;a[$+ga|0]=((ca(ea,4793251)|0)+(ca(ba,2396625)|0)+(ca(da,1198732)|0)|0)>>>23;Y=d[X+(Z+3)|0]|0;fa=d[X+(Z+4)|0]|0;la=d[X+(Z+5)|0]|0;Z=ga|1;a[$+Z|0]=((ca(fa,4793251)|0)+(ca(Y,2396625)|0)+(ca(la,1198732)|0)|0)>>>23;ma=d[X+_|0]|0;na=d[X+(_+1)|0]|0;oa=d[X+(_+2)|0]|0;a[$+(ga+aa)|0]=((ca(na,4793251)|0)+(ca(ma,2396625)|0)+(ca(oa,1198732)|0)|0)>>>23;ga=d[X+(_+3)|0]|0;pa=d[X+(_+4)|0]|0;qa=d[X+(_+5)|0]|0;_=Y+ba+ma+ga|0;ma=la+da+oa+qa|0;a[$+(Z+aa)|0]=((ca(pa,4793251)|0)+(ca(ga,2396625)|0)+(ca(qa,1198732)|0)|0)>>>23;qa=(fa+ea+na+pa|0)*-599156|0;pa=qa+(_*-299683|0)+(ma*898839|0)>>23;if((pa|0)<-128){ra=0}else{ra=(pa|0)>127?-1:pa+128&255}a[ha]=ra;pa=qa+(_*748893|0)+(ma*-149737|0)>>23;if((pa|0)<-128){sa=0}else{sa=(pa|0)>127?-1:pa+128&255}a[ia]=sa;pa=W+2|0;ta=c[H>>2]|0;if((pa|0)<(ta|0)){S=ka;T=ja;U=ia;V=ha;W=pa}else{break}}ua=ka;va=ja;wa=ia;xa=ha;ya=ta;za=c[A>>2]|0}else{ua=L;va=M;wa=N;xa=O;ya=Q;za=R}W=P+2|0;if((W|0)<(za|0)){L=ua;M=va;N=wa;O=xa;P=W;Q=ya;R=za}else{C=xa;D=wa;E=va;F=ua;break}}}else{C=0;D=0;E=0;F=0}}while(0);ua=r+356|0;va=r+360|0;wa=r+28|0;xa=u&1^1;za=r+52|0;ya=r+40|0;ta=r+36|0;ha=r+4|0;ia=r+44|0;ja=q|0;ka=q+32|0;sa=q+4|0;ra=q+36|0;R=q+8|0;Q=q+40|0;P=r+32|0;O=n+12288|0;N=n+12292|0;M=n+12296|0;L=r+24|0;H=j|0;K=r+368|0;J=r+352|0;I=k|0;W=k+32|0;V=k+4|0;U=k+36|0;T=k+8|0;S=k+40|0;B=u?16:17;pa=r+364|0;ma=l|0;_=l+32|0;qa=l+4|0;na=l+36|0;ea=l+8|0;fa=l+40|0;ga=m|0;aa=m+32|0;Z=m+4|0;$=m+36|0;oa=m+8|0;da=m+40|0;la=f|0;ba=f+32|0;Y=c[ua>>2]|0;X=0;Aa=0;Ba=0;Ca=0;Da=0;Ea=0;Fa=C;C=D;D=E;E=F;F=0;Ga=0;Ha=0;Ia=0;a:while(1){if((Y|0)>(c[va>>2]|0)){Ja=X;Ka=Ca;La=149;break}Ma=c[A>>2]|0;if((Y|0)>((Ma|0)/4|0|0)){Ja=X;Ka=Ca;La=149;break}if((Ma|0)>0){Na=Ia;Oa=Ha;Pa=Ga;Qa=F;Ra=E;Sa=D;Ta=C;Ua=Fa;Va=Da;Wa=Ea;Xa=0;Ya=0;Za=0;_a=0;$a=1;ab=Ma;while(1){Ma=(ca($a,ab)|0)/(Y|0)|0;bb=Ma&3;if((bb|0)==0){cb=Ma}else{cb=Ma+4-bb|0}bb=cb-_a|0;if((bb|0)<1){KIb(c[ha>>2]|0,32,2456520,(Ma=i,i=i+16|0,c[Ma>>2]=$a,c[Ma+8>>2]=Y,Ma)|0);i=Ma;db=Ya;eb=Za;fb=Xa;gb=Va;hb=Wa;ib=Ua;jb=Ta;kb=Sa;lb=Ra;mb=Qa;nb=Pa;ob=Oa;pb=Na}else{Ma=c[z>>2]|0;if((Ma|0)==2){qb=c[ia>>2]|0;rb=c[qb+32>>2]|0;sb=(c[qb>>2]|0)+(ca(rb,_a)|0)|0;c[ja>>2]=sb;c[ka>>2]=rb;tb=_a>>1;ub=c[qb+36>>2]|0;c[sa>>2]=(c[qb+4>>2]|0)+(ca(ub,tb)|0);c[ra>>2]=ub;ub=c[qb+40>>2]|0;c[R>>2]=(c[qb+8>>2]|0)+(ca(ub,tb)|0);c[Q>>2]=ub;vb=2;wb=sb;xb=rb}else{rb=c[ba>>2]|0;sb=(c[la>>2]|0)+(ca(rb,_a)|0)|0;c[ja>>2]=sb;c[ka>>2]=rb;vb=Ma;wb=sb;xb=rb}rb=c[P>>2]|0;sb=c[rb>>2]|0;Ma=c[rb+32>>2]|0;ub=ca(Ma,_a)|0;if((vb|0)==2){tb=_a>>1;qb=c[rb+36>>2]|0;yb=(c[rb+4>>2]|0)+(ca(qb,tb)|0)|0;zb=c[rb+40>>2]|0;Ab=(c[rb+8>>2]|0)+(ca(zb,tb)|0)|0;rb=c[ya>>2]|0;Bb=c[rb+36>>2]|0;Cb=(c[rb+4>>2]|0)+(ca(Bb,tb)|0)|0;Db=c[rb+40>>2]|0;Eb=Cb;Fb=(c[rb+8>>2]|0)+(ca(Db,tb)|0)|0;Gb=Bb;Hb=Db;Ib=zb;Jb=qb;Kb=Ab;Lb=yb;Mb=rb}else{Eb=Ua;Fb=Ta;Gb=Sa;Hb=Ra;Ib=Na;Jb=Oa;Kb=Pa;Lb=Qa;Mb=c[ya>>2]|0}rb=c[Mb+32>>2]|0;yb=c[Mb>>2]|0;Ab=ca(rb,_a)|0;qb=(c[wa>>2]|0)+(Xa+10)|0;do{if(!u){if((bb|0)<=0){break}zb=c[sa>>2]|0;Db=c[ra>>2]|0;Bb=c[R>>2]|0;tb=c[Q>>2]|0;Cb=0;Nb=0;Ob=c[za>>2]|0;Pb=vb;Qb=wb;Rb=xb;while(1){if((Ob|0)>0){Sb=Cb>>1;Tb=ca(Cb+_a|0,Ma)|0;if((Pb|0)==2){Ub=ca(Sb,Jb)|0;Vb=ca(Sb,Ib)|0;Wb=c[J>>2]|0;Xb=ca(Cb,Rb)|0;Yb=ca(Db,Sb)|0;Zb=ca(tb,Sb)|0;Sb=0;_b=Nb;while(1){c[ma>>2]=sb+(Sb+Tb);c[_>>2]=Ma;$b=Sb>>1;c[qa>>2]=Lb+($b+Ub);c[na>>2]=Jb;c[ea>>2]=Kb+($b+Vb);c[fa>>2]=Ib;c[ga>>2]=Qb+(Sb+Xb);c[aa>>2]=Rb;c[Z>>2]=zb+($b+Yb);c[$>>2]=Db;c[oa>>2]=Bb+($b+Zb);c[da>>2]=tb;c[Wb+(_b*36|0)+28>>2]=d4(s,l,m)|0;$b=Sb+4|0;ac=_b+1|0;bc=c[za>>2]|0;if(($b|0)<(bc|0)){Sb=$b;_b=ac}else{cc=ac;dc=bc;ec=2;fc=Qb;gc=Rb;break}}}else{_b=c[J>>2]|0;Sb=ca(Cb,xb)|0;Wb=0;Zb=Nb;while(1){c[ma>>2]=sb+(Wb+Tb);c[_>>2]=Ma;c[ga>>2]=wb+(Wb+Sb);c[aa>>2]=xb;c[_b+(Zb*36|0)+28>>2]=d4(s,l,m)|0;Yb=Wb+4|0;Xb=Zb+1|0;Vb=c[za>>2]|0;if((Yb|0)<(Vb|0)){Wb=Yb;Zb=Xb}else{cc=Xb;dc=Vb;ec=Pb;fc=wb;gc=xb;break}}}}else{cc=Nb;dc=Ob;ec=Pb;fc=Qb;gc=Rb}Zb=Cb+4|0;if((Zb|0)<(bb|0)){Cb=Zb;Nb=cc;Ob=dc;Pb=ec;Qb=fc;Rb=gc}else{break}}}}while(0);Rb=(bb|0)>0;Qb=he(bb&65535|0)|0;Pb=Ab+rb|0;Ob=ub+Ma|0;Nb=Ab+(rb<<1)|0;Cb=ub+(Ma<<1)|0;tb=_a+3|0;Bb=ca(rb,tb)|0;Db=ca(Ma,tb)|0;tb=0;zb=1;Zb=Va;Wb=Wa;while(1){if((zb|0)>-1){_b=(zb|0)>3?zb>>2:1;Sb=tb;Tb=0;Vb=0;Xb=Zb;Yb=Wb;while(1){Ub=(Vb|0)==0;bc=Sb;ac=Tb;$b=0;hc=0;ic=Xb;jc=Yb;while(1){b:do{if(u&(hc|0)==2){kc=$b;lc=ac;mc=bc;nc=ic;oc=jc}else{c:do{if((hc|0)==0){c[O>>2]=zb;pc=$3(s,bb,q,1,n,3)|0;c[O>>2]=pc;qc=(pc|0)<(zb|0)?1:ac;c[N>>2]=0;c[M>>2]=0;rc=ca(c[za>>2]|0,bb)|0;sc=(rc|0)/16|0;tc=c[w>>2]|0;uc=c[w+4>>2]|0;if((pc|0)==0){vc=0;wc=4}else{xc=(ca((c[z>>2]|0)==2?6:4,pc)|0)+8|0;vc=(xc|0)<0|0?-1:0;wc=xc}xc=wrc(wc,vc,sc,(sc|0)<0|0?-1:0)|0;pc=Erc(xc<<3|0>>>29,G<<3|xc>>>29,tc,uc)|0;uc=G;if((rc|0)>15){yc=0;zc=uc;Ac=pc}else{Bc=uc;Cc=pc;Dc=qc;Ec=$b;break}while(1){pc=c[J>>2]|0;uc=c[pc+(yc*36|0)+4>>2]<<7;rc=wrc(uc,(uc|0)<0|0?-1:0,Ac,zc)|0;uc=G;c[pc+(yc*36|0)+32>>2]=0;pc=yc+1|0;if((pc|0)<(sc|0)){yc=pc;zc=uc;Ac=rc}else{Bc=uc;Cc=rc;Dc=qc;Ec=$b;break}}}else{if(Ub){kc=$b;lc=ac;mc=bc;nc=ic;oc=jc;break b}if((hc|0)==1){c[N>>2]=Vb;qc=$3(s,bb,q,0,n,3)|0;c[N>>2]=qc;Fc=(qc|0)<(Vb|0)?1:$b;Gc=qc}else{Fc=$b;Gc=c[N>>2]|0}c[M>>2]=hc;a4(s,bb,c[O>>2]|0,Gc,hc,0,o,p)|0;qc=c[pa>>2]|0;c[O>>2]=zb;sc=$3(s,bb,q,1,n,0)|0;if((sc|0)<(c[O>>2]|0)){c[O>>2]=sc}c[N>>2]=Vb;sc=$3(s,bb,q,0,n,1)|0;rc=c[N>>2]|0;if((sc|0)<(rc|0)){c[N>>2]=sc;Hc=qc;Ic=sc}else{Hc=qc;Ic=rc}while(1){rc=a4(s,bb,c[O>>2]|0,Ic,c[M>>2]|0,1,o,p)|0;qc=G;sc=(c[o>>2]|0)==0;if(sc){if((c[p>>2]|0)==0){Bc=qc;Cc=rc;Dc=ac;Ec=Fc;break c}}uc=Hc-1|0;if((Hc|0)==0){Bc=qc;Cc=rc;Dc=ac;Ec=Fc;break c}do{if(!sc){c[O>>2]=zb;rc=$3(s,bb,q,1,n,0)|0;if((rc|0)>=(c[O>>2]|0)){break}c[O>>2]=rc}}while(0);if((c[p>>2]|0)==0){Hc=uc;Ic=c[N>>2]|0;continue}c[N>>2]=Vb;sc=$3(s,bb,q,0,n,1)|0;rc=c[N>>2]|0;if((sc|0)>=(rc|0)){Hc=uc;Ic=rc;continue}c[N>>2]=sc;Hc=uc;Ic=sc}}}while(0);if(!((bc|0)==0|((Bc|0)<(ic|0)|(Bc|0)==(ic|0)&Cc>>>0<jc>>>0))){kc=Ec;lc=Dc;mc=bc;nc=ic;oc=jc;break}sc=c[L>>2]|0;rc=sc+12|0;qc=ca(c[za>>2]|0,bb)|0;pc=(qc|0)/16|0;tc=c[N>>2]|0;if((tc|0)==0){if((c[K>>2]|0)==0){La=73}else{Jc=0}}else{La=73}do{if((La|0)==73){La=0;xc=(c[z>>2]|0)==2;Kc=xc?6:4;Lc=ca(Kc,tc)|0;a[rc]=xc?32:36;xc=Lc+4|0;a[sc+15|0]=xc;a[sc+14|0]=xc>>>8;a[sc+13|0]=xc>>>16;if((tc|0)>0){Mc=4;Nc=0}else{Jc=4;break}while(1){Lc=ca(Nc,Kc)|0;Oc=Mc;Pc=0;while(1){a[sc+(Oc+12)|0]=c[n+6144+(Pc+Lc<<2)>>2]^((Pc|0)>3?128:0);Qc=Pc+1|0;if((Qc|0)<(Kc|0)){Oc=Oc+1|0;Pc=Qc}else{break}}Pc=Nc+1|0;if((Pc|0)<(tc|0)){Mc=Mc+Kc|0;Nc=Pc}else{Jc=xc;break}}}}while(0);tc=c[O>>2]|0;if((tc|0)==0){if((c[K>>2]|0)==0){La=79}else{Rc=Jc}}else{La=79}if((La|0)==79){La=0;rc=Jc+12|0;xc=(c[z>>2]|0)==2;Kc=xc?6:4;Pc=ca(Kc,tc)|0;a[sc+rc|0]=xc?34:38;xc=Pc+4|0;a[sc+(Jc+15)|0]=xc;a[sc+(Jc+14)|0]=xc>>>8;a[sc+(Jc+13)|0]=xc>>>16;if((tc|0)>0){Pc=4;Oc=0;while(1){Lc=ca(Oc,Kc)|0;uc=Pc;Qc=0;while(1){a[sc+(uc+rc)|0]=c[n+(Qc+Lc<<2)>>2]^((Qc|0)>3?128:0);Sc=Qc+1|0;if((Sc|0)<(Kc|0)){uc=uc+1|0;Qc=Sc}else{break}}Qc=Oc+1|0;if((Qc|0)<(tc|0)){Pc=Pc+Kc|0;Oc=Qc}else{Tc=xc;break}}}else{Tc=4}Rc=Tc+Jc|0}if(Rb){xc=0;Oc=0;Kc=0;Pc=0;tc=0;rc=0;Qc=c[za>>2]|0;while(1){if((Qc|0)>0){uc=tc>>1;Lc=ca(tc,rb)|0;Sc=ca(uc,Gb)|0;Uc=ca(uc,Hb)|0;Vc=ca(tc,Ma)|0;Wc=ca(uc,Jb)|0;Xc=ca(uc,Ib)|0;uc=xc;Yc=Oc;Zc=Kc;_c=Pc;$c=rc;ad=0;while(1){bd=c[J>>2]|0;cd=c[z>>2]|0;dd=ad+Lc|0;ed=yb+(dd+Ab)|0;c[I>>2]=ed;c[W>>2]=rb;fd=(cd|0)==2;if(fd){cd=ad>>1;c[V>>2]=Eb+(cd+Sc);c[U>>2]=Gb;c[T>>2]=Fb+(cd+Uc);c[S>>2]=Hb}cd=c[M>>2]|0;do{if((cd|0)==2){gd=c[bd+($c*36|0)+32>>2]|0;if((gd|0)!=2){hd=gd;La=97;break}gd=ad+Vc|0;if(fd){id=ad>>1;jd=Lb+(id+Wc)|0;kd=Kb+(id+Xc)|0;ld=Jb;md=Ib}else{jd=_c;kd=Zc;ld=Yc;md=uc}id=sb+(gd+ub)|0;nd=ed;y=d[id]|d[id+1|0]<<8|d[id+2|0]<<16|d[id+3|0]<<24|0;a[nd]=y;y=y>>8;a[nd+1|0]=y;y=y>>8;a[nd+2|0]=y;y=y>>8;a[nd+3|0]=y;nd=sb+(Ob+gd)|0;id=yb+(Pb+dd)|0;y=d[nd]|d[nd+1|0]<<8|d[nd+2|0]<<16|d[nd+3|0]<<24|0;a[id]=y;y=y>>8;a[id+1|0]=y;y=y>>8;a[id+2|0]=y;y=y>>8;a[id+3|0]=y;id=sb+(Cb+gd)|0;nd=yb+(Nb+dd)|0;y=d[id]|d[id+1|0]<<8|d[id+2|0]<<16|d[id+3|0]<<24|0;a[nd]=y;y=y>>8;a[nd+1|0]=y;y=y>>8;a[nd+2|0]=y;y=y>>8;a[nd+3|0]=y;nd=sb+(gd+Db)|0;gd=yb+(dd+Bb)|0;y=d[nd]|d[nd+1|0]<<8|d[nd+2|0]<<16|d[nd+3|0]<<24|0;a[gd]=y;y=y>>8;a[gd+1|0]=y;y=y>>8;a[gd+2|0]=y;y=y>>8;a[gd+3|0]=y;if((c[z>>2]|0)!=2){od=jd;pd=kd;qd=ld;rd=md;break}gd=c[V>>2]|0;nd=jd;id=gd;y=(d[nd]|d[nd+1|0]<<8)<<16>>16;a[id]=y;y=y>>8;a[id+1|0]=y;id=jd+ld|0;nd=gd+(c[U>>2]|0)|0;y=(d[id]|d[id+1|0]<<8)<<16>>16;a[nd]=y;y=y>>8;a[nd+1|0]=y;nd=c[T>>2]|0;id=kd;gd=nd;y=(d[id]|d[id+1|0]<<8)<<16>>16;a[gd]=y;y=y>>8;a[gd+1|0]=y;gd=kd+md|0;id=nd+(c[S>>2]|0)|0;y=(d[gd]|d[gd+1|0]<<8)<<16>>16;a[id]=y;y=y>>8;a[id+1|0]=y;od=jd;pd=kd;qd=ld;rd=md}else if((cd|0)==0){La=98}else{hd=c[bd+($c*36|0)+32>>2]|0;La=97}}while(0);do{if((La|0)==97){La=0;if((hd|0)==0){La=98;break}c4(s,k,bd+($c*36|0)+8|0,n);od=_c;pd=Zc;qd=Yc;rd=uc}}while(0);if((La|0)==98){La=0;b4(s,k,c[bd+($c*36|0)>>2]|0,n);od=_c;pd=Zc;qd=Yc;rd=uc}cd=ad+4|0;dd=$c+1|0;ed=c[za>>2]|0;if((cd|0)<(ed|0)){uc=rd;Yc=qd;Zc=pd;_c=od;$c=dd;ad=cd}else{sd=rd;td=qd;ud=pd;vd=od;wd=dd;xd=ed;break}}}else{sd=xc;td=Oc;ud=Kc;vd=Pc;wd=rc;xd=Qc}ad=tc+4|0;if((ad|0)<(bb|0)){xc=sd;Oc=td;Kc=ud;Pc=vd;tc=ad;rc=wd;Qc=xd}else{break}}}Qc=c[M>>2]|0;do{if((Qc|0)==2){rc=Rc+4|0;do{if((qc|0)>15){tc=0;Pc=0;Kc=0;Oc=rc;xc=0;while(1){ad=c[J>>2]|0;$c=ad+(xc*36|0)+32|0;_c=c[$c>>2]|0;Zc=(_c|0)!=2;Yc=Pc+1|0;uc=(Zc&1)<<31-Pc|tc;do{if(Zc){if((Yc|0)>=32){yd=1;zd=Yc;Ad=uc;break}yd=0;zd=Pc+2|0;Ad=uc|((_c|0)==1)<<30-Pc}else{yd=0;zd=Yc;Ad=uc}}while(0);do{if((zd|0)==32){uc=sc+(Oc+12)|0;y=je(Ad|0)|0;a[uc]=y;y=y>>8;a[uc+1|0]=y;y=y>>8;a[uc+2|0]=y;y=y>>8;a[uc+3|0]=y;uc=Oc+4|0;Yc=c[$c>>2]|0;if((Yc|0)!=2&(yd|0)==0){Bd=1;Cd=uc;Dd=Kc;Ed=0;Fd=0;Gd=Yc;break}nrc(sc+(Oc+16)|0,H|0,Kc)|0;Bd=0;Cd=uc+Kc|0;Dd=0;Ed=0;Fd=0;Gd=c[$c>>2]|0}else{Bd=0;Cd=Oc;Dd=Kc;Ed=zd;Fd=Ad;Gd=_c}}while(0);if((yd|0)==0){Hd=Ed;Id=Fd}else{Hd=1;Id=((Gd|0)==1)<<31}if((Gd|0)==1){a[j+Dd|0]=c[ad+(xc*36|0)+8>>2];a[j+(Dd+1)|0]=c[ad+(xc*36|0)+12>>2];a[j+(Dd+2)|0]=c[ad+(xc*36|0)+16>>2];a[j+(Dd+3)|0]=c[ad+(xc*36|0)+20>>2];Jd=Dd+4|0}else if((Gd|0)==0){a[j+Dd|0]=c[ad+(xc*36|0)>>2];Jd=Dd+1|0}else{Jd=Dd}if((Bd|0)==0){Kd=Cd;Ld=Jd}else{nrc(sc+(Cd+12)|0,H|0,Jd)|0;Kd=Jd+Cd|0;Ld=0}_c=xc+1|0;if((_c|0)<(pc|0)){tc=Id;Pc=Hd;Kc=Ld;Oc=Kd;xc=_c}else{break}}if((Hd|0)<=0){Md=Kd;break}xc=sc+(Kd+12)|0;y=je(Id|0)|0;a[xc]=y;y=y>>8;a[xc+1|0]=y;y=y>>8;a[xc+2|0]=y;y=y>>8;a[xc+3|0]=y;nrc(sc+(Kd+16)|0,H|0,Ld)|0;Md=Ld+4+Kd|0}else{Md=rc}}while(0);rc=Md-Rc|0;a[sc+(Rc+12)|0]=49;a[sc+(Rc+15)|0]=rc;a[sc+(Rc+14)|0]=rc>>>8;a[sc+(Rc+13)|0]=rc>>>16;Nd=Md}else if((Qc|0)==0){a[sc+(Rc+12)|0]=50;rc=pc+4|0;a[sc+(Rc+15)|0]=rc;a[sc+(Rc+14)|0]=rc>>>8;a[sc+(Rc+13)|0]=rc>>>16;xc=Rc+4|0;if((qc|0)>15){Od=xc;Pd=0}else{Nd=xc;break}while(1){a[sc+(Od+12)|0]=c[(c[J>>2]|0)+(Pd*36|0)>>2];xc=Pd+1|0;if((xc|0)<(pc|0)){Od=Od+1|0;Pd=xc}else{break}}Nd=Rc+((qc|0)>31?rc:5)|0}else if((Qc|0)==1){xc=Rc+4|0;if((qc|0)>15){Oc=xc;Kc=0;while(1){Pc=Kc+32|0;tc=(Pc|0)>(pc|0)?pc:Pc;if((Kc|0)<(tc|0)){bd=c[J>>2]|0;_c=Kc|31;$c=Kc;uc=0;while(1){if((c[bd+($c*36|0)+32>>2]|0)==1){Qd=1<<_c-$c|uc}else{Qd=uc}Yc=$c+1|0;if((Yc|0)<(tc|0)){$c=Yc;uc=Qd}else{break}}uc=sc+(Oc+12)|0;y=je(Qd|0)|0;a[uc]=y;y=y>>8;a[uc+1|0]=y;y=y>>8;a[uc+2|0]=y;y=y>>8;a[uc+3|0]=y;uc=Kc;$c=Oc+4|0;while(1){_c=c[J>>2]|0;if((c[_c+(uc*36|0)+32>>2]|0)==0){a[sc+($c+12)|0]=c[_c+(uc*36|0)>>2];Rd=$c+1|0}else{a[sc+($c+12)|0]=c[_c+(uc*36|0)+8>>2];a[sc+($c+13)|0]=c[_c+(uc*36|0)+12>>2];a[sc+($c+14)|0]=c[_c+(uc*36|0)+16>>2];a[sc+($c+15)|0]=c[_c+(uc*36|0)+20>>2];Rd=$c+4|0}_c=uc+1|0;if((_c|0)<(tc|0)){uc=_c;$c=Rd}else{Sd=Rd;break}}}else{$c=sc+(Oc+12)|0;y=0;a[$c]=y;y=y>>8;a[$c+1|0]=y;y=y>>8;a[$c+2|0]=y;y=y>>8;a[$c+3|0]=y;Sd=Oc+4|0}if((Pc|0)<(pc|0)){Oc=Sd;Kc=Pc}else{Td=Sd;break}}}else{Td=xc}Kc=Td-Rc|0;a[sc+(Rc+12)|0]=48;a[sc+(Rc+15)|0]=Kc;a[sc+(Rc+14)|0]=Kc>>>8;a[sc+(Rc+13)|0]=Kc>>>16;Nd=Td}else{Nd=Rc}}while(0);sc=c[L>>2]|0;a[sc]=B;pc=Nd+12|0;a[sc+3|0]=pc;a[sc+2|0]=pc>>>8;a[sc+1|0]=pc>>>16;pc=sc+4|0;y=0;a[pc]=y;y=y>>8;a[pc+1|0]=y;pc=sc+6|0;y=0;a[pc]=y;y=y>>8;a[pc+1|0]=y;pc=sc+8|0;y=Qb;a[pc]=y;y=y>>8;a[pc+1|0]=y;pc=sc+10|0;y=he(c[za>>2]&65535|0)|0;a[pc]=y;y=y>>8;a[pc+1|0]=y;kc=Ec;lc=Dc;mc=Nd;nc=Bc;oc=Cc}}while(0);pc=hc+1|0;if(pc>>>0<3>>>0){bc=mc;ac=lc;$b=kc;hc=pc;ic=nc;jc=oc}else{break}}jc=Ub?_b:Vb<<2;if((jc|0)<=(zb|0)&(kc|0)==0){Sb=mc;Tb=lc;Vb=jc;Xb=nc;Yb=oc}else{Ud=mc;Vd=lc;Wd=nc;Xd=oc;break}}}else{Ud=tb;Vd=0;Wd=Zb;Xd=Wb}Yb=zb<<2;if((Yb|0)<257&(Vd|0)==0){tb=Ud;zb=Yb;Zb=Wd;Wb=Xd}else{break}}Wb=Ud+12|0;nrc(qb|0,c[L>>2]|0,Wb)|0;if((Wb|0)<0){Yd=Wb;break a}Zb=wrc(Xd,Wd,Za,Ya)|0;db=G;eb=Zb;fb=Wb+Xa|0;gb=Wd;hb=Xd;ib=Eb;jb=Fb;kb=Gb;lb=Hb;mb=Lb;nb=Kb;ob=Jb;pb=Ib}Wb=c[A>>2]|0;if((cb|0)<(Wb|0)){Na=pb;Oa=ob;Pa=nb;Qa=mb;Ra=lb;Sa=kb;Ta=jb;Ua=ib;Va=gb;Wa=hb;Xa=fb;Ya=db;Za=eb;_a=cb;$a=$a+1|0;ab=Wb}else{Zd=pb;_d=ob;$d=nb;ae=mb;be=lb;ce=kb;de=jb;ee=ib;fe=gb;ge=hb;ie=fb;ke=db;le=eb;break}}}else{Zd=Ia;_d=Ha;$d=Ga;ae=F;be=E;ce=D;de=C;ee=Fa;fe=Da;ge=Ea;ie=0;ke=0;le=0}if((Ba|0)==0&(Aa|0)==0|((ke|0)<(Aa|0)|(ke|0)==(Aa|0)&le>>>0<Ba>>>0)){ab=c[wa>>2]|0;a[ab]=xa;$a=ie+10|0;a[ab+3|0]=$a;a[ab+2|0]=$a>>>8;a[ab+1|0]=$a>>>16;_a=ab+4|0;y=he(c[za>>2]&65535|0)|0;a[_a]=y;y=y>>8;a[_a+1|0]=y;_a=ab+6|0;y=he(c[A>>2]&65535|0)|0;a[_a]=y;y=y>>8;a[_a+1|0]=y;_a=ab+8|0;y=he(Y&65535|0)|0;a[_a]=y;y=y>>8;a[_a+1|0]=y;_a=c[ya>>2]|0;c[ya>>2]=c[ta>>2];c[ta>>2]=_a;nrc(t|0,c[wa>>2]|0,$a)|0;me=Y;ne=ke;oe=le;pe=$a}else{me=X;ne=Aa;oe=Ba;pe=Ca}if((Y-me|0)>4){Ja=me;Ka=pe;La=149;break}Y=Y+1|0;X=me;Aa=ne;Ba=oe;Ca=pe;Da=fe;Ea=ge;Fa=ee;C=de;D=ce;E=be;F=ae;Ga=$d;Ha=_d;Ia=Zd}do{if((La|0)==149){Zd=c[r+380>>2]|0;if((Zd|0)!=0){Ia=Zd+Ja|0;c[va>>2]=Ia;_d=c[r+376>>2]|0;if((Ia|0)>=(_d|0)){c[va>>2]=_d}_d=Ja-Zd|0;c[ua>>2]=_d;Zd=c[r+372>>2]|0;if((_d|0)>=(Zd|0)){Yd=Ka;break}c[ua>>2]=Zd;Yd=Ka;break}do{if((Ja|0)==(c[va>>2]|0)){Zd=Ja+1|0;c[va>>2]=Zd;_d=c[r+376>>2]|0;if((Zd|0)<(_d|0)){qe=Zd;break}c[va>>2]=_d;qe=_d}else{c[va>>2]=Ja;qe=Ja}}while(0);_d=qe-1|0;c[ua>>2]=_d;Zd=c[r+372>>2]|0;if((_d|0)>=(Zd|0)){Yd=Ka;break}c[ua>>2]=Zd;Yd=Ka}}while(0);c[e+28>>2]=Yd;if((c[v>>2]|0)==0){Yd=e+36|0;c[Yd>>2]=c[Yd>>2]|1}c[g>>2]=1;c[b+804>>2]=f;f=c[ta>>2]|0;c[ta>>2]=c[P>>2];c[P>>2]=f;f=(c[v>>2]|0)+1|0;c[v>>2]=f;if((f|0)<(c[r+68>>2]|0)){x=0;i=h;return x|0}c[v>>2]=0;x=0;i=h;return x|0}function _3(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;VHb(b+32|0);VHb(b+36|0);VHb(b+40|0);d=a+140|0;if((c[d>>2]|0)==2){VHb(b+44|0)}mJb(b+344|0);mJb(b+348|0);mJb(b+24|0);mJb(b+28|0);mJb(b+352|0);a=b+8|0;b=0;do{mJb(a+(b<<2)|0);b=b+1|0;}while((b|0)<(((c[d>>2]|0)==2?4:3)|0));return 0}function $3(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;j=i;i=i+152|0;k=j|0;l=j+24|0;m=j+88|0;n=a+48|0;o=(c[n>>2]|0)==2?6:4;p=(f|0)!=0;f=(p?g|0:g+6144|0)|0;q=c[(p?g+12288|0:g+12292|0)>>2]|0;r=(b|0)>0;if(!r){s=0;i=j;return s|0}t=a+52|0;u=(h|0)==3;v=a+344|0;w=p?1:4;x=a+352|0;y=o<<1;z=0;A=0;B=0;C=c[t>>2]|0;while(1){if((C|0)>0){D=z;E=A;F=0;G=C;while(1){if(u){H=6}else{if((c[(c[x>>2]|0)+(D*36|0)+32>>2]|0)==(h|0)){H=6}else{I=E;J=G}}if((H|0)==6){H=0;K=c[v>>2]|0;L=ca(E,o)|0;if(p){M=0;N=0;while(1){O=(M|0)<4;P=O&1^1;Q=(O?M:0)+B>>P;R=Q+1|0;S=F>>P;if(O){O=e+32|0;T=c[O>>2]|0;U=ca(T,Q)|0;V=c[e>>2]|0;W=S+1|0;X=ca(T,R)|0;c[K+(N+L<<2)>>2]=((d[V+(U+W)|0]|0)+(d[V+(U+S)|0]|0)+(d[V+(X+S)|0]|0)+(d[V+(X+W)|0]|0)|0)>>>2;W=(F|2)>>P;P=c[O>>2]|0;O=ca(P,Q)|0;X=W+1|0;U=ca(P,R)|0;c[K+((N|1)+L<<2)>>2]=((d[V+(O+X)|0]|0)+(d[V+(O+W)|0]|0)+(d[V+(U+W)|0]|0)+(d[V+(U+X)|0]|0)|0)>>>2}else{X=c[e+36>>2]|0;U=ca(X,Q)|0;V=c[e+4>>2]|0;W=S+1|0;O=ca(X,R)|0;c[K+(N+L<<2)>>2]=((d[V+(U+W)|0]|0)+(d[V+(U+S)|0]|0)+(d[V+(O+S)|0]|0)+(d[V+(O+W)|0]|0)|0)>>>2;O=c[e+40>>2]|0;V=ca(O,Q)|0;Q=c[e+8>>2]|0;U=ca(O,R)|0;c[K+((N|1)+L<<2)>>2]=((d[Q+(V+W)|0]|0)+(d[Q+(V+S)|0]|0)+(d[Q+(U+S)|0]|0)+(d[Q+(U+W)|0]|0)|0)>>>2}W=M+2|0;if((W|0)<(o|0)){M=W;N=N+2|0}else{break}}}else{N=B>>1;M=F>>1;W=0;U=0;while(1){Q=(W|0)>3;S=Q?W-3|0:0;if(Q){Y=N;Z=M}else{Y=B+(W>>1)|0;Z=W&1|F}Q=(ca(c[e+32+(S<<2)>>2]|0,Y)|0)+Z|0;c[K+(U+L<<2)>>2]=d[(c[e+(S<<2)>>2]|0)+Q|0]|0;Q=W+1|0;if((Q|0)<(o|0)){W=Q;U=U+1|0}else{break}}U=F|2;W=U>>1;Q=0;S=o;while(1){V=(Q|0)>3;R=V?Q-3|0:0;if(V){_=N;$=W}else{_=B+(Q>>1)|0;$=Q&1|U}V=(ca(c[e+32+(R<<2)>>2]|0,_)|0)+$|0;c[K+(S+L<<2)>>2]=d[(c[e+(R<<2)>>2]|0)+V|0]|0;V=Q+1|0;if((V|0)<(o|0)){Q=V;S=S+1|0}else{break}}S=B|2;Q=S>>1;N=0;V=y;while(1){R=(N|0)>3;O=R?N-3|0:0;if(R){aa=Q;ba=M}else{aa=S+(N>>1)|0;ba=N&1|F}R=(ca(c[e+32+(O<<2)>>2]|0,aa)|0)+ba|0;c[K+(V+L<<2)>>2]=d[(c[e+(O<<2)>>2]|0)+R|0]|0;R=N+1|0;if((R|0)<(o|0)){N=R;V=V+1|0}else{break}}V=0;N=o+y|0;while(1){M=(V|0)>3;R=M?V-3|0:0;if(M){da=Q;ea=W}else{da=S+(V>>1)|0;ea=V&1|U}M=(ca(c[e+32+(R<<2)>>2]|0,da)|0)+ea|0;c[K+(N+L<<2)>>2]=d[(c[e+(R<<2)>>2]|0)+M|0]|0;M=V+1|0;if((M|0)<(o|0)){V=M;N=N+1|0}else{break}}}I=E+w|0;J=c[t>>2]|0}N=F+4|0;V=D+1|0;if((N|0)<(J|0)){D=V;E=I;F=N;G=J}else{fa=V;ga=I;ha=J;break}}}else{fa=z;ga=A;ha=C}G=B+4|0;if((G|0)<(b|0)){z=fa;A=ga;B=G;C=ha}else{break}}if((ga|0)==0){s=0;i=j;return s|0}ha=(ga|0)<(q|0)?ga:q;q=a+344|0;C=a+348|0;B=a+72|0;Tca(c[q>>2]|0,o,ga,f,ha,1,c[C>>2]|0,B);Uca(c[q>>2]|0,o,ga,f,ha,1,c[C>>2]|0,B);c[m>>2]=k;c[m+32>>2]=4;c[m+4>>2]=k+16;c[m+8>>2]=k+20;c[m+40>>2]=2;c[m+36>>2]=2;if(r){r=a+52|0;k=a+352|0;B=(h|0)==3;f=e|0;ga=e+32|0;o=l|0;q=l+32|0;A=e+4|0;fa=e+36|0;z=l+4|0;J=l+36|0;I=e+8|0;t=e+40|0;e=l+8|0;w=l+40|0;ea=p?1:4;da=0;y=0;ba=0;aa=c[r>>2]|0;while(1){a:do{if((aa|0)>0){$=ba>>1;if(B){_=da;Z=y;Y=0;while(1){v=c[k>>2]|0;H=c[n>>2]|0;x=c[ga>>2]|0;c[o>>2]=(c[f>>2]|0)+((ca(x,ba)|0)+Y);c[q>>2]=x;if((H|0)==2){H=Y>>1;x=c[fa>>2]|0;c[z>>2]=(c[A>>2]|0)+((ca(x,$)|0)+H);c[J>>2]=x;x=c[t>>2]|0;c[e>>2]=(c[I>>2]|0)+((ca(x,$)|0)+H);c[w>>2]=x}x=c[C>>2]|0;H=c[x+(Z<<2)>>2]|0;if(p){c[v+(_*36|0)>>2]=H;b4(a,m,H,g);c[v+(_*36|0)+4>>2]=d4(a,l,m)|0}else{u=v+(_*36|0)+8|0;c[u>>2]=H;c[v+(_*36|0)+12>>2]=c[x+(Z+1<<2)>>2];c[v+(_*36|0)+16>>2]=c[x+(Z+2<<2)>>2];c[v+(_*36|0)+20>>2]=c[x+(Z+3<<2)>>2];c4(a,m,u,g);c[v+(_*36|0)+24>>2]=d4(a,l,m)|0}v=Z+ea|0;u=c[r>>2]|0;x=Y+4|0;H=_+1|0;if((x|0)<(u|0)){_=H;Z=v;Y=x}else{ia=H;ja=v;ka=u;break a}}}else{la=da;ma=y;na=0;oa=aa}while(1){Y=c[k>>2]|0;if((c[Y+(la*36|0)+32>>2]|0)==(h|0)){Z=c[n>>2]|0;_=c[ga>>2]|0;c[o>>2]=(c[f>>2]|0)+((ca(_,ba)|0)+na);c[q>>2]=_;if((Z|0)==2){Z=na>>1;_=c[fa>>2]|0;c[z>>2]=(c[A>>2]|0)+((ca(_,$)|0)+Z);c[J>>2]=_;_=c[t>>2]|0;c[e>>2]=(c[I>>2]|0)+((ca(_,$)|0)+Z);c[w>>2]=_}_=c[C>>2]|0;Z=c[_+(ma<<2)>>2]|0;if(p){c[Y+(la*36|0)>>2]=Z;b4(a,m,Z,g);c[Y+(la*36|0)+4>>2]=d4(a,l,m)|0}else{u=Y+(la*36|0)+8|0;c[u>>2]=Z;c[Y+(la*36|0)+12>>2]=c[_+(ma+1<<2)>>2];c[Y+(la*36|0)+16>>2]=c[_+(ma+2<<2)>>2];c[Y+(la*36|0)+20>>2]=c[_+(ma+3<<2)>>2];c4(a,m,u,g);c[Y+(la*36|0)+24>>2]=d4(a,l,m)|0}pa=ma+ea|0;qa=c[r>>2]|0}else{pa=ma;qa=oa}Y=na+4|0;u=la+1|0;if((Y|0)<(qa|0)){la=u;ma=pa;na=Y;oa=qa}else{ia=u;ja=pa;ka=qa;break}}}else{ia=da;ja=y;ka=aa}}while(0);$=ba+4|0;if(($|0)<(b|0)){da=ia;y=ja;ba=$;aa=ka}else{ra=ja;break}}}else{ra=0}if((ra|0)<(ha|0)){KIb(0,0,2366864,(ra=i,i=i+24|0,c[ra>>2]=2301216,c[ra+8>>2]=2249984,c[ra+16>>2]=898,ra)|0);i=ra;Hd();return 0}else{s=ha;i=j;return s|0}return 0}function a4(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=(c[a+48>>2]|0)==2?6:4;k=ca(c[a+52>>2]|0,b)|0;b=(k|0)/16|0;l=a+336|0;m=c[l>>2]|0;n=c[l+4>>2]|0;if((d|0)==0){o=4}else{o=(ca(j,d)|0)+8|0}if((e|0)==0){p=0}else{p=(ca(j,e)|0)+4|0}e=o+p|0;p=Erc(m<<3|0>>>29,n<<3|m>>>29,e,(e|0)<0|0?-1:0)|0;e=G;if((f|0)==2){o=(k|0)>15;if((g|0)==0){if(!o){q=e;r=p;return(G=q,r)|0}j=a+352|0;d=0;s=e;t=p;u=n;v=m;while(1){w=c[j>>2]|0;x=c[w+(d*36|0)+28>>2]<<7;y=wrc(x,(x|0)<0|0?-1:0,v,u)|0;x=G;z=Erc(v,u,10,0)|0;A=c[w+(d*36|0)+4>>2]<<7;B=wrc(A,(A|0)<0|0?-1:0,z,G)|0;z=G;A=Erc(v,u,34,0)|0;C=c[w+(d*36|0)+24>>2]<<7;D=wrc(C,(C|0)<0|0?-1:0,A,G)|0;A=G;do{if((x|0)>(z|0)|(x|0)==(z|0)&y>>>0>B>>>0|((x|0)>(A|0)|(x|0)==(A|0)&y>>>0>D>>>0)){C=w+(d*36|0)+32|0;if((z|0)>(A|0)|(z|0)==(A|0)&B>>>0>D>>>0){c[C>>2]=1;E=A;F=D;break}else{c[C>>2]=0;E=z;F=B;break}}else{c[w+(d*36|0)+32>>2]=2;E=x;F=y}}while(0);y=wrc(F,E,t,s)|0;x=G;w=d+1|0;if((w|0)>=(b|0)){q=x;r=y;break}d=w;s=x;t=y;u=c[l+4>>2]|0;v=c[l>>2]|0}return(G=q,r)|0}else{a:do{if(o){v=a+352|0;u=0;t=e;s=p;d=0;E=0;F=n;j=m;while(1){y=c[v>>2]|0;x=c[y+(u*36|0)+28>>2]<<7;w=wrc(x,(x|0)<0|0?-1:0,j,F)|0;x=G;B=y+(u*36|0)+32|0;z=c[B>>2]|0;do{if((z|0)==0){D=Erc(j,F,10,0)|0;A=c[y+(u*36|0)+4>>2]<<7;C=wrc(A,(A|0)<0|0?-1:0,D,G)|0;D=G;if((D|0)<(x|0)|(D|0)==(x|0)&C>>>0<w>>>0){H=E;I=d;J=D;K=C;break}c[B>>2]=2;H=E;I=d+1|0;J=x;K=w}else if((z|0)==2){H=E;I=d;J=x;K=w}else{C=Erc(j,F,34,0)|0;D=c[y+(u*36|0)+24>>2]<<7;A=wrc(D,(D|0)<0|0?-1:0,C,G)|0;C=G;if((C|0)<(x|0)|(C|0)==(x|0)&A>>>0<w>>>0){H=E;I=d;J=C;K=A;break}c[B>>2]=2;H=E+1|0;I=d;J=x;K=w}}while(0);w=wrc(K,J,s,t)|0;x=G;B=u+1|0;if((B|0)>=(b|0)){L=x;M=w;N=I;O=H;break a}u=B;t=x;s=w;d=I;E=H;F=c[l+4>>2]|0;j=c[l>>2]|0}}else{L=e;M=p;N=0;O=0}}while(0);c[h>>2]=N;c[i>>2]=O;q=L;r=M;return(G=q,r)|0}}else if((f|0)==1){if((g|0)==0){if((k|0)<=15){q=e;r=p;return(G=q,r)|0}g=a+352|0;M=0;L=e;O=p;N=n;H=m;while(1){I=c[g>>2]|0;J=Erc(H,N,9,0)|0;K=c[I+(M*36|0)+4>>2]<<7;o=wrc(K,(K|0)<0|0?-1:0,J,G)|0;J=G;K=Erc(H,N,33,0)|0;j=c[I+(M*36|0)+24>>2]<<7;F=wrc(j,(j|0)<0|0?-1:0,K,G)|0;K=G;j=(J|0)>(K|0)|(J|0)==(K|0)&o>>>0>F>>>0;c[I+(M*36|0)+32>>2]=j&1;I=wrc(j?F:o,j?K:J,O,L)|0;J=G;K=M+1|0;if((K|0)>=(b|0)){q=J;r=I;break}M=K;L=J;O=I;N=c[l+4>>2]|0;H=c[l>>2]|0}return(G=q,r)|0}c[i>>2]=0;c[h>>2]=0;if((k|0)<=15){q=e;r=p;return(G=q,r)|0}h=c[a+352>>2]|0;i=Erc(m,n,9,0)|0;l=G;H=Erc(m,n,33,0)|0;N=G;O=0;L=e;M=p;while(1){if((c[h+(O*36|0)+32>>2]|0)==0){g=c[h+(O*36|0)+4>>2]<<7;I=wrc(g,(g|0)<0|0?-1:0,i,l)|0;P=G;Q=I}else{I=c[h+(O*36|0)+24>>2]<<7;g=wrc(I,(I|0)<0|0?-1:0,H,N)|0;P=G;Q=g}g=wrc(Q,P,M,L)|0;I=G;J=O+1|0;if((J|0)<(b|0)){O=J;L=I;M=g}else{q=I;r=g;break}}return(G=q,r)|0}else if((f|0)==0){f=b;M=Erc(f<<3|0>>>29,((b|0)<0|0?-1:0)<<3|f>>>29,m,n)|0;n=wrc(M,G,p,e)|0;M=G;if((k|0)<=15){q=M;r=n;return(G=q,r)|0}k=a+352|0;a=0;m=M;M=n;while(1){n=c[k>>2]|0;f=c[n+(a*36|0)+4>>2]<<7;L=wrc(f,(f|0)<0|0?-1:0,M,m)|0;f=G;c[n+(a*36|0)+32>>2]=0;n=a+1|0;if((n|0)<(b|0)){a=n;m=f;M=L}else{q=f;r=L;break}}return(G=q,r)|0}else{q=e;r=p;return(G=q,r)|0}return 0}function b4(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=b+48|0;b=ca((c[g>>2]|0)==2?6:4,e)|0;e=c[f+(b<<2)>>2]&255;h=d+32|0;i=d|0;a[(c[i>>2]|0)+((c[h>>2]|0)+1)|0]=e;a[(c[i>>2]|0)+(c[h>>2]|0)|0]=e;a[(c[i>>2]|0)+1|0]=e;a[c[i>>2]|0]=e;e=c[f+((b|1)<<2)>>2]&255;a[(c[i>>2]|0)+((c[h>>2]|0)+3)|0]=e;a[(c[i>>2]|0)+((c[h>>2]|0)+2)|0]=e;a[(c[i>>2]|0)+3|0]=e;a[(c[i>>2]|0)+2|0]=e;e=c[f+(b+2<<2)>>2]&255;a[(c[i>>2]|0)+(((c[h>>2]|0)*3|0)+1)|0]=e;a[(c[i>>2]|0)+((c[h>>2]|0)*3|0)|0]=e;a[(c[i>>2]|0)+(c[h>>2]<<1|1)|0]=e;a[(c[i>>2]|0)+(c[h>>2]<<1)|0]=e;e=c[f+(b+3<<2)>>2]&255;a[(c[i>>2]|0)+(((c[h>>2]|0)*3|0)+3)|0]=e;a[(c[i>>2]|0)+(((c[h>>2]|0)*3|0)+2)|0]=e;a[(c[i>>2]|0)+((c[h>>2]<<1)+3)|0]=e;a[(c[i>>2]|0)+((c[h>>2]<<1)+2)|0]=e;if((c[g>>2]|0)!=2){return}g=c[f+(b+4<<2)>>2]&255;e=d+36|0;h=d+4|0;a[(c[h>>2]|0)+((c[e>>2]|0)+1)|0]=g;a[(c[h>>2]|0)+(c[e>>2]|0)|0]=g;a[(c[h>>2]|0)+1|0]=g;a[c[h>>2]|0]=g;g=c[f+(b+5<<2)>>2]&255;b=d+40|0;f=d+8|0;a[(c[f>>2]|0)+((c[b>>2]|0)+1)|0]=g;a[(c[f>>2]|0)+(c[b>>2]|0)|0]=g;a[(c[f>>2]|0)+1|0]=g;a[c[f>>2]|0]=g;return}function c4(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b+48|0;b=(c[g>>2]|0)==2?6:4;h=d+32|0;i=d|0;j=d+36|0;k=d+4|0;l=d+40|0;m=d+8|0;d=0;do{n=d|1;o=d>>1;p=0;q=d;while(1){r=e+(q<<2)|0;s=c[f+6144+((ca(c[r>>2]|0,b)|0)<<2)>>2]&255;t=(ca(c[h>>2]|0,d)|0)+p|0;a[(c[i>>2]|0)+t|0]=s;s=c[f+6144+((ca(c[r>>2]|0,b)|0|1)<<2)>>2]&255;t=p|1;u=(ca(c[h>>2]|0,d)|0)+t|0;a[(c[i>>2]|0)+u|0]=s;s=c[f+6144+((ca(c[r>>2]|0,b)|0)+2<<2)>>2]&255;u=(ca(c[h>>2]|0,n)|0)+p|0;a[(c[i>>2]|0)+u|0]=s;s=c[f+6144+((ca(c[r>>2]|0,b)|0)+3<<2)>>2]&255;u=(ca(c[h>>2]|0,n)|0)+t|0;a[(c[i>>2]|0)+u|0]=s;if((c[g>>2]|0)==2){s=c[f+6144+((ca(c[r>>2]|0,b)|0)+4<<2)>>2]&255;u=p>>1;t=(ca(c[j>>2]|0,o)|0)+u|0;a[(c[k>>2]|0)+t|0]=s;s=c[f+6144+((ca(c[r>>2]|0,b)|0)+5<<2)>>2]&255;r=(ca(c[l>>2]|0,o)|0)+u|0;a[(c[m>>2]|0)+r|0]=s}s=p+2|0;if((s|0)<4){p=s;q=q+1|0}else{break}}d=d+2|0;}while((d|0)<4);return}function d4(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[b+32>>2]|0;g=c[b>>2]|0;h=c[e+32>>2]|0;i=c[e>>2]|0;j=0;k=0;do{l=ca(f,j)|0;m=ca(h,j)|0;n=(d[g+l|0]|0)-(d[i+m|0]|0)|0;o=(ca(n,n)|0)+k|0;n=(d[g+(l+1)|0]|0)-(d[i+(m+1)|0]|0)|0;p=(ca(n,n)|0)+o|0;o=(d[g+(l+2)|0]|0)-(d[i+(m+2)|0]|0)|0;n=(ca(o,o)|0)+p|0;p=(d[g+(l+3)|0]|0)-(d[i+(m+3)|0]|0)|0;k=(ca(p,p)|0)+n|0;j=j+1|0;}while((j|0)<4);if((c[a+48>>2]|0)!=2){q=k;return q|0}a=c[b+36>>2]|0;j=c[b+4>>2]|0;i=c[e+36>>2]|0;g=c[e+4>>2]|0;h=(d[j]|0)-(d[g]|0)|0;f=(ca(h,h)|0)+k|0;k=(d[j+1|0]|0)-(d[g+1|0]|0)|0;h=(ca(k,k)|0)+f|0;f=(d[j+a|0]|0)-(d[g+i|0]|0)|0;k=(ca(f,f)|0)+h|0;h=(d[j+(a+1)|0]|0)-(d[g+(i+1)|0]|0)|0;i=(ca(h,h)|0)+k|0;k=c[b+40>>2]|0;h=c[b+8>>2]|0;b=c[e+40>>2]|0;g=c[e+8>>2]|0;e=(d[h]|0)-(d[g]|0)|0;a=(ca(e,e)|0)+i|0;i=(d[h+1|0]|0)-(d[g+1|0]|0)|0;e=(ca(i,i)|0)+a|0;a=(d[h+k|0]|0)-(d[g+b|0]|0)|0;i=(ca(a,a)|0)+e|0;e=(d[h+(k+1)|0]|0)-(d[g+(b+1)|0]|0)|0;q=(ca(e,e)|0)+i|0;return q|0}function e4(a){a=a|0;c[a+140>>2]=7;return 0}function f4(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=e;l=b+124|0;m=c[l>>2]|0;do{if((m|0)>=1){n=b+120|0;o=c[n>>2]|0;if((o|0)<1){break}if(((k|0)/(m|0)|0|0)<(o|0)){KIb(b,16,2207456,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}o=M4a(b,g,0)|0;if((o|0)<0){q=o;i=h;return q|0}c[e+88>>2]=1;c[e+84>>2]=1;o=k<<3;r=o>>>0>2147483639>>>0|(j|0)==0;s=r?0:j;t=r?8:o+8|0;o=c[l>>2]|0;if((o|0)>0){r=e+32|0;u=e;v=e+36|0;w=e+4|0;x=e+40|0;y=e+8|0;z=0;A=0;B=c[n>>2]|0;C=o;while(1){if((B|0)>0){o=ca(c[x>>2]|0,A)|0;D=ca(c[v>>2]|0,A)|0;E=z;F=0;G=(c[u>>2]|0)+(ca(c[r>>2]|0,A)|0)|0;H=(c[w>>2]|0)+D|0;D=(c[y>>2]|0)+o|0;while(1){o=s+(E>>>3)|0;I=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(E&7)>>>27;o=E+5|0;J=t>>>0>o>>>0?o:t;a[G+3|0]=(I*33|0)>>>2;I=s+(J>>>3)|0;o=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>27;I=J+5|0;J=t>>>0>I>>>0?I:t;a[G+2|0]=(o*33|0)>>>2;o=s+(J>>>3)|0;I=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(J&7)>>>27;o=J+5|0;J=t>>>0>o>>>0?o:t;a[G+1|0]=(I*33|0)>>>2;I=s+(J>>>3)|0;o=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>27;I=J+5|0;J=t>>>0>I>>>0?I:t;a[G]=(o*33|0)>>>2;o=s+(J>>>3)|0;I=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(J&7)>>>26;o=J+6|0;J=t>>>0>o>>>0?o:t;a[H]=I<<2;I=s+(J>>>3)|0;o=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>26;I=J+6|0;K=t>>>0>I>>>0?I:t;a[D]=o<<2;o=F+4|0;L=c[n>>2]|0;if((o|0)<(L|0)){E=K;F=o;G=G+4|0;H=H+1|0;D=D+1|0}else{break}}M=K;N=L;O=c[l>>2]|0}else{M=z;N=B;O=C}D=A+1|0;if((D|0)<(O|0)){z=M;A=D;B=N;C=O}else{break}}}c[f>>2]=1;q=k;i=h;return q|0}}while(0);KIb(b,16,2249952,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}function g4(a){a=a|0;var b=0;b=UHb()|0;c[a+804>>2]=b;return((b|0)==0?-12:0)|0}function h4(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;h=c[b+60>>2]|0;i=c[b+428>>2]|0;j=b+124|0;k=b+120|0;l=(ca(c[j>>2]<<5,c[k>>2]|0)|0)/4|0;m=d5a(b,e,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){n=m;return n|0}m=c[b+804>>2]|0;c[m+88>>2]=1;c[m+84>>2]=1;m=e+28|0;b=(c[m>>2]|0)<0?0:c[e+24>>2]|0;l=c[j>>2]|0;if((l|0)>0){o=f+32|0;p=f|0;q=f+36|0;r=f+4|0;s=f+40|0;t=f+8|0;f=h+4|0;h=b;u=0;v=i;i=0;w=c[k>>2]|0;x=l;while(1){if((w|0)>0){l=ca(c[s>>2]|0,u)|0;z=ca(c[q>>2]|0,u)|0;A=u&1;B=h;C=0;D=v;E=(c[p>>2]|0)+(ca(c[o>>2]|0,u)|0)|0;F=(c[r>>2]|0)+z|0;z=(c[t>>2]|0)+l|0;l=i;while(1){G=c[f>>2]|0;if((G|0)==2){H=c[1512744+(A<<3)+((C>>>2&1)<<2)>>2]|0}else if((G|0)==1){H=(ca(D,1664525)|0)+1013904223|0}else if((G|0)==0){H=1227489280}else{H=D}I=(((d[z]|0)+(H>>>16&3)|0)*253|0)>>>10;G=B;y=je(I|((((d[F]|0)+(H>>>18&3)|0)*253|0)>>>10|((((d[E]|0)+(H>>>20&7)|0)*249|0)>>>11|((((d[E+1|0]|0)+(H>>>23&7)|0)*249|0)>>>11|((((d[E+2|0]|0)+(H>>>26&7)|0)*249|0)>>>11|((((d[E+3|0]|0)+(H>>>29)|0)*249|0)>>>11|l<<5)<<5)<<5)<<5)<<6)<<6|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;J=B+4|0;G=C+4|0;K=c[k>>2]|0;if((G|0)<(K|0)){B=J;C=G;D=H;E=E+4|0;F=F+1|0;z=z+1|0;l=I}else{break}}L=J;M=H;N=I;O=K;P=c[j>>2]|0}else{L=h;M=v;N=i;O=w;P=x}l=u+1|0;if((l|0)<(P|0)){h=L;u=l;v=M;i=N;w=O;x=P}else{Q=L;break}}}else{Q=b}c[m>>2]=(Q-b<<3|0)/8|0;b=e+36|0;c[b>>2]=c[b>>2]|1;c[g>>2]=1;n=0;return n|0}function i4(a){a=a|0;VHb(a+804|0);return 0}function j4(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+1244>>2]=a;c[b+1248>>2]=0;c[b+1252>>2]=0;l8(b,a);return 0}function k4(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;j=i;i=i+224|0;k=j|0;l=j+16|0;m=j+80|0;n=j+120|0;o=j+200|0;p=c[e+60>>2]|0;q=p;r=f;s=c[h+24>>2]|0;t=s;a:do{if((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)==1330007625){u=s+4|0;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;do{if(!(v>>>0>4294967287>>>0)){u=v+8|0;w=h+28|0;if(u>>>0>(c[w>>2]|0)>>>0){break}KIb(e,48,2366824,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=s+u|0;z=u;A=w;break a}}while(0);KIb(e,16,2456440,(x=i,i=i+8|0,c[x>>2]=v,x)|0);i=x;B=-1094995529;i=j;return B|0}else{y=s;z=0;A=h+28|0}}while(0);h=(c[A>>2]|0)-z&-2;z=p+1248|0;s=z;A4a(z,p+1252|0,h);z=c[s>>2]|0;if((z|0)==0){KIb(e,16,2301160,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;B=-12;i=j;return B|0}ef[c[p+1100>>2]&4095](z,y,(h|0)/2|0);z=c[s>>2]|0;s=h<<3;h=s>>>0>2147483639>>>0|(z|0)==0;t=h?0:z;z=h?0:s;s=o|0;c[s>>2]=t;c[o+12>>2]=z;h=z|8;w=o+16|0;c[w>>2]=h;c[o+4>>2]=t+(z>>3);z=o+8|0;c[z>>2]=0;u=y;y=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>8&255;u=e;KIb(u,48,2249928,(x=i,i=i+8|0,c[x>>2]=y,x)|0);i=x;if((y|0)==1|(y|0)==2){c[e+140>>2]=2;c[e+796>>2]=8;C=M4a(e,r,0)|0;if((C|0)<0){B=C;i=j;return B|0}C=p+1244|0;D=c[C>>2]|0;c[k>>2]=128;c[k+4>>2]=128;c[k+8>>2]=128;E=c[f>>2]|0;c[z>>2]=h>>>0>16>>>0?16:h;F=0;while(1){if((F|0)>=3){break}G=m4(q,o,l+(F*20|0)|0)|0;if((G|0)<0){H=43;break}else{F=F+1|0}}if((H|0)==43){if((F|0)>=0){I=0;do{c3(l+(I*20|0)|0);I=I+1|0;}while((I|0)<=(F|0))}KIb(c[C>>2]|0,16,2175104,(x=i,i=i+8|0,c[x>>2]=F,x)|0);i=x;B=G;i=j;return B|0}G=D+124|0;if((c[G>>2]|0)>0){D=f+32|0;F=E;E=0;I=c[z>>2]|0;J=c[C>>2]|0;while(1){K=0;L=I;M=J;while(1){N=k+(K<<2)|0;O=F+K|0;P=c[w>>2]|0;b:do{if((c[M+120>>2]|0)>0){Q=l+(K*20|0)+4|0;R=1;S=L;T=c[N>>2]|0;U=O;while(1){V=c[s>>2]|0;W=V+(S>>>3)|0;X=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(S&7)>>>25;W=c[Q>>2]|0;Y=b[W+(X<<2)>>1]|0;Z=b[W+(X<<2)+2>>1]|0;X=Z<<16>>16;if(Z<<16>>16<0){Z=S+7|0;_=P>>>0>Z>>>0?Z:P;Z=V+(_>>>3)|0;V=((je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(_&7)>>>((X+32|0)>>>0))+Y|0;$=b[W+(V<<2)+2>>1]|0;aa=_;ba=b[W+(V<<2)>>1]|0}else{$=X;aa=S;ba=Y}Y=$+aa|0;X=P>>>0>Y>>>0?Y:P;Y=ba+T|0;a[U]=Y;V=c[C>>2]|0;if((R|0)>=(c[V+120>>2]|0)){ca=X;da=V;break b}R=R+1|0;S=X;T=Y;U=U+3|0}}else{ca=L;da=M}}while(0);c[z>>2]=ca;c[N>>2]=d[O]|0;P=K+1|0;if((P|0)<3){K=P;L=ca;M=da}else{break}}M=E+1|0;if((M|0)<(c[G>>2]|0)){F=F+(c[D>>2]|0)|0;E=M;I=ca;J=da}else{break}}}c3(l|0);c3(l+20|0);c3(l+40|0)}else if((y|0)==3){c[e+140>>2]=27;c[e+796>>2]=8;l=M4a(e,r,0)|0;if((l|0)<0){B=l;i=j;return B|0}l=p+1244|0;da=c[l>>2]|0;J=c[f>>2]|0;c[z>>2]=h>>>0>16>>>0?16:h;ca=0;while(1){if((ca|0)>=4){break}ea=m4(q,o,n+(ca*20|0)|0)|0;if((ea|0)<0){H=62;break}else{ca=ca+1|0}}if((H|0)==62){if((ca|0)>=0){I=0;do{c3(n+(I*20|0)|0);I=I+1|0;}while((I|0)<=(ca|0))}KIb(c[l>>2]|0,16,2175104,(x=i,i=i+8|0,c[x>>2]=ca,x)|0);i=x;B=ea;i=j;return B|0}ea=da+124|0;c:do{if((c[ea>>2]|0)>0){da=n+4|0;ca=n+24|0;I=n+44|0;E=n+64|0;D=f+32|0;F=128;G=128;C=128;ba=0;aa=J;$=1;k=c[z>>2]|0;M=c[l>>2]|0;while(1){L=c[w>>2]|0;d:do{if((c[M+120>>2]|0)>0){K=1;v=k;P=ba;U=C;T=G;S=F;R=aa;while(1){Q=c[s>>2]|0;Y=Q+(v>>>3)|0;X=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(v&7)>>>25;Y=c[da>>2]|0;V=b[Y+(X<<2)>>1]|0;W=b[Y+(X<<2)+2>>1]|0;X=W<<16>>16;if(W<<16>>16<0){W=v+7|0;_=L>>>0>W>>>0?W:L;W=Q+(_>>>3)|0;Q=((je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(_&7)>>>((X+32|0)>>>0))+V|0;fa=b[Y+(Q<<2)+2>>1]|0;ga=_;ha=b[Y+(Q<<2)>>1]|0}else{fa=X;ga=v;ha=V}V=fa+ga|0;X=L>>>0>V>>>0?V:L;V=ha+P|0;Q=V&255;a[R]=Q;if(Q<<24>>24==0){a[R+1|0]=0;a[R+2|0]=0;a[R+3|0]=0;ia=S;ja=T;ka=U;la=X}else{Q=c[s>>2]|0;Y=Q+(X>>>3)|0;_=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(X&7)>>>25;Y=c[ca>>2]|0;W=b[Y+(_<<2)>>1]|0;Z=b[Y+(_<<2)+2>>1]|0;_=Z<<16>>16;if(Z<<16>>16<0){Z=X+7|0;ma=L>>>0>Z>>>0?Z:L;Z=Q+(ma>>>3)|0;Q=((je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(ma&7)>>>((_+32|0)>>>0))+W|0;na=b[Y+(Q<<2)+2>>1]|0;oa=ma;pa=b[Y+(Q<<2)>>1]|0}else{na=_;oa=X;pa=W}W=na+oa|0;X=L>>>0>W>>>0?W:L;W=pa+U|0;a[R+1|0]=W;_=c[s>>2]|0;Q=_+(X>>>3)|0;Y=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(X&7)>>>25;Q=c[I>>2]|0;ma=b[Q+(Y<<2)>>1]|0;Z=b[Q+(Y<<2)+2>>1]|0;Y=Z<<16>>16;if(Z<<16>>16<0){Z=X+7|0;qa=L>>>0>Z>>>0?Z:L;Z=_+(qa>>>3)|0;_=((je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(qa&7)>>>((Y+32|0)>>>0))+ma|0;ra=b[Q+(_<<2)+2>>1]|0;sa=qa;ta=b[Q+(_<<2)>>1]|0}else{ra=Y;sa=X;ta=ma}ma=ra+sa|0;X=L>>>0>ma>>>0?ma:L;ma=ta+T|0;a[R+2|0]=ma;Y=c[s>>2]|0;_=Y+(X>>>3)|0;Q=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(X&7)>>>25;_=c[E>>2]|0;qa=b[_+(Q<<2)>>1]|0;Z=b[_+(Q<<2)+2>>1]|0;Q=Z<<16>>16;if(Z<<16>>16<0){Z=X+7|0;ua=L>>>0>Z>>>0?Z:L;Z=Y+(ua>>>3)|0;Y=((je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(ua&7)>>>((Q+32|0)>>>0))+qa|0;va=b[_+(Y<<2)+2>>1]|0;wa=ua;xa=b[_+(Y<<2)>>1]|0}else{va=Q;wa=X;xa=qa}qa=va+wa|0;X=xa+S|0;a[R+3|0]=X;ia=X;ja=ma;ka=W;la=L>>>0>qa>>>0?qa:L}qa=c[l>>2]|0;if((K|0)>=(c[qa+120>>2]|0)){ya=la;za=qa;break d}K=K+1|0;v=la;P=V;U=ka;T=ja;S=ia;R=R+4|0}}else{ya=k;za=M}}while(0);c[z>>2]=ya;L=a[aa]|0;if(L<<24>>24==0){Aa=C;Ba=G;Ca=F}else{Aa=d[aa+1|0]|0;Ba=d[aa+2|0]|0;Ca=d[aa+3|0]|0}if(($|0)>=(c[ea>>2]|0)){break c}F=Ca;G=Ba;C=Aa;ba=L&255;aa=aa+(c[D>>2]|0)|0;$=$+1|0;k=ya;M=za}}}while(0);c3(n|0);c3(n+20|0);c3(n+40|0);c3(n+60|0)}else if((y|0)==0){c[e+140>>2]=4;c[e+796>>2]=8;n=M4a(e,r,0)|0;if((n|0)<0){B=n;i=j;return B|0}n=p+1244|0;p=c[n>>2]|0;r=c[f>>2]|0;e=c[f+4>>2]|0;za=c[f+8>>2]|0;ya=t+1|0;t=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;c[z>>2]=h>>>0>16>>>0?16:h;if((t&255|0)==0){Da=0}else{QIb(p,2123616,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;B=-1163346256;i=j;return B|0}while(1){if((Da|0)>=2){break}Ea=m4(q,o,m+(Da*20|0)|0)|0;if((Ea|0)<0){H=17;break}else{Da=Da+1|0}}if((H|0)==17){if((Da|0)>=0){H=0;do{c3(m+(H*20|0)|0);H=H+1|0;}while((H|0)<=(Da|0))}KIb(c[n>>2]|0,16,2175104,(x=i,i=i+8|0,c[x>>2]=Da,x)|0);i=x;B=Ea;i=j;return B|0}Ea=p+124|0;e:do{if((c[Ea>>2]|0)>0){p=m+4|0;Da=m+24|0;H=f+32|0;o=f+40|0;q=f+36|0;t=128;h=128;ya=128;Aa=1;Ba=r;Ca=c[z>>2]|0;ea=c[n>>2]|0;ia=e;ja=za;while(1){ka=c[w>>2]|0;if((c[ea+120>>2]|0)>0){la=0;l=Ca;xa=ya;do{wa=c[s>>2]|0;va=wa+(l>>>3)|0;ta=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(l&7)>>>25;va=c[p>>2]|0;sa=b[va+(ta<<2)>>1]|0;ra=b[va+(ta<<2)+2>>1]|0;ta=ra<<16>>16;if(ra<<16>>16<0){ra=l+7|0;pa=ka>>>0>ra>>>0?ra:ka;ra=wa+(pa>>>3)|0;wa=((je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(pa&7)>>>((ta+32|0)>>>0))+sa|0;Fa=b[va+(wa<<2)+2>>1]|0;Ga=b[va+(wa<<2)>>1]|0;Ha=pa}else{Fa=ta;Ga=sa;Ha=l}sa=Fa+Ha|0;l=ka>>>0>sa>>>0?sa:ka;xa=Ga+xa|0;a[Ba+la|0]=xa;la=la+1|0;Ia=c[n>>2]|0;}while((la|0)<(c[Ia+120>>2]|0));Ja=l;Ka=c[w>>2]|0;La=Ia}else{Ja=Ca;Ka=ka;La=ea}c[z>>2]=Ja;la=d[Ba]|0;if((c[La+120>>2]>>1|0)>0){xa=0;sa=Ja;ta=h;do{pa=c[s>>2]|0;wa=pa+(sa>>>3)|0;va=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(sa&7)>>>25;wa=c[Da>>2]|0;ra=b[wa+(va<<2)>>1]|0;oa=b[wa+(va<<2)+2>>1]|0;va=oa<<16>>16;if(oa<<16>>16<0){oa=sa+7|0;na=Ka>>>0>oa>>>0?oa:Ka;oa=pa+(na>>>3)|0;pa=((je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(na&7)>>>((va+32|0)>>>0))+ra|0;Ma=b[wa+(pa<<2)+2>>1]|0;Na=b[wa+(pa<<2)>>1]|0;Oa=na}else{Ma=va;Na=ra;Oa=sa}ra=Ma+Oa|0;sa=Ka>>>0>ra>>>0?ra:Ka;ta=Na+ta|0;a[ia+xa|0]=ta;xa=xa+1|0;Pa=c[n>>2]|0;}while((xa|0)<(c[Pa+120>>2]>>1|0));Qa=sa;Ra=c[w>>2]|0;Sa=Pa}else{Qa=Ja;Ra=Ka;Sa=La}c[z>>2]=Qa;xa=d[ia]|0;if((c[Sa+120>>2]>>1|0)>0){ta=0;ka=Qa;l=t;while(1){ra=c[s>>2]|0;va=ra+(ka>>>3)|0;na=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(ka&7)>>>25;va=c[Da>>2]|0;pa=b[va+(na<<2)>>1]|0;wa=b[va+(na<<2)+2>>1]|0;na=wa<<16>>16;if(wa<<16>>16<0){wa=ka+7|0;oa=Ra>>>0>wa>>>0?wa:Ra;wa=ra+(oa>>>3)|0;ra=((je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(oa&7)>>>((na+32|0)>>>0))+pa|0;Ta=b[va+(ra<<2)+2>>1]|0;Ua=b[va+(ra<<2)>>1]|0;Va=oa}else{Ta=na;Ua=pa;Va=ka}pa=Ta+Va|0;na=Ra>>>0>pa>>>0?pa:Ra;pa=Ua+l|0;a[ja+ta|0]=pa;oa=ta+1|0;ra=c[n>>2]|0;if((oa|0)<(c[ra+120>>2]>>1|0)){ta=oa;ka=na;l=pa}else{Wa=na;Xa=ra;break}}}else{Wa=Qa;Xa=Sa}c[z>>2]=Wa;if((Aa|0)>=(c[Ea>>2]|0)){break e}t=d[ja]|0;h=xa;ya=la;Aa=Aa+1|0;Ba=Ba+(c[H>>2]|0)|0;Ca=Wa;ea=Xa;ia=ia+(c[q>>2]|0)|0;ja=ja+(c[o>>2]|0)|0}}}while(0);c3(m|0);c3(m+20|0)}else{KIb(u,16,2207424,(x=i,i=i+8|0,c[x>>2]=y,x)|0);i=x;B=-1094995529;i=j;return B|0}c[f+84>>2]=1;c[f+88>>2]=1;c[g>>2]=1;B=c[A>>2]|0;i=j;return B|0}function l4(a){a=a|0;mJb((c[a+60>>2]|0)+1248|0);return 0}function m4(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+1024|0;j=h|0;k=h+256|0;l=h+512|0;m=f+8|0;n=c[m>>2]|0;o=c[f+16>>2]|0;p=c[f>>2]|0;f=p+(n>>>3)|0;q=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(n&7)>>>27;f=n+5|0;n=o>>>0>f>>>0?f:o;c[m>>2]=n;a:do{if((q|0)==0){r=0}else{f=0;s=0;t=0;u=0;v=n;while(1){w=p+(v>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)>>>23;w=v+9|0;y=o>>>0>w>>>0?w:o;c[m>>2]=y;z=x+f|0;if((z|0)>256){break}w=t+1|0;if((x|0)==0){A=s;B=u;C=y}else{D=w&255;E=x>>>0>1>>>0?x:1;F=u+E|0;G=s;H=0;I=u;J=y;while(1){y=p+(J>>>3)|0;K=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(J&7)>>>24;y=J+8|0;L=o>>>0>y>>>0?y:o;c[m>>2]=L;a[j+I|0]=K;a[k+I|0]=D;b[l+(I<<1)>>1]=G;K=H+1|0;if((K|0)<(x|0)){G=G+1|0;H=K;I=I+1|0;J=L}else{break}}A=s+E|0;B=F;C=L}if((w|0)<(q|0)){f=z;s=A<<1;t=w;u=B;v=C}else{r=B;break a}}c[g+4>>2]=0;KIb(c[e+1244>>2]|0,16,2147568,(v=i,i=i+8|0,c[v>>2]=z,v)|0);i=v;M=-1094995529;i=h;return M|0}}while(0);M=$2(g,7,r,k|0,1,1,l,2,2,j|0,1,1,0)|0;i=h;return M|0}function n4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+60|0;d=c[b>>2]|0;c[a+420>>2]=1;c[a+416>>2]=1;c[a+412>>2]=8e3;e=d+12|0;c[e>>2]=12;f=a+424|0;c[f>>2]=640;a=d;c[a>>2]=pJb(c[e>>2]<<2)|0;g=d+4|0;c[g>>2]=pJb(c[e>>2]<<2)|0;h=d+8|0;c[h>>2]=pJb(c[e>>2]<<2)|0;i=d+28|0;c[i>>2]=pJb((c[e>>2]|0)+(c[f>>2]|0)<<2)|0;e=pJb(c[f>>2]<<2)|0;c[d+32>>2]=e;do{if((c[a>>2]|0)!=0){if((c[g>>2]|0)==0){break}if((c[h>>2]|0)==0){break}if((c[i>>2]|0)==0|(e|0)==0){break}AIb(d+36|0,0);j=0;return j|0}}while(0);d=c[b>>2]|0;kJb(c[d>>2]|0);kJb(c[d+4>>2]|0);kJb(c[d+8>>2]|0);kJb(c[d+28>>2]|0);kJb(c[d+32>>2]|0);j=-12;return j|0}function o4(a,e,f,h){a=a|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;j=i;i=i+400|0;k=j|0;l=e;m=c[a+60>>2]|0;n=h+28|0;o=c[n>>2]|0;do{if((o|0)!=0){p=h+24|0;c[m+20>>2]=~~(+T(+10.0,+(+(-(d[c[p>>2]|0]|0)|0)/10.0))*1081109975.0*.75);q=m+4|0;r=m+12|0;mrc(c[q>>2]|0,0,c[r>>2]<<2|0)|0;s=(c[n>>2]|0)-1|0;t=c[r>>2]|0;r=(s|0)>(t|0)?t:s;if((r|0)<=0){break}s=c[p>>2]|0;p=c[q>>2]|0;q=0;while(1){t=q+1|0;g[p+(q<<2)>>2]=+((d[s+t|0]|0)-127|0)*.0078125;if((t|0)<(r|0)){q=t}else{break}}}}while(0);n=m+24|0;do{if((c[n>>2]|0)==0){c[m+16>>2]=c[m+20>>2];h=m;q=m+12|0;nrc(c[h>>2]|0,c[m+4>>2]|0,c[q>>2]<<2)|0;c[n>>2]=1;u=c[q>>2]|0;v=h}else{h=m+16|0;c[h>>2]=((c[m+20>>2]|0)/2|0)+((c[h>>2]|0)/2|0);h=c[m+12>>2]|0;q=m;if((h|0)<=0){u=h;v=q;break}r=c[q>>2]|0;s=c[m+4>>2]|0;p=0;while(1){t=r+(p<<2)|0;g[t>>2]=+g[t>>2]*.6+ +g[s+(p<<2)>>2]*.4;t=p+1|0;if((t|0)<(h|0)){p=t}else{u=h;v=q;break}}}}while(0);n=m+8|0;q=c[n>>2]|0;h=c[v>>2]|0;p=m+12|0;do{if((u|0)>0){s=q;r=0;t=k|0;while(1){w=h+(r<<2)|0;g[t+(r<<2)>>2]=+g[w>>2];if((r|0)>0){x=r-1|0;y=0;do{g[t+(y<<2)>>2]=+g[s+(y<<2)>>2]+ +g[w>>2]*+g[s+(x-y<<2)>>2];y=y+1|0;}while((y|0)<(r|0))}y=r+1|0;if((y|0)<(u|0)){x=s;s=t;r=y;t=x}else{break}}if((t|0)==(q|0)){z=u;break}nrc(q|0,t|0,u<<2)|0;z=c[p>>2]|0}else{z=u}}while(0);if((z|0)>0){u=c[v>>2]|0;A=1.0;v=0;while(1){B=+g[u+(v<<2)>>2];C=A*(1.0-B*B);q=v+1|0;if((q|0)<(z|0)){A=C;v=q}else{D=C;break}}}else{D=1.0}A=+S(D*+(c[m+16>>2]|0)/1081110016.0);v=a+424|0;u=c[v>>2]|0;if((u|0)>0){q=m+36|0;h=m+292|0;k=m+32|0;r=0;s=c[h>>2]|0;do{c[q+((s&63)<<2)>>2]=(c[q+((s+9&63)<<2)>>2]|0)+(c[q+((s+40&63)<<2)>>2]|0);x=c[h>>2]|0;s=x+1|0;c[h>>2]=s;E=c[k>>2]|0;g[E+(r<<2)>>2]=A*+((c[q+((x&63)<<2)>>2]&65535)-32768|0);r=r+1|0;F=c[v>>2]|0;}while((r|0)<(F|0));G=F;H=c[p>>2]|0;I=E}else{G=u;H=z;I=c[m+32>>2]|0}z=m+28|0;M3((c[z>>2]|0)+(H<<2)|0,c[n>>2]|0,I,G,H);c[e+76>>2]=c[v>>2];H=M4a(a,l,0)|0;if((H|0)<0){J=H;i=j;return J|0}H=c[e>>2]|0;e=c[v>>2]|0;if((e|0)>0){v=c[p>>2]|0;l=c[z>>2]|0;a=0;while(1){b[H+(a<<1)>>1]=~~+g[l+(v+a<<2)>>2];G=a+1|0;if((G|0)<(e|0)){a=G}else{K=l;L=v;break}}}else{K=c[z>>2]|0;L=c[p>>2]|0}nrc(K|0,K+(e<<2)|0,L<<2)|0;c[f>>2]=1;J=o;i=j;return J|0}function p4(a){a=a|0;var b=0;b=c[a+60>>2]|0;kJb(c[b>>2]|0);kJb(c[b+4>>2]|0);kJb(c[b+8>>2]|0);kJb(c[b+28>>2]|0);kJb(c[b+32>>2]|0);return 0}function q4(a){a=a|0;c[(c[a+60>>2]|0)+24>>2]=0;return}function r4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+60|0;e=c[d>>2]|0;if((c[a+416>>2]|0)!=1){KIb(a,16,2366768,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}f=a+424|0;c[f>>2]=640;a=e+28|0;c[a>>2]=10;h=rPa(e,c[f>>2]|0,10,2)|0;if((h|0)<0){g=h;i=b;return g|0}h=e+32|0;c[h>>2]=hJb(c[f>>2]<<2)|0;f=hJb(c[a>>2]<<3)|0;c[e+36>>2]=f;if(!((c[h>>2]|0)==0|(f|0)==0)){g=0;i=b;return g|0}f=c[d>>2]|0;qPa(f);kJb(c[f+32>>2]|0);kJb(c[f+36>>2]|0);g=-12;i=b;return g|0}function s4(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0,v=0,w=0;j=i;k=c[d+60>>2]|0;l=c[f>>2]|0;m=k+28|0;n=e5a(e,(c[m>>2]|0)+1|0)|0;if((n|0)!=0){KIb(d,16,2456352,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;o=n;i=j;return o|0}n=f+76|0;f=c[n>>2]|0;if((f|0)>0){d=c[k+32>>2]|0;p=0;q=0.0;while(1){r=b[l+(p<<1)>>1]|0;c[d+(p<<2)>>2]=r;s=q+ +(ca(r,r)|0);r=p+1|0;t=c[n>>2]|0;if((r|0)<(t|0)){p=r;q=s}else{u=s;v=t;break}}}else{u=0.0;v=f}q=u/+(v|0);do{if(q>0.0){v=~~(-0.0- +Q(+fd(+(q/1081109975.0))*10.0));if((v|0)<0){w=0;break}w=(v|0)>127?127:v&255}else{w=127}}while(0);v=k+36|0;oPa(k,c[k+32>>2]|0,c[m>>2]|0,c[v>>2]|0)|0;k=e+24|0;a[c[k>>2]|0]=w;if((c[m>>2]|0)>0){w=0;while(1){f=w+1|0;a[(c[k>>2]|0)+f|0]=~~(+h[(c[v>>2]|0)+(w<<3)>>3]*127.0+127.0);if((f|0)<(c[m>>2]|0)){w=f}else{break}}}c[g>>2]=1;c[e+28>>2]=(c[m>>2]|0)+1;o=0;i=j;return o|0}function t4(a){a=a|0;var b=0;b=c[a+60>>2]|0;qPa(b);kJb(c[b+32>>2]|0);kJb(c[b+36>>2]|0);return 0}function u4(a){a=a|0;var b=0,d=0,e=0,f=0;b=0;while(1){if(!(b>>>0<371>>>0)){d=0;e=4;break}f=1681920+(b*20|0)|0;if((c[f>>2]|0)==(a|0)){d=f;e=4;break}else{b=b+1|0}}if((e|0)==4){return d|0}return 0}function v4(a){a=a|0;if((a|0)==0){return 1681920}else{return(((a-1681920|0)/20|0)>>>0<370>>>0?a+20|0:0)|0}return 0}function w4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=0;while(1){if((b|0)==0){d=1681920}else{e=((b-1681920|0)/20|0)>>>0<370>>>0?b+20|0:0;if((e|0)==0){f=0;g=5;break}else{d=e}}if((irc(c[d+8>>2]|0,a)|0)==0){f=d;g=5;break}else{b=d}}if((g|0)==5){return f|0}return 0}function x4(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0.0,da=0,ea=0;b=i;e=c[a+60>>2]|0;f=e;h=c[a+96>>2]|0;j=a+100|0;k=c[j>>2]|0;l=h+k|0;m=e+20|0;c[m>>2]=a;n=a;if((k|0)<1){KIb(n,16,2123408,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}KIb(n,48,2640992,(o=i,i=i+8|0,c[o>>2]=k,o)|0);i=o;q=a+416|0;if((c[q>>2]|0)==0){KIb(n,16,2618232,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}AIb(e+1296|0,0);l8(e+24|0,a);r=e+22792|0;s=a+432|0;t=e+1292|0;u=e+22820|0;v=e+22788|0;w=0;x=0;y=0;z=k;k=h;a:while(1){if(!(k>>>0<l>>>0)){A=-63;B=52;break}do{if((z|0)>7){h=k;C=je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;c[r+(y*8432|0)+12>>2]=C;h=k+4|0;D=(he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;h=k+6|0;E=(he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;c[r+(y*8432|0)+16>>2]=E;h=z-8|0;if((h|0)<=7){F=h;G=k+8|0;H=D;I=E;J=C;break}h=k+12|0;K=he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0;L=K&65535;c[r+(y*8432|0)+20>>2]=L;if((K&65535)>>>0>50>>>0){B=11;break a}K=k+14|0;c[r+(y*8432|0)+24>>2]=(he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535;F=z-16|0;G=k+16|0;H=D;I=E;J=C}else{F=z;G=k;H=w;I=c[r+(y*8432|0)+16>>2]|0;J=c[r+(y*8432|0)+12>>2]|0}}while(0);C=r+(y*8432|0)+28|0;c[C>>2]=(H|0)/(c[q>>2]|0)|0;c[r+(y*8432|0)+64>>2]=c[s>>2]<<3;E=r+(y*8432|0)+32|0;c[E>>2]=5;D=r+(y*8432|0)+16|0;K=r+(y*8432|0)+72|0;c[K>>2]=I;h=r+(y*8432|0)+8|0;c[h>>2]=1;KIb(n,48,2569040,(o=i,i=i+16|0,c[o>>2]=y,c[o+8>>2]=J,o)|0);i=o;M=r+(y*8432|0)+60|0;c[M>>2]=0;N=c[r+(y*8432|0)+12>>2]|0;do{if((N|0)==16777219){if((c[q>>2]|0)!=2){B=21;break a}KIb(n,48,2490240,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;if((c[j>>2]|0)>15){c[K>>2]=(c[r+(y*8432|0)+20>>2]|0)+(c[D>>2]|0);c[M>>2]=1;c[h>>2]=2}O=c[C>>2]|0;if((O|0)<=256){P=x;Q=G;break}c[E>>2]=6;if((O|0)<=512){P=x;Q=G;break}c[E>>2]=7;P=x;Q=G}else if((N|0)==16777218){if((c[q>>2]|0)!=1){c[r+(y*8432|0)+68>>2]=1;c[h>>2]=2}KIb(n,48,2517456,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;P=x;Q=G}else if((N|0)==16777217){if((c[q>>2]|0)!=1){B=15;break a}KIb(n,48,2532768,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;P=x;Q=G}else if((N|0)==33554432){KIb(n,48,2479352,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;if((F|0)>3){O=G;R=je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;c[r+(y*8432|0)+36>>2]=R;U=R|x;V=G+4|0;W=R}else{U=x;V=G;W=c[r+(y*8432|0)+36>>2]|0}if((rGb(W,0)|0)<=1){c[C>>2]=H;P=U;Q=V;break}c[K>>2]=(c[r+(y*8432|0)+20>>2]|0)+(c[D>>2]|0);c[M>>2]=1;c[h>>2]=2;R=H>>1;c[C>>2]=R;if((R|0)<=256){P=U;Q=V;break}c[E>>2]=6;if((R|0)<=512){P=U;Q=V;break}c[E>>2]=7;P=U;Q=V}else{B=35;break a}}while(0);if((y|0)>1){if((c[C>>2]|0)!=(c[t>>2]|0)){B=38;break}}c[t>>2]=c[u>>2];c[r+(y*8432|0)+76>>2]=1<<c[E>>2];if((c[K>>2]|0)>53){B=40;break}X=c[r+(y*8432|0)+24>>2]|0;Y=c[M>>2]|0;if((X|0)>6){B=43;break}if((X|0)<(Y<<1|0)){B=43;break}R=c[D>>2]|0;if((R|0)>50){B=45;break}if((R|0)==0){B=47;break}c[r+(y*8432|0)+8272>>2]=r+(y*8432|0)+8288;c[r+(y*8432|0)+8276>>2]=r+(y*8432|0)+8324;c[r+(y*8432|0)+8280>>2]=r+(y*8432|0)+8360;c[r+(y*8432|0)+8284>>2]=r+(y*8432|0)+8396;Z=c[v>>2]|0;_=c[(c[m>>2]|0)+416>>2]|0;if(((c[h>>2]|0)+Z|0)>(_|0)){B=49;break}c[v>>2]=Z+1;R=y+1|0;if((R|0)>5){B=51;break}else{w=H;x=P;y=R;z=F;k=Q}}if((B|0)==11){KIb(n,16,2590888,(o=i,i=i+8|0,c[o>>2]=L,o)|0);i=o;p=-1094995529;i=b;return p|0}else if((B|0)==15){QIb(n,2551032,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==21){QIb(n,2503488,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==35){QIb(n,2469568,(o=i,i=i+8|0,c[o>>2]=N,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==38){KIb(n,16,2460368,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}else if((B|0)==40){QIb(n,2443720,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==43){KIb(n,16,2431200,(o=i,i=i+16|0,c[o>>2]=X,c[o+8>>2]=Y<<1,o)|0);i=o;p=-1094995529;i=b;return p|0}else if((B|0)==45){QIb(n,2420976,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==47){QIb(n,2411672,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==49){KIb(n,16,2404088,(o=i,i=i+16|0,c[o>>2]=Z,c[o+8>>2]=_,o)|0);i=o;p=-1094995529;i=b;return p|0}else if((B|0)==51){QIb(n,2396904,(o=i,i=i+8|0,c[o>>2]=5,o)|0);i=o;p=-1163346256;i=b;return p|0}else if((B|0)==52){while(1){B=0;_=A+63|0;g[5462e3+(_<<2)>>2]=+Jqc(1.0,A);g[5358736+(_<<2)>>2]=+S(+Jqc(1.0,A));_=A+1|0;if((_|0)<64){A=_;B=52}else{break}}B=(c[t>>2]|0)/8|0;A=e+2028|0;c[A>>2]=B;g[e+2032>>2]=+T(+(+g[1365552]),+(1.0/+(B|0)));_=1;Z=B;while(1){g[f+2032+(_<<2)>>2]=+T(+(+g[5462e3+(_+52<<2)>>2]),+(1.0/+(Z|0)));B=_+1|0;if((B|0)>=23){break}_=B;Z=c[A>>2]|0}c[e+22768>>2]=1635328;c[e+22772>>2]=1635288;c[e+22776>>2]=1635216;c[e+22780>>2]=1635080;c[e+22784>>2]=1634816;A=0;Z=0;do{Z=$2(f+1628+(A*20|0)|0,9,24,1511424+(A*24|0)|0,1,1,1510800+(A*48|0)|0,2,2,0,0,0,0)|0|Z;A=A+1|0;}while((A|0)<13);KIb(c[m>>2]|0,48,2376288,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;A=0;_=Z;do{_=$2(f+1888+(A*20|0)|0,c[258096+(A<<2)>>2]|0,c[258128+(A<<2)>>2]|0,c[1622288+(A<<2)>>2]|0,1,1,c[1620792+(A<<2)>>2]|0,2,2,0,0,0,0)|0|_;A=A+1|0;}while((A|0)<7);A=c[v>>2]|0;if((A|0)>0){Z=0;B=_;Y=A;while(1){if((c[f+22792+(Z*8432|0)+60>>2]|0)==1){A=c[f+22792+(Z*8432|0)+24>>2]|0;X=A-2|0;N=$2(f+22792+(Z*8432|0)+40|0,6,(1<<A)-1|0,c[1721352+(X<<2)>>2]|0,1,1,c[1721200+(X<<2)>>2]|0,2,2,0,0,0,0)|0|B;KIb(c[m>>2]|0,48,2369624,(o=i,i=i+8|0,c[o>>2]=Z,o)|0);i=o;$=N;aa=c[v>>2]|0}else{$=B;aa=Y}N=Z+1|0;if((N|0)<(aa|0)){Z=N;B=$;Y=aa}else{ba=$;break}}}else{ba=_}KIb(c[m>>2]|0,48,2354928,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;if((ba|0)!=0){p=ba;i=b;return p|0}ba=c[s>>2]|0;if(ba>>>0>2147483646>>>0){p=-22;i=b;return p|0}s=pJb(ba+19-((ba+3|0)%4|0)|0)|0;c[e+2124>>2]=s;if((s|0)==0){p=-12;i=b;return p|0}s=c[t>>2]|0;ba=hJb(s<<2)|0;_=ba;$=e+1624|0;aa=$;c[aa>>2]=_;if((ba|0)==0){p=-12;i=b;return p|0}G0a(_,s);if((s|0)>0){ca=+S(2.0/+(c[t>>2]|0));_=c[aa>>2]|0;aa=0;do{ba=_+(aa<<2)|0;g[ba>>2]=ca*+g[ba>>2];aa=aa+1|0;}while((aa|0)<(s|0))}aa=s>>>0>65535>>>0;_=aa?s>>>16:s;s=aa?16:0;if((_&65280|0)==0){da=s;ea=_}else{da=s|8;ea=_>>>8}_=da+1+(d[1359664+ea|0]|0)|0;ea=OPa(e+1560|0,_,1,30517578125.0e-15)|0;if((ea|0)!=0){mJb($);p=ea;i=b;return p|0}KIb(c[m>>2]|0,48,2382944,(o=i,i=i+8|0,c[o>>2]=_,o)|0);i=o;c[e>>2]=330;c[e+4>>2]=2;c[e+8>>2]=530;c[e+12>>2]=44;c[e+16>>2]=370;e=c[t>>2]|0;if(!((e|0)==256|(e|0)==512|(e|0)==1024)){QIb(n,2389880,(o=i,i=i+8|0,c[o>>2]=e,o)|0);i=o;p=-1163346256;i=b;return p|0}c[a+420>>2]=8;if((x|0)==0){o=(c[q>>2]|0)==2;q=a+448|0;c[q>>2]=o?3:4;c[q+4>>2]=o?0:0;p=0;i=b;return p|0}else{o=a+448|0;c[o>>2]=x;c[o+4>>2]=0;p=0;i=b;return p|0}}return 0}function y4(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;k=i;i=i+80|0;l=k|0;m=c[j+24>>2]|0;n=c[j+28>>2]|0;j=c[e+60>>2]|0;o=j;p=e+432|0;q=c[p>>2]|0;if((n|0)<(q|0)){r=n;i=k;return r|0}n=j+1556|0;do{if((c[n>>2]|0)>1){c[f+76>>2]=c[j+1292>>2];s=M4a(e,f,0)|0;if((s|0)<0){r=s;i=k;return r|0}else{t=c[f+64>>2]|0;u=c[p>>2]|0;break}}else{t=0;u=q}}while(0);q=j+22792|0;f=j+22796|0;c[f>>2]=u;u=j+22788|0;s=c[u>>2]|0;v=1;while(1){if((v|0)>=(s|0)){break}w=d[m+(v-s+(c[p>>2]|0))|0]<<1;c[q+(v*8432|0)+4>>2]=w;x=(c[f>>2]|0)-(w|1)|0;c[f>>2]=x;if((x|0)<0){y=10;break}else{v=v+1|0}}if((y|0)==10){KIb(e,48,2300824,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;r=-1094995529;i=k;return r|0}a:do{if((s|0)>0){v=e;f=j+10336|0;x=f;w=j+14432|0;A=(t|0)!=0;B=j+2144|0;C=B;D=j+1292|0;E=j+1560|0;F=j+1600|0;G=j+8|0;H=j+12|0;I=j+2028|0;J=j+16|0;K=j+1276|0;L=l;M=j+18528|0;N=j+1268|0;O=j+1284|0;P=j+4|0;Q=0;R=0;S=0;b:while(1){T=q+(Q*8432|0)|0;U=q+(Q*8432|0)+4|0;V=c[U>>2]|0;c[q+(Q*8432|0)+64>>2]=V<<3>>c[q+(Q*8432|0)+68>>2];W=T|0;c[W>>2]=S;X=q+(Q*8432|0)+60|0;Y=c[X>>2]|0;Z=c[p>>2]|0;KIb(v,48,2249488,(z=i,i=i+40|0,c[z>>2]=Q,c[z+8>>2]=V,c[z+16>>2]=Y,c[z+24>>2]=R,c[z+32>>2]=Z,z)|0);i=z;Z=c[U>>2]|0;mrc(f|0,0,4096)|0;Y=q+(Q*8432|0)+8272|0;A4(o,T,m+R|0,Y);do{if((c[X>>2]|0)==0){V=B4(o,T,x)|0;if((V|0)<0){r=V;y=64;break b}if((c[q+(Q*8432|0)+8>>2]|0)!=2){break}A4(o,T,m+(((Z|0)/2|0)+R)|0,q+(Q*8432|0)+8280|0);V=B4(o,T,w)|0;if((V|0)<0){r=V;y=64;break b}}else{mrc(L|0,0,80)|0;mrc(f|0,0,12432)|0;V=c[K>>2]|0;_=c[N>>2]|0;$=a[_+(V>>>3)|0]|0;aa=c[O>>2]|0;ba=((V|0)<(aa|0))+V|0;c[K>>2]=ba;da=q+(Q*8432|0)+20|0;ea=c[1635352+(c[da>>2]<<2)>>2]|0;fa=q+(Q*8432|0)+16|0;ga=c[1635352+((c[fa>>2]|0)-1<<2)>>2]|0;ha=ga-ea+1|0;c:do{if((ea|0)<=(ga|0)){ia=(ha|0)>0;if(($&255&128>>>((V&7)>>>0)|0)==0){if(!ia){break}ja=c[q+(Q*8432|0)+24>>2]|0;ka=0;la=ba;while(1){ma=_+(la>>>3)|0;na=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)>>>((32-ja|0)>>>0);ma=la+ja|0;la=aa>>>0>ma>>>0?ma:aa;c[K>>2]=la;if((na|0)==((1<<ja)-1|0)){y=23;break b}c[l+(ka+ea<<2)>>2]=na;ka=ka+1|0;if((ka|0)>=(ha|0)){break c}}}if(!ia){break}ka=c[q+(Q*8432|0)+44>>2]|0;ja=c[q+(Q*8432|0)+40>>2]|0;la=0;na=ba;do{ma=_+(na>>>3)|0;oa=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>((32-ja|0)>>>0);ma=b[ka+(oa<<2)>>1]|0;pa=b[ka+(oa<<2)+2>>1]|0;oa=pa<<16>>16;if(pa<<16>>16<0){pa=ja+na|0;qa=aa>>>0>pa>>>0?pa:aa;pa=_+(qa>>>3)|0;ra=((je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(qa&7)>>>((oa+32|0)>>>0))+ma|0;sa=b[ka+(ra<<2)+2>>1]|0;ta=b[ka+(ra<<2)>>1]|0;ua=qa}else{sa=oa;ta=ma;ua=na}ma=sa+ua|0;na=aa>>>0>ma>>>0?ma:aa;c[K>>2]=na;c[l+(la+ea<<2)>>2]=ta;la=la+1|0;}while((la|0)<(ha|0))}}while(0);ha=B4(o,T,M)|0;if((ha|0)<0){r=ha;y=64;break b}ha=c[da>>2]|0;if((ha|0)>0){ea=0;do{aa=ea*40|0;_=ea*20|0;ba=aa+20|0;V=0;do{$=V+_|0;g[o+10336+($<<2)>>2]=+g[o+18528+(V+aa<<2)>>2];g[o+14432+($<<2)>>2]=+g[o+18528+(ba+V<<2)>>2];V=V+1|0;}while((V|0)<20);ea=ea+1|0;}while((ea|0)<(ha|0))}ea=q+(Q*8432|0)+24|0;if((ha|0)<(c[fa>>2]|0)){va=ha}else{break}do{da=c[ea>>2]|0;V=c[l+(c[1635352+(va<<2)>>2]<<2)>>2]|0;ba=c[o+22768+(da-2<<2)>>2]|0;ue[c[P>>2]&3](o,T,va,+g[ba+(V+1<<2)>>2],+g[ba+((1<<da)-1-V<<2)>>2],M,x,w);va=va+1|0;}while((va|0)<(c[fa>>2]|0))}}while(0);T=q+(Q*8432|0)+80|0;if(A){wa=c[t+(c[W>>2]<<2)>>2]|0}else{wa=0}Z=c[D>>2]|0;ef[c[F>>2]&4095](E,C,x);mf[c[G>>2]&2047](o,o+2144+(Z<<2)|0,Y,T);fa=Y|0;ea=0;while(1){ha=c[fa>>2]|0;V=c[ha+(ea<<2)>>2]|0;da=ea+1|0;ba=c[ha+(da<<2)>>2]|0;if((ba|V|0)!=0){ha=o+2144+((ca(c[I>>2]|0,ea)|0)+Z<<2)|0;mf[c[H>>2]&2047](o,ha,V,ba)}if((da|0)<8){ea=da}else{break}}nrc(T|0,B|0,c[D>>2]<<2)|0;if((wa|0)!=0){re[c[J>>2]&1023](o,wa)}ea=q+(Q*8432|0)+8|0;do{if((c[ea>>2]|0)==2){if((c[X>>2]|0)==0){Z=q+(Q*8432|0)+8280|0;da=q+(Q*8432|0)+4176|0;if(A){xa=c[t+((c[W>>2]|0)+1<<2)>>2]|0}else{xa=0}ba=c[D>>2]|0;ef[c[F>>2]&4095](E,C,w);mf[c[G>>2]&2047](o,o+2144+(ba<<2)|0,Z,da);V=Z|0;Z=0;while(1){ha=c[V>>2]|0;aa=c[ha+(Z<<2)>>2]|0;_=Z+1|0;$=c[ha+(_<<2)>>2]|0;if(($|aa|0)!=0){ha=o+2144+((ca(c[I>>2]|0,Z)|0)+ba<<2)|0;mf[c[H>>2]&2047](o,ha,aa,$)}if((_|0)<8){Z=_}else{break}}nrc(da|0,B|0,c[D>>2]<<2)|0;if((xa|0)==0){break}re[c[J>>2]&1023](o,xa);break}else{Z=q+(Q*8432|0)+4176|0;if(A){ya=c[t+((c[W>>2]|0)+1<<2)>>2]|0}else{ya=0}ba=c[D>>2]|0;ef[c[F>>2]&4095](E,C,w);mf[c[G>>2]&2047](o,o+2144+(ba<<2)|0,Y,Z);V=0;while(1){_=c[fa>>2]|0;$=c[_+(V<<2)>>2]|0;aa=V+1|0;ha=c[_+(aa<<2)>>2]|0;if((ha|$|0)!=0){_=o+2144+((ca(c[I>>2]|0,V)|0)+ba<<2)|0;mf[c[H>>2]&2047](o,_,$,ha)}if((aa|0)<8){V=aa}else{break}}nrc(Z|0,B|0,c[D>>2]<<2)|0;if((ya|0)==0){break}re[c[J>>2]&1023](o,ya);break}}}while(0);fa=c[U>>2]|0;Y=(c[ea>>2]|0)+S|0;W=c[K>>2]|0;KIb(v,48,2207216,(z=i,i=i+24|0,c[z>>2]=Q,c[z+8>>2]=fa<<3,c[z+16>>2]=W,z)|0);i=z;W=Q+1|0;if((W|0)<(c[u>>2]|0)){Q=W;R=fa+R|0;S=Y}else{break a}}if((y|0)==23){KIb(c[j+20>>2]|0,16,2147192,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;r=-1094995529;i=k;return r|0}else if((y|0)==64){i=k;return r|0}}}while(0);y=c[n>>2]|0;if((y|0)<2){c[n>>2]=y+1;c[h>>2]=0;r=c[p>>2]|0;i=k;return r|0}else{c[h>>2]=1;r=c[p>>2]|0;i=k;return r|0}return 0}function z4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+60>>2]|0;e=a;KIb(e,48,2455600,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;mJb(d+1624|0);mJb(d+2124|0);PPa(d+1560|0);c3(d+1628|0);c3(d+1648|0);c3(d+1668|0);c3(d+1688|0);c3(d+1708|0);c3(d+1728|0);c3(d+1748|0);c3(d+1768|0);c3(d+1788|0);c3(d+1808|0);c3(d+1828|0);c3(d+1848|0);c3(d+1868|0);c3(d+1888|0);c3(d+1908|0);c3(d+1928|0);c3(d+1948|0);c3(d+1968|0);c3(d+1988|0);c3(d+2008|0);f=d+22788|0;if((c[f>>2]|0)<=0){KIb(e,48,2366128,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}g=d+22792|0;d=0;do{c3(g+(d*8432|0)+40|0);d=d+1|0;}while((d|0)<(c[f>>2]|0));KIb(e,48,2366128,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function A4(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=c[a+2124>>2]|0;h=b+64|0;b=c[h>>2]|0;i=g;j=e&3;k=e+(-j|0)|0;e=c[1585768+(j<<2)>>2]|0;l=j+3+((b|0)/8|0)|0;m=(l|0)/4|0;if((l|0)>3){l=0;do{c[i+(l<<2)>>2]=c[k+(l<<2)>>2]^e;l=l+1|0;}while((l|0)<(m|0));n=c[h>>2]|0}else{n=b}b=g+j|0;j=n>>>0>2147483639>>>0|(b|0)==0;g=j?0:b;b=j?0:n;c[a+1268>>2]=g;c[a+1280>>2]=b;n=b+8|0;j=a+1284|0;c[j>>2]=n;c[a+1272>>2]=g+(b+7>>3);h=a+1276|0;c[h>>2]=0;a=f|0;m=c[a>>2]|0;l=0;e=0;while(1){if((l|0)>=(b|0)){o=e;break}k=d[g+(e>>>3)|0]|0;i=((e|0)<(n|0))+e|0;c[h>>2]=i;if((k&128>>>((e&7)>>>0)|0)==0){o=i;break}else{l=l+1|0;e=i}}do{if((l|0)==0){p=0}else{e=0;b=l;i=o;k=n;while(1){q=b-1|0;r=g+(i>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(i&7)>>>29;r=i+3|0;t=k>>>0>r>>>0?r:k;c[h>>2]=t;r=d[g+(t>>>3)|0]|0;u=((t|0)<(k|0))+t|0;c[h>>2]=u;if((r&128>>>((t&7)>>>0)|0)==0){v=-1}else{t=g+(u>>>3)|0;r=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(u&7)>>>28;t=u+4|0;c[h>>2]=k>>>0>t>>>0?t:k;v=r-7|0}if((e|0)>(s|0)){w=e}else{r=e;while(1){t=r+1|0;c[m+(r<<2)>>2]=v;if((t|0)>(s|0)){break}else{r=t}}w=s+1|0}if((q|0)==0){break}e=w;b=q;i=c[h>>2]|0;k=c[j>>2]|0}if((w|0)<9){p=w;break}else{x=m}y=f+4|0;z=c[y>>2]|0;c[y>>2]=x;c[a>>2]=z;return}}while(0);mrc(m+(p<<2)|0,0,36-(p<<2)|0)|0;x=c[a>>2]|0;y=f+4|0;z=c[y>>2]|0;c[y>>2]=x;c[a>>2]=z;return}function B4(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;g=i;i=i+408|0;h=g|0;j=h;k=i;i=i+408|0;l=i;i=i+1024|0;m=i;i=i+80|0;n=i;i=i+80|0;o=i;i=i+512|0;p=o;q=i;i=i+512|0;r=q;s=i;i=i+408|0;mrc(p|0,0,512)|0;mrc(r|0,0,512)|0;t=a+1276|0;u=c[t>>2]|0;v=a+1284|0;w=c[v>>2]|0;x=a+1268|0;y=c[x>>2]|0;z=y+(u>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(u&7)>>>26;z=u+6|0;u=w>>>0>z>>>0?z:w;c[t>>2]=u;z=A-6|0;c[s>>2]=z;A=e+72|0;B=e+20|0;C=1;D=u;u=z;while(1){if((C|0)>=(c[A>>2]|0)){break}z=c[B>>2]|0;if((C|0)<(z<<1|0)){E=(C|0)<2?1:(C|0)/2|0}else{E=C-z|0}z=(E|0)>13?12:E-1|0;F=c[a+1628+(z*20|0)+4>>2]|0;G=c[a+1628+(z*20|0)>>2]|0;z=y+(D>>>3)|0;H=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(D&7)>>>((32-G|0)>>>0);z=b[F+(H<<2)>>1]|0;I=b[F+(H<<2)+2>>1]|0;H=I<<16>>16;if(I<<16>>16<0){I=D+G|0;G=w>>>0>I>>>0?I:w;I=y+(G>>>3)|0;J=((je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(G&7)>>>((H+32|0)>>>0))+z|0;K=b[F+(J<<2)+2>>1]|0;L=b[F+(J<<2)>>1]|0;M=G}else{K=H;L=z;M=D}z=K+M|0;H=w>>>0>z>>>0?z:w;c[t>>2]=H;z=u+L|0;N=z-12|0;c[s+(C<<2)>>2]=N;if((z+51|0)>>>0>126>>>0){O=9;break}else{C=C+1|0;D=H;u=N}}if((O|0)==9){KIb(c[a+20>>2]|0,16,2174864,(u=i,i=i+16|0,c[u>>2]=N,c[u+8>>2]=C,u)|0);i=u;P=-1094995529;i=g;return P|0}u=c[e+32>>2]|0;C=y+(D>>>3)|0;y=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)>>>((32-u|0)>>>0);C=D+u|0;u=w>>>0>C>>>0?C:w;c[t>>2]=u;c[a+1288>>2]=y;mrc(j|0,0,408)|0;mrc(k|0,0,408)|0;mrc(l|0,0,1024)|0;w=c[e+76>>2]|0;C=e+64|0;e=(c[C>>2]|0)-u|0;u=c[a+1292>>2]|0;if((e|0)>(u|0)){Q=(((e-u|0)*5|0|0)/8|0)+u|0}else{Q=e}e=c[A>>2]|0;u=(e|0)>0;D=Q-32|0;if(u){N=0;L=0;M=e;while(1){K=32-(c[s+(L<<2)>>2]|0)-32|0;E=(K|0)/2|0;if((K|0)<-1){R=0}else{R=(E|0)>7?7:E}S=(c[1489912+(R<<2)>>2]|0)+N|0;E=M-1|0;if((E|0)<=0){break}N=S;L=L+1|0;M=E}M=(S|0)<(D|0)?-32:0;S=0;L=0;N=e;while(1){R=16-(c[s+(L<<2)>>2]|0)+M|0;E=(R|0)/2|0;if((R|0)<-1){T=0}else{T=(E|0)>7?7:E}U=(c[1489912+(T<<2)>>2]|0)+S|0;E=N-1|0;if((E|0)<=0){break}S=U;L=L+1|0;N=E}N=((U|0)<(D|0)?0:16)|M;M=0;U=0;L=e;while(1){S=8-(c[s+(U<<2)>>2]|0)+N|0;T=(S|0)/2|0;if((S|0)<-1){V=0}else{V=(T|0)>7?7:T}W=(c[1489912+(V<<2)>>2]|0)+M|0;T=L-1|0;if((T|0)<=0){break}M=W;U=U+1|0;L=T}L=((W|0)<(D|0)?0:8)|N;N=0;W=0;U=e;while(1){M=4-(c[s+(W<<2)>>2]|0)+L|0;V=(M|0)/2|0;if((M|0)<-1){X=0}else{X=(V|0)>7?7:V}Y=(c[1489912+(X<<2)>>2]|0)+N|0;V=U-1|0;if((V|0)<=0){break}N=Y;W=W+1|0;U=V}U=((Y|0)<(D|0)?0:4)|L;L=0;Y=0;W=e;while(1){N=2-(c[s+(Y<<2)>>2]|0)+U|0;X=(N|0)/2|0;if((N|0)<-1){Z=0}else{Z=(X|0)>7?7:X}_=(c[1489912+(Z<<2)>>2]|0)+L|0;X=W-1|0;if((X|0)<=0){break}L=_;Y=Y+1|0;W=X}W=((_|0)<(D|0)?0:2)|U;U=0;_=0;Y=e;while(1){L=1-(c[s+(_<<2)>>2]|0)+W|0;Z=(L|0)/2|0;if((L|0)<-1){$=0}else{$=(Z|0)>7?7:Z}aa=(c[1489912+($<<2)>>2]|0)+U|0;Z=Y-1|0;if((Z|0)<=0){break}U=aa;_=_+1|0;Y=Z}Y=(aa|0)>=(D|0)|W;W=0;aa=0;while(1){_=Y-(c[s+(aa<<2)>>2]|0)|0;U=(_|0)/2|0;if((_|0)<-1){ba=0}else{ba=(U|0)>7?7:U}U=(c[1489912+(ba<<2)>>2]|0)+W|0;c[k+(aa<<2)>>2]=ba;c[h+(aa<<2)>>2]=ba;_=aa+1|0;if((_|0)<(e|0)){W=U;aa=_}else{da=U;ea=Y;break}}}else{Y=(D|0)>0;da=0;ea=((Y?0:16)|(Y?-32:0)|(Y?0:8)|(Y?0:4)|(Y?0:2)|Y&1)^1}a:do{if((w|0)>1){Y=Q<<1;D=da;aa=da;W=1;ba=w;U=w;while(1){if((D+aa|0)>(Y|0)){if(u){fa=-1;ga=0;ha=-999999}else{ia=U;break a}while(1){_=c[k+(ga<<2)>>2]|0;if((_|0)<7){$=(_*-2|0)-(c[s+(ga<<2)>>2]|0)+ea|0;_=($|0)<(ha|0);ja=_?ha:$;ka=_?fa:ga}else{ja=ha;ka=fa}_=ga+1|0;if((_|0)<(e|0)){fa=ka;ga=_;ha=ja}else{break}}if((ka|0)==-1){la=U;O=23;break a}c[l+(ba<<2)>>2]=ka;_=k+(ka<<2)|0;$=c[_>>2]|0;Z=$+1|0;L=D-(c[1489912+($<<2)>>2]|0)+(c[1489912+(Z<<2)>>2]|0)|0;c[_>>2]=Z;ma=U;na=ba+1|0;oa=aa;pa=L}else{if(u){qa=-1;ra=0;sa=999999}else{ia=U;break a}while(1){L=c[h+(ra<<2)>>2]|0;if((L|0)>0){Z=(L*-2|0)-(c[s+(ra<<2)>>2]|0)+ea|0;L=(Z|0)<(sa|0);ta=L?Z:sa;ua=L?ra:qa}else{ta=sa;ua=qa}L=ra+1|0;if((L|0)<(e|0)){qa=ua;ra=L;sa=ta}else{break}}if((ua|0)==-1){la=U;O=23;break a}L=U-1|0;c[l+(L<<2)>>2]=ua;Z=h+(ua<<2)|0;_=c[Z>>2]|0;$=_-1|0;X=aa-(c[1489912+(_<<2)>>2]|0)+(c[1489912+($<<2)>>2]|0)|0;c[Z>>2]=$;ma=L;na=ba;oa=X;pa=D}X=W+1|0;if((X|0)<(w|0)){D=pa;aa=oa;W=X;ba=na;U=ma}else{la=ma;O=23;break}}}else{la=w;O=23}}while(0);do{if((O|0)==23){if(!u){ia=la;break}nrc(r|0,j|0,(e|0)>1?e<<2:4)|0;ia=la}}while(0);la=w-1|0;if((la|0)>0){nrc(p|0,l+(ia<<2)|0,(la|0)>1?la<<2:4)|0}if((y|0)>0){la=0;while(1){ia=q+(c[o+(la<<2)>>2]<<2)|0;l=c[ia>>2]|0;p=l+1|0;c[ia>>2]=p>>>0>8>>>0?l:p;p=la+1|0;if((p|0)<(y|0)){la=p}else{va=0;break}}}else{va=0}while(1){if((va|0)>=(e|0)){break}if((c[q+(va<<2)>>2]|0)>7){P=-1094995529;O=69;break}else{va=va+1|0}}if((O|0)==69){i=g;return P|0}va=m;e=n;if(!u){P=0;i=g;return P|0}u=a|0;la=m|0;y=n|0;o=0;while(1){p=c[q+(o<<2)>>2]|0;do{if((p|0)<7){l=c[264408+(p<<2)>>2]|0;ia=a+1888+(p*20|0)+4|0;w=a+1888+(p*20|0)|0;j=c[202600+(p<<2)>>2]|0;r=c[x>>2]|0;ma=c[1061704+(p<<2)>>2]|0;na=(c[1034736+(p<<2)>>2]|0)+1|0;oa=c[v>>2]|0;pa=0;ua=0;h=c[t>>2]|0;while(1){ta=c[ia>>2]|0;sa=c[w>>2]|0;ra=r+(h>>>3)|0;qa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(h&7)>>>((32-sa|0)>>>0);ra=b[ta+(qa<<2)>>1]|0;ea=b[ta+(qa<<2)+2>>1]|0;qa=ea<<16>>16;do{if(ea<<16>>16<0){ka=sa+h|0;k=oa>>>0>ka>>>0?ka:oa;ka=r+(k>>>3)|0;ja=((je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(k&7)>>>((qa+32|0)>>>0))+ra|0;ka=b[ta+(ja<<2)>>1]|0;ha=b[ta+(ja<<2)+2>>1]|0;ja=ha<<16>>16;if(!(ha<<16>>16<0)){wa=ja;xa=ka;ya=k;break}ha=k-qa|0;k=oa>>>0>ha>>>0?ha:oa;ha=r+(k>>>3)|0;ga=((je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(k&7)>>>((ja+32|0)>>>0))+ka|0;wa=b[ta+(ga<<2)+2>>1]|0;xa=b[ta+(ga<<2)>>1]|0;ya=k}else{wa=qa;xa=ra;ya=h}}while(0);ra=wa+ya|0;qa=oa>>>0>ra>>>0?ra:oa;c[t>>2]=qa;ra=(c[C>>2]|0)<(qa|0);ta=ca(pa,l)|0;sa=ra?0:xa;ea=l;while(1){k=ea-1|0;ga=(ca(sa,ma)|0)/1048576|0;c[m+(k+ta<<2)>>2]=sa-(ca(ga,na)|0);if((k|0)>0){sa=ga;ea=k}else{break}}ea=0;sa=ra?1:ua;k=qa;while(1){ga=ea+ta|0;do{if((c[m+(ga<<2)>>2]|0)==0){c[n+(ga<<2)>>2]=0;za=sa;Aa=k}else{if((k|0)<(c[C>>2]|0)){ka=d[r+(k>>>3)|0]<<(k&7)>>>7;ja=((k|0)<(oa|0))+k|0;c[t>>2]=ja;c[n+(ga<<2)>>2]=ka&1;za=sa;Aa=ja;break}else{c[n+(ga<<2)>>2]=0;za=1;Aa=k;break}}}while(0);ga=ea+1|0;if((ga|0)<(l|0)){ea=ga;sa=za;k=Aa}else{break}}k=pa+1|0;if((k|0)<(j|0)){pa=k;ua=za;h=Aa}else{break}}if((za|0)==0){if((p|0)>6){Ba=p;O=67;break}else{Ca=p;break}}h=c[A>>2]|0;if((h|0)>0){Da=0}else{Ba=7;O=67;break}while(1){c[q+(Da+o<<2)>>2]=7;ua=Da+1|0;if((ua|0)<(h|0)){Da=ua}else{Ba=7;O=67;break}}}else{Ba=p;O=67}}while(0);if((O|0)==67){O=0;mrc(va|0,0,80)|0;mrc(e|0,0,80)|0;Ca=Ba}_e[c[u>>2]&511](a,Ca,c[s+(o<<2)>>2]|0,la,y,f+((o*20|0)<<2)|0);p=o+1|0;if((p|0)<(c[A>>2]|0)){o=p}else{P=0;break}}i=g;return P|0}function C4(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0;i=1531528+(b<<2)|0;j=a+1552|0;k=5358736+(d+63<<2)|0;d=0;do{l=c[e+(d<<2)>>2]|0;do{if((l|0)==0){m=+g[i>>2];n=c[j>>2]|0;c[a+1296+((n&63)<<2)>>2]=(c[a+1296+((n+9&63)<<2)>>2]|0)+(c[a+1296+((n+40&63)<<2)>>2]|0);n=c[j>>2]|0;c[j>>2]=n+1;if(!((c[a+1296+((n&63)<<2)>>2]|0)>-1)){o=m;break}o=-0.0-m}else{m=+g[688328+(b*56|0)+(l<<2)>>2];if((c[f+(d<<2)>>2]|0)==0){o=m;break}o=-0.0-m}}while(0);g[h+(d<<2)>>2]=o*+g[k>>2];d=d+1|0;}while((d|0)<20);return}function D4(a,b,d,e,f,h,i,j){a=a|0;b=b|0;d=d|0;e=+e;f=+f;h=h|0;i=i|0;j=j|0;var k=0,l=0;a=((c[b+20>>2]|0)+d|0)*20|0;b=d*20|0;d=0;do{k=h+(a+d<<2)|0;l=d+b|0;g[i+(l<<2)>>2]=+g[k>>2]*e;g[j+(l<<2)>>2]=+g[k>>2]*f;d=d+1|0;}while((d|0)<20);return}function E4(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0.0,h=0,i=0;f=+g[5462e3+((c[c[d+4>>2]>>2]|0)+63<<2)>>2];d=c[a+1292>>2]|0;if((d|0)<=0){return}h=c[a+1624>>2]|0;a=0;do{i=b+(a<<2)|0;g[i>>2]=f*+g[i>>2]*+g[h+(a<<2)>>2]- +g[e+(a<<2)>>2]*+g[h+(d+~a<<2)>>2];a=a+1|0;}while((a|0)<(d|0));return}function F4(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0.0,h=0,i=0,j=0,k=0.0,l=0.0,m=0;f=+g[5462e3+(d+63<<2)>>2];if((d|0)==(e|0)){h=c[a+2028>>2]|0;if((h|0)>0){i=0}else{return}do{j=b+(i<<2)|0;g[j>>2]=f*+g[j>>2];i=i+1|0;}while((i|0)<(h|0));return}else{k=+g[a+2032+(11-d+e<<2)>>2];e=c[a+2028>>2]|0;if((e|0)>0){l=f;m=0}else{return}while(1){a=b+(m<<2)|0;g[a>>2]=l*+g[a>>2];a=m+1|0;if((a|0)<(e|0)){l=k*l;m=a}else{break}}return}}function G4(a,b){a=a|0;b=b|0;var d=0;d=c[a+1292>>2]|0;kf[c[a+1128>>2]&3](b,a+2144+(d<<2)|0,-1.0,1.0,d+7&-8);return}function H4(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[a+140>>2]=0;d=a+104|0;do{if((c[d>>2]|0)==1){e=a+108|0;if((c[e>>2]|0)!=1e6){break}c[d>>2]=1;c[e>>2]=60}}while(0);d=UHb()|0;c[b>>2]=d;return((d|0)==0?-12:0)|0}function I4(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;h=i;j=c[g+24>>2]|0;k=c[b+60>>2]|0;l=c[k>>2]|0;m=g+28|0;g=c[m>>2]|0;do{if((g|0)>=64){if((a[j]|0)!=25){break}if((a[j+1|0]|0)!=104){break}n=j+17|0;o=a[n]|0;if(!((o&255)>>>0<2>>>0)){break}p=a[j+18|0]|0;if(!((p&255)>>>0<2>>>0)){break}q=j+28|0;r=a[q]|0;if(!((r&255)>>>0<2>>>0)){break}s=a[j+29|0]|0;if(!((s&255)>>>0<2>>>0)){break}if(o<<24>>24==1){KIb(b,16,2366056,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1163346256;i=h;return u|0}if(p<<24>>24==1){KIb(b,16,2300760,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1163346256;i=h;return u|0}if(s<<24>>24==1){KIb(b,16,2249456,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1163346256;i=h;return u|0}s=l+88|0;if(r<<24>>24==0){c[s>>2]=1;c[l+84>>2]=1}else{c[s>>2]=2;c[l+84>>2]=0}s=N4a(b,l)|0;if((s|0)<0){u=s;i=h;return u|0}s=l+72|0;a:do{if((c[s>>2]|0)>0){r=l+32|0;p=l|0;o=l+36|0;v=l+4|0;w=l+40|0;x=l+8|0;y=b;z=g-64|0;A=j+64|0;B=0;while(1){C=A;D=(d[C]|d[C+1|0]<<8)<<16>>16&65535;if((z|0)<(D|0)){E=22;break}C=D-1|0;F=A+(D+1)|0;if(!((a[F]|0)==-3)){E=24;break}G=c[r>>2]|0;H=ca(G,B)|0;I=c[p>>2]|0;J=I+H|0;K=B>>1;L=c[o>>2]|0;M=ca(L,K)|0;N=c[v>>2]|0;O=c[w>>2]|0;P=ca(O,K)|0;K=c[x>>2]|0;Q=I+(G-1+H)|0;H=N+(L-1+M)|0;L=K+(O-1+P)|0;O=(a[n]|0)==0;b:do{if((B&1|0)==0){if(!O){break}G=D-4|0;if((G|0)>0){R=J;S=N+M|0;T=K+P|0;U=0}else{break}while(1){I=R+1|0;if(I>>>0>Q>>>0|S>>>0>H>>>0|T>>>0>L>>>0){break}V=a[A+(U+2)|0]|0;do{if((V&1)==0){E=41}else{if((a[q]|0)!=1){E=41;break}W=(V&255)>>>1&255;X=W>>>1;Y=U+1|0;Z=T+X|0;_=S+X|0;$=R+W|0}}while(0);if((E|0)==41){E=0;a[R]=V;a[S]=a[A+(U+3)|0]|0;W=U+4|0;a[I]=a[A+W|0]|0;a[T]=a[A+(U+5)|0]|0;Y=W;Z=T+1|0;_=S+1|0;$=R+2|0}if((Y|0)<(G|0)){R=$;S=_;T=Z;U=Y}else{break b}}KHb(l,1);KIb(y,24,2147152,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{if(O&(C|0)>0){aa=J;ba=0}else{break}while(1){if(aa>>>0>Q>>>0){break}G=a[A+(ba+2)|0]|0;do{if((G&1)==0){E=32}else{if((a[q]|0)!=1){E=32;break}da=aa+((G&255)>>>1&255)|0}}while(0);if((E|0)==32){E=0;a[aa]=G;da=aa+1|0}I=ba+1|0;if((I|0)<(C|0)){aa=da;ba=I}else{break b}}KHb(l,1);KIb(y,24,2147152,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}}while(0);C=B+1|0;if((C|0)<(c[s>>2]|0)){z=z-D|0;A=A+(D+2)|0;B=C}else{break a}}if((E|0)==22){KHb(l,1);KIb(y,24,2207184,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((E|0)==24){KHb(l,1);B=d[F]|0;KIb(y,24,2174792,(t=i,i=i+16|0,c[t>>2]=D,c[t+8>>2]=B,t)|0);i=t;break}}}while(0);c[f>>2]=1;s=YHb(e,c[k>>2]|0)|0;if((s|0)<0){u=s;i=h;return u|0}u=c[m>>2]|0;i=h;return u|0}}while(0);KIb(b,16,2455520,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}function J4(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function K4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+60>>2]|0;e=a+792|0;f=c[e>>2]|0;if((f|0)==24){c[a+140>>2]=3}else if((f|0)==32){c[a+140>>2]=30}else if((f|0)==16){c[a+140>>2]=46}else{KIb(a,16,2207136,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-1094995529;i=b;return h|0}c[d+12>>2]=f;f=(ca(c[e>>2]|0,c[a+120>>2]|0)|0)/8|0;c[d+4>>2]=f;e=c[a+124>>2]|0;c[d+8>>2]=e;j=ca(f+3&-4,e)|0;c[d+16>>2]=j;e=hJb(j+12|0)|0;c[d+20>>2]=e;if((e|0)==0){KIb(a,16,2174752,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-12;i=b;return h|0}else{g=UHb()|0;c[d>>2]=g;h=(g|0)==0?-12:0;i=b;return h|0}return 0}function L4(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;if((n|0)<2){KIb(b,16,2455496,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}q=g;r=N4a(b,c[q>>2]|0)|0;if((r|0)<0){p=r;i=h;return p|0}r=(d[m]|0)>>>1&7;do{if((r|0)==1){c[l>>2]=c[g+16>>2];if((Aqc(c[g+20>>2]|0,l,m+2|0,n-2|0)|0)==0){break}KIb(b,16,2300720,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}else if((r|0)==0){c[j>>2]=c[g+16>>2];c[k>>2]=n-2;if((SIb(c[g+20>>2]|0,j,m+2|0,k)|0)==0){break}KIb(b,16,2366024,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}else{KIb(b,16,2249408,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}}while(0);o=c[q>>2]|0;b=o+88|0;do{if((a[m]&1)==0){c[b>>2]=2;c[o+84>>2]=0;k=c[g+4>>2]|0;j=c[g+8>>2]|0;r=o+32|0;if((j|0)==0){break}l=k+3&-4;if((k|0)==0){break}s=(c[o>>2]|0)+(ca(c[r>>2]|0,j-1|0)|0)|0;t=j;j=c[g+20>>2]|0;u=s;while(1){s=k;v=j;w=u;while(1){a[w]=(a[w]|0)+(a[v]|0);x=s-1|0;if((x|0)==0){break}else{s=x;v=v+1|0;w=w+1|0}}w=t-1|0;if((w|0)==0){break}else{t=w;j=j+l|0;u=u+(-(c[r>>2]|0)|0)|0}}}else{c[b>>2]=1;c[o+84>>2]=1;r=c[g+4>>2]|0;u=c[g+8>>2]|0;l=r+3&-4;j=o+32|0;if((u|0)==0){break}t=ca(c[j>>2]|0,u-1|0)|0;k=u;u=c[g+20>>2]|0;w=(c[o>>2]|0)+t|0;while(1){nrc(w|0,u|0,r)|0;t=k-1|0;if((t|0)==0){break}else{k=t;u=u+l|0;w=w+(-(c[j>>2]|0)|0)|0}}}}while(0);c[f>>2]=1;f=YHb(e,c[q>>2]|0)|0;p=(f|0)<0?f:n;i=h;return p|0}function M4(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+20|0);VHb(b);return 0}function N4(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;d=c[a+120>>2]|0;c[b+4>>2]=d;if((d&3|0)!=0){e=-1094995529;return e|0}c[b+8>>2]=c[a+124>>2];e=0;return e|0}function O4(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=e;m=j+16|0;n=g+8|0;o=c[n>>2]|0;p=g+4|0;g=c[p>>2]|0;q=ca(o<<1,g+1&-2)|0;r=(c[b+48>>2]|0)==124;s=r?m:j;t=r?j+32|0:m;m=(ca((g*3|0|0)/4|0,o)|0)+48|0;do{if((k|0)==(m|0)){c[b+140>>2]=7}else{if((k|0)==(q|0)){c[b+140>>2]=17;break}KIb(b,16,2300664,(o=i,i=i+16|0,c[o>>2]=k,c[o+8>>2]=m,o)|0);i=o;u=-1094995529;i=h;return u|0}}while(0);m=M4a(b,l,0)|0;if((m|0)<0){u=m;i=h;return u|0}m=c[e>>2]|0;l=c[e+4>>2]|0;b=c[e+8>>2]|0;a:do{if((k|0)==(q|0)){o=(c[p>>2]<<1)+2&-4;g=e+32|0;if((k|0)<=0){break}r=c[g>>2]|0;v=0;w=m+(ca(c[n>>2]|0,r)|0)|0;x=r;while(1){r=w+(-x|0)|0;nrc(r|0,j+v|0,o)|0;y=v+o|0;if((y|0)>=(k|0)){break a}v=y;w=r;x=c[g>>2]|0}}else{g=e+32|0;if((ca(c[g>>2]|0,c[n>>2]|0)|0)<=0){break}x=e+36|0;w=e+40|0;v=0;o=0;r=48;y=0;while(1){z=a[j+r|0]|0;A=z&-16;a[l+o|0]=A;B=(z&255)<<4;a[m+y|0]=B;z=a[j+(r+1)|0]|0;C=z&-16;a[b+v|0]=C;D=(d[s+(z&15)|0]|0)+B|0;a[m+(y+1)|0]=D;B=d[j+(r+2)|0]|0;z=(d[s+(B&15)|0]|0)+D|0;a[m+(y+2)|0]=z;D=z+(d[s+(B>>>4)|0]|0)&255;a[m+(y+3)|0]=D;B=c[p>>2]|0;z=(B|0)/4|0;E=y+4|0;F=r+3|0;G=z-1|0;H=o+1|0;I=v+1|0;if((G|0)==0){J=E;K=F;L=H;M=I;N=B}else{B=v+z|0;O=z*3|0;P=z<<2;Q=D;D=A;A=C;C=r;R=y;S=E;E=F;F=G;G=H;H=I;while(1){I=d[j+E|0]|0;T=(a[t+(I>>>4)|0]|0)+D&255;a[l+G|0]=T;U=(a[s+(I&15)|0]|0)+Q&255;a[m+S|0]=U;I=d[j+(C+4)|0]|0;V=(a[j+(I>>>4|32)|0]|0)+A&255;a[b+H|0]=V;W=(a[s+(I&15)|0]|0)+U&255;a[m+(R+5)|0]=W;U=d[j+(C+5)|0]|0;I=(a[s+(U&15)|0]|0)+W&255;a[m+(R+6)|0]=I;W=I+(a[s+(U>>>4)|0]|0)&255;a[m+(R+7)|0]=W;U=F-1|0;if((U|0)==0){break}else{Q=W;D=T;A=V;C=E;R=S;S=S+4|0;E=E+3|0;F=U;G=G+1|0;H=H+1|0}}J=y+P|0;K=r+O|0;L=o+z|0;M=B;N=c[p>>2]|0}H=c[g>>2]|0;G=H+J-N|0;F=(N|0)/-4|0;if((G|0)<(ca(H,c[n>>2]|0)|0)){v=F+M+(c[w>>2]|0)|0;o=(c[x>>2]|0)+L+F|0;r=K;y=G}else{break}}}}while(0);c[f>>2]=1;u=k;i=h;return u|0}function P4(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=i;j=e>>>0>g>>>0?g:e;e=c;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=je(k|0)|0;l=k&65535;if((e|0)==(-25230976|0)){m=j+1>>1;if((m|0)>0){n=1;o=c;p=f;q=l}else{r=j;i=h;return r|0}while(1){s=o+2|0;b[p>>1]=he(q|0)|0;if((n|0)>=(m|0)){r=j;break}n=n+1|0;o=s;p=p+2|0;q=b[s>>1]|0}i=h;return r|0}else if((e|0)==536864768|(e|0)==(-14745368|0)){q=(g|0)<0?0:f;g=0;p=j+1>>1;do{if((p|0)>0){a:do{if((k|0)==15269663){o=q;n=32;m=c;s=1;t=0;u=l;while(1){v=(he(u|0)|0)&16383;if((n|0)>14){w=n-14|0;x=t<<14|v;z=o}else{A=o;y=je(v>>>((14-n|0)>>>0)|t<<n|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;w=n+18|0;x=v;z=o+4|0}g=x;v=m+2|0;if((s|0)>=(p|0)){B=z;C=w;D=x;break a}A=v;o=z;n=w;m=v;s=s+1|0;t=x;u=(d[A]|d[A+1|0]<<8)<<16>>16}}else{u=q;t=32;s=c;m=1;n=0;o=l;while(1){A=o&16383;if((t|0)>14){E=t-14|0;F=n<<14|A;G=u}else{v=u;y=je(A>>>((14-t|0)>>>0)|n<<t|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;E=t+18|0;F=A;G=u+4|0}g=F;A=s+2|0;if((m|0)>=(p|0)){B=G;C=E;D=F;break a}v=A;u=G;t=E;s=A;m=m+1|0;n=F;o=(d[v]|d[v+1|0]<<8)<<16>>16}}}while(0);if((C|0)>=32){H=B;break}o=D<<C;g=o;n=((31-C|0)>>>3)+1|0;m=o>>>24&255;o=C;s=B;while(1){a[s]=m;t=g;g=t<<8;u=o+8|0;if((u|0)<32){m=t>>>16&255;o=u;s=s+1|0}else{break}}H=B+n|0}else{H=q}}while(0);g=0;r=H-q<<3>>3;i=h;return r|0}else if((e|0)==2147385345){nrc(f|0,c|0,j)|0;r=j;i=h;return r|0}else{r=-1094995529;i=h;return r|0}return 0}function Q4(a){a=a|0;c[(c[a>>2]|0)+40>>2]=0;return 0}function R4(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=i;i=i+48|0;l=k|0;m=k+32|0;n=k+40|0;c[m>>2]=h;c[n>>2]=j;o=c[b>>2]|0;do{if((c[b+176>>2]&1|0)==0){p=o;q=o+20|0;r=c[q>>2]|0;s=o+16|0;t=c[s>>2]|0;a:do{if((r|0)==0){if((j|0)<=0){u=t;v=0;w=31;break}x=j-2|0;y=o+40|0;z=0;A=t;while(1){B=d[h+z|0]|A<<8;do{if((B|0)==(-25230976|0)|(B|0)==2147385345|(B|0)==1683496997){w=12}else if((B|0)==536864768){if((z|0)>=(x|0)){break}if((a[h+(z+1)|0]|0)!=7){break}if((a[h+(z+2)|0]&-16)<<24>>24==-16){w=12}}else if((B|0)==(-14745368|0)){if((z|0)>=(x|0)){break}if(!((a[h+(z+1)|0]&-16)<<24>>24==-16)){break}if((a[h+(z+2)|0]|0)==7){w=12}}}while(0);if((w|0)==12){w=0;C=c[y>>2]|0;if((B|0)==(C|0)){break}if((C|0)==1683496997|(C|0)==0){break}}C=z+1|0;if((C|0)<(j|0)){z=C;A=B}else{u=B;v=0;w=31;break a}}c[y>>2]=B;D=B;E=z+1|0;F=1;w=16}else{D=t;E=0;F=r;w=16}}while(0);b:do{if((w|0)==16){if((E|0)>=(j|0)){u=D;v=F;w=31;break}r=o+44|0;t=o+52|0;A=o+40|0;x=o+48|0;C=j-2|0;G=E;H=D;I=c[r>>2]|0;c:while(1){J=I+1|0;c[r>>2]=J;K=d[h+G|0]|H<<8;do{if((K|0)==(-14745368|0)){if((G|0)>=(C|0)){break}if(!((a[h+(G+1)|0]&-16)<<24>>24==-16)){break}if((a[h+(G+2)|0]|0)==7){w=27}}else if((K|0)==(-25230976|0)|(K|0)==2147385345){w=27}else if((K|0)==536864768){if((G|0)>=(C|0)){break}if((a[h+(G+1)|0]|0)!=7){break}if((a[h+(G+2)|0]&-16)<<24>>24==-16){w=27}}else if((K|0)==1683496997){if((c[t>>2]|0)!=0){w=27;break}c[t>>2]=J;w=27}}while(0);do{if((w|0)==27){w=0;L=c[A>>2]|0;if(!((K|0)==(L|0)|(L|0)==1683496997)){break}if((c[x>>2]|0)<=(J|0)){break c}}}while(0);L=G+1|0;if((L|0)<(j|0)){G=L;H=K;I=J}else{u=K;v=F;w=31;break b}}c[q>>2]=0;c[s>>2]=-1;c[r>>2]=0;M=G-3|0}}while(0);if((w|0)==31){c[q>>2]=v;c[s>>2]=u;M=-100}if((IWa(p,M,m,n)|0)>=0){N=M;O=c[m>>2]|0;P=c[n>>2]|0;break}c[f>>2]=0;c[g>>2]=0;Q=c[n>>2]|0;i=k;return Q|0}else{N=j;O=h;P=j}}while(0);j=o+48|0;o=l|0;mrc(o|0,0,28)|0;do{if((P|0)<12){w=41}else{if((P4(O,12,o,12)|0)<0){w=41;break}h=l+4|0;M=((je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)>>>18&127)+1|0;if(M>>>0<8>>>0){w=41;break}h=l+5|0;u=((je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)>>>12&16383)+1|0;c[j>>2]=u;if(u>>>0<95>>>0){w=41;break}u=l+8|0;h=c[1965816+(((d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>2&15)<<2)>>2]|0;if((h|0)==0){w=41;break}c[b+304>>2]=((M|0)/8|0)<<8;c[e+412>>2]=h}}while(0);if((w|0)==41){c[b+304>>2]=0}c[f>>2]=c[m>>2];c[g>>2]=c[n>>2];Q=N;i=k;return Q|0}function S4(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=c[f+60>>2]|0;c[g+4>>2]=f;if(!(a[1611848]|0)){c[2442996]=1;c[2443005]=2;h=0;i=0;while(1){j=i&65535;c[9772028+(h*20|0)>>2]=9677496+(j<<2);k=h+1|0;l=b[1611592+(k<<1)>>1]|0;c[9772036+(h*20|0)>>2]=(l&65535)-j;$2(9772024+(h*20|0)|0,d[1911016+h|0]|0,12,1911144+(h*12|0)|0,1,1,1911024+(h*24|0)|0,2,2,0,0,0,4)|0;if((k|0)<5){h=k;i=l}else{break}}c[2419324]=-64;c[2419333]=2;i=0;h=1794;do{l=h&65535;c[9677340+(i*20|0)>>2]=9677496+(l<<2);h=b[1611592+(i+6<<1)>>1]|0;c[9677348+(i*20|0)>>2]=(h&65535)-l;$2(9677336+(i*20|0)|0,9,129,603688+(i*129|0)|0,1,1,602392+(i*258|0)|0,2,2,0,0,0,4)|0;i=i+1|0;}while((i|0)<5);c[2418724]=0;c[2418733]=1;c[2418735]=9698952;c[2418737]=8;$2(9674936,3,4,307648,1,1,307616,2,2,0,0,0,4)|0;c[2418740]=9698984;c[2418742]=8;$2(9674956,3,4,307652,1,1,307624,2,2,0,0,0,4)|0;c[2418745]=9699016;c[2418747]=8;$2(9674976,3,4,307656,1,1,307632,2,2,0,0,0,4)|0;c[2418750]=9699048;c[2418752]=4;$2(9674996,2,4,307660,1,1,307640,2,2,0,0,0,4)|0;i=0;h=14;while(1){l=1906560+i|0;k=i+1|0;j=9675096+(k*200|0)|0;m=9675132+(k*200|0)|0;n=1906544+i|0;o=0;p=h;while(1){q=c[1906648+(i<<5)+(o<<2)>>2]|0;if((q|0)==0){r=p;break}c[j>>2]=a[l]|0;c[m>>2]=(o|0)>4?2:1;s=e[1611592+(p<<1)>>1]|0;c[9675136+(k*200|0)+(o*20|0)+4>>2]=9677496+(s<<2);t=p+1|0;c[9675136+(k*200|0)+(o*20|0)+12>>2]=(e[1611592+(t<<1)>>1]|0)-s;$2(9675136+(k*200|0)+(o*20|0)|0,d[1906576+(i*7|0)+o|0]|0,d[n]|0,c[1906968+(i<<5)+(o<<2)>>2]|0,1,1,q,2,2,0,0,0,4)|0;q=o+1|0;if((q|0)<7){o=q;p=t}else{r=t;break}}if((k|0)<10){i=k;h=r}else{break}}a[1611848]=1}qHb(g+291844|0,c[f+88>>2]&8388608);OPa(g+291880|0,6,1,1.0)|0;N2a(g+291944|0);Z4(g+291948|0);yfa(g+291964|0,f);c[f+420>>2]=8;if((c[f+440>>2]|0)==2){g=f+456|0;c[g>>2]=3;c[g+4>>2]=0}g=f+416|0;if((c[g>>2]|0)<=2){return 0}r=f+456|0;if(!((c[r>>2]|0)==3&(c[r+4>>2]|0)==0)){return 0}c[g>>2]=2;return 0}function T4(b,f,h,j){b=b|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ba=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0.0,$c=0.0,ad=0,bd=0,cd=0,dd=0,ed=0;k=i;i=i+6432|0;l=k|0;m=k+32|0;n=k+4128|0;o=k+4256|0;p=k+6304|0;q=k+6336|0;r=k+6352|0;s=k+6368|0;t=k+6400|0;u=f;v=c[j+24>>2]|0;w=c[j+28>>2]|0;j=c[b+60>>2]|0;x=j;y=j+290800|0;c[y>>2]=0;z=j+269256|0;A=P4(v,w,z,20480)|0;v=j+290760|0;c[v>>2]=A;if((A|0)==-1094995529){KIb(b,16,2455464,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=k;return C|0}D=A<<3;A=D>>>0>2147483639>>>0|(z|0)==0;E=A?0:z;z=A?0:D;D=j+290768|0;A=j+290780|0;F=z+8|0;H=j+290784|0;I=j+290776|0;c[D>>2]=E;c[A>>2]=z;c[H>>2]=F;c[j+290772>>2]=E+(z>>3);z=(F|0)<32?F:32;c[I>>2]=z;J=E+(z>>>3)|0;K=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>7&1;J=z|1;z=F>>>0>J>>>0?J:F;c[I>>2]=z;c[j+8>>2]=K;K=E+(z>>>3)|0;J=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(z&7)>>>27;K=z+5|0;z=F>>>0>K>>>0?K:F;c[I>>2]=z;c[j+12>>2]=J+1;J=E+(z>>>3)|0;K=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(z&7)>>>31;J=z+1|0;z=F>>>0>J>>>0?J:F;c[I>>2]=z;c[j+16>>2]=K;J=E+(z>>>3)|0;L=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(z&7)>>>25;J=z+7|0;z=F>>>0>J>>>0?J:F;c[I>>2]=z;J=j+20|0;c[J>>2]=L+1;L=E+(z>>>3)|0;M=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(z&7)>>>18;L=z+14|0;z=F>>>0>L>>>0?L:F;c[I>>2]=z;L=M+1|0;M=j+24|0;c[M>>2]=L;if(L>>>0<95>>>0){C=-1094995529;i=k;return C|0}L=E+(z>>>3)|0;N=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(z&7)>>>26;L=z+6|0;z=F>>>0>L>>>0?L:F;c[I>>2]=z;L=j+28|0;c[L>>2]=N;O=E+(z>>>3)|0;P=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(z&7)>>>28;O=z+4|0;z=F>>>0>O>>>0?O:F;c[I>>2]=z;O=c[1965816+(P<<2)>>2]|0;P=j+32|0;c[P>>2]=O;if((O|0)==0){C=-1094995529;i=k;return C|0}O=E+(z>>>3)|0;Q=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(z&7)>>>27;O=z+5|0;c[j+40>>2]=Q;z=j+36|0;c[z>>2]=c[1614248+(Q<<2)>>2];Q=(F>>>0>O>>>0?O:F)+1|0;O=F>>>0>Q>>>0?Q:F;c[I>>2]=O;Q=E+(O>>>3)|0;R=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>31;Q=O+1|0;O=F>>>0>Q>>>0?Q:F;c[I>>2]=O;c[j+44>>2]=R;R=E+(O>>>3)|0;Q=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>31;R=O+1|0;O=F>>>0>R>>>0?R:F;c[I>>2]=O;c[j+48>>2]=Q;Q=E+(O>>>3)|0;R=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>31;Q=O+1|0;O=F>>>0>Q>>>0?Q:F;c[I>>2]=O;c[j+52>>2]=R;R=E+(O>>>3)|0;Q=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>31;R=O+1|0;O=F>>>0>R>>>0?R:F;c[I>>2]=O;c[j+56>>2]=Q;Q=E+(O>>>3)|0;R=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>29;Q=O+3|0;O=F>>>0>Q>>>0?Q:F;c[I>>2]=O;Q=j+60|0;c[Q>>2]=R;R=E+(O>>>3)|0;S=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>31;R=O+1|0;O=F>>>0>R>>>0?R:F;c[I>>2]=O;R=j+64|0;c[R>>2]=S;S=E+(O>>>3)|0;T=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(O&7)>>>31;S=O+1|0;O=F>>>0>S>>>0?S:F;c[I>>2]=O;S=j+68|0;c[S>>2]=T;T=E+(O>>>3)|0;U=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(O&7)>>>30;T=O+2|0;O=F>>>0>T>>>0?T:F;c[I>>2]=O;T=j+72|0;c[T>>2]=U;V=E+(O>>>3)|0;W=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(O&7)>>>31;V=O+1|0;O=F>>>0>V>>>0?V:F;c[I>>2]=O;c[j+76>>2]=W;if((U|0)==3){c[T>>2]=0;KIb(c[j+4>>2]|0,16,2285520,(B=i,i=i+8|0,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=k;return C|0}if((K|0)==0){X=O}else{K=E+(O>>>3)|0;W=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(O&7)>>>16;K=O+16|0;O=F>>>0>K>>>0?K:F;c[I>>2]=O;c[j+80>>2]=W;X=O}O=E+(X>>>3)|0;W=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(X&7)>>>31;O=X+1|0;X=F>>>0>O>>>0?O:F;c[I>>2]=X;O=j+84|0;c[O>>2]=W;W=E+(X>>>3)|0;K=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(X&7)>>>28;W=X+4|0;X=F>>>0>W>>>0?W:F;c[I>>2]=X;c[j+88>>2]=K;K=E+(X>>>3)|0;W=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(X&7)>>>30;K=X+2|0;X=F>>>0>K>>>0?K:F;c[I>>2]=X;c[j+92>>2]=W;W=E+(X>>>3)|0;K=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(X&7)>>>29;W=X+3|0;X=F>>>0>W>>>0?W:F;c[I>>2]=X;W=j+96|0;c[W>>2]=K;K=E+(X>>>3)|0;V=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(X&7)>>>31;K=X+1|0;X=F>>>0>K>>>0?K:F;c[I>>2]=X;c[j+100>>2]=V;V=E+(X>>>3)|0;K=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(X&7)>>>31;V=X+1|0;X=F>>>0>V>>>0?V:F;c[I>>2]=X;c[j+104>>2]=K;K=E+(X>>>3)|0;V=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(X&7)>>>28;K=X+4|0;X=F>>>0>K>>>0?K:F;c[I>>2]=X;c[j+108>>2]=V;V=j+39776|0;c[V>>2]=(U|0)==0?N:N|128;N=E+(X>>>3)|0;E=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(X&7)>>>28;N=X+4|0;c[I>>2]=F>>>0>N>>>0?N:F;c[j+112>>2]=E+1;W4(x,0,0);c[b+412>>2]=c[P>>2];c[b+72>>2]=c[z>>2];z=j+291836|0;c[z>>2]=20;P=0;while(1){if((P|0)>=((c[J>>2]|0)/8|0|0)){break}Y=V4(x,0,P)|0;if((Y|0)==0){P=P+1|0}else{Z=12;break}}if((Z|0)==12){KIb(b,16,2365976,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=Y;i=k;return C|0}Y=j+120|0;P=c[Y>>2]|0;E=((c[T>>2]|0)!=0)+P|0;a:do{if((E|0)>2){F=b+456|0;if(!((c[F>>2]|0)==3&(c[F+4>>2]|0)==0)){break}do{if((a[j+14852|0]|0)!=0){F=j+14853|0;N=a[F]|0;if(!((N<<24>>24|0)==2|(N<<24>>24|0)==4)){break}if((E|0)>0){X=j+14854|0;U=j+14784|0;K=0;do{_=e[X+(K<<3)>>1]|0;$=_&255;if(($|0)==0){aa=0.0}else{aa=+((_>>>7&2)-1|0)*+g[1611888+($-1<<2)>>2]}g[U+(K<<3)>>2]=aa;$=e[X+(K<<3)+2>>1]|0;_=$&255;if((_|0)==0){ba=0.0}else{ba=+(($>>>7&2)-1|0)*+g[1611888+(_-1<<2)>>2]}g[U+(K<<3)+4>>2]=ba;K=K+1|0;}while((K|0)<(((c[T>>2]|0)!=0)+(c[Y>>2]|0)|0));da=a[F]|0}else{da=N}c[V>>2]=da&255;break a}}while(0);K=c[L>>2]&63;if(K>>>0>9>>>0){KIb(c[j+4>>2]|0,16,2300632,(B=i,i=i+8|0,c[B>>2]=K,B)|0);i=B;C=-1094995529;i=k;return C|0}if(E>>>0>6>>>0){QIb(c[j+4>>2]|0,2249384,(B=i,i=i+8|0,c[B>>2]=E,B)|0);i=B;C=-1163346256;i=k;return C|0}if((E|0)<=0){break}U=j+14784|0;X=0;do{g[U+(X<<3)>>2]=+g[1612856+(K*48|0)+(X<<3)>>2];g[U+(X<<3)+4>>2]=+g[1612856+(K*48|0)+(X<<3)+4>>2];X=X+1|0;}while((X|0)<(((c[T>>2]|0)!=0)+(c[Y>>2]|0)|0))}}while(0);if((c[R>>2]|0)==0){c[j+290796>>2]=0;ea=0}else{R=c[1611856+(c[Q>>2]<<2)>>2]|0;c[j+290796>>2]=R;ea=R}R=c[M>>2]|0;Q=c[v>>2]|0;E=((R|0)>(Q|0)?Q:R)<<3;R=j+290796|0;do{if((ea&-2147483638|0)==0){Q=c[I>>2]|0;da=E-Q|0;X=-Q|0;K=(c[H>>2]|0)-Q|0;if((da|0)<(X|0)){fa=X}else{fa=(K|0)<(da|0)?K:da}da=fa+Q|0;c[I>>2]=da;ga=ea;ha=da}else{da=(ea|0)>0?ea:0;c[R>>2]=da;Q=c[I>>2]|0;K=-Q|0;X=K&31;U=c[H>>2]|0;_=U-Q|0;if((X|0)<(K|0)){ia=K}else{ia=(_|0)<(X|0)?_:X}X=ia+Q|0;c[I>>2]=X;if((E-X|0)<=31){ga=da;ha=X;break}da=j+290804|0;Q=b;_=X;X=U;while(1){U=c[D>>2]|0;K=U+(_>>>3)|0;$=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(_&7)&-65536;K=_+16|0;ja=X>>>0>K>>>0?K:X;c[I>>2]=ja;K=U+(ja>>>3)|0;ka=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(ja&7)>>>16;K=ja+16|0;ja=X>>>0>K>>>0?K:X;c[I>>2]=ja;K=ka|$;do{if((K|0)==1191201283){c[R>>2]=c[R>>2]|2;X4(x);Z=57}else if((K|0)==496366178){$=U+(ja>>>3)|0;ka=((je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ja&7)>>>20)+1|0;if((c[M>>2]|0)!=((ja>>3)-4+ka|0)){break}KIb(Q,48,2123376,(B=i,i=i+8|0,c[B>>2]=ja,B)|0);i=B;$=c[H>>2]|0;la=(c[I>>2]|0)+12|0;c[I>>2]=$>>>0>la>>>0?la:$;KIb(Q,48,2640968,(B=i,i=i+8|0,c[B>>2]=ka,B)|0);i=B;ka=c[I>>2]|0;$=c[H>>2]|0;la=(c[D>>2]|0)+(ka>>>3)|0;ma=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ka&7)>>>28;la=ka+4|0;c[I>>2]=$>>>0>la>>>0?la:$;KIb(Q,48,2618216,(B=i,i=i+8|0,c[B>>2]=ma,B)|0);i=B;c[R>>2]=c[R>>2]|4;Z=57}else if((K|0)==1515870810){ma=c[Y>>2]|0;c[da>>2]=ma;$=U+(ja>>>3)|0;la=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ja&7)>>>22;$=c[M>>2]|0;ka=(ja>>3)-4+la|0;if(!(($|0)==(ka|0)|($|0)==(ka+1|0))){break}ka=ja+10|0;$=X>>>0>ka>>>0?ka:X;c[I>>2]=$;c[R>>2]=c[R>>2]|8;ka=U+($>>>3)|0;la=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<($&7)>>>28;ka=$+4|0;c[I>>2]=X>>>0>ka>>>0?ka:X;if((la|0)!=1){KIb(Q,16,2207096,(B=i,i=i+8|0,c[B>>2]=la,B)|0);i=B;break}if((ma|0)<2){QIb(Q,2174712,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}W4(x,ma,0);if((c[J>>2]|0)>7){ma=0;do{if((V4(x,c[da>>2]|0,ma)|0)!=0){KIb(Q,16,2147120,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}ma=ma+1|0;}while((ma|0)<((c[J>>2]|0)/8|0|0))}c[y>>2]=1;Z=57}else{Z=57}}while(0);if((Z|0)==57){Z=0;U=c[I>>2]|0;ja=-U|0;K=ja&31;N=(c[H>>2]|0)-U|0;if((K|0)<(ja|0)){na=ja}else{na=(N|0)<(K|0)?N:K}c[I>>2]=na+U}oa=c[I>>2]|0;if((E-oa|0)<=31){break}_=oa;X=c[H>>2]|0}ga=c[R>>2]|0;ha=oa}}while(0);do{if((ga&4|0)==0){if((ga&10|0)==0){break}c[z>>2]=30}else{c[z>>2]=40}}while(0);b:do{if(((c[v>>2]|0)-(c[M>>2]|0)|0)>32){ga=c[H>>2]|0;oa=c[D>>2]|0;E=oa+(ha>>>3)|0;na=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(ha&7)&-65536;E=ha+16|0;ia=ga>>>0>E>>>0?E:ga;c[I>>2]=ia;E=oa+(ia>>>3)|0;ea=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(ia&7)>>>16;E=ia+16|0;ia=ga>>>0>E>>>0?E:ga;c[I>>2]=ia;if((ea|na|0)!=1683496997){break}if(((c[A>>2]|0)-ia|0)<52){break}na=ia+8|0;ea=ga>>>0>na>>>0?na:ga;c[I>>2]=ea;na=oa+(ea>>>3)|0;E=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ea&7)>>>30;na=ea+2|0;ea=ga>>>0>na>>>0?na:ga;c[I>>2]=ea;na=d[oa+(ea>>>3)|0]<<(ea&7)>>>7;fa=((ea|0)<(ga|0))+ea|0;c[I>>2]=fa;ea=na<<2&4;na=ea|8;X=oa+(fa>>>3)|0;_=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(fa&7)>>>((32-na|0)>>>0);X=na+fa|0;fa=ea|16;ea=(ga>>>0>X>>>0?X:ga)+fa|0;X=ga>>>0>ea>>>0?ea:ga;c[I>>2]=X;ea=d[oa+(X>>>3)|0]<<(X&7)>>>7;na=((X|0)<(ga|0))+X|0;c[I>>2]=na;X=ea&1;ea=j+291808|0;c[ea>>2]=X;do{if((X|0)==0){pa=1;qa=na;ra=ga;sa=oa}else{Q=na+2|0;da=(ga>>>0>Q>>>0?Q:ga)+3|0;Q=ga>>>0>da>>>0?da:ga;c[I>>2]=Q;da=d[oa+(Q>>>3)|0]|0;U=((Q|0)<(ga|0))+Q|0;c[I>>2]=U;if((da&128>>>((Q&7)>>>0)|0)==0){ta=U}else{Q=-U|0;da=ga-U|0;if((Q|0)>36){ua=Q}else{ua=(da|0)<36?da:36}da=ua+U|0;c[I>>2]=da;ta=da}da=oa+(ta>>>3)|0;U=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ta&7)>>>29;da=ta+3|0;Q=ga>>>0>da>>>0?da:ga;c[I>>2]=Q;da=U+1|0;if(da>>>0>1>>>0){QIb(c[j+4>>2]|0,2503448,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}U=oa+(Q>>>3)|0;K=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(Q&7)>>>29;U=Q+3|0;Q=ga>>>0>U>>>0?U:ga;c[I>>2]=Q;U=K+1|0;if(U>>>0>1>>>0){QIb(c[j+4>>2]|0,2490208,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}K=E+1|0;N=E^31;ja=0;F=Q;while(1){Q=oa+(F>>>3)|0;ma=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(F&7)>>>(N>>>0);Q=K+F|0;la=ga>>>0>Q>>>0?Q:ga;c[I>>2]=la;c[t+(ja<<2)>>2]=ma;ma=ja+1|0;if((ma|0)<(da|0)){ja=ma;F=la}else{va=0;wa=la;break}}while(1){F=c[t+(va<<2)>>2]|0;ja=0;K=wa;while(1){if((1<<ja&F|0)==0){xa=K}else{N=K+8|0;la=ga>>>0>N>>>0?N:ga;c[I>>2]=la;xa=la}la=ja+1|0;if((la|0)>(E|0)){break}else{ja=la;K=xa}}K=va+1|0;if((K|0)<(da|0)){va=K;wa=xa}else{break}}da=d[oa+(xa>>>3)|0]<<(xa&7)>>>7;K=((xa|0)<(ga|0))+xa|0;c[I>>2]=K;ja=da&1;c[j+291812>>2]=ja;if((ja|0)==0){pa=U;qa=K;ra=ga;sa=oa;break}ja=K+2|0;K=ga>>>0>ja>>>0?ja:ga;c[I>>2]=K;ja=oa+(K>>>3)|0;da=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(K&7)>>>30;ja=K+2|0;K=ga>>>0>ja>>>0?ja:ga;c[I>>2]=K;ja=da<<2;da=ja+4|0;F=oa+(K>>>3)|0;la=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(K&7)>>>30;F=K+2|0;K=ga>>>0>F>>>0?F:ga;c[I>>2]=K;F=j+291816|0;c[F>>2]=la+1;la=28-ja|0;ja=0;N=K;K=ga;ma=oa;while(1){Q=ma+(N>>>3)|0;ka=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(N&7)>>>(la>>>0);Q=da+N|0;c[I>>2]=K>>>0>Q>>>0?Q:K;Q=ka-(ka>>>1&1431655765)|0;$=(Q>>>2&858993459)+(Q&858993459)|0;Q=($>>>4)+$&252645135;$=(Q>>>8)+Q|0;Q=ka&44646;ka=Q-(Q>>>1&21777)|0;Q=(ka>>>2&858993459)+(ka&858993459)|0;ka=(Q>>>4)+Q&252645135;Q=(ka>>>8)+ka|0;c[x+291820+(ja<<2)>>2]=((Q>>>16)+Q&63)+(($>>>16)+$&63);$=ja+1|0;Q=c[I>>2]|0;ka=c[H>>2]|0;ya=c[D>>2]|0;if(($|0)<(c[F>>2]|0)){ja=$;N=Q;K=ka;ma=ya}else{pa=U;qa=Q;ra=ka;sa=ya;break}}}}while(0);oa=32-fa|0;ga=0;E=qa;do{na=sa+(E>>>3)|0;X=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(E&7)>>>(oa>>>0);na=E+fa|0;E=ra>>>0>na>>>0?na:ra;c[I>>2]=E;c[s+(ga<<2)>>2]=X;ga=ga+1|0;}while((ga|0)<(pa|0));ga=j+291812|0;fa=j+4|0;oa=j+291816|0;X=1;na=E;while(1){U=c[A>>2]|0;if((U-na|0)<16){break b}ma=c[H>>2]|0;K=c[D>>2]|0;N=K+(na>>>3)|0;ja=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(na&7)>>>23;N=na+9|0;F=(ma>>>0>N>>>0?N:ma)+3|0;N=ma>>>0>F>>>0?F:ma;c[I>>2]=N;do{if((c[ea>>2]|0)==0){za=0;Aa=0;Ba=0;Ca=N}else{F=((N|0)<(ma|0))+N|0;if((d[K+(N>>>3)|0]&128>>>((N&7)>>>0)|0)==0){Da=F}else{da=F+4|0;Da=ma>>>0>da>>>0?da:ma}c[I>>2]=Da;da=d[K+(Da>>>3)|0]|0;F=((Da|0)<(ma|0))+Da|0;c[I>>2]=F;if((da&128>>>((Da&7)>>>0)|0)==0){Ea=F}else{da=-F|0;la=ma-F|0;if((da|0)>24){Fa=da}else{Fa=(la|0)<24?la:24}la=Fa+F|0;c[I>>2]=la;Ea=la}la=d[K+(Ea>>>3)|0]|0;F=((Ea|0)<(ma|0))+Ea|0;c[I>>2]=F;if((la&128>>>((Ea&7)>>>0)|0)==0){Ga=F}else{la=K+(F>>>3)|0;da=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(F&7)>>>22;la=F+10|0;F=ma>>>0>la>>>0?la:ma;c[I>>2]=F;la=(da<<3)+8|0;if((U-F|0)<(la|0)){break b}da=-F|0;ya=ma-F|0;if((la|0)<(da|0)){Ha=da}else{Ha=(ya|0)<(la|0)?ya:la}la=Ha+F|0;c[I>>2]=la;Ga=la}la=Ga+5|0;F=(ma>>>0>la>>>0?la:ma)+4|0;la=ma>>>0>F>>>0?F:ma;c[I>>2]=la;F=K+(la>>>3)|0;ya=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(la&7)>>>24;F=la+8|0;la=ma>>>0>F>>>0?F:ma;c[I>>2]=la;F=ya+1|0;ya=d[K+(la>>>3)|0]|0;da=((la|0)<(ma|0))+la|0;c[I>>2]=da;if((128>>>((la&7)>>>0)&ya|0)==0){ya=da+3|0;la=ma>>>0>ya>>>0?ya:ma;c[I>>2]=la;za=F;Aa=0;Ba=0;Ca=la;break}do{if(F>>>0>2>>>0){la=d[K+(da>>>3)|0]<<(da&7)>>>7;ya=((da|0)<(ma|0))+da|0;c[I>>2]=ya;ka=la&1;if(!(F>>>0>6>>>0)){Ia=0;Ja=ka;Ka=ya;break}la=d[K+(ya>>>3)|0]<<(ya&7)>>>7;Q=((ya|0)<(ma|0))+ya|0;c[I>>2]=Q;Ia=la&1;Ja=ka;Ka=Q}else{Ia=0;Ja=0;Ka=da}}while(0);da=d[K+(Ka>>>3)|0]|0;Q=((Ka|0)<(ma|0))+Ka|0;c[I>>2]=Q;if((da&128>>>((Ka&7)>>>0)|0)==0){La=16;Ma=Q}else{da=K+(Q>>>3)|0;ka=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Q&7)>>>30;da=Q+2|0;Q=(ka<<2)+4|0;ka=Q+(ma>>>0>da>>>0?da:ma)|0;da=ma>>>0>ka>>>0?ka:ma;c[I>>2]=da;La=Q;Ma=da}da=K+(Ma>>>3)|0;Q=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Ma&7)>>>29;da=Ma+3|0;ka=ma>>>0>da>>>0?da:ma;c[I>>2]=ka;if((Q|0)==0){za=F;Aa=Ja;Ba=Ia;Ca=ka;break}da=32-La|0;la=0;ya=ka;while(1){ka=K+(ya>>>3)|0;$=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ya&7)>>>(da>>>0);ka=ya+La|0;Na=ma>>>0>ka>>>0?ka:ma;c[I>>2]=Na;ka=$-($>>>1&1431655765)|0;Oa=(ka>>>2&858993459)+(ka&858993459)|0;ka=(Oa>>>4)+Oa&252645135;Oa=(ka>>>8)+ka|0;ka=$&44646;$=ka-(ka>>>1&21777)|0;ka=($>>>2&858993459)+($&858993459)|0;$=(ka>>>4)+ka&252645135;ka=($>>>8)+$|0;c[l+(la<<2)>>2]=((ka>>>16)+ka&63)+((Oa>>>16)+Oa&63);Oa=la+1|0;if((Oa|0)<(Q|0)){la=Oa;ya=Na}else{Pa=0;Qa=Na;break}}while(1){ya=K+(Qa>>>3)|0;la=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(Qa&7)>>>27;ya=Qa+5|0;da=ma>>>0>ya>>>0?ya:ma;c[I>>2]=da;ya=la+1|0;if((U-da|0)<0){break b}Na=c[l+(Pa<<2)>>2]|0;if((Na|0)>0){Oa=ya>>>0<26>>>0;ka=la^31;$=la-15|0;Ra=47-la|0;la=0;Sa=da;while(1){Ta=K+(Sa>>>3)|0;Ua=(je(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Sa&7);if(Oa){Ta=Sa+ya|0;Va=ma>>>0>Ta>>>0?Ta:ma;c[I>>2]=Va;Wa=Ua>>>(ka>>>0);Xa=Va}else{Va=Sa+16|0;Ta=ma>>>0>Va>>>0?Va:ma;c[I>>2]=Ta;Va=K+(Ta>>>3)|0;Ya=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)>>>(Ra>>>0);Va=Ta+$|0;Ta=ma>>>0>Va>>>0?Va:ma;c[I>>2]=Ta;Wa=Ya|Ua>>>16<<$;Xa=Ta}Ta=Wa-(Wa>>>1&1431655765)|0;Ua=(Ta>>>2&858993459)+(Ta&858993459)|0;Ta=(Ua>>>4)+Ua&252645135;Ua=(Ta>>>8)+Ta|0;Ta=((Ua>>>16)+Ua&63)*5|0;Ua=-Xa|0;Ya=ma-Xa|0;if((Ta|0)<(Ua|0)){Za=Ua}else{Za=(Ya|0)<(Ta|0)?Ya:Ta}Ta=Za+Xa|0;c[I>>2]=Ta;Ya=la+1|0;if((Ya|0)<(Na|0)){la=Ya;Sa=Ta}else{_a=Ta;break}}}else{_a=da}Sa=Pa+1|0;if((Sa|0)<(Q|0)){Pa=Sa;Qa=_a}else{za=F;Aa=Ja;Ba=Ia;Ca=_a;break}}}}while(0);N=((Ca|0)<(ma|0))+Ca|0;F=(d[K+(Ca>>>3)|0]&128>>>((Ca&7)>>>0)|0)!=0;if(F){Q=N+8|0;$a=ma>>>0>Q>>>0?Q:ma}else{$a=N}c[I>>2]=$a;N=(($a|0)<(ma|0))+$a|0;if((d[K+($a>>>3)|0]&128>>>(($a&7)>>>0)|0)==0){ab=N}else{Q=N+5|0;ab=ma>>>0>Q>>>0?Q:ma}Q=(Aa|0)==0;if(Q|F^1){bb=ab}else{F=ab+8|0;bb=ma>>>0>F>>>0?F:ma}c[I>>2]=bb;c:do{if((c[ga>>2]|0)==0){cb=bb}else{F=d[K+(bb>>>3)|0]|0;N=((bb|0)<(ma|0))+bb|0;c[I>>2]=N;if((F&128>>>((bb&7)>>>0)|0)==0){cb=N;break}F=N+1|0;N=(ma>>>0>F>>>0?F:ma)+6|0;F=ma>>>0>N>>>0?N:ma;c[I>>2]=F;N=K+(F>>>3)|0;Sa=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(F&7);N=F+2|0;F=ma>>>0>N>>>0?N:ma;c[I>>2]=F;if((Sa&-1073741824|0)==-1073741824){Sa=F+8|0;db=ma>>>0>Sa>>>0?Sa:ma}else{Sa=F+3|0;db=ma>>>0>Sa>>>0?Sa:ma}c[I>>2]=db;Sa=d[K+(db>>>3)|0]|0;F=((db|0)<(ma|0))+db|0;c[I>>2]=F;N=c[oa>>2]|0;if((Sa&128>>>((db&7)>>>0)|0)==0){Sa=N*6|0;la=-F|0;Na=ma-F|0;if((Sa|0)<(la|0)){eb=la}else{eb=(Na|0)<(Sa|0)?Na:Sa}Sa=eb+F|0;c[I>>2]=Sa;fb=Sa}else{if((N|0)>0){gb=0;hb=F}else{cb=F;break}while(1){F=(c[x+291820+(gb<<2)>>2]|0)*6|0;Sa=-hb|0;Na=ma-hb|0;if((F|0)<(Sa|0)){ib=Sa}else{ib=(Na|0)<(F|0)?Na:F}F=ib+hb|0;c[I>>2]=F;Na=gb+1|0;if((Na|0)<(N|0)){gb=Na;hb=F}else{fb=F;break}}}if((N|0)<=0){cb=fb;break}F=(Ba|0)==0;if((za|0)>0){jb=0;kb=fb}else{Na=0;Sa=fb;while(1){if((U-Sa|0)<0){break b}la=x+291820+(Na<<2)|0;if(F){lb=Sa}else{$=c[la>>2]|0;Ra=32-$|0;ka=0;ya=Sa;while(1){Oa=K+(ya>>>3)|0;Ta=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(ya&7)>>>(Ra>>>0);Oa=ya+$|0;Ya=ma>>>0>Oa>>>0?Oa:ma;c[I>>2]=Ya;Oa=Ta-(Ta>>>1&1431655765)|0;Ta=(Oa>>>2&858993459)+(Oa&858993459)|0;Oa=(Ta>>>4)+Ta&252645135;Ta=(Oa>>>8)+Oa|0;Oa=((Ta>>>16)+Ta&63)*6|0;Ta=-Ya|0;Ua=ma-Ya|0;if((Oa|0)<(Ta|0)){mb=Ta}else{mb=(Ua|0)<(Oa|0)?Ua:Oa}Oa=mb+Ya|0;c[I>>2]=Oa;Ya=ka+1|0;if((Ya|0)<6){ka=Ya;ya=Oa}else{lb=Oa;break}}}if(Q){nb=lb}else{ya=c[la>>2]|0;ka=32-ya|0;$=K+(lb>>>3)|0;Ra=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(lb&7)>>>(ka>>>0);$=ya+lb|0;da=ma>>>0>$>>>0?$:ma;c[I>>2]=da;$=Ra-(Ra>>>1&1431655765)|0;Ra=($>>>2&858993459)+($&858993459)|0;$=(Ra>>>4)+Ra&252645135;Ra=($>>>8)+$|0;$=((Ra>>>16)+Ra&63)*6|0;Ra=-da|0;Oa=ma-da|0;if(($|0)<(Ra|0)){ob=Ra}else{ob=(Oa|0)<($|0)?Oa:$}$=ob+da|0;c[I>>2]=$;da=K+($>>>3)|0;Oa=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<($&7)>>>(ka>>>0);ka=$+ya|0;ya=ma>>>0>ka>>>0?ka:ma;c[I>>2]=ya;ka=Oa-(Oa>>>1&1431655765)|0;Oa=(ka>>>2&858993459)+(ka&858993459)|0;ka=(Oa>>>4)+Oa&252645135;Oa=(ka>>>8)+ka|0;ka=((Oa>>>16)+Oa&63)*6|0;Oa=-ya|0;$=ma-ya|0;if((ka|0)<(Oa|0)){pb=Oa}else{pb=($|0)<(ka|0)?$:ka}ka=pb+ya|0;c[I>>2]=ka;nb=ka}ka=Na+1|0;if((ka|0)<(N|0)){Na=ka;Sa=nb}else{cb=nb;break c}}}while(1){if((U-kb|0)<0){break b}Sa=x+291820+(jb<<2)|0;Na=c[Sa>>2]|0;ka=32-Na|0;ya=0;$=kb;do{Oa=K+($>>>3)|0;da=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<($&7)>>>(ka>>>0);Oa=$+Na|0;Ra=ma>>>0>Oa>>>0?Oa:ma;c[I>>2]=Ra;Oa=da-(da>>>1&1431655765)|0;da=(Oa>>>2&858993459)+(Oa&858993459)|0;Oa=(da>>>4)+da&252645135;da=(Oa>>>8)+Oa|0;Oa=((da>>>16)+da&63)*6|0;da=-Ra|0;Ya=ma-Ra|0;if((Oa|0)<(da|0)){qb=da}else{qb=(Ya|0)<(Oa|0)?Ya:Oa}$=qb+Ra|0;c[I>>2]=$;ya=ya+1|0;}while((ya|0)<(za|0));if(F){rb=$}else{ya=c[Sa>>2]|0;Na=32-ya|0;ka=0;la=$;while(1){Ra=K+(la>>>3)|0;Oa=(je(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(la&7)>>>(Na>>>0);Ra=la+ya|0;Ya=ma>>>0>Ra>>>0?Ra:ma;c[I>>2]=Ya;Ra=Oa-(Oa>>>1&1431655765)|0;Oa=(Ra>>>2&858993459)+(Ra&858993459)|0;Ra=(Oa>>>4)+Oa&252645135;Oa=(Ra>>>8)+Ra|0;Ra=((Oa>>>16)+Oa&63)*6|0;Oa=-Ya|0;da=ma-Ya|0;if((Ra|0)<(Oa|0)){sb=Oa}else{sb=(da|0)<(Ra|0)?da:Ra}Ra=sb+Ya|0;c[I>>2]=Ra;Ya=ka+1|0;if((Ya|0)<6){ka=Ya;la=Ra}else{rb=Ra;break}}}if(Q){tb=rb}else{la=c[Sa>>2]|0;ka=32-la|0;ya=K+(rb>>>3)|0;Na=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(rb&7)>>>(ka>>>0);ya=la+rb|0;$=ma>>>0>ya>>>0?ya:ma;c[I>>2]=$;ya=Na-(Na>>>1&1431655765)|0;Na=(ya>>>2&858993459)+(ya&858993459)|0;ya=(Na>>>4)+Na&252645135;Na=(ya>>>8)+ya|0;ya=((Na>>>16)+Na&63)*6|0;Na=-$|0;Ra=ma-$|0;if((ya|0)<(Na|0)){ub=Na}else{ub=(Ra|0)<(ya|0)?Ra:ya}ya=ub+$|0;c[I>>2]=ya;$=K+(ya>>>3)|0;Ra=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ya&7)>>>(ka>>>0);ka=ya+la|0;la=ma>>>0>ka>>>0?ka:ma;c[I>>2]=la;ka=Ra-(Ra>>>1&1431655765)|0;Ra=(ka>>>2&858993459)+(ka&858993459)|0;ka=(Ra>>>4)+Ra&252645135;Ra=(ka>>>8)+ka|0;ka=((Ra>>>16)+Ra&63)*6|0;Ra=-la|0;ya=ma-la|0;if((ka|0)<(Ra|0)){vb=Ra}else{vb=(ya|0)<(ka|0)?ya:ka}ka=vb+la|0;c[I>>2]=ka;tb=ka}ka=jb+1|0;if((ka|0)<(N|0)){jb=ka;kb=tb}else{cb=tb;break}}}}while(0);Q=K+(cb>>>3)|0;N=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(cb&7)>>>30;Q=cb+2|0;F=ma>>>0>Q>>>0?Q:ma;c[I>>2]=F;if((N|0)==0){Q=K+(F>>>3)|0;ka=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(F&7)>>>20;Q=F+12|0;la=ma>>>0>Q>>>0?Q:ma;c[I>>2]=la;wb=ka;xb=la}else if((N|0)==1){wb=512;xb=F}else if((N|0)==2){wb=256;xb=F}else if((N|0)==3){wb=0;xb=F}else{wb=0;xb=F}F=-xb|0;if((U-xb|0)<0){break b}N=(ja<<3)+8|0;if((xb-na|0)>(N|0)){Z=180;break}la=N+na-xb|0;N=ma-xb|0;if((la|0)<(F|0)){yb=F}else{yb=(N|0)<(la|0)?N:la}c[I>>2]=yb+xb;do{if((wb&512|0)==0){if((wb&224|0)==0){break}c[z>>2]=50}else{c[z>>2]=60}}while(0);if((wb&1|0)==0){KIb(c[fa>>2]|0,24,2404056,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}ma=wb&14;ja=c[R>>2]|0;if((ma|0)!=(ja|0)){KIb(c[fa>>2]|0,24,2396856,(B=i,i=i+16|0,c[B>>2]=ma,c[B+8>>2]=ja,B)|0);i=B}if((X|0)>=(pa|0)){break}X=X+1|0;na=c[I>>2]|0}if((Z|0)==180){KIb(c[fa>>2]|0,24,2411640,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}na=c[I>>2]|0;X=ia-24+(_<<3)|0;if((X|0)>(na|0)){oa=X-na|0;X=-na|0;ga=(c[H>>2]|0)-na|0;if((oa|0)<(X|0)){zb=X}else{zb=(ga|0)<(oa|0)?ga:oa}oa=zb+na|0;c[I>>2]=oa;Ab=oa}else{Ab=na}na=0;oa=Ab;while(1){ga=c[H>>2]|0;X=c[D>>2]|0;ea=X+(oa>>>3)|0;E=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(oa&7)&-65536;ea=oa+16|0;ja=ga>>>0>ea>>>0?ea:ga;c[I>>2]=ja;ea=X+(ja>>>3)|0;X=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ja&7)>>>16;ea=ja+16|0;c[I>>2]=ga>>>0>ea>>>0?ea:ga;ga=X|E;d:do{if((ga|0)==1700671838){KIb(c[fa>>2]|0,48,2469528,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;E=c[I>>2]|0;X=c[H>>2]|0;ea=c[D>>2]|0;ja=ea+(E>>>3)|0;ma=d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0;ja=E&7;U=E+6|0;K=X>>>0>U>>>0?U:X;c[I>>2]=K;U=ea+(K>>>3)|0;la=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(K&7)>>>30;U=K+2|0;K=X>>>0>U>>>0?U:X;c[I>>2]=K;U=la+1|0;la=0;N=K;do{K=ea+(N>>>3)|0;F=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(N&7)>>>18;K=N+14|0;N=X>>>0>K>>>0?K:X;c[I>>2]=N;c[q+(la<<2)>>2]=F+1;la=la+1|0;}while((la|0)<(U|0));la=je(ma|0)|0;F=a[ea+(N>>>3)|0]|0;K=((N|0)<(X|0))+N|0;c[I>>2]=K;ka=0;Q=K;while(1){K=ea+(Q>>>3)|0;ya=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Q&7)>>>29;K=Q+3|0;Ra=X>>>0>K>>>0?K:X;c[I>>2]=Ra;K=ya+1|0;c[r+(ka<<2)>>2]=K;ya=ea+(Ra>>>3)|0;$=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(Ra&7)>>>30;ya=Ra+2|0;Ra=X>>>0>ya>>>0?ya:X;c[I>>2]=Ra;ya=$+5|0;Na=27-$|0;$=0;Bb=Ra;do{Ra=ea+(Bb>>>3)|0;Ya=(je(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Bb&7)>>>(Na>>>0);Ra=ya+Bb|0;Bb=X>>>0>Ra>>>0?Ra:X;c[I>>2]=Bb;c[n+(ka<<5)+($<<2)>>2]=Ya+1;$=$+1|0;}while(($|0)<(K|0));K=ka+1|0;if((K|0)<(U|0)){ka=K;Q=Bb}else{break}}Q=N&7;ka=F&255;ea=E-24+(la<<ja>>>26<<3)|0;if((ea|0)>(Bb|0)){ma=ea-Bb|0;ea=-Bb|0;K=X-Bb|0;if((ma|0)<(ea|0)){Cb=ea}else{Cb=(K|0)<(ma|0)?K:ma}ma=Cb+Bb|0;c[I>>2]=ma;Db=ma}else{Db=Bb}ma=(ka&128>>>(Q>>>0)|0)==0;Q=0;ka=0;K=Db;ea=Db;e:while(1){$=r+(ka<<2)|0;ya=c[$>>2]|0;if((ya+Q|0)>(c[Y>>2]|0)){break d}if((c[J>>2]|0)>7){Na=0;Sa=0;Ya=0;Ra=ya;da=ya;while(1){do{if((Sa|0)==0){if((Ra|0)>0){Oa=c[H>>2]|0;Ua=c[D>>2]|0;Ta=0;Va=c[I>>2]|0;while(1){Eb=Ua+(Va>>>3)|0;Fb=(je(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(Va&7)>>>30;Eb=Va+2|0;Gb=Oa>>>0>Eb>>>0?Eb:Oa;c[I>>2]=Gb;c[p+(Ta<<2)>>2]=Fb+2;Fb=Ta+1|0;if((Fb|0)<(Ra|0)){Ta=Fb;Va=Gb}else{Hb=0;Ib=Ra;Jb=da;break}}while(1){Va=c[n+(ka<<5)+(Hb<<2)>>2]|0;Ta=c[p+(Hb<<2)>>2]|0;if((Va|0)==0){Kb=Ib;Lb=Jb}else{Oa=32-Ta|0;Gb=Va;Va=o+(Hb<<8)|0;while(1){Fb=Gb-1|0;Eb=c[I>>2]|0;Mb=c[H>>2]|0;Nb=Ua+(Eb>>>3)|0;Ob=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Oa>>>0);Nb=Eb+Ta|0;c[I>>2]=Mb>>>0>Nb>>>0?Nb:Mb;c[Va>>2]=Ob;if((Fb|0)==0){break}Gb=Fb;Va=Va+4|0}Va=c[$>>2]|0;Kb=Va;Lb=Va}Va=Hb+1|0;if((Va|0)<(Kb|0)){Hb=Va;Ib=Kb;Jb=Lb}else{Pb=Kb;Qb=Lb;break}}}else{Pb=Ra;Qb=da}Ua=0;while(1){if((Ua|0)>=(Pb|0)){break}Va=c[I>>2]|0;Gb=c[H>>2]|0;Ta=(c[D>>2]|0)+(Va>>>3)|0;Oa=(je(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Va&7)>>>29;Ta=Va+3|0;c[I>>2]=Gb>>>0>Ta>>>0?Ta:Gb;c[p+(Ua<<2)>>2]=Oa;if((Oa|0)==0){Z=229;break e}else{Ua=Ua+1|0}}if((Pb|0)>0){Rb=0}else{Sb=Qb;Tb=Pb;break}while(1){Ua=(c[x+236+(Rb+Q<<2)>>2]|0)==6?607872:608384;Oa=c[p+(Rb<<2)>>2]|0;Gb=c[n+(ka<<5)+(Rb<<2)>>2]|0;if((Gb|0)>0){Ta=32-Oa|0;Va=0;do{do{if((c[o+(Rb<<8)+(Va<<2)>>2]|0)>0){Fb=c[I>>2]|0;Ob=c[H>>2]|0;Mb=c[D>>2]|0;Nb=Mb+(Fb>>>3)|0;Eb=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Fb&7)>>>(Ta>>>0);Nb=Fb+Oa|0;Fb=Ob>>>0>Nb>>>0?Nb:Ob;c[I>>2]=Fb;c[m+(Rb<<9)+(Va<<3)>>2]=c[Ua+(Eb<<2)>>2];if(ma){break}if((c[x+7588+(Rb<<8)+(Va<<2)>>2]|0)==0){break}Eb=Mb+(Fb>>>3)|0;Mb=(je(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(Fb&7)>>>(Ta>>>0);Eb=Fb+Oa|0;c[I>>2]=Ob>>>0>Eb>>>0?Eb:Ob;c[m+(Rb<<9)+(Va<<3)+4>>2]=c[Ua+(Mb<<2)>>2]}}while(0);Va=Va+1|0;}while((Va|0)<(Gb|0))}Gb=Rb+1|0;if((Gb|0)<(Pb|0)){Rb=Gb}else{Ub=Pb;Vb=Qb;Z=239;break}}}else{Ub=Ra;Vb=da;Z=239}}while(0);do{if((Z|0)==239){Z=0;if((Ub|0)>0){Wb=0}else{Sb=Vb;Tb=Ub;break}while(1){Gb=c[n+(ka<<5)+(Wb<<2)>>2]|0;if((Gb|0)>0){Va=Wb+Q|0;Ua=0;do{Oa=c[o+(Wb<<8)+(Ua<<2)>>2]|0;ba=+g[920392+(Oa<<2)>>2];do{if(ma){Xb=0}else{Ta=c[x+7588+(Wb<<8)+(Ua<<2)>>2]|0;if((Ta|0)==0){Xb=0;break}Xb=(Sa|0)>=(Ta|0)|0}}while(0);aa=ba*+(c[m+(Wb<<9)+(Ua<<3)+(Xb<<2)>>2]|0);if((Oa|0)>=1){if((Oa|0)>7){Ta=Oa-3|0;Mb=35-Oa|0;Ob=c[D>>2]|0;Eb=c[I>>2]|0;Fb=c[H>>2]|0;Nb=Ob+(Eb>>>3)|0;Yb=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;Zb=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;_b=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;$b=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;ac=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;bc=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;cc=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Nb=Eb+Ta|0;Eb=Fb>>>0>Nb>>>0?Nb:Fb;c[I>>2]=Eb;Nb=Ob+(Eb>>>3)|0;Ob=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Eb&7)>>>(Mb>>>0);Mb=Eb+Ta|0;c[I>>2]=Fb>>>0>Mb>>>0?Mb:Fb;dc=Yb;ec=Zb;fc=_b;gc=$b;hc=ac;ic=bc;jc=cc;kc=Ob}else{Ob=Oa-1|0;cc=d[2103104+Ob|0]|0;bc=d[2103112+Ob|0]|0;Ob=c[I>>2]|0;ac=c[H>>2]|0;$b=c[D>>2]|0;_b=$b+(Ob>>>3)|0;Zb=32-cc|0;Yb=(je(d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)|0)<<(Ob&7)>>>(Zb>>>0);_b=Ob+cc|0;Ob=ac>>>0>_b>>>0?_b:ac;c[I>>2]=Ob;_b=$b+(Ob>>>3)|0;$b=(je(d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)|0)<<(Ob&7)>>>(Zb>>>0);Zb=Ob+cc|0;c[I>>2]=ac>>>0>Zb>>>0?Zb:ac;ac=bc-1>>1;Zb=c[1367848+(bc<<2)>>2]|0;cc=0;Erc(Zb,cc,Yb,(Yb|0)<0|0?-1:0)|0;Ob=G;_b=Yb-ac-(ca(Ob,bc)|0)|0;Erc(Ob,(Ob|0)<0|0?-1:0,Zb,cc)|0;Yb=G;Fb=Ob-ac-(ca(Yb,bc)|0)|0;Erc(Yb,(Yb|0)<0|0?-1:0,Zb,cc)|0;Ob=G;Mb=Yb-ac-(ca(Ob,bc)|0)|0;Erc(Ob,(Ob|0)<0|0?-1:0,Zb,cc)|0;Yb=G;Ta=Ob-ac-(ca(Yb,bc)|0)|0;Erc($b,($b|0)<0|0?-1:0,Zb,cc)|0;Ob=G;Eb=$b-ac-(ca(Ob,bc)|0)|0;Erc(Ob,(Ob|0)<0|0?-1:0,Zb,cc)|0;$b=G;Nb=Ob-ac-(ca($b,bc)|0)|0;Erc($b,($b|0)<0|0?-1:0,Zb,cc)|0;Ob=G;lc=$b-ac-(ca(Ob,bc)|0)|0;Erc(Ob,(Ob|0)<0|0?-1:0,Zb,cc)|0;cc=G;Zb=Ob-ac-(ca(cc,bc)|0)|0;if((cc|Yb|0)==0&0==0){dc=_b;ec=Fb;fc=Mb;gc=Ta;hc=Eb;ic=Nb;jc=lc;kc=Zb}else{Z=249;break e}}Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)|0;g[Zb>>2]=+g[Zb>>2]+aa*+(dc|0);Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+4|0;g[Zb>>2]=aa*+(ec|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+8|0;g[Zb>>2]=aa*+(fc|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+12|0;g[Zb>>2]=aa*+(gc|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+16|0;g[Zb>>2]=aa*+(hc|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+20|0;g[Zb>>2]=aa*+(ic|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+24|0;g[Zb>>2]=aa*+(jc|0)+ +g[Zb>>2];Zb=x+39808+(Ya*14336|0)+(Va<<11)+(Ua<<5)+28|0;g[Zb>>2]=aa*+(kc|0)+ +g[Zb>>2]}Ua=Ua+1|0;}while((Ua|0)<(Gb|0))}Gb=Wb+1|0;if((Gb|0)<(Ub|0)){Wb=Gb}else{Sb=Vb;Tb=Ub;break}}}}while(0);if((c[S>>2]|0)==0){Gb=c[x+2084+(Na<<2)>>2]|0;if((Sa|0)==(Gb-1|0)){Z=255}else{mc=Gb}}else{Z=255}if((Z|0)==255){Z=0;Gb=c[I>>2]|0;Ua=c[H>>2]|0;Va=(c[D>>2]|0)+(Gb>>>3)|0;Zb=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Gb&7);Va=Gb+16|0;c[I>>2]=Ua>>>0>Va>>>0?Va:Ua;if(!((Zb&-65536|0)==-65536)){Z=257;break e}mc=c[x+2084+(Na<<2)>>2]|0}Zb=Sa+1|0;Ua=(Zb|0)<(mc|0);Va=Ya+1|0;if((Va|0)<((c[J>>2]|0)/8|0|0)){Na=(Ua&1^1)+Na|0;Sa=Ua?Zb:0;Ya=Va;Ra=Tb;da=Sb}else{break}}da=c[I>>2]|0;nc=da;oc=Sb;pc=da}else{nc=K;oc=ya;pc=ea}da=(c[q+(ka<<2)>>2]<<3)+K|0;if((da|0)==(nc|0)){qc=nc;rc=pc}else{Ra=da-nc|0;if(Ra>>>0>7>>>0){KIb(c[fa>>2]|0,16,2420904,(B=i,i=i+8|0,c[B>>2]=Ra,B)|0);i=B;sc=c[I>>2]|0}else{sc=pc}da=-sc|0;Ya=(c[H>>2]|0)-sc|0;if((Ra|0)<(da|0)){tc=da}else{tc=(Ya|0)<(Ra|0)?Ya:Ra}Ra=tc+sc|0;c[I>>2]=Ra;qc=Ra;rc=Ra}Ra=ka+1|0;if((Ra|0)>=(U|0)){break d}Q=oc+Q|0;ka=Ra;K=qc;ea=rc}if((Z|0)==229){Z=0;KIb(c[fa>>2]|0,16,2460344,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}else if((Z|0)==249){Z=0;KIb(c[fa>>2]|0,16,2443672,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}else if((Z|0)==257){Z=0;KIb(c[fa>>2]|0,16,2431160,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break}}else if((ga|0)==1191201283){X4(x);c[R>>2]=c[R>>2]|2}else{KIb(c[fa>>2]|0,48,2479312,(B=i,i=i+8|0,c[B>>2]=ga,B)|0);i=B}}while(0);ga=c[I>>2]|0;ea=(c[s+(na<<2)>>2]<<3)+oa|0;if((ea|0)>(ga|0)){K=ea-ga|0;ea=-ga|0;ka=(c[H>>2]|0)-ga|0;if((K|0)<(ea|0)){uc=ea}else{uc=(ka|0)<(K|0)?ka:K}K=uc+ga|0;c[I>>2]=K;vc=K}else{vc=ga}ga=na+1|0;if((ga|0)<(pa|0)){na=ga;oa=vc}else{break}}}}while(0);c[b+840>>2]=c[z>>2];z=c[Y>>2]|0;vc=c[T>>2]|0;pa=(vc|0)!=0|0;I=pa+z|0;f:do{if((c[R>>2]&2|0)==0){Z=279}else{uc=c[b+440>>2]|0;g:do{if((uc|0)>0){H=pa+P|0;s=j+290840|0;if((uc|0)<(H+(c[s>>2]|0)|0)){Z=279;break f}rc=j+290820|0;qc=c[rc>>2]|0;if((uc|0)>=(z|0)){wc=rc;xc=qc;Z=308;break}oc=s;s=c[j+290812>>2]|0;if((s|0)<=0){yc=qc;zc=H;Ac=rc;Bc=s;break}sc=j+290824|0;tc=H;H=0;pc=qc;while(1){qc=(c[oc+(H<<2)>>2]|0)+tc|0;if((qc|0)>(uc|0)){yc=pc;zc=tc;Ac=rc;Bc=s;break g}nc=c[sc+(H<<2)>>2]|pc;q=H+1|0;if((q|0)<(s|0)){tc=qc;H=q;pc=nc}else{yc=nc;zc=qc;Ac=rc;Bc=s;break}}}else{s=j+290820|0;wc=s;xc=c[s>>2]|0;Z=308}}while(0);do{if((Z|0)==308){uc=c[j+290812>>2]|0;if((uc|0)<=0){yc=xc;zc=I;Ac=wc;Bc=uc;break}s=j+290824|0;rc=0;pc=xc;while(1){H=c[s+(rc<<2)>>2]|pc;tc=rc+1|0;if((tc|0)<(uc|0)){rc=tc;pc=H}else{yc=H;zc=I;Ac=wc;Bc=uc;break}}}}while(0);uc=j+290816|0;pc=c[uc>>2]|0;if((pc|0)>0){rc=0;s=0;while(1){if((1<<rc&yc|0)==0){Cc=s}else{Cc=c[838320+(rc<<2)>>2]|s}H=rc+1|0;if((H|0)<(pc|0)){rc=H;s=Cc}else{Dc=Cc;break}}}else{Dc=0}s=yc-(yc>>>1&1431655765)|0;rc=(s>>>2&858993459)+(s&858993459)|0;s=(rc>>>4)+rc&252645135;rc=(s>>>8)+s|0;s=Dc>>>1;H=Dc-(s&1431655765)|0;tc=(H>>>2&858993459)+(H&858993459)|0;H=(tc>>>4)+tc&252645135;tc=(H>>>8)+H|0;if((((tc>>>16)+tc^(rc>>>16)+rc)&63|0)!=0){KIb(b,48,2550976,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=k;return C|0}rc=b+448|0;c[rc>>2]=Dc;c[rc+4>>2]=(Dc|0)<0|0?-1:0;rc=b+456|0;tc=c[rc+4>>2]|0;H=0;if((tc|0)<(H|0)|(tc|0)==(H|0)&(c[rc>>2]|0)>>>0<0>>>0){if((zc|0)>0){rc=0;do{a[j+(rc+291772)|0]=rc;rc=rc+1|0;}while((rc|0)<(zc|0))}a[j+291804|0]=zc+255}else{rc=j+290812|0;if((Bc|0)>-1){H=j+290824|0;tc=-1;sc=0;oc=pc;qc=Bc;while(1){if((tc|0)>-1){Ec=H+(tc<<2)|0}else{Ec=Ac}if((oc|0)>0){nc=c[Ec>>2]&-65569;q=sc;Sb=0;Tb=oc;while(1){if((nc&1<<Sb|0)==0){Fc=q;Gc=Tb}else{mc=(c[838320+(Sb<<2)>>2]|0)-1&Dc;D=mc-(mc>>>1&1431655765)|0;mc=(D>>>2&858993459)+(D&858993459)|0;D=(mc>>>4)+mc&252645135;mc=(D>>>8)+D|0;a[j+(q+291772)|0]=(mc>>>16)+mc&63;Fc=q+1|0;Gc=c[uc>>2]|0}mc=Sb+1|0;if((mc|0)<(Gc|0)){q=Fc;Sb=mc;Tb=Gc}else{break}}Hc=Fc;Ic=Gc;Jc=c[rc>>2]|0}else{Hc=sc;Ic=oc;Jc=qc}Tb=tc+1|0;if((Tb|0)<(Jc|0)){tc=Tb;sc=Hc;oc=Ic;qc=Jc}else{break}}}qc=(Dc&7)-(s&1)|0;oc=(qc>>>2&858993459)+(qc&858993459)|0;qc=(oc>>>4)+oc&252645135;oc=(qc>>>8)+qc|0;a[j+291804|0]=(oc>>>16)+oc&63}c[j+290764>>2]=j+291772;Kc=zc}}while(0);if((Z|0)==279){zc=c[L>>2]|0;if((zc|0)>=16){KIb(b,16,2569e3,(B=i,i=i+8|0,c[B>>2]=zc,B)|0);i=B;C=-1094995529;i=k;return C|0}Dc=1613400+(zc<<3)|0;Jc=c[Dc>>2]|0;Ic=c[Dc+4>>2]|0;Dc=b+448|0;c[Dc>>2]=Jc;c[Dc+4>>2]=Ic;do{if((c[y>>2]|0)==0){Z=288}else{if((c[j+290808>>2]|0)!=0){Z=288;break}Hc=c[b+440>>2]|0;if((Hc|0)!=0){if((Hc|0)<=(pa+P|0)){Z=288;break}}Hc=Jc|256;Gc=Ic|0;c[Dc>>2]=Hc;c[Dc+4>>2]=Gc;if((vc|0)==0){Fc=1613544+(zc*9|0)|0;c[j+290764>>2]=Fc;Lc=Gc;Mc=Hc;Nc=Fc}else{Fc=Jc|264;Hc=Ic|0;c[Dc>>2]=Fc;c[Dc+4>>2]=Hc;Gc=1613832+(zc*9|0)|0;c[j+290764>>2]=Gc;Lc=Hc;Mc=Fc;Nc=Gc}if((a[Nc+(c[j+290804>>2]|0)|0]|0)<0){C=-1094995529}else{Oc=I;Pc=vc;Qc=Nc;Rc=Lc;Sc=Mc;break}i=k;return C|0}}while(0);do{if((Z|0)==288){Mc=pa+P|0;c[y>>2]=0;if((vc|0)==0){Lc=1613688+(zc*9|0)|0;c[j+290764>>2]=Lc;Oc=Mc;Pc=0;Qc=Lc;Rc=Ic;Sc=Jc;break}else{Lc=Jc|8;Nc=Ic|0;c[Dc>>2]=Lc;c[Dc+4>>2]=Nc;Gc=1613976+(zc*9|0)|0;c[j+290764>>2]=Gc;Oc=Mc;Pc=vc;Qc=Gc;Rc=Nc;Sc=Lc;break}}}while(0);vc=(Pc|0)!=0|0;do{if((Oc|0)>(vc|0)){if((a[Qc+(Oc-1-vc)|0]|0)<0){C=-1094995529}else{break}i=k;return C|0}}while(0);if((rGb(Sc,Rc)|0)!=(Oc|0)){Rc=rGb(c[Dc>>2]|0,c[Dc+4>>2]|0)|0;KIb(b,16,2590840,(B=i,i=i+16|0,c[B>>2]=Oc,c[B+8>>2]=Rc,B)|0);i=B;C=-1094995529;i=k;return C|0}Rc=c[Y>>2]|0;Sc=b+456|0;vc=c[Sc>>2]|0;Qc=c[Sc+4>>2]|0;do{if((((c[T>>2]|0)!=0)+Rc|0)>2&((vc|0)==3&(Qc|0)==0)){if((Rc|0)==2){Tc=c[L>>2]|0}else{Tc=2}c[V>>2]=Tc;c[Dc>>2]=3;c[Dc+4>>2]=0;Uc=2}else{Sc=0;if(!((Qc|0)<(Sc|0)|(Qc|0)==(Sc|0)&vc>>>0<0>>>0)){Uc=Oc;break}c[j+290764>>2]=1613384;Uc=Oc}}while(0);a[j+291804|0]=a[1611832+(c[L>>2]|0)|0]|0;c[j+290872>>2]=0;Kc=Uc}Uc=b+416|0;Oc=c[Uc>>2]|0;if((Oc|0)!=(Kc|0)){if((Oc|0)!=0){KIb(b,32,2532712,(B=i,i=i+16|0,c[B>>2]=Oc,c[B+8>>2]=Kc,B)|0);i=B}c[Uc>>2]=Kc}Oc=f+76|0;c[Oc>>2]=((c[J>>2]|0)/8|0)<<8;vc=M4a(b,u,0)|0;if((vc|0)<0){C=vc;i=k;return C|0}vc=c[f+64>>2]|0;do{if((c[Uc>>2]|0)<(I|0)){f=I-Kc|0;Qc=b+420|0;Dc=SKb(0,f,c[Oc>>2]|0,c[Qc>>2]|0,0)|0;if((Dc|0)<0){C=Dc;i=k;return C|0}Tc=j+269248|0;xJb(Tc,j+269252|0,Dc);Dc=c[Tc>>2]|0;if((Dc|0)==0){C=-12;i=k;return C|0}Tc=TKb(j+269216|0,0,Dc,f,c[Oc>>2]|0,c[Qc>>2]|0,0)|0;if((Tc|0)<0){C=Tc}else{break}i=k;return C|0}}while(0);Oc=c[J>>2]|0;if((Oc|0)>7){b=(Kc|0)>0;Uc=j+290764|0;Tc=j+291956|0;Qc=j+291944|0;f=j+291880|0;Dc=j+39648|0;Rc=j+4|0;Sc=j+269184|0;Pc=Sc;zc=j+269188|0;Ic=j+14784|0;Jc=j+14792|0;pa=j+14800|0;Z=j+14788|0;Lc=j+14796|0;Nc=j+14804|0;Gc=j+14808|0;Mc=j+14816|0;Fc=j+14812|0;Hc=j+14820|0;Ec=j+290872|0;Ac=j+290812|0;Bc=j+290840|0;yc=j+290856|0;Cc=j+291804|0;wc=Sc;Sc=j+290876|0;xc=j+291848|0;z=j+290804|0;R=j+269216|0;oc=0;while(1){if(b){qc=oc<<8;sc=0;while(1){c[wc+(sc<<2)>>2]=(c[vc+(sc<<2)>>2]|0)+(qc<<2);tc=sc+1|0;if((tc|0)<(Kc|0)){sc=tc}else{Vc=Kc;break}}}else{Vc=0}if((Vc|0)<(I|0)){sc=oc<<8;qc=Vc;do{c[wc+(qc<<2)>>2]=(c[R+(qc-Kc<<2)>>2]|0)+(sc<<2);qc=qc+1|0;}while((qc|0)<(I|0))}qc=c[Y>>2]|0;if((qc|0)>0){sc=0;s=qc;while(1){tc=a[(c[Uc>>2]|0)+sc|0]|0;if(tc<<24>>24>-1){ze[c[Tc>>2]&3](x+39808+(oc*14336|0)+(sc<<11)|0,c[x+124+(sc<<2)>>2]|0,Qc,f,x+24384+(sc<<11)|0,x+39616+(sc<<2)|0,x+38720+(sc<<7)|0,(c[O>>2]|0)==0?1221656:1217560,c[x+269184+(tc<<24>>24<<2)>>2]|0,Dc,762939453125.0e-17);Wc=c[Y>>2]|0}else{Wc=s}tc=sc+1|0;if((tc|0)<(Wc|0)){sc=tc;s=Wc}else{Xc=Wc;break}}}else{Xc=qc}s=c[T>>2]|0;do{if((s|0)==0){Yc=Xc;Zc=0}else{sc=s<<1;tc=(s|0)==1;rc=tc&1;uc=tc?1008632:1007608;if((sc|0)<=0){Yc=Xc;Zc=s;break}tc=ca(sc,oc+4|0)|0;H=x+291948+(rc<<2)|0;pc=(rc<<6)+64|0;rc=x+16712+(tc<<2)|0;tc=c[x+269184+(a[Cc]<<2)>>2]|0;Tb=0;while(1){ef[c[H>>2]&4095](tc,rc,uc);Sb=Tb+1|0;if((Sb|0)<(sc|0)){rc=rc+4|0;tc=tc+(pc<<2)|0;Tb=Sb}else{break}}Yc=c[Y>>2]|0;Zc=c[T>>2]|0}}while(0);s=(Zc|0)!=0;do{if(((s&1)+Yc|0)>2){qc=(c[Rc>>2]|0)+456|0;if(!((c[qc>>2]|0)==3&(c[qc+4>>2]|0)==0)){break}qc=c[L>>2]|0;Tb=c[Uc>>2]|0;switch(qc|0){case 0:case 10:{KIb(0,16,2517432,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break};case 5:{pc=c[x+269184+(a[Tb]<<2)>>2]|0;tc=c[x+269184+(a[Tb+1|0]<<2)>>2]|0;rc=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;sc=c[Pc>>2]|0;uc=c[zc>>2]|0;H=0;do{aa=+g[pc+(H<<2)>>2];_c=+g[tc+(H<<2)>>2];$c=+g[rc+(H<<2)>>2];g[sc+(H<<2)>>2]=aa*+g[Ic>>2]+_c*+g[Jc>>2]+$c*+g[pa>>2];g[uc+(H<<2)>>2]=aa*+g[Z>>2]+_c*+g[Lc>>2]+$c*+g[Nc>>2];H=H+1|0;}while((H|0)<256);break};case 6:{H=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;uc=c[Pc>>2]|0;sc=c[zc>>2]|0;rc=0;do{tc=H+(rc<<2)|0;pc=uc+(rc<<2)|0;g[pc>>2]=+g[tc>>2]*+g[pa>>2]+ +g[pc>>2];pc=sc+(rc<<2)|0;g[pc>>2]=+g[tc>>2]*+g[Nc>>2]+ +g[pc>>2];rc=rc+1|0;}while((rc|0)<256);break};case 7:{rc=c[x+269184+(a[Tb]<<2)>>2]|0;sc=c[x+269184+(a[Tb+1|0]<<2)>>2]|0;uc=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;H=c[Pc>>2]|0;pc=c[zc>>2]|0;tc=c[x+269184+(a[Tb+3|0]<<2)>>2]|0;Sb=0;do{$c=+g[rc+(Sb<<2)>>2];_c=+g[sc+(Sb<<2)>>2];aa=+g[uc+(Sb<<2)>>2];q=H+(Sb<<2)|0;g[q>>2]=$c*+g[Ic>>2]+_c*+g[Jc>>2]+aa*+g[pa>>2];nc=pc+(Sb<<2)|0;g[nc>>2]=$c*+g[Z>>2]+_c*+g[Lc>>2]+aa*+g[Nc>>2];mc=tc+(Sb<<2)|0;g[q>>2]=+g[mc>>2]*+g[Gc>>2]+ +g[q>>2];g[nc>>2]=+g[mc>>2]*+g[Fc>>2]+ +g[nc>>2];Sb=Sb+1|0;}while((Sb|0)<256);break};case 8:{Sb=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;tc=c[x+269184+(a[Tb+3|0]<<2)>>2]|0;pc=c[Pc>>2]|0;H=c[zc>>2]|0;uc=0;do{sc=Sb+(uc<<2)|0;rc=tc+(uc<<2)|0;nc=pc+(uc<<2)|0;g[nc>>2]=+g[nc>>2]+(+g[sc>>2]*+g[pa>>2]+ +g[rc>>2]*+g[Gc>>2]);nc=H+(uc<<2)|0;g[nc>>2]=+g[nc>>2]+(+g[sc>>2]*+g[Nc>>2]+ +g[rc>>2]*+g[Fc>>2]);uc=uc+1|0;}while((uc|0)<256);break};case 9:{uc=c[x+269184+(a[Tb]<<2)>>2]|0;H=c[x+269184+(a[Tb+1|0]<<2)>>2]|0;pc=c[x+269184+(a[Tb+2|0]<<2)>>2]|0;tc=c[Pc>>2]|0;Sb=c[zc>>2]|0;rc=c[x+269184+(a[Tb+3|0]<<2)>>2]|0;sc=c[x+269184+(a[Tb+4|0]<<2)>>2]|0;nc=0;do{aa=+g[uc+(nc<<2)>>2];_c=+g[H+(nc<<2)>>2];$c=+g[pc+(nc<<2)>>2];mc=tc+(nc<<2)|0;g[mc>>2]=aa*+g[Ic>>2]+_c*+g[Jc>>2]+$c*+g[pa>>2];q=Sb+(nc<<2)|0;g[q>>2]=aa*+g[Z>>2]+_c*+g[Lc>>2]+$c*+g[Nc>>2];D=rc+(nc<<2)|0;S=sc+(nc<<2)|0;g[mc>>2]=+g[mc>>2]+(+g[D>>2]*+g[Gc>>2]+ +g[S>>2]*+g[Mc>>2]);g[q>>2]=+g[q>>2]+(+g[D>>2]*+g[Fc>>2]+ +g[S>>2]*+g[Hc>>2]);nc=nc+1|0;}while((nc|0)<256);break};default:{}}if(!s){break}nc=d[1613528+qc|0]|0;sc=c[x+269184+(a[1611832+qc|0]<<2)>>2]|0;rc=x+14784+(nc<<3)|0;Sb=c[Pc>>2]|0;tc=x+14784+(nc<<3)+4|0;nc=c[zc>>2]|0;pc=0;do{H=sc+(pc<<2)|0;uc=Sb+(pc<<2)|0;g[uc>>2]=+g[H>>2]*+g[rc>>2]+ +g[uc>>2];uc=nc+(pc<<2)|0;g[uc>>2]=+g[H>>2]*+g[tc>>2]+ +g[uc>>2];pc=pc+1|0;}while((pc|0)<256)}}while(0);do{if((c[W>>2]&1|0)!=0){if((c[y>>2]|0)==0){break}s=c[z>>2]|0;pc=c[Uc>>2]|0;tc=c[wc+(a[pc+s|0]<<2)>>2]|0;nc=c[wc+(a[pc+(s-1)|0]<<2)>>2]|0;xe[c[xc>>2]&7](c[wc+(a[pc+(s-2)|0]<<2)>>2]|0,tc,-.7071067690849304,256);xe[c[xc>>2]&7](nc,tc,-.7071067690849304,256)}}while(0);tc=c[Ec>>2]|0;h:do{if((tc|0)!=0){if((c[Ac>>2]|0)>0){ad=0;bd=P;cd=tc}else{break}while(1){nc=c[Bc+(ad<<2)>>2]|0;s=nc+bd|0;if((nc|0)>0){nc=(s|0)>0;pc=bd;do{do{if((1<<pc&cd|0)!=0){rc=c[wc+(a[(c[Uc>>2]|0)+pc|0]<<2)>>2]|0;if(nc){dd=0}else{break}do{$c=+g[Sc+(pc<<7)+(dd<<2)>>2];if($c!=0.0){xe[c[xc>>2]&7](c[wc+(a[(c[Uc>>2]|0)+dd|0]<<2)>>2]|0,rc,-0.0-$c,256)}dd=dd+1|0;}while((dd|0)<(s|0))}}while(0);pc=pc+1|0;}while((pc|0)<(s|0))}do{if((cd&1<<bd|0)!=0){$c=+g[yc+(ad<<2)>>2];if(!($c!=1.0)){break}if((bd|0)>0){pc=c[Uc>>2]|0;nc=0;do{ya=c[wc+(a[pc+nc|0]<<2)>>2]|0;rc=0;do{Sb=ya+(rc<<2)|0;g[Sb>>2]=$c*+g[Sb>>2];rc=rc+1|0;}while((rc|0)<256);nc=nc+1|0;}while((nc|0)<(bd|0))}if((c[T>>2]|0)==0){break}nc=c[wc+(a[Cc]<<2)>>2]|0;pc=0;do{rc=nc+(pc<<2)|0;g[rc>>2]=$c*+g[rc>>2];pc=pc+1|0;}while((pc|0)<256)}}while(0);pc=ad+1|0;if((pc|0)>=(c[Ac>>2]|0)){break h}ad=pc;bd=s;cd=c[Ec>>2]|0}}}while(0);tc=oc+1|0;pc=(c[J>>2]|0)/8|0;if((tc|0)<(pc|0)){oc=tc}else{ed=pc;break}}}else{ed=(Oc|0)/8|0}Oc=c[T>>2]|0;oc=ca(ed<<1,Oc)|0;if((Oc<<3|0)>0){Oc=j+16712|0;j=0;do{g[Oc+(j<<2)>>2]=+g[Oc+(j+oc<<2)>>2];j=j+1|0;}while((j|0)<(c[T>>2]<<3|0))}T=I4a(u,(c[V>>2]&-129|0)==4|0)|0;if((T|0)<0){C=T;i=k;return C|0}c[h>>2]=1;C=w;i=k;return C|0}function U4(a){a=a|0;var b=0;b=c[a+60>>2]|0;PPa(b+291880|0);mJb(b+269248|0);return 0}function V4(e,f,h){e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0.0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0.0,Ja=0,Ka=0.0,La=0.0,Ma=0.0,Na=0.0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;j=i;i=i+2304|0;k=j|0;l=j+2048|0;m=e+290788|0;n=c[m>>2]|0;o=e+112|0;p=c[o>>2]|0;if((n|0)>=(p|0)){KIb(c[e+4>>2]|0,48,2376264,(q=i,i=i+16|0,c[q>>2]=n,c[q+8>>2]=p,q)|0);i=q;r=-1094995529;i=j;return r|0}p=e+290792|0;do{if((c[p>>2]|0)==0){s=e+290768|0;t=e+290776|0;u=c[t>>2]|0;v=e+290780|0;if(((c[v>>2]|0)-u|0)<0){r=-1094995529;i=j;return r|0}w=(f|0)!=0;if(w){x=f}else{y=e+290784|0;z=c[y>>2]|0;A=s|0;B=(c[A>>2]|0)+(u>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(u&7)>>>30;B=u+2|0;c[t>>2]=z>>>0>B>>>0?B:z;c[e+2084+(n<<2)>>2]=C+1;C=c[t>>2]|0;z=c[y>>2]|0;y=(c[A>>2]|0)+(C>>>3)|0;A=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(C&7)>>>29;y=C+3|0;c[t>>2]=z>>>0>y>>>0?y:z;c[e+2148+(c[m>>2]<<2)>>2]=A;x=0}A=e+120|0;z=c[A>>2]|0;if((x|0)<(z|0)){y=e+290784|0;C=s|0;B=x;u=z;while(1){D=e+124+(B<<2)|0;if((c[D>>2]|0)>0){E=0;do{F=c[t>>2]|0;H=c[y>>2]|0;I=(c[C>>2]|0)+(F>>>3)|0;J=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(F&7)>>>31;I=F+1|0;c[t>>2]=H>>>0>I>>>0?I:H;c[e+2212+(B<<8)+(E<<2)>>2]=J;E=E+1|0;}while((E|0)<(c[D>>2]|0));K=c[A>>2]|0}else{K=u}D=B+1|0;if((D|0)<(K|0)){B=D;u=K}else{L=K;break}}}else{L=z}if((L|0)>(f|0)){u=e+290784|0;B=s|0;C=f;y=L;while(1){D=e+124+(C<<2)|0;E=c[D>>2]|0;if((E|0)>0){J=0;H=E;while(1){if((c[e+2212+(C<<8)+(J<<2)>>2]|0)>0){E=c[t>>2]|0;I=c[u>>2]|0;F=(c[B>>2]|0)+(E>>>3)|0;M=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>20;F=E+12|0;c[t>>2]=I>>>0>F>>>0?F:I;c[e+4004+(C<<8)+(J<<2)>>2]=M;N=c[D>>2]|0}else{N=H}M=J+1|0;if((M|0)<(N|0)){J=M;H=N}else{break}}O=c[A>>2]|0}else{O=y}H=C+1|0;if((H|0)<(O|0)){C=H;y=O}else{P=O;break}}}else{P=L}a:do{if((P|0)>(f|0)){y=e+290784|0;C=s|0;B=f;u=P;b:while(1){z=e+152+(B<<2)|0;H=e+264+(B<<2)|0;if((c[z>>2]|0)>0){J=0;do{D=c[H>>2]|0;if((D|0)==6){M=c[t>>2]|0;I=c[y>>2]|0;F=(c[C>>2]|0)+(M>>>3)|0;E=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(M&7)>>>27;F=M+5|0;c[t>>2]=I>>>0>F>>>0?F:I;c[e+5796+(B<<8)+(J<<2)>>2]=E;Q=E;R=36}else if((D|0)==5){E=c[t>>2]|0;I=c[y>>2]|0;F=(c[C>>2]|0)+(E>>>3)|0;M=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>28;F=E+4|0;c[t>>2]=I>>>0>F>>>0?F:I;c[e+5796+(B<<8)+(J<<2)>>2]=M}else if((D|0)==7){break b}else{M=c[9772028+(D*20|0)>>2]|0;I=c[9772024+(D*20|0)>>2]|0;D=c[2443005]|0;F=c[t>>2]|0;E=c[y>>2]|0;S=c[C>>2]|0;T=S+(F>>>3)|0;U=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(F&7)>>>((32-I|0)>>>0);T=b[M+(U<<2)>>1]|0;V=b[M+(U<<2)+2>>1]|0;U=V<<16>>16;do{if((D|0)>1&V<<16>>16<0){W=F+I|0;X=E>>>0>W>>>0?W:E;W=S+(X>>>3)|0;Y=((je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(X&7)>>>((U+32|0)>>>0))+T|0;W=b[M+(Y<<2)>>1]|0;Z=b[M+(Y<<2)+2>>1]|0;Y=Z<<16>>16;if(!((D|0)>2&Z<<16>>16<0)){_=Y;$=W;aa=X;break}Z=X-U|0;X=E>>>0>Z>>>0?Z:E;Z=S+(X>>>3)|0;ba=((je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(X&7)>>>((Y+32|0)>>>0))+W|0;_=b[M+(ba<<2)+2>>1]|0;$=b[M+(ba<<2)>>1]|0;aa=X}else{_=U;$=T;aa=F}}while(0);F=_+aa|0;c[t>>2]=E>>>0>F>>>0?F:E;F=(c[2442996]|0)+$|0;c[e+5796+(B<<8)+(J<<2)>>2]=F;Q=F;R=36}if((R|0)==36){R=0;if((Q|0)>26){r=-1094995529;R=196;break b}}J=J+1|0;}while((J|0)<(c[z>>2]|0));da=c[A>>2]|0}else{da=u}z=B+1|0;if((z|0)<(da|0)){B=z;u=da}else{ea=da;break a}}if((R|0)==196){i=j;return r|0}KIb(c[e+4>>2]|0,16,2308592,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=j;return r|0}else{ea=P}}while(0);if((ea|0)>(f|0)){u=e+290784|0;B=s|0;C=f;y=ea;while(1){z=e+124+(C<<2)|0;if((c[z>>2]|0)>0){J=e+152+(C<<2)|0;H=e+208+(C<<2)|0;F=0;do{T=e+7588+(C<<8)+(F<<2)|0;c[T>>2]=0;do{if((c[e+2084+(c[m>>2]<<2)>>2]|0)>1){if((F|0)>=(c[J>>2]|0)){break}if((c[e+5796+(C<<8)+(F<<2)>>2]|0)<=0){break}U=c[H>>2]|0;M=c[9674940+(U*20|0)>>2]|0;S=c[9674936+(U*20|0)>>2]|0;U=c[2418733]|0;D=c[t>>2]|0;I=c[u>>2]|0;V=c[B>>2]|0;X=V+(D>>>3)|0;ba=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(D&7)>>>((32-S|0)>>>0);X=b[M+(ba<<2)>>1]|0;W=b[M+(ba<<2)+2>>1]|0;ba=W<<16>>16;do{if((U|0)>1&W<<16>>16<0){Y=D+S|0;Z=I>>>0>Y>>>0?Y:I;Y=V+(Z>>>3)|0;fa=((je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(Z&7)>>>((ba+32|0)>>>0))+X|0;Y=b[M+(fa<<2)>>1]|0;ga=b[M+(fa<<2)+2>>1]|0;fa=ga<<16>>16;if(!((U|0)>2&ga<<16>>16<0)){ha=fa;ia=Y;ja=Z;break}ga=Z-ba|0;Z=I>>>0>ga>>>0?ga:I;ga=V+(Z>>>3)|0;ka=((je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(Z&7)>>>((fa+32|0)>>>0))+Y|0;ha=b[M+(ka<<2)+2>>1]|0;ia=b[M+(ka<<2)>>1]|0;ja=Z}else{ha=ba;ia=X;ja=D}}while(0);D=ha+ja|0;c[t>>2]=I>>>0>D>>>0?D:I;c[T>>2]=(c[2418724]|0)+ia}}while(0);F=F+1|0;}while((F|0)<(c[z>>2]|0));la=c[A>>2]|0}else{la=y}z=C+1|0;if((z|0)<(la|0)){C=z;y=la}else{ma=la;break}}}else{ma=ea}if(((c[v>>2]|0)-(c[t>>2]|0)|0)<0){r=-1094995529;i=j;return r|0}if((ma|0)>(f|0)){y=f;while(1){C=e+124+(y<<2)|0;mrc(e+9380+(y<<9)|0,0,c[C>>2]<<3|0)|0;B=e+236+(y<<2)|0;u=(c[B>>2]|0)==6;z=u?7:6;F=u?607872:608384;if((c[C>>2]|0)>0){u=e+152+(y<<2)|0;H=0;J=0;while(1){T=c[u>>2]|0;if((J|0)<(T|0)){if((c[e+5796+(y<<8)+(J<<2)>>2]|0)>0){R=59}else{na=H;oa=T}}else{R=59}if((R|0)==59){R=0;T=Y4(s,c[B>>2]|0,H,z)|0;c[e+9380+(y<<9)+(J<<3)>>2]=c[F+(T<<2)>>2];na=T;oa=c[u>>2]|0}do{if((J|0)<(oa|0)){if((c[e+7588+(y<<8)+(J<<2)>>2]|0)==0){pa=na;break}T=Y4(s,c[B>>2]|0,na,z)|0;c[e+9380+(y<<9)+(J<<3)+4>>2]=c[F+(T<<2)>>2];pa=T}else{pa=na}}while(0);T=J+1|0;if((T|0)<(c[C>>2]|0)){H=pa;J=T}else{break}}}J=y+1|0;H=c[A>>2]|0;if((J|0)<(H|0)){y=J}else{qa=H;break}}}else{qa=ma}if((qa|0)>(f|0)){y=e+290784|0;H=s|0;J=f;C=qa;while(1){if((c[e+180+(J<<2)>>2]|0)>0){F=c[t>>2]|0;z=c[y>>2]|0;B=(c[H>>2]|0)+(F>>>3)|0;u=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(F&7)>>>29;B=F+3|0;c[t>>2]=z>>>0>B>>>0?B:z;c[e+12964+(J<<2)>>2]=u;ra=c[A>>2]|0}else{ra=C}u=J+1|0;if((u|0)<(ra|0)){J=u;C=ra}else{sa=ra;break}}}else{sa=qa}if(((c[v>>2]|0)-(c[t>>2]|0)|0)<0){r=-1094995529;i=j;return r|0}if((sa|0)>(f|0)){C=e+291840|0;J=e+4|0;H=f;while(1){y=c[e+180+(H<<2)>>2]|0;do{if((y|0)>0){u=c[e+124+(H<<2)>>2]|0;z=e+124+(y-1<<2)|0;if((u|0)<(c[z>>2]|0)){B=e+12964+(H<<2)|0;F=u;do{c[e+12992+(H<<8)+(F<<2)>>2]=Y4(s,c[B>>2]|0,64,7)|0;F=F+1|0;}while((F|0)<(c[z>>2]|0))}if((c[C>>2]&2|0)!=0){break}KIb(c[J>>2]|0,48,2303536,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[C>>2]=c[C>>2]|2}}while(0);y=H+1|0;z=c[A>>2]|0;if((y|0)<(z|0)){H=y}else{ta=z;break}}}else{ta=sa}do{if(!w){if((c[e+44>>2]|0)==0){break}H=c[t>>2]|0;C=c[e+290784>>2]|0;J=(c[s>>2]|0)+(H>>>3)|0;v=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>24;J=H+8|0;c[t>>2]=C>>>0>J>>>0?J:C;c[e+14848>>2]=v}}while(0);if((c[e+16>>2]|0)!=0){v=c[e+290784>>2]|0;C=(c[t>>2]|0)+16|0;c[t>>2]=v>>>0>C>>>0?C:v}if((ta|0)>(f|0)){v=e+290784|0;C=s|0;J=f;H=ta;while(1){z=c[e+152+(J<<2)>>2]|0;y=e+124+(J<<2)|0;if((z|0)<(c[y>>2]|0)){F=z;do{z=c[t>>2]|0;B=c[v>>2]|0;u=(c[C>>2]|0)+(z>>>3)|0;T=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(z&7)>>>22;u=z+10|0;c[t>>2]=B>>>0>u>>>0?u:B;c[e+14920+(J<<8)+(F<<2)>>2]=T;F=F+1|0;}while((F|0)<(c[y>>2]|0));ua=c[A>>2]|0}else{ua=H}y=J+1|0;if((y|0)<(ua|0)){J=y;H=ua}else{break}}}if(w){va=A;break}H=c[e+72>>2]|0;if((H|0)==0){va=A;break}J=H<<1;H=h+4|0;C=ca(J,H)|0;v=ca((c[e+2084+(c[m>>2]<<2)>>2]|0)+H|0,J)|0;J=(C|0)<(v|0);H=c[t>>2]|0;y=e+290784|0;F=c[y>>2]|0;T=s|0;B=(c[T>>2]|0)+(H>>>3)|0;u=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(H&7);if(J){B=C;z=H;D=F;X=u;while(1){ba=z+8|0;c[t>>2]=D>>>0>ba>>>0?ba:D;g[e+16712+(B<<2)>>2]=+(X>>24|0);ba=B+1|0;M=c[t>>2]|0;V=c[y>>2]|0;U=(c[T>>2]|0)+(M>>>3)|0;S=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(M&7);if((ba|0)<(v|0)){B=ba;z=M;D=V;X=S}else{wa=M;xa=V;ya=S;break}}}else{wa=H;xa=F;ya=u}X=wa+8|0;c[t>>2]=xa>>>0>X>>>0?X:xa;if((ya|0)<0){QIb(c[e+4>>2]|0,2292520,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=j;return r|0}else{X=c[607872+(ya>>>24<<2)>>2]|0;c[e+17192>>2]=X;za=+(X|0)*.035;if(J){Aa=C}else{va=A;break}while(1){X=e+16712+(Aa<<2)|0;g[X>>2]=za*+g[X>>2];X=Aa+1|0;if((X|0)<(v|0)){Aa=X}else{va=A;break}}}}else{va=e+120|0}}while(0);Aa=c[p>>2]|0;ya=k|0;xa=(c[e+40>>2]|0)==31?920392:920264;wa=c[va>>2]|0;c:do{if((wa|0)>(f|0)){ua=e+290776|0;ta=e+290780|0;sa=e+291964|0;qa=e+291968|0;ra=l|0;ma=e+291840|0;pa=e+4|0;na=e+291960|0;oa=Aa<<3;ea=e+76|0;la=e+290784|0;ia=e+290768|0;ja=f;d:while(1){ha=c[ua>>2]|0;if(((c[ta>>2]|0)-ha|0)<0){r=-1094995529;R=196;break}P=e+152+(ja<<2)|0;da=c[P>>2]|0;if((da|0)>0){Q=0;$=ha;while(1){ha=c[e+5796+(ja<<8)+(Q<<2)>>2]|0;za=+g[xa+(ha<<2)>>2];aa=c[e+292+(ja<<7)+(ha<<2)>>2]|0;e:do{if((ha|0)==0){g[l+(Q<<2)>>2]=0.0;mrc(k+(Q<<3<<2)|0,0,32)|0;Ba=$}else{_=c[e+7588+(ja<<8)+(Q<<2)>>2]|0;if((_|0)==0){Ca=0}else{Ca=(Aa|0)>=(_|0)|0}g[l+(Q<<2)>>2]=+g[e+1188+(ja<<7)+(aa<<2)>>2]*za*+(c[e+9380+(ja<<9)+(Q<<3)+(Ca<<2)>>2]|0);do{if((ha|0)<=10){_=c[9675136+(ha*200|0)+(aa*20|0)+4>>2]|0;if((_|0)==0){if((ha|0)>=8){break}L=ha-1|0;O=d[2103104+L|0]|0;N=d[2103112+L|0]|0;L=c[la>>2]|0;K=c[ia>>2]|0;x=K+($>>>3)|0;n=32-O|0;A=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<($&7)>>>(n>>>0);x=O+$|0;v=L>>>0>x>>>0?x:L;c[ua>>2]=v;x=K+(v>>>3)|0;K=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(v&7)>>>(n>>>0);n=v+O|0;O=L>>>0>n>>>0?n:L;c[ua>>2]=O;L=Q<<3;n=N-1>>1;v=c[1367848+(N<<2)>>2]|0;x=0;Erc(v,x,A,(A|0)<0|0?-1:0)|0;C=G;c[k+(L<<2)>>2]=A-n-(ca(C,N)|0);Erc(C,(C|0)<0|0?-1:0,v,x)|0;A=G;c[k+((L|1)<<2)>>2]=C-n-(ca(A,N)|0);Erc(A,(A|0)<0|0?-1:0,v,x)|0;C=G;c[k+((L|2)<<2)>>2]=A-n-(ca(C,N)|0);Erc(C,(C|0)<0|0?-1:0,v,x)|0;A=G;c[k+((L|3)<<2)>>2]=C-n-(ca(A,N)|0);Erc(K,(K|0)<0|0?-1:0,v,x)|0;C=G;c[k+((L|4)<<2)>>2]=K-n-(ca(C,N)|0);Erc(C,(C|0)<0|0?-1:0,v,x)|0;K=G;c[k+((L|5)<<2)>>2]=C-n-(ca(K,N)|0);Erc(K,(K|0)<0|0?-1:0,v,x)|0;C=G;c[k+((L|6)<<2)>>2]=K-n-(ca(C,N)|0);Erc(C,(C|0)<0|0?-1:0,v,x)|0;x=G;c[k+((L|7)<<2)>>2]=C-n-(ca(x,N)|0);if((x|A|0)==0&0==0){Ba=O;break e}else{break d}}O=9675136+(ha*200|0)+(aa*20|0)|0;A=9675132+(ha*200|0)|0;x=9675096+(ha*200|0)|0;N=Q<<3;n=c[la>>2]|0;C=c[ia>>2]|0;L=0;v=$;while(1){K=c[O>>2]|0;J=c[A>>2]|0;t=C+(v>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>((32-K|0)>>>0);t=b[_+(u<<2)>>1]|0;F=b[_+(u<<2)+2>>1]|0;u=F<<16>>16;do{if((J|0)>1&F<<16>>16<0){H=K+v|0;X=n>>>0>H>>>0?H:n;H=C+(X>>>3)|0;D=((je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(X&7)>>>((u+32|0)>>>0))+t|0;H=b[_+(D<<2)>>1]|0;z=b[_+(D<<2)+2>>1]|0;D=z<<16>>16;if(!((J|0)>2&z<<16>>16<0)){Da=D;Ea=H;Fa=X;break}z=X-u|0;X=n>>>0>z>>>0?z:n;z=C+(X>>>3)|0;B=((je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(X&7)>>>((D+32|0)>>>0))+H|0;Da=b[_+(B<<2)+2>>1]|0;Ea=b[_+(B<<2)>>1]|0;Fa=X}else{Da=u;Ea=t;Fa=v}}while(0);t=Da+Fa|0;u=n>>>0>t>>>0?t:n;c[ua>>2]=u;c[k+(L+N<<2)>>2]=(c[x>>2]|0)+Ea;t=L+1|0;if((t|0)<8){L=t;v=u}else{Ba=u;break e}}}}while(0);I=ha-3|0;v=35-ha|0;L=Q<<3;x=c[la>>2]|0;N=c[ia>>2]|0;n=N+($>>>3)|0;_=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<($&7)>>v;n=I+$|0;C=x>>>0>n>>>0?n:x;c[ua>>2]=C;c[k+(L<<2)>>2]=_;_=N+(C>>>3)|0;n=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(C&7)>>v;_=I+C|0;C=x>>>0>_>>>0?_:x;c[ua>>2]=C;c[k+((L|1)<<2)>>2]=n;n=N+(C>>>3)|0;_=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7)>>v;n=I+C|0;C=x>>>0>n>>>0?n:x;c[ua>>2]=C;c[k+((L|2)<<2)>>2]=_;_=N+(C>>>3)|0;n=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(C&7)>>v;_=I+C|0;C=x>>>0>_>>>0?_:x;c[ua>>2]=C;c[k+((L|3)<<2)>>2]=n;n=N+(C>>>3)|0;_=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7)>>v;n=I+C|0;C=x>>>0>n>>>0?n:x;c[ua>>2]=C;c[k+((L|4)<<2)>>2]=_;_=N+(C>>>3)|0;n=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(C&7)>>v;_=I+C|0;C=x>>>0>_>>>0?_:x;c[ua>>2]=C;c[k+((L|5)<<2)>>2]=n;n=N+(C>>>3)|0;_=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7)>>v;n=I+C|0;C=x>>>0>n>>>0?n:x;c[ua>>2]=C;c[k+((L|6)<<2)>>2]=_;_=N+(C>>>3)|0;N=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(C&7)>>v;v=I+C|0;C=x>>>0>v>>>0?v:x;c[ua>>2]=C;c[k+((L|7)<<2)>>2]=N;Ba=C}}while(0);ha=Q+1|0;aa=c[P>>2]|0;if((ha|0)<(aa|0)){Q=ha;$=Ba}else{Ga=aa;break}}}else{Ga=da}$=e+39808+(h*14336|0)+(ja<<11)|0;Q=$|0;pe[c[qa>>2]&1023](sa,$|0,ya,ra,Ga<<3);$=c[P>>2]|0;if(($|0)>0){aa=0;ha=$;while(1){if((c[e+2212+(ja<<8)+(aa<<2)>>2]|0)==0){Ha=ha}else{if((c[ea>>2]|0)==0){Ia=+g[e+39808+(h*14336|0)+(ja<<11)+(aa<<5)>>2];Ja=e+4004+(ja<<8)+(aa<<2)|0}else{C=e+4004+(ja<<8)+(aa<<2)|0;N=c[C>>2]|0;L=e+39808+(h*14336|0)+(ja<<11)+(aa<<5)|0;za=+g[L>>2]+(+(b[2033320+(N<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+12>>2]+ +(b[2033322+(N<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+8>>2]+ +(b[2033324+(N<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+4>>2]+ +(b[2033326+(N<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)>>2])*.0001220703125;g[L>>2]=za;Ia=za;Ja=C}C=1;za=Ia;do{L=c[Ja>>2]|0;Ka=za*+(b[2033320+(L<<3)>>1]|0);do{if((C|0)<2){if((c[ea>>2]|0)==0){La=Ka;break}La=Ka+ +(b[2033322+(L<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+(C+2<<2)>>2]}else{La=Ka+ +(b[2033322+(L<<3)>>1]|0)*+g[e+39808+(h*14336|0)+(ja<<11)+(aa<<5)+(C-2<<2)>>2]}}while(0);do{if((C|0)<3){if((c[ea>>2]|0)==0){Ma=La;break}Na=La+ +(b[2033324+(L<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+(C+1<<2)>>2];R=149}else{Ka=La+ +(b[2033324+(L<<3)>>1]|0)*+g[e+39808+(h*14336|0)+(ja<<11)+(aa<<5)+(C-3<<2)>>2];if((C|0)<4){if((c[ea>>2]|0)==0){Ma=Ka;break}else{Na=Ka;R=149;break}}else{Ma=Ka+ +(b[2033326+(L<<3)>>1]|0)*+g[e+39808+(h*14336|0)+(ja<<11)+(aa<<5)+(C-4<<2)>>2];break}}}while(0);if((R|0)==149){R=0;Ma=Na+ +(b[2033326+(L<<3)>>1]|0)*+g[e+17200+(ja<<10)+(aa<<4)+(C<<2)>>2]}N=e+39808+(h*14336|0)+(ja<<11)+(aa<<5)+(C<<2)|0;za=Ma*.0001220703125+ +g[N>>2];g[N>>2]=za;C=C+1|0;}while((C|0)<8);Ha=c[P>>2]|0}C=aa+1|0;if((C|0)<(Ha|0)){aa=C;ha=Ha}else{Oa=Ha;break}}}else{Oa=$}ha=e+124+(ja<<2)|0;aa=c[ha>>2]|0;if((aa|0)>(Oa|0)){if((c[ma>>2]|0)==0){KIb(c[pa>>2]|0,48,2318016,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[ma>>2]=c[ma>>2]|1;Pa=c[P>>2]|0;Qa=c[ha>>2]|0}else{Pa=Oa;Qa=aa}Se[c[na>>2]&1023](Q,e+14920+(ja<<8)|0,1109344,oa,e+9380+(ja<<9)|0,Pa,Qa)}aa=ja+1|0;ha=c[va>>2]|0;if((aa|0)<(ha|0)){ja=aa}else{Ra=ha;break c}}if((R|0)==196){i=j;return r|0}KIb(c[pa>>2]|0,16,2323040,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=j;return r|0}else{Ra=wa}}while(0);if((c[e+68>>2]|0)==0){if((Aa|0)==((c[e+2084+(c[m>>2]<<2)>>2]|0)-1|0)){R=138}}else{R=138}do{if((R|0)==138){Aa=e+290776|0;wa=c[Aa>>2]|0;Qa=c[e+290784>>2]|0;Pa=(c[e+290768>>2]|0)+(wa>>>3)|0;Oa=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(wa&7);Pa=wa+16|0;c[Aa>>2]=Qa>>>0>Pa>>>0?Pa:Qa;if((Oa&-65536|0)==-65536){break}KIb(c[e+4>>2]|0,16,2313240,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=j;return r|0}}while(0);if((Ra|0)>(f|0)){Oa=f;Qa=Ra;while(1){Ra=e+152+(Oa<<2)|0;if((c[Ra>>2]|0)>0){Pa=0;do{Aa=e+39808+(h*14336|0)+(Oa<<11)+(Pa<<5)+16|0;wa=c[Aa+4>>2]|0;Ha=e+17200+(Oa<<10)+(Pa<<4)|0;c[Ha>>2]=c[Aa>>2];c[Ha+4>>2]=wa;wa=e+39808+(h*14336|0)+(Oa<<11)+(Pa<<5)+24|0;Ha=c[wa+4>>2]|0;Aa=e+17200+(Oa<<10)+(Pa<<4)+8|0;c[Aa>>2]=c[wa>>2];c[Aa+4>>2]=Ha;Pa=Pa+1|0;}while((Pa|0)<(c[Ra>>2]|0));Sa=c[va>>2]|0}else{Sa=Qa}Ra=Oa+1|0;if((Ra|0)<(Sa|0)){Oa=Ra;Qa=Sa}else{break}}}Sa=(c[p>>2]|0)+1|0;c[p>>2]=Sa;Qa=c[m>>2]|0;if((Sa|0)<(c[e+2084+(Qa<<2)>>2]|0)){Ta=Qa}else{c[p>>2]=0;p=Qa+1|0;c[m>>2]=p;Ta=p}if(!((Ta|0)>=(c[o>>2]|0)&(f|0)==0)){r=0;i=j;return r|0}if((c[e+48>>2]|0)!=0){f=e+290776|0;o=c[f>>2]|0;Ta=-o|0;p=(c[e+290784>>2]|0)-o|0;if((Ta|0)>32){Ua=Ta}else{Ua=(p|0)<32?p:32}c[f>>2]=Ua+o}do{if((c[e+52>>2]|0)!=0){o=e+290776|0;Ua=c[o>>2]|0;f=e+290784|0;p=c[f>>2]|0;Ta=e+290768|0;m=c[Ta>>2]|0;Qa=m+(Ua>>>3)|0;Sa=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Ua&7)>>>26;Qa=Ua+6|0;Ua=p>>>0>Qa>>>0?Qa:p;c[o>>2]=Ua;Qa=-Ua|0;Oa=Qa&31;h=p-Ua|0;if((Oa|0)<(Qa|0)){Va=Qa}else{Va=(h|0)<(Oa|0)?h:Oa}Oa=Va+Ua|0;c[o>>2]=Oa;Ua=Oa+(Sa<<3)|0;Sa=m+(Oa>>>3)|0;h=(je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Oa&7)&-65536;Sa=Oa+16|0;Oa=p>>>0>Sa>>>0?Sa:p;c[o>>2]=Oa;Sa=m+(Oa>>>3)|0;Qa=(je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Oa&7)>>>16;Sa=Oa+16|0;Oa=p>>>0>Sa>>>0?Sa:p;c[o>>2]=Oa;Sa=Qa|h;if(!((Sa|0)==-1710160480)){KIb(c[e+4>>2]|0,16,2369600,(q=i,i=i+8|0,c[q>>2]=Sa,q)|0);i=q;r=-1094995529;i=j;return r|0}Sa=d[m+(Oa>>>3)|0]|0;h=((Oa|0)<(p|0))+Oa|0;c[o>>2]=h;if((Sa&128>>>((Oa&7)>>>0)|0)==0){Wa=h;Xa=m;Ya=p}else{QIb(c[e+4>>2]|0,2354888,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=c[o>>2]|0;m=c[f>>2]|0;h=(-p&4)+p|0;p=m>>>0>h>>>0?h:m;c[o>>2]=p;h=-p|0;Oa=m-p|0;if((h|0)>44){Za=h}else{Za=(Oa|0)<44?Oa:44}Oa=Za+p|0;c[o>>2]=Oa;Wa=Oa;Xa=c[Ta>>2]|0;Ya=m}m=d[Xa+(Wa>>>3)|0]<<(Wa&7)>>>7;Oa=((Wa|0)<(Ya|0))+Wa|0;c[o>>2]=Oa;p=m&1;a[e+14852|0]=p;do{if(p<<24>>24==0){_a=Oa;$a=Ya}else{m=Xa+(Oa>>>3)|0;h=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(Oa&7)>>>29;m=Oa+3|0;c[o>>2]=Ya>>>0>m>>>0?m:Ya;switch(h|0){case 5:{a[e+14853|0]=8;ab=8;break};case 6:{a[e+14853|0]=7;ab=7;break};case 0:{a[e+14853|0]=0;ab=0;break};case 1:{a[e+14853|0]=2;ab=2;break};case 2:{a[e+14853|0]=4;ab=4;break};case 3:{a[e+14853|0]=5;ab=5;break};case 4:{a[e+14853|0]=6;ab=6;break};default:{KIb(c[e+4>>2]|0,16,2345912,(q=i,i=i+8|0,c[q>>2]=h,q)|0);i=q;r=-1094995529;i=j;return r|0}}h=e+14853|0;m=e+72|0;Sa=0;Qa=c[va>>2]|0;Ra=c[m>>2]|0;Pa=ab;f:while(1){if((((Ra|0)!=0)+Qa|0)>0){pa=0;do{Ha=c[o>>2]|0;Aa=c[f>>2]|0;wa=(c[Ta>>2]|0)+(Ha>>>3)|0;bb=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Ha&7)>>>23;wa=Ha+9|0;c[o>>2]=Aa>>>0>wa>>>0?wa:Aa;if((bb&254)>>>0>241>>>0){break f}b[e+14854+(pa<<3)+(Sa<<1)>>1]=bb;pa=pa+1|0;cb=c[va>>2]|0;db=c[m>>2]|0;}while((pa|0)<(((db|0)!=0)+cb|0));eb=cb;fb=db;gb=a[h]|0}else{eb=Qa;fb=Ra;gb=Pa}pa=Sa+1|0;if((pa|0)<(d[1613528+(gb&255)|0]|0)){Sa=pa;Qa=eb;Ra=fb;Pa=gb}else{R=184;break}}if((R|0)==184){_a=c[o>>2]|0;$a=c[f>>2]|0;break}KIb(c[e+4>>2]|0,16,2339920,(q=i,i=i+8|0,c[q>>2]=bb,q)|0);i=q;r=-1094995529;i=j;return r|0}}while(0);Ta=-_a&7;if((Ta|0)==0){hb=_a}else{Oa=Ta+_a|0;Ta=$a>>>0>Oa>>>0?Oa:$a;c[o>>2]=Ta;hb=Ta}Ta=hb+16|0;Oa=$a>>>0>Ta>>>0?Ta:$a;c[o>>2]=Oa;Ta=Ua-Oa|0;if((Ta|0)<0){KIb(c[e+4>>2]|0,16,2334120,(q=i,i=i+8|0,c[q>>2]=-Ta,q)|0);i=q;r=-1094995529;i=j;return r|0}if((Ua|0)==(Oa|0)){break}QIb(c[e+4>>2]|0,2328880,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;Oa=c[o>>2]|0;p=-Oa|0;Pa=(c[f>>2]|0)-Oa|0;if((Ta|0)<(p|0)){ib=p}else{ib=(Pa|0)<(Ta|0)?Pa:Ta}c[o>>2]=ib+Oa}}while(0);if((c[e+16>>2]|0)==0){r=0;i=j;return r|0}if((c[e+44>>2]|0)==0){r=0;i=j;return r|0}ib=e+290776|0;q=c[e+290784>>2]|0;e=(c[ib>>2]|0)+16|0;c[ib>>2]=q>>>0>e>>>0?e:q;r=0;i=j;return r|0}



function nf(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7&-8;return b|0}function of(){return i|0}function pf(a){a=a|0;i=a}function qf(a,b){a=a|0;b=b|0;if((t|0)==0){t=a;u=b}}function rf(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function sf(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function tf(a){a=a|0;G=a}function uf(a){a=a|0;H=a}function vf(a){a=a|0;I=a}function wf(a){a=a|0;J=a}function xf(a){a=a|0;K=a}function yf(a){a=a|0;L=a}function zf(a){a=a|0;M=a}function Af(a){a=a|0;N=a}function Bf(a){a=a|0;O=a}function Cf(a){a=a|0;P=a}function Df(){}function Ef(){Jxb(c[1270866]|0);c[1270866]=0;OGb(5083472);OGb(6041776);OGb(9800208);OGb(5410088);return}function Ff(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;ld(c[p>>2]|0,d|0,e|0)|0;return}function Gf(a){a=a|0;c[1357568]=a;return}function Hf(a){a=a|0;var b=0;b=c[1357568]|0;if((b|0)==0){fc(a|0)}qe[b&1023](a);fc(a|0)}function If(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=+f;g=+g;var j=0,k=0,l=0.0,m=0;j=i;i=i+8|0;k=j|0;l=+SGb(d,k);do{if((a[c[k>>2]|0]|0)==0){if(l<f|l>g){m=2644576;break}if((e|0)==1024){if(+(~~+l>>>0>>>0)+ +((F=+l,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0)|0)*4294967296.0!=l){m=2470408;break}i=j;return+l}else if((e|0)==128){if(+(~~l|0)!=l){m=2376856;break}i=j;return+l}else{i=j;return+l}}else{m=2644632}}while(0);KIb(0,8,m,(m=i,i=i+32|0,c[m>>2]=b,c[m+8>>2]=d,h[m+16>>3]=f,h[m+24>>3]=g,m)|0);i=m;Hf(1);return 0.0}function Jf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;if((iKb(f,b,d)|0)<0){KIb(0,8,2309200,(g=i,i=i+24|0,c[g>>2]=(d|0)!=0?2256624:2211832,c[g+8>>2]=a,c[g+16>>2]=b,g)|0);i=g;Hf(1);return 0}else{i=e;return(G=c[f+4>>2]|0,c[f>>2]|0)|0}return 0}function Kf(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+64|0;h=a|0;a=c[h>>2]|0;if((a|0)==0){j=zc(10)|0;i=g;return}k=g|0;if((f|0)==0){l=1;m=h;n=a;while(1){o=c[m+4>>2]|0;do{if((o&d|0)==(d|0)){if((o&e|0)!=0){p=l;break}if((l|0)==0){q=n}else{Zc(b|0)|0;q=c[m>>2]|0}CFb(k,q,64)|0;r=m+16|0;if((c[r>>2]|0)!=0){DFb(k,2151448,64)|0;DFb(k,c[r>>2]|0,64)|0}r=c[m+12>>2]|0;Oc(2127024,(s=i,i=i+16|0,c[s>>2]=k,c[s+8>>2]=r,s)|0)|0;i=s;p=0}else{p=l}}while(0);o=m+20|0;r=c[o>>2]|0;if((r|0)==0){break}else{l=p;m=o;n=r}}j=zc(10)|0;i=g;return}else{t=1;u=h;v=a}while(1){a=c[u+4>>2]|0;do{if((a&d|0)==(d|0)){if((a&f|0)==0){w=t;break}if((a&e|0)!=0){w=t;break}if((t|0)==0){x=v}else{Zc(b|0)|0;x=c[u>>2]|0}CFb(k,x,64)|0;h=u+16|0;if((c[h>>2]|0)!=0){DFb(k,2151448,64)|0;DFb(k,c[h>>2]|0,64)|0}h=c[u+12>>2]|0;Oc(2127024,(s=i,i=i+16|0,c[s>>2]=k,c[s+8>>2]=h,s)|0)|0;i=s;w=0}else{w=t}}while(0);a=u+20|0;h=c[a>>2]|0;if((h|0)==0){break}else{t=w;u=a;v=h}}j=zc(10)|0;i=g;return}function Lf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=a;if((c[a+8>>2]|0)==0){f=a}else{QJb(e,0,b,0)|0;zc(10)|0;f=c[e>>2]|0}a=YJb(f,0)|0;if((a|0)==0){i=d;return}else{g=a}do{Lf(g,b);g=YJb(c[e>>2]|0,g)|0;}while((g|0)!=0);i=d;return}function Mf(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=_b(d|0,58)|0;if((h|0)==0){j=lrc(d|0)|0}else{j=h-d|0}h=f|0;k=c[h>>2]|0;l=(k|0)==0;a:do{if(l){m=f;n=9}else{o=f;p=k;while(1){if((krc(d,p,j)|0)==0){if((lrc(p|0)|0)==(j|0)){break}}q=o+20|0;r=c[q>>2]|0;if((r|0)==0){m=q;n=9;break a}else{o=q;p=r}}if((p|0)==0){m=o;n=9}else{s=o;n=20}}}while(0);b:do{if((n|0)==9){if((a[d]|0)!=110){s=m;n=20;break}if((a[d+1|0]|0)!=111){s=m;n=20;break}j=d+2|0;r=_b(j|0,58)|0;if((r|0)==0){t=lrc(j|0)|0}else{t=r-j|0}if(l){u=f;v=e;break}else{w=f;x=k}while(1){if((krc(j,x,t)|0)==0){if((lrc(x|0)|0)==(t|0)){break}}r=w+20|0;q=c[r>>2]|0;if((q|0)==0){u=r;v=e;break b}else{w=r;x=q}}if((c[w>>2]|0)==0){u=w;v=e;break}u=w;v=(c[w+4>>2]&2|0)==0?e:2622224}}while(0);if((n|0)==20){u=s;v=(c[s+4>>2]&2|0)==0?e:2594328}c:do{if((c[u>>2]|0)==0){e=c[h>>2]|0;d:do{if((e|0)!=0){s=f;n=e;while(1){if((krc(2571328,n,7)|0)==0){if((lrc(n|0)|0)==7){break}}w=s+20|0;x=c[w>>2]|0;if((x|0)==0){break d}else{s=w;n=x}}if((n|0)!=0){y=s;break c}}}while(0);KIb(0,16,2553352,(z=i,i=i+8|0,c[z>>2]=d,z)|0);i=z;A=-22;i=g;return A|0}else{y=u}}while(0);u=y+4|0;if((c[u>>2]&1|0)!=0&(v|0)==0){KIb(0,16,2535184,(z=i,i=i+8|0,c[z>>2]=d,z)|0);i=z;A=-22;i=g;return A|0}z=Nf(b,y,d,v)|0;if((z|0)<0){A=z;i=g;return A|0}A=c[u>>2]&1;i=g;return A|0}function Nf(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,G=0,H=0;j=i;i=i+104|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=d+4|0;r=c[q>>2]|0;if((r&49152|0)==0){t=c[d+8>>2]|0}else{t=b+(c[d+8>>2]|0)|0}do{if((r&32768|0)==0){u=t;v=r}else{w=t;x=_b(e|0,58)|0;y=t+4|0;z=(c[y>>2]|0)+1|0;if((z|0)>=134217727){KIb(0,16,2629248,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;Hf(1);return 0}B=iJb(c[w>>2]|0,z<<4)|0;if((B|0)==0){KIb(0,16,2627632,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;Hf(1);return 0}else{C=c[y>>2]|0;mrc(B+(C<<4)|0,0,z-C<<4|0)|0;c[y>>2]=z;c[w>>2]=B;B=rJb((x|0)==0?10230104:x+1|0)|0;x=(c[y>>2]|0)-1|0;c[(c[w>>2]|0)+(x<<4)>>2]=B;u=(c[w>>2]|0)+(x<<4)+8|0;v=c[q>>2]|0;break}}}while(0);do{if((v&8|0)==0){if((v&130|0)!=0){D=+SGb(f,o);if((a[c[o>>2]|0]|0)!=0){E=2644632;KIb(0,8,E,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-2147483648.0,h[A+24>>3]=2147483647.0,A)|0);i=A;Hf(1);return 0}if(D<-2147483648.0|D>2147483647.0){E=2644576;KIb(0,8,E,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-2147483648.0,h[A+24>>3]=2147483647.0,A)|0);i=A;Hf(1);return 0}if(+(~~+D>>>0>>>0)+ +((F=+D,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0)|0)*4294967296.0!=D){E=2470408;KIb(0,8,E,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-2147483648.0,h[A+24>>3]=2147483647.0,A)|0);i=A;Hf(1);return 0}else{c[u>>2]=~~D;break}}if((v&1024|0)!=0){D=+SGb(f,n);if((a[c[n>>2]|0]|0)!=0){G=2644632;KIb(0,8,G,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-9223372036854776000.0,h[A+24>>3]=9223372036854776000.0,A)|0);i=A;Hf(1);return 0}if(D<-9223372036854776000.0|D>9223372036854776000.0){G=2644576;KIb(0,8,G,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-9223372036854776000.0,h[A+24>>3]=9223372036854776000.0,A)|0);i=A;Hf(1);return 0}t=~~+D>>>0;r=(F=+D,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);if(+(t>>>0)+ +(r|0)*4294967296.0!=D){G=2470408;KIb(0,8,G,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-9223372036854776000.0,h[A+24>>3]=9223372036854776000.0,A)|0);i=A;Hf(1);return 0}else{x=u;c[x>>2]=t;c[x+4>>2]=r;break}}if((v&65536|0)!=0){if((iKb(m,f,1)|0)<0){KIb(0,8,2309200,(A=i,i=i+24|0,c[A>>2]=2256624,c[A+8>>2]=e,c[A+16>>2]=f,A)|0);i=A;Hf(1);return 0}else{r=c[m+4>>2]|0;x=u;c[x>>2]=c[m>>2];c[x+4>>2]=r;break}}if((v&256|0)!=0){D=+SGb(f,l);if((a[c[l>>2]|0]|0)==0){g[u>>2]=D;break}else{KIb(0,8,2644632,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-s,h[A+24>>3]=s,A)|0);i=A;Hf(1);return 0}}if((v&131072|0)!=0){D=+SGb(f,k);if((a[c[k>>2]|0]|0)==0){h[u>>3]=D;break}else{KIb(0,8,2644632,(A=i,i=i+32|0,c[A>>2]=e,c[A+8>>2]=f,h[A+16>>3]=-s,h[A+24>>3]=s,A)|0);i=A;Hf(1);return 0}}r=c[d+8>>2]|0;if((r|0)==0){break}x=Ee[r&511](b,e,f)|0;if((x|0)>=0){break}r=p|0;mrc(r|0,0,64)|0;a[r]=0;RGb(x,r,64)|0;KIb(0,16,2465e3,(A=i,i=i+24|0,c[A>>2]=f,c[A+8>>2]=e,c[A+16>>2]=r,A)|0);i=A;H=x;i=j;return H|0}else{x=rJb(f)|0;mJb(u);c[u>>2]=x}}while(0);if((c[q>>2]&2048|0)==0){H=0;i=j;return H|0}else{Hf(0);return 0}return 0}function Of(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=b|0;f=b+4|0;g=c[f>>2]|0;KIb(0,48,2519552,(h=i,i=i+16|0,c[h>>2]=c[c[e>>2]>>2],c[h+8>>2]=g,h)|0);i=h;g=b+12|0;j=b+8|0;b=0;while(1){if((b|0)>=(c[g>>2]|0)){k=7;break}l=c[j>>2]|0;m=l+(b*12|0)|0;n=c[e>>2]|0;o=c[n+8>>2]|0;p=c[m>>2]|0;if((o|0)!=0){if((c[p+4>>2]&o|0)==0){k=5;break}}o=l+(b*12|0)+4|0;q=c[p+12>>2]|0;r=l+(b*12|0)+8|0;s=c[r>>2]|0;KIb(0,48,2491376,(h=i,i=i+24|0,c[h>>2]=c[o>>2],c[h+8>>2]=q,c[h+16>>2]=s,h)|0);i=h;s=Nf(a,c[m>>2]|0,c[o>>2]|0,c[r>>2]|0)|0;if((s|0)<0){t=s;k=8;break}else{b=b+1|0}}if((k|0)==5){a=c[p+12>>2]|0;p=c[n>>2]|0;n=c[f>>2]|0;KIb(0,16,2505040,(h=i,i=i+32|0,c[h>>2]=c[l+(b*12|0)+4>>2],c[h+8>>2]=a,c[h+16>>2]=p,c[h+24>>2]=n,h)|0);i=h;t=-22;i=d;return t|0}else if((k|0)==7){KIb(0,48,2480560,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;t=0;i=d;return t|0}else if((k|0)==8){i=d;return t|0}return 0}function Pf(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((b|0)<=1){g=0;return g|0}h=e|0;i=1;while(1){j=c[d+(i<<2)>>2]|0;k=j+1|0;if((a[j]|0)==45){l=_b(k|0,58)|0;if((l|0)==0){m=lrc(k|0)|0}else{m=l-k|0}l=c[h>>2]|0;n=(l|0)==0;a:do{if(n){o=e;p=12}else{q=e;r=l;while(1){if((krc(k,r,m)|0)==0){if((lrc(r|0)|0)==(m|0)){break}}s=q+20|0;t=c[s>>2]|0;if((t|0)==0){o=s;p=12;break a}else{q=s;r=t}}if((r|0)==0){o=q;p=12}else{u=q}}}while(0);b:do{if((p|0)==12){p=0;if((a[k]|0)!=110){u=o;break}if((a[j+2|0]|0)!=111){u=o;break}t=j+3|0;s=_b(t|0,58)|0;if((s|0)==0){v=lrc(t|0)|0}else{v=s-t|0}if(n){u=e;break}else{w=e;x=l}while(1){if((krc(t,x,v)|0)==0){if((lrc(x|0)|0)==(v|0)){u=w;break b}}s=w+20|0;y=c[s>>2]|0;if((y|0)==0){u=s;break}else{w=s;x=y}}}}while(0);l=c[u>>2]|0;if((l|0)==0){if((irc(k,f)|0)==0){g=i;p=26;break}}else{if((irc(f,l)|0)==0){g=i;p=26;break}}z=(c[u+4>>2]&1)+i|0}else{z=i}l=z+1|0;if((l|0)<(b|0)){i=l}else{g=0;p=26;break}}if((p|0)==26){return g|0}return 0}function Qf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=Pf(b,d,e,2470392)|0;if((g|0)==0){h=Pf(b,d,e,2462792)|0;if((h|0)!=0){j=h;k=3}}else{j=g;k=3}do{if((k|0)==3){g=c[d+(j+1<<2)>>2]|0;if((g|0)==0){break}Rf(0,0,g)|0}}while(0);j=Pf(b,d,e,2445616)|0;g=id(2431952)|0;do{if(!((g|0)==0&(j|0)==0)){Sf(g)|0;h=c[1352790]|0;if((h|0)==0){break}ub(2423384,14,1,h|0)|0;if((b|0)>0){h=b-1|0;l=0;do{m=c[d+(l<<2)>>2]|0;n=a[m]|0;a:do{if(n<<24>>24==0){k=10}else{o=m;p=n;while(1){if(!((p-43&255)>>>0<16>>>0)){if(!((p-64&255)>>>0<27>>>0|p<<24>>24==95|(p-97&255)>>>0<26>>>0)){break}}q=o+1|0;r=a[q]|0;if(r<<24>>24==0){k=10;break a}else{o=q;p=r}}o=c[1352790]|0;if(p<<24>>24==0){s=o;k=15;break}sb(34,o|0)|0;o=a[m]|0;if(!(o<<24>>24==0)){r=m;q=o;do{o=q&255;do{if((q<<24>>24|0)==92|(q<<24>>24|0)==34|(q<<24>>24|0)==36|(q<<24>>24|0)==96){Id(c[1352790]|0,2466104,(t=i,i=i+8|0,c[t>>2]=o,t)|0)|0;i=t}else{u=c[1352790]|0;if((q-32&255)>>>0>94>>>0){Id(u|0,2465464,(t=i,i=i+8|0,c[t>>2]=o,t)|0)|0;i=t;break}else{sb(o|0,u|0)|0;break}}}while(0);r=r+1|0;q=a[r]|0;}while(!(q<<24>>24==0))}sb(34,c[1352790]|0)|0}}while(0);if((k|0)==10){k=0;s=c[1352790]|0;k=15}if((k|0)==15){k=0;xb(m|0,s|0)|0}sb(((l|0)<(h|0)?32:10)|0,c[1352790]|0)|0;l=l+1|0;}while((l|0)<(b|0))}qb(c[1352790]|0)|0}}while(0);if((Pf(b,d,e,2412528)|0)==0){i=f;return}c[1487396]=1;i=f;return}function Rf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;b=d|0;f=Db(e|0,2261056)|0;c[b>>2]=f;g=(f|0)==0;OIb(g&1);if((f|0)==(e|0)){h=e+((a[e+6|0]|0)==43|6)|0}else{h=e}do{if(g){j=0}else{if((a[h]|0)!=0){j=0;break}i=d;return 0}}while(0);while(1){if(!(j>>>0<8>>>0)){break}if((irc(c[774528+(j<<3)>>2]|0,h)|0)==0){k=7;break}else{j=j+1|0}}if((k|0)==7){NIb(c[774532+(j<<3)>>2]|0);i=d;return 0}j=rb(h|0,b|0,10)|0;if((a[c[b>>2]|0]|0)!=0){KIb(0,8,2256568,(b=i,i=i+8|0,c[b>>2]=h,b)|0);i=b;KIb(0,8,2253360,(b=i,i=i+8|0,c[b>>2]=2293560,b)|0);i=b;KIb(0,8,2253360,(b=i,i=i+8|0,c[b>>2]=2286016,b)|0);i=b;KIb(0,8,2253360,(b=i,i=i+8|0,c[b>>2]=2282e3,b)|0);i=b;KIb(0,8,2253360,(b=i,i=i+8|0,c[b>>2]=2277896,b)|0);i=b;KIb(0,8,2253360,(b=i,i=i+8|0,c[b>>2]=2273680,b)|0);i=b;KIb(0,8,2253360,(b=i,i=i+8|0,c[b>>2]=2268760,b)|0);i=b;KIb(0,8,2253360,(b=i,i=i+8|0,c[b>>2]=2264848,b)|0);i=b;KIb(0,8,2253360,(b=i,i=i+8|0,c[b>>2]=2405024,b)|0);i=b;Hf(1);return 0}NIb(j);i=d;return 0}function Sf(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+1120|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+1056|0;c[e>>2]=b;if((c[1352790]|0)!=0){l=0;i=d;return l|0}ie(h|0)|0;m=Ab(h|0)|0;a:do{if((b|0)==0){n=0}else{h=0;o=0;p=b;while(1){if((a[p]|0)==0){n=h;break a}q=VJb(e,2480552,2480192,0,f,g)|0;if((q|0)<0){break}r=c[e>>2]|0;if((a[r]|0)!=0){c[e>>2]=r+1}r=c[f>>2]|0;if((irc(r,2474768)|0)==0){kJb(h);s=c[g>>2]|0;c[g>>2]=0;t=s;u=0}else{KIb(0,16,2474016,(v=i,i=i+8|0,c[v>>2]=r,v)|0);i=v;t=h;u=c[g>>2]|0}kJb(u);kJb(c[f>>2]|0);r=c[e>>2]|0;if((r|0)==0){n=t;break a}else{h=t;o=o+1|0;p=r}}if((o|0)==0){n=h;break}p=k|0;mrc(p|0,0,64)|0;a[p]=0;RGb(q,p,64)|0;KIb(0,16,2477264,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v;n=h}}while(0);SFb(j,0,1);q=m+20|0;k=m+16|0;t=m+12|0;e=m+8|0;f=m+4|0;u=m|0;m=(n|0)!=0?n:2473360;while(1){g=m+1|0;b=a[m]|0;if((b<<24>>24|0)==0){break}else if((b<<24>>24|0)!=37){WFb(j,b,1);m=g;continue}b=m+2|0;p=a[g]|0;if(p<<24>>24==0){break}g=p<<24>>24;if((g|0)==112){UFb(j,2470384,(v=i,i=i+8|0,c[v>>2]=699200,v)|0);i=v;m=b;continue}else if((g|0)==116){r=(c[k>>2]|0)+1|0;s=c[t>>2]|0;w=c[e>>2]|0;x=c[f>>2]|0;y=c[u>>2]|0;UFb(j,2470200,(v=i,i=i+48|0,c[v>>2]=(c[q>>2]|0)+1900,c[v+8>>2]=r,c[v+16>>2]=s,c[v+24>>2]=w,c[v+32>>2]=x,c[v+40>>2]=y,v)|0);i=v;m=b;continue}else if((g|0)==37){WFb(j,p,1);m=b;continue}else{m=b;continue}}kJb(n);if(!((c[j+4>>2]|0)>>>0<(c[j+8>>2]|0)>>>0)){KIb(0,16,2472840,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;l=-12;i=d;return l|0}n=j|0;m=Qc(c[n>>2]|0,2472224)|0;c[1352790]=m;if((m|0)==0){m=c[n>>2]|0;b=pd()|0;p=qd(c[b>>2]|0)|0;KIb(0,16,2471608,(v=i,i=i+16|0,c[v>>2]=m,c[v+8>>2]=p,v)|0);i=v;l=-(c[b>>2]|0)|0;i=d;return l|0}else{PIb(894);b=(c[q>>2]|0)+1900|0;q=(c[k>>2]|0)+1|0;k=c[t>>2]|0;t=c[e>>2]|0;e=c[f>>2]|0;f=c[u>>2]|0;u=c[n>>2]|0;KIb(0,32,2470856,(v=i,i=i+64|0,c[v>>2]=699200,c[v+8>>2]=b,c[v+16>>2]=q,c[v+24>>2]=k,c[v+32>>2]=t,c[v+40>>2]=e,c[v+48>>2]=f,c[v+56>>2]=u,v)|0);i=v;_Fb(j,0)|0;l=0;i=d;return l|0}return 0}function Tf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+168|0;f=b|0;g=b+128|0;h=b+136|0;j=b+144|0;k=b+152|0;l=b+160|0;c[g>>2]=oWa()|0;c[h>>2]=IR()|0;if((irc(d,2405024)|0)==0){m=3}else{if((irc(d,2397704)|0)==0){m=3}}if((m|0)==3){NIb(48)}n=_b(d|0,58)|0;if((n|0)==0){o=d+(lrc(d|0)|0)|0}else{o=n}n=f|0;f=o-d+1|0;CFb(n,d,f>>>0<128>>>0?f:128)|0;f=g;g=DJb(f,n,0,0,3)|0;if((g|0)==0){m=8}else{if((c[g+40>>2]|0)==0){m=8}else{p=g;m=11}}do{if((m|0)==8){g=a[d]|0;if(!((g<<24>>24|0)==118|(g<<24>>24|0)==97|(g<<24>>24|0)==115)){q=0;break}g=DJb(f,d+1|0,0,0,2)|0;if((g|0)==0){q=0;break}if((c[g+40>>2]|0)==0){q=0}else{p=g;m=11}}}while(0);if((m|0)==11){MGb(9800208,d,e,(c[p+12>>2]|0)==0?32:0)|0;q=1}p=DJb(h,d,0,0,3)|0;do{if((p|0)==0){m=17}else{if((c[p+40>>2]|0)==0){m=17;break}MGb(6041776,d,e,(c[p+12>>2]|0)==0?32:0)|0;if((q|0)!=0){KIb(0,40,2390480,(r=i,i=i+8|0,c[r>>2]=d,r)|0);i=r}c[j>>2]=exb()|0;s=1;m=23}}while(0);a:do{if((m|0)==17){c[j>>2]=exb()|0;if((q|0)!=0){s=q;m=23;break}p=DJb(j,d,0,0,3)|0;do{if((p|0)==0){t=Wvb()|0}else{if((c[p+40>>2]|0)==0){t=Wvb()|0;break}h=EJb(c[1270866]|0,d,e,0)|0;if((h|0)>=0){s=1;m=23;break a}KIb(0,16,2383600,(r=i,i=i+8|0,c[r>>2]=d,r)|0);i=r;u=h;i=b;return u|0}}while(0);c[k>>2]=t;p=DJb(k,d,0,0,3)|0;if((p|0)==0){v=0;break}if((c[p+40>>2]|0)==0){v=0;break}h=Xvb()|0;c[l>>2]=h;f=EJb(h,d,e,0)|0;Zvb(l);if((f|0)>=0){MGb(5083472,d,e,(c[p+12>>2]|0)==0?32:0)|0;v=1;break}KIb(0,16,2383600,(r=i,i=i+8|0,c[r>>2]=d,r)|0);i=r;u=f;i=b;return u|0}}while(0);if((m|0)==23){c[k>>2]=Wvb()|0;v=s}u=(v|0)==0?-1414549496:0;i=b;return u|0}function Uf(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+40|0;d=a+36|0;if((c[b>>2]|0)>0){e=0;do{f=c[d>>2]|0;g=f+(e*12|0)+8|0;h=f+(e*12|0)+4|0;if((c[g>>2]|0)>0){f=0;do{mJb((c[h>>2]|0)+(f*36|0)+8|0);OGb((c[h>>2]|0)+(f*36|0)+16|0);OGb((c[h>>2]|0)+(f*36|0)+20|0);OGb((c[h>>2]|0)+(f*36|0)+24|0);Jxb(c[(c[h>>2]|0)+(f*36|0)+28>>2]|0);OGb((c[h>>2]|0)+(f*36|0)+32|0);f=f+1|0;}while((f|0)<(c[g>>2]|0))}mJb(h);e=e+1|0;}while((e|0)<(c[b>>2]|0))}mJb(d);mJb(a+52|0);mJb(a+8|0);Jxb(c[1270866]|0);c[1270866]=0;OGb(5083472);OGb(6041776);OGb(9800208);OGb(5410088);return}function Vf(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;mrc(b|0,0,80)|0;k=b+40|0;c[k>>2]=h;l=pJb(h*12|0)|0;m=l;n=b+36|0;c[n>>2]=m;if((l|0)==0){Hf(1);return 0}o=c[k>>2]|0;a:do{if((o|0)>0){c[l>>2]=g;if((o|0)>1){p=1;q=m}else{break}while(1){c[q+(p*12|0)>>2]=g+(p*12|0);k=p+1|0;if((k|0)>=(o|0)){break a}p=k;q=c[n>>2]|0}}}while(0);c[b>>2]=1071752;c[b+4>>2]=10230104;c[1270866]=Ixb(16,16,0,16,16,0,4,0,0,0)|0;KIb(0,48,2376824,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;b:do{if((d|0)>1){p=(h|0)>0;o=f|0;m=b+44|0;l=g|0;k=1;r=-2;c:while(1){s=r+1|0;t=k;d:while(1){u=t+1|0;v=c[e+(t<<2)>>2]|0;KIb(0,48,2371392,(q=i,i=i+8|0,c[q>>2]=v,q)|0);i=q;e:do{if((a[v]|0)==45){w=v+1|0;x=a[w]|0;if((x<<24>>24|0)==0){y=15;break}else if((x<<24>>24|0)==45){if((a[v+2|0]|0)==0){break d}}if((s|0)==(u|0)){y=15;break}f:do{if(p){z=0;while(1){A=c[g+(z*12|0)+4>>2]|0;if((A|0)!=0){if((irc(A,w)|0)==0){break}}A=z+1|0;if((A|0)<(h|0)){z=A}else{break f}}if(!((z|0)>-1)){break}A=c[e+(u<<2)>>2]|0;if((A|0)==0){y=27;break c}B=c[n>>2]|0;C=B+(z*12|0)+4|0;D=B+(z*12|0)+8|0;E=c[D>>2]|0;F=E+1|0;if((F|0)>=59652323){y=29;break c}G=iJb(c[C>>2]|0,F*36|0)|0;if((G|0)==0){y=31;break c}H=c[D>>2]|0;mrc(G+(H*36|0)|0,0,(F-H|0)*36|0|0)|0;c[D>>2]=F;F=G;c[C>>2]=F;C=F+(E*36|0)|0;nrc(C|0,m|0,36)|0;c[F+(E*36|0)+4>>2]=A;c[C>>2]=c[B+(z*12|0)>>2];c[F+(E*36|0)+28>>2]=c[1270866];c[F+(E*36|0)+32>>2]=c[1270868];c[F+(E*36|0)+16>>2]=c[2450052];c[F+(E*36|0)+20>>2]=c[1510444];c[F+(E*36|0)+24>>2]=c[1352522];c[2450052]=0;c[1510444]=0;c[1352522]=0;c[1270866]=0;c[1270868]=0;c[1270866]=Ixb(16,16,0,16,16,0,4,0,0,0)|0;mrc(m|0,0,36)|0;KIb(0,48,2340608,(q=i,i=i+16|0,c[q>>2]=c[g+(z*12|0)>>2],c[q+8>>2]=A,q)|0);i=q;I=t+2|0;break e}}while(0);A=_b(w|0,58)|0;if((A|0)==0){J=lrc(w|0)|0}else{J=A-w|0}A=c[o>>2]|0;g:do{if((A|0)!=0){E=f;F=A;while(1){if((krc(w,F,J)|0)==0){if((lrc(F|0)|0)==(J|0)){break}}B=E+20|0;C=c[B>>2]|0;if((C|0)==0){break g}else{E=B;F=C}}z=E|0;if((F|0)==0){break}C=c[E+4>>2]|0;do{if((C&2048|0)==0){if((C&1|0)==0){K=2594328;L=u;break}B=c[e+(u<<2)>>2]|0;if((B|0)==0){y=45;break c}else{K=B;L=t+2|0}}else{K=c[e+(u<<2)>>2]|0;L=t+2|0}}while(0);Wf(b,E,w,K);C=c[E+12>>2]|0;KIb(0,48,2334800,(q=i,i=i+24|0,c[q>>2]=c[z>>2],c[q+8>>2]=C,c[q+16>>2]=K,q)|0);i=q;I=L;break e}}while(0);M=e+(u<<2)|0;A=c[M>>2]|0;if((A|0)==0){N=x}else{O=Tf(0,w,A)|0;if((O|0)>-1){A=c[M>>2]|0;KIb(0,48,2329688,(q=i,i=i+16|0,c[q>>2]=w,c[q+8>>2]=A,q)|0);i=q;I=t+2|0;break}if(!((O|0)==-1414549496)){y=52;break c}N=a[w]|0}if(!(N<<24>>24==110)){y=66;break c}if((a[v+2|0]|0)!=111){y=66;break c}A=v+3|0;C=_b(A|0,58)|0;if((C|0)==0){P=lrc(A|0)|0}else{P=C-A|0}C=c[o>>2]|0;h:do{if((C|0)==0){Q=f}else{F=f;B=C;while(1){if((krc(A,B,P)|0)==0){if((lrc(B|0)|0)==(P|0)){Q=F;break h}}G=F+20|0;D=c[G>>2]|0;if((D|0)==0){Q=G;break}else{F=G;B=D}}}}while(0);if((Q|0)==0){y=66;break c}A=Q|0;if((c[A>>2]|0)==0){y=66;break c}if((c[Q+4>>2]&2|0)==0){y=66;break c}Wf(b,Q,w,2622224);C=c[Q+12>>2]|0;KIb(0,48,2318680,(q=i,i=i+16|0,c[q>>2]=c[A>>2],c[q+8>>2]=C,q)|0);i=q;I=u}else{y=15}}while(0);if((y|0)==15){y=0;C=c[n>>2]|0;A=C+4|0;x=C+8|0;B=c[x>>2]|0;F=B+1|0;if((F|0)>=59652323){y=16;break c}z=iJb(c[A>>2]|0,F*36|0)|0;if((z|0)==0){y=18;break c}E=c[x>>2]|0;mrc(z+(E*36|0)|0,0,(F-E|0)*36|0|0)|0;c[x>>2]=F;F=z;c[A>>2]=F;A=F+(B*36|0)|0;nrc(A|0,m|0,36)|0;c[F+(B*36|0)+4>>2]=v;c[A>>2]=c[C>>2];c[F+(B*36|0)+28>>2]=c[1270866];c[F+(B*36|0)+32>>2]=c[1270868];c[F+(B*36|0)+16>>2]=c[2450052];c[F+(B*36|0)+20>>2]=c[1510444];c[F+(B*36|0)+24>>2]=c[1352522];c[2450052]=0;c[1510444]=0;c[1352522]=0;c[1270866]=0;c[1270868]=0;c[1270866]=Ixb(16,16,0,16,16,0,4,0,0,0)|0;mrc(m|0,0,36)|0;KIb(0,48,2356336,(q=i,i=i+8|0,c[q>>2]=c[l>>2],q)|0);i=q;I=u}if((I|0)<(d|0)){t=I}else{break b}}if((u|0)<(d|0)){k=u;r=u}else{break b}}if((y|0)==16){KIb(0,16,2629248,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;Hf(1);return 0}else if((y|0)==18){KIb(0,16,2627632,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;Hf(1);return 0}else if((y|0)==27){KIb(0,16,2346752,(q=i,i=i+8|0,c[q>>2]=w,q)|0);i=q;R=-22;i=j;return R|0}else if((y|0)==29){KIb(0,16,2629248,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;Hf(1);return 0}else if((y|0)==31){KIb(0,16,2627632,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;Hf(1);return 0}else if((y|0)==45){KIb(0,16,2346752,(q=i,i=i+8|0,c[q>>2]=w,q)|0);i=q;R=-22;i=j;return R|0}else if((y|0)==52){r=c[M>>2]|0;KIb(0,16,2323664,(q=i,i=i+16|0,c[q>>2]=w,c[q+8>>2]=r,q)|0);i=q;R=O;i=j;return R|0}else if((y|0)==66){KIb(0,16,2313624,(q=i,i=i+8|0,c[q>>2]=w,q)|0);i=q;R=-1414549496;i=j;return R|0}}}while(0);if((c[b+56>>2]|0)!=0|(c[2450052]|0)!=0|(c[1510444]|0)!=0|(c[1352522]|0)!=0){KIb(0,24,2309144,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}KIb(0,48,2305344,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;R=0;i=j;return R|0}function Wf(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=(c[b+4>>2]&57344|0)==0?a|0:a+44|0;a=g+8|0;h=g+12|0;g=c[h>>2]|0;j=g+1|0;if((j|0)>=178956970){KIb(0,16,2629248,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;Hf(1)}l=iJb(c[a>>2]|0,j*12|0)|0;if((l|0)==0){KIb(0,16,2627632,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;Hf(1)}else{k=c[h>>2]|0;mrc(l+(k*12|0)|0,0,(j-k|0)*12|0|0)|0;c[h>>2]=j;j=l;c[a>>2]=j;c[j+(g*12|0)>>2]=b;c[(c[a>>2]|0)+(g*12|0)+4>>2]=d;c[(c[a>>2]|0)+(g*12|0)+8>>2]=e;i=f;return}}function Xf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;a=b|0;c[a>>2]=AGb()|0;e=BGb(a,d)|0;if((e|0)<0){f=e;i=b;return f|0}zGb(c[a>>2]|0);f=0;i=b;return f|0}function Yf(a){a=a|0;return Sf(0)|0}function Zf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;d=i;i=i+8|0;b=d|0;f=rb(e|0,b|0,10)|0;if((a[c[b>>2]|0]|0)==0){gJb(f);i=d;return 0}else{KIb(0,8,2242560,(d=i,i=i+8|0,c[d>>2]=e,d)|0);i=d;Hf(1);return 0}return 0}function _f(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0.0,k=0,l=0;b=i;i=i+16|0;f=b|0;g=b+8|0;j=+SGb(e,f);do{if((a[c[f>>2]|0]|0)==0){if(j<0.0|j>2147483647.0){k=2644576;break}if(+(~~+j>>>0>>>0)+ +((F=+j,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0)|0)*4294967296.0!=j){k=2470408;break}l=~~j;c[g>>2]=l;c[g+4>>2]=l+1;if((jc(0,g|0)|0)==0){i=b;return 0}Gb(2236192);i=b;return 0}else{k=2644632}}while(0);KIb(0,8,k,(k=i,i=i+32|0,c[k>>2]=d,c[k+8>>2]=e,h[k+16>>3]=0.0,h[k+24>>3]=2147483647.0,k)|0);i=k;Hf(1);return 0}function $f(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+128|0;e=d|0;if((RGb(b,e,128)|0)<0){f=qd(-b|0)|0}else{f=e}KIb(0,16,2232584,(e=i,i=i+16|0,c[e>>2]=a,c[e+8>>2]=f,e)|0);i=e;i=d;return}function ag(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=Pf(a,b,d,2228544)|0;if((c[1487396]|f|0)!=0){i=e;return}KIb(0,32,2486416,(f=i,i=i+8|0,c[f>>2]=699200,f)|0);i=f;KIb(0,32,2485584,(f=i,i=i+16|0,c[f>>2]=c[174802],c[f+8>>2]=2014,f)|0);i=f;KIb(0,32,2644568,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;KIb(0,32,2484768,(f=i,i=i+32|0,c[f>>2]=2512088,c[f+8>>2]=2484208,c[f+16>>2]=2483416,c[f+24>>2]=2482824,f)|0);i=f;KIb(0,32,2481240,(f=i,i=i+8|0,c[f>>2]=2512088,f)|0);i=f;bg(5);bg(3);i=e;return}function bg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=(b&1|0)!=0?2512088:10230104;f=(b&2|0)!=0;if(f){g=yLb()|0;KIb(0,32,2504528,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2501e3,c[h+16>>2]=52,c[h+24>>2]=66,c[h+32>>2]=100,c[h+40>>2]=g>>>16,c[h+48>>2]=g>>>8&255,c[h+56>>2]=g&255,h)|0);i=h}g=(b&4|0)!=0;do{if(g){b=zLb()|0;if((irc(2497880,b)|0)==0){break}if(!(a[156672]|0)){KIb(0,32,2496656,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[156672]=1}KIb(0,32,2495480,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2501e3,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=x5a()|0;KIb(0,32,2504528,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2494448,c[h+16>>2]=55,c[h+24>>2]=52,c[h+32>>2]=102,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=y5a()|0;if((irc(2497880,b)|0)==0){break}if(!(a[156672]|0)){KIb(0,32,2496656,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[156672]=1}KIb(0,32,2495480,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2494448,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=$W()|0;KIb(0,32,2504528,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2493448,c[h+16>>2]=55,c[h+24>>2]=33,c[h+32>>2]=100,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=aX()|0;if((irc(2497880,b)|0)==0){break}if(!(a[156672]|0)){KIb(0,32,2496656,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[156672]=1}KIb(0,32,2495480,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2493448,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=ai()|0;KIb(0,32,2504528,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2492600,c[h+16>>2]=55,c[h+24>>2]=10,c[h+32>>2]=100,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=bi()|0;if((irc(2497880,b)|0)==0){break}if(!(a[156672]|0)){KIb(0,32,2496656,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[156672]=1}KIb(0,32,2495480,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2492600,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=Oi()|0;KIb(0,32,2504528,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2491912,c[h+16>>2]=4,c[h+24>>2]=2,c[h+32>>2]=100,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=Pi()|0;if((irc(2497880,b)|0)==0){break}if(!(a[156672]|0)){KIb(0,32,2496656,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[156672]=1}KIb(0,32,2495480,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2491912,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=xxb()|0;KIb(0,32,2504528,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2491368,c[h+16>>2]=2,c[h+24>>2]=5,c[h+32>>2]=102,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=yxb()|0;if((irc(2497880,b)|0)==0){break}if(!(a[156672]|0)){KIb(0,32,2496656,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[156672]=1}KIb(0,32,2495480,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2491368,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){b=Tvb()|0;KIb(0,32,2504528,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2491064,c[h+16>>2]=0,c[h+24>>2]=18,c[h+32>>2]=100,c[h+40>>2]=b>>>16,c[h+48>>2]=b>>>8&255,c[h+56>>2]=b&255,h)|0);i=h}do{if(g){b=Uvb()|0;if((irc(2497880,b)|0)==0){break}if(!(a[156672]|0)){KIb(0,32,2496656,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[156672]=1}KIb(0,32,2495480,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2491064,c[h+16>>2]=b,h)|0);i=h}}while(0);if(f){f=hvb()|0;KIb(0,32,2504528,(h=i,i=i+64|0,c[h>>2]=e,c[h+8>>2]=2488232,c[h+16>>2]=52,c[h+24>>2]=3,c[h+32>>2]=100,c[h+40>>2]=f>>>16,c[h+48>>2]=f>>>8&255,c[h+56>>2]=f&255,h)|0);i=h}if(!g){i=d;return}g=ivb()|0;if((irc(2497880,g)|0)==0){i=d;return}if(!(a[156672]|0)){KIb(0,32,2496656,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;a[156672]=1}KIb(0,32,2495480,(h=i,i=i+24|0,c[h>>2]=e,c[h+8>>2]=2488232,c[h+16>>2]=g,h)|0);i=h;i=d;return}function cg(a,b,d){a=a|0;b=b|0;d=d|0;d=i;PIb(606);KIb(0,32,2486416,(b=i,i=i+8|0,c[b>>2]=699200,b)|0);i=b;KIb(0,32,2644568,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;KIb(0,32,2484768,(b=i,i=i+32|0,c[b>>2]=10230104,c[b+8>>2]=2484208,c[b+16>>2]=2483416,c[b+24>>2]=2482824,b)|0);i=b;KIb(0,32,2481240,(b=i,i=i+8|0,c[b>>2]=10230104,b)|0);i=b;bg(2);i=d;return 0}function dg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;e=i;i=i+744|0;PIb(606);d=e|0;nrc(d|0,2497880,744)|0;b=Db(d|0,2510680)|0;if((b|0)!=0){f=b;do{a[f]=a[2509456]|0;a[f+1|0]=a[2509457]|0;a[f+2|0]=a[2509458]|0;f=Db(d|0,2510680)|0;}while((f|0)!=0)}f=Db(d|0,2508680)|0;if((f|0)!=0){b=f;do{nrc(b|0,2507848,11)|0;b=Db(d|0,2508680)|0;}while((b|0)!=0)}b=tb(d|0,2507008)|0;KIb(0,32,2506008,(d=i,i=i+8|0,c[d>>2]=2512088,d)|0);i=d;if((b|0)==0){i=e;return 0}else{g=b}do{KIb(0,32,2505032,(d=i,i=i+24|0,c[d>>2]=2512088,c[d+8>>2]=2512088,c[d+16>>2]=g,d)|0);i=d;g=tb(0,2507008)|0;}while((g|0)!=0);i=e;return 0}function eg(a,b,d){a=a|0;b=b|0;d=d|0;d=i;Oc(2224024,(b=i,i=i+24|0,c[b>>2]=699200,c[b+8>>2]=699200,c[b+16>>2]=699200,b)|0)|0;i=b;i=d;return 0}function fg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;Zc(554456)|0;b=2217208;while(1){a=cH(0)|0;a:do{if((a|0)==0){e=0;f=0;g=0;h=0;j=0}else{k=0;l=0;m=0;n=a;while(1){b:do{if((l|0)==0){o=n;while(1){p=c[o>>2]|0;if((irc(p,b)|0)>0){q=o;r=p;break b}p=cH(o)|0;if((p|0)==0){e=m;f=0;g=k;h=0;j=0;break a}else{o=p}}}else{o=n;while(1){p=c[o>>2]|0;if((irc(p,l)|0)<0){if((irc(p,b)|0)>0){q=o;r=p;break b}}p=cH(o)|0;if((p|0)==0){e=m;f=l;g=k;h=0;j=0;break a}else{o=p}}}}while(0);o=c[q+4>>2]|0;p=cH(q)|0;if((p|0)==0){e=o;f=r;g=1;h=0;j=0;break}else{k=1;l=r;m=o;n=p}}}}while(0);c:while(1){s=e;t=f;u=g;a=j;while(1){v=bH(a)|0;w=(t|0)==0;if((v|0)==0){break c}x=c[v>>2]|0;if(!w){if((irc(x,t)|0)>=0){y=u;z=t;A=s;break}}if((irc(x,b)|0)>0){B=c[v+4>>2]|0;C=x;D=0}else{B=s;C=t;D=u}if((C|0)==0){s=B;t=0;u=D;a=v}else{y=D;z=C;A=B;break}}a=(irc(x,z)|0)==0;e=A;f=z;g=y;h=a?1:h;j=v}if(w){break}Oc(2214344,(a=i,i=i+32|0,c[a>>2]=(h|0)!=0?2211824:2151448,c[a+8>>2]=(u|0)!=0?2210312:2151448,c[a+16>>2]=t,c[a+24>>2]=(s|0)!=0?s:2151448,a)|0)|0;i=a;b=t}i=d;return 0}function gg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;b=d|0;a=hg(b)|0;Zc(553968)|0;e=c[b>>2]|0;if((a|0)==0){f=e;kJb(f);i=d;return 0}else{g=0}do{b=c[e+(g<<2)>>2]|0;zc(32)|0;h=b|0;j=(c5a(c[h>>2]|0)|0)!=0;Oc((j?2211824:2196096)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;k=(b5a(c[h>>2]|0)|0)!=0;Oc((k?2210312:2196096)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;switch(c[b+4>>2]|0){case 2:{l=68;break};case 1:{l=65;break};case 3:{l=83;break};case 4:{l=84;break};case 0:{l=86;break};default:{l=63}}zc(l|0)|0;k=b+16|0;Oc(((c[k>>2]&1|0)!=0?2190968:2196096)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;Oc(((c[k>>2]&2|0)!=0?2188496:2196096)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;Oc(((c[k>>2]&4|0)!=0?2185816:2196096)|0,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;k=b+8|0;m=c[b+12>>2]|0;Oc(2183632,(j=i,i=i+16|0,c[j>>2]=c[k>>2],c[j+8>>2]=(m|0)==0?10230104:m,j)|0)|0;i=j;m=0;a:while(1){b=c[h>>2]|0;n=C4a(m)|0;if((n|0)==0){o=0;break}else{p=n}while(1){if((c[p+12>>2]|0)==(b|0)){if((E4a(p)|0)!=0){break}}n=C4a(p)|0;if((n|0)==0){o=0;break a}else{p=n}}if((p|0)==0){o=0;break}if((irc(c[p>>2]|0,c[k>>2]|0)|0)==0){m=p}else{q=15;break}}if((q|0)==15){q=0;m=c[h>>2]|0;Oc(2523616,(j=i,i=i+8|0,c[j>>2]=2571312,j)|0)|0;i=j;b=C4a(0)|0;b:do{if((b|0)!=0){n=b;while(1){if((c[n+12>>2]|0)==(m|0)){if((E4a(n)|0)!=0){break}}r=C4a(n)|0;if((r|0)==0){break b}else{n=r}}if((n|0)==0){break}else{s=n}while(1){Oc(2522632,(j=i,i=i+8|0,c[j>>2]=c[s>>2],j)|0)|0;i=j;r=C4a(s)|0;if((r|0)==0){break b}else{t=r}while(1){if((c[t+12>>2]|0)==(m|0)){if((E4a(t)|0)!=0){break}}r=C4a(t)|0;if((r|0)==0){break b}else{t=r}}if((t|0)==0){break}else{s=t}}}}while(0);zc(41)|0;o=0}c:while(1){m=c[h>>2]|0;b=C4a(o)|0;if((b|0)==0){break}else{u=b}while(1){if((c[u+12>>2]|0)==(m|0)){if((D4a(u)|0)!=0){break}}b=C4a(u)|0;if((b|0)==0){break c}else{u=b}}if((u|0)==0){break}if((irc(c[u>>2]|0,c[k>>2]|0)|0)==0){o=u}else{q=32;break}}if((q|0)==32){q=0;k=c[h>>2]|0;Oc(2523616,(j=i,i=i+8|0,c[j>>2]=2572760,j)|0)|0;i=j;m=C4a(0)|0;d:do{if((m|0)!=0){b=m;while(1){if((c[b+12>>2]|0)==(k|0)){if((D4a(b)|0)!=0){break}}n=C4a(b)|0;if((n|0)==0){break d}else{b=n}}if((b|0)==0){break}else{v=b}while(1){Oc(2522632,(j=i,i=i+8|0,c[j>>2]=c[v>>2],j)|0)|0;i=j;n=C4a(v)|0;if((n|0)==0){break d}else{w=n}while(1){if((c[w+12>>2]|0)==(k|0)){if((D4a(w)|0)!=0){break}}n=C4a(w)|0;if((n|0)==0){break d}else{w=n}}if((w|0)==0){break}else{v=w}}}}while(0);zc(41)|0}zc(10)|0;g=g+1|0;}while(g>>>0<a>>>0);f=e;kJb(f);i=d;return 0}function hg(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=0;e=0;while(1){f=v4(e)|0;if((f|0)==0){break}else{d=d+1|0;e=f}}e=qJb(d,4)|0;f=e;if((e|0)==0){KIb(0,16,2520488,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;Hf(1);return 0}h=v4(0)|0;if((h|0)==0){j=0}else{k=0;l=h;while(1){h=k+1|0;c[f+(k<<2)>>2]=l;m=v4(l)|0;if((m|0)==0){j=h;break}else{k=h;l=m}}}if((j|0)==(d|0)){cd(e|0,d|0,4,386);c[a>>2]=f;i=b;return d|0}else{KIb(0,0,2519520,(g=i,i=i+24|0,c[g>>2]=2518744,c[g+8>>2]=2514792,c[g+16>>2]=1344,g)|0);i=g;Hd();return 0}return 0}function ig(a,b,c){a=a|0;b=b|0;c=c|0;jg(0);return 0}function jg(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+8|0;d=b|0;e=hg(d)|0;Oc(2537816,(f=i,i=i+8|0,c[f>>2]=(a|0)!=0?2536424:2535168,f)|0)|0;i=f;g=c[d>>2]|0;if((e|0)==0){h=g;kJb(h);i=b;return}d=(a|0)==0;a=0;do{j=c[g+(a<<2)>>2]|0;k=j|0;l=c[k>>2]|0;m=C4a(0)|0;a:do{if((m|0)!=0){n=j+4|0;o=j+8|0;p=l;q=m;while(1){r=q;b:while(1){do{if((c[r+12>>2]|0)==(p|0)){if(d){if((E4a(r)|0)==0){break}else{break b}}else{if((D4a(r)|0)==0){break}else{break b}}}}while(0);s=C4a(r)|0;if((s|0)==0){break a}else{r=s}}if((r|0)==0){break a}switch(c[n>>2]|0){case 1:{t=65;break};case 2:{t=68;break};case 3:{t=83;break};case 4:{t=84;break};case 0:{t=86;break};default:{t=63}}Oc(2534328,(f=i,i=i+8|0,c[f>>2]=t,f)|0)|0;i=f;s=r+16|0;Oc(((c[s>>2]&4096|0)!=0?2530064:2196096)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;Oc(((c[s>>2]&8192|0)!=0?2185816:2196096)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;Oc(((c[s>>2]&512|0)!=0?2527184:2196096)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;Oc(((c[s>>2]&1|0)!=0?2526e3:2196096)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;Oc(((c[s>>2]&2|0)!=0?2211824:2196096)|0,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;s=r|0;u=c[r+4>>2]|0;Oc(2183632,(f=i,i=i+16|0,c[f>>2]=c[s>>2],c[f+8>>2]=(u|0)==0?10230104:u,f)|0)|0;i=f;u=c[o>>2]|0;if((irc(c[s>>2]|0,u)|0)!=0){Oc(2524632,(f=i,i=i+8|0,c[f>>2]=u,f)|0)|0;i=f}zc(10)|0;p=c[k>>2]|0;q=C4a(r)|0;if((q|0)==0){break a}}}}while(0);a=a+1|0;}while(a>>>0<e>>>0);h=g;kJb(h);i=b;return}function kg(a,b,c){a=a|0;b=b|0;c=c|0;jg(1);return 0}function lg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;Zc(553944)|0;d=d3(0)|0;if((d|0)==0){e=zc(10)|0;return 0}else{f=d}do{Zc(c[f>>2]|0)|0;f=d3(f)|0;}while((f|0)!=0);e=zc(10)|0;return 0}function mg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;d=i;i=i+8|0;b=d|0;c[b>>2]=0;Zc(553904)|0;a=LC(b,0)|0;if((a|0)!=0){e=a;do{Zc(e|0)|0;e=LC(b,0)|0;}while((e|0)!=0)}Zc(553896)|0;e=LC(b,1)|0;if((e|0)==0){i=d;return 0}else{f=e}do{Zc(f|0)|0;f=LC(b,1)|0;}while((f|0)!=0);i=d;return 0}function ng(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+64|0;d=e|0;Zc(553680)|0;b=$i(0)|0;if((b|0)==0){i=e;return 0}f=d|0;g=d+60|0;d=b;do{b=d+12|0;h=d+20|0;j=c[d+8>>2]|0;if((j|0)==0){k=f;l=13}else{m=f;n=0;while(1){if(!((c[j+(n*60|0)>>2]|0)!=0&m>>>0<g>>>0)){break}switch(c[j+(n*60|0)+4>>2]|0){case 0:{o=86;break};case 3:{o=83;break};case 4:{o=84;break};case 2:{o=68;break};case 1:{o=65;break};default:{o=63}}a[m]=o;m=m+1|0;n=n+1|0}if((n|0)==0){k=m;l=13}else{p=m}}if((l|0)==13){l=0;a[k]=(c[h>>2]&1|0)!=0?78:124;p=k+1|0}a[p]=45;j=p+2|0;a[p+1|0]=62;q=c[b>>2]|0;if((q|0)==0){r=j;l=25}else{s=j;j=0;while(1){if(!((c[q+(j*60|0)>>2]|0)!=0&s>>>0<g>>>0)){break}switch(c[q+(j*60|0)+4>>2]|0){case 4:{t=84;break};case 3:{t=83;break};case 2:{t=68;break};case 1:{t=65;break};case 0:{t=86;break};default:{t=63}}a[s]=t;s=s+1|0;j=j+1|0}if((j|0)==0){r=s;l=25}else{u=s}}if((l|0)==25){l=0;a[r]=(c[h>>2]&2|0)!=0?78:124;u=r+1|0}a[u]=0;q=c[h>>2]|0;b=(c[d+48>>2]|0)!=0?67:46;m=c[d>>2]|0;n=c[d+4>>2]|0;Oc(2162448,(v=i,i=i+48|0,c[v>>2]=(q&196608|0)!=0?84:46,c[v+8>>2]=(q&4|0)!=0?83:46,c[v+16>>2]=b,c[v+24>>2]=m,c[v+32>>2]=f,c[v+40>>2]=n,v)|0)|0;i=v;d=$i(d)|0;}while((d|0)!=0);i=e;return 0}function og(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;b=e|0;Oc(2160360,(a=i,i=i+8|0,c[a>>2]=2158488,a)|0)|0;i=a;f=fKb(0,b)|0;if((f|0)==0){i=e;return 0}else{g=0;h=f}do{f=c[b>>2]|0;j=d[f]|0;k=d[f+1|0]|0;l=d[f+2|0]|0;Oc(2156560,(a=i,i=i+32|0,c[a>>2]=h,c[a+8>>2]=j,c[a+16>>2]=k,c[a+24>>2]=l,a)|0)|0;i=a;g=g+1|0;h=fKb(g,b)|0;}while((h|0)!=0);i=e;return 0}function pg(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;e=i;Zc(553424)|0;b=rKb(0)|0;if((b|0)==0){i=e;return 0}else{f=b}do{b=sKb(f)|0;a=(zxb(b)|0)!=0;g=(Axb(b)|0)!=0;b=d[f+7|0]|0;h=c[f>>2]|0;j=d[f+4|0]|0;k=oKb(f)|0;Oc(2153072,(l=i,i=i+64|0,c[l>>2]=a?73:46,c[l+8>>2]=g?79:46,c[l+16>>2]=(b&8|0)!=0?72:46,c[l+24>>2]=(b&2|0)!=0?80:46,c[l+32>>2]=(b&4|0)!=0?66:46,c[l+40>>2]=h,c[l+48>>2]=j,c[l+56>>2]=k,l)|0)|0;i=l;f=rKb(f)|0;}while((f|0)!=0);i=e;return 0}function qg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+16|0;b=d|0;a=d+8|0;Zc(553376)|0;e=0;do{f=yrc(1,0,e|0)|0;g=G;h=vGb(f,g)|0;c[a>>2]=h;if((h|0)!=0){h=wGb(f,g)|0;Oc(2149424,(j=i,i=i+16|0,c[j>>2]=c[a>>2],c[j+8>>2]=h,j)|0)|0;i=j}e=e+1|0;}while((e|0)<63);Zc(553320)|0;if((yGb(0,b,a)|0)==0){k=0}else{i=d;return 0}do{e=c[a>>2]|0;if((e|0)!=0){Oc(2138624,(j=i,i=i+8|0,c[j>>2]=e,j)|0)|0;i=j;e=0;h=1;while(1){g=c[b>>2]|0;f=c[b+4>>2]|0;if(!((g&h|0)==0&(f&e|0)==0)){l=wrc(h,e,-1,-1)|0;m=(g&l|0)!=0|(f&G|0)!=0?2134904:10230104;f=vGb(h,e)|0;Oc(2136832,(j=i,i=i+16|0,c[j>>2]=m,c[j+8>>2]=f,j)|0)|0;i=j}f=h<<1|0>>>31;m=e<<1|h>>>31;if((f|0)==0&(m|0)==0){break}else{e=m;h=f}}zc(10)|0}k=k+1|0;}while((yGb(k,b,a)|0)==0);i=d;return 0}function rg(a,b,c){a=a|0;b=b|0;c=c|0;c=i;i=i+128|0;b=c|0;Zc(PKb(b,128,-1)|0)|0;Zc(PKb(b,128,0)|0)|0;Zc(PKb(b,128,1)|0)|0;Zc(PKb(b,128,2)|0)|0;Zc(PKb(b,128,3)|0)|0;Zc(PKb(b,128,4)|0)|0;Zc(PKb(b,128,5)|0)|0;Zc(PKb(b,128,6)|0)|0;Zc(PKb(b,128,7)|0)|0;Zc(PKb(b,128,8)|0)|0;Zc(PKb(b,128,9)|0)|0;i=c;return 0}function sg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;b=d|0;PIb(606);f=rJb((e|0)!=0?e:10230104)|0;c[b>>2]=f;e=_b(f|0,61)|0;if((e|0)==0){g=0;h=f}else{a[e]=0;g=e+1|0;h=c[b>>2]|0}if((a[h]|0)==0){Eg(h,g);j=b;mJb(j);i=d;return 0}if((irc(h,2133296)|0)==0){tg(g,0);j=b;mJb(j);i=d;return 0}if((irc(h,2131304)|0)==0){tg(g,1);j=b;mJb(j);i=d;return 0}if((irc(h,2129960)|0)==0){e=iH(g)|0;if((e|0)==0){KIb(0,16,2596520,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;j=b;mJb(j);i=d;return 0}f=c[e+4>>2]|0;Oc(2576944,(k=i,i=i+16|0,c[k>>2]=c[e>>2],c[k+8>>2]=f,k)|0)|0;i=k;f=c[e+12>>2]|0;if((f|0)!=0){Oc(2592984,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k}f=c[e+20>>2]|0;if((f|0)==0){j=b;mJb(j);i=d;return 0}Lf(f,2);j=b;mJb(j);i=d;return 0}if((irc(h,2128512)|0)==0){f=gH(g,0,0)|0;if((f|0)==0){KIb(0,16,2596520,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;j=b;mJb(j);i=d;return 0}e=c[f+4>>2]|0;Oc(2594312,(k=i,i=i+16|0,c[k>>2]=c[f>>2],c[k+8>>2]=e,k)|0)|0;i=k;e=c[f+12>>2]|0;if((e|0)!=0){Oc(2592984,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k}e=c[f+8>>2]|0;if((e|0)!=0){Oc(2587008,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k}e=c[f+20>>2]|0;do{if((e|0)!=0){l=u4(e)|0;if((l|0)==0){break}Oc(2582752,(k=i,i=i+8|0,c[k>>2]=c[l+8>>2],k)|0)|0;i=k}}while(0);e=c[f+16>>2]|0;do{if((e|0)!=0){l=u4(e)|0;if((l|0)==0){break}Oc(2580680,(k=i,i=i+8|0,c[k>>2]=c[l+8>>2],k)|0)|0;i=k}}while(0);e=c[f+24>>2]|0;do{if((e|0)!=0){l=u4(e)|0;if((l|0)==0){break}Oc(2578688,(k=i,i=i+8|0,c[k>>2]=c[l+8>>2],k)|0)|0;i=k}}while(0);e=c[f+36>>2]|0;if((e|0)==0){j=b;mJb(j);i=d;return 0}Lf(e,1);j=b;mJb(j);i=d;return 0}if((irc(h,2127016)|0)!=0){Eg(h,g);j=b;mJb(j);i=d;return 0}h=_i(g)|0;if((g|0)==0){KIb(0,16,2626240,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;j=b;mJb(j);i=d;return 0}if((h|0)==0){KIb(0,16,2624952,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;j=b;mJb(j);i=d;return 0}Oc(2623560,(k=i,i=i+8|0,c[k>>2]=c[h>>2],k)|0)|0;i=k;g=c[h+4>>2]|0;if((g|0)!=0){Oc(2622216,(k=i,i=i+8|0,c[k>>2]=g,k)|0)|0;i=k}g=h+20|0;if((c[g>>2]&4|0)!=0){Zc(554424)|0}Zc(554408)|0;e=h+8|0;f=bj(c[e>>2]|0)|0;if((f|0)>0){l=0;do{m=jj(c[e>>2]|0,l)|0;n=ALb(kj(c[e>>2]|0,l)|0)|0;Oc(2609576,(k=i,i=i+24|0,c[k>>2]=l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;l=l+1|0;}while((l|0)<(f|0))}do{if((c[g>>2]&1|0)==0){if((f|0)!=0){break}Zc(554376)|0}else{Zc(554312)|0}}while(0);Zc(554360)|0;f=h+12|0;l=bj(c[f>>2]|0)|0;if((l|0)>0){e=0;do{n=jj(c[f>>2]|0,e)|0;m=ALb(kj(c[f>>2]|0,e)|0)|0;Oc(2609576,(k=i,i=i+24|0,c[k>>2]=e,c[k+8>>2]=n,c[k+16>>2]=m,k)|0)|0;i=k;e=e+1|0;}while((e|0)<(l|0))}do{if((c[g>>2]&2|0)==0){if((l|0)!=0){break}Zc(554280)|0}else{Zc(554312)|0}}while(0);l=c[h+16>>2]|0;if((l|0)!=0){Lf(l,65560)}if((c[g>>2]&196608|0)==0){j=b;mJb(j);i=d;return 0}Zc(554208)|0;j=b;mJb(j);i=d;return 0}function tg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;if((a|0)==0){KIb(0,16,2575600,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}f=(b|0)!=0;if(f){g=s5a(a)|0}else{g=t5a(a)|0}if((g|0)!=0){Bg(g);i=d;return}g=w4(a)|0;if((g|0)==0){KIb(0,16,2570344,(e=i,i=i+8|0,c[e>>2]=a,e)|0);i=e;i=d;return}h=g|0;g=c[h>>2]|0;j=C4a(0)|0;do{if((j|0)!=0){k=(b|0)==0;l=0;m=g;n=j;a:while(1){o=n;b:while(1){do{if((c[o+12>>2]|0)==(m|0)){if(k){if((E4a(o)|0)==0){break}else{break b}}else{if((D4a(o)|0)==0){break}else{break b}}}}while(0);p=C4a(o)|0;if((p|0)==0){break a}else{o=p}}if((o|0)==0){break}Bg(o);p=c[h>>2]|0;q=C4a(o)|0;if((q|0)==0){r=22;break}else{l=1;m=p;n=q}}if((r|0)==22){i=d;return}if((l|0)==0){break}i=d;return}}while(0);KIb(0,16,2574216,(e=i,i=i+16|0,c[e>>2]=a,c[e+8>>2]=f?2572760:2571312,e)|0);i=e;i=d;return}function ug(){var a=0,b=0,c=0;a=Uc()|0;b=(((a-97|0)>>>0<26>>>0?a^32:a)|0)==89|0;c=a;while(1){if((c|0)==(-1|0)|(c|0)==10){break}c=Uc()|0}return b|0}function vg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=oHb(b,2125512)|0;if((g|0)==0){h=pd()|0;j=qd(c[h>>2]|0)|0;KIb(0,16,2118976,(k=i,i=i+16|0,c[k>>2]=b,c[k+8>>2]=j,k)|0);i=k;l=-(c[h>>2]|0)|0;i=f;return l|0}Rd(g|0,0,2)|0;c[e>>2]=dc(g|0)|0;Rd(g|0,0,0)|0;h=c[e>>2]|0;if((h|0)==-1){j=pd()|0;m=qd(c[j>>2]|0)|0;KIb(0,16,2115200,(k=i,i=i+8|0,c[k>>2]=m,k)|0);i=k;nb(g|0)|0;l=-(c[j>>2]|0)|0;i=f;return l|0}j=hJb(h+1|0)|0;c[d>>2]=j;if((j|0)==0){KIb(0,16,2113360,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;nb(g|0)|0;l=-12;i=f;return l|0}h=Ed(j|0,1,c[e>>2]|0,g|0)|0;j=c[e>>2]|0;do{if(h>>>0<j>>>0){kJb(c[d>>2]|0);if((pc(g|0)|0)==0){n=-541478725;break}m=pd()|0;o=qd(c[m>>2]|0)|0;KIb(0,16,2111504,(k=i,i=i+16|0,c[k>>2]=b,c[k+8>>2]=o,k)|0);i=k;n=-(c[m>>2]|0)|0}else{c[e>>2]=j+1;a[(c[d>>2]|0)+j|0]=0;n=0}}while(0);nb(g|0)|0;l=n;i=f;return l|0}function wg(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g|0;j=id(2109816)|0;c[h>>2]=j;c[h+4>>2]=id(2108208)|0;c[h+8>>2]=2106848;if((e|0)!=0){CFb(a,d,b)|0;k=Qc(a|0,2105536)|0;i=g;return k|0}e=(f|0)==0;l=0;m=j;while(1){do{if((m|0)==0){n=0}else{j=(l|0)!=1?10230104:2643592;Rb(a|0,b|0,2644544,(o=i,i=i+24|0,c[o>>2]=m,c[o+8>>2]=j,c[o+16>>2]=d,o)|0)|0;i=o;p=Qc(a|0,2105536)|0;if((p|0)!=0|e){n=p;break}Rb(a|0,b|0,2637136,(o=i,i=i+32|0,c[o>>2]=m,c[o+8>>2]=j,c[o+16>>2]=f,c[o+24>>2]=d,o)|0)|0;i=o;n=Qc(a|0,2105536)|0}}while(0);o=l+1|0;if(!((o|0)<3&(n|0)==0)){k=n;break}l=o;m=c[h+(o<<2)>>2]|0}i=g;return k|0}function xg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=vY(a,b,d)|0;if((f|0)>=0){i=e;return f|0}KIb(a,16,2633208,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;i=e;return f|0}function yg(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+16|0;j=h|0;k=h+8|0;c[j>>2]=0;l=e+8|0;m=(c[l>>2]|0)!=0?1:2;c[k>>2]=oWa()|0;do{if((g|0)==0){if((c[l>>2]|0)==0){n=c5a(d)|0;break}else{n=b5a(d)|0;break}}else{n=g}}while(0);g=c[(c[f+8>>2]|0)+8>>2]|0;if((g|0)==3){o=115;p=m|32}else if((g|0)==1){o=97;p=m|8}else if((g|0)==0){o=118;p=m|16}else{o=0;p=m}m=LGb(b,10230104,0,2)|0;a:do{if((m|0)!=0){g=e;d=k;l=(n|0)==0;q=n+44|0;r=q;s=m;b:while(1){t=s|0;u=c[t>>2]|0;v=_b(u|0,58)|0;w=(v|0)!=0;do{if(w){x=v+1|0;y=vY(e,f,x)|0;if((y|0)<0){KIb(g,16,2633208,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z}if((y|0)==0){break}else if((y|0)!=1){A=0;break b}a[v]=0;B=c[t>>2]|0;C=17}else{B=u;C=17}}while(0);do{if((C|0)==17){C=0;c:do{if((DJb(d,B,0,p,2)|0)==0){do{if(!l){if((c[q>>2]|0)==0){break}if((DJb(r,c[t>>2]|0,0,p,2)|0)!=0){C=21;break c}}}while(0);u=c[t>>2]|0;if((a[u]|0)!=(o|0)){break}if((DJb(d,u+1|0,0,p,2)|0)==0){break}MGb(j,(c[t>>2]|0)+1|0,c[s+4>>2]|0,0)|0}else{C=21}}while(0);if((C|0)==21){C=0;MGb(j,c[t>>2]|0,c[s+4>>2]|0,0)|0}if(!w){break}a[v]=58}}while(0);s=LGb(b,10230104,s,2)|0;if((s|0)==0){break a}}i=h;return A|0}}while(0);A=c[j>>2]|0;i=h;return A|0}function zg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=a+24|0;f=c[e>>2]|0;if((f|0)==0){g=0;i=d;return g|0}h=pJb(f<<2)|0;f=h;if((h|0)==0){KIb(0,16,2630928,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=0;i=d;return g|0}if((c[e>>2]|0)==0){g=f;i=d;return g|0}h=a+28|0;j=0;while(1){k=c[(c[h>>2]|0)+(j<<2)>>2]|0;c[f+(j<<2)>>2]=yg(b,c[(c[k+8>>2]|0)+48>>2]|0,a,k,0)|0;k=j+1|0;if(k>>>0<(c[e>>2]|0)>>>0){j=k}else{g=f;break}}i=d;return g|0}function Ag(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;if((2147483647/(b|0)|0|0)<=(e|0)){KIb(0,16,2629248,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;Hf(1);return 0}if((c[d>>2]|0)>=(e|0)){h=a;i=f;return h|0}j=iJb(a,ca(e,b)|0)|0;if((j|0)==0){KIb(0,16,2627632,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;Hf(1);return 0}g=c[d>>2]|0;mrc(j+(ca(g,b)|0)|0,0,ca(e-g|0,b)|0)|0;c[d>>2]=e;h=j;i=f;return h|0}function Bg(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+144|0;d=b|0;e=b+16|0;f=(D4a(a)|0)!=0;g=c[a>>2]|0;h=c[a+4>>2]|0;Oc(2566040,(j=i,i=i+24|0,c[j>>2]=f?2562488:2560872,c[j+8>>2]=g,c[j+16>>2]=(h|0)==0?10230104:h,j)|0)|0;i=j;if((c[a+8>>2]|0)>>>0<2>>>0){Oc(2559112,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;h=c[a+16>>2]&12288;if((h|0)==12288){Oc(2558e3,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}else if((h|0)==4096){Oc(2556720,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}else if((h|0)==8192){Oc(2555544,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}else{Oc(2554336,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j}zc(10)|0}h=c[a+20>>2]|0;if((h|0)!=0){Oc(2553320,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;g=c[h>>2]|0;if((g|0)!=0){f=h;h=g;do{g=c[f+4>>2]|0;Oc(2552408,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;f=f+8|0;h=c[f>>2]|0;}while((h|0)!=0)}zc(10)|0}h=c[a+24>>2]|0;if((h|0)!=0){Oc(2547960,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;f=c[h>>2]|0;if(!((f|0)==-1)){g=h;h=f;do{f=mKb(h)|0;Oc(2544936,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;g=g+4|0;h=c[g>>2]|0;}while(!((h|0)==-1))}zc(10)|0}h=c[a+28>>2]|0;if((h|0)!=0){Oc(2543440,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;g=c[h>>2]|0;if((g|0)!=0){f=d|0;d=h;h=g;do{Rb(f|0,16,2541752,(j=i,i=i+8|0,c[j>>2]=h,j)|0)|0;i=j;Oc(2544936,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;d=d+4|0;h=c[d>>2]|0;}while((h|0)!=0)}zc(10)|0}h=c[a+32>>2]|0;if((h|0)!=0){Oc(2540456,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;d=c[h>>2]|0;if(!((d|0)==-1)){f=h;h=d;do{d=LKb(h)|0;Oc(2544936,(j=i,i=i+8|0,c[j>>2]=d,j)|0)|0;i=j;f=f+4|0;h=c[f>>2]|0;}while(!((h|0)==-1))}zc(10)|0}h=c[a+36>>2]|0;if((h|0)!=0){Oc(2539216,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;f=c[h>>2]|0;d=c[h+4>>2]|0;if(!((f|0)==0&(d|0)==0)){g=e|0;e=h;h=d;d=f;do{sGb(g,128,0,d,h);Oc(2544936,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;e=e+8|0;d=c[e>>2]|0;h=c[e+4>>2]|0;}while(!((d|0)==0&(h|0)==0))}zc(10)|0}h=c[a+44>>2]|0;if((h|0)==0){i=b;return}Lf(h,3);i=b;return}function Cg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a>>2]|0;a=c[d+4>>2]|0;e=c[b>>2]|0;b=c[e+4>>2]|0;if((a|0)==(b|0)){f=irc(c[d+8>>2]|0,c[e+8>>2]|0)|0;return f|0}else{f=a-b|0;return f|0}return 0}function Dg(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+1040|0;g=f|0;Kc(g|0,e|0);IIb(a,b,d,e);e=f+16|0;GIb(a,b,d,g|0,e,1024,1005552);xb(e|0,c[1352790]|0)|0;qb(c[1352790]|0)|0;i=f;return}function Eg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;d=i;do{if((b|0)==0){e=0;f=0}else{if((a[b]|0)==0){e=0;f=0;break}if((irc(b,2179096)|0)==0){e=1;f=0;break}if((irc(b,2620328)|0)==0){e=1;f=1;break}KIb(0,16,2458120,(g=i,i=i+8|0,c[g>>2]=b,g)|0);i=g;e=0;f=0}}while(0);KIb(0,32,2527832,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;KIb(0,32,2512640,(g=i,i=i+8|0,c[g>>2]=699200,g)|0);i=g;KIb(0,32,2545936,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;Oc(2366152,(g=i,i=i+8|0,c[g>>2]=699200,g)|0)|0;i=g;Kf(771552,2299216,2048,0,0);Kf(771552,2247224,0,59396,0);if(e){Kf(771552,2204576,4,59392,0);Kf(771552,2172112,0,2612,57344);Kf(771552,2143920,4,560,57344);Kf(771552,2119680,16,36,0);Kf(771552,2637112,20,32,0);Kf(771552,2613368,32,20,0);Kf(771552,2585504,36,16,0)}else{Kf(771552,2172112,0,2612,57344);Kf(771552,2119680,16,36,0);Kf(771552,2613368,32,20,0)}Kf(771552,2563832,512,0,0);zc(10)|0;if((f|0)==0){i=d;return}Lf(oWa()|0,3);Lf(IR()|0,3);Lf(exb()|0,3);Lf(Wvb()|0,8);Lf(mj()|0,65560);i=d;return}function Fg(){var a=0,b=0;a=i;KIb(0,32,2527832,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;KIb(0,32,2512640,(b=i,i=i+8|0,c[b>>2]=699200,b)|0);i=b;KIb(0,32,2545936,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;i=a;return}function Gg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+208|0;e=d|0;f=d+80|0;mrc(e|0,0,80)|0;g=Vf(e,a,b,771552,1146896,2)|0;do{if((g|0)<0){KIb(0,8,2498984,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=g}else{b=Of(0,e|0)|0;if((b|0)<0){KIb(0,8,2486608,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=b;break}b=e+36|0;a=Hg((c[b>>2]|0)+12|0,2474856,18)|0;if((a|0)<0){KIb(0,8,2466072,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=a;break}a=Hg(c[b>>2]|0,2455456,476)|0;if((a|0)<0){KIb(0,8,2438112,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=a;break}Uf(e);k=a;i=d;return k|0}}while(0);Uf(e);e=f|0;RGb(j,e,128)|0;KIb(0,8,2427304,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;k=j;i=d;return k|0}function Hg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+440|0;f=e|0;h=a+8|0;if((c[h>>2]|0)<=0){j=0;i=e;return j|0}k=a+4|0;a=f;l=f+168|0;m=f+188|0;n=f+8|0;o=f+160|0;p=f+176|0;q=f+156|0;r=f+84|0;s=f|0;t=f+124|0;u=f+120|0;v=u;w=f+128|0;x=f+212|0;y=f+148|0;z=0;while(1){A=c[k>>2]|0;B=A+(z*36|0)|0;mrc(a|0,0,440)|0;c[l>>2]=-1;c[l+4>>2]=2147483647;g[m>>2]=.699999988079071;c[n>>2]=0;c[n+4>>2]=-2147483648;c[o>>2]=-1;c[o+4>>2]=2147483647;c[p>>2]=-1;c[p+4>>2]=-1;c[q>>2]=2147483647;c[r>>2]=1;c[s>>2]=B;C=Of(a,B)|0;D=A+(z*36|0)+4|0;E=c[D>>2]|0;if((C|0)<0){F=4;break}KIb(0,48,2215656,(G=i,i=i+16|0,c[G>>2]=b,c[G+8>>2]=E,G)|0);i=G;H=We[d&2047](f,c[D>>2]|0)|0;A=771552;do{B=c[A+8>>2]|0;I=a+B|0;J=A+4|0;K=c[J>>2]|0;do{if((K&32768|0)==0){if((K&16392|0)!=16392){break}mJb(I)}else{L=I;M=a+(B+4)|0;if((c[M>>2]|0)>0){N=0;do{mJb((c[L>>2]|0)+(N<<4)|0);if((c[J>>2]&8|0)!=0){mJb((c[L>>2]|0)+(N<<4)+8|0)}N=N+1|0;}while((N|0)<(c[M>>2]|0))}mJb(I);c[M>>2]=0}}while(0);A=A+20|0;}while((c[A>>2]|0)!=0);if((c[t>>2]|0)>0){A=0;do{mJb((c[u>>2]|0)+(A*24|0)+20|0);A=A+1|0;}while((A|0)<(c[t>>2]|0))}mJb(v);mJb(w);mJb(x);mJb(y);if((H|0)<0){F=18;break}KIb(0,48,2215256,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;A=z+1|0;if((A|0)<(c[h>>2]|0)){z=A}else{j=0;F=20;break}}if((F|0)==4){KIb(0,16,2216248,(G=i,i=i+16|0,c[G>>2]=b,c[G+8>>2]=E,G)|0);i=G;j=C;i=e;return j|0}else if((F|0)==18){C=c[D>>2]|0;KIb(0,16,2215440,(G=i,i=i+16|0,c[G>>2]=b,c[G+8>>2]=C,G)|0);i=G;j=H;i=e;return j|0}else if((F|0)==20){i=e;return j|0}return 0}function Ig(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;f=i;i=i+184|0;g=f|0;j=f+8|0;k=f+16|0;l=f+24|0;m=f+152|0;n=f+160|0;o=f+168|0;p=f+176|0;c[n>>2]=0;q=b+16|0;r=c[q>>2]|0;do{if((r|0)==0){s=0}else{t=iH(r)|0;if((t|0)!=0){s=t;break}KIb(0,8,2223768,(u=i,i=i+8|0,c[u>>2]=c[q>>2],u)|0);i=u;Hf(1);s=0}}while(0);q=(irc(e,2272168)|0)==0;r=q?2271272:e;if((krc(r,2271272,5)|0)==0){v=0}else{v=(irc(r,2222904)|0)!=0|0}c[139256]=c[139256]&v;v=HR()|0;c[k>>2]=v;if((v|0)==0){$f(r,-12);Hf(1)}v=c[b+40>>2]|0;if((v|0)!=0){e=l|0;Rb(e|0,128,2319880,(u=i,i=i+8|0,c[u>>2]=c[(c[b+36>>2]|0)+(v-1<<4)+8>>2],u)|0)|0;i=u;MGb((c[b>>2]|0)+20|0,2222248,e,0)|0}e=b+32|0;v=(s|0)==0;do{if(!((c[e>>2]|0)==0|v)){q=s+20|0;if((c[q>>2]|0)==0){break}if((DJb(q,2378968,0,0,2)|0)==0){break}q=l|0;Rb(q|0,128,2319880,(u=i,i=i+8|0,c[u>>2]=c[(c[b+28>>2]|0)+((c[e>>2]|0)-1<<4)+8>>2],u)|0)|0;i=u;MGb((c[b>>2]|0)+20|0,2378968,q,0)|0}}while(0);e=b+48|0;do{if(!((c[e>>2]|0)==0|v)){l=s+20|0;if((c[l>>2]|0)==0){break}if((DJb(l,2221792,0,0,2)|0)==0){break}MGb((c[b>>2]|0)+20|0,2221792,c[(c[b+44>>2]|0)+((c[e>>2]|0)-1<<4)+8>>2]|0,0)|0}}while(0);v=c[b+56>>2]|0;if((v|0)!=0){MGb((c[b>>2]|0)+20|0,2221584,c[(c[b+52>>2]|0)+(v-1<<4)+8>>2]|0,0)|0}v=c[b+64>>2]|0;if((v|0)!=0){MGb((c[b>>2]|0)+20|0,2221440,c[(c[b+60>>2]|0)+(v-1<<4)+8>>2]|0,0)|0}v=c[b+24>>2]|0;l=(v|0)>0;do{if(l){q=c[b+20>>2]|0;t=0;w=0;while(1){if((irc(c[q+(w<<4)>>2]|0,2210664)|0)==0){x=c[q+(w<<4)+8>>2]|0}else{x=t}y=w+1|0;if((y|0)<(v|0)){t=x;w=y}else{break}}do{if(l){w=c[b+20>>2]|0;t=0;q=0;while(1){if((irc(c[w+(q<<4)>>2]|0,2221128)|0)==0){z=c[w+(q<<4)+8>>2]|0}else{z=t}y=q+1|0;if((y|0)<(v|0)){t=z;q=y}else{break}}if(!l){A=0;B=z;break}q=c[b+20>>2]|0;t=0;w=0;while(1){if((irc(c[q+(w<<4)>>2]|0,2455624)|0)==0){C=c[q+(w<<4)+8>>2]|0}else{C=t}y=w+1|0;if((y|0)<(v|0)){t=C;w=y}else{A=C;B=z;break}}}else{A=0;B=0}}while(0);if((x|0)==0){D=0;E=0;F=0}else{D=c[(xh(x,0,0)|0)+12>>2]|0;E=x;F=1}w=c[k>>2]|0;c[w+1112>>2]=D;if((B|0)==0){H=0;I=w;J=0;K=0}else{w=c[(xh(B,1,0)|0)+12>>2]|0;H=w;I=c[k>>2]|0;J=B;K=1}c[I+1116>>2]=H;if((A|0)==0){c[I+1120>>2]=0;if(F){L=0;M=0;N=I;O=45}else{P=0;Q=0;O=46}}else{w=c[(xh(A,3,0)|0)+12>>2]|0;t=c[k>>2]|0;c[t+1120>>2]=w;if(F){L=1;M=A;N=t;O=45}else{P=1;Q=A;O=46}}if((O|0)==45){bX(N,xh(E,0,0)|0);if(K){R=M;S=L;O=47}else{T=M;U=L;O=48}}else if((O|0)==46){if(K){R=Q;S=P;O=47}else{T=Q;U=P;O=48}}if((O|0)==47){t=c[k>>2]|0;cX(t,xh(J,1,0)|0);if(S){V=R}else{break}}else if((O|0)==48){if(U){V=T}else{break}}t=c[k>>2]|0;dX(t,xh(V,3,0)|0)}else{t=c[k>>2]|0;c[t+1112>>2]=0;c[t+1116>>2]=0;c[t+1120>>2]=0}}while(0);V=c[k>>2]|0;T=V+1084|0;c[T>>2]=c[T>>2]|4;T=V+1160|0;V=1070432;U=c[V+4>>2]|0;c[T>>2]=c[V>>2];c[T+4>>2]=U;U=b|0;T=oX(k,r,s,(c[U>>2]|0)+20|0)|0;if((T|0)<0){$f(r,T);Hf(1)}Lh(c[(c[U>>2]|0)+20>>2]|0);T=c[k>>2]|0;if((c[T+24>>2]|0)==0){W=T}else{s=0;V=T;while(1){zh(b,V,c[(c[V+28>>2]|0)+(s<<2)>>2]|0)|0;T=s+1|0;R=c[k>>2]|0;if(T>>>0<(c[R+24>>2]|0)>>>0){s=T;V=R}else{W=R;break}}}V=zg(W,c[(c[U>>2]|0)+16>>2]|0)|0;c[m>>2]=V;W=c[k>>2]|0;s=c[W+24>>2]|0;if((OX(W,V)|0)<0){KIb(0,8,2220848,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;YX(k);Hf(1)}V=b+8|0;W=c[V>>2]|0;R=c[V+4>>2]|0;T=(W|0)==0&(R|0)==(-2147483648|0);S=c[k>>2]|0;J=S+1056|0;P=c[J>>2]|0;Q=c[J+4>>2]|0;J=(P|0)==0&(Q|0)==(-2147483648|0);K=wrc(J?0:P,J?0:Q,T?0:W,T?0:R)|0;R=G;do{if(!T){if((HX(S,-1,0,-2147483648,K,R,K,R,0)|0)>=0){break}KIb(0,24,2220632,(u=i,i=i+16|0,c[u>>2]=r,h[u+8>>3]=(+(K>>>0)+ +(R|0)*4294967296.0)/1.0e6,u)|0);i=u}}while(0);S=c[k>>2]|0;T=S+24|0;do{if((c[T>>2]|0)==0){X=S}else{W=S+28|0;Q=b+92|0;J=b+248|0;P=b+384|0;L=b+328|0;M=b+108|0;E=b+116|0;N=b+112|0;A=b+104|0;F=b+324|0;I=b+44|0;H=b+424|0;B=b+420|0;D=b+392|0;x=b+400|0;z=b+396|0;C=b+388|0;v=b+380|0;l=b+244|0;t=b+88|0;w=0;a:while(1){q=c[(c[W>>2]|0)+(w<<2)>>2]|0;y=q+8|0;Y=c[y>>2]|0;Z=pJb(296)|0;_=Z;if((Z|0)==0){Hf(1)}$=Ag(c[1475748]|0,4,5484640,(c[1371160]|0)+1|0)|0;c[1475748]=$;c[$+((c[1371160]|0)-1<<2)>>2]=_;$=Z+4|0;c[$>>2]=q;c[Z>>2]=c[1371162];c[Z+8>>2]=1;c[q+76>>2]=48;aa=Z+88|0;h[aa>>3]=1.0;if((c[Q>>2]|0)>0){ba=0;do{ca=xg(S,q,c[(c[t>>2]|0)+(ba<<4)>>2]|0)|0;do{if((ca|0)>0){h[aa>>3]=+h[(c[t>>2]|0)+(ba<<4)+8>>3]}else{if((ca|0)>=0){break}Hf(1)}}while(0);ba=ba+1|0;}while((ba|0)<(c[Q>>2]|0))}do{if((c[J>>2]|0)>0){ba=0;aa=0;while(1){ca=xg(S,q,c[(c[l>>2]|0)+(ba<<4)>>2]|0)|0;do{if((ca|0)>0){da=c[(c[l>>2]|0)+(ba<<4)+8>>2]|0}else{if((ca|0)>=0){da=aa;break}Hf(1);da=aa}}while(0);ca=ba+1|0;if((ca|0)<(c[J>>2]|0)){ba=ca;aa=da}else{break}}if((da|0)==0){break}aa=rb(da|0,j|0,0)|0;if((a[c[j>>2]|0]|0)==0){ea=aa}else{aa=da;ea=d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0}c[(c[y>>2]|0)+52>>2]=ea}}while(0);y=zh(b,S,q)|0;aa=Z+16|0;c[aa>>2]=y;c[Z+104>>2]=yg(c[(c[U>>2]|0)+16>>2]|0,c[(c[(c[$>>2]|0)+8>>2]|0)+48>>2]|0,S,q,y)|0;y=Z+252|0;c[y>>2]=-1;if((c[P>>2]|0)>0){ba=0;do{ca=xg(S,q,c[(c[v>>2]|0)+(ba<<4)>>2]|0)|0;do{if((ca|0)>0){c[y>>2]=c[(c[v>>2]|0)+(ba<<4)+8>>2]}else{if((ca|0)>=0){break}Hf(1)}}while(0);ba=ba+1|0;}while((ba|0)<(c[P>>2]|0))}ba=Z+80|0;c[ba>>2]=0;c[ba+4>>2]=-2147483648;b:do{switch(c[Y+8>>2]|0){case 0:{if((c[aa>>2]|0)==0){c[aa>>2]=c5a(c[Y+48>>2]|0)|0}if((W4a(Y)|0)!=0){ba=Y+88|0;c[ba>>2]=c[ba>>2]|16384}c[Z+124>>2]=c[Y+124>>2];c[Z+128>>2]=c[Y+120>>2];c[Z+132>>2]=c[Y+140>>2];do{if((c[e>>2]|0)>0){ba=0;y=0;while(1){$=xg(S,q,c[(c[I>>2]|0)+(ba<<4)>>2]|0)|0;do{if(($|0)>0){fa=c[(c[I>>2]|0)+(ba<<4)+8>>2]|0}else{if(($|0)>=0){fa=y;break}Hf(1);fa=y}}while(0);$=ba+1|0;if(($|0)<(c[e>>2]|0)){ba=$;y=fa}else{break}}if((fa|0)==0){break}if((cKb(Z+108|0,fa)|0)>=0){break}KIb(0,16,2218056,(u=i,i=i+8|0,c[u>>2]=fa,u)|0);i=u;Hf(1)}}while(0);y=Z+116|0;c[y>>2]=-1;if((c[L>>2]|0)>0){ba=0;do{$=xg(S,q,c[(c[F>>2]|0)+(ba<<4)>>2]|0)|0;do{if(($|0)>0){c[y>>2]=c[(c[F>>2]|0)+(ba<<4)+8>>2]}else{if(($|0)>=0){break}Hf(1)}}while(0);ba=ba+1|0;}while((ba|0)<(c[L>>2]|0))}do{if((c[M>>2]|0)>0){ba=0;y=0;while(1){$=xg(S,q,c[(c[A>>2]|0)+(ba<<4)>>2]|0)|0;do{if(($|0)>0){ga=c[(c[A>>2]|0)+(ba<<4)+8>>2]|0}else{if(($|0)>=0){ga=y;break}Hf(1);ga=y}}while(0);$=ba+1|0;if(($|0)<(c[M>>2]|0)){ba=$;y=ga}else{break}}if((ga|0)==0){break}if((irc(ga,2217904)|0)==0){c[Z+256>>2]=0;break}y=Z+256|0;if((irc(ga,2217760)|0)==0){c[y>>2]=1;break}if((c[y>>2]|0)!=0){break}KIb(0,8,2217544,(u=i,i=i+8|0,c[u>>2]=ga,u)|0);i=u;KIb(0,8,2217360,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;KIb(0,8,2545936,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;Hf(1)}}while(0);do{if((c[E>>2]|0)>0){y=0;ba=0;while(1){$=xg(S,q,c[(c[N>>2]|0)+(y<<4)>>2]|0)|0;do{if(($|0)>0){ha=c[(c[N>>2]|0)+(y<<4)+8>>2]|0}else{if(($|0)>=0){ha=ba;break}Hf(1);ha=ba}}while(0);$=y+1|0;if(($|0)<(c[E>>2]|0)){y=$;ba=ha}else{break}}if((ha|0)==0){break}ba=rJb(ha)|0;c[Z+260>>2]=ba;if((ba|0)!=0){break}Hf(1)}}while(0);c[Z+284>>2]=-1;break};case 1:{ba=Z+120|0;c[ba>>2]=2147483647;if((c[H>>2]|0)>0){y=0;do{$=xg(S,q,c[(c[B>>2]|0)+(y<<4)>>2]|0)|0;do{if(($|0)>0){c[ba>>2]=c[(c[B>>2]|0)+(y<<4)+8>>2]}else{if(($|0)>=0){break}Hf(1)}}while(0);y=y+1|0;}while((y|0)<(c[H>>2]|0))}Mh(_)|0;c[Z+136>>2]=c[Y+420>>2];c[Z+140>>2]=c[Y+412>>2];c[Z+144>>2]=c[Y+416>>2];y=Y+448|0;ba=c[y+4>>2]|0;$=Z+152|0;c[$>>2]=c[y>>2];c[$+4>>2]=ba;break};case 2:case 3:{if((c[aa>>2]|0)==0){c[aa>>2]=c5a(c[Y+48>>2]|0)|0}if((c[D>>2]|0)>0){ba=Z+160|0;$=0;do{y=xg(S,q,c[(c[C>>2]|0)+($<<4)>>2]|0)|0;do{if((y|0)>0){c[ba>>2]=c[(c[C>>2]|0)+($<<4)+8>>2]}else{if((y|0)>=0){break}Hf(1)}}while(0);$=$+1|0;}while(($|0)<(c[D>>2]|0))}if((c[x>>2]|0)>0){ia=0;ja=0}else{break b}while(1){$=xg(S,q,c[(c[z>>2]|0)+(ja<<4)>>2]|0)|0;do{if(($|0)>0){ka=c[(c[z>>2]|0)+(ja<<4)+8>>2]|0}else{if(($|0)>=0){ka=ia;break}Hf(1);ka=ia}}while(0);$=ja+1|0;if(($|0)<(c[x>>2]|0)){ia=ka;ja=$}else{break}}if((ka|0)==0){break b}if((bKb(Y+120|0,Y+124|0,ka)|0)>=0){break b}KIb(0,8,2217048,(u=i,i=i+8|0,c[u>>2]=ka,u)|0);i=u;Hf(1);break};case 4:case-1:{break};default:{O=153;break a}}}while(0);Y=w+1|0;if(Y>>>0<(c[T>>2]|0)>>>0){w=Y}else{O=155;break}}if((O|0)==153){Hd();return 0}else if((O|0)==155){X=c[k>>2]|0;break}}}while(0);cY(X,c[1371162]|0,r,0);c[1475750]=Ag(c[1475750]|0,4,5484648,(c[1371162]|0)+1|0)|0;X=pJb(72)|0;if((X|0)==0){Hf(1)}c[(c[1475750]|0)+((c[1371162]|0)-1<<2)>>2]=X;O=c[k>>2]|0;c[X>>2]=O;T=O+24|0;O=X+12|0;c[O>>2]=(c[1371160]|0)-(c[T>>2]|0);ka=c[V+4>>2]|0;ja=X+40|0;c[ja>>2]=c[V>>2];c[ja+4>>2]=ka;ka=b+160|0;ja=c[ka+4>>2]|0;V=X+48|0;c[V>>2]=c[ka>>2];c[V+4>>2]=ja;ja=b+72|0;V=c[ja>>2]|0;ka=c[ja+4>>2]|0;ja=X+16|0;c[ja>>2]=V;c[ja+4>>2]=ka;ja=(c[2448288]|0)!=0;ia=xrc(V,ka,ja?0:K,ja?0:R)|0;R=X+24|0;c[R>>2]=ia;c[R+4>>2]=G;c[X+56>>2]=c[T>>2];c[X+64>>2]=c[b+80>>2];c[X+68>>2]=c[b+84>>2];X=th(c[(c[U>>2]|0)+16>>2]|0)|0;c[n>>2]=X;U=c[O>>2]|0;if((U|0)<(c[1371160]|0)){O=U;do{U=LGb(c[(c[(c[1475748]|0)+(O<<2)>>2]|0)+104>>2]|0,10230648,0,2)|0;if((U|0)!=0){T=U;do{MGb(n,c[T>>2]|0,0,0)|0;T=LGb(c[(c[(c[1475748]|0)+(O<<2)>>2]|0)+104>>2]|0,10230648,T,2)|0;}while((T|0)!=0)}O=O+1|0;}while((O|0)<(c[1371160]|0));la=c[n>>2]|0}else{la=X}X=LGb(la,10230648,0,2)|0;if((X|0)!=0){la=o;O=p;T=X;do{c[o>>2]=oWa()|0;X=T|0;U=DJb(la,c[X>>2]|0,0,0,3)|0;c[p>>2]=IR()|0;if((U|0)!=0&(DJb(O,c[X>>2]|0,0,0,3)|0)==0){if((c[U+40>>2]&2|0)==0){R=U+4|0;ia=c[R>>2]|0;ja=(c[1371162]|0)-1|0;KIb(0,16,2220360,(u=i,i=i+32|0,c[u>>2]=c[X>>2],c[u+8>>2]=(ia|0)==0?10230648:ia,c[u+16>>2]=ja,c[u+24>>2]=r,u)|0);i=u;Hf(1);ma=R}else{ma=U+4|0}U=c[ma>>2]|0;R=(c[1371162]|0)-1|0;KIb(0,24,2219992,(u=i,i=i+32|0,c[u>>2]=c[X>>2],c[u+8>>2]=(U|0)==0?10230648:U,c[u+16>>2]=R,c[u+24>>2]=r,u)|0);i=u}T=LGb(c[n>>2]|0,10230648,T,2)|0;}while((T|0)!=0)}OGb(n);n=b+100|0;T=c[n>>2]|0;if((T|0)>0){r=b+96|0;b=0;ma=c[k>>2]|0;O=T;while(1){if((c[ma+24>>2]|0)==0){na=ma;oa=O}else{T=0;p=ma;do{la=c[(c[p+28>>2]|0)+(T<<2)>>2]|0;do{if((xg(p,la,c[(c[r>>2]|0)+(b<<4)>>2]|0)|0)==1){o=c[(c[r>>2]|0)+(b<<4)+8>>2]|0;c[g>>2]=0;R=la+8|0;if((c[(c[R>>2]|0)+100>>2]|0)==0){U=c[la>>2]|0;KIb(0,24,2219240,(u=i,i=i+16|0,c[u>>2]=(c[1371162]|0)-1,c[u+8>>2]=U,u)|0);i=u;break}do{if((a[o]|0)==0){U=LGb(c[la+88>>2]|0,2482680,0,0)|0;if((U|0)==0){pa=o;break}pa=c[U+4>>2]|0}else{pa=o}}while(0);if((a[pa]|0)==0){o=c[la>>2]|0;KIb(0,8,2218560,(u=i,i=i+16|0,c[u>>2]=(c[1371162]|0)-1,c[u+8>>2]=o,u)|0);i=u;Hf(1)}uh(pa);if((VD(g,pa,2,1070432,0)|0)<0){KIb(0,8,2218256,(u=i,i=i+8|0,c[u>>2]=pa,u)|0);i=u;Hf(1)}o=c[R>>2]|0;dD(c[g>>2]|0,c[o+96>>2]|0,c[o+100>>2]|0);eD(c[g>>2]|0);WD(c[g>>2]|0)|0}}while(0);T=T+1|0;p=c[k>>2]|0;}while(T>>>0<(c[p+24>>2]|0)>>>0);na=p;oa=c[n>>2]|0}T=b+1|0;if((T|0)<(oa|0)){b=T;ma=na;O=oa}else{break}}}if((s|0)>0){qa=0}else{ra=m;mJb(ra);i=f;return 0}do{OGb((c[m>>2]|0)+(qa<<2)|0);qa=qa+1|0;}while((qa|0)<(s|0));ra=m;mJb(ra);i=f;return 0}function Jg(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0.0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;e=i;i=i+200|0;f=e|0;h=e+8|0;j=e+16|0;k=e+24|0;l=e+32|0;m=e+40|0;n=e+48|0;o=e+56|0;p=e+64|0;q=e+72|0;r=e+80|0;s=e+88|0;t=e+96|0;u=e+104|0;v=e+168|0;w=e+176|0;x=e+184|0;y=e+192|0;c[r>>2]=0;z=c[1371168]|0;a:do{if((z|0)>0){A=0;B=z;while(1){C=c[(c[1510464]|0)+(A<<2)>>2]|0;if((c[C+8>>2]|0)==0){if((Eh(C)|0)<0){break}D=c[1371168]|0}else{D=B}C=A+1|0;if((C|0)<(D|0)){A=C;B=D}else{break a}}KIb(0,8,2264688,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Hf(1)}}while(0);D=b+168|0;z=c[D>>2]|0;B=c[D+4>>2]|0;do{if(!((z|0)==(-1|0)&(B|0)==2147483647)){A=b+160|0;if((c[A>>2]|0)==(-1|0)&(c[A+4>>2]|0)==2147483647){F=B;H=z}else{c[D>>2]=-1;c[D+4>>2]=2147483647;KIb(0,24,2263832,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;C=c[D>>2]|0;I=c[D+4>>2]|0;if((C|0)==(-1|0)&(I|0)==2147483647){break}if((c[A>>2]|0)==(-1|0)&(c[A+4>>2]|0)==2147483647){F=I;H=C}else{break}}C=b+8|0;I=c[C>>2]|0;J=c[C+4>>2]|0;C=(I|0)==0&(J|0)==(-2147483648|0);K=C?0:I;I=C?0:J;if((F|0)>(I|0)|(F|0)==(I|0)&H>>>0>K>>>0){J=xrc(H,F,K,I)|0;c[A>>2]=J;c[A+4>>2]=G;break}else{KIb(0,24,2263080,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;c[D>>2]=-1;c[D+4>>2]=2147483647;break}}}while(0);c[1366872]=Ag(c[1366872]|0,4,5484632,(c[1371158]|0)+1|0)|0;D=pJb(48)|0;if((D|0)==0){Hf(1)}c[(c[1366872]|0)+((c[1371158]|0)-1<<2)>>2]=D;F=D+8|0;c[F>>2]=c[1371156];H=b+160|0;z=c[H+4>>2]|0;B=D+16|0;c[B>>2]=c[H>>2];c[B+4>>2]=z;z=b+8|0;A=c[z+4>>2]|0;J=D+24|0;c[J>>2]=c[z>>2];c[J+4>>2]=A;A=b+176|0;z=c[A+4>>2]|0;I=D+32|0;c[I>>2]=c[A>>2];c[I+4>>2]=z;c[D+40>>2]=c[b+192>>2];z=D+4|0;I=b|0;PGb(z,c[(c[I>>2]|0)+20>>2]|0,0);A=(irc(d,2272168)|0)==0;K=A?2271272:d;d=SO(q,0,c[b+16>>2]|0,K)|0;A=c[q>>2]|0;if((A|0)==0){$f(K,d);Hf(1);L=c[q>>2]|0}else{L=A}A=D;c[A>>2]=L;D=c[H>>2]|0;d=c[H+4>>2]|0;if(!((D|0)==(-1|0)&(d|0)==2147483647)){C=L+1064|0;c[C>>2]=D;c[C+4>>2]=d}d=c[L+8>>2]|0;C=L+1160|0;L=1070432;D=c[L>>2]|0;M=c[L+4>>2]|0;c[C>>2]=D;c[C+4>>2]=M;C=c[1371168]|0;if((C|0)>0){L=b+196|0;N=b+200|0;O=b+204|0;P=0;Q=C;while(1){C=c[(c[1510464]|0)+(P<<2)>>2]|0;R=C+28|0;S=c[R>>2]|0;if((S|0)>0){T=C+24|0;C=0;U=S;while(1){S=c[(c[T>>2]|0)+(C<<2)>>2]|0;V=c[S+16>>2]|0;do{if((V|0)==0){W=U}else{if((c[V>>2]|0)!=0){W=U;break}X=kj(c[(c[V+4>>2]|0)+28>>2]|0,c[V+8>>2]|0)|0;if((X|0)==0){c[L>>2]=1}else if((X|0)==1){c[N>>2]=1}else if((X|0)==3){c[O>>2]=1}ph(S,b,c[q>>2]|0);W=c[R>>2]|0}}while(0);S=C+1|0;if((S|0)<(W|0)){C=S;U=W}else{break}}Y=c[1371168]|0}else{Y=Q}U=P+1|0;if((U|0)<(Y|0)){P=U;Q=Y}else{break}}}Y=d|0;do{if((irc(c[Y>>2]|0,2262728)|0)==0){if((AFb(K,2262432,0)|0)==0){break}d=Mf(b,2598680,2262168,771552)|0;if((d|0)>=0){break}$f(K,d);Hf(1)}}while(0);d=irc(c[Y>>2]|0,2262728)|0;do{if((c[1366868]|d|0)==0){if((AFb(K,2262432,0)|0)==0){Z=66;break}Y=c[q>>2]|0;Q=HR()|0;c[p>>2]=Q;P=Q+1160|0;c[P>>2]=D;c[P+4>>2]=M;P=oX(p,K,0,0)|0;do{if((P|0)<0){$f(K,P);Hf(1)}else{Q=c[p>>2]|0;if((c[Q+24>>2]|0)==0){YX(p);break}else{_=0;$=Q}do{Q=b5a(c[(c[(c[(c[$+28>>2]|0)+(_<<2)>>2]|0)+8>>2]|0)+48>>2]|0)|0;W=wh(b,Y,c[Q+8>>2]|0,-1)|0;O=c[W+12>>2]|0;N=O+8|0;L=c[N>>2]|0;c[W+60>>2]=Q;nrc(O|0,c[(c[(c[p>>2]|0)+28>>2]|0)+(_<<2)>>2]|0,656)|0;U=O+208|0;c[U>>2]=0;c[U+4>>2]=0;U=hJb(104)|0;c[O+184>>2]=U;nrc(U|0,c[(c[(c[(c[p>>2]|0)+28>>2]|0)+(_<<2)>>2]|0)+184>>2]|0,104)|0;c[N>>2]=L;nWa(L,c[(c[(c[(c[p>>2]|0)+28>>2]|0)+(_<<2)>>2]|0)+8>>2]|0)|0;L=c[N>>2]|0;N=c[L+8>>2]|0;do{if((N|0)==1){if((c[W+352>>2]|0)!=0){break}Bh(O,Q)}else if((N|0)==0){if((c[W+352>>2]|0)!=0){break}Ah(O,Q,c[L+140>>2]|0)|0}}while(0);_=_+1|0;$=c[p>>2]|0;}while(_>>>0<(c[$+24>>2]|0)>>>0);YX(p)}}while(0);Y=c[1371156]|0;P=Y-(c[(c[q>>2]|0)+24>>2]|0)|0;if((P|0)<(Y|0)){aa=P}else{break}do{P=c[(c[1366870]|0)+(aa<<2)>>2]|0;Y=c[1371160]|0;L=c[1475748]|0;Q=P+12|0;O=0;while(1){if((O|0)>=(Y|0)){Z=62;break}ba=c[L+(O<<2)>>2]|0;da=ba+4|0;ea=(c[Q>>2]|0)+8|0;if((c[(c[(c[da>>2]|0)+8>>2]|0)+8>>2]|0)==(c[(c[ea>>2]|0)+8>>2]|0)){Z=57;break}else{O=O+1|0}}if((Z|0)==57){Z=0;L=P+24|0;c[L>>2]=ba;c[P+8>>2]=O;Y=c[(c[ea>>2]|0)+8>>2]|0;if((Y|0)==1){c[P+304>>2]=rJb(2261888)|0;fa=c[(c[(c[Q>>2]|0)+8>>2]|0)+8>>2]|0}else{fa=Y}if((fa|0)==0){c[P+304>>2]=rJb(2261656)|0}c[ba+8>>2]=0;c[(c[da>>2]|0)+76>>2]=-16;ga=L}else if((Z|0)==62){Z=0;ga=P+24|0}if((c[ga>>2]|0)==0){L=ALb(c[(c[(c[Q>>2]|0)+8>>2]|0)+8>>2]|0)|0;KIb(0,8,2261272,(E=i,i=i+8|0,c[E>>2]=L,E)|0);i=E;Hf(1)}aa=aa+1|0;}while((aa|0)<(c[1371156]|0))}else{Z=66}}while(0);b:do{if((Z|0)==66){aa=b+124|0;ga=c[aa>>2]|0;if((ga|0)!=0){if((ga|0)<=0){break}ga=b+120|0;da=b+204|0;ba=b+200|0;fa=b+196|0;ea=b+208|0;p=0;while(1){$=c[ga>>2]|0;c:do{if((c[$+(p*24|0)>>2]|0)==0){_=c[$+(p*24|0)+20>>2]|0;if((_|0)!=0){M=c[1371168]|0;d:do{if((M|0)>0){D=c[1510464]|0;d=0;e:while(1){L=c[D+(d<<2)>>2]|0;Y=c[L+28>>2]|0;if((Y|0)>0){W=c[L+24>>2]|0;L=0;do{ha=c[W+(L<<2)>>2]|0;N=c[ha+16>>2]|0;if((N|0)!=0){if((irc(c[N>>2]|0,_)|0)==0){break e}}L=L+1|0;}while((L|0)<(Y|0))}Y=d+1|0;if((Y|0)<(M|0)){d=Y}else{Z=113;break d}}if((ha|0)==0){Z=113}else{ia=ha}}else{Z=113}}while(0);if((Z|0)==113){Z=0;KIb(0,8,2260952,(E=i,i=i+8|0,c[E>>2]=_,E)|0);i=E;Hf(1);ia=0}ph(ia,b,c[q>>2]|0);break}M=c[$+(p*24|0)+4>>2]|0;d=c[$+(p*24|0)+8>>2]|0;D=d+(c[(c[(c[1475750]|0)+(M<<2)>>2]|0)+12>>2]|0)|0;Y=c[(c[1475748]|0)+(D<<2)>>2]|0;if((c[da>>2]|0)!=0){if((c[(c[(c[Y+4>>2]|0)+8>>2]|0)+8>>2]|0)==3){break}}if((c[ba>>2]|0)!=0){if((c[(c[(c[Y+4>>2]|0)+8>>2]|0)+8>>2]|0)==1){break}}if((c[fa>>2]|0)!=0){if((c[(c[(c[Y+4>>2]|0)+8>>2]|0)+8>>2]|0)==0){break}}L=c[(c[(c[Y+4>>2]|0)+8>>2]|0)+8>>2]|0;if((c[ea>>2]|0)!=0&(L|0)==2){break}switch(L|0){case 0:{qh(b,c[q>>2]|0,D)|0;break c;break};case 1:{rh(b,c[q>>2]|0,D)|0;break c;break};case 3:{sh(b,c[q>>2]|0,D);break c;break};case 2:{if((c[(wh(b,c[q>>2]|0,2,D)|0)+352>>2]|0)!=0){break c}KIb(0,8,2233328,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Hf(1);break c;break};case 4:{L=wh(b,c[q>>2]|0,4,D)|0;c[L+352>>2]=1;c[L+344>>2]=1;break c;break};default:{KIb(0,8,2260816,(E=i,i=i+16|0,c[E>>2]=M,c[E+8>>2]=d,E)|0);i=E;Hf(1);break c}}}}while(0);p=p+1|0;if((p|0)>=(c[aa>>2]|0)){break b}}}do{if((c[b+196>>2]|0)==0){aa=c[(c[q>>2]|0)+8>>2]|0;p=c[aa+20>>2]|0;if((p|0)==0){break}ea=qY(aa,p,0)|0;p=c[1371160]|0;if((p|0)<=0){break}aa=c[1475748]|0;fa=(ea|0)==1128878145;ea=-1;ba=0;da=0;while(1){ga=c[(c[aa+(da<<2)>>2]|0)+4>>2]|0;$=c[ga+8>>2]|0;Q=ca(c[$+124>>2]|0,c[$+120>>2]|0)|0;if(fa){ja=Q}else{ja=(c[ga+72>>2]&1024|0)==0?Q:1}do{if((c[$+8>>2]|0)==0&(ja|0)>(ba|0)){if(fa){if((c[ga+72>>2]&1024|0)==0){ka=ba;la=ea;break}}ka=ja;la=da}else{ka=ba;la=ea}}while(0);ga=da+1|0;if((ga|0)<(p|0)){ea=la;ba=ka;da=ga}else{break}}if(!((la|0)>-1)){break}qh(b,c[q>>2]|0,la)|0}}while(0);do{if((c[b+200>>2]|0)==0){da=c[q>>2]|0;if((c[(c[da+8>>2]|0)+16>>2]|0)==0){break}ba=c[1371160]|0;if((ba|0)<=0){break}ea=c[1475748]|0;p=0;fa=-1;aa=0;while(1){ga=c[(c[(c[ea+(aa<<2)>>2]|0)+4>>2]|0)+8>>2]|0;if((c[ga+8>>2]|0)==1){$=c[ga+416>>2]|0;ga=($|0)>(p|0);ma=ga?aa:fa;na=ga?$:p}else{ma=fa;na=p}$=aa+1|0;if(($|0)<(ba|0)){p=na;fa=ma;aa=$}else{break}}if(!((ma|0)>-1)){break}rh(b,da,ma)|0}}while(0);aa=c[b+24>>2]|0;if((aa|0)>0){fa=c[b+20>>2]|0;p=0;ba=0;while(1){if((irc(c[fa+(p<<4)>>2]|0,2455624)|0)==0){oa=c[fa+(p<<4)+8>>2]|0}else{oa=ba}ea=p+1|0;if((ea|0)<(aa|0)){p=ea;ba=oa}else{pa=oa;break}}}else{pa=0}if((c[b+204>>2]|0)!=0){break}if((b5a(c[(c[(c[q>>2]|0)+8>>2]|0)+24>>2]|0)|0)==0&(pa|0)==0){break}ba=c[1371160]|0;p=c[1475748]|0;aa=0;while(1){if((aa|0)>=(ba|0)){break b}if((c[(c[(c[(c[p+(aa<<2)>>2]|0)+4>>2]|0)+8>>2]|0)+8>>2]|0)==3){break}else{aa=aa+1|0}}sh(b,c[q>>2]|0,aa)}}while(0);pa=b+152|0;if((c[pa>>2]|0)>0){oa=b+148|0;ma=0;do{if((VD(s,c[(c[oa>>2]|0)+(ma<<2)>>2]|0,1,1070432,0)|0)<0){KIb(0,8,2259888,(E=i,i=i+8|0,c[E>>2]=c[(c[oa>>2]|0)+(ma<<2)>>2],E)|0);i=E;Hf(1)}na=iD(c[s>>2]|0)|0;la=G;ka=0;if((la|0)<(ka|0)|(la|0)==(ka|0)&na>>>0<1>>>0){KIb(0,8,2259104,(E=i,i=i+8|0,c[E>>2]=c[(c[oa>>2]|0)+(ma<<2)>>2],E)|0);i=E;Hf(1)}ka=na;na=hJb(ka)|0;if((na|0)==0){KIb(0,8,2258856,(E=i,i=i+8|0,c[E>>2]=c[(c[oa>>2]|0)+(ma<<2)>>2],E)|0);i=E;Hf(1)}AD(c[s>>2]|0,na,ka)|0;la=wh(b,c[q>>2]|0,4,-1)|0;ja=la+344|0;c[ja>>2]=1;c[la+352>>2]=0;c[la+356>>2]=c[(c[oa>>2]|0)+(ma<<2)>>2];c[ja>>2]=1;ja=la+12|0;c[(c[(c[ja>>2]|0)+8>>2]|0)+96>>2]=na;na=c[ja>>2]|0;c[(c[na+8>>2]|0)+100>>2]=ka;ka=c[(c[oa>>2]|0)+(ma<<2)>>2]|0;ja=hc(ka|0,47)|0;if((ja|0)==0){qa=ka}else{qa=(a[ja]|0)==0?ka:ja+1|0}MGb(na+88|0,2482680,qa,16)|0;WD(c[s>>2]|0)|0;ma=ma+1|0;}while((ma|0)<(c[pa>>2]|0))}pa=c[1371156]|0;ma=pa-(c[(c[q>>2]|0)+24>>2]|0)|0;if((ma|0)<(pa|0)){pa=ma;do{ma=c[(c[1366870]|0)+(pa<<2)>>2]|0;if((c[ma+352>>2]|0)==0){if((c[ma+356>>2]|0)!=0){Z=143}}else{Z=143}do{if((Z|0)==143){Z=0;s=LGb(c[(c[I>>2]|0)+16>>2]|0,2181896,0,2)|0;if((s|0)==0){break}qa=c[s>>2]|0;if((a[qa+5|0]|0)==0){ra=ma+12|0}else{oa=ma+12|0;if((xg(c[q>>2]|0,c[oa>>2]|0,qa+6|0)|0)==0){break}else{ra=oa}}if((EJb(c[(c[ra>>2]|0)+8>>2]|0,2181896,c[s+4>>2]|0,0)|0)>=0){break}Hf(1)}}while(0);pa=pa+1|0;}while((pa|0)<(c[1371156]|0))}pa=th(c[(c[I>>2]|0)+16>>2]|0)|0;c[r>>2]=pa;I=c[F>>2]|0;if((I|0)<(c[1371156]|0)){ra=I;do{I=LGb(c[(c[(c[1366870]|0)+(ra<<2)>>2]|0)+328>>2]|0,10230648,0,2)|0;if((I|0)!=0){ma=I;do{MGb(r,c[ma>>2]|0,0,0)|0;ma=LGb(c[(c[(c[1366870]|0)+(ra<<2)>>2]|0)+328>>2]|0,10230648,ma,2)|0;}while((ma|0)!=0)}ra=ra+1|0;}while((ra|0)<(c[1371156]|0));sa=c[r>>2]|0}else{sa=pa}pa=LGb(sa,10230648,0,2)|0;if((pa|0)!=0){sa=t;ra=pa;do{c[t>>2]=oWa()|0;pa=ra|0;ma=DJb(sa,c[pa>>2]|0,0,0,3)|0;do{if((ma|0)!=0){if((c[ma+40>>2]&1|0)==0){I=c[ma+4>>2]|0;aa=(c[1371158]|0)-1|0;KIb(0,16,2258408,(E=i,i=i+32|0,c[E>>2]=c[pa>>2],c[E+8>>2]=(I|0)==0?10230648:I,c[E+16>>2]=aa,c[E+24>>2]=K,E)|0);i=E;Hf(1)}aa=c[pa>>2]|0;if((irc(aa,2314800)|0)==0){break}I=c[ma+4>>2]|0;s=(c[1371158]|0)-1|0;KIb(0,24,2257872,(E=i,i=i+32|0,c[E>>2]=aa,c[E+8>>2]=(I|0)==0?10230648:I,c[E+16>>2]=s,c[E+24>>2]=K,E)|0);i=E}}while(0);ra=LGb(c[r>>2]|0,10230648,ra,2)|0;}while((ra|0)!=0)}OGb(r);r=c[q>>2]|0;do{if((c[(c[r+8>>2]|0)+28>>2]&2|0)!=0){if((iX(r+32|0)|0)!=0){break}$f((c[q>>2]|0)+32|0,-22);Hf(1)}}while(0);r=c[(c[q>>2]|0)+8>>2]|0;do{if((c[r+28>>2]&1|0)==0){uh(K);ra=c[q>>2]|0;sa=VD(ra+16|0,K,2,ra+1160|0,z)|0;if((sa|0)>=0){break}$f(K,sa);Hf(1)}else{if((irc(c[r>>2]|0,2257584)|0)!=0){break}if((iX(K)|0)!=0){break}uh(K)}}while(0);ta=+g[b+184>>2];if(ta!=0.0){K=u|0;Rb(K|0,64,2319880,(E=i,i=i+8|0,c[E>>2]=~~(ta*1.0e6),E)|0)|0;i=E;MGb(z,2257224,K,0)|0}c[(c[q>>2]|0)+1080>>2]=~~(+g[b+188>>2]*1.0e6);K=b+336|0;f:do{if((c[K>>2]|0)>0){z=b+332|0;u=b+136|0;r=b+140|0;sa=b+144|0;ra=0;g:while(1){t=rb(c[(c[z>>2]|0)+(ra<<4)+8>>2]|0,v|0,0)|0;if((t|0)>=(c[1371162]|0)){KIb(0,8,2256872,(E=i,i=i+8|0,c[E>>2]=t,E)|0);i=E;Hf(1)}ma=c[(c[z>>2]|0)+(ra<<4)>>2]|0;pa=c[v>>2]|0;s=(a[pa]|0)!=0?pa+1|0:pa;pa=c[q>>2]|0;if((t|0)>-1){ua=c[c[(c[1475750]|0)+(t<<2)>>2]>>2]|0}else{ua=0}c[l>>2]=0;c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;vh(s,j,n,l);vh(ma,k,o,m);do{if((ua|0)==0){s=a[k]|0;if(s<<24>>24==103){Z=183}else{if((a[ma]|0)==0){Z=183}}if((Z|0)==183){Z=0;c[u>>2]=1}if(s<<24>>24==115){Z=186}else{if((a[ma]|0)==0){Z=186}}if((Z|0)==186){Z=0;c[r>>2]=1}if(!(s<<24>>24==99)){if((a[ma]|0)!=0){break}}c[sa>>2]=1}else{s=a[j]|0;if(s<<24>>24==103){Z=192}else{if((a[k]|0)==103){Z=192}}if((Z|0)==192){Z=0;c[u>>2]=1}t=s<<24>>24==115;if(t){Z=195}else{if((a[k]|0)==115){Z=195}}if((Z|0)==195){Z=0;c[r>>2]=1}if(s<<24>>24==99){Z=198}else{if((a[k]|0)==99){Z=198}}if((Z|0)==198){Z=0;c[sa>>2]=1}I=s<<24>>24;if((I|0)==103){va=ua+1140|0}else if((I|0)==99){s=c[n>>2]|0;if((s|0)<0){Z=203}else{if(!(s>>>0<(c[ua+1132>>2]|0)>>>0)){Z=203}}if((Z|0)==203){Z=0;KIb(0,8,2254144,(E=i,i=i+16|0,c[E>>2]=2254e3,c[E+8>>2]=s,E)|0);i=E;Hf(1)}va=(c[(c[ua+1136>>2]|0)+(s<<2)>>2]|0)+32|0}else if((I|0)==112){s=c[n>>2]|0;if((s|0)<0){Z=207}else{if(!(s>>>0<(c[ua+1104>>2]|0)>>>0)){Z=207}}if((Z|0)==207){Z=0;KIb(0,8,2254144,(E=i,i=i+16|0,c[E>>2]=2253792,c[E+8>>2]=s,E)|0);i=E;Hf(1)}va=(c[(c[ua+1108>>2]|0)+(s<<2)>>2]|0)+20|0}else if((I|0)==115){va=0}else{Z=209;break g}I=a[k]|0;s=I<<24>>24;if((s|0)==103){wa=pa+1140|0}else if((s|0)==99){aa=c[o>>2]|0;if((aa|0)<0){Z=214}else{if(!(aa>>>0<(c[pa+1132>>2]|0)>>>0)){Z=214}}if((Z|0)==214){Z=0;KIb(0,8,2254144,(E=i,i=i+16|0,c[E>>2]=2254e3,c[E+8>>2]=aa,E)|0);i=E;Hf(1)}wa=(c[(c[pa+1136>>2]|0)+(aa<<2)>>2]|0)+32|0}else if((s|0)==112){aa=c[o>>2]|0;if((aa|0)<0){Z=218}else{if(!(aa>>>0<(c[pa+1104>>2]|0)>>>0)){Z=218}}if((Z|0)==218){Z=0;KIb(0,8,2254144,(E=i,i=i+16|0,c[E>>2]=2253792,c[E+8>>2]=aa,E)|0);i=E;Hf(1)}wa=(c[(c[pa+1108>>2]|0)+(aa<<2)>>2]|0)+20|0}else if((s|0)==115){wa=0}else{Z=220;break g}do{if(t){s=ua+24|0;h:do{if((c[s>>2]|0)==0){xa=va}else{aa=ua+28|0;oa=c[l>>2]|0;qa=0;while(1){na=xg(ua,c[(c[aa>>2]|0)+(qa<<2)>>2]|0,oa)|0;if((na|0)>0){break}if((na|0)<0){Hf(1)}na=qa+1|0;if(na>>>0<(c[s>>2]|0)>>>0){qa=na}else{xa=va;break h}}xa=(c[(c[aa>>2]|0)+(qa<<2)>>2]|0)+88|0}}while(0);if((xa|0)!=0){ya=xa;break}KIb(0,8,2252504,(E=i,i=i+8|0,c[E>>2]=c[l>>2],E)|0);i=E;Hf(1);ya=0}else{ya=va}}while(0);if(!(I<<24>>24==115)){PGb(wa,c[ya>>2]|0,16);break}t=pa+24|0;if((c[t>>2]|0)==0){break}s=pa+28|0;oa=c[m>>2]|0;na=0;do{ja=xg(pa,c[(c[s>>2]|0)+(na<<2)>>2]|0,oa)|0;do{if((ja|0)>0){PGb((c[(c[s>>2]|0)+(na<<2)>>2]|0)+88|0,c[ya>>2]|0,16)}else{if((ja|0)>=0){break}Hf(1)}}while(0);na=na+1|0;}while(na>>>0<(c[t>>2]|0)>>>0)}}while(0);ra=ra+1|0;if((ra|0)>=(c[K>>2]|0)){break f}}if((Z|0)==209){KIb(0,0,2253552,(E=i,i=i+24|0,c[E>>2]=2280032,c[E+8>>2]=2253344,c[E+16>>2]=469,E)|0);i=E;Hd();return 0}else if((Z|0)==220){KIb(0,0,2253552,(E=i,i=i+24|0,c[E>>2]=2280032,c[E+8>>2]=2253344,c[E+16>>2]=470,E)|0);i=E;Hd();return 0}}}while(0);K=b+156|0;ya=c[K>>2]|0;i:do{if((ya|0)<(c[1371162]|0)){za=ya;Z=248}else{if((ya|0)!=2147483647){KIb(0,8,2256512,(E=i,i=i+8|0,c[E>>2]=ya,E)|0);i=E;Hf(1);za=c[K>>2]|0;Z=248;break}c[K>>2]=-1;m=c[1371162]|0;wa=c[1475750]|0;va=0;while(1){if((va|0)>=(m|0)){break i}if((c[(c[c[wa+(va<<2)>>2]>>2]|0)+1132>>2]|0)==0){va=va+1|0}else{break}}c[K>>2]=va;za=va;Z=248}}while(0);j:do{if((Z|0)==248){if(!((za|0)>-1)){break}K=c[(c[1475750]|0)+(za<<2)>>2]|0;ya=(c[b+144>>2]|0)==0;wa=c[K>>2]|0;m=c[A>>2]|0;l=m+1136|0;xa=wa+1132|0;ua=m+1132|0;m=jJb(c[l>>2]|0,(c[ua>>2]|0)+(c[xa>>2]|0)|0,4)|0;if((m|0)==0){break}c[l>>2]=m;if((c[xa>>2]|0)==0){break}m=wa+1136|0;wa=K+24|0;K=f|0;o=f+4|0;k=h|0;n=h+4|0;if(ya){ya=0;do{j=c[(c[m>>2]|0)+(ya<<2)>>2]|0;v=c[J>>2]|0;ra=c[J+4>>2]|0;sa=(v|0)==0&(ra|0)==(-2147483648|0);r=xrc(sa?0:v,sa?0:ra,c[wa>>2]|0,c[wa+4>>2]|0)|0;c[K>>2]=1;c[o>>2]=1e6;ra=j+4|0;sa=XIb(r,G,f,ra)|0;r=G;v=c[B>>2]|0;u=c[B+4>>2]|0;if((v|0)==(-1|0)&(u|0)==2147483647){Aa=2147483647;Ba=-1}else{c[k>>2]=1;c[n>>2]=1e6;z=XIb(v,u,h,ra)|0;Aa=G;Ba=z}z=j+24|0;u=c[z+4>>2]|0;if(!((u|0)<(r|0)|(u|0)==(r|0)&(c[z>>2]|0)>>>0<sa>>>0)){if(!((Ba|0)==(-1|0)&(Aa|0)==2147483647)){u=j+16|0;v=c[u>>2]|0;pa=c[u+4>>2]|0;u=wrc(Ba,Aa,sa,r)|0;ma=G;if((pa|0)>(ma|0)|(pa|0)==(ma|0)&v>>>0>u>>>0){break j}}u=pJb(40)|0;if((u|0)==0){break j}c[u>>2]=c[j>>2];v=ra;ra=u+4|0;ma=c[v+4>>2]|0;c[ra>>2]=c[v>>2];c[ra+4>>2]=ma;ma=j+16|0;ra=xrc(c[ma>>2]|0,c[ma+4>>2]|0,sa,r)|0;ma=G;v=0;pa=(ma|0)<(v|0)|(ma|0)==(v|0)&ra>>>0<0>>>0;v=u+16|0;c[v>>2]=pa?0:ra;c[v+4>>2]=pa?0:ma;ma=xrc(c[z>>2]|0,c[z+4>>2]|0,sa,r)|0;r=G;sa=(Aa|0)>(r|0)|(Aa|0)==(r|0)&Ba>>>0>ma>>>0;z=u+24|0;c[z>>2]=sa?ma:Ba;c[z+4>>2]=sa?r:Aa;PGb(u+32|0,c[j+32>>2]|0,0);j=c[ua>>2]|0;c[ua>>2]=j+1;c[(c[l>>2]|0)+(j<<2)>>2]=u}ya=ya+1|0;}while(ya>>>0<(c[xa>>2]|0)>>>0)}else{ya=0;do{va=c[(c[m>>2]|0)+(ya<<2)>>2]|0;u=c[J>>2]|0;j=c[J+4>>2]|0;r=(u|0)==0&(j|0)==(-2147483648|0);sa=xrc(r?0:u,r?0:j,c[wa>>2]|0,c[wa+4>>2]|0)|0;c[K>>2]=1;c[o>>2]=1e6;j=va+4|0;r=XIb(sa,G,f,j)|0;sa=G;u=c[B>>2]|0;z=c[B+4>>2]|0;if((u|0)==(-1|0)&(z|0)==2147483647){Ca=2147483647;Da=-1}else{c[k>>2]=1;c[n>>2]=1e6;ma=XIb(u,z,h,j)|0;Ca=G;Da=ma}ma=va+24|0;z=c[ma+4>>2]|0;if(!((z|0)<(sa|0)|(z|0)==(sa|0)&(c[ma>>2]|0)>>>0<r>>>0)){if(!((Da|0)==(-1|0)&(Ca|0)==2147483647)){z=va+16|0;u=c[z>>2]|0;pa=c[z+4>>2]|0;z=wrc(Da,Ca,r,sa)|0;v=G;if((pa|0)>(v|0)|(pa|0)==(v|0)&u>>>0>z>>>0){break j}}z=pJb(40)|0;if((z|0)==0){break j}c[z>>2]=c[va>>2];u=j;j=z+4|0;v=c[u+4>>2]|0;c[j>>2]=c[u>>2];c[j+4>>2]=v;v=va+16|0;va=xrc(c[v>>2]|0,c[v+4>>2]|0,r,sa)|0;v=G;j=0;u=(v|0)<(j|0)|(v|0)==(j|0)&va>>>0<0>>>0;j=z+16|0;c[j>>2]=u?0:va;c[j+4>>2]=u?0:v;v=xrc(c[ma>>2]|0,c[ma+4>>2]|0,r,sa)|0;sa=G;r=(Ca|0)>(sa|0)|(Ca|0)==(sa|0)&Da>>>0>v>>>0;ma=z+24|0;c[ma>>2]=r?v:Da;c[ma+4>>2]=r?sa:Ca;sa=c[ua>>2]|0;c[ua>>2]=sa+1;c[(c[l>>2]|0)+(sa<<2)>>2]=z}ya=ya+1|0;}while(ya>>>0<(c[xa>>2]|0)>>>0)}}}while(0);if((c[b+136>>2]|0)==0&(c[1371162]|0)!=0){PGb((c[q>>2]|0)+1140|0,c[(c[c[c[1475750]>>2]>>2]|0)+1140>>2]|0,16);if(!((c[H>>2]|0)==(-1|0)&(c[H+4>>2]|0)==2147483647)){MGb((c[q>>2]|0)+1140|0,2105584,0,0)|0}MGb((c[q>>2]|0)+1140|0,2256408,0,0)|0}do{if((c[b+140>>2]|0)==0){H=c[F>>2]|0;Ca=c[1371156]|0;if((H|0)<(Ca|0)){Ea=H;Fa=Ca}else{break}while(1){Ca=c[(c[1366870]|0)+(Ea<<2)>>2]|0;H=c[Ca+8>>2]|0;if((H|0)<0){Ga=Fa}else{PGb((c[Ca+12>>2]|0)+88|0,c[(c[(c[(c[1475748]|0)+(H<<2)>>2]|0)+4>>2]|0)+88>>2]|0,16);Ga=c[1371156]|0}H=Ea+1|0;if((H|0)<(Ga|0)){Ea=H;Fa=Ga}else{break}}}}while(0);Ga=b+224|0;if((c[Ga>>2]|0)<=0){i=e;return 0}Fa=b+220|0;b=0;Ea=0;while(1){c[y>>2]=0;F=c[(c[Fa>>2]|0)+(b<<4)+8>>2]|0;H=_b(F|0,61)|0;if((H|0)==0){KIb(0,8,2255552,(E=i,i=i+8|0,c[E>>2]=F,E)|0);i=E;Hf(1)}F=H+1|0;a[H]=0;vh(c[(c[Fa>>2]|0)+(b<<4)>>2]|0,w,y,x);H=a[w]|0;do{if(H<<24>>24==115){Ca=c[q>>2]|0;if((c[Ca+24>>2]|0)==0){Ha=Ea;break}Da=c[x>>2]|0;h=0;B=Ca;while(1){Ca=xg(B,c[(c[B+28>>2]|0)+(h<<2)>>2]|0,Da)|0;do{if((Ca|0)>0){MGb((c[(c[(c[q>>2]|0)+28>>2]|0)+(h<<2)>>2]|0)+88|0,c[(c[Fa>>2]|0)+(b<<4)+8>>2]|0,(a[F]|0)!=0?F:0,0)|0}else{if((Ca|0)>=0){break}Hf(1)}}while(0);Ca=h+1|0;f=c[q>>2]|0;if(Ca>>>0<(c[f+24>>2]|0)>>>0){h=Ca;B=f}else{Ha=Ea;break}}}else{B=H<<24>>24;if((B|0)==103){Ia=(c[q>>2]|0)+1140|0}else if((B|0)==99){B=c[y>>2]|0;if((B|0)<0){Z=293}else{h=c[q>>2]|0;if(B>>>0<(c[h+1132>>2]|0)>>>0){Ja=h}else{Z=293}}if((Z|0)==293){Z=0;KIb(0,8,2254776,(E=i,i=i+8|0,c[E>>2]=B,E)|0);i=E;Hf(1);Ja=c[q>>2]|0}Ia=(c[(c[Ja+1136>>2]|0)+(B<<2)>>2]|0)+32|0}else{KIb(0,8,2254544,(E=i,i=i+8|0,c[E>>2]=c[(c[Fa>>2]|0)+(b<<4)>>2],E)|0);i=E;Hf(1);Ia=Ea}MGb(Ia,c[(c[Fa>>2]|0)+(b<<4)+8>>2]|0,(a[F]|0)!=0?F:0,0)|0;Ha=Ia}}while(0);F=b+1|0;if((F|0)<(c[Ga>>2]|0)){b=F;Ea=Ha}else{break}}i=e;return 0}function Kg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+32|0;f=d|0;g=d+8|0;h=d+16|0;j=d+24|0;k=(a[e]|0)==45;l=k?e+1|0:e;e=rJb(l)|0;c[h>>2]=e;m=_b(e|0,44)|0;c[g>>2]=m;do{if((m|0)==0){n=0;o=-1}else{a[m]=0;e=rb(m+1|0,g|0,0)|0;if((e|0)>=(c[1371162]|0)|(e|0)<0){KIb(0,8,2265904,(p=i,i=i+8|0,c[p>>2]=e,p)|0);i=p;Hf(1)}q=c[g>>2]|0;if((a[q]|0)==0){r=q}else{s=q+1|0;c[g>>2]=s;r=s}s=0;while(1){q=c[(c[1475750]|0)+(e<<2)>>2]|0;t=c[q+56>>2]|0;if((s|0)>=(t|0)){u=0;v=t;break}t=c[q>>2]|0;if((xg(t,c[(c[t+28>>2]|0)+(s<<2)>>2]|0,r)|0)==1){w=9;break}else{s=s+1|0}}if((w|0)==9){u=s;v=c[(c[(c[1475750]|0)+(e<<2)>>2]|0)+56>>2]|0}if((s|0)!=(v|0)){n=u;o=e;break}KIb(0,8,2265616,(p=i,i=i+8|0,c[p>>2]=l,p)|0);i=p;Hf(1);n=u;o=e}}while(0);u=c[h>>2]|0;a:do{if((a[u]|0)==91){c[j>>2]=u+1;v=b+120|0;r=b+124|0;g=Ag(c[v>>2]|0,24,r,(c[r>>2]|0)+1|0)|0;c[v>>2]=g;v=(c[r>>2]|0)-1|0;r=g+(v*24|0)|0;m=GFb(j,2265456)|0;c[g+(v*24|0)+20>>2]=m;if((m|0)!=0){x=r;w=31;break}KIb(0,16,2265256,(p=i,i=i+8|0,c[p>>2]=c[h>>2],p)|0);i=p;Hf(1);x=r;w=31}else{r=rb(u|0,f|0,0)|0;if((r|0)>=(c[1371162]|0)|(r|0)<0){KIb(0,8,2265048,(p=i,i=i+8|0,c[p>>2]=r,p)|0);i=p;Hf(1)}if(k){m=b+124|0;if((c[m>>2]|0)<=0){break}v=b+120|0;g=c[f>>2]|0;t=g+1|0;q=0;while(1){y=c[v>>2]|0;z=y+(q*24|0)|0;do{if((r|0)==(c[y+(q*24|0)+4>>2]|0)){A=c[c[(c[1475750]|0)+(r<<2)>>2]>>2]|0;if((xg(A,c[(c[A+28>>2]|0)+(c[y+(q*24|0)+8>>2]<<2)>>2]|0,(a[g]|0)==58?t:g)|0)<=0){break}c[z>>2]=1}}while(0);y=q+1|0;if((y|0)<(c[m>>2]|0)){q=y}else{x=z;w=31;break a}}}q=c[(c[1475750]|0)+(r<<2)>>2]|0;if((c[q+56>>2]|0)<=0){break}m=c[f>>2]|0;g=m+1|0;t=b+120|0;v=b+124|0;e=(o|0)>-1;s=0;y=0;A=q;while(1){q=c[A>>2]|0;do{if((xg(q,c[(c[q+28>>2]|0)+(y<<2)>>2]|0,(a[m]|0)==58?g:m)|0)<1){B=s}else{C=Ag(c[t>>2]|0,24,v,(c[v>>2]|0)+1|0)|0;c[t>>2]=C;D=(c[v>>2]|0)-1|0;E=C+(D*24|0)|0;c[C+(D*24|0)+4>>2]=r;c[C+(D*24|0)+8>>2]=y;F=C+(D*24|0)+12|0;if(e){c[F>>2]=o;c[C+(D*24|0)+16>>2]=n;B=E;break}else{c[F>>2]=r;c[C+(D*24|0)+16>>2]=y;B=E;break}}}while(0);q=y+1|0;z=c[(c[1475750]|0)+(r<<2)>>2]|0;if((q|0)<(c[z+56>>2]|0)){s=B;y=q;A=z}else{x=B;w=31;break}}}}while(0);do{if((w|0)==31){if((x|0)==0){break}G=h;mJb(G);i=d;return 0}}while(0);KIb(0,8,2264808,(p=i,i=i+8|0,c[p>>2]=l,p)|0);i=p;Hf(1);G=h;mJb(G);i=d;return 0}function Lg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;e=a+128|0;f=a+132|0;a=Ag(c[e>>2]|0,20,f,(c[f>>2]|0)+1|0)|0;c[e>>2]=a;e=(c[f>>2]|0)-1|0;f=a+(e*20|0)|0;g=a+(e*20|0)+8|0;h=a+(e*20|0)+12|0;j=a+(e*20|0)+16|0;k=Bd(d|0,2269208,(l=i,i=i+24|0,c[l>>2]=g,c[l+8>>2]=h,c[l+16>>2]=j,l)|0)|0;i=l;m=(k|0)==1;do{if((k|0)==3|(k|0)==1){if(!((c[g>>2]|0)==-1)){break}c[a+(e*20|0)+4>>2]=-1;c[f>>2]=-1;if(!m){i=b;return 0}c[j>>2]=-1;c[h>>2]=-1;i=b;return 0}}while(0);m=f|0;f=a+(e*20|0)+4|0;e=Bd(d|0,2268984,(l=i,i=i+40|0,c[l>>2]=m,c[l+8>>2]=f,c[l+16>>2]=g,c[l+24>>2]=h,c[l+32>>2]=j,l)|0)|0;i=l;if((e|0)==3){n=7}else if((e|0)!=5){KIb(0,8,2268680,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;Hf(1);n=7}if((n|0)==7){c[j>>2]=-1;c[h>>2]=-1}h=c[m>>2]|0;if(!((h|0)>-1&(h|0)<(c[1371162]|0))){KIb(0,8,2268456,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l;Hf(1)}h=c[f>>2]|0;j=c[m>>2]|0;if((h|0)<0){n=12}else{e=c[(c[1475750]|0)+(j<<2)>>2]|0;if((h|0)<(c[e+56>>2]|0)){o=h;p=j;q=e}else{n=12}}if((n|0)==12){KIb(0,8,2267352,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=h,l)|0);i=l;Hf(1);h=c[m>>2]|0;o=c[f>>2]|0;p=h;q=c[(c[1475750]|0)+(h<<2)>>2]|0}h=(c[(c[(c[q>>2]|0)+28>>2]|0)+(o<<2)>>2]|0)+8|0;if((c[(c[h>>2]|0)+8>>2]|0)!=1){KIb(0,8,2266592,(l=i,i=i+16|0,c[l>>2]=p,c[l+8>>2]=o,l)|0);i=l;Hf(1)}o=c[g>>2]|0;do{if((o|0)>=0){if((o|0)>=(c[(c[h>>2]|0)+416>>2]|0)){break}i=b;return 0}}while(0);h=c[f>>2]|0;KIb(0,8,2266176,(l=i,i=i+24|0,c[l>>2]=c[m>>2],c[l+8>>2]=h,c[l+16>>2]=o,l)|0);i=l;Hf(1);i=b;return 0}function Mg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0.0;e=i;i=i+184|0;f=e+128|0;g=e+136|0;h=Jf(b,d,0)|0;j=(+(h>>>0)+ +(G|0)*4294967296.0)/1.0e6;h=(F=+j,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[f>>2]=~~+j>>>0;c[f+4>>2]=h;nrc(g|0,rc(f|0)|0,44)|0;f=e|0;Fc(f|0,128,2269968,g|0)|0;Mf(a,2598680,f,771552)|0;KIb(0,24,2269528,(f=i,i=i+8|0,c[f>>2]=b,f)|0);i=f;i=e;return 0}function Ng(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2270360,c,771552)|0}function Og(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;d=i;i=i+72|0;b=d|0;c[b>>2]=0;f=(irc(e,2272168)|0)==0;g=f?2271272:e;e=VD(b,g,2,1070432,0)|0;if((e|0)<0){f=d+8|0;mrc(f|0,0,64)|0;a[f]=0;RGb(e,f,64)|0;KIb(0,16,2270712,(h=i,i=i+16|0,c[h>>2]=g,c[h+8>>2]=f,h)|0);i=h;j=e;i=d;return j|0}else{c[1357566]=c[b>>2];j=0;i=d;return j|0}return 0}function Pg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;a:do{if((krc(d,2306584,4)|0)==0){e=0;f=d+4|0}else{if((krc(d,2306384,5)|0)==0){e=1;f=d+5|0;break}if((krc(d,2306224,5)|0)==0){e=2;f=d+5|0;break}h=c[1371162]|0;b:do{if((h|0)>0){j=c[1475750]|0;k=0;c:while(1){l=c[j+(k<<2)>>2]|0;m=c[l+56>>2]|0;if((m|0)>0){n=c[(c[l>>2]|0)+28>>2]|0;l=0;do{o=c[(c[n+(l<<2)>>2]|0)+8>>2]|0;if((c[o+8>>2]|0)==0){p=((c[o+108>>2]|0)*1e3|0|0)/(c[o+104>>2]|0)|0;if((p|0)==25e3){q=0;break c}if((p|0)==29970|(p|0)==23976){q=1;break c}}l=l+1|0;}while((l|0)<(m|0))}k=k+1|0;if((k|0)>=(h|0)){break b}}KIb(0,32,2306008,(r=i,i=i+8|0,c[r>>2]=(q|0)==0?2305848:2305608,r)|0);i=r;e=q;f=d;break a}}while(0);KIb(0,8,2305280,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;KIb(0,8,2304184,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;KIb(0,8,2302368,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;Hf(1);e=3;f=d}}while(0);if((irc(f,2300880)|0)==0){Mf(a,2314016,2297896,771552)|0;Mf(a,2319672,2296504,771552)|0;Mf(a,2177536,2300880,771552)|0;d=(e|0)==0;Mf(a,2455624,d?2295712:2294776,771552)|0;Mf(a,2462784,c[774512+(e<<2)>>2]|0,771552)|0;q=a;MGb((c[q>>2]|0)+16|0,2293552,d?2293144:2291240,16)|0;MGb((c[q>>2]|0)+16|0,2318672,2289536,16)|0;MGb((c[q>>2]|0)+16|0,2288472,2289536,16)|0;MGb((c[q>>2]|0)+16|0,2287696,2289536,16)|0;MGb((c[q>>2]|0)+16|0,2287128,2286912,16)|0;MGb((c[q>>2]|0)+16|0,2286656,2286320,16)|0;Mf(a,2383432,2286008,771552)|0;Mf(a,2380104,2285856,771552)|0;MGb((c[q>>2]|0)+20|0,2284552,2283896,16)|0;MGb((c[q>>2]|0)+20|0,2283448,2283184,16)|0;g[a+184>>2]=.4399999976158142;s=0;i=b;return s|0}if((irc(f,2282992)|0)==0){Mf(a,2314016,2282752,771552)|0;Mf(a,2319672,2296504,771552)|0;Mf(a,2177536,2282992,771552)|0;q=(e|0)==0;Mf(a,2455624,q?2282464:2282224,771552)|0;Mf(a,2462784,c[774512+(e<<2)>>2]|0,771552)|0;Mf(a,2448760,2281992,771552)|0;d=a;MGb((c[d>>2]|0)+16|0,2293552,q?2293144:2291240,16)|0;MGb((c[d>>2]|0)+16|0,2318672,2281728,16)|0;MGb((c[d>>2]|0)+16|0,2288472,2280792,16)|0;MGb((c[d>>2]|0)+16|0,2287696,2280032,16)|0;MGb((c[d>>2]|0)+16|0,2287128,2279624,16)|0;MGb((c[d>>2]|0)+16|0,2279432,2279120,16)|0;MGb((c[d>>2]|0)+16|0,2286656,2286320,16)|0;Mf(a,2383432,2286008,771552)|0;MGb((c[d>>2]|0)+20|0,2284552,2283896,16)|0;s=0;i=b;return s|0}if((irc(f,2278904)|0)==0){Mf(a,2314016,2282752,771552)|0;Mf(a,2319672,2278544,771552)|0;Mf(a,2177536,2278904,771552)|0;d=(e|0)==0;Mf(a,2455624,d?2278288:2277888,771552)|0;Mf(a,2462784,c[774512+(e<<2)>>2]|0,771552)|0;Mf(a,2448760,2281992,771552)|0;q=a;MGb((c[q>>2]|0)+16|0,2293552,d?2293144:2291240,16)|0;MGb((c[q>>2]|0)+16|0,2318672,2277688,16)|0;MGb((c[q>>2]|0)+16|0,2288472,2276552,16)|0;MGb((c[q>>2]|0)+16|0,2287696,2280032,16)|0;MGb((c[q>>2]|0)+16|0,2287128,2279624,16)|0;MGb((c[q>>2]|0)+20|0,2284552,2275856,16)|0;MGb((c[q>>2]|0)+20|0,2283448,2275504,16)|0;MGb((c[q>>2]|0)+16|0,2286656,2275248,16)|0;Mf(a,2383432,2274920,771552)|0;s=0;i=b;return s|0}if((krc(f,2274744,2)|0)!=0){KIb(0,16,2273448,(r=i,i=i+8|0,c[r>>2]=f,r)|0);i=r;s=-22;i=b;return s|0}Mf(a,2177536,2274744,771552)|0;r=(e|0)==0;Mf(a,2455624,r?2278288:2277888,771552)|0;if((krc(f,2274360,4)|0)==0){t=2274064}else{t=r?2281992:2273672}Mf(a,2448760,t,771552)|0;Mf(a,2462784,c[774512+(e<<2)>>2]|0,771552)|0;Mf(a,2383432,2274920,771552)|0;Mf(a,2380104,2285856,771552)|0;s=0;i=b;return s|0}function Qg(a,b,d){a=a|0;b=b|0;d=d|0;if((IFb(d,2310128)|0)==0){c[64350]=1;return 0}if((IFb(d,2309752)|0)==0){c[64350]=2;return 0}if((IFb(d,2309520)|0)==0){c[64350]=0;return 0}if((IFb(d,2309136)|0)==0){c[64350]=255;return 0}if(!((c[64350]|0)==-1)){return 0}c[64350]=~~+If(2540336,d,128,-1.0,2.0);return 0}function Rg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if((irc(b,2491352)|0)==0){KIb(0,24,2311112,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=Mf(a,2310744,d,771552)|0;i=e;return g|0}else{h=FFb(2310424,(f=i,i=i+8|0,c[f>>2]=b+6,f)|0)|0;i=f;f=Mf(a,h,d,771552)|0;kJb(h);g=f;i=e;return g|0}return 0}function Sg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;if((irc(b,2490488)|0)==0){KIb(0,24,2312392,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;MGb((c[a>>2]|0)+16|0,2311472,d,0)|0;i=e;return 0}else{MGb((c[a>>2]|0)+16|0,b,d,0)|0;i=e;return 0}return 0}function Tg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;c[1510464]=Ag(c[1510464]|0,4,5484672,(c[1371168]|0)+1|0)|0;b=pJb(32)|0;a=(c[1371168]|0)-1|0;c[(c[1510464]|0)+(a<<2)>>2]=b;if((b|0)==0){e=-12;return e|0}c[c[(c[1510464]|0)+(a<<2)>>2]>>2]=a;a=rJb(d)|0;d=(c[1371168]|0)-1|0;c[(c[(c[1510464]|0)+(d<<2)>>2]|0)+4>>2]=a;e=(c[(c[(c[1510464]|0)+(d<<2)>>2]|0)+4>>2]|0)==0?-12:0;return e|0}function Ug(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=oh(d)|0;if((b|0)==0){e=-22;return e|0}c[1510464]=Ag(c[1510464]|0,4,5484672,(c[1371168]|0)+1|0)|0;d=pJb(32)|0;a=(c[1371168]|0)-1|0;c[(c[1510464]|0)+(a<<2)>>2]=d;if((d|0)==0){e=-12;return e|0}d=c[1510464]|0;c[c[d+(a<<2)>>2]>>2]=a;c[(c[d+((c[1371168]|0)-1<<2)>>2]|0)+4>>2]=b;e=0;return e|0}function Vg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a+148|0;e=a+152|0;a=Ag(c[b>>2]|0,4,e,(c[e>>2]|0)+1|0)|0;c[b>>2]=a;c[a+((c[e>>2]|0)-1<<2)>>2]=d;return 0}function Wg(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2313608,c,771552)|0}function Xg(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2314016,c,771552)|0}function Yg(a,b,d){a=a|0;b=b|0;d=d|0;d=i;KIb(0,16,2314360,(a=i,i=i+16|0,c[a>>2]=b,c[a+8>>2]=b,a)|0);i=a;i=d;return-22|0}function Zg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;e=FFb(2315200,(f=i,i=i+8|0,c[f>>2]=d,f)|0)|0;i=f;if(!((Mf(a,2315e3,e,771552)|0)>-1)){kJb(e);i=b;return 0}MGb((c[a>>2]|0)+16|0,2314800,d,0)|0;kJb(e);i=b;return 0}function _g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=i;i=i+48|0;b=d+40|0;c[b>>2]=ie(0)|0;a=Ab(b|0)|0;b=d|0;e=c[a+4>>2]|0;f=c[a>>2]|0;Rb(b|0,40,2315544,(g=i,i=i+24|0,c[g>>2]=c[a+8>>2],c[g+8>>2]=e,c[g+16>>2]=f,g)|0)|0;i=g;kJb(c[836152]|0);c[836152]=rJb(b)|0;i=d;return 0}function $g(a,b,d){a=a|0;b=b|0;d=d|0;kJb(c[836152]|0);c[836152]=rJb(d)|0;return 0}function ah(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2315976,c,771552)|0}function bh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a[d]|0;h=FFb(2316944,(j=i,i=i+16|0,c[j>>2]=d+1,c[j+8>>2]=g,j)|0)|0;i=j;j=Mf(b,h,e,771552)|0;kJb(h);i=f;return j|0}function ch(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f|0;CFb(g,e,16)|0;h=_b(g|0,58)|0;if((h|0)==0){KIb(0,8,2318536,(j=i,i=i+16|0,c[j>>2]=e,c[j+8>>2]=d,j)|0);i=j;Hf(1)}a[h]=0;j=~~+If(d,g,128,0.0,1023.0);g=b+212|0;c[g>>2]=Ag(c[g>>2]|0,4,b+216|0,j+1|0)|0;b=~~+If(d,h+1|0,128,0.0,2147483647.0);c[(c[g>>2]|0)+(j<<2)>>2]=b;i=f;return 0}function dh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;if((irc(b,2391560)|0)==0){KIb(0,24,2318944,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;MGb((c[a>>2]|0)+16|0,2318672,d,0)|0;i=e;return 0}else{MGb((c[a>>2]|0)+16|0,b,d,0)|0;i=e;return 0}return 0}function eh(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2319232,c,771552)|0}function fh(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2319432,c,771552)|0}function gh(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2319672,c,771552)|0}function hh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+32|0;f=pGb(d)|0;g=G;if((f|0)==0&(g|0)==0){KIb(0,16,2320824,(h=i,i=i+8|0,c[h>>2]=d,h)|0);i=h;j=-22;i=e;return j|0}d=e|0;Rb(d|0,32,2320176,(h=i,i=i+16|0,c[h>>2]=f,c[h+8>>2]=g,h)|0)|0;i=h;k=c[2450052]|0;l=c[1510444]|0;c[2450052]=0;c[1510444]=0;m=Tf(0,b,d)|0;n=a;PGb((c[n>>2]|0)+16|0,c[2450052]|0,0);PGb((c[n>>2]|0)+20|0,c[1510444]|0,0);OGb(9800208);OGb(6041776);c[2450052]=k;c[1510444]=l;if((m|0)<0){j=m;i=e;return j|0}m=rGb(f,g)|0;Rb(d|0,32,2319880,(h=i,i=i+8|0,c[h>>2]=m,h)|0)|0;i=h;h=_b(b|0,58)|0;b=(h|0)!=0;if(b){o=(lrc(h|0)|0)+3|0}else{o=3}m=pJb(o)|0;if((m|0)==0){j=-12;i=e;return j|0}CFb(m,2380104,3)|0;if(b){DFb(m,h,o)|0}o=Mf(a,m,d,771552)|0;kJb(m);j=o;i=e;return j|0}function ih(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2322056,c,771552)|0}function jh(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2323464,c,771552)|0}function kh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;KIb(0,24,2323616,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;e=Tf(a,2348736,d)|0;i=b;return e|0}function lh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;KIb(0,24,2324088,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;e=Tf(a,2347376,d)|0;i=b;return e|0}function mh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+3016|0;g=f|0;h=f+1e3|0;j=f+2e3|0;k=f+3e3|0;l=f+3008|0;m=a[d]|0;d=j|0;a[d]=m;a[j+1|0]=0;j=c[b+24>>2]|0;if((j|0)>0){n=c[b+20>>2]|0;o=0;p=0;while(1){if((irc(c[n+(o<<4)>>2]|0,d)|0)==0){q=c[n+(o<<4)+8>>2]|0}else{q=p}r=o+1|0;if((r|0)<(j|0)){o=r;p=q}else{s=q;break}}}else{s=0}q=g|0;g=wg(q,1e3,e,m<<24>>24==102|0,s)|0;if((g|0)==0){if((krc(e,2329664,16)|0)==0){KIb(0,8,2329544,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{KIb(0,8,2327808,(t=i,i=i+8|0,c[t>>2]=e,t)|0);i=t}Hf(1)}e=h|0;if((Yb(e|0,1e3,g|0)|0)==0){u=nb(g|0)|0;i=f;return 0}h=b;do{do{if((mc(e|0,2326632)|0)!=0){CFb(d,e,1e3)|0;if((HFb(d,2326024,k)|0)==0){v=17}else{if((HFb(c[k>>2]|0,2325608,l)|0)==0){v=17}}if((v|0)==17){v=0;KIb(0,8,2325168,(t=i,i=i+16|0,c[t>>2]=q,c[t+8>>2]=e,t)|0);i=t;Hf(1)}s=c[k>>2]|0;KIb(0,48,2324840,(t=i,i=i+24|0,c[t>>2]=q,c[t+8>>2]=d,c[t+16>>2]=s,t)|0);i=t;if((irc(d,2377872)|0)==0){Mf(b,2319672,c[k>>2]|0,771552)|0;break}if((irc(d,2429496)|0)==0){Mf(b,2314016,c[k>>2]|0,771552)|0;break}if((irc(d,2361648)|0)==0){Mf(b,2323464,c[k>>2]|0,771552)|0;break}s=(irc(d,2331312)|0)==0;m=c[k>>2]|0;if(s){Mf(b,2330072,m,771552)|0;break}s=c[2450052]|0;p=c[1510444]|0;c[2450052]=0;c[1510444]=0;o=Tf(0,d,m)|0;PGb((c[h>>2]|0)+16|0,c[2450052]|0,0);PGb((c[h>>2]|0)+20|0,c[1510444]|0,0);OGb(9800208);OGb(6041776);c[2450052]=s;c[1510444]=p;if((o|0)>=0){break}o=c[k>>2]|0;KIb(0,8,2324464,(t=i,i=i+32|0,c[t>>2]=q,c[t+8>>2]=e,c[t+16>>2]=d,c[t+24>>2]=o,t)|0);i=t;Hf(1)}}while(0);}while((Yb(e|0,1e3,g|0)|0)!=0);u=nb(g|0)|0;i=f;return 0}function nh(a,b,c){a=a|0;b=b|0;c=c|0;return Mf(a,2330072,c,771552)|0}function oh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+1048|0;d=b|0;e=b+8|0;f=b+1040|0;c[d>>2]=0;c[e>>2]=0;if((UD(d,a,1)|0)<0){KIb(0,16,2313496,(g=i,i=i+8|0,c[g>>2]=a,g)|0);i=g;i=b;return 0}if((_D(e)|0)<0){XD(d)|0;i=b;return 0}g=b+16|0;a=AD(c[d>>2]|0,g,1024)|0;h=c[e>>2]|0;if((a|0)>0){j=a;a=h;while(1){dD(a,g,j);k=AD(c[d>>2]|0,g,1024)|0;l=c[e>>2]|0;if((k|0)>0){j=k;a=l}else{m=l;break}}}else{m=h}bD(m,0);XD(d)|0;d=(aE(c[e>>2]|0,f)|0)<0;i=b;return(d?0:c[f>>2]|0)|0}function ph(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=a+16|0;g=c[f>>2]|0;h=kj(c[(c[g+4>>2]|0)+28>>2]|0,c[g+8>>2]|0)|0;if((h|0)==0){j=qh(b,d,-1)|0}else if((h|0)==1){j=rh(b,d,-1)|0}else{KIb(0,8,2226416,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;Hf(1);j=0}c[j+8>>2]=-1;c[j+300>>2]=a;c[a+4>>2]=j;if((c[j+352>>2]|0)!=0){d=c[j+4>>2]|0;KIb(0,16,2225976,(k=i,i=i+16|0,c[k>>2]=c[j>>2],c[k+8>>2]=d,k)|0);i=k;Hf(1)}do{if((c[j+304>>2]|0)!=0){d=c[j+308>>2]|0;if((d|0)==0){b=c[j+312>>2]|0;if((b|0)==0){break}else{l=b;m=2225496;n=2230864}}else{l=d;m=2225736;n=2231448}d=c[j>>2]|0;b=c[j+4>>2]|0;KIb(0,16,2224976,(k=i,i=i+48|0,c[k>>2]=n,c[k+8>>2]=l,c[k+16>>2]=m,c[k+24>>2]=d,c[k+32>>2]=b,c[k+40>>2]=m,k)|0);i=k;Hf(1)}}while(0);if((Dh(c[a+8>>2]|0,a,c[f>>2]|0)|0)>=0){kl(f);i=e;return}KIb(0,8,2223992,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;Hf(1);kl(f);i=e;return}function qh(d,e,f){d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+8|0;j=h|0;k=j;l=i;i=i+4|0;i=i+7&-8;m=i;i=i+4|0;i=i+7&-8;n=i;i=i+4|0;i=i+7&-8;o=wh(d,e,0,f)|0;f=c[o+12>>2]|0;p=c[f+8>>2]|0;q=d+48|0;do{if((c[q>>2]|0)>0){r=d+44|0;s=0;t=0;while(1){u=xg(e,f,c[(c[r>>2]|0)+(s<<4)>>2]|0)|0;do{if((u|0)>0){v=c[(c[r>>2]|0)+(s<<4)+8>>2]|0}else{if((u|0)>=0){v=t;break}Hf(1);v=t}}while(0);u=s+1|0;if((u|0)<(c[q>>2]|0)){s=u;t=v}else{break}}if((v|0)==0){break}if((cKb(o+76|0,v)|0)>=0){break}KIb(0,8,2230176,(w=i,i=i+8|0,c[w>>2]=v,w)|0);i=w;Hf(1)}}while(0);v=d+288|0;do{if((c[v>>2]|0)>0){q=d+284|0;t=0;s=0;while(1){r=xg(e,f,c[(c[q>>2]|0)+(t<<4)>>2]|0)|0;do{if((r|0)>0){x=c[(c[q>>2]|0)+(t<<4)+8>>2]|0}else{if((r|0)>=0){x=s;break}Hf(1);x=s}}while(0);r=t+1|0;if((r|0)<(c[v>>2]|0)){t=r;s=x}else{break}}if((x|0)==0){break}do{if((aKb(k,x,255,0,0)|0)<0){y=22}else{if((c[j>>2]|0)<1){y=22;break}if((c[k+4>>2]|0)<1){y=22}}}while(0);if((y|0)==22){KIb(0,8,2229832,(w=i,i=i+8|0,c[w>>2]=x,w)|0);i=w;Hf(1)}s=o+92|0;t=c[j+4>>2]|0;c[s>>2]=c[j>>2];c[s+4>>2]=t}}while(0);j=d+376|0;if((c[j>>2]|0)>0){x=d+372|0;y=o+312|0;k=0;do{v=xg(e,f,c[(c[x>>2]|0)+(k<<4)>>2]|0)|0;do{if((v|0)>0){c[y>>2]=c[(c[x>>2]|0)+(k<<4)+8>>2]}else{if((v|0)>=0){break}Hf(1)}}while(0);k=k+1|0;}while((k|0)<(c[j>>2]|0))}j=d+368|0;if((c[j>>2]|0)>0){k=d+364|0;x=o+308|0;y=0;do{v=xg(e,f,c[(c[k>>2]|0)+(y<<4)>>2]|0)|0;do{if((v|0)>0){c[x>>2]=c[(c[k>>2]|0)+(y<<4)+8>>2]}else{if((v|0)>=0){break}Hf(1)}}while(0);y=y+1|0;}while((y|0)<(c[j>>2]|0))}j=o+352|0;do{if((c[j>>2]|0)==0){y=d+56|0;do{if((c[y>>2]|0)>0){k=d+52|0;x=0;v=0;while(1){t=xg(e,f,c[(c[k>>2]|0)+(x<<4)>>2]|0)|0;do{if((t|0)>0){z=c[(c[k>>2]|0)+(x<<4)+8>>2]|0}else{if((t|0)>=0){z=v;break}Hf(1);z=v}}while(0);t=x+1|0;if((t|0)<(c[y>>2]|0)){x=t;v=z}else{break}}if((z|0)==0){break}if((bKb(p+120|0,p+124|0,z)|0)>=0){break}KIb(0,8,2233088,(w=i,i=i+8|0,c[w>>2]=z,w)|0);i=w;Hf(1)}}while(0);c[p+796>>2]=c[1510442];y=d+64|0;do{if((c[y>>2]|0)>0){v=d+60|0;x=0;k=0;while(1){t=xg(e,f,c[(c[v>>2]|0)+(x<<4)>>2]|0)|0;do{if((t|0)>0){A=c[(c[v>>2]|0)+(x<<4)+8>>2]|0}else{if((t|0)>=0){A=k;break}Hf(1);A=k}}while(0);t=x+1|0;if((t|0)<(c[y>>2]|0)){x=t;k=A}else{break}}if((A|0)==0){break}if((a[A]|0)==43){c[o+368>>2]=1;k=A+1|0;x=(a[k]|0)==0?0:k;if((x|0)==0){break}else{B=x}}else{B=A}x=nKb(B)|0;c[p+140>>2]=x;if(!((x|0)==-1)){break}KIb(0,8,2229568,(w=i,i=i+8|0,c[w>>2]=B,w)|0);i=w;Hf(1)}}while(0);y=p+224|0;x=f+80|0;k=c[y+4>>2]|0;c[x>>2]=c[y>>2];c[x+4>>2]=k;if((c[1474792]|0)!=0){c[p+136>>2]=0}k=d+304|0;do{if((c[k>>2]|0)>0){x=d+300|0;y=0;v=0;while(1){t=xg(e,f,c[(c[x>>2]|0)+(y<<4)>>2]|0)|0;do{if((t|0)>0){C=c[(c[x>>2]|0)+(y<<4)+8>>2]|0}else{if((t|0)>=0){C=v;break}Hf(1);C=v}}while(0);t=y+1|0;if((t|0)<(c[k>>2]|0)){y=t;v=C}else{break}}if((C|0)==0){break}v=pJb(128)|0;y=v;x=p+300|0;c[x>>2]=y;if((v|0)==0){KIb(0,8,2229264,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;Hf(1);D=c[x>>2]|0}else{D=y}b[D>>1]=kd(C|0)|0;y=0;x=C;do{v=_b(x|0,44)|0;if((v|0)==0){KIb(0,8,2226712,(w=i,i=i+16|0,c[w>>2]=C,c[w+8>>2]=y,w)|0);i=w;Hf(1)}x=v+1|0;y=y+1|0;b[D+(y<<1)>>1]=kd(x|0)|0;}while((y|0)!=63)}}while(0);k=d+320|0;do{if((c[k>>2]|0)>0){y=d+316|0;x=0;v=0;while(1){t=xg(e,f,c[(c[y>>2]|0)+(x<<4)>>2]|0)|0;do{if((t|0)>0){E=c[(c[y>>2]|0)+(x<<4)+8>>2]|0}else{if((t|0)>=0){E=v;break}Hf(1);E=v}}while(0);t=x+1|0;if((t|0)<(c[k>>2]|0)){x=t;v=E}else{break}}if((E|0)==0){break}v=pJb(128)|0;x=v;if((v|0)==0){KIb(0,8,2229264,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;Hf(1)}Y4a(p,x);b[x>>1]=kd(E|0)|0;v=0;y=E;do{t=_b(y|0,44)|0;if((t|0)==0){KIb(0,8,2226712,(w=i,i=i+16|0,c[w>>2]=E,c[w+8>>2]=v,w)|0);i=w;Hf(1)}y=t+1|0;v=v+1|0;b[x+(v<<1)>>1]=kd(y|0)|0;}while((v|0)!=63)}}while(0);k=d+312|0;do{if((c[k>>2]|0)>0){v=d+308|0;y=0;x=0;while(1){t=xg(e,f,c[(c[v>>2]|0)+(y<<4)>>2]|0)|0;do{if((t|0)>0){F=c[(c[v>>2]|0)+(y<<4)+8>>2]|0}else{if((t|0)>=0){F=x;break}Hf(1);F=x}}while(0);t=y+1|0;if((t|0)<(c[k>>2]|0)){y=t;x=F}else{break}}if((F|0)==0){break}x=pJb(128)|0;y=x;v=p+304|0;c[v>>2]=y;if((x|0)==0){KIb(0,8,2228840,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;Hf(1);G=c[v>>2]|0}else{G=y}b[G>>1]=kd(F|0)|0;y=0;v=F;do{x=_b(v|0,44)|0;if((x|0)==0){KIb(0,8,2226712,(w=i,i=i+16|0,c[w>>2]=F,c[w+8>>2]=y,w)|0);i=w;Hf(1)}v=x+1|0;y=y+1|0;b[G+(y<<1)>>1]=kd(v|0)|0;}while((y|0)!=63)}}while(0);k=d+296|0;do{if((c[k>>2]|0)>0){y=d+292|0;v=0;x=0;while(1){t=xg(e,f,c[(c[y>>2]|0)+(v<<4)>>2]|0)|0;do{if((t|0)>0){H=c[(c[y>>2]|0)+(v<<4)+8>>2]|0}else{if((t|0)>=0){H=x;break}Hf(1);H=x}}while(0);t=v+1|0;if((t|0)<(c[k>>2]|0)){v=t;x=H}else{break}}if((H|0)==0){I=0;break}x=p+532|0;v=0;y=H;while(1){t=Bd(y|0,2228528,(w=i,i=i+24|0,c[w>>2]=l,c[w+8>>2]=m,c[w+16>>2]=n,w)|0)|0;i=w;if((t|0)!=3){KIb(0,8,2228352,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;Hf(1)}t=v+1|0;s=iJb(c[x>>2]|0,t<<4)|0;c[x>>2]=s;c[s+(v<<4)>>2]=c[l>>2];c[s+(v<<4)+4>>2]=c[m>>2];q=c[n>>2]|0;r=s+(v<<4)+8|0;if((q|0)>0){c[r>>2]=q;g[s+(v<<4)+12>>2]=1.0}else{c[r>>2]=0;g[s+(v<<4)+12>>2]=+(-(c[n>>2]|0)|0)/100.0}s=_b(y|0,47)|0;r=(s|0)==0?0:s+1|0;if((r|0)==0){I=t;break}else{v=t;y=r}}}else{I=0}}while(0);c[p+528>>2]=I;c[p+324>>2]=(c[266538]|0)-8;if((c[2333746]|0)!=0){k=p+88|0;c[k>>2]=c[k>>2]|32768}k=d+408|0;do{if((c[k>>2]|0)>0){y=d+404|0;v=0;x=0;while(1){r=xg(e,f,c[(c[y>>2]|0)+(x<<4)>>2]|0)|0;do{if((r|0)>0){J=c[(c[y>>2]|0)+(x<<4)+8>>2]|0}else{if((r|0)>=0){J=v;break}Hf(1);J=v}}while(0);r=x+1|0;if((r|0)<(c[k>>2]|0)){v=J;x=r}else{break}}if((J|0)==0){break}if((J&1|0)!=0){x=p+88|0;c[x>>2]=c[x>>2]|512;MGb(o+328|0,2181896,2227600,32)|0}if((J&2|0)==0){break}x=p+88|0;c[x>>2]=c[x>>2]|1024;MGb(o+328|0,2181896,2226960,32)|0}}while(0);k=d+416|0;if((c[k>>2]|0)>0){x=d+412|0;v=o+292|0;y=0;while(1){r=xg(e,f,c[(c[x>>2]|0)+(y<<4)>>2]|0)|0;do{if((r|0)>0){c[v>>2]=c[(c[x>>2]|0)+(y<<4)+8>>2]}else{if((r|0)>=0){break}Hf(1)}}while(0);r=y+1|0;if((r|0)<(c[k>>2]|0)){y=r}else{K=v;break}}}else{K=o+292|0}v=c[K>>2]|0;do{if((v|0)!=0){y=rJb(v)|0;c[K>>2]=y;if((y|0)!=0){break}Hf(1)}}while(0);v=d+272|0;if((c[v>>2]|0)>0){y=d+268|0;k=o+112|0;x=0;while(1){r=xg(e,f,c[(c[y>>2]|0)+(x<<4)>>2]|0)|0;do{if((r|0)>0){c[k>>2]=c[(c[y>>2]|0)+(x<<4)+8>>2]}else{if((r|0)>=0){break}Hf(1)}}while(0);r=x+1|0;if((r|0)<(c[v>>2]|0)){x=r}else{L=k;break}}}else{L=o+112|0}k=c[L>>2]|0;if((k|0)!=0){c[L>>2]=rJb(k)|0}k=d+280|0;if((c[k>>2]|0)>0){x=d+276|0;v=o+84|0;y=0;do{r=xg(e,f,c[(c[x>>2]|0)+(y<<4)>>2]|0)|0;do{if((r|0)>0){c[v>>2]=c[(c[x>>2]|0)+(y<<4)+8>>2]}else{if((r|0)>=0){break}Hf(1)}}while(0);y=y+1|0;}while((y|0)<(c[k>>2]|0))}k=o+88|0;c[k>>2]=-1;y=d+328|0;if((c[y>>2]|0)>0){x=d+324|0;v=0;do{r=xg(e,f,c[(c[x>>2]|0)+(v<<4)>>2]|0)|0;do{if((r|0)>0){c[k>>2]=c[(c[x>>2]|0)+(v<<4)+8>>2]}else{if((r|0)>=0){break}Hf(1)}}while(0);v=v+1|0;}while((v|0)<(c[y>>2]|0))}y=yh(o)|0;c[o+304>>2]=y;if((y|0)!=0){break}Hf(1)}else{y=d+352|0;if((c[y>>2]|0)<=0){break}v=d+348|0;x=o+360|0;k=0;do{r=xg(e,f,c[(c[v>>2]|0)+(k<<4)>>2]|0)|0;do{if((r|0)>0){c[x>>2]=c[(c[v>>2]|0)+(k<<4)+8>>2]}else{if((r|0)>=0){break}Hf(1)}}while(0);k=k+1|0;}while((k|0)<(c[y>>2]|0))}}while(0);if((c[j>>2]|0)==0){i=h;return o|0}j=c[o+312>>2]|0;f=c[o+308>>2]|0;do{if((j|0)==0){if((f|0)!=0){M=f;N=2231448;break}i=h;return o|0}else{e=(f|0)!=0;M=e?f:j;N=e?2231448:2230864}}while(0);j=ALb(0)|0;f=c[o>>2]|0;e=c[o+4>>2]|0;KIb(0,16,2232288,(w=i,i=i+40|0,c[w>>2]=N,c[w+8>>2]=M,c[w+16>>2]=j,c[w+24>>2]=f,c[w+32>>2]=e,w)|0);i=w;Hf(1);i=h;return o|0}function rh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;f=wh(a,b,1,d)|0;d=f+12|0;g=c[d>>2]|0;h=c[g+8>>2]|0;c[h+8>>2]=1;j=a+376|0;if((c[j>>2]|0)>0){k=a+372|0;l=f+312|0;m=0;do{n=xg(b,g,c[(c[k>>2]|0)+(m<<4)>>2]|0)|0;do{if((n|0)>0){c[l>>2]=c[(c[k>>2]|0)+(m<<4)+8>>2]}else{if((n|0)>=0){break}Hf(1)}}while(0);m=m+1|0;}while((m|0)<(c[j>>2]|0))}j=a+368|0;if((c[j>>2]|0)>0){m=a+364|0;k=f+308|0;l=0;do{n=xg(b,g,c[(c[m>>2]|0)+(l<<4)>>2]|0)|0;do{if((n|0)>0){c[k>>2]=c[(c[m>>2]|0)+(l<<4)+8>>2]}else{if((n|0)>=0){break}Hf(1)}}while(0);l=l+1|0;}while((l|0)<(c[j>>2]|0))}j=f+352|0;do{if((c[j>>2]|0)==0){l=a+32|0;if((c[l>>2]|0)>0){m=a+28|0;k=h+416|0;n=0;do{o=xg(b,g,c[(c[m>>2]|0)+(n<<4)>>2]|0)|0;do{if((o|0)>0){c[k>>2]=c[(c[m>>2]|0)+(n<<4)+8>>2]}else{if((o|0)>=0){break}Hf(1)}}while(0);n=n+1|0;}while((n|0)<(c[l>>2]|0))}l=a+256|0;do{if((c[l>>2]|0)>0){n=a+252|0;m=0;k=0;while(1){o=xg(b,g,c[(c[n>>2]|0)+(m<<4)>>2]|0)|0;do{if((o|0)>0){p=c[(c[n>>2]|0)+(m<<4)+8>>2]|0}else{if((o|0)>=0){p=k;break}Hf(1);p=k}}while(0);o=m+1|0;if((o|0)<(c[l>>2]|0)){m=o;k=p}else{break}}if((p|0)==0){break}k=MKb(p)|0;c[h+420>>2]=k;if(!((k|0)==-1)){break}KIb(0,8,2232800,(q=i,i=i+8|0,c[q>>2]=p,q)|0);i=q;Hf(1)}}while(0);l=a+40|0;if((c[l>>2]|0)>0){k=a+36|0;m=h+412|0;n=0;do{o=xg(b,g,c[(c[k>>2]|0)+(n<<4)>>2]|0)|0;do{if((o|0)>0){c[m>>2]=c[(c[k>>2]|0)+(n<<4)+8>>2]}else{if((o|0)>=0){break}Hf(1)}}while(0);n=n+1|0;}while((n|0)<(c[l>>2]|0))}l=a+432|0;if((c[l>>2]|0)>0){n=a+428|0;k=f+340|0;m=0;while(1){o=xg(b,g,c[(c[n>>2]|0)+(m<<4)>>2]|0)|0;do{if((o|0)>0){c[k>>2]=c[(c[n>>2]|0)+(m<<4)+8>>2]}else{if((o|0)>=0){break}Hf(1)}}while(0);o=m+1|0;if((o|0)<(c[l>>2]|0)){m=o}else{r=k;break}}}else{r=f+340|0}c[r>>2]=rJb(c[r>>2]|0)|0;k=yh(f)|0;c[f+304>>2]=k;if((k|0)==0){Hf(1)}k=a+132|0;if((c[k>>2]|0)>0){m=a+128|0;l=f+8|0;n=f+288|0;o=f|0;s=0;do{t=c[m>>2]|0;u=c[(c[1475748]|0)+(c[l>>2]<<2)>>2]|0;v=c[t+(s*20|0)+8>>2]|0;do{if((v|0)==-1){w=55}else{if((c[u>>2]|0)!=(c[t+(s*20|0)>>2]|0)){break}if((c[c[u+4>>2]>>2]|0)==(c[t+(s*20|0)+4>>2]|0)){w=55}}}while(0);do{if((w|0)==55){w=0;u=c[t+(s*20|0)+12>>2]|0;if(!((u|0)==-1)){if((c[o>>2]|0)!=(u|0)){break}}u=c[t+(s*20|0)+16>>2]|0;if(!((u|0)==-1)){if((c[c[d>>2]>>2]|0)!=(u|0)){break}}u=c[n>>2]|0;if(u>>>0<32>>>0){c[n>>2]=u+1;c[f+160+(u<<2)>>2]=v;break}else{u=c[c[d>>2]>>2]|0;KIb(0,8,2232536,(q=i,i=i+16|0,c[q>>2]=c[o>>2],c[q+8>>2]=u,q)|0);i=q;break}}}while(0);s=s+1|0;}while((s|0)<(c[k>>2]|0))}if((c[j>>2]|0)!=0){break}i=e;return f|0}}while(0);j=c[f+312>>2]|0;d=c[f+308>>2]|0;do{if((j|0)==0){if((d|0)!=0){x=d;y=2231448;break}i=e;return f|0}else{w=(d|0)!=0;x=w?d:j;y=w?2231448:2230864}}while(0);j=ALb(1)|0;d=c[f>>2]|0;w=c[f+4>>2]|0;KIb(0,16,2232288,(q=i,i=i+40|0,c[q>>2]=y,c[q+8>>2]=x,c[q+16>>2]=j,c[q+24>>2]=d,c[q+32>>2]=w,q)|0);i=q;Hf(1);i=e;return f|0}function sh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=wh(a,b,3,d)|0;d=c[f+12>>2]|0;g=c[d+8>>2]|0;c[g+8>>2]=3;h=a+352|0;if((c[h>>2]|0)>0){j=a+348|0;k=f+360|0;l=0;do{m=xg(b,d,c[(c[j>>2]|0)+(l<<4)>>2]|0)|0;do{if((m|0)>0){c[k>>2]=c[(c[j>>2]|0)+(l<<4)+8>>2]}else{if((m|0)>=0){break}Hf(1)}}while(0);l=l+1|0;}while((l|0)<(c[h>>2]|0))}if((c[f+352>>2]|0)!=0){i=e;return}f=a+56|0;if((c[f>>2]|0)<=0){i=e;return}h=a+52|0;a=0;l=0;while(1){j=xg(b,d,c[(c[h>>2]|0)+(a<<4)>>2]|0)|0;do{if((j|0)>0){n=c[(c[h>>2]|0)+(a<<4)+8>>2]|0}else{if((j|0)>=0){n=l;break}Hf(1);n=l}}while(0);j=a+1|0;if((j|0)<(c[f>>2]|0)){a=j;l=n}else{break}}if((n|0)==0){i=e;return}if((bKb(g+120|0,g+124|0,n)|0)>=0){i=e;return}KIb(0,8,2233088,(g=i,i=i+8|0,c[g>>2]=n,g)|0);i=g;Hf(1);i=e;return}function th(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=LGb(b,10230648,0,2)|0;if((f|0)==0){g=0;i=d;return g|0}else{h=f}do{f=h|0;j=c[f>>2]|0;k=_b(j|0,58)|0;if((k|0)==0){MGb(e,j,c[h+4>>2]|0,0)|0}else{a[k]=0;MGb(e,c[f>>2]|0,c[h+4>>2]|0,0)|0;a[k]=58}h=LGb(b,10230648,h,2)|0;}while((h|0)!=0);g=c[e>>2]|0;i=d;return g|0}function uh(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[1518658]|0;if((d|0)!=0&(c[1371154]|0)!=0){ub(2250888,41,1,c[q>>2]|0)|0;Hf(1);e=c[1518658]|0}else{e=d}if((e|0)!=0){i=b;return}e=WC(a)|0;if((e|0)==0){i=b;return}if((irc(e,2410048)|0)!=0){i=b;return}if((XC(a,0)|0)!=0){i=b;return}if((c[139256]|0)==0|(c[1371154]|0)!=0){KIb(0,8,2246896,(f=i,i=i+8|0,c[f>>2]=a,f)|0);i=f;Hf(1);i=b;return}e=c[q>>2]|0;Id(e|0,2249536,(f=i,i=i+8|0,c[f>>2]=a,f)|0)|0;i=f;qb(e|0)|0;Hh();Kb(2,0)|0;if((ug()|0)==0){KIb(0,8,2248240,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;Hf(1)}Ih();i=b;return}function vh(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a[b]|0;if(h<<24>>24==0){a[d]=103;i=g;return}a[d]=h;h=a[b]|0;if((h|0)==99|(h|0)==112){if((a[b+1|0]|0)!=58){i=g;return}c[e>>2]=rb(b+2|0,0,0)|0;i=g;return}else if((h|0)==115){e=b+1|0;d=a[e]|0;if((d<<24>>24|0)==0|(d<<24>>24|0)==58){j=d}else{KIb(0,8,2254544,(k=i,i=i+8|0,c[k>>2]=e,k)|0);i=k;Hf(1);j=a[e]|0}c[f>>2]=j<<24>>24==58?b+2|0:10230648;i=g;return}else if((h|0)==103){i=g;return}else{KIb(0,8,2254344,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;Hf(1);i=g;return}}function wh(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0.0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+1048|0;k=j|0;l=j+8|0;m=j+16|0;n=j+1016|0;o=j+1032|0;p=j+1040|0;q=ZX(e,0)|0;r=e+24|0;s=c[r>>2]|0;if((q|0)==0){KIb(0,8,2246264,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Hf(1);u=c[r>>2]|0}else{u=s}r=u-1|0;if(r>>>0<(c[b+216>>2]|0)>>>0){c[q+4>>2]=c[(c[b+212>>2]|0)+(r<<2)>>2]}c[1366870]=Ag(c[1366870]|0,4,5484624,(c[1371156]|0)+1|0)|0;r=pJb(376)|0;u=r;if((r|0)==0){Hf(1)}c[(c[1366870]|0)+((c[1371156]|0)-1<<2)>>2]=u;v=r;c[v>>2]=(c[1371158]|0)-1;w=r+4|0;c[w>>2]=s-1;s=r+12|0;c[s>>2]=q;x=q+8|0;c[(c[x>>2]|0)+8>>2]=f;y=b+24|0;do{if((c[y>>2]|0)>0){z=b+20|0;A=0;B=0;C=q;while(1){D=xg(e,C,c[(c[z>>2]|0)+(A<<4)>>2]|0)|0;do{if((D|0)>0){E=c[(c[z>>2]|0)+(A<<4)+8>>2]|0}else{if((D|0)>=0){E=B;break}Hf(1);E=B}}while(0);D=A+1|0;if((D|0)>=(c[y>>2]|0)){break}A=D;B=E;C=c[s>>2]|0}if((E|0)==0){F=c[(c[(c[s>>2]|0)+8>>2]|0)+8>>2]|0;G=17;break}if((irc(E,2235896)|0)==0){c[r+352>>2]=1;H=c[r+60>>2]|0;break}else{C=xh(E,c[(c[(c[s>>2]|0)+8>>2]|0)+8>>2]|0,1)|0;c[r+60>>2]=C;c[(c[(c[s>>2]|0)+8>>2]|0)+48>>2]=c[C+12>>2];H=C;break}}else{F=f;G=17}}while(0);if((G|0)==17){G=hH(c[e+8>>2]|0,0,e+32|0,0,F)|0;c[(c[(c[s>>2]|0)+8>>2]|0)+48>>2]=G;s=b5a(G)|0;c[r+60>>2]=s;H=s}s=r+60|0;do{if((H|0)==0){c[r+328>>2]=yg(c[(c[b>>2]|0)+16>>2]|0,0,e,q,0)|0}else{c[p>>2]=0;G=c[s>>2]|0;F=r+328|0;c[F>>2]=yg(c[(c[b>>2]|0)+16>>2]|0,c[G+12>>2]|0,e,q,G)|0;G=b+344|0;if((c[G>>2]|0)<=0){break}E=b+340|0;y=0;C=0;while(1){B=xg(e,q,c[(c[E>>2]|0)+(y<<4)>>2]|0)|0;do{if((B|0)>0){I=c[(c[E>>2]|0)+(y<<4)+8>>2]|0}else{if((B|0)>=0){I=C;break}Hf(1);I=C}}while(0);B=y+1|0;if((B|0)<(c[G>>2]|0)){y=B;C=I}else{break}}if((I|0)==0){break}C=c[c[s>>2]>>2]|0;y=m|0;G=id(2237880)|0;c[n>>2]=G;c[n+4>>2]=id(2237504)|0;c[n+8>>2]=2237208;a:do{if((C|0)==0){E=0;B=-1;A=G;while(1){if((A|0)==0){J=B}else{if((B|0)>=0){K=B;break a}Rb(y|0,1e3,2236168,(t=i,i=i+24|0,c[t>>2]=A,c[t+8>>2]=(E|0)!=1?10230648:2236512,c[t+16>>2]=I,t)|0)|0;i=t;J=VD(p,y,1,1070432,0)|0}z=E+1|0;if(!(z>>>0<3>>>0&(J|0)<0)){K=J;break a}E=z;B=J;A=c[n+(z<<2)>>2]|0}}else{A=0;B=-1;E=G;while(1){if((E|0)==0){L=B}else{z=(A|0)!=1?10230648:2236512;Rb(y|0,1e3,2236752,(t=i,i=i+32|0,c[t>>2]=E,c[t+8>>2]=z,c[t+16>>2]=C,c[t+24>>2]=I,t)|0)|0;i=t;D=VD(p,y,1,1070432,0)|0;if((D|0)>=0){K=D;break a}Rb(y|0,1e3,2236168,(t=i,i=i+24|0,c[t>>2]=E,c[t+8>>2]=z,c[t+16>>2]=I,t)|0)|0;i=t;L=VD(p,y,1,1070432,0)|0}z=A+1|0;if(!(z>>>0<3>>>0&(L|0)<0)){K=L;break a}A=z;B=L;E=c[n+(z<<2)>>2]|0}}}while(0);if((K|0)!=0){y=c[v>>2]|0;C=c[w>>2]|0;KIb(0,8,2244728,(t=i,i=i+24|0,c[t>>2]=I,c[t+8>>2]=y,c[t+16>>2]=C,t)|0);i=t;Hf(1);break}C=c[p>>2]|0;do{if((_D(k)|0)<0){KIb(0,8,2238408,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Hf(1)}while(1){y=(zD(C)|0)<<24>>24;M=c[k>>2]|0;if((y|0)==10|(y|0)==0){break}bD(M,y)}bD(M,0);aE(c[k>>2]|0,l)|0;y=c[l>>2]|0;G=a[y]|0;if((G<<24>>24|0)==0|(G<<24>>24|0)==35){kJb(y)}else{G=_b(y|0,61)|0;if((G|0)==0){KIb(0,8,2245416,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Hf(1)}a[G]=0;MGb(F,y,G+1|0,16)|0;kJb(y)}C=c[p>>2]|0;}while((c[C+52>>2]|0)==0);WD(C)|0}}while(0);lWa(c[x>>2]|0,c[s>>2]|0)|0;c[(c[x>>2]|0)+8>>2]=f;p=r+64|0;c[p>>2]=-1;c[p+4>>2]=2147483647;l=b+232|0;k=c[l>>2]|0;M=b+228|0;if((k|0)>0){I=0;while(1){w=xg(e,q,c[(c[M>>2]|0)+(I<<4)>>2]|0)|0;do{if((w|0)>0){v=(c[M>>2]|0)+(I<<4)+8|0;K=c[v+4>>2]|0;c[p>>2]=c[v>>2];c[p+4>>2]=K}else{if((w|0)>=0){break}Hf(1)}}while(0);w=I+1|0;C=c[l>>2]|0;if((w|0)<(C|0)){I=w}else{N=C;break}}}else{N=k}b:do{if((f|0)==0){k=0;while(1){if((k|0)>=(N|0)){break b}k=k+1|0}}else{k=0;while(1){if((k|0)>=(N|0)){break b}if((a[c[(c[M>>2]|0)+(k<<4)>>2]|0]|0)==0){break}else{k=k+1|0}}KIb(0,24,2243688,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}}while(0);M=r+364|0;c[M>>2]=-1;N=b+360|0;if((c[N>>2]|0)>0){f=b+356|0;k=0;do{I=xg(e,q,c[(c[f>>2]|0)+(k<<4)>>2]|0)|0;do{if((I|0)>0){c[M>>2]=c[(c[f>>2]|0)+(k<<4)+8>>2]}else{if((I|0)>=0){break}Hf(1)}}while(0);k=k+1|0;}while((k|0)<(c[N>>2]|0))}N=b+240|0;do{if((c[N>>2]|0)>0){k=b+236|0;f=0;M=0;while(1){I=xg(e,q,c[(c[k>>2]|0)+(f<<4)>>2]|0)|0;do{if((I|0)>0){O=c[(c[k>>2]|0)+(f<<4)+8>>2]|0}else{if((I|0)>=0){O=M;break}Hf(1);O=M}}while(0);I=f+1|0;if((I|0)<(c[N>>2]|0)){f=I;M=O}else{break}}if((O|0)==0){break}M=r+56|0;f=0;k=O;while(1){I=_b(k|0,44)|0;if((I|0)==0){P=0}else{a[I]=0;P=I+1|0}I=e3(k)|0;if((I|0)==0){KIb(0,8,2242528,(t=i,i=i+8|0,c[t>>2]=k,t)|0);i=t;Hf(1)}if((f|0)==0){c[M>>2]=I}else{c[f+12>>2]=I}if((P|0)==0){break}else{f=I;k=P}}c[o>>2]=0}}while(0);P=b+248|0;do{if((c[P>>2]|0)>0){t=b+244|0;O=0;N=0;while(1){k=xg(e,q,c[(c[t>>2]|0)+(O<<4)>>2]|0)|0;do{if((k|0)>0){Q=c[(c[t>>2]|0)+(O<<4)+8>>2]|0}else{if((k|0)>=0){Q=N;break}Hf(1);Q=N}}while(0);k=O+1|0;if((k|0)<(c[P>>2]|0)){O=k;N=Q}else{break}}if((Q|0)==0){break}N=rb(Q|0,o|0,0)|0;if((a[c[o>>2]|0]|0)==0){R=N}else{N=Q;R=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0}c[(c[x>>2]|0)+52>>2]=R}}while(0);R=b+264|0;do{if((c[R>>2]|0)>0){Q=b+260|0;S=-1.0;o=0;while(1){P=xg(e,q,c[(c[Q>>2]|0)+(o<<4)>>2]|0)|0;do{if((P|0)>0){T=+h[(c[Q>>2]|0)+(o<<4)+8>>3]}else{if((P|0)>=0){T=S;break}Hf(1);T=S}}while(0);P=o+1|0;if((P|0)<(c[R>>2]|0)){S=T;o=P}else{break}}if(T<0.0){break}o=c[x>>2]|0;Q=o+88|0;c[Q>>2]=c[Q>>2]|2;c[o+80>>2]=~~(T*118.0)}}while(0);if((c[(c[e+8>>2]|0)+28>>2]&64|0)!=0){e=(c[x>>2]|0)+88|0;c[e>>2]=c[e>>2]|4194304}e=b|0;OJb(c[(c[e>>2]|0)+28>>2]|0,2242040,0,r+320|0)|0;b=r+332|0;PGb(b,c[(c[e>>2]|0)+32>>2]|0,0);x=c[s>>2]|0;do{if((x|0)!=0){if((A5a(c[x+12>>2]|0)|0)!=24){break}MGb(b,2240480,2239144,0)|0}}while(0);PGb(r+336|0,c[(c[e>>2]|0)+24>>2]|0,0);c[r+8>>2]=g;if(!((g|0)>-1)){U=r+48|0;V=U;W=0;X=-2147483648;Y=V|0;c[Y>>2]=W;Z=V+4|0;c[Z>>2]=X;i=j;return u|0}e=(c[1475748]|0)+(g<<2)|0;c[r+24>>2]=c[e>>2];g=c[e>>2]|0;c[g+8>>2]=0;c[(c[g+4>>2]|0)+76>>2]=-16;U=r+48|0;V=U;W=0;X=-2147483648;Y=V|0;c[Y>>2]=W;Z=V+4|0;c[Z>>2]=X;i=j;return u|0}function xh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=(d|0)!=0;d=f?2234992:2234312;if(f){g=s5a(a)|0}else{g=t5a(a)|0}a:do{if((g|0)==0){h=w4(a)|0;do{if((h|0)!=0){j=c[h>>2]|0;if(f){k=b5a(j)|0}else{k=c5a(j)|0}if((k|0)==0){break}j=c[k>>2]|0;l=c[h+8>>2]|0;KIb(0,40,2234088,(m=i,i=i+24|0,c[m>>2]=d,c[m+8>>2]=j,c[m+16>>2]=l,m)|0);i=m;n=k;break a}}while(0);KIb(0,8,2233856,(m=i,i=i+16|0,c[m>>2]=d,c[m+8>>2]=a,m)|0);i=m;Hf(1);n=0}else{n=g}}while(0);if((c[n+8>>2]|0)==(b|0)){i=e;return n|0}KIb(0,8,2233592,(m=i,i=i+16|0,c[m>>2]=d,c[m+8>>2]=a,m)|0);i=m;Hf(1);i=e;return n|0}function yh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+12>>2]|0;e=a+312|0;f=c[e>>2]|0;g=a+308|0;do{if((f|0)!=0){if((c[g>>2]|0)==0){h=f}else{a=c[d>>2]|0;KIb(0,16,2230400,(j=i,i=i+16|0,c[j>>2]=c[1371158],c[j+8>>2]=a,j)|0);i=j;Hf(1);j=c[e>>2]|0;if((j|0)==0){break}else{h=j}}k=oh(h)|0;i=b;return k|0}}while(0);h=c[g>>2]|0;if((h|0)==0){k=rJb((c[(c[d+8>>2]|0)+8>>2]|0)==0?2261656:2261888)|0;i=b;return k|0}else{k=rJb(h)|0;i=b;return k|0}return 0}function zh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a+24|0;do{if((c[e>>2]|0)>0){f=a+20|0;g=0;h=0;while(1){i=xg(b,d,c[(c[f>>2]|0)+(g<<4)>>2]|0)|0;do{if((i|0)>0){j=c[(c[f>>2]|0)+(g<<4)+8>>2]|0}else{if((i|0)>=0){j=h;break}Hf(1);j=h}}while(0);i=g+1|0;if((i|0)<(c[e>>2]|0)){g=i;h=j}else{break}}h=d+8|0;g=c[h>>2]|0;if((j|0)==0){k=g;break}f=xh(j,c[g+8>>2]|0,0)|0;c[(c[h>>2]|0)+48>>2]=c[f+12>>2];l=f;return l|0}else{k=c[d+8>>2]|0}}while(0);l=c5a(c[k+48>>2]|0)|0;return l|0}function Ah(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+56|0;g=f|0;h=f+24|0;if((d|0)==0){j=e;i=f;return j|0}k=c[d+24>>2]|0;if((k|0)==0){j=e;i=f;return j|0}l=qKb(e)|0;if((l|0)==0){m=0}else{m=(a[l+4|0]&1^1)&255}l=c[b+8>>2]|0;do{if((c[l+680>>2]|0)<0){b=c[l+48>>2]|0;if((b|0)==8){n=g|0;c[n>>2]=12;c[g+4>>2]=13;c[g+8>>2]=0;c[g+12>>2]=4;c[g+16>>2]=-1;o=-1;p=n;break}else if((b|0)==10){b=h|0;c[b>>2]=12;c[h+4>>2]=13;c[h+8>>2]=14;c[h+12>>2]=0;c[h+16>>2]=4;c[h+20>>2]=5;c[h+24>>2]=30;c[h+28>>2]=-1;o=-1;p=b;break}else{o=-1;p=k;break}}else{o=-1;p=k}}while(0);while(1){k=c[p>>2]|0;if((k|0)==-1){break}q=xLa(o,k,e,m,0)|0;if((c[p>>2]|0)==(e|0)){r=12;break}o=q;p=p+4|0}if((r|0)==12){i=f;return((e|0)==-1?q:e)|0}if((e|0)==-1){j=o;i=f;return j|0}q=mKb(e)|0;e=c[d>>2]|0;d=mKb(o)|0;KIb(0,24,2297136,(r=i,i=i+24|0,c[r>>2]=q,c[r+8>>2]=e,c[r+16>>2]=d,r)|0);i=r;j=o;i=f;return j|0}function Bh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;if((b|0)==0){i=d;return}e=b+32|0;f=c[e>>2]|0;if((f|0)==0){i=d;return}g=a+8|0;a=f;while(1){f=c[a>>2]|0;if((f|0)==-1){break}if((f|0)==(c[(c[g>>2]|0)+420>>2]|0)){h=12;break}else{a=a+4|0}}if((h|0)==12){i=d;return}do{if((c[b+16>>2]|0)<0){h=LKb(c[(c[g>>2]|0)+420>>2]|0)|0;if(!(h>>>0>(LKb(c[c[e>>2]>>2]|0)|0)>>>0)){break}KIb(0,16,2548952,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}}while(0);if((LKb(c[(c[g>>2]|0)+420>>2]|0)|0)!=0){h=LKb(c[(c[g>>2]|0)+420>>2]|0)|0;a=c[b>>2]|0;b=LKb(c[c[e>>2]>>2]|0)|0;KIb(0,24,2419488,(j=i,i=i+24|0,c[j>>2]=h,c[j+8>>2]=a,c[j+16>>2]=b,j)|0);i=j}c[(c[g>>2]|0)+420>>2]=c[c[e>>2]>>2];i=d;return}function Ch(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=pJb(32)|0;e=d;if((d|0)==0){Hf(1)}c[d>>2]=c[1371168];f=d+24|0;g=d+28|0;c[f>>2]=Ag(c[f>>2]|0,4,g,(c[g>>2]|0)+1|0)|0;g=pJb(20)|0;c[c[f>>2]>>2]=g;if((g|0)==0){Hf(1)}c[(c[c[f>>2]>>2]|0)+4>>2]=b;c[(c[c[f>>2]>>2]|0)+8>>2]=e;c[b+300>>2]=c[c[f>>2]>>2];f=d+16|0;b=d+20|0;c[f>>2]=Ag(c[f>>2]|0,4,b,(c[b>>2]|0)+1|0)|0;b=pJb(16)|0;c[c[f>>2]>>2]=b;if((b|0)==0){Hf(1)}c[(c[c[f>>2]>>2]|0)+4>>2]=a;c[(c[c[f>>2]>>2]|0)+8>>2]=e;b=a+244|0;d=a+248|0;a=Ag(c[b>>2]|0,4,d,(c[d>>2]|0)+1|0)|0;c[b>>2]=a;c[a+((c[d>>2]|0)-1<<2)>>2]=c[c[f>>2]>>2];f=Ag(c[1510464]|0,4,5484672,(c[1371168]|0)+1|0)|0;c[1510464]=f;c[f+((c[1371168]|0)-1<<2)>>2]=e;return e|0}function Dh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;f=i;i=i+2312|0;g=f|0;h=f+8|0;j=f+16|0;k=f+32|0;l=f+40|0;m=f+48|0;n=f+64|0;o=f+72|0;p=f+80|0;q=f+88|0;r=f+96|0;s=f+104|0;t=f+112|0;u=f+120|0;v=f+1144|0;w=f+1152|0;x=f+1160|0;y=f+1416|0;z=f+1672|0;A=f+1680|0;B=f+1688|0;C=f+1696|0;D=f+1720|0;E=f+1752|0;F=f+1760|0;H=f+1768|0;I=f+1776|0;J=f+2288|0;K=f+2296|0;L=f+2304|0;M=d+12|0;mJb(M);N=e+4|0;O=c[N>>2]|0;P=c[O+28>>2]|0;Q=c[O+40>>2]|0;if((_D(L)|0)<0){Hf(1)}YD(c[L>>2]|0,2338920,(R=i,i=i+8|0,c[R>>2]=c[c[O+4>>2]>>2],R)|0)|0;i=R;if((Q|0)>1){Q=c[L>>2]|0;O=e+8|0;S=jj(P,c[O>>2]|0)|0;YD(Q,2280784,(R=i,i=i+8|0,c[R>>2]=S,R)|0)|0;i=R;T=O}else{T=e+8|0}bD(c[L>>2]|0,0);aE(c[L>>2]|0,M)|0;M=kj(c[(c[N>>2]|0)+28>>2]|0,c[T>>2]|0)|0;if((M|0)==0){L=c[N>>2]|0;e=c[T>>2]|0;O=E;S=I|0;Q=f+2032|0;P=c[d+4>>2]|0;U=P|0;V=c[U>>2]|0;W=c[(c[1366872]|0)+(V<<2)>>2]|0;X=P+12|0;Y=c[(c[X>>2]|0)+8>>2]|0;c[F>>2]=L;c[H>>2]=e;Z=P+4|0;_=c[Z>>2]|0;Rb(S|0,255,2237960,(R=i,i=i+16|0,c[R>>2]=V,c[R+8>>2]=_,R)|0)|0;i=R;_=d|0;V=_i(2180096)|0;$=b+8|0;aa=uj(_,V,S,0,0,c[$>>2]|0)|0;if((aa|0)<0){ba=aa;i=f;return ba|0}aa=c[Y+120>>2]|0;V=c[Y+124>>2]|0;do{if((V|aa|0)==0){ca=L;da=e}else{Y=c[P+320>>2]|0;Rb(Q|0,255,2178160,(R=i,i=i+24|0,c[R>>2]=aa,c[R+8>>2]=V,c[R+16>>2]=Y,R)|0)|0;i=R;Y=c[Z>>2]|0;Rb(S|0,255,2173200,(R=i,i=i+16|0,c[R>>2]=c[U>>2],c[R+8>>2]=Y,R)|0)|0;i=R;Y=_i(2165744)|0;ea=uj(J,Y,S,Q,0,c[$>>2]|0)|0;if((ea|0)<0){ba=ea;i=f;return ba|0}ea=Ri(L,e,c[J>>2]|0,0)|0;if((ea|0)<0){ba=ea;i=f;return ba|0}else{ea=c[J>>2]|0;c[F>>2]=ea;c[H>>2]=0;ca=ea;da=0;break}}}while(0);J=LGb(c[P+328>>2]|0,2153752,0,0)|0;if((J|0)!=0){EJb(c[(c[X>>2]|0)+8>>2]|0,2153752,c[J+4>>2]|0,0)|0}do{if((c[P+368>>2]|0)==0){J=c[X>>2]|0;e=c[(c[J+8>>2]|0)+140>>2]|0;L=P+60|0;Q=c[L>>2]|0;if(!((e|0)==-1)){fa=rJb(mKb(Ah(J,Q,e)|0)|0)|0;break}if((Q|0)==0){fa=0;break}if((c[Q+24>>2]|0)==0){fa=0;break}c[A>>2]=0;if((_D(A)|0)<0){Hf(1)}Q=c[(c[L>>2]|0)+24>>2]|0;L=c[(c[X>>2]|0)+8>>2]|0;do{if((c[L+680>>2]|0)<0){e=c[L+48>>2]|0;if((e|0)==8){J=C|0;c[J>>2]=12;c[C+4>>2]=13;c[C+8>>2]=0;c[C+12>>2]=4;c[C+16>>2]=-1;ga=J;break}else if((e|0)==10){e=D|0;c[e>>2]=12;c[D+4>>2]=13;c[D+8>>2]=14;c[D+12>>2]=0;c[D+16>>2]=4;c[D+20>>2]=5;c[D+24>>2]=30;c[D+28>>2]=-1;ga=e;break}else{ga=Q;break}}else{ga=Q}}while(0);Q=c[ga>>2]|0;if(!((Q|0)==-1)){L=ga;e=Q;do{Q=mKb(e)|0;YD(c[A>>2]|0,2184408,(R=i,i=i+8|0,c[R>>2]=Q,R)|0)|0;i=R;L=L+4|0;e=c[L>>2]|0;}while(!((e|0)==-1))}e=(aE(c[A>>2]|0,B)|0)-1|0;a[(c[B>>2]|0)+e|0]=0;fa=c[B>>2]|0}else{e=c[P+300>>2]|0;if((e|0)!=0){wj(c[(c[e+8>>2]|0)+8>>2]|0,-1)}e=c[(c[(c[X>>2]|0)+8>>2]|0)+140>>2]|0;if((e|0)==-1){fa=0;break}fa=rJb(mKb(e)|0)|0}}while(0);c[E>>2]=fa;do{if((fa|0)!=0){E=c[Z>>2]|0;Rb(S|0,255,2163312,(R=i,i=i+16|0,c[R>>2]=c[U>>2],c[R+8>>2]=E,R)|0)|0;i=R;E=_i(2161144)|0;X=uj(K,E,2161144,fa,0,c[$>>2]|0)|0;mJb(O);if((X|0)<0){ba=X;i=f;return ba|0}X=Ri(ca,da,c[K>>2]|0,0)|0;if((X|0)<0){ba=X;i=f;return ba|0}else{c[F>>2]=c[K>>2];c[H>>2]=0;break}}}while(0);K=c[Z>>2]|0;Rb(S|0,255,2186736,(R=i,i=i+16|0,c[R>>2]=c[U>>2],c[R+8>>2]=K,R)|0)|0;i=R;K=W+24|0;U=W+16|0;W=Gh(c[K>>2]|0,c[K+4>>2]|0,c[U>>2]|0,c[U+4>>2]|0,F,H,S)|0;if((W|0)<0){ba=W;i=f;return ba|0}W=Ri(c[F>>2]|0,c[H>>2]|0,c[_>>2]|0,0)|0;ba=(W|0)<0?W:0;i=f;return ba|0}else if((M|0)==1){M=c[N>>2]|0;N=c[T>>2]|0;T=r;W=s;_=t;H=I|0;I=x|0;x=y|0;y=c[d+4>>2]|0;F=y|0;S=c[F>>2]|0;U=c[(c[1366872]|0)+(S<<2)>>2]|0;K=y+12|0;Z=c[(c[K>>2]|0)+8>>2]|0;c[p>>2]=M;c[q>>2]=N;da=y+4|0;ca=c[da>>2]|0;Rb(H|0,255,2237960,(R=i,i=i+16|0,c[R>>2]=S,c[R+8>>2]=ca,R)|0)|0;i=R;ca=d|0;d=_i(2233920)|0;S=b+8|0;b=uj(ca,d,H,0,0,c[S>>2]|0)|0;if((b|0)<0){ba=b;i=f;return ba|0}b=IJb(c[ca>>2]|0,2230216,1,0,1)|0;if((b|0)<0){ba=b;i=f;return ba|0}b=y+288|0;do{if((c[b>>2]|0)==0){ha=M;ia=N}else{SFb(u,256,8192);d=tGb(c[b>>2]|0)|0;O=G;UFb(u,2226520,(R=i,i=i+16|0,c[R>>2]=d,c[R+8>>2]=O,R)|0);i=R;O=c[b>>2]|0;if((O|0)>0){d=0;$=O;while(1){O=c[y+160+(d<<2)>>2]|0;if((O|0)==-1){ja=$}else{UFb(u,2221640,(R=i,i=i+16|0,c[R>>2]=d,c[R+8>>2]=O,R)|0);i=R;ja=c[b>>2]|0}O=d+1|0;if((O|0)<(ja|0)){d=O;$=ja}else{break}}}$=u|0;KIb(0,32,2218088,(R=i,i=i+8|0,c[R>>2]=c[$>>2],R)|0);i=R;d=_i(2215288)|0;O=uj(v,d,2215288,c[$>>2]|0,0,c[S>>2]|0)|0;if((O|0)<0){ba=O;i=f;return ba|0}O=Ri(M,N,c[v>>2]|0,0)|0;if((O|0)<0){ba=O;i=f;return ba|0}else{O=c[v>>2]|0;c[p>>2]=O;c[q>>2]=0;_Fb(u,0)|0;ha=O;ia=0;break}}}while(0);u=c[Z+416>>2]|0;do{if((u|0)!=0){v=Z+448|0;if(!((c[v>>2]|0)==0&(c[v+4>>2]|0)==0)){break}N=tGb(u)|0;c[v>>2]=N;c[v+4>>2]=G}}while(0);u=c[(c[(c[K>>2]|0)+8>>2]|0)+420>>2]|0;do{if((u|0)==-1){Z=y+60|0;v=c[Z>>2]|0;if((v|0)==0){ka=0;break}if((c[v+32>>2]|0)==0){ka=0;break}c[n>>2]=0;if((_D(n)|0)<0){Hf(1)}v=c[(c[Z>>2]|0)+32>>2]|0;Z=c[v>>2]|0;if(!((Z|0)==-1)){N=v;v=Z;do{Z=LKb(v)|0;YD(c[n>>2]|0,2184408,(R=i,i=i+8|0,c[R>>2]=Z,R)|0)|0;i=R;N=N+4|0;v=c[N>>2]|0;}while(!((v|0)==-1))}v=(aE(c[n>>2]|0,o)|0)-1|0;a[(c[o>>2]|0)+v|0]=0;ka=c[o>>2]|0}else{ka=rJb(LKb(u)|0)|0}}while(0);c[r>>2]=ka;ka=j|0;j=m|0;m=c[(c[(c[K>>2]|0)+8>>2]|0)+412>>2]|0;do{if((m|0)==0){u=y+60|0;o=c[u>>2]|0;if((o|0)==0){la=0;break}if((c[o+28>>2]|0)==0){la=0;break}c[k>>2]=0;if((_D(k)|0)<0){Hf(1)}o=c[(c[u>>2]|0)+28>>2]|0;u=c[o>>2]|0;if((u|0)!=0){n=o;o=u;do{Rb(j|0,16,2182160,(R=i,i=i+8|0,c[R>>2]=o,R)|0)|0;i=R;YD(c[k>>2]|0,2184408,(R=i,i=i+8|0,c[R>>2]=j,R)|0)|0;i=R;n=n+4|0;o=c[n>>2]|0;}while((o|0)!=0)}o=(aE(c[k>>2]|0,l)|0)-1|0;a[(c[l>>2]|0)+o|0]=0;la=c[l>>2]|0}else{Rb(ka|0,16,2182160,(R=i,i=i+8|0,c[R>>2]=m,R)|0)|0;i=R;la=rJb(ka)|0}}while(0);c[s>>2]=la;la=(c[(c[K>>2]|0)+8>>2]|0)+448|0;K=c[la>>2]|0;m=c[la+4>>2]|0;do{if((K|0)==0&(m|0)==0){la=y+60|0;l=c[la>>2]|0;if((l|0)==0){ma=0;break}if((c[l+36>>2]|0)==0){ma=0;break}c[g>>2]=0;if((_D(g)|0)<0){Hf(1)}l=c[(c[la>>2]|0)+36>>2]|0;la=c[l>>2]|0;k=c[l+4>>2]|0;if(!((la|0)==0&(k|0)==0)){o=l;l=k;k=la;do{Rb(j|0,16,2226520,(R=i,i=i+16|0,c[R>>2]=k,c[R+8>>2]=l,R)|0)|0;i=R;YD(c[g>>2]|0,2184408,(R=i,i=i+8|0,c[R>>2]=j,R)|0)|0;i=R;o=o+8|0;k=c[o>>2]|0;l=c[o+4>>2]|0;}while(!((k|0)==0&(l|0)==0))}l=(aE(c[g>>2]|0,h)|0)-1|0;a[(c[h>>2]|0)+l|0]=0;ma=c[h>>2]|0}else{Rb(ka|0,16,2226520,(R=i,i=i+16|0,c[R>>2]=K,c[R+8>>2]=m,R)|0)|0;i=R;ma=rJb(ka)|0}}while(0);c[t>>2]=ma;ka=c[r>>2]|0;do{if((ka|0)==0){r=c[s>>2]|0;if((r|0)==0&(ma|0)==0){na=ha;oa=ia;break}a[I]=0;pa=r;qa=82}else{a[I]=0;EFb(I,256,2212824,(R=i,i=i+8|0,c[R>>2]=ka,R)|0)|0;i=R;pa=c[s>>2]|0;qa=82}}while(0);do{if((qa|0)==82){if((pa|0)!=0){EFb(I,256,2210800,(R=i,i=i+8|0,c[R>>2]=pa,R)|0)|0;i=R}s=c[t>>2]|0;if((s|0)!=0){EFb(I,256,2205448,(R=i,i=i+8|0,c[R>>2]=s,R)|0)|0;i=R}mJb(T);mJb(W);mJb(_);s=c[da>>2]|0;Rb(H|0,255,2197344,(R=i,i=i+16|0,c[R>>2]=c[F>>2],c[R+8>>2]=s,R)|0)|0;i=R;s=_i(2194360)|0;ka=uj(w,s,H,I,0,c[S>>2]|0)|0;if((ka|0)<0){ba=ka;i=f;return ba|0}ka=Ri(ha,ia,c[w>>2]|0,0)|0;if((ka|0)<0){ba=ka;i=f;return ba|0}else{ka=c[w>>2]|0;c[p>>2]=ka;c[q>>2]=0;na=ka;oa=0;break}}}while(0);w=c[y+340>>2]|0;a:do{if((w|0)!=0){if((c[U+40>>2]|0)==0){break}y=c[U>>2]|0;ia=c[y+24>>2]|0;ha=y+28|0;y=0;while(1){if(!(y>>>0<ia>>>0)){break a}if((c[(c[(c[(c[ha>>2]|0)+(y<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==0){break}else{y=y+1|0}}Rb(x|0,256,2338920,(R=i,i=i+8|0,c[R>>2]=w,R)|0)|0;i=R;KIb(0,32,2191968,(R=i,i=i+8|0,c[R>>2]=x,R)|0);i=R;y=_i(2189384)|0;ha=uj(z,y,2189384,x,0,c[S>>2]|0)|0;if((ha|0)<0){ba=ha;i=f;return ba|0}ha=Ri(na,oa,c[z>>2]|0,0)|0;if((ha|0)<0){ba=ha;i=f;return ba|0}else{c[p>>2]=c[z>>2];c[q>>2]=0;break}}}while(0);z=c[da>>2]|0;Rb(H|0,255,2186736,(R=i,i=i+16|0,c[R>>2]=c[F>>2],c[R+8>>2]=z,R)|0)|0;i=R;z=U+24|0;F=U+16|0;U=Gh(c[z>>2]|0,c[z+4>>2]|0,c[F>>2]|0,c[F+4>>2]|0,p,q,H)|0;if((U|0)<0){ba=U;i=f;return ba|0}U=Ri(c[p>>2]|0,c[q>>2]|0,c[ca>>2]|0,0)|0;ba=(U|0)<0?U:0;i=f;return ba|0}else{KIb(0,0,2231368,(R=i,i=i+24|0,c[R>>2]=2192664,c[R+8>>2]=2161664,c[R+16>>2]=581,R)|0);i=R;Hd();return 0}return 0}function Eh(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0.0,Na=0,Oa=0,Pa=0,Qa=0;d=i;i=i+3432|0;e=d|0;f=d+8|0;j=d+1032|0;k=d+1040|0;l=d+1296|0;m=d+1304|0;n=d+1560|0;o=d+1568|0;p=d+1576|0;q=d+2600|0;r=d+2856|0;s=d+2864|0;t=d+2872|0;u=d+2880|0;v=d+2888|0;w=d+2896|0;x=d+2904|0;y=d+2912|0;z=d+2920|0;A=b+8|0;B=c[A>>2]|0;C=b+4|0;D=c[C>>2]|0;E=(D|0)==0;if(E){F=c[(c[(c[c[b+24>>2]>>2]|0)+4>>2]|0)+304>>2]|0}else{F=D}tj(A);D=rj()|0;c[A>>2]=D;if((D|0)==0){G=-12;i=d;return G|0}do{if(E){D=b+24|0;H=c[(c[c[D>>2]>>2]|0)+4>>2]|0;I=z|0;Rb(I|0,512,2136080,(J=i,i=i+8|0,c[J>>2]=c[H+320>>2],J)|0)|0;i=J;K=rJb(I)|0;c[(c[A>>2]|0)+12>>2]=K;a[I]=0;K=H+332|0;L=LGb(c[K>>2]|0,10229984,0,2)|0;if((L|0)!=0){M=L;do{L=c[M+4>>2]|0;EFb(I,512,2630360,(J=i,i=i+16|0,c[J>>2]=c[M>>2],c[J+8>>2]=L,J)|0)|0;i=J;M=LGb(c[K>>2]|0,10229984,M,2)|0;}while((M|0)!=0)}if((a[I]|0)!=0){a[z+((lrc(I|0)|0)-1)|0]=0}EJb(c[A>>2]|0,2605768,I,0)|0;a[I]=0;M=LGb(c[(c[(c[c[D>>2]>>2]|0)+4>>2]|0)+336>>2]|0,10229984,0,2)|0;if((M|0)!=0){K=M;do{M=c[K+4>>2]|0;EFb(I,512,2630360,(J=i,i=i+16|0,c[J>>2]=c[K>>2],c[J+8>>2]=M,J)|0)|0;i=J;K=LGb(c[(c[(c[c[D>>2]>>2]|0)+4>>2]|0)+336>>2]|0,10229984,K,2)|0;}while((K|0)!=0)}if((a[I]|0)!=0){a[z+((lrc(I|0)|0)-1)|0]=0}K=rJb(I)|0;c[(c[A>>2]|0)+16>>2]=K;K=LGb(c[H+328>>2]|0,2580064,0,0)|0;if((K|0)==0){break}EJb(c[A>>2]|0,2580064,c[K+4>>2]|0,0)|0}}while(0);z=ll(c[A>>2]|0,F,x,y)|0;if((z|0)<0){G=z;i=d;return G|0}z=c[x>>2]|0;a:do{if(E){do{if((z|0)!=0){if((c[z+12>>2]|0)!=0){break}K=c[y>>2]|0;if((K|0)==0){break}if((c[K+12>>2]|0)==0){break a}}}while(0);KIb(0,16,2560104,(J=i,i=i+8|0,c[J>>2]=F,J)|0);i=J;G=-22;i=d;return G|0}}while(0);F=E|(B|0)!=0;do{if(F|(z|0)==0){N=z}else{B=b+16|0;E=b+20|0;H=z;b:while(1){I=H+4|0;K=H+8|0;D=kj(c[(c[I>>2]|0)+12>>2]|0,c[K>>2]|0)|0;if(D>>>0>1>>>0){KIb(0,8,2265944,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Hf(1)}M=c[H>>2]|0;do{if((M|0)==0){L=c[1371160]|0;c:do{if((L|0)>0){O=c[1475748]|0;P=0;while(1){Q=c[O+(P<<2)>>2]|0;if((c[(c[(c[Q+4>>2]|0)+8>>2]|0)+8>>2]|0)==(D|0)){if((c[Q+8>>2]|0)!=0){R=Q;S=P;break c}}T=P+1|0;if((T|0)<(L|0)){P=T}else{R=Q;S=T;break}}}else{R=0;S=0}}while(0);if((S|0)!=(L|0)){U=R;break}P=c[(c[I>>2]|0)+8>>2]|0;KIb(0,8,2254376,(J=i,i=i+16|0,c[J>>2]=c[K>>2],c[J+8>>2]=P,J)|0);i=J;Hf(1);U=R}else{P=rb(M|0,w|0,0)|0;if(!((P|0)>-1&(P|0)<(c[1371162]|0))){O=c[C>>2]|0;KIb(0,8,2262440,(J=i,i=i+16|0,c[J>>2]=P,c[J+8>>2]=O,J)|0);i=J;Hf(1)}O=c[c[(c[1475750]|0)+(P<<2)>>2]>>2]|0;T=O+24|0;Q=c[T>>2]|0;if((Q|0)==0){V=35;break b}W=O+28|0;X=c[w>>2]|0;Y=X+1|0;d:do{if((D|0)==0){Z=0;_=Q;while(1){$=c[(c[W>>2]|0)+(Z<<2)>>2]|0;aa=c[(c[$+8>>2]|0)+8>>2]|0;if((aa|0)==0|(aa|0)==3){if((xg(O,$,(a[X]|0)==58?Y:X)|0)==1){ba=Z;break d}ca=c[T>>2]|0}else{ca=_}$=Z+1|0;if($>>>0<ca>>>0){Z=$;_=ca}else{da=X;V=46;break b}}}else{_=0;Z=Q;while(1){$=c[(c[W>>2]|0)+(_<<2)>>2]|0;if((c[(c[$+8>>2]|0)+8>>2]|0)==(D|0)){if((xg(O,$,(a[X]|0)==58?Y:X)|0)==1){ba=_;break d}ea=c[T>>2]|0}else{ea=Z}$=_+1|0;if($>>>0<ea>>>0){_=$;Z=ea}else{da=X;V=46;break b}}}}while(0);T=c[(c[W>>2]|0)+(ba<<2)>>2]|0;if((T|0)==0){da=X;V=46;break b}U=c[(c[1475748]|0)+((c[T>>2]|0)+(c[(c[(c[1475750]|0)+(P<<2)>>2]|0)+12>>2]|0)<<2)>>2]|0}}while(0);if((U|0)==0){V=54;break}c[U+8>>2]=0;D=U+12|0;c[D>>2]=(c[D>>2]|0)+1;c[(c[U+4>>2]|0)+76>>2]=-16;c[B>>2]=Ag(c[B>>2]|0,4,E,(c[E>>2]|0)+1|0)|0;D=pJb(16)|0;M=c[E>>2]|0;c[(c[B>>2]|0)+(M-1<<2)>>2]=D;if((D|0)==0){Hf(1);fa=c[E>>2]|0}else{fa=M}M=fa-1|0;c[(c[(c[B>>2]|0)+(M<<2)>>2]|0)+4>>2]=U;c[(c[(c[B>>2]|0)+(M<<2)>>2]|0)+8>>2]=b;M=U+244|0;D=U+248|0;K=Ag(c[M>>2]|0,4,D,(c[D>>2]|0)+1|0)|0;c[M>>2]=K;c[K+((c[D>>2]|0)-1<<2)>>2]=c[(c[B>>2]|0)+((c[E>>2]|0)-1<<2)>>2];D=c[H+12>>2]|0;if((D|0)==0){V=24;break}else{H=D}}if((V|0)==24){N=c[x>>2]|0;break}else if((V|0)==35){da=c[w>>2]|0;ga=c[C>>2]|0;KIb(0,8,2258512,(J=i,i=i+16|0,c[J>>2]=da,c[J+8>>2]=ga,J)|0);i=J;Hf(1);return 0}else if((V|0)==46){ga=c[C>>2]|0;KIb(0,8,2258512,(J=i,i=i+16|0,c[J>>2]=da,c[J+8>>2]=ga,J)|0);i=J;Hf(1);return 0}else if((V|0)==54){KIb(0,0,2231368,(J=i,i=i+24|0,c[J>>2]=2247472,c[J+8>>2]=2161664,c[J+16>>2]=270,J)|0);i=J;Hd();return 0}}}while(0);e:do{if((N|0)!=0){ga=b+16|0;da=q|0;C=s|0;w=s+4|0;U=b|0;fa=p|0;ba=k|0;ea=m|0;ca=f|0;R=b+12|0;S=0;z=N;f:while(1){H=c[(c[ga>>2]|0)+(S<<2)>>2]|0;E=H+12|0;mJb(E);B=z+4|0;D=c[B>>2]|0;K=c[D+12>>2]|0;M=c[D+24>>2]|0;if((_D(v)|0)<0){Hf(1)}YD(c[v>>2]|0,2338920,(J=i,i=i+8|0,c[J>>2]=c[c[D+4>>2]>>2],J)|0)|0;i=J;if((M|0)>1){M=c[v>>2]|0;D=z+8|0;I=jj(K,c[D>>2]|0)|0;YD(M,2280784,(J=i,i=i+8|0,c[J>>2]=I,J)|0)|0;i=J;ha=D}else{ha=z+8|0}bD(c[v>>2]|0,0);aE(c[v>>2]|0,E)|0;E=kj(c[(c[B>>2]|0)+12>>2]|0,c[ha>>2]|0)|0;do{if((E|0)==0){D=_i(2319984)|0;I=c[H+4>>2]|0;M=I|0;K=c[(c[1475750]|0)+(c[M>>2]<<2)>>2]|0;T=I+108|0;Y=c[T>>2]|0;if((Y|0)==0){O=c[I+4>>2]|0;Q=O+40|0;ia=c[Q>>2]|0;ja=c[Q+4>>2]|0;ka=0;la=c[I+112>>2]|0;ma=O}else{O=c[I+112>>2]|0;ia=O;ja=Y;ka=Y;la=O;ma=c[I+4>>2]|0}c[r>>2]=0;O=I+4|0;Y=c[ma+8>>2]|0;Q=c[Y+8>>2]|0;if((Q|0)==1){V=68;break f}if((ka|0)==0){uY(s,c[K>>2]|0,ma,0);L=c[O>>2]|0;Z=c[L+8>>2]|0;na=c[w>>2]|0;oa=c[C>>2]|0;pa=L;qa=Z;ra=c[Z+8>>2]|0}else{na=la;oa=ka;pa=ma;qa=Y;ra=Q}if((ra|0)==3){Q=c[c[(c[1475750]|0)+(c[M>>2]<<2)>>2]>>2]|0;Y=c[qa+120>>2]|0;Z=c[qa+124>>2]|0;if((Y|0)==0|(Z|0)==0){L=c[Q+24>>2]|0;if((L|0)==0){sa=Y;ta=Z}else{_=c[Q+28>>2]|0;$=0;aa=Y;ua=Z;while(1){va=c[(c[_+($<<2)>>2]|0)+8>>2]|0;if((c[va+8>>2]|0)==0){wa=c[va+120>>2]|0;xa=c[va+124>>2]|0;ya=(ua|0)>(xa|0)?ua:xa;za=(aa|0)>(wa|0)?aa:wa}else{ya=ua;za=aa}wa=$+1|0;if(wa>>>0<L>>>0){$=wa;aa=za;ua=ya}else{sa=za;ta=ya;break}}}if((sa|0)==0|(ta|0)==0){Aa=(ta|0)>576?ta:576;Ba=(sa|0)>720?sa:720}else{Aa=ta;Ba=sa}KIb(Q,32,2270472,(J=i,i=i+16|0,c[J>>2]=Ba,c[J+8>>2]=Aa,J)|0);i=J;Ca=Aa;Da=Ba;Ea=c[(c[O>>2]|0)+8>>2]|0}else{Ca=Z;Da=Y;Ea=qa}c[I+128>>2]=Da;c[Ea+120>>2]=Da;c[I+228>>2]=Da;c[I+124>>2]=Ca;c[Ea+124>>2]=Ca;c[I+232>>2]=Ca;c[Ea+140>>2]=30;c[I+132>>2]=30;ua=UHb()|0;c[I+224>>2]=ua;aa=(ua|0)==0;if(aa){Fa=aa?-12:0;break}Ga=c[O>>2]|0}else{Ga=pa}aa=Ga+80|0;if((c[aa>>2]|0)==0){ua=c[Ga+8>>2]|0;Ha=ua+224|0;Ia=ua+228|0}else{Ha=aa;Ia=Ga+84|0}aa=c[Ia>>2]|0;ua=(aa|0)==0;$=ua?0:c[Ha>>2]|0;SFb(p,0,1);L=c[I+124>>2]|0;_=c[((c[I+280>>2]|0)==0?I+132|0:I+288|0)>>2]|0;P=(c[(c[(c[O>>2]|0)+8>>2]|0)+88>>2]|0)>>>4&524288|2;UFb(p,2310872,(J=i,i=i+64|0,c[J>>2]=c[I+128>>2],c[J+8>>2]=L,c[J+16>>2]=_,c[J+24>>2]=ia,c[J+32>>2]=ja,c[J+40>>2]=$,c[J+48>>2]=ua?1:aa,c[J+56>>2]=P,J)|0);i=J;if(!((oa|0)==0|(na|0)==0)){UFb(p,2306416,(J=i,i=i+16|0,c[J>>2]=oa,c[J+8>>2]=na,J)|0);i=J}P=c[M>>2]|0;aa=c[c[O>>2]>>2]|0;Rb(da|0,255,2473728,(J=i,i=i+24|0,c[J>>2]=c[U>>2],c[J+8>>2]=P,c[J+16>>2]=aa,J)|0)|0;i=J;aa=H|0;P=uj(aa,D,da,c[fa>>2]|0,0,c[A>>2]|0)|0;if((P|0)<0){G=P;V=137;break f}P=c[aa>>2]|0;c[o>>2]=P;if((c[T>>2]|0)==0){Ja=P}else{aa=c[c[O>>2]>>2]|0;Rb(da|0,255,2298136,(J=i,i=i+16|0,c[J>>2]=c[M>>2],c[J+8>>2]=aa,J)|0)|0;i=J;aa=_i(2287840)|0;ua=uj(t,aa,da,2283280,0,c[A>>2]|0)|0;if((ua|0)<0){G=ua;V=137;break f}ua=Ri(P,0,c[t>>2]|0,0)|0;if((ua|0)<0){G=ua;V=137;break f}ua=c[t>>2]|0;c[o>>2]=ua;Ja=ua}if((c[2333752]|0)!=0){ua=c[c[O>>2]>>2]|0;Rb(da|0,255,2279464,(J=i,i=i+16|0,c[J>>2]=c[M>>2],c[J+8>>2]=ua,J)|0)|0;i=J;ua=_i(2275288)|0;P=uj(u,ua,da,10229984,0,c[A>>2]|0)|0;if((P|0)<0){G=P;V=137;break f}P=Ri(Ja,0,c[u>>2]|0,0)|0;if((P|0)<0){G=P;V=137;break f}c[o>>2]=c[u>>2]}P=c[c[O>>2]>>2]|0;Rb(da|0,255,2373184,(J=i,i=i+16|0,c[J>>2]=c[M>>2],c[J+8>>2]=P,J)|0)|0;i=J;P=K+40|0;if((c[P>>2]|0)==0&(c[P+4>>2]|0)==(-2147483648|0)){Ka=-2147483648;La=0}else{P=(c[K+68>>2]|0)==0;Ka=P?-2147483648:0;La=P?0:0}P=K+48|0;ua=Gh(La,Ka,c[P>>2]|0,c[P+4>>2]|0,o,r,da)|0;if((ua|0)<0){G=ua;V=137;break f}ua=Ri(c[o>>2]|0,0,c[B>>2]|0,c[ha>>2]|0)|0;Fa=(ua|0)<0?ua:0}else if((E|0)==1){ua=_i(2542888)|0;P=c[H+4>>2]|0;aa=P|0;$=c[(c[1475750]|0)+(c[aa>>2]<<2)>>2]|0;c[j>>2]=0;_=P+4|0;if((c[(c[(c[_>>2]|0)+8>>2]|0)+8>>2]|0)!=1){V=102;break f}SFb(f,0,1);P=c[(c[_>>2]|0)+8>>2]|0;L=c[P+412>>2]|0;X=LKb(c[P+420>>2]|0)|0;UFb(f,2510264,(J=i,i=i+32|0,c[J>>2]=1,c[J+8>>2]=L,c[J+16>>2]=L,c[J+24>>2]=X,J)|0);i=J;X=c[(c[_>>2]|0)+8>>2]|0;L=X+448|0;P=c[L>>2]|0;W=c[L+4>>2]|0;if((P|0)==0&(W|0)==0){UFb(f,2485288,(J=i,i=i+8|0,c[J>>2]=c[X+416>>2],J)|0);i=J}else{UFb(f,2496184,(J=i,i=i+16|0,c[J>>2]=P,c[J+8>>2]=W,J)|0);i=J}W=c[aa>>2]|0;P=c[c[_>>2]>>2]|0;Rb(da|0,255,2473728,(J=i,i=i+24|0,c[J>>2]=c[U>>2],c[J+8>>2]=W,c[J+16>>2]=P,J)|0)|0;i=J;P=H|0;W=uj(P,ua,da,c[ca>>2]|0,0,c[A>>2]|0)|0;if((W|0)<0){G=W;V=137;break f}W=c[P>>2]|0;c[e>>2]=W;P=c[2547942]|0;if((P|0)>0){mrc(ba|0,0,256)|0;EFb(ba,256,2465224,(J=i,i=i+8|0,c[J>>2]=P,J)|0)|0;i=J;Ma=+g[501186];if(Ma!=.1){EFb(ba,256,2452896,(J=i,i=i+8|0,h[J>>3]=Ma,J)|0)|0;i=J}if((c[R>>2]|0)==0){EFb(ba,256,2436480,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0)|0;i=J}KIb(0,32,2426464,(J=i,i=i+8|0,c[J>>2]=ba,J)|0);i=J;P=c[aa>>2]|0;ua=c[c[_>>2]>>2]|0;Rb(da|0,255,2416336,(J=i,i=i+32|0,c[J>>2]=c[U>>2],c[J+8>>2]=2407584,c[J+16>>2]=P,c[J+24>>2]=ua,J)|0)|0;i=J;ua=_i(2407584)|0;P=uj(l,ua,da,ba,0,c[A>>2]|0)|0;if((P|0)<0){G=P;V=137;break f}P=Ri(W,0,c[l>>2]|0,0)|0;if((P|0)<0){G=P;V=137;break f}P=c[l>>2]|0;c[e>>2]=P;Na=P}else{Na=W}if((c[501184]|0)!=256){KIb(0,24,2400088,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Rb(ea|0,256,2393056,(J=i,i=i+8|0,h[J>>3]=+(c[501184]|0)*.00390625,J)|0)|0;i=J;KIb(0,32,2386432,(J=i,i=i+8|0,c[J>>2]=ea,J)|0);i=J;W=c[aa>>2]|0;P=c[c[_>>2]>>2]|0;Rb(da|0,255,2416336,(J=i,i=i+32|0,c[J>>2]=c[U>>2],c[J+8>>2]=2379224,c[J+16>>2]=W,c[J+24>>2]=P,J)|0)|0;i=J;P=_i(2379224)|0;W=uj(n,P,da,ea,0,c[A>>2]|0)|0;if((W|0)<0){G=W;V=137;break f}W=Ri(Na,0,c[n>>2]|0,0)|0;if((W|0)<0){G=W;V=137;break f}c[e>>2]=c[n>>2]}W=c[c[_>>2]>>2]|0;Rb(da|0,255,2373184,(J=i,i=i+16|0,c[J>>2]=c[aa>>2],c[J+8>>2]=W,J)|0)|0;i=J;W=$+40|0;if((c[W>>2]|0)==0&(c[W+4>>2]|0)==(-2147483648|0)){Oa=-2147483648;Pa=0}else{W=(c[$+68>>2]|0)==0;Oa=W?-2147483648:0;Pa=W?0:0}W=$+48|0;$=Gh(Pa,Oa,c[W>>2]|0,c[W+4>>2]|0,e,j,da)|0;if(($|0)<0){G=$;V=137;break f}$=Ri(c[e>>2]|0,0,c[B>>2]|0,c[ha>>2]|0)|0;Fa=($|0)<0?$:0}else{V=123;break f}}while(0);if((Fa|0)<0){G=Fa;V=137;break}B=c[z+12>>2]|0;if((B|0)==0){break e}else{S=S+1|0;z=B}}if((V|0)==68){KIb(0,16,2315344,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;G=-22;i=d;return G|0}else if((V|0)==102){KIb(0,16,2525456,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;G=-22;i=d;return G|0}else if((V|0)==123){KIb(0,0,2231368,(J=i,i=i+24|0,c[J>>2]=2192664,c[J+8>>2]=2161664,c[J+16>>2]=831,J)|0);i=J;Hd();return 0}else if((V|0)==137){i=d;return G|0}}}while(0);kl(x);x=c[y>>2]|0;V=(x|0)==0;do{if(F){if(!V){J=b+24|0;Fa=0;ha=x;while(1){Dh(b,c[(c[J>>2]|0)+(Fa<<2)>>2]|0,ha)|0;e=c[ha+12>>2]|0;if((e|0)==0){break}else{Fa=Fa+1|0;ha=e}}}kl(y);ha=xj(c[A>>2]|0,0)|0;if((ha|0)<0){G=ha}else{break}i=d;return G|0}else{if(V){break}ha=b+24|0;Fa=b+28|0;J=x;e=c[Fa>>2]|0;while(1){c[ha>>2]=Ag(c[ha>>2]|0,4,Fa,e+1|0)|0;j=pJb(20)|0;Oa=c[Fa>>2]|0;c[(c[ha>>2]|0)+(Oa-1<<2)>>2]=j;if((j|0)==0){Hf(1);Qa=c[Fa>>2]|0}else{Qa=Oa}Oa=Qa-1|0;c[(c[(c[ha>>2]|0)+(Oa<<2)>>2]|0)+8>>2]=b;c[(c[(c[ha>>2]|0)+(Oa<<2)>>2]|0)+16>>2]=J;j=c[J+12>>2]|0;c[(c[(c[(c[ha>>2]|0)+(Oa<<2)>>2]|0)+16>>2]|0)+12>>2]=0;if((j|0)==0){break}else{J=j;e=Qa}}}}while(0);c[b+12>>2]=1;G=0;i=d;return G|0}function Fh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+16|0;e=c[a+20>>2]|0;a=0;while(1){if((a|0)>=(e|0)){f=0;g=4;break}if((c[(c[(c[d>>2]|0)+(a<<2)>>2]|0)+4>>2]|0)==(b|0)){f=1;g=4;break}else{a=a+1|0}}if((g|0)==4){return f|0}return 0}function Gh(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;k=c[f>>2]|0;l=c[k+48>>2]|0;m=(kj(c[k+28>>2]|0,c[g>>2]|0)|0)==0;k=m?2363424:2349680;m=(d|0)==(-1|0)&(e|0)==2147483647;n=(a|0)==0&(b|0)==(-2147483648|0);if(m&n){o=0;i=j;return o|0}p=_i(k)|0;if((p|0)==0){KIb(0,16,2343e3,(q=i,i=i+8|0,c[q>>2]=k,q)|0);i=q;o=-1279870712;i=j;return o|0}r=vj(l,p,h)|0;if((r|0)==0){o=-12;i=j;return o|0}if(m){s=0}else{s=IJb(r,2337112,d,e,1)|0}if((s|0)<0|n){t=s}else{t=IJb(r,2331456,a,b,1)|0}if((t|0)<0){KIb(r,16,2325832,(q=i,i=i+8|0,c[q>>2]=k,q)|0);i=q;o=t;i=j;return o|0}t=gj(r,0)|0;if((t|0)<0){o=t;i=j;return o|0}t=Ri(c[f>>2]|0,c[g>>2]|0,r,0)|0;if((t|0)<0){o=t;i=j;return o|0}c[f>>2]=r;c[g>>2]=0;o=0;i=j;return o|0}function Hh(){var b=0,d=0;b=i;KIb(0,-8,2223800,(d=i,i=i+8|0,c[d>>2]=10230128,d)|0);i=d;if(!(a[679920]|0)){i=b;return}Yd(0,0,5467576)|0;i=b;return}function Ih(){var b=0,d=0,e=0;b=i;i=i+64|0;d=b|0;if(!(a[676880]|0)){do{if((gd(0)|0)!=0){if((gd(2)|0)==0){break}if(($b(0,d|0)|0)!=0){break}nrc(5467576,d|0,60)|0;a[679920]=1;e=d|0;c[e>>2]=c[e>>2]&-1516;e=d+4|0;c[e>>2]=c[e>>2]|1;e=d+12|0;c[e>>2]=c[e>>2]&-32843;e=d+8|0;c[e>>2]=c[e>>2]&-305|48;a[d+23|0]=1;a[d+22|0]=0;Yd(0,0,d|0)|0}}while(0);Kb(3,328)|0}sY()|0;Kb(2,328)|0;Kb(15,328)|0;Kb(24,328)|0;i=b;return}function Jh(b){b=b|0;var d=0;d=i;c[1352984]=b;c[1352986]=(c[1352986]|0)+1;KIb(0,-8,2223800,(b=i,i=i+8|0,c[b>>2]=10230128,b)|0);i=b;if(a[679920]|0){Yd(0,0,5467576)|0}if((c[1352986]|0)>3){fc(123)}else{i=d;return}}function Kh(a){a=a|0;return(c[1352986]|0)>1|0}function Lh(a){a=a|0;var b=0,d=0;b=i;d=LGb(a,10230128,0,2)|0;if((d|0)==0){i=b;return}KIb(0,8,2158376,(a=i,i=i+8|0,c[a>>2]=c[d>>2],a)|0);i=a;Hf(1);i=b;return}function Mh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+256|0;d=a+4|0;e=c[(c[d>>2]|0)+8>>2]|0;f=e+448|0;if(!((c[f>>2]|0)==0&(c[f+4>>2]|0)==0)){g=1;i=b;return g|0}h=e+416|0;e=c[h>>2]|0;if((e|0)>(c[a+120>>2]|0)){g=0;i=b;return g|0}j=tGb(e)|0;e=G;c[f>>2]=j;c[f+4>>2]=e;if((j|0)==0&(e|0)==0){g=0;i=b;return g|0}f=b|0;sGb(f,256,c[h>>2]|0,j,e);e=c[c[d>>2]>>2]|0;KIb(0,24,2133160,(d=i,i=i+24|0,c[d>>2]=c[a>>2],c[d+8>>2]=e,c[d+16>>2]=f,d)|0);i=d;g=1;i=b;return g|0}function Nh(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+272|0;f=e|0;j=e+136|0;Gf(490);ke(c[q>>2]|0,0,2,0)|0;OIb(1);Qf(b,d,771552);do{if((b|0)>1){k=d+4|0;if((irc(c[k>>2]|0,2109704)|0)!=0){l=b;m=d;break}a[676880]=1;PIb(384);l=b-1|0;m=k}else{l=b;m=d}}while(0);Z$();$h();ci();qB();rY()|0;ag(l,m,771552);Ih();if((Gg(l,m)|0)<0){Hf(1)}m=c[1371158]|0;if((m|0)<1&(c[1371162]|0)==0){Fg();KIb(0,24,2627520,(n=i,i=i+8|0,c[n>>2]=699200,n)|0);i=n;Hf(1);o=c[1371158]|0}else{o=m}if((o|0)<1){KIb(0,8,2602024,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;Hf(1)}rd(0,j|0)|0;o=c[j>>2]|0;m=Erc(o,(o|0)<0|0?-1:0,1e6,0)|0;o=c[j+4>>2]|0;j=wrc(m,G,o,(o|0)<0|0?-1:0)|0;o=G;c[2443082]=j;if((Qh()|0)<0){Hf(1)}rd(0,f|0)|0;m=c[f>>2]|0;l=c[f+4>>2]|0;if((c[2333756]|0)!=0){f=Erc(m,(m|0)<0|0?-1:0,1e6,0)|0;m=G;d=xrc(l,(l|0)<0|0?-1:0,j,o)|0;o=wrc(d,G,f,m)|0;p=(+(o>>>0)+ +(G|0)*4294967296.0)/1.0e6;Oc(2576768,(n=i,i=i+8|0,h[n>>3]=p,n)|0)|0;i=n}o=9474168;m=c[o+4>>2]|0;f=9474176;d=c[f>>2]|0;j=c[f+4>>2]|0;KIb(0,48,2557792,(n=i,i=i+32|0,c[n>>2]=c[o>>2],c[n+8>>2]=m,c[n+16>>2]=d,c[n+24>>2]=j,n)|0);i=n;n=9474168;j=9474176;d=c[j>>2]|0;m=c[j+4>>2]|0;j=wrc(d,m,c[n>>2]|0,c[n+4>>2]|0)|0;if(!(+g[208288]*(+(j>>>0)+ +(G|0)*4294967296.0)<+(d>>>0)+ +(m|0)*4294967296.0)){r=c[1352986]|0;s=(r|0)!=0;t=a[840088]|0;u=t&1;v=s?255:u;Hf(v);w=a[840088]|0;x=w&1;i=e;return x|0}Hf(69);r=c[1352986]|0;s=(r|0)!=0;t=a[840088]|0;u=t&1;v=s?255:u;Hf(v);w=a[840088]|0;x=w&1;i=e;return x|0}function Oh(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+136|0;d=b|0;if((c[2333756]|0)!=0){rd(0,d|0)|0;e=c[d+16>>2]|0;d=e;f=Crc(d<<10|0>>>22,((e|0)<0|0?-1:0)<<10|d>>>22,1024,0)|0;Oc(2484352,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g}if((c[1371168]|0)>0){f=0;do{tj((c[(c[1510464]|0)+(f<<2)>>2]|0)+8|0);d=c[(c[1510464]|0)+(f<<2)>>2]|0;e=d+16|0;if((c[d+20>>2]|0)>0){d=0;h=e;while(1){mJb((c[(c[h>>2]|0)+(d<<2)>>2]|0)+12|0);mJb((c[(c[(c[1510464]|0)+(f<<2)>>2]|0)+16>>2]|0)+(d<<2)|0);j=d+1|0;k=c[(c[1510464]|0)+(f<<2)>>2]|0;l=k+16|0;if((j|0)<(c[k+20>>2]|0)){d=j;h=l}else{m=l;break}}}else{m=e}mJb(m);h=c[(c[1510464]|0)+(f<<2)>>2]|0;d=h+24|0;if((c[h+28>>2]|0)>0){h=0;l=d;while(1){mJb((c[(c[l>>2]|0)+(h<<2)>>2]|0)+12|0);mJb((c[(c[(c[1510464]|0)+(f<<2)>>2]|0)+24>>2]|0)+(h<<2)|0);j=h+1|0;k=c[(c[1510464]|0)+(f<<2)>>2]|0;n=k+24|0;if((j|0)<(c[k+28>>2]|0)){h=j;l=n}else{o=n;break}}}else{o=d}mJb(o);mJb((c[(c[1510464]|0)+(f<<2)>>2]|0)+4|0);mJb((c[1510464]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1371168]|0))}mJb(6041856);mJb(5093512);if((c[1371158]|0)>0){f=0;do{o=c[c[(c[1366872]|0)+(f<<2)>>2]>>2]|0;do{if((o|0)!=0){m=c[o+8>>2]|0;if((m|0)==0){break}if((c[m+28>>2]&1|0)!=0){break}m=c[o+16>>2]|0;if((m|0)==0){break}WD(m)|0}}while(0);pX(o);OGb((c[(c[1366872]|0)+(f<<2)>>2]|0)+4|0);mJb((c[1366872]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1371158]|0))}if((c[1371156]|0)>0){f=0;do{d=c[(c[1366870]|0)+(f<<2)>>2]|0;m=c[d+56>>2]|0;if((m|0)==0){p=d}else{d=m;while(1){m=c[d+12>>2]|0;f3(d);if((m|0)==0){break}else{d=m}}p=c[(c[1366870]|0)+(f<<2)>>2]|0}c[p+56>>2]=0;VHb((c[(c[1366870]|0)+(f<<2)>>2]|0)+72|0);HWa(c[(c[(c[1366870]|0)+(f<<2)>>2]|0)+372>>2]|0);mJb((c[(c[1366870]|0)+(f<<2)>>2]|0)+112|0);TGb(c[(c[(c[1366870]|0)+(f<<2)>>2]|0)+116>>2]|0);mJb((c[(c[1366870]|0)+(f<<2)>>2]|0)+304|0);mJb((c[(c[1366870]|0)+(f<<2)>>2]|0)+292|0);mJb((c[1366870]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1371156]|0))}if((c[1371162]|0)>0){f=0;do{YX(c[(c[1475750]|0)+(f<<2)>>2]|0);mJb((c[1475750]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1371162]|0))}if((c[1371160]|0)>0){f=0;do{VHb((c[(c[1475748]|0)+(f<<2)>>2]|0)+20|0);VHb((c[(c[1475748]|0)+(f<<2)>>2]|0)+24|0);OGb((c[(c[1475748]|0)+(f<<2)>>2]|0)+104|0);p5a((c[(c[1475748]|0)+(f<<2)>>2]|0)+176|0);VHb((c[(c[1475748]|0)+(f<<2)>>2]|0)+224|0);mJb((c[(c[1475748]|0)+(f<<2)>>2]|0)+244|0);mJb((c[(c[1475748]|0)+(f<<2)>>2]|0)+260|0);mJb((c[1475748]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[1371160]|0))}f=c[836154]|0;if((f|0)!=0){nb(f|0)|0}kJb(c[836152]|0);mJb(5902992);mJb(5903e3);mJb(5467480);mJb(5467488);Ef();sY()|0;if((c[1352984]|0)!=0){KIb(0,32,2483544,(g=i,i=i+8|0,c[g>>2]=c[1352984],g)|0);i=g}KIb(0,-8,2223800,(g=i,i=i+8|0,c[g>>2]=10230128,g)|0);i=g;if(!(a[679920]|0)){i=b;return}Yd(0,0,5467576)|0;i=b;return}function Ph(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return}function Qh(){var b=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,ob=0,pb=0,rb=0,sb=0,tb=0,vb=0,wb=0,yb=0,zb=0.0,Ab=0,Cb=0.0,Db=0.0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Pc=0,Qc=0,Rc=0,Sc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0;b=i;i=i+24416|0;e=b|0;f=b+80|0;j=b+88|0;k=b+96|0;l=b+128|0;m=b+136|0;n=b+216|0;o=b+248|0;s=b+280|0;t=b+312|0;u=b+344|0;v=b+376|0;w=b+408|0;x=b+440|0;y=b+472|0;z=b+504|0;A=b+536|0;B=b+544|0;C=b+552|0;D=b+560|0;E=b+568|0;H=b+576|0;I=b+584|0;J=b+592|0;K=b+600|0;L=b+608|0;M=b+616|0;N=b+624|0;O=b+632|0;P=b+640|0;S=b+672|0;T=b+704|0;U=b+736|0;V=b+768|0;W=b+800|0;X=b+832|0;Y=b+840|0;Z=b+848|0;_=b+856|0;$=b+864|0;aa=b+992|0;da=b+1e3|0;ea=b+1008|0;fa=b+1136|0;ga=b+5232|0;ia=b+5488|0;ja=b+5744|0;ka=b+5752|0;la=b+5760|0;ma=b+5768|0;na=b+5776|0;oa=b+5840|0;pa=b+22224|0;qa=b+23256|0;ra=b+23264|0;sa=b+23272|0;ta=b+23280|0;ua=b+23288|0;va=b+23296|0;wa=b+23304|0;xa=b+24336|0;ya=b+24344|0;za=b+22232|0;Aa=b+23312|0;Ba=b+24352|0;Ca=sa;Da=ta;Ea=wa;Fa=c[1371168]|0;if((Fa|0)>0){Ga=c[1510464]|0;Ha=c[1475748]|0;Ia=0;Ja=Fa;while(1){Fa=c[Ga+(Ia<<2)>>2]|0;Ka=Fa+28|0;La=c[Ka>>2]|0;if((La|0)>0){Ma=c[Fa+24>>2]|0;Na=Fa+20|0;Oa=Fa+16|0;Fa=0;Pa=La;while(1){La=c[(c[Ma+(Fa<<2)>>2]|0)+4>>2]|0;do{if((La|0)==0){Qa=Pa}else{Ra=La+8|0;if((c[Ra>>2]|0)>-1){Qa=Pa;break}if((c[Na>>2]|0)!=1){Qa=Pa;break}Sa=c[1371160]|0;while(1){Ta=Sa-1|0;if((Sa|0)<=0){break}if((c[(c[c[Oa>>2]>>2]|0)+4>>2]|0)==(c[Ha+(Ta<<2)>>2]|0)){break}else{Sa=Ta}}c[Ra>>2]=Ta;Qa=c[Ka>>2]|0}}while(0);La=Fa+1|0;if((La|0)<(Qa|0)){Fa=La;Pa=Qa}else{break}}Ua=c[1371168]|0}else{Ua=Ja}Pa=Ia+1|0;if((Pa|0)<(Ua|0)){Ia=Pa;Ja=Ua}else{break}}}Ua=c[1371162]|0;if((Ua|0)>0){Ja=0;Ia=Ua;while(1){Ua=c[(c[1475750]|0)+(Ja<<2)>>2]|0;do{if((c[Ua+64>>2]|0)==0){Va=Ia}else{Qa=Ua+56|0;if((c[Qa>>2]|0)<=0){Va=Ia;break}Ta=Ua+12|0;Ha=0;do{Ga=jLb()|0;Pa=(c[(c[1475748]|0)+((c[Ta>>2]|0)+Ha<<2)>>2]|0)+32|0;c[Pa>>2]=Ga;c[Pa+4>>2]=G;Ha=Ha+1|0;}while((Ha|0)<(c[Qa>>2]|0));Va=c[1371162]|0}}while(0);Ua=Ja+1|0;if((Ua|0)<(Va|0)){Ja=Ua;Ia=Va}else{break}}}Va=c[1371158]|0;a:do{if((Va|0)>0){Ia=c[1366872]|0;Ja=0;while(1){Wa=c[c[Ia+(Ja<<2)>>2]>>2]|0;if((c[Wa+24>>2]|0)==0){if((c[(c[Wa+8>>2]|0)+28>>2]&4096|0)==0){break}}Ua=Ja+1|0;if((Ua|0)<(Va|0)){Ja=Ua}else{Xa=0;Ya=0;Za=28;break a}}cY(Wa,Ja,Wa+32|0,1);KIb(0,16,2570552,(_a=i,i=i+8|0,c[_a>>2]=Ja,_a)|0);i=_a;$a=-22}else{Xa=0;Ya=0;Za=28}}while(0);b:do{if((Za|0)==28){while(1){Za=0;if((Ya|0)>=(c[1371168]|0)){break}Wa=xj(c[(c[(c[1510464]|0)+(Ya<<2)>>2]|0)+8>>2]|0,0)|0;if((Wa|0)<0){$a=Wa;break b}Xa=Wa;Ya=Ya+1|0;Za=28}c:do{if((c[1371156]|0)>0){Ja=la|0;Wa=la+4|0;Va=ma|0;Ia=ma+4|0;Ua=va|0;Qa=va+4|0;Ha=ua|0;Ta=ua+4|0;Pa=ra|0;Ga=ra+4|0;Fa=0;Ka=Xa;d:while(1){ab=c[(c[1366870]|0)+(Fa<<2)>>2]|0;bb=ab|0;Oa=c[c[(c[1366872]|0)+(c[bb>>2]<<2)>>2]>>2]|0;Na=ab+8|0;Ma=c[Na>>2]|0;if((Ma|0)>-1){cb=c[(c[1475748]|0)+(Ma<<2)>>2]|0}else{cb=0}e:do{if((c[ab+356>>2]|0)==0){db=ab+12|0;Ma=c[db>>2]|0;La=c[Ma+8>>2]|0;Sa=(cb|0)!=0;do{if(Sa){eb=c[cb+4>>2]|0;fb=c[eb+8>>2]|0;c[Ma+72>>2]=c[eb+72>>2];c[La+796>>2]=c[fb+796>>2];c[La+400>>2]=c[fb+400>>2];gb=fb}else{fb=c[Oa+24>>2]|0;if((fb|0)==0){hb=La+8|0}else{eb=c[Oa+28>>2]|0;ib=La+8|0;jb=0;while(1){kb=c[eb+(jb<<2)>>2]|0;if((kb|0)!=(Ma|0)){if((c[(c[kb+8>>2]|0)+8>>2]|0)==(c[ib>>2]|0)){lb=jb;break}}kb=jb+1|0;if(kb>>>0<fb>>>0){jb=kb}else{lb=kb;break}}if((lb|0)==(fb|0)){hb=ib}else{gb=0;break}}if(!((c[hb>>2]|0)>>>0<2>>>0)){gb=0;break}c[Ma+72>>2]=1;gb=0}}while(0);if((c[ab+352>>2]|0)!=0){if(!Sa){Za=51;break d}if((c[ab+300>>2]|0)!=0){Za=51;break d}Ma=gb+100|0;jb=c[Ma>>2]|0;eb=wrc(jb,(jb|0)<0|0?-1:0,16,0)|0;jb=G;kb=0;if(jb>>>0>kb>>>0|jb>>>0==kb>>>0&eb>>>0>2147483647>>>0){$a=-22;break b}kb=gb+48|0;jb=La+48|0;c[jb>>2]=c[kb>>2];mb=La+8|0;c[mb>>2]=c[gb+8>>2];ob=La+52|0;f:do{if((c[ob>>2]|0)==0){pb=Oa+8|0;rb=c[(c[pb>>2]|0)+32>>2]|0;sb=gb+52|0;do{if((rb|0)!=0){tb=NX(rb,c[sb>>2]|0)|0;if((tb|0)==(c[jb>>2]|0)){break}if((MX(c[(c[pb>>2]|0)+32>>2]|0,c[kb>>2]|0,qa)|0)!=0){break f}}}while(0);c[ob>>2]=c[sb>>2]}}while(0);c[La+72>>2]=c[gb+72>>2];c[La+540>>2]=c[gb+540>>2];c[La+524>>2]=c[gb+524>>2];c[La+408>>2]=c[gb+408>>2];kb=pJb(eb)|0;c[La+96>>2]=kb;if((kb|0)==0){$a=-12;break b}nrc(kb|0,c[gb+96>>2]|0,c[Ma>>2]|0)|0;c[La+100>>2]=c[Ma>>2];c[La+792>>2]=c[gb+792>>2];kb=La+104|0;pb=cb+4|0;rb=(c[pb>>2]|0)+40|0;ib=kb;fb=c[rb+4>>2]|0;c[ib>>2]=c[rb>>2];c[ib+4>>2]=fb;fb=c[Oa+8>>2]|0;rb=c[fb>>2]|0;g:do{if((irc(rb,2638424)|0)==0){tb=c[409284]|0;vb=(tb|0)<0;do{if(vb){wb=c[pb>>2]|0;yb=c[wb+416>>2]|0;zb=+(c[wb+412>>2]|0)/+(yb|0);if(zb<+(c[wb+92>>2]|0)/+(c[wb+96>>2]|0)){Ab=wb;Za=70;break}Cb=.5/zb;zb=+(c[wb+40>>2]|0)/+(c[wb+44>>2]|0);if(!(Cb>zb)){Za=65;break}Db=+(c[gb+104>>2]|0)/+(c[gb+108>>2]|0);if(!(Cb>Db&zb<.002)){Za=65;break}if(Db<.002|(tb|0)==2){Eb=wb;Fb=yb;Za=67}else{Za=68}}else{Za=65}}while(0);do{if((Za|0)==65){Za=0;if((tb|0)!=2){Za=68;break}sb=c[pb>>2]|0;Eb=sb;Fb=c[sb+416>>2]|0;Za=67}}while(0);if((Za|0)==67){Za=0;c[kb>>2]=Fb;c[La+108>>2]=c[Eb+412>>2]<<1;c[La+112>>2]=2;break}do{if((Za|0)==68){Za=0;if(!vb){Za=72;break}Ab=c[pb>>2]|0;Za=70}}while(0);do{if((Za|0)==70){Za=0;vb=gb+112|0;Db=+(c[Ab+40>>2]|0)/+(c[Ab+44>>2]|0);if(!(+(c[gb+104>>2]|0)/+(c[gb+108>>2]|0)*+(c[vb>>2]|0)>Db*2.0)){Za=72;break}if(Db<.002){Gb=vb}else{break g}}}while(0);if((Za|0)==72){Za=0;if((tb|0)!=0){break}Gb=gb+112|0}vb=gb+104|0;sb=c[vb>>2]|0;yb=c[vb+4>>2]|0;c[ib>>2]=sb;c[ib+4>>2]=yb;c[kb>>2]=ca(sb,c[Gb>>2]|0)|0;c[La+108>>2]=yb<<1|0>>>31;c[La+112>>2]=2}else{if((c[fb+28>>2]&1024|0)!=0){break}if((irc(rb,2562808)|0)==0){break}if((irc(rb,2561176)|0)==0){break}if((irc(rb,2559504)|0)==0){break}if((irc(rb,2558296)|0)==0){break}if((irc(rb,2556976)|0)==0){break}if((irc(rb,2555752)|0)==0){break}if((irc(rb,2554584)|0)==0){break}yb=c[409284]|0;do{if((yb|0)<0){sb=c[gb+108>>2]|0;if((sb|0)==0){break g}vb=gb+112|0;wb=c[pb>>2]|0;Db=+(c[wb+40>>2]|0)/+(c[wb+44>>2]|0);if(!(+(c[gb+104>>2]|0)/+(sb|0)*+(c[vb>>2]|0)>Db)){Za=87;break}if(Db<.002|(yb|0)==0){Hb=vb}else{break g}}else{Za=87}}while(0);if((Za|0)==87){Za=0;if((yb|0)!=0){break}Hb=gb+112|0}tb=gb+104|0;vb=c[tb>>2]|0;sb=c[tb+4>>2]|0;c[ib>>2]=vb;c[ib+4>>2]=sb;c[kb>>2]=ca(vb,c[Hb>>2]|0)|0}}while(0);do{if((c[ob>>2]|0)==1684237684){rb=gb+104|0;fb=c[rb>>2]|0;Ma=c[gb+108>>2]|0;if(!((fb|0)<(Ma|0)&(fb|0)>0)){break}eb=Erc(fb,(fb|0)<0|0?-1:0,121,0)|0;fb=G;vb=(Ma|0)<0|0?-1:0;if(!((fb|0)>(vb|0)|(fb|0)==(vb|0)&eb>>>0>Ma>>>0)){break}Ma=rb;rb=c[Ma+4>>2]|0;c[ib>>2]=c[Ma>>2];c[ib+4>>2]=rb}}while(0);ob=ab+76|0;rb=c[ob>>2]|0;do{if((rb|0)==0){Ma=cb+108|0;eb=ob;vb=c[Ma>>2]|0;fb=c[Ma+4>>2]|0;c[eb>>2]=vb;c[eb+4>>2]=fb;eb=vb;if((eb|0)==0){vb=kb|0;Ma=La+108|0;Ib=c[vb>>2]|0;Jb=c[Ma>>2]|0;Kb=vb;Lb=Ma;break}else{Mb=eb;Nb=fb;Za=99;break}}else{Mb=rb;Nb=c[ab+80>>2]|0;Za=99}}while(0);if((Za|0)==99){Za=0;c[ib>>2]=Nb;c[ib+4>>2]=Mb;Ib=Nb;Jb=Mb;Kb=kb|0;Lb=La+108|0}xKb(Kb,Lb,Ib,(Ib|0)<0|0?-1:0,Jb,(Jb|0)<0|0?-1:0,2147483647,0)|0;c[ab+372>>2]=DWa(c[jb>>2]|0)|0;switch(c[mb>>2]|0){case 1:{if((c[501184]|0)!=256){KIb(0,8,2552592,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Hf(1)}rb=gb+448|0;ob=c[rb+4>>2]|0;fb=La+448|0;c[fb>>2]=c[rb>>2];c[fb+4>>2]=ob;c[La+412>>2]=c[gb+412>>2];c[La+416>>2]=c[gb+416>>2];c[La+424>>2]=c[gb+424>>2];c[La+464>>2]=c[gb+464>>2];ob=c[gb+432>>2]|0;fb=La+432|0;c[fb>>2]=ob;c[La+116>>2]=c[gb+116>>2];do{if((ob|0)==1|(ob|0)==1152|(ob|0)==576){rb=c[jb>>2]|0;if((rb|0)!=86017){Ob=rb;break}c[fb>>2]=0;Pb=Ka;break e}else{Ob=c[jb>>2]|0}}while(0);if((Ob|0)!=86019){Pb=Ka;break e}c[fb>>2]=0;Pb=Ka;break e;break};case 2:case 4:{Pb=Ka;break e;break};case 0:{c[La+140>>2]=c[gb+140>>2];jb=La+120|0;c[jb>>2]=c[gb+120>>2];ob=c[gb+124>>2]|0;c[La+124>>2]=ob;c[La+176>>2]=c[gb+176>>2];mb=ab+92|0;do{if((c[mb>>2]|0)==0){kb=(c[pb>>2]|0)+80|0;if((c[kb>>2]|0)==0){ib=gb+224|0;Qb=c[ib+4>>2]|0;Sb=c[ib>>2]|0;break}else{ib=kb;Qb=c[ib+4>>2]|0;Sb=c[ib>>2]|0;break}}else{c[Pa>>2]=ob;c[Ga>>2]=c[jb>>2];yKb(Ca,mb,ra);ib=c[sa>>2]|0;kb=c[sa+4>>2]|0;KIb(0,24,2548768,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Qb=kb;Sb=ib}}while(0);mb=(c[db>>2]|0)+80|0;jb=La+224|0;c[jb>>2]=Sb;c[jb+4>>2]=Qb;jb=mb;c[jb>>2]=Sb;c[jb+4>>2]=Qb;jb=(c[pb>>2]|0)+92|0;mb=(c[db>>2]|0)+92|0;ob=c[jb+4>>2]|0;c[mb>>2]=c[jb>>2];c[mb+4>>2]=ob;Pb=Ka;break e;break};case 3:{c[La+120>>2]=c[gb+120>>2];c[La+124>>2]=c[gb+124>>2];Pb=Ka;break e;break};default:{Za=116;break d}}}ob=ab+60|0;if((c[ob>>2]|0)==0){mb=b5a(c[La+48>>2]|0)|0;c[ob>>2]=mb;if((mb|0)==0){Za=119;break d}}if(Sa){mb=cb+12|0;c[mb>>2]=(c[mb>>2]|0)+1}c[ab+16>>2]=1;mb=ab+300|0;jb=La+8|0;do{if((c[mb>>2]|0)==0){fb=c[jb>>2]|0;if(!(fb>>>0<2>>>0)){Tb=fb;break}if((Eh(Ch(cb,ab)|0)|0)==0){Za=126;break}KIb(0,8,2543752,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Hf(1);Za=126}else{Za=126}}while(0);do{if((Za|0)==126){Za=0;pb=c[jb>>2]|0;if((pb|0)!=0){Tb=pb;break}pb=c[mb>>2]|0;do{if((pb|0)!=0){fb=ab+76|0;if((c[fb>>2]|0)!=0){break}Ij(Da,c[pb>>2]|0);ib=fb;fb=c[ta+4>>2]|0;c[ib>>2]=c[ta>>2];c[ib+4>>2]=fb}}while(0);do{if(Sa){pb=ab+76|0;if((c[pb>>2]|0)!=0){break}yb=cb+108|0;fb=pb;pb=c[yb>>2]|0;ib=c[yb+4>>2]|0;c[fb>>2]=pb;c[fb+4>>2]=ib;if((pb|0)!=0){break}pb=(c[cb+4>>2]|0)+412|0;ib=c[pb>>2]|0;yb=c[pb+4>>2]|0;c[fb>>2]=ib;c[fb+4>>2]=yb;if((ib|0)!=0){break}c[ab+76>>2]=25;c[ab+80>>2]=1;ib=c[ab+4>>2]|0;KIb(0,24,2542184,(_a=i,i=i+16|0,c[_a>>2]=c[bb>>2],c[_a+8>>2]=ib,_a)|0);i=_a}}while(0);ib=c[ob>>2]|0;do{if((ib|0)!=0){yb=c[ib+20>>2]|0;if((yb|0)==0){break}if((c[ab+84>>2]|0)!=0){break}fb=ab+76|0;pb=CKb(fb,yb)|0;yb=(c[(c[ob>>2]|0)+20>>2]|0)+(pb<<3)|0;pb=fb;fb=c[yb+4>>2]|0;c[pb>>2]=c[yb>>2];c[pb+4>>2]=fb}}while(0);if((c[La+48>>2]|0)==13){ib=ab+76|0;fb=ab+80|0;pb=c[ib>>2]|0;yb=c[fb>>2]|0;xKb(ib,fb,pb,(pb|0)<0|0?-1:0,yb,(yb|0)<0|0?-1:0,65535,0)|0}Tb=c[jb>>2]|0}}while(0);do{if((Tb|0)==1){jb=c[c[(c[c[mb>>2]>>2]|0)+16>>2]>>2]|0;c[La+420>>2]=c[jb+52>>2];Sa=La+412|0;c[Sa>>2]=c[jb+48>>2];yb=jb+40|0;pb=c[yb+4>>2]|0;fb=La+448|0;c[fb>>2]=c[yb>>2];c[fb+4>>2]=pb;c[La+416>>2]=Si(jb)|0;jb=c[Sa>>2]|0;c[La+104>>2]=1;c[La+108>>2]=jb;Ub=Ka}else if((Tb|0)==0){jb=La+104|0;Sa=c[ab+76>>2]|0;pb=c[ab+80>>2]|0;fb=jb;c[fb>>2]=pb;c[fb+4>>2]=Sa;yb=c[mb>>2]|0;do{if((yb|0)==0){Vb=pb;Wb=Sa}else{if(!((pb|0)==0|(Sa|0)==0)){Vb=pb;Wb=Sa;break}ib=(c[c[(c[yb>>2]|0)+16>>2]>>2]|0)+56|0;kb=c[ib>>2]|0;rb=c[ib+4>>2]|0;c[fb>>2]=kb;c[fb+4>>2]=rb;Vb=kb;Wb=rb}}while(0);fb=c[64350]|0;do{if(+(Vb|0)/+(Wb|0)<.001&(fb|0)!=0){if((fb|0)==(-1|0)){if((c[(c[Oa+8>>2]|0)+28>>2]&1024|0)!=0){break}}else if(!((fb|0)==254|(fb|0)==1)){break}KIb(Oa,24,2540816,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a}}while(0);fb=ab+104|0;if((c[fb>>2]|0)>0){yb=ab+100|0;Sa=0;pb=c[yb>>2]|0;do{rb=pb+(Sa<<3)|0;kb=c[rb>>2]|0;ib=c[rb+4>>2]|0;c[Ha>>2]=1;c[Ta>>2]=1e6;rb=XIb(kb,ib,ua,jb)|0;pb=c[yb>>2]|0;ib=pb+(Sa<<3)|0;c[ib>>2]=rb;c[ib+4>>2]=G;Sa=Sa+1|0;}while((Sa|0)<(c[fb>>2]|0))}Sa=c[c[(c[c[mb>>2]>>2]|0)+16>>2]>>2]|0;pb=La+120|0;c[pb>>2]=c[Sa+20>>2];yb=c[Sa+24>>2]|0;jb=La+124|0;c[jb>>2]=yb;ib=(c[db>>2]|0)+80|0;rb=ab+92|0;if((c[rb>>2]|0)==0){kb=Sa+28|0;Sa=ib;eb=c[kb>>2]|0;Ma=c[kb+4>>2]|0;c[Sa>>2]=eb;c[Sa+4>>2]=Ma;Xb=Ma;Yb=eb}else{c[Ua>>2]=yb;c[Qa>>2]=c[pb>>2];yKb(Ea,rb,va);rb=ib;ib=c[wa>>2]|0;yb=c[wa+4>>2]|0;c[rb>>2]=ib;c[rb+4>>2]=yb;Xb=yb;Yb=ib}ib=La+224|0;c[ib>>2]=Yb;c[ib+4>>2]=Xb;ib=c[c[ob>>2]>>2]|0;yb=La+140|0;do{if((krc(ib,2539648,7)|0)==0){if(!((c[yb>>2]|0)==-1)){Zb=ib;break}rb=c[(c[c[(c[c[mb>>2]>>2]|0)+16>>2]>>2]|0)+52>>2]|0;if((rb|0)==0){Zb=ib;break}eb=mKb(rb)|0;KIb(0,24,2538264,(_a=i,i=i+8|0,c[_a>>2]=eb,_a)|0);i=_a;Zb=c[c[ob>>2]>>2]|0}else{Zb=ib}}while(0);do{if((krc(Zb,2536704,10)|0)==0){if(!((c[yb>>2]|0)==-1)){break}ib=c[(c[c[(c[c[mb>>2]>>2]|0)+16>>2]>>2]|0)+52>>2]|0;if((ib|0)==0){break}eb=mKb(ib)|0;KIb(0,24,2535440,(_a=i,i=i+8|0,c[_a>>2]=eb,_a)|0);i=_a}}while(0);eb=c[(c[c[(c[c[mb>>2]>>2]|0)+16>>2]>>2]|0)+52>>2]|0;c[yb>>2]=eb;do{if((gb|0)==0){Za=169}else{if((c[pb>>2]|0)!=(c[gb+120>>2]|0)){Za=169;break}if((c[jb>>2]|0)!=(c[gb+124>>2]|0)){Za=169;break}if((eb|0)!=(c[gb+140>>2]|0)){Za=169}}}while(0);if((Za|0)==169){Za=0;c[La+796>>2]=c[1510442]}$b=ab+112|0;eb=c[$b>>2]|0;if((eb|0)==0){Ub=Ka;break}if((krc(eb,2534512,5)|0)==0){ac=UGb(ab+116|0,eb+5|0,1211792,0,0,0,0,0,0)|0;if((ac|0)<0){Za=173;break d}mrc(ab+120|0,0,16)|0;h[ab+136>>3]=+r;h[ab+144>>3]=+r;Ub=ac;break}jb=c[(c[db>>2]|0)+8>>2]|0;pb=eb;yb=1;while(1){ib=a[pb]|0;if((ib<<24>>24|0)==44){bc=yb+1|0}else if((ib<<24>>24|0)==0){break}else{bc=yb}pb=pb+1|0;yb=bc}pb=hJb(yb<<3)|0;ib=pb;if((pb|0)==0){KIb(0,8,2488696,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Hf(1)}if((yb|0)>0){pb=jb+104|0;rb=0;Ma=yb;Sa=0;kb=ib;vb=eb;while(1){sb=_b(vb|0,44)|0;if((sb|0)==0){cc=0}else{a[sb]=0;cc=sb+1|0}do{if((grc(vb,2486648,8)|0)==0){sb=c[c[(c[1366872]|0)+(c[bb>>2]<<2)>>2]>>2]|0;tb=sb+1132|0;wb=c[tb>>2]|0;if(wb>>>0>(2147483647-Ma|0)>>>0){dc=kb;ec=Ma;Za=188}else{fc=Ma-1+wb|0;wb=jJb(kb,fc,8)|0;gc=wb;if((wb|0)==0){dc=gc;ec=fc;Za=188}else{hc=gc;ic=fc}}if((Za|0)==188){Za=0;KIb(0,8,2488696,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Hf(1);hc=dc;ic=ec}fc=vb+8|0;if((a[fc]|0)==0){jc=0;kc=0}else{gc=Jf(2485752,fc,1)|0;jc=G;kc=gc}c[Ja>>2]=1;c[Wa>>2]=1e6;gc=XIb(kc,jc,la,pb)|0;fc=G;if((c[tb>>2]|0)==0){lc=hc;mc=Sa;nc=ic;break}wb=sb+1136|0;sb=Sa;oc=0;while(1){pc=c[(c[wb>>2]|0)+(oc<<2)>>2]|0;qc=pc+16|0;rc=XIb(c[qc>>2]|0,c[qc+4>>2]|0,pc+4|0,pb)|0;pc=wrc(rc,G,gc,fc)|0;rc=sb+1|0;qc=hc+(sb<<3)|0;c[qc>>2]=pc;c[qc+4>>2]=G;qc=oc+1|0;if(qc>>>0<(c[tb>>2]|0)>>>0){sb=rc;oc=qc}else{lc=hc;mc=rc;nc=ic;break}}}else{oc=Jf(2485752,vb,1)|0;c[Va>>2]=1;c[Ia>>2]=1e6;sb=XIb(oc,G,ma,pb)|0;oc=kb+(Sa<<3)|0;c[oc>>2]=sb;c[oc+4>>2]=G;lc=kb;mc=Sa+1|0;nc=Ma}}while(0);oc=rb+1|0;if((oc|0)<(yb|0)){rb=oc;Ma=nc;Sa=mc;kb=lc;vb=cc}else{sc=nc;tc=mc;uc=lc;break}}}else{sc=yb;tc=0;uc=ib}if((tc|0)!=(sc|0)){Za=197;break d}cd(uc|0,tc|0,8,16);c[fb>>2]=tc;c[ab+100>>2]=uc;Ub=Ka}else if((Tb|0)==3){c[La+104>>2]=1;c[La+108>>2]=1e3;vb=La+120|0;if((c[vb>>2]|0)!=0){Ub=Ka;break}kb=c[1475748]|0;c[vb>>2]=c[(c[(c[(c[kb+(c[Na>>2]<<2)>>2]|0)+4>>2]|0)+8>>2]|0)+120>>2];c[La+124>>2]=c[(c[(c[(c[kb+(c[Na>>2]<<2)>>2]|0)+4>>2]|0)+8>>2]|0)+124>>2];Ub=Ka}else{Za=201;break d}}while(0);mb=La+88|0;if((c[mb>>2]&1536|0)==0){Pb=Ub;break}kb=c[ab+292>>2]|0;Rb(Aa|0,1024,2527560,(_a=i,i=i+16|0,c[_a>>2]=(kb|0)==0?2526224:kb,c[_a+8>>2]=Fa,_a)|0)|0;i=_a;if((irc(c[c[ob>>2]>>2]|0,2539648)|0)==0){MGb(ab+328|0,2524872,Aa,16)|0;Pb=Ub;break}kb=c[mb>>2]|0;if((kb&1024|0)==0){vc=kb}else{if((vg(Aa,xa,ya)|0)<0){KIb(0,8,2523832,(_a=i,i=i+8|0,c[_a>>2]=Aa,_a)|0);i=_a;Hf(1)}c[La+672>>2]=c[xa>>2];vc=c[mb>>2]|0}if((vc&512|0)==0){Pb=Ub;break}mb=oHb(Aa,2522872)|0;if((mb|0)==0){kb=qd(c[(pd()|0)>>2]|0)|0;KIb(0,8,2521776,(_a=i,i=i+16|0,c[_a>>2]=Aa,c[_a+8>>2]=kb,_a)|0);i=_a;Hf(1)}c[ab+296>>2]=mb;Pb=Ub}else{Pb=Ka}}while(0);Na=Fa+1|0;wc=c[1371156]|0;if((Na|0)<(wc|0)){Fa=Na;Ka=Pb}else{Za=33;break}}if((Za|0)==33){if((wc|0)>0){xc=0;yc=Pb}else{zc=Pb;Za=214;break}while(1){Ac=c[(c[1366870]|0)+(xc<<2)>>2]|0;if((c[Ac+16>>2]|0)==0){XJb(c[(c[Ac+12>>2]|0)+8>>2]|0,Ac+328|0)|0;Bc=yc}else{Ka=Ac+60|0;Fa=c[Ka>>2]|0;Ia=c[Ac+8>>2]|0;do{if((Ia|0)>-1){Va=c[(c[1475748]|0)+(Ia<<2)>>2]|0;if((Va|0)==0){break}Wa=c[(c[Va+4>>2]|0)+8>>2]|0;if((Wa|0)==0){break}Va=Wa+860|0;if((c[Va>>2]|0)==0){break}Ja=Wa+864|0;Wa=pJb((c[Ja>>2]|0)+1|0)|0;Qa=Ac+12|0;c[(c[(c[Qa>>2]|0)+8>>2]|0)+860>>2]=Wa;Wa=c[(c[(c[Qa>>2]|0)+8>>2]|0)+860>>2]|0;if((Wa|0)==0){Cc=-12;Dc=1;Za=267;break c}nrc(Wa|0,c[Va>>2]|0,c[Ja>>2]|0)|0;c[(c[(c[Qa>>2]|0)+8>>2]|0)+864>>2]=c[Ja>>2]}}while(0);Ia=Ac+328|0;if((LGb(c[Ia>>2]|0,2520704,0,0)|0)==0){MGb(Ia,2520704,2519704,0)|0}Ja=Ac+12|0;Ec=_4a(c[(c[Ja>>2]|0)+8>>2]|0,Fa,Ia)|0;if((Ec|0)<0){break}Qa=c[Ka>>2]|0;do{if((c[Qa+8>>2]|0)==1){if((c[Qa+16>>2]&65536|0)!=0){break}Hj(c[c[Ac+300>>2]>>2]|0,c[(c[(c[Ja>>2]|0)+8>>2]|0)+424>>2]|0)}}while(0);Qa=LGb(c[Ia>>2]|0,10230128,0,2)|0;if((Qa|0)!=0){KIb(0,8,2158376,(_a=i,i=i+8|0,c[_a>>2]=c[Qa>>2],_a)|0);i=_a;Hf(1)}Qa=c[(c[Ja>>2]|0)+8>>2]|0;Ka=c[Qa+72>>2]|0;if((Ka|0)!=0&(Ka|0)<1e3){KIb(0,24,2515520,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Fc=c[(c[Ja>>2]|0)+8>>2]|0}else{Fc=Qa}Qa=c[Fc+100>>2]|0;Ka=wrc(c[2209948]|0,c[2209949]|0,Qa,(Qa|0)<0|0?-1:0)|0;c[2209948]=Ka;c[2209949]=G;Bc=Ec}Ka=xc+1|0;if((Ka|0)<(c[1371156]|0)){xc=Ka;yc=Bc}else{zc=Bc;Za=214;break c}}if((Ec|0)==-733130664){Hf(1)}Ka=c[Ac+4>>2]|0;Rb(za|0,1024,2518864,(_a=i,i=i+16|0,c[_a>>2]=c[Ac>>2],c[_a+8>>2]=Ka,_a)|0)|0;i=_a;Cc=Ec;Dc=1;Za=267;break}else if((Za|0)==51){KIb(0,0,2127408,(_a=i,i=i+24|0,c[_a>>2]=2567120,c[_a+8>>2]=2120856,c[_a+16>>2]=2335,_a)|0);i=_a;Hd();return 0}else if((Za|0)==116){Hd();return 0}else if((Za|0)==119){Ka=u5a(c[(c[(c[db>>2]|0)+8>>2]|0)+48>>2]|0)|0;Qa=c[bb>>2]|0;Fa=c[ab+4>>2]|0;Rb(za|0,1024,2545264,(_a=i,i=i+24|0,c[_a>>2]=Ka,c[_a+8>>2]=Qa,c[_a+16>>2]=Fa,_a)|0)|0;i=_a;Cc=-22;Dc=1;Za=267;break}else if((Za|0)==173){KIb(0,16,2530904,(_a=i,i=i+8|0,c[_a>>2]=(c[$b>>2]|0)+5,_a)|0);i=_a;$a=ac;break b}else if((Za|0)==197){KIb(0,0,2127408,(_a=i,i=i+24|0,c[_a>>2]=2484960,c[_a+8>>2]=2120856,c[_a+16>>2]=2233,_a)|0);i=_a;Hd();return 0}else if((Za|0)==201){Hd();return 0}}else{zc=Xa;Za=214}}while(0);h:do{if((Za|0)==214){i:do{if((c[1371160]|0)>0){Fa=na|0;Qa=0;j:while(1){Gc=c[(c[1475748]|0)+(Qa<<2)>>2]|0;do{if((c[Gc+12>>2]|0)!=0){Ka=c[Gc+16>>2]|0;if((Ka|0)==0){Za=243;break j}Hc=Gc+4|0;c[(c[(c[Hc>>2]|0)+8>>2]|0)+68>>2]=Gc;c[(c[(c[Hc>>2]|0)+8>>2]|0)+152>>2]=304;c[(c[(c[Hc>>2]|0)+8>>2]|0)+484>>2]=56;Va=c[(c[Hc>>2]|0)+8>>2]|0;c[Va+820>>2]=1;IJb(Va,2492016,1,0,0)|0;Va=Gc+104|0;if((LGb(c[Va>>2]|0,2520704,0,0)|0)==0){MGb(Va,2520704,2519704,0)|0}Ic=_4a(c[(c[Hc>>2]|0)+8>>2]|0,Ka,Va)|0;if((Ic|0)<0){Za=247;break j}Ka=LGb(c[Va>>2]|0,10230128,0,2)|0;if((Ka|0)==0){break}KIb(0,8,2158376,(_a=i,i=i+8|0,c[_a>>2]=c[Ka>>2],_a)|0);i=_a;Hf(1)}}while(0);La=Gc+56|0;c[La>>2]=0;c[La+4>>2]=-2147483648;La=Gc+40|0;c[La>>2]=0;c[La+4>>2]=-2147483648;La=Qa+1|0;if((La|0)<(c[1371160]|0)){Qa=La}else{Jc=0;break i}}if((Za|0)==243){Qa=Gc+4|0;Ja=u5a(c[(c[(c[Qa>>2]|0)+8>>2]|0)+48>>2]|0)|0;Ia=c[Gc>>2]|0;La=c[c[Qa>>2]>>2]|0;Rb(za|0,1024,2492720,(_a=i,i=i+24|0,c[_a>>2]=Ja,c[_a+8>>2]=Ia,c[_a+16>>2]=La,_a)|0)|0;i=_a;Kc=-22}else if((Za|0)==247){if((Ic|0)==-733130664){Hf(1)}La=c[Gc>>2]|0;Ia=c[c[Hc>>2]>>2]|0;mrc(Fa|0,0,64)|0;a[Fa]=0;RGb(Ic,Fa,64)|0;Rb(za|0,1024,2491528,(_a=i,i=i+24|0,c[_a>>2]=La,c[_a+8>>2]=Ia,c[_a+16>>2]=Fa,_a)|0)|0;i=_a;Kc=Ic}if((c[1371156]|0)>0){Lc=0}else{Cc=Kc;Dc=1;Za=267;break h}while(1){r5a(c[(c[(c[(c[1366870]|0)+(Lc<<2)>>2]|0)+12>>2]|0)+8>>2]|0)|0;Ia=Lc+1|0;if((Ia|0)<(c[1371156]|0)){Lc=Ia}else{Cc=Kc;Dc=1;Za=267;break h}}}else{Jc=zc}}while(0);Fa=c[1371162]|0;if((Fa|0)>0){Ia=c[1475750]|0;La=c[1475748]|0;Ja=0;do{Qa=c[Ia+(Ja<<2)>>2]|0;ob=c[Qa>>2]|0;Ka=c[ob+1104>>2]|0;if((Ka|0)!=0){Va=Qa+12|0;Qa=c[ob+1108>>2]|0;ob=0;do{Wa=c[Qa+(ob<<2)>>2]|0;Ua=c[Wa+16>>2]|0;Ta=Wa+12|0;Ha=0;while(1){if(!(Ha>>>0<Ua>>>0)){Mc=48;break}if((c[(c[La+((c[(c[Ta>>2]|0)+(Ha<<2)>>2]|0)+(c[Va>>2]|0)<<2)>>2]|0)+8>>2]|0)==0){Mc=0;break}else{Ha=Ha+1|0}}c[Wa+8>>2]=Mc;ob=ob+1|0;}while(ob>>>0<Ka>>>0)}Ja=Ja+1|0;}while((Ja|0)<(Fa|0))}if((c[1371158]|0)<=0){Nc=1;Pc=Jc;break}Fa=1070432;Ja=c[Fa>>2]|0;La=c[Fa+4>>2]|0;Fa=1;Ia=0;while(1){Ka=(c[1366872]|0)+(Ia<<2)|0;ob=c[c[Ka>>2]>>2]|0;Va=ob+1160|0;c[Va>>2]=Ja;c[Va+4>>2]=La;Qc=TO(ob,(c[Ka>>2]|0)+4|0)|0;if((Qc|0)<0){break}Ka=(irc(c[c[ob+8>>2]>>2]|0,2510936)|0)==0;ob=Ka?Fa:0;Ka=Ia+1|0;Va=c[1371158]|0;if((Ka|0)<(Va|0)){Fa=ob;Ia=Ka}else{Rc=Qc;Sc=ob;Uc=Va;Za=268;break h}}mrc(Ba|0,0,64)|0;a[Ba]=0;RGb(Qc,Ba,64)|0;Rb(za|0,1024,2512368,(_a=i,i=i+16|0,c[_a>>2]=Ia,c[_a+8>>2]=Ba,_a)|0)|0;i=_a;Cc=-22;Dc=Fa;Za=267}}while(0);if((Za|0)==267){Rc=Cc;Sc=Dc;Uc=c[1371158]|0;Za=268}do{if((Za|0)==268){if((Uc|0)>0){Vc=0}else{Nc=Sc;Pc=Rc;break}while(1){La=c[c[(c[1366872]|0)+(Vc<<2)>>2]>>2]|0;cY(La,Vc,La+32|0,1);La=Vc+1|0;if((La|0)<(c[1371158]|0)){Vc=La}else{Nc=Sc;Pc=Rc;break}}}}while(0);KIb(0,32,2509672,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Fa=c[1371160]|0;if((Fa|0)>0){Ia=0;La=Fa;while(1){Fa=c[(c[1475748]|0)+(Ia<<2)>>2]|0;Ja=Fa+248|0;Va=c[Ja>>2]|0;if((Va|0)>0){ob=Fa+244|0;Ka=Fa|0;Qa=Fa+4|0;Ha=Fa+16|0;Fa=0;Ta=Va;while(1){Va=c[(c[ob>>2]|0)+(Fa<<2)>>2]|0;if((c[(c[Va+8>>2]|0)+4>>2]|0)==0){Wc=Ta}else{Ua=c[c[Qa>>2]>>2]|0;Ga=c[Ha>>2]|0;if((Ga|0)==0){Xc=2508048}else{Xc=c[Ga>>2]|0}Ga=c[Va+12>>2]|0;KIb(0,32,2508864,(_a=i,i=i+32|0,c[_a>>2]=c[Ka>>2],c[_a+8>>2]=Ua,c[_a+16>>2]=Xc,c[_a+24>>2]=Ga,_a)|0);i=_a;if((c[1371168]|0)>1){KIb(0,32,2507136,(_a=i,i=i+8|0,c[_a>>2]=c[c[(c[(c[ob>>2]|0)+(Fa<<2)>>2]|0)+8>>2]>>2],_a)|0);i=_a}KIb(0,32,2133824,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;Wc=c[Ja>>2]|0}Ga=Fa+1|0;if((Ga|0)<(Wc|0)){Fa=Ga;Ta=Wc}else{break}}Yc=c[1371160]|0}else{Yc=La}Ta=Ia+1|0;if((Ta|0)<(Yc|0)){Ia=Ta;La=Yc}else{break}}}if((c[1371156]|0)>0){La=0;do{Ia=c[(c[1366870]|0)+(La<<2)>>2]|0;Ta=c[Ia+356>>2]|0;k:do{if((Ta|0)==0){Fa=Ia+300|0;Ja=c[Fa>>2]|0;do{if((Ja|0)!=0){if((c[(c[Ja+8>>2]|0)+4>>2]|0)==0){break}KIb(0,32,2505320,(_a=i,i=i+8|0,c[_a>>2]=c[Ja+12>>2],_a)|0);i=_a;if((c[1371168]|0)>1){KIb(0,32,2507136,(_a=i,i=i+8|0,c[_a>>2]=c[c[(c[Fa>>2]|0)+8>>2]>>2],_a)|0);i=_a}ob=c[Ia+4>>2]|0;Ka=c[Ia+60>>2]|0;if((Ka|0)==0){Zc=2508048}else{Zc=c[Ka>>2]|0}KIb(0,32,2504640,(_a=i,i=i+24|0,c[_a>>2]=c[Ia>>2],c[_a+8>>2]=ob,c[_a+16>>2]=Zc,_a)|0);i=_a;break k}}while(0);Fa=Ia+8|0;Ja=c[(c[1475748]|0)+(c[Fa>>2]<<2)>>2]|0;ob=c[c[Ja+4>>2]>>2]|0;Ka=c[Ia>>2]|0;Ha=c[Ia+4>>2]|0;KIb(0,32,2501600,(_a=i,i=i+32|0,c[_a>>2]=c[Ja>>2],c[_a+8>>2]=ob,c[_a+16>>2]=Ka,c[_a+24>>2]=Ha,_a)|0);i=_a;Ha=c[Ia+24>>2]|0;if((Ha|0)!=(c[(c[1475748]|0)+(c[Fa>>2]<<2)>>2]|0)){Ka=c[c[Ha+4>>2]>>2]|0;KIb(0,32,2498896,(_a=i,i=i+16|0,c[_a>>2]=c[Ha>>2],c[_a+8>>2]=Ka,_a)|0);i=_a}if((c[Ia+352>>2]|0)==0){Ka=c[(c[(c[1475748]|0)+(c[Fa>>2]<<2)>>2]|0)+16>>2]|0;if((Ka|0)==0){_c=2508048}else{_c=c[Ka>>2]|0}Ka=c[Ia+60>>2]|0;if((Ka|0)==0){$c=2508048}else{$c=c[Ka>>2]|0}KIb(0,32,2495680,(_a=i,i=i+16|0,c[_a>>2]=_c,c[_a+8>>2]=$c,_a)|0);i=_a}else{KIb(0,32,2496944,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a}KIb(0,32,2133824,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a}else{Ka=c[Ia>>2]|0;Fa=c[Ia+4>>2]|0;KIb(0,32,2506240,(_a=i,i=i+24|0,c[_a>>2]=Ta,c[_a+8>>2]=Ka,c[_a+16>>2]=Fa,_a)|0);i=_a}}while(0);La=La+1|0;}while((La|0)<(c[1371156]|0))}if((Pc|0)!=0){KIb(0,16,2494792,(_a=i,i=i+8|0,c[_a>>2]=za,_a)|0);i=_a;$a=Pc;break}if((Nc|0)==0){$a=0;break}La=oa|0;Ta=pa;Ia=hJb(c[1371158]<<2)|0;c[pa>>2]=Ia;if((Ia|0)==0){Hf(1)}Ia=c[1371158]|0;if((Ia|0)>0){Fa=0;do{c[(c[pa>>2]|0)+(Fa<<2)>>2]=c[c[(c[1366872]|0)+(Fa<<2)>>2]>>2];Fa=Fa+1|0;}while((Fa|0)<(Ia|0))}nU(c[pa>>2]|0,Ia,La,16384)|0;Oc(2493592,(_a=i,i=i+8|0,c[_a>>2]=La,_a)|0)|0;i=_a;qb(c[p>>2]|0)|0;mJb(Ta);$a=0}}while(0);do{if(($a|0)<0){ad=$a}else{if((c[139256]|0)!=0){KIb(0,32,2540200,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a}pa=jLb()|0;oa=G;l:do{if((c[1352984]|0)==0){Nc=Y|0;Pc=Y+4|0;za=X|0;$c=X+4|0;_c=n|0;Zc=o|0;Yc=s|0;Wc=t|0;Xc=u|0;Rc=v|0;Sc=w|0;Vc=x|0;Uc=y|0;Dc=z|0;Cc=P|0;Ba=S|0;Qc=T|0;Jc=U|0;Mc=V|0;zc=W|0;Kc=na|0;Lc=l|0;Ic=l+4|0;Hc=m+32|0;Gc=A|0;Xa=A+4|0;ac=B|0;$b=B+4|0;ab=C|0;bb=C+4|0;db=m+16|0;Ec=m+8|0;Ac=K|0;Bc=K+4|0;yc=N|0;xc=N+4|0;Fc=L|0;Pb=L+4|0;wc=M|0;Ub=M+4|0;Aa=O|0;vc=O+4|0;xa=H|0;ya=H+4|0;Tb=I|0;uc=I+4|0;tc=J|0;sc=J+4|0;lc=E|0;mc=E+4|0;nc=D|0;cc=D+4|0;ma=k|0;ic=m+64|0;hc=j|0;la=j+4|0;jc=fa|0;kc=ga|0;ec=ia|0;dc=ea;bc=ea|0;gb=da|0;Zb=da+4|0;Xb=c[q>>2]|0;Yb=$;wa=$|0;va=_|0;Ea=_+4|0;m:while(1){ua=jLb()|0;Wb=G;n:do{if((c[139256]|0)!=0){if((c[1352986]|0)!=0){break l}Vb=xrc(ua,Wb,c[2458824]|0,c[2458825]|0)|0;cb=G;ta=0;if((cb|0)<(ta|0)|(cb|0)==(ta|0)&Vb>>>0<1e5>>>0|a[676880]){break}mrc(dc|0,0,128)|0;c[bc>>2]=1;c[gb>>2]=0;c[Zb>>2]=0;if((Tc(1,ea|0,0,0,da|0)|0)<=0){c[2458824]=ua;c[2458825]=Wb;break}Vb=Bb(0,aa|0,1)|0;if((Vb|0)==1){dd=d[aa]|0}else{dd=Vb}c[2458824]=ua;c[2458825]=Wb;switch(dd|0){case 113:{break l;break};case 43:{NIb((MIb()|0)+10|0);break n;break};case 45:{NIb((MIb()|0)-10|0);break n;break};case 115:{c[1353610]=c[1353610]^1;break n;break};case 104:{do{if((c[2333750]|0)==0){if((c[2333748]|0)==0){c[2333748]=1;break}else{c[2333750]=1;break}}else{c[2333748]=0;c[2333750]=0}}while(0);NIb(48);break};default:{}}Wa=(dd|0)==99;o:do{if((dd|0)==99|(dd|0)==67){mrc(ec|0,0,256)|0;ub(2593320,62,1,Xb|0)|0;Vb=0;p:while(1){while(1){mrc(Yb|0,0,128)|0;c[wa>>2]=1;c[va>>2]=0;c[Ea>>2]=0;if((Tc(1,$|0,0,0,_|0)|0)<=0){continue}ta=Bb(0,Z|0,1)|0;if((ta|0)==1){ed=d[Z]|0}else{ed=ta}if((ed|0)==10|(ed|0)==13){fd=Vb;Za=348;break p}if((ed|0)>0){break}}gd=Vb+1|0;a[fa+Vb|0]=ed;if(gd>>>0<4095>>>0){Vb=gd}else{Za=337;break}}do{if((Za|0)==337){Za=0;mrc(Yb|0,0,128)|0;c[wa>>2]=1;c[va>>2]=0;c[Ea>>2]=0;if((Tc(1,$|0,0,0,_|0)|0)<=0){a[fa+gd|0]=0;hd=0;break}Vb=Bb(0,Z|0,1)|0;if((Vb|0)==1){id=d[Z]|0}else{id=Vb}if((id|0)==10|(id|0)==13){fd=gd;Za=348;break}a[fa+gd|0]=0;if((id|0)>0){Za=350}else{hd=0}}}while(0);if((Za|0)==348){Za=0;a[fa+fd|0]=0;Za=350}do{if((Za|0)==350){Za=0;Vb=Bd(jc|0,2588568,(_a=i,i=i+32|0,c[_a>>2]=Kc,c[_a+8>>2]=ja,c[_a+16>>2]=kc,c[_a+24>>2]=ec,_a)|0)|0;i=_a;if((Vb|0)<=2){hd=Vb;break}Db=+h[ja>>3];KIb(0,48,2583320,(_a=i,i=i+32|0,c[_a>>2]=Kc,h[_a+8>>3]=Db,c[_a+16>>2]=kc,c[_a+24>>2]=ec,_a)|0);i=_a;if((c[1371168]|0)<=0){break o}Vb=Wa&1;if(Wa){fb=0;while(1){ib=c[(c[(c[1510464]|0)+(fb<<2)>>2]|0)+8>>2]|0;do{if((ib|0)!=0){if(+h[ja>>3]<0.0){yb=yj(ib,Kc,kc,ec,jc,4096,Vb)|0;Id(Xb|0,2581024,(_a=i,i=i+24|0,c[_a>>2]=fb,c[_a+8>>2]=yb,c[_a+16>>2]=jc,_a)|0)|0;i=_a;break}else{ub(2579168,79,1,Xb|0)|0;break}}}while(0);fb=fb+1|0;if((fb|0)>=(c[1371168]|0)){break o}}}else{fb=0;while(1){ib=c[(c[(c[1510464]|0)+(fb<<2)>>2]|0)+8>>2]|0;do{if((ib|0)!=0){Db=+h[ja>>3];if(Db<0.0){yb=yj(ib,Kc,kc,ec,jc,4096,Vb)|0;Id(Xb|0,2581024,(_a=i,i=i+24|0,c[_a>>2]=fb,c[_a+8>>2]=yb,c[_a+16>>2]=jc,_a)|0)|0;i=_a;break}else{zj(ib,Kc,kc,ec,0,Db)|0;break}}}while(0);fb=fb+1|0;if((fb|0)>=(c[1371168]|0)){break o}}}}}while(0);KIb(0,16,2577376,(_a=i,i=i+16|0,c[_a>>2]=hd,c[_a+8>>2]=jc,_a)|0);i=_a}}while(0);Wa=(dd|0)==68;if((dd|0)==100|(dd|0)==68){c[ka>>2]=0;do{if(Wa){fb=c[(c[(c[(c[c[1475748]>>2]|0)+4>>2]|0)+8>>2]|0)+688>>2]<<1;if((fb|0)==0){c[ka>>2]=1;break}c[ka>>2]=fb;if((fb&24640|0)==0){break}else{jd=fb}do{jd=jd<<1;}while((jd&24640|0)!=0);c[ka>>2]=jd}else{fb=bd(2575912,(_a=i,i=i+8|0,c[_a>>2]=ka,_a)|0)|0;i=_a;if((fb|0)==1){break}ub(2574544,26,1,Xb|0)|0}}while(0);if((c[1371160]|0)>0){Wa=c[1475748]|0;fb=0;do{c[(c[(c[(c[Wa+(fb<<2)>>2]|0)+4>>2]|0)+8>>2]|0)+688>>2]=c[ka>>2];fb=fb+1|0;}while((fb|0)<(c[1371160]|0))}if((c[1371156]|0)>0){fb=c[1366870]|0;Wa=0;do{c[(c[(c[(c[fb+(Wa<<2)>>2]|0)+12>>2]|0)+8>>2]|0)+688>>2]=c[ka>>2];Wa=Wa+1|0;}while((Wa|0)<(c[1371156]|0))}if((c[ka>>2]|0)==0){kd=0}else{NIb(48);kd=c[ka>>2]|0}Id(Xb|0,2573e3,(_a=i,i=i+8|0,c[_a>>2]=kd,_a)|0)|0;i=_a;if((dd|0)!=63){break}}else if((dd|0)!=63){break}ub(2571528,337,1,Xb|0)|0}}while(0);if((c[1371156]|0)>0){ld=0}else{Za=394;break}q:while(1){Wa=c[(c[1366870]|0)+(ld<<2)>>2]|0;fb=c[(c[1366872]|0)+(c[Wa>>2]<<2)>>2]|0;Vb=fb|0;do{if((c[Wa+344>>2]|0)==0){ib=c[(c[Vb>>2]|0)+16>>2]|0;if((ib|0)!=0){yb=fD(ib,0,0,1)|0;ib=G;ta=fb+32|0;cb=c[ta+4>>2]|0;if(!(ib>>>0<cb>>>0|ib>>>0==cb>>>0&yb>>>0<(c[ta>>2]|0)>>>0)){break}}ta=c[Wa+20>>2]|0;yb=(ta|0)<0|0?-1:0;cb=Wa+64|0;ib=c[cb+4>>2]|0;if((yb|0)<(ib|0)|(yb|0)==(ib|0)&ta>>>0<(c[cb>>2]|0)>>>0){break q}if((c[(c[Vb>>2]|0)+24>>2]|0)==0){break}cb=fb+8|0;ta=0;do{ib=c[(c[1366870]|0)+((c[cb>>2]|0)+ta<<2)>>2]|0;yb=c[(c[1366872]|0)+(c[ib>>2]<<2)>>2]|0;Da=ib+344|0;c[Da>>2]=c[Da>>2]|1;if((c[yb+40>>2]|0)!=0){Da=ib+32|0;Qb=ib+40|0;Sb=xrc(c[Da>>2]|0,c[Da+4>>2]|0,c[Qb>>2]|0,c[Qb+4>>2]|0)|0;Qb=(c[(c[ib+12>>2]|0)+8>>2]|0)+104|0;c[Nc>>2]=1;c[Pc>>2]=1e6;ib=XIb(Sb,G,Qb,Y)|0;Qb=G;Sb=yb+16|0;yb=c[Sb>>2]|0;Da=c[Sb+4>>2]|0;sa=(Da|0)>(Qb|0)|(Da|0)==(Qb|0)&yb>>>0>ib>>>0;c[Sb>>2]=sa?ib:yb;c[Sb+4>>2]=sa?Qb:Da}ta=ta+1|0;}while(ta>>>0<(c[(c[Vb>>2]|0)+24>>2]|0)>>>0)}}while(0);Vb=ld+1|0;if((Vb|0)<(c[1371156]|0)){ld=Vb}else{Za=394;break m}}Vb=c[1371156]|0;r:do{if((Vb|0)>0){fb=0;Wa=2147483647;ta=-1;cb=0;while(1){Da=c[(c[1366870]|0)+(cb<<2)>>2]|0;Qb=c[Da+12>>2]|0;sa=Qb+208|0;Sb=c[sa>>2]|0;yb=c[sa+4>>2]|0;c[za>>2]=1;c[$c>>2]=1e6;sa=XIb(Sb,yb,Qb+40|0,X)|0;Qb=G;if((c[Da+348>>2]|0)==0){yb=(c[Da+344>>2]|0)==0&((Qb|0)<(Wa|0)|(Qb|0)==(Wa|0)&sa>>>0<ta>>>0);md=yb?Qb:Wa;nd=yb?sa:ta;od=yb?Da:fb}else{md=Wa;nd=ta;od=fb}Da=cb+1|0;rd=c[1371156]|0;if((Da|0)<(rd|0)){fb=od;Wa=md;ta=nd;cb=Da}else{break}}if((od|0)==0){sd=rd;Za=400;break}cb=c[od+300>>2]|0;s:do{if((cb|0)==0){ta=c[od+8>>2]|0;if(!((ta|0)>-1)){Za=432;break m}td=c[(c[1475748]|0)+(ta<<2)>>2]|0;Za=434}else{ta=c[cb+8>>2]|0;Wa=Bj(c[ta+8>>2]|0)|0;t:do{if((Wa|0)>-1){ud=Xh()|0}else{if((Wa|0)==(-541478725|0)){fb=Xh()|0;Da=ta+28|0;if((c[Da>>2]|0)<=0){ud=fb;break}yb=ta+24|0;sa=0;while(1){Qb=c[(c[(c[yb>>2]|0)+(sa<<2)>>2]|0)+4>>2]|0;Sb=c[(c[1366872]|0)+(c[Qb>>2]<<2)>>2]|0;ib=Qb+344|0;c[ib>>2]=c[ib>>2]|1;if((c[Sb+40>>2]|0)!=0){ib=Qb+32|0;ra=Qb+40|0;Ca=xrc(c[ib>>2]|0,c[ib+4>>2]|0,c[ra>>2]|0,c[ra+4>>2]|0)|0;ra=(c[(c[Qb+12>>2]|0)+8>>2]|0)+104|0;c[hc>>2]=1;c[la>>2]=1e6;Qb=XIb(Ca,G,ra,j)|0;ra=G;Ca=Sb+16|0;Sb=c[Ca>>2]|0;ib=c[Ca+4>>2]|0;Ob=(ib|0)>(ra|0)|(ib|0)==(ra|0)&Sb>>>0>Qb>>>0;c[Ca>>2]=Ob?Qb:Sb;c[Ca+4>>2]=Ob?ra:ib}ib=sa+1|0;if((ib|0)<(c[Da>>2]|0)){sa=ib}else{ud=fb;break t}}}else if((Wa|0)!=(-11|0)){vd=Wa;break s}fb=ta+20|0;sa=c[fb>>2]|0;if((sa|0)>0){Da=ta+16|0;yb=0;ib=0;ra=0;Ob=sa;while(1){sa=c[(c[Da>>2]|0)+(ib<<2)>>2]|0;Ca=c[sa+4>>2]|0;Sb=c[(c[1475750]|0)+(c[Ca>>2]<<2)>>2]|0;do{if((c[Sb+8>>2]|0)==0){if((c[Sb+4>>2]|0)!=0){wd=yb;xd=ra;yd=Ob;break}Qb=Uj(c[sa>>2]|0)|0;Jb=(Qb|0)>(yb|0);wd=Jb?Qb:yb;xd=Jb?Ca:ra;yd=c[fb>>2]|0}else{wd=yb;xd=ra;yd=Ob}}while(0);Ca=ib+1|0;if((Ca|0)<(yd|0)){yb=wd;ib=Ca;ra=xd;Ob=yd}else{break}}if((xd|0)!=0){td=xd;Za=434;break s}}Ob=ta+28|0;if((c[Ob>>2]|0)<=0){Za=611;break r}ra=c[ta+24>>2]|0;ib=0;while(1){c[(c[(c[ra+(ib<<2)>>2]|0)+4>>2]|0)+348>>2]=1;yb=ib+1|0;if((yb|0)<(c[Ob>>2]|0)){ib=yb}else{Za=611;break r}}}}while(0);zd=(ud|0)<0?ud:0;Za=608}}while(0);do{if((Za|0)==434){Za=0;cb=td|0;ta=c[cb>>2]|0;Wa=c[(c[1475750]|0)+(ta<<2)>>2]|0;ib=Wa|0;Ob=c[ib>>2]|0;u:do{if((c[Wa+64>>2]|0)==0){Ad=Ob;Za=439}else{ra=Wa+56|0;yb=Wa+12|0;fb=0;while(1){if((fb|0)>=(c[ra>>2]|0)){break}Da=c[(c[1475748]|0)+((c[yb>>2]|0)+fb<<2)>>2]|0;Ca=Da+48|0;sa=VIb(c[Ca>>2]|0,c[Ca+4>>2]|0,1e6,0,1e6,0)|0;Ca=G;Sb=jLb()|0;Jb=Da+32|0;Da=xrc(Sb,G,c[Jb>>2]|0,c[Jb+4>>2]|0)|0;Jb=G;if((Ca|0)>(Jb|0)|(Ca|0)==(Jb|0)&sa>>>0>Da>>>0){Za=440;break u}else{fb=fb+1|0}}Ad=c[ib>>2]|0;Za=439}}while(0);v:do{if((Za|0)==439){Za=0;ib=uX(Ad,m)|0;if((ib|0)==-11){Za=440;break}if((ib|0)<0){do{if(!((ib|0)==-541478725)){$f(Ob+32|0,ib);if((c[2244126]|0)==0){break}Hf(1)}}while(0);c[Wa+4>>2]=1;ib=Wa+56|0;if((c[ib>>2]|0)<=0){Cd=-11;break}fb=Wa+12|0;yb=0;while(1){ra=c[(c[1475748]|0)+((c[fb>>2]|0)+yb<<2)>>2]|0;if((c[ra+12>>2]|0)!=0){Sh(ra,0)|0}if((c[1371156]|0)>0){ra=0;do{Da=c[(c[1366870]|0)+(ra<<2)>>2]|0;do{if((c[Da+8>>2]|0)==((c[fb>>2]|0)+yb|0)){if((c[Da+352>>2]|0)==0){if((c[(c[Da+60>>2]|0)+8>>2]|0)!=3){break}}sa=c[(c[1366872]|0)+(c[Da>>2]<<2)>>2]|0;Jb=Da+344|0;c[Jb>>2]=c[Jb>>2]|1;if((c[sa+40>>2]|0)==0){break}Jb=Da+32|0;Ca=Da+40|0;Sb=xrc(c[Jb>>2]|0,c[Jb+4>>2]|0,c[Ca>>2]|0,c[Ca+4>>2]|0)|0;Ca=(c[(c[Da+12>>2]|0)+8>>2]|0)+104|0;c[Lc>>2]=1;c[Ic>>2]=1e6;Jb=XIb(Sb,G,Ca,l)|0;Ca=G;Sb=sa+16|0;sa=c[Sb>>2]|0;Qb=c[Sb+4>>2]|0;Ib=(Qb|0)>(Ca|0)|(Qb|0)==(Ca|0)&sa>>>0>Jb>>>0;c[Sb>>2]=Ib?Jb:sa;c[Sb+4>>2]=Ib?Ca:Qb}}while(0);ra=ra+1|0;}while((ra|0)<(c[1371156]|0))}ra=yb+1|0;if((ra|0)<(c[ib>>2]|0)){yb=ra}else{Cd=-11;break v}}}if((c[1371162]|0)>0){yb=c[1475750]|0;ib=0;do{c[(c[yb+(ib<<2)>>2]|0)+8>>2]=0;ib=ib+1|0;}while((ib|0)<(c[1371162]|0))}if((c[1371156]|0)>0){ib=c[1366870]|0;yb=0;do{c[(c[ib+(yb<<2)>>2]|0)+348>>2]=0;yb=yb+1|0;}while((yb|0)<(c[1371156]|0))}if((c[2333748]|0)!=0){jY(0,48,m,c[2333750]|0,c[(c[Ob+28>>2]|0)+(c[Hc>>2]<<2)>>2]|0)}yb=c[Hc>>2]|0;do{if((yb|0)<(c[Wa+56>>2]|0)){ib=Wa+12|0;fb=(c[ib>>2]|0)+yb|0;ra=c[(c[1475748]|0)+(fb<<2)>>2]|0;if((c[ra+8>>2]|0)!=0){break}if((c[2369570]|0)!=0){Da=ra+4|0;Qb=ALb(c[(c[(c[Da>>2]|0)+8>>2]|0)+8>>2]|0)|0;mrc(_c|0,0,32)|0;a[_c]=0;Ca=ra+40|0;Ib=c[Ca>>2]|0;Sb=c[Ca+4>>2]|0;if((Ib|0)==0&(Sb|0)==(-2147483648|0)){Rb(_c|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(_c|0,32,2319576,(_a=i,i=i+16|0,c[_a>>2]=Ib,c[_a+8>>2]=Sb,_a)|0)|0;i=_a}mrc(Zc|0,0,32)|0;a[Zc]=0;Sb=c[Ca>>2]|0;Ib=c[Ca+4>>2]|0;if((Sb|0)==0&(Ib|0)==(-2147483648|0)){Rb(Zc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Zc|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Sb>>>0)+ +(Ib|0)*4294967296.0)*1.0e-6,_a)|0)|0;i=_a}mrc(Yc|0,0,32)|0;a[Yc]=0;Ib=ra+56|0;Sb=c[Ib>>2]|0;Ca=c[Ib+4>>2]|0;if((Sb|0)==0&(Ca|0)==(-2147483648|0)){Rb(Yc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Yc|0,32,2319576,(_a=i,i=i+16|0,c[_a>>2]=Sb,c[_a+8>>2]=Ca,_a)|0)|0;i=_a}mrc(Wc|0,0,32)|0;a[Wc]=0;Ca=c[Ib>>2]|0;Sb=c[Ib+4>>2]|0;if((Ca|0)==0&(Sb|0)==(-2147483648|0)){Rb(Wc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Wc|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Ca>>>0)+ +(Sb|0)*4294967296.0)*1.0e-6,_a)|0)|0;i=_a}mrc(Xc|0,0,32)|0;a[Xc]=0;Sb=c[Ec>>2]|0;Ca=c[Ec+4>>2]|0;if((Sb|0)==0&(Ca|0)==(-2147483648|0)){Rb(Xc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Xc|0,32,2319576,(_a=i,i=i+16|0,c[_a>>2]=Sb,c[_a+8>>2]=Ca,_a)|0)|0;i=_a}mrc(Rc|0,0,32)|0;a[Rc]=0;Ca=c[Ec>>2]|0;Sb=c[Ec+4>>2]|0;Ib=c[Da>>2]|0;if((Ca|0)==0&(Sb|0)==(-2147483648|0)){Rb(Rc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Rc|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Ca>>>0)+ +(Sb|0)*4294967296.0)*(+(c[Ib+40>>2]|0)/+(c[Ib+44>>2]|0)),_a)|0)|0;i=_a}mrc(Sc|0,0,32)|0;a[Sc]=0;Ib=c[db>>2]|0;Sb=c[db+4>>2]|0;if((Ib|0)==0&(Sb|0)==(-2147483648|0)){Rb(Sc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Sc|0,32,2319576,(_a=i,i=i+16|0,c[_a>>2]=Ib,c[_a+8>>2]=Sb,_a)|0)|0;i=_a}mrc(Vc|0,0,32)|0;a[Vc]=0;Sb=c[db>>2]|0;Ib=c[db+4>>2]|0;Ca=c[Da>>2]|0;if((Sb|0)==0&(Ib|0)==(-2147483648|0)){Rb(Vc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Vc|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Sb>>>0)+ +(Ib|0)*4294967296.0)*(+(c[Ca+40>>2]|0)/+(c[Ca+44>>2]|0)),_a)|0)|0;i=_a}mrc(Uc|0,0,32)|0;a[Uc]=0;Ca=ra|0;Ib=(c[(c[1475750]|0)+(c[Ca>>2]<<2)>>2]|0)+24|0;Sb=c[Ib>>2]|0;Da=c[Ib+4>>2]|0;if((Sb|0)==0&(Da|0)==(-2147483648|0)){Rb(Uc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Uc|0,32,2319576,(_a=i,i=i+16|0,c[_a>>2]=Sb,c[_a+8>>2]=Da,_a)|0)|0;i=_a}mrc(Dc|0,0,32)|0;a[Dc]=0;Da=(c[(c[1475750]|0)+(c[Ca>>2]<<2)>>2]|0)+24|0;Ca=c[Da>>2]|0;Sb=c[Da+4>>2]|0;if((Ca|0)==0&(Sb|0)==(-2147483648|0)){Rb(Dc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Dc|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Ca>>>0)+ +(Sb|0)*4294967296.0)*1.0e-6,_a)|0)|0;i=_a}KIb(0,32,2615576,(_a=i,i=i+96|0,c[_a>>2]=fb,c[_a+8>>2]=Qb,c[_a+16>>2]=_c,c[_a+24>>2]=Zc,c[_a+32>>2]=Yc,c[_a+40>>2]=Wc,c[_a+48>>2]=Xc,c[_a+56>>2]=Rc,c[_a+64>>2]=Sc,c[_a+72>>2]=Vc,c[_a+80>>2]=Uc,c[_a+88>>2]=Dc,_a)|0);i=_a}Qb=ra+72|0;do{if((c[Qb>>2]|0)==0){fb=Ob+1056|0;Sb=c[fb>>2]|0;Ca=c[fb+4>>2]|0;if((Sb|0)==0&(Ca|0)==(-2147483648|0)){break}Da=ra+4|0;if((c[(c[Da>>2]|0)+188>>2]|0)>=64){break}Ib=ra+40|0;do{if((c[Ib>>2]|0)==0&(c[Ib+4>>2]|0)==(-2147483648|0)){sa=Wa+24|0;Jb=c[sa>>2]|0;Lb=c[sa+4>>2]|0;Kb=xrc(0,0,Sb,Ca)|0;if(!((Jb|0)==(Kb|0)&(Lb|0)==(G|0))){Dd=Ca;Ed=Sb;break}if((c[(c[Ob+4>>2]|0)+8>>2]&512|0)==0){Dd=Ca;Ed=Sb;break}Lb=Ob+24|0;if((c[Lb>>2]|0)==0){Fd=2147483647;Gd=-1;Jd=Ca;Kd=Sb}else{Kb=Ob+28|0;Jb=2147483647;Mb=-1;Nb=0;while(1){Hb=c[(c[Kb>>2]|0)+(Nb<<2)>>2]|0;do{if((c[Hb+76>>2]|0)==48){Ld=Jb;Md=Mb}else{Gb=Hb+48|0;Ab=c[Gb>>2]|0;Eb=c[Gb+4>>2]|0;if((Ab|0)==0&(Eb|0)==(-2147483648|0)){Ld=Jb;Md=Mb;break}Fb=Hb+40|0;c[Gc>>2]=1;c[Xa>>2]=1e6;qa=XIb(Ab,Eb,Fb,A)|0;Eb=G;if(!((Jb|0)>(Eb|0)|(Jb|0)==(Eb|0)&Mb>>>0>qa>>>0)){Ld=Jb;Md=Mb;break}qa=c[Gb>>2]|0;Eb=c[Gb+4>>2]|0;c[ac>>2]=1;c[$b>>2]=1e6;Gb=XIb(qa,Eb,Fb,B)|0;Ld=G;Md=Gb}}while(0);Hb=Nb+1|0;if(Hb>>>0<(c[Lb>>2]|0)>>>0){Jb=Ld;Mb=Md;Nb=Hb}else{break}}Fd=Ld;Gd=Md;Jd=c[fb+4>>2]|0;Kd=c[fb>>2]|0}if(!((Fd|0)>(Jd|0)|(Fd|0)==(Jd|0)&Gd>>>0>Kd>>>0)){Dd=Jd;Ed=Kd;break}Nb=xrc(Gd,Fd,Kd,Jd)|0;Mb=G;KIb(Ob,40,2609880,(_a=i,i=i+16|0,c[_a>>2]=Nb,c[_a+8>>2]=Mb,_a)|0);i=_a;Mb=xrc(0,0,Gd,Fd)|0;c[sa>>2]=Mb;c[sa+4>>2]=G;Dd=c[fb+4>>2]|0;Ed=c[fb>>2]|0}else{Dd=Ca;Ed=Sb}}while(0);c[ab>>2]=1;c[bb>>2]=1e6;Sb=XIb(Ed,Dd,C,(c[Da>>2]|0)+40|0)|0;Ca=G;fb=(c[Da>>2]|0)+188|0;Ib=yrc(1,0,c[fb>>2]|0)|0;Mb=wrc(Ib,G,Sb,Ca)|0;Ib=G;c[Qb>>2]=1;if(!((Ib|0)>(Ca|0)|(Ib|0)==(Ca|0)&Mb>>>0>Sb>>>0)){break}Mb=c[db>>2]|0;Ib=c[db+4>>2]|0;do{if(!((Mb|0)==0&(Ib|0)==(-2147483648|0))){Nb=c[fb>>2]|0;Jb=yrc(1,0,Nb-1|0)|0;Lb=wrc(Jb,G,Sb,Ca)|0;Jb=G;if(!((Ib|0)>(Jb|0)|(Ib|0)==(Jb|0)&Mb>>>0>Lb>>>0)){break}Lb=yrc(1,0,Nb|0)|0;Nb=xrc(Mb,Ib,Lb,G)|0;c[db>>2]=Nb;c[db+4>>2]=G;c[Qb>>2]=0}}while(0);Ib=c[Ec>>2]|0;Mb=c[Ec+4>>2]|0;if((Ib|0)==0&(Mb|0)==(-2147483648|0)){break}Da=c[fb>>2]|0;Nb=yrc(1,0,Da-1|0)|0;Lb=wrc(Nb,G,Sb,Ca)|0;Nb=G;if(!((Mb|0)>(Nb|0)|(Mb|0)==(Nb|0)&Ib>>>0>Lb>>>0)){break}Lb=yrc(1,0,Da|0)|0;Da=xrc(Ib,Mb,Lb,G)|0;c[Ec>>2]=Da;c[Ec+4>>2]=G;c[Qb>>2]=0}}while(0);if(!((c[db>>2]|0)==0&(c[db+4>>2]|0)==(-2147483648|0))){Qb=Wa+24|0;Da=c[Qb>>2]|0;Lb=c[Qb+4>>2]|0;c[nc>>2]=1;c[cc>>2]=1e6;Qb=XIb(Da,Lb,D,(c[ra+4>>2]|0)+40|0)|0;Lb=wrc(c[db>>2]|0,c[db+4>>2]|0,Qb,G)|0;c[db>>2]=Lb;c[db+4>>2]=G}do{if(!((c[Ec>>2]|0)==0&(c[Ec+4>>2]|0)==(-2147483648|0))){Lb=Wa+24|0;Qb=c[Lb>>2]|0;Da=c[Lb+4>>2]|0;c[lc>>2]=1;c[mc>>2]=1e6;Lb=XIb(Qb,Da,E,(c[ra+4>>2]|0)+40|0)|0;Da=wrc(c[Ec>>2]|0,c[Ec+4>>2]|0,Lb,G)|0;Lb=G;c[Ec>>2]=Da;c[Ec+4>>2]=Lb;if((Da|0)==0&(Lb|0)==(-2147483648|0)){break}Db=(+(Da>>>0)+ +(Lb|0)*4294967296.0)*+h[ra+88>>3];Lb=(F=+Db,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[Ec>>2]=~~+Db>>>0;c[Ec+4>>2]=Lb}}while(0);Lb=c[db>>2]|0;Da=c[db+4>>2]|0;do{if((Lb|0)==0&(Da|0)==(-2147483648|0)){Za=542}else{Db=(+(Lb>>>0)+ +(Da|0)*4294967296.0)*+h[ra+88>>3];Qb=~~+Db>>>0;Mb=(F=+Db,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[db>>2]=Qb;c[db+4>>2]=Mb;if((Qb|0)==0&(Mb|0)==(-2147483648|0)){Za=561;break}Ib=ra+40|0;if((c[Ib>>2]|0)!=0|(c[Ib+4>>2]|0)!=(-2147483648|0)|(c[2448288]|0)!=0){Za=542;break}if((c[(c[Ob+4>>2]|0)+8>>2]&512|0)==0){Za=542;break}Ib=Wa+32|0;if((c[Ib>>2]|0)==0&(c[Ib+4>>2]|0)==(-2147483648|0)){Za=542;break}Nb=ra+4|0;Jb=(c[Nb>>2]|0)+40|0;c[xa>>2]=1;c[ya>>2]=1e6;Kb=XIb(Qb,Mb,Jb,H)|0;Jb=xrc(Kb,G,c[Ib>>2]|0,c[Ib+4>>2]|0)|0;Ib=G;Db=+(Jb>>>0)+ +(Ib|0)*4294967296.0;zb=+g[379636];if(!(Db<zb*-1.0*1.0e6)){if(!(Db>zb*1.0e6)){Za=542;break}if((c[(c[(c[Nb>>2]|0)+8>>2]|0)+8>>2]|0)==3){Za=542;break}}Kb=Wa+24|0;Mb=xrc(c[Kb>>2]|0,c[Kb+4>>2]|0,Jb,Ib)|0;Qb=G;c[Kb>>2]=Mb;c[Kb+4>>2]=Qb;KIb(0,48,2607264,(_a=i,i=i+32|0,c[_a>>2]=Jb,c[_a+8>>2]=Ib,c[_a+16>>2]=Mb,c[_a+24>>2]=Qb,_a)|0);i=_a;c[Tb>>2]=1;c[uc>>2]=1e6;Qb=XIb(Jb,Ib,I,(c[Nb>>2]|0)+40|0)|0;Mb=xrc(c[db>>2]|0,c[db+4>>2]|0,Qb,G)|0;Qb=G;c[db>>2]=Mb;c[db+4>>2]=Qb;if((c[Ec>>2]|0)==0&(c[Ec+4>>2]|0)==(-2147483648|0)){Nd=Qb;Od=Mb;Za=543;break}c[tc>>2]=1;c[sc>>2]=1e6;Mb=XIb(Jb,Ib,J,(c[Nb>>2]|0)+40|0)|0;Nb=xrc(c[Ec>>2]|0,c[Ec+4>>2]|0,Mb,G)|0;c[Ec>>2]=Nb;c[Ec+4>>2]=G;Za=542}}while(0);if((Za|0)==542){Za=0;Nd=c[db+4>>2]|0;Od=c[db>>2]|0;Za=543}w:do{if((Za|0)==543){Za=0;if((Od|0)==0&(Nd|0)==(-2147483648|0)){Za=561;break}Da=ra+40|0;if((c[Da>>2]|0)==0&(c[Da+4>>2]|0)==(-2147483648|0)|(c[2448288]|0)!=0){Za=561;break}Lb=ra+4|0;Nb=(c[Lb>>2]|0)+40|0;c[Ac>>2]=1;c[Bc>>2]=1e6;Mb=XIb(Od,Nd,Nb,K)|0;Nb=G;Ib=c[Da>>2]|0;Jb=c[Da+4>>2]|0;Qb=xrc(Mb,Nb,Ib,Jb)|0;Kb=G;zb=+(Qb>>>0)+ +(Kb|0)*4294967296.0;if((c[(c[Ob+4>>2]|0)+8>>2]&512|0)!=0){Db=+g[379636];do{if(!(zb<Db*-1.0*1.0e6)){if(zb>Db*1.0e6){if((c[(c[(c[Lb>>2]|0)+8>>2]|0)+8>>2]|0)!=3){break}}Hb=wrc(Mb,Nb,1e5,0)|0;Gb=G;Fb=ra+64|0;Eb=c[Fb>>2]|0;qa=c[Fb+4>>2]|0;Fb=ra+48|0;Ab=c[Fb>>2]|0;hb=c[Fb+4>>2]|0;Fb=(qa|0)>(hb|0)|(qa|0)==(hb|0)&Eb>>>0>Ab>>>0;lb=Fb?qa:hb;if(!((Gb|0)<(lb|0)|(Gb|0)==(lb|0)&Hb>>>0<(Fb?Eb:Ab)>>>0)){Za=561;break w}}}while(0);Nb=Wa+24|0;Mb=xrc(c[Nb>>2]|0,c[Nb+4>>2]|0,Qb,Kb)|0;Ca=G;c[Nb>>2]=Mb;c[Nb+4>>2]=Ca;KIb(0,48,2604856,(_a=i,i=i+32|0,c[_a>>2]=Qb,c[_a+8>>2]=Kb,c[_a+16>>2]=Mb,c[_a+24>>2]=Ca,_a)|0);i=_a;c[Fc>>2]=1;c[Pb>>2]=1e6;Ca=XIb(Qb,Kb,L,(c[Lb>>2]|0)+40|0)|0;Mb=xrc(c[db>>2]|0,c[db+4>>2]|0,Ca,G)|0;Ca=G;c[db>>2]=Mb;c[db+4>>2]=Ca;if((c[Ec>>2]|0)==0&(c[Ec+4>>2]|0)==(-2147483648|0)){Pd=Ca;Qd=Mb;break}c[wc>>2]=1;c[Ub>>2]=1e6;Mb=XIb(Qb,Kb,M,(c[Lb>>2]|0)+40|0)|0;Ca=xrc(c[Ec>>2]|0,c[Ec+4>>2]|0,Mb,G)|0;c[Ec>>2]=Ca;c[Ec+4>>2]=G;Za=561;break}Db=+g[379634];do{if(zb<Db*-1.0*1.0e6){Za=555}else{if(!(zb>Db*1.0e6)){break}if((c[(c[(c[Lb>>2]|0)+8>>2]|0)+8>>2]|0)!=3){Za=555}}}while(0);if((Za|0)==555){Za=0;Kb=c[db+4>>2]|0;Qb=c[Hc>>2]|0;KIb(0,24,2602712,(_a=i,i=i+40|0,c[_a>>2]=c[db>>2],c[_a+8>>2]=Kb,c[_a+16>>2]=Ib,c[_a+24>>2]=Jb,c[_a+32>>2]=Qb,_a)|0);i=_a;c[db>>2]=0;c[db+4>>2]=-2147483648}Qb=c[Ec>>2]|0;Kb=c[Ec+4>>2]|0;if((Qb|0)==0&(Kb|0)==(-2147483648|0)){Za=561;break}Ca=(c[Lb>>2]|0)+40|0;c[yc>>2]=1;c[xc>>2]=1e6;Mb=XIb(Qb,Kb,Ca,N)|0;Ca=c[Da>>2]|0;Kb=c[Da+4>>2]|0;Qb=xrc(Mb,G,Ca,Kb)|0;Db=+(Qb>>>0)+ +(G|0)*4294967296.0;zb=+g[379634];if(!(Db<zb*-1.0*1.0e6)){if(!(Db>zb*1.0e6)){Za=561;break}if((c[(c[(c[Lb>>2]|0)+8>>2]|0)+8>>2]|0)==3){Za=561;break}}Qb=c[Ec+4>>2]|0;Mb=c[Hc>>2]|0;KIb(0,24,2600704,(_a=i,i=i+40|0,c[_a>>2]=c[Ec>>2],c[_a+8>>2]=Qb,c[_a+16>>2]=Ca,c[_a+24>>2]=Kb,c[_a+32>>2]=Mb,_a)|0);i=_a;c[Ec>>2]=0;c[Ec+4>>2]=-2147483648;Za=561}}while(0);if((Za|0)==561){Za=0;Pd=c[db+4>>2]|0;Qd=c[db>>2]|0}if(!((Qd|0)==0&(Pd|0)==(-2147483648|0))){Mb=(c[ra+4>>2]|0)+40|0;c[Aa>>2]=1;c[vc>>2]=1e6;Kb=XIb(Qd,Pd,Mb,O)|0;Mb=Wa+32|0;c[Mb>>2]=Kb;c[Mb+4>>2]=G}if((c[2369570]|0)==0){Rd=ra|0}else{Mb=(c[Hc>>2]|0)+(c[ib>>2]|0)|0;Kb=ra+4|0;Ca=ALb(c[(c[(c[Kb>>2]|0)+8>>2]|0)+8>>2]|0)|0;mrc(Cc|0,0,32)|0;a[Cc]=0;Qb=c[Ec>>2]|0;Nb=c[Ec+4>>2]|0;if((Qb|0)==0&(Nb|0)==(-2147483648|0)){Rb(Cc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Cc|0,32,2319576,(_a=i,i=i+16|0,c[_a>>2]=Qb,c[_a+8>>2]=Nb,_a)|0)|0;i=_a}mrc(Ba|0,0,32)|0;a[Ba]=0;Nb=c[Ec>>2]|0;Qb=c[Ec+4>>2]|0;Sb=c[Kb>>2]|0;if((Nb|0)==0&(Qb|0)==(-2147483648|0)){Rb(Ba|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Ba|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Nb>>>0)+ +(Qb|0)*4294967296.0)*(+(c[Sb+40>>2]|0)/+(c[Sb+44>>2]|0)),_a)|0)|0;i=_a}mrc(Qc|0,0,32)|0;a[Qc]=0;Sb=c[db>>2]|0;Qb=c[db+4>>2]|0;if((Sb|0)==0&(Qb|0)==(-2147483648|0)){Rb(Qc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Qc|0,32,2319576,(_a=i,i=i+16|0,c[_a>>2]=Sb,c[_a+8>>2]=Qb,_a)|0)|0;i=_a}mrc(Jc|0,0,32)|0;a[Jc]=0;Qb=c[db>>2]|0;Sb=c[db+4>>2]|0;Nb=c[Kb>>2]|0;if((Qb|0)==0&(Sb|0)==(-2147483648|0)){Rb(Jc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Jc|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Qb>>>0)+ +(Sb|0)*4294967296.0)*(+(c[Nb+40>>2]|0)/+(c[Nb+44>>2]|0)),_a)|0)|0;i=_a}mrc(Mc|0,0,32)|0;a[Mc]=0;Nb=ra|0;Sb=(c[(c[1475750]|0)+(c[Nb>>2]<<2)>>2]|0)+24|0;Qb=c[Sb>>2]|0;Kb=c[Sb+4>>2]|0;if((Qb|0)==0&(Kb|0)==(-2147483648|0)){Rb(Mc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(Mc|0,32,2319576,(_a=i,i=i+16|0,c[_a>>2]=Qb,c[_a+8>>2]=Kb,_a)|0)|0;i=_a}mrc(zc|0,0,32)|0;a[zc]=0;Kb=(c[(c[1475750]|0)+(c[Nb>>2]<<2)>>2]|0)+24|0;Qb=c[Kb>>2]|0;Sb=c[Kb+4>>2]|0;if((Qb|0)==0&(Sb|0)==(-2147483648|0)){Rb(zc|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(zc|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Qb>>>0)+ +(Sb|0)*4294967296.0)*1.0e-6,_a)|0)|0;i=_a}KIb(0,32,2598888,(_a=i,i=i+64|0,c[_a>>2]=Mb,c[_a+8>>2]=Ca,c[_a+16>>2]=Cc,c[_a+24>>2]=Ba,c[_a+32>>2]=Qc,c[_a+40>>2]=Jc,c[_a+48>>2]=Mc,c[_a+56>>2]=zc,_a)|0);i=_a;Rd=Nb}Nb=c[Ec>>2]|0;Ca=c[Ec+4>>2]|0;Mb=c[(c[1475750]|0)+(c[Rd>>2]<<2)>>2]|0;Sb=Mb+56|0;if((c[Sb>>2]|0)>0){Qb=Mb+12|0;Mb=ra+4|0;Kb=0;do{fb=c[(c[1475748]|0)+((c[Qb>>2]|0)+Kb<<2)>>2]|0;Ab=fb+224|0;do{if((c[Ab>>2]|0)!=0){Eb=XIb(Nb,Ca,(c[Mb>>2]|0)+40|0,(c[fb+4>>2]|0)+40|0)|0;Fb=wrc(Eb,G,-1,-1)|0;Eb=G;Hb=fb+208|0;lb=c[Hb+4>>2]|0;if(!((Eb|0)>(lb|0)|(Eb|0)==(lb|0)&Fb>>>0>(c[Hb>>2]|0)>>>0)){break}lb=fb+216|0;Gb=c[lb+4>>2]|0;if((Eb|0)<(Gb|0)|(Eb|0)==(Gb|0)&Fb>>>0<(c[lb>>2]|0)>>>0){if((c[c[Ab>>2]>>2]|0)==0){Za=591}}else{Za=591}if((Za|0)==591){Za=0;Wh(fb,0)}lb=fb+248|0;if((c[lb>>2]|0)<=0){break}Gb=fb+244|0;hb=0;qa=0;do{hb=(Uj(c[c[(c[Gb>>2]|0)+(qa<<2)>>2]>>2]|0)|0)+hb|0;qa=qa+1|0;Sd=c[lb>>2]|0;}while((qa|0)<(Sd|0));if((hb|0)==0){break}qa=c[Ab>>2]|0;sa=qa+136|0;c[sa>>2]=Fb;c[sa+4>>2]=Eb;c[Hb>>2]=Fb;c[Hb+4>>2]=Eb;if((Sd|0)>0){Td=0}else{break}do{Pj(c[c[(c[Gb>>2]|0)+(Td<<2)>>2]>>2]|0,qa,12)|0;Td=Td+1|0;}while((Td|0)<(c[lb>>2]|0))}}while(0);Kb=Kb+1|0;}while((Kb|0)<(c[Sb>>2]|0))}Sb=Sh(ra,m)|0;if((Sb|0)>=0){break}Kb=c[Rd>>2]|0;Mb=c[c[ra+4>>2]>>2]|0;mrc(Kc|0,0,64)|0;a[Kc]=0;RGb(Sb,Kc,64)|0;KIb(0,16,2597160,(_a=i,i=i+24|0,c[_a>>2]=Kb,c[_a+8>>2]=Mb,c[_a+16>>2]=Kc,_a)|0);i=_a;if((c[2244126]|0)==0){break}Hf(1)}else{Mb=c[(c[1475750]|0)+(ta<<2)>>2]|0;Kb=c[Mb>>2]|0;Sb=c[(c[Kb+28>>2]|0)+(yb<<2)>>2]|0;Ca=Mb+60|0;if((yb|0)<(c[Ca>>2]|0)){break}Mb=ALb(c[(c[Sb+8>>2]|0)+8>>2]|0)|0;Nb=c[Hc>>2]|0;Qb=c[ic>>2]|0;ib=c[ic+4>>2]|0;mrc(ma|0,0,32)|0;a[ma]=0;Ab=c[db>>2]|0;fb=c[db+4>>2]|0;if((Ab|0)==0&(fb|0)==(-2147483648|0)){Rb(ma|0,32,2331072,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0)|0;i=_a}else{Rb(ma|0,32,2325104,(_a=i,i=i+8|0,h[_a>>3]=(+(Ab>>>0)+ +(fb|0)*4294967296.0)*(+(c[Sb+40>>2]|0)/+(c[Sb+44>>2]|0)),_a)|0)|0;i=_a}KIb(Kb,24,2594568,(_a=i,i=i+48|0,c[_a>>2]=Mb,c[_a+8>>2]=ta,c[_a+16>>2]=Nb,c[_a+24>>2]=Qb,c[_a+32>>2]=ib,c[_a+40>>2]=ma,_a)|0);i=_a;c[Ca>>2]=(c[Hc>>2]|0)+1}}while(0);P1(m);Cd=0}}while(0);if((Za|0)==440){Za=0;c[Wa+8>>2]=1;Cd=-11}if((Cd|0)==-11){if((c[(c[(c[1475750]|0)+(c[cb>>2]<<2)>>2]|0)+8>>2]|0)==0){Za=611;break r}c[od+348>>2]=1;Za=611;break r}else{if((Cd|0)<0){vd=Cd;break}zd=Xh()|0;Za=608;break}}}while(0);if((Za|0)==608){Za=0;if((zd|0)<0){vd=zd}else{Za=611;break}}if(!((vd|0)==(-11|0)|(vd|0)==(-541478725|0))){Za=610;break m}}else{sd=Vb;Za=400}}while(0);do{if((Za|0)==400){Za=0;Vb=c[1366870]|0;ta=0;while(1){if((ta|0)>=(sd|0)){Za=410;break}if((c[(c[Vb+(ta<<2)>>2]|0)+348>>2]|0)==0){ta=ta+1|0}else{break}}if((Za|0)==410){Za=0;KIb(0,40,2128920,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;break}if((c[1371162]|0)>0){ta=c[1475750]|0;Ob=0;do{c[(c[ta+(Ob<<2)>>2]|0)+8>>2]=0;Ob=Ob+1|0;}while((Ob|0)<(c[1371162]|0));Ud=c[1371156]|0}else{Ud=sd}if((Ud|0)>0){Ob=0;do{c[(c[Vb+(Ob<<2)>>2]|0)+348>>2]=0;Ob=Ob+1|0;}while((Ob|0)<(c[1371156]|0))}kLb(1e4)|0;Za=611}}while(0);if((Za|0)==611){Za=0;Rh(0,pa,oa,ua,Wb)}if((c[1352984]|0)!=0){break l}}if((Za|0)==394){KIb(0,40,2523344,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;break}else if((Za|0)==432){KIb(0,0,2127408,(_a=i,i=i+24|0,c[_a>>2]=2125776,c[_a+8>>2]=2120856,c[_a+16>>2]=3385,_a)|0);i=_a;Hd();return 0}else if((Za|0)==610){KIb(0,16,2508528,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;break}}}while(0);Ta=c[1371160]|0;if((Ta|0)>0){La=0;Ia=Ta;while(1){Ta=c[(c[1475748]|0)+(La<<2)>>2]|0;do{if((c[(c[(c[1475750]|0)+(c[Ta>>2]<<2)>>2]|0)+4>>2]|0)==0){if((c[Ta+12>>2]|0)==0){Vd=Ia;break}Sh(Ta,0)|0;Vd=c[1371160]|0}else{Vd=Ia}}while(0);Ta=La+1|0;if((Ta|0)<(Vd|0)){La=Ta;Ia=Vd}else{break}}}Ia=c[1371156]|0;if((Ia|0)>0){La=e+24|0;Ta=e+28|0;Hc=e+8|0;ma=e+16|0;db=e+48|0;ic=0;Kc=Ia;while(1){Ia=c[(c[1366870]|0)+(ic<<2)>>2]|0;Ec=Ia+12|0;zc=c[(c[Ec>>2]|0)+8>>2]|0;Mc=Ia|0;Jc=c[c[(c[1366872]|0)+(c[Mc>>2]<<2)>>2]>>2]|0;x:do{if((c[Ia+16>>2]|0)==0){Wd=Kc}else{Qc=c[zc+8>>2]|0;do{if((Qc|0)==1){if((c[zc+424>>2]|0)<2){Wd=Kc;break x}}else if((Qc|0)==0){if((c[(c[Jc+8>>2]|0)+28>>2]&32|0)==0){break}if((c[(c[zc+12>>2]|0)+12>>2]|0)==14){Wd=Kc;break x}}}while(0);Wb=Ia+4|0;ua=Ia+296|0;Ba=Ia+344|0;Cc=zc+104|0;vc=zc+668|0;Aa=Qc;while(1){if((Aa|0)==0){Xd=3387920;Zd=2483856;_d=656}else if((Aa|0)==1){Xd=10191776;Zd=2494096;_d=802}else{break}J1(e);c[La>>2]=0;c[Ta>>2]=0;Th(0,(_a=i,i=i+1|0,i=i+7&-8,c[_a>>2]=0,_a)|0);i=_a;xc=hf[_d&1023](zc,e,0,f)|0;yc=c[Mc>>2]|0;Ub=c[Wb>>2]|0;Th(2472656,(_a=i,i=i+24|0,c[_a>>2]=Zd,c[_a+8>>2]=yc,c[_a+16>>2]=Ub,_a)|0);i=_a;if((xc|0)<0){KIb(0,8,2464488,(_a=i,i=i+8|0,c[_a>>2]=Zd,_a)|0);i=_a;Hf(1)}xc=c[ua>>2]|0;do{if((xc|0)!=0){Ub=c[vc>>2]|0;if((Ub|0)==0){break}xb(Ub|0,xc|0)|0}}while(0);if((c[f>>2]|0)==0){break}do{if((c[Ba>>2]&2|0)==0){xc=c[Ta>>2]|0;Ub=wrc(c[Xd>>2]|0,c[Xd+4>>2]|0,xc,(xc|0)<0|0?-1:0)|0;c[Xd>>2]=Ub;c[Xd+4>>2]=G;Ub=c[Hc>>2]|0;xc=c[Hc+4>>2]|0;if(!((Ub|0)==0&(xc|0)==(-2147483648|0))){yc=XIb(Ub,xc,Cc,(c[Ec>>2]|0)+40|0)|0;c[Hc>>2]=yc;c[Hc+4>>2]=G}yc=c[ma>>2]|0;xc=c[ma+4>>2]|0;if(!((yc|0)==0&(xc|0)==(-2147483648|0))){Ub=XIb(yc,xc,Cc,(c[Ec>>2]|0)+40|0)|0;c[ma>>2]=Ub;c[ma+4>>2]=G}Ub=c[db>>2]|0;if((Ub|0)>0){xc=XIb(Ub,(Ub|0)<0|0?-1:0,Cc,(c[Ec>>2]|0)+40|0)|0;c[db>>2]=xc}xc=c[Ta>>2]|0;Uh(Jc,e,Ia);if(!((c[(c[(c[Ec>>2]|0)+8>>2]|0)+8>>2]|0)==0&(c[836152]|0)!=0)){break}Vh(Ia,xc)}else{P1(e)}}while(0);Aa=c[(c[(c[Ec>>2]|0)+8>>2]|0)+8>>2]|0}Wd=c[1371156]|0}}while(0);Ec=ic+1|0;if((Ec|0)<(Wd|0)){ic=Ec;Kc=Wd}else{break}}}KIb(0,-8,2223800,(_a=i,i=i+8|0,c[_a>>2]=10230128,_a)|0);i=_a;if(a[679920]|0){Yd(0,0,5467576)|0}if((c[1371158]|0)>0){Kc=0;do{$O(c[c[(c[1366872]|0)+(Kc<<2)>>2]>>2]|0)|0;Kc=Kc+1|0;}while((Kc|0)<(c[1371158]|0))}Kc=jLb()|0;Rh(1,pa,oa,Kc,G);Kc=c[1371156]|0;if((Kc|0)>0){ic=0;Ta=Kc;while(1){Kc=c[(c[1366870]|0)+(ic<<2)>>2]|0;if((c[Kc+16>>2]|0)==0){$d=Ta}else{db=Kc+12|0;mJb((c[(c[db>>2]|0)+8>>2]|0)+672|0);r5a(c[(c[db>>2]|0)+8>>2]|0)|0;$d=c[1371156]|0}db=ic+1|0;if((db|0)<($d|0)){ic=db;Ta=$d}else{break}}}if((c[1371160]|0)>0){ae=0}else{ad=0;break}while(1){Ta=c[(c[1475748]|0)+(ae<<2)>>2]|0;do{if((c[Ta+12>>2]|0)!=0){ic=Ta+4|0;r5a(c[(c[ic>>2]|0)+8>>2]|0)|0;oa=c[Ta+272>>2]|0;if((oa|0)==0){break}qe[oa&1023](c[(c[ic>>2]|0)+8>>2]|0)}}while(0);Ta=ae+1|0;if((Ta|0)<(c[1371160]|0)){ae=Ta}else{ad=0;break}}}}while(0);ae=c[1366870]|0;if((ae|0)==0){i=b;return ad|0}$d=c[1371156]|0;if(($d|0)>0){be=0;ce=$d;de=ae}else{i=b;return ad|0}while(1){ae=c[de+(be<<2)>>2]|0;if((ae|0)==0){ee=ce}else{if((c[ae+352>>2]|0)!=0){mJb((c[(c[ae+12>>2]|0)+8>>2]|0)+96|0)}$d=ae+296|0;_a=c[$d>>2]|0;if((_a|0)!=0){nb(_a|0)|0;c[$d>>2]=0}mJb((c[(c[ae+12>>2]|0)+8>>2]|0)+860|0);mJb(ae+100|0);mJb(ae+340|0);OGb(ae+328|0);OGb(ae+332|0);OGb(ae+336|0);ee=c[1371156]|0}ae=be+1|0;if((ae|0)>=(ee|0)){break}be=ae;ce=ee;de=c[1366870]|0}i=b;return ad|0}function Rh(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,H=0.0,I=0,J=0.0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0.0,S=0.0,T=0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0,_=0.0,$=0.0,ba=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0.0,ja=0,ka=0,la=0.0;j=i;i=i+2064|0;k=j|0;l=j+1024|0;m=j+2048|0;n=j+2056|0;do{if((c[174890]|0)==0){if((b|0)!=0|(c[1357566]|0)!=0){break}i=j;return}}while(0);o=(b|0)!=0;do{if(!o){p=c[174894]|0;r=c[174895]|0;if((p|0)==(-1|0)&(r|0)==(-1|0)){c[174894]=f;c[174895]=g;i=j;return}s=xrc(f,g,p,r)|0;r=G;p=0;if((r|0)<(p|0)|(r|0)==(p|0)&s>>>0<5e5>>>0){i=j;return}else{c[174894]=f;c[174895]=g;break}}}while(0);s=(c[c[c[1366872]>>2]>>2]|0)+16|0;p=iD(c[s>>2]|0)|0;r=G;t=0;if((r|0)<(t|0)|(r|0)==(t|0)&p>>>0<1>>>0){t=fD(c[s>>2]|0,0,0,1)|0;u=G;v=t}else{u=r;v=p}p=k|0;a[p]=0;SFb(l,0,1);if((c[1371156]|0)>0){r=m|0;t=m+4|0;s=n|0;w=n+4|0;x=xrc(f,g,d,e)|0;y=(+(x>>>0)+ +(G|0)*4294967296.0)/1.0e6;x=y>1.0;e=-2147483648;d=0;g=0;f=0;while(1){z=c[(c[1366870]|0)+(g<<2)>>2]|0;A=z+12|0;B=c[(c[A>>2]|0)+8>>2]|0;do{if((c[z+352>>2]|0)==0){C=c[B+804>>2]|0;if((C|0)==0){D=-1.0;break}D=+(c[C+168>>2]|0)/118.0}else{D=-1.0}}while(0);C=(c[B+8>>2]|0)==0;do{if((f|0)==0){if(!C){E=0;break}F=c[z+20>>2]|0;if(x){H=+(F|0)/y}else{H=0.0}I=lrc(p|0)|0;J=D;Rb(k+I|0,1024-I|0,2212504,(K=i,i=i+32|0,c[K>>2]=F,c[K+8>>2]=H<9.95,h[K+16>>3]=H,h[K+24>>3]=J,K)|0)|0;i=K;UFb(l,2210672,(K=i,i=i+8|0,c[K>>2]=F,K)|0);i=K;UFb(l,2204144,(K=i,i=i+8|0,h[K>>3]=H,K)|0);i=K;I=z|0;L=z+4|0;M=c[L>>2]|0;UFb(l,2215016,(K=i,i=i+24|0,c[K>>2]=c[I>>2],c[K+8>>2]=M,h[K+16>>3]=J,K)|0);i=K;if(o){M=lrc(p|0)|0;Rb(k+M|0,1024-M|0,2196856,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}if((c[1353610]|0)!=0){M=Lc(+D)|0;if((M|0)>-1&M>>>0<52>>>0){N=5430280+(M<<2)|0;c[N>>2]=(c[N>>2]|0)+1;O=0}else{O=0}do{N=lrc(p|0)|0;M=Lc(+(+lc(+(+((c[5430280+(O<<2)>>2]|0)+1|0)))))|0;Rb(k+N|0,1024-N|0,2194128,(K=i,i=i+8|0,c[K>>2]=M,K)|0)|0;i=K;O=O+1|0;}while((O|0)<32)}if((c[B+88>>2]&32768|0)==0){E=1;break}M=B+804|0;if(!((c[M>>2]|0)!=0|o)){E=1;break}N=lrc(p|0)|0;Rb(k+N|0,1024-N|0,2191744,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K;N=B+120|0;P=B+124|0;J=+(F|0);if(o){Q=0;R=0.0;S=0.0;while(1){T=B+720+(Q<<3)|0;U=J*+(ca(c[P>>2]|0,c[N>>2]|0)|0)*255.0*255.0;V=+((c[T>>2]|0)>>>0)+ +((c[T+4>>2]|0)>>>0)*4294967296.0;if((Q|0)==0){W=U}else{W=U*.25}U=R+V;X=S+W;Y=+aa(V/W)*-10.0/2.302585092994046;T=lrc(p|0)|0;Z=a[699568+Q|0]|0;Rb(k+T|0,1024-T|0,2189248,(K=i,i=i+16|0,c[K>>2]=Z,h[K+8>>3]=Y,K)|0)|0;i=K;T=c[L>>2]|0;UFb(l,2186544,(K=i,i=i+32|0,c[K>>2]=c[I>>2],c[K+8>>2]=T,c[K+16>>2]=Z|32,h[K+24>>3]=Y,K)|0);i=K;Z=Q+1|0;if((Z|0)<3){Q=Z;R=U;S=X}else{_=U;$=X;break}}}else{Q=0;S=0.0;R=0.0;while(1){F=(c[M>>2]|0)+224+(Q<<3)|0;J=+(ca(c[P>>2]|0,c[N>>2]|0)|0)*255.0*255.0;X=+((c[F>>2]|0)>>>0)+ +((c[F+4>>2]|0)>>>0)*4294967296.0;if((Q|0)==0){ba=J}else{ba=J*.25}J=S+X;U=R+ba;Y=+aa(X/ba)*-10.0/2.302585092994046;F=lrc(p|0)|0;Z=a[699568+Q|0]|0;Rb(k+F|0,1024-F|0,2189248,(K=i,i=i+16|0,c[K>>2]=Z,h[K+8>>3]=Y,K)|0)|0;i=K;F=c[L>>2]|0;UFb(l,2186544,(K=i,i=i+32|0,c[K>>2]=c[I>>2],c[K+8>>2]=F,c[K+16>>2]=Z|32,h[K+24>>3]=Y,K)|0);i=K;Z=Q+1|0;if((Z|0)<3){Q=Z;S=J;R=U}else{_=J;$=U;break}}}R=+aa(_/$)*-10.0/2.302585092994046;Q=lrc(p|0)|0;Rb(k+Q|0,1024-Q|0,2184160,(K=i,i=i+8|0,h[K>>3]=R,K)|0)|0;i=K;Q=c[L>>2]|0;UFb(l,2182016,(K=i,i=i+24|0,c[K>>2]=c[I>>2],c[K+8>>2]=Q,h[K+16>>3]=R,K)|0);i=K;E=1}else{if(!C){E=f;break}Q=lrc(p|0)|0;R=D;Rb(k+Q|0,1024-Q|0,2217792,(K=i,i=i+8|0,h[K>>3]=R,K)|0)|0;i=K;Q=c[z+4>>2]|0;UFb(l,2215016,(K=i,i=i+24|0,c[K>>2]=c[z>>2],c[K+8>>2]=Q,h[K+16>>3]=R,K)|0);i=K;E=f}}while(0);if(o){da=39}else{if((c[z+344>>2]|0)==0){da=39}else{ea=e;fa=d}}do{if((da|0)==39){da=0;C=c[A>>2]|0;B=C+16|0;Q=c[B>>2]|0;N=c[B+4>>2]|0;if((Q|0)==0&(N|0)==(-2147483648|0)){ea=e;fa=d;break}c[r>>2]=1;c[t>>2]=1e6;B=XIb(Q,N,C+40|0,m)|0;C=G;if((e|0)>(C|0)|(e|0)==(C|0)&d>>>0>B>>>0){ea=e;fa=d;break}B=c[A>>2]|0;C=B+16|0;N=c[C>>2]|0;Q=c[C+4>>2]|0;c[s>>2]=1;c[w>>2]=1e6;C=XIb(N,Q,B+40|0,n)|0;ea=G;fa=C}}while(0);A=g+1|0;if((A|0)<(c[1371156]|0)){e=ea;d=fa;g=A;f=E}else{ga=ea;ha=fa;break}}}else{ga=-2147483648;ha=0}fa=Crc(ha,ga,1e6,0)|0;ea=fa;fa=Drc(ha,ga,1e6,0)|0;E=fa;fa=(ea|0)%60|0;f=(ea|0)/3600|0;g=((ea|0)/60|0|0)%60|0;ea=-1;if(((ha|0)!=0|(ga|0)!=0)&((u|0)>(ea|0)|(u|0)==(ea|0)&v>>>0>-1>>>0)){ia=(+((v<<3|0>>>29)>>>0)+ +(u<<3|v>>>29|0)*4294967296.0)/((+(ha>>>0)+ +(ga|0)*4294967296.0)/1.0e3)}else{ia=-1.0}ea=0;d=(u|0)<(ea|0)|(u|0)==(ea|0)&v>>>0<0>>>0;ea=lrc(p|0)|0;e=k+ea|0;n=1024-ea|0;if(d){Rb(e|0,n|0,2179792,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}else{Rb(e|0,n|0,2178032,(K=i,i=i+8|0,h[K>>3]=(+(v>>>0)+ +(u|0)*4294967296.0)*.0009765625,K)|0)|0;i=K}n=lrc(p|0)|0;Rb(k+n|0,1024-n|0,2172176,(K=i,i=i+32|0,c[K>>2]=f,c[K+8>>2]=g,c[K+16>>2]=fa,c[K+24>>2]=(E*100|0|0)/1e6|0,K)|0)|0;i=K;n=lrc(p|0)|0;e=k+n|0;ea=1024-n|0;if(ia<0.0){Rb(e|0,ea|0,2165328,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}else{Rb(e|0,ea|0,2162992,(K=i,i=i+8|0,h[K>>3]=ia,K)|0)|0;i=K}if(d){UFb(l,2160824,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}else{UFb(l,2159168,(K=i,i=i+16|0,c[K>>2]=v,c[K+8>>2]=u,K)|0);i=K}UFb(l,2157104,(K=i,i=i+16|0,c[K>>2]=ha,c[K+8>>2]=ga,K)|0);i=K;UFb(l,2155296,(K=i,i=i+32|0,c[K>>2]=f,c[K+8>>2]=g,c[K+16>>2]=fa,c[K+24>>2]=E,K)|0);i=K;E=c[1371164]|0;fa=c[1371166]|0;if((fa|E|0)==0){ja=E}else{g=lrc(p|0)|0;Rb(k+g|0,1024-g|0,2153640,(K=i,i=i+16|0,c[K>>2]=E,c[K+8>>2]=fa,K)|0)|0;i=K;ja=c[1371164]|0}UFb(l,2152e3,(K=i,i=i+8|0,c[K>>2]=ja,K)|0);i=K;UFb(l,2149776,(K=i,i=i+8|0,c[K>>2]=c[1371166],K)|0);i=K;ja=c[174890]|0;if((ja|b|0)!=0){do{if((ja|0)==1){if((MIb()|0)>=32){da=60;break}b=c[q>>2]|0;Id(b|0,2144544,(K=i,i=i+8|0,c[K>>2]=p,K)|0)|0;i=K;ka=b}else{da=60}}while(0);if((da|0)==60){KIb(0,32,2144544,(K=i,i=i+8|0,c[K>>2]=p,K)|0);i=K;ka=c[q>>2]|0}qb(ka|0)|0}do{if((c[1357566]|0)==0){if(o){break}i=j;return}else{UFb(l,2139208,(K=i,i=i+8|0,c[K>>2]=o?2137200:2135472,K)|0);i=K;ka=c[l+4>>2]|0;p=(c[l+8>>2]|0)-1|0;dD(c[1357566]|0,c[l>>2]|0,ka>>>0>p>>>0?p:ka);eD(c[1357566]|0);_Fb(l,0)|0;if(o){WD(c[1357566]|0)|0;c[1357566]=0;break}else{i=j;return}}}while(0);o=wrc(c[846980]|0,c[846981]|0,c[2547944]|0,c[2547945]|0)|0;l=wrc(o,G,c[2443080]|0,c[2443081]|0)|0;o=wrc(l,G,c[1273376]|0,c[1273377]|0)|0;l=wrc(o,G,c[2209948]|0,c[2209949]|0)|0;o=G;if((l|0)==0&(o|0)==0){la=0.0}else{ka=xrc(v,u,l,o)|0;la=(+(ka>>>0)+ +(G|0)*4294967296.0)*100.0/(+(l>>>0)+ +(o|0)*4294967296.0)}KIb(0,32,2133824,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;ia=(+((c[2547944]|0)>>>0)+ +(c[2547945]|0)*4294967296.0)*.0009765625;D=(+((c[1273376]|0)>>>0)+ +(c[1273377]|0)*4294967296.0)*.0009765625;$=(+((c[2443080]|0)>>>0)+ +(c[2443081]|0)*4294967296.0)*.0009765625;_=(+((c[2209948]|0)>>>0)+ +(c[2209949]|0)*4294967296.0)*.0009765625;KIb(0,32,2131784,(K=i,i=i+48|0,h[K>>3]=(+((c[846980]|0)>>>0)+ +(c[846981]|0)*4294967296.0)*.0009765625,h[K+8>>3]=ia,h[K+16>>3]=D,h[K+24>>3]=$,h[K+32>>3]=_,h[K+40>>3]=la,K)|0);i=K;o=wrc(c[2443080]|0,c[2443081]|0,c[846980]|0,c[846981]|0)|0;l=wrc(o,G,c[2547944]|0,c[2547945]|0)|0;o=wrc(l,G,c[1273376]|0,c[1273377]|0)|0;l=G;ka=xrc(0,0,c[2209948]|0,c[2209949]|0)|0;if(!((o|0)==(ka|0)&(l|0)==(G|0))){i=j;return}KIb(0,24,2130240,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;i=j;return}function Sh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ca=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0;e=i;i=i+1056|0;f=e|0;g=e+8|0;j=e+16|0;k=e+96|0;l=e+104|0;m=e+112|0;n=e+120|0;o=e+128|0;p=e+136|0;q=e+168|0;r=e+200|0;s=e+208|0;t=e+216|0;u=e+248|0;v=e+280|0;w=e+312|0;x=e+568|0;y=e+576|0;z=e+640|0;A=e+704|0;B=e+712|0;C=e+720|0;D=e+728|0;E=e+736|0;H=e+744|0;I=e+752|0;J=e+760|0;K=e+824|0;L=e+904|0;M=e+912|0;N=e+920|0;O=e+928|0;P=e+1008|0;S=e+1016|0;T=e+1024|0;U=e+1032|0;V=e+1040|0;W=e+1048|0;c[N>>2]=0;X=b+96|0;if((c[X>>2]|0)==0){Y=c[b+4>>2]|0;Z=c[Y+92>>2]|0;if((Z|0)==0){_=0;$=0}else{aa=+((c[(c[Y+8>>2]|0)+176>>2]|0)*-1e6|0|0)/(+(Z|0)/+(c[Y+96>>2]|0));_=(F=+aa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);$=~~+aa>>>0}Z=b+48|0;c[Z>>2]=$;c[Z+4>>2]=_;_=b+64|0;c[_>>2]=0;c[_+4>>2]=0;do{if((d|0)!=0){$=d+8|0;ca=c[$>>2]|0;da=c[$+4>>2]|0;if((ca|0)==0&(da|0)==(-2147483648|0)){break}if((c[b+12>>2]|0)!=0){break}c[P>>2]=1;c[P+4>>2]=1e6;$=XIb(ca,da,Y+40|0,P)|0;da=wrc(c[Z>>2]|0,c[Z+4>>2]|0,$,G)|0;$=G;c[Z>>2]=da;c[Z+4>>2]=$;c[_>>2]=da;c[_+4>>2]=$}}while(0);c[X>>2]=1}X=b+40|0;if((c[X>>2]|0)==0&(c[X+4>>2]|0)==(-2147483648|0)){_=b+48|0;Z=c[_+4>>2]|0;c[X>>2]=c[_>>2];c[X+4>>2]=Z}Z=b+56|0;if((c[Z>>2]|0)==0&(c[Z+4>>2]|0)==(-2147483648|0)){_=b+64|0;P=c[_+4>>2]|0;c[Z>>2]=c[_>>2];c[Z+4>>2]=P}P=(d|0)==0;do{if(P){J1(O);c[O+24>>2]=0;c[O+28>>2]=0;ea=0}else{nrc(O|0,d|0,80)|0;_=d+16|0;Y=c[_>>2]|0;$=c[_+4>>2]|0;if((Y|0)==0&($|0)==(-2147483648|0)){fa=19;break}_=b+4|0;da=(c[_>>2]|0)+40|0;c[S>>2]=1;c[S+4>>2]=1e6;ca=XIb(Y,$,da,S)|0;da=G;$=b+48|0;c[$>>2]=ca;c[$+4>>2]=da;c[X>>2]=ca;c[X+4>>2]=da;if((c[(c[(c[_>>2]|0)+8>>2]|0)+8>>2]|0)==0){if((c[b+12>>2]|0)!=0){fa=19;break}}_=b+64|0;c[_>>2]=ca;c[_+4>>2]=da;c[Z>>2]=ca;c[Z+4>>2]=da;fa=19}}while(0);a:while(1){if((fa|0)==19){fa=0;if((c[b+12>>2]|0)==0){fa=190;break}S=c[O+28>>2]|0;if((S|0)>0){ea=S;continue}if(!P){break}if((c[N>>2]|0)==0){ga=0;fa=251;break}else{ea=S}}S=c[Z+4>>2]|0;da=b+64|0;c[da>>2]=c[Z>>2];c[da+4>>2]=S;S=c[X+4>>2]|0;ca=b+48|0;c[ca>>2]=c[X>>2];c[ca+4>>2]=S;S=O+28|0;do{if((ea|0)!=0){if((ea|0)==(c[d+28>>2]|0)){break}_=b+100|0;KIb(0,(c[_>>2]|0)!=0?40:24,2310248,(ia=i,i=i+8|0,c[ia>>2]=c[d+32>>2],ia)|0);i=ia;c[_>>2]=1}}while(0);_=b+4|0;$=c[(c[_>>2]|0)+8>>2]|0;Y=c[$+8>>2]|0;b:do{if((Y|0)==1){ja=y|0;ka=z|0;la=x;ma=b+20|0;na=c[ma>>2]|0;if((na|0)==0){oa=UHb()|0;c[ma>>2]=oa;if((oa|0)==0){ga=-12;fa=251;break a}else{pa=oa}}else{pa=na}na=b+24|0;if((c[na>>2]|0)==0){oa=UHb()|0;c[na>>2]=oa;if((oa|0)==0){ga=-12;fa=251;break a}qa=c[ma>>2]|0}else{qa=pa}Th(0,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;ma=n5a($,qa,N,O)|0;oa=b|0;ra=c[c[_>>2]>>2]|0;Th(2233456,(ia=i,i=i+16|0,c[ia>>2]=c[oa>>2],c[ia+8>>2]=ra,ia)|0);i=ia;do{if((ma|0)>-1){ra=c[$+412>>2]|0;if((ra|0)<1){KIb($,16,2229664,(ia=i,i=i+8|0,c[ia>>2]=ra,ia)|0);i=ia;sa=-1094995529;fa=35;break}ra=c[N>>2]|0;if((ra|0)!=0){ta=ma;ua=0;va=ra;fa=38;break}if((c[S>>2]|0)==0){wa=ma}else{ta=ma;ua=0;va=0;fa=38}}else{sa=ma;fa=35}}while(0);if((fa|0)==35){fa=0;ta=sa;ua=(sa|0)<0;va=c[N>>2]|0;fa=38}do{if((fa|0)==38){fa=0;ma=9474168+(ta>>>31<<3)|0;ra=wrc(c[ma>>2]|0,c[ma+4>>2]|0,1,0)|0;c[ma>>2]=ra;c[ma+4>>2]=G;if((va|0)==0|ua){if((c[S>>2]|0)==0){wa=ta;break}else{xa=ta;break b}}ma=qa+76|0;ra=c[ma>>2]|0;ya=Erc(ra,(ra|0)<0|0?-1:0,1e6,0)|0;ra=c[$+412>>2]|0;za=Crc(ya,G,ra,(ra|0)<0|0?-1:0)|0;ra=G;ya=wrc(c[Z>>2]|0,c[Z+4>>2]|0,za,ra)|0;c[Z>>2]=ya;c[Z+4>>2]=G;ya=wrc(c[X>>2]|0,c[X+4>>2]|0,za,ra)|0;c[X>>2]=ya;c[X+4>>2]=G;ya=b+136|0;ra=qa+80|0;do{if((c[ya>>2]|0)==(c[ra>>2]|0)){if((c[b+144>>2]|0)!=(c[$+416>>2]|0)){fa=47;break}za=b+152|0;Aa=qa+352|0;if(!((c[za>>2]|0)==(c[Aa>>2]|0)&(c[za+4>>2]|0)==(c[Aa+4>>2]|0))){fa=47;break}if((c[b+140>>2]|0)!=(c[qa+344>>2]|0)){fa=47}}else{fa=47}}while(0);do{if((fa|0)==47){fa=0;Aa=w|0;za=c[_>>2]|0;Ba=c[za+8>>2]|0;Ca=Ba+448|0;c:do{if((c[Ca>>2]|0)==0&(c[Ca+4>>2]|0)==0){Da=Ba+416|0;Ea=c[Da>>2]|0;do{if((Ea|0)>(c[b+120>>2]|0)){Fa=za}else{Ga=tGb(Ea)|0;Ha=G;c[Ca>>2]=Ga;c[Ca+4>>2]=Ha;if((Ga|0)==0&(Ha|0)==0){Fa=c[_>>2]|0;break}else{sGb(Aa,256,c[Da>>2]|0,Ga,Ha);Ha=c[c[_>>2]>>2]|0;KIb(0,24,2133160,(ia=i,i=i+24|0,c[ia>>2]=c[oa>>2],c[ia+8>>2]=Ha,c[ia+16>>2]=Aa,ia)|0);i=ia;break c}}}while(0);Da=c[Fa>>2]|0;KIb(0,8,2225784,(ia=i,i=i+16|0,c[ia>>2]=c[oa>>2],c[ia+8>>2]=Da,ia)|0);i=ia;Hf(1)}}while(0);Aa=$+448|0;Ca=c[Aa+4>>2]|0;za=qa+352|0;c[za>>2]=c[Aa>>2];c[za+4>>2]=Ca;Ca=b+144|0;Aa=b+152|0;sGb(ja,64,c[Ca>>2]|0,c[Aa>>2]|0,c[Aa+4>>2]|0);Ba=$+416|0;sGb(ka,64,c[Ba>>2]|0,c[za>>2]|0,c[za+4>>2]|0);Da=c[oa>>2]|0;Ea=c[c[_>>2]>>2]|0;Ha=b+140|0;Ga=c[Ha>>2]|0;Ia=LKb(c[ya>>2]|0)|0;Ja=c[Ca>>2]|0;Ka=qa+344|0;La=c[Ka>>2]|0;Ma=LKb(c[ra>>2]|0)|0;Na=c[Ba>>2]|0;KIb(0,32,2221232,(ia=i,i=i+80|0,c[ia>>2]=Da,c[ia+8>>2]=Ea,c[ia+16>>2]=Ga,c[ia+24>>2]=Ia,c[ia+32>>2]=Ja,c[ia+40>>2]=ja,c[ia+48>>2]=La,c[ia+56>>2]=Ma,c[ia+64>>2]=Na,c[ia+72>>2]=ka,ia)|0);i=ia;c[ya>>2]=c[ra>>2];c[Ha>>2]=c[Ka>>2];Ka=c[za+4>>2]|0;c[Aa>>2]=c[za>>2];c[Aa+4>>2]=Ka;c[Ca>>2]=c[Ba>>2];if((c[1371168]|0)>0){Oa=0}else{break}do{do{if((Fh(c[(c[1510464]|0)+(Oa<<2)>>2]|0,b)|0)!=0){Ba=c[(c[1510464]|0)+(Oa<<2)>>2]|0;if((Eh(Ba)|0)<0){KIb(0,8,2254024,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Hf(1)}Ca=Ba+28|0;Ka=c[Ca>>2]|0;if((Ka|0)<=0){break}Aa=Ba+24|0;Ba=0;za=Ka;while(1){Ka=c[(c[(c[Aa>>2]|0)+(Ba<<2)>>2]|0)+4>>2]|0;Ha=c[Ka+60>>2]|0;do{if((c[Ha+8>>2]|0)==1){if((c[Ha+16>>2]&65536|0)!=0){Pa=za;break}Hj(c[c[Ka+300>>2]>>2]|0,c[(c[(c[Ka+12>>2]|0)+8>>2]|0)+424>>2]|0);Pa=c[Ca>>2]|0}else{Pa=za}}while(0);Ka=Ba+1|0;if((Ka|0)<(Pa|0)){Ba=Ka;za=Pa}else{break}}}}while(0);Oa=Oa+1|0;}while((Oa|0)<(c[1371168]|0))}}while(0);ra=qa+136|0;ya=c[ra>>2]|0;za=c[ra+4>>2]|0;do{if((ya|0)==0&(za|0)==(-2147483648|0)){Ba=qa+144|0;Ca=c[Ba>>2]|0;Aa=c[Ba+4>>2]|0;if(!((Ca|0)==0&(Aa|0)==(-2147483648|0))){c[ra>>2]=Ca;c[ra+4>>2]=Aa;Aa=O+8|0;c[Aa>>2]=0;c[Aa+4>>2]=-2147483648;Aa=(c[_>>2]|0)+40|0;Ca=c[Aa+4>>2]|0;c[x>>2]=c[Aa>>2];c[x+4>>2]=Ca;break}Ca=O+8|0;Aa=c[Ca>>2]|0;Ba=c[Ca+4>>2]|0;if((Aa|0)==0&(Ba|0)==(-2147483648|0)){Ka=c[ca+4>>2]|0;c[ra>>2]=c[ca>>2];c[ra+4>>2]=Ka;c[x>>2]=1;c[la+4>>2]=1e6;break}else{c[ra>>2]=Aa;c[ra+4>>2]=Ba;c[Ca>>2]=0;c[Ca+4>>2]=-2147483648;Ca=(c[_>>2]|0)+40|0;Ba=c[Ca+4>>2]|0;c[x>>2]=c[Ca>>2];c[x+4>>2]=Ba;break}}else{Ba=$+104|0;c[A>>2]=1;c[A+4>>2]=1e6;Ca=XIb(ya,za,Ba,A)|0;Aa=G;c[Z>>2]=Ca;c[Z+4>>2]=Aa;c[da>>2]=Ca;c[da+4>>2]=Aa;c[X>>2]=Ca;c[X+4>>2]=Aa;c[ca>>2]=Ca;c[ca+4>>2]=Aa;Aa=Ba;Ba=c[Aa+4>>2]|0;c[x>>2]=c[Aa>>2];c[x+4>>2]=Ba}}while(0);za=c[ra>>2]|0;ya=c[ra+4>>2]|0;if(!((za|0)==0&(ya|0)==(-2147483648|0))){c[B>>2]=1;Ba=(c[(c[_>>2]|0)+8>>2]|0)+412|0;c[B+4>>2]=c[Ba>>2];Aa=c[ma>>2]|0;c[C>>2]=1;c[C+4>>2]=c[Ba>>2];Ba=_Ib(la,za,ya,B,Aa,b+80|0,C)|0;c[ra>>2]=Ba;c[ra+4>>2]=G}Ba=b+248|0;Aa=b+244|0;ya=0;za=0;while(1){Ca=c[Ba>>2]|0;if((ya|0)>=(Ca|0)){Qa=za;break}if((ya|0)<(Ca-1|0)){Ca=c[na>>2]|0;Ka=YHb(Ca,qa)|0;if((Ka|0)<0){Qa=Ka;break}else{Ra=Ca}}else{Ra=qa}Ca=Pj(c[c[(c[Aa>>2]|0)+(ya<<2)>>2]>>2]|0,Ra,4)|0;Ka=(Ca|0)==-541478725?0:Ca;if((Ka|0)<0){Qa=Ka;break}else{ya=ya+1|0;za=Ka}}c[ra>>2]=0;c[ra+4>>2]=-2147483648;WHb(c[na>>2]|0);WHb(qa);xa=(Qa|0)<0?Qa:ta;break b}}while(0);na=b+248|0;if((c[na>>2]|0)<=0){xa=wa;break}la=b+244|0;ka=0;while(1){Rj(c[c[(c[la>>2]|0)+(ka<<2)>>2]>>2]|0,0,0)|0;ja=ka+1|0;if((ja|0)<(c[na>>2]|0)){ka=ja}else{xa=wa;break}}}else if((Y|0)==0){ka=t|0;na=u|0;la=v|0;ja=y|0;oa=b+20|0;za=c[oa>>2]|0;if((za|0)==0){ya=UHb()|0;c[oa>>2]=ya;if((ya|0)==0){Sa=-12}else{Ta=ya;fa=81}}else{Ta=za;fa=81}d:do{if((fa|0)==81){fa=0;za=b+24|0;if((c[za>>2]|0)==0){ya=UHb()|0;c[za>>2]=ya;if((ya|0)==0){Sa=-12;break}Ua=c[oa>>2]|0}else{Ua=Ta}ya=c[ca>>2]|0;Aa=c[ca+4>>2]|0;c[r>>2]=1;c[r+4>>2]=1e6;Ba=XIb(ya,Aa,r,(c[_>>2]|0)+40|0)|0;Aa=O+16|0;c[Aa>>2]=Ba;c[Aa+4>>2]=G;Th(0,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Aa=k5a(c[(c[_>>2]|0)+8>>2]|0,Ua,N,O)|0;Ba=b|0;ya=c[c[_>>2]>>2]|0;Th(2265488,(ia=i,i=i+16|0,c[ia>>2]=c[Ba>>2],c[ia+8>>2]=ya,ia)|0);i=ia;ya=c[N>>2]|0;ma=(Aa|0)<0;if((ya|0)!=0|ma){fa=86}else{if((c[S>>2]|0)!=0){fa=86}}if((fa|0)==86){fa=0;Ka=9474168+(Aa>>>31<<3)|0;Ca=wrc(c[Ka>>2]|0,c[Ka+4>>2]|0,1,0)|0;c[Ka>>2]=Ca;c[Ka+4>>2]=G}if((ya|0)==0|ma){if((c[S>>2]|0)!=0){Sa=Aa;break}ma=b+248|0;if((c[ma>>2]|0)<=0){Sa=Aa;break}ya=b+244|0;Ka=0;while(1){Rj(c[c[(c[ya>>2]|0)+(Ka<<2)>>2]>>2]|0,0,0)|0;Ca=Ka+1|0;if((Ca|0)<(c[ma>>2]|0)){Ka=Ca}else{Sa=Aa;break d}}}Ka=c[b+116>>2]|0;if((Ka|0)>-1){c[Ua+300>>2]=Ka}Ka=c[b+280>>2]|0;ma=Ua+80|0;do{if((Ka|0)==0){Va=0;fa=97}else{if((c[ma>>2]|0)!=(c[b+284>>2]|0)){Va=0;fa=97;break}ya=We[Ka&2047](c[(c[_>>2]|0)+8>>2]|0,Ua)|0;if((ya|0)<0){Wa=ya;Xa=Aa}else{Va=ya;fa=97}}}while(0);e:do{if((fa|0)==97){fa=0;c[b+288>>2]=c[ma>>2];Ka=zHb(Ua)|0;ya=G;ra=(Ka|0)==0&(ya|0)==(-2147483648|0);if(!ra){Ca=Ua+136|0;c[Ca>>2]=Ka;c[Ca+4>>2]=ya;Ca=(c[_>>2]|0)+40|0;c[s>>2]=1;c[s+4>>2]=1e6;Ha=XIb(Ka,ya,Ca,s)|0;Ca=G;c[da>>2]=Ha;c[da+4>>2]=Ca;c[Z>>2]=Ha;c[Z+4>>2]=Ca}if((c[2369570]|0)!=0){Ca=c[c[_>>2]>>2]|0;mrc(ka|0,0,32)|0;a[ka]=0;Ha=Ua+136|0;Na=c[Ha>>2]|0;Ma=c[Ha+4>>2]|0;if((Na|0)==0&(Ma|0)==(-2147483648|0)){Rb(ka|0,32,2331072,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0)|0;i=ia}else{Rb(ka|0,32,2319576,(ia=i,i=i+16|0,c[ia>>2]=Na,c[ia+8>>2]=Ma,ia)|0)|0;i=ia}mrc(na|0,0,32)|0;a[na]=0;Ma=c[Ha>>2]|0;Na=c[Ha+4>>2]|0;Ha=c[_>>2]|0;if((Ma|0)==0&(Na|0)==(-2147483648|0)){Rb(na|0,32,2331072,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0)|0;i=ia}else{Rb(na|0,32,2325104,(ia=i,i=i+8|0,h[ia>>3]=(+(Ma>>>0)+ +(Na|0)*4294967296.0)*(+(c[Ha+40>>2]|0)/+(c[Ha+44>>2]|0)),ia)|0)|0;i=ia}mrc(la|0,0,32)|0;a[la]=0;Ha=c[_>>2]|0;if(ra){Rb(la|0,32,2331072,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0)|0;i=ia}else{Rb(la|0,32,2325104,(ia=i,i=i+8|0,h[ia>>3]=(+(Ka>>>0)+ +(ya|0)*4294967296.0)*(+(c[Ha+40>>2]|0)/+(c[Ha+44>>2]|0)),ia)|0)|0;i=ia}Ha=c[Ua+84>>2]|0;ra=c[Ua+88>>2]|0;Na=c[_>>2]|0;Ma=c[Na+40>>2]|0;La=c[Na+44>>2]|0;KIb(0,32,2261912,(ia=i,i=i+80|0,c[ia>>2]=Ca,c[ia+8>>2]=ka,c[ia+16>>2]=na,c[ia+24>>2]=Ka,c[ia+32>>2]=ya,c[ia+40>>2]=la,c[ia+48>>2]=Ha,c[ia+56>>2]=ra,c[ia+64>>2]=Ma,c[ia+72>>2]=La,ia)|0);i=ia}c[S>>2]=0;La=(c[_>>2]|0)+80|0;if((c[La>>2]|0)!=0){Ma=La;La=Ua+124|0;ra=c[Ma+4>>2]|0;c[La>>2]=c[Ma>>2];c[La+4>>2]=ra}ra=b+128|0;La=c[ra>>2]|0;Ma=Ua+68|0;Ha=b+124|0;ya=c[Ha>>2]|0;Ka=Ua+72|0;do{if((La|0)==(c[Ma>>2]|0)){if((ya|0)!=(c[Ka>>2]|0)){fa=115;break}if((c[b+132>>2]|0)!=(c[ma>>2]|0)){fa=115}}else{fa=115}}while(0);do{if((fa|0)==115){fa=0;Ca=c[Ba>>2]|0;Na=c[c[_>>2]>>2]|0;Ja=b+132|0;Ia=mKb(c[Ja>>2]|0)|0;Ga=c[Ma>>2]|0;Ea=c[Ka>>2]|0;Da=mKb(c[ma>>2]|0)|0;KIb(0,32,2257664,(ia=i,i=i+64|0,c[ia>>2]=Ca,c[ia+8>>2]=Na,c[ia+16>>2]=La,c[ia+24>>2]=ya,c[ia+32>>2]=Ia,c[ia+40>>2]=Ga,c[ia+48>>2]=Ea,c[ia+56>>2]=Da,ia)|0);i=ia;c[ra>>2]=c[Ma>>2];c[Ha>>2]=c[Ka>>2];c[Ja>>2]=c[ma>>2];if((c[1371168]|0)<=0){break}Ja=b+252|0;Da=0;do{do{if((Fh(c[(c[1510464]|0)+(Da<<2)>>2]|0,b)|0)!=0){if((c[Ja>>2]|0)==0){break}if((Eh(c[(c[1510464]|0)+(Da<<2)>>2]|0)|0)>=0){break}KIb(0,8,2254024,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Hf(1)}}while(0);Da=Da+1|0;}while((Da|0)<(c[1371168]|0))}}while(0);Ka=ZJb(pWa()|0,Ua,2245640)|0;Ha=b+248|0;Ma=c[Ha>>2]|0;if((Ma|0)<=0){Wa=Va;Xa=Aa;break}ra=Ka;ya=Ka;Ka=b+244|0;La=Aa;Da=Va;Ja=0;Ea=Ma;while(1){if((c[ra>>2]|0)==0){Ma=(c[_>>2]|0)+80|0;Ga=c[Ma+4>>2]|0;c[ya>>2]=c[Ma>>2];c[ya+4>>2]=Ga;Ya=c[Ha>>2]|0}else{Ya=Ea}if((Ja|0)<(Ya-1|0)){Ga=c[za>>2]|0;Ma=YHb(Ga,Ua)|0;if((Ma|0)<0){Wa=Ma;Xa=La;break e}else{Za=Ga;_a=Ma}}else{Za=Ua;_a=Da}Ma=Pj(c[c[(c[Ka>>2]|0)+(Ja<<2)>>2]>>2]|0,Za,4)|0;do{if((Ma|0)==-541478725){$a=0}else{if((Ma|0)>=0){$a=Ma;break}mrc(ja|0,0,64)|0;a[ja]=0;RGb(Ma,ja,64)|0;KIb(0,8,2237312,(ia=i,i=i+8|0,c[ia>>2]=ja,ia)|0);i=ia;Hf(1);$a=Ma}}while(0);Ma=Ja+1|0;Ga=c[Ha>>2]|0;if((Ma|0)<(Ga|0)){La=$a;Da=_a;Ja=Ma;Ea=Ga}else{Wa=_a;Xa=$a;break}}}}while(0);WHb(c[za>>2]|0);WHb(Ua);Sa=(Wa|0)<0?Wa:Xa}}while(0);ja=c[O+48>>2]|0;do{if((ja|0)==0){la=c[_>>2]|0;na=c[la+8>>2]|0;ka=c[na+104>>2]|0;if((ka|0)==0){ab=-2147483648;bb=0;cb=0;break}oa=c[na+108>>2]|0;if((oa|0)==0){ab=-2147483648;bb=0;cb=0;break}Aa=c[la+240>>2]|0;if((Aa|0)==0){db=c[na+112>>2]|0}else{db=(c[Aa+36>>2]|0)+1|0}Aa=Erc(db,(db|0)<0|0?-1:0,1e6,0)|0;na=Erc(Aa,G,ka,(ka|0)<0|0?-1:0)|0;ka=Crc(na,G,oa,(oa|0)<0|0?-1:0)|0;eb=ka;fa=141}else{ka=(c[_>>2]|0)+40|0;c[T>>2]=1;c[T+4>>2]=1e6;oa=XIb(ja,(ja|0)<0|0?-1:0,ka,T)|0;eb=oa;fa=141}}while(0);do{if((fa|0)==141){fa=0;if((c[ca>>2]|0)==0&(c[ca+4>>2]|0)==(-2147483648|0)|(eb|0)==0){ab=-2147483648;bb=0;cb=eb;break}ja=wrc(c[X>>2]|0,c[X+4>>2]|0,eb,(eb|0)<0|0?-1:0)|0;ab=G;bb=ja;cb=eb}}while(0);c[X>>2]=bb;c[X+4>>2]=ab;if((c[N>>2]|0)==0){xa=Sa;break}ja=wrc(c[Z>>2]|0,c[Z+4>>2]|0,cb,(cb|0)<0|0?-1:0)|0;c[Z>>2]=ja;c[Z+4>>2]=G;xa=Sa}else if((Y|0)==3){ja=p;oa=q;ka=o5a($,p,N,O)|0;na=c[N>>2]|0;Aa=(ka|0)<0;if((na|0)!=0|Aa){fa=147}else{if((c[S>>2]|0)!=0){fa=147}}if((fa|0)==147){fa=0;la=9474168+(ka>>>31<<3)|0;ma=wrc(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=ma;c[la+4>>2]=G}if(Aa|(na|0)==0){if((c[S>>2]|0)!=0){xa=ka;break}Aa=b+248|0;if((c[Aa>>2]|0)<=0){xa=ka;break}la=b+244|0;ma=0;while(1){Rj(c[c[(c[la>>2]|0)+(ma<<2)>>2]>>2]|0,0,0)|0;Ba=ma+1|0;if((Ba|0)<(c[Aa>>2]|0)){ma=Ba}else{xa=ka;break b}}}if((c[b+160>>2]|0)==0){fb=ka;gb=na;fa=158}else{ma=b+168|0;Aa=c[ma>>2]|0;do{if((Aa|0)==0){hb=1;ib=0;jb=na}else{la=p+24|0;Ba=b+200|0;Ea=xrc(c[la>>2]|0,c[la+4>>2]|0,c[Ba>>2]|0,c[Ba+4>>2]|0)|0;Ba=VIb(Ea,G,1e3,0,1e6,0)|0;Ea=Ba;Ba=b+184|0;la=c[Ba>>2]|0;if(!(Ea>>>0<la>>>0)){hb=Ea;ib=Aa;jb=na;break}KIb(c[(c[_>>2]|0)+8>>2]|0,48,2306088,(ia=i,i=i+24|0,c[ia>>2]=la,c[ia+8>>2]=Ea,c[ia+16>>2]=(Ea|0)<1?2296744:10230128,ia)|0);i=ia;c[Ba>>2]=Ea;hb=Ea;ib=c[ma>>2]|0;jb=c[N>>2]|0}}while(0);c[ma>>2]=jb;c[N>>2]=ib;na=b+172|0;Aa=c[na>>2]|0;c[na>>2]=ka;na=b+176|0;c[oa>>2]=c[na>>2];c[oa+4>>2]=c[na+4>>2];c[oa+8>>2]=c[na+8>>2];c[oa+12>>2]=c[na+12>>2];c[oa+16>>2]=c[na+16>>2];c[oa+20>>2]=c[na+20>>2];c[oa+24>>2]=c[na+24>>2];c[oa+28>>2]=c[na+28>>2];c[na>>2]=c[ja>>2];c[na+4>>2]=c[ja+4>>2];c[na+8>>2]=c[ja+8>>2];c[na+12>>2]=c[ja+12>>2];c[na+16>>2]=c[ja+16>>2];c[na+20>>2]=c[ja+20>>2];c[na+24>>2]=c[ja+24>>2];c[na+28>>2]=c[ja+28>>2];c[ja>>2]=c[oa>>2];c[ja+4>>2]=c[oa+4>>2];c[ja+8>>2]=c[oa+8>>2];c[ja+12>>2]=c[oa+12>>2];c[ja+16>>2]=c[oa+16>>2];c[ja+20>>2]=c[oa+20>>2];c[ja+24>>2]=c[oa+24>>2];c[ja+28>>2]=c[oa+28>>2];if((hb|0)<1){kb=Aa}else{fb=Aa;gb=ib;fa=158}}do{if((fa|0)==158){fa=0;if((gb|0)==0){xa=fb;break b}Wh(b,p);Aa=p+12|0;if(!((c[Aa>>2]|0)!=0&(c[1371156]|0)>0)){kb=fb;break}na=b|0;Ea=p+24|0;Ba=k|0;la=k+4|0;Ja=p+4|0;Da=l|0;La=l+4|0;Ha=m|0;Ka=m+4|0;ya=p+8|0;ra=j+24|0;Ga=j+28|0;Ma=n|0;Ia=n+4|0;Na=j+8|0;Ca=o|0;lb=o+4|0;mb=j+48|0;nb=g|0;ob=g+4|0;pb=f|0;qb=f+4|0;rb=0;while(1){sb=c[(c[1366870]|0)+(rb<<2)>>2]|0;tb=sb|0;ub=c[(c[1366872]|0)+(c[tb>>2]<<2)>>2]|0;f:do{if((c[sb+8>>2]|0)==((c[c[_>>2]>>2]|0)+(c[(c[(c[1475750]|0)+(c[na>>2]<<2)>>2]|0)+12>>2]|0)|0)){vb=sb+344|0;if((c[vb>>2]|0)!=0){break}wb=ub+24|0;xb=c[wb>>2]|0;yb=c[wb+4>>2]|0;if(!((xb|0)==0&(yb|0)==(-2147483648|0))){wb=c[da+4>>2]|0;if((wb|0)<(yb|0)|(wb|0)==(yb|0)&(c[da>>2]|0)>>>0<xb>>>0){break}}if((c[sb+16>>2]|0)==0){break}wb=c[ub>>2]|0;zb=c[Ea>>2]|0;Ab=c[Ea+4>>2]|0;if((zb|0)==0&(Ab|0)==(-2147483648|0)){KIb(0,16,2286976,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;if((c[2244126]|0)==0){break}Hf(1);break}Bb=sb+12|0;Cb=c[(c[Bb>>2]|0)+8>>2]|0;if((c[1273378]|0)==0){c[1273378]=hJb(1048576)|0;Db=(c[(c[1366872]|0)+(c[tb>>2]<<2)>>2]|0)+24|0;Eb=c[Ea+4>>2]|0;Fb=c[Ea>>2]|0;Gb=c[Db+4>>2]|0;Hb=c[Db>>2]|0}else{Eb=Ab;Fb=zb;Gb=yb;Hb=xb}xb=Cb+48|0;yb=(c[xb>>2]|0)==94209?2:1;zb=(Hb|0)==0&(Gb|0)==(-2147483648|0);Ab=xrc(Fb,Eb,zb?0:Hb,zb?0:Gb)|0;zb=G;Db=Cb+104|0;Ib=sb+32|0;Jb=sb+40|0;Kb=0;while(1){c[Ba>>2]=1;c[la>>2]=1e6;Lb=XIb(Ab,zb,k,Db)|0;Mb=G;c[Ib>>2]=Lb;c[Ib+4>>2]=Mb;Nb=(c[(c[1366872]|0)+(c[tb>>2]<<2)>>2]|0)+16|0;Ob=c[Nb>>2]|0;Pb=c[Nb+4>>2]|0;if(!((Ob|0)==(-1|0)&(Pb|0)==2147483647)){Nb=xrc(Lb,Mb,c[Jb>>2]|0,c[Jb+4>>2]|0)|0;Mb=(c[(c[Bb>>2]|0)+8>>2]|0)+104|0;c[nb>>2]=1;c[ob>>2]=1e6;if((YIb(Nb,G,Mb,Ob,Pb,g)|0)>-1){break}}c[Ea>>2]=Ab;c[Ea+4>>2]=zb;Pb=c[Ja>>2]|0;c[Da>>2]=1;c[La>>2]=1e3;c[Ha>>2]=1;c[Ka>>2]=1e6;Ob=XIb(Pb,0,l,m)|0;Pb=wrc(c[Ea>>2]|0,c[Ea+4>>2]|0,Ob,G)|0;c[Ea>>2]=Pb;c[Ea+4>>2]=G;c[ya>>2]=(c[ya>>2]|0)-(c[Ja>>2]|0);c[Ja>>2]=0;if((Kb|0)==1){c[Aa>>2]=0}Pb=j5a(Cb,c[1273378]|0,1048576,p)|0;if((Pb|0)<0){KIb(0,8,2282856,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Hf(1)}J1(j);c[ra>>2]=c[1273378];c[Ga>>2]=Pb;Pb=c[Ea>>2]|0;Ob=c[Ea+4>>2]|0;c[Ma>>2]=1;c[Ia>>2]=1e6;Mb=XIb(Pb,Ob,n,(c[Bb>>2]|0)+40|0)|0;c[Na>>2]=Mb;c[Na+4>>2]=G;Mb=c[ya>>2]|0;c[Ca>>2]=1;c[lb>>2]=1e3;Ob=XIb(Mb,0,o,(c[Bb>>2]|0)+40|0)|0;c[mb>>2]=Ob;do{if((c[xb>>2]|0)==94209){if((Kb|0)==0){Ob=wrc((c[Ja>>2]|0)*90|0,0,c[Na>>2]|0,c[Na+4>>2]|0)|0;c[Na>>2]=Ob;c[Na+4>>2]=G;break}else{Ob=wrc((c[ya>>2]|0)*90|0,0,c[Na>>2]|0,c[Na+4>>2]|0)|0;c[Na>>2]=Ob;c[Na+4>>2]=G;break}}}while(0);Ob=c[Ga>>2]|0;Mb=wrc(c[1273376]|0,c[1273377]|0,Ob,(Ob|0)<0|0?-1:0)|0;c[1273376]=Mb;c[1273377]=G;Uh(wb,j,sb);Kb=Kb+1|0;if((Kb|0)>=(yb|0)){break f}}yb=c[(c[1366872]|0)+(c[tb>>2]<<2)>>2]|0;c[vb>>2]=c[vb>>2]|1;if((c[yb+40>>2]|0)==0){break}Kb=xrc(c[Ib>>2]|0,c[Ib+4>>2]|0,c[Jb>>2]|0,c[Jb+4>>2]|0)|0;wb=(c[(c[Bb>>2]|0)+8>>2]|0)+104|0;c[pb>>2]=1;c[qb>>2]=1e6;xb=XIb(Kb,G,wb,f)|0;wb=G;Kb=yb+16|0;yb=c[Kb>>2]|0;Cb=c[Kb+4>>2]|0;zb=(Cb|0)>(wb|0)|(Cb|0)==(wb|0)&yb>>>0>xb>>>0;c[Kb>>2]=zb?xb:yb;c[Kb+4>>2]=zb?wb:Cb}}while(0);tb=rb+1|0;if((tb|0)<(c[1371156]|0)){rb=tb}else{kb=fb;break}}}}while(0);p5a(p);xa=kb}else{ga=-1;fa=251;break a}}while(0);if((xa|0)<0){ga=xa;fa=251;break}da=O+8|0;c[da>>2]=0;c[da+4>>2]=-2147483648;da=O+16|0;c[da>>2]=0;c[da+4>>2]=-2147483648;if(P){fa=19;continue}da=c[S>>2]|0;$=(c[(c[(c[_>>2]|0)+8>>2]|0)+8>>2]|0)==1?xa:da;Y=O+24|0;c[Y>>2]=(c[Y>>2]|0)+$;c[S>>2]=da-$;fa=19}if((fa|0)==190){O=c[X>>2]|0;xa=c[X+4>>2]|0;P=b+48|0;c[P>>2]=O;c[P+4>>2]=xa;kb=c[b+4>>2]|0;p=c[kb+8>>2]|0;fb=c[p+8>>2]|0;do{if((fb|0)==1){f=c[p+424>>2]|0;j=Erc(f,(f|0)<0|0?-1:0,1e6,0)|0;f=c[p+412>>2]|0;o=Crc(j,G,f,(f|0)<0|0?-1:0)|0;f=wrc(O,xa,o,G)|0;o=G;c[X>>2]=f;c[X+4>>2]=o;Qb=o;Sb=f}else if((fb|0)==0){f=b+108|0;o=c[f>>2]|0;if((o|0)!=0){j=b+112|0;c[U>>2]=c[j>>2];c[U+4>>2]=o;o=XIb(O,xa,738952,U)|0;n=wrc(o,G,1,0)|0;o=c[f>>2]|0;c[V>>2]=c[j>>2];c[V+4>>2]=o;o=XIb(n,G,V,738952)|0;n=G;c[X>>2]=o;c[X+4>>2]=n;Qb=n;Sb=o;break}o=c[d+48>>2]|0;if((o|0)!=0){c[W>>2]=1;c[W+4>>2]=1e6;n=XIb(o,(o|0)<0|0?-1:0,kb+40|0,W)|0;o=wrc(c[X>>2]|0,c[X+4>>2]|0,n,G)|0;n=G;c[X>>2]=o;c[X+4>>2]=n;Qb=n;Sb=o;break}o=c[p+104>>2]|0;if((o|0)==0){Qb=xa;Sb=O;break}n=c[kb+240>>2]|0;if((n|0)==0){Tb=c[p+112>>2]|0}else{Tb=(c[n+36>>2]|0)+1|0}n=Erc(Tb,(Tb|0)<0|0?-1:0,1e6,0)|0;j=Erc(n,G,o,(o|0)<0|0?-1:0)|0;o=c[p+108>>2]|0;n=Crc(j,G,o,(o|0)<0|0?-1:0)|0;o=wrc(O,xa,n,G)|0;n=G;c[X>>2]=o;c[X+4>>2]=n;Qb=n;Sb=o}else{Qb=xa;Sb=O}}while(0);O=c[P+4>>2]|0;xa=b+64|0;c[xa>>2]=c[P>>2];c[xa+4>>2]=O;c[Z>>2]=Sb;c[Z+4>>2]=Qb}else if((fa|0)==251){i=e;return ga|0}if(!((d|0)!=0&(c[1371156]|0)>0)){ga=0;i=e;return ga|0}fa=b|0;Qb=b+4|0;Z=J;Sb=H|0;O=H+4|0;xa=I|0;P=I+4|0;X=d+36|0;p=d+8|0;Tb=b+64|0;kb=K+8|0;W=d+16|0;V=b+48|0;U=L|0;fb=L+4|0;o=K+16|0;n=d+28|0;j=M|0;f=M+4|0;ia=b+80|0;b=d+48|0;m=K+48|0;l=K+36|0;g=K+24|0;k=K+28|0;Gb=d+24|0;Hb=K|0;Eb=D|0;Fb=D+4|0;gb=E|0;ib=E+4|0;hb=0;while(1){N=c[(c[1366870]|0)+(hb<<2)>>2]|0;jb=N|0;q=c[(c[1366872]|0)+(c[jb>>2]<<2)>>2]|0;Sa=c[(c[1475750]|0)+(c[fa>>2]<<2)>>2]|0;g:do{if((c[N+8>>2]|0)==((c[c[Qb>>2]>>2]|0)+(c[Sa+12>>2]|0)|0)){cb=N+344|0;if((c[cb>>2]|0)!=0){break}ab=q+24|0;bb=c[ab>>2]|0;eb=c[ab+4>>2]|0;ab=(bb|0)==0&(eb|0)==(-2147483648|0);if(!ab){T=c[Tb+4>>2]|0;if((T|0)<(eb|0)|(T|0)==(eb|0)&(c[Tb>>2]|0)>>>0<bb>>>0){break}}if((c[N+16>>2]|0)!=0){break}T=ab?0:bb;bb=ab?0:eb;c[Sb>>2]=1;c[O>>2]=1e6;eb=N+12|0;ab=XIb(T,bb,H,(c[eb>>2]|0)+40|0)|0;db=G;c[xa>>2]=1;c[P>>2]=1e6;Xa=XIb(T,bb,I,(c[Qb>>2]|0)+40|0)|0;Wa=G;J1(K);Ua=c[N+20>>2]|0;do{if((Ua|0)==0){if((c[X>>2]&1|0)!=0){break}if((c[N+360>>2]|0)==0){break g}}}while(0);$a=c[p>>2]|0;_a=c[p+4>>2]|0;Za=(Ua|0)!=0;do{if(($a|0)==0&(_a|0)==(-2147483648|0)){if(Za){break}Ya=c[Tb+4>>2]|0;if(!((Ya|0)<(bb|0)|(Ya|0)==(bb|0)&(c[Tb>>2]|0)>>>0<T>>>0)){break}if((c[N+364>>2]|0)==0){break g}}else{if(!(((_a|0)<(Wa|0)|(_a|0)==(Wa|0)&$a>>>0<Xa>>>0)&(Za^1))){break}if((c[N+364>>2]|0)==0){break g}}}while(0);Za=q+16|0;Xa=c[Za>>2]|0;$a=c[Za+4>>2]|0;do{if(!((Xa|0)==(-1|0)&($a|0)==2147483647)){Za=c[Tb>>2]|0;Wa=c[Tb+4>>2]|0;_a=wrc(Xa,$a,T,bb)|0;Ua=G;if((Wa|0)<(Ua|0)|(Wa|0)==(Ua|0)&Za>>>0<_a>>>0){break}_a=c[(c[1366872]|0)+(c[jb>>2]<<2)>>2]|0;c[cb>>2]=c[cb>>2]|1;if((c[_a+40>>2]|0)==0){break g}Za=N+32|0;Ua=N+40|0;Wa=xrc(c[Za>>2]|0,c[Za+4>>2]|0,c[Ua>>2]|0,c[Ua+4>>2]|0)|0;Ua=(c[(c[eb>>2]|0)+8>>2]|0)+104|0;c[gb>>2]=1;c[ib>>2]=1e6;Za=XIb(Wa,G,Ua,E)|0;Ua=G;Wa=_a+16|0;_a=c[Wa>>2]|0;Ya=c[Wa+4>>2]|0;Va=(Ya|0)>(Ua|0)|(Ya|0)==(Ua|0)&_a>>>0>Za>>>0;c[Wa>>2]=Va?Za:_a;c[Wa+4>>2]=Va?Ua:Ya;break g}}while(0);bb=Sa+48|0;T=c[bb>>2]|0;$a=c[bb+4>>2]|0;do{if(!((T|0)==(-1|0)&($a|0)==2147483647)){bb=(c[Sa>>2]|0)+1056|0;Xa=Sa+40|0;Ya=c[Xa>>2]|0;Ua=c[Xa+4>>2]|0;Xa=(Ya|0)==0&(Ua|0)==(-2147483648|0);Va=c[Tb>>2]|0;Wa=c[Tb+4>>2]|0;_a=wrc(c[bb>>2]|0,c[bb+4>>2]|0,T,$a)|0;bb=wrc(_a,G,Xa?0:Ya,Xa?0:Ua)|0;Ua=G;if((Wa|0)<(Ua|0)|(Wa|0)==(Ua|0)&Va>>>0<bb>>>0){break}bb=c[(c[1366872]|0)+(c[jb>>2]<<2)>>2]|0;c[cb>>2]=c[cb>>2]|1;if((c[bb+40>>2]|0)==0){break g}Va=N+32|0;Ua=N+40|0;Wa=xrc(c[Va>>2]|0,c[Va+4>>2]|0,c[Ua>>2]|0,c[Ua+4>>2]|0)|0;Ua=(c[(c[eb>>2]|0)+8>>2]|0)+104|0;c[Eb>>2]=1;c[Fb>>2]=1e6;Va=XIb(Wa,G,Ua,D)|0;Ua=G;Wa=bb+16|0;bb=c[Wa>>2]|0;Xa=c[Wa+4>>2]|0;Ya=(Xa|0)>(Ua|0)|(Xa|0)==(Ua|0)&bb>>>0>Va>>>0;c[Wa>>2]=Ya?Va:bb;c[Wa+4>>2]=Ya?Ua:Xa;break g}}while(0);cb=c[eb>>2]|0;$a=c[(c[cb+8>>2]|0)+8>>2]|0;if(($a|0)==1){T=c[n>>2]|0;Xa=wrc(c[2547944]|0,c[2547945]|0,T,(T|0)<0|0?-1:0)|0;c[2547944]=Xa;c[2547945]=G}else if(($a|0)==0){Xa=c[n>>2]|0;T=wrc(c[846980]|0,c[846981]|0,Xa,(Xa|0)<0|0?-1:0)|0;c[846980]=T;c[846981]=G;T=N+32|0;Xa=wrc(c[T>>2]|0,c[T+4>>2]|0,1,0)|0;c[T>>2]=Xa;c[T+4>>2]=G}else if(($a|0)==2){T=c[n>>2]|0;Xa=wrc(c[2443080]|0,c[2443081]|0,T,(T|0)<0|0?-1:0)|0;c[2443080]=Xa;c[2443081]=G}else if(($a|0)==3){$a=c[n>>2]|0;Xa=wrc(c[1273376]|0,c[1273377]|0,$a,($a|0)<0|0?-1:0)|0;c[1273376]=Xa;c[1273377]=G}Xa=c[p>>2]|0;$a=c[p+4>>2]|0;if((Xa|0)==0&($a|0)==(-2147483648|0)){Ub=-2147483648;Vb=0}else{T=XIb(Xa,$a,(c[Qb>>2]|0)+40|0,cb+40|0)|0;cb=xrc(T,G,ab,db)|0;Ub=G;Vb=cb}c[kb>>2]=Vb;c[kb+4>>2]=Ub;cb=c[W>>2]|0;T=c[W+4>>2]|0;if((cb|0)==0&(T|0)==(-2147483648|0)){$a=c[V>>2]|0;Xa=c[V+4>>2]|0;c[U>>2]=1;c[fb>>2]=1e6;Ua=XIb($a,Xa,L,(c[eb>>2]|0)+40|0)|0;Wb=G;Xb=Ua}else{Ua=XIb(cb,T,(c[Qb>>2]|0)+40|0,(c[eb>>2]|0)+40|0)|0;Wb=G;Xb=Ua}Ua=xrc(Xb,Wb,ab,db)|0;c[o>>2]=Ua;c[o+4>>2]=G;Ua=c[eb>>2]|0;do{if((c[(c[Ua+8>>2]|0)+8>>2]|0)==1){if((c[W>>2]|0)==0&(c[W+4>>2]|0)==(-2147483648|0)){Yb=Ua;break}T=B5a(c[(c[Qb>>2]|0)+8>>2]|0,c[n>>2]|0)|0;cb=c[Qb>>2]|0;Xa=c[cb+8>>2]|0;if((T|0)==0){Zb=c[Xa+424>>2]|0}else{Zb=T}T=c[W>>2]|0;$a=c[W+4>>2]|0;c[j>>2]=1;c[f>>2]=c[Xa+412>>2];Xa=_Ib(cb+40|0,T,$a,M,Zb,ia,(c[eb>>2]|0)+40|0)|0;$a=xrc(Xa,G,ab,db)|0;Xa=G;c[kb>>2]=$a;c[kb+4>>2]=Xa;c[o>>2]=$a;c[o+4>>2]=Xa;Yb=c[eb>>2]|0}else{Yb=Ua}}while(0);Ua=c[b>>2]|0;db=XIb(Ua,(Ua|0)<0|0?-1:0,(c[Qb>>2]|0)+40|0,Yb+40|0)|0;c[m>>2]=db;db=c[X>>2]|0;c[l>>2]=db;Ua=c[(c[eb>>2]|0)+8>>2]|0;ab=c[Ua+48>>2]|0;do{if((ab|0)==28|(ab|0)==1|(ab|0)==2|(ab|0)==71){c[g>>2]=c[Gb>>2];c[k>>2]=c[n>>2]}else{if((GWa(c[N+372>>2]|0,Ua,g,k,c[Gb>>2]|0,c[n>>2]|0,db&1)|0)==0){break}Xa=aGb(c[g>>2]|0,c[k>>2]|0,116,0,0)|0;c[Hb>>2]=Xa;if((Xa|0)!=0){break}Hf(1)}}while(0);O1(K,d)|0;db=c[(c[eb>>2]|0)+8>>2]|0;Ua=q|0;do{if((c[db+8>>2]|0)==0){if((c[(c[(c[Ua>>2]|0)+8>>2]|0)+28>>2]&32|0)==0){break}a2(J,c[g>>2]|0,c[db+140>>2]|0,c[db+120>>2]|0,c[db+124>>2]|0)|0;c[g>>2]=Z;c[k>>2]=64;c[l>>2]=c[l>>2]|1}}while(0);Uh(c[Ua>>2]|0,K,N);db=(c[(c[eb>>2]|0)+8>>2]|0)+428|0;c[db>>2]=(c[db>>2]|0)+1}}while(0);N=hb+1|0;if((N|0)<(c[1371156]|0)){hb=N}else{ga=0;break}}i=e;return ga|0}function Th(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+1176|0;e=d|0;f=d+136|0;if((c[2333754]|0)==0){i=d;return}rd(0,e|0)|0;g=c[e>>2]|0;h=Erc(g,(g|0)<0|0?-1:0,1e6,0)|0;g=c[e+4>>2]|0;e=wrc(h,G,g,(g|0)<0|0?-1:0)|0;g=G;if((a|0)!=0){h=f;c[h>>2]=b;c[h+4>>2]=0;h=d+152|0;Ad(h|0,1024,a|0,f|0)|0;f=c[2443082]|0;a=xrc(e,g,f,(f|0)<0|0?-1:0)|0;f=G;Oc(2314864,(g=i,i=i+24|0,c[g>>2]=a,c[g+8>>2]=f,c[g+16>>2]=h,g)|0)|0;i=g}c[2443082]=e;i=d;return}function Uh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;f=i;i=i+208|0;g=f|0;j=f+80|0;k=f+112|0;l=f+144|0;m=f+176|0;n=c[e+56>>2]|0;o=e+12|0;p=c[(c[o>>2]|0)+8>>2]|0;q=p+8|0;r=c[q>>2]|0;s=(r|0)==0;if(s&(c[64350]|0)==255){t=3}else{if((r|0)==1&(c[2547942]|0)<0){t=3}}if((t|0)==3){r=d+16|0;c[r>>2]=0;c[r+4>>2]=-2147483648;r=d+8|0;c[r>>2]=0;c[r+4>>2]=-2147483648}if(s){if((c[p+12>>2]|0)==0){t=6}}else{t=6}do{if((t|0)==6){s=e+20|0;r=c[s>>2]|0;u=(r|0)<0|0?-1:0;v=e+64|0;w=c[v+4>>2]|0;if((u|0)<(w|0)|(u|0)==(w|0)&r>>>0<(c[v>>2]|0)>>>0){c[s>>2]=r+1;break}P1(d);i=f;return}}while(0);if((n|0)!=0){r=g;s=d;v=g+24|0;w=g+28|0;u=d+24|0;x=d+28|0;y=d+36|0;z=g+52|0;A=g|0;g=d+32|0;B=p+12|0;C=n;do{nrc(r|0,s|0,80)|0;n=g3(C,p,0,v,w,c[u>>2]|0,c[x>>2]|0,c[y>>2]&1)|0;do{if((n|0)==0){if((c[v>>2]|0)==(c[u>>2]|0)){break}if((c[z>>2]|0)==0){t=16;break}D=hJb((c[w>>2]|0)+16|0)|0;if((D|0)==0){E=-12;t=20;break}F=c[w>>2]|0;nrc(D|0,c[v>>2]|0,F)|0;mrc(D+F|0,0,16)|0;c[v>>2]=D;c[A>>2]=0;t=17}else{t=16}}while(0);do{if((t|0)==16){t=0;if((n|0)>0){t=17;break}if((n|0)<0){E=n;t=20}}}while(0);do{if((t|0)==17){t=0;P1(d);n=aGb(c[v>>2]|0,c[w>>2]|0,116,0,0)|0;c[A>>2]=n;if((n|0)!=0){break}Hf(1)}else if((t|0)==20){t=0;n=c[g>>2]|0;D=c[B>>2]|0;if((D|0)==0){H=2378480}else{H=c[D>>2]|0}KIb(0,16,2385504,(I=i,i=i+24|0,c[I>>2]=c[c[C+4>>2]>>2],c[I+8>>2]=n,c[I+16>>2]=H,I)|0);i=I;$f(10230128,E);if((c[2244126]|0)==0){break}Hf(1)}}while(0);nrc(s|0,r|0,80)|0;C=c[C+12>>2]|0;}while((C|0)!=0)}C=c[(c[b+8>>2]|0)+28>>2]|0;do{if((C&128|0)==0){r=c[q>>2]|0;if(!(r>>>0<2>>>0)){break}s=d+16|0;E=c[s>>2]|0;H=c[s+4>>2]|0;if((E|0)==0&(H|0)==(-2147483648|0)){break}B=e+48|0;g=c[B>>2]|0;t=c[B+4>>2]|0;if((g|0)==0&(t|0)==(-2147483648|0)){break}B=wrc(g,t,C>>>17&1^1,0)|0;A=G;if(!((H|0)<(A|0)|(H|0)==(A|0)&E>>>0<B>>>0)){break}w=xrc(B,A,E,H)|0;v=G;z=0;if((v|0)>(z|0)|(v|0)==(z|0)&w>>>0>2>>>0){J=24}else{J=(r|0)==0?24:48}r=b;w=c[c[o>>2]>>2]|0;KIb(r,J,2372552,(I=i,i=i+48|0,c[I>>2]=c[e>>2],c[I+8>>2]=w,c[I+16>>2]=g,c[I+24>>2]=t,c[I+32>>2]=E,c[I+40>>2]=H,I)|0);i=I;if((c[2244126]|0)!=0){KIb(0,8,2361152,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;Hf(1)}KIb(r,J,2348552,(I=i,i=i+16|0,c[I>>2]=B,c[I+8>>2]=A,I)|0);i=I;r=d+8|0;H=c[r>>2]|0;E=c[r+4>>2]|0;t=c[s+4>>2]|0;if(!((E|0)<(t|0)|(E|0)==(t|0)&H>>>0<(c[s>>2]|0)>>>0)){t=(E|0)>(A|0)|(E|0)==(A|0)&H>>>0>B>>>0;c[r>>2]=t?H:B;c[r+4>>2]=t?E:A}c[s>>2]=B;c[s+4>>2]=A}}while(0);J=d+16|0;C=c[J+4>>2]|0;q=e+48|0;c[q>>2]=c[J>>2];c[q+4>>2]=C;c[d+32>>2]=c[e+4>>2];if((c[2369570]|0)!=0){C=ALb(c[(c[(c[o>>2]|0)+8>>2]|0)+8>>2]|0)|0;q=j|0;mrc(q|0,0,32)|0;a[q]=0;j=d+8|0;A=c[j>>2]|0;s=c[j+4>>2]|0;if((A|0)==0&(s|0)==(-2147483648|0)){Rb(q|0,32,2331072,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Rb(q|0,32,2319576,(I=i,i=i+16|0,c[I>>2]=A,c[I+8>>2]=s,I)|0)|0;i=I}s=k|0;mrc(s|0,0,32)|0;a[s]=0;k=c[j>>2]|0;A=c[j+4>>2]|0;j=c[o>>2]|0;if((k|0)==0&(A|0)==(-2147483648|0)){Rb(s|0,32,2331072,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Rb(s|0,32,2325104,(I=i,i=i+8|0,h[I>>3]=(+(k>>>0)+ +(A|0)*4294967296.0)*(+(c[j+40>>2]|0)/+(c[j+44>>2]|0)),I)|0)|0;i=I}j=l|0;mrc(j|0,0,32)|0;a[j]=0;l=c[J>>2]|0;A=c[J+4>>2]|0;if((l|0)==0&(A|0)==(-2147483648|0)){Rb(j|0,32,2331072,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Rb(j|0,32,2319576,(I=i,i=i+16|0,c[I>>2]=l,c[I+8>>2]=A,I)|0)|0;i=I}A=m|0;mrc(A|0,0,32)|0;a[A]=0;m=c[J>>2]|0;l=c[J+4>>2]|0;J=c[o>>2]|0;if((m|0)==0&(l|0)==(-2147483648|0)){Rb(A|0,32,2331072,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Rb(A|0,32,2325104,(I=i,i=i+8|0,h[I>>3]=(+(m>>>0)+ +(l|0)*4294967296.0)*(+(c[J+40>>2]|0)/+(c[J+44>>2]|0)),I)|0)|0;i=I}J=c[d+28>>2]|0;KIb(0,32,2342288,(I=i,i=i+48|0,c[I>>2]=C,c[I+8>>2]=q,c[I+16>>2]=s,c[I+24>>2]=j,c[I+32>>2]=A,c[I+40>>2]=J,I)|0);i=I}I=_O(b,d)|0;if((I|0)>=0){i=f;return}$f(2336424,I);a[840088]=1;if((c[1371156]|0)>0){K=0}else{i=f;return}do{I=c[(c[1366870]|0)+(K<<2)>>2]|0;d=I+344|0;c[d>>2]=((I|0)==(e|0)?3:1)|c[d>>2];K=K+1|0;}while((K|0)<(c[1371156]|0));i=f;return}function Vh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0.0,k=0,l=0.0,m=0.0;d=i;do{if((c[836154]|0)==0){e=Qc(c[836152]|0,2450424)|0;c[836154]=e;if((e|0)!=0){break}Gb(2434088);Hf(1)}}while(0);e=a+12|0;a=c[e>>2]|0;f=c[a+8>>2]|0;if((c[f+8>>2]|0)!=0){i=d;return}g=f+804|0;j=+(c[(c[g>>2]|0)+168>>2]|0)/118.0;Id(c[836154]|0,2425312,(k=i,i=i+16|0,c[k>>2]=c[a+64>>2],h[k+8>>3]=j,k)|0)|0;i=k;if((c[f+88>>2]&32768|0)!=0){a=(c[g>>2]|0)+224|0;j=+aa((+((c[a>>2]|0)>>>0)+ +((c[a+4>>2]|0)>>>0)*4294967296.0)/(+(ca(c[f+124>>2]|0,c[f+120>>2]|0)|0)*255.0*255.0))*-10.0/2.302585092994046;Id(c[836154]|0,2414520,(k=i,i=i+8|0,h[k>>3]=j,k)|0)|0;i=k}Id(c[836154]|0,2406712,(k=i,i=i+8|0,c[k>>2]=b,k)|0)|0;i=k;a=(c[e>>2]|0)+16|0;j=+(c[f+104>>2]|0)/+(c[f+108>>2]|0);l=(+((c[a>>2]|0)>>>0)+ +(c[a+4>>2]|0)*4294967296.0)*j;m=l<.01?.01:l;a=c[846980]|0;f=c[846981]|0;Id(c[836154]|0,2399208,(k=i,i=i+32|0,h[k>>3]=(+(a>>>0)+ +(f|0)*4294967296.0)*.0009765625,h[k+8>>3]=m,h[k+16>>3]=+(b<<3|0)/j/1.0e3,h[k+24>>3]=(+((a<<3|0>>>29)>>>0)+ +(f<<3|a>>>29|0)*4294967296.0)/m/1.0e3,k)|0)|0;i=k;a=c[836154]|0;f=(BLb(c[(c[g>>2]|0)+88>>2]|0)|0)<<24>>24;Id(a|0,2392112,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k;i=d;return}function Wh(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a+228|0;j=c[h>>2]|0;k=a+232|0;l=c[k>>2]|0;m=a+224|0;n=c[m>>2]|0;if((n|0)==0){i=e;return}if((b|0)==0){o=a+216|0;p=2147483647;q=-1;r=c[o+4>>2]|0;s=c[o>>2]|0;t=0;u=n}else{o=b+24|0;v=wrc((c[b+4>>2]|0)*1e3|0,0,c[o>>2]|0,c[o+4>>2]|0)|0;c[f>>2]=1;c[f+4>>2]=1e6;w=a+4|0;x=XIb(v,G,f,(c[w>>2]|0)+40|0)|0;f=G;v=wrc((c[b+8>>2]|0)*1e3|0,0,c[o>>2]|0,c[o+4>>2]|0)|0;c[g>>2]=1;c[g+4>>2]=1e6;o=XIb(v,G,g,(c[w>>2]|0)+40|0)|0;p=G;q=o;r=f;s=x;t=c[b+12>>2]|0;u=c[m>>2]|0}WHb(u);x=c[m>>2]|0;c[x+68>>2]=c[h>>2];c[x+72>>2]=c[k>>2];c[x+80>>2]=30;if((XHb(u,32)|0)<0){KIb(c[(c[a+4>>2]|0)+8>>2]|0,16,2278968,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;i=e;return}mrc(c[u>>2]|0,0,ca(c[u+32>>2]|0,c[u+72>>2]|0)|0)|0;u=c[n>>2]|0;x=c[n+32>>2]|0;if((t|0)>0){n=b+16|0;b=0;do{k=c[(c[n>>2]|0)+(b<<2)>>2]|0;a:do{if((c[k+84>>2]|0)==1){h=c[k>>2]|0;do{if((h|0)>=0){f=k+8|0;o=c[f>>2]|0;if((o+h|0)>(j|0)){break}w=c[k+4>>2]|0;if((w|0)<0){break}g=k+12|0;v=c[g>>2]|0;if((v+w|0)>(l|0)){break}z=c[k+24>>2]|0;if((v|0)<=0){break a}A=(ca(w,x)|0)+(h<<2)|0;w=k+52|0;B=u+A|0;A=c[k+20>>2]|0;C=0;D=o;o=v;while(1){if((D|0)>0){v=B;E=A;F=0;while(1){c[v>>2]=c[z+((d[E]|0)<<2)>>2];H=F+1|0;I=c[f>>2]|0;if((H|0)<(I|0)){v=v+4|0;E=E+1|0;F=H}else{break}}J=I;K=c[g>>2]|0}else{J=D;K=o}F=C+1|0;if((F|0)<(K|0)){B=B+x|0;A=A+(c[w>>2]|0)|0;C=F;D=J;o=K}else{break a}}}}while(0);KIb(0,24,2269752,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}else{KIb(0,24,2274784,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}}while(0);b=b+1|0;}while((b|0)<(t|0))}t=c[m>>2]|0;m=t+136|0;c[m>>2]=s;c[m+4>>2]=r;m=a+208|0;c[m>>2]=s;c[m+4>>2]=r;r=a+248|0;if((c[r>>2]|0)>0){m=a+244|0;s=0;do{Pj(c[c[(c[m>>2]|0)+(s<<2)>>2]>>2]|0,t,12)|0;s=s+1|0;}while((s|0)<(c[r>>2]|0))}r=a+216|0;c[r>>2]=q;c[r+4>>2]=p;i=e;return}function Xh(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0,db=0,eb=0,fb=0.0,gb=0.0,hb=0,ib=0,jb=0,kb=0.0,lb=0.0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0.0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0;b=i;i=i+664|0;d=b|0;e=b+8|0;f=b+16|0;j=b+96|0;k=b+104|0;l=b+112|0;m=b+120|0;n=b+200|0;o=b+592|0;if((c[1371156]|0)<=0){p=0;i=b;return p|0}q=b+528|0;s=b+208|0;t=b+240|0;u=b+272|0;v=b+304|0;w=b+336|0;x=b+368|0;y=b+400|0;z=b+432|0;A=b+464|0;B=b+496|0;C=m+24|0;D=m+28|0;E=m+8|0;F=m+16|0;H=m+36|0;I=l|0;J=l+4|0;K=k|0;L=k+4|0;M=b+600|0;N=b+632|0;O=f+24|0;P=f+28|0;Q=f+8|0;R=f+16|0;S=f+48|0;T=e|0;U=e+4|0;V=d|0;W=d+4|0;X=o|0;Y=o+4|0;Z=0;a:while(1){_=c[(c[1366870]|0)+(Z<<2)>>2]|0;$=_|0;aa=c[(c[1366872]|0)+(c[$>>2]<<2)>>2]|0;ba=_+12|0;ca=c[(c[ba>>2]|0)+8>>2]|0;da=c[_+300>>2]|0;do{if((da|0)!=0){ea=c[da>>2]|0;fa=_+72|0;ga=c[fa>>2]|0;if((ga|0)==0){ha=UHb()|0;c[fa>>2]=ha;if((ha|0)==0){p=-12;ia=187;break a}else{ja=ha}}else{ja=ga}ga=Gj(ea,ja,2)|0;if((ga|0)<0){ka=ga}else{ga=_+344|0;ha=ja+136|0;fa=ea+16|0;la=_+92|0;ma=ja+124|0;na=ca+224|0;oa=aa|0;pa=_+8|0;qa=_+76|0;ra=_+80|0;sa=_+32|0;ta=_+20|0;ua=_+64|0;va=ja+296|0;wa=ja+168|0;xa=ja+88|0;ya=_+108|0;za=_+104|0;Aa=_+100|0;Ba=_+116|0;Ca=_+152|0;Da=_+120|0;Ea=_+136|0;Fa=_+144|0;Ga=_+128|0;Ha=_+4|0;Ia=_+296|0;Ja=ja+300|0;Ka=_+88|0;La=ja;Ma=_+40|0;Na=ca+104|0;Oa=Na|0;Pa=ca+108|0;Qa=ca+12|0;Ra=ca+416|0;Sa=ja+76|0;Ta=aa+24|0;while(1){if((c[ga>>2]|0)==0){Ua=c[ha>>2]|0;Va=c[ha+4>>2]|0;if((Ua|0)==0&(Va|0)==(-2147483648|0)){Wa=-2147483648;Xa=0}else{Ya=c[Ta>>2]|0;Za=c[Ta+4>>2]|0;_a=(Ya|0)==0&(Za|0)==(-2147483648|0);$a=XIb(Ua,Va,(c[c[fa>>2]>>2]|0)+56|0,Na)|0;Va=G;c[X>>2]=1;c[Y>>2]=1e6;Ua=XIb(_a?0:Ya,_a?0:Za,o,Na)|0;Za=xrc($a,Va,Ua,G)|0;Ua=G;c[ha>>2]=Za;c[ha+4>>2]=Ua;Wa=Ua;Xa=Za}Za=c[(c[c[fa>>2]>>2]|0)+16>>2]|0;b:do{if((Za|0)==0){c[ha>>2]=Xa;c[ha+4>>2]=Wa;if((c[la>>2]|0)==0){Ua=c[ma+4>>2]|0;c[na>>2]=c[ma>>2];c[na+4>>2]=Ua}if((c[2369570]|0)!=0){mrc(M|0,0,32)|0;a[M]=0;Ua=c[ha>>2]|0;Va=c[ha+4>>2]|0;if((Ua|0)==0&(Va|0)==(-2147483648|0)){Rb(M|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(M|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=Ua,c[ab+8>>2]=Va,ab)|0)|0;i=ab}mrc(N|0,0,32)|0;a[N]=0;Va=c[ha>>2]|0;Ua=c[ha+4>>2]|0;if((Va|0)==0&(Ua|0)==(-2147483648|0)){Rb(N|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(N|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(Va>>>0)+ +(Ua|0)*4294967296.0)*(+(c[Oa>>2]|0)/+(c[Pa>>2]|0)),ab)|0)|0;i=ab}Ua=c[Oa>>2]|0;Va=c[Pa>>2]|0;KIb(0,32,2113800,(ab=i,i=i+32|0,c[ab>>2]=M,c[ab+8>>2]=N,c[ab+16>>2]=Ua,c[ab+24>>2]=Va,ab)|0);i=ab}Va=c[oa>>2]|0;Ua=c[(c[ba>>2]|0)+8>>2]|0;$a=c[pa>>2]|0;do{if(($a|0)>-1){_a=c[(c[1475748]|0)+($a<<2)>>2]|0;if((_a|0)==0){bb=0.0;cb=0;db=0;break}Ya=c[_a+4>>2]|0;eb=Ya+48|0;if((c[eb>>2]|0)==0&(c[eb+4>>2]|0)==(-2147483648|0)){bb=0.0;cb=_a;db=1;break}eb=Ya+200|0;if((c[eb>>2]|0)==0&(c[eb+4>>2]|0)==(-2147483648|0)){bb=0.0;cb=_a;db=1;break}eb=c[qa>>2]|0;if((eb|0)==0){bb=0.0;cb=_a;db=1;break}bb=1.0/(+(eb|0)/+(c[ra>>2]|0)*(+(c[Ua+104>>2]|0)/+(c[Ua+108>>2]|0)));cb=_a;db=1}else{bb=0.0;cb=0;db=0}}while(0);fb=+((c[ha>>2]|0)>>>0)+ +(c[ha+4>>2]|0)*4294967296.0;gb=bb+(fb-(+((c[sa>>2]|0)>>>0)+ +(c[sa+4>>2]|0)*4294967296.0));$a=c[64350]|0;if(($a|0)==-1){_a=c[Va+8>>2]|0;do{if((irc(c[_a>>2]|0,2638424)|0)==0){hb=2}else{eb=c[_a+28>>2]|0;if((eb&1024|0)==0){ib=1}else{ib=eb>>>6&2^2}if(!(db&(ib|0)==1)){hb=ib;break}eb=c[(c[1475750]|0)+(c[cb>>2]<<2)>>2]|0;if((c[(c[eb>>2]|0)+24>>2]|0)!=1){hb=1;break}Ya=eb+16|0;hb=(c[Ya>>2]|0)==0&(c[Ya+4>>2]|0)==0?254:1}}while(0);jb=(hb|0)==1&(c[2448288]|0)!=0?254:hb}else{jb=$a}c:do{switch(jb|0){case 254:{if((c[ta>>2]|0)!=0){kb=gb;ia=44;break c}lb=gb-bb;if(lb<.5){kb=gb;ia=44;break c}_a=Lc(+lb)|0;KIb(0,48,2633576,(ab=i,i=i+8|0,c[ab>>2]=_a,ab)|0);i=ab;_a=Lc(+fb)|0;c[sa>>2]=_a;c[sa+4>>2]=(_a|0)<0|0?-1:0;kb=bb;ia=44;break};case 1:{kb=gb;ia=44;break};case 2:{if(!(gb>-.6)){mb=0;nb=0;break c}if(!(gb>.6)){mb=0;nb=1;break c}_a=Lc(+fb)|0;c[sa>>2]=_a;c[sa+4>>2]=(_a|0)<0|0?-1:0;mb=0;nb=1;break};case 255:case 0:{_a=Lc(+fb)|0;c[sa>>2]=_a;c[sa+4>>2]=(_a|0)<0|0?-1:0;mb=0;nb=1;break};default:{ia=51;break a}}}while(0);do{if((ia|0)==44){ia=0;if(kb<-1.1){mb=0;nb=0;break}if(!(kb>1.1)){mb=0;nb=1;break}$a=Lc(+kb)|0;mb=($a|0)<0|0?-1:0;nb=$a}}while(0);$a=c[ta>>2]|0;_a=xrc(c[ua>>2]|0,c[ua+4>>2]|0,$a,($a|0)<0|0?-1:0)|0;$a=G;Ya=(mb|0)>($a|0)|(mb|0)==($a|0)&nb>>>0>_a>>>0;eb=Ya?_a:nb;Ya?$a:mb;$a=eb;if(($a|0)==0){c[1371166]=(c[1371166]|0)+1;KIb(0,40,2631944,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;break}do{if(($a|0)>1){eb=$a-1|0;if(+($a|0)>+g[379634]*30.0){KIb(0,16,2629760,(ab=i,i=i+8|0,c[ab>>2]=eb,ab)|0);i=ab;c[1371166]=(c[1371166]|0)+1;break b}else{c[1371164]=(c[1371164]|0)+eb;KIb(0,40,2628e3,(ab=i,i=i+8|0,c[ab>>2]=eb,ab)|0);i=ab;break}}}while(0);if(($a|0)<=0){break}eb=Va+8|0;Ya=Ua+408|0;_a=Ua+316|0;ob=Ua+12|0;pb=Ua+668|0;qb=Ua+104|0;rb=qb|0;sb=Ua+108|0;tb=Ua+104|0;ub=Ua+804|0;vb=0;wb=0;while(1){J1(m);c[C>>2]=0;c[D>>2]=0;yb=c[sa+4>>2]|0;c[ha>>2]=c[sa>>2];c[ha+4>>2]=yb;yb=(c[(c[1366872]|0)+(c[$>>2]<<2)>>2]|0)+16|0;zb=c[yb>>2]|0;Ab=c[yb+4>>2]|0;if(!((zb|0)==(-1|0)&(Ab|0)==2147483647)){yb=xrc(c[sa>>2]|0,c[sa+4>>2]|0,c[Ma>>2]|0,c[Ma+4>>2]|0)|0;Bb=(c[(c[ba>>2]|0)+8>>2]|0)+104|0;c[I>>2]=1;c[J>>2]=1e6;if((YIb(yb,G,Bb,zb,Ab,l)|0)>-1){break}}do{if((c[(c[eb>>2]|0)+28>>2]&32|0)==0){ia=69}else{if((c[(c[ob>>2]|0)+12>>2]|0)!=14){ia=69;break}Ab=c[va>>2]|0;zb=c[ub>>2]|0;c[zb+296>>2]=Ab;Bb=c[Ja>>2]|0;c[zb+300>>2]=Bb;if((Ab|0)==0){Cb=1}else{Cb=(Bb|0)!=0?4:5}c[Ya>>2]=Cb;c[C>>2]=La;c[D>>2]=64;Bb=XIb(c[ha>>2]|0,c[ha+4>>2]|0,qb,(c[ba>>2]|0)+40|0)|0;c[E>>2]=Bb;c[E+4>>2]=G;c[H>>2]=c[H>>2]|1;Bb=c[D>>2]|0;Ab=wrc(c[846980]|0,c[846981]|0,Bb,(Bb|0)<0|0?-1:0)|0;c[846980]=Ab;c[846981]=G;Uh(Va,m,_);Db=wb}}while(0);do{if((ia|0)==69){ia=0;Ab=c[(c[ba>>2]|0)+8>>2]|0;do{if((c[Ab+88>>2]&537133056|0)!=0){Bb=c[Ka>>2]|0;if(!((Bb|0)>-1)){break}c[Ja>>2]=(Bb|0)!=0}}while(0);do{if((c[va>>2]|0)==0){c[Ya>>2]=1}else{Bb=(c[Ja>>2]|0)!=0;if((c[(c[ob>>2]|0)+12>>2]|0)==8){c[Ya>>2]=Bb?2:3;break}else{c[Ya>>2]=Bb?4:5;break}}}while(0);c[wa>>2]=c[Ab+80>>2];if((c[_a>>2]|0)==0){c[xa>>2]=0}Bb=c[ha>>2]|0;zb=c[ha+4>>2]|0;if((Bb|0)==0&(zb|0)==(-2147483648|0)){Eb=+r}else{Eb=(+(Bb>>>0)+ +(zb|0)*4294967296.0)*(+(c[tb>>2]|0)/+(c[sb>>2]|0))}yb=c[ya>>2]|0;do{if((yb|0)<(c[za>>2]|0)){Fb=(c[Aa>>2]|0)+(yb<<3)|0;Gb=c[Fb+4>>2]|0;if((zb|0)<(Gb|0)|(zb|0)==(Gb|0)&Bb>>>0<(c[Fb>>2]|0)>>>0){ia=84;break}c[ya>>2]=yb+1;ia=88}else{ia=84}}while(0);do{if((ia|0)==84){ia=0;yb=c[Ba>>2]|0;if((yb|0)==0){break}h[Ca>>3]=Eb;Bb=+XGb(yb,Da,0)!=0.0;fb=+h[Da>>3];if(Bb){h[Ea>>3]=fb;h[Fa>>3]=+h[Ca>>3];h[Ga>>3]=+h[Ga>>3]+1.0;h[Da>>3]=fb+1.0;ia=88;break}else{h[Da>>3]=fb+1.0;break}}}while(0);if((ia|0)==88){ia=0;c[xa>>2]=1;KIb(0,48,2626712,(ab=i,i=i+8|0,h[ab>>3]=Eb,ab)|0);i=ab}Th(0,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;if((c[2369570]|0)!=0){mrc(s|0,0,32)|0;a[s]=0;Bb=c[ha>>2]|0;yb=c[ha+4>>2]|0;if((Bb|0)==0&(yb|0)==(-2147483648|0)){Rb(s|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(s|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=Bb,c[ab+8>>2]=yb,ab)|0)|0;i=ab}mrc(t|0,0,32)|0;a[t]=0;yb=c[ha>>2]|0;Bb=c[ha+4>>2]|0;if((yb|0)==0&(Bb|0)==(-2147483648|0)){Rb(t|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(t|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(yb>>>0)+ +(Bb|0)*4294967296.0)*(+(c[rb>>2]|0)/+(c[sb>>2]|0)),ab)|0)|0;i=ab}Bb=c[rb>>2]|0;yb=c[sb>>2]|0;KIb(0,32,2625064,(ab=i,i=i+32|0,c[ab>>2]=s,c[ab+8>>2]=t,c[ab+16>>2]=Bb,c[ab+24>>2]=yb,ab)|0);i=ab}yb=i5a(Ua,m,ja,n)|0;Bb=c[Ha>>2]|0;Th(2623880,(ab=i,i=i+16|0,c[ab>>2]=c[$>>2],c[ab+8>>2]=Bb,ab)|0);i=ab;if((yb|0)<0){KIb(0,8,2622448,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;Hf(1)}if((c[n>>2]|0)==0){Db=wb;break}if((c[2369570]|0)!=0){mrc(u|0,0,32)|0;a[u]=0;yb=c[E>>2]|0;Bb=c[E+4>>2]|0;if((yb|0)==0&(Bb|0)==(-2147483648|0)){Rb(u|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(u|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=yb,c[ab+8>>2]=Bb,ab)|0)|0;i=ab}mrc(v|0,0,32)|0;a[v]=0;Bb=c[E>>2]|0;yb=c[E+4>>2]|0;if((Bb|0)==0&(yb|0)==(-2147483648|0)){Rb(v|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(v|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(Bb>>>0)+ +(yb|0)*4294967296.0)*(+(c[rb>>2]|0)/+(c[sb>>2]|0)),ab)|0)|0;i=ab}mrc(w|0,0,32)|0;a[w]=0;yb=c[F>>2]|0;Bb=c[F+4>>2]|0;if((yb|0)==0&(Bb|0)==(-2147483648|0)){Rb(w|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(w|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=yb,c[ab+8>>2]=Bb,ab)|0)|0;i=ab}mrc(x|0,0,32)|0;a[x]=0;Bb=c[F>>2]|0;yb=c[F+4>>2]|0;if((Bb|0)==0&(yb|0)==(-2147483648|0)){Rb(x|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(x|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(Bb>>>0)+ +(yb|0)*4294967296.0)*(+(c[rb>>2]|0)/+(c[sb>>2]|0)),ab)|0)|0;i=ab}KIb(0,32,2620760,(ab=i,i=i+32|0,c[ab>>2]=u,c[ab+8>>2]=v,c[ab+16>>2]=w,c[ab+24>>2]=x,ab)|0);i=ab}yb=c[E>>2]|0;Bb=c[E+4>>2]|0;do{if((yb|0)==0&(Bb|0)==(-2147483648|0)){if((c[(c[ob>>2]|0)+16>>2]&32|0)!=0){break}zb=c[sa>>2]|0;Ab=c[sa+4>>2]|0;c[E>>2]=zb;c[E+4>>2]=Ab;if(!((zb|0)==0&(Ab|0)==(-2147483648|0))){Hb=Ab;Ib=zb;ia=117}}else{Hb=Bb;Ib=yb;ia=117}}while(0);if((ia|0)==117){ia=0;yb=XIb(Ib,Hb,qb,(c[ba>>2]|0)+40|0)|0;c[E>>2]=yb;c[E+4>>2]=G}yb=c[F>>2]|0;Bb=c[F+4>>2]|0;if(!((yb|0)==0&(Bb|0)==(-2147483648|0))){zb=XIb(yb,Bb,qb,(c[ba>>2]|0)+40|0)|0;c[F>>2]=zb;c[F+4>>2]=G}if((c[2369570]|0)!=0){mrc(y|0,0,32)|0;a[y]=0;zb=c[E>>2]|0;Bb=c[E+4>>2]|0;if((zb|0)==0&(Bb|0)==(-2147483648|0)){Rb(y|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(y|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=zb,c[ab+8>>2]=Bb,ab)|0)|0;i=ab}mrc(z|0,0,32)|0;a[z]=0;Bb=c[E>>2]|0;zb=c[E+4>>2]|0;yb=c[ba>>2]|0;if((Bb|0)==0&(zb|0)==(-2147483648|0)){Rb(z|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(z|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(Bb>>>0)+ +(zb|0)*4294967296.0)*(+(c[yb+40>>2]|0)/+(c[yb+44>>2]|0)),ab)|0)|0;i=ab}mrc(A|0,0,32)|0;a[A]=0;yb=c[F>>2]|0;zb=c[F+4>>2]|0;if((yb|0)==0&(zb|0)==(-2147483648|0)){Rb(A|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(A|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=yb,c[ab+8>>2]=zb,ab)|0)|0;i=ab}mrc(B|0,0,32)|0;a[B]=0;zb=c[F>>2]|0;yb=c[F+4>>2]|0;Bb=c[ba>>2]|0;if((zb|0)==0&(yb|0)==(-2147483648|0)){Rb(B|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(B|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(zb>>>0)+ +(yb|0)*4294967296.0)*(+(c[Bb+40>>2]|0)/+(c[Bb+44>>2]|0)),ab)|0)|0;i=ab}KIb(0,32,2620760,(ab=i,i=i+32|0,c[ab>>2]=y,c[ab+8>>2]=z,c[ab+16>>2]=A,c[ab+24>>2]=B,ab)|0);i=ab}Bb=c[D>>2]|0;yb=wrc(c[846980]|0,c[846981]|0,Bb,(Bb|0)<0|0?-1:0)|0;c[846980]=yb;c[846981]=G;Uh(Va,m,_);P1(m);yb=c[Ia>>2]|0;if((yb|0)==0){Db=Bb;break}zb=c[pb>>2]|0;if((zb|0)==0){Db=Bb;break}xb(zb|0,yb|0)|0;Db=Bb}}while(0);Bb=wrc(c[sa>>2]|0,c[sa+4>>2]|0,1,0)|0;c[sa>>2]=Bb;c[sa+4>>2]=G;c[ta>>2]=(c[ta>>2]|0)+1;if(!((c[836152]|0)==0|(Db|0)==0)){Vh(_,Db)}Bb=vb+1|0;if((Bb|0)<($a|0)){vb=Bb;wb=Db}else{break b}}wb=c[(c[1366872]|0)+(c[$>>2]<<2)>>2]|0;c[ga>>2]=c[ga>>2]|1;if((c[wb+40>>2]|0)==0){break}vb=xrc(c[sa>>2]|0,c[sa+4>>2]|0,c[Ma>>2]|0,c[Ma+4>>2]|0)|0;$a=(c[(c[ba>>2]|0)+8>>2]|0)+104|0;c[K>>2]=1;c[L>>2]=1e6;pb=XIb(vb,G,$a,k)|0;$a=G;vb=wb+16|0;wb=c[vb>>2]|0;Va=c[vb+4>>2]|0;qb=(Va|0)>($a|0)|(Va|0)==($a|0)&wb>>>0>pb>>>0;c[vb>>2]=qb?pb:wb;c[vb+4>>2]=qb?$a:Va}else if((Za|0)==1){c[ha>>2]=Xa;c[ha+4>>2]=Wa;do{if((c[(c[Qa>>2]|0)+16>>2]&16384|0)==0){Va=c[Ra>>2]|0;if((Va|0)==(GHb(ja)|0)){break}KIb(0,16,2111984,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;break b}}while(0);Va=c[oa>>2]|0;$a=c[(c[ba>>2]|0)+8>>2]|0;c[j>>2]=0;J1(f);c[O>>2]=0;c[P>>2]=0;qb=(c[(c[1366872]|0)+(c[$>>2]<<2)>>2]|0)+16|0;vb=c[qb>>2]|0;wb=c[qb+4>>2]|0;do{if(!((vb|0)==(-1|0)&(wb|0)==2147483647)){qb=xrc(c[sa>>2]|0,c[sa+4>>2]|0,c[Ma>>2]|0,c[Ma+4>>2]|0)|0;pb=(c[(c[ba>>2]|0)+8>>2]|0)+104|0;c[T>>2]=1;c[U>>2]=1e6;if(!((YIb(qb,G,pb,vb,wb,e)|0)>-1)){break}pb=c[(c[1366872]|0)+(c[$>>2]<<2)>>2]|0;c[ga>>2]=c[ga>>2]|1;if((c[pb+40>>2]|0)==0){break b}qb=xrc(c[sa>>2]|0,c[sa+4>>2]|0,c[Ma>>2]|0,c[Ma+4>>2]|0)|0;ob=(c[(c[ba>>2]|0)+8>>2]|0)+104|0;c[V>>2]=1;c[W>>2]=1e6;sb=XIb(qb,G,ob,d)|0;ob=G;qb=pb+16|0;pb=c[qb>>2]|0;rb=c[qb+4>>2]|0;Ua=(rb|0)>(ob|0)|(rb|0)==(ob|0)&pb>>>0>sb>>>0;c[qb>>2]=Ua?sb:pb;c[qb+4>>2]=Ua?ob:rb;break b}}while(0);wb=c[ha>>2]|0;vb=c[ha+4>>2]|0;if((wb|0)==0&(vb|0)==(-2147483648|0)|(c[2547942]|0)<0){rb=c[sa>>2]|0;ob=c[sa+4>>2]|0;c[ha>>2]=rb;c[ha+4>>2]=ob;Jb=ob;Kb=rb}else{Jb=vb;Kb=wb}wb=c[Sa>>2]|0;vb=wrc(wb,(wb|0)<0|0?-1:0,Kb,Jb)|0;c[sa>>2]=vb;c[sa+4>>2]=G;if((c[P>>2]|0)==0){if((c[O>>2]|0)!=0){ia=151;break a}}Th(0,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;if((c[2369570]|0)!=0){mrc(s|0,0,32)|0;a[s]=0;vb=c[ha>>2]|0;wb=c[ha+4>>2]|0;if((vb|0)==0&(wb|0)==(-2147483648|0)){Rb(s|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(s|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=vb,c[ab+8>>2]=wb,ab)|0)|0;i=ab}mrc(t|0,0,32)|0;a[t]=0;wb=c[ha>>2]|0;vb=c[ha+4>>2]|0;rb=$a+104|0;if((wb|0)==0&(vb|0)==(-2147483648|0)){Rb(t|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab;Lb=rb|0;Mb=$a+108|0}else{ob=rb|0;rb=$a+108|0;Rb(t|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(wb>>>0)+ +(vb|0)*4294967296.0)*(+(c[ob>>2]|0)/+(c[rb>>2]|0)),ab)|0)|0;i=ab;Lb=ob;Mb=rb}rb=c[Lb>>2]|0;ob=c[Mb>>2]|0;KIb(0,32,2107144,(ab=i,i=i+32|0,c[ab>>2]=s,c[ab+8>>2]=t,c[ab+16>>2]=rb,c[ab+24>>2]=ob,ab)|0);i=ab}if((f5a($a,f,ja,j)|0)<0){KIb(0,8,2105816,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0);i=ab;Hf(1)}ob=c[Ha>>2]|0;Th(2104296,(ab=i,i=i+16|0,c[ab>>2]=c[$>>2],c[ab+8>>2]=ob,ab)|0);i=ab;if((c[j>>2]|0)==0){break}ob=c[Q>>2]|0;rb=c[Q+4>>2]|0;if(!((ob|0)==0&(rb|0)==(-2147483648|0))){vb=XIb(ob,rb,$a+104|0,(c[ba>>2]|0)+40|0)|0;c[Q>>2]=vb;c[Q+4>>2]=G}vb=c[R>>2]|0;rb=c[R+4>>2]|0;if(!((vb|0)==0&(rb|0)==(-2147483648|0))){ob=XIb(vb,rb,$a+104|0,(c[ba>>2]|0)+40|0)|0;c[R>>2]=ob;c[R+4>>2]=G}ob=c[S>>2]|0;if((ob|0)>0){rb=XIb(ob,(ob|0)<0|0?-1:0,$a+104|0,(c[ba>>2]|0)+40|0)|0;c[S>>2]=rb}if((c[2369570]|0)!=0){mrc(u|0,0,32)|0;a[u]=0;rb=c[Q>>2]|0;ob=c[Q+4>>2]|0;if((rb|0)==0&(ob|0)==(-2147483648|0)){Rb(u|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(u|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=rb,c[ab+8>>2]=ob,ab)|0)|0;i=ab}mrc(v|0,0,32)|0;a[v]=0;ob=c[Q>>2]|0;rb=c[Q+4>>2]|0;vb=c[ba>>2]|0;if((ob|0)==0&(rb|0)==(-2147483648|0)){Rb(v|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(v|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(ob>>>0)+ +(rb|0)*4294967296.0)*(+(c[vb+40>>2]|0)/+(c[vb+44>>2]|0)),ab)|0)|0;i=ab}mrc(w|0,0,32)|0;a[w]=0;vb=c[R>>2]|0;rb=c[R+4>>2]|0;if((vb|0)==0&(rb|0)==(-2147483648|0)){Rb(w|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(w|0,32,2319576,(ab=i,i=i+16|0,c[ab>>2]=vb,c[ab+8>>2]=rb,ab)|0)|0;i=ab}mrc(x|0,0,32)|0;a[x]=0;rb=c[R>>2]|0;vb=c[R+4>>2]|0;ob=c[ba>>2]|0;if((rb|0)==0&(vb|0)==(-2147483648|0)){Rb(x|0,32,2331072,(ab=i,i=i+1|0,i=i+7&-8,c[ab>>2]=0,ab)|0)|0;i=ab}else{Rb(x|0,32,2325104,(ab=i,i=i+8|0,h[ab>>3]=(+(rb>>>0)+ +(vb|0)*4294967296.0)*(+(c[ob+40>>2]|0)/+(c[ob+44>>2]|0)),ab)|0)|0;i=ab}KIb(0,32,2643752,(ab=i,i=i+32|0,c[ab>>2]=u,c[ab+8>>2]=v,c[ab+16>>2]=w,c[ab+24>>2]=x,ab)|0);i=ab}ob=c[P>>2]|0;vb=wrc(c[2547944]|0,c[2547945]|0,ob,(ob|0)<0|0?-1:0)|0;c[2547944]=vb;c[2547945]=G;Uh(Va,f,_);P1(f)}else{ia=184;break a}}while(0);WHb(ja)}else{WHb(ja)}Za=Gj(ea,ja,2)|0;if((Za|0)<0){ka=Za;break}}}if((ka|0)==(-11|0)|(ka|0)==(-541478725|0)){break}mrc(q|0,0,64)|0;a[q]=0;RGb(ka,q,64)|0;KIb(0,24,2115832,(ab=i,i=i+8|0,c[ab>>2]=q,ab)|0);i=ab}}while(0);_=Z+1|0;if((_|0)<(c[1371156]|0)){Z=_}else{p=0;ia=187;break}}if((ia|0)==51){KIb(0,0,2127408,(ab=i,i=i+24|0,c[ab>>2]=2110320,c[ab+8>>2]=2120856,c[ab+16>>2]=884,ab)|0);i=ab;Hd();return 0}else if((ia|0)==151){KIb(0,0,2127408,(ab=i,i=i+24|0,c[ab>>2]=2108672,c[ab+8>>2]=2120856,c[ab+16>>2]=708,ab)|0);i=ab;Hd();return 0}else if((ia|0)==184){KIb(0,0,2127408,(ab=i,i=i+24|0,c[ab>>2]=2110320,c[ab+8>>2]=2120856,c[ab+16>>2]=1171,ab)|0);i=ab;Hd();return 0}else if((ia|0)==187){i=b;return p|0}return 0}function Yh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[b+68>>2]|0;g=c[d>>2]|0;if((g|0)==-1){h=d;j=c[h>>2]|0;i=e;return j|0}k=f+264|0;l=f+256|0;m=f;n=f+4|0;o=d;d=g;a:while(1){if((a[(qKb(d)|0)+7|0]&8)==0){h=o;p=16;break}g=c[o>>2]|0;q=0;while(1){r=c[5915296+(q<<4)>>2]|0;if((r|0)==0){break}if((c[5915308+(q<<4)>>2]|0)==(g|0)){p=7;break}else{q=q+1|0}}do{if((p|0)==7){p=0;g=c[k>>2]|0;if((g|0)!=0){if((g|0)!=(c[5915304+(q<<4)>>2]|0)){break}}g=c[l>>2]|0;if((g|0)!=1){if((g|0)!=(c[5915304+(q<<4)>>2]|0)){break}}if((ve[c[5915300+(q<<4)>>2]&4095](b)|0)>=0){p=14;break a}if((c[l>>2]|0)!=(c[5915304+(q<<4)>>2]|0)){break}g=c[m>>2]|0;s=c[c[n>>2]>>2]|0;KIb(0,8,2491096,(t=i,i=i+24|0,c[t>>2]=r,c[t+8>>2]=g,c[t+16>>2]=s,t)|0);i=t;Hf(1)}}while(0);t=o+4|0;s=c[t>>2]|0;if((s|0)==-1){h=t;p=16;break}else{o=t;d=s}}if((p|0)==14){c[k>>2]=c[5915304+(q<<4)>>2];c[f+284>>2]=c[o>>2];h=o;j=c[h>>2]|0;i=e;return j|0}else if((p|0)==16){j=c[h>>2]|0;i=e;return j|0}return 0}function Zh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=c[a+68>>2]|0;f=c[e+276>>2]|0;do{if((f|0)!=0){if((c[b+80>>2]|0)!=(c[e+284>>2]|0)){break}g=Ee[f&511](a,b,d)|0;return g|0}}while(0);g=K4a(a,b,d)|0;return g|0}function _h(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a;a=c[d>>2]|0;e=c[d+4>>2]|0;d=b;b=c[d>>2]|0;f=c[d+4>>2]|0;if((e|0)<(f|0)|(e|0)==(f|0)&a>>>0<b>>>0){g=-1;return g|0}g=((e|0)>(f|0)|(e|0)==(f|0)&a>>>0>b>>>0)&1;return g|0}function $h(){if(a[1982096]|0){return}a[1982096]=1;return}function ai(){return 3607140}function bi(){return 2150696}function ci(){if(a[1978272]|0){return}a[1978272]=1;aj(1436920)|0;aj(1436864)|0;aj(1436808)|0;aj(1436752)|0;aj(1436696)|0;aj(1436584)|0;aj(1436528)|0;aj(1436472)|0;aj(1436416)|0;aj(1436360)|0;aj(1436304)|0;aj(1436248)|0;aj(1436192)|0;aj(1436136)|0;aj(1436080)|0;aj(1436024)|0;aj(1435968)|0;aj(1435912)|0;aj(1435856)|0;aj(1435800)|0;aj(1435744)|0;aj(1435688)|0;aj(1435632)|0;aj(1435576)|0;aj(1435520)|0;aj(1435464)|0;aj(1435408)|0;aj(1435352)|0;aj(1435296)|0;aj(1435240)|0;aj(1435184)|0;aj(1435128)|0;aj(1435072)|0;aj(1435016)|0;aj(1434960)|0;aj(1434904)|0;aj(1434848)|0;aj(1434792)|0;aj(1434736)|0;aj(1434680)|0;aj(1434624)|0;aj(1434568)|0;aj(1434512)|0;aj(1434456)|0;aj(1434400)|0;aj(1434344)|0;aj(1430888)|0;aj(1430832)|0;aj(1430776)|0;aj(1431056)|0;aj(1261648)|0;aj(1261592)|0;aj(1261536)|0;aj(1261480)|0;aj(1261424)|0;aj(1261368)|0;aj(1261312)|0;aj(1261256)|0;aj(1261200)|0;aj(1261144)|0;aj(1261088)|0;aj(1261032)|0;aj(1260976)|0;aj(1260920)|0;aj(1260864)|0;aj(1260808)|0;aj(1260752)|0;aj(1260696)|0;aj(1260640)|0;aj(1260584)|0;aj(1260528)|0;aj(1260472)|0;aj(1260416)|0;aj(1260360)|0;aj(1260304)|0;aj(1260248)|0;aj(1260192)|0;aj(1260136)|0;aj(1260024)|0;aj(1259968)|0;aj(1259912)|0;aj(1259856)|0;aj(1259800)|0;aj(1259744)|0;aj(1259688)|0;aj(1259632)|0;aj(1259576)|0;aj(1259520)|0;aj(1259464)|0;aj(1259408)|0;aj(1259352)|0;aj(1259296)|0;aj(1259072)|0;aj(1259016)|0;aj(1258960)|0;aj(1258848)|0;aj(1258904)|0;aj(1258792)|0;aj(1258736)|0;aj(1258680)|0;aj(1258624)|0;aj(1258568)|0;aj(1258512)|0;aj(1258456)|0;aj(1258400)|0;aj(1258344)|0;aj(1258288)|0;aj(1258232)|0;aj(1258176)|0;aj(1258120)|0;aj(1258064)|0;aj(1258008)|0;aj(1257952)|0;aj(1257896)|0;aj(1257840)|0;aj(1257784)|0;aj(1257728)|0;aj(1257672)|0;aj(1257616)|0;aj(1257560)|0;aj(1257504)|0;aj(1257448)|0;aj(1257392)|0;aj(1257336)|0;aj(1257280)|0;aj(1257224)|0;aj(1257168)|0;aj(1257112)|0;aj(1257056)|0;aj(1257e3)|0;aj(1256944)|0;aj(1256888)|0;aj(1256832)|0;aj(1256776)|0;aj(1256720)|0;aj(1256664)|0;aj(1256608)|0;aj(1256552)|0;aj(1256496)|0;aj(1256440)|0;aj(1256384)|0;aj(1256328)|0;aj(1256272)|0;aj(1256216)|0;aj(1256160)|0;aj(1256104)|0;aj(1256048)|0;aj(1250384)|0;aj(1250328)|0;aj(1250272)|0;aj(1250216)|0;aj(1250160)|0;aj(1250104)|0;aj(1250048)|0;aj(1249992)|0;aj(1249936)|0;aj(1249880)|0;aj(1249824)|0;aj(1250496)|0;aj(1428096)|0;aj(1428040)|0;aj(1427984)|0;aj(1427928)|0;aj(1427040)|0;aj(1426984)|0;aj(1250552)|0;aj(1431e3)|0;aj(1430944)|0;aj(1250440)|0;aj(1431112)|0;aj(1250608)|0;aj(1436640)|0;aj(1260080)|0;rl();return}function di(a,b){a=a|0;b=b|0;var d=0;a=i;i=i+8|0;d=a|0;c[d>>2]=b;VHb(d);i=a;return 0}function ei(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;d=a;a=il(b+20|0,c[b+16>>2]|0,d)|0;if((a|0)<0){e=a;return e|0}a=jl(b+8|0,0,c[b+4>>2]|0,d)|0;e=(a|0)<0?a:0;return e|0}function fi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+24|0;d=b|0;e=b+16|0;f=c[a+44>>2]|0;g=d|0;h=f+8|0;j=c[h+4>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=j;j=d+8|0;c[j>>2]=-1;c[j+4>>2]=-1;j=e|0;c[j>>2]=c[f+20>>2];c[e+4>>2]=-1;dl(a,Sk(1)|0);bl(a,Pk(g)|0);cl(a,Ok(j)|0);i=b;return 0}function gi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[(c[a>>2]|0)+44>>2]|0;f=e+24|0;g=oi(a,c[f>>2]|0)|0;c[d>>2]=g;if((g|0)==0){h=-12;i=b;return h|0}j=e+32|0;k=c[j+4>>2]|0;l=g+136|0;c[l>>2]=c[j>>2];c[l+4>>2]=k;k=e+8|0;e=c[k+4>>2]|0;l=g+352|0;c[l>>2]=c[k>>2];c[l+4>>2]=e;c[g+344>>2]=c[a+48>>2];e=lj(a,$Hb(g)|0)|0;VHb(d);if((e|0)<0){h=e;i=b;return h|0}d=c[f>>2]|0;f=wrc(c[j>>2]|0,c[j+4>>2]|0,d,(d|0)<0|0?-1:0)|0;c[j>>2]=f;c[j+4>>2]=G;h=e;i=b;return h|0}function hi(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+128|0;d=a|0;a=c[(c[d>>2]|0)+44>>2]|0;e=b|0;f=a+8|0;sGb(e,128,0,c[f>>2]|0,c[f+4>>2]|0);f=c[a+24>>2]|0;KIb(c[d>>2]|0,40,2537224,(d=i,i=i+24|0,c[d>>2]=c[a+20>>2],c[d+8>>2]=e,c[d+16>>2]=f,d)|0);i=d;i=b;return 0}function ii(a){a=a|0;var d=0,e=0,f=0,g=0.0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0;d=c[a+44>>2]|0;a=hJb(65536)|0;e=d+40|0;c[e>>2]=a;if((a|0)==0){f=-12;return f|0}a=d+8|0;g=+Jqc(+h[a>>3],32);i=d+28|0;j=c[i>>2]|0;c[d+60>>2]=~~(g/+(j|0)+.5);k=c[e>>2]|0;b[k>>1]=0;b[k+16384>>1]=32760;e=8192;while(1){l=e>>>1;m=65536;n=0;while(1){o=n+e|0;p=(b[k+(o<<1)>>1]|0)+(b[k+(n<<1)>>1]|0)|0;q=8192-n|0;r=(b[k+(q-e<<1)>>1]|0)+(b[k+(q<<1)>>1]|0)|0;s=(ca(r,r)|0)+(ca(p,p)|0)|0;t=0;u=m;while(1){v=u;w=0;x=Erc(v,w,s,t)|0;y=Frc(0,1073217600,x,G)|0;x=wrc(y,G,1,0)|0;y=wrc(x,G,v,w)|0;w=y>>>1|G<<31;if((u|0)==(w|0)){break}else{u=w}}b[k+(n+l<<1)>>1]=((ca(u,p)|0)+32767|0)>>>16;b[k+(q-l<<1)>>1]=((ca(u,r)|0)+32768|0)>>>16;if(o>>>0<4096>>>0){m=u;n=o}else{break}}if(e>>>0>3>>>0){e=l}else{z=0;break}}while(1){e=k+(z<<1)|0;b[e>>1]=((b[e>>1]|0)+4|0)>>>3;e=z+1|0;if(e>>>0<8193>>>0){z=e}else{A=0;break}}while(1){b[k+(16384-A<<1)>>1]=b[k+(A<<1)>>1]|0;z=A+1|0;if(z>>>0<8192>>>0){A=z}else{B=0;break}}do{b[k+(B+16384<<1)>>1]=-(b[k+(B<<1)>>1]|0);B=B+1|0;}while(B>>>0<16384>>>0);g=+h[d+16>>3];if(!(g!=0.0)){f=0;return f|0}c[d+64>>2]=j;c[d+72>>2]=(j>>>0)/25|0;C=+Jqc(g*+h[a>>3],32);c[d+80>>2]=~~(C/+(c[i>>2]|0)+.5);f=0;return f|0}function ji(a){a=a|0;mJb((c[a+44>>2]|0)+40|0);return}function ki(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+8|0;d=b|0;e=d|0;c[e>>2]=c[(c[a+44>>2]|0)+28>>2];c[d+4>>2]=-1;dl(a,Ok(684216)|0);bl(a,Pk(687160)|0);cl(a,Ok(e)|0);i=b;return 0}function li(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[(c[a>>2]|0)+44>>2]|0;e=c[d+24>>2]|0;f=d+32|0;g=c[f>>2]|0;h=c[f+4>>2]|0;do{if((g|0)==0&(h|0)==0){i=e}else{f=(e|0)<0|0?-1:0;j=d+48|0;k=xrc(g,h,c[j>>2]|0,c[j+4>>2]|0)|0;j=G;l=(f|0)>(j|0)|(f|0)==(j|0)&e>>>0>k>>>0?k:e;if((l|0)==0){m=-541478725}else{i=l;break}return m|0}}while(0);e=oi(a,i)|0;if((e|0)==0){m=-12;return m|0}h=c[e>>2]|0;if((i|0)>0){g=d+56|0;l=c[d+40>>2]|0;k=c[d+60>>2]|0;j=d+68|0;f=c[d+72>>2]|0;n=d+76|0;o=d+80|0;p=c[d+64>>2]|0;q=c[g>>2]|0;r=ca(i,k)|0;s=0;t=q;u=c[j>>2]|0;while(1){v=b[l+(t>>>17<<1)>>1]|0;w=h+(s<<1)|0;b[w>>1]=v;if(u>>>0<f>>>0){x=c[n>>2]|0;b[w>>1]=v+(b[l+(x>>>17<<1)>>1]<<1);c[n>>2]=x+(c[o>>2]|0)}x=u+1|0;y=(x|0)==(p|0)?0:x;x=s+1|0;if((x|0)<(i|0)){s=x;t=t+k|0;u=y}else{break}}c[g>>2]=q+r;c[j>>2]=y}y=d+48|0;d=c[y+4>>2]|0;j=e+136|0;c[j>>2]=c[y>>2];c[j+4>>2]=d;d=wrc(c[y>>2]|0,c[y+4>>2]|0,i,(i|0)<0|0?-1:0)|0;c[y>>2]=d;c[y+4>>2]=G;m=lj(a,e)|0;return m|0}function mi(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;a=b+32|0;d=c[b+28>>2]|0;b=VIb(c[a>>2]|0,c[a+4>>2]|0,d,(d|0)<0|0?-1:0,1e6,0)|0;c[a>>2]=b;c[a+4>>2]=G;return 0}function ni(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[c[(c[a+8>>2]|0)+32>>2]>>2]|0;a=c[(c[d+12>>2]|0)+24>>2]|0;do{if((a|0)!=0){e=We[a&2047](d,b)|0;if((e|0)==0){break}else{f=e}return f|0}}while(0);f=pi(d,b)|0;return f|0}function oi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[(c[a+12>>2]|0)+24>>2]|0;do{if((d|0)!=0){e=We[d&2047](a,b)|0;if((e|0)==0){break}else{f=e}return f|0}}while(0);f=pi(a,b)|0;return f|0}function pi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=UHb()|0;c[e>>2]=f;g=a+148|0;h=c[g>>2]|0;j=a+40|0;do{if((h|0)==(rGb(c[j>>2]|0,c[j+4>>2]|0)|0)){k=f}else{if((rGb(c[j>>2]|0,c[j+4>>2]|0)|0)==0){k=c[e>>2]|0;break}else{KIb(0,0,2133432,(l=i,i=i+24|0,c[l>>2]=2484080,c[l+8>>2]=2385664,c[l+16>>2]=47,l)|0);i=l;Hd();return 0}}}while(0);if((k|0)==0){m=0;i=d;return m|0}c[k+76>>2]=b;f=a+52|0;c[k+80>>2]=c[f>>2];HHb(k,c[g>>2]|0);g=c[j+4>>2]|0;l=k+352|0;c[l>>2]=c[j>>2];c[l+4>>2]=g;c[k+344>>2]=c[a+48>>2];if((XHb(k,0)|0)<0){VHb(e);m=0;i=d;return m|0}else{VKb(c[k+64>>2]|0,0,b,h,c[f>>2]|0)|0;m=c[e>>2]|0;i=d;return m|0}return 0}function qi(a){a=a|0;VHb((c[a+44>>2]|0)+4|0);return}function ri(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;c[d>>2]=0;e=c[c[a+16>>2]>>2]|0;f=c[c[a+32>>2]>>2]|0;a=Ok(683856)|0;if((a|0)==0){g=-12;i=b;return g|0}Yk(a,e+68|0);Rk(d,3,0)|0;Xk(c[d>>2]|0,e+84|0);d=Uk()|0;if((d|0)==0){g=-12;i=b;return g|0}Yk(d,e+76|0);e=Ok(686760)|0;if((e|0)==0){g=-12;i=b;return g|0}Yk(e,f+64|0);g=0;i=b;return g|0}function si(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[(c[a>>2]|0)+44>>2]|0;d=b+8|0;c[a+20>>2]=c[d>>2];e=b+12|0;c[a+24>>2]=c[e>>2];c[a+28>>2]=1;c[a+32>>2]=1;f=b+64|0;g=a+116|0;a=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=a;c[b+16>>2]=(c[d>>2]|0)/2|0;c[b+20>>2]=(c[e>>2]|0)/2|0;return 0}function ti(e,f){e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0,S=0,T=0,U=0.0,V=0.0,W=0,X=0,Y=0;j=i;i=i+8|0;k=j|0;c[k>>2]=f;l=c[e+8>>2]|0;e=c[c[l+32>>2]>>2]|0;m=c[l+44>>2]|0;l=c[m+16>>2]|0;n=c[m+20>>2]|0;o=m+56|0;p=+h[o>>3];q=m+4|0;r=c[q>>2]|0;do{if((r|0)==0){s=e+20|0;t=5}else{u=e+20|0;if((c[r+68>>2]|0)!=(c[u>>2]|0)){s=u;t=5;break}if((c[r+72>>2]|0)==(c[e+24>>2]|0)){v=f;w=r}else{s=u;t=5}}}while(0);if((t|0)==5){VHb(q);r=e+24|0;f=bv(e,c[s>>2]|0,c[r>>2]|0)|0;c[q>>2]=f;if((f|0)==0){VHb(k);x=-12;i=j;return x|0}if((c[r>>2]|0)>0){u=0;y=f;while(1){z=(c[y>>2]|0)+(ca(c[y+32>>2]|0,u)|0)|0;mrc(z|0,0,c[s>>2]<<2|0)|0;z=u+1|0;A=c[q>>2]|0;if((z|0)<(c[r>>2]|0)){u=z;y=A}else{B=A;break}}}else{B=f}v=c[k>>2]|0;w=B}B=v+136|0;f=c[B+4>>2]|0;y=w+136|0;c[y>>2]=c[B>>2];c[y+4>>2]=f;f=c[w+32>>2]|0;y=m+40|0;do{if((c[y>>2]|0)==0){if((c[m+44>>2]|0)!=0){t=13;break}if((c[m+48>>2]|0)==0){C=v}else{t=13}}else{t=13}}while(0);do{if((t|0)==13){B=m+12|0;u=c[B>>2]|0;if((u|0)<=0){C=v;break}r=m+8|0;s=m+44|0;A=m+48|0;z=0;D=c[w>>2]|0;E=c[r>>2]|0;F=u;while(1){if((E<<2|0)>0){u=0;do{G=D+u|0;H=(d[G]|0)-(c[y>>2]|0)|0;a[G]=(H|0)>0?H&255:0;H=D+(u|1)|0;G=(d[H]|0)-(c[s>>2]|0)|0;a[H]=(G|0)>0?G&255:0;G=D+(u|2)|0;H=(d[G]|0)-(c[A>>2]|0)|0;a[G]=(H|0)>0?H&255:0;u=u+4|0;I=c[r>>2]|0;}while((u|0)<(I<<2|0));J=I;K=c[B>>2]|0}else{J=E;K=F}u=z+1|0;if((u|0)<(K|0)){z=u;D=D+f|0;E=J;F=K}else{break}}C=c[k>>2]|0}}while(0);K=c[C+80>>2]|0;do{if((K|0)==3){if((c[C+76>>2]|0)<=0){break}J=m+24|0;L=+(l|0);M=+(n|0);f=m+12|0;I=m+8|0;y=m+28|0;w=m+32|0;v=m+36|0;F=0;E=C;while(1){D=c[E>>2]|0;z=F<<1;B=D+(z<<2)|0;N=+g[D+((z|1)<<2)>>2];if((c[J>>2]|0)==0){O=+g[B>>2];P=p*(N-O)*.5;Q=1.0-p*(N+O)*.5}else{P=p*N;Q=p*+g[B>>2]+1.0}B=~~(L*(P+1.0));z=~~(M*Q);D=c[q>>2]|0;r=c[D+32>>2]|0;A=c[f>>2]|0;do{if(+h[o>>3]>1.0){if(!(A>>>0>z>>>0)){R=E;break}if((c[I>>2]|0)>>>0>B>>>0){S=B;T=z;t=41}else{R=E}}else{s=A-1|0;u=(c[I>>2]|0)-1|0;S=u>>>0<B>>>0?u:B;T=s>>>0<z>>>0?s:z;t=41}}while(0);if((t|0)==41){t=0;z=(S<<2)+(ca(T,r)|0)|0;B=c[D>>2]|0;A=B+z|0;s=(d[A]|0)+(c[y>>2]|0)|0;a[A]=(s|0)>255?-1:s&255;s=B+(z+1)|0;A=(d[s]|0)+(c[w>>2]|0)|0;a[s]=(A|0)>255?-1:A&255;A=B+(z+2)|0;z=(d[A]|0)+(c[v>>2]|0)|0;a[A]=(z|0)>255?-1:z&255;R=c[k>>2]|0}z=F+1|0;if((z|0)<(c[R+76>>2]|0)){F=z;E=R}else{break}}}else if((K|0)==1){if((c[C+76>>2]|0)<=0){break}E=m+24|0;M=+(l|0);L=+(n|0);F=m+12|0;v=m+8|0;w=m+28|0;y=m+32|0;I=m+36|0;f=0;J=C;while(1){z=c[J>>2]|0;A=f<<1;B=z+(A<<1)|0;s=b[z+((A|1)<<1)>>1]|0;A=s<<16>>16;if((c[E>>2]|0)==0){z=b[B>>1]|0;U=p*+(A-z|0)/65535.0;V=1.0-p*+(z+A|0)/65535.0}else{U=p*+(s<<16>>16|0)/32767.0;V=p*+(b[B>>1]|0)/32767.0+1.0}B=~~(M*(U+1.0));s=~~(L*V);A=c[q>>2]|0;z=c[A+32>>2]|0;u=c[F>>2]|0;do{if(+h[o>>3]>1.0){if(!(u>>>0>s>>>0)){W=J;break}if((c[v>>2]|0)>>>0>B>>>0){X=B;Y=s;t=32}else{W=J}}else{H=u-1|0;G=(c[v>>2]|0)-1|0;X=G>>>0<B>>>0?G:B;Y=H>>>0<s>>>0?H:s;t=32}}while(0);if((t|0)==32){t=0;s=(X<<2)+(ca(Y,z)|0)|0;B=c[A>>2]|0;u=B+s|0;D=(d[u]|0)+(c[w>>2]|0)|0;a[u]=(D|0)>255?-1:D&255;D=B+(s+1)|0;u=(d[D]|0)+(c[y>>2]|0)|0;a[D]=(u|0)>255?-1:u&255;u=B+(s+2)|0;s=(d[u]|0)+(c[I>>2]|0)|0;a[u]=(s|0)>255?-1:s&255;W=c[k>>2]|0}s=f+1|0;if((s|0)<(c[W+76>>2]|0)){f=s;J=W}else{break}}}}while(0);VHb(k);x=lj(e,$Hb(c[q>>2]|0)|0)|0;i=j;return x|0}function ui(a){a=a|0;var b=0,d=0.0,e=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=+(c[a+48>>2]|0)/(+(c[b+64>>2]|0)/+(c[b+68>>2]|0))+.5;if(d<1024.0){e=1024}else{e=~~d}c[a+136>>2]=e;c[a+132>>2]=e;c[a+128>>2]=e;return 0}function vi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+128|0;d=b|0;e=b+64|0;f=c[a+44>>2]|0;g=f+12|0;h=f+4|0;if((c[g>>2]|0)==0){j=h}else{k=d|0;l=d+4|0;m=d+8|0;n=d+12|0;o=d+16|0;p=d+20|0;q=d+24|0;r=d+28|0;s=d+32|0;t=d+36|0;u=d+40|0;v=a+24|0;w=a+12|0;x=a+16|0;y=a+20|0;z=0;while(1){A=h;if((c[A>>2]|0)!=0){B=0;do{mrc(d|0,0,20)|0;c[p>>2]=104;c[q>>2]=732;c[r>>2]=0;c[s>>2]=0;c[t>>2]=246;mrc(u|0,0,20)|0;C=FFb(2214248,(D=i,i=i+24|0,c[D>>2]=z,c[D+8>>2]=118,c[D+16>>2]=B,D)|0)|0;i=D;c[k>>2]=C;Qi(c[v>>2]|0,v,12,w,x,d)|0;c[y>>2]=c[v>>2];B=B+1|0;}while(B>>>0<(c[A>>2]|0)>>>0)}B=f+8|0;if((c[B>>2]|0)!=0){C=0;do{c[k>>2]=0;c[l>>2]=1;c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;c[p>>2]=104;c[q>>2]=732;c[r>>2]=0;c[s>>2]=0;c[t>>2]=246;mrc(u|0,0,20)|0;E=FFb(2214248,(D=i,i=i+24|0,c[D>>2]=z,c[D+8>>2]=97,c[D+16>>2]=C,D)|0)|0;i=D;c[k>>2]=E;Qi(c[v>>2]|0,v,12,w,x,d)|0;c[y>>2]=c[v>>2];C=C+1|0;}while(C>>>0<(c[B>>2]|0)>>>0)}B=z+1|0;if(B>>>0<(c[g>>2]|0)>>>0){z=B}else{j=A;break}}}z=e;g=e+4|0;v=e+44|0;y=e+48|0;d=e|0;x=a+40|0;w=a+28|0;k=a+32|0;u=a+36|0;if((c[j>>2]|0)!=0){t=0;do{mrc(e|0,0,60)|0;c[v>>2]=876;c[y>>2]=2742;s=FFb(2152992,(D=i,i=i+16|0,c[D>>2]=118,c[D+8>>2]=t,D)|0)|0;i=D;c[d>>2]=s;Qi(c[x>>2]|0,x,4,w,k,e)|0;c[u>>2]=c[x>>2];t=t+1|0;}while(t>>>0<(c[j>>2]|0)>>>0)}j=f+8|0;if((c[j>>2]|0)!=0){t=0;do{mrc(z|0,0,60)|0;c[g>>2]=1;c[v>>2]=876;c[y>>2]=2742;s=FFb(2152992,(D=i,i=i+16|0,c[D>>2]=97,c[D+8>>2]=t,D)|0)|0;i=D;c[d>>2]=s;Qi(c[x>>2]|0,x,4,w,k,e)|0;c[u>>2]=c[x>>2];t=t+1|0;}while(t>>>0<(c[j>>2]|0)>>>0)}j=qJb(c[a+24>>2]|0,1048)|0;c[f+40>>2]=j;if((j|0)==0){F=-12;i=b;return F|0}c[f+32>>2]=c[x>>2];F=0;i=b;return F|0}function wi(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+8|0;f=d|0;g=c[a+44>>2]|0;h=a+24|0;if((c[h>>2]|0)!=0){j=a+12|0;k=g+40|0;l=0;do{mJb((c[j>>2]|0)+(l*60|0)|0);m=c[k>>2]|0;n=m+(l*1048|0)+1046|0;o=b[n>>1]|0;if(!(o<<16>>16==0)){p=m+(l*1048|0)+1044|0;q=o;do{o=m+(l*1048|0)+20+((e[p>>1]|0)<<2)|0;r=c[o>>2]|0;b[n>>1]=q-1;c[o>>2]=0;b[p>>1]=(b[p>>1]|0)+1&255;c[f>>2]=r;VHb(f);q=b[n>>1]|0;}while(!(q<<16>>16==0))}l=l+1|0;}while(l>>>0<(c[h>>2]|0)>>>0)}h=a+40|0;if((c[h>>2]|0)==0){s=g+40|0;t=s;u=c[t>>2]|0;v=u;kJb(v);i=d;return}l=a+28|0;a=0;do{mJb((c[l>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[h>>2]|0)>>>0);s=g+40|0;t=s;u=c[t>>2]|0;v=u;kJb(v);i=d;return}function xi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[a+44>>2]|0;d=b+4|0;e=a+32|0;f=b+12|0;b=a+16|0;g=a+40|0;a=0;h=0;i=0;j=0;a:while(1){k=c[d+(a<<2)>>2]|0;if((k|0)==0){l=h;m=i;n=j}else{o=(a|0)==1;p=h;q=0;r=i;s=j;while(1){t=Sk(a)|0;if((t|0)==0){u=-12;v=15;break a}Yk(t,(c[(c[e>>2]|0)+(p<<2)>>2]|0)+64|0);if(o){w=Uk()|0;if((w|0)==0){u=-12;v=15;break a}Yk(w,(c[(c[e>>2]|0)+(p<<2)>>2]|0)+72|0);x=Vk()|0;if((x|0)==0){u=-12;v=15;break a}Xk(x,(c[(c[e>>2]|0)+(p<<2)>>2]|0)+80|0);y=x;z=w}else{y=s;z=r}if((c[f>>2]|0)!=0){if(o){w=p;x=0;while(1){Yk(t,(c[(c[b>>2]|0)+(w<<2)>>2]|0)+68|0);Yk(z,(c[(c[b>>2]|0)+(w<<2)>>2]|0)+76|0);Xk(y,(c[(c[b>>2]|0)+(w<<2)>>2]|0)+84|0);A=x+1|0;if(A>>>0<(c[f>>2]|0)>>>0){w=(c[g>>2]|0)+w|0;x=A}else{break}}}else{x=p;w=0;while(1){Yk(t,(c[(c[b>>2]|0)+(x<<2)>>2]|0)+68|0);A=w+1|0;if(A>>>0<(c[f>>2]|0)>>>0){x=(c[g>>2]|0)+x|0;w=A}else{break}}}}w=p+1|0;x=q+1|0;if(x>>>0<k>>>0){p=w;q=x;r=z;s=y}else{l=w;m=z;n=y;break}}}s=a+1|0;if(s>>>0<2>>>0){a=s;h=l;i=m;j=n}else{u=0;v=15;break}}if((v|0)==15){return u|0}return 0}function yi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+8>>2]|0;return bv(c[(c[e+32>>2]|0)+((((((c[a+12>>2]|0)-(c[e+12>>2]|0)|0)/60|0)>>>0)%((c[e+40>>2]|0)>>>0)|0)<<2)>>2]|0,b,d)|0}function zi(a,b){a=a|0;b=b|0;var d=0;d=c[a+8>>2]|0;return oi(c[(c[d+32>>2]|0)+((((((c[a+12>>2]|0)-(c[d+12>>2]|0)|0)/60|0)>>>0)%((c[d+40>>2]|0)>>>0)|0)<<2)>>2]|0,b)|0}function Ai(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+8|0;g=f|0;h=c[a+8>>2]|0;j=c[a+12>>2]|0;c[g>>2]=d;a=c[h+44>>2]|0;k=c[h+12>>2]|0;l=(j-k|0)/60|0;j=c[a+16>>2]|0;if(l>>>0<j>>>0){KIb(h,16,2596160,(m=i,i=i+8|0,c[m>>2]=c[k+(l*60|0)>>2],m)|0);i=m;VHb(g);n=0;i=f;return n|0}if(l>>>0<((c[h+40>>2]|0)+j|0)>>>0){n=Di(h,l,d)|0;i=f;return n|0}j=c[a+40>>2]|0;a=j+(l*1048|0)+1046|0;g=b[a>>1]|0;if(g<<16>>16==256){KIb(h,24,2572520,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;m=j+(l*1048|0)+1044|0;h=e[m>>1]|0;k=(b[a>>1]|0)-1&65535;b[a>>1]=k;VHb(j+(l*1048|0)+20+(((k&65535)+h&255)<<2)|0);o=b[a>>1]|0;p=m}else{o=g;p=j+(l*1048|0)+1044|0}g=e[p>>1]|0;b[a>>1]=o+1;c[j+(l*1048|0)+20+((g+(o&65535)&255)<<2)>>2]=d;n=0;i=f;return n|0}function Bi(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;d=i;i=i+8|0;f=d|0;g=c[a>>2]|0;h=g+44|0;j=c[h>>2]|0;k=j+16|0;l=(c[k>>2]|0)+(((c[a+4>>2]|0)-(c[g+28>>2]|0)|0)/60|0)|0;a=g+24|0;if(!(l>>>0<(c[a>>2]|0)>>>0)){m=-541478725;i=d;return m|0}n=j+40|0;o=g+16|0;p=g;q=g+12|0;r=g+40|0;s=j+32|0;j=g+32|0;t=f|0;u=f+4|0;v=l;a:while(1){if((c[(c[n>>2]|0)+(v*1048|0)+16>>2]|0)==0){l=Wi(c[(c[o>>2]|0)+(v<<2)>>2]|0)|0;if(!((l|0)==-541478725)){m=l;w=35;break}l=c[h>>2]|0;c[(c[l+40>>2]|0)+(v*1048|0)+16>>2]=1;x=l+32|0;l=(c[x>>2]|0)-1|0;c[x>>2]=l;KIb(p,40,2623392,(y=i,i=i+16|0,c[y>>2]=c[(c[q>>2]|0)+(v*60|0)>>2],c[y+8>>2]=l,y)|0);i=y}l=c[k>>2]|0;x=c[r>>2]|0;z=l-1+x|0;if((c[s>>2]|0)==0){A=x}else{x=l;while(1){do{if((c[(c[n>>2]|0)+(x*1048|0)+16>>2]|0)==0){l=Wi(c[(c[o>>2]|0)+(x<<2)>>2]|0)|0;if((l|0)==-541478725){B=c[h>>2]|0;c[(c[B+40>>2]|0)+(x*1048|0)+16>>2]=1;C=B+32|0;B=(c[C>>2]|0)-1|0;c[C>>2]=B;KIb(p,40,2623392,(y=i,i=i+16|0,c[y>>2]=c[(c[q>>2]|0)+(x*60|0)>>2],c[y+8>>2]=B,y)|0);i=y;break}else{if((l|0)<0){m=l;w=35;break a}else{break}}}}while(0);if((x|0)==(z|0)){D=c[k>>2]|0}else{D=x+1|0}if((c[s>>2]|0)==0){break}else{x=D}}A=c[r>>2]|0}x=c[h>>2]|0;z=x+16|0;l=c[z>>2]|0;B=l+A|0;C=x+40|0;E=c[C>>2]|0;F=E+(l*1048|0)|0;H=c[F>>2]|0;I=c[F+4>>2]|0;F=l+1|0;if(F>>>0<B>>>0){l=I;J=H;K=F;while(1){F=E+(K*1048|0)|0;L=c[F>>2]|0;M=c[F+4>>2]|0;F=(l|0)>(M|0)|(l|0)==(M|0)&J>>>0>L>>>0;N=F?J:L;L=F?l:M;M=K+1|0;if(M>>>0<B>>>0){l=L;J=N;K=M}else{O=L;P=N;break}}}else{O=I;P=H}K=x+24|0;J=wrc(c[K>>2]|0,c[K+4>>2]|0,P,O)|0;l=G;c[K>>2]=J;c[K+4>>2]=l;c[z>>2]=B;c[x+32>>2]=c[r>>2];KIb(p,40,2105424,(y=i,i=i+16|0,c[y>>2]=J,c[y+8>>2]=l,y)|0);i=y;l=c[z>>2]|0;do{if(l>>>0<(c[a>>2]|0)>>>0){J=c[x+4>>2]|0;K=(c[x+8>>2]|0)+J|0;E=c[r>>2]|0;if(J>>>0<K>>>0){N=J;J=l;L=E;while(1){M=J-L+N|0;F=c[o>>2]|0;Q=c[h>>2]|0;R=c[(c[j>>2]|0)+(N<<2)>>2]|0;S=Q+40|0;T=(c[S>>2]|0)+(M*1048|0)|0;U=c[T>>2]|0;V=c[T+4>>2]|0;T=Q+24|0;Q=c[T>>2]|0;W=c[T+4>>2]|0;c[t>>2]=1;T=c[(c[F+(M<<2)>>2]|0)+48>>2]|0;c[u>>2]=T;F=R+40|0;X=rGb(c[F>>2]|0,c[F+4>>2]|0)|0;if((T|0)==0){m=-558323010;w=35;break a}T=(c[S>>2]|0)+(M*1048|0)|0;M=xrc(P,O,c[T>>2]|0,c[T+4>>2]|0)|0;T=R+56|0;S=XIb(M,G,T,f)|0;M=G;F=c[u>>2]|0;if((F|0)<48e3){Y=9600}else{Y=(F|0)/5|0}if(!((S|0)==0&(M|0)==0)){F=R+52|0;Z=xrc(U,V,P,O)|0;V=wrc(Z,G,Q,W)|0;W=G;Q=Y;Z=0;U=0;_=M;M=S;while(1){S=(Q|0)<0|0?-1:0;$=(S|0)>(_|0)|(S|0)==(_|0)&Q>>>0>M>>>0?M:Q;S=oi(R,$)|0;if((S|0)==0){m=-12;w=35;break a}VKb(c[S+64>>2]|0,0,$,X,c[F>>2]|0)|0;aa=XIb(U,Z,f,T)|0;ba=wrc(V,W,aa,G)|0;aa=S+136|0;c[aa>>2]=ba;c[aa+4>>2]=G;aa=lj(R,S)|0;if((aa|0)<0){m=aa;w=35;break a}aa=$;S=($|0)<0|0?-1:0;ba=wrc(aa,S,U,Z)|0;ca=G;da=xrc(M,_,aa,S)|0;if((M|0)==(aa|0)&(_|0)==(S|0)){break}else{Q=$;Z=ca;U=ba;_=G;M=da}}}M=N+1|0;_=c[z>>2]|0;U=c[r>>2]|0;if(M>>>0<K>>>0){N=M;J=_;L=U}else{ea=_;fa=U;break}}}else{ea=l;fa=E}L=ea+fa|0;if(ea>>>0<L>>>0){ga=ea}else{break}do{while(1){J=c[C>>2]|0;N=J+(ga*1048|0)+1046|0;K=b[N>>1]|0;if(K<<16>>16==0){break}U=J+(ga*1048|0)+1044|0;_=J+(ga*1048|0)+20+((e[U>>1]|0)<<2)|0;J=c[_>>2]|0;b[N>>1]=K-1;c[_>>2]=0;b[U>>1]=(b[U>>1]|0)+1&255;U=Di(g,ga,J)|0;if((U|0)<0){m=U;w=35;break a}}ga=ga+1|0;}while(ga>>>0<L>>>0)}}while(0);C=(c[r>>2]|0)+v|0;if(C>>>0<(c[a>>2]|0)>>>0){v=C}else{m=-541478725;w=35;break}}if((w|0)==35){i=d;return m|0}return 0}function Ci(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=((c[a+4>>2]|0)-(c[d+28>>2]|0)|0)/60|0;g=d+16|0;h=c[(c[g>>2]|0)+(f<<2)>>2]|0;c[a+56>>2]=1;c[a+60>>2]=1e6;j=a+20|0;c[j>>2]=c[h+20>>2];k=a+24|0;c[k>>2]=c[h+24>>2];l=a+28|0;m=h+28|0;n=l;o=c[m>>2]|0;p=c[m+4>>2]|0;c[n>>2]=o;c[n+4>>2]=p;c[a+52>>2]=c[h+52>>2];h=e+12|0;if(!((c[h>>2]|0)>>>0>1>>>0)){q=0;i=b;return q|0}p=d+40|0;m=l|0;l=a+32|0;a=d;r=d+12|0;d=e+36|0;e=2;s=f;t=o;while(1){o=(c[p>>2]|0)+s|0;u=c[(c[g>>2]|0)+(o<<2)>>2]|0;if((t|0)==0){v=u+28|0;w=c[v>>2]|0;x=c[v+4>>2]|0;c[n>>2]=w;c[n+4>>2]=x;y=w}else{y=t}w=c[j>>2]|0;x=c[u+20>>2]|0;do{if((w|0)==(x|0)){v=c[k>>2]|0;z=c[u+24>>2]|0;if((v|0)!=(z|0)){A=z;B=v;C=10;break}z=c[u+28>>2]|0;if(!((y|0)==(z|0)|(z|0)==0)){A=v;B=v;C=10;break}if((c[l>>2]|0)!=(c[u+32>>2]|0)){A=v;B=v;C=10}}else{A=c[u+24>>2]|0;B=c[k>>2]|0;C=10}}while(0);if((C|0)==10){C=0;v=c[r>>2]|0;z=c[u+28>>2]|0;D=c[u+32>>2]|0;E=c[v+(f*60|0)>>2]|0;F=c[l>>2]|0;KIb(a,16,2128352,(G=i,i=i+80|0,c[G>>2]=c[v+(o*60|0)>>2],c[G+8>>2]=x,c[G+16>>2]=A,c[G+24>>2]=z,c[G+32>>2]=D,c[G+40>>2]=E,c[G+48>>2]=w,c[G+56>>2]=B,c[G+64>>2]=y,c[G+72>>2]=F,G)|0);i=G;if((c[d>>2]|0)==0){q=-22;C=13;break}}if(!(e>>>0<(c[h>>2]|0)>>>0)){q=0;C=13;break}e=e+1|0;s=o;t=c[m>>2]|0}if((C|0)==13){i=b;return q|0}return 0}function Di(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=c[a+44>>2]|0;h=c[(c[a+16>>2]|0)+(b<<2)>>2]|0;j=c[(c[a+32>>2]|0)+(((b>>>0)%((c[a+40>>2]|0)>>>0)|0)<<2)>>2]|0;a=c[g+40>>2]|0;k=d+136|0;l=j+56|0;m=XIb(c[k>>2]|0,c[k+4>>2]|0,h+56|0,l)|0;n=G;c[k>>2]=m;c[k+4>>2]=n;o=a+(b*1048|0)|0;c[o>>2]=m;c[o+4>>2]=n;p=a+(b*1048|0)+8|0;b=c[p>>2]|0;a=c[p+4>>2]|0;q=wrc(b,a,1,0)|0;r=G;c[p>>2]=q;c[p+4>>2]=r;p=c[h+48>>2]|0;do{if((p|0)==0){h=0;if(!((a|0)>(h|0)|(a|0)==(h|0)&b>>>0>0>>>0)){break}h=VIb(m,n,q,r,b,a)|0;c[o>>2]=h;c[o+4>>2]=G}else{h=c[d+76>>2]|0;c[f>>2]=1;c[f+4>>2]=p;s=XIb(h,(h|0)<0|0?-1:0,f,l)|0;h=wrc(c[o>>2]|0,c[o+4>>2]|0,s,G)|0;c[o>>2]=h;c[o+4>>2]=G}}while(0);o=g+24|0;g=wrc(c[k>>2]|0,c[k+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[k>>2]=g;c[k+4>>2]=G;k=lj(j,d)|0;i=e;return k|0}function Ei(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;mJb(b+80|0);F1(c[b+52>>2]|0);a=b+20|0;d=b+60|0;if((c[a>>2]|0)>0){e=d;f=0;do{mJb((c[e>>2]|0)+(f<<2)|0);f=f+1|0;}while((f|0)<(c[a>>2]|0))}mJb(d);mJb(b+72|0);VHb(b+12|0);return}function Fi(a){a=a|0;var b=0,d=0,e=0;b=c[c[a+16>>2]>>2]|0;d=c[c[a+32>>2]>>2]|0;a=Ok(683848)|0;if((a|0)==0){e=-12;return e|0}Yk(a,b+68|0);a=Vk()|0;if((a|0)==0){e=-12;return e|0}Xk(a,b+84|0);a=Uk()|0;if((a|0)==0){e=-12;return e|0}Yk(a,b+76|0);b=Ok(684264)|0;if((b|0)==0){e=-12;return e|0}Yk(b,d+64|0);e=0;return e|0}function Gi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a|0;d=c[b>>2]|0;e=c[d+44>>2]|0;f=c[c[d+16>>2]>>2]|0;d=e+16|0;c[d>>2]=0;do{g=Wi(f)|0;}while((c[d>>2]|0)==0&(g|0)>-1);if(!((g|0)==-541478725)){return g|0}if((c[e+12>>2]|0)==0){return g|0}e=c[(c[b>>2]|0)+44>>2]|0;b=e+48|0;d=(c[b>>2]|0)+1|0;c[b>>2]=d;if((d|0)>=(c[a+20>>2]|0)){c[b>>2]=0}c[e+64>>2]=0;c[e+16>>2]=1;lj(a,$Hb(c[e+12>>2]|0)|0)|0;return g|0}function Hi(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0,B=0,C=0,D=0;b=i;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=c[d+44>>2]|0;h=f+4|0;j=a+20|0;c[j>>2]=c[h>>2];k=f+8|0;l=c[k>>2]|0;m=a+24|0;c[m>>2]=l;if((c[f+32>>2]|0)==0){n=l}else{n=(l|0)/(c[e+148>>2]|0)|0}c[f+24>>2]=n;l=n<<1;n=1;while(1){o=1<<n;if((o|0)<(l|0)){n=n+1|0}else{break}}l=f+56|0;do{if((n|0)!=(c[l>>2]|0)){p=f+52|0;F1(c[p>>2]|0);c[p>>2]=D1(n,0)|0;c[l>>2]=n;p=f+20|0;q=f+60|0;r=q;if((c[p>>2]|0)>0){s=0;do{mJb((c[r>>2]|0)+(s<<2)|0);s=s+1|0;}while((s|0)<(c[p>>2]|0))}mJb(q);s=c[e+148>>2]|0;c[p>>2]=s;if(!(s>>>0<65536>>>0|(s&1073741823|0)==(s|0))){t=-22;i=b;return t|0}if(!(o>>>0<65536>>>0|(o&1073741823|0)==(o|0))){t=-22;i=b;return t|0}u=o<<2;v=hJb(s<<2)|0;c[r>>2]=v;if((v|0)==0){t=-12;i=b;return t|0}else{w=0}while(1){if((w|0)>=(c[p>>2]|0)){break}v=hJb(u)|0;c[(c[r>>2]|0)+(w<<2)>>2]=v;if((c[(c[r>>2]|0)+(w<<2)>>2]|0)==0){t=-12;x=34;break}else{w=w+1|0}}if((x|0)==34){i=b;return t|0}c[f+64>>2]=0;r=f+72|0;u=jJb(c[r>>2]|0,o,4)|0;p=u;c[r>>2]=p;if((u|0)==0){t=-12;i=b;return t|0}u=c[f+76>>2]|0;do{if((u|0)==1){if((o|0)<=0){break}y=+(o-1|0);r=0;do{g[p+(r<<2)>>2]=(1.0- +U(+(r|0)*6.283185307179586/y))*.5;r=r+1|0;}while((r|0)<(o|0))}else if((u|0)==3){if((o|0)<=0){break}y=+(o-1|0);r=0;do{z=+(r|0);g[p+(r<<2)>>2]=.41999998688697815- +U(z*6.283185307179586/y)*.5+ +U(z*12.566370614359172/y)*.07999999821186066;r=r+1|0;}while((r|0)<(o|0))}else if((u|0)==2){if((o|0)<=0){break}y=+(o-1|0);r=0;do{g[p+(r<<2)>>2]=.5400000214576721- +U(+(r|0)*6.283185307179586/y)*.46000000834465027;r=r+1|0;}while((r|0)<(o|0))}else if((u|0)==0){if((o|0)>0){A=0}else{break}do{g[p+(A<<2)>>2]=1.0;A=A+1|0;}while((A|0)<(o|0))}else{KIb(0,0,2293680,(B=i,i=i+24|0,c[B>>2]=2286104,c[B+8>>2]=2282056,c[B+16>>2]=229,B)|0);i=B;Hd();return 0}}while(0);p=f+12|0;VHb(p);u=bv(a,c[j>>2]|0,c[m>>2]|0)|0;c[p>>2]=u;if((u|0)==0){t=-12;i=b;return t|0}c[a+28>>2]=1;c[a+32>>2]=1;if((c[m>>2]|0)<=0){break}p=u|0;r=u+32|0;q=u+4|0;v=u+36|0;s=u+8|0;C=u+40|0;u=0;do{D=(c[p>>2]|0)+(ca(c[r>>2]|0,u)|0)|0;mrc(D|0,0,c[j>>2]|0)|0;D=(c[q>>2]|0)+(ca(c[v>>2]|0,u)|0)|0;mrc(D|0,-128|0,c[j>>2]|0)|0;D=(c[s>>2]|0)+(ca(c[C>>2]|0,u)|0)|0;mrc(D|0,-128|0,c[j>>2]|0)|0;u=u+1|0;}while((u|0)<(c[m>>2]|0))}}while(0);a=f+48|0;if((c[a>>2]|0)>=(c[j>>2]|0)){c[a>>2]=0}a=f+80|0;c[a>>2]=jJb(c[a>>2]|0,(c[m>>2]|0)*3|0,4)|0;m=c[k>>2]|0;KIb(d,40,2278008,(B=i,i=i+24|0,c[B>>2]=c[h>>2],c[B+8>>2]=m,c[B+16>>2]=o,B)|0);i=B;t=0;i=b;return t|0}function Ii(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0.0,O=0,P=0.0,Q=0.0,R=0.0,T=0.0,W=0.0,X=0.0,Y=0,Z=0,_=0,$=0,ba=0,da=0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0.0,pa=0,qa=0.0,ra=0,sa=0.0,ta=0;f=i;i=i+16|0;h=f|0;j=f+8|0;c[j>>2]=e;k=d+8|0;l=c[k>>2]|0;m=c[l+44>>2]|0;n=c[e+76>>2]|0;o=m+68|0;c[o>>2]=0;if((n|0)==0){VHb(j);i=f;return 0}p=h|0;q=h+4|0;r=d+48|0;d=n;n=e;e=l;l=m;a:while(1){m=c[c[e+32>>2]>>2]|0;s=c[l+12>>2]|0;t=1<<(c[l+56>>2]|0)-1;u=t<<1;v=1.0/(+S(+(t|0))*32768.0);t=l+64|0;w=c[t>>2]|0;x=u-w|0;y=(x|0)>(d|0)?d:x;x=l+20|0;z=c[x>>2]|0;A=(z|0)>0;do{if(A){B=c[n+64>>2]|0;C=c[l+68>>2]|0;if((y|0)<=0){break}D=c[l+72>>2]|0;E=c[l+60>>2]|0;F=0;do{H=c[B+(F<<2)>>2]|0;I=c[E+(F<<2)>>2]|0;J=0;do{K=J+w|0;g[I+(K<<2)>>2]=+(b[H+(J+C<<1)>>1]|0)*+g[D+(K<<2)>>2];J=J+1|0;}while((J|0)<(y|0));F=F+1|0;}while((F|0)<(z|0))}}while(0);F=y+w|0;c[t>>2]=F;if((F|0)==(u|0)){F=c[l+24>>2]|0;if(A){D=l+52|0;C=l+60|0;E=0;while(1){E1(c[D>>2]|0,c[(c[C>>2]|0)+(E<<2)>>2]|0);B=E+1|0;J=c[x>>2]|0;if((B|0)<(J|0)){E=B}else{L=J;break}}}else{L=z}E=m+24|0;C=c[E>>2]|0;if((C|0)>0){D=c[l+80>>2]|0;A=0;do{u=A*3|0;g[D+(u<<2)>>2]=0.0;g[D+(u+1<<2)>>2]=127.5;g[D+(u+2<<2)>>2]=127.5;A=A+1|0;}while((A|0)<(C|0))}if((L|0)>0){C=l+32|0;A=l+36|0;D=l+44|0;z=(F|0)>0;u=l+80|0;t=l+60|0;w=l+40|0;J=0;B=L;while(1){H=c[C>>2]|0;do{if((H|0)==1){if((c[A>>2]|0)==0){M=256.0;N=256.0;O=24}else{P=256.0;Q=256.0;R=256.0}}else if((H|0)==0){T=256.0/+(B|0);I=c[A>>2]|0;if((I|0)==1){P=T;Q=T;R=T;break}else if((I|0)!=0){O=21;break a}M=T;N=T*3.141592653589793;O=24}else{O=22;break a}}while(0);do{if((O|0)==24){O=0;if((B|0)<=1){P=0.0;Q=0.0;R=M;break}T=+(J|0)*6.283185307179586/+(B|0);P=N*+U(T)*.5;Q=N*+V(T)*.5;R=M}}while(0);T=+g[D>>2];W=Q*T;X=P*T;if(z){I=ca(J,F)|0;K=0;Y=H;while(1){Z=(((Y|0)==0?0:I)+K|0)*3|0;_=c[u>>2]|0;$=_+(Z<<2)|0;ba=K<<1;da=c[(c[t>>2]|0)+(J<<2)>>2]|0;T=v*+Xb(+(+g[da+(ba<<2)>>2]),+(+g[da+((ba|1)<<2)>>2]));ba=c[w>>2]|0;if((ba|0)==1){ea=+S(T)}else if((ba|0)==2){ea=+yb(+T)}else if((ba|0)==3){fa=T<1.0?T:1.0;ea=1.0- +aa(fa>1.0e-6?fa:1.0e-6)/-13.815510557964274}else if((ba|0)==0){ea=T}else{O=32;break a}if((c[A>>2]|0)==1){ba=1;while(1){if(!(ba>>>0<7>>>0)){break}if(+g[1070304+(ba<<4)>>2]<ea){ba=ba+1|0}else{break}}da=ba-1|0;T=+g[1070304+(da<<4)>>2];do{if(ea>T){fa=+g[1070304+(ba<<4)>>2];if(ea<fa){ga=(ea-T)/(fa-T);fa=1.0-ga;ha=fa*+g[1070316+(da<<4)>>2]+ga*+g[1070316+(ba<<4)>>2];ia=fa*+g[1070312+(da<<4)>>2]+ga*+g[1070312+(ba<<4)>>2];ja=+g[1070308+(da<<4)>>2]*fa+ga*+g[1070308+(ba<<4)>>2];break}else{ha=+g[1070316+(ba<<4)>>2];ia=+g[1070312+(ba<<4)>>2];ja=+g[1070308+(ba<<4)>>2];break}}else{ha=+g[1070316+(da<<4)>>2];ia=+g[1070312+(da<<4)>>2];ja=+g[1070308+(da<<4)>>2]}}while(0);g[$>>2]=R*ja+ +g[$>>2];da=_+(Z+1<<2)|0;g[da>>2]=W*ia+ +g[da>>2];da=_+(Z+2<<2)|0;g[da>>2]=X*ha+ +g[da>>2]}else{g[$>>2]=R*ea+ +g[$>>2];da=_+(Z+1<<2)|0;g[da>>2]=W*ea+ +g[da>>2];da=_+(Z+2<<2)|0;g[da>>2]=X*ea+ +g[da>>2]}da=K+1|0;if((da|0)>=(F|0)){break}K=da;Y=c[C>>2]|0}ka=c[x>>2]|0}else{ka=B}Y=J+1|0;if((Y|0)<(ka|0)){J=Y;B=ka}else{break}}}if((c[l+28>>2]|0)==0){la=l+48|0}else{B=m+20|0;do{if((c[E>>2]|0)>0){J=s|0;x=s+32|0;C=0;do{F=c[J>>2]|0;A=ca(c[x>>2]|0,C)|0;orc(F+A|0,F+(A+1)|0,(c[B>>2]|0)-1|0)|0;C=C+1|0;ma=c[E>>2]|0;}while((C|0)<(ma|0));if((ma|0)<=0){break}C=s+4|0;x=s+36|0;J=0;do{A=c[C>>2]|0;F=ca(c[x>>2]|0,J)|0;orc(A+F|0,A+(F+1)|0,(c[B>>2]|0)-1|0)|0;J=J+1|0;na=c[E>>2]|0;}while((J|0)<(na|0));if((na|0)<=0){break}J=s+8|0;x=s+40|0;C=0;do{F=c[J>>2]|0;A=ca(c[x>>2]|0,C)|0;orc(F+A|0,F+(A+1)|0,(c[B>>2]|0)-1|0)|0;C=C+1|0;}while((C|0)<(c[E>>2]|0))}}while(0);C=l+48|0;c[C>>2]=(c[B>>2]|0)-1;la=C}C=l+80|0;x=c[E>>2]|0;J=s+32|0;b:do{if((x|0)>0){A=(ca(c[J>>2]|0,x-1|0)|0)+(c[la>>2]|0)|0;F=0;w=(c[s>>2]|0)+A|0;while(1){v=+g[(c[C>>2]|0)+((F*3|0)<<2)>>2];do{if(v<=255.0&v<0.0){oa=0.0}else{if(v>255.0){oa=255.0;break}oa=v}}while(0);a[w]=~~+Lc(+oa);Z=F+1|0;pa=c[E>>2]|0;if((Z|0)>=(pa|0)){break}F=Z;w=w+(-(c[J>>2]|0)|0)|0}w=s+36|0;if((pa|0)<=0){break}F=(ca(c[w>>2]|0,pa-1|0)|0)+(c[la>>2]|0)|0;Z=0;_=(c[s+4>>2]|0)+F|0;while(1){v=+g[(c[C>>2]|0)+((Z*3|0)+1<<2)>>2];do{if(v<=255.0&v<0.0){qa=0.0}else{if(v>255.0){qa=255.0;break}qa=v}}while(0);a[_]=~~+Lc(+qa);F=Z+1|0;ra=c[E>>2]|0;if((F|0)>=(ra|0)){break}Z=F;_=_+(-(c[w>>2]|0)|0)|0}w=s+40|0;if((ra|0)<=0){break}_=(ca(c[w>>2]|0,ra-1|0)|0)+(c[la>>2]|0)|0;Z=0;F=(c[s+8>>2]|0)+_|0;while(1){v=+g[(c[C>>2]|0)+((Z*3|0)+2<<2)>>2];do{if(v<=255.0&v<0.0){sa=0.0}else{if(v>255.0){sa=255.0;break}sa=v}}while(0);a[F]=~~+Lc(+sa);_=Z+1|0;if((_|0)>=(c[E>>2]|0)){break b}Z=_;F=F+(-(c[w>>2]|0)|0)|0}}}while(0);E=n+136|0;C=c[E>>2]|0;J=c[E+4>>2]|0;E=c[l+68>>2]|0;c[p>>2]=1;c[q>>2]=c[r>>2];x=XIb(E,(E|0)<0|0?-1:0,h,m+56|0)|0;E=wrc(x,G,C,J)|0;J=s+136|0;c[J>>2]=E;c[J+4>>2]=G;J=c[(c[m>>2]|0)+44>>2]|0;E=J+48|0;C=(c[E>>2]|0)+1|0;c[E>>2]=C;if((C|0)>=(c[m+20>>2]|0)){c[E>>2]=0}c[J+64>>2]=0;c[J+16>>2]=1;if((lj(m,$Hb(c[J+12>>2]|0)|0)|0)<0){O=86;break}}if((y|0)<0){O=86;break}c[o>>2]=(c[o>>2]|0)+y;if((d|0)==(y|0)){O=86;break}J=c[k>>2]|0;d=d-y|0;n=c[j>>2]|0;e=J;l=c[J+44>>2]|0}if((O|0)==21){KIb(0,0,2293680,(ta=i,i=i+24|0,c[ta>>2]=2286104,c[ta+8>>2]=2282056,c[ta+16>>2]=357,ta)|0);i=ta;Hd();return 0}else if((O|0)==22){KIb(0,0,2293680,(ta=i,i=i+24|0,c[ta>>2]=2286104,c[ta+8>>2]=2282056,c[ta+16>>2]=367,ta)|0);i=ta;Hd();return 0}else if((O|0)==32){KIb(0,0,2293680,(ta=i,i=i+24|0,c[ta>>2]=2286104,c[ta+8>>2]=2282056,c[ta+16>>2]=404,ta)|0);i=ta;Hd();return 0}else if((O|0)==86){VHb(j);i=f;return 0}return 0}function Ji(a){a=a|0;VHb((c[a+44>>2]|0)+24|0);return}function Ki(a){a=a|0;var b=0,d=0,e=0;b=c[c[a+16>>2]>>2]|0;d=c[c[a+32>>2]>>2]|0;a=Ok(683840)|0;if((a|0)==0){e=-12;return e|0}Yk(a,b+68|0);a=Vk()|0;if((a|0)==0){e=-12;return e|0}Xk(a,b+84|0);a=Uk()|0;if((a|0)==0){e=-12;return e|0}Yk(a,b+76|0);b=Ok(684256)|0;if((b|0)==0){e=-12;return e|0}Yk(b,d+64|0);e=0;return e|0}function Li(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a|0;d=c[b>>2]|0;e=c[d+44>>2]|0;f=c[c[d+16>>2]>>2]|0;d=e+28|0;c[d>>2]=0;do{g=Wi(f)|0;}while((c[d>>2]|0)==0&(g|0)>-1);if(!((g|0)==-541478725)){return g|0}if((c[e+24>>2]|0)==0){return g|0}e=c[(c[b>>2]|0)+44>>2]|0;b=e+24|0;if((lj(a,c[b>>2]|0)|0)>-1){c[e+28>>2]=1}c[b>>2]=0;c[e+20>>2]=0;return g|0}function Mi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=f;j=c[a>>2]|0;k=c[c[j+16>>2]>>2]|0;l=c[j+44>>2]|0;m=l+32|0;if((c[m>>2]|0)==0){n=k+48|0;o=c[l+4>>2]|0;p=+(c[n>>2]|0)/(+(o|0)*(+(c[l+12>>2]|0)/+(c[l+16>>2]|0)))+.5;if(p<1.0){q=1}else{q=~~p}c[m>>2]=q;r=o;s=n}else{r=c[l+4>>2]|0;s=k+48|0}c[l+20>>2]=0;k=l+4|0;c[a+20>>2]=r;r=l+8|0;c[a+24>>2]=c[r>>2];c[a+28>>2]=1;c[a+32>>2]=1;c[d>>2]=c[s>>2];c[d+4>>2]=c[m>>2];c[e>>2]=c[k>>2];c[e+4>>2]=1;zKb(g,d,e);e=a+116|0;a=c[f>>2]|0;d=c[f+4>>2]|0;c[e>>2]=a;c[e+4>>2]=d;e=c[r>>2]|0;r=c[m>>2]|0;KIb(j,40,2480112,(j=i,i=i+32|0,c[j>>2]=c[k>>2],c[j+8>>2]=e,h[j+16>>3]=+(a|0)/+(d|0),c[j+24>>2]=r,j)|0);i=j;i=b;return 0}function Ni(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;g=i;i=i+16|0;h=g|0;j=g+8|0;c[h>>2]=f;k=c[e+8>>2]|0;l=c[c[k+32>>2]>>2]|0;m=c[k+44>>2]|0;k=c[f+76>>2]|0;n=m+24|0;o=c[n>>2]|0;if((o|0)==0){p=0}else{p=c[o+32>>2]|0}q=c[e+148>>2]|0;r=c[m+32>>2]|0;s=255/(ca(r,q)|0)|0;a:do{if((k|0)>0){t=l+20|0;u=l+24|0;v=j|0;w=j+4|0;x=e+48|0;y=l+56|0;z=(q|0)>0;A=m+36|0;B=m+20|0;C=m+4|0;D=l|0;E=m+8|0;F=m+40|0;H=0;I=c[f>>2]|0;J=0;K=p;L=o;b:while(1){do{if((L|0)==0){M=bv(l,c[t>>2]|0,c[u>>2]|0)|0;c[n>>2]=M;if((M|0)==0){N=-12;O=34;break b}c[M+68>>2]=c[t>>2];c[M+72>>2]=c[u>>2];P=c[h>>2]|0;Q=P+136|0;R=c[Q>>2]|0;S=c[Q+4>>2]|0;Q=(I-(c[P>>2]|0)>>1|0)/(q|0)|0;c[v>>2]=1;c[w>>2]=c[x>>2];P=XIb(Q,(Q|0)<0|0?-1:0,j,y)|0;Q=wrc(P,G,R,S)|0;S=M+136|0;c[S>>2]=Q;c[S+4>>2]=G;S=c[M+32>>2]|0;if((c[u>>2]|0)<=0){T=M;U=S;break}Q=M|0;R=0;while(1){P=(c[Q>>2]|0)+(ca(R,S)|0)|0;mrc(P|0,0,c[t>>2]|0)|0;P=R+1|0;if((P|0)<(c[u>>2]|0)){R=P}else{T=M;U=S;break}}}else{T=L;U=K}}while(0);if(z){S=T|0;M=1;R=I;while(1){Q=(c[E>>2]|0)/2|0;P=Q;V=(Q|0)<0|0?-1:0;W=R+2|0;X=b[R>>1]|0;Y=VIb(X<<16>>16,X<<16>>16<0|0?-1:0,P,V,32767,0)|0;X=xrc(P,V,Y,G)|0;Y=X;X=c[F>>2]|0;do{if((X|0)==1){V=(c[u>>2]|0)-1|0;if((Y|0)<0){Z=0}else{Z=(Y|0)>(V|0)?V:Y}if((Q|0)>(Z|0)){_=Q;$=Z<<16>>16}else{_=Z;$=Q}if(($|0)<(_|0)){aa=$}else{break}do{V=(c[S>>2]|0)+((c[B>>2]|0)+(ca(aa,U)|0))|0;a[V]=(d[V]|0)+s;aa=aa+1|0;}while((aa|0)<(_|0))}else if((X|0)==0){if(!((Y|0)>-1)){break}if((Y|0)>=(c[u>>2]|0)){break}V=(c[S>>2]|0)+((c[B>>2]|0)+(ca(Y,U)|0))|0;a[V]=(d[V]|0)+s}}while(0);if((M|0)>=(q|0)){break}M=M+1|0;R=W}ba=I+(q<<1)|0}else{ba=I}R=(c[A>>2]|0)+1|0;c[A>>2]=R;if((R|0)==(r|0)){c[A>>2]=0;R=(c[B>>2]|0)+1|0;c[B>>2]=R;da=R}else{da=c[B>>2]|0}if((da|0)==(c[C>>2]|0)){ea=c[(c[D>>2]|0)+44>>2]|0;fa=ea+24|0;ga=lj(l,c[fa>>2]|0)|0;if(!((ga|0)>-1)){O=30;break}c[ea+28>>2]=1;c[fa>>2]=0;c[ea+20>>2]=0;ha=ga}else{ha=J}R=H+1|0;if((R|0)<(k|0)){H=R;I=ba;J=ha;K=U;L=c[n>>2]|0}else{ia=ha;break a}}if((O|0)==30){c[fa>>2]=0;c[ea+20>>2]=0;ia=ga;break}else if((O|0)==34){i=g;return N|0}}else{ia=0}}while(0);VHb(h);N=ia;i=g;return N|0}function Oi(){return 262756}function Pi(){return 2641496}function Qi(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c[b>>2]|0;i=h>>>0<a>>>0?h:a;a=nJb(c[e>>2]|0,h+1|0,60)|0;h=nJb(c[f>>2]|0,(c[b>>2]|0)+1|0,4)|0;j=(a|0)!=0;if(j){c[e>>2]=a}if((h|0)==0){k=-12;return k|0}c[f>>2]=h;if(!j){k=-12;return k|0}j=c[e>>2]|0;h=i+1|0;orc(j+(h*60|0)|0,j+(i*60|0)|0,((c[b>>2]|0)-i|0)*60|0|0)|0;j=c[f>>2]|0;orc(j+(h<<2)|0,j+(i<<2)|0,(c[b>>2]|0)-i<<2|0)|0;nrc((c[e>>2]|0)+(i*60|0)|0,g|0,60)|0;c[(c[f>>2]|0)+(i<<2)>>2]=0;i=(c[b>>2]|0)+1|0;c[b>>2]=i;if(!(h>>>0<i>>>0)){k=0;return k|0}g=c[f>>2]|0;f=h;h=i;while(1){i=c[g+(f<<2)>>2]|0;if((i|0)==0){l=h}else{e=i+d|0;c[e>>2]=(c[e>>2]|0)+1;l=c[b>>2]|0}e=f+1|0;if(e>>>0<l>>>0){f=e;h=l}else{k=0;break}}return k|0}function Ri(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;if(!((c[a+40>>2]|0)>>>0>b>>>0)){g=-1;i=f;return g|0}if(!((c[d+24>>2]|0)>>>0>e>>>0)){g=-1;i=f;return g|0}h=a+32|0;if((c[(c[h>>2]|0)+(b<<2)>>2]|0)!=0){g=-1;i=f;return g|0}j=d+16|0;if((c[(c[j>>2]|0)+(e<<2)>>2]|0)!=0){g=-1;i=f;return g|0}k=a+28|0;l=c[(c[k>>2]|0)+(b*60|0)+4>>2]|0;m=d+12|0;if((l|0)!=(c[(c[m>>2]|0)+(e*60|0)+4>>2]|0)){n=c[a+8>>2]|0;o=ALb(l)|0;l=c[d+8>>2]|0;p=ALb(c[(c[m>>2]|0)+(e*60|0)+4>>2]|0)|0;KIb(a,16,2462416,(q=i,i=i+48|0,c[q>>2]=n,c[q+8>>2]=b,c[q+16>>2]=(o|0)!=0?o:2371168,c[q+24>>2]=l,c[q+32>>2]=e,c[q+40>>2]=(p|0)!=0?p:2371168,q)|0);i=q;g=-22;i=f;return g|0}q=pJb(168)|0;p=q;if((q|0)==0){g=-12;i=f;return g|0}c[(c[j>>2]|0)+(e<<2)>>2]=p;c[(c[h>>2]|0)+(b<<2)>>2]=p;c[q>>2]=a;c[q+8>>2]=d;d=c[k>>2]|0;c[q+4>>2]=d+(b*60|0);c[q+12>>2]=(c[m>>2]|0)+(e*60|0);c[q+16>>2]=c[d+(b*60|0)+4>>2];c[q+52>>2]=-1;g=0;i=f;return g|0}function Si(a){a=a|0;return c[a+148>>2]|0}function Ti(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=a+12|0;h=a+8|0;j=c[h>>2]|0;k=((c[g>>2]|0)-(c[j+12>>2]|0)|0)/60|0;l=c[(c[a>>2]|0)+8>>2]|0;m=c[j+8>>2]|0;KIb(j,40,2304944,(j=i,i=i+24|0,c[j>>2]=c[b+8>>2],c[j+8>>2]=l,c[j+16>>2]=m,j)|0);i=j;c[(c[(c[h>>2]|0)+16>>2]|0)+(k<<2)>>2]=0;j=Ri(b,e,c[h>>2]|0,k)|0;if((j|0)<0){c[(c[(c[h>>2]|0)+16>>2]|0)+(k<<2)>>2]=a;n=j;i=f;return n|0}c[h>>2]=b;c[g>>2]=(c[b+12>>2]|0)+(d*60|0);c[(c[b+16>>2]|0)+(d<<2)>>2]=a;d=a+68|0;if((c[d>>2]|0)!=0){al(d,(c[(c[b+32>>2]|0)+(e<<2)>>2]|0)+68|0)}d=a+76|0;if((c[d>>2]|0)!=0){al(d,(c[(c[b+32>>2]|0)+(e<<2)>>2]|0)+76|0)}d=a+84|0;if((c[d>>2]|0)==0){n=0;i=f;return n|0}$k(d,(c[(c[b+32>>2]|0)+(e<<2)>>2]|0)+84|0);n=0;i=f;return n|0}function Ui(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;d=a+24|0;e=c[d>>2]|0;if((e|0)==0){f=0;i=b;return f|0}g=a+16|0;h=0;j=e;a:while(1){k=c[(c[g>>2]|0)+(h<<2)>>2]|0;do{if((k|0)==0){l=j}else{m=k|0;e=c[m>>2]|0;if((c[e+24>>2]|0)==0){n=0}else{n=c[c[e+16>>2]>>2]|0}o=k+104|0;c[o>>2]=0;c[o+4>>2]=-2147483648;o=k+92|0;p=c[o>>2]|0;if((p|0)==1){q=7;break a}else if((p|0)!=0){l=j;break}c[o>>2]=1;p=Ui(e)|0;if((p|0)<0){f=p;q=50;break a}p=c[(c[k+4>>2]|0)+48>>2]|0;if((p|0)==0){r=c[m>>2]|0;if((c[r+24>>2]|0)!=1){q=11;break a}}else{s=ve[p&4095](k)|0;if((s|0)<0){q=13;break a}}p=c[k+16>>2]|0;b:do{if((p|0)==0){e=k+56|0;do{if((c[e>>2]|0)==0){t=k+60|0;if((c[t>>2]|0)!=0){break}if((n|0)==0){c[k+56>>2]=1;c[t>>2]=1e6;break}else{t=n+56|0;u=e;v=c[t+4>>2]|0;c[u>>2]=c[t>>2];c[u+4>>2]=v;break}}}while(0);e=k+28|0;do{if((c[e>>2]|0)==0){v=k+32|0;if((c[v>>2]|0)!=0){q=25;break}if((n|0)==0){c[k+28>>2]=1;c[v>>2]=1;if((c[k+20>>2]|0)==0){q=35;break a}else{q=34;break}}else{v=n+28|0;u=e;t=c[v+4>>2]|0;c[u>>2]=c[v>>2];c[u+4>>2]=t;break}}else{q=25}}while(0);do{if((q|0)==25){q=0;if((n|0)!=0){break}if((c[k+20>>2]|0)==0){q=35;break a}else{q=34}}}while(0);if((q|0)==34){q=0;if((c[k+24>>2]|0)==0){q=35;break a}else{break}}e=k+116|0;do{if((c[e>>2]|0)==0){if((c[k+120>>2]|0)!=0){break}t=n+116|0;u=e;v=c[t+4>>2]|0;c[u>>2]=c[t>>2];c[u+4>>2]=v}}while(0);e=k+20|0;if((c[e>>2]|0)==0){c[e>>2]=c[n+20>>2]}e=k+24|0;if((c[e>>2]|0)!=0){break}c[e>>2]=c[n+24>>2]}else if((p|0)==1){do{if((n|0)==0){w=c[k+56>>2]|0;q=42}else{e=k+56|0;if((c[e>>2]|0)!=0){break b}if((c[k+60>>2]|0)==0){v=n+56|0;u=e;e=c[v>>2]|0;t=c[v+4>>2]|0;c[u>>2]=e;c[u+4>>2]=t;w=e;q=42;break}else{break}}}while(0);if((q|0)==42){q=0;if((w|0)!=0){break}}e=k+60|0;if((c[e>>2]|0)!=0){break}t=c[k+48>>2]|0;c[k+56>>2]=1;c[e>>2]=t}}while(0);p=c[(c[k+12>>2]|0)+48>>2]|0;if((p|0)!=0){x=ve[p&4095](k)|0;if((x|0)<0){q=47;break a}}c[o>>2]=2;l=c[d>>2]|0}}while(0);p=h+1|0;if(p>>>0<l>>>0){h=p;j=l}else{f=0;q=50;break}}if((q|0)==7){KIb(a,32,2253032,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;f=0;i=b;return f|0}else if((q|0)==11){KIb(r,16,2210048,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;f=-22;i=b;return f|0}else if((q|0)==13){r=c[m>>2]|0;KIb(r,16,2177352,(y=i,i=i+8|0,c[y>>2]=c[r+8>>2],y)|0);i=y;f=s;i=b;return f|0}else if((q|0)==35){KIb(c[m>>2]|0,16,2149192,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;f=-22;i=b;return f|0}else if((q|0)==47){KIb(c[m>>2]|0,16,2125280,(y=i,i=i+8|0,c[y>>2]=c[(c[k+8>>2]|0)+8>>2],y)|0);i=y;f=x;i=b;return f|0}else if((q|0)==50){i=b;return f|0}return 0}function Vi(a,b,d){a=a|0;b=b|0;d=d|0;d=i;i=i+128|0;if((c[b+16>>2]|0)==0){i=d;return}a=b+40|0;sGb(d|0,128,-1,c[a>>2]|0,c[a+4>>2]|0);i=d;return}function Wi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+128|0;if((c[a+16>>2]|0)!=0){d=a+40|0;sGb(b|0,128,-1,c[d>>2]|0,c[d+4>>2]|0)}d=a+144|0;if((c[d>>2]|0)!=0){e=-541478725;i=b;return e|0}f=a+152|0;if((c[f>>2]|0)!=0){KIb(0,0,2643384,(g=i,i=i+24|0,c[g>>2]=2620152,c[g+8>>2]=2592720,c[g+16>>2]=342,g)|0);i=g;Hd();return 0}c[f>>2]=1;h=a+4|0;j=a|0;k=a+124|0;l=a+156|0;m=-1;while(1){n=c[(c[h>>2]|0)+44>>2]|0;do{if((n|0)==0){o=c[c[(c[j>>2]|0)+16>>2]>>2]|0;if((o|0)==0){p=m;break}p=Wi(o)|0}else{p=ve[n&4095](a)|0}}while(0);if((p|0)==-541478725){n=c[k>>2]|0;if((n|0)==0){q=13;break}c[k>>2]=0;r=Xi(a,n)|0}else{r=p}if((r|0)<0){q=16;break}n=c[f>>2]|0;if((n|0)==0){e=r;q=22;break}if((c[l>>2]&1|0)==0){q=21;break}if((n|0)==0){e=r;q=22;break}else{m=r}}do{if((q|0)==13){c[f>>2]=0}else if((q|0)==16){c[f>>2]=0;if((r|0)==-541478725){break}else{e=r}i=b;return e|0}else if((q|0)==21){KIb(0,0,2643384,(g=i,i=i+24|0,c[g>>2]=2569984,c[g+8>>2]=2592720,c[g+16>>2]=360,g)|0);i=g;Hd();return 0}else if((q|0)==22){i=b;return e|0}}while(0);c[d>>2]=1;e=-541478725;i=b;return e|0}function Xi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0.0,F=0.0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[f>>2]=b;j=a+8|0;k=c[j>>2]|0;l=c[a+12>>2]|0;c[g>>2]=0;m=c[k+60>>2]|0;if((c[a+144>>2]|0)!=0){VHb(f);n=-541478725;i=d;return n|0}o=c[l+36>>2]|0;p=(o|0)==0?658:o;a:do{if((c[l+56>>2]|0)==0){q=b;s=15}else{if((bIb(b)|0)!=0){q=c[f>>2]|0;s=15;break}KIb(c[j>>2]|0,48,2303984,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;o=a+16|0;u=c[o>>2]|0;if((u|0)==1){v=oi(a,c[(c[f>>2]|0)+76>>2]|0)|0;s=9}else if((u|0)==0){v=bv(a,c[a+20>>2]|0,c[a+24>>2]|0)|0;s=9}else{w=-22}do{if((s|0)==9){c[g>>2]=v;if((v|0)==0){w=-12;break}u=ZHb(v,c[f>>2]|0)|0;if((u|0)<0){w=u;break}u=c[o>>2]|0;if((u|0)==0){x=c[g>>2]|0;y=c[f>>2]|0;vIb(x|0,x+32|0,y|0,y+32|0,c[y+80>>2]|0,c[y+68>>2]|0,c[y+72>>2]|0)}else if((u|0)==1){u=c[(c[g>>2]|0)+64>>2]|0;y=c[f>>2]|0;x=c[y+64>>2]|0;z=c[y+76>>2]|0;A=y+352|0;y=rGb(c[A>>2]|0,c[A+4>>2]|0)|0;XKb(u,x,0,0,z,y,c[(c[f>>2]|0)+80>>2]|0)|0}else{w=-22;break}VHb(f);break a}}while(0);VHb(g);VHb(f);n=w;i=d;return n|0}}while(0);if((s|0)==15){c[g>>2]=q}b:do{if((m|0)!=0){q=a+56|0;s=a+60|0;w=m;do{B=+h[w>>3];f=(c[g>>2]|0)+136|0;if(B>(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)*(+(c[q>>2]|0)/+(c[s>>2]|0))){break b}f=w+8|0;v=c[f>>2]|0;b=w+12|0;l=c[b>>2]|0;KIb(c[j>>2]|0,48,2293032,(t=i,i=i+24|0,h[t>>3]=B,c[t+8>>2]=v,c[t+16>>2]=l,t)|0);i=t;Yi(c[j>>2]|0,c[f>>2]|0,c[b>>2]|0,0,0,c[w+16>>2]|0)|0;b=(c[j>>2]|0)+60|0;f=c[b>>2]|0;mJb(f+12|0);mJb(f+8|0);c[b>>2]=c[f+20>>2];kJb(f);w=c[(c[j>>2]|0)+60>>2]|0;}while((w|0)!=0)}}while(0);j=c[g>>2]|0;t=j+136|0;m=c[t>>2]|0;w=c[t+4>>2]|0;do{if((c[k+64>>2]|0)==0){C=p;D=a+160|0}else{t=DHb(j)|0;s=G;q=a+160|0;f=c[k+72>>2]|0;h[f+8>>3]=+((c[q>>2]|0)>>>0)+ +(c[q+4>>2]|0)*4294967296.0;if((m|0)==0&(w|0)==(-2147483648|0)){E=+r}else{E=(+(m>>>0)+ +(w|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}h[f>>3]=E;if((t|0)==(-1|0)&(s|0)==(-1|0)){F=+r}else{F=+(t>>>0)+ +(s|0)*4294967296.0}h[f+16>>3]=F;s=+R(+(+XGb(c[k+68>>2]|0,f,0)))<.5;c[k+76>>2]=s&1;if(!s){C=p;D=q;break}C=(c[(c[k+4>>2]|0)+20>>2]&65536|0)==0?p:658;D=q}}while(0);p=We[C&2047](a,c[g>>2]|0)|0;g=wrc(c[D>>2]|0,c[D+4>>2]|0,1,0)|0;c[D>>2]=g;c[D+4>>2]=G;c[a+152>>2]=0;if((m|0)==0&(w|0)==(-2147483648|0)){n=p;i=d;return n|0}c[e>>2]=1;c[e+4>>2]=1e6;D=XIb(m,w,a+56|0,e)|0;e=a+104|0;c[e>>2]=D;c[e+4>>2]=G;e=c[a+100>>2]|0;if((e|0)==0){n=p;i=d;return n|0}if(!((c[a+112>>2]|0)>-1)){n=p;i=d;return n|0}Aj(e,a);n=p;i=d;return n|0}function Yi(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;i=i+256|0;if((irc(b,2552144)|0)==0){j=h|0;mrc(j|0,0,256)|0;k=(e|0)==0;l=k?j:e;j=c[a+8>>2]|0;EFb(l,k?256:f,2533984,(m=i,i=i+16|0,c[m>>2]=c[c[a+4>>2]>>2],c[m+8>>2]=j,m)|0)|0;i=m;if(!k){n=0;i=h;return n|0}KIb(a,32,2518480,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=0;i=h;return n|0}if((irc(b,2504320)|0)==0){n=Zi(a,d)|0;i=h;return n|0}m=c[(c[a+4>>2]|0)+48>>2]|0;if((m|0)==0){n=-38;i=h;return n|0}n=se[m&127](a,b,d,e,f,g)|0;i=h;return n|0}function Zi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=a+68|0;f=c[e>>2]|0;g=c[a+4>>2]|0;if((c[g+20>>2]&196608|0)==0){KIb(a,16,2232184,(h=i,i=i+8|0,c[h>>2]=c[g>>2],h)|0);i=h;j=-1163346256;i=d;return j|0}g=rJb(b)|0;if((g|0)==0){j=-12;i=d;return j|0}b=a+72|0;do{if((c[b>>2]|0)==0){k=qJb(3,8)|0;c[b>>2]=k;if((k|0)!=0){break}kJb(g);j=-12;i=d;return j|0}}while(0);b=a+44|0;k=UGb(e,g,282136,0,0,0,0,0,c[b>>2]|0)|0;if((k|0)<0){KIb(c[b>>2]|0,16,2228280,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h;kJb(g);j=k;i=d;return j|0}else{TGb(f);f=a+64|0;kJb(c[f>>2]|0);c[f>>2]=g;j=0;i=d;return j|0}return 0}function _i(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){b=0;return b|0}else{d=0}while(1){e=c[((d|0)==0?6041832:d+44|0)>>2]|0;if((e|0)==0){b=0;f=4;break}if((irc(c[e>>2]|0,a)|0)==0){b=e;f=4;break}else{d=e}}if((f|0)==4){return b|0}return 0}function $i(a){a=a|0;return c[((a|0)==0?6041832:a+44|0)>>2]|0}function aj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[253228]|0;if((c[a+20>>2]&196608|0)==196608){KIb(0,0,2643384,(e=i,i=i+24|0,c[e>>2]=2490880,c[e+8>>2]=2592720,c[e+16>>2]=484,e)|0);i=e;Hd();return 0}f=c[a+8>>2]|0;a:do{if((f|0)!=0){g=0;while(1){if((c[f+(g*60|0)>>2]|0)==0){break a}if((c[f+(g*60|0)+36>>2]|0)!=0){if((c[f+(g*60|0)+16>>2]|0)!=0){h=8;break}if((c[f+(g*60|0)+28>>2]|0)!=0){h=8;break}}g=g+1|0}if((h|0)==8){KIb(0,0,2643384,(e=i,i=i+24|0,c[e>>2]=2479928,c[e+8>>2]=2592720,c[e+16>>2]=489,e)|0);i=e;Hd();return 0}}}while(0);e=a+44|0;c[e>>2]=0;h=a;a=d;while(1){d=c[a>>2]|0;if((d|0)==0){f=a;if(((E=c[f>>2]|0,(c[f>>2]|0)==0?(c[f>>2]=h)|0:0,E)|0)==0){break}j=c[a>>2]|0}else{j=d}a=j+44|0}c[253228]=e;i=b;return 0}function bj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;do{if((a|0)==0){b=0}else{if((c[a>>2]|0)==0){b=0;break}else{d=a;e=0}while(1){f=d+60|0;g=e+1|0;if((c[f>>2]|0)==0){b=g;break}else{d=f;e=g}}}}while(0);return b|0}function cj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a|0)==0){d=0;return d|0}e=pJb(80)|0;f=e;if((e|0)==0){d=0;return d|0}c[e>>2]=1978472;c[e+4>>2]=a;if((b|0)==0){g=0}else{g=rJb(b)|0}c[e+8>>2]=g;g=c[a+40>>2]|0;do{if((g|0)==0){h=8}else{b=pJb(g)|0;c[e+44>>2]=b;if((b|0)!=0){h=8;break}i=e+56|0}}while(0);a:do{if((h|0)==8){SJb(e);g=c[a+16>>2]|0;if((g|0)!=0){b=e+44|0;c[c[b>>2]>>2]=g;SJb(c[b>>2]|0)}b=pJb(4)|0;g=e+56|0;c[g>>2]=b;if((b|0)==0){i=g;break}c[b>>2]=306;b=a+8|0;j=c[b>>2]|0;do{if((j|0)==0){h=14}else{if((c[j>>2]|0)==0){h=14;break}else{k=j;l=0}do{k=k+60|0;l=l+1|0;}while((c[k>>2]|0)!=0);m=e+24|0;c[m>>2]=l;if((l|0)==0){n=m;break}o=hJb(l*60|0)|0;c[e+12>>2]=o;if((o|0)==0){i=g;break a}p=c[m>>2]|0;nrc(o|0,c[b>>2]|0,p*60|0)|0;o=pJb(p<<2)|0;c[e+16>>2]=o;if((o|0)==0){i=g;break a}else{n=m}}}while(0);if((h|0)==14){b=e+24|0;c[b>>2]=0;n=b}b=a+12|0;j=c[b>>2]|0;do{if((j|0)==0){h=21}else{if((c[j>>2]|0)==0){h=21;break}else{q=j;r=0}do{q=q+60|0;r=r+1|0;}while((c[q>>2]|0)!=0);m=e+40|0;c[m>>2]=r;if((r|0)==0){s=0;break}o=hJb(r*60|0)|0;c[e+28>>2]=o;if((o|0)==0){i=g;break a}p=c[m>>2]|0;nrc(o|0,c[b>>2]|0,p*60|0)|0;o=pJb(p<<2)|0;c[e+32>>2]=o;if((o|0)==0){i=g;break a}s=c[m>>2]|0}}while(0);if((h|0)==21){c[e+40>>2]=0;s=0}c[e+36>>2]=s;c[e+20>>2]=c[n>>2];d=f;return d|0}}while(0);mJb(e+16|0);mJb(e+12|0);c[e+24>>2]=0;mJb(e+32|0);mJb(e+28|0);c[e+40>>2]=0;mJb(e+44|0);mJb(i);kJb(e);d=0;return d|0}function dj(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((f|0)<=0){return 0}if((e|0)==0){g=0;do{hf[b&1023](a,d,g,f)|0;g=g+1|0;}while((g|0)<(f|0));return 0}else{g=0;do{c[e+(g<<2)>>2]=hf[b&1023](a,d,g,f)|0;g=g+1|0;}while((g|0)<(f|0));return 0}return 0}function ej(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){return}b=c[a+48>>2]|0;if((b|0)!=0){sj(b,a)}b=a+4|0;d=c[(c[b>>2]|0)+32>>2]|0;if((d|0)!=0){qe[d&1023](a)}d=a+24|0;if((c[d>>2]|0)!=0){e=a+16|0;f=0;do{fj(c[(c[e>>2]|0)+(f<<2)>>2]|0);f=f+1|0;}while(f>>>0<(c[d>>2]|0)>>>0)}d=a+40|0;if((c[d>>2]|0)!=0){f=a+32|0;e=0;do{fj(c[(c[f>>2]|0)+(e<<2)>>2]|0);e=e+1|0;}while(e>>>0<(c[d>>2]|0)>>>0)}d=a+44|0;if((c[(c[b>>2]|0)+16>>2]|0)!=0){WJb(c[d>>2]|0)}mJb(a+8|0);mJb(a+12|0);mJb(a+28|0);mJb(a+16|0);mJb(a+32|0);mJb(d);d=a+60|0;b=c[d>>2]|0;if((b|0)!=0){e=b;do{mJb(e+12|0);mJb(e+8|0);c[d>>2]=c[e+20>>2];kJb(e);e=c[d>>2]|0;}while((e|0)!=0)}e=a;WJb(e);d=a+68|0;TGb(c[d>>2]|0);c[d>>2]=0;mJb(a+72|0);mJb(a+56|0);kJb(e);return}function fj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;if((a|0)==0){i=b;return}e=c[a>>2]|0;if((e|0)==0){f=a}else{c[(c[e+32>>2]|0)+((((c[a+4>>2]|0)-(c[e+28>>2]|0)|0)/60|0)<<2)>>2]=0;f=c[d>>2]|0}e=c[f+8>>2]|0;if((e|0)==0){g=f}else{c[(c[e+16>>2]|0)+((((c[f+12>>2]|0)-(c[e+12>>2]|0)|0)/60|0)<<2)>>2]=0;g=c[d>>2]|0}Zk(g+64|0);Zk(g+68|0);Zk(g+72|0);Zk(g+76|0);_k(g+80|0);_k(g+84|0);if((g|0)==0){i=b;return}VHb(g+124|0);mJb(d);i=b;return}function gj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;c[f>>2]=0;a:do{if((d|0)==0){j=41}else{if((a[d]|0)==0){j=41;break}k=b+4|0;l=c[k>>2]|0;if((c[l+16>>2]|0)==0){KIb(b,16,2444680,(m=i,i=i+8|0,c[m>>2]=d,m)|0);i=m;n=-22;i=e;return n|0}o=c[l>>2]|0;do{if((irc(o,2431528)|0)!=0){if((irc(o,2422200)|0)==0){break}if((irc(o,2412104)|0)==0){break}if((irc(o,2404736)|0)==0){break}if((irc(o,2397320)|0)==0){break}if((irc(o,2390280)|0)==0){break}if((irc(o,2383408)|0)==0){break}if((irc(o,2376616)|0)==0){break}do{if((irc(o,2346320)|0)==0){l=(krc(d,2340256,7)|0)==0;p=l?d+7|0:d;l=LFb(h,p,2334432,1,0)|0;if((l|0)<0){KIb(b,16,2329360,(m=i,i=i+8|0,c[m>>2]=p,m)|0);i=m;q=l;break a}else{l=ij(b,f,c[h>>2]|0)|0;kJb(c[h>>2]|0);r=l;break}}else{r=ij(b,f,d)|0}}while(0);if((r|0)<0){q=r;break a}else{j=41;break a}}}while(0);o=rJb(d)|0;c[g>>2]=o;if((o|0)==0){q=-12;break}l=c[c[k>>2]>>2]|0;do{if((irc(l,2412104)|0)==0){s=1;t=o}else{if((irc(l,2397320)|0)==0){s=1;t=o;break}p=(irc(l,2404736)|0)==0;s=p?3:0;t=o}}while(0);while(1){if((s|0)==0){u=t;break}k=_b(t|0,58)|0;if((k|0)==0){j=19;break}else{s=s-1|0;t=k+1|0}}if((j|0)==19){u=o+(lrc(o|0)|0)|0}k=_b(u|0,58)|0;p=(k|0)!=0|0;v=(k|0)==0;b:do{if((irc(l,2376616)|0)==0){if(v){j=32;break}else{w=0;x=k}while(1){y=x+1|0;if((a[y]|0)==58){z=x;break}A=_b(y|0,61)|0;B=_b(y|0,58)|0;if((A|0)!=0){if((B|0)==0|A>>>0<B>>>0){j=27;break}}a[x]=124;B=_b(y|0,58)|0;if((B|0)==0){j=33;break b}else{w=1;x=B}}if((j|0)==27){if((y|0)==0){C=w;j=31;break}else{z=y}}if((a[z]|0)!=58){C=w;j=31;break}orc(z|0,z+1|0,lrc(z|0)|0)|0;j=33}else{if(v){C=p;j=31;break}else{D=k}while(1){a[D]=124;B=_b(D+1|0,58)|0;if((B|0)==0){C=p;j=31;break}else{D=B}}}}while(0);if((j|0)==31){if((C|0)==0){j=32}else{j=33}}if((j|0)==32){E=b}else if((j|0)==33){p=b;KIb(p,24,2370328,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;E=p}p=c[g>>2]|0;KIb(E,48,2355768,(m=i,i=i+8|0,c[m>>2]=p,m)|0);i=m;k=ij(b,f,p)|0;mJb(g);if((k|0)<0){q=k}else{j=41}}}while(0);do{if((j|0)==41){g=hj(b,f)|0;if((g|0)<0){q=g;break}E=LGb(c[f>>2]|0,10230296,0,2)|0;if((E|0)==0){q=g;break}KIb(b,16,2318392,(m=i,i=i+8|0,c[m>>2]=c[E>>2],m)|0);i=m;q=-1414549496}}while(0);OGb(f);n=q;i=e;return n|0}function hj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=a;f=XJb(e,b)|0;if((f|0)<0){KIb(e,16,2470080,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=f;i=d;return h|0}j=a+4|0;k=c[j>>2]|0;l=a+52|0;do{if((c[k+20>>2]&4|0)==0){m=7}else{n=c[a+48>>2]|0;if((c[l>>2]&1&c[n+24>>2]|0)==0){m=7;break}o=c[(c[n+32>>2]|0)+4>>2]|0;if((o|0)==0){m=7;break}c[l>>2]=1;c[c[a+56>>2]>>2]=o;p=c[j>>2]|0}}while(0);if((m|0)==7){c[l>>2]=0;p=k}do{if((c[p+16>>2]|0)==0){q=f;r=p}else{k=XJb(c[a+44>>2]|0,b)|0;if((k|0)>=0){q=k;r=c[j>>2]|0;break}KIb(e,16,2461224,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=k;i=d;return h|0}}while(0);g=c[r+52>>2]|0;if((g|0)!=0){h=We[g&2047](a,0)|0;i=d;return h|0}g=c[r+24>>2]|0;if((g|0)!=0){h=ve[g&4095](a)|0;i=d;return h|0}g=c[r+28>>2]|0;if((g|0)==0){h=q;i=d;return h|0}h=We[g&2047](a,b)|0;i=d;return h|0}function ij(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+88|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;c[g>>2]=e;if((e|0)==0){l=0;i=f;return l|0}a:do{if((a[e]|0)==0){m=0}else{n=b+44|0;o=b;p=0;q=0;r=-1;s=e;b:while(1){t=p;while(1){u=CJb(c[n>>2]|0,t)|0;if((u|0)==0){v=0;w=r;x=0;break}if((c[u+12>>2]|0)!=128){y=c[u+8>>2]|0;if((y|0)!=(r|0)){z=9;break}}if((a[s]|0)==0){m=q;break a}else{t=u}}if((z|0)==9){z=0;v=c[u>>2]|0;w=y;x=u}A=VJb(g,2285752,2281632,(v|0)!=0|0,h,j)|0;if((A|0)<0){z=11;break}t=c[g>>2]|0;if((a[t]|0)!=0){c[g>>2]=t+1}t=c[h>>2]|0;if((t|0)==0){B=v;C=x}else{D=x;while(1){E=CJb(c[n>>2]|0,D)|0;if((E|0)==0){B=t;C=0;break}else{D=E}}}D=c[j>>2]|0;KIb(o,48,2268360,(F=i,i=i+16|0,c[F>>2]=B,c[F+8>>2]=D,F)|0);i=F;D=(DJb(o,B,0,0,0)|0)==0;t=c[j>>2]|0;do{if(D){MGb(d,B,t,0)|0;G=EJb(c[n>>2]|0,B,c[j>>2]|0,0)|0;if((G|0)>=0){break}if((DJb(c[n>>2]|0,B,0,0,3)|0)==0){z=23;break b}}else{H=EJb(o,B,t,0)|0;if((H|0)<0){z=20;break b}}}while(0);kJb(c[j>>2]|0);kJb(c[h>>2]|0);t=q+1|0;D=c[g>>2]|0;if((a[D]|0)==0){m=t;break a}else{p=C;q=t;r=w;s=D}}if((z|0)==11){s=c[g>>2]|0;if((A|0)==-22){KIb(o,16,2277608,(F=i,i=i+8|0,c[F>>2]=s,F)|0);i=F;l=-22;i=f;return l|0}else{r=k|0;mrc(r|0,0,64)|0;a[r]=0;RGb(A,r,64)|0;KIb(o,16,2273360,(F=i,i=i+16|0,c[F>>2]=s,c[F+8>>2]=r,F)|0);i=F;l=A;i=f;return l|0}}else if((z|0)==20){kJb(c[j>>2]|0);kJb(c[h>>2]|0);l=H;i=f;return l|0}else if((z|0)==23){if((G|0)==-1414549496){KIb(o,16,2264560,(F=i,i=i+8|0,c[F>>2]=B,F)|0);i=F}kJb(c[j>>2]|0);kJb(c[h>>2]|0);l=G;i=f;return l|0}}}while(0);G=c[b+64>>2]|0;do{if((G|0)!=0){h=Zi(b,G)|0;if((h|0)<0){l=h}else{break}i=f;return l|0}}while(0);l=m;i=f;return l|0}function jj(a,b){a=a|0;b=b|0;return c[a+(b*60|0)>>2]|0}function kj(a,b){a=a|0;b=b|0;return c[a+(b*60|0)+4>>2]|0}function lj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;d=i;i=i+144|0;e=d|0;f=d+8|0;g=a+16|0;do{if((c[g>>2]|0)!=0){h=a+40|0;sGb(d+16|0,128,-1,c[h>>2]|0,c[h+4>>2]|0);if((c[g>>2]|0)!=1){break}h=a+132|0;j=c[h>>2]|0;if((j|0)==0){break}k=a+124|0;l=c[k>>2]|0;m=c[b+76>>2]|0;if(!((l|0)!=0|(m|0)<(j|0))){if((m|0)<=(c[a+136>>2]|0)){break}}c[e>>2]=b;j=GHb(b)|0;n=a+156|0;c[n>>2]=c[n>>2]|1;n=f|0;o=f+4|0;p=a+48|0;q=a+128|0;r=a+56|0;s=a+52|0;t=0;u=l;l=m;m=0;a:while(1){v=u;w=l;x=m;while(1){if((w|0)==0){y=18;break a}if((v|0)==0){c[n>>2]=1;c[o>>2]=c[p>>2];z=oi(a,c[q>>2]|0)|0;if((z|0)==0){y=12;break a}ZHb(z,c[e>>2]|0)|0;A=(c[e>>2]|0)+136|0;B=c[A>>2]|0;C=c[A+4>>2]|0;A=z+136|0;c[A>>2]=B;c[A+4>>2]=C;if(!((B|0)==0&(C|0)==(-2147483648|0))){C=XIb(x,(x|0)<0|0?-1:0,f,r)|0;B=wrc(c[A>>2]|0,c[A+4>>2]|0,C,G)|0;c[A>>2]=B;c[A+4>>2]=G}c[z+76>>2]=0;D=z;E=0}else{D=v;E=c[v+76>>2]|0}z=D+76|0;A=(c[q>>2]|0)-E|0;B=(w|0)>(A|0)?A:w;XKb(c[D+64>>2]|0,c[(c[e>>2]|0)+64>>2]|0,E,x,B,j,c[s>>2]|0)|0;F=B+x|0;H=w-B|0;A=(c[z>>2]|0)+B|0;c[z>>2]=A;if((A|0)<(c[h>>2]|0)){v=D;w=H;x=F}else{break}}t=Xi(a,D)|0;u=0;l=H;m=F}if((y|0)==12){KIb(c[a+8>>2]|0,24,2308856,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;I=0;i=d;return I|0}else if((y|0)==18){VHb(e);c[k>>2]=v;I=t;i=d;return I|0}}}while(0);I=Xi(a,b)|0;i=d;return I|0}function mj(){return 1978472}function nj(a,b){a=a|0;b=b|0;return lj(c[c[(c[a+8>>2]|0)+32>>2]>>2]|0,b)|0}function oj(a){a=a|0;var b=0,d=0;b=c[a+8>>2]|0;if((b|0)!=0){d=b;return d|0}d=c[c[a+4>>2]>>2]|0;return d|0}function pj(a,b){a=a|0;b=b|0;var d=0,e=0;do{if((b|0)==0){d=c[a+4>>2]|0;if((d|0)==0){break}if((c[d+16>>2]|0)==0){break}d=c[a+44>>2]|0;if((d|0)==0){break}else{e=d}return e|0}}while(0);e=0;return e|0}function qj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;a:do{if((a|0)==0){b=0}else{d=0;while(1){e=c[((d|0)==0?6041832:d+44|0)>>2]|0;if((e|0)==0){f=0;break}if((c[e+16>>2]|0)==(a|0)){b=e;break a}else{d=e}}return f|0}}while(0);while(1){a=c[((b|0)==0?6041832:b+44|0)>>2]|0;if((a|0)==0){f=0;g=6;break}d=c[a+16>>2]|0;if((d|0)==0){b=a}else{f=d;g=6;break}}if((g|0)==6){return f|0}return 0}function rj(){var a=0,b=0,d=0,e=0,f=0;a=i;i=i+8|0;b=a|0;d=pJb(60)|0;c[b>>2]=d;if((d|0)==0){e=0;i=a;return e|0}f=pJb(8)|0;c[d+32>>2]=f;if((f|0)==0){mJb(b);e=0;i=a;return e|0}else{c[d>>2]=1225176;SJb(d);e=c[b>>2]|0;i=a;return e|0}return 0}function sj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+20|0;e=c[d>>2]|0;f=a+8|0;a=0;while(1){if(!(a>>>0<e>>>0)){g=5;break}h=c[f>>2]|0;if((c[h+(a<<2)>>2]|0)==(b|0)){break}else{a=a+1|0}}if((g|0)==5){return}g=e-1|0;e=h+(g<<2)|0;h=c[e>>2]|0;c[e>>2]=b;c[(c[f>>2]|0)+(a<<2)>>2]=h;c[d>>2]=g;return}function tj(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;if((b|0)==0){return}if((c[b+20>>2]|0)==0){d=b}else{e=b;while(1){ej(c[c[e+8>>2]>>2]|0);b=c[a>>2]|0;if((c[b+20>>2]|0)==0){d=b;break}else{e=b}}}mJb(d+48|0);mJb((c[a>>2]|0)+12|0);mJb((c[a>>2]|0)+44|0);mJb((c[a>>2]|0)+16|0);mJb((c[a>>2]|0)+8|0);mJb((c[a>>2]|0)+32|0);mJb(a);return}function uj(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;f=g+24|0;do{if((c[f>>2]|0)!=0){h=(c[g+32>>2]|0)+4|0;if((c[h>>2]|0)!=0){break}i=c[g+40>>2]|0;if((i|0)==0){c[f>>2]=0;c[g+28>>2]=1;break}else{c[h>>2]=i;break}}}while(0);f=cj(b,d)|0;do{if((f|0)!=0){d=g+8|0;b=g+20|0;i=iJb(c[d>>2]|0,(c[b>>2]<<2)+4|0)|0;if((i|0)==0){ej(f);break}h=i;c[d>>2]=h;d=c[b>>2]|0;i=d+1|0;c[b>>2]=i;c[h+(d<<2)>>2]=f;c[g+4>>2]=i;c[f+48>>2]=g;c[a>>2]=f;i=gj(f,e)|0;if((i|0)>=0){j=0;return j|0}d=c[a>>2]|0;if((d|0)!=0){ej(d)}c[a>>2]=0;j=i;return j|0}}while(0);c[a>>2]=0;j=-12;return j|0}function vj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+24|0;do{if((c[e>>2]|0)!=0){f=(c[a+32>>2]|0)+4|0;if((c[f>>2]|0)!=0){break}g=c[a+40>>2]|0;if((g|0)==0){c[e>>2]=0;c[a+28>>2]=1;break}else{c[f>>2]=g;break}}}while(0);e=cj(b,d)|0;if((e|0)==0){h=0;return h|0}d=a+8|0;b=a+20|0;g=iJb(c[d>>2]|0,(c[b>>2]<<2)+4|0)|0;if((g|0)==0){ej(e);h=0;return h|0}else{f=g;c[d>>2]=f;d=c[b>>2]|0;g=d+1|0;c[b>>2]=g;c[f+(d<<2)>>2]=e;c[a+4>>2]=g;c[e+48>>2]=a;h=e;return h|0}return 0}function wj(a,b){a=a|0;b=b|0;c[a+56>>2]=b;return}function xj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0;e=i;i=i+1360|0;f=e|0;g=e+8|0;h=e+264|0;j=e+296|0;k=e+1320|0;l=e+1328|0;m=b+20|0;n=c[m>>2]|0;o=(n|0)==0;a:do{if(o){p=k;q=l|0;r=16}else{s=c[b+8>>2]|0;t=0;b:while(1){u=c[s+(t<<2)>>2]|0;v=c[u+24>>2]|0;w=u+16|0;x=0;while(1){if(!(x>>>0<v>>>0)){break}y=c[(c[w>>2]|0)+(x<<2)>>2]|0;if((y|0)==0){r=8;break b}if((c[y>>2]|0)==0){r=8;break b}else{x=x+1|0}}w=c[u+40>>2]|0;v=u+32|0;z=0;while(1){if(!(z>>>0<w>>>0)){break}y=c[(c[v>>2]|0)+(z<<2)>>2]|0;if((y|0)==0){r=13;break b}if((c[y+8>>2]|0)==0){r=13;break b}else{z=z+1|0}}v=t+1|0;if(v>>>0<n>>>0){t=v}else{r=15;break}}if((r|0)==8){t=c[u+12>>2]|0;s=c[t+(x*60|0)>>2]|0;v=ALb(c[t+(x*60|0)+4>>2]|0)|0;t=c[u+8>>2]|0;w=c[c[u+4>>2]>>2]|0;KIb(d,16,2355456,(A=i,i=i+32|0,c[A>>2]=s,c[A+8>>2]=v,c[A+16>>2]=t,c[A+24>>2]=w,A)|0);i=A;B=-22;i=e;return B|0}else if((r|0)==13){w=c[u+28>>2]|0;t=c[w+(z*60|0)>>2]|0;v=ALb(c[w+(z*60|0)+4>>2]|0)|0;w=c[u+8>>2]|0;s=c[c[u+4>>2]>>2]|0;KIb(d,16,2346168,(A=i,i=i+32|0,c[A>>2]=t,c[A+8>>2]=v,c[A+16>>2]=w,c[A+24>>2]=s,A)|0);i=A;B=-22;i=e;return B|0}else if((r|0)==15){s=k;w=l|0;if(o){p=s;q=w;r=16;break}v=b+8|0;t=0;y=0;C=n;c:while(1){D=c[(c[v>>2]|0)+(y<<2)>>2]|0;E=D+24|0;F=c[E>>2]|0;if((F|0)==0){G=t;H=C}else{I=D+16|0;D=0;J=t;K=F;while(1){F=c[(c[I>>2]|0)+(D<<2)>>2]|0;if((c[(c[F+12>>2]|0)+52>>2]|0)==0){L=J;M=K}else{if((c[F+16>>2]|0)==0){N=_i(2383232)|0}else{N=_i(2376480)|0}Rb(w|0,32,2370024,(A=i,i=i+8|0,c[A>>2]=J,A)|0)|0;i=A;O=uj(k,N,w,0,0,b)|0;if((O|0)<0){B=O;r=330;break c}O=Ti(F,c[k>>2]|0,0,0)|0;if((O|0)<0){B=O;r=330;break c}L=J+1|0;M=c[E>>2]|0}O=D+1|0;if(O>>>0<M>>>0){D=O;J=L;K=M}else{break}}G=L;H=c[m>>2]|0}K=y+1|0;if(K>>>0<H>>>0){t=G;y=K;C=H}else{P=H;Q=v;R=s;S=w;break a}}if((r|0)==330){i=e;return B|0}}}}while(0);if((r|0)==16){P=0;Q=b+8|0;R=p;S=q}q=g|0;g=h|0;h=b;S=b+12|0;p=b+44|0;R=j|0;H=j+4|0;G=P;while(1){d:do{if((G|0)==0){T=0;r=109}else{P=0;L=0;M=G;while(1){k=c[(c[Q>>2]|0)+(L<<2)>>2]|0;N=c[k+24>>2]|0;e:do{if((N|0)==0){r=35}else{n=c[k+16>>2]|0;o=0;while(1){l=c[n+(o<<2)>>2]|0;if((c[l+68>>2]|0)==0){r=47;break e}if((c[l+16>>2]|0)==1){if((c[l+76>>2]|0)==0){r=47;break e}if((c[l+84>>2]|0)==0){r=47;break e}}l=o+1|0;if(l>>>0<N>>>0){o=l}else{r=35;break}}}}while(0);f:do{if((r|0)==35){r=0;N=c[k+40>>2]|0;if((N|0)==0){U=P;V=M;break}o=c[k+32>>2]|0;n=0;while(1){l=c[o+(n<<2)>>2]|0;if((c[l+64>>2]|0)==0){r=47;break f}if((c[l+16>>2]|0)==1){if((c[l+72>>2]|0)==0){r=47;break f}if((c[l+80>>2]|0)==0){r=47;break f}}l=n+1|0;if(l>>>0<N>>>0){n=l}else{U=P;V=M;break}}}}while(0);if((r|0)==47){r=0;if((c[(c[k+4>>2]|0)+36>>2]|0)==0){W=el(k)|0}else{W=Dj(k)|0}if((W|0)<0&(W|0)!=-11){X=W;break d}U=(W>>>31^1)+P|0;V=c[m>>2]|0}n=L+1|0;if(n>>>0<V>>>0){P=U;L=n;M=V}else{break}}if((V|0)==0){T=U;r=109;break}else{Y=0;Z=0;_=0;$=0;aa=0;ba=0;ca=V}g:while(1){M=c[(c[Q>>2]|0)+(ba<<2)>>2]|0;L=M+24|0;if((c[L>>2]|0)==0){da=Y;ea=Z;fa=_;ga=$;ha=aa;ia=ca}else{P=M+16|0;M=Y;n=Z;N=_;o=$;l=aa;u=0;while(1){ja=c[(c[P>>2]|0)+(u<<2)>>2]|0;do{if((ja|0)==0){ka=l;la=o;ma=N;na=n;oa=M}else{z=ja+64|0;x=c[z>>2]|0;w=ja+68|0;s=c[w>>2]|0;v=ja+16|0;if((x|0)==(s|0)|(x|0)==0|(s|0)==0){pa=0}else{pa=(Ej(x,s,c[v>>2]|0,0)|0)==0|0}h:do{if((c[v>>2]|0)==1){s=ja+72|0;x=c[s>>2]|0;C=ja+76|0;y=c[C>>2]|0;if((x|0)==(y|0)|(x|0)==0|(y|0)==0){qa=pa}else{t=(Ej(x,y,0,1)|0)==0;y=t?1:pa;if((c[v>>2]|0)==1){qa=y}else{ra=y;sa=o;ta=N;ua=n;break}}y=c[ja+80>>2]|0;do{if((y|0)==0){r=63}else{t=c[ja+84>>2]|0;if((t|0)==0){r=63;break}if((y|0)==(t|0)){va=qa;wa=o;xa=N+1|0;ya=n;break}if((qa|0)!=0){va=qa;wa=o;xa=N;ya=n;break}va=(Mk(y,t)|0)==0|0;wa=o;xa=N;ya=n+1|0}}while(0);if((r|0)==63){r=0;va=qa;wa=o+1|0;xa=N;ya=n}y=c[s>>2]|0;do{if((y|0)!=0){t=c[C>>2]|0;if((t|0)==0){break}if((y|0)==(t|0)){ra=va;sa=wa;ta=xa+1|0;ua=ya;break h}if((va|0)!=0){ra=va;sa=wa;ta=xa;ua=ya;break h}ra=(Lk(y,t)|0)==0|0;sa=wa;ta=xa;ua=ya+1|0;break h}}while(0);ra=va;sa=wa+1|0;ta=xa;ua=ya}else{ra=pa;sa=o;ta=N;ua=n}}while(0);y=c[z>>2]|0;do{if((y|0)==0){r=77}else{C=c[w>>2]|0;if((C|0)==0){r=77;break}if((y|0)==(C|0)){za=ra;Aa=sa;Ba=ta+1|0;Ca=ua;r=82;break}if((ra|0)!=0){Da=ua;Ea=ta;Fa=sa;break}za=(Kk(y,C,c[v>>2]|0)|0)==0|0;Aa=sa;Ba=ta;Ca=ua+1|0;r=82}}while(0);if((r|0)==77){r=0;za=ra;Aa=sa+1|0;Ba=ta;Ca=ua;r=82}if((r|0)==82){r=0;if((za|0)==0){ka=l;la=Aa;ma=Ba;na=Ca;oa=M;break}else{Da=Ca;Ea=Ba;Fa=Aa}}y=c[v>>2]|0;if((y|0)==0){w=_i(2569720)|0;if((w|0)==0){r=85;break g}Rb(g|0,30,2533496,(A=i,i=i+8|0,c[A>>2]=l,A)|0)|0;i=A;z=uj(f,w,g,c[S>>2]|0,0,b)|0;if((z|0)<0){X=z;break d}else{Ga=l+1|0;Ha=M}}else if((y|0)==1){y=_i(2518072)|0;if((y|0)==0){r=88;break g}Rb(g|0,30,2490600,(A=i,i=i+8|0,c[A>>2]=M,A)|0)|0;i=A;a[q]=0;z=c[p>>2]|0;if((z|0)==0){Ia=0}else{Rb(q|0,256,2479792,(A=i,i=i+8|0,c[A>>2]=z,A)|0)|0;i=A;Ia=c[p>>2]|0}z=uj(f,y,g,Ia,0,b)|0;if((z|0)<0){X=z;break d}else{Ga=l;Ha=M+1|0}}else{X=-22;break d}z=c[f>>2]|0;y=Ti(ja,z,0,0)|0;if((y|0)<0){X=y;break d}Dj(z)|0;w=c[c[z+16>>2]>>2]|0;C=c[c[z+32>>2]>>2]|0;z=w+16|0;if((Kk(c[w+64>>2]|0,c[w+68>>2]|0,c[z>>2]|0)|0)==0){r=95}else{if((Kk(c[C+64>>2]|0,c[C+68>>2]|0,c[C+16>>2]|0)|0)==0){r=95}else{Ja=y}}if((r|0)==95){r=0;Ja=y|-38}do{if((c[z>>2]|0)==1){if((Lk(c[w+72>>2]|0,c[w+76>>2]|0)|0)!=0){if((Mk(c[w+80>>2]|0,c[w+84>>2]|0)|0)!=0){Ka=Ja;break}}Ka=Ja|-38}else{Ka=Ja}}while(0);if((c[C+16>>2]|0)==1){if((Lk(c[C+72>>2]|0,c[C+76>>2]|0)|0)==0){r=103;break g}if((Mk(c[C+80>>2]|0,c[C+84>>2]|0)|0)==0){r=103;break g}}if((Ka|0)<0){La=Ka;break g}else{ka=Ga;la=Fa;ma=Ea;na=Da;oa=Ha}}}while(0);w=u+1|0;if(w>>>0<(c[L>>2]|0)>>>0){M=oa;n=na;N=ma;o=la;l=ka;u=w}else{break}}da=oa;ea=na;fa=ma;ga=la;ha=ka;ia=c[m>>2]|0}u=ba+1|0;if(u>>>0<ia>>>0){Y=da;Z=ea;_=fa;$=ga;aa=ha;ba=u;ca=ia}else{r=110;break}}if((r|0)==85){r=0;KIb(d,16,2551704,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;X=-22;break}else if((r|0)==88){r=0;KIb(d,16,2504088,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;X=-22;break}else if((r|0)==103){r=0;La=Ka|-38}else if((r|0)==110){r=0;KIb(h,48,2460832,(A=i,i=i+32|0,c[A>>2]=U,c[A+8>>2]=ea,c[A+16>>2]=fa,c[A+24>>2]=ga,A)|0);i=A;if((ga|0)==0){X=0;break}if((ea|U|0)!=0){X=-11;break}SFb(j,0,1);u=c[m>>2]|0;if((u|0)!=0){l=0;o=u;while(1){u=c[(c[Q>>2]|0)+(l<<2)>>2]|0;N=c[u+24>>2]|0;i:do{if((N|0)==0){r=115}else{n=c[u+16>>2]|0;M=0;while(1){L=c[n+(M<<2)>>2]|0;if((c[L+68>>2]|0)==0){r=127;break i}if((c[L+16>>2]|0)==1){if((c[L+76>>2]|0)==0){r=127;break i}if((c[L+84>>2]|0)==0){r=127;break i}}L=M+1|0;if(L>>>0<N>>>0){M=L}else{r=115;break}}}}while(0);j:do{if((r|0)==115){r=0;N=c[u+40>>2]|0;if((N|0)==0){Ma=o;break}M=c[u+32>>2]|0;n=0;while(1){L=c[M+(n<<2)>>2]|0;if((c[L+64>>2]|0)==0){r=127;break j}if((c[L+16>>2]|0)==1){if((c[L+72>>2]|0)==0){r=127;break j}if((c[L+80>>2]|0)==0){r=127;break j}}L=n+1|0;if(L>>>0<N>>>0){n=L}else{Ma=o;break}}}}while(0);if((r|0)==127){r=0;n=c[u+8>>2]|0;UFb(j,2444416,(A=i,i=i+16|0,c[A>>2]=(c[H>>2]|0)!=0?2431400:10230448,c[A+8>>2]=n,A)|0);i=A;Ma=c[m>>2]|0}n=l+1|0;if(n>>>0<Ma>>>0){l=n;o=Ma}else{break}}}KIb(h,16,2411888,(A=i,i=i+8|0,c[A>>2]=c[R>>2],A)|0);i=A;X=-5;break}o=c[(c[ja+8>>2]|0)+8>>2]|0;KIb(d,16,2469824,(A=i,i=i+16|0,c[A>>2]=c[(c[ja>>2]|0)+8>>2],c[A+8>>2]=o,A)|0);i=A;X=La}}while(0);if((r|0)==109){r=0;KIb(h,48,2460832,(A=i,i=i+32|0,c[A>>2]=T,c[A+8>>2]=0,c[A+16>>2]=0,c[A+24>>2]=0,A)|0);i=A;X=0}if(!((X|0)==-11)){break}KIb(h,48,2176744,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;G=c[m>>2]|0}if((X|0)<0){B=X;i=e;return B|0}else{Na=0;Oa=0}while(1){Pa=c[m>>2]|0;if(!(Oa>>>0<Pa>>>0)){if((Na|0)==0){break}else{Na=0;Oa=0;continue}}X=c[(c[Q>>2]|0)+(Oa<<2)>>2]|0;G=X+24|0;do{if((c[G>>2]|0)==0){Qa=0}else{h=X+16|0;T=X+40|0;La=X+32|0;ja=0;d=0;while(1){R=c[(c[h>>2]|0)+(d<<2)>>2]|0;Ma=c[R+68>>2]|0;k:do{if((Ma|0)==0){Ra=ja}else{if((c[Ma>>2]|0)!=1){Ra=ja;break}H=c[c[Ma+4>>2]>>2]|0;j=c[T>>2]|0;if((j|0)==0){Ra=ja;break}U=c[La>>2]|0;ea=c[R+16>>2]|0;ga=ja;fa=0;Ka=j;l:while(1){j=c[U+(fa<<2)>>2]|0;m:do{if((ea|0)==(c[j+16>>2]|0)){Sa=j+64|0;ia=c[Sa>>2]|0;ca=ia|0;ba=c[ca>>2]|0;if((ba|0)==0){break l}else if((ba|0)==1){Ta=ga;Ua=Ka;break}ha=ia+4|0;ia=0;while(1){if(!(ia>>>0<ba>>>0)){Ta=ga;Ua=Ka;break m}Va=c[ha>>2]|0;if((c[Va+(ia<<2)>>2]|0)==(H|0)){break}else{ia=ia+1|0}}c[Va>>2]=H;c[ca>>2]=1;Ta=1;Ua=c[T>>2]|0}else{Ta=ga;Ua=Ka}}while(0);j=fa+1|0;if(j>>>0<Ua>>>0){ga=Ta;fa=j;Ka=Ua}else{Ra=Ta;break k}}Qk(Sa,H,(H|0)<0|0?-1:0)|0;Ra=1}}while(0);R=d+1|0;Wa=c[G>>2]|0;if(R>>>0<Wa>>>0){ja=Ra;d=R}else{break}}if((Wa|0)==0){Qa=Ra;break}else{Xa=Ra;Ya=0}while(1){d=c[(c[h>>2]|0)+(Ya<<2)>>2]|0;ja=c[d+76>>2]|0;n:do{if((ja|0)==0){Za=Xa}else{if((c[ja>>2]|0)!=1){Za=Xa;break}R=c[c[ja+4>>2]>>2]|0;Ma=c[T>>2]|0;if((Ma|0)==0){Za=Xa;break}u=c[La>>2]|0;Ka=c[d+16>>2]|0;fa=Xa;ga=0;ea=Ma;o:while(1){Ma=c[u+(ga<<2)>>2]|0;p:do{if((Ka|0)==(c[Ma+16>>2]|0)){_a=Ma+72|0;U=c[_a>>2]|0;j=U|0;C=c[j>>2]|0;if((C|0)==1){$a=fa;ab=ea;break}else if((C|0)==0){break o}ia=U+4|0;U=0;while(1){if(!(U>>>0<C>>>0)){$a=fa;ab=ea;break p}bb=c[ia>>2]|0;if((c[bb+(U<<2)>>2]|0)==(R|0)){break}else{U=U+1|0}}c[bb>>2]=R;c[j>>2]=1;$a=1;ab=c[T>>2]|0}else{$a=fa;ab=ea}}while(0);Ma=ga+1|0;if(Ma>>>0<ab>>>0){fa=$a;ga=Ma;ea=ab}else{Za=$a;break n}}Qk(_a,R,(R|0)<0|0?-1:0)|0;Za=1}}while(0);d=Ya+1|0;cb=c[G>>2]|0;if(d>>>0<cb>>>0){Xa=Za;Ya=d}else{break}}if((cb|0)==0){Qa=Za;break}else{db=Za;eb=0}while(1){d=c[(c[h>>2]|0)+(eb<<2)>>2]|0;ja=c[d+84>>2]|0;q:do{if((ja|0)==0){fb=db}else{if((c[ja+4>>2]|0)!=1){fb=db;break}ea=c[ja>>2]|0;ga=c[ea>>2]|0;fa=c[ea+4>>2]|0;ea=c[T>>2]|0;if((ea|0)==0){fb=db;break}Ka=-1;u=c[La>>2]|0;H=c[d+16>>2]|0;r:do{if((fa|0)>(Ka|0)|(fa|0)==(Ka|0)&ga>>>0>-1>>>0|(ga&2147483647|0)==0&(fa&0|0)==0){Ma=db;U=0;ia=ea;while(1){C=c[u+(U<<2)>>2]|0;ca=C+80|0;ha=c[ca>>2]|0;s:do{if((H|0)==(c[C+16>>2]|0)){ba=ha+4|0;aa=c[ba>>2]|0;if((aa|0)==1){gb=Ma;hb=ia;break}$=ha+8|0;if((a[$]|0)!=0){ib=Ma;jb=ca;kb=ha;lb=$;break r}$=ha|0;_=0;while(1){if((_|0)>=(aa|0)){gb=Ma;hb=ia;break s}mb=c[$>>2]|0;Z=mb+(_<<3)|0;if((c[Z>>2]|0)==(ga|0)&(c[Z+4>>2]|0)==(fa|0)){break}else{_=_+1|0}}c[mb>>2]=ga;c[mb+4>>2]=fa;c[ba>>2]=1;gb=1;hb=c[T>>2]|0}else{gb=Ma;hb=ia}}while(0);ha=U+1|0;if(ha>>>0<hb>>>0){Ma=gb;U=ha;ia=hb}else{fb=gb;break q}}}else{ia=db;U=0;Ma=ea;while(1){ha=c[u+(U<<2)>>2]|0;ca=ha+80|0;C=c[ca>>2]|0;t:do{if((H|0)==(c[ha+16>>2]|0)){j=C+4|0;_=c[j>>2]|0;if((_|0)==1){nb=ia;ob=Ma;break}$=C+8|0;if((a[$]|0)!=0){if((a[C+9|0]|0)!=0){ib=ia;jb=ca;kb=C;lb=$;break r}}$=C|0;aa=0;while(1){if((aa|0)>=(_|0)){nb=ia;ob=Ma;break t}pb=c[$>>2]|0;Z=pb+(aa<<3)|0;if((c[Z>>2]|0)==(ga|0)&(c[Z+4>>2]|0)==(fa|0)){break}else{aa=aa+1|0}}c[pb>>2]=ga;c[pb+4>>2]=fa;c[j>>2]=1;nb=1;ob=c[T>>2]|0}else{nb=ia;ob=Ma}}while(0);C=U+1|0;if(C>>>0<ob>>>0){ia=nb;U=C;Ma=ob}else{fb=nb;break q}}}}while(0);a[kb+9|0]=0;a[lb]=0;Rk(jb,ga,fa)|0;fb=ib}}while(0);d=eb+1|0;if(d>>>0<(c[G>>2]|0)>>>0){db=fb;eb=d}else{Qa=fb;break}}}}while(0);Na=Qa|Na;Oa=Oa+1|0}u:do{if((Pa|0)==0){qb=0;rb=0;sb=0}else{Oa=0;v:do{Na=c[(c[Q>>2]|0)+(Oa<<2)>>2]|0;Qa=c[Na+24>>2]|0;do{if((Qa|0)!=0){fb=c[Na+16>>2]|0;eb=0;while(1){tb=c[fb+(eb<<2)>>2]|0;if((c[tb+16>>2]|0)==1){if((c[c[tb+68>>2]>>2]|0)==1){ub=eb;break}}db=eb+1|0;if(db>>>0<Qa>>>0){eb=db}else{ub=db;break}}if((ub|0)==(Qa|0)){break}eb=c[c[(c[tb+68>>2]|0)+4>>2]>>2]|0;fb=QKb(eb)|0;db=Na+40|0;ib=c[db>>2]|0;if((ib|0)==0){break}jb=Na+32|0;lb=(fb|0)==4;kb=0;nb=ib;while(1){ib=c[(c[jb>>2]|0)+(kb<<2)>>2]|0;do{if((c[ib+16>>2]|0)==1){ob=ib+64|0;pb=c[ob>>2]|0;if((c[pb>>2]|0)>>>0<2>>>0){vb=nb;break}w:do{if(lb){gb=-1;hb=-2147483648;mb=0;Za=pb;while(1){cb=c[(c[Za+4>>2]|0)+(mb<<2)>>2]|0;Ya=QKb(cb)|0;if((NKb(cb)|0)==(eb|0)){wb=mb;break w}if((OKb(cb)|0)==(eb|0)|(Ya|0)==8){wb=mb;break w}cb=Ya-4|0;Xa=((Ya|0)<4?0:1073741823)-((cb|0)>-1?cb:4-Ya|0)|0;Ya=(Xa|0)>(hb|0);cb=Ya?mb:gb;_a=mb+1|0;$a=c[ob>>2]|0;if(_a>>>0<(c[$a>>2]|0)>>>0){gb=cb;hb=Ya?Xa:hb;mb=_a;Za=$a}else{wb=cb;break}}}else{Za=-1;mb=-2147483648;hb=0;gb=pb;while(1){cb=c[(c[gb+4>>2]|0)+(hb<<2)>>2]|0;$a=QKb(cb)|0;if((NKb(cb)|0)==(eb|0)){wb=hb;break w}if((OKb(cb)|0)==(eb|0)){wb=hb;break w}cb=$a-fb|0;_a=(($a|0)<(fb|0)?0:1073741823)-((cb|0)>-1?cb:-cb|0)|0;cb=(_a|0)>(mb|0);$a=cb?hb:Za;Xa=hb+1|0;Ya=c[ob>>2]|0;if(Xa>>>0<(c[Ya>>2]|0)>>>0){Za=$a;mb=cb?_a:mb;hb=Xa;gb=Ya}else{wb=$a;break}}}}while(0);if(!((wb|0)>-1)){r=208;break v}pb=c[(c[ob>>2]|0)+4>>2]|0;gb=pb+(wb<<2)|0;hb=c[gb>>2]|0;c[gb>>2]=c[pb>>2];c[pb>>2]=hb;vb=c[db>>2]|0}else{vb=nb}}while(0);ib=kb+1|0;if(ib>>>0<vb>>>0){kb=ib;nb=vb}else{break}}}}while(0);Oa=Oa+1|0;xb=c[m>>2]|0;}while(Oa>>>0<xb>>>0);if((r|0)==208){KIb(0,0,2304128,(A=i,i=i+24|0,c[A>>2]=2592176,c[A+8>>2]=2209400,c[A+16>>2]=1010,A)|0);i=A;Hd();return 0}if((xb|0)==0){qb=0;rb=0;sb=0;break}Oa=c[Q>>2]|0;Na=0;Qa=xb;nb=xb;while(1){kb=c[Oa+(Na<<2)>>2]|0;db=c[kb+24>>2]|0;do{if((db|0)==0){yb=Qa;zb=nb}else{fb=c[kb+16>>2]|0;eb=0;while(1){Ab=c[fb+(eb<<2)>>2]|0;if((c[Ab+16>>2]|0)==1){if((c[c[Ab+76>>2]>>2]|0)==1){Bb=eb;break}}lb=eb+1|0;if(lb>>>0<db>>>0){eb=lb}else{Bb=lb;break}}if((Bb|0)==(db|0)){yb=Qa;zb=nb;break}eb=c[c[(c[Ab+76>>2]|0)+4>>2]>>2]|0;fb=kb+40|0;lb=c[fb>>2]|0;if((lb|0)==0){yb=Qa;zb=nb;break}jb=c[kb+32>>2]|0;ib=0;fa=0;ga=lb;while(1){lb=c[jb+(fa<<2)>>2]|0;do{if((c[lb+16>>2]|0)==1){hb=c[lb+72>>2]|0;pb=c[hb>>2]|0;if(pb>>>0<2>>>0){Cb=ib;Db=ga;break}gb=c[hb+4>>2]|0;hb=0;mb=ib;Za=2147483647;while(1){$a=eb-(c[gb+(hb<<2)>>2]|0)|0;Ya=($a|0)>-1?$a:-$a|0;$a=(Ya|0)<(Za|0);Eb=$a?hb:mb;Xa=hb+1|0;if(Xa>>>0<pb>>>0){hb=Xa;mb=Eb;Za=$a?Ya:Za}else{break}}Za=gb+(Eb<<2)|0;mb=c[Za>>2]|0;c[Za>>2]=c[gb>>2];c[gb>>2]=mb;Cb=Eb;Db=c[fb>>2]|0}else{Cb=ib;Db=ga}}while(0);lb=fa+1|0;if(lb>>>0<Db>>>0){ib=Cb;fa=lb;ga=Db}else{break}}ga=c[m>>2]|0;yb=ga;zb=ga}}while(0);kb=Na+1|0;if(kb>>>0<yb>>>0){Na=kb;Qa=yb;nb=zb}else{break}}if((zb|0)==0){qb=0;rb=0;sb=0;break}else{Fb=0;Gb=zb;Hb=Oa}x:while(1){nb=c[Hb+(Fb<<2)>>2]|0;Qa=c[nb+24>>2]|0;do{if((Qa|0)==0){Ib=Gb}else{Na=c[nb+16>>2]|0;kb=0;while(1){Jb=c[Na+(kb<<2)>>2]|0;if((c[Jb+16>>2]|0)==1){if((c[(c[Jb+84>>2]|0)+4>>2]|0)==1){Kb=kb;break}}db=kb+1|0;if(db>>>0<Qa>>>0){kb=db}else{Kb=db;break}}if((Kb|0)==(Qa|0)){Ib=Gb;break}kb=nb+40|0;Na=c[kb>>2]|0;if((Na|0)==0){Ib=Gb;break}db=nb+32|0;ga=Jb+84|0;fa=0;ib=Na;while(1){Na=c[(c[db>>2]|0)+(fa<<2)>>2]|0;do{if((c[Na+16>>2]|0)==1){fb=Na+80|0;eb=c[fb>>2]|0;if((c[eb+4>>2]|0)<2){Lb=ib;break}else{Mb=2147483647;Nb=-2147483648;Ob=-1;Pb=0;Qb=eb}while(1){eb=c[c[ga>>2]>>2]|0;jb=c[eb>>2]|0;lb=c[eb+4>>2]|0;eb=(c[Qb>>2]|0)+(Pb<<3)|0;mb=c[eb>>2]|0;Za=c[eb+4>>2]|0;eb=rGb(jb,lb)|0;hb=rGb(mb,Za)|0;pb=hb-eb|0;ob=0;Ya=(lb|0)<(ob|0)|(lb|0)==(ob|0)&jb>>>0<0>>>0;if((jb&2147483647|0)==0&(lb&0|0)==0|Ya^1){ob=-1;if((Za|0)>(ob|0)|(Za|0)==(ob|0)&mb>>>0>-1>>>0|(mb&2147483647|0)==0&(Za&0|0)==0){Sb=lb;Tb=jb;Ub=Za;Vb=mb;Wb=0;Xb=1e5}else{r=243}}else{r=243}if((r|0)==243){r=0;if(Ya){Ya=jb&2147483647;Yb=(Ya|0)==0?eb:Ya}else{Yb=eb}eb=0;if((Za|0)<(eb|0)|(Za|0)==(eb|0)&mb>>>0<0>>>0){eb=mb&2147483647;Zb=(eb|0)==0?hb:eb}else{Zb=hb}hb=Zb-Yb|0;Sb=0;Tb=0;Ub=0;Vb=0;Wb=0;Xb=((Yb|0)>(Zb|0)?8e4:9e4)-((hb|0)>-1?hb:-hb|0)|0}while(1){hb=1712744+(Wb<<4)|0;eb=c[hb>>2]|0;mb=c[hb+4>>2]|0;hb=1712752+(Wb<<4)|0;Za=c[hb>>2]|0;Ya=c[hb+4>>2]|0;do{if((eb&Tb|0)==0&(mb&Sb|0)==0){_b=Xb;$b=Ub;ac=Vb;bc=Sb;cc=Tb}else{if(!((eb&Vb|0)==0&(mb&Ub|0)==0)){_b=Xb;$b=Ub;ac=Vb;bc=Sb;cc=Tb;break}if((Za&Vb|0)==0&(Ya&Ub|0)==0){_b=Xb;$b=Ub;ac=Vb;bc=Sb;cc=Tb;break}if(!((Za&Tb|0)==0&(Ya&Sb|0)==0)){_b=Xb;$b=Ub;ac=Vb;bc=Sb;cc=Tb;break}_b=Xb-2+((rGb(Za,Ya)|0)*10|0)|0;$b=Ub&~Ya;ac=Vb&~Za;bc=Sb&~mb;cc=Tb&~eb}}while(0);eb=Wb+1|0;if(eb>>>0<21>>>0){Sb=bc;Tb=cc;Ub=$b;Vb=ac;Wb=eb;Xb=_b}else{break}}if((cc&8|0)==0&(bc&0|0)==0){dc=_b}else{dc=(ac&8|0)==0&($b&0|0)==0?_b:_b+10|0}eb=ac&-9;mb=$b|0;Za=rGb(eb&cc,mb&bc)|0;Ya=(Za*10|0)+dc+((rGb(eb&((cc|8)^-9),mb&~bc)|0)*-5|0)|0;if((Ya|0)>(Nb|0)){r=258}else{if((pb|0)<(Mb|0)&(Ya|0)==(Nb|0)){r=258}else{ec=Ob;fc=Nb;gc=Mb}}if((r|0)==258){r=0;ec=Pb;fc=Ya;gc=pb}Ya=Pb+1|0;hc=c[fb>>2]|0;if((Ya|0)<(c[hc+4>>2]|0)){Mb=gc;Nb=fc;Ob=ec;Pb=Ya;Qb=hc}else{break}}if(!((ec|0)>-1)){break x}fb=c[hc>>2]|0;gb=fb+(ec<<3)|0;Ya=c[gb>>2]|0;mb=c[gb+4>>2]|0;eb=c[fb+4>>2]|0;c[gb>>2]=c[fb>>2];c[gb+4>>2]=eb;c[fb>>2]=Ya;c[fb+4>>2]=mb;Lb=c[kb>>2]|0}else{Lb=ib}}while(0);Na=fa+1|0;if(Na>>>0<Lb>>>0){fa=Na;ib=Lb}else{break}}Ib=c[m>>2]|0}}while(0);nb=Fb+1|0;if(!(nb>>>0<Ib>>>0)){qb=0;rb=0;sb=Ib;break u}Fb=nb;Gb=Ib;Hb=c[Q>>2]|0}KIb(0,0,2304128,(A=i,i=i+24|0,c[A>>2]=2592176,c[A+8>>2]=2209400,c[A+16>>2]=941,A)|0);i=A;Hd();return 0}}while(0);y:while(1){Hb=qb;Ib=rb;while(1){if(Hb>>>0<sb>>>0){break}if((Ib|0)==0){r=291;break y}else{Hb=0;Ib=0}}Gb=c[(c[Q>>2]|0)+(Hb<<2)>>2]|0;Fb=Gb+24|0;Lb=c[Fb>>2]|0;if((Lb|0)==0){ic=Ib}else{ec=Gb+16|0;hc=0;Qb=Ib;Pb=Lb;while(1){Lb=c[(c[ec>>2]|0)+(hc<<2)>>2]|0;Ob=c[Lb+64>>2]|0;do{if((Ob|0)==0){jc=Qb;kc=Pb}else{if((c[Ob>>2]|0)!=1){jc=Qb;kc=Pb;break}fc=Cj(Lb,0)|0;if((fc|0)<0){lc=fc;r=299;break y}jc=1;kc=c[Fb>>2]|0}}while(0);Lb=hc+1|0;if(Lb>>>0<kc>>>0){hc=Lb;Qb=jc;Pb=kc}else{ic=jc;break}}}Pb=Gb+40|0;Qb=c[Pb>>2]|0;do{if((Qb|0)==0){mc=ic}else{hc=Gb+32|0;ec=0;Ib=ic;Lb=Qb;while(1){Ob=c[(c[hc>>2]|0)+(ec<<2)>>2]|0;fc=c[Ob+64>>2]|0;do{if((fc|0)==0){nc=Ib;oc=Lb}else{if((c[fc>>2]|0)!=1){nc=Ib;oc=Lb;break}Nb=Cj(Ob,0)|0;if((Nb|0)<0){lc=Nb;r=299;break y}nc=1;oc=c[Pb>>2]|0}}while(0);Ob=ec+1|0;if(Ob>>>0<oc>>>0){ec=Ob;Ib=nc;Lb=oc}else{break}}if((c[Fb>>2]|0)==0|(oc|0)==0){mc=nc;break}Lb=Gb+16|0;if((c[(c[c[Lb>>2]>>2]|0)+52>>2]|0)>-1){pc=0;qc=nc;rc=oc}else{mc=nc;break}while(1){Ib=c[(c[hc>>2]|0)+(pc<<2)>>2]|0;if((c[Ib+52>>2]|0)<0){ec=Cj(Ib,c[c[Lb>>2]>>2]|0)|0;if((ec|0)<0){lc=ec;r=299;break y}sc=1;tc=c[Pb>>2]|0}else{sc=qc;tc=rc}ec=pc+1|0;if(ec>>>0<tc>>>0){pc=ec;qc=sc;rc=tc}else{mc=sc;break}}}}while(0);qb=Hb+1|0;rb=mc;sb=c[m>>2]|0}z:do{if((r|0)==291){if((sb|0)==0){uc=sb;break}else{vc=0}while(1){mc=c[(c[Q>>2]|0)+(vc<<2)>>2]|0;rb=mc+24|0;qb=mc+16|0;sc=0;while(1){if(!(sc>>>0<(c[rb>>2]|0)>>>0)){break}tc=Cj(c[(c[qb>>2]|0)+(sc<<2)>>2]|0,0)|0;if((tc|0)<0){lc=tc;r=299;break z}else{sc=sc+1|0}}sc=mc+40|0;qb=mc+32|0;rb=0;while(1){if(!(rb>>>0<(c[sc>>2]|0)>>>0)){break}tc=Cj(c[(c[qb>>2]|0)+(rb<<2)>>2]|0,0)|0;if((tc|0)<0){lc=tc;r=299;break z}else{rb=rb+1|0}}rb=vc+1|0;qb=c[m>>2]|0;if(rb>>>0<qb>>>0){vc=rb}else{uc=qb;break}}}}while(0);do{if((r|0)==299){vc=(lc|0)<0?lc:0;if((vc|0)==0){uc=c[m>>2]|0;break}else{B=vc;i=e;return B|0}}}while(0);A:do{if((uc|0)==0){wc=0}else{lc=0;vc=uc;sb=uc;while(1){Hb=c[(c[Q>>2]|0)+(lc<<2)>>2]|0;if((c[Hb+40>>2]|0)==0){qb=Ui(Hb)|0;if((qb|0)!=0){B=qb;r=330;break}qb=c[m>>2]|0;xc=qb;yc=qb}else{xc=vc;yc=sb}qb=lc+1|0;if(qb>>>0<xc>>>0){lc=qb;vc=xc;sb=yc}else{break}}if((r|0)==330){i=e;return B|0}if((yc|0)==0){wc=0;break}else{zc=0;Ac=0}while(1){sb=c[(c[Q>>2]|0)+(zc<<2)>>2]|0;vc=sb+24|0;if((c[vc>>2]|0)==0){Bc=0}else{lc=sb+16|0;qb=0;Hb=c[lc>>2]|0;while(1){c[(c[Hb+(qb<<2)>>2]|0)+100>>2]=b;rb=c[lc>>2]|0;c[(c[rb+(qb<<2)>>2]|0)+112>>2]=-1;sc=qb+1|0;mc=c[vc>>2]|0;if(sc>>>0<mc>>>0){qb=sc;Hb=rb}else{Bc=mc;break}}}Hb=sb+40|0;do{if((c[Hb>>2]|0)==0){Cc=Bc;r=315}else{qb=sb+32|0;lc=0;mc=c[qb>>2]|0;do{c[(c[mc+(lc<<2)>>2]|0)+100>>2]=b;mc=c[qb>>2]|0;c[(c[mc+(lc<<2)>>2]|0)+112>>2]=-1;lc=lc+1|0;Dc=c[Hb>>2]|0;}while(lc>>>0<Dc>>>0);if((Dc|0)!=0){Ec=Ac;break}Cc=c[vc>>2]|0;r=315}}while(0);if((r|0)==315){r=0;if(Cc>>>0>(2147483647-Ac|0)>>>0){B=-22;break}Ec=Cc+Ac|0}vc=zc+1|0;if(vc>>>0<(c[m>>2]|0)>>>0){zc=vc;Ac=Ec}else{wc=Ec;break A}}i=e;return B|0}}while(0);Ec=qJb(wc,4)|0;Ac=Ec;if((Ec|0)==0){B=-12;i=e;return B|0}Ec=c[m>>2]|0;if((Ec|0)==0){Fc=0}else{zc=c[Q>>2]|0;Q=0;Cc=0;r=Ec;while(1){Ec=c[zc+(Q<<2)>>2]|0;do{if((c[Ec+40>>2]|0)==0){Dc=Ec+24|0;if((c[Dc>>2]|0)==0){Gc=Cc;Hc=r;break}Bc=Ec+16|0;yc=0;xc=Cc;uc=c[Bc>>2]|0;while(1){c[Ac+(xc<<2)>>2]=c[uc+(yc<<2)>>2];Ic=xc+1|0;vc=c[Bc>>2]|0;c[(c[vc+(yc<<2)>>2]|0)+112>>2]=xc;Hb=yc+1|0;if(Hb>>>0<(c[Dc>>2]|0)>>>0){yc=Hb;xc=Ic;uc=vc}else{break}}Gc=Ic;Hc=c[m>>2]|0}else{Gc=Cc;Hc=r}}while(0);Ec=Q+1|0;if(Ec>>>0<Hc>>>0){Q=Ec;Cc=Gc;r=Hc}else{Fc=Gc;break}}}if((Fc|0)!=(wc|0)){KIb(0,0,2304128,(A=i,i=i+24|0,c[A>>2]=2252456,c[A+8>>2]=2209400,c[A+16>>2]=1143,A)|0);i=A;Hd();return 0}c[b+48>>2]=Ac;c[b+52>>2]=wc;B=0;i=e;return B|0}function yj(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((b|0)==0){j=-38;return j|0}k=(i&1|0)==0;do{if((i&3|0)==1){l=yj(b,d,e,f,g,h,i|2)|0;if((l|0)==-38){break}else{j=l}return j|0}}while(0);if(!((h|0)==0|(g|0)==0)){a[g]=0}l=b+20|0;m=c[l>>2]|0;if((m|0)==0){j=-38;return j|0}n=b+8|0;if(k){k=0;b=-38;o=m;while(1){p=c[(c[n>>2]|0)+(k<<2)>>2]|0;do{if((irc(d,2620296)|0)==0){q=19}else{r=c[p+8>>2]|0;if((r|0)!=0){if((irc(d,r)|0)==0){q=19;break}}if((irc(d,c[c[p+4>>2]>>2]|0)|0)==0){q=19}else{s=b;t=o}}}while(0);if((q|0)==19){q=0;r=Yi(p,e,f,g,h,i)|0;if((r|0)!=-38&(r|0)<0){j=r;q=22;break}s=r;t=c[l>>2]|0}r=k+1|0;if(r>>>0<t>>>0){k=r;b=s;o=t}else{j=s;q=22;break}}if((q|0)==22){return j|0}}else{s=0;t=m;while(1){m=c[(c[n>>2]|0)+(s<<2)>>2]|0;do{if((irc(d,2620296)|0)==0){q=12}else{o=c[m+8>>2]|0;if((o|0)!=0){if((irc(d,o)|0)==0){q=12;break}}if((irc(d,c[c[m+4>>2]>>2]|0)|0)==0){q=12}else{u=t}}}while(0);if((q|0)==12){q=0;p=Yi(m,e,f,g,h,i)|0;if(!((p|0)==-38)){j=p;q=22;break}u=c[l>>2]|0}p=s+1|0;if(p>>>0<u>>>0){s=p;t=u}else{j=-38;q=22;break}}if((q|0)==22){return j|0}}return 0}function zj(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=+g;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a|0)==0){return 0}i=a+20|0;j=c[i>>2]|0;if((j|0)==0){return 0}k=a+8|0;a=(f&1|0)==0;l=0;m=j;a:while(1){j=c[(c[k>>2]|0)+(l<<2)>>2]|0;b:do{if((j|0)==0){n=m}else{do{if((irc(b,2620296)|0)!=0){if((irc(b,c[j+8>>2]|0)|0)==0){break}if((irc(b,c[c[j+4>>2]>>2]|0)|0)!=0){n=m;break b}}}while(0);o=j+60|0;while(1){p=c[o>>2]|0;if((p|0)==0){q=0;break}if(+h[p>>3]>g){q=p;break}else{o=p+20|0}}c[o>>2]=pJb(24)|0;p=rJb(d)|0;c[(c[o>>2]|0)+8>>2]=p;p=rJb(e)|0;c[(c[o>>2]|0)+12>>2]=p;p=c[o>>2]|0;h[p>>3]=g;c[p+16>>2]=f;c[p+20>>2]=q;if(!a){r=14;break a}n=c[i>>2]|0}}while(0);j=l+1|0;if(j>>>0<n>>>0){l=j;m=n}else{r=14;break}}if((r|0)==14){return 0}return 0}function Aj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b+112|0;e=c[d>>2]|0;f=a+48|0;g=c[f>>2]|0;a:do{if((e|0)==0){h=0}else{i=b+104|0;j=c[i>>2]|0;k=c[i+4>>2]|0;i=e;while(1){l=i-1>>1;m=c[g+(l<<2)>>2]|0;n=m+104|0;o=c[n+4>>2]|0;if(!((o|0)<(k|0)|(o|0)==(k|0)&(c[n>>2]|0)>>>0<j>>>0)){h=i;break a}c[g+(i<<2)>>2]=m;c[m+112>>2]=i;if((l|0)==0){h=0;break}else{i=l}}}}while(0);c[g+(h<<2)>>2]=b;c[d>>2]=h;g=c[f>>2]|0;f=h<<1|1;e=a+52|0;a=c[e>>2]|0;if((f|0)>=(a|0)){p=h;q=g+(p<<2)|0;c[q>>2]=b;c[d>>2]=p;return}i=b+104|0;j=c[i>>2]|0;k=c[i+4>>2]|0;i=h;h=f;f=a;while(1){a=h+1|0;if((a|0)<(f|0)){l=(c[g+(a<<2)>>2]|0)+104|0;m=c[l+4>>2]|0;n=(c[g+(h<<2)>>2]|0)+104|0;o=c[n+4>>2]|0;r=(m|0)<(o|0)|(m|0)==(o|0)&(c[l>>2]|0)>>>0<(c[n>>2]|0)>>>0?a:h}else{r=h}a=c[g+(r<<2)>>2]|0;n=a+104|0;l=c[n+4>>2]|0;if((k|0)<(l|0)|(k|0)==(l|0)&j>>>0<(c[n>>2]|0)>>>0){p=i;s=11;break}c[g+(i<<2)>>2]=a;c[a+112>>2]=i;a=r<<1|1;n=c[e>>2]|0;if((a|0)<(n|0)){i=r;h=a;f=n}else{p=r;s=11;break}}if((s|0)==11){q=g+(p<<2)|0;c[q>>2]=b;c[d>>2]=p;return}}function Bj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;d=a+48|0;e=a+52|0;if((c[e>>2]|0)==0){f=-541478725;i=b;return f|0}while(1){a=c[c[d>>2]>>2]|0;g=Wi(a)|0;if(!((g|0)==-541478725)){f=g;h=16;break}g=c[a+8>>2]|0;if((g|0)==0){j=2370440}else{j=c[g+8>>2]|0}k=c[a+12>>2]|0;if((k|0)==0){l=2370440}else{l=c[k>>2]|0}KIb(g,48,2461416,(g=i,i=i+16|0,c[g>>2]=j,c[g+8>>2]=l,g)|0);i=g;g=a+112|0;a=c[g>>2]|0;k=(c[e>>2]|0)-1|0;c[e>>2]=k;if((a|0)<(k|0)){a=c[d>>2]|0;m=c[a+(k<<2)>>2]|0;n=c[g>>2]|0;o=n<<1|1;a:do{if((o|0)<(k|0)){p=m+104|0;q=c[p>>2]|0;r=c[p+4>>2]|0;p=n;s=o;t=k;while(1){u=s+1|0;if((u|0)<(t|0)){v=(c[a+(u<<2)>>2]|0)+104|0;w=c[v+4>>2]|0;x=(c[a+(s<<2)>>2]|0)+104|0;y=c[x+4>>2]|0;z=(w|0)<(y|0)|(w|0)==(y|0)&(c[v>>2]|0)>>>0<(c[x>>2]|0)>>>0?u:s}else{z=s}u=c[a+(z<<2)>>2]|0;x=u+104|0;v=c[x+4>>2]|0;if((r|0)<(v|0)|(r|0)==(v|0)&q>>>0<(c[x>>2]|0)>>>0){A=p;break a}c[a+(p<<2)>>2]=u;c[u+112>>2]=p;u=z<<1|1;x=c[e>>2]|0;if((u|0)<(x|0)){p=z;s=u;t=x}else{A=z;break}}}else{A=n}}while(0);c[a+(A<<2)>>2]=m;c[m+112>>2]=A}c[g>>2]=-1;if((c[e>>2]|0)==0){f=-541478725;h=16;break}}if((h|0)==16){i=b;return f|0}return 0}function Cj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;if((b|0)==0){f=0;i=e;return f|0}g=b+64|0;h=c[g>>2]|0;if((h|0)==0){f=0;i=e;return f|0}j=b+16|0;k=c[j>>2]|0;do{if((k|0)!=0|(d|0)==0){l=h;m=k}else{if((c[d+16>>2]|0)!=0){l=h;m=0;break}n=d+52|0;o=(a[(qKb(c[n>>2]|0)|0)+4|0]&1^1)&255;p=c[g>>2]|0;if((c[p>>2]|0)==0){q=-1}else{r=-1;s=0;t=p;while(1){p=xLa(r,c[(c[t+4>>2]|0)+(s<<2)>>2]|0,c[n>>2]|0,o,0)|0;u=s+1|0;v=c[g>>2]|0;if(u>>>0<(c[v>>2]|0)>>>0){r=p;s=u;t=v}else{q=p;break}}}t=c[b>>2]|0;s=mKb(q)|0;r=c[c[g>>2]>>2]|0;p=mKb(c[n>>2]|0)|0;KIb(t,48,2148752,(w=i,i=i+32|0,c[w>>2]=s,c[w+8>>2]=r,c[w+16>>2]=p,c[w+24>>2]=o,w)|0);i=w;p=c[g>>2]|0;c[c[p+4>>2]>>2]=q;l=p;m=c[j>>2]|0}}while(0);c[l>>2]=1;c[b+52>>2]=c[c[l+4>>2]>>2];l=b+72|0;a:do{if((m|0)==1){j=c[l>>2]|0;q=j|0;if((c[q>>2]|0)==0){d=c[b>>2]|0;h=c[(c[b+8>>2]|0)+8>>2]|0;KIb(d,16,2124672,(w=i,i=i+16|0,c[w>>2]=c[d+8>>2],c[w+8>>2]=h,w)|0);i=w;f=-22;i=e;return f|0}c[q>>2]=1;c[b+48>>2]=c[c[j+4>>2]>>2];j=b+80|0;q=c[j>>2]|0;if((a[q+8|0]|0)!=0){h=b|0;d=c[h>>2]|0;k=c[(c[b+8>>2]|0)+8>>2]|0;KIb(d,16,2642816,(w=i,i=i+16|0,c[w>>2]=c[d+8>>2],c[w+8>>2]=k,w)|0);i=w;if((a[(c[j>>2]|0)+9|0]|0)!=0){f=-22;i=e;return f|0}KIb(c[h>>2]|0,16,2619424,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;f=-22;i=e;return f|0}c[q+4>>2]=1;h=c[q>>2]|0;q=c[h>>2]|0;k=c[h+4>>2]|0;h=b+40|0;c[h>>2]=q;c[h+4>>2]=k;d=0;do{if((k|0)<(d|0)|(k|0)==(d|0)&q>>>0<0>>>0){p=q&2147483647;r=b+148|0;c[r>>2]=p;if((p|0)==0){x=r;break}c[h>>2]=0;c[h+4>>2]=0;y=j;break a}else{r=b+148|0;c[r>>2]=0;x=r}}while(0);c[x>>2]=rGb(q,k)|0;y=j}else{y=b+80|0}}while(0);Zk(g);Zk(b+68|0);Zk(l);Zk(b+76|0);_k(y);_k(b+84|0);f=0;i=e;return f|0}function Dj(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+64|0;e=d|0;f=b+16|0;g=c[f>>2]|0;do{if((g|0)==0){h=4}else{j=c[g>>2]|0;if((j|0)==0){h=4;break}k=c[j+16>>2]|0}}while(0);do{if((h|0)==4){g=c[b+32>>2]|0;if((g|0)==0){k=0;break}j=c[g>>2]|0;if((j|0)==0){k=0;break}k=c[j+16>>2]|0}}while(0);j=ve[c[(c[b+4>>2]|0)+36>>2]&4095](b)|0;if((j|0)<0){if((j|0)==-11){l=-11;i=d;return l|0}g=c[b+8>>2]|0;m=e|0;mrc(m|0,0,64)|0;a[m]=0;RGb(j,m,64)|0;KIb(b,16,2404480,(n=i,i=i+16|0,c[n>>2]=g,c[n+8>>2]=m,n)|0);i=n;l=j;i=d;return l|0}j=b+24|0;if((c[j>>2]|0)!=0){m=b;g=0;do{e=c[(c[(c[f>>2]|0)+(g<<2)>>2]|0)+84>>2]|0;do{if((e|0)!=0){if((c[e+4>>2]|0)==0){o=e+8|0;do{if((a[e+9|0]|0)!=0){if((a[o]|0)!=0){break}KIb(m,24,2390104,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}}while(0);a[o]=1;break}else{p=e+8|0;q=e+9|0;if((a[p]|0)==0){if((a[q]|0)!=0){h=18}}else{h=18}if((h|0)==18){h=0;KIb(m,24,2397112,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}a[q]=0;a[p]=0;break}}}while(0);g=g+1|0;}while(g>>>0<(c[j>>2]|0)>>>0)}j=b+40|0;if((c[j>>2]|0)!=0){g=b;m=b+32|0;f=0;do{e=c[(c[(c[m>>2]|0)+(f<<2)>>2]|0)+80>>2]|0;do{if((e|0)!=0){if((c[e+4>>2]|0)==0){p=e+8|0;do{if((a[e+9|0]|0)!=0){if((a[p]|0)!=0){break}KIb(g,24,2390104,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}}while(0);a[p]=1;break}else{o=e+8|0;q=e+9|0;if((a[o]|0)==0){if((a[q]|0)!=0){h=29}}else{h=29}if((h|0)==29){h=0;KIb(g,24,2397112,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}a[q]=0;a[o]=0;break}}}while(0);f=f+1|0;}while(f>>>0<(c[j>>2]|0)>>>0)}j=Sk(k)|0;if((j|0)==0){l=-12;i=d;return l|0}dl(b,j);if((k|0)!=1){l=0;i=d;return l|0}k=Uk()|0;if((k|0)==0){l=-12;i=d;return l|0}cl(b,k);k=Vk()|0;if((k|0)==0){l=-12;i=d;return l|0}bl(b,k);l=0;i=d;return l|0}function Ej(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+40|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;if((a|0)==(b|0)){m=1;i=f;return m|0}n=h;o=sJb(a,16)|0;p=o;c[h>>2]=p;do{if((o|0)==0){q=p}else{c[o+8>>2]=0;c[o+12>>2]=0;r=c[h>>2]|0;s=r+4|0;c[s>>2]=sJb(c[s>>2]|0,c[r>>2]<<2)|0;r=c[h>>2]|0;if((c[r+4>>2]|0)!=0){q=r;break}if((c[a+4>>2]|0)==0){q=r;break}mJb(n);q=c[h>>2]|0}}while(0);c[j>>2]=q;q=g;h=sJb(b,16)|0;n=h;c[g>>2]=n;do{if((h|0)==0){t=n}else{c[h+8>>2]=0;c[h+12>>2]=0;a=c[g>>2]|0;o=a+4|0;c[o>>2]=sJb(c[o>>2]|0,c[a>>2]<<2)|0;a=c[g>>2]|0;if((c[a+4>>2]|0)!=0){t=a;break}if((c[b+4>>2]|0)==0){t=a;break}mJb(q);t=c[g>>2]|0}}while(0);c[k>>2]=t;g=c[j>>2]|0;q=(g|0)==0;if(q|(t|0)==0){if(q){u=t}else{mJb(g+4|0);u=c[k>>2]|0}if((u|0)!=0){mJb(u+4|0)}mJb(j);mJb(k);m=0;i=f;return m|0}if((e|0)==0){v=Kk(g,t,d)|0}else{v=Lk(g,t)|0}c[l>>2]=v;if((v|0)==0){mJb((c[j>>2]|0)+4|0);mJb((c[k>>2]|0)+4|0);mJb(j);mJb(k);m=0;i=f;return m|0}else{mJb(v+4|0);mJb(v+12|0);mJb(l);m=1;i=f;return m|0}return 0}function Fj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;if((a|0)==0){i=b;return}d=c[a>>2]|0;e=d+88|0;f=c[e>>2]|0;if((f|0)==0){KIb(0,0,2601152,(g=i,i=i+24|0,c[g>>2]=2615912,c[g+8>>2]=2459144,c[g+16>>2]=102,g)|0);i=g;Hd()}g=f-1|0;c[e>>2]=g;if((g|0)==0){qe[c[d+72>>2]&1023](d)}d=a+36|0;if((c[d>>2]|0)!=(a+4|0)){mJb(d)}d=a+72|0;g=c[d>>2]|0;if((g|0)!=0){mJb(g+40|0)}mJb(d);mJb(a+76|0);OGb(a+108|0);kJb(a);i=b;return}function Gj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=c[c[a+16>>2]>>2]|0;h=(c[a+44>>2]|0)+4|0;do{if((fHb(c[h>>2]|0)|0)==0){if((d&2|0)!=0){j=-11;i=e;return j|0}a=Wi(g)|0;if((a|0)<0){j=a}else{break}i=e;return j|0}}while(0);if((fHb(c[h>>2]|0)|0)==0){j=-22;i=e;return j|0}g=c[h>>2]|0;do{if((d&1|0)==0){iHb(g,f,4,0)|0;aIb(b,c[f>>2]|0);VHb(f)}else{h=c[g>>2]|0;a=c[g+4>>2]|0;k=c[g+12>>2]|0;do{if(a>>>0<k>>>0){if(!(a>>>0<h>>>0)){l=a;break}l=k+(a-h)|0}else{l=h+(a-k)|0}}while(0);k=c[l>>2]|0;c[f>>2]=k;a=YHb(b,k)|0;if((a|0)<0){j=a}else{break}i=e;return j|0}}while(0);j=0;i=e;return j|0}function Hj(a,b){a=a|0;b=b|0;var d=0;d=c[c[a+16>>2]>>2]|0;c[d+128>>2]=b;c[d+136>>2]=b;c[d+132>>2]=b;return}function Ij(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=c[c[b+4>>2]>>2]|0;do{if((irc(e,2600344)|0)!=0){if((irc(e,2458960)|0)==0){break}KIb(0,0,2302936,(f=i,i=i+24|0,c[f>>2]=2176032,c[f+8>>2]=2208592,c[f+16>>2]=360,f)|0);i=f;Hd()}}while(0);e=(c[c[b+16>>2]>>2]|0)+116|0;b=a;a=c[e+4>>2]|0;c[b>>2]=c[e>>2];c[b+4>>2]=a;i=d;return}function Jj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;a=c[e+56>>2]|0;if((a|0)!=0){tFb(a)}a=e+4|0;e=c[a>>2]|0;if((e|0)==0){i=b;return}f=(fHb(e)|0)>>>0>3>>>0;e=c[a>>2]|0;if(f){f=d;g=e;while(1){iHb(g,f,4,0)|0;VHb(d);h=(fHb(c[a>>2]|0)|0)>>>0>3>>>0;j=c[a>>2]|0;if(h){g=j}else{k=j;break}}}else{k=e}eHb(k);c[a>>2]=0;i=b;return}function Kj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=0;f=e+16|0;g=c[f>>2]|0;if((g&3|0)!=0){KIb(a,16,2369816,(h=i,i=i+16|0,c[h>>2]=g,c[h+8>>2]=4,h)|0);i=h;j=-22;i=b;return j|0}if((g|0)==0){el(a)|0;j=0;i=b;return j|0}h=e+12|0;e=0;k=g;while(1){if(!(e>>>0<k>>>2>>>0)){l=9;break}g=c[(c[h>>2]|0)+(e<<2)>>2]|0;m=Qk(d,g,(g|0)<0|0?-1:0)|0;if((m|0)<0){l=8;break}e=e+1|0;k=c[f>>2]|0}if((l|0)==8){Zk(d);j=m;i=b;return j|0}else if((l|0)==9){dl(a,c[d>>2]|0);j=0;i=b;return j|0}return 0}function Lj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a+44|0;f=c[e>>2]|0;do{if((b|0)==0){g=f}else{h=c[b>>2]|0;j=CLb(4,h,-1,-1)|0;if(j>>>0>536870911>>>0){k=-22;i=d;return k|0}l=JJb(f,2431296,h,j<<2,0)|0;if((l|0)<0){k=l;i=d;return k|0}else{g=c[e>>2]|0;break}}}while(0);e=dHb(32)|0;c[g+4>>2]=e;if((e|0)==0){KIb(a,16,2411736,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-12;i=d;return k|0}else{c[g+8>>2]=100;a=g+64|0;c[a>>2]=0;c[a+4>>2]=-2147483648;k=0;i=d;return k|0}return 0}function Mj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;c[d>>2]=0;c[e>>2]=0;g=f+24|0;h=c[g>>2]|0;if((h&3|0)!=0){KIb(a,16,2404264,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=4,j)|0);i=j;k=-22;i=b;return k|0}l=f+52|0;m=c[l>>2]|0;if((m&3|0)!=0){KIb(a,16,2396960,(j=i,i=i+16|0,c[j>>2]=m,c[j+8>>2]=4,j)|0);i=j;k=-22;i=b;return k|0}m=f+32|0;n=c[m>>2]|0;if((n&7|0)!=0){KIb(a,16,2389960,(j=i,i=i+16|0,c[j>>2]=n,c[j+8>>2]=8,j)|0);i=j;k=-22;i=b;return k|0}o=f+40|0;p=c[o>>2]|0;if((p&3|0)!=0){KIb(a,16,2383096,(j=i,i=i+16|0,c[j>>2]=p,c[j+8>>2]=4,j)|0);i=j;k=-22;i=b;return k|0}do{if((h|0)==0){q=n}else{p=f+20|0;r=0;s=h;while(1){if(!(r>>>0<s>>>2>>>0)){t=15;break}u=c[(c[p>>2]|0)+(r<<2)>>2]|0;v=Qk(d,u,(u|0)<0|0?-1:0)|0;if((v|0)<0){break}r=r+1|0;s=c[g>>2]|0}if((t|0)==15){dl(a,c[d>>2]|0);q=c[m>>2]|0;break}Zk(d);k=v;i=b;return k|0}}while(0);do{if((q|0)==0){if((c[o>>2]|0)!=0){t=19;break}if((c[f+44>>2]|0)!=0){t=19}}else{t=19}}while(0);if((t|0)==19){v=f+28|0;g=0;h=q;while(1){if(!(g>>>0<h>>>3>>>0)){break}q=(c[v>>2]|0)+(g<<3)|0;w=Rk(e,c[q>>2]|0,c[q+4>>2]|0)|0;if((w|0)<0){t=24;break}g=g+1|0;h=c[m>>2]|0}if((t|0)==24){_k(e);k=w;i=b;return k|0}w=f+36|0;m=0;while(1){if(!(m>>>0<(c[o>>2]|0)>>>2>>>0)){break}h=c[(c[w>>2]|0)+(m<<2)>>2]|0;x=Rk(e,h|0,((h|0)<0|0?-1:0)|-2147483648)|0;if((x|0)<0){t=28;break}m=m+1|0}if((t|0)==28){_k(e);k=x;i=b;return k|0}do{if((c[f+44>>2]|0)!=0){if((c[e>>2]|0)!=0){KIb(a,24,2376368,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;break}x=Wk()|0;c[e>>2]=x;if((x|0)==0){k=-12}else{break}i=b;return k|0}}while(0);bl(a,c[e>>2]|0)}e=c[l>>2]|0;if((e|0)==0){k=0;i=b;return k|0}c[d>>2]=0;j=f+48|0;f=0;x=e;while(1){if(!(f>>>0<x>>>2>>>0)){t=40;break}e=c[(c[j>>2]|0)+(f<<2)>>2]|0;y=Qk(d,e,(e|0)<0|0?-1:0)|0;if((y|0)<0){t=39;break}f=f+1|0;x=c[l>>2]|0}if((t|0)==39){Zk(d);k=y;i=b;return k|0}else if((t|0)==40){cl(a,c[d>>2]|0);k=0;i=b;return k|0}return 0}function Nj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a+44|0;f=c[e>>2]|0;do{if((b|0)==0){g=f}else{h=c[b>>2]|0;j=CLb(4,h,-1,-1)|0;if(j>>>0>536870911>>>0){k=-22;i=d;return k|0}l=JJb(f,2642344,h,j<<2,0)|0;if((l|0)<0){k=l;i=d;return k|0}l=c[b+16>>2]|0;j=CLb(4,l,-1,-1)|0;if(j>>>0>536870911>>>0){k=-22;i=d;return k|0}h=JJb(f,2591648,l,j<<2,0)|0;if((h|0)<0){k=h;i=d;return k|0}h=c[b+4>>2]|0;j=CLb(8,h,-1,-1)|0;if(j>>>0>268435455>>>0){k=-22;i=d;return k|0}l=JJb(f,2551352,h,j<<3,0)|0;if((l|0)<0){k=l;i=d;return k|0}l=c[b+8>>2]|0;j=CLb(4,l,-1,-1)|0;if(j>>>0>536870911>>>0){k=-22;i=d;return k|0}h=JJb(f,2517752,l,j<<2,0)|0;if((h|0)<0){k=h;i=d;return k|0}h=c[b+12>>2]|0;j=IJb(f,2490360,h,(h|0)<0|0?-1:0,0)|0;if((j|0)<0){k=j;i=d;return k|0}else{g=c[e>>2]|0;break}}}while(0);e=dHb(32)|0;c[g+4>>2]=e;if((e|0)==0){KIb(a,16,2411736,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-12;i=d;return k|0}else{c[g+8>>2]=100;a=g+64|0;c[a>>2]=0;c[a+4>>2]=-2147483648;k=0;i=d;return k|0}return 0}function Oj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=c[a+8>>2]|0;a=f+44|0;g=c[a>>2]|0;h=e;c[e>>2]=b;b=(c[a>>2]|0)+4|0;do{if((gHb(c[b>>2]|0)|0)>>>0<4>>>0){a=c[b>>2]|0;if((hHb(a,(fHb(a)|0)<<1)|0)>=0){break}KIb(f,16,2444e3,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-12;i=d;return k|0}}while(0);jHb(c[b>>2]|0,h,4,0)|0;h=g+8|0;if((c[h>>2]|0)==0){k=0;i=d;return k|0}b=(fHb(c[g+4>>2]|0)|0)>>>2;g=c[h>>2]|0;if(b>>>0<g>>>0){k=0;i=d;return k|0}b=c[f+8>>2]|0;a=(b|0)!=0?b:c[c[f+4>>2]>>2]|0;KIb(f,24,2460632,(j=i,i=i+16|0,c[j>>2]=g,c[j+8>>2]=a,j)|0);i=j;c[h>>2]=(c[h>>2]|0)*10|0;k=0;i=d;return k|0}function Pj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;do{if((b|0)!=0){g=b+352|0;h=c[g>>2]|0;j=c[g+4>>2]|0;do{if(!((h|0)==0&(j|0)==0)){g=rGb(h,j)|0;if((g|0)==(GHb(b)|0)){break}KIb(0,16,2588200,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;k=-22;i=e;return k|0}}while(0);if((d&8|0)==0){break}j=UHb()|0;c[f>>2]=j;if((j|0)==0){k=-12;i=e;return k|0}h=YHb(j,b)|0;if((h|0)>-1){l=Qj(a,j,d)|0}else{l=h}VHb(f);k=l;i=e;return k|0}}while(0);k=Qj(a,b,d)|0;i=e;return k|0}function Qj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=c[a+44>>2]|0;c[g+24>>2]=0;h=g+84|0;if((b|0)==0){c[h>>2]=1;j=0;i=e;return j|0}if((c[h>>2]|0)!=0){j=-22;i=e;return j|0}h=(c[b+360>>2]|0)!=0;a:do{if((d&1|0)==0){k=c[(c[c[a+32>>2]>>2]|0)+16>>2]|0;if((k|0)==0){do{if((c[g+32>>2]|0)==(c[b+68>>2]|0)){if((c[g+36>>2]|0)!=(c[b+72>>2]|0)){break}if((c[g+40>>2]|0)==(c[b+80>>2]|0)){break a}}}while(0);KIb(a,32,2345976,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}else if((k|0)==1){m=b+352|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((n|0)==0&(o|0)==0){p=g+72|0;q=c[p>>2]|0;r=c[p+4>>2]|0;c[m>>2]=q;c[m+4>>2]=r;s=r;t=q}else{s=o;t=n}do{if((c[g+60>>2]|0)==(c[b+80>>2]|0)){if((c[g+56>>2]|0)!=(c[b+344>>2]|0)){break}n=g+72|0;if(!((c[n>>2]|0)==(t|0)&(c[n+4>>2]|0)==(s|0))){break}n=c[g+64>>2]|0;if((n|0)==(GHb(b)|0)){break a}}}while(0);KIb(a,16,2339992,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=-22;i=e;return j|0}else{j=-22;i=e;return j|0}}}while(0);l=g+4|0;do{if((gHb(c[l>>2]|0)|0)==0){g=c[l>>2]|0;s=hHb(g,(fHb(g)|0)+4|0)|0;if((s|0)<0){j=s}else{break}i=e;return j|0}}while(0);s=UHb()|0;c[f>>2]=s;if((s|0)==0){j=-12;i=e;return j|0}do{if(h){aIb(s,b)}else{g=YHb(s,b)|0;if((g|0)>=0){break}VHb(f);j=g;i=e;return j|0}}while(0);s=jHb(c[l>>2]|0,f,4,0)|0;if((s|0)<0){if(h){aIb(b,c[f>>2]|0)}VHb(f);j=s;i=e;return j|0}do{if((d&4|0)!=0){s=ve[c[(c[a+28>>2]|0)+44>>2]&4095](c[c[a+32>>2]>>2]|0)|0;if((s|0)<0){j=s}else{break}i=e;return j|0}}while(0);j=0;i=e;return j|0}function Rj(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[a+44>>2]|0;c[g>>2]=0;c[h>>2]=0;k=j+84|0;if((b|0)==0){c[k>>2]=1;l=0;i=f;return l|0}if((c[k>>2]|0)!=0){l=-22;i=f;return l|0}k=UHb()|0;c[g>>2]=k;if((k|0)==0){l=-12;i=f;return l|0}k=b+100|0;j=aGb(0,0,374,b,(c[k>>2]|0)>>>1&1^1)|0;c[h>>2]=j;a:do{if((j|0)==0){m=-12}else{n=Iz(c[g>>2]|0,b)|0;if((n|0)<0){m=n;break}n=c[(c[g>>2]|0)+80>>2]|0;b:do{if((c[(c[c[a+32>>2]>>2]|0)+16>>2]|0)==0){o=qKb(n)|0;p=uKb(c[(c[g>>2]|0)+80>>2]|0)|0;if((o|0)==0|(p|0)<1){m=-22;break a}q=o+6|0;o=0;while(1){if((o|0)>=(p|0)){break b}if((o-1|0)>>>0<2>>>0){r=d[q]|0}else{r=0}s=c[g>>2]|0;t=c[s+72>>2]|0;u=c[s+32+(o<<2)>>2]|0;s=eGb(c[h>>2]|0)|0;if((s|0)==0){m=-12;break a}v=ca(t>>r,u)|0;u=aGb(c[(c[g>>2]|0)+(o<<2)>>2]|0,v,256,s,(c[k>>2]|0)>>>1&1^1)|0;c[(c[g>>2]|0)+360+(o<<2)>>2]=u;w=c[g>>2]|0;if((c[w+360+(o<<2)>>2]|0)==0){break}else{o=o+1|0}}WHb(w);m=-12;break a}else{o=RKb(n)|0;q=(c[g>>2]|0)+352|0;p=rGb(c[q>>2]|0,c[q+4>>2]|0)|0;q=(o|0)!=0?p:1;p=q>>>0>8>>>0;if(p){o=q-8|0;c[(c[g>>2]|0)+396>>2]=o;u=pJb(o<<2)|0;c[(c[g>>2]|0)+392>>2]=u;if((c[(c[g>>2]|0)+392>>2]|0)==0){m=-12;break a}}u=p?8:q;p=0;while(1){if(!(p>>>0<u>>>0)){break}o=eGb(c[h>>2]|0)|0;if((o|0)==0){m=-12;break a}s=c[g>>2]|0;v=aGb(c[(c[s+64>>2]|0)+(p<<2)>>2]|0,c[s+32>>2]|0,256,o,(c[k>>2]|0)>>>1&1^1)|0;c[(c[g>>2]|0)+360+(p<<2)>>2]=v;x=c[g>>2]|0;if((c[x+360+(p<<2)>>2]|0)==0){y=23;break}else{p=p+1|0}}if((y|0)==23){WHb(x);m=-12;break a}p=q-8|0;u=0;while(1){if(!(u>>>0<p>>>0)){break b}v=eGb(c[h>>2]|0)|0;if((v|0)==0){m=-12;break a}o=c[g>>2]|0;s=aGb(c[(c[o+64>>2]|0)+(u+8<<2)>>2]|0,c[o+32>>2]|0,256,v,(c[k>>2]|0)>>>1&1^1)|0;c[(c[(c[g>>2]|0)+392>>2]|0)+(u<<2)>>2]=s;z=c[g>>2]|0;if((c[(c[z+392>>2]|0)+(u<<2)>>2]|0)==0){break}else{u=u+1|0}}WHb(z);m=-12;break a}}while(0);m=Pj(a,c[g>>2]|0,e)|0}}while(0);fGb(h);VHb(g);l=m;i=f;return l|0}function Sj(a,b){a=a|0;b=b|0;Fj(a);return}function Tj(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;fGb(d);i=b;return}function Uj(a){a=a|0;return c[(c[a+44>>2]|0)+24>>2]|0}function Vj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;d=c[a+44>>2]|0;e=d+40|0;do{if(!((c[e>>2]|0)==-1)){f=d+32|0;if((c[f>>2]|0)==0){break}g=d+36|0;if((c[g>>2]|0)==0){break}h=d+8|0;j=d+12|0;if(!(+(c[h>>2]|0)/+(c[j>>2]|0)>0.0)){break}k=dHb(4)|0;c[d+4>>2]=k;if((k|0)==0){l=-12;i=b;return l|0}k=c[f>>2]|0;f=c[g>>2]|0;g=mKb(c[e>>2]|0)|0;m=c[h>>2]|0;h=c[j>>2]|0;j=c[d+16>>2]|0;n=c[d+20>>2]|0;o=c[d+44>>2]|0;p=c[d+48>>2]|0;q=c[d+52>>2]|0;KIb(a,40,2503576,(r=i,i=i+80|0,c[r>>2]=k,c[r+8>>2]=f,c[r+16>>2]=g,c[r+24>>2]=m,c[r+32>>2]=h,c[r+40>>2]=j,c[r+48>>2]=n,c[r+56>>2]=o,c[r+64>>2]=p,c[r+72>>2]=(q|0)!=0?q:10230560,r)|0);i=r;c[d+28>>2]=100;l=0;i=b;return l|0}}while(0);KIb(a,16,2517528,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;l=-22;i=b;return l|0}function Wj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;d=b|0;e=(c[a+44>>2]|0)+4|0;a=c[e>>2]|0;a:do{if((a|0)==0){f=0}else{g=d;h=a;while(1){j=(fHb(h)|0)==0;k=c[e>>2]|0;if(j){f=k;break a}iHb(k,g,4,0)|0;VHb(d);k=c[e>>2]|0;if((k|0)==0){f=0;break}else{h=k}}}}while(0);eHb(f);c[e>>2]=0;i=b;return}function Xj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=c[a+44>>2]|0;c[d>>2]=0;c[e>>2]=0;c[f>>2]=0;h=c[(c[c[a+32>>2]>>2]|0)+16>>2]|0;if((h|0)==0){j=c[g+40>>2]|0;Qk(e,j,(j|0)<0|0?-1:0)|0;dl(a,c[e>>2]|0);k=0;i=b;return k|0}else if((h|0)==1){h=c[g+60>>2]|0;Qk(e,h,(h|0)<0|0?-1:0)|0;dl(a,c[e>>2]|0);e=c[g+56>>2]|0;Qk(f,e,(e|0)<0|0?-1:0)|0;cl(a,c[f>>2]|0);f=g+72|0;e=c[f>>2]|0;h=c[f+4>>2]|0;if((e|0)==0&(h|0)==0){f=c[g+64>>2]|0;l=((f|0)<0|0?-1:0)|-2147483648;m=f|0}else{l=h;m=e}Rk(d,m,l)|0;bl(a,c[d>>2]|0);k=0;i=b;return k|0}else{k=-22;i=b;return k|0}return 0}function Yj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=c[a+44>>2]|0;e=d+60|0;if((c[e>>2]|0)==-1){KIb(a,16,2250264,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}h=d+80|0;j=c[h>>2]|0;do{if((j|0)==0){if((c[d+64>>2]|0)!=0){break}KIb(a,16,2147704,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else{k=pGb(j)|0;l=G;m=d+72|0;c[m>>2]=k;c[m+4>>2]=l;if((k|0)==0&(l|0)==0){KIb(a,16,2207736,(f=i,i=i+8|0,c[f>>2]=c[h>>2],f)|0);i=f;g=-22;i=b;return g|0}m=rGb(k,l)|0;l=d+64|0;k=c[l>>2]|0;if((k|0)==0|(m|0)==(k|0)){c[l>>2]=m;break}l=c[h>>2]|0;KIb(a,16,2175320,(f=i,i=i+24|0,c[f>>2]=k,c[f+8>>2]=l,c[f+16>>2]=m,f)|0);i=f;g=-22;i=b;return g|0}}while(0);j=dHb(4)|0;c[d+4>>2]=j;if((j|0)==0){g=-12;i=b;return g|0}j=d+8|0;m=c[j>>2]|0;if((m|0)==0){l=d+56|0;k=c[l>>2]|0;c[j>>2]=1;c[d+12>>2]=k;n=1;o=k;p=l}else{n=m;o=c[d+12>>2]|0;p=d+56|0}m=LKb(c[e>>2]|0)|0;e=c[p>>2]|0;p=c[h>>2]|0;KIb(a,40,2123720,(f=i,i=i+40|0,c[f>>2]=n,c[f+8>>2]=o,c[f+16>>2]=m,c[f+24>>2]=e,c[f+32>>2]=p,f)|0);i=f;c[d+28>>2]=100;g=0;i=b;return g|0}function Zj(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;a=fHb(c[b+4>>2]|0)|0;do{if((a|0)==0){if((c[b+84>>2]|0)==0){break}else{d=-541478725}return d|0}}while(0);d=a>>>2;return d|0}function _j(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;e=c[(c[a>>2]|0)+44>>2]|0;f=e+4|0;if((fHb(c[f>>2]|0)|0)!=0){iHb(c[f>>2]|0,d,4,0)|0;g=lj(a,c[d>>2]|0)|0;i=b;return g|0}if((c[e+84>>2]|0)!=0){g=-541478725;i=b;return g|0}d=e+24|0;c[d>>2]=(c[d>>2]|0)+1;g=-11;i=b;return g|0}function $j(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[(c[a>>2]|0)+44>>2]|0;d=c[a+16>>2]|0;do{if((d|0)==0){c[a+20>>2]=c[b+32>>2];c[a+24>>2]=c[b+36>>2];e=b+44|0;f=a+28|0;g=c[e+4>>2]|0;c[f>>2]=c[e>>2];c[f+4>>2]=g}else if((d|0)==1){g=b+72|0;if(!((c[g>>2]|0)==0&(c[g+4>>2]|0)==0)){break}f=a+40|0;e=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=e}else{h=-22;return h|0}}while(0);d=b+8|0;e=a+56|0;g=c[d+4>>2]|0;c[e>>2]=c[d>>2];c[e+4>>2]=g;g=b+16|0;b=a+116|0;a=c[g+4>>2]|0;c[b>>2]=c[g>>2];c[b+4>>2]=a;h=0;return h|0}function ak(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+144|0;d=b|0;e=b+64|0;f=b+104|0;g=c[a+44>>2]|0;j=g+6280|0;k=c[j>>2]|0;a:do{if(!((k|0)==32|(k|0)==40)){do{if((c[g+32>>2]|0)==0){if((c[g+6284>>2]|0)!=0){break}c[j>>2]=32;break a}}while(0);c[j>>2]=40}}while(0);j=g+96|0;c[g+100>>2]=(c[j>>2]|0)*3|0;k=qJb(8001,24)|0;l=k;if((k|0)==0){m=0}else{k=0;while(1){n=+(k|0)/100.0+-70.0;h[l+(k*24|0)+16>>3]=n;h[l+(k*24|0)+8>>3]=+T(+10.0,+((n+.691)/10.0));o=k+1|0;if((o|0)<8001){k=o}else{m=l;break}}}l=g+5452|0;c[l>>2]=m;m=qJb(8001,24)|0;k=m;if((m|0)==0){c[g+6244>>2]=0;p=-12;i=b;return p|0}else{q=0}do{n=+(q|0)/100.0+-70.0;h[k+(q*24|0)+16>>3]=n;h[k+(q*24|0)+8>>3]=+T(+10.0,+((n+.691)/10.0));q=q+1|0;}while((q|0)<8001);c[g+6244>>2]=k;if((c[l>>2]|0)==0){p=-12;i=b;return p|0}h[g+6248>>3]=-70.0;h[g+6256>>3]=0.0;l=g+32|0;do{if((c[l>>2]|0)==0){r=0;s=d|0;t=d+4|0;u=d+8|0;v=d+48|0;w=d+52|0}else{g=e;mrc(g|0,0,40)|0;k=rJb(2207256)|0;q=d|0;c[q>>2]=k;m=d+4|0;c[m>>2]=0;o=d+8|0;nrc(o|0,g|0,40)|0;g=d+48|0;c[g>>2]=1014;x=d+52|0;c[x>>2]=0;c[x+4>>2]=0;if((k|0)==0){p=-12;i=b;return p|0}else{k=a+40|0;Qi(0,k,4,a+28|0,a+32|0,d)|0;c[a+36>>2]=c[k>>2];r=c[l>>2]|0;s=q;t=m;u=o;v=g;w=x;break}}}while(0);e=f;mrc(e|0,0,40)|0;f=FFb(2174976,(x=i,i=i+8|0,c[x>>2]=r,x)|0)|0;i=x;c[s>>2]=f;c[t>>2]=1;nrc(u|0,e|0,40)|0;c[v>>2]=1968;c[w>>2]=0;c[w+4>>2]=0;if((f|0)==0){p=-12;i=b;return p|0}f=a+40|0;Qi(c[l>>2]|0,f,4,a+28|0,a+32|0,d)|0;c[a+36>>2]=c[f>>2];KIb(a,40,2147240,(x=i,i=i+8|0,c[x>>2]=c[j>>2],x)|0);i=x;p=0;i=b;return p|0}function bk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0;b=i;d=c[a+44>>2]|0;e=a;f=d+4664|0;g=+h[d+5432>>3];j=+h[d+6256>>3];k=d+5456|0;l=+h[d+6224>>3];m=+h[d+6264>>3];n=+h[d+6272>>3];KIb(e,32,2455848,(o=i,i=i+48|0,h[o>>3]=+h[d+6248>>3],h[o+8>>3]=g,h[o+16>>3]=j,h[o+24>>3]=l,h[o+32>>3]=m,h[o+40>>3]=n,o)|0);i=o;p=d+4|0;q=c[p>>2]|0;if((q&2|0)==0){r=q}else{q=c[d+112>>2]|0;if((q|0)>0){s=c[d+12>>2]|0;t=0;n=0.0;while(1){m=+h[s+(t<<3)>>3];l=n>m?n:m;u=t+1|0;if((u|0)<(q|0)){t=u;n=l}else{v=l;break}}}else{v=0.0}n=+fd(+v)*20.0;KIb(e,32,2366472,(o=i,i=i+8|0,h[o>>3]=n,o)|0);i=o;r=c[p>>2]|0}p=d+112|0;if((r&4|0)!=0){r=c[p>>2]|0;if((r|0)>0){t=c[d+8>>2]|0;q=0;n=0.0;while(1){v=+h[t+(q<<3)>>3];l=n>v?n:v;s=q+1|0;if((s|0)<(r|0)){q=s;n=l}else{w=l;break}}}else{w=0.0}n=+fd(+w)*20.0;KIb(e,32,2300936,(o=i,i=i+8|0,h[o>>3]=n,o)|0);i=o}KIb(e,32,2249584,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;mJb(d+108|0);mJb(d+116|0);mJb(d+8|0);mJb(d+12|0);mJb(d+16|0);mJb(d+5452|0);mJb(d+6244|0);if((c[p>>2]|0)>0){o=f;f=k;k=0;do{mJb(o+(k<<2)|0);mJb(f+(k<<2)|0);k=k+1|0;}while((k|0)<(c[p>>2]|0))}p=a+40|0;if((c[p>>2]|0)==0){x=d+92|0;y=x;VHb(y);z=d+24|0;mJb(z);A=d+20|0;B=A;Zvb(B);i=b;return}k=a+28|0;a=0;do{mJb((c[k>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[p>>2]|0)>>>0);x=d+92|0;y=x;VHb(y);z=d+24|0;mJb(z);A=d+20|0;B=A;Zvb(B);i=b;return}function ck(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[c[a+16>>2]>>2]|0;d=a+32|0;e=c[c[d>>2]>>2]|0;do{if((c[(c[a+44>>2]|0)+32>>2]|0)==0){f=e}else{g=Ok(686752)|0;if((g|0)==0){h=-12;return h|0}else{Yk(g,e+64|0);f=c[(c[d>>2]|0)+4>>2]|0;break}}}while(0);d=Ok(684208)|0;if((d|0)==0){h=-12;return h|0}Yk(d,b+68|0);Yk(d,f+64|0);d=Vk()|0;if((d|0)==0){h=-12;return h|0}Xk(d,b+84|0);Xk(d,f+80|0);d=Ok(686952)|0;if((d|0)==0){h=-12;return h|0}Yk(d,b+76|0);Yk(d,f+72|0);h=0;return h|0}function dk(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;d=i;e=c[b>>2]|0;f=c[e+44>>2]|0;g=f+36|0;h=c[g>>2]|0;j=f+40|0;k=c[j>>2]|0;if((h|0)<640|(k|0)<480){KIb(e,16,2532808,(l=i,i=i+16|0,c[l>>2]=h,c[l+8>>2]=k,l)|0);i=l;m=-22;i=d;return m|0}k=b+20|0;c[k>>2]=h;h=b+24|0;c[h>>2]=c[j>>2];c[f+44>>2]=8;c[f+48>>2]=40;c[f+52>>2]=24;e=(c[j>>2]|0)-48|0;c[f+56>>2]=e;n=f+84|0;c[n>>2]=20;o=f+88|0;c[o>>2]=e;p=c[g>>2]|0;g=f+76|0;c[g>>2]=p-28;q=f+80|0;c[q>>2]=40;r=f+60|0;c[r>>2]=40;s=f+64|0;c[s>>2]=40;t=f+68|0;c[t>>2]=p-76;p=f+72|0;c[p>>2]=e;e=f+92|0;VHb(e);u=bv(b,c[k>>2]|0,c[h>>2]|0)|0;c[e>>2]=u;if((u|0)==0){m=-12;i=d;return m|0}c[b+28>>2]=1;c[b+32>>2]=1;e=qJb((c[p>>2]|0)+1|0,4)|0;h=f+108|0;c[h>>2]=e;if((e|0)==0){m=-12;i=d;return m|0}e=u|0;k=u+32|0;mrc(c[e>>2]|0,0,ca(c[k>>2]|0,c[j>>2]|0)|0)|0;fk(u,8,24,0,1211835,2479368,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=f+96|0;v=c[j>>2]|0;w=f+100|0;if((v|0)<(-v<<1|0)){x=v}else{y=v;z=v;while(1){A=+(y|0)+ +(z<<1|0);v=c[w>>2]|0;B=+(v|0);if(A<0.0){C=0.0}else{C=A>B?B:A}A=+(v|0);v=~~((A-C)*+(c[p>>2]|0)/A);if((y|0)<10){D=(((y|0)>-10)<<3)+8|0}else{D=8}c[(c[h>>2]|0)+(v<<2)>>2]=y;if((y|0)<0){E=45}else{E=(y|0)>0?43:32}fk(u,D,v-4+(c[s>>2]|0)|0,0,1211835,2469584,(l=i,i=i+16|0,c[l>>2]=E,c[l+8>>2]=(y|0)>-1?y:-y|0,l)|0);i=l;v=y-1|0;F=c[j>>2]|0;if((v|0)<(-F<<1|0)){x=F;break}else{y=v;z=F}}}C=+(x<<1|0);x=c[w>>2]|0;A=+(x|0);if(C<0.0){G=0.0}else{G=C>A?A:C}C=+(x|0);x=c[p>>2]|0;w=~~((C-G)*+(x|0)/C);z=f+104|0;c[z>>2]=w;a:do{if((x|0)>0){f=c[k>>2]|0;y=((c[r>>2]|0)*3|0)+(ca(f,c[s>>2]|0)|0)|0;j=(c[e>>2]|0)+y|0;y=0;l=f;f=x;E=w;while(1){if((c[(c[h>>2]|0)+(y<<2)>>2]|0)==0){H=((E|0)==(y|0))<<2}else{H=4}D=1146960+(((E|0)<(y|0)|H)*3|0)|0;u=c[t>>2]|0;if((u|0)>0){F=0;do{v=j+(F*3|0)|0;a[v]=a[D]|0;a[v+1|0]=a[D+1|0]|0;a[v+2|0]=a[D+2|0]|0;F=F+1|0;I=c[t>>2]|0;}while((F|0)<(I|0));J=c[k>>2]|0;K=c[p>>2]|0;L=I}else{J=l;K=f;L=u}F=y+1|0;if((F|0)>=(K|0)){M=L;break a}j=j+J|0;y=F;l=J;f=K;E=c[z>>2]|0}}else{M=c[t>>2]|0}}while(0);do{if((M|0)>0){z=0;K=(c[e>>2]|0)+(((c[r>>2]|0)*3|0)+(ca((c[s>>2]|0)-1|0,c[k>>2]|0)|0))|0;while(1){a[K]=a[2460416]|0;a[K+1|0]=a[2460417]|0;a[K+2|0]=a[2460418]|0;J=z+1|0;if((J|0)<(M|0)){z=J;K=K+3|0}else{break}}K=c[t>>2]|0;if((K|0)<=0){break}z=0;J=(c[e>>2]|0)+(((c[r>>2]|0)*3|0)+(ca((c[s>>2]|0)+(c[p>>2]|0)|0,c[k>>2]|0)|0))|0;while(1){a[J]=a[2460416]|0;a[J+1|0]=a[2460417]|0;a[J+2|0]=a[2460418]|0;L=z+1|0;if((L|0)<(K|0)){z=L;J=J+3|0}else{break}}}}while(0);M=c[p>>2]|0;J=c[k>>2]|0;do{if((M|0)>0){z=0;K=(c[e>>2]|0)+(((c[r>>2]|0)*3|0)-3+(ca(c[s>>2]|0,J)|0))|0;while(1){a[K]=a[2460416]|0;a[K+1|0]=a[2460417]|0;a[K+2|0]=a[2460418]|0;L=z+1|0;if((L|0)<(M|0)){z=L;K=K+J|0}else{break}}K=c[p>>2]|0;z=c[k>>2]|0;if((K|0)<=0){break}L=0;I=(c[e>>2]|0)+((ca(c[s>>2]|0,z)|0)+(((c[r>>2]|0)+(c[t>>2]|0)|0)*3|0))|0;while(1){a[I]=a[2460416]|0;a[I+1|0]=a[2460417]|0;a[I+2|0]=a[2460418]|0;H=L+1|0;if((H|0)<(K|0)){L=H;I=I+z|0}else{break}}}}while(0);t=c[n>>2]|0;do{if((t|0)>0){r=0;s=(c[e>>2]|0)+(((c[g>>2]|0)*3|0)+(ca((c[q>>2]|0)-1|0,c[k>>2]|0)|0))|0;while(1){a[s]=a[2460416]|0;a[s+1|0]=a[2460417]|0;a[s+2|0]=a[2460418]|0;p=r+1|0;if((p|0)<(t|0)){r=p;s=s+3|0}else{break}}s=c[n>>2]|0;r=c[o>>2]|0;if((s|0)<=0){N=r;break}p=0;J=(c[e>>2]|0)+(((c[g>>2]|0)*3|0)+(ca((c[q>>2]|0)+r|0,c[k>>2]|0)|0))|0;while(1){a[J]=a[2460416]|0;a[J+1|0]=a[2460417]|0;a[J+2|0]=a[2460418]|0;r=p+1|0;if((r|0)<(s|0)){p=r;J=J+3|0}else{break}}N=c[o>>2]|0}else{N=c[o>>2]|0}}while(0);t=c[k>>2]|0;do{if((N|0)>0){J=0;p=(c[e>>2]|0)+(((c[g>>2]|0)*3|0)-3+(ca(c[q>>2]|0,t)|0))|0;while(1){a[p]=a[2460416]|0;a[p+1|0]=a[2460417]|0;a[p+2|0]=a[2460418]|0;s=J+1|0;if((s|0)<(N|0)){J=s;p=p+t|0}else{break}}p=c[o>>2]|0;J=c[k>>2]|0;if((p|0)<=0){break}s=0;r=(c[e>>2]|0)+((ca(c[q>>2]|0,J)|0)+(((c[g>>2]|0)+(c[n>>2]|0)|0)*3|0))|0;while(1){a[r]=a[2460416]|0;a[r+1|0]=a[2460417]|0;a[r+2|0]=a[2460418]|0;M=s+1|0;if((M|0)<(p|0)){s=M;r=r+J|0}else{break}}}}while(0);n=b+156|0;c[n>>2]=c[n>>2]|1;m=0;i=d;return m|0}function ek(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0;b=c[(c[a>>2]|0)+44>>2]|0;d=a+40|0;e=rGb(c[d>>2]|0,c[d+4>>2]|0)|0;c[b+112>>2]=e;f=qJb(e,8)|0;g=b+116|0;c[g>>2]=f;if((f|0)==0){i=-12;return i|0}a:do{if((e|0)>0){f=b+4664|0;j=b+5456|0;k=0;l=0;while(1){m=c[d>>2]|0;n=c[d+4>>2]|0;o=k;while(1){p=yrc(1,0,o|0)|0;q=G;r=o+1|0;if((p&m|0)==0&(q&n|0)==0&(o|0)<63){o=r}else{break}}if((o|0)==3|(o|0)==35){h[(c[g>>2]|0)+(l<<3)>>3]=0.0}else{if((p&231216|0)==0&(q&6|0)==0){s=1.0}else{s=1.41}h[(c[g>>2]|0)+(l<<3)>>3]=s;n=f+(l<<2)|0;c[n>>2]=qJb(19200,8)|0;m=qJb(144e3,8)|0;c[j+(l<<2)>>2]=m;if((c[n>>2]|0)==0|(m|0)==0){i=-12;break}}m=l+1|0;if((m|0)<(e|0)){k=r;l=m}else{break a}}return i|0}}while(0);r=a+156|0;c[r>>2]=c[r>>2]|1;r=b+4|0;g=c[r>>2]|0;do{if((g&4|0)==0){t=g}else{q=b+24|0;c[q>>2]=hJb(e*153600|0)|0;p=b+8|0;c[p>>2]=qJb(e,8)|0;l=b+16|0;c[l>>2]=qJb(e,8)|0;k=Xvb()|0;j=b+20|0;c[j>>2]=k;if((c[q>>2]|0)==0){i=-12;return i|0}if((c[p>>2]|0)==0){i=-12;return i|0}if((c[l>>2]|0)==0|(k|0)==0){i=-12;return i|0}IJb(k,2123464,c[d>>2]|0,c[d+4>>2]|0,0)|0;k=c[a+48>>2]|0;IJb(c[j>>2]|0,2641040,k,(k|0)<0|0?-1:0,0)|0;k=a+52|0;LJb(c[j>>2]|0,2618288,c[k>>2]|0,0)|0;IJb(c[j>>2]|0,2591008,c[d>>2]|0,c[d+4>>2]|0,0)|0;IJb(c[j>>2]|0,2569096,192e3,0,0)|0;LJb(c[j>>2]|0,2551080,c[k>>2]|0,0)|0;k=$vb(c[j>>2]|0)|0;if((k|0)<0){i=k;return i|0}else{t=c[r>>2]|0;break}}}while(0);do{if((t&2|0)!=0){r=qJb(e,8)|0;c[b+12>>2]=r;if((r|0)==0){i=-12}else{break}return i|0}}while(0);i=0;return i|0}function fk(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=i;i=i+144|0;l=k|0;m=k+128|0;n=l|0;mrc(n|0,0,128)|0;if((f|0)==1){o=16;p=1961016}else if((f|0)==0){o=8;p=1965880}else{i=k;return}f=m;c[f>>2]=j;c[f+4>>2]=0;Ad(n|0,128,h|0,m|0)|0;m=a[n]|0;if(m<<24>>24==0){i=k;return}h=b|0;f=b+32|0;b=0;j=n;n=c[f>>2]|0;q=m;while(1){m=0;r=(c[h>>2]|0)+((ca(n,e)|0)+(((b<<3)+d|0)*3|0))|0;s=q;while(1){if((a[p+((ca(s<<24>>24,o)|0)+m)|0]|0)>-1){mrc(r|0,0,3)|0}else{a[r]=a[g]|0;a[r+1|0]=a[g+1|0]|0;a[r+2|0]=a[g+2|0]|0}t=r+3|0;if((a[p+((ca(a[j]|0,o)|0)+m)|0]&64)==0){mrc(t|0,0,3)|0}else{a[t]=a[g]|0;a[t+1|0]=a[g+1|0]|0;a[t+2|0]=a[g+2|0]|0}t=r+6|0;if((a[p+((ca(a[j]|0,o)|0)+m)|0]&32)==0){mrc(t|0,0,3)|0}else{a[t]=a[g]|0;a[t+1|0]=a[g+1|0]|0;a[t+2|0]=a[g+2|0]|0}t=r+9|0;if((a[p+((ca(a[j]|0,o)|0)+m)|0]&16)==0){mrc(t|0,0,3)|0}else{a[t]=a[g]|0;a[t+1|0]=a[g+1|0]|0;a[t+2|0]=a[g+2|0]|0}t=r+12|0;if((a[p+((ca(a[j]|0,o)|0)+m)|0]&8)==0){mrc(t|0,0,3)|0}else{a[t]=a[g]|0;a[t+1|0]=a[g+1|0]|0;a[t+2|0]=a[g+2|0]|0}t=r+15|0;if((a[p+((ca(a[j]|0,o)|0)+m)|0]&4)==0){mrc(t|0,0,3)|0}else{a[t]=a[g]|0;a[t+1|0]=a[g+1|0]|0;a[t+2|0]=a[g+2|0]|0}t=r+18|0;if((a[p+((ca(a[j]|0,o)|0)+m)|0]&2)==0){mrc(t|0,0,3)|0}else{a[t]=a[g]|0;a[t+1|0]=a[g+1|0]|0;a[t+2|0]=a[g+2|0]|0}t=r+21|0;if((a[p+((ca(a[j]|0,o)|0)+m)|0]&1)==0){mrc(t|0,0,3)|0}else{a[t]=a[g]|0;a[t+1|0]=a[g+1|0]|0;a[t+2|0]=a[g+2|0]|0}u=c[f>>2]|0;t=m+1|0;if((t|0)>=(o|0)){break}m=t;r=r+u|0;s=a[j]|0}s=b+1|0;r=l+s|0;m=a[r]|0;if(m<<24>>24==0){break}else{b=s;j=r;n=u;q=m}}i=k;return}function gk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,H=0.0,I=0,J=0.0,K=0,L=0.0,M=0.0,N=0.0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0.0,Qa=0,Ra=0.0,Sa=0,Ta=0,Ua=0,Va=0.0,Wa=0.0,Xa=0.0,Ya=0.0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0.0,gb=0.0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0;e=i;i=i+296|0;f=e|0;g=e+8|0;j=e+136|0;k=e+200|0;l=e+264|0;m=c[b+8>>2]|0;n=c[m+44>>2]|0;o=c[n+112>>2]|0;p=c[d+76>>2]|0;q=d|0;r=c[q>>2]|0;s=c[n+92>>2]|0;t=n+4|0;do{if((c[t>>2]&4|0)!=0){u=n+24|0;v=c[u>>2]|0;w=bwb(c[n+20>>2]|0,u,19200,q,p)|0;if((w|0)<0){x=w;i=e;return x|0}u=(o|0)>0;if(u){mrc(c[n+16>>2]|0,0,o<<3|0)|0}if((w|0)<=0){break}y=n+8|0;z=n+16|0;if(u){A=v;B=0}else{break}while(1){v=c[y>>2]|0;u=c[z>>2]|0;C=A;D=0;while(1){E=v+(D<<3)|0;F=+h[E>>3];H=+h[C>>3];I=H<0.0;if(I){J=-0.0-H}else{J=H}K=F>J;if(K|I^1){L=K?F:H}else{L=-0.0-H}h[E>>3]=L;E=u+(D<<3)|0;H=+h[E>>3];F=+h[C>>3];K=F<0.0;if(K){M=-0.0-F}else{M=F}I=H>M;if(I|K^1){N=I?H:F}else{N=-0.0-F}h[E>>3]=N;E=D+1|0;if((E|0)<(o|0)){C=C+8|0;D=E}else{break}}D=B+1|0;if((D|0)<(w|0)){A=A+(o<<3)|0;B=D}else{break}}}}while(0);a:do{if((p|0)>0){B=n+4916|0;A=n+5708|0;q=n+5424|0;w=n+6216|0;z=(o|0)>0;y=n+120|0;D=m+32|0;C=d+136|0;u=f|0;v=f+4|0;E=b+48|0;I=n+32|0;K=n+6284|0;O=m;P=n+6280|0;Q=l|0;R=n+6248|0;S=n+6256|0;T=n+8|0;U=n+16|0;V=n+12|0;W=g|0;X=d+440|0;Y=n+6264|0;Z=n+6272|0;_=k|0;$=j|0;aa=n+96|0;ba=n+100|0;da=n+72|0;ea=s|0;fa=n+64|0;ga=s+32|0;ha=n+60|0;ia=n+80|0;ja=n+76|0;ka=n+88|0;la=s+136|0;ma=n+104|0;na=n+108|0;oa=n+84|0;pa=n+68|0;qa=n+6244|0;ra=n+6232|0;sa=n+6240|0;ta=n+6224|0;ua=n+5452|0;va=n+5440|0;wa=n+5448|0;xa=n+5432|0;ya=n+116|0;za=n+5712|0;Aa=n+4920|0;Ba=n+128|0;Ca=Ba;Da=n+1640|0;Ea=Ba;Ba=n+3152|0;Fa=n+4664|0;Ga=n+5456|0;Ha=r;Ia=0;while(1){Ja=c[B>>2]|0;Ka=c[A>>2]|0;La=Ja+1|0;c[B>>2]=La;if((La|0)==19200){c[q>>2]=1;c[B>>2]=0}La=Ka+1|0;c[A>>2]=La;if((La|0)==144e3){c[w>>2]=1;c[A>>2]=0}if(z){La=Ha;Ma=0;while(1){if((c[t>>2]&2|0)!=0){Na=(c[V>>2]|0)+(Ma<<3)|0;N=+h[Na>>3];M=+h[La>>3];Oa=M<0.0;if(Oa){Pa=-0.0-M}else{Pa=M}Qa=N>Pa;if(Qa|Oa^1){Ra=Qa?N:M}else{Ra=-0.0-M}h[Na>>3]=Ra}M=+h[La>>3];Na=Ma*3|0;h[Ca+(Na<<3)>>3]=M;if(+h[(c[ya>>2]|0)+(Ma<<3)>>3]!=0.0){Qa=Da+(Na<<3)|0;Oa=Na+1|0;Sa=Da+(Oa<<3)|0;N=+h[Sa>>3];Ta=Na+2|0;h[Da+(Ta<<3)>>3]=N;L=+h[Qa>>3];h[Sa>>3]=L;J=+h[Ea+(Oa<<3)>>3];F=M*1.53512485958697+J*-2.69169618940638+ +h[Ea+(Ta<<3)>>3]*1.19839281085285-L*-1.69065929318241-N*.73248077421585;h[Qa>>3]=F;h[Ca+(Ta<<3)>>3]=J;h[Ca+(Oa<<3)>>3]=M;Qa=Ba+(Na<<3)|0;Na=Ba+(Oa<<3)|0;M=+h[Na>>3];h[Ba+(Ta<<3)>>3]=M;J=+h[Qa>>3];h[Na>>3]=J;H=N+(F+L*-2.0)-J*-1.99004745483398-M*.99007225036621;h[Qa>>3]=H;M=H*H;Qa=Aa+(Ma<<3)|0;Na=Fa+(Ma<<2)|0;h[Qa>>3]=+h[Qa>>3]+M- +h[(c[Na>>2]|0)+(Ja<<3)>>3];Qa=za+(Ma<<3)|0;Ta=Ga+(Ma<<2)|0;h[Qa>>3]=M+ +h[Qa>>3]- +h[(c[Ta>>2]|0)+(Ka<<3)>>3];h[(c[Na>>2]|0)+(Ja<<3)>>3]=M;h[(c[Ta>>2]|0)+(Ka<<3)>>3]=M}Ta=Ma+1|0;if((Ta|0)<(o|0)){La=La+8|0;Ma=Ta}else{break}}Ua=Ha+(o<<3)|0}else{Ua=Ha}Ma=(c[y>>2]|0)+1|0;c[y>>2]=Ma;if((Ma|0)==4800){Ma=c[c[D>>2]>>2]|0;La=c[C>>2]|0;Ka=c[C+4>>2]|0;c[u>>2]=1;c[v>>2]=c[E>>2];Ja=Ma+56|0;Ta=XIb(Ia,(Ia|0)<0|0?-1:0,f,Ja)|0;Na=wrc(Ta,G,La,Ka)|0;Ka=G;c[y>>2]=0;if((c[q>>2]|0)==0){Va=1.0e-12}else{if(z){La=c[ya>>2]|0;M=1.0e-12;Ta=0;while(1){H=M+ +h[La+(Ta<<3)>>3]*+h[Aa+(Ta<<3)>>3];Qa=Ta+1|0;if((Qa|0)<(o|0)){M=H;Ta=Qa}else{Wa=H;break}}}else{Wa=1.0e-12}Va=Wa/19200.0}M=+fd(+Va)*10.0+-.691;if((c[w>>2]|0)==0){Xa=1.0e-12}else{if(z){Ta=c[ya>>2]|0;H=1.0e-12;La=0;while(1){J=H+ +h[Ta+(La<<3)>>3]*+h[za+(La<<3)>>3];Qa=La+1|0;if((Qa|0)<(o|0)){H=J;La=Qa}else{Ya=J;break}}}else{Ya=1.0e-12}Xa=Ya/144.0e3}H=+fd(+Xa)*10.0+-.691;do{if(!(M<-70.0)){La=~~((M+70.0)*100.0);if((La|0)<0){Za=0}else{Za=(La|0)>8e3?8e3:La}La=(c[ua>>2]|0)+(Za*24|0)|0;c[La>>2]=(c[La>>2]|0)+1;J=Va+ +h[va>>3];h[va>>3]=J;La=(c[wa>>2]|0)+1|0;c[wa>>2]=La;L=J/+(La|0);J=+fd(+(L!=0.0?L:1.0e-12))*10.0+-.691+-10.0;h[xa>>3]=J;La=~~((J+70.0)*100.0);if((La|0)<0){_a=0}else{Ta=(La|0)>8e3?8e3:La;if((Ta|0)<8001){_a=Ta}else{break}}Ta=c[ua>>2]|0;J=0.0;La=0;Qa=_a;do{Oa=c[Ta+(Qa*24|0)>>2]|0;La=Oa+La|0;J=J+ +(Oa|0)*+h[Ta+(Qa*24|0)+8>>3];Qa=Qa+1|0;}while((Qa|0)<8001);if((La|0)==0){break}h[R>>3]=+fd(+(J/+(La|0)))*10.0+-.691}}while(0);do{if(!(H<-70.0)){Qa=~~((H+70.0)*100.0);if((Qa|0)<0){$a=0}else{$a=(Qa|0)>8e3?8e3:Qa}Qa=(c[qa>>2]|0)+($a*24|0)|0;c[Qa>>2]=(c[Qa>>2]|0)+1;L=Xa+ +h[ra>>3];h[ra>>3]=L;Qa=(c[sa>>2]|0)+1|0;c[sa>>2]=Qa;F=L/+(Qa|0);L=+fd(+(F!=0.0?F:1.0e-12))*10.0+-.691+-20.0;h[ta>>3]=L;Qa=~~((L+70.0)*100.0);if((Qa|0)<0){ab=0}else{Ta=(Qa|0)>8e3?8e3:Qa;if((Ta|0)<8001){ab=Ta}else{break}}Ta=c[qa>>2]|0;Qa=0;Oa=ab;do{Qa=(c[Ta+(Oa*24|0)>>2]|0)+Qa|0;Oa=Oa+1|0;}while((Oa|0)<8001);if((Qa|0)==0){break}Oa=~~(+(Qa*10|0|0)/100.0+.5);Ta=ab;La=0;while(1){if((Ta|0)>=8001){break}bb=c[qa>>2]|0;Sa=(c[bb+(Ta*24|0)>>2]|0)+La|0;if((Sa|0)<(Oa|0)){Ta=Ta+1|0;La=Sa}else{cb=67;break}}if((cb|0)==67){cb=0;h[Y>>3]=+h[bb+(Ta*24|0)+16>>3]}La=~~(+(Qa*95|0|0)/100.0+.5);Oa=8e3;Sa=Qa;while(1){if(!((Oa|0)>-1)){break}db=c[qa>>2]|0;eb=Sa-(c[db+(Oa*24|0)>>2]|0)|0;if((eb|0)<(La|0)){cb=71;break}else{Oa=Oa-1|0;Sa=eb}}if((cb|0)==71){cb=0;h[Z>>3]=+h[db+(Oa*24|0)+16>>3]}h[S>>3]=+h[Z>>3]- +h[Y>>3]}}while(0);if((c[I>>2]|0)!=0){J=+(c[aa>>2]<<1|0);L=H+23.0+J;Sa=c[ba>>2]|0;F=+(Sa|0);if(L<0.0){fb=0.0}else{fb=L>F?F:L}L=+(Sa|0);Sa=c[da>>2]|0;N=+(Sa|0);La=~~((L-fb)*N/L);gb=M+23.0+J;if(gb<0.0){hb=0.0}else{hb=gb>F?F:gb}Qa=~~((L-hb)*N/L);if((Sa|0)>0){Sa=((c[ha>>2]|0)*3|0)+(ca(c[ga>>2]|0,c[fa>>2]|0)|0)|0;Ta=0;eb=(c[ea>>2]|0)+Sa|0;while(1){Sa=c[ma>>2]|0;if((c[(c[na>>2]|0)+(Ta<<2)>>2]|0)==0){ib=((Sa|0)==(Ta|0))<<2}else{ib=4}jb=1146960+(((Sa|0)<(Ta|0)|((Ta|0)>=(La|0))<<1|ib)*3|0)|0;orc(eb|0,eb+3|0,((c[pa>>2]|0)*3|0)-3|0)|0;Sa=eb+(((c[pa>>2]|0)*3|0)-3)|0;a[Sa]=a[jb]|0;a[Sa+1|0]=a[jb+1|0]|0;a[Sa+2|0]=a[jb+2|0]|0;jb=Ta+1|0;if((jb|0)<(c[da>>2]|0)){Ta=jb;eb=eb+(c[ga>>2]|0)|0}else{break}}}eb=c[ka>>2]|0;b:do{if((eb|0)>0){Ta=c[ga>>2]|0;La=((c[ja>>2]|0)*3|0)+(ca(Ta,c[ia>>2]|0)|0)|0;jb=0;Sa=(c[ea>>2]|0)+La|0;La=Ta;Ta=eb;while(1){kb=c[ma>>2]|0;if((c[(c[na>>2]|0)+(jb<<2)>>2]|0)==0){lb=((kb|0)==(jb|0))<<2}else{lb=4}mb=1146960+(((kb|0)<(jb|0)|((jb|0)>=(Qa|0))<<1|lb)*3|0)|0;if((c[oa>>2]|0)>0){kb=0;do{nb=Sa+(kb*3|0)|0;a[nb]=a[mb]|0;a[nb+1|0]=a[mb+1|0]|0;a[nb+2|0]=a[mb+2|0]|0;kb=kb+1|0;}while((kb|0)<(c[oa>>2]|0));ob=c[ga>>2]|0;pb=c[ka>>2]|0}else{ob=La;pb=Ta}kb=jb+1|0;if((kb|0)>=(pb|0)){break b}jb=kb;Sa=Sa+ob|0;La=ob;Ta=pb}}}while(0);L=+h[R>>3];N=+h[S>>3];fk(s,8,4,1,1211832,2260592,(qb=i,i=i+32|0,h[qb>>3]=M,h[qb+8>>3]=H,h[qb+16>>3]=L,h[qb+24>>3]=N,qb)|0);i=qb;c[la>>2]=Na;c[la+4>>2]=Ka;Qa=lj(Ma,$Hb(s)|0)|0;if((Qa|0)<0){x=Qa;break}}do{if((c[K>>2]|0)!=0){Rb(W|0,128,2256192,(qb=i,i=i+8|0,h[qb>>3]=M,qb)|0)|0;i=qb;MGb(X,2251992,W,0)|0;Rb(W|0,128,2256192,(qb=i,i=i+8|0,h[qb>>3]=H,qb)|0)|0;i=qb;MGb(X,2241608,W,0)|0;Rb(W|0,128,2256192,(qb=i,i=i+8|0,h[qb>>3]=+h[R>>3],qb)|0)|0;i=qb;MGb(X,2235616,W,0)|0;Rb(W|0,128,2256192,(qb=i,i=i+8|0,h[qb>>3]=+h[S>>3],qb)|0)|0;i=qb;MGb(X,2232016,W,0)|0;Rb(W|0,128,2256192,(qb=i,i=i+8|0,h[qb>>3]=+h[Y>>3],qb)|0)|0;i=qb;MGb(X,2228144,W,0)|0;Rb(W|0,128,2256192,(qb=i,i=i+8|0,h[qb>>3]=+h[Z>>3],qb)|0)|0;i=qb;MGb(X,2223488,W,0)|0;Qa=c[t>>2]|0;if((Qa&2|0)==0|z^1){rb=Qa}else{Qa=0;do{Rb($|0,64,2219840,(qb=i,i=i+8|0,c[qb>>2]=Qa,qb)|0)|0;i=qb;Rb(W|0,128,2256192,(qb=i,i=i+8|0,h[qb>>3]=+h[(c[V>>2]|0)+(Qa<<3)>>3],qb)|0)|0;i=qb;MGb(X,$,W,0)|0;Qa=Qa+1|0;}while((Qa|0)<(o|0));rb=c[t>>2]|0}if((rb&4|0)==0|z^1){break}else{sb=0}do{Rb(_|0,64,2216872,(qb=i,i=i+8|0,c[qb>>2]=sb,qb)|0)|0;i=qb;Rb(W|0,128,2256192,(qb=i,i=i+8|0,h[qb>>3]=+h[(c[T>>2]|0)+(sb<<3)>>3],qb)|0)|0;i=qb;MGb(X,_,W,0)|0;sb=sb+1|0;}while((sb|0)<(o|0))}}while(0);Qa=c[P>>2]|0;mrc(Q|0,0,32)|0;a[Q]=0;if((Na|0)==0&(Ka|0)==(-2147483648|0)){Rb(Q|0,32,2190712,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0)|0;i=qb}else{Rb(Q|0,32,2188096,(qb=i,i=i+8|0,h[qb>>3]=(+(Na>>>0)+ +(Ka|0)*4294967296.0)*(+(c[Ja>>2]|0)/+(c[Ma+60>>2]|0)),qb)|0)|0;i=qb}N=+h[R>>3];L=+h[S>>3];KIb(O,Qa,2214104,(qb=i,i=i+40|0,c[qb>>2]=Q,h[qb+8>>3]=M,h[qb+16>>3]=H,h[qb+24>>3]=N,h[qb+32>>3]=L,qb)|0);i=qb;Qa=c[t>>2]|0;if((Qa&2|0)==0){tb=Qa}else{KIb(O,c[P>>2]|0,2211664,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;Qa=c[P>>2]|0;if(z){eb=0;Ta=Qa;while(1){L=+fd(+(+h[(c[V>>2]|0)+(eb<<3)>>3]))*20.0;KIb(O,Ta,2209016,(qb=i,i=i+8|0,h[qb>>3]=L,qb)|0);i=qb;La=eb+1|0;Sa=c[P>>2]|0;if((La|0)<(o|0)){eb=La;Ta=Sa}else{ub=Sa;break}}}else{ub=Qa}KIb(O,ub,2200536,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;tb=c[t>>2]|0}if((tb&4|0)==0){vb=tb}else{KIb(O,c[P>>2]|0,2195824,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;Ta=c[P>>2]|0;if(z){eb=0;Ma=Ta;while(1){H=+fd(+(+h[(c[U>>2]|0)+(eb<<3)>>3]))*20.0;KIb(O,Ma,2209016,(qb=i,i=i+8|0,h[qb>>3]=H,qb)|0);i=qb;Ja=eb+1|0;Ka=c[P>>2]|0;if((Ja|0)<(o|0)){eb=Ja;Ma=Ka}else{wb=Ka;break}}}else{wb=Ta}KIb(O,wb,2200536,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;vb=c[t>>2]|0}if((vb&4|0)!=0){KIb(O,c[P>>2]|0,2193232,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb;Ma=c[P>>2]|0;if(z){eb=0;Qa=Ma;while(1){H=+fd(+(+h[(c[T>>2]|0)+(eb<<3)>>3]))*20.0;KIb(O,Qa,2209016,(qb=i,i=i+8|0,h[qb>>3]=H,qb)|0);i=qb;Ka=eb+1|0;Ja=c[P>>2]|0;if((Ka|0)<(o|0)){eb=Ka;Qa=Ja}else{xb=Ja;break}}}else{xb=Ma}KIb(O,xb,2200536,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb}KIb(O,c[P>>2]|0,2249584,(qb=i,i=i+1|0,i=i+7&-8,c[qb>>2]=0,qb)|0);i=qb}Qa=Ia+1|0;if((Qa|0)<(p|0)){Ha=Ua;Ia=Qa}else{yb=I;zb=D;break a}}i=e;return x|0}else{yb=n+32|0;zb=m+32|0}}while(0);x=lj(c[(c[zb>>2]|0)+(c[yb>>2]<<2)>>2]|0,d)|0;i=e;return x|0}function hk(a){a=a|0;var b=0;b=c[(c[a+8>>2]|0)+44>>2]|0;do{if((c[b+6284>>2]|0)==0){if((c[b+4>>2]&4|0)!=0){break}return 0}}while(0);b=(c[a+48>>2]|0)/10|0;c[a+128>>2]=b;c[a+136>>2]=b;c[a+132>>2]=b;return 0}function ik(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=c[(c[a+4>>2]|0)+12>>2]|0;g=e+4|0;h=qJb(c[g>>2]|0,132)|0;c[e+8>>2]=h;if((h|0)==0){j=-12;i=b;return j|0}if((c[g>>2]|0)<=0){j=0;i=b;return j|0}h=d;e=d|0;k=f+4|0;f=d+4|0;l=d+36|0;m=d+20|0;n=a+24|0;o=a+12|0;p=a+16|0;q=a+20|0;a=d+24|0;r=0;while(1){mrc(h|0,0,60)|0;s=FFb(2568832,(t=i,i=i+8|0,c[t>>2]=r,t)|0)|0;i=t;c[e>>2]=s;if((s|0)==0){j=-12;u=10;break}c[f>>2]=c[k>>2];c[l>>2]=156;s=c[k>>2]|0;if((s|0)==0){c[m>>2]=218}else if((s|0)==1){c[a>>2]=1016}else{u=8;break}Qi(r,n,12,o,p,d)|0;c[q>>2]=c[n>>2];s=r+1|0;if((s|0)<(c[g>>2]|0)){r=s}else{j=0;u=10;break}}if((u|0)==8){KIb(0,0,2640640,(t=i,i=i+24|0,c[t>>2]=2550872,c[t+8>>2]=2532560,c[t+16>>2]=130,t)|0);i=t;Hd();return 0}else if((u|0)==10){i=b;return j|0}return 0}function jk(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;f=d|0;g=a+24|0;if((c[g>>2]|0)==0){i=d;return}h=(c[a+44>>2]|0)+8|0;j=a+12|0;a=0;do{k=c[h>>2]|0;l=k+(a*132|0)+130|0;m=b[l>>1]|0;if(!(m<<16>>16==0)){n=k+(a*132|0)+128|0;o=m;do{m=k+(a*132|0)+((e[n>>1]|0)<<2)|0;p=c[m>>2]|0;b[l>>1]=o-1;c[m>>2]=0;b[n>>1]=(b[n>>1]|0)+1&31;c[f>>2]=p;VHb(f);o=b[l>>1]|0;}while(!(o<<16>>16==0))}mJb((c[h>>2]|0)+(a*132|0)|0);mJb((c[j>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[g>>2]|0)>>>0);i=d;return}function kk(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[a>>2]|0;a=d+24|0;e=c[a>>2]|0;a:do{if((e|0)!=0){f=(c[d+44>>2]|0)+8|0;g=d+16|0;h=0;i=e;b:while(1){do{if((b[(c[f>>2]|0)+(h*132|0)+130>>1]|0)==0){j=c[(c[g>>2]|0)+(h<<2)>>2]|0;if((c[j+144>>2]|0)!=0){k=i;break}l=Wi(j)|0;if(!((l|0)==-541478725)){m=l;break b}k=c[a>>2]|0}else{k=i}}while(0);l=h+1|0;if(l>>>0<k>>>0){h=l;i=k}else{break a}}return m|0}}while(0);m=mk(d)|0;return m|0}function lk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;d=c[a>>2]|0;e=d+16|0;f=c[c[e>>2]>>2]|0;a:do{if((c[a+16>>2]|0)==0){c[a+56>>2]=1;c[a+60>>2]=1e6;g=c[f+20>>2]|0;c[a+20>>2]=g;h=c[f+24>>2]|0;c[a+24>>2]=h;j=f+28|0;k=a+28|0;l=c[j>>2]|0;m=c[j+4>>2]|0;c[k>>2]=l;c[k+4>>2]=m;c[a+52>>2]=c[f+52>>2];c[a+116>>2]=1;c[a+120>>2]=0;k=c[d+24>>2]|0;j=l;l=m;m=1;while(1){if(!(m>>>0<k>>>0)){break a}n=c[(c[e>>2]|0)+(m<<2)>>2]|0;o=c[n+20>>2]|0;p=c[n+24>>2]|0;if(!((g|0)==(o|0)&(h|0)==(p|0))){q=p;break}if((j|0)!=(c[n+28>>2]|0)){q=h;break}if((l|0)==(c[n+32>>2]|0)){m=m+1|0}else{q=h;break}}k=c[n+28>>2]|0;p=c[n+32>>2]|0;KIb(d,16,2146672,(r=i,i=i+72|0,c[r>>2]=c[(c[d+12>>2]|0)+(m*60|0)>>2],c[r+8>>2]=o,c[r+16>>2]=q,c[r+24>>2]=k,c[r+32>>2]=p,c[r+40>>2]=g,c[r+48>>2]=h,c[r+56>>2]=j,c[r+64>>2]=l,r)|0);i=r;s=-22;i=b;return s|0}}while(0);q=a+156|0;c[q>>2]=c[q>>2]|1;s=0;i=b;return s|0}function mk(a){a=a|0;var d=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0;d=i;f=c[a+44>>2]|0;g=c[a+24>>2]|0;if((g|0)==0){j=-541478725;i=d;return j|0}k=c[f+8>>2]|0;l=a+16|0;m=0;n=-1;o=2147483647;p=-1;while(1){if((b[k+(m*132|0)+130>>1]|0)==0){if((c[(c[(c[l>>2]|0)+(m<<2)>>2]|0)+144>>2]|0)==0){j=0;q=11;break}else{r=o;s=p;t=n}}else{u=(c[k+(m*132|0)+((b[k+(m*132|0)+128>>1]&31)<<2)>>2]|0)+136|0;v=c[u>>2]|0;w=c[u+4>>2]|0;u=(w|0)<(o|0)|(w|0)==(o|0)&v>>>0<p>>>0;r=u?w:o;s=u?v:p;t=u?m:n}u=m+1|0;if(u>>>0<g>>>0){m=u;n=t;o=r;p=s}else{break}}if((q|0)==11){i=d;return j|0}if((t|0)<0){j=-541478725;i=d;return j|0}q=c[f+8>>2]|0;f=q+(t*132|0)+128|0;s=q+(t*132|0)+130|0;p=b[s>>1]|0;if(p<<16>>16==0){KIb(0,0,2640640,(x=i,i=i+24|0,c[x>>2]=2617912,c[x+8>>2]=2590464,c[x+16>>2]=101,x)|0);i=x;Hd();return 0}r=q+(t*132|0)+(e[f>>1]<<2)|0;q=c[r>>2]|0;b[s>>1]=p-1;c[r>>2]=0;b[f>>1]=(b[f>>1]|0)+1&31;f=q+136|0;y=(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)*1.0e-6;KIb(a,48,2122944,(x=i,i=i+16|0,c[x>>2]=t,h[x+8>>3]=y,x)|0);i=x;j=lj(c[c[a+32>>2]>>2]|0,q)|0;i=d;return j|0}function nk(a,d){a=a|0;d=d|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;j=f+8|0;c[g>>2]=d;k=c[a+8>>2]|0;l=((c[a+12>>2]|0)-(c[k+12>>2]|0)|0)/60|0;m=d+136|0;d=c[m>>2]|0;n=c[m+4>>2]|0;if((d|0)==0&(n|0)==(-2147483648|0)){KIb(k,24,2517272,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;VHb(g);p=-1094995529;i=f;return p|0}m=c[k+44>>2]|0;c[j>>2]=1;c[j+4>>2]=1e6;q=XIb(d,n,a+56|0,j)|0;j=G;a=(c[g>>2]|0)+136|0;c[a>>2]=q;c[a+4>>2]=j;a=k;n=m+8|0;m=e[(c[n>>2]|0)+(l*132|0)+130>>1]|0;KIb(a,48,2503304,(o=i,i=i+24|0,h[o>>3]=(+(q>>>0)+ +(j|0)*4294967296.0)*1.0e-6,c[o+8>>2]=l,c[o+16>>2]=m,o)|0);i=o;m=c[n>>2]|0;n=c[g>>2]|0;g=m+(l*132|0)+130|0;j=b[g>>1]|0;if(j<<16>>16==32){KIb(a,24,2490128,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;o=m+(l*132|0)+128|0;a=e[o>>1]|0;q=(b[g>>1]|0)-1&65535;b[g>>1]=q;VHb(m+(l*132|0)+(((q&65535)+a&31)<<2)|0);r=b[g>>1]|0;s=o}else{r=j;s=m+(l*132|0)+128|0}j=e[s>>1]|0;b[g>>1]=r+1;c[m+(l*132|0)+((j+(r&65535)&31)<<2)>>2]=n;p=mk(k)|0;i=f;return p|0}function ok(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;if((c[d+272>>2]|0)!=4){i=b;return 0}e=d+264|0;f=c[e>>2]|0;if((f|0)==(-1|0)&(c[e+4>>2]|0)==(-1|0)){g=wKb()|0;c[e>>2]=g;c[e+4>>2]=0;h=g}else{h=f}KIb(a,32,2420664,(a=i,i=i+8|0,c[a>>2]=h,a)|0);i=a;AIb(d+4|0,h);i=b;return 0}function pk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=(bIb(b)|0)!=0;h=g&1;j=c[a+272>>2]|0;if((j|0)==1){k=0}else if((j|0)==3){k=h^1}else if((j|0)==4){l=a+4|0;m=a+260|0;a=c[m>>2]|0;c[l+((a&63)<<2)>>2]=(c[l+((a+9&63)<<2)>>2]|0)+(c[l+((a+40&63)<<2)>>2]|0);a=c[m>>2]|0;c[m>>2]=a+1;k=c[l+((a&63)<<2)>>2]&1}else if((j|0)==2){k=1}else{k=h}j=c[732280+(k<<2)>>2]|0;KIb(f,40,2479056,(a=i,i=i+24|0,c[a>>2]=c[732280+(h<<2)>>2],c[a+8>>2]=j,c[a+16>>2]=(h|0)==(k|0)?2469280:10230488,a)|0);i=a;do{if((k|0)==1&(g^1)){a=cIb(b)|0;if((a|0)<0){n=a}else{o=b;break}i=d;return n|0}else{if(!(g&(k|0)==0)){o=b;break}a=$Hb(b)|0;if((a|0)==0){n=-12}else{o=a;break}i=d;return n|0}}while(0);b=lj(c[c[f+32>>2]>>2]|0,o)|0;if(!(g&(k|0)==0)){n=b;i=d;return n|0}VHb(e);n=b;i=d;return n|0}function qk(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+44>>2]|0;e=uk(a)|0;if((e|0)<0){f=e;i=b;return f|0}if((c[d+312>>2]|0)==0){f=0;i=b;return f|0}KIb(a,16,2219728,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-22;i=b;return f|0}function rk(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;d=b+8|0;TGb(c[d>>2]|0);c[d>>2]=0;d=a+40|0;if((c[d>>2]|0)!=0){e=a+28|0;a=0;do{mJb((c[e>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0)}if((c[b+312>>2]|0)==0){return}VHb(b+1576|0);d=b+316|0;b=c[d>>2]|0;if((b|0)==0){return}r5a(b)|0;mJb(d);return}function sk(a){a=a|0;var b=0;b=uk(a)|0;return((b|0)<0?b:0)|0}function tk(a){a=a|0;var b=0;if((c[(c[a+44>>2]|0)+312>>2]|0)==0){b=el(a)|0;return b|0}else{dl(a,Ok(686736)|0);b=0;return b|0}return 0}function uk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=e+4|0;g=a;h=UGb(e+8|0,c[f>>2]|0,281984,0,0,0,0,0,g)|0;j=c[f>>2]|0;if((h|0)<0){KIb(g,16,2248056,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;l=h;i=b;return l|0}c[e+312>>2]=(Db(j|0,2205968)|0)!=0;j=d;h=e+1596|0;if((c[h>>2]|0)<=0){l=0;i=b;return l|0}e=d|0;g=a+4|0;f=d+4|0;m=d+44|0;n=a+40|0;o=a+28|0;p=a+32|0;q=a+36|0;a=0;while(1){mrc(j|0,0,60)|0;r=FFb(2173824,(k=i,i=i+8|0,c[k>>2]=a,k)|0)|0;i=k;c[e>>2]=r;if((r|0)==0){l=-12;s=7;break}c[f>>2]=c[(c[(c[g>>2]|0)+8>>2]|0)+4>>2];c[m>>2]=1120;Qi(a,n,4,o,p,d)|0;c[q>>2]=c[n>>2];r=a+1|0;if((r|0)<(c[h>>2]|0)){a=r}else{l=0;s=7;break}}if((s|0)==7){i=b;return l|0}return 0}function vk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;d=c[c[b+16>>2]>>2]|0;e=((c[a+4>>2]|0)-(c[b+28>>2]|0)|0)/60|0;a=(c[b+44>>2]|0)+1592|0;while(1){b=Wi(d)|0;if((b|0)<0){f=b;g=4;break}if((c[a>>2]|0)==(e|0)){f=0;g=4;break}}if((g|0)==4){return f|0}return 0}function wk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0.0,B=0,C=0.0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0.0,fa=0.0,ga=0,ha=0,ia=0,ja=0.0,ka=0.0,la=0;d=i;i=i+48|0;e=d|0;f=d+40|0;c[f>>2]=b;g=c[a+8>>2]|0;a=g+44|0;j=c[a>>2]|0;l=d+8|0;m=c[c[g+16>>2]>>2]|0;n=j+16|0;o=j+32|0;p=c[o+4>>2]&2147483647;q=2146435072;s=b+136|0;t=c[s>>2]|0;u=c[s+4>>2]|0;if(p>>>0>q>>>0|p>>>0==q>>>0&(c[o>>2]|0)>>>0>0>>>0){if((t|0)==0&(u|0)==(-2147483648|0)){v=+r}else{v=+(t>>>0)+ +(u|0)*4294967296.0}h[o>>3]=v}o=j+64|0;q=c[o+4>>2]&2147483647;p=2146435072;if(q>>>0>p>>>0|q>>>0==p>>>0&(c[o>>2]|0)>>>0>0>>>0){if((t|0)==0&(u|0)==(-2147483648|0)){w=+r}else{w=+(t>>>0)+ +(u|0)*4294967296.0}h[o>>3]=w*(+(c[m+56>>2]|0)/+(c[m+60>>2]|0))}o=m+160|0;p=j+264|0;h[p>>3]=+((c[o>>2]|0)>>>0)+ +(c[o+4>>2]|0)*4294967296.0;if((t|0)==0&(u|0)==(-2147483648|0)){o=j+24|0;h[o>>3]=+r;x=+r;y=o}else{w=+(t>>>0)+ +(u|0)*4294967296.0;u=j+24|0;h[u>>3]=w;x=w;y=u}u=j+56|0;h[u>>3]=x*(+(c[m+56>>2]|0)/+(c[m+60>>2]|0));t=DHb(b)|0;if((t|0)==(-1|0)&(G|0)==(-1|0)){z=+r}else{t=DHb(b)|0;z=+(t>>>0)+ +(G|0)*4294967296.0}h[j+296>>3]=z;t=m+16|0;o=c[t>>2]|0;do{if((o|0)==0){if((c[b+296>>2]|0)==0){A=0.0}else{A=(c[b+300>>2]|0)!=0?1.0:2.0}h[j+208>>3]=A;h[j+88>>3]=+((c[b+88>>2]|0)>>>0>>>0);if((c[j+312>>2]|0)==0){break}q=c[a>>2]|0;s=q+1576|0;B=c[s>>2]|0;c[e>>2]=B;do{if((B|0)==0){C=0.0}else{D=b+72|0;E=c[D>>2]|0;if((E|0)!=(c[B+72>>2]|0)){C=0.0;break}F=b+68|0;H=c[F>>2]|0;if((H|0)!=(c[B+68>>2]|0)){C=0.0;break}I=c[b+32>>2]|0;if((I|0)!=(c[B+32>>2]|0)){C=0.0;break}do{if((E-8|0)>0){J=I<<3;K=q+376|0;L=0;M=0;N=0;O=0;P=c[b>>2]|0;Q=c[B>>2]|0;S=H;T=E;while(1){if(((S*3|0)-8|0)>0){U=L;V=M;W=N;X=0;do{Y=Xe[c[K>>2]&511](q,P+X|0,Q+X|0,I,8)|0;W=wrc(Y,(Y|0)<0|0?-1:0,W,V)|0;V=G;U=U+64|0;X=X+8|0;Z=c[F>>2]|0;}while((X|0)<((Z*3|0)-8|0));_=U;$=V;aa=W;ca=Z;da=c[D>>2]|0}else{_=L;$=M;aa=N;ca=S;da=T}X=O+8|0;if((X|0)<(da-8|0)){L=_;M=$;N=aa;O=X;P=P+J|0;Q=Q+J|0;S=ca;T=da}else{break}}if((_|0)==0){ea=0.0;break}T=Crc(aa,$,_,(_|0)<0|0?-1:0)|0;ea=+(T>>>0)+ +(G|0)*4294967296.0}else{ea=0.0}}while(0);D=q+1568|0;z=+R(+(ea- +h[D>>3]));x=(ea>z?z:ea)/100.0;if(x<0.0){fa=0.0}else{fa=x>1.0?1.0:x}h[D>>3]=ea;VHb(e);C=fa}}while(0);c[s>>2]=$Hb(b)|0;h[j+304>>3]=C;Rb(l|0,32,2251856,(ga=i,i=i+8|0,h[ga>>3]=C,ga)|0)|0;i=ga;MGb(QHb(b)|0,2241472,l,0)|0}else if((o|0)==1){h[j+248>>3]=+(c[b+76>>2]|0)}}while(0);C=+XGb(c[j+8>>2]|0,n,0);n=j+1584|0;h[n>>3]=C;o=m+8|0;fa=+h[y>>3];ea=+h[u>>3];m=~~+h[j+288>>3];KIb(c[o>>2]|0,48,2235536,(ga=i,i=i+32|0,h[ga>>3]=+h[p>>3],h[ga+8>>3]=fa,h[ga+16>>3]=ea,c[ga+24>>2]=m,ga)|0);i=ga;m=c[t>>2]|0;if((m|0)==0){l=c[o>>2]|0;ea=+h[j+208>>3];do{if(ea==0.0){ha=80}else{if(ea==1.0){ha=84;break}ha=ea==2.0?66:63}}while(0);e=(BLb(~~+h[j+88>>3])|0)<<24>>24;ea=+h[j+304>>3];KIb(l,48,2231896,(ga=i,i=i+24|0,c[ga>>2]=ha,c[ga+8>>2]=e,h[ga+16>>3]=ea,ga)|0);i=ga}else if((m|0)==1){m=~~+h[j+240>>3];KIb(c[o>>2]|0,48,2228064,(ga=i,i=i+16|0,c[ga>>2]=~~+h[j+248>>3],c[ga+8>>2]=m,ga)|0);i=ga}do{if(C==0.0){c[j+1592>>2]=-1;ia=-1}else{h[k>>3]=C;m=c[k+4>>2]&2147483647;e=2146435072;if(m>>>0>e>>>0|m>>>0==e>>>0&(c[k>>2]|0)>>>0>0>>>0|C<0.0){c[j+1592>>2]=0;ia=0;break}else{ea=+ba(C)+-1.0;fa=+((c[j+1596>>2]|0)-1|0);e=~~(ea>fa?fa:ea);c[j+1592>>2]=e;ia=e;break}}}while(0);KIb(c[o>>2]|0,48,2223312,(ga=i,i=i+16|0,h[ga>>3]=C,c[ga+8>>2]=ia,ga)|0);i=ga;do{if(C!=0.0){h[j+280>>3]=+h[p>>3];ea=+h[y>>3];h[j+48>>3]=ea;fa=+h[u>>3];h[j+80>>3]=fa;ga=j+272|0;h[ga>>3]=+h[ga>>3]+1.0;if((c[t>>2]|0)!=1){ja=ea;ka=fa;break}ga=j+240|0;h[ga>>3]=+h[ga>>3]+ +(c[b+76>>2]|0);ja=ea;ka=fa}else{ja=+h[y>>3];ka=+h[u>>3]}}while(0);h[j+40>>3]=ja;h[j+72>>3]=ka;if(+h[n>>3]!=0.0){la=lj(c[(c[g+32>>2]|0)+(c[j+1592>>2]<<2)>>2]|0,c[f>>2]|0)|0;i=d;return la|0}else{VHb(f);la=0;i=d;return la|0}return 0}function xk(a){a=a|0;var b=0,d=0.0,e=0;b=c[(c[a+8>>2]|0)+44>>2]|0;mrc(b+264|0,0,16)|0;h[b+16>>3]=+(c[a+56>>2]|0)/+(c[a+60>>2]|0);h[b+40>>3]=+r;h[b+48>>3]=+r;h[b+80>>3]=+r;h[b+72>>3]=+r;h[b+32>>3]=+r;h[b+64>>3]=+r;h[b+96>>3]=1.0;h[b+104>>3]=2.0;h[b+112>>3]=3.0;h[b+128>>3]=5.0;h[b+136>>3]=6.0;h[b+144>>3]=7.0;h[b+152>>3]=1.0;h[b+160>>3]=2.0;h[b+168>>3]=3.0;h[b+184>>3]=5.0;h[b+192>>3]=6.0;h[b+200>>3]=7.0;h[b+216>>3]=0.0;h[b+224>>3]=1.0;h[b+232>>3]=2.0;h[b+88>>3]=+r;h[b+208>>3]=+r;h[b+304>>3]=+r;h[b+240>>3]=+r;h[b+248>>3]=+r;if((c[a+16>>2]|0)==1){d=+(c[a+48>>2]|0)}else{d=+r}h[b+256>>3]=d;if((c[b+312>>2]|0)==0){e=0;return e|0}a=mWa(0)|0;c[b+316>>2]=a;if((a|0)==0){e=-12;return e|0}Nba(b+320|0,a);e=0;return e|0}function yk(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0.0,na=0;d=i;i=i+2200|0;e=d|0;f=d+64|0;g=d+1088|0;j=d+1112|0;k=d+1120|0;l=d+1128|0;m=d+1160|0;n=d+1168|0;o=d+1176|0;p=c[b+44>>2]|0;q=c[p+12>>2]|0;r=p+16|0;s=c[r>>2]|0;do{if((q|0)==0){t=s}else{u=b;if((s|0)!=0){KIb(u,16,2516624,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=d;return w|0}x=lHb(q,m,n,0,u)|0;if((x|0)<0){w=x;i=d;return w|0}x=hJb((c[n>>2]|0)+1|0)|0;u=c[m>>2]|0;y=c[n>>2]|0;if((x|0)!=0){nrc(x|0,u|0,y)|0;a[x+y|0]=0;mHb(u,y);c[r>>2]=x;t=x;break}mHb(u,y);w=-12;i=d;return w|0}}while(0);r=p+4|0;n=p+8|0;p=b;b=l;c[k>>2]=t;c[r>>2]=0;c[n>>2]=0;m=l+16|0;q=l|0;s=l+8|0;y=l+20|0;u=l+24|0;l=g;x=e|0;e=g+16|0;z=g|0;A=g+4|0;B=g+8|0;C=g+12|0;g=A;D=B;E=C;F=f|0;a:do{if((a[t]|0)!=0){G=t;H=0;I=0;while(1){J=G;while(1){K=ud(J|0,2468944)|0;L=J+K|0;c[k>>2]=L;M=a[L]|0;if((M<<24>>24|0)==0){break a}else if((M<<24>>24|0)!=35){break}M=K+1|0;N=J+M|0;c[k>>2]=N;O=mc(N|0,2313040)|0;N=J+(O+M)|0;c[k>>2]=N;if((a[N]|0)==0){break a}N=J+(K+2+O)|0;c[k>>2]=N;if((a[N]|0)==0){break a}else{J=N}}N=J+((ud(L|0,2468944)|0)+K)|0;c[k>>2]=N;if((a[N]|0)==0){P=N}else{mrc(b|0,0,32)|0;c[m>>2]=H;N=GFb(k,2430688)|0;b:do{if((N|0)==0){Q=24}else{if((a[N]|0)==0){Q=24;break}O=HFb(N,2420440,j)|0;M=iKb(q,O,1)|0;if((M|0)<0){KIb(p,16,2411128,(v=i,i=i+16|0,c[v>>2]=O,c[v+8>>2]=H,v)|0);i=v;R=M;break}M=c[j>>2]|0;do{if((M|0)==0){c[s>>2]=-1;c[s+4>>2]=2147483647}else{S=iKb(s,M,1)|0;if((S|0)<0){KIb(p,16,2403424,(v=i,i=i+16|0,c[v>>2]=c[j>>2],c[v+8>>2]=H,v)|0);i=v;R=S;break b}S=c[s+4>>2]|0;T=c[q+4>>2]|0;if(!((S|0)<(T|0)|(S|0)==(T|0)&(c[s>>2]|0)>>>0<(c[q>>2]|0)>>>0)){break}KIb(p,16,2396456,(v=i,i=i+24|0,c[v>>2]=c[j>>2],c[v+8>>2]=H,c[v+16>>2]=O,v)|0);i=v;R=-22;break b}}while(0);c[y>>2]=0;c[u>>2]=0;O=c[k>>2]|0;if((a[O]|0)==0){R=0;break}else{U=0;V=0;W=O}c:while(1){mrc(l|0,0,16)|0;c[e>>2]=U;O=ud(W|0,2468944)|0;M=W+O|0;c[k>>2]=M;if((a[M]|0)==91){T=W+(O+1)|0;c[k>>2]=T;if((a[T]|0)==0){Q=38;break}else{X=T;Y=0}while(1){Z=mc(X|0,2354536)|0;if((krc(X,2568080,5)|0)==0){_=Y|1}else{if((krc(X,2549960,5)|0)!=0){Q=32;break c}_=Y|2}c[z>>2]=_;T=X+Z|0;c[k>>2]=T;$=a[T]|0;if($<<24>>24==93){break}if((ud(T|0,2339640)|0)==0){Q=35;break c}if($<<24>>24==0){Q=38;break c}T=X+(Z+1)|0;c[k>>2]=T;if((a[T]|0)==0){Q=38;break c}else{X=T;Y=_}}T=X+(Z+1)|0;c[k>>2]=T;aa=T}else{c[z>>2]=1;aa=M}c[k>>2]=aa+(ud(aa|0,2468944)|0);T=GFb(k,2430688)|0;c[A>>2]=T;if((T|0)==0){Q=43;break}if((a[T]|0)==0){Q=43;break}T=c[k>>2]|0;c[k>>2]=T+(ud(T|0,2468944)|0);T=GFb(k,2430688)|0;c[B>>2]=T;if((T|0)==0){Q=46;break}if((a[T]|0)==0){Q=46;break}T=c[k>>2]|0;c[k>>2]=T+(ud(T|0,2468944)|0);c[C>>2]=GFb(k,2430688)|0;ba=U+1|0;T=c[u>>2]|0;if((T|0)==(V|0)){O=V<<1;S=(O|0)<16?16:O;O=jJb(c[y>>2]|0,S,40)|0;ca=O;c[y>>2]=ca;if((O|0)==0){Q=52;break}da=S;ea=c[u>>2]|0;fa=ca}else{da=V;ea=T;fa=c[y>>2]|0}c[u>>2]=ea+1;T=fa+(ea*20|0)|0;c[T>>2]=c[l>>2];c[T+4>>2]=c[l+4>>2];c[T+8>>2]=c[l+8>>2];c[T+12>>2]=c[l+12>>2];c[T+16>>2]=c[l+16>>2];T=c[k>>2]|0;ca=ud(T|0,2468944)|0;S=T+ca|0;c[k>>2]=S;O=a[S]|0;if((O<<24>>24|0)==59|(O<<24>>24|0)==0){R=0;break b}else if((O<<24>>24|0)!=44){Q=54;break}O=T+(ca+1)|0;c[k>>2]=O;if((a[O]|0)==0){R=0;break b}else{U=ba;V=da;W=O}}if((Q|0)==32){Q=0;CFb(x,X,64)|0;KIb(p,16,2345656,(v=i,i=i+24|0,c[v>>2]=x,c[v+8>>2]=H,c[v+16>>2]=U,v)|0);i=v;R=-22;break}else if((Q|0)==35){Q=0;KIb(p,16,2333904,(v=i,i=i+24|0,c[v>>2]=$<<24>>24,c[v+8>>2]=H,c[v+16>>2]=U,v)|0);i=v;R=-22;break}else if((Q|0)==38){Q=0;KIb(p,16,2328552,(v=i,i=i+16|0,c[v>>2]=H,c[v+8>>2]=U,v)|0);i=v;R=-22;break}else if((Q|0)==43){Q=0;KIb(p,16,2322720,(v=i,i=i+16|0,c[v>>2]=H,c[v+8>>2]=U,v)|0);i=v}else if((Q|0)==46){Q=0;KIb(p,16,2317688,(v=i,i=i+16|0,c[v>>2]=H,c[v+8>>2]=U,v)|0);i=v}else if((Q|0)==52){Q=0;KIb(p,16,2382616,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;R=-12;break}else if((Q|0)==54){Q=0;KIb(p,16,2375920,(v=i,i=i+16|0,c[v>>2]=H,c[v+8>>2]=ba,v)|0);i=v;O=c[z>>2]|0;SFb(f,0,1);if((O&1|0)==0){ga=1}else{UFb(f,2531872,(v=i,i=i+8|0,c[v>>2]=2568080,v)|0);i=v;ga=0}if((O&2|0)!=0){if((ga|0)==0){WFb(f,43,1)}UFb(f,2531872,(v=i,i=i+8|0,c[v>>2]=2549960,v)|0);i=v}O=c[A>>2]|0;ca=c[B>>2]|0;T=c[C>>2]|0;KIb(p,16,2369264,(v=i,i=i+32|0,c[v>>2]=c[F>>2],c[v+8>>2]=O,c[v+16>>2]=ca,c[v+24>>2]=T,v)|0);i=v;R=-22;break}mJb(g);mJb(D);mJb(E);R=-22}}while(0);if((Q|0)==24){Q=0;KIb(p,16,2389576,(v=i,i=i+8|0,c[v>>2]=H,v)|0);i=v;R=-22}kJb(N);if((R|0)<0){w=R;Q=85;break}P=c[k>>2]|0}J=ud(P|0,2468944)|0;T=P+J|0;c[k>>2]=T;ca=a[T]|0;if((ca<<24>>24|0)==0){ha=T}else if((ca<<24>>24|0)==59){ca=P+(J+1)|0;c[k>>2]=ca;ha=ca}else{Q=65;break}ca=H+1|0;J=c[n>>2]|0;if((J|0)==(I|0)){T=I<<1;O=(T|0)<16?16:T;T=jJb(c[r>>2]|0,O,64)|0;S=T;c[r>>2]=S;if((T|0)==0){Q=71;break}ia=O;ja=c[n>>2]|0;ka=S;la=c[k>>2]|0}else{ia=I;ja=J;ka=c[r>>2]|0;la=ha}c[n>>2]=ja+1;J=ka+(ja<<5)|0;c[J>>2]=c[b>>2];c[J+4>>2]=c[b+4>>2];c[J+8>>2]=c[b+8>>2];c[J+12>>2]=c[b+12>>2];c[J+16>>2]=c[b+16>>2];c[J+20>>2]=c[b+20>>2];c[J+24>>2]=c[b+24>>2];c[J+28>>2]=c[b+28>>2];if((a[la]|0)==0){break a}else{G=la;H=ca;I=ia}}if((Q|0)==65){KIb(p,16,2459648,(v=i,i=i+8|0,c[v>>2]=H,v)|0);i=v;w=-22;i=d;return w|0}else if((Q|0)==71){KIb(p,16,2443016,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-12;i=d;return w|0}else if((Q|0)==85){i=d;return w|0}}}while(0);cd(c[r>>2]|0,c[n>>2]|0,32,510);KIb(p,48,2502664,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;if((c[n>>2]|0)<=0){w=0;i=d;return w|0}Q=o|0;ia=0;while(1){la=c[r>>2]|0;b=la+(ia<<5)|0;ja=la+(ia<<5)+8|0;ma=(+((c[ja>>2]|0)>>>0)+ +(c[ja+4>>2]|0)*4294967296.0)/1.0e6;ja=c[la+(ia<<5)+16>>2]|0;KIb(p,40,2489544,(v=i,i=i+24|0,h[v>>3]=(+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0)/1.0e6,h[v+8>>3]=ma,c[v+16>>2]=ja,v)|0);i=v;ja=la+(ia<<5)+24|0;if((c[ja>>2]|0)>0){b=la+(ia<<5)+20|0;la=0;do{ka=c[b>>2]|0;ha=c[ka+(la*20|0)>>2]|0;SFb(o,0,1);if((ha&1|0)==0){na=1}else{UFb(o,2531872,(v=i,i=i+8|0,c[v>>2]=2568080,v)|0);i=v;na=0}if((ha&2|0)!=0){if((na|0)==0){WFb(o,43,1)}UFb(o,2531872,(v=i,i=i+8|0,c[v>>2]=2549960,v)|0);i=v}ha=c[ka+(la*20|0)+4>>2]|0;k=c[ka+(la*20|0)+8>>2]|0;P=c[ka+(la*20|0)+12>>2]|0;R=c[ka+(la*20|0)+16>>2]|0;KIb(p,40,2478600,(v=i,i=i+40|0,c[v>>2]=c[Q>>2],c[v+8>>2]=ha,c[v+16>>2]=k,c[v+24>>2]=P,c[v+32>>2]=R,v)|0);i=v;la=la+1|0;}while((la|0)<(c[ja>>2]|0))}ja=ia+1|0;if((ja|0)<(c[n>>2]|0)){ia=ja}else{w=0;break}}i=d;return w|0}function zk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+44>>2]|0;a=b+8|0;d=b+4|0;if((c[a>>2]|0)<=0){mJb(d);return}b=d;e=0;do{f=c[b>>2]|0;g=f+(e<<5)+24|0;h=f+(e<<5)+20|0;f=c[h>>2]|0;if((c[g>>2]|0)>0){i=0;j=f;while(1){kJb(c[j+(i*20|0)+4>>2]|0);kJb(c[j+(i*20|0)+8>>2]|0);kJb(c[j+(i*20|0)+12>>2]|0);k=i+1|0;l=c[h>>2]|0;if((k|0)<(c[g>>2]|0)){i=k;j=l}else{m=l;break}}}else{m=f}kJb(m);e=e+1|0;}while((e|0)<(c[a>>2]|0));mJb(d);return}function Ak(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+2120|0;f=e|0;g=e+8|0;j=e+1032|0;k=e+2056|0;l=b+8|0;m=c[l>>2]|0;n=c[m+44>>2]|0;o=d+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;do{if(!((p|0)==0&(q|0)==(-2147483648|0))){c[f>>2]=1;c[f+4>>2]=1e6;o=XIb(p,q,b+56|0,f)|0;r=G;s=n+8|0;if((c[s>>2]|0)<=0){break}t=n+4|0;u=m;v=g|0;w=(+(o>>>0)+ +(r|0)*4294967296.0)/1.0e6;x=b+100|0;y=j|0;z=k|0;A=0;do{B=c[t>>2]|0;C=B+(A<<5)|0;D=B+(A<<5)+28|0;E=C|0;F=c[E>>2]|0;H=c[E+4>>2]|0;do{if((c[D>>2]|0)==0){if((r|0)<(H|0)|(r|0)==(H|0)&o>>>0<F>>>0){break}E=B+(A<<5)+8|0;I=c[E+4>>2]|0;if(!((r|0)<(I|0)|(r|0)==(I|0)&o>>>0<(c[E>>2]|0)>>>0)){break}c[D>>2]=1;J=1;K=8}else{J=0;K=8}}while(0);a:do{if((K|0)==8){K=0;E=C|0;do{if((r|0)<(H|0)|(r|0)==(H|0)&o>>>0<F>>>0){K=10}else{I=B+(A<<5)+8|0;L=c[I+4>>2]|0;if(!((r|0)<(L|0)|(r|0)==(L|0)&o>>>0<(c[I>>2]|0)>>>0)){K=10;break}if((J|0)==0){break a}else{M=J}}}while(0);if((K|0)==10){K=0;c[D>>2]=0;M=J|2}SFb(g,0,1);if((M&1|0)==0){N=1}else{UFb(g,2531872,(O=i,i=i+8|0,c[O>>2]=2568080,O)|0);i=O;N=0}if((M&2|0)!=0){if((N|0)==0){WFb(g,43,1)}UFb(g,2531872,(O=i,i=i+8|0,c[O>>2]=2549960,O)|0);i=O}I=c[B+(A<<5)+16>>2]|0;P=(+((c[E>>2]|0)>>>0)+ +(c[E+4>>2]|0)*4294967296.0)/1.0e6;L=B+(A<<5)+8|0;Q=(+((c[L>>2]|0)>>>0)+ +(c[L+4>>2]|0)*4294967296.0)/1.0e6;KIb(u,40,2639712,(O=i,i=i+40|0,c[O>>2]=c[v>>2],c[O+8>>2]=I,h[O+16>>3]=P,h[O+24>>3]=Q,h[O+32>>3]=w,O)|0);i=O;I=B+(A<<5)+24|0;L=c[I>>2]|0;if((L|0)<=0){break}R=B+(A<<5)+20|0;S=0;T=L;while(1){L=c[R>>2]|0;if((c[L+(S*20|0)>>2]&M|0)==0){U=T}else{V=L+(S*20|0)+16|0;W=L+(S*20|0)+4|0;X=c[W>>2]|0;Y=L+(S*20|0)+8|0;Z=c[Y>>2]|0;_=L+(S*20|0)+12|0;L=c[_>>2]|0;KIb(u,40,2616952,(O=i,i=i+32|0,c[O>>2]=c[V>>2],c[O+8>>2]=X,c[O+16>>2]=Z,c[O+24>>2]=L,O)|0);i=O;L=yj(c[x>>2]|0,c[W>>2]|0,c[Y>>2]|0,c[_>>2]|0,y,1024,1)|0;_=c[V>>2]|0;mrc(z|0,0,64)|0;a[z]=0;RGb(L,z,64)|0;KIb(u,40,2589776,(O=i,i=i+24|0,c[O>>2]=_,c[O+8>>2]=z,c[O+16>>2]=y,O)|0);i=O;U=c[I>>2]|0}_=S+1|0;if((_|0)<(U|0)){S=_;T=U}else{break}}}}while(0);A=A+1|0;}while((A|0)<(c[s>>2]|0))}}while(0);if(!((c[b+16>>2]|0)>>>0<2>>>0)){$=-38;i=e;return $|0}$=lj(c[c[(c[l>>2]|0)+32>>2]>>2]|0,d)|0;i=e;return $|0}function Bk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a;e=b;f=xrc(c[d>>2]|0,c[d+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;e=G;d=0;if((e|0)>(d|0)|(e|0)==(d|0)&f>>>0>0>>>0){g=1;return g|0}((e|0)<0|0?-1:0)>>31|((e|0)<0|0?-1:0)<<1;f=e>>31|((e|0)<0|0?-1:0)<<1;if((f|0)!=0){g=f;return g|0}g=(c[a+16>>2]|0)-(c[b+16>>2]|0)|0;return g|0}function Ck(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a|0;g=c[f>>2]|0;j=c[g+44>>2]|0;k=c[c[g+16>>2]>>2]|0;l=j+8|0;h[l>>3]=1.0e-6;m=k+56|0;n=k+60|0;h[j+16>>3]=+(c[m>>2]|0)/+(c[n>>2]|0);h[j+24>>3]=+(c[k+48>>2]|0);c[a+20>>2]=c[k+20>>2];c[a+24>>2]=c[k+24>>2];k=j+4|0;j=ZGb(d,c[k>>2]|0,281968,l,0,0,0,0,0,0,0)|0;if((j|0)<0){KIb(g,16,2121648,(o=i,i=i+8|0,c[o>>2]=c[k>>2],o)|0);i=o;p=j;i=b;return p|0}AKb(e,+h[d>>3],2147483647);d=c[e>>2]|0;j=c[e+4>>2]|0;if((d|0)<1|(j|0)<1){KIb(g,16,2639144,(o=i,i=i+16|0,c[o>>2]=d,c[o+8>>2]=j,o)|0);i=o;p=-22;i=b;return p|0}else{c[a+56>>2]=d;c[a+60>>2]=j;a=c[n>>2]|0;KIb(c[f>>2]|0,40,2616528,(o=i,i=i+32|0,c[o>>2]=c[m>>2],c[o+8>>2]=a,c[o+16>>2]=d,c[o+24>>2]=j,o)|0);i=o;p=0;i=b;return p|0}return 0}function Dk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=c[a+8>>2]|0;f=c[c[e+32>>2]>>2]|0;g=a+56|0;h=f+56|0;j=g|0;k=c[j>>2]|0;l=a+60|0;a=c[l>>2]|0;m=h|0;n=c[m>>2]|0;o=f+60|0;p=c[o>>2]|0;q=Erc(p,(p|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;r=G;s=Erc(n,(n|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;do{if((q|0)==(s|0)&(r|0)==(G|0)){if(!((p|0)==0|(a|0)==0)){t=lj(f,b)|0;i=d;return t|0}if((k|0)==0|(n|0)==0){break}if((k>>31|0)!=(n>>31|0)){break}t=lj(f,b)|0;i=d;return t|0}}while(0);n=b+136|0;k=c[n>>2]|0;a=c[n+4>>2]|0;p=XIb(k,a,g,h)|0;h=G;c[n>>2]=p;c[n+4>>2]=h;n=c[l>>2]|0;l=c[m>>2]|0;m=c[o>>2]|0;KIb(e,48,2549576,(e=i,i=i+64|0,c[e>>2]=c[j>>2],c[e+8>>2]=n,c[e+16>>2]=k,c[e+24>>2]=a,c[e+32>>2]=l,c[e+40>>2]=m,c[e+48>>2]=p,c[e+56>>2]=h,e)|0);i=e;t=lj(f,b)|0;i=d;return t|0}function Ek(a){a=a|0;var b=0;b=c[a+44>>2]|0;c[b+8>>2]=b;return 0}function Fk(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=c[b+4>>2]|0;if((a|0)==0){d=b+12|0;e=d;VHb(e);return}else{f=a}while(1){a=c[f+4>>2]|0;VHb(f|0);kJb(f);if((a|0)==0){break}else{f=a}}d=b+12|0;e=d;VHb(e);return}function Gk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a|0;e=c[d>>2]|0;f=c[e+44>>2]|0;g=f+4|0;h=g;j=c[h>>2]|0;do{if((j|0)==0){k=Wi(c[c[e+16>>2]>>2]|0)|0;if((k|0)>=0){l=c[h>>2]|0;if((l|0)!=0){m=l;break}KIb(0,0,2246640,(l=i,i=i+24|0,c[l>>2]=2204936,c[l+8>>2]=2172752,c[l+16>>2]=240,l)|0);i=l;Hd();return 0}if(!((k|0)==-541478725)){n=k;i=b;return n|0}if((c[a+88>>2]|0)==0){n=-541478725;i=b;return n|0}n=Hk(c[d>>2]|0)|0;i=b;return n|0}else{m=j}}while(0);if((c[a+88>>2]|0)!=0){n=Hk(c[d>>2]|0)|0;i=b;return n|0}d=lj(a,c[m>>2]|0)|0;m=c[h>>2]|0;a=c[m+4>>2]|0;j=f+8|0;if((c[j>>2]|0)==(m|0)){c[j>>2]=f}mJb(g);c[h>>2]=a;n=d;i=b;return n|0}function Hk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+8|0;d=b|0;e=c[c[a+32>>2]>>2]|0;f=c[a+44>>2]|0;g=f+4|0;h=g;j=c[h>>2]|0;do{if((j|0)==0){c[d>>2]=0;k=4}else{l=c[j>>2]|0;c[d>>2]=l;if((l|0)==0){k=4;break}m=f+12|0;if((c[f+12>>2]|0)!=0){n=m;k=7;break}o=e+88|0;if((c[l+76>>2]|0)<(c[o>>2]|0)){p=o;q=m;k=22;break}if((RKb(c[l+80>>2]|0)|0)==0){r=1;k=11}else{s=l+352|0;t=rGb(c[s>>2]|0,c[s+4>>2]|0)|0;if((t|0)>0){r=t;k=11}}if((k|0)==11){t=c[l+64>>2]|0;l=128;s=0;do{u=c[t+(s<<2)>>2]|0;v=128;while(1){if(((u|0)%(v|0)|0|0)==0){break}else{v=v>>1}}l=(v|0)<(l|0)?v:l;s=s+1|0;}while((s|0)<(r|0));if((l|0)<=31){p=o;q=m;k=22;break}}s=c[d>>2]|0;if((c[s+76>>2]|0)==(c[o>>2]|0)){t=c[h>>2]|0;u=c[t+4>>2]|0;w=f+8|0;if((c[w>>2]|0)==(t|0)){c[w>>2]=f}mJb(g);c[h>>2]=u;x=s;break}else{u=$Hb(s)|0;if((u|0)==0){y=-12;i=b;return y|0}else{c[u+76>>2]=c[o>>2];Ik(e,c[d>>2]|0,c[o>>2]|0);x=u;break}}}}while(0);do{if((k|0)==4){if((c[f+12>>2]|0)==0){y=-541478725;i=b;return y|0}else{n=f+12|0;k=7;break}}}while(0);if((k|0)==7){p=e+88|0;q=n;k=22}if((k|0)==22){n=e+40|0;r=rGb(c[n>>2]|0,c[n+4>>2]|0)|0;n=c[q>>2]|0;j=c[p>>2]|0;do{if((n|0)==0){u=oi(e,j)|0;c[q>>2]=u;if((u|0)==0){y=-12;i=b;return y|0}else{c[u+76>>2]=0;s=(c[d>>2]|0)+136|0;w=c[s+4>>2]|0;t=u+136|0;c[t>>2]=c[s>>2];c[t+4>>2]=w;w=c[p>>2]|0;c[f+16>>2]=w;z=u;A=w;break}}else{if((j|0)==(c[f+16>>2]|0)){z=n;A=j;break}KIb(a,16,2145336,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;y=-22;i=b;return y|0}}while(0);j=f+16|0;a:do{if((c[z+76>>2]|0)<(A|0)){n=a+16|0;p=e+52|0;w=f+8|0;u=f;t=A;while(1){s=c[h>>2]|0;if((s|0)==0){C=Wi(c[c[n>>2]>>2]|0)|0;if((C|0)==-541478725){k=31;break}if((C|0)<0){y=C;k=44;break}C=c[h>>2]|0;if((C|0)==0){k=35;break}D=C;E=c[j>>2]|0}else{D=s;E=t}s=c[D>>2]|0;c[d>>2]=s;C=c[q>>2]|0;F=c[C+76>>2]|0;G=E-F|0;H=s+76|0;I=c[H>>2]|0;J=(G|0)>(I|0)?I:G;XKb(c[C+64>>2]|0,c[s+64>>2]|0,F,0,J,r,c[p>>2]|0)|0;F=(c[q>>2]|0)+76|0;c[F>>2]=(c[F>>2]|0)+J;if((J|0)==(c[H>>2]|0)){VHb(d);H=c[h>>2]|0;F=c[H+4>>2]|0;if((c[w>>2]|0)==(H|0)){c[w>>2]=u}mJb(g);c[h>>2]=F}else{Ik(e,s,J)}J=c[q>>2]|0;s=c[j>>2]|0;if((c[J+76>>2]|0)<(s|0)){t=s}else{K=J;break a}}if((k|0)==31){t=c[q>>2]|0;u=c[t+76>>2]|0;VKb(c[t+64>>2]|0,u,(c[j>>2]|0)-u|0,r,c[p>>2]|0)|0;u=c[q>>2]|0;c[u+76>>2]=c[j>>2];K=u;break}else if((k|0)==35){KIb(0,0,2246640,(B=i,i=i+24|0,c[B>>2]=2121568,c[B+8>>2]=2172752,c[B+16>>2]=204,B)|0);i=B;Hd();return 0}else if((k|0)==44){i=b;return y|0}}else{K=z}}while(0);c[q>>2]=0;x=K}y=lj(e,x)|0;i=b;return y|0}function Ik(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+8|0;f=e|0;g=a+40|0;h=rGb(c[g>>2]|0,c[g+4>>2]|0)|0;g=a+52|0;j=(RKb(c[g>>2]|0)|0)!=0;k=j?h:1;l=QKb(c[g>>2]|0)|0;g=ca(l,j?1:h)|0;h=b+76|0;j=c[h>>2]|0;if((j|0)<=(d|0)){KIb(0,0,2246640,(l=i,i=i+24|0,c[l>>2]=2639072,c[l+8>>2]=2172752,c[l+16>>2]=113,l)|0);i=l;Hd()}if((k|0)>0){l=ca(g,d)|0;m=b+64|0;n=0;while(1){o=(c[m>>2]|0)+(n<<2)|0;c[o>>2]=(c[o>>2]|0)+l;o=n+1|0;if((o|0)<(k|0)){n=o}else{p=m;break}}}else{p=b+64|0}m=c[p>>2]|0;if((b|0)==(m|0)){q=j}else{nrc(b|0,m|0,k>>>0>8>>>0?32:k<<2)|0;q=c[h>>2]|0}k=ca(g,d)|0;g=b+32|0;c[g>>2]=(c[g>>2]|0)-k;c[h>>2]=q-d;q=b+136|0;if((c[q>>2]|0)==0&(c[q+4>>2]|0)==(-2147483648|0)){i=e;return}c[f>>2]=1;c[f+4>>2]=c[a+48>>2];b=XIb(d,(d|0)<0|0?-1:0,f,a+56|0)|0;a=wrc(c[q>>2]|0,c[q+4>>2]|0,b,G)|0;c[q>>2]=a;c[q+4>>2]=G;i=e;return}function Jk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=c[(c[a+8>>2]|0)+44>>2]|0;a=pJb(8)|0;f=b+8|0;c[(c[f>>2]|0)+4>>2]=a;a=c[(c[f>>2]|0)+4>>2]|0;if((a|0)==0){VHb(e);g=-12;i=d;return g|0}else{c[f>>2]=a;c[a>>2]=c[e>>2];g=0;i=d;return g|0}return 0}function Kk(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;c[h>>2]=b;c[j>>2]=e;c[k>>2]=0;if((b|0)==(e|0)){l=b;i=g;return l|0}do{if((f|0)==0){if((c[b>>2]|0)==0){m=0;n=0;o=0;p=0;q=b;r=e;break}else{s=0;t=0;u=0;v=0;w=0;x=e;y=b}while(1){if((c[x>>2]|0)==0){z=s;A=t;B=u;C=v;D=x;E=y}else{F=s;G=t;H=u;I=v;J=0;K=c[(c[y+4>>2]|0)+(w<<2)>>2]|0;while(1){L=qKb(K)|0;M=qKb(c[(c[(c[j>>2]|0)+4>>2]|0)+(J<<2)>>2]|0)|0;N=a[L+7|0]|0;O=a[M+7|0]&N&128|H;P=(d[L+4|0]|0)>>>0>1>>>0;if(P){Q=(d[M+4|0]|0)>>>0>1>>>0|0}else{Q=0}M=Q|G;L=c[h>>2]|0;R=c[(c[L+4>>2]|0)+(w<<2)>>2]|0;S=c[j>>2]|0;if((R|0)==(c[(c[S+4>>2]|0)+(J<<2)>>2]|0)){T=N&128|I;U=P&1|F}else{T=I;U=F}P=J+1|0;if(P>>>0<(c[S>>2]|0)>>>0){F=U;G=M;H=O;I=T;J=P;K=R}else{z=U;A=M;B=O;C=T;D=S;E=L;break}}}K=w+1|0;if(K>>>0<(c[E>>2]|0)>>>0){s=z;t=A;u=B;v=C;w=K;x=D;y=E}else{m=C;n=B;o=A;p=z;q=E;r=D;break}}}else{m=0;n=0;o=0;p=0;q=b;r=e}}while(0);if((n|0)>(m|0)|(o|0)>(p|0)){l=0;i=g;return l|0}p=c[q>>2]|0;q=c[r>>2]|0;r=p>>>0>q>>>0?q:p;p=pJb(16)|0;q=p;c[k>>2]=q;a:do{if((p|0)==0){V=q}else{b:do{if((r|0)==0){W=q}else{o=hJb(r<<2)|0;c[(c[k>>2]|0)+4>>2]=o;do{if((o|0)!=0){m=c[h>>2]|0;n=m|0;e=c[n>>2]|0;if((e|0)==0){W=c[k>>2]|0;break b}b=c[j>>2]|0;D=b|0;E=m+4|0;z=c[k>>2]|0;A=z+4|0;B=c[D>>2]|0;C=0;y=0;x=B;w=e;e=B;c:while(1){if((x|0)==0){X=y;Y=0;Z=w;_=e}else{B=(c[E>>2]|0)+(C<<2)|0;v=c[b+4>>2]|0;u=0;t=y;s=x;T=e;while(1){U=c[B>>2]|0;if((U|0)==(c[v+(u<<2)>>2]|0)){Q=c[n>>2]|0;if(!(t>>>0<(Q>>>0>s>>>0?s:Q)>>>0)){$=23;break c}c[(c[A>>2]|0)+(t<<2)>>2]=U;aa=t+1|0;ba=c[D>>2]|0}else{aa=t;ba=T}U=u+1|0;if(U>>>0<ba>>>0){u=U;t=aa;s=ba;T=ba}else{break}}X=aa;Y=ba;Z=c[n>>2]|0;_=ba}T=C+1|0;if(T>>>0<Z>>>0){C=T;y=X;x=Y;w=Z;e=_}else{break}}if(($|0)==23){KIb(0,16,2523984,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;kJb(c[(c[k>>2]|0)+4>>2]|0);kJb(c[k>>2]|0);l=0;i=g;return l|0}c[z>>2]=X;if((X|0)==0){V=z;break a}e=iJb(c[z+12>>2]|0,(c[m+8>>2]|0)+(c[z+8>>2]|0)<<2)|0;if((e|0)==0){break}c[(c[k>>2]|0)+12>>2]=e;e=c[h>>2]|0;w=e+12|0;if((c[e+8>>2]|0)==0){ca=w;da=e}else{e=0;x=w;while(1){w=c[k>>2]|0;c[(c[w+12>>2]|0)+(c[w+8>>2]<<2)>>2]=c[(c[x>>2]|0)+(e<<2)>>2];w=c[k>>2]|0;y=w+8|0;C=c[y>>2]|0;c[y>>2]=C+1;c[c[(c[w+12>>2]|0)+(C<<2)>>2]>>2]=w;w=e+1|0;C=c[h>>2]|0;y=C+12|0;if(w>>>0<(c[C+8>>2]|0)>>>0){e=w;x=y}else{ca=y;da=C;break}}}mJb(ca);mJb(da+4|0);mJb(h);x=c[k>>2]|0;e=iJb(c[x+12>>2]|0,(c[(c[j>>2]|0)+8>>2]|0)+(c[x+8>>2]|0)<<2)|0;if((e|0)==0){break}c[(c[k>>2]|0)+12>>2]=e;e=c[j>>2]|0;x=e+12|0;if((c[e+8>>2]|0)==0){ea=x;fa=e}else{e=0;z=x;while(1){x=c[k>>2]|0;c[(c[x+12>>2]|0)+(c[x+8>>2]<<2)>>2]=c[(c[z>>2]|0)+(e<<2)>>2];x=c[k>>2]|0;m=x+8|0;C=c[m>>2]|0;c[m>>2]=C+1;c[c[(c[x+12>>2]|0)+(C<<2)>>2]>>2]=x;x=e+1|0;C=c[j>>2]|0;m=C+12|0;if(x>>>0<(c[C+8>>2]|0)>>>0){e=x;z=m}else{ea=m;fa=C;break}}}mJb(ea);mJb(fa+4|0);mJb(j);l=c[k>>2]|0;i=g;return l|0}}while(0);V=c[k>>2]|0;break a}}while(0);c[W>>2]=0;V=W}}while(0);if((V|0)!=0){mJb(V+12|0);mJb((c[k>>2]|0)+4|0)}mJb(k);l=0;i=g;return l|0}function Lk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[e>>2]=a;c[f>>2]=b;c[g>>2]=0;if((a|0)==(b|0)){h=a;i=d;return h|0}j=c[a>>2]|0;a:do{if((j|0)==0){k=iJb(c[b+12>>2]|0,(c[a+8>>2]|0)+(c[b+8>>2]|0)<<2)|0;if((k|0)==0){l=36;break}c[(c[f>>2]|0)+12>>2]=k;k=c[e>>2]|0;m=k+12|0;if((c[k+8>>2]|0)==0){n=m}else{k=0;o=m;while(1){m=c[f>>2]|0;c[(c[m+12>>2]|0)+(c[m+8>>2]<<2)>>2]=c[(c[o>>2]|0)+(k<<2)>>2];m=c[f>>2]|0;p=m+8|0;q=c[p>>2]|0;c[p>>2]=q+1;c[c[(c[m+12>>2]|0)+(q<<2)>>2]>>2]=m;m=k+1|0;q=c[e>>2]|0;p=q+12|0;if(m>>>0<(c[q+8>>2]|0)>>>0){k=m;o=p}else{n=p;break}}}mJb(n);mJb((c[e>>2]|0)+4|0);mJb(e);o=c[f>>2]|0;c[g>>2]=o;h=o;i=d;return h|0}else{o=c[b>>2]|0;if((o|0)==0){k=iJb(c[a+12>>2]|0,(c[b+8>>2]|0)+(c[a+8>>2]|0)<<2)|0;if((k|0)==0){l=36;break}c[(c[e>>2]|0)+12>>2]=k;k=c[f>>2]|0;p=k+12|0;if((c[k+8>>2]|0)==0){r=p}else{k=0;m=p;while(1){p=c[e>>2]|0;c[(c[p+12>>2]|0)+(c[p+8>>2]<<2)>>2]=c[(c[m>>2]|0)+(k<<2)>>2];p=c[e>>2]|0;q=p+8|0;s=c[q>>2]|0;c[q>>2]=s+1;c[c[(c[p+12>>2]|0)+(s<<2)>>2]>>2]=p;p=k+1|0;s=c[f>>2]|0;q=s+12|0;if(p>>>0<(c[s+8>>2]|0)>>>0){k=p;m=q}else{r=q;break}}}mJb(r);mJb((c[f>>2]|0)+4|0);mJb(f);m=c[e>>2]|0;c[g>>2]=m;h=m;i=d;return h|0}m=j>>>0>o>>>0?o:j;k=pJb(16)|0;q=k;c[g>>2]=q;if((k|0)==0){t=q;break}do{if((m|0)==0){u=q}else{k=hJb(m<<2)|0;c[(c[g>>2]|0)+4>>2]=k;if((k|0)==0){l=36;break a}k=c[e>>2]|0;p=k|0;s=c[p>>2]|0;if((s|0)==0){u=c[g>>2]|0;break}v=c[f>>2]|0;w=v|0;x=k+4|0;k=c[g>>2]|0;y=k+4|0;z=c[w>>2]|0;A=0;B=0;C=z;D=s;s=z;b:while(1){if((C|0)==0){E=A;F=0;G=D;H=s}else{z=(c[x>>2]|0)+(B<<2)|0;I=c[v+4>>2]|0;J=A;K=0;L=C;M=s;while(1){N=c[z>>2]|0;if((N|0)==(c[I+(K<<2)>>2]|0)){O=c[p>>2]|0;if(!(J>>>0<(O>>>0>L>>>0?L:O)>>>0)){l=14;break b}c[(c[y>>2]|0)+(J<<2)>>2]=N;P=J+1|0;Q=c[w>>2]|0}else{P=J;Q=M}N=K+1|0;if(N>>>0<Q>>>0){J=P;K=N;L=Q;M=Q}else{break}}E=P;F=Q;G=c[p>>2]|0;H=Q}M=B+1|0;if(M>>>0<G>>>0){A=E;B=M;C=F;D=G;s=H}else{break}}if((l|0)==14){KIb(0,16,2523984,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;kJb(c[(c[g>>2]|0)+4>>2]|0);kJb(c[g>>2]|0);h=0;i=d;return h|0}c[k>>2]=E;if((E|0)==0){t=k;break a}s=iJb(c[k+12>>2]|0,(c[(c[e>>2]|0)+8>>2]|0)+(c[k+8>>2]|0)<<2)|0;if((s|0)==0){l=36;break a}c[(c[g>>2]|0)+12>>2]=s;s=c[e>>2]|0;D=s+12|0;if((c[s+8>>2]|0)==0){R=D}else{s=0;C=D;while(1){D=c[g>>2]|0;c[(c[D+12>>2]|0)+(c[D+8>>2]<<2)>>2]=c[(c[C>>2]|0)+(s<<2)>>2];D=c[g>>2]|0;B=D+8|0;A=c[B>>2]|0;c[B>>2]=A+1;c[c[(c[D+12>>2]|0)+(A<<2)>>2]>>2]=D;D=s+1|0;A=c[e>>2]|0;B=A+12|0;if(D>>>0<(c[A+8>>2]|0)>>>0){s=D;C=B}else{R=B;break}}}mJb(R);mJb((c[e>>2]|0)+4|0);mJb(e);C=c[g>>2]|0;s=iJb(c[C+12>>2]|0,(c[(c[f>>2]|0)+8>>2]|0)+(c[C+8>>2]|0)<<2)|0;if((s|0)==0){l=36;break a}c[(c[g>>2]|0)+12>>2]=s;s=c[f>>2]|0;C=s+12|0;if((c[s+8>>2]|0)==0){S=C}else{s=0;k=C;while(1){C=c[g>>2]|0;c[(c[C+12>>2]|0)+(c[C+8>>2]<<2)>>2]=c[(c[k>>2]|0)+(s<<2)>>2];C=c[g>>2]|0;B=C+8|0;D=c[B>>2]|0;c[B>>2]=D+1;c[c[(c[C+12>>2]|0)+(D<<2)>>2]>>2]=C;C=s+1|0;D=c[f>>2]|0;B=D+12|0;if(C>>>0<(c[D+8>>2]|0)>>>0){s=C;k=B}else{S=B;break}}}mJb(S);mJb((c[f>>2]|0)+4|0);mJb(f);h=c[g>>2]|0;i=d;return h|0}}while(0);c[u>>2]=0;t=u}}while(0);if((l|0)==36){t=c[g>>2]|0}if((t|0)!=0){mJb(t+12|0);mJb((c[g>>2]|0)+4|0)}mJb(g);h=0;i=d;return h|0}function Mk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;c[f>>2]=b;c[g>>2]=d;c[h>>2]=0;j=(a[b+9|0]|0)+(a[b+8|0]|0)|0;k=(a[d+9|0]|0)+(a[d+8|0]|0)|0;if((d|0)==(b|0)){l=b;i=e;return l|0}if(j>>>0<k>>>0){c[g>>2]=b;c[f>>2]=d;m=k;n=j;o=b;p=d}else{m=j;n=k;o=d;p=b}do{if((m|0)==1){if((n|0)!=0){q=13;break}b=o+4|0;d=c[b>>2]|0;if((d|0)<=0){l=0;i=e;return l|0}k=c[o>>2]|0;j=0;r=0;while(1){s=k+(r<<3)|0;t=c[s>>2]|0;u=c[s+4>>2]|0;s=-1;if((u|0)>(s|0)|(u|0)==(s|0)&t>>>0>-1>>>0|(t&2147483647|0)==0&(u&0|0)==0){s=k+(j<<3)|0;c[s>>2]=t;c[s+4>>2]=u;v=j+1|0}else{v=j}u=r+1|0;if((u|0)<(d|0)){j=v;r=u}else{break}}if((v|0)==0){l=0;i=e;return l|0}else{c[b>>2]=v;q=13;break}}else if((m|0)==0){r=c[p+4>>2]|0;j=c[o+4>>2]|0;d=pJb(20)|0;k=d;c[h>>2]=k;if((d|0)==0){w=k;break}k=hJb(j+r<<3)|0;c[c[h>>2]>>2]=k;if((k|0)==0){q=54;break}k=c[f>>2]|0;r=c[k+4>>2]|0;j=(r|0)>0;do{if(j){d=c[g>>2]|0;u=d+4|0;s=c[h>>2]|0;t=d|0;d=c[k>>2]|0;x=0;y=0;while(1){z=d+(x<<3)|0;A=c[z>>2]|0;B=c[z+4>>2]|0;C=-1;do{if((B|0)>(C|0)|(B|0)==(C|0)&A>>>0>-1>>>0|(A&2147483647|0)==0&(B&0|0)==0){D=c[u>>2]|0;if((D|0)<=0){E=y;break}F=c[t>>2]|0;G=0;H=y;I=B;J=A;while(1){K=F+(G<<3)|0;if((J|0)==(c[K>>2]|0)&(I|0)==(c[K+4>>2]|0)){L=(c[s>>2]|0)+(H<<3)|0;c[L>>2]=J;c[L+4>>2]=I;c[K>>2]=0;c[K+4>>2]=0;c[z>>2]=0;c[z+4>>2]=0;M=H+1|0;N=0;O=0}else{M=H;N=I;O=J}K=G+1|0;if((K|0)<(D|0)){G=K;H=M;I=N;J=O}else{E=M;break}}}else{E=y}}while(0);z=x+1|0;if((z|0)<(r|0)){x=z;y=E}else{break}}if(j){P=0;Q=E;R=k}else{S=E;T=k;break}while(1){y=(c[R>>2]|0)+(P<<3)|0;x=c[y>>2]|0;s=c[y+4>>2]|0;do{if((x|0)==0&(s|0)==0){U=Q;V=R}else{y=-1;if(!((s|0)>(y|0)|(s|0)==(y|0)&x>>>0>-1>>>0|(x&2147483647|0)==0&(s&0|0)==0)){U=Q;V=R;break}y=rGb(x,s)|0;t=y|0;u=((y|0)<0|0?-1:0)|-2147483648;y=c[g>>2]|0;d=c[y+4>>2]|0;z=c[f>>2]|0;if((d|0)<=0){U=Q;V=z;break}A=z|0;B=c[h>>2]|0;C=c[y>>2]|0;y=0;J=Q;while(1){I=C+(y<<3)|0;if((c[I>>2]|0)==(t|0)&(c[I+4>>2]|0)==(u|0)){I=(c[A>>2]|0)+(P<<3)|0;H=c[I+4>>2]|0;G=(c[B>>2]|0)+(J<<3)|0;c[G>>2]=c[I>>2];c[G+4>>2]=H;W=J+1|0}else{W=J}H=y+1|0;if((H|0)<(d|0)){y=H;J=W}else{U=W;V=z;break}}}}while(0);s=P+1|0;if((s|0)<(c[V+4>>2]|0)){P=s;Q=U;R=V}else{S=U;T=V;break}}}else{S=0;T=k}}while(0);k=c[g>>2]|0;c[g>>2]=T;c[f>>2]=k;j=c[k+4>>2]|0;if((j|0)>0){r=0;b=S;s=k;x=T;while(1){z=(c[s>>2]|0)+(r<<3)|0;J=c[z>>2]|0;y=c[z+4>>2]|0;do{if((J|0)==0&(y|0)==0){X=b;Y=s;Z=x}else{z=-1;if(!((y|0)>(z|0)|(y|0)==(z|0)&J>>>0>-1>>>0|(J&2147483647|0)==0&(y&0|0)==0)){X=b;Y=s;Z=x;break}z=rGb(J,y)|0;d=z|0;B=((z|0)<0|0?-1:0)|-2147483648;z=c[g>>2]|0;A=c[z+4>>2]|0;u=c[f>>2]|0;if((A|0)<=0){X=b;Y=u;Z=z;break}t=u|0;C=c[h>>2]|0;H=c[z>>2]|0;G=0;I=b;while(1){D=H+(G<<3)|0;if((c[D>>2]|0)==(d|0)&(c[D+4>>2]|0)==(B|0)){D=(c[t>>2]|0)+(r<<3)|0;F=c[D+4>>2]|0;K=(c[C>>2]|0)+(I<<3)|0;c[K>>2]=c[D>>2];c[K+4>>2]=F;_=I+1|0}else{_=I}F=G+1|0;if((F|0)<(A|0)){G=F;I=_}else{X=_;Y=u;Z=z;break}}}}while(0);y=r+1|0;J=c[Y+4>>2]|0;if((y|0)<(J|0)){r=y;b=X;s=Y;x=Z}else{$=X;aa=Y;ba=Z;ca=J;break}}}else{$=S;aa=k;ba=T;ca=j}c[g>>2]=aa;c[f>>2]=ba;x=c[ba+4>>2]|0;if((x|0)>0){s=c[h>>2]|0;b=s|0;r=c[ba>>2]|0;J=0;y=$;while(1){z=r+(J<<3)|0;u=c[z>>2]|0;I=c[z+4>>2]|0;G=0;a:do{if(((u&2147483647|0)!=0|(I&0|0)!=0)&((I|0)<(G|0)|(I|0)==(G|0)&u>>>0<0>>>0)&(ca|0)>0){A=c[aa>>2]|0;C=0;t=y;B=I;d=u;while(1){H=A+(C<<3)|0;if((d|0)==(c[H>>2]|0)&(B|0)==(c[H+4>>2]|0)){H=(c[b>>2]|0)+(t<<3)|0;c[H>>2]=d;c[H+4>>2]=B;da=t+1|0}else{da=t}H=C+1|0;if((H|0)>=(ca|0)){ea=da;break a}C=H;t=da;B=c[z+4>>2]|0;d=c[z>>2]|0}}else{ea=y}}while(0);z=J+1|0;if((z|0)<(x|0)){J=z;y=ea}else{fa=ea;ga=s;break}}}else{fa=$;ga=c[h>>2]|0}c[ga+4>>2]=fa;if((fa|0)==0){w=ga;break}s=iJb(c[ga+16>>2]|0,(c[ba+12>>2]|0)+(c[ga+12>>2]|0)<<2)|0;if((s|0)==0){q=54;break}c[(c[h>>2]|0)+16>>2]=s;s=c[f>>2]|0;y=s+16|0;if((c[s+12>>2]|0)==0){ha=y}else{s=0;J=y;while(1){y=c[h>>2]|0;c[(c[y+16>>2]|0)+(c[y+12>>2]<<2)>>2]=c[(c[J>>2]|0)+(s<<2)>>2];y=c[h>>2]|0;x=y+12|0;b=c[x>>2]|0;c[x>>2]=b+1;c[c[(c[y+16>>2]|0)+(b<<2)>>2]>>2]=y;y=s+1|0;b=c[f>>2]|0;x=b+16|0;if(y>>>0<(c[b+12>>2]|0)>>>0){s=y;J=x}else{ha=x;break}}}mJb(ha);mJb(c[f>>2]|0);mJb(f);J=c[h>>2]|0;s=iJb(c[J+16>>2]|0,(c[(c[g>>2]|0)+12>>2]|0)+(c[J+12>>2]|0)<<2)|0;if((s|0)==0){q=54;break}c[(c[h>>2]|0)+16>>2]=s;s=c[g>>2]|0;J=s+16|0;if((c[s+12>>2]|0)==0){ia=J;ja=s}else{s=0;x=J;while(1){J=c[h>>2]|0;c[(c[J+16>>2]|0)+(c[J+12>>2]<<2)>>2]=c[(c[x>>2]|0)+(s<<2)>>2];J=c[h>>2]|0;y=J+12|0;b=c[y>>2]|0;c[y>>2]=b+1;c[c[(c[J+16>>2]|0)+(b<<2)>>2]>>2]=J;J=s+1|0;b=c[g>>2]|0;y=b+16|0;if(J>>>0<(c[b+12>>2]|0)>>>0){s=J;x=y}else{ia=y;ja=b;break}}}mJb(ia);mJb(ja);mJb(g);l=c[h>>2]|0;i=e;return l|0}else{q=13}}while(0);do{if((q|0)==13){ja=iJb(c[o+16>>2]|0,(c[p+12>>2]|0)+(c[o+12>>2]|0)<<2)|0;if((ja|0)==0){q=54;break}c[(c[g>>2]|0)+16>>2]=ja;ja=c[f>>2]|0;ia=ja+16|0;if((c[ja+12>>2]|0)==0){ka=ia}else{ja=0;ha=ia;while(1){ia=c[g>>2]|0;c[(c[ia+16>>2]|0)+(c[ia+12>>2]<<2)>>2]=c[(c[ha>>2]|0)+(ja<<2)>>2];ia=c[g>>2]|0;ga=ia+12|0;ba=c[ga>>2]|0;c[ga>>2]=ba+1;c[c[(c[ia+16>>2]|0)+(ba<<2)>>2]>>2]=ia;ia=ja+1|0;ba=c[f>>2]|0;ga=ba+16|0;if(ia>>>0<(c[ba+12>>2]|0)>>>0){ja=ia;ha=ga}else{ka=ga;break}}}mJb(ka);mJb(c[f>>2]|0);mJb(f);l=c[g>>2]|0;i=e;return l|0}}while(0);if((q|0)==54){w=c[h>>2]|0}if((w|0)!=0){mJb(w+16|0);mJb(c[h>>2]|0)}mJb(h);l=0;i=e;return l|0}function Nk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=b;while(1){b=c[d>>2]|0;if((b|0)==-1){e=0;f=4;break}if((b|0)==(a|0)){e=1;f=4;break}else{d=d+4|0}}if((f|0)==4){return e|0}return 0}function Ok(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((a|0)==0){b=0}else{d=0;while(1){if((c[a+(d<<2)>>2]|0)==-1){b=d;break}else{d=d+1|0}}}d=pJb(16)|0;e=d;if((d|0)==0){f=0;return f|0}c[d>>2]=b;if((b|0)==0){f=e;return f|0}g=hJb(b<<2)|0;c[d+4>>2]=g;if((g|0)==0){kJb(d);f=0;return f|0}if((b|0)==0){f=e;return f|0}g=c[d+4>>2]|0;d=b;while(1){b=d-1|0;c[g+(b<<2)>>2]=c[a+(b<<2)>>2];if((b|0)==0){f=e;break}else{d=b}}return f|0}function Pk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((a|0)==0){b=0}else{d=0;while(1){e=a+(d<<3)|0;if((c[e>>2]|0)==(-1|0)&(c[e+4>>2]|0)==(-1|0)){b=d;break}else{d=d+1|0}}}d=pJb(20)|0;e=d;if((d|0)==0){f=0;return f|0}c[d+4>>2]=b;if((b|0)==0){f=e;return f|0}g=b<<3;b=hJb(g)|0;c[d>>2]=b;if((b|0)==0){kJb(d);f=0;return f|0}else{nrc(b|0,a|0,g)|0;f=e;return f|0}return 0}function Qk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;d=c[a>>2]|0;do{if((d|0)==0){e=pJb(16)|0;f=e;c[a>>2]=f;if((e|0)==0){g=-12}else{h=f;break}return g|0}else{h=d}}while(0);d=iJb(c[h+4>>2]|0,(c[h>>2]<<2)+4|0)|0;if((d|0)==0){g=-12;return g|0}c[(c[a>>2]|0)+4>>2]=d;d=c[a>>2]|0;a=d|0;h=c[a>>2]|0;c[a>>2]=h+1;c[(c[d+4>>2]|0)+(h<<2)>>2]=b;g=0;return g|0}function Rk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[a>>2]|0;do{if((e|0)==0){f=pJb(20)|0;g=f;c[a>>2]=g;if((f|0)==0){h=-12}else{i=g;break}return h|0}else{i=e}}while(0);e=iJb(c[i>>2]|0,(c[i+4>>2]<<3)+8|0)|0;if((e|0)==0){h=-12;return h|0}c[c[a>>2]>>2]=e;e=c[a>>2]|0;a=e+4|0;i=c[a>>2]|0;c[a>>2]=i+1;a=(c[e>>2]|0)+(i<<3)|0;c[a>>2]=b;c[a+4>>2]=d;h=0;return h|0}function Sk(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((b|0)==0){d=0;e=0;while(1){do{if((a[(qKb(e)|0)+7|0]&8)==0){if((d|0)==0){f=pJb(16)|0;g=f;if((f|0)==0){h=g;break}else{i=g}}else{i=d}g=i+4|0;f=i|0;j=iJb(c[g>>2]|0,(c[f>>2]<<2)+4|0)|0;if((j|0)==0){h=i;break}k=j;c[g>>2]=k;g=c[f>>2]|0;c[f>>2]=g+1;c[k+(g<<2)>>2]=e;h=i}else{h=d}}while(0);g=e+1|0;if((g|0)<333){d=h;e=g}else{l=h;break}}return l|0}h=(b|0)==1;b=h?10:0;if(h){m=0;n=0}else{l=0;return l|0}while(1){qKb(n)|0;if((m|0)==0){h=pJb(16)|0;e=h;if((h|0)==0){o=e}else{p=e;q=11}}else{p=m;q=11}do{if((q|0)==11){q=0;e=p+4|0;h=p|0;d=iJb(c[e>>2]|0,(c[h>>2]<<2)+4|0)|0;if((d|0)==0){o=p;break}i=d;c[e>>2]=i;e=c[h>>2]|0;c[h>>2]=e+1;c[i+(e<<2)>>2]=n;o=p}}while(0);e=n+1|0;if((e|0)<(b|0)){m=o;n=e}else{l=o;break}}return l|0}function Tk(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=0;b=0;while(1){do{if((RKb(b)|0)==0){d=a}else{if((a|0)==0){e=pJb(16)|0;f=e;if((e|0)==0){d=f;break}else{g=f}}else{g=a}f=g+4|0;e=g|0;h=iJb(c[f>>2]|0,(c[e>>2]<<2)+4|0)|0;if((h|0)==0){d=g;break}i=h;c[f>>2]=i;f=c[e>>2]|0;c[e>>2]=f+1;c[i+(f<<2)>>2]=b;d=g}}while(0);f=b+1|0;if((f|0)<10){a=d;b=f}else{break}}return d|0}function Uk(){return pJb(16)|0}function Vk(){var b=0,c=0;b=pJb(20)|0;if((b|0)==0){c=0;return c|0}a[b+8|0]=1;c=b;return c|0}function Wk(){var b=0,c=0;b=pJb(20)|0;if((b|0)==0){c=0;return c|0}a[b+9|0]=1;a[b+8|0]=1;c=b;return c|0}function Xk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[b>>2]=a;d=a+16|0;e=c[d>>2]|0;f=a+12|0;a=(c[f>>2]|0)+1|0;c[f>>2]=a;g=iJb(e,a<<2)|0;c[d>>2]=g;c[g+((c[f>>2]|0)-1<<2)>>2]=b;return}function Yk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[b>>2]=a;d=a+12|0;e=c[d>>2]|0;f=a+8|0;a=(c[f>>2]|0)+1|0;c[f>>2]=a;g=iJb(e,a<<2)|0;c[d>>2]=g;c[g+((c[f>>2]|0)-1<<2)>>2]=b;return}function Zk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a>>2]|0;if((b|0)==0){return}d=c[b+8>>2]|0;e=b+12|0;f=0;while(1){if(!(f>>>0<d>>>0)){g=b;h=d;break}i=c[e>>2]|0;j=i+(f<<2)|0;k=f+1|0;if((c[j>>2]|0)==(a|0)){l=5;break}else{f=k}}do{if((l|0)==5){if(!((f|0)>-1)){g=b;h=d;break}orc(j|0,i+(k<<2)|0,(d-f<<2)-4|0)|0;e=c[a>>2]|0;g=e;h=c[e+8>>2]|0}}while(0);f=h-1|0;c[g+8>>2]=f;if((f|0)==0){kJb(c[g+4>>2]|0);kJb(c[(c[a>>2]|0)+12>>2]|0);kJb(c[a>>2]|0)}c[a>>2]=0;return}function _k(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a>>2]|0;if((b|0)==0){return}d=c[b+12>>2]|0;e=b+16|0;f=0;while(1){if(!(f>>>0<d>>>0)){g=b;h=d;break}i=c[e>>2]|0;j=i+(f<<2)|0;k=f+1|0;if((c[j>>2]|0)==(a|0)){l=5;break}else{f=k}}do{if((l|0)==5){if(!((f|0)>-1)){g=b;h=d;break}orc(j|0,i+(k<<2)|0,(d-f<<2)-4|0)|0;e=c[a>>2]|0;g=e;h=c[e+12>>2]|0}}while(0);f=h-1|0;c[g+12>>2]=f;if((f|0)==0){kJb(c[g>>2]|0);kJb(c[(c[a>>2]|0)+16>>2]|0);kJb(c[a>>2]|0)}c[a>>2]=0;return}function $k(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a>>2]|0;e=c[d+12>>2]|0;f=d+16|0;d=0;while(1){if(!(d>>>0<e>>>0)){g=6;break}h=(c[f>>2]|0)+(d<<2)|0;if((c[h>>2]|0)==(a|0)){break}else{d=d+1|0}}if((g|0)==6){return}if(!((d|0)>-1)){return}c[h>>2]=b;c[b>>2]=c[a>>2];c[a>>2]=0;return}function al(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a>>2]|0;e=c[d+8>>2]|0;f=d+12|0;d=0;while(1){if(!(d>>>0<e>>>0)){g=6;break}h=(c[f>>2]|0)+(d<<2)|0;if((c[h>>2]|0)==(a|0)){break}else{d=d+1|0}}if((g|0)==6){return}if(!((d|0)>-1)){return}c[h>>2]=b;c[b>>2]=c[a>>2];c[a>>2]=0;return}function bl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=a+24|0;f=c[b>>2]|0;if((f|0)==0){g=0}else{h=a+16|0;j=0;k=0;l=f;while(1){f=c[(c[h>>2]|0)+(k<<2)>>2]|0;do{if((f|0)==0){m=j;n=l}else{o=f+84|0;if((c[o>>2]|0)!=0){m=j;n=l;break}p=c[e>>2]|0;c[o>>2]=p;q=p+16|0;r=c[q>>2]|0;s=p+12|0;p=(c[s>>2]|0)+1|0;c[s>>2]=p;t=iJb(r,p<<2)|0;c[q>>2]=t;c[t+((c[s>>2]|0)-1<<2)>>2]=o;m=j+1|0;n=c[b>>2]|0}}while(0);f=k+1|0;if(f>>>0<n>>>0){j=m;k=f;l=n}else{g=m;break}}}m=a+40|0;n=c[m>>2]|0;if((n|0)==0){u=g}else{l=a+32|0;a=g;g=0;k=n;while(1){n=c[(c[l>>2]|0)+(g<<2)>>2]|0;do{if((n|0)==0){v=a;w=k}else{j=n+80|0;if((c[j>>2]|0)!=0){v=a;w=k;break}b=c[e>>2]|0;c[j>>2]=b;h=b+16|0;f=c[h>>2]|0;o=b+12|0;b=(c[o>>2]|0)+1|0;c[o>>2]=b;s=iJb(f,b<<2)|0;c[h>>2]=s;c[s+((c[o>>2]|0)-1<<2)>>2]=j;v=a+1|0;w=c[m>>2]|0}}while(0);n=g+1|0;if(n>>>0<w>>>0){a=v;g=n;k=w}else{u=v;break}}}if((u|0)!=0){i=d;return}u=c[e>>2]|0;mJb(u);mJb(u+16|0);mJb(e);i=d;return}function cl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=a+24|0;f=c[b>>2]|0;if((f|0)==0){g=0}else{h=a+16|0;j=0;k=0;l=f;while(1){f=c[(c[h>>2]|0)+(k<<2)>>2]|0;do{if((f|0)==0){m=j;n=l}else{o=f+76|0;if((c[o>>2]|0)!=0){m=j;n=l;break}p=c[e>>2]|0;c[o>>2]=p;q=p+12|0;r=c[q>>2]|0;s=p+8|0;p=(c[s>>2]|0)+1|0;c[s>>2]=p;t=iJb(r,p<<2)|0;c[q>>2]=t;c[t+((c[s>>2]|0)-1<<2)>>2]=o;m=j+1|0;n=c[b>>2]|0}}while(0);f=k+1|0;if(f>>>0<n>>>0){j=m;k=f;l=n}else{g=m;break}}}m=a+40|0;n=c[m>>2]|0;if((n|0)==0){u=g}else{l=a+32|0;a=g;g=0;k=n;while(1){n=c[(c[l>>2]|0)+(g<<2)>>2]|0;do{if((n|0)==0){v=a;w=k}else{j=n+72|0;if((c[j>>2]|0)!=0){v=a;w=k;break}b=c[e>>2]|0;c[j>>2]=b;h=b+12|0;f=c[h>>2]|0;o=b+8|0;b=(c[o>>2]|0)+1|0;c[o>>2]=b;s=iJb(f,b<<2)|0;c[h>>2]=s;c[s+((c[o>>2]|0)-1<<2)>>2]=j;v=a+1|0;w=c[m>>2]|0}}while(0);n=g+1|0;if(n>>>0<w>>>0){a=v;g=n;k=w}else{u=v;break}}}if((u|0)!=0){i=d;return}u=c[e>>2]|0;mJb(u+4|0);mJb(u+12|0);mJb(e);i=d;return}function dl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=a+24|0;f=c[b>>2]|0;if((f|0)==0){g=0}else{h=a+16|0;j=0;k=0;l=f;while(1){f=c[(c[h>>2]|0)+(k<<2)>>2]|0;do{if((f|0)==0){m=j;n=l}else{o=f+68|0;if((c[o>>2]|0)!=0){m=j;n=l;break}p=c[e>>2]|0;c[o>>2]=p;q=p+12|0;r=c[q>>2]|0;s=p+8|0;p=(c[s>>2]|0)+1|0;c[s>>2]=p;t=iJb(r,p<<2)|0;c[q>>2]=t;c[t+((c[s>>2]|0)-1<<2)>>2]=o;m=j+1|0;n=c[b>>2]|0}}while(0);f=k+1|0;if(f>>>0<n>>>0){j=m;k=f;l=n}else{g=m;break}}}m=a+40|0;n=c[m>>2]|0;if((n|0)==0){u=g}else{l=a+32|0;a=g;g=0;k=n;while(1){n=c[(c[l>>2]|0)+(g<<2)>>2]|0;do{if((n|0)==0){v=a;w=k}else{j=n+64|0;if((c[j>>2]|0)!=0){v=a;w=k;break}b=c[e>>2]|0;c[j>>2]=b;h=b+12|0;f=c[h>>2]|0;o=b+8|0;b=(c[o>>2]|0)+1|0;c[o>>2]=b;s=iJb(f,b<<2)|0;c[h>>2]=s;c[s+((c[o>>2]|0)-1<<2)>>2]=j;v=a+1|0;w=c[m>>2]|0}}while(0);n=g+1|0;if(n>>>0<w>>>0){a=v;g=n;k=w}else{u=v;break}}}if((u|0)!=0){i=d;return}u=c[e>>2]|0;mJb(u+4|0);mJb(u+12|0);mJb(e);i=d;return}function el(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[b+16>>2]|0;do{if((d|0)==0){e=4}else{f=c[d>>2]|0;if((f|0)==0){e=4;break}g=c[f+16>>2]|0}}while(0);do{if((e|0)==4){d=c[b+32>>2]|0;if((d|0)==0){g=0;break}f=c[d>>2]|0;if((f|0)==0){g=0;break}g=c[f+16>>2]|0}}while(0);dl(b,Sk(g)|0);if((g|0)!=1){return 0}g=pJb(20)|0;if((g|0)==0){h=0}else{a[g+8|0]=1;h=g}bl(b,h);cl(b,pJb(16)|0);return 0}function fl(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[b+16>>2]|0;do{if((d|0)==0){e=4}else{f=c[d>>2]|0;if((f|0)==0){e=4;break}g=c[f+16>>2]|0}}while(0);do{if((e|0)==4){d=c[b+32>>2]|0;if((d|0)==0){g=0;break}f=c[d>>2]|0;if((f|0)==0){g=0;break}g=c[f+16>>2]|0}}while(0);dl(b,Sk(g)|0);if((g|0)!=1){return 0}g=pJb(20)|0;if((g|0)==0){h=0}else{a[g+9|0]=1;a[g+8|0]=1;h=g}bl(b,h);cl(b,pJb(16)|0);return 0}function gl(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+8|0;g=f|0;h=nKb(d)|0;do{if((h|0)==-1){j=rb(d|0,g|0,0)|0;if(!((a[c[g>>2]|0]|0)!=0|j>>>0>332>>>0)){k=j;break}KIb(e,16,2602992,(j=i,i=i+8|0,c[j>>2]=d,j)|0);i=j;l=-22;i=f;return l|0}else{k=h}}while(0);c[b>>2]=k;l=0;i=f;return l|0}function hl(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+8|0;g=f|0;h=MKb(d)|0;do{if((h|0)==-1){j=rb(d|0,g|0,0)|0;if(!((a[c[g>>2]|0]|0)!=0|j>>>0>9>>>0)){k=j;break}KIb(e,16,2451240,(j=i,i=i+8|0,c[j>>2]=d,j)|0);i=j;l=-22;i=f;return l|0}else{k=h}}while(0);c[b>>2]=k;l=0;i=f;return l|0}function il(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0;f=i;i=i+8|0;g=f|0;h=+SGb(d,g);do{if(!((a[c[g>>2]|0]|0)!=0|h<1.0)){j=~~h;if(+(j|0)!=h|h>2147483647.0){break}c[b>>2]=j;k=0;i=f;return k|0}}while(0);KIb(e,16,2297344,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;k=-22;i=f;return k|0}function jl(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+8|0;h=g|0;j=(d|0)!=0;do{if(j){k=rb(e|0,h|0,10)|0;l=c[h>>2]|0;if((a[l]|0)!=99){break}if((a[l+1|0]|0)!=0){break}if(!((k-1|0)>>>0<62>>>0)){break}c[d>>2]=k;c[b>>2]=0;c[b+4>>2]=0;m=0;i=g;return m|0}}while(0);k=pGb(e)|0;l=G;do{if((k|0)==0&(l|0)==0){n=rb(e|0,h|0,10)|0;if((a[c[h>>2]|0]|0)==0){if((n|0)!=0){o=(n|0)<0|0?-1:0;p=n;break}}KIb(f,16,2246480,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;m=-22;i=g;return m|0}else{o=l;p=k}}while(0);c[b>>2]=p;c[b+4>>2]=o;if(!j){m=0;i=g;return m|0}c[d>>2]=rGb(p,o)|0;m=0;i=g;return m|0}function kl(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;if((b|0)==0){return}d=a;e=b;while(1){b=c[e+12>>2]|0;mJb(e);mJb(d);c[a>>2]=b;if((b|0)==0){break}else{e=b}}return}function ll(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+40|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;c[h>>2]=d;c[j>>2]=0;c[k>>2]=0;c[l>>2]=0;c[h>>2]=d+(ud(d|0,2518816)|0);d=ml(h,b)|0;a:do{if((d|0)<0){n=d}else{o=c[h>>2]|0;c[h>>2]=o+(ud(o|0,2518816)|0);o=b;p=nl(h,j,l,o)|0;if((p|0)<0){n=p;break}else{q=0}while(1){p=ol(m,h,b,q,o)|0;if((p|0)<0){n=p;break a}p=pl(c[m>>2]|0,j,k,o)|0;if((p|0)<0){n=p;break a}p=ql(h,j,k,l,o)|0;if((p|0)<0){n=p;break a}p=c[h>>2]|0;r=ud(p|0,2518816)|0;c[h>>2]=p+(r+1);s=a[p+r|0]|0;do{if(s<<24>>24==59){r=c[j>>2]|0;if((r|0)==0){t=q+1|0;break}p=l;u=c[l>>2]|0;while(1){if((u|0)==0){v=12;break}w=u+12|0;x=c[w>>2]|0;if((x|0)==0){v=13;break}else{p=w;u=x}}if((v|0)==12){v=0;c[p>>2]=r}else if((v|0)==13){v=0;c[w>>2]=r}c[j>>2]=0;v=15}else{v=15}}while(0);if((v|0)==15){v=0;u=q+1|0;if((s<<24>>24|0)==0){break}else if((s<<24>>24|0)==59|(s<<24>>24|0)==44){t=u}else{v=17;break}}u=c[h>>2]|0;c[h>>2]=u+(ud(u|0,2518816)|0);u=nl(h,j,l,o)|0;if((u|0)<0){n=u;break a}else{q=t}}if((v|0)==17){KIb(o,16,2602112,(u=i,i=i+8|0,c[u>>2]=(c[h>>2]|0)-1,u)|0);i=u;n=-22;break}u=l;x=c[l>>2]|0;while(1){if((x|0)==0){v=22;break}y=x+12|0;z=c[y>>2]|0;if((z|0)==0){v=23;break}else{u=y;x=z}}if((v|0)==22){c[u>>2]=c[j>>2]}else if((v|0)==23){c[y>>2]=c[j>>2]}c[j>>2]=0;c[e>>2]=c[k>>2];A=0;B=c[l>>2]|0;c[f>>2]=B;i=g;return A|0}}while(0);y=b+20|0;v=b+8|0;if((c[y>>2]|0)!=0){do{ej(c[c[v>>2]>>2]|0);}while((c[y>>2]|0)!=0)}mJb(v);v=c[k>>2]|0;if((v|0)!=0){y=k;b=v;while(1){v=c[b+12>>2]|0;mJb(b);mJb(y);c[k>>2]=v;if((v|0)==0){break}else{b=v}}}b=c[l>>2]|0;if((b|0)!=0){k=l;y=b;while(1){b=c[y+12>>2]|0;mJb(y);mJb(k);c[l>>2]=b;if((b|0)==0){break}else{y=b}}}y=c[j>>2]|0;if((y|0)!=0){l=j;k=y;while(1){y=c[k+12>>2]|0;mJb(k);mJb(l);c[j>>2]=y;if((y|0)==0){break}else{k=y}}}c[e>>2]=0;A=n;B=0;c[f>>2]=B;i=g;return A|0}function ml(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[a>>2]|0;f=_b(e|0,59)|0;if((krc(e,2442488,10)|0)!=0){g=0;i=d;return g|0}if((f|0)==0){KIb(b,16,2430416,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-22;i=d;return g|0}c[a>>2]=e+4;e=b+12|0;mJb(e);b=f+1|0;h=pJb(b-(c[a>>2]|0)|0)|0;c[e>>2]=h;if((h|0)==0){g=-12;i=d;return g|0}e=c[a>>2]|0;CFb(h,e,b-e|0)|0;c[a>>2]=f+1;g=0;i=d;return g|0}function nl(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+16|0;h=g|0;j=g+8|0;c[j>>2]=0;k=c[b>>2]|0;do{if((a[k]|0)==91){l=h;m=0;n=k;while(1){c[b>>2]=n+1;o=GFb(b,2172504)|0;c[h>>2]=o;do{if((a[o]|0)==0){KIb(f,16,2144904,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;q=7}else{r=c[b>>2]|0;c[b>>2]=r+1;if((a[r]|0)==93){s=o;break}KIb(f,16,2121176,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;q=7}}while(0);if((q|0)==7){q=0;mJb(l);s=c[h>>2]|0}if((s|0)==0){t=-22;q=31;break}o=c[e>>2]|0;a:do{if((o|0)==0){q=15}else{r=e;u=o;while(1){v=c[u>>2]|0;if((v|0)!=0){if((irc(v,s)|0)==0){break}}v=u+12|0;w=c[v>>2]|0;if((w|0)==0){q=15;break a}else{r=v;u=w}}if((u|0)==0){q=15;break}w=u+12|0;c[r>>2]=c[w>>2];c[w>>2]=0;kJb(s);x=u}}while(0);if((q|0)==15){q=0;o=pJb(16)|0;if((o|0)==0){q=16;break}c[o>>2]=s;c[o+8>>2]=m;x=o}o=j;w=c[j>>2]|0;while(1){if((w|0)==0){q=21;break}y=w+12|0;v=c[y>>2]|0;if((v|0)==0){q=22;break}else{o=y;w=v}}if((q|0)==21){q=0;c[o>>2]=x}else if((q|0)==22){q=0;c[y>>2]=x}w=c[b>>2]|0;v=w+(ud(w|0,2518816)|0)|0;c[b>>2]=v;z=m+1|0;if((a[v]|0)==91){m=z;n=v}else{q=24;break}}if((q|0)==16){kJb(s);t=-12;i=g;return t|0}else if((q|0)==24){A=z;B=c[j>>2]|0;break}else if((q|0)==31){i=g;return t|0}}else{A=0;B=0}}while(0);z=j;s=B;while(1){if((s|0)==0){q=28;break}C=s+12|0;B=c[C>>2]|0;if((B|0)==0){q=29;break}else{z=C;s=B}}if((q|0)==28){c[z>>2]=c[d>>2]}else if((q|0)==29){c[C>>2]=c[d>>2]}c[d>>2]=c[j>>2];t=A;i=g;return t|0}function ol(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+32|0;j=GFb(d,2616184)|0;k=c[d>>2]|0;if((a[k]|0)==61){c[d>>2]=k+1;l=GFb(d,2588944)|0}else{l=0}d=h|0;Rb(d|0,30,2567544,(k=i,i=i+16|0,c[k>>2]=j,c[k+8>>2]=f,k)|0)|0;i=k;f=_i(j)|0;if((f|0)==0){KIb(g,16,2549304,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;m=-22;kJb(j);kJb(l);i=h;return m|0}n=vj(e,f,d)|0;c[b>>2]=n;if((n|0)==0){KIb(g,16,2531352,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;m=-12;kJb(j);kJb(l);i=h;return m|0}do{if((irc(j,2516120)|0)!=0|(l|0)==0){o=0;p=l;q=n}else{if((Db(l|0,2502216)|0)!=0){o=0;p=l;q=n;break}d=c[e+12>>2]|0;if((d|0)==0){o=0;p=l;q=n;break}f=FFb(2489120,(k=i,i=i+16|0,c[k>>2]=l,c[k+8>>2]=d,k)|0)|0;i=k;if((f|0)==0){m=-12;kJb(j);kJb(l);i=h;return m|0}else{o=f;p=f;q=c[b>>2]|0;break}}}while(0);n=gj(q,p)|0;if((n|0)<0){KIb(g,16,2478152,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;if((p|0)!=0){KIb(g,16,2468568,(k=i,i=i+8|0,c[k>>2]=p,k)|0);i=k}KIb(g,16,2459280,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;ej(c[b>>2]|0);c[b>>2]=0}kJb(o);m=n;kJb(j);kJb(l);i=h;return m|0}function pl(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;g=a+24|0;h=c[b>>2]|0;j=(h|0)==0;a:do{if((c[g>>2]|0)==0){k=j}else{l=a+4|0;m=0;n=h;o=j;b:while(1){if(o){p=pJb(16)|0;if((p|0)==0){q=-12;r=21;break}else{s=p}}else{p=n+12|0;c[b>>2]=c[p>>2];c[p>>2]=0;s=n}p=s+4|0;t=c[p>>2]|0;do{if((t|0)==0){c[p>>2]=a;c[s+8>>2]=m;u=d;v=c[d>>2]|0;while(1){if((v|0)==0){r=13;break}w=v+12|0;x=c[w>>2]|0;if((x|0)==0){r=14;break}else{u=w;v=x}}if((r|0)==13){r=0;c[u>>2]=s;break}else if((r|0)==14){r=0;c[w>>2]=s;break}}else{v=c[s+8>>2]|0;x=Ri(t,v,a,m)|0;if((x|0)==0){y=0}else{z=c[c[l>>2]>>2]|0;KIb(e,16,2204408,(A=i,i=i+32|0,c[A>>2]=c[c[t+4>>2]>>2],c[A+8>>2]=v,c[A+16>>2]=z,c[A+24>>2]=m,A)|0);i=A;y=x}kJb(c[s>>2]|0);kJb(s);if((y|0)<0){q=y;r=21;break b}}}while(0);t=m+1|0;p=c[b>>2]|0;x=(p|0)==0;if(t>>>0<(c[g>>2]|0)>>>0){m=t;n=p;o=x}else{k=x;break a}}if((r|0)==21){i=f;return q|0}}}while(0);if(!k){KIb(e,16,2638728,(A=i,i=i+8|0,c[A>>2]=c[c[a+4>>2]>>2],A)|0);i=A;q=-22;i=f;return q|0}A=c[a+40>>2]|0;if((A|0)==0){q=0;i=f;return q|0}else{B=A}while(1){A=B-1|0;e=pJb(16)|0;if((e|0)==0){q=-12;r=21;break}c[e+4>>2]=a;c[e+8>>2]=A;c[e+12>>2]=c[b>>2];c[b>>2]=e;if((A|0)==0){q=0;r=21;break}else{B=A}}if((r|0)==21){i=f;return q|0}return 0}function ql(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+8|0;j=h|0;k=c[b>>2]|0;if((a[k]|0)!=91){l=0;i=h;return l|0}m=j;n=0;o=k;a:while(1){c[b>>2]=o+1;k=GFb(b,2172504)|0;c[j>>2]=k;do{if((a[k]|0)==0){KIb(g,16,2144904,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=7}else{r=c[b>>2]|0;c[b>>2]=r+1;if((a[r]|0)==93){s=k;break}KIb(g,16,2121176,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=7}}while(0);if((q|0)==7){q=0;mJb(m);s=c[j>>2]|0}k=c[d>>2]|0;if((s|0)==0){l=-22;q=22;break}if((k|0)==0){q=10;break}r=k+12|0;c[d>>2]=c[r>>2];t=c[e>>2]|0;b:do{if((t|0)==0){q=20}else{u=e;v=t;while(1){w=v|0;x=c[w>>2]|0;if((x|0)!=0){if((irc(x,s)|0)==0){break}}x=v+12|0;y=c[x>>2]|0;if((y|0)==0){q=20;break b}else{u=x;v=y}}if((v|0)==0){q=20;break}y=v+12|0;c[u>>2]=c[y>>2];c[y>>2]=0;y=c[k+4>>2]|0;x=c[k+8>>2]|0;z=c[v+4>>2]|0;A=c[v+8>>2]|0;B=Ri(y,x,z,A)|0;if((B|0)!=0){C=c[c[z+4>>2]>>2]|0;KIb(g,16,2204408,(p=i,i=i+32|0,c[p>>2]=c[c[y+4>>2]>>2],c[p+8>>2]=x,c[p+16>>2]=C,c[p+24>>2]=A,p)|0);i=p;if((B|0)<0){q=18;break a}}kJb(c[w>>2]|0);kJb(s);kJb(v);kJb(k)}}while(0);if((q|0)==20){q=0;c[k>>2]=s;c[r>>2]=c[f>>2];c[f>>2]=k}t=c[b>>2]|0;A=t+(ud(t|0,2518816)|0)|0;c[b>>2]=A;t=n+1|0;if((a[A]|0)==91){n=t;o=A}else{l=t;q=22;break}}if((q|0)==10){KIb(g,16,2246112,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;kJb(s);l=-22;i=h;return l|0}else if((q|0)==18){kJb(s);l=B;i=h;return l|0}else if((q|0)==22){i=h;return l|0}return 0}function rl(){return}function sl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+44>>2]|0;e=d+4|0;f=a;a=UGb(d+8|0,c[e>>2]|0,281880,0,0,0,0,0,f)|0;if((a|0)<0){KIb(f,16,2531200,(f=i,i=i+8|0,c[f>>2]=c[e>>2],f)|0);i=f;g=a;i=b;return g|0}else{h[d+32>>3]=0.0;h[d+160>>3]=0.0;h[d+64>>3]=+r;h[d+72>>3]=+r;h[d+80>>3]=+r;h[d+88>>3]=+r;h[d+112>>3]=+r;h[d+120>>3]=+r;g=0;i=b;return g|0}return 0}function tl(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+8|0;TGb(c[b>>2]|0);c[b>>2]=0;return}function ul(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,S=0,T=0;e=i;i=i+192|0;f=e|0;g=e+64|0;j=e+128|0;l=b+8|0;m=c[(c[l>>2]|0)+44>>2]|0;n=d+136|0;o=c[n>>2]|0;p=c[n+4>>2]|0;q=m+16|0;s=m+112|0;t=c[s+4>>2]&2147483647;u=2146435072;if(t>>>0>u>>>0|t>>>0==u>>>0&(c[s>>2]|0)>>>0>0>>>0){if((o|0)==0&(p|0)==(-2147483648|0)){h[s>>3]=+r;v=+r}else{h[s>>3]=+(o>>>0)+ +(p|0)*4294967296.0;v=(+(o>>>0)+ +(p|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[m+120>>3]=v}s=(o|0)==0&(p|0)==(-2147483648|0);if(s){u=m+96|0;h[u>>3]=+r;w=+r;x=u}else{u=m+96|0;h[u>>3]=+(o>>>0)+ +(p|0)*4294967296.0;w=(+(o>>>0)+ +(p|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0));x=u}u=m+128|0;h[u>>3]=w;t=DHb(d)|0;if((t|0)==(-1|0)&(G|0)==(-1|0)){y=+r}else{t=DHb(d)|0;y=+(t>>>0)+ +(G|0)*4294967296.0}t=m+56|0;h[t>>3]=y;z=jLb()|0;h[m+144>>3]=+(z>>>0)+ +(G|0)*4294967296.0;z=b+16|0;A=c[z>>2]|0;if((A|0)==0){h[m+24>>3]=+(c[d+296>>2]|0)}else if((A|0)==1){y=+(c[d+76>>2]|0);h[m+160>>3]=y;h[m+48>>3]=y}y=+XGb(c[m+8>>2]|0,q,0);h[k>>3]=y;q=c[k+4>>2]&2147483647;A=2146435072;B=q>>>0>A>>>0|q>>>0==A>>>0&(c[k>>2]|0)>>>0>0>>>0;if(B){C=-2147483648;D=0}else{C=(F=+y,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);D=~~+y>>>0}c[n>>2]=D;c[n+4>>2]=C;C=c[l>>2]|0;D=m+32|0;w=+h[D>>3];A=(F=+w,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);q=f|0;mrc(q|0,0,64)|0;a[q]=0;v=+h[x>>3];f=c[x+4>>2]&2147483647;E=2146435072;if(f>>>0>E>>>0|f>>>0==E>>>0&(c[x>>2]|0)>>>0>0>>>0){Rb(q|0,64,2567400,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{x=(F=+v,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Rb(q|0,64,2549152,(H=i,i=i+16|0,c[H>>2]=~~+v>>>0,c[H+8>>2]=x,H)|0)|0;i=H}v=+h[u>>3];u=g|0;mrc(u|0,0,64)|0;a[u]=0;I=+h[t>>3];g=c[t+4>>2]&2147483647;x=2146435072;if(g>>>0>x>>>0|g>>>0==x>>>0&(c[t>>2]|0)>>>0>0>>>0){Rb(u|0,64,2567400,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{t=(F=+I,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Rb(u|0,64,2549152,(H=i,i=i+16|0,c[H>>2]=~~+I>>>0,c[H+8>>2]=t,H)|0)|0;i=H}KIb(C,48,2121024,(H=i,i=i+40|0,c[H>>2]=~~+w>>>0,c[H+8>>2]=A,c[H+16>>2]=q,h[H+24>>3]=v,c[H+32>>2]=u,H)|0);i=H;u=c[z>>2]|0;if((u|0)==0){v=+h[m+24>>3];q=(F=+v,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);KIb(c[l>>2]|0,48,2638560,(H=i,i=i+16|0,c[H>>2]=~~+v>>>0,c[H+8>>2]=q,H)|0);i=H}else if((u|0)==1){v=+h[m+48>>3];u=(F=+v,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);w=+h[m+40>>3];q=(F=+w,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);KIb(c[l>>2]|0,48,2615952,(H=i,i=i+32|0,c[H>>2]=~~+v>>>0,c[H+8>>2]=u,c[H+16>>2]=~~+w>>>0,c[H+24>>2]=q,H)|0);i=H}q=c[l>>2]|0;u=j|0;mrc(u|0,0,64)|0;a[u]=0;if(B){Rb(u|0,64,2567400,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{B=(F=+y,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Rb(u|0,64,2549152,(H=i,i=i+16|0,c[H>>2]=~~+y>>>0,c[H+8>>2]=B,H)|0)|0;i=H}if(y==-9223372036854776000.0){J=+r}else{J=y*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}KIb(q,48,2588784,(H=i,i=i+16|0,c[H>>2]=u,h[H+8>>3]=J,H)|0);i=H;if((c[z>>2]|0)==0){K=+h[D>>3]+1.0}else{K=+h[D>>3]+ +(c[d+76>>2]|0)}h[D>>3]=K;if(s){h[m+64>>3]=+r;L=+r}else{K=+(o>>>0)+ +(p|0)*4294967296.0;h[m+64>>3]=K;L=K*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[m+72>>3]=L;p=c[n>>2]|0;o=c[n+4>>2]|0;if((p|0)==0&(o|0)==(-2147483648|0)){h[m+80>>3]=+r;M=+r}else{h[m+80>>3]=+(p>>>0)+ +(o|0)*4294967296.0;M=(+(p>>>0)+ +(o|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[m+88>>3]=M;if((c[m+176>>2]|0)!=1){N=c[l>>2]|0;O=N+32|0;P=c[O>>2]|0;S=c[P>>2]|0;T=lj(S,d)|0;i=e;return T|0}b=m+40|0;h[b>>3]=+h[b>>3]+ +(c[d+76>>2]|0);N=c[l>>2]|0;O=N+32|0;P=c[O>>2]|0;S=c[P>>2]|0;T=lj(S,d)|0;i=e;return T|0}function vl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0.0,l=0.0;b=i;d=c[(c[a+8>>2]|0)+44>>2]|0;e=d+176|0;c[e>>2]=c[a+16>>2];f=d+16|0;g=d+136|0;h[g>>3]=+(c[a+56>>2]|0)/+(c[a+60>>2]|0);j=jLb()|0;h[d+152>>3]=+(j>>>0)+ +(G|0)*4294967296.0;if((c[e>>2]|0)==1){k=+(c[a+48>>2]|0)}else{k=+r}h[d+104>>3]=k;h[d+168>>3]=k;d=c[a+116>>2]|0;do{if((d|0)==0){l=+r}else{e=c[a+120>>2]|0;if((e|0)==0){l=+r;break}l=+(d|0)/+(e|0)}}while(0);h[f>>3]=l;KIb(c[a>>2]|0,40,2144648,(a=i,i=i+24|0,h[a>>3]=+h[g>>3],h[a+8>>3]=l,h[a+16>>3]=k,a)|0);i=a;i=b;return 0}function wl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+96|0;d=b+32|0;e=(c[a+44>>2]|0)+4|0;if((c[e>>2]|0)<=0){i=b;return 0}f=d;g=b|0;h=a+4|0;j=d+4|0;k=d|0;l=a+40|0;m=a+28|0;n=a+32|0;o=a+36|0;a=0;do{mrc(f|0,0,60)|0;Rb(g|0,32,2172136,(p=i,i=i+8|0,c[p>>2]=a,p)|0)|0;i=p;c[j>>2]=c[(c[(c[h>>2]|0)+8>>2]|0)+4>>2];c[k>>2]=rJb(g)|0;Qi(a,l,4,m,n,d)|0;c[o>>2]=c[l>>2];a=a+1|0;}while((a|0)<(c[e>>2]|0));i=b;return 0}function xl(a){a=a|0;var b=0,d=0;b=a+40|0;if((c[b>>2]|0)==0){return}d=a+28|0;a=0;do{mJb((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function yl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=c[a+8>>2]|0;a=b+40|0;f=c[a>>2]|0;a:do{if((f|0)==0){g=-541478725}else{h=b+32|0;j=-541478725;k=0;l=f;while(1){if((c[(c[(c[h>>2]|0)+(k<<2)>>2]|0)+144>>2]|0)==0){m=$Hb(c[e>>2]|0)|0;if((m|0)==0){g=-12;break a}n=lj(c[(c[h>>2]|0)+(k<<2)>>2]|0,m)|0;if((n|0)<0){g=n;break a}o=n;p=c[a>>2]|0}else{o=j;p=l}n=k+1|0;if(n>>>0<p>>>0){j=o;k=n;l=p}else{g=o;break}}}}while(0);VHb(e);i=d;return g|0}function zl(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;d=i;i=i+384|0;e=d|0;f=d+256|0;g=d+264|0;j=d+272|0;k=d+296|0;l=d+304|0;m=d+320|0;n=c[b+44>>2]|0;o=n+28|0;if((c[o>>2]|0)==0){KIb(b,16,2477896,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=d;return q|0}r=+h[n+16>>3]*1.0e6+.5;s=(F=+r,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);t=n+8|0;c[t>>2]=~~+r>>>0;c[t+4>>2]=s;s=c[n+32>>2]|0;if((s|0)==0){u=d+280|0;v=(irc(c[c[b+4>>2]>>2]|0,2449784)|0)==0;w=c[n+36>>2]|0;Rb(u|0,16,2468312,(p=i,i=i+16|0,c[p>>2]=v?97:118,c[p+8>>2]=w,p)|0)|0;i=p;x=u}else{x=s}s=1;u=x;while(1){c[k>>2]=u;w=a[u]|0;if((w<<24>>24|0)==43){y=s+1|0}else if((w<<24>>24|0)==0){break}else{y=s}s=y;u=u+1|0}if(!((c[n+40>>2]|0)==1|(s|0)==1)){KIb(b,16,2458896,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1163346256;i=d;return q|0}qB();u=n+24|0;y=c[u>>2]|0;if((y|0)==0){z=0}else{z=iH(y)|0}y=n+44|0;c[y>>2]=0;w=oX(y,c[o>>2]|0,z,0)|0;if((w|0)<0){KIb(b,16,2442008,(p=i,i=i+8|0,c[p>>2]=c[o>>2],p)|0);i=p;q=w;i=d;return q|0}if((OX(c[y>>2]|0,0)|0)<0){KIb(b,24,2430128,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}w=c[t>>2]|0;z=c[t+4>>2]|0;v=0;do{if((z|0)>(v|0)|(z|0)==(v|0)&w>>>0>0>>>0){A=c[y>>2]|0;B=A+1056|0;C=c[B>>2]|0;D=c[B+4>>2]|0;do{if((C|0)==0&(D|0)==(-2147483648|0)){E=z;H=w}else{B=xrc(-1,2147483647,C,D)|0;I=G;if(!((z|0)>(I|0)|(z|0)==(I|0)&w>>>0>B>>>0)){B=wrc(C,D,w,z)|0;E=G;H=B;break}KIb(b,16,2419744,(p=i,i=i+40|0,c[p>>2]=c[o>>2],c[p+8>>2]=C,c[p+16>>2]=D,c[p+24>>2]=w,c[p+32>>2]=z,p)|0);i=p;q=-22;i=d;return q|0}}while(0);D=GX(A,-1,H,E,1)|0;if((D|0)>=0){break}KIb(b,16,2410552,(p=i,i=i+24|0,c[p>>2]=c[o>>2],c[p+8>>2]=H,c[p+16>>2]=E,p)|0);i=p;q=D;i=d;return q|0}}while(0);E=c[y>>2]|0;H=c[E+24>>2]|0;if((H|0)!=0){z=c[E+28>>2]|0;E=0;do{c[(c[z+(E<<2)>>2]|0)+76>>2]=48;E=E+1|0;}while(E>>>0<H>>>0)}H=qJb(s,8)|0;E=n+224|0;c[E>>2]=H;if((H|0)==0){q=-12;i=d;return q|0}H=(s|0)>0;a:do{if(H){z=b;w=g|0;v=n+220|0;D=0;C=x;while(1){B=HFb(C,2402888,k)|0;if((B|0)==0){q=-558323010;J=72;break}I=c[y>>2]|0;c[f>>2]=-1;K=Bd(B|0,2328024,(p=i,i=i+24|0,c[p>>2]=w,c[p+8>>2]=f,c[p+16>>2]=j,p)|0)|0;i=p;b:do{if((K-1|0)>>>0<2>>>0){L=(a[w]|0)!=118|0;M=WX(I,L,c[f>>2]|0,-1,0,0)|0;if((M|0)<0){N=ALb(L)|0;L=c[f>>2]|0;KIb(z,16,2322216,(p=i,i=i+16|0,c[p>>2]=N,c[p+8>>2]=L,p)|0);i=p;O=0;break}else{O=c[(c[I+28>>2]|0)+(M<<2)>>2]|0;break}}else{M=I+24|0;do{if((c[M>>2]|0)==0){P=0}else{L=I+28|0;N=0;S=0;T=0;c:while(1){U=vY(I,c[(c[L>>2]|0)+(N<<2)>>2]|0,B)|0;if((U|0)<0){J=38;break}do{if((U|0)==0){V=T;W=S}else{X=c[(c[L>>2]|0)+(N<<2)>>2]|0;if((c[X+76>>2]|0)==48){if((T|0)==0){V=X;W=S;break}else{J=43;break c}}else{V=T;W=S+1|0;break}}}while(0);U=N+1|0;if(U>>>0<(c[M>>2]|0)>>>0){N=U;S=W;T=V}else{J=45;break}}if((J|0)==38){J=0;KIb(z,16,2317112,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;O=0;break b}else if((J|0)==43){J=0;KIb(z,24,2312680,(p=i,i=i+16|0,c[p>>2]=B,c[p+8>>2]=N,p)|0);i=p;Y=T}else if((J|0)==45){J=0;if((V|0)==0){P=W;break}else{Y=V}}S=c[(c[Y+8>>2]|0)+8>>2]|0;if(S>>>0<2>>>0){O=Y;break b}L=ALb(S)|0;KIb(z,16,2284824,(p=i,i=i+16|0,c[p>>2]=B,c[p+8>>2]=L,p)|0);i=p;O=0;break b}}while(0);KIb(z,24,2308e3,(p=i,i=i+16|0,c[p>>2]=B,c[p+8>>2]=(P|0)!=0?2302896:2291680,p)|0);i=p;O=0}}while(0);if((O|0)==0){q=-22;J=72;break}c[O+76>>2]=0;c[(c[E>>2]|0)+(D<<3)>>2]=O;B=c[v>>2]|0;I=c[O>>2]|0;c[v>>2]=(B|0)>(I|0)?B:I;I=D+1|0;if((I|0)<(s|0)){D=I;C=0}else{break a}}if((J|0)==72){i=d;return q|0}}}while(0);if((HFb(0,2402888,k)|0)!=0){q=-558323010;i=d;return q|0}k=n+220|0;O=qJb((c[k>>2]|0)+1|0,4)|0;P=O;c[n+228>>2]=P;if((O|0)==0){q=-12;i=d;return q|0}if((c[k>>2]|0)>=0){O=0;do{c[P+(O<<2)>>2]=-1;O=O+1|0;}while((O|0)<=(c[k>>2]|0))}d:do{if(H){k=c[E>>2]|0;O=0;do{c[P+(c[c[k+(O<<3)>>2]>>2]<<2)>>2]=O;O=O+1|0;}while((O|0)<(s|0));if(!H){J=58;break}O=m;k=l|0;Y=m+4|0;V=m|0;W=m+48|0;f=m+44|0;j=b+40|0;y=b+28|0;x=b+32|0;g=b+36|0;C=b;D=e|0;v=0;e:while(1){mrc(O|0,0,60)|0;Rb(k|0,16,2395976,(p=i,i=i+8|0,c[p>>2]=v,p)|0)|0;i=p;c[Y>>2]=c[(c[(c[(c[E>>2]|0)+(v<<3)>>2]|0)+8>>2]|0)+8>>2];c[V>>2]=rJb(k)|0;c[W>>2]=1306;c[f>>2]=3014;Qi(v,j,4,y,x,m)|0;c[g>>2]=c[j>>2];z=(c[E>>2]|0)+(v<<3)|0;w=c5a(c[(c[(c[z>>2]|0)+8>>2]|0)+48>>2]|0)|0;if((w|0)==0){J=62;break}A=c[(c[z>>2]|0)+8>>2]|0;c[A+488>>2]=1;Z=_4a(A,w,0)|0;if((Z|0)<0){J=64;break}w=c[(c[(c[E>>2]|0)+(v<<3)>>2]|0)+8>>2]|0;do{if((c[(c[w+12>>2]|0)+8>>2]|0)==1){A=w+448|0;if(!((c[A>>2]|0)==0&(c[A+4>>2]|0)==0)){break}z=w+416|0;I=tGb(c[z>>2]|0)|0;B=G;_=c[z>>2]|0;if((I|0)==0&(B|0)==0){J=68;break e}sGb(D,256,_,I,B);KIb(C,24,2375400,(p=i,i=i+16|0,c[p>>2]=v,c[p+8>>2]=D,p)|0);i=p;c[A>>2]=I;c[A+4>>2]=B}}while(0);w=v+1|0;if((w|0)<(s|0)){v=w}else{$=C;break d}}if((J|0)==62){KIb(C,16,2368696,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=d;return q|0}else if((J|0)==64){KIb(C,16,2353816,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=Z;i=d;return q|0}else if((J|0)==68){KIb(C,16,2381984,(p=i,i=i+16|0,c[p>>2]=v,c[p+8>>2]=_,p)|0);i=p;q=-22;i=d;return q|0}}else{J=58}}while(0);if((J|0)==58){$=b}b=c[t+4>>2]|0;J=c[u>>2]|0;u=c[o>>2]|0;o=c[n+36>>2]|0;KIb($,40,2388968,(p=i,i=i+40|0,c[p>>2]=c[t>>2],c[p+8>>2]=b,c[p+16>>2]=J,c[p+24>>2]=u,c[p+32>>2]=o,p)|0);i=p;q=0;i=d;return q|0}function Al(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+44>>2]|0;d=a+40|0;if((c[d>>2]|0)==0){e=b+224|0}else{f=a+28|0;a=b+224|0;g=a;h=0;while(1){mJb((c[f>>2]|0)+(h*60|0)|0);i=c[(c[g>>2]|0)+(h<<3)>>2]|0;if((i|0)!=0){r5a(c[i+8>>2]|0)|0}i=h+1|0;if(i>>>0<(c[d>>2]|0)>>>0){h=i}else{e=a;break}}}mJb(e);mJb(b+228|0);VHb(b+216|0);e=b+44|0;if((c[e>>2]|0)==0){return}YX(e);return}function Bl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;c[d>>2]=0;c[d+4>>2]=-1;g=e;c[g>>2]=c[205466];c[g+4>>2]=c[205467];c[g+8>>2]=c[205468];c[g+12>>2]=c[205469];g=a+40|0;if((c[g>>2]|0)==0){i=b;return 0}h=f+224|0;f=a+32|0;a=d;d=e|0;e=0;do{j=c[(c[(c[h>>2]|0)+(e<<3)>>2]|0)+8>>2]|0;k=c[(c[f>>2]|0)+(e<<2)>>2]|0;l=c[j+8>>2]|0;if((l|0)==0){c[a>>2]=c[j+140>>2];Yk(Ok(a)|0,k+64|0)}else if((l|0)==1){c[a>>2]=c[j+420>>2];Yk(Ok(a)|0,k+64|0);c[a>>2]=c[j+412>>2];Yk(Ok(a)|0,k+72|0);l=j+448|0;j=c[l+4>>2]|0;c[d>>2]=c[l>>2];c[d+4>>2]=j;Xk(Pk(d)|0,k+80|0)}e=e+1|0;}while(e>>>0<(c[g>>2]|0)>>>0);i=b;return 0}function Cl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;d=(c[(c[b+44>>2]|0)+224>>2]|0)+((((c[a+4>>2]|0)-(c[b+28>>2]|0)|0)/60|0)<<3)|0;b=c[d>>2]|0;e=c[b+8>>2]|0;f=b+40|0;b=a+56|0;g=c[f+4>>2]|0;c[b>>2]=c[f>>2];c[b+4>>2]=g;if((c[e+8>>2]|0)!=0){return 0}c[a+20>>2]=c[e+120>>2];c[a+24>>2]=c[e+124>>2];e=(c[d>>2]|0)+412|0;d=a+116|0;a=c[e+4>>2]|0;c[d>>2]=c[e>>2];c[d+4>>2]=a;return 0}function Dl(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;d=i;i=i+136|0;e=d+64|0;f=c[b>>2]|0;g=((c[b+4>>2]|0)-(c[f+28>>2]|0)|0)/60|0;b=d+72|0;h=f+44|0;j=d|0;k=f+40|0;l=f;m=f+32|0;a:while(1){f=c[h>>2]|0;n=f+56|0;o=n;c[e>>2]=0;p=f+84|0;do{if((c[p>>2]|0)==0){q=f+48|0;if((c[q>>2]|0)==0){r=f+136|0;s=r;t=uX(c[f+44>>2]|0,s)|0;if((t|0)>=0){nrc(n|0,r|0,80)|0;break}J1(s);nrc(n|0,r|0,80)|0;if(!((t|0)==-541478725)){u=t;v=38;break a}c[q>>2]=1;continue a}t=f+224|0;r=c[t>>2]|0;if((c[r+(g<<3)+4>>2]|0)==0){c[f+88>>2]=c[c[r+(g<<3)>>2]>>2];break}w=f+40|0;if((c[w>>2]|0)==1){u=-541478725;v=38;break a}r=f+8|0;s=c[f+44>>2]|0;x=s+1056|0;y=c[x>>2]|0;z=c[x+4>>2]|0;x=(y|0)==0&(z|0)==(-2147483648|0);A=wrc(x?0:y,x?0:z,c[r>>2]|0,c[r+4>>2]|0)|0;B=GX(s,-1,A,G,1)|0;if((B|0)<0){v=9;break a}if((c[k>>2]|0)!=0){A=0;s=c[t>>2]|0;do{z5a(c[(c[s+(A<<3)>>2]|0)+8>>2]|0);s=c[t>>2]|0;c[s+(A<<3)+4>>2]=0;A=A+1|0;}while(A>>>0<(c[k>>2]|0)>>>0)}c[q>>2]=0;A=c[w>>2]|0;c[w>>2]=A-((A|0)>1);KIb(l,40,2345176,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;continue a}}while(0);n=c[f+88>>2]|0;do{if((n|0)<=(c[f+220>>2]|0)){A=c[(c[f+228>>2]|0)+(n<<2)>>2]|0;if((A|0)<0){break}s=c[f+224>>2]|0;t=c[(c[m>>2]|0)+(A<<2)>>2]|0;r=UHb()|0;z=f+216|0;c[z>>2]=r;if((r|0)==0){u=-12;v=38;break a}x=s+(A<<3)|0;y=c[(c[x>>2]|0)+8>>2]|0;D=c[y+8>>2]|0;if((D|0)==0){E=k5a(y,r,e,o)|0;v=24}else if((D|0)==1){E=n5a(y,r,e,o)|0;v=24}else{F=-38}do{if((v|0)==24){v=0;if((E|0)<0){F=E;break}do{if((E|0)==0){v=29}else{if((c[(c[(c[x>>2]|0)+8>>2]|0)+8>>2]|0)==0){v=29;break}H=E;I=c[p>>2]|0}}while(0);if((v|0)==29){v=0;r=c[p>>2]|0;H=r;I=r}r=f+80|0;c[r>>2]=(c[r>>2]|0)+H;y=I-H|0;c[p>>2]=y;if((y|0)<1){P1(f+136|0);c[p>>2]=0;c[r>>2]=0}if((c[e>>2]|0)!=0){r=zHb(c[z>>2]|0)|0;y=c[z>>2]|0;D=y+136|0;c[D>>2]=r;c[D+4>>2]=G;D=lj(t,y)|0;c[z>>2]=0;if((D|0)<0){u=D;v=38;break a}D=(A|0)==(g|0);if(D){u=D&1;v=38;break a}else{continue a}}if((H|0)==0){c[s+(A<<3)+4>>2]=1}VHb(z);continue a}}while(0);mrc(b|0,0,64)|0;a[b]=0;RGb(F,b,64)|0;KIb(l,24,2339128,(C=i,i=i+8|0,c[C>>2]=b,C)|0);i=C;VHb(z);P1(f+136|0);c[p>>2]=0;c[f+80>>2]=0;continue a}}while(0);P1(f+136|0);c[p>>2]=0;c[f+80>>2]=0}if((v|0)==9){mrc(j|0,0,64)|0;a[j]=0;RGb(B,j,64)|0;KIb(l,16,2333496,(C=i,i=i+8|0,c[C>>2]=j,C)|0);i=C;c[w>>2]=1;u=B;J=(u|0)>0;K=J?0:u;i=d;return K|0}else if((v|0)==38){J=(u|0)>0;K=J?0:u;i=d;return K|0}return 0}function El(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+120|0;c[b>>2]=0;c[b+4>>2]=-2147483648;return 0}function Fl(a){a=a|0;var b=0;b=a+156|0;c[b>>2]=c[b>>2]|1;return 0}function Gl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[e>>2]=b;h=c[a+8>>2]|0;j=c[h+44>>2]|0;k=j+144|0;if((c[k>>2]|0)!=0){VHb(e);l=0;i=d;return l|0}m=b+136|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((n|0)==0&(o|0)==(-2147483648|0)){m=j+136|0;p=c[m+4>>2]|0;q=c[m>>2]|0;r=b;s=m}else{c[f>>2]=1;c[f+4>>2]=c[a+48>>2];m=XIb(n,o,a+56|0,f)|0;p=G;q=m;r=c[e>>2]|0;s=j+136|0}m=r+76|0;f=c[m>>2]|0;o=f;n=(f|0)<0|0?-1:0;b=wrc(o,n,q,p)|0;t=G;c[s>>2]=b;c[s+4>>2]=t;s=j+88|0;u=c[s>>2]|0;v=c[s+4>>2]|0;s=0;do{if((v|0)<(s|0)|(v|0)==(s|0)&u>>>0<0>>>0){w=j+72|0;if((c[w>>2]|0)==0&(c[w+4>>2]|0)==(-2147483648|0)){x=0;y=0;z=13}else{A=1;B=n;C=o;z=10}}else{w=j+112|0;D=c[w>>2]|0;E=c[w+4>>2]|0;w=wrc(D,E,o,n)|0;F=G;if(!((F|0)>(v|0)|(F|0)==(v|0)&w>>>0>u>>>0)){A=1;B=n;C=o;z=10;break}w=xrc(u,v,D,E)|0;E=G;D=(n|0)>(E|0)|(n|0)==(E|0)&o>>>0>w>>>0;A=0;B=D?E:n;C=D?w:o;z=10}}while(0);do{if((z|0)==10){v=j+72|0;u=c[v>>2]|0;s=c[v+4>>2]|0;if(((q|0)!=0|(p|0)!=(-2147483648|0))&((u|0)!=0|(s|0)!=(-2147483648|0))&((t|0)>(s|0)|(t|0)==(s|0)&b>>>0>u>>>0)){v=xrc(u,s,q,p)|0;s=G;u=(B|0)>(s|0)|(B|0)==(s|0)&C>>>0>v>>>0;x=u?s:B;y=u?v:C;z=13;break}else{if((A|0)==0){x=B;y=C;z=13;break}else{H=f;break}}}}while(0);a:do{if((z|0)==13){C=j+120|0;B=c[C>>2]|0;A=c[C+4>>2]|0;if((B|0)==0&(A|0)==(-2147483648|0)){b=wrc(y,x,q,p)|0;t=G;c[C>>2]=b;c[C+4>>2]=t;I=t;J=b}else{I=A;J=B}B=j+96|0;A=c[B>>2]|0;b=c[B+4>>2]|0;do{if((A|0)==(-1|0)&(b|0)==2147483647){B=j+80|0;if(!((c[B>>2]|0)==0&(c[B+4>>2]|0)==(-2147483648|0))){K=1;L=0;M=0;z=20;break}B=j+128|0;if((c[B>>2]|0)==0&(c[B+4>>2]|0)==0){N=n;O=o}else{K=1;L=0;M=0;z=20}}else{B=j+112|0;t=c[B>>2]|0;C=c[B+4>>2]|0;if(!((C|0)<(b|0)|(C|0)==(b|0)&t>>>0<A>>>0)){K=1;L=0;M=0;z=20;break}B=xrc(A,b,t,C)|0;C=G;t=0;v=(C|0)<(t|0)|(C|0)==(t|0)&B>>>0<0>>>0;K=0;L=v?0:C;M=v?0:B;z=20}}while(0);b:do{if((z|0)==20){b=j+80|0;A=c[b>>2]|0;B=c[b+4>>2]|0;if(((q|0)!=0|(p|0)!=(-2147483648|0))&((A|0)!=0|(B|0)!=(-2147483648|0))&((p|0)<(B|0)|(p|0)==(B|0)&q>>>0<A>>>0)){b=xrc(A,B,q,p)|0;B=G;A=(L|0)>(B|0)|(L|0)==(B|0)&M>>>0>b>>>0;P=0;Q=A?L:B;R=A?M:b}else{P=K;Q=L;R=M}b=j+128|0;A=c[b>>2]|0;B=c[b+4>>2]|0;do{if(!((A|0)==0&(B|0)==0)){b=xrc(q,p,J,I)|0;v=G;if(!((v|0)<(B|0)|(v|0)==(B|0)&b>>>0<A>>>0)){break}b=xrc(A,B,q,p)|0;v=wrc(b,G,J,I)|0;b=G;C=(Q|0)>(b|0)|(Q|0)==(b|0)&R>>>0>v>>>0;N=C?Q:b;O=C?R:v;break b}}while(0);if((P|0)==0){N=Q;O=R;break}c[a+144>>2]=1;c[k>>2]=1;H=c[m>>2]|0;break a}}while(0);B=j+112|0;A=wrc(c[B>>2]|0,c[B+4>>2]|0,o,n)|0;c[B>>2]=A;c[B+4>>2]=G;B=0;A=(x|0)<(B|0)|(x|0)==(B|0)&y>>>0<0>>>0;B=A?0:y;v=A?0:x;A=(n|0)>(N|0)|(n|0)==(N|0)&o>>>0>O>>>0;C=A?O:o;b=A?N:n;do{if(!((v|0)<(b|0)|(v|0)==(b|0)&B>>>0<C>>>0)){if((B|0)==(C|0)&(v|0)==(b|0)&(f|0)==0){break}KIb(0,0,2430024,(A=i,i=i+24|0,c[A>>2]=2419584,c[A+8>>2]=2410424,c[A+16>>2]=323,A)|0);i=A;Hd();return 0}}while(0);if((B|0)==0&(v|0)==0){c[m>>2]=C;S=r;T=h+32|0}else{A=h+32|0;t=c[c[A>>2]>>2]|0;u=xrc(C,b,B,v)|0;s=oi(t,u)|0;if((s|0)==0){VHb(e);l=-12;i=d;return l|0}ZHb(s,c[e>>2]|0)|0;u=c[e>>2]|0;XKb(c[s+64>>2]|0,c[u+64>>2]|0,0,B,c[s+76>>2]|0,c[a+148>>2]|0,c[u+80>>2]|0)|0;u=s+136|0;if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==(-2147483648|0))){c[g>>2]=1;c[g+4>>2]=c[s+344>>2];t=XIb(B,v,g,a+56|0)|0;w=wrc(c[u>>2]|0,c[u+4>>2]|0,t,G)|0;c[u>>2]=w;c[u+4>>2]=G}VHb(e);c[e>>2]=s;S=s;T=A}l=lj(c[c[T>>2]>>2]|0,S)|0;i=d;return l|0}}while(0);S=j+112|0;j=wrc(c[S>>2]|0,c[S+4>>2]|0,H,(H|0)<0|0?-1:0)|0;c[S>>2]=j;c[S+4>>2]=G;VHb(e);l=0;i=d;return l|0}function Hl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0,q=0,r=0;b=i;i=i+8|0;d=b|0;e=d;f=i;i=i+8|0;g=i;i=i+8|0;j=i;i=i+8|0;k=c[(c[a+8>>2]|0)+44>>2]|0;if((c[a+16>>2]|0)==0){l=a+56|0;m=c[l+4>>2]|0;c[d>>2]=c[l>>2];c[d+4>>2]=m}else{m=c[a+48>>2]|0;c[d>>2]=1;c[e+4>>2]=m}n=+h[k+56>>3];if(n!=1.7976931348623157e+308){o=n*1.0e6;m=(F=+o,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);d=k+16|0;c[d>>2]=~~+o>>>0;c[d+4>>2]=m}o=+h[k+64>>3];if(o!=1.7976931348623157e+308){n=o*1.0e6;m=(F=+n,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);d=k+24|0;c[d>>2]=~~+n>>>0;c[d+4>>2]=m}n=+h[k+48>>3];if(n!=0.0){o=n*1.0e6;m=(F=+o,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);d=k+8|0;c[d>>2]=~~+o>>>0;c[d+4>>2]=m}m=k+16|0;d=c[m>>2]|0;a=c[m+4>>2]|0;do{if(!((d|0)==(-1|0)&(a|0)==2147483647)){c[f>>2]=1;c[f+4>>2]=1e6;m=XIb(d,a,f,e)|0;l=G;p=k+72|0;q=c[p>>2]|0;r=c[p+4>>2]|0;if(!((q|0)==0&(r|0)==(-2147483648|0)|((l|0)<(r|0)|(l|0)==(r|0)&m>>>0<q>>>0))){break}c[p>>2]=m;c[p+4>>2]=l}}while(0);f=k+24|0;a=c[f>>2]|0;d=c[f+4>>2]|0;do{if(!((a|0)==(-1|0)&(d|0)==2147483647)){c[g>>2]=1;c[g+4>>2]=1e6;f=XIb(a,d,g,e)|0;l=G;p=k+80|0;m=c[p>>2]|0;q=c[p+4>>2]|0;if(!((m|0)==0&(q|0)==(-2147483648|0)|((l|0)>(q|0)|(l|0)==(q|0)&f>>>0>m>>>0))){break}c[p>>2]=f;c[p+4>>2]=l}}while(0);g=k+8|0;d=c[g>>2]|0;a=c[g+4>>2]|0;if((d|0)==0&(a|0)==0){i=b;return 0}c[j>>2]=1;c[j+4>>2]=1e6;g=XIb(d,a,j,e)|0;e=k+128|0;c[e>>2]=g;c[e+4>>2]=G;i=b;return 0}function Il(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=g+144|0;if((c[h>>2]|0)!=0){VHb(e);j=0;i=d;return j|0}k=g+32|0;l=c[k>>2]|0;m=c[k+4>>2]|0;k=-1;n=g+72|0;o=c[n>>2]|0;p=c[n+4>>2]|0;if((m|0)>(k|0)|(m|0)==(k|0)&l>>>0>-1>>>0){k=g+104|0;n=c[k+4>>2]|0;q=((n|0)<(m|0)|(n|0)==(m|0)&(c[k>>2]|0)>>>0<l>>>0)&1;if((o|0)==0&(p|0)==(-2147483648|0)){r=q;s=7}else{t=q;s=6}}else{if((o|0)==0&(p|0)==(-2147483648|0)){s=8}else{t=1;s=6}}if((s|0)==6){q=b+136|0;l=c[q>>2]|0;k=c[q+4>>2]|0;r=(l|0)==0&(k|0)==(-2147483648|0)|((k|0)<(p|0)|(k|0)==(p|0)&l>>>0<o>>>0)?t:0;s=7}if((s|0)==7){if((r|0)==0){s=8}}a:do{if((s|0)==8){r=g+120|0;t=c[r>>2]|0;o=c[r+4>>2]|0;do{if((t|0)==0&(o|0)==(-2147483648|0)){l=b+136|0;p=c[l>>2]|0;k=c[l+4>>2]|0;if((p|0)==0&(k|0)==(-2147483648|0)){u=-2147483648;v=0;break}c[r>>2]=p;c[r+4>>2]=k;u=k;v=p}else{u=o;v=t}}while(0);t=g+40|0;o=c[t>>2]|0;r=c[t+4>>2]|0;t=g+80|0;p=c[t>>2]|0;k=c[t+4>>2]|0;do{if((o|0)==(-1|0)&(r|0)==2147483647){if(!((p|0)==0&(k|0)==(-2147483648|0))){w=1;s=15;break}t=g+128|0;if(!((c[t>>2]|0)==0&(c[t+4>>2]|0)==0)){x=1;s=16}}else{t=g+104|0;l=c[t+4>>2]|0;q=(l|0)>=(r|0)&((l|0)>(r|0)|(c[t>>2]|0)>>>0>=o>>>0)&1;if((p|0)==0&(k|0)==(-2147483648|0)){x=q;s=16}else{w=q;s=15}}}while(0);if((s|0)==15){o=b+136|0;r=c[o>>2]|0;q=c[o+4>>2]|0;x=((r|0)!=0|(q|0)!=(-2147483648|0))&((q|0)<(k|0)|(q|0)==(k|0)&r>>>0<p>>>0)?0:w;s=16}do{if((s|0)==16){r=g+128|0;q=c[r>>2]|0;o=c[r+4>>2]|0;do{if((q|0)==0&(o|0)==0){y=x}else{r=b+136|0;t=c[r>>2]|0;l=c[r+4>>2]|0;if((t|0)==0&(l|0)==(-2147483648|0)){y=x;break}r=xrc(t,l,v,u)|0;l=G;y=(l|0)<(o|0)|(l|0)==(o|0)&r>>>0<q>>>0?0:x}}while(0);if((y|0)==0){break}c[a+144>>2]=1;c[h>>2]=1;break a}}while(0);p=g+104|0;k=wrc(c[p>>2]|0,c[p+4>>2]|0,1,0)|0;c[p>>2]=k;c[p+4>>2]=G;j=lj(c[c[f+32>>2]>>2]|0,b)|0;i=d;return j|0}}while(0);b=g+104|0;g=wrc(c[b>>2]|0,c[b+4>>2]|0,1,0)|0;c[b>>2]=g;c[b+4>>2]=G;VHb(e);j=0;i=d;return j|0}function Jl(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;f=d|0;g=d+8|0;h=c[a+44>>2]|0;a=h+12|0;j=h+142|0;k=b[j>>1]|0;if(!(k<<16>>16==0)){l=h+140|0;m=k;do{k=a+((e[l>>1]|0)<<2)|0;n=c[k>>2]|0;b[j>>1]=m-1;c[k>>2]=0;b[l>>1]=(b[l>>1]|0)+1&31;c[g>>2]=n;VHb(g);m=b[j>>1]|0;}while(!(m<<16>>16==0))}m=h+144|0;j=h+274|0;g=b[j>>1]|0;if(g<<16>>16==0){i=d;return}l=h+272|0;h=g;do{g=m+((e[l>>1]|0)<<2)|0;a=c[g>>2]|0;b[j>>1]=h-1;c[g>>2]=0;b[l>>1]=(b[l>>1]|0)+1&31;c[f>>2]=a;VHb(f);h=b[j>>1]|0;}while(!(h<<16>>16==0));i=d;return}function Kl(a){a=a|0;var b=0,d=0,e=0;b=Ok(686920)|0;d=Ok(687176)|0;e=a+16|0;Yk(b,(c[c[e>>2]>>2]|0)+68|0);Yk(d,(c[(c[e>>2]|0)+4>>2]|0)+68|0);Yk(b,(c[c[a+32>>2]>>2]|0)+64|0);return 0}function Ll(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a>>2]|0;a=c[d+44>>2]|0;e=a;c[e>>2]=1;f=a+142|0;g=d+16|0;d=a+12|0;h=a+140|0;while(1){if((b[f>>1]|0)==0){i=0}else{i=(c[d+((b[h>>1]&31)<<2)>>2]|0)!=0|0}a=Wi(c[(c[g>>2]|0)+(i<<2)>>2]|0)|0;if((a|0)<0){j=a;k=6;break}if((c[e>>2]|0)==0){j=0;k=6;break}}if((k|0)==6){return j|0}return 0}function Ml(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a>>2]|0;e=c[d+16>>2]|0;f=c[e>>2]|0;g=c[e+4>>2]|0;e=c[f+20>>2]|0;h=c[g+20>>2]|0;j=f+24|0;k=c[j>>2]|0;l=c[g+24>>2]|0;if((e|0)==(h|0)&(k|0)==(l|0)){c[a+20>>2]=e;c[a+24>>2]=c[j>>2];j=f+56|0;g=a+56|0;m=c[j+4>>2]|0;c[g>>2]=c[j>>2];c[g+4>>2]=m;m=f+28|0;g=a+28|0;j=c[m+4>>2]|0;c[g>>2]=c[m>>2];c[g+4>>2]=j;j=f+116|0;f=a+116|0;a=c[j+4>>2]|0;c[f>>2]=c[j>>2];c[f+4>>2]=a;n=0;i=b;return n|0}else{KIb(d,16,2203112,(d=i,i=i+32|0,c[d>>2]=e,c[d+8>>2]=k,c[d+16>>2]=h,c[d+24>>2]=l,d)|0);i=d;n=-22;i=b;return n|0}return 0}function Nl(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+8|0;j=h|0;k=c[f+8>>2]|0;l=k+44|0;m=c[l>>2]|0;n=m+144|0;o=m+12|0;p=(c[(c[k+16>>2]|0)+4>>2]|0)==(f|0)?n:o;f=p+130|0;q=b[f>>1]|0;if(q<<16>>16==32){KIb(k,24,2120304,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=p+128|0;t=e[s>>1]|0;u=(b[f>>1]|0)-1&65535;b[f>>1]=u;VHb(p+(((u&65535)+t&31)<<2)|0);v=b[f>>1]|0;w=s}else{v=q;w=p+128|0}q=e[w>>1]|0;b[f>>1]=v+1;c[p+((q+(v&65535)&31)<<2)>>2]=g;g=m+142|0;v=m+140|0;q=m+274|0;p=m+272|0;f=m;m=k+32|0;k=0;while(1){w=b[g>>1]|0;if(w<<16>>16==0){x=k;y=23;break}s=e[v>>1]|0;if((c[o+((s&31)<<2)>>2]|0)==0){x=k;y=23;break}if((b[q>>1]|0)==0){x=k;y=23;break}if((c[n+((b[p>>1]&31)<<2)>>2]|0)==0){x=k;y=23;break}t=o+(s<<2)|0;s=c[t>>2]|0;b[g>>1]=w-1;c[t>>2]=0;b[v>>1]=(b[v>>1]|0)+1&31;t=b[q>>1]|0;if(t<<16>>16==0){y=10;break}w=n+(e[p>>1]<<2)|0;u=c[w>>2]|0;b[q>>1]=t-1;c[w>>2]=0;b[p>>1]=(b[p>>1]|0)+1&31;c[j>>2]=u;c[f>>2]=0;w=c[l>>2]|0;t=c[s+72>>2]|0;a:do{if((c[w+4>>2]|0)==0){z=c[s+44>>2]|0;A=c[u+32>>2]|0;B=u+72|0;if((t|0)<=0){break}C=s+12|0;D=u|0;E=(z|0)>(A|0)?A:z;F=0;do{if((F|0)>=(c[B>>2]|0)){break a}G=(c[C>>2]|0)+(ca(F,z)|0)|0;nrc(G|0,(c[D>>2]|0)+(ca(F,A)|0)|0,E)|0;F=F+1|0;}while((F|0)<(t|0))}else{if((t|0)<=0){break}F=u|0;E=u+32|0;A=s|0;D=s+32|0;z=w+11|0;C=s+68|0;B=0;G=c[C>>2]|0;while(1){if((G|0)>0){H=ca(c[D>>2]|0,B)|0;I=ca(c[E>>2]|0,B)|0;J=(c[F>>2]|0)+I|0;I=(c[A>>2]|0)+(H+(d[z]|0))|0;H=0;while(1){a[I]=a[J]|0;K=H+1|0;L=c[C>>2]|0;if((K|0)<(L|0)){J=J+1|0;I=I+4|0;H=K}else{M=L;break}}}else{M=G}H=B+1|0;if((H|0)<(t|0)){B=H;G=M}else{break}}}}while(0);t=lj(c[c[m>>2]>>2]|0,s)|0;VHb(j);if((t|0)>-1){k=t}else{x=t;y=23;break}}if((y|0)==10){KIb(0,0,2448800,(r=i,i=i+24|0,c[r>>2]=2359656,c[r+8>>2]=2295720,c[r+16>>2]=101,r)|0);i=r;Hd();return 0}else if((y|0)==23){i=h;return x|0}return 0}function Ol(a){a=a|0;var b=0;b=c[(c[a+8>>2]|0)+44>>2]|0;c[b+4>>2]=(Kz(b+8|0,c[a+52>>2]|0)|0)>>>31^1;return 0}function Pl(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;j=f+28|0;if((c[j>>2]|0)==0){k=0;i=b;return k|0}l=f+24|0;if(!(+g[l>>2]>0.0)){k=0;i=b;return k|0}m=a;KIb(m,24,2441712,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;if((ZGb(d,c[j>>2]|0,0,0,0,0,0,0,0,0,m)|0)<0){KIb(m,16,2429952,(a=i,i=i+8|0,c[a>>2]=c[j>>2],a)|0);i=a;k=-22;i=b;return k|0}else{AKb(e,+h[d>>3]/+g[l>>2],c[f+20>>2]|0);l=f+4|0;d=c[e>>2]|0;a=c[e+4>>2]|0;c[l>>2]=d;c[l+4>>2]=a;l=f+12|0;c[l>>2]=d;c[l+4>>2]=a;k=0;i=b;return k|0}return 0}function Ql(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+8|0;a=(c[(c[d>>2]|0)+44>>2]|0)+12|0;e=b+124|0;f=c[a+4>>2]|0;c[e>>2]=c[a>>2];c[e+4>>2]=f;return lj(c[c[(c[d>>2]|0)+32>>2]>>2]|0,b)|0}function Rl(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a+8|0;h=c[(c[f>>2]|0)+44>>2]|0;j=a+28|0;k=j;l=c[k>>2]|0;m=c[k+4>>2]|0;do{if((c[h+28>>2]|0)==0){n=4}else{if(!(+g[h+24>>2]>0.0)){n=4;break}o=h+12|0}}while(0);do{if((n|0)==4){p=h+12|0;q=Sl(a,p)|0;if((q|0)==0){o=p;break}else{r=q}i=b;return r|0}}while(0);n=o;q=c[n+4>>2]|0;c[k>>2]=c[n>>2];c[k+4>>2]=q;q=a+20|0;k=c[q>>2]|0;n=a+24|0;p=c[n>>2]|0;s=d|0;t=d+4|0;if((l|0)==0|(m|0)==0){xKb(s,t,k,(k|0)<0|0?-1:0,p,(p|0)<0|0?-1:0,2147483647,0)|0}else{d=ca(k,l)|0;k=ca(p,m)|0;xKb(s,t,d,(d|0)<0|0?-1:0,k,(k|0)<0|0?-1:0,2147483647,0)|0}k=c[q>>2]|0;d=c[n>>2]|0;p=c[o>>2]|0;o=c[h+16>>2]|0;h=e|0;u=e+4|0;if((p|0)==0|(o|0)==0){xKb(h,u,k,(k|0)<0|0?-1:0,d,(d|0)<0|0?-1:0,2147483647,0)|0}else{e=ca(p,k)|0;k=ca(o,d)|0;xKb(h,u,e,(e|0)<0|0?-1:0,k,(k|0)<0|0?-1:0,2147483647,0)|0}k=c[n>>2]|0;n=c[s>>2]|0;s=c[t>>2]|0;t=c[j>>2]|0;j=c[a+32>>2]|0;a=c[h>>2]|0;h=c[u>>2]|0;KIb(c[f>>2]|0,40,2566816,(f=i,i=i+80|0,c[f>>2]=c[q>>2],c[f+8>>2]=k,c[f+16>>2]=l,c[f+24>>2]=m,c[f+32>>2]=n,c[f+40>>2]=s,c[f+48>>2]=t,c[f+56>>2]=j,c[f+64>>2]=a,c[f+72>>2]=h,f)|0);i=f;r=0;i=b;return r|0}function Sl(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0;e=i;i=i+72|0;f=e|0;g=e+56|0;j=e+64|0;k=j;l=c[a+8>>2]|0;m=c[l+44>>2]|0;n=qKb(c[a+52>>2]|0)|0;o=+(c[a+20>>2]|0);p=f|0;h[p>>3]=o;q=+(c[a+24>>2]|0);h[f+8>>3]=q;r=o/q;h[f+16>>3]=r;s=c[a+28>>2]|0;if((s|0)==0){t=1.0}else{t=+(s|0)/+(c[a+32>>2]|0)}h[f+32>>3]=t;h[f+24>>3]=t*r;h[f+40>>3]=+(1<<(d[n+5|0]|0)|0);h[f+48>>3]=+(1<<(d[n+6|0]|0)|0);n=m+28|0;f=l;do{if((ZGb(g,c[n>>2]|0,281848,p,0,0,0,0,0,0,f)|0)<0){l=aKb(b,c[n>>2]|0,c[m+20>>2]|0,0,f)|0;if((l|0)>=0){u=c[b>>2]|0;break}KIb(f,16,2548480,(v=i,i=i+8|0,c[v>>2]=c[n>>2],v)|0);i=v;w=l;i=e;return w|0}else{AKb(k,+h[g>>3],c[m+20>>2]|0);l=b;a=c[j>>2]|0;s=c[j+4>>2]|0;c[l>>2]=a;c[l+4>>2]=s;u=a}}while(0);do{if((u|0)>=0){if((c[b+4>>2]|0)<1){break}else{w=0}i=e;return w|0}}while(0);KIb(f,16,2530720,(v=i,i=i+8|0,c[v>>2]=c[n>>2],v)|0);i=v;w=-22;i=e;return w|0}function Tl(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+8|0;d=b|0;e=a+8|0;f=c[(c[e>>2]|0)+44>>2]|0;h=a+28|0;j=h;k=c[j>>2]|0;l=c[j+4>>2]|0;do{if((c[f+28>>2]|0)==0){m=4}else{if(!(+g[f+24>>2]>0.0)){m=4;break}n=f+4|0}}while(0);do{if((m|0)==4){o=f+4|0;p=Sl(a,o)|0;if((p|0)==0){n=o;break}else{q=p}i=b;return q|0}}while(0);p=n;n=c[p>>2]|0;do{if((n|0)==0){m=8}else{o=f+8|0;r=c[o>>2]|0;if((r|0)==0){m=8;break}s=f+12|0;t=ca(c[a+24>>2]|0,n)|0;u=ca(c[a+20>>2]|0,r)|0;xKb(s,f+16|0,t,(t|0)<0|0?-1:0,u,(u|0)<0|0?-1:0,2147483647,0)|0;u=s;s=c[u+4>>2]|0;c[j>>2]=c[u>>2];c[j+4>>2]=s;v=o;w=p}}while(0);if((m|0)==8){c[a+28>>2]=1;c[a+32>>2]=1;v=a+24|0;w=a+20|0}m=c[v>>2]|0;v=c[w>>2]|0;w=a+20|0;p=c[w>>2]|0;j=a+24|0;f=c[j>>2]|0;n=d|0;o=d+4|0;if((k|0)==0|(l|0)==0){xKb(n,o,p,(p|0)<0|0?-1:0,f,(f|0)<0|0?-1:0,2147483647,0)|0}else{d=ca(p,k)|0;p=ca(f,l)|0;xKb(n,o,d,(d|0)<0|0?-1:0,p,(p|0)<0|0?-1:0,2147483647,0)|0}p=c[j>>2]|0;j=c[n>>2]|0;n=c[o>>2]|0;o=c[h>>2]|0;h=c[a+32>>2]|0;KIb(c[e>>2]|0,40,2402736,(e=i,i=i+80|0,c[e>>2]=c[w>>2],c[e+8>>2]=p,c[e+16>>2]=j,c[e+24>>2]=n,c[e+32>>2]=k,c[e+40>>2]=l,c[e+48>>2]=v,c[e+56>>2]=m,c[e+64>>2]=o,c[e+72>>2]=h,e)|0);i=e;q=0;i=b;return q|0}function Ul(a){a=a|0;dl(a,Ok(686712)|0);return 0}function Vl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+112|0;f=e|0;g=b+8|0;j=c[g>>2]|0;k=Jz(f,c[d>>2]|0,c[d+32>>2]|0,c[b+20>>2]|0,c[b+24>>2]|0,c[(c[j+44>>2]|0)+4>>2]|0)|0;l=f+4|0;m=f|0;n=(c[l>>2]|0)-(c[m>>2]|0)+1|0;o=f+12|0;p=f+8|0;f=(c[o>>2]|0)-(c[p>>2]|0)+1|0;q=j;j=b+160|0;r=c[j>>2]|0;s=c[j+4>>2]|0;j=e+48|0;mrc(j|0,0,32)|0;a[j]=0;t=d+136|0;u=c[t>>2]|0;v=c[t+4>>2]|0;if((u|0)==0&(v|0)==(-2147483648|0)){Rb(j|0,32,2530656,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0)|0;i=w}else{Rb(j|0,32,2501520,(w=i,i=i+16|0,c[w>>2]=u,c[w+8>>2]=v,w)|0)|0;i=w}v=e+80|0;mrc(v|0,0,32)|0;a[v]=0;u=c[t>>2]|0;x=c[t+4>>2]|0;if((u|0)==0&(x|0)==(-2147483648|0)){Rb(v|0,32,2530656,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0)|0;i=w}else{Rb(v|0,32,2515376,(w=i,i=i+8|0,h[w>>3]=(+(u>>>0)+ +(x|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),w)|0)|0;i=w}KIb(q,32,2244456,(w=i,i=i+32|0,c[w>>2]=r,c[w+8>>2]=s,c[w+16>>2]=j,c[w+24>>2]=v,w)|0);i=w;if((k|0)==0){KIb(q,32,2548472,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=c[g>>2]|0;z=y+32|0;A=c[z>>2]|0;B=c[A>>2]|0;C=lj(B,d)|0;i=e;return C|0}k=QHb(d)|0;v=e+16|0;Rb(v|0,32,2202936,(w=i,i=i+8|0,c[w>>2]=c[m>>2],w)|0)|0;i=w;MGb(k,2171152,v,0)|0;Rb(v|0,32,2202936,(w=i,i=i+8|0,c[w>>2]=c[l>>2],w)|0)|0;i=w;MGb(k,2143752,v,0)|0;Rb(v|0,32,2202936,(w=i,i=i+8|0,c[w>>2]=c[p>>2],w)|0)|0;i=w;MGb(k,2120208,v,0)|0;Rb(v|0,32,2202936,(w=i,i=i+8|0,c[w>>2]=c[o>>2],w)|0)|0;i=w;MGb(k,2638128,v,0)|0;Rb(v|0,32,2202936,(w=i,i=i+8|0,c[w>>2]=n,w)|0)|0;i=w;MGb(k,2615056,v,0)|0;Rb(v|0,32,2202936,(w=i,i=i+8|0,c[w>>2]=f,w)|0)|0;i=w;MGb(k,2588032,v,0)|0;v=c[m>>2]|0;m=c[l>>2]|0;l=c[p>>2]|0;p=c[o>>2]|0;KIb(q,32,2566744,(w=i,i=i+112|0,c[w>>2]=v,c[w+8>>2]=m,c[w+16>>2]=l,c[w+24>>2]=p,c[w+32>>2]=n,c[w+40>>2]=f,c[w+48>>2]=n,c[w+56>>2]=f,c[w+64>>2]=v,c[w+72>>2]=l,c[w+80>>2]=v,c[w+88>>2]=l,c[w+96>>2]=n,c[w+104>>2]=f,w)|0);i=w;KIb(q,32,2548472,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=c[g>>2]|0;z=y+32|0;A=c[z>>2]|0;B=c[A>>2]|0;C=lj(B,d)|0;i=e;return C|0}function Wl(a){a=a|0;dl(a,Ok(686648)|0);return 0}function Xl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;a=c[b+44>>2]|0;d=Wi(c[c[b+16>>2]>>2]|0)|0;if(!((d|0)==-541478725)){return d|0}if((c[a+48>>2]|0)==0){return d|0}e=a+40|0;f=c[e+4>>2]|0;g=a+32|0;c[g>>2]=c[e>>2];c[g+4>>2]=f;Yl(b);return d|0}function Yl(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+96|0;e=c[b+44>>2]|0;f=e+32|0;g=e+24|0;j=xrc(c[f>>2]|0,c[f+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;k=G;l=e+16|0;m=c[l+4>>2]|0;if((k|0)<(m|0)|(k|0)==(m|0)&j>>>0<(c[l>>2]|0)>>>0){i=d;return}l=c[c[b+16>>2]>>2]|0;b=d|0;mrc(b|0,0,32)|0;a[b]=0;j=c[g>>2]|0;m=c[g+4>>2]|0;k=l+56|0;if((j|0)==0&(m|0)==(-2147483648|0)){Rb(b|0,32,2566560,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0)|0;i=n}else{Rb(b|0,32,2548360,(n=i,i=i+8|0,h[n>>3]=(+(j>>>0)+ +(m|0)*4294967296.0)*(+(c[k>>2]|0)/+(c[l+60>>2]|0)),n)|0)|0;i=n}m=d+32|0;mrc(m|0,0,32)|0;a[m]=0;j=c[f>>2]|0;o=c[f+4>>2]|0;if((j|0)==0&(o|0)==(-2147483648|0)){Rb(m|0,32,2566560,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0)|0;i=n}else{Rb(m|0,32,2548360,(n=i,i=i+8|0,h[n>>3]=(+(j>>>0)+ +(o|0)*4294967296.0)*(+(c[k>>2]|0)/+(c[l+60>>2]|0)),n)|0)|0;i=n}o=d+64|0;mrc(o|0,0,32)|0;a[o]=0;j=xrc(c[f>>2]|0,c[f+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;g=G;if((j|0)==0&(g|0)==(-2147483648|0)){Rb(o|0,32,2566560,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0)|0;i=n}else{Rb(o|0,32,2548360,(n=i,i=i+8|0,h[n>>3]=(+(j>>>0)+ +(g|0)*4294967296.0)*(+(c[k>>2]|0)/+(c[l+60>>2]|0)),n)|0)|0;i=n}KIb(e,32,2587832,(n=i,i=i+24|0,c[n>>2]=b,c[n+8>>2]=m,c[n+16>>2]=o,n)|0);i=n;i=d;return}function Zl(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0;f=i;i=i+64|0;g=f|0;j=f+32|0;k=b+8|0;l=c[k>>2]|0;m=c[l+44>>2]|0;n=b+24|0;o=c[n>>2]|0;if((o|0)>0){p=b+20|0;q=e+32|0;r=m+72|0;s=m+76|0;t=c[e>>2]|0;u=0;v=c[p>>2]|0;w=o;while(1){if((v|0)>0){x=c[r>>2]|0;y=0;z=c[s>>2]|0;do{z=((d[t+y|0]|0)>>>0<=x>>>0)+z|0;c[s>>2]=z;y=y+1|0;A=c[p>>2]|0;}while((y|0)<(A|0));B=A;C=c[n>>2]|0}else{B=v;C=w}y=u+1|0;if((y|0)<(C|0)){t=t+(c[q>>2]|0)|0;u=y;v=B;w=C}else{D=C;E=B;F=s;break}}}else{D=o;E=c[b+20>>2]|0;F=m+76|0}G=+((c[F>>2]|0)>>>0>>>0)/+(ca(E,D)|0);D=b+160|0;E=c[D>>2]|0;o=c[D+4>>2]|0;D=g|0;mrc(D|0,0,32)|0;a[D]=0;g=e+136|0;s=c[g>>2]|0;B=c[g+4>>2]|0;if((s|0)==0&(B|0)==(-2147483648|0)){Rb(D|0,32,2566560,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Rb(D|0,32,2501392,(H=i,i=i+16|0,c[H>>2]=s,c[H+8>>2]=B,H)|0)|0;i=H}B=j|0;mrc(B|0,0,32)|0;a[B]=0;j=c[g>>2]|0;s=c[g+4>>2]|0;if((j|0)==0&(s|0)==(-2147483648|0)){Rb(B|0,32,2566560,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Rb(B|0,32,2548360,(H=i,i=i+8|0,h[H>>3]=(+(j>>>0)+ +(s|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),H)|0)|0;i=H}b=(BLb(c[e+88>>2]|0)|0)<<24>>24;KIb(l,48,2515216,(H=i,i=i+48|0,c[H>>2]=E,c[H+8>>2]=o,h[H+16>>3]=G,c[H+24>>2]=D,c[H+32>>2]=B,c[H+40>>2]=b,H)|0);i=H;H=m+48|0;b=(c[H>>2]|0)!=0;do{if(G<+h[m+56>>3]){if(!b){break}c[H>>2]=0;B=c[g+4>>2]|0;D=m+32|0;c[D>>2]=c[g>>2];c[D+4>>2]=B;Yl(l)}else{if(b){break}c[H>>2]=1;B=c[g+4>>2]|0;D=m+24|0;c[D>>2]=c[g>>2];c[D+4>>2]=B}}while(0);H=c[g+4>>2]|0;b=m+40|0;c[b>>2]=c[g>>2];c[b+4>>2]=H;c[F>>2]=0;F=lj(c[c[(c[k>>2]|0)+32>>2]>>2]|0,e)|0;i=f;return F|0}function _l(b){b=b|0;var d=0,e=0,f=0,g=0,j=0.0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0.0;d=i;i=i+32|0;e=c[(c[b+8>>2]|0)+44>>2]|0;f=b+56|0;g=b+60|0;j=+h[e+8>>3]/(+(c[f>>2]|0)/+(c[g>>2]|0));k=(F=+j,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);l=e+16|0;c[l>>2]=~~+j>>>0;c[l+4>>2]=k;k=(Nk(c[b+52>>2]|0,720)|0)==0;b=e+64|0;j=+h[b>>3];if(k){m=j*219.0+16.0}else{m=j*255.0}k=e+72|0;c[k>>2]=~~m;n=d|0;mrc(n|0,0,32)|0;a[n]=0;o=c[l>>2]|0;p=c[l+4>>2]|0;if((o|0)==0&(p|0)==(-2147483648|0)){Rb(n|0,32,2566560,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;r=+h[b>>3];s=c[k>>2]|0;t=e+56|0;u=t;v=+h[u>>3];KIb(e,40,2530480,(q=i,i=i+32|0,c[q>>2]=n,h[q+8>>3]=r,c[q+16>>2]=s,h[q+24>>3]=v,q)|0);i=q;i=d;return 0}else{Rb(n|0,32,2548360,(q=i,i=i+8|0,h[q>>3]=(+(o>>>0)+ +(p|0)*4294967296.0)*(+(c[f>>2]|0)/+(c[g>>2]|0)),q)|0)|0;i=q;r=+h[b>>3];s=c[k>>2]|0;t=e+56|0;u=t;v=+h[u>>3];KIb(e,40,2530480,(q=i,i=i+32|0,c[q>>2]=n,h[q+8>>3]=r,c[q+16>>2]=s,h[q+24>>3]=v,q)|0);i=q;i=d;return 0}return 0}function $l(a){a=a|0;dl(a,Ok(686608)|0);return 0}function am(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0;e=i;f=a+8|0;g=c[f>>2]|0;j=c[g+44>>2]|0;k=b+72|0;l=c[k>>2]|0;if((l|0)>0){m=a+20|0;n=b+32|0;o=j+8|0;p=j+16|0;q=0;r=c[b>>2]|0;s=c[m>>2]|0;t=l;while(1){if((s|0)>0){l=c[o>>2]|0;u=0;v=c[p>>2]|0;do{v=((d[r+u|0]|0|0)<(l|0))+v|0;c[p>>2]=v;u=u+1|0;w=c[m>>2]|0;}while((u|0)<(w|0));x=w;y=c[k>>2]|0}else{x=s;y=t}u=q+1|0;if((u|0)<(y|0)){q=u;r=r+(c[n>>2]|0)|0;s=x;t=y}else{break}}}if((c[b+84>>2]|0)!=0){c[j+20>>2]=c[j+12>>2]}y=j+16|0;t=(((c[y>>2]|0)*100|0)>>>0)/((ca(c[a+24>>2]|0,c[a+20>>2]|0)|0)>>>0)|0;if((t|0)<(c[j+4>>2]|0)){z=g;A=j+12|0;B=c[A>>2]|0;C=B+1|0;c[A>>2]=C;c[y>>2]=0;D=z+32|0;E=c[D>>2]|0;F=c[E>>2]|0;G=lj(F,b)|0;i=e;return G|0}x=j+12|0;s=c[x>>2]|0;n=b+136|0;r=c[n>>2]|0;q=c[n+4>>2]|0;if((r|0)==0&(q|0)==(-2147483648|0)){H=-1.0}else{H=(+(r>>>0)+ +(q|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}a=(BLb(c[b+88>>2]|0)|0)<<24>>24;n=c[j+20>>2]|0;KIb(g,32,2143224,(g=i,i=i+56|0,c[g>>2]=s,c[g+8>>2]=t,c[g+16>>2]=r,c[g+24>>2]=q,h[g+32>>3]=H,c[g+40>>2]=a,c[g+48>>2]=n,g)|0);i=g;z=c[f>>2]|0;A=x;B=c[A>>2]|0;C=B+1|0;c[A>>2]=C;c[y>>2]=0;D=z+32|0;E=c[D>>2]|0;F=c[E>>2]|0;G=lj(F,b)|0;i=e;return G|0}function bm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+44>>2]|0;d=b+480|0;e=b+464|0;f=b+472|0;g=b+460|0;i=a;a=0;a:while(1){j=d+(a<<5)|0;k=c[e>>2]|0;if((k|0)>-1){c[j>>2]=k}l=+h[f>>3];if(l<1.0){h[d+(a<<5)+8>>3]=l}switch(c[j>>2]|0){case 18:{c[d+(a<<5)+24>>2]=2;break};case 19:{c[d+(a<<5)+24>>2]=52;break};case 22:{c[d+(a<<5)+24>>2]=48;break};case 1:{c[d+(a<<5)+24>>2]=14;break};case 10:{c[d+(a<<5)+24>>2]=70;break};case 2:{c[d+(a<<5)+24>>2]=66;break};case 20:{c[d+(a<<5)+24>>2]=64;break};case 21:{c[d+(a<<5)+24>>2]=42;break};case 6:{c[d+(a<<5)+24>>2]=26;break};case 23:{c[d+(a<<5)+24>>2]=46;break};case 8:{c[d+(a<<5)+24>>2]=20;break};case 4:{c[d+(a<<5)+24>>2]=58;break};case 11:{c[d+(a<<5)+24>>2]=8;break};case 14:{c[d+(a<<5)+24>>2]=4;break};case 15:{c[d+(a<<5)+24>>2]=44;break};case 5:{c[d+(a<<5)+24>>2]=36;break};case 12:{c[d+(a<<5)+24>>2]=50;break};case 13:{c[d+(a<<5)+24>>2]=40;break};case 0:{c[d+(a<<5)+24>>2]=54;break};case 16:{c[d+(a<<5)+24>>2]=18;break};case 17:{c[d+(a<<5)+24>>2]=38;break};case 9:{c[d+(a<<5)+24>>2]=72;break};case 3:{c[d+(a<<5)+24>>2]=28;break};case 7:{c[d+(a<<5)+24>>2]=16;break};default:{}}j=c[g>>2]|0;k=d+(a<<5)+20|0;m=c[k>>2]|0;n=(m|0)==0;do{if((j|0)==0){if(!n){o=m;p=35}}else{if(!n){o=m;p=35;break}q=rJb(j)|0;c[k>>2]=q;if((q|0)==0){r=-12;p=39;break a}else{o=q;p=35}}}while(0);if((p|0)==35){p=0;k=UGb(d+(a<<5)+16|0,o,281792,0,0,0,0,0,i)|0;if((k|0)<0){r=k;p=39;break}c[d+(a<<5)+24>>2]=22}k=a+1|0;if(k>>>0<4>>>0){a=k}else{p=38;break}}if((p|0)==38){c[b+432>>2]=318;r=0;return r|0}else if((p|0)==39){return r|0}return 0}function cm(a){a=a|0;var b=0;b=c[a+44>>2]|0;Vz(b+8|0);TGb(c[b+496>>2]|0);TGb(c[b+528>>2]|0);TGb(c[b+560>>2]|0);TGb(c[b+592>>2]|0);return}function dm(a){a=a|0;dl(a,Ok(686536)|0);return 0}function em(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)<(l|0)&(j|0)>0){p=g;q=e;r=b;s=k}else{return}while(1){k=0;do{b=d[r+k|0]|0;e=(d[q+k|0]|0)+b|0;a[p+k|0]=~~(+(b|0)+o*+(((e|0)<255?e:255)-b|0));k=k+1|0;}while((k|0)<(j|0));k=s+1|0;if((k|0)<(l|0)){p=p+i|0;q=q+f|0;r=r+c|0;s=k}else{break}}return}function fm(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0,r=0;n=+h[l+8>>3];if((j|0)<(k|0)&(i|0)>0){o=f;p=d;q=b;r=j}else{return}while(1){j=0;do{b=a[q+j|0]|0;d=b&255;a[o+j|0]=~~(+(d|0)+n*+((a[p+j|0]&b&255)-d|0));j=j+1|0;}while((j|0)<(i|0));j=r+1|0;if((j|0)<(k|0)){o=o+g|0;p=p+e|0;q=q+c|0;r=j}else{break}}return}function gm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)<(l|0)&(j|0)>0){p=g;q=e;r=b;s=k}else{return}while(1){k=0;do{b=d[r+k|0]|0;a[p+k|0]=~~(+(b|0)+o*+((((d[q+k|0]|0)+b|0)>>>1)-b|0));k=k+1|0;}while((k|0)<(j|0));k=s+1|0;if((k|0)<(l|0)){p=p+i|0;q=q+f|0;r=r+c|0;s=k}else{break}}return}function hm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=p&255;if(p<<24>>24==0){r=q}else{p=255-((((d[g+k|0]|0)<<8^65280)>>>0)/(q>>>0)|0)|0;r=(p|0)<0?0:p}a[n+k|0]=~~(+(q|0)+o*+(r-q|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function im(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0,r=0;n=+h[l+8>>3];if((j|0)<(k|0)&(i|0)>0){o=f;p=d;q=b;r=j}else{return}while(1){j=0;do{b=a[q+j|0]|0;d=b&255;f=a[p+j|0]|0;a[o+j|0]=~~(+(d|0)+n*+((((b&255)>>>0>(f&255)>>>0?f:b)&255)-d|0));j=j+1|0;}while((j|0)<(i|0));j=r+1|0;if((j|0)<(k|0)){o=o+g|0;p=p+e|0;q=q+c|0;r=j}else{break}}return}function jm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=p-(d[g+k|0]|0)|0;a[n+k|0]=~~(+(p|0)+o*+(((q|0)>-1?q:-q|0)-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function km(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=p&255;a[n+k|0]=~~(+(q|0)+o*(+((p&255)>>>0)/+((d[g+k|0]|0)>>>0)*255.0- +(q|0)));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function lm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=p&255;if(p<<24>>24==-1){r=q}else{p=((d[g+k|0]|0)<<8>>>0)/((q^255)>>>0)|0;r=p>>>0<255>>>0?p:255}a[n+k|0]=~~(+(q|0)+o*+(r-q|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function mm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=d[g+k|0]|0;a[n+k|0]=~~(+(p|0)+o*+(q-(((ca(p<<1,q)|0)>>>0)/255|0)|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function nm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=a[g+k|0]|0;r=q&255;if(q<<24>>24>-1){s=(((ca(r,p)|0)>>>0)/255|0)<<1}else{s=255-((((ca(r^255,p^255)|0)>>>0)/255|0)<<1)|0}a[n+k|0]=~~(+(p|0)+o*+(s-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function om(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;q=a[f+j|0]|0;a[m+j|0]=~~(+(p|0)+n*+((((o&255)>>>0>(q&255)>>>0?o:q)&255)-p|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function pm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;a[n+k|0]=~~(+(p|0)+o*+((((ca(d[g+k|0]|0,p)|0)>>>0)/255|0)-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function qm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=p^255;r=q-(d[g+k|0]|0)|0;a[n+k|0]=~~(+(p|0)+o*+(q-((r|0)>-1?r:-r|0)|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function rm(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;uIb(e,f,a,b,g,i-h|0);return}function sm(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;a[m+j|0]=~~(+(p|0)+n*+(((a[f+j|0]|o)&255)-p|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function tm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=p&255;if(p<<24>>24>-1){r=(((ca(d[g+k|0]|0,q)|0)>>>0)/255|0)<<1}else{r=255-((((ca((d[g+k|0]|0)^255,q^255)|0)>>>0)/255|0)<<1)|0}a[n+k|0]=~~(+(q|0)+o*+(r-q|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function um(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0,r=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;q=a[f+j|0]|0;r=(o&255)>>>0>(q&255)>>>0;a[m+j|0]=~~(+(p|0)+n*+((p^255)-((r?o:q)&255)+((r?q:o)&255)|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function vm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=a[g+k|0]|0;r=(q&255)<<1;if(q<<24>>24>-1){s=p>>>0>r>>>0?r:p}else{q=r-256|0;s=(p|0)>(q|0)?p:q}a[n+k|0]=~~(+(p|0)+o*+(s-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function wm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0,r=0,s=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=a[g+k|0]|0;r=q&255;if(q<<24>>24==-1){s=r}else{q=((ca(p,p)|0)>>>0)/((r^255)>>>0)|0;s=q>>>0<255>>>0?q:255}a[n+k|0]=~~(+(p|0)+o*+(s-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function xm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=p^255;a[n+k|0]=~~(+(p|0)+o*+(q-(((ca((d[g+k|0]|0)^255,q)|0)>>>0)/255|0)|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function ym(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0.0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=a[e+k|0]|0;q=+(p&255|0);r=d[g+k|0]|0;s=+(r|0);if(p<<24>>24<0){t=s+ -127.5;if(t<0.0){u=-0.0-t}else{u=t}v=s+(q+ -127.5)*+(r^255|0)/127.5*(.5-u/255.0)}else{t=s+ -127.5;if(t<0.0){w=-0.0-t}else{w=t}v=s-s*((127.5-q)/127.5)*(.5-w/255.0)}a[n+k|0]=~~(q+o*(v-q));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function zm(b,c,e,f,g,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0.0,p=0,q=0;o=+h[m+8>>3];if((k|0)>=(l|0)){return}m=(j|0)>0;n=g;g=e;e=b;b=k;while(1){if(m){k=0;do{p=d[e+k|0]|0;q=p-(d[g+k|0]|0)|0;a[n+k|0]=~~(+(p|0)+o*+(((q|0)<0?0:q)-p|0));k=k+1|0;}while((k|0)<(j|0))}k=b+1|0;if((k|0)<(l|0)){n=n+i|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function Am(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;q=+(p|0);r=a[f+j|0]|0;s=r&255;do{if(r<<24>>24>-1){if(o<<24>>24==0){t=p;break}u=255-((255-(s<<1)<<8|0)/(p|0)|0)|0;t=(u|0)<0?0:u}else{if(o<<24>>24==-1){t=p;break}u=((s<<9)-65536|0)/(p^255|0)|0;t=(u|0)<255?u:255}}while(0);a[m+j|0]=~~(q+n*+(t-p|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function Bm(b,c,d,e,f,g,i,j,k,l,m){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0.0,o=0,p=0;n=+h[l+8>>3];if((j|0)>=(k|0)){return}l=(i|0)>0;m=f;f=d;d=b;b=j;while(1){if(l){j=0;do{o=a[d+j|0]|0;p=o&255;a[m+j|0]=~~(+(p|0)+n*+(((a[f+j|0]^o)&255)-p|0));j=j+1|0;}while((j|0)<(i|0))}j=b+1|0;if((j|0)<(k|0)){m=m+g|0;f=f+e|0;d=d+c|0;b=j}else{break}}return}function Cm(b,e,f,g,i,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;p=c[n+16>>2]|0;if((l|0)>=(m|0)){return}n=o+8|0;q=(k|0)>0;r=o+64|0;s=o+80|0;t=o+72|0;u=o+88|0;v=i;i=f;f=b;b=l;while(1){h[n>>3]=+(b|0);if(q){l=0;do{h[o>>3]=+(l|0);w=+((d[f+l|0]|0)>>>0);h[r>>3]=w;h[s>>3]=w;w=+((d[i+l|0]|0)>>>0);h[t>>3]=w;h[u>>3]=w;a[v+l|0]=~~+XGb(p,o,0);l=l+1|0;}while((l|0)<(k|0))}l=b+1|0;if((l|0)<(m|0)){v=v+j|0;i=i+g|0;f=f+e|0;b=l}else{break}}return}function Dm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+40|0;f=e|0;g=e+8|0;c[f>>2]=b;h=c[a+44>>2]|0;j=c[c[a+16>>2]>>2]|0;k=c[c[a+32>>2]>>2]|0;l=bv(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((l|0)==0){m=b;i=e;return m|0}ZHb(l,b)|0;b=h+456|0;if((c[b>>2]|0)>0){k=h+448|0;n=h+452|0;o=l+68|0;p=l+72|0;q=h+480|0;h=g|0;r=g+4|0;s=g+8|0;t=g+12|0;u=g+16|0;v=g+20|0;w=g+24|0;x=g+28|0;y=a+56|0;z=g;g=a+48|0;A=0;do{if((A-1|0)>>>0<2>>>0){B=c[n>>2]|0;C=c[k>>2]|0}else{B=0;C=0}D=-(-(c[o>>2]|0)>>C)|0;E=-(-(c[p>>2]|0)>>B)|0;c[h>>2]=c[f>>2];c[r>>2]=d;c[s>>2]=l;c[t>>2]=j;c[u>>2]=A;c[v>>2]=D;c[w>>2]=E;c[x>>2]=q+(A<<5);D=c[(c[g>>2]|0)+28>>2]|0;Xe[c[c[y>>2]>>2]&511](a,366,z,0,(D|0)<(E|0)?D:E)|0;A=A+1|0;}while((A|0)<(c[b>>2]|0))}VHb(f);m=l;i=e;return m|0}function Em(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0.0,w=0.0;a=i;i=i+96|0;f=a|0;g=c[b+24>>2]|0;j=(ca(g,d)|0)/(e|0)|0;k=(ca(g,d+1|0)|0)/(e|0)|0;e=c[b+16>>2]|0;d=c[b>>2]|0;l=c[d+(e<<2)>>2]|0;m=c[b+4>>2]|0;n=c[m+(e<<2)>>2]|0;o=c[b+8>>2]|0;p=c[o+(e<<2)>>2]|0;q=c[b+12>>2]|0;s=q+160|0;h[f+56>>3]=+((c[s>>2]|0)>>>0)+ +(c[s+4>>2]|0)*4294967296.0;s=o+136|0;t=c[s>>2]|0;u=c[s+4>>2]|0;if((t|0)==0&(u|0)==(-2147483648|0)){v=+r}else{v=(+(t>>>0)+ +(u|0)*4294967296.0)*(+(c[q+56>>2]|0)/+(c[q+60>>2]|0))}h[f+48>>3]=v;q=c[b+20>>2]|0;v=+(q|0);h[f+16>>3]=v;w=+(g|0);h[f+24>>3]=w;h[f+32>>3]=v/+(c[o+68>>2]|0);h[f+40>>3]=w/+(c[o+72>>2]|0);g=c[b+28>>2]|0;b=c[d+32+(e<<2)>>2]|0;d=l+(ca(b,j)|0)|0;l=c[m+32+(e<<2)>>2]|0;m=n+(ca(l,j)|0)|0;n=c[o+32+(e<<2)>>2]|0;e=p+(ca(n,j)|0)|0;we[c[g+24>>2]&127](d,b,m,l,e,n,q,j,k,g,f|0);i=a;return 0}function Fm(a){a=a|0;return Uz((c[(c[a>>2]|0)+44>>2]|0)+8|0,a)|0}function Gm(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;e=c[a>>2]|0;f=c[e+16>>2]|0;g=c[f>>2]|0;h=c[f+4>>2]|0;f=c[e+44>>2]|0;j=g+52|0;k=qKb(c[j>>2]|0)|0;if((c[j>>2]|0)!=(c[h+52>>2]|0)){KIb(e,16,2159776,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=b;return m|0}n=c[g+20>>2]|0;o=c[h+20>>2]|0;p=g+24|0;q=c[p>>2]|0;r=c[h+24>>2]|0;do{if((n|0)==(o|0)&(q|0)==(r|0)){s=g+28|0;if((c[s>>2]|0)!=(c[h+28>>2]|0)){t=q;break}if((c[g+32>>2]|0)!=(c[h+32>>2]|0)){t=q;break}c[a+20>>2]=n;c[a+24>>2]=c[p>>2];u=g+56|0;v=a+56|0;w=c[u+4>>2]|0;c[v>>2]=c[u>>2];c[v+4>>2]=w;w=s;s=a+28|0;v=c[w+4>>2]|0;c[s>>2]=c[w>>2];c[s+4>>2]=v;v=g+116|0;s=a+116|0;w=c[v+4>>2]|0;c[s>>2]=c[v>>2];c[s+4>>2]=w;c[f+448>>2]=d[k+5|0]|0;c[f+452>>2]=d[k+6|0]|0;c[f+456>>2]=uKb(c[j>>2]|0)|0;w=Rz(e,f+8|0)|0;m=(w|0)<0?w:0;i=b;return m|0}else{t=r}}while(0);r=c[e+12>>2]|0;f=c[g+28>>2]|0;j=c[g+32>>2]|0;g=c[r+60>>2]|0;k=c[h+28>>2]|0;a=c[h+32>>2]|0;KIb(e,16,2157864,(l=i,i=i+80|0,c[l>>2]=c[r>>2],c[l+8>>2]=n,c[l+16>>2]=q,c[l+24>>2]=f,c[l+32>>2]=j,c[l+40>>2]=g,c[l+48>>2]=o,c[l+56>>2]=t,c[l+64>>2]=k,c[l+72>>2]=a,l)|0);i=l;m=-22;i=b;return m|0}function Hm(a,b){a=a|0;b=b|0;return Tz((c[(c[a+8>>2]|0)+44>>2]|0)+8|0,a,b)|0}function Im(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=d+12|0;f=c[e>>2]|0;if((f|0)==0){KIb(a,16,2445624,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-22;i=b;return g|0}a=d+24|0;do{if((c[a>>2]|0)==0){h=rJb(f)|0;c[a>>2]=h;if((h|0)==0){g=-12}else{break}i=b;return g|0}}while(0);a=d+20|0;if((c[a>>2]|0)<0){c[a>>2]=c[d+8>>2]}a=d+36|0;do{if((c[a>>2]|0)==0){f=rJb(c[e>>2]|0)|0;c[a>>2]=f;if((f|0)==0){g=-12}else{break}i=b;return g|0}}while(0);a=d+32|0;if((c[a>>2]|0)>=0){g=0;i=b;return g|0}c[a>>2]=c[d+8>>2];g=0;i=b;return g|0}function Jm(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+80|0);mJb(b+84|0);return}function Km(a){a=a|0;dl(a,Ok(686480)|0);return 0}function Lm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+40|0;f=e|0;g=e+8|0;h=e+24|0;c[f>>2]=d;j=c[b+8>>2]|0;k=c[j+44>>2]|0;l=c[c[j+32>>2]>>2]|0;j=c[b+20>>2]|0;b=-(-j>>c[k+40>>2])|0;m=c[d+72>>2]|0;n=-(-m>>c[k+44>>2])|0;c[g>>2]=j;c[g+4>>2]=b;c[g+8>>2]=b;c[g+12>>2]=j;c[h>>2]=m;c[h+4>>2]=n;c[h+8>>2]=n;c[h+12>>2]=m;m=bv(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((m|0)==0){VHb(f);o=-12;i=e;return o|0}ZHb(m,d)|0;d=k+48|0;n=k+64|0;j=k+80|0;b=k+84|0;k=0;while(1){p=c[f>>2]|0;q=c[p+(k<<2)>>2]|0;if((q|0)==0){r=0;break}s=c[p+32+(k<<2)>>2]|0;if((s|0)==0){r=0;break}p=c[m+(k<<2)>>2]|0;t=c[m+32+(k<<2)>>2]|0;u=c[g+(k<<2)>>2]|0;v=c[h+(k<<2)>>2]|0;w=c[d+(k<<2)>>2]|0;x=c[n+(k<<2)>>2]|0;y=(w|0)==0;a:do{if((v|0)>0&(y&(p|0)==(q|0)^1)){z=(u|0)>0;A=(x|0)>2;B=(x|0)>1;if(y|(x|0)==0){if(z){C=0}else{break}while(1){D=ca(C,t)|0;E=ca(C,s)|0;F=0;do{a[p+(F+D)|0]=a[q+(F+E)|0]|0;F=F+1|0;}while((F|0)<(u|0));C=C+1|0;if((C|0)>=(v|0)){break a}}}else{G=0}do{F=ca(G,t)|0;E=p+F|0;D=c[j>>2]|0;H=q+(ca(G,s)|0)|0;I=c[b>>2]|0;Nm(D,1,H,1,u,w);do{if(A){H=D;J=I;K=x;while(1){Nm(J,1,H,1,u,w);L=K-1|0;if((L|0)>2){M=H;H=J;K=L;J=M}else{N=J;O=16;break}}}else{if(B){N=D;O=16;break}if(z){P=0}else{break}do{a[p+(P+F)|0]=a[D+P|0]|0;P=P+1|0;}while((P|0)<(u|0))}}while(0);if((O|0)==16){O=0;Nm(E,1,N,1,u,w)}G=G+1|0;}while((G|0)<(v|0))}}while(0);v=k+1|0;if((v|0)<4){k=v}else{r=0;break}}do{k=c[f>>2]|0;if((c[k+(r<<2)>>2]|0)==0){break}if((c[k+32+(r<<2)>>2]|0)==0){break}k=c[m+(r<<2)>>2]|0;G=c[m+32+(r<<2)>>2]|0;N=c[g+(r<<2)>>2]|0;O=c[h+(r<<2)>>2]|0;P=c[d+(r<<2)>>2]|0;C=c[n+(r<<2)>>2]|0;v=(P|0)==0;if((N|0)>0&(v^1)){w=v|(C|0)==0;v=(O|0)>0;u=(C|0)>2;p=(C|0)>1;x=0;do{s=k+x|0;q=c[j>>2]|0;b:do{if(!w){t=c[b>>2]|0;Nm(q,1,s,G,O,P);do{if(u){y=q;z=t;B=C;while(1){Nm(z,1,y,1,O,P);A=B-1|0;if((A|0)>2){D=y;y=z;B=A;z=D}else{Q=z;break}}}else{if(p){Q=q;break}if(v){R=0}else{break b}while(1){a[k+((ca(R,G)|0)+x)|0]=a[q+R|0]|0;R=R+1|0;if((R|0)>=(O|0)){break b}}}}while(0);Nm(s,G,Q,1,O,P)}}while(0);x=x+1|0;}while((x|0)<(N|0))}r=r+1|0;}while((r|0)<4);VHb(f);o=lj(l,m)|0;i=e;return o|0}function Mm(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+56|0;e=b|0;f=b+48|0;g=qKb(c[a+52>>2]|0)|0;j=c[a+8>>2]|0;k=c[j+44>>2]|0;l=a+20|0;m=c[l>>2]|0;n=a+24|0;a=c[n>>2]|0;o=(m|0)>(a|0);p=o?m:a;q=hJb(p)|0;c[k+80>>2]=q;if((q|0)==0){r=-12;i=b;return r|0}q=hJb(p)|0;c[k+84>>2]=q;if((q|0)==0){r=-12;i=b;return r|0}q=d[g+5|0]|0;c[k+40>>2]=q;p=d[g+6|0]|0;c[k+44>>2]=p;g=e|0;h[g>>3]=+(c[l>>2]|0);h[e+8>>3]=+(c[n>>2]|0);n=m>>q;h[e+16>>3]=+(n|0);l=a>>p;h[e+24>>3]=+(l|0);h[e+32>>3]=+(1<<q|0);h[e+40>>3]=+(1<<p|0);p=c[k+12>>2]|0;e=j;j=ZGb(f,p,281760,g,0,0,0,0,0,0,e)|0;q=k+4|0;c[q>>2]=~~+h[f>>3];if((j|0)<0){KIb(0,16,2429440,(s=i,i=i+8|0,c[s>>2]=p,s)|0);i=s;r=j;i=b;return r|0}j=c[k+24>>2]|0;p=ZGb(f,j,281760,g,0,0,0,0,0,0,e)|0;t=k+16|0;c[t>>2]=~~+h[f>>3];if((p|0)<0){KIb(0,16,2418976,(s=i,i=i+8|0,c[s>>2]=j,s)|0);i=s;r=p;i=b;return r|0}p=c[k+36>>2]|0;j=ZGb(f,p,281760,g,0,0,0,0,0,0,e)|0;g=~~+h[f>>3];f=k+28|0;c[f>>2]=g;if((j|0)<0){KIb(0,16,2409992,(s=i,i=i+8|0,c[s>>2]=p,s)|0);i=s;r=j;i=b;return r|0}j=k+8|0;p=c[j>>2]|0;u=c[t>>2]|0;v=k+20|0;w=c[v>>2]|0;x=k+32|0;y=c[x>>2]|0;KIb(e,40,2402240,(s=i,i=i+80|0,c[s>>2]=c[q>>2],c[s+8>>2]=p,c[s+16>>2]=u,c[s+24>>2]=w,c[s+32>>2]=g,c[s+40>>2]=y,c[s+48>>2]=m,c[s+56>>2]=n,c[s+64>>2]=a,c[s+72>>2]=l,s)|0);i=s;y=c[q>>2]|0;do{if((y|0)<0){z=o?a:m}else{q=o?a:m;if((y<<1|0)>(q|0)){z=q;break}g=c[t>>2]|0;do{if((g|0)>=0){if((g<<1|0)>(((n|0)>(l|0)?l:n)|0)){break}w=c[f>>2]|0;if((w|0)<0|(w<<1|0)>(q|0)){KIb(e,16,2381424,(s=i,i=i+16|0,c[s>>2]=w,c[s+8>>2]=(q|0)/2|0,s)|0);i=s;r=-22;i=b;return r|0}else{c[k+48>>2]=y;c[k+56>>2]=g;c[k+52>>2]=g;c[k+60>>2]=w;c[k+64>>2]=c[j>>2];w=c[v>>2]|0;c[k+72>>2]=w;c[k+68>>2]=w;c[k+76>>2]=c[x>>2];r=0;i=b;return r|0}}}while(0);KIb(e,16,2388288,(s=i,i=i+16|0,c[s>>2]=g,c[s+8>>2]=(((n|0)>(l|0)?l:n)|0)/2|0,s)|0);i=s;r=-22;i=b;return r|0}}while(0);KIb(e,16,2395528,(s=i,i=i+16|0,c[s>>2]=y,c[s+8>>2]=(z|0)/2|0,s)|0);i=s;r=-22;i=b;return r|0}function Nm(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=h<<1|1;j=(((i|0)/2|0)+65536|0)/(i|0)|0;if((h|0)>0){i=0;k=0;while(1){l=((d[e+(ca(i,f)|0)|0]|0)<<1)+k|0;m=i+1|0;if((m|0)<(h|0)){i=m;k=l}else{n=l;break}}}else{n=0}k=(d[e+(ca(h,f)|0)|0]|0)+n|0;if((h|0)<0){o=0;p=k}else{n=0;i=k;do{k=d[e+(ca(n+h|0,f)|0)|0]|0;i=k-(d[e+(ca(h-n|0,f)|0)|0]|0)+i|0;a[b+(ca(n,c)|0)|0]=((ca(i,j)|0)+32768|0)>>>16;n=n+1|0;}while((n|0)<=(h|0));o=h+1|0;p=i}i=g-h|0;if((o|0)<(i|0)){n=~h;k=o;l=p;while(1){m=d[e+(ca(k+h|0,f)|0)|0]|0;q=m-(d[e+(ca(k+n|0,f)|0)|0]|0)+l|0;a[b+(ca(k,c)|0)|0]=((ca(q,j)|0)+32768|0)>>>16;m=k+1|0;if((m|0)<(i|0)){k=m;l=q}else{r=i;s=q;break}}}else{r=o;s=p}if((r|0)>=(g|0)){return}p=~h;h=(g<<1)+p|0;o=r;r=s;do{s=d[e+(ca(h-o|0,f)|0)|0]|0;r=s-(d[e+(ca(o+p|0,f)|0)|0]|0)+r|0;a[b+(ca(o,c)|0)|0]=((ca(r,j)|0)+32768|0)>>>16;o=o+1|0;}while((o|0)<(g|0));return}function Om(a){a=a|0;dl(a,Ok(686432)|0);return 0}function Pm(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=c[(c[b>>2]|0)+44>>2]|0;e=b+52|0;b=qKb(c[e>>2]|0)|0;f=hJb(6144)|0;g=f;if((f|0)==0){i=-12;return i|0}j=f+2048|0;k=f+4096|0;l=0;do{m=+(l|0);n=m+-85.0;o=n*-.015625+.5;if(o<0.0){p=0.0}else{p=o>1.0?178.5:o*178.5}o=n*.015625+.5;if(o<0.0){q=0.0}else{q=o>1.0?1.0:o}o=(m+85.0+-255.0)*-.015625+.5;if(o<0.0){r=0.0}else{r=o>1.0?1.0:o}h[g+(l<<3)>>3]=p;h[j+(l<<3)>>3]=q*r*178.5;h[k+(255-l<<3)>>3]=p;l=l+1|0;}while((l|0)<256);l=d+8|0;s=d+16|0;t=d+24|0;u=d+32|0;v=d+40|0;w=d+48|0;x=d+56|0;y=d+64|0;z=d+72|0;A=0;do{p=+(A|0);r=+h[g+(A<<3)>>3];B=~~(p+ +h[l>>3]*r);if(B>>>0>255>>>0){C=-B>>31&255}else{C=B&255}B=C&255;D=~~(+(B|0)+ +h[s>>3]*+h[j+(B<<3)>>3]);if(D>>>0>255>>>0){E=-D>>31&255}else{E=D&255}D=E&255;B=~~(+(D|0)+ +h[t>>3]*+h[k+(D<<3)>>3]);if(B>>>0>255>>>0){F=-B>>31&255}else{F=B&255}B=~~(p+r*+h[u>>3]);if(B>>>0>255>>>0){G=-B>>31&255}else{G=B&255}B=G&255;D=~~(+(B|0)+ +h[v>>3]*+h[j+(B<<3)>>3]);if(D>>>0>255>>>0){H=-D>>31&255}else{H=D&255}D=H&255;B=~~(+(D|0)+ +h[w>>3]*+h[k+(D<<3)>>3]);if(B>>>0>255>>>0){I=-B>>31&255}else{I=B&255}B=~~(p+r*+h[x>>3]);if(B>>>0>255>>>0){J=-B>>31&255}else{J=B&255}B=J&255;D=~~(+(B|0)+ +h[y>>3]*+h[j+(B<<3)>>3]);if(D>>>0>255>>>0){K=-D>>31&255}else{K=D&255}D=K&255;B=~~(+(D|0)+ +h[z>>3]*+h[k+(D<<3)>>3]);if(B>>>0>255>>>0){L=-B>>31&255}else{L=B&255}a[d+(A+80)|0]=F;a[d+(A+336)|0]=I;a[d+(A+592)|0]=L;A=A+1|0;}while((A|0)<256);kJb(f);Kz(d+848|0,c[e>>2]|0)|0;c[d+852>>2]=(pKb(b)|0)>>3;i=0;return i|0}function Qm(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=c[b+8>>2]|0;b=c[h+44>>2]|0;j=h+32|0;h=c[c[j>>2]>>2]|0;k=a[b+848|0]|0;l=a[b+849|0]|0;m=a[b+850|0]|0;n=a[b+851|0]|0;o=c[b+852>>2]|0;p=c[e>>2]|0;do{if((bIb(e)|0)==0){q=h+24|0;r=bv(h,c[h+20>>2]|0,c[q>>2]|0)|0;if((r|0)!=0){ZHb(r,c[g>>2]|0)|0;s=r;t=q;break}VHb(g);u=-12;i=f;return u|0}else{s=e;t=h+24|0}}while(0);e=c[s>>2]|0;q=c[t>>2]|0;a:do{if((q|0)>0){r=h+20|0;v=k&255;w=l&255;x=m&255;y=n&255;z=s+32|0;A=c[r>>2]|0;if((o|0)==4){B=e;C=0;D=p;E=A;F=q}else{G=e;H=0;I=p;J=A;A=q;while(1){if((ca(J,o)|0)>0){K=0;do{L=K+v|0;a[G+L|0]=a[b+((d[I+L|0]|0)+80)|0]|0;L=K+w|0;a[G+L|0]=a[b+((d[I+L|0]|0)+336)|0]|0;L=K+x|0;a[G+L|0]=a[b+((d[I+L|0]|0)+592)|0]|0;K=K+o|0;M=c[r>>2]|0;}while((K|0)<(ca(M,o)|0));N=M;O=c[t>>2]|0}else{N=J;O=A}K=c[g>>2]|0;L=H+1|0;if((L|0)<(O|0)){G=G+(c[z>>2]|0)|0;H=L;I=I+(c[K+32>>2]|0)|0;J=N;A=O}else{P=K;break a}}}while(1){if((E<<2|0)>0){A=0;do{J=A+v|0;a[B+J|0]=a[b+((d[D+J|0]|0)+80)|0]|0;J=A+w|0;a[B+J|0]=a[b+((d[D+J|0]|0)+336)|0]|0;J=A+x|0;a[B+J|0]=a[b+((d[D+J|0]|0)+592)|0]|0;if((c[g>>2]|0)!=(s|0)){J=A+y|0;a[B+J|0]=a[D+J|0]|0}A=A+4|0;Q=c[r>>2]|0;}while((A|0)<(Q<<2|0));R=Q;S=c[t>>2]|0}else{R=E;S=F}A=c[g>>2]|0;J=C+1|0;if((J|0)<(S|0)){B=B+(c[z>>2]|0)|0;C=J;D=D+(c[A+32>>2]|0)|0;E=R;F=S}else{P=A;break}}}else{P=c[g>>2]|0}}while(0);if((P|0)!=(s|0)){VHb(g)}u=lj(c[c[j>>2]>>2]|0,s)|0;i=f;return u|0}function Rm(a){a=a|0;mJb((c[a+44>>2]|0)+200|0);return}function Sm(a){a=a|0;dl(a,Ok(686368)|0);return 0}function Tm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0;b=c[(c[a>>2]|0)+44>>2]|0;d=a+52|0;Kz(b+204|0,c[d>>2]|0)|0;a=c[d>>2]|0;if((a|0)==42|(a|0)==68|(a|0)==292|(a|0)==294){e=65536}else{e=256}a=hJb(e<<6)|0;d=a;c[b+200>>2]=d;if((a|0)==0){f=-12;return f|0}a=e<<2;c[b+136>>2]=d;c[b+140>>2]=d+(e<<2);g=e<<1;c[b+144>>2]=d+(g<<2);i=g|e;c[b+148>>2]=d+(i<<2);c[b+152>>2]=d+(a<<2);j=a|e;c[b+156>>2]=d+(j<<2);k=j+e|0;c[b+160>>2]=d+(k<<2);l=k+e|0;c[b+164>>2]=d+(l<<2);m=e<<3;c[b+168>>2]=d+(m<<2);n=m|e;c[b+172>>2]=d+(n<<2);o=n+e|0;c[b+176>>2]=d+(o<<2);p=o+e|0;c[b+180>>2]=d+(p<<2);q=m|a;c[b+184>>2]=d+(q<<2);r=q|e;c[b+188>>2]=d+(r<<2);s=r+e|0;c[b+192>>2]=d+(s<<2);t=s+e|0;c[b+196>>2]=d+(t<<2);u=+h[b+8>>3];v=+h[b+16>>3];w=+h[b+24>>3];x=+h[b+32>>3];y=+h[b+40>>3];z=+h[b+48>>3];A=+h[b+56>>3];B=+h[b+64>>3];C=+h[b+72>>3];D=+h[b+80>>3];E=+h[b+88>>3];F=+h[b+96>>3];G=+h[b+104>>3];H=+h[b+112>>3];I=+h[b+120>>3];J=+h[b+128>>3];b=0;while(1){K=+(b|0);c[d+(b<<2)>>2]=~~+Nb(+(K*u));c[d+(e+b<<2)>>2]=~~+Nb(+(K*v));c[d+(g+b<<2)>>2]=~~+Nb(+(K*w));c[d+(i+b<<2)>>2]=~~+Nb(+(K*x));c[d+(a+b<<2)>>2]=~~+Nb(+(K*y));c[d+(j+b<<2)>>2]=~~+Nb(+(K*z));c[d+(k+b<<2)>>2]=~~+Nb(+(K*A));c[d+(l+b<<2)>>2]=~~+Nb(+(K*B));c[d+(m+b<<2)>>2]=~~+Nb(+(K*C));c[d+(n+b<<2)>>2]=~~+Nb(+(K*D));c[d+(o+b<<2)>>2]=~~+Nb(+(K*E));c[d+(p+b<<2)>>2]=~~+Nb(+(K*F));c[d+(q+b<<2)>>2]=~~+Nb(+(K*G));c[d+(r+b<<2)>>2]=~~+Nb(+(K*H));c[d+(s+b<<2)>>2]=~~+Nb(+(K*I));c[d+(t+b<<2)>>2]=~~+Nb(+(K*J));L=b+1|0;if((L|0)<(e|0)){b=L}else{f=0;break}}return f|0}function Um(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;h=i;i=i+8|0;j=h|0;c[j>>2]=g;k=c[f+8>>2]|0;f=c[k+44>>2]|0;l=k+32|0;k=c[c[l>>2]>>2]|0;m=a[f+204|0]|0;n=a[f+205|0]|0;o=a[f+206|0]|0;p=a[f+207|0]|0;q=c[g>>2]|0;do{if((bIb(g)|0)==0){r=bv(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((r|0)!=0){ZHb(r,c[j>>2]|0)|0;s=r;break}VHb(j);t=-12;i=h;return t|0}else{s=g}}while(0);g=c[s>>2]|0;a:do{switch(c[k+52>>2]|0){case 294:case 292:{r=c[k+24>>2]|0;if((r|0)<=0){break a}u=c[k+20>>2]<<2;v=(u|0)>0;w=c[(c[j>>2]|0)+32>>2]|0;x=c[s+32>>2]|0;y=m&255;z=n&255;A=o&255;B=p&255;C=f+136|0;D=f+140|0;E=f+144|0;F=f+148|0;G=f+152|0;H=f+156|0;I=f+160|0;J=f+164|0;K=f+168|0;L=f+172|0;M=f+176|0;N=f+180|0;O=f+184|0;P=f+188|0;Q=f+192|0;R=f+196|0;S=0;T=g;U=q;while(1){V=U;W=T;if(v){X=c[C>>2]|0;Y=c[D>>2]|0;Z=c[E>>2]|0;_=c[F>>2]|0;$=c[G>>2]|0;aa=c[H>>2]|0;ba=c[I>>2]|0;ca=c[J>>2]|0;da=c[K>>2]|0;ea=c[L>>2]|0;fa=c[M>>2]|0;ga=c[N>>2]|0;ha=c[O>>2]|0;ia=c[P>>2]|0;ja=c[Q>>2]|0;ka=c[R>>2]|0;la=0;do{ma=la+y|0;na=la+z|0;oa=la+A|0;pa=la+B|0;qa=e[V+(ma<<1)>>1]|0;ra=e[V+(na<<1)>>1]|0;sa=e[V+(oa<<1)>>1]|0;ta=e[V+(pa<<1)>>1]|0;ua=(c[Y+(ra<<2)>>2]|0)+(c[X+(qa<<2)>>2]|0)+(c[Z+(sa<<2)>>2]|0)+(c[_+(ta<<2)>>2]|0)|0;if(ua>>>0>65535>>>0){va=-ua>>31&65535}else{va=ua&65535}b[W+(ma<<1)>>1]=va;ma=(c[aa+(ra<<2)>>2]|0)+(c[$+(qa<<2)>>2]|0)+(c[ba+(sa<<2)>>2]|0)+(c[ca+(ta<<2)>>2]|0)|0;if(ma>>>0>65535>>>0){wa=-ma>>31&65535}else{wa=ma&65535}b[W+(na<<1)>>1]=wa;na=(c[ea+(ra<<2)>>2]|0)+(c[da+(qa<<2)>>2]|0)+(c[fa+(sa<<2)>>2]|0)+(c[ga+(ta<<2)>>2]|0)|0;if(na>>>0>65535>>>0){xa=-na>>31&65535}else{xa=na&65535}b[W+(oa<<1)>>1]=xa;oa=(c[ia+(ra<<2)>>2]|0)+(c[ha+(qa<<2)>>2]|0)+(c[ja+(sa<<2)>>2]|0)+(c[ka+(ta<<2)>>2]|0)|0;if(oa>>>0>65535>>>0){ya=-oa>>31&65535}else{ya=oa&65535}b[W+(pa<<1)>>1]=ya;la=la+4|0;}while((la|0)<(u|0))}la=S+1|0;if((la|0)<(r|0)){S=la;T=T+x|0;U=U+w|0}else{break}}break};case 297:case 295:case 298:case 296:{w=k+24|0;U=c[w>>2]|0;if((U|0)<=0){break a}x=k+20|0;T=s+32|0;S=m&255;r=n&255;u=o&255;B=f+136|0;A=f+140|0;z=f+144|0;y=f+152|0;R=f+156|0;Q=f+160|0;P=f+168|0;O=f+172|0;N=f+176|0;M=p&255;L=0;K=g;J=q;I=c[x>>2]|0;H=U;while(1){if((I<<2|0)>0){U=0;do{G=U+S|0;F=U+r|0;E=U+u|0;D=d[J+G|0]|0;C=d[J+F|0]|0;v=d[J+E|0]|0;la=(c[(c[A>>2]|0)+(C<<2)>>2]|0)+(c[(c[B>>2]|0)+(D<<2)>>2]|0)+(c[(c[z>>2]|0)+(v<<2)>>2]|0)|0;if(la>>>0>255>>>0){za=-la>>31&255}else{za=la&255}a[K+G|0]=za;G=(c[(c[R>>2]|0)+(C<<2)>>2]|0)+(c[(c[y>>2]|0)+(D<<2)>>2]|0)+(c[(c[Q>>2]|0)+(v<<2)>>2]|0)|0;if(G>>>0>255>>>0){Aa=-G>>31&255}else{Aa=G&255}a[K+F|0]=Aa;F=(c[(c[O>>2]|0)+(C<<2)>>2]|0)+(c[(c[P>>2]|0)+(D<<2)>>2]|0)+(c[(c[N>>2]|0)+(v<<2)>>2]|0)|0;if(F>>>0>255>>>0){Ba=-F>>31&255}else{Ba=F&255}a[K+E|0]=Ba;if((c[j>>2]|0)!=(s|0)){a[K+(U+M)|0]=0}U=U+4|0;Ca=c[x>>2]|0;}while((U|0)<(Ca<<2|0));Da=Ca;Ea=c[w>>2]|0}else{Da=I;Ea=H}U=L+1|0;if((U|0)<(Ea|0)){L=U;K=K+(c[T>>2]|0)|0;J=J+(c[(c[j>>2]|0)+32>>2]|0)|0;I=Da;H=Ea}else{break}}break};case 29:case 27:case 30:case 28:{H=k+24|0;I=c[H>>2]|0;if((I|0)<=0){break a}J=k+20|0;T=s+32|0;K=m&255;L=n&255;w=o&255;x=p&255;M=f+136|0;N=f+140|0;P=f+144|0;O=f+148|0;Q=f+152|0;y=f+156|0;R=f+160|0;z=f+164|0;B=f+168|0;A=f+172|0;u=f+176|0;r=f+180|0;S=f+184|0;U=f+188|0;E=f+192|0;F=f+196|0;v=0;D=g;C=q;G=c[J>>2]|0;la=I;while(1){if((G<<2|0)>0){I=0;do{W=I+K|0;ka=I+L|0;ja=I+w|0;ha=I+x|0;ia=d[C+W|0]|0;ga=d[C+ka|0]|0;fa=d[C+ja|0]|0;da=d[C+ha|0]|0;ea=(c[(c[N>>2]|0)+(ga<<2)>>2]|0)+(c[(c[M>>2]|0)+(ia<<2)>>2]|0)+(c[(c[P>>2]|0)+(fa<<2)>>2]|0)+(c[(c[O>>2]|0)+(da<<2)>>2]|0)|0;if(ea>>>0>255>>>0){Fa=-ea>>31&255}else{Fa=ea&255}a[D+W|0]=Fa;W=(c[(c[y>>2]|0)+(ga<<2)>>2]|0)+(c[(c[Q>>2]|0)+(ia<<2)>>2]|0)+(c[(c[R>>2]|0)+(fa<<2)>>2]|0)+(c[(c[z>>2]|0)+(da<<2)>>2]|0)|0;if(W>>>0>255>>>0){Ga=-W>>31&255}else{Ga=W&255}a[D+ka|0]=Ga;ka=(c[(c[A>>2]|0)+(ga<<2)>>2]|0)+(c[(c[B>>2]|0)+(ia<<2)>>2]|0)+(c[(c[u>>2]|0)+(fa<<2)>>2]|0)+(c[(c[r>>2]|0)+(da<<2)>>2]|0)|0;if(ka>>>0>255>>>0){Ha=-ka>>31&255}else{Ha=ka&255}a[D+ja|0]=Ha;ja=(c[(c[U>>2]|0)+(ga<<2)>>2]|0)+(c[(c[S>>2]|0)+(ia<<2)>>2]|0)+(c[(c[E>>2]|0)+(fa<<2)>>2]|0)+(c[(c[F>>2]|0)+(da<<2)>>2]|0)|0;if(ja>>>0>255>>>0){Ia=-ja>>31&255}else{Ia=ja&255}a[D+ha|0]=Ia;I=I+4|0;Ja=c[J>>2]|0;}while((I|0)<(Ja<<2|0));Ka=Ja;La=c[H>>2]|0}else{Ka=G;La=la}I=v+1|0;if((I|0)<(La|0)){v=I;D=D+(c[T>>2]|0)|0;C=C+(c[(c[j>>2]|0)+32>>2]|0)|0;G=Ka;la=La}else{break}}break};case 3:case 2:{la=k+24|0;G=c[la>>2]|0;if((G|0)<=0){break a}C=k+20|0;T=s+32|0;D=m&255;v=n&255;H=o&255;J=f+136|0;F=f+140|0;E=f+144|0;S=f+152|0;U=f+156|0;r=f+160|0;u=f+168|0;B=f+172|0;A=f+176|0;z=0;R=g;Q=q;y=c[C>>2]|0;O=G;while(1){if((y*3|0|0)>0){G=0;do{P=G+D|0;M=G+v|0;N=G+H|0;x=d[Q+P|0]|0;w=d[Q+M|0]|0;L=d[Q+N|0]|0;K=(c[(c[F>>2]|0)+(w<<2)>>2]|0)+(c[(c[J>>2]|0)+(x<<2)>>2]|0)+(c[(c[E>>2]|0)+(L<<2)>>2]|0)|0;if(K>>>0>255>>>0){Ma=-K>>31&255}else{Ma=K&255}a[R+P|0]=Ma;P=(c[(c[U>>2]|0)+(w<<2)>>2]|0)+(c[(c[S>>2]|0)+(x<<2)>>2]|0)+(c[(c[r>>2]|0)+(L<<2)>>2]|0)|0;if(P>>>0>255>>>0){Na=-P>>31&255}else{Na=P&255}a[R+M|0]=Na;M=(c[(c[B>>2]|0)+(w<<2)>>2]|0)+(c[(c[u>>2]|0)+(x<<2)>>2]|0)+(c[(c[A>>2]|0)+(L<<2)>>2]|0)|0;if(M>>>0>255>>>0){Oa=-M>>31&255}else{Oa=M&255}a[R+N|0]=Oa;G=G+3|0;Pa=c[C>>2]|0;}while((G|0)<(Pa*3|0|0));Qa=Pa;Ra=c[la>>2]|0}else{Qa=y;Ra=O}G=z+1|0;if((G|0)<(Ra|0)){z=G;R=R+(c[T>>2]|0)|0;Q=Q+(c[(c[j>>2]|0)+32>>2]|0)|0;y=Qa;O=Ra}else{break}}break};case 68:case 42:{O=c[k+24>>2]|0;if((O|0)<=0){break a}y=(c[k+20>>2]|0)*3|0;Q=c[(c[j>>2]|0)+32>>2]|0;T=c[s+32>>2]|0;R=m&255;z=n&255;la=o&255;C=f+136|0;A=f+140|0;u=f+144|0;B=f+152|0;r=f+156|0;S=f+160|0;U=f+168|0;E=f+172|0;J=f+176|0;if((y|0)>0){Sa=0;Ta=g;Ua=q}else{break a}while(1){F=Ua;H=Ta;v=c[C>>2]|0;D=c[A>>2]|0;G=c[u>>2]|0;N=c[B>>2]|0;M=c[r>>2]|0;L=c[S>>2]|0;x=c[U>>2]|0;w=c[E>>2]|0;P=c[J>>2]|0;K=0;do{I=K+R|0;ha=K+z|0;ja=K+la|0;da=e[F+(I<<1)>>1]|0;fa=e[F+(ha<<1)>>1]|0;ia=e[F+(ja<<1)>>1]|0;ga=(c[D+(fa<<2)>>2]|0)+(c[v+(da<<2)>>2]|0)+(c[G+(ia<<2)>>2]|0)|0;if(ga>>>0>65535>>>0){Va=-ga>>31&65535}else{Va=ga&65535}b[H+(I<<1)>>1]=Va;I=(c[M+(fa<<2)>>2]|0)+(c[N+(da<<2)>>2]|0)+(c[L+(ia<<2)>>2]|0)|0;if(I>>>0>65535>>>0){Wa=-I>>31&65535}else{Wa=I&65535}b[H+(ha<<1)>>1]=Wa;ha=(c[w+(fa<<2)>>2]|0)+(c[x+(da<<2)>>2]|0)+(c[P+(ia<<2)>>2]|0)|0;if(ha>>>0>65535>>>0){Xa=-ha>>31&65535}else{Xa=ha&65535}b[H+(ja<<1)>>1]=Xa;K=K+3|0;}while((K|0)<(y|0));K=Sa+1|0;if((K|0)<(O|0)){Sa=K;Ta=Ta+T|0;Ua=Ua+Q|0}else{break}}break};default:{}}}while(0);if((c[j>>2]|0)!=(s|0)){VHb(j)}t=lj(c[c[l>>2]>>2]|0,s)|0;i=h;return t|0}function Vm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+44>>2]|0;e=c[d+588>>2]|0;if((e|0)==-1){KIb(a,16,2444616,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}if((c[d+584>>2]|0)!=(e|0)){g=0;i=b;return g|0}KIb(a,16,2355704,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}function Wm(a){a=a|0;dl(a,Ok(686352)|0);return 0}function Xm(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0,R=0.0,S=0.0,T=0.0,U=0,V=0.0,W=0.0,X=0.0,Y=0,Z=0.0,_=0.0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;f=i;i=i+296|0;g=f|0;j=f+288|0;c[j>>2]=e;k=c[b+8>>2]|0;b=k+44|0;l=c[b>>2]|0;m=l;n=c[c[k+32>>2]>>2]|0;o=bv(n,c[n+20>>2]|0,c[n+24>>2]|0)|0;if((o|0)==0){VHb(j);p=-12;i=f;return p|0}ZHb(o,e)|0;e=c[l+584>>2]|0;if((e|0)==-1){q=MHb(c[j>>2]|0)|0;if((q|0)==5){r=8}else if((q|0)==7){r=12}else if((q|0)==4){r=4}else if((q|0)==1){r=0}else{KIb(k,16,2476944,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;p=-22;i=f;return p|0}q=c[l+588>>2]|0;c[l+592>>2]=q+r;t=q}else{q=c[l+588>>2]|0;c[l+592>>2]=q+(e<<2);t=q}if((t|0)==2){NHb(o,5)}else if((t|0)==3){NHb(o,7)}else if((t|0)==0){NHb(o,1)}else if((t|0)==1){NHb(o,4)}t=c[b>>2]|0;b=0;do{u=+h[936+(b*72|0)>>3];v=+h[968+(b*72|0)>>3];w=+h[1e3+(b*72|0)>>3];x=+h[976+(b*72|0)>>3];y=+h[992+(b*72|0)>>3];z=v*w-x*y;A=+h[944+(b*72|0)>>3];B=+h[960+(b*72|0)>>3];C=w*B;D=+h[984+(b*72|0)>>3];E=x*D;F=+h[952+(b*72|0)>>3];G=y*B-v*D;H=1.0/(F*G+(u*z-A*(C-E)));h[g+(b*72|0)>>3]=z*H;h[g+(b*72|0)+8>>3]=H*(y*F-w*A);h[g+(b*72|0)+16>>3]=H*(x*A-v*F);h[g+(b*72|0)+24>>3]=H*(E-C);h[g+(b*72|0)+32>>3]=H*(u*w-D*F);h[g+(b*72|0)+40>>3]=H*(B*F-u*x);h[g+(b*72|0)+48>>3]=H*G;h[g+(b*72|0)+56>>3]=H*(A*D-u*y);h[g+(b*72|0)+64>>3]=(u*v-A*B)*H;b=b+1|0;}while((b|0)<4);b=t+4|0;t=k;k=0;q=0;while(1){H=+h[g+(q*72|0)>>3];B=+h[g+(q*72|0)+24>>3];A=+h[g+(q*72|0)+48>>3];v=+h[g+(q*72|0)+8>>3];u=+h[g+(q*72|0)+32>>3];y=+h[g+(q*72|0)+56>>3];D=+h[g+(q*72|0)+16>>3];G=+h[g+(q*72|0)+40>>3];x=+h[g+(q*72|0)+64>>3];e=k;r=0;while(1){F=+h[936+(r*72|0)>>3];w=+h[944+(r*72|0)>>3];C=+h[952+(r*72|0)>>3];E=H*F+B*w+A*C;z=v*F+u*w+y*C;I=D*F+G*w+x*C;C=+h[960+(r*72|0)>>3];w=+h[968+(r*72|0)>>3];F=+h[976+(r*72|0)>>3];J=H*C+B*w+A*F;K=v*C+u*w+y*F;L=D*C+G*w+x*F;F=+h[984+(r*72|0)>>3];w=+h[992+(r*72|0)>>3];C=+h[1e3+(r*72|0)>>3];M=H*F+B*w+A*C;N=v*F+u*w+y*C;O=D*F+G*w+x*C;C=E*65536.0;if(E<0.0){P=C+-.5+2.220446049250313e-16}else{P=C+.5}Q=~~P;c[b+(e*36|0)>>2]=Q;C=z*65536.0;if(z<0.0){R=C+-.5+2.220446049250313e-16}else{R=C+.5}c[b+(e*36|0)+4>>2]=~~R;C=I*65536.0;if(I<0.0){S=C+-.5+2.220446049250313e-16}else{S=C+.5}c[b+(e*36|0)+8>>2]=~~S;C=J*65536.0;if(J<0.0){T=C+-.5+2.220446049250313e-16}else{T=C+.5}U=~~T;c[b+(e*36|0)+12>>2]=U;C=K*65536.0;if(K<0.0){V=C+-.5+2.220446049250313e-16}else{V=C+.5}c[b+(e*36|0)+16>>2]=~~V;C=L*65536.0;if(L<0.0){W=C+-.5+2.220446049250313e-16}else{W=C+.5}c[b+(e*36|0)+20>>2]=~~W;C=M*65536.0;if(M<0.0){X=C+-.5+2.220446049250313e-16}else{X=C+.5}Y=~~X;c[b+(e*36|0)+24>>2]=Y;C=N*65536.0;if(N<0.0){Z=C+-.5+2.220446049250313e-16}else{Z=C+.5}c[b+(e*36|0)+28>>2]=~~Z;C=O*65536.0;if(O<0.0){_=C+-.5+2.220446049250313e-16}else{_=C+.5}c[b+(e*36|0)+32>>2]=~~_;if(!((Q|0)==65536&(U|0)==0&(Y|0)==0)){KIb(t,16,2467624,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}Y=r+1|0;if((Y|0)<4){e=e+1|0;r=Y}else{break}}r=q+1|0;if((r|0)<4){k=k+4|0;q=r}else{break}}q=c[j>>2]|0;k=c[q+80>>2]|0;do{if((k|0)==0){s=c[q>>2]|0;t=c[q+32>>2]|0;b=c[q+36>>2]|0;g=c[q+72>>2]|0;r=c[q+68>>2]|0;e=c[o>>2]|0;Y=c[o+32>>2]|0;U=c[o+36>>2]|0;Q=c[l+592>>2]|0;$=c[m+4+(Q*36|0)+4>>2]|0;aa=c[m+4+(Q*36|0)+8>>2]|0;ba=c[m+4+(Q*36|0)+16>>2]|0;da=c[m+4+(Q*36|0)+20>>2]|0;ea=c[m+4+(Q*36|0)+28>>2]|0;fa=c[m+4+(Q*36|0)+32>>2]|0;if((g|0)<=0){break}Q=(r|0)>0;ga=t<<1;ha=Y<<1;ia=e+Y|0;Y=e;e=c[o+8>>2]|0;ja=c[o+4>>2]|0;ka=s+t|0;t=0;la=s;s=c[q+8>>2]|0;ma=c[q+4>>2]|0;while(1){if(Q){na=0;do{oa=na>>1;pa=(d[ma+oa|0]|0)-128|0;qa=(d[s+oa|0]|0)-128|0;ra=(ca(pa,$)|0)+1081344+(ca(qa,aa)|0)|0;sa=((d[la+na|0]|0)<<16)-1048576+ra>>16;if(sa>>>0>255>>>0){ta=-sa>>31&255}else{ta=sa&255}a[Y+na|0]=ta;sa=na|1;ua=ra-1048576|0;ra=((d[la+sa|0]|0)<<16)+ua>>16;if(ra>>>0>255>>>0){va=-ra>>31&255}else{va=ra&255}a[Y+sa|0]=va;ra=((d[ka+na|0]|0)<<16)+ua>>16;if(ra>>>0>255>>>0){wa=-ra>>31&255}else{wa=ra&255}a[ia+na|0]=wa;ra=((d[ka+sa|0]|0)<<16)+ua>>16;if(ra>>>0>255>>>0){xa=-ra>>31&255}else{xa=ra&255}a[ia+sa|0]=xa;sa=(ca(pa,ba)|0)+8421376+(ca(qa,da)|0)>>16;if(sa>>>0>255>>>0){ya=-sa>>31&255}else{ya=sa&255}a[ja+oa|0]=ya;sa=(ca(pa,ea)|0)+8421376+(ca(qa,fa)|0)>>16;if(sa>>>0>255>>>0){za=-sa>>31&255}else{za=sa&255}a[e+oa|0]=za;na=na+2|0;}while((na|0)<(r|0))}na=t+2|0;if((na|0)<(g|0)){ia=ia+ha|0;Y=Y+ha|0;e=e+U|0;ja=ja+U|0;ka=ka+ga|0;t=na;la=la+ga|0;s=s+b|0;ma=ma+b|0}else{break}}}else if((k|0)==4){b=c[q+32>>2]|0;ma=c[q+36>>2]|0;s=c[q+72>>2]|0;ga=c[q+68>>2]|0;la=c[o+32>>2]|0;t=c[o+36>>2]|0;ka=c[l+592>>2]|0;U=c[m+4+(ka*36|0)+4>>2]|0;ja=c[m+4+(ka*36|0)+8>>2]|0;e=c[m+4+(ka*36|0)+16>>2]|0;ha=c[m+4+(ka*36|0)+20>>2]|0;Y=c[m+4+(ka*36|0)+28>>2]|0;ia=c[m+4+(ka*36|0)+32>>2]|0;if(!((s|0)>0&(ga|0)>0)){break}ka=c[o>>2]|0;g=c[o+8>>2]|0;r=c[o+4>>2]|0;fa=0;ea=c[q>>2]|0;da=c[q+8>>2]|0;ba=c[q+4>>2]|0;while(1){aa=0;do{$=aa>>1;Q=(d[ba+$|0]|0)-128|0;na=(d[da+$|0]|0)-128|0;oa=(ca(Q,U)|0)+1081344+(ca(na,ja)|0)|0;sa=((d[ea+aa|0]|0)<<16)-1048576+oa>>16;if(sa>>>0>255>>>0){Aa=-sa>>31&255}else{Aa=sa&255}a[ka+aa|0]=Aa;sa=aa|1;qa=oa-1048576+((d[ea+sa|0]|0)<<16)>>16;if(qa>>>0>255>>>0){Ba=-qa>>31&255}else{Ba=qa&255}a[ka+sa|0]=Ba;sa=(ca(Q,e)|0)+8421376+(ca(na,ha)|0)>>16;if(sa>>>0>255>>>0){Ca=-sa>>31&255}else{Ca=sa&255}a[r+$|0]=Ca;sa=(ca(Q,Y)|0)+8421376+(ca(na,ia)|0)>>16;if(sa>>>0>255>>>0){Da=-sa>>31&255}else{Da=sa&255}a[g+$|0]=Da;aa=aa+2|0;}while((aa|0)<(ga|0));aa=fa+1|0;if((aa|0)<(s|0)){ka=ka+la|0;g=g+t|0;r=r+t|0;fa=aa;ea=ea+b|0;da=da+ma|0;ba=ba+ma|0}else{break}}}else{ma=c[o+32>>2]|0;ba=c[q+32>>2]|0;da=c[q+72>>2]|0;b=c[q+68>>2]<<1;ea=c[l+592>>2]|0;fa=c[m+4+(ea*36|0)+4>>2]|0;t=c[m+4+(ea*36|0)+8>>2]|0;r=c[m+4+(ea*36|0)+16>>2]|0;g=c[m+4+(ea*36|0)+20>>2]|0;la=c[m+4+(ea*36|0)+28>>2]|0;ka=c[m+4+(ea*36|0)+32>>2]|0;if((da|0)<=0){break}ea=(b|0)>0;s=0;ga=c[o>>2]|0;ia=c[q>>2]|0;while(1){if(ea){Y=0;do{ha=(d[ia+Y|0]|0)-128|0;e=Y|2;ja=(d[ia+e|0]|0)-128|0;U=ca(ha,fa)|0;aa=ca(ja,t)|0;$=(ca(ha,r)|0)+8421376+(ca(ja,g)|0)>>16;if($>>>0>255>>>0){Ea=-$>>31&255}else{Ea=$&255}a[ga+Y|0]=Ea;$=Y|1;sa=U+32768+aa|0;aa=((d[ia+$|0]|0)<<16)+sa>>16;if(aa>>>0>255>>>0){Fa=-aa>>31&255}else{Fa=aa&255}a[ga+$|0]=Fa;$=(ca(ha,la)|0)+8421376+(ca(ja,ka)|0)>>16;if($>>>0>255>>>0){Ga=-$>>31&255}else{Ga=$&255}a[ga+e|0]=Ga;e=Y|3;$=((d[ia+e|0]|0)<<16)+sa>>16;if($>>>0>255>>>0){Ha=-$>>31&255}else{Ha=$&255}a[ga+e|0]=Ha;Y=Y+4|0;}while((Y|0)<(b|0))}Y=s+1|0;if((Y|0)<(da|0)){s=Y;ga=ga+ma|0;ia=ia+ba|0}else{break}}}}while(0);VHb(j);p=lj(n,o)|0;i=f;return p|0}function Ym(a){a=a|0;var b=0,e=0,f=0,g=0;b=i;e=c[a+8>>2]|0;f=c[e+44>>2]|0;g=qKb(c[a+52>>2]|0)|0;c[f+596>>2]=d[g+5|0]|0;c[f+600>>2]=d[g+6|0]|0;g=c[1644304+(c[f+588>>2]<<2)>>2]|0;KIb(e,40,2487936,(e=i,i=i+16|0,c[e>>2]=c[1644304+(c[f+584>>2]<<2)>>2],c[e+8>>2]=g,e)|0);i=e;i=b;return 0}function Zm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[c[(c[a+8>>2]|0)+32>>2]>>2]|0;a=bv(f,c[b+68>>2]|0,c[b+72>>2]|0)|0;if((a|0)==0){VHb(e);g=-12;i=d;return g|0}else{ZHb(a,b)|0;_Hb(a,c[e>>2]|0)|0;VHb(e);g=lj(f,a)|0;i=d;return g|0}return 0}function _m(a){a=a|0;var b=0;b=c[a+44>>2]|0;a=b+72|0;TGb(c[a>>2]|0);c[a>>2]=0;a=b+76|0;TGb(c[a>>2]|0);c[a>>2]=0;return}function $m(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=0;do{g=qKb(f)|0;h=a[g+7|0]|0;do{if((h&12)==0){if((a[g+5|0]|0)==0){if((a[g+6|0]|0)!=0){j=5}}else{j=5}if((j|0)==5){j=0;if((h&16)==0){break}}Qk(e,f,(f|0)<0|0?-1:0)|0}}while(0);f=f+1|0;}while((f|0)<333);dl(b,c[e>>2]|0);i=d;return 0}function an(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+12>>2];c[a+24>>2]=c[b+16>>2];d=b+20|0;b=a+28|0;a=c[d+4>>2]|0;c[b>>2]=c[d>>2];c[b+4>>2]=a;return 0}function bn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b+8|0;f=c[(c[e>>2]|0)+44>>2]|0;g=qKb(c[b+52>>2]|0)|0;i=f+12|0;c[d+68>>2]=c[i>>2];j=f+16|0;c[d+72>>2]=c[j>>2];l=b+160|0;h[f+200>>3]=+((c[l>>2]|0)>>>0)+ +(c[l+4>>2]|0)*4294967296.0;l=d+136|0;m=c[l>>2]|0;n=c[l+4>>2]|0;if((m|0)==0&(n|0)==(-2147483648|0)){o=+r}else{o=(+(m>>>0)+ +(n|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[f+216>>3]=o;n=DHb(d)|0;if((n|0)==(-1|0)&(G|0)==(-1|0)){p=+r}else{n=DHb(d)|0;p=+(n>>>0)+ +(G|0)*4294967296.0}h[f+208>>3]=p;n=f+72|0;m=f+80|0;l=f+184|0;h[l>>3]=+XGb(c[n>>2]|0,m,0);q=f+192|0;h[q>>3]=+XGb(c[f+76>>2]|0,m,0);p=+XGb(c[n>>2]|0,m,0);h[l>>3]=p;l=f+4|0;h[k>>3]=p;m=c[k+4>>2]&2147483647;n=2146435072;do{if(!(m>>>0>n>>>0|m>>>0==n>>>0&(c[k>>2]|0)>>>0>0>>>0)){s=p>2147483647.0;if(s|p<-2147483648.0){c[l>>2]=s?2147483647:-2147483648;break}else{c[l>>2]=~~+Nb(+p);break}}}while(0);n=f+8|0;p=+h[q>>3];m=c[q+4>>2]&2147483647;s=2146435072;do{if(!(m>>>0>s>>>0|m>>>0==s>>>0&(c[q>>2]|0)>>>0>0>>>0)){t=p>2147483647.0;if(t|p<-2147483648.0){c[n>>2]=t?2147483647:-2147483648;break}else{c[n>>2]=~~+Nb(+p);break}}}while(0);q=c[l>>2]|0;if((q|0)<0){c[l>>2]=0;u=0}else{u=q}q=c[n>>2]|0;if((q|0)<0){c[n>>2]=0;v=0}else{v=q}q=c[i>>2]|0;i=c[b+20>>2]|0;if((q+u|0)>>>0>i>>>0){s=i-q|0;c[l>>2]=s;w=s}else{w=u}u=c[j>>2]|0;j=c[b+24>>2]|0;if((u+v|0)>>>0>j>>>0){b=j-u|0;c[n>>2]=b;x=b}else{x=v}v=c[f+48>>2]|0;b=w&-1<<v;c[l>>2]=b;l=c[f+52>>2]|0;w=x&-1<<l;c[n>>2]=w;n=ca(w,c[d+32>>2]|0)|0;x=d|0;c[x>>2]=(c[x>>2]|0)+((ca(c[f+32>>2]|0,b)|0)+n);do{if((a[g+7|0]&66)==0){n=d+4|0;x=c[n>>2]|0;if((x|0)!=0){u=ca(w>>l,c[d+36>>2]|0)|0;c[n>>2]=x+(((ca(c[f+36>>2]|0,b)|0)>>v)+u)}u=d+8|0;x=c[u>>2]|0;if((x|0)==0){break}n=ca(w>>l,c[d+40>>2]|0)|0;c[u>>2]=x+(((ca(c[f+40>>2]|0,b)|0)>>v)+n)}}while(0);v=d+12|0;l=c[v>>2]|0;if((l|0)==0){y=c[e>>2]|0;z=y+32|0;A=c[z>>2]|0;B=c[A>>2]|0;C=lj(B,d)|0;return C|0}g=ca(c[d+44>>2]|0,w)|0;c[v>>2]=l+((ca(c[f+44>>2]|0,b)|0)+g);y=c[e>>2]|0;z=y+32|0;A=c[z>>2]|0;B=c[A>>2]|0;C=lj(B,d)|0;return C|0}function cn(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+24|0;e=b|0;f=b+8|0;g=b+16|0;j=c[a+8>>2]|0;k=c[j+44>>2]|0;l=qKb(c[a+52>>2]|0)|0;m=c[c[j+16>>2]>>2]|0;n=+(c[m+20>>2]|0);h[k+88>>3]=n;o=k+80|0;h[o>>3]=n;n=+(c[m+24>>2]|0);h[k+104>>3]=n;h[k+96>>3]=n;m=a+20|0;p=a+24|0;n=+(c[m>>2]|0)/+(c[p>>2]|0);h[k+144>>3]=n;q=a+28|0;s=q|0;t=c[s>>2]|0;if((t|0)==0){u=1.0}else{u=+(t|0)/+(c[a+32>>2]|0)}h[k+152>>3]=u;h[k+160>>3]=u*n;t=l+5|0;h[k+168>>3]=+(1<<(d[t]|0)|0);v=l+6|0;h[k+176>>3]=+(1<<(d[v]|0)|0);h[k+184>>3]=+r;h[k+192>>3]=+r;w=k+120|0;h[w>>3]=+r;x=k+112|0;h[x>>3]=+r;y=k+136|0;h[y>>3]=+r;z=k+128|0;h[z>>3]=+r;h[k+200>>3]=0.0;h[k+216>>3]=+r;h[k+208>>3]=+r;nIb(k+32|0,0,l);l=k+48|0;c[l>>2]=d[t]|0;t=k+52|0;c[t>>2]=d[v]|0;v=k+64|0;A=c[v>>2]|0;B=j;j=ZGb(e,A,281680,o,0,0,0,0,0,0,B)|0;do{if((j|0)<0){C=A;D=j}else{n=+h[e>>3];h[w>>3]=n;h[x>>3]=n;E=k+68|0;F=c[E>>2]|0;G=ZGb(e,F,281680,o,0,0,0,0,0,0,B)|0;if((G|0)<0){C=F;D=G;break}n=+h[e>>3];h[y>>3]=n;h[z>>3]=n;G=c[v>>2]|0;F=ZGb(e,G,281680,o,0,0,0,0,0,0,B)|0;if((F|0)<0){C=G;D=F;break}n=+h[e>>3];F=c[e>>2]|0;G=c[e+4>>2]|0;h[w>>3]=n;h[x>>3]=n;H=k+12|0;I=G&2147483647;G=2146435072;do{if(!(I>>>0>G>>>0|I>>>0==G>>>0&(F|0)>>>0>0>>>0)){J=n>2147483647.0;if(J|n<-2147483648.0){c[H>>2]=J?2147483647:-2147483648;break}J=~~+Nb(+n);c[H>>2]=J;K=k+16|0;u=+h[z>>3];L=c[z+4>>2]&2147483647;M=2146435072;if(L>>>0>M>>>0|L>>>0==M>>>0&(c[z>>2]|0)>>>0>0>>>0){break}M=u>2147483647.0;if(M|u<-2147483648.0){c[K>>2]=M?2147483647:-2147483648;break}M=~~+Nb(+u);c[H>>2]=J&-1<<c[l>>2];c[K>>2]=M&-1<<c[t>>2];M=k+72|0;TGb(c[M>>2]|0);J=k+76|0;TGb(c[J>>2]|0);c[J>>2]=0;c[M>>2]=0;if((UGb(M,c[k+56>>2]|0,281680,0,0,0,0,0,B)|0)<0){N=-22;i=b;return N|0}if((UGb(J,c[k+60>>2]|0,281680,0,0,0,0,0,B)|0)<0){N=-22;i=b;return N|0}if((c[k+28>>2]|0)==0){J=q;M=k+20|0;L=c[J>>2]|0;O=c[J+4>>2]|0;c[M>>2]=L;c[M+4>>2]=O;P=L;Q=O}else{c[g>>2]=c[m>>2];c[g+4>>2]=c[p>>2];yKb(f,q,g);O=k+20|0;L=k+24|0;M=ca(c[K>>2]|0,c[f>>2]|0)|0;J=ca(c[H>>2]|0,c[f+4>>2]|0)|0;xKb(O,L,M,(M|0)<0|0?-1:0,J,(J|0)<0|0?-1:0,2147483647,0)|0;P=c[O>>2]|0;Q=c[L>>2]|0}L=c[p>>2]|0;O=c[s>>2]|0;J=c[a+32>>2]|0;M=c[H>>2]|0;R=c[K>>2]|0;KIb(B,40,2467376,(S=i,i=i+64|0,c[S>>2]=c[m>>2],c[S+8>>2]=L,c[S+16>>2]=O,c[S+24>>2]=J,c[S+32>>2]=M,c[S+40>>2]=R,c[S+48>>2]=P,c[S+56>>2]=Q,S)|0);i=S;R=c[H>>2]|0;M=c[K>>2]|0;do{if(!((R|0)<1|(M|0)<1)){K=c[m>>2]|0;if((R|0)>(K|0)){break}if((M|0)>(c[p>>2]|0)){break}J=(K-R|0)/2|0;K=k+4|0;c[K>>2]=J;O=((c[p>>2]|0)-M|0)/2|0;c[K>>2]=J&-1<<c[l>>2];c[k+8>>2]=O&-1<<c[t>>2];N=0;i=b;return N|0}}while(0);KIb(B,16,2457544,(S=i,i=i+16|0,c[S>>2]=R,c[S+8>>2]=M,S)|0);i=S;N=-22;i=b;return N|0}}while(0);H=c[E>>2]|0;KIb(B,16,2476648,(S=i,i=i+16|0,c[S>>2]=c[v>>2],c[S+8>>2]=H,S)|0);i=S;N=-22;i=b;return N|0}}while(0);KIb(0,16,2440872,(S=i,i=i+8|0,c[S>>2]=C,S)|0);i=S;N=D;i=b;return N|0}function dn(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+44>>2]|0;c[d+32>>2]=-2;e=c[d+24>>2]|0;f=c[d+28>>2]|0;KIb(a,40,2441792,(a=i,i=i+24|0,c[a>>2]=c[d+20>>2],c[a+8>>2]=e,c[a+16>>2]=f,a)|0);i=a;i=b;return 0}function en(a){a=a|0;dl(a,Ok(686304)|0);return 0}function fn(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0.0;e=i;i=i+32|0;f=e|0;g=a+8|0;j=c[g>>2]|0;k=c[j+44>>2]|0;l=c[k+36>>2]|0;m=k+32|0;n=(c[m>>2]|0)+1|0;c[m>>2]=n;if((n|0)<=0){o=j;p=o+32|0;q=c[p>>2]|0;r=c[q>>2]|0;s=lj(r,b)|0;i=e;return s|0}n=QHb(b)|0;t=c[k+28>>2]|0;do{if((t|0)>0){if((c[m>>2]|0)<=(t|0)){break}c[k+4>>2]=(c[b+68>>2]|0)-1;c[k+8>>2]=(c[b+72>>2]|0)-1;c[k+12>>2]=0;c[k+16>>2]=0;c[m>>2]=1}}while(0);m=k+8|0;t=j;j=b|0;u=b+32|0;v=b+68|0;w=k+20|0;x=0;while(1){if((x|0)>=(c[m>>2]|0)){break}y=(c[j>>2]|0)+(ca(c[u>>2]|0,x)|0)|0;z=c[v>>2]|0;do{if((l|0)==1){if((z|0)>0){A=z;B=y;C=0}else{D=z;E=0;break}while(1){F=A-1|0;G=(d[B]|0)+C|0;if((F|0)>0){A=F;B=B+1|0;C=G}else{D=z;E=G;break}}}else if((l|0)==3|(l|0)==4){if((z|0)>0){G=z;F=y;H=0;while(1){I=G-1|0;J=(d[F]|0)+H+(d[F+1|0]|0)+(d[F+2|0]|0)|0;if((I|0)>0){G=I;F=F+l|0;H=J}else{K=J;break}}}else{K=0}D=z*3|0;E=K}else{D=z;E=0}}while(0);z=(E|0)/(D|0)|0;KIb(t,48,2457176,(L=i,i=i+8|0,c[L>>2]=z,L)|0);i=L;if((z|0)>(c[w>>2]|0)){M=15;break}x=x+1|0}if((M|0)==15){c[m>>2]=x}x=b+72|0;D=k+16|0;E=c[x>>2]|0;while(1){N=E-1|0;if((N|0)<=(c[D>>2]|0)){break}K=(c[j>>2]|0)+(ca(c[u>>2]|0,N)|0)|0;C=c[v>>2]|0;do{if((l|0)==1){if((C|0)>0){O=C;P=K;Q=0}else{R=C;S=0;break}while(1){B=O-1|0;A=(d[P]|0)+Q|0;if((B|0)>0){O=B;P=P+1|0;Q=A}else{R=C;S=A;break}}}else if((l|0)==3|(l|0)==4){if((C|0)>0){A=C;B=K;z=0;while(1){y=A-1|0;H=(d[B]|0)+z+(d[B+1|0]|0)+(d[B+2|0]|0)|0;if((y|0)>0){A=y;B=B+l|0;z=H}else{T=H;break}}}else{T=0}R=C*3|0;S=T}else{R=C;S=0}}while(0);C=(S|0)/(R|0)|0;KIb(t,48,2457176,(L=i,i=i+8|0,c[L>>2]=C,L)|0);i=L;if((C|0)>(c[w>>2]|0)){M=25;break}else{E=N}}if((M|0)==25){c[D>>2]=N}N=k+4|0;E=0;while(1){if((E|0)>=(c[N>>2]|0)){break}R=(c[j>>2]|0)+(ca(E,l)|0)|0;S=c[u>>2]|0;T=c[x>>2]|0;do{if((l|0)==3|(l|0)==4){if((T|0)>0){Q=T;P=R;O=0;while(1){C=Q-1|0;K=(d[P]|0)+O+(d[P+1|0]|0)+(d[P+2|0]|0)|0;if((C|0)>0){Q=C;P=P+S|0;O=K}else{U=K;break}}}else{U=0}V=T*3|0;W=U}else if((l|0)==1){if((T|0)>0){X=T;Y=R;Z=0}else{V=T;W=0;break}while(1){O=X-1|0;P=(d[Y]|0)+Z|0;if((O|0)>0){X=O;Y=Y+S|0;Z=P}else{V=T;W=P;break}}}else{V=T;W=0}}while(0);T=(W|0)/(V|0)|0;KIb(t,48,2457176,(L=i,i=i+8|0,c[L>>2]=T,L)|0);i=L;if((T|0)>(c[w>>2]|0)){M=36;break}E=E+1|0}if((M|0)==36){c[N>>2]=E}E=c[v>>2]|0;v=k+12|0;a:do{if((l|0)==3){V=E;while(1){W=V-1|0;Z=c[v>>2]|0;if((W|0)<=(Z|0)){_=Z;break a}Z=c[u>>2]|0;Y=c[x>>2]|0;if((Y|0)>0){X=Y;U=(c[j>>2]|0)+(W*3|0)|0;T=0;while(1){S=X-1|0;R=(d[U]|0)+T+(d[U+1|0]|0)+(d[U+2|0]|0)|0;if((S|0)>0){X=S;U=U+Z|0;T=R}else{$=R;break}}}else{$=0}T=($|0)/(Y*3|0|0)|0;KIb(t,48,2457176,(L=i,i=i+8|0,c[L>>2]=T,L)|0);i=L;if((T|0)>(c[w>>2]|0)){aa=W;M=52;break}else{V=W}}}else if((l|0)==1){V=E;while(1){T=V-1|0;Z=c[v>>2]|0;if((T|0)<=(Z|0)){_=Z;break a}Z=c[u>>2]|0;U=c[x>>2]|0;if((U|0)>0){X=U;R=(c[j>>2]|0)+T|0;S=0;while(1){P=X-1|0;O=(d[R]|0)+S|0;if((P|0)>0){X=P;R=R+Z|0;S=O}else{ba=O;break}}}else{ba=0}S=(ba|0)/(U|0)|0;KIb(t,48,2457176,(L=i,i=i+8|0,c[L>>2]=S,L)|0);i=L;if((S|0)>(c[w>>2]|0)){aa=T;M=52;break}else{V=T}}}else{V=E;while(1){S=V-1|0;Z=c[v>>2]|0;if((S|0)<=(Z|0)){_=Z;break a}Z=c[u>>2]|0;R=c[x>>2]|0;if((l-3|0)>>>0<2>>>0){X=ca(S,l)|0;if((R|0)>0){W=R;Y=(c[j>>2]|0)+X|0;X=0;while(1){O=W-1|0;P=(d[Y]|0)+X+(d[Y+1|0]|0)+(d[Y+2|0]|0)|0;if((O|0)>0){W=O;Y=Y+Z|0;X=P}else{da=P;break}}}else{da=0}ea=R*3|0;fa=da}else{ea=R;fa=0}X=(fa|0)/(ea|0)|0;KIb(t,48,2457176,(L=i,i=i+8|0,c[L>>2]=X,L)|0);i=L;if((X|0)>(c[w>>2]|0)){aa=S;M=52;break}else{V=S}}}}while(0);if((M|0)==52){c[v>>2]=aa;_=aa}aa=c[N>>2]|0;M=aa+1&-2;w=(c[m>>2]|0)+1&-2;ea=_-M+1|0;_=(c[D>>2]|0)-w+1|0;fa=k+24|0;k=c[fa>>2]|0;do{if((k|0)<2){c[fa>>2]=16;ga=16}else{if((k&1|0)==0){ga=k;break}da=k<<1;c[fa>>2]=da;ga=da}}while(0);fa=(ea|0)%(ga|0)|0;k=ea-fa|0;ea=(((fa|0)/2|0)+1&-2)+M|0;M=(_|0)%(ga|0)|0;ga=_-M|0;_=(((M|0)/2|0)+1&-2)+w|0;w=f|0;Rb(w|0,32,2612344,(L=i,i=i+8|0,c[L>>2]=aa,L)|0)|0;i=L;MGb(n,2585672,w,0)|0;Rb(w|0,32,2612344,(L=i,i=i+8|0,c[L>>2]=c[v>>2],L)|0)|0;i=L;MGb(n,2564800,w,0)|0;Rb(w|0,32,2612344,(L=i,i=i+8|0,c[L>>2]=c[m>>2],L)|0)|0;i=L;MGb(n,2546688,w,0)|0;Rb(w|0,32,2612344,(L=i,i=i+8|0,c[L>>2]=c[D>>2],L)|0)|0;i=L;MGb(n,2529032,w,0)|0;Rb(w|0,32,2612344,(L=i,i=i+8|0,c[L>>2]=k,L)|0)|0;i=L;MGb(n,2513864,w,0)|0;Rb(w|0,32,2612344,(L=i,i=i+8|0,c[L>>2]=ga,L)|0)|0;i=L;MGb(n,2500184,w,0)|0;Rb(w|0,32,2612344,(L=i,i=i+8|0,c[L>>2]=ea,L)|0)|0;i=L;MGb(n,2487512,w,0)|0;Rb(w|0,32,2612344,(L=i,i=i+8|0,c[L>>2]=_,L)|0)|0;i=L;MGb(n,2476296,w,0)|0;w=c[v>>2]|0;v=c[m>>2]|0;m=c[D>>2]|0;D=b+136|0;n=c[D>>2]|0;aa=c[D+4>>2]|0;if((n|0)==0&(aa|0)==(-2147483648|0)){ha=-1.0}else{ha=(+(n>>>0)+ +(aa|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}KIb(t,32,2467e3,(L=i,i=i+120|0,c[L>>2]=c[N>>2],c[L+8>>2]=w,c[L+16>>2]=v,c[L+24>>2]=m,c[L+32>>2]=k,c[L+40>>2]=ga,c[L+48>>2]=ea,c[L+56>>2]=_,c[L+64>>2]=n,c[L+72>>2]=aa,h[L+80>>3]=ha,c[L+88>>2]=k,c[L+96>>2]=ga,c[L+104>>2]=ea,c[L+112>>2]=_,L)|0);i=L;o=c[g>>2]|0;p=o+32|0;q=c[p>>2]|0;r=c[q>>2]|0;s=lj(r,b)|0;i=e;return s|0}function gn(a){a=a|0;var b=0;b=c[(c[a+8>>2]|0)+44>>2]|0;nIb(b+36|0,0,qKb(c[a+52>>2]|0)|0);c[b+4>>2]=(c[a+20>>2]|0)-1;c[b+8>>2]=(c[a+24>>2]|0)-1;c[b+12>>2]=0;c[b+16>>2]=0;return 0}function hn(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0.0,R=0,S=0.0,T=0.0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0.0,ba=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0,ka=0.0,la=0,ma=0,na=0,oa=0;e=i;i=i+1064|0;f=e|0;g=e+8|0;j=e+16|0;k=e+24|0;l=e+1048|0;m=b+44|0;n=c[m>>2]|0;mrc(l|0,0,16)|0;o=n+8|0;p=o;q=o;o=c[n+24>>2]|0;do{if((o|0)!=0){do{if((c[q>>2]|0)==0){r=rJb(o)|0;c[q>>2]=r;if((r|0)==0){s=-12}else{break}i=e;return s|0}}while(0);r=n+12|0;do{if((c[r>>2]|0)==0){t=rJb(o)|0;c[r>>2]=t;if((t|0)==0){s=-12}else{break}i=e;return s|0}}while(0);r=n+16|0;if((c[r>>2]|0)!=0){break}t=rJb(o)|0;c[r>>2]=t;if((t|0)==0){s=-12}else{break}i=e;return s|0}}while(0);o=c[n+1052>>2]|0;do{if((o|0)!=0){t=c[m>>2]|0;SFb(k,0,1);r=lHb(o,g,j,0,0)|0;a:do{if((r|0)<0){u=r}else{v=c[j>>2]|0;if(v>>>0<2>>>0){u=-1094995529;break}w=c[g>>2]|0;x=w+2|0;c[g>>2]=x;y=v-2|0;c[j>>2]=y;if(y>>>0<2>>>0){u=-1094995529;break}y=x;x=(he((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535;c[g>>2]=w+4;c[j>>2]=v-4;v=x>>>0>4>>>0?4:x;b:do{if((v|0)==0){z=r}else{x=k|0;w=t+8|0;y=b;A=0;while(1){ZFb(k);B=c[j>>2]|0;if(B>>>0<2>>>0){u=-1094995529;break a}C=c[g>>2]|0;D=C;E=(d[D]|d[D+1|0]<<8)<<16>>16;D=(he(E|0)|0)&65535;F=C+2|0;c[g>>2]=F;C=B-2|0;c[j>>2]=C;c:do{if(!(E<<16>>16==0)){if(C>>>0<2>>>0){u=-1094995529;break a}else{G=C;H=1;I=F}while(1){B=I;J=(d[B]|d[B+1|0]<<8)<<16>>16;B=I+2|0;c[g>>2]=B;K=G-2|0;c[j>>2]=K;if(K>>>0<2>>>0){u=-1094995529;break a}K=(he(J|0)|0)&65535;J=B;B=(he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535;c[g>>2]=I+4;c[j>>2]=G-4;UFb(k,2367336,(L=i,i=i+16|0,h[L>>3]=+(B|0)/255.0,h[L+8>>3]=+(K|0)/255.0,L)|0);i=L;if((H|0)>=(D|0)){break c}K=c[j>>2]|0;if(K>>>0<2>>>0){u=-1094995529;break a}G=K;H=H+1|0;I=c[g>>2]|0}}}while(0);F=c[x>>2]|0;do{if((a[F]|0)!=0){C=c[735280+(A<<2)>>2]|0;E=w+(C<<2)|0;if((c[E>>2]|0)!=0){break}K=rJb(F)|0;c[E>>2]=K;KIb(y,48,2352616,(L=i,i=i+32|0,c[L>>2]=A,c[L+8>>2]=C,c[L+16>>2]=D,c[L+24>>2]=K,L)|0);i=L;if((c[E>>2]|0)==0){z=-12;break b}}}while(0);D=A+1|0;if(D>>>0<v>>>0){A=D}else{z=r;break}}}}while(0);_Fb(k,0)|0;mHb(c[g>>2]|0,c[j>>2]|0);u=z}}while(0);if((u|0)<0){s=u}else{break}i=e;return s|0}}while(0);u=n+4|0;z=c[u>>2]|0;do{if((z|0)!=0){do{if((c[q>>2]|0)==0){if((1030>>>(z>>>0)&1|0)==0){break}j=rJb(c[1623376+(z<<4)>>2]|0)|0;c[q>>2]=j;if((j|0)==0){s=-12}else{break}i=e;return s|0}}while(0);j=n+12|0;do{if((c[j>>2]|0)==0){g=c[u>>2]|0;if((1030>>>(g>>>0)&1|0)==0){break}k=rJb(c[1623380+(g<<4)>>2]|0)|0;c[j>>2]=k;if((k|0)==0){s=-12}else{break}i=e;return s|0}}while(0);j=n+16|0;do{if((c[j>>2]|0)==0){k=c[u>>2]|0;if((1030>>>(k>>>0)&1|0)==0){break}g=rJb(c[1623384+(k<<4)>>2]|0)|0;c[j>>2]=g;if((g|0)==0){s=-12}else{break}i=e;return s|0}}while(0);j=n+20|0;if((c[j>>2]|0)!=0){break}g=c[u>>2]|0;if(!((g-3|0)>>>0<7>>>0)){break}k=rJb(c[1623388+(g<<4)>>2]|0)|0;c[j>>2]=k;if((k|0)==0){s=-12}else{break}i=e;return s|0}}while(0);u=n+28|0;q=b;b=0;d:while(1){if((b|0)>=4){M=101;break}z=l+(b<<2)|0;k=c[p+(b<<2)>>2]|0;c[f>>2]=k;e:do{if((k|0)==0){N=0}else{j=k;O=0;while(1){if((a[j]|0)==0){N=O;break e}g=pJb(24)|0;if((g|0)==0){s=-12;M=112;break d}I=g;H=g;G=g+8|0;mrc(g|0,0,20)|0;h[H>>3]=+SGb(j,f);g=c[f>>2]|0;do{if((g|0)==0){P=0}else{if((a[g]|0)==0){P=g;break}o=g+1|0;c[f>>2]=o;P=o}}while(0);Q=+SGb(P,f);h[G>>3]=Q;g=c[f>>2]|0;do{if((g|0)==0){R=0}else{if((a[g]|0)==0){R=g;break}o=g+1|0;c[f>>2]=o;R=o}}while(0);S=+h[H>>3];if(S<0.0|S>1.0){M=51;break d}if(Q<0.0|Q>1.0){M=51;break d}if((c[z>>2]|0)==0){c[z>>2]=I}if((O|0)!=0){T=+h[O>>3];if((~~(T*255.0)|0)>=(~~(S*255.0)|0)){M=56;break d}c[O+16>>2]=I}if((R|0)==0){N=I;break}else{j=R;O=I}}}}while(0);k=c[z>>2]|0;if((k|0)==0){j=pJb(24)|0;if((j|0)==0){s=-12;M=112;break}g=j;mrc(j|0,0,20)|0;h[j>>3]=0.0;c[z>>2]=g;U=g;V=g}else{if(+h[k>>3]!=0.0){g=pJb(24)|0;if((g|0)==0){s=-12;M=112;break}mrc(g|0,0,16)|0;c[g+16>>2]=k;j=g;c[z>>2]=j;W=j}else{W=k}if((N|0)==0){M=65;break}else{U=N;V=W}}if(+h[U>>3]!=1.0){k=pJb(24)|0;if((k|0)==0){s=-12;M=112;break}h[k>>3]=1.0;h[k+8>>3]=1.0;c[k+16>>2]=0;c[U+16>>2]=k;X=c[z>>2]|0}else{X=V}k=(X|0)==0;if(k){Y=0}else{j=X;g=0;while(1){G=g+1|0;o=c[j+16>>2]|0;if((o|0)==0){Y=G;break}else{j=o;g=G}}}g=qJb(Y,24)|0;j=g;z=Y-1|0;G=hJb(z<<3)|0;o=G;m=qJb(Y,8)|0;r=m;if((g|0)==0|(G|0)==0|(m|0)==0){Z=-12}else{if(!k){_=0.0;t=X;v=-1;while(1){A=t|0;if(!((v|0)==-1)){h[o+(v<<3)>>3]=+h[A>>3]-_}y=c[t+16>>2]|0;if((y|0)==0){break}else{_=+h[A>>3];t=y;v=v+1|0}}}if((z|0)>1){_=+h[o>>3];v=X;t=1;$=_;k=c[X+16>>2]|0;while(1){aa=+h[k+8>>3];y=c[k+16>>2]|0;ba=+h[o+(t<<3)>>3];h[r+(t<<3)>>3]=((+h[y+8>>3]-aa)/ba-(aa- +h[v+8>>3])/$)*6.0;A=t+1|0;if((A|0)<(z|0)){v=k;t=A;$=ba;k=y}else{break}}h[j+(z*24|0)+8>>3]=1.0;h[g+8>>3]=1.0;k=1;$=_;while(1){h[j+(k*24|0)>>3]=$;ba=+h[o+(k<<3)>>3];h[j+(k*24|0)+8>>3]=($+ba)*2.0;h[j+(k*24|0)+16>>3]=ba;t=k+1|0;if((t|0)<(z|0)){k=t;$=ba}else{break}}}else{h[j+(z*24|0)+8>>3]=1.0;h[g+8>>3]=1.0}if((Y|0)>1){k=1;$=+h[g+16>>3];do{_=+h[j+(k*24|0)>>3];ba=+h[j+(k*24|0)+8>>3]-$*_;if(ba!=0.0){ca=1.0/ba}else{ca=1.0}t=j+(k*24|0)+16|0;$=ca*+h[t>>3];h[t>>3]=$;t=r+(k<<3)|0;h[t>>3]=ca*(+h[t>>3]-_*+h[r+(k-1<<3)>>3]);k=k+1|0;}while((k|0)<(Y|0))}k=Y-2|0;if((k|0)>-1){t=k;$=+h[r+(z<<3)>>3];while(1){k=r+(t<<3)|0;_=+h[k>>3]-$*+h[j+(t*24|0)+16>>3];h[k>>3]=_;if((t|0)>0){t=t-1|0;$=_}else{break}}}t=X+16|0;j=c[t>>2]|0;if((j|0)==0){M=91;break}else{da=X;ea=0;fa=t;ga=j}while(1){$=+h[da+8>>3];_=+h[o+(ea<<3)>>3];ba=+h[r+(ea<<3)>>3];j=ea+1|0;aa=+h[r+(j<<3)>>3]-ba;ha=(+h[ga+8>>3]-$)/_-_*ba*.5-_*aa/6.0;ia=ba*.5;ba=aa/(_*6.0);t=~~(+h[da>>3]*255.0);z=~~(+h[ga>>3]*255.0);if(!((z|t)>>>0<256>>>0)){M=94;break d}if((t|0)>(z|0)){ja=ga}else{k=t;do{_=+(k-t|0)/255.0;aa=$+ha*_+_*ia*_+_*_*ba*_;ka=aa;if(ka<0.0){la=0}else{la=ka>1.0?-1:~~(ka*255.0)}a[u+(b<<8)+k|0]=la;KIb(q,48,2611896,(L=i,i=i+32|0,h[L>>3]=_,h[L+8>>3]=aa,c[L+16>>2]=k,c[L+24>>2]=la&255,L)|0);i=L;k=k+1|0;}while((k|0)<=(z|0));ja=c[fa>>2]|0}z=ja+16|0;k=c[z>>2]|0;if((k|0)==0){Z=0;break}else{da=ja;ea=j;fa=z;ga=k}}}kJb(g);kJb(G);kJb(m);if((Z|0)<0){s=Z;M=112;break}else{b=b+1|0}}if((M|0)==51){KIb(q,16,2585256,(L=i,i=i+16|0,h[L>>3]=S,h[L+8>>3]=Q,L)|0);i=L;s=-22;i=e;return s|0}else if((M|0)==56){ca=+h[O+8>>3];KIb(q,16,2564424,(L=i,i=i+32|0,h[L>>3]=T,h[L+8>>3]=ca,h[L+16>>3]=S,h[L+24>>3]=Q,L)|0);i=L;s=-22;i=e;return s|0}else if((M|0)==65){KIb(0,0,2167640,(L=i,i=i+24|0,c[L>>2]=2546416,c[L+8>>2]=2117496,c[L+16>>2]=194,L)|0);i=L;Hd();return 0}else if((M|0)==91){KIb(0,0,2167640,(L=i,i=i+24|0,c[L>>2]=2141056,c[L+8>>2]=2117496,c[L+16>>2]=283,L)|0);i=L;Hd();return 0}else if((M|0)==94){KIb(0,0,2167640,(L=i,i=i+24|0,c[L>>2]=2635304,c[L+8>>2]=2117496,c[L+16>>2]=298,L)|0);i=L;Hd();return 0}else if((M|0)==101){if((c[n+20>>2]|0)!=0){O=0;while(1){b=u+O|0;a[b]=a[n+((d[b]|0)+796)|0]|0;b=O+1|0;if((b|0)<256){O=b}else{ma=0;break}}while(1){O=u+256+ma|0;a[O]=a[n+((d[O]|0)+796)|0]|0;O=ma+1|0;if((O|0)<256){ma=O}else{na=0;break}}do{ma=u+512+na|0;a[ma]=a[n+((d[ma]|0)+796)|0]|0;na=na+1|0;}while((na|0)<256)}na=l|0;if((MIb()|0)>39){n=c[na>>2]|0;KIb(q,40,2441e3,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L;if((n|0)!=0){ma=n;do{Q=+h[ma+8>>3];KIb(q,40,2353160,(L=i,i=i+16|0,h[L>>3]=+h[ma>>3],h[L+8>>3]=Q,L)|0);i=L;ma=c[ma+16>>2]|0;}while((ma|0)!=0)}KIb(q,40,2291032,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;KIb(q,40,2240280,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L;ma=0;do{KIb(q,40,2199264,(L=i,i=i+8|0,c[L>>2]=d[u+ma|0]|0,L)|0);i=L;ma=ma+1|0;}while((ma|0)<256);KIb(q,40,2291032,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;ma=c[l+4>>2]|0;KIb(q,40,2441e3,(L=i,i=i+8|0,c[L>>2]=1,L)|0);i=L;if((ma|0)!=0){n=ma;do{Q=+h[n+8>>3];KIb(q,40,2353160,(L=i,i=i+16|0,h[L>>3]=+h[n>>3],h[L+8>>3]=Q,L)|0);i=L;n=c[n+16>>2]|0;}while((n|0)!=0)}KIb(q,40,2291032,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;KIb(q,40,2240280,(L=i,i=i+8|0,c[L>>2]=1,L)|0);i=L;n=0;do{KIb(q,40,2199264,(L=i,i=i+8|0,c[L>>2]=d[u+256+n|0]|0,L)|0);i=L;n=n+1|0;}while((n|0)<256);KIb(q,40,2291032,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;n=c[l+8>>2]|0;KIb(q,40,2441e3,(L=i,i=i+8|0,c[L>>2]=2,L)|0);i=L;if((n|0)!=0){ma=n;do{Q=+h[ma+8>>3];KIb(q,40,2353160,(L=i,i=i+16|0,h[L>>3]=+h[ma>>3],h[L+8>>3]=Q,L)|0);i=L;ma=c[ma+16>>2]|0;}while((ma|0)!=0)}KIb(q,40,2291032,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;KIb(q,40,2240280,(L=i,i=i+8|0,c[L>>2]=2,L)|0);i=L;ma=0;do{KIb(q,40,2199264,(L=i,i=i+8|0,c[L>>2]=d[u+512+ma|0]|0,L)|0);i=L;ma=ma+1|0;}while((ma|0)<256);KIb(q,40,2291032,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L}L=c[na>>2]|0;if((L|0)!=0){na=L;while(1){L=c[na+16>>2]|0;kJb(na);if((L|0)==0){break}else{na=L}}}na=c[l+4>>2]|0;if((na|0)!=0){L=na;while(1){na=c[L+16>>2]|0;kJb(L);if((na|0)==0){break}else{L=na}}}L=c[l+8>>2]|0;if((L|0)!=0){na=L;while(1){L=c[na+16>>2]|0;kJb(na);if((L|0)==0){break}else{na=L}}}na=c[l+12>>2]|0;if((na|0)==0){s=0;i=e;return s|0}else{oa=na}while(1){na=c[oa+16>>2]|0;kJb(oa);if((na|0)==0){s=0;break}else{oa=na}}i=e;return s|0}else if((M|0)==112){i=e;return s|0}return 0}function jn(a){a=a|0;dl(a,Ok(686256)|0);return 0}function kn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;a=c[c[g+32>>2]>>2]|0;do{if((bIb(b)|0)==0){h=a+24|0;j=bv(a,c[a+20>>2]|0,c[h>>2]|0)|0;if((j|0)!=0){ZHb(j,c[e>>2]|0)|0;k=j;l=c[e>>2]|0;m=h;break}VHb(e);n=-12;i=d;return n|0}else{k=b;l=b;m=a+24|0}}while(0);c[f>>2]=l;c[f+4>>2]=k;l=c[m>>2]|0;m=c[(c[g+48>>2]|0)+28>>2]|0;Xe[c[c[g+56>>2]>>2]&511](g,732,f,0,(l|0)>(m|0)?m:l)|0;if((k|0)!=(c[e>>2]|0)){VHb(e)}n=lj(a,k)|0;i=d;return n|0}function ln(a){a=a|0;var b=0,d=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=a+52|0;a=qKb(c[d>>2]|0)|0;Kz(b+1056|0,c[d>>2]|0)|0;c[b+1060>>2]=(pKb(a)|0)>>3;return 0}function mn(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=c[b+44>>2]|0;b=c[e>>2]|0;i=c[e+4>>2]|0;e=c[h+1060>>2]|0;j=c[b+72>>2]|0;k=(ca(j,f)|0)/(g|0)|0;l=(ca(j,f+1|0)|0)/(g|0)|0;g=i+32|0;f=c[g>>2]|0;j=(c[i>>2]|0)+(ca(f,k)|0)|0;m=b+32|0;n=c[m>>2]|0;o=(c[b>>2]|0)+(ca(n,k)|0)|0;if((k|0)>=(l|0)){return 0}p=b+68|0;q=d[h+1056|0]|0;r=d[h+1057|0]|0;s=d[h+1058|0]|0;t=d[h+1059|0]|0;u=c[p>>2]|0;if((i|0)!=(b|0)&(e|0)==4){b=k;i=j;v=o;w=u;x=f;y=n;while(1){if((w<<2|0)>0){z=0;do{A=z+q|0;a[i+A|0]=a[h+((d[v+A|0]|0)+28)|0]|0;A=z+r|0;a[i+A|0]=a[h+((d[v+A|0]|0)+284)|0]|0;A=z+s|0;a[i+A|0]=a[h+((d[v+A|0]|0)+540)|0]|0;A=z+t|0;a[i+A|0]=a[v+A|0]|0;z=z+4|0;B=c[p>>2]|0;}while((z|0)<(B<<2|0));C=B;D=c[g>>2]|0;E=c[m>>2]|0}else{C=w;D=x;E=y}z=b+1|0;if((z|0)<(l|0)){b=z;i=i+D|0;v=v+E|0;w=C;x=D;y=E}else{break}}return 0}else{E=k;k=j;j=o;o=u;u=f;f=n;while(1){if((ca(o,e)|0)>0){n=0;do{y=n+q|0;a[k+y|0]=a[h+((d[j+y|0]|0)+28)|0]|0;y=n+r|0;a[k+y|0]=a[h+((d[j+y|0]|0)+284)|0]|0;y=n+s|0;a[k+y|0]=a[h+((d[j+y|0]|0)+540)|0]|0;n=n+e|0;F=c[p>>2]|0;}while((n|0)<(ca(F,e)|0));G=F;H=c[g>>2]|0;I=c[m>>2]|0}else{G=o;H=u;I=f}n=E+1|0;if((n|0)<(l|0)){E=n;k=k+H|0;j=j+I|0;o=G;u=H;f=I}else{break}}return 0}return 0}function nn(a){a=a|0;var b=0,d=0,e=0,f=0,h=0;b=c[a+44>>2]|0;d=c[b+4>>2]|0;do{if((d|0)!=0){e=UGb(b+8|0,d,281672,0,0,0,0,0,a)|0;if((e|0)<0){f=e}else{break}return f|0}}while(0);g[b+36>>2]=+g[b+32>>2]*3.0;c[b+112>>2]=16-(c[b+108>>2]|0);a=b+116|0;c[a>>2]=G1(4,0)|0;d=b+120|0;c[d>>2]=G1(4,1)|0;e=b+124|0;c[e>>2]=hJb(1024)|0;h=hJb(1024)|0;c[b+128>>2]=h;if((c[a>>2]|0)==0){f=-12;return f|0}if((c[d>>2]|0)==0|(h|0)==0){f=-12;return f|0}else{return((c[e>>2]|0)==0?-12:0)|0}return 0}function on(a){a=a|0;var b=0;b=c[a+44>>2]|0;I1(c[b+116>>2]|0);I1(c[b+120>>2]|0);kJb(c[b+124>>2]|0);kJb(c[b+128>>2]|0);kJb(c[b+100>>2]|0);kJb(c[b+76>>2]|0);kJb(c[b+80>>2]|0);kJb(c[b+84>>2]|0);kJb(c[b+88>>2]|0);kJb(c[b+92>>2]|0);kJb(c[b+96>>2]|0);TGb(c[b+8>>2]|0);return}function pn(a){a=a|0;dl(a,Ok(686240)|0);return 0}function qn(b,e){b=b|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0,ba=0,da=0,ea=0.0,fa=0,ga=0,ha=0,ia=0,ja=0;f=i;i=i+8|0;j=f|0;c[j>>2]=e;k=c[b+8>>2]|0;l=k+44|0;m=c[l>>2]|0;n=c[c[k+32>>2]>>2]|0;do{if((bIb(e)|0)==0){k=bv(n,c[n+20>>2]|0,c[n+24>>2]|0)|0;if((k|0)!=0){ZHb(k,c[j>>2]|0)|0;o=0;p=k;q=c[j>>2]|0;break}VHb(j);r=-12;i=f;return r|0}else{o=1;p=e;q=e}}while(0);e=m+40|0;k=m+76|0;s=k;t=m+104|0;u=c[t>>2]|0;v=c[q+32>>2]|0;w=m+24|0;x=c[w>>2]|0;y=m+28|0;z=c[y>>2]|0;do{if((z|0)>0){A=e;B=m+44|0;C=m+48|0;D=m+52|0;E=m+56|0;F=m+60|0;G=m+64|0;H=m+68|0;I=m+72|0;if((x|0)<=0){break}J=c[q>>2]|0;K=0;L=c[k>>2]|0;M=c[m+80>>2]|0;N=c[m+84>>2]|0;while(1){O=0;P=J;while(1){Q=P+1|0;R=P+2|0;g[L+(O<<2)>>2]=+g[A>>2]*+(d[P]|0|0)+ +g[B>>2]*+(d[Q]|0|0)+ +g[C>>2]*+(d[R]|0|0);g[M+(O<<2)>>2]=+g[D>>2]*+(d[P]|0|0)+ +g[E>>2]*+(d[Q]|0|0)+ +g[F>>2]*+(d[R]|0|0);g[N+(O<<2)>>2]=+g[G>>2]*+(d[P]|0|0)+ +g[H>>2]*+(d[Q]|0|0)+ +g[I>>2]*+(d[R]|0|0);R=O+1|0;if((R|0)<(x|0)){O=R;P=P+3|0}else{break}}P=K+1|0;if((P|0)<(z|0)){J=J+v|0;K=P;L=L+(u<<2)|0;M=M+(u<<2)|0;N=N+(u<<2)|0}else{break}}}}while(0);v=m+88|0;k=v;q=0;N=u;u=x;x=z;while(1){z=c[k+(q<<2)>>2]|0;M=c[s+(q<<2)>>2]|0;L=c[l>>2]|0;K=c[L+100>>2]|0;mrc(z|0,0,ca(N<<2,x)|0)|0;J=x-15|0;if((J|0)>0){I=u-15|0;H=(I|0)>0;G=L+112|0;F=L+124|0;E=L+116|0;D=L+128|0;C=L+8|0;B=L+120|0;A=L+16|0;P=L+36|0;O=0;R=M;M=z;while(1){if(H){Q=0;while(1){S=0;T=R+(Q<<2)|0;while(1){U=c[F>>2]|0;nrc(U|0,T|0,64)|0;H1(c[E>>2]|0,U);V=c[D>>2]|0;g[V+(S<<2)>>2]=+g[U>>2]*.25;g[V+(S+16<<2)>>2]=+g[U+4>>2]*.3535533905932738;g[V+(S+32<<2)>>2]=+g[U+8>>2]*.3535533905932738;g[V+(S+48<<2)>>2]=+g[U+12>>2]*.3535533905932738;g[V+(S+64<<2)>>2]=+g[U+16>>2]*.3535533905932738;g[V+(S+80<<2)>>2]=+g[U+20>>2]*.3535533905932738;g[V+(S+96<<2)>>2]=+g[U+24>>2]*.3535533905932738;g[V+(S+112<<2)>>2]=+g[U+28>>2]*.3535533905932738;g[V+(S+128<<2)>>2]=+g[U+32>>2]*.3535533905932738;g[V+(S+144<<2)>>2]=+g[U+36>>2]*.3535533905932738;g[V+(S+160<<2)>>2]=+g[U+40>>2]*.3535533905932738;g[V+(S+176<<2)>>2]=+g[U+44>>2]*.3535533905932738;g[V+(S+192<<2)>>2]=+g[U+48>>2]*.3535533905932738;g[V+(S+208<<2)>>2]=+g[U+52>>2]*.3535533905932738;g[V+(S+224<<2)>>2]=+g[U+56>>2]*.3535533905932738;g[V+(S+240<<2)>>2]=+g[U+60>>2]*.3535533905932738;U=S+1|0;if((U|0)<16){S=U;T=T+(N<<2)|0}else{W=0;X=V;break}}while(1){H1(c[E>>2]|0,X);g[X>>2]=+g[X>>2]*.25;T=X+4|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+8|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+12|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+16|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+20|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+24|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+28|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+32|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+36|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+40|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+44|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+48|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+52|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+56|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=X+60|0;g[T>>2]=+g[T>>2]*.3535533905932738;T=W+1|0;if((T|0)<16){W=T;X=X+64|0}else{break}}T=c[D>>2]|0;S=c[F>>2]|0;V=0;do{U=V<<4;Y=0;do{g[S+(Y+U<<2)>>2]=+g[T+((Y<<4)+V<<2)>>2];Y=Y+1|0;}while((Y|0)<16);V=V+1|0;}while((V|0)<16);if((c[C>>2]|0)==0){V=0;Y=S;while(1){U=0;Z=Y;while(1){_=+g[Z>>2];if(_<0.0){$=-0.0-_}else{$=_}if($<+g[P>>2]){g[Z>>2]=0.0}aa=U+1|0;if((aa|0)<16){U=aa;Z=Z+4|0}else{break}}Z=V+1|0;if((Z|0)<16){V=Z;Y=Y+64|0}else{ba=S;da=T;break}}}else{T=0;Y=S;while(1){V=0;Z=Y;while(1){_=+g[Z>>2];if(_<0.0){ea=-0.0-_}else{ea=_}h[A>>3]=ea;_=+XGb(c[C>>2]|0,A,L);g[Z>>2]=_*+g[Z>>2];U=V+1|0;if((U|0)<16){V=U;Z=Z+4|0}else{break}}Z=T+1|0;if((Z|0)<16){T=Z;Y=Y+64|0}else{break}}ba=c[F>>2]|0;da=c[D>>2]|0}Y=0;T=ba;while(1){g[T>>2]=+g[T>>2]*4.0;S=T+4|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+8|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+12|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+16|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+20|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+24|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+28|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+32|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+36|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+40|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+44|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+48|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+52|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+56|0;g[S>>2]=+g[S>>2]*2.82842712474619;S=T+60|0;g[S>>2]=+g[S>>2]*2.82842712474619;H1(c[B>>2]|0,T);S=Y+1|0;if((S|0)<16){Y=S;T=T+64|0}else{break}}T=c[F>>2]|0;Y=0;do{g[da>>2]=+g[T+(Y<<2)>>2]*4.0;S=1;do{g[da+(S<<2)>>2]=+g[T+((S<<4)+Y<<2)>>2]*2.82842712474619;S=S+1|0;}while((S|0)<16);H1(c[B>>2]|0,da);S=Y+Q|0;Z=0;do{V=M+(S+(ca(Z,N)|0)<<2)|0;g[V>>2]=+g[da+(Z<<2)>>2]+ +g[V>>2];Z=Z+1|0;}while((Z|0)<16);Y=Y+1|0;}while((Y|0)<16);Y=c[G>>2]|0;T=Y+Q|0;if((T|0)<(I|0)){Q=T}else{fa=Y;break}}}else{fa=c[G>>2]|0}Q=ca(fa,N)|0;Y=fa+O|0;if((Y|0)<(J|0)){O=Y;R=R+(Q<<2)|0;M=M+(Q<<2)|0}else{break}}}if((x|0)>0&(u|0)>0){M=0;R=z;O=K;while(1){J=0;do{G=R+(J<<2)|0;g[G>>2]=+g[O+(J<<2)>>2]*+g[G>>2];J=J+1|0;}while((J|0)<(u|0));J=M+1|0;if((J|0)<(x|0)){M=J;R=R+(N<<2)|0;O=O+(N<<2)|0}else{break}}}O=q+1|0;if((O|0)>=3){break}q=O;N=c[t>>2]|0;u=c[w>>2]|0;x=c[y>>2]|0}x=p|0;u=p+32|0;N=c[u>>2]|0;q=c[t>>2]|0;t=c[w>>2]|0;fa=c[y>>2]|0;do{if((fa|0)>0){da=e;ba=m+52|0;X=m+64|0;W=m+44|0;l=m+56|0;s=m+68|0;k=m+48|0;O=m+60|0;R=m+72|0;if((t|0)<=0){break}M=c[x>>2]|0;K=0;z=c[v>>2]|0;J=c[m+92>>2]|0;G=c[m+96>>2]|0;while(1){I=0;B=M;while(1){F=z+(I<<2)|0;D=J+(I<<2)|0;L=G+(I<<2)|0;A=~~(+g[F>>2]*+g[da>>2]+ +g[D>>2]*+g[ba>>2]+ +g[L>>2]*+g[X>>2]);if(A>>>0>255>>>0){ga=-A>>31&255}else{ga=A&255}a[B]=ga;A=~~(+g[F>>2]*+g[W>>2]+ +g[D>>2]*+g[l>>2]+ +g[L>>2]*+g[s>>2]);if(A>>>0>255>>>0){ha=-A>>31&255}else{ha=A&255}a[B+1|0]=ha;A=~~(+g[F>>2]*+g[k>>2]+ +g[D>>2]*+g[O>>2]+ +g[L>>2]*+g[R>>2]);if(A>>>0>255>>>0){ia=-A>>31&255}else{ia=A&255}a[B+2|0]=ia;A=I+1|0;if((A|0)<(t|0)){I=A;B=B+3|0}else{break}}B=K+1|0;if((B|0)<(fa|0)){M=M+N|0;K=B;z=z+(q<<2)|0;J=J+(q<<2)|0;G=G+(q<<2)|0}else{break}}}}while(0);if((o|0)==0){o=c[x>>2]|0;x=c[j>>2]|0;q=c[x>>2]|0;N=c[u>>2]|0;u=c[x+32>>2]|0;x=b+20|0;fa=c[w>>2]|0;w=((c[x>>2]|0)-fa|0)*3|0;t=c[b+24>>2]|0;b=c[y>>2]|0;ia=t-b|0;do{if((w|0)==0){ja=b}else{ha=fa*3|0;if((b|0)<=0){ja=b;break}ga=0;m=o+ha|0;v=q+ha|0;while(1){nrc(m|0,v|0,w)|0;ha=ga+1|0;e=c[y>>2]|0;if((ha|0)<(e|0)){ga=ha;m=m+N|0;v=v+u|0}else{ja=e;break}}}}while(0);a:do{if((t|0)!=(b|0)&(ia|0)>0){y=1;w=o+(ca(ja,N)|0)|0;fa=q+(ca(ja,u)|0)|0;while(1){nrc(w|0,fa|0,(c[x>>2]|0)*3|0)|0;if((y|0)>=(ia|0)){break a}y=y+1|0;w=w+N|0;fa=fa+u|0}}}while(0);VHb(j)}r=lj(n,p)|0;i=f;return r|0}function rn(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+48|0;e=b|0;f=b+40|0;h=c[a+8>>2]|0;j=c[h+44>>2]|0;g[e>>2]=.5773502588272095;g[e+4>>2]=.5773502588272095;g[e+8>>2]=.5773502588272095;g[e+12>>2]=.7071067690849304;g[e+16>>2]=0.0;g[e+20>>2]=-.7071067690849304;g[e+24>>2]=.40824830532073975;g[e+28>>2]=-.8164966106414795;g[e+32>>2]=.40824830532073975;k=f|0;Kz(k,c[a+52>>2]|0)|0;l=d[k]|0;g[j+40>>2]=+g[e+(l*12|0)+(l<<2)>>2];l=f+1|0;g[j+44>>2]=+g[e+((d[k]|0)*12|0)+((d[l]|0)<<2)>>2];m=f+2|0;g[j+48>>2]=+g[e+((d[k]|0)*12|0)+((d[m]|0)<<2)>>2];g[j+52>>2]=+g[e+((d[l]|0)*12|0)+((d[k]|0)<<2)>>2];f=d[l]|0;g[j+56>>2]=+g[e+(f*12|0)+(f<<2)>>2];g[j+60>>2]=+g[e+((d[l]|0)*12|0)+((d[m]|0)<<2)>>2];g[j+64>>2]=+g[e+((d[m]|0)*12|0)+((d[k]|0)<<2)>>2];g[j+68>>2]=+g[e+((d[m]|0)*12|0)+((d[l]|0)<<2)>>2];l=d[m]|0;g[j+72>>2]=+g[e+(l*12|0)+(l<<2)>>2];l=a+20|0;e=c[l>>2]|0;m=j+112|0;k=c[m>>2]|0;f=e-((e-16|0)%(k|0)|0)|0;e=j+24|0;c[e>>2]=f;n=a+24|0;a=c[n>>2]|0;o=a-((a-16|0)%(k|0)|0)|0;k=j+28|0;c[k>>2]=o;a=c[l>>2]|0;if((f|0)==(a|0)){p=o}else{KIb(h,24,2584680,(q=i,i=i+8|0,c[q>>2]=a-f,q)|0);i=q;p=c[k>>2]|0}f=c[n>>2]|0;if((p|0)!=(f|0)){KIb(h,24,2563856,(q=i,i=i+8|0,c[q>>2]=f-p,q)|0);i=q}q=(c[e>>2]|0)+31&-32;c[j+104>>2]=q;p=q<<2;f=j+76|0;h=0;while(1){r=hJb(ca(p,c[k>>2]|0)|0)|0;s=r;if((h|0)>=2){t=10;break}n=f+(h*12|0)|0;c[n>>2]=s;a=f+(h*12|0)+4|0;c[a>>2]=hJb(ca(p,c[k>>2]|0)|0)|0;o=hJb(ca(p,c[k>>2]|0)|0)|0;c[f+(h*12|0)+8>>2]=o;if((c[n>>2]|0)==0){u=-12;t=28;break}if((c[a>>2]|0)==0|(o|0)==0){u=-12;t=28;break}h=h+1|0}if((t|0)==10){h=j+100|0;c[h>>2]=s;if((r|0)==0){u=-12;i=b;return u|0}r=qJb(c[k>>2]|0,p)|0;p=r;if((r|0)==0){u=-12;i=b;return u|0}s=c[k>>2]|0;if((s-15|0)>0){j=0;f=c[e>>2]|0;o=s;while(1){if((f-15|0)>0){a=0;do{n=0;do{l=(ca(n+j|0,q)|0)+a|0;v=p+(l<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+1<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+2<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+3<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+4<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+5<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+6<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+7<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+8<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+9<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+10<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+11<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+12<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+13<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+14<<2)|0;c[v>>2]=(c[v>>2]|0)+1;v=p+(l+15<<2)|0;c[v>>2]=(c[v>>2]|0)+1;n=n+1|0;}while((n|0)<16);w=c[m>>2]|0;a=w+a|0;x=c[e>>2]|0;}while((a|0)<(x-15|0));y=x;z=c[k>>2]|0;A=w}else{y=f;z=o;A=c[m>>2]|0}a=A+j|0;if((a|0)<(z-15|0)){j=a;f=y;o=z}else{B=z;break}}}else{B=s}if((B|0)>0){s=c[e>>2]|0;e=(s|0)>0;z=0;do{if(e){o=ca(z,q)|0;y=c[h>>2]|0;f=0;do{j=f+o|0;g[y+(j<<2)>>2]=1.0/+(c[p+(j<<2)>>2]|0);f=f+1|0;}while((f|0)<(s|0))}z=z+1|0;}while((z|0)<(B|0))}kJb(r);u=0;i=b;return u|0}else if((t|0)==28){i=b;return u|0}return 0}function sn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=d|0;g=rJb(2438248)|0;c[f>>2]=g;mrc(d+4|0,0,32)|0;c[d+36>>2]=214;c[d+40>>2]=0;c[d+44>>2]=0;h=d+48|0;c[h>>2]=1270;c[d+52>>2]=0;c[d+56>>2]=0;if((g|0)==0){j=-12;i=b;return j|0}g=a+24|0;k=a+12|0;l=a+16|0;Qi(0,g,12,k,l,d)|0;m=a+20|0;c[m>>2]=c[g>>2];do{if((c[e+128>>2]|0)!=0){n=rJb(2350984)|0;c[f>>2]=n;c[h>>2]=0;if((n|0)==0){j=-12;i=b;return j|0}else{Qi(1,g,12,k,l,d)|0;c[m>>2]=c[g>>2];break}}}while(0);g=c[e+120>>2]|0;do{if((g-1&g|0)==0){m=c[e+124>>2]|0;if((m-1&m|0)!=0){break}m=e+40|0;c[m>>2]=0;c[m+4>>2]=-2147483648;j=0;i=b;return j|0}}while(0);KIb(a,16,2289432,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-22;i=b;return j|0}function tn(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;VHb(b+16|0);mJb(b+76|0);mJb(b+4|0);mJb(b+20|0);b=a+24|0;if((c[b>>2]|0)==0){return}d=a+12|0;a=0;do{mJb((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function un(a){a=a|0;dl(a,Ok(686096)|0);return 0}function vn(a,b){a=a|0;b=b|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0.0,Na=0.0;f=i;i=i+8|0;g=f|0;j=c[a+8>>2]|0;k=c[c[j+32>>2]>>2]|0;l=c[j+44>>2]|0;m=l+8|0;n=c[m>>2]|0;do{if((c[a+12>>2]|0)==(c[j+12>>2]|0)){c[(c[l+4>>2]|0)+(n*24|0)>>2]=b;c[l+24>>2]=1}else{c[(c[l+20>>2]|0)+(n<<2)>>2]=b;c[l+28>>2]=1;if((c[l+24>>2]|0)==0){o=0}else{break}i=f;return o|0}}while(0);a=l+24|0;p=l+128|0;q=l+28|0;do{if((c[p>>2]|0)!=0){if((c[q>>2]|0)==0){o=0}else{break}i=f;return o|0}}while(0);c[q>>2]=0;c[a>>2]=0;if((b|0)==0){r=-1;s=-1;t=0;u=-2147483648}else{if((n|0)==0){v=l+16|0;w=c[l+4>>2]|0}else{a=c[l+4>>2]|0;v=a+((n-1|0)*24|0)|0;w=a}a=c[v>>2]|0;v=(a|0)==0?b:a;a=l+4|0;q=c[l+76>>2]|0;x=l+72|0;mrc(q|0,0,c[x>>2]<<3|0)|0;y=v+68|0;z=v+72|0;A=l+120|0;B=l+124|0;C=l+60|0;D=l+64|0;E=l+52|0;H=l+56|0;I=v+8|0;J=(c[l+132>>2]|0)==0;K=0;while(1){if(J){L=1}else{L=(c[I>>2]|0)!=0?3:1}if((K|0)>=(L|0)){break}M=c[v+32+(K<<2)>>2]|0;N=c[b+32+(K<<2)>>2]|0;O=c[y>>2]|0;if((K|0)==0){P=(c[B>>2]|0)/2|0;S=(c[A>>2]|0)/2|0;T=O;U=c[z>>2]|0}else{V=c[E>>2]|0;W=c[H>>2]|0;P=((c[B>>2]|0)/2|0)>>W;S=((c[A>>2]|0)/2|0)>>V;T=-(-O>>V)|0;U=-(-(c[z>>2]|0)>>W)|0}a:do{if((U|0)>0){W=(T|0)>0;V=(c[C>>2]|0)==8;O=c[v+(K<<2)>>2]|0;X=c[b+(K<<2)>>2]|0;Y=0;while(1){Z=(Y|0)/(P|0)|0;do{if(V){if(W){_=0;$=0}else{break}while(1){aa=_+S|0;da=(T|0)>(aa|0);ea=da?aa:T;if((_|0)<(ea|0)){fa=_;ga=0;ia=0;while(1){ja=(d[O+fa|0]|0)-(d[X+fa|0]|0)|0;ka=(ja|0)>-1?ja:-ja|0;ja=wrc(ka,(ka|0)<0|0?-1:0,ia,ga)|0;ka=G;la=fa+1|0;if((la|0)<(ea|0)){fa=la;ga=ka;ia=ja}else{ma=ka;na=ja;break}}}else{ma=0;na=0}ia=q+((ca(c[D>>2]|0,Z)|0)+$<<3)|0;ga=wrc(c[ia>>2]|0,c[ia+4>>2]|0,na,ma)|0;c[ia>>2]=ga;c[ia+4>>2]=G;if(da){_=aa;$=$+1|0}else{break}}}else{if(!W){break}ia=ca(c[D>>2]|0,Z)|0;ga=O;fa=X;ea=0;ja=0;while(1){ka=ea+S|0;la=(T|0)>(ka|0);oa=la?ka:T;if((ea|0)<(oa|0)){pa=ea;qa=0;ra=0;while(1){sa=(e[ga+(pa<<1)>>1]|0)-(e[fa+(pa<<1)>>1]|0)|0;ta=(sa|0)>-1?sa:-sa|0;sa=wrc(ta,(ta|0)<0|0?-1:0,ra,qa)|0;ta=G;ua=pa+1|0;if((ua|0)<(oa|0)){pa=ua;qa=ta;ra=sa}else{va=ta;wa=sa;break}}}else{va=0;wa=0}ra=q+(ja+ia<<3)|0;qa=wrc(c[ra>>2]|0,c[ra+4>>2]|0,wa,va)|0;c[ra>>2]=qa;c[ra+4>>2]=G;if(la){ea=ka;ja=ja+1|0}else{break}}}}while(0);Z=Y+1|0;if((Z|0)>=(U|0)){break a}O=O+M|0;X=X+N|0;Y=Z}}}while(0);K=K+1|0}K=(c[l+68>>2]|0)-1|0;do{if((K|0)>0){U=c[D>>2]|0;va=U-1|0;if((va|0)>0){xa=0;ya=-1;za=-1}else{Aa=-1;Ba=-1;break}while(1){wa=xa+1|0;T=ca(xa,U)|0;S=ca(wa,U)|0;$=0;_=ya;ma=za;do{na=$+T|0;P=q+(na<<3)|0;v=q+(na+1<<3)|0;na=wrc(c[v>>2]|0,c[v+4>>2]|0,c[P>>2]|0,c[P+4>>2]|0)|0;P=$+S|0;v=q+(P<<3)|0;C=wrc(na,G,c[v>>2]|0,c[v+4>>2]|0)|0;v=q+(P+1<<3)|0;P=wrc(C,G,c[v>>2]|0,c[v+4>>2]|0)|0;v=G;C=(v|0)>(_|0)|(v|0)==(_|0)&P>>>0>ma>>>0;ma=C?P:ma;_=C?v:_;$=$+1|0;}while(($|0)<(va|0));if((wa|0)<(K|0)){xa=wa;ya=_;za=ma}else{Aa=_;Ba=ma;break}}}else{Aa=-1;Ba=-1}}while(0);za=w+(n*24|0)+16|0;c[za>>2]=0;c[za+4>>2]=0;ya=c[x>>2]|0;if((ya|0)>0){x=0;xa=0;K=0;do{D=q+(x<<3)|0;K=wrc(c[D>>2]|0,c[D+4>>2]|0,K,xa)|0;xa=G;c[za>>2]=K;c[za+4>>2]=xa;x=x+1|0;}while((x|0)<(ya|0))}ya=w+(n*24|0)+8|0;c[ya>>2]=Ba;c[ya+4>>2]=Aa;Aa=(c[m>>2]|0)+1|0;c[m>>2]=Aa;ya=l+80|0;if((Aa|0)!=(c[ya>>2]|0)){o=0;i=f;return o|0}Aa=l+16|0;VHb(Aa);c[Aa>>2]=$Hb(b)|0;c[m>>2]=0;m=c[ya>>2]|0;ya=c[a>>2]|0;if((m|0)>0){a=l+112|0;b=c[a>>2]|0;Aa=c[a+4>>2]|0;a=0;Ba=0;n=-1;while(1){w=ya+(a*24|0)+16|0;x=c[w+4>>2]|0;xa=(x|0)>(Aa|0)|(x|0)==(Aa|0)&(c[w>>2]|0)>>>0>b>>>0?a:n;w=ya+(a*24|0)+8|0;x=c[w+4>>2]|0;za=ya+(Ba*24|0)+8|0;K=c[za+4>>2]|0;q=(x|0)<(K|0)|(x|0)==(K|0)&(c[w>>2]|0)>>>0<(c[za>>2]|0)>>>0?a:Ba;za=a+1|0;if((za|0)<(m|0)){a=za;Ba=q;n=xa}else{Ca=q;Da=xa;break}}}else{Ca=0;Da=-1}n=ya+(Ca*24|0)+8|0;ya=c[n+4>>2]|0;Ba=l+104|0;a=c[Ba+4>>2]|0;m=(ya|0)<(a|0)|(ya|0)==(a|0)&(c[n>>2]|0)>>>0<(c[Ba>>2]|0)>>>0?Ca:-1;r=Da;s=m;t=Ca;u=(Da|0)>-1&(m|0)<0?Da:Ca}b:do{if((MIb()|0)>47){Ca=j;Da=l+80|0;KIb(Ca,48,2239048,(m=i,i=i+8|0,c[m>>2]=c[Da>>2],m)|0);i=m;Ba=l+4|0;n=c[Da>>2]|0;if((n|0)>0){Ea=0;Fa=n}else{o=0;i=f;return o|0}while(1){n=c[Ba>>2]|0;if((c[n+(Ea*24|0)>>2]|0)==0){Ga=Fa;Ha=Ba;break b}a=Ea+1|0;ya=n+(Ea*24|0)+16|0;b=c[ya>>2]|0;Aa=c[ya+4>>2]|0;ya=n+(Ea*24|0)+8|0;n=c[ya>>2]|0;xa=c[ya+4>>2]|0;KIb(Ca,48,2198120,(m=i,i=i+72|0,c[m>>2]=a,c[m+8>>2]=b,c[m+16>>2]=Aa,c[m+24>>2]=n,c[m+32>>2]=xa,c[m+40>>2]=(Ea|0)==(r|0)?2166584:10230008,c[m+48>>2]=(Ea|0)==(s|0)?2116760:10230008,c[m+56>>2]=(Ea|0)==(t|0)?2634680:10230008,c[m+64>>2]=(Ea|0)==(u|0)?2611080:10230008,m)|0);i=m;xa=c[Da>>2]|0;if((a|0)<(xa|0)){Ea=a;Fa=xa}else{Ga=xa;Ha=Ba;break}}}else{Ga=c[l+80>>2]|0;Ha=l+4|0}}while(0);Fa=l+80|0;if((Ga|0)<=0){o=0;i=f;return o|0}Ga=l+20|0;Ea=k+160|0;t=l+32|0;s=l+40|0;l=0;r=0;while(1){j=c[Ha>>2]|0;Ba=c[j+(l*24|0)>>2]|0;if((Ba|0)==0){o=r;Ia=65;break}if((l|0)==(u|0)){if((c[p>>2]|0)==0){Ja=j}else{VHb((c[Ga>>2]|0)+(u<<2)|0);Ja=c[Ha>>2]|0}VHb(Ja+(u*24|0)|0);Ka=r}else{c[g>>2]=Ba;j=Ba+136|0;Da=c[j>>2]|0;m=c[j+4>>2]|0;do{if(!((Da|0)==0&(m|0)==(-2147483648|0))){if(!((c[s>>2]|0)==0&(c[s+4>>2]|0)==(-2147483648|0))){break}c[s>>2]=Da;c[s+4>>2]=m}}while(0);if((c[p>>2]|0)==0){La=Ba}else{VHb(g);m=c[(c[Ga>>2]|0)+(l<<2)>>2]|0;c[g>>2]=m;La=m}m=c[s>>2]|0;Da=c[s+4>>2]|0;if((m|0)==0&(Da|0)==(-2147483648|0)){Ma=0.0}else{Ma=+(m>>>0)+ +(Da|0)*4294967296.0}Na=(+((c[Ea>>2]|0)>>>0)+ +(c[Ea+4>>2]|0)*4294967296.0)*+h[t>>3]+Ma;Da=(F=+Na,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);m=La+136|0;c[m>>2]=~~+Na>>>0;c[m+4>>2]=Da;Da=lj(k,La)|0;if((Da|0)<0){o=Da;Ia=65;break}else{Ka=Da}}Da=l+1|0;if((Da|0)<(c[Fa>>2]|0)){l=Da;r=Ka}else{o=Ka;Ia=65;break}}if((Ia|0)==65){i=f;return o|0}return 0}function wn(a){a=a|0;var b=0,f=0,g=0,i=0,j=0,k=0,l=0.0,m=0,n=0,o=0;b=c[(c[a+8>>2]|0)+44>>2]|0;f=qKb(c[a+52>>2]|0)|0;g=c[a+20>>2]|0;i=c[a+24>>2]|0;c[b+52>>2]=d[f+5|0]|0;c[b+56>>2]=d[f+6|0]|0;a=((e[f+8>>1]|0)>>>11&15)+1|0;c[b+60>>2]=a;f=(1<<a)-1|0;a=f;j=(f|0)<0|0?-1:0;f=Erc(i,(i|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;k=Erc(f,G,a,j)|0;l=+h[b+96>>3]*(+(k>>>0)+ +(G|0)*4294967296.0)/100.0;k=(F=+l,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);f=b+112|0;c[f>>2]=~~+l>>>0;c[f+4>>2]=k;k=c[b+120>>2]|0;f=c[b+124>>2]|0;m=Erc(f,(f|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;n=Erc(m,G,a,j)|0;l=+h[b+88>>3]*(+(n>>>0)+ +(G|0)*4294967296.0)/100.0;n=(F=+l,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);j=b+104|0;c[j>>2]=~~+l>>>0;c[j+4>>2]=n;n=(k|0)/2|0;k=(g-1+n|0)/(n|0)|0;c[b+64>>2]=k;n=(f|0)/2|0;f=(i-1+n|0)/(n|0)|0;c[b+68>>2]=f;n=ca(k,f)|0;c[b+72>>2]=n;f=b+76|0;c[f>>2]=hJb(n<<3)|0;n=b+80|0;k=qJb(c[n>>2]|0,24)|0;c[b+4>>2]=k;if((c[f>>2]|0)==0|(k|0)==0){o=-12;return o|0}do{if((c[b+128>>2]|0)!=0){k=qJb(c[n>>2]|0,4)|0;c[b+20>>2]=k;if((k|0)==0){o=-12}else{break}return o|0}}while(0);o=0;return o|0}function xn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a>>2]|0;a=b+44|0;d=c[a>>2]|0;e=d+128|0;f=c[e>>2]|0;g=f<<1|1;h=d+48|0;if((g&c[h>>2]|0)==(g|0)){i=-541478725;return i|0}do{if((c[d+24>>2]|0)==0){g=c[c[b+16>>2]>>2]|0;j=Wi(g)|0;if((j|0)==-541478725){c[h>>2]=c[h>>2]|1;k=vn(g,0)|0}else{k=j}if((k|0)<0){i=k;return i|0}else{l=c[e>>2]|0;break}}else{l=f}}while(0);do{if((l|0)!=0){f=c[a>>2]|0;if((c[f+28>>2]|0)!=0){break}e=c[(c[b+16>>2]|0)+4>>2]|0;k=Wi(e)|0;if((k|0)==-541478725){h=f+48|0;c[h>>2]=c[h>>2]|2;m=vn(e,0)|0}else{m=k}if((m|0)<0){i=m}else{break}return i|0}}while(0);i=0;return i|0}function yn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+8|0;d=b|0;e=d;f=i;i=i+8|0;g=i;i=i+8|0;j=g;k=i;i=i+8|0;l=c[a>>2]|0;m=c[l+44>>2]|0;n=c[(c[l+16>>2]|0)+(((c[m+128>>2]|0)!=0)<<2)>>2]|0;o=n+116|0;p=o;q=c[p>>2]|0;r=c[p+4>>2]|0;c[d>>2]=q;c[d+4>>2]=r;p=q;q=r;do{if((p|0)==0){s=q}else{if((q|0)==0){s=0;break}r=m+80|0;c[f>>2]=(c[r>>2]|0)-1;c[f+4>>2]=c[r>>2];yKb(j,e,f);r=c[g>>2]|0;t=c[g+4>>2]|0;c[d>>2]=r;c[d+4>>2]=t;u=c[n+120>>2]|0;KIb(l,40,2387536,(v=i,i=i+32|0,c[v>>2]=c[o>>2],c[v+8>>2]=u,c[v+16>>2]=r,c[v+24>>2]=t,v)|0);i=v;t=a+156|0;c[t>>2]=c[t>>2]|1;t=a+56|0;r=n+56|0;u=t;w=c[r+4>>2]|0;c[u>>2]=c[r>>2];c[u+4>>2]=w;w=a+116|0;u=c[d+4>>2]|0;c[w>>2]=c[d>>2];c[w+4>>2]=u;u=n+28|0;w=a+28|0;r=c[u+4>>2]|0;c[w>>2]=c[u>>2];c[w+4>>2]=r;c[a+20>>2]=c[n+20>>2];c[a+24>>2]=c[n+24>>2];yKb(k,e,t);h[m+32>>3]=+(c[k+4>>2]|0)/+(c[k>>2]|0);x=0;i=b;return x|0}}while(0);KIb(l,16,2394688,(v=i,i=i+16|0,c[v>>2]=p,c[v+8>>2]=s,v)|0);i=v;x=-22;i=b;return x|0}function zn(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;a=b+36|0;d=pJb((c[a>>2]<<3)+16|0)|0;c[b+4>>2]=d;if((d|0)==0){e=-12;return e|0}d=b+24|0;c[d>>2]=0;c[d+4>>2]=0;c[b+8>>2]=0;c[b+12>>2]=1;c[b+16>>2]=2;c[b+20>>2]=3;c[b+32>>2]=(c[a>>2]|0)+2;e=0;return e|0}function An(a){a=a|0;mJb((c[a+44>>2]|0)+4|0);return}function Bn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=i;i=i+8|0;g=i;i=i+8|0;h=c[a>>2]|0;j=c[c[h+16>>2]>>2]|0;k=(c[h+44>>2]|0)+36|0;l=c[k>>2]<<1;c[d>>2]=1;c[d+4>>2]=l;yKb(e,j+56|0,d);d=a+56|0;l=c[e+4>>2]|0;c[d>>2]=c[e>>2];c[d+4>>2]=l;c[f>>2]=c[k>>2]<<1;c[f+4>>2]=1;yKb(g,j+116|0,f);f=a+116|0;a=c[g+4>>2]|0;c[f>>2]=c[g>>2];c[f+4>>2]=a;KIb(h,40,2238712,(h=i,i=i+8|0,c[h>>2]=c[k>>2],h)|0);i=h;i=b;return 0}function Cn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;e=c[a+8>>2]|0;a=c[c[e+32>>2]>>2]|0;f=c[e+44>>2]|0;g=c[f+4>>2]|0;h=b+136|0;j=c[h>>2]|0;k=c[h+4>>2]|0;if((j|0)==0&(k|0)==(-2147483648|0)){l=lj(a,b)|0;i=d;return l|0}m=f+32|0;n=c[m>>2]|0;if((n|0)==0){o=c[f+12>>2]|0;p=g+(o<<3)|0;q=c[p+4>>2]|0;do{if((k|0)<(q|0)|(k|0)==(q|0)&j>>>0<(c[p>>2]|0)>>>0){r=c[f+16>>2]|0;s=g+(r<<3)|0;t=wrc(c[s>>2]|0,c[s+4>>2]|0,j,k)|0;s=c[f+20>>2]|0;u=g+(s<<3)|0;v=xrc(t,G,c[u>>2]|0,c[u+4>>2]|0)|0;u=c[f+8>>2]|0;t=g+(u<<3)|0;w=xrc(v,G,c[t>>2]|0,c[t+4>>2]|0)|0;t=G;v=c[f+36>>2]|0;x=v+2|0;if((x|0)>0){y=0}else{z=v;A=r;B=u;C=s;break}while(1){D=g+(y<<3)|0;E=wrc(w,t,c[D>>2]|0,c[D+4>>2]|0)|0;c[D>>2]=E;c[D+4>>2]=G;D=y+1|0;if((D|0)<(x|0)){y=D}else{z=v;A=r;B=u;C=s;break}}}else{z=c[f+36>>2]|0;A=c[f+16>>2]|0;B=c[f+8>>2]|0;C=c[f+20>>2]|0}}while(0);y=z-1|0;p=g+(A<<3)|0;q=g+(B<<3)|0;B=xrc(c[p>>2]|0,c[p+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;q=Erc(B,G,y,(y|0)<0|0?-1:0)|0;y=G;B=z+1|0;p=g+(C<<3)|0;s=xrc(j,k,c[p>>2]|0,c[p+4>>2]|0)|0;p=Erc(s,G,B,(B|0)<0|0?-1:0)|0;B=G;s=f+24|0;u=wrc(c[s>>2]|0,c[s+4>>2]|0,q,y)|0;y=wrc(u,G,p,B)|0;c[s>>2]=y;c[s+4>>2]=G;F=o;H=A;I=C;J=z}else{c[m>>2]=n-1;n=c[f+36>>2]|0;m=Erc(j<<1|0>>>31,k<<1|j>>>31,n,(n|0)<0|0?-1:0)|0;z=f+24|0;c[z>>2]=m;c[z+4>>2]=G;F=c[f+12>>2]|0;H=c[f+16>>2]|0;I=c[f+20>>2]|0;J=n}n=g+(F<<3)|0;c[n>>2]=j;c[n+4>>2]=k;c[f+8>>2]=F;c[f+12>>2]=H;c[f+16>>2]=I;H=f+36|0;F=J+2|0;c[f+20>>2]=(I+1|0)%(F|0)|0;I=f+24|0;f=c[I>>2]|0;J=c[I+4>>2]|0;c[h>>2]=f;c[h+4>>2]=J;I=e;if((F|0)>0){F=0;do{e=g+(F<<3)|0;n=c[e+4>>2]|0;KIb(I,48,2197904,(K=i,i=i+16|0,c[K>>2]=c[e>>2],c[K+8>>2]=n,K)|0);i=K;F=F+1|0;}while((F|0)<((c[H>>2]|0)+2|0));L=c[h+4>>2]|0;M=c[h>>2]|0}else{L=J;M=f}KIb(I,48,2166328,(K=i,i=i+32|0,c[K>>2]=j,c[K+8>>2]=k,c[K+16>>2]=M,c[K+24>>2]=L,K)|0);i=K;l=lj(a,b)|0;i=d;return l|0}function Dn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;d=c[a+44>>2]|0;e=d+4|0;f=c[e>>2]|0;if((f|0)==-1){KIb(d,16,2437464,(g=i,i=i+8|0,c[g>>2]=2350368,g)|0);i=g;h=-22;i=b;return h|0}j=d+8|0;k=c[j>>2]|0;if((k|0)==-1){KIb(d,16,2437464,(g=i,i=i+8|0,c[g>>2]=2288800,g)|0);i=g;h=-22;i=b;return h|0}l=d+12|0;m=c[l>>2]|0;if((m|0)==-1){KIb(d,16,2437464,(g=i,i=i+8|0,c[g>>2]=2238664,g)|0);i=g;h=-22;i=b;return h|0}n=d+16|0;o=c[n>>2]|0;if((o|0)==-1){KIb(d,16,2437464,(g=i,i=i+8|0,c[g>>2]=2197888,g)|0);i=g;h=-22;i=b;return h|0}else{p=d+20|0;q=c[p>>2]|0;r=c[d+24>>2]|0;KIb(a,40,2166232,(g=i,i=i+48|0,c[g>>2]=f,c[g+8>>2]=k,c[g+16>>2]=m,c[g+24>>2]=o,c[g+32>>2]=q,c[g+40>>2]=r,g)|0);i=g;g=c[p>>2]|0;p=g<<1;c[l>>2]=(c[l>>2]|0)+p;c[n>>2]=(c[n>>2]|0)+p;c[e>>2]=(c[e>>2]|0)-g;c[j>>2]=(c[j>>2]|0)-g;h=0;i=b;return h|0}return 0}function En(a){a=a|0;dl(a,Ok(686056)|0);return 0}function Fn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=c[b+8>>2]|0;j=c[h+44>>2]|0;k=c[c[h+32>>2]>>2]|0;h=qKb(c[b+52>>2]|0)|0;l=d[h+5|0]|0;m=d[h+6|0]|0;do{if((bIb(e)|0)==0){h=bv(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((h|0)!=0){ZHb(h,c[g>>2]|0)|0;n=h;o=1;p=c[g>>2]|0;break}VHb(g);q=-12;i=f;return q|0}else{n=e;o=0;p=e}}while(0);e=p+124|0;h=c[e+4>>2]|0;r=c[e>>2]|0;e=(r|0)==0;s=b+20|0;t=b+24|0;b=j+4|0;u=j+8|0;v=j+12|0;w=j+16|0;x=j+20|0;y=j+24|0;j=e?1:h;z=e?0:(h|0)<0|0?-1:0;h=e?1:r;A=e?0:(r|0)<0|0?-1:0;r=0;e=p;while(1){p=c[e+(r<<2)>>2]|0;if((p|0)==0){break}B=c[e+32+(r<<2)>>2]|0;if((B|0)==0){break}C=(r-1|0)>>>0<2>>>0;D=C?l:0;E=C?m:0;C=c[n+(r<<2)>>2]|0;F=c[n+32+(r<<2)>>2]|0;H=-(c[s>>2]|0)>>D;I=-(c[t>>2]|0)>>E;J=c[b>>2]|0;K=J>>D;L=c[u>>2]|0;M=L>>E;N=c[x>>2]>>(D>>>0>E>>>0?E:D);O=c[y>>2]|0;P=K-(-((c[v>>2]|0)+(J&(1<<D)-1)|0)>>D)|0;D=P+H|0;J=M-(-((c[w>>2]|0)+(L&(1<<E)-1)|0)>>E)|0;E=J+I|0;L=(K|0)<0?0:K;Q=P-((D|0)>0?D:0)|0;D=(M|0)<0?0:M;R=ca(D,B)|0;S=R+L|0;T=R-1+Q|0;U=J-((E|0)>0?E:0)-1|0;E=ca(U,B)|0;V=E+L|0;if(o){uIb(C,F,p,B,-H|0,-I|0)}I=D+1|0;if((I|0)<(U|0)){H=L+1|0;W=Q-1|0;Q=(H|0)<(W|0);X=N+M|0;Y=N+K|0;K=N;Z=0;_=N-1|0;$=J-N|0;aa=P-N|0;ba=1-P+N|0;P=N+1-J|0;J=(O|0)!=0;O=I;da=p+(ca(I,B)|0)|0;ea=C+(ca(I,F)|0)|0;while(1){I=O-D|0;C=ca(I,B)|0;fa=ca(I-1|0,B)|0;ga=ca(I+1|0,B)|0;ha=ea+H|0;ia=da+H|0;a:do{if(Q){ja=(d[p+(C+T)|0]|0)+(d[p+(fa+T)|0]|0)+(d[p+(ga+T)|0]|0)|0;ka=(d[p+(C+S)|0]|0)+(d[p+(fa+S)|0]|0)+(d[p+(ga+S)|0]|0)|0;la=I;ma=(I|0)<0|0?-1:0;na=U-O|0;oa=na;pa=(na|0)<0|0?-1:0;na=Erc(oa,pa,h,A)|0;qa=G;ra=Erc(la,ma,h,A)|0;sa=G;ta=ka;ka=0;ua=ja;ja=0;va=Erc(la,ma,j,z)|0;ma=Erc(va,G,oa,pa)|0;pa=G;oa=M-O+N|0;va=O>>>0<$>>>0;la=P+O|0;if(O>>>0<X>>>0){wa=ia;xa=ha;ya=L;za=H;while(1){Aa=W-za|0;Ba=Aa;Ca=(Aa|0)<0|0?-1:0;Aa=za-L|0;Da=Aa;Ea=(Aa|0)<0|0?-1:0;Fa=Erc(Da,Ea,Ba,Ca)|0;Ga=G;Ha=Erc(Fa,Ga,na,qa)|0;Ia=G;Ja=Erc(Fa,Ga,ra,sa)|0;Ga=G;Fa=Erc(Ba,Ca,ta,ka)|0;Ka=G;La=Erc(Da,Ea,ua,ja)|0;Ma=G;Na=Aa+1|0;Aa=(d[p+(ya+R)|0]|0)+(d[p+(za+R)|0]|0)+(d[p+(Na+S)|0]|0)|0;Oa=Erc(Aa,(Aa|0)<0|0?-1:0,Ha,Ia)|0;Aa=G;Pa=(d[p+(ya+E)|0]|0)+(d[p+(za+E)|0]|0)+(d[p+(Na+V)|0]|0)|0;Na=Erc(Pa,(Pa|0)<0|0?-1:0,Ja,Ga)|0;Pa=G;Qa=wrc(Fa,Ka,La,Ma)|0;Ma=Erc(ma,pa,Qa,G)|0;Qa=wrc(Oa,Aa,Ma,G)|0;Ma=wrc(Qa,G,Na,Pa)|0;Pa=G;Na=wrc(Ba,Ca,Da,Ea)|0;Ea=Erc(Na,G,ma,pa)|0;Na=wrc(Ea,G,Ha,Ia)|0;Ia=wrc(Na,G,Ja,Ga)|0;Ga=Erc(Ia,G,3,0)|0;Ia=Frc(Ma,Pa,Ga,G)|0;if(za>>>0<Y>>>0){Ra=Y-za|0}else{Ra=za>>>0<aa>>>0?0:za+ba|0}Ga=Ra>>>0>oa>>>0?Ra:oa;Pa=ca(d[wa]|0,Ga)|0;Ma=Erc(N-Ga|0,0,Ia,G)|0;Ia=wrc(Ma,G,Pa,0)|0;Pa=Frc(Ia,G,K,Z)|0;a[xa]=(Ga|0)==(_|0)&J?0:Pa&255;Pa=za+1|0;if((Pa|0)<(W|0)){wa=wa+1|0;xa=xa+1|0;ya=za;za=Pa}else{break a}}}else{Sa=ia;Ta=ha;Ua=L;Va=H}while(1){za=W-Va|0;ya=za;xa=(za|0)<0|0?-1:0;za=Va-L|0;wa=za;oa=(za|0)<0|0?-1:0;Pa=Erc(wa,oa,ya,xa)|0;Ga=G;Ia=Erc(Pa,Ga,na,qa)|0;Ma=G;Ja=Erc(Pa,Ga,ra,sa)|0;Ga=G;Pa=Erc(ya,xa,ta,ka)|0;Na=G;Ha=Erc(wa,oa,ua,ja)|0;Ea=G;Da=za+1|0;za=(d[p+(Ua+R)|0]|0)+(d[p+(Va+R)|0]|0)+(d[p+(Da+S)|0]|0)|0;Ca=Erc(za,(za|0)<0|0?-1:0,Ia,Ma)|0;za=G;Ba=(d[p+(Ua+E)|0]|0)+(d[p+(Va+E)|0]|0)+(d[p+(Da+V)|0]|0)|0;Da=Erc(Ba,(Ba|0)<0|0?-1:0,Ja,Ga)|0;Ba=G;Qa=wrc(Pa,Na,Ha,Ea)|0;Ea=Erc(ma,pa,Qa,G)|0;Qa=wrc(Ca,za,Ea,G)|0;Ea=wrc(Qa,G,Da,Ba)|0;Ba=G;Da=wrc(ya,xa,wa,oa)|0;oa=Erc(Da,G,ma,pa)|0;Da=wrc(oa,G,Ia,Ma)|0;Ma=wrc(Da,G,Ja,Ga)|0;Ga=Erc(Ma,G,3,0)|0;Ma=Frc(Ea,Ba,Ga,G)|0;Ga=G;Ba=Va>>>0<aa>>>0;do{if(va&Va>>>0>=Y>>>0&Ba){a[Ta]=Ma}else{if(Va>>>0<Y>>>0){Wa=Y-Va|0}else{Wa=Ba?0:Va+ba|0}if(va){Xa=Wa}else{Xa=Wa>>>0>la>>>0?Wa:la}Ea=ca(d[Sa]|0,Xa)|0;Ja=Erc(N-Xa|0,0,Ma,Ga)|0;Da=wrc(Ea,0,Ja,G)|0;Ja=Frc(Da,G,K,Z)|0;a[Ta]=Ja;if(!((Xa|0)==(_|0)&J)){break}a[Ta]=0}}while(0);Ga=Va+1|0;if((Ga|0)<(W|0)){Sa=Sa+1|0;Ta=Ta+1|0;Ua=Va;Va=Ga}else{break}}}}while(0);ha=O+1|0;if((ha|0)<(U|0)){O=ha;da=da+B|0;ea=ea+F|0}else{break}}}F=r+1|0;if((F|0)>=4){break}r=F;e=c[g>>2]|0}if(o){VHb(g)}q=lj(k,n)|0;i=f;return q|0}function Gn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+44>>2]|0;c[d+1312>>2]=20;e=d+20|0;f=c[e>>2]|0;g=(f|0)/2|0;if((f|0)<8){h=4}else{h=(g|0)>128?128:g}c[e>>2]=h;h=d+8|0;if((c[h>>2]&15|0)!=0){KIb(a,16,2437120,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1163346256;i=b;return k|0}g=c[d+1368>>2]|0;if((g|0)==0){l=c[d+1316>>2]|0}else{f=Qc(g|0,2350312)|0;c[d+1316>>2]=f;l=f}if((l|0)!=0){ub(2288624,1,104,l|0)|0}l=d+1360|0;f=c[l>>2]|0;if((f|0)>0){g=d+1352|0;c[g>>2]=(c[g>>2]|0)+(f&15);g=f&-16;c[l>>2]=g;m=g}else{m=f}c[d+1376>>2]=4;f=a;if((c[d+1372>>2]|0)==0){a=c[d+1364>>2]|0;g=c[d+1352>>2]|0;l=c[d+1356>>2]|0;n=c[h>>2]|0;h=c[d+12>>2]|0;o=c[d+16>>2]|0;p=c[e>>2]<<1;e=c[d+24>>2]|0;q=c[d+28>>2]|0;KIb(f,40,2197744,(j=i,i=i+80|0,c[j>>2]=m,c[j+8>>2]=a,c[j+16>>2]=g,c[j+24>>2]=l,c[j+32>>2]=n,c[j+40>>2]=h,c[j+48>>2]=o,c[j+56>>2]=p,c[j+64>>2]=e,c[j+72>>2]=q,j)|0);i=j;k=0;i=b;return k|0}else{KIb(f,16,2238544,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=b;return k|0}return 0}function Hn(a){a=a|0;var b=0;b=c[a+44>>2]|0;VHb(b+4|0);a=c[b+1316>>2]|0;if((a|0)!=0){nb(a|0)|0}a=b+32|0;b=c[a>>2]|0;if((b|0)==0){mJb(a);return}r5a(b)|0;mJb(a);return}function In(a){a=a|0;dl(a,Ok(686008)|0);return 0}function Jn(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0;a=i;i=i+48|0;n=a|0;o=a+16|0;p=a+32|0;c[n>>2]=g;c[n+8>>2]=h;c[n+4>>2]=h;c[o>>2]=b;c[o+8>>2]=e;c[o+4>>2]=e;c[p>>2]=d;c[p+8>>2]=f;c[p+4>>2]=f;f=0;d=0;while(1){if((d|0)>=3){q=f;r=4;break}e=lB(c[l+(d<<2)>>2]|0,c[m+(d<<2)>>2]|0,c[l+32+(d<<2)>>2]|0,c[m+32+(d<<2)>>2]|0,c[o+(d<<2)>>2]|0,c[p+(d<<2)>>2]|0,c[n+(d<<2)>>2]|0,j,k)|0;if((e|0)<0){q=e;r=4;break}else{f=e;d=d+1|0}}if((r|0)==4){i=a;return q|0}return 0}function Kn(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0,U=0.0,V=0.0;e=i;i=i+376|0;f=e|0;g=e+8|0;j=e+40|0;k=e+80|0;l=e+120|0;c[f>>2]=b;m=a+8|0;n=c[m>>2]|0;o=c[n+44>>2]|0;p=o;q=c[c[n+32>>2]>>2]|0;mrc(g|0,0,32)|0;r=2.0/+(c[o+1312>>2]|0);n=bv(q,c[q+20>>2]|0,c[q+24>>2]|0)|0;if((n|0)==0){VHb(f);s=-12;i=e;return s|0}ZHb(n,b)|0;b=o+1360|0;t=c[b>>2]|0;do{if((t|0)<0){u=7}else{v=o+1364|0;w=c[v>>2]|0;if((w|0)<0){u=7;break}x=o+1352|0;y=c[x>>2]|0;if((y|0)<0){u=7;break}z=o+1356|0;A=c[z>>2]|0;if((A|0)<0){u=7;break}B=c[o+4>>2]|0;C=c[f>>2]|0;D=c[((B|0)==0?C:B)>>2]|0;B=c[C>>2]|0;E=a+20|0;F=c[E>>2]|0;G=(t|0)>(F|0)?F:t;c[b>>2]=G;F=a+24|0;H=c[F>>2]|0;I=(w|0)>(H|0)?H:w;c[v>>2]=I;v=c[E>>2]|0;if((y+G|0)>>>0>v>>>0){E=v-G|0;c[x>>2]=E;J=E}else{J=y}y=c[F>>2]|0;if((A+I|0)>>>0>y>>>0){F=y-I|0;c[z>>2]=F;K=F}else{K=A}A=J&-16;c[x>>2]=A;x=c[C+32>>2]|0;C=(ca(x,I)|0)+G|0;Mn(p,D+C|0,B+C|0,A,K,x,g)}}while(0);if((u|0)==7){u=c[o+4>>2]|0;K=c[f>>2]|0;Mn(p,c[((u|0)==0?K:u)>>2]|0,c[K>>2]|0,c[a+20>>2]|0,c[a+24>>2]|0,c[K+32>>2]|0,g)}K=g|0;L=+h[K>>3];u=g+8|0;M=+h[u>>3];p=g+16|0;N=+h[p>>3];J=g+24|0;O=+h[J>>3];P=r;r=1.0-P;g=o+1320|0;Q=P*L+r*+h[g>>3];h[g>>3]=Q;g=o+1328|0;R=P*M+r*+h[g>>3];h[g>>3]=R;g=o+1336|0;S=P*N+r*+h[g>>3];h[g>>3]=S;g=o+1344|0;T=P*O+r*+h[g>>3];h[g>>3]=T;r=O-T;h[J>>3]=r;P=(L-Q)*-1.0;h[K>>3]=P;U=(M-R)*-1.0;h[u>>3]=U;V=(N-S)*-1.0;h[p>>3]=V;g=o+1316|0;if((c[g>>2]|0)!=0){b=l|0;Rb(b|0,256,2289968,(l=i,i=i+96|0,h[l>>3]=L,h[l+8>>3]=Q,h[l+16>>3]=P,h[l+24>>3]=M,h[l+32>>3]=R,h[l+40>>3]=U,h[l+48>>3]=N,h[l+56>>3]=S,h[l+64>>3]=V,h[l+72>>3]=O,h[l+80>>3]=T,h[l+88>>3]=r,l)|0)|0;i=l;l=lrc(b|0)|0;ub(b|0,1,l|0,c[g>>2]|0)|0}g=o+1280|0;T=+h[g>>3]+P;l=o+1288|0;P=+h[l>>3]+U;b=o+1296|0;U=+h[b>>3]+V;t=o+1304|0;V=+h[t>>3]+r;h[J>>3]=V;r=T*.9;h[K>>3]=r;T=P*.9;h[u>>3]=T;P=U*.9;h[p>>3]=P;h[g>>3]=r;h[l>>3]=T;h[b>>3]=P;h[t>>3]=V;U=P;P=V/100.0+1.0;t=j|0;kB(r,T,U,P,t);j=a+20|0;b=c[j>>2]|0;l=a+52|0;V=r/+((b|0)/(-(-b>>(d[(qKb(c[l>>2]|0)|0)+5|0]|0))|0)|0|0);b=a+24|0;a=c[b>>2]|0;g=k|0;kB(V,T/+((a|0)/(-(-a>>(d[(qKb(c[l>>2]|0)|0)+6|0]|0))|0)|0|0),U,P,g);a=c[o+1376>>2]|0;k=c[m>>2]|0;m=c[j>>2]|0;j=c[b>>2]|0;p=-(-m>>(d[(qKb(c[l>>2]|0)|0)+5|0]|0))|0;u=-(c[b>>2]|0)|0;b=-(u>>(d[(qKb(c[l>>2]|0)|0)+6|0]|0))|0;l=Be[a&7](k,m,j,p,b,t,g,1,c[o+16>>2]|0,c[f>>2]|0,n)|0;g=o+4|0;VHb(g);if((l|0)<0){s=l;i=e;return s|0}c[g>>2]=c[f>>2];s=lj(q,n)|0;i=e;return s|0}function Ln(a){a=a|0;var b=0;b=c[(c[a+8>>2]|0)+44>>2]|0;c[b+4>>2]=0;mrc(b+1280|0,0,32)|0;a=mWa(0)|0;c[b+32>>2]=a;Nba(b+36|0,a);return 0}function Mn(a,b,e,f,g,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0.0,eb=0.0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0.0,ub=0,vb=0,wb=0.0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0.0,Db=0.0,Eb=0.0,Fb=0.0,Gb=0.0;l=i;i=i+66568|0;m=l|0;n=ca(f<<3,g)|0;o=a+20|0;p=hJb((n>>>0)/(c[o>>2]<<4>>>0)|0)|0;n=p;q=a+8|0;r=c[q>>2]|0;s=r<<1|1;t=c[a+12>>2]|0;do{if((s|0)>0){if((t<<1|1|0)>0){u=0}else{break}do{v=t<<1|1;mrc(m+(u*516|0)|0,0,((v|0)>1?v<<2:4)|0)|0;u=u+1|0;}while((u|0)<(s|0))}}while(0);s=a+12|0;u=c[o>>2]|0;do{if((t|0)<(g-t-(u<<1)|0)){v=f-16|0;w=a+24|0;x=a+28|0;y=a+88|0;z=a;A=0;B=0;C=0;D=t;E=r;F=u;G=0;H=0;I=0;J=0;while(1){K=F<<1;if((E|0)<(v-E|0)){L=ca(D,j)|0;M=+(D|0);N=A;O=B;P=C;Q=E;R=K;S=E;T=G;W=H;X=I;Y=J;while(1){if((R|0)<0){Z=255;$=0}else{aa=255;ba=0;da=0;while(1){ea=(ca(D-ba|0,j)|0)+Q|0;fa=aa;ga=0;ha=da;while(1){ia=d[e+(ea-ga)|0]|0;if((ia|0)<(fa|0)){ja=ha;ka=ia}else{ja=(ia|0)>(ha|0)?ia:ha;ka=fa}ia=ga+1|0;if((ia|0)<16){fa=ka;ga=ia;ha=ja}else{break}}ha=ba+1|0;if((ha|0)>(R|0)){Z=ka;$=ja;break}else{aa=ka;ba=ha;da=ja}}}do{if(($-Z|0)>(c[w>>2]|0)){da=c[x>>2]|0;if((da|0)==1){ba=c[s>>2]|0;aa=1-ba|0;ha=b+(Q+L)|0;if((aa|0)<(ba|0)){ga=2147483647;fa=aa;aa=S;ea=ba;ba=X;ia=Y;while(1){la=1-aa|0;if((la|0)<(aa|0)){ma=(ca(D-fa|0,j)|0)+Q|0;na=ga;oa=la;la=ba;pa=ia;do{qa=Xe[c[y>>2]&511](z,ha,e+(ma-oa)|0,j,c[o>>2]|0)|0;ra=(qa|0)<(na|0);pa=ra?fa:pa;la=ra?oa:la;na=ra?qa:na;oa=oa+2|0;sa=c[q>>2]|0;}while((oa|0)<(sa|0));ta=na;ua=sa;va=c[s>>2]|0;wa=la;xa=pa}else{ta=ga;ua=aa;va=ea;wa=ba;xa=ia}oa=fa+2|0;if((oa|0)<(va|0)){ga=ta;fa=oa;aa=ua;ea=va;ba=wa;ia=xa}else{ya=ta;za=wa;Aa=xa;break}}}else{ya=2147483647;za=X;Aa=Y}ia=Aa+1|0;ba=za-1|0;ea=za+1|0;aa=ya;fa=Aa-1|0;ga=za;oa=Aa;while(1){ma=(ca(D-fa|0,j)|0)+Q|0;if((fa|0)==(Aa|0)){qa=aa;ra=ba;Ba=ga;Ca=oa;while(1){if((ra|0)==(za|0)){Da=qa;Ea=Ba;Fa=Ca}else{Ga=Xe[c[y>>2]&511](z,ha,e+(ma-ra)|0,j,c[o>>2]|0)|0;Ha=(Ga|0)<(qa|0);Da=Ha?Ga:qa;Ea=Ha?ra:Ba;Fa=Ha?Aa:Ca}Ha=ra+1|0;if((Ha|0)>(ea|0)){Ia=Da;Ja=Ea;Ka=Fa;break}else{qa=Da;ra=Ha;Ba=Ea;Ca=Fa}}}else{Ca=aa;Ba=ba;ra=ga;qa=oa;while(1){pa=Xe[c[y>>2]&511](z,ha,e+(ma-Ba)|0,j,c[o>>2]|0)|0;la=(pa|0)<(Ca|0);na=la?fa:qa;Ha=la?Ba:ra;Ga=la?pa:Ca;pa=Ba+1|0;if((pa|0)>(ea|0)){Ia=Ga;Ja=Ha;Ka=na;break}else{Ca=Ga;Ba=pa;ra=Ha;qa=na}}}qa=fa+1|0;if((qa|0)>(ia|0)){La=Ia;Ma=Ja;Na=Ka;Oa=Ja;Pa=Ka;break}else{aa=Ia;fa=qa;ga=Ja;oa=Ka}}}else if((da|0)==0){oa=c[s>>2]|0;ga=-oa|0;if((oa|0)<(ga|0)){Qa=P;Ra=O;Sa=N;Ta=-1;Ua=-1;Va=-1;Wa=-1;break}fa=b+(Q+L)|0;aa=2147483647;ia=ga;ga=S;ea=oa;oa=T;ha=W;ba=X;qa=Y;while(1){ra=-ga|0;if((ga|0)<(ra|0)){Xa=aa;Ya=ga;Za=ea;_a=oa;$a=ha;ab=ba;bb=qa}else{Ba=(ca(D-ia|0,j)|0)+Q|0;Ca=aa;ma=ra;ra=oa;na=ha;Ha=ba;pa=qa;do{Ga=Xe[c[y>>2]&511](z,fa,e+(Ba-ma)|0,j,c[o>>2]|0)|0;la=(Ga|0)<(Ca|0);pa=la?ia:pa;Ha=la?ma:Ha;na=la?ia:na;ra=la?ma:ra;Ca=la?Ga:Ca;ma=ma+1|0;cb=c[q>>2]|0;}while((ma|0)<=(cb|0));Xa=Ca;Ya=cb;Za=c[s>>2]|0;_a=ra;$a=na;ab=Ha;bb=pa}ma=ia+1|0;if((ma|0)>(Za|0)){La=Xa;Ma=_a;Na=$a;Oa=ab;Pa=bb;break}else{aa=Xa;ia=ma;ga=Ya;ea=Za;oa=_a;ha=$a;ba=ab;qa=bb}}}else{Qa=P;Ra=O;Sa=N;Ta=-1;Ua=-1;Va=-1;Wa=-1;break}if((La|0)>512){Qa=P;Ra=O;Sa=N;Ta=-1;Ua=-1;Va=-1;Wa=-1;break}if((Ma|0)==-1){Qa=P;Ra=O;Sa=N;Ta=-1;Ua=Na;Va=Oa;Wa=Pa;break}if((Na|0)==-1){Qa=P;Ra=O;Sa=N;Ta=Ma;Ua=-1;Va=Oa;Wa=Pa;break}qa=c[s>>2]|0;ba=c[q>>2]|0;ha=m+((ba+Ma|0)*516|0)+(qa+Na<<2)|0;c[ha>>2]=(c[ha>>2]|0)+1;if((Q|0)>(ba|0)&(D|0)>(qa|0)){db=+_(+(+(Pa+D|0)),+(+(Oa+Q|0)))- +_(+M,+(+(Q|0)));do{if(db>3.141592653589793){eb=db+ -6.283185307179586}else{if(!(db<-3.141592653589793)){eb=db;break}eb=db+6.283185307179586}}while(0);h[n+(N<<3)>>3]=eb;fb=N+1|0}else{fb=N}Qa=Pa+P|0;Ra=Oa+O|0;Sa=fb;Ta=Oa;Ua=Pa;Va=Oa;Wa=Pa}else{Qa=P;Ra=O;Sa=N;Ta=T;Ua=W;Va=X;Wa=Y}}while(0);qa=Q+16|0;ba=c[q>>2]|0;ha=c[o>>2]|0;oa=ha<<1;if((qa|0)<(v-ba|0)){N=Sa;O=Ra;P=Qa;Q=qa;R=oa;S=ba;T=Ta;W=Ua;X=Va;Y=Wa}else{gb=Sa;hb=Ra;ib=Qa;jb=oa;kb=ba;lb=Ta;mb=Ua;nb=Va;ob=Wa;pb=ha;break}}}else{gb=A;hb=B;ib=C;jb=K;kb=E;lb=G;mb=H;nb=I;ob=J;pb=F}Y=jb+D|0;if((Y|0)<(g-(c[s>>2]|0)-(pb<<1)|0)){A=gb;B=hb;C=ib;D=Y;E=kb;F=pb;G=lb;H=mb;I=nb;J=ob}else{break}}if((gb|0)==0){qb=ib;rb=hb;sb=53;break}J=(hb|0)/(gb|0)|0;I=(ib|0)/(gb|0)|0;H=(gb|0)/5|0;cd(p|0,gb|0,8,490);G=gb-H|0;if((H|0)<(G|0)){M=0.0;F=H;while(1){db=M+ +h[n+(F<<3)>>3];E=F+1|0;if((E|0)<(G|0)){M=db;F=E}else{tb=db;break}}}else{tb=0.0}M=tb/+(gb-(H<<1)|0);F=k+16|0;h[F>>3]=M;if(!(M<.001)){ub=I;vb=J;wb=M;break}h[F>>3]=0.0;ub=I;vb=J;wb=0.0}else{qb=0;rb=0;sb=53}}while(0);if((sb|0)==53){h[k+16>>3]=0.0;ub=qb;vb=rb;wb=0.0}rb=c[s>>2]|0;s=rb<<1;qb=c[q>>2]|0;do{if((s|0)>-1){q=qb<<1|1;sb=k|0;gb=k+8|0;if((q|0)>0){xb=0;yb=s}else{zb=sb;Ab=gb;break}while(1){n=xb;ib=0;while(1){hb=c[m+(ib*516|0)+(yb<<2)>>2]|0;if((hb|0)>(n|0)){h[sb>>3]=+(ib-qb|0);h[gb>>3]=+(yb-rb|0);Bb=hb}else{Bb=n}hb=ib+1|0;if((hb|0)<(q|0)){n=Bb;ib=hb}else{break}}if((yb|0)>0){xb=Bb;yb=yb-1|0}else{zb=sb;Ab=gb;break}}}else{zb=k|0;Ab=k+8|0}}while(0);tb=+(vb-((f|0)/2|0)|0);eb=+(ub-((g|0)/2|0)|0);g=k+16|0;M=+U(wb)+-1.0;db=+V(wb);Cb=+h[zb>>3]+(tb*M-eb*db);h[zb>>3]=Cb;Db=+h[Ab>>3]+(tb*db+eb*M);h[Ab>>3]=Db;M=Cb;Cb=+(-qb<<1|0);eb=+(qb<<1|0);if(M<Cb){Eb=Cb}else{Eb=M>eb?eb:M}h[zb>>3]=Eb;Eb=Db;Db=+(-rb<<1|0);M=+(s|0);if(Eb<Db){Fb=Db}else{Fb=Eb>M?M:Eb}h[Ab>>3]=Fb;Fb=wb;if(Fb<-.10000000149011612){Gb=-.10000000149011612;h[g>>3]=Gb;kJb(p);i=l;return}Gb=Fb>.10000000149011612?.10000000149011612:Fb;h[g>>3]=Gb;kJb(p);i=l;return}function Nn(a,b){a=a|0;b=b|0;var c=0.0,d=0.0,e=0;c=+h[a>>3];d=+h[b>>3];if(c<d){e=-1;return e|0}e=c>d|0;return e|0}function On(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+8|0;f=e|0;g=c[b+44>>2]|0;h=c[g+24>>2]|0;if((irc(h,2332520)|0)==0){c[g+32>>2]=1;j=0;i=e;return j|0}if((dKb(f|0,h,-1,b)|0)<0){j=-22;i=e;return j|0}if((c[g+32>>2]|0)!=0){j=0;i=e;return j|0}b=f|0;h=f+1|0;k=f+2|0;a[g+28|0]=(((d[b]|0)*263|0)+16896+((d[h]|0)*516|0)+((d[k]|0)*100|0)|0)>>>10;a[g+29|0]=((((d[b]|0)*-152|0)+511+((d[h]|0)*-298|0)+((d[k]|0)*450|0)|0)>>>10)+128;a[g+30|0]=((((d[b]|0)*450|0)+511+((d[h]|0)*-377|0)+((d[k]|0)*-73|0)|0)>>>10)+128;a[g+31|0]=a[f+3|0]|0;j=0;i=e;return j|0}function Pn(a){a=a|0;dl(a,Ok(685960)|0);return 0}function Qn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0.0,U=0,V=0,W=0;f=b+8|0;b=c[f>>2]|0;g=c[b+44>>2]|0;h=e+72|0;if((c[h>>2]|0)<=0){i=b;j=i+32|0;k=c[j>>2]|0;l=c[k>>2]|0;m=lj(l,e)|0;return m|0}b=e|0;n=e+32|0;o=g+36|0;p=g+32|0;q=e+68|0;r=g+4|0;s=g+8|0;t=g+12|0;u=g+16|0;v=g+20|0;w=g+31|0;x=g+28|0;y=g+40|0;z=g+29|0;A=g+30|0;g=0;do{B=c[b>>2]|0;C=ca(c[n>>2]|0,g)|0;D=g>>c[o>>2];E=c[e+4>>2]|0;F=ca(D,c[e+36>>2]|0)|0;G=c[e+8>>2]|0;H=ca(D,c[e+40>>2]|0)|0;D=c[q>>2]|0;I=(D|0)>0;do{if((c[p>>2]|0)==0){if(I){J=0;K=D}else{break}while(1){L=+((d[w]|0)>>>0)/255.0;M=c[t>>2]|0;N=(J-(c[r>>2]|0)|0)%(M|0)|0;O=c[u>>2]|0;P=(g-(c[s>>2]|0)|0)%(O|0)|0;Q=c[v>>2]|0;if((((N|0)<0?M:0)+N|0)<(Q|0)){R=12}else{if((((P|0)<0?O:0)+P|0)<(Q|0)){R=12}else{S=K}}if((R|0)==12){R=0;T=1.0-L;Q=B+(C+J)|0;a[Q]=~~(T*+(d[Q]|0|0)+L*+(d[x]|0|0));Q=E+(F+(J>>c[y>>2]))|0;a[Q]=~~(T*+(d[Q]|0|0)+L*+(d[z]|0|0));Q=G+(H+(J>>c[y>>2]))|0;a[Q]=~~(T*+(d[Q]|0|0)+L*+(d[A]|0|0));S=c[q>>2]|0}Q=J+1|0;if((Q|0)<(S|0)){J=Q;K=S}else{break}}}else{if(I){U=0;V=D}else{break}while(1){Q=c[t>>2]|0;P=(U-(c[r>>2]|0)|0)%(Q|0)|0;O=c[u>>2]|0;N=(g-(c[s>>2]|0)|0)%(O|0)|0;M=c[v>>2]|0;if((((P|0)<0?Q:0)+P|0)<(M|0)){R=8}else{if((((N|0)<0?O:0)+N|0)<(M|0)){R=8}else{W=V}}if((R|0)==8){R=0;M=B+(C+U)|0;a[M]=~a[M];W=c[q>>2]|0}M=U+1|0;if((M|0)<(W|0)){U=M;V=W}else{break}}}}while(0);g=g+1|0;}while((g|0)<(c[h>>2]|0));i=c[f>>2]|0;j=i+32|0;k=c[j>>2]|0;l=c[k>>2]|0;m=lj(l,e)|0;return m|0}function Rn(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0.0,q=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=i;i=i+112|0;e=b|0;f=b+104|0;g=c[a+8>>2]|0;j=c[g+44>>2]|0;k=qKb(c[a+52>>2]|0)|0;l=d[k+5|0]|0;c[j+40>>2]=l;m=d[k+6|0]|0;c[j+36>>2]=m;k=a+24|0;n=+(c[k>>2]|0);h[e+32>>3]=n;h[e+24>>3]=n;o=a+20|0;p=+(c[o>>2]|0);h[e+48>>3]=p;h[e+40>>3]=p;q=c[a+28>>2]|0;if((q|0)==0){s=1.0}else{s=+(q|0)/+(c[a+32>>2]|0)}h[e+56>>3]=s;a=e|0;h[a>>3]=s*(p/n);h[e+8>>3]=+(l|0);h[e+16>>3]=+(m|0);m=e+64|0;h[m>>3]=+r;l=e+72|0;h[l>>3]=+r;q=e+80|0;h[q>>3]=+r;t=e+88|0;h[t>>3]=+r;u=e+96|0;h[u>>3]=+r;e=j+44|0;v=g;g=j+4|0;w=j+48|0;x=j+8|0;y=j+52|0;z=j+12|0;A=j+56|0;B=j+16|0;C=j+60|0;D=j+20|0;E=0;do{F=c[e>>2]|0;G=ZGb(f,F,281616,a,0,0,0,0,0,0,v)|0;H=(E|0)==5;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[m>>3]=n;c[g>>2]=~~n;F=c[w>>2]|0;G=ZGb(f,F,281616,a,0,0,0,0,0,0,v)|0;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[l>>3]=n;c[x>>2]=~~n;F=c[y>>2]|0;G=ZGb(f,F,281616,a,0,0,0,0,0,0,v)|0;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[t>>3]=n;c[z>>2]=~~n;F=c[A>>2]|0;G=ZGb(f,F,281616,a,0,0,0,0,0,0,v)|0;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[q>>3]=n;c[B>>2]=~~n;F=c[C>>2]|0;G=ZGb(f,F,281616,a,0,0,0,0,0,0,v)|0;if((G|0)<0&H){I=G;J=F;K=17;break}n=+h[f>>3];h[u>>3]=n;c[D>>2]=~~n;E=E+1|0;}while((E|0)<6);if((K|0)==17){KIb(v,16,2401344,(L=i,i=i+8|0,c[L>>2]=J,L)|0);i=L;M=I;i=b;return M|0}I=c[z>>2]|0;if((I|0)>0){N=I}else{N=c[o>>2]|0}c[z>>2]=N;z=c[B>>2]|0;if((z|0)>0){O=z}else{O=c[k>>2]|0}c[B>>2]=O;if((N|O|0)<0){KIb(v,16,2417912,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;M=-22;i=b;return M|0}else{B=c[x>>2]|0;x=d[j+28|0]|0;k=d[j+29|0]|0;z=d[j+30|0]|0;o=d[j+31|0]|0;KIb(v,40,2408816,(L=i,i=i+64|0,c[L>>2]=c[g>>2],c[L+8>>2]=B,c[L+16>>2]=N,c[L+24>>2]=O,c[L+32>>2]=x,c[L+40>>2]=k,c[L+48>>2]=z,c[L+56>>2]=o,L)|0);i=L;M=0;i=b;return M|0}return 0}function Sn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0,U=0,V=0.0,W=0,X=0;f=b+8|0;b=c[(c[f>>2]|0)+44>>2]|0;g=c[b+4>>2]|0;h=c[b+8>>2]|0;i=(h|0)>0?h:0;j=b+16|0;k=e+72|0;if((i|0)>=(c[k>>2]|0)){l=c[f>>2]|0;m=l+32|0;n=c[m>>2]|0;o=c[n>>2]|0;p=lj(o,e)|0;return p|0}q=e|0;r=e+32|0;s=b+36|0;t=b+32|0;u=(g|0)>0?g:0;v=e+68|0;w=b+12|0;x=b+20|0;y=h-1|0;z=b+28|0;A=b+31|0;B=b+40|0;C=b+29|0;D=b+30|0;b=i;while(1){if((b|0)>=((c[j>>2]|0)+h|0)){E=24;break}i=c[q>>2]|0;F=ca(c[r>>2]|0,b)|0;G=b>>c[s>>2];H=c[e+4>>2]|0;I=ca(G,c[e+36>>2]|0)|0;J=c[e+8>>2]|0;K=ca(G,c[e+40>>2]|0)|0;G=c[w>>2]|0;L=G+g|0;M=(u|0)<(L|0);a:do{if((c[t>>2]|0)==0){if(!M){break}N=b-h|0;O=y-b|0;P=u;Q=L;R=G;while(1){if((P|0)>=(c[v>>2]|0)){break a}S=+((d[A]|0)>>>0)/255.0;T=c[x>>2]|0;do{if((N|0)<(T|0)){E=21}else{if((O+(c[j>>2]|0)|0)<(T|0)){E=21;break}if((P-g|0)<(T|0)){E=21;break}if((Q+~P|0)<(T|0)){E=21}else{U=R}}}while(0);if((E|0)==21){E=0;V=1.0-S;T=i+(F+P)|0;a[T]=~~(V*+(d[T]|0|0)+S*+(d[z]|0|0));T=H+(I+(P>>c[B>>2]))|0;a[T]=~~(V*+(d[T]|0|0)+S*+(d[C]|0|0));T=J+(K+(P>>c[B>>2]))|0;a[T]=~~(V*+(d[T]|0|0)+S*+(d[D]|0|0));U=c[w>>2]|0}T=P+1|0;W=U+g|0;if((T|0)<(W|0)){P=T;Q=W;R=U}else{break}}}else{if(!M){break}R=b-h|0;Q=y-b|0;P=u;O=L;N=G;while(1){if((P|0)>=(c[v>>2]|0)){break a}W=c[x>>2]|0;do{if((R|0)<(W|0)){E=14}else{if((Q+(c[j>>2]|0)|0)<(W|0)){E=14;break}if((P-g|0)<(W|0)){E=14;break}if((O+~P|0)<(W|0)){E=14}else{X=N}}}while(0);if((E|0)==14){E=0;W=i+(F+P)|0;a[W]=~a[W];X=c[w>>2]|0}W=P+1|0;T=X+g|0;if((W|0)<(T|0)){P=W;O=T;N=X}else{break}}}}while(0);F=b+1|0;if((F|0)<(c[k>>2]|0)){b=F}else{E=24;break}}if((E|0)==24){l=c[f>>2]|0;m=l+32|0;n=c[m>>2]|0;o=c[n>>2]|0;p=lj(o,e)|0;return p|0}return 0}function Tn(b){b=b|0;var d=0;d=c[b+44>>2]|0;a[d+32|0]=~~(+h[d+16>>3]*255.0+.5);a[d+33|0]=~~(+h[d+24>>3]*255.0+.5);return 0}function Un(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+4|0);mJb(b+8|0);mJb(b+12|0);return}function Vn(a){a=a|0;dl(a,Ok(685952)|0);return 0}function Wn(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+8|0;j=h|0;c[j>>2]=g;k=c[f+8>>2]|0;l=k+44|0;m=c[l>>2]|0;n=c[c[k+32>>2]>>2]|0;k=c[m+4>>2]|0;o=c[m+8>>2]|0;do{if((bIb(g)|0)==0){m=bv(n,c[n+20>>2]|0,c[n+24>>2]|0)|0;if((m|0)!=0){ZHb(m,c[j>>2]|0)|0;p=m;q=0;r=c[j>>2]|0;break}VHb(j);s=-12;i=h;return s|0}else{p=g;q=1;r=g}}while(0);g=f+20|0;m=c[g>>2]|0;t=f+24|0;f=c[t>>2]|0;u=c[r>>2]|0;v=c[r+32>>2]|0;nrc(k|0,u|0,m)|0;nrc(k+m|0,u+v|0,m)|0;r=k+(m<<1)|0;w=v<<1;x=u+w|0;y=f-2|0;if((y|0)>2){f=m-2|0;z=v*-2|0;if((f|0)>2){A=m-1|0;B=x;C=r;D=2;while(1){a[C]=a[B]|0;a[C+1|0]=a[B+1|0]|0;E=2;while(1){F=E+z|0;G=E+w|0;H=E-v|0;I=E+v|0;J=E+1|0;a[C+E|0]=((((d[B+(I-1)|0]|0)+(d[B+(H-1)|0]|0)+(d[B+(H+1)|0]|0)+(d[B+(I+1)|0]|0)|0)*9|0)+((d[B+(G-2)|0]|0)+(d[B+(F-2)|0]|0)+(d[B+(F+2)|0]|0)+(d[B+(G+2)|0]|0)<<1)+((d[B+(G-1)|0]|0)+(d[B+(F-1)|0]|0)+(d[B+(F+1)|0]|0)+(d[B+(G+1)|0]|0)+(d[B+(H-2)|0]|0)+(d[B+(I-2)|0]|0)+(d[B+(H+2)|0]|0)+(d[B+(I+2)|0]|0)<<2)+((d[B+E|0]|0)*15|0)+(((d[B+I|0]|0)+(d[B+H|0]|0)+(d[B+(E-1)|0]|0)+(d[B+J|0]|0)|0)*12|0)+(((d[B+G|0]|0)+(d[B+F|0]|0)+(d[B+(E-2)|0]|0)+(d[B+(E+2)|0]|0)|0)*5|0)|0)/159|0;if((J|0)<(f|0)){E=J}else{break}}a[C+f|0]=a[B+f|0]|0;a[C+A|0]=a[B+A|0]|0;E=D+1|0;if((E|0)<(y|0)){B=B+v|0;C=C+m|0;D=E}else{break}}}else{D=x;C=r;B=2;while(1){a[C]=a[D]|0;a[C+1|0]=a[D+1|0]|0;a[C+2|0]=a[D+2|0]|0;a[C+3|0]=a[D+3|0]|0;A=B+1|0;if((A|0)<(y|0)){D=D+v|0;C=C+m|0;B=A}else{break}}}K=u+(ca(v,y)|0)|0;L=k+(ca(y,m)|0)|0}else{K=x;L=r}nrc(L|0,K|0,m)|0;nrc(L+m|0,K+v|0,m)|0;m=c[g>>2]|0;v=c[t>>2]|0;K=v-1|0;do{if((K|0)>1){L=m-1|0;r=m+1|0;x=(c[l>>2]|0)+12|0;if((L|0)>1){M=1;N=k;O=o}else{P=m;Q=v;break}while(1){y=O+(m<<1)|0;u=ca(M,m)|0;B=1;while(1){C=d[N+(B-1)|0]|0;D=B+1|0;A=d[N+D|0]|0;f=B+m|0;w=d[N+(f+L)|0]|0;z=d[N+(r+f)|0]|0;E=A-C-(d[N+(B+L)|0]<<1)+(d[N+(D+m)|0]<<1)-w+z|0;J=w-(A+C)+z-(d[N+B|0]<<1)+(d[N+(f+m)|0]<<1)|0;z=-E|0;C=-J|0;b[O+(f<<1)>>1]=((J|0)>-1?J:C)+((E|0)>-1?E:z);do{if((E|0)==0){R=20}else{f=(E|0)<0;A=f?z:E;w=(f?C:J)<<16;f=A*27146|0;F=A*158218|0;A=-f|0;if((w|0)>(-F|0)&(w|0)<(A|0)){S=0;break}if((w|0)>(A|0)&(w|0)<(f|0)){S=2;break}if((w|0)>(f|0)&(w|0)<(F|0)){S=1}else{R=20}}}while(0);if((R|0)==20){R=0;S=3}a[(c[x>>2]|0)+(B+u)|0]=S;if((D|0)<(L|0)){B=D}else{break}}B=M+1|0;if((B|0)<(K|0)){M=B;N=N+m|0;O=y}else{break}}P=c[g>>2]|0;Q=c[t>>2]|0}else{P=m;Q=v}}while(0);mrc(k|0,0,ca(Q,P)|0)|0;P=c[g>>2]|0;Q=c[t>>2]|0;v=Q-1|0;if((v|0)>1){m=P-1|0;O=(m|0)>1;N=(c[l>>2]|0)+12|0;M=P<<1;K=P+1|0;S=M-1|0;L=M|1;x=o;o=1;r=k;while(1){B=r+P|0;u=x+(P<<1)|0;if(O){J=ca(o,P)|0;C=1;do{E=a[(c[N>>2]|0)+(C+J)|0]|0;do{if((E|0)==2){z=C+P|0;F=b[x+(z<<1)>>1]|0;if(!((F&65535)>>>0>(e[x+(m+C<<1)>>1]|0)>>>0)){break}if(!((F&65535)>>>0>(e[x+(K+C<<1)>>1]|0)>>>0)){break}if((F&65535)>>>0>255>>>0){T=-(F&65535)>>31&255}else{T=F&255}a[r+z|0]=T}else if((E|0)==1){z=C+P|0;F=b[x+(z<<1)>>1]|0;if(!((F&65535)>>>0>(e[x+(C-1<<1)>>1]|0)>>>0)){break}if(!((F&65535)>>>0>(e[x+(L+C<<1)>>1]|0)>>>0)){break}if((F&65535)>>>0>255>>>0){U=-(F&65535)>>31&255}else{U=F&255}a[r+z|0]=U}else if((E|0)==0){z=C+P|0;F=b[x+(z<<1)>>1]|0;if(!((F&65535)>>>0>(e[x+(S+C<<1)>>1]|0)>>>0)){break}if(!((F&65535)>>>0>(e[x+(C+1<<1)>>1]|0)>>>0)){break}if((F&65535)>>>0>255>>>0){V=-(F&65535)>>31&255}else{V=F&255}a[r+z|0]=V}else if((E|0)==3){z=C+P|0;F=b[x+(z<<1)>>1]|0;if(!((F&65535)>>>0>(e[x+(C<<1)>>1]|0)>>>0)){break}if(!((F&65535)>>>0>(e[x+(C+M<<1)>>1]|0)>>>0)){break}if((F&65535)>>>0>255>>>0){W=-(F&65535)>>31&255}else{W=F&255}a[r+z|0]=W}}while(0);C=C+1|0;}while((C|0)<(m|0))}C=o+1|0;if((C|0)<(v|0)){x=u;o=C;r=B}else{break}}X=c[t>>2]|0;Y=c[g>>2]|0}else{X=Q;Y=P}P=c[p+32>>2]|0;Q=c[l>>2]|0;l=a[Q+32|0]|0;g=a[Q+33|0]|0;if((X|0)>0){Q=(Y|0)>0;t=Y-1|0;r=X-1|0;o=0;x=k;k=c[p>>2]|0;while(1){if(Q){v=(o|0)==0;m=(o|0)==(r|0);W=0;do{M=a[x+W|0]|0;a:do{if((M&255)>>>0>(g&255)>>>0){a[k+W|0]=M}else{if((W|0)==0){if((M&255)>>>0>(l&255)>>>0){R=61}}else{if(((W|0)==(t|0)|v|m)&(M&255)>>>0>(l&255)>>>0){R=61}}b:do{if((R|0)==61){R=0;V=W-Y|0;do{if(!((d[x+(V-1)|0]|0)>>>0>(g&255)>>>0)){if((d[x+V|0]|0)>>>0>(g&255)>>>0){break}if((d[x+(V+1)|0]|0)>>>0>(g&255)>>>0){break}if((d[x+(W-1)|0]|0)>>>0>(g&255)>>>0){break}if((d[x+(W+1)|0]|0)>>>0>(g&255)>>>0){break}S=W+Y|0;if((d[x+(S-1)|0]|0)>>>0>(g&255)>>>0){break}if((d[x+S|0]|0)>>>0>(g&255)>>>0){break}if(!((d[x+(S+1)|0]|0)>>>0>(g&255)>>>0)){break b}}}while(0);a[k+W|0]=M;break a}}while(0);a[k+W|0]=0}}while(0);W=W+1|0;}while((W|0)<(Y|0))}W=o+1|0;if((W|0)<(X|0)){o=W;x=x+Y|0;k=k+P|0}else{break}}}if(!q){VHb(j)}s=lj(n,p)|0;i=h;return s|0}function Xn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=a+20|0;e=a+24|0;a=b+4|0;c[a>>2]=hJb(ca(c[e>>2]|0,c[d>>2]|0)|0)|0;f=b+8|0;c[f>>2]=qJb(ca(c[e>>2]|0,c[d>>2]|0)|0,2)|0;g=hJb(ca(c[e>>2]|0,c[d>>2]|0)|0)|0;c[b+12>>2]=g;if((c[a>>2]|0)==0){return-12|0}else{return((c[f>>2]|0)==0|(g|0)==0?-12:0)|0}return 0}function Yn(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=b+264|0;d=c[a>>2]|0;if((d|0)==-1){e=wKb()|0;c[a>>2]=e;f=e}else{f=d}AIb(b+4|0,f);return 0}function Zn(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+284|0);mJb(b+272|0);mJb(b+280|0);return}function _n(a){a=a|0;dl(a,Ok(685920)|0);return 0}function $n(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=b+8|0;g=c[(c[f>>2]|0)+44>>2]|0;h=a[g+296|0]|0;i=a[g+297|0]|0;j=a[g+298|0]|0;k=e|0;l=b+24|0;m=c[l>>2]|0;if((m|0)>0){n=b+20|0;o=e+32|0;p=h&255;q=g+272|0;r=i&255;s=j&255;t=g+292|0;u=c[k>>2]|0;v=0;w=0;x=c[n>>2]|0;y=m;while(1){if((x|0)>0){m=c[q>>2]|0;z=c[t>>2]|0;A=u;B=v;C=0;while(1){c[m+(B<<2)>>2]=d[A+p|0]|0;c[m+(B+1<<2)>>2]=d[A+r|0]|0;D=B+3|0;c[m+(B+2<<2)>>2]=d[A+s|0]|0;E=C+1|0;F=c[n>>2]|0;if((E|0)<(F|0)){A=A+(d[z+4|0]|0)|0;B=D;C=E}else{break}}G=D;H=F;I=c[l>>2]|0}else{G=v;H=x;I=y}C=w+1|0;if((C|0)<(I|0)){u=u+(c[o>>2]|0)|0;v=G;w=C;x=H;y=I}else{J=q;break}}}else{J=g+272|0}q=g+276|0;I=g+284|0;y=g+288|0;H=g+268|0;x=g+280|0;w=g+4|0;Tca(c[J>>2]|0,3,c[q>>2]|0,c[I>>2]|0,c[y>>2]|0,c[H>>2]|0,c[x>>2]|0,w);Uca(c[J>>2]|0,3,c[q>>2]|0,c[I>>2]|0,c[y>>2]|0,c[H>>2]|0,c[x>>2]|0,w);w=c[l>>2]|0;if((w|0)<=0){K=c[f>>2]|0;L=K+32|0;M=c[L>>2]|0;N=c[M>>2]|0;O=lj(N,e)|0;return O|0}H=b+20|0;b=e+32|0;y=h&255;h=i&255;i=j&255;j=g+292|0;g=c[k>>2]|0;k=0;q=0;J=c[H>>2]|0;G=w;while(1){if((J|0)>0){w=g;v=k;o=0;while(1){P=v+1|0;u=(c[(c[x>>2]|0)+(v<<2)>>2]|0)*3|0;a[w+y|0]=c[(c[I>>2]|0)+(u<<2)>>2];a[w+h|0]=c[(c[I>>2]|0)+(u+1<<2)>>2];a[w+i|0]=c[(c[I>>2]|0)+(u+2<<2)>>2];u=o+1|0;Q=c[H>>2]|0;if((u|0)<(Q|0)){w=w+(d[(c[j>>2]|0)+4|0]|0)|0;v=P;o=u}else{break}}R=P;S=Q;T=c[l>>2]|0}else{R=k;S=J;T=G}o=q+1|0;if((o|0)<(T|0)){g=g+(c[b>>2]|0)|0;k=R;q=o;J=S;G=T}else{break}}K=c[f>>2]|0;L=K+32|0;M=c[L>>2]|0;N=c[M>>2]|0;O=lj(N,e)|0;return O|0}function ao(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=a+52|0;c[b+292>>2]=qKb(c[d>>2]|0)|0;e=ca(c[a+24>>2]|0,c[a+20>>2]|0)|0;a=b+276|0;c[a>>2]=e;f=b+272|0;g=jJb(c[f>>2]|0,e,12)|0;c[f>>2]=g;if((g|0)==0){h=-12;return h|0}g=b+280|0;f=jJb(c[g>>2]|0,c[a>>2]|0,4)|0;c[g>>2]=f;if((f|0)==0){h=-12;return h|0}f=b+284|0;g=jJb(c[f>>2]|0,c[b+288>>2]|0,12)|0;c[f>>2]=g;if((g|0)==0){h=-12;return h|0}Kz(b+296|0,c[d>>2]|0)|0;h=0;return h|0}function bo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=c[e+4>>2]|0;g=f&15|f>>4;f=a+40|0;h=d;j=e+8|0;e=d|0;k=d+4|0;l=d+48|0;m=a+28|0;n=a+32|0;o=a+36|0;mrc(h|0,0,60)|0;do{if((g&1|0)!=0){a=FFb(2287344,(p=i,i=i+8|0,c[p>>2]=c[f>>2],p)|0)|0;i=p;if((a|0)==0){q=-12;i=b;return q|0}else{c[j+(c[f>>2]<<2)>>2]=0;c[e>>2]=a;c[k>>2]=0;c[l>>2]=452;Qi(c[f>>2]|0,f,4,m,n,d)|0;c[o>>2]=c[f>>2];break}}}while(0);mrc(h|0,0,60)|0;do{if((g&2|0)!=0){a=FFb(2287344,(p=i,i=i+8|0,c[p>>2]=c[f>>2],p)|0)|0;i=p;if((a|0)==0){q=-12;i=b;return q|0}else{c[j+(c[f>>2]<<2)>>2]=1;c[e>>2]=a;c[k>>2]=0;c[l>>2]=452;Qi(c[f>>2]|0,f,4,m,n,d)|0;c[o>>2]=c[f>>2];break}}}while(0);mrc(h|0,0,60)|0;do{if((g&4|0)!=0){a=FFb(2287344,(p=i,i=i+8|0,c[p>>2]=c[f>>2],p)|0)|0;i=p;if((a|0)==0){q=-12;i=b;return q|0}else{c[j+(c[f>>2]<<2)>>2]=2;c[e>>2]=a;c[k>>2]=0;c[l>>2]=452;Qi(c[f>>2]|0,f,4,m,n,d)|0;c[o>>2]=c[f>>2];break}}}while(0);mrc(h|0,0,60)|0;if((g&8|0)==0){q=0;i=b;return q|0}g=FFb(2287344,(p=i,i=i+8|0,c[p>>2]=c[f>>2],p)|0)|0;i=p;if((g|0)==0){q=-12;i=b;return q|0}c[j+(c[f>>2]<<2)>>2]=3;c[e>>2]=g;c[k>>2]=0;c[l>>2]=452;Qi(c[f>>2]|0,f,4,m,n,d)|0;c[o>>2]=c[f>>2];q=0;i=b;return q|0}function co(a){a=a|0;var b=0,d=0;b=a+40|0;if((c[b>>2]|0)==0){return}d=a+28|0;a=0;do{mJb((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function eo(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b+16|0;f=c[c[d>>2]>>2]|0;g=c[f+64>>2]|0;if((g|0)==0){h=-11;return h|0}if((c[g>>2]|0)==0){h=-11;return h|0}if((c[f+68>>2]|0)==0){f=Ok(686960)|0;Yk(f,(c[c[d>>2]>>2]|0)+68|0);i=c[(c[c[d>>2]>>2]|0)+64>>2]|0}else{i=g}g=i+4|0;d=qKb(c[c[g>>2]>>2]|0)|0;f=(e[d+8>>1]|0)>>>11&15;j=a[d+7|0]&1;d=i|0;i=1;while(1){if(!(i>>>0<(c[d>>2]|0)>>>0)){k=9;break}l=qKb(c[(c[g>>2]|0)+(i<<2)>>2]|0)|0;if(!(f<<16>>16==((e[l+8>>1]|0)>>>11&15))){h=-11;k=14;break}if((j|0)==(a[l+7|0]&1|0)){i=i+1|0}else{h=-11;k=14;break}}if((k|0)==9){if(f<<16>>16==7){m=686816}else{m=(j|0)==0?686824:686832}j=b+40|0;if((c[j>>2]|0)==0){h=0;return h|0}f=b+32|0;b=0;while(1){i=Ok(m)|0;Yk(i,(c[(c[f>>2]|0)+(b<<2)>>2]|0)+64|0);i=b+1|0;if(i>>>0<(c[j>>2]|0)>>>0){b=i}else{h=0;break}}return h|0}else if((k|0)==14){return h|0}return 0}function fo(a){a=a|0;c[(c[a+44>>2]|0)+4>>2]=8;return bo(a)|0}function go(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a>>2]|0;e=c[c[b+16>>2]>>2]|0;f=c[b+44>>2]|0;g=qKb(c[e+52>>2]|0)|0;if(!(((c[f+8+((((c[a+4>>2]|0)-(c[b+28>>2]|0)|0)/60|0)<<2)>>2]|0)-1|0)>>>0<2>>>0)){return 0}c[a+24>>2]=-(-(c[e+24>>2]|0)>>(d[g+6|0]|0));c[a+20>>2]=-(-(c[e+20>>2]|0)>>(d[g+5|0]|0));return 0}function ho(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=i;i=i+8|0;f=e|0;c[f>>2]=d;d=c[b+8>>2]|0;b=c[d+44>>2]|0;g=d+40|0;a:do{if((c[g>>2]|0)==0){h=0;j=0}else{k=d+32|0;l=b+8|0;m=b+40|0;n=b+24|0;o=b+48|0;p=b+44|0;q=0;r=0;s=0;while(1){t=c[(c[k>>2]|0)+(s<<2)>>2]|0;u=c[l+(s<<2)>>2]|0;do{if((c[t+144>>2]|0)==0){v=t+20|0;w=t+24|0;x=bv(t,c[v>>2]|0,c[w>>2]|0)|0;if((x|0)==0){h=-12;j=r;break a}ZHb(x,c[f>>2]|0)|0;y=c[x>>2]|0;z=c[x+32>>2]|0;A=c[f>>2]|0;b:do{if((c[m>>2]|0)==0){uIb(y,z,c[A+(u<<2)>>2]|0,c[A+32+(u<<2)>>2]|0,c[n+(u<<2)>>2]|0,c[w>>2]|0)}else{B=c[A>>2]|0;C=c[A+32>>2]|0;D=c[v>>2]|0;E=c[w>>2]|0;F=c[o>>2]|0;if((E|0)<=0){break}G=c[p>>2]|0;H=(D|0)>0;I=u<<1;if((G|0)==2){J=B;K=y;L=0;while(1){if(H){M=0;do{N=(ca(M,F)|0)+I|0;O=M<<1;a[K+O|0]=a[J+N|0]|0;a[K+(O|1)|0]=a[J+(N+1)|0]|0;M=M+1|0;}while((M|0)<(D|0))}M=L+1|0;if((M|0)<(E|0)){J=J+C|0;K=K+z|0;L=M}else{break b}}}else if((G|0)!=1){break}if(H){P=B;Q=y;R=0}else{break}while(1){L=0;do{a[Q+L|0]=a[P+((ca(L,F)|0)+u)|0]|0;L=L+1|0;}while((L|0)<(D|0));L=R+1|0;if((L|0)<(E|0)){P=P+C|0;Q=Q+z|0;R=L}else{break}}}}while(0);z=lj(t,x)|0;if((z|0)==-541478725){S=r+1|0;T=-541478725;break}else{if((z|0)<0){h=z;j=r;break a}else{S=r;T=z;break}}}else{S=r;T=q}}while(0);t=s+1|0;if(t>>>0<(c[g>>2]|0)>>>0){q=T;r=S;s=t}else{h=T;j=S;break}}}}while(0);VHb(f);if((j|0)==(c[g>>2]|0)){i=e;return-541478725|0}else{i=e;return((h|0)==-541478725?0:h)|0}return 0}function io(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+8|0;g=f|0;h=c[b+8>>2]|0;j=c[h+44>>2]|0;k=b+52|0;l=qKb(c[k>>2]|0)|0;m=l+7|0;n=a[m]|0;if((n&32)==0){o=(d[l+4|0]|0)>>>0>2>>>0?112:16}else{o=7}if((c[j+4>>2]&~((n<<24>>24<0?8:0)|o)|0)!=0){KIb(h,16,2428312,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-22;i=f;return p|0}h=pIb(j+24|0,c[k>>2]|0,c[b+20>>2]|0)|0;if((h|0)<0){p=h;i=f;return p|0}c[j+44>>2]=(((e[l+8>>1]|0)>>>11&15)+1|0)>>>3;c[j+48>>2]=(pKb(l)|0)>>3;c[j+40>>2]=((d[m]|0)>>>4&1^1)&255;if((a[m]&32)==0){p=0;i=f;return p|0}Kz(g|0,c[k>>2]|0)|0;k=j+8|0;c[k>>2]=d[g+(c[k>>2]|0)|0]|0;k=j+12|0;c[k>>2]=d[g+(c[k>>2]|0)|0]|0;k=j+16|0;c[k>>2]=d[g+(c[k>>2]|0)|0]|0;k=j+20|0;c[k>>2]=d[g+(c[k>>2]|0)|0]|0;p=0;i=f;return p|0}function jo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;d=c[a+44>>2]|0;e=d+20|0;f=c[e>>2]|0;c[d+12>>2]=65536/(f|0)|0;c[d+72>>2]=0;g=d+64|0;if((c[g>>2]|0)==0&(c[g+4>>2]|0)==0){j=f}else{c[e>>2]=0;j=0}e=c[d+16>>2]|0;if((e|j|0)!=0){f=c[d+52>>2]|0;KIb(a,40,2435424,(k=i,i=i+32|0,c[k>>2]=(c[d+4>>2]|0)==0?2348920:2287280,c[k+8>>2]=e,c[k+16>>2]=j,c[k+24>>2]=f,k)|0);i=k}f=d+56|0;j=c[f>>2]|0;e=c[f+4>>2]|0;f=c[g>>2]|0;l=c[g+4>>2]|0;if((j|f|0)==0&(e|l|0)==0){m=d+76|0;n=grc(m,2197064,4)|0;o=(n|0)==0;p=o&1;q=d+80|0;r=q;c[r>>2]=p;i=b;return 0}g=c[d+52>>2]|0;KIb(a,40,2237600,(k=i,i=i+32|0,c[k>>2]=(c[d+4>>2]|0)==0?2348920:2287280,h[k+8>>3]=(+(j>>>0)+ +(e>>>0)*4294967296.0)/1.0e6,h[k+16>>3]=(+(f>>>0)+ +(l>>>0)*4294967296.0)/1.0e6,c[k+24>>2]=g,k)|0);i=k;m=d+76|0;n=grc(m,2197064,4)|0;o=(n|0)==0;p=o&1;q=d+80|0;r=q;c[r>>2]=p;i=b;return 0}function ko(a){a=a|0;if((c[(c[a+44>>2]|0)+80>>2]|0)==0){dl(a,Ok(684224)|0);return 0}else{dl(a,Ok(685840)|0);return 0}return 0}function lo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=b+8|0;f=c[e>>2]|0;g=c[f+44>>2]|0;h=d+136|0;i=c[h>>2]|0;j=c[h+4>>2]|0;if((i|0)==0&(j|0)==(-2147483648|0)){k=-1.0}else{k=(+(i>>>0)+ +(j|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}j=g+72|0;i=c[j>>2]|0;do{if((i|0)==1){l=11}else if((i|0)==0){c[g+8>>2]=0;h=g+56|0;m=c[h>>2]|0;n=c[h+4>>2]|0;if(k<(+(m>>>0)+ +(n>>>0)*4294967296.0)/1.0e6){l=19;break}o=b+160|0;p=c[o+4>>2]|0;q=g+16|0;r=c[q>>2]|0;s=(r|0)<0|0?-1:0;if((p|0)<(s|0)|(p|0)==(s|0)&(c[o>>2]|0)>>>0<r>>>0){l=19;break}c[j>>2]=1;s=(r|0)==0;if((m|0)==0&(n|0)==0){if(s){l=11;break}t=k*1.0e6;n=~~+t>>>0;m=(F=+t,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[h>>2]=n;c[h+4>>2]=m;if(!(((n|0)!=0|(m|0)!=0)&(r|0)==0)){l=11;break}}else{if(!s){l=11;break}}c[q>>2]=c[o>>2];l=11}else{u=i;l=16}}while(0);do{if((l|0)==11){i=g+64|0;o=c[i>>2]|0;q=c[i+4>>2]|0;if((o|0)==0&(q|0)==0){i=b+160|0;s=c[i>>2]|0;r=c[i+4>>2]|0;i=c[g+16>>2]|0;m=xrc(s,r,i,(i|0)<0|0?-1:0)|0;n=c[g+12>>2]|0;h=Erc(m,G,n,(n|0)<0|0?-1:0)|0;n=g+8|0;c[n>>2]=h;h=(c[g+20>>2]|0)+i|0;i=(h|0)<0|0?-1:0;if(!((r|0)>(i|0)|(r|0)==(i|0)&s>>>0>h>>>0)){u=1;l=16;break}c[j>>2]=2;v=n;l=18;break}else{n=g+56|0;t=(+((c[n>>2]|0)>>>0)+ +((c[n+4>>2]|0)>>>0)*4294967296.0)/1.0e6;w=(+(o>>>0)+ +(q>>>0)*4294967296.0)/1.0e6;q=g+8|0;c[q>>2]=~~((k-t)*65535.0/w);if(!(k>t+w)){l=19;break}c[j>>2]=2;v=q;l=18;break}}}while(0);do{if((l|0)==16){if((u|0)!=2){l=19;break}v=g+8|0;l=18}}while(0);do{if((l|0)==18){c[v>>2]=65535;x=-1;y=g+8|0}else if((l|0)==19){u=c[g+8>>2]|0;j=g+8|0;if(!(u>>>0>65535>>>0)){x=u&65535;y=j;break}x=-u>>31&65535;y=j}}while(0);l=x&65535;c[y>>2]=l;if((c[g+4>>2]|0)==1){x=l^65535;c[y>>2]=x;z=x}else{z=l}if((z|0)>=65535){A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;E=lj(D,d)|0;return E|0}if((c[g+52>>2]|0)!=0){z=c[d+72>>2]|0;l=c[(c[f+48>>2]|0)+28>>2]|0;Xe[c[c[f+56>>2]>>2]&511](f,426,d,0,(z|0)>(l|0)?l:z)|0;A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;E=lj(D,d)|0;return E|0}do{if((a[g+44|0]|0)!=0){if((c[g+80>>2]|0)!=0){break}z=c[d+72>>2]|0;l=c[(c[f+48>>2]|0)+28>>2]|0;Xe[c[c[f+56>>2]>>2]&511](f,150,d,0,(z|0)>(l|0)?l:z)|0;A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;E=lj(D,d)|0;return E|0}}while(0);g=f+56|0;z=d;l=d+72|0;x=c[l>>2]|0;y=f+48|0;v=c[(c[y>>2]|0)+28>>2]|0;Xe[c[c[g>>2]>>2]&511](f,600,z,0,(x|0)>(v|0)?v:x)|0;if((c[d+4>>2]|0)==0){A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;E=lj(D,d)|0;return E|0}if((c[d+8>>2]|0)==0){A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;E=lj(D,d)|0;return E|0}x=c[l>>2]|0;l=c[(c[y>>2]|0)+28>>2]|0;Xe[c[c[g>>2]>>2]&511](f,798,z,0,(x|0)>(l|0)?l:x)|0;A=c[e>>2]|0;B=A+32|0;C=c[B>>2]|0;D=c[C>>2]|0;E=lj(D,d)|0;return E|0}function mo(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[(c[b+8>>2]|0)+44>>2]|0;f=b+52|0;b=qKb(c[f>>2]|0)|0;c[e+24>>2]=d[b+5|0]|0;c[e+28>>2]=d[b+6|0]|0;c[e+32>>2]=(oKb(b)|0)>>3;g=e+52|0;c[g>>2]=(d[b+7|0]|0)>>>7&255&c[g>>2];a[e+44|0]=(Kz(e+45|0,c[f>>2]|0)|0)>>>31&255^1;if((Nk(c[f>>2]|0,553032)|0)==0){h=0;i=e+36|0;j=i;c[j>>2]=h;k=h<<16;l=k|32768;m=e+40|0;n=m;c[n>>2]=l;return 0}h=(c[g>>2]|0)!=0?0:16;i=e+36|0;j=i;c[j>>2]=h;k=h<<16;l=k|32768;m=e+40|0;n=m;c[n>>2]=l;return 0}function no(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=c[b+44>>2]|0;b=h+44|0;i=a[b]|0;j=i<<24>>24!=0?0:3;k=c[e+72>>2]|0;l=(ca(k,f)|0)/(g|0)|0;m=(ca(k,f+1|0)|0)/(g|0)|0;if((l|0)>=(m|0)){return 0}g=e+(j<<2)|0;f=e+32+(j<<2)|0;j=h+48|0;k=e+68|0;e=h+36|0;n=h+8|0;o=h+40|0;h=l;l=c[k>>2]|0;p=i;while(1){i=p<<24>>24!=0?4:1;if((l|0)>0){q=(ca(d[j]|0,p&255)|0)+(ca(c[f>>2]|0,h)|0)|0;r=0;s=(c[g>>2]|0)+q|0;while(1){q=ca((d[s]|0)-(c[e>>2]|0)|0,c[n>>2]|0)|0;a[s]=(q+(c[o>>2]|0)|0)>>>16;q=r+1|0;t=c[k>>2]|0;if((q|0)<(t|0)){r=q;s=s+i|0}else{u=t;break}}}else{u=l}i=h+1|0;if((i|0)>=(m|0)){break}h=i;l=u;p=a[b]|0}return 0}function oo(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;j=c[b+44>>2]|0;b=c[e+72>>2]|0;k=(ca(b,f)|0)/(g|0)|0;l=(ca(b,f+1|0)|0)/(g|0)|0;if((c[j+52>>2]|0)!=0){g=j+76|0;if((k|0)>=(l|0)){i=h;return 0}f=e;b=e+32|0;m=e+68|0;n=d[j+45|0]|0;o=j+8|0;p=j+77|0;q=d[j+46|0]|0;r=j+78|0;s=d[j+47|0]|0;t=j+79|0;u=d[j+48|0]|0;v=k;w=c[m>>2]|0;while(1){if((w|0)>0){x=ca(c[b>>2]|0,v)|0;y=0;z=(c[f>>2]|0)+x|0;while(1){x=d[g]|0;A=z+n|0;B=(ca((d[A]|0)-x|0,c[o>>2]|0)|0)+(x<<16|32768)>>16;if(B>>>0>255>>>0){C=-B>>31&255}else{C=B&255}a[A]=C;A=d[p]|0;B=z+q|0;x=(ca((d[B]|0)-A|0,c[o>>2]|0)|0)+(A<<16|32768)>>16;if(x>>>0>255>>>0){D=-x>>31&255}else{D=x&255}a[B]=D;B=d[r]|0;x=z+s|0;A=(ca((d[x]|0)-B|0,c[o>>2]|0)|0)+(B<<16|32768)>>16;if(A>>>0>255>>>0){E=-A>>31&255}else{E=A&255}a[x]=E;x=d[t]|0;A=z+u|0;B=(ca((d[A]|0)-x|0,c[o>>2]|0)|0)+(x<<16|32768)>>16;if(B>>>0>255>>>0){F=-B>>31&255}else{F=B&255}a[A]=F;A=y+1|0;B=c[m>>2]|0;if((A|0)<(B|0)){y=A;z=z+4|0}else{G=B;break}}}else{G=w}z=v+1|0;if((z|0)<(l|0)){v=z;w=G}else{break}}i=h;return 0}G=c[j+32>>2]|0;if((G|0)==3){w=j+76|0;if((k|0)>=(l|0)){i=h;return 0}v=e;m=e+32|0;F=e+68|0;o=d[j+45|0]|0;u=j+8|0;t=j+77|0;E=d[j+46|0]|0;s=j+78|0;r=d[j+47|0]|0;D=k;q=c[F>>2]|0;while(1){if((q|0)>0){p=ca(c[m>>2]|0,D)|0;C=0;n=(c[v>>2]|0)+p|0;while(1){p=d[w]|0;g=n+o|0;f=(ca((d[g]|0)-p|0,c[u>>2]|0)|0)+(p<<16|32768)>>16;if(f>>>0>255>>>0){H=-f>>31&255}else{H=f&255}a[g]=H;g=d[t]|0;f=n+E|0;p=(ca((d[f]|0)-g|0,c[u>>2]|0)|0)+(g<<16|32768)>>16;if(p>>>0>255>>>0){I=-p>>31&255}else{I=p&255}a[f]=I;f=d[s]|0;p=n+r|0;g=(ca((d[p]|0)-f|0,c[u>>2]|0)|0)+(f<<16|32768)>>16;if(g>>>0>255>>>0){J=-g>>31&255}else{J=g&255}a[p]=J;p=C+1|0;g=c[F>>2]|0;if((p|0)<(g|0)){C=p;n=n+3|0}else{K=g;break}}}else{K=q}n=D+1|0;if((n|0)<(l|0)){D=n;q=K}else{break}}i=h;return 0}else if((G|0)==4){G=j+76|0;if((k|0)>=(l|0)){i=h;return 0}K=e;q=e+32|0;D=e+68|0;e=d[j+45|0]|0;F=j+8|0;J=j+77|0;u=d[j+46|0]|0;r=j+78|0;s=d[j+47|0]|0;j=k;k=c[D>>2]|0;while(1){if((k|0)>0){I=ca(c[q>>2]|0,j)|0;E=0;t=(c[K>>2]|0)+I|0;while(1){I=d[G]|0;H=t+e|0;o=(ca((d[H]|0)-I|0,c[F>>2]|0)|0)+(I<<16|32768)>>16;if(o>>>0>255>>>0){L=-o>>31&255}else{L=o&255}a[H]=L;H=d[J]|0;o=t+u|0;I=(ca((d[o]|0)-H|0,c[F>>2]|0)|0)+(H<<16|32768)>>16;if(I>>>0>255>>>0){M=-I>>31&255}else{M=I&255}a[o]=M;o=d[r]|0;I=t+s|0;H=(ca((d[I]|0)-o|0,c[F>>2]|0)|0)+(o<<16|32768)>>16;if(H>>>0>255>>>0){N=-H>>31&255}else{N=H&255}a[I]=N;I=E+1|0;H=c[D>>2]|0;if((I|0)<(H|0)){E=I;t=t+4|0}else{O=H;break}}}else{O=k}t=j+1|0;if((t|0)<(l|0)){j=t;k=O}else{break}}i=h;return 0}else{KIb(0,0,2366584,(h=i,i=i+24|0,c[h>>2]=2351560,c[h+8>>2]=2344024,c[h+16>>2]=190,h)|0);i=h;Hd();return 0}return 0}function po(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=c[b+44>>2]|0;b=c[e+72>>2]|0;i=(ca(b,f)|0)/(g|0)|0;j=(ca(b,f+1|0)|0)/(g|0)|0;if((i|0)>=(j|0)){return 0}g=e;f=e+32|0;b=e+68|0;e=h+32|0;k=h+36|0;l=h+8|0;m=h+40|0;h=i;i=c[b>>2]|0;n=c[e>>2]|0;while(1){if((ca(n,i)|0)>0){o=ca(c[f>>2]|0,h)|0;p=0;q=(c[g>>2]|0)+o|0;while(1){o=ca((d[q]|0)-(c[k>>2]|0)|0,c[l>>2]|0)|0;a[q]=(o+(c[m>>2]|0)|0)>>>16;o=p+1|0;r=c[b>>2]|0;s=c[e>>2]|0;if((o|0)<(ca(s,r)|0)){p=o;q=q+1|0}else{t=r;u=s;break}}}else{t=i;u=n}q=h+1|0;if((q|0)<(j|0)){h=q;i=t;n=u}else{break}}return 0}function qo(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=c[b+44>>2]|0;b=-(c[e+68>>2]|0)>>c[h+24>>2];i=-b|0;j=-(-(c[e+72>>2]|0)>>c[h+28>>2])|0;k=(ca(j,f)|0)/(g|0)|0;l=(ca(f+1|0,j)|0)/(g|0)|0;g=(k|0)<(l|0);j=(b|0)<0;b=h+8|0;if(!g){return 0}h=e+4|0;f=e+36|0;if(j){m=k}else{return 0}do{n=ca(c[f>>2]|0,m)|0;o=0;p=(c[h>>2]|0)+n|0;while(1){a[p]=((ca((d[p]|0)-128|0,c[b>>2]|0)|0)+8421367|0)>>>16;n=o+1|0;if((n|0)<(i|0)){o=n;p=p+1|0}else{break}}m=m+1|0;}while((m|0)<(l|0));if(!g){return 0}g=e+8|0;m=e+40|0;if(j){q=k}else{return 0}do{k=ca(c[m>>2]|0,q)|0;j=0;e=(c[g>>2]|0)+k|0;while(1){a[e]=((ca((d[e]|0)-128|0,c[b>>2]|0)|0)+8421367|0)>>>16;k=j+1|0;if((k|0)<(i|0)){j=k;e=e+1|0}else{break}}q=q+1|0;}while((q|0)<(l|0));return 0}function ro(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=c[c[d+16>>2]>>2]|0;c[e+8>>2]=uKb(c[a+52>>2]|0)|0;g=f+20|0;h=c[g>>2]|0;c[a+20>>2]=h;j=f+24|0;f=c[e+4>>2]|0;e=(((f|0)==0)+(c[j>>2]|0)|0)/2|0;c[a+24>>2]=e;a=c[j>>2]|0;KIb(d,40,2633840,(d=i,i=i+40|0,c[d>>2]=c[g>>2],c[d+8>>2]=a,c[d+16>>2]=(f|0)==1?2165448:2237512,c[d+24>>2]=h,c[d+32>>2]=e,d)|0);i=d;i=b;return 0}function so(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+8>>2]|0;a=c[d+44>>2]|0;e=c[c[d+32>>2]>>2]|0;c[b+72>>2]=c[e+24>>2];c[b+296>>2]=0;d=a+8|0;if((c[d>>2]|0)<=0){f=lj(e,b)|0;return f|0}if((c[a+4>>2]|0)==1){a=0;do{g=b+(a<<2)|0;h=c[b+32+(a<<2)>>2]|0;c[g>>2]=(c[g>>2]|0)+h;c[b+32+(a<<2)>>2]=h<<1;a=a+1|0;}while((a|0)<(c[d>>2]|0));f=lj(e,b)|0;return f|0}else{a=0;do{h=b+32+(a<<2)|0;c[h>>2]=c[h>>2]<<1;a=a+1|0;}while((a|0)<(c[d>>2]|0));f=lj(e,b)|0;return f|0}return 0}function to(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=d|0;g=rJb(2434376)|0;c[f>>2]=g;mrc(d+4|0,0,32)|0;c[d+36>>2]=178;c[d+40>>2]=0;c[d+44>>2]=0;h=d+48|0;c[h>>2]=162;c[d+52>>2]=0;c[d+56>>2]=0;if((g|0)==0){j=-12;i=b;return j|0}g=a+24|0;k=a+12|0;l=a+16|0;Qi(0,g,12,k,l,d)|0;m=a+20|0;c[m>>2]=c[g>>2];do{if((c[e+68>>2]|0)!=0){n=rJb(2348696)|0;c[f>>2]=n;c[h>>2]=0;if((n|0)==0){j=-12;i=b;return j|0}else{Qi(1,g,12,k,l,d)|0;c[m>>2]=c[g>>2];break}}}while(0);g=c[e+128>>2]|0;do{if((g-1&g|0)==0){m=c[e+132>>2]|0;if((m-1&m|0)!=0){break}if((c[e+136>>2]|0)<=(ca(m,g)|0)){j=0;i=b;return j|0}KIb(a,16,2237432,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;j=-22;i=b;return j|0}}while(0);KIb(a,16,2287056,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;j=-22;i=b;return j|0}function uo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+44>>2]|0;d=b+4|0;e=c[d>>2]|0;f=b+8|0;if((e|0)==(c[f>>2]|0)){g=e}else{VHb(d);g=c[f>>2]|0}d=b+12|0;if((c[d>>2]|0)!=(g|0)){VHb(d)}VHb(f);mJb(b+140|0);mJb(b+172|0);mJb(b+216|0);mJb(b+204|0);b=a+24|0;if((c[b>>2]|0)==0){return}f=a+12|0;a=0;do{mJb((c[f>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function vo(a){a=a|0;dl(a,Ok(685816)|0);return 0}function wo(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;f=i;i=i+80|0;g=f|0;j=f+24|0;k=f+48|0;l=c[b+8>>2]|0;m=c[c[l+32>>2]>>2]|0;n=c[l+44>>2]|0;o=n;mrc(g|0,-1|0,20)|0;mrc(j|0,0,20)|0;do{if((c[b+12>>2]|0)==(c[l+12>>2]|0)){p=n+4|0;q=c[p>>2]|0;r=n+8|0;if((q|0)==(c[r>>2]|0)){s=q}else{VHb(p);s=c[r>>2]|0}c[p>>2]=s;q=n+12|0;t=c[q>>2]|0;c[r>>2]=t;if((e|0)==0){u=t}else{c[q>>2]=e;u=e}do{if((s|0)==0){c[p>>2]=t;if((t|0)==0){v=0;i=f;return v|0}if((u|0)!=0){break}KIb(0,0,2196896,(w=i,i=i+24|0,c[w>>2]=2165368,c[w+8>>2]=2139224,c[w+16>>2]=697,w)|0);i=w;Hd();return 0}else{if(!((t|0)==0|(u|0)==0)){break}KIb(0,0,2196896,(w=i,i=i+24|0,c[w>>2]=2165368,c[w+8>>2]=2139224,c[w+16>>2]=697,w)|0);i=w;Hd();return 0}}while(0);c[n+28>>2]=1}else{t=n+16|0;p=c[t>>2]|0;q=n+20|0;if((p|0)==(c[q>>2]|0)){x=p}else{VHb(t);x=c[q>>2]|0}c[t>>2]=x;p=n+24|0;r=c[p>>2]|0;c[q>>2]=r;if((e|0)==0){y=r}else{c[p>>2]=e;y=e}do{if((x|0)==0){c[t>>2]=r;if((r|0)==0){v=0;i=f;return v|0}if((y|0)!=0){break}KIb(0,0,2196896,(w=i,i=i+24|0,c[w>>2]=2115880,c[w+8>>2]=2139224,c[w+16>>2]=700,w)|0);i=w;Hd();return 0}else{if(!((r|0)==0|(y|0)==0)){break}KIb(0,0,2196896,(w=i,i=i+24|0,c[w>>2]=2115880,c[w+8>>2]=2139224,c[w+16>>2]=700,w)|0);i=w;Hd();return 0}}while(0);c[n+32>>2]=1;if((c[n+28>>2]|0)==0){v=0}else{break}i=f;return v|0}}while(0);y=n+28|0;x=n+68|0;e=n+32|0;do{if((c[x>>2]|0)!=0){if((c[e>>2]|0)==0){v=0}else{break}i=f;return v|0}}while(0);c[e>>2]=0;c[y>>2]=0;y=n+8|0;e=c[y>>2]|0;u=c[n+64>>2]|0;do{if((u|0)==-1){if((c[e+296>>2]|0)==0){z=1;break}z=c[e+300>>2]|0}else{z=u}}while(0);u=c[n+76>>2]|0;s=(u|0)==-1?z:u;if(!(z>>>0<2>>>0|s>>>0<2>>>0)){KIb(0,0,2196896,(w=i,i=i+24|0,c[w>>2]=2633728,c[w+8>>2]=2139224,c[w+16>>2]=711,w)|0);i=w;Hd();return 0}u=(s|0)!=(z|0)?1204024:1204048;z=n+116|0;do{if((c[z>>2]|0)==0){r=$Hb(e)|0;c[j+4>>2]=r;if((r|0)==0){v=-12}else{break}i=f;return v|0}else{r=n+4|0;t=n+12|0;p=yo(l,0,s,c[r>>2]|0,e,c[t>>2]|0)|0;c[j>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}q=g|0;c[q>>2]=zo(o,p)|0;p=yo(l,1,s,c[r>>2]|0,c[y>>2]|0,c[t>>2]|0)|0;c[j+4>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}c[g+4>>2]=zo(o,p)|0;p=yo(l,2,s,c[r>>2]|0,c[y>>2]|0,c[t>>2]|0)|0;c[j+8>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}c[g+8>>2]=zo(o,p)|0;do{if((c[z>>2]|0)!=1){p=yo(l,3,s,c[r>>2]|0,c[y>>2]|0,c[t>>2]|0)|0;c[j+12>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}c[g+12>>2]=zo(o,p)|0;if((c[z>>2]|0)==1){break}p=yo(l,4,s,c[r>>2]|0,c[y>>2]|0,c[t>>2]|0)|0;c[j+16>>2]=p;if((p|0)==0){v=-12;i=f;return v|0}else{c[g+16>>2]=zo(o,p)|0;break}}}while(0);t=c[g+4>>2]|0;r=c[g+8>>2]|0;p=c[g+12>>2]|0;A=c[g+16>>2]|0;KIb(l,32,2610024,(w=i,i=i+40|0,c[w>>2]=c[q>>2],c[w+8>>2]=t,c[w+16>>2]=r,c[w+24>>2]=p,c[w+32>>2]=A,w)|0);i=w}}while(0);z=c[u+4>>2]|0;A=c[u>>2]|0;p=Ao(o,z,A,s)|0;r=n+72|0;if(((c[r>>2]|0)-4|0)>>>0<2>>>0){B=Ao(o,p,c[u+8>>2]|0,s)|0}else{B=p}p=c[n+112>>2]|0;do{if((p|0)==1){o=n+56|0;t=c[o>>2]|0;C=c[o+4>>2]|0;D=m+160|0;E=c[D>>2]|0;F=c[D+4>>2]|0;D=wrc(E,F,-1,-1)|0;if((t|0)==(D|0)&(C|0)==(G|0)){C=n+48|0;D=c[C+4>>2]|0;t=n+96|0;H=c[t>>2]|0;I=c[t+4>>2]|0;if((D|0)>(I|0)|(D|0)==(I|0)&(c[C>>2]|0)>>>0>H>>>0){J=1;break}else{K=I;L=H}}else{H=c[n+4>>2]|0;I=c[y>>2]|0;C=c[I+32>>2]|0;D=c[H+32>>2]|0;t=c[H+68>>2]|0;M=c[H+72>>2]|0;if((M|0)>0){N=(t|0)>0;O=c[I>>2]|0;I=c[H>>2]|0;H=0;P=0;Q=0;while(1){if(N){R=0;S=P;T=Q;while(1){U=(d[I+R|0]|0)-(d[O+R|0]|0)|0;V=(U|0)>-1?U:-U|0;U=wrc(V,(V|0)<0|0?-1:0,T,S)|0;V=G;W=R+1|0;if((W|0)<(t|0)){R=W;S=V;T=U}else{X=V;Y=U;break}}}else{X=P;Y=Q}T=H+1|0;if((T|0)<(M|0)){O=O+C|0;I=I+D|0;H=T;P=X;Q=Y}else{Z=X;_=Y;break}}}else{Z=0;_=0}Q=n+96|0;P=c[Q>>2]|0;H=c[Q+4>>2]|0;if((Z|0)>(H|0)|(Z|0)==(H|0)&_>>>0>P>>>0){J=1;break}else{K=H;L=P}}c[o>>2]=E;c[o+4>>2]=F;P=c[y>>2]|0;H=c[n+12>>2]|0;Q=c[H+32>>2]|0;D=c[P+32>>2]|0;I=c[P+68>>2]|0;C=c[P+72>>2]|0;if((C|0)>0){O=(I|0)>0;M=c[H>>2]|0;H=c[P>>2]|0;P=0;t=0;N=0;while(1){if(O){q=0;T=t;S=N;while(1){R=(d[H+q|0]|0)-(d[M+q|0]|0)|0;U=(R|0)>-1?R:-R|0;R=wrc(U,(U|0)<0|0?-1:0,S,T)|0;U=G;V=q+1|0;if((V|0)<(I|0)){q=V;T=U;S=R}else{$=U;aa=R;break}}}else{$=t;aa=N}S=P+1|0;if((S|0)<(C|0)){M=M+Q|0;H=H+D|0;P=S;t=$;N=aa}else{ba=$;ca=aa;break}}}else{ba=0;ca=0}N=n+48|0;c[N>>2]=ca;c[N+4>>2]=ba;J=((ba|0)>(K|0)|(ba|0)==(K|0)&ca>>>0>L>>>0)&1}else{J=0}}while(0);if((p|0)==1){if((J|0)==0){da=B}else{ea=52}}else if((p|0)==2){ea=52}else{da=B}a:do{if((ea|0)==52){switch(c[r>>2]|0){case 5:{p=g|0;L=j|0;da=Bo(l,p,Bo(l,p,B,c[u+16>>2]|0,L,s)|0,c[u+12>>2]|0,L,s)|0;break a;break};case 1:{da=Bo(l,g|0,B,c[u+8>>2]|0,j|0,s)|0;break a;break};case 2:{da=Bo(l,g|0,B,c[u+16>>2]|0,j|0,s)|0;break a;break};case 3:{L=g|0;p=j|0;da=Bo(l,L,Bo(l,L,Bo(l,L,B,c[u+8>>2]|0,p,s)|0,c[u+16>>2]|0,p,s)|0,c[u+12>>2]|0,p,s)|0;break a;break};case 4:{da=Bo(l,g|0,B,(B|0)==(A|0)?z:A,j|0,s)|0;break a;break};case 0:{da=Bo(l,g|0,B,(B|0)==(A|0)?z:A,j|0,s)|0;break a;break};default:{KIb(0,0,2196896,(w=i,i=i+24|0,c[w>>2]=2583464,c[w+8>>2]=2139224,c[w+16>>2]=780,w)|0);i=w;Hd();return 0}}}}while(0);do{if((c[x>>2]|0)==0){A=j+(da<<2)|0;z=c[A>>2]|0;if((z|0)==0){fa=yo(l,da,s,c[n+4>>2]|0,c[y>>2]|0,c[n+12>>2]|0)|0;ea=65;break}else{c[A>>2]=0;ga=z;break}}else{fa=yo(l,da,s,c[n+16>>2]|0,c[n+20>>2]|0,c[n+24>>2]|0)|0;ea=65}}while(0);do{if((ea|0)==65){if((fa|0)==0){v=-12}else{ga=fa;break}i=f;return v|0}}while(0);VHb(j|0);VHb(j+4|0);VHb(j+8|0);VHb(j+12|0);VHb(j+16|0);j=n+136|0;n=(c[g+(da<<2)>>2]|0)>=(c[j>>2]|0);fa=n&1;ea=ga+296|0;c[ea>>2]=fa;y=l;if(n){n=m+160|0;l=c[n>>2]|0;x=c[n+4>>2]|0;n=k|0;mrc(n|0,0,32)|0;a[n]=0;k=e+136|0;e=c[k>>2]|0;z=c[k+4>>2]|0;if((e|0)==0&(z|0)==(-2147483648|0)){Rb(n|0,32,2499024,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0)|0;i=w}else{Rb(n|0,32,2486680,(w=i,i=i+8|0,h[w>>3]=(+(e>>>0)+ +(z|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),w)|0)|0;i=w}KIb(y,24,2562856,(w=i,i=i+24|0,c[w>>2]=l,c[w+8>>2]=x,c[w+16>>2]=n,w)|0);i=w;c[ga+300>>2]=s;ha=c[ea>>2]|0}else{ha=fa}fa=c[g>>2]|0;ea=c[g+4>>2]|0;s=c[g+8>>2]|0;n=c[g+12>>2]|0;x=c[g+16>>2]|0;g=c[j>>2]|0;KIb(y,48,2545352,(w=i,i=i+72|0,c[w>>2]=J,c[w+8>>2]=fa,c[w+16>>2]=ea,c[w+24>>2]=s,c[w+32>>2]=n,c[w+40>>2]=x,c[w+48>>2]=g,c[w+56>>2]=da,c[w+64>>2]=(ha|0)!=0?2527680:2512616,w)|0);i=w;v=lj(m,ga)|0;i=f;return v|0}function xo(a){a=a|0;var b=0,e=0,f=0,g=0,i=0,j=0.0,k=0.0,l=0,m=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=qKb(c[e>>2]|0)|0;g=c[a+20>>2]|0;i=c[a+24>>2]|0;j=+(ca(i,g)|0)*255.0;k=+h[b+104>>3]*j/100.0;a=(F=+k,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);l=b+96|0;c[l>>2]=~~+k>>>0;c[l+4>>2]=a;a=sIb(b+140|0,b+156|0,g,i,c[e>>2]|0,32)|0;if((a|0)<0){m=a;return m|0}a=sIb(b+172|0,b+188|0,g,i,c[e>>2]|0,32)|0;if((a|0)<0){m=a;return m|0}else{c[b+36>>2]=d[f+5|0]|0;c[b+40>>2]=d[f+6|0]|0;f=g+15&-16;c[b+208>>2]=f;c[b+212>>2]=(g>>1)+15&-16;m=b+216|0;c[m>>2]=hJb(ca(f,(i|0)/2|0)|0)|0;f=c[b+128>>2]|0;a=c[b+132>>2]|0;e=hJb(ca((((((f|0)/2|0)+g|0)/(f|0)|0)<<4)+16|0,((((a|0)/2|0)+i|0)/(a|0)|0)+1|0)|0)|0;c[b+204>>2]=e;return((c[m>>2]|0)==0|(e|0)==0?-12:0)|0}return 0}function yo(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;j=c[a+44>>2]|0;if((b|0)==1){k=$Hb(f)|0;i=h;return k|0}l=c[c[a+32>>2]>>2]|0;a=bv(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((a|0)==0){k=0;i=h;return k|0}ZHb(a,f)|0;if((b|0)==0){l=1-d|0;m=f+68|0;n=f+72|0;o=j+36|0;p=j+40|0;q=0;do{r=c[f+(q<<2)>>2]|0;if((r|0)==0){break}s=c[f+32+(q<<2)>>2]|0;if((s|0)==0){break}t=c[a+32+(q<<2)>>2]|0;u=(c[a+(q<<2)>>2]|0)+(ca(t,l)|0)|0;v=r+(ca(s,l)|0)|0;r=c[m>>2]|0;if((q|0)==0){w=c[n>>2]|0;x=r}else{w=-(-(c[n>>2]|0)>>c[p>>2])|0;x=-(-r>>c[o>>2])|0}uIb(u,t<<1,v,s<<1,x,(w|0)/2|0);q=q+1|0;}while((q|0)<4);q=e+68|0;w=e+72|0;x=0;while(1){n=c[e+(x<<2)>>2]|0;if((n|0)==0){k=a;y=62;break}m=c[e+32+(x<<2)>>2]|0;if((m|0)==0){k=a;y=62;break}l=c[a+32+(x<<2)>>2]|0;s=(c[a+(x<<2)>>2]|0)+(ca(l,d)|0)|0;v=n+(ca(m,d)|0)|0;n=c[q>>2]|0;if((x|0)==0){z=c[w>>2]|0;A=n}else{z=-(-(c[w>>2]|0)>>c[p>>2])|0;A=-(-n>>c[o>>2])|0}uIb(s,l<<1,v,m<<1,A,(z|0)/2|0);m=x+1|0;if((m|0)<4){x=m}else{k=a;y=62;break}}if((y|0)==62){i=h;return k|0}}else if((b|0)==4){x=f+68|0;z=f+72|0;A=j+36|0;o=j+40|0;p=0;do{w=c[f+(p<<2)>>2]|0;if((w|0)==0){break}q=c[f+32+(p<<2)>>2]|0;if((q|0)==0){break}m=c[a+32+(p<<2)>>2]|0;v=(c[a+(p<<2)>>2]|0)+(ca(m,d)|0)|0;l=w+(ca(q,d)|0)|0;w=c[x>>2]|0;if((p|0)==0){B=c[z>>2]|0;C=w}else{B=-(-(c[z>>2]|0)>>c[o>>2])|0;C=-(-w>>c[A>>2])|0}uIb(v,m<<1,l,q<<1,C,(B|0)/2|0);p=p+1|0;}while((p|0)<4);p=1-d|0;B=g+68|0;C=g+72|0;z=0;while(1){x=c[g+(z<<2)>>2]|0;if((x|0)==0){k=a;y=62;break}q=c[g+32+(z<<2)>>2]|0;if((q|0)==0){k=a;y=62;break}l=c[a+32+(z<<2)>>2]|0;m=(c[a+(z<<2)>>2]|0)+(ca(l,p)|0)|0;v=x+(ca(q,p)|0)|0;x=c[B>>2]|0;if((z|0)==0){D=c[C>>2]|0;E=x}else{D=-(-(c[C>>2]|0)>>c[o>>2])|0;E=-(-x>>c[A>>2])|0}uIb(m,l<<1,v,q<<1,E,(D|0)/2|0);q=z+1|0;if((q|0)<4){z=q}else{k=a;y=62;break}}if((y|0)==62){i=h;return k|0}}else if((b|0)==3){z=f+68|0;D=f+72|0;E=j+36|0;A=j+40|0;o=0;do{C=c[f+(o<<2)>>2]|0;if((C|0)==0){break}B=c[f+32+(o<<2)>>2]|0;if((B|0)==0){break}p=c[a+32+(o<<2)>>2]|0;q=(c[a+(o<<2)>>2]|0)+(ca(p,d)|0)|0;v=C+(ca(B,d)|0)|0;C=c[z>>2]|0;if((o|0)==0){F=c[D>>2]|0;G=C}else{F=-(-(c[D>>2]|0)>>c[A>>2])|0;G=-(-C>>c[E>>2])|0}uIb(q,p<<1,v,B<<1,G,(F|0)/2|0);o=o+1|0;}while((o|0)<4);o=1-d|0;F=e+68|0;G=e+72|0;D=0;while(1){z=c[e+(D<<2)>>2]|0;if((z|0)==0){k=a;y=62;break}B=c[e+32+(D<<2)>>2]|0;if((B|0)==0){k=a;y=62;break}v=c[a+32+(D<<2)>>2]|0;p=(c[a+(D<<2)>>2]|0)+(ca(v,o)|0)|0;q=z+(ca(B,o)|0)|0;z=c[F>>2]|0;if((D|0)==0){H=c[G>>2]|0;I=z}else{H=-(-(c[G>>2]|0)>>c[A>>2])|0;I=-(-z>>c[E>>2])|0}uIb(p,v<<1,q,B<<1,I,(H|0)/2|0);B=D+1|0;if((B|0)<4){D=B}else{k=a;y=62;break}}if((y|0)==62){i=h;return k|0}}else if((b|0)==2){b=1-d|0;D=f+68|0;H=f+72|0;I=j+36|0;E=j+40|0;j=0;do{A=c[f+(j<<2)>>2]|0;if((A|0)==0){break}G=c[f+32+(j<<2)>>2]|0;if((G|0)==0){break}F=c[a+32+(j<<2)>>2]|0;o=(c[a+(j<<2)>>2]|0)+(ca(F,b)|0)|0;e=A+(ca(G,b)|0)|0;A=c[D>>2]|0;if((j|0)==0){J=c[H>>2]|0;K=A}else{J=-(-(c[H>>2]|0)>>c[E>>2])|0;K=-(-A>>c[I>>2])|0}uIb(o,F<<1,e,G<<1,K,(J|0)/2|0);j=j+1|0;}while((j|0)<4);j=g+68|0;J=g+72|0;K=0;while(1){H=c[g+(K<<2)>>2]|0;if((H|0)==0){k=a;y=62;break}D=c[g+32+(K<<2)>>2]|0;if((D|0)==0){k=a;y=62;break}b=c[a+32+(K<<2)>>2]|0;f=(c[a+(K<<2)>>2]|0)+(ca(b,d)|0)|0;G=H+(ca(D,d)|0)|0;H=c[j>>2]|0;if((K|0)==0){L=c[J>>2]|0;M=H}else{L=-(-(c[J>>2]|0)>>c[E>>2])|0;M=-(-H>>c[I>>2])|0}uIb(f,b<<1,G,D<<1,M,(L|0)/2|0);D=K+1|0;if((D|0)<4){K=D}else{k=a;y=62;break}}if((y|0)==62){i=h;return k|0}}else{KIb(0,0,2196896,(k=i,i=i+24|0,c[k>>2]=2583464,c[k+8>>2]=2139224,c[k+16>>2]=638,k)|0);i=k;Hd();return 0}return 0}function zo(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;g=c[e+120>>2]|0;h=g*6|0;i=e+124|0;j=f+68|0;k=f+72|0;l=(g|0)<0;m=e+36|0;n=e+40|0;o=0;do{p=c[f+(o<<2)>>2]|0;q=c[f+32+(o<<2)>>2]|0;r=c[j>>2]|0;if((o|0)==0){s=c[k>>2]|0;t=r}else{s=-(-(c[k>>2]|0)>>c[n>>2])|0;t=-(-r>>c[m>>2])|0}r=c[e+172+(o<<2)>>2]|0;u=c[e+188+(o<<2)>>2]|0;v=(s|0)>0;do{if(l){if(v){w=r;x=0}else{break}while(1){mrc(w|0,-1|0,t|0)|0;y=x+1|0;if((y|0)<(s|0)){w=w+u|0;x=y}else{break}}}else{if(v){y=r;z=0;while(1){mrc(y|0,0,t|0)|0;A=z+1|0;if((A|0)<(s|0)){y=y+u|0;z=A}else{break}}}z=(t|0)>0;do{if(z){y=q<<1;A=0;do{B=d[p+A|0]|0;C=d[p+(A+q)|0]|0;D=B-C|0;do{if((((D|0)>-1?D:-D|0)|0)>(g|0)){E=(C*-6|0)+(B<<2)+(d[p+(A+y)|0]<<1)|0;if((((E|0)>-1?E:-E|0)|0)<=(h|0)){break}a[r+A|0]=-1}}while(0);A=A+1|0;}while((A|0)<(t|0));if(!z){F=17;break}A=q<<1;y=q*3|0;B=0;while(1){C=d[p+(B+q)|0]|0;D=d[p+B|0]|0;E=C-D|0;G=d[p+(A+B)|0]|0;H=C-G|0;do{if((((E|0)>-1?E:-E|0)|0)>(g|0)&(((H|0)>-1?H:-H|0)|0)>(g|0)){I=((G+D|0)*-3|0)+(C<<2)+(d[p+(y+B)|0]<<1)|0;if((((I|0)>-1?I:-I|0)|0)<=(h|0)){break}a[r+(B+u)|0]=-1}}while(0);C=B+1|0;if((C|0)<(t|0)){B=C}else{J=A;break}}}else{F=17}}while(0);if((F|0)==17){F=0;J=q<<1}A=p+J|0;B=r+(u<<1)|0;y=s-2|0;if((y|0)>2){C=q*-2|0;D=ca(u,y)|0;G=ca(q,y)|0;H=B;E=A;I=2;while(1){if(z){K=0;do{L=d[E+K|0]|0;M=d[E+(K-q)|0]|0;N=L-M|0;O=d[E+(K+q)|0]|0;P=L-O|0;do{if((((N|0)>-1?N:-N|0)|0)>(g|0)&(((P|0)>-1?P:-P|0)|0)>(g|0)){Q=(d[E+(K+C)|0]|0)+(L<<2)+((O+M|0)*-3|0)+(d[E+(K+J)|0]|0)|0;if((((Q|0)>-1?Q:-Q|0)|0)<=(h|0)){break}a[H+K|0]=-1}}while(0);K=K+1|0;}while((K|0)<(t|0))}K=I+1|0;if((K|0)<(y|0)){H=H+u|0;E=E+q|0;I=K}else{break}}R=r+D|0;S=p+G|0}else{R=B;S=A}if(!z){break}I=q*-2|0;E=0;do{H=d[S+E|0]|0;y=d[S+(E-q)|0]|0;C=H-y|0;K=d[S+(E+q)|0]|0;M=H-K|0;do{if((((C|0)>-1?C:-C|0)|0)>(g|0)&(((M|0)>-1?M:-M|0)|0)>(g|0)){O=((K+y|0)*-3|0)+(H<<2)+(d[S+(E+I)|0]<<1)|0;if((((O|0)>-1?O:-O|0)|0)<=(h|0)){break}a[R+E|0]=-1}}while(0);E=E+1|0;}while((E|0)<(t|0));if(z){T=0}else{break}do{E=d[S+(T+q)|0]|0;I=d[S+T|0]|0;A=E-I|0;do{if((((A|0)>-1?A:-A|0)|0)>(g|0)){B=(I*-6|0)+(E<<2)+(d[S+(T-q)|0]<<1)|0;if((((B|0)>-1?B:-B|0)|0)<=(h|0)){break}a[R+(T+u)|0]=-1}}while(0);T=T+1|0;}while((T|0)<(t|0))}}while(0);o=o+1|0;U=(c[i>>2]|0)!=0;}while((o|0)<((U?3:1)|0));do{if(U){o=e+172|0;i=c[o>>2]|0;t=c[k>>2]|0;T=-t>>c[n>>2];R=e+188|0;h=c[R>>2]<<1;S=c[e+196>>2]|0;g=h>>1;J=~T;if(!((T|0)<-2)){V=t;W=R;X=o;break}T=-(c[j>>2]|0)>>c[m>>2];s=~T;x=(T|0)<-2;T=S<<1;w=i+h|0;l=i+g|0;f=i+(-g|0)|0;g=c[e+180>>2]|0;u=c[e+176>>2]|0;q=i;i=1;while(1){p=f+h|0;r=q+h|0;v=l+h|0;z=w+h|0;E=g+S|0;I=u+S|0;if(x){A=r;B=v;G=(i&1|0)==0;D=z;H=p;y=1;do{K=y+S|0;do{if((a[g+K|0]|0)==-1){M=y-1|0;if((a[g+M|0]|0)==-1){F=68;break}if((a[g+y|0]|0)==-1){F=68;break}C=y+1|0;if((a[g+C|0]|0)==-1){F=68;break}if((a[g+(M+S)|0]|0)==-1){F=68;break}if((a[g+(C+S)|0]|0)==-1){F=68;break}if((a[g+(T+M)|0]|0)==-1){F=68;break}if((a[g+(T+y)|0]|0)==-1){F=68;break}if((a[g+(T+C)|0]|0)==-1){F=68}else{F=59}}else{F=59}}while(0);do{if((F|0)==59){F=0;if(!((a[u+K|0]|0)==-1)){break}C=y-1|0;if((a[u+C|0]|0)==-1){F=68;break}if((a[u+y|0]|0)==-1){F=68;break}M=y+1|0;if((a[u+M|0]|0)==-1){F=68;break}if((a[u+(C+S)|0]|0)==-1){F=68;break}if((a[u+(M+S)|0]|0)==-1){F=68;break}if((a[u+(T+C)|0]|0)==-1){F=68;break}if((a[u+(T+y)|0]|0)==-1){F=68;break}if((a[u+(T+M)|0]|0)==-1){F=68}}}while(0);do{if((F|0)==68){F=0;b[A+(y<<1)>>1]=-1;b[B+(y<<1)>>1]=-1;if(G){b[D+(y<<1)>>1]=-1;break}else{b[H+(y<<1)>>1]=-1;break}}}while(0);y=y+1|0;}while((y|0)<(s|0))}y=i+1|0;if((y|0)<(J|0)){w=z;l=v;f=p;g=E;u=I;q=r;i=y}else{V=t;W=R;X=o;break}}}else{V=c[k>>2]|0;W=e+188|0;X=e+172|0}}while(0);k=c[e+128>>2]|0;m=c[e+132>>2]|0;n=(k|0)/2|0;U=(m|0)/2|0;o=c[W>>2]|0;W=c[X>>2]|0;X=c[j>>2]|0;j=((X+n|0)/(k|0)|0)+1|0;R=j<<2;t=c[e+204>>2]|0;e=ca(((V+U|0)/(m|0)|0)+1|0,j)|0;j=e<<2;i=(V|0)%(U|0)|0;q=X-((X|0)%(n|0)|0)|0;u=V-((i|0)==0?U:i)|0;mrc(t|0,0,e<<4|0)|0;e=W+o|0;if((m|0)>3){i=(X|0)>0;g=o<<1;f=ca(o,(U|0)>2?U:2)|0;l=W;w=1;J=e;while(1){s=ca((w|0)/(m|0)|0,R)|0;T=ca((w+U|0)/(m|0)|0,R)|0;if(i){S=0;do{do{if((a[l+S|0]|0)==-1){if(!((a[l+(S+o)|0]|0)==-1)){break}if(!((a[l+(g+S)|0]|0)==-1)){break}x=((S|0)/(k|0)|0)<<2;h=((S+n|0)/(k|0)|0)<<2;y=t+(x+s<<2)|0;c[y>>2]=(c[y>>2]|0)+1;y=t+((h+s|1)<<2)|0;c[y>>2]=(c[y>>2]|0)+1;y=t+((x+T|2)<<2)|0;c[y>>2]=(c[y>>2]|0)+1;y=t+((h+T|3)<<2)|0;c[y>>2]=(c[y>>2]|0)+1}}while(0);S=S+1|0;}while((S|0)<(X|0))}S=w+1|0;if((S|0)<(U|0)){l=J;w=S;J=J+o|0}else{break}}Y=W+f|0}else{Y=e}if((U|0)<(u|0)){e=(q|0)>0;f=(q|0)<(X|0);W=ca(o,U)|0;J=(m|0)>1;w=-o|0;l=Y;g=U;while(1){i=ca((g|0)/(m|0)|0,R)|0;S=g+U|0;T=ca((S|0)/(m|0)|0,R)|0;if(e){s=0;while(1){do{if((k|0)<2|J^1){F=102}else{r=l+s|0;I=0;E=0;while(1){p=0;v=E;while(1){do{if((a[r+(p-o)|0]|0)==-1){if(!((a[r+p|0]|0)==-1)){Z=v;break}Z=((a[r+(p+o)|0]|0)==-1)+v|0}else{Z=v}}while(0);z=p+1|0;if((z|0)<(n|0)){p=z;v=Z}else{break}}v=I+1|0;if((v|0)<(U|0)){r=r+o|0;I=v;E=Z}else{break}}if((Z|0)==0){F=102;break}E=((s|0)/(k|0)|0)<<2;I=s+n|0;r=((I|0)/(k|0)|0)<<2;v=t+(E+i<<2)|0;c[v>>2]=(c[v>>2]|0)+Z;v=t+((r+i|1)<<2)|0;c[v>>2]=(c[v>>2]|0)+Z;v=t+((E+T|2)<<2)|0;c[v>>2]=(c[v>>2]|0)+Z;v=t+((r+T|3)<<2)|0;c[v>>2]=(c[v>>2]|0)+Z;_=I}}while(0);if((F|0)==102){F=0;_=s+n|0}if((_|0)<(q|0)){s=_}else{break}}}if(f){s=q;do{do{if(J){I=l+s|0;v=0;r=0;while(1){do{if((a[I+w|0]|0)==-1){if(!((a[I]|0)==-1)){$=r;break}$=((a[I+o|0]|0)==-1)+r|0}else{$=r}}while(0);E=v+1|0;if((E|0)<(U|0)){I=I+o|0;v=E;r=$}else{break}}if(($|0)==0){break}r=((s|0)/(k|0)|0)<<2;v=((s+n|0)/(k|0)|0)<<2;I=t+(r+i<<2)|0;c[I>>2]=(c[I>>2]|0)+$;I=t+((v+i|1)<<2)|0;c[I>>2]=(c[I>>2]|0)+$;I=t+((r+T|2)<<2)|0;c[I>>2]=(c[I>>2]|0)+$;I=t+((v+T|3)<<2)|0;c[I>>2]=(c[I>>2]|0)+$}}while(0);s=s+1|0;}while((s|0)<(X|0))}s=l+W|0;if((S|0)<(u|0)){l=s;g=S}else{aa=s;break}}}else{aa=Y}Y=V-1|0;if((u|0)<(Y|0)&(X|0)>0){V=aa;aa=u;while(1){u=ca((aa|0)/(m|0)|0,R)|0;g=ca((aa+U|0)/(m|0)|0,R)|0;l=0;do{do{if((a[V+(l-o)|0]|0)==-1){if(!((a[V+l|0]|0)==-1)){break}if(!((a[V+(l+o)|0]|0)==-1)){break}W=((l|0)/(k|0)|0)<<2;$=((l+n|0)/(k|0)|0)<<2;w=t+(W+u<<2)|0;c[w>>2]=(c[w>>2]|0)+1;w=t+(($+u|1)<<2)|0;c[w>>2]=(c[w>>2]|0)+1;w=t+((W+g|2)<<2)|0;c[w>>2]=(c[w>>2]|0)+1;w=t+(($+g|3)<<2)|0;c[w>>2]=(c[w>>2]|0)+1}}while(0);l=l+1|0;}while((l|0)<(X|0));l=aa+1|0;if((l|0)<(Y|0)){V=V+o|0;aa=l}else{break}}}if((j|0)>0){ba=0;da=0}else{ea=0;return ea|0}while(1){aa=c[t+(da<<2)>>2]|0;o=(aa|0)>(ba|0)?aa:ba;aa=da+1|0;if((aa|0)<(j|0)){ba=o;da=aa}else{ea=o;break}}return ea|0}function Ao(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0.0,Pb=0.0,Qb=0.0,Rb=0.0,Sb=0.0,Tb=0;h=b+8|0;i=c[h>>2]|0;j=b+80|0;k=i+68|0;l=i+72|0;m=b+84|0;n=b+88|0;o=2-g|0;p=g+1|0;q=(e|0)<3?o:p;r=q+1|0;s=(f|0)<3?o:p;p=(e|0)>2^(g|0)==1;g=b+4|0;o=b+12|0;t=b+36|0;u=b+40|0;v=0;w=0;x=0;y=0;z=0;A=0;B=0;C=0;D=0;E=0;F=0;H=0;I=0;while(1){J=c[b+140+(I<<2)>>2]|0;K=c[b+156+(I<<2)>>2]|0;L=c[i+(I<<2)>>2]|0;M=c[i+32+(I<<2)>>2]|0;N=M<<1;O=c[k>>2]|0;P=(I|0)==0;if(P){Q=c[l>>2]|0;R=O}else{Q=-(-(c[l>>2]|0)>>c[u>>2])|0;R=-(-O>>c[t>>2])|0}O=(I|0)!=0|0;S=c[m>>2]>>O;T=c[n>>2]>>O;O=P?8:4;P=R-O|0;if((Q|0)>0){U=J;V=0;while(1){mrc(U|0,0,R|0)|0;W=V+1|0;if((W|0)<(Q|0)){U=U+K|0;V=W}else{break}}}V=ca(M,r)|0;U=L+V|0;W=L+(V-N)|0;X=L+(V+N)|0;V=ca(K,q)|0;Y=J+V|0;if((e|0)==4|(e|0)==2){Z=o}else if((e|0)==3|(e|0)==0){Z=g}else{Z=h}_=c[Z>>2]|0;$=c[_+32+(I<<2)>>2]|0;aa=$<<1;ba=c[_+(I<<2)>>2]|0;_=ca($,q)|0;$=ba+_|0;da=ba+(_+aa)|0;if((f|0)==3|(f|0)==0){ea=g}else if((f|0)==4|(f|0)==2){ea=o}else{ea=h}_=c[ea>>2]|0;ba=c[_+32+(I<<2)>>2]|0;fa=ba<<1;ga=c[_+(I<<2)>>2]|0;_=ca(ba,s)|0;ba=ga+_|0;ha=ga+(_+fa)|0;_=K<<1;if(p){Co(b,da,aa,ha,fa,J+(V+_)|0,_,Q,R,I)}else{Co(b,$,aa,ba,fa,Y,_,Q,R,I)}V=Q-2|0;if((V|0)>2){ga=(S|0)==(T|0);ia=(O|0)<(P|0);ja=Y;Y=2;ka=v;la=w;ma=x;na=y;oa=z;pa=A;qa=B;ra=C;sa=D;ta=E;ua=F;va=H;wa=W;W=U;U=X;X=$;$=da;da=ba;ba=ha;while(1){do{if(ga|(Y|0)<(S|0)|(Y|0)>(T|0)){if(ia){xa=O;ya=ka;za=la;Aa=ma;Ba=na;Ca=oa;Da=pa;Ea=qa;Fa=ra;Ga=sa;Ha=ta;Ia=ua;Ja=va}else{Ka=ua;La=va;Ma=sa;Na=ta;Oa=qa;Pa=ra;Qa=oa;Ra=pa;Sa=ma;Ta=na;Ua=ka;Va=la;break}while(1){ha=a[ja+xa|0]|0;if(ha<<24>>24==0){if((a[ja+(xa+_)|0]|0)==0){Wa=Ia;Xa=Ja;Ya=Ga;Za=Ha;_a=Ea;$a=Fa;ab=Ca;bb=Da;cb=Aa;db=Ba;eb=ya;fb=za}else{gb=22}}else{gb=22}do{if((gb|0)==22){gb=0;hb=(d[W+xa|0]<<2)+(d[wa+xa|0]|0)+(d[U+xa|0]|0)|0;ib=(((d[$+xa|0]|0)+(d[X+xa|0]|0)|0)*3|0)-hb|0;jb=(ib|0)>-1?ib:-ib|0;do{if((jb|0)>23){if((ha&1)==0){if((a[ja+(xa+_)|0]&1)==0){kb=Ia;lb=Ja}else{gb=25}}else{gb=25}if((gb|0)==25){gb=0;ib=wrc(jb,(jb|0)<0|0?-1:0,Ja,Ia)|0;kb=G;lb=ib}if((jb|0)<=42){mb=Ga;nb=Ha;ob=Ea;pb=Fa;qb=kb;rb=lb;break}if((ha&2)==0){if((a[ja+(xa+_)|0]&2)==0){sb=Ga;tb=Ha}else{gb=29}}else{gb=29}if((gb|0)==29){gb=0;ib=wrc(jb,(jb|0)<0|0?-1:0,Ha,Ga)|0;sb=G;tb=ib}if((ha&4)==0){if((a[ja+(xa+_)|0]&4)==0){mb=sb;nb=tb;ob=Ea;pb=Fa;qb=kb;rb=lb;break}}ib=wrc(jb,(jb|0)<0|0?-1:0,Fa,Ea)|0;mb=sb;nb=tb;ob=G;pb=ib;qb=kb;rb=lb}else{mb=Ga;nb=Ha;ob=Ea;pb=Fa;qb=Ia;rb=Ja}}while(0);jb=(((d[ba+xa|0]|0)+(d[da+xa|0]|0)|0)*3|0)-hb|0;ib=(jb|0)>-1?jb:-jb|0;if((ib|0)<=23){Wa=qb;Xa=rb;Ya=mb;Za=nb;_a=ob;$a=pb;ab=Ca;bb=Da;cb=Aa;db=Ba;eb=ya;fb=za;break}if((ha&1)==0){if((a[ja+(xa+_)|0]&1)==0){ub=Ca;vb=Da}else{gb=36}}else{gb=36}if((gb|0)==36){gb=0;jb=wrc(ib,(ib|0)<0|0?-1:0,Da,Ca)|0;ub=G;vb=jb}if((ib|0)<=42){Wa=qb;Xa=rb;Ya=mb;Za=nb;_a=ob;$a=pb;ab=ub;bb=vb;cb=Aa;db=Ba;eb=ya;fb=za;break}if((ha&2)==0){if((a[ja+(xa+_)|0]&2)==0){wb=Aa;xb=Ba}else{gb=40}}else{gb=40}if((gb|0)==40){gb=0;jb=wrc(ib,(ib|0)<0|0?-1:0,Ba,Aa)|0;wb=G;xb=jb}if((ha&4)==0){if((a[ja+(xa+_)|0]&4)==0){Wa=qb;Xa=rb;Ya=mb;Za=nb;_a=ob;$a=pb;ab=ub;bb=vb;cb=wb;db=xb;eb=ya;fb=za;break}}jb=wrc(ib,(ib|0)<0|0?-1:0,za,ya)|0;Wa=qb;Xa=rb;Ya=mb;Za=nb;_a=ob;$a=pb;ab=ub;bb=vb;cb=wb;db=xb;eb=G;fb=jb}}while(0);ha=xa+1|0;if((ha|0)<(P|0)){xa=ha;ya=eb;za=fb;Aa=cb;Ba=db;Ca=ab;Da=bb;Ea=_a;Fa=$a;Ga=Ya;Ha=Za;Ia=Wa;Ja=Xa}else{Ka=Wa;La=Xa;Ma=Ya;Na=Za;Oa=_a;Pa=$a;Qa=ab;Ra=bb;Sa=cb;Ta=db;Ua=eb;Va=fb;break}}}else{Ka=ua;La=va;Ma=sa;Na=ta;Oa=qa;Pa=ra;Qa=oa;Ra=pa;Sa=ma;Ta=na;Ua=ka;Va=la}}while(0);ha=Y+2|0;if((ha|0)<(V|0)){ja=ja+_|0;Y=ha;ka=Ua;la=Va;ma=Sa;na=Ta;oa=Qa;pa=Ra;qa=Oa;ra=Pa;sa=Ma;ta=Na;ua=Ka;va=La;wa=wa+N|0;W=W+N|0;U=U+N|0;X=X+aa|0;$=$+aa|0;da=da+fa|0;ba=ba+fa|0}else{yb=Ua;zb=Va;Ab=Sa;Bb=Ta;Cb=Qa;Db=Ra;Eb=Oa;Fb=Pa;Gb=Ma;Hb=Na;Ib=Ka;Jb=La;break}}}else{yb=v;zb=w;Ab=x;Bb=y;Cb=z;Db=A;Eb=B;Fb=C;Gb=D;Hb=E;Ib=F;Jb=H}fa=I+1|0;if((fa|0)<(((c[j>>2]|0)!=0?3:1)|0)){v=yb;w=zb;x=Ab;y=Bb;z=Cb;A=Db;B=Eb;C=Fb;D=Gb;E=Hb;F=Ib;H=Jb;I=fa}else{break}}I=0;H=0;do{if((Gb>>>0<I>>>0|Gb>>>0==I>>>0&Hb>>>0<500>>>0)&(Ab>>>0<H>>>0|Ab>>>0==H>>>0&Bb>>>0<500>>>0)){F=0;E=0;if(!(Eb>>>0>F>>>0|Eb>>>0==F>>>0&Fb>>>0>499>>>0|(yb>>>0>E>>>0|yb>>>0==E>>>0&zb>>>0>499>>>0))){Kb=Gb;Lb=Hb;Mb=Ab;Nb=Bb;break}E=Eb>>>0>yb>>>0|Eb>>>0==yb>>>0&Fb>>>0>zb>>>0;F=E?Eb:yb;D=Erc(E?zb:Fb,E?yb:Eb,3,0)|0;C=G;B=F>>>0>C>>>0|F>>>0==C>>>0&(E?Fb:zb)>>>0>D>>>0;Kb=B?Eb:Gb;Lb=B?Fb:Hb;Mb=B?yb:Ab;Nb=B?zb:Bb}else{Kb=Gb;Lb=Hb;Mb=Ab;Nb=Bb}}while(0);Bb=~~((+(Jb>>>0)+ +(Ib>>>0)*4294967296.0)/6.0+.5);Ib=~~((+(Db>>>0)+ +(Cb>>>0)*4294967296.0)/6.0+.5);Cb=~~((+(Lb>>>0)+ +(Kb>>>0)*4294967296.0)/6.0+.5);Kb=~~((+(Nb>>>0)+ +(Mb>>>0)*4294967296.0)/6.0+.5);Mb=(Bb|0)>(Ib|0);Nb=Mb?Bb:Ib;Ob=+(Nb|0);Lb=Mb?Ib:Bb;if((Lb|0)>1){Pb=+(Lb|0)}else{Pb=1.0}Qb=Ob/Pb;Lb=(Cb|0)>(Kb|0);Bb=Lb?Cb:Kb;Pb=+(Bb|0);Ib=Lb?Kb:Cb;if((Ib|0)>1){Rb=+(Ib|0)}else{Rb=1.0}Sb=Pb/Rb;Rb=Pb/((Nb|0)>1?Ob:1.0);if((Cb|0)>499|(Kb|0)>499){if(!((Cb<<1|0)<(Kb|0)|(Kb<<1|0)<(Cb|0))){gb=56}}else{gb=56}do{if((gb|0)==56){if((Cb|0)>999|(Kb|0)>999){if((Cb*3|0|0)<(Kb<<1|0)){break}if((Kb*3|0|0)<(Cb<<1|0)){break}}if((Cb|0)>1999|(Kb|0)>1999){if((Cb*5|0|0)<(Kb<<2|0)){break}if((Kb*5|0|0)<(Cb<<2|0)){break}}if(((Cb|0)>3999|(Kb|0)>3999)&Sb>Qb){break}do{if(Rb>.005&(Bb|0)>150){if(!((Cb<<1|0)<(Kb|0)|(Kb<<1|0)<(Cb|0))){break}Tb=Lb?f:e;return Tb|0}}while(0);Tb=Mb?f:e;return Tb|0}}while(0);Tb=Lb?f:e;return Tb|0}function Bo(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=c[a+44>>2]|0;i=h;j=b+(d<<2)|0;k=c[j>>2]|0;if((k|0)<0){l=f+(d<<2)|0;m=c[l>>2]|0;if((m|0)==0){n=yo(a,d,g,c[h+4>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0)|0;c[l>>2]=n;o=n}else{o=m}m=zo(i,o)|0;c[j>>2]=m;p=m}else{p=k}k=b+(e<<2)|0;b=c[k>>2]|0;if((b|0)<0){m=f+(e<<2)|0;f=c[m>>2]|0;if((f|0)==0){o=yo(a,e,g,c[h+4>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0)|0;c[m>>2]=o;q=o}else{q=f}f=zo(i,q)|0;c[k>>2]=f;r=f;s=c[j>>2]|0}else{r=b;s=p}do{if((r*3|0|0)<(s|0)){t=12}else{if((r<<1|0)>=(s|0)){break}if((s|0)>(c[h+136>>2]|0)){t=12}}}while(0);do{if((t|0)==12){p=r-s|0;if((((p|0)>-1?p:-p|0)|0)<=29){break}if((r|0)<(c[h+136>>2]|0)){u=e}else{break}return u|0}}while(0);u=d;return u|0}function Co(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;n=c[((m|0)==0?b+208|0:b+212|0)>>2]|0;m=c[b+216>>2]|0;b=k>>1;if((b|0)>0&(l|0)>0){o=m;p=g+(-h|0)|0;g=e+(-f|0)|0;e=0;while(1){q=0;do{r=(d[g+q|0]|0)-(d[p+q|0]|0)|0;a[o+q|0]=(r|0)>-1?r:-r|0;q=q+1|0;}while((q|0)<(l|0));q=e+1|0;if((q|0)<(b|0)){o=o+n|0;p=p+h|0;g=g+f|0;e=q}else{break}}}e=k-2|0;if((e|0)<=2){return}f=l-1|0;g=(f|0)>1;h=n<<1;p=k-4|0;k=n*3|0;o=2;b=i;i=m;while(1){m=i+n|0;if(g){q=(o|0)==2;r=(o|0)==(p|0);s=1;do{t=a[i+(s+n)|0]|0;a:do{if((t&255)>>>0>3>>>0){u=s-1|0;v=s+2|0;w=u;x=0;do{x=((d[i+w|0]|0)>>>0>3>>>0)+x+((d[i+(w+n)|0]|0)>>>0>3>>>0)+((d[i+(h+w)|0]|0)>>>0>3>>>0)|0;w=w+1|0;}while((w|0)<(v|0)&(x|0)<2);if((x|0)<=1){break}w=b+s|0;a[w]=1;if((t&255)>>>0>19>>>0){y=u;z=0;A=0;B=0}else{break}do{C=(d[i+y|0]|0)>>>0>19>>>0;A=C?1:A;D=(d[i+(h+y)|0]|0)>>>0>19>>>0;z=(C&1)+z+((d[i+(y+n)|0]|0)>>>0>19>>>0)+(D&1)|0;B=D?1:B;y=y+1|0;}while((y|0)<(v|0)&(z|0)<6);if((z|0)<=3){break}if(!((A|0)==0|(B|0)==0)){a[w]=3;break}v=s-4|0;u=(v|0)>0?v:0;v=s+5|0;x=(v|0)>(l|0)?l:v;if((u|0)<(x|0)){v=u;u=A;D=B;C=0;E=0;while(1){if(q){F=C}else{F=(d[i+(v-n)|0]|0)>>>0>19>>>0?1:C}G=(d[i+v|0]|0)>>>0>19>>>0?1:u;H=(d[i+(h+v)|0]|0)>>>0>19>>>0?1:D;if(r){I=E}else{I=(d[i+(k+v)|0]|0)>>>0>19>>>0?1:E}J=v+1|0;if((J|0)<(x|0)){v=J;u=G;D=H;C=F;E=I}else{K=G;L=H;M=F;N=I;break}}}else{K=A;L=B;M=0;N=0}E=(K|0)!=0;if(E){if((M|L|0)==0){O=27}}else{O=27}do{if((O|0)==27){O=0;if((L|0)!=0){if(!((N|0)==0&(E^1))){break}}if((z|0)<=5){break a}a[w]=5;break a}}while(0);a[w]=3}}while(0);s=s+1|0;}while((s|0)<(f|0))}s=o+2|0;if((s|0)<(e|0)){o=s;b=b+j|0;i=m}else{break}}return}function Do(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a>>2]|0;a=b+44|0;d=c[a>>2]|0;e=d+68|0;f=c[e>>2]|0;g=f<<1|1;h=d+44|0;if((g&c[h>>2]|0)==(g|0)){i=-541478725;return i|0}do{if((c[d+28>>2]|0)==0){g=c[c[b+16>>2]>>2]|0;j=Wi(g)|0;if((j|0)==-541478725){c[h>>2]=c[h>>2]|1;k=wo(g,0)|0}else{k=j}if((k|0)<0){i=k;return i|0}else{l=c[e>>2]|0;break}}else{l=f}}while(0);do{if((l|0)!=0){f=c[a>>2]|0;if((c[f+32>>2]|0)!=0){break}e=c[(c[b+16>>2]|0)+4>>2]|0;k=Wi(e)|0;if((k|0)==-541478725){h=f+44|0;c[h>>2]=c[h>>2]|2;m=wo(e,0)|0}else{m=k}if((m|0)<0){i=m}else{break}return i|0}}while(0);i=0;return i|0}function Eo(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a>>2]|0;d=c[(c[b+16>>2]|0)+(((c[(c[b+44>>2]|0)+68>>2]|0)!=0)<<2)>>2]|0;b=a+156|0;c[b>>2]=c[b>>2]|1;b=d+56|0;e=a+56|0;f=c[b+4>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=f;f=d+28|0;e=a+28|0;b=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=b;b=d+116|0;e=a+116|0;f=c[b+4>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=f;c[a+20>>2]=c[d+20>>2];c[a+24>>2]=c[d+24>>2];return 0}function Fo(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=b+16|0;if((c[c[f>>2]>>2]|0)==0){g=0;i=d;return g|0}c[e>>2]=0;h=0;a:while(1){j=qKb(h)|0;do{if((a[j+7|0]&14)==0){if((a[j+4|0]|0)==0){break}if((a[j+6|0]|0)!=0){break}k=Qk(e,h,(h|0)<0|0?-1:0)|0;if((k|0)<0){l=7;break a}}}while(0);j=h+1|0;if((j|0)<333){h=j}else{l=9;break}}if((l|0)==7){Zk(e);g=k;i=d;return g|0}else if((l|0)==9){Yk(c[e>>2]|0,(c[c[f>>2]>>2]|0)+68|0);Yk(c[e>>2]|0,(c[c[b+32>>2]>>2]|0)+64|0);g=0;i=d;return g|0}return 0}function Go(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=c[c[f+32>>2]>>2]|0;h=c[b+296>>2]|0;do{if((h|0)!=0){j=a+4|0;if((c[b+300>>2]|0)==(c[j>>2]|0)){break}do{if((bIb(b)|0)==0){k=bv(g,c[g+20>>2]|0,c[g+24>>2]|0)|0;if((k|0)!=0){ZHb(k,c[e>>2]|0)|0;l=k;m=c[e>>2]|0;break}VHb(e);n=-12;i=d;return n|0}else{l=b;m=b}}while(0);k=c[m+72>>2]|0;o=a+8|0;p=k-1|0;a:do{if((k|0)>0){q=0;r=m;while(1){s=c[r+(q<<2)>>2]|0;if((s|0)==0){break a}t=c[r+32+(q<<2)>>2]|0;if((t|0)==0){break a}u=c[l+32+(q<<2)>>2]|0;v=c[o+(q<<2)>>2]|0;w=c[l+(q<<2)>>2]|0;b:do{if((c[j>>2]|0)==0){x=-t|0;y=-u|0;z=t<<1;A=p;B=w+(ca(u,p)|0)|0;C=s+(ca(t,p)|0)|0;while(1){if((A|0)<=0){break}D=C+x|0;nrc(B|0,D|0,v)|0;A=A-1|0;B=B+y|0;C=D}nrc(B|0,C+z|0,v)|0}else{y=-(t<<1)|0;A=1;x=w;D=s;E=r;while(1){if((A|0)<(c[E+72>>2]|0)){F=D+t|0;nrc(x|0,F|0,v)|0;G=F}else{nrc(x|0,D+y|0,v)|0;G=D+t|0}if((A|0)>=(k|0)){break b}A=A+1|0;x=x+u|0;D=G;E=c[e>>2]|0}}}while(0);u=q+1|0;if((u|0)>=4){break a}q=u;r=c[e>>2]|0}}else{r=0;q=m;while(1){if((c[q+(r<<2)>>2]|0)==0){break a}if((c[q+32+(r<<2)>>2]|0)==0){break a}u=r+1|0;if((u|0)>=4){break a}r=u;q=c[e>>2]|0}}}while(0);c[l+300>>2]=c[j>>2];if((c[e>>2]|0)!=(l|0)){VHb(e)}n=lj(g,l)|0;i=d;return n|0}}while(0);KIb(f,40,2115776,(f=i,i=i+8|0,c[f>>2]=(h|0)!=0?2633616:2609912,f)|0);i=f;n=lj(g,c[e>>2]|0)|0;i=d;return n|0}function Ho(a){a=a|0;return pIb((c[(c[a+8>>2]|0)+44>>2]|0)+8|0,c[a+52>>2]|0,c[a+20>>2]|0)|0}function Io(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+40|0;e=d|0;f=d+32|0;g=c[b+44>>2]|0;h=c[g+4>>2]|0;if((h|0)==0){j=-22;i=d;return j|0}k=e|0;l=b;b=g+8|0;g=h;while(1){h=_b(g|0,124)|0;m=(h|0)!=0;if(m){n=h-g|0}else{n=lrc(g|0)|0}if((n|0)>31){o=7;break}nrc(k|0,g|0,n)|0;a[e+n|0]=0;p=gl(f,k,l)|0;if((p|0)<0){j=p;o=10;break}c[b+(c[f>>2]<<2)>>2]=1;p=m?h+1|0:0;if((p|0)==0){j=0;o=10;break}else{g=p}}if((o|0)==7){KIb(l,16,2165200,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=-1;i=d;return j|0}else if((o|0)==10){i=d;return j|0}return 0}function Jo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=0;f=0;while(1){if((c[e+8+(f<<2)>>2]|0)==1){if((Qk(d,f,(f|0)<0|0?-1:0)|0)<0){g=4;break}}h=f+1|0;if((h|0)<333){f=h}else{g=6;break}}if((g|0)==4){Zk(d);j=0;dl(a,j);i=b;return 0}else if((g|0)==6){j=c[d>>2]|0;dl(a,j);i=b;return 0}return 0}function Ko(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=0;f=0;while(1){if((c[e+8+(f<<2)>>2]|0)==0){if((Qk(d,f,(f|0)<0|0?-1:0)|0)<0){g=4;break}}h=f+1|0;if((h|0)<333){f=h}else{g=6;break}}if((g|0)==4){Zk(d);j=0;dl(a,j);i=b;return 0}else if((g|0)==6){j=c[d>>2]|0;dl(a,j);i=b;return 0}return 0}function Lo(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+44>>2]|0;e=dHb(8)|0;c[d+4>>2]=e;if((e|0)==0){f=-12;i=b;return f|0}e=d+8|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=c[d+28>>2]|0;KIb(a,40,2348144,(a=i,i=i+16|0,c[a>>2]=c[d+24>>2],c[a+8>>2]=e,a)|0);i=a;f=0;i=b;return f|0}function Mo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;f=e+4|0;g=c[f>>2]|0;if((g|0)==0){h=e+48|0}else{j=(fHb(g)|0)>>>2;g=e+48|0;c[g>>2]=(c[g>>2]|0)+j;j=c[f>>2]|0;k=d;if((fHb(j)|0)!=0){do{iHb(j,k,4,0)|0;VHb(d);}while((fHb(j)|0)!=0)}eHb(c[f>>2]|0);h=g}g=c[e+40>>2]|0;f=c[h>>2]|0;h=c[e+44>>2]|0;KIb(a,40,2433664,(a=i,i=i+32|0,c[a>>2]=c[e+36>>2],c[a+8>>2]=g,c[a+16>>2]=f,c[a+24>>2]=h,a)|0);i=a;i=b;return}function No(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=f+40|0;h=c[g>>2]|0;j=e+16|0;e=0;k=h;while(1){if((k|0)!=(h|0)){l=e;m=11;break}n=Wi(c[c[j>>2]>>2]|0)|0;if(!((n|0)>-1)){break}e=n;k=c[g>>2]|0}if((m|0)==11){i=b;return l|0}if(!((n|0)==-541478725)){l=n;i=b;return l|0}n=f+4|0;if((fHb(c[n>>2]|0)|0)==0){l=-541478725;i=b;return l|0}if((fHb(c[n>>2]|0)|0)==0){l=0;i=b;return l|0}k=d;e=f+8|0;f=a+56|0;while(1){iHb(c[n>>2]|0,k,4,0)|0;h=XIb(c[e>>2]|0,c[e+4>>2]|0,(c[c[j>>2]>>2]|0)+56|0,f)|0;o=c[g>>2]|0;p=wrc(o,(o|0)<0|0?-1:0,h,G)|0;h=c[d>>2]|0;o=h+136|0;c[o>>2]=p;c[o+4>>2]=G;o=lj(a,h)|0;if((o|0)<0){l=o;m=11;break}c[g>>2]=(c[g>>2]|0)+1;if((fHb(c[n>>2]|0)|0)==0){l=0;m=11;break}}if((m|0)==11){i=b;return l|0}return 0}function Oo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=d+24|0;f=a+56|0;g=c[e>>2]|0;c[f>>2]=c[d+28>>2];c[f+4>>2]=g;g=e;e=a+116|0;f=c[g+4>>2]|0;c[e>>2]=c[g>>2];c[e+4>>2]=f;f=c[c[b+16>>2]>>2]|0;c[a+20>>2]=c[f+20>>2];c[a+24>>2]=c[f+24>>2];return 0}function Po(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0;d=i;i=i+96|0;e=d|0;f=d+8|0;g=d+16|0;j=d+24|0;k=d+32|0;l=d+40|0;m=d+48|0;n=d+56|0;o=d+64|0;p=d+72|0;q=d+80|0;r=d+88|0;c[n>>2]=b;s=c[a+8>>2]|0;t=c[s+44>>2]|0;u=c[c[s+32>>2]>>2]|0;v=t+36|0;c[v>>2]=(c[v>>2]|0)+1;v=t+8|0;w=b+136|0;x=(c[w>>2]|0)==0&(c[w+4>>2]|0)==(-2147483648|0);if((c[v>>2]|0)==0&(c[v+4>>2]|0)==(-2147483648|0)){if(x){KIb(s,24,2438664,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;VHb(n);w=t+48|0;c[w>>2]=(c[w>>2]|0)+1;z=0;i=d;return z|0}w=c[t+4>>2]|0;A=m;c[m>>2]=b;do{if((gHb(w)|0)==0){B=hHb(w,(fHb(w)|0)<<1)|0;if((B|0)==0){C=5;break}VHb(m);if((B|0)<0){z=B}else{break}i=d;return z|0}else{C=5}}while(0);if((C|0)==5){jHb(w,A,4,0)|0}D=+h[t+16>>3];if(!(D!=1.7976931348623157e+308&D!=-9223372036854776000.0)){A=(c[n>>2]|0)+136|0;w=c[A+4>>2]|0;c[v>>2]=c[A>>2];c[v+4>>2]=w;z=0;i=d;return z|0}E=D*1.0e6;D=E>-9223372036854776000.0?E:-9223372036854776000.0;if(D>9223372036854776000.0){H=2147483647;I=-1}else{H=(F=+D,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);I=~~+D>>>0}c[o>>2]=1;c[o+4>>2]=1e6;w=XIb(I,H,o,a+56|0)|0;o=G;c[v>>2]=w;c[v+4>>2]=o;c[p>>2]=1;c[p+4>>2]=1e6;A=XIb(I,H,p,u+56|0)|0;p=G;KIb(s,40,2455808,(y=i,i=i+32|0,c[y>>2]=w,c[y+8>>2]=o,c[y+16>>2]=A,c[y+24>>2]=p,y)|0);i=y;z=0;i=d;return z|0}p=t+4|0;do{if(x){J=b}else{A=(fHb(c[p>>2]|0)|0)<1;o=c[n>>2]|0;if(A){J=o;break}A=o+136|0;o=xrc(c[A>>2]|0,c[A+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;A=a+56|0;w=u+56|0;H=WIb(o,G,A,w,c[t+32>>2]|0)|0;o=t+40|0;I=c[o>>2]|0;m=xrc(H,G,I,(I|0)<0|0?-1:0)|0;I=G;H=0;B=c[p>>2]|0;if((I|0)<(H|0)|(I|0)==(H|0)&m>>>0<1>>>0){H=(fHb(B)|0)>>>2;KIb(s,48,2427800,(y=i,i=i+8|0,c[y>>2]=H,y)|0);i=y;K=t+48|0;c[K>>2]=(c[K>>2]|0)+H;iHb(c[p>>2]|0,q,4,0)|0;H=c[p>>2]|0;K=k;if((fHb(H)|0)!=0){do{iHb(H,K,4,0)|0;VHb(k);}while((fHb(H)|0)!=0)}H=c[p>>2]|0;K=j;c[j>>2]=c[q>>2];do{if((gHb(H)|0)==0){L=hHb(H,(fHb(H)|0)<<1)|0;if((L|0)==0){C=26;break}VHb(j);M=L}else{C=26}}while(0);if((C|0)==26){jHb(H,K,4,0)|0;M=0}VHb(n);z=M;i=d;return z|0}L=r;N=wrc(m,I,-1,-1)|0;O=G;P=s;S=g;T=t+44|0;U=0;V=0;W=0;X=B;a:while(1){iHb(X,L,4,0)|0;if((fHb(c[p>>2]|0)|0)==0&((V|0)<(O|0)|(V|0)==(O|0)&W>>>0<N>>>0)){Y=$Hb(c[r>>2]|0)|0;KIb(P,48,2417552,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;if((Y|0)==0){Z=-12;C=34;break}_=c[p>>2]|0;c[g>>2]=Y;do{if((gHb(_)|0)==0){Y=hHb(_,(fHb(_)|0)<<1)|0;if((Y|0)==0){C=32;break}VHb(g);if((Y|0)<0){Z=Y;C=34;break a}}else{C=32}}while(0);if((C|0)==32){C=0;jHb(_,S,4,0)|0}c[T>>2]=(c[T>>2]|0)+1}Y=XIb(c[v>>2]|0,c[v+4>>2]|0,A,w)|0;$=c[o>>2]|0;aa=wrc($,($|0)<0|0?-1:0,Y,G)|0;Y=c[r>>2]|0;$=Y+136|0;c[$>>2]=aa;c[$+4>>2]=G;ca=lj(u,Y)|0;if((ca|0)<0){C=37;break}c[o>>2]=(c[o>>2]|0)+1;Y=U+1|0;$=Y;aa=(Y|0)<0|0?-1:0;da=c[p>>2]|0;if((aa|0)<(I|0)|(aa|0)==(I|0)&$>>>0<m>>>0){U=Y;V=aa;W=$;X=da}else{C=39;break}}if((C|0)==34){VHb(r);VHb(n);z=Z;i=d;return z|0}else if((C|0)==37){VHb(n);z=ca;i=d;return z|0}else if((C|0)==39){X=f;if((fHb(da)|0)!=0){do{iHb(da,X,4,0)|0;VHb(f);}while((fHb(da)|0)!=0)}X=c[p>>2]|0;W=e;c[e>>2]=c[n>>2];do{if((gHb(X)|0)==0){V=hHb(X,(fHb(X)|0)<<1)|0;if((V|0)==0){break}VHb(e);z=V;i=d;return z|0}}while(0);jHb(X,W,4,0)|0;z=0;i=d;return z|0}}}while(0);e=c[p>>2]|0;p=l;c[l>>2]=J;do{if((gHb(e)|0)==0){J=hHb(e,(fHb(e)|0)<<1)|0;if((J|0)==0){break}VHb(l);z=J;i=d;return z|0}}while(0);jHb(e,p,4,0)|0;z=0;i=d;return z|0}function Qo(a){a=a|0;var b=0;b=c[a+44>>2]|0;VHb(b+12|0);VHb(b+16|0);return}function Ro(a){a=a|0;dl(a,Ok(1211328)|0);return 0}function So(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=f;h=f+12|0;j=h;k=e+16|0;e=h;do{if((c[e>>2]|0)==0){l=Wi(c[c[k>>2]>>2]|0)|0;if((l|0)<0){m=l}else{n=l;break}i=b;return m|0}else{n=0}}while(0);l=f+16|0;do{if((c[l>>2]|0)==0){o=Wi(c[(c[k>>2]|0)+4>>2]|0)|0;if((o|0)<0){m=o}else{p=o;break}i=b;return m|0}else{p=n}}while(0);n=f+8|0;if((c[n>>2]|0)==3){k=f+24|0;if((c[k>>2]|0)==0&(c[k+4>>2]|0)==(-2147483648|0)){f=(c[h>>2]|0)+136|0;o=c[f+4>>2]|0;c[k>>2]=c[f>>2];c[k+4>>2]=o;q=0;r=p}else{q=0;r=p}while(1){if((q|0)>=2){m=r;s=20;break}p=c[k>>2]|0;o=c[k+4>>2]|0;f=wrc(p,o,1,0)|0;c[k>>2]=f;c[k+4>>2]=G;f=j+(q<<2)|0;t=c[f>>2]|0;u=t+136|0;c[u>>2]=p;c[u+4>>2]=o;o=iLb(t)|0;if((o|0)==0){m=-12;s=20;break}c[o>>2]=c[n>>2];o=lj(a,c[f>>2]|0)|0;c[f>>2]=0;if((o|0)<0){m=o;s=20;break}else{q=q+1|0;r=o}}if((s|0)==20){i=b;return m|0}}s=bv(a,c[a+20>>2]|0,c[a+24>>2]|0)|0;c[d>>2]=s;if((s|0)==0){m=-12;i=b;return m|0}r=c[n>>2]|0;if((r|0)==6){Vo(g,s,1)}else if((r|0)==1){Uo(g,s,0)}else if((r|0)==2){Vo(g,s,0)}else if((r|0)==7){Uo(g,s,1)}s=ZHb(c[d>>2]|0,c[h>>2]|0)|0;if((s|0)<0){VHb(d);m=s;i=b;return m|0}VHb(e);VHb(l);l=iLb(c[d>>2]|0)|0;if((l|0)==0){VHb(d);m=-12;i=b;return m|0}else{c[l>>2]=c[n>>2];m=lj(a,c[d>>2]|0)|0;i=b;return m|0}return 0}function To(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=c[d+16>>2]|0;g=c[f>>2]|0;h=c[g+20>>2]|0;j=c[g+24>>2]|0;k=g+56|0;g=c[k>>2]|0;l=c[k+4>>2]|0;k=g;m=l;n=m;o=c[f+4>>2]|0;f=c[o+20>>2]|0;p=c[o+24>>2]|0;if(!((h|0)==(f|0)&(j|0)==(p|0))){KIb(d,16,2527480,(q=i,i=i+32|0,c[q>>2]=h,c[q+8>>2]=j,c[q+16>>2]=f,c[q+24>>2]=p,q)|0);i=q;r=-1094995529;i=b;return r|0}p=c[o+56>>2]|0;f=c[o+60>>2]|0;o=Erc(f,(f|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;s=G;t=Erc(p,(p|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;do{if((o|0)==(t|0)&(s|0)==(G|0)){if((f|0)==0|(n|0)==0){if((k|0)==0|(p|0)==0){break}if((k>>31|0)!=(p>>31|0)){break}}u=qKb(c[a+52>>2]|0)|0;c[e+4>>2]=u;if((u|0)==0){r=-558323010;i=b;return r|0}switch(c[e+8>>2]|0){case 3:{u=e+24|0;c[u>>2]=0;c[u+4>>2]=-2147483648;v=j;w=h;x=m<<1|0>>>31;break};case 6:case 2:{v=j<<1;w=h;x=n;break};case 7:case 1:{v=j;w=h<<1;x=n;break};default:{KIb(d,16,2498872,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=b;return r|0}}c[a+20>>2]=w;c[a+24>>2]=v;u=a+56|0;c[u>>2]=g|0;c[u+4>>2]=x|l&0;r=0;i=b;return r|0}}while(0);KIb(d,16,2512312,(q=i,i=i+32|0,c[q>>2]=k,c[q+8>>2]=n,c[q+16>>2]=p,c[q+24>>2]=f,q)|0);i=q;r=-1094995529;i=b;return r|0}function Uo(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=e+68|0;h=e+72|0;i=b+4|0;j=c[i>>2]|0;if((a[j+4|0]|0)==0){return}k=b+12|0;l=b+16|0;b=(f|0)==0;f=0;m=(c[g>>2]|0)/2|0;n=c[h>>2]|0;o=j;while(1){j=c[k>>2]|0;p=c[j+(f<<2)>>2]|0;q=c[(c[l>>2]|0)+(f<<2)>>2]|0;r=e+(f<<2)|0;s=c[r>>2]|0;if((f-1|0)>>>0<2>>>0){t=-(-(c[h>>2]|0)>>d[o+6|0])|0;u=-(((c[g>>2]|0)/-2|0)>>d[o+5|0])|0}else{t=n;u=m}do{if(b){v=e+32+(f<<2)|0;uIb(s,c[v>>2]|0,p,c[j+32+(f<<2)>>2]|0,u,t);uIb((c[r>>2]|0)+u|0,c[v>>2]|0,q,c[(c[l>>2]|0)+32+(f<<2)>>2]|0,u,t)}else{if((t|0)<=0){break}v=e+32+(f<<2)|0;if((u|0)>0){w=0;x=p;y=q;z=s}else{break}while(1){A=0;B=0;while(1){a[z+B|0]=a[x+A|0]|0;a[z+(B|1)|0]=a[y+A|0]|0;C=A+1|0;if((C|0)<(u|0)){A=C;B=B+2|0}else{break}}B=w+1|0;if((B|0)<(t|0)){w=B;x=x+(c[(c[k>>2]|0)+32+(f<<2)>>2]|0)|0;y=y+(c[(c[l>>2]|0)+32+(f<<2)>>2]|0)|0;z=z+(c[v>>2]|0)|0}else{break}}}}while(0);s=f+1|0;q=c[i>>2]|0;if((s|0)<(d[q+4|0]|0)){f=s;m=u;n=t;o=q}else{break}}return}function Vo(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=e+68|0;h=c[g>>2]|0;i=e+72|0;j=(c[i>>2]|0)/2|0;k=b+4|0;l=c[k>>2]|0;if((a[l+4|0]|0)==0){return}m=b+12|0;n=b+16|0;if((f|0)==0){b=0;o=h;p=j;q=l;while(1){if((b-1|0)>>>0<2>>>0){r=-(((c[i>>2]|0)/-2|0)>>d[q+6|0])|0;s=-(-(c[g>>2]|0)>>d[q+5|0])|0}else{r=p;s=o}t=e+32+(b<<2)|0;u=c[t>>2]|0;v=ca(u,r)|0;w=e+(b<<2)|0;x=c[m>>2]|0;uIb(c[w>>2]|0,u,c[x+(b<<2)>>2]|0,c[x+32+(b<<2)>>2]|0,s,r);x=c[n>>2]|0;uIb((c[w>>2]|0)+v|0,c[t>>2]|0,c[x+(b<<2)>>2]|0,c[x+32+(b<<2)>>2]|0,s,r);x=b+1|0;t=c[k>>2]|0;if((x|0)<(d[t+4|0]|0)){b=x;o=s;p=r;q=t}else{break}}return}else{q=0;r=h;h=j;j=l;while(1){if((q-1|0)>>>0<2>>>0){y=-(((c[i>>2]|0)/-2|0)>>d[j+6|0])|0;z=-(-(c[g>>2]|0)>>d[j+5|0])|0}else{y=h;z=r}l=e+32+(q<<2)|0;p=c[l>>2]|0;s=e+(q<<2)|0;o=c[m>>2]|0;uIb(c[s>>2]|0,p<<f,c[o+(q<<2)>>2]|0,c[o+32+(q<<2)>>2]|0,z,y);o=c[n>>2]|0;uIb((c[s>>2]|0)+p|0,c[l>>2]<<f,c[o+(q<<2)>>2]|0,c[o+32+(q<<2)>>2]|0,z,y);o=q+1|0;l=c[k>>2]|0;if((o|0)<(d[l+4|0]|0)){q=o;r=z;h=y;j=l}else{break}}return}}function Wo(a,b){a=a|0;b=b|0;c[(c[(c[a+8>>2]|0)+44>>2]|0)+12>>2]=b;return 0}function Xo(a,b){a=a|0;b=b|0;c[(c[(c[a+8>>2]|0)+44>>2]|0)+16>>2]=b;return 0}function Yo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a>>2]|0;g=c[f+44>>2]|0;j=c[c[f+16>>2]>>2]|0;k=a+156|0;c[k>>2]=c[k>>2]|1;k=j+116|0;l=g+4|0;c[d>>2]=c[l>>2];c[d+4>>2]=1;zKb(e,k,d);d=a+116|0;a=c[e>>2]|0;g=c[e+4>>2]|0;c[d>>2]=a;c[d+4>>2]=g;d=c[k>>2]|0;k=c[j+120>>2]|0;j=a;a=g;KIb(f,40,2236784,(f=i,i=i+56|0,c[f>>2]=c[l>>2],c[f+8>>2]=d,c[f+16>>2]=k,h[f+24>>3]=+(d|0)/+(k|0),c[f+32>>2]=j,c[f+40>>2]=a,h[f+48>>3]=+(j|0)/+(a|0),f)|0);i=f;i=b;return 0}function Zo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=a+160|0;a=c[(c[f+44>>2]|0)+4>>2]|0;h=Drc(c[g>>2]|0,c[g+4>>2]|0,a,(a|0)<0|0?-1:0)|0;if((h|0)==0&(G|0)==0){j=lj(c[c[f+32>>2]>>2]|0,b)|0;i=d;return j|0}else{VHb(e);j=0;i=d;return j|0}return 0}function _o(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+24|0;d=b|0;e=c[a+44>>2]|0;f=e+20|0;g=f;h=f;f=c[h>>2]|0;j=(f|0)==0;do{if(j){if((c[e+36>>2]|0)==0){do{if((c[e+40>>2]|0)==0){if((c[e+44>>2]|0)!=0){break}KIb(a,16,2433328,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-22;i=b;return l|0}}while(0);m=e+64|0;c[m>>2]=j&1;if(j){n=m}else{o=m;p=12;break}}else{m=e+64|0;c[m>>2]=j&1;n=m}if((c[e+24>>2]|0)!=0){o=n;p=12;break}if((c[e+28>>2]|0)!=0){o=n;p=12;break}q=n;r=e+24|0;p=18}else{m=e+64|0;c[m>>2]=j&1;o=m;p=12}}while(0);a:do{if((p|0)==12){do{if((c[e+36>>2]|0)==0){if((c[e+40>>2]|0)!=0){break}if((c[e+44>>2]|0)!=0){break}j=c[e+24>>2]|0;n=e+24|0;if((j|0)==0){q=o;r=n;p=18;break a}s=j;t=e+28|0;u=o;v=n;p=21;break a}}while(0);KIb(a,16,2347904,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-22;i=b;return l|0}}while(0);do{if((p|0)==18){k=e+28|0;o=c[k>>2]|0;if((o|0)==0){c[r>>2]=rJb(f)|0;c[k>>2]=rJb(c[h>>2]|0)|0;w=q;x=r;break}else{n=rJb(o)|0;c[r>>2]=n;s=n;t=k;u=q;v=r;p=21;break}}}while(0);do{if((p|0)==21){if((c[t>>2]|0)!=0){w=u;x=v;break}c[t>>2]=rJb(s)|0;w=u;x=v}}while(0);v=e+32|0;if((c[v>>2]|0)==0){c[v>>2]=rJb(2286664)|0}u=e+36|0;if((c[u>>2]|0)==0){c[u>>2]=rJb(2236776)|0}s=e+40|0;if((c[s>>2]|0)==0){c[s>>2]=rJb(2196592)|0}t=e+44|0;r=c[t>>2]|0;if((r|0)==0){q=rJb(2164912)|0;c[t>>2]=q;y=q}else{y=r}do{if((c[w>>2]|0)==0){if((c[x>>2]|0)==0){l=-12;i=b;return l|0}if((c[e+28>>2]|0)==0){l=-12;i=b;return l|0}if((c[v>>2]|0)==0){l=-12}else{break}i=b;return l|0}else{if((c[u>>2]|0)==0){l=-12;i=b;return l|0}if((c[s>>2]|0)==0|(y|0)==0){l=-12}else{break}i=b;return l|0}}while(0);y=d|0;s=d+4|0;u=d+8|0;v=d+12|0;x=d+16|0;r=d+20|0;d=e+4|0;e=a;a=0;q=0;while(1){if((a|0)>=4){l=q;p=42;break}t=c[w>>2]|0;c[y>>2]=6;c[s>>2]=4;c[u>>2]=8;c[v>>2]=2;c[x>>2]=c[1150200+(a<<2)>>2];c[r>>2]=0;if((a|0)<3){z=(t|0)==0?a:a+4|0}else{z=3}h=UGb(d+(a<<2)|0,c[g+(z<<2)>>2]|0,281576,0,0,(t|0)!=0?1150240:1150216,y,0,e)|0;if((h|0)<0){l=h;p=42;break}else{a=a+1|0;q=h}}if((p|0)==42){i=b;return l|0}return 0}function $o(a){a=a|0;var b=0;b=c[a+44>>2]|0;TGb(c[b+4>>2]|0);TGb(c[b+8>>2]|0);TGb(c[b+12>>2]|0);TGb(c[b+16>>2]|0);return}function ap(a){a=a|0;if((c[(c[a+44>>2]|0)+64>>2]|0)==0){dl(a,Ok(1149176)|0);return 0}else{dl(a,Ok(1149224)|0);return 0}return 0}function bp(a,b,c){a=a|0;b=+b;c=+c;return+(+fp(a,b,c,0))}function cp(a,b,c){a=a|0;b=+b;c=+c;return+(+fp(a,b,c,1))}function dp(a,b,c){a=a|0;b=+b;c=+c;return+(+fp(a,b,c,2))}function ep(a,b,c){a=a|0;b=+b;c=+c;return+(+fp(a,b,c,3))}function fp(a,b,e,f){a=a|0;b=+b;e=+e;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0.0;g=c[a+48>>2]|0;h=c[g+(f<<2)>>2]|0;i=c[g+32+(f<<2)>>2]|0;j=c[g+68>>2]|0;if((f-1|0)>>>0<2>>>0){k=-(-(c[g+72>>2]|0)>>c[a+56>>2])|0;l=-(-j>>c[a+52>>2])|0}else{k=c[g+72>>2]|0;l=j}if((h|0)==0){m=0.0;return+m}n=b;b=+(l-2|0);if(n<0.0){o=0.0}else{o=n>b?b:n}l=~~o;n=e;e=+(k-2|0);if(n<0.0){p=0.0}else{p=n>e?e:n}k=~~p;n=o- +(l|0);o=p- +(k|0);p=1.0-n;j=ca(k,i)|0;g=l+1|0;a=ca(k+1|0,i)|0;m=(1.0-o)*(p*+(d[h+(j+l)|0]|0|0)+n*+(d[h+(j+g)|0]|0|0))+o*(p*+(d[h+(a+l)|0]|0|0)+n*+(d[h+(a+g)|0]|0|0));return+m}function gp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0;e=i;i=i+72|0;f=e|0;g=e+8|0;c[f>>2]=d;j=c[b+8>>2]|0;k=c[j+44>>2]|0;l=c[c[j+32>>2]>>2]|0;mrc(g|0,0,64)|0;j=g|0;m=b+160|0;h[g+32>>3]=+((c[m>>2]|0)>>>0)+ +(c[m+4>>2]|0)*4294967296.0;m=d+136|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((n|0)==0&(o|0)==(-2147483648|0)){p=+r}else{p=(+(n>>>0)+ +(o|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0))}h[g+56>>3]=p;o=k+48|0;c[o>>2]=d;d=bv(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((d|0)==0){VHb(f);q=-12;i=e;return q|0}ZHb(d,c[f>>2]|0)|0;f=k+60|0;n=c[f>>2]|0;a:do{if((n|0)>0){m=b+20|0;s=k+52|0;t=b+24|0;u=k+56|0;v=g+16|0;w=g+24|0;x=g+40|0;y=g+48|0;z=g+8|0;A=k+4|0;B=0;C=n;while(1){D=c[d+(B<<2)>>2]|0;if((D|0)==0){break a}E=c[d+32+(B<<2)>>2]|0;F=c[m>>2]|0;if((B-1|0)>>>0<2>>>0){G=c[t>>2]|0;H=-(-G>>c[u>>2])|0;I=-(-F>>c[s>>2])|0;J=G}else{G=c[t>>2]|0;H=G;I=F;J=G}p=+(I|0);h[v>>3]=p;K=+(H|0);h[w>>3]=K;h[x>>3]=p/+(F|0);h[y>>3]=K/+(J|0);b:do{if((H|0)>0){F=A+(B<<2)|0;if((I|0)>0){L=0;M=D}else{G=0;while(1){h[z>>3]=+(G|0);N=G+1|0;if((N|0)<(H|0)){G=N}else{O=C;break b}}}while(1){h[z>>3]=+(L|0);G=0;do{h[j>>3]=+(G|0);a[M+G|0]=~~+XGb(c[F>>2]|0,j,k);G=G+1|0;}while((G|0)<(I|0));G=L+1|0;if((G|0)<(H|0)){L=G;M=M+E|0}else{break}}O=c[f>>2]|0}else{O=C}}while(0);E=B+1|0;if((E|0)<(O|0)){B=E;C=O}else{break}}}}while(0);VHb(o);q=lj(l,d)|0;i=e;return q|0}function hp(a){a=a|0;var b=0,e=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;c[b+52>>2]=d[e+5|0]|0;c[b+56>>2]=d[e+6|0]|0;c[b+60>>2]=d[e+4|0]|0;return 0}function ip(b,c,f,g,h,i){b=b|0;c=c|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((g|0)>0){j=0;k=f}else{return}do{f=(d[c+j|0]|0)<<7;l=(e[k>>1]|0)-f|0;m=127-((ca((l|0)>-1?l:-l|0,h)|0)>>16)|0;n=(m|0)<0?0:m;m=(ca(ca(n,l)|0,n)|0)>>14;n=(e[i+((j&7)<<1)>>1]|0)+f+m>>7;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[b+j|0]=o;k=k+((j&1)<<1)|0;j=j+1|0;}while((j|0)<(g|0));return}function jp(a,c,f,g,h,i){a=a|0;c=c|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((i|0)>0){j=0}else{return}do{k=j<<1;l=k|1;m=(d[g+k|0]|0)+(e[f+(j<<1)>>1]|0)+(d[g+l|0]|0)+(d[g+(k+h)|0]|0)+(d[g+(l+h)|0]|0)|0;l=c+(j<<1)|0;k=e[l>>1]|0;b[l>>1]=m;b[a+(j<<1)>>1]=m-k;j=j+1|0;}while((j|0)<(i|0));return}function kp(a){a=a|0;var b=0,d=0,e=0.0,f=0,j=0,k=0;b=i;d=c[a+44>>2]|0;e=+g[d+4>>2];c[d+8>>2]=~~(32768.0/e);f=d+12|0;j=(c[f>>2]|0)+1&-2;if((j|0)<4){k=4}else{k=(j|0)>32?32:j}c[f>>2]=k;c[d+36>>2]=322;c[d+32>>2]=20;KIb(a,40,2432936,(a=i,i=i+16|0,h[a>>3]=e,c[a+8>>2]=k,a)|0);i=a;i=b;return 0}function lp(a){a=a|0;mJb((c[a+44>>2]|0)+28|0);return}function mp(a){a=a|0;dl(a,Ok(685776)|0);return 0}function np(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+8|0;g=f|0;c[g>>2]=d;h=c[a+8>>2]|0;j=c[h+44>>2]|0;k=c[c[h+32>>2]>>2]|0;do{if((bIb(d)|0)==0){h=bv(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((h|0)!=0){ZHb(h,c[g>>2]|0)|0;l=0;m=h;break}VHb(g);n=-12;i=f;return n|0}else{l=1;m=d}}while(0);d=a+20|0;h=a+24|0;a=j+12|0;o=j+28|0;p=j+8|0;q=j+36|0;r=j+32|0;s=j+16|0;t=j+20|0;u=j+24|0;j=0;do{v=c[g>>2]|0;w=c[v+(j<<2)>>2]|0;if((w|0)==0){break}x=c[v+32+(j<<2)>>2]|0;if((x|0)==0){break}v=(j|0)==0;y=c[(v?a:u)>>2]|0;z=c[(v?h:t)>>2]|0;A=c[(v?d:s)>>2]|0;v=c[m+(j<<2)>>2]|0;a:do{if((((A|0)>(z|0)?z:A)|0)>(y<<1|0)){B=c[m+32+(j<<2)>>2]|0;C=(A+15&-16|0)/2|0;D=2097152/((ca(y,y)|0)>>>0)|0;E=c[o>>2]|0;F=E+32|0;G=C+32|0;H=c[p>>2]|0;mrc(F|0,0,(C<<1)+32|0)|0;I=(y|0)>0;if(I){J=x<<1;K=(A|0)/2|0;L=0;while(1){M=E+((ca(L,C)|0)+G<<1)|0;N=E+((ca(L-1|0,C)|0)+G<<1)|0;O=w+(ca(J,L)|0)|0;_e[c[q>>2]&511](F,M,N,O,x,K);O=L+1|0;if((O|0)<(y|0)){L=O}else{P=y;Q=K;break}}}else{P=0;Q=(A|0)/2|0}K=z-y|0;L=(y+1+A|0)/2|0;J=(y|0)/-2|0;O=(y|0)>1;N=16-y|0;M=E+(J+16<<1)|0;R=I^1;S=P;do{do{if((S|0)<(K|0)){T=S+y|0;U=((T|0)/2|0|0)%(y|0)|0;V=E+((ca(U,C)|0)+G<<1)|0;W=E+((ca(((U|0)!=0?U:y)-1|0,C)|0)+G<<1)|0;U=w+(ca(T,x)|0)|0;_e[c[q>>2]&511](F,V,W,U,x,Q);if(I){U=0;W=0;while(1){V=(e[E+(U+16<<1)>>1]|0)+W|0;T=U+1|0;if((T|0)<(y|0)){U=T;W=V}else{X=y;Y=V;break}}}else{X=0;Y=0}if((X|0)<(Q|0)){W=X;U=Y;while(1){V=E+(W+N<<1)|0;T=(e[E+(W+16<<1)>>1]|0)-(e[V>>1]|0)+U|0;b[V>>1]=(ca(T,D)|0)>>>16;V=W+1|0;if((V|0)<(Q|0)){W=V;U=T}else{Z=Q;_=T;break}}}else{Z=X;_=Y}if((Z|0)<(L|0)){U=(ca(_,D)|0)>>>16&65535;W=Z;do{b[E+(W+N<<1)>>1]=U;W=W+1|0;}while((W|0)<(L|0))}if(O){$=J}else{break}do{b[E+($+16<<1)>>1]=b[F>>1]|0;$=$+1|0;}while(($|0)<0)}}while(0);W=(S|0)!=(y|0);if(W|R){aa=W?S:0}else{W=0;while(1){U=v+(ca(W,B)|0)|0;T=w+(ca(W,x)|0)|0;_e[c[r>>2]&511](U,T,M,A,H,1532304+((W&7)<<4)|0);T=W+1|0;if((T|0)<(y|0)){W=T}else{aa=y;break}}}W=v+(ca(aa,B)|0)|0;T=w+(ca(aa,x)|0)|0;_e[c[r>>2]&511](W,T,M,A,H,1532304+((aa&7)<<4)|0);T=aa+1|0;if((T|0)>=(z|0)){break a}W=v+(ca(T,B)|0)|0;U=w+(ca(T,x)|0)|0;_e[c[r>>2]&511](W,U,M,A,H,1532304+((T&7)<<4)|0);S=aa+2|0;}while((S|0)<(z|0))}else{if((v|0)==(w|0)){break}uIb(v,c[m+32+(j<<2)>>2]|0,w,x,A,z)}}while(0);j=j+1|0;}while((j|0)<4);if((l|0)==0){VHb(g)}n=lj(k,m)|0;i=f;return n|0}function op(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;f=d[e+5|0]|0;g=d[e+6|0]|0;e=b+28|0;mJb(e);h=a+20|0;i=b+12|0;j=qJb(((ca((c[h>>2]|0)+15&-16,(c[i>>2]|0)+1|0)|0)/2|0)+32|0,2)|0;c[e>>2]=j;if((j|0)==0){k=-12;return k|0}c[b+16>>2]=-(-(c[h>>2]|0)>>f);c[b+20>>2]=-(-(c[a+24>>2]|0)>>g);a=c[i>>2]|0;i=(((a>>f)+(a>>g)|0)/2|0)+1&-2;if((i|0)<4){l=4}else{l=(i|0)>32?32:i}c[b+24>>2]=l;k=0;return k|0}function pp(d){d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;g=0;do{h=qKb(g)|0;do{if((a[h+7|0]&12)==0){if((a[h+5|0]|0)!=(a[h+6|0]|0)){if(((b[h+10>>1]^b[h+8>>1])&3)==0){break}}Qk(f,g,(g|0)<0|0?-1:0)|0}}while(0);g=g+1|0;}while((g|0)<333);dl(d,c[f>>2]|0);i=e;return 0}function qp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e|0;g=e+8|0;c[f>>2]=d;h=c[b+8>>2]|0;j=c[c[h+32>>2]>>2]|0;k=j+24|0;l=bv(j,c[j+20>>2]|0,c[k>>2]|0)|0;if((l|0)==0){VHb(f);m=-12;i=e;return m|0}ZHb(l,d)|0;if((a[(qKb(c[b+52>>2]|0)|0)+7|0]&2)==0){n=c[f>>2]|0}else{b=c[f>>2]|0;nrc(c[l+4>>2]|0,c[b+4>>2]|0,1024)|0;n=b}c[g>>2]=n;c[g+4>>2]=l;n=c[k>>2]|0;k=c[(c[h+48>>2]|0)+28>>2]|0;Xe[c[c[h+56>>2]>>2]&511](h,558,g,0,(n|0)>(k|0)?k:n)|0;VHb(f);m=lj(j,l)|0;i=e;return m|0}function rp(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;f=d[e+5|0]|0;g=d[e+6|0]|0;nIb(b,0,e);e=a+20|0;h=c[e>>2]|0;c[b+28>>2]=h;c[b+16>>2]=h;h=-(-(c[e>>2]|0)>>f)|0;c[b+24>>2]=h;c[b+20>>2]=h;h=a+24|0;a=c[h>>2]|0;c[b+44>>2]=a;c[b+32>>2]=a;a=-(-(c[h>>2]|0)>>g)|0;c[b+40>>2]=a;c[b+36>>2]=a;return 0}function sp(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=c[d+44>>2]|0;d=c[e>>2]|0;i=c[e+4>>2]|0;e=h+16|0;j=h+32|0;k=f+1|0;l=h;h=0;while(1){m=c[d+(h<<2)>>2]|0;if((m|0)==0){n=20;break}o=d+32+(h<<2)|0;p=c[o>>2]|0;if((p|0)==0){n=20;break}q=c[e+(h<<2)>>2]|0;r=c[j+(h<<2)>>2]|0;s=(ca(r,f)|0)/(g|0)|0;t=(ca(r,k)|0)/(g|0)|0;r=c[l+(h<<2)>>2]|0;u=i+32+(h<<2)|0;v=(c[i+(h<<2)>>2]|0)+(ca(c[u>>2]|0,s)|0)|0;w=m+((ca(r,q-1|0)|0)+(ca(s,p)|0))|0;a:do{if((s|0)<(t|0)){p=(q|0)>0;if((r|0)==1){m=s;x=v;y=w;while(1){if(p){z=0;do{a[x+z|0]=a[y+(-z|0)|0]|0;z=z+1|0;}while((z|0)<(q|0))}z=m+1|0;if((z|0)<(t|0)){m=z;x=x+(c[u>>2]|0)|0;y=y+(c[o>>2]|0)|0}else{break a}}}else{A=s;B=v;C=w}while(1){do{if((r|0)==2){y=B;x=C;if(p){D=0}else{break}do{b[y+(D<<1)>>1]=b[x+(-D<<1)>>1]|0;D=D+1|0;}while((D|0)<(q|0))}else if((r|0)==4){x=B;y=C;if(p){E=0}else{break}do{c[x+(E<<2)>>2]=c[y+(-E<<2)>>2];E=E+1|0;}while((E|0)<(q|0))}else if((r|0)==3){if(p){F=0;G=C;H=B}else{break}while(1){y=a[G]|0;x=a[G+1|0]|0;a[H+2|0]=a[G+2|0]|0;a[H+1|0]=x;a[H]=y;y=F+1|0;if((y|0)<(q|0)){F=y;G=G-3|0;H=H+3|0}else{break}}}else{if(p){I=0}else{break}do{y=ca(I,r)|0;nrc(B+y|0,C+(-y|0)|0,r)|0;I=I+1|0;}while((I|0)<(q|0))}}while(0);y=A+1|0;if((y|0)<(t|0)){A=y;B=B+(c[u>>2]|0)|0;C=C+(c[o>>2]|0)|0}else{break}}}}while(0);o=h+1|0;if((o|0)<4){h=o}else{n=20;break}}if((n|0)==20){return 0}return 0}function tp(a){a=a|0;var b=0,d=0,e=0.0,f=0;b=i;d=c[a+44>>2]|0;e=+g[d+8>>2];f=c[d+12>>2]|0;KIb(a,40,2432752,(a=i,i=i+24|0,h[a>>3]=+g[d+4>>2],h[a+8>>3]=e,c[a+16>>2]=f,a)|0);i=a;i=b;return 0}function up(a){a=a|0;dl(a,Ok(685744)|0);return 0}function vp(b,e){b=b|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;f=i;i=i+8|0;h=f|0;c[h>>2]=e;j=c[b+8>>2]|0;k=c[j+44>>2]|0;l=c[c[j+32>>2]>>2]|0;j=~~(+g[k+4>>2]*1.0e3);m=~~(+g[k+8>>2]*1.0e3);n=bv(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((n|0)==0){VHb(h);o=-12;i=f;return o|0}ZHb(n,e)|0;e=k+16|0;p=e;mrc(e|0,0,1024)|0;q=n|0;r=b+24|0;s=c[r>>2]|0;if((s|0)>0){t=c[h>>2]|0;u=b+20|0;v=k+3092|0;w=n+32|0;x=k+3088|0;y=k+3089|0;z=k+3090|0;A=k+3091|0;B=0;C=c[t>>2]|0;D=c[q>>2]|0;E=c[u>>2]|0;F=c[v>>2]|0;G=t;t=s;while(1){if((ca(F,E)|0)>0){s=0;do{H=(((d[C+((d[y]|0)+s)|0]|0)*182|0)+((d[C+((d[x]|0)+s)|0]|0)*55|0)+((d[C+((d[z]|0)+s)|0]|0)*19|0)|0)>>>8;a[D+((d[A]|0)+s)|0]=H;I=p+(H<<2)|0;c[I>>2]=(c[I>>2]|0)+1;J=c[v>>2]|0;s=J+s|0;K=c[u>>2]|0;}while((s|0)<(ca(J,K)|0));L=K;M=J;N=c[h>>2]|0;O=c[r>>2]|0}else{L=E;M=F;N=G;O=t}s=B+1|0;if((s|0)<(O|0)){B=s;C=C+(c[N+32>>2]|0)|0;D=D+(c[w>>2]|0)|0;E=L;F=M;G=N;t=O}else{break}}P=c[e>>2]|0}else{P=0}e=k+2064|0;O=e;c[e>>2]=P;e=1;t=P;do{t=(c[p+(e<<2)>>2]|0)+t|0;c[O+(e<<2)>>2]=t;e=e+1|0;}while((e|0)<256);e=b+20|0;b=0;do{t=O+(b<<2)|0;p=ca(c[t>>2]|0,m)|0;c[t>>2]=(p|0)/(ca(c[e>>2]|0,c[r>>2]|0)|0)|0;b=b+1|0;}while((b|0)<256);b=255-j|0;m=0;do{p=O+(m<<2)|0;c[p>>2]=((ca(m,b)|0)/255|0)+((ca(c[p>>2]|0,j)|0)/255|0);m=m+1|0;}while((m|0)<256);m=k+1040|0;j=m;mrc(m|0,0,1024)|0;b=c[r>>2]|0;if((b|0)>0){p=c[h>>2]|0;t=k+3092|0;P=n+32|0;N=k+3088|0;G=k+3091|0;M=k+12|0;F=k+3089|0;L=k+3090|0;k=m;m=0;E=739187;w=c[p>>2]|0;D=c[q>>2]|0;q=c[e>>2]|0;C=c[t>>2]|0;B=p;p=b;while(1){if((ca(C,q)|0)>0){b=0;J=E;K=C;while(1){u=a[D+((d[G]|0)+b)|0]|0;v=u&255;if(u<<24>>24==0){if((K|0)>0){A=0;while(1){a[D+(A+b)|0]=0;z=A+1|0;x=c[t>>2]|0;if((z|0)<(x|0)){A=z}else{Q=x;break}}}else{Q=K}c[k>>2]=(c[k>>2]|0)+1;R=J;S=Q}else{A=c[O+(v<<2)>>2]|0;x=c[M>>2]|0;do{if((x|0)==0){T=J;U=A}else{z=(x|0)==1;y=c[O+(v-1<<2)>>2]|0;if(z){V=(y+A|0)/2|0}else{V=y}do{if(u<<24>>24==-1){W=A}else{y=c[O+(v+1<<2)>>2]|0;if(!z){W=y;break}W=(y+A|0)/2|0}}while(0);if((V|0)==(W|0)){T=J;U=A;break}z=(((J<<12)+150889|0)>>>0)%714025|0;T=z;U=(((ca(z,1-V+W|0)|0)>>>0)/714025|0)+V|0}}while(0);A=(d[N]|0)+b|0;u=d[w+A|0]|0;x=d[w+((d[F]|0)+b)|0]|0;z=d[w+((d[L]|0)+b)|0]|0;y=u>>>0>x>>>0?u:x;s=y>>>0>z>>>0?y:z;if(((ca(s,U)|0)/(v|0)|0|0)>255){X=((z*255|0)>>>0)/(s>>>0)|0;Y=((x*255|0)>>>0)/(s>>>0)|0;Z=((u*255|0)>>>0)/(s>>>0)|0}else{X=((ca(z,U)|0)>>>0)/(v>>>0)|0;Y=((ca(x,U)|0)>>>0)/(v>>>0)|0;Z=((ca(u,U)|0)>>>0)/(v>>>0)|0}a[D+A|0]=Z;a[D+((d[F]|0)+b)|0]=Y;a[D+((d[L]|0)+b)|0]=X;A=(Y*182|0)+(Z*55|0)+(X*19|0)|0;u=A>>>8;if(A>>>0>65535>>>0){_=-u>>31&255}else{_=u&255}u=j+((_&255)<<2)|0;c[u>>2]=(c[u>>2]|0)+1;R=T;S=c[t>>2]|0}u=S+b|0;$=c[e>>2]|0;if((u|0)<(ca(S,$)|0)){b=u;J=R;K=S}else{break}}aa=R;ba=$;da=S;ea=c[h>>2]|0;fa=c[r>>2]|0}else{aa=E;ba=q;da=C;ea=B;fa=p}K=m+1|0;if((K|0)<(fa|0)){m=K;E=aa;w=w+(c[ea+32>>2]|0)|0;D=D+(c[P>>2]|0)|0;q=ba;C=da;B=ea;p=fa}else{break}}}VHb(h);o=lj(l,n)|0;i=f;return o|0}function wp(a){a=a|0;var b=0,d=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=a+52|0;c[b+3092>>2]=(oKb(qKb(c[d>>2]|0)|0)|0)/8|0;Kz(b+3088|0,c[d>>2]|0)|0;return 0}function xp(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[(c[a+44>>2]|0)+4>>2]|0;if((d|0)==1){e=156464}else if((d|0)==0){e=1009656}else if((d|0)==2|(d|0)==3){e=1643688}else{KIb(0,0,2432640,(d=i,i=i+24|0,c[d>>2]=2347456,c[d+8>>2]=2286360,c[d+16>>2]=121,d)|0);i=d;Hd();return 0}dl(a,Ok(e)|0);i=b;return 0}function yp(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[(c[a>>2]|0)+44>>2]|0;e=c[d+4>>2]|0;do{if((e|0)==0){c[a+20>>2]=256;f=ca(c[d+1064>>2]|0,c[d+1032>>2]|0)|0;c[a+24>>2]=ca((f|0)>1?f:1,(c[d+1048>>2]|0)+(c[d+1044>>2]|0)|0)|0}else if((e|0)==2|(e|0)==3){c[a+20>>2]=256;c[a+24>>2]=256}else if((e|0)==1){f=ca(c[d+1064>>2]|0,c[d+1032>>2]|0)|0;g=(f|0)>1?f<<8:256;if((c[d+1056>>2]|0)==0){c[a+20>>2]=g;break}else{c[a+24>>2]=g;break}}else{KIb(0,0,2432640,(g=i,i=i+24|0,c[g>>2]=2347456,c[g+8>>2]=2286360,c[g+16>>2]=176,g)|0);i=g;Hd();return 0}}while(0);c[a+28>>2]=1;c[a+32>>2]=1;i=b;return 0}function zp(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;g=i;i=i+8|0;h=g|0;c[h>>2]=f;j=c[e+8>>2]|0;k=c[j+44>>2]|0;l=c[c[j+32>>2]>>2]|0;j=l+20|0;m=l+24|0;n=bv(l,c[j>>2]|0,c[m>>2]|0)|0;if((n|0)==0){VHb(h);o=-12;i=g;return o|0}p=f+136|0;f=c[p+4>>2]|0;q=n+136|0;c[q>>2]=c[p>>2];c[q+4>>2]=f;f=k+1032|0;q=c[f>>2]|0;if((q|0)>0){p=k+1072|0;r=k+1036|0;s=0;t=q;while(1){u=c[m>>2]|0;if((s-1|0)>>>0<2>>>0){v=c[p>>2]|0;w=d[v+5|0]|0;x=-(-u>>d[v+6|0])|0}else{w=0;x=u}u=-(-(c[j>>2]|0)>>w)|0;if((x|0)>0){v=0;do{y=b[(c[p>>2]|0)+8+(s<<1)>>1]&3;z=(c[n+(y<<2)>>2]|0)+(ca(c[n+32+(y<<2)>>2]|0,v)|0)|0;mrc(z|0,a[(c[r>>2]|0)+s|0]|0,u|0)|0;v=v+1|0;}while((v|0)<(x|0));A=c[f>>2]|0}else{A=t}v=s+1|0;if((v|0)<(A|0)){s=v;t=A}else{B=A;break}}}else{B=q}q=c[k+4>>2]|0;do{if((q|0)==2){A=e+24|0;t=c[A>>2]|0;if((t|0)>0){s=e+20|0;x=n+32|0;r=n|0;p=0;w=c[s>>2]|0;m=t;while(1){t=c[h>>2]|0;v=ca(c[t+36>>2]|0,p)|0;u=ca(c[t+40>>2]|0,p)|0;if((w|0)>0){z=0;y=w;C=t;while(1){t=ca(d[(c[C+4>>2]|0)+(z+v)|0]|0,c[x>>2]|0)|0;D=(c[r>>2]|0)+((d[(c[C+8>>2]|0)+(z+u)|0]|0)+t)|0;t=a[D]|0;if(t<<24>>24==-1){E=y}else{a[D]=t+1;E=c[s>>2]|0}t=z+1|0;if((t|0)>=(E|0)){break}z=t;y=E;C=c[h>>2]|0}F=E;H=c[A>>2]|0}else{F=w;H=m}C=p+1|0;if((C|0)<(H|0)){p=C;w=F;m=H}else{I=r;J=x;break}}}else{I=n|0;J=n+32|0}x=n+4|0;r=n+8|0;m=0;do{w=c[I>>2]|0;p=ca(c[J>>2]|0,m)|0;A=m&255;s=0;do{if((a[w+(s+p)|0]|0)==0){C=(ca(c[J>>2]|0,m)|0)+s|0;a[(c[x>>2]|0)+C|0]=A;C=(ca(c[J>>2]|0,m)|0)+s|0;a[(c[r>>2]|0)+C|0]=s}s=s+1|0;}while((s|0)<256);m=m+1|0;}while((m|0)<256)}else if((q|0)==1){if((B|0)<=0){break}m=k+1064|0;r=k+1052|0;x=k+1056|0;s=k+1060|0;A=k+1072|0;p=0;w=B;while(1){C=ca(c[m>>2]|0,p<<8)|0;y=c[h>>2]|0;z=c[r>>2]|0;u=c[s>>2]|0;v=c[A>>2]|0;t=b[v+8+(p<<1)>>1]&3;if((p-1|0)>>>0<2>>>0){K=d[v+6|0]|0;L=d[v+5|0]|0}else{K=0;L=0}v=c[y+32+(t<<2)>>2]|0;D=c[n+32+(t<<2)>>2]|0;M=ca(D,(u|0)==1?-1:1)|0;N=c[n+(t<<2)>>2]|0;O=(c[x>>2]|0)!=0;if(O){P=ca(D,C>>K)|0}else{P=C>>L}C=N+P|0;Q=N+(P+(ca(D,(256>>>(K>>>0))-1|0)|0))|0;R=(u|0)!=0;u=R?Q:C;Q=-(c[y+72>>2]|0)>>K;S=-Q|0;T=-(c[y+68>>2]|0)>>L;U=-T|0;if(O|R^1){V=C}else{V=N+(P+(256>>>(L>>>0)))|0}if((Q|0)<0){Q=255-z&255;N=(T|0)<0;T=V;C=0;W=c[y+(t<<2)>>2]|0;while(1){t=W+U|0;if(N){if(O){if(R){y=u;X=W;while(1){Y=y+(ca((d[X]|0)>>>(K>>>0),M)|0)|0;Z=d[Y]|0;if(Z>>>0>Q>>>0){_=-1}else{_=Z+z&255}a[Y]=_;Y=X+1|0;if(Y>>>0<t>>>0){y=y+1|0;X=Y}else{break}}}else{X=u;y=W;while(1){Y=X+(ca((d[y]|0)>>>(K>>>0),M)|0)|0;Z=d[Y]|0;if(Z>>>0>Q>>>0){$=-1}else{$=Z+z&255}a[Y]=$;Y=y+1|0;if(Y>>>0<t>>>0){X=X+1|0;y=Y}else{break}}}}else{if(R){y=W;do{X=T+(-((d[y]|0)>>>(L>>>0))|0)|0;Y=d[X]|0;if(Y>>>0>Q>>>0){aa=-1}else{aa=Y+z&255}a[X]=aa;y=y+1|0;}while(y>>>0<t>>>0)}else{y=W;do{X=T+((d[y]|0)>>>(L>>>0))|0;Y=d[X]|0;if(Y>>>0>Q>>>0){ba=-1}else{ba=Y+z&255}a[X]=ba;y=y+1|0;}while(y>>>0<t>>>0)}}}t=C+1|0;if((t|0)<(S|0)){T=T+D|0;C=t;W=W+v|0}else{break}}da=c[f>>2]|0}else{da=w}v=p+1|0;if((v|0)<(da|0)){p=v;w=da}else{break}}}else if((q|0)==0){if((B|0)<=0){break}w=k+1072|0;p=k+1044|0;x=k+1048|0;A=k+1064|0;s=k+8|0;r=s;m=k+1068|0;v=k+1040|0;W=0;do{C=b[(c[w>>2]|0)+8+(W<<1)>>1]&3;D=ca((c[x>>2]|0)+(c[p>>2]|0)|0,W)|0;T=ca(D,c[A>>2]|0)|0;D=c[h>>2]|0;S=D+72|0;z=c[S>>2]|0;if((z|0)>0){Q=c[D+(C<<2)>>2]|0;R=D+68|0;M=0;u=z;z=c[R>>2]|0;while(1){O=ca(c[D+32+(C<<2)>>2]|0,M)|0;if((z|0)>0){N=0;do{U=r+(d[Q+(N+O)|0]<<2)|0;c[U>>2]=(c[U>>2]|0)+1;N=N+1|0;ea=c[R>>2]|0;}while((N|0)<(ea|0));fa=c[S>>2]|0;ga=ea}else{fa=u;ga=z}N=M+1|0;if((N|0)<(fa|0)){M=N;u=fa;z=ga}else{ha=0;ia=0;break}}}else{ha=0;ia=0}do{z=c[r+(ia<<2)>>2]|0;ha=ha>>>0>z>>>0?ha:z;ia=ia+1|0;}while((ia|0)<256);ja=+lc(+(+((ha+1|0)>>>0>>>0)));if((c[j>>2]|0)>0){z=ha;u=0;M=wrc(z,u,-1,-1)|0;S=G;R=n+32+(C<<2)|0;Q=n+(C<<2)|0;D=0;N=c[p>>2]|0;while(1){if((c[m>>2]|0)==0){O=N;U=(N|0)<0|0?-1:0;t=Erc(c[r+(D<<2)>>2]|0,0,O,U)|0;y=wrc(M,S,t,G)|0;t=Crc(y,G,z,u)|0;y=xrc(O,U,t,G)|0;ka=y}else{ka=~~+Nb(+(+(N|0)*(1.0- +lc(+(+(((c[r+(D<<2)>>2]|0)+1|0)>>>0>>>0)))/ja)))}y=N-1|0;if((y|0)<(ka|0)){la=N}else{t=y;do{do{if((c[A>>2]|0)==0){y=(ca(c[R>>2]|0,t+T|0)|0)+D|0;a[(c[Q>>2]|0)+y|0]=-1}else{if((c[f>>2]|0)<=0){break}y=t+T|0;U=0;do{O=(ca(c[n+32+(U<<2)>>2]|0,y)|0)+D|0;a[(c[n+(U<<2)>>2]|0)+O|0]=a[(c[v>>2]|0)+U|0]|0;U=U+1|0;}while((U|0)<(c[f>>2]|0))}}while(0);t=t-1|0;}while((t|0)>=(ka|0));la=c[p>>2]|0}t=(c[x>>2]|0)+la-1|0;if((t|0)<(la|0)){ma=la}else{U=D&255;y=t;while(1){t=(ca(c[R>>2]|0,y+T|0)|0)+D|0;a[(c[Q>>2]|0)+t|0]=U;t=y-1|0;O=c[p>>2]|0;if((t|0)<(O|0)){ma=O;break}else{y=t}}}y=D+1|0;if((y|0)<(c[j>>2]|0)){D=y;N=ma}else{break}}}mrc(s|0,0,1024)|0;W=W+1|0;}while((W|0)<(c[f>>2]|0))}else if((q|0)==3){W=e+24|0;s=c[W>>2]|0;if((s|0)<=0){break}p=e+20|0;x=n+32|0;v=n|0;A=n+4|0;r=n+8|0;m=0;w=c[p>>2]|0;N=s;while(1){s=c[h>>2]|0;D=ca(c[s+36>>2]|0,m)|0;Q=ca(c[s+40>>2]|0,m)|0;if((w|0)>0){T=0;R=s;while(1){s=a[(c[R+4>>2]|0)+(T+D)|0]|0;u=s&255;z=a[(c[R+8>>2]|0)+(T+Q)|0]|0;S=z&255;M=(ca(c[x>>2]|0,u)|0)+S|0;C=(c[v>>2]|0)+M|0;if((a[C]|0)==0){y=128-u|0;u=128-S|0;a[C]=((u|0)>-1?u:-u|0)+((y|0)>-1?y:-y|0)}a[(c[A>>2]|0)+M|0]=s;a[(c[r>>2]|0)+M|0]=z;z=T+1|0;na=c[p>>2]|0;if((z|0)>=(na|0)){break}T=z;R=c[h>>2]|0}oa=na;pa=c[W>>2]|0}else{oa=w;pa=N}R=m+1|0;if((R|0)<(pa|0)){m=R;w=oa;N=pa}else{break}}}else{KIb(0,0,2432640,(N=i,i=i+24|0,c[N>>2]=2347456,c[N+8>>2]=2286360,c[N+16>>2]=342,N)|0);i=N;Hd();return 0}}while(0);VHb(h);o=lj(l,n)|0;i=g;return o|0}function Ap(a){a=a|0;var b=0,e=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;a=qKb(c[e>>2]|0)|0;c[b+1072>>2]=a;c[b+1032>>2]=d[a+4|0]|0;a=c[e>>2]|0;if((a|0)==317|(a|0)==82){c[b+1036>>2]=1904880;c[b+1040>>2]=152144;return 0}else{c[b+1036>>2]=1904872;c[b+1040>>2]=152136;return 0}return 0}function Bp(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0.0,j=0.0,k=0.0,l=0.0;b=i;d=c[a+44>>2]|0;e=d+40|0;f=+h[e>>3];if(f!=0.0){g=f}else{h[e>>3]=4.0;g=4.0}e=d+56|0;f=+h[e>>3];if(f!=0.0){j=f}else{f=g*3.0*.25;h[e>>3]=f;j=f}e=d+48|0;f=+h[e>>3];if(f!=0.0){k=f}else{f=g*6.0*.25;h[e>>3]=f;k=f}e=d+64|0;f=+h[e>>3];if(f!=0.0){l=f}else{f=k*j/g;h[e>>3]=f;l=f}KIb(a,40,2432336,(a=i,i=i+32|0,h[a>>3]=g,h[a+8>>3]=j,h[a+16>>3]=k,h[a+24>>3]=l,a)|0);i=a;i=b;return 0}function Cp(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+4|0);mJb(b+8|0);mJb(b+12|0);mJb(b+16|0);mJb(b+20|0);mJb(b+24|0);mJb(b+28|0);mJb(b+32|0);return}function Dp(a){a=a|0;dl(a,Ok(685664)|0);return 0}function Ep(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=i;i=i+16|0;j=h|0;k=h+8|0;c[j>>2]=g;l=c[f+8>>2]|0;f=c[l+44>>2]|0;m=c[c[l+32>>2]>>2]|0;do{if((bIb(g)|0)==0){n=4}else{if((c[l+76>>2]|0)!=0){n=4;break}c[k>>2]=g;o=1}}while(0);do{if((n|0)==4){g=bv(m,c[m+20>>2]|0,c[m+24>>2]|0)|0;c[k>>2]=g;if((g|0)!=0){ZHb(g,c[j>>2]|0)|0;o=0;break}VHb(j);p=-12;i=h;return p|0}}while(0);n=f+80|0;g=f+20|0;q=f+24|0;r=f+72|0;s=f+76|0;t=f+4|0;u=f+116|0;v=f+120|0;w=f+124|0;x=f+148|0;f=0;do{y=c[n>>2]|0;a:do{if((y|0)==8){z=c[j>>2]|0;A=c[z+(f<<2)>>2]|0;B=c[k>>2]|0;C=c[B+(f<<2)>>2]|0;D=c[g>>2]|0;E=q+(f<<2)|0;F=(f|0)!=0;G=-(F&1)|0;H=-(c[z+68>>2]|0)>>(c[r>>2]&G);I=-H|0;J=-(c[z+72>>2]|0)>>(c[s>>2]&G);G=-J|0;K=c[z+32+(f<<2)>>2]|0;z=c[B+32+(f<<2)>>2]|0;B=c[t+((F?2:0)<<2)>>2]|0;L=c[t+((F?3:1)<<2)>>2]|0;F=c[E>>2]|0;do{if((F|0)==0){M=hJb(ca(I<<1,G)|0)|0;c[E>>2]=M;if((J|0)>=0){N=M;break}O=(H|0)<0;P=0;Q=M;R=A;while(1){if(O){S=0;do{b[Q+(S<<1)>>1]=d[R+S|0]<<8|127;S=S+1|0;}while((S|0)<(I|0))}S=P+1|0;if((S|0)<(G|0)){P=S;Q=Q+(I<<1)|0;R=R+K|0}else{N=M;break}}}else{N=F}}while(0);if((b[B>>1]|0)==0){if((J|0)>=0){break}F=(H|0)<0;E=N;M=C;R=0;Q=A;while(1){if(F){P=0;do{O=E+(P<<1)|0;S=d[Q+P|0]<<8|127;T=S+(b[L+(((e[O>>1]|0)-S>>4)+4096<<1)>>1]|0)|0;b[O>>1]=T;a[M+P|0]=T>>>8;P=P+1|0;}while((P|0)<(I|0))}P=R+1|0;if((P|0)<(G|0)){E=E+(I<<1)|0;M=M+z|0;R=P;Q=Q+K|0}else{break a}}}Q=B+8192|0;R=L+8192|0;M=a[A]|0;b:do{if((H|0)<0){E=0;F=(M&255)<<8|127;J=M;while(1){P=(J&255)<<8|127;T=(b[B+((F-P>>4)+4096<<1)>>1]|0)+P|0;b[D+(E<<1)>>1]=T;P=N+(E<<1)|0;O=(b[L+(((e[P>>1]|0)-T>>4)+4096<<1)>>1]|0)+T|0;b[P>>1]=O;a[C+E|0]=O>>>8;O=E+1|0;if((O|0)>=(I|0)){break b}E=O;F=T;J=a[A+O|0]|0}}}while(0);if((G|0)<=1){break}M=~H;J=(H|0)<-1;F=K+1|0;E=N;O=C;T=A;P=1;while(1){S=T+K|0;U=O+z|0;V=E+(I<<1)|0;W=c[u>>2]|0;if((W|0)==0){X=d[S]<<8|127;Y=(b[B+(((e[D>>1]|0)-X>>4)+4096<<1)>>1]|0)+X|0;b[D>>1]=Y;if(J){Z=0;_=X;X=Y;while(1){$=d[T+(F+Z)|0]<<8|127;aa=$+(b[B+((_-$>>4)+4096<<1)>>1]|0)|0;$=E+(Z-H<<1)|0;ba=(b[L+(((e[$>>1]|0)-X>>4)+4096<<1)>>1]|0)+X|0;b[$>>1]=ba;a[O+(Z+z)|0]=ba>>>8;ba=Z+1|0;$=D+(ba<<1)|0;da=(b[B+(((e[$>>1]|0)-aa>>4)+4096<<1)>>1]|0)+aa|0;b[$>>1]=da;if((ba|0)<(M|0)){Z=ba;_=aa;X=da}else{ea=M;fa=da;break}}}else{ea=0;fa=Y}X=E+(ea-H<<1)|0;_=(b[L+(((e[X>>1]|0)-fa>>4)+4096<<1)>>1]|0)+fa|0;b[X>>1]=_;a[O+(ea+z)|0]=_>>>8}else{Se[W&1023](S,U,D,V,I,Q,R)}_=P+1|0;if((_|0)<(G|0)){E=V;O=U;T=S;P=_}else{break}}}else if((y|0)==16){P=c[j>>2]|0;T=c[P+(f<<2)>>2]|0;O=c[k>>2]|0;E=c[O+(f<<2)>>2]|0;G=c[g>>2]|0;R=q+(f<<2)|0;Q=(f|0)!=0;I=-(Q&1)|0;D=-(c[P+68>>2]|0)>>(c[r>>2]&I);z=-D|0;L=-(c[P+72>>2]|0)>>(c[s>>2]&I);I=-L|0;H=c[P+32+(f<<2)>>2]|0;P=c[O+32+(f<<2)>>2]|0;O=c[t+((Q?2:0)<<2)>>2]|0;M=c[t+((Q?3:1)<<2)>>2]|0;Q=c[R>>2]|0;do{if((Q|0)==0){B=hJb(ca(z<<1,I)|0)|0;c[R>>2]=B;if((L|0)>=0){ga=B;break}F=(D|0)<0;J=0;K=B;A=T;while(1){if(F){C=0;do{b[K+(C<<1)>>1]=b[A+(C<<1)>>1]|0;C=C+1|0;}while((C|0)<(z|0))}C=J+1|0;if((C|0)<(I|0)){J=C;K=K+(z<<1)|0;A=A+H|0}else{ga=B;break}}}else{ga=Q}}while(0);if((b[O>>1]|0)==0){if((L|0)>=0){break}Q=(D|0)<0;R=ga;B=E;A=0;K=T;while(1){if(Q){J=0;do{F=R+(J<<1)|0;S=J<<1;U=b[K+S>>1]|0;V=(b[M+((e[F>>1]|65536)-(U&65535)<<1)>>1]|0)+U&65535;b[F>>1]=V;b[B+S>>1]=V;J=J+1|0;}while((J|0)<(z|0))}J=A+1|0;if((J|0)<(I|0)){R=R+(z<<1)|0;B=B+P|0;A=J;K=K+H|0}else{break a}}}K=O+131072|0;A=M+131072|0;if((D|0)<0){B=0;R=e[T>>1]|0;do{Q=B<<1;L=e[T+Q>>1]|0;R=(b[O+(R+65536-L<<1)>>1]|0)+L|0;b[G+(B<<1)>>1]=R;L=ga+(B<<1)|0;J=(e[M+(65536-R+(e[L>>1]|0)<<1)>>1]|0)+R&65535;b[L>>1]=J;b[E+Q>>1]=J;B=B+1|0;}while((B|0)<(z|0))}if((I|0)<=1){break}B=~D;R=(D|0)<-1;J=H+2|0;Q=ga;L=E;V=T;S=1;while(1){F=V+H|0;U=L+P|0;W=Q+(z<<1)|0;Y=c[x>>2]|0;if((Y|0)==0){C=e[F>>1]|0;_=(b[O+(65536-C+(e[G>>1]|0)<<1)>>1]|0)+C|0;b[G>>1]=_;if(R){X=0;Z=C;C=_;while(1){da=X<<1;aa=e[V+(J+da)>>1]|0;ba=(b[O+(Z+65536-aa<<1)>>1]|0)+aa|0;aa=Q+(X-D<<1)|0;$=(e[M+(65536-C+(e[aa>>1]|0)<<1)>>1]|0)+C&65535;b[aa>>1]=$;b[L+(da+P)>>1]=$;$=X+1|0;da=G+($<<1)|0;aa=(b[O+(65536-ba+(e[da>>1]|0)<<1)>>1]|0)+ba|0;b[da>>1]=aa;if(($|0)<(B|0)){X=$;Z=ba;C=aa}else{ha=B;ia=aa;break}}}else{ha=0;ia=_}C=Q+(ha-D<<1)|0;Z=(e[M+(65536-ia+(e[C>>1]|0)<<1)>>1]|0)+ia&65535;b[C>>1]=Z;b[L+((ha<<1)+P)>>1]=Z}else{Se[Y&1023](F,U,G,W,z,K,A)}Z=S+1|0;if((Z|0)<(I|0)){Q=W;L=U;V=F;S=Z}else{break}}}else if((y|0)==10){S=c[j>>2]|0;V=c[S+(f<<2)>>2]|0;L=c[k>>2]|0;Q=c[L+(f<<2)>>2]|0;I=c[g>>2]|0;A=q+(f<<2)|0;K=(f|0)!=0;z=-(K&1)|0;G=-(c[S+68>>2]|0)>>(c[r>>2]&z);P=-G|0;M=-(c[S+72>>2]|0)>>(c[s>>2]&z);z=-M|0;D=c[S+32+(f<<2)>>2]|0;S=c[L+32+(f<<2)>>2]|0;L=c[t+((K?2:0)<<2)>>2]|0;B=c[t+((K?3:1)<<2)>>2]|0;K=c[A>>2]|0;do{if((K|0)==0){O=hJb(ca(P<<1,z)|0)|0;c[A>>2]=O;if((M|0)>=0){ja=O;break}J=(G|0)<0;R=0;H=O;T=V;while(1){if(J){E=0;do{b[H+(E<<1)>>1]=b[T+(E<<1)>>1]<<6|31;E=E+1|0;}while((E|0)<(P|0))}E=R+1|0;if((E|0)<(z|0)){R=E;H=H+(P<<1)|0;T=T+D|0}else{ja=O;break}}}else{ja=K}}while(0);if((b[L>>1]|0)==0){if((M|0)>=0){break}K=(G|0)<0;A=ja;O=Q;T=0;H=V;while(1){if(K){R=0;do{J=A+(R<<1)|0;F=R<<1;U=e[H+F>>1]<<6|31;W=U+(b[B+(((e[J>>1]|0)-U>>4)+4096<<1)>>1]|0)|0;b[J>>1]=W;b[O+F>>1]=W>>>6;R=R+1|0;}while((R|0)<(P|0))}R=T+1|0;if((R|0)<(z|0)){A=A+(P<<1)|0;O=O+S|0;T=R;H=H+D|0}else{break a}}}H=L+8192|0;T=B+8192|0;if((G|0)<0){O=0;A=e[V>>1]<<6|31;do{K=O<<1;M=e[V+K>>1]<<6|31;A=M+(b[L+((A-M>>4)+4096<<1)>>1]|0)|0;b[I+(O<<1)>>1]=A;M=ja+(O<<1)|0;R=(b[B+(((e[M>>1]|0)-A>>4)+4096<<1)>>1]|0)+A|0;b[M>>1]=R;b[Q+K>>1]=R>>>6;O=O+1|0;}while((O|0)<(P|0))}if((z|0)<=1){break}O=~G;A=(G|0)<-1;R=D+2|0;K=ja;M=Q;W=V;F=1;while(1){J=W+D|0;U=M+S|0;Y=K+(P<<1)|0;_=c[w>>2]|0;if((_|0)==0){E=e[J>>1]<<6|31;Z=(b[L+(((e[I>>1]|0)-E>>4)+4096<<1)>>1]|0)+E|0;b[I>>1]=Z;if(A){C=0;X=E;E=Z;while(1){aa=C<<1;ba=e[W+(R+aa)>>1]<<6|31;$=ba+(b[L+((X-ba>>4)+4096<<1)>>1]|0)|0;ba=K+(C-G<<1)|0;da=(b[B+(((e[ba>>1]|0)-E>>4)+4096<<1)>>1]|0)+E|0;b[ba>>1]=da;b[M+(aa+S)>>1]=da>>>6;da=C+1|0;aa=I+(da<<1)|0;ba=(b[L+(((e[aa>>1]|0)-$>>4)+4096<<1)>>1]|0)+$|0;b[aa>>1]=ba;if((da|0)<(O|0)){C=da;X=$;E=ba}else{ka=O;la=ba;break}}}else{ka=0;la=Z}E=K+(ka-G<<1)|0;X=(b[B+(((e[E>>1]|0)-la>>4)+4096<<1)>>1]|0)+la|0;b[E>>1]=X;b[M+((ka<<1)+S)>>1]=X>>>6}else{Se[_&1023](J,U,I,Y,P,H,T)}X=F+1|0;if((X|0)<(z|0)){K=Y;M=U;W=J;F=X}else{break}}}else if((y|0)==9){F=c[j>>2]|0;W=c[F+(f<<2)>>2]|0;M=c[k>>2]|0;K=c[M+(f<<2)>>2]|0;z=c[g>>2]|0;T=q+(f<<2)|0;H=(f|0)!=0;P=-(H&1)|0;I=-(c[F+68>>2]|0)>>(c[r>>2]&P);S=-I|0;B=-(c[F+72>>2]|0)>>(c[s>>2]&P);P=-B|0;G=c[F+32+(f<<2)>>2]|0;F=c[M+32+(f<<2)>>2]|0;M=c[t+((H?2:0)<<2)>>2]|0;O=c[t+((H?3:1)<<2)>>2]|0;H=c[T>>2]|0;do{if((H|0)==0){L=hJb(ca(S<<1,P)|0)|0;c[T>>2]=L;if((B|0)>=0){ma=L;break}R=(I|0)<0;A=0;D=L;V=W;while(1){if(R){Q=0;do{b[D+(Q<<1)>>1]=b[V+(Q<<1)>>1]<<7|63;Q=Q+1|0;}while((Q|0)<(S|0))}Q=A+1|0;if((Q|0)<(P|0)){A=Q;D=D+(S<<1)|0;V=V+G|0}else{ma=L;break}}}else{ma=H}}while(0);if((b[M>>1]|0)==0){if((B|0)>=0){break}H=(I|0)<0;T=ma;L=K;V=0;D=W;while(1){if(H){A=0;do{R=T+(A<<1)|0;J=A<<1;U=e[D+J>>1]<<7|63;Y=U+(b[O+(((e[R>>1]|0)-U>>4)+4096<<1)>>1]|0)|0;b[R>>1]=Y;b[L+J>>1]=Y>>>7;A=A+1|0;}while((A|0)<(S|0))}A=V+1|0;if((A|0)<(P|0)){T=T+(S<<1)|0;L=L+F|0;V=A;D=D+G|0}else{break a}}}D=M+8192|0;V=O+8192|0;if((I|0)<0){L=0;T=e[W>>1]<<7|63;do{H=L<<1;B=e[W+H>>1]<<7|63;T=B+(b[M+((T-B>>4)+4096<<1)>>1]|0)|0;b[z+(L<<1)>>1]=T;B=ma+(L<<1)|0;A=(b[O+(((e[B>>1]|0)-T>>4)+4096<<1)>>1]|0)+T|0;b[B>>1]=A;b[K+H>>1]=A>>>7;L=L+1|0;}while((L|0)<(S|0))}if((P|0)<=1){break}L=~I;T=(I|0)<-1;A=G+2|0;H=ma;B=K;Y=W;J=1;while(1){R=Y+G|0;U=B+F|0;_=H+(S<<1)|0;Z=c[v>>2]|0;if((Z|0)==0){Q=e[R>>1]<<7|63;X=(b[M+(((e[z>>1]|0)-Q>>4)+4096<<1)>>1]|0)+Q|0;b[z>>1]=X;if(T){E=0;C=Q;Q=X;while(1){ba=E<<1;$=e[Y+(A+ba)>>1]<<7|63;da=$+(b[M+((C-$>>4)+4096<<1)>>1]|0)|0;$=H+(E-I<<1)|0;aa=(b[O+(((e[$>>1]|0)-Q>>4)+4096<<1)>>1]|0)+Q|0;b[$>>1]=aa;b[B+(ba+F)>>1]=aa>>>7;aa=E+1|0;ba=z+(aa<<1)|0;$=(b[M+(((e[ba>>1]|0)-da>>4)+4096<<1)>>1]|0)+da|0;b[ba>>1]=$;if((aa|0)<(L|0)){E=aa;C=da;Q=$}else{na=L;oa=$;break}}}else{na=0;oa=X}Q=H+(na-I<<1)|0;C=(b[O+(((e[Q>>1]|0)-oa>>4)+4096<<1)>>1]|0)+oa|0;b[Q>>1]=C;b[B+((na<<1)+F)>>1]=C>>>7}else{Se[Z&1023](R,U,z,_,S,D,V)}C=J+1|0;if((C|0)<(P|0)){H=_;B=U;Y=R;J=C}else{break}}}}while(0);f=f+1|0;}while((f|0)<3);if((c[l+76>>2]|0)!=0){VHb(k);p=lj(m,c[j>>2]|0)|0;i=h;return p|0}if((o|0)==0){VHb(j)}p=lj(m,c[k>>2]|0)|0;i=h;return p|0}function Fp(a){a=a|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0.0,v=0.0;f=a+8|0;g=c[(c[f>>2]|0)+44>>2]|0;i=qKb(c[a+52>>2]|0)|0;j=c[(c[f>>2]|0)+44>>2]|0;mJb(j+4|0);mJb(j+8|0);mJb(j+12|0);mJb(j+16|0);mJb(j+20|0);mJb(j+24|0);mJb(j+28|0);mJb(j+32|0);c[g+72>>2]=d[i+5|0]|0;c[g+76>>2]=d[i+6|0]|0;j=g+80|0;c[j>>2]=((e[i+8>>1]|0)>>>11&15)+1;i=hJb(c[a+20>>2]<<1)|0;c[g+20>>2]=i;if((i|0)==0){k=-12;return k|0}i=g+40|0;a=g+4|0;g=0;while(1){if((g|0)>=4){k=0;l=12;break}m=+h[i+(g<<3)>>3];f=(c[j>>2]|0)==16?8:4;n=hJb(1024<<f)|0;o=n;if((n|0)==0){break}p=-1.3862943611198906/+aa(1.0-(m>252.0?252.0:m)/255.0+-1.0e-5);n=-255<<f;q=255<<f;if((n|0)<=(q|0)){r=9-f|0;s=(1<<8-f)-1|0;t=256<<f;f=n;do{u=+(s+(f<<r)|0)*.001953125;if(u<0.0){v=-0.0-u}else{v=u}b[o+(f+t<<1)>>1]=Lc(+(u*+T(+(1.0-v/255.0),+p)*256.0))|0;f=f+1|0;}while((f|0)<=(q|0))}b[o>>1]=m!=0.0|0;c[a+(g<<2)>>2]=o;g=g+1|0}if((l|0)==12){return k|0}c[a+(g<<2)>>2]=0;k=-12;return k|0}function Gp(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0;b=i;d=c[a+44>>2]|0;e=d+16|0;do{if((c[e>>2]|0)!=0){if((c[d+12>>2]|0)==0){break}KIb(a,16,2582808,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;h=-22;i=b;return h|0}}while(0);j=d+44|0;k=c[j>>2]|0;do{if((k|0)!=0){l=Kp(d+48|0,j,k,2236320,a)|0;if((l|0)<0){h=l}else{break}i=b;return h|0}}while(0);k=d+32|0;l=c[k>>2]|0;do{if((l|0)!=0){m=Kp(d+36|0,k,l,2286112,a)|0;if((m|0)<0){h=m}else{break}i=b;return h|0}}while(0);l=d+12|0;m=c[l>>2]|0;do{if((m|0)!=0){n=Kp(d+20|0,l,m,2432280,a)|0;if((n|0)<0){h=n}else{break}i=b;return h|0}}while(0);m=c[e>>2]|0;do{if((m|0)==0){o=0;p=a}else{n=a;q=Kp(d+24|0,e,m,2347184,n)|0;if((q|0)<0){h=q;i=b;return h|0}else{o=c[e>>2]|0;p=n;break}}}while(0);e=c[l>>2]|0;l=c[k>>2]|0;k=c[j>>2]|0;KIb(p,40,2562520,(f=i,i=i+32|0,c[f>>2]=o,c[f+8>>2]=e,c[f+16>>2]=l,c[f+24>>2]=k,f)|0);i=f;r=+g[d+8>>2];s=+V(r)*65536.0;t=+g[d+28>>2];c[d+64>>2]=~~+Lc(+(s*t));c[d+68>>2]=~~+Lc(+(t*+U(r)*65536.0));c[d+60>>2]=1;h=0;i=b;return h|0}function Hp(a){a=a|0;var b=0;b=c[a+44>>2]|0;TGb(c[b+48>>2]|0);TGb(c[b+20>>2]|0);TGb(c[b+24>>2]|0);TGb(c[b+36>>2]|0);return}function Ip(a){a=a|0;dl(a,Ok(685624)|0);return 0}function Jp(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=c[a+44>>2]|0;do{if((irc(b,2432280)|0)==0){f=Kp(g+20|0,g+12|0,d,2432280,a)|0;if((f|0)<0){h=f;return h|0}else{mJb(g+16|0);break}}else{if((irc(b,2347184)|0)==0){f=Kp(g+24|0,g+16|0,d,2347184,a)|0;if((f|0)<0){h=f;return h|0}else{mJb(g+12|0);break}}if((irc(b,2286112)|0)==0){f=Kp(g+36|0,g+32|0,d,2286112,a)|0;if((f|0)<0){h=f}else{break}return h|0}if((irc(b,2236320)|0)!=0){h=-38;return h|0}f=Kp(g+48|0,g+44|0,d,2236320,a)|0;if((f|0)<0){h=f}else{break}return h|0}}while(0);h=0;return h|0}function Kp(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+8|0;h=g|0;j=rJb(d)|0;if((j|0)==0){k=-12;i=g;return k|0}l=UGb(h,d,281552,0,0,0,0,0,f)|0;if((l|0)<0){KIb(f,16,2196168,(f=i,i=i+16|0,c[f>>2]=d,c[f+8>>2]=e,f)|0);i=f;kJb(j);k=l;i=g;return k|0}l=c[a>>2]|0;if((l|0)!=0){TGb(l)}c[a>>2]=c[h>>2];mJb(b);c[b>>2]=j;k=0;i=g;return k|0}function Lp(b,e){b=b|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0.0,E=0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0,L=0,M=0.0,N=0;f=i;i=i+8|0;j=f|0;c[j>>2]=e;k=b+8|0;l=c[k>>2]|0;m=c[l+44>>2]|0;n=m;o=c[c[l+32>>2]>>2]|0;l=m+64|0;p=c[l>>2]|0;q=m+68|0;s=c[q>>2]|0;t=m+40|0;u=+g[t>>2];do{if((bIb(e)|0)==0){v=bv(o,c[o+20>>2]|0,c[o+24>>2]|0)|0;if((v|0)!=0){ZHb(v,c[j>>2]|0)|0;w=0;x=v;y=c[j>>2]|0;break}VHb(j);z=-12;i=f;return z|0}else{w=1;x=e;y=e}}while(0);e=b+160|0;v=m+72|0;h[v>>3]=+((c[e>>2]|0)>>>0)+ +(c[e+4>>2]|0)*4294967296.0;e=y+136|0;y=c[e>>2]|0;A=c[e+4>>2]|0;if((y|0)==0&(A|0)==(-2147483648|0)){e=m+96|0;h[e>>3]=+r;B=+r;C=e}else{e=m+96|0;h[e>>3]=(+(y>>>0)+ +(A|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0));B=+(y>>>0)+ +(A|0)*4294967296.0;C=e}h[m+80>>3]=B;do{if((c[m+32>>2]|0)!=0){B=+XGb(c[m+36>>2]|0,v,0);e=m+28|0;g[e>>2]=B;if(!(B<-10.0|B>10.0)){break}A=~~B;if((A|0)<-10){D=-10.0}else{D=(A|0)>10?10.0:+(A|0)}g[e>>2]=D;KIb(c[k>>2]|0,24,2455632,(E=i,i=i+24|0,c[E>>2]=-10,c[E+8>>2]=10,h[E+16>>3]=D,E)|0);i=E}}while(0);do{if((c[m+44>>2]|0)!=0){D=+XGb(c[m+48>>2]|0,v,0);g[t>>2]=D;e=D<-10.0;A=D>10.0;if(!(e|A)){break}if(e){F=-10.0}else{F=A?10.0:D}g[t>>2]=F;KIb(c[k>>2]|0,24,2438360,(E=i,i=i+24|0,c[E>>2]=-10,c[E+8>>2]=10,h[E+16>>3]=F,E)|0);i=E}}while(0);do{if((c[m+12>>2]|0)==0){if((c[m+16>>2]|0)==0){G=+g[m+8>>2];H=+g[m+4>>2];break}else{F=+XGb(c[m+24>>2]|0,v,0);g[m+8>>2]=F;D=F*180.0/3.141592653589793;g[m+4>>2]=D;G=F;H=D;break}}else{D=+XGb(c[m+20>>2]|0,v,0);g[m+4>>2]=D;F=D*3.141592653589793/180.0;g[m+8>>2]=F;G=F;H=D}}while(0);A=m+28|0;D=+g[A>>2];F=+g[t>>2];B=+h[C>>3];C=~~+h[v>>3];KIb(c[k>>2]|0,48,2427656,(E=i,i=i+48|0,h[E>>3]=G/3.141592653589793,h[E+8>>3]=H,h[E+16>>3]=D,h[E+24>>3]=F,h[E+32>>3]=B,c[E+40>>2]=C,E)|0);i=E;B=+g[m+8>>2];F=+V(B)*65536.0;D=+g[A>>2];A=~~+Lc(+(F*D));c[l>>2]=A;l=~~+Lc(+(D*+U(B)*65536.0));c[q>>2]=l;q=m+60|0;do{if((c[q>>2]|0)==0&(p|0)==(A|0)&(s|0)==(l|0)){I=33}else{E=0;do{C=E-128|0;k=(ca(C,l)|0)+8421376|0;v=(ca(C,A)|0)+8421376|0;C=0;do{e=C-128|0;y=k-(ca(e,A)|0)>>16;J=v+(ca(e,l)|0)>>16;if(y>>>0>255>>>0){K=-y>>31&255}else{K=y&255}a[n+368+(E<<8)+C|0]=K;if(J>>>0>255>>>0){L=-J>>31&255}else{L=J&255}a[n+65904+(E<<8)+C|0]=L;C=C+1|0;}while((C|0)<256);E=E+1|0;}while((E|0)<256);if((c[q>>2]|0)==0){I=33;break}M=+g[t>>2];I=34}}while(0);if((I|0)==33){B=+g[t>>2];if(u!=B&B!=0.0){M=B;I=34}}if((I|0)==34){B=M*25.5;I=0;do{L=~~(B+ +(I|0));if(L>>>0>255>>>0){N=-L>>31&255}else{N=L&255}a[n+112+I|0]=N;I=I+1|0;}while((I|0)<256)}I=(w|0)!=0;do{if(!I){if(!(+g[t>>2]!=0.0)){w=c[j>>2]|0;uIb(c[x>>2]|0,c[x+32>>2]|0,c[w>>2]|0,c[w+32>>2]|0,c[b+20>>2]|0,c[b+24>>2]|0)}w=c[j>>2]|0;N=c[w+12>>2]|0;if((N|0)==0){break}uIb(c[x+12>>2]|0,c[x+44>>2]|0,N,c[w+44>>2]|0,c[b+20>>2]|0,c[b+24>>2]|0)}}while(0);w=c[x+36>>2]|0;N=c[j>>2]|0;L=c[N+36>>2]|0;K=b+20|0;l=-(c[K>>2]|0)>>c[m+52>>2];A=-l|0;s=b+24|0;b=-(c[s>>2]|0)>>c[m+56>>2];if((b|0)!=0&(l|0)<0){l=c[N+8>>2]|0;m=c[N+4>>2]|0;N=c[x+8>>2]|0;p=c[x+4>>2]|0;E=-b|0;while(1){b=0;do{C=d[m+b|0]|0;v=d[l+b|0]|0;a[p+b|0]=a[n+368+(C<<8)+v|0]|0;a[N+b|0]=a[n+65904+(C<<8)+v|0]|0;b=b+1|0;}while((b|0)<(A|0));b=E-1|0;if((b|0)==0){break}else{l=l+L|0;m=m+L|0;N=N+w|0;p=p+w|0;E=b}}}do{if(+g[t>>2]!=0.0){E=c[x+32>>2]|0;w=c[j>>2]|0;p=c[w+32>>2]|0;N=c[K>>2]|0;L=c[s>>2]|0;if(!((L|0)!=0&(N|0)>0)){break}m=c[w>>2]|0;w=c[x>>2]|0;l=L;while(1){L=0;do{a[w+L|0]=a[(d[m+L|0]|0)+(n+112)|0]|0;L=L+1|0;}while((L|0)<(N|0));L=l-1|0;if((L|0)==0){break}else{m=m+p|0;w=w+E|0;l=L}}}}while(0);if(!I){VHb(j)}c[q>>2]=0;z=lj(o,x)|0;i=f;return z|0}function Mp(a){a=a|0;var b=0,e=0,f=0.0,g=0,i=0,j=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;c[b+52>>2]=d[e+5|0]|0;c[b+56>>2]=d[e+6|0]|0;h[b+72>>3]=0.0;h[b+104>>3]=+(c[a+56>>2]|0)/+(c[a+60>>2]|0);e=c[a+116>>2]|0;if((e|0)==0){f=+r;g=b+88|0;i=g;h[i>>3]=f;return 0}j=c[a+120>>2]|0;if((j|0)==0){f=+r;g=b+88|0;i=g;h[i>>3]=f;return 0}f=+(e|0)/+(j|0);g=b+88|0;i=g;h[i>>3]=f;return 0}function Np(b){b=b|0;var d=0;d=c[b+44>>2]|0;c[d+12>>2]=3;b=d+48|0;y=50529027;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[d+64>>2]=434;return 0}function Op(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=a;a=c[d+20>>2]|0;f=c[d+24>>2]|0;g=c[d+28>>2]|0;KIb(e,32,2432016,(h=i,i=i+32|0,c[h>>2]=c[d+16>>2],c[h+8>>2]=a,c[h+16>>2]=f,c[h+24>>2]=g,h)|0);i=h;g=c[d+36>>2]|0;f=c[d+40>>2]|0;a=c[d+44>>2]|0;KIb(e,32,2346848,(h=i,i=i+32|0,c[h>>2]=c[d+32>>2],c[h+8>>2]=g,c[h+16>>2]=f,c[h+24>>2]=a,h)|0);i=h;VHb(d+60|0);VHb(d+52|0);VHb(d+56|0);i=b;return}function Pp(a){a=a|0;dl(a,Ok(685544)|0);return 0}function Qp(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)>0){f=c;g=b;h=0;i=0;j=a}else{k=0;return k|0}while(1){a=(d[f]|0)+(d[j]|0)-((d[g]|0)<<1)|0;b=((a|0)>-1?a:-a|0)+i|0;a=h+1|0;if((a|0)<(e|0)){f=f+1|0;g=g+1|0;h=a;i=b;j=j+1|0}else{k=b;break}}return k|0}function Rp(a){a=a|0;var b=0;b=a+156|0;c[b>>2]=c[b>>2]|1;return 0}function Sp(e,f){e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;h=i;i=i+16|0;j=h|0;k=c[e+8>>2]|0;l=k+44|0;m=c[l>>2]|0;n=m+60|0;if((c[n>>2]|0)!=0){VHb(n)}o=m+52|0;p=c[o>>2]|0;c[n>>2]=p;q=m+56|0;r=c[q>>2]|0;c[o>>2]=r;c[q>>2]=f;if((r|0)==0){s=0;i=h;return s|0}if((p|0)==0){c[n>>2]=$Hb(r)|0}r=m+68|0;n=c[r>>2]|0;if((n|0)==0){p=qKb(c[e+52>>2]|0)|0;c[r>>2]=p;t=p}else{t=n}if(!((b[t+8>>1]&16384)==0)){c[m+64>>2]=268}m=c[l>>2]|0;mrc(j|0,0,16)|0;l=m+68|0;t=c[l>>2]|0;if((a[t+4|0]|0)==0){u=0;v=0;w=0.0;x=0.0}else{n=m+52|0;p=m+60|0;r=m+56|0;e=m+64|0;f=0;q=0;y=0;z=t;while(1){t=c[n>>2]|0;A=c[t+68>>2]|0;B=c[t+72>>2]|0;C=c[t+32+(y<<2)>>2]|0;if((y|0)!=0&(y|0)<3){D=-(-B>>d[z+6|0])|0;E=-(-A>>d[z+5|0])|0}else{D=B;E=A}A=D-2|0;if((A|0)>2){B=f;F=q;H=2;I=t;while(1){t=ca(H,C)|0;J=c[I+(y<<2)>>2]|0;K=(c[(c[r>>2]|0)+(y<<2)>>2]|0)+t|0;L=J+(t-C)|0;M=J+(t+C)|0;N=hf[c[e>>2]&1023](L,(c[(c[p>>2]|0)+(y<<2)>>2]|0)+t|0,M,E)|0;O=H&1;P=j+(O<<3)|0;Q=wrc(c[P>>2]|0,c[P+4>>2]|0,N,(N|0)<0|0?-1:0)|0;c[P>>2]=Q;c[P+4>>2]=G;P=hf[c[e>>2]&1023](L,K,M,E)|0;K=j+((O^1)<<3)|0;O=wrc(c[K>>2]|0,c[K+4>>2]|0,P,(P|0)<0|0?-1:0)|0;c[K>>2]=O;c[K+4>>2]=G;K=hf[c[e>>2]&1023](L,J+t|0,M,E)|0;R=wrc(K,(K|0)<0|0?-1:0,F,B)|0;S=G;K=H+1|0;if((K|0)>=(A|0)){break}B=S;F=R;H=K;I=c[n>>2]|0}T=S;U=R;V=c[l>>2]|0}else{T=f;U=q;V=z}I=y+1|0;if((I|0)<(d[V+4|0]|0)){f=T;q=U;y=I;z=V}else{break}}V=j|0;z=j+8|0;u=T;v=U;w=+((c[V>>2]|0)>>>0)+ +(c[V+4>>2]|0)*4294967296.0;x=+((c[z>>2]|0)>>>0)+ +(c[z+4>>2]|0)*4294967296.0}W=+g[m+4>>2];do{if(w>x*W){X=0}else{if(x>w*W){X=1;break}X=x>(+(v>>>0)+ +(u|0)*4294967296.0)*+g[m+8>>2]?2:3}}while(0);u=m+48|0;v=m+49|0;orc(v|0,u|0,3)|0;z=X&255;a[u]=z;u=z<<24>>24==3;z=u?3:X;V=u&1^1;u=a[v]|0;v=u&255;do{if(u<<24>>24==3){Y=V;Z=z;_=45}else{U=(z|0)==3?v:z;if((v|0)!=(U|0)){$=0;aa=U;break}Y=V+1|0;Z=v;_=45}}while(0);do{if((_|0)==45){v=a[m+50|0]|0;V=v&255;if(v<<24>>24==3){ba=Y;da=Z}else{v=(Z|0)==3?V:Z;if((V|0)!=(v|0)){$=0;aa=v;break}ba=Y+1|0;da=V}V=a[m+51|0]|0;v=V&255;if(V<<24>>24==3){$=ba;aa=da;break}V=(da|0)==3?v:da;$=(v|0)==(V|0)?ba+1|0:0;aa=V}}while(0);ba=m+12|0;da=c[ba>>2]|0;do{if((da|0)==3){if(($|0)==0){break}c[ba>>2]=aa;ea=aa;_=29}else{if(($|0)<=2){ea=da;_=29;break}c[ba>>2]=aa;ea=aa;_=29}}while(0);do{if((_|0)==29){if((ea|0)==1){aa=c[m+52>>2]|0;c[aa+300>>2]=0;c[aa+296>>2]=1;break}else if((ea|0)==2){c[(c[m+52>>2]|0)+296>>2]=0;break}else if((ea|0)==0){aa=c[m+52>>2]|0;c[aa+300>>2]=1;c[aa+296>>2]=1;break}else{break}}}while(0);ea=m+16+(X<<2)|0;c[ea>>2]=(c[ea>>2]|0)+1;ea=m+32+(c[ba>>2]<<2)|0;c[ea>>2]=(c[ea>>2]|0)+1;ea=k;if((X|0)==0){fa=2633304}else if((X|0)==2){fa=2582784}else if((X|0)==3){fa=2562496}else if((X|0)==1){fa=2609600}else{fa=0}X=c[ba>>2]|0;if((X|0)==1){ga=2609600}else if((X|0)==2){ga=2582784}else if((X|0)==3){ga=2562496}else if((X|0)==0){ga=2633304}else{ga=0}KIb(ea,48,2115288,(ea=i,i=i+16|0,c[ea>>2]=fa,c[ea+8>>2]=ga,ea)|0);i=ea;ea=c[c[k+32>>2]>>2]|0;s=lj(ea,$Hb(c[o>>2]|0)|0)|0;i=h;return s|0}function Tp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)>0){f=c;g=b;h=0;i=0;j=a}else{k=0;return k|0}while(1){a=(e[f>>1]|0)+(e[j>>1]|0)-((e[g>>1]|0)<<1)|0;b=((a|0)>-1?a:-a|0)+i|0;a=h+1|0;if((a|0)<(d|0)){f=f+2|0;g=g+2|0;h=a;i=b;j=j+2|0}else{k=b;break}}return k|0}function Up(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=0;do{if((a[(qKb(f)|0)+7|0]&10)==0){Qk(e,f,(f|0)<0|0?-1:0)|0}f=f+1|0;}while((f|0)<333);dl(b,c[e>>2]|0);i=d;return 0}function Vp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=c[c[f+32>>2]>>2]|0;f=bv(h,c[h+20>>2]|0,c[h+24>>2]|0)|0;if((f|0)==0){VHb(e);j=-12;i=d;return j|0}ZHb(f,b)|0;b=c[f>>2]|0;k=c[e>>2]|0;l=c[k>>2]|0;m=g+32|0;n=m;o=c[m>>2]|0;m=a+24|0;a=c[f+32>>2]|0;p=c[k+32>>2]|0;k=c[g+4>>2]|0;q=c[g+16>>2]|0;r=1-q|0;s=c[m>>2]>>1;do{if((k|0)==2){if((s|0)>0){t=0}else{break}do{u=t<<1;nrc(b+(ca(t,a)|0)|0,l+(ca(u+q|0,p)|0)|0,o)|0;nrc(b+(ca(t+s|0,a)|0)|0,l+(ca(u+r|0,p)|0)|0,o)|0;t=t+1|0;}while((t|0)<(s|0))}else if((k|0)==1){if((s|0)>0){v=0}else{break}do{u=v<<1;nrc(b+(ca(u+q|0,a)|0)|0,l+(ca(v,p)|0)|0,o)|0;nrc(b+(ca(u+r|0,a)|0)|0,l+(ca(v+s|0,p)|0)|0,o)|0;v=v+1|0;}while((v|0)<(s|0))}else if((k|0)==0){if((s|0)<=0){break}u=a<<1;w=0;do{x=w<<1;nrc(b+(ca(u,w)|0)|0,l+(ca(x+q|0,p)|0)|0,o)|0;nrc(b+(ca(x|1,a)|0)|0,l+(ca(x+r|0,p)|0)|0,o)|0;w=w+1|0;}while((w|0)<(s|0))}}while(0);s=g+28|0;o=c[s>>2]|0;p=g+52|0;r=c[p>>2]|0;if((o-r|0)>1){l=g+48|0;a=g+8|0;b=g+20|0;q=1;while(1){k=c[f+(q<<2)>>2]|0;v=c[e>>2]|0;t=c[v+(q<<2)>>2]|0;w=c[n+(q<<2)>>2]|0;u=c[f+32+(q<<2)>>2]|0;x=c[v+32+(q<<2)>>2]|0;v=c[a>>2]|0;y=c[b>>2]|0;z=1-y|0;A=c[l>>2]>>1;do{if((v|0)==2){if((A|0)>0){B=0}else{break}do{C=B<<1;nrc(k+(ca(B,u)|0)|0,t+(ca(C+y|0,x)|0)|0,w)|0;nrc(k+(ca(B+A|0,u)|0)|0,t+(ca(C+z|0,x)|0)|0,w)|0;B=B+1|0;}while((B|0)<(A|0))}else if((v|0)==0){if((A|0)<=0){break}C=u<<1;D=0;do{E=D<<1;nrc(k+(ca(C,D)|0)|0,t+(ca(E+y|0,x)|0)|0,w)|0;nrc(k+(ca(E|1,u)|0)|0,t+(ca(E+z|0,x)|0)|0,w)|0;D=D+1|0;}while((D|0)<(A|0))}else if((v|0)==1){if((A|0)>0){F=0}else{break}do{D=F<<1;nrc(k+(ca(D+y|0,u)|0)|0,t+(ca(F,x)|0)|0,w)|0;nrc(k+(ca(D+z|0,u)|0)|0,t+(ca(F+A|0,x)|0)|0,w)|0;F=F+1|0;}while((F|0)<(A|0))}}while(0);A=q+1|0;w=c[s>>2]|0;x=c[p>>2]|0;if((A|0)<(w-x|0)){q=A}else{G=w;H=x;break}}}else{G=o;H=r}do{if((H|0)!=0){r=G-1|0;o=c[f+(r<<2)>>2]|0;q=c[e>>2]|0;p=c[q+(r<<2)>>2]|0;s=c[n+(r<<2)>>2]|0;F=c[f+32+(r<<2)>>2]|0;B=c[q+32+(r<<2)>>2]|0;r=c[g+12>>2]|0;q=c[g+24>>2]|0;l=1-q|0;b=c[m>>2]>>1;if((r|0)==0){if((b|0)<=0){break}a=F<<1;x=0;do{w=x<<1;nrc(o+(ca(a,x)|0)|0,p+(ca(w+q|0,B)|0)|0,s)|0;nrc(o+(ca(w|1,F)|0)|0,p+(ca(w+l|0,B)|0)|0,s)|0;x=x+1|0;}while((x|0)<(b|0))}else if((r|0)==2){if((b|0)>0){I=0}else{break}do{x=I<<1;nrc(o+(ca(I,F)|0)|0,p+(ca(x+q|0,B)|0)|0,s)|0;nrc(o+(ca(I+b|0,F)|0)|0,p+(ca(x+l|0,B)|0)|0,s)|0;I=I+1|0;}while((I|0)<(b|0))}else if((r|0)==1){if((b|0)>0){J=0}else{break}do{x=J<<1;nrc(o+(ca(x+q|0,F)|0)|0,p+(ca(J,B)|0)|0,s)|0;nrc(o+(ca(x+l|0,F)|0)|0,p+(ca(J+b|0,B)|0)|0,s)|0;J=J+1|0;}while((J|0)<(b|0))}else{break}}}while(0);VHb(e);j=lj(h,f)|0;i=d;return j|0}function Wp(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=qKb(c[e>>2]|0)|0;c[b+28>>2]=uKb(c[e>>2]|0)|0;c[b+52>>2]=(d[f+7|0]|0)>>>7&255;g=pIb(b+32|0,c[e>>2]|0,c[a+20>>2]|0)|0;if((g|0)<0){h=g;return h|0}c[b+48>>2]=-(-(c[a+24>>2]|0)>>(d[f+6|0]|0));h=0;return h|0}function Xp(a){a=a|0;var b=0;b=c[a+44>>2]|0;VHb(b+12|0);VHb(b+16|0);return}function Yp(a){a=a|0;dl(a,Ok(1211280)|0);return 0}function Zp(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=c[d+44>>2]|0;if((c[f+8>>2]|0)==0){KIb(d,24,2609368,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}h=e+24|0;if((c[h>>2]|0)<2){KIb(d,16,2582560,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;j=-1094995529;i=b;return j|0}else{c[a+20>>2]=c[e+20>>2];c[a+24>>2]=c[h>>2];h=a+56|0;k=e+56|0;l=h;m=c[k>>2]|0;n=c[k+4>>2]|0;c[l>>2]=m;c[l+4>>2]=n;n=e+116|0;e=a+116|0;l=c[n+4>>2]|0;c[e>>2]=c[n>>2];c[e+4>>2]=l;c[h>>2]=m<<1;c[a+120>>2]=l<<1|0>>>31;l=a+156|0;c[l>>2]=c[l>>2]|1;KIb(d,40,2562400,(g=i,i=i+8|0,c[g>>2]=(c[f+4>>2]|0)==0?2285904:2195976,g)|0);i=g;j=0;i=b;return j|0}return 0}function _p(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=c[a+8>>2]|0;f=c[c[e+32>>2]>>2]|0;g=c[e+44>>2]|0;h=g+12|0;VHb(h);j=g+16|0;k=c[j>>2]|0;c[h>>2]=k;c[j>>2]=b;if((k|0)==0|(b|0)==0){l=0;i=d;return l|0}if((c[k+296>>2]|0)==0){k=c[g+4>>2]|0;g=bv(f,c[f+20>>2]|0,c[f+24>>2]|0)|0;if((g|0)==0){l=-12;i=d;return l|0}b=(k|0)==0|0;ZHb(g,c[h>>2]|0)|0;c[g+296>>2]=1;c[g+300>>2]=b;k=g+136|0;m=Crc(c[k>>2]|0,c[k+4>>2]|0,2,0)|0;c[k>>2]=m;c[k+4>>2]=G;$p(c[h>>2]|0,g,a,b^1);VHb(h);$p(c[j>>2]|0,g,a,b);VHb(j);l=lj(f,g)|0;i=d;return l|0}else{KIb(e,24,2544720,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;e=$Hb(c[h>>2]|0)|0;if((e|0)==0){l=-12;i=d;return l|0}h=e+136|0;g=Crc(c[h>>2]|0,c[h+4>>2]|0,2,0)|0;c[h>>2]=g;c[h+4>>2]=G;l=lj(f,e)|0;i=d;return l|0}return 0}function $p(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=i;j=f+52|0;k=qKb(c[j>>2]|0)|0;l=d[k+6|0]|0;m=k+4|0;if((a[m]|0)==0){i=h;return}k=f+24|0;n=f+20|0;f=(g|0)==0|0;o=(g|0)==1;g=0;while(1){p=c[k>>2]|0;if((g-1|0)>>>0<2>>>0){q=-(-p>>l)|0}else{q=p}p=oIb(c[j>>2]|0,c[n>>2]|0,g)|0;r=c[e+(g<<2)>>2]|0;s=c[b+(g<<2)>>2]|0;if(!((p|0)>-1)){t=6;break}u=q+f|0;v=(u|0)/2|0;w=c[b+32+(g<<2)>>2]|0;if(o){x=c[e+32+(g<<2)>>2]|0;y=r+x|0;z=s+w|0;A=x}else{y=r;z=s;A=c[e+32+(g<<2)>>2]|0}s=b+32+(g<<2)|0;r=w<<1;w=A<<1;a:do{if((u|0)>1&(p|0)>0){x=v;B=y;C=z;while(1){D=c[s>>2]|0;E=(x|0)==(v|0)?C:C+(-D|0)|0;F=(x|0)==1?C:C+D|0;D=0;do{a[B+D|0]=((d[E+D|0]|0)+1+(d[F+D|0]|0)+(d[C+D|0]<<1)|0)>>>2;D=D+1|0;}while((D|0)<(p|0));D=x-1|0;if((D|0)<=0){break a}x=D;B=B+w|0;C=C+r|0}}}while(0);r=g+1|0;if((r|0)<(d[m]|0)){g=r}else{t=16;break}}if((t|0)==6){KIb(0,0,2527064,(g=i,i=i+24|0,c[g>>2]=2511968,c[g+8>>2]=2497760,c[g+16>>2]=144,g)|0);i=g;Hd()}else if((t|0)==16){i=h;return}}function aq(a){a=a|0;kJb(c[(c[a+44>>2]|0)+36>>2]|0);return}function bq(a){a=a|0;dl(a,Ok(685496)|0);return 0}function cq(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0.0,Ca=0.0,Da=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=c[b+8>>2]|0;j=c[h+44>>2]|0;k=c[c[h+32>>2]>>2]|0;h=j+4|0;l=c[h>>2]|0;c[h>>2]=l+1;h=c[j+8>>2]|0;m=c[j+16>>2]|0;n=c[j+12>>2]|0;o=c[j+20>>2]|0;p=c[j+24>>2]|0;q=c[j+32>>2]|0;r=bv(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((r|0)==0){VHb(g);s=-12;i=f;return s|0}ZHb(r,e)|0;c[r+296>>2]=0;e=b+24|0;t=j+68|0;u=j+52|0;v=1-m|0;w=m+2|0;x=3-m|0;z=m-2|0;A=~m;B=m-4|0;C=-3-m|0;D=j+36|0;E=5-v|0;F=-5-v|0;G=(h|0)==0|(l|0)==0;l=(n|0)==0;n=(q|0)==0;q=b+52|0;b=(o|0)==0;o=(p|0)!=0;p=j+28|0;j=0;do{H=c[g>>2]|0;I=c[H+(j<<2)>>2]|0;if((I|0)==0){break}J=c[H+32+(j<<2)>>2]|0;if((J|0)==0){break}H=(j|0)==0;K=c[e>>2]|0;if(H){L=K}else{L=-(-K>>c[p>>2])|0}K=c[t+(j<<2)>>2]|0;M=c[u+(j<<2)>>2]|0;N=c[r+(j<<2)>>2]|0;O=c[r+32+(j<<2)>>2]|0;P=ca(J,v)|0;Q=I+P|0;R=ca(O,v)|0;if((L|0)>0){S=J<<1;T=O<<1;U=N+R|0;V=0;W=Q;while(1){nrc(U|0,W|0,K)|0;X=V+2|0;if((X|0)<(L|0)){U=U+T|0;V=X;W=W+S|0}else{Y=S;break}}}else{Y=J<<1}nrc(N+(ca(O,m)|0)|0,Q|0,K)|0;nrc(N+(ca(O,w)|0)|0,I+(ca(J,x)|0)|0,K)|0;nrc(N+(ca(O,z+L|0)|0)|0,I+(ca(J,L+A|0)|0)|0,K)|0;nrc(N+(ca(O,B+L|0)|0)|0,I+(ca(J,C+L|0)|0)|0,K)|0;S=D+(j<<2)|0;W=c[S>>2]|0;V=ca(M,E)|0;T=M<<1;U=M<<2;X=(J*5|0)-P|0;Z=J*3|0;_=J<<2;$=F+L|0;if((E|0)>($|0)){aa=W}else{ba=(K|0)>0;da=O<<1;ea=H?235:240;fa=H?-21:-128;ga=I+(X-_)|0;ha=I+(X+_)|0;_=N+((O*5|0)-R)|0;ia=I+(X+Z)|0;ja=I+(X-Z)|0;Z=I+(X+Y)|0;ka=I+(X-Y)|0;la=I+(X+J)|0;ma=I+(X-J)|0;na=E;oa=I+X|0;X=W+(V+U)|0;pa=W+(V-U)|0;U=W+(V+T)|0;qa=W+(V-T)|0;ra=W+(V+M)|0;sa=W+(V-M)|0;ta=W+V|0;while(1){if(ba){V=0;do{do{if(G){ua=19}else{W=a[oa+V|0]|0;va=(d[ta+V|0]|0)-(W&255)|0;if((((va|0)>-1?va:-va|0)|0)>(h|0)){ua=19;break}va=(d[sa+V|0]|0)-(d[ma+V|0]|0)|0;if((((va|0)>-1?va:-va|0)|0)>(h|0)){ua=19;break}va=(d[ra+V|0]|0)-(d[la+V|0]|0)|0;if((((va|0)>-1?va:-va|0)|0)>(h|0)){ua=19;break}a[_+V|0]=W;wa=V}}while(0);do{if((ua|0)==19){ua=0;if(!l){W=V&-4;if(!n){va=_+W|0;y=-1;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;wa=V|3;break}if((c[q>>2]|0)==1){va=_+W|0;y=-2132049685;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;wa=V|3;break}else{a[_+V|0]=fa;wa=V;break}}do{if(n){if((c[q>>2]|0)!=1){xa=16;ya=ea;break}xa=16;ya=(V&1|0)!=0?240:235}else{xa=0;ya=255}}while(0);va=(d[la+V|0]|0)+(d[ma+V|0]|0)|0;if(b){W=va<<3;if(o){za=W-(d[ka+V|0]|0)+((d[ta+V|0]|0)+(d[oa+V|0]|0)<<1)-(d[Z+V|0]|0)-(d[qa+V|0]|0)-(d[U+V|0]|0)|0}else{za=((d[ta+V|0]|0)<<1)+W-(d[qa+V|0]|0)-(d[U+V|0]|0)|0}W=za>>4;if((W|0)<(xa|0)){Aa=xa&255}else{Aa=((W|0)>(ya|0)?ya:W)&255}a[_+V|0]=Aa;wa=V;break}else{Ba=+(va|0)*.526;if(o){Ca=Ba+ +((d[ta+V|0]|0)+(d[oa+V|0]|0)|0)*.17- +((d[Z+V|0]|0)+(d[ka+V|0]|0)+(d[qa+V|0]|0)+(d[U+V|0]|0)|0)*.116- +((d[ia+V|0]|0)+(d[ja+V|0]|0)|0)*.026+ +((d[ha+V|0]|0)+(d[ga+V|0]|0)+(d[pa+V|0]|0)+(d[X+V|0]|0)|0)*.031}else{Ca=Ba+ +(d[ta+V|0]|0|0)*.17- +((d[U+V|0]|0)+(d[qa+V|0]|0)|0)*.116- +((d[ia+V|0]|0)+(d[ja+V|0]|0)|0)*.026+ +((d[pa+V|0]|0)<<1|0)*.031}va=~~Ca;if((va|0)<(xa|0)){Da=xa&255}else{Da=((va|0)>(ya|0)?ya:va)&255}a[_+V|0]=Da;wa=V;break}}}while(0);V=wa+1|0;}while((V|0)<(K|0))}V=na+2|0;if((V|0)>($|0)){break}else{ga=ga+Y|0;ha=ha+Y|0;_=_+da|0;ia=ia+Y|0;ja=ja+Y|0;Z=Z+Y|0;ka=ka+Y|0;la=la+Y|0;ma=ma+Y|0;na=V;oa=oa+Y|0;X=X+T|0;pa=pa+T|0;U=U+T|0;qa=qa+T|0;ra=ra+T|0;sa=sa+T|0;ta=ta+T|0}}aa=c[S>>2]|0}uIb(aa,M,c[(c[g>>2]|0)+(j<<2)>>2]|0,J,K,L);j=j+1|0;}while((j|0)<4);VHb(g);s=lj(k,r)|0;i=f;return s|0}function dq(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[(c[b+8>>2]|0)+44>>2]|0;f=b+52|0;g=qKb(c[f>>2]|0)|0;c[e+32>>2]=a[(qKb(c[f>>2]|0)|0)+7|0]&32;c[e+28>>2]=d[g+6|0]|0;g=e+36|0;h=b+20|0;i=sIb(g,e+52|0,c[h>>2]|0,c[b+24>>2]|0,c[f>>2]|0,16)|0;if((i|0)<0){j=i;return j|0}mrc(c[g>>2]|0,0,i|0)|0;i=pIb(e+68|0,c[f>>2]|0,c[h>>2]|0)|0;j=(i|0)<0?i:0;return j|0}function eq(a){a=a|0;return 0}function fq(a){a=a|0;var b=0;b=c[a+44>>2]|0;a=b+1044|0;TGb(c[a>>2]|0);c[a>>2]=0;mJb(b+1028|0);a=b+1048|0;TGb(c[a>>2]|0);c[a>>2]=0;mJb(b+1032|0);a=b+1052|0;TGb(c[a>>2]|0);c[a>>2]=0;mJb(b+1036|0);a=b+1056|0;TGb(c[a>>2]|0);c[a>>2]=0;mJb(b+1040|0);return}function gq(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;if((c[b+1128>>2]|0)==0){d=(c[b+1132>>2]|0)!=0?880:2022512}else{d=679584}dl(a,Ok(d)|0);return 0}function hq(a){a=a|0;c[(c[a+44>>2]|0)+1132>>2]=1;return 0}function iq(a){a=a|0;c[(c[a+44>>2]|0)+1128>>2]=1;return 0}function jq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+44|0;e=c[d>>2]|0;f=e+1140|0;KIb(a,48,2138488,(a=i,i=i+8|0,c[a>>2]=c[f>>2],a)|0);i=a;a=e+1028|0;e=0;while(1){if((e|0)>=4){g=0;h=7;break}if((e|0)==3){j=(c[f>>2]|0)!=0?2633072:2115016}else{j=2633072}k=rJb(j)|0;c[a+(e<<2)>>2]=k;if((k|0)==0){break}else{e=e+1|0}}if((h|0)==7){i=b;return g|0}h=c[d>>2]|0;d=h+1044|0;TGb(c[d>>2]|0);c[d>>2]=0;mJb(h+1028|0);d=h+1048|0;TGb(c[d>>2]|0);c[d>>2]=0;mJb(h+1032|0);d=h+1052|0;TGb(c[d>>2]|0);c[d>>2]=0;mJb(h+1036|0);d=h+1056|0;TGb(c[d>>2]|0);c[d>>2]=0;mJb(h+1040|0);g=-12;i=b;return g|0}function kq(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=c[b+8>>2]|0;j=c[h+44>>2]|0;k=c[c[h+32>>2]>>2]|0;do{if((bIb(e)|0)==0){h=bv(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((h|0)!=0){ZHb(h,c[g>>2]|0)|0;l=h;m=0;break}VHb(g);n=-12;i=f;return n|0}else{l=e;m=1}}while(0);a:do{if((c[j+1128>>2]|0)==0){e=j+1064|0;h=j+1060|0;o=b+24|0;p=b+20|0;q=j+4|0;r=0;s=c[g>>2]|0;while(1){t=c[s+(r<<2)>>2]|0;if((t|0)==0){break a}if((c[s+32+(r<<2)>>2]|0)==0){break a}if((r-1|0)>>>0<2>>>0){u=c[h>>2]|0;v=c[e>>2]|0}else{u=0;v=0}w=-(c[o>>2]|0)>>v;x=-w|0;y=-(c[p>>2]|0)>>u;z=-y|0;do{if((w|0)<0){A=l+32+(r<<2)|0;if((y|0)<0){B=0;C=c[l+(r<<2)>>2]|0;D=t}else{E=s;break}while(1){F=0;do{a[C+F|0]=a[(d[D+F|0]|0)+(q+(r<<8))|0]|0;F=F+1|0;}while((F|0)<(z|0));F=c[g>>2]|0;G=B+1|0;if((G|0)<(x|0)){B=G;C=C+(c[A>>2]|0)|0;D=D+(c[F+32+(r<<2)>>2]|0)|0}else{E=F;break}}}else{E=s}}while(0);x=r+1|0;if((x|0)<4){r=x;s=E}else{break}}}else{s=c[g>>2]|0;if((c[s+72>>2]|0)<=0){break}r=b+20|0;q=l+32|0;p=j+1136|0;o=1;e=c[l>>2]|0;h=c[s>>2]|0;x=s;while(1){s=c[r>>2]|0;if((s|0)>0){z=0;t=e;y=h;w=c[p>>2]|0;while(1){if((w|0)==4){a[t+3|0]=a[j+((d[y+3|0]|0)+772)|0]|0;H=13}else if((w|0)==2){H=14}else if((w|0)==3){H=13}if((H|0)==13){H=0;a[t+2|0]=a[j+((d[y+2|0]|0)+516)|0]|0;H=14}if((H|0)==14){H=0;a[t+1|0]=a[j+((d[y+1|0]|0)+260)|0]|0}a[t]=a[j+((d[y]|0)+4)|0]|0;A=c[p>>2]|0;F=z+1|0;if((F|0)<(s|0)){z=F;t=t+A|0;y=y+A|0;w=A}else{break}}I=c[g>>2]|0}else{I=x}if((o|0)>=(c[I+72>>2]|0)){break a}o=o+1|0;e=e+(c[q>>2]|0)|0;h=h+(c[I+32>>2]|0)|0;x=I}}}while(0);if((m|0)==0){VHb(g)}n=lj(k,l)|0;i=f;return n|0}function lq(b){b=b|0;var e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0.0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+40|0;f=e|0;g=e+8|0;j=e+24|0;l=c[b+8>>2]|0;m=c[l+44>>2]|0;n=b+52|0;o=qKb(c[n>>2]|0)|0;c[m+1060>>2]=d[o+5|0]|0;c[m+1064>>2]=d[o+6|0]|0;p=m+1072|0;h[p>>3]=+(c[b+20>>2]|0);h[m+1080>>3]=+(c[b+24>>2]|0);switch(c[n>>2]|0){case 6:case 7:case 0:case 4:case 33:case 5:case 35:case 300:case 299:{c[g+8>>2]=16;c[g+4>>2]=16;c[g>>2]=16;c[j>>2]=235;c[j+8>>2]=240;c[j+4>>2]=240;c[g+12>>2]=0;c[j+12>>2]=255;break};default:{mrc(g|0,0,16)|0;c[j+12>>2]=255;c[j+8>>2]=255;c[j+4>>2]=255;c[j>>2]=255}}b=m+1128|0;c[b>>2]=0;q=m+1132|0;c[q>>2]=0;do{if((Nk(c[n>>2]|0,880)|0)==0){if((Nk(c[n>>2]|0,679584)|0)==0){r=8;break}c[b>>2]=1;r=9}else{c[q>>2]=1;r=8}}while(0);if((r|0)==8){if((c[b>>2]|0)!=0){r=9}}if((r|0)==9){Kz(f|0,c[n>>2]|0)|0;c[m+1136>>2]=(oKb(o)|0)>>3}n=o+4|0;if((a[n]|0)==0){s=0;i=e;return s|0}o=m+1044|0;q=m+1028|0;t=l;l=m+1096|0;u=m+1104|0;v=m+1088|0;w=m+1120|0;x=m+1112|0;y=m+4|0;z=0;a:while(1){if((c[b>>2]|0)==0){A=z}else{A=d[f+z|0]|0}B=o+(z<<2)|0;TGb(c[B>>2]|0);c[B>>2]=0;C=q+(z<<2)|0;if((UGb(B,c[C>>2]|0,281520,1204144,1204160,0,0,0,t)|0)<0){r=15;break}D=c[j+(z<<2)>>2]|0;h[l>>3]=+(D|0);E=c[g+(z<<2)>>2]|0;h[u>>3]=+(E|0);F=+(D+E|0);G=0;while(1){H=+(G|0);h[v>>3]=H;if((G|0)<(E|0)){I=E}else{I=(G|0)>(D|0)?D:G}h[w>>3]=+(I|0);J=~~(F-H);if((J|0)<(E|0)){K=E}else{K=(J|0)>(D|0)?D:J}h[x>>3]=+(K|0);H=+XGb(c[B>>2]|0,p,m);h[k>>3]=H;J=c[k+4>>2]&2147483647;L=2146435072;if(J>>>0>L>>>0|J>>>0==L>>>0&(c[k>>2]|0)>>>0>0>>>0){r=22;break a}L=~~H;if((L|0)<(E|0)){M=E}else{M=(L|0)>(D|0)?D:L}a[y+(A<<8)+G|0]=M;KIb(t,48,2320712,(N=i,i=i+24|0,c[N>>2]=A,c[N+8>>2]=G,c[N+16>>2]=M&255,N)|0);i=N;L=G+1|0;if((L|0)<256){G=L}else{break}}D=z+1|0;if((D|0)<(d[n]|0)){z=D}else{s=0;r=27;break}}if((r|0)==15){KIb(t,16,2332144,(N=i,i=i+24|0,c[N>>2]=c[q+(A<<2)>>2],c[N+8>>2]=A,c[N+16>>2]=z,N)|0);i=N;s=-22;i=e;return s|0}else if((r|0)==22){KIb(t,16,2326464,(N=i,i=i+24|0,c[N>>2]=c[C>>2],c[N+8>>2]=G,c[N+16>>2]=A,N)|0);i=N;s=-22;i=e;return s|0}else if((r|0)==27){i=e;return s|0}return 0}function mq(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0.0;c=~~b;d=~~+h[a+1104>>3];e=~~+h[a+1096>>3];if((c|0)<(d|0)){f=d;g=+(f|0);return+g}f=(c|0)>(e|0)?e:c;g=+(f|0);return+g}function nq(a,b){a=a|0;b=+b;var c=0.0,d=0.0;c=+h[a+1104>>3];d=+h[a+1096>>3]-c;return+(c+d*+T(+((+h[a+1120>>3]-c)/d),+b))}function oq(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;d=i;i=i+632|0;e=d|0;f=d+16|0;j=d+24|0;k=d+32|0;l=d+40|0;m=d+552|0;n=d+568|0;o=b+44|0;p=c[o>>2]|0;q=p+8|0;r=c[q>>2]|0;if((r|0)==0){s=p;c[p+3145752>>2]=32;t=0;while(1){u=+(t|0)*.032258063554763794;v=0;do{w=+(v|0)*.032258063554763794;x=0;do{g[s+24+(t*49152|0)+(v*768|0)+(x*12|0)>>2]=u;g[s+24+(t*49152|0)+(v*768|0)+(x*12|0)+4>>2]=w;g[s+24+(t*49152|0)+(v*768|0)+(x*12|0)+8>>2]=+(x|0)*.032258063554763794;x=x+1|0;}while((x|0)<32);v=v+1|0;}while((v|0)<32);v=t+1|0;if((v|0)<32){t=v}else{y=0;break}}i=d;return y|0}t=Qc(r|0,2387024)|0;if((t|0)==0){r=-(c[(pd()|0)>>2]|0)|0;s=c[q>>2]|0;v=n|0;mrc(v|0,0,64)|0;a[v]=0;RGb(r,v,64)|0;KIb(b,16,238e4,(z=i,i=i+16|0,c[z>>2]=s,c[z+8>>2]=v,z)|0);i=z;y=r;i=d;return y|0}r=hc(c[q>>2]|0,46)|0;a:do{if((r|0)==0){KIb(b,16,2373736,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529}else{q=r+1|0;b:do{if((IFb(q,2365864)|0)==0){c[p+3145752>>2]=33;v=l|0;s=c[o>>2]|0;n=c[s+3145752>>2]|0;if((n|0)<=0){break}x=s+24|0;s=0;c:while(1){B=0;do{C=0;do{if((Yb(v|0,512,t|0)|0)==0){break c}else{D=v}while(1){E=a[D]|0;if(!(E<<24>>24==0)){if((OFb(E<<24>>24)|0)!=0){D=D+1|0;continue}E=a[D]|0;if(!((E<<24>>24|0)==0|(E<<24>>24|0)==35)){break}}if((Yb(v|0,512,t|0)|0)==0){break c}else{D=v}}Bd(v|0,2283760,(z=i,i=i+24|0,c[z>>2]=x+(s*49152|0)+(B*768|0)+(C*12|0),c[z+8>>2]=x+(s*49152|0)+(B*768|0)+(C*12|0)+4,c[z+16>>2]=x+(s*49152|0)+(B*768|0)+(C*12|0)+8,z)|0)|0;i=z;C=C+1|0;}while((C|0)<(n|0));B=B+1|0;}while((B|0)<(n|0));s=s+1|0;if((s|0)>=(n|0)){break b}}KIb(b,16,2289320,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}else{if((IFb(q,2350944)|0)==0){n=l|0;s=c[o>>2]|0;c[s+3145752>>2]=17;d:do{if((Yb(n|0,512,t|0)|0)!=0){x=n;while(1){v=a[x]|0;if(!(v<<24>>24==0)){if((OFb(v<<24>>24)|0)!=0){x=x+1|0;continue}v=a[x]|0;if(!((v<<24>>24|0)==0|(v<<24>>24|0)==35)){break}}if((Yb(n|0,512,t|0)|0)==0){break d}else{x=n}}x=s+24|0;v=0;e:while(1){B=0;do{C=0;do{if((Yb(n|0,512,t|0)|0)==0){break e}else{F=n}while(1){E=a[F]|0;if(!(E<<24>>24==0)){if((OFb(E<<24>>24)|0)!=0){F=F+1|0;continue}E=a[F]|0;if(!((E<<24>>24|0)==0|(E<<24>>24|0)==35)){break}}if((Yb(n|0,512,t|0)|0)==0){break e}else{F=n}}E=Bd(n|0,2254656,(z=i,i=i+24|0,c[z>>2]=f,c[z+8>>2]=j,c[z+16>>2]=k,z)|0)|0;i=z;if((E|0)!=3){A=-1094995529;break a}g[x+(v*49152|0)+(B*768|0)+(C*12|0)>>2]=+(c[f>>2]|0)*.000244140625;g[x+(v*49152|0)+(B*768|0)+(C*12|0)+4>>2]=+(c[j>>2]|0)*.000244140625;g[x+(v*49152|0)+(B*768|0)+(C*12|0)+8>>2]=+(c[k>>2]|0)*.000244140625;C=C+1|0;}while((C|0)<17);B=B+1|0;}while((B|0)<17);v=v+1|0;if((v|0)>=17){break b}}KIb(b,16,2289320,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}}while(0);KIb(b,16,2289320,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}if((IFb(q,2343688)|0)==0){n=l|0;s=e;v=c[o>>2]|0;mrc(m|0,0,12)|0;c[s>>2]=c[183828];c[s+4>>2]=c[183829];c[s+8>>2]=c[183830];do{if((Yb(n|0,512,t|0)|0)==0){break b}}while((krc(n,2279912,12)|0)!=0);s=rb(l+12|0,0,0)|0;if((s-2|0)>>>0>62>>>0){KIb(b,16,2275696,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-22;break a}c[v+3145752>>2]=s;if((s|0)<=0){break}x=v+24|0;B=l+7|0;C=m|0;E=l+11|0;G=b;H=m+4|0;I=m+8|0;J=e|0;K=e+4|0;L=e+8|0;M=0;f:while(1){N=0;do{O=0;do{if((Yb(n|0,512,t|0)|0)==0){break f}while(1){if((krc(n,2271024,7)|0)==0){if((krc(B,2266496,4)|0)==0){P=C}else{Q=(krc(B,2262952,4)|0)==0;R=Q?J:0;if((R|0)==0){A=-1094995529;break a}else{P=R}}Bd(E|0,2283760,(z=i,i=i+24|0,c[z>>2]=P,c[z+8>>2]=P+4,c[z+16>>2]=P+8,z)|0)|0;i=z;u=+g[H>>2];w=+g[I>>2];S=+g[J>>2];T=+g[K>>2];U=+g[L>>2];KIb(G,48,2258976,(z=i,i=i+48|0,h[z>>3]=+g[C>>2],h[z+8>>3]=u,h[z+16>>3]=w,h[z+24>>3]=S,h[z+32>>3]=T,h[z+40>>3]=U,z)|0);i=z;V=n}else{V=n}while(1){R=a[V]|0;if(R<<24>>24==0){break}if((OFb(R<<24>>24)|0)==0){W=64;break}else{V=V+1|0}}if((W|0)==64){W=0;R=a[V]|0;if(!((R<<24>>24|0)==0|(R<<24>>24|0)==35)){break}}if((Yb(n|0,512,t|0)|0)==0){break f}}R=x+(O*49152|0)+(N*768|0)+(M*12|0)|0;Q=x+(O*49152|0)+(N*768|0)+(M*12|0)+4|0;X=x+(O*49152|0)+(N*768|0)+(M*12|0)+8|0;Y=Bd(n|0,2283760,(z=i,i=i+24|0,c[z>>2]=R,c[z+8>>2]=Q,c[z+16>>2]=X,z)|0)|0;i=z;if((Y|0)!=3){A=-1094995529;break a}g[R>>2]=+g[R>>2]*(+g[J>>2]- +g[C>>2]);g[Q>>2]=+g[Q>>2]*(+g[K>>2]- +g[H>>2]);g[X>>2]=+g[X>>2]*(+g[L>>2]- +g[I>>2]);O=O+1|0;}while((O|0)<(s|0));N=N+1|0;}while((N|0)<(s|0));M=M+1|0;if((M|0)>=(s|0)){break b}}KIb(G,16,2289320,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}if((IFb(q,2337680)|0)!=0){KIb(b,16,2332072,(z=i,i=i+8|0,c[z>>2]=q,z)|0);i=z;A=-22;break a}s=l|0;M=c[o>>2]|0;I=l+3|0;L=l+2|0;H=-1;K=-1;g:while(1){Z=H;h:while(1){while(1){if((Yb(s|0,512,t|0)|0)==0){_=0;$=1;aa=2;break g}if((krc(s,2320688,2)|0)==0){break h}if((krc(s,2315880,3)|0)==0){break}if((krc(s,2311344,6)|0)==0){W=80;break g}}Z=rb(I|0,0,0)|0}H=Z;K=rb(L|0,0,0)|0}i:do{if((W|0)==80){L=l+6|0;while(1){if((OFb(a[L]|0)|0)==0){break}else{L=L+1|0}}H=a[L]|0;I=H<<24>>24;if((I|0)==103){ba=1}else if((I|0)==98){ba=2}else{ba=0}j:do{if(H<<24>>24==0){da=L}else{I=H;G=L;while(1){C=G+1|0;if((OFb(I<<24>>24)|0)!=0){da=G;break j}J=a[C]|0;if(J<<24>>24==0){da=C;break}else{I=J;G=C}}}}while(0);while(1){if((OFb(a[da]|0)|0)==0){break}da=da+1|0}L=a[da]|0;H=L<<24>>24;if((H|0)==114){ea=0}else if((H|0)==98){ea=2}else{ea=1}k:do{if(L<<24>>24==0){fa=da}else{H=L;G=da;while(1){I=G+1|0;if((OFb(H<<24>>24)|0)!=0){fa=G;break k}C=a[I]|0;if(C<<24>>24==0){fa=I;break}else{H=C;G=I}}}}while(0);while(1){if((OFb(a[fa]|0)|0)==0){break}fa=fa+1|0}L=a[fa]|0;G=L<<24>>24;if((G|0)==114){ga=0}else if((G|0)==103){ga=1}else{ga=2}if(L<<24>>24==0){_=ba;$=ea;aa=ga;break}else{ha=L;ia=fa}while(1){L=ia+1|0;if((OFb(ha<<24>>24)|0)!=0){_=ba;$=ea;aa=ga;break i}G=a[L]|0;if(G<<24>>24==0){_=ba;$=ea;aa=ga;break}else{ha=G;ia=L}}}}while(0);if((K|0)==-1|(Z|0)==-1){KIb(b,16,2306760,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}if((K|0)<2|(Z|0)<2|(K|0)>262144|(Z|0)>262144){KIb(b,16,2300480,(z=i,i=i+16|0,c[z>>2]=K,c[z+8>>2]=Z,z)|0);i=z;A=-1094995529;break a}else{ja=1}while(1){if((ca(ca(ja,ja)|0,ja)|0)<(K|0)){ja=ja+1|0}else{break}}c[M+3145752>>2]=ja;U=1.0/+(Z-1|0);if((ja|0)<=0){break}K=M+24|0;L=m|0;G=m+4|0;H=m+8|0;I=m+((_&255)<<2)|0;C=m+(($&255)<<2)|0;J=m+((aa&255)<<2)|0;n=0;l:while(1){x=0;do{E=0;do{if((Yb(s|0,512,t|0)|0)==0){break l}B=Bd(s|0,2283760,(z=i,i=i+24|0,c[z>>2]=L,c[z+8>>2]=G,c[z+16>>2]=H,z)|0)|0;i=z;if((B|0)!=3){A=-1094995529;break a}g[K+(n*49152|0)+(x*768|0)+(E*12|0)>>2]=U*+g[I>>2];g[K+(n*49152|0)+(x*768|0)+(E*12|0)+4>>2]=U*+g[C>>2];g[K+(n*49152|0)+(x*768|0)+(E*12|0)+8>>2]=U*+g[J>>2];E=E+1|0;}while((E|0)<(ja|0));x=x+1|0;}while((x|0)<(ja|0));n=n+1|0;if((n|0)>=(ja|0)){break b}}KIb(b,16,2289320,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;break a}}while(0);if((c[p+3145752>>2]|0)!=0){A=0;break}KIb(b,16,2326360,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529}}while(0);nb(t|0)|0;y=A;i=d;return y|0}function pq(a){a=a|0;dl(a,Ok(685432)|0);return 0}function qq(a){a=a|0;c[(c[a+44>>2]|0)+3146200>>2]=198;return 0}function rq(a){a=a|0;Vz((c[a+44>>2]|0)+3145776|0);return}function sq(a,b,f){a=a|0;b=b|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=c[c[a+16>>2]>>2]|0;i=c[a+44>>2]|0;a=i;j=c[f>>2]|0;k=c[f+32>>2]|0;f=c[i+3145768>>2]|0;l=c[i+3145760>>2]|0;m=i+3145756|0;n=c[i+3145752>>2]|0;o=(n|0)>0;if((c[i+3145764>>2]|0)==0){if(!o){p=h+8|0;q=c[p>>2]|0;r=tq(q,b)|0;return r|0}s=i+3145757|0;t=i+3145758|0;u=0;v=0;w=0;while(1){x=u;y=v;z=0;while(1){A=x;B=y;C=0;do{D=(ca(A,k)|0)+(ca(B,l)|0)|0;g[a+24+(w*49152|0)+(z*768|0)+(C*12|0)>>2]=+(d[j+((d[m]|0)+D)|0]|0|0)/255.0;g[a+24+(w*49152|0)+(z*768|0)+(C*12|0)+4>>2]=+(d[j+((d[s]|0)+D)|0]|0|0)/255.0;g[a+24+(w*49152|0)+(z*768|0)+(C*12|0)+8>>2]=+(d[j+((d[t]|0)+D)|0]|0|0)/255.0;D=B+1|0;E=(D|0)==(f|0);A=(E&1)+A|0;B=E?0:D;C=C+1|0;}while((C|0)<(n|0));C=z+1|0;if((C|0)<(n|0)){x=A;y=B;z=C}else{break}}z=w+1|0;if((z|0)<(n|0)){u=A;v=B;w=z}else{break}}p=h+8|0;q=c[p>>2]|0;r=tq(q,b)|0;return r|0}else{if(!o){p=h+8|0;q=c[p>>2]|0;r=tq(q,b)|0;return r|0}o=i+3145757|0;w=i+3145758|0;i=0;B=0;v=0;while(1){A=0;u=B;t=v;while(1){s=0;F=u;G=t;do{z=j+((ca(F,l)|0)+(ca(G,k)|0))|0;g[a+24+(i*49152|0)+(A*768|0)+(s*12|0)>>2]=+(e[z+((d[m]|0)<<1)>>1]|0|0)/65535.0;g[a+24+(i*49152|0)+(A*768|0)+(s*12|0)+4>>2]=+(e[z+((d[o]|0)<<1)>>1]|0|0)/65535.0;g[a+24+(i*49152|0)+(A*768|0)+(s*12|0)+8>>2]=+(e[z+((d[w]|0)<<1)>>1]|0|0)/65535.0;z=F+1|0;y=(z|0)==(f|0);F=y?0:z;G=(y&1)+G|0;s=s+1|0;}while((s|0)<(n|0));s=A+1|0;if((s|0)<(n|0)){A=s;u=F;t=G}else{break}}t=i+1|0;if((t|0)<(n|0)){i=t;B=F;v=G}else{break}}p=h+8|0;q=c[p>>2]|0;r=tq(q,b)|0;return r|0}return 0}function tq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+44>>2]|0;h=c[c[a+32>>2]>>2]|0;do{if((bIb(b)|0)==0){j=h+24|0;k=bv(h,c[h+20>>2]|0,c[j>>2]|0)|0;if((k|0)!=0){ZHb(k,c[e>>2]|0)|0;l=k;m=c[e>>2]|0;n=j;break}VHb(e);o=0;i=d;return o|0}else{l=b;m=b;n=h+24|0}}while(0);c[f>>2]=m;c[f+4>>2]=l;m=c[n>>2]|0;n=c[(c[a+48>>2]|0)+28>>2]|0;Xe[c[c[a+56>>2]>>2]&511](a,c[g+20>>2]|0,f,0,(m|0)>(n|0)?n:m)|0;if((l|0)==(c[e>>2]|0)){o=l;i=d;return o|0}VHb(e);o=l;i=d;return o|0}function uq(a){a=a|0;return Uz((c[(c[a>>2]|0)+44>>2]|0)+3145776|0,a)|0}function vq(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=c[c[b+16>>2]>>2]|0;c[a+20>>2]=c[e+20>>2];c[a+24>>2]=c[e+24>>2];f=e+56|0;e=a+56|0;a=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=a;a=Rz(b,d+3145776|0)|0;return((a|0)<0?a:0)|0}function wq(a,b){a=a|0;b=b|0;return Tz((c[(c[a+8>>2]|0)+44>>2]|0)+3145776|0,a,b)|0}function xq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;a=qKb(c[e>>2]|0)|0;f=c[e>>2]|0;if((f|0)==42|(f|0)==68|(f|0)==292|(f|0)==294){g=1}else{g=0}Kz(d+12|0,f)|0;c[d+16>>2]=(pKb(a)|0)>>g+3;a=c[d+4>>2]|0;if((a|0)==2){f=d+20|0;if((g|0)==0){c[f>>2]=220;i=b;return 0}else{c[f>>2]=482;i=b;return 0}}else if((a|0)==1){f=d+20|0;if((g|0)==0){c[f>>2]=216;i=b;return 0}else{c[f>>2]=726;i=b;return 0}}else if((a|0)==0){a=d+20|0;if((g|0)==0){c[a>>2]=438;i=b;return 0}else{c[a>>2]=744;i=b;return 0}}else{KIb(0,0,2427464,(b=i,i=i+24|0,c[b>>2]=2393912,c[b+8>>2]=2408320,c[b+16>>2]=492,b)|0);i=b;Hd();return 0}return 0}function yq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=a+52|0;g=qKb(c[f>>2]|0)|0;h=e+3145764|0;c[h>>2]=0;j=c[f>>2]|0;if((j|0)==42|(j|0)==68|(j|0)==292|(j|0)==294){c[h>>2]=1}c[e+3145760>>2]=(pKb(g)|0)>>3;Kz(e+3145756|0,c[f>>2]|0)|0;f=a+20|0;g=c[f>>2]|0;h=a+24|0;a=c[h>>2]|0;do{if((g|0)>(a|0)){KIb(d,32,2465888,(k=i,i=i+8|0,c[k>>2]=g-a,k)|0);i=k}else{if((g|0)>=(a|0)){break}KIb(d,32,2455344,(k=i,i=i+8|0,c[k>>2]=a-g,k)|0);i=k}}while(0);g=c[f>>2]|0;f=c[h>>2]|0;h=(g|0)>(f|0)?f:g;c[e+3145768>>2]=h;g=1;while(1){l=ca(g,g)|0;m=ca(l,g)|0;if((m|0)<(h|0)){g=g+1|0}else{break}}if((m|0)!=(h|0)){KIb(d,24,2438168,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;n=-1094995529;i=b;return n|0}if(l>>>0>64>>>0){KIb(d,16,2400832,(k=i,i=i+24|0,c[k>>2]=8,c[k+8>>2]=512,c[k+16>>2]=512,k)|0);i=k;n=-22;i=b;return n|0}else{c[e+3145752>>2]=l;n=0;i=b;return n|0}return 0}function zq(a,f,h,i){a=a|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0;j=c[a+44>>2]|0;a=j;k=c[f>>2]|0;l=c[f+4>>2]|0;f=c[j+16>>2]|0;m=c[k+72>>2]|0;n=(ca(m,h)|0)/(i|0)|0;o=(ca(m,h+1|0)|0)/(i|0)|0;if((n|0)>=(o|0)){return 0}i=c[k+32>>2]|0;h=c[l+32>>2]|0;m=ca(i,n)|0;p=ca(h,n)|0;q=j+3145752|0;r=d[j+12|0]|0;s=d[j+13|0]|0;t=d[j+14|0]|0;u=(l|0)!=(k|0)&(f|0)==4;v=d[j+15|0]|0;j=c[k+68>>2]|0;w=(c[k>>2]|0)+m|0;m=(c[l>>2]|0)+p|0;p=n;while(1){n=m;l=w;k=ca(j,f)|0;if((k|0)>0){x=c[q>>2]|0;y=0;do{z=+(x-1|0)*15259021896696422.0e-21;A=y+r|0;B=y+s|0;C=y+t|0;D=~~(z*+(e[l+(C<<1)>>1]|0|0)+.5);E=~~(+(e[l+(B<<1)>>1]|0|0)*z+.5);F=~~(+(e[l+(A<<1)>>1]|0|0)*z+.5);z=+g[a+24+(F*49152|0)+(E*768|0)+(D*12|0)+4>>2];G=+g[a+24+(F*49152|0)+(E*768|0)+(D*12|0)+8>>2];H=~~(+g[a+24+(F*49152|0)+(E*768|0)+(D*12|0)>>2]*65535.0);if(H>>>0>65535>>>0){I=-H>>31&65535}else{I=H&65535}b[n+(A<<1)>>1]=I;A=~~(z*65535.0);if(A>>>0>65535>>>0){J=-A>>31&65535}else{J=A&65535}b[n+(B<<1)>>1]=J;B=~~(G*65535.0);if(B>>>0>65535>>>0){K=-B>>31&65535}else{K=B&65535}b[n+(C<<1)>>1]=K;if(u){C=y+v|0;b[n+(C<<1)>>1]=b[l+(C<<1)>>1]|0}y=y+f|0;}while((y|0)<(k|0))}k=p+1|0;if((k|0)<(o|0)){w=w+i|0;m=m+h|0;p=k}else{break}}return 0}function Aq(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=c[b+44>>2]|0;b=i;j=c[e>>2]|0;k=c[e+4>>2]|0;e=c[i+16>>2]|0;l=c[j+72>>2]|0;m=(ca(l,f)|0)/(h|0)|0;n=(ca(l,f+1|0)|0)/(h|0)|0;h=k+32|0;f=j+32|0;if((m|0)>=(n|0)){return 0}l=c[f>>2]|0;o=c[h>>2]|0;p=ca(l,m)|0;q=ca(o,m)|0;r=j+68|0;s=i+3145752|0;t=d[i+12|0]|0;u=d[i+13|0]|0;v=d[i+14|0]|0;w=(k|0)!=(j|0)&(e|0)==4;x=d[i+15|0]|0;i=(c[j>>2]|0)+p|0;p=(c[k>>2]|0)+q|0;q=m;m=c[r>>2]|0;k=o;o=l;while(1){if((ca(m,e)|0)>0){l=0;do{y=+((c[s>>2]|0)-1|0)*.00392156862745098;j=l+t|0;z=l+u|0;A=l+v|0;B=~~(y*+(d[i+A|0]|0|0)+.5);C=~~(+(d[i+z|0]|0|0)*y+.5);D=~~(+(d[i+j|0]|0|0)*y+.5);y=+g[b+24+(D*49152|0)+(C*768|0)+(B*12|0)+4>>2];E=+g[b+24+(D*49152|0)+(C*768|0)+(B*12|0)+8>>2];F=~~(+g[b+24+(D*49152|0)+(C*768|0)+(B*12|0)>>2]*255.0);if(F>>>0>255>>>0){G=-F>>31&255}else{G=F&255}a[p+j|0]=G;j=~~(y*255.0);if(j>>>0>255>>>0){H=-j>>31&255}else{H=j&255}a[p+z|0]=H;z=~~(E*255.0);if(z>>>0>255>>>0){I=-z>>31&255}else{I=z&255}a[p+A|0]=I;if(w){A=l+x|0;a[p+A|0]=a[i+A|0]|0}l=l+e|0;J=c[r>>2]|0;}while((l|0)<(ca(J,e)|0));K=J;L=c[h>>2]|0;M=c[f>>2]|0}else{K=m;L=k;M=o}l=q+1|0;if((l|0)<(n|0)){i=i+M|0;p=p+L|0;q=l;m=K;k=L;o=M}else{break}}return 0}function Bq(a,f,h,j){a=a|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+16|0;l=k|0;m=c[a+44>>2]|0;a=m;n=c[f>>2]|0;o=c[f+4>>2]|0;f=c[m+16>>2]|0;p=c[n+72>>2]|0;q=(ca(p,h)|0)/(j|0)|0;r=(ca(p,h+1|0)|0)/(j|0)|0;j=o+32|0;h=n+32|0;if((q|0)>=(r|0)){i=k;return 0}p=c[h>>2]|0;s=c[j>>2]|0;t=ca(p,q)|0;u=ca(s,q)|0;v=n+68|0;w=m+3145752|0;x=d[m+12|0]|0;y=d[m+13|0]|0;z=d[m+14|0]|0;A=l|0;B=l+4|0;C=l+8|0;D=(o|0)!=(n|0)&(f|0)==4;E=d[m+15|0]|0;m=(c[n>>2]|0)+t|0;t=(c[o>>2]|0)+u|0;u=q;q=c[v>>2]|0;o=s;s=p;while(1){p=t;n=m;if((ca(q,f)|0)>0){F=0;do{G=+((c[w>>2]|0)-1|0)*15259021896696422.0e-21;H=F+x|0;I=F+y|0;J=F+z|0;Gq(l,a,+(e[n+(H<<1)>>1]|0|0)*G,+(e[n+(I<<1)>>1]|0|0)*G,G*+(e[n+(J<<1)>>1]|0|0));K=~~(+g[A>>2]*65535.0);if(K>>>0>65535>>>0){L=-K>>31&65535}else{L=K&65535}b[p+(H<<1)>>1]=L;H=~~(+g[B>>2]*65535.0);if(H>>>0>65535>>>0){M=-H>>31&65535}else{M=H&65535}b[p+(I<<1)>>1]=M;I=~~(+g[C>>2]*65535.0);if(I>>>0>65535>>>0){N=-I>>31&65535}else{N=I&65535}b[p+(J<<1)>>1]=N;if(D){J=F+E|0;b[p+(J<<1)>>1]=b[n+(J<<1)>>1]|0}F=F+f|0;O=c[v>>2]|0;}while((F|0)<(ca(O,f)|0));P=O;Q=c[j>>2]|0;R=c[h>>2]|0}else{P=q;Q=o;R=s}F=u+1|0;if((F|0)<(r|0)){m=m+R|0;t=t+Q|0;u=F;q=P;o=Q;s=R}else{break}}i=k;return 0}function Cq(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=i;i=i+16|0;k=j|0;l=c[b+44>>2]|0;b=l;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[l+16>>2]|0;o=c[m+72>>2]|0;p=(ca(o,f)|0)/(h|0)|0;q=(ca(o,f+1|0)|0)/(h|0)|0;h=n+32|0;f=m+32|0;if((p|0)>=(q|0)){i=j;return 0}o=c[f>>2]|0;r=c[h>>2]|0;s=ca(o,p)|0;t=ca(r,p)|0;u=m+68|0;v=l+3145752|0;w=d[l+12|0]|0;x=d[l+13|0]|0;y=d[l+14|0]|0;z=k|0;A=k+4|0;B=k+8|0;C=(n|0)!=(m|0)&(e|0)==4;D=d[l+15|0]|0;l=(c[m>>2]|0)+s|0;s=(c[n>>2]|0)+t|0;t=p;p=c[u>>2]|0;n=r;r=o;while(1){if((ca(p,e)|0)>0){o=0;do{E=+((c[v>>2]|0)-1|0)*.00392156862745098;m=o+w|0;F=o+x|0;G=o+y|0;Gq(k,b,+(d[l+m|0]|0|0)*E,+(d[l+F|0]|0|0)*E,E*+(d[l+G|0]|0|0));H=~~(+g[z>>2]*255.0);if(H>>>0>255>>>0){I=-H>>31&255}else{I=H&255}a[s+m|0]=I;m=~~(+g[A>>2]*255.0);if(m>>>0>255>>>0){J=-m>>31&255}else{J=m&255}a[s+F|0]=J;F=~~(+g[B>>2]*255.0);if(F>>>0>255>>>0){K=-F>>31&255}else{K=F&255}a[s+G|0]=K;if(C){G=o+D|0;a[s+G|0]=a[l+G|0]|0}o=o+e|0;L=c[u>>2]|0;}while((o|0)<(ca(L,e)|0));M=L;N=c[h>>2]|0;O=c[f>>2]|0}else{M=p;N=n;O=r}o=t+1|0;if((o|0)<(q|0)){l=l+O|0;s=s+N|0;t=o;p=M;n=N;r=O}else{break}}i=j;return 0}function Dq(a,f,h,j){a=a|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+16|0;l=k|0;m=c[a+44>>2]|0;a=m;n=c[f>>2]|0;o=c[f+4>>2]|0;f=c[m+16>>2]|0;p=c[n+72>>2]|0;q=(ca(p,h)|0)/(j|0)|0;r=(ca(p,h+1|0)|0)/(j|0)|0;j=o+32|0;h=n+32|0;if((q|0)>=(r|0)){i=k;return 0}p=c[h>>2]|0;s=c[j>>2]|0;t=ca(p,q)|0;u=ca(s,q)|0;v=n+68|0;w=m+3145752|0;x=d[m+12|0]|0;y=d[m+13|0]|0;z=d[m+14|0]|0;A=l|0;B=l+4|0;C=l+8|0;D=(o|0)!=(n|0)&(f|0)==4;E=d[m+15|0]|0;m=(c[n>>2]|0)+t|0;t=(c[o>>2]|0)+u|0;u=q;q=c[v>>2]|0;o=s;s=p;while(1){p=t;n=m;if((ca(q,f)|0)>0){F=0;do{G=+((c[w>>2]|0)-1|0)*15259021896696422.0e-21;H=F+x|0;I=F+y|0;J=F+z|0;Fq(l,a,+(e[n+(H<<1)>>1]|0|0)*G,+(e[n+(I<<1)>>1]|0|0)*G,G*+(e[n+(J<<1)>>1]|0|0));K=~~(+g[A>>2]*65535.0);if(K>>>0>65535>>>0){L=-K>>31&65535}else{L=K&65535}b[p+(H<<1)>>1]=L;H=~~(+g[B>>2]*65535.0);if(H>>>0>65535>>>0){M=-H>>31&65535}else{M=H&65535}b[p+(I<<1)>>1]=M;I=~~(+g[C>>2]*65535.0);if(I>>>0>65535>>>0){N=-I>>31&65535}else{N=I&65535}b[p+(J<<1)>>1]=N;if(D){J=F+E|0;b[p+(J<<1)>>1]=b[n+(J<<1)>>1]|0}F=F+f|0;O=c[v>>2]|0;}while((F|0)<(ca(O,f)|0));P=O;Q=c[j>>2]|0;R=c[h>>2]|0}else{P=q;Q=o;R=s}F=u+1|0;if((F|0)<(r|0)){m=m+R|0;t=t+Q|0;u=F;q=P;o=Q;s=R}else{break}}i=k;return 0}function Eq(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=i;i=i+16|0;k=j|0;l=c[b+44>>2]|0;b=l;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[l+16>>2]|0;o=c[m+72>>2]|0;p=(ca(o,f)|0)/(h|0)|0;q=(ca(o,f+1|0)|0)/(h|0)|0;h=n+32|0;f=m+32|0;if((p|0)>=(q|0)){i=j;return 0}o=c[f>>2]|0;r=c[h>>2]|0;s=ca(o,p)|0;t=ca(r,p)|0;u=m+68|0;v=l+3145752|0;w=d[l+12|0]|0;x=d[l+13|0]|0;y=d[l+14|0]|0;z=k|0;A=k+4|0;B=k+8|0;C=(n|0)!=(m|0)&(e|0)==4;D=d[l+15|0]|0;l=(c[m>>2]|0)+s|0;s=(c[n>>2]|0)+t|0;t=p;p=c[u>>2]|0;n=r;r=o;while(1){if((ca(p,e)|0)>0){o=0;do{E=+((c[v>>2]|0)-1|0)*.00392156862745098;m=o+w|0;F=o+x|0;G=o+y|0;Fq(k,b,+(d[l+m|0]|0|0)*E,+(d[l+F|0]|0|0)*E,E*+(d[l+G|0]|0|0));H=~~(+g[z>>2]*255.0);if(H>>>0>255>>>0){I=-H>>31&255}else{I=H&255}a[s+m|0]=I;m=~~(+g[A>>2]*255.0);if(m>>>0>255>>>0){J=-m>>31&255}else{J=m&255}a[s+F|0]=J;F=~~(+g[B>>2]*255.0);if(F>>>0>255>>>0){K=-F>>31&255}else{K=F&255}a[s+G|0]=K;if(C){G=o+D|0;a[s+G|0]=a[l+G|0]|0}o=o+e|0;L=c[u>>2]|0;}while((o|0)<(ca(L,e)|0));M=L;N=c[h>>2]|0;O=c[f>>2]|0}else{M=p;N=n;O=r}o=t+1|0;if((o|0)<(q|0)){l=l+O|0;s=s+N|0;t=o;p=M;n=N;r=O}else{break}}i=j;return 0}function Fq(a,b,d,e,f){a=a|0;b=b|0;d=+d;e=+e;f=+f;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0,C=0,D=0,E=0.0,F=0.0,G=0.0;h=~~d;i=~~e;j=~~f;k=h+1|0;l=(c[b+3145752>>2]|0)-1|0;m=(k|0)>(l|0)?l:k;k=i+1|0;n=(k|0)>(l|0)?l:k;k=j+1|0;o=(k|0)>(l|0)?l:k;p=d- +(h|0);d=e- +(i|0);e=f- +(j|0);f=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)>>2];q=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)+4>>2];r=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)+8>>2];s=+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)>>2];t=+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)+4>>2];u=+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)+8>>2];if(p>d){if(d>e){v=1.0-p;w=p-d;x=d-e;y=e*u+(v*r+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+8>>2]+x*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+8>>2]);z=e*t+(v*q+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+4>>2]+x*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+4>>2]);A=e*s+(v*f+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)>>2]+x*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}if(p>e){x=1.0-p;w=p-e;v=e-d;y=d*u+(x*r+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+8>>2]+v*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+8>>2]);z=d*t+(x*q+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+4>>2]+v*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+4>>2]);A=d*s+(x*f+w*+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)>>2]+v*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}else{v=1.0-e;w=e-p;x=p-d;y=d*u+(v*r+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+8>>2]+x*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+8>>2]);z=d*t+(v*q+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+4>>2]+x*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+4>>2]);A=d*s+(v*f+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)>>2]+x*+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}}else{if(e>d){x=1.0-e;w=e-d;v=d-p;y=p*u+(x*r+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+8>>2]+v*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+8>>2]);z=p*t+(x*q+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+4>>2]+v*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+4>>2]);A=p*s+(x*f+w*+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)>>2]+v*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}v=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)>>2];w=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)+4>>2];x=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)+8>>2];if(e>p){E=1.0-d;F=d-e;G=e-p;y=p*u+(E*r+F*x+G*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+8>>2]);z=p*t+(E*q+F*w+G*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+4>>2]);A=p*s+(E*f+F*v+G*+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}else{G=1.0-d;F=d-p;d=p-e;y=e*u+(G*r+F*x+d*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+8>>2]);z=e*t+(G*q+F*w+d*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+4>>2]);A=e*s+(G*f+F*v+d*+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)>>2]);B=a|0;g[B>>2]=A;C=a+4|0;g[C>>2]=z;D=a+8|0;g[D>>2]=y;return}}}function Gq(a,b,d,e,f){a=a|0;b=b|0;d=+d;e=+e;f=+f;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0;h=~~d;i=~~e;j=~~f;k=h+1|0;l=(c[b+3145752>>2]|0)-1|0;m=(k|0)>(l|0)?l:k;k=i+1|0;n=(k|0)>(l|0)?l:k;k=j+1|0;o=(k|0)>(l|0)?l:k;p=d- +(h|0);d=e- +(i|0);e=f- +(j|0);f=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)>>2];q=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)+4>>2];r=+g[b+24+(h*49152|0)+(i*768|0)+(j*12|0)+8>>2];s=+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)>>2];t=+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+4>>2];u=+g[b+24+(h*49152|0)+(i*768|0)+(o*12|0)+8>>2];v=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)>>2];w=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)+4>>2];x=+g[b+24+(h*49152|0)+(n*768|0)+(j*12|0)+8>>2];y=+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)>>2];z=+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+4>>2];A=+g[b+24+(h*49152|0)+(n*768|0)+(o*12|0)+8>>2];B=f+p*(+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)>>2]-f);f=q+p*(+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+4>>2]-q);q=r+p*(+g[b+24+(m*49152|0)+(i*768|0)+(j*12|0)+8>>2]-r);r=s+p*(+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)>>2]-s);s=t+p*(+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+4>>2]-t);t=u+p*(+g[b+24+(m*49152|0)+(i*768|0)+(o*12|0)+8>>2]-u);u=B+d*(v+p*(+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)>>2]-v)-B);B=f+d*(w+p*(+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+4>>2]-w)-f);f=q+d*(x+p*(+g[b+24+(m*49152|0)+(n*768|0)+(j*12|0)+8>>2]-x)-q);q=B+e*(s+d*(z+p*(+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)+4>>2]-z)-s)-B);B=f+e*(t+d*(A+p*(+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)+8>>2]-A)-t)-f);g[a>>2]=u+e*(r+d*(y+p*(+g[b+24+(m*49152|0)+(n*768|0)+(o*12|0)>>2]-y)-r)-u);g[a+4>>2]=q;g[a+8>>2]=B;return}function Hq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+8>>2]|0;a=c[c[d+32>>2]>>2]|0;e=tq(d,b)|0;if((e|0)==0){f=-12;return f|0}f=lj(a,e)|0;return f|0}function Iq(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+16|0;a=c[b>>2]|0;if((a|0)==0){return}r5a(a)|0;mJb(b);return}function Jq(a){a=a|0;dl(a,Ok(685424)|0);return 0}function Kq(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0;f=i;i=i+104|0;g=f|0;h=f+8|0;j=f+16|0;k=f+96|0;c[g>>2]=e;l=c[b+8>>2]|0;m=c[l+44>>2]|0;n=c[c[l+32>>2]>>2]|0;c[k>>2]=0;l=bv(n,c[n+20>>2]|0,c[n+24>>2]|0)|0;c[h>>2]=l;if((l|0)==0){VHb(g);o=-12;i=f;return o|0}ZHb(l,e)|0;c[(c[g>>2]|0)+168>>2]=(c[m+12>>2]|0)*118|0;J1(j);c[j+24>>2]=0;c[j+28>>2]=0;e=m+16|0;p=i5a(c[e>>2]|0,j,c[g>>2]|0,k)|0;if((p|0)<0){P1(j);VHb(g);VHb(h);o=p;i=f;return o|0}p=c[(c[e>>2]|0)+804>>2]|0;e=b+20|0;k=b+24|0;b=m+8|0;m=0;q=l;while(1){l=(m|0)!=0|0;r=-(c[e>>2]|0)>>l;s=-r|0;t=-(c[k>>2]|0)>>l;l=-t|0;u=c[p+32+(m<<2)>>2]|0;v=c[(c[g>>2]|0)+32+(m<<2)>>2]|0;w=c[q+32+(m<<2)>>2]|0;x=(t|0)<0;do{if(x){y=p+(m<<2)|0;z=~t;A=~r;B=~v;C=v-1|0;D=1-v|0;E=v+1|0;F=-2-v|0;G=v+2|0;H=~u;I=u+1|0;J=-3-v|0;K=D-2|0;L=v+3|0;M=-2-u|0;N=u+2|0;O=v-2|0;P=D+1|0;Q=1-u|0;R=u-1|0;S=v-3|0;T=2-v|0;U=D+2|0;V=2-u|0;W=u-2|0;X=-4-r|0;Y=0;do{if(!(((c[b>>2]^Y)&1|0)==0|(r|0)>-1)){Z=ca(Y,u)|0;_=ca(Y,v)|0;$=ca(Y,w)|0;aa=0;do{ba=aa+Z|0;da=c[y>>2]|0;ea=da+ba|0;fa=aa+_|0;ga=c[(c[g>>2]|0)+(m<<2)>>2]|0;ha=(c[(c[h>>2]|0)+(m<<2)>>2]|0)+(aa+$)|0;if((Y|0)<1|(Y|0)>=(z|0)){a[ha]=a[ea]|0}else{ia=ba-u|0;ja=fa-v|0;ka=d[ga+ja|0]|0;la=(d[da+ia|0]|0)-ka|0;ma=ba+u|0;na=fa+v|0;oa=d[ga+na|0]|0;pa=(d[da+ma|0]|0)-oa|0;qa=d[ea]|0;do{if((aa|0)<3|(aa|0)>(X|0)){ra=-aa|0;sa=A-aa|0;if((ra|0)>-1){ta=ra}else{ta=(sa|0)<-1?sa:-1}ua=d[ga+(ja+ta)|0]|0;va=d[ga+(na+ta)|0]|0;wa=ua-va|0;xa=(sa|0)<0?sa:0;ya=d[ga+(ja+xa)|0]|0;za=d[ga+(na+xa)|0]|0;xa=ya-za|0;Aa=(sa|0)<1?sa:1;Ba=d[ga+(ja+Aa)|0]|0;Ca=d[ga+(na+Aa)|0]|0;Da=Ba-Ca|0;Ea=((wa|0)>-1?wa:-wa|0)-1+((xa|0)>-1?xa:-xa|0)+((Da|0)>-1?Da:-Da|0)|0;if((ra|0)>-2){Fa=ra}else{Fa=(sa|0)<-2?sa:-2}Da=d[ga+(ja+Fa)|0]|0;xa=Da-za|0;wa=ua-Ca|0;Ga=(sa|0)<2?sa:2;Ha=d[ga+(na+Ga)|0]|0;Ia=ya-Ha|0;Ja=((xa|0)>-1?xa:-xa|0)+((wa|0)>-1?wa:-wa|0)+((Ia|0)>-1?Ia:-Ia|0)|0;do{if((Ja|0)<(Ea|0)){if((ra|0)>-3){Ka=ra}else{Ka=(sa|0)<-3?sa:-3}Ia=(d[ga+(ja+Ka)|0]|0)-Ca|0;wa=Da-Ha|0;xa=ua-(d[ga+(na+((sa|0)<3?sa:3))|0]|0)|0;La=((Ia|0)>-1?Ia:-Ia|0)+((wa|0)>-1?wa:-wa|0)+((xa|0)>-1?xa:-xa|0)|0;if((La|0)>=(Ja|0)){Ma=(d[da+(ia+ta)|0]|0)-ua|0;Na=(d[da+(ma+Aa)|0]|0)-Ca|0;Oa=Ja;break}Ma=(d[da+(ia+Fa)|0]|0)-Da|0;Na=(d[da+(ma+Ga)|0]|0)-Ha|0;Oa=La}else{Ma=la;Na=pa;Oa=Ea}}while(0);Ea=d[ga+(na+Fa)|0]|0;Ha=ya-Ea|0;Da=Ba-va|0;Ja=d[ga+(ja+Ga)|0]|0;Ca=Ja-za|0;ua=((Da|0)>-1?Da:-Da|0)+((Ha|0)>-1?Ha:-Ha|0)+((Ca|0)>-1?Ca:-Ca|0)|0;if((ua|0)>=(Oa|0)){Pa=Ma;Qa=Na;break}if((ra|0)>-3){Ra=ra}else{Ra=(sa|0)<-3?sa:-3}Ca=Ba-(d[ga+(na+Ra)|0]|0)|0;Ha=Ja-Ea|0;Da=(d[ga+(ja+((sa|0)<3?sa:3))|0]|0)-va|0;if((((Ca|0)>-1?Ca:-Ca|0)+((Ha|0)>-1?Ha:-Ha|0)+((Da|0)>-1?Da:-Da|0)|0)>=(ua|0)){Pa=(d[da+(ia+Aa)|0]|0)-Ba|0;Qa=(d[da+(ma+ta)|0]|0)-va|0;break}Pa=(d[da+(ia+Ga)|0]|0)-Ja|0;Qa=(d[da+(ma+Fa)|0]|0)-Ea|0}else{Ea=d[ga+(fa+B)|0]|0;Ja=d[ga+(C+fa)|0]|0;ua=Ea-Ja|0;Da=ka-oa|0;Ha=d[ga+(fa+D)|0]|0;Ca=d[ga+(E+fa)|0]|0;La=Ha-Ca|0;xa=((Da|0)>-1?Da:-Da|0)-1+((ua|0)>-1?ua:-ua|0)+((La|0)>-1?La:-La|0)|0;La=d[ga+(F+fa)|0]|0;ua=La-oa|0;Da=Ea-Ca|0;wa=d[ga+(G+fa)|0]|0;Ia=ka-wa|0;Sa=((ua|0)>-1?ua:-ua|0)+((Da|0)>-1?Da:-Da|0)+((Ia|0)>-1?Ia:-Ia|0)|0;do{if((Sa|0)<(xa|0)){Ia=(d[ga+(J+fa)|0]|0)-Ca|0;Da=La-wa|0;ua=(d[ga+(K+fa)|0]|0)-(d[ga+(L+fa)|0]|0)|0;Ta=((Ia|0)>-1?Ia:-Ia|0)+((Da|0)>-1?Da:-Da|0)+((ua|0)>-1?ua:-ua|0)|0;if((Ta|0)>=(Sa|0)){Ua=Sa;Va=(d[da+(ba+H)|0]|0)-Ea|0;Wa=(d[da+(I+ba)|0]|0)-Ca|0;break}Ua=Ta;Va=(d[da+(M+ba)|0]|0)-La|0;Wa=(d[da+(N+ba)|0]|0)-wa|0}else{Ua=xa;Va=la;Wa=pa}}while(0);xa=d[ga+(O+fa)|0]|0;wa=ka-xa|0;La=Ha-Ja|0;Ca=(d[ga+(P+fa)|0]|0)-oa|0;Ea=((La|0)>-1?La:-La|0)+((wa|0)>-1?wa:-wa|0)+((Ca|0)>-1?Ca:-Ca|0)|0;if((Ea|0)>=(Ua|0)){Pa=Va;Qa=Wa;break}Ca=Ha-(d[ga+(S+fa)|0]|0)|0;wa=d[ga+(T+fa)|0]|0;La=wa-xa|0;Sa=(d[ga+(U+fa)|0]|0)-Ja|0;if((((La|0)>-1?La:-La|0)+((Ca|0)>-1?Ca:-Ca|0)+((Sa|0)>-1?Sa:-Sa|0)|0)>=(Ea|0)){Pa=(d[da+(Q+ba)|0]|0)-Ha|0;Qa=(d[da+(R+ba)|0]|0)-Ja|0;break}Pa=(d[da+(V+ba)|0]|0)-wa|0;Qa=(d[da+(W+ba)|0]|0)-xa|0}}while(0);ba=Pa+Qa|0;da=((Pa|0)>-1?Pa:-Pa|0)-((Qa|0)>-1?Qa:-Qa|0)|0;fa=(((da|0)>-1?da:-da|0)|0)/2|0;da=qa-((((ba|0)>0?-fa|0:fa)+ba|0)/2|0)|0;if(da>>>0>255>>>0){Xa=(da>>31^255)&255}else{Xa=da&255}a[ha]=Xa;a[ea]=Xa}aa=aa+1|0;}while((aa|0)<(s|0))}Y=Y+1|0;}while((Y|0)<(l|0));if(!x){break}Y=p+(m<<2)|0;if((r|0)<0){Ya=0}else{break}do{if(((c[b>>2]^Ya)&1|0)==0){W=ca(Ya,v)|0;V=ca(Ya,w)|0;R=ca(Ya,u)|0;Q=0;do{U=a[(c[(c[g>>2]|0)+(m<<2)>>2]|0)+(Q+W)|0]|0;a[(c[(c[h>>2]|0)+(m<<2)>>2]|0)+(Q+V)|0]=U;a[(c[Y>>2]|0)+(Q+R)|0]=U;Q=Q+1|0;}while((Q|0)<(s|0))}Ya=Ya+1|0;}while((Ya|0)<(l|0))}}while(0);l=m+1|0;if((l|0)>=3){break}m=l;q=c[h>>2]|0}c[b>>2]=c[b>>2]^1;P1(j);VHb(g);o=lj(n,c[h>>2]|0)|0;i=f;return o|0}function Lq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[a+8>>2]|0;f=c[e+44>>2]|0;c[d>>2]=0;g=b5a(1397641047)|0;if((g|0)==0){KIb(e,16,2497456,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;h=-22;i=b;return h|0}e=mWa(g)|0;c[f+16>>2]=e;if((e|0)==0){h=-12;i=b;return h|0}c[e+120>>2]=c[a+20>>2];c[e+124>>2]=c[a+24>>2];c[e+104>>2]=1;c[e+108>>2]=25;c[e+136>>2]=300;c[e+156>>2]=0;c[e+140>>2]=0;a=e+88|0;c[a>>2]=524290;c[e+680>>2]=-2;c[e+80>>2]=1;c[e+236>>2]=0;c[e+232>>2]=0;c[e+240>>2]=1;MGb(d,2486168,2474440,0)|0;j=c[f+4>>2]|0;if((j|0)==3){c[e+364>>2]=3;k=7}else if((j|0)==1){k=8}else if((j|0)==2){k=7}else if((j|0)==0){l=c[a>>2]|0;k=9}if((k|0)==7){c[e+144>>2]=50;k=8}if((k|0)==8){j=c[a>>2]|4;c[a>>2]=j;c[e+248>>2]=2;l=j;k=9}if((k|0)==9){c[a>>2]=l|16}l=_4a(e,g,d)|0;OGb(d);h=(l|0)<0?l:0;i=b;return h|0}function Mq(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+64|0;f=e|0;g=c[b+44>>2]|0;h=g+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;h=g+16|0;l=qKb(c[h>>2]|0)|0;c[g+92>>2]=l;do{if(!((a[l+7|0]&16)==0)){if((d[l+4|0]|0)>>>0<2>>>0){break}m=uKb(c[h>>2]|0)|0;c[g+24>>2]=m;a:do{if((m|0)>0){n=g+60|0;o=g+20|0;p=k;q=j;r=m;while(1){s=r-1|0;t=q&15;c[n+(s<<3)>>2]=t;u=(q>>>4|p<<28)&15;c[n+(s<<3)+4>>2]=u;if(t>>>0>3>>>0|u>>>0>3>>>0){break}t=q>>>8|p<<24;v=c[o>>2]|0;w=u+1|0;u=(v|0)>(w|0)?v:w;c[o>>2]=u;if((s|0)>0){p=p>>8|((p|0)<0|0?-1:0)<<24;q=t;r=s}else{x=u;break a}}KIb(b,16,2344232,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-22;i=e;return z|0}else{x=c[g+20>>2]|0}}while(0);m=g+20|0;if(!((x|0)!=0&(x|0)<5)){KIb(0,0,2284104,(y=i,i=i+24|0,c[y>>2]=2234632,c[y+8>>2]=2194912,c[y+16>>2]=96,y)|0);i=y;Hd();return 0}r=f;q=f|0;p=f+36|0;o=b+24|0;n=b+12|0;u=b+16|0;s=b+20|0;t=0;while(1){if((t|0)>=(c[m>>2]|0)){z=0;A=18;break}mrc(f|0,0,60)|0;w=FFb(2163696,(y=i,i=i+8|0,c[y>>2]=t,y)|0)|0;i=y;c[q>>2]=w;if((w|0)==0){z=-12;A=18;break}c[p>>2]=842;B=Qi(t,o,12,n,u,f)|0;c[s>>2]=c[o>>2];if((B|0)<0){A=17;break}t=t+1|0}if((A|0)==17){mJb(r);z=B;i=e;return z|0}else if((A|0)==18){i=e;return z|0}}}while(0);KIb(b,16,2428528,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-22;i=e;return z|0}function Nq(a){a=a|0;var b=0,d=0;bA((c[a+44>>2]|0)+96|0);b=a+24|0;if((c[b>>2]|0)==0){return}d=a+12|0;a=0;do{mJb((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function Oq(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+8|0;f=e|0;g=c[a+44>>2]|0;c[f>>2]=0;h=g+16|0;j=g+92|0;c[j>>2]=qKb(c[h>>2]|0)|0;k=0;do{l=qKb(k)|0;do{if(((b[(c[j>>2]|0)+8>>1]^b[l+8>>1])&30720)==0){m=uKb(k)|0;if((m|0)!=(d[l+4|0]|0|0)){break}Qk(f,k,(k|0)<0|0?-1:0)|0}}while(0);k=k+1|0;}while((k|0)<333);k=g+20|0;if((c[k>>2]|0)>0){g=a+16|0;j=0;do{Yk(c[f>>2]|0,(c[(c[g>>2]|0)+(j<<2)>>2]|0)+68|0);j=j+1|0;}while((j|0)<(c[k>>2]|0))}c[f>>2]=0;k=c[h>>2]|0;Qk(f,k,(k|0)<0|0?-1:0)|0;Yk(c[f>>2]|0,(c[c[a+32>>2]>>2]|0)+64|0);i=e;return 0}function Pq(a,b){a=a|0;b=b|0;return cA((c[(c[a+8>>2]|0)+44>>2]|0)+96|0,a,b)|0}function Qq(a){a=a|0;return dA((c[(c[a>>2]|0)+44>>2]|0)+96|0,a)|0}function Rq(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=i;i=i+208|0;f=b|0;g=c[a>>2]|0;h=c[g+44>>2]|0;j=h+96|0;k=g;l=h+20|0;Wz(j,k,c[l>>2]|0);m=h+152|0;c[h+132>>2]=h;c[h+128>>2]=2470;n=g+16|0;o=c[c[n>>2]>>2]|0;p=c[o+20>>2]|0;q=a+20|0;c[q>>2]=p;r=a+24|0;c[r>>2]=c[o+24>>2];s=o+56|0;o=a+56|0;t=c[s+4>>2]|0;c[o>>2]=c[s>>2];c[o+4>>2]=t;t=(c[c[n>>2]>>2]|0)+116|0;o=a+116|0;s=c[t+4>>2]|0;c[o>>2]=c[t>>2];c[o+4>>2]=s;s=a+28|0;o=(c[c[n>>2]>>2]|0)+28|0;t=s;u=c[o+4>>2]|0;c[t>>2]=c[o>>2];c[t+4>>2]=u;u=h+92|0;t=c[u>>2]|0;o=-(-p>>(d[t+5|0]|0))|0;p=h+28|0;v=p;c[h+36>>2]=o;c[h+32>>2]=o;o=c[q>>2]|0;c[h+40>>2]=o;c[p>>2]=o;o=-(-(c[r>>2]|0)>>(d[t+6|0]|0))|0;t=h+44|0;p=t;c[h+52>>2]=o;c[h+48>>2]=o;o=c[r>>2]|0;c[h+56>>2]=o;c[t>>2]=o;a:do{if((c[l>>2]|0)>0){o=s|0;t=a+32|0;r=0;while(1){w=c[(c[n>>2]|0)+(r<<2)>>2]|0;q=w+52|0;x=qKb(c[q>>2]|0)|0;y=c[o>>2]|0;z=c[w+28>>2]|0;if((y|0)!=(z|0)){A=5;break}B=c[t>>2]|0;C=c[w+32>>2]|0;if((B|0)!=(C|0)){D=C;E=B;break}B=c[w+20>>2]|0;C=-(-B>>(d[x+5|0]|0))|0;c[f+(r*52|0)+28>>2]=C;c[f+(r*52|0)+24>>2]=C;c[f+(r*52|0)+32>>2]=B;c[f+(r*52|0)+20>>2]=B;B=c[w+24>>2]|0;C=-(-B>>(d[x+6|0]|0))|0;c[f+(r*52|0)+44>>2]=C;c[f+(r*52|0)+40>>2]=C;c[f+(r*52|0)+48>>2]=B;c[f+(r*52|0)+36>>2]=B;B=uKb(c[q>>2]|0)|0;q=f+(r*52|0)+16|0;c[q>>2]=B;if((B|0)>0){B=0;do{c[f+(r*52|0)+(B<<2)>>2]=((e[x+8+(B<<1)>>1]|0)>>>11&15)+1;B=B+1|0;}while((B|0)<(c[q>>2]|0))}q=w+56|0;B=m+(r*184|0)+140|0;x=c[q+4>>2]|0;c[B>>2]=c[q>>2];c[B+4>>2]=x;c[m+(r*184|0)+180>>2]=1;c[m+(r*184|0)+132>>2]=0;c[m+(r*184|0)+136>>2]=0;x=r+1|0;if((x|0)<(c[l>>2]|0)){r=x}else{break a}}if((A|0)==5){D=c[w+32>>2]|0;E=c[t>>2]|0}o=c[(c[g+12>>2]|0)+(r*60|0)>>2]|0;x=c[c[g+28>>2]>>2]|0;KIb(k,16,2561760,(F=i,i=i+56|0,c[F>>2]=r,c[F+8>>2]=o,c[F+16>>2]=z,c[F+24>>2]=D,c[F+32>>2]=x,c[F+40>>2]=y,c[F+48>>2]=E,F)|0);i=F;G=-22;i=b;return G|0}}while(0);E=c[h+24>>2]|0;y=h+60|0;h=0;while(1){if((h|0)>=(E|0)){A=20;break}H=c[y+(h<<3)+4>>2]|0;I=c[y+(h<<3)>>2]|0;if((I+1|0)>(c[f+(H*52|0)+16>>2]|0)){A=13;break}J=((e[(c[u>>2]|0)+8+(h<<1)>>1]|0)>>>11&15)+1|0;K=c[f+(H*52|0)+(I<<2)>>2]|0;if((J|0)!=(K|0)){A=15;break}L=c[v+(h<<2)>>2]|0;M=c[f+(H*52|0)+20+(I<<2)>>2]|0;if((L|0)!=(M|0)){A=17;break}N=c[p+(h<<2)>>2]|0;O=c[f+(H*52|0)+36+(I<<2)>>2]|0;if((N|0)==(O|0)){h=h+1|0}else{A=19;break}}if((A|0)==13){KIb(k,16,2544280,(F=i,i=i+16|0,c[F>>2]=H,c[F+8>>2]=I,F)|0);i=F;G=-22;i=b;return G|0}else if((A|0)==15){KIb(k,16,2526656,(F=i,i=i+40|0,c[F>>2]=h,c[F+8>>2]=J,c[F+16>>2]=H,c[F+24>>2]=I,c[F+32>>2]=K,F)|0);i=F;G=-22;i=b;return G|0}else if((A|0)==17){KIb(k,16,2511544,(F=i,i=i+40|0,c[F>>2]=h,c[F+8>>2]=L,c[F+16>>2]=H,c[F+24>>2]=I,c[F+32>>2]=M,F)|0);i=F;G=-22;i=b;return G|0}else if((A|0)==19){KIb(k,16,2497384,(F=i,i=i+40|0,c[F>>2]=h,c[F+8>>2]=N,c[F+16>>2]=H,c[F+24>>2]=I,c[F+32>>2]=O,F)|0);i=F;G=-22;i=b;return G|0}else if((A|0)==20){G=Xz(j)|0;i=b;return G|0}return 0}function Sq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=c[c[(c[a+4>>2]|0)+32>>2]>>2]|0;f=c[a+36>>2]|0;mrc(d|0,0,16)|0;a=f+20|0;g=f+96|0;h=0;while(1){if((h|0)>=(c[a>>2]|0)){break}j=aA(g,h,d+(h<<2)|0,0)|0;if((j|0)<0){k=j;l=9;break}else{h=h+1|0}}if((l|0)==9){i=b;return k|0}l=bv(e,c[e+20>>2]|0,c[e+24>>2]|0)|0;if((l|0)==0){k=-12;i=b;return k|0}h=f+120|0;g=XIb(c[h>>2]|0,c[h+4>>2]|0,f+108|0,e+56|0)|0;h=l+136|0;c[h>>2]=g;c[h+4>>2]=G;h=f+24|0;if((c[h>>2]|0)>0){g=f+60|0;a=f+28|0;j=f+44|0;f=0;do{m=c[g+(f<<3)>>2]|0;n=c[d+(c[g+(f<<3)+4>>2]<<2)>>2]|0;uIb(c[l+(f<<2)>>2]|0,c[l+32+(f<<2)>>2]|0,c[n+(m<<2)>>2]|0,c[n+32+(m<<2)>>2]|0,c[a+(f<<2)>>2]|0,c[j+(f<<2)>>2]|0);f=f+1|0;}while((f|0)<(c[h>>2]|0))}k=lj(e,l)|0;i=b;return k|0}function Tq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=0;while(1){d=(c[1637296+(b<<3)>>2]|0)==(a|0);if((b|0)==63){e=4;break}if(d){f=b;break}else{b=b+1|0}}do{if((e|0)==4){if(d){f=63;break}else{g=-1}return g|0}}while(0);g=c[1637300+(f<<3)>>2]|0;return g|0}function Uq(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;b=i;i=i+16|0;a=b|0;f=a;c[f>>2]=e;c[f+4>>2]=0;LIb(0,48,d,a|0);i=b;return}function Vq(){return}function Wq(a,b){a=a|0;b=b|0;c[a+84>>2]=c[b+84>>2];c[a+88>>2]=c[b+88>>2];c[a+92>>2]=c[b+92>>2];if((c[a+20>>2]|0)!=(c[b+20>>2]|0)){return}if((c[a+24>>2]|0)!=(c[b+24>>2]|0)){return}c[a+80>>2]=c[b+80>>2];c[a+76>>2]=c[b+76>>2];return}function Xq(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=a|0;i=c[h>>2]|0;if((i&256|0)!=0){j=e&-2;k=(g&1)+g|0;do{if((b|0)==0){if((c[a+20>>2]|0)!=(f|0)){break}l=c[a+60>>2]|0;mrc((c[a+44>>2]|0)+(ca(l,j)|0)|0,0,ca(l,k)|0)|0;l=c[a+64>>2]|0;m=a+112|0;n=c[m>>2]|0;mrc((c[a+48>>2]|0)+(ca(j>>n,l)|0)|0,-128|0,ca(k>>n,l)|0)|0;l=c[a+68>>2]|0;n=c[m>>2]|0;mrc((c[a+52>>2]|0)+(ca(j>>n,l)|0)|0,-128|0,ca(k>>n,l)|0)|0;return}}while(0);l=k+j|0;if((k|0)<=0){return}k=a+44|0;n=a+60|0;m=a+48|0;o=a+108|0;p=a+64|0;q=a+112|0;r=a+52|0;s=a+68|0;t=j;do{mrc((c[k>>2]|0)+((ca(c[n>>2]|0,t)|0)+b)|0,0,f|0)|0;mrc((c[k>>2]|0)+((ca(c[n>>2]|0,t+1|0)|0)+b)|0,0,f|0)|0;j=c[o>>2]|0;mrc((c[m>>2]|0)+((ca(t>>c[q>>2],c[p>>2]|0)|0)+(b>>j))|0,-128|0,f>>j|0)|0;j=c[o>>2]|0;mrc((c[r>>2]|0)+((ca(t>>c[q>>2],c[s>>2]|0)|0)+(b>>j))|0,-128|0,f>>j|0)|0;t=t+2|0;}while((t|0)<(l|0));return}l=g+e|0;if((g|0)<=0){return}g=a+44|0;t=a+60|0;s=a+12|0;a=e;e=i;while(1){i=ca(c[t>>2]|0,a)|0;q=(d[s]|0)>>>3;r=(c[g>>2]|0)+((ca(q,b)|0)+i)|0;do{if((e&512|0)==0){mrc(r|0,0,ca(q,f)|0)|0}else{i=r;o=(ca(q,f)|0)/4|0;p=o-3|0;m=(p|0)>0;if((e&1024|0)==0){if(m){n=0;while(1){c[i+((n|3)<<2)>>2]=-2147450880;c[i+((n|2)<<2)>>2]=-2147450880;c[i+((n|1)<<2)>>2]=-2147450880;c[i+(n<<2)>>2]=-2147450880;k=n+4|0;if((k|0)<(p|0)){n=k}else{u=k;break}}}else{u=0}if((u|0)<(o|0)){v=u}else{break}do{c[i+(v<<2)>>2]=-2147450880;v=v+1|0;}while((v|0)<(o|0))}else{if(m){n=0;while(1){c[i+((n|3)<<2)>>2]=8388736;c[i+((n|2)<<2)>>2]=8388736;c[i+((n|1)<<2)>>2]=8388736;c[i+(n<<2)>>2]=8388736;k=n+4|0;if((k|0)<(p|0)){n=k}else{w=k;break}}}else{w=0}if((w|0)<(o|0)){x=w}else{break}do{c[i+(x<<2)>>2]=8388736;x=x+1|0;}while((x|0)<(o|0))}}}while(0);q=a+1|0;if((q|0)>=(l|0)){break}a=q;e=c[h>>2]|0}return}function Yq(a,b){a=a|0;b=b|0;return 1}function Zq(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;k=i;l=f>>16;if((c[b+292>>2]|0)!=0){KIb(0,0,2562944,(m=i,i=i+24|0,c[m>>2]=2428256,c[m+8>>2]=2344e3,c[m+16>>2]=310,m)|0);i=m;Hd();return 0}n=b+48|0;o=c[n>>2]|0;if((o|0)==0&(h|0)>0){c[n>>2]=h;p=h}else{p=o}o=b+52|0;q=c[o>>2]|0;if((q|0)==0&(j|0)>0){c[o>>2]=j;r=j}else{r=q}q=(h|0)==-1;if((p|0)>(h|0)&(q^1)){KIb(0,0,2562944,(m=i,i=i+24|0,c[m>>2]=2283952,c[m+8>>2]=2344e3,c[m+16>>2]=316,m)|0);i=m;Hd();return 0}s=(j|0)==-1;if((r|0)>(j|0)&(s^1)){KIb(0,0,2562944,(m=i,i=i+24|0,c[m>>2]=2234424,c[m+8>>2]=2344e3,c[m+16>>2]=317,m)|0);i=m;Hd();return 0}if((p|0)<=0){KIb(0,0,2562944,(m=i,i=i+24|0,c[m>>2]=2194792,c[m+8>>2]=2344e3,c[m+16>>2]=318,m)|0);i=m;Hd();return 0}if((r|0)<=0){KIb(0,0,2562944,(m=i,i=i+24|0,c[m>>2]=2163592,c[m+8>>2]=2344e3,c[m+16>>2]=319,m)|0);i=m;Hd();return 0}KIb(c[b-608+912>>2]|0,48,2137672,(m=i,i=i+32|0,c[m>>2]=h,c[m+8>>2]=j,c[m+16>>2]=p,c[m+24>>2]=r,m)|0);i=m;if(q){t=c[n>>2]|0}else{t=h}if(s){u=c[o>>2]|0}else{u=j}if((g&4|0)==0){v=t}else{v=t+15&-16}a:do{switch(f&255|0){case 4:{if((g&2|0)!=0){w=31;break a}j=b+64|0;s=c[j>>2]|0;if((s|0)!=0){x=s;break a}s=hA(v,u)|0;c[j>>2]=s;y=s;w=42;break};case 5:{b:do{if((l|0)==-1){s=0;while(1){if((s|0)>=50){z=0;break}j=c[b+72+(s<<2)>>2]|0;if((j|0)==0){A=s;break b}if((c[j+116>>2]|0)==0){A=s;break b}else{s=s+1|0}}i=k;return z|0}else{A=l}}while(0);if(A>>>0>49>>>0){z=0;i=k;return z|0}s=b+72+(A<<2)|0;j=c[s>>2]|0;if((j|0)==0){h=hA(v,u)|0;c[s>>2]=h;B=h}else{B=j}c[B+8>>2]=A;y=B;w=42;break};case 0:{j=b+68|0;h=c[j>>2]|0;if((h|0)!=0){x=h;break a}h=hA(v,u)|0;c[j>>2]=h;y=h;w=42;break};case 1:{h=b+56|0;j=c[h>>2]|0;if((j|0)!=0){x=j;break a}j=hA(v,u)|0;c[h>>2]=j;y=j;w=42;break};case 2:{j=b+64|0;h=c[j>>2]|0;if((h|0)!=0){x=h;break a}h=hA(v,u)|0;c[j>>2]=h;y=h;w=42;break};case 3:{w=31;break};default:{z=0;i=k;return z|0}}}while(0);if((w|0)==31){B=b+272|0;A=c[B>>2]|0;l=c[b+56+(A<<2)>>2]|0;if((l|0)==0){h=hA(v,u)|0;c[b+56+(c[B>>2]<<2)>>2]=h;h=c[B>>2]|0;C=h;D=c[b+56+(h<<2)>>2]|0}else{C=A;D=l}c[B>>2]=C^1;y=D;w=42}do{if((w|0)==42){if((y|0)==0){z=0}else{x=y;break}i=k;return z|0}}while(0);y=x+4|0;a[y]=f;c[x+36>>2]=c[n>>2];c[x+40>>2]=c[o>>2];o=x|0;n=c[o>>2]&52992|g&6399;c[o>>2]=n;if((c[b+28>>2]|0)==0){f=n&53247;c[o>>2]=f;E=f}else{E=n}n=x+20|0;f=c[n>>2]|0;if((f|0)==(v|0)){if((c[x+24>>2]|0)!=(u|0)){w=47}}else{w=47}if((w|0)==47){do{if((E&16384|0)!=0){if((f|0)>=(v|0)){if((c[x+24>>2]|0)>=(u|0)){break}}kJb(c[x+44>>2]|0);c[o>>2]=c[o>>2]&-16385;Uq(0,0,2114256,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);c[n>>2]=v;f=c[x+108>>2]|0;c[x+100>>2]=v-1+(1<<f)>>f;c[x+24>>2]=u;f=c[x+112>>2]|0;c[x+104>>2]=u-1+(1<<f)>>f}f=x+12|0;if((a[f]|0)==0){iA(x,e)}e=c[o>>2]|0;do{if((e&16384|0)==0){if((a[y]|0)==0){break}if((c[b+16>>2]|0)!=0){KIb(0,0,2562944,(m=i,i=i+24|0,c[m>>2]=2632376,c[m+8>>2]=2344e3,c[m+16>>2]=395,m)|0);i=m;Hd();return 0}if((e&8192|0)!=0){break}if((a[f]|0)==0){Uq(0,0,2608504,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;z=0;i=k;return z|0}do{if((g&8|0)!=0){if((e&768|0)==768){F=(8<<c[x+108>>2])-1|0}else{F=15}u=F+t&~F;if((c[n>>2]|0)==(u|0)){break}c[n>>2]=u;v=c[x+108>>2]|0;c[x+100>>2]=u-1+(1<<v)>>v}}while(0);gA(x);Xq(x,0,0,c[n>>2]|0,c[x+24>>2]|0)}}while(0);if((c[b+24>>2]|0)!=0){KIb(0,0,2562944,(m=i,i=i+24|0,c[m>>2]=2581896,c[m+8>>2]=2344e3,c[m+16>>2]=432,m)|0);i=m;Hd();return 0}b=c[o>>2]|0;if((b&32768|0)==0){if((a[y]|0)==0){G=2526600}else{G=(b&8192|0)!=0?2511512:2497328}y=c[n>>2]|0;n=c[x+24>>2]|0;F=d[f]|0;if((b&512|0)==0){H=(b&1024|0)!=0?2454992:2437896}else{H=2465760}f=(ca(ca(F,y)|0,n)|0)/8|0;Uq(0,0,2561640,(m=i,i=i+72|0,c[m>>2]=2544176,c[m+8>>2]=G,c[m+16>>2]=(b&4096|0)!=0?2486144:10230520,c[m+24>>2]=y,c[m+32>>2]=n,c[m+40>>2]=F,c[m+48>>2]=H,c[m+56>>2]=(b&256|0)!=0?2427312:2417136,c[m+64>>2]=f,m)|0);i=m;f=c[x+44>>2]|0;b=c[x+48>>2]|0;H=c[x+52>>2]|0;F=c[x+60>>2]|0;n=c[x+64>>2]|0;y=c[x+68>>2]|0;G=c[x+100>>2]|0;t=c[x+104>>2]|0;e=c[x+108>>2]|0;g=c[x+112>>2]|0;Uq(0,0,2408152,(m=i,i=i+88|0,c[m>>2]=c[x+16>>2],c[m+8>>2]=f,c[m+16>>2]=b,c[m+24>>2]=H,c[m+32>>2]=F,c[m+40>>2]=n,c[m+48>>2]=y,c[m+56>>2]=G,c[m+64>>2]=t,c[m+72>>2]=e,c[m+80>>2]=g,m)|0);i=m;c[o>>2]=c[o>>2]|32768}c[x+76>>2]=0;o=x+116|0;c[o>>2]=(c[o>>2]|0)+1;z=x;i=k;return z|0}function _q(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a-304+300|0;j=h+612|0;k=c[c[(c[j>>2]|0)+32>>2]>>2]|0;l=UHb()|0;c[f>>2]=l;if((c[a+292>>2]|0)==0){KIb(0,0,2562944,(m=i,i=i+24|0,c[m>>2]=2400744,c[m+8>>2]=2344e3,c[m+16>>2]=467,m)|0);i=m;Hd();return 0}KIb(c[j>>2]|0,48,2393784,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;if((l|0)==0){VHb(f);n=0;i=e;return n|0}c[l+68>>2]=c[b+36>>2];c[l+72>>2]=c[b+40>>2];c[l+288>>2]=0;m=b+16|0;j=0;while(1){if((j|0)==63){o=63;break}if((c[m>>2]|0)==(c[1637296+(j<<3)>>2]|0)){o=j;break}else{j=j+1|0}}j=l+80|0;c[j>>2]=c[1637300+(o<<3)>>2];o=h+624|0;a=0;while(1){p=1637296+(a<<3)|0;if((a|0)==63){q=63;break}if((c[o>>2]|0)==(c[1637300+(a<<3)>>2]|0)){q=a;break}else{a=a+1|0}}if((c[m>>2]|0)==(c[p>>2]|0)){c[j>>2]=c[1637300+(q<<3)>>2]}q=l+32|0;j=b+60|0;c[q>>2]=c[j>>2];c[q+4>>2]=c[j+4>>2];c[q+8>>2]=c[j+8>>2];c[q+12>>2]=c[j+12>>2];do{if((c[b+60>>2]|0)!=0){c[l>>2]=c[b+44>>2];if((c[b+64>>2]|0)==0){break}c[(c[f>>2]|0)+4>>2]=c[b+48>>2];if((c[b+68>>2]|0)==0){break}c[(c[f>>2]|0)+8>>2]=c[b+52>>2];if((c[b+72>>2]|0)==0){break}c[(c[f>>2]|0)+12>>2]=c[b+56>>2]}}while(0);if(d!=-9223372036854776000.0){r=+(c[k+56>>2]|0)/+(c[k+60>>2]|0)*d;b=(F=+r,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);l=c[f>>2]|0;j=l+136|0;c[j>>2]=~~+r>>>0;c[j+4>>2]=b;s=l}else{s=c[f>>2]|0}c[g>>2]=s;c[f>>2]=$Hb(s)|0;VHb(g);lj(k,c[f>>2]|0)|0;f=h+616|0;c[f>>2]=(c[f>>2]|0)+1;n=1;i=e;return n|0}function $q(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;if((b|0)>0&(d|0)>0){h=c[a+292>>2]|0;c[h+48>>2]=b;c[h+52>>2]=d;i=i;return 1}else{KIb(0,0,2562944,(d=i,i=i+24|0,c[d>>2]=2386936,c[d+8>>2]=2344e3,c[d+16>>2]=514,d)|0);i=d;Hd();return 0}return 0}function ar(a,b,d){a=a|0;b=b|0;d=d|0;d=i;KIb(c[a-304+912>>2]|0,48,2379936,(a=i,i=i+8|0,c[a>>2]=b,a)|0);i=a;i=d;return 0}function br(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+256|0;e=c[b+44>>2]|0;f=AGb()|0;c[2093459]=f&1;c[2093460]=f&2;c[2093463]=f&8;c[2093464]=f&16;c[2093465]=f&64;c[2093466]=f&128;c[2093467]=f&256;c[2093468]=f&512;c[2093470]=f&16384;c[2093461]=f&4;c[2093462]=f&32;c[e+612>>2]=b;f=c[e+620>>2]|0;do{if((f|0)!=0){g=d|0;h=Bd(f|0,2337624,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;if((h|0)!=1){break}h=lrc(g|0)|0;k=f+h|0;if((a[k]|0)==61){l=f+(h+1)|0}else{l=k}k=0;while(1){if((k|0)==7){m=9;break}n=c[1224856+(k<<2)>>2]|0;if((irc(g,c[n+4>>2]|0)|0)==0){break}else{k=k+1|0}}if((m|0)==9){KIb(b,16,2326296,(j=i,i=i+8|0,c[j>>2]=g,j)|0);i=j;o=-22;i=d;return o|0}k=b;KIb(k,24,2320528,(j=i,i=i+8|0,c[j>>2]=g,j)|0);i=j;h=e+4|0;mrc(h|0,0,304)|0;p=h;c[p>>2]=n;c[e+296>>2]=e+308;c[e+24>>2]=10;c[e+8>>2]=86;c[e+16>>2]=254;c[e+12>>2]=204;c[e+44>>2]=1024;c[e+48>>2]=0;if((c[n+20>>2]|0)==0){q=n}else{KIb(k,16,2315800,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=c[p>>2]|0}if((We[c[q+16>>2]&2047](h,l)|0)>=1){o=0;i=d;return o|0}KIb(k,16,2311288,(j=i,i=i+16|0,c[j>>2]=g,c[j+8>>2]=l,j)|0);i=j;o=-1;i=d;return o|0}}while(0);KIb(b,16,2332008,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;o=-22;i=d;return o|0}function cr(a){a=a|0;var b=0,d=0;b=(c[a+44>>2]|0)+4|0;if((b|0)==0){return}a=b;while(1){b=c[a+292>>2]|0;d=c[a+32>>2]|0;if((d|0)!=0){qe[d&1023](a)}jA(c[a+56>>2]|0);jA(c[a+60>>2]|0);jA(c[a+64>>2]|0);jA(c[a+68>>2]|0);if((b|0)==0){break}else{a=b}}return}function dr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+8|0;d=b|0;c[d>>2]=0;e=c[a+44>>2]|0;f=a;g=e+4|0;h=e+16|0;e=-1;j=0;k=1637296;while(1){KIb(f,48,2350704,(l=i,i=i+8|0,c[l>>2]=c[k>>2],l)|0);i=l;do{if((We[c[h>>2]&2047](g,c[k>>2]|0)|0)==0){m=e}else{KIb(f,48,2343584,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;n=c[1637300+(j<<3)>>2]|0;if((n|0)==(e|0)){m=e;break}Qk(d,n,(n|0)<0|0?-1:0)|0;m=n}}while(0);l=j+1|0;if((l|0)==63){break}else{e=m;j=l;k=1637296+(l<<3)|0}}k=c[d>>2]|0;if((k|0)==0){o=-1;i=b;return o|0}dl(a,k);o=0;i=b;return o|0}function er(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;KIb(c[a-304+912>>2]|0,48,2306720,(a=i,i=i+8|0,c[a>>2]=b,a)|0);i=a;a=0;while(1){if((a|0)==63){e=0;f=4;break}if((c[1637296+(a<<3)>>2]|0)==(b|0)){e=1;f=4;break}else{a=a+1|0}}if((f|0)==4){i=d;return e|0}return 0}function fr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a|0;a=c[(c[d>>2]|0)+44>>2]|0;e=a+612|0;KIb(c[e>>2]|0,48,2279856,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=a+616|0;c[g>>2]=0;do{h=Wi(c[c[(c[d>>2]|0)+16>>2]>>2]|0)|0;if((h|0)<0){break}}while((c[g>>2]|0)==0);KIb(c[e>>2]|0,48,2275640,(f=i,i=i+8|0,c[f>>2]=h,f)|0);i=f;i=b;return h|0}function gr(a){a=a|0;var b=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+356>>2];c[a+24>>2]=c[b+360>>2];return 0}function hr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0.0,m=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[(c[a+8>>2]|0)+44>>2]|0;g=hA(c[b+68>>2]|0,c[b+72>>2]|0)|0;h=b+136|0;j=c[h>>2]|0;k=c[h+4>>2]|0;if((j|0)==0&(k|0)==(-2147483648|0)){l=-9223372036854776000.0}else{l=(+(j>>>0)+ +(k|0)*4294967296.0)/(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}k=a+52|0;a=0;while(1){m=1637296+(a<<3)|0;if((a|0)==63){break}if((c[1637300+(a<<3)>>2]|0)==(c[k>>2]|0)){break}else{a=a+1|0}}iA(g,c[m>>2]|0);c[f+624>>2]=c[k>>2];k=g+44|0;m=b;c[k>>2]=c[m>>2];c[k+4>>2]=c[m+4>>2];c[k+8>>2]=c[m+8>>2];c[k+12>>2]=c[m+12>>2];m=g+60|0;k=b+32|0;c[m>>2]=c[k>>2];c[m+4>>2]=c[k+4>>2];c[m+8>>2]=c[k+8>>2];c[m+12>>2]=c[k+12>>2];if((c[b+296>>2]|0)!=0){k=g+88|0;c[k>>2]=c[k>>2]|32}if((c[b+300>>2]|0)!=0){k=g+88|0;c[k>>2]=c[k>>2]|2}if((c[b+292>>2]|0)!=0){k=g+88|0;c[k>>2]=c[k>>2]|4}k=g|0;c[k>>2]=c[k>>2]|2;if((bIb(b)|0)==0){c[k>>2]=c[k>>2]|1}if((Je[c[f+24>>2]&31](f+4|0,g,l)|0)==0){KIb(c[f+612>>2]|0,48,2266432,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;jA(g);i=d;return 0}else{VHb(e);jA(g);i=d;return 0}return 0}function ir(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=0;while(1){if((f|0)==63){break}g=1637296+(f<<3)|0;if((c[1637300+(f<<3)>>2]|0)==(c[e>>2]|0)){h=4;break}else{f=f+1|0}}do{if((h|0)==4){f=a+20|0;if((c[f>>2]|0)==0){break}e=a+24|0;if((c[e>>2]|0)==0){break}c[d+280>>2]=1;c[d+288>>2]=c[e>>2];c[d+284>>2]=c[f>>2];j=c[g>>2]|0;c[d+292>>2]=j;k=c[f>>2]|0;f=c[e>>2]|0;e=((me[c[d+8>>2]&255](d+4|0,k,f,k,f,0,j)|0)<1)<<31>>31;i=b;return e|0}}while(0);KIb(0,0,2562944,(b=i,i=i+24|0,c[b>>2]=2270952,c[b+8>>2]=2344e3,c[b+16>>2]=687,b)|0);i=b;Hd();return 0}function jr(a){a=a|0;var b=0,d=0,e=0,f=0,j=0.0,k=0;b=i;d=c[a+44>>2]|0;e=c[d+8>>2]|0;f=c[d+4>>2]|0;j=+g[d+12>>2];KIb(a,40,2427424,(a=i,i=i+32|0,c[a>>2]=c[d+16>>2],c[a+8>>2]=e,c[a+16>>2]=f,h[a+24>>3]=j,a)|0);i=a;a=mWa(0)|0;c[d+1280>>2]=a;if((a|0)==0){k=-12;i=b;return k|0}Nba(d+36|0,a);k=0;i=b;return k|0}function kr(a){a=a|0;var b=0;b=c[a+44>>2]|0;VHb(b+32|0);a=b+1280|0;b=c[a>>2]|0;if((b|0)==0){return}r5a(b)|0;mJb(a);return}function lr(a){a=a|0;dl(a,Ok(685376)|0);return 0}function mr(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;a=c[c[b+16>>2]>>2]|0;d=(c[b+44>>2]|0)+20|0;do{e=Wi(a)|0;}while((c[d>>2]|0)>0&(e|0)>-1);return e|0}function nr(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+200|0;f=e|0;j=e+128|0;k=e+136|0;l=e+168|0;c[j>>2]=d;m=b+8|0;n=c[m>>2]|0;o=n+44|0;p=c[o>>2]|0;q=c[c[n+32>>2]>>2]|0;n=p+32|0;r=c[n>>2]|0;a:do{if((r|0)==0){s=22}else{t=c[p+16>>2]|0;do{if((t|0)>0){if((c[p+20>>2]|0)>=(t|0)){s=22;break a}}else{if((t|0)>=0){break}if(((c[p+20>>2]|0)-1|0)>(t|0)){s=22;break a}}}while(0);t=c[r>>2]|0;b:do{if((t|0)!=0){u=p+28|0;v=p+24|0;w=r+68|0;x=r+72|0;y=f|0;z=0;A=t;do{B=c[r+32+(z<<2)>>2]|0;if((B|0)==0){break b}if((z-1|0)>>>0<2>>>0){C=c[v>>2]|0;D=c[u>>2]|0}else{C=0;D=0}E=c[d+(z<<2)>>2]|0;F=-(c[w>>2]|0)>>C;G=-(c[x>>2]|0)>>D;H=c[o>>2]|0;I=+(ca((G|0)/-16|0,(F|0)/-16|0)|0);J=~~(+g[H+12>>2]*I);K=-7-G|0;c:do{if((K|0)>0){G=-7-F|0;L=H+40|0;M=H+60|0;N=H+8|0;O=H+4|0;if((G|0)>8){P=0;Q=0}else{R=0;while(1){R=R+4|0;if((R|0)>=(K|0)){break c}}}while(1){R=ca(P,B)|0;S=8;T=Q;while(1){U=S+R|0;mf[c[L>>2]&2047](y,E+U|0,A+U|0,B);U=ve[c[M>>2]&4095](y)|0;if((U|0)>(c[N>>2]|0)){s=22;break a}if((U|0)>(c[O>>2]|0)){U=T+1|0;if((U|0)>(J|0)){s=22;break a}else{V=U}}else{V=T}U=S+4|0;if((U|0)<(G|0)){S=U;T=V}else{break}}T=P+4|0;if((T|0)<(K|0)){P=T;Q=V}else{break}}}}while(0);z=z+1|0;A=c[r+(z<<2)>>2]|0;}while((A|0)!=0)}}while(0);t=p+20|0;A=c[t>>2]|0;z=(A|0)<0?1:A+1|0;c[t>>2]=z;W=z}}while(0);do{if((s|0)==22){VHb(n);c[n>>2]=c[j>>2];r=p+20|0;V=c[r>>2]|0;c[r>>2]=(V|0)<0?V-1|0:-1;V=lj(q,$Hb(c[j>>2]|0)|0)|0;if((V|0)>=0){W=c[r>>2]|0;break}X=V>>>31;i=e;return X|0}}while(0);q=c[m>>2]|0;m=p+20|0;p=k|0;mrc(p|0,0,32)|0;a[p]=0;k=(c[j>>2]|0)+136|0;n=c[k>>2]|0;s=c[k+4>>2]|0;if((n|0)==0&(s|0)==(-2147483648|0)){Rb(p|0,32,2526560,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0)|0;i=Y}else{Rb(p|0,32,2497296,(Y=i,i=i+16|0,c[Y>>2]=n,c[Y+8>>2]=s,Y)|0)|0;i=Y}s=l|0;mrc(s|0,0,32)|0;a[s]=0;l=(c[j>>2]|0)+136|0;n=c[l>>2]|0;k=c[l+4>>2]|0;if((n|0)==0&(k|0)==(-2147483648|0)){Rb(s|0,32,2526560,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0)|0;i=Y}else{Rb(s|0,32,2511424,(Y=i,i=i+8|0,h[Y>>3]=(+(n>>>0)+ +(k|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),Y)|0)|0;i=Y}b=c[m>>2]|0;KIb(q,48,2581808,(Y=i,i=i+32|0,c[Y>>2]=(W|0)>0?2561560:2544136,c[Y+8>>2]=p,c[Y+16>>2]=s,c[Y+24>>2]=b,Y)|0);i=Y;if((c[m>>2]|0)<=0){X=0;i=e;return X|0}VHb(j);X=0;i=e;return X|0}function or(a){a=a|0;var b=0,e=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;c[b+24>>2]=d[e+5|0]|0;c[b+28>>2]=d[e+6|0]|0;return 0}function pr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0,H=0;d=c[b+44>>2]|0;AGb()|0;b=d+49468|0;e=b;f=c[d+308>>2]|0;g=(f|0)>-1?f:123457;c[d+49736>>2]=g;f=c[d+40>>2]|0;h=(f|0)==0;if(!h){c[b>>2]=f}b=c[d+44>>2]|0;i=(b|0)==0;if(!i){c[d+49472>>2]=b}c[d+99164>>2]=g;if(!h){c[d+98896>>2]=f}if(!i){c[d+98900>>2]=b}c[d+148592>>2]=g;if(!h){c[d+148324>>2]=f}if(!i){c[d+148328>>2]=b}c[d+198020>>2]=g;if(!h){c[d+197752>>2]=f}if(!i){c[d+197756>>2]=b}b=d;i=d+263564|0;f=0;do{if((c[e+(f*49428|0)>>2]|0)!=0){h=hJb(5120)|0;g=c[b+49468+(f*49428|0)>>2]|0;j=c[b+49468+(f*49428|0)+4>>2]|0;if((h|0)==0){k=-12;l=34;break}AIb(b+49468+(f*49428|0)+8|0,c[b+49468+(f*49428|0)+268>>2]|0);m=b+49468+(f*49428|0)+264|0;n=(j&8|0)==0;o=j&16;p=(o|0)!=0;q=+(g|0);r=(g|0)/2|0;s=q/1.7320508075688772;t=(o|0)==0;o=c[m>>2]|0;if((j&1|0)==0){j=0;u=0;v=o;while(1){w=v;do{c[b+49468+(f*49428|0)+8+((w&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((w+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((w+40&63)<<2)>>2]|0);x=c[m>>2]|0;y=x+1|0;c[m>>2]=y;z=+((c[b+49468+(f*49428|0)+8+((x&63)<<2)>>2]|0)>>>0>>>0)*2.0*2.3283064365386963e-10+-1.0;c[b+49468+(f*49428|0)+8+((y&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((x+10&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((x+41&63)<<2)>>2]|0);x=c[m>>2]|0;w=x+1|0;c[m>>2]=w;A=+((c[b+49468+(f*49428|0)+8+((x&63)<<2)>>2]|0)>>>0>>>0)*2.0*2.3283064365386963e-10+-1.0;B=z*z+A*A;}while(!(B<1.0));A=s*z*+S(+aa(B)*-2.0/B);if(t){C=A}else{C=A*.5+ +(ca(a[734944+((j|0)%4|0)|0]|0,g)|0)*.35}A=C;if(A<-128.0){D=-128.0}else{D=A>127.0?127.0:A}if(n){E=D}else{E=D/3.0}a[h+u|0]=~~E;w=c[m>>2]|0;c[b+49468+(f*49428|0)+8+((w&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((w+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((w+40&63)<<2)>>2]|0);w=c[m>>2]|0;x=w+1|0;c[m>>2]=x;y=u+1|0;if((y|0)<5120){j=j+1+(((~~(+((c[b+49468+(f*49428|0)+8+((w&63)<<2)>>2]|0)>>>0>>>0)*6.0*2.3283064365386963e-10)|0)==0)<<31>>31)|0;u=y;v=x}else{F=0;G=x;break}}}else{v=0;u=0;j=o;while(1){c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((j+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((j+40&63)<<2)>>2]|0);t=c[m>>2]|0;x=t+1|0;c[m>>2]=x;y=~~(q*+((c[b+49468+(f*49428|0)+8+((t&63)<<2)>>2]|0)>>>0>>>0)*2.3283064365386963e-10)-r|0;do{if(n){if(p){a[h+u|0]=~~(+((y|0)/2|0|0)+ +(ca(a[734944+((v|0)%4|0)|0]|0,g)|0)*.25);break}else{a[h+u|0]=y;break}}else{if(p){a[h+u|0]=~~(+((y|0)/6|0|0)+ +(ca(a[734944+((v|0)%4|0)|0]|0,g)|0)*.25/3.0);break}else{a[h+u|0]=(y|0)/3|0;break}}}while(0);c[b+49468+(f*49428|0)+8+((x&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((t+10&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((t+41&63)<<2)>>2]|0);y=c[m>>2]|0;w=y+1|0;c[m>>2]=w;H=u+1|0;if((H|0)<5120){v=v+1+(((~~(+((c[b+49468+(f*49428|0)+8+((y&63)<<2)>>2]|0)>>>0>>>0)*6.0*2.3283064365386963e-10)|0)==0)<<31>>31)|0;u=H;j=w}else{F=0;G=w;break}}}while(1){c[b+49468+(f*49428|0)+8+((G&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((G+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((G+40&63)<<2)>>2]|0);j=c[m>>2]|0;c[m>>2]=j+1;c[b+49468+(f*49428|0)+276+(F*12|0)>>2]=h+(c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]&1023);j=c[m>>2]|0;c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((j+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((j+40&63)<<2)>>2]|0);j=c[m>>2]|0;c[m>>2]=j+1;c[b+49468+(f*49428|0)+276+(F*12|0)+4>>2]=h+(c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]&1023);j=c[m>>2]|0;c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((j+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((j+40&63)<<2)>>2]|0);j=c[m>>2]|0;c[m>>2]=j+1;c[b+49468+(f*49428|0)+276+(F*12|0)+8>>2]=h+(c[b+49468+(f*49428|0)+8+((j&63)<<2)>>2]&1023);j=F+1|0;if((j|0)>=4096){break}F=j;G=c[m>>2]|0}if((c[i>>2]|0)==0){j=0;do{u=c[m>>2]|0;c[b+49468+(f*49428|0)+8+((u&63)<<2)>>2]=(c[b+49468+(f*49428|0)+8+((u+9&63)<<2)>>2]|0)+(c[b+49468+(f*49428|0)+8+((u+40&63)<<2)>>2]|0);u=c[m>>2]|0;c[m>>2]=u+1;c[b+247180+(j<<2)>>2]=c[b+49468+(f*49428|0)+8+((u&63)<<2)>>2]&1023;j=j+1|0;}while((j|0)<4096);c[i>>2]=1}c[b+49468+(f*49428|0)+272>>2]=h}f=f+1|0;}while((f|0)<4);if((l|0)==34){return k|0}c[d+263568>>2]=226;c[d+263572>>2]=672;k=0;return k|0}function qr(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+49740|0);mJb(b+99168|0);mJb(b+148596|0);mJb(b+198024|0);return}function rr(b){b=b|0;var d=0,f=0,g=0,h=0;d=i;i=i+8|0;f=d|0;c[f>>2]=0;g=0;do{h=qKb(g)|0;do{if(!((a[h+7|0]&16)==0)){if((((e[h+8>>1]|0)>>>11&65535)+1&7|0)!=0){break}Qk(f,g,(g|0)<0|0?-1:0)|0}}while(0);g=g+1|0;}while((g|0)<333);dl(b,c[f>>2]|0);i=d;return 0}function sr(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)>0){h=0}else{return}do{i=(a[e+(h+g)|0]|0)+(d[c+h|0]|0)|0;if(i>>>0>255>>>0){j=-i>>31&255}else{j=i&255}a[b+h|0]=j;h=h+1|0;}while((h|0)<(f|0));return}function tr(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)<=0){return}g=f+4|0;h=f+8|0;i=0;do{j=a[d+i|0]|0;a[b+i|0]=((ca((a[(c[g>>2]|0)+i|0]|0)+(a[(c[f>>2]|0)+i|0]|0)+(a[(c[h>>2]|0)+i|0]|0)|0,j)|0)>>>7)+j;i=i+1|0;}while((i|0)<(e|0));return}function ur(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;a=c[c[g+32>>2]>>2]|0;h=c[g+44>>2]|0;do{if((bIb(b)|0)==0){j=bv(a,c[a+20>>2]|0,c[a+24>>2]|0)|0;if((j|0)!=0){ZHb(j,c[e>>2]|0)|0;k=j;l=c[e>>2]|0;break}VHb(e);m=-12;i=d;return m|0}else{k=b;l=b}}while(0);c[f>>2]=l;c[f+4>>2]=k;l=c[h+24>>2]|0;h=c[(c[g+48>>2]|0)+28>>2]|0;Xe[c[c[g+56>>2]>>2]&511](g,704,f,0,(l|0)>(h|0)?h:l)|0;if((c[e>>2]|0)!=(k|0)){VHb(e)}m=lj(a,k)|0;i=d;return m|0}function vr(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=qKb(c[e>>2]|0)|0;c[b+4>>2]=uKb(c[e>>2]|0)|0;g=pIb(b+8|0,c[e>>2]|0,c[a+20>>2]|0)|0;if((g|0)<0){h=g;return h|0}g=a+24|0;a=-(-(c[g>>2]|0)>>(d[f+6|0]|0))|0;c[b+32>>2]=a;c[b+28>>2]=a;a=c[g>>2]|0;c[b+36>>2]=a;c[b+24>>2]=a;h=0;return h|0}function wr(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=c[a+44>>2]|0;a=f;g=f+4|0;if((c[g>>2]|0)<=0){return 0}h=f+24|0;i=d+1|0;j=b+4|0;k=b;b=f+8|0;l=f+263568|0;m=f+263572|0;f=0;do{n=c[h+(f<<2)>>2]|0;o=(ca(n,d)|0)/(e|0)|0;p=(ca(n,i)|0)/(e|0)|0;n=c[j>>2]|0;q=c[n+32+(f<<2)>>2]|0;r=(c[n+(f<<2)>>2]|0)+(ca(q,o)|0)|0;n=c[k>>2]|0;s=c[n+32+(f<<2)>>2]|0;t=(c[n+(f<<2)>>2]|0)+(ca(s,o)|0)|0;n=c[b+(f<<2)>>2]|0;u=c[a+49468+(f*49428|0)+272>>2]|0;v=c[a+49468+(f*49428|0)+4>>2]|0;do{if((u|0)==0){if((r|0)==(t|0)){break}uIb(r,q,t,s,n,p-o|0)}else{if((o|0)>=(p|0)){break}w=(v&2|0)==0;x=(v&8|0)==0;y=a+49468+(f*49428|0)+264|0;z=t;A=o;B=r;while(1){C=A&4095;if(w){D=c[a+247180+(C<<2)>>2]|0}else{E=c[y>>2]|0;c[a+49468+(f*49428|0)+8+((E&63)<<2)>>2]=(c[a+49468+(f*49428|0)+8+((E+9&63)<<2)>>2]|0)+(c[a+49468+(f*49428|0)+8+((E+40&63)<<2)>>2]|0);E=c[y>>2]|0;c[y>>2]=E+1;D=c[a+49468+(f*49428|0)+8+((E&63)<<2)>>2]&1023}if(x){pe[c[l>>2]&1023](B,z,u,n,D)}else{mf[c[m>>2]&2047](B,z,n,a+49468+(f*49428|0)+276+(C*12|0)|0);c[a+49468+(f*49428|0)+276+(C*12|0)+((D&3)<<2)>>2]=u+D}C=A+1|0;if((C|0)<(p|0)){z=z+s|0;A=C;B=B+q|0}else{break}}}}while(0);f=f+1|0;}while((f|0)<(c[g>>2]|0));return 0}function xr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+44>>2]|0;if((c[d+12>>2]|0)!=0){KIb(a,24,2437632,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c[d+28>>2]=3}a=d+472|0;e=d+648|0;if((c[a>>2]|0)==0){f=5}else{g=c[e>>2]|0;if((g|0)==2){f=5}else{h=g}}if((f|0)==5){c[a>>2]=0;c[e>>2]=2;h=2}e=d+468|0;if(!((c[e>>2]|0)!=0|(h|0)==1)){j=d+464|0;k=j;c[k>>2]=146;i=b;return 0}c[e>>2]=1;c[d+648>>2]=1;j=d+464|0;k=j;c[k>>2]=146;i=b;return 0}function yr(a){a=a|0;var b=0;b=c[a+44>>2]|0;Vz(b+40|0);a=b+652|0;TGb(c[a>>2]|0);c[a>>2]=0;a=b+656|0;TGb(c[a>>2]|0);c[a>>2]=0;return}function zr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[(c[a+44>>2]|0)+28>>2]|0;if((d|0)==1){e=Ok(686856)|0;f=Ok(686776)|0;g=e}else if((d|0)==3){e=Ok(686888)|0;f=Ok(686792)|0;g=e}else if((d|0)==0){e=Ok(686872)|0;f=Ok(686784)|0;g=e}else if((d|0)==2){d=Ok(686840)|0;f=Ok(686768)|0;g=d}else{KIb(0,0,2474336,(d=i,i=i+24|0,c[d>>2]=2465696,c[d+8>>2]=2454712,c[d+16>>2]=254,d)|0);i=d;Hd();return 0}d=a+16|0;Yk(g,(c[c[d>>2]>>2]|0)+68|0);Yk(f,(c[(c[d>>2]|0)+4>>2]|0)+68|0);Yk(g,(c[c[a+32>>2]>>2]|0)+64|0);i=b;return 0}function Ar(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0;g=i;f=a+44|0;e=c[f>>2]|0;do{if((irc(b,2426824)|0)==0){j=e+652|0;l=a;m=c[j>>2]|0;n=UGb(j,d,281456,0,0,0,0,0,l)|0;if((n|0)>=0){TGb(m);break}KIb(l,16,2234e3,(o=i,i=i+16|0,c[o>>2]=d,c[o+8>>2]=b,o)|0);i=o;c[j>>2]=m;p=n;i=g;return p|0}else{if((irc(b,2343168)|0)!=0){p=-38;i=g;return p|0}n=e+656|0;m=a;j=c[n>>2]|0;l=UGb(n,d,281456,0,0,0,0,0,m)|0;if((l|0)>=0){TGb(j);break}KIb(m,16,2234e3,(o=i,i=i+16|0,c[o>>2]=d,c[o+8>>2]=b,o)|0);i=o;c[n>>2]=j;p=l;i=g;return p|0}}while(0);if((c[e+32>>2]|0)!=0){p=0;i=g;return p|0}b=c[f>>2]|0;f=b+652|0;d=b+520|0;l=b+600|0;h[l>>3]=+XGb(c[f>>2]|0,d,0);j=b+608|0;h[j>>3]=+XGb(c[b+656>>2]|0,d,0);q=+XGb(c[f>>2]|0,d,0);h[l>>3]=q;h[k>>3]=q;l=c[k+4>>2]&2147483647;d=2146435072;if(l>>>0>d>>>0|l>>>0==d>>>0&(c[k>>2]|0)>>>0>0>>>0){r=2147483647}else{r=-1<<c[b+512>>2]&~~q}c[b+4>>2]=r;r=c[j+4>>2]&2147483647;d=2146435072;if(r>>>0>d>>>0|r>>>0==d>>>0&(c[j>>2]|0)>>>0>0>>>0){s=2147483647}else{s=-1<<c[b+516>>2]&~~+h[j>>3]}c[b+8>>2]=s;s=c[e+4>>2]|0;q=+h[e+608>>3];b=c[e+8>>2]|0;KIb(a,40,2283392,(o=i,i=i+32|0,h[o>>3]=+h[e+600>>3],c[o+8>>2]=s,h[o+16>>3]=q,c[o+24>>2]=b,o)|0);i=o;p=0;i=g;return p|0}function Br(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0.0,v=0.0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;g=i;j=b+44|0;l=c[j>>2]|0;m=c[c[b+16>>2]>>2]|0;if((c[l+32>>2]|0)==1){n=DHb(e)|0;o=G;p=m+160|0;q=l+616|0;h[q>>3]=+((c[p>>2]|0)>>>0)+ +(c[p+4>>2]|0)*4294967296.0;p=e+136|0;s=c[p>>2]|0;t=c[p+4>>2]|0;if((s|0)==0&(t|0)==(-2147483648|0)){u=+r}else{u=(+(s>>>0)+ +(t|0)*4294967296.0)*(+(c[m+56>>2]|0)/+(c[m+60>>2]|0))}m=l+632|0;h[m>>3]=u;if((n|0)==(-1|0)&(o|0)==(-1|0)){v=+r}else{v=+(n>>>0)+ +(o|0)*4294967296.0}o=l+624|0;h[o>>3]=v;n=c[j>>2]|0;t=n+652|0;s=n+520|0;p=n+600|0;h[p>>3]=+XGb(c[t>>2]|0,s,0);w=n+608|0;h[w>>3]=+XGb(c[n+656>>2]|0,s,0);v=+XGb(c[t>>2]|0,s,0);h[p>>3]=v;h[k>>3]=v;p=c[k+4>>2]&2147483647;s=2146435072;if(p>>>0>s>>>0|p>>>0==s>>>0&(c[k>>2]|0)>>>0>0>>>0){x=2147483647}else{x=-1<<c[n+512>>2]&~~v}c[n+4>>2]=x;x=c[w+4>>2]&2147483647;s=2146435072;if(x>>>0>s>>>0|x>>>0==s>>>0&(c[w>>2]|0)>>>0>0>>>0){y=2147483647}else{y=-1<<c[n+516>>2]&~~+h[w>>3]}c[n+8>>2]=y;v=+h[m>>3];u=+h[o>>3];z=+h[l+600>>3];o=l+4|0;m=c[o>>2]|0;A=+h[l+608>>3];y=l+8|0;n=c[y>>2]|0;KIb(b,48,2427176,(b=i,i=i+56|0,h[b>>3]=+h[q>>3],h[b+8>>3]=v,h[b+16>>3]=u,h[b+24>>3]=z,c[b+32>>2]=m,h[b+40>>3]=A,c[b+48>>2]=n,b)|0);i=b;B=c[j>>2]|0;C=o;D=y}else{B=l;C=l+4|0;D=l+8|0}l=c[C>>2]|0;C=c[D>>2]|0;D=c[f+68>>2]|0;y=c[f+72>>2]|0;o=c[e+68>>2]|0;j=c[e+72>>2]|0;if((o|0)<=(l|0)){i=g;return e|0}if(!((D+l|0)>-1&(j|0)>(C|0))){i=g;return e|0}if((y+C|0)<0){i=g;return e|0}if((a[B+16|0]|0)!=0){b=d[B+17|0]|0;n=d[B+18|0]|0;m=d[B+19|0]|0;q=d[B+20|0]|0;w=c[B+480>>2]|0;s=d[B+23|0]|0;x=d[B+24|0]|0;p=d[B+25|0]|0;t=d[B+26|0]|0;E=c[B+496>>2]|0;F=(C|0)<0?-C|0:0;H=f+32|0;I=e+32|0;J=j-C|0;K=(J|0)>(y|0)?y:J;if((F|0)>=(K|0)){i=g;return e|0}J=c[I>>2]|0;L=c[H>>2]|0;M=ca(J,F+C|0)|0;N=ca(L,F)|0;O=(l|0)<0?-l|0:0;P=ca(E,O)|0;Q=ca(w,O+l|0)|0;R=o-l|0;S=(R|0)>(D|0)?D:R;R=(O|0)<(S|0);T=(a[B+21|0]|0)!=0;U=(c[e>>2]|0)+M|0;M=(c[f>>2]|0)+N|0;N=F;F=J;J=L;while(1){if(R){L=U+Q|0;V=M+P|0;W=O;while(1){X=V+t|0;Y=a[X]|0;do{if(T){Z=Y&255;if((Y<<24>>24|0)==0|(Y<<24>>24|0)==(-1|0)){_=Y;break}$=d[L+q|0]|0;_=((Z*65025|0|0)/((($+Z|0)*255|0)-(ca($,Z)|0)|0)|0)&255}else{_=Y}}while(0);Y=_&255;if((Y|0)==255){a[L+b|0]=a[V+s|0]|0;a[L+n|0]=a[V+x|0]|0;a[L+m|0]=a[V+p|0]|0}else if((Y|0)!=0){Z=L+b|0;$=Y^255;aa=ca(d[Z]|0,$)|0;a[Z]=((((ca(d[V+s|0]|0,Y)|0)+aa|0)*257|0)+32896|0)>>>16;aa=L+n|0;Z=ca(d[aa]|0,$)|0;a[aa]=((((ca(d[V+x|0]|0,Y)|0)+Z|0)*257|0)+32896|0)>>>16;Z=L+m|0;aa=ca(d[Z]|0,$)|0;a[Z]=((((ca(d[V+p|0]|0,Y)|0)+aa|0)*257|0)+32896|0)>>>16}do{if(T){if((Y|0)==255){a[L+q|0]=a[X]|0;break}else if((Y|0)==0){break}else{aa=L+q|0;Z=d[aa]|0;a[aa]=(((ca((d[X]|0)*257|0,Z^255)|0)+32896|0)>>>16)+Z;break}}}while(0);X=W+1|0;if((X|0)<(S|0)){L=L+w|0;V=V+E|0;W=X}else{break}}ba=c[I>>2]|0;da=c[H>>2]|0}else{ba=F;da=J}W=N+1|0;if((W|0)<(K|0)){U=U+ba|0;M=M+da|0;N=W;F=ba;J=da}else{break}}i=g;return e|0}da=(a[B+21|0]|0)!=0;do{if(da){J=(C|0)<0?-C|0:0;ba=f+12|0;F=f+44|0;N=e+44|0;M=j-C|0;U=(M|0)>(y|0)?y:M;if((J|0)>=(U|0)){ea=ba;fa=F;break}M=(l|0)<0?-l|0:0;K=M+l|0;H=o-l|0;I=(H|0)>(D|0)?D:H;if((M|0)>=(I|0)){ea=ba;fa=F;break}H=ca(c[F>>2]|0,J)|0;E=(c[ba>>2]|0)+H|0;H=(c[e+12>>2]|0)+(ca(c[N>>2]|0,J+C|0)|0)|0;w=J;while(1){J=E+M|0;S=H+K|0;q=M;while(1){T=a[J]|0;p=T&255;if((T<<24>>24|0)==0|(T<<24>>24|0)==(-1|0)){ga=T}else{m=d[S]|0;ga=((p*65025|0|0)/(((m+p|0)*255|0)-(ca(m,p)|0)|0)|0)&255}m=ga&255;if((m|0)==255){a[S]=T}else if((m|0)!=0){m=d[S]|0;a[S]=(((ca(p*257|0,m^255)|0)+32896|0)>>>16)+m}m=q+1|0;if((m|0)<(I|0)){J=J+1|0;S=S+1|0;q=m}else{break}}q=w+1|0;if((q|0)<(U|0)){E=E+(c[F>>2]|0)|0;H=H+(c[N>>2]|0)|0;w=q}else{ea=ba;fa=F;break}}}else{ea=f+12|0;fa=f+44|0}}while(0);ga=-D|0;D=-y|0;y=-o|0;o=-j|0;j=B+512|0;F=B+516|0;B=0;do{if((B|0)==0){ha=0;ia=0}else{ha=c[F>>2]|0;ia=c[j>>2]|0}ba=-(ga>>ia)|0;w=-(D>>ha)|0;N=C>>ha;H=l>>ia;E=(N|0)<0?-N|0:0;U=f+32+(B<<2)|0;I=e+32+(B<<2)|0;M=-(N+(o>>ha)|0)|0;K=(M|0)>(w|0)?w:M;if((E|0)<(K|0)){M=c[fa>>2]|0;q=c[I>>2]|0;S=c[U>>2]|0;J=ca(M,E<<ha)|0;m=ca(q,E+N|0)|0;N=ca(S,E)|0;p=(H|0)<0?-H|0:0;T=p+H|0;x=p<<ia;n=-(H+(y>>ia)|0)|0;H=(n|0)>(ba|0)?ba:n;n=(p|0)<(H|0);s=(ia|0)!=0;b=s^1;_=(ha|0)==0;t=_|b;O=_&b;b=1<<ia;P=E;E=(c[f+(B<<2)>>2]|0)+N|0;N=(c[e+(B<<2)>>2]|0)+m|0;m=(c[ea>>2]|0)+J|0;J=q;q=S;S=M;while(1){if(n){M=P+1|0;Q=(M|0)>=(w|0);R=t|Q;W=_|Q;Q=p;V=E+p|0;L=N+T|0;X=m+x|0;while(1){do{if(R){ja=57}else{if((Q+1|0)>=(ba|0)){ja=57;break}Y=c[fa>>2]|0;ka=((d[X+Y|0]|0)+(d[X]|0)+(d[X+1|0]|0)+(d[X+(Y+1)|0]|0)|0)>>>2}}while(0);do{if((ja|0)==57){ja=0;if(O){ka=d[X]|0;break}do{if(s){if((Q+1|0)>=(ba|0)){ja=61;break}Y=a[X]|0;la=((d[X+1|0]|0)+(Y&255)|0)>>>1;ma=Y}else{ja=61}}while(0);if((ja|0)==61){ja=0;Y=a[X]|0;la=Y&255;ma=Y}Y=ma&255;if(W){na=Y}else{na=((d[X+(c[fa>>2]|0)|0]|0)+Y|0)>>>1}ka=(na+la|0)>>>1}}while(0);do{if(da){if((ka|0)==0){oa=0;break}else if((ka|0)==255){oa=255;break}do{if(R){ja=72}else{if((Q+1|0)>=(ba|0)){ja=72;break}Y=c[fa>>2]|0;pa=((d[L+Y|0]|0)+(d[L]|0)+(d[L+1|0]|0)+(d[L+(Y+1)|0]|0)|0)>>>2&255}}while(0);do{if((ja|0)==72){ja=0;if(O){pa=a[L]|0;break}do{if(s){if((Q+1|0)>=(ba|0)){ja=76;break}Y=a[L]|0;qa=((d[L+1|0]|0)+(Y&255)|0)>>>1;ra=Y}else{ja=76}}while(0);if((ja|0)==76){ja=0;Y=a[L]|0;qa=Y&255;ra=Y}Y=ra&255;if(W){sa=Y}else{sa=((d[L+(c[fa>>2]|0)|0]|0)+Y|0)>>>1}pa=(sa+qa|0)>>>1&255}}while(0);Y=pa&255;oa=(ka*65025|0|0)/(((Y+ka|0)*255|0)-(ca(Y,ka)|0)|0)|0}else{oa=ka}}while(0);Y=ca(d[L]|0,255-oa|0)|0;a[L]=((((ca(d[V]|0,oa)|0)+Y|0)*257|0)+32896|0)>>>16;Y=Q+1|0;if((Y|0)<(H|0)){Q=Y;V=V+1|0;L=L+1|0;X=X+b|0}else{break}}ta=c[I>>2]|0;ua=c[U>>2]|0;va=c[fa>>2]|0;wa=M}else{ta=J;ua=q;va=S;wa=P+1|0}if((wa|0)<(K|0)){P=wa;E=E+ua|0;N=N+ta|0;m=m+(va<<ha)|0;J=ta;q=ua;S=va}else{break}}}B=B+1|0;}while((B|0)<3);i=g;return e|0}function Cr(a){a=a|0;return Uz((c[(c[a>>2]|0)+44>>2]|0)+40|0,a)|0}function Dr(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;d=Rz(b,(c[b+44>>2]|0)+40|0)|0;if((d|0)<0){e=d;return e|0}d=c[c[b+16>>2]>>2]|0;c[a+20>>2]=c[d+20>>2];c[a+24>>2]=c[d+24>>2];b=d+56|0;d=a+56|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;e=0;return e|0}function Er(a,b){a=a|0;b=b|0;return Tz((c[(c[a+8>>2]|0)+44>>2]|0)+40|0,a,b)|0}function Fr(b){b=b|0;var e=0,f=0;e=c[(c[b+8>>2]|0)+44>>2]|0;f=b+52|0;b=qKb(c[f>>2]|0)|0;nIb(e+480|0,0,b);c[e+512>>2]=d[b+5|0]|0;c[e+516>>2]=d[b+6|0]|0;a[e+16|0]=(Kz(e+17|0,c[f>>2]|0)|0)>>>31&255^1;a[e+21|0]=Nk(c[f>>2]|0,2021168)|0;return 0}function Gr(b){b=b|0;var e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0.0,q=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=c[b+8>>2]|0;g=f+44|0;j=c[g>>2]|0;l=b+52|0;b=qKb(c[l>>2]|0)|0;nIb(j+496|0,0,b);m=f+16|0;n=c[m>>2]|0;o=c[n>>2]|0;p=+(c[o+20>>2]|0);h[j+528>>3]=p;h[j+520>>3]=p;p=+(c[o+24>>2]|0);h[j+544>>3]=p;h[j+536>>3]=p;o=c[n+4>>2]|0;p=+(c[o+20>>2]|0);h[j+560>>3]=p;h[j+552>>3]=p;p=+(c[o+24>>2]|0);h[j+576>>3]=p;h[j+568>>3]=p;h[j+584>>3]=+(1<<(d[b+5|0]|0)|0);h[j+592>>3]=+(1<<(d[b+6|0]|0)|0);b=j+600|0;h[b>>3]=+r;o=j+608|0;h[o>>3]=+r;h[j+616>>3]=0.0;h[j+632>>3]=+r;h[j+624>>3]=+r;n=j+652|0;q=c[j+640>>2]|0;s=f;f=c[n>>2]|0;t=UGb(n,q,281456,0,0,0,0,0,s)|0;if((t|0)<0){KIb(s,16,2234e3,(u=i,i=i+16|0,c[u>>2]=q,c[u+8>>2]=2426824,u)|0);i=u;c[n>>2]=f;v=t;i=e;return v|0}TGb(f);f=j+656|0;t=c[j+644>>2]|0;n=c[f>>2]|0;q=UGb(f,t,281456,0,0,0,0,0,s)|0;if((q|0)<0){KIb(s,16,2234e3,(u=i,i=i+16|0,c[u>>2]=t,c[u+8>>2]=2343168,u)|0);i=u;c[f>>2]=n;v=q;i=e;return v|0}TGb(n);a[j+22|0]=(Kz(j+23|0,c[l>>2]|0)|0)>>>31&255^1;a[j+27|0]=Nk(c[l>>2]|0,2021168)|0;if((c[j+32>>2]|0)==0){l=c[g>>2]|0;g=l+652|0;n=l+520|0;q=l+600|0;h[q>>3]=+XGb(c[g>>2]|0,n,0);f=l+608|0;h[f>>3]=+XGb(c[l+656>>2]|0,n,0);p=+XGb(c[g>>2]|0,n,0);h[q>>3]=p;h[k>>3]=p;q=c[k+4>>2]&2147483647;n=2146435072;if(q>>>0>n>>>0|q>>>0==n>>>0&(c[k>>2]|0)>>>0>0>>>0){w=2147483647}else{w=-1<<c[l+512>>2]&~~p}c[l+4>>2]=w;w=c[f+4>>2]&2147483647;n=2146435072;if(w>>>0>n>>>0|w>>>0==n>>>0&(c[f>>2]|0)>>>0>0>>>0){x=2147483647}else{x=-1<<c[l+516>>2]&~~+h[f>>3]}c[l+8>>2]=x;x=c[j+4>>2]|0;p=+h[o>>3];o=c[j+8>>2]|0;KIb(s,40,2283392,(u=i,i=i+32|0,h[u>>3]=+h[b>>3],c[u+8>>2]=x,h[u+16>>3]=p,c[u+24>>2]=o,u)|0);i=u}o=c[c[m>>2]>>2]|0;x=c[o+20>>2]|0;b=c[o+24>>2]|0;l=mKb(c[o+52>>2]|0)|0;o=c[(c[m>>2]|0)+4>>2]|0;m=c[o+20>>2]|0;f=c[o+24>>2]|0;n=mKb(c[o+52>>2]|0)|0;o=c[1510720+(c[j+648>>2]<<2)>>2]|0;KIb(s,40,2230656,(u=i,i=i+56|0,c[u>>2]=x,c[u+8>>2]=b,c[u+16>>2]=l,c[u+24>>2]=m,c[u+32>>2]=f,c[u+40>>2]=n,c[u+48>>2]=o,u)|0);i=u;v=0;i=e;return v|0}function Hr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+44>>2]|0;a=b+24|0;d=b+28|0;if((c[a>>2]|0)<0){return}else{e=0}do{mJb(d+(e<<4)|0);e=e+1|0;f=c[a>>2]|0;}while((e|0)<=(f|0));if((f|0)<0){return}else{g=0}do{mJb(d+(g<<4)+4|0);g=g+1|0;h=c[a>>2]|0;}while((g|0)<=(h|0));if((h|0)<0){return}else{i=0}do{mJb(d+(i<<4)+8|0);i=i+1|0;j=c[a>>2]|0;}while((i|0)<=(j|0));if((j|0)<0){return}else{k=0}do{mJb(d+(k<<4)+12|0);k=k+1|0;}while((k|0)<=(c[a>>2]|0));return}function Ir(a){a=a|0;dl(a,Ok(685336)|0);return 0}function Jr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;j=g;k=c[c[f+32>>2]>>2]|0;f=a+20|0;l=-(-(c[f>>2]|0)>>c[g+304>>2])|0;m=a+24|0;a=-(-(c[m>>2]|0)>>c[g+308>>2])|0;do{if((bIb(b)|0)==0){n=bv(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((n|0)!=0){ZHb(n,c[e>>2]|0)|0;o=0;p=n;q=c[e>>2]|0;break}VHb(e);r=-12;i=d;return r|0}else{o=1;p=b;q=b}}while(0);Lr(j,c[p>>2]|0,c[p+32>>2]|0,c[q>>2]|0,c[q+32>>2]|0,c[f>>2]|0,c[m>>2]|0,+h[g+8>>3]);q=c[e>>2]|0;b=g+16|0;Lr(j,c[p+4>>2]|0,c[p+36>>2]|0,c[q+4>>2]|0,c[q+36>>2]|0,l,a,+h[b>>3]);q=c[e>>2]|0;Lr(j,c[p+8>>2]|0,c[p+40>>2]|0,c[q+8>>2]|0,c[q+40>>2]|0,l,a,+h[b>>3]);if(!o){o=c[e>>2]|0;b=c[o+12>>2]|0;if((b|0)!=0){uIb(c[p+12>>2]|0,c[p+44>>2]|0,b,c[o+44>>2]|0,c[f>>2]|0,c[m>>2]|0)}VHb(e)}r=lj(k,p)|0;i=d;return r|0}function Kr(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;f=c[a+24>>2]|0;c[b+304>>2]=d[e+5|0]|0;c[b+308>>2]=d[e+6|0]|0;e=b+300|0;c[e>>2]=(c[a+20>>2]|0)+15&-16;a=b+24|0;g=(f<<2)+60&-64;f=b+28|0;b=0;while(1){h=c[a>>2]|0;if((b|0)>(h|0)){i=0;j=h;break}h=hJb(ca(g,c[e>>2]|0)|0)|0;c[f+(b<<4)>>2]=h;if((h|0)==0){k=-12;l=4;break}else{b=b+1|0}}if((l|0)==4){return k|0}while(1){if((i|0)>(j|0)){m=0;n=j;break}b=hJb(ca(g,c[e>>2]|0)|0)|0;c[f+(i<<4)+4>>2]=b;if((b|0)==0){k=-12;l=4;break}i=i+1|0;j=c[a>>2]|0}if((l|0)==4){return k|0}while(1){if((m|0)>(n|0)){o=0;p=n;break}j=hJb(ca(g,c[e>>2]|0)|0)|0;c[f+(m<<4)+8>>2]=j;if((j|0)==0){k=-12;l=4;break}m=m+1|0;n=c[a>>2]|0}if((l|0)==4){return k|0}while(1){if((o|0)>(p|0)){k=0;l=4;break}n=hJb(ca(g,c[e>>2]|0)|0)|0;c[f+(o<<4)+12>>2]=n;if((n|0)==0){k=-12;l=4;break}o=o+1|0;p=c[a>>2]|0}if((l|0)==4){return k|0}return 0}function Lr(b,e,f,h,i,j,k,l){b=b|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=+l;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0;m=c[b+24>>2]|0;while(1){n=1<<m;if((n|0)>(j|0)|(n|0)>(k|0)){m=m-1|0}else{break}}n=(k|0)>0;if(n){o=(j|0)>0;p=b+300|0;q=b+28|0;r=0;do{if(o){s=ca(r,i)|0;t=c[p>>2]|0;u=c[q>>2]|0;v=0;do{g[u+((ca(t,r)|0)+v<<2)>>2]=+((d[h+(v+s)|0]|0)>>>0);v=v+1|0;}while((v|0)<(j|0))}r=r+1|0;}while((r|0)<(k|0))}r=(m|0)>0;do{if(r){h=b+32|0;q=b+300|0;p=b+36|0;i=0;while(1){o=i+1|0;v=c[q>>2]|0;s=1<<i;Nr(c[h>>2]|0,c[p>>2]|0,c[b+28+(i<<4)>>2]|0,1,v,s,j,k);Nr(c[b+28+(o<<4)>>2]|0,c[b+28+(o<<4)+4>>2]|0,c[h>>2]|0,v,1,s,k,j);Nr(c[b+28+(o<<4)+8>>2]|0,c[b+28+(o<<4)+12>>2]|0,c[p>>2]|0,v,1,s,k,j);if((o|0)<(m|0)){i=o}else{break}}if(!r){break}i=(j|0)>0;p=b+300|0;w=-0.0-l;h=0;do{h=h+1|0;do{if(n){q=b+28+(h<<4)+4|0;o=0;do{if(i){s=ca(c[p>>2]|0,o)|0;v=c[q>>2]|0;t=0;do{u=v+(s+t<<2)|0;x=+g[u>>2];do{if(x>l){y=x-l}else{if(!(x<w)){y=0.0;break}y=x+l}}while(0);g[u>>2]=y;t=t+1|0;}while((t|0)<(j|0))}o=o+1|0;}while((o|0)<(k|0));if(!n){break}o=b+28+(h<<4)+8|0;q=0;do{if(i){t=ca(c[p>>2]|0,q)|0;s=c[o>>2]|0;v=0;do{z=s+(t+v<<2)|0;x=+g[z>>2];do{if(x>l){A=x-l}else{if(!(x<w)){A=0.0;break}A=x+l}}while(0);g[z>>2]=A;v=v+1|0;}while((v|0)<(j|0))}q=q+1|0;}while((q|0)<(k|0));if(!n){break}q=b+28+(h<<4)+12|0;o=0;do{if(i){v=ca(c[p>>2]|0,o)|0;t=c[q>>2]|0;s=0;do{u=t+(v+s<<2)|0;x=+g[u>>2];do{if(x>l){B=x-l}else{if(!(x<w)){B=0.0;break}B=x+l}}while(0);g[u>>2]=B;s=s+1|0;}while((s|0)<(j|0))}o=o+1|0;}while((o|0)<(k|0))}}while(0);}while((h|0)<(m|0));if(!r){break}h=b+32|0;p=b+300|0;i=b+36|0;o=m;while(1){q=o-1|0;s=c[b+28+(q<<4)>>2]|0;v=c[p>>2]|0;t=1<<q;Mr(c[h>>2]|0,c[b+28+(o<<4)>>2]|0,c[b+28+(o<<4)+4>>2]|0,v,1,t,k,j);Mr(c[i>>2]|0,c[b+28+(o<<4)+8>>2]|0,c[b+28+(o<<4)+12>>2]|0,v,1,t,k,j);Mr(s,c[h>>2]|0,c[i>>2]|0,1,v,t,j,k);if((q|0)>0){o=q}else{break}}}}while(0);if(!n){return}n=(j|0)>0;m=b+300|0;r=b+28|0;b=0;do{if(n){o=b&7;i=ca(b,f)|0;h=0;do{p=(ca(c[m>>2]|0,b)|0)+h|0;q=~~(+g[(c[r>>2]|0)+(p<<2)>>2]+ +(d[1532240+((h&7)<<3)+o|0]|0|0)*.015625+.0078125);if(q>>>0>255>>>0){C=(q>>31^255)&255}else{C=q&255}a[e+(h+i)|0]=C;h=h+1|0;}while((h|0)<(j|0))}b=b+1|0;}while((b|0)<(k|0));return}function Mr(a,b,c,d,e,f,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((j|0)<=0){return}k=(f|0)>0;l=ca(f,d)|0;m=f-1+i|0;i=0;do{if(k){n=ca(i,e)|0;o=0;do{p=(ca(o,d)|0)+n|0;q=(m-o|0)/(f|0)|0;if((q|0)>0){r=q-1|0;s=r<<1;t=0;do{u=(ca(t,l)|0)+p|0;v=+g[b+(u<<2)>>2]*.7884856164056598;w=+g[c+(u<<2)>>2]*.8526986790094001;x=1;do{y=t-x|0;if(y>>>0>r>>>0){z=y;while(1){A=((z|0)>0?s:0)-z|0;if(A>>>0>r>>>0){z=A}else{B=A;break}}}else{B=y}z=ca(B,l)|0;A=x+t|0;if(A>>>0>r>>>0){C=A;while(1){D=((C|0)>0?s:0)-C|0;if(D>>>0>r>>>0){C=D}else{E=D;break}}}else{E=A}C=ca(E,l)|0;y=z+p|0;D=C+p|0;v=v+ +h[1077328+(x<<3)>>3]*(+g[b+(y<<2)>>2]+ +g[b+(D<<2)>>2]);w=w+ +h[1077368+(x<<3)>>3]*(+g[c+(y<<2)>>2]+ +g[c+(D<<2)>>2]);x=x+1|0;}while((x|0)<5);g[a+(u<<2)>>2]=(v+w)*.5;t=t+1|0;}while((t|0)<(q|0))}o=o+1|0;}while((o|0)<(f|0))}i=i+1|0;}while((i|0)<(j|0));return}function Nr(a,b,c,d,e,f,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0;if((j|0)<=0){return}k=ca(f,d)|0;l=f-1+i|0;if((f|0)>0){m=0}else{return}do{i=ca(m,e)|0;n=0;do{o=(ca(n,d)|0)+i|0;p=(l-n|0)/(f|0)|0;if((p|0)>0){q=p-1|0;r=q<<1;s=0;do{t=(ca(s,k)|0)+o|0;u=+g[c+(t<<2)>>2];v=1;w=u*.8526986790094001;x=u*.7884856164056598;do{y=s-v|0;if(y>>>0>q>>>0){z=y;while(1){A=((z|0)>0?r:0)-z|0;if(A>>>0>q>>>0){z=A}else{B=A;break}}}else{B=y}u=+g[c+((ca(B,k)|0)+o<<2)>>2];z=v+s|0;if(z>>>0>q>>>0){A=z;while(1){C=((A|0)>0?r:0)-A|0;if(C>>>0>q>>>0){A=C}else{D=C;break}}}else{D=z}E=u+ +g[c+((ca(D,k)|0)+o<<2)>>2];w=w+ +h[1648672+(v<<3)>>3]*E;x=x+ +h[1648712+(v<<3)>>3]*E;v=v+1|0;}while((v|0)<5);g[a+(t<<2)>>2]=w;g[b+(t<<2)>>2]=x;s=s+1|0;}while((s|0)<(p|0))}n=n+1|0;}while((n|0)<(f|0));m=m+1|0;}while((m|0)<(j|0));return}function Or(a){a=a|0;dl(a,Qz(0)|0);return 0}function Pr(a){a=a|0;var b=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+4>>2];c[a+24>>2]=c[b+8>>2];return 0}function Qr(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=bv(c[c[f+32>>2]>>2]|0,(c[a+4>>2]|0)+b-(c[a+20>>2]|0)|0,(c[a+8>>2]|0)+e-(c[a+24>>2]|0)|0)|0;if((g|0)==0){h=0;return h|0}c[g+68>>2]=b;c[g+72>>2]=e;e=g|0;b=c[e>>2]|0;if((b|0)==0){h=g;return h|0}f=c[g+32>>2]|0;if((f|0)==0){h=g;return h|0}i=c[a+12>>2]|0;j=ca(i>>(d[a+80|0]|0),c[a+60>>2]|0)|0;k=c[a+16>>2]|0;c[e>>2]=b+((ca(k>>(d[a+84|0]|0),f)|0)+j);j=g+4|0;f=c[j>>2]|0;if((f|0)==0){h=g;return h|0}b=c[g+36>>2]|0;if((b|0)==0){h=g;return h|0}c[j>>2]=f+((ca(k>>(d[a+85|0]|0),b)|0)+(ca(i>>(d[a+81|0]|0),c[a+64>>2]|0)|0));b=g+8|0;f=c[b>>2]|0;if((f|0)==0){h=g;return h|0}j=c[g+40>>2]|0;if((j|0)==0){h=g;return h|0}c[b>>2]=f+((ca(k>>(d[a+86|0]|0),j)|0)+(ca(i>>(d[a+82|0]|0),c[a+68>>2]|0)|0));j=g+12|0;f=c[j>>2]|0;if((f|0)==0){h=g;return h|0}b=c[g+44>>2]|0;if((b|0)==0){h=g;return h|0}c[j>>2]=f+((ca(k>>(d[a+87|0]|0),b)|0)+(ca(i>>(d[a+83|0]|0),c[a+72>>2]|0)|0));h=g;return h|0}function Rr(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;e=i;i=i+24|0;f=e|0;g=e+16|0;c[g>>2]=b;h=a+8|0;j=c[(c[h>>2]|0)+44>>2]|0;k=j;a:do{if((bIb(b)|0)==0){l=j+4|0;m=j+8|0;n=41}else{o=f;p=f|0;q=b|0;r=b+72|0;s=j+12|0;t=j+16|0;u=j+4|0;v=b+68|0;w=j+8|0;x=f+4|0;y=b+4|0;z=b+8|0;A=b+12|0;B=f+8|0;C=f+12|0;D=0;do{E=c[b+360+(D<<2)>>2]|0;if((E|0)==0){break}mrc(o|0,-1|0,16)|0;do{if((c[q>>2]|0)!=0){if((eIb(b,0)|0)==(E|0)){c[p>>2]=0;F=x}else{F=p}if((c[y>>2]|0)==0){break}if((eIb(b,1)|0)==(E|0)){c[F>>2]=1;G=F+4|0}else{G=F}if((c[z>>2]|0)==0){break}if((eIb(b,2)|0)==(E|0)){c[G>>2]=2;H=G+4|0}else{H=G}if((c[A>>2]|0)==0){break}if((eIb(b,3)|0)!=(E|0)){break}c[H>>2]=3}}while(0);I=E+4|0;J=E+8|0;K=c[p>>2]|0;L=(K|0)>-1;M=b+(K<<2)|0;N=c[x>>2]|0;O=(N|0)>-1;P=b+(N<<2)|0;Q=c[B>>2]|0;R=(Q|0)>-1;S=b+(Q<<2)|0;T=c[C>>2]|0;U=(T|0)>-1;V=b+(T<<2)|0;W=k+84+T|0;X=b+32+(T<<2)|0;T=k+84+Q|0;Y=b+32+(Q<<2)|0;Q=k+84+N|0;Z=b+32+(N<<2)|0;N=k+84+K|0;_=b+32+(K<<2)|0;$=0;aa=K;b:while(1){if(!((aa|0)>-1)){break}K=d[k+80+aa|0]|0;ba=d[k+84+aa|0]|0;da=c[b+(aa<<2)>>2]|0;ea=c[r>>2]|0;fa=c[b+32+(aa<<2)>>2]|0;ga=da+(ca(ea>>ba,fa)|0)|0;ha=c[s>>2]|0;ia=c[k+60+(aa<<2)>>2]|0;ja=ca(ha>>K,ia)|0;ka=c[t>>2]|0;la=(ca(ka>>ba,fa)|0)+ja|0;ja=c[u>>2]|0;ma=ca(ja-ha-(c[v>>2]|0)>>K,ia)|0;ha=(ca((c[w>>2]|0)-(ka+ea)>>ba,fa)|0)+ma|0;if((fa|0)<(ca(ja>>K,ia)|0)){l=u;m=w;n=41;break a}ia=c[I>>2]|0;K=da;if((K-ia|0)<(la|0)){l=u;m=w;n=41;break a}da=ga;if((ia+(c[J>>2]|0)-da|0)<(ha|0)){l=u;m=w;n=41;break a}do{if(L){ia=c[M>>2]|0;if(($|0)!=0){ga=K-(ia+(ca(ea>>(d[N]|0),c[_>>2]|0)|0))|0;if((((ga|0)>0?1:-1)|0)!=(((ga-la|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}ga=da-ia|0;if((((ga|0)>0?1:-1)|0)!=(((ga+ha|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}}if(!O){break}ga=c[P>>2]|0;if(($|0)!=1){ia=K-(ga+(ca(ea>>(d[Q]|0),c[Z>>2]|0)|0))|0;if((((ia|0)>0?1:-1)|0)!=(((ia-la|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}ia=da-ga|0;if((((ia|0)>0?1:-1)|0)!=(((ia+ha|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}}if(!R){break}ia=c[S>>2]|0;if(($|0)!=2){ga=K-(ia+(ca(ea>>(d[T]|0),c[Y>>2]|0)|0))|0;if((((ga|0)>0?1:-1)|0)!=(((ga-la|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}ga=da-ia|0;if((((ga|0)>0?1:-1)|0)!=(((ga+ha|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}}if(!U){break}ga=c[V>>2]|0;if(($|0)==3){break b}ia=K-(ga+(ca(ea>>(d[W]|0),c[X>>2]|0)|0))|0;if((((ia|0)>0?1:-1)|0)!=(((ia-la|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}ia=da-ga|0;if((((ia|0)>0?1:-1)|0)!=(((ia+ha|0)>0?1:-1)|0)){l=u;m=w;n=41;break a}}}while(0);ha=$+1|0;if(!(ha>>>0<4>>>0)){break}$=ha;aa=c[f+(ha<<2)>>2]|0}D=D+1|0;}while((D|0)<4);D=c[g>>2]|0;w=D|0;u=c[w>>2]|0;if((u|0)==0){na=D;oa=0;pa=t;break}v=c[D+32>>2]|0;if((v|0)==0){na=D;oa=0;pa=t;break}r=c[s>>2]|0;C=ca(r>>(d[j+80|0]|0),c[j+60>>2]|0)|0;B=c[t>>2]|0;c[w>>2]=u+(-(C+(ca(B>>(d[j+84|0]|0),v)|0)|0)|0);v=D+4|0;C=c[v>>2]|0;if((C|0)==0){na=D;oa=0;pa=t;break}u=c[D+36>>2]|0;if((u|0)==0){na=D;oa=0;pa=t;break}c[v>>2]=C+(-((ca(r>>(d[j+81|0]|0),c[j+64>>2]|0)|0)+(ca(B>>(d[j+85|0]|0),u)|0)|0)|0);u=D+8|0;C=c[u>>2]|0;if((C|0)==0){na=D;oa=0;pa=t;break}v=c[D+40>>2]|0;if((v|0)==0){na=D;oa=0;pa=t;break}c[u>>2]=C+(-((ca(r>>(d[j+82|0]|0),c[j+68>>2]|0)|0)+(ca(B>>(d[j+86|0]|0),v)|0)|0)|0);v=D+12|0;C=c[v>>2]|0;if((C|0)==0){na=D;oa=0;pa=t;break}u=c[D+44>>2]|0;if((u|0)==0){na=D;oa=0;pa=t;break}c[v>>2]=C+(-((ca(r>>(d[j+83|0]|0),c[j+72>>2]|0)|0)+(ca(B>>(d[j+87|0]|0),u)|0)|0)|0);na=D;oa=0;pa=t}}while(0);do{if((n|0)==41){KIb(c[h>>2]|0,48,2337424,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;f=c[a+20>>2]|0;k=c[l>>2]|0;b=c[a+24>>2]|0;H=c[m>>2]|0;G=bv(c[c[(c[h>>2]|0)+32>>2]>>2]|0,(f|0)>(k|0)?f:k,(b|0)>(H|0)?b:H)|0;if((G|0)!=0){ZHb(G,c[g>>2]|0)|0;na=G;oa=1;pa=j+16|0;break}VHb(g);qa=-12;i=e;return qa|0}}while(0);m=c[pa>>2]|0;if((m|0)==0){ra=0}else{Oz(j+48|0,j+92|0,na|0,na+32|0,0,0,c[j+4>>2]|0,m);ra=c[pa>>2]|0}m=j+8|0;a=c[m>>2]|0;l=c[j+24>>2]|0;n=l+ra|0;G=j+48|0;H=j+92|0;b=na|0;k=na+32|0;if((a|0)>(n|0)){Oz(G,H,b,k,0,n,c[j+4>>2]|0,a-ra-l|0);sa=c[pa>>2]|0}else{sa=ra}ra=j+12|0;Oz(G,H,b,k,0,sa,c[ra>>2]|0,c[(c[g>>2]|0)+72>>2]|0);if(oa){oa=c[g>>2]|0;Nz(G,b,k,oa|0,oa+32|0,c[ra>>2]|0,c[pa>>2]|0,0,0,c[oa+68>>2]|0,c[oa+72>>2]|0)}oa=(c[j+20>>2]|0)+(c[ra>>2]|0)|0;ra=j+4|0;Oz(G,H,b,k,oa,c[pa>>2]|0,(c[ra>>2]|0)-oa|0,c[(c[g>>2]|0)+72>>2]|0);c[na+68>>2]=c[ra>>2];c[na+72>>2]=c[m>>2];if((c[g>>2]|0)!=(na|0)){VHb(g)}qa=lj(c[c[(c[h>>2]|0)+32>>2]>>2]|0,na)|0;i=e;return qa|0}function Sr(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0.0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;b=i;i=i+128|0;e=b|0;f=b+120|0;g=c[a+8>>2]|0;j=c[g+44>>2]|0;k=j+48|0;Lz(k,c[a+52>>2]|0,0)|0;l=j+44|0;Mz(k,j+92|0,l);m=a+20|0;n=+(c[m>>2]|0);h[e+8>>3]=n;o=e|0;h[o>>3]=n;p=a+24|0;q=+(c[p>>2]|0);h[e+24>>3]=q;h[e+16>>3]=q;s=e+40|0;h[s>>3]=+r;t=e+32|0;h[t>>3]=+r;u=e+56|0;h[u>>3]=+r;v=e+48|0;h[v>>3]=+r;w=n/q;h[e+80>>3]=w;x=c[a+28>>2]|0;if((x|0)==0){y=1.0}else{y=+(x|0)/+(c[a+32>>2]|0)}h[e+88>>3]=y;h[e+96>>3]=y*w;h[e+104>>3]=+(1<<(d[j+88|0]|0)|0);h[e+112>>3]=+(1<<(d[j+89|0]|0)|0);a=j+28|0;x=g;ZGb(f,c[a>>2]|0,281392,o,0,0,0,0,0,0,x)|0;w=+h[f>>3];h[s>>3]=w;h[t>>3]=w;g=j+4|0;c[g>>2]=~~w;z=c[j+32>>2]|0;A=ZGb(f,z,281392,o,0,0,0,0,0,0,x)|0;do{if((A|0)<0){B=z;C=A}else{w=+h[f>>3];h[u>>3]=w;h[v>>3]=w;D=j+8|0;c[D>>2]=~~w;E=c[a>>2]|0;F=ZGb(f,E,281392,o,0,0,0,0,0,0,x)|0;if((F|0)<0){B=E;C=F;break}w=+h[f>>3];h[s>>3]=w;h[t>>3]=w;c[g>>2]=~~w;F=j+36|0;ZGb(f,c[F>>2]|0,281392,o,0,0,0,0,0,0,x)|0;w=+h[f>>3];E=e+64|0;h[E>>3]=w;G=j+12|0;c[G>>2]=~~w;H=c[j+40>>2]|0;I=ZGb(f,H,281392,o,0,0,0,0,0,0,x)|0;if((I|0)<0){B=H;C=I;break}w=+h[f>>3];h[e+72>>3]=w;I=j+16|0;c[I>>2]=~~w;H=c[F>>2]|0;F=ZGb(f,H,281392,o,0,0,0,0,0,0,x)|0;if((F|0)<0){B=H;C=F;break}w=+h[f>>3];h[E>>3]=w;E=~~w;c[G>>2]=E;F=c[g>>2]|0;do{if((F|0)>=0){H=c[D>>2]|0;if((H|E|0)<0){break}if((c[I>>2]|0)<0){break}if((F|0)==0){J=c[m>>2]|0;c[g>>2]=J;K=J}else{K=F}if((H|0)==0){c[D>>2]=c[p>>2]}c[g>>2]=Pz(k,0,-1,K)|0;c[D>>2]=Pz(k,1,-1,c[D>>2]|0)|0;c[G>>2]=Pz(k,0,-1,c[G>>2]|0)|0;c[I>>2]=Pz(k,1,-1,c[I>>2]|0)|0;c[j+20>>2]=Pz(k,0,-1,c[m>>2]|0)|0;c[j+24>>2]=Pz(k,1,-1,c[p>>2]|0)|0;H=c[p>>2]|0;J=c[g>>2]|0;L=c[D>>2]|0;M=c[G>>2]|0;N=c[I>>2]|0;O=d[l]|0;P=d[j+45|0]|0;Q=d[j+46|0]|0;R=d[j+47|0]|0;KIb(x,40,2465632,(S=i,i=i+80|0,c[S>>2]=c[m>>2],c[S+8>>2]=H,c[S+16>>2]=J,c[S+24>>2]=L,c[S+32>>2]=M,c[S+40>>2]=N,c[S+48>>2]=O,c[S+56>>2]=P,c[S+64>>2]=Q,c[S+72>>2]=R,S)|0);i=S;R=c[G>>2]|0;Q=c[I>>2]|0;do{if((R|Q|0)>=0){P=c[g>>2]|0;if((P|0)<1){break}O=c[D>>2]|0;if((O|0)<1){break}if(((c[m>>2]|0)+R|0)>>>0>P>>>0){break}if(((c[p>>2]|0)+Q|0)>>>0>O>>>0){break}else{T=0}i=b;return T|0}}while(0);O=(c[m>>2]|0)+R|0;P=(c[p>>2]|0)+Q|0;N=c[g>>2]|0;M=c[D>>2]|0;KIb(x,16,2454536,(S=i,i=i+48|0,c[S>>2]=R,c[S+8>>2]=Q,c[S+16>>2]=O,c[S+24>>2]=P,c[S+32>>2]=N,c[S+40>>2]=M,S)|0);i=S;T=-22;i=b;return T|0}}while(0);KIb(x,16,2474280,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;T=-22;i=b;return T|0}}while(0);KIb(0,16,2437544,(S=i,i=i+8|0,c[S>>2]=B,S)|0);i=S;T=C;i=b;return T|0}function Tr(a){a=a|0;var b=0;b=c[a+44>>2]|0;a=c[b+4204>>2]|0;if((a|0)==0){c[b+4252>>2]=118;return 0}else if((a|0)==1){c[b+4252>>2]=36;return 0}else{return 0}return 0}function Ur(a){a=a|0;mJb((c[a+44>>2]|0)+104|0);return}function Vr(a){a=a|0;dl(a,Ok(685264)|0);return 0}function Wr(b,e,f,g,h,i,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;m=c[b+4208>>2]|0;if((j|0)<=0){return}n=b+104|0;b=i-1|0;o=j-1|0;if((i|0)>0){p=0}else{return}do{q=ca(p<<l,m)|0;r=ca(p,f)|0;s=0;do{t=(s<<k)+q|0;u=c[n>>2]|0;v=c[u+(t<<3)>>2]>>k;w=c[u+(t<<3)+4>>2]>>l;t=v&255;u=w&255;x=v>>8;v=w>>8;w=ca(v,h)|0;y=w+x|0;z=256-t|0;A=256-u|0;do{if(x>>>0<b>>>0){if(v>>>0<o>>>0){B=ca(d[g+y|0]|0,z)|0;C=ca((ca(d[g+(y+1)|0]|0,t)|0)+B|0,A)|0;B=y+h|0;D=ca(d[g+B|0]|0,z)|0;E=C+32768+(ca((ca(d[g+(B+1)|0]|0,t)|0)+D|0,u)|0)>>16;if((E|0)<0){F=0;break}else{G=E;H=11;break}}else{E=(ca((v|0)<0?0:o,h)|0)+x|0;D=ca(d[g+E|0]|0,z)|0;G=(D+128+(ca(d[g+(E+1)|0]|0,t)|0)|0)>>>8;H=11;break}}else{E=(x|0)<0?0:b;if(v>>>0<o>>>0){D=E+w|0;B=ca(d[g+D|0]|0,A)|0;G=(B+128+(ca(d[g+(D+h)|0]|0,u)|0)|0)>>>8;H=11;break}else{G=d[g+((ca((v|0)<0?0:o,h)|0)+E)|0]|0;H=11;break}}}while(0);if((H|0)==11){H=0;F=(G|0)>255?-1:G&255}a[e+(s+r)|0]=F;s=s+1|0;}while((s|0)<(i|0));p=p+1|0;}while((p|0)<(j|0));return}function Xr(b,e,f,g,h,i,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;m=c[b+4208>>2]|0;if((j|0)<=0){return}n=(i|0)>0;o=b+104|0;p=i-2|0;q=j-2|0;r=h<<1;s=i-1|0;t=j-1|0;u=0;do{if(n){v=ca(u<<l,m)|0;w=ca(u,f)|0;x=0;do{y=(x<<k)+v|0;z=c[o>>2]|0;A=c[z+(y<<3)>>2]>>k;B=c[z+(y<<3)+4>>2]>>l;y=A&255;z=B&255;C=A>>8;A=B>>8;if((C|0)>0&(A|0)>0&(C|0)<(p|0)&(A|0)<(q|0)){B=(ca(A,h)|0)+C|0;D=c[b+108+(y<<4)>>2]|0;E=c[b+108+(y<<4)+4>>2]|0;F=c[b+108+(y<<4)+8>>2]|0;G=c[b+108+(y<<4)+12>>2]|0;H=B-1|0;I=ca(d[g+(H-h)|0]|0,D)|0;J=(ca(d[g+(B-h)|0]|0,E)|0)+I|0;I=B+1|0;K=J+(ca(d[g+(I-h)|0]|0,F)|0)|0;J=B+2|0;L=ca(K+(ca(d[g+(J-h)|0]|0,G)|0)|0,c[b+108+(z<<4)>>2]|0)|0;K=ca(d[g+H|0]|0,D)|0;M=(ca(d[g+B|0]|0,E)|0)+K|0;K=M+(ca(d[g+I|0]|0,F)|0)|0;M=(ca(K+(ca(d[g+J|0]|0,G)|0)|0,c[b+108+(z<<4)+4>>2]|0)|0)+L|0;L=ca(d[g+(H+h)|0]|0,D)|0;K=(ca(d[g+(B+h)|0]|0,E)|0)+L|0;L=K+(ca(d[g+(I+h)|0]|0,F)|0)|0;K=M+(ca(L+(ca(d[g+(J+h)|0]|0,G)|0)|0,c[b+108+(z<<4)+8>>2]|0)|0)|0;L=ca(d[g+(H+r)|0]|0,D)|0;D=(ca(d[g+(B+r)|0]|0,E)|0)+L|0;L=D+(ca(d[g+(I+r)|0]|0,F)|0)|0;N=K+(ca(L+(ca(d[g+(J+r)|0]|0,G)|0)|0,c[b+108+(z<<4)+12>>2]|0)|0)|0}else{G=A-1|0;A=C-1|0;J=0;L=0;while(1){K=G+L|0;if((K|0)<0){O=0}else{O=(K|0)<(j|0)?K:t}K=c[b+108+(z<<4)+(L<<2)>>2]|0;F=ca(O,h)|0;if((A|0)<0){P=0}else{P=(A|0)<(i|0)?A:s}I=ca(K,c[b+108+(y<<4)>>2]|0)|0;D=(ca(I,d[g+(P+F)|0]|0)|0)+J|0;if((C|0)<0){Q=0}else{Q=(C|0)<(i|0)?C:s}I=ca(K,c[b+108+(y<<4)+4>>2]|0)|0;E=(ca(I,d[g+(Q+F)|0]|0)|0)+D|0;D=C+1|0;if((D|0)<0){R=0}else{R=(D|0)<(i|0)?D:s}D=ca(K,c[b+108+(y<<4)+8>>2]|0)|0;I=(ca(D,d[g+(R+F)|0]|0)|0)+E|0;E=C+2|0;if((E|0)<0){S=0}else{S=(E|0)<(i|0)?E:s}E=ca(K,c[b+108+(y<<4)+12>>2]|0)|0;K=(ca(E,d[g+(S+F)|0]|0)|0)+I|0;I=L+1|0;if((I|0)<4){J=K;L=I}else{N=K;break}}}L=N+2097152>>22;if((L|0)<0){T=0}else{T=(L|0)>255?-1:L&255}a[e+(x+w)|0]=T;x=x+1|0;}while((x|0)<(i|0))}u=u+1|0;}while((u|0)<(j|0));return}function Yr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[c[f+32>>2]>>2]|0;g=c[f+44>>2]|0;f=g;h=bv(a,c[a+20>>2]|0,c[a+24>>2]|0)|0;if((h|0)==0){VHb(e);j=-12;i=d;return j|0}ZHb(h,b)|0;b=g+4248|0;if((c[b>>2]|0)>0){k=g+4240|0;l=g+4244|0;m=g+4252|0;n=g+4208|0;o=g+4224|0;g=0;do{if((g-1|0)>>>0<2>>>0){p=c[l>>2]|0;q=c[k>>2]|0}else{p=0;q=0}r=c[e>>2]|0;Te[c[m>>2]&255](f,c[h+(g<<2)>>2]|0,c[h+32+(g<<2)>>2]|0,c[r+(g<<2)>>2]|0,c[r+32+(g<<2)>>2]|0,c[n+(g<<2)>>2]|0,c[o+(g<<2)>>2]|0,q,p);g=g+1|0;}while((g|0)<(c[b>>2]|0))}VHb(e);j=lj(a,h)|0;i=d;return j|0}function Zr(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0,S=0.0,T=0.0,U=0.0,V=0.0,W=0.0;b=i;i=i+16|0;e=b|0;f=c[a+8>>2]|0;g=c[f+44>>2]|0;j=g+40|0;k=j;l=a+52|0;m=qKb(c[l>>2]|0)|0;n=e|0;o=a+20|0;p=c[o>>2]|0;q=+(p|0);h[n>>3]=q;r=a+24|0;a=c[r>>2]|0;s=+(a|0);h[e+8>>3]=s;e=g+4|0;t=f;f=0;while(1){if((f|0)>=2){u=0;v=30;break}w=c[e+(f<<2)>>2]|0;if((w|0)==0){x=-22;v=17;break}y=ZGb(k+(f<<3)|0,w,281376,n,0,0,0,0,0,0,t)|0;if((y|0)<0){x=y;v=17;break}else{f=f+1|0}}if((v|0)==17){i=b;return x|0}else if((v|0)==30){while(1){v=0;if((u|0)>=2){z=0;v=33;break}f=c[e+8+(u<<2)>>2]|0;if((f|0)==0){x=-22;v=17;break}y=ZGb(k+16+(u<<3)|0,f,281376,n,0,0,0,0,0,0,t)|0;if((y|0)<0){x=y;v=17;break}else{u=u+1|0;v=30}}if((v|0)==17){i=b;return x|0}else if((v|0)==33){while(1){v=0;if((z|0)>=2){A=0;v=36;break}u=c[e+16+(z<<2)>>2]|0;if((u|0)==0){x=-22;v=17;break}y=ZGb(k+32+(z<<3)|0,u,281376,n,0,0,0,0,0,0,t)|0;if((y|0)<0){x=y;v=17;break}else{z=z+1|0;v=33}}if((v|0)==17){i=b;return x|0}else if((v|0)==36){while(1){v=0;if((A|0)>=2){v=37;break}z=c[e+24+(A<<2)>>2]|0;if((z|0)==0){x=-22;v=17;break}y=ZGb(k+48+(A<<3)|0,z,281376,n,0,0,0,0,0,0,t)|0;if((y|0)<0){x=y;v=17;break}else{A=A+1|0;v=36}}if((v|0)==17){i=b;return x|0}else if((v|0)==37){c[g+4240>>2]=d[m+5|0]|0;v=m+6|0;c[g+4244>>2]=d[v]|0;c[g+4248>>2]=uKb(c[l>>2]|0)|0;m=pIb(g+4208|0,c[l>>2]|0,c[o>>2]|0)|0;if((m|0)<0){x=m;i=b;return x|0}m=-(-(c[r>>2]|0)>>(d[v]|0))|0;c[g+4232>>2]=m;c[g+4228>>2]=m;m=c[r>>2]|0;c[g+4236>>2]=m;c[g+4224>>2]=m;m=g+104|0;r=jJb(c[m>>2]|0,ca(p,a)|0,16)|0;v=r;c[m>>2]=v;if((r|0)==0){x=-12;i=b;return x|0}B=+h[j>>3];C=+h[g+56>>3];D=+h[g+72>>3];E=+h[g+88>>3];F=B-C-D+E;G=+h[g+80>>3];H=+h[g+96>>3];I=G-H;J=+h[g+48>>3];K=+h[g+64>>3];L=H+(J-K-G);M=D-E;N=s*(F*I-M*L);O=C-E;E=K-H;H=q*(O*L-F*E);F=O*I-M*E;E=s*(C-B)*F+C*N;C=q*(D-B)*F+D*H;D=s*q*B*F;B=s*(K-J)*F+K*N;K=q*(G-J)*F+G*H;G=s*q*J*F;do{if((a|0)>0){J=s*q*F;if((p|0)>0){P=0}else{break}do{M=+(P|0);I=C*M;O=H*M;L=K*M;j=ca(P,p)|0;r=0;do{M=+(r|0);S=J+(O+N*M);m=~~+Q((G+(L+B*M))*256.0/S+.5);o=r+j|0;c[v+(o<<3)>>2]=~~+Q((D+(I+E*M))*256.0/S+.5);c[v+(o<<3)+4>>2]=m;r=r+1|0;}while((r|0)<(p|0));P=P+1|0;}while((P|0)<(a|0))}}while(0);a=g+108|0;g=0;while(1){E=+(g|0)*.00390625;D=+R(+(0.0-E+-1.0));do{if(D<1.0){T=1.0-D*D*2.4+D*D*D*1.4}else{if(!(D<2.0)){T=0.0;break}T=D*-4.8+2.4-D*D*-3.0+D*D*D*-.6}}while(0);D=+R(+(1.0-E+-1.0));do{if(D<1.0){U=1.0-D*D*2.4+D*D*D*1.4}else{if(!(D<2.0)){U=0.0;break}U=D*-4.8+2.4-D*D*-3.0+D*D*D*-.6}}while(0);D=+R(+(2.0-E+-1.0));do{if(D<1.0){V=1.0-D*D*2.4+D*D*D*1.4}else{if(!(D<2.0)){V=0.0;break}V=D*-4.8+2.4-D*D*-3.0+D*D*D*-.6}}while(0);D=+R(+(3.0-E+-1.0));do{if(D<1.0){W=1.0-D*D*2.4+D*D*D*1.4}else{if(!(D<2.0)){W=0.0;break}W=D*-4.8+2.4-D*D*-3.0+D*D*D*-.6}}while(0);D=T+0.0+U+V+W;c[a+(g<<4)>>2]=~~+Q(T*2048.0/D+.5);c[a+(g<<4)+4>>2]=~~+Q(U*2048.0/D+.5);c[a+(g<<4)+8>>2]=~~+Q(V*2048.0/D+.5);c[a+(g<<4)+12>>2]=~~+Q(W*2048.0/D+.5);P=g+1|0;if((P|0)<256){g=P}else{x=0;break}}i=b;return x|0}}}}return 0}function _r(a){a=a|0;VHb((c[a+44>>2]|0)+8|0);return}function $r(a){a=a|0;dl(a,Ok(685192)|0);return 0}function as(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,R=0.0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0.0,Ma=0.0,Na=0.0,Oa=0.0,Pa=0.0,Qa=0.0,Ra=0,Sa=0.0,Ta=0.0,Ua=0.0,Va=0,Wa=0.0,Xa=0.0,Ya=0,Za=0.0,_a=0,$a=0;e=i;i=i+16|0;f=e|0;g=e+8|0;c[f>>2]=b;j=c[a+8>>2]|0;a=c[c[j+32>>2]>>2]|0;k=c[j+44>>2]|0;l=a+20|0;m=a+24|0;n=bv(a,c[l>>2]|0,c[m>>2]|0)|0;c[g>>2]=n;if((n|0)==0){VHb(f);o=-12;i=e;return o|0}ZHb(n,b)|0;b=k+8|0;n=c[b>>2]|0;do{if((n|0)==0){p=bv(a,c[l>>2]|0,c[m>>2]|0)|0;c[b>>2]=p;if((p|0)!=0){q=0;break}VHb(f);VHb(g);o=-12;i=e;return o|0}else{p=c[f>>2]|0;r=c[k+4>>2]|0;s=c[n>>2]|0;t=c[n+32>>2]|0;u=c[p+32>>2]|0;v=c[p>>2]|0;w=c[p+72>>2]|0;x=c[p+68>>2]|0;do{if((r|0)==7){if((c[p+296>>2]|0)==0){y=65536.0;z=65536.0;A=0;B=65536.0;C=j;D=61;break}else{E=(c[p+300>>2]|0)!=0?1:2;D=60;break}}else if((r|0)==8){if((c[p+296>>2]|0)==0){F=6;D=13;break}F=(c[p+300>>2]|0)!=0?3:4;D=13}else{if(r>>>0<3>>>0){E=r;D=60}else{F=r;D=13}}}while(0);do{if((D|0)==13){r=ca(w-2|0,u)|0;p=v+r|0;a:do{if((u|0)<(r|0)){G=u<<1;H=-u|0;I=-t|0;J=t<<1;K=u-x|0;L=t-x|0;M=(x|0)>0;N=v+u|0;O=s+t|0;P=0.0;Q=0.0;R=0.0;S=0;b:while(1){T=N;do{if((F|0)==4){U=N+x|0;if((S|0)==0){if(!M){V=0;W=0;X=0;Y=O;Z=N;break}_=N+1|0;$=(U>>>0>_>>>0?U:_)+(-T|0)|0;_=N;aa=O;ba=0;da=0;while(1){ea=d[_]|0;fa=d[_+G|0]|0;ga=(ea-(d[_+u|0]|0)<<2)+fa-(d[_+H|0]|0)|0;ha=(ca(ga,ga)|0)+da|0;ga=fa-(d[aa+I|0]|0)+(ea-(d[aa+t|0]|0)<<2)|0;ia=(ca(ga,ga)|0)+ba|0;ja=_+1|0;if(ja>>>0<U>>>0){_=ja;aa=aa+1|0;ba=ia;da=ha}else{break}}V=ha;W=0;X=ia;Y=O+$|0;Z=ja;break}else{if(!M){V=0;W=0;X=0;Y=O;Z=N;break}da=N+1|0;ba=(U>>>0>da>>>0?U:da)+(-T|0)|0;da=N;aa=O;_=0;ga=0;while(1){ea=d[da+u|0]|0;fa=d[da+H|0]|0;ka=((d[da]|0)-ea<<2)+(d[da+G|0]|0)-fa|0;la=(ca(ka,ka)|0)+ga|0;ka=(d[aa+J|0]|0)-fa+((d[aa]|0)-ea<<2)|0;ma=(ca(ka,ka)|0)+_|0;na=da+1|0;if(na>>>0<U>>>0){da=na;aa=aa+1|0;_=ma;ga=la}else{break}}V=la;W=0;X=ma;Y=O+ba|0;Z=na;break}}else if((F|0)==5){ga=N+x|0;if((S|0)==0){if(!M){V=0;W=0;X=0;Y=O;Z=N;break}_=N+1|0;aa=(ga>>>0>_>>>0?ga:_)+(-T|0)|0;_=N;da=O;U=0;$=0;while(1){ka=((d[_]|0)-(d[da+t|0]|0)<<2)+(d[_+G|0]|0)-(d[da+I|0]|0)|0;oa=(ca(ka,ka)|0)+U|0;ka=((d[da]|0)-(d[_+u|0]|0)<<2)+(d[da+J|0]|0)-(d[_+H|0]|0)|0;pa=(ca(ka,ka)|0)+$|0;qa=_+1|0;if(qa>>>0<ga>>>0){_=qa;da=da+1|0;U=oa;$=pa}else{break}}V=0;W=pa;X=oa;Y=O+aa|0;Z=qa;break}else{if(!M){V=0;W=0;X=0;Y=O;Z=N;break}$=N+1|0;U=(ga>>>0>$>>>0?ga:$)+(-T|0)|0;$=N;da=O;_=0;ba=0;while(1){ka=((d[$]|0)-(d[da+t|0]|0)<<2)+(d[$+G|0]|0)-(d[da+I|0]|0)|0;ra=(ca(ka,ka)|0)+ba|0;ka=((d[da]|0)-(d[$+u|0]|0)<<2)+(d[da+J|0]|0)-(d[$+H|0]|0)|0;sa=(ca(ka,ka)|0)+_|0;ta=$+1|0;if(ta>>>0<ga>>>0){$=ta;da=da+1|0;_=sa;ba=ra}else{break}}V=0;W=ra;X=sa;Y=O+U|0;Z=ta;break}}else if((F|0)==3){ba=N+x|0;if((S|0)==0){if(!M){V=0;W=0;X=0;Y=O;Z=N;break}_=N+1|0;da=(ba>>>0>_>>>0?ba:_)+(-T|0)|0;_=N;$=O;ga=0;aa=0;while(1){ka=d[_+u|0]|0;ea=d[_+H|0]|0;fa=((d[_]|0)-ka<<2)+(d[_+G|0]|0)-ea|0;ua=(ca(fa,fa)|0)+aa|0;fa=(d[$+J|0]|0)-ea+((d[$]|0)-ka<<2)|0;va=(ca(fa,fa)|0)+ga|0;wa=_+1|0;if(wa>>>0<ba>>>0){_=wa;$=$+1|0;ga=va;aa=ua}else{break}}V=ua;W=va;X=0;Y=O+da|0;Z=wa;break}else{if(!M){V=0;W=0;X=0;Y=O;Z=N;break}aa=N+1|0;ga=(ba>>>0>aa>>>0?ba:aa)+(-T|0)|0;aa=N;$=O;_=0;U=0;while(1){fa=d[aa]|0;ka=d[aa+G|0]|0;ea=(fa-(d[aa+u|0]|0)<<2)+ka-(d[aa+H|0]|0)|0;xa=(ca(ea,ea)|0)+U|0;ea=ka-(d[$+I|0]|0)+(fa-(d[$+t|0]|0)<<2)|0;ya=(ca(ea,ea)|0)+_|0;za=aa+1|0;if(za>>>0<ba>>>0){aa=za;$=$+1|0;_=ya;U=xa}else{break}}V=xa;W=ya;X=0;Y=O+ga|0;Z=za;break}}else if((F|0)==6){U=N+x|0;if((S|0)==0){if(!M){V=0;W=0;X=0;Y=O;Z=N;break}_=N+1|0;$=(U>>>0>_>>>0?U:_)+(-T|0)|0;_=N;aa=O;ba=0;da=0;ea=0;while(1){fa=d[_]|0;ka=d[_+u|0]|0;Aa=d[_+G|0]|0;Ba=d[_+H|0]|0;Ca=(fa-ka<<2)+Aa-Ba|0;Da=(ca(Ca,Ca)|0)+ea|0;Ca=Aa-(d[aa+I|0]|0)+(fa-(d[aa+t|0]|0)<<2)|0;Ea=(ca(Ca,Ca)|0)+ba|0;Ca=(d[aa+J|0]|0)-Ba+((d[aa]|0)-ka<<2)|0;Fa=(ca(Ca,Ca)|0)+da|0;Ga=_+1|0;if(Ga>>>0<U>>>0){_=Ga;aa=aa+1|0;ba=Ea;da=Fa;ea=Da}else{break}}V=Da;W=Fa;X=Ea;Y=O+$|0;Z=Ga;break}else{if(!M){V=0;W=0;X=0;Y=O;Z=N;break}ea=N+1|0;da=(U>>>0>ea>>>0?U:ea)+(-T|0)|0;ea=N;ba=O;aa=0;_=0;ga=0;while(1){Ca=d[ea]|0;ka=d[ea+u|0]|0;Ba=d[ea+G|0]|0;fa=d[ea+H|0]|0;Aa=(Ca-ka<<2)+Ba-fa|0;Ha=(ca(Aa,Aa)|0)+ga|0;Aa=Ba-(d[ba+I|0]|0)+(Ca-(d[ba+t|0]|0)<<2)|0;Ia=(ca(Aa,Aa)|0)+_|0;Aa=(d[ba+J|0]|0)-fa+((d[ba]|0)-ka<<2)|0;Ja=(ca(Aa,Aa)|0)+aa|0;Ka=ea+1|0;if(Ka>>>0<U>>>0){ea=Ka;ba=ba+1|0;aa=Ja;_=Ia;ga=Ha}else{break}}V=Ha;W=Ia;X=Ja;Y=O+da|0;Z=Ka;break}}else{break b}}while(0);La=P+ +(V|0);Ma=Q+ +(W|0);Na=R+ +(X|0);T=Z+K|0;if(T>>>0<p>>>0){N=T;O=Y+L|0;P=La;Q=Ma;R=Na;S=S^1}else{Oa=La;Pa=Ma;Qa=Na;break a}}KIb(0,0,2427080,(Ra=i,i=i+24|0,c[Ra>>2]=2416824,c[Ra+8>>2]=2407960,c[Ra+16>>2]=203,Ra)|0);i=Ra;Hd();return 0}else{Oa=0.0;Pa=0.0;Qa=0.0}}while(0);R=1.0/+(ca(x,w-3|0)|0)/25.0;Q=Oa*R;P=Pa*R;Na=Qa*R;if((F|0)==4){Sa=Na;Ta=65536.0;Ua=Q}else if((F|0)==3){Sa=65536.0;Ta=P;Ua=Q}else{Sa=Na;Ta=P;Ua=(F|0)==5?65536.0:Q}if(Sa<Ua&Sa<Ta){Va=98;Wa=Ua;Xa=Ta;Ya=2;Za=Sa;_a=j;break}else{y=Ua;z=Ta;A=Ta<Ua&Ta<Sa&1;B=Sa;C=j;D=61;break}}else if((D|0)==60){p=j;if((E|0)==2){Va=98;Wa=65536.0;Xa=65536.0;Ya=2;Za=65536.0;_a=p}else{y=65536.0;z=65536.0;A=E;B=65536.0;C=p;D=61}}}while(0);if((D|0)==61){Va=(A|0)==1?116:112;Wa=y;Xa=z;Ya=A;Za=B;_a=C}KIb(_a,48,2400552,(Ra=i,i=i+32|0,c[Ra>>2]=Va,h[Ra+8>>3]=Xa,h[Ra+16>>3]=Za,h[Ra+24>>3]=Wa,Ra)|0);i=Ra;q=Ya}}while(0);Ya=k+12|0;Ra=c[Ya>>2]|0;if((Ra|0)>0){Va=k+16|0;_a=k+32|0;k=0;C=Ra;while(1){Ra=Va+(k<<2)|0;if((c[Ra>>2]|0)>0){A=_a+(k<<2)|0;D=1;E=0;j=c[(c[b>>2]|0)+(k<<2)>>2]|0;F=c[(c[f>>2]|0)+(k<<2)>>2]|0;Y=c[(c[g>>2]|0)+(k<<2)>>2]|0;while(1){nrc(Y|0,((q|0)==(((D|0)!=0?2:1)|0)?j:F)|0,c[A>>2]|0)|0;nrc(j|0,F|0,c[A>>2]|0)|0;Z=E+1|0;if((Z|0)<(c[Ra>>2]|0)){D=D^1;E=Z;j=j+(c[(c[b>>2]|0)+32+(k<<2)>>2]|0)|0;F=F+(c[(c[f>>2]|0)+32+(k<<2)>>2]|0)|0;Y=Y+(c[(c[g>>2]|0)+32+(k<<2)>>2]|0)|0}else{break}}$a=c[Ya>>2]|0}else{$a=C}Y=k+1|0;if((Y|0)<($a|0)){k=Y;C=$a}else{break}}}VHb(f);o=lj(a,c[g>>2]|0)|0;i=e;return o|0}function bs(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=qKb(c[e>>2]|0)|0;g=pIb(b+32|0,c[e>>2]|0,c[a+20>>2]|0)|0;if((g|0)<0){h=g;return h|0}g=a+24|0;a=-(-(c[g>>2]|0)>>(d[f+6|0]|0))|0;c[b+24>>2]=a;c[b+20>>2]=a;a=c[g>>2]|0;c[b+28>>2]=a;c[b+16>>2]=a;c[b+12>>2]=uKb(c[e>>2]|0)|0;h=0;return h|0}function cs(a){a=a|0;mJb((c[a+44>>2]|0)+4|0);return}function ds(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=c[b+8>>2]|0;j=c[h+44>>2]|0;k=c[c[h+32>>2]>>2]|0;h=c[b+20>>2]|0;l=c[b+24>>2]|0;b=j;m=c[b>>2]|0;n=-(-h>>d[m+5|0])|0;o=-l>>d[m+6|0];m=-o|0;p=bv(k,c[k+20>>2]|0,c[k+24>>2]|0)|0;if((p|0)==0){VHb(g);q=-12;i=f;return q|0}ZHb(p,e)|0;e=p|0;r=c[e>>2]|0;if((r|0)!=0){s=c[p+32>>2]|0;if((s|0)>0){t=0}else{t=ca(s,l-1|0)|0}mrc(r+t|0,0,ca((s|0)>-1?s:-s|0,l)|0)|0}s=p+4|0;t=c[s>>2]|0;if((t|0)!=0){r=c[p+36>>2]|0;if((r|0)>0){u=0}else{u=ca(r,~o)|0}mrc(t+u|0,0,ca((r|0)>-1?r:-r|0,m)|0)|0}r=c[p+8>>2]|0;if((r|0)!=0){u=c[p+40>>2]|0;if((u|0)>0){v=0}else{v=ca(u,~o)|0}mrc(r+v|0,0,ca((u|0)>-1?u:-u|0,m)|0)|0}u=c[p+12>>2]|0;if((u|0)!=0){v=c[p+44>>2]|0;if((v|0)>0){w=0}else{w=ca(v,l-1|0)|0}mrc(u+w|0,0,ca((v|0)>-1?v:-v|0,l)|0)|0}v=c[b>>2]|0;if((a[v+7|0]&66)==0){x=v}else{nrc(c[s>>2]|0,c[(c[g>>2]|0)+4>>2]|0,1024)|0;x=c[b>>2]|0}if((a[x+4|0]|0)!=0){s=j+4|0;j=p+32|0;v=0;w=x;while(1){x=(v-1|0)>>>0<2>>>0;u=x?n:h;r=x?m:l;if((r|0)>0){x=0;o=w;while(1){t=c[g>>2]|0;kKb(c[s>>2]|0,t|0,t+32|0,o,0,x,v,u,0);lKb(c[s>>2]|0,e,j,c[b>>2]|0,0,x,v,u);t=x+1|0;y=c[b>>2]|0;if((t|0)<(r|0)){x=t;o=y}else{z=y;break}}}else{z=w}o=v+1|0;if((o|0)<(d[z+4|0]|0)){v=o;w=z}else{break}}}VHb(g);q=lj(k,p)|0;i=f;return q|0}function es(a){a=a|0;var b=0,d=0;b=c[(c[a+8>>2]|0)+44>>2]|0;c[b>>2]=qKb(c[a+52>>2]|0)|0;d=b+4|0;mJb(d);b=hJb(c[a+20>>2]<<1)|0;c[d>>2]=b;return((b|0)==0?-12:0)|0}function fs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+44>>2]|0;a=b+4|0;d=b+12|0;e=0;while(1){if((e|0)>=7){break}f=jvb(c[a>>2]|0,e)|0;c[d+(e<<2)>>2]=f;if((f|0)==0){g=-542398533;h=5;break}else{e=e+1|0}}if((h|0)==5){return g|0}c[b+8>>2]=6;g=0;return g|0}function gs(a){a=a|0;var b=0;b=c[a+44>>2]|0;kvb(c[b+12>>2]|0);kvb(c[b+16>>2]|0);kvb(c[b+20>>2]|0);kvb(c[b+24>>2]|0);kvb(c[b+28>>2]|0);kvb(c[b+32>>2]|0);kvb(c[b+36>>2]|0);a=c[b+40>>2]|0;if((a|0)==0){return}nvb(a);return}function hs(a){a=a|0;dl(a,Ok(700192)|0);return 0}function is(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=c[a+44>>2]|0;if((irc(b,2425504)|0)!=0){h=-38;return h|0}b=rb(d|0,0,10)|0;if((b|0)<0){i=0}else{i=(b|0)>6?6:b}c[g+8>>2]=i;h=0;return h|0}function js(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[e>>2]=b;h=c[a+8>>2]|0;a=c[h+44>>2]|0;j=c[c[h+32>>2]>>2]|0;h=(c[j+20>>2]|0)+7&-8;k=j+24|0;l=bv(j,h,(c[k>>2]|0)+7&-8)|0;if((l|0)==0){VHb(e);m=-12;i=d;return m|0}else{ZHb(l,b)|0;b=c[e>>2]|0;c[l+68>>2]=c[b+68>>2];c[l+72>>2]=c[b+72>>2];n=SHb(b,f,g)|0;b=c[e>>2]|0;ovb(b|0,b+32|0,l|0,l+32|0,h,c[k>>2]|0,n,c[f>>2]|0,c[a+12+(c[a+8>>2]<<2)>>2]|0,c[a+40>>2]|0,((c[g>>2]|0)!=0?16:0)|c[l+88>>2]);VHb(e);m=lj(j,l)|0;i=d;return m|0}return 0}function ks(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[(c[a+8>>2]|0)+44>>2]|0;switch(c[a+52>>2]|0){case 12:case 0:{e=524313;break};case 13:case 4:{e=524297;break};case 14:case 5:{e=524296;break};case 7:{e=524298;break};default:{KIb(0,0,2163096,(f=i,i=i+24|0,c[f>>2]=2137264,c[f+8>>2]=2113968,c[f+16>>2]=102,f)|0);i=f;Hd();return 0}}f=lvb(c[a+20>>2]|0,c[a+24>>2]|0,e)|0;c[d+40>>2]=f;i=b;return((f|0)==0?-12:0)|0}function ls(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;e=c[a+44>>2]|0;h[e+456>>3]=s;h[e+464>>3]=-s;f=e+484|0;g=c[f>>2]|0;do{if((g|0)!=0){j=Qc(g|0,2342368)|0;c[e+480>>2]=j;if((j|0)!=0){break}j=-(c[(pd()|0)>>2]|0)|0;k=d|0;RGb(j,k,128)|0;KIb(a,16,2282888,(l=i,i=i+16|0,c[l>>2]=c[f>>2],c[l+8>>2]=k,l)|0);i=l;m=j;i=b;return m|0}}while(0);c[e+432>>2]=292;m=0;i=b;return m|0}function ms(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0.0,k=0.0,l=0.0,m=0.0;b=i;d=c[a+44>>2]|0;e=d+472|0;f=c[e>>2]|0;g=c[e+4>>2]|0;if(!((f|0)==0&(g|0)==0)){e=c[d+504>>2]|0;j=+((ca(e,e)|0)>>>0>>>0);k=+aa(j/(+h[d+448>>3]/(+(f>>>0)+ +(g>>>0)*4294967296.0)))*10.0/2.302585092994046;l=+aa(j/+h[d+464>>3])*10.0/2.302585092994046;m=+aa(j/+h[d+456>>3])*10.0/2.302585092994046;KIb(a,32,2425336,(a=i,i=i+24|0,h[a>>3]=k,h[a+8>>3]=l,h[a+16>>3]=m,a)|0);i=a}Vz(d+8|0);a=c[d+480>>2]|0;if((a|0)==0){i=b;return}nb(a|0)|0;i=b;return}function ns(a){a=a|0;dl(a,Ok(684992)|0);return 0}function os(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+288|0;j=g|0;k=g+128|0;l=g+256|0;m=c[b+44>>2]|0;b=QHb(e)|0;Ge[c[m+556>>2]&255](m,e|0,e+32|0,f|0,f+32|0,c[e+68>>2]|0,c[e+72>>2]|0,l|0);f=m+520|0;n=c[f>>2]|0;o=(n|0)>0;if(o){p=0;q=0.0;while(1){r=q+ +h[l+(p<<3)>>3];s=p+1|0;if((s|0)<(n|0)){p=s;q=r}else{t=r;break}}}else{t=0.0}q=t/+(n|0);n=m+456|0;t=+h[n>>3];h[n>>3]=t>q?q:t;n=m+464|0;t=+h[n>>3];h[n>>3]=t>q?t:q;n=m+448|0;h[n>>3]=q+ +h[n>>3];n=m+472|0;p=wrc(c[n>>2]|0,c[n+4>>2]|0,1,0)|0;c[n>>2]=p;c[n+4>>2]=G;if(o){o=m+508|0;p=j|0;j=k|0;t=q;k=m+488|0;s=m+504|0;u=0;do{if((c[o>>2]|0)==0){v=u}else{v=d[m+(u+512)|0]|0}w=m+(u+516)|0;x=a[w]|0;y=l+(v<<3)|0;Rb(p|0,128,2561272,(z=i,i=i+8|0,h[z>>3]=+h[y>>3],z)|0)|0;i=z;if(x<<24>>24==0){MGb(b,2233512,p,0)|0}else{Rb(j|0,128,2543816,(z=i,i=i+16|0,c[z>>2]=2233512,c[z+8>>2]=x<<24>>24,z)|0)|0;i=z;MGb(b,j,p,0)|0}Rb(p|0,128,2561272,(z=i,i=i+8|0,h[z>>3]=t,z)|0)|0;i=z;MGb(b,2194144,p,0)|0;x=a[w]|0;w=c[k+(v<<2)>>2]|0;r=+aa(+((ca(w,w)|0)>>>0>>>0)/+h[y>>3])*10.0/2.302585092994046;Rb(p|0,128,2561272,(z=i,i=i+8|0,h[z>>3]=r,z)|0)|0;i=z;if(x<<24>>24==0){MGb(b,2163048,p,0)|0}else{Rb(j|0,128,2543816,(z=i,i=i+16|0,c[z>>2]=2163048,c[z+8>>2]=x<<24>>24,z)|0)|0;i=z;MGb(b,j,p,0)|0}x=c[s>>2]|0;r=+aa(+((ca(x,x)|0)>>>0>>>0)/q)*10.0/2.302585092994046;Rb(p|0,128,2561272,(z=i,i=i+8|0,h[z>>3]=r,z)|0)|0;i=z;MGb(b,2137216,p,0)|0;u=u+1|0;}while((u|0)<(c[f>>2]|0))}u=m+480|0;p=c[u>>2]|0;if((p|0)==0){i=g;return e|0}b=c[n+4>>2]|0;Id(p|0,2113944,(z=i,i=i+24|0,c[z>>2]=c[n>>2],c[z+8>>2]=b,h[z+16>>3]=q,z)|0)|0;i=z;do{if((c[f>>2]|0)>0){b=m+508|0;n=0;do{if((c[b>>2]|0)==0){A=n}else{A=d[m+(n+512)|0]|0}q=+h[l+(A<<3)>>3];Id(c[u>>2]|0,2632040,(z=i,i=i+16|0,c[z>>2]=a[m+(n+516)|0]|0,h[z+8>>3]=q,z)|0)|0;i=z;n=n+1|0;B=c[f>>2]|0;}while((n|0)<(B|0));if((B|0)<=0){break}n=m+508|0;b=m+488|0;p=0;do{if((c[n>>2]|0)==0){C=p}else{C=d[m+(p+512)|0]|0}s=c[b+(C<<2)>>2]|0;q=+aa(+((ca(s,s)|0)>>>0>>>0)/+h[l+(C<<3)>>3])*10.0/2.302585092994046;Id(c[u>>2]|0,2607496,(z=i,i=i+16|0,c[z>>2]=a[m+(p+516)|0]|0,h[z+8>>3]=q,z)|0)|0;i=z;p=p+1|0;}while((p|0)<(c[f>>2]|0))}}while(0);sb(10,c[u>>2]|0)|0;i=g;return e|0}function ps(a){a=a|0;return Uz((c[(c[a>>2]|0)+44>>2]|0)+8|0,a)|0}function qs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=c[c[b+16>>2]>>2]|0;c[a+20>>2]=c[e+20>>2];c[a+24>>2]=c[e+24>>2];f=e+56|0;g=a+56|0;h=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;h=e+28|0;g=a+28|0;f=c[h+4>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=f;f=e+116|0;e=a+116|0;a=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=a;a=Rz(b,d+8|0)|0;return((a|0)<0?a:0)|0}function rs(a,b){a=a|0;b=b|0;return Tz((c[(c[a+8>>2]|0)+44>>2]|0)+8|0,a,b)|0}function ss(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=f+52|0;j=qKb(c[h>>2]|0)|0;k=c[f+8>>2]|0;l=c[k+44>>2]|0;m=l+520|0;c[m>>2]=d[j+4|0]|0;n=c[k+16>>2]|0;o=c[n>>2]|0;p=c[n+4>>2]|0;do{if((c[o+20>>2]|0)==(c[p+20>>2]|0)){if((c[o+24>>2]|0)!=(c[p+24>>2]|0)){break}if((c[o+52>>2]|0)!=(c[p+52>>2]|0)){KIb(k,16,2437288,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-22;i=g;return r|0}switch(c[h>>2]|0){case 8:case 32:case 82:case 84:case 86:case 314:case 316:case 88:case 317:case 319:case 320:case 12:case 13:case 34:case 14:{c[l+488>>2]=(1<<((e[j+8>>1]|0)>>>11&15)+1)-1;c[l+492>>2]=(1<<((e[j+10>>1]|0)>>>11&15)+1)-1;c[l+496>>2]=(1<<((e[j+12>>1]|0)>>>11&15)+1)-1;c[l+500>>2]=(1<<((e[j+14>>1]|0)>>>11&15)+1)-1;break};default:{c[l+488>>2]=235<<((e[j+8>>1]|0)>>>11&15)-7;c[l+492>>2]=240<<((e[j+10>>1]|0)>>>11&15)-7;c[l+496>>2]=240<<((e[j+12>>1]|0)>>>11&15)-7;c[l+500>>2]=(1<<((e[j+14>>1]|0)>>>11&15)+1)-1}}n=Kz(l+512|0,c[h>>2]|0)|0;s=n>>>31;c[l+508>>2]=s^1;a[l+516|0]=(n>>31&7)+114;n=(s|0)!=1;a[l+517|0]=n?103:117;a[l+518|0]=n?98:118;a[l+519|0]=97;n=c[m>>2]|0;if((n|0)>0){s=l+488|0;t=l+504|0;u=0;v=c[t>>2]|0;while(1){w=v+(c[s+(u<<2)>>2]|0)|0;c[t>>2]=w;x=u+1|0;if((x|0)<(n|0)){u=x;v=w}else{y=w;break}}}else{y=c[l+504>>2]|0}c[l+504>>2]=(y|0)/(n|0)|0;v=f+24|0;u=-(-(c[v>>2]|0)>>(d[j+6|0]|0))|0;c[l+548>>2]=u;c[l+544>>2]=u;u=c[v>>2]|0;c[l+552>>2]=u;c[l+540>>2]=u;u=f+20|0;v=-(-(c[u>>2]|0)>>(d[j+5|0]|0))|0;c[l+532>>2]=v;c[l+528>>2]=v;v=c[u>>2]|0;c[l+536>>2]=v;c[l+524>>2]=v;c[l+556>>2]=(b[j+8>>1]&16384)>>>0>14336>>>0?14:2;r=0;i=g;return r|0}}while(0);KIb(k,16,2454240,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-22;i=g;return r|0}function ts(a,b,d,f,g,i,j,k){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=c[a+520>>2]|0;if((j|0)>0){l=0}else{return}do{i=c[a+524+(l<<2)>>2]|0;m=c[a+540+(l<<2)>>2]|0;n=(c[g+(l<<2)>>2]|0)/2|0;o=(c[d+(l<<2)>>2]|0)/2|0;if((m|0)>0&(i|0)>0){p=c[b+(l<<2)>>2]|0;q=c[f+(l<<2)>>2]|0;r=0;s=0;t=0;while(1){u=0;v=s;w=t;do{x=(e[p+(u<<1)>>1]|0)-(e[q+(u<<1)>>1]|0)|0;w=wrc(ca(x,x)|0,0,w,v)|0;v=G;u=u+1|0;}while((u|0)<(i|0));u=r+1|0;if((u|0)<(m|0)){p=p+(o<<1)|0;q=q+(n<<1)|0;r=u;s=v;t=w}else{y=v;z=w;break}}}else{y=0;z=0}h[k+(l<<3)>>3]=(+(z>>>0)+ +(y>>>0)*4294967296.0)/+(ca(m,i)|0);l=l+1|0;}while((l|0)<(j|0));return}function us(a,b,e,f,g,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=c[a+520>>2]|0;if((j|0)>0){l=0}else{return}do{i=c[a+524+(l<<2)>>2]|0;m=c[a+540+(l<<2)>>2]|0;n=c[g+(l<<2)>>2]|0;o=c[e+(l<<2)>>2]|0;if((m|0)>0&(i|0)>0){p=c[b+(l<<2)>>2]|0;q=c[f+(l<<2)>>2]|0;r=0;s=0;t=0;while(1){u=0;v=0;do{w=(d[p+u|0]|0)-(d[q+u|0]|0)|0;v=(ca(w,w)|0)+v|0;u=u+1|0;}while((u|0)<(i|0));u=wrc(v,(v|0)<0|0?-1:0,t,s)|0;w=G;x=r+1|0;if((x|0)<(m|0)){p=p+o|0;q=q+n|0;r=x;s=w;t=u}else{y=w;z=u;break}}}else{y=0;z=0}h[k+(l<<3)>>3]=(+(z>>>0)+ +(y>>>0)*4294967296.0)/+(ca(m,i)|0);l=l+1|0;}while((l|0)<(j|0));return}function vs(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=c[b+92>>2]|0;if((a|0)!=0){d=a;while(1){kJb(c[d+20>>2]|0);kJb(c[d+24>>2]|0);kJb(c[d+28>>2]|0);e=c[d+36>>2]|0;f=d;mrc(f|0,0,40)|0;kJb(f);if((e|0)!=(a|0)&(e|0)!=0){d=e}else{break}}}c[b+88>>2]=0;mJb(b+104|0);mJb(b+108|0);mJb(b+112|0);mJb(b+128|0);mJb(b+132|0);mJb(b+136|0);mJb(b+152|0);mJb(b+156|0);mJb(b+160|0);mJb(b+176|0);mJb(b+180|0);mJb(b+184|0);mJb(b+200|0);mJb(b+204|0);mJb(b+208|0);mJb(b+224|0);mJb(b+228|0);mJb(b+232|0);mJb(b+248|0);mJb(b+252|0);mJb(b+256|0);mJb(b+272|0);mJb(b+276|0);mJb(b+280|0);mJb(b+296|0);mJb(b+300|0);mJb(b+304|0);mJb(b+320|0);mJb(b+324|0);mJb(b+328|0);return}function ws(a){a=a|0;dl(a,Ok(684936)|0);return 0}function xs(a){a=a|0;var b=0;b=a+156|0;c[b>>2]=c[b>>2]|1;return 0}function ys(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[c[f+32>>2]>>2]|0;h=c[f+44>>2]|0;j=h;k=Es(j)|0;if((k|0)==0){KIb(f,24,2416800,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;f=Fs(j)|0;l=f+4|0;if((c[l>>2]|0)>0){m=f+8|0;n=0;do{o=c[f+12+(n<<2)>>2]|0;do{if((o|0)!=0){p=(c[m>>2]^n&1)+1|0;if((p&1|0)!=0){q=o|0;c[q>>2]=(c[q>>2]|0)-1}if((p&2|0)==0){break}p=o+4|0;c[p>>2]=(c[p>>2]|0)-1}}while(0);n=n+1|0;}while((n|0)<(c[l>>2]|0))}l=c[f+28>>2]|0;if((l|0)!=0){n=l|0;c[n>>2]=(c[n>>2]|0)-1}n=c[f+32>>2]|0;if((n|0)!=0){l=n+4|0;c[l>>2]=(c[l>>2]|0)-1}l=c[f+36>>2]|0;if((l|0)!=0){n=l|0;c[n>>2]=(c[n>>2]|0)-1;n=l+4|0;c[n>>2]=(c[n>>2]|0)-1}n=f|0;c[n>>2]=(c[n>>2]|0)-1;r=0;VHb(e);i=d;return r|0}n=h+52|0;f=a+52|0;l=a+20|0;m=a+24|0;vIb(k+8|0,n,b|0,b+32|0,c[f>>2]|0,c[l>>2]|0,c[m>>2]|0);b=c[e>>2]|0;if((c[b+296>>2]|0)==0){s=0}else{s=(c[b+300>>2]|0)==0|0}Gs(j,k,s);Gs(j,k,s^1);if((c[(c[e>>2]|0)+292>>2]|0)!=0){Gs(j,k,s)}s=k|0;c[s>>2]=(c[s>>2]|0)-1;s=k+4|0;c[s>>2]=(c[s>>2]|0)-1;s=Fs(j)|0;if((s|0)==0){r=0;VHb(e);i=d;return r|0}k=s+4|0;b=c[k>>2]|0;do{if((b|0)<2){if((b|0)>0){a=s+8|0;o=0;do{p=c[s+12+(o<<2)>>2]|0;do{if((p|0)!=0){q=(c[a>>2]^o&1)+1|0;if((q&1|0)!=0){t=p|0;c[t>>2]=(c[t>>2]|0)-1}if((q&2|0)==0){break}q=p+4|0;c[q>>2]=(c[q>>2]|0)-1}}while(0);o=o+1|0;}while((o|0)<(c[k>>2]|0))}o=c[s+28>>2]|0;if((o|0)!=0){a=o|0;c[a>>2]=(c[a>>2]|0)-1}a=c[s+32>>2]|0;if((a|0)!=0){o=a+4|0;c[o>>2]=(c[o>>2]|0)-1}o=c[s+36>>2]|0;if((o|0)!=0){a=o|0;c[a>>2]=(c[a>>2]|0)-1;a=o+4|0;c[a>>2]=(c[a>>2]|0)-1}a=s|0;c[a>>2]=(c[a>>2]|0)-1;a=Fs(j)|0;if((a|0)==0){r=0;VHb(e);i=d;return r|0}o=a+4|0;p=c[o>>2]|0;if((p|0)>=2){u=a;break}if((p|0)>0){p=a+8|0;q=0;do{t=c[a+12+(q<<2)>>2]|0;do{if((t|0)!=0){v=(c[p>>2]^q&1)+1|0;if((v&1|0)!=0){w=t|0;c[w>>2]=(c[w>>2]|0)-1}if((v&2|0)==0){break}v=t+4|0;c[v>>2]=(c[v>>2]|0)-1}}while(0);q=q+1|0;}while((q|0)<(c[o>>2]|0))}o=c[a+28>>2]|0;if((o|0)!=0){q=o|0;c[q>>2]=(c[q>>2]|0)-1}q=c[a+32>>2]|0;if((q|0)!=0){o=q+4|0;c[o>>2]=(c[o>>2]|0)-1}o=c[a+36>>2]|0;if((o|0)!=0){q=o|0;c[q>>2]=(c[q>>2]|0)-1;q=o+4|0;c[q>>2]=(c[q>>2]|0)-1}q=a|0;c[q>>2]=(c[q>>2]|0)-1;if((c[(c[e>>2]|0)+292>>2]|0)==0){r=0;VHb(e);i=d;return r|0}q=Fs(j)|0;if((q|0)==0){r=0;VHb(e);i=d;return r|0}o=q+4|0;p=c[o>>2]|0;if((p|0)>=2){u=q;break}if((p|0)>0){p=q+8|0;t=0;do{v=c[q+12+(t<<2)>>2]|0;do{if((v|0)!=0){w=(c[p>>2]^t&1)+1|0;if((w&1|0)!=0){x=v|0;c[x>>2]=(c[x>>2]|0)-1}if((w&2|0)==0){break}w=v+4|0;c[w>>2]=(c[w>>2]|0)-1}}while(0);t=t+1|0;}while((t|0)<(c[o>>2]|0))}o=c[q+28>>2]|0;if((o|0)!=0){t=o|0;c[t>>2]=(c[t>>2]|0)-1}t=c[q+32>>2]|0;if((t|0)!=0){o=t+4|0;c[o>>2]=(c[o>>2]|0)-1}o=c[q+36>>2]|0;if((o|0)!=0){t=o|0;c[t>>2]=(c[t>>2]|0)-1;t=o+4|0;c[t>>2]=(c[t>>2]|0)-1}t=q|0;c[t>>2]=(c[t>>2]|0)-1;r=0;VHb(e);i=d;return r|0}else{u=s}}while(0);s=u+36|0;do{if((c[s>>2]|0)==0){k=0;while(1){if((k|0)>=2){y=78;break}z=k^1;A=c[u+28+(k<<2)>>2]|0;if((c[A+(z<<2)>>2]|0)==0){y=74;break}else{k=k+1|0}}if((y|0)==74){c[s>>2]=A;if((A|0)!=0){k=A|0;c[k>>2]=(c[k>>2]|0)+1;k=A+4|0;c[k>>2]=(c[k>>2]|0)+1}k=c[u+28+(z<<2)>>2]|0;q=h+48|0;if((c[q>>2]|0)>0){B=0}else{break}do{b=c[j+52+(B<<2)>>2]|0;t=ca(b,z)|0;o=b<<1;uIb((c[A+8+(B<<2)>>2]|0)+t|0,o,(c[k+8+(B<<2)>>2]|0)+t|0,o,b,c[j+68+(B<<2)>>2]>>1);B=B+1|0;}while((B|0)<(c[q>>2]|0))}else if((y|0)==78){q=Es(j)|0;c[s>>2]=q;k=c[u+28>>2]|0;b=h+48|0;if((c[b>>2]|0)>0){C=0}else{break}do{o=c[j+52+(C<<2)>>2]|0;t=o<<1;uIb(c[q+8+(C<<2)>>2]|0,t,c[k+8+(C<<2)>>2]|0,t,o,c[j+68+(C<<2)>>2]>>1);C=C+1|0;D=c[b>>2]|0;}while((C|0)<(D|0));k=c[s>>2]|0;q=c[u+32>>2]|0;if((D|0)>0){E=0}else{break}do{o=c[j+52+(E<<2)>>2]|0;t=o<<1;uIb((c[k+8+(E<<2)>>2]|0)+o|0,t,(c[q+8+(E<<2)>>2]|0)+o|0,t,o,c[j+68+(E<<2)>>2]>>1);E=E+1|0;}while((E|0)<(c[b>>2]|0))}}}while(0);E=bv(g,c[g+20>>2]|0,c[g+24>>2]|0)|0;if((E|0)==0){r=-12;VHb(e);i=d;return r|0}ZHb(E,c[e>>2]|0)|0;vIb(E|0,E+32|0,(c[s>>2]|0)+8|0,n,c[f>>2]|0,c[l>>2]|0,c[m>>2]|0);m=lj(g,E)|0;E=u+4|0;if((c[E>>2]|0)>0){g=u+8|0;l=0;do{f=c[u+12+(l<<2)>>2]|0;do{if((f|0)!=0){n=(c[g>>2]^l&1)+1|0;if((n&1|0)!=0){j=f|0;c[j>>2]=(c[j>>2]|0)-1}if((n&2|0)==0){break}n=f+4|0;c[n>>2]=(c[n>>2]|0)-1}}while(0);l=l+1|0;}while((l|0)<(c[E>>2]|0))}E=c[u+28>>2]|0;if((E|0)!=0){l=E|0;c[l>>2]=(c[l>>2]|0)-1}l=c[u+32>>2]|0;if((l|0)!=0){E=l+4|0;c[E>>2]=(c[E>>2]|0)-1}E=c[s>>2]|0;if((E|0)!=0){s=E|0;c[s>>2]=(c[s>>2]|0)-1;s=E+4|0;c[s>>2]=(c[s>>2]|0)-1}s=u|0;c[s>>2]=(c[s>>2]|0)-1;r=m;VHb(e);i=d;return r|0}function zs(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;e=c[a+8>>2]|0;f=c[e+44>>2]|0;g=a+52|0;h=qKb(c[g>>2]|0)|0;j=c[f+20>>2]|0;k=uKb(c[g>>2]|0)|0;c[f+48>>2]=k;if((j+1|0)>(k|0)){KIb(e,16,2454200,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=b;return m|0}k=f;g=a+24|0;n=-(-(c[g>>2]|0)>>(d[h+6|0]|0))|0;o=f+68|0;c[f+76>>2]=n;c[f+72>>2]=n;n=c[g>>2]|0;c[f+80>>2]=n;c[o>>2]=n;n=a+20|0;a=-(-(c[n>>2]|0)>>(d[h+5|0]|0))|0;h=f+52|0;c[f+60>>2]=a;c[f+56>>2]=a;a=c[n>>2]|0;c[f+64>>2]=a;c[h>>2]=a;a=h+(j<<2)|0;h=c[f+4>>2]|0;n=(c[a>>2]|0)-((c[f+8>>2]|0)+h<<3)>>3;c[f+32>>2]=n;g=c[f+12>>2]|0;p=(c[o+(j<<2)>>2]|0)-((c[f+16>>2]|0)+g<<1)>>3;c[f+36>>2]=p;j=f+44|0;c[j>>2]=(ca(g<<1,c[a>>2]|0)|0)+(h<<3);h=f+40|0;c[h>>2]=ca(p,n)|0;a=e;KIb(a,48,2437168,(l=i,i=i+16|0,c[l>>2]=n,c[l+8>>2]=p,l)|0);i=l;p=c[h>>2]|0;KIb(a,48,2427056,(l=i,i=i+16|0,c[l>>2]=c[j>>2],c[l+8>>2]=p,l)|0);i=l;l=pJb(40)|0;p=l;do{if((l|0)!=0){if((Ds(k,p)|0)<0){kJb(l);break}else{q=p;r=8}while(1){if((r|0)<=0){s=12;break}j=pJb(40)|0;a=q+36|0;c[a>>2]=j;if((j|0)==0){t=p;s=8;break}c[j+32>>2]=q;j=c[a>>2]|0;if((Ds(k,j)|0)<0){u=p;s=10;break}else{q=j;r=r-1|0}}if((s|0)==8){while(1){s=0;kJb(c[t+20>>2]|0);kJb(c[t+24>>2]|0);kJb(c[t+28>>2]|0);j=c[t+36>>2]|0;a=t;mrc(a|0,0,40)|0;kJb(a);if((j|0)!=(p|0)&(j|0)!=0){t=j;s=8}else{break}}}else if((s|0)==10){while(1){s=0;kJb(c[u+20>>2]|0);kJb(c[u+24>>2]|0);kJb(c[u+28>>2]|0);j=c[u+36>>2]|0;a=u;mrc(a|0,0,40)|0;kJb(a);if((j|0)!=(p|0)&(j|0)!=0){u=j;s=10}else{break}}}else if((s|0)==12){c[q+36>>2]=p;c[l+32>>2]=q;c[f+92>>2]=p;c[f+376>>2]=2;c[f+380>>2]=108;c[f+384>>2]=186;m=0;i=b;return m|0}}}while(0);c[f+92>>2]=0;m=-12;i=b;return m|0}function As(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b;b=a;a=0;f=0;while(1){g=(d[b]|0)-(d[e]|0)|0;h=(d[b+1|0]|0)-(d[e+1|0]|0)|0;i=(d[b+2|0]|0)-(d[e+2|0]|0)|0;j=(d[b+3|0]|0)-(d[e+3|0]|0)|0;k=(d[b+4|0]|0)-(d[e+4|0]|0)|0;l=(d[b+5|0]|0)-(d[e+5|0]|0)|0;m=(d[b+6|0]|0)-(d[e+6|0]|0)|0;n=(d[b+7|0]|0)-(d[e+7|0]|0)|0;o=(n>>>31)+((m>>>31)+((l>>>31)+((k>>>31)+((j>>>31)+((i>>>31)+((h>>>31)+((g>>>31)+f+(g>>31^g))+(h>>31^h))+(i>>31^i))+(j>>31^j))+(k>>31^k))+(l>>31^l))+(m>>31^m))+(n>>31^n)|0;n=a+1|0;if((n|0)<4){e=e+c|0;b=b+c|0;a=n;f=o}else{break}}return o|0}function Bs(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b;b=a;a=0;f=0;while(1){g=0;h=f;do{i=d[b+g|0]|0;j=d[e+g|0]|0;k=(i<<1)-(d[e+(g-c)|0]|0)-j|0;l=(j<<1)-i-(d[b+(g+c)|0]|0)|0;h=(k>>>31)+h+(k>>31^k)+(l>>>31)+(l>>31^l)|0;g=g+1|0;}while((g|0)<8);g=a+1|0;if((g|0)<4){e=e+c|0;b=b+c|0;a=g;f=h}else{break}}return h|0}function Cs(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c=b;f=0;g=0;h=a[b]|0;while(1){b=c+e|0;i=a[b]|0;j=(h&255)-(i&255)|0;k=(d[c+1|0]|0)-(d[c+(e+1)|0]|0)|0;l=(d[c+2|0]|0)-(d[c+(e+2)|0]|0)|0;m=(d[c+3|0]|0)-(d[c+(e+3)|0]|0)|0;n=(d[c+4|0]|0)-(d[c+(e+4)|0]|0)|0;o=(d[c+5|0]|0)-(d[c+(e+5)|0]|0)|0;p=(d[c+6|0]|0)-(d[c+(e+6)|0]|0)|0;q=(d[c+7|0]|0)-(d[c+(e+7)|0]|0)|0;r=(q>>>31)+((p>>>31)+((o>>>31)+((n>>>31)+((m>>>31)+((l>>>31)+((k>>>31)+((j>>>31)+g+(j>>31^j))+(k>>31^k))+(l>>31^l))+(m>>31^m))+(n>>31^n))+(o>>31^o))+(p>>31^p))+(q>>31^q)|0;q=f+1|0;if((q|0)<3){c=b;f=q;g=r;h=i}else{break}}return r<<2|0}function Ds(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+40|0;a=b+20|0;c[a>>2]=qJb((c[d>>2]|0)+15&-16,4)|0;e=b+24|0;c[e>>2]=qJb((c[d>>2]|0)+15&-16,4)|0;f=qJb((c[d>>2]|0)+15&-16,4)|0;d=b+28|0;c[d>>2]=f;do{if((c[a>>2]|0)!=0){if((c[e>>2]|0)==0|(f|0)==0){break}else{g=0}return g|0}}while(0);mJb(a);mJb(e);mJb(d);g=-12;return g|0}function Es(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+96|0;d=b|0;if((c[d>>2]|0)==0){if((c[a+100>>2]|0)==0){e=0;f=b;g=d}else{h=10}}else{h=10}do{if((h|0)==10){d=a+120|0;b=d|0;if((c[b>>2]|0)==0){if((c[a+124>>2]|0)==0){e=1;f=d;g=b;break}}b=a+144|0;d=b|0;if((c[d>>2]|0)==0){if((c[a+148>>2]|0)==0){e=2;f=b;g=d;break}}d=a+168|0;b=d|0;if((c[b>>2]|0)==0){if((c[a+172>>2]|0)==0){e=3;f=d;g=b;break}}b=a+192|0;d=b|0;if((c[d>>2]|0)==0){if((c[a+196>>2]|0)==0){e=4;f=b;g=d;break}}d=a+216|0;b=d|0;if((c[b>>2]|0)==0){if((c[a+220>>2]|0)==0){e=5;f=d;g=b;break}}b=a+240|0;d=b|0;if((c[d>>2]|0)==0){if((c[a+244>>2]|0)==0){e=6;f=b;g=d;break}}d=a+264|0;b=d|0;if((c[b>>2]|0)==0){if((c[a+268>>2]|0)==0){e=7;f=d;g=b;break}}b=a+288|0;d=b|0;if((c[d>>2]|0)==0){if((c[a+292>>2]|0)==0){e=8;f=b;g=d;break}}d=a+312|0;b=d|0;if((c[b>>2]|0)!=0){i=0;return i|0}if((c[a+316>>2]|0)==0){e=9;f=d;g=b;break}else{i=0}return i|0}}while(0);do{if((c[a+96+(e*24|0)+8>>2]|0)==0){b=a+48|0;if((c[b>>2]|0)>0){j=0}else{break}do{c[a+96+(e*24|0)+8+(j<<2)>>2]=hJb(ca(c[a+52+(j<<2)>>2]|0,c[a+68+(j<<2)>>2]|0)|0)|0;j=j+1|0;k=c[b>>2]|0;}while((j|0)<(k|0));if((k|0)!=1){h=8;break}c[a+96+(e*24|0)+12>>2]=hJb(1024)|0}else{h=8}}while(0);do{if((h|0)==8){if((f|0)==0){i=0}else{break}return i|0}}while(0);c[g>>2]=(c[g>>2]|0)+1;g=a+96+(e*24|0)+4|0;c[g>>2]=(c[g>>2]|0)+1;i=f;return i|0}function Fs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=a+336|0;d=a+84|0;e=c[d>>2]|0;f=c[e+36>>2]|0;g=c[f+36>>2]|0;h=c[a+88>>2]|0;if((e|0)==0|(h|0)==0|(e|0)==(h|0)){i=0;return i|0}j=(f|0)==(h|0);if(j){i=0;return i|0}else{k=3;l=g}while(1){if((l|0)==(h|0)){break}k=k+1|0;l=c[l+36>>2]|0}if((k|0)<4){i=0;return i|0}if(j){m=2;n=1;o=10}else{j=3;k=g;while(1){if((k|0)==(h|0)){break}j=j+1|0;k=c[k+36>>2]|0}k=j-1|0;if((k|0)>0){m=j;n=k;o=10}}if((o|0)==10){k=m-3|0;m=a+40|0;j=e;h=0;while(1){a:do{if((h|0)<(k|0)){l=c[j+36>>2]|0;p=c[l+36>>2]|0;q=c[p+36>>2]|0;r=j+8|0;s=c[r>>2]|0;if((s&1|0)!=0){t=r;break}c[r>>2]=s|1;s=(c[l+4>>2]|0)==(c[q+4>>2]|0);do{if((c[j+4>>2]|0)==(c[p+4>>2]|0)){if(s){break}u=p+12|0;c[u>>2]=c[u>>2]|2;t=r;break a}else{if(!s){break}u=l+12|0;c[u>>2]=c[u>>2]|1;t=r;break a}}while(0);s=c[m>>2]|0;if((s|0)>0){u=c[p+20>>2]|0;v=c[q+20>>2]|0;w=0;x=0;y=0;while(1){z=(c[u+(w<<2)>>2]|0)-(c[v+(w<<2)>>2]|0)|0;A=(z|0)>(x|0)?z:x;B=-z|0;z=(y|0)<(B|0)?B:y;B=w+1|0;if((B|0)<(s|0)){w=B;x=A;y=z}else{C=A;D=z;break}}}else{C=0;D=0}if((C+D|0)<128){t=r;break}if((C|0)>(D<<2|0)){y=l+12|0;c[y>>2]=c[y>>2]|1}if((D|0)<=(C<<2|0)){t=r;break}y=p+12|0;c[y>>2]=c[y>>2]|2;t=r}else{t=j+8|0}}while(0);y=c[t>>2]|0;do{if((y&2|0)==0){c[t>>2]=y|2;x=c[j+36>>2]|0;w=c[x+36>>2]|0;if((c[j+4>>2]|0)==(c[w+4>>2]|0)){c[j+16>>2]=1;c[x+16>>2]=0;c[w+16>>2]=-1;s=x+8|0;c[s>>2]=c[s>>2]|2;s=w+8|0;c[s>>2]=c[s>>2]|2;E=x;break}s=c[m>>2]|0;if((s|0)>0){w=c[j+28>>2]|0;v=c[(c[j+32>>2]|0)+28>>2]|0;u=c[x+28>>2]|0;q=c[j+24>>2]|0;z=c[x+24>>2]|0;A=0;B=0;F=0;while(1){G=c[w+(F<<2)>>2]|0;H=c[v+(F<<2)>>2]|0;I=c[u+(F<<2)>>2]|0;J=G-H|0;K=(J>>>31)-(H+G)+(c[q+(F<<2)>>2]|0)+(J>>31^J)|0;J=G-I|0;H=J>>31;L=(c[z+(F<<2)>>2]|0)-(I+G)+((H^J)-H)|0;H=((K|0)>0?K:0)-((L|0)>0?L:0)|0;L=(H|0)>(B|0)?H:B;K=-H|0;H=(A|0)<(K|0)?K:A;K=F+1|0;if((K|0)<(s|0)){A=H;B=L;F=K}else{M=H;N=L;break}}}else{M=0;N=0}if((M+N|0)<64){E=x;break}if((M|0)>(N*6|0|0)){c[j+16>>2]=-1;E=x;break}if((N|0)<=(M*6|0|0)){E=x;break}c[j+16>>2]=1;E=x}else{E=c[j+36>>2]|0}}while(0);y=h+1|0;if((y|0)<(n|0)){j=E;h=y}else{break}}}h=c[e+16>>2]|0;b:do{if((h|0)==-1){O=1}else{E=0;j=e;while(1){if((E|0)>=3){break}if((c[j+12>>2]&2|0)!=0){o=43;break}n=c[j+36>>2]|0;M=E+1|0;if((c[n+12>>2]&1|0)==0){E=M;j=n}else{P=M;o=45;break}}if((o|0)==43){P=E+1|0;o=45}do{if((o|0)==45){if((P|0)==1){Q=(c[a+24>>2]|0)>>>31^1}else{Q=P}if((Q|0)==2){do{if((c[a+28>>2]|0)!=0){if((c[(c[e+32>>2]|0)+12>>2]&2|0)==0){break}if((c[g+12>>2]&1|0)==0){break}if((h|0)!=1){O=1;break b}if(!((c[f+16>>2]|0)==-1)){O=1;break b}}}while(0);O=(c[f+16>>2]|0)!=1?2:1;break b}else if((Q|0)==3){O=(c[g+16>>2]|0)!=1|2;break b}else if((Q|0)==1){if(!((c[a+24>>2]|0)<1&(h|0)==1)){O=1;break b}O=(c[f+16>>2]|0)==-1?2:1;break b}else{break}}}while(0);E=c[f+16>>2]|0;if((E|0)==(-1|0)){O=2;break}else if((E|0)==1){O=1;break}if(!((c[g+16>>2]|0)==-1)){O=2;break}O=(h|0)==1?3:1}}while(0);h=c[f+16>>2]|0;f=b|0;if((c[f>>2]|0)!=0){i=0;return i|0}c[f>>2]=1;c[a+340>>2]=O;f=a+344|0;c[f>>2]=c[e>>2];g=a+372|0;c[g>>2]=0;Q=0;P=e;do{c[a+348+(Q<<2)>>2]=c[P+4>>2];c[(c[d>>2]|0)+4>>2]=0;P=c[(c[d>>2]|0)+36>>2]|0;c[d>>2]=P;Q=Q+1|0;}while((Q|0)<(O|0));if((O|0)==2){c[a+364+(c[f>>2]<<2)>>2]=c[a+348>>2];c[a+364+((c[f>>2]^1)<<2)>>2]=c[a+352>>2]}else if((O|0)==3){if((h|0)==0){Q=a+352|0;R=(c[a+348>>2]|0)==(c[Q>>2]|0)?-1:1;S=Q}else{R=h;S=a+352|0}c[a+364+(c[f>>2]<<2)>>2]=c[a+348+(R+1<<2)>>2];c[a+364+((c[f>>2]^1)<<2)>>2]=c[S>>2]}else if((O|0)==1){c[a+364+(c[f>>2]<<2)>>2]=c[a+348>>2];c[a+364+((c[f>>2]^1)<<2)>>2]=0}f=c[a+364>>2]|0;O=(f|0)==0;if(!O){S=f|0;c[S>>2]=(c[S>>2]|0)+1}S=c[a+368>>2]|0;if((S|0)!=0){a=S+4|0;c[a>>2]=(c[a>>2]|0)+1}if((f|0)!=(S|0)){i=b;return i|0}c[g>>2]=f;if(O){i=b;return i|0}O=f|0;c[O>>2]=(c[O>>2]|0)+1;O=f+4|0;c[O>>2]=(c[O>>2]|0)+1;i=b;return i|0}function Gs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=a+92|0;f=a+84|0;do{if((c[(c[e>>2]|0)+36>>2]|0)==(c[f>>2]|0)){g=pJb(40)|0;h=g;if((g|0)==0){return}if((Ds(a,h)|0)>=0){i=c[e>>2]|0;c[g+32>>2]=i;c[g+36>>2]=c[f>>2];c[i+36>>2]=h;c[(c[f>>2]|0)+32>>2]=h;break}kJb(g);return}}while(0);g=a+88|0;h=c[g>>2]|0;do{if((h|0)!=0){if((c[h>>2]|0)!=(d|0)){break}return}}while(0);h=c[e>>2]|0;c[h>>2]=d;do{if((b|0)==0){j=0}else{i=d+1|0;if((i&1|0)!=0){k=b|0;c[k>>2]=(c[k>>2]|0)+1}if((i&2|0)==0){j=b;break}i=b+4|0;c[i>>2]=(c[i>>2]|0)+1;j=b}}while(0);b=h+4|0;c[b>>2]=j;c[h+8>>2]=0;c[h+12>>2]=0;c[h+16>>2]=0;i=h+32|0;Hs(a,c[h+20>>2]|0,j,d,c[(c[i>>2]|0)+32>>2]|0,d,c[a+376>>2]|0);j=c[h+24>>2]|0;k=(d|0)!=0;l=c[i>>2]|0;i=c[a+380>>2]|0;m=c[(k?l:h)+4>>2]|0;n=c[a+20>>2]|0;o=c[a+52+(n<<2)>>2]|0;p=o<<3;q=o<<1;r=c[a+32>>2]<<3;do{if((m|0)!=0){s=c[(k?h:l)+4>>2]|0;if((s|0)==0){break}t=c[a+44>>2]|0;u=a+36|0;if(!((c[u>>2]|0)>0&(r|0)>0)){break}v=((r-1|0)>>>3)+1|0;w=j;x=(c[m+8+(n<<2)>>2]|0)+t|0;y=(c[s+8+(n<<2)>>2]|0)+(t+o)|0;t=0;while(1){s=w;z=0;while(1){c[s>>2]=Ee[i&511](x+z|0,y+z|0,q)|0;A=z+8|0;if((A|0)<(r|0)){s=s+4|0;z=A}else{break}}z=t+1|0;if((z|0)<(c[u>>2]|0)){w=w+(v<<2)|0;x=x+p|0;y=y+p|0;t=z}else{break}}}}while(0);Hs(a,c[h+28>>2]|0,c[b>>2]|0,d,h,-1,c[a+384>>2]|0);a=c[e>>2]|0;if((c[f>>2]|0)==0){c[f>>2]=a}c[g>>2]=a;c[e>>2]=c[a+36>>2];return}function Hs(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c[a+20>>2]|0;j=c[a+52+(i<<2)>>2]|0;k=j<<3;l=j<<1;m=c[a+32>>2]|0;n=m<<3;if((d|0)==0){return}o=c[f+4>>2]|0;if((o|0)==0){return}if((o|0)==(d|0)&(e|0)==(g|0)){mrc(b|0,0,c[a+40>>2]<<2|0)|0;return}f=ca(j,e)|0;e=c[a+44>>2]|0;p=(c[d+8+(i<<2)>>2]|0)+(e+f)|0;f=(c[o+8+(i<<2)>>2]|0)+(e+(ca(j,g)|0))|0;g=a+36|0;a=c[g>>2]|0;if((a|0)<=0){return}if((n|0)<=0){j=0;do{j=j+1|0;}while((j|0)<(a|0));return}a=(((m<<3)-1|0)>>>3)+1|0;m=b;b=p;p=f;f=0;while(1){j=m;e=0;while(1){c[j>>2]=Ee[h&511](b+e|0,p+e|0,l)|0;i=e+8|0;if((i|0)<(n|0)){j=j+4|0;e=i}else{break}}e=f+1|0;if((e|0)<(c[g>>2]|0)){m=m+(a<<2)|0;b=b+k|0;p=p+k|0;f=e}else{break}}return}function Is(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;i=i+104|0;e=d|0;f=d+8|0;g=d+24|0;h=d+72|0;j=d+80|0;k=d+88|0;l=d+96|0;m=c[b+44>>2]|0;n=c[m+4>>2]|0;if((n|0)==0){KIb(b,16,2425040,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=d;return p|0}q=m+24|0;r=b;b=f;s=g;t=f|0;f=d+40|0;u=fA(t,f,h,j,e,n,r)|0;if((u|0)<0){v=u}else{u=g|0;g=d+56|0;n=c[h>>2]|0;w=c[j>>2]|0;x=jB(u,g,n,w,8,t,f,n,w,c[e>>2]|0,r)|0;if((x|0)<0){y=x}else{e=hJb(ca(c[j>>2]|0,c[h>>2]|0)|0)|0;c[q>>2]=e;w=c[h>>2]|0;uIb(e,w,c[u>>2]|0,c[g>>2]|0,w,c[j>>2]|0);y=(e|0)==0?-12:x}mJb(b);mJb(s);v=y}if((v|0)<0){p=v;i=d;return p|0}c[m+16>>2]=c[h>>2];c[m+20>>2]=c[j>>2];v=c[h>>2]|0;Ls(c[q>>2]|0,v,v,c[j>>2]|0,16,k);v=pJb((ca(c[j>>2]|0,(c[h>>2]|0)/2|0)|0)/2|0)|0;y=m+44|0;c[y>>2]=v;if((v|0)==0){p=-12;i=d;return p|0}s=c[q>>2]|0;b=c[h>>2]|0;x=(b|0)/2|0;e=c[j>>2]|0;w=(e|0)/2|0;if((e|0)>1){e=(b|0)>1;g=0;do{if(e){u=g<<1;n=ca(u,b)|0;f=ca(u|1,b)|0;u=ca(g,x)|0;t=0;do{z=t<<1;A=z+n|0;do{if((a[s+A|0]|0)==0){if((a[s+(A|1)|0]|0)!=0){B=1;break}C=z+f|0;if((a[s+C|0]|0)!=0){B=1;break}B=(a[s+(C+1)|0]|0)!=0|0}else{B=1}}while(0);a[v+(t+u)|0]=B;t=t+1|0;}while((t|0)<(x|0))}g=g+1|0;}while((g|0)<(w|0))}Ls(v,x,x,w,0,l);w=c[k>>2]|0;k=c[l>>2]|0;l=(w|0)>(k|0)?w:k;x=m+12|0;c[x>>2]=l;v=hJb((l<<2)+4|0)|0;l=v;if((v|0)==0){p=-12;i=d;return p|0}a:do{if((c[x>>2]|0)>=0){v=0;b:while(1){g=v<<3|4;B=hJb(g)|0;s=l+(v<<2)|0;c[s>>2]=B;if((B|0)==0){p=-12;D=31;break}B=-v|0;if((v|0)>=(B|0)){b=ca(v,v)|0;e=B;do{t=hJb(g)|0;u=e+v|0;c[(c[s>>2]|0)+(u<<2)>>2]=t;t=c[(c[s>>2]|0)+(u<<2)>>2]|0;if((t|0)==0){p=-12;D=31;break b}f=ca(e,e)|0;n=B;z=t;while(1){c[z+(n+v<<2)>>2]=((ca(n,n)|0)+f|0)<=(b|0);t=n+1|0;if((t|0)>(v|0)){break}n=t;z=c[(c[s>>2]|0)+(u<<2)>>2]|0}e=e+1|0;}while((e|0)<=(v|0))}v=v+1|0;if((v|0)>(c[x>>2]|0)){break a}}if((D|0)==31){i=d;return p|0}}}while(0);c[m+8>>2]=l;l=m+28|0;D=c[h>>2]|0;Jz(l,c[q>>2]|0,D,D,c[j>>2]|0,0)|0;D=m+48|0;q=(c[h>>2]|0)/2|0;Jz(D,c[y>>2]|0,q,q,(c[j>>2]|0)/2|0,0)|0;j=c[m+32>>2]|0;q=c[m+36>>2]|0;y=c[m+40>>2]|0;KIb(r,40,2342024,(o=i,i=i+40|0,c[o>>2]=c[l>>2],c[o+8>>2]=j,c[o+16>>2]=q,c[o+24>>2]=y,c[o+32>>2]=w,o)|0);i=o;w=c[m+52>>2]|0;y=c[m+56>>2]|0;q=c[m+60>>2]|0;KIb(r,40,2282784,(o=i,i=i+40|0,c[o>>2]=c[D>>2],c[o+8>>2]=w,c[o+16>>2]=y,c[o+24>>2]=q,c[o+32>>2]=k,o)|0);i=o;p=0;i=d;return p|0}function Js(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+44>>2]|0;mJb(b+24|0);mJb(b+44|0);a=b+8|0;d=a;if((c[d>>2]|0)==0){return}e=b+12|0;if((c[e>>2]|0)>=0){b=0;do{f=-b|0;if((b|0)>=(f|0)){g=f;do{mJb((c[(c[d>>2]|0)+(b<<2)>>2]|0)+(g+b<<2)|0);g=g+1|0;}while((g|0)<=(b|0))}mJb((c[d>>2]|0)+(b<<2)|0);b=b+1|0;}while((b|0)<=(c[e>>2]|0))}mJb(a);return}function Ks(a){a=a|0;dl(a,Ok(684928)|0);return 0}function Ls(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((g|0)>0&(f|0)>0){j=0;do{k=ca(j,e)|0;l=0;do{m=b+(l+k)|0;a[m]=(d[m]|0|0)>(h|0)|0;l=l+1|0;}while((l|0)<(f|0));j=j+1|0;}while((j|0)<(g|0))}j=b+(e+1)|0;h=g-1|0;g=(h|0)>1;l=f-1|0;f=(l|0)>1;k=-e|0;m=0;while(1){n=m+1|0;if(g&f){o=1;p=0;q=j}else{r=22;break}while(1){s=2;t=p;u=q;while(1){v=a[u]|0;w=u+1|0;do{if((v&255|0)<(n|0)){x=t}else{if((d[w]|0|0)<(n|0)){x=t;break}if((d[u-1|0]|0|0)<(n|0)){x=t;break}if((d[u+e|0]|0|0)<(n|0)){x=t;break}if((d[u+k|0]|0|0)<(n|0)){x=t;break}a[u]=v+1;x=1}}while(0);if((s|0)>=(l|0)){break}s=s+1|0;t=x;u=w}u=o+1|0;if((u|0)<(h|0)){o=u;p=x;q=q+e|0}else{break}}if((x|0)==0){break}else{m=n}}if((r|0)==22){y=m+2|0;z=y>>2;A=y+z|0;c[i>>2]=A;return}if(g&f){B=1}else{y=m+2|0;z=y>>2;A=y+z|0;c[i>>2]=A;return}do{f=ca(B,e)|0;g=1;do{r=b+(g+f)|0;x=a[r]|0;a[r]=((x&255)>>>2)+x;g=g+1|0;}while((g|0)<(l|0));B=B+1|0;}while((B|0)<(h|0));y=m+2|0;z=y>>2;A=y+z|0;c[i>>2]=A;return}function Ms(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=c[c[f+32>>2]>>2]|0;do{if((bIb(b)|0)==0){f=bv(h,c[h+20>>2]|0,c[h+24>>2]|0)|0;if((f|0)!=0){ZHb(f,c[e>>2]|0)|0;j=0;k=f;l=c[e>>2]|0;break}VHb(e);m=-12;i=d;return m|0}else{j=1;k=b;l=b}}while(0);b=g+8|0;f=a+20|0;n=c[f>>2]|0;o=a+24|0;Os(c[b>>2]|0,c[l>>2]|0,c[l+32>>2]|0,c[k>>2]|0,c[k+32>>2]|0,c[g+24>>2]|0,n,n,c[o>>2]|0,j,g+28|0);n=c[e>>2]|0;l=g+44|0;a=(c[f>>2]|0)/2|0;p=g+48|0;Os(c[b>>2]|0,c[n+4>>2]|0,c[n+36>>2]|0,c[k+4>>2]|0,c[k+36>>2]|0,c[l>>2]|0,a,a,(c[o>>2]|0)/2|0,j,p);a=c[e>>2]|0;n=(c[f>>2]|0)/2|0;Os(c[b>>2]|0,c[a+8>>2]|0,c[a+40>>2]|0,c[k+8>>2]|0,c[k+40>>2]|0,c[l>>2]|0,n,n,(c[o>>2]|0)/2|0,j,p);if((j|0)==0){VHb(e)}m=lj(h,k)|0;i=d;return m|0}function Ns(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=c[a+20>>2]|0;g=c[e+16>>2]|0;do{if((f|0)==(g|0)){h=c[a+24>>2]|0;j=c[e+20>>2]|0;if((h|0)==(j|0)){k=0}else{l=j;m=h;break}i=b;return k|0}else{l=c[e+20>>2]|0;m=c[a+24>>2]|0}}while(0);KIb(d,32,2113848,(d=i,i=i+32|0,c[d>>2]=g,c[d+8>>2]=l,c[d+16>>2]=f,c[d+24>>2]=m,d)|0);i=d;k=-22;i=b;return k|0}function Os(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;o=(m|0)!=0;if(!o){uIb(g,h,e,f,k,l)}m=c[n+8>>2]|0;p=n+12|0;q=c[p>>2]|0;if((m|0)>(q|0)){return}r=n|0;s=n+4|0;n=k-1|0;k=l-1|0;l=m;m=c[s>>2]|0;t=q;while(1){q=ca(l,f)|0;u=ca(l,h)|0;v=c[r>>2]|0;if((v|0)>(m|0)){w=m;x=t}else{y=ca(l,j)|0;z=v;do{v=a[i+(z+y)|0]|0;do{if(v<<24>>24==0){if(o){break}a[g+(z+u)|0]=a[e+(z+q)|0]|0}else{A=v&255;B=z-A|0;C=(B|0)<0?0:B;B=l-A|0;D=(B|0)<0?0:B;B=A+z|0;E=(n|0)>(B|0)?B:n;B=A+l|0;F=(k|0)>(B|0)?B:k;do{if((D|0)>(F|0)){G=-1}else{B=(C|0)>(E|0);H=E+1-C|0;I=h-H|0;J=j-H|0;H=b+(A<<2)|0;K=D;L=0;M=0;N=g+((ca(D,h)|0)+C)|0;O=i+((ca(D,j)|0)+C)|0;while(1){if(B){P=L;Q=M;R=N;S=O}else{T=K-D|0;U=C;V=L;W=M;X=N;Y=O;while(1){do{if((a[Y]|0)==0){if((c[(c[(c[H>>2]|0)+(U-C<<2)>>2]|0)+(T<<2)>>2]|0)==0){Z=W;_=V;break}Z=W+1|0;_=(d[X]|0)+V|0}else{Z=W;_=V}}while(0);$=X+1|0;aa=Y+1|0;ba=U+1|0;if((ba|0)>(E|0)){P=_;Q=Z;R=$;S=aa;break}else{U=ba;V=_;W=Z;X=$;Y=aa}}}Y=K+1|0;if((Y|0)>(F|0)){break}else{K=Y;L=P;M=Q;N=R+I|0;O=S+J|0}}if((Q|0)==0){G=-1;break}G=((((Q>>>1)+P|0)>>>0)/(Q>>>0)|0)&255}}while(0);a[g+(z+u)|0]=G}}while(0);z=z+1|0;da=c[s>>2]|0;}while((z|0)<=(da|0));w=da;x=c[p>>2]|0}z=l+1|0;if((z|0)>(x|0)){break}else{l=z;m=w;t=x}}return}function Ps(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;d=c[b+44>>2]|0;if((irc(d,2496960)|0)==0){c[b+48>>2]=0;e=0;return e|0}if(!((dKb(b+40|0,d,-1,a)|0)>-1)){e=-22;return e|0}c[b+48>>2]=1;e=0;return e|0}function Qs(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+20|0;TGb(c[b>>2]|0);c[b>>2]=0;return}function Rs(a){a=a|0;dl(a,Ok(684840)|0);return 0}function Ss(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=i;f=c[a+44>>2]|0;do{if((irc(b,2424984)|0)!=0){if((irc(b,2341984)|0)==0){break}else{h=-38}i=g;return h|0}}while(0);b=f+20|0;f=c[b>>2]|0;e=a;a=UGb(b,d,281320,0,0,0,0,0,e)|0;if((a|0)<0){KIb(e,16,2282688,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;c[b>>2]=f;h=a;i=g;return h|0}else{TGb(f);h=a;i=g;return h|0}return 0}function Ts(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0;b=i;i=i+8|0;e=b|0;f=c[a>>2]|0;g=c[f+44>>2]|0;j=c[c[f+16>>2]>>2]|0;k=j+52|0;l=qKb(c[k>>2]|0)|0;m=g+176|0;Lz(m,c[k>>2]|0,0)|0;Mz(m,g+220|0,g+40|0);m=d[l+5|0]|0;c[g+52>>2]=m;n=d[l+6|0]|0;c[g+56>>2]=n;o=+(c[j+20>>2]|0);h[g+88>>3]=o;l=g+80|0;h[l>>3]=o;o=+(c[j+24>>2]|0);h[g+104>>3]=o;h[g+96>>3]=o;h[g+144>>3]=+(1<<m|0);h[g+152>>3]=+(1<<n|0);h[g+160>>3]=+r;h[g+168>>3]=+r;n=g+120|0;h[n>>3]=+r;m=g+112|0;h[m>>3]=+r;j=g+136|0;h[j>>3]=+r;p=g+128|0;h[p>>3]=+r;q=g+20|0;TGb(c[q>>2]|0);c[q>>2]=0;s=g+16|0;t=f;f=UGb(q,c[s>>2]|0,281320,1204176,1204192,0,0,0,t)|0;if((f|0)<0){KIb(t,16,2379760,(u=i,i=i+8|0,c[u>>2]=c[s>>2],u)|0);i=u;v=f;i=b;return v|0}f=g+24|0;ZGb(e,c[f>>2]|0,281320,l,1204176,1204192,0,0,g,0,t)|0;o=+h[e>>3];h[n>>3]=o;h[m>>3]=o;s=g+36|0;c[s>>2]=~~(+h[e>>3]+.5);q=c[g+28>>2]|0;w=ZGb(e,q,281320,l,1204176,1204192,0,0,g,0,t)|0;o=+h[e>>3];do{if((w|0)>=0){x=c[e+4>>2]&2146435072;y=2146435072;if(!((x>>>0<y>>>0|x>>>0==y>>>0&(c[e>>2]&0)>>>0<0>>>0)&o>0.0)){break}h[j>>3]=o;h[p>>3]=o;y=g+32|0;c[y>>2]=~~(+h[e>>3]+.5);x=c[f>>2]|0;z=ZGb(e,x,281320,l,1204176,1204192,0,0,g,0,t)|0;A=+h[e>>3];do{if((z|0)>=0){B=c[e+4>>2]&2146435072;C=2146435072;if(!((B>>>0<C>>>0|B>>>0==C>>>0&(c[e>>2]&0)>>>0<0>>>0)&A>0.0)){break}h[n>>3]=A;h[m>>3]=A;c[s>>2]=~~(+h[e>>3]+.5);c[g+60>>2]=uKb(c[k>>2]|0)|0;c[a+20>>2]=c[s>>2];c[a+24>>2]=c[y>>2];v=0;i=b;return v|0}}while(0);KIb(t,16,2373496,(u=i,i=i+24|0,c[u>>2]=2607328,c[u+8>>2]=x,h[u+16>>3]=A,u)|0);i=u;v=z;i=b;return v|0}}while(0);KIb(t,16,2373496,(u=i,i=i+24|0,c[u>>2]=2113760,c[u+8>>2]=q,h[u+16>>3]=o,u)|0);i=u;v=w;i=b;return v|0}function Us(a,b){a=a|0;b=+b;var c=0.0,d=0.0,e=0.0,f=0.0,g=0.0,i=0.0;c=+h[a+80>>3];d=+h[a+96>>3];e=+U(b);f=+V(b);b=d*f;g=e;e=g*(-0.0-c);i=c*g;g=f*(-0.0-d);return+((g<0.0?0.0:g)+((i<0.0?0.0:i)+((b<0.0?0.0:b)+(e<0.0?0.0:e))))}function Vs(a,b){a=a|0;b=+b;var c=0.0,d=0.0,e=0.0,f=0.0,g=0.0,i=0.0;c=+h[a+80>>3];d=+h[a+96>>3];e=+V(b);f=+U(b);b=f*(-0.0-d);g=e;e=g*(-0.0-c);i=d*f;f=c*g;return+((f<0.0?0.0:f)+((i<0.0?0.0:i)+((e<0.0?0.0:e)+(b<0.0?0.0:b))))}function Ws(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+64|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;j=c[c[g+32>>2]>>2]|0;k=c[g+44>>2]|0;l=j+20|0;m=j+24|0;n=bv(j,c[l>>2]|0,c[m>>2]|0)|0;if((n|0)==0){VHb(e);o=-12;i=d;return o|0}ZHb(n,b)|0;b=a+160|0;p=k+160|0;h[p>>3]=+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0;b=(c[e>>2]|0)+136|0;q=c[b>>2]|0;s=c[b+4>>2]|0;if((q|0)==0&(s|0)==(-2147483648|0)){t=+r}else{t=(+(q>>>0)+ +(s|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}s=k+168|0;h[s>>3]=t;t=+XGb(c[k+20>>2]|0,k+80|0,k);h[k+8>>3]=t;u=+h[s>>3];KIb(g,48,2343368,(s=i,i=i+24|0,h[s>>3]=+h[p>>3],h[s+8>>3]=u,h[s+16>>3]=t/3.141592653589793,s)|0);i=s;s=~~(t*65536.0);p=s;q=(s|0)<0|0?-1:0;b=(s|0)<0;v=xrc(205887,0,p,q)|0;w=Drc(b?v:p,b?G:q,411774,0)|0;q=G;b=0;p=(q|0)>(b|0)|(q|0)==(b|0)&w>>>0>308829>>>0;b=wrc(w,q,-411774,-1)|0;v=p?b:w;w=p?G:q;q=0;p=(w|0)>(q|0)|(w|0)==(q|0)&v>>>0>102942>>>0;q=xrc(205887,0,v,w)|0;b=p?q:v;v=p?G:w;w=Erc(b,v,b,v)|0;p=G;q=xrc(0,0,w>>>16|p<<16,p>>>16|0<<16)|0;p=G;w=Erc(b,v,q,p)|0;x=Crc(w,G,393216,0)|0;w=G;y=Erc(x,w,q,p)|0;p=Crc(y,G,1310720,0)|0;y=wrc(p,G,x,w)|0;w=wrc(y,G,b,v)|0;v=w;w=s+102943|0;s=w;b=(w|0)<0|0?-1:0;y=(w|0)<0;w=xrc(205887,0,s,b)|0;x=Drc(y?w:s,y?G:b,411774,0)|0;b=G;y=0;s=(b|0)>(y|0)|(b|0)==(y|0)&x>>>0>308829>>>0;y=wrc(x,b,-411774,-1)|0;w=s?y:x;x=s?G:b;b=0;s=(x|0)>(b|0)|(x|0)==(b|0)&w>>>0>102942>>>0;b=xrc(205887,0,w,x)|0;y=s?b:w;w=s?G:x;x=Erc(y,w,y,w)|0;s=G;b=xrc(0,0,x>>>16|s<<16,s>>>16|0<<16)|0;s=G;x=Erc(y,w,b,s)|0;p=Crc(x,G,393216,0)|0;x=G;q=Erc(p,x,b,s)|0;s=Crc(q,G,1310720,0)|0;q=wrc(s,G,p,x)|0;x=wrc(q,G,y,w)|0;w=x;if((c[k+48>>2]|0)!=0){Oz(k+176|0,k+220|0,n|0,n+32|0,0,0,c[l>>2]|0,c[m>>2]|0)}x=k+60|0;if((c[x>>2]|0)>0){y=k+52|0;q=k+56|0;k=f|0;p=f+4|0;s=f+8|0;b=a+20|0;z=f+12|0;A=a+24|0;a=f+16|0;B=f+20|0;C=f+24|0;D=f+28|0;E=f+32|0;F=f+36|0;H=f+40|0;I=f+44|0;J=f+48|0;K=g+56|0;L=f;f=g+48|0;M=0;do{if((M-1|0)>>>0<2>>>0){N=c[q>>2]|0;O=c[y>>2]|0}else{N=0;O=0}P=-(c[l>>2]|0)>>O;Q=-(c[m>>2]|0)>>N;R=-Q|0;c[k>>2]=c[e>>2];c[p>>2]=n;c[s>>2]=-(-(c[b>>2]|0)>>O);c[z>>2]=-(-(c[A>>2]|0)>>N);c[a>>2]=-P;c[B>>2]=R;c[C>>2]=M;c[D>>2]=ca((P|0)/2|0,w)|0;c[E>>2]=ca((P|0)/-2|0,v)|0;P=(Q|0)/2|0;c[F>>2]=ca(P,v)|0;c[H>>2]=ca(P,w)|0;c[I>>2]=w;c[J>>2]=v;P=c[(c[f>>2]|0)+28>>2]|0;Xe[c[c[K>>2]>>2]&511](g,44,L,0,(P|0)<(R|0)?P:R)|0;M=M+1|0;}while((M|0)<(c[x>>2]|0))}VHb(e);o=lj(j,n)|0;i=d;return o|0}function Xs(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;j=i;i=i+8|0;k=j|0;l=c[f>>2]|0;m=c[f+4>>2]|0;n=c[e+44>>2]|0;e=c[f+16>>2]|0;o=c[f+20>>2]|0;p=c[f+8>>2]|0;q=c[f+12>>2]|0;r=c[f+24>>2]|0;s=c[f+28>>2]|0;t=c[f+32>>2]|0;u=c[f+44>>2]|0;v=c[f+48>>2]|0;w=(ca(o,g)|0)/(h|0)|0;x=(ca(o,g+1|0)|0)/(h|0)|0;if((w|0)>=(x|0)){i=j;return 0}h=ca(w,u)|0;g=ca(w,v)|0;o=(p<<16|0)/2|0;y=(q<<16|0)/2|0;z=(e|0)>0;A=m+(r<<2)|0;B=m+32+(r<<2)|0;m=n+188+(r<<2)|0;C=n+64|0;n=p-1|0;D=q-1|0;E=l+(r<<2)|0;F=l+32+(r<<2)|0;r=k|0;l=w;w=(c[f+40>>2]|0)+h|0;h=(c[f+36>>2]|0)+g|0;while(1){if(z){g=w+t+y|0;f=h+s+o|0;H=0;do{f=f+u|0;g=g-v|0;I=f>>16;J=g>>16;do{if(!((J|0)>(q|0)|(I|0)<=(p|0)&(I|0)>-2&(J|0)>-2^1)){K=c[A>>2]|0;L=ca(c[B>>2]|0,l)|0;M=c[m>>2]|0;N=(ca(M,H)|0)+L|0;L=K+N|0;do{if((c[C>>2]|0)==0){if((I|0)<0){O=0}else{O=(I|0)>(n|0)?n:I}if((J|0)<0){P=0}else{P=(J|0)>(D|0)?D:J}Q=(c[E>>2]|0)+((ca(c[F>>2]|0,P)|0)+(ca(O,M)|0))|0}else{R=c[E>>2]|0;S=c[F>>2]|0;if((I|0)<0){T=0}else{T=(I|0)>(n|0)?n:I}if((J|0)<0){U=0}else{U=(J|0)>(D|0)?D:J}V=f&65535;W=g&65535;X=T+1|0;Y=U+1|0;if((M|0)<=0){Q=r;break}Z=ca(T,M)|0;_=ca(U,S)|0;$=ca((X|0)>(n|0)?n:X,M)|0;X=ca((Y|0)>(D|0)?D:Y,S)|0;S=65536-V|0;Y=65536-W|0;aa=0;ba=W;W=0;da=0;while(1){ea=da+Z|0;fa=da+$|0;ga=(ca(d[R+(fa+_)|0]|0,V)|0)+(ca(d[R+(ea+_)|0]|0,S)|0)|0;ha=(ca(d[R+(fa+X)|0]|0,V)|0)+(ca(d[R+(ea+X)|0]|0,S)|0)|0;ea=Erc(ga,(ga|0)<0|0?-1:0,Y,aa)|0;ga=G;fa=Erc(ha,(ha|0)<0|0?-1:0,ba,W)|0;wrc(fa,G,ea,ga)|0;a[k+da|0]=G;ga=da+1|0;if((ga|0)<(M|0)){da=ga}else{Q=r;break}}}}while(0);if((M|0)==2){b[L>>1]=b[Q>>1]|0;break}else if((M|0)==4){c[L>>2]=c[Q>>2];break}else if((M|0)==3){da=a[Q]|0;W=a[Q+1|0]|0;a[K+(N+2)|0]=a[Q+2|0]|0;a[K+(N+1)|0]=W;a[L]=da;break}else if((M|0)==1){a[L]=a[Q]|0;break}else{nrc(L|0,Q|0,M)|0;break}}}while(0);H=H+1|0;}while((H|0)<(e|0))}H=l+1|0;if((H|0)<(x|0)){l=H;w=w+u|0;h=h+v|0}else{break}}i=j;return 0}function Ys(a){a=a|0;var b=0,d=0,e=0,f=0.0,j=0.0,k=0.0,l=0.0,m=0.0;b=i;d=c[a+44>>2]|0;e=d+2092|0;f=+g[e>>2];if(f<.1){j=+g[d+4>>2];g[e>>2]=j;k=j}else{k=f}e=d+2096|0;f=+g[e>>2];if(f<.1){j=+g[d+8>>2];g[e>>2]=j;l=j}else{l=f}e=d+2100|0;f=+g[e>>2];j=+g[d+12>>2];if(f<.1){g[e>>2]=j;m=j}else{m=f}g[d+2104>>2]=3.0;g[d+16>>2]=3.0;c[d+4188>>2]=16;f=+g[d+8>>2];KIb(a,40,2424640,(a=i,i=i+48|0,h[a>>3]=+g[d+4>>2],h[a+8>>3]=f,h[a+16>>3]=j,h[a+24>>3]=k,h[a+32>>3]=l,h[a+40>>3]=m,a)|0);i=a;i=b;return 0}function Zs(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=b+20|0;d=c[a>>2]|0;if((d|0)!=0){Jxb(d);c[a>>2]=0}mJb(b+24|0);mJb(b+40|0);a=b+2108|0;d=c[a>>2]|0;if((d|0)==0){e=b+2112|0;mJb(e);f=b+2128|0;mJb(f);return}Jxb(d);c[a>>2]=0;e=b+2112|0;mJb(e);f=b+2128|0;mJb(f);return}function _s(a){a=a|0;dl(a,Ok(684816)|0);return 0}function $s(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=c[c[f+32>>2]>>2]|0;f=bv(h,c[h+20>>2]|0,c[h+24>>2]|0)|0;if((f|0)==0){VHb(e);j=-12;i=d;return j|0}ZHb(f,b)|0;b=c[e>>2]|0;k=a+20|0;l=a+24|0;ct(c[f>>2]|0,c[f+32>>2]|0,c[b>>2]|0,c[b+32>>2]|0,c[k>>2]|0,c[l>>2]|0,g+4|0);b=c[e>>2]|0;if((c[b+8>>2]|0)!=0){a=-(-(c[k>>2]|0)>>c[g+4180>>2])|0;k=-(-(c[l>>2]|0)>>c[g+4184>>2])|0;l=g+2092|0;ct(c[f+4>>2]|0,c[f+36>>2]|0,c[b+4>>2]|0,c[b+36>>2]|0,a,k,l);b=c[e>>2]|0;ct(c[f+8>>2]|0,c[f+40>>2]|0,c[b+8>>2]|0,c[b+40>>2]|0,a,k,l)}VHb(e);j=lj(h,f)|0;i=d;return j|0}function at(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;f=b+4180|0;c[f>>2]=d[e+5|0]|0;g=b+4184|0;c[g>>2]=d[e+6|0]|0;e=b+20|0;h=c[e>>2]|0;if((h|0)!=0){Jxb(h);c[e>>2]=0}mJb(b+24|0);mJb(b+40|0);e=a+20|0;h=a+24|0;a=b+4188|0;i=bt(b+4|0,c[e>>2]|0,c[h>>2]|0,c[a>>2]|0)|0;if((i|0)<0){j=i;return j|0}i=b+2108|0;k=c[i>>2]|0;if((k|0)!=0){Jxb(k);c[i>>2]=0}mJb(b+2112|0);mJb(b+2128|0);j=bt(b+2092|0,-(-(c[e>>2]|0)>>c[f>>2])|0,-(-(c[h>>2]|0)>>c[g>>2])|0,c[a>>2]|0)|0;return j|0}function bt(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0;f=i;i=i+16|0;j=f|0;k=b+7&-8;l=hJb(ca(k,d)|0)|0;c[a+20>>2]=l;if((l|0)==0){m=-12;i=f;return m|0}c[a+24>>2]=k;k=a+12|0;l=Kxb(+g[a+4>>2],+g[k>>2])|0;c[j+4>>2]=l;c[j>>2]=l;c[j+12>>2]=0;c[j+8>>2]=0;c[a+16>>2]=Ixb(b,d,8,b,d,8,e,j,0,0)|0;Mxb(l);l=Kxb(+g[a+8>>2],5.0)|0;j=l+4|0;e=c[l>>2]|0;d=0;do{b=c[j>>2]|0;n=(b|0)/2|0;o=d-256+n|0;if((o|0)>-1&(o|0)<(b|0)){p=+h[e+(o<<3)>>3]}else{p=0.0}c[a+40+(d<<2)>>2]=~~(p/+h[e+(n<<3)>>3]*4096.0+.5);d=d+1|0;}while((d|0)<512);Mxb(l);l=Kxb(+g[a>>2],+g[k>>2])|0;k=l+4|0;d=c[k>>2]|0;c[a+28>>2]=d;e=(c[k>>2]|0)+7&-8;j=a+32|0;c[j>>2]=e;n=hJb(ca(d<<2,e)|0)|0;e=n;c[a+36>>2]=e;if((n|0)==0){Mxb(l);m=-12;i=f;return m|0}n=c[k>>2]|0;if((n|0)>0){a=l|0;d=0;o=n;while(1){if((o|0)>0){n=c[a>>2]|0;p=+h[n+(d<<3)>>3];b=0;while(1){c[e+((ca(c[j>>2]|0,d)|0)+b<<2)>>2]=~~(+h[n+(b<<3)>>3]*p*1024.0+.5);q=b+1|0;r=c[k>>2]|0;if((q|0)<(r|0)){b=q}else{s=r;break}}}else{s=o}b=d+1|0;if((b|0)<(s|0)){d=b;o=s}else{break}}}Mxb(l);m=0;i=f;return m|0}function ct(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=i;i=i+2152|0;m=l|0;n=l+2088|0;o=l+2104|0;p=l+2120|0;q=l+2136|0;nrc(m|0,k|0,2088)|0;k=c[m+28>>2]|0;r=n|0;c[r>>2]=f;mrc(n+4|0,0,12)|0;n=(k|0)/2|0;k=o|0;c[k>>2]=g;mrc(o+4|0,0,12)|0;o=p|0;s=c[m+20>>2]|0;c[o>>2]=s;mrc(p+4|0,0,12)|0;p=q|0;t=c[m+24>>2]|0;c[p>>2]=t;mrc(q+4|0,0,12)|0;hxb(c[m+16>>2]|0,r,k,0,j,o,p)|0;if((j|0)<=0){i=l;return}p=(h|0)>0;o=n<<1|1;k=(o|0)>0;r=c[m+32>>2]|0;q=c[m+36>>2]|0;u=(h<<1)-1|0;v=(j<<1)-1|0;w=h-n|0;x=0;do{if(p){y=ca(t,x)|0;z=x-n|0;A=ca(x,e)|0;B=0;do{C=d[s+(y+B)|0]|0;do{if((B|0)>=(n|0)&(B|0)<(w|0)){if(!k){D=0;E=0;break}F=B-n|0;G=C|256;H=0;I=0;J=0;while(1){K=z+H|0;if((K|0)<0){L=-K|0}else{L=(K|0)<(j|0)?K:v-K|0}K=ca(t,L)|0;M=ca(r,H)|0;N=ca(L,g)|0;O=I;P=0;Q=J;do{R=F+P|0;S=ca(c[q+(M+P<<2)>>2]|0,c[m+40+(G-(d[s+(K+R)|0]|0)<<2)>>2]|0)|0;Q=(ca(d[f+(R+N)|0]|0,S)|0)+Q|0;O=S+O|0;P=P+1|0;}while((P|0)<(o|0));P=H+1|0;if((P|0)<(o|0)){H=P;I=O;J=Q}else{D=Q;E=O;break}}}else{if(!k){D=0;E=0;break}J=B-n|0;I=C|256;H=0;G=0;F=0;while(1){P=z+H|0;if((P|0)<0){T=-P|0}else{T=(P|0)<(j|0)?P:v-P|0}P=ca(t,T)|0;N=ca(r,H)|0;K=ca(T,g)|0;M=G;S=F;R=0;do{U=J+R|0;if((U|0)<0){V=-U|0}else{V=(U|0)<(h|0)?U:u-U|0}U=ca(c[q+(N+R<<2)>>2]|0,c[m+40+(I-(d[s+(P+V)|0]|0)<<2)>>2]|0)|0;S=(ca(d[f+(V+K)|0]|0,U)|0)+S|0;M=U+M|0;R=R+1|0;}while((R|0)<(o|0));R=H+1|0;if((R|0)<(o|0)){H=R;G=M;F=S}else{D=S;E=M;break}}}}while(0);a[b+(B+A)|0]=(((E|0)/2|0)+D|0)/(E|0)|0;B=B+1|0;}while((B|0)<(h|0))}x=x+1|0;}while((x|0)<(j|0));i=l;return}function dt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+40|0;e=d|0;f=d+32|0;g=c[a+44>>2]|0;h=g+28|0;j=c[h>>2]|0;k=c[g+60>>2]|0;a:do{if((j|0)==0){l=g+60|0;if((k|0)==0){m=l;n=14;break}if((c[g+64>>2]|0)!=0){o=j;p=k;q=l;n=9;break}c[h>>2]=k;c[l>>2]=j;o=k;p=j;q=l;n=9}else{do{if((k|0)==0){if((c[g+64>>2]|0)!=0){break}o=j;p=0;q=g+60|0;n=9;break a}}while(0);KIb(a,16,2424544,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=d;return s|0}}while(0);if((n|0)==9){do{if((o|0)==0){t=p}else{j=g+20|0;k=g+24|0;l=bKb(j,k,o)|0;if((l|0)>=0){u=e|0;Rb(u|0,31,2282472,(r=i,i=i+8|0,c[r>>2]=c[j>>2],r)|0)|0;i=r;EJb(g,2233120,u,0)|0;Rb(u|0,31,2282472,(r=i,i=i+8|0,c[r>>2]=c[k>>2],r)|0)|0;i=r;EJb(g,2193888,u,0)|0;t=c[q>>2]|0;break}KIb(a,16,2341608,(r=i,i=i+8|0,c[r>>2]=c[h>>2],r)|0);i=r;s=l;i=d;return s|0}}while(0);if((t|0)==0){m=q;n=14}else{v=q}}if((n|0)==14){EJb(g,2233120,2162784,0)|0;v=m}m=g+64|0;n=c[m>>2]|0;if((n|0)==0){EJb(g,2193888,2137032,0)|0;w=c[m>>2]|0}else{w=n}n=g+68|0;m=c[n>>2]|0;q=c[g+56>>2]|0;KIb(a,40,2113616,(r=i,i=i+32|0,c[r>>2]=c[v>>2],c[r+8>>2]=w,c[r+16>>2]=(m|0)!=0?m:10230752,c[r+24>>2]=q,r)|0);i=r;r=g+32|0;c[r>>2]=0;do{if((c[n>>2]|0)!=0){c[f>>2]=exb()|0;q=f;m=DJb(q,2607128,0,0,2)|0;w=HJb(q,m,c[n>>2]|0,r)|0;if((w|0)<0){s=w}else{break}i=d;return s|0}}while(0);c[g+16>>2]=c[b>>2];c[b>>2]=0;s=0;i=d;return s|0}function et(a){a=a|0;var b=0;b=c[a+44>>2]|0;a=b+4|0;Jxb(c[a>>2]|0);Jxb(c[b+8>>2]|0);Jxb(c[b+12>>2]|0);c[a>>2]=0;OGb(b+16|0);return}function ft(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=a+16|0;do{if((c[c[e>>2]>>2]|0)!=0){c[d>>2]=0;f=0;while(1){if((zxb(f)|0)==0){if((Bxb(f)|0)!=0){g=5}}else{g=5}if((g|0)==5){g=0;h=Qk(d,f,(f|0)<0|0?-1:0)|0;if((h|0)<0){break}}j=f+1|0;if((j|0)<333){f=j}else{g=8;break}}if((g|0)==8){Yk(c[d>>2]|0,(c[c[e>>2]>>2]|0)+68|0);break}Zk(d);k=h;i=b;return k|0}}while(0);h=a+32|0;if((c[c[h>>2]>>2]|0)==0){k=0;i=b;return k|0}c[d>>2]=0;a=0;while(1){if((Axb(a)|0)!=0|(a|0)==11){g=13}else{if((Bxb(a)|0)!=0){g=13}}if((g|0)==13){g=0;l=Qk(d,a,(a|0)<0|0?-1:0)|0;if((l|0)<0){g=14;break}}e=a+1|0;if((e|0)<333){a=e}else{g=16;break}}if((g|0)==14){Zk(d);k=l;i=b;return k|0}else if((g|0)==16){Yk(c[d>>2]|0,(c[c[h>>2]>>2]|0)+64|0);k=0;i=b;return k|0}return 0}function gt(a){a=a|0;var b=0;if((a|0)==0){b=exb()|0}else{b=0}return b|0}function ht(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0,F=0.0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;e=i;i=i+160|0;f=e|0;g=e+120|0;j=e+128|0;k=e+144|0;l=e+152|0;m=l;n=c[b>>2]|0;o=c[c[n+16>>2]>>2]|0;p=b+52|0;q=c[p>>2]|0;s=c[n+44>>2]|0;t=o+52|0;u=qKb(c[t>>2]|0)|0;v=qKb(c[p>>2]|0)|0;w=o+20|0;x=+(c[w>>2]|0);h[f+8>>3]=x;y=f|0;h[y>>3]=x;z=o+24|0;A=+(c[z>>2]|0);h[f+24>>3]=A;h[f+16>>3]=A;B=f+40|0;h[B>>3]=+r;C=f+32|0;h[C>>3]=+r;D=f+56|0;h[D>>3]=+r;E=f+48|0;h[E>>3]=+r;F=x/A;h[f+64>>3]=F;H=o+28|0;I=H|0;J=c[I>>2]|0;if((J|0)==0){K=1.0}else{K=+(J|0)/+(c[o+32>>2]|0)}h[f+72>>3]=K;h[f+80>>3]=K*F;h[f+88>>3]=+(1<<(d[u+5|0]|0)|0);h[f+96>>3]=+(1<<(d[u+6|0]|0)|0);h[f+104>>3]=+(1<<(d[v+5|0]|0)|0);h[f+112>>3]=+(1<<(d[v+6|0]|0)|0);v=s+60|0;f=n;ZGb(g,c[v>>2]|0,281256,y,0,0,0,0,0,0,f)|0;F=+h[g>>3];h[B>>3]=F;h[C>>3]=F;C=s+20|0;c[C>>2]=~~F;B=s+64|0;n=c[B>>2]|0;J=ZGb(g,n,281256,y,0,0,0,0,0,0,f)|0;do{if((J|0)<0){L=J;M=n}else{F=+h[g>>3];h[D>>3]=F;h[E>>3]=F;N=s+24|0;c[N>>2]=~~F;O=c[v>>2]|0;P=ZGb(g,O,281256,y,0,0,0,0,0,0,f)|0;if((P|0)<0){L=P;M=O;break}O=~~+h[g>>3];c[C>>2]=O;P=c[N>>2]|0;Q=(O|0)<-1?-O|0:1;R=(P|0)<-1?-P|0:1;if((O&P|0)<0){c[N>>2]=0;c[C>>2]=0;S=0;T=8}else{if((O|0)==0){S=P;T=8}else{U=O;V=P}}if((T|0)==8){U=c[w>>2]|0;V=S}if((V|0)==0){W=c[z>>2]|0}else{W=V}P=W;O=(W|0)<0|0?-1:0;if((U|0)<0){N=c[w>>2]|0;X=ca(c[z>>2]|0,Q)|0;Y=VIb(P,O,N,(N|0)<0|0?-1:0,X,(X|0)<0|0?-1:0)|0;X=Erc(Y,G,Q,(Q|0)<0|0?-1:0)|0;Z=G;_=X}else{Z=(U|0)<0|0?-1:0;_=U}if((W|0)<0){X=c[z>>2]|0;Q=ca(c[w>>2]|0,R)|0;Y=VIb(_,Z,X,(X|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;Q=Erc(Y,G,R,(R|0)<0|0?-1:0)|0;$=G;aa=Q}else{$=O;aa=P}P=c[s+104>>2]|0;do{if((P|0)==0){ba=Z;da=_;ea=$;fa=aa}else{O=c[w>>2]|0;Q=O;R=(O|0)<0|0?-1:0;O=c[z>>2]|0;Y=O;X=(O|0)<0|0?-1:0;O=VIb(aa,$,Q,R,Y,X)|0;N=VIb(_,Z,Y,X,Q,R)|0;R=N;N=O;O=N;Q=(N|0)<0|0?-1:0;N=(Q|0)>(Z|0)|(Q|0)==(Z|0)&O>>>0>_>>>0;if((P|0)==1){X=R;Y=(R|0)<0|0?-1:0;ga=(Y|0)>($|0)|(Y|0)==($|0)&X>>>0>aa>>>0;ba=N?Z:Q;da=N?_:O;ea=ga?$:Y;fa=ga?aa:X;break}else{X=R;ga=(R|0)<0|0?-1:0;R=(ga|0)>($|0)|(ga|0)==($|0)&X>>>0>aa>>>0;ba=N?Q:Z;da=N?O:_;ea=R?ga:$;fa=R?X:aa;break}}}while(0);P=0;X=0;do{if((ba|0)>(P|0)|(ba|0)==(P|0)&da>>>0>2147483647>>>0|((ea|0)>(X|0)|(ea|0)==(X|0)&fa>>>0>2147483647>>>0)){T=22}else{R=c[w>>2]|0;ga=Erc(R,(R|0)<0|0?-1:0,fa,ea)|0;R=G;O=0;if((R|0)>(O|0)|(R|0)==(O|0)&ga>>>0>2147483647>>>0){T=22;break}ga=c[z>>2]|0;O=Erc(ga,(ga|0)<0|0?-1:0,da,ba)|0;ga=G;R=0;if((ga|0)>(R|0)|(ga|0)==(R|0)&O>>>0>2147483647>>>0){T=22}}}while(0);if((T|0)==22){KIb(f,16,2230528,(ha=i,i=i+1|0,i=i+7&-8,c[ha>>2]=0,ha)|0);i=ha}X=b+20|0;c[X>>2]=da;P=b+24|0;c[P>>2]=fa;O=d[u+7|0]|0;if((O&2|0)==0){ia=O>>>6&1}else{ia=1}c[s+48>>2]=ia;O=(q|0)==11?19:q;if((a[(qKb(O)|0)+7|0]&2)==0){ja=(d[(qKb(O)|0)+7|0]|0)>>>6&1}else{ja=1}c[s+52>>2]=ja;R=s+4|0;ga=c[R>>2]|0;if((ga|0)!=0){Jxb(ga)}ga=s+8|0;N=c[ga>>2]|0;if((N|0)!=0){Jxb(N)}N=s+12|0;Q=c[N>>2]|0;if((Q|0)!=0){Jxb(Q)}c[R>>2]=0;c[N>>2]=0;c[ga>>2]=0;do{if((c[w>>2]|0)==(c[X>>2]|0)){if((c[z>>2]|0)!=(c[P>>2]|0)){T=36;break}if((c[t>>2]|0)!=(c[p>>2]|0)){T=36}}else{T=36}}while(0);a:do{if((T|0)==36){c[j>>2]=R;c[j+4>>2]=ga;c[j+8>>2]=N;Q=s+16|0;Y=O;ka=(O|0)<0|0?-1:0;la=s+32|0;ma=s+96|0;na=s+100|0;oa=s+88|0;pa=s+92|0;qa=s+56|0;ra=0;b:while(1){if((ra|0)>=3){break a}sa=c[j+(ra<<2)>>2]|0;ta=Fxb()|0;c[sa>>2]=ta;if((ta|0)==0){ua=-12;T=50;break}va=c[Q>>2]|0;c:do{if((va|0)==0){wa=ta}else{xa=0;ya=va;while(1){za=LGb(ya,10230752,xa,2)|0;Aa=c[sa>>2]|0;if((za|0)==0){wa=Aa;break c}Ba=EJb(Aa,c[za>>2]|0,c[za+4>>2]|0,0)|0;if((Ba|0)<0){ua=Ba;T=50;break b}xa=za;ya=c[Q>>2]|0}}}while(0);va=c[w>>2]|0;IJb(wa,2226760,va,(va|0)<0|0?-1:0,0)|0;va=(ra|0)!=0|0;ta=c[z>>2]>>va;IJb(c[sa>>2]|0,2221840,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[t>>2]|0;IJb(c[sa>>2]|0,2218320,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[X>>2]|0;IJb(c[sa>>2]|0,2215472,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[P>>2]>>va;IJb(c[sa>>2]|0,2212920,ta,(ta|0)<0|0?-1:0,0)|0;IJb(c[sa>>2]|0,2210888,Y,ka,0)|0;IJb(c[sa>>2]|0,2607128,c[la>>2]|0,0,0)|0;ta=c[ma>>2]|0;IJb(c[sa>>2]|0,2206312,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[na>>2]|0;IJb(c[sa>>2]|0,2197728,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[oa>>2]|0;IJb(c[sa>>2]|0,2194560,ta,(ta|0)<0|0?-1:0,0)|0;ta=c[pa>>2]|0;IJb(c[sa>>2]|0,2192216,ta,(ta|0)<0|0?-1:0,0)|0;ta=Gxb(c[sa>>2]|0,0,0)|0;if((ta|0)<0){ua=ta;T=50;break}if((c[qa>>2]|0)==0){break a}else{ra=ra+1|0}}if((T|0)==50){i=e;return ua|0}}}while(0);O=b+28|0;if((c[I>>2]|0)==0){N=H;ga=O;R=c[N+4>>2]|0;c[ga>>2]=c[N>>2];c[ga+4>>2]=R}else{c[k>>2]=ca(c[w>>2]|0,c[P>>2]|0)|0;c[k+4>>2]=ca(c[z>>2]|0,c[X>>2]|0)|0;yKb(m,k,H);R=O;ga=c[l+4>>2]|0;c[R>>2]=c[l>>2];c[R+4>>2]=ga}ga=c[w>>2]|0;R=c[z>>2]|0;N=mKb(c[t>>2]|0)|0;ra=c[I>>2]|0;qa=c[o+32>>2]|0;pa=c[X>>2]|0;oa=c[P>>2]|0;na=mKb(c[p>>2]|0)|0;ma=c[O>>2]|0;O=c[b+32>>2]|0;la=c[s+32>>2]|0;KIb(f,40,2189528,(ha=i,i=i+88|0,c[ha>>2]=ga,c[ha+8>>2]=R,c[ha+16>>2]=N,c[ha+24>>2]=ra,c[ha+32>>2]=qa,c[ha+40>>2]=pa,c[ha+48>>2]=oa,c[ha+56>>2]=na,c[ha+64>>2]=ma,c[ha+72>>2]=O,c[ha+80>>2]=la,ha)|0);i=ha;ua=0;i=e;return ua|0}}while(0);f=c[v>>2]|0;v=c[B>>2]|0;KIb(0,16,2187016,(ha=i,i=i+24|0,c[ha>>2]=M,c[ha+8>>2]=f,c[ha+16>>2]=v,ha)|0);i=ha;ua=L;i=e;return ua|0}function it(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+96|0;f=e|0;g=e+8|0;h=e+40|0;j=e+48|0;k=e+56|0;l=e+64|0;m=e+72|0;n=e+80|0;o=e+88|0;c[f>>2]=b;p=a+8|0;q=c[p>>2]|0;r=c[q+44>>2]|0;s=c[c[q+32>>2]>>2]|0;q=a+52|0;t=qKb(c[q>>2]|0)|0;u=a+20|0;do{if((c[b+68>>2]|0)==(c[u>>2]|0)){if((c[b+72>>2]|0)!=(c[a+24>>2]|0)){v=4;break}if((c[b+80>>2]|0)!=(c[q>>2]|0)){v=4}}else{v=4}}while(0);do{if((v|0)==4){q=g|0;Rb(q|0,31,2282472,(b=i,i=i+8|0,c[b>>2]=c[s+20>>2],b)|0)|0;i=b;EJb(r,2233120,q,0)|0;Rb(q|0,31,2282472,(b=i,i=i+8|0,c[b>>2]=c[s+24>>2],b)|0)|0;i=b;EJb(r,2193888,q,0)|0;q=c[f>>2]|0;b=c[c[(c[p>>2]|0)+16>>2]>>2]|0;c[b+52>>2]=c[q+80>>2];c[b+20>>2]=c[q+68>>2];c[b+24>>2]=c[q+72>>2];q=ht(s)|0;if((q|0)<0){w=q}else{break}i=e;return w|0}}while(0);g=r+4|0;if((c[g>>2]|0)==0){w=lj(s,c[f>>2]|0)|0;i=e;return w|0}c[r+36>>2]=d[t+5|0]|0;c[r+40>>2]=d[t+6|0]|0;t=s+20|0;q=s+24|0;b=bv(s,c[t>>2]|0,c[q>>2]|0)|0;if((b|0)==0){VHb(f);w=-12;i=e;return w|0}ZHb(b,c[f>>2]|0)|0;c[b+68>>2]=c[t>>2];c[b+72>>2]=c[q>>2];if((c[r+52>>2]|0)!=0){x=c[s+52>>2]|0;rIb(c[b+4>>2]|0,(x|0)==11?19:x)|0}x=OHb(c[f>>2]|0)|0;y=r+72|0;do{if((c[y>>2]|0)==0){if((c[r+76>>2]|0)!=0){v=15;break}if((c[r+80>>2]|x|0)!=0){v=15;break}if((c[r+84>>2]|0)!=0){v=15}}else{v=15}}while(0);do{if((v|0)==15){Exb(c[g>>2]|0,n,h,o,j,k,l,m)|0;z=c[y>>2]|0;if((z|0)!=0){c[n>>2]=jt(z,MHb(c[f>>2]|0)|0)|0}z=c[r+76>>2]|0;if((z|0)!=0){c[o>>2]=jt(z,2)|0}z=c[r+80>>2]|0;do{if((z|0)==0){if((x|0)==0){break}c[h>>2]=(x|0)==2}else{c[h>>2]=(z|0)==2}}while(0);z=c[r+84>>2]|0;if((z|0)==0){A=c[j>>2]|0}else{B=(z|0)==2|0;c[j>>2]=B;A=B}Cxb(c[g>>2]|0,c[n>>2]|0,c[h>>2]|0,c[o>>2]|0,A,c[k>>2]|0,c[l>>2]|0,c[m>>2]|0)|0;B=c[r+8>>2]|0;if((B|0)!=0){Cxb(B,c[n>>2]|0,c[h>>2]|0,c[o>>2]|0,c[j>>2]|0,c[k>>2]|0,c[l>>2]|0,c[m>>2]|0)|0}B=c[r+12>>2]|0;if((B|0)==0){break}Cxb(B,c[n>>2]|0,c[h>>2]|0,c[o>>2]|0,c[j>>2]|0,c[k>>2]|0,c[l>>2]|0,c[m>>2]|0)|0}}while(0);m=c[f>>2]|0;l=c[m+124>>2]|0;k=c[q>>2]|0;q=Erc(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=c[u>>2]|0;u=Erc(q,G,l,(l|0)<0|0?-1:0)|0;l=G;q=c[m+128>>2]|0;m=c[t>>2]|0;t=Erc(m,(m|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;q=a+24|0;a=c[q>>2]|0;m=Erc(t,G,a,(a|0)<0|0?-1:0)|0;xKb(b+124|0,b+128|0,u,l,m,G,2147483647,0)|0;m=c[r+56>>2]|0;do{if((m|0)>0){C=c[f>>2]|0;v=34}else{l=c[f>>2]|0;if((m|0)<0){if((c[l+296>>2]|0)!=0){C=l;v=34;break}}kt(c[(c[p>>2]|0)+44>>2]|0,b,l,c[g>>2]|0,c[q>>2]|0,1,0)}}while(0);if((v|0)==34){kt(c[(c[p>>2]|0)+44>>2]|0,b,C,c[r+8>>2]|0,((c[q>>2]|0)+1|0)/2|0,2,0);kt(c[(c[p>>2]|0)+44>>2]|0,b,c[f>>2]|0,c[r+12>>2]|0,(c[q>>2]|0)/2|0,2,1)}VHb(f);w=lj(s,b)|0;i=e;return w|0}function jt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=(a|0)==0?2149904:a;a=(Db(c|0,2146488)|0)!=0;a:do{if(a){d=a?1:b}else{e=(Db(c|0,2139840)|0)!=0;if(e){d=e?4:b;break}e=(Db(c|0,2137560)|0)!=0;if(e){d=e?7:b;break}do{if((Db(c|0,2149904)|0)==0){if((Db(c|0,2135864)|0)!=0){break}if((Db(c|0,2134016)|0)==0){d=b;break a}}}while(0);d=5}}while(0);return Oxb((d|0)==0|d>>>0>7>>>0?5:d)|0}function kt(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+64|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=c[d+32>>2]|0;p=m|0;c[p>>2]=ca(o,g)|0;q=c[b+32>>2]|0;r=n|0;c[r>>2]=ca(q,g)|0;s=k|0;c[s>>2]=(c[d>>2]|0)+(ca(o,h)|0);o=l|0;c[o>>2]=(c[b>>2]|0)+(ca(q,h)|0);q=c[d+36>>2]|0;c[m+4>>2]=ca(q,g)|0;t=c[b+36>>2]|0;c[n+4>>2]=ca(t,g)|0;u=c[d+4>>2]|0;v=k+4|0;c[v>>2]=u+(ca(q,h)|0);q=c[b+4>>2]|0;w=l+4|0;c[w>>2]=q+(ca(t,h)|0);t=c[d+40>>2]|0;c[m+8>>2]=ca(t,g)|0;x=c[b+40>>2]|0;c[n+8>>2]=ca(x,g)|0;c[k+8>>2]=(c[d+8>>2]|0)+(ca(t,h)|0);c[l+8>>2]=(c[b+8>>2]|0)+(ca(x,h)|0);x=c[d+44>>2]|0;c[m+12>>2]=ca(x,g)|0;m=c[b+44>>2]|0;c[n+12>>2]=ca(m,g)|0;c[k+12>>2]=(c[d+12>>2]|0)+(ca(x,h)|0);c[l+12>>2]=(c[b+12>>2]|0)+(ca(m,h)|0);if((c[a+48>>2]|0)!=0){c[v>>2]=u}if((c[a+52>>2]|0)==0){y=hxb(e,s,p,0,f,o,r)|0;i=j;return}c[w>>2]=q;y=hxb(e,s,p,0,f,o,r)|0;i=j;return}function lt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=Wi(c[c[b+16>>2]>>2]|0)|0;if(!((e|0)==-541478725)){f=e;return f|0}e=d+4|0;b=c[e>>2]|0;if((b|0)==0){f=-541478725;return f|0}g=b+136|0;h=c[g>>2]|0;i=c[g+4>>2]<<1|h>>>31;c[g>>2]=h<<1|0>>>31;c[g+4>>2]=i;i=c[d>>2]|0;a:do{if((i|0)>0){if((c[b+300>>2]|0)==0){d=0;while(1){g=b+32+(d<<2)|0;c[g>>2]=c[g>>2]<<1;g=d+1|0;if((g|0)<(i|0)){d=g}else{j=b;break a}}}else{k=0}do{d=b+(k<<2)|0;g=b+32+(k<<2)|0;h=c[g>>2]|0;c[d>>2]=(c[d>>2]|0)+h;c[g>>2]=h<<1;k=k+1|0;}while((k|0)<(i|0));j=c[e>>2]|0}else{j=b}}while(0);b=lj(a,j)|0;c[e>>2]=0;f=b;return f|0}function mt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=c[c[d+16>>2]>>2]|0;c[e>>2]=uKb(c[f+52>>2]|0)|0;e=f+24|0;if((c[e>>2]&1|0)==0){c[a+56>>2]=c[f+56>>2];c[a+60>>2]=c[f+60>>2]<<1;c[a+116>>2]=c[f+116>>2]<<1;c[a+120>>2]=c[f+120>>2];c[a+20>>2]=c[f+20>>2];c[a+24>>2]=(c[e>>2]|0)/2|0;g=0;i=b;return g|0}else{KIb(d,16,2341072,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;g=-1094995529;i=b;return g|0}return 0}function nt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[a+8>>2]|0;a=c[d+44>>2]|0;e=c[c[d+32>>2]>>2]|0;c[b+72>>2]=c[e+24>>2];c[b+296>>2]=0;d=a+4|0;f=c[d>>2]|0;do{if((f|0)!=0){g=c[a>>2]|0;if((g|0)>0){if((c[f+300>>2]|0)==0){h=0;do{i=f+32+(h<<2)|0;c[i>>2]=c[i>>2]<<1;h=h+1|0;}while((h|0)<(g|0))}else{h=0;do{i=f+(h<<2)|0;j=f+32+(h<<2)|0;k=c[j>>2]|0;c[i>>2]=(c[i>>2]|0)+k;c[j>>2]=k<<1;h=h+1|0;}while((h|0)<(g|0))}}g=f+136|0;h=c[g>>2]|0;k=c[g+4>>2]|0;if((h|0)==0&(k|0)==(-2147483648|0)){l=-2147483648;m=0}else{j=b+136|0;i=c[j>>2]|0;n=c[j+4>>2]|0;j=(i|0)==0&(n|0)==(-2147483648|0);o=wrc(i,n,h,k)|0;l=j?-2147483648:G;m=j?0:o}c[g>>2]=m;c[g+4>>2]=l;g=lj(e,f)|0;if((g|0)<0){p=g}else{break}return p|0}}while(0);f=$Hb(b)|0;c[d>>2]=f;if((f|0)==0){p=-12;return p|0}f=c[a>>2]|0;if((f|0)>0){if((c[b+300>>2]|0)==0){a=0;do{d=b+(a<<2)|0;l=b+32+(a<<2)|0;m=c[l>>2]|0;c[d>>2]=(c[d>>2]|0)+m;c[l>>2]=m<<1;a=a+1|0;}while((a|0)<(f|0))}else{a=0;do{m=b+32+(a<<2)|0;c[m>>2]=c[m>>2]<<1;a=a+1|0;}while((a|0)<(f|0))}}f=b+136|0;a=c[f>>2]|0;m=c[f+4>>2]|0;if(!((a|0)==0&(m|0)==(-2147483648|0))){c[f>>2]=a<<1|0>>>31;c[f+4>>2]=m<<1|a>>>31}p=lj(e,b)|0;return p|0}function ot(a,b){a=a|0;b=b|0;var d=0;d=c[a+8>>2]|0;a=c[(c[d+44>>2]|0)+4>>2]|0;if((a|0)==2){c[b+296>>2]=0}else if((a|0)!=(-1|0)){c[b+296>>2]=1;c[b+300>>2]=a}return lj(c[c[d+32>>2]>>2]|0,b)|0}function pt(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;f=i;i=i+80|0;g=f|0;j=f+16|0;k=f+48|0;l=b+8|0;m=c[l>>2]|0;n=qKb(c[b+52>>2]|0)|0;mrc(g|0,0,16)|0;o=d[n+6|0]|0;p=e+80|0;q=e+68|0;r=b+24|0;s=0;t=0;while(1){u=e+(s<<2)|0;if((c[u>>2]|0)==0){v=t;break}w=e+32+(s<<2)|0;if((c[w>>2]|0)==0){v=t;break}x=oIb(c[p>>2]|0,c[q>>2]|0,s)|0;y=c[r>>2]|0;if((s-1|0)>>>0<2>>>0){z=-(-y>>o)|0}else{z=y}if((x|0)<0){A=x;B=24;break}if((z|0)>0){y=g+(s<<2)|0;C=c[w>>2]|0;w=0;D=t;E=c[u>>2]|0;u=c[y>>2]|0;while(1){F=oFb(u,E,x)|0;H=oFb(D,E,x)|0;I=w+1|0;if((I|0)<(z|0)){w=I;D=H;E=E+C|0;u=F}else{break}}c[y>>2]=F;J=H}else{J=t}u=s+1|0;if((u|0)<4){s=u;t=J}else{v=J;break}}if((B|0)==24){i=f;return A|0}B=m;m=b+160|0;J=c[m>>2]|0;t=c[m+4>>2]|0;m=j|0;mrc(m|0,0,32)|0;a[m]=0;j=e+136|0;s=c[j>>2]|0;H=c[j+4>>2]|0;if((s|0)==0&(H|0)==(-2147483648|0)){Rb(m|0,32,2193688,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}else{Rb(m|0,32,2136880,(K=i,i=i+16|0,c[K>>2]=s,c[K+8>>2]=H,K)|0)|0;i=K}H=k|0;mrc(H|0,0,32)|0;a[H]=0;k=c[j>>2]|0;s=c[j+4>>2]|0;if((k|0)==0&(s|0)==(-2147483648|0)){Rb(H|0,32,2193688,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0)|0;i=K}else{Rb(H|0,32,2162600,(K=i,i=i+8|0,h[K>>3]=(+(k>>>0)+ +(s|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),K)|0)|0;i=K}b=DHb(e)|0;s=G;k=c[n>>2]|0;n=c[e+124>>2]|0;j=c[e+128>>2]|0;F=c[q>>2]|0;q=c[e+72>>2]|0;if((c[e+296>>2]|0)==0){L=80}else{L=(c[e+300>>2]|0)!=0?84:66}z=c[e+84>>2]|0;o=(BLb(c[e+88>>2]|0)|0)<<24>>24;r=c[g>>2]|0;KIb(B,32,2340912,(K=i,i=i+128|0,c[K>>2]=J,c[K+8>>2]=t,c[K+16>>2]=m,c[K+24>>2]=H,c[K+32>>2]=b,c[K+40>>2]=s,c[K+48>>2]=k,c[K+56>>2]=n,c[K+64>>2]=j,c[K+72>>2]=F,c[K+80>>2]=q,c[K+88>>2]=L,c[K+96>>2]=z,c[K+104>>2]=o,c[K+112>>2]=v,c[K+120>>2]=r,K)|0);i=K;do{if((c[e+4>>2]|0)!=0){if((c[e+36>>2]|0)==0){break}KIb(B,32,2282216,(K=i,i=i+8|0,c[K>>2]=c[g+4>>2],K)|0);i=K;if((c[e+8>>2]|0)==0){break}if((c[e+40>>2]|0)==0){break}KIb(B,32,2282216,(K=i,i=i+8|0,c[K>>2]=c[g+8>>2],K)|0);i=K;if((c[e+12>>2]|0)==0){break}if((c[e+44>>2]|0)==0){break}KIb(B,32,2282216,(K=i,i=i+8|0,c[K>>2]=c[g+12>>2],K)|0);i=K}}while(0);KIb(B,32,2232792,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;A=lj(c[c[(c[l>>2]|0)+32>>2]>>2]|0,e)|0;i=f;return A|0}function qt(a){a=a|0;var b=0,d=0,e=0,f=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0;b=i;d=c[a+44>>2]|0;e=d+24|0;f=+g[e>>2];if(f<.1){j=+g[d+4>>2];g[e>>2]=j;k=j}else{k=f}e=d+28|0;f=+g[e>>2];if(f<-1.0){j=+g[d+8>>2];g[e>>2]=j;l=j}else{l=f}e=d+32|0;m=c[e>>2]|0;n=c[d+12>>2]|0;if((m|0)<-30){c[e>>2]=n;o=n}else{o=m}g[d+36>>2]=3.0;g[d+16>>2]=3.0;c[d+52>>2]=4;f=+g[d+8>>2];KIb(a,40,2423736,(a=i,i=i+48|0,h[a>>3]=+g[d+4>>2],h[a+8>>3]=f,c[a+16>>2]=n,h[a+24>>3]=k,h[a+32>>3]=l,c[a+40>>2]=o,a)|0);i=a;i=b;return 0}function rt(a){a=a|0;var b=0;b=c[a+44>>2]|0;Jxb(c[b+20>>2]|0);Jxb(c[b+40>>2]|0);return}function st(a){a=a|0;dl(a,Ok(684784)|0);return 0}function tt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=c[c[f+32>>2]>>2]|0;f=a+20|0;j=-(-(c[f>>2]|0)>>c[g+44>>2])|0;k=a+24|0;a=-(-(c[k>>2]|0)>>c[g+48>>2])|0;l=bv(h,c[h+20>>2]|0,c[h+24>>2]|0)|0;if((l|0)==0){VHb(e);m=-12;i=d;return m|0}ZHb(l,b)|0;b=c[e>>2]|0;wt(c[l>>2]|0,c[l+32>>2]|0,c[b>>2]|0,c[b+32>>2]|0,c[f>>2]|0,c[k>>2]|0,c[g+12>>2]|0,c[g+20>>2]|0);k=c[e>>2]|0;if((c[k+8>>2]|0)!=0){f=g+32|0;b=g+40|0;wt(c[l+4>>2]|0,c[l+36>>2]|0,c[k+4>>2]|0,c[k+36>>2]|0,j,a,c[f>>2]|0,c[b>>2]|0);k=c[e>>2]|0;wt(c[l+8>>2]|0,c[l+40>>2]|0,c[k+8>>2]|0,c[k+40>>2]|0,j,a,c[f>>2]|0,c[b>>2]|0)}VHb(e);m=lj(h,l)|0;i=d;return m|0}function ut(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;f=b+44|0;c[f>>2]=d[e+5|0]|0;g=b+48|0;c[g>>2]=d[e+6|0]|0;e=a+20|0;h=a+24|0;a=b+52|0;vt(b+4|0,c[e>>2]|0,c[h>>2]|0,c[a>>2]|0);vt(b+24|0,-(-(c[e>>2]|0)>>c[f>>2])|0,-(-(c[h>>2]|0)>>c[g>>2])|0,c[a>>2]|0);return 0}function vt(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;j=f|0;k=Kxb(+g[a>>2],+g[a+12>>2])|0;if((k|0)==0){i=f;return}l=a+4|0;Lxb(k,+g[l>>2]);m=(c[k>>2]|0)+(((c[k+4>>2]|0)/2|0)<<3)|0;h[m>>3]=1.0- +g[l>>2]+ +h[m>>3];c[j+4>>2]=k;c[j>>2]=k;c[j+12>>2]=0;c[j+8>>2]=0;c[a+16>>2]=Nxb(0,b,d,8,b,d,8,e,j,0,0)|0;Mxb(k);i=f;return}function wt(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;m=i;i=i+64|0;n=m|0;o=m+16|0;p=m+32|0;q=m+48|0;r=n|0;c[r>>2]=f;mrc(n+4|0,0,12)|0;n=o|0;c[n>>2]=b;mrc(o+4|0,0,12)|0;o=p|0;c[o>>2]=g;mrc(p+4|0,0,12)|0;p=q|0;c[p>>2]=e;mrc(q+4|0,0,12)|0;hxb(l,r,o,0,j,n,p)|0;if((k|0)>0){if((j|0)<=0){i=m;return}p=k<<1;if((h|0)>0){s=0}else{i=m;return}do{n=ca(s,g)|0;o=ca(s,e)|0;r=0;do{l=a[f+(r+n)|0]|0;q=l&255;t=b+(r+o)|0;u=q-(d[t]|0)|0;do{if((u|0)>0){if((u|0)>(p|0)){a[t]=l;break}if((u|0)<=(k|0)){break}a[t]=q-k}else{v=-u|0;if((p|0)<(v|0)){a[t]=l;break}if((v|0)<=(k|0)){break}a[t]=q+k}}while(0);r=r+1|0;}while((r|0)<(h|0));s=s+1|0;}while((s|0)<(j|0));i=m;return}else{if(!((k|0)<0&(j|0)>0)){i=m;return}s=-k|0;p=k*-2|0;r=k<<1;if((h|0)>0){w=0}else{i=m;return}do{o=ca(w,g)|0;n=ca(w,e)|0;q=0;do{t=a[f+(q+o)|0]|0;l=b+(q+n)|0;u=d[l]|0;v=(t&255)-u|0;do{if((v|0)>0){if((v|0)<=(s|0)){a[l]=t;break}if((v|0)>(p|0)){break}a[l]=u-k}else{if((v|0)>=(k|0)){a[l]=t;break}if((v|0)<(r|0)){break}a[l]=u+k}}while(0);q=q+1|0;}while((q|0)<(h|0));w=w+1|0;}while((w|0)<(j|0));i=m;return}}function xt(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;a=mWa(0)|0;c[b+32>>2]=a;if((a|0)==0){d=-12;return d|0}Nba(b+36|0,a);c[b+1300>>2]=72;a=c[b+12>>2]|0;if((a|0)==1){c[b+1304>>2]=64;d=0;return d|0}else if((a|0)==0){c[b+1304>>2]=376;d=0;return d|0}else{d=0;return d|0}return 0}function yt(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;mJb(b+28|0);mJb(b+24|0);a=b+32|0;d=c[a>>2]|0;if((d|0)==0){e=b+1280|0;mJb(e);return}r5a(d)|0;mJb(a);e=b+1280|0;mJb(e);return}function zt(a){a=a|0;dl(a,Ok(684736)|0);return 0}function At(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=c[a+44>>2]|0;if((irc(b,2423600)|0)!=0){h=-38;return h|0}if((irc(d,2340768)|0)==0){c[g+4>>2]=6;h=0;return h|0}b=rb(d|0,0,10)|0;if((b|0)<0){i=0}else{i=(b|0)>6?6:b}c[g+4>>2]=i;h=0;return h|0}function Bt(c,e,f,g,h,i,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((i|0)<=0){return}l=(h|0)>0;m=0;do{n=k+(m<<3)|0;if(l){o=ca(m,g)|0;p=ca(m,f)|0;q=k+(m<<3)+1|0;r=k+(m<<3)+2|0;s=k+(m<<3)+3|0;t=k+(m<<3)+4|0;u=k+(m<<3)+5|0;v=k+(m<<3)+6|0;w=k+(m<<3)+7|0;x=0;do{y=x+o|0;z=(b[e+(y<<1)>>1]<<j)+(d[n]|0)|0;A=z>>6;if((A&256|0)==0){B=A&255}else{B=(z>>31^255)&255}z=x+p|0;a[c+z|0]=B;A=(b[e+(y+1<<1)>>1]<<j)+(d[q]|0)|0;C=A>>6;if((C&256|0)==0){D=C&255}else{D=(A>>31^255)&255}a[c+(z+1)|0]=D;A=(b[e+(y+2<<1)>>1]<<j)+(d[r]|0)|0;C=A>>6;if((C&256|0)==0){E=C&255}else{E=(A>>31^255)&255}a[c+(z+2)|0]=E;A=(b[e+(y+3<<1)>>1]<<j)+(d[s]|0)|0;C=A>>6;if((C&256|0)==0){F=C&255}else{F=(A>>31^255)&255}a[c+(z+3)|0]=F;A=(b[e+(y+4<<1)>>1]<<j)+(d[t]|0)|0;C=A>>6;if((C&256|0)==0){G=C&255}else{G=(A>>31^255)&255}a[c+(z+4)|0]=G;A=(b[e+(y+5<<1)>>1]<<j)+(d[u]|0)|0;C=A>>6;if((C&256|0)==0){H=C&255}else{H=(A>>31^255)&255}a[c+(z+5)|0]=H;A=(b[e+(y+6<<1)>>1]<<j)+(d[v]|0)|0;C=A>>6;if((C&256|0)==0){I=C&255}else{I=(A>>31^255)&255}a[c+(z+6)|0]=I;A=(b[e+(y+7<<1)>>1]<<j)+(d[w]|0)|0;y=A>>6;if((y&256|0)==0){J=y&255}else{J=(A>>31^255)&255}a[c+(z+7)|0]=J;x=x+8|0;}while((x|0)<(h|0))}m=m+1|0;}while((m|0)<(i|0));return}function Ct(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=(e<<4)-1|0;e=g<<1;mrc(a|0,0,128)|0;b[a>>1]=((b[c>>1]|0)+4|0)>>>3;h=1;do{i=b[c+(h<<1)>>1]|0;if((i+g|0)>>>0>e>>>0){b[a+(d[f+h|0]<<1)>>1]=(i+4|0)>>>3}h=h+1|0;}while((h|0)<64);return}function Dt(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=e<<4;e=g-1|0;h=e<<1;mrc(a|0,0,128)|0;b[a>>1]=((b[c>>1]|0)+4|0)>>>3;i=1-g|4;g=1;do{j=b[c+(g<<1)>>1]|0;k=j<<16>>16;l=k+e|0;do{if(l>>>0>h>>>0){m=d[f+g|0]|0;if(j<<16>>16>0){b[a+(m<<1)>>1]=(i+k|0)>>>3;break}else{b[a+(m<<1)>>1]=(l+4|0)>>>3;break}}}while(0);g=g+1|0;}while((g|0)<64);return}function Et(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[g+44>>2]|0;j=h;k=c[c[g+32>>2]>>2]|0;c[f>>2]=0;l=h+8|0;do{if((c[l>>2]|0)==0){m=SHb(b,f,h+16|0)|0;if((m|0)==0){n=0;break}if((c[h+1288>>2]|0)!=0){n=m;break}if((c[(c[e>>2]|0)+88>>2]|0)==3){n=m;break}o=c[f>>2]|0;if((o|0)==0){p=c[a+20>>2]|0;q=1}else{p=o;q=(c[a+24>>2]|0)+15>>4}o=ca(p+15>>4,q)|0;if((o|0)>(c[h+1284>>2]|0)){KIb(0,0,2496752,(r=i,i=i+24|0,c[r>>2]=2485640,c[r+8>>2]=2474088,c[r+16>>2]=315,r)|0);i=r;Hd();return 0}else{nrc(c[h+1280>>2]|0,m|0,o)|0;n=m;break}}else{n=0}}while(0);do{if((c[h+4>>2]|0)==0){s=b}else{if((c[g+76>>2]|0)!=0){s=b;break}if((c[h+1288>>2]|0)==0){q=c[h+1280>>2]|0;t=(q|0)==0?n:q}else{t=n}if((t|0)==0){if((c[l>>2]|0)==0){s=b;break}}q=a+20|0;p=-(-(c[q>>2]|0)>>c[h+1292>>2])|0;m=a+24|0;o=-(-(c[m>>2]|0)>>c[h+1296>>2])|0;r=(bIb(c[e>>2]|0)|0)==0;u=c[q>>2]|0;do{if(r){v=21}else{if((u&7|0)!=0){v=21;break}w=c[m>>2]|0;if((w&7|0)!=0){v=21;break}x=b;y=u;z=w;A=c[e>>2]|0}}while(0);do{if((v|0)==21){r=bv(k,u+7&-8,(c[m>>2]|0)+7&-8)|0;if((r|0)!=0){ZHb(r,c[e>>2]|0)|0;w=c[e>>2]|0;c[r+68>>2]=c[w+68>>2];c[r+72>>2]=c[w+72>>2];x=r;y=c[q>>2]|0;z=c[m>>2]|0;A=w;break}VHb(e);B=-12;i=d;return B|0}}while(0);Gt(j,c[x>>2]|0,c[A>>2]|0,c[x+32>>2]|0,c[A+32>>2]|0,y,z,t,c[f>>2]|0,1);m=c[e>>2]|0;Gt(j,c[x+4>>2]|0,c[m+4>>2]|0,c[x+36>>2]|0,c[m+36>>2]|0,p,o,t,c[f>>2]|0,0);m=c[e>>2]|0;Gt(j,c[x+8>>2]|0,c[m+8>>2]|0,c[x+40>>2]|0,c[m+40>>2]|0,p,o,t,c[f>>2]|0,0);s=x}}while(0);x=c[e>>2]|0;if((x|0)!=(s|0)){f=c[x+12>>2]|0;if((f|0)!=0){uIb(c[s+12>>2]|0,c[s+44>>2]|0,f,c[x+44>>2]|0,c[a+20>>2]|0,c[a+24>>2]|0)}VHb(e)}B=lj(k,s)|0;i=d;return B|0}function Ft(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+24|0;f=(c[e>>2]|0)+31&-16;g=qKb(c[a+52>>2]|0)|0;c[b+1292>>2]=d[g+5|0]|0;c[b+1296>>2]=d[g+6|0]|0;g=a+20|0;a=(c[g>>2]|0)+31&-16;h=b+20|0;c[h>>2]=a;i=b+28|0;c[i>>2]=hJb(ca(f<<1,a)|0)|0;a=b+24|0;c[a>>2]=hJb(ca(c[h>>2]|0,f)|0)|0;do{if((c[b+1288>>2]|0)==0){f=ca((c[e>>2]|0)+15>>4,(c[g>>2]|0)+15>>4)|0;c[b+1284>>2]=f;h=qJb(f,1)|0;c[b+1280>>2]=h;if((h|0)!=0){break}return-12|0}}while(0);if((c[i>>2]|0)==0){return-12|0}else{return((c[a>>2]|0)==0?-12:0)|0}return 0}function Gt(b,e,f,g,h,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;o=i;i=i+256|0;p=o|0;q=b+4|0;r=1<<c[q>>2];if((n|0)==0){s=j+31&-16}else{s=c[b+20>>2]|0}t=p;u=p+128|0;p=b+24|0;if((k|0)>0){v=0;do{w=ca(v+8|0,s)|0;x=w+8|0;nrc((c[p>>2]|0)+x|0,f+(ca(v,h)|0)|0,j)|0;y=x+j|0;z=c[p>>2]|0;a[z+(w+7)|0]=a[z+x|0]|0;x=c[p>>2]|0;a[x+y|0]=a[x+(y-1)|0]|0;x=c[p>>2]|0;a[x+(w+6)|0]=a[x+(w+9)|0]|0;x=c[p>>2]|0;a[x+(y+1)|0]=a[x+(y-2)|0]|0;x=c[p>>2]|0;a[x+(w+5)|0]=a[x+(w+10)|0]|0;x=c[p>>2]|0;a[x+(y+2)|0]=a[x+(y-3)|0]|0;x=c[p>>2]|0;a[x+(w+4)|0]=a[x+(w+11)|0]|0;x=c[p>>2]|0;a[x+(y+3)|0]=a[x+(y-4)|0]|0;x=c[p>>2]|0;a[x+(w+3)|0]=a[x+(w+12)|0]|0;x=c[p>>2]|0;a[x+(y+4)|0]=a[x+(y-5)|0]|0;x=c[p>>2]|0;a[x+(w+2)|0]=a[x+(w+13)|0]|0;x=c[p>>2]|0;a[x+(y+5)|0]=a[x+(y-6)|0]|0;x=c[p>>2]|0;a[x+(w+1)|0]=a[x+(w+14)|0]|0;x=c[p>>2]|0;a[x+(y+6)|0]=a[x+(y-7)|0]|0;x=c[p>>2]|0;a[x+w|0]=a[x+(w+15)|0]|0;x=c[p>>2]|0;a[x+(y+7)|0]=a[x+(w+j)|0]|0;v=v+1|0;}while((v|0)<(k|0))}v=k+8|0;h=k+7|0;f=0;do{w=c[p>>2]|0;nrc(w+(ca(7-f|0,s)|0)|0,w+(ca(f+8|0,s)|0)|0,s)|0;w=c[p>>2]|0;nrc(w+(ca(v+f|0,s)|0)|0,w+(ca(h-f|0,s)|0)|0,s)|0;f=f+1|0;}while((f|0)<8);if((v|0)<=0){i=o;return}f=b+28|0;h=s<<4;w=j+8|0;x=(w|0)>0;y=b+8|0;z=n+3|0;n=j-1|0;A=k-1|0;k=b+16|0;B=(r|0)>0;C=r-1|0;D=b+36|0;E=b+1144|0;F=b+1304|0;G=b+1164|0;H=b+1152|0;I=b+1300|0;b=0;while(1){J=b+8|0;mrc((c[f>>2]|0)+((ca(J,s)|0)<<1)|0,0,h|0)|0;a:do{if(x){K=ca(((b|0)>(A|0)?A:b)>>z,m)|0;if(B){L=0}else{M=0;while(1){M=M+8|0;if((M|0)>=(w|0)){break a}}}do{M=c[y>>2]|0;do{if((M|0)==0){N=d[l+((((L|0)>(n|0)?n:L)>>z)+K)|0]|0;O=c[k>>2]|0;if((O|0)==2){P=N>>>2}else if((O|0)==3){P=65-N>>2}else if((O|0)==1){P=N>>>1}else{P=N}if((P|0)<1){Q=1;break}if((O|0)==3){Q=65-N>>2;break}else if((O|0)==2){Q=N>>>2;break}else if((O|0)==1){Q=N>>>1;break}else{Q=N;break}}else{Q=M}}while(0);M=0;do{N=C+M|0;O=(d[775856+(N<<1)|0]|0)+L+(ca((d[775857+(N<<1)|0]|0)+b|0,s)|0)|0;ef[c[D>>2]&4095](t,(c[p>>2]|0)+O|0,s);qe[c[E>>2]&1023](t);mf[c[F>>2]&2047](u,t,Q,G);qe[c[H>>2]&1023](u);N=c[f>>2]|0;R=O+2|0;S=O+4|0;T=O+6|0;U=0;do{V=U<<3;W=ca(U,s)|0;X=N+(W+O<<1)|0;c[X>>2]=(c[X>>2]|0)+(c[u+(V<<1)>>2]|0);X=N+(R+W<<1)|0;c[X>>2]=(c[X>>2]|0)+(c[u+((V|2)<<1)>>2]|0);X=N+(S+W<<1)|0;c[X>>2]=(c[X>>2]|0)+(c[u+((V|4)<<1)>>2]|0);X=N+(T+W<<1)|0;c[X>>2]=(c[X>>2]|0)+(c[u+((V|6)<<1)>>2]|0);U=U+1|0;}while((U|0)<8);M=M+1|0;}while((M|0)<(r|0));L=L+8|0;}while((L|0)<(w|0))}}while(0);if((b|0)!=0){K=e+(ca(b-8|0,g)|0)|0;M=(c[f>>2]|0)+((ca(b,s)|0)+8<<1)|0;U=v-b|0;Ge[c[I>>2]&255](K,M,g,s,j,(U|0)<8?U:8,6-(c[q>>2]|0)|0,1012784)}if((J|0)<(v|0)){b=J}else{break}}i=o;return}function Ht(a){a=a|0;VHb((c[a+44>>2]|0)+160|0);return}function It(a){a=a|0;dl(a,Ok((c[(c[a+44>>2]|0)+40>>2]|0)>>>0<14>>>0?2018760:738960)|0);return 0}function Jt(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;b=i;i=i+16|0;e=b|0;f=b+8|0;g=c[a>>2]|0;j=c[c[g+16>>2]>>2]|0;k=c[g+44>>2]|0;l=c[j+28>>2]|0;m=c[j+32>>2]|0;n=c[j+116>>2]|0;o=c[j+120>>2]|0;p=c[j+56>>2]|0;q=c[j+60>>2]|0;r=a+52|0;s=qKb(c[r>>2]|0)|0;t=c[k+4>>2]|0;a:do{switch(t|0){case 24:case 22:case 25:case 23:{u=c[j+24>>2]|0;do{if(((c[k+40>>2]|0)-16|0)>>>0<2>>>0){if((u&3|0)==0){break}KIb(g,16,2192128,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=b;return w|0}}while(0);if((u&1|0)==0){break a}KIb(g,16,2189456,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=b;return w|0};case 20:case 18:case 21:case 19:{if((c[j+20>>2]&1|0)==0){break a}KIb(g,16,2194440,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=b;return w|0};default:{}}}while(0);x=j+20|0;y=c[x>>2]|0;z=k+76|0;c[z>>2]=y;c[k+8>>2]=y;A=j+24|0;j=c[A>>2]|0;B=k+80|0;c[B>>2]=j;c[k+12>>2]=j;C=k+84|0;c[C>>2]=1;D=k+36|0;E=k+32|0;F=k+20|0;G=k+16|0;H=G;I=k+28|0;J=k+24|0;mrc(G|0,0,24)|0;switch(t|0){case 25:{K=m<<1;L=17;break};case 18:{M=l;L=11;break};case 24:{N=m<<1;L=15;break};case 19:{O=l;L=13;break};case 23:{K=m;L=17;break};case 21:{O=l<<1;L=13;break};case 22:{N=m;L=15;break};case 20:{M=l<<1;L=11;break};case 27:case 26:{G=a+156|0;c[G>>2]=c[G>>2]|1;P=m;Q=p<<1;R=o<<1;S=l;T=c[z>>2]|0;U=c[B>>2]|0;break};default:{KIb(g,16,2186904,(v=i,i=i+8|0,c[v>>2]=t,v)|0);i=v;w=-22;i=b;return w|0}}if((L|0)==11){t=(c[x>>2]|0)/2|0;c[z>>2]=t;c[F>>2]=t;P=m;Q=p;R=o;S=M;T=t;U=j}else if((L|0)==13){t=(c[x>>2]|0)/2|0;c[z>>2]=t;c[H>>2]=t;P=m;Q=p;R=o;S=O;T=t;U=j}else if((L|0)==15){j=(c[A>>2]|0)/2|0;c[B>>2]=j;c[D>>2]=j;P=N;Q=p;R=o;S=l;T=y;U=j}else if((L|0)==17){j=(c[A>>2]|0)/2|0;c[B>>2]=j;c[E>>2]=j;P=K;Q=p;R=o;S=l;T=y;U=j}j=k+44|0;c[j>>2]=T;y=k+48|0;c[y>>2]=U;l=k+72|0;o=k+68|0;p=k+52|0;K=p;A=k+40|0;mrc(p|0,0,24)|0;p=c[A>>2]|0;switch(p|0){case 24:{V=S<<1;L=27;break};case 12:case 13:case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 9:case 10:case 11:{N=e|0;Kz(N,c[r>>2]|0)|0;t=k+88|0;c[t+((d[N]|0)<<2)>>2]=2018776+((c[A>>2]|0)*72|0);c[t+((d[e+1|0]|0)<<2)>>2]=2018800+((c[A>>2]|0)*72|0);c[t+((d[e+2|0]|0)<<2)>>2]=2018824+((c[A>>2]|0)*72|0);W=P;X=q;Y=n;Z=S;_=c[j>>2]|0;break};case 25:{$=S<<1;L=29;break};case 21:{aa=P<<1;L=25;break};case 22:{V=S;L=27;break};case 18:{ba=P;L=23;break};case 20:{ba=P<<1;L=23;break};case 19:{aa=P;L=25;break};case 16:{c[C>>2]=2;c[B>>2]=(U|0)/2|0;c[I>>2]=1;c[k+64>>2]=1;W=P;X=q;Y=n;Z=S;_=T;break};case 17:{c[C>>2]=2;c[B>>2]=(U|0)/2|0;c[J>>2]=1;c[k+60>>2]=1;W=P;X=q;Y=n;Z=S;_=T;break};case 23:{$=S;L=29;break};case 14:{W=P;X=q;Y=n;Z=S;_=T;break};case 15:{c[H>>2]=c[F>>2];c[E>>2]=c[D>>2];W=P;X=q;Y=n;Z=S;_=T;break};case 27:case 26:{W=P;X=q<<1;Y=n<<1;Z=S;_=T;break};default:{KIb(g,16,2184464,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v;w=-22;i=b;return w|0}}if((L|0)==23){v=T<<1;c[j>>2]=v;c[k+56>>2]=T;W=ba;X=q;Y=n;Z=S;_=v}else if((L|0)==25){v=T<<1;c[j>>2]=v;c[K>>2]=T;W=aa;X=q;Y=n;Z=S;_=v}else if((L|0)==27){c[y>>2]=U<<1;c[l>>2]=U;W=P;X=q;Y=n;Z=V;_=T}else if((L|0)==29){c[y>>2]=U<<1;c[o>>2]=U;W=P;X=q;Y=n;Z=$;_=T}c[a+20>>2]=_;c[a+24>>2]=c[y>>2];c[a+116>>2]=Y;c[a+120>>2]=R;c[a+56>>2]=Q;c[a+60>>2]=X;c[a+28>>2]=Z;c[a+32>>2]=W;W=pIb(k+104|0,c[r>>2]|0,c[z>>2]|0)|0;if((W|0)<0){w=W;i=b;return w|0}c[k+100>>2]=uKb(c[r>>2]|0)|0;nIb(k+144|0,0,s);yKb(f,a+116|0,a+56|0);h[k+168>>3]=+(c[f+4>>2]|0)/+(c[f>>2]|0);f=c[B>>2]|0;B=s+6|0;a=-(-f>>(d[B]|0))|0;c[k+128>>2]=a;c[k+124>>2]=a;c[k+132>>2]=f;c[k+120>>2]=f;c[k+136>>2]=d[s+5|0]|0;c[k+140>>2]=d[B]|0;w=0;i=b;return w|0}function Kt(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0.0,ma=0;f=i;i=i+80|0;g=f|0;j=f+8|0;k=f+16|0;l=f+32|0;m=f+48|0;n=f+64|0;c[g>>2]=e;o=c[b+8>>2]|0;b=c[o+44>>2]|0;p=c[c[o+32>>2]>>2]|0;o=b+4|0;q=c[o>>2]|0;do{if((q-26|0)>>>0<2>>>0){r=b+160|0;s=c[r>>2]|0;if((s|0)!=0){t=(q|0)==27;u=t?e:s;v=t?s:e;break}c[r>>2]=e;w=0;i=f;return w|0}else{u=e;v=e}}while(0);q=p+20|0;r=p+24|0;s=bv(p,c[q>>2]|0,c[r>>2]|0)|0;c[j>>2]=s;if((s|0)==0){VHb(b+160|0);VHb(g);w=-12;i=f;return w|0}ZHb(s,e)|0;e=b+40|0;do{if(((c[e>>2]|0)-26|0)>>>0<2>>>0){t=bv(p,c[q>>2]|0,c[r>>2]|0)|0;if((t|0)!=0){ZHb(t,c[g>>2]|0)|0;x=t;y=c[j>>2]|0;break}VHb(j);VHb(b+160|0);VHb(g);w=-12;i=f;return w|0}else{x=s;y=s}}while(0);r=b+136|0;q=b+140|0;t=-(c[b+32>>2]|0)|0;z=c[b+24>>2]|0;A=b+144|0;B=-(c[b+16>>2]|0)|0;C=-(c[b+36>>2]|0)|0;D=c[b+28>>2]|0;E=-(c[b+20>>2]|0)|0;G=-(c[b+68>>2]|0)|0;H=c[b+60>>2]|0;I=-(c[b+52>>2]|0)|0;J=-(c[b+72>>2]|0)|0;K=c[b+64>>2]|0;L=-(c[b+56>>2]|0)|0;M=0;do{if((M-1|0)>>>0<2>>>0){N=c[q>>2]|0;O=c[r>>2]|0}else{N=0;O=0}P=ca(z-(t>>N)|0,c[u+32+(M<<2)>>2]|0)|0;S=c[A+(M<<2)>>2]|0;c[m+(M<<2)>>2]=P-((ca(S,B)|0)>>O);c[n+(M<<2)>>2]=(ca(D-(C>>N)|0,c[v+32+(M<<2)>>2]|0)|0)-((ca(S,E)|0)>>O);c[k+(M<<2)>>2]=(ca(c[y+32+(M<<2)>>2]|0,H-(G>>N)|0)|0)-((ca(S,I)|0)>>O);c[l+(M<<2)>>2]=(ca(K-(J>>N)|0,c[x+32+(M<<2)>>2]|0)|0)-((ca(S,L)|0)>>O);M=M+1|0;}while((M|0)<4);a:do{switch(c[e>>2]|0){case 12:case 13:case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 9:case 10:case 11:{M=c[u>>2]|0;O=c[v>>2]|0;L=c[s>>2]|0;N=c[b+44>>2]|0;J=b+88|0;K=b+48|0;I=c[K>>2]|0;if((I|0)<=0){break a}G=s+32|0;H=c[m>>2]|0;E=u+32|0;C=c[n>>2]|0;D=v+32|0;B=b+92|0;A=b+96|0;if((N|0)>0){T=0}else{t=0;while(1){t=t+1|0;if((t|0)>=(I|0)){break a}}}do{I=ca(c[D>>2]|0,T)|0;t=ca(c[E>>2]|0,T)|0;z=0;r=t+H|0;t=I+C|0;I=ca(c[G>>2]|0,T)|0;while(1){q=c[J>>2]|0;S=M+r|0;P=O+t|0;U=M+(r+1)|0;V=M+(r+2)|0;W=O+(t+1)|0;X=O+(t+2)|0;Y=ca(c[q>>2]|0,d[S]|0)|0;Z=ca(c[q+12>>2]|0,d[P]|0)|0;_=ca(c[q+4>>2]|0,d[U]|0)|0;$=ca(c[q+16>>2]|0,d[W]|0)|0;aa=ca(c[q+8>>2]|0,d[V]|0)|0;da=Z+Y+_+$+aa+(ca(c[q+20>>2]|0,d[X]|0)|0)>>16;if(da>>>0>255>>>0){ea=-da>>31&255}else{ea=da&255}a[L+I|0]=ea;da=c[B>>2]|0;q=ca(c[da>>2]|0,d[S]|0)|0;aa=ca(c[da+12>>2]|0,d[P]|0)|0;$=ca(c[da+4>>2]|0,d[U]|0)|0;_=ca(c[da+16>>2]|0,d[W]|0)|0;Y=ca(c[da+8>>2]|0,d[V]|0)|0;Z=aa+q+$+_+Y+(ca(c[da+20>>2]|0,d[X]|0)|0)>>16;if(Z>>>0>255>>>0){fa=-Z>>31&255}else{fa=Z&255}a[L+(I+1)|0]=fa;Z=c[A>>2]|0;da=ca(c[Z>>2]|0,d[S]|0)|0;S=ca(c[Z+12>>2]|0,d[P]|0)|0;P=ca(c[Z+4>>2]|0,d[U]|0)|0;U=ca(c[Z+16>>2]|0,d[W]|0)|0;W=ca(c[Z+8>>2]|0,d[V]|0)|0;V=S+da+P+U+W+(ca(c[Z+20>>2]|0,d[X]|0)|0)>>16;if(V>>>0>255>>>0){ga=-V>>31&255}else{ga=V&255}a[L+(I+2)|0]=ga;V=z+1|0;if((V|0)<(N|0)){z=V;r=r+3|0;t=t+3|0;I=I+3|0}else{break}}T=T+1|0;}while((T|0)<(c[K>>2]|0));break};case 14:{ia=u;ja=21;break};case 15:{ia=v;ja=21;break};case 26:case 27:case 18:case 19:case 20:case 21:case 22:case 23:case 24:case 25:case 16:case 17:{K=b+100|0;if((c[K>>2]|0)<=0){break a}N=b+84|0;L=b+104|0;A=b+120|0;B=0;O=y;while(1){M=c[N>>2]|0;J=ca(M,c[O+32+(B<<2)>>2]|0)|0;G=ca(c[u+32+(B<<2)>>2]|0,M)|0;M=L+(B<<2)|0;C=A+(B<<2)|0;uIb((c[O+(B<<2)>>2]|0)+(c[k+(B<<2)>>2]|0)|0,J,(c[u+(B<<2)>>2]|0)+(c[m+(B<<2)>>2]|0)|0,G,c[M>>2]|0,c[C>>2]|0);G=c[N>>2]|0;J=ca(G,c[x+32+(B<<2)>>2]|0)|0;H=ca(c[v+32+(B<<2)>>2]|0,G)|0;uIb((c[x+(B<<2)>>2]|0)+(c[l+(B<<2)>>2]|0)|0,J,(c[v+(B<<2)>>2]|0)+(c[n+(B<<2)>>2]|0)|0,H,c[M>>2]|0,c[C>>2]|0);C=B+1|0;if((C|0)>=(c[K>>2]|0)){break a}B=C;O=c[j>>2]|0}break};default:{KIb(0,0,2182296,(O=i,i=i+24|0,c[O>>2]=2180160,c[O+8>>2]=2178200,c[O+16>>2]=611,O)|0);i=O;Hd();return 0}}}while(0);do{if((ja|0)==21){n=b+100|0;if((c[n>>2]|0)<=0){break}v=b+104|0;l=b+120|0;u=0;do{uIb(c[s+(u<<2)>>2]|0,c[s+32+(u<<2)>>2]|0,(c[ia+(u<<2)>>2]|0)+(c[m+(u<<2)>>2]|0)|0,c[ia+32+(u<<2)>>2]|0,c[v+(u<<2)>>2]|0,c[l+(u<<2)>>2]|0);u=u+1|0;}while((u|0)<(c[n>>2]|0))}}while(0);VHb(g);VHb(b+160|0);g=c[j>>2]|0;do{if((x|0)==(g|0)){if(!(((c[o>>2]|0)-26|0)>>>0<2>>>0)){ka=s;break}ia=p+160|0;la=(+((c[ia>>2]|0)>>>0)+ +(c[ia+4>>2]|0)*4294967296.0)*+h[b+168>>3];ia=(F=+la,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);m=s+136|0;c[m>>2]=~~+la>>>0;c[m+4>>2]=ia;ka=s}else{if((c[e>>2]|0)==26){c[j>>2]=x;ma=g}else{ma=x}ia=p+160|0;m=b+168|0;la=(+((c[ia>>2]|0)>>>0)+ +(c[ia+4>>2]|0)*4294967296.0)*+h[m>>3];ja=(F=+la,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);n=ma+136|0;c[n>>2]=~~+la>>>0;c[n+4>>2]=ja;lj(p,ma)|0;ja=c[j>>2]|0;la=(+((c[ia>>2]|0)>>>0)+ +(c[ia+4>>2]|0)*4294967296.0)*+h[m>>3];m=(F=+la,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);ia=ja+136|0;c[ia>>2]=~~+la>>>0;c[ia+4>>2]=m;ka=ja}}while(0);w=lj(p,ka)|0;i=f;return w|0}function Lt(a){a=a|0;dl(a,Ok(684672)|0);return 0}function Mt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[c[(c[a>>2]|0)+16>>2]>>2]|0;e=d+20|0;f=a+20|0;c[f>>2]=c[e>>2]<<1;g=d+24|0;h=a+24|0;c[h>>2]=c[g>>2]<<1;a=c[d+8>>2]|0;j=mKb(c[d+52>>2]|0)|0;d=c[e>>2]|0;e=c[g>>2]|0;g=c[f>>2]|0;f=c[h>>2]|0;KIb(a,40,2340440,(a=i,i=i+40|0,c[a>>2]=j,c[a+8>>2]=d,c[a+16>>2]=e,c[a+24>>2]=g,c[a+32>>2]=f,a)|0);i=a;i=b;return 0}function Nt(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=b+8|0;j=c[c[(c[h>>2]|0)+32>>2]>>2]|0;k=j+20|0;l=j+24|0;m=bv(j,c[k>>2]|0,c[l>>2]|0)|0;if((m|0)==0){VHb(g);n=-12;i=f;return n|0}ZHb(m,e)|0;c[m+68>>2]=c[k>>2];c[m+72>>2]=c[l>>2];l=c[g>>2]|0;k=c[l>>2]|0;e=c[l+32>>2]|0;l=c[m>>2]|0;o=c[m+32>>2]|0;p=c[b+20>>2]|0;q=c[b+24>>2]|0;b=c[(c[h>>2]|0)+44>>2]|0;h=c[b+16>>2]|0;r=c[b>>2]|0;s=c[b+4>>2]|0;t=c[b+8>>2]|0;u=c[b+12>>2]|0;v=q-1|0;if((q|0)!=0){w=o<<1;x=b+20|0;b=(p|0)==0;z=q-3|0;A=p-3|0;B=k+(ca((v|0)<2?v:2,e)|0)|0;C=k+(ca((v|0)<1?v:1,e)|0)|0;v=k;D=k;k=0;while(1){E=ca(k,w)|0;F=ca(k<<1|1,o)|0;if((h|0)==4){G=c[B+8>>2]|0;H=c[B+4>>2]|0;I=c[B>>2]|0;J=c[C+8>>2]|0;K=c[D>>2]|0;L=c[D+4>>2]|0;M=c[D+8>>2]|0;N=c[v>>2]|0;O=c[v+4>>2]|0;P=c[v+8>>2]|0;Q=c[C>>2]|0;R=c[C+4>>2]|0}else if((h|0)==3){G=(d[B+7|0]|0)<<8|(d[B+8|0]|0)<<16|(d[B+6|0]|0);H=(d[B+4|0]|0)<<8|(d[B+5|0]|0)<<16|(d[B+3|0]|0);I=(d[B+1|0]|0)<<8|(d[B+2|0]|0)<<16|(d[B]|0);J=(d[C+7|0]|0)<<8|(d[C+8|0]|0)<<16|(d[C+6|0]|0);K=(d[D+1|0]|0)<<8|(d[D+2|0]|0)<<16|(d[D]|0);L=(d[D+4|0]|0)<<8|(d[D+5|0]|0)<<16|(d[D+3|0]|0);M=(d[D+7|0]|0)<<8|(d[D+8|0]|0)<<16|(d[D+6|0]|0);N=(d[v+1|0]|0)<<8|(d[v+2|0]|0)<<16|(d[v]|0);O=(d[v+4|0]|0)<<8|(d[v+5|0]|0)<<16|(d[v+3|0]|0);P=(d[v+7|0]|0)<<8|(d[v+8|0]|0)<<16|(d[v+6|0]|0);Q=(d[C+1|0]|0)<<8|(d[C+2|0]|0)<<16|(d[C]|0);R=(d[C+4|0]|0)<<8|(d[C+5|0]|0)<<16|(d[C+3|0]|0)}else{S=D;T=(d[S]|d[S+1|0]<<8)<<16>>16;if((c[x>>2]|0)==0){S=D+2|0;U=D+4|0;V=v;W=v+2|0;X=v+4|0;Y=C;Z=C+2|0;_=C+4|0;$=B;aa=B+2|0;ba=B+4|0;da=(d[ba]|d[ba+1|0]<<8)<<16>>16;ea=(d[$]|d[$+1|0]<<8)<<16>>16;fa=(d[_]|d[_+1|0]<<8)<<16>>16;ga=(d[Y]|d[Y+1|0]<<8)<<16>>16;ha=(d[X]|d[X+1|0]<<8)<<16>>16;ia=(d[V]|d[V+1|0]<<8)<<16>>16;ja=(d[U]|d[U+1|0]<<8)<<16>>16;ka=T;la=(d[S]|d[S+1|0]<<8)<<16>>16;ma=(d[W]|d[W+1|0]<<8)<<16>>16;na=(d[Z]|d[Z+1|0]<<8)<<16>>16;oa=(d[aa]|d[aa+1|0]<<8)<<16>>16}else{aa=he(T|0)|0;T=D+2|0;Z=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=D+4|0;W=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=v;S=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=v+2|0;U=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=v+4|0;V=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=C;X=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=C+2|0;Y=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=C+4|0;_=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=B;$=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=B+2|0;ba=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;T=B+4|0;da=he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0;ea=$;fa=_;ga=X;ha=V;ia=S;ja=W;ka=aa;la=Z;ma=U;na=Y;oa=ba}G=da&65535;H=oa&65535;I=ea&65535;J=fa&65535;K=ka&65535;L=la&65535;M=ja&65535;N=ia&65535;O=ma&65535;P=ha&65535;Q=ga&65535;R=na&65535}if(!b){ba=D;Y=v;U=C;Z=B;aa=R;W=Q;S=Q;V=P;X=O;_=N;$=N;T=M;pa=L;qa=K;ra=K;sa=J;ta=I;ua=I;va=H;wa=G;xa=0;while(1){ya=(W|0)==(X|0);za=ya^1;Aa=(_|0)==(aa|0);do{if(Aa|za){Ba=Aa^1;if(!(ya|Ba)){Ca=_;Da=_;break}if(Ba|za){Ba=(X|0)==(aa|0);Ea=(aa|0)==(ua|0);Fa=(W|0)==(va|0);do{if(Fa|Ba&Ea^1|(aa|0)==(ta|0)){if(Ea|(_|0)==(W|0)&Fa^1|(W|0)==(wa|0)){Ga=((W&r)>>>1)+(W&s&aa)+((aa&r)>>>1)|0;break}else{Ga=(((W&t)>>>2)*3|0)+((aa&t)>>>2)+((((W&u)*3|0)+(aa&u)|0)>>>2&u)|0;break}}else{Ga=(((aa&t)>>>2)*3|0)+((W&t)>>>2)+((((aa&u)*3|0)+(W&u)|0)>>>2&u)|0}}while(0);Fa=(X|0)==(qa|0);Ea=(_|0)==(pa|0);if(!(Ea|Ba&Fa^1|(X|0)==(ra|0))){Ca=Ga;Da=(((X&t)>>>2)*3|0)+((_&t)>>>2)+((((X&u)*3|0)+(_&u)|0)>>>2&u)|0;break}if(Fa|(_|0)==(W|0)&Ea^1|(_|0)==(T|0)){Ca=Ga;Da=((_&r)>>>1)+(_&s&X)+((X&r)>>>1)|0;break}else{Ca=Ga;Da=(((_&t)>>>2)*3|0)+((X&t)>>>2)+((((_&u)*3|0)+(X&u)|0)>>>2&u)|0;break}}if((X|0)==($|0)){Ha=($|0)!=(ua|0)|0}else{Ha=1}if((_|0)==($|0)){Ia=($|0)!=(ua|0)|0}else{Ia=1}if((X|0)==(S|0)){Ja=(X|0)!=(qa|0)|0}else{Ja=1}if((_|0)==(S|0)){Ka=(_|0)!=(qa|0)|0}else{Ka=1}if((X|0)==(va|0)){La=(va|0)!=(sa|0)|0}else{La=1}if((_|0)==(va|0)){Ma=(va|0)!=(sa|0)|0}else{Ma=1}if((X|0)==(pa|0)){Na=(pa|0)!=(V|0)|0}else{Na=1}if((_|0)==(pa|0)){Oa=(pa|0)!=(V|0)|0}else{Oa=1}Ea=Ha-Ia+Ja-Ka+La-Ma+(Na-Oa)|0;if((Ea|0)>0){Ca=X;Da=X;break}if((Ea|0)<0){Ca=_;Da=_;break}Ea=((_&r)>>>1)+(_&s&X)+((X&r)>>>1)|0;Ca=Ea;Da=Ea}else{Ca=W;Da=W}}while(0);do{if((_|0)!=(aa|0)|ya|($|0)!=(_|0)|(_|0)==(va|0)){if((X|0)!=(_|0)|(_|0)!=(S|0)|($|0)==(W|0)|(_|0)==(ta|0)){Pa=W;break}Pa=(_&s&W)+((_&r)>>>1)+((W&r)>>>1)|0}else{Pa=($&s&W)+(($&r)>>>1)+((W&r)>>>1)|0}}while(0);do{if((W|0)==(pa|0)|ya&(Aa^1)&(S|0)==(W|0)^1){if((aa|0)!=(W|0)|($|0)!=(W|0)|(S|0)==(_|0)|(W|0)==(ra|0)){Qa=_;break}Qa=($&s&_)+(($&r)>>>1)+((_&r)>>>1)|0}else{Qa=(_&s&W)+((_&r)>>>1)+((W&r)>>>1)|0}}while(0);do{if((h|0)==4){Aa=xa<<3;ya=Aa+E|0;c[l+ya>>2]=Qa;c[l+(ya+4)>>2]=Da;ya=Aa+F|0;c[l+ya>>2]=Pa;c[l+(ya+4)>>2]=Ca}else if((h|0)==3){ya=xa*6|0;Aa=ya+E|0;a[l+Aa|0]=Qa;a[l+(Aa|1)|0]=Qa>>>8;a[l+(Aa+2)|0]=Qa>>>16;a[l+(Aa+3)|0]=Da;a[l+(Aa+4)|0]=Da>>>8;a[l+(Aa+5)|0]=Da>>>16;Aa=ya+F|0;a[l+Aa|0]=Pa;a[l+(Aa+1)|0]=Pa>>>8;a[l+(Aa+2)|0]=Pa>>>16;a[l+(Aa+3)|0]=Ca;a[l+(Aa+4)|0]=Ca>>>8;a[l+(Aa+5)|0]=Ca>>>16}else{Aa=Qa|Da<<16;if((c[x>>2]|0)==0){ya=xa<<2;za=l+(ya+E)|0;y=Aa;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=l+(ya+F)|0;y=Pa|Ca<<16;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;break}else{za=xa<<2;ya=l+(za+E)|0;y=je(Aa|0)|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=l+(za+F)|0;y=je(Pa|Ca<<16|0)|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;break}}}while(0);do{if(xa>>>0<A>>>0){ya=xa+3|0;if((h|0)==4){Ra=c[Z+(ya<<2)>>2]|0;Sa=c[U+(ya<<2)>>2]|0;Ta=c[ba+(ya<<2)>>2]|0;Ua=c[Y+(ya<<2)>>2]|0;break}else if((h|0)==3){za=ya*3|0;Aa=za+2|0;Ea=za+1|0;Ra=(d[B+Ea|0]|0)<<8|(d[B+Aa|0]|0)<<16|(d[B+za|0]|0);Sa=(d[C+Ea|0]|0)<<8|(d[C+Aa|0]|0)<<16|(d[C+za|0]|0);Ta=(d[D+Ea|0]|0)<<8|(d[D+Aa|0]|0)<<16|(d[D+za|0]|0);Ua=(d[v+Ea|0]|0)<<8|(d[v+Aa|0]|0)<<16|(d[v+za|0]|0);break}else{za=ya<<1;ya=D+za|0;Aa=(d[ya]|d[ya+1|0]<<8)<<16>>16;if((c[x>>2]|0)==0){ya=v+za|0;Ea=C+za|0;Fa=B+za|0;Va=(d[Fa]|d[Fa+1|0]<<8)<<16>>16;Wa=Aa;Xa=(d[ya]|d[ya+1|0]<<8)<<16>>16;Ya=(d[Ea]|d[Ea+1|0]<<8)<<16>>16}else{Ea=he(Aa|0)|0;Aa=v+za|0;ya=he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0;Aa=C+za|0;Fa=he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0;Aa=B+za|0;Va=he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0;Wa=Ea;Xa=ya;Ya=Fa}Ra=Va&65535;Sa=Ya&65535;Ta=Wa&65535;Ua=Xa&65535;break}}else{Ra=wa;Sa=sa;Ta=T;Ua=V}}while(0);Fa=xa+1|0;if(Fa>>>0<p>>>0){S=W;W=aa;aa=sa;$=_;_=X;X=V;V=Ua;ra=qa;qa=pa;pa=T;T=Ta;sa=Sa;ta=ua;ua=va;va=wa;wa=Ra;xa=Fa}else{break}}}if(k>>>0<z>>>0){Za=B+e|0}else{Za=B}xa=k+1|0;if(xa>>>0<q>>>0){D=v;v=C;C=B;B=Za;k=xa}else{break}}}VHb(g);n=lj(j,m)|0;i=f;return n|0}function Ot(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=b;c[d>>2]=-16843010;e=b+4|0;c[e>>2]=16843009;f=b+8|0;c[f>>2]=-50529028;g=b+12|0;c[g>>2]=50529027;h=b+16|0;c[h>>2]=4;switch(c[a+52>>2]|0){case 49:case 45:{c[b+20>>2]=1;i=6;break};case 44:case 48:{i=4;break};case 50:case 46:{i=6;break};case 43:case 47:{c[b+20>>2]=1;i=4;break};case 2:case 3:{c[h>>2]=3;return 0};default:{return 0}}if((i|0)==4){c[d>>2]=-136382498;c[e>>2]=136382497;c[f>>2]=-409147492;c[g>>2]=409147491;c[h>>2]=2;return 0}else if((i|0)==6){c[d>>2]=2078178270;c[e>>2]=69272609;c[f>>2]=1939633052;c[g>>2]=207817827;c[h>>2]=2;return 0}return 0}function Pt(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;g=0;do{h=qKb(g)|0;a:do{if((a[h+7|0]&110)==0){j=a[h+4|0]|0;if((j&255)>>>0<3>>>0){break}if(!(((b[h+12>>1]^b[h+10>>1])&30720)==0)){break}k=j&255;j=0;while(1){if((j|0)>=(k|0)){break}l=b[h+8+(j<<1)>>1]|0;if(!((l&2016)==32)){break a}if((l&3|0)==(j|0)){j=j+1|0}else{break a}}Qk(f,g,(g|0)<0|0?-1:0)|0}}while(0);g=g+1|0;}while((g|0)<333);dl(d,c[f>>2]|0);i=e;return 0}function Qt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=cv(a,b,d)|0;d=e+8|0;b=c[d>>2]|0;a=e+4|0;c[d>>2]=c[a>>2];c[a>>2]=b;b=e+40|0;a=c[b>>2]|0;d=e+36|0;c[b>>2]=c[d>>2];c[d>>2]=a;a=e+240|0;d=c[a>>2]|0;b=c[a+4>>2]|0;f=e+232|0;g=c[f+4>>2]|0;c[a>>2]=c[f>>2];c[a+4>>2]=g;c[f>>2]=d;c[f+4>>2]=b;b=e+368|0;f=c[b>>2]|0;d=e+364|0;c[b>>2]=c[d>>2];c[d>>2]=f;return e|0}function Rt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+8|0;e=c[d>>2]|0;f=b+4|0;c[d>>2]=c[f>>2];c[f>>2]=e;e=b+40|0;f=c[e>>2]|0;d=b+36|0;c[e>>2]=c[d>>2];c[d>>2]=f;f=b+240|0;d=c[f>>2]|0;e=c[f+4>>2]|0;g=b+232|0;h=c[g+4>>2]|0;c[f>>2]=c[g>>2];c[f+4>>2]=h;c[g>>2]=d;c[g+4>>2]=e;e=b+368|0;g=c[e>>2]|0;d=b+364|0;c[e>>2]=c[d>>2];c[d>>2]=g;return lj(c[c[(c[a+8>>2]|0)+32>>2]>>2]|0,b)|0}function St(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=c[b+44>>2]|0;f=e+8|0;g=c[f>>2]|0;h=a[g]|0;if(h<<24>>24==0){KIb(b,16,2422464,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=d;return k|0}l=e+16|0;m=e+20|0;n=g;g=0;o=h;while(1){if((MFb(o<<24>>24)|0)==0){p=5;break}h=(a[n]|0)-48|0;q=(h|0)>(g|0)?h:g;r=(c[l>>2]|0)+2|0;c[l>>2]=r;s=(a[n]|0)-48+(c[m>>2]|0)|0;c[m>>2]=s;h=n+1|0;t=a[h]|0;if(t<<24>>24==0){p=7;break}else{n=h;g=q;o=t}}if((p|0)==5){KIb(b,16,2340344,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=d;return k|0}else if((p|0)==7){p=(q+1|0)/2|0;q=c[f>>2]|0;c[e+32>>2]=p;KIb(b,32,2281768,(j=i,i=i+32|0,c[j>>2]=q,c[j+8>>2]=p,c[j+16>>2]=r,c[j+24>>2]=s,j)|0);i=j;k=0;i=d;return k|0}return 0}function Tt(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;VHb(b+96|0);a=b+32|0;if((c[a>>2]|0)<=0){return}d=b+76|0;b=0;do{VHb(d+(b<<2)|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return}function Ut(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=0;do{if((a[(qKb(f)|0)+7|0]&14)==0){Qk(e,f,(f|0)<0|0?-1:0)|0}f=f+1|0;}while((f|0)<333);dl(b,c[e>>2]|0);i=d;return 0}function Vt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+8|0;d=b|0;e=d;f=i;i=i+8|0;g=i;i=i+8|0;j=g;k=i;i=i+8|0;l=k;m=i;i=i+8|0;n=c[a>>2]|0;o=c[n+44>>2]|0;p=c[c[n+16>>2]>>2]|0;q=p+116|0;r=q;s=c[r>>2]|0;t=c[r+4>>2]|0;c[d>>2]=s;c[d+4>>2]=t;r=s;s=t;do{if((r|0)==0){u=s}else{if((s|0)==0){u=0;break}t=o+16|0;v=c[t>>2]|0;c[f>>2]=c[o+20>>2];c[f+4>>2]=v;yKb(j,e,f);v=c[g>>2]|0;w=c[g+4>>2]|0;c[d>>2]=v;c[d+4>>2]=w;x=n;y=c[p+120>>2]|0;KIb(x,40,2473984,(z=i,i=i+32|0,c[z>>2]=c[q>>2],c[z+8>>2]=y,c[z+16>>2]=v,c[z+24>>2]=w,z)|0);i=z;w=a+156|0;c[w>>2]=c[w>>2]|1;w=a+116|0;v=c[d+4>>2]|0;c[w>>2]=c[d>>2];c[w+4>>2]=v;v=a+56|0;w=p+56|0;yKb(l,w,t);t=v;y=c[k>>2]|0;A=c[k+4>>2]|0;c[t>>2]=y;c[t+4>>2]=A;t=c[p+60>>2]|0;KIb(x,40,2465440,(z=i,i=i+32|0,c[z>>2]=c[w>>2],c[z+8>>2]=t,c[z+16>>2]=y,c[z+24>>2]=A,z)|0);i=z;yKb(m,e,v);h[o+24>>3]=+(c[m+4>>2]|0)/+(c[m>>2]|0);B=0;i=b;return B|0}}while(0);KIb(n,16,2485504,(z=i,i=i+16|0,c[z>>2]=r,c[z+8>>2]=u,z)|0);i=z;B=-22;i=b;return B|0}function Wt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0.0,H=0;e=i;i=i+8|0;f=e|0;c[f>>2]=d;d=c[b+8>>2]|0;b=c[c[d+32>>2]>>2]|0;g=c[d+44>>2]|0;d=g+12|0;j=c[d>>2]|0;k=c[g+8>>2]|0;l=a[k+j|0]|0;m=l-48|0;n=j+1|0;c[d>>2]=n;if((a[k+n|0]|0)==0){c[d>>2]=0}if((m|0)==0){VHb(f);o=0;i=e;return o|0}d=g+36|0;if((c[d>>2]|0)==0){p=0;q=m}else{m=g+40|0;if((c[m>>2]|0)>0){n=g+76|0;k=g+4|0;j=g+96|0;r=g+60|0;s=g+44|0;t=0;do{u=c[n>>2]|0;v=c[u+32+(t<<2)>>2]|0;w=c[k>>2]|0;x=(c[u+(t<<2)>>2]|0)+(ca(w,v)|0)|0;u=c[j>>2]|0;y=c[u+32+(t<<2)>>2]|0;z=(c[u+(t<<2)>>2]|0)+(ca(y,w)|0)|0;u=r+(t<<2)|0;A=s+(t<<2)|0;uIb(x,v<<1,z,y<<1,c[u>>2]|0,(1-w+(c[A>>2]|0)|0)/2|0);w=c[n>>2]|0;y=c[w+32+(t<<2)>>2]|0;z=(c[k>>2]|0)==0|0;v=-z|0;x=c[f>>2]|0;B=c[x+32+(t<<2)>>2]|0;uIb((c[w+(t<<2)>>2]|0)+(y&v)|0,y<<1,(c[x+(t<<2)>>2]|0)+(B&v)|0,B<<1,c[u>>2]|0,((z^1)+(c[A>>2]|0)|0)/2|0);t=t+1|0;}while((t|0)<(c[m>>2]|0))}c[d>>2]=0;p=1;q=l-49|0}if((q|0)>1){l=g+40|0;m=g+76|0;t=g+60|0;k=g+44|0;n=q-2|0;s=n>>>1;r=s<<1;j=p+s|0;s=q;A=p;z=c[l>>2]|0;while(1){if((z|0)>0){u=m+(A<<2)|0;B=0;while(1){v=c[u>>2]|0;x=c[f>>2]|0;uIb(c[v+(B<<2)>>2]|0,c[v+32+(B<<2)>>2]|0,c[x+(B<<2)>>2]|0,c[x+32+(B<<2)>>2]|0,c[t+(B<<2)>>2]|0,c[k+(B<<2)>>2]|0);x=B+1|0;v=c[l>>2]|0;if((x|0)<(v|0)){B=x}else{C=v;break}}}else{C=z}B=s-2|0;if((B|0)>1){s=B;A=A+1|0;z=C}else{break}}D=n-r|0;E=j+1|0}else{D=q;E=p}if((D|0)>0){D=g+40|0;if((c[D>>2]|0)>0){p=g+96|0;q=g+60|0;j=g+44|0;r=0;do{n=c[p>>2]|0;C=c[f>>2]|0;uIb(c[n+(r<<2)>>2]|0,c[n+32+(r<<2)>>2]|0,c[C+(r<<2)>>2]|0,c[C+32+(r<<2)>>2]|0,c[q+(r<<2)>>2]|0,c[j+(r<<2)>>2]|0);r=r+1|0;}while((r|0)<(c[D>>2]|0))}c[d>>2]=1}a:do{if((E|0)>0){d=g+76|0;D=b+160|0;r=g+24|0;j=0;while(1){q=$Hb(c[d+(j<<2)>>2]|0)|0;if((q|0)==0){break}G=(+((c[D>>2]|0)>>>0)+ +(c[D+4>>2]|0)*4294967296.0)*+h[r>>3];p=(F=+G,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);C=q+136|0;c[C>>2]=~~+G>>>0;c[C+4>>2]=p;p=lj(b,q)|0;q=j+1|0;if((q|0)<(E|0)){j=q}else{H=p;break a}}VHb(f);o=-12;i=e;return o|0}else{H=0}}while(0);VHb(f);o=H;i=e;return o|0}function Xt(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=qKb(c[e>>2]|0)|0;g=a+20|0;h=a+24|0;i=bv(a,c[g>>2]|0,c[h>>2]|0)|0;c[b+96>>2]=i;if((i|0)==0){j=-12;return j|0}i=b+32|0;k=b+76|0;l=0;while(1){if((l|0)>=(c[i>>2]|0)){break}m=bv(a,c[g>>2]|0,c[h>>2]|0)|0;c[k+(l<<2)>>2]=m;if((m|0)==0){j=-12;n=7;break}else{l=l+1|0}}if((n|0)==7){return j|0}n=pIb(b+60|0,c[e>>2]|0,c[g>>2]|0)|0;if((n|0)<0){j=n;return j|0}n=-(-(c[h>>2]|0)>>(d[f+6|0]|0))|0;c[b+52>>2]=n;c[b+48>>2]=n;n=c[h>>2]|0;c[b+56>>2]=n;c[b+44>>2]=n;c[b+40>>2]=uKb(c[e>>2]|0)|0;j=0;return j|0}function Yt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=d+8|0;f=qJb(c[e>>2]|0,3076)|0;c[d+12>>2]=f;d=a;if((f|0)==0){KIb(d,16,2422376,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-12;i=b;return h|0}else{KIb(d,40,2340304,(g=i,i=i+8|0,c[g>>2]=c[e>>2],g)|0);i=g;h=0;i=b;return h|0}return 0}function Zt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+44>>2]|0;a=b+12|0;d=a;e=b+8|0;if((c[e>>2]|0)>0){f=0}else{mJb(a);return}while(1){b=(c[d>>2]|0)+(f*3076|0)|0;if((c[b>>2]|0)==0){g=4;break}VHb(b);b=f+1|0;if((b|0)<(c[e>>2]|0)){f=b}else{g=4;break}}if((g|0)==4){mJb(a);return}}function _t(a){a=a|0;dl(a,Ok(684656)|0);return 0}function $t(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a>>2]|0;d=b+16|0;e=(c[b+44>>2]|0)+4|0;while(1){f=Wi(c[c[d>>2]>>2]|0)|0;if((f|0)==-541478725){g=3;break}if((f|0)<0){h=f;g=8;break}if((c[e>>2]|0)==0){h=0;g=8;break}}if((g|0)==3){do{if((c[e>>2]|0)!=0){d=lj(a,au(b)|0)|0;if((d|0)<0){h=d}else{break}return h|0}}while(0);h=-541478725;return h|0}else if((g|0)==8){return h|0}return 0}function au(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0.0,s=0.0,t=0,u=0,v=0,w=0;b=i;i=i+6144|0;d=b|0;e=c[a+44>>2]|0;f=e+4|0;g=c[f>>2]|0;mrc(d|0,0,6144)|0;j=(g|0)>0;k=+(g|0);l=e+12|0;if(j){m=0;do{n=c[l>>2]|0;o=0;p=+h[d+(m<<3)>>3];do{p=p+ +(c[n+(o*3076|0)+4+(m<<2)>>2]|0);o=o+1|0;}while((o|0)<(g|0));h[d+(m<<3)>>3]=p/k;m=m+1|0;}while(m>>>0<768>>>0)}else{m=0;do{o=d+(m<<3)|0;h[o>>3]=+h[o>>3]/k;m=m+1|0;}while(m>>>0<768>>>0)}do{if(j){m=c[l>>2]|0;o=0;n=0;k=-1.0;while(1){q=0;r=0.0;do{s=+h[d+(q<<3)>>3]- +(c[m+(n*3076|0)+4+(q<<2)>>2]|0);r=r+s*s;q=q+1|0;}while((q|0)<768);q=(n|0)==0|r<k;t=q?n:o;u=n+1|0;if((u|0)<(g|0)){o=t;n=u;k=q?r:k}else{break}}if(j){v=0}else{w=t;break}while(1){mrc((c[l>>2]|0)+(v*3076|0)+4|0,0,3072)|0;if((v|0)!=(t|0)){VHb((c[l>>2]|0)+(v*3076|0)|0)}n=v+1|0;if((n|0)<(g|0)){v=n}else{w=t;break}}}else{w=0}}while(0);c[f>>2]=0;f=c[(c[l>>2]|0)+(w*3076|0)>>2]|0;t=f+136|0;k=(+((c[t>>2]|0)>>>0)+ +(c[t+4>>2]|0)*4294967296.0)*(+(c[e+16>>2]|0)/+(c[e+20>>2]|0));KIb(a,32,2162248,(a=i,i=i+24|0,c[a>>2]=w,h[a+8>>3]=k,c[a+16>>2]=g,a)|0);i=a;c[(c[l>>2]|0)+(w*3076|0)>>2]=0;i=b;return f|0}function bu(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[a+8>>2]|0;f=c[e+44>>2]|0;g=c[c[e+32>>2]>>2]|0;h=f+4|0;i=c[h>>2]|0;j=c[f+12>>2]|0;k=c[b>>2]|0;c[j+(i*3076|0)>>2]=b;l=a+24|0;m=c[l>>2]|0;if((m|0)>0){n=a+20|0;a=b+32|0;b=0;o=k;k=c[n>>2]|0;p=m;while(1){if((k|0)>0){m=0;do{q=m*3|0;r=j+(i*3076|0)+4+((d[o+q|0]|0)<<2)|0;c[r>>2]=(c[r>>2]|0)+1;r=j+(i*3076|0)+4+((d[o+(q+1)|0]|0|256)<<2)|0;c[r>>2]=(c[r>>2]|0)+1;r=j+(i*3076|0)+4+((d[o+(q+2)|0]|0|512)<<2)|0;c[r>>2]=(c[r>>2]|0)+1;m=m+1|0;s=c[n>>2]|0;}while((m|0)<(s|0));t=s;u=c[l>>2]|0}else{t=k;u=p}m=b+1|0;if((m|0)<(u|0)){b=m;o=o+(c[a>>2]|0)|0;k=t;p=u}else{break}}v=c[h>>2]|0}else{v=i}i=v+1|0;c[h>>2]=i;if((i|0)<(c[f+8>>2]|0)){w=0;return w|0}w=lj(g,au(e)|0)|0;return w|0}function cu(a){a=a|0;var b=0,d=0;b=a+56|0;d=(c[(c[a+8>>2]|0)+44>>2]|0)+16|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;return 0}function du(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+44>>2]|0;e=c[d+4>>2]|0;f=c[d+8>>2]|0;if(e>>>0>1024>>>0|f>>>0>1024>>>0){KIb(a,16,2421968,(g=i,i=i+16|0,c[g>>2]=e,c[g+8>>2]=f,g)|0);i=g;h=-22;i=b;return h|0}j=d+24|0;d=c[j>>2]|0;k=ca(f,e)|0;if((d|0)==0){c[j>>2]=k;h=0;i=b;return h|0}if(!(d>>>0>k>>>0)){h=0;i=b;return h|0}KIb(a,16,2340088,(g=i,i=i+24|0,c[g>>2]=e,c[g+8>>2]=f,c[g+16>>2]=k,g)|0);i=g;h=-22;i=b;return h|0}function eu(a){a=a|0;dl(a,Qz(0)|0);return 0}function fu(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;a=c[b+44>>2]|0;d=Wi(c[c[b+16>>2]>>2]|0)|0;if(!((d|0)==-541478725)){e=d;return e|0}if((c[a+20>>2]|0)==0){e=-541478725;return e|0}e=hu(b)|0;return e|0}function gu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a>>2]|0;g=c[f+44>>2]|0;h=c[c[f+16>>2]>>2]|0;j=c[g+4>>2]|0;k=c[g+16>>2]|0;l=ca(j-1|0,k)|0;m=c[g+12>>2]<<1;n=m+l|0;l=g+8|0;o=c[l>>2]|0;p=(ca(o-1|0,k)|0)+m|0;m=c[h+20>>2]|0;if(m>>>0>(((2147483647-n|0)>>>0)/(j>>>0)|0)>>>0){KIb(f,16,2496576,(q=i,i=i+16|0,c[q>>2]=j,c[q+8>>2]=m,q)|0);i=q;r=-22;i=b;return r|0}k=h+24|0;s=c[k>>2]|0;if(s>>>0>(((2147483647-p|0)>>>0)/(o>>>0)|0)>>>0){KIb(f,16,2485456,(q=i,i=i+16|0,c[q>>2]=o,c[q+8>>2]=s,q)|0);i=q;r=-22;i=b;return r|0}else{c[a+20>>2]=(ca(m,j)|0)+n;c[a+24>>2]=(ca(c[k>>2]|0,c[l>>2]|0)|0)+p;p=h+28|0;l=a+28|0;k=c[p+4>>2]|0;c[l>>2]=c[p>>2];c[l+4>>2]=k;k=c[g+24>>2]|0;c[d>>2]=1;c[d+4>>2]=k;yKb(e,h+116|0,d);d=a+116|0;k=c[e+4>>2]|0;c[d>>2]=c[e>>2];c[d+4>>2]=k;k=g+28|0;Lz(k,c[h+52>>2]|0,0)|0;Mz(k,g+72|0,g+96|0);g=a+156|0;c[g>>2]=c[g>>2]|1;r=0;i=b;return r|0}return 0}function hu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a+44|0;d=c[b>>2]|0;e=c[c[a+32>>2]>>2]|0;f=c[d+92>>2]|0;g=d+20|0;h=c[g>>2]|0;i=d+24|0;if(!(h>>>0<(c[i>>2]|0)>>>0)){j=lj(e,f)|0;c[g>>2]=0;return j|0}k=a+16|0;a=f|0;l=f+32|0;m=d;d=h;while(1){h=c[c[k>>2]>>2]|0;n=c[h+20>>2]|0;o=c[h+24>>2]|0;h=m+20|0;p=c[m+4>>2]|0;q=c[m+12>>2]|0;r=c[m+16>>2]|0;Oz(m+28|0,m+72|0,a,l,(ca(r+n|0,(d>>>0)%(p>>>0)|0)|0)+q|0,(ca(r+o|0,(d>>>0)/(p>>>0)|0)|0)+q|0,n,o);c[h>>2]=(c[h>>2]|0)+1;if(!((c[g>>2]|0)>>>0<(c[i>>2]|0)>>>0)){break}h=c[b>>2]|0;m=h;d=c[h+20>>2]|0}j=lj(e,f)|0;c[g>>2]=0;return j|0}function iu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=c[a+8>>2]|0;f=b+44|0;g=c[f>>2]|0;h=c[c[b+32>>2]>>2]|0;j=g+20|0;do{if((c[j>>2]|0)==0){k=h+20|0;l=h+24|0;m=bv(h,c[k>>2]|0,c[l>>2]|0)|0;n=g+92|0;c[n>>2]=m;if((m|0)==0){VHb(e);o=-12;i=d;return o|0}ZHb(m,c[e>>2]|0)|0;m=c[n>>2]|0;c[m+68>>2]=c[k>>2];c[m+72>>2]=c[l>>2];if((c[g+12>>2]|0)==0){if((c[g+16>>2]|0)==0){p=n;break}}Oz(g+28|0,g+72|0,m|0,m+32|0,0,0,c[k>>2]|0,c[l>>2]|0);p=n}else{p=g+92|0}}while(0);h=c[f>>2]|0;f=c[c[b+16>>2]>>2]|0;n=c[h+20>>2]|0;l=c[h+4>>2]|0;k=c[h+12>>2]|0;m=c[h+16>>2]|0;h=(ca(m+(c[f+20>>2]|0)|0,(n>>>0)%(l>>>0)|0)|0)+k|0;q=(ca((c[f+24>>2]|0)+m|0,(n>>>0)/(l>>>0)|0)|0)+k|0;k=c[p>>2]|0;p=c[e>>2]|0;Nz(g+28|0,k|0,k+32|0,p|0,p+32|0,h,q,0,0,c[a+20>>2]|0,c[a+24>>2]|0);VHb(e);e=(c[j>>2]|0)+1|0;c[j>>2]=e;if((e|0)!=(c[g+24>>2]|0)){o=0;i=d;return o|0}o=hu(b)|0;i=d;return o|0}function ju(a){a=a|0;var b=0;b=c[a+44>>2]|0;VHb(b+20|0);VHb(b+24|0);mJb(b+28|0);return}function ku(a){a=a|0;dl(a,Ok(684592)|0);return 0}function lu(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;e=c[a>>2]|0;f=c[c[e+16>>2]>>2]|0;g=a+52|0;h=qKb(c[g>>2]|0)|0;j=c[e+44>>2]|0;k=h+6|0;c[j+16>>2]=d[k]|0;h=a+156|0;c[h>>2]=c[h>>2]|1;h=a+20|0;c[h>>2]=c[f+20>>2];l=j+4|0;m=c[l>>2]|0;do{if((m|0)==0|(m|0)==3){n=a+24|0;c[n>>2]=c[f+24>>2]<<1;if((m|0)!=3){o=n;break}p=(Nk(c[g>>2]|0,1204208)|0)==0;q=p?16:0;p=j+28|0;r=j+44|0;s=sIb(p,r,c[h>>2]|0,c[n>>2]|0,c[g>>2]|0,1)|0;if((s|0)<0){t=s;i=b;return t|0}s=c[p>>2]|0;if((s|0)==0){o=n;break}mrc(s|0,q|0,ca(c[r>>2]|0,c[n>>2]|0)|0)|0;r=c[j+32>>2]|0;if((r|0)==0){o=n;break}mrc(r|0,-128|0,ca(c[j+48>>2]|0,-(-(c[n>>2]|0)>>(d[k]|0))|0)|0)|0;r=c[j+36>>2]|0;if((r|0)==0){o=n;break}mrc(r|0,-128|0,ca(c[j+52>>2]|0,-(-(c[n>>2]|0)>>(d[k]|0))|0)|0)|0;r=c[j+40>>2]|0;if((r|0)==0){o=n;break}mrc(r|0,q|0,ca(c[j+56>>2]|0,c[n>>2]|0)|0)|0;o=n}else{n=a+24|0;c[n>>2]=c[f+24>>2];o=n}}while(0);a=j+8|0;j=c[a>>2]|0;do{if((j&1|0)==0){u=j}else{k=c[l>>2]|0;if((k-4|0)>>>0<2>>>0){u=j;break}KIb(e,24,2416592,(v=i,i=i+8|0,c[v>>2]=k,v)|0);i=v;k=c[a>>2]&-2;c[a>>2]=k;u=k}}while(0);a=c[f+24>>2]|0;f=c[o>>2]|0;KIb(e,40,2407784,(v=i,i=i+32|0,c[v>>2]=c[l>>2],c[v+8>>2]=(u&1|0)!=0?2400288:2393320,c[v+16>>2]=a,c[v+24>>2]=f,v)|0);i=v;t=0;i=b;return t|0}function mu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;e=c[a+8>>2]|0;f=c[c[e+32>>2]>>2]|0;g=c[e+44>>2]|0;e=g+20|0;VHb(e);h=g+24|0;j=c[h>>2]|0;c[e>>2]=j;c[h>>2]=b;if((j|0)==0){k=0;i=d;return k|0}e=c[g+4>>2]|0;a:do{switch(e|0){case 0:{l=f+24|0;m=bv(f,c[f+20>>2]|0,c[l>>2]|0)|0;if((m|0)==0){k=-12;i=d;return k|0}else{ZHb(m,j)|0;c[m+72>>2]=c[l>>2];c[m+296>>2]=1;c[m+300>>2]=1;l=m|0;n=m+32|0;o=a+52|0;p=a+20|0;q=a+24|0;r=g+8|0;nu(l,n,j|0,j+32|0,c[o>>2]|0,c[p>>2]|0,c[q>>2]|0,2,0,c[r>>2]|0);nu(l,n,b|0,b+32|0,c[o>>2]|0,c[p>>2]|0,c[q>>2]|0,2,1,c[r>>2]|0);VHb(h);s=m;break a}break};case 2:case 1:{m=$Hb((e|0)==1?j:b)|0;if((m|0)==0){k=-12;i=d;return k|0}else{VHb(h);s=m;break a}break};case 6:{m=$Hb(j)|0;if((m|0)==0){k=-12;i=d;return k|0}c[m+296>>2]=1;r=lj(f,m)|0;if((r|0)<0){k=r;i=d;return k|0}r=c[b+300>>2]|0;m=bv(f,c[f+20>>2]|0,c[f+24>>2]|0)|0;if((m|0)==0){k=-12;i=d;return k|0}else{ZHb(m,b)|0;c[m+296>>2]=1;q=m|0;p=m+32|0;o=a+52|0;n=a+20|0;l=a+24|0;t=(r|0)!=0|0;r=g+8|0;nu(q,p,j|0,j+32|0,c[o>>2]|0,c[n>>2]|0,c[l>>2]|0,t,t,c[r>>2]|0);u=t^1;nu(q,p,b|0,b+32|0,c[o>>2]|0,c[n>>2]|0,c[l>>2]|0,u,u,c[r>>2]|0);s=m;break a}break};case 3:{m=f+24|0;r=bv(f,c[f+20>>2]|0,c[m>>2]|0)|0;if((r|0)==0){k=-12;i=d;return k|0}else{ZHb(r,j)|0;c[r+72>>2]=c[m>>2];m=c[g+12>>2]&1;u=r|0;l=r+32|0;n=a+52|0;o=a+20|0;p=a+24|0;q=g+8|0;nu(u,l,j|0,j+32|0,c[n>>2]|0,c[o>>2]|0,c[p>>2]|0,2,m,c[q>>2]|0);nu(u,l,g+28|0,g+44|0,c[n>>2]|0,c[o>>2]|0,c[p>>2]|0,2,m^1,c[q>>2]|0);s=r;break a}break};case 4:case 5:{r=bv(f,c[f+20>>2]|0,c[f+24>>2]|0)|0;if((r|0)==0){k=-12;i=d;return k|0}else{q=(e|0)==4|0;ZHb(r,j)|0;c[r+296>>2]=1;c[r+300>>2]=q;m=r|0;p=r+32|0;o=a+52|0;n=a+20|0;l=a+24|0;u=q^1;t=g+8|0;nu(m,p,j|0,j+32|0,c[o>>2]|0,c[n>>2]|0,c[l>>2]|0,u,u,c[t>>2]|0);nu(m,p,b|0,b+32|0,c[o>>2]|0,c[n>>2]|0,c[l>>2]|0,q,q,c[t>>2]|0);VHb(h);s=r;break a}break};default:{KIb(0,0,2386576,(r=i,i=i+24|0,c[r>>2]=2379432,c[r+8>>2]=2373384,c[r+16>>2]=350,r)|0);i=r;Hd();return 0}}}while(0);h=lj(f,s)|0;s=g+12|0;c[s>>2]=(c[s>>2]|0)+1;k=h;i=d;return k|0}function nu(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;n=qKb(h)|0;o=(k|0)==2?1:2;p=n+4|0;if((a[p]|0)==0){return}q=-(-j>>d[n+6|0])|0;n=(k|0)==0|0;r=(k|0)==1;k=(l|0)==1;l=(m&1|0)==0;m=0;while(1){s=oIb(h,i,m)|0;t=c[b+(m<<2)>>2]|0;u=c[f+(m<<2)>>2]|0;if((s|0)<0){v=16;break}w=(((m-1|0)>>>0<2>>>0?q:j)+n|0)/(o|0)|0;if(r){x=u+(c[g+(m<<2)>>2]|0)|0}else{x=u}if(k){y=t+(c[e+(m<<2)>>2]|0)|0}else{y=t}a:do{if(l){uIb(y,c[e+(m<<2)>>2]<<1,x,ca(c[g+(m<<2)>>2]|0,o)|0,s,w)}else{t=g+(m<<2)|0;u=c[t>>2]|0;z=ca(u,o)|0;A=c[e+(m<<2)>>2]<<1;if((w|0)>0&(s|0)>0){B=y;C=x;D=w;E=u}else{break}while(1){u=(D|0)==(w|0)?C:C+(-E|0)|0;F=(D|0)==1?C:C+E|0;G=0;do{a[B+G|0]=((d[u+G|0]|0)+1+(d[F+G|0]|0)+(d[C+G|0]<<1)|0)>>>2;G=G+1|0;}while((G|0)<(s|0));G=D-1|0;if((G|0)<=0){break a}B=B+A|0;C=C+z|0;D=G;E=c[t>>2]|0}}}while(0);s=m+1|0;if((s|0)<(d[p]|0)){m=s}else{v=16;break}}if((v|0)==16){return}}function ou(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=0;do{g=qKb(f)|0;do{if((a[g+7|0]&14)==0){if((a[g+5|0]|0)!=(a[g+6|0]|0)){break}Qk(e,f,(f|0)<0|0?-1:0)|0}}while(0);f=f+1|0;}while((f|0)<333);dl(b,c[e>>2]|0);i=d;return 0}function pu(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=i;i=i+16|0;e=b|0;f=b+8|0;g=f;h=c[a>>2]|0;j=c[h+44>>2]|0;k=c[c[h+16>>2]>>2]|0;l=qKb(c[a+52>>2]|0)|0;m=qKb(c[k+52>>2]|0)|0;n=j+32|0;if((c[n>>2]&4|0)!=0){KIb(h,24,2453160,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[n>>2]=c[n>>2]&3;c[j+28>>2]=1}p=k+20|0;q=c[p>>2]|0;r=k+24|0;s=c[r>>2]|0;if((q|0)<(s|0)){t=5}else{if((c[j+28>>2]|0)!=1){t=5}}do{if((t|0)==5){u=j+28|0;if((q|0)<=(s|0)){if((c[u>>2]|0)==2){break}}c[u>>2]=0;c[j+4>>2]=d[m+5|0]|0;c[j+8>>2]=d[m+6|0]|0;nIb(j+12|0,0,l);u=c[r>>2]|0;v=a+20|0;c[v>>2]=u;w=c[p>>2]|0;x=a+24|0;c[x>>2]=w;y=k+28|0;z=a+28|0;if((c[y>>2]|0)==0){A=y;B=z;C=c[A+4>>2]|0;c[B>>2]=c[A>>2];c[B+4>>2]=C;D=u;E=w}else{c[e>>2]=1;c[e+4>>2]=1;zKb(g,e,y);y=z;z=c[f+4>>2]|0;c[y>>2]=c[f>>2];c[y+4>>2]=z;D=c[v>>2]|0;E=c[x>>2]|0}x=h;v=c[p>>2]|0;z=c[r>>2]|0;y=c[n>>2]|0;if((y|0)==1){F=1;G=2416552;t=13}else{w=(y|0)==3?2416552:2407704;if((y|0)==0){H=1;I=w}else{F=y;G=w;t=13}}if((t|0)==13){H=(F|0)==3|0;I=G}KIb(x,40,2426664,(o=i,i=i+56|0,c[o>>2]=v,c[o+8>>2]=z,c[o+16>>2]=y,c[o+24>>2]=D,c[o+32>>2]=E,c[o+40>>2]=I,c[o+48>>2]=H,o)|0);i=o;i=b;return 0}}while(0);KIb(h,40,2436704,(o=i,i=i+32|0,c[o>>2]=q,c[o+8>>2]=s,c[o+16>>2]=q,c[o+24>>2]=s,o)|0);i=o;i=b;return 0}function qu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((c[(c[(c[a+8>>2]|0)+44>>2]|0)+28>>2]|0)==0){e=cv(a,b,d)|0;return e|0}else{e=av(a,b,d)|0;return e|0}return 0}function ru(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;a=c[c[g+32>>2]>>2]|0;if((c[(c[g+44>>2]|0)+28>>2]|0)!=0){h=lj(a,b)|0;i=d;return h|0}j=a+24|0;k=bv(a,c[a+20>>2]|0,c[j>>2]|0)|0;if((k|0)==0){VHb(e);h=-12;i=d;return h|0}ZHb(k,b)|0;b=c[e>>2]|0;l=b+124|0;if((c[l>>2]|0)==0){m=l;l=k+124|0;n=c[m+4>>2]|0;c[l>>2]=c[m>>2];c[l+4>>2]=n}else{c[k+124>>2]=c[b+128>>2];c[k+128>>2]=c[b+124>>2]}c[f>>2]=b;c[f+4>>2]=k;b=c[j>>2]|0;j=c[(c[g+48>>2]|0)+28>>2]|0;Xe[c[c[g+56>>2]>>2]&511](g,804,f,0,(b|0)>(j|0)?j:b)|0;VHb(e);h=lj(a,k)|0;i=d;return h|0}function su(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;h=c[d+44>>2]|0;d=c[e+4>>2]|0;i=c[e>>2]|0;e=c[d>>2]|0;if((e|0)==0){return 0}j=h+4|0;k=h+8|0;l=h+12|0;m=d+68|0;n=d+72|0;o=f+1|0;p=h+32|0;h=i+72|0;q=0;r=e;do{if((q-1|0)>>>0<2>>>0){s=c[k>>2]|0;t=c[j>>2]|0}else{s=0;t=0}e=-(c[m>>2]|0)>>t;u=-e|0;v=-(c[n>>2]|0)>>s;w=-v|0;x=(ca(w,f)|0)/(g|0)|0;y=(ca(o,w)|0)/(g|0)|0;w=c[d+32+(q<<2)>>2]|0;z=c[i+(q<<2)>>2]|0;A=c[i+32+(q<<2)>>2]|0;B=c[p>>2]|0;if((B&1|0)==0){C=z;D=A}else{C=z+(ca((c[h>>2]>>s)-1|0,A)|0)|0;D=-A|0}if((B&2|0)==0){E=x;F=w}else{E=~x-v|0;F=-w|0}v=r+(ca(w,E)|0)|0;a:do{switch(c[l+(q<<2)>>2]|0){case 4:{if((x|0)<(y|0)&(e|0)<0){G=x;H=v}else{break a}while(1){w=G<<2;B=0;do{c[H+(B<<2)>>2]=c[C+((ca(B,D)|0)+w)>>2];B=B+1|0;}while((B|0)<(u|0));B=G+1|0;if((B|0)<(y|0)){G=B;H=H+F|0}else{break}}break};case 3:{if((x|0)>=(y|0)){break a}B=(e|0)<0;w=x;A=v;while(1){if(B){z=w*3|0;I=0;do{J=(ca(I,D)|0)+z|0;K=a[C+J|0]|0;L=a[C+(J+1)|0]|0;M=I*3|0;a[A+(M+2)|0]=a[C+(J+2)|0]|0;a[A+(M+1)|0]=L;a[A+M|0]=K;I=I+1|0;}while((I|0)<(u|0))}I=w+1|0;if((I|0)<(y|0)){w=I;A=A+F|0}else{break}}break};case 1:{if((x|0)>=(y|0)){break a}A=(e|0)<0;w=x;B=v;while(1){if(A){I=0;do{a[B+I|0]=a[C+((ca(I,D)|0)+w)|0]|0;I=I+1|0;}while((I|0)<(u|0))}I=w+1|0;if((I|0)<(y|0)){w=I;B=B+F|0}else{break}}break};case 6:{if((x|0)<(y|0)&(e|0)<0){N=x;O=v}else{break a}while(1){B=N*6|0;w=0;do{A=(ca(w,D)|0)+B|0;I=a[C+A|0]|0;z=a[C+(A+1)|0]|0;K=a[C+(A+2)|0]|0;M=a[C+(A+3)|0]|0;L=a[C+(A+4)|0]|0;J=w*6|0;a[O+(J+5)|0]=a[C+(A+5)|0]|0;a[O+(J+4)|0]=L;a[O+(J+3)|0]=M;a[O+(J+2)|0]=K;a[O+(J|1)|0]=z;a[O+J|0]=I;w=w+1|0;}while((w|0)<(u|0));w=N+1|0;if((w|0)<(y|0)){N=w;O=O+F|0}else{break}}break};case 8:{if((x|0)<(y|0)&(e|0)<0){P=x;Q=v}else{break a}while(1){w=P<<3;B=0;do{I=C+((ca(B,D)|0)+w)|0;J=c[I+4>>2]|0;z=Q+(B<<3)|0;c[z>>2]=c[I>>2];c[z+4>>2]=J;B=B+1|0;}while((B|0)<(u|0));B=P+1|0;if((B|0)<(y|0)){P=B;Q=Q+F|0}else{break}}break};case 2:{if((x|0)>=(y|0)){break a}B=(e|0)<0;w=x;J=v;while(1){if(B){z=w<<1;I=0;do{b[J+(I<<1)>>1]=b[C+((ca(I,D)|0)+z)>>1]|0;I=I+1|0;}while((I|0)<(u|0))}I=w+1|0;if((I|0)<(y|0)){w=I;J=J+F|0}else{break}}break};default:{}}}while(0);q=q+1|0;r=c[d+(q<<2)>>2]|0;}while((r|0)!=0);return 0}function tu(a){a=a|0;var b=0,d=0,e=0,f=0,h=0.0,j=0,k=0;b=i;d=c[a+44>>2]|0;e=c[d+4>>2]|0;f=c[d+8>>2]|0;h=+g[d+20>>2];c[d+28>>2]=e;c[d+32>>2]=f;c[d+36>>2]=~~(h*65536.0);j=(e|0)/2|0;c[d+40>>2]=j;e=(f|0)/2|0;c[d+44>>2]=e;f=e+j<<1;c[d+48>>2]=f;c[d+52>>2]=1<<f-1;f=c[d+12>>2]|0;j=c[d+16>>2]|0;h=+g[d+24>>2];c[d+304>>2]=f;c[d+308>>2]=j;c[d+312>>2]=~~(h*65536.0);e=(f|0)/2|0;c[d+316>>2]=e;f=(j|0)/2|0;c[d+320>>2]=f;j=f+e<<1;c[d+324>>2]=j;c[d+328>>2]=1<<j-1;c[d+592>>2]=306;if((c[d+588>>2]|0)==0){k=0;i=b;return k|0}KIb(a,16,2418832,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-22;i=b;return k|0}function uu(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=b+28|0;d=b+44|0;if((c[d>>2]<<1|0)>0){e=0;do{kJb(c[a+28+(e<<2)>>2]|0);e=e+1|0;}while((e|0)<(c[d>>2]<<1|0))}d=b+304|0;e=b+320|0;if((c[e>>2]<<1|0)>0){f=0}else{return}do{kJb(c[d+28+(f<<2)>>2]|0);f=f+1|0;}while((f|0)<(c[e>>2]<<1|0));return}function vu(a){a=a|0;dl(a,Ok(684544)|0);return 0}function wu(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;g=i;i=i+296|0;h=g|0;j=g+248|0;k=g+264|0;l=g+280|0;m=c[c[b+16>>2]>>2]|0;n=c[b+44>>2]|0;b=c[m+20>>2]|0;c[j>>2]=b;o=-(-b>>c[n+580>>2])|0;c[j+8>>2]=o;c[j+4>>2]=o;o=c[m+24>>2]|0;c[k>>2]=o;m=-(-o>>c[n+584>>2])|0;c[k+8>>2]=m;c[k+4>>2]=m;m=n+28|0;c[l>>2]=m;p=n+304|0;c[l+8>>2]=p;c[l+4>>2]=p;p=h;n=0;q=b;b=o;o=m;while(1){m=c[f+(n<<2)>>2]|0;r=c[f+32+(n<<2)>>2]|0;s=c[e+(n<<2)>>2]|0;t=c[e+32+(n<<2)>>2]|0;u=c[o+8>>2]|0;v=c[o+12>>2]|0;w=-v|0;x=c[o+16>>2]|0;y=c[o+20>>2]|0;z=c[o+24>>2]|0;do{if((u|0)==0){uIb(m,r,s,t,q,b)}else{A=x<<1;B=(A|0)>0;if(B){C=(v<<1)+q<<2;D=0;do{mrc(c[o+28+(D<<2)>>2]|0,0,C|0)|0;D=D+1|0;}while((D|0)<(A|0))}D=-x|0;C=x+b|0;if((C|0)<=(D|0)){break}E=v<<1;F=(v<<3)-4|0;G=v+q|0;H=(G|0)>(w|0);I=(E|0)>0;J=(ca(x,t)|0)+v|0;K=(ca(x,r)|0)+v|0;L=q-1|0;M=0;N=D;D=s;O=m;while(1){P=(N|0)<(b|0)?D:M;mrc(p|0,0,F|0)|0;a:do{if(H){Q=(N|0)<(x|0);R=P+L|0;if(I){S=w}else{T=w;while(1){do{if((T|0)<1){U=P}else{if((T|0)>=(q|0)){U=R;break}U=P+T|0}}while(0);V=d[U]|0;if(B){W=T+v|0;X=0;Y=V;while(1){Z=(c[o+28+(X<<2)>>2]|0)+(W<<2)|0;_=(c[Z>>2]|0)+Y|0;c[Z>>2]=Y;Z=(c[o+28+((X|1)<<2)>>2]|0)+(W<<2)|0;$=(c[Z>>2]|0)+_|0;c[Z>>2]=_;_=X+2|0;if((_|0)<(A|0)){X=_;Y=$}else{aa=$;break}}}else{aa=V}if(!((T|0)<(v|0)|Q)){Y=d[D+(T-J)|0]|0;X=((ca(Y-((aa+z|0)>>>(y>>>0))|0,u)|0)>>16)+Y|0;if(X>>>0>255>>>0){ba=-X>>31&255}else{ba=X&255}a[O+(T-K)|0]=ba}T=T+1|0;if((T|0)>=(G|0)){break a}}}do{do{if((S|0)<1){da=P}else{if((S|0)>=(q|0)){da=R;break}da=P+S|0}}while(0);V=0;T=d[da]|0;do{X=h+(V<<2)|0;Y=(c[X>>2]|0)+T|0;c[X>>2]=T;X=h+((V|1)<<2)|0;T=(c[X>>2]|0)+Y|0;c[X>>2]=Y;V=V+2|0;}while((V|0)<(E|0));if(B){V=S+v|0;Y=0;X=T;while(1){W=(c[o+28+(Y<<2)>>2]|0)+(V<<2)|0;$=(c[W>>2]|0)+X|0;c[W>>2]=X;W=(c[o+28+((Y|1)<<2)>>2]|0)+(V<<2)|0;_=(c[W>>2]|0)+$|0;c[W>>2]=$;$=Y+2|0;if(($|0)<(A|0)){Y=$;X=_}else{ea=_;break}}}else{ea=T}if(!((S|0)<(v|0)|Q)){X=d[D+(S-J)|0]|0;Y=((ca(X-((ea+z|0)>>>(y>>>0))|0,u)|0)>>16)+X|0;if(Y>>>0>255>>>0){fa=-Y>>31&255}else{fa=Y&255}a[O+(S-K)|0]=fa}S=S+1|0;}while((S|0)<(G|0))}}while(0);if((N|0)>-1){ga=O+r|0;ha=D+t|0}else{ga=O;ha=D}Q=N+1|0;if((Q|0)<(C|0)){M=P;N=Q;D=ha;O=ga}else{break}}}}while(0);t=n+1|0;if((t|0)>=3){break}n=t;q=c[j+(t<<2)>>2]|0;b=c[k+(t<<2)>>2]|0;o=c[l+(t<<2)>>2]|0}i=g;return 0}function xu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=a+8|0;a=c[f>>2]|0;g=c[a+44>>2]|0;h=c[c[a+32>>2]>>2]|0;a=bv(h,c[h+20>>2]|0,c[h+24>>2]|0)|0;if((a|0)==0){VHb(e);j=-12;i=d;return j|0}ZHb(a,b)|0;b=Ee[c[g+592>>2]&511](c[f>>2]|0,c[e>>2]|0,a)|0;VHb(e);if((b|0)<0){j=b;i=d;return j|0}j=lj(h,a)|0;i=d;return j|0}function yu(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=a+8|0;e=c[(c[b>>2]|0)+44>>2]|0;f=qKb(c[a+52>>2]|0)|0;g=e+580|0;c[g>>2]=d[f+5|0]|0;c[e+584>>2]=d[f+6|0]|0;f=a+20|0;a=zu(c[b>>2]|0,e+28|0,2416424,c[f>>2]|0)|0;if((a|0)<0){h=a;return h|0}a=zu(c[b>>2]|0,e+304|0,2407688,-(-(c[f>>2]|0)>>c[g>>2])|0)|0;h=(a|0)<0?a:0;return h|0}function zu(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=c[b+8>>2]|0;if((g|0)==0){j=2400240}else{j=(g|0)<0?2393272:2386536}k=c[b>>2]|0;l=c[b+4>>2]|0;m=a;if((k&1&l|0)==0){KIb(m,16,2379304,(n=i,i=i+24|0,c[n>>2]=d,c[n+8>>2]=k,c[n+16>>2]=l,n)|0);i=n;o=-22;i=f;return o|0}KIb(m,40,2373280,(n=i,i=i+40|0,c[n>>2]=j,c[n+8>>2]=d,c[n+16>>2]=k,c[n+24>>2]=l,h[n+32>>3]=+(g|0)/65535.0,n)|0);i=n;n=b+12|0;g=b+16|0;l=0;while(1){if((l|0)>=(c[g>>2]<<1|0)){o=0;p=8;break}k=hJb((c[n>>2]<<1)+e<<2)|0;c[b+28+(l<<2)>>2]=k;if((k|0)==0){o=-12;p=8;break}else{l=l+1|0}}if((p|0)==8){i=f;return o|0}return 0}function Au(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+8>>2]|0;a=c[e+44>>2]|0;f=bv(c[c[e+32>>2]>>2]|0,b,d)|0;if((f|0)==0){g=0;return g|0}b=a;a=-d|0;e=f|0;h=c[e>>2]|0;if((h|0)!=0){i=f+32|0;j=c[i>>2]|0;c[e>>2]=h+(ca(j,d-1|0)|0);c[i>>2]=-j}j=f+4|0;i=c[j>>2]|0;if((i|0)!=0){h=f+36|0;e=c[h>>2]|0;c[j>>2]=i+(ca(e,~(a>>c[b>>2]))|0);c[h>>2]=-e}e=f+8|0;h=c[e>>2]|0;if((h|0)!=0){i=f+40|0;j=c[i>>2]|0;c[e>>2]=h+(ca(j,~(a>>c[b>>2]))|0);c[i>>2]=-j}j=f+12|0;i=c[j>>2]|0;if((i|0)==0){g=f;return g|0}b=f+44|0;a=c[b>>2]|0;c[j>>2]=i+(ca(a,d-1|0)|0);c[b>>2]=-a;g=f;return g|0}function Bu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a+8|0;e=c[(c[d>>2]|0)+44>>2]|0;f=a+24|0;a=b|0;g=c[a>>2]|0;if((g|0)!=0){h=b+32|0;i=c[h>>2]|0;c[a>>2]=g+(ca(i,(c[f>>2]|0)-1|0)|0);c[h>>2]=-i}i=b+4|0;h=c[i>>2]|0;if((h|0)!=0){g=b+36|0;a=c[g>>2]|0;c[i>>2]=h+(ca(a,~(-(c[f>>2]|0)>>c[e>>2]))|0);c[g>>2]=-a}a=b+8|0;g=c[a>>2]|0;if((g|0)!=0){h=b+40|0;i=c[h>>2]|0;c[a>>2]=g+(ca(i,~(-(c[f>>2]|0)>>c[e>>2]))|0);c[h>>2]=-i}i=b+12|0;h=c[i>>2]|0;if((h|0)==0){j=c[d>>2]|0;k=j+32|0;l=c[k>>2]|0;m=c[l>>2]|0;n=lj(m,b)|0;return n|0}e=b+44|0;g=c[e>>2]|0;c[i>>2]=h+(ca(g,(c[f>>2]|0)-1|0)|0);c[e>>2]=-g;j=c[d>>2]|0;k=j+32|0;l=c[k>>2]|0;m=c[l>>2]|0;n=lj(m,b)|0;return n|0}function Cu(a){a=a|0;var b=0;b=c[(c[a+8>>2]|0)+44>>2]|0;c[b>>2]=d[(qKb(c[a+52>>2]|0)|0)+6|0]|0;return 0}function Du(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+44>>2]|0;e=a;a=UGb(d+16|0,c[d+20>>2]|0,281224,0,0,0,0,0,e)|0;if((a|0)<0){KIb(e,16,2417744,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=a;i=b;return g|0}a=UGb(d+32|0,c[d+36>>2]|0,281224,0,0,0,0,0,e)|0;if((a|0)<0){KIb(e,16,2337968,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=a;i=b;return g|0}a=UGb(d+48|0,c[d+52>>2]|0,281224,0,0,0,0,0,e)|0;if((a|0)>=0){g=0;i=b;return g|0}KIb(e,16,2280176,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=a;i=b;return g|0}function Eu(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+120|0);TGb(c[b+16>>2]|0);TGb(c[b+32>>2]|0);TGb(c[b+48>>2]|0);return}function Fu(a){a=a|0;dl(a,Ok(684504)|0);return 0}function Gu(b,e){b=b|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0.0,O=0,P=0,Q=0,R=0.0,S=0.0,T=0.0,U=0,V=0.0,W=0,X=0.0,Y=0,Z=0;f=i;i=i+8|0;h=f|0;c[h>>2]=e;j=c[b+8>>2]|0;k=c[j+44>>2]|0;l=c[c[j+32>>2]>>2]|0;j=bv(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((j|0)==0){VHb(h);m=-12;i=f;return m|0}ZHb(j,e)|0;if((c[k+12>>2]|0)==1){Iu(k,b,c[h>>2]|0)}e=k+4|0;a:do{if((a[(c[e>>2]|0)+7|0]&32)==0){n=k+120|0;o=k+124|0;p=b+20|0;q=b+24|0;r=k+148|0;s=k+144|0;t=0;do{u=c[h>>2]|0;v=c[u+(t<<2)>>2]|0;if((v|0)==0){break a}w=c[u+32+(t<<2)>>2]|0;if((w|0)==0){break a}u=c[j+32+(t<<2)>>2]|0;x=(t-1|0)>>>0<2>>>0;if(x){y=c[e>>2]|0;z=d[y+6|0]|0;A=d[y+5|0]|0}else{z=0;A=0}y=-(c[p>>2]|0)>>A;B=-y|0;C=-(c[q>>2]|0)>>z;D=-C|0;if((C|0)!=0){C=(y|0)==0;y=c[o>>2]<<z;E=c[j+(t<<2)>>2]|0;F=v;v=c[n>>2]|0;G=0;while(1){if(!C){if(x){H=0;I=E;J=F;while(1){if((c[r>>2]|0)==0){K=0.0}else{L=c[s>>2]|0;c[s>>2]=(ca(L,1664525)|0)+1013904223;K=+(L>>>0>>>0)*2.3283064365386963e-10}L=~~(K+(+g[v+(H<<A<<2)>>2]*+((d[J]|0)-127|0)+127.0));if(L>>>0>255>>>0){M=-L>>31&255}else{M=L&255}a[I]=M;L=H+1|0;if(L>>>0<B>>>0){H=L;I=I+1|0;J=J+1|0}else{break}}}else{J=0;I=E;H=F;while(1){if((c[r>>2]|0)==0){N=0.0}else{L=c[s>>2]|0;c[s>>2]=(ca(L,1664525)|0)+1013904223;N=+(L>>>0>>>0)*2.3283064365386963e-10}L=~~(N+ +g[v+(J<<2)>>2]*+(d[H]|0|0));if(L>>>0>255>>>0){O=-L>>31&255}else{O=L&255}a[I]=O;L=J+1|0;if(L>>>0<B>>>0){J=L;I=I+1|0;H=H+1|0}else{break}}}}H=G+1|0;if(H>>>0<D>>>0){E=E+u|0;F=F+w|0;v=v+(y<<2)|0;G=H}else{break}}}t=t+1|0;}while((t|0)<4)}else{t=c[h>>2]|0;s=c[j+32>>2]|0;r=c[t+32>>2]|0;n=c[k+124>>2]|0;o=b+24|0;q=c[o>>2]|0;if((q|0)==0){break}p=b+20|0;G=k+148|0;y=k+144|0;v=c[k+120>>2]|0;w=c[t>>2]|0;t=c[j>>2]|0;F=0;u=c[p>>2]|0;E=q;while(1){if((u|0)==0){P=0;Q=E}else{q=w;D=t;B=0;while(1){R=+g[v+(B<<2)>>2];S=R*+(d[q]|0|0);if((c[G>>2]|0)==0){T=0.0}else{x=c[y>>2]|0;c[y>>2]=(ca(x,1664525)|0)+1013904223;T=+(x>>>0>>>0)*2.3283064365386963e-10}x=~~(S+T);if(x>>>0>255>>>0){U=-x>>31&255}else{U=x&255}a[D]=U;S=R*+(d[q+1|0]|0|0);if((c[G>>2]|0)==0){V=0.0}else{x=c[y>>2]|0;c[y>>2]=(ca(x,1664525)|0)+1013904223;V=+(x>>>0>>>0)*2.3283064365386963e-10}x=~~(S+V);if(x>>>0>255>>>0){W=-x>>31&255}else{W=x&255}a[D+1|0]=W;S=R*+(d[q+2|0]|0|0);if((c[G>>2]|0)==0){X=0.0}else{x=c[y>>2]|0;c[y>>2]=(ca(x,1664525)|0)+1013904223;X=+(x>>>0>>>0)*2.3283064365386963e-10}x=~~(S+X);if(x>>>0>255>>>0){Y=-x>>31&255}else{Y=x&255}a[D+2|0]=Y;x=B+1|0;Z=c[p>>2]|0;if(x>>>0<Z>>>0){q=q+3|0;D=D+3|0;B=x}else{break}}P=Z;Q=c[o>>2]|0}B=F+1|0;if(B>>>0<Q>>>0){v=v+(n<<2)|0;w=w+r|0;t=t+s|0;F=B;u=P;E=Q}else{break}}}}while(0);m=lj(l,j)|0;i=f;return m|0}function Hu(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0.0,u=0,v=0,w=0.0,x=0;b=i;i=i+8|0;d=b|0;e=d;f=i;i=i+8|0;j=i;i=i+8|0;k=c[(c[a+8>>2]|0)+44>>2]|0;l=k;m=a+28|0;n=c[m>>2]|0;o=c[m+4>>2]|0;c[d>>2]=n;c[d+4>>2]=o;c[k+4>>2]=qKb(c[a+52>>2]|0)|0;m=a+20|0;h[k+64>>3]=+(c[m>>2]|0);p=a+24|0;h[k+72>>3]=+(c[p>>2]|0);h[k+112>>3]=+(c[a+56>>2]|0)/+(c[a+60>>2]|0);q=c[a+116>>2]|0;s=n;n=o;do{if((q|0)==0){t=+r}else{o=c[a+120>>2]|0;if((o|0)==0){t=+r;break}t=+(q|0)/+(o|0)}}while(0);h[k+96>>3]=t;do{if((s|0)==0|(n|0)==0){c[e+4>>2]=1;c[d>>2]=1;u=k+152|0;v=8}else{q=k+152|0;if((s|0)<=(n|0)){u=q;v=8;break}zKb(f,e,q);g[k+136>>2]=+(c[f>>2]|0)/+(c[f+4>>2]|0);g[k+140>>2]=1.0}}while(0);if((v|0)==8){zKb(j,u,e);g[k+140>>2]=+(c[j>>2]|0)/+(c[j+4>>2]|0);g[k+136>>2]=1.0}t=+Xb(+(+(c[m>>2]|0)*.5),+(+(c[p>>2]|0)*.5));h[k+128>>3]=t;w=+g[k+140>>2];KIb(k,48,2320024,(j=i,i=i+24|0,h[j>>3]=+g[k+136>>2],h[j+8>>3]=w,h[j+16>>3]=t,j)|0);i=j;j=(c[m>>2]|0)+31&-32;c[k+124>>2]=j;m=hJb(ca(c[p>>2]<<2,j)|0)|0;c[k+120>>2]=m;if((m|0)==0){x=-12;i=b;return x|0}if((c[k+12>>2]|0)!=0){x=0;i=b;return x|0}Iu(l,a,0);x=0;i=b;return x|0}function Iu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0;e=c[a+120>>2]|0;f=c[a+124>>2]|0;if((d|0)==0){h[a+80>>3]=0.0;h[a+104>>3]=+r;h[a+88>>3]=+r}else{i=b+160|0;h[a+80>>3]=+((c[i>>2]|0)>>>0)+ +(c[i+4>>2]|0)*4294967296.0;i=d+136|0;d=c[i>>2]|0;j=c[i+4>>2]|0;if((d|0)==0&(j|0)==(-2147483648|0)){h[a+104>>3]=+r;k=+r}else{h[a+104>>3]=(+(d>>>0)+ +(j|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0));k=+(d>>>0)+ +(j|0)*4294967296.0}h[a+88>>3]=k}j=a+64|0;k=+XGb(c[a+16>>2]|0,j,0);if(k<0.0){l=0.0}else{l=k>1.5707963705062866?1.5707963705062866:k}d=a+24|0;h[d>>3]=l;i=a+40|0;h[i>>3]=+XGb(c[a+32>>2]|0,j,0);m=a+56|0;h[m>>3]=+XGb(c[a+48>>2]|0,j,0);j=b+24|0;n=c[j>>2]|0;o=(n|0)>0;if((c[a+8>>2]|0)==0){if(!o){return}p=b+20|0;q=a+136|0;s=a+140|0;t=a+128|0;u=0;v=e;w=c[p>>2]|0;x=n;while(1){if((w|0)>0){l=+(u|0);y=0;do{k=+Xb(+(+(~~((+(y|0)- +h[i>>3])*+g[q>>2])|0)),+(+(~~((l- +h[m>>3])*+g[s>>2])|0)));z=k/+h[t>>3];if(z>1.0){A=0.0}else{k=+U(z*+h[d>>3]);z=k*k;A=z*z}g[v+(y<<2)>>2]=A;y=y+1|0;B=c[p>>2]|0;}while((y|0)<(B|0));C=B;D=c[j>>2]|0}else{C=w;D=x}y=u+1|0;if((y|0)<(D|0)){u=y;v=v+(f<<2)|0;w=C;x=D}else{break}}return}else{if(!o){return}o=b+20|0;b=a+136|0;D=a+140|0;x=a+128|0;a=0;C=e;e=c[o>>2]|0;w=n;while(1){if((e|0)>0){A=+(a|0);n=0;do{l=+Xb(+(+(~~((+(n|0)- +h[i>>3])*+g[b>>2])|0)),+(+(~~((A- +h[m>>3])*+g[D>>2])|0)));z=l/+h[x>>3];if(z>1.0){E=0.0}else{l=+U(z*+h[d>>3]);z=l*l;E=z*z}g[C+(n<<2)>>2]=1.0/E;n=n+1|0;F=c[o>>2]|0;}while((n|0)<(F|0));G=F;H=c[j>>2]|0}else{G=e;H=w}n=a+1|0;if((n|0)<(H|0)){a=n;C=C+(f<<2)|0;e=G;w=H}else{break}}return}}function Ju(a){a=a|0;var b=0;b=c[a+44>>2]|0;VHb(b+56|0);VHb(b+60|0);VHb(b+64|0);mJb(b+68|0);return}function Ku(a){a=a|0;dl(a,Ok(684432)|0);return 0}function Lu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a>>2]|0;a=c[b+44>>2]|0;d=a+60|0;e=a+64|0;f=a+48|0;a=b+16|0;while(1){if((c[f>>2]|0)!=0){g=-541478725;h=9;break}b=Wi(c[c[a>>2]>>2]|0)|0;if((b|0)==-541478725){if((c[d>>2]|0)==0){g=-541478725;h=9;break}i=$Hb(c[e>>2]|0)|0;if((i|0)==0){g=-12;h=9;break}j=(c[e>>2]|0)+136|0;k=c[j>>2]|0;l=(c[d>>2]|0)+136|0;m=xrc(k<<1|0>>>31,c[j+4>>2]<<1|k>>>31,c[l>>2]|0,c[l+4>>2]|0)|0;l=i+136|0;c[l>>2]=m;c[l+4>>2]=G;Nu(c[c[a>>2]>>2]|0,i)|0;c[f>>2]=1}else{if((b|0)<0){g=b;h=9;break}}if((c[d>>2]|0)!=0){g=0;h=9;break}}if((h|0)==9){return g|0}return 0}function Mu(a){a=a|0;var b=0;b=c[c[(c[a>>2]|0)+16>>2]>>2]|0;c[a+56>>2]=c[b+56>>2];c[a+60>>2]=c[b+60>>2]<<1;c[a+116>>2]=c[b+116>>2]<<1;c[a+120>>2]=c[b+120>>2];b=a+156|0;c[b>>2]=c[b>>2]|1;return 0}function Nu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+8>>2]|0;a=c[d+44>>2]|0;e=a+56|0;VHb(e);f=a+60|0;c[e>>2]=c[f>>2];g=a+64|0;h=c[g>>2]|0;c[f>>2]=h;c[g>>2]=b;do{if((h|0)==0){g=$Hb(b)|0;c[f>>2]=g;if((g|0)==0){i=-12}else{j=g;break}return i|0}else{j=h}}while(0);if((c[a+8>>2]|0)==0){k=5}else{if((c[j+296>>2]|0)!=0){k=5}}do{if((k|0)==5){if((c[d+76>>2]|0)!=0){break}if((c[e>>2]|0)==0){i=0;return i|0}a=Ou(d,0)|0;if((a|0)<0){i=a;return i|0}i=Ou(d,1)|0;return i|0}}while(0);k=$Hb(j)|0;if((k|0)==0){i=-12;return i|0}VHb(e);e=k+136|0;j=c[e>>2]|0;a=c[e+4>>2]|0;if(!((j|0)==0&(a|0)==(-2147483648|0))){c[e>>2]=j<<1|0>>>31;c[e+4>>2]=a<<1|j>>>31}i=lj(c[c[d+32>>2]>>2]|0,k)|0;return i|0}function Ou(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;f=i;i=i+48|0;g=f|0;h=f+24|0;j=b+44|0;k=c[j>>2]|0;l=c[c[b+32>>2]>>2]|0;b=bv(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;if((b|0)==0){m=-12;i=f;return m|0}n=k+60|0;ZHb(b,c[n>>2]|0)|0;c[b+296>>2]=0;do{if((e|0)==0){o=b+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;if((p|0)==0&(q|0)==(-2147483648|0)){break}c[o>>2]=p<<1|0>>>31;c[o+4>>2]=q<<1|p>>>31}else{p=(c[n>>2]|0)+136|0;q=c[p>>2]|0;o=c[p+4>>2]|0;p=(c[k+64>>2]|0)+136|0;r=c[p>>2]|0;s=c[p+4>>2]|0;if((r|0)==0&(s|0)==(-2147483648|0)|(q|0)==0&(o|0)==(-2147483648|0)){p=b+136|0;c[p>>2]=0;c[p+4>>2]=-2147483648;break}else{p=wrc(r,s,q,o)|0;o=b+136|0;c[o>>2]=p;c[o+4>>2]=G;break}}}while(0);e=k+44|0;o=c[e>>2]|0;p=c[((o|0)==0?k+56|0:k+64|0)>>2]|0;q=k+52|0;if((c[q>>2]|0)>0){s=k+4|0;k=g|0;r=g+4|0;t=g+8|0;u=g+12|0;v=h|0;w=h+4|0;x=h+8|0;y=h+12|0;z=g+16|0;A=h+16|0;B=0;do{C=c[n>>2]|0;D=c[s>>2]|0;E=c[j>>2]|0;F=c[C+(B<<2)>>2]|0;H=c[p+(B<<2)>>2]|0;I=c[b+(B<<2)>>2]|0;J=c[E+12+(B<<2)>>2]|0;K=c[E+28+(B<<2)>>2]|0;L=c[C+32+(B<<2)>>2]|0;M=c[p+32+(B<<2)>>2]|0;N=c[b+32+(B<<2)>>2]|0;O=E+44|0;P=c[O>>2]|0;Q=C+300|0;C=c[Q>>2]|0;R=(P|0)==(C|0)|0;S=-R|0;if((R|0)<(K|0)){T=L<<1;U=N<<1;V=I+(N&S)|0;W=F+(L&S)|0;S=R;while(1){nrc(V|0,W|0,J)|0;R=S+2|0;if((R|0)<(K|0)){V=V+U|0;W=W+T|0;S=R}else{break}}X=c[O>>2]|0;Y=c[Q>>2]|0}else{X=P;Y=C}S=(X|0)!=(Y|0);T=S&1;a:do{if((T|0)<(K|0)){W=-T|0;U=E+68|0;V=J<<2;R=a[785880+D|0]|0;Z=D>>>0<2>>>0;_=(J|0)>0;$=1648872+(D<<4)|0;aa=1648876+(D<<4)|0;ba=1648880+(D<<4)|0;da=1648884+(D<<4)|0;ea=a[785888+D|0]|0;fa=N<<1;ga=1648904+(D*20|0)|0;ha=1648908+(D*20|0)|0;ia=1648912+(D*20|0)|0;ja=1648916+(D*20|0)|0;ka=1648920+(D*20|0)|0;la=I+(N&W)|0;ma=T;na=S?2:1;oa=W;while(1){mrc(c[U>>2]|0,0,V|0)|0;if(Z){W=0;pa=na;qa=oa;while(1){ra=pa-R|0;sa=ra+(((ra|0)>0?pa:R)+qa&-2)|0;while(1){if((sa|0)<(K|0)){break}else{sa=sa-2|0}}c[g+(W<<2)>>2]=F+(ca(sa,L)|0);ra=W+1|0;if((ra|0)<(R|0)){W=ra;pa=pa+2|0;qa=qa-2|0}else{break}}}qa=c[U>>2]|0;do{if((R|0)==4){if(!_){break}pa=c[$>>2]|0;W=c[aa>>2]|0;ra=c[ba>>2]|0;ta=c[da>>2]|0;ua=c[k>>2]|0;va=c[r>>2]|0;wa=c[t>>2]|0;xa=c[u>>2]|0;ya=xa+J|0;za=qa;Aa=0;Ba=ua;Ca=va;Da=wa;Ea=xa;while(1){xa=ca(d[Ba]|0,pa)|0;Fa=xa+(c[za>>2]|0)|0;c[za>>2]=Fa;xa=(ca(d[Ca]|0,W)|0)+Fa|0;c[za>>2]=xa;Fa=xa+(ca(d[Da]|0,ra)|0)|0;c[za>>2]=Fa;c[za>>2]=Fa+(ca(d[Ea]|0,ta)|0);Fa=Aa+1|0;if((Fa|0)<(J|0)){za=za+4|0;Aa=Fa;Ba=Ba+1|0;Ca=Ca+1|0;Da=Da+1|0;Ea=Ea+1|0}else{break}}c[k>>2]=ua+J;c[r>>2]=va+J;c[t>>2]=wa+J;c[u>>2]=ya}else if((R|0)==2){if(!_){break}Ea=c[$>>2]|0;Da=c[aa>>2]|0;Ca=c[k>>2]|0;Ba=c[r>>2]|0;Aa=qa;za=0;ta=Ca;ra=Ba;while(1){W=ca(d[ta]|0,Ea)|0;pa=W+(c[Aa>>2]|0)|0;c[Aa>>2]=pa;c[Aa>>2]=(ca(d[ra]|0,Da)|0)+pa;pa=za+1|0;if((pa|0)<(J|0)){Aa=Aa+4|0;za=pa;ta=ta+1|0;ra=ra+1|0}else{break}}c[k>>2]=Ca+J;c[r>>2]=Ba+J}}while(0);if(Z){ra=0;ta=na;za=oa;while(1){Aa=ta-ea|0;Da=Aa+(((Aa|0)>0?ta:ea)+za&-2)|0;while(1){if((Da|0)<(K|0)){break}else{Da=Da-2|0}}c[g+(ra<<2)>>2]=F+(ca(Da,L)|0);c[h+(ra<<2)>>2]=H+(ca(Da,M)|0);Ba=ra+1|0;if((Ba|0)<(ea|0)){ra=Ba;ta=ta+2|0;za=za-2|0}else{break}}}do{if((ea|0)==3){if(!_){break}za=c[ga>>2]|0;ta=c[ha>>2]|0;ra=c[ia>>2]|0;Ba=c[k>>2]|0;Ca=c[v>>2]|0;Aa=c[r>>2]|0;Ea=c[w>>2]|0;ya=c[t>>2]|0;wa=c[x>>2]|0;va=Ea+J|0;ua=qa;pa=0;W=Ba;sa=Ca;Fa=Aa;xa=Ea;Ea=ya;Ga=wa;while(1){Ha=ca(d[W]|0,za)|0;Ia=Ha+(c[ua>>2]|0)|0;c[ua>>2]=Ia;Ha=(ca(d[sa]|0,za)|0)+Ia|0;c[ua>>2]=Ha;Ia=Ha+(ca(d[Fa]|0,ta)|0)|0;c[ua>>2]=Ia;Ha=Ia+(ca(d[xa]|0,ta)|0)|0;c[ua>>2]=Ha;Ia=Ha+(ca(d[Ea]|0,ra)|0)|0;c[ua>>2]=Ia;c[ua>>2]=Ia+(ca(d[Ga]|0,ra)|0);Ia=pa+1|0;if((Ia|0)<(J|0)){ua=ua+4|0;pa=Ia;W=W+1|0;sa=sa+1|0;Fa=Fa+1|0;xa=xa+1|0;Ea=Ea+1|0;Ga=Ga+1|0}else{break}}c[k>>2]=Ba+J;c[v>>2]=Ca+J;c[r>>2]=Aa+J;c[w>>2]=va;c[t>>2]=ya+J;c[x>>2]=wa+J;Ja=42}else if((ea|0)==5){if(!_){break}Ga=c[ga>>2]|0;Ea=c[ha>>2]|0;xa=c[ia>>2]|0;Fa=c[ja>>2]|0;sa=c[ka>>2]|0;W=c[k>>2]|0;pa=c[v>>2]|0;ua=c[r>>2]|0;ra=c[w>>2]|0;ta=c[t>>2]|0;za=c[x>>2]|0;Da=c[u>>2]|0;Ia=c[y>>2]|0;Ha=c[z>>2]|0;Ka=c[A>>2]|0;La=Ia+J|0;Ma=ra+J|0;Na=qa;Oa=0;Pa=W;Qa=pa;Ra=ua;Sa=ra;ra=ta;Ta=za;Ua=Da;Va=Ia;Ia=Ha;Wa=Ka;while(1){Xa=ca(d[Pa]|0,Ga)|0;Ya=Xa+(c[Na>>2]|0)|0;c[Na>>2]=Ya;Xa=(ca(d[Qa]|0,Ga)|0)+Ya|0;c[Na>>2]=Xa;Ya=Xa+(ca(d[Ra]|0,Ea)|0)|0;c[Na>>2]=Ya;Xa=Ya+(ca(d[Sa]|0,Ea)|0)|0;c[Na>>2]=Xa;Ya=Xa+(ca(d[ra]|0,xa)|0)|0;c[Na>>2]=Ya;Xa=Ya+(ca(d[Ta]|0,xa)|0)|0;c[Na>>2]=Xa;Ya=Xa+(ca(d[Ua]|0,Fa)|0)|0;c[Na>>2]=Ya;Xa=Ya+(ca(d[Va]|0,Fa)|0)|0;c[Na>>2]=Xa;Ya=Xa+(ca(d[Ia]|0,sa)|0)|0;c[Na>>2]=Ya;c[Na>>2]=Ya+(ca(d[Wa]|0,sa)|0);Ya=Oa+1|0;if((Ya|0)<(J|0)){Na=Na+4|0;Oa=Ya;Pa=Pa+1|0;Qa=Qa+1|0;Ra=Ra+1|0;Sa=Sa+1|0;ra=ra+1|0;Ta=Ta+1|0;Ua=Ua+1|0;Va=Va+1|0;Ia=Ia+1|0;Wa=Wa+1|0}else{break}}c[k>>2]=W+J;c[v>>2]=pa+J;c[r>>2]=ua+J;c[w>>2]=Ma;c[t>>2]=ta+J;c[x>>2]=za+J;c[u>>2]=Da+J;c[y>>2]=La;c[z>>2]=Ha+J;c[A>>2]=Ka+J;Ja=42}else{Ja=42}}while(0);do{if((Ja|0)==42){Ja=0;if(_){Za=qa;_a=la;$a=0}else{break}while(1){Wa=c[Za>>2]|0;if((Wa|0)<0){ab=0}else{ab=(Wa|0)>16711680?-1:Wa>>>16&255}a[_a]=ab;Wa=$a+1|0;if((Wa|0)<(J|0)){Za=Za+4|0;_a=_a+1|0;$a=Wa}else{break}}}}while(0);qa=ma+2|0;if((qa|0)>=(K|0)){break a}la=la+fa|0;ma=qa;na=na+2|0;oa=oa-2|0}}}while(0);B=B+1|0;}while((B|0)<(c[q>>2]|0));bb=c[e>>2]|0}else{bb=o}c[e>>2]=(bb|0)==0;m=lj(l,b)|0;i=f;return m|0}function Pu(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[(c[a+8>>2]|0)+44>>2]|0;e=a+52|0;f=qKb(c[e>>2]|0)|0;g=b+12|0;h=pIb(g,c[e>>2]|0,c[a+20>>2]|0)|0;if((h|0)<0){i=h;return i|0}h=a+24|0;a=-(-(c[h>>2]|0)>>(d[f+6|0]|0))|0;c[b+36>>2]=a;c[b+32>>2]=a;a=c[h>>2]|0;c[b+40>>2]=a;c[b+28>>2]=a;c[b+52>>2]=uKb(c[e>>2]|0)|0;e=qJb(c[g>>2]|0,4)|0;c[b+68>>2]=e;i=(e|0)==0?-12:0;return i|0}function Qu(a){a=a|0;var b=0;b=c[a+44>>2]|0;VHb(b+28|0);VHb(b+20|0);VHb(b+24|0);return}function Ru(a){a=a|0;dl(a,Ok(684296)|0);return 0}function Su(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a|0;a=c[b>>2]|0;d=c[a+44>>2]|0;if((c[d+16>>2]|0)!=0){Yu(a,1)|0;e=0;return e|0}a=d+20|0;f=d+24|0;g=d+48|0;while(1){if((c[g>>2]|0)!=0){e=-541478725;h=11;break}d=Wi(c[c[(c[b>>2]|0)+16>>2]>>2]|0)|0;if((d|0)==-541478725){if((c[a>>2]|0)==0){e=-541478725;h=11;break}i=$Hb(c[f>>2]|0)|0;if((i|0)==0){e=-12;h=11;break}j=(c[f>>2]|0)+136|0;k=c[j>>2]|0;l=(c[a>>2]|0)+136|0;m=xrc(k<<1|0>>>31,c[j+4>>2]<<1|k>>>31,c[l>>2]|0,c[l+4>>2]|0)|0;l=i+136|0;c[l>>2]=m;c[l+4>>2]=G;Zu(c[c[(c[b>>2]|0)+16>>2]>>2]|0,i)|0;c[g>>2]=1}else{if((d|0)<0){e=d;h=11;break}}if((c[a>>2]|0)!=0){e=0;h=11;break}}if((h|0)==11){return e|0}return 0}function Tu(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[a>>2]|0;h=c[g+44>>2]|0;j=c[c[g+16>>2]>>2]|0;c[a+56>>2]=c[j+56>>2];c[a+60>>2]=c[j+60>>2]<<1;k=c[j+20>>2]|0;l=a+20|0;c[l>>2]=k;m=a+24|0;c[m>>2]=c[j+24>>2];if((c[h+4>>2]&1|0)==0){n=k}else{c[e>>2]=2;c[e+4>>2]=1;yKb(f,j+116|0,e);e=a+116|0;j=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=j;n=c[l>>2]|0}do{if((n|0)>=3){if((c[m>>2]|0)<3){break}l=qKb(c[a+52>>2]|0)|0;c[h+44>>2]=l;j=h+36|0;if((b[l+8>>1]&16384)==0){c[j>>2]=6;c[h+40>>2]=78;o=0;i=d;return o|0}else{c[j>>2]=50;c[h+40>>2]=24;o=0;i=d;return o|0}}}while(0);KIb(g,16,2393120,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;o=-22;i=d;return o|0}function Uu(a,c,d,f,g,h,i,j,k){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;l=a;a=c;c=d;d=f;f=(j|0)!=0;j=f?a:c;m=f?c:d;f=(i|0)/2|0;i=(h|0)/2|0;if((g|0)<=0){return}h=f-1|0;n=i-1|0;o=f+1|0;p=i+1|0;q=f-2|0;r=i+2|0;s=f-3|0;t=i+3|0;u=i-2|0;v=f+2|0;w=i-3|0;x=f+3|0;y=f<<1;z=i<<1;if((k&2|0)==0){k=m;A=j;B=0;C=d;D=c;E=a;F=l;while(1){G=b[D+(f<<1)>>1]|0;H=G&65535;I=e[A>>1]|0;J=e[k>>1]|0;K=(J+I|0)>>>1;L=b[D+(i<<1)>>1]|0;M=L&65535;N=I-J|0;J=(e[E+(f<<1)>>1]|0)-H|0;I=(e[E+(i<<1)>>1]|0)-M|0;O=((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)>>1;J=(e[C+(f<<1)>>1]|0)-H|0;I=(e[C+(i<<1)>>1]|0)-M|0;P=((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)>>1;J=((N|0)>-1?N:-N|0)>>1;N=(J|0)>(O|0)?J:O;O=(N|0)>(P|0)?N:P;P=e[D+(h<<1)>>1]|0;N=e[D+(n<<1)>>1]|0;J=P-N|0;I=H-M|0;Q=e[D+(o<<1)>>1]|0;R=e[D+(p<<1)>>1]|0;S=Q-R|0;T=((I|0)>-1?I:-I|0)-1+((J|0)>-1?J:-J|0)+((S|0)>-1?S:-S|0)|0;S=e[D+(q<<1)>>1]|0;J=S-M|0;I=P-R|0;U=e[D+(r<<1)>>1]|0;V=H-U|0;W=((J|0)>-1?J:-J|0)+((I|0)>-1?I:-I|0)+((V|0)>-1?V:-V|0)|0;if((W|0)<(T|0)){V=(e[D+(s<<1)>>1]|0)-R|0;I=S-U|0;J=P-(e[D+(t<<1)>>1]|0)|0;X=((V|0)>-1?V:-V|0)+((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)|0;J=(X|0)<(W|0);Y=J?X:W;Z=J?U+S|0:R+P|0}else{Y=T;Z=M+H|0}T=e[D+(u<<1)>>1]|0;P=H-T|0;R=Q-N|0;S=e[D+(v<<1)>>1]|0;U=S-M|0;J=((R|0)>-1?R:-R|0)+((P|0)>-1?P:-P|0)+((U|0)>-1?U:-U|0)|0;if((J|0)<(Y|0)){U=Q-(e[D+(w<<1)>>1]|0)|0;P=S-T|0;R=(e[D+(x<<1)>>1]|0)-N|0;_=(((U|0)>-1?U:-U|0)+((P|0)>-1?P:-P|0)+((R|0)>-1?R:-R|0)|0)<(J|0)?S+T|0:N+Q|0}else{_=Z}Q=_>>>1;N=(G&65535)>>>0>(L&65535)>>>0;L=K-(N?M:H)|0;G=(((e[k+(y<<1)>>1]|0)+(e[A+(y<<1)>>1]|0)|0)>>>1)-H|0;T=(((e[k+(z<<1)>>1]|0)+(e[A+(z<<1)>>1]|0)|0)>>>1)-M|0;S=(G|0)>(T|0);J=S?T:G;R=K-(N?H:M)|0;M=S?G:T;T=(R|0)>(M|0)?M:R;R=(O|0)>(T|0)?O:T;T=-((L|0)>(J|0)?L:J)|0;J=(R|0)>(T|0)?R:T;T=J+K|0;if((Q|0)>(T|0)){$=T&65535}else{T=K-J|0;$=((Q|0)<(T|0)?T:Q)&65535}b[F>>1]=$;Q=B+1|0;if((Q|0)<(g|0)){k=k+2|0;A=A+2|0;B=Q;C=C+2|0;D=D+2|0;E=E+2|0;F=F+2|0}else{break}}return}else{F=m;m=j;j=0;E=d;d=c;c=a;a=l;while(1){l=e[d+(f<<1)>>1]|0;D=e[m>>1]|0;C=e[F>>1]|0;B=(C+D|0)>>>1;A=e[d+(i<<1)>>1]|0;k=D-C|0;C=(e[c+(f<<1)>>1]|0)-l|0;D=(e[c+(i<<1)>>1]|0)-A|0;$=((D|0)>-1?D:-D|0)+((C|0)>-1?C:-C|0)>>1;C=(e[E+(f<<1)>>1]|0)-l|0;D=(e[E+(i<<1)>>1]|0)-A|0;z=((D|0)>-1?D:-D|0)+((C|0)>-1?C:-C|0)>>1;C=((k|0)>-1?k:-k|0)>>1;k=(C|0)>($|0)?C:$;$=(k|0)>(z|0)?k:z;z=e[d+(h<<1)>>1]|0;k=e[d+(n<<1)>>1]|0;C=z-k|0;D=l-A|0;y=e[d+(o<<1)>>1]|0;_=e[d+(p<<1)>>1]|0;Z=y-_|0;Y=((D|0)>-1?D:-D|0)-1+((C|0)>-1?C:-C|0)+((Z|0)>-1?Z:-Z|0)|0;Z=e[d+(q<<1)>>1]|0;C=Z-A|0;D=z-_|0;Q=e[d+(r<<1)>>1]|0;T=l-Q|0;J=((C|0)>-1?C:-C|0)+((D|0)>-1?D:-D|0)+((T|0)>-1?T:-T|0)|0;if((J|0)<(Y|0)){T=(e[d+(s<<1)>>1]|0)-_|0;D=Z-Q|0;C=z-(e[d+(t<<1)>>1]|0)|0;K=((T|0)>-1?T:-T|0)+((D|0)>-1?D:-D|0)+((C|0)>-1?C:-C|0)|0;C=(K|0)<(J|0);aa=C?K:J;ba=C?Q+Z|0:_+z|0}else{aa=Y;ba=A+l|0}Y=e[d+(u<<1)>>1]|0;z=l-Y|0;l=y-k|0;_=e[d+(v<<1)>>1]|0;Z=_-A|0;A=((l|0)>-1?l:-l|0)+((z|0)>-1?z:-z|0)+((Z|0)>-1?Z:-Z|0)|0;if((A|0)<(aa|0)){Z=y-(e[d+(w<<1)>>1]|0)|0;z=_-Y|0;l=(e[d+(x<<1)>>1]|0)-k|0;ca=(((Z|0)>-1?Z:-Z|0)+((z|0)>-1?z:-z|0)+((l|0)>-1?l:-l|0)|0)<(A|0)?_+Y|0:k+y|0}else{ca=ba}y=ca>>>1;k=$+B|0;if((y|0)>(k|0)){da=k&65535}else{k=B-$|0;da=((y|0)<(k|0)?k:y)&65535}b[a>>1]=da;y=j+1|0;if((y|0)<(g|0)){F=F+2|0;m=m+2|0;j=y;E=E+2|0;d=d+2|0;c=c+2|0;a=a+2|0}else{break}}return}}function Vu(a,c,d,f,g,h,i,j,k){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=a;a=c;c=d;d=f;f=(j|0)!=0;j=f?a:c;m=f?c:d;n=(i|0)/2|0;i=(h|0)/2|0;h=(k&2|0)==0;k=n<<1;o=i<<1;if(h){p=m;q=j;r=0;s=d;t=c;u=a;v=l;while(1){w=b[t+(n<<1)>>1]|0;x=w&65535;y=e[q>>1]|0;z=e[p>>1]|0;A=(z+y|0)>>>1;B=b[t+(i<<1)>>1]|0;C=B&65535;D=y-z|0;z=(e[u+(n<<1)>>1]|0)-x|0;y=(e[u+(i<<1)>>1]|0)-C|0;E=((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)>>1;z=(e[s+(n<<1)>>1]|0)-x|0;y=(e[s+(i<<1)>>1]|0)-C|0;F=((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)>>1;z=((D|0)>-1?D:-D|0)>>1;D=(z|0)>(E|0)?z:E;E=(D|0)>(F|0)?D:F;F=(C+x|0)>>>1;D=(w&65535)>>>0>(B&65535)>>>0;B=A-(D?C:x)|0;w=(((e[p+(k<<1)>>1]|0)+(e[q+(k<<1)>>1]|0)|0)>>>1)-x|0;z=(((e[p+(o<<1)>>1]|0)+(e[q+(o<<1)>>1]|0)|0)>>>1)-C|0;y=(w|0)>(z|0);G=y?z:w;H=A-(D?x:C)|0;C=y?w:z;z=(H|0)>(C|0)?C:H;H=(E|0)>(z|0)?E:z;z=-((B|0)>(G|0)?B:G)|0;G=(H|0)>(z|0)?H:z;z=G+A|0;if((F|0)>(z|0)){I=z&65535}else{z=A-G|0;I=((F|0)<(z|0)?z:F)&65535}b[v>>1]=I;F=r+1|0;if((F|0)<3){p=p+2|0;q=q+2|0;r=F;s=s+2|0;t=t+2|0;u=u+2|0;v=v+2|0}else{break}}}else{v=m;m=j;j=0;u=d;t=c;s=a;r=l;while(1){q=e[t+(n<<1)>>1]|0;p=e[m>>1]|0;I=e[v>>1]|0;F=(I+p|0)>>>1;z=e[t+(i<<1)>>1]|0;G=p-I|0;I=(e[s+(n<<1)>>1]|0)-q|0;p=(e[s+(i<<1)>>1]|0)-z|0;A=((p|0)>-1?p:-p|0)+((I|0)>-1?I:-I|0)>>1;I=(e[u+(n<<1)>>1]|0)-q|0;p=(e[u+(i<<1)>>1]|0)-z|0;H=((p|0)>-1?p:-p|0)+((I|0)>-1?I:-I|0)>>1;I=((G|0)>-1?G:-G|0)>>1;G=(I|0)>(A|0)?I:A;A=(G|0)>(H|0)?G:H;H=(z+q|0)>>>1;q=A+F|0;if((H|0)>(q|0)){J=q&65535}else{q=F-A|0;J=((H|0)<(q|0)?q:H)&65535}b[r>>1]=J;H=j+1|0;if((H|0)<3){v=v+2|0;m=m+2|0;j=H;u=u+2|0;t=t+2|0;s=s+2|0;r=r+2|0}else{break}}}r=g-3|0;s=l+(r<<1)|0;l=a+(r<<1)|0;a=c+(r<<1)|0;c=d+(r<<1)|0;d=f?l:a;t=f?a:c;if(h){h=t;f=d;u=r;j=c;m=a;v=l;J=s;while(1){H=b[m+(n<<1)>>1]|0;q=H&65535;A=e[f>>1]|0;F=e[h>>1]|0;z=(F+A|0)>>>1;G=b[m+(i<<1)>>1]|0;I=G&65535;p=A-F|0;F=(e[v+(n<<1)>>1]|0)-q|0;A=(e[v+(i<<1)>>1]|0)-I|0;B=((A|0)>-1?A:-A|0)+((F|0)>-1?F:-F|0)>>1;F=(e[j+(n<<1)>>1]|0)-q|0;A=(e[j+(i<<1)>>1]|0)-I|0;E=((A|0)>-1?A:-A|0)+((F|0)>-1?F:-F|0)>>1;F=((p|0)>-1?p:-p|0)>>1;p=(F|0)>(B|0)?F:B;B=(p|0)>(E|0)?p:E;E=(I+q|0)>>>1;p=(H&65535)>>>0>(G&65535)>>>0;G=z-(p?I:q)|0;H=(((e[h+(k<<1)>>1]|0)+(e[f+(k<<1)>>1]|0)|0)>>>1)-q|0;F=(((e[h+(o<<1)>>1]|0)+(e[f+(o<<1)>>1]|0)|0)>>>1)-I|0;A=(H|0)>(F|0);C=A?F:H;w=z-(p?q:I)|0;I=A?H:F;F=(w|0)>(I|0)?I:w;w=(B|0)>(F|0)?B:F;F=-((G|0)>(C|0)?G:C)|0;C=(w|0)>(F|0)?w:F;F=C+z|0;if((E|0)>(F|0)){K=F&65535}else{F=z-C|0;K=((E|0)<(F|0)?F:E)&65535}b[J>>1]=K;E=u+1|0;if((E|0)<(g|0)){h=h+2|0;f=f+2|0;u=E;j=j+2|0;m=m+2|0;v=v+2|0;J=J+2|0}else{break}}return}else{J=t;t=d;d=r;r=c;c=a;a=l;l=s;while(1){s=e[c+(n<<1)>>1]|0;v=e[t>>1]|0;m=e[J>>1]|0;j=(m+v|0)>>>1;u=e[c+(i<<1)>>1]|0;f=v-m|0;m=(e[a+(n<<1)>>1]|0)-s|0;v=(e[a+(i<<1)>>1]|0)-u|0;h=((v|0)>-1?v:-v|0)+((m|0)>-1?m:-m|0)>>1;m=(e[r+(n<<1)>>1]|0)-s|0;v=(e[r+(i<<1)>>1]|0)-u|0;K=((v|0)>-1?v:-v|0)+((m|0)>-1?m:-m|0)>>1;m=((f|0)>-1?f:-f|0)>>1;f=(m|0)>(h|0)?m:h;h=(f|0)>(K|0)?f:K;K=(u+s|0)>>>1;s=h+j|0;if((K|0)>(s|0)){L=s&65535}else{s=j-h|0;L=((K|0)<(s|0)?s:K)&65535}b[l>>1]=L;K=d+1|0;if((K|0)<(g|0)){J=J+2|0;t=t+2|0;d=K;r=r+2|0;c=c+2|0;a=a+2|0;l=l+2|0}else{break}}return}}function Wu(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;l=(j|0)!=0;if((g|0)<=0){return}j=i-1|0;m=h-1|0;n=i+1|0;o=h+1|0;p=i-2|0;q=h+2|0;r=i-3|0;s=h+3|0;t=h-2|0;u=i+2|0;v=h-3|0;w=i+3|0;x=(k&2|0)==0;k=i<<1;y=h<<1;z=l?e:f;A=l?c:e;l=0;B=f;f=e;e=c;c=b;while(1){b=a[f+i|0]|0;C=b&255;D=d[A]|0;E=d[z]|0;F=(E+D|0)>>>1;G=a[f+h|0]|0;H=G&255;I=D-E|0;E=(d[e+i|0]|0)-C|0;D=(d[e+h|0]|0)-H|0;J=((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)>>1;E=(d[B+i|0]|0)-C|0;D=(d[B+h|0]|0)-H|0;K=((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)>>1;E=((I|0)>-1?I:-I|0)>>1;I=(E|0)>(J|0)?E:J;J=(I|0)>(K|0)?I:K;K=d[f+j|0]|0;I=d[f+m|0]|0;E=K-I|0;D=C-H|0;L=d[f+n|0]|0;M=d[f+o|0]|0;N=L-M|0;O=((D|0)>-1?D:-D|0)-1+((E|0)>-1?E:-E|0)+((N|0)>-1?N:-N|0)|0;N=d[f+p|0]|0;E=N-H|0;D=K-M|0;P=d[f+q|0]|0;Q=C-P|0;R=((E|0)>-1?E:-E|0)+((D|0)>-1?D:-D|0)+((Q|0)>-1?Q:-Q|0)|0;if((R|0)<(O|0)){Q=(d[f+r|0]|0)-M|0;D=N-P|0;E=K-(d[f+s|0]|0)|0;S=((Q|0)>-1?Q:-Q|0)+((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)|0;E=(S|0)<(R|0);T=E?S:R;U=E?P+N|0:M+K|0}else{T=O;U=H+C|0}O=d[f+t|0]|0;K=C-O|0;M=L-I|0;N=d[f+u|0]|0;P=N-H|0;E=((M|0)>-1?M:-M|0)+((K|0)>-1?K:-K|0)+((P|0)>-1?P:-P|0)|0;if((E|0)<(T|0)){P=L-(d[f+v|0]|0)|0;K=N-O|0;M=(d[f+w|0]|0)-I|0;V=(((P|0)>-1?P:-P|0)+((K|0)>-1?K:-K|0)+((M|0)>-1?M:-M|0)|0)<(E|0)?N+O|0:I+L|0}else{V=U}L=V>>>1;if(x){I=(b&255)>>>0>(G&255)>>>0;G=F-(I?H:C)|0;b=(((d[z+k|0]|0)+(d[A+k|0]|0)|0)>>>1)-C|0;O=(((d[z+y|0]|0)+(d[A+y|0]|0)|0)>>>1)-H|0;N=(b|0)>(O|0);E=N?O:b;M=F-(I?C:H)|0;H=N?b:O;O=(M|0)>(H|0)?H:M;M=(J|0)>(O|0)?J:O;O=-((G|0)>(E|0)?G:E)|0;W=(M|0)>(O|0)?M:O}else{W=J}J=W+F|0;if((L|0)>(J|0)){X=J&255}else{J=F-W|0;X=((L|0)<(J|0)?J:L)&255}a[c]=X;L=l+1|0;if((L|0)<(g|0)){z=z+1|0;A=A+1|0;l=L;B=B+1|0;f=f+1|0;e=e+1|0;c=c+1|0}else{break}}return}function Xu(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;l=(j|0)!=0;j=(k&2|0)==0;k=i<<1;m=h<<1;n=l?e:f;o=l?c:e;p=0;q=f;r=e;s=c;t=b;while(1){u=a[r+i|0]|0;v=u&255;w=d[o]|0;x=d[n]|0;y=(x+w|0)>>>1;z=a[r+h|0]|0;A=z&255;B=w-x|0;x=(d[s+i|0]|0)-v|0;w=(d[s+h|0]|0)-A|0;C=((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)>>1;x=(d[q+i|0]|0)-v|0;w=(d[q+h|0]|0)-A|0;D=((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)>>1;x=((B|0)>-1?B:-B|0)>>1;B=(x|0)>(C|0)?x:C;C=(B|0)>(D|0)?B:D;D=(A+v|0)>>>1;if(j){B=(u&255)>>>0>(z&255)>>>0;z=y-(B?A:v)|0;u=(((d[n+k|0]|0)+(d[o+k|0]|0)|0)>>>1)-v|0;x=(((d[n+m|0]|0)+(d[o+m|0]|0)|0)>>>1)-A|0;w=(u|0)>(x|0);E=w?x:u;F=y-(B?v:A)|0;A=w?u:x;x=(F|0)>(A|0)?A:F;F=(C|0)>(x|0)?C:x;x=-((z|0)>(E|0)?z:E)|0;G=(F|0)>(x|0)?F:x}else{G=C}C=G+y|0;if((D|0)>(C|0)){H=C&255}else{C=y-G|0;H=((D|0)<(C|0)?C:D)&255}a[t]=H;D=p+1|0;if((D|0)<3){n=n+1|0;o=o+1|0;p=D;q=q+1|0;r=r+1|0;s=s+1|0;t=t+1|0}else{break}}t=g-7|0;s=c+t|0;r=e+t|0;q=f+t|0;p=l?s:r;o=l?r:q;l=g-3|0;n=i-1|0;H=h-1|0;G=i+1|0;D=h+1|0;C=i-2|0;y=h+2|0;x=i-3|0;F=h+3|0;E=h-2|0;z=i+2|0;A=h-3|0;u=i+3|0;w=g-6|0;v=(l|0)>(w|0)?l:w;w=v+7-g|0;B=o+w|0;I=f+v|0;f=e+v|0;e=o;o=p;J=t;K=q;q=r;r=s;s=b+t|0;while(1){t=a[q+i|0]|0;L=t&255;M=d[o]|0;N=d[e]|0;O=(N+M|0)>>>1;P=a[q+h|0]|0;Q=P&255;R=M-N|0;N=(d[r+i|0]|0)-L|0;M=(d[r+h|0]|0)-Q|0;S=((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)>>1;N=(d[K+i|0]|0)-L|0;M=(d[K+h|0]|0)-Q|0;T=((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)>>1;N=((R|0)>-1?R:-R|0)>>1;R=(N|0)>(S|0)?N:S;S=(R|0)>(T|0)?R:T;T=d[q+n|0]|0;R=d[q+H|0]|0;N=T-R|0;M=L-Q|0;U=d[q+G|0]|0;V=d[q+D|0]|0;W=U-V|0;X=((M|0)>-1?M:-M|0)-1+((N|0)>-1?N:-N|0)+((W|0)>-1?W:-W|0)|0;W=d[q+C|0]|0;N=W-Q|0;M=T-V|0;Y=d[q+y|0]|0;Z=L-Y|0;_=((N|0)>-1?N:-N|0)+((M|0)>-1?M:-M|0)+((Z|0)>-1?Z:-Z|0)|0;if((_|0)<(X|0)){Z=(d[q+x|0]|0)-V|0;M=W-Y|0;N=T-(d[q+F|0]|0)|0;$=((Z|0)>-1?Z:-Z|0)+((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)|0;N=($|0)<(_|0);aa=N?Y+W|0:V+T|0;ba=N?$:_}else{aa=Q+L|0;ba=X}X=d[q+E|0]|0;_=L-X|0;$=U-R|0;N=d[q+z|0]|0;T=N-Q|0;V=(($|0)>-1?$:-$|0)+((_|0)>-1?_:-_|0)+((T|0)>-1?T:-T|0)|0;if((V|0)<(ba|0)){T=U-(d[q+A|0]|0)|0;_=N-X|0;$=(d[q+u|0]|0)-R|0;ca=(((T|0)>-1?T:-T|0)+((_|0)>-1?_:-_|0)+(($|0)>-1?$:-$|0)|0)<(V|0)?N+X|0:R+U|0}else{ca=aa}U=ca>>>1;if(j){R=(t&255)>>>0>(P&255)>>>0;P=O-(R?Q:L)|0;t=(((d[e+k|0]|0)+(d[o+k|0]|0)|0)>>>1)-L|0;X=(((d[e+m|0]|0)+(d[o+m|0]|0)|0)>>>1)-Q|0;N=(t|0)>(X|0);V=N?X:t;$=O-(R?L:Q)|0;Q=N?t:X;X=($|0)>(Q|0)?Q:$;$=(S|0)>(X|0)?S:X;X=-((P|0)>(V|0)?P:V)|0;da=($|0)>(X|0)?$:X}else{da=S}S=da+O|0;if((U|0)>(S|0)){ea=S&255}else{S=O-da|0;ea=((U|0)<(S|0)?S:U)&255}a[s]=ea;U=J+1|0;if((U|0)<(l|0)){e=e+1|0;o=o+1|0;J=U;K=K+1|0;q=q+1|0;r=r+1|0;s=s+1|0}else{break}}s=B;B=p+w|0;w=l;l=I;I=f;f=c+v|0;c=b+v|0;while(1){v=a[I+i|0]|0;b=v&255;p=d[B]|0;r=d[s]|0;q=(r+p|0)>>>1;K=a[I+h|0]|0;J=K&255;o=p-r|0;r=(d[f+i|0]|0)-b|0;p=(d[f+h|0]|0)-J|0;e=((p|0)>-1?p:-p|0)+((r|0)>-1?r:-r|0)>>1;r=(d[l+i|0]|0)-b|0;p=(d[l+h|0]|0)-J|0;ea=((p|0)>-1?p:-p|0)+((r|0)>-1?r:-r|0)>>1;r=((o|0)>-1?o:-o|0)>>1;o=(r|0)>(e|0)?r:e;e=(o|0)>(ea|0)?o:ea;ea=(J+b|0)>>>1;if(j){o=(v&255)>>>0>(K&255)>>>0;K=q-(o?J:b)|0;v=(((d[s+k|0]|0)+(d[B+k|0]|0)|0)>>>1)-b|0;r=(((d[s+m|0]|0)+(d[B+m|0]|0)|0)>>>1)-J|0;p=(v|0)>(r|0);da=p?r:v;ca=q-(o?b:J)|0;J=p?v:r;r=(ca|0)>(J|0)?J:ca;ca=(e|0)>(r|0)?e:r;r=-((K|0)>(da|0)?K:da)|0;fa=(ca|0)>(r|0)?ca:r}else{fa=e}e=fa+q|0;if((ea|0)>(e|0)){ga=e&255}else{e=q-fa|0;ga=((ea|0)<(e|0)?e:ea)&255}a[c]=ga;ea=w+1|0;if((ea|0)<(g|0)){s=s+1|0;B=B+1|0;w=ea;l=l+1|0;I=I+1|0;f=f+1|0;c=c+1|0}else{break}}return}function Yu(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+24|0;g=f|0;h=b+44|0;j=c[h>>2]|0;k=b+32|0;l=c[c[k>>2]>>2]|0;m=c[j+8>>2]|0;do{if((m|0)==-1){n=c[j+20>>2]|0;if((c[n+296>>2]|0)==0){o=1;break}o=c[n+300>>2]|0}else{o=m^1}}while(0);m=(e|0)!=0;do{if(m){e=bv(l,c[l+20>>2]|0,c[l+24>>2]|0)|0;n=j+32|0;c[n>>2]=e;if((e|0)==0){p=-12;i=f;return p|0}else{ZHb(e,c[j+20>>2]|0)|0;e=c[n>>2]|0;c[e+296>>2]=0;q=c[h>>2]|0;r=e;break}}else{q=j;r=c[j+32>>2]|0}}while(0);h=j+32|0;l=m&1^1;e=g;c[g>>2]=r;n=g+4|0;c[n>>2]=0;s=g+8|0;c[s>>2]=0;t=g+12|0;c[t>>2]=0;c[g+16>>2]=o^l;c[g+20>>2]=o;o=q+44|0;q=c[o>>2]|0;if((a[q+4|0]|0)!=0){g=r+68|0;u=r+72|0;r=b+56|0;v=b+48|0;w=0;x=q;do{q=c[g>>2]|0;y=c[u>>2]|0;if((w-1|0)>>>0<2>>>0){z=-(-y>>d[x+6|0])|0;A=-(-q>>d[x+5|0])|0}else{z=y;A=q}c[s>>2]=A;c[t>>2]=z;c[n>>2]=w;q=c[(c[v>>2]|0)+28>>2]|0;Xe[c[c[r>>2]>>2]&511](b,204,e,0,(z|0)>(q|0)?q:z)|0;w=w+1|0;x=c[o>>2]|0;}while((w|0)<(d[x+4|0]|0))}do{if(m){x=(c[j+20>>2]|0)+136|0;w=c[x>>2]|0;o=c[x+4>>2]|0;x=(c[j+24>>2]|0)+136|0;z=c[x>>2]|0;e=c[x+4>>2]|0;if((z|0)==0&(e|0)==(-2147483648|0)|(w|0)==0&(o|0)==(-2147483648|0)){x=c[h>>2]|0;b=x+136|0;c[b>>2]=0;c[b+4>>2]=-2147483648;B=x;break}else{x=wrc(z,e,w,o)|0;o=c[h>>2]|0;w=o+136|0;c[w>>2]=x;c[w+4>>2]=G;B=o;break}}else{B=c[h>>2]|0}}while(0);h=lj(c[c[k>>2]>>2]|0,B)|0;c[j+16>>2]=(c[j+4>>2]&1|0)==0?0:l;p=h;i=f;return p|0}function Zu(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=c[b+8>>2]|0;h=c[g+44>>2]|0;if((e|0)==0){KIb(0,0,2386496,(j=i,i=i+24|0,c[j>>2]=2379248,c[j+8>>2]=2373248,c[j+16>>2]=317,j)|0);i=j;Hd();return 0}if((c[h+16>>2]|0)!=0){Yu(g,1)|0}k=h+28|0;if((c[k>>2]|0)!=0){VHb(k)}l=h+20|0;c[k>>2]=c[l>>2];m=h+24|0;n=c[m>>2]|0;c[l>>2]=n;c[m>>2]=e;if((n|0)==0){o=0;i=f;return o|0}p=h+44|0;q=a[(c[p>>2]|0)+4|0]|0;r=q&255;s=0;while(1){if((s|0)>=(r|0)){t=e;u=n;v=q;break}if((c[e+32+(s<<2)>>2]|0)==(c[n+32+(s<<2)>>2]|0)){s=s+1|0}else{w=11;break}}if((w|0)==11){KIb(g,40,2363616,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;_u(b,c[m>>2]|0);t=c[m>>2]|0;u=c[l>>2]|0;v=a[(c[p>>2]|0)+4|0]|0}s=v&255;v=0;while(1){if((v|0)>=(s|0)){break}if((c[t+32+(v<<2)>>2]|0)==(c[u+32+(v<<2)>>2]|0)){v=v+1|0}else{w=15;break}}if((w|0)==15){_u(b,u)}u=c[k>>2]|0;a:do{if((u|0)!=0){v=c[m>>2]|0;t=d[(c[p>>2]|0)+4|0]|0;s=0;while(1){if((s|0)>=(t|0)){break a}if((c[v+32+(s<<2)>>2]|0)==(c[u+32+(s<<2)>>2]|0)){s=s+1|0}else{break}}_u(b,u)}}while(0);u=c[m>>2]|0;m=c[l>>2]|0;s=d[(c[p>>2]|0)+4|0]|0;p=0;while(1){if((p|0)>=(s|0)){w=24;break}if((c[u+32+(p<<2)>>2]|0)==(c[m+32+(p<<2)>>2]|0)){p=p+1|0}else{break}}b:do{if((w|0)==24){p=c[k>>2]|0;v=(p|0)==0;c:do{if(!v){t=0;while(1){if((t|0)>=(s|0)){break c}if((c[u+32+(t<<2)>>2]|0)==(c[p+32+(t<<2)>>2]|0)){t=t+1|0}else{break b}}}}while(0);if((c[h+12>>2]|0)==0){w=30}else{if((c[m+296>>2]|0)!=0){w=30}}do{if((w|0)==30){if((c[g+76>>2]|0)!=0){break}do{if(v){p=$Hb(m)|0;c[k>>2]=p;if((p|0)==0){o=-12}else{break}i=f;return o|0}}while(0);p=bv(c[c[g+32>>2]>>2]|0,c[b+20>>2]|0,c[b+24>>2]|0)|0;t=h+32|0;c[t>>2]=p;if((p|0)==0){o=-12;i=f;return o|0}ZHb(p,c[l>>2]|0)|0;p=c[t>>2]|0;c[p+296>>2]=0;t=p+136|0;p=c[t>>2]|0;n=c[t+4>>2]|0;if(!((p|0)==0&(n|0)==(-2147483648|0))){c[t>>2]=p<<1|0>>>31;c[t+4>>2]=n<<1|p>>>31}o=Yu(g,0)|0;i=f;return o|0}}while(0);v=$Hb(m)|0;p=h+32|0;c[p>>2]=v;if((v|0)==0){o=-12;i=f;return o|0}VHb(k);v=c[p>>2]|0;p=v+136|0;n=c[p>>2]|0;t=c[p+4>>2]|0;if(!((n|0)==0&(t|0)==(-2147483648|0))){c[p>>2]=n<<1|0>>>31;c[p+4>>2]=t<<1|n>>>31}o=lj(c[c[g+32>>2]>>2]|0,v)|0;i=f;return o|0}}while(0);KIb(g,16,2349848,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;o=-1;i=f;return o|0}function _u(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;f=cv(a,c[b+68>>2]|0,c[b+72>>2]|0)|0;c[e>>2]=f;if((f|0)==0){i=d;return}ZHb(f,b)|0;vIb(f|0,f+32|0,b|0,b+32|0,c[f+80>>2]|0,c[f+68>>2]|0,c[f+72>>2]|0);WHb(b);aIb(b,f);VHb(e);i=d;return}function $u(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=c[a+44>>2]|0;a=b+4|0;h=c[a>>2]|0;i=g+20|0;j=c[(c[i>>2]|0)+32+(h<<2)>>2]|0;k=(((e[(c[g+44>>2]|0)+8+(h<<1)>>1]|0)>>>11&15)+8|0)>>>3;h=k*3|0;l=b+12|0;m=c[l>>2]|0;n=(ca(m,d)|0)/(f|0)|0;o=(ca(m,d+1|0)|0)/(f|0)|0;if((n|0)>=(o|0)){return 0}f=b+16|0;d=b;m=b+8|0;p=g+28|0;q=g+24|0;r=g+36|0;s=-j|0;t=b+20|0;b=g+40|0;u=g+4|0;g=n;while(1){n=c[f>>2]|0;if(((n^g)&1|0)==0){v=c[a>>2]|0;w=c[d>>2]|0;x=ca(c[w+32+(v<<2)>>2]|0,g)|0;y=ca(g,j)|0;nrc((c[w+(v<<2)>>2]|0)+x|0,(c[(c[i>>2]|0)+(v<<2)>>2]|0)+y|0,ca(c[m>>2]|0,k)|0)|0;z=g+1|0}else{y=ca(g,j)|0;v=c[a>>2]|0;x=c[(c[p>>2]|0)+(v<<2)>>2]|0;w=x+y|0;A=c[(c[i>>2]|0)+(v<<2)>>2]|0;B=A+y|0;C=c[(c[q>>2]|0)+(v<<2)>>2]|0;D=C+y|0;E=c[d>>2]|0;F=ca(c[E+32+(v<<2)>>2]|0,g)|0;G=c[E+(v<<2)>>2]|0;v=G+F|0;do{if((g|0)==1){H=2;I=c[l>>2]|0}else{E=g+2|0;J=c[l>>2]|0;if((E|0)==(J|0)){H=2;I=E;break}H=c[u>>2]|0;I=J}}while(0);J=y+h|0;E=g+1|0;K=(g|0)!=0?s:j;Te[c[r>>2]&255](G+(F+h)|0,x+J|0,A+J|0,C+J|0,(c[m>>2]|0)-2-(8/(k>>>0)|0)|0,(E|0)<(I|0)?j:s,K,c[t>>2]^n,H);Te[c[b>>2]&255](v,w,B,D,c[m>>2]|0,(E|0)<(c[l>>2]|0)?j:s,K,c[t>>2]^c[f>>2],H);z=E}if((z|0)<(o|0)){g=z}else{break}}return 0}function av(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=c[c[(c[a+8>>2]|0)+32>>2]>>2]|0;Vi(0,g,0);a=c[(c[g+12>>2]|0)+20>>2]|0;do{if((a|0)!=0){h=Ee[a&511](g,b,d)|0;if((h|0)==0){break}else{j=h}i=e;return j|0}}while(0);a=UHb()|0;c[f>>2]=a;if((a|0)==0){j=0;i=e;return j|0}c[a+68>>2]=b;c[a+72>>2]=d;c[a+80>>2]=c[g+52>>2];if((XHb(a,32)|0)>=0){j=a;i=e;return j|0}VHb(f);j=c[f>>2]|0;i=e;return j|0}function bv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;Vi(0,a,0);g=c[(c[a+12>>2]|0)+20>>2]|0;do{if((g|0)!=0){h=Ee[g&511](a,b,d)|0;if((h|0)==0){break}else{j=h}i=e;return j|0}}while(0);g=UHb()|0;c[f>>2]=g;if((g|0)==0){j=0;i=e;return j|0}c[g+68>>2]=b;c[g+72>>2]=d;c[g+80>>2]=c[a+52>>2];if((XHb(g,32)|0)>=0){j=g;i=e;return j|0}VHb(f);j=c[f>>2]|0;i=e;return j|0}function cv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=UHb()|0;c[f>>2]=g;if((g|0)==0){h=0;i=e;return h|0}c[g+68>>2]=b;c[g+72>>2]=d;c[g+80>>2]=c[a+52>>2];if((XHb(g,32)|0)>=0){h=g;i=e;return h|0}VHb(f);h=c[f>>2]|0;i=e;return h|0}function dv(a,b){a=a|0;b=b|0;var d=0;a=i;i=i+8|0;d=a|0;c[d>>2]=b;VHb(d);i=a;return 0}function ev(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;f=b+44|0;g=c[f>>2]|0;j=g+4|0;k=g+12|0;do{if((c[j>>2]|0)==0){if((c[k>>2]|0)!=0){break}if((c[g+356>>2]|0)!=0){break}EJb(g,2416752,2337408,0)|0}}while(0);l=(c[g+356>>2]|0)==0;do{if((c[k>>2]|0)==0){if(!l){m=hv(b)|0;if((m|0)<0){n=m}else{break}i=e;return n|0}m=pJb(ca(c[g+8>>2]|0,c[j>>2]|0)|0)|0;o=g+28|0;c[o>>2]=m;if((m|0)==0){n=-12;i=e;return n|0}m=g+72|0;p=c[m>>2]|0;if((p|0)==-1){q=wKb()|0;c[m>>2]=q;r=q}else{r=p}p=g+96|0;AIb(p,r);if((c[j>>2]|0)<=0){break}q=g+352|0;m=g+64|0;s=0;do{t=c[q>>2]|0;c[p+((t&63)<<2)>>2]=(c[p+((t+9&63)<<2)>>2]|0)+(c[p+((t+40&63)<<2)>>2]|0);t=c[q>>2]|0;c[q>>2]=t+1;if(!(+((c[p+((t&63)<<2)>>2]|0)>>>0>>>0)/4294967295.0>+h[m>>3])){a[(c[o>>2]|0)+s|0]=1}s=s+1|0;}while((s|0)<(c[j>>2]|0))}else{if(!l){KIb(b,16,2279632,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;n=-22;i=e;return n|0}s=c[f>>2]|0;o=s+20|0;m=s+24|0;p=lHb(c[s+12>>2]|0,o,m,0,b)|0;if((p|0)<0){n=p;i=e;return n|0}p=hJb((c[m>>2]|0)+1|0)|0;q=s+356|0;c[q>>2]=p;if((p|0)==0){n=-12;i=e;return n|0}nrc(p|0,c[o>>2]|0,c[m>>2]|0)|0;a[(c[q>>2]|0)+(c[m>>2]|0)|0]=0;m=hv(b)|0;if((m|0)<0){n=m}else{break}i=e;return n|0}}while(0);f=c[g+8>>2]|0;l=c[g+56>>2]|0;r=c[g+60>>2]|0;k=d[g+40|0]|0;m=c[g+76>>2]|0;q=c[g+80>>2]|0;o=c[g+84>>2]|0;p=c[g+72>>2]|0;KIb(b,40,2230464,(u=i,i=i+72|0,c[u>>2]=c[j>>2],c[u+8>>2]=f,c[u+16>>2]=l,c[u+24>>2]=r,c[u+32>>2]=k,c[u+40>>2]=m,c[u+48>>2]=q,c[u+56>>2]=o,c[u+64>>2]=p,u)|0);i=u;n=0;i=e;return n|0}function fv(a){a=a|0;var b=0;b=c[a+44>>2]|0;mHb(c[b+20>>2]|0,c[b+24>>2]|0);mJb(b+28|0);mJb(b+356|0);return}function gv(a){a=a|0;dl(a,Ok(684288)|0);return 0}function hv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[b+44>>2]|0;f=e+356|0;g=lrc(c[f>>2]|0)|0;h=b;KIb(h,48,2192208,(b=i,i=i+8|0,c[b>>2]=g,b)|0);i=b;j=e+4|0;k=c[j>>2]|0;do{if((k|0)==0){c[j>>2]=g;l=~~(+(g|0)*1.618033988749895);c[e+8>>2]=l;m=g;n=l}else{if((g|0)<=(k|0)){m=k;n=c[e+8>>2]|0;break}KIb(h,16,2161264,(b=i,i=i+16|0,c[b>>2]=k,c[b+8>>2]=g,b)|0);i=b;o=-22;i=d;return o|0}}while(0);k=pJb(ca(n,m)|0)|0;m=e+28|0;c[m>>2]=k;if((k|0)==0){o=-12;i=d;return o|0}k=((c[j>>2]|0)-g|0)/2|0;g=c[f>>2]|0;while(1){f=a[g]|0;KIb(h,48,2135856,(b=i,i=i+16|0,c[b>>2]=k,c[b+8>>2]=f<<24>>24==10?78:f<<24>>24,b)|0);i=b;f=a[g]|0;if((f<<24>>24|0)==10|(f<<24>>24|0)==0){o=0;break}j=(NFb(f<<24>>24)|0)!=0|0;a[(c[m>>2]|0)+k|0]=j;k=k+1|0;g=g+1|0}i=d;return o|0}function iv(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;e=b|0;f=c[(c[e>>2]|0)+44>>2]|0;g=f+8|0;h=bv(b,c[f+4>>2]|0,c[g>>2]|0)|0;if((h|0)==0){i=-12;return i|0}c[h+124>>2]=1;c[h+128>>2]=1;j=f+88|0;do{if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){if((c[f+84>>2]|0)==0){break}if(((c[g>>2]|0)-1|0)>0){k=0}else{break}do{kv(c[(c[e>>2]|0)+44>>2]|0);k=k+1|0;}while((k|0)<((c[g>>2]|0)-1|0))}}while(0);g=c[(c[e>>2]|0)+44>>2]|0;k=c[h>>2]|0;do{if((c[g+80>>2]|0)==0){l=0;m=c[g+8>>2]|0}else{j=g+88|0;n=c[j+4>>2]|0;o=c[g+8>>2]|0;p=(o|0)<0|0?-1:0;if((n|0)<(p|0)|(n|0)==(p|0)&(c[j>>2]|0)>>>0<o>>>0){l=0;m=o;break}l=((c[g+36>>2]|0)+1|0)%(o|0)|0;m=o}}while(0);o=g+8|0;if((m|0)>0){j=g+28|0;p=g+4|0;n=h+32|0;q=l;l=k;k=1;r=c[p>>2]|0;s=m;while(1){m=c[j>>2]|0;t=ca(q,r)|0;if((r|0)>0){u=0;v=0;w=0;x=l;y=r;while(1){z=v+1|0;A=((d[m+(u+t)|0]|0)<<7-v|w&255)&255;if((z|0)==8){B=15}else{if((u|0)==(y-1|0)){B=15}else{C=x;D=A;E=z;F=y}}if((B|0)==15){B=0;a[x]=A;C=x+1|0;D=0;E=0;F=c[p>>2]|0}A=u+1|0;if((A|0)<(F|0)){u=A;v=E;w=D;x=C;y=F}else{break}}H=F;I=c[o>>2]|0}else{H=r;I=s}if((k|0)>=(I|0)){break}q=(q+1|0)%(I|0)|0;l=l+(c[n>>2]|0)|0;k=k+1|0;r=H;s=I}J=c[(c[e>>2]|0)+44>>2]|0}else{J=g}kv(J);J=f+48|0;f=c[J>>2]|0;g=c[J+4>>2]|0;e=wrc(f,g,1,0)|0;c[J>>2]=e;c[J+4>>2]=G;J=h+136|0;c[J>>2]=f;c[J+4>>2]=g;i=lj(b,h)|0;return i|0}function jv(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+4>>2];c[a+24>>2]=c[b+8>>2];d=a+56|0;a=c[b+56>>2]|0;c[d>>2]=c[b+60>>2];c[d+4>>2]=a;return 0}function kv(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=c[b+28>>2]|0;f=b+36|0;g=c[f>>2]|0;h=b+4|0;i=c[h>>2]|0;j=ca(i,g)|0;c[b+32>>2]=g;k=(g|0)==((c[b+8>>2]|0)-1|0)?0:g+1|0;c[f>>2]=k;f=ca(k,i)|0;if((i|0)<=0){l=b+88|0;m=l;n=m|0;o=c[n>>2]|0;p=m+4|0;q=c[p>>2]|0;r=1;s=0;t=wrc(o,q,r,s)|0;u=G;v=m|0;c[v>>2]=t;w=m+4|0;c[w>>2]=u;return}k=b+76|0;g=j-1|0;x=b+40|0;y=0;z=i;do{if((c[k>>2]|0)==0){if((y|0)>0){A=(d[e+(g+y)|0]|0)<<2}else{A=0}i=y+1|0;if((i|0)<(z|0)){B=d[e+(i+j)|0]|0}else{B=0}C=(d[e+(y+j)|0]|0)<<1|A|B}else{i=y+1|0;C=(d[e+(y+j)|0]|0)<<1|(d[e+(g+((y-1|0)<0?z:y))|0]|0)<<2|(d[e+(((i|0)==(z|0)?0:i)+j)|0]|0)}a[e+(y+f)|0]=((d[x]|0)&1<<C|0)!=0|0;y=y+1|0;z=c[h>>2]|0;}while((y|0)<(z|0));l=b+88|0;m=l;n=m|0;o=c[n>>2]|0;p=m+4|0;q=c[p>>2]|0;r=1;s=0;t=wrc(o,q,r,s)|0;u=G;v=m|0;c[v>>2]=t;w=m+4|0;c[w>>2]=u;return}function lv(d){d=d|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;f=i;i=i+8|0;g=f|0;j=d+44|0;k=c[j>>2]|0;l=k+4|0;do{if((c[l>>2]|0)==0){if((c[k+12>>2]|0)!=0){break}EJb(k,2279560,2230304,0)|0}}while(0);m=k+40|0;n=k+38|0;o=k+16|0;p=c[o>>2]|0;q=d;b[m>>1]=0;b[n>>1]=0;d=a[p]|0;do{if((Ob(2605448,d<<24>>24|0,5)|0)==0){r=rb(p|0,g|0,10)|0;if((a[c[g>>2]|0]|0)!=0){s=15;break}b[m>>1]=r&511;b[n>>1]=r>>>9}else{r=p;t=d;while(1){if((t<<24>>24|0)==98|(t<<24>>24|0)==66){u=m}else{u=n}v=r+1|0;w=a[v]|0;if((w-48&255)>>>0<9>>>0){x=v;v=w;y=b[u>>1]|0;while(1){z=(1<<(v<<24>>24)-48)+(y&65535)&65535;b[u>>1]=z;A=x+1|0;B=a[A]|0;if((B-48&255)>>>0<9>>>0){x=A;v=B;y=z}else{C=x;D=B;break}}}else{C=r;D=w}if(!(D<<24>>24==47)){E=D;break}x=C+2|0;y=a[x]|0;if((Ob(2605448,y<<24>>24|0,5)|0)==0){E=y;break}else{r=x;t=y}}if(!(E<<24>>24==0)){s=15}}}while(0);if((s|0)==15){KIb(q,16,2579776,(F=i,i=i+8|0,c[F>>2]=p,F)|0);i=F;G=-22;i=f;return G|0}do{if((c[k+80>>2]|0)==0){if((grc(k+92|0,10230360,3)|0)==0){break}KIb(q,24,2192040,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}}while(0);a:do{if((c[k+12>>2]|0)==0){p=k+8|0;s=qJb(ca(c[l>>2]|0,c[p>>2]|0)|0,1)|0;E=k+28|0;c[E>>2]=s;do{if((s|0)==0){H=0;I=k+32|0}else{C=qJb(ca(c[l>>2]|0,c[p>>2]|0)|0,1)|0;D=k+32|0;c[D>>2]=C;if((C|0)==0){H=c[E>>2]|0;I=D;break}D=k+72|0;C=c[D>>2]|0;if((C|0)==-1){u=wKb()|0;c[D>>2]=u;J=u}else{J=C}C=k+96|0;AIb(C,J);u=c[l>>2]|0;d=c[p>>2]|0;if((ca(d,u)|0)>0){g=k+352|0;t=k+64|0;r=0;while(1){y=c[g>>2]|0;c[C+((y&63)<<2)>>2]=(c[C+((y+9&63)<<2)>>2]|0)+(c[C+((y+40&63)<<2)>>2]|0);y=c[g>>2]|0;c[g>>2]=y+1;if(!(+((c[C+((y&63)<<2)>>2]|0)>>>0>>>0)/4294967295.0>+h[t>>3])){a[(c[E>>2]|0)+r|0]=-1}y=r+1|0;x=c[l>>2]|0;v=c[p>>2]|0;if((y|0)<(ca(v,x)|0)){r=y}else{K=x;L=v;break}}}else{K=u;L=d}a[k+36|0]=0;M=K;N=L;O=D;break a}}while(0);kJb(H);kJb(c[I>>2]|0);G=-12;i=f;return G|0}else{p=c[j>>2]|0;E=p+12|0;s=p+20|0;r=p+24|0;t=lHb(c[E>>2]|0,s,r,0,q)|0;if((t|0)<0){G=t;i=f;return G|0}mJb(E);E=c[r>>2]|0;if((E|0)==0){P=0;Q=0}else{r=c[s>>2]|0;t=0;C=0;g=0;w=0;while(1){if((a[r+t|0]|0)==10){R=(g|0)>(w|0)?g:w;S=0;T=C+1|0}else{R=w;S=g+1|0;T=C}v=t+1|0;if(v>>>0<E>>>0){t=v;C=T;g=S;w=R}else{P=T;Q=R;break}}}KIb(q,48,2135800,(F=i,i=i+16|0,c[F>>2]=P,c[F+8>>2]=Q,F)|0);i=F;w=p+4|0;g=c[w>>2]|0;do{if((g|0)==0){c[w>>2]=Q;c[p+8>>2]=P;U=P;V=Q}else{C=c[p+8>>2]|0;if(!((Q|0)>(g|0)|(P|0)>(C|0))){U=C;V=g;break}KIb(q,16,2112352,(F=i,i=i+32|0,c[F>>2]=g,c[F+8>>2]=C,c[F+16>>2]=Q,c[F+24>>2]=P,F)|0);i=F;G=-22;i=f;return G|0}}while(0);g=p+8|0;C=qJb(ca(U,V)|0,1)|0;t=p+28|0;c[t>>2]=C;do{if((C|0)==0){W=0;X=p+32|0}else{E=qJb(ca(c[w>>2]|0,c[g>>2]|0)|0,1)|0;r=p+32|0;c[r>>2]=E;if((E|0)==0){W=c[t>>2]|0;X=r;break}if((P|0)>0){r=c[s>>2]|0;E=((c[g>>2]|0)-P|0)/2|0;v=0;while(1){x=((c[w>>2]|0)-Q|0)/2|0;y=a[r]|0;KIb(q,48,2630160,(F=i,i=i+24|0,c[F>>2]=E,c[F+8>>2]=x,c[F+16>>2]=y<<24>>24==10?78:y<<24>>24,F)|0);i=F;y=a[r]|0;B=r+1|0;if(y<<24>>24==10){Y=B}else{z=x;x=y;y=B;while(1){B=((NFb(x<<24>>24)|0)!=0)<<31>>31;A=(ca(c[w>>2]|0,E)|0)+z|0;a[(c[t>>2]|0)+A|0]=B;B=z+1|0;A=a[y]|0;KIb(q,48,2630160,(F=i,i=i+24|0,c[F>>2]=E,c[F+8>>2]=B,c[F+16>>2]=A<<24>>24==10?78:A<<24>>24,F)|0);i=F;A=a[y]|0;Z=y+1|0;if(A<<24>>24==10){Y=Z;break}else{z=B;x=A;y=Z}}}y=v+1|0;if((y|0)<(P|0)){r=Y;E=E+1|0;v=y}else{break}}}a[p+36|0]=0;M=c[l>>2]|0;N=c[k+8>>2]|0;O=k+72|0;break a}}while(0);kJb(W);kJb(c[X>>2]|0);G=-12;i=f;return G|0}}while(0);X=c[k+56>>2]|0;W=c[k+60>>2]|0;l=c[o>>2]|0;o=e[n>>1]|0;n=e[m>>1]|0;m=c[k+76>>2]|0;k=c[O>>2]|0;KIb(q,40,2161168,(F=i,i=i+72|0,c[F>>2]=M,c[F+8>>2]=N,c[F+16>>2]=X,c[F+24>>2]=W,c[F+32>>2]=l,c[F+40>>2]=o,c[F+48>>2]=n,c[F+56>>2]=m,c[F+64>>2]=k,F)|0);i=F;G=0;i=f;return G|0}function mv(a){a=a|0;var b=0;b=c[a+44>>2]|0;mHb(c[b+20>>2]|0,c[b+24>>2]|0);mJb(b+16|0);mJb(b+28|0);mJb(b+32|0);return}function nv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=-1;c[d+4>>2]=-1;do{if((c[e+80>>2]|0)==0){if((grc(e+84|0,2416408,3)|0)!=0){break}if((grc(e+88|0,10230360,3)|0)!=0){break}c[d>>2]=10;c[e+356>>2]=356;f=d;g=Ok(f)|0;dl(a,g);i=b;return 0}}while(0);c[d>>2]=2;c[e+356>>2]=306;f=d;g=Ok(f)|0;dl(a,g);i=b;return 0}function ov(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c[b+44>>2]|0;b=c[f+28+((d[f+36|0]|0)<<2)>>2]|0;g=f+8|0;h=c[g>>2]|0;if((h|0)<=0){return}i=e|0;j=e+32|0;e=f+4|0;k=f+80|0;l=f+84|0;m=f+88|0;n=f+92|0;o=f+89|0;p=f+93|0;q=f+90|0;r=f+94|0;f=0;s=c[e>>2]|0;t=h;while(1){if((s|0)>0){h=ca(c[j>>2]|0,f)|0;u=(c[i>>2]|0)+h|0;h=0;v=s;while(1){w=a[b+((ca(v,f)|0)+h)|0]|0;x=c[k>>2]|0;y=w<<24>>24==-1;if((x|0)==0|y){z=y?l:m;a[u+2|0]=a[z+2|0]|0;a[u+1|0]=a[z+1|0]|0;a[u]=a[z]|0}else{z=ca(w&255^255,x)|0;x=(z|0)>255?255:z;z=d[m]|0;a[u]=((((ca((d[n]|0)-z|0,x)|0)+(z<<8)|0)*257|0)+32896|0)>>>16;z=d[o]|0;a[u+1|0]=((((ca((d[p]|0)-z|0,x)|0)+(z<<8)|0)*257|0)+32896|0)>>>16;z=d[q]|0;a[u+2|0]=((((ca((d[r]|0)-z|0,x)|0)+(z<<8)|0)*257|0)+32896|0)>>>16}z=h+1|0;A=c[e>>2]|0;if((z|0)<(A|0)){u=u+3|0;h=z;v=A}else{break}}B=A;C=c[g>>2]|0}else{B=s;C=t}v=f+1|0;if((v|0)<(C|0)){f=v;s=B;t=C}else{break}}return}function pv(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=c[b+44>>2]|0;b=c[f+28+(d[f+36|0]<<2)>>2]|0;g=f+8|0;h=c[g>>2]|0;if((h|0)<=0){return}i=e|0;j=e+32|0;e=f+4|0;f=0;k=c[e>>2]|0;l=h;while(1){if((k|0)>0){h=ca(c[j>>2]|0,f)|0;m=0;n=0;o=0;p=(c[i>>2]|0)+h|0;h=k;while(1){q=n+1|0;r=(((a[b+((ca(h,f)|0)+m)|0]|0)==-1)<<7-n|o&255)&255;if((q|0)==8){s=7}else{if((m|0)==(h-1|0)){s=7}else{t=p;u=r;v=q;w=h}}if((s|0)==7){s=0;a[p]=r;t=p+1|0;u=0;v=0;w=c[e>>2]|0}r=m+1|0;if((r|0)<(w|0)){m=r;n=v;o=u;p=t;h=w}else{break}}x=w;y=c[g>>2]|0}else{x=k;y=l}h=f+1|0;if((h|0)<(y|0)){f=h;k=x;l=y}else{break}}return}function qv(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;d=b|0;f=c[(c[d>>2]|0)+44>>2]|0;g=bv(b,c[f+4>>2]|0,c[f+8>>2]|0)|0;if((g|0)==0){h=-12;return h|0}c[g+124>>2]=1;c[g+128>>2]=1;i=f+48|0;j=c[i>>2]|0;k=c[i+4>>2]|0;l=wrc(j,k,1,0)|0;c[i>>2]=l;c[i+4>>2]=G;i=g+136|0;c[i>>2]=j;c[i+4>>2]=k;re[c[f+356>>2]&1023](c[d>>2]|0,g);f=c[(c[d>>2]|0)+44>>2]|0;d=f+36|0;k=a[d]|0;i=f+28|0;j=c[i+((k&255)<<2)>>2]|0;l=f+8|0;m=c[l>>2]|0;if((m|0)>0){n=f+4|0;o=f+76|0;p=f+38|0;q=f+40|0;f=c[i+((k<<24>>24==0)<<2)>>2]|0;i=0;r=c[n>>2]|0;s=m;while(1){if((r|0)>0){m=i-1|0;t=(m|0)<0;u=t?-1:m;m=i+1|0;v=f;w=0;x=r;do{if((c[o>>2]|0)==0){y=w-1|0;z=w+1|0;A=u;B=u;C=(y|0)>-1?y:-1;D=(m|0)==(c[l>>2]|0)?-1:m;E=(z|0)==(x|0)?-1:z}else{z=c[l>>2]|0;y=w+1|0;A=(t?z:i)-1|0;B=(t?z:i)-1|0;C=((w-1|0)<0?x:w)-1|0;D=(m|0)==(z|0)?0:m;E=(y|0)==(x|0)?0:y}y=(C|0)==-1;if((A|0)==-1|y){F=0}else{F=(a[j+((ca(A,x)|0)+C)|0]|0)==-1|0}do{if((B|0)==-1){H=0;I=F;J=(E|0)==-1}else{z=ca(B,x)|0;K=((a[j+(z+w)|0]|0)==-1)+F|0;if((E|0)==-1){H=0;I=K;J=1;break}H=(a[j+(z+E)|0]|0)==-1|0;I=K;J=0}}while(0);if(y){L=0}else{L=(a[j+(C+(ca(x,i)|0))|0]|0)==-1|0}if(J){M=0}else{M=(a[j+(E+(ca(x,i)|0))|0]|0)==-1|0}K=(D|0)==-1;if(K|y){N=0}else{N=(a[j+((ca(D,x)|0)+C)|0]|0)==-1|0}z=H+I+L+M+N|0;do{if(K){O=0;P=z}else{Q=ca(D,x)|0;R=((a[j+(Q+w)|0]|0)==-1)+z|0;if(J){O=0;P=R;break}O=(a[j+(Q+E)|0]|0)==-1|0;P=R}}while(0);z=a[j+((ca(x,i)|0)+w)|0]|0;do{if((e[(z<<24>>24==-1?p:q)>>1]&1<<O+P|0)==0){if(z<<24>>24==0){a[v]=0;break}else{a[v]=z-1;break}}else{a[v]=-1}}while(0);v=v+1|0;w=w+1|0;x=c[n>>2]|0;}while((w|0)<(x|0));S=v;T=x;U=c[l>>2]|0;V=m}else{S=f;T=r;U=s;V=i+1|0}if((V|0)<(U|0)){f=S;i=V;r=T;s=U}else{break}}W=a[d]|0}else{W=k}a[d]=W<<24>>24==0|0;h=lj(b,g)|0;return h|0}function rv(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+4>>2];c[a+24>>2]=c[b+8>>2];d=a+56|0;a=c[b+56>>2]|0;c[d>>2]=c[b+60>>2];c[d+4>>2]=a;return 0}function sv(a){a=a|0;var b=0,d=0.0,e=0;b=c[a+44>>2]|0;a=b+80|0;d=+h[a>>3];h[a>>3]=d*d;a=c[b+8>>2]|0;d=+(a|0);e=b+56|0;h[e>>3]=+h[e>>3]/d;e=b+64|0;h[e>>3]=+h[e>>3]/d;e=ca((c[b+4>>2]|0)*3|0,a)|0;a=b+96|0;c[a>>2]=e;c[b+100>>2]=0;c[b+104>>2]=hJb(e*24|0)|0;c[b+108>>2]=hJb((c[a>>2]|0)*24|0)|0;c[b+112>>2]=hJb((c[b+32>>2]<<4)+256|0)|0;return 0}function tv(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+104|0);mJb(b+108|0);mJb(b+112|0);return}function uv(a){a=a|0;dl(a,Ok(684280)|0);return 0}function vv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0.0,O=0,P=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0.0,ra=0,sa=0,ta=0,ua=0,va=0.0,wa=0.0,xa=0.0,ya=0,za=0.0,Aa=0.0,Ba=0.0,Ca=0.0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0.0,Pa=0,Qa=0.0,Ra=0,Sa=0.0,Ta=0.0,Ua=0.0,Va=0.0,Wa=0,Xa=0.0,Ya=0.0,Za=0,_a=0.0,$a=0.0,ab=0.0,bb=0.0,cb=0.0,db=0.0,eb=0,fb=0.0,gb=0.0,hb=0,ib=0.0,jb=0,kb=0,lb=0.0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0;b=i;d=a|0;e=c[(c[d>>2]|0)+44>>2]|0;f=bv(a,c[e+4>>2]|0,c[e+8>>2]|0)|0;if((f|0)==0){g=-12;i=b;return g|0}c[f+124>>2]=1;c[f+128>>2]=1;j=e+24|0;e=c[j>>2]|0;k=c[j+4>>2]|0;l=wrc(e,k,1,0)|0;c[j>>2]=l;c[j+4>>2]=G;j=f+136|0;c[j>>2]=e;c[j+4>>2]=k;j=c[d>>2]|0;d=c[f>>2]|0;l=d;m=(c[f+32>>2]|0)/4|0;n=j+44|0;o=c[n>>2]|0;p=+h[o+56>>3];q=+(e>>>0)+ +(k|0)*4294967296.0;r=p*+T(+(+h[o+64>>3]/p),+(q/+h[o+72>>3]));k=o+48|0;e=o+8|0;p=+h[k>>3]+r*(+((c[e>>2]|0)/-2|0|0)+-.5);s=o+136|0;a:do{if(+h[s>>3]!=0.0){t=0}else{u=c[o+100>>2]|0;if((u|0)<=0){t=0;break}v=c[o+104>>2]|0;w=0;while(1){if(+h[v+(w*24|0)+8>>3]>p){t=w;break a}x=w+1|0;if((x|0)<(u|0)){w=x}else{t=x;break}}}}while(0);w=o+4|0;mrc(d|0,0,c[w>>2]<<2|0)|0;d=c[e>>2]|0;if((d|0)>0){p=r*3.0*.5;y=r*.5;u=o+40|0;v=o+116|0;x=o+120|0;z=o+128|0;A=o+32|0;B=o+112|0;C=o+80|0;D=o+88|0;E=o+92|0;F=o+96|0;H=o+108|0;I=t;J=0;K=t;L=0.0;t=0;M=d;while(1){d=t+1|0;N=+h[k>>3]+r*+(t-((M|0)/2|0)|0);O=c[n>>2]|0;do{if(+h[O+136>>3]!=0.0){P=J;W=I;X=M}else{Y=O+104|0;Z=O+100|0;_=c[Z>>2]|0;if((I|0)>=(_|0)){P=J;W=I;X=M;break}$=O+40|0;ba=O+4|0;da=O+96|0;ea=O+108|0;fa=J;ga=I;ha=_;while(1){_=c[Y>>2]|0;ia=_+(ga*24|0)|0;if(+h[_+(ga*24|0)+8>>3]>N){ja=fa;ka=ga;break}_=c[ba>>2]|0;la=~~+Nb(+((+h[ia>>3]- +h[$>>3])/r+ +((_|0)/2|0|0)));do{if((la|0)>=(_|0)|(la|0)<0){ma=fa;na=ha}else{if((fa|0)>=(c[da>>2]|0)){ma=fa;na=ha;break}oa=(c[ea>>2]|0)+(fa*24|0)|0;pa=ia;c[oa>>2]=c[pa>>2];c[oa+4>>2]=c[pa+4>>2];c[oa+8>>2]=c[pa+8>>2];c[oa+12>>2]=c[pa+12>>2];c[oa+16>>2]=c[pa+16>>2];c[oa+20>>2]=c[pa+20>>2];ma=fa+1|0;na=c[Z>>2]|0}}while(0);ia=ga+1|0;if((ia|0)<(na|0)){fa=ma;ga=ia;ha=na}else{ja=ma;ka=ia;break}}P=ja;W=ka;X=c[e>>2]|0}}while(0);b:do{if((d|0)<(X|0)){O=ca(d,m)|0;ha=l+(O<<2)|0;mrc(ha|0,0,c[w>>2]<<2|0)|0;qa=p+N;ga=c[n>>2]|0;if(+h[ga+136>>3]!=0.0){ra=K;break}fa=ga+100|0;Z=c[fa>>2]|0;if((K|0)>=(Z|0)){ra=K;break}ea=ga+40|0;da=ga+4|0;$=c[ga+104>>2]|0;if((ha|0)==0){ha=K;while(1){if(+h[$+(ha*24|0)+8>>3]>qa){ra=ha;break b}ga=ha+1|0;if((ga|0)<(Z|0)){ha=ga}else{ra=ga;break b}}}else{sa=K;ta=Z}while(1){if(+h[$+(sa*24|0)+8>>3]>qa){ra=sa;break b}ha=c[da>>2]|0;ga=~~+Nb(+((+h[$+(sa*24|0)>>3]- +h[ea>>3])/r+ +((ha|0)/2|0|0)));if((ga|0)>-1&(ga|0)<(ha|0)){c[l+(ga+O<<2)>>2]=c[$+(sa*24|0)+16>>2];ua=c[fa>>2]|0}else{ua=ta}ga=sa+1|0;if((ga|0)<(ua|0)){sa=ga;ta=ua}else{ra=ga;break}}}else{ra=K}}while(0);fa=c[w>>2]|0;if((fa|0)>0){$=ca(t,m)|0;O=$-1|0;ea=(t|0)==0;da=ca(d,m)|0;Z=ca(t-1|0,m)|0;ga=P;qa=L;ha=0;ba=fa;while(1){fa=ha-((ba|0)/2|0)|0;va=+h[u>>3]+r*+(fa|0);Y=c[v>>2]|0;wa=+(Y>>>0>>>0)*2.3283064365386963e-10;c[v>>2]=(ca(Y,1664525)|0)+1013904223;Y=l+(ha+$<<2)|0;c:do{if((c[Y>>2]|0)>>>0>16777215>>>0){xa=qa;ya=ga}else{za=+h[s>>3];d:do{if(za!=0.0){Aa=va+za*+U(q*+h[x>>3]);Ba=N+za*+V(q*+h[z>>3]);Ca=Aa}else{if((ha|0)==0|ea){Ba=N;Ca=va;break}ia=ha+1|0;if((ia|0)==(ba|0)){Ba=N;Ca=va;break}la=c[e>>2]|0;if((d|0)==(la|0)){Ba=N;Ca=va;break}_=ha-(ba>>1)|0;pa=ca(la,(_|0)>-1?_:-_|0)|0;_=t-(la>>1)|0;oa=ca((_|0)>-1?_:-_|0,ba)|0;if((((pa|0)>(oa|0)?pa:oa)|0)<((ca(la,ba)|0)>>3|0)){Ba=N;Ca=va;break}la=c[l+(ia+$<<2)>>2]|0;oa=ha-1|0;pa=c[l+(oa+da<<2)>>2]|0;_=c[l+(ha+da<<2)>>2]|0;Da=c[l+(ia+da<<2)>>2]|0;Ea=(_|0)==0;do{if((la|0)==0|Ea){Fa=(Da|0)==0;if(!((pa|0)==0|Fa)){Ga=c[l+(ia+Z<<2)>>2]|0;Ha=pa;Ia=c[l+(oa+Z<<2)>>2]|0;Ja=Da;break}if(!Ea){Ga=c[l+(oa+$<<2)>>2]|0;Ha=c[l+(ia+Z<<2)>>2]|0;Ia=_;Ja=c[l+(ha+Z<<2)>>2]|0;break}if(Fa){Ba=N;Ca=va;break d}Ga=c[l+(oa+$<<2)>>2]|0;Ha=c[l+(ia+Z<<2)>>2]|0;Ia=c[l+(oa+Z<<2)>>2]|0;Ja=Da}else{Ga=la;Ha=c[l+(oa+$<<2)>>2]|0;Ia=_;Ja=c[l+(ha+Z<<2)>>2]|0}}while(0);_=Ga&255;oa=Ha&255;la=_+oa|0;Da=Ia&255;ia=Ja&255;Ea=Da+ia|0;pa=la-Ea|0;if((((pa|0)>-1?pa:-pa|0)|0)>5){Ba=N;Ca=va;break}pa=_-oa|0;oa=Da-ia|0;if((((pa|0)>-1?pa:-pa|0)+((oa|0)>-1?oa:-oa|0)|0)>20){Ba=N;Ca=va;break}oa=Ga>>>8&255;pa=Ha>>>8&255;ia=oa+pa|0;Da=Ia>>>8&255;_=Ja>>>8&255;Fa=Da+_|0;Ka=ia-Fa|0;if((((Ka|0)>-1?Ka:-Ka|0)|0)>5){Ba=N;Ca=va;break}Ka=oa-pa|0;pa=Da-_|0;if((((Ka|0)>-1?Ka:-Ka|0)+((pa|0)>-1?pa:-pa|0)|0)>20){Ba=N;Ca=va;break}pa=Ga>>>16&255;Ka=Ha>>>16&255;_=pa+Ka|0;Da=Ia>>>16&255;oa=Ja>>>16&255;La=Da+oa|0;Ma=_-La|0;if((((Ma|0)>-1?Ma:-Ma|0)|0)>5){Ba=N;Ca=va;break}Ma=pa-Ka|0;Ka=Da-oa|0;if((((Ma|0)>-1?Ma:-Ma|0)+((Ka|0)>-1?Ka:-Ka|0)|0)>20){Ba=N;Ca=va;break}Ka=(Ea+2+la|0)>>>2|(Fa+2+ia|0)>>>2<<8|(La+2+_|0)>>>2<<16|-16777216;c[Y>>2]=Ka;if((ga|0)>=(c[F>>2]|0)){xa=qa;ya=ga;break c}_=c[H>>2]|0;h[_+(ga*24|0)>>3]=va;h[_+(ga*24|0)+8>>3]=N;c[_+(ga*24|0)+16>>2]=Ka;xa=qa;ya=ga+1|0;break c}}while(0);do{if((ha|0)==0){Na=57}else{if((c[E>>2]|0)!=0){Na=57;break}if((c[l+(O+ha<<2)>>2]|0)==-16777216){Na=57}else{Oa=qa;Pa=0}}}while(0);if((Na|0)==57){Na=0;Ka=ca(fa,fa)|0;_=t-((c[e>>2]|0)/2|0)|0;Oa=r*+S(+((ca(_,_)|0)+Ka|0))/+(ba|0);Pa=1}Ka=c[A>>2]|0;_=Ka-8|0;za=Oa;Aa=Ba;Qa=Ca;La=0;while(1){if((La|0)>=(_|0)){Ra=La;Sa=Qa;Ta=Aa;Na=77;break}Ua=va+(Qa*Qa-Aa*Aa);Va=N+Qa*2.0*Aa;Wa=c[B>>2]|0;h[Wa+(La<<4)>>3]=Ua;h[Wa+(La<<4)+8>>3]=Va;ia=La|1;Xa=va+(Ua*Ua-Va*Va);Ya=N+Va*Ua*2.0;if(Pa){Fa=La>>1;Ua=+R(+(+h[Wa+(Fa<<4)>>3]-Xa));if(!(Ua+ +R(+(+h[Wa+(Fa<<4)+8>>3]-Ya))>za)){Ra=ia;Sa=Xa;Ta=Ya;Na=77;break}}h[Wa+(ia<<4)>>3]=Xa;h[Wa+(ia<<4)+8>>3]=Ya;ia=La|2;Ua=va+(Xa*Xa-Ya*Ya);Va=N+Ya*Xa*2.0;h[Wa+(ia<<4)>>3]=Ua;h[Wa+(ia<<4)+8>>3]=Va;ia=La|3;Xa=va+(Ua*Ua-Va*Va);Ya=N+Va*Ua*2.0;if(Pa){Fa=ia>>1;Ua=+R(+(+h[Wa+(Fa<<4)>>3]-Xa));if(!(Ua+ +R(+(+h[Wa+(Fa<<4)+8>>3]-Ya))>za)){Ra=ia;Sa=Xa;Ta=Ya;Na=77;break}}h[Wa+(ia<<4)>>3]=Xa;h[Wa+(ia<<4)+8>>3]=Ya;ia=La|4;Ua=va+(Xa*Xa-Ya*Ya);Va=N+Ya*Xa*2.0;h[Wa+(ia<<4)>>3]=Ua;h[Wa+(ia<<4)+8>>3]=Va;ia=La|5;Xa=va+(Ua*Ua-Va*Va);Ya=N+Va*Ua*2.0;if(Pa){Fa=ia>>1;Ua=+R(+(+h[Wa+(Fa<<4)>>3]-Xa));if(!(Ua+ +R(+(+h[Wa+(Fa<<4)+8>>3]-Ya))>za)){Ra=ia;Sa=Xa;Ta=Ya;Na=77;break}}h[Wa+(ia<<4)>>3]=Xa;h[Wa+(ia<<4)+8>>3]=Ya;ia=La|6;Ua=va+(Xa*Xa-Ya*Ya);Va=N+Ya*Xa*2.0;h[Wa+(ia<<4)>>3]=Ua;h[Wa+(ia<<4)+8>>3]=Va;Za=La|7;_a=va+(Ua*Ua-Va*Va);$a=N+Va*Ua*2.0;if(Pa){ia=Za>>1;Ua=+R(+(+h[Wa+(ia<<4)>>3]-_a));if(!(Ua+ +R(+(+h[Wa+(ia<<4)+8>>3]-$a))>za)){Ra=Za;Sa=_a;Ta=$a;Na=77;break}}h[Wa+(Za<<4)>>3]=_a;h[Wa+(Za<<4)+8>>3]=$a;ab=+h[C>>3];if(_a*_a+$a*$a>ab){Na=69;break}else{Aa=$a;Qa=_a;La=La+8|0}}e:do{if((Na|0)==69){Na=0;Qa=$a;Aa=_a;La=Za-((Za|0)<7?Za:7)|0;while(1){if((La|0)>=(Ka|0)){Ra=La;Sa=Aa;Ta=Qa;Na=77;break e}bb=+h[Wa+(La<<4)>>3];cb=+h[Wa+(La<<4)+8>>3];db=bb*bb+cb*cb;if(db>ab){break}else{Qa=cb;Aa=bb;La=La+1|0}}_=c[D>>2]|0;if((_|0)==0){Aa=+(La|0);ia=Lc(+((+V(Aa)+1.0)*127.0))|0;Fa=((Lc(+((+V(Aa/1.234)+1.0)*127.0))|0)<<16)+ia|0;eb=Fa+((Lc(+((+V(Aa/100.0)+1.0)*127.0))|0)<<8)|0;fb=cb;gb=Aa}else if((_|0)==1){Aa=+(La|0)+ +lc(+(+aa(ab)/+aa(db)));Fa=Lc(+((+V(Aa)+1.0)*127.0))|0;ia=((Lc(+((+V(Aa/1.234)+1.0)*127.0))|0)<<16)+Fa|0;eb=ia+((Lc(+((+V(Aa/100.0)+1.0)*127.0))|0)<<8)|0;fb=cb;gb=Aa}else if((_|0)==3){Aa=bb/ab;Qa=cb/ab;eb=~~(Aa*128.0+128.0)<<8&65280|~~(Qa*128.0+128.0)&255;fb=Qa;gb=Aa}else if((_|0)==2){hb=16777215;break}else{Ra=La;Sa=bb;Ta=cb;Na=77;break}if((eb|0)==0){Ra=La;Sa=gb;Ta=fb;Na=77}else{hb=eb}}}while(0);f:do{if((Na|0)==77){Na=0;Ka=c[E>>2]|0;if((Ka|0)==1){Aa=Oa*Oa*10.0;_=Ra;do{_=_-1|0;if((_|0)==0){hb=0;break f}ia=c[B>>2]|0;Qa=+h[ia+(_<<4)>>3]-Sa;za=+h[ia+(_<<4)+8>>3]-Ta;}while(!(Qa*Qa+za*za<Aa));La=Ra-_|0;hb=La<<5&224|La<<10&57344|La<<15&14680064;break}else if((Ka|0)==3){La=c[B>>2]|0;if((Ra|0)>0){Aa=9999.0;ia=0;Fa=Ra;while(1){la=Fa-1|0;za=+h[La+(la<<4)>>3];Qa=+h[La+(la<<4)+8>>3];Ua=za*za+Qa*Qa;Ea=Ua<Aa;Qa=Ea?Ua:Aa;Ma=Ea?la:ia;if((la|0)>0){Aa=Qa;ia=Ma;Fa=la}else{ib=Qa;jb=Ma;break}}}else{ib=9999.0;jb=0}Aa=+S(ib);Fa=Lc(+(wa+(+h[La+(jb<<4)>>3]/Aa+1.0)*127.0))|0;hb=((Lc(+(wa+(+h[(c[B>>2]|0)+(jb<<4)+8>>3]/Aa+1.0)*127.0))|0)<<8)+Fa|0;break}else if((Ka|0)==2){hb=~~(+Q(wa+ +(Ra|0)*255.0/+(c[A>>2]|0))*65793.0);break}else{hb=0;break}}}while(0);Fa=hb|-16777216;c[Y>>2]=Fa;if((ga|0)>=(c[F>>2]|0)){xa=Oa;ya=ga;break}ia=c[H>>2]|0;h[ia+(ga*24|0)>>3]=va;h[ia+(ga*24|0)+8>>3]=N;c[ia+(ga*24|0)+16>>2]=Fa;xa=Oa;ya=ga+1|0}}while(0);Y=ha+1|0;fa=c[w>>2]|0;if((Y|0)<(fa|0)){ga=ya;qa=xa;ha=Y;ba=fa}else{kb=ya;lb=xa;break}}}else{kb=P;lb=L}qa=y+N;ba=c[n>>2]|0;g:do{if(+h[ba+136>>3]!=0.0){mb=kb;nb=W}else{ha=ba+104|0;ga=ba+100|0;O=c[ga>>2]|0;if((W|0)>=(O|0)){mb=kb;nb=W;break}Z=ba+40|0;$=ba+4|0;da=ba+96|0;ea=ba+108|0;fa=kb;Y=W;Fa=O;while(1){O=c[ha>>2]|0;ia=O+(Y*24|0)|0;if(+h[O+(Y*24|0)+8>>3]>qa){mb=fa;nb=Y;break g}O=c[$>>2]|0;_=~~+Nb(+((+h[ia>>3]- +h[Z>>3])/r+ +((O|0)/2|0|0)));do{if((_|0)>=(O|0)|(_|0)<0){ob=fa;pb=Fa}else{if((fa|0)>=(c[da>>2]|0)){ob=fa;pb=Fa;break}Ma=(c[ea>>2]|0)+(fa*24|0)|0;la=ia;c[Ma>>2]=c[la>>2];c[Ma+4>>2]=c[la+4>>2];c[Ma+8>>2]=c[la+8>>2];c[Ma+12>>2]=c[la+12>>2];c[Ma+16>>2]=c[la+16>>2];c[Ma+20>>2]=c[la+20>>2];ob=fa+1|0;pb=c[ga>>2]|0}}while(0);ia=Y+1|0;if((ia|0)<(pb|0)){fa=ob;Y=ia;Fa=pb}else{mb=ob;nb=ia;break}}}}while(0);ba=c[e>>2]|0;if((d|0)<(ba|0)){I=nb;J=mb;K=ra;L=lb;t=d;M=ba}else{qb=mb;rb=H;sb=F;break}}}else{qb=0;rb=o+108|0;sb=o+96|0}F=o+104|0;H=c[F>>2]|0;c[F>>2]=c[rb>>2];c[rb>>2]=H;c[o+100>>2]=qb;if((qb|0)==(c[sb>>2]|0)){KIb(j,32,2247504,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}g=lj(a,f)|0;i=b;return g|0}function wv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=d+4|0;f=d+8|0;if((tIb(c[e>>2]|0,c[f>>2]|0,0,b)|0)<0){g=-22;return g|0}c[a+20>>2]=c[e>>2];c[a+24>>2]=c[f>>2];f=a+56|0;a=c[d+12>>2]|0;c[f>>2]=c[d+16>>2];c[f+4>>2]=a;g=0;return g|0}function xv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;g=f+32|0;j=c[g>>2]|0;k=c[g+4>>2]|0;l=-1;if((k|0)>(l|0)|(k|0)==(l|0)&j>>>0>-1>>>0){c[d>>2]=1;c[d+4>>2]=1e6;l=f+4|0;m=c[l>>2]|0;n=f+8|0;c[e>>2]=c[n>>2];c[e+4>>2]=m;m=XIb(j,k,d,e)|0;o=G;p=m;q=c[g+4>>2]|0;r=c[g>>2]|0;s=l;t=n}else{o=-1;p=-1;q=k;r=j;s=f+4|0;t=f+8|0}j=f+24|0;c[j>>2]=p;c[j+4>>2]=o;j=f+16|0;c[j>>2]=0;c[j+4>>2]=0;j=c[s>>2]|0;s=c[t>>2]|0;t=0;if((q|0)<(t|0)|(q|0)==(t|0)&r>>>0<0>>>0){u=-1.0}else{u=(+(p>>>0)+ +(o|0)*4294967296.0)*(+(s|0)/+(j|0))}KIb(a,40,2414912,(a=i,i=i+24|0,c[a>>2]=j,c[a+8>>2]=s,h[a+16>>3]=u,a)|0);i=a;a=0;do{u=(a|0)==0?.3535533905932738:.5;v=+(a|0)*.39269908169872414;s=a<<3;h[9881472+(s<<3)>>3]=+U(v*.5)*u;h[9881472+((s|1)<<3)>>3]=u*+U(v*1.5);h[9881472+((s|2)<<3)>>3]=u*+U(v*2.5);h[9881472+((s|3)<<3)>>3]=u*+U(v*3.5);h[9881472+((s|4)<<3)>>3]=u*+U(v*4.5);h[9881472+((s|5)<<3)>>3]=u*+U(v*5.5);h[9881472+((s|6)<<3)>>3]=u*+U(v*6.5);h[9881472+((s|7)<<3)>>3]=u*+U(v*7.5);a=a+1|0;}while((a|0)<8);i=b;return 0}function yv(a){a=a|0;dl(a,Ok(684272)|0);return 0}function zv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0.0,L=0.0;d=c[(c[b>>2]|0)+44>>2]|0;e=-(-512>>c[d+40>>2])|0;f=-512>>c[d+44>>2];g=-f|0;h=c[b+160>>2]|0;i=c[d+48>>2]|0;j=d+24|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=-1;do{if((l|0)>(j|0)|(l|0)==(j|0)&k>>>0>-1>>>0){m=d+16|0;n=c[m+4>>2]|0;if((n|0)>(l|0)|(n|0)==(l|0)&(c[m>>2]|0)>>>0>k>>>0){o=-541478725}else{break}return o|0}}while(0);k=bv(b,512,512)|0;if((k|0)==0){o=-12;return o|0}l=d+16|0;d=c[l>>2]|0;j=c[l+4>>2]|0;m=wrc(d,j,1,0)|0;c[l>>2]=m;c[l+4>>2]=G;l=k+136|0;c[l>>2]=d;c[l+4>>2]=j;j=k|0;l=k+32|0;d=0;do{mrc((c[j>>2]|0)+(ca(c[l>>2]|0,d)|0)|0,0,512)|0;d=d+1|0;}while((d|0)<512);if((f|0)<0){f=k+4|0;d=k+36|0;m=k+8|0;n=k+40|0;p=0;do{mrc((c[f>>2]|0)+(ca(c[d>>2]|0,p)|0)|0,-128|0,e|0)|0;mrc((c[m>>2]|0)+(ca(c[n>>2]|0,p)|0)|0,-128|0,e|0)|0;p=p+1|0;}while((p|0)<(g|0))}do{if((i|0)==10){if(((h>>>0)%30|0|0)==0){break}q=(((h>>>0)/30|0)>>>0)%10|0;r=12}else{q=i;r=12}}while(0);a:do{if((r|0)==12){switch(q|0){case 0:{i=c[j>>2]|0;g=c[l>>2]|0;p=0;e=(h>>>0)%30|0;while(1){n=ca(p,g)|0;m=ca(p|1,g)|0;d=ca(p|2,g)|0;f=ca(p|3,g)|0;s=ca(p|4,g)|0;t=ca(p|5,g)|0;u=ca(p|6,g)|0;v=ca(p|7,g)|0;w=0;x=e;while(1){y=x&255;mrc(i+(w+n)|0,y|0,8)|0;mrc(i+(w+m)|0,y|0,8)|0;mrc(i+(w+d)|0,y|0,8)|0;mrc(i+(w+f)|0,y|0,8)|0;mrc(i+(w+s)|0,y|0,8)|0;mrc(i+(w+t)|0,y|0,8)|0;mrc(i+(w+u)|0,y|0,8)|0;mrc(i+(w+v)|0,y|0,8)|0;y=w+16|0;if((y|0)<256){w=y;x=x+1|0}else{break}}x=p+16|0;if((x|0)<256){p=x;e=e+16|0}else{break}}break};case 8:{e=c[j>>2]|0;p=c[l>>2]|0;i=(h>>>0)%30|0;g=16-(i>>>4)|0;x=i;w=0;while(1){v=ca(x,p)|0;u=ca(x+1|0,p)|0;t=ca(x+2|0,p)|0;s=ca(x+3|0,p)|0;f=ca(x+4|0,p)|0;d=ca(x+5|0,p)|0;m=ca(x+6|0,p)|0;n=ca(x+7|0,p)|0;y=ca(x+8|0,p)|0;z=ca(x+9|0,p)|0;A=ca(x+10|0,p)|0;B=ca(x+11|0,p)|0;C=ca(x+12|0,p)|0;D=ca(x+13|0,p)|0;E=ca(x+14|0,p)|0;F=ca(x+15|0,p)|0;H=i;I=w;while(1){J=((H+x&16|0)!=0?I:-I|0)&255;mrc(e+(H+v)|0,J|0,16)|0;mrc(e+(H+u)|0,J|0,16)|0;mrc(e+(H+t)|0,J|0,16)|0;mrc(e+(H+s)|0,J|0,16)|0;mrc(e+(H+f)|0,J|0,16)|0;mrc(e+(H+d)|0,J|0,16)|0;mrc(e+(H+m)|0,J|0,16)|0;mrc(e+(H+n)|0,J|0,16)|0;mrc(e+(H+y)|0,J|0,16)|0;mrc(e+(H+z)|0,J|0,16)|0;mrc(e+(H+A)|0,J|0,16)|0;mrc(e+(H+B)|0,J|0,16)|0;mrc(e+(H+C)|0,J|0,16)|0;mrc(e+(H+D)|0,J|0,16)|0;mrc(e+(H+E)|0,J|0,16)|0;mrc(e+(H+F)|0,J|0,16)|0;J=H+16|0;if((J|0)<256){H=J;I=I+1|0}else{break}}I=x+16|0;if((I|0)<256){x=I;w=g+w|0}else{break}}break};case 9:{w=c[j>>2]|0;g=c[l>>2]|0;K=+((h>>>0)%30|0|0)/30.0;x=0;do{e=x-128|0;i=ca(e,e)|0;e=ca(x,g)|0;p=0;do{I=p-128|0;L=+S(+((ca(I,I)|0)+i|0))/20.0;if(L- +(~~L|0)<K){I=p+e|0;a[w+I|0]=-1;a[w+(I+256)|0]=0}else{I=p&255;H=p+e|0;a[w+H|0]=I;a[w+(H+256)|0]=I}p=p+1|0;}while((p|0)<256);x=x+1|0;}while((x|0)<256);break};case 2:{Bv(c[j>>2]|0,c[l>>2]|0,(h>>>0)%30|0);break a;break};case 3:{Bv(c[k+4>>2]|0,c[k+36>>2]|0,(h>>>0)%30|0);break a;break};case 4:{x=c[j>>2]|0;w=c[l>>2]|0;g=0;p=(h>>>0)%30|0;while(1){e=ca(g,w)|0;i=0;I=p;while(1){Cv(x+(i+e)|0,w,I<<2,1);H=i+16|0;if((H|0)<256){i=H;I=I+1|0}else{break}}I=g+16|0;if((I|0)<256){g=I;p=p+16|0}else{break}}break};case 5:{p=c[k+4>>2]|0;g=c[k+36>>2]|0;w=0;x=(h>>>0)%30|0;while(1){I=ca(w,g)|0;i=0;e=x;while(1){Cv(p+(i+I)|0,g,e<<2,1);H=i+16|0;if((H|0)<256){i=H;e=e+1|0}else{break}}e=w+16|0;if((e|0)<256){w=e;x=x+16|0}else{break}}break};case 6:{x=k+4|0;w=k+36|0;g=k+8|0;p=k+40|0;e=((h>>>0)%30|0)<<2|256;i=0;I=0;while(1){H=i<<1;F=0;E=I;while(1){D=c[j>>2]|0;C=c[l>>2]|0;B=(ca(H,C)|0)+(F<<1)|0;A=(c[x>>2]|0)+((ca(c[w>>2]|0,i)|0)+F)|0;z=(c[g>>2]|0)+((ca(c[p>>2]|0,i)|0)+F)|0;if((E&1|0)!=0){Cv(D+B|0,C,e,1)}if((E&2|0)!=0){Cv(D+(B|8)|0,c[l>>2]|0,e,1)}if((E&4|0)!=0){C=c[l>>2]|0;Cv(D+((C<<3)+B)|0,C,e,1)}if((E&8|0)!=0){C=c[l>>2]|0;Cv(D+((C<<3)+(B|8))|0,C,e,1)}if((E&16|0)!=0){Cv(A,c[w>>2]|0,e,1)}if((E&32|0)!=0){Cv(z,c[p>>2]|0,e,1)}z=F+16|0;if((z|0)>=128){break}F=z;E=E+1|0}E=i+16|0;if((E|0)<128){i=E;I=I+8|0}else{break}}break};case 7:{I=c[j>>2]|0;i=c[l>>2]|0;e=((h>>>0)%30|0)<<3;p=0;do{if((p&16|0)==0){w=(e|0)/(((p|0)/32|0)+1|0)|0;g=ca(p,i)|0;x=0;do{a[I+(x+g)|0]=x+w;x=x+1|0;}while((x|0)<256)}p=p+1|0;}while((p|0)<256);break};case 1:{p=c[k+4>>2]|0;I=c[k+36>>2]|0;i=0;e=(h>>>0)%30|0;while(1){x=ca(i,I)|0;w=ca(i|1,I)|0;g=ca(i|2,I)|0;E=ca(i|3,I)|0;F=ca(i|4,I)|0;H=ca(i|5,I)|0;z=ca(i|6,I)|0;A=ca(i|7,I)|0;C=0;B=e;while(1){D=B&255;mrc(p+(C+x)|0,D|0,8)|0;mrc(p+(C+w)|0,D|0,8)|0;mrc(p+(C+g)|0,D|0,8)|0;mrc(p+(C+E)|0,D|0,8)|0;mrc(p+(C+F)|0,D|0,8)|0;mrc(p+(C+H)|0,D|0,8)|0;mrc(p+(C+z)|0,D|0,8)|0;mrc(p+(C+A)|0,D|0,8)|0;D=C+16|0;if((D|0)<256){C=D;B=B+1|0}else{break}}B=i+16|0;if((B|0)<256){i=B;e=e+16|0}else{break}}break};default:{break a}}}}while(0);o=lj(b,k)|0;return o|0}function Av(a){a=a|0;var b=0,e=0;b=c[(c[a>>2]|0)+44>>2]|0;e=qKb(c[a+52>>2]|0)|0;c[b+40>>2]=d[e+5|0]|0;c[b+44>>2]=d[e+6|0]|0;c[a+20>>2]=512;c[a+24>>2]=512;e=a+56|0;a=c[b+4>>2]|0;c[e>>2]=c[b+8>>2];c[e+4>>2]=a;return 0}function Bv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=(c<<2)+384|0;c=0;e=0;while(1){f=ca(c,b)|0;Cv(a+f|0,b,d,e);g=e|1;Cv(a+(f+16)|0,b,d,g);Cv(a+(f+32)|0,b,d,g+1|0);g=e|3;Cv(a+(f+48)|0,b,d,g);Cv(a+(f+64)|0,b,d,g+1|0);Cv(a+(f+80)|0,b,d,g+2|0);Cv(a+(f+96)|0,b,d,g+3|0);Cv(a+(f+112)|0,b,d,e|7);f=c+16|0;if((f|0)<128){c=f;e=e+8|0}else{break}}return}function Cv(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0,u=0,v=0;g=i;i=i+768|0;j=g|0;k=g+512|0;mrc(k|0,0,256)|0;c[k>>2]=1024;if((e|0)!=0){c[k+(f<<2)>>2]=e}e=0;while(1){f=e<<3;l=+(c[k+(f<<2)>>2]|0);m=+(c[k+((f|1)<<2)>>2]|0);n=+(c[k+((f|2)<<2)>>2]|0);o=+(c[k+((f|3)<<2)>>2]|0);p=+(c[k+((f|4)<<2)>>2]|0);q=+(c[k+((f|5)<<2)>>2]|0);r=+(c[k+((f|6)<<2)>>2]|0);s=+(c[k+((f|7)<<2)>>2]|0);t=0;do{h[j+(t+f<<3)>>3]=l*+h[9881472+(t<<3)>>3]+0.0+ +h[9881472+(t+8<<3)>>3]*m+ +h[9881472+(t+16<<3)>>3]*n+ +h[9881472+(t+24<<3)>>3]*o+ +h[9881472+(t+32<<3)>>3]*p+ +h[9881472+(t+40<<3)>>3]*q+ +h[9881472+(t+48<<3)>>3]*r+ +h[9881472+(t+56<<3)>>3]*s;t=t+1|0;}while((t|0)<8);t=e+1|0;if((t|0)<8){e=t}else{u=0;break}}do{s=+h[j+(u<<3)>>3];r=+h[j+(u+8<<3)>>3];q=+h[j+(u+16<<3)>>3];p=+h[j+(u+24<<3)>>3];o=+h[j+(u+32<<3)>>3];n=+h[j+(u+40<<3)>>3];m=+h[j+(u+48<<3)>>3];l=+h[j+(u+56<<3)>>3];e=0;do{k=~~+Q(s*+h[9881472+(e<<3)>>3]+0.0+ +h[9881472+(e+8<<3)>>3]*r+ +h[9881472+(e+16<<3)>>3]*q+ +h[9881472+(e+24<<3)>>3]*p+ +h[9881472+(e+32<<3)>>3]*o+ +h[9881472+(e+40<<3)>>3]*n+ +h[9881472+(e+48<<3)>>3]*m+ +h[9881472+(e+56<<3)>>3]*l+.5);if((k|0)<0){v=0}else{v=(k|0)>255?-1:k&255}a[b+((ca(e,d)|0)+u)|0]=v;e=e+1|0;}while((e|0)<8);u=u+1|0;}while((u|0)<8);i=g;return}function Dv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+68>>2]=670;c[e+56>>2]=1;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;KIb(a,40,2542536,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Ev(a){a=a|0;VHb((c[a+44>>2]|0)+64|0);return}function Fv(a){a=a|0;dl(a,Qz(0)|0);return 0}function Gv(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0;h=i;i=i+8|0;g=h|0;f=c[b+44>>2]|0;do{if((irc(d,2274736)|0)!=0){if((irc(d,2310832)|0)==0){break}else{j=-38}i=h;return j|0}}while(0);d=dKb(g,e,-1,b)|0;if((d|0)<0){j=d;i=h;return j|0}d=f+140|0;b=d;y=c[g>>2]|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;Mz(f+76|0,f+120|0,d);c[f+60>>2]=1;j=0;i=h;return j|0}function Hv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+68>>2]=8;c[e+56>>2]=1;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;KIb(a,40,2542536,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Iv(a){a=a|0;dl(a,Ok(1142920)|0);return 0}function Jv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;c[(c[d>>2]|0)+68>>2]=118;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;KIb(a,40,2542536,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Kv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;c[(c[d>>2]|0)+68>>2]=594;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;KIb(a,40,2542536,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Lv(a){a=a|0;dl(a,Ok(310904)|0);return 0}function Mv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+56>>2]=1;c[e+68>>2]=182;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;KIb(a,40,2542536,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Nv(a){a=a|0;dl(a,Ok(679456)|0);return 0}function Ov(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+68>>2]=44;c[e+56>>2]=1;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;KIb(a,40,2542536,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Pv(a){a=a|0;dl(a,Ok(563216)|0);return 0}function Qv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e+68>>2]=282;c[e+56>>2]=1;e=c[d>>2]|0;d=c[e+24>>2]|0;f=c[e+28>>2]|0;g=e+16|0;c[g>>2]=f;c[g+4>>2]=d;c[e+12>>2]=0;g=e+32|0;c[g>>2]=0;c[g+4>>2]=0;g=c[e+8>>2]|0;j=e+40|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&k>>>0<0>>>0){m=-1.0}else{m=(+(k>>>0)+ +(l|0)*4294967296.0)/1.0e6}l=c[e+48>>2]|0;k=c[e+52>>2]|0;KIb(a,40,2542536,(a=i,i=i+56|0,c[a>>2]=c[e+4>>2],c[a+8>>2]=g,c[a+16>>2]=d,c[a+24>>2]=f,h[a+32>>3]=m,c[a+40>>2]=l,c[a+48>>2]=k,a)|0);i=a;i=b;return 0}function Rv(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+8|0;g=f|0;h=c[b+44>>2]|0;b=h;j=qKb(c[e+80>>2]|0)|0;NHb(e,1);k=h+4|0;l=j+5|0;m=1<<(d[l]|0);n=((c[k>>2]|0)/8|0)-1+m&-m;m=h+8|0;h=j+6|0;j=1<<(d[h]|0);o=(((c[m>>2]|0)*7|0|0)/12|0)-1+j&-j;Sv(b,1146944,0,0,n,o,e);j=1<<(d[l]|0);p=(((((c[k>>2]|0)+3|0)/4|0)*3|0|0)/7|0)-1+j&-j;Sv(b,682712,n,0,p,o,e);j=n+p|0;Sv(b,682716,j,0,p,o,e);q=j+p|0;Sv(b,682720,q,0,p,o,e);r=q+p|0;Sv(b,682724,r,0,p,o,e);q=r+p|0;Sv(b,682728,q,0,p,o,e);r=q+p|0;Sv(b,682732,r,0,p,o,e);Sv(b,682736,r+p|0,0,p,o,e);r=g;q=n+(p*7|0)|0;Sv(b,1146944,q,0,(c[k>>2]|0)-q|0,o,e);q=1<<(d[h]|0);h=((c[m>>2]|0)/12|0)-1+q&-q;Sv(b,1617576,0,o,n,h,e);Sv(b,1077760,n,o,p,h,e);q=p*6|0;Sv(b,682712,j,o,q,h,e);s=j+q|0;Sv(b,1900752,s,o,(c[k>>2]|0)-s|0,h,e);t=h+o|0;Sv(b,1224,0,t,n,h,e);Sv(b,696304,n,t,p,h,e);if((q|0)>0){o=g;u=r+1|0;v=r+2|0;w=r+3|0;r=0;x=j;y=a[l]|0;while(1){c[g>>2]=0;a[o]=(r*255|0|0)/(q|0)|0;a[u]=-128;a[v]=-128;a[w]=-1;Sv(b,o,x,t,1<<(y&255),h,e);z=a[l]|0;A=1<<(z&255);B=A+x|0;C=A+r|0;if((C|0)<(q|0)){r=C;x=B;y=z}else{D=B;break}}}else{D=j}Sv(b,682096,D,t,(c[k>>2]|0)-D|0,h,e);D=t+h|0;Sv(b,1146952,0,D,n,(c[m>>2]|0)-D|0,e);h=1<<(d[l]|0);t=((p*3|0|0)/2|0)-1+h&-h;Sv(b,1904904,n,D,t,(c[m>>2]|0)-D|0,e);h=t+n|0;n=1<<(d[l]|0);t=(p<<1)-1+n&-n;Sv(b,152152,h,D,t,(c[m>>2]|0)-D|0,e);n=t+h|0;h=1<<(d[l]|0);t=((p*5|0|0)/6|0)-1+h&-h;Sv(b,1904904,n,D,t,(c[m>>2]|0)-D|0,e);h=t+n|0;n=1<<(d[l]|0);l=((p|0)/3|0)-1+n&-n;Sv(b,785600,h,D,l,(c[m>>2]|0)-D|0,e);n=l+h|0;Sv(b,1904904,n,D,l,(c[m>>2]|0)-D|0,e);h=n+l|0;Sv(b,1904896,h,D,l,(c[m>>2]|0)-D|0,e);n=h+l|0;Sv(b,1904904,n,D,l,(c[m>>2]|0)-D|0,e);h=n+l|0;Sv(b,1904888,h,D,l,(c[m>>2]|0)-D|0,e);n=h+l|0;Sv(b,1904904,n,D,s-n|0,(c[m>>2]|0)-D|0,e);Sv(b,1146952,s,D,(c[k>>2]|0)-s|0,(c[m>>2]|0)-D|0,e);i=f;return}function Sv(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=i;m=qKb(c[k+80>>2]|0)|0;n=c[b+4>>2]|0;o=n-1|0;p=o>>>0<f>>>0?o:f;f=c[b+8>>2]|0;b=f-1|0;o=b>>>0<g>>>0?b:g;g=n-p|0;b=g>>>0<h>>>0?g:h;h=f-o|0;g=h>>>0<j>>>0?h:j;if((b+p|0)>>>0>n>>>0){KIb(0,0,2525032,(q=i,i=i+24|0,c[q>>2]=2509904,c[q+8>>2]=2495864,c[q+16>>2]=850,q)|0);i=q;Hd()}if((g+o|0)>>>0>f>>>0){KIb(0,0,2525032,(q=i,i=i+24|0,c[q>>2]=2485080,c[q+8>>2]=2495864,c[q+16>>2]=851,q)|0);i=q;Hd()}q=c[k>>2]|0;if((q|0)==0){i=l;return}f=m+5|0;n=m+6|0;m=0;j=q;do{q=c[k+32+(m<<2)>>2]|0;if((m-1|0)>>>0<2>>>0){h=d[f]|0;r=d[n]|0;s=g>>>(r>>>0);t=b>>>(h>>>0);u=o>>>(r>>>0);v=p>>>(h>>>0)}else{s=g;t=b;u=o;v=p}h=(ca(u,q)|0)+v|0;r=j+h|0;mrc(r|0,a[e+m|0]|0,t|0)|0;if((s|0)>1){w=j+(h+q)|0;h=1;while(1){nrc(w|0,r|0,t)|0;x=h+1|0;if((x|0)<(s|0)){w=w+q|0;h=x}else{break}}}m=m+1|0;j=c[k+(m<<2)>>2]|0;}while((j|0)!=0);i=l;return}function Tv(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[a+44>>2]|0;a=e;f=qKb(c[b+80>>2]|0)|0;NHb(b,5);g=e+4|0;h=f+5|0;i=1<<(d[h]|0);j=-i|0;k=(((c[g>>2]|0)+6|0)/7|0)-1+i&j;l=c[e+8>>2]|0;e=1<<(d[f+6|0]|0);f=-e|0;m=((l<<1|0)/3|0)-1+e&f;n=((l*3|0|0)/4|0)-1+e-m&f;f=k*5|0;e=i-1+((f|0)/4|0)|0;i=l-n|0;l=0;o=0;while(1){Sv(a,682712+(o<<2)|0,l,0,k,m,b);Sv(a,111224+(o<<2)|0,l,m,k,n,b);p=o+1|0;if((p|0)<7){l=l+k|0;o=p}else{break}}o=e&j;j=i-m|0;i=n+m|0;Sv(a,1077760,0,i,o,j,b);Sv(a,152152,o,i,o,j,b);m=o<<1;Sv(a,696304,m,i,o,j,b);n=m+o|0;o=1<<(d[h]|0);m=f-1-n+o&-o;Sv(a,1904912,n,i,m,j,b);o=m+n|0;n=1<<(d[h]|0);h=((k|0)/3|0)-1+n&-n;Sv(a,785592,o,i,h,j,b);n=h+o|0;Sv(a,1904912,n,i,h,j,b);o=n+h|0;Sv(a,704120,o,i,h,j,b);n=o+h|0;Sv(a,1904912,n,i,(c[g>>2]|0)-n|0,j,b);return}function Uv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+8|0;d=b|0;e=a|0;f=c[(c[e>>2]|0)+44>>2]|0;g=f+40|0;h=c[g+4>>2]|0;j=-1;do{if((h|0)>(j|0)|(h|0)==(j|0)&(c[g>>2]|0)>>>0>-1>>>0){k=f+32|0;l=c[k>>2]|0;m=c[k+4>>2]|0;c[d>>2]=1;c[d+4>>2]=1e6;k=XIb(l,m,f+16|0,d)|0;m=G;l=c[g+4>>2]|0;if((m|0)<(l|0)|(m|0)==(l|0)&k>>>0<(c[g>>2]|0)>>>0){break}else{n=-541478725}i=b;return n|0}}while(0);g=f+56|0;if((c[g>>2]|0)==0){o=bv(a,c[f+4>>2]|0,c[f+8>>2]|0)|0}else{d=f+60|0;j=f+64|0;if((c[d>>2]|0)!=0){VHb(j);c[d>>2]=0}d=c[j>>2]|0;do{if((d|0)==0){h=bv(a,c[f+4>>2]|0,c[f+8>>2]|0)|0;c[j>>2]=h;if((h|0)==0){n=-12;i=b;return n|0}else{re[c[f+68>>2]&1023](c[e>>2]|0,h);p=c[j>>2]|0;break}}else{p=d}}while(0);o=$Hb(p)|0}if((o|0)==0){n=-12;i=b;return n|0}p=f+32|0;d=c[p+4>>2]|0;j=o+136|0;c[j>>2]=c[p>>2];c[j+4>>2]=d;c[o+84>>2]=1;c[o+296>>2]=0;c[o+88>>2]=1;d=f+48|0;j=o+124|0;h=c[d+4>>2]|0;c[j>>2]=c[d>>2];c[j+4>>2]=h;if((c[g>>2]|0)==0){re[c[f+68>>2]&1023](c[e>>2]|0,o)}e=wrc(c[p>>2]|0,c[p+4>>2]|0,1,0)|0;c[p>>2]=e;c[p+4>>2]=G;p=f+12|0;c[p>>2]=(c[p>>2]|0)+1;n=lj(a,o)|0;i=b;return n|0}function Vv(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[(c[a>>2]|0)+44>>2]|0;c[a+20>>2]=c[b+4>>2];c[a+24>>2]=c[b+8>>2];d=b+48|0;e=a+28|0;f=c[d+4>>2]|0;c[e>>2]=c[d>>2];c[e+4>>2]=f;f=b+24|0;e=a+116|0;d=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=d;d=b+16|0;b=a+56|0;a=c[d+4>>2]|0;c[b>>2]=c[d>>2];c[b+4>>2]=a;return 0}function Wv(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=c[e+44>>2]|0;h=c[f+68>>2]|0;i=c[f+72>>2]|0;if((i|0)<=0){return}j=(h|0)>0;k=f|0;l=f+32|0;f=e+32|0;e=g+144|0;m=g+145|0;n=g+146|0;o=g+147|0;g=i<<1;p=0;do{a:do{if(j){q=p*3|0;r=(q|0)<(g|0);if((q|0)<(i|0)){q=0;while(1){s=(q<<8|0)/(h|0)|0;t=c[k>>2]|0;u=c[l>>2]|0;switch(c[(c[c[f>>2]>>2]|0)+52>>2]|0){case 46:{b[t+(ca(u,p)|0)+(q<<1)>>1]=s>>>3;break};case 2:case 3:{v=s<<((d[e]|0)<<3);w=(ca(u,p)|0)+(q*3|0)|0;a[t+w|0]=v;a[t+(w+1)|0]=v>>>8;a[t+(w+2)|0]=v>>>16;break};case 50:{b[t+(ca(u,p)|0)+(q<<1)>>1]=s>>>3<<10;break};case 44:{b[t+(ca(u,p)|0)+(q<<1)>>1]=s>>>3;break};case 62:{b[t+(ca(u,p)|0)+(q<<1)>>1]=s>>>4;break};case 64:{b[t+(ca(u,p)|0)+(q<<1)>>1]=s>>>4<<8;break};case 28:case 30:case 27:case 29:{v=t+((ca(u,p)|0)+(q<<2))|0;y=(s<<((d[e]|0)<<3))+(255<<((d[o]|0)<<3))|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;break};case 48:{b[t+(ca(u,p)|0)+(q<<1)>>1]=s>>>3<<11;break};default:{}}q=q+1|0;if((q|0)>=(h|0)){break a}}}else{q=0;while(1){s=(q<<8|0)/(h|0)|0;u=r?s:0;t=r?0:s;s=c[k>>2]|0;v=c[l>>2]|0;switch(c[(c[c[f>>2]>>2]|0)+52>>2]|0){case 64:{b[s+(ca(v,p)|0)+(q<<1)>>1]=u&65520|t>>>4;break};case 46:{b[s+(ca(v,p)|0)+(q<<1)>>1]=u>>>3<<5|t>>>3<<10;break};case 50:{b[s+(ca(v,p)|0)+(q<<1)>>1]=u>>>3<<5|t>>>3;break};case 62:{b[s+(ca(v,p)|0)+(q<<1)>>1]=u&65520|t>>>4<<8;break};case 28:case 30:case 27:case 29:{w=s+((ca(v,p)|0)+(q<<2))|0;y=(u<<((d[m]|0)<<3))+(t<<((d[n]|0)<<3))+(255<<((d[o]|0)<<3))|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;break};case 2:case 3:{w=(u<<((d[m]|0)<<3))+(t<<((d[n]|0)<<3))|0;x=(ca(v,p)|0)+(q*3|0)|0;a[s+x|0]=w;a[s+(x+1)|0]=w>>>8;a[s+(x+2)|0]=w>>>16;break};case 48:{b[s+(ca(v,p)|0)+(q<<1)>>1]=u>>>2<<5|t>>>3;break};case 44:{b[s+(ca(v,p)|0)+(q<<1)>>1]=u>>>2<<5|t>>>3<<11;break};default:{}}q=q+1|0;if((q|0)>=(h|0)){break a}}}}}while(0);p=p+1|0;}while((p|0)<(i|0));return}function Xv(a){a=a|0;var b=0,d=0,e=0,f=0;b=a|0;Kz((c[(c[b>>2]|0)+44>>2]|0)+144|0,c[a+52>>2]|0)|0;d=c[(c[b>>2]|0)+44>>2]|0;c[a+20>>2]=c[d+4>>2];c[a+24>>2]=c[d+8>>2];b=d+48|0;e=a+28|0;f=c[b+4>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=f;f=d+24|0;e=a+116|0;b=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=b;b=d+16|0;d=a+56|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;return 0}function Yv(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;f=c[b+44>>2]|0;b=c[e>>2]|0;g=c[e+68>>2]|0;h=c[e+72>>2]|0;i=(h+g|0)/4|0;do{if((h|0)>0){j=((ca(h,h)|0)>>>2)+((ca(g,g)|0)>>>2)-(ca(i,i)|0)|0;k=1-g|0;l=e+32|0;if((g|0)>0){m=j;n=1-h|0;o=0;p=b}else{q=l;break}while(1){j=m;r=k;s=0;t=0;u=0;v=p;while(1){w=(j|0)<0?t^7:t;a[v]=w<<31>>31;a[v+1|0]=w<<30>>31;a[v+2|0]=w<<29>>31;w=s+8|0;if((w|0)<(g|0)){x=t;y=w}else{x=t+1|0;y=w-g|0}w=u+1|0;if((w|0)<(g|0)){j=r+j|0;r=r+2|0;s=y;t=x;u=w;v=v+3|0}else{break}}v=o+1|0;if((v|0)<(h|0)){m=n+m|0;n=n+2|0;o=v;p=p+(c[l>>2]|0)|0}else{q=l;break}}}else{q=e+32|0}}while(0);e=b+(ca((h*3|0|0)/4|0,c[q>>2]|0)|0)|0;p=f+12|0;o=f+16|0;n=f+20|0;m=1536/(g|0)|0;x=1536%(g|0)|0;if((g|0)>0){y=((((ca(c[p>>2]<<8,c[o>>2]|0)|0)>>>0)/((c[n>>2]|0)>>>0)|0)>>>0)%1536|0;i=0;l=0;k=e;while(1){v=(y|0)<256;u=y-256|0;do{if(u>>>0>1023>>>0){z=-1;A=15}else{if((y-512|0)>>>0<512>>>0){a[k]=0;B=k+1|0;A=17;break}else{z=((y|0)<512?511-y|0:y)&255;A=15;break}}}while(0);do{if((A|0)==15){A=0;t=k+1|0;a[k]=z;if((y|0)<=1023){B=t;A=17;break}a[t]=0;C=k+2|0;A=20}}while(0);if((A|0)==17){A=0;if(u>>>0<512>>>0){D=-1}else{D=(v?y:1023-y|0)&255}t=k+2|0;a[B]=D;if((y|0)<512){E=0;F=t}else{C=t;A=20}}do{if((A|0)==20){A=0;if((y-768|0)>>>0<512>>>0){E=-1;F=C;break}E=((y|0)<768?y:1535-y|0)&255;F=C}}while(0);a[F]=E;v=y+m|0;u=i+x|0;if((u|0)>1535){H=u-1536|0;I=v+1|0}else{H=u;I=v}v=l+1|0;if((v|0)<(g|0)){y=(I|0)>1535?I-1536|0:I;i=H;l=v;k=k+3|0}else{break}}}if((h|0)>7){k=g*3|0;l=(h|0)/8|0;H=e;e=c[q>>2]|0;while(1){nrc(H+e|0,H|0,k)|0;i=c[q>>2]|0;I=l-1|0;if((I|0)>0){l=I;H=H+i|0;e=i}else{break}}}e=(g|0)/80|0;if((g|0)<=79){return}H=e*13|0;if((h|0)<(H|0)){return}l=c[o>>2]|0;o=c[n>>2]|0;n=c[p>>2]|0;p=c[f+72>>2]|0;if(!(+(l|0)/+(o|0)*+(n>>>0>>>0)*+T(+10.0,+(+(p|0)))<2147483647.0)){return}if((p|0)>0){f=0;k=0;i=1;while(1){I=Erc(i,k,10,0)|0;y=G;x=f+1|0;if((x|0)<(p|0)){f=x;k=y;i=I}else{J=y;K=I;break}}}else{J=0;K=1}i=ca(l,n)|0;n=UIb(i,0,K,J,o,(o|0)<0|0?-1:0,0)|0;o=c[q>>2]|0;J=e*-24|0;K=e*3|0;i=e*24|0;l=(H|0)>0;k=n;n=1;f=b+((ca(o,(h-H|0)/2|0)|0)+((g-((g-(e<<6)|0)/2|0)|0)*3|0))|0;g=o;while(1){o=f+J|0;h=d[1520296+((k|0)%10|0)|0]|0;if(l){b=0;p=o;while(1){mrc(p|0,0,i|0)|0;I=b+1|0;if((I|0)<(H|0)){b=I;p=p+g|0}else{L=0;break}}}else{L=0}do{do{if((1<<L&h|0)!=0){p=ca(K,c[1520192+(L<<4)>>2]|0)|0;b=ca(c[1520196+(L<<4)>>2]|0,e)|0;if((b|0)<=0){break}I=0;y=f+(ca((ca(c[1520188+(L<<4)>>2]|0,g)|0)-24+((c[1520184+(L<<4)>>2]|0)*3|0)|0,e)|0)|0;while(1){mrc(y|0,-1|0,p|0)|0;x=I+1|0;if((x|0)<(b|0)){I=x;y=y+g|0}else{break}}}}while(0);L=L+1|0;}while(L>>>0<7>>>0);if(!((k+9|0)>>>0>18>>>0&(n|0)<8)){break}k=(k|0)/10|0;n=n+1|0;f=o;g=c[q>>2]|0}return}function Zv(a,b){a=a|0;b=b|0;return}function _v(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;i=i+8|0;h=g|0;j=c[(c[e+44>>2]|0)+148>>2]|0;e=c[f+68>>2]|0;k=c[f+72>>2]|0;l=c[f>>2]|0;m=c[f+32>>2]|0;n=f+80|0;f=qKb(c[n>>2]|0)|0;if((e|0)!=(k|0)){KIb(0,0,2525032,(o=i,i=i+24|0,c[o>>2]=2325744,c[o+8>>2]=2495864,c[o+16>>2]=300,o)|0);i=o;Hd()}k=ca(j,j)|0;if((e|0)!=(ca(k,j)|0)){KIb(0,0,2525032,(o=i,i=i+24|0,c[o>>2]=2325744,c[o+8>>2]=2495864,c[o+16>>2]=300,o)|0);i=o;Hd()}o=h|0;Kz(o,c[n>>2]|0)|0;switch(c[n>>2]|0){case 28:case 30:case 27:case 29:{p=0;q=255;r=-1;break};case 42:case 68:case 292:case 294:{p=1;q=-1;r=-1;break};default:{p=0;q=0;r=0}}n=(pKb(f)|0)>>p+3;s=(+(1<<(p<<3)+8|0)+-1.0)/+(k-1|0);if((k|0)==0){i=g;return}f=(p|0)==0;p=h+1|0;j=h+2|0;t=(n|0)==4;u=h+3|0;h=0;v=0;w=0;while(1){x=~~(s*+(w|0));y=x>>>0>255>>>0;z=-x>>31;A=x>>>0>65535>>>0;B=h;C=v;D=0;while(1){E=~~(s*+(D|0));F=E>>>0>255>>>0;G=-E>>31;H=E>>>0>65535>>>0;I=B;J=C;K=0;do{L=ca(I,m)|0;do{if(f){M=(ca(J,n)|0)+L|0;N=~~(s*+(K|0));if(N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}a[l+((d[o]|0)+M)|0]=O;a[l+((d[p]|0)+M)|0]=F?G:E;a[l+((d[j]|0)+M)|0]=y?z:x;if(!t){break}a[l+((d[u]|0)+M)|0]=r}else{M=l+L|0;N=ca(J,n)|0;P=~~(s*+(K|0));if(P>>>0>65535>>>0){Q=-P>>31&65535}else{Q=P&65535}b[M+((d[o]|0)+N<<1)>>1]=Q;b[M+((d[p]|0)+N<<1)>>1]=H?G:E;b[M+((d[j]|0)+N<<1)>>1]=A?z:x;if(!t){break}b[M+((d[u]|0)+N<<1)>>1]=q}}while(0);L=J+1|0;N=(L|0)==(e|0);I=(N&1)+I|0;J=N?0:L;K=K+1|0;}while((K|0)<(k|0));K=D+1|0;if((K|0)<(k|0)){B=I;C=J;D=K}else{break}}D=w+1|0;if((D|0)<(k|0)){h=I;v=J;w=D}else{break}}i=g;return}function $v(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[(c[a>>2]|0)+44>>2]|0;d=c[b+148>>2]|0;e=ca(ca(d,d)|0,d)|0;d=b+8|0;c[d>>2]=e;c[b+4>>2]=e;c[a+20>>2]=e;c[a+24>>2]=c[d>>2];d=b+48|0;e=a+28|0;f=c[d+4>>2]|0;c[e>>2]=c[d>>2];c[e+4>>2]=f;f=b+24|0;e=a+116|0;d=c[f+4>>2]|0;c[e>>2]=c[f>>2];c[e+4>>2]=d;d=b+16|0;b=a+56|0;a=c[d+4>>2]|0;c[b>>2]=c[d>>2];c[b+4>>2]=a;return 0}function aw(a,b){a=a|0;b=b|0;var d=0;d=c[a+44>>2]|0;Oz(d+76|0,d+120|0,b|0,b+32|0,0,0,c[d+4>>2]|0,c[d+8>>2]|0);return}function bw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a|0;d=c[b>>2]|0;e=c[d+44>>2]|0;f=e+76|0;Lz(f,c[a+52>>2]|0,0)|0;Mz(f,e+120|0,e+140|0);g=e+4|0;c[g>>2]=Pz(f,0,-1,c[g>>2]|0)|0;h=e+8|0;e=Pz(f,1,-1,c[h>>2]|0)|0;c[h>>2]=e;if((tIb(c[g>>2]|0,e,0,d)|0)<0){i=-22;return i|0}d=c[(c[b>>2]|0)+44>>2]|0;c[a+20>>2]=c[d+4>>2];c[a+24>>2]=c[d+8>>2];b=d+48|0;e=a+28|0;g=c[b+4>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=g;g=d+24|0;e=a+116|0;b=c[g+4>>2]|0;c[e>>2]=c[g>>2];c[e+4>>2]=b;b=d+16|0;d=a+56|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;i=0;return i|0}function cw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+44>>2]|0;e=c[d+24>>2]|0;a:do{if((e|0)==0){f=hw(a,-1)|0;if((f|0)<0){g=f;i=b;return g|0}h=d+28|0;j=tGb(c[h>>2]|0)|0;k=G;l=d+16|0;c[l>>2]=j;c[l+4>>2]=k;if(!((j|0)==0&(k|0)==0)){m=f;break}k=c[h>>2]|0;if((k|0)>=1){m=f;break}KIb(a,16,2452544,(f=i,i=i+8|0,c[f>>2]=k,f)|0);i=f;g=-22;i=b;return g|0}else{do{if((irc(e,2465144)|0)==0){if((irc(c[c[a+4>>2]>>2]|0,2414512)|0)!=0){break}c[d+36>>2]=1;m=0;break a}}while(0);f=d+16|0;k=jl(f,0,e,a)|0;if((k|0)<0){g=k;i=b;return g|0}k=hw(a,rGb(c[f>>2]|0,c[f+4>>2]|0)|0)|0;if((k|0)<0){g=k}else{m=k;break}i=b;return g|0}}while(0);e=c[d+4>>2]|0;do{if((e|0)==0){n=m}else{k=il(d+8|0,e,a)|0;if((k|0)==0){n=0;break}else{g=k}i=b;return g|0}}while(0);a=d+72|0;c[a>>2]=0;c[a+4>>2]=0;g=n;i=b;return g|0}function dw(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;a=b+28|0;d=b+48|0;if((c[a>>2]|0)<=0){mJb(d);return}b=d;e=0;do{TGb(c[(c[b>>2]|0)+(e<<2)>>2]|0);c[(c[b>>2]|0)+(e<<2)>>2]=0;e=e+1|0;}while((e|0)<(c[a>>2]|0));mJb(d);return}function ew(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+16|0;f=c[a+44>>2]|0;g=d|0;h=f+16|0;j=c[h>>2]|0;k=c[h+4>>2]|0;if((j|0)==0&(k|0)==0){h=c[f+28>>2]|0;l=((h|0)<0|0?-1:0)|-2147483648;m=h|0}else{l=k;m=j}c[g>>2]=m;c[g+4>>2]=l;l=d+8|0;c[l>>2]=-1;c[l+4>>2]=-1;l=e|0;c[l>>2]=c[f+8>>2];c[e+4>>2]=-1;dl(a,Ok(684200)|0);bl(a,Pk(g)|0);cl(a,Ok(l)|0);i=b;return 0}function fw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=c[c[a+16>>2]>>2]|0;f=c[c[a+32>>2]>>2]|0;g=c[a+44>>2]|0;h=Wk()|0;c[d>>2]=h;Xk(h,e+84|0);do{if((c[g+36>>2]|0)==0){c[d>>2]=0;e=g+136|0;h=c[e>>2]|0;j=c[e+4>>2]|0;if((h|0)==0&(j|0)==0){e=c[g+28>>2]|0;k=((e|0)<0|0?-1:0)|-2147483648;l=e|0}else{k=j;l=h}Rk(d,l,k)|0;Xk(c[d>>2]|0,f+80|0)}else{h=Wk()|0;c[d>>2]=h;if((h|0)==0){m=-12;i=b;return m|0}else{bl(a,h);break}}}while(0);d=Ok(2032240)|0;if((d|0)==0){m=-12;i=b;return m|0}dl(a,d);d=Uk()|0;if((d|0)==0){m=-12;i=b;return m|0}cl(a,d);m=0;i=b;return m|0}function gw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=c[c[b+16>>2]>>2]|0;do{if((c[d+36>>2]|0)==0){f=e+148|0}else{g=e+40|0;i=c[g+4>>2]|0;j=d+16|0;c[j>>2]=c[g>>2];c[j+4>>2]=i;i=e+148|0;j=hw(b,c[i>>2]|0)|0;if((j|0)<0){k=j}else{f=i;break}return k|0}}while(0);b=d+72|0;c[b>>2]=0;c[b+4>>2]=0;b=c[f>>2]|0;h[d+96>>3]=+(b|0);c[d+32>>2]=b;h[d+104>>3]=+(c[a+148>>2]|0);h[d+120>>3]=+(c[e+48>>2]|0);h[d+112>>3]=+r;e=d+128|0;d=jJb(c[e>>2]|0,c[f>>2]|0,8)|0;c[e>>2]=d;k=(d|0)==0?-12:0;return k|0}function hw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;f=c[a+44>>2]|0;g=f+52|0;h=rJb(c[g>>2]|0)|0;if((h|0)==0){j=-12;i=d;return j|0}if((c[g>>2]|0)==0){KIb(a,16,2629912,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;j=-22;i=d;return j|0}g=(irc(c[c[a+4>>2]>>2]|0,2414512)|0)==0;l=g?2032688:0;m=g?2032680:0;g=f+28|0;n=f+48|0;f=n;if((c[g>>2]|0)>0){o=0;do{TGb(c[(c[f>>2]|0)+(o<<2)>>2]|0);c[(c[f>>2]|0)+(o<<2)>>2]=0;o=o+1|0;}while((o|0)<(c[g>>2]|0))}mJb(n);c[g>>2]=0;c[e>>2]=h;o=n;n=a;a=0;p=0;q=h;while(1){r=HFb(q,2605048,e)|0;if((r|0)==0){s=11;break}if((uJb(o,g,4,0)|0)==0){t=-12;break}u=(c[g>>2]|0)-1|0;c[(c[f>>2]|0)+(u<<2)>>2]=0;v=UGb((c[f>>2]|0)+(u<<2)|0,r,281192,m,l,0,0,0,n)|0;if((v|0)<0){t=v;break}a=v;p=r;q=c[e>>2]|0}a:do{if((s|0)==11){e=c[g>>2]|0;b:do{if((e|0)<(b|0)){q=a;r=e;while(1){if((r|0)>=(b|0)){w=q;break b}if((uJb(o,g,4,0)|0)==0){t=-12;break a}v=(c[g>>2]|0)-1|0;c[(c[f>>2]|0)+(v<<2)>>2]=0;u=UGb((c[f>>2]|0)+(v<<2)|0,p,281192,m,l,0,0,0,n)|0;if((u|0)<0){t=u;break a}else{q=u;r=r+1|0}}}else{w=a}}while(0);if((b|0)<=0){t=w;break}e=c[g>>2]|0;if((e|0)==(b|0)){t=w;break}KIb(n,16,2579328,(k=i,i=i+16|0,c[k>>2]=e,c[k+8>>2]=b,k)|0);i=k;t=-22}}while(0);kJb(h);j=t;i=d;return j|0}function iw(a,b){a=a|0;b=+b;var d=0,e=0;d=~~b;e=(c[a+32>>2]|0)-1|0;return+(+h[(c[a+128>>2]|0)+(((d|0)>(e|0)?e:d)<<3)>>3])}function jw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;j=c[c[f+32>>2]>>2]|0;f=c[b+76>>2]|0;k=oi(j,f)|0;if((k|0)==0){l=-12;i=d;return l|0}ZHb(k,b)|0;m=b+136|0;b=c[m>>2]|0;n=c[m+4>>2]|0;if((b|0)==0&(n|0)==(-2147483648|0)){o=+r}else{o=(+(b>>>0)+ +(n|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}if((f|0)>0){n=g+72|0;b=g+88|0;m=a+48|0;p=g+112|0;q=a+148|0;a=j+148|0;s=g+80|0;t=g+48|0;u=k+64|0;v=g+128|0;w=0;x=c[n+4>>2]|0;y=c[n>>2]|0;do{h[b>>3]=+(y>>>0)+ +(x>>>0)*4294967296.0;h[p>>3]=o+ +(w|0)/+(c[m>>2]|0);z=c[q>>2]|0;if((z|0)>0){A=c[(c[e>>2]|0)+64>>2]|0;B=c[v>>2]|0;C=0;do{h[B+(C<<3)>>3]=+h[(c[A+(C<<2)>>2]|0)+(w<<3)>>3];C=C+1|0;}while((C|0)<(z|0))}if((c[a>>2]|0)>0){z=0;do{h[s>>3]=+(z|0);D=+XGb(c[(c[t>>2]|0)+(z<<2)>>2]|0,s,g);h[(c[(c[u>>2]|0)+(z<<2)>>2]|0)+(w<<3)>>3]=D;z=z+1|0;}while((z|0)<(c[a>>2]|0));E=c[n+4>>2]|0;F=c[n>>2]|0}else{E=x;F=y}w=w+1|0;y=wrc(F,E,1,0)|0;x=G;c[n>>2]=y;c[n+4>>2]=x;}while((w|0)<(f|0))}VHb(e);l=lj(j,k)|0;i=d;return l|0}function kw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[(c[a>>2]|0)+44>>2]|0;d=b+72|0;e=b+8|0;f=b+64|0;g=c[f>>2]|0;i=c[f+4>>2]|0;f=-1;do{if((i|0)>(f|0)|(i|0)==(f|0)&g>>>0>-1>>>0){j=c[e>>2]|0;k=VIb(c[d>>2]|0,c[d+4>>2]|0,1e6,0,j,(j|0)<0|0?-1:0)|0;j=G;if((j|0)<(i|0)|(j|0)==(i|0)&k>>>0<g>>>0){break}else{l=-541478725}return l|0}}while(0);g=b+56|0;i=oi(a,c[g>>2]|0)|0;if((i|0)==0){l=-12;return l|0}f=c[g>>2]|0;if((f|0)>0){k=b+88|0;j=b+112|0;m=b+28|0;n=b+48|0;o=b+80|0;p=i+64|0;q=0;r=c[d+4>>2]|0;s=c[d>>2]|0;t=c[m>>2]|0;u=f;while(1){v=+(s>>>0)+ +(r>>>0)*4294967296.0;h[k>>3]=v;h[j>>3]=v/+(c[e>>2]|0);if((t|0)>0){f=0;do{v=+XGb(c[(c[n>>2]|0)+(f<<2)>>2]|0,o,0);h[(c[(c[p>>2]|0)+(f<<2)>>2]|0)+(q<<3)>>3]=v;f=f+1|0;w=c[m>>2]|0;}while((f|0)<(w|0));x=w;y=c[d+4>>2]|0;z=c[d>>2]|0;A=c[g>>2]|0}else{x=t;y=r;z=s;A=u}f=q+1|0;B=wrc(z,y,1,0)|0;C=G;c[d>>2]=B;c[d+4>>2]=C;if((f|0)<(A|0)){q=f;r=C;s=B;t=x;u=A}else{break}}}A=b+40|0;b=c[A+4>>2]|0;u=i+136|0;c[u>>2]=c[A>>2];c[u+4>>2]=b;c[i+344>>2]=c[e>>2];e=c[g>>2]|0;g=wrc(c[A>>2]|0,c[A+4>>2]|0,e,(e|0)<0|0?-1:0)|0;c[A>>2]=g;c[A+4>>2]=G;l=lj(a,i)|0;return l|0}function lw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0;b=i;i=i+128|0;d=a|0;e=c[(c[d>>2]|0)+44>>2]|0;f=e+8|0;g=c[f>>2]|0;c[a+56>>2]=1;c[a+60>>2]=g;c[a+48>>2]=c[f>>2];h[e+120>>3]=+(c[f>>2]|0);h[e+96>>3]=+r;h[e+104>>3]=+(c[a+148>>2]|0);a=b|0;g=e+16|0;sGb(a,128,0,c[g>>2]|0,c[g+4>>2]|0);g=e+64|0;e=c[g>>2]|0;j=c[g+4>>2]|0;KIb(c[d>>2]|0,40,2373104,(d=i,i=i+32|0,c[d>>2]=c[f>>2],c[d+8>>2]=a,c[d+16>>2]=e,c[d+24>>2]=j,d)|0);i=d;i=b;return 0}function mw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+44>>2]|0;e=a;KIb(e,24,2414200,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;a=d+4|0;c[a>>2]=-1;f=d+8|0;c[f>>2]=0;c[f+4>>2]=0;g=c[d+20>>2]|0;do{if((g|0)==0){h=0}else{if((irc(g,2336240)|0)==0){h=0;break}j=hl(a,g,e)|0;if((j|0)<0){k=j}else{h=j;break}i=b;return k|0}}while(0);g=c[d+24>>2]|0;if((g|0)==0){k=h;i=b;return k|0}if((irc(g,2336240)|0)==0){k=h;i=b;return k|0}k=jl(f,0,g,e)|0;i=b;return k|0}function nw(a){a=a|0;Zvb((c[a+44>>2]|0)+16|0);return}function ow(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[d>>2]=0;f=c[a+44>>2]|0;g=c[c[a+16>>2]>>2]|0;h=c[c[a+32>>2]>>2]|0;Yk(Sk(1)|0,g+68|0);a=c[f+4>>2]|0;if((a|0)==-1){Yk(Sk(1)|0,h+64|0)}else{c[d>>2]=0;Qk(d,a,(a|0)<0|0?-1:0)|0;Yk(c[d>>2]|0,h+64|0)}Xk(Vk()|0,g+84|0);g=f+8|0;f=c[g>>2]|0;d=c[g+4>>2]|0;if((f|0)==0&(d|0)==0){Xk(Vk()|0,h+80|0);i=b;return 0}else{c[e>>2]=0;Rk(e,f,d)|0;Xk(c[e>>2]|0,h+80|0);i=b;return 0}return 0}function pw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+128|0;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=c[d+44>>2]|0;g=f+4|0;h=c[g>>2]|0;if((h|0)==-1){j=c[a+52>>2]|0;c[g>>2]=j;k=j}else{k=h}h=f+8|0;j=c[h>>2]|0;g=c[h+4>>2]|0;if((j|0)==0&(g|0)==0){l=a+40|0;m=c[l>>2]|0;n=c[l+4>>2]|0;c[h>>2]=m;c[h+4>>2]=n;o=n;p=m}else{o=g;p=j}j=f+16|0;f=c[e+48>>2]|0;g=e+40|0;m=e+52|0;e=d;d=Yvb(c[j>>2]|0,p,o,k,f,c[g>>2]|0,c[g+4>>2]|0,c[m>>2]|0,f,0,e)|0;c[j>>2]=d;if((d|0)==0){q=-12;i=b;return q|0}j=$vb(d)|0;if((j|0)<0){q=j;i=b;return q|0}j=b|0;sGb(j,64,-1,c[g>>2]|0,c[g+4>>2]|0);g=b+64|0;d=a+40|0;sGb(g,64,-1,c[d>>2]|0,c[d+4>>2]|0);d=LKb(c[m>>2]|0)|0;m=LKb(c[a+52>>2]|0)|0;KIb(e,40,2135488,(e=i,i=i+32|0,c[e>>2]=d,c[e+8>>2]=j,c[e+16>>2]=m,c[e+24>>2]=g,e)|0);i=e;q=0;i=b;return q|0}function qw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=c[b+76>>2]|0;h=c[c[f+32>>2]>>2]|0;f=oi(h,g)|0;if((f|0)==0){j=-12;i=d;return j|0}bwb(c[a+16>>2]|0,c[f+64>>2]|0,g,c[b+64>>2]|0,g)|0;ZHb(f,b)|0;HHb(f,c[h+148>>2]|0);b=h+40|0;g=c[b+4>>2]|0;a=f+352|0;c[a>>2]=c[b>>2];c[a+4>>2]=g;g=lj(h,f)|0;VHb(e);j=g;i=d;return j|0}function rw(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;a=b+12|0;d=b+8|0;if((c[a>>2]|0)<=0){mJb(d);return}b=d;e=0;do{kJb(c[(c[b>>2]|0)+(e<<4)+12>>2]|0);e=e+1|0;}while((e|0)<(c[a>>2]|0));mJb(d);return}function sw(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(684176)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function tw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=e+16|0;h=Wi(c[c[g>>2]>>2]|0)|0;if(!((h|0)==-541478725)){j=h;i=b;return j|0}if((c[e+76>>2]|0)!=0){j=-541478725;i=b;return j|0}e=f+20|0;h=c[e>>2]|0;if((h|0)==0){j=-541478725;i=b;return j|0}k=h>>>0>2048>>>0?2048:h;h=oi(a,k)|0;if((h|0)==0){j=-12;i=b;return j|0}c[e>>2]=(c[e>>2]|0)-k;VKb(c[h+64>>2]|0,0,c[h+76>>2]|0,c[a+148>>2]|0,c[h+80>>2]|0)|0;e=f+24|0;f=c[e+4>>2]|0;l=h+136|0;c[l>>2]=c[e>>2];c[l+4>>2]=f;if(!((c[e>>2]|0)==0&(c[e+4>>2]|0)==(-2147483648|0))){c[d>>2]=1;c[d+4>>2]=c[a+48>>2];f=XIb(k,(k|0)<0|0?-1:0,d,a+56|0)|0;a=wrc(c[e>>2]|0,c[e+4>>2]|0,f,G)|0;c[e>>2]=a;c[e+4>>2]=G}j=uw(c[c[g>>2]>>2]|0,h)|0;i=b;return j|0}function uw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[g+44>>2]|0;do{if((c[g+76>>2]|0)==0){if((c[h+4>>2]|0)==0){break}j=oi(a,c[b+76>>2]|0)|0;if((j|0)==0){k=-12;i=d;return k|0}ZHb(j,b)|0;l=h+12|0;if((c[l>>2]|0)>0){m=h+8|0;n=j+64|0;o=h+16|0;p=h+32|0;q=0;r=b;while(1){s=(c[m>>2]|0)+(q<<4)|0;t=c[(c[r+64>>2]|0)+(q<<2)>>2]|0;u=c[(c[n>>2]|0)+(q<<2)>>2]|0;if((c[s>>2]|0)==0){nrc(u|0,t|0,ca(c[o>>2]|0,c[r+76>>2]|0)|0)|0}else{mf[c[p>>2]&2047](s,c[r+76>>2]|0,t,u)}u=q+1|0;t=c[e>>2]|0;if((u|0)<(c[l>>2]|0)){q=u;r=t}else{v=t;break}}}else{v=b}r=v+136|0;q=c[r>>2]|0;l=c[r+4>>2]|0;r=c[v+76>>2]|0;c[f>>2]=1;c[f+4>>2]=c[a+48>>2];p=XIb(r,(r|0)<0|0?-1:0,f,a+56|0)|0;r=wrc(p,G,q,l)|0;l=h+24|0;c[l>>2]=r;c[l+4>>2]=G;VHb(e);k=lj(c[c[g+32>>2]>>2]|0,j)|0;i=d;return k|0}}while(0);k=lj(c[c[g+32>>2]>>2]|0,b)|0;i=d;return k|0}function vw(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+8>>2]|0;h=c[f+44>>2]|0;c[d>>2]=0;j=a+148|0;k=qJb(c[j>>2]|0,16)|0;l=h+8|0;c[l>>2]=k;if((k|0)==0){m=-12;i=b;return m|0}k=h+12|0;c[k>>2]=c[j>>2];j=a+52|0;n=h+16|0;c[n>>2]=QKb(c[j>>2]|0)|0;o=a+48|0;a=c[h+4>>2]|0;p=0;while(1){q=c[k>>2]|0;if((p|0)>=(q|0)){r=q;break}q=c[l>>2]|0;s=HFb(a,2229632,d)|0;if((s|0)==0){t=6;break}Bd(s|0,2191696,(u=i,i=i+8|0,c[u>>2]=e,u)|0)|0;i=u;s=~~(+g[e>>2]*+(c[o>>2]|0)/1.0e3);c[q+(p<<4)>>2]=s;if((s|0)<0){t=8;break}else{a=0;p=p+1|0}}if((t|0)==6){r=c[k>>2]|0}else if((t|0)==8){KIb(f,16,2160752,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;m=-22;i=b;return m|0}p=h+20|0;a:do{if((r|0)>0){a=0;o=r;while(1){v=c[l>>2]|0;e=v+(a<<4)|0;d=c[e>>2]|0;if((d|0)==0){w=o}else{s=c[n>>2]|0;if((s|0)==0){break}if(!((2147483647/(s>>>0)|0)>>>0>d>>>0)){break}q=hJb(ca(s,d)|0)|0;c[v+(a<<4)+12>>2]=q;if((q|0)==0){m=-12;t=24;break}q=c[p>>2]|0;d=c[e>>2]|0;c[p>>2]=q>>>0>d>>>0?q:d;w=c[k>>2]|0}d=a+1|0;if((d|0)<(w|0)){a=d;o=w}else{break a}}if((t|0)==24){i=b;return m|0}c[v+(a<<4)+12>>2]=0;m=-12;i=b;return m|0}}while(0);if((c[p>>2]|0)==0){KIb(f,16,2135392,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;m=-22;i=b;return m|0}switch(c[j>>2]|0){case 5:{c[h+32>>2]=722;m=0;i=b;return m|0};case 8:{c[h+32>>2]=630;m=0;i=b;return m|0};case 9:{c[h+32>>2]=156;m=0;i=b;return m|0};case 6:{c[h+32>>2]=480;m=0;i=b;return m|0};case 7:{c[h+32>>2]=8;m=0;i=b;return m|0};default:{m=0;i=b;return m|0}}return 0}function ww(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b+12>>2]|0;if((d|0)==0){return}h=b+4|0;i=b|0;j=b+8|0;b=f;f=e;e=d;while(1){d=c[h>>2]|0;k=c[i>>2]|0;if(d>>>0<k>>>0){l=k-d|0;k=e>>>0>l>>>0?l:e;nrc(g+d|0,f|0,k)|0;mrc(b|0,-128|0,k|0)|0;c[h>>2]=(c[h>>2]|0)+k;m=e-k|0;n=f+k|0;o=b+k|0}else{a[b]=a[g+(c[j>>2]|0)|0]|0;a[g+(c[j>>2]|0)|0]=a[f]|0;k=(c[j>>2]|0)+1|0;c[j>>2]=k>>>0<(c[i>>2]|0)>>>0?k:0;m=e-1|0;n=f+1|0;o=b+1|0}if((m|0)==0){break}else{b=o;f=n;e=m}}return}function xw(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=c[a+12>>2]|0;if((d|0)==0){return}h=a+4|0;i=a|0;j=a+8|0;a=f;f=e;e=d;d=c[h>>2]|0;while(1){k=c[i>>2]|0;if(d>>>0<k>>>0){l=k-d|0;m=e>>>0>l>>>0?l:e;l=m<<1;nrc(g+(d<<1)|0,f|0,l)|0;mrc(a|0,0,l|0)|0;l=(c[h>>2]|0)+m|0;c[h>>2]=l;n=e-m|0;o=f+(m<<1)|0;p=a+(m<<1)|0;q=l}else{l=c[j>>2]|0;m=g+(l<<1)|0;b[a>>1]=b[m>>1]|0;b[m>>1]=b[f>>1]|0;m=l+1|0;c[j>>2]=m>>>0<k>>>0?m:0;n=e-1|0;o=f+2|0;p=a+2|0;q=d}if((n|0)==0){break}else{a=p;f=o;e=n;d=q}}return}function yw(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[a+12>>2]|0;if((b|0)==0){return}g=a+4|0;h=a|0;i=a+8|0;a=e;e=d;d=b;while(1){b=c[g>>2]|0;j=c[h>>2]|0;if(b>>>0<j>>>0){k=j-b|0;j=d>>>0>k>>>0?k:d;k=j<<2;nrc(f+(b<<2)|0,e|0,k)|0;mrc(a|0,0,k|0)|0;c[g>>2]=(c[g>>2]|0)+j;l=d-j|0;m=e+(j<<2)|0;n=a+(j<<2)|0}else{c[a>>2]=c[f+(c[i>>2]<<2)>>2];c[f+(c[i>>2]<<2)>>2]=c[e>>2];j=(c[i>>2]|0)+1|0;c[i>>2]=j>>>0<(c[h>>2]|0)>>>0?j:0;l=d-1|0;m=e+4|0;n=a+4|0}if((l|0)==0){break}else{a=n;e=m;d=l}}return}function zw(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[a+12>>2]|0;if((b|0)==0){return}h=a+4|0;i=a|0;j=a+8|0;a=e;e=d;d=b;b=c[h>>2]|0;while(1){k=c[i>>2]|0;if(b>>>0<k>>>0){l=k-b|0;m=d>>>0>l>>>0?l:d;l=m<<2;nrc(f+(b<<2)|0,e|0,l)|0;mrc(a|0,0,l|0)|0;l=(c[h>>2]|0)+m|0;c[h>>2]=l;n=d-m|0;o=e+(m<<2)|0;p=a+(m<<2)|0;q=l}else{l=c[j>>2]|0;m=f+(l<<2)|0;g[a>>2]=+g[m>>2];g[m>>2]=+g[e>>2];m=l+1|0;c[j>>2]=m>>>0<k>>>0?m:0;n=d-1|0;o=e+4|0;p=a+4|0;q=b}if((n|0)==0){break}else{a=p;e=o;d=n;b=q}}return}function Aw(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[a+12>>2]|0;if((b|0)==0){return}g=a+4|0;i=a|0;j=a+8|0;a=e;e=d;d=b;b=c[g>>2]|0;while(1){k=c[i>>2]|0;if(b>>>0<k>>>0){l=k-b|0;m=d>>>0>l>>>0?l:d;l=m<<3;nrc(f+(b<<3)|0,e|0,l)|0;mrc(a|0,0,l|0)|0;l=(c[g>>2]|0)+m|0;c[g>>2]=l;n=d-m|0;o=e+(m<<3)|0;p=a+(m<<3)|0;q=l}else{l=c[j>>2]|0;m=f+(l<<3)|0;h[a>>3]=+h[m>>3];h[m>>3]=+h[e>>3];m=l+1|0;c[j>>2]=m>>>0<k>>>0?m:0;n=d-1|0;o=e+8|0;p=a+8|0;q=b}if((n|0)==0){break}else{a=p;e=o;d=n;b=q}}return}function Bw(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0;d=i;i=i+16|0;e=d|0;f=d+8|0;j=c[b+44>>2]|0;k=j+12|0;l=c[k>>2]|0;do{if((l|0)!=0){m=j+16|0;n=c[m>>2]|0;if((n|0)==0){break}else{o=l;p=1}while(1){q=a[o]|0;if((q<<24>>24|0)==0){r=n;s=1;break}else if((q<<24>>24|0)==124){t=p+1|0}else{t=p}o=o+1|0;p=t}while(1){n=a[r]|0;if((n<<24>>24|0)==0){break}else if((n<<24>>24|0)==124){u=s+1|0}else{u=s}r=r+1|0;s=u}n=j+20|0;c[n>>2]=jJb(c[n>>2]|0,p,4)|0;q=j+24|0;v=jJb(c[q>>2]|0,s,4)|0;c[q>>2]=v;w=c[n>>2]|0;if((w|0)==0|(v|0)==0){x=-12;i=d;return x|0}v=c[k>>2]|0;c[e>>2]=0;if((p|0)>0){y=0;z=0;A=v;while(1){v=Bd(HFb(A,2135376,e)|0,2111944,(B=i,i=i+8|0,c[B>>2]=w+(y<<2),B)|0)|0;i=B;C=((v|0)==1)+z|0;v=y+1|0;if((v|0)<(p|0)){y=v;z=C;A=0}else{D=C;break}}}else{D=0}A=c[m>>2]|0;z=c[q>>2]|0;c[f>>2]=0;if((s|0)>0){y=0;w=0;C=A;while(1){A=Bd(HFb(C,2135376,f)|0,2111944,(B=i,i=i+8|0,c[B>>2]=z+(y<<2),B)|0)|0;i=B;v=((A|0)==1)+w|0;A=y+1|0;if((A|0)<(s|0)){y=A;w=v;C=0}else{E=v;break}}}else{E=0}if((D|0)!=(E|0)){KIb(b,16,2336032,(B=i,i=i+16|0,c[B>>2]=D,c[B+8>>2]=E,B)|0);i=B;x=-22;i=d;return x|0}C=j+28|0;c[C>>2]=D;if((D|0)==0){KIb(b,16,2278776,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;x=-22;i=d;return x|0}w=j+48|0;y=jJb(c[w>>2]|0,D,4)|0;c[w>>2]=y;if((y|0)==0){x=-12;i=d;return x|0}else{F=0}while(1){if((F|0)>=(D|0)){G=25;break}H=+g[(c[n>>2]|0)+(F<<2)>>2];if(H<=0.0|H>9.0e4){G=22;break}I=+g[(c[q>>2]|0)+(F<<2)>>2];if(I<=0.0|I>1.0){G=24;break}else{F=F+1|0}}if((G|0)==22){KIb(b,16,2229456,(B=i,i=i+16|0,c[B>>2]=F,h[B+8>>3]=H,B)|0);i=B;x=-22;i=d;return x|0}else if((G|0)==24){KIb(b,16,2191600,(B=i,i=i+16|0,c[B>>2]=F,h[B+8>>3]=I,B)|0);i=B;x=-22;i=d;return x|0}else if((G|0)==25){q=j+56|0;c[q>>2]=0;c[q+4>>2]=-2147483648;KIb(b,48,2160728,(B=i,i=i+8|0,c[B>>2]=c[C>>2],B)|0);i=B;x=0;i=d;return x|0}}}while(0);KIb(b,16,2414016,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;x=-22;i=d;return x|0}function Cw(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+20|0);mJb(b+24|0);mJb(b+48|0);a=b+36|0;b=c[a>>2]|0;if((b|0)==0){mJb(a);return}mJb(b);mJb(a);return}function Dw(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(684152)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function Ew(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=Wi(c[c[e+16>>2]>>2]|0)|0;if(!((g|0)==-541478725)){h=g;i=b;return h|0}if((c[e+76>>2]|0)!=0){h=-541478725;i=b;return h|0}e=f+44|0;g=c[e>>2]|0;if((g|0)==0){h=-541478725;i=b;return h|0}j=(g|0)>2048?2048:g;g=oi(a,j)|0;if((g|0)==0){h=-12;i=b;return h|0}c[e>>2]=(c[e>>2]|0)-j;e=g+64|0;k=g+76|0;l=a+148|0;VKb(c[e>>2]|0,0,c[k>>2]|0,c[l>>2]|0,c[g+80>>2]|0)|0;m=c[e>>2]|0;_e[c[f+64>>2]&511](f,c[f+36>>2]|0,m,m,c[k>>2]|0,c[l>>2]|0);l=f+56|0;f=c[l+4>>2]|0;k=g+136|0;c[k>>2]=c[l>>2];c[k+4>>2]=f;if(!((c[l>>2]|0)==0&(c[l+4>>2]|0)==(-2147483648|0))){c[d>>2]=1;c[d+4>>2]=c[a+48>>2];f=XIb(j,(j|0)<0|0?-1:0,d,a+56|0)|0;d=wrc(c[l>>2]|0,c[l+4>>2]|0,f,G)|0;c[l>>2]=d;c[l+4>>2]=G}h=lj(a,g)|0;i=b;return h|0}function Fw(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0,w=0,x=0;b=i;d=c[a>>2]|0;e=c[d+44>>2]|0;f=e+28|0;if((c[f>>2]|0)>0){j=c[e+20>>2]|0;k=a+48|0;l=c[e+48>>2]|0;m=e+40|0;n=c[e+24>>2]|0;o=1.0;p=0;while(1){q=~~(+g[j+(p<<2)>>2]*+(c[k>>2]|0)/1.0e3);c[l+(p<<2)>>2]=q;r=c[m>>2]|0;s=(r|0)>(q|0)?r:q;c[m>>2]=s;t=o+ +g[n+(p<<2)>>2];q=p+1|0;if((q|0)<(c[f>>2]|0)){o=t;p=q}else{u=t;v=s;break}}}else{u=1.0;v=c[e+40>>2]|0}p=e+40|0;if((v|0)<1){KIb(d,16,2452352,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-22;i=b;return x|0}c[e+44>>2]=v;o=+g[e+8>>2];if(u*+g[e+4>>2]*o>1.0){KIb(d,24,2436096,(w=i,i=i+8|0,h[w>>3]=o,w)|0);i=w}w=a+52|0;d=c[w>>2]|0;if((d|0)==6){c[e+64>>2]=232}else if((d|0)==7){c[e+64>>2]=218}else if((d|0)==8){c[e+64>>2]=114}else if((d|0)==9){c[e+64>>2]=334}d=e+36|0;e=d;v=c[e>>2]|0;if((v|0)!=0){mJb(v)}mJb(d);x=WKb(e,0,c[a+148>>2]|0,c[p>>2]|0,c[w>>2]|0,0)|0;i=b;return x|0}function Gw(a,b,d,e,f,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;i=i|0;var j=0.0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0,L=0.0,M=0.0;j=+g[a+8>>2];k=+g[a+4>>2];l=c[a+28>>2]|0;m=c[a+40>>2]|0;n=a+32|0;if((i|0)<=0){o=0;c[n>>2]=o;return}p=c[n>>2]|0;q=(f|0)>0;r=(l|0)>0;s=a+48|0;t=a+24|0;a=0;while(1){u=c[d+(a<<2)>>2]|0;v=c[e+(a<<2)>>2]|0;w=c[b+(a<<2)>>2]|0;a:do{if(q){if(r){x=p;y=u;z=v;A=0}else{B=p;C=u;D=v;E=0;while(1){F=+h[C>>3];G=j*k*F;if(G<-1.0){H=-1.0}else{H=G>1.0?1.0:G}h[D>>3]=H;h[w+(B<<3)>>3]=F;I=B+1|0;J=I-((I|0)<(m|0)?0:m)|0;I=E+1|0;if((I|0)<(f|0)){B=J;C=C+8|0;D=D+8|0;E=I}else{K=J;break a}}}while(1){F=+h[y>>3];E=x+m|0;D=c[s>>2]|0;C=c[t>>2]|0;B=0;G=k*F;do{J=E-(c[D+(B<<2)>>2]|0)|0;G=G+ +h[w+(J-((J|0)<(m|0)?0:m)<<3)>>3]*+g[C+(B<<2)>>2];B=B+1|0;}while((B|0)<(l|0));L=j*G;if(L<-1.0){M=-1.0}else{M=L>1.0?1.0:L}h[z>>3]=M;h[w+(x<<3)>>3]=F;B=x+1|0;C=B-((B|0)<(m|0)?0:m)|0;B=A+1|0;if((B|0)<(f|0)){x=C;y=y+8|0;z=z+8|0;A=B}else{K=C;break}}}else{K=p}}while(0);w=a+1|0;if((w|0)<(i|0)){a=w}else{o=K;break}}c[n>>2]=o;return}function Hw(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0.0,G=0.0,H=0,I=0,J=0,K=0.0,L=0.0;i=+g[a+8>>2];j=+g[a+4>>2];k=c[a+28>>2]|0;l=c[a+40>>2]|0;m=a+32|0;if((h|0)<=0){n=0;c[m>>2]=n;return}o=c[m>>2]|0;p=(f|0)>0;q=(k|0)>0;r=a+48|0;s=a+24|0;a=0;while(1){t=c[d+(a<<2)>>2]|0;u=c[e+(a<<2)>>2]|0;v=c[b+(a<<2)>>2]|0;a:do{if(p){if(q){w=o;x=t;y=u;z=0}else{A=o;B=t;C=u;D=0;while(1){E=+g[B>>2];F=i*j*E;if(F<-1.0){G=-1.0}else{G=F>1.0?1.0:F}g[C>>2]=G;g[v+(A<<2)>>2]=E;H=A+1|0;I=H-((H|0)<(l|0)?0:l)|0;H=D+1|0;if((H|0)<(f|0)){A=I;B=B+4|0;C=C+4|0;D=H}else{J=I;break a}}}while(1){E=+g[x>>2];D=w+l|0;C=c[r>>2]|0;B=c[s>>2]|0;A=0;F=j*E;do{I=D-(c[C+(A<<2)>>2]|0)|0;F=F+ +g[v+(I-((I|0)<(l|0)?0:l)<<2)>>2]*+g[B+(A<<2)>>2];A=A+1|0;}while((A|0)<(k|0));K=i*F;if(K<-1.0){L=-1.0}else{L=K>1.0?1.0:K}g[y>>2]=L;g[v+(w<<2)>>2]=E;A=w+1|0;B=A-((A|0)<(l|0)?0:l)|0;A=z+1|0;if((A|0)<(f|0)){w=B;x=x+4|0;y=y+4|0;z=A}else{J=B;break}}}else{J=o}}while(0);v=a+1|0;if((v|0)<(h|0)){a=v}else{n=J;break}}c[m>>2]=n;return}function Iw(a,d,e,f,h,i){a=a|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0.0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0.0,I=0.0,J=0,K=0;j=+g[a+8>>2];k=+g[a+4>>2];l=c[a+28>>2]|0;m=c[a+40>>2]|0;n=a+32|0;if((i|0)<=0){o=0;c[n>>2]=o;return}p=c[n>>2]|0;q=(h|0)>0;r=(l|0)>0;s=a+48|0;t=a+24|0;a=0;while(1){u=c[d+(a<<2)>>2]|0;if(q){v=p;w=c[e+(a<<2)>>2]|0;x=c[f+(a<<2)>>2]|0;y=0;while(1){z=b[w>>1]|0;A=k*+(z<<16>>16|0);if(r){B=v+m|0;C=c[s>>2]|0;D=c[t>>2]|0;E=0;F=A;while(1){G=B-(c[C+(E<<2)>>2]|0)|0;H=F+ +(b[u+(G-((G|0)<(m|0)?0:m)<<1)>>1]|0)*+g[D+(E<<2)>>2];G=E+1|0;if((G|0)<(l|0)){E=G;F=H}else{I=H;break}}}else{I=A}F=j*I;if(F<-32768.0){J=-32768}else{J=F>32767.0?32767:~~F}b[x>>1]=J;b[u+(v<<1)>>1]=z;E=v+1|0;D=E-((E|0)<(m|0)?0:m)|0;E=y+1|0;if((E|0)<(h|0)){v=D;w=w+2|0;x=x+2|0;y=E}else{K=D;break}}}else{K=p}y=a+1|0;if((y|0)<(i|0)){a=y}else{o=K;break}}c[n>>2]=o;return}function Jw(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0.0,H=0.0,I=0,J=0;i=+g[a+8>>2];j=+g[a+4>>2];k=c[a+28>>2]|0;l=c[a+40>>2]|0;m=a+32|0;if((h|0)<=0){n=0;c[m>>2]=n;return}o=(f|0)>0;p=(k|0)>0;q=a+48|0;r=a+24|0;a=0;while(1){s=c[b+(a<<2)>>2]|0;t=c[m>>2]|0;if(o){u=t;v=c[d+(a<<2)>>2]|0;w=c[e+(a<<2)>>2]|0;x=0;while(1){y=c[v>>2]|0;z=j*+(y|0);if(p){A=u+l|0;B=c[q>>2]|0;C=c[r>>2]|0;D=0;E=z;while(1){F=A-(c[B+(D<<2)>>2]|0)|0;G=E+ +(c[s+(F-((F|0)<(l|0)?0:l)<<2)>>2]|0)*+g[C+(D<<2)>>2];F=D+1|0;if((F|0)<(k|0)){D=F;E=G}else{H=G;break}}}else{H=z}E=i*H;if(E<-2147483648.0){I=-2147483648}else{I=E>2147483647.0?2147483647:~~E}c[w>>2]=I;c[s+(u<<2)>>2]=y;D=u+1|0;C=D-((D|0)<(l|0)?0:l)|0;D=x+1|0;if((D|0)<(f|0)){u=C;v=v+4|0;w=w+4|0;x=D}else{J=C;break}}}else{J=t}x=a+1|0;if((x|0)<(h|0)){a=x}else{n=J;break}}c[m>>2]=n;return}function Kw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[g+44>>2]|0;j=h;do{if((bIb(b)|0)==0){k=oi(a,c[b+76>>2]|0)|0;if((k|0)==0){l=-12;i=d;return l|0}else{ZHb(k,c[e>>2]|0)|0;m=k;n=c[e>>2]|0;break}}else{m=b;n=b}}while(0);b=n+76|0;_e[c[h+64>>2]&511](j,c[h+36>>2]|0,c[n+64>>2]|0,c[m+64>>2]|0,c[b>>2]|0,c[a+148>>2]|0);j=n+136|0;k=c[j>>2]|0;o=c[j+4>>2]|0;j=c[b>>2]|0;c[f>>2]=1;c[f+4>>2]=c[a+48>>2];b=XIb(j,(j|0)<0|0?-1:0,f,a+56|0)|0;a=wrc(b,G,k,o)|0;o=h+56|0;c[o>>2]=a;c[o+4>>2]=G;if((n|0)!=(m|0)){VHb(e)}l=lj(c[c[g+32>>2]>>2]|0,m)|0;i=d;return l|0}function Lw(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;a=c[b+12>>2]|0;d=xrc(-1,2147483647,a,(a|0)<0|0?-1:0)|0;a=G;e=b+16|0;b=c[e+4>>2]|0;return((a|0)<(b|0)|(a|0)==(b|0)&d>>>0<(c[e>>2]|0)>>>0?-22:0)|0}function Mw(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(684112)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function Nw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[g+44>>2]|0;j=c[c[g+32>>2]>>2]|0;g=c[b+76>>2]|0;k=b+136|0;b=c[k>>2]|0;l=c[k+4>>2]|0;c[f>>2]=1;c[f+4>>2]=c[j+48>>2];k=XIb(b,l,f,j+56|0)|0;f=G;l=h+4|0;if((c[l>>2]|0)==0){b=h+16|0;m=c[h+12>>2]|0;n=wrc(m,(m|0)<0|0?-1:0,c[b>>2]|0,c[b+4>>2]|0)|0;b=G;if((b|0)<(f|0)|(b|0)==(f|0)&n>>>0<k>>>0){o=4}}else{n=c[h+12>>2]|0;b=h+16|0;m=c[b>>2]|0;p=c[b+4>>2]|0;b=wrc(n,(n|0)<0|0?-1:0,k,f)|0;n=G;if((n|0)<(p|0)|(n|0)==(p|0)&b>>>0<m>>>0){o=4}}if((o|0)==4){q=lj(j,c[e>>2]|0)|0;i=d;return q|0}m=c[e>>2]|0;do{if((bIb(m)|0)==0){b=oi(a,g)|0;if((b|0)==0){q=-12;i=d;return q|0}else{ZHb(b,c[e>>2]|0)|0;r=b;break}}else{r=m}}while(0);do{if((c[l>>2]|0)==0){m=wrc(k,f,g,(g|0)<0|0?-1:0)|0;a=G;b=h+16|0;p=c[b>>2]|0;n=c[b+4>>2]|0;if((a|0)<(n|0)|(a|0)==(n|0)&m>>>0<p>>>0){o=11;break}m=xrc(k,f,p,n)|0;s=G;t=m;u=h+12|0;o=14}else{m=h+16|0;n=c[m>>2]|0;p=c[m+4>>2]|0;m=h+12|0;a=c[m>>2]|0;b=a;v=(a|0)<0|0?-1:0;a=wrc(b,v,n,p)|0;w=G;if((w|0)<(f|0)|(w|0)==(f|0)&a>>>0<k>>>0){o=11;break}a=xrc(n,p,k,f)|0;p=wrc(a,G,b,v)|0;s=G;t=p;u=m;o=14}}while(0);if((o|0)==11){f=c[r+64>>2]|0;k=GHb(r)|0;VKb(f,0,g,k,c[r+80>>2]|0)|0}else if((o|0)==14){o=c[h+40>>2]|0;k=c[r+64>>2]|0;f=c[e>>2]|0;m=c[f+64>>2]|0;p=GHb(f)|0;Te[o&255](k,m,g,p,(c[l>>2]|0)!=0?-1:1,t,s,c[u>>2]|0,c[h+8>>2]|0)}if((c[e>>2]|0)!=(r|0)){VHb(e)}q=lj(j,r)|0;i=d;return q|0}function Ow(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[(c[a+8>>2]|0)+44>>2]|0;switch(c[a+52>>2]|0){case 6:{c[b+40>>2]=142;break};case 3:{c[b+40>>2]=48;break};case 4:{c[b+40>>2]=116;break};case 9:{c[b+40>>2]=172;break};case 7:{c[b+40>>2]=26;break};case 1:{c[b+40>>2]=46;break};case 8:{c[b+40>>2]=32;break};case 2:{c[b+40>>2]=54;break};default:{}}d=b+24|0;e=c[d>>2]|0;f=c[d+4>>2]|0;if(!((e|0)==0&(f|0)==0)){d=c[a+48>>2]|0;g=VIb(e,f,d,(d|0)<0|0?-1:0,1e6,0)|0;c[b+12>>2]=g}g=b+32|0;d=c[g>>2]|0;f=c[g+4>>2]|0;if((d|0)==0&(f|0)==0){return 0}g=c[a+48>>2]|0;a=VIb(d,f,g,(g|0)<0|0?-1:0,1e6,0)|0;g=b+16|0;c[g>>2]=a;c[g+4>>2]=G;return 0}function Pw(a,b,d,e,f,g,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;var l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0;l=c[a>>2]|0;a=c[b>>2]|0;if((d|0)<=0){return}m=+(j|0);j=(e|0)>0;if((k|0)==1){b=0;n=0;while(1){o=ca(n,f)|0;p=wrc(o,(o|0)<0|0?-1:0,g,i)|0;q=(+(p>>>0)+ +(G|0)*4294967296.0)/m;if(q<1.0){r=q<0.0?0.0:q*3.141592653589793*.5}else{r=1.5707963267948966}q=+V(r);if(j){p=0;o=b;while(1){h[l+(o<<3)>>3]=q*+h[a+(o<<3)>>3];s=p+1|0;if((s|0)<(e|0)){p=s;o=o+1|0}else{break}}t=b+e|0}else{t=b}o=n+1|0;if((o|0)<(d|0)){b=t;n=o}else{break}}return}else{u=0;v=0}while(1){n=ca(v,f)|0;t=wrc(n,(n|0)<0|0?-1:0,g,i)|0;r=(+(t>>>0)+ +(G|0)*4294967296.0)/m;if(r<1.0){w=r<0.0?0.0:r}else{w=1.0}switch(k|0){case 2:{x=1.0- +U((+T(+(w*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 7:{x=w*w*w;break};case 8:{x=+S(w);break};case 6:{x=w*w;break};case 5:{r=1.0-w;x=1.0-r*r;break};case 9:{x=+yb(+w);break};case 3:{x=(1.0- +U(w*3.141592653589793))*.5;break};case 4:{x=+T(+.1,+((1.0-w)*5.0));break};default:{x=w}}if(j){t=0;n=u;while(1){h[l+(n<<3)>>3]=x*+h[a+(n<<3)>>3];b=t+1|0;if((b|0)<(e|0)){t=b;n=n+1|0}else{break}}y=u+e|0}else{y=u}n=v+1|0;if((n|0)<(d|0)){u=y;v=n}else{break}}return}function Qw(a,b,d,e,f,g,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;var l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0;if((d|0)<=0){return}l=+(j|0);j=(e|0)>0;m=0;do{n=ca(m,f)|0;o=wrc(n,(n|0)<0|0?-1:0,g,i)|0;p=(+(o>>>0)+ +(G|0)*4294967296.0)/l;if(p<1.0){q=p<0.0?0.0:p}else{q=1.0}switch(k|0){case 7:{r=q*q*q;break};case 8:{r=+S(q);break};case 3:{r=(1.0- +U(q*3.141592653589793))*.5;break};case 9:{r=+yb(+q);break};case 6:{r=q*q;break};case 5:{p=1.0-q;r=1.0-p*p;break};case 2:{r=1.0- +U((+T(+(q*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 1:{r=+V(q*3.141592653589793*.5);break};case 4:{r=+T(+.1,+((1.0-q)*5.0));break};default:{r=q}}if(j){o=0;do{h[(c[a+(o<<2)>>2]|0)+(m<<3)>>3]=r*+h[(c[b+(o<<2)>>2]|0)+(m<<3)>>3];o=o+1|0;}while((o|0)<(e|0))}m=m+1|0;}while((m|0)<(d|0));return}function Rw(a,b,d,e,f,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0,u=0;l=c[a>>2]|0;a=c[b>>2]|0;if((d|0)<=0){return}m=+(j|0);j=(e|0)>0;b=0;n=0;while(1){o=ca(n,f)|0;p=wrc(o,(o|0)<0|0?-1:0,h,i)|0;q=(+(p>>>0)+ +(G|0)*4294967296.0)/m;if(q<1.0){r=q<0.0?0.0:q}else{r=1.0}switch(k|0){case 9:{s=+yb(+r);break};case 3:{s=(1.0- +U(r*3.141592653589793))*.5;break};case 7:{s=r*r*r;break};case 5:{q=1.0-r;s=1.0-q*q;break};case 8:{s=+S(r);break};case 4:{s=+T(+.1,+((1.0-r)*5.0));break};case 1:{s=+V(r*3.141592653589793*.5);break};case 2:{s=1.0- +U((+T(+(r*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 6:{s=r*r;break};default:{s=r}}if(j){p=0;o=b;while(1){g[l+(o<<2)>>2]=s*+g[a+(o<<2)>>2];t=p+1|0;if((t|0)<(e|0)){p=t;o=o+1|0}else{break}}u=b+e|0}else{u=b}o=n+1|0;if((o|0)<(d|0)){b=u;n=o}else{break}}return}function Sw(a,b,d,e,f,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0;if((d|0)<=0){return}l=+(j|0);j=(e|0)>0;m=0;do{n=ca(m,f)|0;o=wrc(n,(n|0)<0|0?-1:0,h,i)|0;p=(+(o>>>0)+ +(G|0)*4294967296.0)/l;if(p<1.0){q=p<0.0?0.0:p}else{q=1.0}switch(k|0){case 8:{r=+S(q);break};case 9:{r=+yb(+q);break};case 4:{r=+T(+.1,+((1.0-q)*5.0));break};case 1:{r=+V(q*3.141592653589793*.5);break};case 7:{r=q*q*q;break};case 6:{r=q*q;break};case 3:{r=(1.0- +U(q*3.141592653589793))*.5;break};case 2:{r=1.0- +U((+T(+(q*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 5:{p=1.0-q;r=1.0-p*p;break};default:{r=q}}if(j){o=0;do{g[(c[a+(o<<2)>>2]|0)+(m<<2)>>2]=r*+g[(c[b+(o<<2)>>2]|0)+(m<<2)>>2];o=o+1|0;}while((o|0)<(e|0))}m=m+1|0;}while((m|0)<(d|0));return}function Tw(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0,u=0;l=c[a>>2]|0;a=c[d>>2]|0;if((e|0)<=0){return}m=+(j|0);j=(f|0)>0;d=0;n=0;while(1){o=ca(n,g)|0;p=wrc(o,(o|0)<0|0?-1:0,h,i)|0;q=(+(p>>>0)+ +(G|0)*4294967296.0)/m;if(q<1.0){r=q<0.0?0.0:q}else{r=1.0}switch(k|0){case 9:{s=+yb(+r);break};case 3:{s=(1.0- +U(r*3.141592653589793))*.5;break};case 7:{s=r*r*r;break};case 5:{q=1.0-r;s=1.0-q*q;break};case 4:{s=+T(+.1,+((1.0-r)*5.0));break};case 1:{s=+V(r*3.141592653589793*.5);break};case 8:{s=+S(r);break};case 2:{s=1.0- +U((+T(+(r*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 6:{s=r*r;break};default:{s=r}}if(j){p=0;o=d;while(1){b[l+(o<<1)>>1]=~~(s*+(b[a+(o<<1)>>1]|0));t=p+1|0;if((t|0)<(f|0)){p=t;o=o+1|0}else{break}}u=d+f|0}else{u=d}o=n+1|0;if((o|0)<(e|0)){d=u;n=o}else{break}}return}function Uw(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0;if((e|0)<=0){return}l=+(j|0);j=(f|0)>0;m=0;do{n=ca(m,g)|0;o=wrc(n,(n|0)<0|0?-1:0,h,i)|0;p=(+(o>>>0)+ +(G|0)*4294967296.0)/l;if(p<1.0){q=p<0.0?0.0:p}else{q=1.0}switch(k|0){case 9:{r=+yb(+q);break};case 5:{p=1.0-q;r=1.0-p*p;break};case 2:{r=1.0- +U((+T(+(q*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 1:{r=+V(q*3.141592653589793*.5);break};case 8:{r=+S(q);break};case 7:{r=q*q*q;break};case 4:{r=+T(+.1,+((1.0-q)*5.0));break};case 3:{r=(1.0- +U(q*3.141592653589793))*.5;break};case 6:{r=q*q;break};default:{r=q}}if(j){o=0;do{b[(c[a+(o<<2)>>2]|0)+(m<<1)>>1]=~~(r*+(b[(c[d+(o<<2)>>2]|0)+(m<<1)>>1]|0));o=o+1|0;}while((o|0)<(f|0))}m=m+1|0;}while((m|0)<(e|0));return}function Vw(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0;k=c[a>>2]|0;a=c[b>>2]|0;if((d|0)<=0){return}l=+(i|0);i=(e|0)>0;b=0;m=0;while(1){n=ca(m,f)|0;o=wrc(n,(n|0)<0|0?-1:0,g,h)|0;p=(+(o>>>0)+ +(G|0)*4294967296.0)/l;if(p<1.0){q=p<0.0?0.0:p}else{q=1.0}switch(j|0){case 3:{r=(1.0- +U(q*3.141592653589793))*.5;break};case 7:{r=q*q*q;break};case 5:{p=1.0-q;r=1.0-p*p;break};case 9:{r=+yb(+q);break};case 4:{r=+T(+.1,+((1.0-q)*5.0));break};case 1:{r=+V(q*3.141592653589793*.5);break};case 8:{r=+S(q);break};case 2:{r=1.0- +U((+T(+(q*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 6:{r=q*q;break};default:{r=q}}if(i){o=0;n=b;while(1){c[k+(n<<2)>>2]=~~(r*+(c[a+(n<<2)>>2]|0));s=o+1|0;if((s|0)<(e|0)){o=s;n=n+1|0}else{break}}t=b+e|0}else{t=b}n=m+1|0;if((n|0)<(d|0)){b=t;m=n}else{break}}return}function Ww(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0.0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0;if((d|0)<=0){return}k=+(i|0);i=(e|0)>0;l=0;do{m=ca(l,f)|0;n=wrc(m,(m|0)<0|0?-1:0,g,h)|0;o=(+(n>>>0)+ +(G|0)*4294967296.0)/k;if(o<1.0){p=o<0.0?0.0:o}else{p=1.0}switch(j|0){case 9:{q=+yb(+p);break};case 5:{o=1.0-p;q=1.0-o*o;break};case 2:{q=1.0- +U((+T(+(p*2.0+-1.0),+3.0)+1.0)*.7853981633974483);break};case 1:{q=+V(p*3.141592653589793*.5);break};case 8:{q=+S(p);break};case 7:{q=p*p*p;break};case 4:{q=+T(+.1,+((1.0-p)*5.0));break};case 3:{q=(1.0- +U(p*3.141592653589793))*.5;break};case 6:{q=p*p;break};default:{q=p}}if(i){n=0;do{c[(c[a+(n<<2)>>2]|0)+(l<<2)>>2]=~~(q*+(c[(c[b+(n<<2)>>2]|0)+(l<<2)>>2]|0));n=n+1|0;}while((n|0)<(e|0))}l=l+1|0;}while((l|0)<(d|0));return}function Xw(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[b+44>>2]|0;f=c[e+16>>2]|0;a:do{if((f|0)!=0){if((_b(f|0,44)|0)==0){g=124}else{KIb(b,24,2413736,(h=i,i=i+8|0,c[h>>2]=2335864,h)|0);i=h;g=44}j=e+4|0;k=f;while(1){l=_b(k|0,g|0)|0;if((l|0)==0){m=0}else{a[l]=0;m=l+1|0}l=MKb(k)|0;if((l|0)==-1){break}Qk(j,l,(l|0)<0|0?-1:0)|0;if((m|0)==0){break a}else{k=m}}KIb(b,16,2278552,(h=i,i=i+8|0,c[h>>2]=k,h)|0);i=h;n=-22;i=d;return n|0}}while(0);m=c[e+20>>2]|0;b:do{if((m|0)!=0){if((_b(m|0,44)|0)==0){o=124}else{KIb(b,24,2413736,(h=i,i=i+8|0,c[h>>2]=2229312,h)|0);i=h;o=44}g=e+8|0;f=m;while(1){j=_b(f|0,o|0)|0;if((j|0)==0){p=0}else{a[j]=0;p=j+1|0}j=rb(f|0,0,0)|0;l=(j|0)>0?j:0;if((l|0)==0){break}Qk(g,l,(l|0)<0|0?-1:0)|0;if((p|0)==0){break b}else{f=p}}KIb(b,16,2191392,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;n=-22;i=d;return n|0}}while(0);p=c[e+24>>2]|0;if((p|0)==0){n=0;i=d;return n|0}if((_b(p|0,44)|0)==0){q=124}else{KIb(b,24,2413736,(h=i,i=i+8|0,c[h>>2]=2160584,h)|0);i=h;q=44}o=e+12|0;e=p;while(1){p=_b(e|0,q|0)|0;if((p|0)==0){r=0}else{a[p]=0;r=p+1|0}p=pGb(e)|0;m=G;if((p|0)==0&(m|0)==0){break}Rk(o,p,m)|0;if((r|0)==0){n=0;s=28;break}else{e=r}}if((s|0)==28){i=d;return n|0}KIb(b,16,2135264,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;n=-22;i=d;return n|0}function Yw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+44>>2]|0;d=c[b+4>>2]|0;if((d|0)==0){e=Sk(1)|0}else{e=d}dl(a,e);e=c[b+8>>2]|0;if((e|0)==0){f=Uk()|0}else{f=e}cl(a,f);f=c[b+12>>2]|0;if((f|0)!=0){g=f;bl(a,g);return 0}g=Wk()|0;bl(a,g);return 0}function Zw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=e+4|0;g=qJb(c[f>>2]|0,144)|0;c[e+140>>2]=g;if((g|0)==0){h=-12;i=b;return h|0}if((c[f>>2]|0)<=0){h=0;i=b;return h|0}g=d;e=d|0;j=d+4|0;k=d+36|0;l=a+24|0;m=a+12|0;n=a+16|0;o=a+20|0;a=0;while(1){p=FFb(2111792,(q=i,i=i+8|0,c[q>>2]=a,q)|0)|0;i=q;mrc(g|0,0,60)|0;c[e>>2]=p;c[j>>2]=1;c[k>>2]=404;if((p|0)==0){h=-12;r=6;break}Qi(a,l,12,m,n,d)|0;c[o>>2]=c[l>>2];p=a+1|0;if((p|0)<(c[f>>2]|0)){a=p}else{h=0;r=6;break}}if((r|0)==6){i=b;return h|0}return 0}function _w(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;f=d|0;g=c[a+44>>2]|0;h=g+4|0;j=g+140|0;if((c[h>>2]|0)<=0){mJb(j);i=d;return}g=j;k=a+12|0;a=0;do{l=c[g>>2]|0;do{if((l|0)!=0){m=l+(a*144|0)+130|0;n=b[m>>1]|0;if(n<<16>>16==0){break}o=l+(a*144|0)+128|0;p=n;do{n=l+(a*144|0)+((e[o>>1]|0)<<2)|0;q=c[n>>2]|0;b[m>>1]=p-1;c[n>>2]=0;b[o>>1]=(b[o>>1]|0)+1&31;c[f>>2]=q;VHb(f);p=b[m>>1]|0;}while(!(p<<16>>16==0))}}while(0);l=c[k>>2]|0;if((l|0)!=0){mJb(l+(a*60|0)|0)}a=a+1|0;}while((a|0)<(c[h>>2]|0));mJb(j);i=d;return}function $w(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;b=i;i=i+648|0;d=b|0;e=b+256|0;f=b+520|0;g=c[a+44>>2]|0;h=g+4|0;j=c[h>>2]|0;a:do{if((j|0)>0){k=a+16|0;l=b+264|0;m=a;n=g+140|0;o=0;p=0;q=0;r=0;s=0;while(1){t=c[(c[(c[k>>2]|0)+(q<<2)>>2]|0)+80>>2]|0;if((t|0)==0){u=6;break}v=c[t+4>>2]|0;if((v|0)==0){u=6;break}w=c[t>>2]|0;t=c[w>>2]|0;x=c[w+4>>2]|0;w=d+(q<<3)|0;c[w>>2]=t;c[w+4>>2]=x;if((v|0)>1){sGb(l,256,0,t,x);v=q+1|0;KIb(m,32,2335704,(y=i,i=i+16|0,c[y>>2]=l,c[y+8>>2]=v,y)|0);i=y;z=v}else{z=q+1|0}v=rGb(t,x)|0;c[(c[n>>2]|0)+(q*144|0)+132>>2]=v;A=(((t&p|0)!=0|(x&o|0)!=0)&1)+r|0;B=t|p;C=x|o;D=v+s|0;E=c[h>>2]|0;if((z|0)<(E|0)){o=C;p=B;q=z;r=A;s=D}else{break}}if((u|0)==6){KIb(m,24,2413528,(y=i,i=i+8|0,c[y>>2]=q+1,y)|0);i=y;F=-11;i=b;return F|0}if((D|0)>32){KIb(a,16,2278504,(y=i,i=i+8|0,c[y>>2]=32,y)|0);i=y;F=-22;i=b;return F|0}if((A|0)==0){s=g+8|0;c[f>>2]=s;if((E|0)<=1){H=0;I=0;J=E;K=C;L=B;u=22;break}r=c[g+140>>2]|0;p=1;o=s;while(1){s=o+(c[r+((p-1|0)*144|0)+132>>2]<<2)|0;c[f+(p<<2)>>2]=s;n=p+1|0;if((n|0)<(E|0)){p=n;o=s}else{H=0;I=0;J=E;K=C;L=B;u=22;break a}}}KIb(a,24,2229080,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;if((D|0)>0){o=g+8|0;p=0;do{c[o+(p<<2)>>2]=p;p=p+1|0;}while((p|0)<(D|0))}p=tGb(D)|0;o=G;if(!((p|0)==0&(o|0)==0)){M=o;N=p;break}p=yrc(1,0,D|0)|0;o=wrc(p,G,-1,-1)|0;M=G;N=o}else{c[f>>2]=g+8;H=0;I=0;J=j;K=0;L=0;u=22}}while(0);if((u|0)==22){while(1){u=0;if((J|0)>0){j=yrc(1,0,H|0)|0;g=G;D=0;y=I;B=J;while(1){C=d+(D<<3)|0;if((c[C>>2]&j|0)==0&(c[C+4>>2]&g|0)==0){O=y;P=B}else{C=f+(D<<2)|0;E=c[C>>2]|0;c[C>>2]=E+4;c[E>>2]=y;O=y+1|0;P=c[h>>2]|0}E=D+1|0;if((E|0)<(P|0)){D=E;y=O;B=P}else{Q=O;R=P;break}}}else{Q=I;R=J}B=H+1|0;if((B|0)<64){H=B;I=Q;J=R;K=K;L=L;u=22}else{M=K;N=L;break}}}dl(a,Ok(1334448)|0);L=(c[h>>2]|0)>0;c[e>>2]=0;if(L){L=a+16|0;K=0;do{u=d+(K<<3)|0;Rk(e,c[u>>2]|0,c[u+4>>2]|0)|0;Xk(c[e>>2]|0,(c[(c[L>>2]|0)+(K<<2)>>2]|0)+84|0);K=K+1|0;u=(K|0)<(c[h>>2]|0);c[e>>2]=0}while(u)}Rk(e,N,M)|0;Xk(c[e>>2]|0,(c[c[a+32>>2]>>2]|0)+80|0);cl(a,Uk()|0);F=0;i=b;return F|0}function ax(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;h=i;i=i+272|0;j=h|0;k=h+8|0;l=h+136|0;m=h+264|0;c[j>>2]=g;n=c[f+8>>2]|0;o=c[n+44>>2]|0;p=n+32|0;q=c[c[p>>2]>>2]|0;r=n+16|0;s=o+4|0;t=c[s>>2]|0;u=0;while(1){if((u|0)>=(t|0)){break}if((c[(c[r>>2]|0)+(u<<2)>>2]|0)==(f|0)){break}else{u=u+1|0}}f=o+140|0;t=c[f>>2]|0;v=t+(u*144|0)+130|0;if((b[v>>1]|0)==32){VHb(j);w=-12;i=h;return w|0}x=$Hb(g)|0;g=b[v>>1]|0;if(g<<16>>16==32){KIb(n,24,2629536,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;n=t+(u*144|0)+128|0;A=e[n>>1]|0;B=(b[v>>1]|0)-1&65535;b[v>>1]=B;VHb(t+(u*144|0)+(((B&65535)+A&31)<<2)|0);C=b[v>>1]|0;D=n}else{C=g;D=t+(u*144|0)+128|0}g=e[D>>1]|0;b[v>>1]=C+1;c[t+(u*144|0)+((g+(C&65535)&31)<<2)>>2]=x;x=(c[f>>2]|0)+(u*144|0)+136|0;c[x>>2]=(c[x>>2]|0)+(c[(c[j>>2]|0)+76>>2]|0);VHb(j);j=c[f>>2]|0;x=c[j+136>>2]|0;u=c[s>>2]|0;if((u|0)>1){C=x;g=1;while(1){t=c[j+(g*144|0)+136>>2]|0;v=(C|0)>(t|0)?t:C;t=g+1|0;if((t|0)<(u|0)){C=v;g=t}else{E=v;break}}}else{E=x}if((E|0)==0){w=0;i=h;return w|0}x=oi(c[c[p>>2]>>2]|0,E)|0;if((x|0)==0){w=-12;i=h;return w|0}g=c[x>>2]|0;C=c[s>>2]|0;if((C|0)>0){u=c[o+136>>2]|0;j=0;v=c[f>>2]|0;do{if((b[v+(j*144|0)+130>>1]|0)==0){F=0}else{F=c[v+(j*144|0)+((b[v+(j*144|0)+128>>1]&31)<<2)>>2]|0}c[k+(j<<2)>>2]=F;v=c[f>>2]|0;c[l+(j<<2)>>2]=(c[F>>2]|0)+(ca(ca(c[v+(j*144|0)+132>>2]|0,c[v+(j*144|0)+140>>2]|0)|0,u)|0);j=j+1|0;}while((j|0)<(C|0))}C=c[k>>2]|0;ZHb(x,C)|0;j=C+136|0;C=c[j>>2]|0;u=c[j+4>>2]|0;if((C|0)==0&(u|0)==(-2147483648|0)){H=-2147483648;I=0}else{j=c[(c[f>>2]|0)+140>>2]|0;v=c[(c[c[r>>2]>>2]|0)+48>>2]|0;c[m>>2]=1;c[m+4>>2]=v;v=XIb(j,(j|0)<0|0?-1:0,m,(c[c[p>>2]>>2]|0)+56|0)|0;m=wrc(v,G,C,u)|0;H=G;I=m}m=x+136|0;c[m>>2]=I;c[m+4>>2]=H;c[x+76>>2]=E;H=q+40|0;m=c[H+4>>2]|0;I=x+352|0;c[I>>2]=c[H>>2];c[I+4>>2]=m;HHb(x,c[q+148>>2]|0);q=o+136|0;m=o+8|0;o=g;g=E;E=c[s>>2]|0;a:while(1){I=(E|0)>0;if(I){H=c[f>>2]|0;u=g;C=0;while(1){v=(c[(c[k+(C<<2)>>2]|0)+76>>2]|0)-(c[H+(C*144|0)+140>>2]|0)|0;j=(u|0)>(v|0)?v:u;v=C+1|0;if((v|0)<(E|0)){u=j;C=v}else{J=j;break}}}else{J=g}C=c[q>>2]|0;do{if((C|0)==4){u=c[f>>2]|0;if(I){H=0;j=0;do{j=(c[u+(H*144|0)+132>>2]|0)+j|0;H=H+1|0;}while((H|0)<(E|0));K=j<<2}else{K=0}if((J|0)==0){L=o;break}H=ca(K,J)|0;if(I){M=J;N=o}else{L=o+H|0;break}while(1){v=M-1|0;r=m;F=0;while(1){t=u+(F*144|0)+132|0;if((c[t>>2]|0)>0){D=l+(F<<2)|0;n=r;A=1;B=c[D>>2]|0;while(1){O=n+4|0;P=B;Q=N+(c[n>>2]<<2)|0;y=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=(c[D>>2]|0)+4|0;c[D>>2]=Q;if((A|0)<(c[t>>2]|0)){n=O;A=A+1|0;B=Q}else{R=O;break}}}else{R=r}B=F+1|0;if((B|0)<(E|0)){r=R;F=B}else{break}}if((v|0)==0){break}else{M=v;N=N+K|0}}L=o+H|0}else if((C|0)==2){u=c[f>>2]|0;if(I){j=0;F=0;do{F=(c[u+(j*144|0)+132>>2]|0)+F|0;j=j+1|0;}while((j|0)<(E|0));S=F<<1}else{S=0}if((J|0)==0){L=o;break}j=ca(S,J)|0;if(I){T=J;U=o}else{L=o+j|0;break}while(1){H=T-1|0;r=m;B=0;while(1){A=u+(B*144|0)+132|0;if((c[A>>2]|0)>0){n=l+(B<<2)|0;t=r;D=1;O=c[n>>2]|0;while(1){Q=t+4|0;P=O;V=U+(c[t>>2]<<1)|0;y=(d[P]|d[P+1|0]<<8)<<16>>16;a[V]=y;y=y>>8;a[V+1|0]=y;V=(c[n>>2]|0)+2|0;c[n>>2]=V;if((D|0)<(c[A>>2]|0)){t=Q;D=D+1|0;O=V}else{W=Q;break}}}else{W=r}O=B+1|0;if((O|0)<(E|0)){r=W;B=O}else{break}}if((H|0)==0){break}else{T=H;U=U+S|0}}L=o+j|0}else if((C|0)==1){u=c[f>>2]|0;if(I){F=0;B=0;while(1){r=(c[u+(F*144|0)+132>>2]|0)+B|0;v=F+1|0;if((v|0)<(E|0)){F=v;B=r}else{X=r;break}}}else{X=0}if((J|0)==0){L=o;break}B=ca(X,J)|0;if(I){Y=J;Z=o}else{L=o+B|0;break}while(1){F=Y-1|0;j=m;r=0;while(1){v=u+(r*144|0)+132|0;if((c[v>>2]|0)>0){O=l+(r<<2)|0;D=j;t=1;A=c[O>>2]|0;while(1){n=D+4|0;a[Z+(c[D>>2]|0)|0]=a[A]|0;Q=(c[O>>2]|0)+1|0;c[O>>2]=Q;if((t|0)<(c[v>>2]|0)){D=n;t=t+1|0;A=Q}else{_=n;break}}}else{_=j}A=r+1|0;if((A|0)<(E|0)){j=_;r=A}else{break}}if((F|0)==0){break}else{Y=F;Z=Z+X|0}}L=o+B|0}else{u=c[f>>2]|0;if(I){r=0;j=0;while(1){H=(c[u+(r*144|0)+132>>2]|0)+j|0;A=r+1|0;if((A|0)<(E|0)){r=A;j=H}else{$=H;break}}}else{$=0}if((J|0)==0){L=o;break}j=ca($,C)|0;r=ca(ca($,J)|0,C)|0;if(I){aa=J;ba=o}else{L=o+r|0;break}while(1){B=aa-1|0;H=m;A=0;while(1){t=u+(A*144|0)+132|0;if((c[t>>2]|0)>0){D=l+(A<<2)|0;v=H;O=1;n=c[D>>2]|0;while(1){Q=v+4|0;nrc(ba+(ca(c[v>>2]|0,C)|0)|0,n|0,C)|0;V=(c[D>>2]|0)+C|0;c[D>>2]=V;if((O|0)<(c[t>>2]|0)){v=Q;O=O+1|0;n=V}else{da=Q;break}}}else{da=H}n=A+1|0;if((n|0)<(E|0)){H=da;A=n}else{break}}if((B|0)==0){break}else{aa=B;ba=ba+j|0}}L=o+r|0}}while(0);C=g-J|0;I=c[s>>2]|0;if((I|0)>0){j=0;while(1){u=c[f>>2]|0;A=u+(j*144|0)+136|0;c[A>>2]=(c[A>>2]|0)-J;A=u+(j*144|0)+140|0;u=(c[A>>2]|0)+J|0;c[A>>2]=u;H=k+(j<<2)|0;if((u|0)==(c[(c[H>>2]|0)+76>>2]|0)){c[A>>2]=0;VHb(H);A=c[f>>2]|0;u=A+(j*144|0)+128|0;F=A+(j*144|0)+130|0;n=b[F>>1]|0;if(n<<16>>16==0){ea=79;break a}O=A+(j*144|0)+(e[u>>1]<<2)|0;b[F>>1]=n-1;c[O>>2]=0;b[u>>1]=(b[u>>1]|0)+1&31;u=c[f>>2]|0;do{if((b[u+(j*144|0)+130>>1]|0)==0){c[H>>2]=0;fa=0}else{O=c[u+(j*144|0)+((b[u+(j*144|0)+128>>1]&31)<<2)>>2]|0;c[H>>2]=O;if((O|0)==0){fa=0;break}fa=c[O>>2]|0}}while(0);c[l+(j<<2)>>2]=fa}H=j+1|0;u=c[s>>2]|0;if((H|0)<(u|0)){j=H}else{ga=u;break}}}else{ga=I}if((g|0)==(J|0)){break}else{o=L;g=C;E=ga}}if((ea|0)==79){KIb(0,0,2191360,(z=i,i=i+24|0,c[z>>2]=2160560,c[z+8>>2]=2135232,c[z+16>>2]=101,z)|0);i=z;Hd();return 0}w=lj(c[c[p>>2]>>2]|0,x)|0;i=h;return w|0}function bx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a>>2]|0;a=c[b+44>>2]|0;d=b+16|0;b=a+4|0;e=c[b>>2]|0;if((e|0)<=0){f=0;return f|0}g=a+140|0;a=0;h=e;while(1){if((c[(c[g>>2]|0)+(a*144|0)+136>>2]|0)==0){e=Wi(c[(c[d>>2]|0)+(a<<2)>>2]|0)|0;if((e|0)<0){f=e;i=7;break}j=c[b>>2]|0}else{j=h}e=a+1|0;if((e|0)<(j|0)){a=e;h=j}else{f=0;i=7;break}}if((i|0)==7){return f|0}return 0}function cx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+1024|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=f+4|0;h=c[g>>2]|0;j=e+16|0;k=1;while(1){if((k|0)>=(h|0)){break}l=c[j>>2]|0;m=c[(c[l+(k<<2)>>2]|0)+48>>2]|0;n=c[(c[l>>2]|0)+48>>2]|0;if((m|0)==(n|0)){k=k+1|0}else{o=4;break}}if((o|0)==4){KIb(e,16,2541960,(p=i,i=i+24|0,c[p>>2]=m,c[p+8>>2]=k,c[p+16>>2]=n,p)|0);i=p;q=-22;i=b;return q|0}n=e+32|0;c[f+136>>2]=QKb(c[(c[c[n>>2]>>2]|0)+52>>2]|0)|0;f=c[c[j>>2]>>2]|0;c[a+48>>2]=c[f+48>>2];k=f+56|0;f=a+56|0;a=c[k+4>>2]|0;c[f>>2]=c[k>>2];c[f+4>>2]=a;SFb(d,0,1);if((c[g>>2]|0)>0){a=0;do{UFb(d,2524808,(p=i,i=i+16|0,c[p>>2]=(a|0)!=0?2509608:10230576,c[p+8>>2]=a,p)|0);i=p;f=(c[(c[j>>2]|0)+(a<<2)>>2]|0)+40|0;qGb(d,-1,c[f>>2]|0,c[f+4>>2]|0);a=a+1|0;}while((a|0)<(c[g>>2]|0))}UFb(d,2484944,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;g=(c[c[n>>2]>>2]|0)+40|0;qGb(d,-1,c[g>>2]|0,c[g+4>>2]|0);KIb(e,40,2473424,(p=i,i=i+8|0,c[p>>2]=c[d>>2],p)|0);i=p;q=0;i=b;return q|0}function dx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+96|0;d=b+32|0;e=c[a+44>>2]|0;f=e+40|0;if((c[f>>2]|0)<=0){g=e+4|0;h=g;qHb(h,0);i=b;return 0}j=d;k=b|0;l=d+4|0;m=d|0;n=d+36|0;o=a+24|0;p=a+12|0;q=a+16|0;r=a+20|0;a=0;do{mrc(j|0,0,60)|0;Rb(k|0,32,2413360,(s=i,i=i+8|0,c[s>>2]=a,s)|0)|0;i=s;c[l>>2]=1;c[m>>2]=rJb(k)|0;c[n>>2]=1004;Qi(a,o,12,p,q,d)|0;c[r>>2]=c[o>>2];a=a+1|0;}while((a|0)<(c[f>>2]|0));g=e+4|0;h=g;qHb(h,0);i=b;return 0}function ex(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+44>>2]|0;d=b+68|0;e=d;f=c[e>>2]|0;if((f|0)!=0){g=b+40|0;a:do{if((c[g>>2]|0)>0){h=0;i=f;while(1){tFb(c[i+(h<<2)>>2]|0);j=h+1|0;if((j|0)>=(c[g>>2]|0)){break a}h=j;i=c[e>>2]|0}}}while(0);mJb(d)}d=b+96|0;e=c[d>>2]|0;if((e|0)!=0){g=e+8|0;f=c[g>>2]|0;if((f|0)!=0){i=f;do{c[g>>2]=c[i+16>>2];kJb(i);i=c[g>>2]|0;}while((i|0)!=0)}c[e>>2]=0;c[e+4>>2]=0;c[e+12>>2]=0}mJb(d);mJb(b+72|0);mJb(b+76|0);b=a+24|0;if((c[b>>2]|0)==0){return}d=a+12|0;a=0;do{mJb((c[d>>2]|0)+(a*60|0)|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return}function fx(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=0;Qk(d,3,0)|0;Qk(d,8,0)|0;dl(a,c[d>>2]|0);bl(a,Vk()|0);cl(a,Uk()|0);i=b;return 0}function gx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=c[c[f+32>>2]>>2]|0;j=f+16|0;k=c[f+24>>2]|0;l=0;while(1){if(!(l>>>0<k>>>0)){m=4;break}if((c[(c[j>>2]|0)+(l<<2)>>2]|0)==(a|0)){break}else{l=l+1|0}}if((m|0)==4){KIb(f,16,2335496,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;VHb(e);i=d;return o|0}if((l|0)==0){f=b+136|0;m=XIb(c[f>>2]|0,c[f+4>>2]|0,a+56|0,h+56|0)|0;h=G;a=c[g+96>>2]|0;f=c[(c[e>>2]|0)+76>>2]|0;j=hJb(24)|0;k=j;if((j|0)==0){o=-12;VHb(e);i=d;return o|0}c[j>>2]=f;p=j+8|0;c[p>>2]=m;c[p+4>>2]=h;c[j+16>>2]=0;j=a+8|0;do{if((c[j>>2]|0)==0){c[j>>2]=k;c[a+12>>2]=k}else{h=a+12|0;p=c[h>>2]|0;if((p|0)==0){KIb(0,0,2278376,(n=i,i=i+24|0,c[n>>2]=2229016,c[n+8>>2]=2191296,c[n+16>>2]=145,n)|0);i=n;Hd();return 0}else{c[p+16>>2]=k;c[h>>2]=k;break}}}while(0);k=a|0;c[k>>2]=(c[k>>2]|0)+1;k=a+4|0;c[k>>2]=(c[k>>2]|0)+f;q=c[e>>2]|0}else{q=b}o=wFb(c[(c[g+68>>2]|0)+(l<<2)>>2]|0,c[q+64>>2]|0,c[q+76>>2]|0)|0;VHb(e);i=d;return o|0}function hx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;d=i;e=c[b>>2]|0;f=c[e+44>>2]|0;g=f+40|0;h=c[g>>2]|0;if((h|0)<=0){c[f+44>>2]=0;j=-541478725;i=d;return j|0}k=f+72|0;l=c[k>>2]|0;m=0;n=0;do{n=((a[l+m|0]|0)!=0)+n|0;m=m+1|0;}while((m|0)<(h|0));m=f+44|0;c[m>>2]=n;if((n|0)==0){j=-541478725;i=d;return j|0}o=f+48|0;p=c[o>>2]|0;do{if((p|0)==2){if((a[l]|0)==0){j=-541478725}else{break}i=d;return j|0}else if((p|0)==1){if((n|0)==(h|0)){q=9;break}else{j=-541478725}i=d;return j|0}else{q=9}}while(0);do{if((q|0)==9){if((a[l]|0)!=0){break}h=jx(e,1)|0;if((h|0)<0){j=h;i=d;return j|0}h=c[g>>2]|0;if((h|0)<=0){c[m>>2]=0;j=-541478725;i=d;return j|0}n=c[k>>2]|0;p=0;r=0;do{r=((a[n+p|0]|0)!=0)+r|0;p=p+1|0;}while((p|0)<(h|0));c[m>>2]=r;if((r|0)==0){j=-541478725;i=d;return j|0}p=c[o>>2]|0;do{if((p|0)==2){if((a[n]|0)==0){j=-541478725}else{break}i=d;return j|0}else if((p|0)==1){if((r|0)==(h|0)){break}else{j=-541478725}i=d;return j|0}}while(0);if((h|0)<=1){KIb(0,0,2278376,(s=i,i=i+24|0,c[s>>2]=2426168,c[s+8>>2]=2191296,c[s+16>>2]=325,s)|0);i=s;Hd();return 0}r=f+68|0;p=1;t=2147483647;u=h;v=n;while(1){if((a[v+p|0]|0)==0){w=t;x=u}else{y=yFb(c[(c[r>>2]|0)+(p<<2)>>2]|0)|0;w=(t|0)>(y|0)?y:t;x=c[g>>2]|0}y=p+1|0;if((y|0)>=(x|0)){break}p=y;t=w;u=x;v=c[k>>2]|0}v=(w|0)==2147483647?0:w;if((v|0)==0){j=-11;i=d;return j|0}j=kx(b,v)|0;i=d;return j|0}}while(0);w=f+96|0;x=c[w>>2]|0;l=c[x>>2]|0;do{if((l|0)==0){v=Wi(c[c[e+16>>2]>>2]|0)|0;if((v|0)==-541478725){a[c[k>>2]|0]=0;j=(c[g>>2]|0)==1?-541478725:-11;i=d;return j|0}if((v|0)<0){j=v;i=d;return j|0}else{v=c[w>>2]|0;z=v;A=c[v>>2]|0;break}}else{z=x;A=l}}while(0);if((A|0)<=0){KIb(0,0,2278376,(s=i,i=i+24|0,c[s>>2]=2452296,c[s+8>>2]=2191296,c[s+16>>2]=425,s)|0);i=s;Hd();return 0}A=c[z+8>>2]|0;if((A|0)==0){B=0}else{B=c[A>>2]|0}do{if((c[m>>2]|0)>1){A=jx(e,B)|0;if((A|0)<0){j=A;i=d;return j|0}A=c[g>>2]|0;if((A|0)<=0){c[m>>2]=0;j=-541478725;i=d;return j|0}z=c[k>>2]|0;l=0;x=0;do{x=((a[z+l|0]|0)!=0)+x|0;l=l+1|0;}while((l|0)<(A|0));c[m>>2]=x;if((x|0)==0){j=-541478725;i=d;return j|0}l=c[o>>2]|0;do{if((l|0)==2){if((a[z]|0)==0){j=-541478725}else{break}i=d;return j|0}else if((l|0)==1){if((x|0)==(A|0)){break}else{j=-541478725}i=d;return j|0}}while(0);if((x|0)<=1){C=B;break}if((A|0)<=1){KIb(0,0,2278376,(s=i,i=i+24|0,c[s>>2]=2426168,c[s+8>>2]=2191296,c[s+16>>2]=325,s)|0);i=s;Hd();return 0}l=f+68|0;v=1;u=2147483647;t=A;p=z;while(1){if((a[p+v|0]|0)==0){D=u;E=t}else{r=yFb(c[(c[l>>2]|0)+(v<<2)>>2]|0)|0;D=(u|0)>(r|0)?r:u;E=c[g>>2]|0}r=v+1|0;if((r|0)>=(E|0)){break}v=r;u=D;t=E;p=c[k>>2]|0}p=(D|0)==2147483647?0:D;if((p|0)==0){j=-11;i=d;return j|0}else{C=(p|0)>(B|0)?B:p;break}}else{C=B}}while(0);B=c[w>>2]|0;w=B+8|0;D=c[w>>2]|0;k=(D|0)==0;if(k){F=-2147483648;H=0}else{E=D+8|0;F=c[E+4>>2]|0;H=c[E>>2]|0}E=f+88|0;c[E>>2]=H;c[E+4>>2]=F;F=B+4|0;a:do{if((c[F>>2]|0)>(C|0)){if((C|0)<=0){break}E=B+12|0;H=B|0;f=C;g=D;while(1){if((g|0)==0){q=66;break}I=g|0;J=c[I>>2]|0;if((J|0)>(f|0)){q=70;break}o=f-J|0;m=c[g+16>>2]|0;c[w>>2]=m;if((m|0)==0){c[E>>2]=0}c[H>>2]=(c[H>>2]|0)-1;c[F>>2]=(c[F>>2]|0)-(c[I>>2]|0);kJb(g);if((o|0)<=0){break a}f=o;g=c[w>>2]|0}if((q|0)==66){KIb(0,0,2278376,(s=i,i=i+24|0,c[s>>2]=2435952,c[s+8>>2]=2191296,c[s+16>>2]=113,s)|0);i=s;Hd();return 0}else if((q|0)==70){c[I>>2]=J-f;H=g+8|0;E=wrc(c[H>>2]|0,c[H+4>>2]|0,f,(f|0)<0|0?-1:0)|0;c[H>>2]=E;c[H+4>>2]=G;c[F>>2]=(c[F>>2]|0)-f;break}}else{if(!k){H=D;do{c[w>>2]=c[H+16>>2];kJb(H);H=c[w>>2]|0;}while((H|0)!=0)}c[B>>2]=0;c[F>>2]=0;c[B+12>>2]=0}}while(0);j=kx(b,C)|0;i=d;return j|0}function ix(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+64|0;e=d|0;f=c[b>>2]|0;h=c[f+44>>2]|0;j=b+52|0;c[h+64>>2]=RKb(c[j>>2]|0)|0;k=b+48|0;c[h+60>>2]=c[k>>2];l=c[k>>2]|0;c[b+56>>2]=1;c[b+60>>2]=l;l=h+88|0;c[l>>2]=0;c[l+4>>2]=-2147483648;l=pJb(16)|0;c[h+96>>2]=l;if((l|0)==0){m=-12;i=d;return m|0}l=h+40|0;n=pJb(c[l>>2]<<2)|0;o=h+68|0;c[o>>2]=n;if((n|0)==0){m=-12;i=d;return m|0}n=b+40|0;b=h+56|0;c[b>>2]=rGb(c[n>>2]|0,c[n+4>>2]|0)|0;p=0;while(1){q=c[l>>2]|0;if((p|0)>=(q|0)){break}r=uFb(c[j>>2]|0,c[b>>2]|0,1024)|0;c[(c[o>>2]|0)+(p<<2)>>2]=r;if((c[(c[o>>2]|0)+(p<<2)>>2]|0)==0){m=-12;s=15;break}else{p=p+1|0}}if((s|0)==15){i=d;return m|0}s=hJb(q)|0;q=h+72|0;c[q>>2]=s;if((s|0)==0){m=-12;i=d;return m|0}mrc(s|0,1,c[l>>2]|0)|0;s=c[l>>2]|0;p=h+44|0;c[p>>2]=s;o=pJb(s<<2)|0;s=o;c[h+76>>2]=s;if((o|0)==0){m=-12;i=d;return m|0}o=h+80|0;g[o>>2]=+(c[p>>2]|0);p=c[l>>2]|0;if((p|0)>0){h=c[q>>2]|0;q=0;do{if((a[h+q|0]|0)==1){g[s+(q<<2)>>2]=1.0/+g[o>>2]}else{g[s+(q<<2)>>2]=0.0}q=q+1|0;}while((q|0)<(p|0))}p=e|0;sGb(p,64,-1,c[n>>2]|0,c[n+4>>2]|0);n=c[l>>2]|0;l=LKb(c[j>>2]|0)|0;j=c[k>>2]|0;KIb(f,40,2465056,(f=i,i=i+32|0,c[f>>2]=n,c[f+8>>2]=l,c[f+16>>2]=j,c[f+24>>2]=p,f)|0);i=f;m=0;i=d;return m|0}function jx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[b+44>>2]|0;g=f+40|0;if((c[g>>2]|0)<=1){KIb(0,0,2278376,(h=i,i=i+24|0,c[h>>2]=2426168,c[h+8>>2]=2191296,c[h+16>>2]=347,h)|0);i=h;Hd();return 0}h=f+72|0;j=f+68|0;f=b+16|0;b=1;a:while(1){b:do{if((a[(c[h>>2]|0)+b|0]|0)!=0){k=0;while(1){if((k|0)==(-541478725|0)){break}else if((k|0)!=0){l=10;break}if((yFb(c[(c[j>>2]|0)+(b<<2)>>2]|0)|0)>=(d|0)){break b}k=Wi(c[(c[f>>2]|0)+(b<<2)>>2]|0)|0}if((l|0)==10){l=0;if((k|0)<0){m=k;l=12;break a}else{break}}if((yFb(c[(c[j>>2]|0)+(b<<2)>>2]|0)|0)!=0){break}a[(c[h>>2]|0)+b|0]=0}}while(0);n=b+1|0;if((n|0)<(c[g>>2]|0)){b=n}else{m=0;l=12;break}}if((l|0)==12){i=e;return m|0}return 0}function kx(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+16|0;f=e|0;h=e+8|0;j=c[(c[b>>2]|0)+44>>2]|0;k=j+80|0;l=+g[k>>2];m=+(c[j+44>>2]|0);if(l>m){n=l- +(d|0)/(+g[j+52>>2]*+(c[j+60>>2]|0));g[k>>2]=n>m?n:m}o=j+40|0;p=c[o>>2]|0;if((p|0)>0){q=j+76|0;r=c[j+72>>2]|0;s=0;do{if((a[r+s|0]|0)==1){g[(c[q>>2]|0)+(s<<2)>>2]=1.0/+g[k>>2]}else{g[(c[q>>2]|0)+(s<<2)>>2]=0.0}s=s+1|0;}while((s|0)<(p|0))}p=oi(b,d)|0;c[f>>2]=p;if((p|0)==0){t=-12;i=e;return t|0}p=oi(b,d)|0;c[h>>2]=p;if((p|0)==0){VHb(f);t=-12;i=e;return t|0}p=c[o>>2]|0;if((p|0)>0){s=j+72|0;q=j+68|0;k=j+64|0;r=j+56|0;u=j+8|0;v=j+76|0;w=0;x=p;while(1){if((a[(c[s>>2]|0)+w|0]|0)==1){zFb(c[(c[q>>2]|0)+(w<<2)>>2]|0,c[(c[h>>2]|0)+64>>2]|0,d)|0;p=c[r>>2]|0;if((c[k>>2]|0)==0){y=1;z=ca(p,d)|0;A=18}else{if((p|0)>0){y=p;z=d;A=18}}if((A|0)==18){A=0;p=z+15&-16;B=0;do{xe[c[u>>2]&7](c[(c[(c[f>>2]|0)+64>>2]|0)+(B<<2)>>2]|0,c[(c[(c[h>>2]|0)+64>>2]|0)+(B<<2)>>2]|0,+g[(c[v>>2]|0)+(w<<2)>>2],p);B=B+1|0;}while((B|0)<(y|0))}C=c[o>>2]|0}else{C=x}B=w+1|0;if((B|0)<(C|0)){w=B;x=C}else{break}}}VHb(h);h=j+88|0;j=c[h+4>>2]|0;C=c[f>>2]|0;f=C+136|0;c[f>>2]=c[h>>2];c[f+4>>2]=j;j=c[h>>2]|0;f=c[h+4>>2]|0;if(!((j|0)==0&(f|0)==(-2147483648|0))){x=wrc(j,f,d,(d|0)<0|0?-1:0)|0;c[h>>2]=x;c[h+4>>2]=G}t=lj(b,C)|0;i=e;return t|0}function lx(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+44>>2]|0;e=d+8|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=d+32|0;if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){f=0;i=b;return f|0}e=d+24|0;if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){f=0;i=b;return f|0}KIb(a,16,2413104,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-22;i=b;return f|0}function mx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=Wi(c[c[e+16>>2]>>2]|0)|0;if(!((g|0)==-541478725)){h=g;i=b;return h|0}if((c[e+76>>2]|0)!=0){h=-541478725;i=b;return h|0}e=c[f+16>>2]|0;g=f+32|0;j=c[g>>2]|0;k=c[g+4>>2]|0;l=0;m=f+24|0;if((k|0)>(l|0)|(k|0)==(l|0)&j>>>0>0>>>0){c[m>>2]=j;c[m+4>>2]=k;c[g>>2]=0;c[g+4>>2]=0;n=k;o=j;p=6}else{j=c[m>>2]|0;k=c[m+4>>2]|0;m=0;if((k|0)>(m|0)|(k|0)==(m|0)&j>>>0>0>>>0){n=k;o=j;p=6}else{q=e}}if((p|0)==6){p=f+24|0;j=(e|0)<0|0?-1:0;k=(j|0)>(n|0)|(j|0)==(n|0)&e>>>0>o>>>0?o:e;e=xrc(o,n,k,(k|0)<0|0?-1:0)|0;c[p>>2]=e;c[p+4>>2]=G;q=k}if((q|0)==0){h=-541478725;i=b;return h|0}k=oi(a,q)|0;if((k|0)==0){h=-12;i=b;return h|0}p=a+48|0;if((c[k+344>>2]|0)!=(c[p>>2]|0)){KIb(0,0,2629464,(r=i,i=i+24|0,c[r>>2]=2604624,c[r+8>>2]=2578928,c[r+16>>2]=111,r)|0);i=r;Hd();return 0}if((c[k+76>>2]|0)!=(q|0)){KIb(0,0,2629464,(r=i,i=i+24|0,c[r>>2]=2559320,c[r+8>>2]=2578928,c[r+16>>2]=112,r)|0);i=r;Hd();return 0}r=c[k+64>>2]|0;e=GHb(k)|0;VKb(r,0,q,e,c[k+80>>2]|0)|0;e=f+8|0;f=c[e+4>>2]|0;r=k+136|0;c[r>>2]=c[e>>2];c[r+4>>2]=f;if(!((c[e>>2]|0)==0&(c[e+4>>2]|0)==(-2147483648|0))){c[d>>2]=1;c[d+4>>2]=c[p>>2];p=XIb(q,(q|0)<0|0?-1:0,d,a+56|0)|0;d=wrc(c[e>>2]|0,c[e+4>>2]|0,p,G)|0;c[e>>2]=d;c[e+4>>2]=G}h=lj(a,k)|0;i=b;return h|0}function nx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=g+32|0;j=c[h>>2]|0;k=c[h+4>>2]|0;l=c[b+76>>2]|0;if(!((j|0)==0&(k|0)==0)){m=xrc(j,k,l,(l|0)<0|0?-1:0)|0;c[h>>2]=m;c[h+4>>2]=G}h=b+136|0;m=c[h>>2]|0;k=c[h+4>>2]|0;c[e>>2]=1;c[e+4>>2]=c[a+48>>2];h=XIb(l,(l|0)<0|0?-1:0,e,a+56|0)|0;a=wrc(h,G,m,k)|0;k=g+8|0;c[k>>2]=a;c[k+4>>2]=G;k=lj(c[c[f+32>>2]>>2]|0,b)|0;i=d;return k|0}function ox(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0,j=0.0,k=0,l=0.0,m=0.0;b=i;d=c[a+44>>2]|0;e=d+8|0;f=+h[e>>3];g=d+32|0;j=+h[g>>3];if(f>1.0-j*j){KIb(a,24,2413e3,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=+h[e>>3];m=+h[g>>3]}else{l=f;m=j}if(!(l/(1.0-m)>1.0/+h[d+16>>3])){i=b;return 0}KIb(a,24,2335288,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;i=b;return 0}function px(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+56|0);mJb(b+64|0);return}function qx(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(684072)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function rx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0.0,r=0,s=0.0,t=0;b=i;d=c[a>>2]|0;a=c[d+44>>2]|0;e=c[c[d+16>>2]>>2]|0;d=e+48|0;f=~~(+h[a+24>>3]*.001*+(c[d>>2]|0)+.5);g=a+52|0;c[g>>2]=f;j=a+56|0;c[j>>2]=qJb(f,c[e+148>>2]<<3)|0;f=~~(+(c[d>>2]|0)/+h[a+40>>3]+.5);d=a+60|0;c[d>>2]=f;k=hJb(f<<2)|0;c[a+64>>2]=k;if((k|0)==0){l=-12;i=b;return l|0}if((c[j>>2]|0)==0){l=-12;i=b;return l|0}j=c[d>>2]|0;m=+(j|0);d=~~(m*.25+.5);if((j|0)!=0){f=c[a+48>>2]|0;n=+(c[g>>2]|0)+-1.0;if((f|0)==1){g=0;o=k;while(1){p=((g+d|0)>>>0)%(j>>>0)|0;q=+(p>>>0>>>0)*2.0/m;r=(p<<2>>>0)/(j>>>0)|0;if((r|0)==0){s=q+.5}else if((r|0)==1|(r|0)==2){s=1.5-q}else if((r|0)==3){s=q+ -1.5}else{s=q}q=n*s+1.0;c[o>>2]=~~(q+(q<0.0?-.5:.5));r=g+1|0;if(r>>>0<j>>>0){g=r;o=o+4|0}else{break}}}else if((f|0)==0){f=0;o=k;while(1){s=n*(+V(+((((f+d|0)>>>0)%(j>>>0)|0)>>>0>>>0)/m*2.0*3.141592653589793)+1.0)*.5+1.0;c[o>>2]=~~(s+(s<0.0?-.5:.5));k=f+1|0;if(k>>>0<j>>>0){f=k;o=o+4|0}else{break}}}else{KIb(0,0,2452264,(t=i,i=i+24|0,c[t>>2]=2435944,c[t+8>>2]=2426120,c[t+16>>2]=145,t)|0);i=t;Hd();return 0}}c[a+72>>2]=0;c[a+68>>2]=0;switch(c[e+52>>2]|0){case 8:{c[a+76>>2]=380;l=0;i=b;return l|0};case 1:{c[a+76>>2]=544;l=0;i=b;return l|0};case 3:{c[a+76>>2]=190;l=0;i=b;return l|0};case 4:{c[a+76>>2]=676;l=0;i=b;return l|0};case 6:{c[a+76>>2]=258;l=0;i=b;return l|0};case 9:{c[a+76>>2]=194;l=0;i=b;return l|0};case 2:{c[a+76>>2]=572;l=0;i=b;return l|0};case 7:{c[a+76>>2]=186;l=0;i=b;return l|0};default:{KIb(0,0,2452264,(t=i,i=i+24|0,c[t>>2]=2435944,c[t+8>>2]=2426120,c[t+16>>2]=292,t)|0);i=t;Hd();return 0}}return 0}function sx(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0;g=c[a+56>>2]|0;i=a+68|0;j=c[i>>2]|0;k=a+72|0;l=c[k>>2]|0;if((e|0)<=0){m=l;n=j;c[i>>2]=n;c[k>>2]=m;return}o=c[a+64>>2]|0;p=c[a+52>>2]|0;q=c[a+60>>2]|0;r=a+8|0;s=a+32|0;t=a+16|0;if((f|0)>0){u=c[b>>2]|0;v=c[d>>2]|0;w=l;x=j;y=0}else{d=l;l=j;j=0;while(1){b=l+1|0;a=b-((b|0)<(p|0)?0:p)|0;b=d+1|0;z=b-((b|0)<(q|0)?0:q)|0;b=j+1|0;if((b|0)<(e|0)){d=z;l=a;j=b}else{m=z;n=a;break}}c[i>>2]=n;c[k>>2]=m;return}while(1){j=(c[o+(w<<2)>>2]|0)+x|0;l=ca(j-((j|0)<(p|0)?0:p)|0,f)|0;j=x+1|0;d=j-((j|0)<(p|0)?0:p)|0;j=ca(d,f)|0;a=v+(f<<3)|0;z=u;b=v;A=0;while(1){B=+h[z>>3]*+h[r>>3]+ +h[g+(A+l<<3)>>3]*+h[s>>3];h[g+(A+j<<3)>>3]=B;h[b>>3]=+h[t>>3]*B;C=A+1|0;if((C|0)<(f|0)){z=z+8|0;b=b+8|0;A=C}else{break}}A=w+1|0;b=A-((A|0)<(q|0)?0:q)|0;A=y+1|0;if((A|0)<(e|0)){u=u+(f<<3)|0;v=a;w=b;x=d;y=A}else{m=b;n=d;break}}c[i>>2]=n;c[k>>2]=m;return}function tx(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0;g=i;if((f|0)<=0){KIb(0,0,2452264,(j=i,i=i+24|0,c[j>>2]=2415256,c[j+8>>2]=2426120,c[j+16>>2]=254,j)|0);i=j;Hd()}j=c[a+56>>2]|0;k=c[a+52>>2]|0;l=a+68|0;m=c[l>>2]|0;n=a+72|0;o=c[n>>2]|0;p=(e|0)>0;q=a+8|0;r=a+64|0;s=a+32|0;t=a+60|0;u=a+16|0;a=0;do{v=ca(k,a)|0;if(p){w=c[r>>2]|0;x=c[t>>2]|0;y=m;z=o;A=c[b+(a<<2)>>2]|0;B=c[d+(a<<2)>>2]|0;C=0;while(1){D=(c[w+(z<<2)>>2]|0)+y|0;E=+h[A>>3]*+h[q>>3]+ +h[j+(D+v+((D|0)<(k|0)?0:-k|0)<<3)>>3]*+h[s>>3];D=z+1|0;F=D-((D|0)<(x|0)?0:x)|0;D=y+1|0;G=D-((D|0)<(k|0)?0:k)|0;h[j+(G+v<<3)>>3]=E;h[B>>3]=E*+h[u>>3];D=C+1|0;if((D|0)<(e|0)){y=G;z=F;A=A+8|0;B=B+8|0;C=D}else{H=G;I=F;break}}}else{H=m;I=o}a=a+1|0;}while((a|0)<(f|0));c[l>>2]=H;c[n>>2]=I;i=g;return}function ux(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0;i=c[a+56>>2]|0;j=a+68|0;k=c[j>>2]|0;l=a+72|0;m=c[l>>2]|0;if((e|0)<=0){n=m;o=k;c[j>>2]=o;c[l>>2]=n;return}p=c[a+64>>2]|0;q=c[a+52>>2]|0;r=(f|0)>0;s=c[a+60>>2]|0;t=a+8|0;u=a+32|0;v=a+16|0;a=c[b>>2]|0;b=c[d>>2]|0;d=m;m=k;k=0;while(1){w=(c[p+(d<<2)>>2]|0)+m|0;x=ca(w-((w|0)<(q|0)?0:q)|0,f)|0;w=m+1|0;y=w-((w|0)<(q|0)?0:q)|0;w=ca(y,f)|0;if(r){z=b+(f<<2)|0;A=a;B=b;C=0;while(1){D=+g[A>>2]*+h[t>>3]+ +h[i+(C+x<<3)>>3]*+h[u>>3];h[i+(C+w<<3)>>3]=D;g[B>>2]=+h[v>>3]*D;E=C+1|0;if((E|0)<(f|0)){A=A+4|0;B=B+4|0;C=E}else{break}}F=a+(f<<2)|0;G=z}else{F=a;G=b}C=d+1|0;B=C-((C|0)<(s|0)?0:s)|0;C=k+1|0;if((C|0)<(e|0)){a=F;b=G;d=B;m=y;k=C}else{n=B;o=y;break}}c[j>>2]=o;c[l>>2]=n;return}function vx(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0;j=i;if((f|0)<=0){KIb(0,0,2452264,(k=i,i=i+24|0,c[k>>2]=2415256,c[k+8>>2]=2426120,c[k+16>>2]=255,k)|0);i=k;Hd()}k=c[a+56>>2]|0;l=c[a+52>>2]|0;m=a+68|0;n=c[m>>2]|0;o=a+72|0;p=c[o>>2]|0;q=(e|0)>0;r=a+8|0;s=a+64|0;t=a+32|0;u=a+60|0;v=a+16|0;a=0;do{w=ca(l,a)|0;if(q){x=c[s>>2]|0;y=c[u>>2]|0;z=n;A=p;B=c[b+(a<<2)>>2]|0;C=c[d+(a<<2)>>2]|0;D=0;while(1){E=(c[x+(A<<2)>>2]|0)+z|0;F=+g[B>>2]*+h[r>>3]+ +h[k+(E+w+((E|0)<(l|0)?0:-l|0)<<3)>>3]*+h[t>>3];E=A+1|0;G=E-((E|0)<(y|0)?0:y)|0;E=z+1|0;H=E-((E|0)<(l|0)?0:l)|0;h[k+(H+w<<3)>>3]=F;g[C>>2]=F*+h[v>>3];E=D+1|0;if((E|0)<(e|0)){z=H;A=G;B=B+4|0;C=C+4|0;D=E}else{I=H;J=G;break}}}else{I=n;J=p}a=a+1|0;}while((a|0)<(f|0));c[m>>2]=I;c[o>>2]=J;i=j;return}function wx(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0;i=c[a+56>>2]|0;j=a+68|0;k=c[j>>2]|0;l=a+72|0;m=c[l>>2]|0;if((f|0)<=0){n=m;o=k;c[j>>2]=o;c[l>>2]=n;return}p=c[a+64>>2]|0;q=c[a+52>>2]|0;r=(g|0)>0;s=c[a+60>>2]|0;t=a+8|0;u=a+32|0;v=a+16|0;a=c[d>>2]|0;d=c[e>>2]|0;e=m;m=k;k=0;while(1){w=(c[p+(e<<2)>>2]|0)+m|0;x=ca(w-((w|0)<(q|0)?0:q)|0,g)|0;w=m+1|0;y=w-((w|0)<(q|0)?0:q)|0;w=ca(y,g)|0;if(r){z=d+(g<<1)|0;A=a;B=d;C=0;while(1){D=+(b[A>>1]|0)*+h[t>>3]+ +h[i+(C+x<<3)>>3]*+h[u>>3];h[i+(C+w<<3)>>3]=D;b[B>>1]=~~(+h[v>>3]*D);E=C+1|0;if((E|0)<(g|0)){A=A+2|0;B=B+2|0;C=E}else{break}}F=a+(g<<1)|0;G=z}else{F=a;G=d}C=e+1|0;B=C-((C|0)<(s|0)?0:s)|0;C=k+1|0;if((C|0)<(f|0)){a=F;d=G;e=B;m=y;k=C}else{n=B;o=y;break}}c[j>>2]=o;c[l>>2]=n;return}function xx(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0;j=i;if((g|0)<=0){KIb(0,0,2452264,(k=i,i=i+24|0,c[k>>2]=2415256,c[k+8>>2]=2426120,c[k+16>>2]=256,k)|0);i=k;Hd()}k=c[a+56>>2]|0;l=c[a+52>>2]|0;m=a+68|0;n=c[m>>2]|0;o=a+72|0;p=c[o>>2]|0;q=(f|0)>0;r=a+8|0;s=a+64|0;t=a+32|0;u=a+60|0;v=a+16|0;a=0;do{w=ca(l,a)|0;if(q){x=c[s>>2]|0;y=c[u>>2]|0;z=n;A=p;B=c[d+(a<<2)>>2]|0;C=c[e+(a<<2)>>2]|0;D=0;while(1){E=(c[x+(A<<2)>>2]|0)+z|0;F=+(b[B>>1]|0)*+h[r>>3]+ +h[k+(E+w+((E|0)<(l|0)?0:-l|0)<<3)>>3]*+h[t>>3];E=A+1|0;G=E-((E|0)<(y|0)?0:y)|0;E=z+1|0;H=E-((E|0)<(l|0)?0:l)|0;h[k+(H+w<<3)>>3]=F;b[C>>1]=~~(F*+h[v>>3]);E=D+1|0;if((E|0)<(f|0)){z=H;A=G;B=B+2|0;C=C+2|0;D=E}else{I=H;J=G;break}}}else{I=n;J=p}a=a+1|0;}while((a|0)<(g|0));c[m>>2]=I;c[o>>2]=J;i=j;return}function yx(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0;g=c[a+56>>2]|0;i=a+68|0;j=c[i>>2]|0;k=a+72|0;l=c[k>>2]|0;if((e|0)<=0){m=l;n=j;c[i>>2]=n;c[k>>2]=m;return}o=c[a+64>>2]|0;p=a+52|0;q=(f|0)>0;r=a+60|0;s=a+8|0;t=a+32|0;u=a+16|0;a=c[b>>2]|0;b=c[d>>2]|0;d=l;l=j;j=1;while(1){v=(c[o+(d<<2)>>2]|0)+l|0;w=c[p>>2]|0;x=ca(v-((v|0)<(w|0)?0:w)|0,f)|0;v=l+1|0;y=v-((v|0)<(w|0)?0:w)|0;w=ca(y,f)|0;if(q){v=b+(f<<2)|0;z=a;A=b;B=0;while(1){C=+(c[z>>2]|0)*+h[s>>3]+ +h[g+(B+x<<3)>>3]*+h[t>>3];h[g+(B+w<<3)>>3]=C;c[A>>2]=~~(+h[u>>3]*C);D=B+1|0;if((D|0)<(f|0)){z=z+4|0;A=A+4|0;B=D}else{break}}E=a+(f<<2)|0;F=v}else{E=a;F=b}B=d+1|0;A=c[r>>2]|0;z=B-((B|0)<(A|0)?0:A)|0;if((j|0)>=(e|0)){m=z;n=y;break}a=E;b=F;d=z;l=y;j=j+1|0}c[i>>2]=n;c[k>>2]=m;return}function zx(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0;g=i;if((f|0)<=0){KIb(0,0,2452264,(j=i,i=i+24|0,c[j>>2]=2415256,c[j+8>>2]=2426120,c[j+16>>2]=257,j)|0);i=j;Hd()}j=c[a+56>>2]|0;k=a+52|0;l=a+68|0;m=a+72|0;n=(e|0)>0;o=a+8|0;p=a+64|0;q=a+32|0;r=a+60|0;s=a+16|0;a=0;do{t=c[k>>2]|0;u=ca(t,a)|0;v=c[l>>2]|0;w=c[m>>2]|0;a:do{if(n){x=c[p>>2]|0;y=v;z=w;A=c[b+(a<<2)>>2]|0;B=c[d+(a<<2)>>2]|0;C=1;D=t;while(1){E=(c[x+(z<<2)>>2]|0)+y|0;F=+(c[A>>2]|0)*+h[o>>3]+ +h[j+(E+u+((E|0)<(D|0)?0:-D|0)<<3)>>3]*+h[q>>3];E=z+1|0;G=c[r>>2]|0;H=E-((E|0)<(G|0)?0:G)|0;G=y+1|0;E=G-((G|0)<(D|0)?0:D)|0;h[j+(E+u<<3)>>3]=F;c[B>>2]=~~(F*+h[s>>3]);if((C|0)>=(e|0)){I=E;J=H;break a}y=E;z=H;A=A+4|0;B=B+4|0;C=C+1|0;D=c[k>>2]|0}}else{I=v;J=w}}while(0);a=a+1|0;}while((a|0)<(f|0));c[l>>2]=I;c[m>>2]=J;i=g;return}function Ax(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;h=g;j=c[c[f+32>>2]>>2]|0;do{if((bIb(b)|0)==0){f=oi(a,c[b+76>>2]|0)|0;if((f|0)==0){k=-12;i=d;return k|0}else{ZHb(f,c[e>>2]|0)|0;l=f;m=c[e>>2]|0;break}}else{l=b;m=b}}while(0);b=c[g+76>>2]|0;g=c[m+64>>2]|0;a=c[l+64>>2]|0;f=c[l+76>>2]|0;n=GHb(l)|0;pe[b&1023](h,g,a,f,n);if((m|0)!=(l|0)){VHb(e)}k=lj(j,l)|0;i=d;return k|0}function Bx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+44>>2]|0;a=d+24|0;c[a>>2]=0;c[a+4>>2]=-2147483648;a=Xvb()|0;e=d+16|0;c[e>>2]=a;if((a|0)==0){f=-12;return f|0}do{if((b|0)==0){g=0}else{a=0;h=0;while(1){i=LGb(c[b>>2]|0,10230160,a,2)|0;if((i|0)==0){j=5;break}k=EJb(c[e>>2]|0,c[i>>2]|0,c[i+4>>2]|0,0)|0;if((k|0)<0){f=k;j=8;break}else{a=i;h=k}}if((j|0)==5){OGb(b);g=h;break}else if((j|0)==8){return f|0}}}while(0);j=c[d+4>>2]|0;if((j|0)<=0){f=g;return f|0}IJb(c[e>>2]|0,2412896,j,(j|0)<0|0?-1:0,0)|0;f=g;return f|0}function Cx(a){a=a|0;Zvb((c[a+44>>2]|0)+16|0);return}function Dx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=(c[a+44>>2]|0)+16|0;h=NJb(c[g>>2]|0,2412896,0)|0;j=h;h=NJb(c[g>>2]|0,2335184,0)|0;k=G;l=NJb(c[g>>2]|0,2278152,0)|0;g=l;l=c[c[a+16>>2]>>2]|0;m=c[c[a+32>>2]>>2]|0;a=Sk(1)|0;n=Uk()|0;o=Wk()|0;Yk(a,l+68|0);Yk(n,l+76|0);Xk(o,l+84|0);if((j|0)>0){l=d|0;c[l>>2]=j;c[d+4>>2]=-1;p=Ok(l)|0}else{p=Uk()|0}Yk(p,m+72|0);if((g|0)==-1){q=Sk(1)|0}else{p=e|0;c[p>>2]=g;c[e+4>>2]=-1;q=Ok(p)|0}Yk(q,m+64|0);if((h|0)==0&(k|0)==0){r=Wk()|0;s=m+80|0;Xk(r,s);i=b;return 0}else{q=f|0;c[q>>2]=h;c[q+4>>2]=k;k=f+8|0;c[k>>2]=-1;c[k+4>>2]=-1;r=Pk(q)|0;s=m+80|0;Xk(r,s);i=b;return 0}return 0}function Ex(a,b){a=a|0;b=b|0;var d=0;if((b|0)!=0){d=0;return d|0}d=c[a+16>>2]|0;return d|0}function Fx(a){a=a|0;var b=0;if((a|0)==0){b=Wvb()|0}else{b=0}return b|0}function Gx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=e+16|0;e=c[c[g>>2]>>2]|0;h=f+32|0;c[h>>2]=0;j=e;while(1){k=Wi(j)|0;if(!((c[h>>2]|0)==0&(k|0)>-1)){break}j=c[c[g>>2]>>2]|0}if(!((k|0)==-541478725)){l=k;i=b;return l|0}k=oi(a,4096)|0;c[d>>2]=k;if((k|0)==0){l=-12;i=b;return l|0}g=f+16|0;f=gwb(c[g>>2]|0,0,-2147483648)|0;j=G;h=c[e+48>>2]|0;e=h>>1;m=e;n=(e|0)<0|0?-1:0;e=bwb(c[g>>2]|0,c[k+64>>2]|0,4096,0,0)|0;if((e|0)<1){VHb(d);l=(e|0)==0?-541478725:e;i=b;return l|0}else{d=xrc(0,0,m,n)|0;g=0;o=(j|0)>(g|0)|(j|0)==(g|0)&f>>>0>0>>>0;g=wrc(o?m:d,o?n:G,f,j)|0;j=Crc(g,G,h,(h|0)<0|0?-1:0)|0;c[k+344>>2]=c[a+48>>2];c[k+76>>2]=e;e=k+136|0;c[e>>2]=j;c[e+4>>2]=G;l=lj(a,k)|0;i=b;return l|0}return 0}function Hx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+256|0;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=c[d+44>>2]|0;g=f+16|0;j=a+40|0;k=a+52|0;l=a+48|0;m=e+40|0;n=e+52|0;o=e+48|0;p=d;d=Yvb(c[g>>2]|0,c[j>>2]|0,c[j+4>>2]|0,c[k>>2]|0,c[l>>2]|0,c[m>>2]|0,c[m+4>>2]|0,c[n>>2]|0,c[o>>2]|0,0,p)|0;c[g>>2]=d;if((d|0)==0){q=-12;i=b;return q|0}if((c[m>>2]|0)==0&(c[m+4>>2]|0)==0){r=c[e+148>>2]|0;IJb(d,2135e3,r,(r|0)<0|0?-1:0,0)|0}if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){r=c[a+148>>2]|0;IJb(c[g>>2]|0,2111656,r,(r|0)<0|0?-1:0,0)|0}r=$vb(c[g>>2]|0)|0;if((r|0)<0){q=r;i=b;return q|0}r=NJb(c[g>>2]|0,2412896,0)|0;d=r;r=NJb(c[g>>2]|0,2335184,0)|0;s=G;t=NJb(c[g>>2]|0,2278152,0)|0;c[a+56>>2]=1;c[a+60>>2]=d;if((c[l>>2]|0)!=(d|0)){KIb(0,0,2629392,(u=i,i=i+24|0,c[u>>2]=2604512,c[u+8>>2]=2578800,c[u+16>>2]=157,u)|0);i=u;Hd();return 0}g=c[j>>2]|0;v=c[j+4>>2]|0;if(!((g|0)==(r|0)&(v|0)==(s|0)|(g|0)==0&(v|0)==0)){KIb(0,0,2629392,(u=i,i=i+24|0,c[u>>2]=2559200,c[u+8>>2]=2578800,c[u+16>>2]=158,u)|0);i=u;Hd();return 0}if((c[k>>2]|0)!=(t|0)){KIb(0,0,2629392,(u=i,i=i+24|0,c[u>>2]=2541824,c[u+8>>2]=2578800,c[u+16>>2]=159,u)|0);i=u;Hd();return 0}h[f+8>>3]=+(d|0)/+(c[o>>2]|0);d=b|0;f=e+148|0;sGb(d,128,c[f>>2]|0,c[m>>2]|0,c[m+4>>2]|0);m=b+128|0;e=a+148|0;sGb(m,128,c[e>>2]|0,c[j>>2]|0,c[j+4>>2]|0);j=c[f>>2]|0;f=LKb(c[n>>2]|0)|0;n=c[o>>2]|0;o=c[e>>2]|0;e=LKb(c[k>>2]|0)|0;k=c[l>>2]|0;KIb(p,40,2524672,(u=i,i=i+64|0,c[u>>2]=j,c[u+8>>2]=d,c[u+16>>2]=f,c[u+24>>2]=n,c[u+32>>2]=o,c[u+40>>2]=m,c[u+48>>2]=e,c[u+56>>2]=k,u)|0);i=u;q=0;i=b;return q|0}function Ix(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;j=c[g+44>>2]|0;k=c[b+76>>2]|0;l=~~(+(k|0)*+h[j+8>>3]+32.0);m=c[c[g+32>>2]>>2]|0;g=j+16|0;n=m+48|0;o=c[n>>2]|0;p=fwb(c[g>>2]|0,o,(o|0)<0|0?-1:0)|0;o=G;q=0;if((o|0)>(q|0)|(o|0)==(q|0)&p>>>0>0>>>0){q=wrc(p,o,l,0)|0;r=q}else{r=l}l=oi(m,r)|0;c[f>>2]=l;if((l|0)==0){s=-12;i=d;return s|0}ZHb(l,b)|0;c[l+80>>2]=c[m+52>>2];HHb(l,c[m+148>>2]|0);q=m+40|0;o=c[q+4>>2]|0;p=l+352|0;c[p>>2]=c[q>>2];c[p+4>>2]=o;c[l+344>>2]=c[n>>2];o=b+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;if((p|0)==0&(q|0)==(-2147483648|0)){o=l+136|0;c[o>>2]=0;c[o+4>>2]=-2147483648;t=l;u=b}else{b=c[a+56>>2]|0;l=c[n>>2]|0;n=Erc(l,(l|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;b=a+48|0;l=c[b>>2]|0;o=Erc(n,G,l,(l|0)<0|0?-1:0)|0;l=c[a+60>>2]|0;a=VIb(p,q,o,G,l,(l|0)<0|0?-1:0)|0;l=gwb(c[g>>2]|0,a,G)|0;a=G;o=0;q=(a|0)>(o|0)|(a|0)==(o|0)&l>>>0>0>>>0;o=c[b>>2]|0;b=o>>1;p=b;n=(b|0)<0|0?-1:0;b=xrc(0,0,p,n)|0;v=wrc(q?p:b,q?n:G,l,a)|0;a=Crc(v,G,o,(o|0)<0|0?-1:0)|0;o=G;v=c[f>>2]|0;l=v+136|0;c[l>>2]=a;c[l+4>>2]=o;l=j+24|0;c[l>>2]=a;c[l+4>>2]=o;t=v;u=c[e>>2]|0}v=bwb(c[g>>2]|0,c[t+64>>2]|0,r,c[u+64>>2]|0,k)|0;if((v|0)<1){VHb(f);VHb(e);s=0;i=d;return s|0}else{c[t+76>>2]=v;v=lj(m,t)|0;c[j+32>>2]=1;VHb(e);s=v;i=d;return s|0}return 0}function Jx(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a+44>>2]|0;e=d+16|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=c[d+24>>2]|0;KIb(a,40,2412768,(a=i,i=i+16|0,c[a>>2]=c[d+4>>2],c[a+8>>2]=e,a)|0);i=a;i=b;return 0}function Kx(a){a=a|0;tFb(c[(c[a+44>>2]|0)+8>>2]|0);return}function Lx(a){a=a|0;var b=0,d=0;b=Wi(c[c[(c[a>>2]|0)+16>>2]>>2]|0)|0;if(!((b|0)==-541478725)){d=b;return d|0}b=Nx(a)|0;if((b|0)<0){d=b;return d|0}d=(b|0)>0?0:-541478725;return d|0}function Mx(a){a=a|0;var b=0,d=0,e=0;b=c[(c[a>>2]|0)+44>>2]|0;d=uFb(c[a+52>>2]|0,c[a+148>>2]|0,c[b+4>>2]|0)|0;c[b+8>>2]=d;if((d|0)==0){e=-12;return e|0}d=a+156|0;c[d>>2]=c[d>>2]|1;e=0;return e|0}function Nx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[(c[a>>2]|0)+44>>2]|0;do{if((c[b+24>>2]|0)==0){d=b+4|0;e=c[d>>2]|0;f=b+8|0;if((e|0)>(yFb(c[f>>2]|0)|0)){g=0;h=yFb(c[f>>2]|0)|0;break}else{g=0;h=c[d>>2]|0;break}}else{d=b+8|0;if((yFb(c[d>>2]|0)|0)==0){i=0}else{i=c[b+4>>2]|0}if((i|0)>(yFb(c[d>>2]|0)|0)){j=yFb(c[d>>2]|0)|0}else{j=i}g=i-j|0;h=i}}while(0);if((h|0)==0){k=0;return k|0}i=oi(a,h)|0;if((i|0)==0){k=-12;return k|0}j=i+64|0;zFb(c[b+8>>2]|0,c[j>>2]|0,h)|0;if((g|0)!=0){VKb(c[j>>2]|0,h-g|0,g,c[a+148>>2]|0,c[a+52>>2]|0)|0}c[i+76>>2]=h;g=a+40|0;j=c[g+4>>2]|0;d=i+352|0;c[d>>2]=c[g>>2];c[d+4>>2]=j;c[i+344>>2]=c[a+48>>2];j=b+16|0;b=c[j+4>>2]|0;d=i+136|0;c[d>>2]=c[j>>2];c[d+4>>2]=b;b=c[j>>2]|0;d=c[j+4>>2]|0;if(!((b|0)==0&(d|0)==(-2147483648|0))){g=wrc(b,d,h,(h|0)<0|0?-1:0)|0;c[j>>2]=g;c[j+4>>2]=G}j=lj(a,i)|0;k=(j|0)<0?j:h;return k|0}function Ox(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;a=c[f+44>>2]|0;g=c[c[f+32>>2]>>2]|0;h=c[b+76>>2]|0;j=a+8|0;do{if((xFb(c[j>>2]|0)|0)<(h|0)){k=f;KIb(k,48,2629344,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l;m=c[j>>2]|0;if((vFb(m,(yFb(m)|0)+h|0)|0)>=0){n=c[e>>2]|0;break}KIb(k,16,2604416,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l;o=-1;i=d;return o|0}else{n=b}}while(0);wFb(c[j>>2]|0,c[n+64>>2]|0,h)|0;h=a+16|0;if((c[h>>2]|0)==0&(c[h+4>>2]|0)==(-2147483648|0)){b=n+136|0;n=c[b+4>>2]|0;c[h>>2]=c[b>>2];c[h+4>>2]=n}VHb(e);e=yFb(c[j>>2]|0)|0;n=a+4|0;if((e|0)<(c[n>>2]|0)){o=0;i=d;return o|0}while(1){Nx(g)|0;e=yFb(c[j>>2]|0)|0;if((e|0)<(c[n>>2]|0)){o=0;break}}i=d;return o|0}function Px(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+8|0;d=b|0;e=d|0;c[e>>2]=c[(c[a+44>>2]|0)+4>>2];c[d+4>>2]=-1;d=Ok(e)|0;Yk(d,(c[c[a+32>>2]>>2]|0)+72|0);i=b;return 0}function Qx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=c[a>>2]|0;e=c[c[d+16>>2]>>2]|0;f=e+56|0;g=c[f>>2]|0;h=c[f+4>>2]|0;f=g;j=h;k=j;l=c[e+48>>2]|0;if((f|0)==1&(k|0)==(l|0)){c[a+56>>2]=1;c[a+60>>2]=c[a+48>>2];i=b;return 0}e=c[d+44>>2]|0;m=a+56|0;c[m>>2]=g|0;c[m+4>>2]=j|h&0;c[e+8>>2]=1;e=c[a+48>>2]|0;if(!(+(f|0)/+(k|0)>1.0/+(((l|0)>(e|0)?l:e)|0))){i=b;return 0}KIb(d,24,2191024,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;i=b;return 0}function Rx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=c[c[d+32>>2]>>2]|0;d=f+48|0;c[b+344>>2]=c[d>>2];if((c[e+8>>2]|0)==0){g=lj(f,b)|0;return g|0}e=b+136|0;h=c[a+48>>2]|0;a=c[d>>2]|0;d=VIb(c[e>>2]|0,c[e+4>>2]|0,h,(h|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;c[e>>2]=d;c[e+4>>2]=G;g=lj(f,b)|0;return g|0}function Sx(a){a=a|0;mJb(c[a+44>>2]|0);return}function Tx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+192|0;f=e|0;g=e+128|0;j=e+160|0;k=b+8|0;l=c[k>>2]|0;m=c[l+44>>2]|0;n=c[b+148>>2]|0;o=d+80|0;p=RKb(c[o>>2]|0)|0;q=QKb(c[o>>2]|0)|0;r=(p|0)!=0;p=ca(q,r?1:n)|0;q=d+76|0;s=ca(p,c[q>>2]|0)|0;p=r?n:1;r=m;m=iJb(c[r>>2]|0,n<<2)|0;if((m|0)==0){t=-12;i=e;return t|0}n=m;c[r>>2]=n;m=(p|0)>0;if(m){u=c[d+64>>2]|0;v=0;w=0;while(1){x=c[u+(v<<2)>>2]|0;c[n+(v<<2)>>2]=oFb(0,x,s)|0;if((v|0)==0){y=c[n>>2]|0}else{y=oFb(w,x,s)|0}x=v+1|0;if((x|0)<(p|0)){v=x;w=y}else{z=y;break}}}else{z=0}y=f|0;f=d+352|0;sGb(y,128,-1,c[f>>2]|0,c[f+4>>2]|0);f=l;l=b+160|0;w=c[l>>2]|0;v=c[l+4>>2]|0;l=g|0;mrc(l|0,0,32)|0;a[l]=0;g=d+136|0;s=c[g>>2]|0;n=c[g+4>>2]|0;if((s|0)==0&(n|0)==(-2147483648|0)){Rb(l|0,32,2160376,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0)|0;i=A}else{Rb(l|0,32,2111544,(A=i,i=i+16|0,c[A>>2]=s,c[A+8>>2]=n,A)|0)|0;i=A}n=j|0;mrc(n|0,0,32)|0;a[n]=0;j=c[g>>2]|0;s=c[g+4>>2]|0;if((j|0)==0&(s|0)==(-2147483648|0)){Rb(n|0,32,2160376,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0)|0;i=A}else{Rb(n|0,32,2134912,(A=i,i=i+8|0,h[A>>3]=(+(j>>>0)+ +(s|0)*4294967296.0)*(+(c[b+56>>2]|0)/+(c[b+60>>2]|0)),A)|0)|0;i=A}b=DHb(d)|0;s=G;j=LKb(c[o>>2]|0)|0;o=GHb(d)|0;g=c[d+344>>2]|0;u=c[q>>2]|0;KIb(f,32,2334856,(A=i,i=i+96|0,c[A>>2]=w,c[A+8>>2]=v,c[A+16>>2]=l,c[A+24>>2]=n,c[A+32>>2]=b,c[A+40>>2]=s,c[A+48>>2]=j,c[A+56>>2]=o,c[A+64>>2]=y,c[A+72>>2]=g,c[A+80>>2]=u,c[A+88>>2]=z,A)|0);i=A;KIb(f,32,2277904,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;if(m){m=0;do{KIb(f,32,2228552,(A=i,i=i+8|0,c[A>>2]=c[(c[r>>2]|0)+(m<<2)>>2],A)|0);i=A;m=m+1|0;}while((m|0)<(p|0))}KIb(f,32,2190976,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;t=lj(c[c[(c[k>>2]|0)+32>>2]>>2]|0,d)|0;i=e;return t|0}function Ux(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0.0,H=0.0,I=0.0,J=0.0,K=0,L=0.0,M=0.0,N=0,O=0.0,P=0,Q=0.0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0,aa=0.0,ba=0,ca=0.0,da=0,ea=0.0,fa=0.0,ga=0.0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0.0,ta=0,ua=0,va=0,wa=0.0,xa=0,ya=0,za=0.0,Aa=0.0,Ba=0.0,Ca=0.0,Da=0,Ea=0.0,Fa=0.0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;b=i;d=c[a+44>>2]|0;e=d+8|0;if((c[e>>2]|0)>0){f=d+4|0;g=d+16|0;j=a;k=0;l=0;m=0;n=0;o=0.0;p=0.0;q=1.7976931348623157e+308;r=2.2250738585072014e-308;s=0.0;t=0.0;u=1.7976931348623157e+308;v=2.2250738585072014e-308;w=0;x=0;y=0;while(1){z=c[f>>2]|0;A=z+(w*120|0)+112|0;B=c[A>>2]|0;C=c[A+4>>2]|0;D=c[g+4>>2]|0;if(C>>>0<D>>>0|C>>>0==D>>>0&B>>>0<(c[g>>2]|0)>>>0){E=+h[z+(w*120|0)+16>>3];F=E/(+(B>>>0)+ +(C>>>0)*4294967296.0);h[z+(w*120|0)+40>>3]=F;h[z+(w*120|0)+32>>3]=F;H=F;I=F;J=E}else{H=+h[z+(w*120|0)+32>>3];I=+h[z+(w*120|0)+40>>3];J=+h[z+(w*120|0)+16>>3]}D=z+(w*120|0)+48|0;E=+h[D>>3];F=q>E?E:q;K=z+(w*120|0)+56|0;E=+h[K>>3];L=r>E?r:E;E=u>H?H:u;M=v>I?v:I;N=z+(w*120|0)+8|0;O=+h[N>>3];P=z+(w*120|0)+16|0;Q=t+J;T=z+(w*120|0)+96|0;U=wrc(c[T>>2]|0,c[T+4>>2]|0,y,x)|0;V=G;W=z+(w*120|0)+104|0;X=wrc(c[W>>2]|0,c[W+4>>2]|0,l,k)|0;Y=G;Z=z+(w*120|0)+80|0;_=o+ +h[Z>>3];$=z+(w*120|0)+88|0;aa=p+ +h[$>>3];ba=wrc(B,C,n,m)|0;C=G;B=+R(+O)>+R(+s);ca=B?O:s;B=w+1|0;KIb(j,32,2412440,(da=i,i=i+8|0,c[da>>2]=B,da)|0);i=da;KIb(j,32,2334736,(da=i,i=i+8|0,h[da>>3]=+h[N>>3]/(+((c[A>>2]|0)>>>0)+ +((c[A+4>>2]|0)>>>0)*4294967296.0),da)|0);i=da;KIb(j,32,2277872,(da=i,i=i+8|0,h[da>>3]=+h[D>>3],da)|0);i=da;KIb(j,32,2228512,(da=i,i=i+8|0,h[da>>3]=+h[K>>3],da)|0);i=da;O=-0.0- +h[D>>3];ea=+h[K>>3];fa=+fd(+(ea<O?O:ea))*20.0;KIb(j,32,2190920,(da=i,i=i+8|0,h[da>>3]=fa,da)|0);i=da;fa=+fd(+(+S(+h[P>>3]/(+((c[A>>2]|0)>>>0)+ +((c[A+4>>2]|0)>>>0)*4294967296.0))))*20.0;KIb(j,32,2160312,(da=i,i=i+8|0,h[da>>3]=fa,da)|0);i=da;fa=+fd(+(+S(+h[z+(w*120|0)+40>>3])))*20.0;KIb(j,32,2134848,(da=i,i=i+8|0,h[da>>3]=fa,da)|0);i=da;fa=+h[z+(w*120|0)+32>>3];if(fa!=1.0){ea=+fd(+(+S(fa)))*20.0;KIb(j,32,2111448,(da=i,i=i+8|0,h[da>>3]=ea,da)|0);i=da}ea=+h[P>>3];if(ea!=0.0){fa=-0.0- +h[D>>3];O=+h[K>>3];ga=(O<fa?fa:O)/+S(ea/(+((c[A>>2]|0)>>>0)+ +((c[A+4>>2]|0)>>>0)*4294967296.0))}else{ga=1.0}KIb(j,32,2629192,(da=i,i=i+8|0,h[da>>3]=ga,da)|0);i=da;ea=+h[Z>>3]+ +h[$>>3];$=wrc(c[W>>2]|0,c[W+4>>2]|0,c[T>>2]|0,c[T+4>>2]|0)|0;O=+fd(+(ea/(+($>>>0)+ +(G>>>0)*4294967296.0)))*20.0;KIb(j,32,2604240,(da=i,i=i+8|0,h[da>>3]=O,da)|0);i=da;$=wrc(c[W>>2]|0,c[W+4>>2]|0,c[T>>2]|0,c[T+4>>2]|0)|0;T=G;KIb(j,32,2578552,(da=i,i=i+16|0,c[da>>2]=$,c[da+8>>2]=T,da)|0);i=da;if((B|0)<(c[e>>2]|0)){k=Y;l=X;m=C;n=ba;o=_;p=aa;q=F;r=L;s=ca;t=Q;u=E;v=M;w=B;x=V;y=U}else{ha=Y;ia=X;ja=C;ka=ba;la=_;ma=aa;na=F;oa=L;pa=ca;qa=Q;ra=E;sa=M;ta=V;ua=U;va=j;break}}}else{ha=0;ia=0;ja=0;ka=0;la=0.0;ma=0.0;na=1.7976931348623157e+308;oa=2.2250738585072014e-308;pa=0.0;qa=0.0;ra=1.7976931348623157e+308;sa=2.2250738585072014e-308;ta=0;ua=0;va=a}KIb(va,32,2559072,(da=i,i=i+1|0,i=i+7&-8,c[da>>2]=0,da)|0);i=da;a=c[e>>2]|0;j=Frc(ka,ja,a,(a|0)<0|0?-1:0)|0;v=pa/(+(j>>>0)+ +(G>>>0)*4294967296.0);KIb(va,32,2334736,(da=i,i=i+8|0,h[da>>3]=v,da)|0);i=da;KIb(va,32,2277872,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;KIb(va,32,2228512,(da=i,i=i+8|0,h[da>>3]=oa,da)|0);i=da;v=-0.0-na;na=+fd(+(oa<v?v:oa))*20.0;KIb(va,32,2190920,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;na=+fd(+(+S(qa/(+(ka>>>0)+ +(ja>>>0)*4294967296.0))))*20.0;KIb(va,32,2160312,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;na=+fd(+(+S(sa)))*20.0;KIb(va,32,2134848,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;if(!(ra!=1.0)){wa=ma+la;xa=wrc(ia,ha,ua,ta)|0;ya=G;za=+(xa>>>0)+ +(ya>>>0)*4294967296.0;Aa=wa/za;Ba=+fd(+Aa);Ca=Ba*20.0;KIb(va,32,2604240,(da=i,i=i+8|0,h[da>>3]=Ca,da)|0);i=da;Da=c[e>>2]|0;Ea=+(Da|0);Fa=za/Ea;KIb(va,32,2541704,(da=i,i=i+8|0,h[da>>3]=Fa,da)|0);i=da;Ga=c[e>>2]|0;Ha=Ga;Ia=(Ga|0)<0|0?-1:0;Ja=Frc(ka,ja,Ha,Ia)|0;Ka=G;La=2524560;KIb(va,32,La,(da=i,i=i+16|0,c[da>>2]=Ja,c[da+8>>2]=Ka,da)|0);i=da;Ma=d+4|0;mJb(Ma);i=b;return}na=+fd(+(+S(ra)))*20.0;KIb(va,32,2111448,(da=i,i=i+8|0,h[da>>3]=na,da)|0);i=da;wa=ma+la;xa=wrc(ia,ha,ua,ta)|0;ya=G;za=+(xa>>>0)+ +(ya>>>0)*4294967296.0;Aa=wa/za;Ba=+fd(+Aa);Ca=Ba*20.0;KIb(va,32,2604240,(da=i,i=i+8|0,h[da>>3]=Ca,da)|0);i=da;Da=c[e>>2]|0;Ea=+(Da|0);Fa=za/Ea;KIb(va,32,2541704,(da=i,i=i+8|0,h[da>>3]=Fa,da)|0);i=da;Ga=c[e>>2]|0;Ha=Ga;Ia=(Ga|0)<0|0?-1:0;Ja=Frc(ka,ja,Ha,Ia)|0;Ka=G;La=2524560;KIb(va,32,La,(da=i,i=i+16|0,c[da>>2]=Ja,c[da+8>>2]=Ka,da)|0);i=da;Ma=d+4|0;mJb(Ma);i=b;return}function Vx(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(684056)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function Wx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,i=0.0,j=0.0,k=0.0,l=0;b=c[(c[a>>2]|0)+44>>2]|0;d=a+148|0;e=qJb(120,c[d>>2]|0)|0;f=e;c[b+4>>2]=f;if((e|0)==0){g=-12;return g|0}e=c[d>>2]|0;c[b+8>>2]=e;i=+h[b+24>>3];j=+(c[a+48>>2]|0);h[b+32>>3]=+$(-1.0/i/j);k=i*5.0*j+.5;a=(F=+k,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);d=b+16|0;c[d>>2]=~~+k>>>0;c[d+4>>2]=a;if((e|0)>0){l=0}else{g=0;return g|0}while(1){h[f+(l*120|0)+32>>3]=1.7976931348623157e+308;h[f+(l*120|0)+48>>3]=1.7976931348623157e+308;h[f+(l*120|0)+40>>3]=2.2250738585072014e-308;h[f+(l*120|0)+56>>3]=2.2250738585072014e-308;a=l+1|0;if((a|0)<(e|0)){l=a}else{g=0;break}}return g|0}function Xx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a+8|0;e=c[(c[d>>2]|0)+44>>2]|0;f=e;g=c[e+8>>2]|0;i=c[a+52>>2]|0;a:do{if((i|0)==4){a=b+76|0;j=c[a>>2]|0;if((j|0)<=0){break}k=e+4|0;if((g|0)>0){l=0;m=c[c[b+64>>2]>>2]|0}else{n=0;while(1){n=n+1|0;if((n|0)>=(j|0)){break a}}}while(1){j=0;n=m;while(1){Yx(f,(c[k>>2]|0)+(j*120|0)|0,+h[n>>3]);o=j+1|0;if((o|0)<(g|0)){j=o;n=n+8|0}else{break}}n=l+1|0;if((n|0)<(c[a>>2]|0)){l=n;m=m+(g<<3)|0}else{break}}}else if((i|0)==9){if((g|0)<=0){break}a=e+4|0;k=b+64|0;n=b+76|0;j=0;o=c[n>>2]|0;while(1){p=(c[a>>2]|0)+(j*120|0)|0;if((o|0)>0){q=0;r=c[(c[k>>2]|0)+(j<<2)>>2]|0;while(1){Yx(f,p,+h[r>>3]);s=q+1|0;t=c[n>>2]|0;if((s|0)<(t|0)){q=s;r=r+8|0}else{u=t;break}}}else{u=o}r=j+1|0;if((r|0)<(g|0)){j=r;o=u}else{break}}}}while(0);return lj(c[c[(c[d>>2]|0)+32>>2]>>2]|0,b)|0}function Yx(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0.0,g=0,i=0.0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+48|0;f=+h[e>>3];do{if(f>d){h[e>>3]=d;h[b+64>>3]=1.0;h[b+80>>3]=0.0;g=b+96|0;c[g>>2]=1;c[g+4>>2]=0}else{if(!(f==d)){if(!(+h[b>>3]==f)){break}i=+h[b+64>>3];g=b+80|0;h[g>>3]=+h[g>>3]+i*i;break}g=b+96|0;j=wrc(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=j;c[g+4>>2]=G;g=b+64|0;if(+h[b>>3]==d){k=+h[g>>3]+1.0}else{k=1.0}h[g>>3]=k}}while(0);e=b+56|0;k=+h[e>>3];do{if(k<d){h[e>>3]=d;h[b+72>>3]=1.0;h[b+88>>3]=0.0;g=b+104|0;c[g>>2]=1;c[g+4>>2]=0;l=b|0}else{if(!(k==d)){g=b|0;if(!(+h[g>>3]==k)){l=g;break}f=+h[b+72>>3];j=b+88|0;h[j>>3]=+h[j>>3]+f*f;l=g;break}g=b+104|0;j=wrc(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=j;c[g+4>>2]=G;g=b|0;j=b+72|0;if(+h[g>>3]==d){m=+h[j>>3]+1.0}else{m=1.0}h[j>>3]=m;l=g}}while(0);e=b+8|0;h[e>>3]=+h[e>>3]+d;e=b+16|0;h[e>>3]=d*d+ +h[e>>3];e=b+24|0;m=+h[a+32>>3];k=+h[e>>3]*m+(1.0-m)*d*d;h[e>>3]=k;h[l>>3]=d;l=b+112|0;e=c[l>>2]|0;g=c[l+4>>2]|0;j=a+16|0;a=c[j+4>>2]|0;if(g>>>0<a>>>0|g>>>0==a>>>0&e>>>0<(c[j>>2]|0)>>>0){n=1;o=0;p=wrc(e,g,n,o)|0;q=G;r=l|0;c[r>>2]=p;s=l+4|0;c[s>>2]=q;return}j=b+40|0;d=+h[j>>3];h[j>>3]=d>k?d:k;j=b+32|0;d=+h[j>>3];h[j>>3]=d>k?k:d;n=1;o=0;p=wrc(e,g,n,o)|0;q=G;r=l|0;c[r>>2]=p;s=l+4|0;c[s>>2]=q;return}function Zx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=d+4|0;f=d+8|0;g=a;a=UGb(e,c[f>>2]|0,281160,0,0,0,0,0,g)|0;if((a|0)<0){KIb(g,16,2412320,(g=i,i=i+8|0,c[g>>2]=c[f>>2],g)|0);i=g;h=a;i=b;return h|0}a=d+16|0;d=0;while(1){+XGb(c[e>>2]|0,a,0);g=d+1|0;if((g|0)<42){d=g}else{h=0;break}}i=b;return h|0}function _x(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+4|0;TGb(c[b>>2]|0);c[b>>2]=0;return}function $x(a){a=a|0;var b=0,d=0,e=0;b=a+16|0;d=a+32|0;a=c[c[b>>2]>>2]|0;e=c[a+64>>2]|0;Yk(e,a+68|0);Yk(e,(c[c[d>>2]>>2]|0)+64|0);e=Uk()|0;Yk(e,(c[c[b>>2]>>2]|0)+76|0);Yk(e,(c[c[d>>2]>>2]|0)+72|0);e=c[c[b>>2]>>2]|0;a=c[e+80>>2]|0;Xk(a,e+84|0);Xk(a,(c[c[d>>2]>>2]|0)+80|0);a=c[(c[b>>2]|0)+4>>2]|0;e=c[a+64>>2]|0;Yk(e,a+68|0);Yk(e,(c[(c[d>>2]|0)+4>>2]|0)+64|0);e=Uk()|0;Yk(e,(c[(c[b>>2]|0)+4>>2]|0)+76|0);Yk(e,(c[(c[d>>2]|0)+4>>2]|0)+72|0);e=c[(c[b>>2]|0)+4>>2]|0;b=c[e+80>>2]|0;Xk(b,e+84|0);Xk(b,(c[(c[d>>2]|0)+4>>2]|0)+80|0);return 0}function ay(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a>>2]|0;d=c[b+44>>2]|0;e=(c[(c[b+32>>2]|0)+4>>2]|0)==(a|0)|0;a=d+208+(e<<2)|0;f=(c[a>>2]|0)+1|0;c[a>>2]=f;g=d+220|0;if((f|0)==0){return 0}f=1<<e;e=d+216|0;h=d+64|0;d=b+16|0;while(1){i=c[g>>2]|0;if((i&f|0)!=0){j=9;break}k=c[e>>2]|0;do{if((c[h+(k*72|0)+68>>2]|0)==0){c[g>>2]=1<<k|i;Wi(c[(c[d>>2]|0)+(k<<2)>>2]|0)|0;l=c[e>>2]|0;if((1<<l&c[g>>2]|0)==0){break}c[e>>2]=(l|0)==0}else{cy(b)}}while(0);if((c[a>>2]|0)==0){j=9;break}}if((j|0)==9){return 0}return 0}function by(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;d=c[(c[b+16>>2]|0)+(((c[(c[b+32>>2]|0)+4>>2]|0)==(a|0))<<2)>>2]|0;c[a+48>>2]=c[d+48>>2];b=d+56|0;d=a+56|0;a=c[b+4>>2]|0;c[d>>2]=c[b>>2];c[d+4>>2]=a;return 0}function cy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+44>>2]|0;d=b+216|0;e=c[d>>2]|0;f=b+64|0;if((c[f+(e*72|0)+68>>2]|0)!=0){g=b+220|0;h=b+4|0;i=b+16|0;j=e;while(1){dy(a,j);if((c[g>>2]|0)==0){e=+XGb(c[h>>2]|0,i,0)>=0.0|0;c[d>>2]=e;k=e}else{k=c[d>>2]|0}if((c[f+(k*72|0)+68>>2]|0)==0){break}else{j=k}}}if((c[b+132>>2]|0)==16){dy(a,0)}if((c[b+204>>2]|0)!=16){return}dy(a,1);return}function dy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0;d=c[a+44>>2]|0;e=d+64|0;f=e+(b*72|0)+64|0;g=e+(b*72|0)+(c[f>>2]<<2)|0;i=c[g>>2]|0;c[g>>2]=0;g=d+16|0;j=g+(b<<3)|0;h[j>>3]=+h[j>>3]+1.0;k=+(c[i+76>>2]|0);j=g+(b+2<<3)|0;h[j>>3]=+h[j>>3]+k;j=i+136|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=c[(c[a+32>>2]|0)+(b<<2)>>2]|0;if((l|0)==0&(m|0)==(-2147483648|0)){n=g+(b+4<<3)|0}else{o=g+(b+4<<3)|0;h[o>>3]=(+(l>>>0)+ +(m|0)*4294967296.0)*(+(c[j+56>>2]|0)/+(c[j+60>>2]|0));n=o}h[n>>3]=k/+(c[(c[(c[a+16>>2]|0)+(b<<2)>>2]|0)+48>>2]|0)+ +h[n>>3];lj(j,i)|0;i=e+(b*72|0)+68|0;c[i>>2]=(c[i>>2]|0)-1;c[f>>2]=(c[f>>2]|0)+1&15;f=d+208+(b<<2)|0;b=c[f>>2]|0;if((b|0)==0){return}c[f>>2]=b-1;return}function ey(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=(c[(c[d+16>>2]|0)+4>>2]|0)==(a|0)|0;a=e+64|0;g=c[a+(f*72|0)+64>>2]|0;h=a+(f*72|0)+68|0;i=c[h>>2]|0;c[h>>2]=i+1;c[a+(f*72|0)+((i+g&15)<<2)>>2]=b;b=e+220|0;c[b>>2]=c[b>>2]&~(1<<f);cy(d);return 0}function fy(a){a=a|0;var b=0;b=c[a+44>>2]|0;c[b+40>>2]=-1;c[b+160>>2]=0;return 0}function gy(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+44>>2]|0;a=b+152|0;c[a>>2]=0;c[a+4>>2]=0;c[b+160>>2]=0;a=b+88|0;d=b+96|0;c[b+108>>2]=0;c[b+140>>2]=0;mrc(b+12|0,0,28)|0;mrc(b+72|0,0,16)|0;mrc(b+120|0,0,16)|0;e=(c[b+52>>2]|0)/2|0;f=xrc(0,0,e,(e|0)<0|0?-1:0)|0;e=G;c[a>>2]=f;c[a+4>>2]=e;c[d>>2]=f;c[d+4>>2]=e;VHb(b+176|0);c[b+180>>2]=0;c[b+184>>2]=0;mrc(b+192|0,0,16)|0;mJb(b+104|0);mJb(b+136|0);mJb(b+112|0);mJb(b+144|0);mJb(b+4|0);mJb(b+56|0);mJb(b+172|0);e=b+164|0;F1(c[e>>2]|0);c[e>>2]=0;e=b+168|0;F1(c[e>>2]|0);c[e>>2]=0;return}function hy(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(684032)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function iy(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0.0,m=0,n=0;j=i;i=i+8|0;g=j|0;if((irc(d,2412272)|0)!=0){k=-38;i=j;return k|0}d=c[b+44>>2]|0;f=d;c[g>>2]=0;l=+SGb(e,g);m=c[g>>2]|0;do{if((m|0)!=0){if((a[m]|0)==0){break}KIb(b,16,2334592,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;k=-22;i=j;return k|0}}while(0);if(l<.5|l>2.0){KIb(b,16,2277704,(n=i,i=i+8|0,h[n>>3]=l,n)|0);i=n;k=-22;i=j;return k|0}else{n=c[d+152>>2]&1^1;b=f+88+(n<<5)|0;e=(c[d+52>>2]|0)/2|0;m=e;g=(e|0)<0|0?-1:0;e=wrc(m,g,c[b>>2]|0,c[b+4>>2]|0)|0;b=d+72|0;c[b>>2]=e;c[b+4>>2]=G;b=f+88+(n<<5)+8|0;n=wrc(m,g,c[b>>2]|0,c[b+4>>2]|0)|0;b=d+80|0;c[b>>2]=n;c[b+4>>2]=G;h[d+64>>3]=l;k=0;i=j;return k|0}return 0}function jy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=f;h=Wi(c[c[e+16>>2]>>2]|0)|0;if(!((h|0)==-541478725)){j=h;i=b;return j|0}h=c[f+8>>2]|0;e=f+176|0;k=f+180|0;l=f+48|0;m=f+184|0;n=f+152|0;o=f+160|0;p=f+24|0;q=f+32|0;r=a+48|0;s=f+200|0;t=d|0;u=d+4|0;v=a+56|0;w=f+164|0;x=f+52|0;f=c[e>>2]|0;a:while(1){if((f|0)==0){y=oi(a,h)|0;c[e>>2]=y;if((y|0)==0){j=-12;z=24;break}A=c[y>>2]|0;c[k>>2]=A;y=A+(ca(c[l>>2]|0,h)|0)|0;c[m>>2]=y;B=y}else{B=c[m>>2]|0}y=c[n>>2]&1;A=g+88+(y<<5)|0;c[o>>2]=4;C=c[p>>2]|0;D=c[p+4>>2]|0;E=A|0;F=g+88+(y<<5)+20|0;H=c[F>>2]|0;I=H;J=(H|0)<0|0?-1:0;H=wrc(I,J,c[E>>2]|0,c[E+4>>2]|0)|0;E=G;if((C|0)==(H|0)&(D|0)==(E|0)){K=c[q>>2]|0;L=c[q+4>>2]|0;M=g+88+(y<<5)+8|0;N=wrc(c[M>>2]|0,c[M+4>>2]|0,I,J)|0;if((K|0)==(N|0)&(L|0)==(G|0)){O=0}else{z=9}}else{z=9}b:do{if((z|0)==9){z=0;do{if((E|0)<(D|0)|(E|0)==(D|0)&H>>>0<C>>>0){ky(g,0,0)|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){break}ly(g,A);E1(c[w>>2]|0,c[g+88+(y<<5)+24>>2]|0);if((my(g)|0)==0){break}ky(g,0,0)|0}}while(0);L=g+88+(y<<5)+8|0;N=(c[x>>2]|0)/2|0;K=c[F>>2]|0;J=(N|0)>(K|0)?K:N;N=wrc(J,(J|0)<0|0?-1:0,c[L>>2]|0,c[L+4>>2]|0)|0;J=G;while(1){P=c[q>>2]|0;Q=c[q+4>>2]|0;if(!((Q|0)<(J|0)|(Q|0)==(J|0)&P>>>0<N>>>0)){break}if((ny(g,k,B)|0)!=0){O=-11;break b}}K=(Q|0)>(J|0)|(Q|0)==(J|0)&P>>>0>N>>>0;I=K?P:N;M=K?Q:J;K=c[L>>2]|0;R=c[L+4>>2]|0;S=c[F>>2]|0;T=wrc(S,(S|0)<0|0?-1:0,K,R)|0;S=G;if((M|0)>(S|0)|(M|0)==(S|0)&I>>>0>T>>>0|((R|0)>(M|0)|(R|0)==(M|0)&K>>>0>I>>>0)){z=17;break a}U=xrc(I,M,K,R)|0;R=c[g+88+(y<<5)+16>>2]|0;K=c[l>>2]|0;V=Erc(K,(K|0)<0|0?-1:0,U,G)|0;U=c[k>>2]|0;W=xrc(T,S,I,M)|0;M=ca(K,W)|0;W=B-U|0;K=(M|0)>(W|0)?W:M;nrc(U|0,R+V|0,K)|0;V=(K|0)/(c[l>>2]|0)|0;R=wrc(c[q>>2]|0,c[q+4>>2]|0,V,(V|0)<0|0?-1:0)|0;V=G;c[q>>2]=R;c[q+4>>2]=V;c[k>>2]=U+K;O=(R|0)==(T|0)&(V|0)==(S|0)?0:-11}}while(0);y=c[e>>2]|0;F=((c[k>>2]|0)-(c[y>>2]|0)|0)/(c[l>>2]|0)|0;do{if((F|0)==0){X=y}else{c[y+344>>2]=c[r>>2];c[y+76>>2]=F;A=c[s>>2]|0;C=c[s+4>>2]|0;c[t>>2]=1;c[u>>2]=c[r>>2];H=XIb(A,C,d,v)|0;C=c[e>>2]|0;A=C+136|0;c[A>>2]=H;c[A+4>>2]=G;A=lj(a,C)|0;c[e>>2]=0;c[k>>2]=0;c[m>>2]=0;if((A|0)<0){X=0;break}A=wrc(c[s>>2]|0,c[s+4>>2]|0,F,(F|0)<0|0?-1:0)|0;c[s>>2]=A;c[s+4>>2]=G;X=0}}while(0);if((O|0)==-11){f=X}else{z=23;break}}if((z|0)==17){KIb(0,0,2160256,(X=i,i=i+24|0,c[X>>2]=2134752,c[X+8>>2]=2111416,c[X+16>>2]=956,X)|0);i=X;Hd();return 0}else if((z|0)==23){VHb(e);c[k>>2]=0;c[m>>2]=0;j=-541478725;i=b;return j|0}else if((z|0)==24){i=b;return j|0}return 0}function ky(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;e=i;f=c[a+152>>2]&1;g=a+88+(f<<5)|0;h=a+52|0;j=c[h>>2]|0;k=wrc(j,(j|0)<0|0?-1:0,c[g>>2]|0,c[g+4>>2]|0)|0;l=G;m=a+24|0;n=c[m>>2]|0;o=c[m+4>>2]|0;do{if((b|0)==0){p=o;q=n;r=j}else{s=xrc(k,l,n,o)|0;t=s;if(!((o|0)<(l|0)|(o|0)==(l|0)&n>>>0<k>>>0)){p=o;q=n;r=j;break}s=c[b>>2]|0;u=a+8|0;v=c[u>>2]|0;if((t|0)>(v|0)){KIb(0,0,2160256,(w=i,i=i+24|0,c[w>>2]=2559032,c[w+8>>2]=2111416,c[w+16>>2]=443,w)|0);i=w;Hd();return 0}if(s>>>0<d>>>0){x=d;y=a+48|0;z=a+20|0;A=a+4|0;B=a+12|0;C=a+16|0;D=s;E=c[y>>2]|0;F=v;v=c[z>>2]|0;H=o;I=n;while(1){J=(x-D|0)/(E|0)|0;K=(t|0)>(J|0)?J:t;J=(K|0)>(F|0)?F:K;K=F-v|0;L=(J|0)>(K|0)?K:J;K=J-L|0;J=(K|0)>(F|0)?F:K;if((L|0)==0){M=D;N=E;O=F;P=v;Q=H;R=I}else{nrc((c[A>>2]|0)+(ca(E,v)|0)|0,D|0,ca(L,E)|0)|0;K=c[y>>2]|0;S=D+(ca(K,L)|0)|0;T=wrc(c[m>>2]|0,c[m+4>>2]|0,L,(L|0)<0|0?-1:0)|0;U=G;c[m>>2]=T;c[m+4>>2]=U;V=(c[B>>2]|0)+L|0;W=c[u>>2]|0;X=(V|0)>(W|0)?W:V;c[B>>2]=X;V=((c[z>>2]|0)+L|0)%(W|0)|0;c[z>>2]=V;c[C>>2]=V-((X|0)<(W|0)?X:0);M=S;N=K;O=W;P=V;Q=U;R=T}if((J|0)==0){Y=M;Z=N;_=O;$=P;aa=Q;ba=R}else{nrc(c[A>>2]|0,M|0,ca(N,J)|0)|0;T=c[y>>2]|0;U=M+(ca(T,J)|0)|0;V=wrc(c[m>>2]|0,c[m+4>>2]|0,J,(J|0)<0|0?-1:0)|0;W=G;c[m>>2]=V;c[m+4>>2]=W;K=(c[B>>2]|0)+J|0;S=c[u>>2]|0;X=(K|0)>(S|0)?S:K;c[B>>2]=X;K=((c[z>>2]|0)+J|0)%(S|0)|0;c[z>>2]=K;c[C>>2]=K-((X|0)<(S|0)?X:0);Y=U;Z=T;_=S;$=K;aa=W;ba=V}if(((aa|0)<(l|0)|(aa|0)==(l|0)&ba>>>0<k>>>0)&Y>>>0<d>>>0){D=Y;E=Z;F=_;v=$;H=aa;I=ba}else{da=Y;ea=aa;fa=ba;break}}}else{da=s;ea=o;fa=n}c[b>>2]=da;if((ea|0)>(l|0)|(ea|0)==(l|0)&fa>>>0>k>>>0){KIb(0,0,2160256,(w=i,i=i+24|0,c[w>>2]=2541616,c[w+8>>2]=2111416,c[w+16>>2]=492,w)|0);i=w;Hd();return 0}if((fa|0)==(k|0)&(ea|0)==(l|0)){p=l;q=k;r=c[h>>2]|0;break}else{ga=-11;i=e;return ga|0}}}while(0);h=(l|0)>(p|0)|(l|0)==(p|0)&k>>>0>q>>>0;ea=xrc(k,l,q,p)|0;l=h?ea:0;ea=h?G:0;h=r;k=(r|0)<0|0?-1:0;if((ea|0)<(k|0)|(ea|0)==(k|0)&l>>>0<h>>>0){r=xrc(h,k,l,ea)|0;ha=r}else{ha=0}c[a+88+(f<<5)+20>>2]=ha;r=c[a+88+(f<<5)+16>>2]|0;f=c[a+12>>2]|0;ea=xrc(q,p,f,(f|0)<0|0?-1:0)|0;f=G;p=c[g>>2]|0;q=c[g+4>>2]|0;do{if((q|0)<(f|0)|(q|0)==(f|0)&p>>>0<ea>>>0){l=xrc(ea,f,p,q)|0;k=G;h=ha;fa=0;da=(k|0)>(fa|0)|(k|0)==(fa|0)&l>>>0>h>>>0;b=da?h:l;l=da?fa:k;if((b|0)==(h|0)&(l|0)==(fa|0)){KIb(0,0,2160256,(w=i,i=i+24|0,c[w>>2]=2604152,c[w+8>>2]=2111416,c[w+16>>2]=540,w)|0);i=w;Hd();return 0}else{k=a+48|0;da=c[k>>2]|0;n=Erc(da,(da|0)<0|0?-1:0,b,l)|0;mrc(r|0,0,n|0)|0;n=c[k>>2]|0;k=Erc(n,(n|0)<0|0?-1:0,b,l)|0;ia=r+k|0;ja=l;ka=b;la=fa;ma=h;break}}else{ia=r;ja=0;ka=0;la=0;ma=ha}}while(0);if((ka|0)==(ma|0)&(ja|0)==(la|0)){ga=0;i=e;return ga|0}ha=c[a+16>>2]|0;r=c[a+20>>2]|0;q=(ha|0)<(r|0);if(q){na=r}else{na=c[a+8>>2]|0}p=na-ha|0;na=wrc(p,(p|0)<0|0?-1:0,ka,ja)|0;h=wrc(na,G,q?0:r,q?0:(r|0)<0|0?-1:0)|0;r=G;if((la|0)>(r|0)|(la|0)==(r|0)&ma>>>0>h>>>0){KIb(0,0,2160256,(w=i,i=i+24|0,c[w>>2]=2578504,c[w+8>>2]=2111416,c[w+16>>2]=558,w)|0);i=w;Hd();return 0}w=c[a+4>>2]|0;h=a+48|0;a=c[h>>2]|0;r=c[g>>2]|0;q=c[g+4>>2]|0;g=xrc(ka,ja,ea,f)|0;f=wrc(g,G,r,q)|0;q=f;f=(q|0)<(p|0);r=f?0:q-p|0;do{if(f){g=p-q|0;ea=xrc(ma,la,ka,ja)|0;na=ea;fa=(g|0)>(na|0)?na:g;g=xrc(ea,G,fa,0)|0;ea=g;if((fa|0)==0){oa=ia;pa=ea;qa=a;break}nrc(ia|0,w+(ca(a,q+ha|0)|0)|0,ca(a,fa)|0)|0;g=c[h>>2]|0;oa=ia+(ca(g,fa)|0)|0;pa=ea;qa=g}else{g=xrc(ma,la,ka,ja)|0;oa=ia;pa=g;qa=a}}while(0);if((pa|0)==0){ga=0;i=e;return ga|0}nrc(oa|0,w+(ca(qa,r)|0)|0,ca(qa,pa)|0)|0;ga=0;i=e;return ga|0}function ly(a,e){a=a|0;e=e|0;var f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0.0,Q=0,S=0,T=0.0,U=0.0,V=0;f=c[e+16>>2]|0;i=e+24|0;mrc(c[i>>2]|0,0,c[a+52>>2]<<3|0)|0;switch(c[a+40>>2]|0){case 2:{j=c[a+44>>2]|0;k=ca(c[e+20>>2]<<2,j)|0;l=f+k|0;m=c[i>>2]|0;n=(k|0)>0;if((j|0)==1){if(n){o=m;p=f}else{return}while(1){k=p+4|0;g[o>>2]=+(c[p>>2]|0);if(k>>>0<l>>>0){o=o+4|0;p=k}else{break}}return}if(!n){return}if((j|0)>1){q=m;r=f}else{n=m;m=f;while(1){p=m+4|0;g[n>>2]=+(c[m>>2]|0);if(p>>>0<l>>>0){n=n+4|0;m=p}else{break}}return}while(1){s=+(c[r>>2]|0);t=+R(+s);m=(j|0)>2?j<<2:8;u=t<2147483648.0?t:2147483648.0;t=s;n=1;p=r;while(1){o=p+4|0;s=+(c[o>>2]|0);v=+R(+s);w=v<2147483648.0?v:2147483648.0;k=u<w;x=k?s:t;y=n+1|0;if((y|0)<(j|0)){u=k?w:u;t=x;n=y;p=o}else{break}}p=r+m|0;g[q>>2]=x;if(p>>>0<l>>>0){q=q+4|0;r=p}else{break}}return};case 0:{r=c[a+44>>2]|0;q=ca(r,c[e+20>>2]|0)|0;l=f+q|0;j=c[i>>2]|0;p=(q|0)>0;if((r|0)==1){if(p){z=j;A=f}else{return}while(1){q=A+1|0;g[z>>2]=+((d[A]|0)>>>0);if(q>>>0<l>>>0){z=z+4|0;A=q}else{break}}return}if(p){B=j;C=f}else{return}while(1){x=+((d[C]|0)>>>0);t=+R(+x);j=C+1|0;if((r|0)>1){p=(r|0)>2?r:2;A=1;u=x;w=t<127.0?t:127.0;z=j;while(1){t=+((d[z]|0)>>>0);s=+R(+t);v=s<127.0?s:127.0;q=w<v;D=q?t:u;n=A+1|0;if((n|0)<(r|0)){A=n;u=D;w=q?v:w;z=z+1|0}else{break}}E=D;F=C+p|0}else{E=x;F=j}g[B>>2]=E;if(F>>>0<l>>>0){B=B+4|0;C=F}else{break}}return};case 3:{F=c[a+44>>2]|0;C=ca(c[e+20>>2]<<2,F)|0;B=f+C|0;l=c[i>>2]|0;r=(C|0)>0;if((F|0)==1){if(r){G=l;H=f}else{return}while(1){C=H+4|0;g[G>>2]=+g[H>>2];if(C>>>0<B>>>0){G=G+4|0;H=C}else{break}}return}if(!r){return}if((F|0)>1){I=l;J=f}else{r=l;l=f;while(1){H=l+4|0;g[r>>2]=+g[l>>2];if(H>>>0<B>>>0){r=r+4|0;l=H}else{break}}return}while(1){E=+g[J>>2];D=+R(+E);l=(F|0)>2?F<<2:8;w=D<1.0?D:1.0;D=E;r=1;H=J;while(1){G=H+4|0;E=+g[G>>2];u=+R(+E);v=u<1.0?u:1.0;C=w<v;K=C?E:D;z=r+1|0;if((z|0)<(F|0)){w=C?v:w;D=K;r=z;H=G}else{break}}H=J+l|0;g[I>>2]=K;if(H>>>0<B>>>0){I=I+4|0;J=H}else{break}}return};case 1:{J=c[a+44>>2]|0;I=ca(c[e+20>>2]<<1,J)|0;B=f+I|0;F=c[i>>2]|0;H=(I|0)>0;if((J|0)==1){if(H){L=F;M=f}else{return}while(1){I=M+2|0;g[L>>2]=+(b[M>>1]|0);if(I>>>0<B>>>0){L=L+4|0;M=I}else{break}}return}if(!H){return}if((J|0)>1){N=F;O=f}else{H=F;F=f;while(1){M=F+2|0;g[H>>2]=+(b[F>>1]|0);if(M>>>0<B>>>0){H=H+4|0;F=M}else{break}}return}while(1){K=+(b[O>>1]|0);D=+R(+K);F=(J|0)>2?J<<1:4;w=K;H=1;K=D<32767.0?D:32767.0;M=O;while(1){L=M+2|0;D=+(b[L>>1]|0);x=+R(+D);v=x<32767.0?x:32767.0;I=K<v;P=I?D:w;r=H+1|0;if((r|0)<(J|0)){w=P;H=r;K=I?v:K;M=L}else{break}}M=O+F|0;g[N>>2]=P;if(M>>>0<B>>>0){N=N+4|0;O=M}else{break}}return};case 4:{O=c[a+44>>2]|0;a=ca(c[e+20>>2]<<3,O)|0;e=f+a|0;N=c[i>>2]|0;i=(a|0)>0;if((O|0)==1){if(i){Q=N;S=f}else{return}while(1){a=S+8|0;g[Q>>2]=+h[S>>3];if(a>>>0<e>>>0){Q=Q+4|0;S=a}else{break}}return}if(!i){return}i=(O|0)>1;S=N;N=f;while(1){P=+h[N>>3];K=+R(+P);f=N+8|0;if(i){Q=(O|0)>2?O<<3:16;w=K<1.0?K:1.0;K=P;a=1;B=f;while(1){v=+h[B>>3];D=+R(+v);x=D<1.0?D:1.0;J=w<x;T=J?v:K;M=a+1|0;if((M|0)<(O|0)){w=J?x:w;K=T;a=M;B=B+8|0}else{break}}U=T;V=N+Q|0}else{U=P;V=f}g[S>>2]=U;if(V>>>0<e>>>0){S=S+4|0;N=V}else{break}}return};default:{return}}}function my(a){a=a|0;var b=0,d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0;b=c[a+152>>2]|0;d=b&1^1;e=b&1;b=a+88+(d<<5)+8|0;f=a+80|0;i=xrc(c[b>>2]|0,c[b+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=c[a+52>>2]|0;b=(f|0)/2|0;j=b;k=(b|0)<0|0?-1:0;l=wrc(i,G,j,k)|0;m=+(l>>>0)+ +(G|0)*4294967296.0;l=a+88+(d<<5)|0;i=a+72|0;n=c[i>>2]|0;o=c[i+4>>2]|0;i=wrc(j,k,c[l>>2]|0,c[l+4>>2]|0)|0;l=xrc(i,G,n,o)|0;o=~~(m-(+(l>>>0)+ +(G|0)*4294967296.0)/+h[a+64>>3]);l=c[a+172>>2]|0;n=c[a+168>>2]|0;i=c[a+88+(e<<5)+24>>2]|0;k=c[a+88+(d<<5)+24>>2]|0;d=-o|0;g[l>>2]=+g[k>>2]*+g[i>>2];g[l+4>>2]=+g[k+4>>2]*+g[i+4>>2];if((f|0)>1){j=l+8|0;p=1;q=k;k=i;while(1){i=q+8|0;r=k+8|0;s=i|0;t=r|0;u=q+12|0;v=k+12|0;g[j>>2]=+g[s>>2]*+g[t>>2]+ +g[u>>2]*+g[v>>2];g[j+4>>2]=+g[u>>2]*+g[t>>2]- +g[s>>2]*+g[v>>2];v=p+1|0;if((v|0)<(f|0)){j=j+8|0;p=v;q=i;k=r}else{break}}}E1(n,l);n=(d|0)>0?d:0;k=(n|0)>(f|0)?f:n;n=b-o+b|0;q=f-((f|0)/16|0)|0;f=(n|0)>(q|0)?q:n;n=(f|0)>0?f:0;if((k|0)<(n|0)){m=-3.4028234663852886e+38;f=l+(k<<2)|0;l=k;q=d;while(1){w=+g[f>>2]*+(n-l|0)*+(l+o|0)*+(l-k|0);p=w>m;j=p?l-b|0:q;r=l+1|0;if((r|0)<(n|0)){m=p?w:m;f=f+4|0;l=r;q=j}else{x=j;break}}}else{x=d}if((x|0)==0){return x|0}d=a+88+(e<<5)|0;q=xrc(c[d>>2]|0,c[d+4>>2]|0,x,(x|0)<0|0?-1:0)|0;c[d>>2]=q;c[d+4>>2]=G;c[a+88+(e<<5)+20>>2]=0;return x|0}function ny(e,f,j){e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0.0,Ba=0.0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0.0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0;k=i;l=c[e+152>>2]|0;m=l&1^1;n=l&1;l=e+88+(n<<5)|0;o=e+32|0;p=c[o>>2]|0;q=c[o+4>>2]|0;r=e+88+(n<<5)+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;r=(q|0)>(t|0)|(q|0)==(t|0)&p>>>0>s>>>0;u=r?p:s;v=r?q:t;r=e+88+(m<<5)+8|0;w=c[r>>2]|0;x=c[r+4>>2]|0;r=c[e+88+(m<<5)+20>>2]|0;y=wrc(r,(r|0)<0|0?-1:0,w,x)|0;r=G;z=c[e+88+(n<<5)+20>>2]|0;A=z;B=(z|0)<0|0?-1:0;z=wrc(A,B,s,t)|0;C=G;D=(r|0)>(C|0)|(r|0)==(C|0)&y>>>0>z>>>0;E=D?z:y;y=D?C:r;r=xrc(E,y,u,v)|0;C=G;D=xrc(u,v,w,x)|0;x=G;w=xrc(u,v,s,t)|0;t=G;s=c[e+56>>2]|0;z=s+(D<<2)|0;F=s+(w<<2)|0;s=c[e+88+(m<<5)+16>>2]|0;m=c[e+48>>2]|0;H=m;I=(m|0)<0|0?-1:0;m=Erc(H,I,D,x)|0;x=s+m|0;m=c[e+88+(n<<5)+16>>2]|0;n=Erc(H,I,w,t)|0;t=m+n|0;n=c[f>>2]|0;if((v|0)>(y|0)|(v|0)==(y|0)&u>>>0>E>>>0|((C|0)>(B|0)|(C|0)==(B|0)&r>>>0>A>>>0)){KIb(0,0,2160256,(A=i,i=i+24|0,c[A>>2]=2629072,c[A+8>>2]=2111416,c[A+16>>2]=798,A)|0);i=A;Hd();return 0}switch(c[e+40>>2]|0){case 2:{A=n;B=j;u=0;if(((C|0)>(u|0)|(C|0)==(u|0)&r>>>0>0>>>0)&n>>>0<j>>>0){u=e+44|0;v=l|0;m=A;w=t;I=0;H=0;s=x;D=F;J=z;K=q;L=p;M=c[u>>2]|0;while(1){N=+g[J>>2];O=+g[D>>2];if((M|0)>0){P=wrc(c[v>>2]|0,c[v+4>>2]|0,H,I)|0;Q=G;R=0;if((Q|0)<(R|0)|(Q|0)==(R|0)&P>>>0<0>>>0){P=m;R=w;Q=s;S=0;while(1){c[P>>2]=c[Q>>2];T=S+1|0;U=Q+4|0;V=R+4|0;W=P+4|0;X=c[u>>2]|0;if((T|0)<(X|0)){P=W;R=V;Q=U;S=T}else{Y=W;Z=V;_=U;$=X;break}}}else{S=m;Q=w;R=s;P=0;while(1){c[S>>2]=~~(N*+(c[R>>2]|0)+O*+(c[Q>>2]|0));X=P+1|0;U=R+4|0;V=Q+4|0;W=S+4|0;T=c[u>>2]|0;if((X|0)<(T|0)){S=W;Q=V;R=U;P=X}else{Y=W;Z=V;_=U;$=T;break}}}}else{Y=m;Z=w;_=s;$=M}P=wrc(H,I,1,0)|0;R=G;aa=wrc(L,K,1,0)|0;ba=G;if(((R|0)<(C|0)|(R|0)==(C|0)&P>>>0<r>>>0)&Y>>>0<B>>>0){m=Y;w=Z;I=R;H=P;s=_;D=D+4|0;J=J+4|0;K=ba;L=aa;M=$}else{break}}c[o>>2]=aa;c[o+4>>2]=ba;ca=Y;da=ba;ea=aa}else{ca=A;da=q;ea=p}fa=ca;ga=da;ha=ea;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};case 0:{ea=0;if(!(((C|0)>(ea|0)|(C|0)==(ea|0)&r>>>0>0>>>0)&n>>>0<j>>>0)){fa=n;ga=q;ha=p;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0}ea=e+44|0;da=l|0;ca=0;A=0;aa=n;ba=t;Y=x;$=F;M=z;L=c[ea>>2]|0;K=q;J=p;while(1){O=+g[M>>2];N=+g[$>>2];if((L|0)>0){D=0;_=aa;s=ba;H=Y;do{I=a[H]|0;Z=wrc(c[da>>2]|0,c[da+4>>2]|0,A,ca)|0;w=G;m=0;if((w|0)<(m|0)|(w|0)==(m|0)&Z>>>0<0>>>0){ka=I}else{ka=~~(O*+((I&255)>>>0)+N*+((d[s]|0)>>>0))}a[_]=ka;D=D+1|0;H=H+1|0;s=s+1|0;_=_+1|0;la=c[ea>>2]|0;}while((D|0)<(la|0));ma=_;na=s;oa=H;pa=la;qa=c[o+4>>2]|0;ra=c[o>>2]|0}else{ma=aa;na=ba;oa=Y;pa=L;qa=K;ra=J}D=wrc(A,ca,1,0)|0;I=G;Z=wrc(ra,qa,1,0)|0;m=G;c[o>>2]=Z;c[o+4>>2]=m;if(((I|0)<(C|0)|(I|0)==(C|0)&D>>>0<r>>>0)&ma>>>0<j>>>0){ca=I;A=D;aa=ma;ba=na;Y=oa;$=$+4|0;M=M+4|0;L=pa;K=m;J=Z}else{fa=ma;ga=m;ha=Z;break}}c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};case 1:{ma=n;J=j;K=0;if(((C|0)>(K|0)|(C|0)==(K|0)&r>>>0>0>>>0)&n>>>0<j>>>0){K=c[e+44>>2]|0;pa=(K|0)>0;L=l|0;M=0;$=0;oa=ma;Y=t;na=x;ba=F;aa=z;A=q;ca=p;while(1){N=+g[aa>>2];O=+g[ba>>2];if(pa){qa=wrc(c[L>>2]|0,c[L+4>>2]|0,$,M)|0;ra=G;la=0;ea=(K|0)>1?K:1;if((ra|0)<(la|0)|(ra|0)==(la|0)&qa>>>0<0>>>0){qa=0;la=oa;ra=na;while(1){b[la>>1]=b[ra>>1]|0;ka=qa+1|0;if((ka|0)<(K|0)){qa=ka;la=la+2|0;ra=ra+2|0}else{break}}}else{ra=0;la=oa;qa=Y;H=na;while(1){b[la>>1]=~~(N*+(b[H>>1]|0)+O*+(b[qa>>1]|0));s=ra+1|0;if((s|0)<(K|0)){ra=s;la=la+2|0;qa=qa+2|0;H=H+2|0}else{break}}}sa=oa+(ea<<1)|0;ta=Y+(ea<<1)|0;ua=na+(ea<<1)|0}else{sa=oa;ta=Y;ua=na}H=wrc($,M,1,0)|0;qa=G;va=wrc(ca,A,1,0)|0;wa=G;if(((qa|0)<(C|0)|(qa|0)==(C|0)&H>>>0<r>>>0)&sa>>>0<J>>>0){M=qa;$=H;oa=sa;Y=ta;na=ua;ba=ba+4|0;aa=aa+4|0;A=wa;ca=va}else{break}}c[o>>2]=va;c[o+4>>2]=wa;xa=sa;ya=wa;za=va}else{xa=ma;ya=q;za=p}fa=xa;ga=ya;ha=za;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};case 4:{za=n;ya=j;xa=0;if(((C|0)>(xa|0)|(C|0)==(xa|0)&r>>>0>0>>>0)&n>>>0<j>>>0){xa=c[e+44>>2]|0;ma=(xa|0)>0;va=l|0;wa=x;sa=t;ca=za;A=0;aa=0;ba=F;ua=z;na=q;ta=p;while(1){O=+g[ua>>2];N=+g[ba>>2];if(ma){Y=wrc(c[va>>2]|0,c[va+4>>2]|0,aa,A)|0;oa=G;$=0;M=(oa|0)<($|0)|(oa|0)==($|0)&Y>>>0<0>>>0;Y=(xa|0)>1?xa:1;$=sa+(Y<<3)|0;oa=wa;J=sa;K=ca;L=0;while(1){Aa=+h[oa>>3];if(M){Ba=Aa}else{Ba=O*Aa+N*+h[J>>3]}h[K>>3]=Ba;pa=L+1|0;if((pa|0)<(xa|0)){oa=oa+8|0;J=J+8|0;K=K+8|0;L=pa}else{break}}Ca=wa+(Y<<3)|0;Da=$;Ea=ca+(Y<<3)|0}else{Ca=wa;Da=sa;Ea=ca}L=wrc(aa,A,1,0)|0;K=G;Fa=wrc(ta,na,1,0)|0;Ga=G;if(((K|0)<(C|0)|(K|0)==(C|0)&L>>>0<r>>>0)&Ea>>>0<ya>>>0){wa=Ca;sa=Da;ca=Ea;A=K;aa=L;ba=ba+4|0;ua=ua+4|0;na=Ga;ta=Fa}else{break}}c[o>>2]=Fa;c[o+4>>2]=Ga;Ha=Ea;Ia=Ga;Ja=Fa}else{Ha=za;Ia=q;Ja=p}fa=Ha;ga=Ia;ha=Ja;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};case 3:{Ja=n;Ia=j;Ha=0;if(((C|0)>(Ha|0)|(C|0)==(Ha|0)&r>>>0>0>>>0)&n>>>0<j>>>0){j=c[e+44>>2]|0;e=(j|0)>0;Ha=l|0;l=x;x=t;t=Ja;za=0;Fa=0;Ga=F;F=z;z=q;Ea=p;while(1){Ba=+g[F>>2];N=+g[Ga>>2];if(e){ta=wrc(c[Ha>>2]|0,c[Ha+4>>2]|0,Fa,za)|0;na=G;ua=0;ba=(na|0)<(ua|0)|(na|0)==(ua|0)&ta>>>0<0>>>0;ta=(j|0)>1?j:1;ua=x+(ta<<2)|0;na=l;aa=x;A=t;ca=0;while(1){O=+g[na>>2];if(ba){Ka=O}else{Ka=Ba*O+N*+g[aa>>2]}g[A>>2]=Ka;Da=ca+1|0;if((Da|0)<(j|0)){na=na+4|0;aa=aa+4|0;A=A+4|0;ca=Da}else{break}}La=l+(ta<<2)|0;Ma=ua;Na=t+(ta<<2)|0}else{La=l;Ma=x;Na=t}ca=wrc(Fa,za,1,0)|0;A=G;Oa=wrc(Ea,z,1,0)|0;Pa=G;if(((A|0)<(C|0)|(A|0)==(C|0)&ca>>>0<r>>>0)&Na>>>0<Ia>>>0){l=La;x=Ma;t=Na;za=A;Fa=ca;Ga=Ga+4|0;F=F+4|0;z=Pa;Ea=Oa}else{break}}c[o>>2]=Oa;c[o+4>>2]=Pa;Qa=Na;Ra=Pa;Sa=Oa}else{Qa=Ja;Ra=q;Sa=p}fa=Qa;ga=Ra;ha=Sa;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0};default:{fa=n;ga=q;ha=p;c[f>>2]=fa;ia=(ha|0)==(E|0)&(ga|0)==(y|0);ja=ia?0:-11;i=k;return ja|0}}return 0}function oy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0.0,P=0,S=0,T=0,U=0,V=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[f>>2]=b;j=c[a+8>>2]|0;a=c[j+44>>2]|0;k=a;l=c[c[j+32>>2]>>2]|0;j=c[b+76>>2]|0;m=a+64|0;n=~~(+(j|0)/+h[m>>3]+.5);o=c[b>>2]|0;c[g>>2]=o;b=a+48|0;p=ca(c[b>>2]|0,j)|0;q=o+p|0;a:do{if((p|0)>0){o=a+176|0;r=a+180|0;s=a+184|0;t=a+160|0;u=a+152|0;v=a+164|0;w=a+52|0;x=a+88|0;y=a+120|0;z=a+96|0;A=a+128|0;B=a+140|0;C=l+48|0;D=a+200|0;E=e|0;H=e+4|0;I=l+56|0;while(1){if((c[o>>2]|0)==0){J=oi(l,n)|0;c[o>>2]=J;if((J|0)==0){K=-12;break}ZHb(J,c[f>>2]|0)|0;J=c[c[o>>2]>>2]|0;c[r>>2]=J;L=J+(ca(c[b>>2]|0,n)|0)|0;c[s>>2]=L;M=L}else{M=c[s>>2]|0}b:while(1){L=c[t>>2]|0;while(1){if((L|0)==0){if((ky(k,g,q)|0)!=0){break b}ly(k,k+88+((c[u>>2]&1)<<5)|0);E1(c[v>>2]|0,c[k+88+((c[u>>2]&1)<<5)+24>>2]|0);if((c[u>>2]|0)==0&(c[u+4>>2]|0)==0){break}c[t>>2]=1;N=14}else if((L|0)==2){N=17}else if((L|0)==1){N=14}else if((L|0)!=3){continue b}do{if((N|0)==14){N=0;if((my(k)|0)==0){c[t>>2]=3;break}else{c[t>>2]=2;N=17;break}}}while(0);if((N|0)==17){N=0;if((ky(k,g,q)|0)!=0){break b}ly(k,k+88+((c[u>>2]&1)<<5)|0);E1(c[v>>2]|0,c[k+88+((c[u>>2]&1)<<5)+24>>2]|0);c[t>>2]=3}if((ny(k,r,M)|0)!=0){break b}J=(c[w>>2]|0)/2|0;O=+h[m>>3]*+(J|0);P=wrc(c[u>>2]|0,c[u+4>>2]|0,1,0)|0;c[u>>2]=P;c[u+4>>2]=G;S=P&1^1;T=P&1;P=k+88+(S<<5)|0;U=wrc(~~+O>>>0,(F=+O,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0),c[P>>2]|0,c[P+4>>2]|0)|0;P=k+88+(T<<5)|0;c[P>>2]=U;c[P+4>>2]=G;P=k+88+(S<<5)+8|0;S=wrc(c[P>>2]|0,c[P+4>>2]|0,J,(J|0)<0|0?-1:0)|0;J=k+88+(T<<5)+8|0;c[J>>2]=S;c[J+4>>2]=G;c[k+88+(T<<5)+20>>2]=0;c[t>>2]=0;L=0}L=(c[w>>2]|0)/2|0;O=+h[m>>3]*+(L|0);c[u>>2]=1;c[u+4>>2]=0;T=wrc(~~+O>>>0,(F=+O,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0),c[x>>2]|0,c[x+4>>2]|0)|0;c[y>>2]=T;c[y+4>>2]=G;T=wrc(c[z>>2]|0,c[z+4>>2]|0,L,(L|0)<0|0?-1:0)|0;c[A>>2]=T;c[A+4>>2]=G;c[B>>2]=0}T=c[r>>2]|0;if((T|0)==(c[s>>2]|0)){L=c[o>>2]|0;J=(T-(c[L>>2]|0)|0)/(c[b>>2]|0)|0;c[L+344>>2]=c[C>>2];c[L+76>>2]=J;L=c[D>>2]|0;T=c[D+4>>2]|0;c[E>>2]=1;c[H>>2]=c[C>>2];S=XIb(L,T,e,I)|0;T=c[o>>2]|0;L=T+136|0;c[L>>2]=S;c[L+4>>2]=G;L=lj(l,T)|0;c[o>>2]=0;c[r>>2]=0;c[s>>2]=0;if((L|0)<0){V=L;break a}L=wrc(c[D>>2]|0,c[D+4>>2]|0,J,(J|0)<0|0?-1:0)|0;c[D>>2]=L;c[D+4>>2]=G}if(!((c[g>>2]|0)>>>0<q>>>0)){N=25;break a}}i=d;return K|0}else{N=25}}while(0);if((N|0)==25){N=a+192|0;a=wrc(c[N>>2]|0,c[N+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[N>>2]=a;c[N+4>>2]=G;V=0}VHb(f);K=V;i=d;return K|0}function py(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;b=i;e=c[a+8>>2]|0;f=c[e+44>>2]|0;h=c[a+52>>2]|0;j=c[a+48>>2]|0;k=a+40|0;a=rGb(c[k>>2]|0,c[k+4>>2]|0)|0;k=(c[c[e+32>>2]>>2]|0)+156|0;c[k>>2]=c[k>>2]|1;k=QKb(h)|0;c[f+40>>2]=h;c[f+44>>2]=a;h=f+48|0;c[h>>2]=ca(k,a)|0;a=(j|0)/24|0;j=f+52|0;c[j>>2]=a;k=a>>>0>65535>>>0;e=k?a>>>16:a;l=k?16:0;if((e&65280|0)==0){m=l;n=e}else{m=l|8;n=e>>>8}e=(d[1359664+n|0]|0)+m|0;m=1<<e;if(m>>>0>a>>>0){KIb(0,0,2160256,(n=i,i=i+24|0,c[n>>2]=2524528,c[n+8>>2]=2111416,c[n+16>>2]=272,n)|0);i=n;Hd();return 0}if(m>>>0<a>>>0){c[j>>2]=m<<1;o=e+1|0}else{o=e}e=f+104|0;mJb(e);m=hJb(ca(c[h>>2]|0,c[j>>2]|0)|0)|0;c[e>>2]=m;if((m|0)==0){m=f+152|0;c[m>>2]=0;c[m+4>>2]=0;c[f+160>>2]=0;m=f+88|0;a=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;n=(c[j>>2]|0)/2|0;l=xrc(0,0,n,(n|0)<0|0?-1:0)|0;n=G;c[m>>2]=l;c[m+4>>2]=n;c[a>>2]=l;c[a+4>>2]=n;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(f+136|0);mJb(f+112|0);mJb(f+144|0);mJb(f+4|0);mJb(f+56|0);mJb(f+172|0);n=f+164|0;F1(c[n>>2]|0);c[n>>2]=0;n=f+168|0;F1(c[n>>2]|0);c[n>>2]=0;p=-12;i=b;return p|0}n=f+136|0;mJb(n);a=hJb(ca(c[h>>2]|0,c[j>>2]|0)|0)|0;c[n>>2]=a;if((a|0)==0){a=f+152|0;c[a>>2]=0;c[a+4>>2]=0;c[f+160>>2]=0;a=f+88|0;l=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;m=(c[j>>2]|0)/2|0;k=xrc(0,0,m,(m|0)<0|0?-1:0)|0;m=G;c[a>>2]=k;c[a+4>>2]=m;c[l>>2]=k;c[l+4>>2]=m;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(n);mJb(f+112|0);mJb(f+144|0);mJb(f+4|0);mJb(f+56|0);mJb(f+172|0);m=f+164|0;F1(c[m>>2]|0);c[m>>2]=0;m=f+168|0;F1(c[m>>2]|0);c[m>>2]=0;p=-12;i=b;return p|0}m=f+112|0;mJb(m);l=hJb(c[j>>2]<<3)|0;c[m>>2]=l;if((l|0)==0){l=f+152|0;c[l>>2]=0;c[l+4>>2]=0;c[f+160>>2]=0;l=f+88|0;k=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;a=(c[j>>2]|0)/2|0;q=xrc(0,0,a,(a|0)<0|0?-1:0)|0;a=G;c[l>>2]=q;c[l+4>>2]=a;c[k>>2]=q;c[k+4>>2]=a;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(n);mJb(m);mJb(f+144|0);mJb(f+4|0);mJb(f+56|0);mJb(f+172|0);a=f+164|0;F1(c[a>>2]|0);c[a>>2]=0;a=f+168|0;F1(c[a>>2]|0);c[a>>2]=0;p=-12;i=b;return p|0}a=f+144|0;mJb(a);k=hJb(c[j>>2]<<3)|0;c[a>>2]=k;if((k|0)==0){k=f+152|0;c[k>>2]=0;c[k+4>>2]=0;c[f+160>>2]=0;k=f+88|0;q=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;l=(c[j>>2]|0)/2|0;r=xrc(0,0,l,(l|0)<0|0?-1:0)|0;l=G;c[k>>2]=r;c[k+4>>2]=l;c[q>>2]=r;c[q+4>>2]=l;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(n);mJb(m);mJb(a);mJb(f+4|0);mJb(f+56|0);mJb(f+172|0);l=f+164|0;F1(c[l>>2]|0);c[l>>2]=0;l=f+168|0;F1(c[l>>2]|0);c[l>>2]=0;p=-12;i=b;return p|0}l=f+164|0;F1(c[l>>2]|0);c[l>>2]=0;q=f+168|0;F1(c[q>>2]|0);c[q>>2]=0;r=o+1|0;o=D1(r,0)|0;c[l>>2]=o;if((o|0)==0){o=f+152|0;c[o>>2]=0;c[o+4>>2]=0;c[f+160>>2]=0;o=f+88|0;k=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;s=(c[j>>2]|0)/2|0;t=xrc(0,0,s,(s|0)<0|0?-1:0)|0;s=G;c[o>>2]=t;c[o+4>>2]=s;c[k>>2]=t;c[k+4>>2]=s;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(n);mJb(m);mJb(a);mJb(f+4|0);mJb(f+56|0);mJb(f+172|0);F1(c[l>>2]|0);c[l>>2]=0;F1(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}s=D1(r,1)|0;c[q>>2]=s;if((s|0)==0){s=f+152|0;c[s>>2]=0;c[s+4>>2]=0;c[f+160>>2]=0;s=f+88|0;r=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;k=(c[j>>2]|0)/2|0;t=xrc(0,0,k,(k|0)<0|0?-1:0)|0;k=G;c[s>>2]=t;c[s+4>>2]=k;c[r>>2]=t;c[r+4>>2]=k;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(n);mJb(m);mJb(a);mJb(f+4|0);mJb(f+56|0);mJb(f+172|0);F1(c[l>>2]|0);c[l>>2]=0;F1(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}k=f+172|0;mJb(k);r=hJb(c[j>>2]<<3)|0;c[k>>2]=r;if((r|0)==0){r=f+152|0;c[r>>2]=0;c[r+4>>2]=0;c[f+160>>2]=0;r=f+88|0;t=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;s=(c[j>>2]|0)/2|0;o=xrc(0,0,s,(s|0)<0|0?-1:0)|0;s=G;c[r>>2]=o;c[r+4>>2]=s;c[t>>2]=o;c[t+4>>2]=s;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(n);mJb(m);mJb(a);mJb(f+4|0);mJb(f+56|0);mJb(k);F1(c[l>>2]|0);c[l>>2]=0;F1(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}s=f+8|0;c[s>>2]=(c[j>>2]|0)*3|0;t=f+4|0;mJb(t);o=hJb(ca(c[h>>2]|0,c[s>>2]|0)|0)|0;c[t>>2]=o;if((o|0)==0){o=f+152|0;c[o>>2]=0;c[o+4>>2]=0;c[f+160>>2]=0;o=f+88|0;s=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;h=(c[j>>2]|0)/2|0;r=xrc(0,0,h,(h|0)<0|0?-1:0)|0;h=G;c[o>>2]=r;c[o+4>>2]=h;c[s>>2]=r;c[s+4>>2]=h;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(n);mJb(m);mJb(a);mJb(t);mJb(f+56|0);mJb(k);F1(c[l>>2]|0);c[l>>2]=0;F1(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}h=f+56|0;mJb(h);s=hJb(c[j>>2]<<2)|0;r=s;c[h>>2]=r;if((s|0)==0){s=f+152|0;c[s>>2]=0;c[s+4>>2]=0;c[f+160>>2]=0;s=f+88|0;o=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;u=(c[j>>2]|0)/2|0;v=xrc(0,0,u,(u|0)<0|0?-1:0)|0;u=G;c[s>>2]=v;c[s+4>>2]=u;c[o>>2]=v;c[o+4>>2]=u;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;mJb(e);mJb(n);mJb(m);mJb(a);mJb(t);mJb(h);mJb(k);F1(c[l>>2]|0);c[l>>2]=0;F1(c[q>>2]|0);c[q>>2]=0;p=-12;i=b;return p|0}q=c[j>>2]|0;if((q|0)>0){w=+(q-1|0);j=0;do{g[r+(j<<2)>>2]=(1.0- +U(+(j|0)/w*6.283185307179586))*.5;j=j+1|0;}while((j|0)<(q|0))}j=f+152|0;c[j>>2]=0;c[j+4>>2]=0;c[f+160>>2]=0;j=f+88|0;r=f+96|0;c[f+108>>2]=0;c[f+140>>2]=0;mrc(f+12|0,0,28)|0;mrc(f+72|0,0,16)|0;mrc(f+120|0,0,16)|0;l=(q|0)/2|0;q=xrc(0,0,l,(l|0)<0|0?-1:0)|0;l=G;c[j>>2]=q;c[j+4>>2]=l;c[r>>2]=q;c[r+4>>2]=l;VHb(f+176|0);c[f+180>>2]=0;c[f+184>>2]=0;mrc(f+192|0,0,16)|0;p=0;i=b;return p|0}function qy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1510608;c[e+4>>2]=1;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function ry(a){a=a|0;mJb((c[a+44>>2]|0)+96|0);return}function sy(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(684008)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function ty(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1955880;c[e+4>>2]=2;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function uy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=305096;c[e+4>>2]=3;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function vy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1959512;c[e+4>>2]=5;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function wy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1958936;c[e+4>>2]=6;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function xy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=920032;c[e+4>>2]=9;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function yy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1104424;c[e+4>>2]=8;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function zy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=2021680;c[e+4>>2]=7;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function Ay(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0.0;b=i;d=a+44|0;e=c[d>>2]|0;c[e>>2]=1914456;c[e+4>>2]=0;e=c[d>>2]|0;if((c[e+4>>2]|0)==0){f=0;i=b;return f|0}g=+h[e+32>>3];j=+h[e+40>>3];if(g>0.0&j>0.0){f=0;i=b;return f|0}KIb(a,16,2484704,(a=i,i=i+16|0,h[a>>3]=g,h[a+8>>3]=j,a)|0);i=a;f=-22;i=b;return f|0}function By(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0.0,j=0,k=0.0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0;b=i;d=c[a>>2]|0;a=c[d+44>>2]|0;e=c[c[d+16>>2]>>2]|0;f=+$(+h[a+24>>3]/40.0*2.302585092994046);g=+h[a+32>>3];j=c[e+48>>2]|0;k=g*6.283185307179586/+(j|0);if(k>3.141592653589793){KIb(d,16,2230032,(l=i,i=i+16|0,h[l>>3]=g,c[l+8>>2]=j,l)|0);i=l;m=-22;i=b;return m|0}switch(c[a+8>>2]|0){case 3:{n=+V(k)/(+h[a+40>>3]*2.0);break};case 2:{o=+V(k);n=o*+tc(+(k*+h[a+40>>3]*.34657359027997264/o));break};case 1:{n=+V(k)/(g*2.0/+h[a+40>>3]);break};case 4:{n=+V(k)*.5*+S((f+1.0/f)*(1.0/+h[a+40>>3]+-1.0)+2.0);break};case 0:{n=0.0;break};default:{KIb(0,0,2226336,(l=i,i=i+24|0,c[l>>2]=2221568,c[l+8>>2]=2218016,c[l+16>>2]=266,l)|0);i=l;Hd();return 0}}a:do{switch(c[a+4>>2]|0){case 1:{g=n/f;o=g+1.0;h[a+48>>3]=o;p=+U(k)*-2.0;h[a+56>>3]=p;q=1.0-g;h[a+64>>3]=q;g=f*n;r=g+1.0;h[a+72>>3]=r;h[a+80>>3]=p;s=1.0-g;h[a+88>>3]=s;t=o;u=p;v=q;w=r;x=p;y=s;break};case 0:{t=+h[a+48>>3];u=+h[a+56>>3];v=+h[a+64>>3];w=+h[a+72>>3];x=+h[a+80>>3];y=+h[a+88>>3];break};case 6:{s=n+1.0;h[a+48>>3]=s;p=+U(k)*-2.0;h[a+56>>3]=p;r=1.0-n;h[a+64>>3]=r;h[a+72>>3]=1.0;h[a+80>>3]=p;h[a+88>>3]=1.0;t=s;u=p;v=r;w=1.0;x=p;y=1.0;break};case 7:{p=n+1.0;h[a+48>>3]=p;r=+U(k)*-2.0;h[a+56>>3]=r;s=1.0-n;h[a+64>>3]=s;h[a+72>>3]=s;h[a+80>>3]=r;h[a+88>>3]=p;t=p;u=r;v=s;w=s;x=r;y=p;break};case 3:{p=f+1.0;r=f+-1.0;s=+U(k);q=r*s;o=p-q;g=n*+S(f)*2.0;z=o+g;h[a+48>>3]=z;A=p*s;s=(r-A)*2.0;h[a+56>>3]=s;B=o-g;h[a+64>>3]=B;o=p+q;q=f*(o+g);h[a+72>>3]=q;p=f*-2.0*(r+A);h[a+80>>3]=p;A=f*(o-g);h[a+88>>3]=A;t=z;u=s;v=B;w=q;x=p;y=A;break};case 5:{j=(c[a+16>>2]|0)==0;A=n+1.0;h[a+48>>3]=A;p=+U(k)*-2.0;h[a+56>>3]=p;q=1.0-n;h[a+64>>3]=q;if(j){h[a+72>>3]=n;h[a+80>>3]=0.0;B=-0.0-n;h[a+88>>3]=B;t=A;u=p;v=q;w=n;x=0.0;y=B;break a}else{B=+V(k);s=B*.5;h[a+72>>3]=s;h[a+80>>3]=0.0;z=B*-.5;h[a+88>>3]=z;t=A;u=p;v=q;w=s;x=0.0;y=z;break a}break};case 2:{z=f+1.0;s=f+-1.0;q=+U(k);p=s*q;A=z+p;B=n*+S(f)*2.0;g=A+B;h[a+48>>3]=g;o=z*q;q=(s+o)*-2.0;h[a+56>>3]=q;r=A-B;h[a+64>>3]=r;A=z-p;p=f*(A+B);h[a+72>>3]=p;z=f*2.0*(s-o);h[a+80>>3]=z;o=f*(A-B);h[a+88>>3]=o;t=g;u=q;v=r;w=p;x=z;y=o;break};case 9:{if((c[a+12>>2]|0)==1){h[a+48>>3]=1.0;o=+$(-0.0-k);z=-0.0-o;h[a+56>>3]=z;h[a+64>>3]=0.0;p=1.0-o;h[a+72>>3]=p;mrc(a+80|0,0,16)|0;t=1.0;u=z;v=0.0;w=p;x=0.0;y=0.0;break a}else{p=n+1.0;h[a+48>>3]=p;z=+U(k);o=z*-2.0;h[a+56>>3]=o;r=1.0-n;h[a+64>>3]=r;q=1.0-z;z=q*.5;h[a+72>>3]=z;h[a+80>>3]=q;h[a+88>>3]=z;t=p;u=o;v=r;w=z;x=q;y=z;break a}break};case 8:{if((c[a+12>>2]|0)==1){h[a+48>>3]=1.0;z=+$(-0.0-k);q=-0.0-z;h[a+56>>3]=q;h[a+64>>3]=0.0;r=(z+1.0)*.5;h[a+72>>3]=r;z=-0.0-r;h[a+80>>3]=z;h[a+88>>3]=0.0;t=1.0;u=q;v=0.0;w=r;x=z;y=0.0;break a}else{z=n+1.0;h[a+48>>3]=z;r=+U(k);q=r*-2.0;h[a+56>>3]=q;o=1.0-n;h[a+64>>3]=o;p=r+1.0;r=p*.5;h[a+72>>3]=r;g=-0.0-p;h[a+80>>3]=g;h[a+88>>3]=r;t=z;u=q;v=o;w=r;x=g;y=r;break a}break};default:{KIb(0,0,2226336,(l=i,i=i+24|0,c[l>>2]=2221568,c[l+8>>2]=2218016,c[l+16>>2]=364,l)|0);i=l;Hd();return 0}}}while(0);h[a+56>>3]=u/t;h[a+64>>3]=v/t;h[a+72>>3]=w/t;h[a+80>>3]=x/t;h[a+88>>3]=y/t;j=a+96|0;d=e+148|0;C=jJb(c[j>>2]|0,32,c[d>>2]|0)|0;c[j>>2]=C;if((C|0)==0){m=-12;i=b;return m|0}mrc(C|0,0,c[d>>2]<<5|0)|0;d=c[e+52>>2]|0;if((d|0)==8){c[a+100>>2]=4;m=0;i=b;return m|0}else if((d|0)==9){c[a+100>>2]=6;m=0;i=b;return m|0}else if((d|0)==7){c[a+100>>2]=2;m=0;i=b;return m|0}else if((d|0)==6){c[a+100>>2]=8;m=0;i=b;return m|0}else{KIb(0,0,2226336,(l=i,i=i+24|0,c[l>>2]=2221568,c[l+8>>2]=2218016,c[l+16>>2]=383,l)|0);i=l;Hd();return 0}return 0}function Cy(a,d,e,f,g,j,k,l,m,n,o,p){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=+l;m=+m;n=+n;o=+o;p=+p;var q=0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0.0,F=0.0,G=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0;q=i;r=a;a=d;s=+h[f>>3];t=+h[g>>3];u=+h[j>>3];v=+h[k>>3];w=-0.0-o;o=-0.0-p;if((e|0)>1){p=s;x=t;y=u;z=v;d=0;A=1;while(1){B=+(b[r+(d<<1)>>1]|0);C=y*w+(z*o+(p*m+x*n+B*l));do{if(C<-32768.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(d<<1)>>1]=-32768}else{if(C>32767.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(d<<1)>>1]=32767;break}else{b[a+(d<<1)>>1]=~~C;break}}}while(0);E=+(b[r+(A<<1)>>1]|0);F=C*w+(y*o+(p*n+B*m+E*l));do{if(F<-32768.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(A<<1)>>1]=-32768}else{if(F>32767.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(A<<1)>>1]=32767;break}else{b[a+(A<<1)>>1]=~~F;break}}}while(0);G=d+2|0;H=G|1;if((H|0)<(e|0)){p=E;x=B;y=F;z=C;d=G;A=H}else{I=E;J=B;K=F;L=C;M=G;break}}}else{I=s;J=t;K=u;L=v;M=0}if((M|0)>=(e|0)){N=L;O=K;P=J;Q=I;h[f>>3]=Q;h[g>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}v=+(b[r+(M<<1)>>1]|0);u=L*o+(K*w+(J*n+(I*m+v*l)));if(u<-32768.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(M<<1)>>1]=-32768;N=K;O=u;P=I;Q=v;h[f>>3]=Q;h[g>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}if(u>32767.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;b[a+(M<<1)>>1]=32767;N=K;O=u;P=I;Q=v;h[f>>3]=Q;h[g>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}else{b[a+(M<<1)>>1]=~~u;N=K;O=u;P=I;Q=v;h[f>>3]=Q;h[g>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}}function Dy(a,b,d,e,f,g,j,k,l,m,n,o){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=+k;l=+l;m=+m;n=+n;o=+o;var p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0,D=0.0,E=0.0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0.0,N=0.0,O=0.0,P=0.0;p=i;q=a;a=b;r=+h[e>>3];s=+h[f>>3];t=+h[g>>3];u=+h[j>>3];v=-0.0-n;n=-0.0-o;if((d|0)>1){o=r;w=s;x=t;y=u;b=0;z=1;while(1){A=+(c[q+(b<<2)>>2]|0);B=x*v+(y*n+(o*l+w*m+A*k));do{if(B<-2147483648.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(b<<2)>>2]=-2147483648}else{if(B>2147483647.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(b<<2)>>2]=2147483647;break}else{c[a+(b<<2)>>2]=~~B;break}}}while(0);D=+(c[q+(z<<2)>>2]|0);E=B*v+(x*n+(o*m+A*l+D*k));do{if(E<-2147483648.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(z<<2)>>2]=-2147483648}else{if(E>2147483647.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(z<<2)>>2]=2147483647;break}else{c[a+(z<<2)>>2]=~~E;break}}}while(0);F=b+2|0;G=F|1;if((G|0)<(d|0)){o=D;w=A;x=E;y=B;b=F;z=G}else{H=D;I=A;J=E;K=B;L=F;break}}}else{H=r;I=s;J=t;K=u;L=0}if((L|0)>=(d|0)){M=K;N=J;O=I;P=H;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}u=+(c[q+(L<<2)>>2]|0);t=K*n+(J*v+(I*m+(H*l+u*k)));if(t<-2147483648.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(L<<2)>>2]=-2147483648;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}if(t>2147483647.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[a+(L<<2)>>2]=2147483647;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}else{c[a+(L<<2)>>2]=~~t;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}}function Ey(a,b,d,e,f,j,k,l,m,n,o,p){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;j=j|0;k=k|0;l=+l;m=+m;n=+n;o=+o;p=+p;var q=0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0.0,F=0.0,G=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0;q=i;r=a;a=b;s=+h[e>>3];t=+h[f>>3];u=+h[j>>3];v=+h[k>>3];w=-0.0-o;o=-0.0-p;if((d|0)>1){p=s;x=t;y=u;z=v;b=0;A=1;while(1){B=+g[r+(b<<2)>>2];C=y*w+(z*o+(p*m+x*n+B*l));do{if(C<-1.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(b<<2)>>2]=-1.0}else{if(C>1.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(b<<2)>>2]=1.0;break}else{g[a+(b<<2)>>2]=C;break}}}while(0);E=+g[r+(A<<2)>>2];F=C*w+(y*o+(p*n+B*m+E*l));do{if(F<-1.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(A<<2)>>2]=-1.0}else{if(F>1.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(A<<2)>>2]=1.0;break}else{g[a+(A<<2)>>2]=F;break}}}while(0);G=b+2|0;H=G|1;if((H|0)<(d|0)){p=E;x=B;y=F;z=C;b=G;A=H}else{I=E;J=B;K=F;L=C;M=G;break}}}else{I=s;J=t;K=u;L=v;M=0}if((M|0)>=(d|0)){N=L;O=K;P=J;Q=I;h[e>>3]=Q;h[f>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}v=+g[r+(M<<2)>>2];u=L*o+(K*w+(J*n+(I*m+v*l)));if(u<-1.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(M<<2)>>2]=-1.0;N=K;O=u;P=I;Q=v;h[e>>3]=Q;h[f>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}if(u>1.0){KIb(0,24,2215224,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;g[a+(M<<2)>>2]=1.0;N=K;O=u;P=I;Q=v;h[e>>3]=Q;h[f>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}else{g[a+(M<<2)>>2]=u;N=K;O=u;P=I;Q=v;h[e>>3]=Q;h[f>>3]=P;h[j>>3]=O;h[k>>3]=N;i=q;return}}function Fy(a,b,d,e,f,g,j,k,l,m,n,o){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=+k;l=+l;m=+m;n=+n;o=+o;var p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0,D=0.0,E=0.0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0.0,N=0.0,O=0.0,P=0.0;p=i;q=a;a=b;r=+h[e>>3];s=+h[f>>3];t=+h[g>>3];u=+h[j>>3];v=-0.0-n;n=-0.0-o;if((d|0)>1){o=r;w=s;x=t;y=u;b=0;z=1;while(1){A=+h[q+(b<<3)>>3];B=x*v+(y*n+(o*l+w*m+A*k));do{if(B<-1.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(b<<3)>>3]=-1.0}else{if(B>1.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(b<<3)>>3]=1.0;break}else{h[a+(b<<3)>>3]=B;break}}}while(0);D=+h[q+(z<<3)>>3];E=B*v+(x*n+(o*m+A*l+D*k));do{if(E<-1.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(z<<3)>>3]=-1.0}else{if(E>1.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(z<<3)>>3]=1.0;break}else{h[a+(z<<3)>>3]=E;break}}}while(0);F=b+2|0;G=F|1;if((G|0)<(d|0)){o=D;w=A;x=E;y=B;b=F;z=G}else{H=D;I=A;J=E;K=B;L=F;break}}}else{H=r;I=s;J=t;K=u;L=0}if((L|0)>=(d|0)){M=K;N=J;O=I;P=H;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}u=+h[q+(L<<3)>>3];t=K*n+(J*v+(I*m+(H*l+u*k)));if(t<-1.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(L<<3)>>3]=-1.0;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}if(t>1.0){KIb(0,24,2215224,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;h[a+(L<<3)>>3]=1.0;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}else{h[a+(L<<3)>>3]=t;M=J;N=t;O=H;P=u;h[e>>3]=P;h[f>>3]=O;h[g>>3]=N;h[j>>3]=M;i=p;return}}function Gy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[a+8>>2]|0;g=c[f+44>>2]|0;j=c[c[f+32>>2]>>2]|0;f=c[b+76>>2]|0;do{if((bIb(b)|0)==0){k=oi(a,f)|0;if((k|0)==0){l=-12;i=d;return l|0}else{ZHb(k,c[e>>2]|0)|0;m=k;n=c[e>>2]|0;break}}else{m=b;n=b}}while(0);if((GHb(n)|0)>0){b=g+100|0;a=m+64|0;k=g+96|0;o=g+72|0;p=g+80|0;q=g+88|0;r=g+56|0;s=g+64|0;g=0;t=n;while(1){u=c[k>>2]|0;lf[c[b>>2]&15](c[(c[t+64>>2]|0)+(g<<2)>>2]|0,c[(c[a>>2]|0)+(g<<2)>>2]|0,f,u+(g<<5)|0,u+(g<<5)+8|0,u+(g<<5)+16|0,u+(g<<5)+24|0,+h[o>>3],+h[p>>3],+h[q>>3],+h[r>>3],+h[s>>3]);u=g+1|0;v=(u|0)<(GHb(c[e>>2]|0)|0);w=c[e>>2]|0;if(v){g=u;t=w}else{x=w;break}}}else{x=n}if((x|0)!=(m|0)){VHb(e)}l=lj(j,m)|0;i=d;return l|0}function Hy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=i;i=i+312|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+296|0;m=d+304|0;n=c[b+44>>2]|0;o=c[n+8>>2]|0;a:do{if((o|0)==0){p=0;q=0;r=1;s=68}else{t=_b(o|0,45)|0;u=(MFb(a[o]|0)|0)!=0;do{if((t|0)==0){v=u?1:2}else{w=(MFb(a[t+1|0]|0)|0)!=0;if(u){v=w?3:4;break}else{v=w?5:6;break}}}while(0);if((_b(o|0,44)|0)==0){x=124}else{KIb(b,24,2410704,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;x=44}u=_b(o|0,x|0)|0;do{if((u|0)==0){z=1}else{t=1;w=u;do{A=w+1|0;t=((a[A]|0)!=0)+t|0;w=_b(A|0,x|0)|0;}while((w|0)!=0);if((t|0)<=64){if((t|0)>0){z=t;break}else{p=t;q=v;r=0;s=68;break a}}KIb(b,16,2333616,(y=i,i=i+8|0,c[y>>2]=t,y)|0);i=y;B=-22;i=d;return B|0}}while(0);u=n+24|0;w=o;A=0;C=0;D=0;b:while(1){c[l>>2]=-1;c[m>>2]=-1;switch(v|0){case 4:{E=_b(w|0,45)|0;if((E|0)==0){s=39;break b}F=E+1|0;a[E]=0;c[f>>2]=0;if((F|0)==0){s=47;break b}E=lrc(w|0)|0;Bd(w|0,2134448,(y=i,i=i+16|0,c[y>>2]=l,c[y+8>>2]=f,y)|0)|0;i=y;if((c[f>>2]|0)!=(E|0)){s=47;break b}if((c[l>>2]|0)>>>0>64>>>0){s=47;break b}E=_b(F|0,x|0)|0;if((E|0)==0){H=0}else{a[E]=0;H=E+1|0}E=pGb(F)|0;F=G;if((rGb(E,F)|0)!=1){s=47;break b}if(!((E&C|0)==0&(F&A|0)==0)){s=47;break b}c[u+(D*24|0)+16>>2]=c[l>>2];I=u+(D*24|0)+8|0;c[I>>2]=E;c[I+4>>2]=F;J=F|A;K=E|C;L=H;break};case 1:{E=_b(w|0,x|0)|0;if((E|0)==0){M=0}else{a[E]=0;M=E+1|0}c[j>>2]=0;E=lrc(w|0)|0;Bd(w|0,2134448,(y=i,i=i+16|0,c[y>>2]=l,c[y+8>>2]=j,y)|0)|0;i=y;if((c[j>>2]|0)!=(E|0)){s=20;break b}E=c[l>>2]|0;if(E>>>0>64>>>0){s=20;break b}c[u+(D*24|0)+16>>2]=E;c[u+(D*24|0)+20>>2]=D;J=A;K=C;L=M;break};case 6:{E=_b(w|0,45)|0;if((E|0)==0){s=65;break b}F=E+1|0;a[E]=0;if((F|0)==0){s=65;break b}E=pGb(w)|0;I=G;if((rGb(E,I)|0)!=1){s=65;break b}N=_b(F|0,x|0)|0;if((N|0)==0){O=0}else{a[N]=0;O=N+1|0}N=pGb(F)|0;F=G;if((rGb(N,F)|0)!=1){s=65;break b}if(!((N&C|0)==0&(F&A|0)==0)){s=65;break b}P=u+(D*24|0)|0;c[P>>2]=E;c[P+4>>2]=I;I=u+(D*24|0)+8|0;c[I>>2]=N;c[I+4>>2]=F;J=F|A;K=N|C;L=O;break};case 2:{N=_b(w|0,x|0)|0;if((N|0)==0){Q=0}else{a[N]=0;Q=N+1|0}N=pGb(w)|0;F=G;if((rGb(N,F)|0)!=1){s=25;break b}I=u+(D*24|0)|0;c[I>>2]=N;c[I+4>>2]=F;c[u+(D*24|0)+20>>2]=D;J=A;K=C;L=Q;break};case 5:{F=_b(w|0,45)|0;if((F|0)==0){s=56;break b}I=F+1|0;a[F]=0;if((I|0)==0){s=56;break b}F=pGb(w)|0;N=G;if((rGb(F,N)|0)!=1){s=56;break b}P=_b(I|0,x|0)|0;if((P|0)==0){R=0}else{a[P]=0;R=P+1|0}c[e>>2]=0;P=lrc(I|0)|0;Bd(I|0,2134448,(y=i,i=i+16|0,c[y>>2]=m,c[y+8>>2]=e,y)|0)|0;i=y;if((c[e>>2]|0)!=(P|0)){s=56;break b}P=c[m>>2]|0;if(P>>>0>64>>>0){s=56;break b}I=u+(D*24|0)|0;c[I>>2]=F;c[I+4>>2]=N;c[u+(D*24|0)+20>>2]=P;J=A;K=C;L=R;break};case 3:{P=_b(w|0,45)|0;if((P|0)==0){s=28;break b}N=P+1|0;a[P]=0;c[h>>2]=0;if((N|0)==0){s=36;break b}P=lrc(w|0)|0;Bd(w|0,2134448,(y=i,i=i+16|0,c[y>>2]=l,c[y+8>>2]=h,y)|0)|0;i=y;if((c[h>>2]|0)!=(P|0)){s=36;break b}if((c[l>>2]|0)>>>0>64>>>0){s=36;break b}P=_b(N|0,x|0)|0;if((P|0)==0){S=0}else{a[P]=0;S=P+1|0}c[g>>2]=0;P=lrc(N|0)|0;Bd(N|0,2134448,(y=i,i=i+16|0,c[y>>2]=m,c[y+8>>2]=g,y)|0)|0;i=y;if((c[g>>2]|0)!=(P|0)){s=36;break b}if((c[m>>2]|0)>>>0>64>>>0){s=36;break b}c[u+(D*24|0)+16>>2]=c[l>>2];c[u+(D*24|0)+20>>2]=c[m>>2];J=A;K=C;L=S;break};default:{J=A;K=C;L=w}}P=D+1|0;if((P|0)<(z|0)){w=L;A=J;C=K;D=P}else{s=69;break}}if((s|0)==20){KIb(b,16,1711832,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==25){KIb(b,16,1711832,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==28){c[h>>2]=0;s=36}else if((s|0)==39){c[f>>2]=0;s=47}else if((s|0)==56){KIb(b,16,1711832,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==65){KIb(b,16,1711832,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==69){c[n+1564>>2]=v;D=n+1560|0;c[D>>2]=z;if((K|0)==0&(J|0)==0){T=0;U=v;V=z;W=D;s=70;break}else{X=J;Y=K;Z=0;_=v;$=J;aa=K;ba=D;ca=0;break}}if((s|0)==36){KIb(b,16,1711832,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}else if((s|0)==47){KIb(b,16,1711832,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}}}while(0);if((s|0)==68){c[n+1564>>2]=q;K=n+1560|0;c[K>>2]=p;T=r;U=q;V=p;W=K;s=70}if((s|0)==70){s=tGb(V)|0;X=G;Y=s;Z=T;_=U;$=0;aa=0;ba=W;ca=1}W=n+16|0;c[W>>2]=Y;c[W+4>>2]=X;U=n+12|0;T=c[U>>2]|0;if((T|0)==0){da=X;ea=Y}else{Y=pGb(T)|0;T=G;if((Y|0)==0&(T|0)==0){KIb(b,16,2276952,(y=i,i=i+8|0,c[y>>2]=c[U>>2],y)|0);i=y;B=-22;i=d;return B|0}do{if(Z){X=rGb(Y,T)|0;c[ba>>2]=X;if((X|0)<=0){break}X=n+24|0;s=0;do{c[X+(s*24|0)+16>>2]=s;c[X+(s*24|0)+20>>2]=s;s=s+1|0;}while((s|0)<(c[ba>>2]|0))}else{if(!((aa|0)==(Y|0)&($|0)==(T|0)|ca)){s=k|0;sGb(s,256,0,aa,$);KIb(b,16,2227800,(y=i,i=i+16|0,c[y>>2]=c[U>>2],c[y+8>>2]=s,y)|0);i=y;B=-22;i=d;return B|0}s=c[ba>>2]|0;if((s|0)==(rGb(Y,T)|0)){break}s=c[ba>>2]|0;KIb(b,16,2190392,(y=i,i=i+16|0,c[y>>2]=c[U>>2],c[y+8>>2]=s,y)|0);i=y;B=-22;i=d;return B|0}}while(0);c[W>>2]=Y;c[W+4>>2]=T;da=T;ea=Y}if((ea|0)==0&(da|0)==0){KIb(b,16,2159872,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;B=-22;i=d;return B|0}Rk(n+4|0,ea,da)|0;if(!((_|0)==6|(_|0)==4)){B=0;i=d;return B|0}if((c[ba>>2]|0)<=0){B=0;i=d;return B|0}_=n+24|0;n=0;while(1){da=_+(n*24|0)+8|0;c[_+(n*24|0)+20>>2]=uGb(c[W>>2]|0,c[W+4>>2]|0,c[da>>2]|0,c[da+4>>2]|0)|0;da=n+1|0;if((da|0)<(c[ba>>2]|0)){n=da}else{B=0;break}}i=d;return B|0}function Iy(a){a=a|0;var b=0,d=0;b=c[a+44>>2]|0;dl(a,Tk()|0);cl(a,Uk()|0);d=Vk()|0;Xk(d,(c[c[a+16>>2]>>2]|0)+84|0);Xk(c[b+4>>2]|0,(c[c[a+32>>2]>>2]|0)+80|0);return 0}function Jy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+264|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;h=c[c[g+32>>2]>>2]|0;j=c[g+44>>2]|0;g=a+40|0;a=rGb(c[g>>2]|0,c[g+4>>2]|0)|0;g=c[j+1560>>2]|0;k=b+64|0;l=c[k>>2]|0;m=l;nrc(f|0,m|0,a<<2)|0;do{if((g|0)>(a|0)){if(!(g>>>0>8>>>0)){if((l|0)==(b|0)){break}kJb(m);n=c[e>>2]|0;c[n+64>>2]=n;break}n=pJb(g<<2)|0;o=n;if((n|0)==0){VHb(e);p=-12;i=d;return p|0}n=c[k>>2]|0;if((n|0)==(b|0)){c[k>>2]=o;break}else{kJb(n);c[(c[e>>2]|0)+64>>2]=o;break}}}while(0);if((g|0)>0){k=j+24|0;j=0;do{c[(c[(c[e>>2]|0)+64>>2]|0)+(c[k+(j*24|0)+20>>2]<<2)>>2]=c[f+(c[k+(j*24|0)+16>>2]<<2)>>2];j=j+1|0;}while((j|0)<(g|0))}j=c[e>>2]|0;k=c[j+64>>2]|0;if((j|0)==(k|0)){q=j}else{nrc(j|0,k|0,g>>>0<8>>>0?g<<2:32)|0;q=c[e>>2]|0}p=lj(h,q)|0;i=d;return p|0}function Ky(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+256|0;d=c[a+8>>2]|0;e=c[d+44>>2]|0;f=a+40|0;a=rGb(c[f>>2]|0,c[f+4>>2]|0)|0;g=e+1560|0;if((c[g>>2]|0)<=0){h=0;i=b;return h|0}j=e+24|0;k=e+1564|0;e=b|0;l=d;d=0;m=0;while(1){n=j+(m*24|0)|0;if(((c[k>>2]|0)-5|0)>>>0<2>>>0){o=n|0;p=uGb(c[f>>2]|0,c[f+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[j+(m*24|0)+16>>2]=p;q=p}else{q=c[j+(m*24|0)+16>>2]|0}p=j+(m*24|0)+16|0;do{if((q|0)>-1&(q|0)<(a|0)){r=d}else{sGb(e,256,0,c[f>>2]|0,c[f+4>>2]|0);o=n|0;s=c[o>>2]|0;t=c[o+4>>2]|0;if((s|0)==0&(t|0)==0){KIb(l,16,2524336,(u=i,i=i+16|0,c[u>>2]=c[p>>2],c[u+8>>2]=e,u)|0);i=u;r=-22;break}else{o=vGb(s,t)|0;KIb(l,16,2541376,(u=i,i=i+16|0,c[u>>2]=o,c[u+8>>2]=e,u)|0);i=u;r=-22;break}}}while(0);p=m+1|0;if((p|0)<(c[g>>2]|0)){d=r;m=p}else{h=r;break}}i=b;return h|0}function Ly(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+64|0;d=b|0;e=c[a+44>>2]|0;f=e+16|0;g=pGb(c[f>>2]|0)|0;h=G;j=e+8|0;c[j>>2]=g;c[j+4>>2]=h;if((g|0)==0&(h|0)==0){KIb(a,16,2410360,(e=i,i=i+8|0,c[e>>2]=c[f>>2],e)|0);i=e;k=-22;i=b;return k|0}e=rGb(g,h)|0;if((e|0)<=0){k=0;i=b;return k|0}h=d;g=d+4|0;f=d|0;l=a+40|0;m=a+28|0;n=a+32|0;o=a+36|0;a=0;while(1){p=xGb(c[j>>2]|0,c[j+4>>2]|0,a)|0;q=G;mrc(h|0,0,60)|0;c[g>>2]=1;c[f>>2]=vGb(p,q)|0;Qi(a,l,4,m,n,d)|0;c[o>>2]=c[l>>2];q=a+1|0;if((q|0)<(e|0)){a=q}else{k=0;break}}i=b;return k|0}function My(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+44>>2]|0;c[d>>2]=0;dl(a,Tk()|0);cl(a,Uk()|0);g=f+8|0;Rk(d,c[g>>2]|0,c[g+4>>2]|0)|0;Xk(c[d>>2]|0,(c[c[a+16>>2]>>2]|0)+84|0);d=a+40|0;if((c[d>>2]|0)==0){i=b;return 0}f=a+32|0;a=0;do{c[e>>2]=0;h=xGb(c[g>>2]|0,c[g+4>>2]|0,a)|0;Rk(e,h,G)|0;Xk(c[e>>2]|0,(c[(c[f>>2]|0)+(a<<2)>>2]|0)+80|0);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0);i=b;return 0}function Ny(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;b=c[a+8>>2]|0;a=b+40|0;f=b+32|0;b=0;g=0;while(1){if(!(b>>>0<(c[a>>2]|0)>>>0)){h=g;j=5;break}k=$Hb(c[e>>2]|0)|0;if((k|0)==0){h=-12;j=5;break}l=c[k+64>>2]|0;m=c[l+(b<<2)>>2]|0;c[l>>2]=m;c[k>>2]=m;m=(c[e>>2]|0)+352|0;l=xGb(c[m>>2]|0,c[m+4>>2]|0,b)|0;m=k+352|0;c[m>>2]=l;c[m+4>>2]=G;HHb(k,1);m=lj(c[(c[f>>2]|0)+(b<<2)>>2]|0,k)|0;if((m|0)<0){h=m;j=5;break}else{b=b+1|0;g=m}}if((j|0)==5){VHb(e);i=d;return h|0}return 0}function Oy(a){a=a|0;var b=0;b=(c[a+44>>2]|0)+96|0;c[b>>2]=0;c[b+4>>2]=-2147483648;return 0}function Py(a){a=a|0;var b=0;b=c[a+44>>2]|0;mJb(b+24|0);mJb(b+20|0);VHb(b+80|0);return}function Qy(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(684e3)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function Ry(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,H=0.0,I=0.0,J=0.0,K=0,L=0,M=0,N=0.0;b=i;i=i+8|0;d=b|0;e=a|0;f=c[e>>2]|0;g=c[f+44>>2]|0;j=Wi(c[c[f+16>>2]>>2]|0)|0;if(!((j|0)==-541478725)){k=j;i=b;return k|0}if((c[f+76>>2]|0)!=0){k=-541478725;i=b;return k|0}if((c[g+88>>2]|0)==0){k=-541478725;i=b;return k|0}g=c[(c[e>>2]|0)+44>>2]|0;e=c[a+148>>2]|0;f=g+88|0;j=c[f>>2]|0;l=oi(a,(j|0)<2048?j:2048)|0;if((l|0)==0){k=-12;i=b;return k|0}j=g+96|0;m=c[j+4>>2]|0;n=l+136|0;c[n>>2]=c[j>>2];c[n+4>>2]=m;m=l+76|0;n=c[m>>2]|0;c[d>>2]=1;c[d+4>>2]=c[a+48>>2];o=XIb(n,(n|0)<0|0?-1:0,d,a+56|0)|0;d=wrc(c[j>>2]|0,c[j+4>>2]|0,o,G)|0;c[j>>2]=d;c[j+4>>2]=G;do{if((e|0)>0){j=c[(c[g+80>>2]|0)+64>>2]|0;d=c[l+64>>2]|0;o=c[g+24>>2]|0;n=g+92|0;p=c[n>>2]|0;q=c[m>>2]|0;r=g+32|0;s=g+40|0;t=g+20|0;u=g+4|0;if((q|0)<=0){v=p;w=q;x=n;break}y=c[g+84>>2]|0;z=0;while(1){A=c[j+(z<<2)>>2]|0;B=c[d+(z<<2)>>2]|0;C=o+(z*24|0)+16|0;D=p;E=0;do{F=+h[A+(D<<3)>>3];H=+h[C>>3];if(+h[r>>3]>H){I=+h[s>>3]}else{J=+aa(H);K=c[u>>2]|0;L=c[t>>2]|0;M=1;while(1){if((M|0)>=(K|0)){break}if(J>+h[L+(M<<5)>>3]){M=M+1|0}else{break}}K=M-1|0;H=J- +h[L+(K<<5)>>3];I=+$(+h[L+(K<<5)+8>>3]+H*(H*+h[L+(K<<5)+16>>3]+ +h[L+(K<<5)+24>>3]))}H=F*I;if(H<-1.0){N=-1.0}else{N=H>1.0?1.0:H}h[B+(E<<3)>>3]=N;K=D+1|0;D=K-((K|0)<(y|0)?0:y)|0;E=E+1|0;}while((E|0)<(q|0));E=z+1|0;if((E|0)<(e|0)){z=E}else{v=D;w=q;x=n;break}}}else{v=0;w=c[m>>2]|0;x=g+92|0}}while(0);c[f>>2]=(c[f>>2]|0)-w;c[x>>2]=v;k=lj(a,l)|0;i=b;return k|0}function Sy(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0,Q=0,R=0.0,W=0,X=0,Y=0,Z=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0,na=0,oa=0.0,pa=0.0;d=i;i=i+8|0;e=d|0;f=c[b>>2]|0;g=f+44|0;j=c[g>>2]|0;k=c[b+48>>2]|0;l=j+48|0;m=+h[l>>3]*2.302585092994046;c[e>>2]=0;n=c[b+148>>2]|0;o=j+8|0;p=c[o>>2]|0;q=1;while(1){r=a[p]|0;if((r<<24>>24|0)==0){break}else if((r<<24>>24|0)==32|(r<<24>>24|0)==124){s=q+1|0}else{s=q}p=p+1|0;q=s}t=m/20.0;s=j+12|0;p=c[s>>2]|0;r=1;while(1){u=a[p]|0;if((u<<24>>24|0)==0){break}else if((u<<24>>24|0)==32|(u<<24>>24|0)==124){v=r+1|0}else{v=r}p=p+1|0;r=v}v=j+16|0;p=c[v>>2]|0;u=1;while(1){w=a[p]|0;if((w<<24>>24|0)==32|(w<<24>>24|0)==124){x=u+1|0}else if((w<<24>>24|0)==0){break}else{x=u}p=p+1|0;u=x}if((n|0)<1){KIb(f,16,2464880,(y=i,i=i+8|0,c[y>>2]=n,y)|0);i=y;z=-22;i=d;return z|0}if((q|0)>(n|0)|(r|0)>(n|0)){KIb(f,16,2451632,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-22;i=d;return z|0}x=c[g>>2]|0;mJb(x+24|0);mJb(x+20|0);VHb(x+80|0);if(n>>>0<89478485>>>0){A=pJb(n*24|0)|0}else{A=0}x=j+24|0;c[x>>2]=A;A=(u<<1)+8|0;c[j+4>>2]=A;do{if(A>>>0<67108863>>>0){p=pJb(A<<5)|0;w=j+20|0;c[w>>2]=p;if((c[x>>2]|0)==0|(p|0)==0){break}a:do{if((q|0)>0){p=0;B=0;C=c[o>>2]|0;while(1){D=HFb(C,2435632,e)|0;E=Bd(D|0,2425872,(y=i,i=i+8|0,c[y>>2]=(c[x>>2]|0)+(p*24|0),y)|0)|0;i=y;if(+h[(c[x>>2]|0)+(p*24|0)>>3]<0.0){break}D=((E|0)==1)+B|0;E=p+1|0;if((E|0)<(q|0)){p=E;B=D;C=0}else{F=D;break a}}C=c[g>>2]|0;mJb(C+24|0);mJb(C+20|0);VHb(C+80|0);z=-22;i=d;return z|0}else{F=0}}while(0);b:do{if((r|0)>0){C=0;B=0;p=c[s>>2]|0;while(1){D=HFb(p,2435632,e)|0;E=Bd(D|0,2425872,(y=i,i=i+8|0,c[y>>2]=(c[x>>2]|0)+(C*24|0)+8,y)|0)|0;i=y;if(+h[(c[x>>2]|0)+(C*24|0)+8>>3]<0.0){break}D=((E|0)==1)+B|0;E=C+1|0;if((E|0)<(r|0)){C=E;B=D;p=0}else{G=D;break b}}p=c[g>>2]|0;mJb(p+24|0);mJb(p+20|0);VHb(p+80|0);z=-22;i=d;return z|0}else{G=0}}while(0);if((F|0)!=(G|0)){KIb(f,16,2415072,(y=i,i=i+16|0,c[y>>2]=F,c[y+8>>2]=G,y)|0);i=y;p=c[g>>2]|0;mJb(p+24|0);mJb(p+20|0);VHb(p+80|0);z=-22;i=d;return z|0}do{if((u|0)>0){p=f;B=0;C=c[v>>2]|0;while(1){D=HFb(C,2435632,e)|0;H=B+1|0;E=H<<1;I=c[w>>2]|0;J=Bd(D|0,2407144,(y=i,i=i+16|0,c[y>>2]=I+(E<<5),c[y+8>>2]=I+(E<<5)+8,y)|0)|0;i=y;if((J|0)!=2){K=38;break}if((B|0)==0){J=c[w>>2]|0;L=J;M=+h[J+(E<<5)>>3]}else{J=c[w>>2]|0;m=+h[J+(E<<5)>>3];if(+h[J+(B<<1<<5)>>3]>m){K=42;break}else{L=J;M=m}}J=L+(E<<5)+8|0;m=+h[J>>3]-M;h[J>>3]=m;KIb(p,48,2386024,(y=i,i=i+24|0,c[y>>2]=B,h[y+8>>3]=M,h[y+16>>3]=m,y)|0);i=y;if((H|0)<(u|0)){B=H;C=0}else{K=44;break}}if((K|0)==38){KIb(p,16,2399680,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;C=c[g>>2]|0;mJb(C+24|0);mJb(C+20|0);VHb(C+80|0);z=-22;i=d;return z|0}else if((K|0)==42){KIb(p,16,2392608,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;C=c[g>>2]|0;mJb(C+24|0);mJb(C+20|0);VHb(C+80|0);z=-22;i=d;return z|0}else if((K|0)==44){if((H|0)==0){K=45;break}C=c[w>>2]|0;if(+h[C+(H<<1<<5)>>3]!=0.0){N=C;O=H;K=47;break}else{P=H;Q=C;break}}}else{K=45}}while(0);if((K|0)==45){N=c[w>>2]|0;O=0;K=47}if((K|0)==47){P=O+1|0;Q=N}h[Q>>3]=+h[Q+64>>3]- +h[l>>3]*2.0;h[Q+8>>3]=+h[Q+72>>3];C=P+1|0;if((C|0)>2){B=2;J=C;C=Q;while(1){E=B<<1;I=E-2|0;m=+h[C+(I<<5)+8>>3];D=E-4|0;R=+h[C+(I<<5)>>3];c:do{if((m- +h[C+(D<<5)+8>>3])*(+h[C+(E<<5)>>3]-R)-(+h[C+(E<<5)+8>>3]-m)*(R- +h[C+(D<<5)>>3])!=0.0){W=J;X=B}else{I=J-1|0;Y=B-1|0;if((Y|0)<(I|0)){Z=Y;aa=C}else{W=I;X=Y;break}while(1){ba=Z+1|0;ca=aa+(Z<<1<<5)|0;da=aa+(ba<<1<<5)|0;c[ca>>2]=c[da>>2];c[ca+4>>2]=c[da+4>>2];c[ca+8>>2]=c[da+8>>2];c[ca+12>>2]=c[da+12>>2];c[ca+16>>2]=c[da+16>>2];c[ca+20>>2]=c[da+20>>2];c[ca+24>>2]=c[da+24>>2];c[ca+28>>2]=c[da+28>>2];if((ba|0)>=(I|0)){W=I;X=Y;break c}Z=ba;aa=c[w>>2]|0}}}while(0);D=X+1|0;E=c[w>>2]|0;if((D|0)<(W|0)){B=D;J=W;C=E}else{ea=E;break}}}else{ea=Q}C=j+56|0;J=0;while(1){if((J|0)!=0){if(!(+h[ea+(J-2<<5)>>3]!=0.0)){break}}B=ea+(J<<5)+8|0;R=+h[C>>3]+ +h[B>>3];w=ea+(J<<5)|0;h[w>>3]=+h[w>>3]*.11512925464970229;h[B>>3]=R*.11512925464970229;J=J+2|0}R=+h[ea+64>>3];if(R!=0.0){J=4;C=2;m=R;while(1){B=J-4|0;h[ea+(B<<5)+16>>3]=0.0;w=ea+(C<<5)+8|0;R=+h[w>>3];fa=R- +h[ea+(B<<5)+8>>3];E=ea+(C<<5)|0;ga=m- +h[ea+(B<<5)>>3];h[ea+(B<<5)+24>>3]=fa/ga;h[ea+(C<<5)+16>>3]=0.0;ha=+h[ea+(J<<5)+8>>3];B=ea+(J<<5)|0;ia=+h[B>>3];h[ea+(C<<5)+24>>3]=(ha-R)/(ia-m);ja=+_(+fa,+ga);ka=+S(fa*fa+ga*ga);ga=t>ka?ka:t;ka=m- +U(ja)*ga;D=J-3|0;p=ea+(D<<5)|0;h[p>>3]=ka;fa=R-ga*+V(ja);Y=ea+(D<<5)+8|0;h[Y>>3]=fa;ja=+h[w>>3];ga=ha-ja;ha=+h[E>>3];R=ia-ha;ia=+_(+ga,+R);la=+S(ga*ga+R*R)*.5;R=t>la?la:t;la=ha+ +U(ia)*R;ga=ja+ +V(ia)*R;h[E>>3]=la;h[w>>3]=ga;R=+h[p>>3];ia=(ha+ka+la)/3.0-R;ka=+h[Y>>3];ha=la-R;R=((ga+(ja+fa))/3.0-ka)/ia;fa=((ga-ka)/ha-R)/(ha-ia);h[ea+(D<<5)+16>>3]=fa;h[ea+(D<<5)+24>>3]=R-ia*fa;fa=+h[B>>3];if(fa!=0.0){C=J;J=J+2|0;m=fa}else{break}}ma=J-1|0;na=J}else{ma=1;na=2}h[ea+(ma<<5)>>3]=0.0;h[ea+(ma<<5)+8>>3]=+h[ea+(na<<5)+8>>3];h[j+32>>3]=+$(+h[ea+32>>3]);h[j+40>>3]=+$(+h[ea+40>>3]);m=+(k|0);if((n|0)>0){fa=1.0/m;C=j+64|0;B=0;do{D=c[x>>2]|0;Y=D+(B*24|0)|0;ia=+h[Y>>3];if(ia>fa){oa=1.0- +$(-1.0/(m*ia))}else{oa=1.0}h[Y>>3]=oa;Y=D+(B*24|0)+8|0;ia=+h[Y>>3];if(ia>fa){pa=1.0- +$(-1.0/(m*ia))}else{pa=1.0}h[Y>>3]=pa;h[D+(B*24|0)+16>>3]=+T(+10.0,+(+h[C>>3]/20.0));B=B+1|0;}while((B|0)<(n|0))}B=~~(m*+h[j+72>>3]);C=j+84|0;c[C>>2]=B;if((B|0)<1){c[j+104>>2]=192;z=0;i=d;return z|0}B=UHb()|0;c[j+80>>2]=B;if((B|0)==0){J=c[g>>2]|0;mJb(J+24|0);mJb(J+20|0);VHb(J+80|0);z=-12;i=d;return z|0}c[B+80>>2]=c[b+52>>2];c[B+76>>2]=c[C>>2];C=b+40|0;J=c[C+4>>2]|0;D=B+352|0;c[D>>2]=c[C>>2];c[D+4>>2]=J;J=XHb(B,32)|0;if((J|0)!=0){z=J;i=d;return z|0}J=b+156|0;c[J>>2]=c[J>>2]|1;c[j+104>>2]=944;z=0;i=d;return z|0}else{c[j+20>>2]=0}}while(0);j=c[g>>2]|0;mJb(j+24|0);mJb(j+20|0);VHb(j+80|0);z=-12;i=d;return z|0}function Ty(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0.0,H=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+44>>2]|0;j=c[c[a+16>>2]>>2]|0;k=c[j+148>>2]|0;l=c[b+76>>2]|0;do{if((bIb(b)|0)==0){m=oi(j,l)|0;c[f>>2]=m;if((m|0)==0){VHb(e);n=-12;i=d;return n|0}o=ZHb(m,c[e>>2]|0)|0;if((o|0)>=0){p=m;q=c[e>>2]|0;break}VHb(f);VHb(e);n=o;i=d;return n|0}else{c[f>>2]=b;p=b;q=b}}while(0);if((k|0)>0){b=g+24|0;j=(l|0)>0;o=g+32|0;m=g+40|0;r=g+20|0;s=g+4|0;g=0;do{t=c[(c[q+64>>2]|0)+(g<<2)>>2]|0;u=c[(c[p+64>>2]|0)+(g<<2)>>2]|0;v=c[b>>2]|0;if(j){w=v+(g*24|0)+16|0;x=v+(g*24|0)+8|0;y=v+(g*24|0)|0;v=0;do{z=t+(v<<3)|0;A=+R(+(+h[z>>3]));B=+h[w>>3];C=A-B;A=B+C*+h[(C>0.0?y:x)>>3];h[w>>3]=A;C=+h[z>>3];if(+h[o>>3]>A){D=+h[m>>3]}else{B=+aa(A);z=c[s>>2]|0;E=c[r>>2]|0;F=1;while(1){if((F|0)>=(z|0)){break}if(B>+h[E+(F<<5)>>3]){F=F+1|0}else{break}}z=F-1|0;A=B- +h[E+(z<<5)>>3];D=+$(+h[E+(z<<5)+8>>3]+A*(A*+h[E+(z<<5)+16>>3]+ +h[E+(z<<5)+24>>3]))}A=C*D;if(A<-1.0){G=-1.0}else{G=A>1.0?1.0:A}h[u+(v<<3)>>3]=G;v=v+1|0;}while((v|0)<(l|0))}g=g+1|0;}while((g|0)<(k|0))}if((q|0)==(p|0)){H=q}else{VHb(e);H=c[f>>2]|0}n=lj(c[c[a+32>>2]>>2]|0,H)|0;i=d;return n|0}function Uy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0.0,U=0.0,V=0.0,W=0.0,X=0,Y=0,Z=0,_=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0.0,ka=0.0,la=0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[e>>2]=b;j=c[a+44>>2]|0;k=c[c[a+16>>2]>>2]|0;l=c[k+148>>2]|0;m=c[b+76>>2]|0;c[f>>2]=0;n=j+96|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==(-2147483648|0)){o=b+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;o=(p|0)==0&(q|0)==(-2147483648|0);c[n>>2]=o?0:p;c[n+4>>2]=o?0:q}a:do{if((l|0)>0){q=j+80|0;o=j+24|0;p=j+88|0;r=j+92|0;s=(m|0)>0;t=j+84|0;u=g|0;v=g+4|0;w=k+48|0;x=k+56|0;y=j+32|0;z=j+40|0;A=j+20|0;B=j+4|0;C=0;D=0;E=b;b:while(1){F=c[(c[E+64>>2]|0)+(C<<2)>>2]|0;H=c[(c[(c[q>>2]|0)+64>>2]|0)+(C<<2)>>2]|0;I=c[o>>2]|0;J=c[p>>2]|0;K=c[r>>2]|0;if(s){L=I+(C*24|0)+16|0;M=I+(C*24|0)+8|0;N=I+(C*24|0)|0;I=J;O=0;P=K;Q=0;S=D;while(1){T=+h[F+(Q<<3)>>3];U=+R(+T);V=+h[L>>3];W=U-V;U=V+W*+h[(W>0.0?N:M)>>3];h[L>>3]=U;X=c[t>>2]|0;if((I|0)<(X|0)){Y=O;Z=I+1|0;_=X;ba=S;ca=H+(P<<3)|0}else{if((S|0)==0){X=m-Q|0;da=oi(k,X)|0;c[f>>2]=da;if((da|0)==0){ea=11;break b}fa=ZHb(da,c[e>>2]|0)|0;if((fa|0)<0){ea=13;break b}ga=c[n+4>>2]|0;ha=da+136|0;c[ha>>2]=c[n>>2];c[ha+4>>2]=ga;c[u>>2]=1;c[v>>2]=c[w>>2];ga=XIb(X,(X|0)<0|0?-1:0,g,x)|0;X=wrc(c[n>>2]|0,c[n+4>>2]|0,ga,G)|0;c[n>>2]=X;c[n+4>>2]=G;ia=c[f>>2]|0;ja=+h[L>>3]}else{ia=S;ja=U}X=c[(c[ia+64>>2]|0)+(C<<2)>>2]|0;ga=H+(P<<3)|0;U=+h[ga>>3];if(+h[y>>3]>ja){ka=+h[z>>3]}else{W=+aa(ja);ha=c[B>>2]|0;da=c[A>>2]|0;la=1;while(1){if((la|0)>=(ha|0)){break}if(W>+h[da+(la<<5)>>3]){la=la+1|0}else{break}}ha=la-1|0;V=W- +h[da+(ha<<5)>>3];ka=+$(+h[da+(ha<<5)+8>>3]+V*(V*+h[da+(ha<<5)+16>>3]+ +h[da+(ha<<5)+24>>3]))}V=U*ka;if(V<-1.0){ma=-1.0}else{ma=V>1.0?1.0:V}h[X+(O<<3)>>3]=ma;Y=O+1|0;Z=I;_=c[t>>2]|0;ba=ia;ca=ga}h[ca>>3]=T;ha=P+1|0;na=ha-((ha|0)<(_|0)?0:_)|0;ha=Q+1|0;if((ha|0)<(m|0)){I=Z;O=Y;P=na;Q=ha;S=ba}else{oa=Z;pa=na;qa=ba;break}}}else{oa=J;pa=K;qa=D}S=C+1|0;if((S|0)>=(l|0)){ra=oa;sa=pa;ta=p;ua=r;break a}C=S;D=qa;E=c[e>>2]|0}if((ea|0)==11){VHb(e);va=-12;i=d;return va|0}else if((ea|0)==13){VHb(f);VHb(e);va=fa;i=d;return va|0}}else{ra=0;sa=0;ta=j+88|0;ua=j+92|0}}while(0);c[ta>>2]=ra;c[ua>>2]=sa;VHb(e);e=c[f>>2]|0;if((e|0)==0){va=0;i=d;return va|0}va=lj(c[c[a+32>>2]>>2]|0,e)|0;i=d;return va|0}function Vy(a,b){a=a|0;b=b|0;var d=0;d=c[a+8>>2]|0;return We[c[(c[d+44>>2]|0)+104>>2]&2047](d,b)|0}function Wy(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[d>>2]=0;c[e>>2]=0;Qk(d,1,0)|0;dl(a,c[d>>2]|0);Rk(e,3,0)|0;bl(a,c[e>>2]|0);cl(a,Ok(683832)|0);i=b;return 0}function Xy(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;h=d+8|0;j=c[c[(c[h>>2]|0)+32>>2]>>2]|0;k=oi(d,c[e+76>>2]|0)|0;if((k|0)==0){VHb(g);l=-12;i=f;return l|0}ZHb(k,e)|0;e=c[(c[h>>2]|0)+44>>2]|0;h=e;d=c[k>>2]|0;m=c[g>>2]|0;n=c[m>>2]|0;o=n;p=c[m+76>>2]<<1;m=(p|0)<64?p:64;nrc(e+128|0,n|0,m<<1)|0;n=h+(m<<1)|0;if(h>>>0<n>>>0){m=h;p=d;while(1){q=0;r=0;s=0;while(1){t=(ca(a[1234264+s|0]|0,b[m+(s<<1)>>1]|0)|0)+q|0;u=r+1&65535;if(u<<16>>16<64){q=t;r=u;s=u<<16>>16}else{break}}s=t>>6;if((s+32768|0)>>>0>65535>>>0){v=(t>>31^32767)&65535}else{v=s&65535}b[p>>1]=v;s=p+2|0;r=m+2|0;if(r>>>0<n>>>0){m=r;p=s}else{w=s;break}}}else{w=d}d=c[(c[g>>2]|0)+76>>2]<<1;if((d|0)>63){p=o+(d-64<<1)|0;if(o>>>0<p>>>0){m=o;o=w;while(1){w=0;n=0;v=0;while(1){x=(ca(a[1234264+v|0]|0,b[m+(v<<1)>>1]|0)|0)+w|0;t=n+1&65535;if(t<<16>>16<64){w=x;n=t;v=t<<16>>16}else{break}}v=x>>6;if((v+32768|0)>>>0>65535>>>0){y=(x>>31^32767)&65535}else{y=v&65535}b[o>>1]=y;v=m+2|0;if(v>>>0<p>>>0){m=v;o=o+2|0}else{break}}}nrc(e|0,p|0,128)|0}else{orc(e|0,h+(d<<1)|0,128)|0}VHb(g);l=lj(j,k)|0;i=f;return l|0}function Yy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;i=i+112|0;e=d|0;f=d+8|0;g=d+16|0;h=d+48|0;j=b+44|0;k=c[j>>2]|0;l=k+12|0;m=pGb(c[l>>2]|0)|0;n=G;o=k+16|0;c[o>>2]=m;c[o+4>>2]=n;if((m|0)==0&(n|0)==0){KIb(b,16,2408912,(p=i,i=i+8|0,c[p>>2]=c[l>>2],p)|0);i=p;q=-22;i=d;return q|0}l=rGb(m,n)|0;n=k+24|0;c[n>>2]=l;m=k+28|0;c[m>>2]=pJb(l*24|0)|0;l=k+36|0;c[l>>2]=pJb(c[n>>2]<<2)|0;r=k+4|0;s=pJb(c[r>>2]<<2)|0;c[k+32>>2]=s;if((c[m>>2]|0)==0){q=-12;i=d;return q|0}if((c[l>>2]|0)==0|(s|0)==0){q=-12;i=d;return q|0}if((c[n>>2]|0)>0){s=0;do{l=xGb(c[o>>2]|0,c[o+4>>2]|0,s)|0;k=c[m>>2]|0;t=k+(s*24|0)+16|0;c[t>>2]=l;c[t+4>>2]=G;c[k+(s*24|0)>>2]=-1;s=s+1|0;}while((s|0)<(c[n>>2]|0))}n=c[j>>2]|0;j=c[n+8>>2]|0;c[e>>2]=j;a:do{if((j|0)!=0){if((_b(j|0,44)|0)==0){u=124}else{KIb(b,24,2134152,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=44}s=n+16|0;m=n+28|0;o=n+4|0;k=j;while(1){if((a[k]|0)==0){break a}t=_b(k|0,u|0)|0;if((t|0)==0){v=0}else{a[t]=0;v=t+1|0}t=_b(k|0,45)|0;if((t|0)==0){w=15;break}x=t+1|0;a[t]=0;t=pGb(x)|0;l=G;if((t|0)==0&(l|0)==0){w=17;break}if((rGb(t,l)|0)!=1){w=19;break}y=c[s>>2]|0;z=c[s+4>>2]|0;if((y&t|0)==0&(z&l|0)==0){w=21;break}A=uGb(y,z,t,l)|0;if((c[(c[m>>2]|0)+(A*24|0)>>2]|0)>-1){w=23;break}B=rb(k|0,e|0,0)|0;if((B|0)<0){w=26;break}if((B|0)>=(c[o>>2]|0)){w=26;break}l=c[e>>2]|0;if((a[l]|0)==0){C=l}else{t=l+1|0;c[e>>2]=t;C=t}t=rb(C|0,f|0,0)|0;if((c[f>>2]|0)==(C|0)){l=pGb(C)|0;z=G;if((l|0)==0&(z|0)==0){w=31;break}if((rGb(l,z)|0)!=1){w=33;break}y=c[m>>2]|0;c[y+(A*24|0)>>2]=B;D=y+(A*24|0)+8|0;c[D>>2]=l;c[D+4>>2]=z}else{z=c[m>>2]|0;c[z+(A*24|0)>>2]=B;c[z+(A*24|0)+4>>2]=t}c[e>>2]=v;if((v|0)==0){break a}else{k=v}}if((w|0)==15){KIb(b,16,2110656,(p=i,i=i+8|0,c[p>>2]=k,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==17){KIb(b,16,2628344,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==19){KIb(b,16,2603480,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==21){KIb(b,16,2577776,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==23){KIb(b,16,2558656,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==26){KIb(b,16,2541256,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==31){KIb(b,16,2524216,(p=i,i=i+8|0,c[p>>2]=C,p)|0);i=p;q=-22;i=d;return q|0}else if((w|0)==33){KIb(b,16,2509096,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=d;return q|0}}}while(0);if((c[r>>2]|0)<=0){q=0;i=d;return q|0}w=h;C=g|0;g=h+4|0;B=h|0;x=h+36|0;v=h+52|0;e=b+24|0;f=b+12|0;u=b+16|0;j=b+20|0;b=0;while(1){mrc(w|0,0,60)|0;Rb(C|0,32,2332560,(p=i,i=i+8|0,c[p>>2]=b,p)|0)|0;i=p;c[g>>2]=1;c[B>>2]=rJb(C)|0;c[x>>2]=960;c[v>>2]=1;Qi(b,e,12,f,u,h)|0;c[j>>2]=c[e>>2];n=b+1|0;if((n|0)<(c[r>>2]|0)){b=n}else{q=0;break}}i=d;return q|0}function Zy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+44>>2]|0;d=a+24|0;if((c[d>>2]|0)==0){e=b+32|0;f=b+28|0;mJb(f);g=b+36|0;mJb(g);mJb(e);return}h=a+12|0;a=b+32|0;i=a;j=0;while(1){mJb((c[h>>2]|0)+(j*60|0)|0);VHb((c[i>>2]|0)+(j<<2)|0);k=j+1|0;if(k>>>0<(c[d>>2]|0)>>>0){j=k}else{e=a;break}}f=b+28|0;mJb(f);g=b+36|0;mJb(g);mJb(e);return}function _y(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;c[d>>2]=0;f=e+16|0;Rk(d,c[f>>2]|0,c[f+4>>2]|0)|0;Xk(c[d>>2]|0,(c[c[a+32>>2]>>2]|0)+80|0);d=a+24|0;if((c[d>>2]|0)==0){g=Tk()|0;dl(a,g);h=Uk()|0;cl(a,h);i=b;return 0}f=a+16|0;e=0;do{j=Vk()|0;Xk(j,(c[(c[f>>2]|0)+(e<<2)>>2]|0)+84|0);e=e+1|0;}while(e>>>0<(c[d>>2]|0)>>>0);g=Tk()|0;dl(a,g);h=Uk()|0;cl(a,h);i=b;return 0}function $y(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a+8>>2]|0;f=c[e+44>>2]|0;g=e+16|0;h=c[e+24>>2]|0;e=0;while(1){if(!(e>>>0<h>>>0)){j=4;break}if((c[(c[g>>2]|0)+(e<<2)>>2]|0)==(a|0)){break}else{e=e+1|0}}if((j|0)==4){KIb(0,0,2276088,(k=i,i=i+24|0,c[k>>2]=2227136,c[k+8>>2]=2189952,c[k+16>>2]=90,k)|0);i=k;Hd();return 0}j=(c[f+32>>2]|0)+(e<<2)|0;if((c[j>>2]|0)==0){c[j>>2]=b;i=d;return 0}else{KIb(0,0,2276088,(k=i,i=i+24|0,c[k>>2]=2159592,c[k+8>>2]=2189952,c[k+16>>2]=91,k)|0);i=k;Hd();return 0}return 0}function az(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e+44>>2]|0;g=e+24|0;a:do{if((c[g>>2]|0)==0){h=0}else{j=e+16|0;k=f+32|0;l=0;m=0;while(1){if((c[(c[k>>2]|0)+(l<<2)>>2]|0)==0){n=Wi(c[(c[j>>2]|0)+(l<<2)>>2]|0)|0;if((n|0)<0){o=n;break}}do{if((l|0)==0){n=c[(c[c[k>>2]>>2]|0)+76>>2]|0;p=c[g>>2]|0;if(!(p>>>0>1>>>0)){q=n;r=p;break}p=c[j>>2]|0;s=1;while(1){c[(c[p+(s<<2)>>2]|0)+88>>2]=n;t=s+1|0;u=c[g>>2]|0;if(t>>>0<u>>>0){s=t}else{q=n;r=u;break}}}else{q=m;r=c[g>>2]|0}}while(0);n=l+1|0;if(n>>>0<r>>>0){l=n;m=q}else{h=q;break a}}i=b;return o|0}}while(0);q=UHb()|0;c[d>>2]=q;if((q|0)==0){o=-12;i=b;return o|0}r=f+24|0;e=c[r>>2]|0;do{if(e>>>0>8>>>0){m=pJb(e<<2)|0;c[(c[d>>2]|0)+64>>2]=m;m=c[d>>2]|0;if((c[m+64>>2]|0)==0){v=-12;break}w=c[r>>2]|0;x=m;y=15}else{w=e;x=q;y=15}}while(0);b:do{if((y|0)==15){do{if((w|0)>0){q=f+28|0;e=f+32|0;m=f+36|0;l=0;j=0;k=2147483647;n=x;while(1){s=c[q>>2]|0;p=c[(c[e>>2]|0)+(c[s+(l*24|0)>>2]<<2)>>2]|0;u=c[s+(l*24|0)+4>>2]|0;c[(c[n+64>>2]|0)+(l<<2)>>2]=c[(c[p+64>>2]|0)+(u<<2)>>2];s=c[p+32>>2]|0;z=(k|0)>(s|0)?s:k;s=eIb(p,u)|0;if((s|0)==0){v=-22;break b}u=s|0;p=0;while(1){if((p|0)>=(j|0)){break}if((c[c[(c[m>>2]|0)+(p<<2)>>2]>>2]|0)==(c[u>>2]|0)){break}else{p=p+1|0}}if((p|0)==(l|0)){c[(c[m>>2]|0)+(j<<2)>>2]=s;A=j+1|0}else{A=j}u=l+1|0;if((u|0)>=(c[r>>2]|0)){break}l=u;j=A;k=z;n=c[d>>2]|0}if(!(A>>>0>8>>>0)){B=z;C=A;break}n=A-8|0;c[(c[d>>2]|0)+396>>2]=n;k=pJb(n<<2)|0;c[(c[d>>2]|0)+392>>2]=k;k=c[d>>2]|0;if((c[k+392>>2]|0)!=0){B=z;C=A;break}c[k+396>>2]=0;v=-12;break b}else{B=2147483647;C=0}}while(0);k=C>>>0<8>>>0?C:8;n=f+36|0;j=0;while(1){if(!(j>>>0<k>>>0)){break}l=eGb(c[(c[n>>2]|0)+(j<<2)>>2]|0)|0;c[(c[d>>2]|0)+360+(j<<2)>>2]=l;if((c[(c[d>>2]|0)+360+(j<<2)>>2]|0)==0){v=-12;break b}else{j=j+1|0}}j=0;k=c[d>>2]|0;while(1){if((j|0)>=(c[k+396>>2]|0)){break}l=eGb(c[(c[n>>2]|0)+(j+8<<2)>>2]|0)|0;c[(c[(c[d>>2]|0)+392>>2]|0)+(j<<2)>>2]=l;l=c[d>>2]|0;if((c[(c[l+392>>2]|0)+(j<<2)>>2]|0)==0){v=-12;break b}else{j=j+1|0;k=l}}c[k+76>>2]=h;j=a+40|0;n=c[j+4>>2]|0;l=k+352|0;c[l>>2]=c[j>>2];c[l+4>>2]=n;HHb(k,c[a+148>>2]|0);n=c[d>>2]|0;c[n+80>>2]=c[a+52>>2];c[n+344>>2]=c[a+48>>2];l=f+32|0;j=(c[c[l>>2]>>2]|0)+136|0;m=c[j+4>>2]|0;e=n+136|0;c[e>>2]=c[j>>2];c[e+4>>2]=m;c[n+32>>2]=B;m=c[n+64>>2]|0;if((n|0)==(m|0)){D=n}else{e=c[r>>2]|0;nrc(n|0,m|0,e>>>0<8>>>0?e<<2:32)|0;D=c[d>>2]|0}e=lj(a,D)|0;if((c[g>>2]|0)==0){o=e;i=b;return o|0}else{E=0}while(1){VHb((c[l>>2]|0)+(E<<2)|0);m=E+1|0;if(m>>>0<(c[g>>2]|0)>>>0){E=m}else{o=e;break}}i=b;return o|0}}while(0);VHb(d);o=v;i=b;return o|0}function bz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;a=c[e+44>>2]|0;f=e+24|0;g=pJb(c[f>>2]<<3)|0;h=g;c[d>>2]=h;if((g|0)==0){j=-12;i=b;return j|0}g=a+24|0;k=c[g>>2]|0;a:do{if((k|0)>0){l=a+28|0;m=e+16|0;n=0;o=h;p=k;while(1){q=c[l>>2]|0;r=q+(n*24|0)|0;s=c[r>>2]|0;if((s|0)<0){t=o;u=p}else{v=q+(n*24|0)+8|0;w=c[v>>2]|0;x=c[v+4>>2]|0;y=(c[(c[m>>2]|0)+(s<<2)>>2]|0)+40|0;if((w|0)==0&(x|0)==0){s=xGb(c[y>>2]|0,c[y+4>>2]|0,c[q+(n*24|0)+4>>2]|0)|0;q=G;c[v>>2]=s;c[v+4>>2]=q;z=q;A=s}else{z=x;A=w}if((c[y>>2]&A|0)==0&(c[y+4>>2]&z|0)==0){B=10;break}y=c[d>>2]|0;w=y+(c[r>>2]<<3)|0;x=c[w+4>>2]|z;c[w>>2]=c[w>>2]|A;c[w+4>>2]=x;t=y;u=c[g>>2]|0}y=n+1|0;if((y|0)<(u|0)){n=y;o=t;p=u}else{break}}if((B|0)==10){p=vGb(A,z)|0;o=c[r>>2]|0;KIb(e,16,2407080,(C=i,i=i+16|0,c[C>>2]=p,c[C+8>>2]=o,C)|0);i=C;D=-22;break}if((u|0)<=0){B=31;break}o=c[a+28>>2]|0;p=e+16|0;n=0;m=u;while(1){l=o+(n*24|0)|0;b:do{if((c[l>>2]|0)<0){y=c[f>>2]|0;if((y|0)==0){E=m;break}x=c[p>>2]|0;w=o+(n*24|0)+16|0;s=c[w>>2]|0;q=c[w+4>>2]|0;w=0;while(1){v=(c[x+(w<<2)>>2]|0)+40|0;if(!((c[v>>2]&s|0)==0&(c[v+4>>2]&q|0)==0)){F=t+(w<<3)|0;if((c[F>>2]&s|0)==0&(c[F+4>>2]&q|0)==0){break}}v=w+1|0;if(v>>>0<y>>>0){w=v}else{E=m;break b}}c[l>>2]=w;y=o+(n*24|0)+8|0;c[y>>2]=s;c[y+4>>2]=q;y=c[F+4>>2]|q;c[F>>2]=c[F>>2]|s;c[F+4>>2]=y;E=c[g>>2]|0}else{E=m}}while(0);l=n+1|0;if((l|0)<(E|0)){n=l;m=E}else{break}}if((E|0)<=0){B=31;break}m=a+28|0;n=e+16|0;o=0;while(1){H=c[m>>2]|0;p=H+(o*24|0)|0;l=c[p>>2]|0;if((l|0)<0){y=c[d>>2]|0;x=c[f>>2]|0;v=0;while(1){if(!(v>>>0<x>>>0)){I=l;break}J=y+(v<<3)|0;K=c[J>>2]|0;L=c[J+4>>2]|0;M=(c[(c[n>>2]|0)+(v<<2)>>2]|0)+40|0;N=c[M>>2]|0;O=c[M+4>>2]|0;if((N&K|0)==(N|0)&(O&L|0)==(O|0)){v=v+1|0}else{B=27;break}}if((B|0)==27){B=0;c[p>>2]=v;y=xGb(N&~K,O&~L,0)|0;x=G;M=H+(o*24|0)+8|0;c[M>>2]=y;c[M+4>>2]=x;M=c[J+4>>2]|x;c[J>>2]=c[J>>2]|y;c[J+4>>2]=M;I=c[p>>2]|0}if((I|0)<0){break}else{P=I}}else{P=l}M=(c[(c[n>>2]|0)+(P<<2)>>2]|0)+40|0;y=H+(o*24|0)+8|0;c[H+(o*24|0)+4>>2]=uGb(c[M>>2]|0,c[M+4>>2]|0,c[y>>2]|0,c[y+4>>2]|0)|0;y=o+1|0;if((y|0)<(c[g>>2]|0)){o=y}else{B=31;break a}}n=H+(o*24|0)+16|0;m=vGb(c[n>>2]|0,c[n+4>>2]|0)|0;KIb(e,16,2399624,(C=i,i=i+8|0,c[C>>2]=m,C)|0);i=C;D=0}else{B=31}}while(0);do{if((B|0)==31){H=e;KIb(H,40,2392592,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;if((c[g>>2]|0)>0){P=a+28|0;I=0;do{J=c[P>>2]|0;L=c[J+(I*24|0)>>2]|0;O=J+(I*24|0)+8|0;K=vGb(c[O>>2]|0,c[O+4>>2]|0)|0;O=J+(I*24|0)+16|0;J=vGb(c[O>>2]|0,c[O+4>>2]|0)|0;KIb(H,40,2386008,(C=i,i=i+24|0,c[C>>2]=L,c[C+8>>2]=K,c[C+16>>2]=J,C)|0);i=C;I=I+1|0;}while((I|0)<(c[g>>2]|0))}KIb(H,40,2378864,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;I=c[f>>2]|0;if((I|0)==0){D=0;break}else{Q=0;R=I}while(1){I=(c[d>>2]|0)+(Q<<3)|0;if((c[I>>2]|0)==0&(c[I+4>>2]|0)==0){KIb(H,24,2372912,(C=i,i=i+8|0,c[C>>2]=Q,C)|0);i=C;S=c[f>>2]|0}else{S=R}I=Q+1|0;if(I>>>0<S>>>0){Q=I;R=S}else{D=0;break}}}}while(0);mJb(d);j=D;i=b;return j|0}function cz(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+72|0;e=d|0;f=d+8|0;g=d+16|0;j=d+24|0;k=d+32|0;l=d+40|0;m=d+48|0;n=d+56|0;o=d+64|0;p=o;q=i;i=i+8|0;r=c[b+44>>2]|0;s=r+4|0;t=rJb(c[s>>2]|0)|0;c[o>>2]=0;c[o+4>>2]=0;if((c[s>>2]|0)==0){KIb(b,16,2408584,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-22;i=d;return v|0}if((t|0)==0){v=-12;i=d;return v|0}s=HFb(t,2332368,j)|0;c[g>>2]=s;o=r+8|0;w=r+31780|0;x=b;b=jl(o,w,s,x)|0;a:do{if((b|0)<0){y=b}else{s=HFb(0,2332368,j)|0;c[g>>2]=s;do{if((s|0)==0){z=0}else{A=r+31768|0;B=r+16|0;C=s;b:while(1){if((fz(g,k,n)|0)!=0){D=9;break}if((c[n>>2]|0)==0){E=c[k>>2]|0}else{F=c[o>>2]|0;H=c[o+4>>2]|0;I=yrc(1,0,c[k>>2]|0)|0;J=G;if((I&F|0)==0&(J&H|0)==0){D=12;break}K=wrc(I,J,-1,-1)|0;J=rGb(K&F,G&H)|0;c[k>>2]=J;E=J}if((E|0)<0){D=17;break}if((E|0)>=(c[w>>2]|0)){D=17;break}c[f>>2]=0;Bd(c[g>>2]|0,2577744,(u=i,i=i+8|0,c[u>>2]=f,u)|0)|0;i=u;J=c[f>>2]|0;H=c[g>>2]|0;F=H+J|0;c[g>>2]=F;K=a[F]|0;if((K<<24>>24|0)==60){F=yrc(1,0,E|0)|0;I=G|c[A+4>>2];c[A>>2]=F|c[A>>2];c[A+4>>2]=I}else if((K<<24>>24|0)!=61){D=21;break}K=H+(J+1)|0;while(1){c[g>>2]=K;h[q>>3]=1.0;J=Bd(K|0,2134088,(u=i,i=i+24|0,c[u>>2]=q,c[u+8>>2]=m,c[u+16>>2]=m,u)|0)|0;i=u;if((J|0)!=0){c[g>>2]=K+(c[m>>2]|0)}if((fz(g,l,n)|0)!=0){D=25;break b}J=c[n>>2]|0;H=p+(J<<2)|0;c[H>>2]=(c[H>>2]|0)+1;if((c[p+(((J|0)==0)<<2)>>2]|0)!=0){D=27;break b}h[B+(E*504|0)+(c[l>>2]<<3)>>3]=+h[q>>3];c[e>>2]=0;J=c[g>>2]|0;Bd(J|0,2577744,(u=i,i=i+8|0,c[u>>2]=e,u)|0)|0;i=u;H=c[e>>2]|0;L=J+H|0;c[g>>2]=L;I=a[L]|0;if((I<<24>>24|0)==0){break}else if((I<<24>>24|0)!=43){D=29;break b}K=J+(H+1)|0}K=HFb(0,2332368,j)|0;c[g>>2]=K;if((K|0)==0){D=31;break}else{C=K}}if((D|0)==9){KIb(x,16,2275920,(u=i,i=i+8|0,c[u>>2]=c[g>>2],u)|0);i=u;y=-22;break a}else if((D|0)==12){KIb(x,16,2226968,(u=i,i=i+8|0,c[u>>2]=C,u)|0);i=u;y=-22;break a}else if((D|0)==17){KIb(x,16,2189776,(u=i,i=i+8|0,c[u>>2]=C,u)|0);i=u;y=-22;break a}else if((D|0)==21){KIb(x,16,2159440,(u=i,i=i+8|0,c[u>>2]=C,u)|0);i=u;y=-22;break a}else if((D|0)==25){KIb(x,16,2110584,(u=i,i=i+8|0,c[u>>2]=c[g>>2],u)|0);i=u;y=-22;break a}else if((D|0)==27){KIb(x,16,2628264,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;y=-22;break a}else if((D|0)==29){KIb(x,16,2603368,(u=i,i=i+8|0,c[u>>2]=L,u)|0);i=u;y=-22;break a}else if((D|0)==31){z=(c[p+4>>2]|0)!=0|0;break}}}while(0);c[r+31776>>2]=z;y=0}}while(0);kJb(t);v=y;i=d;return v|0}function dz(a){a=a|0;Zvb((c[a+44>>2]|0)+31916|0);return}function ez(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+8|0;d=b|0;e=c[a+44>>2]|0;f=e;g=c[c[a+16>>2]>>2]|0;j=c[c[a+32>>2]>>2]|0;k=0;a:while(1){l=0;m=0;while(1){n=+h[f+16+(k*504|0)+(l<<3)>>3];o=n!=0.0;if(o&n!=1.0){p=0;break a}if(o){if((m|0)==0){q=m+1|0}else{p=0;break a}}else{q=m}o=l+1|0;if((o|0)<63){l=o;m=q}else{break}}m=k+1|0;if((m|0)<63){k=m}else{p=1;break}}c[e+31784>>2]=p;dl(a,Sk(1)|0);p=Uk()|0;if((p|0)==0){r=-12;i=b;return r|0}cl(a,p);Xk(Wk()|0,g+84|0);c[d>>2]=0;g=e+8|0;p=c[g>>2]|0;a=c[g+4>>2]|0;if((p|0)==0&(a|0)==0){g=c[e+31780>>2]|0;s=((g|0)<0|0?-1:0)|-2147483648;t=g|0}else{s=a;t=p}Rk(d,t,s)|0;Xk(c[d>>2]|0,j+80|0);r=0;i=b;return r|0}function fz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+32|0;f=e|0;g=e+16|0;h=e+24|0;c[h>>2]=0;c[f>>2]=0;Bd(c[a>>2]|0,2577744,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;k=(c[a>>2]|0)+(c[f>>2]|0)|0;c[a>>2]=k;f=e+8|0;l=Bd(k|0,2558608,(j=i,i=i+16|0,c[j>>2]=f,c[j+8>>2]=g,j)|0)|0;i=j;if((l|0)==0){l=Bd(c[a>>2]|0,2541224,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;j=c[h>>2]|0;if(!((l|0)!=0&(j|0)>-1&(j|0)<63)){m=-22;i=e;return m|0}c[b>>2]=j;c[d>>2]=0;c[a>>2]=(c[a>>2]|0)+(c[g>>2]|0);m=0;i=e;return m|0}j=pGb(f)|0;f=G;l=1;if((f|0)<(l|0)|(f|0)==(l|0)&j>>>0<0>>>0){n=f;o=j}else{c[h>>2]=(c[h>>2]|0)+32;n=(f|0)<0|0?-1:0;o=f}l=0;if((n|0)<(l|0)|(n|0)==(l|0)&o>>>0<65536>>>0){p=n;q=o}else{c[h>>2]=(c[h>>2]|0)+16;p=n>>16|((n|0)<0|0?-1:0)<<16;q=o>>>16|n<<16}n=0;if((p|0)<(n|0)|(p|0)==(n|0)&q>>>0<256>>>0){r=p;s=q}else{c[h>>2]=(c[h>>2]|0)+8;r=p>>8|((p|0)<0|0?-1:0)<<24;s=q>>>8|p<<24}p=0;if((r|0)<(p|0)|(r|0)==(p|0)&s>>>0<16>>>0){t=r;u=s}else{c[h>>2]=(c[h>>2]|0)+4;t=r>>4|((r|0)<0|0?-1:0)<<28;u=s>>>4|r<<28}r=0;if((t|0)<(r|0)|(t|0)==(r|0)&u>>>0<4>>>0){v=t;w=u}else{c[h>>2]=(c[h>>2]|0)+2;v=t>>2|((t|0)<0|0?-1:0)<<30;w=u>>>2|t<<30}t=0;u=c[h>>2]|0;if((v|0)<(t|0)|(v|0)==(t|0)&w>>>0<2>>>0){x=u}else{w=u+1|0;c[h>>2]=w;x=w}if((x|0)>62){m=-22;i=e;return m|0}w=yrc(1,0,x|0)|0;if(!((j|0)==(w|0)&(f|0)==(G|0))){m=-22;i=e;return m|0}c[b>>2]=x;c[d>>2]=1;c[a>>2]=(c[a>>2]|0)+(c[g>>2]|0);m=0;i=e;return m|0}function gz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=b;f=c[b+76>>2]|0;g=a+8|0;a=c[c[(c[g>>2]|0)+32>>2]>>2]|0;h=oi(a,f)|0;if((h|0)==0){j=-12;i=d;return j|0}bwb(c[(c[(c[g>>2]|0)+44>>2]|0)+31916>>2]|0,c[h+64>>2]|0,f,c[b+64>>2]|0,f)|0;ZHb(h,b)|0;b=a+40|0;f=c[b+4>>2]|0;g=h+352|0;c[g>>2]=c[b>>2];c[g+4>>2]=f;HHb(h,c[a+148>>2]|0);f=lj(a,h)|0;VHb(e);j=f;i=d;return j|0}function hz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0,E=0.0,F=0,H=0,I=0,J=0,K=0;b=i;i=i+1024|0;d=b|0;e=c[a+8>>2]|0;f=c[e+44>>2]|0;if((c[f+31776>>2]|0)!=0){g=a+40|0;j=c[g>>2]|0;k=c[g+4>>2]|0;g=f+31780|0;l=f+16|0;m=0;n=0;while(1){o=yrc(1,0,m|0)|0;if((j&o|0)==0&(k&G|0)==0){p=n}else{if((c[g>>2]|0)>0){o=0;do{h[l+(o*504|0)+(n<<3)>>3]=+h[l+(o*504|0)+(m<<3)>>3];o=o+1|0;}while((o|0)<(c[g>>2]|0))}p=n+1|0}o=m+1|0;if((o|0)<63){m=o;n=p}else{break}}}p=a+148|0;do{if((c[p>>2]|0)<=32){n=f+31780|0;if((c[n>>2]|0)>32){break}m=f+31916|0;g=f+8|0;l=c[a+52>>2]|0;k=c[a+48>>2]|0;j=a+40|0;o=e;q=Yvb(c[m>>2]|0,c[g>>2]|0,c[g+4>>2]|0,l,k,c[j>>2]|0,c[j+4>>2]|0,l,k,0,o)|0;c[m>>2]=q;if((q|0)==0){r=-12;i=b;return r|0}if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){k=c[p>>2]|0;IJb(q,2484528,k,(k|0)<0|0?-1:0,0)|0}if((c[g>>2]|0)==0&(c[g+4>>2]|0)==0){k=c[n>>2]|0;IJb(c[m>>2]|0,2473192,k,(k|0)<0|0?-1:0,0)|0}k=f+31784|0;q=(c[n>>2]|0)>0;if((c[k>>2]|0)==0){if(q){l=f+31768|0;s=f+16|0;t=s;u=0;while(1){v=c[l>>2]|0;w=c[l+4>>2]|0;x=yrc(1,0,u|0)|0;do{if(!((v&x|0)==0&(w&G|0)==0)){y=c[p>>2]|0;z=(y|0)>0;if(z){A=0;B=0.0;while(1){C=B+ +h[t+(u*504|0)+(A<<3)>>3];D=A+1|0;if((D|0)<(y|0)){A=D;B=C}else{E=C;break}}}else{E=0.0}if(E>-1.0e-5&E<1.0e-5){if(!(E!=0.0)){break}KIb(o,24,2435520,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;break}else{if(z){H=0}else{break}do{A=t+(u*504|0)+(H<<3)|0;h[A>>3]=+h[A>>3]/E;H=H+1|0;}while((H|0)<(y|0))}}}while(0);w=u+1|0;if((w|0)<(c[n>>2]|0)){u=w}else{I=s;break}}}else{I=f+16|0}IJb(c[m>>2]|0,2464832,c[j>>2]|0,c[j+4>>2]|0,0)|0;IJb(c[m>>2]|0,2425760,c[g>>2]|0,c[g+4>>2]|0,0)|0;zvb(c[m>>2]|0,I,63)|0}else{if(q){s=f+16|0;u=f+31788|0;t=u;l=0;while(1){w=c[p>>2]|0;x=0;while(1){if((x|0)>=(w|0)){J=-1;break}if(+h[s+(l*504|0)+(x<<3)>>3]!=0.0){J=x;break}else{x=x+1|0}}c[t+(l<<2)>>2]=J;x=l+1|0;if((x|0)<(c[n>>2]|0)){l=x}else{K=u;break}}}else{K=f+31788|0}IJb(c[m>>2]|0,2464832,c[g>>2]|0,c[g+4>>2]|0,0)|0;u=c[n>>2]|0;IJb(c[m>>2]|0,2451520,u,(u|0)<0|0?-1:0,0)|0;Vvb(c[m>>2]|0,K)|0}u=$vb(c[m>>2]|0)|0;if((u|0)<0){r=u;i=b;return r|0}if((c[n>>2]|0)>0){u=d|0;l=d+1024|0;t=f+16|0;s=0;do{if((c[p>>2]|0)>0){q=u;j=0;while(1){x=l-q|0;B=+h[t+(s*504|0)+(j<<3)>>3];w=Rb(q|0,x|0,2414984,(F=i,i=i+24|0,c[F>>2]=(j|0)!=0?2407072:10230384,h[F+8>>3]=B,c[F+16>>2]=j,F)|0)|0;i=F;v=j+1|0;if((v|0)<(c[p>>2]|0)){q=q+((x|0)>(w|0)?w:x)|0;j=v}else{break}}}KIb(o,40,2392576,(F=i,i=i+16|0,c[F>>2]=s,c[F+8>>2]=u,F)|0);i=F;s=s+1|0;}while((s|0)<(c[n>>2]|0))}if((c[k>>2]|0)==0){r=0;i=b;return r|0}KIb(o,32,2385976,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;if((c[n>>2]|0)>0){s=f+31788|0;u=0;do{t=c[s+(u<<2)>>2]|0;if((t|0)<0){KIb(o,32,2378856,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}else{KIb(o,32,2372904,(F=i,i=i+8|0,c[F>>2]=t,F)|0);i=F}u=u+1|0;}while((u|0)<(c[n>>2]|0))}KIb(o,32,2362272,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;r=0;i=b;return r|0}}while(0);KIb(e,16,2495096,(F=i,i=i+8|0,c[F>>2]=32,F)|0);i=F;r=-1163346256;i=b;return r|0}function iz(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0;b=i;d=c[a+44>>2]|0;e=d;f=0;j=0;while(1){k=(c[e+(j<<2)>>2]|0)+f|0;l=j+1|0;if((l|0)<12e3){f=k;j=l}else{m=12e3;n=0;break}}while(1){o=m-1|0;if((m|0)==0){break}j=(c[e+(o<<2)>>2]|0)+n|0;if((j*20|0)>>>0<k>>>0){m=o;n=j}else{break}}p=64.54- +(o|0)/100.0;if(p<-24.0){q=-24.0}else{q=p>64.0?64.0:p}o=a;KIb(o,32,2408344,(a=i,i=i+8|0,h[a>>3]=q,a)|0);i=a;KIb(o,32,2332112,(a=i,i=i+8|0,h[a>>3]=+g[d+48e3>>2],a)|0);i=a;i=b;return}function jz(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[d>>2]=0;c[e>>2]=0;Qk(d,3,0)|0;dl(a,c[d>>2]|0);Rk(e,3,0)|0;bl(a,c[e>>2]|0);c[d>>2]=0;e=0;do{f=c[1204424+(e*232|0)>>2]|0;Qk(d,f,(f|0)<0|0?-1:0)|0;e=e+1|0;}while(e>>>0<20>>>0);cl(a,c[d>>2]|0);i=b;return 0}function kz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0.0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0,pa=0.0,qa=0.0,ra=0,sa=0,ta=0.0,ua=0.0,va=0,wa=0,xa=0.0,ya=0.0,za=0,Aa=0,Ba=0.0,Ca=0.0,Da=0,Ea=0,Fa=0.0,Ga=0.0,Ha=0,Ia=0,Ja=0.0,Ka=0.0,La=0,Ma=0.0,Na=0,Oa=0,Pa=0,Qa=0.0,Ra=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;j=c[a+8>>2]|0;k=c[c[j+32>>2]>>2]|0;l=c[j+44>>2]|0;j=l;m=b+76|0;n=oi(a,c[m>>2]|0)|0;c[f>>2]=n;if((n|0)==0){VHb(e);o=-12;i=d;return o|0}a=c[m>>2]|0;m=l+48e3|0;p=c[b>>2]|0;if((a|0)==0){q=0.0}else{b=p;r=0.0;s=a;while(1){a=s-1|0;t=+g[b>>2];do{if(t>r){u=t}else{v=-0.0-t;if(!(r<v)){u=r;break}u=v}}while(0);t=+g[b+4>>2];do{if(t>u){w=t}else{v=-0.0-t;if(!(u<v)){w=u;break}w=v}}while(0);if((a|0)==0){q=w;break}else{b=b+8|0;r=w;s=a}}}w=+g[m>>2];g[m>>2]=q>w?q:w;m=p;p=n|0;s=c[p>>2]|0;b=n+76|0;n=c[b>>2]|0;x=c[l+48012>>2]|0;y=c[l+48016>>2]|0;z=l+48028|0;A=l+49052|0;B=l+48004|0;C=c[B>>2]|0;D=-20;while(1){if((D|0)>=0){break}E=D+C|0;if(+R(+(+g[j+48028+(E<<2)>>2]))>1.0e-10){break}if(+R(+(+g[j+49052+(E<<2)>>2]))>1.0e-10){break}else{D=D+1|0}}if((D|0)==0){mrc(z|0,0,2048)|0}if((n|0)==0){F=C}else{D=y+8|0;E=x+8|0;G=y+16|0;H=x+16|0;I=y+24|0;J=x+24|0;K=y+32|0;L=x+32|0;M=y+40|0;N=x+40|0;O=y+48|0;P=x+48|0;S=y+56|0;T=x+56|0;U=y+64|0;V=x+64|0;W=y+72|0;X=x+72|0;Y=y+80|0;Z=x+80|0;x=l+48972|0;_=l+49996|0;$=s;s=m;m=C;C=n;while(1){n=C-1|0;w=+g[s>>2];g[j+49052+(m<<2)>>2]=w;q=+h[y>>3];r=+g[s+4>>2];aa=m+1|0;g[j+49052+(aa<<2)>>2]=r;ba=m-2|0;u=+h[D>>3];t=+h[E>>3];ca=m-1|0;da=m-4|0;v=+h[G>>3];ea=+h[H>>3];fa=m-3|0;ga=m-6|0;ha=+h[I>>3];ia=+h[J>>3];ja=m-5|0;ka=m-8|0;la=+h[K>>3];ma=+h[L>>3];na=m-7|0;oa=m-10|0;pa=+h[M>>3];qa=+h[N>>3];ra=m-9|0;sa=m-12|0;ta=+h[O>>3];ua=+h[P>>3];va=m-11|0;wa=m-14|0;xa=+h[S>>3];ya=+h[T>>3];za=m-13|0;Aa=m-16|0;Ba=+h[U>>3];Ca=+h[V>>3];Da=m-15|0;Ea=m-18|0;Fa=+h[W>>3];Ga=+h[X>>3];Ha=m-17|0;Ia=m-20|0;Ja=+h[Y>>3];Ka=+h[Z>>3];La=m-19|0;Ma=q*r+(u*+g[j+49052+(ca<<2)>>2]-t*+g[j+48028+(ca<<2)>>2])+(v*+g[j+49052+(fa<<2)>>2]-ea*+g[j+48028+(fa<<2)>>2])+(ha*+g[j+49052+(ja<<2)>>2]-ia*+g[j+48028+(ja<<2)>>2])+(la*+g[j+49052+(na<<2)>>2]-ma*+g[j+48028+(na<<2)>>2])+(pa*+g[j+49052+(ra<<2)>>2]-qa*+g[j+48028+(ra<<2)>>2])+(ta*+g[j+49052+(va<<2)>>2]-ua*+g[j+48028+(va<<2)>>2])+(xa*+g[j+49052+(za<<2)>>2]-ya*+g[j+48028+(za<<2)>>2])+(Ba*+g[j+49052+(Da<<2)>>2]-Ca*+g[j+48028+(Da<<2)>>2])+(Fa*+g[j+49052+(Ha<<2)>>2]-Ga*+g[j+48028+(Ha<<2)>>2])+(Ja*+g[j+49052+(La<<2)>>2]-Ka*+g[j+48028+(La<<2)>>2]);r=w*q+(+g[j+49052+(ba<<2)>>2]*u- +g[j+48028+(ba<<2)>>2]*t)+(+g[j+49052+(da<<2)>>2]*v- +g[j+48028+(da<<2)>>2]*ea)+(+g[j+49052+(ga<<2)>>2]*ha- +g[j+48028+(ga<<2)>>2]*ia)+(+g[j+49052+(ka<<2)>>2]*la- +g[j+48028+(ka<<2)>>2]*ma)+(+g[j+49052+(oa<<2)>>2]*pa- +g[j+48028+(oa<<2)>>2]*qa)+(+g[j+49052+(sa<<2)>>2]*ta- +g[j+48028+(sa<<2)>>2]*ua)+(+g[j+49052+(wa<<2)>>2]*xa- +g[j+48028+(wa<<2)>>2]*ya)+(+g[j+49052+(Aa<<2)>>2]*Ba- +g[j+48028+(Aa<<2)>>2]*Ca)+(+g[j+49052+(Ea<<2)>>2]*Fa- +g[j+48028+(Ea<<2)>>2]*Ga)+(+g[j+49052+(Ia<<2)>>2]*Ja- +g[j+48028+(Ia<<2)>>2]*Ka);g[j+48028+(m<<2)>>2]=r;g[$>>2]=r;r=Ma;g[j+48028+(aa<<2)>>2]=r;g[$+4>>2]=r;aa=m+2|0;if((aa|0)==256){nrc(z|0,x|0,80)|0;nrc(A|0,_|0,80)|0;Na=20}else{Na=aa}if((n|0)==0){F=Na;break}else{$=$+8|0;s=s+8|0;m=Na;C=n}}}c[B>>2]=F;F=c[p>>2]|0;B=c[b>>2]|0;C=c[l+48020>>2]|0;Na=c[l+48024>>2]|0;m=l+50076|0;s=l+51100|0;$=l+48008|0;_=c[$>>2]|0;A=-4;while(1){if((A|0)>=0){break}x=A+_|0;if(+R(+(+g[j+50076+(x<<2)>>2]))>1.0e-10){break}if(+R(+(+g[j+51100+(x<<2)>>2]))>1.0e-10){break}else{A=A+1|0}}if((A|0)==0){mrc(m|0,0,2048)|0}if((B|0)==0){Oa=_}else{A=Na+8|0;x=C+8|0;z=Na+16|0;Z=C+16|0;C=l+51084|0;Y=l+52108|0;X=F;F=_;_=B;while(1){B=_-1|0;r=+g[X>>2];g[j+51100+(F<<2)>>2]=r;Ma=+h[Na>>3];W=X+4|0;Ka=+g[W>>2];V=F+1|0;g[j+51100+(V<<2)>>2]=Ka;U=F-2|0;Ja=+h[A>>3];Ga=+h[x>>3];T=F-1|0;S=F-4|0;Fa=+h[z>>3];Ca=+h[Z>>3];P=F-3|0;Ba=Ma*Ka+(Ja*+g[j+51100+(T<<2)>>2]-Ga*+g[j+50076+(T<<2)>>2])+(Fa*+g[j+51100+(P<<2)>>2]-Ca*+g[j+50076+(P<<2)>>2]);Ka=r*Ma+(+g[j+51100+(U<<2)>>2]*Ja- +g[j+50076+(U<<2)>>2]*Ga)+(+g[j+51100+(S<<2)>>2]*Fa- +g[j+50076+(S<<2)>>2]*Ca);g[j+50076+(F<<2)>>2]=Ka;g[X>>2]=Ka;Ka=Ba;g[j+50076+(V<<2)>>2]=Ka;g[W>>2]=Ka;W=F+2|0;if((W|0)==256){c[m>>2]=c[C>>2];c[m+4>>2]=c[C+4>>2];c[m+8>>2]=c[C+8>>2];c[m+12>>2]=c[C+12>>2];c[s>>2]=c[Y>>2];c[s+4>>2]=c[Y+4>>2];c[s+8>>2]=c[Y+8>>2];c[s+12>>2]=c[Y+12>>2];Pa=4}else{Pa=W}if((B|0)==0){Oa=Pa;break}else{X=X+8|0;F=Pa;_=B}}}c[$>>2]=Oa;Oa=c[b>>2]|0;if((Oa|0)==0){Qa=1.0e-16}else{b=c[p>>2]|0;p=Oa;Ka=1.0e-16;while(1){$=p-1|0;Ba=+g[b>>2];Ca=+g[b+4>>2];Fa=Ka+(Ba*Ba+Ca*Ca);if(($|0)==0){Qa=Fa;break}else{b=b+8|0;p=$;Ka=Fa}}}p=~~+Q((+fd(+(Qa/+(Oa|0)))*10.0+90.0+-3.0)*100.0);if((p|0)<0){Ra=0}else{Ra=(p|0)>11999?11999:p}p=l+(Ra<<2)|0;c[p>>2]=(c[p>>2]|0)+1;VHb(f);o=lj(k,c[e>>2]|0)|0;i=d;return o|0}function lz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[(c[a+8>>2]|0)+44>>2]|0;e=a+48|0;f=0;while(1){if(!(f>>>0<20>>>0)){g=4;break}if((c[1204424+(f*232|0)>>2]|0)==(c[e>>2]|0)){g=5;break}else{f=f+1|0}}if((g|0)==4){KIb(0,0,2226888,(h=i,i=i+24|0,c[h>>2]=2189680,c[h+8>>2]=2159376,c[h+16>>2]=351,h)|0);i=h;Hd();return 0}else if((g|0)==5){c[d+48012>>2]=1204520+(f*232|0);c[d+48016>>2]=1204432+(f*232|0);c[d+48020>>2]=1204632+(f*232|0);c[d+48024>>2]=1204608+(f*232|0);c[d+48004>>2]=20;c[d+48008>>2]=4;d=(c[e>>2]|0)/20|0;c[a+136>>2]=d;c[a+132>>2]=d;c[a+128>>2]=d;i=b;return 0}return 0}function mz(a){a=a|0;var b=0,c=0,d=0;b=Vk()|0;do{if((b|0)==0){c=-12}else{bl(a,b);d=Ok(683976)|0;if((d|0)==0){c=-12;break}dl(a,d);d=Uk()|0;if((d|0)==0){c=-12;break}cl(a,d);c=0}}while(0);return c|0}function nz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0.0,k=0,l=0,m=0,n=0,o=0;d=a+8|0;e=c[(c[d>>2]|0)+44>>2]|0;f=c[a+148>>2]|0;g=c[a+48>>2]|0;i=ca(c[b+76>>2]|0,f)|0;j=+(f|0)*+(g|0)*+h[e+16>>3];f=(F=+j,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);k=e+40|0;l=c[k>>2]|0;if(!((l|0)==0|(l|0)==(g|0))){m=e+24|0;n=Erc(c[m>>2]|0,c[m+4>>2]|0,g,(g|0)<0|0?-1:0)|0;o=Crc(n,G,l,(l|0)<0|0?-1:0)|0;c[m>>2]=o;c[m+4>>2]=G}c[k>>2]=g;_e[c[e+44>>2]&511](e,b,i,~~+j>>>0,f,a+56|0);return lj(c[c[(c[d>>2]|0)+32>>2]>>2]|0,b)|0}function oz(a){a=a|0;var b=0,d=0;b=c[(c[a+8>>2]|0)+44>>2]|0;d=c[a+52>>2]|0;if((d|0)==3){c[b+44>>2]=62;return 0}else if((d|0)==4){c[b+44>>2]=352;return 0}else if((d|0)==1){a=b+8|0;h[a>>3]=+h[a>>3]*32767.0;c[b+44>>2]=230;return 0}else if((d|0)==2){d=b+8|0;h[d>>3]=+h[d>>3]*2147483647.0;c[b+44>>2]=248;return 0}else{return 0}return 0}function pz(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0.0,L=0;k=i;i=i+96|0;l=j;j=i;i=i+8|0;c[j>>2]=c[l>>2];c[j+4>>2]=c[l+4>>2];m=+h[b+8>>3];if((e|0)<=0){i=k;return}n=-0.0-m;l=j|0;o=j+4|0;j=k|0;p=k+32|0;q=k+64|0;r=b+32|0;s=d+440|0;t=d+136|0;u=b;v=b+24|0;w=v;x=b+16|0;b=c[d>>2]|0;d=0;while(1){y=+h[b>>3];if(y<m){z=y<=n}else{z=1}A=c[l>>2]|0;B=c[o>>2]|0;C=(c[r>>2]|0)!=0|(c[r+4>>2]|0)!=0;do{if(z){if(C){mrc(p|0,0,32)|0;a[p]=0;D=c[t>>2]|0;E=c[t+4>>2]|0;if((D|0)==0&(E|0)==(-2147483648|0)){Rb(p|0,32,2541192,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Rb(p|0,32,2524144,(H=i,i=i+8|0,h[H>>3]=(+(D>>>0)+ +(E|0)*4294967296.0)*(+(A|0)/+(B|0)),H)|0)|0;i=H}MGb(s,2603320,p,0)|0;mrc(q|0,0,32)|0;a[q]=0;E=xrc(c[t>>2]|0,c[t+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0)|0;D=G;if((E|0)==0&(D|0)==(-2147483648|0)){Rb(q|0,32,2541192,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Rb(q|0,32,2524144,(H=i,i=i+8|0,h[H>>3]=(+(E>>>0)+ +(D|0)*4294967296.0)*(+(A|0)/+(B|0)),H)|0)|0;i=H}MGb(s,2577688,q,0)|0;D=LGb(c[s>>2]|0,2603320,0,0)|0;if((D|0)==0){I=0}else{I=c[D+4>>2]|0}D=LGb(c[s>>2]|0,2577688,0,0)|0;if((D|0)==0){J=0}else{J=c[D+4>>2]|0}KIb(u,32,2558504,(H=i,i=i+16|0,c[H>>2]=I,c[H+8>>2]=J,H)|0);i=H}mrc(w|0,0,16)|0}else{if(C){break}D=wrc(c[v>>2]|0,c[v+4>>2]|0,1,0)|0;E=G;c[v>>2]=D;c[v+4>>2]=E;if((E|0)<(g|0)|(E|0)==(g|0)&D>>>0<f>>>0){break}y=+(A|0)/+(B|0);K=+h[x>>3]/y+.5;D=xrc(c[t>>2]|0,c[t+4>>2]|0,~~+K>>>0,(F=+K,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0))|0;E=G;c[r>>2]=D;c[r+4>>2]=E;mrc(j|0,0,32)|0;a[j]=0;if((D|0)==0&(E|0)==(-2147483648|0)){Rb(j|0,32,2541192,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Rb(j|0,32,2524144,(H=i,i=i+8|0,h[H>>3]=y*(+(D>>>0)+ +(E|0)*4294967296.0),H)|0)|0;i=H}MGb(s,2110528,j,0)|0;E=LGb(c[s>>2]|0,2110528,0,0)|0;if((E|0)==0){L=0}else{L=c[E+4>>2]|0}KIb(u,32,2628216,(H=i,i=i+8|0,c[H>>2]=L,H)|0);i=H}}while(0);B=d+1|0;if((B|0)<(e|0)){b=b+8|0;d=B}else{break}}i=k;return}function qz(b,d,e,f,j,k){b=b|0;d=d|0;e=e|0;f=f|0;j=j|0;k=k|0;var l=0,m=0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0.0,M=0;l=i;i=i+96|0;m=k;k=i;i=i+8|0;c[k>>2]=c[m>>2];c[k+4>>2]=c[m+4>>2];n=+h[b+8>>3];if((e|0)<=0){i=l;return}o=-0.0-n;m=k|0;p=k+4|0;k=l|0;q=l+32|0;r=l+64|0;s=b+32|0;t=d+440|0;u=d+136|0;v=b;w=b+24|0;x=w;y=b+16|0;b=c[d>>2]|0;d=0;while(1){z=+g[b>>2];if(z<n){A=z<=o}else{A=1}B=c[m>>2]|0;C=c[p>>2]|0;D=(c[s>>2]|0)!=0|(c[s+4>>2]|0)!=0;do{if(A){if(D){mrc(q|0,0,32)|0;a[q]=0;E=c[u>>2]|0;H=c[u+4>>2]|0;if((E|0)==0&(H|0)==(-2147483648|0)){Rb(q|0,32,2541192,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Rb(q|0,32,2524144,(I=i,i=i+8|0,h[I>>3]=(+(E>>>0)+ +(H|0)*4294967296.0)*(+(B|0)/+(C|0)),I)|0)|0;i=I}MGb(t,2603320,q,0)|0;mrc(r|0,0,32)|0;a[r]=0;H=xrc(c[u>>2]|0,c[u+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;E=G;if((H|0)==0&(E|0)==(-2147483648|0)){Rb(r|0,32,2541192,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Rb(r|0,32,2524144,(I=i,i=i+8|0,h[I>>3]=(+(H>>>0)+ +(E|0)*4294967296.0)*(+(B|0)/+(C|0)),I)|0)|0;i=I}MGb(t,2577688,r,0)|0;E=LGb(c[t>>2]|0,2603320,0,0)|0;if((E|0)==0){J=0}else{J=c[E+4>>2]|0}E=LGb(c[t>>2]|0,2577688,0,0)|0;if((E|0)==0){K=0}else{K=c[E+4>>2]|0}KIb(v,32,2558504,(I=i,i=i+16|0,c[I>>2]=J,c[I+8>>2]=K,I)|0);i=I}mrc(x|0,0,16)|0}else{if(D){break}E=wrc(c[w>>2]|0,c[w+4>>2]|0,1,0)|0;H=G;c[w>>2]=E;c[w+4>>2]=H;if((H|0)<(j|0)|(H|0)==(j|0)&E>>>0<f>>>0){break}z=+(B|0)/+(C|0);L=+h[y>>3]/z+.5;E=xrc(c[u>>2]|0,c[u+4>>2]|0,~~+L>>>0,(F=+L,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0))|0;H=G;c[s>>2]=E;c[s+4>>2]=H;mrc(k|0,0,32)|0;a[k]=0;if((E|0)==0&(H|0)==(-2147483648|0)){Rb(k|0,32,2541192,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}else{Rb(k|0,32,2524144,(I=i,i=i+8|0,h[I>>3]=z*(+(E>>>0)+ +(H|0)*4294967296.0),I)|0)|0;i=I}MGb(t,2110528,k,0)|0;H=LGb(c[t>>2]|0,2110528,0,0)|0;if((H|0)==0){M=0}else{M=c[H+4>>2]|0}KIb(v,32,2628216,(I=i,i=i+8|0,c[I>>2]=M,I)|0);i=I}}while(0);C=d+1|0;if((C|0)<(e|0)){b=b+4|0;d=C}else{break}}i=l;return}function rz(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0.0,K=0.0,L=0;k=i;i=i+96|0;l=j;j=i;i=i+8|0;c[j>>2]=c[l>>2];c[j+4>>2]=c[l+4>>2];l=~~+h[b+8>>3];if((e|0)<=0){i=k;return}m=-l|0;n=j|0;o=j+4|0;j=k|0;p=k+32|0;q=k+64|0;r=b+32|0;s=d+440|0;t=d+136|0;u=b;v=b+24|0;w=v;x=b+16|0;b=c[d>>2]|0;d=0;while(1){y=c[b>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;B=(c[r>>2]|0)!=0|(c[r+4>>2]|0)!=0;do{if((y|0)<=(m|0)|(y|0)>=(l|0)){if(B){mrc(p|0,0,32)|0;a[p]=0;C=c[t>>2]|0;D=c[t+4>>2]|0;if((C|0)==0&(D|0)==(-2147483648|0)){Rb(p|0,32,2541192,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0)|0;i=E}else{Rb(p|0,32,2524144,(E=i,i=i+8|0,h[E>>3]=(+(C>>>0)+ +(D|0)*4294967296.0)*(+(z|0)/+(A|0)),E)|0)|0;i=E}MGb(s,2603320,p,0)|0;mrc(q|0,0,32)|0;a[q]=0;D=xrc(c[t>>2]|0,c[t+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0)|0;C=G;if((D|0)==0&(C|0)==(-2147483648|0)){Rb(q|0,32,2541192,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0)|0;i=E}else{Rb(q|0,32,2524144,(E=i,i=i+8|0,h[E>>3]=(+(D>>>0)+ +(C|0)*4294967296.0)*(+(z|0)/+(A|0)),E)|0)|0;i=E}MGb(s,2577688,q,0)|0;C=LGb(c[s>>2]|0,2603320,0,0)|0;if((C|0)==0){H=0}else{H=c[C+4>>2]|0}C=LGb(c[s>>2]|0,2577688,0,0)|0;if((C|0)==0){I=0}else{I=c[C+4>>2]|0}KIb(u,32,2558504,(E=i,i=i+16|0,c[E>>2]=H,c[E+8>>2]=I,E)|0);i=E}mrc(w|0,0,16)|0}else{if(B){break}C=wrc(c[v>>2]|0,c[v+4>>2]|0,1,0)|0;D=G;c[v>>2]=C;c[v+4>>2]=D;if((D|0)<(g|0)|(D|0)==(g|0)&C>>>0<f>>>0){break}J=+(z|0)/+(A|0);K=+h[x>>3]/J+.5;C=xrc(c[t>>2]|0,c[t+4>>2]|0,~~+K>>>0,(F=+K,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0))|0;D=G;c[r>>2]=C;c[r+4>>2]=D;mrc(j|0,0,32)|0;a[j]=0;if((C|0)==0&(D|0)==(-2147483648|0)){Rb(j|0,32,2541192,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0)|0;i=E}else{Rb(j|0,32,2524144,(E=i,i=i+8|0,h[E>>3]=J*(+(C>>>0)+ +(D|0)*4294967296.0),E)|0)|0;i=E}MGb(s,2110528,j,0)|0;D=LGb(c[s>>2]|0,2110528,0,0)|0;if((D|0)==0){L=0}else{L=c[D+4>>2]|0}KIb(u,32,2628216,(E=i,i=i+8|0,c[E>>2]=L,E)|0);i=E}}while(0);A=d+1|0;if((A|0)<(e|0)){b=b+4|0;d=A}else{break}}i=k;return}function sz(d,e,f,g,j,k){d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0;l=i;i=i+96|0;m=k;k=i;i=i+8|0;c[k>>2]=c[m>>2];c[k+4>>2]=c[m+4>>2];m=~~+h[d+8>>3];if((f|0)<=0){i=l;return}n=-(m<<16>>16)|0;o=k|0;p=k+4|0;k=l|0;q=l+32|0;r=l+64|0;s=d+32|0;t=e+440|0;u=e+136|0;v=d;w=d+24|0;x=w;y=d+16|0;d=c[e>>2]|0;e=0;while(1){z=b[d>>1]|0;if(z<<16>>16<m<<16>>16){A=(z<<16>>16|0)<=(n|0)}else{A=1}z=c[o>>2]|0;B=c[p>>2]|0;C=(c[s>>2]|0)!=0|(c[s+4>>2]|0)!=0;do{if(A){if(C){mrc(q|0,0,32)|0;a[q]=0;D=c[u>>2]|0;E=c[u+4>>2]|0;if((D|0)==0&(E|0)==(-2147483648|0)){Rb(q|0,32,2541192,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Rb(q|0,32,2524144,(H=i,i=i+8|0,h[H>>3]=(+(D>>>0)+ +(E|0)*4294967296.0)*(+(z|0)/+(B|0)),H)|0)|0;i=H}MGb(t,2603320,q,0)|0;mrc(r|0,0,32)|0;a[r]=0;E=xrc(c[u>>2]|0,c[u+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;D=G;if((E|0)==0&(D|0)==(-2147483648|0)){Rb(r|0,32,2541192,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Rb(r|0,32,2524144,(H=i,i=i+8|0,h[H>>3]=(+(E>>>0)+ +(D|0)*4294967296.0)*(+(z|0)/+(B|0)),H)|0)|0;i=H}MGb(t,2577688,r,0)|0;D=LGb(c[t>>2]|0,2603320,0,0)|0;if((D|0)==0){I=0}else{I=c[D+4>>2]|0}D=LGb(c[t>>2]|0,2577688,0,0)|0;if((D|0)==0){J=0}else{J=c[D+4>>2]|0}KIb(v,32,2558504,(H=i,i=i+16|0,c[H>>2]=I,c[H+8>>2]=J,H)|0);i=H}mrc(x|0,0,16)|0}else{if(C){break}D=wrc(c[w>>2]|0,c[w+4>>2]|0,1,0)|0;E=G;c[w>>2]=D;c[w+4>>2]=E;if((E|0)<(j|0)|(E|0)==(j|0)&D>>>0<g>>>0){break}K=+(z|0)/+(B|0);L=+h[y>>3]/K+.5;D=xrc(c[u>>2]|0,c[u+4>>2]|0,~~+L>>>0,(F=+L,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0))|0;E=G;c[s>>2]=D;c[s+4>>2]=E;mrc(k|0,0,32)|0;a[k]=0;if((D|0)==0&(E|0)==(-2147483648|0)){Rb(k|0,32,2541192,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0)|0;i=H}else{Rb(k|0,32,2524144,(H=i,i=i+8|0,h[H>>3]=K*(+(D>>>0)+ +(E|0)*4294967296.0),H)|0)|0;i=H}MGb(t,2110528,k,0)|0;E=LGb(c[t>>2]|0,2110528,0,0)|0;if((E|0)==0){M=0}else{M=c[E+4>>2]|0}KIb(v,32,2628216,(H=i,i=i+8|0,c[H>>2]=M,H)|0);i=H}}while(0);B=e+1|0;if((B|0)<(f|0)){d=d+2|0;e=B}else{break}}i=l;return}function tz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+44>>2]|0;e=d+52|0;f=c[d+48>>2]|0;d=a;a=c[e>>2]|0;g=UGb(e,f,281104,0,0,0,0,0,d)|0;if((g|0)<0){KIb(d,16,2628160,(d=i,i=i+8|0,c[d>>2]=f,d)|0);i=d;c[e>>2]=a;h=g;i=b;return h|0}else{TGb(a);h=0;i=b;return h|0}return 0}function uz(a){a=a|0;var b=0;b=c[a+44>>2]|0;TGb(c[b+52>>2]|0);WJb(b);return}function vz(a){a=a|0;var b=0,d=0,e=0;b=c[a+44>>2]|0;d=Wk()|0;if((d|0)==0){e=-12;return e|0}bl(a,d);d=Ok(683888+((c[b+40>>2]|0)*28|0)|0)|0;if((d|0)==0){e=-12;return e|0}dl(a,d);d=Uk()|0;if((d|0)==0){e=-12;return e|0}cl(a,d);e=0;return e|0}function wz(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;f=c[a+44>>2]|0;if((irc(b,2233912)|0)!=0){h=-38;i=g;return h|0}b=f+52|0;e=a;j=c[b>>2]|0;k=UGb(b,d,281104,0,0,0,0,0,e)|0;if((k|0)<0){KIb(e,16,2628160,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;c[b>>2]=j;h=k;i=g;return h|0}TGb(j);if((c[f+44>>2]|0)!=0){h=0;i=g;return h|0}xz(a)|0;h=0;i=g;return h|0}function xz(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0,j=0,l=0,m=0,n=0,o=0.0,p=0,q=0;b=i;d=c[a+44>>2]|0;e=d+56|0;f=+XGb(c[d+52>>2]|0,e,0);g=d+152|0;h[g>>3]=f;h[k>>3]=f;j=c[k+4>>2]&2147483647;l=2146435072;do{if(j>>>0>l>>>0|j>>>0==l>>>0&(c[k>>2]|0)>>>0>0>>>0){m=a;if((c[d+44>>2]|0)!=0){KIb(m,24,2331848,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h[g>>3]=0.0;o=0.0;p=m;break}KIb(m,16,2408e3,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=-22;i=b;return q|0}else{o=f;p=a}}while(0);h[d+144>>3]=o;o=+h[d+128>>3];f=+h[d+96>>3];a=d+40|0;l=c[700168+(c[a>>2]<<2)>>2]|0;KIb(p,40,2275552,(n=i,i=i+32|0,h[n>>3]=+h[e>>3],h[n+8>>3]=o,h[n+16>>3]=f,c[n+24>>2]=l,n)|0);i=n;if((c[a>>2]|0)==0){a=~~(+h[g>>3]*256.0+.5);c[d+160>>2]=a;h[g>>3]=+(a|0)*.00390625;KIb(p,40,2226768,(n=i,i=i+8|0,c[n>>2]=a,n)|0);i=n}f=+h[g>>3];o=+aa(f)*20.0/2.302585092994046;KIb(p,40,2189600,(n=i,i=i+16|0,h[n>>3]=f,h[n+8>>3]=o,n)|0);i=n;n=d+180|0;c[n>>2]=1;switch(NKb(c[d+172>>2]|0)|0){case 4:{qHb(d+4|0,0);c[n>>2]=8;q=0;i=b;return q|0};case 0:{p=d+176|0;if((c[d+160>>2]|0)<16777216){c[p>>2]=880;q=0;i=b;return q|0}else{c[p>>2]=240;q=0;i=b;return q|0}break};case 1:{p=d+176|0;if((c[d+160>>2]|0)<65536){c[p>>2]=126;q=0;i=b;return q|0}else{c[p>>2]=92;q=0;i=b;return q|0}break};case 3:{qHb(d+4|0,0);c[n>>2]=4;q=0;i=b;return q|0};case 2:{c[d+176>>2]=48;q=0;i=b;return q|0};default:{q=0;i=b;return q|0}}return 0}function yz(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)>0){g=0}else{return}do{h=(ca((d[c+g|0]|0)-128|0,f)|0)+128>>8;i=h+128|0;if(i>>>0>255>>>0){j=-128-h>>31&255}else{j=i&255}a[b+g|0]=j;g=g+1|0;}while((g|0)<(e|0));return}function zz(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e|0)<=0){return}g=f;h=(f|0)<0|0?-1:0;f=0;do{i=wrc(d[c+f|0]|0,0,-128,-1)|0;j=Erc(i,G,g,h)|0;i=wrc(j,G,128,0)|0;j=G;k=wrc(i>>>8|j<<24,j>>>8|0<<24,128,0)|0;j=k;if(j>>>0>255>>>0){l=-j>>31&255}else{l=k&255}a[b+f|0]=l;f=f+1|0;}while((f|0)<(e|0));return}function Az(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=a;a=c;if((d|0)>0){g=0}else{return}do{c=(ca(b[a+(g<<1)>>1]|0,e)|0)+128|0;h=c>>8;if((h+32768|0)>>>0>65535>>>0){i=(c>>31^32767)&65535}else{i=h&65535}b[f+(g<<1)>>1]=i;g=g+1|0;}while((g|0)<(d|0));return}function Bz(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a;a=c;if((d|0)<=0){return}c=e;g=(e|0)<0|0?-1:0;e=0;do{h=b[a+(e<<1)>>1]|0;i=Erc(h<<16>>16,h<<16>>16<0|0?-1:0,c,g)|0;h=wrc(i,G,128,0)|0;i=h>>>8|G<<24;h=i;if((h+32768|0)>>>0>65535>>>0){j=(h>>31^32767)&65535}else{j=i&65535}b[f+(e<<1)>>1]=j;e=e+1|0;}while((e|0)<(d|0));return}function Cz(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;a=b;if((d|0)<=0){return}b=e;g=(e|0)<0|0?-1:0;e=0;do{h=c[a+(e<<2)>>2]|0;i=Erc(h,(h|0)<0|0?-1:0,b,g)|0;h=wrc(i,G,128,0)|0;i=G;j=h>>>8|i<<24;h=wrc(j,i>>8|((i|0)<0|0?-1:0)<<24,-2147483648,0)|0;k=G;l=0;if(k>>>0>l>>>0|k>>>0==l>>>0&h>>>0>-1>>>0){((i|0)<0|0?-1:0)>>31|((i|0)<0|0?-1:0)<<1;m=(i>>31|((i|0)<0|0?-1:0)<<1)^2147483647}else{m=j}c[f+(e<<2)>>2]=m;e=e+1|0;}while((e|0)<(d|0));return}function Dz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0.0,m=0.0,n=0.0;b=i;d=c[a>>2]|0;a=c[d+44>>2]|0;e=c[c[d+16>>2]>>2]|0;f=e+52|0;c[a+172>>2]=c[f>>2];g=e+148|0;j=a+164|0;c[j>>2]=c[g>>2];if((RKb(c[f>>2]|0)|0)==0){k=1}else{k=c[j>>2]|0}c[a+168>>2]=k;h[a+144>>3]=+r;h[a+128>>3]=+r;h[a+120>>3]=+r;h[a+112>>3]=+r;h[a+96>>3]=+r;h[a+88>>3]=+r;h[a+80>>3]=+r;h[a+72>>3]=+r;h[a+56>>3]=+r;l=+(c[g>>2]|0);h[a+64>>3]=l;m=+(c[e+56>>2]|0)/+(c[e+60>>2]|0);h[a+136>>3]=m;n=+(c[e+48>>2]|0);h[a+104>>3]=n;KIb(c[e>>2]|0,40,2325312,(e=i,i=i+24|0,h[e>>3]=m,h[e+8>>3]=n,h[e+16>>3]=l,e)|0);i=e;e=xz(d)|0;i=b;return e|0}function Ez(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0,A=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=b;g=c[a+8>>2]|0;j=c[g+44>>2]|0;k=c[c[g+32>>2]>>2]|0;l=c[b+76>>2]|0;m=j+56|0;n=j+112|0;o=c[n+4>>2]&2147483647;p=2146435072;q=b+136|0;s=c[q>>2]|0;t=c[q+4>>2]|0;if(o>>>0>p>>>0|o>>>0==p>>>0&(c[n>>2]|0)>>>0>0>>>0){if((s|0)==0&(t|0)==(-2147483648|0)){h[n>>3]=+r;u=+r}else{h[n>>3]=+(s>>>0)+ +(t|0)*4294967296.0;u=(+(s>>>0)+ +(t|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}h[j+120>>3]=u}if((s|0)==0&(t|0)==(-2147483648|0)){h[j+96>>3]=+r;v=+r}else{h[j+96>>3]=+(s>>>0)+ +(t|0)*4294967296.0;v=(+(s>>>0)+ +(t|0)*4294967296.0)*(+(c[a+56>>2]|0)/+(c[a+60>>2]|0))}h[j+128>>3]=v;t=a+160|0;h[m>>3]=+((c[t>>2]|0)>>>0)+ +(c[t+4>>2]|0)*4294967296.0;t=DHb(b)|0;b=G;if((t|0)==(-1|0)&(b|0)==(-1|0)){w=+r}else{w=+(t>>>0)+ +(b|0)*4294967296.0}h[j+88>>3]=w;if((c[j+44>>2]|0)==1){xz(g)|0}g=j+152|0;do{if(+h[g>>3]==1.0){x=15}else{b=j+160|0;if((c[b>>2]|0)==256){x=15;break}t=c[e>>2]|0;do{if((bIb(t)|0)==0){m=oi(a,l)|0;c[f>>2]=m;if((m|0)==0){y=-12;i=d;return y|0}s=ZHb(m,c[e>>2]|0)|0;if((s|0)>=0){break}VHb(f);VHb(e);y=s;i=d;return y|0}else{c[f>>2]=t}}while(0);t=j+40|0;if((c[t>>2]|0)==0){if((c[b>>2]|0)>0){x=23}}else{x=23}a:do{if((x|0)==23){if((RKb(c[(c[e>>2]|0)+80>>2]|0)|0)==0){s=ca(c[j+164>>2]|0,l)|0;m=c[j+180>>2]|0;z=m-1+s&-m}else{m=c[j+180>>2]|0;z=l-1+m&-m}if((c[t>>2]|0)==0){m=j+168|0;if((c[m>>2]|0)<=0){break}s=j+176|0;n=0;while(1){mf[c[s>>2]&2047](c[(c[(c[f>>2]|0)+64>>2]|0)+(n<<2)>>2]|0,c[(c[(c[e>>2]|0)+64>>2]|0)+(n<<2)>>2]|0,z,c[b>>2]|0);n=n+1|0;if((n|0)>=(c[m>>2]|0)){break a}}}m=(NKb(c[j+172>>2]|0)|0)==3;n=j+168|0;s=(c[n>>2]|0)>0;if(m){if(!s){break}m=j+12|0;p=0;do{xe[c[m>>2]&7](c[(c[(c[f>>2]|0)+64>>2]|0)+(p<<2)>>2]|0,c[(c[(c[e>>2]|0)+64>>2]|0)+(p<<2)>>2]|0,+h[g>>3],z);p=p+1|0;}while((p|0)<(c[n>>2]|0))}else{if(!s){break}p=j+16|0;m=0;do{ye[c[p>>2]&3](c[(c[(c[f>>2]|0)+64>>2]|0)+(m<<2)>>2]|0,c[(c[(c[e>>2]|0)+64>>2]|0)+(m<<2)>>2]|0,+h[g>>3],z);m=m+1|0;}while((m|0)<(c[n>>2]|0))}}}while(0);b=c[e>>2]|0;if((b|0)==(c[f>>2]|0)){A=b;break}VHb(e);A=c[f>>2]|0}}while(0);if((x|0)==15){x=c[e>>2]|0;c[f>>2]=x;A=x}x=j+72|0;h[x>>3]=+h[x>>3]+ +(c[A+76>>2]|0);y=lj(k,A)|0;i=d;return y|0}function Fz(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;b=i;i=i+736|0;e=b|0;f=c[a+44>>2]|0;mrc(e|0,0,736)|0;g=f;f=0;j=0;k=0;do{l=g+(f<<3)|0;k=wrc(c[l>>2]|0,c[l+4>>2]|0,k,j)|0;j=G;f=f+1|0;}while((f|0)<65536);f=a;KIb(f,32,2407880,(a=i,i=i+16|0,c[a>>2]=k,c[a+8>>2]=j,a)|0);i=a;if((k|0)==0&(j|0)==0){i=b;return}l=j>>>1|0<<31;m=l>>>0>65535>>>0;n=m?j>>>17|0<<15:l;l=m?16:0;if((n&65280|0)==0){o=l;p=n}else{o=l|8;p=n>>>8}n=(d[1359664+p|0]|0)+o|0;o=0;p=0;l=0;m=0;q=0;do{r=g+(o<<3)|0;s=zrc(c[r>>2]|0,c[r+4>>2]|0,n|0)|0;r=G;q=wrc(s,r,q,m)|0;m=G;t=o-32768|0;u=Erc(ca(t,t)|0,0,s,r)|0;l=wrc(u,G,l,p)|0;p=G;o=o+1|0;}while((o|0)<65536);if((q|0)==0&(m|0)==0){i=b;return}o=wrc(l,p,q>>>1|m<<31,m>>>1|0<<31)|0;p=Frc(o,G,q,m)|0;m=G;q=0;if(!(m>>>0<q>>>0|m>>>0==q>>>0&p>>>0<1073741825>>>0)){KIb(0,0,2331736,(a=i,i=i+24|0,c[a>>2]=2275472,c[a+8>>2]=2226680,c[a+16>>2]=111,a)|0);i=a;Hd()}if((p|0)==0&(m|0)==0){v=91.0}else{v=+aa((+(p>>>0)+ +(m>>>0)*4294967296.0)*9.313225746154785e-10)*-4.342944819032518}KIb(f,32,2189480,(a=i,i=i+8|0,h[a>>3]=-0.0-v,a)|0);i=a;m=32768;while(1){if((m|0)<=0){break}p=g+(m+32768<<3)|0;if(!((c[p>>2]|0)==0&(c[p+4>>2]|0)==0)){break}p=g+(32768-m<<3)|0;if((c[p>>2]|0)==0&(c[p+4>>2]|0)==0){m=m-1|0}else{break}}p=ca(m,m)|0;if((p|0)==0){w=91.0}else{w=+aa(+(p>>>0>>>0)*9.313225746154785e-10)*-4.342944819032518}KIb(f,32,2159296,(a=i,i=i+8|0,h[a>>3]=-0.0-w,a)|0);i=a;p=0;while(1){m=g+(p<<3)|0;q=p-32768|0;o=ca(q,q)|0;if((o|0)==0){x=91}else{x=~~(+aa(+(o>>>0>>>0)*9.313225746154785e-10)*-4.342944819032518)}o=e+(x<<3)|0;q=wrc(c[o>>2]|0,c[o+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;c[o>>2]=q;c[o+4>>2]=G;o=p+1|0;if((o|0)<65536){p=o}else{y=0;break}}while(1){if((y|0)>=92){z=28;break}p=e+(y<<3)|0;A=c[p>>2]|0;B=c[p+4>>2]|0;if((A|0)==0&(B|0)==0){y=y+1|0}else{break}}if((z|0)==28){i=b;return}z=Frc(k,j,1e3,0)|0;p=G;x=0;if(j>>>0>x>>>0|j>>>0==x>>>0&k>>>0>999>>>0){C=y;D=0;E=0;F=B;H=A}else{i=b;return}while(1){KIb(f,32,2133960,(a=i,i=i+24|0,c[a>>2]=C,c[a+8>>2]=H,c[a+16>>2]=F,a)|0);i=a;A=wrc(H,F,E,D)|0;B=G;y=C+1|0;if(!((y|0)<92&(B>>>0<p>>>0|B>>>0==p>>>0&A>>>0<z>>>0))){break}k=e+(y<<3)|0;C=y;D=B;E=A;F=c[k+4>>2]|0;H=c[k>>2]|0}i=b;return}function Gz(a){a=a|0;var b=0,c=0;b=Ok(683872)|0;if((b|0)==0){c=-12;return c|0}dl(a,b);c=0;return c|0}function Hz(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=a+8|0;a=c[(c[e>>2]|0)+44>>2]|0;f=d+352|0;g=c[d+76>>2]|0;h=rGb(c[f>>2]|0,c[f+4>>2]|0)|0;if((RKb(c[d+80>>2]|0)|0)==0){i=1;j=ca(h,g)|0;k=4}else{if((h|0)>0){i=h;j=g;k=4}}do{if((k|0)==4){g=c[d+64>>2]|0;h=a;if((j|0)>0){l=0}else{break}do{f=c[g+(l<<2)>>2]|0;m=0;do{n=h+((b[f+(m<<1)>>1]|0)+32768<<3)|0;o=wrc(c[n>>2]|0,c[n+4>>2]|0,1,0)|0;c[n>>2]=o;c[n+4>>2]=G;m=m+1|0;}while((m|0)<(j|0));l=l+1|0;}while((l|0)<(i|0))}}while(0);return lj(c[c[(c[e>>2]|0)+32>>2]>>2]|0,d)|0}function Iz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;if((a|0)==0){e=-22;i=d;return e|0}if((b|0)==0){KIb(0,0,2525832,(f=i,i=i+24|0,c[f>>2]=2407824,c[f+8>>2]=2331656,c[f+16>>2]=93,f)|0);i=f;Hd();return 0}nrc(a|0,b+4|0,32)|0;nrc(a+32|0,b+40|0,32)|0;g=b+80|0;h=c[g+4>>2]|0;j=a+136|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;h=b+96|0;c[a+80>>2]=c[h>>2];j=b+88|0;EHb(a,c[j>>2]|0,c[j+4>>2]|0);j=c[b+104>>2]|0;if((j|0)==1){g=b+76|0;k=c[g>>2]|0;if((k|0)==0){KIb(0,0,2525832,(f=i,i=i+24|0,c[f>>2]=2226608,c[f+8>>2]=2331656,c[f+16>>2]=114,f)|0);i=f;Hd();return 0}l=k|0;k=rGb(c[l>>2]|0,c[l+4>>2]|0)|0;l=(RKb(c[h>>2]|0)|0)!=0;h=l?k:1;do{if(h>>>0>8>>>0){k=h<<2;l=pJb(k)|0;c[a+64>>2]=l;if((l|0)==0){e=-12;i=d;return e|0}else{nrc(l|0,c[b+36>>2]|0,k)|0;break}}else{c[a+64>>2]=a}}while(0);h=c[g>>2]|0;c[a+76>>2]=c[h+8>>2];IHb(a,c[h+12>>2]|0);h=c[g>>2]|0;FHb(a,c[h>>2]|0,c[h+4>>2]|0);HHb(a,c[(c[g>>2]|0)+16>>2]|0);e=0;i=d;return e|0}else if((j|0)==0){j=b+72|0;b=c[j>>2]|0;if((b|0)==0){KIb(0,0,2525832,(f=i,i=i+24|0,c[f>>2]=2275416,c[f+8>>2]=2331656,c[f+16>>2]=104,f)|0);i=f;Hd();return 0}c[a+68>>2]=c[b>>2];c[a+72>>2]=c[b+4>>2];f=b+8|0;b=a+124|0;g=c[f+4>>2]|0;c[b>>2]=c[f>>2];c[b+4>>2]=g;g=c[j>>2]|0;c[a+296>>2]=c[g+16>>2];c[a+300>>2]=c[g+20>>2];c[a+84>>2]=c[g+28>>2];c[a+88>>2]=c[g+24>>2];e=0;i=d;return e|0}else{e=-22;i=d;return e|0}return 0}function Jz(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:do{if((f|0)>0){i=0;while(1){j=0;while(1){if((j|0)>=(g|0)){break}if((d[b+((ca(j,e)|0)+i)|0]|0|0)>(h|0)){k=i;break a}else{j=j+1|0}}j=i+1|0;if((j|0)<(f|0)){i=j}else{k=j;break}}}else{k=0}}while(0);if((k|0)==(f|0)){l=0;return l|0}i=f-1|0;b:do{if((i|0)<(k|0)){m=i}else{j=i;while(1){n=0;while(1){if((n|0)>=(g|0)){break}if((d[b+((ca(n,e)|0)+j)|0]|0|0)>(h|0)){m=j;break b}else{n=n+1|0}}n=j-1|0;if((n|0)<(k|0)){m=n;break}else{j=n}}}}while(0);c:do{if((g|0)>0){i=0;j=b;while(1){n=0;while(1){if((n|0)>=(f|0)){break}if((d[j+n|0]|0|0)>(h|0)){o=i;break c}else{n=n+1|0}}n=i+1|0;if((n|0)<(g|0)){i=n;j=j+e|0}else{o=n;break}}}else{o=0}}while(0);j=g-1|0;d:do{if((j|0)<(o|0)){p=j}else{g=-e|0;i=j;n=b+(ca(j,e)|0)|0;while(1){q=0;while(1){if((q|0)>=(f|0)){break}if((d[n+q|0]|0|0)>(h|0)){p=i;break d}else{q=q+1|0}}q=i-1|0;if((q|0)<(o|0)){p=q;break}else{i=q;n=n+g|0}}}}while(0);c[a>>2]=k;c[a+8>>2]=o;c[a+4>>2]=m;c[a+12>>2]=p;l=1;return l|0}function Kz(b,c){b=b|0;c=c|0;var d=0;switch(c|0){case 68:case 67:case 293:case 294:case 30:case 298:case 3:{a[b+2|0]=0;a[b+1|0]=1;a[b]=2;a[b+3|0]=3;d=0;return d|0};case 295:case 27:{a[b+3|0]=0;a[b]=1;a[b+1|0]=2;a[b+2|0]=3;d=0;return d|0};case 42:case 41:case 291:case 292:case 296:case 28:case 2:{a[b]=0;a[b+1|0]=1;a[b+2|0]=2;a[b+3|0]=3;d=0;return d|0};case 317:case 82:{a[b+1|0]=0;a[b+2|0]=1;a[b]=2;a[b+3|0]=3;d=0;return d|0};case 297:case 29:{a[b+3|0]=0;a[b+2|0]=1;a[b+1|0]=2;a[b]=3;d=0;return d|0};default:{d=-22;return d|0}}return 0}function Lz(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+16|0;h=g|0;j=qKb(f)|0;k=h;mrc(k|0,0,16)|0;if((c[j>>2]|0)==0){l=-22;i=g;return l|0}if(!((a[j+7|0]&15)==0)){l=-38;i=g;return l|0}m=j+4|0;n=a[m]|0;a:do{if(n<<24>>24==0){o=0}else{p=0;q=0;while(1){r=b[j+8+(p<<1)>>1]|0;if(!((r&30720)==14336)){l=-38;s=14;break}t=r&3;u=h+(t<<2)|0;v=c[u>>2]|0;w=((r&65535)>>>2&7)+1|0;if(!((v|0)==0|(v|0)==(w|0))){l=-38;s=14;break}c[u>>2]=w;if(w>>>0>7>>>0){l=-38;s=14;break}w=t+1|0;t=q>>>0>w>>>0?q:w;w=p+1|0;if(w>>>0<(n&255)>>>0){p=w;q=t}else{o=t;break a}}if((s|0)==14){i=g;return l|0}}}while(0);s=j+5|0;do{if((a[s]|0)==0){n=j+6|0;if((a[n]|0)!=0&o>>>0<3>>>0){l=-38}else{x=n;break}i=g;return l|0}else{if(o>>>0<3>>>0){l=-38;i=g;return l|0}else{x=j+6|0;break}}}while(0);mrc(e|0,0,44)|0;c[e>>2]=j;c[e+4>>2]=f;c[e+8>>2]=o;o=e+12|0;c[o>>2]=c[k>>2];c[o+4>>2]=c[k+4>>2];c[o+8>>2]=c[k+8>>2];c[o+12>>2]=c[k+12>>2];k=a[s]|0;a[e+40|0]=k;a[e+34|0]=k;a[e+33|0]=k;k=a[x]|0;a[e+41|0]=k;a[e+38|0]=k;a[e+37|0]=k;k=0;while(1){x=b[j+8+(k<<1)>>1]|0;s=(x&3)+(e+28)|0;a[s]=1<<((x&65535)>>>5&7)-1|d[s];s=k+1|0;if(s>>>0<((d[m]|0)-1|1)>>>0){k=s}else{l=0;break}}i=g;return l|0}function Mz(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=e|0;if((h|0)!=(f|0)){j=f;k=e;y=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y}k=c[b>>2]|0;a:do{if(!((a[k+7|0]&32)==0)){switch(c[b+4>>2]|0){case 295:case 27:{l=1;m=2;n=3;o=0;break};case 68:case 67:case 293:case 294:case 30:case 298:case 3:{l=2;m=1;n=0;o=3;break};case 317:case 82:{l=2;m=0;n=1;o=3;break};case 42:case 41:case 291:case 292:case 296:case 28:case 2:{l=0;m=1;n=2;o=3;break};case 297:case 29:{l=3;m=2;n=1;o=0;break};default:{break a}}if((c[b+8>>2]|0)==1){j=e+4|0;a[j+l|0]=a[f]|0;a[j+m|0]=a[f+1|0]|0;a[j+n|0]=a[f+2|0]|0;a[j+o|0]=a[f+3|0]|0;i=g;return}else{a[e+4+(l<<2)|0]=a[f]|0;a[e+4+(m<<2)|0]=a[f+1|0]|0;a[e+4+(n<<2)|0]=a[f+2|0]|0;a[e+4+(o<<2)|0]=a[f+3|0]|0;i=g;return}}}while(0);if(((c[b+8>>2]|0)-3|0)>>>0<2>>>0){o=f+1|0;n=f+2|0;a[e+4|0]=(((d[f]|0)*263|0)+16896+((d[o]|0)*516|0)+((d[n]|0)*100|0)|0)>>>10;a[e+8|0]=((((d[f]|0)*-152|0)+511+((d[o]|0)*-298|0)+((d[n]|0)*450|0)|0)>>>10)+128;a[e+12|0]=((((d[f]|0)*450|0)+511+((d[o]|0)*-377|0)+((d[n]|0)*-73|0)|0)>>>10)+128;a[e+16|0]=a[f+3|0]|0;i=g;return}n=c[b+4>>2]|0;if((n|0)==8|(n|0)==66){a[e+4|0]=(((d[f]|0)*263|0)+16896+((d[f+1|0]|0)*516|0)+((d[f+2|0]|0)*100|0)|0)>>>10;a[e+8|0]=a[f+3|0]|0;i=g;return}else{KIb(0,24,2231400,(f=i,i=i+8|0,c[f>>2]=c[k>>2],f)|0);i=f;mrc(h|0,-128|0,20)|0;i=g;return}}function Nz(a,b,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;n=a+8|0;o=c[n>>2]|0;if((o|0)==0){return}p=-l|0;l=-m|0;m=0;q=o;while(1){o=d[a+36+m|0]|0;r=g+(m<<2)|0;s=d[a+32+m|0]|0;t=c[a+12+(m<<2)>>2]|0;u=e+(m<<2)|0;v=ca(p>>s,-t|0)|0;w=l>>o;x=-w|0;if((w|0)<0){w=ca(j>>s,t)|0;y=ca(k>>o,c[r>>2]|0)|0;z=(ca(c[u>>2]|0,i>>o)|0)+(ca(h>>s,t)|0)|0;t=0;s=(c[f+(m<<2)>>2]|0)+(w+y)|0;y=(c[b+(m<<2)>>2]|0)+z|0;while(1){nrc(y|0,s|0,v)|0;z=t+1|0;if((z|0)<(x|0)){t=z;s=s+(c[r>>2]|0)|0;y=y+(c[u>>2]|0)|0}else{break}}A=c[n>>2]|0}else{A=q}u=m+1|0;if(u>>>0<A>>>0){m=u;q=A}else{break}}return}function Oz(a,b,e,f,g,h,i,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=a+8|0;if((c[k>>2]|0)==0){return}l=-i|0;i=-j|0;j=0;while(1){m=c[e+(j<<2)>>2]|0;n=d[a+36+j|0]|0;o=f+(j<<2)|0;p=ca(h>>n,c[o>>2]|0)|0;q=d[a+32+j|0]|0;r=a+12+(j<<2)|0;s=c[r>>2]|0;t=(ca(g>>q,s)|0)+p|0;p=m+t|0;u=l>>q;q=-u|0;v=i>>n;n=-v|0;if((v|0)==0){w=11;break}if((u|0)<0){u=b+4+(j<<2)|0;v=0;x=p;y=s;while(1){nrc(x|0,u|0,y)|0;z=c[r>>2]|0;A=v+1|0;if((A|0)<(q|0)){v=A;x=x+z|0;y=z}else{B=z;break}}}else{B=s}y=ca(B,q)|0;if((n|0)>1){x=1;v=m+((c[o>>2]|0)+t)|0;while(1){nrc(v|0,p|0,y)|0;r=x+1|0;if((r|0)<(n|0)){x=r;v=v+(c[o>>2]|0)|0}else{break}}}o=j+1|0;if(o>>>0<(c[k>>2]|0)>>>0){j=o}else{w=11;break}}if((w|0)==11){return}}function Pz(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=a[(c|0)==0?b+40|0:b+41|0]|0;b=f&255;if(f<<24>>24==0){g=e;return g|0}if((d|0)>-1){if((d|0)==0){h=1<<b-1}else{h=(1<<b)-1|0}i=h+e|0}else{i=e}g=i>>b<<b;return g|0}function Qz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;a=i;i=i+1384|0;b=a|0;d=a+1336|0;e=0;f=0;while(1){if((Lz(d,e,0)|0)>-1){c[b+(f<<2)>>2]=e;g=f+1|0}else{g=f}h=e+1|0;if((h|0)<333){e=h;f=g}else{break}}c[b+(g<<2)>>2]=-1;g=Ok(b|0)|0;i=a;return g|0}function Rz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b|0;Wz(d,a,2);c[b+36>>2]=b;c[b+32>>2]=2448;e=a+16|0;a=(c[c[e>>2]>>2]|0)+56|0;f=b+196|0;g=c[a+4>>2]|0;c[f>>2]=c[a>>2];c[f+4>>2]=g;g=(c[(c[e>>2]|0)+4>>2]|0)+56|0;e=b+380|0;f=c[g+4>>2]|0;c[e>>2]=c[g>>2];c[e+4>>2]=f;c[b+236>>2]=2;c[b+188>>2]=0;f=b+192|0;c[f>>2]=2;e=b+420|0;c[e>>2]=1;c[b+372>>2]=1;g=b+376|0;c[g>>2]=2;if((c[b+428>>2]|0)!=0){c[g>>2]=0;c[f>>2]=0}if((c[b+432>>2]|0)!=0){h=Xz(d)|0;return h|0}c[g>>2]=1;c[e>>2]=0;h=Xz(d)|0;return h|0}function Sz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+4>>2]|0;g=f;h=c[a+36>>2]|0;c[d>>2]=0;c[e>>2]=0;a=h;j=aA(a,0,d,1)|0;do{if((j|0)<0){k=j}else{l=aA(a,1,e,0)|0;if((l|0)<0){k=l;break}l=c[d>>2]|0;if((l|0)==0){KIb(0,0,2230624,(m=i,i=i+24|0,c[m>>2]=2525424,c[m+8>>2]=2407600,c[m+16>>2]=34,m)|0);i=m;Hd();return 0}m=l+136|0;l=f+32|0;n=XIb(c[m>>2]|0,c[m+4>>2]|0,h+12|0,(c[c[l>>2]>>2]|0)+56|0)|0;m=c[d>>2]|0;o=m+136|0;c[o>>2]=n;c[o+4>>2]=G;o=c[e>>2]|0;do{if((o|0)==0){p=m}else{if((c[f+76>>2]|0)!=0){p=m;break}n=Ee[c[h+424>>2]&511](g,m,o)|0;c[d>>2]=n;p=n}}while(0);q=lj(c[c[l>>2]>>2]|0,p)|0;i=b;return q|0}}while(0);VHb(d);q=k;i=b;return q|0}function Tz(a,b,c){a=a|0;b=b|0;c=c|0;return cA(a|0,b,c)|0}function Uz(a,b){a=a|0;b=b|0;return dA(a|0,b)|0}function Vz(a){a=a|0;bA(a|0);return}function Wz(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=1209064;c[a+4>>2]=b;c[a+8>>2]=d;return}function Xz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;d=a+12|0;e=d|0;f=a+8|0;a:do{if((c[e>>2]|0)==0){g=c[f>>2]|0;do{if((g|0)==0){h=a}else{j=d;k=a+16|0;l=0;m=0;n=0;o=0;b:while(1){do{if((c[a+56+(l*184|0)+180>>2]|0)==0){p=m;q=n;r=o}else{if((n|0)==0){s=a+56+(l*184|0)+140|0;t=c[s>>2]|0;u=c[s+4>>2]|0;c[j>>2]=t;c[j+4>>2]=u;u=t;p=u;q=u;r=u;break}u=c[k>>2]|0;t=u;s=(u|0)<0|0?-1:0;u=c[a+56+(l*184|0)+144>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=TIb(t,s,v,w)|0;x=Crc(t,s,u,G)|0;u=Erc(x,G,v,w)|0;w=G;v=0;if(!((w|0)<(v|0)|(w|0)==(v|0)&u>>>0<5e5>>>0)){y=9;break b}c[k>>2]=u;u=c[a+56+(l*184|0)+140>>2]|0;v=TIb(o,(o|0)<0|0?-1:0,u,(u|0)<0|0?-1:0)|0;u=v;c[e>>2]=u;p=u;q=u;r=u}}while(0);u=l+1|0;if(u>>>0<g>>>0){l=u;m=p;n=q;o=r}else{y=12;break}}if((y|0)==9){c[e>>2]=1;c[k>>2]=1e6;z=1;A=a}else if((y|0)==12){o=a;if((p|0)==0){h=o;break}else{z=p;A=o}}o=c[a+16>>2]|0;KIb(A,40,2525296,(B=i,i=i+16|0,c[B>>2]=z,c[B+8>>2]=o,B)|0);i=B;break a}}while(0);KIb(h,16,2230240,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-22;i=b;return C|0}}while(0);if((c[f>>2]|0)!=0){B=0;do{h=a+56+(B*184|0)+168|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=a+56+(B*184|0)+160|0;c[h>>2]=0;c[h+4>>2]=-2147483648;B=B+1|0;}while(B>>>0<(c[f>>2]|0)>>>0)}c[a+44>>2]=-1;Yz(a);C=0;i=b;return C|0}function Yz(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[b+8>>2]|0;do{if((e|0)==0){f=b+44|0;g=0;h=f;j=c[f>>2]|0}else{f=0;k=0;while(1){if((a[b+56+(f*184|0)+177|0]|0)==2){l=k}else{m=c[b+56+(f*184|0)+180>>2]|0;l=k>>>0>m>>>0?k:m}m=f+1|0;if(m>>>0<e>>>0){f=m;k=l}else{break}}k=b+44|0;f=c[k>>2]|0;if(!(l>>>0>f>>>0)){g=l;h=k;j=f;break}KIb(0,0,2407520,(n=i,i=i+24|0,c[n>>2]=2628104,c[n+8>>2]=2275352,c[n+16>>2]=63,n)|0);i=n;Hd()}}while(0);if(g>>>0<j>>>0){KIb(b,40,2603168,(n=i,i=i+8|0,c[n>>2]=g,n)|0);i=n}if((g|0)==0){a[b+49|0]=1;i=d;return}else{c[h>>2]=g;i=d;return}}function Zz(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;if((a[d+56+(f*184|0)+176|0]|0)==0){_z(d,f,g);i=h;return 0}j=d+56+(f*184|0)+130|0;k=b[j>>1]|0;if(k<<16>>16==32){KIb(d,24,2133920,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;l=d+56+(f*184|0)+128|0;m=e[l>>1]|0;n=(b[j>>1]|0)-1&65535;b[j>>1]=n;VHb(d+56+(f*184|0)+(((n&65535)+m&31)<<2)|0);o=b[j>>1]|0;p=l}else{o=k;p=d+56+(f*184|0)+128|0}k=e[p>>1]|0;b[j>>1]=o+1;c[d+56+(f*184|0)+((k+(o&65535)&31)<<2)>>2]=g;i=h;return 0}function _z(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=b+56+(d*184|0)+176|0;if((a[g]|0)!=0){KIb(0,0,2407520,(h=i,i=i+24|0,c[h>>2]=2110432,c[h+8>>2]=2275352,c[h+16>>2]=182,h)|0);i=h;Hd()}if((e|0)!=0){h=e+136|0;j=XIb(c[h>>2]|0,c[h+4>>2]|0,b+56+(d*184|0)+140|0,b+12|0)|0;k=G;c[h>>2]=j;c[h+4>>2]=k;l=k;m=j;n=b+56+(d*184|0)+152|0;c[n>>2]=e;o=b+56+(d*184|0)+168|0;p=o|0;c[p>>2]=m;q=o+4|0;c[q>>2]=l;a[g]=1;i=f;return}do{if((a[b+56+(d*184|0)+177|0]|0)==1){if((c[b+56+(d*184|0)+136>>2]|0)==2){r=2147483647;s=-1;break}j=b+56+(d*184|0)+160|0;k=wrc(c[j>>2]|0,c[j+4>>2]|0,1,0)|0;r=G;s=k}else{r=2147483647;s=-1}}while(0);c[b+56+(d*184|0)+180>>2]=0;Yz(b);l=r;m=s;n=b+56+(d*184|0)+152|0;c[n>>2]=e;o=b+56+(d*184|0)+168|0;p=o|0;c[p>>2]=m;q=o+4|0;c[q>>2]=l;a[g]=1;i=f;return}function $z(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;g=d+48|0;if((a[g]|0)!=0){KIb(0,0,2407520,(h=i,i=i+24|0,c[h>>2]=2331464,c[h+8>>2]=2275352,c[h+16>>2]=211,h)|0);i=h;Hd()}h=d+8|0;j=c[h>>2]|0;if((j|0)==0){k=0}else{l=0;m=j;while(1){do{if((a[d+56+(l*184|0)+176|0]|0)==0){j=d+56+(l*184|0)+130|0;n=b[j>>1]|0;if(n<<16>>16==0){o=m;break}p=d+56+(l*184|0)+128|0;q=d+56+(l*184|0)+(e[p>>1]<<2)|0;r=c[q>>2]|0;b[j>>1]=n-1;c[q>>2]=0;b[p>>1]=(b[p>>1]|0)+1&31;_z(d,l,r);o=c[h>>2]|0}else{o=m}}while(0);r=l+1|0;if(r>>>0<o>>>0){l=r;m=o}else{k=o;break}}}a[g]=0;o=d+49|0;if((a[o]|0)!=0){i=f;return}m=d+224|0;l=d+24|0;r=d+44|0;p=k;q=0;n=k;j=k;s=k;a:while(1){do{if((p|0)==0){k=c[m>>2]|0;t=c[m+4>>2]|0;u=t;v=k;w=0;x=n;y=j;z=t;A=k}else{k=-1;t=0;while(1){do{if((a[d+56+(t*184|0)+176|0]|0)==0){if((k|0)>=0){B=d+56+(t*184|0)+160|0;C=c[B+4>>2]|0;D=d+56+(k*184|0)+160|0;E=c[D+4>>2]|0;if(!((C|0)<(E|0)|(C|0)==(E|0)&(c[B>>2]|0)>>>0<(c[D>>2]|0)>>>0)){F=k;break}}F=t}else{F=k}}while(0);D=t+1|0;if(D>>>0<s>>>0){k=F;t=D}else{break}}if((F|0)>-1){G=18;break a}t=c[m>>2]|0;k=c[m+4>>2]|0;if(s>>>0>1>>>0){H=1;I=k;J=t}else{u=k;v=t;w=s;x=s;y=s;z=k;A=t;break}while(1){D=d+56+(H*184|0)+168|0;B=c[D>>2]|0;E=c[D+4>>2]|0;D=(E|0)<(I|0)|(E|0)==(I|0)&B>>>0<J>>>0;C=D?B:J;B=D?E:I;E=H+1|0;if(E>>>0<s>>>0){H=E;I=B;J=C}else{u=B;v=C;w=s;x=s;y=s;z=k;A=t;break}}}}while(0);if((v|0)==(-1|0)&(u|0)==2147483647){G=23;break}if((w|0)==0){K=0;L=q;M=x;N=y;O=s}else{t=0;k=z;C=A;while(1){B=d+56+(t*184|0)+168|0;do{if((C|0)==(v|0)&(k|0)==(u|0)){P=d+56+(t*184|0)+177|0;G=28}else{if((c[d+56+(t*184|0)+132>>2]|0)!=2){break}E=d+56+(t*184|0)+177|0;if((a[E]|0)==0){P=E;G=28}}}while(0);do{if((G|0)==28){G=0;E=d+56+(t*184|0)+148|0;VHb(E);D=d+56+(t*184|0)+152|0;Q=c[D>>2]|0;c[E>>2]=Q;E=c[B+4>>2]|0;R=d+56+(t*184|0)+160|0;c[R>>2]=c[B>>2];c[R+4>>2]=E;c[D>>2]=0;c[B>>2]=0;c[B+4>>2]=-2147483648;a[d+56+(t*184|0)+176|0]=0;D=(Q|0)!=0;a[P]=D?1:2;if(!((c[d+56+(t*184|0)+180>>2]|0)!=(c[r>>2]|0)|(Q|0)==0)){a[g]=1}if(D){break}if((c[d+56+(t*184|0)+136>>2]|0)!=0){break}a[o]=1}}while(0);B=t+1|0;S=c[h>>2]|0;if(!(B>>>0<S>>>0)){break}D=d+56+(B*184|0)+168|0;t=B;k=c[D+4>>2]|0;C=c[D>>2]|0}K=S;L=a[o]|0;M=S;N=S;O=S}do{if(L<<24>>24==0){C=a[g]|0;if(C<<24>>24==0){break}if((M|0)==0){G=40;break a}else{T=0;U=C}while(1){do{if((a[d+56+(T*184|0)+177|0]|0)==0){if((c[d+56+(T*184|0)+132>>2]|0)!=0){V=U;break}a[g]=0;V=0}else{V=U}}while(0);C=T+1|0;if(C>>>0<N>>>0){T=C;U=V}else{break}}c[l>>2]=v;c[l+4>>2]=u;if(V<<24>>24==0){p=N;q=L;n=N;j=N;s=O;continue a}else{G=47;break a}}else{a[g]=0}}while(0);c[l>>2]=v;c[l+4>>2]=u;p=K;q=L;n=M;j=N;s=O}if((G|0)==18){c[d+40>>2]=F;i=f;return}else if((G|0)==23){a[o]=1;i=f;return}else if((G|0)==40){c[l>>2]=v;c[l+4>>2]=u;i=f;return}else if((G|0)==47){i=f;return}}function aA(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+8|0;h=g|0;j=b+56+(d*184|0)+148|0;k=c[j>>2]|0;if((k|0)==0){c[e>>2]=0;l=0;i=g;return l|0}c[h>>2]=k;if((f|0)==0){m=k}else{if((a[b+56+(d*184|0)+176|0]|0)==0){n=2147483647;o=-1}else{f=b+56+(d*184|0)+168|0;n=c[f+4>>2]|0;o=c[f>>2]|0}f=c[b+8>>2]|0;a:do{if((f|0)==0){p=15}else{q=0;b:while(1){do{if((q|0)!=(d|0)){if((c[b+56+(q*184|0)+180>>2]|0)==0){break}if((a[b+56+(q*184|0)+176|0]|0)==0){break b}r=b+56+(q*184|0)+168|0;s=c[r+4>>2]|0;if((s|0)<(n|0)|(s|0)==(n|0)&(c[r>>2]|0)>>>0<o>>>0){break b}}}while(0);r=q+1|0;if(r>>>0<f>>>0){q=r}else{p=15;break a}}q=$Hb(k)|0;c[h>>2]=q;if((q|0)==0){l=-12;i=g;return l|0}r=cIb(q)|0;if((r|0)>=0){t=q;break}VHb(h);l=r;i=g;return l|0}}while(0);if((p|0)==15){c[j>>2]=0;t=k}a[b+48|0]=0;m=t}c[e>>2]=m;l=0;i=g;return l|0}function bA(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;f=d|0;g=a+8|0;if((c[g>>2]|0)==0){i=d;return}h=0;do{VHb(a+56+(h*184|0)+148|0);VHb(a+56+(h*184|0)+152|0);j=a+56+(h*184|0)+130|0;k=b[j>>1]|0;if(!(k<<16>>16==0)){l=a+56+(h*184|0)+128|0;m=k;do{k=a+56+(h*184|0)+((e[l>>1]|0)<<2)|0;n=c[k>>2]|0;b[j>>1]=m-1;c[k>>2]=0;b[l>>1]=(b[l>>1]|0)+1&31;c[f>>2]=n;VHb(f);m=b[j>>1]|0;}while(!(m<<16>>16==0))}h=h+1|0;}while(h>>>0<(c[g>>2]|0)>>>0);i=d;return}function cA(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=b+32|0;if((c[g>>2]|0)==0){KIb(0,0,2407520,(h=i,i=i+24|0,c[h>>2]=2226528,c[h+8>>2]=2275352,c[h+16>>2]=276,h)|0);i=h;Hd();return 0}j=b+49|0;k=b+48|0;$z(b);if((a[j]|0)==0){l=0}else{m=-541478725;i=f;return m|0}while(1){if((a[k]|0)==0){n=l;o=0;break}p=ve[c[g>>2]&4095](b)|0;if((p|0)<0){m=p;q=17;break}a[k]=0;p=l+1|0;$z(b);r=a[j]|0;if(r<<24>>24==0){l=p}else{n=p;o=r;break}}if((q|0)==17){i=f;return m|0}do{if((n|0)==0){if(o<<24>>24==0){break}else{m=-541478725}i=f;return m|0}else{if((n|0)<0){m=n}else{break}i=f;return m|0}}while(0);Zz(b,((c[d+12>>2]|0)-(c[(c[d+8>>2]|0)+12>>2]|0)|0)/60|0,e)|0;if((c[g>>2]|0)==0){KIb(0,0,2407520,(h=i,i=i+24|0,c[h>>2]=2226528,c[h+8>>2]=2275352,c[h+16>>2]=276,h)|0);i=h;Hd();return 0}$z(b);if((a[j]|0)!=0){s=-541478725;t=(s|0)<0;u=t?s:0;i=f;return u|0}if((a[k]|0)==0){s=0;t=(s|0)<0;u=t?s:0;i=f;return u|0}j=ve[c[g>>2]&4095](b)|0;if((j|0)<0){s=j;t=(s|0)<0;u=t?s:0;i=f;return u|0}a[k]=0;s=1;t=(s|0)<0;u=t?s:0;i=f;return u|0}function dA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=c[d>>2]|0;g=b+32|0;if((c[g>>2]|0)==0){KIb(0,0,2407520,(h=i,i=i+24|0,c[h>>2]=2226528,c[h+8>>2]=2275352,c[h+16>>2]=276,h)|0);i=h;Hd();return 0}j=b+49|0;k=b+48|0;$z(b);if((a[j]|0)!=0){l=-541478725;i=e;return l|0}if((a[k]|0)!=0){m=ve[c[g>>2]&4095](b)|0;if((m|0)<0){l=m;i=e;return l|0}a[k]=0;l=0;i=e;return l|0}m=d+156|0;c[m>>2]=c[m>>2]|1;m=c[b+40>>2]|0;d=Wi(c[(c[f+16>>2]|0)+(m<<2)>>2]|0)|0;if(!((d|0)==-541478725)){l=d;i=e;return l|0}Zz(b,m,0)|0;if((c[g>>2]|0)==0){KIb(0,0,2407520,(h=i,i=i+24|0,c[h>>2]=2226528,c[h+8>>2]=2275352,c[h+16>>2]=276,h)|0);i=h;Hd();return 0}$z(b);if((a[j]|0)!=0){l=-541478725;i=e;return l|0}if((a[k]|0)==0){l=0;i=e;return l|0}j=ve[c[g>>2]&4095](b)|0;if((j|0)<0){l=j;i=e;return l|0}a[k]=0;l=0;i=e;return l|0}function eA(a){a=a|0;return 2577616}function fA(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+104|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;c[k>>2]=0;J1(n);qB();o=oX(k,g,iH(2229560)|0,0)|0;if((o|0)<0){KIb(h,16,2524928,(p=i,i=i+8|0,c[p>>2]=g,p)|0);i=p;q=o;i=j;return q|0}o=c[(c[c[(c[k>>2]|0)+28>>2]>>2]|0)+8>>2]|0;r=c5a(c[o+48>>2]|0)|0;do{if((r|0)==0){KIb(h,16,2407376,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=-22}else{t=_4a(o,r,0)|0;if((t|0)<0){KIb(h,16,2331344,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=t;break}t=UHb()|0;c[l>>2]=t;if((t|0)==0){KIb(h,16,2275264,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=-12;break}t=uX(c[k>>2]|0,n)|0;if((t|0)<0){KIb(h,16,2226488,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=t;break}t=k5a(o,c[l>>2]|0,m,n)|0;if((t|0)<0|(c[m>>2]|0)==0){KIb(h,16,2189392,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=t;break}t=c[l>>2]|0;c[d>>2]=c[t+68>>2];u=c[t+72>>2]|0;c[e>>2]=u;v=c[t+80>>2]|0;c[f>>2]=v;t=sIb(a,b,c[d>>2]|0,u,v,16)|0;if((t|0)<0){s=t;break}t=c[l>>2]|0;vIb(a,b,t|0,t+32|0,c[f>>2]|0,c[d>>2]|0,c[e>>2]|0);s=0}}while(0);P1(n);r5a(o)|0;YX(k);mJb(l);if((s|0)>=0){q=s;i=j;return q|0}KIb(h,16,2159256,(p=i,i=i+8|0,c[p>>2]=g,p)|0);i=p;q=s;i=j;return q|0}function gA(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+1024|0;e=b|0;f=a+16|0;if((rIb(e|0,Tq(c[f>>2]|0)|0)|0)>-1){g=a|0;c[g>>2]=c[g>>2]|2048}g=a+12|0;h=a+20|0;j=ca(d[g]|0,c[h>>2]|0)|0;k=a+24|0;l=(ca(j,(c[k>>2]|0)+2|0)|0)/8|0;if((c[f>>2]|0)==959465033){j=hJb((ca(c[a+104>>2]|0,c[a+100>>2]|0)|0)+l|0)|0;c[a+44>>2]=j;m=j}else{j=hJb(l)|0;c[a+44>>2]=j;m=j}j=a|0;l=c[j>>2]|0;if((l&256|0)==0){c[a+60>>2]=(ca(d[g]|0,c[h>>2]|0)|0)/8|0;if((l&2048|0)==0){n=l;o=n|16384;c[j>>2]=o;i=b;return}g=hJb(1024)|0;c[a+48>>2]=g;nrc(g|0,e|0,1024)|0;n=c[j>>2]|0;o=n|16384;c[j>>2]=o;i=b;return}e=c[f>>2]|0;if((e-1358954548&-67108609|0)==0){p=2}else{p=(e-872415313&-16776964|0)==0?2:1}e=ca(c[h>>2]|0,p)|0;c[a+72>>2]=e;c[a+60>>2]=e;h=c[a+96>>2]|0;f=c[a+100>>2]|0;if((h|0)<=2){c[a+64>>2]=f;c[a+48>>2]=m+(ca(c[k>>2]|0,e)|0);n=l;o=n|16384;c[j>>2]=o;i=b;return}g=ca(f,p)|0;c[a+68>>2]=g;c[a+64>>2]=g;p=ca(c[k>>2]|0,e)|0;e=m+p|0;if((l&1024|0)==0){c[a+52>>2]=e;k=ca(c[a+104>>2]|0,g)|0;f=k+p|0;c[a+48>>2]=m+f;if((h|0)<=3){n=l;o=n|16384;c[j>>2]=o;i=b;return}c[a+56>>2]=m+(k+f);n=l;o=n|16384;c[j>>2]=o;i=b;return}else{c[a+48>>2]=e;e=ca(c[a+104>>2]|0,g)|0;g=e+p|0;c[a+52>>2]=m+g;if((h|0)<=3){n=l;o=n|16384;c[j>>2]=o;i=b;return}c[a+56>>2]=m+(e+g);n=l;o=n|16384;c[j>>2]=o;i=b;return}}function hA(a,b){a=a|0;b=b|0;var d=0,e=0;d=Pqc(124)|0;if((d|0)==0){e=0;return e|0}mrc(d|0,0,124)|0;c[d+36>>2]=a;c[d+20>>2]=a;c[d+40>>2]=b;c[d+24>>2]=b;e=d;return e|0}function iA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b|0;g=c[f>>2]&-1793;c[f>>2]=g;c[b+16>>2]=d;do{if(!((d|0)==1515343433|(d|0)==1515342164|(d|0)==1515342146|(d|0)==1297106259)){h=d&-65536;if((h|0)==499646464|(h|0)==499580928){break}h=b+96|0;c[h>>2]=1;j=d&-256;if((j|0)==1380401664){k=d&127;if(k>>>0<8>>>0&(d&128|0)==0){a[b+12|0]=k;i=e;return}else{a[b+12|0]=k+7&255&-8;i=e;return}}else if((j|0)==1111970304){j=d&127;if(j>>>0<8>>>0&(d&128|0)==0){a[b+12|0]=j}else{a[b+12|0]=j+7&255&-8}c[f>>2]=g|1024;i=e;return}else{c[h>>2]=3;if((d|0)==1195528728){a[b+12|0]=24;c[f>>2]=g|256;i=e;return}else if((d|0)==1195528746){a[b+12|0]=42;c[f>>2]=g|256;i=e;return}else if((d|0)==1195528740){a[b+12|0]=36;c[f>>2]=g|256;i=e;return}else{c[f>>2]=g|512;if((pB(d,0,0,0)|0)!=0){c[f>>2]=c[f>>2]|256;j=b+108|0;k=b+112|0;a[b+12|0]=pB(d,j,k,0)|0;c[b+100>>2]=c[b+20>>2]>>c[j>>2];c[b+104>>2]=c[b+24>>2]>>c[k>>2]}if((d|0)==842094169|(d|0)==961893977|(d|0)==1345598516|(d|0)==1345466932|(d|0)==1345401140|(d|0)==1345336372|(d|0)==1362375732|(d|0)==875836497|(d|0)==1412707380|(d|0)==875836500|(d|0)==1429484596|(d|0)==875836501|(d|0)==1379152948|(d|0)==875836498|(d|0)==1395930164|(d|0)==875836499|(d|0)==1362244148|(d|0)==875704913|(d|0)==1412575796|(d|0)==875704916|(d|0)==1429353012|(d|0)==875704917|(d|0)==1379021364|(d|0)==875704914|(d|0)==1395798580|(d|0)==875704915|(d|0)==1362113076|(d|0)==875704401|(d|0)==1412444724|(d|0)==875704404|(d|0)==1429221940|(d|0)==875704405|(d|0)==1378890292|(d|0)==875704402|(d|0)==1395667508|(d|0)==875704403){i=e;return}else if((d|0)==842094158){k=c[f>>2]|1024;c[f>>2]=k;l=k;m=28}else if((d|0)==825382478){l=c[f>>2]|0;m=28}else if((d|0)==808596553|(d|0)==1448433993){c[f>>2]=c[f>>2]|1024;i=e;return}else if((d|0)==1498831189){c[f>>2]=c[f>>2]|1024;m=26}else if((d|0)==540422489|(d|0)==1496397344){a[b+12|0]=16;m=23}else if((d|0)==808466521|(d|0)==538982489){m=23}else if((d|0)==844715353){m=26}else if((d|0)==1093677620|(d|0)==1093808692|(d|0)==1093940276|(d|0)==959465033){c[h>>2]=4;i=e;return}else if((d|0)==1496449032){c[h>>2]=2;i=e;return}else{Uq(13,2,2229224,(k=i,i=i+8|0,c[k>>2]=d,k)|0);i=k;a[b+12|0]=0;i=e;return}if((m|0)==23){c[f>>2]=c[f>>2]&-257;c[h>>2]=1;i=e;return}else if((m|0)==26){c[b+108>>2]=1;a[b+12|0]=16;c[h>>2]=1;i=e;return}else if((m|0)==28){c[f>>2]=l|256;a[b+12|0]=12;c[h>>2]=2;c[b+100>>2]=c[b+20>>2];c[b+104>>2]=c[b+24>>2]>>1;c[b+108>>2]=0;c[b+112>>2]=1;i=e;return}}}}}while(0);a[b+12|0]=0;i=e;return}function jA(a){a=a|0;var b=0;if((a|0)==0){return}b=a|0;do{if((c[b>>2]&16384|0)!=0){kJb(c[a+44>>2]|0);if((c[b>>2]&2048|0)==0){break}kJb(c[a+48>>2]|0)}}while(0);Qqc(a);return}function kA(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;c[a+8>>2]=344;c[a+12>>2]=652;c[a+20>>2]=8;c[a+32>>2]=500;e=Pqc(12)|0;c[a+300>>2]=e;mrc(e|0,0,12)|0;if((b|0)==0){i=d;return 1}Bd(b|0,2275256,(b=i,i=i+16|0,c[b>>2]=e+4,c[b+8>>2]=e+8,b)|0)|0;i=b;i=d;return 1}function lA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;do{if((b|0)==8){e=c[d>>2]|0;if((irc(e,2226472)|0)==0){c[d+4>>2]=c[(c[a+300>>2]|0)+4>>2];f=1;return f|0}if((irc(e,2189368)|0)!=0){break}c[d+4>>2]=c[(c[a+300>>2]|0)+8>>2];f=1;return f|0}else if((b|0)==6){e=c[d>>2]|0;if((irc(e,2226472)|0)==0){c[(c[a+300>>2]|0)+4>>2]=c[d+4>>2];f=1;return f|0}if((irc(e,2189368)|0)!=0){break}c[(c[a+300>>2]|0)+8>>2]=c[d+4>>2];f=1;return f|0}}while(0);f=ar(a,b,d)|0;return f|0}function mA(a,b){a=a|0;b=b|0;var c=0;if((b|0)==961893977|(b|0)==959465033|(b|0)==842094169|(b|0)==808596553|(b|0)==1448433993|(b|0)==1280330819|(b|0)==808466521|(b|0)==538982489|(b|0)==842094158|(b|0)==825382478|(b|0)==1345598516|(b|0)==1345466932|(b|0)==1345401140){c=Yq(a,b)|0}else{c=0}return c|0}function nA(b,e,f){b=b|0;e=e|0;f=+f;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=e+36|0;h=e+40|0;i=Zq(c[b+292>>2]|0,c[e+16>>2]|0,0,0,c[g>>2]|0,c[h>>2]|0)|0;j=e+60|0;k=i+60|0;c[k>>2]=c[j>>2];l=e+44|0;m=i+44|0;c[i+48>>2]=c[e+48>>2];c[i+52>>2]=c[e+52>>2];c[i+64>>2]=c[e+64>>2];c[i+68>>2]=c[e+68>>2];e=b+300|0;n=c[e>>2]|0;o=n|0;if((c[o>>2]|0)==0){c[o>>2]=Pqc(ca(c[h>>2]|0,c[j>>2]|0)|0)|0;p=c[e>>2]|0}else{p=n}do{if((c[p+4>>2]|0)==0){if((c[p+8>>2]|0)!=0){break}c[m>>2]=c[l>>2];q=_q(b,i,f)|0;return q|0}}while(0);n=c[p>>2]|0;c[m>>2]=n;m=c[k>>2]|0;k=c[j>>2]|0;j=c[g>>2]|0;g=c[h>>2]|0;h=c[e>>2]|0;e=(c[h+8>>2]<<16)+6553600|0;p=(e|0)/100|0;o=((((c[h+4>>2]|0)*511|0)+51100|0)/200|0)-128+((e|0)/-51200|0)|0;if((g|0)==0|(j|0)==0){q=_q(b,i,f)|0;return q|0}e=c[l>>2]|0;l=n;n=g;while(1){g=j;h=e;r=l;while(1){s=o+((ca(d[h]|0,p)|0)>>16)|0;if((s&768|0)==0){t=s&255}else{t=-s>>31&255}a[r]=t;s=g-1|0;if((s|0)==0){break}else{g=s;h=h+1|0;r=r+1|0}}r=n-1|0;if((r|0)==0){break}else{e=e+k|0;l=l+m|0;n=r}}q=_q(b,i,f)|0;return q|0}function oA(a){a=a|0;var b=0;b=a+300|0;Qqc(c[c[b>>2]>>2]|0);Qqc(c[b>>2]|0);return}function pA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0;d=i;i=i+64|0;e=d|0;c[a+8>>2]=450;c[a+12>>2]=654;c[a+20>>2]=16;c[a+32>>2]=458;f=Pqc(394208)|0;c[a+300>>2]=f;c[f+394192>>2]=0;c[f+394168>>2]=0;c[f+394180>>2]=0;c[f+131332>>2]=0;h[f+131336>>3]=1.0;h[f+131344>>3]=0.0;h[f+131352>>3]=1.0;c[f+131328>>2]=0;c[f+394196>>2]=0;c[f+394172>>2]=0;c[f+394184>>2]=0;c[f+262700>>2]=0;h[f+262704>>3]=1.0;h[f+262712>>3]=0.0;h[f+262720>>3]=1.0;c[f+262696>>2]=0;c[f+394200>>2]=0;c[f+394176>>2]=0;c[f+394188>>2]=0;c[f+394068>>2]=0;h[f+394072>>3]=1.0;h[f+394080>>3]=0.0;h[f+394088>>3]=1.0;c[f+394064>>2]=0;a=f+394104|0;h[a>>3]=1.0;g=f+394112|0;h[g>>3]=0.0;j=f+394120|0;h[j>>3]=1.0;k=f+394128|0;h[k>>3]=1.0;l=f+394136|0;h[l>>3]=1.0;m=f+394144|0;h[m>>3]=1.0;n=f+394152|0;h[n>>3]=1.0;o=f+394160|0;h[o>>3]=1.0;if((b|0)==0){i=d;return 1}p=e|0;h[p>>3]=1.0;q=e+8|0;h[q>>3]=1.0;r=e+16|0;h[r>>3]=0.0;s=e+24|0;h[s>>3]=1.0;t=e+32|0;h[t>>3]=1.0;u=e+40|0;h[u>>3]=1.0;v=e+48|0;h[v>>3]=1.0;w=e+56|0;h[w>>3]=1.0;Bd(b|0,2275216,(b=i,i=i+64|0,c[b>>2]=p,c[b+8>>2]=q,c[b+16>>2]=r,c[b+24>>2]=s,c[b+32>>2]=t,c[b+40>>2]=u,c[b+48>>2]=v,c[b+56>>2]=w,b)|0)|0;i=b;x=+h[t>>3];h[m>>3]=x;y=+h[u>>3];h[n>>3]=y;z=+h[v>>3];h[o>>3]=z;A=+h[w>>3];h[l>>3]=A;B=+h[p>>3];h[k>>3]=B;C=B*y;p=f+131352|0;h[p>>3]=C;D=+S(z/y);l=f+262720|0;h[l>>3]=D;z=+S(x/y);w=f+394088|0;h[w>>3]=z;h[f+394096>>3]=A;h[f+262728>>3]=A;h[f+131360>>3]=A;o=f+131328|0;c[o>>2]=0;v=f+262696|0;c[v>>2]=0;n=f+394064|0;c[n>>2]=0;u=f+131336|0;do{if(+h[u>>3]==1.0){if(!(+h[f+131344>>3]==0.0&C==1.0)){E=5;break}c[f+131332>>2]=0}else{E=5}}while(0);if((E|0)==5){c[f+131332>>2]=192}m=f+262704|0;do{if(+h[m>>3]==1.0){if(!(+h[f+262712>>3]==0.0&D==1.0)){E=9;break}c[f+262700>>2]=0}else{E=9}}while(0);if((E|0)==9){c[f+262700>>2]=192}t=f+394072|0;do{if(+h[t>>3]==1.0){if(!(+h[f+394080>>3]==0.0&z==1.0)){E=13;break}c[f+394068>>2]=0}else{E=13}}while(0);if((E|0)==13){c[f+394068>>2]=192}z=+h[g>>3];D=+h[j>>3];Uq(29,6,2226376,(b=i,i=i+32|0,h[b>>3]=+h[a>>3],h[b+8>>3]=z,h[b+16>>3]=B,h[b+24>>3]=D,b)|0);i=b;D=+h[q>>3];h[a>>3]=D;h[u>>3]=D;c[o>>2]=0;q=f+131344|0;do{if(D==1.0){if(!(+h[q>>3]==0.0)){E=18;break}if(!(+h[p>>3]==1.0)){E=18;break}c[f+131332>>2]=0}else{E=18}}while(0);if((E|0)==18){c[f+131332>>2]=192}B=+h[g>>3];z=+h[k>>3];C=+h[j>>3];Uq(29,6,2226376,(b=i,i=i+32|0,h[b>>3]=D,h[b+8>>3]=B,h[b+16>>3]=z,h[b+24>>3]=C,b)|0);i=b;C=+h[r>>3];h[g>>3]=C;h[q>>3]=C;c[o>>2]=0;do{if(+h[u>>3]==1.0&C==0.0){if(!(+h[p>>3]==1.0)){E=22;break}c[f+131332>>2]=0}else{E=22}}while(0);if((E|0)==22){c[f+131332>>2]=192}z=+h[k>>3];B=+h[j>>3];Uq(29,6,2226376,(b=i,i=i+32|0,h[b>>3]=+h[a>>3],h[b+8>>3]=C,h[b+16>>3]=z,h[b+24>>3]=B,b)|0);i=b;B=+h[s>>3];h[j>>3]=B;h[m>>3]=B;h[t>>3]=B;c[v>>2]=0;c[n>>2]=0;do{if(B==1.0){do{if(+h[f+262712>>3]==0.0){if(!(+h[l>>3]==1.0)){E=28;break}c[f+262700>>2]=0}else{E=28}}while(0);if((E|0)==28){c[f+262700>>2]=192}if(!(+h[f+394080>>3]==0.0)){E=32;break}if(!(+h[w>>3]==1.0)){E=32;break}c[f+394068>>2]=0}else{c[f+262700>>2]=192;E=32}}while(0);if((E|0)==32){c[f+394068>>2]=192}z=+h[g>>3];C=+h[k>>3];Uq(29,6,2226376,(b=i,i=i+32|0,h[b>>3]=+h[a>>3],h[b+8>>3]=z,h[b+16>>3]=C,h[b+24>>3]=B,b)|0);i=b;i=d;return 1}function qA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0,p=0,q=0,r=0;e=i;do{if((b|0)==6){f=c[d>>2]|0;if((irc(f,2189352)|0)==0){g=c[a+300>>2]|0;j=+$(+(c[d+4>>2]|0)*2.0794415416798357/100.0);h[g+394128>>3]=j;k=+h[g+394152>>3];l=j*k;h[g+131352>>3]=l;m=+S(+h[g+394160>>3]/k);h[g+262720>>3]=m;n=+S(+h[g+394144>>3]/k);h[g+394088>>3]=n;k=+h[g+394136>>3];h[g+394096>>3]=k;h[g+262728>>3]=k;h[g+131360>>3]=k;c[g+131328>>2]=0;c[g+262696>>2]=0;c[g+394064>>2]=0;do{if(+h[g+131336>>3]==1.0){if(!(+h[g+131344>>3]==0.0&l==1.0)){o=6;break}c[g+131332>>2]=0}else{o=6}}while(0);if((o|0)==6){c[g+131332>>2]=192}do{if(+h[g+262704>>3]==1.0){if(!(+h[g+262712>>3]==0.0&m==1.0)){o=10;break}c[g+262700>>2]=0}else{o=10}}while(0);if((o|0)==10){c[g+262700>>2]=192}do{if(+h[g+394072>>3]==1.0){if(!(+h[g+394080>>3]==0.0&n==1.0)){o=14;break}c[g+394068>>2]=0}else{o=14}}while(0);if((o|0)==14){c[g+394068>>2]=192}n=+h[g+394112>>3];m=+h[g+394120>>3];Uq(29,6,2226376,(p=i,i=i+32|0,h[p>>3]=+h[g+394104>>3],h[p+8>>3]=n,h[p+16>>3]=j,h[p+24>>3]=m,p)|0);i=p;q=1;i=e;return q|0}if((irc(f,2159216)|0)==0){r=c[a+300>>2]|0;m=+((c[d+4>>2]|0)+100|0)*.01;h[r+394104>>3]=m;h[r+131336>>3]=m;c[r+131328>>2]=0;do{if(m==1.0){if(!(+h[r+131344>>3]==0.0)){o=21;break}if(!(+h[r+131352>>3]==1.0)){o=21;break}c[r+131332>>2]=0}else{o=21}}while(0);if((o|0)==21){c[r+131332>>2]=192}j=+h[r+394112>>3];n=+h[r+394128>>3];l=+h[r+394120>>3];Uq(29,6,2226376,(p=i,i=i+32|0,h[p>>3]=m,h[p+8>>3]=j,h[p+16>>3]=n,h[p+24>>3]=l,p)|0);i=p;q=1;i=e;return q|0}if((irc(f,2133872)|0)==0){g=c[a+300>>2]|0;l=+(c[d+4>>2]|0)*.01;h[g+394112>>3]=l;h[g+131344>>3]=l;c[g+131328>>2]=0;do{if(+h[g+131336>>3]==1.0&l==0.0){if(!(+h[g+131352>>3]==1.0)){o=27;break}c[g+131332>>2]=0}else{o=27}}while(0);if((o|0)==27){c[g+131332>>2]=192}m=+h[g+394128>>3];n=+h[g+394120>>3];Uq(29,6,2226376,(p=i,i=i+32|0,h[p>>3]=+h[g+394104>>3],h[p+8>>3]=l,h[p+16>>3]=m,h[p+24>>3]=n,p)|0);i=p;q=1;i=e;return q|0}if((irc(f,2110384)|0)!=0){break}r=c[a+300>>2]|0;n=+((c[d+4>>2]|0)+100|0)/100.0;h[r+394120>>3]=n;h[r+262704>>3]=n;h[r+394072>>3]=n;c[r+262696>>2]=0;c[r+394064>>2]=0;do{if(n==1.0){do{if(+h[r+262712>>3]==0.0){if(!(+h[r+262720>>3]==1.0)){o=35;break}c[r+262700>>2]=0}else{o=35}}while(0);if((o|0)==35){c[r+262700>>2]=192}if(!(+h[r+394080>>3]==0.0)){o=39;break}if(!(+h[r+394088>>3]==1.0)){o=39;break}c[r+394068>>2]=0}else{c[r+262700>>2]=192;o=39}}while(0);if((o|0)==39){c[r+394068>>2]=192}l=+h[r+394112>>3];m=+h[r+394128>>3];Uq(29,6,2226376,(p=i,i=i+32|0,h[p>>3]=+h[r+394104>>3],h[p+8>>3]=l,h[p+16>>3]=m,h[p+24>>3]=n,p)|0);i=p;q=1;i=e;return q|0}else if((b|0)==8){f=c[d>>2]|0;if((irc(f,2189352)|0)==0){c[d+4>>2]=~~(+aa(+h[(c[a+300>>2]|0)+394128>>3])*100.0/2.0794415416798357);q=1;i=e;return q|0}if((irc(f,2159216)|0)==0){c[d+4>>2]=~~(+h[(c[a+300>>2]|0)+394104>>3]*100.0)-100;q=1;i=e;return q|0}if((irc(f,2133872)|0)==0){c[d+4>>2]=~~(+h[(c[a+300>>2]|0)+394112>>3]*100.0);q=1;i=e;return q|0}if((irc(f,2110384)|0)!=0){break}c[d+4>>2]=~~(+h[(c[a+300>>2]|0)+394120>>3]*100.0)-100;q=1;i=e;return q|0}}while(0);q=ar(a,b,d)|0;i=e;return q|0}function rA(a,b){a=a|0;b=b|0;var c=0;if((b|0)==961893977|(b|0)==959465033|(b|0)==842094169|(b|0)==808596553|(b|0)==1448433993|(b|0)==808466521|(b|0)==538982489|(b|0)==1345598516|(b|0)==1345466932|(b|0)==1345401140){c=Yq(a,b)|0}else{c=0}return c|0}function sA(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[a+300>>2]|0;f=e+394168|0;g=b+36|0;h=c[g>>2]|0;do{if((c[f>>2]|0)==(h|0)){i=e+394180|0;j=b+40|0;if((c[i>>2]|0)!=(c[j>>2]|0)){k=j;l=i;m=5;break}n=b+96|0}else{k=b+40|0;l=e+394180|0;m=5}}while(0);do{if((m|0)==5){c[f>>2]=h;i=c[k>>2]|0;c[l>>2]=i;j=c[g>>2]>>c[b+108>>2];c[e+394176>>2]=j;c[e+394172>>2]=j;o=c[k>>2]>>c[b+112>>2];c[e+394188>>2]=o;c[e+394184>>2]=o;p=ca(i,h)|0;i=b+96|0;if((c[i>>2]|0)>1){q=ca(j,o)|0;o=e+394192|0;j=Sqc(c[o>>2]|0,(q<<1)+p|0)|0;c[o>>2]=j;c[e+394196>>2]=j+p;c[e+394200>>2]=j+(q+p);n=i;break}else{q=e+394192|0;c[q>>2]=Sqc(c[q>>2]|0,p)|0;n=i;break}}}while(0);h=Zq(c[a+292>>2]|0,c[b+16>>2]|0,0,0,c[g>>2]|0,c[b+40>>2]|0)|0;g=0;do{k=e+(g*131368|0)+131332|0;if((c[k>>2]|0)==0){c[h+44+(g<<2)>>2]=c[b+44+(g<<2)>>2];c[h+60+(g<<2)>>2]=c[b+60+(g<<2)>>2]}else{l=c[e+394192+(g<<2)>>2]|0;c[h+44+(g<<2)>>2]=l;f=e+394168+(g<<2)|0;m=c[f>>2]|0;c[h+60+(g<<2)>>2]=m;Se[c[k>>2]&1023](e+(g*131368|0)|0,l,c[b+44+(g<<2)>>2]|0,c[f>>2]|0,c[e+394180+(g<<2)>>2]|0,m,c[b+60+(g<<2)>>2]|0)}g=g+1|0;}while(g>>>0<((c[n>>2]|0)>1?3:1)>>>0);return _q(a,h,d)|0}function tA(a){a=a|0;var b=0;b=a+300|0;a=c[b>>2]|0;if((a|0)==0){return}Qqc(c[a+394192>>2]|0);Qqc(c[b>>2]|0);return}function uA(f,g,i,j,k,l,m){f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0;n=f+131328|0;if((c[n>>2]|0)==0){o=+h[f+131352>>3];p=+h[f+131360>>3];q=1.0-p;r=1.0/(o<.001|o>1.0e3?1.0:o);s=f+131336|0;t=f+131344|0;u=0;while(1){o=+h[t>>3]+(+h[s>>3]*(+(u>>>0>>>0)/255.0+-.5)+.5);do{if(o>0.0){v=q*o+p*+T(+o,+r);if(v<1.0){a[f+u|0]=~~(v*256.0);break}else{a[f+u|0]=-1;break}}else{a[f+u|0]=0}}while(0);w=u+1|0;if(w>>>0<256>>>0){u=w}else{x=0;break}}do{b[f+256+(x<<1)>>1]=(d[f+(x>>>8)|0]|0)<<8|(d[f+(x&255)|0]|0);x=x+1|0;}while(x>>>0<65536>>>0);c[n>>2]=1}n=j>>>3;x=n<<2;if((k|0)==0){return}if((n|0)==0){n=0;u=i;s=g;while(1){if((j|0)!=0){t=0;do{a[s+t|0]=a[f+(d[u+t|0]|0)|0]|0;t=t+1|0;}while(t>>>0<j>>>0)}t=n+1|0;if(t>>>0<k>>>0){n=t;u=u+m|0;s=s+l|0}else{break}}return}else{y=0;z=i;A=g}while(1){g=z;i=A;s=0;do{b[i+(s<<1)>>1]=b[f+256+((e[g+(s<<1)>>1]|0)<<1)>>1]|0;u=s|1;b[i+(u<<1)>>1]=b[f+256+((e[g+(u<<1)>>1]|0)<<1)>>1]|0;u=s|2;b[i+(u<<1)>>1]=b[f+256+((e[g+(u<<1)>>1]|0)<<1)>>1]|0;u=s|3;b[i+(u<<1)>>1]=b[f+256+((e[g+(u<<1)>>1]|0)<<1)>>1]|0;s=s+4|0;}while(s>>>0<x>>>0);g=s<<1;if(g>>>0<j>>>0){i=g;do{a[A+i|0]=a[f+(d[z+i|0]|0)|0]|0;i=i+1|0;}while(i>>>0<j>>>0)}i=y+1|0;if(i>>>0<k>>>0){y=i;z=z+m|0;A=A+l|0}else{break}}return}function vA(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0;e=i;i=i+272|0;f=e|0;g=e+8|0;h=e+264|0;c[f>>2]=0;c[h>>2]=-1;c[a+4>>2]=50;c[a+20>>2]=6;c[a+16>>2]=486;c[a+12>>2]=204;c[a+32>>2]=118;c[a+8>>2]=248;j=a+300|0;c[j>>2]=pJb(296)|0;Vq();a=c[j>>2]|0;c[a+256>>2]=4;k=a+284|0;c[k>>2]=0;if((d|0)!=0){Bd(d|0,2275088,(d=i,i=i+32|0,c[d>>2]=h,c[d+8>>2]=a+264,c[d+16>>2]=f,c[d+24>>2]=k,d)|0)|0;i=d}d=c[h>>2]|0;do{if((d-4|0)>>>0<2>>>0){h=c[j>>2]|0;c[h+256>>2]=d;l=h}else{h=c[j>>2]|0;if((d|0)<=5){l=h;break}c[h+256>>2]=5;l=h}}while(0);d=l+264|0;if((c[d>>2]|0)<0){c[d>>2]=0}j=c[f>>2]|0;do{if((j|0)<-15){c[f>>2]=-15;m=-15}else{if((j|0)<=32){m=j;break}c[f>>2]=32;m=32}}while(0);j=l+272|0;c[j>>2]=0;c[f>>2]=0;n=+(m+16|0)/71.0;m=0;do{c[g+(m<<2)>>2]=~~(+(b[1623248+(m<<1)>>1]|0)*n+.5);m=m+1|0;}while((m|0)<64);c[f>>2]=0;m=0;do{h=m<<3;k=c[g+((h|2)<<2)>>2]|0;a=c[g+((h|6)<<2)>>2]|0;o=a;p=((a|0)<0|0?-1:0)<<16|o>>>16|((k|0)<0|0?-1:0)|c[g+(h<<2)>>2]|(c[g+((h|4)<<2)>>2]<<16|0>>>16);a=m<<1;q=l+(a<<3)|0;c[q>>2]=o<<16|0>>>16|k|(0<<16|0>>>16);c[q+4>>2]=p;p=c[g+((h|5)<<2)>>2]|0;q=c[g+((h|3)<<2)>>2]|0;k=q;o=((q|0)<0|0?-1:0)<<16|k>>>16|((p|0)<0|0?-1:0)|c[g+((h|1)<<2)>>2]|(c[g+((h|7)<<2)>>2]<<16|0>>>16);h=l+((a|1)<<3)|0;c[h>>2]=k<<16|0>>>16|p|(0<<16|0>>>16);c[h+4>>2]=o;m=m+1|0;}while((m|0)<8);c[f>>2]=8;f=c[d>>2]|0;if((f|0)==0){i=e;return 1}c[j>>2]=f;j=l;d=l+128|0;l=0;do{b[d+(l<<1)>>1]=ca(b[j+(l<<1)>>1]|0,f)|0;l=l+1|0;}while((l|0)<64);i=e;return 1}function wA(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=b+31&-16;j=a+300|0;c[(c[j>>2]|0)+260>>2]=i;k=pJb(i*48|0)|0;c[(c[j>>2]|0)+280>>2]=k;k=hJb(ca(c[(c[j>>2]|0)+260>>2]|0,d+31&-16)|0)|0;c[(c[j>>2]|0)+276>>2]=k;return $q(a,b,d,e,f,g,h)|0}function xA(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=b|0;if((c[e>>2]&8192|0)==0){f=Zq(c[a+292>>2]|0,c[b+16>>2]|0,2,24,c[b+20>>2]|0,c[b+24>>2]|0)|0;Wq(f,b);g=f}else{g=c[a+296>>2]|0}f=a+300|0;h=c[f>>2]|0;c[h+268>>2]=c[b+92>>2];do{if((c[b+84>>2]|0)==3){i=h}else{j=b+76|0;k=c[j>>2]|0;if((k|0)==0){i=h;break}if((c[h+264>>2]|0)!=0){i=h;break}l=c[b+80>>2]|0;if((l|0)==0){m=1;n=(c[b+36>>2]|0)+15>>4}else{m=(c[b+40>>2]|0)+15>>4;n=l}l=h+288|0;o=c[l>>2]|0;p=ca(m,n)|0;if((o|0)==0){c[l>>2]=Pqc(p)|0;q=c[(c[f>>2]|0)+288>>2]|0;r=c[j>>2]|0}else{q=o;r=k}nrc(q|0,r|0,p)|0;i=c[f>>2]|0}}while(0);do{if((c[i+256>>2]|0)==0){if((c[e>>2]&8192|0)==0){break}s=_q(a,g,d)|0;return s|0}}while(0);e=c[i+288>>2]|0;if((c[i+284>>2]|0)!=0|(e|0)==0){t=c[b+76>>2]|0}else{t=e}do{if((t|0)==0){if((c[i+264>>2]|0)!=0){break}e=c[g+44>>2]|0;r=c[b+44>>2]|0;q=b+36|0;n=c[q>>2]|0;m=b+40|0;h=c[m>>2]|0;p=c[g+60>>2]|0;k=c[b+60>>2]|0;do{if((p|0)==(k|0)){if((p|0)<0){o=ca(h-1|0,p)|0;u=e+o|0;v=r+o|0;w=-p|0}else{u=e;v=r;w=p}nrc(u|0,v|0,ca(w,h)|0)|0}else{if((h|0)>0){x=r;y=0;z=e}else{break}while(1){nrc(z|0,x|0,n)|0;o=y+1|0;if((o|0)<(h|0)){x=x+k|0;y=o;z=z+p|0}else{break}}}}while(0);p=c[g+48>>2]|0;k=c[b+48>>2]|0;h=b+108|0;n=c[q>>2]>>c[h>>2];e=b+112|0;r=c[m>>2]>>c[e>>2];o=c[g+64>>2]|0;j=c[b+64>>2]|0;do{if((o|0)==(j|0)){if((o|0)<0){l=ca(r-1|0,o)|0;A=p+l|0;B=k+l|0;C=-o|0}else{A=p;B=k;C=o}nrc(A|0,B|0,ca(C,r)|0)|0}else{if((r|0)>0){D=k;E=0;F=p}else{break}while(1){nrc(F|0,D|0,n)|0;l=E+1|0;if((l|0)<(r|0)){D=D+j|0;E=l;F=F+o|0}else{break}}}}while(0);o=c[g+52>>2]|0;j=c[b+52>>2]|0;r=c[q>>2]>>c[h>>2];n=c[m>>2]>>c[e>>2];p=c[g+68>>2]|0;k=c[b+68>>2]|0;if((p|0)==(k|0)){if((p|0)<0){l=ca(n-1|0,p)|0;G=o+l|0;H=j+l|0;I=-p|0}else{G=o;H=j;I=p}nrc(G|0,H|0,ca(I,n)|0)|0;s=_q(a,g,d)|0;return s|0}else{if((n|0)>0){J=j;K=0;L=o}else{s=_q(a,g,d)|0;return s|0}while(1){nrc(L|0,J|0,r)|0;o=K+1|0;if((o|0)<(n|0)){J=J+k|0;K=o;L=L+p|0}else{break}}s=_q(a,g,d)|0;return s|0}}}while(0);L=b+36|0;K=b+40|0;J=b+80|0;CA(i,c[g+44>>2]|0,c[b+44>>2]|0,c[g+60>>2]|0,c[b+60>>2]|0,c[L>>2]|0,c[K>>2]|0,t,c[J>>2]|0,1);i=b+108|0;I=b+112|0;CA(c[f>>2]|0,c[g+48>>2]|0,c[b+48>>2]|0,c[g+64>>2]|0,c[b+64>>2]|0,c[L>>2]>>c[i>>2],c[K>>2]>>c[I>>2],t,c[J>>2]|0,0);CA(c[f>>2]|0,c[g+52>>2]|0,c[b+52>>2]|0,c[g+68>>2]|0,c[b+68>>2]|0,c[L>>2]>>c[i>>2],c[K>>2]>>c[I>>2],t,c[J>>2]|0,0);s=_q(a,g,d)|0;return s|0}function yA(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=b|0;f=c[e>>2]|0;if((f&1|0)!=0){return}g=b+20|0;h=Zq(c[a+292>>2]|0,c[b+16>>2]|0,d[b+4|0]|0,f,c[g>>2]|0,c[b+24>>2]|0)|0;f=a+296|0;c[f>>2]=h;c[b+44>>2]=c[h+44>>2];h=c[f>>2]|0;c[b+60>>2]=c[h+60>>2];c[g>>2]=c[h+20>>2];g=c[e>>2]|0;if((g&256|0)!=0){c[b+48>>2]=c[h+48>>2];c[b+52>>2]=c[(c[f>>2]|0)+52>>2];h=c[f>>2]|0;c[b+64>>2]=c[h+64>>2];c[b+68>>2]=c[h+68>>2]}c[e>>2]=g|8192;return}function zA(a,b){a=a|0;b=b|0;var c=0;if((b|0)==961893977|(b|0)==959465033|(b|0)==842094169|(b|0)==808596553|(b|0)==1448433993|(b|0)==1280330819|(b|0)==808466521|(b|0)==538982489|(b|0)==1345598516|(b|0)==1345466932|(b|0)==1345401140){c=Yq(a,b)|0}else{c=0}return c|0}function AA(a){a=a|0;var b=0;b=a+300|0;a=c[b>>2]|0;if((a|0)==0){return}kJb(c[a+280>>2]|0);c[(c[b>>2]|0)+280>>2]=0;kJb(c[(c[b>>2]|0)+276>>2]|0);c[(c[b>>2]|0)+276>>2]=0;Qqc(c[(c[b>>2]|0)+288>>2]|0);c[(c[b>>2]|0)+288>>2]=0;kJb(c[b>>2]|0);c[b>>2]=0;return}function BA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if((b|0)==4){e=5}else if((b|0)==5){f=c[d>>2]|0;g=(c[a+300>>2]|0)+256|0;c[g>>2]=f;if((f|0)>=4){e=1;break}c[g>>2]=4;e=1}else{e=ar(a,b,d)|0}}while(0);return e|0}function CA(e,f,g,h,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;p=i;i=i+3072|0;q=p|0;if((o|0)==0){r=k+16|0}else{r=c[e+260>>2]|0}s=e+256|0;t=6-(c[s>>2]|0)|0;u=o+3|0;o=q;v=q+1536|0;w=v;x=v;mrc(x|0,0,384)|0;if((g|0)==0|(f|0)==0){i=p;return}v=e+276|0;if((l|0)>0){y=0;do{z=ca(y+8|0,r)|0;A=z+8|0;nrc((c[v>>2]|0)+A|0,g+(ca(y,j)|0)|0,k)|0;B=A+k|0;C=c[v>>2]|0;a[C+(z+7)|0]=a[C+A|0]|0;A=c[v>>2]|0;a[A+B|0]=a[A+(B-1)|0]|0;A=c[v>>2]|0;a[A+(z+6)|0]=a[A+(z+9)|0]|0;A=c[v>>2]|0;a[A+(B+1)|0]=a[A+(B-2)|0]|0;A=c[v>>2]|0;a[A+(z+5)|0]=a[A+(z+10)|0]|0;A=c[v>>2]|0;a[A+(B+2)|0]=a[A+(B-3)|0]|0;A=c[v>>2]|0;a[A+(z+4)|0]=a[A+(z+11)|0]|0;A=c[v>>2]|0;a[A+(B+3)|0]=a[A+(B-4)|0]|0;A=c[v>>2]|0;a[A+(z+3)|0]=a[A+(z+12)|0]|0;A=c[v>>2]|0;a[A+(B+4)|0]=a[A+(B-5)|0]|0;A=c[v>>2]|0;a[A+(z+2)|0]=a[A+(z+13)|0]|0;A=c[v>>2]|0;a[A+(B+5)|0]=a[A+(B-6)|0]|0;A=c[v>>2]|0;a[A+(z+1)|0]=a[A+(z+14)|0]|0;A=c[v>>2]|0;a[A+(B+6)|0]=a[A+(B-7)|0]|0;A=c[v>>2]|0;a[A+z|0]=a[A+(z+15)|0]|0;A=c[v>>2]|0;a[A+(B+7)|0]=a[A+(z+k)|0]|0;y=y+1|0;}while((y|0)<(l|0))}y=l+8|0;j=l+7|0;g=0;do{z=c[v>>2]|0;nrc(z+(ca(7-g|0,r)|0)|0,z+(ca(g+8|0,r)|0)|0,r)|0;z=c[v>>2]|0;nrc(z+(ca(y+g|0,r)|0)|0,z+(ca(j-g|0,r)|0)|0,r)|0;g=g+1|0;}while((g|0)<8);g=e+280|0;j=k<<1;mrc((c[g>>2]|0)+((r<<3)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*9|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*10|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*11|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*12|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*13|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*14|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*15|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r<<4|8)<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*17|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*18|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*19|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*20|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*21|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*22|0)+8<<1)|0,0,j|0)|0;mrc((c[g>>2]|0)+((r*23|0)+8<<1)|0,0,j|0)|0;if((t|0)<(y|0)){j=l-1|0;l=k-80|0;z=(l|0)>0;A=k+8|0;B=q+128|0;C=e+128|0;D=t-8|0;E=(r<<3)+8|0;F=e+264|0;G=q;H=q+1408|0;I=q+2944|0;q=e+268|0;J=e+272|0;K=e;e=t;while(1){L=e-4|0;M=(L|0)>(j|0)?j:L;L=ca(((M|0)<0?0:M)>>u,n)|0;M=ca(e,r)|0;N=e&1;DA(o,(c[v>>2]|0)+(M+2-N)|0,r,2);if(z){O=M+10-N|0;P=2-N+(ca(e&15,r)|0)|0;Q=0;while(1){DA(B,(c[v>>2]|0)+(O+Q)|0,r,22);if((c[F>>2]|0)==0){R=Q-2|0;S=0;do{T=R+S|0;U=d[m+((((T|0)<0?0:T)>>u)+L)|0]|0;T=c[q>>2]|0;if((T|0)==3){V=65-U>>2}else if((T|0)==2){V=U>>>2}else if((T|0)==1){V=U>>>1}else{V=U}if((V|0)!=(c[J>>2]|0)){c[J>>2]=V;U=0;do{b[C+(U<<1)>>1]=ca(b[K+(U<<1)>>1]|0,V)|0;U=U+1|0;}while((U|0)<64)}U=S<<3;EA(C,o+(U<<1)|0,w+(U<<1)|0,8);S=S+8|0;}while((S|0)<88)}else{EA(C,o,w,88)}FA(w,(c[g>>2]|0)+(P+Q<<1)|0,r,22);c[G>>2]=c[H>>2];c[G+4>>2]=c[H+4>>2];c[G+8>>2]=c[H+8>>2];c[G+12>>2]=c[H+12>>2];c[G+16>>2]=c[H+16>>2];c[G+20>>2]=c[H+20>>2];c[G+24>>2]=c[H+24>>2];c[G+28>>2]=c[H+28>>2];c[G+32>>2]=c[H+32>>2];c[G+36>>2]=c[H+36>>2];c[G+40>>2]=c[H+40>>2];c[G+44>>2]=c[H+44>>2];c[G+48>>2]=c[H+48>>2];c[G+52>>2]=c[H+52>>2];c[G+56>>2]=c[H+56>>2];c[G+60>>2]=c[H+60>>2];c[G+64>>2]=c[H+64>>2];c[G+68>>2]=c[H+68>>2];c[G+72>>2]=c[H+72>>2];c[G+76>>2]=c[H+76>>2];c[G+80>>2]=c[H+80>>2];c[G+84>>2]=c[H+84>>2];c[G+88>>2]=c[H+88>>2];c[G+92>>2]=c[H+92>>2];c[G+96>>2]=c[H+96>>2];c[G+100>>2]=c[H+100>>2];c[G+104>>2]=c[H+104>>2];c[G+108>>2]=c[H+108>>2];c[G+112>>2]=c[H+112>>2];c[G+116>>2]=c[H+116>>2];c[G+120>>2]=c[H+120>>2];c[G+124>>2]=c[H+124>>2];c[x>>2]=c[I>>2];c[x+4>>2]=c[I+4>>2];c[x+8>>2]=c[I+8>>2];c[x+12>>2]=c[I+12>>2];c[x+16>>2]=c[I+16>>2];c[x+20>>2]=c[I+20>>2];c[x+24>>2]=c[I+24>>2];c[x+28>>2]=c[I+28>>2];c[x+32>>2]=c[I+32>>2];c[x+36>>2]=c[I+36>>2];c[x+40>>2]=c[I+40>>2];c[x+44>>2]=c[I+44>>2];c[x+48>>2]=c[I+48>>2];c[x+52>>2]=c[I+52>>2];c[x+56>>2]=c[I+56>>2];c[x+60>>2]=c[I+60>>2];c[x+64>>2]=c[I+64>>2];c[x+68>>2]=c[I+68>>2];c[x+72>>2]=c[I+72>>2];c[x+76>>2]=c[I+76>>2];c[x+80>>2]=c[I+80>>2];c[x+84>>2]=c[I+84>>2];c[x+88>>2]=c[I+88>>2];c[x+92>>2]=c[I+92>>2];S=Q+88|0;if((S|0)<(l|0)){Q=S}else{W=S;break}}}else{W=0}Q=A-W|0;if((Q|0)>8){DA(B,(c[v>>2]|0)+(M+10-N+W)|0,r,Q-4>>2)}EA(C,o,w,Q&-2);FA(w,(c[g>>2]|0)+(2-N+(ca(e&15,r)|0)+W<<1)|0,r,Q>>2);Q=D+e|0;do{if((Q&7|0)==0&(Q|0)!=0){P=f+(ca(Q-8|0,h)|0)|0;L=c[g>>2]|0;if((Q&8|0)==0){HA(P,L+16|0,h,r,k,8,5-(c[s>>2]|0)|0);break}else{GA(P,L+(E<<1)|0,h,r,k,8,5-(c[s>>2]|0)|0);break}}}while(0);Q=e+t|0;if((Q|0)<(y|0)){e=Q}else{X=Q;break}}}else{X=t}t=X&7;if((t|0)==0){i=p;return}e=f+(ca(X-8&-8,h)|0)|0;f=c[g>>2]|0;if((X&8|0)==0){HA(e,f+16|0,h,r,k,t,5-(c[s>>2]|0)|0);i=p;return}else{GA(e,f+((r<<3)+8<<1)|0,h,r,k,t,5-(c[s>>2]|0)|0);i=p;return}}function DA(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=f<<2;if((g|0)<=0){return}f=e*7|0;h=e*6|0;i=e<<1;j=e*5|0;k=e*3|0;l=e<<2;m=g;g=c;c=a;while(1){a=d[g]|0;n=d[g+f|0]|0;o=n+a|0;p=a-n|0;n=d[g+e|0]|0;a=d[g+h|0]|0;q=a+n|0;r=n-a|0;a=d[g+i|0]|0;n=d[g+j|0]|0;s=n+a|0;t=a-n|0;n=d[g+k|0]|0;a=d[g+l|0]|0;u=a+n|0;v=u+o|0;w=o-u|0;u=s+q|0;b[c+4>>1]=v+u;b[c+6>>1]=v-u;u=((q-s+w|0)*46340|0)>>16;b[c>>1]=u+w;b[c+2>>1]=w-u;u=n-a+t|0;a=r+p|0;n=(((u<<2)-(a<<2)|0)*6270|0)>>16;w=n+((u*35468|0)>>16)|0;u=n+((a*85628|0)>>16)|0;a=((t+r|0)*46340|0)>>16;r=a+p|0;t=p-a|0;b[c+8>>1]=w+t;b[c+10>>1]=t-w;b[c+12>>1]=u+r;b[c+14>>1]=r-u;u=m-1|0;if((u|0)>0){m=u;g=g+1|0;c=c+16|0}else{break}}return}function EA(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((f|0)>0){g=f;h=c;i=d}else{return}while(1){d=h;c=i;f=a;j=8;while(1){k=b[d>>1]|0;l=b[d+112>>1]|0;m=l+k|0;n=k-l|0;l=b[d+16>>1]|0;k=b[d+96>>1]|0;o=k+l|0;p=l-k|0;k=b[d+32>>1]|0;l=b[d+80>>1]|0;q=l+k|0;r=k-l|0;l=b[d+48>>1]|0;k=b[d+64>>1]|0;s=k+l|0;t=s+m|0;u=m-s|0;s=q+o|0;m=t+s|0;v=t-s|0;s=((o-q+u|0)*46340|0)>>16;q=s+u|0;o=u-s|0;s=b[f>>1]|0;u=(m+s|0)>>>0>s<<1>>>0?m+2|0:2;m=b[f+32>>1]|0;s=(q+m|0)>>>0>m<<1>>>0?q:0;q=b[f+64>>1]|0;m=(v+q|0)>>>0>q<<1>>>0?v:0;v=b[f+96>>1]|0;q=(o+v|0)>>>0>v<<1>>>0?o:0;o=u+m>>2;v=u-m>>2;m=s+q>>2;u=(((s-q|0)*23170|0)>>16)-m|0;q=m+o|0;s=o-m|0;m=u+v|0;o=v-u|0;u=l-k+r|0;k=p+n|0;l=((u-k|0)*25080|0)>>16;v=l+((u*35468|0)>>16)|0;u=l+((k*85628|0)>>16)|0;k=((r+p|0)*46340|0)>>16;p=k+n|0;r=n-k|0;k=v+r|0;n=r-v|0;v=u+p|0;r=p-u|0;u=b[f+16>>1]|0;p=(v+u|0)>>>0>u<<1>>>0?v:0;v=b[f+48>>1]|0;u=(n+v|0)>>>0>v<<1>>>0?n:0;n=b[f+80>>1]|0;v=(k+n|0)>>>0>n<<1>>>0?k:0;k=b[f+112>>1]|0;n=(k+r|0)>>>0>k<<1>>>0?r:0;r=v+u|0;k=v-u|0;u=n+p|0;v=p-n|0;n=u+r>>2;p=((v+k|0)*30274|0)>>16;l=((k*-42812|0)>>16)-n+p|0;k=(((u-r|0)*23170|0)>>16)-l|0;r=k+(((v*17734|0)>>16)-p)|0;b[c>>1]=q+(e[c>>1]|0)+n;p=c+16|0;b[p>>1]=m+(e[p>>1]|0)+l;p=c+32|0;b[p>>1]=o+(e[p>>1]|0)+k;p=c+48|0;b[p>>1]=(e[p>>1]|0)+s-r;p=c+64|0;b[p>>1]=(e[p>>1]|0)+s+r;r=c+80|0;b[r>>1]=(e[r>>1]|0)+o-k;b[c+96>>1]=m-l;b[c+112>>1]=q-n;n=j-1|0;if((n|0)>0){d=d+2|0;c=c+2|0;f=f+2|0;j=n}else{break}}j=g-2|0;if((j|0)>0){g=j;h=h+32|0;i=i+32|0}else{break}}return}function FA(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=f<<2;if((g|0)<=0){return}f=d<<1;h=d*3|0;i=d<<2;j=d*5|0;k=d*6|0;l=d*7|0;m=g;g=c;c=a;while(1){a=b[c+4>>1]|0;n=b[c+6>>1]|0;o=n+a|0;p=a-n|0;n=b[c>>1]|0;a=b[c+2>>1]|0;q=a+n|0;r=(((n-a|0)*23170|0)>>16<<2)-q|0;a=b[c+8>>1]|0;n=b[c+10>>1]|0;s=n+a|0;t=a-n|0;n=b[c+12>>1]|0;a=b[c+14>>1]|0;u=a+n|0;v=n-a|0;a=u+s|0;n=((v+t|0)*15137|0)>>16;w=(n+((t*-21406|0)>>16)<<3)-a|0;t=(((u-s|0)*11585|0)>>16<<3)-w|0;s=t+(((v*8867|0)>>16)-n<<3)|0;n=q+o+4|0;b[g>>1]=((n+a|0)>>>3)+(e[g>>1]|0);v=r+p+4|0;u=g+(d<<1)|0;b[u>>1]=((v+w|0)>>>3)+(e[u>>1]|0);u=p-r+4|0;r=g+(f<<1)|0;b[r>>1]=((u+t|0)>>>3)+(e[r>>1]|0);r=o-q+4|0;q=g+(h<<1)|0;b[q>>1]=((r-s|0)>>>3)+(e[q>>1]|0);q=g+(i<<1)|0;b[q>>1]=((r+s|0)>>>3)+(e[q>>1]|0);q=g+(j<<1)|0;b[q>>1]=((u-t|0)>>>3)+(e[q>>1]|0);q=g+(k<<1)|0;b[q>>1]=((v-w|0)>>>3)+(e[q>>1]|0);q=g+(l<<1)|0;b[q>>1]=(e[q>>1]|0)+((n-a|0)>>>3);a=m-1|0;if((a|0)>0){m=a;g=g+2|0;c=c+16|0}else{break}}return}function GA(c,e,f,g,h,i,j){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((i|0)<=0){return}k=(h|0)>0;l=6-j|0;m=g<<3;n=e;e=0;o=c;while(1){if(k){c=(d[1532176+(e<<3)|0]|0)>>>(j>>>0);p=(d[1532177+(e<<3)|0]|0)>>>(j>>>0);q=(d[1532178+(e<<3)|0]|0)>>>(j>>>0);r=(d[1532179+(e<<3)|0]|0)>>>(j>>>0);s=(d[1532180+(e<<3)|0]|0)>>>(j>>>0);t=(d[1532181+(e<<3)|0]|0)>>>(j>>>0);u=(d[1532182+(e<<3)|0]|0)>>>(j>>>0);v=(d[1532183+(e<<3)|0]|0)>>>(j>>>0);w=0;do{x=n+(w<<1)|0;y=c+(b[x>>1]|0)>>l;b[n+(w-m<<1)>>1]=0;b[x>>1]=0;if((y&256|0)==0){z=y&255}else{z=(y>>31^255)&255}a[o+w|0]=z;y=w|1;x=n+(y<<1)|0;A=p+(b[x>>1]|0)>>l;b[n+(y-m<<1)>>1]=0;b[x>>1]=0;if((A&256|0)==0){B=A&255}else{B=(A>>31^255)&255}a[o+y|0]=B;y=w|2;A=n+(y<<1)|0;x=q+(b[A>>1]|0)>>l;b[n+(y-m<<1)>>1]=0;b[A>>1]=0;if((x&256|0)==0){C=x&255}else{C=(x>>31^255)&255}a[o+y|0]=C;y=w|3;x=n+(y<<1)|0;A=r+(b[x>>1]|0)>>l;b[n+(y-m<<1)>>1]=0;b[x>>1]=0;if((A&256|0)==0){D=A&255}else{D=(A>>31^255)&255}a[o+y|0]=D;y=w|4;A=n+(y<<1)|0;x=s+(b[A>>1]|0)>>l;b[n+(y-m<<1)>>1]=0;b[A>>1]=0;if((x&256|0)==0){E=x&255}else{E=(x>>31^255)&255}a[o+y|0]=E;y=w|5;x=n+(y<<1)|0;A=t+(b[x>>1]|0)>>l;b[n+(y-m<<1)>>1]=0;b[x>>1]=0;if((A&256|0)==0){F=A&255}else{F=(A>>31^255)&255}a[o+y|0]=F;y=w|6;A=n+(y<<1)|0;x=u+(b[A>>1]|0)>>l;b[n+(y-m<<1)>>1]=0;b[A>>1]=0;if((x&256|0)==0){G=x&255}else{G=(x>>31^255)&255}a[o+y|0]=G;y=w|7;x=n+(y<<1)|0;A=v+(b[x>>1]|0)>>l;b[n+(y-m<<1)>>1]=0;b[x>>1]=0;if((A&256|0)==0){H=A&255}else{H=(A>>31^255)&255}a[o+y|0]=H;w=w+8|0;}while((w|0)<(h|0))}w=e+1|0;if((w|0)<(i|0)){n=n+(g<<1)|0;e=w;o=o+f|0}else{break}}return}function HA(c,e,f,g,h,i,j){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((i|0)<=0){return}k=(h|0)>0;l=g<<4;m=6-j|0;n=e;e=0;o=c;while(1){if(k){c=(d[1532176+(e<<3)|0]|0)>>>(j>>>0);p=(d[1532177+(e<<3)|0]|0)>>>(j>>>0);q=(d[1532178+(e<<3)|0]|0)>>>(j>>>0);r=(d[1532179+(e<<3)|0]|0)>>>(j>>>0);s=(d[1532180+(e<<3)|0]|0)>>>(j>>>0);t=(d[1532181+(e<<3)|0]|0)>>>(j>>>0);u=(d[1532182+(e<<3)|0]|0)>>>(j>>>0);v=(d[1532183+(e<<3)|0]|0)>>>(j>>>0);w=0;do{x=n+(w+l<<1)|0;y=(b[x>>1]|0)+(b[n+(w<<1)>>1]|0)+c>>m;b[x>>1]=0;if((y&256|0)==0){z=y&255}else{z=(y>>31^255)&255}a[o+w|0]=z;y=w|1;x=n+(y+l<<1)|0;A=(b[x>>1]|0)+(b[n+(y<<1)>>1]|0)+p>>m;b[x>>1]=0;if((A&256|0)==0){B=A&255}else{B=(A>>31^255)&255}a[o+y|0]=B;y=w|2;A=n+(y+l<<1)|0;x=(b[A>>1]|0)+(b[n+(y<<1)>>1]|0)+q>>m;b[A>>1]=0;if((x&256|0)==0){C=x&255}else{C=(x>>31^255)&255}a[o+y|0]=C;y=w|3;x=n+(y+l<<1)|0;A=(b[x>>1]|0)+(b[n+(y<<1)>>1]|0)+r>>m;b[x>>1]=0;if((A&256|0)==0){D=A&255}else{D=(A>>31^255)&255}a[o+y|0]=D;y=w|4;A=n+(y+l<<1)|0;x=(b[A>>1]|0)+(b[n+(y<<1)>>1]|0)+s>>m;b[A>>1]=0;if((x&256|0)==0){E=x&255}else{E=(x>>31^255)&255}a[o+y|0]=E;y=w|5;x=n+(y+l<<1)|0;A=(b[x>>1]|0)+(b[n+(y<<1)>>1]|0)+t>>m;b[x>>1]=0;if((A&256|0)==0){F=A&255}else{F=(A>>31^255)&255}a[o+y|0]=F;y=w|6;A=n+(y+l<<1)|0;x=(b[A>>1]|0)+(b[n+(y<<1)>>1]|0)+u>>m;b[A>>1]=0;if((x&256|0)==0){G=x&255}else{G=(x>>31^255)&255}a[o+y|0]=G;y=w|7;x=n+(y+l<<1)|0;A=(b[x>>1]|0)+(b[n+(y<<1)>>1]|0)+v>>m;b[x>>1]=0;if((A&256|0)==0){H=A&255}else{H=(A>>31^255)&255}a[o+y|0]=H;w=w+8|0;}while((w|0)<(h|0))}w=e+1|0;if((w|0)<(i|0)){n=n+(g<<1)|0;e=w;o=o+f|0}else{break}}return}function IA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;c[a+4>>2]=120;c[a+12>>2]=240;c[a+20>>2]=2;e=Rqc(1,12)|0;f=a+300|0;c[f>>2]=e;c[e>>2]=1;if((b|0)!=0){Bd(b|0,2275080,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g}c[1366862]=42;c[1366866]=252;c[1366864]=590;e=c[f>>2]|0;b=c[e>>2]|0;if((b|0)==0){c[e+8>>2]=42;c[(c[f>>2]|0)+4>>2]=42;i=d;return 1}else if((b|0)==1){h=252;j=e}else{Uq(29,2,2226248,(g=i,i=i+8|0,c[g>>2]=b,g)|0);i=g;h=c[1366866]|0;j=c[f>>2]|0}c[j+4>>2]=h;c[(c[f>>2]|0)+8>>2]=c[1366864];i=d;return 1}function JA(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return $q(a,b,c,d,e,f,844715353)|0}function KA(a,b){a=a|0;b=b|0;var c=0;if((b|0)==842094169|(b|0)==1448433993|(b|0)==808596553){c=Yq(a,844715353)|0}else{c=0}return c|0}function LA(b,d,e){b=b|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=d+36|0;g=d+40|0;h=Zq(c[b+292>>2]|0,844715353,2,16,c[f>>2]|0,c[g>>2]|0)|0;i=c[h+44>>2]|0;j=c[h+60>>2]|0;k=c[f>>2]|0;f=c[g>>2]|0;g=c[b+300>>2]|0;l=c[d+44>>2]|0;m=c[d+48>>2]|0;n=c[d+52>>2]|0;o=c[d+60>>2]|0;p=c[d+64>>2]|0;q=c[d+68>>2]|0;d=(k+1|0)>>>0<3>>>0;if(!d){r=(k|0)/2|0;s=n;t=m;u=l;v=i;w=r;while(1){a[v]=a[u]|0;a[v+1|0]=a[t]|0;a[v+2|0]=a[u+1|0]|0;a[v+3|0]=a[s]|0;x=w-1|0;if((x|0)==0){break}else{s=s+1|0;t=t+1|0;u=u+2|0;v=v+4|0;w=x}}w=n+q|0;v=m+p|0;u=l+o|0;t=i+j|0;s=r;while(1){a[t]=a[u]|0;a[t+1|0]=a[v]|0;a[t+2|0]=a[u+1|0]|0;a[t+3|0]=a[w]|0;r=s-1|0;if((r|0)==0){break}else{w=w+1|0;v=v+1|0;u=u+2|0;t=t+4|0;s=r}}}s=l+(o<<1)|0;t=i+(j<<1)|0;u=f-2|0;if((u|0)>2){f=-p|0;v=-q|0;w=ca(u,j)|0;r=n;x=m;y=s;z=2;A=t;while(1){B=z&2;C=B-1|0;D=ca(C,p)|0;E=ca(C,q)|0;Se[c[g+4+((B>>>1^z&1)<<2)>>2]&1023](A,y,x,r,k,D,E);E=(z&3|0)==1;F=x+(E?f:p)|0;G=r+(E?v:q)|0;E=z+1|0;if((E|0)<(u|0)){r=G;x=F;y=y+o|0;z=E;A=A+j|0}else{break}}H=G;I=F;J=l+(ca(o,u)|0)|0;K=i+w|0}else{H=n;I=m;J=s;K=t}if(d){L=_q(b,h,e)|0;return L|0}d=(k|0)/2|0;k=H;t=I;s=J;m=K;n=d;while(1){a[m]=a[s]|0;a[m+1|0]=a[t]|0;a[m+2|0]=a[s+1|0]|0;a[m+3|0]=a[k]|0;w=n-1|0;if((w|0)==0){break}else{k=k+1|0;t=t+1|0;s=s+2|0;m=m+4|0;n=w}}n=H+q|0;q=I+p|0;p=J+o|0;o=K+j|0;j=d;while(1){a[o]=a[p]|0;a[o+1|0]=a[q]|0;a[o+2|0]=a[p+1|0]|0;a[o+3|0]=a[n]|0;d=j-1|0;if((d|0)==0){break}else{n=n+1|0;q=q+1|0;p=p+2|0;o=o+4|0;j=d}}L=_q(b,h,e)|0;return L|0}function MA(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;if((f+1|0)>>>0<3>>>0){return}h=e;e=d;d=c;c=b;b=(f|0)/2|0;while(1){a[c]=a[d]|0;a[c+1|0]=a[e]|0;a[c+2|0]=a[d+1|0]|0;a[c+3|0]=a[h]|0;f=b-1|0;if((f|0)==0){break}else{h=h+1|0;e=e+1|0;d=d+2|0;c=c+4|0;b=f}}return}function NA(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0;if((g+1|0)>>>0<3>>>0){return}j=h<<1;h=i<<1;i=f;f=e;e=c;c=b;b=(g|0)/2|0;while(1){a[c]=a[e]|0;a[c+1|0]=(((d[f]|0)*7|0)+(d[f+j|0]|0)|0)>>>3;a[c+2|0]=a[e+1|0]|0;a[c+3|0]=(((d[i]|0)*7|0)+(d[i+h|0]|0)|0)>>>3;g=b-1|0;if((g|0)==0){break}else{i=i+1|0;f=f+1|0;e=e+2|0;c=c+4|0;b=g}}return}function OA(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0;if((g+1|0)>>>0<3>>>0){return}j=h<<1;h=i<<1;i=f;f=e;e=c;c=b;b=(g|0)/2|0;while(1){a[c]=a[e]|0;a[c+1|0]=(((d[f]|0)*5|0)+((d[f+j|0]|0)*3|0)|0)>>>3;a[c+2|0]=a[e+1|0]|0;a[c+3|0]=(((d[i]|0)*5|0)+((d[i+h|0]|0)*3|0)|0)>>>3;g=b-1|0;if((g|0)==0){break}else{i=i+1|0;f=f+1|0;e=e+2|0;c=c+4|0;b=g}}return}function PA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0.0;d=i;c[a+4>>2]=28;c[a+20>>2]=14;c[a+16>>2]=664;c[a+12>>2]=714;c[a+32>>2]=402;c[a+8>>2]=430;e=Pqc(20)|0;f=e;g=a+300|0;c[g>>2]=f;mrc(e|0,0,20)|0;do{if((b|0)==0){h=f}else{Bd(b|0,2275032,(a=i,i=i+16|0,c[a>>2]=e,c[a+8>>2]=e+4,a)|0)|0;i=a;a=c[g>>2]|0;if((c[a>>2]|0)>=0){h=a;break}c[a>>2]=0;h=a}}while(0);g=0;do{j=(g|0)<1?1.0:+(g|0);e=0;do{c[3661368+(g<<6)+(e<<2)>>2]=~~(j*((e&1|0)!=0?3.16227766017:2.0)*((e&4|0)!=0?3.16227766017:2.0)*4.0+-1.0);e=e+1|0;}while((e|0)<16);g=g+1|0;}while((g|0)<99);g=c[h+4>>2]|0;if((g|0)==1){c[169982]=526;i=d;return 1}else if((g|0)==0){c[169982]=616;i=d;return 1}else{c[169982]=588;i=d;return 1}return 0}function QA(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=b+31&-16;j=a+300|0;c[(c[j>>2]|0)+12>>2]=i;k=hJb(ca(i,d+31&-16|8)|0)|0;c[(c[j>>2]|0)+16>>2]=k;return $q(a,b,d,e,f,g,h)|0}function RA(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;if((c[b>>2]&8192|0)==0){e=Zq(c[a+292>>2]|0,c[b+16>>2]|0,2,24,c[b+20>>2]|0,c[b+24>>2]|0)|0;Wq(e,b);f=e}else{f=c[a+296>>2]|0}e=a+300|0;g=c[e>>2]|0;c[g+8>>2]=c[b+92>>2];h=b+76|0;i=c[h>>2]|0;do{if((i|0)==0){if((c[g>>2]|0)!=0){break}j=c[f+44>>2]|0;k=c[b+44>>2]|0;l=b+36|0;m=c[l>>2]|0;n=b+40|0;o=c[n>>2]|0;p=c[f+60>>2]|0;q=c[b+60>>2]|0;do{if((p|0)==(q|0)){if((p|0)<0){r=ca(o-1|0,p)|0;s=j+r|0;t=k+r|0;u=-p|0}else{s=j;t=k;u=p}nrc(s|0,t|0,ca(u,o)|0)|0}else{if((o|0)>0){v=k;w=0;x=j}else{break}while(1){nrc(x|0,v|0,m)|0;r=w+1|0;if((r|0)<(o|0)){v=v+q|0;w=r;x=x+p|0}else{break}}}}while(0);p=c[f+48>>2]|0;q=c[b+48>>2]|0;o=b+108|0;m=c[l>>2]>>c[o>>2];j=b+112|0;k=c[n>>2]>>c[j>>2];r=c[f+64>>2]|0;y=c[b+64>>2]|0;do{if((r|0)==(y|0)){if((r|0)<0){z=ca(k-1|0,r)|0;A=p+z|0;B=q+z|0;C=-r|0}else{A=p;B=q;C=r}nrc(A|0,B|0,ca(C,k)|0)|0}else{if((k|0)>0){D=q;E=0;F=p}else{break}while(1){nrc(F|0,D|0,m)|0;z=E+1|0;if((z|0)<(k|0)){D=D+y|0;E=z;F=F+r|0}else{break}}}}while(0);r=c[f+52>>2]|0;y=c[b+52>>2]|0;k=c[l>>2]>>c[o>>2];m=c[n>>2]>>c[j>>2];p=c[f+68>>2]|0;q=c[b+68>>2]|0;if((p|0)==(q|0)){if((p|0)<0){z=ca(m-1|0,p)|0;G=r+z|0;H=y+z|0;I=-p|0}else{G=r;H=y;I=p}nrc(G|0,H|0,ca(I,m)|0)|0;J=_q(a,f,d)|0;return J|0}else{if((m|0)>0){K=y;L=0;M=r}else{J=_q(a,f,d)|0;return J|0}while(1){nrc(M|0,K|0,k)|0;r=L+1|0;if((r|0)<(m|0)){K=K+q|0;L=r;M=M+p|0}else{break}}J=_q(a,f,d)|0;return J|0}}}while(0);M=b+36|0;L=b+40|0;K=b+80|0;ZA(g,c[f+44>>2]|0,c[b+44>>2]|0,c[f+60>>2]|0,c[b+60>>2]|0,c[M>>2]|0,c[L>>2]|0,i,c[K>>2]|0,1);i=b+108|0;g=b+112|0;ZA(c[e>>2]|0,c[f+48>>2]|0,c[b+48>>2]|0,c[f+64>>2]|0,c[b+64>>2]|0,c[M>>2]>>c[i>>2],c[L>>2]>>c[g>>2],c[h>>2]|0,c[K>>2]|0,0);ZA(c[e>>2]|0,c[f+52>>2]|0,c[b+52>>2]|0,c[f+68>>2]|0,c[b+68>>2]|0,c[M>>2]>>c[i>>2],c[L>>2]>>c[g>>2],c[h>>2]|0,c[K>>2]|0,0);J=_q(a,f,d)|0;return J|0}function SA(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=b|0;f=c[e>>2]|0;if((f&1|0)!=0){return}g=b+20|0;h=Zq(c[a+292>>2]|0,c[b+16>>2]|0,d[b+4|0]|0,f|2,c[g>>2]|0,c[b+24>>2]|0)|0;f=a+296|0;c[f>>2]=h;c[b+44>>2]=c[h+44>>2];h=c[f>>2]|0;c[b+60>>2]=c[h+60>>2];c[g>>2]=c[h+20>>2];g=c[e>>2]|0;if((g&256|0)!=0){c[b+48>>2]=c[h+48>>2];c[b+52>>2]=c[(c[f>>2]|0)+52>>2];h=c[f>>2]|0;c[b+64>>2]=c[h+64>>2];c[b+68>>2]=c[h+68>>2]}c[e>>2]=g|8192;return}function TA(a,b){a=a|0;b=b|0;var c=0;if((b|0)==961893977|(b|0)==959465033|(b|0)==842094169|(b|0)==808596553|(b|0)==1448433993|(b|0)==1280330819|(b|0)==808466521|(b|0)==538982489|(b|0)==1345598516|(b|0)==1345466932|(b|0)==1345401140){c=Yq(a,b)|0}else{c=0}return c|0}function UA(a){a=a|0;var b=0;b=a+300|0;a=c[b>>2]|0;if((a|0)==0){return}kJb(c[a+16>>2]|0);c[(c[b>>2]|0)+16>>2]=0;Qqc(c[b>>2]|0);c[b>>2]=0;return}function VA(a,b,c){a=a|0;b=b|0;c=c|0;return ar(a,b,c)|0}function WA(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b[a>>1]<<12;f=1;while(1){g=c[3661368+(d<<6)+(f<<2)>>2]|0;h=b[a+(f<<1)>>1]|0;if((h+g|0)>>>0>g<<1>>>0){i=(ca(c[1486888+(f<<2)>>2]|0,h)|0)+e|0}else{i=e}h=f+1|0;if((h|0)<16){e=i;f=h}else{break}}return i+2048>>12|0}function XA(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b[a>>1]<<12;f=1;while(1){g=c[3661368+(d<<6)+(f<<2)>>2]|0;h=b[a+(f<<1)>>1]|0;i=h<<16>>16;j=i+g|0;do{if(j>>>0>g<<1>>>0){if(h<<16>>16>0){k=(ca(c[1486888+(f<<2)>>2]|0,i-g|0)|0)+e|0;break}else{k=(ca(c[1486888+(f<<2)>>2]|0,j)|0)+e|0;break}}else{k=e}}while(0);j=f+1|0;if((j|0)<16){e=k;f=j}else{break}}return k+2048>>12|0}function YA(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b[a>>1]<<12;f=1;while(1){g=c[3661368+(d<<6)+(f<<2)>>2]|0;h=g<<1;i=b[a+(f<<1)>>1]|0;j=i<<16>>16;k=j+g|0;do{if(k>>>0>h>>>0){if((j+h|0)>>>0>g<<2>>>0){l=(ca(c[1486888+(f<<2)>>2]|0,j)|0)+e|0;break}if(i<<16>>16>0){l=(ca(j-g<<1,c[1486888+(f<<2)>>2]|0)|0)+e|0;break}else{l=(ca(k<<1,c[1486888+(f<<2)>>2]|0)|0)+e|0;break}}else{l=e}}while(0);k=f+1|0;if((k|0)<16){e=l;f=k}else{break}}return l+2048>>12|0}function ZA(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;if((n|0)==0){o=j+31&-16}else{o=c[e+12>>2]|0}p=c[e+16>>2]|0;q=o<<3;r=p;s=p+32|0;if((g|0)==0|(f|0)==0){return}t=(k|0)>0;if(t){u=q+8|0;v=q-1|0;w=0;do{x=u+(ca(w,o)|0)|0;y=x+q|0;z=p+y|0;nrc(z|0,g+(ca(w,i)|0)|0,j)|0;A=v+x|0;B=x+j|0;x=v+B|0;C=B+q|0;a[p+A|0]=a[z]|0;a[p+C|0]=a[p+x|0]|0;a[p+(A-1)|0]=a[p+(y+1)|0]|0;a[p+(C+1)|0]=a[p+(x-1)|0]|0;a[p+(A-2)|0]=a[p+(y+2)|0]|0;a[p+(C+2)|0]=a[p+(x-2)|0]|0;a[p+(A-3)|0]=a[p+(y+3)|0]|0;a[p+(C+3)|0]=a[p+(x-3)|0]|0;a[p+(A-4)|0]=a[p+(y+4)|0]|0;a[p+(C+4)|0]=a[p+(x-4)|0]|0;a[p+(A-5)|0]=a[p+(y+5)|0]|0;a[p+(C+5)|0]=a[p+(x-5)|0]|0;a[p+(A-6)|0]=a[p+(y+6)|0]|0;a[p+(C+6)|0]=a[p+(x-6)|0]|0;a[p+(A-7)|0]=a[p+(y+7)|0]|0;a[p+(C+7)|0]=a[p+(x-7)|0]|0;w=w+1|0;}while((w|0)<(k|0))}w=k+8|0;v=k+7|0;i=0;do{nrc(p+((ca(7-i|0,o)|0)+q)|0,p+((ca(i+8|0,o)|0)+q)|0,o)|0;nrc(p+((ca(w+i|0,o)|0)+q)|0,p+((ca(v-i|0,o)|0)+q)|0,o)|0;i=i+1|0;}while((i|0)<8);if(!t){return}t=q+13|0;i=o*6|0;v=o*5|0;w=o<<1;g=o<<2;u=o*3|0;x=(j|0)>0;C=n+3|0;n=e|0;y=j-1|0;A=k-1|0;z=e+8|0;e=~j;B=0;do{D=ca(B+5|0,o)|0;E=0;F=p+((q|5)+D)|0;G=s;while(1){H=(d[F+i|0]|0)+(d[F]|0)|0;I=(d[F+v|0]|0)+(d[F+o|0]|0)|0;J=(d[F+g|0]|0)+(d[F+w|0]|0)|0;K=d[F+u|0]<<1;L=K-H|0;M=K+H|0;H=J+I|0;K=J-I|0;b[G>>1]=M+H;b[G+4>>1]=M-H;b[G+2>>1]=(L<<1)+K;b[G+6>>1]=L-(K<<1);K=E+1|0;if((K|0)<4){E=K;F=F+1|0;G=G+8|0}else{break}}G=0;F=p+(q+9+D)|0;E=p+64|0;while(1){K=(d[F+i|0]|0)+(d[F]|0)|0;L=(d[F+v|0]|0)+(d[F+o|0]|0)|0;H=(d[F+g|0]|0)+(d[F+w|0]|0)|0;M=d[F+u|0]<<1;I=M-K|0;J=M+K|0;K=H+L|0;M=H-L|0;b[E>>1]=J+K;b[E+4>>1]=J-K;b[E+2>>1]=(I<<1)+M;b[E+6>>1]=I-(M<<1);M=G+1|0;if((M|0)<4){G=M;F=F+1|0;E=E+8|0}else{break}}if(x){E=ca(((B|0)<(A|0)?B:A)>>C,m)|0;F=B&7;G=ca(B,h)|0;M=0;while(1){I=M+8|0;K=(I|0)<(j|0)?I:j;I=c[n>>2]|0;do{if((I|0)==0){J=d[l+((((M|0)<(y|0)?M:y)>>C)+E)|0]|0;L=c[z>>2]|0;if((L|0)==1){N=J>>>1;break}else if((L|0)==3){N=65-J>>2;break}else if((L|0)==2){N=J>>>2;break}else{N=J;break}}else{N=I}}while(0);if((M|0)<(K|0)){I=-9-M|0;J=(I|0)<(e|0)?e:I;I=M;do{L=I<<2;H=s+(L<<1)|0;if((I&3|0)==0){O=0;P=p+(t+I+D)|0;Q=s+(L+32<<1)|0;while(1){L=(d[P+i|0]|0)+(d[P]|0)|0;R=(d[P+v|0]|0)+(d[P+o|0]|0)|0;S=(d[P+g|0]|0)+(d[P+w|0]|0)|0;T=d[P+u|0]<<1;U=T-L|0;V=T+L|0;L=S+R|0;T=S-R|0;b[Q>>1]=V+L;b[Q+4>>1]=V-L;b[Q+2>>1]=(U<<1)+T;b[Q+6>>1]=U-(T<<1);T=O+1|0;if((T|0)<4){O=T;P=P+1|0;Q=Q+8|0}else{W=0;X=H;Y=r;break}}}else{W=0;X=H;Y=r}while(1){Q=(b[X+48>>1]|0)+(b[X>>1]|0)|0;P=(b[X+40>>1]|0)+(b[X+8>>1]|0)|0;O=(b[X+32>>1]|0)+(b[X+16>>1]|0)|0;T=b[X+24>>1]<<1;U=T-Q|0;L=T+Q|0;Q=O+P|0;T=O-P|0;b[Y>>1]=L+Q;b[Y+16>>1]=L-Q;b[Y+8>>1]=(U<<1)+T;b[Y+24>>1]=U-(T<<1);T=W+1|0;if((T|0)<4){W=T;X=X+2|0;Y=Y+2|0}else{break}}H=We[c[169982]&2047](r,N)|0;T=(d[(I&7)+(1532112+(F<<3))|0]|0)+H>>6;if(T>>>0>255>>>0){Z=-T>>31&255}else{Z=T&255}a[f+(I+G)|0]=Z;I=I+1|0;}while((I|0)<(K|0));_=~J}else{_=M}if((_|0)<(j|0)){M=_}else{break}}}B=B+1|0;}while((B|0)<(k|0));return}function _A(a,b){a=a|0;b=b|0;c[a+4>>2]=42;c[a+20>>2]=12;c[a+32>>2]=390;c[a+44>>2]=1024;b=Rqc(1,24)|0;c[a+300>>2]=b;c[b>>2]=0;return 1}function $A(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return $q(a,b,c,d,e,f,g)|0}function aB(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;e=i;f=c[b+88>>2]|0;g=a+300|0;h=c[c[g>>2]>>2]|0;j=Zq(c[a+292>>2]|0,c[b+16>>2]|0,1,17,c[b+20>>2]|0,c[b+24>>2]|0)|0;k=(c[g>>2]|0)+8|0;l=wrc(c[k>>2]|0,c[k+4>>2]|0,1,0)|0;c[k>>2]=l;c[k+4>>2]=G;if((h|0)==0){if((f&2|0)==0){m=4}else{m=5}}else if((h|0)==1){if((f&2|0)==0){n=1}else{m=4}}else{n=h}if((m|0)==4){Uq(29,2,2226152,(k=i,i=i+24|0,c[k>>2]=h,c[k+8>>2]=f>>>1&1,c[k+16>>2]=f>>>2&1,k)|0);i=k;if((h|0)==1){m=5}else{n=h^1}}if((m|0)==5){m=_q(a,b,-9223372036854776000.0)|0;h=(c[g>>2]|0)+16|0;k=wrc(c[h>>2]|0,c[h+4>>2]|0,1,0)|0;c[h>>2]=k;c[h+4>>2]=G;if((f&4|0)==0){o=0;p=m;q=c[g>>2]|0;r=q|0;c[r>>2]=o;i=e;return p|0}h=c[b+36>>2]|0;k=c[b+40>>2]|0;l=(k|0)/2|0;s=c[j+60>>2]<<1;t=c[b+60>>2]<<1;if((k|0)>1){k=c[b+44>>2]|0;u=0;v=c[j+44>>2]|0;while(1){nrc(v|0,k|0,h)|0;w=u+1|0;if((w|0)<(l|0)){k=k+t|0;u=w;v=v+s|0}else{break}}}if((c[b>>2]&256|0)==0){o=1;p=m;q=c[g>>2]|0;r=q|0;c[r>>2]=o;i=e;return p|0}s=b+100|0;v=c[s>>2]|0;u=b+104|0;t=c[u>>2]|0;k=(t|0)/2|0;l=c[j+64>>2]<<1;h=c[b+64>>2]<<1;if((t|0)>1){w=c[b+48>>2]|0;x=0;y=c[j+48>>2]|0;while(1){nrc(y|0,w|0,v)|0;z=x+1|0;if((z|0)<(k|0)){w=w+h|0;x=z;y=y+l|0}else{break}}A=c[s>>2]|0;B=c[u>>2]|0}else{A=v;B=t}t=(B|0)/2|0;v=c[j+68>>2]<<1;u=c[b+68>>2]<<1;if((B|0)<=1){o=1;p=m;q=c[g>>2]|0;r=q|0;c[r>>2]=o;i=e;return p|0}B=c[b+52>>2]|0;s=0;l=c[j+52>>2]|0;while(1){nrc(l|0,B|0,A)|0;y=s+1|0;if((y|0)<(t|0)){B=B+u|0;s=y;l=l+v|0}else{o=1;p=m;break}}q=c[g>>2]|0;r=q|0;c[r>>2]=o;i=e;return p|0}m=j+44|0;v=j+60|0;l=c[v>>2]|0;s=b+44|0;u=b+60|0;B=c[u>>2]|0;t=b+36|0;A=c[t>>2]|0;y=b+40|0;x=c[y>>2]|0;h=(x|0)/2|0;w=l<<1;k=B<<1;if((x|0)>1){x=(c[s>>2]|0)+B|0;B=0;z=(c[m>>2]|0)+l|0;while(1){nrc(z|0,x|0,A)|0;l=B+1|0;if((l|0)<(h|0)){x=x+k|0;B=l;z=z+w|0}else{break}}}w=b|0;do{if((c[w>>2]&256|0)!=0){z=c[j+64>>2]|0;B=c[b+64>>2]|0;k=b+100|0;x=c[k>>2]|0;h=b+104|0;A=c[h>>2]|0;l=(A|0)/2|0;C=z<<1;D=B<<1;if((A|0)>1){E=(c[b+48>>2]|0)+B|0;B=0;F=(c[j+48>>2]|0)+z|0;while(1){nrc(F|0,E|0,x)|0;z=B+1|0;if((z|0)<(l|0)){E=E+D|0;B=z;F=F+C|0}else{break}}H=c[k>>2]|0;I=c[h>>2]|0}else{H=x;I=A}C=c[j+68>>2]|0;F=c[b+68>>2]|0;B=(I|0)/2|0;D=C<<1;E=F<<1;if((I|0)<=1){break}l=(c[b+52>>2]|0)+F|0;F=0;z=(c[j+52>>2]|0)+C|0;while(1){nrc(z|0,l|0,H)|0;C=F+1|0;if((C|0)<(B|0)){l=l+E|0;F=C;z=z+D|0}else{break}}}}while(0);H=_q(a,j,-9223372036854776000.0)|0;I=(c[g>>2]|0)+16|0;D=wrc(c[I>>2]|0,c[I+4>>2]|0,1,0)|0;c[I>>2]=D;c[I+4>>2]=G;if((f&4|0)!=0){f=_q(a,b,-9223372036854776000.0)|0|H;a=(c[g>>2]|0)+16|0;I=wrc(c[a>>2]|0,c[a+4>>2]|0,1,0)|0;c[a>>2]=I;c[a+4>>2]=G;o=0;p=f;q=c[g>>2]|0;r=q|0;c[r>>2]=o;i=e;return p|0}f=c[t>>2]|0;t=c[y>>2]|0;y=(t|0)/2|0;a=c[v>>2]<<1;v=c[u>>2]<<1;if((t|0)>1){t=c[s>>2]|0;s=0;u=c[m>>2]|0;while(1){nrc(u|0,t|0,f)|0;m=s+1|0;if((m|0)<(y|0)){t=t+v|0;s=m;u=u+a|0}else{break}}}if((c[w>>2]&256|0)==0){o=n;p=H;q=c[g>>2]|0;r=q|0;c[r>>2]=o;i=e;return p|0}w=b+100|0;a=c[w>>2]|0;u=b+104|0;s=c[u>>2]|0;v=(s|0)/2|0;t=c[j+64>>2]<<1;y=c[b+64>>2]<<1;if((s|0)>1){f=c[b+48>>2]|0;m=0;I=c[j+48>>2]|0;while(1){nrc(I|0,f|0,a)|0;D=m+1|0;if((D|0)<(v|0)){f=f+y|0;m=D;I=I+t|0}else{break}}J=c[w>>2]|0;K=c[u>>2]|0}else{J=a;K=s}s=(K|0)/2|0;a=c[j+68>>2]<<1;u=c[b+68>>2]<<1;if((K|0)<=1){o=n;p=H;q=c[g>>2]|0;r=q|0;c[r>>2]=o;i=e;return p|0}K=c[b+52>>2]|0;b=0;w=c[j+52>>2]|0;while(1){nrc(w|0,K|0,J)|0;j=b+1|0;if((j|0)<(s|0)){K=K+u|0;b=j;w=w+a|0}else{o=n;p=H;break}}q=c[g>>2]|0;r=q|0;c[r>>2]=o;i=e;return p|0}function bB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+300|0;a=c[d>>2]|0;e=a+8|0;f=c[e+4>>2]|0;g=a+16|0;a=c[g>>2]|0;h=c[g+4>>2]|0;Uq(29,4,2274984,(g=i,i=i+32|0,c[g>>2]=c[e>>2],c[g+8>>2]=f,c[g+16>>2]=a,c[g+24>>2]=h,g)|0);i=g;Qqc(c[d>>2]|0);i=b;return}function cB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;c[e>>2]=-1;c[a+4>>2]=126;c[a+20>>2]=4;c[a+16>>2]=510;c[a+12>>2]=332;c[a+32>>2]=532;c[a+8>>2]=60;f=Pqc(1092)|0;g=a+300|0;c[g>>2]=f;mrc(f|0,0,1092)|0;Vq();f=c[g>>2]|0;c[f>>2]=4;if((b|0)!=0){Bd(b|0,2274968,(b=i,i=i+24|0,c[b>>2]=e,c[b+8>>2]=f+4,c[b+16>>2]=f+8,b)|0)|0;i=b}b=c[e>>2]|0;e=c[g>>2]|0;if(b>>>0<9>>>0){c[e>>2]=b}b=e+4|0;if((c[b>>2]|0)>=0){i=d;return 1}c[b>>2]=0;i=d;return 1}function dB(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;j=i;i=i+8|0;k=j|0;l=b5a(1397641047)|0;m=b+63&-32;n=d+63&-32;o=a+300|0;p=c[o>>2]|0;c[p+16>>2]=m;c[p+40>>2]=Pqc(ca(n<<1,m)|0)|0;p=c[o>>2]|0;c[p+28>>2]=Pqc(ca(c[p+16>>2]|0,n)|0)|0;p=m>>1;m=n>>1;q=c[o>>2]|0;c[q+20>>2]=p;r=ca(n,p)|0;c[q+44>>2]=Pqc(r)|0;q=c[o>>2]|0;c[q+32>>2]=Pqc(ca(c[q+20>>2]|0,m)|0)|0;q=c[o>>2]|0;c[q+24>>2]=p;c[q+48>>2]=Pqc(r)|0;r=c[o>>2]|0;c[r+36>>2]=Pqc(ca(c[r+24>>2]|0,m)|0)|0;if((1<<c[c[o>>2]>>2]|0)<=0){s=d+16|0;t=UHb()|0;u=c[o>>2]|0;v=u+1084|0;c[v>>2]=t;w=UHb()|0;x=c[o>>2]|0;y=x+1088|0;c[y>>2]=w;z=b*10|0;A=z+160|0;B=ca(A,s)|0;C=c[o>>2]|0;D=C+52|0;c[D>>2]=B;E=Pqc(B)|0;F=C+56|0;c[F>>2]=E;G=$q(a,b,d,e,f,g,h)|0;i=j;return G|0}m=b+16|0;r=d+16|0;q=0;while(1){c[k>>2]=0;p=mWa(0)|0;c[(c[o>>2]|0)+60+(q<<2)>>2]=p;c[p+120>>2]=m;c[p+124>>2]=r;c[p+104>>2]=1;c[p+108>>2]=25;c[p+136>>2]=300;c[p+156>>2]=0;c[p+140>>2]=0;c[p+88>>2]=524290;c[p+680>>2]=-2;c[p+80>>2]=123;MGb(k,2226120,2189312,0)|0;_4a(p,l,k)|0;OGb(k);p=q+1|0;if((p|0)<(1<<c[c[o>>2]>>2]|0)){q=p}else{s=r;break}}t=UHb()|0;u=c[o>>2]|0;v=u+1084|0;c[v>>2]=t;w=UHb()|0;x=c[o>>2]|0;y=x+1088|0;c[y>>2]=w;z=b*10|0;A=z+160|0;B=ca(A,s)|0;C=c[o>>2]|0;D=C+52|0;c[D>>2]=B;E=Pqc(B)|0;F=C+56|0;c[F>>2]=E;G=$q(a,b,d,e,f,g,h)|0;i=j;return G|0}function eB(e,f,g){e=e|0;f=f|0;g=+g;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;h=f|0;if((c[h>>2]&8192|0)==0){i=Zq(c[e+292>>2]|0,c[f+16>>2]|0,2,24,c[f+20>>2]|0,c[f+24>>2]|0)|0;Wq(i,f);j=i}else{j=c[e+296>>2]|0}i=c[e+300>>2]|0;k=i+12|0;c[k>>2]=c[f+92>>2];l=i|0;m=c[l>>2]|0;do{if((m|0)==0){if((c[h>>2]&8192|0)==0){break}n=_q(e,j,g)|0;return n|0}}while(0);h=c[f+76>>2]|0;do{if((h|0)==0){if((c[i+4>>2]|0)!=0){break}o=c[j+44>>2]|0;p=c[f+44>>2]|0;q=f+36|0;r=c[q>>2]|0;s=f+40|0;t=c[s>>2]|0;u=c[j+60>>2]|0;v=c[f+60>>2]|0;do{if((u|0)==(v|0)){if((u|0)<0){w=ca(t-1|0,u)|0;x=o+w|0;y=p+w|0;z=-u|0}else{x=o;y=p;z=u}nrc(x|0,y|0,ca(z,t)|0)|0}else{if((t|0)>0){A=p;B=0;C=o}else{break}while(1){nrc(C|0,A|0,r)|0;w=B+1|0;if((w|0)<(t|0)){A=A+v|0;B=w;C=C+u|0}else{break}}}}while(0);u=c[j+48>>2]|0;v=c[f+48>>2]|0;t=f+108|0;r=c[q>>2]>>c[t>>2];o=f+112|0;p=c[s>>2]>>c[o>>2];w=c[j+64>>2]|0;D=c[f+64>>2]|0;do{if((w|0)==(D|0)){if((w|0)<0){E=ca(p-1|0,w)|0;F=u+E|0;G=v+E|0;H=-w|0}else{F=u;G=v;H=w}nrc(F|0,G|0,ca(H,p)|0)|0}else{if((p|0)>0){I=v;J=0;K=u}else{break}while(1){nrc(K|0,I|0,r)|0;E=J+1|0;if((E|0)<(p|0)){I=I+D|0;J=E;K=K+w|0}else{break}}}}while(0);w=c[j+52>>2]|0;D=c[f+52>>2]|0;p=c[q>>2]>>c[t>>2];r=c[s>>2]>>c[o>>2];u=c[j+68>>2]|0;v=c[f+68>>2]|0;if((u|0)==(v|0)){if((u|0)<0){E=ca(r-1|0,u)|0;L=w+E|0;M=D+E|0;N=-u|0}else{L=w;M=D;N=u}nrc(L|0,M|0,ca(N,r)|0)|0;n=_q(e,j,g)|0;return n|0}else{if((r|0)>0){O=D;P=0;Q=w}else{n=_q(e,j,g)|0;return n|0}while(1){nrc(Q|0,O|0,p)|0;w=P+1|0;if((w|0)<(r|0)){O=O+v|0;P=w;Q=Q+u|0}else{break}}n=_q(e,j,g)|0;return n|0}}}while(0);Q=c[f+36>>2]|0;P=c[f+40>>2]|0;O=i+1084|0;N=0;do{M=(N|0)!=0|0;L=Q>>M;K=P>>M;J=c[i+16+(N<<2)>>2]|0;I=16>>>(M>>>0);M=f+44+(N<<2)|0;H=c[M>>2]|0;do{if((H|0)!=0){if((c[j+44+(N<<2)>>2]|0)==0){break}a:do{if((K|0)>0){G=i+28+(N<<2)|0;F=f+60+(N<<2)|0;if((I|0)>0){R=0;S=H}else{C=(ca(I,J)|0)+I|0;nrc((c[G>>2]|0)+C|0,H|0,L)|0;if((K|0)>1){T=1}else{break}while(1){C=(ca(T+I|0,J)|0)+I|0;nrc((c[G>>2]|0)+C|0,(c[M>>2]|0)+(ca(c[F>>2]|0,T)|0)|0,L)|0;C=T+1|0;if((C|0)<(K|0)){T=C}else{U=19;break a}}}while(1){C=(ca(R+I|0,J)|0)+I|0;nrc((c[G>>2]|0)+C|0,S+(ca(c[F>>2]|0,R)|0)|0,L)|0;B=C-1|0;A=C+L|0;z=A-1|0;y=0;x=0;while(1){u=c[G>>2]|0;a[u+(B+x)|0]=a[u+(y+C)|0]|0;u=c[G>>2]|0;a[u+(y+A)|0]=a[u+(z+x)|0]|0;u=y+1|0;v=~y;if((u|0)<(I|0)){y=u;x=v}else{break}}x=R+1|0;if((x|0)>=(K|0)){U=19;break a}R=x;S=c[M>>2]|0}}else{U=19}}while(0);do{if((U|0)==19){U=0;if((I|0)<=0){break}G=i+28+(N<<2)|0;F=I-1|0;x=K+I|0;y=K-1+I|0;z=0;A=0;while(1){C=c[G>>2]|0;nrc(C+(ca(F+A|0,J)|0)|0,C+(ca(z+I|0,J)|0)|0,J)|0;C=c[G>>2]|0;nrc(C+(ca(x+z|0,J)|0)|0,C+(ca(y+A|0,J)|0)|0,J)|0;C=z+1|0;B=~z;if((C|0)<(I|0)){z=C;A=B}else{break}}}}while(0);c[(c[O>>2]|0)+32+(N<<2)>>2]=J;mrc(c[i+40+(N<<2)>>2]|0,0,ca(J<<1,(I<<1)+K|0)|0)|0}}while(0);N=N+1|0;}while((N|0)<3);N=1<<m;m=c[i+4>>2]|0;if((m|0)==0){U=d[h]|0;h=c[k>>2]|0;if((h|0)==1){V=U>>>1}else if((h|0)==2){V=U>>>2}else if((h|0)==3){V=65-U>>2}else{V=U}U=c[O>>2]|0;c[U+168>>2]=V*118|0;W=U}else{U=c[O>>2]|0;c[U+168>>2]=m*118|0;W=U}b:do{if((N|0)>0){U=N-1|0;m=i+28|0;V=i+32|0;h=i+36|0;k=i+56|0;S=i+52|0;R=i+1088|0;T=i+16|0;f=i+40|0;K=(P|0)/2|0;I=(Q|0)/2|0;J=i+20|0;M=i+44|0;L=i+24|0;H=i+48|0;A=(P|0)<1|(Q|0)<1;z=(P|0)<2|(Q|0)<2;y=0;x=W;while(1){G=U+y|0;F=d[774832+(G<<1)|0]|0;B=d[774833+(G<<1)|0]|0;c[x>>2]=(c[m>>2]|0)+((ca(c[x+32>>2]|0,B)|0)+F);G=F>>>1;C=B>>>1;v=c[O>>2]|0;c[v+4>>2]=(c[V>>2]|0)+((ca(c[v+36>>2]|0,C)|0)+G);v=c[O>>2]|0;c[v+8>>2]=(c[h>>2]|0)+((ca(c[v+40>>2]|0,C)|0)+G);v=i+60+(y<<2)|0;h5a(c[v>>2]|0,c[k>>2]|0,c[S>>2]|0,c[O>>2]|0)|0;u=c[(c[v>>2]|0)+804>>2]|0;c[R>>2]=u;v=16-B|0;B=c[u+32>>2]|0;if(!A){r=16-F|0;F=c[u>>2]|0;p=c[T>>2]|0;o=c[f>>2]|0;s=0;do{t=ca(s+v|0,B)|0;q=ca(p,s)|0;w=0;do{D=o+(w+q<<1)|0;b[D>>1]=(b[D>>1]|0)+(d[F+(r+w+t)|0]|0);w=w+1|0;}while((w|0)<(Q|0));s=s+1|0;}while((s|0)<(P|0))}s=c[u+36>>2]|0;r=8-G+(ca(s,8-C|0)|0)|0;if(!z){F=c[u+40>>2]|0;o=c[u+8>>2]|0;p=c[u+4>>2]|0;B=c[J>>2]|0;v=c[M>>2]|0;w=c[L>>2]|0;t=c[H>>2]|0;q=0;do{D=ca(q,s)|0;E=ca(B,q)|0;X=ca(F,q)|0;Y=ca(w,q)|0;Z=0;do{_=r+Z|0;$=v+(Z+E<<1)|0;b[$>>1]=(b[$>>1]|0)+(d[p+(_+D)|0]|0);$=t+(Z+Y<<1)|0;b[$>>1]=(b[$>>1]|0)+(d[o+(_+X)|0]|0);Z=Z+1|0;}while((Z|0)<(I|0));q=q+1|0;}while((q|0)<(K|0))}q=y+1|0;if((q|0)>=(N|0)){aa=0;break b}y=q;x=c[O>>2]|0}}else{aa=0}}while(0);do{O=(aa|0)!=0|0;N=c[j+44+(aa<<2)>>2]|0;do{if((N|0)!=0){W=c[i+40+(aa<<2)>>2]|0;x=c[j+60+(aa<<2)>>2]|0;y=c[i+16+(aa<<2)>>2]|0;K=Q>>O;I=P>>O;H=8-(c[l>>2]|0)|0;if((I|0)<=0){break}L=(K|0)>0;M=0;do{J=M&7;if(L){z=ca(M,y)|0;f=d[1532048+(J<<3)|0]|0;T=ca(M,x)|0;A=d[1532049+(J<<3)|0]|0;R=d[1532050+(J<<3)|0]|0;S=d[1532051+(J<<3)|0]|0;k=d[1532052+(J<<3)|0]|0;h=d[1532053+(J<<3)|0]|0;V=d[1532054+(J<<3)|0]|0;m=d[1532055+(J<<3)|0]|0;J=0;do{U=J+z|0;q=(b[W+(U<<1)>>1]<<H)+f|0;o=q>>8;if((o&256|0)==0){ba=o&255}else{ba=(q>>31^255)&255}q=J+T|0;a[N+q|0]=ba;o=(b[W+(U+1<<1)>>1]<<H)+A|0;t=o>>8;if((t&256|0)==0){da=t&255}else{da=(o>>31^255)&255}a[N+(q+1)|0]=da;o=(b[W+(U+2<<1)>>1]<<H)+R|0;t=o>>8;if((t&256|0)==0){ea=t&255}else{ea=(o>>31^255)&255}a[N+(q+2)|0]=ea;o=(b[W+(U+3<<1)>>1]<<H)+S|0;t=o>>8;if((t&256|0)==0){fa=t&255}else{fa=(o>>31^255)&255}a[N+(q+3)|0]=fa;o=(b[W+(U+4<<1)>>1]<<H)+k|0;t=o>>8;if((t&256|0)==0){ga=t&255}else{ga=(o>>31^255)&255}a[N+(q+4)|0]=ga;o=(b[W+(U+5<<1)>>1]<<H)+h|0;t=o>>8;if((t&256|0)==0){ha=t&255}else{ha=(o>>31^255)&255}a[N+(q+5)|0]=ha;o=(b[W+(U+6<<1)>>1]<<H)+V|0;t=o>>8;if((t&256|0)==0){ia=t&255}else{ia=(o>>31^255)&255}a[N+(q+6)|0]=ia;o=(b[W+(U+7<<1)>>1]<<H)+m|0;U=o>>8;if((U&256|0)==0){ja=U&255}else{ja=(o>>31^255)&255}a[N+(q+7)|0]=ja;J=J+8|0;}while((J|0)<(K|0))}M=M+1|0;}while((M|0)<(I|0))}}while(0);aa=aa+1|0;}while((aa|0)<3);n=_q(e,j,g)|0;return n|0}function fB(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=b|0;f=c[e>>2]|0;if((f&1|0)!=0){return}g=b+20|0;h=Zq(c[a+292>>2]|0,c[b+16>>2]|0,d[b+4|0]|0,f|2,c[g>>2]|0,c[b+24>>2]|0)|0;f=a+296|0;c[f>>2]=h;c[b+44>>2]=c[h+44>>2];h=c[f>>2]|0;c[b+60>>2]=c[h+60>>2];c[g>>2]=c[h+20>>2];g=c[e>>2]|0;if((g&256|0)!=0){c[b+48>>2]=c[h+48>>2];c[b+52>>2]=c[(c[f>>2]|0)+52>>2];h=c[f>>2]|0;c[b+64>>2]=c[h+64>>2];c[b+68>>2]=c[h+68>>2]}c[e>>2]=g|8192;return}function gB(a,b){a=a|0;b=b|0;var c=0;if((b|0)==842094169|(b|0)==808596553|(b|0)==1448433993|(b|0)==808466521|(b|0)==538982489){c=Yq(a,b)|0}else{c=0}return c|0}function hB(a){a=a|0;var b=0,d=0;b=a+300|0;a=c[b>>2]|0;if((a|0)==0){return}Qqc(c[a+40>>2]|0);c[(c[b>>2]|0)+40>>2]=0;Qqc(c[(c[b>>2]|0)+28>>2]|0);c[(c[b>>2]|0)+28>>2]=0;Qqc(c[(c[b>>2]|0)+44>>2]|0);c[(c[b>>2]|0)+44>>2]=0;Qqc(c[(c[b>>2]|0)+32>>2]|0);c[(c[b>>2]|0)+32>>2]=0;Qqc(c[(c[b>>2]|0)+48>>2]|0);c[(c[b>>2]|0)+48>>2]=0;Qqc(c[(c[b>>2]|0)+36>>2]|0);c[(c[b>>2]|0)+36>>2]=0;a=0;d=c[b>>2]|0;do{mJb(d+60+(a<<2)|0);a=a+1|0;d=c[b>>2]|0}while((a|0)<256);Qqc(d);c[b>>2]=0;return}function iB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((b|0)==5){c[c[a+300>>2]>>2]=c[d>>2];e=1}else if((b|0)==4){e=8}else{e=ar(a,b,d)|0}return e|0}function jB(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0;n=i;o=Ixb(j,k,l,d,e,f,0,0,0,0)|0;if((o|0)==0){p=mKb(l)|0;l=mKb(f)|0;KIb(m,16,2224832,(m=i,i=i+48|0,c[m>>2]=p,c[m+8>>2]=j,c[m+16>>2]=k,c[m+24>>2]=l,c[m+32>>2]=d,c[m+40>>2]=e,m)|0);i=m;q=-22;Jxb(o);i=n;return q|0}m=sIb(a,b,d,e,f,16)|0;if((m|0)<0){q=m;Jxb(o);i=n;return q|0}hxb(o,g,h,0,k,a,b)|0;q=0;Jxb(o);i=n;return q|0}function kB(a,b,c,d,e){a=+a;b=+b;c=+c;d=+d;e=e|0;var f=0.0;f=c;c=d*+U(f);g[e>>2]=c;d=-0.0- +V(f);g[e+4>>2]=d;g[e+8>>2]=a;g[e+12>>2]=-0.0-d;g[e+16>>2]=c;g[e+20>>2]=b;g[e+24>>2]=0.0;g[e+28>>2]=0.0;g[e+32>>2]=1.0;return}function lB(b,c,d,e,f,h,i,j,k){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0,Q=0.0,R=0.0,S=0,T=0,U=0.0;if((j|0)==0){l=6}else if((j|0)==2){l=2}else if((j|0)==1){l=4}else{m=-22;return m|0}if((h|0)<=0){m=0;return m|0}j=(f|0)>0;n=i+4|0;o=i+8|0;p=i+12|0;q=i+16|0;r=i+20|0;s=h-1|0;t=+(s|0);u=f-1|0;v=+(u|0);w=u<<1;x=s<<1;y=(k|0)==1;z=0;A=0;while(1){a:do{if(j){B=+(z|0);C=ca(z,e)|0;D=ca(z,d)|0;if(y){E=0;while(1){F=+(E|0);G=a[b+(E+D)|0]|0;a[c+(E+C)|0]=Fe[l&7](+g[o>>2]+(F*+g[i>>2]+B*+g[n>>2]),+g[r>>2]+(F*+g[p>>2]+B*+g[q>>2]),b,f,h,d,G)|0;H=E+1|0;if((H|0)<(f|0)){E=H}else{I=G;break a}}}else{J=0;K=A}while(1){F=+(J|0);L=+g[o>>2]+(F*+g[i>>2]+B*+g[n>>2]);M=+g[r>>2]+(F*+g[p>>2]+B*+g[q>>2]);if((k|0)==2){if(M<0.0){N=0.0}else{N=M>t?t:M}if(L<0.0){O=0.0}else{O=L>v?v:L}P=a[b+(~~O+(ca(~~N,d)|0))|0]|0;Q=N;R=O}else if((k|0)==3){E=~~L;if(E>>>0>u>>>0){D=E;while(1){G=((D|0)>0?w:0)-D|0;if(G>>>0>u>>>0){D=G}else{S=G;break}}}else{S=E}F=+(S|0);D=~~M;if(D>>>0>s>>>0){G=D;while(1){H=((G|0)>0?x:0)-G|0;if(H>>>0>s>>>0){G=H}else{T=H;break}}}else{T=D}U=+(T|0);P=a[b+((ca(~~U,d)|0)+~~F)|0]|0;Q=U;R=F}else{P=K;Q=M;R=L}a[c+(J+C)|0]=Fe[l&7](R,Q,b,f,h,d,P)|0;G=J+1|0;if((G|0)<(f|0)){J=G;K=P}else{I=P;break}}}else{I=A}}while(0);C=z+1|0;if((C|0)<(h|0)){z=C;A=I}else{m=0;break}}return m|0}function mB(b,c,d,e,f,g,h){b=+b;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=~~(b+.5);do{if((i|0)<0){j=h}else{k=~~(c+.5);if((k|0)<0){j=h;break}if(!((i|0)<(e|0)&(k|0)<(f|0))){j=h;break}j=a[d+((ca(k,g)|0)+i)|0]|0}}while(0);return j|0}function nB(b,c,d,e,f,g,h){b=+b;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0;if(b<-1.0){i=h;return i|0}if(+(e|0)<b|c<-1.0){i=h;return i|0}if(+(f|0)<c){i=h;return i|0}j=~~b;k=j+1|0;l=~~c;m=l+1|0;do{if((m|k|0)<0){n=h}else{if(!((k|0)<(e|0)&(m|0)<(f|0))){n=h;break}n=a[d+((ca(m,g)|0)+k)|0]|0}}while(0);o=n&255;do{if((k|l|0)<0){p=h}else{if(!((k|0)<(e|0)&(l|0)<(f|0))){p=h;break}p=a[d+((ca(l,g)|0)+k)|0]|0}}while(0);n=p&255;do{if((m|j|0)<0){q=h}else{if(!((j|0)<(e|0)&(m|0)<(f|0))){q=h;break}q=a[d+((ca(m,g)|0)+j)|0]|0}}while(0);p=q&255;do{if((l|j|0)<0){r=h}else{if(!((j|0)<(e|0)&(l|0)<(f|0))){r=h;break}r=a[d+((ca(l,g)|0)+j)|0]|0}}while(0);s=b- +(j|0);t=c- +(l|0);u=+(m|0)-c;c=+(k|0)-b;i=~~(t*s*+(o|0)+s*u*+(n|0)+t*c*+(p|0)+c*u*+(r&255|0));return i|0}function oB(b,c,d,e,f,g,h){b=+b;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0;if(b<-1.0){i=h;return i|0}if(+(e|0)<b|c<-1.0){i=h;return i|0}if(+(f|0)<c){i=h;return i|0}j=~~b;k=j+1|0;l=~~c;m=l+1|0;do{if((m|k|0)<0){n=h}else{if(!((k|0)<(e|0)&(m|0)<(f|0))){n=h;break}n=a[d+((ca(m,g)|0)+k)|0]|0}}while(0);do{if((k|l|0)<0){o=h}else{if(!((k|0)<(e|0)&(l|0)<(f|0))){o=h;break}o=a[d+((ca(l,g)|0)+k)|0]|0}}while(0);do{if((m|j|0)<0){p=h}else{if(!((j|0)<(e|0)&(m|0)<(f|0))){p=h;break}p=a[d+((ca(m,g)|0)+j)|0]|0}}while(0);do{if((l|j|0)<0){q=h}else{if(!((j|0)<(e|0)&(l|0)<(f|0))){q=h;break}q=a[d+((ca(l,g)|0)+j)|0]|0}}while(0);r=+(k|0)-b;s=+(m|0)-c;t=1.0- +S(r*s);u=c- +(l|0);c=1.0- +S(r*u);r=b- +(j|0);b=1.0- +S(r*s);s=1.0- +S(r*u);i=~~((+(n&255|0)*t+ +(o&255|0)*c+ +(p&255|0)*b+ +(q&255|0)*s)/(t+c+b+s));return i|0}function pB(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a&-16776976|0)==872415312){f=je(a|0)|0}else{f=a}do{if((f&-268435201|0)==1342177332){a=f>>24;if((a|0)==80){g=8;h=0}else if((a|0)==81){g=16;h=0}else if((a|0)==82){g=10;h=0}else if((a|0)==83){g=9;h=0}else{g=8;h=1}a=f&16777215;if((a|0)==3289652){i=g;j=h;k=0;l=1;break}else if((a|0)==3223860){i=g;j=h;k=0;l=2;break}else if((a|0)==3421236){i=g;j=h;k=0;l=0;break}else if((a|0)==3159092){i=g;j=h;k=1;l=0;break}else if((a|0)==3158580){i=g;j=h;k=1;l=1;break}else{i=g;j=1;k=0;l=0;break}}else{if((f|0)==1093808692){i=8;j=0;k=0;l=1;break}else if((f|0)==1093677620|(f|0)==808596553|(f|0)==1448433993|(f|0)==842094169){i=8;j=0;k=1;l=1;break}else if((f|0)==1093940276){i=8;j=0;k=0;l=0;break}else if((f|0)==538982489|(f|0)==808466521){i=8;j=0;k=31;l=31;break}else if((f|0)==959465033|(f|0)==961893977){i=8;j=0;k=2;l=2;break}else{i=8;j=1;k=0;l=0;break}}}while(0);if((b|0)!=0){c[b>>2]=l}if((d|0)!=0){c[d>>2]=k}if((e|0)!=0){c[e>>2]=i}e=16>>>(l>>>0)>>k;if((f|0)==1093940276|(f|0)==1093808692|(f|0)==1093677620){m=e+16|0}else{m=e+8|0}e=ca(m,i+7>>3)|0;return((j|0)!=0?0:e)|0}function qB(){if(a[1998448]|0){return}a[1998448]=1;Z$();eH(1454824);dH(1454224);eH(1443344);dH(1444576);dH(1442440);dH(1442360);dH(1442280);eH(1437224);eH(1437056);dH(1437144);dH(1436976);dH(1434264);eH(1433960);dH(1434048);eH(1433056);dH(1433144);dH(1432456);dH(1432272);dH(1432088);dH(1432008);eH(1431336);dH(1431800);eH(1430400);dH(1430592);eH(1430232);dH(1430320);eH(1431200);eH(1428360);dH(1428448);eH(1427760);dH(1427848);eH(1427672);dH(1427592);dH(1427096);dH(1426136);dH(1425952);dH(1425376);dH(1425768);eH(1425208);dH(1425296);dH(1424816);dH(1424400);dH(1424632);dH(1424216);eH(1424048);dH(1424136);eH(1423728);dH(1423816);dH(1412880);dH(1412592);dH(1406120);eH(1405680);eH(1402984);dH(1403088);eH(1402784);dH(1402872);dH(1402312);eH(1401984);dH(1402072);eH(1399104);dH(1399296);dH(1398816);eH(1398440);dH(1398528);dH(1398360);eH(1396656);dH(1398280);dH(1393672);dH(1393408);dH(1393488);eH(1392544);dH(1393128);dH(1390928);eH(1390424);eH(1390160);dH(1390248);eH(1389992);dH(1390080);eH(1389128);dH(1389216);eH(1388648);dH(1388840);dH(1387424);eH(1387048);dH(1387240);dH(1386784);eH(1386696);eH(1386608);dH(1386424);eH(1385880);dH(1386136);eH(1385504);dH(1385696);dH(1385320);eH(1382600);dH(1382792);dH(1381760);eH(1380456);dH(1380544);eH(1379792);dH(1380136);eH(1378912);dH(1379312);eH(1375808);dH(1375944);eH(1375672);eH(1374936);dH(1375488);eH(1374744);dH(1374832);dH(1374560);eH(1374080);dH(1374168);dH(1372464);dH(1372280);dH(1372096);eH(1371824);dH(1371912);eH(1371656);dH(1371744);eH(1371488);dH(1371576);dH(1370872);dH(1367768);eH(1367680);eH(1367512);dH(1367600);eH(1367424);dH(1367344);dH(1367264);eH(1367096);dH(1367184);eH(1362040);dH(1362128);dH(1361440);eH(1360960);dH(1361048);dH(1360152);dH(1360072);dH(1359544);dH(1359464);eH(1359288);dH(1359376);eH(1358624);eH(1358824);dH(1358912);eH(1358992);dH(1356352);eH(1356080);dH(1356168);eH(1355600);dH(1355792);eH(1352424);dH(1352880);dH(1352296);eH(1352128);dH(1352216);eH(1351688);dH(1351776);eH(1350944);eH(1350464);dH(1350552);eH(1349856);dH(1348008);dH(1348088);eH(1346624);eH(1346536);eH(1346240);eH(1345504);eH(1345416);eH(1345120);eH(1345032);dH(1343376);eH(1343208);dH(1343296);dH(1343128);dH(1342944);eH(1342856);dH(1342672);dH(1342592);dH(1341144);dH(1340336);dH(1340256);dH(1339880);eH(1339e3);dH(1339088);eH(1339240);dH(1338584);dH(1338400);dH(1337384);dH(1337304);eH(1337216);eH(1336608);dH(1336896);dH(1335368);eH(1335184);dH(1335272);eH(1334616);dH(1334704);eH(1334472);dH(1334264);eH(1333368);dH(1333560);eH(1331176);dH(1331368);eH(1332032);dH(1332224);eH(1331656);dH(1331848);eH(1332784);dH(1332976);eH(1332408);dH(1332600);eH(1328464);dH(1328656);eH(1328088);dH(1328280);eH(1329632);dH(1329824);eH(1329048);dH(1329240);eH(1330800);dH(1330992);eH(1330216);dH(1330408);eH(1327504);dH(1327696);eH(1325416);dH(1325608);eH(1325040);dH(1325232);eH(1326168);dH(1326360);eH(1325792);dH(1325984);eH(1326920);dH(1327112);eH(1326544);dH(1326736);eH(1324664);dH(1324856);dH(1323536);dH(1323456);eH(1322048);dH(1321864);dH(1321784);dH(1321600);dH(1319496);eH(1317152);dH(1317344);dH(1316872);dH(1316792);dH(1316240);eH(1314208);dH(1314312);eH(1313624);dH(1314024);dH(1313544);dH(1313360);eH(1313192);dH(1313280);eH(1313104);dH(1311704);dH(1311520);dH(1307280);dH(1306688);eH(1306600);eH(1302536);dH(1306104);dH(1306024);dH(1305456);eH(1305184);dH(1305272);eH(1305096);dH(1305016);dH(1304624);eH(1304040);dH(1304128);eH(1303768);dH(1303856);eH(1303640);eH(1302944);dH(1303136);dH(1302656);dH(1302144);dH(1301960);eH(1297720);dH(1297808);dH(1292544);eH(1292016);dH(1292104);eH(1291824);eH(1291736);dH(1291408);dH(1291328);eH(1353064);dH(1278288);eH(1277968);dH(1278056);dH(1277264);dH(1276576);dH(1276904);eH(1275872);eH(1263832);dH(1266472);eH(1261808);dH(1261896);dH(1255824);dH(1255744);dH(1255352);eH(1255088);dH(1255200);dH(1250848);dH(1250664);eH(1249560);dH(1249744);eH(1249392);dH(1249480);dH(1249104);eH(1249016);eH(1248640);dH(1248728);dH(1245640);dH(1245560);eH(1245376);dH(1245480);eH(1245208);dH(1245296);dH(1245128);dH(1244632);dH(1243808);dH(1243312);dH(1242920);eH(1242416);dH(1242504);MC(1389296)|0;return}function rB(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,2659560,5)|0)==0;return(b?100:0)|0}function sB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+16|0;d=b|0;e=c[a+16>>2]|0;f=d|0;AD(e,f,6)|0;g=ZX(a,0)|0;if((g|0)==0){h=-12;i=b;return h|0}do{if((grc(f,2659560,6)|0)==0){a=c[g+8>>2]|0;c[a+52>>2]=1919770995;c[a+48>>2]=73728;c[a+412>>2]=8e3;j=a;k=8e3}else{AD(e,d+6|0,3)|0;if((grc(f,2659568,9)|0)==0){a=c[g+8>>2]|0;c[a+52>>2]=1651990899;c[a+48>>2]=73729;c[a+412>>2]=16e3;j=a;k=16e3;break}else{h=-1;i=b;return h|0}}}while(0);c[j+416>>2]=1;f=j+448|0;c[f>>2]=4;c[f+4>>2]=0;c[j+8>>2]=1;_X(g,64,1,k);h=0;i=b;return h|0}function tB(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+28|0;g=c[(c[c[f>>2]>>2]|0)+8>>2]|0;h=b+16|0;b=fD(c[h>>2]|0,0,0,1)|0;i=G;if((jD(c[h>>2]|0)|0)!=0){j=-5;return j|0}k=zD(c[h>>2]|0)|0;l=k>>>3&15;m=g+48|0;g=c[m>>2]|0;do{if((g|0)==73729){if((l-11|0)>>>0<3>>>0){j=-5}else{n=d[2019824+l|0]|0;break}return j|0}else if((g|0)==73728){n=(d[2019840+l|0]|0)+1|0}else{j=-5;return j|0}}while(0);if((K1(e,n)|0)!=0){j=-5;return j|0}c[(c[(c[c[f>>2]>>2]|0)+8>>2]|0)+72>>2]=n*400|0;c[e+32>>2]=0;f=e+64|0;c[f>>2]=b;c[f+4>>2]=i;i=e+24|0;a[c[i>>2]|0]=k;c[e+48>>2]=(c[m>>2]|0)==73728?160:320;m=n-1|0;if((AD(c[h>>2]|0,(c[i>>2]|0)+1|0,m)|0)==(m|0)){j=0;return j|0}P1(e);j=-5;return j|0}function uB(a){a=a|0;var b=0,d=0,e=0;b=c[a+16>>2]|0;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;c[a+12>>2]=0;a=c[d+48>>2]|0;if((a|0)==73728){dD(b,2659560,6)}else if((a|0)==73729){dD(b,2659568,9)}else{e=-1;return e|0}eD(b);e=0;return e|0}function vB(a,b){a=a|0;b=b|0;dD(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function wB(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==541478988){e=b+16|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)!=1296649793){break}e=b+20|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}e=b+22|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}else{f=100}return f|0}}while(0);f=0;return f|0}function xB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+12>>2]|0;e=d;f=c[a+16>>2]|0;hD(f,4,0)|0;if((DD(f)|0)!=256){QIb(a,2406376,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1163346256;i=b;return h|0}c[d>>2]=DD(f)|0;j=d+4|0;c[j>>2]=FD(f)|0;hD(f,2,0)|0;k=d+8|0;c[k>>2]=DD(f)|0;if((FD(f)|0)!=1296649793){h=-1094995529;i=b;return h|0}l=ZX(a,0)|0;if((l|0)==0){h=-12;i=b;return h|0}m=l+8|0;n=c[m>>2]|0;c[n+8>>2]=0;c[n+48>>2]=135;c[n+52>>2]=0;n=DD(f)|0;c[(c[m>>2]|0)+120>>2]=n;n=DD(f)|0;c[(c[m>>2]|0)+124>>2]=n;do{if((zD(f)|0)==0){hD(f,1,0)|0;if((zD(f)|0)!=0){c[j>>2]=(c[j>>2]|0)-1}hD(f,1,0)|0;if((zD(f)|0)!=0){break}if((zD(f)|0)!=1){break}hD(f,1,0)|0;if((zD(f)|0)!=1){break}hD(f,32,0)|0;n=l+64|0;c[n>>2]=FD(f)|0;c[n+4>>2]=0;_X(l,64,1,DD(f)|0);hD(f,58,0)|0;c[(c[m>>2]|0)+100>>2]=1152;n=pJb(1168)|0;c[(c[m>>2]|0)+96>>2]=n;n=c[m>>2]|0;o=c[n+96>>2]|0;if((o|0)==0){h=-12;i=b;return h|0}p=AD(f,o,c[n+100>>2]|0)|0;if((p|0)<0){h=p;i=b;return h|0}p=c[k>>2]|0;n=fD(f,p,(p|0)<0|0?-1:0,0)|0;p=n;if((p|0)<0){h=p;i=b;return h|0}p=d+12|0;n=0;do{c[p+(n*12|0)>>2]=DD(f)|0;c[p+(n*12|0)+4>>2]=DD(f)|0;c[p+(n*12|0)+8>>2]=DD(f)|0;n=n+1|0;}while((n|0)<256);a:do{if((c[j>>2]|0)==0){q=-541478725}else{n=0;b:while(1){p=c[e+12+(n*12|0)+4>>2]|0;do{if((p|0)!=0){o=c[e+12+(n*12|0)>>2]|0;if((o|0)>0){break}if((o|0)!=(-p|0)){break b}}}while(0);p=n+1|0;if((p|0)<256){n=p}else{q=-1094995529;break a}}c[d+3084>>2]=n;if((n|0)<0){h=n;i=b;return h|0}c[d+3088>>2]=-1;h=0;i=b;return h|0}}while(0);c[d+3084>>2]=q;h=q;i=b;return h|0}}while(0);QIb(a,2330760,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1163346256;i=b;return h|0}function yB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[a+12>>2]|0;e=d;f=a+16|0;a=c[f>>2]|0;if((jD(a)|0)!=0){g=-5;return g|0}h=d+3084|0;i=c[h>>2]|0;if((i|0)<0){g=i;return g|0}j=d+12|0;k=d+3088|0;l=d+8|0;m=d+4|0;d=i;i=c[k>>2]|0;a:while(1){n=j+(d*12|0)|0;if((i|0)<0){o=(d<<16|1536)+(c[l>>2]|0)|0;fD(a,o,(o|0)<0|0?-1:0,0)|0;o=j+(d*12|0)+4|0;hD(a,(c[o>>2]<<1)+8|0,0)|0;c[k>>2]=0;p=0;q=o}else{p=i;q=j+(d*12|0)+4|0}o=c[q>>2]|0;if(p>>>0<o>>>0){r=16;break}s=(c[n>>2]|0)+o|0;if((c[m>>2]|0)>>>0>s>>>0){t=0}else{u=-541478725;r=13;break}b:while(1){o=c[e+12+(t*12|0)+4>>2]|0;do{if((o|0)!=0){v=c[e+12+(t*12|0)>>2]|0;if((v|0)>(s|0)){break}if((v+o|0)>>>0>s>>>0){break b}}}while(0);o=t+1|0;if((o|0)<256){t=o}else{u=-1094995529;r=13;break a}}c[h>>2]=t;if((t|0)<0){g=t;r=20;break}c[k>>2]=-1;d=t;i=-1}if((r|0)==13){c[h>>2]=u;g=u;return g|0}else if((r|0)==16){u=fD(a,0,0,1)|0;i=(c[l>>2]|0)+1544+(c[h>>2]<<16)+(c[k>>2]<<1)|0;fD(a,i,(i|0)<0|0?-1:0,0)|0;i=DD(a)|0;h=u;fD(a,h,(h|0)<0|0?-1:0,0)|0;h=fX(c[f>>2]|0,b,i)|0;c[b+28>>2]=h;if((h|0)<0){g=h;return g|0}h=c[k>>2]|0;if((c[n>>2]|0)==(-h|0)){n=b+36|0;c[n>>2]=c[n>>2]|1;w=c[k>>2]|0}else{w=h}c[k>>2]=w+1;g=0;return g|0}else if((r|0)==20){return g|0}return 0}function zB(a){a=a|0;var b=0;b=(krc(c[a+4>>2]|0,2406360,8)|0)==0;return(b?100:0)|0}function AB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+16>>2]|0;FD(b)|0;FD(b)|0;FD(b)|0;d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}a=d+8|0;d=c[a>>2]|0;c[d+8>>2]=1;c[d+48>>2]=69661;FD(b)|0;d=FD(b)|0;f=c[a>>2]|0;c[f+412>>2]=d;if((QX(f,b,8)|0)<0){e=-12;return e|0}f=(FD(b)|0)==0;b=c[a>>2]|0;a=b+416|0;if(f){c[a>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;g=4}else{c[a>>2]=2;a=b+448|0;c[a>>2]=3;c[a+4>>2]=0;g=8}c[b+792>>2]=4;c[b+72>>2]=ca(g,c[b+412>>2]|0)|0;c[b+432>>2]=1;e=0;return e|0}function BB(a,b){a=a|0;b=b|0;var d=0;if((fX(c[a+16>>2]|0,b,4096)|0)<1){d=-5;return d|0}a=b+36|0;c[a>>2]=c[a>>2]&-3;c[b+32>>2]=0;d=0;return d|0}function CB(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=541278541){e=0;return e|0}a=b+4|0;e=(((d[a]|d[a+1|0]<<8)<<16>>16)-3800&65535)>>>0>190>>>0?25:100;return e|0}



function DB(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;h=c[f+16>>2]|0;j=c[f+12>>2]|0;k=fD(h,0,0,1)|0;l=j;c[l>>2]=k;if((FD(h)|0)!=541278541){m=-1094995529;i=g;return m|0}k=(DD(h)|0)&65535;n=j+24|0;b[n>>1]=k;if((k-3800&65535)>>>0>190>>>0){o=k<<16>>16;KIb(f,16,2274600,(p=i,i=i+16|0,c[p>>2]=(o|0)/1e3|0,c[p+8>>2]=((o|0)%1e3|0|0)/10|0,p)|0);i=p;m=-1163346256;i=g;return m|0}do{if(k<<16>>16>3979){b[j+26>>1]=DD(h)|0;o=j+28|0;c[o>>2]=FD(h)|0;c[j+32>>2]=FD(h)|0;c[j+36>>2]=FD(h)|0;c[j+40>>2]=FD(h)|0;c[j+44>>2]=FD(h)|0;c[j+48>>2]=FD(h)|0;c[j+52>>2]=FD(h)|0;AD(h,j+56|0,16)|0;q=c[o>>2]|0;if(q>>>0>52>>>0){hD(h,q-52|0,0)|0;}b[j+72>>1]=DD(h)|0;b[j+74>>1]=DD(h)|0;c[j+76>>2]=FD(h)|0;c[j+80>>2]=FD(h)|0;c[j+84>>2]=FD(h)|0;b[j+88>>1]=DD(h)|0;b[j+90>>1]=DD(h)|0;c[j+92>>2]=FD(h)|0}else{c[j+28>>2]=0;q=j+32|0;c[q>>2]=32;o=j+72|0;b[o>>1]=DD(h)|0;r=j+74|0;b[r>>1]=DD(h)|0;b[j+90>>1]=DD(h)|0;c[j+92>>2]=FD(h)|0;s=j+40|0;c[s>>2]=FD(h)|0;c[j+52>>2]=FD(h)|0;t=j+84|0;c[t>>2]=FD(h)|0;c[j+80>>2]=FD(h)|0;u=b[r>>1]|0;if((u&4)==0){v=u}else{hD(h,4,0)|0;c[q>>2]=(c[q>>2]|0)+4;v=b[r>>1]|0}if((v&16)==0){c[j+36>>2]=c[t>>2]<<2;w=v}else{t=FD(h)|0;c[q>>2]=(c[q>>2]|0)+4;c[j+36>>2]=t<<2;w=b[r>>1]|0}r=w&65535;do{if((r&1|0)==0){t=j+88|0;if((r&8|0)==0){b[t>>1]=16;break}else{b[t>>1]=24;break}}else{b[j+88>>1]=8}}while(0);r=b[n>>1]|0;a:do{if(r<<16>>16>3949){c[j+76>>2]=294912}else{do{if(!(r<<16>>16>3899)){if(r<<16>>16>3799){if((e[o>>1]|0)>>>0>3999>>>0){break}}c[j+76>>2]=9216;break a}}while(0);c[j+76>>2]=73728}}while(0);if(!((w&32)==0)){break}hD(h,c[s>>2]|0,0)|0;}}while(0);w=j+84|0;v=c[w>>2]|0;if((v|0)==0){KIb(f,16,2225664,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;m=-22;i=g;return m|0}if(v>>>0>134217727>>>0){KIb(f,16,2189168,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;m=-1094995529;i=g;return m|0}k=j+36|0;o=(c[k>>2]|0)>>>2;if(o>>>0<v>>>0){KIb(f,16,2159056,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=v,p)|0);i=p;m=-1094995529;i=g;return m|0}o=hJb(v<<5)|0;v=j+16|0;c[v>>2]=o;if((o|0)==0){m=-12;i=g;return m|0}o=c[k>>2]|0;r=(c[j+28>>2]|0)+(c[l>>2]|0)+(c[j+32>>2]|0)+o+(c[j+40>>2]|0)|0;t=j+4|0;c[t>>2]=r;q=c[w>>2]|0;if((b[n>>1]|0)<3810){c[t>>2]=q+r}c[j+12>>2]=0;r=j+80|0;u=c[r>>2]|0;x=j+8|0;c[x>>2]=u;if(q>>>0>1>>>0){c[x>>2]=(ca(c[j+76>>2]|0,q-1|0)|0)+u}do{if((o|0)!=0){u=pJb(o)|0;q=j+96|0;c[q>>2]=u;if((u|0)==0){m=-12;i=g;return m|0}u=h+52|0;b:do{if((c[k>>2]|0)>>>0>3>>>0){x=0;do{if((c[u>>2]|0)!=0){break b}z=FD(h)|0;c[(c[q>>2]|0)+(x<<2)>>2]=z;x=x+1|0;}while(x>>>0<(c[k>>2]|0)>>>2>>>0)}}while(0);c:do{if((b[n>>1]|0)<3810){q=pJb(c[w>>2]|0)|0;s=j+100|0;c[s>>2]=q;if((q|0)==0){m=-12;i=g;return m|0}if((c[w>>2]|0)==0){A=48;break}else{B=0}while(1){if((c[u>>2]|0)!=0){break c}q=(zD(h)|0)&255;a[(c[s>>2]|0)+B|0]=q;q=B+1|0;if(q>>>0<(c[w>>2]|0)>>>0){B=q}else{A=48;break}}}else{A=48}}while(0);if((A|0)==48){if((c[u>>2]|0)==0){break}}KIb(f,24,2133760,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);B=c[t>>2]|0;t=c[v>>2]|0;k=t|0;c[k>>2]=B;c[k+4>>2]=0;o=j+76|0;c[t+8>>2]=c[o>>2];c[t+16>>2]=0;s=c[w>>2]|0;if(s>>>0>1>>>0){q=c[j+96>>2]|0;x=1;z=B;while(1){B=(c[l>>2]|0)+(c[q+(x<<2)>>2]|0)|0;C=B;D=0;E=t+(x<<5)|0;c[E>>2]=C;c[E+4>>2]=D;c[t+(x<<5)+8>>2]=c[o>>2];c[t+(x-1<<5)+12>>2]=B-z;E=xrc(C,D,c[k>>2]|0,c[k+4>>2]|0)|0;c[t+(x<<5)+16>>2]=E&3;E=x+1|0;D=c[w>>2]|0;if(E>>>0<D>>>0){x=E;z=B}else{F=D;break}}}else{F=s}c[t+(F-1<<5)+8>>2]=c[r>>2];F=iD(h)|0;t=G;s=0;z=c[w>>2]|0;if((t|0)>(s|0)|(t|0)==(s|0)&F>>>0>0>>>0){s=c[v>>2]|0;x=s+(z-1<<5)|0;k=xrc(F,t,c[x>>2]|0,c[x+4>>2]|0)|0;x=xrc(k,G,c[j+52>>2]|0,0)|0;k=x&-4;if((k|0)<1){H=s;A=56}else{I=k;J=s}}else{H=c[v>>2]|0;A=56}if((A|0)==56){I=c[r>>2]<<3;J=H}c[J+(z-1<<5)+12>>2]=I;if((c[w>>2]|0)==0){K=0}else{I=0;while(1){z=c[J+(I<<5)+16>>2]|0;if((z|0)==0){L=J+(I<<5)+12|0}else{H=J+(I<<5)|0;A=xrc(c[H>>2]|0,c[H+4>>2]|0,z,(z|0)<0|0?-1:0)|0;c[H>>2]=A;c[H+4>>2]=G;H=J+(I<<5)+12|0;c[H>>2]=(c[H>>2]|0)+z;L=H}c[L>>2]=(c[L>>2]|0)+3&-4;H=I+1|0;z=c[w>>2]|0;if(H>>>0<z>>>0){I=H}else{K=z;break}}}I=b[n>>1]|0;if(!(I<<16>>16>3809|(K|0)==0)){L=j+100|0;z=0;H=K;while(1){do{if(z>>>0<(H-1|0)>>>0){K=z+1|0;A=c[L>>2]|0;if((a[A+K|0]|0)==0){M=A;N=K;break}s=J+(z<<5)+12|0;c[s>>2]=(c[s>>2]|0)+4;M=A;N=K}else{M=c[L>>2]|0;N=z+1|0}}while(0);u=J+(z<<5)+16|0;K=c[u>>2]<<3;c[u>>2]=K;c[u>>2]=K+(d[M+z|0]|0);K=c[w>>2]|0;if(N>>>0<K>>>0){z=N;H=K}else{break}}}H=I<<16>>16;I=j+72|0;N=e[I>>1]|0;KIb(f,48,2110240,(p=i,i=i+24|0,c[p>>2]=(H|0)/1e3|0,c[p+8>>2]=((H|0)%1e3|0|0)/10|0,c[p+16>>2]=N,p)|0);i=p;p=ZX(f,0)|0;if((p|0)==0){m=-12;i=g;return m|0}N=c[w>>2]|0;if((N|0)==0){O=0;P=0}else{H=ca(c[o>>2]|0,N-1|0)|0;N=H+(c[r>>2]|0)|0;O=(N|0)<0|0?-1:0;P=N}N=p+8|0;r=c[N>>2]|0;c[r+8>>2]=1;c[r+48>>2]=86049;c[r+52>>2]=541413441;c[r+416>>2]=e[j+90>>1]|0;H=j+92|0;c[r+412>>2]=c[H>>2];c[r+792>>2]=e[j+88>>1]|0;r=p+64|0;c[r>>2]=c[w>>2];c[r+4>>2]=0;r=p+48|0;c[r>>2]=0;c[r+4>>2]=0;r=p+56|0;c[r>>2]=P;c[r+4>>2]=O;_X(p,64,1,c[H>>2]|0);if((PX(c[N>>2]|0,6)|0)!=0){m=-12;i=g;return m|0}H=c[(c[N>>2]|0)+96>>2]|0;y=b[n>>1]|0;a[H]=y;y=y>>8;a[H+1|0]=y;H=(c[(c[N>>2]|0)+96>>2]|0)+2|0;y=b[I>>1]|0;a[H]=y;y=y>>8;a[H+1|0]=y;H=(c[(c[N>>2]|0)+96>>2]|0)+4|0;y=b[j+74>>1]|0;a[H]=y;y=y>>8;a[H+1|0]=y;if((c[w>>2]|0)!=0){H=0;j=0;N=0;while(1){I=c[v>>2]|0;n=I+(H<<5)+24|0;c[n>>2]=N;c[n+4>>2]=j;n=I+(H<<5)|0;xX(p,c[n>>2]|0,c[n+4>>2]|0,N,j,0,0,1)|0;n=wrc(c[o>>2]|0,0,N,j)|0;I=H+1|0;if(I>>>0<(c[w>>2]|0)>>>0){H=I;j=G;N=n}else{break}}}if((c[h+88>>2]|0)==0){m=0;i=g;return m|0}HB(f)|0;fD(h,0,0,0)|0;m=0;i=g;return m|0}function EB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[b+12>>2]|0;g=b+16|0;if((jD(c[g>>2]|0)|0)!=0){h=-541478725;i=e;return h|0}j=f+12|0;k=c[j>>2]|0;l=f+84|0;if(!(k>>>0<(c[l>>2]|0)>>>0)){h=-541478725;i=e;return h|0}m=f+16|0;n=(c[m>>2]|0)+(k<<5)|0;k=fD(c[g>>2]|0,c[n>>2]|0,c[n+4>>2]|0,0)|0;n=G;o=0;if((n|0)<(o|0)|(n|0)==(o|0)&k>>>0<0>>>0){h=-5;i=e;return h|0}k=c[j>>2]|0;o=c[((k|0)==((c[l>>2]|0)-1|0)?f+80|0:f+76|0)>>2]|0;f=c[(c[m>>2]|0)+(k<<5)+12>>2]|0;if((f|0)<1|f>>>0>2147483639>>>0){KIb(b,16,2330728,(b=i,i=i+8|0,c[b>>2]=f,b)|0);i=b;c[j>>2]=(c[j>>2]|0)+1;h=-5;i=e;return h|0}if((K1(d,f+8|0)|0)<0){h=-12;i=e;return h|0}f=d+24|0;b=c[f>>2]|0;y=o;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=(c[f>>2]|0)+4|0;y=c[(c[m>>2]|0)+(c[j>>2]<<5)+16>>2]|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=AD(c[g>>2]|0,(c[f>>2]|0)+8|0,c[(c[m>>2]|0)+(c[j>>2]<<5)+12>>2]|0)|0;if((b|0)<0){P1(d);h=b;i=e;return h|0}else{f=(c[m>>2]|0)+(c[j>>2]<<5)+24|0;m=c[f+4>>2]|0;g=d+8|0;c[g>>2]=c[f>>2];c[g+4>>2]=m;c[d+32>>2]=0;c[d+28>>2]=b+8;c[j>>2]=(c[j>>2]|0)+1;h=0;i=e;return h|0}return 0}function FB(a){a=a|0;var b=0;b=c[a+12>>2]|0;mJb(b+16|0);mJb(b+96|0);mJb(b+100|0);return 0}function GB(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[a+12>>2]|0;h=CX(g,d,e,f)|0;if((h|0)<0){i=-1;return i|0}f=(c[g+400>>2]|0)+(h*24|0)|0;g=fD(c[a+16>>2]|0,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=G;a=0;if((f|0)<(a|0)|(f|0)==(a|0)&g>>>0<0>>>0){i=-1;return i|0}c[b+12>>2]=h;i=0;return i|0}function HB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+2136|0;e=d|0;f=d+2048|0;g=b+16|0;h=c[g>>2]|0;j=iD(h)|0;k=G;l=0;if((k|0)<(l|0)|(k|0)==(l|0)&j>>>0<32>>>0){m=0;n=0;i=d;return(G=m,n)|0}l=wrc(j,k,-32,-1)|0;o=G;fD(h,l,o,0)|0;p=d+2128|0;AD(h,p,8)|0;if((krc(p,2218160,8)|0)!=0){m=0;n=0;i=d;return(G=m,n)|0}if((FD(h)|0)>>>0>2e3>>>0){KIb(b,16,2522104,(q=i,i=i+8|0,c[q>>2]=2e3,q)|0);i=q;m=0;n=0;i=d;return(G=m,n)|0}p=FD(h)|0;if((p-32|0)>>>0>16777216>>>0){KIb(b,16,2406248,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;m=0;n=0;i=d;return(G=m,n)|0}r=p;s=0;if((s|0)>(o|0)|(s|0)==(o|0)&r>>>0>l>>>0){KIb(b,16,2330664,(q=i,i=i+8|0,c[q>>2]=p,q)|0);i=q;m=0;n=0;i=d;return(G=m,n)|0}p=xrc(j,k,r,s)|0;s=G;r=wrc(p,s,-32,-1)|0;k=G;j=FD(h)|0;if(j>>>0>65536>>>0){KIb(b,16,2274496,(q=i,i=i+8|0,c[q>>2]=j,q)|0);i=q;m=0;n=0;i=d;return(G=m,n)|0}if(((FD(h)|0)&536870912|0)!=0){KIb(b,16,2225592,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;m=0;n=0;i=d;return(G=m,n)|0}fD(h,p,s,0)|0;s=e|0;p=d+1024|0;h=f;l=b+1140|0;o=b;t=0;while(1){if(!(t>>>0<j>>>0)){m=k;n=r;u=36;break}v=c[g>>2]|0;w=FD(v)|0;x=FD(v)|0;y=0;while(1){z=zD(v)|0;if((z-32|0)>>>0>94>>>0){A=y;break}a[e+y|0]=z;B=y+1|0;if(B>>>0<1023>>>0){y=B}else{A=B;break}}a[e+A|0]=0;do{if((z|0)==0){if((w|0)==-1){C=-1;break}if((x&2|0)==0){y=hJb(w+1|0)|0;if((y|0)==0){C=-12;break}B=AD(v,y,w)|0;if((B|0)<0){kJb(y);C=B;break}else{a[y+B|0]=0;MGb(l,s,y,8)|0;C=0;break}}y=ZX(b,0)|0;if((y|0)==0){C=-12;break}B=LD(v,w,p,1024)|0;D=w-B|0;if((w|0)==(B|0)){KIb(o,24,2110208,(q=i,i=i+8|0,c[q>>2]=s,q)|0);i=q;C=0;break}MGb(y+88|0,s,p,0)|0;B=nJ(p)|0;if((B|0)==0){E=y+8|0;if((QX(c[E>>2]|0,c[g>>2]|0,D)|0)<0){C=-12;break}c[(c[E>>2]|0)+8>>2]=4;C=0;break}E=fX(c[g>>2]|0,f,D)|0;if((E|0)<0){KIb(o,16,2627968,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=E;break}else{E=y+72|0;c[E>>2]=c[E>>2]|1024;E=c[y+8>>2]|0;c[E+8>>2]=0;c[E+48>>2]=B;nrc(y+104|0,h|0,80)|0;c[y+136>>2]=c[y>>2];B=y+140|0;c[B>>2]=c[B>>2]|1;C=0;break}}else{KIb(o,24,2133712,(q=i,i=i+8|0,c[q>>2]=s,q)|0);i=q;C=-1}}while(0);if((C|0)<0){m=k;n=r;u=36;break}else{t=t+1|0}}if((u|0)==36){i=d;return(G=m,n)|0}return 0}function IB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=0;c[f>>2]=0;g=_D(e)|0;do{if((g|0)>=0){kD(c[e>>2]|0,-536870912);cD(c[e>>2]|0,0,8);h=b+1140|0;j=LGb(c[h>>2]|0,10230136,0,2)|0;if((j|0)==0){break}k=b;l=0;m=j;a:while(1){j=m;while(1){n=j|0;o=c[n>>2]|0;while(1){p=a[o]|0;if((p-32&255)>>>0<95>>>0){o=o+1|0}else{break}}if(p<<24>>24==0){break}KIb(k,24,2159024,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;o=LGb(c[h>>2]|0,10230136,j,2)|0;if((o|0)==0){q=l;break a}else{j=o}}o=j+4|0;r=lrc(c[o>>2]|0)|0;kD(c[e>>2]|0,r);kD(c[e>>2]|0,0);mD(c[e>>2]|0,c[n>>2]|0)|0;dD(c[e>>2]|0,c[o>>2]|0,r);r=l+1|0;o=LGb(c[h>>2]|0,10230136,j,2)|0;if((o|0)==0){q=r;break}else{l=r;m=o}}if((q|0)==0){break}m=aE(c[e>>2]|0,f)|0;if((m|0)<1){break}l=m+20|0;h=b+16|0;dD(c[h>>2]|0,2218160,8);kD(c[h>>2]|0,2e3);kD(c[h>>2]|0,l);kD(c[h>>2]|0,q);dD(c[h>>2]|0,c[f>>2]|0,m);dD(c[h>>2]|0,2218160,8);kD(c[h>>2]|0,2e3);kD(c[h>>2]|0,l);kD(c[h>>2]|0,q);kD(c[h>>2]|0,-1073741824);cD(c[h>>2]|0,0,8)}}while(0);q=c[e>>2]|0;if((q|0)==0){s=f;mJb(s);i=d;return g|0}if((c[f>>2]|0)!=0){s=f;mJb(s);i=d;return g|0}aE(q,f)|0;s=f;mJb(s);i=d;return g|0}function JB(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=Bd(c[a+4>>2]|0,2189128,(a=i,i=i+8|0,c[a>>2]=b,a)|0)|0;i=a;i=b;return((d|0)==1?50:0)|0}function KB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+4104|0;e=d|0;f=d+8|0;g=c[b+12>>2]|0;h=ZX(b,0)|0;c[e>>2]=0;c[e+4>>2]=-2147483648;if((h|0)==0){j=-12;i=d;return j|0}_X(h,64,c[g+28>>2]|0,c[g+24>>2]|0);k=c[h+8>>2]|0;c[k+8>>2]=3;c[k+48>>2]=94210;k=b+16|0;b=f|0;h=g+4|0;g=0;l=0;a:while(1){m=0;n=1;b:while(1){do{if((jD(c[k>>2]|0)|0)!=0){o=16;break a}if((KD(c[k>>2]|0,b,4096)|0)==0){o=16;break a}a[f+(mc(b|0,2330608)|0)|0]=0;p=Bd(b|0,2274464,(q=i,i=i+8|0,c[q>>2]=e,q)|0)|0;i=q;if((p|0)==1){break b}}while((a[b]|0)==0);p=(n|0)!=0;if(!p){if((IV(h,2225568,1,1)|0)==0){j=-12;o=17;break a}}q=IV(h,b,lrc(b|0)|0,n^1)|0;if((q|0)==0){j=-12;o=17;break a}if(!p){m=q;n=0;continue}p=c[e+4>>2]|0;r=q+8|0;c[r>>2]=c[e>>2];c[r+4>>2]=p;c[q+48>>2]=-1;p=q+64|0;c[p>>2]=l;c[p+4>>2]=g;m=q;n=0}n=fD(c[k>>2]|0,0,0,1)|0;q=G;if((m|0)==0){g=q;l=n;continue}p=m+8|0;r=xrc(c[e>>2]|0,c[e+4>>2]|0,c[p>>2]|0,c[p+4>>2]|0)|0;c[m+48>>2]=r;g=q;l=n}if((o|0)==16){JV(h);j=0;i=d;return j|0}else if((o|0)==17){i=d;return j|0}return 0}function LB(a,b){a=a|0;b=b|0;return MV((c[a+12>>2]|0)+4|0,b)|0}function MB(a){a=a|0;OV((c[a+12>>2]|0)+4|0);return 0}function NB(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV((c[a+12>>2]|0)+4|0,a,b,d,e,f,g,h,i,j)|0}function OB(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,1431640,16)|0)==0;return(b?100:0)|0}function PB(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;f=i;i=i+1160|0;g=f|0;h=f+8|0;j=f+1032|0;k=f+1040|0;l=f+1056|0;m=f+1072|0;n=f+1152|0;o=e+12|0;p=c[o>>2]|0;q=e+16|0;r=c[q>>2]|0;MS(r,l)|0;s=l|0;if((grc(s,1431640,16)|0)!=0){t=-1094995529;i=f;return t|0}GD(r)|0;FD(r)|0;zD(r)|0;zD(r)|0;u=p+4|0;mrc(u|0,-1|0,512)|0;v=p+520|0;w=0;do{b[v+(w*1216|0)+144>>1]=128;w=w+1|0;}while((w|0)<128);w=u;u=fD(r,0,0,1)|0;x=G;MS(r,l)|0;y=GD(r)|0;z=G;a:do{if((grc(s,1431880,16)|0)==0){A=z;B=y}else{C=e+1076|0;D=e;E=k|0;F=e+24|0;H=j|0;I=h|0;J=g|0;K=g+4|0;L=e+1100|0;M=m+24|0;N=m+28|0;O=e+1140|0;P=x;Q=u;R=z;S=y;b:while(1){T=0;if((R|0)<(T|0)|(R|0)==(T|0)&S>>>0<24>>>0){t=-1094995529;U=147;break}c:do{if((grc(s,1431688,16)|0)==0){T=c[o>>2]|0;V=c[q>>2]|0;MS(V,T+158512|0)|0;W=GD(V)|0;X=T+158528|0;c[X>>2]=W;c[X+4>>2]=G;X=GD(V)|0;W=T+158536|0;c[W>>2]=X;c[W+4>>2]=G;GD(V)|0;W=GD(V)|0;X=T+158544|0;c[X>>2]=W;c[X+4>>2]=G;X=GD(V)|0;W=T+158552|0;c[W>>2]=X;c[W+4>>2]=G;c[T+158560>>2]=FD(V)|0;c[T+158564>>2]=FD(V)|0;c[T+158568>>2]=FD(V)|0;W=T+158572|0;c[W>>2]=FD(V)|0;X=T+158576|0;c[X>>2]=FD(V)|0;if((c[W>>2]|0)>>>0>536870911>>>0){t=-1094995529;U=147;break b}c[T+158580>>2]=FD(V)|0;c[C>>2]=c[X>>2];U=125}else{if((grc(s,1431288,16)|0)==0){X=c[o>>2]|0;V=c[q>>2]|0;if((c[F>>2]|0)==127){U=15;break b}T=fD(V,0,0,1)|0;W=G;Y=ZX(e,0)|0;if((Y|0)==0){t=-12;U=147;break b}_X(Y,32,1,1e3);Z=c[X+158560>>2]|0;_=0;d:do{if((c[X+158568>>2]&1|0)==0){$=iD(V)|0;aa=G;ba=0;do{if(!((aa|0)<(ba|0)|(aa|0)==(ba|0)&$>>>0<1>>>0)){ca=X+158528|0;da=c[ca>>2]|0;ea=c[ca+4>>2]|0;ca=0;if((ea|0)<(ca|0)|(ea|0)==(ca|0)&da>>>0<1>>>0){break}ca=xrc($,aa,da,ea)|0;ea=G;da=-1;fa=(ea|0)>(da|0)|(ea|0)==(da|0)&ca>>>0>-1>>>0;da=xrc(0,0,ca,ea)|0;ga=fa?ea:G;ea=0;if(!((ga|0)<(ea|0)|(ga|0)==(ea|0)&(fa?ca:da)>>>0<1e4>>>0)){break d}}}while(0);aa=X+158544|0;$=Frc(c[aa>>2]|0,c[aa+4>>2]|0,1e4,0)|0;aa=xrc($,G,Z,_)|0;$=Y+56|0;c[$>>2]=aa;c[$+4>>2]=G}}while(0);MS(V,k)|0;do{if((grc(E,1431976,16)|0)==0){ha=1;ia=0}else{if((grc(E,1431168,16)|0)==0){ha=0;ia=0;break}if((grc(E,1431624,16)|0)==0){c[(c[Y+8>>2]|0)+48>>2]=8;ha=0;ia=0;break}if((grc(E,1431928,16)|0)==0){ha=2;ia=0;break}if((grc(E,1431736,16)|0)==0){ha=-1;ia=1}else{t=-1;U=147;break b}}}while(0);MS(V,k)|0;hD(V,8,0)|0;_=FD(V)|0;FD(V)|0;Z=(DD(V)|0)&127;$=Y+4|0;c[$>>2]=Z;c[X+4+(Z<<2)>>2]=(c[F>>2]|0)-1;Z=c[$>>2]|0;$=X+520|0;FD(V)|0;do{if(ia){MS(V,k)|0;if((grc(E,1431752,16)|0)!=0){U=31;break}MS(V,k)|0;FD(V)|0;FD(V)|0;FD(V)|0;MS(V,k)|0;FD(V)|0;aa=Y+8|0;ba=c[aa>>2]|0;c[ba+8>>2]=1;ja=1;ka=aa;la=ba;U=32}else{U=31}}while(0);do{if((U|0)==31){U=0;X=Y+8|0;ba=c[X>>2]|0;c[ba+8>>2]=ha;if((ha|0)==1){ja=0;ka=X;la=ba;U=32;break}else if((ha|0)!=0){break}ba=fD(V,0,0,1)|0;aa=G;da=wrc(S,R,-24,-1)|0;ca=wrc(da,G,T,W)|0;da=xrc(ca,G,ba,aa)|0;aa=G;ba=0;if(!((aa|0)>(ba|0)|(aa|0)==(ba|0)&da>>>0>50>>>0)){break}FD(V)|0;FD(V)|0;zD(V)|0;DD(V)|0;da=FD(V)|0;ba=FD(V)|0;c[(c[X>>2]|0)+120>>2]=ba;ba=FD(V)|0;c[(c[X>>2]|0)+124>>2]=ba;DD(V)|0;ba=DD(V)|0;c[(c[X>>2]|0)+792>>2]=ba;ba=FD(V)|0;hD(V,20,0)|0;if((da|0)>40){aa=eX(V,da-40|0)|0;c[(c[X>>2]|0)+100>>2]=aa;da=pJb(aa+16|0)|0;c[(c[X>>2]|0)+96>>2]=da;da=c[X>>2]|0;aa=c[da+96>>2]|0;if((aa|0)==0){t=-12;U=147;break b}AD(V,aa,c[da+100>>2]|0)|0}da=c[X>>2]|0;aa=c[da+100>>2]|0;do{if((aa|0)==0){ma=da}else{if((c[da+792>>2]|0)>=9){ma=da;break}nrc($+(Z*1216|0)+152|0,c[da+96>>2]|0,(aa|0)>1024?1024:aa)|0;c[$+(Z*1216|0)+148>>2]=1;ma=c[X>>2]|0}}while(0);c[ma+52>>2]=ba;aa=JX(1409152,ba)|0;da=c[X>>2]|0;c[da+48>>2]=aa;if((ba|0)==542266948){c[Y+236>>2]=1;c[da+124>>2]=0;c[da+120>>2]=0;mJb(da+96|0);da=c[X>>2]|0;c[da+100>>2]=0;na=c[da+48>>2]|0}else{na=aa}if((na|0)!=28){break}c[Y+236>>2]=4}}while(0);e:do{if((U|0)==32){U=0;aa=OS(V,la,_)|0;if((aa|0)<0){t=aa;U=147;break b}if((ja|0)==0){oa=c[ka>>2]|0}else{c[Y+440>>2]=1;aa=c[ka>>2]|0;c[aa+52>>2]=0;oa=aa}c[Y+236>>2]=(c[oa+48>>2]|0)!=86018;aa=fD(V,0,0,1)|0;da=G;ca=xrc(32,0,T,W)|0;fa=wrc(ca,G,aa,da)|0;da=G;if((da|0)>(R|0)|(da|0)==(R|0)&fa>>>0>S>>>0){pa=$+(Z*1216|0)+120|0}else{fa=$+(Z*1216|0)+120|0;c[fa>>2]=zD(V)|0;c[$+(Z*1216|0)+124>>2]=DD(V)|0;c[$+(Z*1216|0)+128>>2]=DD(V)|0;DD(V)|0;zD(V)|0;pa=fa}if((c[pa>>2]|0)<=1){break}fa=c[$+(Z*1216|0)+128>>2]|0;do{if((fa|0)!=0){da=c[$+(Z*1216|0)+124>>2]|0;if(((da|0)/(fa|0)|0|0)<2){break}if(((da|0)%(fa|0)|0|0)==0){break e}}}while(0);c[pa>>2]=0}}while(0);Z=fD(V,0,0,1)|0;$=G;Y=wrc(S,R,-24,-1)|0;_=wrc(Y,G,T,W)|0;Y=xrc(_,G,Z,$)|0;hD(V,Y,G)|0;U=125;break}if((grc(s,1431912,16)|0)==0){Y=c[q>>2]|0;$=DD(Y)|0;Z=DD(Y)|0;_=DD(Y)|0;fa=DD(Y)|0;X=DD(Y)|0;VB(e,2246344,0,$,32);VB(e,2221456,0,Z,32);VB(e,2217928,0,_,32);VB(e,2237584,0,fa,32);hD(Y,X,(X|0)<0|0?-1:0)|0;U=125;break}if((grc(s,1431608,16)|0)==0){X=c[o>>2]|0;Y=c[q>>2]|0;fa=DD(Y)|0;if((fa|0)<=0){U=125;break}_=X+157704|0;X=0;while(1){Z=zD(Y)|0;$=MD(Y,Z,H,6)|0;if($>>>0<Z>>>0){hD(Y,Z-$|0,0)|0;}if((X|0)<128){CFb(_+(X*6|0)|0,H,6)|0}$=X+1|0;if(($|0)<(fa|0)){X=$}else{U=125;break c}}}if((grc(s,1431704,16)|0)==0){X=c[q>>2]|0;fa=c[o>>2]|0;_=DD(X)|0;if((_|0)<=0){U=125;break}Y=fa+156680|0;V=fa+156684|0;fa=0;while(1){W=DD(X)|0;T=(W&1)+W|0;W=MD(X,T,I,1024)|0;if((W|0)<(T|0)){$=T-W|0;hD(X,$,($|0)<0|0?-1:0)|0;}$=DD(X)|0;W=DD(X)|0;if(($|0)==0){qa=(W&1)+W|0}else{qa=W}do{if((irc(I,2229864)|0)==0){W=c[q>>2]|0;if(($|0)==2){ra=FD(W)|0}else if(($|0)==3){ra=FD(W)|0}else if(($|0)==4){T=GD(W)|0;ra=T}else if(($|0)==5){ra=DD(W)|0}else{ra=-2147483648}c[Y>>2]=ra}else{if((irc(I,2226136)|0)!=0){VB(e,I,$,qa,32);break}W=c[q>>2]|0;if(($|0)==2){sa=FD(W)|0}else if(($|0)==3){sa=FD(W)|0}else if(($|0)==4){T=GD(W)|0;sa=T}else if(($|0)==5){sa=DD(W)|0}else{sa=-2147483648}c[V>>2]=sa}}while(0);$=fa+1|0;if(($|0)<(_|0)){fa=$}else{U=125;break c}}}if((grc(s,1431440,16)|0)==0){UB(e);U=125;break}if((grc(s,1431424,16)|0)==0){UB(e);U=125;break}if((grc(s,1431720,16)|0)==0){fa=c[o>>2]|0;_=c[q>>2]|0;GD(_)|0;GD(_)|0;V=FD(_)|0;FD(_)|0;FD(_)|0;FD(_)|0;FD(_)|0;FD(_)|0;FD(_)|0;FD(_)|0;Y=DD(_)|0;X=DD(_)|0;$=Y>>>0<128>>>0;if($){b[fa+520+(Y*1216|0)+144>>1]=X}GD(_)|0;X=DD(_)|0;W=DD(_)|0;if($){c[fa+156168+(Y<<2)>>2]=V;c[fa+520+(Y*1216|0)+1176>>2]=0}if((X|0)>0){V=0;do{DD(_)|0;T=DD(_)|0;hD(_,T,(T|0)<0|0?-1:0)|0;V=V+1|0;}while((V|0)<(X|0))}if((W|0)<=0){break}X=fa+520|0;V=X+(Y*1216|0)+1176|0;if($){ta=0}else{T=0;while(1){MS(_,k)|0;DD(_)|0;Z=FD(_)|0;hD(_,Z,(Z|0)<0|0?-1:0)|0;T=T+1|0;if((T|0)>=(W|0)){break c}}}while(1){MS(_,k)|0;T=DD(_)|0;$=FD(_)|0;hD(_,$,($|0)<0|0?-1:0)|0;if(ta>>>0<8>>>0){a[X+(Y*1216|0)+1180+(ta<<2)|0]=a[E]|0;b[X+(Y*1216|0)+1180+(ta<<2)+2>>1]=T;KIb(D,48,2233616,(ua=i,i=i+16|0,c[ua>>2]=d[E]|0,c[ua+8>>2]=T&65535,ua)|0);i=ua;c[V>>2]=(c[V>>2]|0)+1}ta=ta+1|0;if((ta|0)>=(W|0)){break c}}}if((grc(s,1431672,16)|0)==0){MS(r,l)|0;hD(r,6,0)|0;break}if((grc(s,1431592,16)|0)==0){W=c[q>>2]|0;V=c[o>>2]|0;GD(W)|0;GD(W)|0;Y=FD(W)|0;DD(W)|0;X=DD(W)|0;if((X|0)>0){_=0;do{zD(W)|0;_=_+1|0;}while((_|0)<(X|0))}if((Y|0)<=0){U=125;break}X=V+158560|0;_=0;while(1){GD(W)|0;T=GD(W)|0;$=xrc(T,G,(c[X>>2]|0)*1e4|0,0)|0;T=G;DD(W)|0;FD(W)|0;FD(W)|0;fa=FD(W)|0;Z=MD(W,fa<<1,I,1024)|0;if((Z|0)<(fa|0)){ba=fa-Z|0;hD(W,ba,(ba|0)<0|0?-1:0)|0;}c[J>>2]=1;c[K>>2]=1e7;aY(e,_,g,$,T,0,-2147483648,I)|0;T=_+1|0;if((T|0)<(Y|0)){_=T}else{U=125;break c}}}if((jD(r)|0)!=0){t=-541478725;U=147;break b}if((c[L>>2]|0)!=0){U=125;break}if((grc(s,1431896,16)|0)==0){KIb(D,24,2372792,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;_=FD(r)|0;KIb(D,48,2361792,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;fX(r,m,_)|0;hY(D,48,c[M>>2]|0,c[N>>2]|0);P1(m);VB(e,2348848,-1,FD(r)|0,32);VB(e,2342528,-1,FD(r)|0,32);VB(e,2336704,-1,FD(r)|0,32);U=125;break}if((grc(s,1431768,16)|0)==0){KIb(D,24,2331192,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;MGb(O,2325248,2319744,0)|0;U=125;break}if((grc(s,1431784,16)|0)!=0){U=125;break}KIb(D,32,2315040,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;U=125}}while(0);if((U|0)==125){U=0;_=fD(r,0,0,1)|0;Y=G;W=wrc(S,R,Q,P)|0;X=G;if(!((_|0)==(W|0)&(Y|0)==(X|0))){Y=fD(r,0,0,1)|0;_=xrc(Y,G,Q,P)|0;Y=G;KIb(D,48,2310456,(ua=i,i=i+32|0,c[ua>>2]=_,c[ua+8>>2]=Y,c[ua+16>>2]=S,c[ua+24>>2]=R,ua)|0);i=ua}fD(r,W,X,0)|0;}X=fD(r,0,0,1)|0;W=G;MS(r,l)|0;Y=GD(r)|0;_=G;if((grc(s,1431880,16)|0)==0){A=_;B=Y;break a}else{P=W;Q=X;R=_;S=Y}}if((U|0)==15){KIb(D,16,2215128,(ua=i,i=i+1|0,i=i+7&-8,c[ua>>2]=0,ua)|0);i=ua;t=-22;i=f;return t|0}else if((U|0)==147){i=f;return t|0}}}while(0);ua=fD(r,0,0,1)|0;s=p+158488|0;c[s>>2]=ua;c[s+4>>2]=G;s=0;if((c[p+158568>>2]&1|0)==0&((A|0)>(s|0)|(A|0)==(s|0)&B>>>0>99>>>0)){s=wrc(B,A,-24,-1)|0;A=p+158496|0;c[A>>2]=s;c[A+4>>2]=G}else{A=p+158496|0;c[A>>2]=-1;c[A+4>>2]=-1}MS(r,l)|0;GD(r)|0;zD(r)|0;zD(r)|0;if((jD(r)|0)!=0){t=-541478725;i=f;return t|0}l=fD(r,0,0,1)|0;r=p+158480|0;c[r>>2]=l;c[r+4>>2]=G;c[p+158472>>2]=0;r=e+28|0;l=p+156168|0;A=p+156680|0;s=A;B=p+157704|0;ua=n|0;m=n+1|0;g=n+2|0;n=A;A=p+156684|0;p=0;do{o=c[w+(p<<2)>>2]|0;do{if((o|0)>-1){q=c[(c[r>>2]|0)+(o<<2)>>2]|0;ta=c[q+8>>2]|0;k=ta+72|0;if((c[k>>2]|0)==0){c[k>>2]=c[l+(p<<2)>>2]}k=c[s+(p<<3)>>2]|0;do{if((k|0)>0){sa=c[s+(p<<3)+4>>2]|0;if((sa|0)<=0){U=136;break}xKb(q+80|0,q+84|0,k,(k|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0,2147483647,0)|0}else{U=136}}while(0);do{if((U|0)==136){U=0;k=c[n>>2]|0;if((k|0)<=0){break}sa=c[A>>2]|0;if((sa|0)<=0){break}if((c[ta+8>>2]|0)!=0){break}xKb(q+80|0,q+84|0,k,(k|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0,2147483647,0)|0}}while(0);ta=b[v+(p*1216|0)+144>>1]|0;if(!((ta&65535)>>>0<128>>>0)){break}sa=ta&65535;ta=B+(sa*6|0)|0;if((ta|0)==0){break}if(!((lrc(ta|0)|0)>>>0>1>>>0)){break}a[ua]=a[ta]|0;a[m]=a[B+(sa*6|0)+1|0]|0;a[g]=0;sa=hE(ua,0)|0;if((sa|0)==0){break}MGb(q+88|0,2306240,sa,0)|0}}while(0);p=p+1|0;}while((p|0)<128);cL(e+1140|0,0,1431456);t=0;i=f;return t|0}function QB(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;g=i;h=e+12|0;j=c[h>>2]|0;k=e+16|0;l=c[k>>2]|0;if((jD(l)|0)!=0){m=-541478725;i=g;return m|0}n=e;o=e+28|0;p=e+1096|0;q=e+1100|0;r=e+1076|0;s=e+1248|0;e=j+158472|0;t=j+158600|0;u=j+158648|0;v=l;l=j;a:while(1){j=l+158472|0;w=l+158648|0;x=l+158600|0;y=l+158664|0;z=l+158624|0;A=l+158612|0;B=l+520|0;C=l+158668|0;D=l+158620|0;E=l+158608|0;F=l+158632|0;H=l+158644|0;I=l+158640|0;J=l+158604|0;K=l+158560|0;L=l+158656|0;while(1){M=c[j>>2]|0;if((M|0)<16){break}b:do{if((c[w>>2]|0)==0){N=c[h>>2]|0;O=zD(v)|0;P=N+158600|0;c[P>>2]=(c[P>>2]|0)-1;c[N+158612>>2]=O>>7;P=O&127;O=N+158664|0;c[O>>2]=c[N+4+(P<<2)>>2];Q=N+520|0;R=N+158588|0;S=(c[R>>2]|0)>>>4&3;if((S|0)==2){c[N+158604>>2]=DD(v)|0;T=3}else if((S|0)==3){c[N+158604>>2]=FD(v)|0;T=5}else if((S|0)==1){c[N+158604>>2]=zD(v)|0;T=2}else{c[N+158604>>2]=0;T=1}S=(c[R>>2]|0)>>>2&3;if((S|0)==2){c[N+158620>>2]=DD(v)|0;U=T+2|0}else if((S|0)==3){c[N+158620>>2]=FD(v)|0;U=T+4|0}else if((S|0)==1){c[N+158620>>2]=zD(v)|0;U=T+1|0}else{c[N+158620>>2]=0;U=T}S=c[R>>2]&3;if((S|0)==3){R=FD(v)|0;c[N+158608>>2]=R;V=U+4|0;W=R}else if((S|0)==2){R=DD(v)|0;c[N+158608>>2]=R;V=U+2|0;W=R}else if((S|0)==1){S=zD(v)|0;c[N+158608>>2]=S;V=U+1|0;W=S}else{c[N+158608>>2]=0;V=U;W=0}S=N+158608|0;R=wrc(V,(V|0)<0|0?-1:0,W,(W|0)<0|0?-1:0)|0;X=G;Y=N+158472|0;Z=c[Y>>2]|0;_=(Z|0)<0|0?-1:0;c:do{if((X|0)>(_|0)|(X|0)==(_|0)&R>>>0>Z>>>0){KIb(n,16,2414760,($=i,i=i+8|0,c[$>>2]=W,$)|0);i=$}else{do{if((W|0)>7){aa=fD(v,0,0,1)|0;ba=c[S>>2]|0;da=wrc(ba,(ba|0)<0|0?-1:0,aa,G)|0;aa=G;ba=FD(v)|0;ea=Q+(P*1216|0)+92|0;c[ea>>2]=ba;if((ba-1|0)>>>0>16777214>>>0){KIb(n,16,2406840,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;c[ea>>2]=0;break c}ea=N+158632|0;c[ea>>2]=FD(v)|0;c[ea+4>>2]=0;ba=Q+(P*1216|0)+1176|0;d:do{if((c[ba>>2]|0)>0){fa=0;while(1){ga=b[Q+(P*1216|0)+1180+(fa<<2)+2>>1]|0;if(ga<<16>>16==-1){ha=DD(v)|0}else{ha=ga&65535}ga=fD(v,0,0,1)|0;ia=wrc(ga,G,ha,(ha|0)<0|0?-1:0)|0;ga=G;if((ga|0)>(aa|0)|(ga|0)==(aa|0)&ia>>>0>da>>>0){break}ja=d[Q+(P*1216|0)+1180+(fa<<2)|0]|0;do{if((ja|0)==84){ka=zD(v)|0;la=zD(v)|0;if(!((ka|0)>0&(la|0)>0)){break}ma=c[O>>2]|0;if(!((ma|0)>-1)){break}na=c[(c[o>>2]|0)+(ma<<2)>>2]|0;c[na+80>>2]=ka;c[na+84>>2]=la}else if((ja|0)==42){hD(v,8,0)|0;la=GD(v)|0;na=G;GD(v)|0;if((la|0)==(-1|0)&(na|0)==(-1|0)){c[ea>>2]=0;c[ea+4>>2]=-2147483648;break}else{ka=Crc(la,na,1e4,0)|0;c[ea>>2]=ka;c[ea+4>>2]=G;break}}}while(0);fD(v,ia,ga,0)|0;fa=fa+1|0;if((fa|0)>=(c[ba>>2]|0)){break d}}KIb(n,16,2399432,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$}}while(0);fD(v,da,aa,0)|0;oa=(c[S>>2]|0)+V|0}else{if((W|0)==1){ba=N+158620|0;c[N+158648>>2]=c[ba>>2];c[ba>>2]=0;ba=c[N+158592>>2]|0;ea=N+158632|0;c[ea>>2]=ba;c[ea+4>>2]=(ba|0)<0|0?-1:0;c[N+158644>>2]=zD(v)|0;oa=V+1|0;break}else if((W|0)==0){oa=V;break}else{KIb(n,16,2392472,($=i,i=i+8|0,c[$>>2]=W,$)|0);i=$;break c}}}while(0);do{if((c[N+158584>>2]&1|0)==0){ba=c[Y>>2]|0;ea=ba-oa|0;c[N+158624>>2]=ea;pa=oa;qa=ea;ra=ba}else{ba=(c[N+158596>>2]|0)>>>6&3;if((ba|0)==3){ea=FD(v)|0;c[N+158624>>2]=ea;sa=oa+4|0;ta=ea}else if((ba|0)==2){ea=DD(v)|0;c[N+158624>>2]=ea;sa=oa+2|0;ta=ea}else if((ba|0)==1){ba=zD(v)|0;c[N+158624>>2]=ba;sa=oa+1|0;ta=ba}else{c[N+158624>>2]=0;sa=oa;ta=0}ba=c[Y>>2]|0;if((sa|0)>(ba|0)){KIb(n,16,2385824,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;break c}ea=ba-sa|0;if(!(ta>>>0>ea>>>0)){pa=sa;qa=ta;ra=ba;break}fa=N+158616|0;ja=c[fa>>2]|0;if(ta>>>0>(ja+ea|0)>>>0){KIb(n,16,2378648,($=i,i=i+16|0,c[$>>2]=ba,c[$+8>>2]=sa,$)|0);i=$;break c}else{ka=ta-ea|0;ea=ka+ba|0;c[Y>>2]=ea;c[fa>>2]=ja-ka;pa=sa;qa=ta;ra=ea;break}}}while(0);if((c[S>>2]|0)==1){c[N+158640>>2]=qa;if((qa|0)>(ra|0)){break}}c[Y>>2]=ra-pa;ea=c[y>>2]|0;do{if((ea|0)>=0){ka=c[(c[o>>2]|0)+(ea<<2)>>2]|0;ja=c[ka+76>>2]|0;if((ja|0)>47){break}if((c[A>>2]|0)==0){if((ja|0)>31){break}ja=c[ka+4>>2]|0;if((c[B+(ja*1216|0)+112>>2]|0)==0){ua=ja}else{break}}else{ua=c[ka+4>>2]|0}ka=B+(ua*1216|0)|0;c[C>>2]=ka;c[B+(ua*1216|0)+112>>2]=0;va=ka;wa=74;break b}}while(0);c[w>>2]=0;hD(v,c[z>>2]|0,0)|0;ea=c[z>>2]|0;c[j>>2]=(c[j>>2]|0)-ea;if((c[y>>2]|0)>=0){break b}KIb(n,16,2540744,($=i,i=i+8|0,c[$>>2]=ea,$)|0);i=$;break b}}while(0);c[x>>2]=0;c[w>>2]=0}else{va=c[C>>2]|0;wa=74}}while(0);e:do{if((wa|0)==74){wa=0;if((va|0)==0){wa=75;break a}xa=va+88|0;do{if((c[xa>>2]|0)==0){if((c[D>>2]|0)==0){break}hD(v,c[z>>2]|0,0)|0;c[j>>2]=(c[j>>2]|0)-(c[z>>2]|0);break e}}while(0);do{if((c[E>>2]|0)==1){Y=c[w>>2]|0;c[F>>2]=Y;c[F+4>>2]=(Y|0)<0|0?-1:0;c[w>>2]=(c[H>>2]|0)+Y;Y=zD(v)|0;c[z>>2]=Y;N=va+92|0;c[N>>2]=Y;c[j>>2]=(c[j>>2]|0)-1;Y=(c[I>>2]|0)-1|0;c[I>>2]=Y;S=c[N>>2]|0;if((Y|0)<(S|0)){c[w>>2]=0;hD(v,Y,(Y|0)<0|0?-1:0)|0;c[j>>2]=(c[j>>2]|0)-(c[I>>2]|0);break e}else{c[I>>2]=Y-S;ya=N;break}}else{ya=va+92|0}}while(0);za=va+8|0;Aa=va+36|0;N=c[Aa>>2]|0;S=c[ya>>2]|0;if((N|0)==(S|0)){if(((c[z>>2]|0)+(c[xa>>2]|0)|0)>>>0>N>>>0){wa=86}}else{wa=86}do{if((wa|0)==86){wa=0;Y=va+32|0;if((c[Y>>2]|0)==0){Ba=S}else{KIb(n,32,2494744,($=i,i=i+16|0,c[$>>2]=N,c[$+8>>2]=S,$)|0);i=$;c[xa>>2]=0;P1(za);Ba=c[ya>>2]|0}K1(za,Ba)|0;a[va+4|0]=c[J>>2];O=xrc(c[F>>2]|0,c[F+4>>2]|0,c[K>>2]|0,0)|0;P=va+24|0;c[P>>2]=O;c[P+4>>2]=G;c[va+40>>2]=c[y>>2];P=c[L>>2]|0;O=c[L+4>>2]|0;Q=va+136|0;c[Q>>2]=P;c[Q+4>>2]=O;Q=va+72|0;c[Q>>2]=P;c[Q+4>>2]=O;c[va+116>>2]=0;do{if((c[Y>>2]|0)!=0){O=va+148|0;if((c[O>>2]|0)==0){break}Q=U1(za,0,1024)|0;if((Q|0)==0){KIb(n,16,2484312,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;break}else{nrc(Q|0,va+152|0,1024)|0;c[O>>2]=0;break}}}while(0);if((c[(c[(c[(c[o>>2]|0)+(c[y>>2]<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==1){c[A>>2]=1}else{if((c[A>>2]|0)==0){break}}Y=va+44|0;c[Y>>2]=c[Y>>2]|1}}while(0);S=c[z>>2]|0;N=(c[j>>2]|0)-S|0;c[j>>2]=N;if((N|0)<0){break}N=c[D>>2]|0;Y=c[Aa>>2]|0;if(N>>>0>=Y>>>0|S>>>0>(Y-N|0)>>>0){KIb(n,16,2473032,($=i,i=i+24|0,c[$>>2]=N,c[$+8>>2]=S,c[$+16>>2]=Y,$)|0);i=$;break}O=c[xa>>2]|0;do{if((N|0)==(O|0)){Ca=N;Da=S}else{Q=va+116|0;if((c[Q>>2]|0)!=0){Ca=N;Da=S;break}mrc((c[va+32>>2]|0)+O|0,0,Y-O|0)|0;c[Q>>2]=1;Ca=c[D>>2]|0;Da=c[z>>2]|0}}while(0);Ea=va+32|0;O=AD(v,(c[Ea>>2]|0)+Ca|0,Da)|0;Y=c[z>>2]|0;do{if((O|0)==(Y|0)){Fa=O}else{if((O|0)<0){m=O;wa=131;break a}S=(c[D>>2]|0)+O|0;if((S|0)==0){m=-541478725;wa=131;break a}if((c[va+120>>2]|0)>1){mrc((c[Ea>>2]|0)+S|0,0,Y-O|0)|0;Fa=c[z>>2]|0;break}else{M1(za,S);Fa=O;break}}}while(0);O=c[p>>2]|0;do{if((O|0)!=0){if((c[q>>2]|0)!=20){break}j$(O,(c[Ea>>2]|0)+(c[D>>2]|0)|0,Fa)}}while(0);Ga=(c[xa>>2]|0)+Fa|0;c[xa>>2]=Ga;if((Ga|0)!=(c[Aa>>2]|0)){break}if((c[(c[(c[(c[o>>2]|0)+(c[y>>2]<<2)>>2]|0)+8>>2]|0)+48>>2]|0)==2&(Ga|0)>100){Ha=0}else{wa=118;break a}while(1){if((Ha|0)>=(Ga|0)){break}if((a[(c[Ea>>2]|0)+Ha|0]|0)==0){Ha=Ha+1|0}else{break}}if((Ha|0)!=(Ga|0)){wa=118;break a}KIb(n,48,2464800,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;c[xa>>2]=0;P1(za)}}while(0);if((jD(v)|0)!=0){m=-541478725;wa=131;break a}}y=(c[l+158616>>2]|0)+M|0;if(!((y|0)>-1)){wa=6;break}hD(v,y,(y|0)<0|0?-1:0)|0;y=fD(v,0,0,1)|0;D=G;c[L>>2]=y;c[L+4>>2]=D;z=l+158496|0;j=c[z>>2]|0;A=c[z+4>>2]|0;if(!((j|0)==(-1|0)&(A|0)==(-1|0))){z=l+158488|0;K=xrc(y,D,c[z>>2]|0,c[z+4>>2]|0)|0;z=G;if(!(z>>>0<A>>>0|z>>>0==A>>>0&K>>>0<j>>>0)){m=-541478725;wa=131;break}}j=c[k>>2]|0;K=c[h>>2]|0;do{if((c[K+158672>>2]|0)==0){if((c[r>>2]|0)==0){Ia=32768;Ja=-1;Ka=-1;La=-1;break}A=fD(j,0,0,1)|0;z=xrc(A,G,c[s>>2]|0,c[s+4>>2]|0)|0;A=Drc(z,G,c[r>>2]|0,0)|0;z=wrc(A,G,3,0)|0;Ia=z;Ja=-1;Ka=-1;La=-1}else{Ia=3;Ja=-1;Ka=-1;La=-1}}while(0);while(1){if((Ia|0)<=0){wa=137;break}L=zD(j)|0;if((Ka|0)==130&(Ja|0)==0&(L|0)==0){Ma=0;Na=0;wa=142;break}else{Ia=Ia-1|0;La=Ka;Ka=Ja;Ja=L}}do{if((wa|0)==137){wa=0;if((La|0)==130){Ma=Ka;Na=Ja;wa=142;break}if((c[j+76>>2]|0)==-11){wa=173;break}if((jD(j)|0)==0){L=fD(j,0,0,1)|0;z=G;KIb(n,16,2133632,($=i,i=i+24|0,c[$>>2]=La,c[$+8>>2]=L,c[$+16>>2]=z,$)|0);i=$}if((La&143|0)==130){Ma=Ka;Na=Ja;wa=142;break}if((jD(j)|0)!=0){Oa=Ka;Pa=La;Qa=8;wa=148;break}fD(j,-1,-1,1)|0;Oa=Ka;Pa=La;Qa=8;wa=148}}while(0);do{if((wa|0)==142){wa=0;if((Ma|Na|0)==0){z=zD(j)|0;Oa=zD(j)|0;Pa=z;Qa=11;wa=148;break}if((jD(j)|0)!=0){wa=173;break}KIb(n,16,2110120,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;wa=173}}while(0);do{if((wa|0)==148){wa=0;z=K+158584|0;c[z>>2]=Pa;c[K+158588>>2]=Oa;L=Pa>>>5&3;if((L|0)==3){Ra=Qa|4;Sa=FD(j)|0}else if((L|0)==2){Ra=Qa+2|0;Sa=DD(j)|0}else if((L|0)==1){Ra=Qa+1|0;Sa=zD(j)|0}else{Ra=Qa;Sa=c[r>>2]|0}L=(c[z>>2]|0)>>>1&3;if((L|0)==3){FD(j)|0;Ta=Ra+4|0}else if((L|0)==2){DD(j)|0;Ta=Ra+2|0}else if((L|0)==1){zD(j)|0;Ta=Ra+1|0}else{Ta=Ra}L=(c[z>>2]|0)>>>3&3;if((L|0)==1){Ua=Ta+1|0;Va=zD(j)|0}else if((L|0)==3){Ua=Ta+4|0;Va=FD(j)|0}else if((L|0)==2){Ua=Ta+2|0;Va=DD(j)|0}else{Ua=Ta;Va=0}if((Sa|0)==0|Sa>>>0>536870911>>>0){L=fD(j,0,0,1)|0;A=G;KIb(n,16,2627928,($=i,i=i+24|0,c[$>>2]=Sa,c[$+8>>2]=L,c[$+16>>2]=A,$)|0);i=$;wa=173;break}if(!(Va>>>0<Sa>>>0)){A=fD(j,0,0,1)|0;L=G;KIb(n,16,2602680,($=i,i=i+24|0,c[$>>2]=Va,c[$+8>>2]=A,c[$+16>>2]=L,$)|0);i=$;wa=173;break}c[K+158592>>2]=FD(j)|0;DD(j)|0;if((c[z>>2]&1|0)==0){c[K+158600>>2]=1;c[K+158596>>2]=128;Wa=Ua}else{z=zD(j)|0;c[K+158596>>2]=z;c[K+158600>>2]=z&63;Wa=Ua+1|0}z=Sa-Va|0;if(Wa>>>0>z>>>0){c[K+158472>>2]=0;L=fD(j,0,0,1)|0;A=G;KIb(n,16,2577312,($=i,i=i+40|0,c[$>>2]=Wa,c[$+8>>2]=Sa,c[$+16>>2]=Va,c[$+24>>2]=L,c[$+32>>2]=A,$)|0);i=$;wa=173;break}c[K+158472>>2]=z-Wa;z=c[K+158572>>2]|0;if(Sa>>>0<z>>>0){Xa=Va-Sa+z|0}else{Xa=Va}c[K+158616>>2]=Xa}}while(0);do{if((wa|0)==173){wa=0;if((c[e>>2]|0)<16){break}if((c[t>>2]|0)>=1){wa=175;break a}}}while(0);c[u>>2]=0;K=c[k>>2]|0;j=c[h>>2]|0;if((jD(K)|0)==0){v=K;l=j}else{m=-541478725;wa=131;break}}if((wa|0)==6){Cd(2558280,2158920,1128,2653448);return 0}else if((wa|0)==75){KIb(0,0,2523800,($=i,i=i+24|0,c[$>>2]=2508856,c[$+8>>2]=2158920,c[$+16>>2]=1160,$)|0);i=$;Hd();return 0}else if((wa|0)==118){l=va+120|0;v=c[l>>2]|0;do{if((v|0)>1){h=va+124|0;k=c[h>>2]|0;if((Ga|0)!=(ca(k,v)|0)){KIb(n,16,2451032,($=i,i=i+24|0,c[$>>2]=Ga,c[$+8>>2]=k,c[$+16>>2]=v,$)|0);i=$;break}k=cGb(Ga+16|0)|0;if((k|0)==0){break}u=k+4|0;t=c[u>>2]|0;mrc(t+(c[Aa>>2]|0)|0,0,16)|0;e=c[Aa>>2]|0;f:do{if((e|0)>0){Xa=va+128|0;Va=0;Sa=e;Wa=c[Xa>>2]|0;while(1){Ua=(Va|0)/(Wa|0)|0;Ta=c[l>>2]|0;Ra=((ca(c[h>>2]|0,(Ua|0)%(Ta|0)|0)|0)/(Wa|0)|0)+((Ua|0)/(Ta|0)|0)|0;if((Va+Wa|0)>(Sa|0)){wa=125;break}if((Ra+1|0)>((Sa|0)/(Wa|0)|0|0)){wa=127;break}nrc(t+Va|0,(c[Ea>>2]|0)+(ca(Ra,Wa)|0)|0,Wa)|0;Wa=c[Xa>>2]|0;Va=Wa+Va|0;Sa=c[Aa>>2]|0;if((Va|0)>=(Sa|0)){break f}}if((wa|0)==125){Cd(2435288,2158920,1309,2653448);return 0}else if((wa|0)==127){Cd(2425584,2158920,1310,2653448);return 0}}}while(0);t=za|0;fGb(t);c[t>>2]=k;c[Ea>>2]=c[u>>2]}}while(0);c[xa>>2]=0;nrc(f|0,za|0,80)|0;c[va+60>>2]=0;c[za>>2]=0;c[Aa>>2]=0;c[Ea>>2]=0;c[va+52>>2]=0;c[va+48>>2]=0;m=0;i=g;return m|0}else if((wa|0)==131){i=g;return m|0}else if((wa|0)==175){Cd(2189e3,2158920,1352,2653432);return 0}return 0}function RB(b){b=b|0;var d=0,e=0;d=c[b+12>>2]|0;c[d+158472>>2]=0;b=d+520|0;mrc(d+158584|0,0,44)|0;mrc(d+158632|0,0,20)|0;e=0;do{P1(b+(e*1216|0)+8|0);c[b+(e*1216|0)+92>>2]=0;c[b+(e*1216|0)+88>>2]=0;a[b+(e*1216|0)+4|0]=0;e=e+1|0;}while((e|0)<128);c[d+158668>>2]=0;return 0}function SB(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+16|0;j=h|0;k=b+12|0;l=c[k>>2]|0;m=b+28|0;n=c[(c[m>>2]|0)+(d<<2)>>2]|0;o=b+1076|0;if((c[o>>2]|0)==0){p=-1;i=h;return p|0}q=b+16|0;r=c[q>>2]|0;do{if((r|0)!=0){s=ZD(r,d,e,f,g)|0;t=s;if((t|0)>-1){s=c[k>>2]|0;c[s+158472>>2]=0;u=s+520|0;mrc(s+158584|0,0,44)|0;mrc(s+158632|0,0,20)|0;v=0;do{P1(u+(v*1216|0)+8|0);c[u+(v*1216|0)+92>>2]=0;c[u+(v*1216|0)+88>>2]=0;a[u+(v*1216|0)+4|0]=0;v=v+1|0;}while((v|0)<128);c[s+158668>>2]=0}if((t|0)==-38){break}else{p=t}i=h;return p|0}}while(0);if((e|0)==0&(f|0)==0){r=c[k>>2]|0;c[r+158472>>2]=0;v=r+520|0;mrc(r+158584|0,0,44)|0;mrc(r+158632|0,0,20)|0;u=0;do{P1(v+(u*1216|0)+8|0);c[v+(u*1216|0)+92>>2]=0;c[v+(u*1216|0)+88>>2]=0;a[v+(u*1216|0)+4|0]=0;u=u+1|0;}while((u|0)<128);c[r+158668>>2]=0;r=b+1248|0;fD(c[q>>2]|0,c[r>>2]|0,c[r+4>>2]|0,0)|0;p=0;i=h;return p|0}r=l+158504|0;l=c[r>>2]|0;a:do{if((l|0)==0){u=j|0;v=c[k>>2]|0;w=fD(c[q>>2]|0,0,0,1)|0;x=G;y=c[q>>2]|0;z=v+158488|0;A=v+158496|0;B=wrc(c[A>>2]|0,c[A+4>>2]|0,c[z>>2]|0,c[z+4>>2]|0)|0;z=fD(y,B,G,0)|0;do{if((z|0)>=0){B=MS(c[q>>2]|0,j)|0;b:do{if((B|0)<0){C=B}else{y=B;while(1){A=(grc(u,1431304,16)|0)==0;D=GD(c[q>>2]|0)|0;E=G;if(A){break}A=0;if((E|0)<(A|0)|(E|0)==(A|0)&D>>>0<24>>>0){C=y;break b}if((jD(c[q>>2]|0)|0)!=0){C=y;break b}A=c[q>>2]|0;F=wrc(D,E,-24,-1)|0;hD(A,F,G)|0;F=MS(c[q>>2]|0,j)|0;if((F|0)<0){C=F;break b}else{y=F}}y=MS(c[q>>2]|0,j)|0;if((y|0)<0){C=y;break}F=GD(c[q>>2]|0)|0;A=G;E=FD(c[q>>2]|0)|0;D=FD(c[q>>2]|0)|0;H=b;KIb(H,48,2274416,(I=i,i=i+32|0,c[I>>2]=F,c[I+8>>2]=A,c[I+16>>2]=E,c[I+24>>2]=D,I)|0);i=I;if((D|0)>0){E=b+1248|0;J=v+158560|0;K=0;L=-1;M=-1;while(1){N=FD(c[q>>2]|0)|0;O=DD(c[q>>2]|0)|0;P=c[E>>2]|0;Q=c[E+4>>2]|0;R=Erc(c[o>>2]|0,0,N,(N|0)<0|0?-1:0)|0;S=wrc(R,G,P,Q)|0;Q=G;P=VIb(F,A,K,(K|0)<0|0?-1:0,1e4,0)|0;R=xrc(P,G,c[J>>2]|0,0)|0;P=G;T=0;U=(P|0)>(T|0)|(P|0)==(T|0)&R>>>0>0>>>0;T=U?R:0;R=U?P:0;if((S|0)==(M|0)&(Q|0)==(L|0)){V=L;W=M}else{KIb(H,48,2225528,(I=i,i=i+32|0,c[I>>2]=N,c[I+8>>2]=O,c[I+16>>2]=T,c[I+24>>2]=R,I)|0);i=I;xX(c[(c[m>>2]|0)+(d<<2)>>2]|0,S,Q,T,R,c[o>>2]|0,0,1)|0;V=Q;W=S}S=K+1|0;if((S|0)<(D|0)){K=S;L=V;M=W}else{break}}}c[v+158504>>2]=(D|0)>1;C=y}}while(0);fD(c[q>>2]|0,w,x,0)|0;if((C|0)<0){break}X=c[r>>2]|0;Y=29;break a}}while(0);c[r>>2]=-1}else{X=l;Y=29}}while(0);do{if((Y|0)==29){if((X|0)<=0){break}l=n+400|0;if((c[l>>2]|0)==0){break}r=CX(n,e,f,g)|0;if(!((r|0)>-1)){break}C=(c[l>>2]|0)+(r*24|0)|0;r=c[C>>2]|0;l=c[C+4>>2]|0;KIb(b,48,2330576,(I=i,i=i+16|0,c[I>>2]=r,c[I+8>>2]=l,I)|0);i=I;C=fD(c[q>>2]|0,r,l,0)|0;l=G;r=0;if((l|0)<(r|0)|(l|0)==(r|0)&C>>>0<0>>>0){p=-1;i=h;return p|0}C=c[k>>2]|0;c[C+158472>>2]=0;r=C+520|0;mrc(C+158584|0,0,44)|0;mrc(C+158632|0,0,20)|0;l=0;do{P1(r+(l*1216|0)+8|0);c[r+(l*1216|0)+92>>2]=0;c[r+(l*1216|0)+88>>2]=0;a[r+(l*1216|0)+4|0]=0;l=l+1|0;}while((l|0)<128);c[C+158668>>2]=0;l=c[k>>2]|0;r=l+4|0;W=l+520|0;l=0;while(1){V=c[r+(l<<2)>>2]|0;do{if((V|0)>=0){if((c[(c[(c[(c[m>>2]|0)+(V<<2)>>2]|0)+8>>2]|0)+8>>2]|0)!=0){break}c[W+(l*1216|0)+112>>2]=1}}while(0);V=l+1|0;if((V|0)<128){l=V}else{p=0;break}}i=h;return p|0}}while(0);if((DX(b,d,e,f,g)|0)<0){p=-1;i=h;return p|0}g=c[k>>2]|0;c[g+158472>>2]=0;f=g+520|0;mrc(g+158584|0,0,44)|0;mrc(g+158632|0,0,20)|0;e=0;do{P1(f+(e*1216|0)+8|0);c[f+(e*1216|0)+92>>2]=0;c[f+(e*1216|0)+88>>2]=0;a[f+(e*1216|0)+4|0]=0;e=e+1|0;}while((e|0)<128);c[g+158668>>2]=0;g=c[k>>2]|0;k=g+4|0;e=g+520|0;g=0;while(1){f=c[k+(g<<2)>>2]|0;do{if((f|0)>=0){if((c[(c[(c[(c[m>>2]|0)+(f<<2)>>2]|0)+8>>2]|0)+8>>2]|0)!=0){break}c[e+(g*1216|0)+112>>2]=1}}while(0);f=g+1|0;if((f|0)<128){g=f}else{p=0;break}}i=h;return p|0}function TB(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;i=i+1096|0;f=g|0;h=g+80|0;j=b+12|0;k=c[j>>2]|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[b+24>>2]|0;if((n|0)!=0){o=0;do{p=h+(o<<3)|0;c[p>>2]=l;c[p+4>>2]=m;o=o+1|0;}while(o>>>0<n>>>0)}n=c[b+1076>>2]|0;if((n|0)==0){q=m;r=l}else{o=n;n=0;p=b+1248|0;s=c[p>>2]|0;t=c[p+4>>2]|0;p=wrc(l,m,-1,-1)|0;m=wrc(p,G,o,n)|0;p=xrc(m,G,s,t)|0;m=G;l=Drc(p,m,o,n)|0;n=xrc(s,t,l,G)|0;l=wrc(n,G,p,m)|0;q=G;r=l}c[e>>2]=r;c[e+4>>2]=q;l=fD(c[b+16>>2]|0,r,q,0)|0;q=G;r=0;if((q|0)<(r|0)|(q|0)==(r|0)&l>>>0<0>>>0){u=-2147483648;v=0;i=g;return(G=u,v)|0}yX(b);l=c[j>>2]|0;c[l+158472>>2]=0;j=l+520|0;mrc(l+158584|0,0,44)|0;mrc(l+158632|0,0,20)|0;r=0;do{P1(j+(r*1216|0)+8|0);c[j+(r*1216|0)+92>>2]=0;c[j+(r*1216|0)+88>>2]=0;a[j+(r*1216|0)+4|0]=0;r=r+1|0;}while((r|0)<128);c[l+158668>>2]=0;a:do{if((uX(b,f)|0)>=0){l=f+16|0;r=f+36|0;j=f+32|0;q=b+28|0;m=k+520|0;p=f+28|0;while(1){w=c[l>>2]|0;x=c[l+4>>2]|0;P1(f);if((c[r>>2]&1|0)!=0){n=c[j>>2]|0;t=c[(c[q>>2]|0)+(n<<2)>>2]|0;s=m+((c[t+4>>2]|0)*1216|0)+136|0;y=c[s>>2]|0;z=c[s+4>>2]|0;o=c[p>>2]|0;A=h+(n<<3)|0;n=c[A>>2]|0;B=c[A+4>>2]|0;C=wrc(y,z,1,0)|0;D=xrc(C,G,n,B)|0;xX(t,y,z,w,x,o,D,1)|0;D=wrc(c[s>>2]|0,c[s+4>>2]|0,1,0)|0;c[A>>2]=D;c[A+4>>2]=G;if((c[j>>2]|0)==(d|0)){break}}if((uX(b,f)|0)<0){break a}}c[e>>2]=y;c[e+4>>2]=z;u=x;v=w;i=g;return(G=u,v)|0}}while(0);KIb(b,32,2406176,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;u=-2147483648;v=0;i=g;return(G=u,v)|0}function UB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+1024|0;d=a+16|0;e=c[d>>2]|0;f=c[a+12>>2]|0;g=DD(e)|0;if((g|0)<=0){i=b;return}h=b|0;j=f+156680|0;f=0;do{DD(e)|0;k=DD(e)|0;l=DD(e)|0;m=DD(e)|0;n=FD(e)|0;o=MD(e,l,h,1024)|0;if((o|0)<(l|0)){p=l-o|0;hD(e,p,(p|0)<0|0?-1:0)|0;}do{if((irc(h,2229864)|0)==0){p=c[d>>2]|0;if((m|0)==2){q=DD(p)|0}else if((m|0)==5){q=DD(p)|0}else if((m|0)==4){o=GD(p)|0;q=o}else if((m|0)==3){q=FD(p)|0}else{q=-2147483648}if((k|0)>=128){break}c[j+(k<<3)>>2]=q}else{if((irc(h,2226136)|0)!=0){VB(a,h,m,n,16);break}p=c[d>>2]|0;if((m|0)==4){o=GD(p)|0;r=o}else if((m|0)==5){r=DD(p)|0}else if((m|0)==3){r=FD(p)|0}else if((m|0)==2){r=DD(p)|0}else{r=-2147483648}if((k|0)>=128){break}c[j+(k<<3)+4>>2]=r}}while(0);f=f+1|0;}while((f|0)<(g|0));i=b;return}function VB(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;h=i;i=i+168|0;j=h|0;k=h+8|0;l=h+88|0;m=h+152|0;n=h+160|0;o=b+16|0;p=fD(c[o>>2]|0,0,0,1)|0;q=G;if(f>>>0>2147483635>>>0){i=h;return}r=f<<1;s=hJb(r+22|0)|0;c[n>>2]=s;a:do{if((s|0)!=0){if((e|0)==1){if((irc(d,2297232)|0)!=0){if((irc(d,2287240)|0)!=0){KIb(b,40,2283016,(t=i,i=i+8|0,c[t>>2]=d,t)|0);i=t;break}c[j>>2]=0;MI(b,2287240,j);if((c[j>>2]|0)!=0){PI(b,j)|0}NI(j);break}u=k;v=l|0;w=m;mrc(u|0,0,80)|0;c[m>>2]=0;if((f|0)<9){KIb(b,16,2265712,(t=i,i=i+8|0,c[t>>2]=f,t)|0);i=t;break}x=zD(c[o>>2]|0)|0;if(x>>>0>20>>>0|(x|0)<0){KIb(b,24,2262192,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;y=0}else{y=x}x=FD(c[o>>2]|0)|0;z=f-5|0;A=z-(MD(c[o>>2]|0,z,v,64)|0)|0;z=1372896;while(1){B=c[z+32>>2]|0;if((B|0)==0){C=14;break}if((krc(z|0,v,64)|0)==0){break}else{z=z+36|0}}if((C|0)==14){KIb(b,16,2258168,(t=i,i=i+8|0,c[t>>2]=v,t)|0);i=t;break}if((x|0)>=(A|0)){KIb(b,16,2254200,(t=i,i=i+16|0,c[t>>2]=x,c[t+8>>2]=A,t)|0);i=t;break}z=A-x|0;D=z<<1|1;E=hJb(D)|0;c[m>>2]=E;if((E|0)==0){break}MD(c[o>>2]|0,z,E,D)|0;do{if((fX(c[o>>2]|0,k,x)|0)>=0){D=ZX(b,0)|0;if((D|0)==0){break}E=D+72|0;c[E>>2]=c[E>>2]|1024;E=c[D+8>>2]|0;c[E+8>>2]=0;c[E+48>>2]=B;nrc(D+104|0,u|0,80)|0;c[D+136>>2]=c[D>>2];E=D+140|0;c[E>>2]=c[E>>2]|1;E=c[m>>2]|0;if((a[E]|0)==0){mJb(w);F=D+88|0}else{z=D+88|0;MGb(z,2246344,E,8)|0;F=z}MGb(F,2237584,c[1372808+(y<<2)>>2]|0,0)|0;break a}}while(0);mJb(w);P1(k);break}else if((e|0)==(-1|0)){AD(c[o>>2]|0,s,f)|0;a[(c[n>>2]|0)+f|0]=0}else if((e|0)==0){MD(c[o>>2]|0,f,s,r|1)|0}else{if(!((e-2|0)>>>0<4>>>0)){u=b;if((e|0)==6){KIb(u,48,2274928,(t=i,i=i+8|0,c[t>>2]=d,t)|0);i=t;break}else{KIb(u,48,2269992,(t=i,i=i+16|0,c[t>>2]=e,c[t+8>>2]=d,t)|0);i=t;break}}u=c[o>>2]|0;do{if((e|0)==4){x=GD(u)|0;H=x}else if((e|0)==5){H=DD(u)|0}else if((e|0)==2){if((g|0)==32){H=FD(u)|0;break}else{H=DD(u)|0;break}}else if((e|0)==3){H=FD(u)|0}else{H=-2147483648}}while(0);Rb(c[n>>2]|0,22,2279144,(t=i,i=i+16|0,c[t>>2]=H,c[t+8>>2]=(H|0)<0|0?-1:0,t)|0)|0;i=t}u=c[n>>2]|0;if((a[u]|0)==0){break}MGb(b+1140|0,d,u,0)|0}}while(0);mJb(n);n=c[o>>2]|0;o=wrc(p,q,f,(f|0)<0|0?-1:0)|0;fD(n,o,G,0)|0;i=h;return}function WB(a){a=a|0;var d=0,e=0,f=0,g=0;d=c[a+12>>2]|0;e=a+1076|0;c[e>>2]=3200;f=d+155656|0;c[f>>2]=0;c[f+4>>2]=0;c[d+159040>>2]=hJb(12288)|0;c[d+159044>>2]=512;b[d+159048>>1]=0;if((aC(a,0,0,50,0)|0)<0){g=-1;return g|0}eD(c[a+16>>2]|0);c[d+155696>>2]=0;mrc(d+155680|0,-1|0,16)|0;$C(d+158904|0,d+155700|0,c[e>>2]|0,1,0,0,0,0)|0;e=a+1204|0;if((c[e>>2]|0)>=0){g=0;return g|0}c[e>>2]=1;g=0;return g|0}function XB(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;g=b+12|0;h=c[g>>2]|0;j=c[e+36>>2]|0;k=fD(c[b+16>>2]|0,0,0,1)|0;l=G;m=c[e+32>>2]|0;n=(c[(c[b+28>>2]|0)+(m<<2)>>2]|0)+8|0;o=h+8|0;p=(c[(c[n>>2]|0)+8>>2]|0)==1?j&-2:j;j=e+8|0;q=c[j>>2]|0;r=c[j+4>>2]|0;j=e+16|0;do{if((q|0)==0&(r|0)==(-2147483648|0)){s=c[j>>2]|0;t=c[j+4>>2]|0;if(!((s|0)==0&(t|0)==(-2147483648|0))){u=t;v=s;break}KIb(0,0,2558208,(s=i,i=i+24|0,c[s>>2]=2484272,c[s+8>>2]=2523720,c[s+16>>2]=886,s)|0);i=s;Hd();return 0}else{u=r;v=q}}while(0);q=Erc(v,u,1e4,0)|0;u=G;v=h+155664|0;r=c[v>>2]|0;s=c[v+4>>2]|0;t=(c[e+48>>2]|0)*1e4|0;w=wrc(t,(t|0)<0|0?-1:0,q,u)|0;t=G;x=(s|0)>(t|0)|(s|0)==(t|0)&r>>>0>w>>>0;c[v>>2]=x?r:w;c[v+4>>2]=x?s:t;t=h+155656|0;s=c[t>>2]|0;x=c[t+4>>2]|0;v=s;w=c[j>>2]|0;r=c[j+4>>2]|0;j=c[e+28>>2]|0;y=c[g>>2]|0;if((j|0)>0){z=c[e+24>>2]|0;e=y+155680|0;A=y+155676|0;B=y+155672|0;C=wrc(w,r,3100,0)|0;D=o+(m*1216|0)|0;E=(p&1|0)==0;F=o+(m*1216|0)+4|0;H=C;C=y+158904|0;I=y+155688|0;J=y+155696|0;y=z;z=0;while(1){K=j-z|0;a:do{if((c[e>>2]|0)==(-1|0)&(c[e+4>>2]|0)==(-1|0)){L=11}else{while(1){M=c[A>>2]|0;N=M-29|0;if((N|0)>=(K|0)){break}if((c[(c[n>>2]|0)+8>>2]|0)!=1){break}_B(b);if((c[e>>2]|0)==(-1|0)&(c[e+4>>2]|0)==(-1|0)){L=11;break a}}if((N|0)>0){O=N;L=14;break}P=0;Q=M;R=a[B]|0}}while(0);if((L|0)==11){L=0;S=(K|0)<3154;a[B]=S&1;c[A>>2]=3200;c[e>>2]=w;c[e+4>>2]=r;O=S?3153:3174;L=14}if((L|0)==14){L=0;if((K|0)>(O|0)){T=O}else{T=(K|0)==(O-1|0)?O-2|0:K}S=c[g>>2]|0;U=S+158904|0;V=c[D>>2]|0;bD(U,E?V:V|128);bD(U,d[F]|0);kD(U,z);bD(U,8);kD(U,j);kD(U,H);if((a[S+155672|0]|0)!=0){oD(U,T)}dD(C,y,T);U=a[B]|0;S=(U<<24>>24==0?-15:-17)-T+(c[A>>2]|0)|0;c[A>>2]=S;c[I>>2]=w;c[I+4>>2]=r;c[J>>2]=(c[J>>2]|0)+1;P=T;Q=S;R=U}U=P+z|0;S=y+P|0;do{if(R<<24>>24==0){_B(b)}else{if((Q|0)>=30){break}_B(b)}}while(0);if((U|0)<(j|0)){y=S;z=U}else{W=F;break}}}else{W=o+(m*1216|0)+4|0}a[W]=(a[W]|0)+1;W=wrc(q,u,40999999,0)|0;u=Crc(W,G,1e7,0)|0;W=u;do{if((c[h+4>>2]|0)==0){if((p&1|0)==0){break}u=xrc(c[t>>2]|0,c[t+4>>2]|0,s,x)|0;q=$B(c[g>>2]|0,W,v,u&65535,k,l)|0;if((q|0)<0){X=q}else{break}i=f;return X|0}}while(0);c[h+159076>>2]=W;X=0;i=f;return X|0}function YB(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a+12|0;f=c[d>>2]|0;if((c[f+158916>>2]|0)>>>0>(c[f+158908>>2]|0)>>>0){_B(a)}g=a+16|0;h=fD(c[g>>2]|0,0,0,1)|0;i=G;j=f+4|0;do{if((c[j>>2]|0)==0){k=f+159072|0;if((c[k>>2]|0)==0){break}l=$B(c[d>>2]|0,(c[f+159076>>2]|0)+1|0,0,0,0,0)|0;if((l|0)<0){m=l;return m|0}l=c[f+159040>>2]|0;n=b[f+159048>>1]|0;o=c[k>>2]|0;k=c[g>>2]|0;VS(k,1431304);rD(k,(o*6|0)+56|0,0);VS(k,8779896);rD(k,1e7,0);kD(k,n&65535);kD(k,o);if((o|0)==0){break}else{p=0}do{kD(k,c[l+(p*24|0)>>2]|0);oD(k,e[l+(p*24|0)+4>>1]|0);p=p+1|0;}while(p>>>0<o>>>0)}}while(0);eD(c[g>>2]|0);p=c[g>>2]|0;do{if((c[j>>2]|0)==0){if((c[p+88>>2]|0)==0){q=10;break}o=fD(p,0,0,1)|0;l=G;fD(c[g>>2]|0,0,0,0)|0;k=f+159032|0;n=xrc(h,i,c[k>>2]|0,c[k+4>>2]|0)|0;aC(a,o,l,n,G)|0}else{q=10}}while(0);if((q|0)==10){q=c[d>>2]|0;oD(p,17700);oD(p,8);d=q;kD(p,c[d>>2]|0);oD(p,0);oD(p,8);c[d>>2]=(c[d>>2]|0)+1}mJb(f+159040|0);m=0;return m|0}function ZB(a){a=a|0;var d=0,e=0,f=0,g=0;d=c[a+12>>2]|0;c[d+4>>2]=1;e=a+1076|0;c[e>>2]=3200;f=d+155656|0;c[f>>2]=0;c[f+4>>2]=0;c[d+159040>>2]=hJb(12288)|0;c[d+159044>>2]=512;b[d+159048>>1]=0;if((aC(a,0,0,50,0)|0)<0){g=-1;return g|0}eD(c[a+16>>2]|0);c[d+155696>>2]=0;mrc(d+155680|0,-1|0,16)|0;$C(d+158904|0,d+155700|0,c[e>>2]|0,1,0,0,0,0)|0;e=a+1204|0;if((c[e>>2]|0)>=0){g=0;return g|0}c[e>>2]=1;g=0;return g|0}function _B(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=b+12|0;f=c[e>>2]|0;g=f+155688|0;h=c[g>>2]|0;j=c[g+4>>2]|0;k=f+155680|0;l=k;m=c[l>>2]|0;n=c[l+4>>2]|0;if((j|0)<(n|0)|(j|0)==(n|0)&h>>>0<m>>>0){KIb(0,0,2558208,(o=i,i=i+24|0,c[o>>2]=2540648,c[o+8>>2]=2523720,c[o+16>>2]=704,o)|0);i=o;Hd()}if((c[f+4>>2]|0)==0){p=n;q=m;r=j;s=h;t=f;u=b+16|0}else{h=b+16|0;j=c[h>>2]|0;m=(c[b+1076>>2]|0)+8|0;oD(j,17444);oD(j,m);n=f;kD(j,c[n>>2]|0);oD(j,0);oD(j,m);c[n>>2]=(c[n>>2]|0)+1;p=c[l+4>>2]|0;q=c[l>>2]|0;r=c[g+4>>2]|0;s=c[g>>2]|0;t=c[e>>2]|0;u=h}h=q;e=xrc(s,r,q,p)|0;p=e;e=f+155696|0;q=c[e>>2]|0;r=f+155676|0;s=c[r>>2]|0;g=c[u>>2]|0;l=fD(g,0,0,1)|0;n=G;m=t+155672|0;t=((a[m]|0)==0?-11:-12)+s|0;if(!((t|0)>-1)){KIb(0,0,2558208,(o=i,i=i+24|0,c[o>>2]=2494624,c[o+8>>2]=2523720,c[o+16>>2]=665,o)|0);i=o;Hd()}bD(g,130);bD(g,0);bD(g,0);s=(a[m]|0)!=0|0;do{if((t|0)>0){if((t|0)<256){v=s|8;break}else{v=s|16;break}}else{v=s}}while(0);bD(g,v);bD(g,93);if((v&16|0)!=0){oD(g,t-2|0)}if((v&8|0)!=0){bD(g,t-1|0)}kD(g,h);oD(g,p);if((a[m]|0)!=0){bD(g,q|128)}q=fD(g,0,0,1)|0;g=xrc(q,G,l,n)|0;n=g;g=c[r>>2]|0;if((n|0)>(g|0)){KIb(0,0,2558208,(o=i,i=i+24|0,c[o>>2]=2508768,c[o+8>>2]=2523720,c[o+16>>2]=716,o)|0);i=o;Hd()}else{o=f+155700|0;mrc(f+(158900-g)|0,0,g|0)|0;g=b+1076|0;dD(c[u>>2]|0,o,(c[g>>2]|0)-n|0);eD(c[u>>2]|0);u=f+155656|0;n=wrc(c[u>>2]|0,c[u+4>>2]|0,1,0)|0;c[u>>2]=n;c[u+4>>2]=G;c[e>>2]=0;mrc(k|0,-1|0,16)|0;$C(f+158904|0,o,c[g>>2]|0,1,0,0,0,0)|0;i=d;return}}function $B(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=a+159072|0;j=c[i>>2]|0;do{if((j|0)<(d|0)){if((j|0)==0){c[a+159052>>2]=e;b[a+159056>>1]=f;k=a+159064|0;c[k>>2]=g;c[k+4>>2]=h}k=a+159044|0;do{if((c[k>>2]|0)>>>0<d>>>0){l=d+512&-512;c[k>>2]=l;m=oJb(a+159040|0,l,24)|0;if((m|0)>=0){n=c[i>>2]|0;break}c[k>>2]=0;o=m;return o|0}else{n=j}}while(0);if((n|0)>=(d|0)){break}k=a+159052|0;m=c[a+159040>>2]|0;l=a+159056|0;p=a+159064|0;q=n;do{c[m+(q*24|0)>>2]=c[k>>2];b[m+(q*24|0)+4>>1]=b[l>>1]|0;r=c[i>>2]|0;s=Erc(r,(r|0)<0|0?-1:0,1e7,0)|0;r=m+(q*24|0)+8|0;c[r>>2]=s;c[r+4>>2]=G;r=c[p+4>>2]|0;s=m+(q*24|0)+16|0;c[s>>2]=c[p>>2];c[s+4>>2]=r;q=q+1|0;}while((q|0)<(d|0))}}while(0);n=a+159048|0;j=b[n>>1]|0;b[n>>1]=(j&65535)>>>0>(f&65535)>>>0?j:f;c[a+159052>>2]=e;b[a+159056>>1]=f;f=a+159064|0;c[f>>2]=g;c[f+4>>2]=h;c[i>>2]=d;o=0;return o|0}function aC(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;h=i;i=i+80|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=h+64|0;s=h+72|0;t=b+12|0;u=c[t>>2]|0;v=b+16|0;w=c[v>>2]|0;x=b+1140|0;cL(x,1431456,0);y=LGb(c[x>>2]|0,2188896,0,0)|0;z=LGb(c[x>>2]|0,2158816,0,0)|0;A=LGb(c[x>>2]|0,2133560,0,0)|0;B=LGb(c[x>>2]|0,2110080,0,0)|0;C=LGb(c[x>>2]|0,2627872,0,0)|0;D=u+155664|0;E=wrc(c[D>>2]|0,c[D+4>>2]|0,31e6,0)|0;F=G;H=(y|0)==0;if(H&(z|0)==0&(A|0)==0){I=(C|0)!=0|(B|0)!=0}else{I=1}J=KGb(c[x>>2]|0)|0;K=b+24|0;if((c[K>>2]|0)==0){L=0}else{M=b+28|0;N=0;O=0;while(1){P=c[(c[M>>2]|0)+(O<<2)>>2]|0;Q=c[P+8>>2]|0;_X(P,32,1,1e3);P=(c[Q+72>>2]|0)+N|0;Q=O+1|0;if(Q>>>0<(c[K>>2]|0)>>>0){N=P;O=Q}else{L=P;break}}}O=u+4|0;if((c[O>>2]|0)!=0){N=c[t>>2]|0;M=c[v>>2]|0;oD(M,18468);oD(M,8);P=N;kD(M,c[P>>2]|0);oD(M,3072);oD(M,8);c[P>>2]=(c[P>>2]|0)+1}VS(w,1431640);rD(w,-1,-1);P=(J|0)!=0;kD(w,(P&1)+(I?4:3)+(c[K>>2]|0)|0);bD(w,1);bD(w,2);M=fD(w,0,0,1)|0;N=G;Q=fD(w,0,0,1)|0;R=G;VS(w,1431688);rD(w,24,0);VS(w,8779896);rD(w,d,e);rD(w,-717324288,27111902);e=u+155656|0;rD(w,c[e>>2]|0,c[e+4>>2]|0);rD(w,E,F);rD(w,c[D>>2]|0,c[D+4>>2]|0);rD(w,3100,0);if((c[O>>2]|0)==0){S=(c[w+88>>2]|0)==0?3:2}else{S=3}kD(w,S);S=b+1076|0;kD(w,c[S>>2]|0);kD(w,c[S>>2]|0);kD(w,L);L=fD(w,0,0,1)|0;S=G;D=wrc(Q,R,16,0)|0;fD(w,D,G,0)|0;D=xrc(L,S,Q,R)|0;rD(w,D,G);fD(w,L,S,0)|0;S=fD(w,0,0,1)|0;L=G;VS(w,1431672);rD(w,24,0);VS(w,1431656);kD(w,6);oD(w,0);D=fD(w,0,0,1)|0;R=G;Q=wrc(S,L,16,0)|0;fD(w,Q,G,0)|0;Q=xrc(D,R,S,L)|0;rD(w,Q,G);fD(w,D,R,0)|0;if(I){if((_D(q)|0)<0){T=-12;i=h;return T|0}I=fD(w,0,0,1)|0;R=G;VS(w,1431912);rD(w,24,0);if(H){U=0}else{U=nD(c[q>>2]|0,c[y+4>>2]|0)|0}oD(w,U);if((z|0)==0){V=0}else{V=nD(c[q>>2]|0,c[z+4>>2]|0)|0}oD(w,V);if((A|0)==0){W=0}else{W=nD(c[q>>2]|0,c[A+4>>2]|0)|0}oD(w,W);if((B|0)==0){X=0}else{X=nD(c[q>>2]|0,c[B+4>>2]|0)|0}oD(w,X);if((C|0)==0){Y=0}else{Y=nD(c[q>>2]|0,c[C+4>>2]|0)|0}oD(w,Y);Y=aE(c[q>>2]|0,p)|0;dD(w,c[p>>2]|0,Y);mJb(p);p=fD(w,0,0,1)|0;Y=G;q=wrc(I,R,16,0)|0;fD(w,q,G,0)|0;q=xrc(p,Y,I,R)|0;rD(w,q,G);fD(w,p,Y,0)|0;}if(P){P=fD(w,0,0,1)|0;Y=G;VS(w,1431704);rD(w,24,0);oD(w,J);J=LGb(c[x>>2]|0,10230728,0,2)|0;if((J|0)!=0){p=n;q=l;R=J;do{J=c[R>>2]|0;if((_D(o)|0)>=0){nD(c[o>>2]|0,J)|0;J=aE(c[o>>2]|0,n)|0;oD(w,J);dD(w,c[n>>2]|0,J);mJb(p)}oD(w,0);J=c[R+4>>2]|0;if((_D(m)|0)>=0){nD(c[m>>2]|0,J)|0;J=aE(c[m>>2]|0,l)|0;oD(w,J);dD(w,c[l>>2]|0,J);mJb(q)}R=LGb(c[x>>2]|0,10230728,R,2)|0;}while((R|0)!=0)}R=fD(w,0,0,1)|0;x=G;q=wrc(P,Y,16,0)|0;fD(w,q,G,0)|0;q=xrc(R,x,P,Y)|0;rD(w,q,G);fD(w,R,x,0)|0;}do{if((c[O>>2]|0)==0){x=b+1132|0;if((c[x>>2]|0)==0){break}R=j;q=c[t>>2]|0;Y=c[v>>2]|0;P=fD(Y,0,0,1)|0;l=G;VS(Y,1431592);rD(Y,24,0);VS(Y,1431320);kD(Y,c[x>>2]|0);oD(Y,0);oD(Y,0);a:do{if((c[x>>2]|0)!=0){m=b+1136|0;p=q+159032|0;n=q+159072|0;o=q+159040|0;J=0;while(1){I=c[(c[m>>2]|0)+(J<<2)>>2]|0;C=LGb(c[I+32>>2]|0,2188896,0,0)|0;X=I+16|0;B=XIb(c[X>>2]|0,c[X+4>>2]|0,I+4|0,2013568)|0;I=G;X=wrc(c[p>>2]|0,c[p+4>>2]|0,50,0)|0;W=G;A=c[n>>2]|0;b:do{if((A|0)>0){V=c[o>>2]|0;z=0;U=0;y=W;H=X;while(1){D=V+(z*24|0)+8|0;Q=c[D>>2]|0;L=c[D+4>>2]|0;if(!(L>>>0<I>>>0|L>>>0==I>>>0&Q>>>0<B>>>0)){Z=U;_=y;$=H;break b}L=V+(z*24|0)+16|0;D=c[L>>2]|0;S=c[L+4>>2]|0;L=z+1|0;F=(Q|0)/1e4|0;if((L|0)<(A|0)){z=L;U=F;y=S;H=D}else{Z=F;_=S;$=D;break}}}else{Z=0;_=W;$=X}}while(0);X=(C|0)!=0;if(X){if((_D(k)|0)<0){T=-12;break}nD(c[k>>2]|0,c[C+4>>2]|0)|0;aa=aE(c[k>>2]|0,j)|0}else{aa=0}rD(Y,$,_);W=wrc(B,I,31e6,0)|0;rD(Y,W,G);oD(Y,aa+12|0);kD(Y,Z);kD(Y,0);kD(Y,(aa|0)/2|0);if(X){dD(Y,c[j>>2]|0,aa);mJb(R)}J=J+1|0;if(!(J>>>0<(c[x>>2]|0)>>>0)){break a}}i=h;return T|0}}while(0);x=fD(Y,0,0,1)|0;R=G;q=wrc(P,l,16,0)|0;fD(Y,q,G,0)|0;q=xrc(x,R,P,l)|0;rD(Y,q,G);fD(Y,x,R,0)|0;}}while(0);aa=b+28|0;c:do{if((c[K>>2]|0)!=0){b=u+8|0;j=0;while(1){Z=c[(c[(c[aa>>2]|0)+(j<<2)>>2]|0)+8>>2]|0;_=j+1|0;c[b+(j*1216|0)>>2]=_;a[b+(j*1216|0)+4|0]=1;$=Z+8|0;if((c[$>>2]|0)==1){ba=18;ca=8}else{ba=(c[Z+100>>2]|0)+51|0;ca=0}k=fD(w,0,0,1)|0;v=G;VS(w,1431288);rD(w,24,0);if((c[$>>2]|0)==1){VS(w,1431976);VS(w,1431992)}else{VS(w,1431168);VS(w,1431184)}rD(w,0,0);t=fD(w,0,0,1)|0;R=G;kD(w,ba);kD(w,ca);oD(w,_);kD(w,0);if((c[$>>2]|0)==1){$=US(w,Z)|0;if(($|0)<0){T=-1;break}if(($|0)!=(ba|0)){x=fD(w,0,0,1)|0;q=G;fD(w,t,R,0)|0;kD(w,$);fD(w,x,q,0)|0;}bD(w,1);do{if((c[Z+48>>2]|0)==69643){da=52}else{q=Z+432|0;x=c[q>>2]|0;if((x|0)==0){da=52;break}oD(w,x);oD(w,c[q>>2]|0)}}while(0);if((da|0)==52){da=0;oD(w,400);oD(w,400)}oD(w,1);bD(w,0)}else{kD(w,c[Z+120>>2]|0);kD(w,c[Z+124>>2]|0);bD(w,2);oD(w,(c[Z+100>>2]|0)+40|0);XS(w,Z,1409152,1,0)}q=fD(w,0,0,1)|0;x=G;$=wrc(k,v,16,0)|0;fD(w,$,G,0)|0;$=xrc(q,x,k,v)|0;rD(w,$,G);fD(w,q,x,0)|0;if(_>>>0<(c[K>>2]|0)>>>0){j=_}else{break c}}i=h;return T|0}}while(0);ba=fD(w,0,0,1)|0;ca=G;VS(w,1431944);rD(w,24,0);VS(w,1431960);kD(w,c[K>>2]|0);j=r;b=0;while(1){if(!(b>>>0<(c[K>>2]|0)>>>0)){da=72;break}Y=c[(c[(c[aa>>2]|0)+(b<<2)>>2]|0)+8>>2]|0;l=Y+48|0;P=b5a(c[l>>2]|0)|0;x=Y+8|0;q=c[x>>2]|0;if((q|0)==1){oD(w,2)}else if((q|0)==0){oD(w,1)}else{oD(w,-1)}do{if((c[l>>2]|0)==86024){ea=2577216}else{if((P|0)==0){ea=Y+16|0;break}else{ea=c[P>>2]|0;break}}}while(0);if((_D(s)|0)<0){T=-12;da=75;break}nD(c[s>>2]|0,ea)|0;P=aE(c[s>>2]|0,r)|0;oD(w,(P|0)/2|0);dD(w,c[r>>2]|0,P);mJb(j);oD(w,0);if((c[x>>2]|0)==1){oD(w,2);oD(w,c[Y+52>>2]|0)}else{oD(w,4);kD(w,c[Y+52>>2]|0)}if((c[Y+52>>2]|0)==0){T=-1;da=75;break}else{b=b+1|0}}if((da|0)==72){b=fD(w,0,0,1)|0;j=G;r=wrc(ba,ca,16,0)|0;fD(w,r,G,0)|0;r=xrc(b,j,ba,ca)|0;rD(w,r,G);fD(w,b,j,0)|0;j=fD(w,0,0,1)|0;b=G;r=xrc(j,b,M,N)|0;ca=r;if((c[O>>2]|0)!=0){O=ca+88|0;r=wrc(M,N,-40,-1)|0;fD(w,r,G,0)|0;oD(w,O);r=wrc(M,N,-32,-1)|0;fD(w,r,G,0)|0;oD(w,O)}O=ca+30|0;ca=wrc(M,N,-14,-1)|0;fD(w,ca,G,0)|0;rD(w,O,(O|0)<0|0?-1:0);fD(w,j,b,0)|0;O=u+159032|0;c[O>>2]=j;c[O+4>>2]=b;VS(w,1431880);rD(w,f,g);VS(w,8779896);rD(w,c[e>>2]|0,c[e+4>>2]|0);bD(w,1);bD(w,1);T=0;i=h;return T|0}else if((da|0)==75){i=h;return T|0}return 0}function bC(a){a=a|0;var b=0;b=c[a+4>>2]|0;if((grc(b,2225328,13)|0)==0){return 100}else{a=(grc(b+3|0,2225328,13)|0)==0;return(a?100:0)|0}return 0}function cC(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+2112|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+1088|0;p=c[b+12>>2]|0;q=ZX(b,0)|0;if((q|0)==0){r=-12;i=d;return r|0}_X(q,64,1,100);s=q+8|0;q=c[s>>2]|0;c[q+8>>2]=3;c[q+48>>2]=94212;SFb(n,0,-1);SFb(o,0,-1);q=b+16|0;b=o|0;t=p;p=o+4|0;u=2147483647;a:while(1){v=c[q>>2]|0;w=fD(v,0,0,1)|0;x=G;ZFb(o);do{y=(zD(v)|0)&255;if(y<<24>>24==0){break}WFb(o,y,1);}while(!(y<<24>>24==10));v=c[b>>2]|0;y=a[v]|0;if(y<<24>>24==0){break}do{if((grc(v,2405608,8)|0)==0){z=2}else{A=y<<24>>24==91?2147483647:u;if((A|0)!=0){z=A;break}A=Bd(v|0,2274200,(B=i,i=i+64|0,c[B>>2]=e,c[B+8>>2]=f,c[B+16>>2]=g,c[B+24>>2]=h,c[B+32>>2]=j,c[B+40>>2]=k,c[B+48>>2]=l,c[B+56>>2]=m,B)|0)|0;i=B;if((A|0)==8){A=c[j>>2]|0;C=Erc(A,(A|0)<0|0?-1:0,3600,0)|0;A=G;D=c[k>>2]|0;E=Erc(D,(D|0)<0|0?-1:0,60,0)|0;D=wrc(E,G,C,A)|0;A=c[l>>2]|0;C=wrc(D,G,A,(A|0)<0|0?-1:0)|0;A=Erc(C,G,100,0)|0;C=wrc(A,G,c[m>>2]|0,0)|0;A=G;D=c[e>>2]|0;E=Erc(D,(D|0)<0|0?-1:0,3600,0)|0;D=G;F=c[f>>2]|0;H=Erc(F,(F|0)<0|0?-1:0,60,0)|0;F=wrc(H,G,E,D)|0;D=c[g>>2]|0;E=wrc(F,G,D,(D|0)<0|0?-1:0)|0;D=Erc(E,G,100,0)|0;E=c[h>>2]|0;F=wrc(D,G,E,(E|0)<0|0?-1:0)|0;E=G;D=xrc(C,A,F,E)|0;I=0;J=D;K=E;L=F}else{I=1;J=-1;K=-2147483648;L=0}if(I){u=0;continue a}F=IV(t,c[b>>2]|0,c[p>>2]|0,0)|0;if((F|0)==0){r=-12;M=17;break a}E=F+64|0;c[E>>2]=w;c[E+4>>2]=x;E=F+8|0;c[E>>2]=L;c[E+4>>2]=K;c[F+48>>2]=J;u=0;continue a}}while(0);UFb(n,2330200,(B=i,i=i+8|0,c[B>>2]=v,B)|0);i=B;u=z-1|0}if((M|0)==17){i=d;return r|0}_Fb(o,0)|0;o=T5a(c[s>>2]|0,n)|0;if((o|0)<0){r=o;i=d;return r|0}JV(t);r=o;i=d;return r|0}function dC(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function eC(a){a=a|0;OV(c[a+12>>2]|0);return 0}function fC(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function gC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;d=c[a+12>>2]|0;e=c[c[a+28>>2]>>2]|0;f=c[e+8>>2]|0;do{if((c[a+24>>2]|0)==1){g=c[f+48>>2]|0;if(!((g|0)==94212|(g|0)==1095979808)){break}c[d+4>>2]=(g|0)==1095979808;_X(e,64,1,100);g=d;h=c[g>>2]|0;j=f+100|0;k=c[j>>2]|0;a:do{if(h>>>0<k>>>0){l=f+96|0;m=a+16|0;n=0;o=h;p=k;while(1){q=c[l>>2]|0;r=q+o|0;s=_b(r|0,10)|0;if((s|0)==0){t=q+p|0}else{t=s+1|0}s=t-r|0;dD(c[m>>2]|0,r,s);q=(c[g>>2]|0)+s|0;c[g>>2]=q;if((n|0)!=0){if((grc(n,2158704,8)|0)==0){u=m;break a}}s=c[j>>2]|0;if(q>>>0<s>>>0){n=r;o=q;p=s}else{u=m;break}}}else{u=a+16|0}}while(0);eD(c[u>>2]|0);v=0;i=b;return v|0}}while(0);KIb(a,16,2188808,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;v=-1;i=b;return v|0}function hC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+8|0;f=e|0;if((c[(c[b+12>>2]|0)+4>>2]|0)==0){dD(c[b+16>>2]|0,c[d+24>>2]|0,c[d+28>>2]|0);i=e;return 0}g=d+8|0;h=c[g>>2]|0;j=c[g+4>>2]|0;g=c[d+48>>2]|0;k=wrc(g,(g|0)<0|0?-1:0,h,j)|0;g=G;l=c[d+24>>2]|0;d=l+((mc(l|0,2274184)|0)+1)|0;c[f>>2]=d;l=rb(d|0,f|0,10)|0;d=c[f>>2]|0;if((a[d]|0)==44){m=d+1|0;c[f>>2]=m;n=m}else{n=d}d=Crc(h,j,36e4,0)|0;m=d;d=Crc(h,j,6e3,0)|0;f=Crc(k,g,36e4,0)|0;o=f;f=Crc(k,g,6e3,0)|0;p=Crc(h,j,100,0)|0;q=Drc(h,j,100,0)|0;j=Crc(k,g,100,0)|0;h=Drc(k,g,100,0)|0;g=(m|0)>9;k=(o|0)>9;YD(c[b+16>>2]|0,2225232,(b=i,i=i+80|0,c[b>>2]=l,c[b+8>>2]=g?9:m,c[b+16>>2]=g?59:(d|0)%60|0,c[b+24>>2]=g?59:(p|0)%60|0,c[b+32>>2]=g?99:q,c[b+40>>2]=k?9:o,c[b+48>>2]=k?59:(f|0)%60|0,c[b+56>>2]=k?59:(j|0)%60|0,c[b+64>>2]=k?99:h,c[b+72>>2]=n,b)|0)|0;i=b;i=e;return 0}function iC(a){a=a|0;var b=0,d=0;b=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;d=c[c[a+12>>2]>>2]|0;dD(c[a+16>>2]|0,(c[b+96>>2]|0)+d|0,(c[b+100>>2]|0)-d|0);return 0}function jC(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1297241171){e=0;return e|0}a=b+10|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){e=12;return e|0}a=b+12|0;f=(d[a]|d[a+1|0]<<8)<<16>>16;if(f<<16>>16==0|((he(f|0)|0)&65535)>>>0>256>>>0){e=12;return e|0}else{e=b+16|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=(b|0)==0|(je(b|0)|0)>>>0>384e3>>>0;return(e?12:66)|0}return 0}function kC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=ZX(a,0)|0;if((d|0)==0){e=-12;i=b;return e|0}f=a+16|0;hD(c[f>>2]|0,8,0)|0;g=d+8|0;c[(c[g>>2]|0)+8>>2]=1;h=JX(1411592,HD(c[f>>2]|0)|0)|0;c[(c[g>>2]|0)+48>>2]=h;h=HD(c[f>>2]|0)|0;if((h|0)!=16){QIb(a,2330152,(a=i,i=i+8|0,c[a>>2]=h,a)|0);i=a;e=-1094995529;i=b;return e|0}a=HD(c[f>>2]|0)|0;h=c[g>>2]|0;c[h+416>>2]=a;if((a|0)==4){j=h+448|0;c[j>>2]=263;c[j+4>>2]=0}else if((a|0)==2){j=h+448|0;c[j>>2]=3;c[j+4>>2]=0}else if((a|0)==0){e=-1094995529;i=b;return e|0}hD(c[f>>2]|0,2,0)|0;a=JD(c[f>>2]|0)|0;c[(c[g>>2]|0)+412>>2]=a;if((a|0)<1){e=-1094995529;i=b;return e|0}a=d+48|0;c[a>>2]=0;c[a+4>>2]=0;a=d+56|0;c[a>>2]=JD(c[f>>2]|0)|0;c[a+4>>2]=0;hD(c[f>>2]|0,40,0)|0;_X(d,64,1,c[(c[g>>2]|0)+412>>2]|0);e=0;i=b;return e|0}function lC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a+16|0;if((jD(c[e>>2]|0)|0)!=0){f=-541478725;i=d;return f|0}g=fD(c[e>>2]|0,0,0,1)|0;h=G;j=FD(c[e>>2]|0)|0;k=JD(c[e>>2]|0)|0;l=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+416>>2]|0;if(k>>>0>(2147483647/(l|0)|0)>>>0){f=-1094995529;i=d;return f|0}m=ca(l,k)|0;k=hD(c[e>>2]|0,24,0)|0;l=k;if((l|0)<0){f=l;i=d;return f|0}if((j|0)==1262701634){l=fX(c[e>>2]|0,b,m)|0;c[b+32>>2]=0;k=b+64|0;c[k>>2]=g;c[k+4>>2]=h;f=l;i=d;return f|0}else{KIb(a,16,2405440,(a=i,i=i+8|0,c[a>>2]=j,a)|0);i=a;hD(c[e>>2]|0,m,0)|0;f=-1094995529;i=d;return f|0}return 0}function mC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((c[a+24>>2]|0)!=1){KIb(a,16,2188776,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}h=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;j=c[h+48>>2]|0;if((j|0)==1095123744){KIb(a,16,2158664,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1163346256;i=b;return g|0}k=IX(1411592,j)|0;if((k|0)==0){KIb(a,16,2133464,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}j=d+32|0;l=c[j>>2]|0;m=c[j+4>>2]|0;n=0;o=(m|0)>(n|0)|(m|0)==(n|0)&l>>>0>0>>>0;n=d+24|0;p=c[n>>2]|0;q=c[n+4>>2]|0;if(!((q|0)<(m|0)|(q|0)==(m|0)&p>>>0<l>>>0|o^1)){KIb(a,16,2110032,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}n=0;do{if((q|0)>(n|0)|(q|0)==(n|0)&p>>>0>0>>>0){r=d+24|0;s=c[h+412>>2]|0;t=UIb(p,q,s,(s|0)<0|0?-1:0,1e3,0,2)|0;s=G;c[r>>2]=t;c[r+4>>2]=s;r=0;if(!(s>>>0>r>>>0|s>>>0==r>>>0&t>>>0>-1>>>0)){break}KIb(a,16,2627840,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}}while(0);q=h+412|0;do{if(o){p=c[q>>2]|0;n=UIb(l,m,p,(p|0)<0|0?-1:0,1e3,0,2)|0;p=G;c[j>>2]=n;c[j+4>>2]=p;t=0;if(!(p>>>0>t>>>0|p>>>0==t>>>0&n>>>0>-1>>>0)){break}KIb(a,16,2602568,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}}while(0);kD(e,1297241171);f=fD(e,0,0,1)|0;a=d+8|0;c[a>>2]=f;c[a+4>>2]=G;lD(e,0);tD(e,k);tD(e,16);tD(e,c[h+416>>2]|0);tD(e,0);lD(e,c[q>>2]|0);q=fD(e,0,0,1)|0;h=d+16|0;c[h>>2]=q;c[h+4>>2]=G;lD(e,0);lD(e,0);lD(e,0);lD(e,0);lD(e,0);kD(e,127);sD(e,0,0);sD(e,0,0);lD(e,0);eD(e);g=0;i=b;return g|0}function nC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;f=b+28|0;g=(c[f>>2]|0)/(c[e+416>>2]|0)|0;if((c[e+428>>2]|0)==1){c[(c[a+12>>2]|0)+40>>2]=g}kD(d,1262701634);lD(d,g);sD(d,0,0);sD(d,0,0);sD(d,0,0);dD(d,c[b+24>>2]|0,c[f>>2]|0);return 0}function oC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=a+16|0;e=c[d>>2]|0;f=c[a+12>>2]|0;g=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;h=fD(e,0,0,1)|0;j=G;k=wrc(h,j,-64,-1)|0;l=c[g+428>>2]<<5;m=xrc(k,G,l,(l|0)<0|0?-1:0)|0;l=c[g+432>>2]|0;g=Crc(m,G,l,(l|0)<0|0?-1:0)|0;l=G;m=a;KIb(m,48,2405416,(a=i,i=i+16|0,c[a>>2]=g,c[a+8>>2]=l,a)|0);i=a;if((c[(c[d>>2]|0)+88>>2]|0)==0){i=b;return 0}d=f+16|0;fD(e,c[d>>2]|0,c[d+4>>2]|0,0)|0;d=g;lD(e,d);n=f+24|0;o=c[n>>2]|0;p=c[n+4>>2]|0;q=0;do{if((p|0)>(q|0)|(p|0)==(q|0)&o>>>0>0>>>0){if((p|0)<(l|0)|(p|0)==(l|0)&o>>>0<g>>>0){lD(e,o);break}else{KIb(m,24,2330096,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c[n>>2]=-1;c[n+4>>2]=-1;hD(e,4,0)|0;break}}else{hD(e,4,0)|0;}}while(0);o=f+32|0;p=c[o>>2]|0;q=c[o+4>>2]|0;do{if((p|0)==0&(q|0)==0){r=12}else{s=c[n+4>>2]|0;t=-1;if(!((s|0)>(t|0)|(s|0)==(t|0)&(c[n>>2]|0)>>>0>-1>>>0)){r=12;break}if((q|0)>(l|0)|(q|0)==(l|0)&p>>>0>g>>>0){KIb(m,24,2274128,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c[o>>2]=g;c[o+4>>2]=l;u=g}else{u=p}lD(e,u)}}while(0);if((r|0)==12){lD(e,d)}lD(e,c[f+40>>2]|0);d=f+8|0;fD(e,c[d>>2]|0,c[d+4>>2]|0,0)|0;lD(e,k);k=c[n+4>>2]|0;d=-1;if((k|0)>(d|0)|(k|0)==(d|0)&(c[n>>2]|0)>>>0>-1>>>0){hD(e,6,0)|0;tD(e,65535)}fD(e,h,j,0)|0;eD(e);i=b;return 0}function pC(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==46){if((a[d+1|0]|0)!=115){break}if((a[d+2|0]|0)!=110){break}if((a[d+3|0]|0)==100){e=100}else{break}return e|0}}while(0);e=0;return e|0}function qC(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;e=c[a+16>>2]|0;if((FD(e)|0)!=1684960046){f=-1094995529;i=b;return f|0}g=JD(e)|0;h=JD(e)|0;j=(h|0)==-1;if((h|0)<-1){KIb(a,16,2158560,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;f=-1094995529;i=b;return f|0}l=JD(e)|0;m=JD(e)|0;n=JD(e)|0;if((g|0)>24){o=g-24|0;hD(e,o,(o|0)<0|0?-1:0)|0;}o=JX(1689344,l)|0;if((o|0)==0){QIb(a,2133368,(k=i,i=i+8|0,c[k>>2]=l,k)|0);i=k;f=-1163346256;i=b;return f|0}e=g5a(o)|0;do{if((o|0)==909260615){if((l|0)==926037554){p=2;break}g=l-23|0;if(g>>>0<4>>>0){p=d[2004752+g|0]|0;break}else{KIb(0,0,2109968,(k=i,i=i+24|0,c[k>>2]=2627784,c[k+8>>2]=2602520,c[k+16>>2]=114,k)|0);i=k;Hd();return 0}}else{if((e|0)!=0){p=e;break}QIb(a,2577064,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;f=-1163346256;i=b;return f|0}}while(0);do{if((n|0)!=0){if(!(n>>>0<(2147483647/(p<<7|0)|0)>>>0)){break}if((m|0)<1){KIb(a,16,2540544,(k=i,i=i+8|0,c[k>>2]=m,k)|0);i=k;f=-1094995529;i=b;return f|0}e=ZX(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=c[e+8>>2]|0;c[g+8>>2]=1;c[g+52>>2]=l;c[g+48>>2]=o;c[g+416>>2]=n;c[g+412>>2]=m;c[g+792>>2]=p;c[g+72>>2]=ca(ca(n,m)|0,p)|0;q=ca(n,p)|0;if((q|0)>15){r=(q|0)/8|0}else{r=1}c[g+432>>2]=r;if(!j){g=h;q=Erc(n,(n|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;s=Crc(g<<3|0>>>29,((h|0)<0|0?-1:0)<<3|g>>>29,q,G)|0;q=e+56|0;c[q>>2]=s;c[q+4>>2]=G}q=e+48|0;c[q>>2]=0;c[q+4>>2]=0;_X(e,64,1,m);f=0;i=b;return f|0}}while(0);KIb(a,16,2558120,(k=i,i=i+8|0,c[k>>2]=n,k)|0);i=k;f=-1094995529;i=b;return f|0}function rC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[a+24>>2]|0)!=1){KIb(a,16,2274032,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}h=IX(1689344,c[e+48>>2]|0)|0;j=e+52|0;c[j>>2]=h;if((h|0)==0){KIb(a,16,2224952,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else{kD(d,1684960046);lD(d,32);lD(d,-1);lD(d,c[j>>2]|0);lD(d,c[e+412>>2]|0);lD(d,c[e+416>>2]|0);sD(d,0,0);eD(d);g=0;i=b;return g|0}return 0}function sC(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+16|0;a=c[b>>2]|0;d=fD(a,0,0,1)|0;e=G;f=0;if(!((c[(c[b>>2]|0)+88>>2]|0)!=0&((e|0)<(f|0)|(e|0)==(f|0)&d>>>0<2147483647>>>0))){return 0}fD(a,8,0,0)|0;f=wrc(d,e,-32,0)|0;lD(a,f);fD(a,d,e,0)|0;eD(a);return 0}function tC(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;a=b+8|0;do{if((grc(b,1967960,4)|0)==0){if((grc(a,1967964,4)|0)==0){d=100}else{break}return d|0}}while(0);do{if((grc(b,1967968,4)|0)==0){if((grc(a,1967972,4)|0)==0){d=100}else{break}return d|0}}while(0);do{if((grc(b,1967976,4)|0)==0){if((grc(a,1967980,4)|0)==0){d=100}else{break}return d|0}}while(0);do{if((grc(b,1967984,4)|0)==0){if((grc(a,1967988,4)|0)==0){d=100}else{break}return d|0}}while(0);do{if((grc(b,1967992,4)|0)==0){if((grc(a,1967996,4)|0)==0){d=100}else{break}return d|0}}while(0);d=0;return d|0}function uC(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0;e=i;i=i+248|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+64|0;o=e+72|0;p=e+80|0;q=e+144|0;r=e+152|0;s=e+216|0;t=e+224|0;u=e+232|0;v=e+240|0;w=v;x=c[b+12>>2]|0;y=b+16|0;z=c[y>>2]|0;c[x+68>>2]=-1;A=q|0;AD(z,A,4)|0;B=x+8|0;c[B>>2]=FD(z)|0;c[B+4>>2]=0;C=fD(z,0,0,1)|0;D=wrc(c[B>>2]|0,c[B+4>>2]|0,C,G)|0;c[B>>2]=D;c[B+4>>2]=G;AD(z,q+4|0,4)|0;D=0;while(1){if((D|0)==5){E=-1094995529;F=225;break}if((grc(A,1967960+(D<<3)|0,8)|0)==0){break}else{D=D+1|0}}if((F|0)==225){i=e;return E|0}if((a[q+7|0]|0)==25){KIb(b,32,2287136,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}q=x+80|0;KIb(x,48,2494504,(H=i,i=i+8|0,c[H>>2]=c[q>>2],H)|0);i=H;D=iD(z)|0;A=G;C=x+24|0;c[C>>2]=D;c[C+4>>2]=A;I=x+32|0;c[I>>2]=D;c[I+4>>2]=A;J=0;K=c[B>>2]|0;L=c[B+4>>2]|0;if((A|0)<(J|0)|(A|0)==(J|0)&D>>>0<1>>>0|((A|0)<(L|0)|(A|0)==(L|0)&D>>>0<K>>>0)){D=(K|0)==8&(L|0)==0;c[C>>2]=D?-1:K;c[C+4>>2]=D?2147483647:L}if((jD(z)|0)!=0){E=-1094995529;i=e;return E|0}L=p|0;D=b+1140|0;K=p+4|0;A=p+7|0;p=r|0;J=l|0;l=m|0;m=r+4|0;M=r+7|0;r=x+60|0;N=x+64|0;O=b+24|0;P=b;Q=b+28|0;R=x+72|0;S=b+1064|0;T=z+88|0;U=b+1084|0;V=b+1156|0;W=u+4|0;X=u|0;Y=t|0;Z=t+4|0;_=k|0;$=k;k=0;aa=0;ba=0;ca=0;da=0;ea=0;fa=0;ga=-1;ha=-1;a:while(1){ia=FD(z)|0;ja=FD(z)|0;b:do{if((ia|0)==1718776947){if((ja|0)==0){ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break}do{if(ga>>>0<(c[O>>2]|0)>>>0){if((c[R>>2]|0)!=0){break}ta=fD(z,0,0,1)|0;ua=G;if(ua>>>0<da>>>0|ua>>>0==da>>>0&ta>>>0<ea>>>0){va=0;wa=xrc(ea,da,ta,ua)|0;ua=G;xa=va>>>0>ua>>>0|va>>>0==ua>>>0&ja>>>0>wa>>>0?wa:ja}else{xa=ja}wa=c[(c[Q>>2]|0)+(ga<<2)>>2]|0;ua=wa+8|0;va=c[ua>>2]|0;ta=va+8|0;if(!((c[ta>>2]|0)==-1)){hD(z,xa,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}if((ha|0)==1){ya=OS(z,va,xa)|0;if((ya|0)<0){E=ya;F=225;break a}ya=c[ua>>2]|0;za=ya+432|0;Aa=k+1076|0;c[Aa>>2]=c[za>>2];Ba=k+24|0;Ca=c[Ba>>2]|0;do{if((Ca|0)==0){Da=ya}else{Ea=c[za>>2]|0;if((Ea|0)==0|(Ca|0)==(Ea|0)){Da=ya;break}KIb(P,24,2414720,(H=i,i=i+16|0,c[H>>2]=Ca,c[H+8>>2]=Ea,H)|0);i=H;Ea=c[ua>>2]|0;c[Ba>>2]=c[Ea+432>>2];Da=Ea}}while(0);if((xa&1|0)==0){Fa=Da}else{hD(z,1,0)|0;Fa=c[ua>>2]|0}Ca=wa+236|0;c[Ca>>2]=3;ya=Fa+48|0;za=c[ya>>2]|0;do{if((za|0)==86018){if((c[Fa+100>>2]|0)==0){break}c[Ca>>2]=0}}while(0);if((c[Fa+56>>2]|0)==1851881537){c[ya>>2]=81922;c[Fa+52>>2]=0;c[Aa>>2]=0;Ga=81922}else{Ga=za}if((ca|0)!=0){c[ya>>2]=69651;c[Aa>>2]=0;ka=1;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}c:do{if((Ga|0)==86018){Ca=c[Aa>>2]|0;do{if((Ca|0)>4|(Ca|0)==0){Ea=c[Aa>>2]|0;if((Ea|0)!=1024){Ha=Ea;break}if((c[Ba>>2]|0)==1024){break c}else{F=129}}else{KIb(P,48,2399384,(H=i,i=i+8|0,c[H>>2]=Ca,H)|0);i=H;c[Aa>>2]=0;Ea=c[(c[ua>>2]|0)+48>>2]|0;if((Ea|0)==86018){F=129}else{Ia=Ea;F=132;break c}}}while(0);if((F|0)==129){F=0;Ha=c[Aa>>2]|0}if((Ha|0)!=4096){Ia=86018;F=132;break}if((c[Ba>>2]|0)!=4096){Ia=86018;F=132}}else{Ia=Ga;F=132}}while(0);if((F|0)==132){F=0;if((Ia|0)!=86017){ka=1;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}if((c[Aa>>2]|0)!=1152){ka=1;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}if((c[Ba>>2]|0)!=1152){ka=1;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}}KIb(P,48,2392440,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[Ba>>2]=0;ka=1;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}else if((ha|0)==0){if((ca|0)!=0){c[va+120>>2]=aa;c[va+124>>2]=ba;c[ta>>2]=0;c[va+48>>2]=108;hD(z,xa,0)|0;ka=0;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}ya=QS(z,wa,s)|0;if((ya|0)==1112758340|(ya|0)==1095981124){za=c[ua>>2]|0;c[za+8>>2]=3;c[za+52>>2]=ya;c[za+48>>2]=94211;ka=0;la=ga;ma=fa;na=da;oa=ea;pa=0;qa=ba;ra=aa;sa=k;break b}do{if((xa-41|0)>>>0<1073741783>>>0){za=0;Ca=c[C+4>>2]|0;if(!((za|0)<(Ca|0)|(za|0)==(Ca|0)&xa>>>0<(c[C>>2]|0)>>>0)){break}Ca=c[s>>2]|0;if((Ca|0)!=(xa-1|0)|(Ca&1|0)==0){za=xa-40|0;Ea=c[ua>>2]|0;c[Ea+100>>2]=za;Ja=Ea;Ka=za}else{za=Ca-40|0;Ca=c[ua>>2]|0;c[Ca+100>>2]=za;Ja=Ca;Ka=za}if((QX(Ja,z,Ka)|0)<0){E=-12;F=225;break a}}}while(0);Ba=c[ua>>2]|0;Aa=c[Ba+100>>2]|0;if((Aa&1|0)==0){La=Ba;Ma=Aa}else{zD(z)|0;Aa=c[ua>>2]|0;La=Aa;Ma=c[Aa+100>>2]|0}do{if((Ma|0)!=0){Aa=c[La+792>>2]|0;if((Aa|0)>=9){break}Ba=4<<Aa;Aa=(Ba|0)>(Ma|0)?Ma:Ba;Ba=c[La+96>>2]|0;za=Ma-Aa|0;Ca=(Aa|0)/4|0;if((Aa|0)>3){Aa=0;do{Ea=Ba+(za+(Aa<<2))|0;c[k+48+(Aa<<2)>>2]=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|-16777216;Aa=Aa+1|0;}while((Aa|0)<(Ca|0))}c[k+1072>>2]=1}}while(0);c[La+8>>2]=0;c[La+52>>2]=ya;Ca=JX(1409152,ya)|0;Aa=c[ua>>2]|0;c[Aa+48>>2]=Ca;Ca=wa+236|0;c[Ca>>2]=2;za=c[Aa+52>>2]|0;do{if((za|0)==1213420374){c[Ca>>2]=1;Na=Aa}else if((za|0)==0){if((c[Aa+124>>2]|0)<=0){Na=Aa;break}Ba=Aa+100|0;Ea=c[Ba>>2]|0;if(!(Ea>>>0<1073741824>>>0)){Na=Aa;break}c[Ba>>2]=Ea+9;Oa=lJb(Aa+96|0,Ea+25|0)|0;Pa=c[ua>>2]|0;if((Oa|0)<0){F=108;break a}nrc((c[Pa+96>>2]|0)+((c[Pa+100>>2]|0)-9)|0,2425568,9)|0;Na=c[ua>>2]|0}else{Na=Aa}}while(0);Aa=Na+124|0;ua=c[Aa>>2]|0;c[Aa>>2]=(ua|0)>-1?ua:-ua|0;ka=0;la=ga;ma=fa;na=da;oa=ea;pa=0;qa=ba;ra=aa;sa=k;break b}else if((ha|0)==3){c[ta>>2]=3;c[wa+440>>2]=1;hD(z,xa,0)|0;ka=3;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}else{c[ta>>2]=2;c[va+48>>2]=0;c[va+52>>2]=0;hD(z,xa,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}}}while(0);hD(z,ja,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k}else if((ia|0)==2019847785){ua=fD(z,0,0,1)|0;Aa=ua;do{if((c[T>>2]|0)!=0){if((c[U>>2]&2|0)!=0){break}if((c[q>>2]|0)==0){break}if((AC(b,0)|0)>=0){break}if((c[V>>2]&8|0)!=0){E=-1094995529;F=225;break a}}}while(0);fD(z,Aa+ja|0,0,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k}else if((ia|0)==1886548086){if(ga>>>0<(c[O>>2]|0)>>>0&ja>>>0>36>>>0){ua=c[(c[Q>>2]|0)+(ga<<2)>>2]|0;FD(z)|0;FD(z)|0;FD(z)|0;FD(z)|0;FD(z)|0;za=DD(z)|0;c[W>>2]=za;Ca=DD(z)|0;c[X>>2]=Ca;ya=FD(z)|0;c[Y>>2]=ya;Ea=FD(z)|0;c[Z>>2]=Ea;FD(z)|0;if(!((Ca|0)==0|(za|0)==0|(ya|0)==0|(Ea|0)==0)){zKb(w,u,t);Ea=ua+80|0;ua=c[v+4>>2]|0;c[Ea>>2]=c[v>>2];c[Ea+4>>2]=ua}Qa=ja-36|0}else{Qa=ja}hD(z,Qa,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k}else if((ia|0)==1685222515){do{if(ga>>>0<(c[O>>2]|0)>>>0){ua=c[(c[(c[Q>>2]|0)+(ga<<2)>>2]|0)+8>>2]|0;if((c[ua+100>>2]|0)!=0){break}if((c[ua+52>>2]|0)==875967048){break}ua=fD(z,0,0,1)|0;Ea=G;if(Ea>>>0<da>>>0|Ea>>>0==da>>>0&ua>>>0<ea>>>0){ya=0;za=xrc(ea,da,ua,Ea)|0;Ea=G;Ra=ya>>>0>Ea>>>0|ya>>>0==Ea>>>0&ja>>>0>za>>>0?za:ja}else{Ra=ja}za=(c[(c[Q>>2]|0)+(ga<<2)>>2]|0)+8|0;if(Ra>>>0<1073741824>>>0){if((QX(c[za>>2]|0,z,Ra)|0)<0){E=-12;F=225;break a}}if((c[(c[za>>2]|0)+100>>2]&1|0)==0){ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}zD(z)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break b}}while(0);hD(z,ja,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k}else if((ia|0)==1751936356){c[r>>2]=1;hD(z,(ja&1)+ja|0,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k}else if((ia|0)==1414087753){mrc(p|0,0,64)|0;Aa=(ja&1)+ja|0;hD(z,Aa-(AD(z,p,Aa>>>0>63>>>0?63:Aa)|0)|0,0)|0;Aa=Bd(p|0,2319688,(H=i,i=i+32|0,c[H>>2]=J,c[H+8>>2]=n,c[H+16>>2]=l,c[H+24>>2]=o,H)|0)|0;i=H;if((Aa|0)==4){Sa=0}else{if((a[m]|0)!=47){ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break}if((a[M]|0)!=47){ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break}a[M]=45;a[m]=45;MGb(D,2310440,p,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break}while(1){if((IFb(J,827296+(Sa<<2)|0)|0)==0){Aa=Sa+1|0;za=c[n>>2]|0;Rb(L|0,64,2315016,(H=i,i=i+32|0,c[H>>2]=c[o>>2],c[H+8>>2]=Aa,c[H+16>>2]=za,c[H+24>>2]=l,H)|0)|0;i=H;MGb(D,2310440,L,0)|0;Ta=Aa}else{Ta=Sa+1|0}if((Ta|0)<12){Sa=Ta}else{ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break}}}else if((ia|0)==1414744396){Aa=fD(z,0,0,1)|0;Ua=ja;Va=0;za=wrc(Aa,G,Ua,Va)|0;Aa=G;Ea=FD(z)|0;if((Ea|0)==1769369453){F=12;break a}else if((Ea|0)==1330007625){RS(b,ja-4|0,0)|0;ka=ha;la=ga;ma=fa;na=Aa;oa=za;pa=ca;qa=ba;ra=aa;sa=k;break}else if((Ea|0)!=1952736110){ka=ha;la=ga;ma=fa;na=Aa;oa=za;pa=ca;qa=ba;ra=aa;sa=k;break}Ea=fD(c[y>>2]|0,0,0,1)|0;ya=G;if(!(ya>>>0<Aa>>>0|ya>>>0==Aa>>>0&Ea>>>0<za>>>0)){ka=ha;la=ga;ma=fa;na=Aa;oa=za;pa=ca;qa=ba;ra=aa;sa=k;break}while(1){Ea=FD(c[y>>2]|0)|0;ya=FD(c[y>>2]|0)|0;ua=c[y>>2]|0;do{if((Ea|0)==1735680878){Ca=fD(ua,0,0,1)|0;Ba=wrc(Ca,G,ya,0)|0;Ca=G;Wa=fD(c[y>>2]|0,0,0,1)|0;Xa=G;if(!(Xa>>>0<Ca>>>0|Xa>>>0==Ca>>>0&Wa>>>0<Ba>>>0)){break}do{Wa=DD(c[y>>2]|0)|0;Xa=DD(c[y>>2]|0)|0;mrc(L|0,0,64)|0;Ya=0;Za=fD(c[y>>2]|0,0,0,1)|0;_a=xrc(Ba,Ca,Za,G)|0;Za=G;if(Ya>>>0>Za>>>0|Ya>>>0==Za>>>0&(Xa&65535)>>>0>_a>>>0){_a=fD(c[y>>2]|0,0,0,1)|0;Za=xrc(Ba,Ca,_a,G)|0;$a=Za&65535}else{$a=Xa&65535}Xa=$a&65535;Za=Xa-(AD(c[y>>2]|0,L,($a&65535)>>>0>63>>>0?63:Xa)|0)|0;Xa=Wa&65535;do{if((Xa|0)==3){ab=2306232;F=27}else if((Xa|0)==19){if((a[K]|0)!=58){ab=2310440;F=27;break}if((a[A]|0)!=58){ab=2310440;F=27;break}a[A]=45;a[K]=45;ab=2310440;F=27}else if((Xa|0)==4){ab=2297216;F=27}}while(0);if((F|0)==27){F=0;MGb(D,ab,L,0)|0}hD(c[y>>2]|0,Za&65535,0)|0;Xa=fD(c[y>>2]|0,0,0,1)|0;Wa=G;}while(Wa>>>0<Ca>>>0|Wa>>>0==Ca>>>0&Xa>>>0<Ba>>>0)}else{hD(ua,ya,0)|0;}}while(0);ya=fD(c[y>>2]|0,0,0,1)|0;ua=G;if(!(ua>>>0<Aa>>>0|ua>>>0==Aa>>>0&ya>>>0<za>>>0)){ka=ha;la=ga;ma=fa;na=Aa;oa=za;pa=ca;qa=ba;ra=aa;sa=k;break}}}else if((ia|0)==1752591713){bb=1;F=41}else if((ia|0)==1751742049){bb=ca;F=41}else if((ia|0)==1752331379){za=FD(z)|0;Aa=FD(z)|0;if((za|0)==1935958384){hD(z,ja-8|0,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k;break}ya=ga+1|0;ua=ZX(b,0)|0;if((ua|0)==0){E=-1094995529;F=225;break a}c[ua+4>>2]=ya;Ea=pJb(1184)|0;va=Ea;if((Ea|0)==0){E=-1094995529;F=225;break a}c[ua+12>>2]=Ea;if((ca|0)==0){cb=za}else{cb=(ya|0)!=0?1935963489:1935960438}if((cb|0)==1937138025|(cb|0)==1935767145){if((c[O>>2]|0)!=1){E=-1094995529;F=225;break a}if(!((Aa|0)==1819506276|(Aa|0)==1685288548|(Aa|0)==1684567652)){E=-1094995529;F=225;break a}za=c[c[Q>>2]>>2]|0;ta=c[za+12>>2]|0;wa=ta;mJb((c[za+8>>2]|0)+96|0);mJb((c[c[Q>>2]>>2]|0)+8|0);za=c[c[Q>>2]>>2]|0;Ba=c[za+184>>2]|0;if((Ba|0)==0){db=za}else{mJb(Ba+32|0);db=c[c[Q>>2]>>2]|0}mJb(db+184|0);mJb(c[Q>>2]|0);c[O>>2]=0;Ba=KF(b)|0;c[R>>2]=Ba;if((Ba|0)==0){E=-1094995529;F=225;break a}c[(c[c[Q>>2]>>2]|0)+12>>2]=ta;hD(z,12,0)|0;Ba=ta+16|0;c[Ba>>2]=FD(z)|0;za=ta+20|0;c[za>>2]=FD(z)|0;hD(z,4,0)|0;ta=FD(z)|0;Ca=ta;Xa=0;Wa=c[Ba>>2]|0;do{if((Wa|0)!=0){Ba=c[za>>2]|0;if((Ba|0)==0|(ta|0)==0){break}_a=Erc(Ca,Xa,1e6,0)|0;Ya=VIb(_a,G,Wa,0,Ba,0)|0;c[S>>2]=Ya;c[S+4>>2]=G}}while(0);Wa=(c[O>>2]|0)-1|0;hD(z,ja-36|0,0)|0;ka=ha;la=Wa;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=wa;break}if(!(ya>>>0<(c[O>>2]|0)>>>0)){F=59;break a}c[(c[ua+8>>2]|0)+56>>2]=Aa;FD(z)|0;DD(z)|0;DD(z)|0;FD(z)|0;Wa=Ea+16|0;c[Wa>>2]=FD(z)|0;Xa=FD(z)|0;Ca=Ea+20|0;c[Ca>>2]=Xa;ta=c[Wa>>2]|0;do{if((ta|0)==0|(Xa|0)==0){KIb(P,24,2472904,(H=i,i=i+16|0,c[H>>2]=ta,c[H+8>>2]=Xa,H)|0);i=H;if((fa|0)==0){c[Ca>>2]=25;c[Wa>>2]=1;eb=1;fb=25;break}else{c[Ca>>2]=1e6;c[Wa>>2]=fa;eb=fa;fb=1e6;break}}else{eb=ta;fb=Xa}}while(0);_X(ua,64,eb,fb);Xa=Ea+32|0;c[Xa>>2]=FD(z)|0;c[Xa+4>>2]=0;ta=ua+64|0;c[ta>>2]=FD(z)|0;c[ta+4>>2]=0;Aa=ua+48|0;c[Aa>>2]=0;c[Aa+4>>2]=0;FD(z)|0;FD(z)|0;Aa=Erc(c[Wa>>2]|0,0,c[Xa>>2]|0,c[Xa+4>>2]|0)|0;wa=Crc(Aa,G,c[Ca>>2]|0,0)|0;Aa=G;za=0;if((Aa|0)>(za|0)|(Aa|0)==(za|0)&wa>>>0>3600>>>0){F=65;break a}wa=FD(z)|0;za=Ea+24|0;c[za>>2]=wa;Aa=(wa|0)<1;Ya=Erc(Aa?1:wa,Aa?0:(wa|0)<0|0?-1:0,c[Xa>>2]|0,c[Xa+4>>2]|0)|0;c[Xa>>2]=Ya;c[Xa+4>>2]=G;if((cb|0)==1935960438){c[za>>2]=0;gb=0;F=72}else if((cb|0)==1937012852){hb=3;ib=wa;F=71}else if((cb|0)==1937006948){hb=2;ib=wa;F=71}else if((cb|0)==1935963489){hb=1;ib=wa;F=71}else{KIb(P,32,2450920,(H=i,i=i+8|0,c[H>>2]=cb,H)|0);i=H;hb=ha;ib=c[za>>2]|0;F=71}if((F|0)==71){F=0;if((ib|0)==0){gb=hb;F=72}else{jb=hb}}do{if((F|0)==72){F=0;za=c[ta>>2]|0;wa=c[ta+4>>2]|0;Ya=ua+56|0;c[Ya>>2]=za;c[Ya+4>>2]=wa;Aa=0;if(!((wa|0)>(Aa|0)|(wa|0)==(Aa|0)&za>>>0>0>>>0)){jb=gb;break}za=c[I>>2]|0;Aa=c[I+4>>2]|0;wa=0;if(!((Aa|0)>(wa|0)|(Aa|0)==(wa|0)&za>>>0>0>>>0)){jb=gb;break}wa=c[B+4>>2]|0;if(!((wa|0)>(Aa|0)|(wa|0)==(Aa|0)&(c[B>>2]|0)>>>0>za>>>0)){jb=gb;break}KIb(P,48,2434496,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;za=VIb(c[Ya>>2]|0,c[Ya+4>>2]|0,c[I>>2]|0,c[I+4>>2]|0,c[B>>2]|0,c[B+4>>2]|0)|0;c[Ya>>2]=za;c[Ya+4>>2]=G;jb=gb}}while(0);ua=c[Xa+4>>2]|0;ta=Ea;c[ta>>2]=c[Xa>>2];c[ta+4>>2]=ua;hD(z,ja-48|0,0)|0;ka=jb;la=ya;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=va}else if((ia|0)==1852994675){ua=c[O>>2]|0;if((ua|0)==0){F=164;break}ta=c[(c[Q>>2]|0)+(ua-1<<2)>>2]|0;ua=c[y>>2]|0;mrc(_|0,0,5)|0;Ca=(ja&1)+ja|0;if((Ca|0)==-1){E=-22;F=225;break a}Wa=hJb(Ca+1|0)|0;if((Wa|0)==0){E=-12;F=225;break a}AD(ua,Wa,Ca)|0;a[Wa+Ca|0]=0;c[$>>2]=1852994675;Ca=MGb((ta|0)==0?D:ta+88|0,_,Wa,8)|0;if((Ca|0)<0){E=Ca;F=225;break a}else{ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k}}else{F=164}}while(0);if((F|0)==41){F=0;ia=FD(z)|0;FD(z)|0;FD(z)|0;Ca=(FD(z)|0)&32;c[N>>2]=c[N>>2]|Ca;hD(z,8,0)|0;FD(z)|0;FD(z)|0;Ca=FD(z)|0;Wa=FD(z)|0;hD(z,ja-40|0,0)|0;ka=ha;la=ga;ma=ia;na=da;oa=ea;pa=bb;qa=Wa;ra=Ca;sa=k}else if((F|0)==164){F=0;if(ja>>>0>1e6>>>0){F=165;break}hD(z,(ja&1)+ja|0,0)|0;ka=ha;la=ga;ma=fa;na=da;oa=ea;pa=ca;qa=ba;ra=aa;sa=k}if((jD(z)|0)==0){k=sa;aa=ra;ba=qa;ca=pa;da=na;ea=oa;fa=ma;ga=la;ha=ka}else{E=-1094995529;F=225;break}}do{if((F|0)==12){ka=fD(z,0,0,1)|0;ha=wrc(ka,G,-4,-1)|0;ka=G;la=x+40|0;c[la>>2]=ha;c[la+4>>2]=ka;if((ja|0)==0){la=c[C+4>>2]|0;ma=x+16|0;c[ma>>2]=c[C>>2];c[ma+4>>2]=la;break}else{la=wrc(ja&1,0,Ua,Va)|0;ma=wrc(la,G,ha,ka)|0;ka=x+16|0;c[ka>>2]=ma;c[ka+4>>2]=G;break}}else if((F|0)==59){KIb(0,0,2405168,(H=i,i=i+24|0,c[H>>2]=2484240,c[H+8>>2]=2273896,c[H+16>>2]=549,H)|0);i=H;Hd();return 0}else if((F|0)==65){KIb(P,16,2464728,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;E=-1094995529;i=e;return E|0}else if((F|0)==108){c[Pa+100>>2]=0;E=Oa;i=e;return E|0}else if((F|0)==165){KIb(P,16,2385728,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;if((c[V>>2]&8|0)==0){ka=fD(z,0,0,1)|0;ma=wrc(ka,G,-4,-1)|0;ka=x+40|0;c[ka>>2]=ma;c[ka+4>>2]=G;ka=c[C+4>>2]|0;ma=x+16|0;c[ma>>2]=c[C>>2];c[ma+4>>2]=ka;break}else{E=-1094995529;i=e;return E|0}}else if((F|0)==225){i=e;return E|0}}while(0);if((ga|0)!=((c[O>>2]|0)-1|0)){E=-1094995529;i=e;return E|0}ga=x+56|0;x=c[ga>>2]|0;do{if((x|0)==0){if((c[T>>2]|0)==0){kb=0;break}yC(b);kb=c[ga>>2]|0}else{kb=x}}while(0);c[ga>>2]=kb|1;kb=fD(c[y>>2]|0,0,0,1)|0;ga=G;x=c[O>>2]|0;if((x|0)==0){fD(c[y>>2]|0,kb,ga,0)|0;F=180}else{T=2147483647;C=-1;z=0;V=0;Oa=0;Pa=x;while(1){x=c[(c[Q>>2]|0)+(Oa<<2)>>2]|0;Va=c[x+404>>2]|0;if((Va|0)<1){lb=z;mb=V;nb=T;ob=C;pb=Pa}else{Ua=x+400|0;x=c[Ua>>2]|0;if((Va|0)>1){ja=x|0;ka=c[ja>>2]|0;ma=c[ja+4>>2]|0;ja=c[y>>2]|0;ha=wrc(ka,ma,4,0)|0;fD(ja,ha,G,0)|0;ha=wrc(FD(c[y>>2]|0)|0,0,ka,ma)|0;ma=G;ka=c[Ua>>2]|0;Ua=ka+24|0;ja=c[Ua+4>>2]|0;la=(ma|0)>(ja|0)|(ma|0)==(ja|0)&ha>>>0>(c[Ua>>2]|0)>>>0;qb=la?2147483647:z;rb=la?-1:V;sb=c[O>>2]|0;tb=ka}else{qb=z;rb=V;sb=Pa;tb=x}x=tb|0;ka=c[x>>2]|0;la=c[x+4>>2]|0;x=(la|0)>(qb|0)|(la|0)==(qb|0)&ka>>>0>rb>>>0;Ua=tb+((Va-1|0)*24|0)|0;Va=c[Ua>>2]|0;ha=c[Ua+4>>2]|0;Ua=(ha|0)<(T|0)|(ha|0)==(T|0)&Va>>>0<C>>>0;lb=x?la:qb;mb=x?ka:rb;nb=Ua?ha:T;ob=Ua?Va:C;pb=sb}Va=Oa+1|0;if(Va>>>0<pb>>>0){T=nb;C=ob;z=lb;V=mb;Oa=Va;Pa=pb}else{break}}fD(c[y>>2]|0,kb,ga,0)|0;if((lb|0)>(nb|0)|(lb|0)==(nb|0)&mb>>>0>ob>>>0){ub=1}else{F=180}}do{if((F|0)==180){ob=qJb(c[O>>2]|0,4)|0;mb=ob;if((ob|0)==0){ub=0;break}nb=f|0;lb=f+4|0;ga=g|0;kb=g+4|0;y=h|0;pb=h+4|0;Pa=j|0;Oa=j+4|0;V=0;z=0;C=0;T=0;while(1){if((z|0)==(-1|0)&(V|0)==2147483647){F=198;break}if((c[O>>2]|0)==0){vb=2147483647;wb=-1;xb=-1073741824;yb=0;zb=1073741823;Ab=-1}else{sb=2147483647;rb=-1;qb=-1073741824;tb=0;Va=1073741823;Ua=-1;ha=0;while(1){ka=c[(c[Q>>2]|0)+(ha<<2)>>2]|0;x=c[ka+12>>2]|0;la=c[ka+404>>2]|0;ja=mb+(ha<<2)|0;ma=c[ja>>2]|0;d:do{if((ma|0)<(la|0)){fa=c[ka+400>>2]|0;oa=ma;while(1){ea=fa+(oa*24|0)|0;na=c[ea+4>>2]|0;if(!((na|0)<(C|0)|(na|0)==(C|0)&(c[ea>>2]|0)>>>0<T>>>0)){Bb=oa;break d}ea=oa+1|0;c[ja>>2]=ea;if((ea|0)<(la|0)){oa=ea}else{Bb=ea;break}}}else{Bb=ma}}while(0);if((Bb|0)<(la|0)){ma=ka+400|0;oa=(c[ma>>2]|0)+(Bb*24|0)+8|0;fa=x+24|0;ea=c[fa>>2]|0;na=(ea|0)>1;da=Crc(c[oa>>2]|0,c[oa+4>>2]|0,na?ea:1,na?(ea|0)<0|0?-1:0:0)|0;ea=ka+40|0;c[nb>>2]=1;c[lb>>2]=1e6;na=XIb(da,G,ea,f)|0;da=G;if((Va|0)>(da|0)|(Va|0)==(da|0)&Ua>>>0>na>>>0){na=(c[ma>>2]|0)+((c[ja>>2]|0)*24|0)+8|0;da=c[fa>>2]|0;fa=(da|0)>1;oa=Crc(c[na>>2]|0,c[na+4>>2]|0,fa?da:1,fa?(da|0)<0|0?-1:0:0)|0;c[ga>>2]=1;c[kb>>2]=1e6;da=XIb(oa,G,ea,g)|0;Cb=G;Db=da}else{Cb=Va;Db=Ua}da=c[ja>>2]|0;ea=(c[ma>>2]|0)+(da*24|0)|0;ma=c[ea>>2]|0;oa=c[ea+4>>2]|0;ea=(sb|0)>(oa|0)|(sb|0)==(oa|0)&rb>>>0>ma>>>0;Eb=Cb;Fb=Db;Gb=ea?oa:sb;Hb=ea?ma:rb;Ib=da}else{Eb=Va;Fb=Ua;Gb=sb;Hb=rb;Ib=Bb}do{if((Ib|0)==0){Jb=qb;Kb=tb}else{da=ka+400|0;ma=(c[da>>2]|0)+((Ib-1|0)*24|0)+8|0;ea=x+24|0;oa=c[ea>>2]|0;fa=(oa|0)>1;na=Crc(c[ma>>2]|0,c[ma+4>>2]|0,fa?oa:1,fa?(oa|0)<0|0?-1:0:0)|0;oa=ka+40|0;c[y>>2]=1;c[pb>>2]=1e6;fa=XIb(na,G,oa,h)|0;na=G;if((qb|0)>(na|0)|(qb|0)==(na|0)&tb>>>0>fa>>>0){Jb=qb;Kb=tb;break}fa=(c[da>>2]|0)+(((c[ja>>2]|0)-1|0)*24|0)+8|0;da=c[ea>>2]|0;ea=(da|0)>1;na=Crc(c[fa>>2]|0,c[fa+4>>2]|0,ea?da:1,ea?(da|0)<0|0?-1:0:0)|0;c[Pa>>2]=1;c[Oa>>2]=1e6;da=XIb(na,G,oa,j)|0;Jb=G;Kb=da}}while(0);ja=ha+1|0;if(ja>>>0<(c[O>>2]|0)>>>0){sb=Gb;rb=Hb;qb=Jb;tb=Kb;Va=Eb;Ua=Fb;ha=ja}else{vb=Gb;wb=Hb;xb=Jb;yb=Kb;zb=Eb;Ab=Fb;break}}}ha=xrc(yb,xb,Ab,zb)|0;Ua=G;Va=0;tb=wrc(wb,vb,1,0)|0;if((Ua|0)>(Va|0)|(Ua|0)==(Va|0)&ha>>>0>2e6>>>0){F=197;break}else{V=vb;z=wb;C=G;T=tb}}if((F|0)==197){kJb(ob);ub=1;break}else if((F|0)==198){kJb(ob);ub=0;break}}}while(0);c[N>>2]=c[U>>2]&65536|ub|c[N>>2];ub=LGb(c[D>>2]|0,2378640,0,0)|0;do{if((ub|0)!=0){if((irc(c[ub+4>>2]|0,2372776)|0)!=0){break}D=c[O>>2]|0;if((D|0)==0){break}U=c[Q>>2]|0;F=0;do{wb=c[U+(F<<2)>>2]|0;if(((c[(c[wb+8>>2]|0)+48>>2]|0)-1|0)>>>0<2>>>0){c[wb+236>>2]=1}F=F+1|0;}while(F>>>0<D>>>0)}}while(0);ub=c[O>>2]|0;D=0;while(1){if(!(D>>>0<ub>>>0)){break}if((c[(c[(c[Q>>2]|0)+(D<<2)>>2]|0)+404>>2]|0)==0){D=D+1|0}else{break}}if((c[R>>2]|0)==0){Lb=ub;Mb=(c[N>>2]|0)==0}else{c[N>>2]=0;Lb=c[O>>2]|0;Mb=1}do{if((D|0)==(Lb|0)){if(Mb){break}KIb(P,24,2361672,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[N>>2]=0}else{if(Mb){break}KIb(P,32,2348768,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ub=c[O>>2]|0;if((ub|0)==0){break}else{Nb=0;Ob=ub}while(1){ub=c[(c[Q>>2]|0)+(Nb<<2)>>2]|0;R=c[(c[ub+12>>2]|0)+24>>2]|0;do{if((c[ub+404>>2]|0)!=1|(R|0)==0){Pb=Ob}else{F=R;while(1){if((F|0)<1024){F=F<<1}else{break}}U=c[ub+400>>2]|0;ob=U|0;wb=c[ob>>2]|0;vb=c[ob+4>>2]|0;ob=c[U+16>>2]>>2;zb=ob;Ab=(ob|0)<0|0?-1:0;xb=U+8|0;U=c[xb>>2]|0;yb=c[xb+4>>2]|0;if((ob|0)<=0){Pb=Ob;break}ob=F;xb=(F|0)<0|0?-1:0;Fb=0;Eb=0;do{Kb=wrc(Eb,Fb,wb,vb)|0;Jb=G;Hb=wrc(Eb,Fb,U,yb)|0;Gb=G;j=xrc(zb,Ab,Eb,Fb)|0;h=G;xX(ub,Kb,Jb,Hb,Gb,(xb|0)>(h|0)|(xb|0)==(h|0)&ob>>>0>j>>>0?j:F,0,1)|0;Eb=wrc(Eb,Fb,ob,xb)|0;Fb=G;}while((Fb|0)<(Ab|0)|(Fb|0)==(Ab|0)&Eb>>>0<zb>>>0);Pb=c[O>>2]|0}}while(0);ub=Nb+1|0;if(ub>>>0<Pb>>>0){Nb=ub;Ob=Pb}else{break}}}}while(0);dL(b,0,1967944);dL(b,0,1316424);E=0;i=e;return E|0}function vC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;f=i;i=i+320|0;g=f|0;h=f+256|0;j=f+264|0;k=f+272|0;l=f+288|0;m=f+296|0;n=f+304|0;o=f+312|0;p=c[b+12>>2]|0;q=b+16|0;r=c[q>>2]|0;s=p+72|0;t=c[s>>2]|0;do{if((t|0)==0){u=p+64|0;if((c[u>>2]|0)==0){v=u;break}w=b+24|0;x=c[w>>2]|0;if((x|0)==0){y=-541478725;i=f;return y|0}z=b+28|0;A=n|0;B=n+4|0;C=0;D=2147483647;E=-1;F=0;H=0;I=x;while(1){x=c[(c[z>>2]|0)+(C<<2)>>2]|0;J=c[x+12>>2]|0;K=J;L=c[K>>2]|0;M=c[K+4>>2]|0;K=c[x+404>>2]|0;do{if((K|0)==0){N=H;O=F;P=D;Q=E;R=I}else{if((c[J+8>>2]|0)==0){S=(c[x+400>>2]|0)+((K-1|0)*24|0)+8|0;T=c[S+4>>2]|0;if((M|0)>(T|0)|(M|0)==(T|0)&L>>>0>(c[S>>2]|0)>>>0){N=H;O=F;P=D;Q=E;R=I;break}}S=c[J+24>>2]|0;c[A>>2]=(S|0)<1?1:S;c[B>>2]=1e6;S=XIb(L,M,x+40|0,n)|0;T=G;U=(T|0)<(D|0)|(T|0)==(D|0)&S>>>0<E>>>0;N=U?C:H;O=U?x:F;P=U?T:D;Q=U?S:E;R=c[w>>2]|0}}while(0);x=C+1|0;if(x>>>0<R>>>0){C=x;D=P;E=Q;F=O;H=N;I=R}else{break}}if((O|0)==0){y=-541478725;i=f;return y|0}I=c[O+12>>2]|0;H=I;F=c[H>>2]|0;E=c[H+4>>2]|0;D=I+8|0;do{if((c[D>>2]|0)==0){C=CX(O,F,E,4)|0;if((C|0)>-1){w=c[O+400>>2]|0;B=w+(C*24|0)+8|0;A=c[B+4>>2]|0;c[H>>2]=c[B>>2];c[H+4>>2]=A;V=C;W=w;break}else{y=-541478725;i=f;return y|0}}else{w=CX(O,F,E,5)|0;if((w|0)>-1){V=w;W=c[O+400>>2]|0;break}else{y=-541478725;i=f;return y|0}}}while(0);E=W+(V*24|0)|0;F=I+12|0;H=(c[F>>2]|0)-(c[D>>2]|0)|0;w=c[q>>2]|0;C=wrc(c[E>>2]|0,c[E+4>>2]|0,8,0)|0;E=wrc(C,G,H,(H|0)<0|0?-1:0)|0;H=fD(w,E,G,0)|0;E=G;w=0;if((E|0)<(w|0)|(E|0)==(w|0)&H>>>0<0>>>0){y=-541478725;i=f;return y|0}if((c[D>>2]|0)>(c[F>>2]|0)){KIb(0,0,2405168,(X=i,i=i+24|0,c[X>>2]=2602472,c[X+8>>2]=2273896,c[X+16>>2]=1220,X)|0);i=X;Hd();return 0}c[p+68>>2]=N;if((c[D>>2]|0)!=0){v=u;break}H=c[(c[O+400>>2]|0)+(V*24|0)+16>>2]>>2;c[D>>2]=H;c[F>>2]=H;v=u}else{H=LF(t,e)|0;if((H|0)>-1){y=H;i=f;return y|0}else{v=p+64|0;break}}}while(0);t=p+68|0;V=b+28|0;O=l|0;N=l+4|0;q=b+24|0;W=p+48|0;R=g|0;g=j;Q=e+28|0;P=e+24|0;n=k|0;H=k+4|0;F=k+8|0;w=e;E=e+16|0;C=e+32|0;A=e+36|0;B=e+64|0;z=e|0;x=e+52|0;M=b;L=m|0;J=m+4|0;a:while(1){K=c[t>>2]|0;if(!((K|0)>-1)){S=zC(b,0)|0;if((S|0)<0){y=S;Y=94;break}else{continue}}Z=c[(c[V>>2]|0)+(K<<2)>>2]|0;K=Z+12|0;_=c[K>>2]|0;S=_;U=c[S>>2]|0;T=c[S+4>>2]|0;$=Z+40|0;c[O>>2]=1;c[N>>2]=1e6;aa=XIb(U,T,$,l)|0;T=G;U=c[q>>2]|0;if((U|0)!=0){ba=2147483647;ca=-1;da=0;ea=0;fa=U;while(1){U=c[(c[V>>2]|0)+(ea<<2)>>2]|0;ga=c[U+12>>2]|0;do{if((c[U+76>>2]|0)>47|(ga|0)==0){ha=da;ia=ba;ja=ca;ka=fa}else{if((c[ga+1112>>2]|0)==0){ha=da;ia=ba;ja=ca;ka=fa;break}la=ga+1104|0;ma=c[la>>2]|0;na=c[la+4>>2]|0;c[L>>2]=1;c[J>>2]=1e6;la=XIb(ma,na,U+40|0,m)|0;na=G;ma=(na|0)<=(T|0)&((na|0)<(T|0)|la>>>0<=aa>>>0)&((na|0)<(ba|0)|(na|0)==(ba|0)&la>>>0<ca>>>0);ha=ma?U:da;ia=ma?na:ba;ja=ma?la:ca;ka=c[q>>2]|0}}while(0);U=ea+1|0;if(U>>>0<ka>>>0){ba=ia;ca=ja;da=ha;ea=U;fa=ka}else{break}}if((ha|0)!=0){Y=31;break}}fa=_+24|0;ea=c[fa>>2]|0;if((ea|0)<2){oa=2147483647}else{oa=(ea|0)<32?ea<<10:ea}ea=_+8|0;da=c[ea>>2]|0;ca=fD(r,0,0,1)|0;c[W>>2]=ca;c[W+4>>2]=G;ca=fX(r,e,(oa|0)>(da|0)?da:oa)|0;if((ca|0)<0){y=ca;Y=94;break}da=_+1072|0;do{if((c[da>>2]|0)!=0){if(!((c[Q>>2]|0)>>>0<1073741823>>>0)){break}ba=U1(e,0,1024)|0;if((ba|0)==0){KIb(M,16,2577024,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;break}else{nrc(ba|0,_+48|0,1024)|0;c[da>>2]=0;break}}}while(0);da=c[s>>2]|0;do{if((da|0)==0){ba=Z+8|0;aa=c[ba>>2]|0;do{if((c[aa+8>>2]|0)==3){if((c[aa+52>>2]|0)!=0){break}T=c[Q>>2]|0;if((T|0)<=6){break}u=c[P>>2]|0;if((irc(u,2540536)|0)!=0){break}D=u+5|0;if(!((d[D]|d[D+1|0]<<8)<<16>>16<<16>>16==2)){break}c[h>>2]=50;D=c[K>>2]|0;I=aD(u+7|0,T-7|0,0,0,0,0,0)|0;c[j>>2]=I;T=FD(I)|0;do{if(!(T>>>0>((c[I+16>>2]|0)-(c[I+12>>2]|0)|0)>>>0)){u=MD(I,T,R,256)|0;hD(c[j>>2]|0,T-u|0,0)|0;if((a[R]|0)!=0){MGb(Z+88|0,2523648,R,0)|0}DD(c[j>>2]|0)|0;FD(c[j>>2]|0)|0;u=c[j>>2]|0;U=c[u+12>>2]|0;ga=(c[u+16>>2]|0)-U|0;c[n>>2]=0;c[H>>2]=U;c[F>>2]=ga;ga=lX(k,1,h)|0;if((ga|0)==0){break}U=HR()|0;u=D+1080|0;c[u>>2]=U;if((U|0)==0){break}c[U+16>>2]=c[j>>2];if((oX(u,10230600,ga,0)|0)==0){qX(c[u>>2]|0,D+1088|0)|0;nrc(c[ba>>2]|0,c[(c[c[(c[u>>2]|0)+28>>2]>>2]|0)+8>>2]|0,960)|0;c[(c[(c[c[(c[u>>2]|0)+28>>2]>>2]|0)+8>>2]|0)+96>>2]=0;ga=c[c[(c[u>>2]|0)+28>>2]>>2]|0;_X(Z,64,c[ga+40>>2]|0,c[ga+44>>2]|0)}c[D+1168>>2]=c[P>>2];mrc(w|0,0,80)|0;ga=wrc(c[S>>2]|0,c[S+4>>2]|0,1,0)|0;c[S>>2]=ga;c[S+4>>2]=G;c[t>>2]=-1;c[ea>>2]=0;continue a}}while(0);mJb(g)}}while(0);aa=c[S>>2]|0;D=c[S+4>>2]|0;c[E>>2]=aa;c[E+4>>2]=D;T=c[fa>>2]|0;if((T|0)!=0){I=Crc(aa,D,T,(T|0)<0|0?-1:0)|0;c[E>>2]=I;c[E+4>>2]=G}c[C>>2]=c[t>>2];do{if((c[(c[ba>>2]|0)+8>>2]|0)==0){I=Z+400|0;if((c[I>>2]|0)==0){Y=73;break}T=CX(Z,c[S>>2]|0,c[S+4>>2]|0,0)|0;D=c[I>>2]|0;if(!((T|0)>-1)){break}I=D+(T*24|0)+8|0;if(!((c[I>>2]|0)==(c[S>>2]|0)&(c[I+4>>2]|0)==(c[S+4>>2]|0))){break}b:do{if((T|0)==((c[Z+404>>2]|0)-1|0)){I=(ca|0)>256?256:ca;if((I|0)<=0){break}if((c[(c[ba>>2]|0)+48>>2]|0)==13){pa=0;qa=-1}else{break}while(1){if((qa|0)==438){break}aa=d[(c[P>>2]|0)+pa|0]|qa<<8;ga=pa+1|0;if((ga|0)<(I|0)){pa=ga;qa=aa}else{break b}}if((d[(c[P>>2]|0)+pa|0]|0)>>>0<64>>>0){break}I=D+(T*24|0)+16|0;c[I>>2]=c[I>>2]&-2}}while(0);if((c[D+(T*24|0)+16>>2]&1|0)==0){break}c[A>>2]=c[A>>2]|1}else{Y=73}}while(0);if((Y|0)==73){Y=0;c[A>>2]=c[A>>2]|1}ba=c[Q>>2]|0;do{if((c[fa>>2]|0)==0){I=c[_+1076>>2]|0;if((I|0)==0){ra=1;break}ra=(ba-1+I|0)/(I|0)|0}else{ra=ba}}while(0);ba=wrc(c[S>>2]|0,c[S+4>>2]|0,ra,(ra|0)<0|0?-1:0)|0;c[S>>2]=ba;c[S+4>>2]=G}else{ba=c[z>>2]|0;I=c[x>>2]|0;aa=MF(da,e,c[P>>2]|0,c[Q>>2]|0,c[B>>2]|0,c[B+4>>2]|0)|0;c[x>>2]=I;c[z>>2]=ba;c[A>>2]=c[A>>2]|1;if((aa|0)>=0){break}P1(e)}}while(0);da=c[ea>>2]|0;c[ea>>2]=da-ca;if((da|0)==(ca|0)){c[t>>2]=-1;c[_+12>>2]=0}sa=(c[v>>2]|0)==0;if(!sa){Y=81;break}da=c[B>>2]|0;S=c[B+4>>2]|0;fa=-1;ta=_+1176|0;if(!((S|0)>(fa|0)|(S|0)==(fa|0)&da>>>0>-1>>>0)){Y=83;break}fa=c[ta+4>>2]|0;if(!((fa|0)>(S|0)|(fa|0)==(S|0)&(c[ta>>2]|0)>>>0>da>>>0)){Y=86;break}P1(e)}do{if((Y|0)==31){e=c[ha+12>>2]|0;B=e+1088|0;nrc(w|0,B|0,80)|0;c[C>>2]=c[ha>>2];if((qX(c[e+1080>>2]|0,B)|0)>=0){y=0;i=f;return y|0}c[e+1112>>2]=0;y=0;i=f;return y|0}else if((Y|0)==81){e=_+1176|0;c[e>>2]=0;c[e+4>>2]=0;y=0;i=f;return y|0}else if((Y|0)==83){c[ta>>2]=0;c[ta+4>>2]=0}else if((Y|0)==86){e=_+1176|0;c[e>>2]=0;c[e+4>>2]=0;if(sa){break}else{y=0}i=f;return y|0}else if((Y|0)==94){i=f;return y|0}}while(0);if((c[Z+404>>2]|0)<=1){y=0;i=f;return y|0}if((c[p+56>>2]|0)<=1){y=0;i=f;return y|0}Z=c[E>>2]|0;Y=c[E+4>>2]|0;c[o>>2]=1;c[o+4>>2]=1e6;E=XIb(Z,Y,$,o)|0;o=G;$=p+88|0;p=c[$>>2]|0;Y=c[$+4>>2]|0;Z=xrc(p,Y,E,o)|0;sa=G;_=0;if((sa|0)>(_|0)|(sa|0)==(_|0)&Z>>>0>2e6>>>0){c[v>>2]=1;KIb(M,32,2558072,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;y=0;i=f;return y|0}if(!((Y|0)<(o|0)|(Y|0)==(o|0)&p>>>0<E>>>0)){y=0;i=f;return y|0}c[$>>2]=E;c[$+4>>2]=o;y=0;i=f;return y|0}function wC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[a+12>>2]|0;d=a+24|0;e=c[d>>2]|0;if((e|0)==0){f=b+72|0;g=f;h=c[g>>2]|0;i=h;kJb(i);return 0}j=a+28|0;a=0;k=e;while(1){e=c[(c[(c[j>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;if((e|0)==0){l=k}else{m=e+1080|0;n=c[m>>2]|0;if((n|0)!=0){mJb(n+16|0);YX(m)}kJb(c[e+1168>>2]|0);P1(e+1088|0);l=c[d>>2]|0}e=a+1|0;if(e>>>0<l>>>0){a=e;k=l}else{break}}f=b+72|0;g=f;h=c[g>>2]|0;i=h;kJb(i);return 0}function xC(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;g=i;h=c[a+12>>2]|0;j=h+72|0;k=(c[j>>2]|0)==0?b:0;b=h+56|0;if((c[b>>2]|0)==0){yC(a);c[b>>2]=c[b>>2]|1}if(!((k|0)>-1)){KIb(0,0,2405168,(l=i,i=i+24|0,c[l>>2]=2329856,c[l+8>>2]=2273896,c[l+16>>2]=1597,l)|0);i=l;Hd();return 0}b=a+28|0;m=c[(c[b>>2]|0)+(k<<2)>>2]|0;k=(c[m+12>>2]|0)+24|0;n=c[k>>2]|0;o=(n|0)>1;p=Erc(o?n:1,o?(n|0)<0|0?-1:0:0,d,e)|0;n=CX(m,p,G,f)|0;if((n|0)<0){p=c[m+404>>2]|0;if((p|0)<=0){q=-1094995529;i=g;return q|0}o=c[k>>2]|0;r=(o|0)>1;s=Erc(r?o:1,r?(o|0)<0|0?-1:0:0,d,e)|0;e=G;d=c[m+400>>2]|0;o=d+8|0;r=c[o>>2]|0;t=c[o+4>>2]|0;o=d+((p-1|0)*24|0)+8|0;p=c[o>>2]|0;d=c[o+4>>2]|0;KIb(a,48,2224752,(l=i,i=i+48|0,c[l>>2]=s,c[l+8>>2]=e,c[l+16>>2]=r,c[l+24>>2]=t,c[l+32>>2]=p,c[l+40>>2]=d,l)|0);i=l;q=-1094995529;i=g;return q|0}d=c[m+400>>2]|0;p=d+(n*24|0)|0;t=c[p>>2]|0;r=c[p+4>>2]|0;p=d+(n*24|0)+8|0;n=c[k>>2]|0;k=(n|0)>1;d=Crc(c[p>>2]|0,c[p+4>>2]|0,k?n:1,k?(n|0)<0|0?-1:0:0)|0;n=G;if((c[j>>2]|0)!=0){k=fD(c[a+16>>2]|0,t,r,0)|0;p=G;e=0;if((p|0)<(e|0)|(p|0)==(e|0)&k>>>0<0>>>0){q=-1;i=g;return q|0}NF(c[j>>2]|0,d,n);c[h+68>>2]=-1;q=0;i=g;return q|0}j=a+24|0;do{if((c[j>>2]|0)==0){u=r;v=t}else{k=m+40|0;e=r;p=t;s=0;a:while(1){o=c[(c[b>>2]|0)+(s<<2)>>2]|0;w=c[o+12>>2]|0;c[w+8>>2]=0;c[w+12>>2]=0;x=w+1080|0;do{if((c[x>>2]|0)==0){if((c[o+404>>2]|0)<1){y=e;z=p;break}A=o+40|0;B=c[A>>2]|0;C=Erc(c[w+20>>2]|0,0,B,(B|0)<0|0?-1:0)|0;B=G;D=c[o+44>>2]|0;E=Erc(c[w+16>>2]|0,0,D,(D|0)<0|0?-1:0)|0;if(!((C|0)==(E|0)&(B|0)==(G|0))){F=21;break a}B=XIb(d,n,k,A)|0;A=c[w+24>>2]|0;E=(A|0)>1;C=Erc(E?A:1,E?(A|0)<0|0?-1:0:0,B,G)|0;B=CX(o,C,G,((c[(c[o+8>>2]|0)+8>>2]|0)!=0?4:0)|f|1)|0;C=(c[o+400>>2]|0)+(((B|0)<0?0:B)*24|0)|0;B=c[C>>2]|0;A=c[C+4>>2]|0;C=w+1176|0;c[C>>2]=B;c[C+4>>2]=A;C=(e|0)>(A|0)|(e|0)==(A|0)&p>>>0>B>>>0;y=C?A:e;z=C?B:p}else{B=XIb(d,n,k,o+40|0)|0;C=G;A=w+1088|0;P1(A);if(!((HX(c[x>>2]|0,0,0,-2147483648,B,C,B,C,0)|0)>-1)){if(!((HX(c[x>>2]|0,0,B,C,B,C,-1,2147483647,0)|0)>-1)){y=e;z=p;break}}qX(c[x>>2]|0,A)|0;y=e;z=p}}while(0);x=s+1|0;H=c[j>>2]|0;if(x>>>0<H>>>0){e=y;p=z;s=x}else{break}}if((F|0)==21){KIb(0,0,2405168,(l=i,i=i+24|0,c[l>>2]=2188600,c[l+8>>2]=2273896,c[l+16>>2]=1654,l)|0);i=l;Hd();return 0}if((H|0)==0){u=y;v=z;break}s=m+40|0;p=h+64|0;e=0;k=H;while(1){x=c[(c[b>>2]|0)+(e<<2)>>2]|0;w=c[x+12>>2]|0;do{if((c[w+1080>>2]|0)==0){if((c[x+404>>2]|0)<1){I=k;break}o=XIb(d,n,s,x+40|0)|0;A=c[w+24>>2]|0;C=(A|0)>1;B=Erc(C?A:1,C?(A|0)<0|0?-1:0:0,o,G)|0;o=CX(x,B,G,((c[(c[x+8>>2]|0)+8>>2]|0)!=0?4:0)|f|1)|0;B=(o|0)<0?0:o;o=x+400|0;b:do{if((c[p>>2]|0)==0){A=B;while(1){if((A|0)<=0){J=A;break b}C=A-1|0;E=(c[o>>2]|0)+(C*24|0)|0;D=c[E+4>>2]|0;if((D|0)<(y|0)|(D|0)==(y|0)&(c[E>>2]|0)>>>0<z>>>0){J=A;break}else{A=C}}}else{J=B}}while(0);B=(c[o>>2]|0)+(J*24|0)+8|0;A=c[B+4>>2]|0;C=w;c[C>>2]=c[B>>2];c[C+4>>2]=A;I=c[j>>2]|0}else{I=k}}while(0);w=e+1|0;if(w>>>0<I>>>0){e=w;k=I}else{u=y;v=z;break}}}}while(0);z=fD(c[a+16>>2]|0,v,u,0)|0;u=G;v=0;if((u|0)<(v|0)|(u|0)==(v|0)&z>>>0<0>>>0){KIb(a,16,2158544,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;q=-1;i=g;return q|0}else{c[h+68>>2]=-1;l=h+88|0;c[l>>2]=-2147483648;c[l+4>>2]=-1;q=0;i=g;return q|0}return 0}function yC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;g=fD(f,0,0,1)|0;h=G;i=d+16|0;j=fD(f,c[i>>2]|0,c[i+4>>2]|0,0)|0;i=G;k=0;if((i|0)<(k|0)|(i|0)==(k|0)&j>>>0<0>>>0){l=fD(f,g,h,0)|0;m=G;return}j=a+24|0;k=a+28|0;i=d+56|0;d=-1;while(1){n=FD(f)|0;o=FD(f)|0;if((jD(f)|0)!=0){p=35;break}q=fD(f,0,0,1)|0;r=G;s=wrc(o&1,0,o,0)|0;t=wrc(s,G,q,r)|0;r=G;a:do{if((n|0)==1414744396){if((FD(f)|0)!=1330007625){u=d;break}RS(a,o-4|0,0)|0;u=d}else if((n|0)==829973609){q=c[b>>2]|0;s=c[e>>2]|0;v=(o|0)/16|0;if((o|0)<16){p=33;break}w=fD(s,0,0,1)|0;x=G;y=q+40|0;z=wrc(c[y>>2]|0,c[y+4>>2]|0,4,0)|0;fD(s,z,G,0)|0;if((zC(a,1)|0)==0){z=fD(s,0,0,1)|0;A=wrc(z,G,-8,-1)|0;B=G;C=A}else{B=0;C=0}c[q+68>>2]=-1;fD(s,w,x,0)|0;x=c[j>>2]|0;do{if((x|0)==1){if((c[(c[(c[c[k>>2]>>2]|0)+8>>2]|0)+52>>2]|0)!=1397050701){D=0;E=0;F=B;H=C;break}D=c[y+4>>2]|0;E=c[y>>2]|0;F=0;H=0}else{D=0;E=0;F=B;H=C}}while(0);do{if((o|0)>15){y=(H|0)==0&(F|0)==0;w=q+64|0;A=0;z=1;I=-1;J=-1;K=D;L=E;M=0;while(1){if((jD(s)|0)!=0){p=33;break a}N=FD(s)|0;O=FD(s)|0;P=FD(s)|0;Q=FD(s)|0;R=(N>>>8&255)-528+((N&255)*10|0)|0;if(R>>>0<(c[j>>2]|0)>>>0){N=c[(c[k>>2]|0)+(R<<2)>>2]|0;R=c[N+12>>2]|0;S=(z|0)==0|y;T=P;P=0;U=xrc(H,F,T,P)|0;V=S?z:0;W=S?L:U;U=S?K:G;S=wrc(W,U,T,P)|0;P=S;if((I|0)==(P|0)){c[w>>2]=1}if((J|0)==(P|0)|(Q|0)==0){X=J}else{T=R+32|0;xX(N,S|0,G&0,c[T>>2]|0,c[T+4>>2]|0,Q,0,O>>>4&1)|0;X=P}do{if((c[R+24>>2]|0)==0){T=c[R+1076>>2]|0;if((T|0)==0){Y=1;break}Y=(Q-1+T|0)/(T|0)|0}else{Y=Q}}while(0);Q=R+32|0;T=wrc(c[Q>>2]|0,c[Q+4>>2]|0,Y,(Y|0)<0|0?-1:0)|0;c[Q>>2]=T;c[Q+4>>2]=G;Z=O&16|M;_=U;$=W;aa=X;ba=P;ca=V}else{Z=M;_=K;$=L;aa=J;ba=I;ca=z}Q=A+1|0;if((Q|0)<(v|0)){A=Q;z=ca;I=ba;J=aa;K=_;L=$;M=Z}else{break}}if((Z|0)!=0){break}da=c[j>>2]|0;p=26}else{da=x;p=26}}while(0);do{if((p|0)==26){p=0;if((da|0)==0){break}else{ea=0;fa=da}while(1){x=c[(c[k>>2]|0)+(ea<<2)>>2]|0;if((c[x+404>>2]|0)==0){ga=fa}else{v=(c[x+400>>2]|0)+16|0;c[v>>2]=c[v>>2]|1;ga=c[j>>2]|0}v=ea+1|0;if(v>>>0<ga>>>0){ea=v;fa=ga}else{break}}}}while(0);c[i>>2]=2;u=0}else{p=33}}while(0);if((p|0)==33){p=0;if((d|0)==0){p=35;break}else{u=d}}o=fD(f,t,r,0)|0;n=G;v=0;if((n|0)<(v|0)|(n|0)==(v|0)&o>>>0<0>>>0){p=35;break}else{d=u}}if((p|0)==35){l=fD(f,g,h,0)|0;m=G;return}}function zC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=fD(f,0,0,1)|0;h=G;a:do{if((jD(f)|0)==0){j=e+32|0;k=e+24|0;l=a+24|0;m=e+72|0;n=e+48|0;o=a+28|0;p=a;q=(b|0)==0;r=h;s=g;b:while(1){t=wrc(s,r,9,0)|0;u=G;v=r;w=s;x=-1;y=-1;z=-1;A=-1;B=-1;C=-1;D=-1;c:while(1){E=zD(f)|0;F=(E<<24)+z+(A<<8)+(B<<16)|0;H=(x-48|0)>>>0<10>>>0;do{if(H){if(!((y-48|0)>>>0<10>>>0)){I=100;break}I=(x*10|0)-528+y|0}else{I=100}}while(0);J=c[j+4>>2]|0;K=0;L=xrc(0,0,((J|0)>(K|0)|(J|0)==(K|0)&(c[j>>2]|0)>>>0>0>>>0)&1,0)|0;M=F;N=0;K=wrc(w&L,v&G,M,N)|0;L=G;J=c[k+4>>2]|0;do{if(L>>>0>J>>>0|L>>>0==J>>>0&K>>>0>(c[k>>2]|0)>>>0|C>>>0>127>>>0){O=y}else{P=(C|0)==105;do{if(P){if((D|0)==120){if(I>>>0<(c[l>>2]|0)>>>0){Q=14;break c}else{Q=11;break}}else if((D|0)==100){if((x|0)==120&(y|0)==49){Q=14;break c}else{break}}else{break}}else{Q=11}}while(0);if((Q|0)==11){Q=0;if((C|0)==74&(D|0)==85&(x|0)==78&(y|0)==75){Q=14;break c}if(P&(D|0)==100&(x|0)==120&(y|0)==49){Q=14;break c}}if((C|0)==76&(D|0)==73&(x|0)==83&(y|0)==84){Q=17;break c}R=c[m>>2]|0;do{if((R|0)==0){if(!((C-48|0)>>>0<10>>>0&(D-48|0)>>>0<10>>>0)){S=100;break}S=(C*10|0)-528+D|0}else{S=0}}while(0);P=xrc(w,v,c[n>>2]|0,c[n+4>>2]|0)|0;if((P&1|0)==0&(G&0|0)==0){if((D-48|0)>>>0>9>>>0|H^1){T=100}else{T=(D*10|0)-528+x|0}if(T>>>0<(c[l>>2]|0)>>>0){O=y;break}}P=c[l>>2]|0;if((x|0)==105&(y|0)==120){if(S>>>0<P>>>0){Q=27;break c}else{U=120}}else{U=y}if(!(S>>>0<P>>>0)){O=U;break}V=c[o>>2]|0;W=c[V+(S<<2)>>2]|0;X=c[W+12>>2]|0;Y=X;if((X|0)==0){KIb(p,24,2109928,(Z=i,i=i+8|0,c[Z>>2]=S,Z)|0);i=Z;O=U;break}do{if(P>>>0>1>>>0){_=c[V+4>>2]|0;$=c[_+12>>2]|0;aa=$;if((x|0)!=119){ba=S;ca=Y;da=W;ea=R;break}if(!((y|0)==98&(S|0)==0)){ba=S;ca=Y;da=W;ea=R;break}if((c[(c[W+8>>2]|0)+8>>2]|0)!=0){ba=0;ca=Y;da=W;ea=R;break}if((c[(c[_+8>>2]|0)+8>>2]|0)!=1){ba=0;ca=Y;da=W;ea=R;break}if((c[X+40>>2]|0)!=25699){ba=0;ca=Y;da=W;ea=R;break}if((c[$+40>>2]|0)!=30562){if((c[$+44>>2]|0)!=0){ba=0;ca=Y;da=W;ea=R;break}}KIb(p,24,2627728,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;ba=1;ca=aa;da=_;ea=c[m>>2]|0}else{ba=S;ca=Y;da=W;ea=R}}while(0);do{if((ea|0)==0){R=c[da+76>>2]|0;if((R|0)>-1&(F|0)==0){if(q){fa=0;Q=44;break c}else{break}}else{if((R|0)>47&q){fa=F;Q=44;break c}else{break}}}}while(0);if((x|0)==112){if((y|0)==99&F>>>0<1029>>>0){Q=50;break c}}ga=ca+44|0;ha=c[ga>>2]|0;if(((ha|0)<5|((u|0)>(v|0)|(u|0)==(v|0)&t>>>0>w>>>0))&x>>>0<128>>>0&y>>>0<128>>>0){break b}if(((x<<8)+y|0)==(c[ca+40>>2]|0)){break b}else{O=y}}}while(0);H=wrc(w,v,1,0)|0;K=G;if((jD(f)|0)==0){v=K;w=H;C=D;D=x;x=O;y=z;z=A;A=B;B=E}else{break a}}if((Q|0)==14){Q=0;hD(f,M,N)|0;}else if((Q|0)==17){Q=0;hD(f,4,0)|0;}else if((Q|0)==27){Q=0;hD(f,M,N)|0;}else if((Q|0)==44){Q=0;do{if((c[ca+24>>2]|0)==0){B=c[ca+1076>>2]|0;if((B|0)==0){ia=1;break}ia=(fa-1+B|0)/(B|0)|0}else{ia=fa}}while(0);B=ca|0;A=wrc(c[B>>2]|0,c[B+4>>2]|0,ia,(ia|0)<0|0?-1:0)|0;c[B>>2]=A;c[B+4>>2]=G;hD(f,M,N)|0;}else if((Q|0)==50){Q=0;B=zD(f)|0;A=B+255+(zD(f)|0)&255;DD(f)|0;if((B|0)<=(A|0)){z=B;do{c[ca+48+(z<<2)>>2]=(JD(f)|0)>>>8|-16777216;z=z+1|0;}while((z|0)<=(A|0))}c[ca+1072>>2]=1}s=fD(f,0,0,1)|0;r=G;if((jD(f)|0)!=0){break a}}if(!q){ja=0;i=d;return ja|0}r=(x<<8)+y|0;s=ca+40|0;if((r|0)==(c[s>>2]|0)){ka=ha+1|0}else{c[s>>2]=r;ka=0}c[ga>>2]=ka;c[e+68>>2]=ba;c[ca+12>>2]=F+8;c[ca+8>>2]=F;do{if((F|0)==0){if((c[ca+24>>2]|0)==0){break}else{ja=0}i=d;return ja|0}}while(0);q=fD(f,0,0,1)|0;r=wrc(q,G,-8,-1)|0;q=G;s=c[da+400>>2]|0;do{if((s|0)!=0){m=c[da+404>>2]|0;if((m|0)==0){break}p=s+((m-1|0)*24|0)|0;m=c[p+4>>2]|0;if(m>>>0<q>>>0|m>>>0==q>>>0&(c[p>>2]|0)>>>0<r>>>0){break}else{ja=0}i=d;return ja|0}}while(0);s=ca|0;xX(da,r,q,c[s>>2]|0,c[s+4>>2]|0,F,0,1)|0;ja=0;i=d;return ja|0}}while(0);F=c[f+76>>2]|0;ja=(F|0)==0?-541478725:F;i=d;return ja|0}function AC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=DD(f)|0;h=zD(f)|0;j=zD(f)|0;k=FD(f)|0;l=FD(f)|0;m=GD(f)|0;n=G;o=(l>>>8&255)-528+((l&255)*10|0)|0;l=e+24|0;p=c[l>>2]|0;q=c[l+4>>2]|0;if(o>>>0>=(c[a+24>>2]|0)>>>0|(o|0)<0){r=-1094995529;i=d;return r|0}l=c[(c[a+28>>2]|0)+(o<<2)>>2]|0;o=c[l+12>>2]|0;if((h|0)!=0){r=-1094995529;i=d;return r|0}FD(f)|0;h=(j|0)!=0;if(h&(g|0)!=2|(j|0)>1){r=-1094995529;i=d;return r|0}j=0;do{if((q|0)<(j|0)|(q|0)==(j|0)&p>>>0<1>>>0|((n|0)<(q|0)|(n|0)==(q|0)&m>>>0<p>>>0)){s=n;t=m}else{KIb(a,16,2336680,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;g=n;v=(n|0)<0|0?-1:0;if(!((g|0)==(m|0|0)&(v|0)==(n&0|0))){r=-1094995529;i=d;return r|0}w=1;if(((v|0)<(q|0)|(v|0)==(q|0)&g>>>0<p>>>0)&((q|0)<(w|0)|(q|0)==(w|0)&p>>>0<0>>>0)){s=v;t=g;break}else{r=-1094995529}i=d;return r|0}}while(0);a:do{if((k|0)>0){p=wrc(t,s,-8,-1)|0;q=G;n=e+64|0;m=o+24|0;j=o+1076|0;g=o+32|0;v=e+76|0;if(h){x=-1;y=-1;z=0}else{w=0;A=b;while(1){B=GD(f)|0;C=G;FD(f)|0;D=FD(f)|0;if((jD(f)|0)!=0){r=-1094995529;E=28;break}F=fD(f,0,0,1)|0;H=G;if((c[v>>2]|0)>1e3){E=22;break}I=wrc(B,C,8,0)|0;C=fD(f,I,G,0)|0;I=G;B=0;if((I|0)<(B|0)|(I|0)==(B|0)&C>>>0<0>>>0){r=-1;E=28;break}c[v>>2]=(c[v>>2]|0)+1;AC(a,A)|0;c[v>>2]=(c[v>>2]|0)-1;C=fD(f,F,H,0)|0;H=G;F=0;if((H|0)<(F|0)|(H|0)==(F|0)&C>>>0<0>>>0){E=25;break}C=w+1|0;if((C|0)<(k|0)){w=C;A=D+A|0}else{break a}}if((E|0)==22){KIb(a,16,2331160,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;r=-1094995529;i=d;return r|0}else if((E|0)==25){KIb(a,16,2325200,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;r=-1;i=d;return r|0}else if((E|0)==28){i=d;return r|0}}while(1){A=FD(f)|0;w=wrc(p,q,A,0)|0;v=G;D=FD(f)|0;C=D&2147483647;if((jD(f)|0)!=0){r=-1094995529;break}F=(y|0)==(w|0)&(x|0)==(v|0);if(F|(A|0)==0){c[n>>2]=1}do{if(F){E=16}else{if((C|0)==0){if((c[m>>2]|0)!=0){J=0;break}}xX(l,w,v,c[g>>2]|0,c[g+4>>2]|0,C,0,D>>>31^1)|0;E=16}}while(0);do{if((E|0)==16){E=0;if((c[m>>2]|0)!=0){J=C;break}D=c[j>>2]|0;if((D|0)==0){J=1;break}J=(C-1+D|0)/(D|0)|0}}while(0);C=wrc(c[g>>2]|0,c[g+4>>2]|0,J,(J|0)<0|0?-1:0)|0;c[g>>2]=C;c[g+4>>2]=G;C=z+1|0;if((C|0)<(k|0)){x=v;y=w;z=C}else{break a}}i=d;return r|0}}while(0);c[e+56>>2]=2;r=0;i=d;return r|0}function BC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;b=i;i=i+56|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=b+32|0;j=b+40|0;k=b+48|0;l=c[a+12>>2]|0;m=a+16|0;n=c[m>>2]|0;o=a+24|0;p=c[o>>2]|0;if(p>>>0>100>>>0){KIb(a,16,2508696,(q=i,i=i+8|0,c[q>>2]=100,q)|0);i=q;r=-22;i=b;return r|0}s=a+28|0;t=0;u=p;while(1){if(!(t>>>0<u>>>0)){break}p=pJb(48)|0;c[(c[(c[s>>2]|0)+(t<<2)>>2]|0)+12>>2]=p;if((c[(c[(c[s>>2]|0)+(t<<2)>>2]|0)+12>>2]|0)==0){r=-12;v=77;break}t=t+1|0;u=c[o>>2]|0}if((v|0)==77){i=b;return r|0}c[l+32>>2]=0;u=HC(a,n,2494464,2484224)|0;t=G;kD(n,1751742049);kD(n,56);p=c[o>>2]|0;do{if((p|0)==0){w=0;x=0;v=12}else{y=c[s>>2]|0;z=p>>>0>1>>>0;A=0;B=0;C=0;do{D=c[(c[y+(B<<2)>>2]|0)+8>>2]|0;C=(c[D+72>>2]|0)+C|0;A=(c[D+8>>2]|0)==0?D:A;B=B+1|0;}while(B>>>0<p>>>0);B=z?p:1;y=(C|0)/8|0;if((A|0)==0){w=y;x=B;v=12;break}D=c[A+104>>2]|0;E=Erc(D,(D|0)<0|0?-1:0,1e6,0)|0;D=c[A+108>>2]|0;F=Crc(E,G,D,(D|0)<0|0?-1:0)|0;kD(n,F);H=y;I=B;J=A;K=1}}while(0);if((v|0)==12){kD(n,0);H=w;I=x;J=0;K=0}kD(n,H);kD(n,0);H=n+88|0;if((c[H>>2]|0)==0){kD(n,2304)}else{kD(n,2320)}x=fD(n,0,0,1)|0;w=l+24|0;c[w>>2]=x;c[w+4>>2]=G;kD(n,0);kD(n,0);kD(n,c[o>>2]|0);kD(n,1048576);if(K){kD(n,c[J+120>>2]|0);kD(n,c[J+124>>2]|0)}else{kD(n,0);kD(n,0)}kD(n,0);kD(n,0);kD(n,0);kD(n,0);a:do{if((I|0)>0){J=h|0;K=h+4|0;o=g|0;w=g+4|0;x=0;b:while(1){p=c[(c[(c[s>>2]|0)+(x<<2)>>2]|0)+12>>2]|0;B=SS(n,2329816)|0;y=G;kD(n,1819440243);F=c[(c[(c[s>>2]|0)+(x<<2)>>2]|0)+8>>2]|0;D=SS(n,2450912)|0;E=G;L=F+8|0;M=c[L>>2]|0;if((M|0)==0){v=24}else if((M|0)==2){kD(n,1937006948);v=27}else if((M|0)==1){kD(n,1935963489);v=27}else if((M|0)==3){if((c[F+48>>2]|0)==94211){v=24}else{v=23;break}}else{v=28}if((v|0)==24){v=0;kD(n,1935960438);v=27}if((v|0)==27){v=0;if((c[L>>2]|0)==0){v=29}else{v=28}}do{if((v|0)==28){v=0;if((c[F+48>>2]|0)==94211){v=29;break}kD(n,1)}}while(0);if((v|0)==29){v=0;kD(n,c[F+52>>2]|0)}kD(n,0);oD(n,0);oD(n,0);kD(n,0);YS(F,d,e,f);M=F+48|0;do{if((c[L>>2]|0)==0){if((c[M>>2]|0)==94211){break}N=c[d>>2]|0;O=(N|0)<0|0?-1:0;P=c[f>>2]|0;Q=Erc(P,(P|0)<0|0?-1:0,1e3,0)|0;P=G;if(!((O|0)>(P|0)|(O|0)==(P|0)&N>>>0>Q>>>0)){break}c[d>>2]=600;c[f>>2]=1}}while(0);_X(c[(c[s>>2]|0)+(x<<2)>>2]|0,64,c[f>>2]|0,c[d>>2]|0);if((c[M>>2]|0)==94211){c[d>>2]=0;c[f>>2]=0;R=0}else{R=c[f>>2]|0}kD(n,R);kD(n,c[d>>2]|0);kD(n,0);Q=fD(n,0,0,1)|0;N=p;c[N>>2]=Q;c[N+4>>2]=G;if((c[H>>2]|0)==0){kD(n,1073741824)}else{kD(n,0)}N=c[L>>2]|0;if((N|0)==0){kD(n,1048576)}else if((N|0)==1){kD(n,12288)}else{kD(n,0)}kD(n,-1);kD(n,c[e>>2]|0);kD(n,0);N=F+120|0;oD(n,c[N>>2]|0);Q=F+124|0;oD(n,c[Q>>2]|0);TS(n,D,E);do{if((c[L>>2]|0)!=2){P=SS(n,2399376)|0;O=G;S=c[L>>2]|0;if((S|0)==3){if((c[M>>2]|0)==94211){v=48}}else if((S|0)==0){v=48}else if((S|0)==1){T=US(n,F)|0;if((T|0)<0){r=T;v=77;break b}}else{v=50;break b}if((v|0)==48){v=0;XS(n,F,1409152,0,0)}TS(n,P,O);O=LGb(c[(c[(c[s>>2]|0)+(x<<2)>>2]|0)+88>>2]|0,2378600,0,0)|0;if((O|0)!=0){ZS(c[m>>2]|0,2372768,c[O+4>>2]|0)}if((c[M>>2]|0)!=94211){break}O=LGb(c[(c[(c[s>>2]|0)+(x<<2)>>2]|0)+88>>2]|0,2361656,0,0)|0;if((O|0)==0){break}P=hE(c[O+4>>2]|0,2)|0;if((P|0)==0){break}O=FFb(2348744,(q=i,i=i+8|0,c[q>>2]=P,q)|0)|0;i=q;ZS(c[m>>2]|0,2372768,O);kJb(O)}}while(0);if((c[H>>2]|0)!=0){c[p+36>>2]=0;c[p+32>>2]=0;M=SS(n,2342512)|0;E=p+24|0;c[E>>2]=M;c[E+4>>2]=G;oD(n,4);bD(n,0);bD(n,0);kD(n,0);M=c[L>>2]|0;if((M|0)==0){U=6553600;V=1660944384}else{U=(M|0)==3?7536640:7798784;V=1644167168}kD(n,(((x|0)%10|0)<<8)+12288&65280|((x|0)/10|0)+48&255|V|U);rD(n,0,0);M=0;do{rD(n,0,0);M=M+1|0;}while((M|0)<512);TS(n,c[E>>2]|0,c[E+4>>2]|0)}do{if((c[L>>2]|0)==0){M=c[(c[s>>2]|0)+(x<<2)>>2]|0;if((c[M+80>>2]|0)<=0){break}if((c[M+84>>2]|0)<=0){break}M=SS(n,2336672)|0;p=(c[(c[s>>2]|0)+(x<<2)>>2]|0)+80|0;c[J>>2]=c[N>>2];c[K>>2]=c[Q>>2];yKb(g,p,h);p=c[o>>2]|0;D=c[w>>2]|0;xKb(j,k,p,(p|0)<0|0?-1:0,D,(D|0)<0|0?-1:0,65535,0)|0;kD(n,0);kD(n,0);kD(n,Lc(+(1.0/(+(c[F+104>>2]|0)/+(c[F+108>>2]|0))))|0);kD(n,c[N>>2]|0);kD(n,c[Q>>2]|0);oD(n,c[k>>2]|0);oD(n,c[j>>2]|0);kD(n,c[N>>2]|0);kD(n,c[Q>>2]|0);kD(n,1);kD(n,c[Q>>2]|0);kD(n,c[N>>2]|0);kD(n,c[Q>>2]|0);kD(n,c[N>>2]|0);kD(n,0);kD(n,0);kD(n,0);kD(n,0);D=M;TS(n,D,(D|0)<0|0?-1:0)}}while(0);TS(n,B,y);x=x+1|0;if((x|0)>=(I|0)){break a}}if((v|0)==23){KIb(a,16,2434416,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1163346256;i=b;return r|0}else if((v|0)==50){x=ALb(S)|0;KIb(a,16,2392360,(q=i,i=i+8|0,c[q>>2]=(x|0)!=0?x:2385720,q)|0);i=q;r=-22;i=b;return r|0}else if((v|0)==77){i=b;return r|0}}}while(0);if((c[H>>2]|0)!=0){H=SS(n,2342512)|0;v=l+16|0;c[v>>2]=H;c[v+4>>2]=G;kD(n,1819108463);kD(n,1751936356);kD(n,248);H=0;do{kD(n,0);H=H+4|0;}while((H|0)<248);TS(n,c[v>>2]|0,c[v+4>>2]|0)}TS(n,u,t);_S(a);t=c[a+1316>>2]|0;a=(t|0)<0?1016:t;if((a|0)!=0){t=SS(n,2342512)|0;u=G;if((a|0)>0){v=a;do{kD(n,0);v=v-4|0;}while((v|0)>0)}TS(n,t,u)}u=SS(n,2329816)|0;t=l+8|0;c[t>>2]=u;c[t+4>>2]=G;kD(n,1769369453);eD(n);r=0;i=b;return r|0}function CC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=i;i=i+88|0;f=e|0;g=e+8|0;h=c[b+12>>2]|0;j=b+16|0;k=c[j>>2]|0;l=c[d+32>>2]|0;m=c[(c[b+28>>2]|0)+(l<<2)>>2]|0;n=c[m+12>>2]|0;o=c[m+8>>2]|0;m=c[d+28>>2]|0;p=o+432|0;a:do{if((c[p>>2]|0)==0){q=d+16|0;r=n+16|0;s=o+48|0;t=g+28|0;u=g+24|0;v=g+32|0;while(1){w=c[q>>2]|0;x=c[q+4>>2]|0;if((w|0)==0&(x|0)==(-2147483648|0)){y=r;break a}z=c[r>>2]|0;A=z;B=(z|0)<0|0?-1:0;if(!((x|0)>(B|0)|(x|0)==(B|0)&w>>>0>A>>>0)){y=r;break a}if((c[s>>2]|0)==94211|(z|0)==0){y=r;break a}C=xrc(w,x,A,B)|0;D=G;B=0;if((D|0)>(B|0)|(D|0)==(B|0)&C>>>0>6e4>>>0){break}J1(g);c[t>>2]=0;c[u>>2]=0;c[v>>2]=l;CC(b,g)|0;if((c[p>>2]|0)!=0){y=r;break a}}KIb(b,16,2576968,(r=i,i=i+16|0,c[r>>2]=C,c[r+8>>2]=D,r)|0);i=r;E=-22;i=e;return E|0}else{y=n+16|0}}while(0);c[y>>2]=(c[y>>2]|0)+1;do{if((c[k+88>>2]|0)!=0){y=fD(k,0,0,1)|0;D=h;C=xrc(y,G,c[D>>2]|0,c[D+4>>2]|0)|0;y=G;p=0;if(!((y|0)>(p|0)|(y|0)==(p|0)&C>>>0>1073741824>>>0)){break}FC(b);C=h+8|0;TS(k,c[C>>2]|0,c[C+4>>2]|0);if((c[h+32>>2]|0)==1){EC(b)}TS(k,c[D>>2]|0,c[D+4>>2]|0);D=HC(b,k,2558048,2540528)|0;c[C>>2]=D;c[C+4>>2]=G}}while(0);b=f|0;C=o+8|0;o=c[C>>2]|0;a[b]=((l|0)/10|0)+48;a[f+1|0]=((l|0)%10|0)+48;do{if((o|0)==0){a[f+2|0]=100;a[f+3|0]=99}else{l=f+2|0;if((o|0)==3){a[l]=115;a[f+3|0]=98;break}else{a[l]=119;a[f+3|0]=98;break}}}while(0);a[f+4|0]=0;f=c[d+36>>2]<<4&16;if((c[C>>2]|0)==1){C=n+8|0;o=wrc(c[C>>2]|0,c[C+4>>2]|0,m,(m|0)<0|0?-1:0)|0;c[C>>2]=o;c[C+4>>2]=G}if((c[(c[j>>2]|0)+88>>2]|0)!=0){j=n+32|0;C=c[j>>2]|0;o=(C|0)/16384|0;l=(C|0)%16384|0;D=n+36|0;p=n+40|0;y=c[p>>2]|0;do{if((c[D>>2]|0)>(C|0)){F=c[y+(o<<2)>>2]|0}else{g=jJb(y,4,o+1|0)|0;c[p>>2]=g;if((g|0)==0){c[D>>2]=0;c[j>>2]=0;E=-12;i=e;return E|0}g=hJb(196608)|0;c[(c[p>>2]|0)+(o<<2)>>2]=g;g=c[(c[p>>2]|0)+(o<<2)>>2]|0;if((g|0)==0){E=-12;i=e;return E|0}else{c[D>>2]=(c[D>>2]|0)+16384;F=g;break}}}while(0);c[F+(l*12|0)>>2]=f;f=fD(k,0,0,1)|0;F=h+8|0;h=xrc(f,G,c[F>>2]|0,c[F+4>>2]|0)|0;F=c[(c[n+40>>2]|0)+(o<<2)>>2]|0;c[F+(l*12|0)+4>>2]=h;c[F+(l*12|0)+8>>2]=m;c[j>>2]=(c[j>>2]|0)+1}dD(k,b,4);kD(k,m);dD(k,c[d+24>>2]|0,m);if((m&1|0)==0){E=0;i=e;return E|0}bD(k,0);E=0;i=e;return E|0}function DC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;do{if((c[d+88>>2]|0)!=0){e=b+32|0;if((c[e>>2]|0)==1){f=b+8|0;TS(d,c[f>>2]|0,c[f+4>>2]|0);EC(a);f=b;TS(d,c[f>>2]|0,c[f+4>>2]|0);break}FC(a);f=b+8|0;TS(d,c[f>>2]|0,c[f+4>>2]|0);f=b;TS(d,c[f>>2]|0,c[f+4>>2]|0);f=fD(d,0,0,1)|0;g=G;h=b+16|0;i=wrc(c[h>>2]|0,c[h+4>>2]|0,-8,-1)|0;fD(d,i,G,0)|0;kD(d,1414744396);hD(d,16,0)|0;i=c[a+24>>2]|0;if((i|0)==0){j=0}else{h=c[a+28>>2]|0;k=0;l=0;while(1){m=c[h+(l<<2)>>2]|0;n=c[m+8>>2]|0;o=c[m+12>>2]|0;do{if((c[n+8>>2]|0)==0){m=c[o+16>>2]|0;p=(k|0)<(m|0)?m:k}else{if(!(((c[n+48>>2]|0)-86016|0)>>>0<2>>>0)){p=k;break}p=(c[o+16>>2]|0)+k|0}}while(0);o=l+1|0;if(o>>>0<i>>>0){k=p;l=o}else{j=p;break}}}kD(d,j);fD(d,f,g,0)|0;GC(a,c[e>>2]|0)}}while(0);d=a+24|0;if((c[d>>2]|0)==0){return 0}j=a+28|0;a=0;do{p=c[(c[(c[j>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;b=p+36|0;l=p+40|0;if((c[b>>2]|0)>16383){k=l;i=0;do{mJb((c[k>>2]|0)+(i<<2)|0);i=i+1|0;}while((i|0)<((c[b>>2]|0)/16384|0|0))}mJb(l);c[p+32>>2]=0;c[b>>2]=0;a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0);return 0}function EC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[a+16>>2]|0;d=c[a+12>>2]|0;if((c[b+88>>2]|0)==0){return}e=SS(b,2602464)|0;f=G;g=a+24|0;h=a+28|0;if((c[g>>2]|0)==0){i=0}else{j=c[h>>2]|0;k=0;while(1){c[(c[(c[j+(k<<2)>>2]|0)+12>>2]|0)+20>>2]=0;l=k+1|0;m=c[g>>2]|0;if(l>>>0<m>>>0){k=l}else{i=m;break}}}k=-1;j=1;m=0;l=0;n=i;a:while(1){if(m>>>0<n>>>0){o=m;p=j;q=n}else{i=(((k|0)%10|0)<<8)+12288&65280|((k|0)/10|0)+48&255;r=l|0;s=l+4|0;t=l+8|0;u=j;while(1){if((u|0)!=0){break a}v=c[(c[h>>2]|0)+(k<<2)>>2]|0;w=c[v+12>>2]|0;x=c[(c[v+8>>2]|0)+8>>2]|0;if((x|0)==0){y=6553600;z=1660944384}else{y=(x|0)==3?7536640:7798784;z=1644167168}kD(b,i|z|y);kD(b,c[r>>2]|0);kD(b,c[s>>2]|0);kD(b,c[t>>2]|0);x=w+20|0;c[x>>2]=(c[x>>2]|0)+1;x=c[g>>2]|0;if((x|0)==0){u=1}else{o=0;p=1;q=x;break}}}u=c[(c[(c[h>>2]|0)+(o<<2)>>2]|0)+12>>2]|0;t=c[u+20>>2]|0;do{if((c[u+32>>2]|0)>(t|0)){s=(t|0)%16384|0;r=c[(c[u+40>>2]|0)+(((t|0)/16384|0)<<2)>>2]|0;i=r+(s*12|0)|0;if((p|0)==0){if(!((c[r+(s*12|0)+4>>2]|0)>>>0<(c[l+4>>2]|0)>>>0)){A=k;B=0;C=l;break}}A=o;B=0;C=i}else{A=k;B=p;C=l}}while(0);k=A;j=B;m=o+1|0;l=C;n=q}TS(b,e,f);GC(a,c[d+32>>2]|0);return}function FC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;d=c[a+16>>2]|0;e=c[a+12>>2]|0;if((c[d+88>>2]|0)==0){KIb(0,0,2273856,(f=i,i=i+24|0,c[f>>2]=2133320,c[f+8>>2]=2188576,c[f+16>>2]=430,f)|0);i=f;Hd()}g=e+32|0;h=c[g>>2]|0;if((h|0)>256){KIb(a,16,2109864,(f=i,i=i+16|0,c[f>>2]=h,c[f+8>>2]=256,f)|0);i=f;i=b;return}f=a+24|0;if((c[f>>2]|0)==0){i=b;return}h=a+28|0;a=e+8|0;e=0;do{j=c[(c[h>>2]|0)+(e<<2)>>2]|0;k=c[j+12>>2]|0;l=c[(c[j+8>>2]|0)+8>>2]|0;if((l|0)==0){m=6553600;n=1660944384}else{m=(l|0)==3?7536640:7798784;n=1644167168}l=fD(d,0,0,1)|0;j=G;kD(d,(e<<24)+805306368|3176553);o=k+24|0;p=k+32|0;kD(d,(c[p>>2]<<3)+24|0);oD(d,2);bD(d,0);bD(d,1);kD(d,c[p>>2]|0);kD(d,(((e|0)%10|0)<<8)+12288&65280|((e|0)/10|0)+48&255|n|m);rD(d,c[a>>2]|0,c[a+4>>2]|0);kD(d,0);if((c[p>>2]|0)>0){q=k+40|0;k=0;do{r=(k|0)%16384|0;s=c[(c[q>>2]|0)+(((k|0)/16384|0)<<2)>>2]|0;kD(d,(c[s+(r*12|0)+4>>2]|0)+8|0);kD(d,(c[s+(r*12|0)>>2]<<27&-2147483648|c[s+(r*12|0)+8>>2]&2147483647)^-2147483648);k=k+1|0;}while((k|0)<(c[p>>2]|0))}eD(d);k=fD(d,0,0,1)|0;q=G;r=o;s=wrc(c[r>>2]|0,c[r+4>>2]|0,-8,-1)|0;fD(d,s,G,0)|0;kD(d,2019847785);hD(d,8,0)|0;kD(d,c[g>>2]|0);s=c[g>>2]<<4;hD(d,s,(s|0)<0|0?-1:0)|0;rD(d,l,j);s=xrc(k,q,l,j)|0;kD(d,s);kD(d,c[p>>2]|0);fD(d,k,q,0)|0;e=e+1|0;}while(e>>>0<(c[f>>2]|0)>>>0);i=b;return}function GC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[a+16>>2]|0;j=c[a+12>>2]|0;k=fD(h,0,0,1)|0;l=G;m=a+24|0;a:do{if((c[m>>2]|0)==0){n=0}else{o=a+28|0;p=0;q=0;while(1){r=c[(c[o>>2]|0)+(q<<2)>>2]|0;s=c[r+12>>2]|0;t=s;u=c[t>>2]|0;v=c[t+4>>2]|0;if((u|0)==0&(v|0)==0){break}t=c[r+8>>2]|0;fD(h,u,v,0)|0;YS(t,e,f,g);v=c[f>>2]|0;if((v|0)==0){kD(h,c[s+16>>2]|0)}else{u=s+8|0;r=Crc(c[u>>2]|0,c[u+4>>2]|0,v,(v|0)<0|0?-1:0)|0;kD(h,r)}if((c[t+8>>2]|0)==0){t=c[s+16>>2]|0;w=(p|0)>(t|0)?p:t}else{w=p}t=q+1|0;if(t>>>0<(c[m>>2]|0)>>>0){p=w;q=t}else{n=w;break a}}KIb(0,0,2273856,(x=i,i=i+24|0,c[x>>2]=2224720,c[x+8>>2]=2188576,c[x+16>>2]=127,x)|0);i=x;Hd()}}while(0);if((b|0)!=1){y=fD(h,k,l,0)|0;z=G;i=d;return}b=j+24|0;j=c[b>>2]|0;w=c[b+4>>2]|0;if((j|0)==0&(w|0)==0){KIb(0,0,2273856,(x=i,i=i+24|0,c[x>>2]=2158504,c[x+8>>2]=2188576,c[x+16>>2]=140,x)|0);i=x;Hd()}fD(h,j,w,0)|0;kD(h,n);y=fD(h,k,l,0)|0;z=G;i=d;return}function HC(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[a+12>>2]|0;h=g+32|0;c[h>>2]=(c[h>>2]|0)+1;h=a+24|0;if((c[h>>2]|0)!=0){i=c[a+28>>2]|0;a=0;do{c[(c[(c[i+(a<<2)>>2]|0)+12>>2]|0)+32>>2]=0;a=a+1|0;}while(a>>>0<(c[h>>2]|0)>>>0)}h=SS(b,2523624)|0;a=g;c[a>>2]=h;c[a+4>>2]=G;kD(b,(d[e+1|0]|0)<<8|(d[e]|0)|(d[e+2|0]|0)<<16|(d[e+3|0]|0)<<24);e=SS(b,2329816)|0;a=G;kD(b,(d[f+1|0]|0)<<8|(d[f]|0)|(d[f+2|0]|0)<<16|(d[f+3|0]|0)<<24);return(G=a,e)|0}function IC(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((b|0)==0){d=2627600;return d|0}d=c[b>>2]|0;return d|0}function JC(a,b){a=a|0;b=b|0;var d=0,e=0;do{if((b|0)==0){d=c[a+8>>2]|0;if((d|0)==0){break}if((c[(c[a+4>>2]|0)+56>>2]|0)==0){break}else{e=d}return e|0}}while(0);e=0;return e|0}function KC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;a:do{if((a|0)==0){b=0}else{d=0;while(1){e=c[((d|0)==0?6041800:d+28|0)>>2]|0;if((e|0)==0){b=0;break a}if((c[e+56>>2]|0)==(a|0)){b=e;break}else{d=e}}}}while(0);while(1){a=c[((b|0)==0?6041800:b+28|0)>>2]|0;if((a|0)==0){f=0;g=6;break}d=c[a+56>>2]|0;if((d|0)==0){b=a}else{f=d;g=6;break}}if((g|0)==6){return f|0}return 0}function LC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a>>2]|0;e=c[((d|0)==0?6041800:d+28|0)>>2]|0;d=e;c[a>>2]=d;if((e|0)==0){f=0;return f|0}a:do{if((b|0)==0){g=e;h=d;while(1){if((c[g+12>>2]|0)!=0){i=g;break a}j=c[((h|0)==0?6041800:h+28|0)>>2]|0;k=j;c[a>>2]=k;if((j|0)==0){f=0;break}else{g=j;h=k}}return f|0}else{h=e;g=d;while(1){if((c[h+16>>2]|0)!=0){i=h;break a}k=c[((g|0)==0?6041800:g+28|0)>>2]|0;j=k;c[a>>2]=j;if((k|0)==0){f=0;break}else{h=k;g=j}}return f|0}}while(0);f=c[i>>2]|0;return f|0}function MC(a){a=a|0;var b=0,d=0;b=6041800;while(1){d=c[b>>2]|0;if((d|0)==0){break}else{b=d+28|0}}c[b>>2]=a;c[a+28>>2]=0;return 0}function NC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+4|0;e=c[d>>2]|0;f=c[e+8>>2]|0;if((f|0)==0){g=Ee[c[e+4>>2]&511](a,c[a+12>>2]|0,c[a+16>>2]|0)|0}else{g=hf[f&1023](a,c[a+12>>2]|0,c[a+16>>2]|0,b)|0}if((g|0)!=0){h=g;return h|0}c[a+28>>2]=1;do{if((c[a+16>>2]&2|0)==0){if((irc(c[c[d>>2]>>2]|0,2519488)|0)==0){break}else{h=0}return h|0}}while(0);g=a+24|0;if((c[g>>2]|0)!=0){h=0;return h|0}b=c[(c[d>>2]|0)+20>>2]|0;do{if((b|0)!=0){d=hf[b&1023](a,0,0,0)|0;f=G;e=0;if((f|0)<(e|0)|(f|0)==(e|0)&d>>>0<0>>>0){break}else{h=0}return h|0}}while(0);c[g>>2]=1;h=0;return h|0}function OC(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[(c[a+4>>2]|0)+20>>2]|0;if((f|0)==0){g=-1;h=-38;return(G=g,h)|0}i=hf[f&1023](a,b,d,e&-131073)|0;g=G;h=i;return(G=g,h)|0}function PC(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+8|0;h=g|0;if((c[1510450]|0)==0){KIb(0,24,2404928,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}k=QC(d)|0;if((k|0)==0){c[b>>2]=0;if((AFb(2329656,d,0)|0)==0){l=-1330794744;i=g;return l|0}KIb(0,24,2273600,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;l=-1330794744;i=g;return l|0}m=h;do{if((e&1|0)!=0){if((c[k+12>>2]|0)!=0){break}KIb(0,16,2223936,(j=i,i=i+8|0,c[j>>2]=c[k>>2],j)|0);i=j;l=-5;i=g;return l|0}}while(0);do{if((e&2|0)!=0){if((c[k+16>>2]|0)!=0){break}KIb(0,16,2188400,(j=i,i=i+8|0,c[j>>2]=c[k>>2],j)|0);i=j;l=-5;i=g;return l|0}}while(0);n=pJb((lrc(d|0)|0)+49|0)|0;o=n;c[h>>2]=o;a:do{if((n|0)==0){p=-12;q=o}else{c[n>>2]=1238072;r=n+48|0;c[n+12>>2]=r;prc(r|0,d|0)|0;c[(c[h>>2]|0)+4>>2]=k;r=c[h>>2]|0;c[r+16>>2]=e;c[r+24>>2]=0;c[r+20>>2]=0;s=c[k+52>>2]|0;b:do{if((s|0)==0){t=r}else{u=pJb(s)|0;c[(c[h>>2]|0)+8>>2]=u;u=c[h>>2]|0;v=c[u+8>>2]|0;if((v|0)==0){p=-12;q=u;break a}w=c[k+56>>2]|0;if((w|0)==0){t=u;break}x=k|0;y=lrc(c[x>>2]|0)|0;z=_b(c[u+12>>2]|0,44)|0;c[v>>2]=w;SJb(c[(c[h>>2]|0)+8>>2]|0);w=c[h>>2]|0;v=c[w+12>>2]|0;if(!((krc(c[x>>2]|0,v,y)|0)==0&(v+y|0)==(z|0))){t=w;break}w=a[z+1|0]|0;y=w<<24>>24;v=z+2|0;while(1){A=_b(v|0,y|0)|0;if(!((A|0)!=0&v>>>0<A>>>0)){B=21;break}x=A+1|0;C=_b(x|0,y|0)|0;if((C|0)==0){B=21;break}a[A]=0;a[C]=0;u=EJb(c[(c[h>>2]|0)+8>>2]|0,v,x,0)|0;if((u|0)==-1414549496){B=19;break}a[A]=w;a[C]=w;if((u|0)>-1){v=C+1|0}else{break}}do{if((B|0)==19){KIb(c[h>>2]|0,16,2158440,(j=i,i=i+8|0,c[j>>2]=v,j)|0);i=j;a[A]=w;a[C]=w}else if((B|0)==21){if((v|0)!=(A|0)){break}orc(z|0,v+1|0,lrc(v|0)|0)|0;t=c[h>>2]|0;break b}}while(0);KIb(c[h>>2]|0,16,2133224,(j=i,i=i+8|0,c[j>>2]=z,j)|0);i=j;mJb((c[h>>2]|0)+8|0);mJb(m);p=-22;q=c[h>>2]|0;break a}}while(0);if((f|0)!=0){s=f;r=t+32|0;v=c[s+4>>2]|0;c[r>>2]=c[s>>2];c[r+4>>2]=v}c[b>>2]=t;l=0;i=g;return l|0}}while(0);c[b>>2]=0;if((q|0)!=0){mJb(q+8|0)}mJb(m);l=p;i=g;return l|0}function QC(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+256|0;e=d|0;f=d+128|0;g=ud(b|0,2109712)|0;h=a[b+g|0]|0;if((h<<24>>24|0)==58){j=g+1|0;k=4}else if((h<<24>>24|0)==44){h=g+1|0;if((_b(b+h|0,58)|0)==0){k=5}else{j=h;k=4}}else{k=5}if((k|0)==4){CFb(e|0,b,j>>>0>128>>>0?128:j)|0}else if((k|0)==5){j=e|0;a[j]=a[2519488]|0;a[j+1|0]=a[2519489]|0;a[j+2|0]=a[2519490]|0;a[j+3|0]=a[2519491]|0;a[j+4|0]=a[2519492]|0}j=e|0;e=_b(j|0,44)|0;if((e|0)!=0){a[e]=0}e=f|0;CFb(e,j,128)|0;f=_b(e|0,43)|0;if((f|0)!=0){a[f]=0}f=c[1510450]|0;if((f|0)==0){l=0;i=d;return l|0}else{m=f}while(1){f=c[m>>2]|0;if((irc(j,f)|0)==0){l=m;k=15;break}if((c[m+60>>2]&1|0)!=0){if((irc(e,f)|0)==0){l=m;k=15;break}}f=c[((m|0)==0?6041800:m+28|0)>>2]|0;if((f|0)==0){l=0;k=15;break}else{m=f}}if((k|0)==15){i=d;return l|0}return 0}function RC(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+8|0;h=g|0;j=PC(a,b,d,e)|0;if((j|0)!=0){k=j;i=g;return k|0}do{if((f|0)==0){l=5}else{j=c[a>>2]|0;if((c[(c[j+4>>2]|0)+56>>2]|0)==0){l=5;break}e=XJb(c[j+8>>2]|0,f)|0;if((e|0)<0){m=e}else{l=5}}}while(0);do{if((l|0)==5){e=c[a>>2]|0;j=e+4|0;d=c[j>>2]|0;b=c[d+8>>2]|0;if((b|0)==0){n=Ee[c[d+4>>2]&511](e,c[e+12>>2]|0,c[e+16>>2]|0)|0}else{n=hf[b&1023](e,c[e+12>>2]|0,c[e+16>>2]|0,f)|0}if((n|0)!=0){m=n;break}c[e+28>>2]=1;do{if((c[e+16>>2]&2|0)==0){if((irc(c[c[j>>2]>>2]|0,2519488)|0)==0){break}else{k=0}i=g;return k|0}}while(0);b=e+24|0;if((c[b>>2]|0)!=0){k=0;i=g;return k|0}d=c[(c[j>>2]|0)+20>>2]|0;do{if((d|0)!=0){o=hf[d&1023](e,0,0,0)|0;p=G;q=0;if((p|0)<(q|0)|(p|0)==(q|0)&o>>>0<0>>>0){break}else{k=0}i=g;return k|0}}while(0);c[b>>2]=1;k=0;i=g;return k|0}}while(0);n=c[a>>2]|0;f=h;c[h>>2]=n;if((n|0)!=0){h=n+4|0;do{if((c[n+28>>2]|0)!=0){l=c[(c[h>>2]|0)+24>>2]|0;if((l|0)==0){break}ve[l&4095](n)|0}}while(0);l=c[h>>2]|0;if((c[l+52>>2]|0)!=0){h=n+8|0;if((c[l+56>>2]|0)!=0){WJb(c[h>>2]|0)}mJb(h)}mJb(f)}c[a>>2]=0;k=m;i=g;return k|0}function SC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;if((a|0)==0){e=0;i=b;return e|0}f=a+4|0;do{if((c[a+28>>2]|0)==0){g=0}else{h=c[(c[f>>2]|0)+24>>2]|0;if((h|0)==0){g=0;break}g=ve[h&4095](a)|0}}while(0);h=c[f>>2]|0;if((c[h+52>>2]|0)!=0){f=a+8|0;if((c[h+56>>2]|0)!=0){WJb(c[f>>2]|0)}mJb(f)}mJb(d);e=g;i=b;return e|0}function TC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=a+16|0;if((c[e>>2]&1|0)==0){f=-5;return f|0}g=c[(c[a+4>>2]|0)+12>>2]|0;h=a+32|0;i=a+40|0;j=(h|0)==0;k=h|0;h=a+36|0;l=0;m=5;n=0;o=0;p=b;q=d;a:while(1){if(j){while(1){r=Ee[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}else{while(1){r=c[k>>2]|0;if((r|0)!=0){if((ve[r&4095](c[h>>2]|0)|0)!=0){f=-1414092869;t=20;break a}}r=Ee[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}if((c[e>>2]&8|0)!=0){f=s;t=20;break}do{if((s|0)==-11){if((m|0)!=0){u=m-1|0;v=0;w=n;x=o;break}do{if((c[i>>2]|0)==0&(c[i+4>>2]|0)==0){y=n;z=o}else{r=jLb()|0;A=G;if((o|0)==0&(n|0)==0){y=A;z=r;break}B=wrc(c[i>>2]|0,c[i+4>>2]|0,o,n)|0;C=G;if((A|0)>(C|0)|(A|0)==(C|0)&r>>>0>B>>>0){f=-5;t=20;break a}else{y=n;z=o}}}while(0);kLb(1e3)|0;u=0;v=0;w=y;x=z}else{if((s|0)<1){t=17;break a}u=(m|0)>2?m:2;v=s;w=n;x=o}}while(0);B=v+l|0;if((B|0)<1){l=B;m=u;n=w;o=x;p=b+B|0;q=d-B|0}else{f=B;t=20;break}}if((t|0)==17){f=(s|0)<0&(s|0)!=-541478725?s:l;return f|0}else if((t|0)==20){return f|0}return 0}function UC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=a+16|0;if((c[e>>2]&1|0)==0){f=-5;return f|0}g=c[(c[a+4>>2]|0)+12>>2]|0;h=a+32|0;i=a+40|0;if((d|0)<=0){f=0;return f|0}j=(h|0)==0;k=h|0;h=a+36|0;l=0;m=5;n=0;o=0;p=b;q=d;a:while(1){if(j){while(1){r=Ee[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}else{while(1){r=c[k>>2]|0;if((r|0)!=0){if((ve[r&4095](c[h>>2]|0)|0)!=0){f=-1414092869;t=21;break a}}r=Ee[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}if((c[e>>2]&8|0)!=0){f=s;t=21;break}do{if((s|0)==-11){if((m|0)!=0){u=m-1|0;v=0;w=n;x=o;break}do{if((c[i>>2]|0)==0&(c[i+4>>2]|0)==0){y=n;z=o}else{r=jLb()|0;A=G;if((o|0)==0&(n|0)==0){y=A;z=r;break}B=wrc(c[i>>2]|0,c[i+4>>2]|0,o,n)|0;C=G;if((A|0)>(C|0)|(A|0)==(C|0)&r>>>0>B>>>0){f=-5;t=21;break a}else{y=n;z=o}}}while(0);kLb(1e3)|0;u=0;v=0;w=y;x=z}else{if((s|0)<1){t=18;break a}u=(m|0)>2?m:2;v=s;w=n;x=o}}while(0);B=v+l|0;if((B|0)<(d|0)){l=B;m=u;n=w;o=x;p=b+B|0;q=d-B|0}else{f=B;t=21;break}}if((t|0)==18){f=(s|0)<0&(s|0)!=-541478725?s:l;return f|0}else if((t|0)==21){return f|0}return 0}function VC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=a+16|0;if((c[e>>2]&2|0)==0){f=-5;return f|0}g=c[a+20>>2]|0;if((g|0)!=0&(g|0)<(d|0)){f=-5;return f|0}g=c[(c[a+4>>2]|0)+16>>2]|0;h=a+32|0;i=a+40|0;if((d|0)<=0){f=0;return f|0}j=(h|0)==0;k=h|0;h=a+36|0;l=0;m=5;n=0;o=0;p=b;q=d;a:while(1){if(j){while(1){r=Ee[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}else{while(1){r=c[k>>2]|0;if((r|0)!=0){if((ve[r&4095](c[h>>2]|0)|0)!=0){f=-1414092869;t=22;break a}}r=Ee[g&511](a,p,q)|0;if(!((r|0)==-4)){s=r;break}}}if((c[e>>2]&8|0)!=0){f=s;t=22;break}do{if((s|0)==-11){if((m|0)!=0){u=m-1|0;v=0;w=n;x=o;break}do{if((c[i>>2]|0)==0&(c[i+4>>2]|0)==0){y=n;z=o}else{r=jLb()|0;A=G;if((o|0)==0&(n|0)==0){y=A;z=r;break}B=wrc(c[i>>2]|0,c[i+4>>2]|0,o,n)|0;C=G;if((A|0)>(C|0)|(A|0)==(C|0)&r>>>0>B>>>0){f=-5;t=22;break a}else{y=n;z=o}}}while(0);kLb(1e3)|0;u=0;v=0;w=y;x=z}else{if((s|0)<1){t=19;break a}u=(m|0)>2?m:2;v=s;w=n;x=o}}while(0);B=v+l|0;if((B|0)<(d|0)){l=B;m=u;n=w;o=x;p=b+B|0;q=d-B|0}else{f=B;t=22;break}}if((t|0)==19){f=(s|0)<0&(s|0)!=-541478725?s:l;return f|0}else if((t|0)==22){return f|0}return 0}function WC(a){a=a|0;var b=0,d=0;b=QC(a)|0;if((b|0)==0){d=0;return d|0}d=c[b>>2]|0;return d|0}function XC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=PC(f,a,b,0)|0;if((g|0)!=0){h=g;i=d;return h|0}g=c[f>>2]|0;f=g+4|0;a=c[f>>2]|0;j=c[a+64>>2]|0;if((j|0)==0){k=c[a+8>>2]|0;if((k|0)==0){l=Ee[c[a+4>>2]&511](g,c[g+12>>2]|0,c[g+16>>2]|0)|0}else{l=hf[k&1023](g,c[g+12>>2]|0,c[g+16>>2]|0,0)|0}do{if((l|0)==0){c[g+28>>2]=1;if((c[g+16>>2]&2|0)==0){if((irc(c[c[f>>2]>>2]|0,2519488)|0)!=0){m=0;break}}k=g+24|0;if((c[k>>2]|0)!=0){m=0;break}a=c[(c[f>>2]|0)+20>>2]|0;if((a|0)!=0){n=hf[a&1023](g,0,0,0)|0;a=G;o=0;if(!((a|0)<(o|0)|(a|0)==(o|0)&n>>>0<0>>>0)){m=0;break}}c[k>>2]=1;m=0}else{m=l}}while(0);p=(m|0)>-1?b:m}else{p=We[j&2047](g,b)|0}b=e;c[e>>2]=g;if((g|0)==0){h=p;i=d;return h|0}do{if((c[g+28>>2]|0)!=0){e=c[(c[f>>2]|0)+24>>2]|0;if((e|0)==0){break}ve[e&4095](g)|0}}while(0);e=c[f>>2]|0;if((c[e+52>>2]|0)!=0){f=g+8|0;if((c[e+56>>2]|0)!=0){WJb(c[f>>2]|0)}mJb(f)}mJb(b);h=p;i=d;return h|0}function YC(a){a=a|0;var b=0,d=0,e=0;do{if((a|0)!=0){b=c[a>>2]|0;if((b|0)==0){break}d=ve[b&4095](c[a+4>>2]|0)|0;if((d|0)==0){break}else{e=d}return e|0}}while(0);e=0;return e|0}function ZC(a,b){a=a|0;b=b|0;var d=0;if((b|0)==0){d=c[a+20>>2]|0}else{d=0}return d|0}function _C(a){a=a|0;return((a|0)!=0?0:1238072)|0}function $C(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;c[a+4>>2]=b;c[a+8>>2]=d;c[a+12>>2]=b;c[a+20>>2]=f;c[a+104>>2]=0;f=(e|0)!=0;if(f){c[a+16>>2]=b+d;c[a+56>>2]=1}else{c[a+16>>2]=b;c[a+56>>2]=0}c[a+28>>2]=h;c[a+24>>2]=g;c[a+32>>2]=i;h=a+40|0;c[a+76>>2]=0;mrc(h|0,0,16)|0;c[a+88>>2]=(i|0)!=0;c[a+60>>2]=0;c[a+72>>2]=0;if((g|0)!=0|f){j=a+80|0;c[j>>2]=0;k=a+84|0;c[k>>2]=0;return 0}c[h>>2]=d;c[h+4>>2]=(d|0)<0|0?-1:0;c[a+16>>2]=b+d;j=a+80|0;c[j>>2]=0;k=a+84|0;c[k>>2]=0;return 0}function aD(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=pJb(128)|0;if((i|0)==0){j=0;return j|0}c[i+4>>2]=a;c[i+8>>2]=b;c[i+12>>2]=a;c[i+20>>2]=e;c[i+104>>2]=0;e=(d|0)!=0;if(e){c[i+16>>2]=a+b;c[i+56>>2]=1}else{c[i+16>>2]=a;c[i+56>>2]=0}c[i+28>>2]=g;c[i+24>>2]=f;c[i+32>>2]=h;g=i+40|0;c[i+76>>2]=0;mrc(g|0,0,16)|0;c[i+88>>2]=(h|0)!=0;c[i+60>>2]=0;c[i+72>>2]=0;if(!((f|0)!=0|e)){e=g;c[e>>2]=b;c[e+4>>2]=(b|0)<0|0?-1:0;c[i+16>>2]=a+b}c[i+80>>2]=0;c[i+84>>2]=0;j=i;return j|0}function bD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b+12|0;f=c[e>>2]|0;c[e>>2]=f+1;a[f]=d;d=c[e>>2]|0;if(d>>>0<(c[b+16>>2]|0)>>>0){return}f=b+4|0;g=c[f>>2]|0;do{if(d>>>0>g>>>0){h=d-g|0;i=c[b+28>>2]|0;do{if((i|0)!=0){j=b+76|0;if((c[j>>2]|0)!=0){break}k=Ee[i&511](c[b+20>>2]|0,g,h)|0;if((k|0)>=0){break}c[j>>2]=k}}while(0);i=b+124|0;c[i>>2]=(c[i>>2]|0)+1;i=b+40|0;k=wrc(c[i>>2]|0,c[i+4>>2]|0,h,(h|0)<0|0?-1:0)|0;c[i>>2]=k;c[i+4>>2]=G;i=c[b+72>>2]|0;if((i|0)==0){l=c[f>>2]|0;break}else{k=b+64|0;j=b+68|0;m=c[j>>2]|0;c[k>>2]=Ee[i&511](c[k>>2]|0,m,(c[e>>2]|0)-m|0)|0;m=c[f>>2]|0;c[j>>2]=m;l=m;break}}else{l=g}}while(0);c[e>>2]=l;return}function cD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((d|0)<=0){return}e=a+16|0;f=a+12|0;g=b&255;b=a+4|0;h=a+28|0;i=a+124|0;j=a+40|0;k=a+72|0;l=a+64|0;m=a+68|0;n=a+76|0;o=a+20|0;a=d;d=c[f>>2]|0;while(1){p=(c[e>>2]|0)-d|0;q=(p|0)>(a|0)?a:p;mrc(d|0,g|0,q|0)|0;p=(c[f>>2]|0)+q|0;c[f>>2]=p;if(p>>>0<(c[e>>2]|0)>>>0){r=p}else{s=c[b>>2]|0;do{if(p>>>0>s>>>0){t=p-s|0;u=c[h>>2]|0;do{if((u|0)!=0){if((c[n>>2]|0)!=0){break}v=Ee[u&511](c[o>>2]|0,s,t)|0;if((v|0)>=0){break}c[n>>2]=v}}while(0);c[i>>2]=(c[i>>2]|0)+1;u=wrc(c[j>>2]|0,c[j+4>>2]|0,t,(t|0)<0|0?-1:0)|0;c[j>>2]=u;c[j+4>>2]=G;u=c[k>>2]|0;if((u|0)==0){w=c[b>>2]|0;break}else{v=c[m>>2]|0;c[l>>2]=Ee[u&511](c[l>>2]|0,v,(c[f>>2]|0)-v|0)|0;v=c[b>>2]|0;c[m>>2]=v;w=v;break}}else{w=s}}while(0);c[f>>2]=w;r=w}s=a-q|0;if((s|0)>0){a=s;d=r}else{break}}return}function dD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;do{if((c[a+104>>2]|0)!=0){e=a+72|0;if((c[e>>2]|0)!=0){break}f=a+12|0;g=c[f>>2]|0;h=a+4|0;i=c[h>>2]|0;do{if(g>>>0>i>>>0){j=g-i|0;k=a+28|0;l=c[k>>2]|0;do{if((l|0)!=0){m=a+76|0;if((c[m>>2]|0)!=0){break}n=Ee[l&511](c[a+20>>2]|0,i,j)|0;if((n|0)>=0){break}c[m>>2]=n}}while(0);l=a+124|0;c[l>>2]=(c[l>>2]|0)+1;l=a+40|0;n=wrc(c[l>>2]|0,c[l+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[l>>2]=n;c[l+4>>2]=G;l=c[e>>2]|0;if((l|0)==0){o=c[h>>2]|0;p=k;break}else{n=a+64|0;m=a+68|0;q=c[m>>2]|0;c[n>>2]=Ee[l&511](c[n>>2]|0,q,(c[f>>2]|0)-q|0)|0;q=c[h>>2]|0;c[m>>2]=q;o=q;p=k;break}}else{o=i;p=a+28|0}}while(0);c[f>>2]=o;c[a+48>>2]=0;i=c[p>>2]|0;do{if((i|0)!=0){h=a+76|0;if((c[h>>2]|0)!=0){break}e=Ee[i&511](c[a+20>>2]|0,b,d)|0;if((e|0)>=0){break}c[h>>2]=e}}while(0);i=a+124|0;c[i>>2]=(c[i>>2]|0)+1;i=a+40|0;f=wrc(c[i>>2]|0,c[i+4>>2]|0,d,(d|0)<0|0?-1:0)|0;c[i>>2]=f;c[i+4>>2]=G;return}}while(0);if((d|0)<=0){return}p=a+16|0;o=a+12|0;i=a+4|0;f=a+28|0;e=a+124|0;h=a+40|0;g=a+72|0;q=a+64|0;m=a+68|0;n=a+76|0;l=a+20|0;a=d;d=b;b=c[o>>2]|0;while(1){r=(c[p>>2]|0)-b|0;s=(r|0)>(a|0)?a:r;nrc(b|0,d|0,s)|0;r=(c[o>>2]|0)+s|0;c[o>>2]=r;if(r>>>0<(c[p>>2]|0)>>>0){t=r}else{u=c[i>>2]|0;do{if(r>>>0>u>>>0){v=r-u|0;w=c[f>>2]|0;do{if((w|0)!=0){if((c[n>>2]|0)!=0){break}x=Ee[w&511](c[l>>2]|0,u,v)|0;if((x|0)>=0){break}c[n>>2]=x}}while(0);c[e>>2]=(c[e>>2]|0)+1;w=wrc(c[h>>2]|0,c[h+4>>2]|0,v,(v|0)<0|0?-1:0)|0;c[h>>2]=w;c[h+4>>2]=G;w=c[g>>2]|0;if((w|0)==0){y=c[i>>2]|0;break}else{k=c[m>>2]|0;c[q>>2]=Ee[w&511](c[q>>2]|0,k,(c[o>>2]|0)-k|0)|0;k=c[i>>2]|0;c[m>>2]=k;y=k;break}}else{y=u}}while(0);c[o>>2]=y;t=y}u=a-s|0;if((u|0)<=0){break}a=u;d=d+s|0;b=t}return}function eD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+12|0;d=c[b>>2]|0;e=a+4|0;f=c[e>>2]|0;if(!(d>>>0>f>>>0)){g=f;c[b>>2]=g;h=a+48|0;c[h>>2]=0;return}i=d-f|0;d=c[a+28>>2]|0;do{if((d|0)!=0){j=a+76|0;if((c[j>>2]|0)!=0){break}k=Ee[d&511](c[a+20>>2]|0,f,i)|0;if((k|0)>=0){break}c[j>>2]=k}}while(0);f=a+124|0;c[f>>2]=(c[f>>2]|0)+1;f=a+40|0;d=wrc(c[f>>2]|0,c[f+4>>2]|0,i,(i|0)<0|0?-1:0)|0;c[f>>2]=d;c[f+4>>2]=G;f=c[a+72>>2]|0;if((f|0)==0){g=c[e>>2]|0;c[b>>2]=g;h=a+48|0;c[h>>2]=0;return}else{d=a+64|0;i=a+68|0;k=c[i>>2]|0;c[d>>2]=Ee[f&511](c[d>>2]|0,k,(c[b>>2]|0)-k|0)|0;k=c[e>>2]|0;c[i>>2]=k;g=k;c[b>>2]=g;h=a+48|0;c[h>>2]=0;return}}function fD(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=e&131072;if((a|0)==0){g=-1;h=-22;return(G=g,h)|0}i=a+16|0;j=a+4|0;k=a+40|0;l=a+56|0;m=a+12|0;n=a+48|0;o=a+104|0;p=a+32|0;q=a+88|0;r=a+20|0;s=a+52|0;t=d;d=b;b=e;u=e&-131073;a:while(1){e=c[i>>2]|0;v=c[j>>2]|0;w=v;x=e-w|0;y=c[k>>2]|0;z=c[k+4>>2]|0;A=c[l>>2]|0;B=(A|0)!=0;C=x;D=(x|0)<0|0?-1:0;E=xrc(y,z,B?0:C,B?0:D)|0;B=G;if(u>>>0>1>>>0){g=-1;h=-22;F=45;break}if((u|0)==1){H=(c[m>>2]|0)-w|0;I=wrc(H,(H|0)<0|0?-1:0,E,B)|0;H=G;if((d|0)==0&(t|0)==0){g=H;h=I;F=45;break}J=wrc(I,H,d,t)|0;K=G;L=J}else{K=t;L=d}M=xrc(L,K,E,B)|0;J=G;do{if((c[n>>2]|0)==0){if((c[o>>2]|0)==0){H=0;if((J|0)<(H|0)|(J|0)==(H|0)&M>>>0<0>>>0|((J|0)>(D|0)|(J|0)==(D|0)&M>>>0>C>>>0)){break}else{F=11;break a}}else{H=0;if((J|0)<(H|0)|(J|0)==(H|0)&M>>>0<0>>>0|(c[p>>2]|0)!=0|((J|0)>(D|0)|(J|0)==(D|0)&M>>>0>C>>>0)){break}else{F=11;break a}}}}while(0);if((c[q>>2]|0)==0){F=14}else{C=e+4096-w|0;D=(C|0)<0|0?-1:0;if(!((J|0)>(D|0)|(J|0)==(D|0)&M>>>0>C>>>0)){F=14}}do{if((F|0)==14){F=0;C=-1;if(!((A|0)==0&((J|0)>(C|0)|(J|0)==(C|0)&M>>>0>-1>>>0))){break}if((c[o>>2]|0)==0){if((b|0)==2){break}else{F=18;break a}}else{if((c[p>>2]|0)!=0|(b|0)==2){break}else{F=18;break a}}}}while(0);w=0;if(!((A|0)==0&((J|0)<(w|0)|(J|0)==(w|0)&M>>>0<0>>>0))){F=28;break}w=xrc(0,0,M,J)|0;e=G;C=x>>1;D=C;H=(C|0)<0|0?-1:0;if(!((H|0)>(e|0)|(H|0)==(e|0)&D>>>0>w>>>0)){F=38;break}w=c[p>>2]|0;e=0;if(!((w|0)!=0&((K|0)>(e|0)|(K|0)==(e|0)&L>>>0>0>>>0))){N=w;F=39;break}e=(H|0)>(B|0)|(H|0)==(B|0)&D>>>0>E>>>0;C=xrc(E,B,e?E:D,e?B:H)|0;H=G;e=hf[w&1023](c[r>>2]|0,C,H,0)|0;w=G;D=0;if((w|0)<(D|0)|(w|0)==(D|0)&e>>>0<0>>>0){g=w;h=e;F=45;break}e=c[j>>2]|0;c[m>>2]=e;c[i>>2]=e;c[k>>2]=C;c[k+4>>2]=H;c[s>>2]=0;gD(a);t=K;d=L;b=f;u=0}do{if((F|0)==11){c[m>>2]=v+M}else if((F|0)==18){u=y;b:do{if((z|0)<(K|0)|(z|0)==(K|0)&y>>>0<L>>>0){while(1){if((c[s>>2]|0)!=0){g=-1;h=-541478725;break}gD(a);f=c[k>>2]|0;b=c[k+4>>2]|0;if(!((b|0)<(K|0)|(b|0)==(K|0)&f>>>0<L>>>0)){O=f;break b}}return(G=g,h)|0}else{O=u}}while(0);if((c[s>>2]|0)==0){c[m>>2]=(c[i>>2]|0)+(L-O);break}else{g=-1;h=-541478725;return(G=g,h)|0}}else if((F|0)==28){if((A|0)==0){F=38;break}u=c[m>>2]|0;do{if(u>>>0>v>>>0){B=u-v|0;E=c[a+28>>2]|0;do{if((E|0)!=0){x=a+76|0;if((c[x>>2]|0)!=0){break}J=Ee[E&511](c[r>>2]|0,v,B)|0;if((J|0)>=0){break}c[x>>2]=J}}while(0);E=a+124|0;c[E>>2]=(c[E>>2]|0)+1;E=wrc(c[k>>2]|0,c[k+4>>2]|0,B,(B|0)<0|0?-1:0)|0;c[k>>2]=E;c[k+4>>2]=G;E=c[a+72>>2]|0;if((E|0)==0){P=c[j>>2]|0;break}else{J=a+64|0;x=a+68|0;f=c[x>>2]|0;c[J>>2]=Ee[E&511](c[J>>2]|0,f,(c[m>>2]|0)-f|0)|0;f=c[j>>2]|0;c[x>>2]=f;P=f;break}}else{P=v}}while(0);c[m>>2]=P;c[n>>2]=1;F=38}else if((F|0)==45){return(G=g,h)|0}}while(0);if((F|0)==38){N=c[p>>2]|0;F=39}if((F|0)==39){if((N|0)==0){g=-1;h=-32;return(G=g,h)|0}F=hf[N&1023](c[r>>2]|0,L,K,0)|0;r=G;N=0;if((r|0)<(N|0)|(r|0)==(N|0)&F>>>0<0>>>0){g=r;h=F;return(G=g,h)|0}F=a+120|0;c[F>>2]=(c[F>>2]|0)+1;F=c[j>>2]|0;if((c[l>>2]|0)==0){c[i>>2]=F}c[m>>2]=F;c[k>>2]=L;c[k+4>>2]=K}c[s>>2]=0;g=K;h=L;return(G=g,h)|0}function gD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;d=c[a+60>>2]|0;e=(d|0)==0?32768:d;d=a+16|0;f=c[d>>2]|0;g=a+4|0;h=c[g>>2]|0;j=f;k=h;l=a+8|0;m=c[l>>2]|0;n=(e+j-k|0)<(m|0)?f:h;o=k-n+m|0;m=a+24|0;k=c[m>>2]|0;do{if((k|0)==0){if((c[a+12>>2]|0)>>>0<f>>>0){break}c[a+52>>2]=1}}while(0);p=a+52|0;if((c[p>>2]|0)!=0){i=b;return}q=c[a+72>>2]|0;if((q|0)!=0&(n|0)==(h|0)){r=a+68|0;s=c[r>>2]|0;if(f>>>0>s>>>0){f=a+64|0;c[f>>2]=Ee[q&511](c[f>>2]|0,s,j-s|0)|0;t=c[g>>2]|0;u=c[m>>2]|0}else{t=h;u=k}c[r>>2]=t;v=u;w=t}else{v=k;w=h}a:do{if((v|0)!=0){do{if((c[l>>2]|0)>(e|0)){if((n|0)==(w|0)){h=hJb(e)|0;k=c[g>>2]|0;do{if((h|0)==0){x=k}else{kJb(k);c[g>>2]=h;c[l>>2]=e;c[a+12>>2]=h;t=a+56|0;if((c[t>>2]|0)==0){c[d>>2]=h;c[t>>2]=0;x=h;break}else{c[d>>2]=h+e;c[t>>2]=1;x=h;break}}}while(0);c[a+68>>2]=x;y=x}else{y=n}if((o|0)<(e|0)){KIb(0,0,2404808,(h=i,i=i+24|0,c[h>>2]=2158416,c[h+8>>2]=2273528,c[h+16>>2]=443,h)|0);i=h;Hd()}else{h=c[m>>2]|0;if((h|0)==0){break a}else{z=h;A=y;B=e;break}}}else{z=v;A=n;B=o}}while(0);h=Ee[z&511](c[a+20>>2]|0,A,B)|0;if((h|0)>=1){k=h;t=(h|0)<0|0?-1:0;u=a+40|0;r=wrc(c[u>>2]|0,c[u+4>>2]|0,k,t)|0;c[u>>2]=r;c[u+4>>2]=G;c[a+12>>2]=A;c[d>>2]=A+h;u=a+112|0;r=wrc(c[u>>2]|0,c[u+4>>2]|0,k,t)|0;c[u>>2]=r;c[u+4>>2]=G;i=b;return}c[p>>2]=1;if((h|0)>=0){i=b;return}c[a+76>>2]=h;i=b;return}}while(0);c[p>>2]=1;i=b;return}function hD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fD(a,b,c,1)|0;return(G=G,d)|0}function iD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)==0){b=-1;d=-22;return(G=b,d)|0}e=a+32|0;f=c[e>>2]|0;if((f|0)==0){b=-1;d=-38;return(G=b,d)|0}g=a+20|0;h=hf[f&1023](c[g>>2]|0,0,0,65536)|0;f=G;i=0;if(!((f|0)<(i|0)|(f|0)==(i|0)&h>>>0<0>>>0)){b=f;d=h;return(G=b,d)|0}h=hf[c[e>>2]&1023](c[g>>2]|0,-1,-1,2)|0;f=G;i=0;if((f|0)<(i|0)|(f|0)==(i|0)&h>>>0<0>>>0){b=f;d=h;return(G=b,d)|0}i=wrc(h,f,1,0)|0;f=G;h=a+40|0;hf[c[e>>2]&1023](c[g>>2]|0,c[h>>2]|0,c[h+4>>2]|0,0)|0;b=f;d=i;return(G=b,d)|0}function jD(a){a=a|0;var b=0,d=0;do{if((a|0)==0){b=0}else{d=a+52|0;if((c[d>>2]|0)==0){b=0;break}c[d>>2]=0;gD(a);b=c[d>>2]|0}}while(0);return b|0}function kD(a,b){a=a|0;b=b|0;bD(a,b&255);bD(a,b>>>8&255);bD(a,b>>>16&255);bD(a,b>>>24);return}function lD(a,b){a=a|0;b=b|0;bD(a,b>>>24);bD(a,b>>>16&255);bD(a,b>>>8&255);bD(a,b&255);return}function mD(a,b){a=a|0;b=b|0;var c=0,d=0;if((b|0)==0){bD(a,0);c=1;return c|0}else{d=(lrc(b|0)|0)+1|0;dD(a,b,d);c=d;return c|0}return 0}function nD(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;g=a[e]|0;a:do{if(g<<24>>24==0){h=0;j=0}else{k=b;l=0;m=0;n=e;o=g;while(1){p=m;q=n;r=o;b:while(1){s=q+1|0;t=r&255;u=t>>>1&64;c:do{if((t&192|0)==128|(r&255)>>>0>253>>>0){v=s}else{if((u&t|0)==0){w=t;x=u;y=s;break b}else{z=t;A=u;B=s}while(1){C=B+1|0;D=(d[B]|0)-128|0;if(D>>>0>63>>>0){v=C;break c}E=D+(z<<6)|0;D=A<<5;if((D&E|0)==0){w=E;x=D;y=C;break b}else{z=E;A=D;B=C}}}}while(0);KIb(k,16,2519264,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;s=a[v]|0;if(s<<24>>24==0){h=-22;j=l;break a}else{p=-22;q=v;r=s}}r=(x<<1)-1&w;if(r>>>0<65536>>>0){bD(b,r&255);bD(b,r>>>8&255);F=l+2|0}else{q=r-65536|0;bD(b,q>>>10&255);bD(b,q>>>18&39|216);bD(b,q&255);bD(b,q>>>8&3|220);F=l+4|0}q=a[y]|0;if(q<<24>>24==0){h=p;j=F;break}else{l=F;m=p;n=y;o=q}}}}while(0);bD(b,0);bD(b,0);i=f;return((h|0)==0?j+2|0:h)|0}function oD(a,b){a=a|0;b=b|0;bD(a,b&255);bD(a,b>>8);return}function pD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=1;d=b;b=a;while(1){a=b>>>7|d<<25;e=d>>>7|0<<25;if((a|0)==0&(e|0)==0){break}else{c=c+1|0;d=e;b=a}}return c|0}function qD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=1;e=c;f=b;while(1){g=f>>>7|e<<25;h=e>>>7|0<<25;if((g|0)==0&(h|0)==0){break}else{d=d+1|0;e=h;f=g}}f=d-1|0;if((f|0)>0){i=f}else{j=b;k=j;l=k&127;bD(a,l);return}do{f=zrc(b|0,c|0,i*7|0|0)|0;bD(a,f&127|128);i=i-1|0;}while((i|0)>0);j=b;k=j;l=k&127;bD(a,l);return}function rD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b;bD(a,d&255);bD(a,d>>>8&255);bD(a,d>>>16&255);bD(a,d>>>24);bD(a,c&255);bD(a,(c>>>8|0<<24)&255);bD(a,(c>>>16|0<<16)&255);bD(a,c>>>24|0<<8);return}function sD(a,b,c){a=a|0;b=b|0;c=c|0;bD(a,c>>>24|0<<8);bD(a,(c>>>16|0<<16)&255);bD(a,(c>>>8|0<<24)&255);bD(a,c&255);c=b;bD(a,c>>>24);bD(a,c>>>16&255);bD(a,c>>>8&255);bD(a,c&255);return}function tD(a,b){a=a|0;b=b|0;bD(a,b>>8);bD(a,b&255);return}function uD(a,b){a=a|0;b=b|0;bD(a,b&255);bD(a,b>>>8&255);bD(a,b>>16);return}function vD(a,b){a=a|0;b=b|0;bD(a,b>>16);bD(a,b>>>8&255);bD(a,b&255);return}function wD(a,b,c){a=a|0;b=b|0;c=c|0;return EGb(DGb(3)|0,a,b,c)|0}function xD(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+72|0;d=a+64|0;e=c[a+68>>2]|0;f=Ee[c[b>>2]&511](c[d>>2]|0,e,(c[a+12>>2]|0)-e|0)|0;c[d>>2]=f;c[b>>2]=0;return f|0}function yD(a,b,d){a=a|0;b=b|0;d=d|0;c[a+72>>2]=b;if((b|0)==0){return}c[a+64>>2]=d;c[a+68>>2]=c[a+12>>2];return}function zD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{gD(a);h=c[b>>2]|0;i=c[f>>2]|0}if(!(h>>>0<i>>>0)){j=0;return j|0}c[b>>2]=h+1;j=d[h]|0;return j|0}function AD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=a+16|0;f=a+12|0;g=a+104|0;h=a+8|0;i=a+72|0;j=a+56|0;k=a+24|0;l=a+40|0;m=a+112|0;n=a+4|0;o=a+20|0;p=d;q=b;a:while(1){b=(p|0)>0;if(!b){break}while(1){r=c[f>>2]|0;s=(c[e>>2]|0)-r|0;t=(s|0)>(p|0)?p:s;if((t|0)!=0){if((c[j>>2]|0)==0){u=16;break}}if((c[g>>2]|0)==0){if((p|0)>(c[h>>2]|0)){u=7}}else{u=7}if((u|0)==7){u=0;if((c[i>>2]|0)==0){u=8;break}}gD(a);if((c[e>>2]|0)==(c[f>>2]|0)|b^1){break a}}if((u|0)==8){u=0;b=c[k>>2]|0;if((b|0)==0){v=t}else{v=Ee[b&511](c[o>>2]|0,q,p)|0}if((v|0)<1){u=11;break}b=v;s=(v|0)<0|0?-1:0;w=wrc(c[l>>2]|0,c[l+4>>2]|0,b,s)|0;c[l>>2]=w;c[l+4>>2]=G;w=wrc(c[m>>2]|0,c[m+4>>2]|0,b,s)|0;c[m>>2]=w;c[m+4>>2]=G;w=c[n>>2]|0;c[f>>2]=w;c[e>>2]=w;x=v}else if((u|0)==16){u=0;nrc(q|0,r|0,t)|0;c[f>>2]=(c[f>>2]|0)+t;x=t}p=p-x|0;q=q+x|0}do{if((u|0)==11){c[a+52>>2]=1;if((v|0)>=0){break}c[a+76>>2]=v}}while(0);do{if((p|0)==(d|0)){v=c[a+76>>2]|0;if((v|0)!=0){y=v;return y|0}if((a|0)==0){break}v=a+52|0;if((c[v>>2]|0)==0){break}c[v>>2]=0;gD(a);if((c[v>>2]|0)==0){break}else{y=-541478725}return y|0}}while(0);y=d-p|0;return y|0}function BD(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=a+12|0;g=c[f>>2]|0;do{if(((c[a+16>>2]|0)-g|0)>=(d|0)){if((c[a+56>>2]|0)!=0){break}c[e>>2]=g;c[f>>2]=(c[f>>2]|0)+d;h=d;return h|0}}while(0);c[e>>2]=b;h=AD(a,b,d)|0;return h|0}function CD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)<0){e=-1;return e|0}f=c[a+24>>2]|0;do{if((f|0)!=0){if((c[a+56>>2]|0)==0){break}g=Ee[f&511](c[a+20>>2]|0,b,d)|0;if((g|0)<=0){e=g;return e|0}h=a+40|0;i=wrc(c[h>>2]|0,c[h+4>>2]|0,g,(g|0)<0|0?-1:0)|0;c[h>>2]=i;c[h+4>>2]=G;e=g;return e|0}}while(0);f=a+16|0;g=c[f>>2]|0;h=a+12|0;i=c[h>>2]|0;if((g|0)==(i|0)){j=c[a+4>>2]|0;c[h>>2]=j;c[f>>2]=j;gD(a);j=c[h>>2]|0;k=(c[f>>2]|0)-j|0;l=j}else{k=g-i|0;l=i}i=(k|0)>(d|0)?d:k;nrc(b|0,l|0,i)|0;c[h>>2]=(c[h>>2]|0)+i;do{if((i|0)==0){h=c[a+76>>2]|0;if((h|0)!=0){e=h;return e|0}if((a|0)==0){break}h=a+52|0;if((c[h>>2]|0)==0){break}c[h>>2]=0;gD(a);if((c[h>>2]|0)==0){break}else{e=-541478725}return e|0}}while(0);e=i;return e|0}function DD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{gD(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=d[h]|0;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{gD(a);l=c[b>>2]|0;m=c[f>>2]|0}if(!(l>>>0<m>>>0)){n=0;o=n|j;return o|0}c[b>>2]=l+1;n=(d[l]|0)<<8;o=n|j;return o|0}function ED(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{gD(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=d[h]|0;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{gD(a);l=c[b>>2]|0;m=c[f>>2]|0}if(l>>>0<m>>>0){i=l+1|0;c[b>>2]=i;n=(d[l]|0)<<8;o=i}else{n=0;o=l}l=n|j;if(o>>>0<m>>>0){p=o;q=m}else{gD(a);p=c[b>>2]|0;q=c[f>>2]|0}if(!(p>>>0<q>>>0)){r=0;s=l|r;return s|0}c[b>>2]=p+1;r=(d[p]|0)<<16;s=l|r;return s|0}function FD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{gD(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=d[h]|0;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{gD(a);l=c[b>>2]|0;m=c[f>>2]|0}if(l>>>0<m>>>0){i=l+1|0;c[b>>2]=i;n=(d[l]|0)<<8;o=i}else{n=0;o=l}l=n|j;if(o>>>0<m>>>0){p=o;q=m}else{gD(a);p=c[b>>2]|0;q=c[f>>2]|0}if(p>>>0<q>>>0){m=p+1|0;c[b>>2]=m;r=d[p]|0;s=m}else{r=0;s=p}if(s>>>0<q>>>0){t=s;u=q}else{gD(a);t=c[b>>2]|0;u=c[f>>2]|0}if(!(t>>>0<u>>>0)){v=0;w=v|r;x=w<<16;y=l|x;return y|0}c[b>>2]=t+1;v=(d[t]|0)<<8;w=v|r;x=w<<16;y=l|x;return y|0}function GD(a){a=a|0;var b=0;b=FD(a)|0;return(G=FD(a)|0,b|0)|0}function HD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{gD(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=(d[h]|0)<<8;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{gD(a);l=c[b>>2]|0;m=c[f>>2]|0}if(!(l>>>0<m>>>0)){n=0;o=n|j;return o|0}c[b>>2]=l+1;n=d[l]|0;o=n|j;return o|0}function ID(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{gD(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=(d[h]|0)<<8;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{gD(a);l=c[b>>2]|0;m=c[f>>2]|0}if(l>>>0<m>>>0){i=l+1|0;c[b>>2]=i;n=d[l]|0;o=i}else{n=0;o=l}l=(n|j)<<8;if(o>>>0<m>>>0){p=o;q=m}else{gD(a);p=c[b>>2]|0;q=c[f>>2]|0}if(!(p>>>0<q>>>0)){r=0;s=r|l;return s|0}c[b>>2]=p+1;r=d[p]|0;s=r|l;return s|0}function JD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;if(e>>>0<g>>>0){h=e;i=g}else{gD(a);h=c[b>>2]|0;i=c[f>>2]|0}if(h>>>0<i>>>0){g=h+1|0;c[b>>2]=g;j=(d[h]|0)<<8;k=g}else{j=0;k=h}if(k>>>0<i>>>0){l=k;m=i}else{gD(a);l=c[b>>2]|0;m=c[f>>2]|0}if(l>>>0<m>>>0){i=l+1|0;c[b>>2]=i;n=d[l]|0;o=i}else{n=0;o=l}l=(n|j)<<16;if(o>>>0<m>>>0){p=o;q=m}else{gD(a);p=c[b>>2]|0;q=c[f>>2]|0}if(p>>>0<q>>>0){m=p+1|0;c[b>>2]=m;r=(d[p]|0)<<8;s=m}else{r=0;s=p}if(s>>>0<q>>>0){t=s;u=q}else{gD(a);t=c[b>>2]|0;u=c[f>>2]|0}if(!(t>>>0<u>>>0)){v=0;w=r|l;x=w|v;return x|0}c[b>>2]=t+1;v=d[t]|0;w=r|l;x=w|v;return x|0}function KD(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+12|0;g=b+16|0;h=e-1|0;e=0;while(1){i=c[f>>2]|0;j=c[g>>2]|0;if(i>>>0<j>>>0){k=i;l=j}else{gD(b);k=c[f>>2]|0;l=c[g>>2]|0}if(!(k>>>0<l>>>0)){m=e;break}c[f>>2]=k+1;j=a[k]|0;if(j<<24>>24==0){m=e;break}if((e|0)<(h|0)){a[d+e|0]=j;n=e+1|0}else{n=e}if(j<<24>>24==10){m=n;break}else{e=n}}a[d+m|0]=0;return m|0}function LD(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f|0)<1){g=-22;return g|0}h=f-1|0;f=(h|0)>(d|0)?d:h;h=b+12|0;i=b+16|0;j=0;while(1){if((j|0)>=(f|0)){k=9;break}l=c[h>>2]|0;m=c[i>>2]|0;if(l>>>0<m>>>0){n=l;o=m}else{gD(b);n=c[h>>2]|0;o=c[i>>2]|0}if(!(n>>>0<o>>>0)){k=7;break}c[h>>2]=n+1;m=a[n]|0;a[e+j|0]=m;l=j+1|0;if(m<<24>>24==0){g=l;k=16;break}else{j=l}}if((k|0)==7){a[e+j|0]=0;g=j+1|0;return g|0}else if((k|0)==9){a[e+j|0]=0;e=j;while(1){if((e|0)>=(d|0)){g=d;k=16;break}j=c[h>>2]|0;n=c[i>>2]|0;if(j>>>0<n>>>0){p=j;q=n}else{gD(b);p=c[h>>2]|0;q=c[i>>2]|0}if(!(p>>>0<q>>>0)){k=14;break}c[h>>2]=p+1;n=e+1|0;if((a[p]|0)==0){g=n;k=16;break}else{e=n}}if((k|0)==14){g=e+1|0;return g|0}else if((k|0)==16){return g|0}}else if((k|0)==16){return g|0}return 0}function MD(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((g|0)<1){h=-22;return h|0}i=b+12|0;j=b+16|0;k=f;l=g-1|0;g=f;f=0;a:while(1){m=(g-k|0)<(l|0);n=f;while(1){if((n+1|0)>=(e|0)){o=n;break a}p=n+2|0;if((p|0)>(e|0)){o=p;break a}q=c[i>>2]|0;r=c[j>>2]|0;if(q>>>0<r>>>0){s=q;t=r}else{gD(b);s=c[i>>2]|0;t=c[j>>2]|0}if(s>>>0<t>>>0){r=s+1|0;c[i>>2]=r;u=d[s]|0;v=r}else{u=0;v=s}if(v>>>0<t>>>0){w=v;x=t}else{gD(b);w=c[i>>2]|0;x=c[j>>2]|0}if(w>>>0<x>>>0){r=w+1|0;c[i>>2]=r;y=(d[w]|0)<<8;z=r}else{y=0;z=w}r=y|u;q=r-55296|0;if(q>>>0<2048>>>0){A=n+4|0;if((A|0)>(e|0)){o=A;break a}if(z>>>0<x>>>0){B=z;C=x}else{gD(b);B=c[i>>2]|0;C=c[j>>2]|0}if(B>>>0<C>>>0){D=B+1|0;c[i>>2]=D;E=d[B]|0;F=D}else{E=0;F=B}if(F>>>0<C>>>0){G=F;H=C}else{gD(b);G=c[i>>2]|0;H=c[j>>2]|0}if(G>>>0<H>>>0){c[i>>2]=G+1;I=(d[G]|0)<<8}else{I=0}D=I|E;if(D>>>0>1023>>>0|q>>>0>1023>>>0){o=A;break a}J=A;K=(q<<10)+65536+D|0}else{J=p;K=r}if((K|0)==0){o=J;break a}if(!(K>>>0<128>>>0)){break}if(m){L=29;break}else{n=J}}if((L|0)==29){L=0;a[g]=K;g=g+1|0;f=J;continue}n=K>>>0>65535>>>0;r=n?K>>>16:K;p=n?16:0;if((r&65280|0)==0){M=p;N=r}else{M=p|8;N=r>>>8}r=(M+4+(d[1359664+N|0]|0)|0)/5|0;p=(r*6|0)-6|0;if(m){a[g]=K>>>(p>>>0)|256-(256>>>(r>>>0));O=p;P=g+1|0}else{O=p;P=g}while(1){if((P-k|0)>=(l|0)){Q=O;break}if((O|0)<=5){g=P;f=J;continue a}p=O-6|0;a[P]=K>>>(p>>>0)&63|128;O=p;P=P+1|0}while(1){if((Q|0)<=5){g=P;f=J;continue a}Q=Q-6|0}}a[g]=0;h=o;return h|0}function ND(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;if((g|0)<1){h=-22;return h|0}i=b+12|0;j=b+16|0;k=f;l=g-1|0;g=f;f=0;a:while(1){m=(g-k|0)<(l|0);n=f;while(1){if((n+1|0)>=(e|0)){o=n;break a}p=n+2|0;if((p|0)>(e|0)){o=p;break a}q=c[i>>2]|0;r=c[j>>2]|0;if(q>>>0<r>>>0){s=q;t=r}else{gD(b);s=c[i>>2]|0;t=c[j>>2]|0}if(s>>>0<t>>>0){r=s+1|0;c[i>>2]=r;u=(d[s]|0)<<8;v=r}else{u=0;v=s}if(v>>>0<t>>>0){w=v;x=t}else{gD(b);w=c[i>>2]|0;x=c[j>>2]|0}if(w>>>0<x>>>0){r=w+1|0;c[i>>2]=r;y=d[w]|0;z=r}else{y=0;z=w}r=y|u;q=r-55296|0;if(q>>>0<2048>>>0){A=n+4|0;if((A|0)>(e|0)){o=A;break a}if(z>>>0<x>>>0){B=z;C=x}else{gD(b);B=c[i>>2]|0;C=c[j>>2]|0}if(B>>>0<C>>>0){D=B+1|0;c[i>>2]=D;E=(d[B]|0)<<8;F=D}else{E=0;F=B}if(F>>>0<C>>>0){G=F;H=C}else{gD(b);G=c[i>>2]|0;H=c[j>>2]|0}if(G>>>0<H>>>0){c[i>>2]=G+1;I=d[G]|0}else{I=0}D=I|E;if(D>>>0>1023>>>0|q>>>0>1023>>>0){o=A;break a}J=A;K=(q<<10)+65536+D|0}else{J=p;K=r}if((K|0)==0){o=J;break a}if(!(K>>>0<128>>>0)){break}if(m){L=29;break}else{n=J}}if((L|0)==29){L=0;a[g]=K;g=g+1|0;f=J;continue}n=K>>>0>65535>>>0;r=n?K>>>16:K;p=n?16:0;if((r&65280|0)==0){M=p;N=r}else{M=p|8;N=r>>>8}r=(M+4+(d[1359664+N|0]|0)|0)/5|0;p=(r*6|0)-6|0;if(m){a[g]=K>>>(p>>>0)|256-(256>>>(r>>>0));O=p;P=g+1|0}else{O=p;P=g}while(1){p=(P-k|0)<(l|0);r=O;while(1){if((r|0)<=5){g=P;f=J;continue a}r=r-6|0;if(p){break}}a[P]=K>>>(r>>>0)&63|128;O=r;P=P+1|0}}a[g]=0;h=o;return h|0}function OD(a){a=a|0;var b=0,c=0;b=JD(a)|0;c=JD(a)|0;return(G=b|0,c)|0}function PD(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a+12|0;e=a+16|0;f=0;g=0;h=c[b>>2]|0;i=c[e>>2]|0;while(1){if(h>>>0<i>>>0){j=h;k=i}else{gD(a);j=c[b>>2]|0;k=c[e>>2]|0}if(!(j>>>0<k>>>0)){break}l=j+1|0;c[b>>2]=l;m=d[j]|0;n=m&127|(g<<7|0>>>25);o=f<<7|g>>>25|0;if((m&128|0)==0){p=o;q=n;r=7;break}else{f=o;g=n;h=l;i=k}}if((r|0)==7){return(G=p,q)|0}p=f<<7|g>>>25;q=g<<7|0>>>25;return(G=p,q)|0}function QD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[b+20>>2]|0;e=(d|0)==0?32768:d;f=hJb(e)|0;if((f|0)==0){g=-12;return g|0}h=b+16|0;i=c[h>>2]|0;j=pJb(128)|0;if((j|0)==0){c[a>>2]=0;kJb(f);g=-12;return g|0}c[j+4>>2]=f;c[j+8>>2]=e;c[j+12>>2]=f;c[j+20>>2]=b;k=j+104|0;c[k>>2]=0;if((i&2|0)==0){c[j+16>>2]=f;c[j+56>>2]=0}else{c[j+16>>2]=f+e;c[j+56>>2]=1}c[j+28>>2]=210;c[j+24>>2]=442;c[j+32>>2]=676;c[j+76>>2]=0;mrc(j+40|0,0,16)|0;c[j+72>>2]=0;c[j+80>>2]=0;c[j+84>>2]=0;c[a>>2]=j;c[k>>2]=c[h>>2]&32768;c[j+88>>2]=(c[b+24>>2]|0)==0;c[j+60>>2]=d;d=c[b+4>>2]|0;if((d|0)!=0){c[j+80>>2]=c[d+32>>2];c[j+84>>2]=c[d+36>>2]}c[j>>2]=1241280;g=0;return g|0}function RD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a+60>>2]|0;f=a+12|0;g=a+4|0;h=(c[f>>2]|0)+b+((e|0)==0?32768:e)-(c[g>>2]|0)|0;e=a+8|0;if((h|0)<(c[e>>2]|0)){j=0;i=d;return j|0}if((c[a+88>>2]|0)!=0){j=0;i=d;return j|0}if((c[a+56>>2]|0)!=0){KIb(0,0,2404808,(b=i,i=i+24|0,c[b>>2]=2329592,c[b+8>>2]=2273528,c[b+16>>2]=770,b)|0);i=b;Hd();return 0}b=hJb(h)|0;if((b|0)==0){j=-12;i=d;return j|0}k=c[g>>2]|0;nrc(b|0,k|0,c[e>>2]|0)|0;kJb(k);k=c[g>>2]|0;c[f>>2]=b+((c[f>>2]|0)-k);f=a+16|0;c[f>>2]=b+((c[f>>2]|0)-k);c[g>>2]=b;c[e>>2]=h;j=0;i=d;return j|0}function SD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=hJb(b)|0;if((d|0)==0){e=-12;return e|0}f=a+4|0;kJb(c[f>>2]|0);c[f>>2]=d;c[a+8>>2]=b;c[a+12>>2]=d;f=a+56|0;if((c[f>>2]|0)==0){c[a+16>>2]=d;c[f>>2]=0;e=0;return e|0}else{c[a+16>>2]=d+b;c[f>>2]=1;e=0;return e|0}return 0}function TD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[b>>2]|0;if((c[a+56>>2]|0)!=0){mJb(b);f=-22;return f|0}g=a+16|0;h=a+4|0;i=(c[g>>2]|0)-(c[h>>2]|0)|0;j=a+40|0;k=xrc(c[j>>2]|0,c[j+4>>2]|0,i,(i|0)<0|0?-1:0)|0;l=G;m=d;n=(d|0)<0|0?-1:0;if((l|0)>(n|0)|(l|0)==(n|0)&k>>>0>m>>>0){mJb(b);f=-22;return f|0}o=xrc(m,n,k,l)|0;l=o;o=i+d-l|0;k=a+8|0;n=c[k>>2]|0;m=(n|0)>(o|0)?n:o;do{if((m|0)>(d|0)){n=jJb(e,1,m)|0;c[b>>2]=n;if((n|0)==0){f=-12}else{p=n;break}return f|0}else{p=e}}while(0);if((o|0)>(d|0)){nrc(p+d|0,(c[h>>2]|0)+l|0,i-l|0)|0;q=o}else{q=d}kJb(c[h>>2]|0);c[h>>2]=p;c[a+12>>2]=p;c[k>>2]=m;c[j>>2]=q;c[j+4>>2]=(q|0)<0|0?-1:0;c[g>>2]=p+q;c[a+52>>2]=0;c[a+48>>2]=0;f=0;return f|0}function UD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=RC(f,b,d,0,0)|0;do{if((g|0)<0){h=g}else{d=QD(a,c[f>>2]|0)|0;if((d|0)>=0){h=0;break}SC(c[f>>2]|0)|0;h=d}}while(0);i=e;return h|0}function VD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+8|0;h=g|0;j=RC(h,b,d,e,f)|0;do{if((j|0)<0){k=j}else{f=QD(a,c[h>>2]|0)|0;if((f|0)>=0){k=0;break}SC(c[h>>2]|0)|0;k=f}}while(0);i=g;return k|0}function WD(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;if((a|0)==0){d=0;i=b;return d|0}e=a+12|0;f=c[e>>2]|0;g=a+4|0;h=c[g>>2]|0;do{if(f>>>0>h>>>0){j=f-h|0;k=c[a+28>>2]|0;do{if((k|0)!=0){l=a+76|0;if((c[l>>2]|0)!=0){break}m=Ee[k&511](c[a+20>>2]|0,h,j)|0;if((m|0)>=0){break}c[l>>2]=m}}while(0);k=a+124|0;c[k>>2]=(c[k>>2]|0)+1;k=a+40|0;m=wrc(c[k>>2]|0,c[k+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[k>>2]=m;c[k+4>>2]=G;k=c[a+72>>2]|0;if((k|0)==0){n=c[g>>2]|0;break}else{m=a+64|0;l=a+68|0;o=c[l>>2]|0;c[m>>2]=Ee[k&511](c[m>>2]|0,o,(c[e>>2]|0)-o|0)|0;o=c[g>>2]|0;c[l>>2]=o;n=o;break}}else{n=h}}while(0);c[e>>2]=n;c[a+48>>2]=0;n=c[a+20>>2]|0;mJb(g);g=a;if((c[a+56>>2]|0)==0){e=a+112|0;h=c[e+4>>2]|0;f=c[a+120>>2]|0;KIb(g,48,2188336,(p=i,i=i+24|0,c[p>>2]=c[e>>2],c[p+8>>2]=h,c[p+16>>2]=f,p)|0);i=p}else{f=c[a+124>>2]|0;KIb(g,48,2223808,(p=i,i=i+16|0,c[p>>2]=c[a+120>>2],c[p+8>>2]=f,p)|0);i=p}kJb(g);d=SC(n)|0;i=b;return d|0}function XD(a){a=a|0;var b=0;b=WD(c[a>>2]|0)|0;c[a>>2]=0;return b|0}function YD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+4112|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=e+16|0;d=Ad(g|0,4096,b|0,f|0)|0;dD(a,g,lrc(g|0)|0);i=e;return d|0}function ZD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=c[a+84>>2]|0;if((g|0)==0){h=-1;i=-38;return(G=h,i)|0}j=c[a+20>>2]|0;k=Xe[g&511](j,b,d,e,f)|0;f=G;e=-1;if(!((f|0)>(e|0)|(f|0)==(e|0)&k>>>0>-1>>>0)){h=f;i=k;return(G=h,i)|0}c[a+12>>2]=c[a+16>>2];e=hf[c[a+32>>2]&1023](j,0,0,1)|0;j=G;d=-1;if(!((j|0)>(d|0)|(j|0)==(d|0)&e>>>0>-1>>>0)){d=(e|0)==(-38|0)&(j|0)==(-1|0);return(G=d?f:j,d?k:e)|0}d=a+40|0;c[d>>2]=e;c[d+4>>2]=j;h=f;i=k;return(G=h,i)|0}function _D(a){a=a|0;var b=0,d=0,e=0,f=0;b=pJb(1048)|0;if((b|0)==0){d=-12;return d|0}c[b+16>>2]=1024;e=b+20|0;f=pJb(128)|0;if((f|0)==0){c[a>>2]=0;kJb(b);d=-12;return d|0}else{c[f+4>>2]=e;c[f+8>>2]=1024;c[f+12>>2]=e;c[f+20>>2]=b;c[f+104>>2]=0;c[f+16>>2]=b+1044;c[f+56>>2]=1;c[f+28>>2]=50;c[f+24>>2]=0;c[f+32>>2]=764;c[f+76>>2]=0;mrc(f+40|0,0,16)|0;c[f+88>>2]=1;c[f+72>>2]=0;c[f+80>>2]=0;c[f+84>>2]=0;c[a>>2]=f;c[f+60>>2]=0;d=0;return d|0}return 0}function $D(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((b|0)<1){d=-1;return d|0}e=qc(b|0,24)|0;if(G){d=-1;return d|0}f=pJb(e)|0;if((f|0)==0){d=-12;return d|0}c[f+16>>2]=b;e=f+20|0;g=pJb(128)|0;if((g|0)==0){c[a>>2]=0;kJb(f);d=-12;return d|0}else{c[g+4>>2]=e;c[g+8>>2]=b;c[g+12>>2]=e;c[g+20>>2]=f;c[g+104>>2]=0;c[g+16>>2]=f+(b+20);c[g+56>>2]=1;c[g+28>>2]=342;c[g+24>>2]=0;c[g+32>>2]=0;mrc(g+40|0,0,16)|0;mrc(g+72|0,0,20)|0;c[a>>2]=g;c[g+60>>2]=b;d=0;return d|0}return 0}function aE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a|0)==0){c[b>>2]=0;d=0;return d|0}e=a+20|0;f=c[e>>2]|0;if((c[a+60>>2]|0)==0){dD(a,9907024,16);g=16}else{g=0}h=a+12|0;i=c[h>>2]|0;j=a+4|0;k=c[j>>2]|0;do{if(i>>>0>k>>>0){l=i-k|0;m=c[a+28>>2]|0;do{if((m|0)!=0){n=a+76|0;if((c[n>>2]|0)!=0){break}o=Ee[m&511](c[e>>2]|0,k,l)|0;if((o|0)>=0){break}c[n>>2]=o}}while(0);m=a+124|0;c[m>>2]=(c[m>>2]|0)+1;m=a+40|0;o=wrc(c[m>>2]|0,c[m+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[m>>2]=o;c[m+4>>2]=G;m=c[a+72>>2]|0;if((m|0)==0){p=c[j>>2]|0;break}else{o=a+64|0;n=a+68|0;q=c[n>>2]|0;c[o>>2]=Ee[m&511](c[o>>2]|0,q,(c[h>>2]|0)-q|0)|0;q=c[j>>2]|0;c[n>>2]=q;p=q;break}}else{p=k}}while(0);c[h>>2]=p;c[a+48>>2]=0;c[b>>2]=c[f+12>>2];b=c[f+4>>2]|0;kJb(f);kJb(a);d=b-g|0;return d|0}function bE(a){a=a|0;var b=0,d=0,e=0,f=0;b=pJb(1048)|0;if((b|0)==0){d=-12;return d|0}c[b+16>>2]=1024;e=b+20|0;f=pJb(128)|0;if((f|0)==0){c[a>>2]=0;kJb(b);d=-12;return d|0}else{c[f+4>>2]=e;c[f+8>>2]=1024;c[f+12>>2]=e;c[f+20>>2]=b;c[f+104>>2]=0;c[f+16>>2]=b+1044;c[f+56>>2]=1;c[f+24>>2]=0;c[f+32>>2]=764;c[f+76>>2]=0;mrc(f+40|0,0,16)|0;c[f+88>>2]=1;c[f+72>>2]=0;c[f+80>>2]=0;c[f+84>>2]=0;c[a>>2]=f;c[f+60>>2]=0;c[f+28>>2]=232;d=0;return d|0}return 0}function cE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=(c[b>>2]|0)+d|0;c[b>>2]=e;b=a+4|0;if((e|0)<=(c[b>>2]|0)){return d|0}c[b>>2]=e;return d|0}function dE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+20>>2]|0;d=a+12|0;e=c[d>>2]|0;f=a+4|0;g=c[f>>2]|0;do{if(e>>>0>g>>>0){h=e-g|0;i=c[a+28>>2]|0;do{if((i|0)!=0){j=a+76|0;if((c[j>>2]|0)!=0){break}k=Ee[i&511](b,g,h)|0;if((k|0)>=0){break}c[j>>2]=k}}while(0);i=a+124|0;c[i>>2]=(c[i>>2]|0)+1;i=a+40|0;k=wrc(c[i>>2]|0,c[i+4>>2]|0,h,(h|0)<0|0?-1:0)|0;c[i>>2]=k;c[i+4>>2]=G;i=c[a+72>>2]|0;if((i|0)==0){l=c[f>>2]|0;break}else{k=a+64|0;j=a+68|0;m=c[j>>2]|0;c[k>>2]=Ee[i&511](c[k>>2]|0,m,(c[d>>2]|0)-m|0)|0;m=c[f>>2]|0;c[j>>2]=m;l=m;break}}else{l=g}}while(0);c[d>>2]=l;c[a+48>>2]=0;l=c[b+4>>2]|0;kJb(b);kJb(a);return l|0}function eE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=je(e|0)|0;g=b;h=c[g>>2]|0;i=qc(h|0,4)|0;j=i;i=b+8|0;k=c[i>>2]|0;if(G|j>>>0>1073741823>>>0){l=-1;return l|0}do{if(j>>>0>k>>>0){m=k;while(1){if((m|0)==0){n=j}else{n=m+1+(m>>>1)|0}if(j>>>0>n>>>0){m=n}else{break}}if(!(n>>>0>k>>>0)){o=7;break}m=b+12|0;p=lJb(m,n)|0;if((p|0)>=0){c[i>>2]=n;q=c[g>>2]|0;r=m;break}c[i>>2]=0;c[b+4>>2]=0;l=p;return l|0}else{o=7}}while(0);if((o|0)==7){q=h;r=b+12|0}h=(c[r>>2]|0)+q|0;y=f;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[g>>2]=j;h=b+4|0;if((j|0)>(c[h>>2]|0)){c[h>>2]=j}f=qc(j|0,e|0)|0;q=f;f=c[i>>2]|0;if(G|q>>>0>1073741823>>>0){l=-1;return l|0}do{if(q>>>0>f>>>0){r=f;while(1){if((r|0)==0){s=q}else{s=r+1+(r>>>1)|0}if(q>>>0>s>>>0){r=s}else{break}}if(!(s>>>0>f>>>0)){o=19;break}r=b+12|0;n=lJb(r,s)|0;if((n|0)>=0){c[i>>2]=s;t=c[g>>2]|0;u=r;break}c[i>>2]=0;c[h>>2]=0;l=n;return l|0}else{o=19}}while(0);if((o|0)==19){t=j;u=b+12|0}nrc((c[u>>2]|0)+t|0,d|0,e)|0;c[g>>2]=q;if((q|0)<=(c[h>>2]|0)){l=e;return l|0}c[h>>2]=q;l=e;return l|0}function fE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=a;f=c[e>>2]|0;g=qc(f|0,d|0)|0;h=g;g=a+8|0;i=c[g>>2]|0;if(G|h>>>0>1073741823>>>0){j=-1;return j|0}do{if(h>>>0>i>>>0){k=i;while(1){if((k|0)==0){l=h}else{l=k+1+(k>>>1)|0}if(h>>>0>l>>>0){k=l}else{break}}if(!(l>>>0>i>>>0)){m=7;break}k=a+12|0;n=lJb(k,l)|0;if((n|0)>=0){c[g>>2]=l;o=c[e>>2]|0;p=k;break}c[g>>2]=0;c[a+4>>2]=0;j=n;return j|0}else{m=7}}while(0);if((m|0)==7){o=f;p=a+12|0}nrc((c[p>>2]|0)+o|0,b|0,d)|0;c[e>>2]=h;e=a+4|0;if((h|0)<=(c[e>>2]|0)){j=d;return j|0}c[e>>2]=h;j=d;return j|0}function gE(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==2){f=c[a+4>>2]|0;g=wrc(f,(f|0)<0|0?-1:0,b,d)|0;h=G;i=g}else if((e|0)==1){e=c[a>>2]|0;g=wrc(e,(e|0)<0|0?-1:0,b,d)|0;h=G;i=g}else{h=d;i=b}b=0;if(h>>>0>b>>>0|h>>>0==b>>>0&i>>>0>2147483647>>>0){j=-1;k=-1;return(G=j,k)|0}c[a>>2]=i;j=0;k=0;return(G=j,k)|0}function hE(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(c>>>0>2>>>0){d=0;return d|0}else{f=0}do{g=Bc(a|0,1013016+((e[1013e3+(f<<1)>>1]|0)*6|0)|0,e[1013008+(f<<1)>>1]|0|0,6,354)|0;h=g;f=f+1|0;i=(g|0)!=0;}while((f|0)<3&(i^1));if(!i){d=0;return d|0}i=b[1013e3+(c<<1)>>1]|0;f=i&65535;j=1013008+(c<<1)|0;if(h>>>0<(1013016+(f*6|0)|0)>>>0){k=7}else{if(h>>>0<(1013016+(((e[j>>1]|0)+f|0)*6|0)|0)>>>0){l=h}else{k=7}}do{if((k|0)==7){h=b[g+4>>1]|0;m=h&65535;if(!((h&65535)>>>0<(i&65535)>>>0)){if((m|0)<((e[j>>1]|0)+f|0)){l=1013016+(m*6|0)|0;break}}h=b[1013020+(m*6|0)>>1]|0;m=h&65535;if(!((h&65535)>>>0<(i&65535)>>>0)){if((m|0)<((e[j>>1]|0)+f|0)){l=1013016+(m*6|0)|0;break}}if((c|0)==1){n=0}else{d=0;return d|0}do{o=Bc(a|0,1013016+((e[1013e3+(n<<1)>>1]|0)*6|0)|0,e[1013008+(n<<1)>>1]|0|0,6,354)|0;p=o;n=n+1|0;q=(o|0)!=0;}while((n|0)<3&(q^1));if(!q){d=0;return d|0}do{if(o>>>0>=1013016>>>0&o>>>0<1015920>>>0){r=p}else{m=b[o+4>>1]|0;h=m&65535;if((m&65535)>>>0<484>>>0){r=1013016+(h*6|0)|0;break}m=b[1013020+(h*6|0)>>1]|0;if((m&65535)>>>0<484>>>0){r=1013016+((m&65535)*6|0)|0;break}else{d=0}return d|0}}while(0);d=r|0;return d|0}}while(0);d=l|0;return d|0}function iE(a,b){a=a|0;b=b|0;return irc(a,b)|0}function jE(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1414087218){e=0;return e|0}a=b+12|0;f=(d[a]|d[a+1|0]<<8)<<16>>16;if(f<<16>>16==0|((he(f|0)|0)&65535)>>>0>256>>>0){e=25;return e|0}f=b+14|0;b=((he((d[f]|d[f+1|0]<<8)<<16>>16|0)|0)&65535)>>>0>256>>>0;e=b?25:50;return e|0}function kE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=ZX(a,0)|0;if((d|0)==0){e=-12;i=b;return e|0}f=d+8|0;c[(c[f>>2]|0)+8>>2]=1;g=a+16|0;hD(c[g>>2]|0,4,0)|0;hD(c[g>>2]|0,8,0)|0;h=HD(c[g>>2]|0)|0;do{if((h&65535)<<16>>16==0){c[(c[f>>2]|0)+416>>2]=1}else{j=h&65535;if((j|0)==65535){c[(c[f>>2]|0)+416>>2]=2;break}QIb(a,2404728,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;e=-1163346256;i=b;return e|0}}while(0);h=(HD(c[g>>2]|0)|0)&65535;c[(c[f>>2]|0)+792>>2]=h;j=HD(c[g>>2]|0)|0;hD(c[g>>2]|0,2,0)|0;hD(c[g>>2]|0,2,0)|0;hD(c[g>>2]|0,1,0)|0;l=ID(c[g>>2]|0)|0;c[(c[f>>2]|0)+412>>2]=l;hD(c[g>>2]|0,12,0)|0;hD(c[g>>2]|0,6,0)|0;hD(c[g>>2]|0,20,0)|0;hD(c[g>>2]|0,64,0)|0;g=j&65535;j=KX(h,0,1,g)|0;l=c[f>>2]|0;c[l+48>>2]=j;if((j|0)==0){QIb(a,2329336,(k=i,i=i+16|0,c[k>>2]=h,c[k+8>>2]=g,k)|0);i=k;e=-1163346256;i=b;return e|0}else{c[l+432>>2]=(ca(c[l+416>>2]|0,h)|0)/8|0;_X(d,64,1,c[l+412>>2]|0);e=0;i=b;return e|0}return 0}function lE(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==119){if((a[d+1|0]|0)!=87){break}if((a[d+2|0]|0)!=16){break}if((a[d+3|0]|0)==0){e=55}else{break}return e|0}}while(0);e=0;return e|0}function mE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+12>>2]|0;e=a+20|0;c[e>>2]=c[e>>2]|1;e=a+16|0;hD(c[e>>2]|0,4,0)|0;f=d+16|0;c[f>>2]=DD(c[e>>2]|0)|0;g=d+20|0;c[g>>2]=DD(c[e>>2]|0)|0;c[d+24>>2]=DD(c[e>>2]|0)|0;c[d+28>>2]=DD(c[e>>2]|0)|0;c[d+32>>2]=FD(c[e>>2]|0)|0;c[d+36>>2]=0;c[d+40>>2]=0;c[d+12>>2]=0;c[d+8>>2]=0;d=c[f>>2]|0;f=c[g>>2]|0;if((d|0)==318&(f|0)==198){i=b;return 0}KIb(a,16,2404536,(a=i,i=i+16|0,c[a>>2]=d,c[a+8>>2]=f,a)|0);i=a;i=b;return 0}function nE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+776|0;f=e|0;g=b+12|0;h=c[g>>2]|0;j=h+40|0;k=b+16|0;do{if((c[j>>2]|0)>0){l=fD(c[k>>2]|0,0,0,1)|0;m=G;n=h+12|0;o=MY(b,d,c[n>>2]|0,c[j>>2]|0)|0;p=fD(c[k>>2]|0,0,0,1)|0;q=xrc(p,G,l,m)|0;m=q;c[j>>2]=(c[j>>2]|0)-m;if((o|0)<0){r=n;break}c[d+32>>2]=c[c[n>>2]>>2];o=d+36|0;c[o>>2]=c[o>>2]|1;if((m|0)>0){s=0}else{r=n;break}i=e;return s|0}else{r=h+12|0}}while(0);n=h+36|0;m=f|0;f=d+32|0;o=d+36|0;q=0;l=c[n>>2]|0;a:while(1){if((l|0)<1){if((DD(c[k>>2]|0)|0)==0){s=-5;t=31;break}p=(DD(c[k>>2]|0)|0)-4|0;c[n>>2]=p;if((p|0)>0){u=q}else{q=q;l=p;continue}}else{u=q}while(1){v=zD(c[k>>2]|0)|0;p=zD(c[k>>2]|0)|0;w=DD(c[k>>2]|0)|0;if((w|0)<4){s=-1094995529;t=31;break a}c[n>>2]=(c[n>>2]|0)-w;do{if((p|0)==2){if((c[r>>2]|0)==0){x=ZX(b,0)|0;c[r>>2]=x;if((x|0)==0){s=-12;t=31;break a}c[(c[x+8>>2]|0)+8>>2]=1}c[j>>2]=w-4;x=c[g>>2]|0;y=fD(c[k>>2]|0,0,0,1)|0;z=G;A=x+12|0;B=x+40|0;x=MY(b,d,c[A>>2]|0,c[B>>2]|0)|0;C=fD(c[k>>2]|0,0,0,1)|0;D=xrc(C,G,y,z)|0;z=D;c[B>>2]=(c[B>>2]|0)-z;if((x|0)==-5){E=u;break}if((x|0)<0){s=x;t=31;break a}c[f>>2]=c[c[A>>2]>>2];c[o>>2]=c[o>>2]|1;if((z|0)==0){E=u}else{s=z;t=31;break a}}else if((p|0)==1){t=14;break a}else if((p|0)==3){z=w-4|0;if(z>>>0>772>>>0){s=-1094995529;t=31;break a}if((AD(c[k>>2]|0,m,z)|0)<(z|0)){s=-5;t=31;break a}else{E=w}}else{z=w-4|0;hD(c[k>>2]|0,z,(z|0)<0|0?-1:0)|0;E=u}}while(0);p=c[n>>2]|0;if((p|0)>0){u=E}else{q=E;l=p;continue a}}}if((t|0)==14){l=h+8|0;do{if((c[l>>2]|0)==0){E=ZX(b,0)|0;c[l>>2]=E;if((E|0)==0){s=-12;i=e;return s|0}else{q=c[E+8>>2]|0;c[q+8>>2]=0;c[q+48>>2]=83;c[q+120>>2]=c[h+16>>2];c[q+124>>2]=c[h+20>>2];c[q+792>>2]=c[h+24>>2];q=c[h+32>>2]|0;n=E+64|0;c[n>>2]=q;c[n+4>>2]=(q|0)<0|0?-1:0;c[E+92>>2]=c[h+28>>2];c[E+96>>2]=1;q=E+92|0;n=E+412|0;E=c[q+4>>2]|0;c[n>>2]=c[q>>2];c[n+4>>2]=E;break}}}while(0);h=c[g>>2]|0;g=K1(d,w+u|0)|0;if((g|0)<0){s=g;i=e;return s|0}g=d+24|0;if((u|0)!=0){a[c[g>>2]|0]=0;a[(c[g>>2]|0)+1|0]=3;a[(c[g>>2]|0)+2|0]=u;a[(c[g>>2]|0)+3|0]=u>>>8;nrc((c[g>>2]|0)+4|0,m|0,u-4|0)|0}a[(c[g>>2]|0)+u|0]=v;a[(c[g>>2]|0)+(u+1)|0]=1;a[(c[g>>2]|0)+(u+2)|0]=w;a[(c[g>>2]|0)+(u+3)|0]=w>>>8;m=(AD(c[k>>2]|0,(c[g>>2]|0)+(u+4)|0,w-4|0)|0)+4|0;if((m|0)<(w|0)){P1(d);s=-5;i=e;return s|0}c[d+28>>2]=m+u;c[f>>2]=c[c[h+8>>2]>>2];if((v|0)!=0){s=0;i=e;return s|0}c[o>>2]=c[o>>2]|1;s=0;i=e;return s|0}else if((t|0)==31){i=e;return s|0}return 0}function oE(a){a=a|0;return 0}function pE(b){b=b|0;var e=0,f=0;e=c[b+4>>2]|0;b=e;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)!=4475222){f=0;return f|0}f=(a[e+4|0]|0)==2?100:25;return f|0}function qE(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;hD(d,5,0)|0;c[b>>2]=DD(d)|0;c[b+8>>2]=DD(d)|0;c[b+12>>2]=DD(d)|0;c[b+16>>2]=DD(d)|0;DD(d)|0;c[b+20>>2]=-1;c[b+24>>2]=-1;c[b+4>>2]=11111;b=a+20|0;c[b>>2]=c[b>>2]|1;return 0}function rE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+8|0;f=e|0;g=c[b+12>>2]|0;h=c[b+16>>2]|0;j=g+32|0;if((c[j>>2]|0)!=0){k=-541478725;i=e;return k|0}if((jD(h)|0)!=0){k=-541478725;i=e;return k|0}l=zD(h)|0;m=l&255;n=l&255;switch(n|0){case 1:case 4:case 3:{l=g+20|0;o=c[l>>2]|0;if((o|0)<0){p=ZX(b,0)|0;if((p|0)==0){k=-12;i=e;return k|0}c[l>>2]=c[p>>2];if((c[g+24>>2]|0)<0){QIb(b,2188176,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}_X(p,64,185,c[g+4>>2]|0);r=c[p+8>>2]|0;c[r+8>>2]=0;c[r+48>>2]=104;c[r+120>>2]=c[g+8>>2];c[r+124>>2]=c[g+12>>2];s=c[l>>2]|0}else{s=o}o=c[(c[(c[b+28>>2]|0)+(s<<2)>>2]|0)+8>>2]|0;s=ca(c[o+124>>2]|0,c[o+120>>2]|0)|0;c[f>>2]=1e3;o=hJb(1e3)|0;if((o|0)==0){k=-12;i=e;return k|0}r=fD(h,0,0,1)|0;a[o]=m;p=(c[g+16>>2]|0)+(DD(h)|0)|0;a:do{if((m<<24>>24|0)==4){if((AD(h,o+1|0,2)|0)==2){t=o;u=3;v=0;w=35}else{x=-5;y=o}}else if((m<<24>>24|0)==3){z=o;A=1;B=0;while(1){C=wJb(z,f,A+1e3|0)|0;if((C|0)==0){k=-12;break}D=zD(h)|0;E=A+1|0;a[C+A|0]=D;do{if((D|0)>127){a[C+E|0]=zD(h)|0;F=A+2|0}else{if((D|0)==0){F=E;break}if((AD(h,C+E|0,D)|0)!=(D|0)){x=-5;y=C;break a}F=D+E|0}}while(0);E=(D&127)+B|0;if((E|0)==(s|0)){H=C;I=F;J=1;w=40;break a}if((E|0)>(s|0)){x=-1094995529;y=C;break a}if((D|0)==0){K=C;L=F;M=1;w=44;break a}else{z=C;A=F;B=E}}i=e;return k|0}else{t=o;u=1;v=0;w=35}}while(0);b:do{if((w|0)==35){while(1){w=0;o=wJb(t,f,u+1e3|0)|0;if((o|0)==0){k=-12;break}F=zD(h)|0;m=u+1|0;a[o+u|0]=F;B=(F|0)==0;if((F|0)>127|B){N=m}else{if((AD(h,o+m|0,F)|0)!=(F|0)){x=-5;y=o;break b}N=F+m|0}m=(F&127)+v|0;if((m|0)==(s|0)){H=o;I=N;J=0;w=40;break b}if((m|0)>(s|0)){x=-1094995529;y=o;break b}if(B){K=o;L=N;M=0;w=44;break b}else{t=o;u=N;v=m;w=35}}i=e;return k|0}}while(0);do{if((w|0)==40){if((zD(h)|0)==0){K=H;L=I;M=J;w=44;break}fD(h,-1,-1,1)|0;K=H;L=I;M=J;w=44}}while(0);do{if((w|0)==44){J=K1(d,L)|0;if((J|0)<0){x=J;y=K;break}nrc(c[d+24>>2]|0,K|0,L)|0;kJb(K);wrc(0,r,0,-1)|0;J=G;I=d+64|0;c[I>>2]=J;c[I+4>>2]=(J|0)<0|0?-1:0;c[d+32>>2]=c[l>>2];c[d+48>>2]=p;if(M){J=d+36|0;c[J>>2]=c[J>>2]|1}J=g+28|0;I=J;if((c[I>>2]|0)!=0){H=U1(d,0,768)|0;if((H|0)!=0){nrc(H|0,c[I>>2]|0,768)|0}mJb(J)}J=g;c[J>>2]=(c[J>>2]|0)-1;k=0;i=e;return k|0}}while(0);kJb(y);k=x;i=e;return k|0};case 124:{DD(h)|0;c[g+4>>2]=1e6/(256-(zD(h)|0)|0)|0;break};case 2:{x=g+28|0;y=x;if((c[y>>2]|0)!=0){KIb(b,24,2404360,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;mJb(x)}M=hJb(768)|0;c[y>>2]=M;if((M|0)==0){k=-12;i=e;return k|0}if((AD(h,M,768)|0)==768){k=rE(b,d)|0;i=e;return k|0}else{mJb(x);k=-5;i=e;return k|0}break};case 125:{break};case 20:{if((c[g>>2]|0)!=0){KIb(b,40,2273240,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}c[j>>2]=1;k=-5;i=e;return k|0};default:{KIb(b,16,2223608,(q=i,i=i+24|0,c[q>>2]=n,c[q+8>>2]=n,c[q+16>>2]=n,q)|0);i=q;k=-1094995529;i=e;return k|0}}n=g+24|0;do{if((c[n>>2]|0)<0){j=ZX(b,0)|0;if((j|0)==0){k=-12;i=e;return k|0}else{c[n>>2]=c[j>>2];x=c[j+8>>2]|0;c[x+8>>2]=1;c[x+48>>2]=65541;c[x+416>>2]=1;M=x+448|0;c[M>>2]=4;c[M+4>>2]=0;c[x+792>>2]=8;M=g+4|0;y=c[M>>2]|0;c[x+412>>2]=y;c[x+72>>2]=y<<3;y=j+48|0;c[y>>2]=0;c[y+4>>2]=0;_X(j,64,1,c[M>>2]|0);break}}}while(0);g=DD(h)|0;M=fX(h,d,g)|0;if((M|0)==(g|0)){c[d+32>>2]=c[n>>2];c[d+48>>2]=g;g=d+36|0;c[g>>2]=c[g>>2]|1;k=0;i=e;return k|0}if((M|0)<0){k=M;i=e;return k|0}KIb(b,16,2329088,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;k=-5;i=e;return k|0}function sE(a){a=a|0;mJb((c[a+12>>2]|0)+28|0);return 0}function tE(a){a=a|0;var b=0;b=c[a+4>>2]|0;return((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==1227245122?100:0)|0}function uE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=ZX(a,0)|0;if((e|0)==0){f=-12;return f|0}g=ZX(a,0)|0;if((g|0)==0){f=-12;return f|0}hD(d,8,0)|0;a=FD(d)|0;h=b;c[h>>2]=FD(d)|0;FD(d)|0;FD(d)|0;FD(d)|0;b=FD(d)|0;hD(d,12,0)|0;i=FD(d)|0;j=e+8|0;c[(c[j>>2]|0)+120>>2]=i;i=FD(d)|0;c[(c[j>>2]|0)+124>>2]=i;hD(d,8,0)|0;i=hJb(768)|0;c[(c[j>>2]|0)+96>>2]=i;i=c[j>>2]|0;k=c[i+96>>2]|0;if((k|0)==0){f=-12;return f|0}c[i+100>>2]=768;AD(d,k,768)|0;k=FD(d)|0;i=g+8|0;c[(c[i>>2]|0)+412>>2]=k;_X(e,32,1,b);b=c[j>>2]|0;c[b+8>>2]=0;c[b+48>>2]=118;c[b+140>>2]=11;b=c[h>>2]|0;h=b;j=(b|0)<0|0?-1:0;b=e+56|0;c[b>>2]=h;c[b+4>>2]=j;b=e+64|0;c[b>>2]=h;c[b+4>>2]=j;j=c[i>>2]|0;c[j+8>>2]=1;c[j+48>>2]=65541;c[j+416>>2]=1;b=j+448|0;c[b>>2]=4;c[b+4>>2]=0;c[j+792>>2]=8;c[j+72>>2]=c[j+412>>2]<<3;j=a-3|0;fD(d,j,(j|0)<0|0?-1:0,0)|0;_X(g,64,1,c[(c[i>>2]|0)+412>>2]|0);f=0;return f|0}function vE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=e;if((c[g>>2]|0)==0){h=-541478725;i=d;return h|0}if((jD(f)|0)!=0){h=-541478725;i=d;return h|0}j=e+16|0;do{if((c[j>>2]|0)==0){k=0;do{if((jD(f)|0)!=0){h=-5;l=14;break}k=(zD(f)|0)+(k<<8)|0;}while((k|0)!=1230389587);if((l|0)==14){i=d;return h|0}k=FD(f)|0;FD(f)|0;m=FD(f)|0;FD(f)|0;n=FD(f)|0;o=n-m|0;m=k-n|0;c[e+12>>2]=m;if((o|m|0)<0){KIb(a,16,2404216,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=d;return h|0}m=fX(f,b,o)|0;if((m|0)<0){h=m;i=d;return h|0}else{o=e+4|0;n=c[o>>2]|0;k=b+8|0;c[k>>2]=n;c[k+4>>2]=(n|0)<0|0?-1:0;c[o>>2]=n+m;p=m;break}}else{m=e+12|0;n=c[m>>2]|0;if((n|0)<=0){p=-11;break}o=fX(f,b,n)|0;if((o|0)<0){h=o;i=d;return h|0}else{n=e+8|0;k=c[n>>2]|0;q=b+8|0;c[q>>2]=k;c[q+4>>2]=(k|0)<0|0?-1:0;c[n>>2]=k+((o|0)/(c[m>>2]|0)|0);c[g>>2]=(c[g>>2]|0)-1;p=o;break}}}while(0);g=(c[j>>2]|0)==0|0;c[j>>2]=g;c[b+32>>2]=g;h=p;i=d;return h|0}function wE(b){b=b|0;var e=0,f=0,g=0,h=0;e=c[b+4>>2]|0;b=a[e]|0;a:do{if((b<<24>>24|0)==66){if((a[e+1|0]|0)!=73){break}if((a[e+2|0]|0)==75){switch(a[e+3|0]|0){case 98:case 102:case 103:case 104:case 105:{f=9;break a;break};default:{}}}if(b<<24>>24==75){f=6}}else if((b<<24>>24|0)==75){f=6}}while(0);do{if((f|0)==6){if((a[e+1|0]|0)!=66){break}if((a[e+2|0]|0)!=50){break}b=a[e+3|0]|0;if((b<<24>>24|0)==97|(b<<24>>24|0)==100|(b<<24>>24|0)==102|(b<<24>>24|0)==103){f=9}}}while(0);do{if((f|0)==9){b=e+8|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==0){break}b=e+20|0;g=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;if(!((g|0)!=0&g>>>0<7681>>>0)){break}g=e+24|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;if(!((b|0)!=0&b>>>0<4801>>>0)){break}b=e+28|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==0){break}b=e+32|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==0){break}else{h=100}return h|0}}while(0);h=0;return h|0}function xE(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=ZX(b,0)|0;if((g|0)==0){h=-12;i=d;return h|0}j=FD(f)|0;k=g+8|0;c[(c[k>>2]|0)+52>>2]=j;j=e;c[j>>2]=(FD(f)|0)+8;l=FD(f)|0;m=g+56|0;c[m>>2]=l;c[m+4>>2]=0;if(l>>>0>1e6>>>0){KIb(b,16,2273096,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h=-5;i=d;return h|0}l=FD(f)|0;if(l>>>0>(c[j>>2]|0)>>>0){KIb(b,16,2223512,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h=-5;i=d;return h|0}hD(f,4,0)|0;l=FD(f)|0;c[(c[k>>2]|0)+120>>2]=l;l=FD(f)|0;c[(c[k>>2]|0)+124>>2]=l;l=FD(f)|0;o=FD(f)|0;if((l|0)==0|(o|0)==0){KIb(b,16,2188104,(n=i,i=i+16|0,c[n>>2]=l,c[n+8>>2]=o,n)|0);i=n;h=-5;i=d;return h|0}_X(g,64,o,l);l=g+92|0;o=c[g+40>>2]|0;c[l>>2]=c[g+44>>2];c[l+4>>2]=o;o=c[k>>2]|0;c[o+8>>2]=0;c[o+48>>2]=136;if((c[o+52>>2]&16777215|0)==3293771){KIb(b,24,2158240,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=c[k>>2]|0;c[l+48>>2]=0;p=l}else{p=o}if((QX(p,f,4)|0)<0){h=-12;i=d;return h|0}p=FD(f)|0;o=e+4|0;c[o>>2]=p;if(p>>>0>256>>>0){KIb(b,16,2132696,(n=i,i=i+8|0,c[n>>2]=p,n)|0);i=n;h=-5;i=d;return h|0}do{if((p|0)!=0){hD(f,p<<2,0)|0;if((c[o>>2]|0)==0){break}else{q=0}while(1){l=ZX(b,0)|0;if((l|0)==0){h=-12;r=33;break}s=l+8|0;t=c[s>>2]|0;c[t+8>>2]=1;c[t+52>>2]=0;t=DD(f)|0;c[(c[s>>2]|0)+412>>2]=t;_X(l,64,1,t);t=DD(f)|0;l=c[s>>2]|0;c[l+48>>2]=t>>>12&1|86064;u=l+416|0;if((t&8192|0)==0){c[u>>2]=1;t=l+448|0;c[t>>2]=4;c[t+4>>2]=0}else{c[u>>2]=2;u=l+448|0;c[u>>2]=3;c[u+4>>2]=0}if((PX(l,4)|0)!=0){h=-12;r=33;break}l=c[(c[s>>2]|0)+96>>2]|0;y=c[(c[k>>2]|0)+52>>2]|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=q+1|0;v=c[o>>2]|0;if(l>>>0<v>>>0){q=l}else{r=15;break}}if((r|0)==15){if((v|0)==0){break}l=b+28|0;s=0;do{u=FD(f)|0;s=s+1|0;c[(c[(c[l>>2]|0)+(s<<2)>>2]|0)+4>>2]=u;}while(s>>>0<(c[o>>2]|0)>>>0)}else if((r|0)==33){i=d;return h|0}}}while(0);o=0;v=FD(f)|0;while(1){q=o;k=0;p=c[m>>2]|0;s=c[m+4>>2]|0;if(!((k|0)<(s|0)|(k|0)==(s|0)&q>>>0<p>>>0)){r=32;break}l=wrc(p,s,-1,-1)|0;if((q|0)==(l|0)&(k|0)==(G|0)){w=0;x=c[j>>2]|0}else{w=v&1;x=FD(f)|0}l=v&-2;s=x&-2;if(!(s>>>0>l>>>0)){r=30;break}p=xX(g,l,0,q,k,s-l|0,0,w)|0;if((p|0)<0){h=p;r=33;break}else{o=o+1|0;v=s}}if((r|0)==30){KIb(b,16,2109608,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;h=-5;i=d;return h|0}else if((r|0)==32){n=c[g+400>>2]|0;fD(f,c[n>>2]|0,c[n+4>>2]|0,0)|0;c[e+8>>2]=-1;h=0;i=d;return h|0}else if((r|0)==33){i=d;return h|0}return 0}function yE(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;f=c[a+12>>2]|0;g=c[a+16>>2]|0;h=f+8|0;j=c[h>>2]|0;do{if((j|0)<0){k=c[c[a+28>>2]>>2]|0;l=f+16|0;m=c[l>>2]|0;n=c[l+4>>2]|0;o=k+56|0;p=c[o+4>>2]|0;if(!((n|0)<(p|0)|(n|0)==(p|0)&m>>>0<(c[o>>2]|0)>>>0)){q=-541478725;i=e;return q|0}o=CX(k,m,n,4)|0;if((o|0)>=0){c[f+2072>>2]=c[(c[k+400>>2]|0)+(o*24|0)+16>>2]>>2;c[h>>2]=0;r=0;break}o=c[l+4>>2]|0;KIb(a,16,2404144,(s=i,i=i+16|0,c[s>>2]=c[l>>2],c[s+8>>2]=o,s)|0);i=s;q=-5;i=e;return q|0}else{r=j}}while(0);j=f+4|0;o=f+2072|0;a:do{if(r>>>0<(c[j>>2]|0)>>>0){while(1){t=FD(g)|0;u=c[o>>2]|0;if(t>>>0>(u-4|0)>>>0){v=8;break}c[o>>2]=-4-t+u;c[h>>2]=(c[h>>2]|0)+1;if(t>>>0>3>>>0){break}hD(g,t,0)|0;if(!((c[h>>2]|0)>>>0<(c[j>>2]|0)>>>0)){break a}}if((v|0)==8){l=f+16|0;k=c[l+4>>2]|0;KIb(a,16,2328944,(s=i,i=i+32|0,c[s>>2]=c[l>>2],c[s+8>>2]=k,c[s+16>>2]=t,c[s+24>>2]=u,s)|0);i=s;q=-5;i=e;return q|0}k=fX(g,b,t)|0;if((k|0)<0){q=k;i=e;return q|0}c[b+32>>2]=c[h>>2];k=c[h>>2]|0;l=f+24+(k-1<<3)|0;n=c[l+4>>2]|0;m=b+8|0;c[m>>2]=c[l>>2];c[m+4>>2]=n;if((c[b+28>>2]|0)<=3){q=0;i=e;return q|0}n=c[b+24>>2]|0;m=wrc(c[l>>2]|0,c[l+4>>2]|0,((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>0)/(c[(c[(c[(c[a+28>>2]|0)+(k<<2)>>2]|0)+8>>2]|0)+416>>2]<<1>>>0)|0,0)|0;c[l>>2]=m;c[l+4>>2]=G;q=0;i=e;return q|0}}while(0);a=fX(g,b,c[o>>2]|0)|0;if((a|0)<0){q=a;i=e;return q|0}c[b+32>>2]=0;a=f+16|0;f=c[a>>2]|0;o=c[a+4>>2]|0;g=wrc(f,o,1,0)|0;c[a>>2]=g;c[a+4>>2]=G;a=b+8|0;c[a>>2]=f;c[a+4>>2]=o;o=b+36|0;c[o>>2]=c[o>>2]|1;c[h>>2]=-1;q=0;i=e;return q|0}function zE(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;f=c[a+12>>2]|0;e=c[a+16>>2]|0;if((c[e+88>>2]|0)==0){g=-1;return g|0}d=c[(c[c[a+28>>2]>>2]|0)+400>>2]|0;a=fD(e,c[d>>2]|0,c[d+4>>2]|0,0)|0;d=G;e=0;if((d|0)<(e|0)|(d|0)==(e|0)&a>>>0<0>>>0){g=-1;return g|0}mrc(f+16|0,0,2056)|0;c[f+8>>2]=-1;g=0;return g|0}function AE(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+48|0;e=d|0;f=d+40|0;g=c[b+12>>2]|0;h=b+16|0;j=c[h>>2]|0;k=ZX(b,0)|0;if((k|0)==0){l=-12;i=d;return l|0}m=k+8|0;n=c[m>>2]|0;c[n+52>>2]=0;c[n+8>>2]=0;o=g+8|0;if((c[o>>2]|0)==0){c[n+120>>2]=640;c[n+124>>2]=400}_X(k,60,c[g+20>>2]|0,c[g+16>>2]|0);n=g+4|0;p=~~(+(c[k+40>>2]|0)/+(c[k+44>>2]|0)*+(c[n>>2]|0));c[n>>2]=(p|0)<1?1:p;p=c[m>>2]|0;c[p+48>>2]=1112823892;if((PX(p,2)|0)!=0){l=-12;i=d;return l|0}a[c[(c[m>>2]|0)+96>>2]|0]=16;a[(c[(c[m>>2]|0)+96>>2]|0)+1|0]=0;if((c[j+88>>2]|0)==0){l=0;i=d;return l|0}c[f>>2]=0;p=iD(j)|0;n=g+24|0;c[n>>2]=p;c[n+4>>2]=G;do{if((aU(b,n,f,0)|0)<0){p=e|0;g=c[h>>2]|0;k=iD(g)|0;q=wrc(k,G,-256,-1)|0;fD(g,q,G,0)|0;if((AD(g,p,16)|0)!=16){break}if((grc(p,785328,16)|0)!=0){break}if((zD(g)|0)!=1){break}q=wrc(c[n>>2]|0,c[n+4>>2]|0,-256,-1)|0;c[n>>2]=q;c[n+4>>2]=G;q=zD(g)|0;if((q-1|0)>>>0>11>>>0){break}k=(AD(g,p,12)|0)!=12;if(!(k|(a[p]|0)==0)){a[e+q|0]=0;MGb(b+1140|0,2523456,p,0)|0}q=zD(g)|0;if((q-1|0)>>>0>19>>>0){break}k=(AD(g,p,20)|0)!=20;if(!(k|(a[p]|0)==0)){a[e+q|0]=0;MGb(b+1140|0,2508608,p,0)|0}q=zD(g)|0;if((q-1|0)>>>0>19>>>0){break}k=(AD(g,p,20)|0)!=20;if(!(k|(a[p]|0)==0)){a[e+q|0]=0;MGb(b+1140|0,2494240,p,0)|0}q=zD(g)|0;if((q-1|0)>>>0>34>>>0){break}k=(AD(g,p,35)|0)!=35;if(k|(a[p]|0)==0){break}a[e+q|0]=0;MGb(b+1140|0,2484008,p,0)|0}}while(0);if((c[o>>2]|0)==0){if((c[f>>2]|0)==0){f=c[n>>2]|0;o=c[n+4>>2]|0;b=c[m>>2]|0;e=0;h=o>>>0>e>>>0|o>>>0==e>>>0&f>>>0>4e3>>>0?1280:640;c[b+120>>2]=h;r=b;s=o;t=f;u=h}else{h=c[m>>2]|0;r=h;s=c[n+4>>2]|0;t=c[n>>2]|0;u=c[h+120>>2]|0}h=u>>3<<1;u=Frc(t,s,h,(h|0)<0|0?-1:0)|0;c[r+124>>2]=u<<4|0>>>28}fD(j,0,0,0)|0;l=0;i=d;return l|0}function BE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=d+24|0;f=c[e>>2]|0;g=a+16|0;a=c[g>>2]|0;do{if((f|0)==0&(c[e+4>>2]|0)==0){if((jD(a)|0)!=0){h=-5;return h|0}if((fX(c[g>>2]|0,b,c[d+4>>2]|0)|0)<0){h=-5}else{break}return h|0}else{if((fX(a,b,f)|0)<0){h=-5;return h|0}else{c[e>>2]=-1;c[e+4>>2]=-1;break}}}while(0);e=b+36|0;c[e>>2]=c[e>>2]|1;h=0;return h|0}function CE(b){b=b|0;var e=0,f=0,g=0,h=0;e=c[b+4>>2]|0;b=e;do{if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==1313423960){if((a[e+4|0]|0)!=26){break}f=e+5|0;g=(d[f]|d[f+1|0]<<8)<<16>>16;if(!(g<<16>>16!=0&(g&65535)>>>0<161>>>0)){break}g=a[e+9|0]|0;if(g<<24>>24!=0&(g&255)>>>0<33>>>0){h=100}else{break}return h|0}}while(0);h=0;return h|0}function DE(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[b+12>>2]|0;e=c[b+16>>2]|0;f=ZX(b,0)|0;if((f|0)==0){g=-12;return g|0}h=f+8|0;i=c[h>>2]|0;c[i+52>>2]=0;c[i+8>>2]=0;if((c[d+8>>2]|0)==0){c[i+120>>2]=640;c[i+124>>2]=400}_X(f,60,c[d+20>>2]|0,c[d+16>>2]|0);i=d+4|0;j=~~(+(c[f+40>>2]|0)/+(c[f+44>>2]|0)*+(c[i>>2]|0));c[i>>2]=(j|0)<1?1:j;hD(e,5,0)|0;j=(DD(e)|0)<<3;c[(c[h>>2]|0)+120>>2]=j;j=DD(e)|0;c[(c[h>>2]|0)+124>>2]=j;j=(zD(e)|0)&255;i=j<<24>>24;f=(c[h>>2]|0)+124|0;c[f>>2]=ca(c[f>>2]|0,i)|0;f=(zD(e)|0)&255;k=c[h>>2]|0;l=f<<24>>24;m=(l&1|0)==0?2:50;if((l&2|0)==0){n=m;o=m}else{p=m|(ca((l<<4&256)+256|0,i)|0);n=p;o=p}c[k+100>>2]=o;c[k+48>>2]=(l&4|0)!=0?1480739150:1112823892;if((PX(k,n)|0)!=0){g=-12;return g|0}a[c[(c[h>>2]|0)+96>>2]|0]=j;a[(c[(c[h>>2]|0)+96>>2]|0)+1|0]=f;f=c[h>>2]|0;if((AD(e,(c[f+96>>2]|0)+2|0,(c[f+100>>2]|0)-2|0)|0)<0){g=-5;return g|0}if((c[e+88>>2]|0)==0){g=0;return g|0}f=iD(e)|0;j=wrc(f,G,-9,-1)|0;f=c[(c[h>>2]|0)+100>>2]|0;n=xrc(j,G,f,(f|0)<0|0?-1:0)|0;f=d+24|0;c[f>>2]=n;c[f+4>>2]=G;aU(b,f,0,0)|0;f=(c[(c[h>>2]|0)+100>>2]|0)+9|0;fD(e,f,(f|0)<0|0?-1:0,0)|0;g=0;return g|0}function EE(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=b+12|0;g=c[f>>2]|0;h=c[b+16>>2]|0;if((zD(h)|0)!=1){j=-1094995529;i=d;return j|0}k=c[f>>2]|0;f=ZX(b,0)|0;if((f|0)==0){j=-12;i=d;return j|0}l=f+8|0;m=c[l>>2]|0;c[m+52>>2]=0;c[m+8>>2]=0;if((c[k+8>>2]|0)==0){c[m+120>>2]=640;c[m+124>>2]=400}_X(f,60,c[k+20>>2]|0,c[k+16>>2]|0);m=k+4|0;k=~~(+(c[f+40>>2]|0)/+(c[f+44>>2]|0)*+(c[m>>2]|0));c[m>>2]=(k|0)<1?1:k;k=c[l>>2]|0;c[k+48>>2]=1112823892;if((PX(k,4146)|0)!=0){j=-12;i=d;return j|0}a[c[(c[l>>2]|0)+96>>2]|0]=16;a[(c[(c[l>>2]|0)+96>>2]|0)+1|0]=3;if((AD(h,(c[(c[l>>2]|0)+96>>2]|0)+2|0,24)|0)<0){j=-5;i=d;return j|0}hD(h,144,0)|0;if((AD(h,(c[(c[l>>2]|0)+96>>2]|0)+26|0,24)|0)<0){j=-5;i=d;return j|0}if((AD(h,(c[(c[l>>2]|0)+96>>2]|0)+50|0,4096)|0)<0){j=-5;i=d;return j|0}if((c[h+88>>2]|0)==0){j=0;i=d;return j|0}c[e>>2]=0;k=iD(h)|0;m=wrc(k,G,-4289,-1)|0;k=g+24|0;c[k>>2]=m;c[k+4>>2]=G;c[(c[l>>2]|0)+120>>2]=640;aU(b,k,e,0)|0;if((c[g+8>>2]|0)==0){g=c[l>>2]|0;l=c[g+120>>2]>>3<<1;e=Frc(c[k>>2]|0,c[k+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[g+124>>2]=e<<4|0>>>28}fD(h,4289,0,0)|0;j=0;i=d;return j|0}function FE(a){a=a|0;var b=0,d=0;if((c[a+8>>2]|0)>>>0<12>>>0){b=0;return b|0}d=(grc(c[a+4>>2]|0,1076560,12)|0)==0;b=d?100:0;return b|0}function GE(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;f=c[b+12>>2]|0;g=c[b+16>>2]|0;c[e>>2]=0;if((c[g+88>>2]|0)==0){h=-5;i=d;return h|0}j=ZX(b,0)|0;if((j|0)==0){h=-12;i=d;return h|0}k=j+8|0;l=c[k>>2]|0;c[l+52>>2]=0;c[l+8>>2]=0;m=f+8|0;if((c[m>>2]|0)==0){c[l+120>>2]=640;c[l+124>>2]=400}_X(j,60,c[f+20>>2]|0,c[f+16>>2]|0);l=f+4|0;n=~~(+(c[j+40>>2]|0)/+(c[j+44>>2]|0)*+(c[l>>2]|0));c[l>>2]=(n|0)<1?1:n;n=c[k>>2]|0;c[n+48>>2]=4801606;if((PX(n,4146)|0)!=0){h=-12;i=d;return h|0}a[c[(c[k>>2]|0)+96>>2]|0]=16;a[(c[(c[k>>2]|0)+96>>2]|0)+1|0]=3;n=iD(g)|0;l=wrc(n,G,-4144,-1)|0;fD(g,l,G,0)|0;if((AD(g,(c[(c[k>>2]|0)+96>>2]|0)+50|0,4096)|0)<0){h=-5;i=d;return h|0}if((AD(g,(c[(c[k>>2]|0)+96>>2]|0)+2|0,48)|0)<0){h=-5;i=d;return h|0}l=iD(g)|0;n=wrc(l,G,-4156,-1)|0;l=f+24|0;c[l>>2]=n;c[l+4>>2]=G;aU(b,l,e,0)|0;if((c[m>>2]|0)==0){m=c[k>>2]|0;k=c[m+120>>2]>>3<<1;e=Frc(c[l>>2]|0,c[l+4>>2]|0,k,(k|0)<0|0?-1:0)|0;c[m+124>>2]=e<<4|0>>>28}fD(g,12,0,0)|0;h=0;i=d;return h|0}function HE(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[a+8>>2]|0;if((b|0)<64){e=0;return e|0}f=c[a+4>>2]|0;a=f;g=f+2|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==27425){h=0}else{e=0;return e|0}while(1){a=(d[g]|d[g+1|0]<<8)<<16>>16;if(!((a<<16>>16|0)==80|(a<<16>>16|0)==64)){e=0;i=5;break}f=(a&65535)+h|0;if((f+3|0)<(b|0)&(f|0)<800){h=f}else{e=50;i=5;break}}if((i|0)==5){return e|0}return 0}function IE(a){a=a|0;var b=0,d=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86070;c[a+412>>2]=8e3;c[a+432>>2]=16;c[a+416>>2]=1;_X(b,64,1,100);d=0;return d|0}function JE(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0;f=i;i=i+168|0;g=f|0;h=c[b+16>>2]|0;b=fD(h,0,0,1)|0;j=G;if((jD(h)|0)!=0){k=-541478725;i=f;return k|0}DD(h)|0;l=DD(h)|0;m=l>>>3;if(l>>>0>87>>>0){k=-1094995529;i=f;return k|0}l=m<<4;n=AD(h,g,l)|0;if((n|0)<0){k=n;i=f;return k|0}if((n|0)!=(l|0)){k=-5;i=f;return k|0}if((K1(e,m)|0)<0){k=-12;i=f;return k|0}l=0;do{if((m|0)!=0){n=c[e+24>>2]|0;h=32;o=0;p=g|0;q=0;while(1){r=n;s=h;t=0;u=p;v=q;while(1){w=(d[u]|d[u+1|0]<<8)<<16>>16<<16>>16==129|0;if((s|0)>1){x=s-1|0;z=v<<1|w;A=r}else{B=r;y=je(w>>>((1-s|0)>>>0)|v<<s|0)|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;x=s+31|0;z=w;A=r+4|0}l=z;w=t+1|0;if((w|0)<8){r=A;s=x;t=w;u=u+2|0;v=z}else{break}}v=o+1|0;if((v|0)<(m|0)){n=A;h=x;o=v;p=p+16|0;q=z}else{break}}if((x|0)>=32){break}q=z<<x;l=q;p=q>>>24&255;q=x;o=A;while(1){a[o]=p;h=l;l=h<<8;n=q+8|0;if((n|0)<32){p=h>>>16&255;q=n;o=o+1|0}else{break}}}}while(0);l=0;c[e+48>>2]=1;l=e+64|0;c[l>>2]=b;c[l+4>>2]=j;k=0;i=f;return k|0}function KE(a){a=a|0;var b=0;b=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;c[b+48>>2]=86070;c[b+416>>2]=1;c[b+792>>2]=16;c[b+432>>2]=2;return 0}function LE(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=c[a+16>>2]|0;oD(e,27425);oD(e,80);a=c[b+24>>2]|0;b=(a|0)==0?8:88;f=0;g=0;while(1){oD(e,((d[a+(f>>>3)|0]|0)<<(f&7)>>>6&2)+127|0);h=g+1|0;if((h|0)<80){f=((f|0)<(b|0))+f|0;g=h}else{break}}return 0}function ME(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[d+8>>2]|0;c[f+8>>2]=0;c[f+48>>2]=155;c[f+120>>2]=640;c[f+124>>2]=429;c[f+140>>2]=11;_X(d,16,1,12);d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}a=c[d+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86073;c[a+416>>2]=2;f=a+448|0;c[f>>2]=3;c[f+4>>2]=0;c[a+412>>2]=22050;_X(d,16,1,22050);c[b+8>>2]=1;d=b+16|0;c[d>>2]=0;c[d+4>>2]=0;e=0;return e|0}function NE(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=c[b+12>>2]|0;h=g+8|0;j=b+16|0;while(1){if((c[h>>2]|0)==0){k=13;break}l=c[j>>2]|0;if((c[l+52>>2]|0)!=0){m=-541478725;k=16;break}n=zD(l)|0;if((n|0)==1){m=-541478725;k=16;break}else if((n|0)!=0){k=5;break}}do{if((k|0)==5){l=ED(c[j>>2]|0)|0;o=g+4|0;c[o>>2]=l;if((l|0)==0){m=-1094995529;i=f;return m|0}p=g;q=lJb(g,l+1|0)|0;if((q|0)<0){m=q;i=f;return m|0}a[c[p>>2]|0]=n;q=AD(c[j>>2]|0,(c[p>>2]|0)+1|0,c[o>>2]|0)|0;if((q|0)!=(c[o>>2]|0)){m=-5;i=f;return m|0}if((n&32|0)==0){r=q;break}o=((d[(c[p>>2]|0)+1|0]|0)*65|0)+1|0;if((o|0)>=(q|0)){KIb(b,16,2402600,(l=i,i=i+16|0,c[l>>2]=o,c[l+8>>2]=q,l)|0);i=l;m=-1094995529;i=f;return m|0}if((K1(e,o)|0)<0){m=-12;i=f;return m|0}o=e+28|0;nrc(c[e+24>>2]|0,(c[p>>2]|0)+1|0,c[o>>2]|0)|0;c[e+32>>2]=1;l=g+16|0;q=c[l+4>>2]|0;s=e+8|0;c[s>>2]=c[l>>2];c[s+4>>2]=q;q=(d[(c[p>>2]|0)+1|0]|0)<<5;c[e+48>>2]=q;p=wrc(q,0,c[l>>2]|0,c[l+4>>2]|0)|0;c[l>>2]=p;c[l+4>>2]=G;c[h>>2]=0;m=c[o>>2]|0;i=f;return m|0}else if((k|0)==13){r=c[g+4>>2]|0}else if((k|0)==16){i=f;return m|0}}while(0);if((K1(e,r+1|0)|0)<0){m=-12;i=f;return m|0}c[e+32>>2]=0;c[h>>2]=1;h=e+28|0;nrc(c[e+24>>2]|0,c[g>>2]|0,c[h>>2]|0)|0;m=c[h>>2]|0;i=f;return m|0}function OE(a){a=a|0;mJb(c[a+12>>2]|0);return 0}function PE(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<2096){return 0}b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1){return 0}a=b+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>0>1e5>>>0){return 0}a=b+12|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>0>8>>>0){return 0}a=b+16|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=2096){return 0}a=b+21|0;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((e|0)==0){return 0}a=b+25|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==2096){a=b+48|0;return((((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>0)%(e>>>0)|0|0)==0?50:0)|0}else{return 0}return 0}function QE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=b+8|0;b=c[e>>2]|0;c[b+8>>2]=1;c[b+48>>2]=69638;b=a+16|0;FD(c[b>>2]|0)|0;FD(c[b>>2]|0)|0;f=FD(c[b>>2]|0)|0;c[(c[e>>2]|0)+412>>2]=f;f=FD(c[b>>2]|0)|0;c[(c[e>>2]|0)+416>>2]=f;f=a+1248|0;c[f>>2]=FD(c[b>>2]|0)|0;c[f+4>>2]=0;zD(c[b>>2]|0)|0;a=c[(c[e>>2]|0)+416>>2]|0;g=ca(FD(c[b>>2]|0)|0,a)|0;c[(c[e>>2]|0)+432>>2]=g;fD(c[b>>2]|0,c[f>>2]|0,c[f+4>>2]|0,0)|0;d=0;return d|0}function RE(a,b){a=a|0;b=b|0;return fX(c[a+16>>2]|0,b,c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+432>>2]|0)|0}function SE(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297371986){e=b+4|0;f=(d[e]|d[e+1|0]<<8)<<16>>16;if((f<<16>>16|0)==(-2|0)|(f<<16>>16|0)==(-257|0)){g=66}else{break}return g|0}}while(0);g=0;return g|0}function TE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;d=a+12|0;e=c[d>>2]|0;f=ZX(a,0)|0;if((f|0)==0){g=-12;i=b;return g|0}h=f+8|0;c[(c[h>>2]|0)+8>>2]=1;j=a+16|0;hD(c[j>>2]|0,4,0)|0;k=HD(c[j>>2]|0)|0;if((k|0)==65534){QIb(a,2327776,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;g=-1163346256;i=b;return g|0}else if((k|0)==65279){m=zD(c[j>>2]|0)|0;n=zD(c[j>>2]|0)|0;hD(c[j>>2]|0,4,0)|0;o=HD(c[j>>2]|0)|0;if(o>>>0<14>>>0){g=-1094995529;i=b;return g|0}hD(c[j>>2]|0,o-14|0,0)|0;o=fD(c[j>>2]|0,0,0,1)|0;p=G;if((FD(c[j>>2]|0)|0)!=1145128264){g=-1094995529;i=b;return g|0}q=JD(c[j>>2]|0)|0;if(q>>>0<256>>>0){g=-1094995529;i=b;return g|0}hD(c[j>>2]|0,4,0)|0;r=JD(c[j>>2]|0)|0;s=q;t=0;if(r>>>0>q>>>0){g=-1094995529;i=b;return g|0}hD(c[j>>2]|0,12,0)|0;q=wrc(JD(c[j>>2]|0)|0,0,16,0)|0;u=G;if(u>>>0>t>>>0|u>>>0==t>>>0&q>>>0>s>>>0){g=-1094995529;i=b;return g|0}v=c[j>>2]|0;w=fD(v,0,0,1)|0;x=G;y=wrc(o,p,8,0)|0;z=wrc(y,G,r,0)|0;r=xrc(z,G,w,x)|0;hD(v,r,G)|0;r=zD(c[j>>2]|0)|0;if((r|0)==0){A=65563}else if((r|0)==2){A=69650}else if((r|0)==1){A=1347637264}else{QIb(a,2272152,(l=i,i=i+8|0,c[l>>2]=r,l)|0);i=l;g=-1163346256;i=b;return g|0}hD(c[j>>2]|0,1,0)|0;c[(c[h>>2]|0)+48>>2]=A;r=zD(c[j>>2]|0)|0;c[(c[h>>2]|0)+416>>2]=r;if((r|0)==0){g=-1094995529;i=b;return g|0}hD(c[j>>2]|0,1,0)|0;r=HD(c[j>>2]|0)|0;c[(c[h>>2]|0)+412>>2]=r;if((r|0)==0){g=-1094995529;i=b;return g|0}hD(c[j>>2]|0,2,0)|0;hD(c[j>>2]|0,4,0)|0;r=f+48|0;c[r>>2]=0;c[r+4>>2]=0;r=f+56|0;c[r>>2]=JD(c[j>>2]|0)|0;c[r+4>>2]=0;_X(f,64,1,c[(c[h>>2]|0)+412>>2]|0);f=JD(c[j>>2]|0)|0;c[e+8>>2]=0;r=JD(c[j>>2]|0)|0;v=e+4|0;c[v>>2]=r;if(r>>>0>65535>>>0){KIb(a,24,2222880,(l=i,i=i+8|0,c[l>>2]=r,l)|0);i=l;g=-1094995529;i=b;return g|0}r=JD(c[j>>2]|0)|0;x=e;c[x>>2]=r;w=c[(c[h>>2]|0)+416>>2]|0;if(r>>>0>(65535/(w|0)|0)>>>0){g=-1094995529;i=b;return g|0}c[x>>2]=ca(w,r)|0;c[e+12>>2]=JD(c[j>>2]|0)|0;r=JD(c[j>>2]|0)|0;w=e+16|0;c[w>>2]=r;x=c[(c[h>>2]|0)+416>>2]|0;if(r>>>0>(65535/(x|0)|0)>>>0){g=-1094995529;i=b;return g|0}c[w>>2]=ca(x,r)|0;hD(c[j>>2]|0,4,0)|0;hD(c[j>>2]|0,4,0)|0;r=(A|0)==69650;a:do{if(r){A=c[j>>2]|0;x=wrc(q,u,o,p)|0;w=G;z=fD(A,0,0,1)|0;y=xrc(x,w,z,G)|0;hD(A,y,G)|0;y=wrc(JD(c[j>>2]|0)|0,0,16,0)|0;A=G;if(A>>>0>t>>>0|A>>>0==t>>>0&y>>>0>s>>>0){g=-1094995529;i=b;return g|0}z=c[j>>2]|0;w=wrc(y,A,o,p)|0;A=G;y=fD(z,0,0,1)|0;x=xrc(w,A,y,G)|0;hD(z,x,G)|0;x=pJb(c[(c[h>>2]|0)+416>>2]<<5)|0;z=e+20|0;c[z>>2]=x;if((x|0)==0){g=-12;i=b;return g|0}if((c[(c[h>>2]|0)+416>>2]|0)>0){B=0;C=x}else{D=27;break}while(1){if((AD(c[j>>2]|0,C+(B<<5)|0,32)|0)!=32){E=-1094995529;break a}hD(c[j>>2]|0,24,0)|0;x=B+1|0;if((x|0)>=(c[(c[h>>2]|0)+416>>2]|0)){D=27;break a}B=x;C=c[z>>2]|0}}else{D=27}}while(0);b:do{if((D|0)==27){C=fD(c[j>>2]|0,0,0,1)|0;B=xrc(C,G,o,p)|0;C=G;if((t|0)<(C|0)|(t|0)==(C|0)&s>>>0<B>>>0){E=-1094995529;break}B=c[j>>2]|0;C=fD(B,0,0,1)|0;u=G;q=wrc(s,t,o,p)|0;z=xrc(q,G,C,u)|0;hD(B,z,G)|0;if((jD(c[j>>2]|0)|0)!=0){E=-541478725;break}z=a;B=e+24|0;c:do{if(r){while(1){u=FD(c[j>>2]|0)|0;C=JD(c[j>>2]|0)|0;if(C>>>0<8>>>0){E=-1094995529;break b}q=C-8|0;do{if((u|0)==1096040772){break c}else if((u|0)==1129333825){C=ca(c[v>>2]<<2,c[(c[h>>2]|0)+416>>2]|0)|0;if(q>>>0<C>>>0){E=-1094995529;break b}if((c[B>>2]|0)!=0){KIb(z,24,2187712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;D=38;break}x=pJb(C)|0;c[B>>2]=x;if((x|0)==0){E=-12;break b}AD(c[j>>2]|0,x,C)|0;hD(c[j>>2]|0,q-C|0,0)|0;}else{KIb(z,24,2132456,(l=i,i=i+8|0,c[l>>2]=u,l)|0);i=l;D=38}}while(0);if((D|0)==38){D=0;hD(c[j>>2]|0,q,0)|0;}if((jD(c[j>>2]|0)|0)!=0){E=-541478725;break b}}}else{while(1){u=FD(c[j>>2]|0)|0;C=JD(c[j>>2]|0)|0;if(C>>>0<8>>>0){E=-1094995529;break b}x=C-8|0;if((u|0)==1096040772){break c}else if((u|0)!=1129333825){KIb(z,24,2132456,(l=i,i=i+8|0,c[l>>2]=u,l)|0);i=l}hD(c[j>>2]|0,x,0)|0;if((jD(c[j>>2]|0)|0)!=0){E=-541478725;break b}}}}while(0);x=f;u=0;C=fD(c[j>>2]|0,0,0,1)|0;y=G;if((u|0)<(y|0)|(u|0)==(y|0)&x>>>0<C>>>0){E=-1094995529;break}if(!((c[B>>2]|0)!=0|r^1)){E=-1094995529;break}C=c[j>>2]|0;y=fD(C,0,0,1)|0;A=xrc(x,u,y,G)|0;hD(C,A,G)|0;if((m|0)==1&(n|0)==0){g=0;i=b;return g|0}QIb(z,2157808,(l=i,i=i+16|0,c[l>>2]=m,c[l+8>>2]=n,l)|0);i=l;g=0;i=b;return g|0}}while(0);n=c[d>>2]|0;mJb(n+20|0);mJb(n+24|0);g=E;i=b;return g|0}else{KIb(a,16,2402216,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;g=-1094995529;i=b;return g|0}return 0}function UE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;f=c[b+12>>2]|0;g=b+16|0;if((jD(c[g>>2]|0)|0)!=0){h=-541478725;return h|0}b=f+8|0;i=(c[b>>2]|0)+1|0;c[b>>2]=i;j=c[f+4>>2]|0;do{if((i|0)==(j|0)){k=c[f+16>>2]|0;l=k;m=((k>>>0)/(c[e+416>>2]<<3>>>0)|0)*14|0}else{if(i>>>0<j>>>0){l=c[f>>2]|0;m=c[f+12>>2]|0;break}else{h=-541478725;return h|0}}}while(0);if((c[e+48>>2]|0)==69650){j=e+416|0;if((K1(d,l+8+((c[j>>2]|0)*36|0)|0)|0)<0){h=-12;return h|0}e=c[d+24>>2]|0;i=e;y=je(l|0)|0;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;i=e+4|0;y=je(m|0)|0;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;i=c[j>>2]<<5;nrc(e+8|0,c[f+20>>2]|0,i)|0;k=i|8;i=c[j>>2]<<2;nrc(e+k|0,(c[f+24>>2]|0)+(ca((c[b>>2]|0)-1|0,i)|0)|0,i)|0;b=AD(c[g>>2]|0,e+(i+k)|0,l)|0;if((b|0)!=(l|0)){P1(d)}c[d+48>>2]=m;n=b}else{n=fX(c[g>>2]|0,d,l)|0}c[d+32>>2]=0;h=(n|0)==(l|0)?n:-5;return h|0}function VE(a){a=a|0;var b=0;b=c[a+12>>2]|0;mJb(b+20|0);mJb(b+24|0);return 0}function WE(b){b=b|0;var e=0,f=0,g=0;if((c[b+8>>2]|0)<16){return 0}e=c[b+4>>2]|0;b=e;if(!((d[b]|d[b+1|0]<<8)<<16>>16<<16>>16==1)){return 0}b=a[e+2|0]|0;if(b<<24>>24==0){return 0}if((a[e+3|0]|0)==0){return 0}f=(b&255)+1|0;b=e+4|0;if(((d[b]|d[b+1|0]<<8)<<16>>16&65535|0)!=(f|0)){return 0}b=a[e+6|0]|0;if(b<<24>>24==0){return 0}if((a[e+7|0]|0)==0){return 0}g=(b&255)+f|0;f=e+8|0;if(((d[f]|d[f+1|0]<<8)<<16>>16&65535|0)!=(g|0)){return 0}f=a[e+10|0]|0;if(f<<24>>24==0){return 0}if((a[e+11|0]|0)==0){return 0}b=e+12|0;if(((d[b]|d[b+1|0]<<8)<<16>>16&65535|0)!=((f&255)+g|0)){return 0}if((a[e+14|0]|0)==0){return 0}else{return((a[e+15|0]|0)==0?0:100)|0}return 0}function XE(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[d+16>>2]|0;g=c[d+12>>2]|0;h=g+8|0;j=0;k=0;do{b[h+(k<<2)>>1]=DD(f)|0;a[h+(k<<2)+2|0]=zD(f)|0;l=zD(f)|0;a[h+(k<<2)+3|0]=l;m=l&255;if(m>>>0>32>>>0){n=3;break}j=m+j|0;k=k+1|0;}while((k|0)<512);if((n|0)==3){KIb(d,16,2327544,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=e;return o|0}n=d+20|0;c[n>>2]=c[n>>2]|1;n=ZX(d,0)|0;if((n|0)==0){o=-12;i=e;return o|0}d=c[n+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=103;c[d+120>>2]=320;c[d+124>>2]=192;c[n+80>>2]=5;c[n+84>>2]=6;_X(n,64,2,25);d=j;k=(j|0)<0|0?-1:0;j=n+64|0;c[j>>2]=d;c[j+4>>2]=k;j=n+56|0;c[j>>2]=d;c[j+4>>2]=k;k=n+48|0;c[k>>2]=0;c[k+4>>2]=0;c[g+2056>>2]=0;c[g+2188>>2]=0;c[g+2192>>2]=0;o=0;i=e;return o|0}function YE(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[b+16>>2]|0;j=c[b+12>>2]|0;k=j+2056|0;l=c[k>>2]|0;m=j+8|0;n=j+2192|0;o=j+2188|0;do{if((c[n>>2]|0)!=0){c[o>>2]=(c[o>>2]|0)+1;c[n>>2]=0;p=DD(h)|0;if((p|0)<=42){break}q=j+2196|0;do{if((c[q>>2]|0)==0){r=ZX(b,0)|0;c[q>>2]=r;if((r|0)==0){s=-12;i=g;return s|0}else{c[(c[r+8>>2]|0)+8>>2]=1;break}}}while(0);hD(h,26,0)|0;r=MY(b,f,c[q>>2]|0,p-26|0)|0;if((r|0)<=0){break}c[f+32>>2]=1;t=f+36|0;c[t>>2]=c[t>>2]|1;s=r;i=g;return s|0}}while(0);r=c[o>>2]|0;do{if((r|0)<(d[m+(l<<2)+3|0]|0)){t=m+(l<<2)|0;if((r|0)==0){u=t;v=14;break}w=t;x=r;y=j+2060|0}else{t=c[k>>2]|0;if((t|0)>510){s=-541478725;i=g;return s|0}z=l+1|0;if((a[m+(z<<2)+2|0]|0)==0){s=-541478725;i=g;return s|0}else{c[k>>2]=t+1;c[o>>2]=0;u=m+(z<<2)|0;v=14;break}}}while(0);if((v|0)==14){fD(h,e[u>>1]<<11,0,0)|0;m=j+2060|0;j=0;do{c[m+(j<<2)>>2]=FD(h)|0;j=j+1|0;}while((j|0)<32);w=u;x=c[o>>2]|0;y=m}fD(h,(e[w>>1]<<11)+(c[y+(x<<2)>>2]|0)|0,0,0)|0;x=DD(h)|0;y=K1(f,x+769|0)|0;if((y|0)<0){s=y;i=g;return s|0}y=f+24|0;a[c[y>>2]|0]=0;w=f+28|0;c[w>>2]=x+1;do{if((AD(h,(c[y>>2]|0)+1|0,x)|0)<(x|0)){A=-5}else{m=DD(h)|0;if((m|0)==768){v=21}else if((m|0)!=0){KIb(b,16,2401984,(u=i,i=i+8|0,c[u>>2]=m,u)|0);i=u;A=-1094995529;break}if((v|0)==21){u=c[y>>2]|0;a[u]=a[u]|1;if((AD(h,(c[y>>2]|0)+(c[w>>2]|0)|0,768)|0)<768){A=-5;break}c[w>>2]=(c[w>>2]|0)+768}c[f+32>>2]=0;c[n>>2]=1;if((c[k>>2]|0)!=0){s=0;i=g;return s|0}if((c[o>>2]|0)!=0){s=0;i=g;return s|0}u=f+36|0;c[u>>2]=c[u>>2]|1;u=c[y>>2]|0;a[u]=a[u]|2;s=0;i=g;return s|0}}while(0);P1(f);s=A;i=g;return s|0}function ZE(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1717985635){e=b+4|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==256){f=100}else{break}return f|0}}while(0);f=0;return f|0}function _E(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;d=i;i=i+1088|0;e=d|0;f=d+32|0;g=d+1056|0;j=d+1072|0;l=b+16|0;m=c[l>>2]|0;n=b+12|0;o=c[n>>2]|0;hD(m,8,0)|0;if((JD(m)|0)!=1684370275){KIb(b,16,2401680,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=d;return q|0}r=OD(m)|0;if(!((r|0)==32&(G|0)==0)){q=-1094995529;i=d;return q|0}r=c[l>>2]|0;s=c[n>>2]|0;t=ZX(b,0)|0;if((t|0)==0){q=-12;i=d;return q|0}u=t+8|0;c[(c[u>>2]|0)+8>>2]=1;t=OD(r)|0;v=G;c[(c[u>>2]|0)+412>>2]=~~(c[k>>2]=t,c[k+4>>2]=v,+h[k>>3]);v=FD(r)|0;c[(c[u>>2]|0)+52>>2]=v;v=JD(r)|0;t=JD(r)|0;w=s;c[w>>2]=t;c[(c[u>>2]|0)+432>>2]=t;t=s+4|0;c[t>>2]=JD(r)|0;s=JD(r)|0;c[(c[u>>2]|0)+416>>2]=s;s=JD(r)|0;r=c[u>>2]|0;c[r+792>>2]=s;x=c[t>>2]|0;do{if((x|0)>0){t=c[w>>2]|0;if((t|0)<=0){z=8;break}A=c[r+412>>2]|0;B=t;C=Erc(B<<3|0>>>29,((t|0)<0|0?-1:0)<<3|B>>>29,A,(A|0)<0|0?-1:0)|0;A=Frc(C,G,x,(x|0)<0|0?-1:0)|0;c[r+72>>2]=A}else{z=8}}while(0);if((z|0)==8){c[r+72>>2]=0}x=c[r+52>>2]|0;if((x|0)==1835233388){r=zL(s,(v|4)^2)|0;c[(c[u>>2]|0)+48>>2]=r}else{r=JX(1408976,x)|0;c[(c[u>>2]|0)+48>>2]=r}r=b+28|0;u=c[c[r>>2]>>2]|0;if((jD(m)|0)!=0){q=-1094995529;i=d;return q|0}x=b;v=o+32|0;s=o+40|0;w=m+88|0;A=j|0;C=j+4|0;j=e|0;e=f|0;f=b+1140|0;B=0;a:while(1){if((B|0)!=0){t=c[s+4>>2]|0;D=0;if((t|0)<(D|0)|(t|0)==(D|0)&(c[s>>2]|0)>>>0<0>>>0){E=B;z=60;break}if((c[w>>2]|0)==0){E=B;z=60;break}}D=JD(m)|0;F=OD(m)|0;H=G;t=fD(m,0,0,1)|0;I=G;if((jD(m)|0)!=0){E=B;z=60;break}do{if((D|0)==1667785070){J=LM(b,c[l>>2]|0,u,F,H)|0;if((J|0)<0){q=J;z=71;break a}else{K=B}}else if((D|0)==1684108385){hD(m,4,0)|0;J=fD(m,0,0,1)|0;c[v>>2]=J;c[v+4>>2]=G;J=0;L=(H|0)<(J|0)|(H|0)==(J|0)&F>>>0<0>>>0;J=wrc(F,H,-4,-1)|0;M=L?-1:J;J=L?-1:G;c[s>>2]=M;c[s+4>>2]=J;L=0;if(!((J|0)>(L|0)|(J|0)==(L|0)&M>>>0>0>>>0)){K=1;break}if((c[w>>2]|0)==0){K=1;break}hD(m,M,J)|0;K=1}else if((D|0)==1885432692){J=c[l>>2]|0;M=c[c[r>>2]>>2]|0;L=c[n>>2]|0;N=fD(J,0,0,1)|0;O=G;P=OD(J)|0;Q=G;R=0;if(Q>>>0>R>>>0|Q>>>0==R>>>0&P>>>0>89478485>>>0){q=-1094995529;z=71;break a}R=OD(J)|0;S=M+64|0;c[S>>2]=R;c[S+4>>2]=G;R=JD(J)|0;T=wrc(c[S>>2]|0,c[S+4>>2]|0,R,0)|0;c[S>>2]=T;c[S+4>>2]=G;T=JD(J)|0;R=wrc(c[S>>2]|0,c[S+4>>2]|0,T,0)|0;c[S>>2]=R;c[S+4>>2]=G;S=M+56|0;c[S>>2]=0;c[S+4>>2]=0;M=0;if((Q|0)>(M|0)|(Q|0)==(M|0)&P>>>0>0>>>0){M=L;R=L+4|0;T=0;U=0;V=0;W=0;X=0;while(1){xX(c[c[r>>2]>>2]|0,U,T,X,W,0,0,1)|0;Y=c[M>>2]|0;if((Y|0)==0){Z=GJ(J)|0}else{Z=Y}Y=wrc(Z,(Z|0)<0|0?-1:0,U,T)|0;_=G;$=c[R>>2]|0;if(($|0)==0){aa=GJ(J)|0}else{aa=$}$=wrc(c[S>>2]|0,c[S+4>>2]|0,aa,(aa|0)<0|0?-1:0)|0;ba=G;c[S>>2]=$;c[S+4>>2]=ba;ca=V+1|0;da=(ca|0)<0|0?-1:0;if((da|0)<(Q|0)|(da|0)==(Q|0)&ca>>>0<P>>>0){T=_;U=Y;V=ca;W=ba;X=$}else{ea=_;fa=Y;break}}}else{ea=0;fa=0}X=fD(J,0,0,1)|0;W=xrc(X,G,N,O)|0;X=G;if((X|0)>(H|0)|(X|0)==(H|0)&W>>>0>F>>>0){z=48;break a}W=wrc(N,O,F,H)|0;X=G;V=fD(J,0,0,1)|0;U=xrc(W,X,V,G)|0;hD(J,U,G)|0;U=L+8|0;c[U>>2]=fa;c[U+4>>2]=ea;K=B}else if((D|0)==1718773093){z=53}else if((D|0)==1768842863){U=c[l>>2]|0;V=JD(U)|0;if((V|0)==0){K=B;break}else{ga=0}while(1){LD(U,2147483647,j,32)|0;LD(U,2147483647,e,1024)|0;MGb(f,j,e,0)|0;X=ga+1|0;if(X>>>0<V>>>0){ga=X}else{K=B;break}}}else if((D|0)==1802857321){ha=c[l>>2]|0;V=0;if(H>>>0>V>>>0|H>>>0==V>>>0&F>>>0>2147483631>>>0){q=-1094995529;z=71;break a}ia=(c[c[r>>2]>>2]|0)+8|0;V=c[ia>>2]|0;U=c[V+48>>2]|0;if((U|0)==86018){L=fD(ha,0,0,1)|0;J=G;yL(b,ha,g)|0;O=fD(ha,0,0,1)|0;N=G;X=wrc(L,J,F,H)|0;J=xrc(X,G,O,N)|0;N=J;if((N|0)<0){z=28;break a}J=c[ia>>2]|0;if((c[J+96>>2]|0)==0){z=28;break a}if((c[J+48>>2]|0)!=86018){z=28;break a}hD(ha,N,(N|0)<0|0?-1:0)|0;K=B;break}else if((U|0)==86032){U=0;if((H|0)<(U|0)|(H|0)==(U|0)&F>>>0<24>>>0){z=31;break a}AD(ha,A,12)|0;if((PX(c[ia>>2]|0,36)|0)!=0){q=-1094995529;z=71;break a}if((grc(C,2132376,8)|0)!=0){U=c[(c[ia>>2]|0)+96>>2]|0;y=603979776;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=(c[(c[ia>>2]|0)+96>>2]|0)+4|0;y=1667329121;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=(c[(c[ia>>2]|0)+96>>2]|0)+8|0;y=0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;nrc((c[(c[ia>>2]|0)+96>>2]|0)+12|0,A|0,12)|0;AD(ha,(c[(c[ia>>2]|0)+96>>2]|0)+24|0,12)|0;U=wrc(F,H,-24,-1)|0;hD(ha,U,G)|0;K=B;break}U=0;if((H|0)<(U|0)|(H|0)==(U|0)&F>>>0<48>>>0){z=35;break a}AD(ha,c[(c[ia>>2]|0)+96>>2]|0,36)|0;U=wrc(F,H,-48,-1)|0;hD(ha,U,G)|0;K=B;break}else{if((QX(V,ha,F)|0)<0){q=-1094995529;z=71;break a}else{K=B;break}}}else{V=D>>>16&255;U=D>>>8&255;N=D&255;KIb(x,24,2327264,(p=i,i=i+56|0,c[p>>2]=D,c[p+8>>2]=D>>>0>536870911>>>0?D>>>24:32,c[p+16>>2]=V>>>0<32>>>0?32:V,c[p+24>>2]=U>>>0<32>>>0?32:U,c[p+32>>2]=N>>>0<32>>>0?32:N,c[p+40>>2]=F,c[p+48>>2]=H,p)|0);i=p;z=53}}while(0);if((z|0)==53){z=0;D=0;if((H|0)<(D|0)|(H|0)==(D|0)&F>>>0<0>>>0){q=-1094995529;z=71;break}else{K=B}}D=0;if((H|0)>(D|0)|(H|0)==(D|0)&F>>>0>0>>>0){D=xrc(-1,2147483647,F,H)|0;N=G;if((I|0)>(N|0)|(I|0)==(N|0)&t>>>0>D>>>0){q=-1094995529;z=71;break}D=wrc(t,I,F,H)|0;N=G;U=fD(m,0,0,1)|0;V=xrc(D,N,U,G)|0;U=G;J=0;if((U|0)<(J|0)|(U|0)==(J|0)&V>>>0<0>>>0){ja=0;ka=0}else{V=fD(m,0,0,1)|0;J=xrc(D,N,V,G)|0;ja=G;ka=J}hD(m,ka,ja)|0;}if((jD(m)|0)==0){B=K}else{E=K;z=60;break}}if((z|0)==28){KIb(x,16,2187544,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=d;return q|0}else if((z|0)==31){KIb(x,16,2157712,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;hD(ha,F,H)|0;q=-1094995529;i=d;return q|0}else if((z|0)==35){KIb(x,16,2157712,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;mJb((c[ia>>2]|0)+96|0);q=-1094995529;i=d;return q|0}else if((z|0)==48){KIb(x,16,2222640,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=d;return q|0}else if((z|0)==60){if((E|0)==0){q=-1094995529;i=d;return q|0}E=c[o>>2]|0;do{if((E|0)>0){x=c[o+4>>2]|0;if((x|0)<=0){z=65;break}ia=o+40|0;H=c[ia>>2]|0;F=c[ia+4>>2]|0;ia=0;if(!((F|0)>(ia|0)|(F|0)==(ia|0)&H>>>0>0>>>0)){break}ia=Crc(H,F,E,(E|0)<0|0?-1:0)|0;F=Erc(ia,G,x,(x|0)<0|0?-1:0)|0;x=u+64|0;c[x>>2]=F;c[x+4>>2]=G}else{z=65}}while(0);b:do{if((z|0)==65){do{if((c[u+404>>2]|0)!=0){E=u+56|0;x=c[E>>2]|0;F=c[E+4>>2]|0;E=0;if(!((F|0)>(E|0)|(F|0)==(E|0)&x>>>0>0>>>0)){break}E=c[u+8>>2]|0;ia=c[E+412>>2]|0;H=o+40|0;ha=c[H>>2]|0;K=Erc(ha<<3|0>>>29,c[H+4>>2]<<3|ha>>>29,ia,(ia|0)<0|0?-1:0)|0;ia=Crc(K,G,x,F)|0;c[E+72>>2]=ia;break b}}while(0);KIb(b,16,2271640,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=d;return q|0}}while(0);_X(u,64,1,c[(c[u+8>>2]|0)+412>>2]|0);p=u+48|0;c[p>>2]=0;c[p+4>>2]=0;p=o+40|0;u=c[p+4>>2]|0;b=-1;if(!((u|0)>(b|0)|(u|0)==(b|0)&(c[p>>2]|0)>>>0>-1>>>0)){q=0;i=d;return q|0}p=o+32|0;fD(m,c[p>>2]|0,c[p+4>>2]|0,0)|0;q=0;i=d;return q|0}else if((z|0)==71){i=d;return q|0}return 0}function $E(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[a+16>>2]|0;e=c[c[a+28>>2]>>2]|0;f=c[a+12>>2]|0;if((jD(d)|0)!=0){g=-541478725;return g|0}a=f+40|0;h=c[a>>2]|0;i=c[a+4>>2]|0;a=0;do{if((i|0)>(a|0)|(i|0)==(a|0)&h>>>0>0>>>0){j=f+32|0;k=wrc(c[j>>2]|0,c[j+4>>2]|0,h,i)|0;j=G;l=fD(d,0,0,1)|0;m=G;n=xrc(k,j,l,m)|0;o=G;if((k|0)==(l|0)&(j|0)==(m|0)){g=-541478725;return g|0}m=0;if((o|0)<(m|0)|(o|0)==(m|0)&n>>>0<0>>>0){g=-5}else{p=o;q=n;break}return g|0}else{p=0;q=4096}}while(0);i=c[f+4>>2]|0;h=c[f>>2]|0;do{if((h|0)>0&(i|0)==1){a=4096-(4096%(h|0)|0)|0;n=(a|0)<0|0?-1:0;o=(n|0)>(p|0)|(n|0)==(p|0)&a>>>0>q>>>0?q:a;r=(o|0)/(h|0)|0;s=o}else{o=c[e+404>>2]|0;if((o|0)==0){r=i;s=h;break}a=f+16|0;n=c[a>>2]|0;m=c[a+4>>2]|0;a=o-1|0;o=a;j=(a|0)<0|0?-1:0;if((m|0)<(j|0)|(m|0)==(j|0)&n>>>0<o>>>0){a=wrc(n,m,1,0)|0;l=a;a=c[e+400>>2]|0;k=a+(l*24|0)|0;t=n;u=a+(t*24|0)|0;v=xrc(c[k>>2]|0,c[k+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;u=a+(l*24|0)+8|0;l=a+(t*24|0)+8|0;t=xrc(c[u>>2]|0,c[u+4>>2]|0,c[l>>2]|0,c[l+4>>2]|0)|0;r=t;s=v;break}if((n|0)==(o|0)&(m|0)==(j|0)){j=f+8|0;m=n;n=c[e+400>>2]|0;o=n+(m*24|0)|0;v=xrc(c[j>>2]|0,c[j+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;o=e+56|0;j=n+(m*24|0)+8|0;m=xrc(c[o>>2]|0,c[o+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;r=m;s=v;break}else{g=-5;return g|0}}}while(0);e=(s|0)<0|0?-1:0;if((s|0)==0|(r|0)==0|((e|0)>(p|0)|(e|0)==(p|0)&s>>>0>q>>>0)){g=-5;return g|0}q=fX(d,b,s)|0;if((q|0)<0){g=q;return g|0}c[b+28>>2]=q;c[b+32>>2]=0;q=f+24|0;s=c[q>>2]|0;d=c[q+4>>2]|0;p=b+8|0;c[p>>2]=s;c[p+4>>2]=d;p=b+16|0;c[p>>2]=s;c[p+4>>2]=d;d=f+16|0;f=wrc(c[d>>2]|0,c[d+4>>2]|0,1,0)|0;c[d>>2]=f;c[d+4>>2]=G;d=wrc(c[q>>2]|0,c[q+4>>2]|0,r,(r|0)<0|0?-1:0)|0;c[q>>2]=d;c[q+4>>2]=G;g=0;return g|0}function aF(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[c[a+28>>2]>>2]|0;g=c[a+12>>2]|0;h=0;i=(e|0)>(h|0)|(e|0)==(h|0)&d>>>0>0>>>0;h=i?d:0;d=i?e:0;e=c[g+4>>2]|0;do{if((e|0)>0){i=c[g>>2]|0;if((i|0)<=0){j=6;break}k=i;l=(i|0)<0|0?-1:0;i=e;m=(e|0)<0|0?-1:0;n=Crc(h,d,i,m)|0;o=Erc(n,G,k,l)|0;n=G;p=g+40|0;q=c[p>>2]|0;r=c[p+4>>2]|0;p=0;if((r|0)>(p|0)|(r|0)==(p|0)&q>>>0>0>>>0){p=(n|0)>(r|0)|(n|0)==(r|0)&o>>>0>q>>>0;s=p?r:n;t=p?q:o}else{s=n;t=o}o=Crc(t,s,k,l)|0;l=G;k=Erc(i,m,o,l)|0;u=G;v=k;w=l;x=o;y=s;z=t}else{j=6}}while(0);do{if((j|0)==6){if((c[b+404>>2]|0)==0){A=-1;return A|0}else{t=CX(b,h,d,f)|0;s=c[b+400>>2]|0;e=s+(t*24|0)+8|0;o=s+(t*24|0)|0;u=c[e+4>>2]|0;v=c[e>>2]|0;w=(t|0)<0|0?-1:0;x=t;y=c[o+4>>2]|0;z=c[o>>2]|0;break}}}while(0);b=c[a+16>>2]|0;a=g+32|0;f=wrc(c[a>>2]|0,c[a+4>>2]|0,z,y)|0;y=fD(b,f,G,0)|0;f=G;b=0;if((f|0)<(b|0)|(f|0)==(b|0)&y>>>0<0>>>0){A=-1;return A|0}y=g+16|0;c[y>>2]=x;c[y+4>>2]=w;w=g+24|0;c[w>>2]=v;c[w+4>>2]=u;A=0;return A|0}function bF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;f=c[a+12>>2]|0;g=e+48|0;j=IX(1408976,c[g>>2]|0)|0;if((c[a+24>>2]|0)!=1){KIb(a,16,2271464,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=b;return m|0}n=c[g>>2]|0;if((n-86018|0)>>>0<2>>>0){KIb(a,16,2222432,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1163346256;i=b;return m|0}a:do{switch(n|0){case 65540:case 65536:case 65537:case 65548:case 65549:case 65544:case 65545:case 65557:case 65556:case 65559:case 65558:case 65543:case 65542:{o=1835233388;break};default:{if((j|0)!=0){o=j;break a}KIb(a,16,2187400,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=b;return m|0}}}while(0);j=e+432|0;do{if((c[j>>2]|0)==0){if((c[d+88>>2]|0)!=0){break}KIb(a,16,2157576,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=b;return m|0}}while(0);kD(d,1717985635);tD(d,1);tD(d,0);kD(d,1668506980);sD(d,32,0);h[k>>3]=+(c[e+412>>2]|0);sD(d,c[k>>2]|0,c[k+4>>2]|0);kD(d,o);switch(c[g>>2]|0){case 65557:case 65559:{p=3;break};case 65536:case 65548:case 65544:{p=2;break};case 65556:case 65558:{p=1;break};default:{p=0}}lD(d,p);lD(d,c[j>>2]|0);j=c[g>>2]|0;p=e+416|0;o=c[p>>2]|0;if((j|0)==65540|(j|0)==65536|(j|0)==65537|(j|0)==65548|(j|0)==65549|(j|0)==65544|(j|0)==65545|(j|0)==65557|(j|0)==65556|(j|0)==65559|(j|0)==65558|(j|0)==65543|(j|0)==65542){q=1}else if((j|0)==86016|(j|0)==86017){q=1152}else if((j|0)==86035){q=o<<11}else if((j|0)==86025|(j|0)==86026){q=6}else if((j|0)==69632){q=64}else if((j|0)==73728|(j|0)==86034|(j|0)==86076|(j|0)==86040){q=160}else if((j|0)==86032){q=4096}else if((j|0)==86046){q=320}else if((j|0)==69638){q=(((o*-14|0)+2048|0)/(o|0)|0)+2|0}else if((j|0)==69633){l=o<<2;q=((1024-l<<3|0)/(l|0)|0)+1|0}else if((j|0)==86059){q=384}else if((j|0)==86019){q=1536}else{q=0}lD(d,q);lD(d,c[p>>2]|0);lD(d,g5a(c[g>>2]|0)|0);p=e+448|0;if(!((c[p>>2]|0)==0&(c[p+4>>2]|0)==0)){kD(d,1851877475);sD(d,12,0);KJ(d,c[p>>2]|0,c[p+4>>2]|0)}p=c[g>>2]|0;if((p|0)==86035){kD(d,1768650091);g=e+100|0;q=c[g>>2]|0;sD(d,q,(q|0)<0|0?-1:0);dD(d,c[e+96>>2]|0,c[g>>2]|0)}else if((p|0)==86032){kD(d,1768650091);g=e+100|0;q=(c[g>>2]|0)+12|0;sD(d,q,(q|0)<0|0?-1:0);dD(d,2576368,12);dD(d,c[e+96>>2]|0,c[g>>2]|0)}else if((p|0)==73728){kD(d,1768650091);sD(d,29,0);dD(d,2557384,12);lD(d,17);dD(d,2540096,8);bD(d,0);tD(d,33279);bD(d,0);bD(d,1)}p=a+1140|0;do{if((KGb(c[p>>2]|0)|0)!=0){kD(d,1868983913);a=LGb(c[p>>2]|0,10230592,0,2)|0;if((a|0)==0){r=0;s=4}else{g=0;e=0;q=a;do{a=lrc(c[q>>2]|0)|0;e=wrc(a+2+(lrc(c[q+4>>2]|0)|0)|0,0,e,g)|0;g=G;q=LGb(c[p>>2]|0,10230592,q,2)|0;}while((q|0)!=0);q=wrc(e,g,4,0)|0;r=G;s=q}sD(d,s,r);lD(d,KGb(c[p>>2]|0)|0);q=LGb(c[p>>2]|0,10230592,0,2)|0;if((q|0)==0){break}else{t=q}do{mD(d,c[t>>2]|0)|0;mD(d,c[t+4>>2]|0)|0;t=LGb(c[p>>2]|0,10230592,t,2)|0;}while((t|0)!=0)}}while(0);kD(d,1635017060);t=fD(d,0,0,1)|0;p=f;c[p>>2]=t;c[p+4>>2]=G;sD(d,-1,-1);lD(d,0);eD(d);m=0;i=b;return m|0}function cF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+12>>2]|0;f=d+28|0;dD(c[b+16>>2]|0,c[d+24>>2]|0,c[f>>2]|0);if((c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+432>>2]|0)!=0){g=0;return g|0}b=e+8|0;d=c[b>>2]|0;h=e+16|0;i=(c[h>>2]|0)+5|0;do{if((i|0)<0){c[b>>2]=0}else{j=wJb(d,e+12|0,i)|0;c[b>>2]=j;if((j|0)==0){break}k=c[f>>2]|0;l=k>>28;if((l|0)==0){m=k}else{k=c[h>>2]|0;c[h>>2]=k+1;a[j+k|0]=l|128;m=c[f>>2]|0}l=m>>21;if((l|0)==0){n=m}else{k=c[h>>2]|0;c[h>>2]=k+1;a[(c[b>>2]|0)+k|0]=l|128;n=c[f>>2]|0}l=n>>14;if((l|0)==0){o=n}else{k=c[h>>2]|0;c[h>>2]=k+1;a[(c[b>>2]|0)+k|0]=l|128;o=c[f>>2]|0}l=o>>7;if((l|0)==0){p=o&255}else{k=c[h>>2]|0;c[h>>2]=k+1;a[(c[b>>2]|0)+k|0]=l|128;p=c[f>>2]&255}l=c[h>>2]|0;c[h>>2]=l+1;a[(c[b>>2]|0)+l|0]=p&127;l=e+20|0;c[l>>2]=(c[l>>2]|0)+1;g=0;return g|0}}while(0);kJb(d);g=-12;return g|0}function dF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[d+88>>2]|0)==0){f=b+8|0;mJb(f);return 0}a=fD(d,0,0,1)|0;g=G;h=b;fD(d,c[h>>2]|0,c[h+4>>2]|0,0)|0;i=c[h>>2]|0;j=c[h+4>>2]|0;h=wrc(a,g,-8,-1)|0;k=xrc(h,G,i,j)|0;sD(d,k,G);fD(d,a,g,0)|0;if((c[e+432>>2]|0)==0){kD(d,1953194352);g=b+16|0;a=(c[g>>2]|0)+24|0;sD(d,a,(a|0)<0|0?-1:0);a=b+20|0;k=c[a>>2]|0;sD(d,k,(k|0)<0|0?-1:0);k=c[a>>2]|0;a=c[e+48>>2]|0;j=c[e+416>>2]|0;if((a|0)==73728|(a|0)==86034|(a|0)==86076|(a|0)==86040){l=160}else if((a|0)==86016|(a|0)==86017){l=1152}else if((a|0)==69632){l=64}else if((a|0)==86035){l=j<<11}else if((a|0)==65540|(a|0)==65536|(a|0)==65537|(a|0)==65548|(a|0)==65549|(a|0)==65544|(a|0)==65545|(a|0)==65557|(a|0)==65556|(a|0)==65559|(a|0)==65558|(a|0)==65543|(a|0)==65542){l=1}else if((a|0)==69638){l=(((j*-14|0)+2048|0)/(j|0)|0)+2|0}else if((a|0)==86019){l=1536}else if((a|0)==86032){l=4096}else if((a|0)==86059){l=384}else if((a|0)==86046){l=320}else if((a|0)==86025|(a|0)==86026){l=6}else if((a|0)==69633){a=j<<2;l=((1024-a<<3|0)/(a|0)|0)+1|0}else{l=0}sD(d,ca(l,k)|0,0);lD(d,0);lD(d,0);dD(d,c[b+8>>2]|0,c[g>>2]|0);c[b+12>>2]=0}eD(d);f=b+8|0;mJb(f);return 0}function eF(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[b+8>>2]|0;do{if((e|0)>0){f=c[b+4>>2]|0;g=-256;h=0;i=0;j=0;k=0;a:while(1){l=d[f+k|0]|g;do{if((g|0)==256){if(l>>>0<432>>>0){if(l>>>0<j>>>0){m=0;n=14;break a}else{o=l}}else{o=0}if((l|0)==438|(l|0)==435){p=o;q=i;r=h+1|0;break}else if((l|0)==432){if((a[f+(k+1)|0]|0)==32){p=o;q=i+1|0;r=h;break}else{m=0;n=14;break a}}else{if((l|0)==436|l>>>0>439>>>0){m=0;n=14;break a}else{p=o;q=i;r=h;break}}}else{p=j;q=i;r=h}}while(0);s=k+1|0;if((s|0)<(e|0)){g=l<<8;h=r;i=q;j=p;k=s}else{n=11;break}}if((n|0)==11){if((q|0)==0){break}if((q*9|0|0)>(r*10|0|0)){break}else{m=50}return m|0}else if((n|0)==14){return m|0}}}while(0);m=0;return m|0}function fF(a){a=a|0;var b=0,d=0,e=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=0;c[e+48>>2]=133;_X(b,32,1,300);e=iD(c[a+16>>2]|0)|0;a=e;if((a|0)<=0){d=0;return d|0}e=(ca(c[b+44>>2]|0,a)|0)/7200|0;a=b+56|0;c[a>>2]=e;c[a+4>>2]=(e|0)<0|0?-1:0;d=0;return d|0}function gF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=d+24|0;f=b+16|0;b=fX(c[f>>2]|0,d,24)|0;a:do{if((b|0)<1){g=b}else{h=b;while(1){if((a[c[e>>2]|0]&63)==9){g=h;break a}P1(d);i=fX(c[f>>2]|0,d,24)|0;if((i|0)<1){g=i;break}else{h=i}}}}while(0);c[d+32>>2]=0;f=d+64|0;b=Crc(c[f>>2]|0,c[f+4>>2]|0,24,0)|0;f=G;h=d+8|0;c[h>>2]=b;c[h+4>>2]=f;h=d+16|0;c[h>>2]=b;c[h+4>>2]=f;if((g|0)<=5){return g|0}f=c[e>>2]|0;if(!((a[f]&63)==9)){return g|0}if(!((a[f+1|0]&63)==1)){return g|0}if(!((a[f+5|0]&15)==0)){return g|0}c[d+36>>2]=1;return g|0}function hF(b){b=b|0;var e=0,f=0,g=0,h=0;if((c[b+8>>2]|0)<32){e=0;return e|0}f=c[b+4>>2]|0;b=f+24|0;g=b|0;h=b+4|0;if(!((d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)==0&(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)==0)){e=0;return e|0}h=f+10|0;if(!((d[h]|d[h+1|0]<<8)<<16>>16<<16>>16==0)){e=0;return e|0}if((a[f]|0)!=1){e=0;return e|0}h=f+20|0;g=he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0;if((g&65535)>>>0>512>>>0){e=0;return e|0}if((a[f+18|0]|0)!=0){e=0;return e|0}if((a[f+19|0]|0)==0){e=0;return e|0}h=f+14|0;if((d[h]|d[h+1|0]<<8)<<16>>16<<16>>16==0){e=0;return e|0}h=f+16|0;if((d[h]|d[h+1|0]<<8)<<16>>16<<16>>16==0){e=0;return e|0}h=f+2|0;b=je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;h=f+22|0;if(b>>>0<((g&65535)+32+((he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>0){e=0;return e|0}h=f+6|0;g=f+12|0;e=((d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)==0?60:30)>>>(((d[g]|d[g+1|0]<<8)<<16>>16<<16>>16!=256|0)>>>0);return e|0}function iF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+12>>2]|0;e=d+8|0;f=c[e>>2]|0;do{if((f|0)!=0){g=cKb(d+12|0,f)|0;if((g|0)>=0){break}KIb(a,16,2271288,(h=i,i=i+8|0,c[h>>2]=c[e>>2],h)|0);i=h;j=g;i=b;return j|0}}while(0);c[d+20>>2]=0;c[d+56>>2]=-1;c[d+60>>2]=-1;d=a+20|0;c[d>>2]=c[d>>2]|1;j=0;i=b;return j|0}function jF(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;g=c[b+12>>2]|0;h=c[b+16>>2]|0;if((jD(h)|0)!=0){j=-541478725;i=f;return j|0}k=fD(h,0,0,1)|0;l=G;m=g+20|0;n=g+24|0;do{if((c[m>>2]|0)==0){if((AD(h,n,32)|0)==32){break}else{j=-541478725}i=f;return j|0}}while(0);if((a[n]|0)!=1){KIb(b,16,2326720,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;j=-1094995529;i=f;return j|0}o=g+26|0;p=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=g+38|0;q=he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0;o=g+40|0;r=he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0;o=g+44|0;s=he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0;o=g+46|0;t=(d[o]|d[o+1|0]<<8)<<16>>16;o=he(t|0)|0;u=q&65535;q=r&65535;r=ca(u+15&131056,q)|0;v=((ca(r,d[g+43|0]|0)|0)>>>3)+(s&65535)|0;if((s&65535)>>>0>512>>>0){j=-1094995529;i=f;return j|0}s=0;r=wrc(o&65535,0,32,0)|0;w=wrc(r,G,v,0)|0;r=G;if(s>>>0<r>>>0|s>>>0==r>>>0&p>>>0<w>>>0){j=-1094995529;i=f;return j|0}do{if((c[m>>2]|0)==0){x=18}else{w=o&65535;if(t<<16>>16==0){x=18;break}r=g+60|0;if((c[r>>2]|0)==-1){s=ZX(b,0)|0;if((s|0)==0){j=-12;i=f;return j|0}y=c[s+8>>2]|0;c[y+8>>2]=1;c[y+52>>2]=0;c[y+48>>2]=65540;z=y+416|0;if((a[g+25|0]&16)==0){c[z>>2]=1;A=y+448|0;c[A>>2]=4;c[A+4>>2]=0}else{c[z>>2]=2;z=y+448|0;c[z>>2]=3;c[z+4>>2]=0}z=g+4|0;c[y+412>>2]=c[z>>2];y=s+48|0;c[y>>2]=0;c[y+4>>2]=0;c[r>>2]=c[s>>2];_X(s,64,1,c[z>>2]|0)}z=fX(h,e,w)|0;if((z|0)<0){j=z;i=f;return j|0}else{c[e+32>>2]=c[r>>2];r=e+64|0;c[r>>2]=k;c[r+4>>2]=l;c[e+48>>2]=w;c[m>>2]=0;B=z;break}}}while(0);do{if((x|0)==18){z=g+56|0;do{if((c[z>>2]|0)==-1){w=ZX(b,0)|0;if((w|0)==0){j=-12;i=f;return j|0}r=c[w+8>>2]|0;c[r+8>>2]=0;c[r+52>>2]=0;c[r+48>>2]=160;c[r+120>>2]=u;c[r+124>>2]=q;r=w+48|0;c[r>>2]=0;c[r+4>>2]=0;c[z>>2]=c[w>>2];if((c[g+8>>2]|0)==0){_X(w,64,1,c[g+4>>2]|0);break}else{_X(w,64,c[g+16>>2]|0,c[g+12>>2]|0);break}}}while(0);if((K1(e,v+32|0)|0)<0){j=-12;i=f;return j|0}w=e+24|0;nrc(c[w>>2]|0,n|0,32)|0;r=AD(h,(c[w>>2]|0)+32|0,v)|0;if((r|0)<0){P1(e);j=r;i=f;return j|0}M1(e,r+32|0);c[e+32>>2]=c[z>>2];w=e+36|0;c[w>>2]=c[w>>2]|1;w=e+64|0;c[w>>2]=k;c[w+4>>2]=l;if((c[g+8>>2]|0)==0){w=o&65535;C=t<<16>>16==0?220:w;D=w}else{C=1;D=o&65535}c[e+48>>2]=C;c[m>>2]=D;if(t<<16>>16==0){B=r;break}else{j=r}i=f;return j|0}}while(0);hD(h,p-32-(o&65535)-v|0,0)|0;j=B;i=f;return j|0}function kF(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,2523200,20)|0)!=0;return(b?0:100)|0}function lF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;d=i;i=i+4120|0;e=d|0;f=d+8|0;g=d+4104|0;h=d+4112|0;j=b+12|0;k=c[j>>2]|0;l=b+16|0;m=f|0;n=KD(c[l>>2]|0,m,4096)|0;a:do{if((n|0)<1){o=n;p=63}else{q=k+20|0;r=e;s=b+32|0;t=0;u=0;v=0;b:while(1){w=u+16|0;c:do{if((u|0)==0){x=v;while(1){y=x+1|0;c[g>>2]=m;z=ud(m|0,2271280)|0;A=f+z|0;c[g>>2]=A;B=mc(A|0,2271280)|0;C=f+(B+z)|0;c[g>>2]=C;if((a[C]|0)==0){D=C}else{E=z+1+B|0;B=f+E|0;c[g>>2]=B;a[C]=0;C=f+(E+(ud(B|0,2271280)|0))|0;c[g>>2]=C;D=C}C=a[A]|0;do{if(!((C<<24>>24|0)==0|(C<<24>>24|0)==35)){if((irc(A,2326712)|0)==0){F=y;break c}if((irc(A,2187256)|0)==0){p=18;break b}if((irc(A,2109136)|0)!=0){H=y;I=A;p=62;break b}B=ud(D|0,2271280)|0;E=D+B|0;c[g>>2]=E;z=mc(E|0,2271280)|0;J=D+(z+B)|0;c[g>>2]=J;if((a[J]|0)==0){K=J}else{c[g>>2]=D+(B+1+z);a[J]=0;J=c[g>>2]|0;z=J+(ud(J|0,2271280)|0)|0;c[g>>2]=z;K=z}z=ud(K|0,2271280)|0;J=K+z|0;c[g>>2]=J;B=mc(J|0,2271280)|0;L=K+(B+z)|0;c[g>>2]=L;if((a[L]|0)!=0){c[g>>2]=K+(z+1+B);a[L]=0;L=c[g>>2]|0;c[g>>2]=L+(ud(L|0,2271280)|0)}if((irc(E,2626984)|0)!=0){M=y;p=59;break b}if((irc(J,2601560)|0)!=0){M=y;p=59;break b}if((c[q>>2]|0)>=0){break}c[q>>2]=1}}while(0);A=KD(c[l>>2]|0,m,4096)|0;if((A|0)<1){o=A;p=63;break a}else{x=y}}}else{x=v;while(1){N=x+1|0;c[g>>2]=m;A=ud(m|0,2271280)|0;C=f+A|0;c[g>>2]=C;J=mc(C|0,2271280)|0;E=f+(J+A)|0;c[g>>2]=E;if((a[E]|0)==0){O=E}else{L=A+1+J|0;J=f+L|0;c[g>>2]=J;a[E]=0;E=f+(L+(ud(J|0,2271280)|0))|0;c[g>>2]=E;O=E}E=a[C]|0;do{if(!((E<<24>>24|0)==0|(E<<24>>24|0)==35)){if((irc(C,2326712)|0)==0){F=N;break c}if((irc(C,2187256)|0)==0){J=ud(O|0,2271280)|0;P=O+J|0;c[g>>2]=P;L=mc(P|0,2271280)|0;A=O+(L+J)|0;c[g>>2]=A;if((a[A]|0)!=0){c[g>>2]=O+(J+1+L);a[A]=0;A=c[g>>2]|0;c[g>>2]=A+(ud(A|0,2271280)|0)}Q=iKb(h,P,1)|0;if((Q|0)<0){p=49;break b}A=c[h+4>>2]|0;c[w>>2]=c[h>>2];c[w+4>>2]=A;break}if((irc(C,2109136)|0)!=0){H=N;I=C;p=62;break b}A=ud(O|0,2271280)|0;L=O+A|0;c[g>>2]=L;J=mc(L|0,2271280)|0;B=O+(J+A)|0;c[g>>2]=B;if((a[B]|0)==0){R=B}else{c[g>>2]=O+(A+1+J);a[B]=0;B=c[g>>2]|0;J=B+(ud(B|0,2271280)|0)|0;c[g>>2]=J;R=J}J=ud(R|0,2271280)|0;B=R+J|0;c[g>>2]=B;A=mc(B|0,2271280)|0;z=R+(A+J)|0;c[g>>2]=z;if((a[z]|0)!=0){c[g>>2]=R+(J+1+A);a[z]=0;z=c[g>>2]|0;c[g>>2]=z+(ud(z|0,2271280)|0)}if((irc(L,2626984)|0)!=0){M=N;p=59;break b}if((irc(B,2601560)|0)!=0){M=N;p=59;break b}if((c[q>>2]|0)>=0){break}c[q>>2]=1}}while(0);C=KD(c[l>>2]|0,m,4096)|0;if((C|0)<1){o=C;p=63;break a}else{x=N}}}}while(0);S=GFb(g,2271280)|0;if((S|0)==0){p=26;break}c[e>>2]=S;w=c[j>>2]|0;do{if((c[w+20>>2]|0)>0){x=a[S]|0;if(x<<24>>24==0){break}else{T=S;U=S;V=x}while(1){x=V<<24>>24;do{if(((x|32)-97|0)>>>0<26>>>0|(x-48|0)>>>0<10>>>0){W=U}else{if((V<<24>>24|0)==95|(V<<24>>24|0)==45){W=U;break}if((T|0)==(U|0)){p=35;break b}if((V<<24>>24|0)==46){W=U;break}else if((V<<24>>24|0)!=47){p=35;break b}W=T+1|0}}while(0);x=T+1|0;C=a[x]|0;if(C<<24>>24==0){break}else{T=x;U=W;V=C}}}}while(0);C=lrc(s|0)|0;x=C+16+(lrc(S|0)|0)|0;C=hJb(x)|0;if((C|0)==0){X=0;Y=-12;break}_W(C,x,s,S);mJb(r);x=w+12|0;E=c[x>>2]|0;if(E>>>0<t>>>0){Z=E;_=c[w+4>>2]|0;$=t}else{B=t<<1;L=B>>>0>16>>>0?B:16;if(L>>>0<=E>>>0|L>>>0>178956970>>>0){X=C;Y=-12;break}E=w+4|0;B=iJb(c[E>>2]|0,L*24|0)|0;if((B|0)==0){X=C;Y=-12;break}z=B;c[E>>2]=z;Z=c[x>>2]|0;_=z;$=L}c[x>>2]=Z+1;x=_+(Z*24|0)|0;mrc(x|0,0,24)|0;c[x>>2]=C;C=_+(Z*24|0)+8|0;c[C>>2]=0;c[C+4>>2]=-2147483648;C=_+(Z*24|0)+16|0;c[C>>2]=0;c[C+4>>2]=-2147483648;C=KD(c[l>>2]|0,m,4096)|0;if((C|0)<1){o=C;p=63;break a}else{t=$;u=x;v=F}}if((p|0)==18){v=ud(D|0,2271280)|0;u=D+v|0;c[g>>2]=u;t=mc(u|0,2271280)|0;u=D+(t+v)|0;c[g>>2]=u;if((a[u]|0)!=0){c[g>>2]=D+(v+1+t);a[u]=0;u=c[g>>2]|0;c[g>>2]=u+(ud(u|0,2271280)|0)}KIb(b,16,2157416,(aa=i,i=i+8|0,c[aa>>2]=y,aa)|0);i=aa;ba=-1094995529;break}else if((p|0)==26){KIb(b,16,2222264,(aa=i,i=i+8|0,c[aa>>2]=F,aa)|0);i=aa;ba=-1094995529;break}else if((p|0)==35){KIb(b,16,2540048,(aa=i,i=i+8|0,c[aa>>2]=S,aa)|0);i=aa;X=0;Y=-1}else if((p|0)==49){KIb(b,16,2132200,(aa=i,i=i+16|0,c[aa>>2]=N,c[aa+8>>2]=P,aa)|0);i=aa;ba=Q;break}else if((p|0)==59){KIb(b,16,2576304,(aa=i,i=i+8|0,c[aa>>2]=M,aa)|0);i=aa;ba=-1094995529;break}else if((p|0)==62){KIb(b,16,2557328,(aa=i,i=i+16|0,c[aa>>2]=H,c[aa+8>>2]=I,aa)|0);i=aa;ba=-1094995529;break}kJb(X);kJb(c[e>>2]|0);ba=Y}}while(0);d:do{if((p|0)==63){if((o|0)<0){ba=o;break}Y=c[k+12>>2]|0;if((Y|0)==0){ba=-1094995529;break}e=c[k+4>>2]|0;X=0;aa=0;I=0;while(1){H=e+(I*24|0)+8|0;M=c[H>>2]|0;Q=c[H+4>>2]|0;if((M|0)==0&(Q|0)==(-2147483648|0)){c[H>>2]=aa;c[H+4>>2]=X;ca=X;da=aa}else{ca=Q;da=M}M=e+(I*24|0)+16|0;Q=c[M>>2]|0;H=c[M+4>>2]|0;if((Q|0)==0&(H|0)==(-2147483648|0)){ea=ca;fa=da;ga=I;break}M=wrc(Q,H,da,ca)|0;H=G;Q=I+1|0;if(Q>>>0<Y>>>0){X=H;aa=M;I=Q}else{ea=H;fa=M;ga=Q;break}}if((ga|0)==(Y|0)){I=b+1064|0;c[I>>2]=fa;c[I+4>>2]=ea;c[k+24>>2]=1}I=pF(b,0)|0;if((I|0)<0){ba=I;break}I=k+16|0;if((c[(c[I>>2]|0)+24>>2]|0)==0){ha=0;i=d;return ha|0}else{ia=0}while(1){aa=ZX(b,0)|0;if((aa|0)==0){ba=-12;break d}X=c[(c[(c[I>>2]|0)+28>>2]|0)+(ia<<2)>>2]|0;e=nWa(c[aa+8>>2]|0,c[X+8>>2]|0)|0;if((e|0)<0){ba=e;break d}e=X+412|0;Q=aa+412|0;M=c[e+4>>2]|0;c[Q>>2]=c[e>>2];c[Q+4>>2]=M;M=X+92|0;Q=aa+92|0;e=c[M+4>>2]|0;c[Q>>2]=c[M>>2];c[Q+4>>2]=e;e=X+40|0;Q=aa+40|0;M=c[e+4>>2]|0;c[Q>>2]=c[e>>2];c[Q+4>>2]=M;M=X+80|0;X=aa+80|0;aa=c[M+4>>2]|0;c[X>>2]=c[M>>2];c[X+4>>2]=aa;aa=ia+1|0;if(aa>>>0<(c[(c[I>>2]|0)+24>>2]|0)>>>0){ia=aa}else{ha=0;break}}i=d;return ha|0}}while(0);ia=c[j>>2]|0;j=ia+16|0;if((c[j>>2]|0)!=0){YX(j)}j=ia+12|0;b=ia+4|0;if((c[j>>2]|0)!=0){ia=b;k=0;do{mJb((c[ia>>2]|0)+(k*24|0)|0);k=k+1|0;}while(k>>>0<(c[j>>2]|0)>>>0)}mJb(b);ha=ba;i=d;return ha|0}function mF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;e=d|0;f=a+12|0;g=c[f>>2]|0;h=g+16|0;while(1){j=uX(c[h>>2]|0,b)|0;if(!((j|0)==-541478725)){k=7;break}l=c[f>>2]|0;m=c[l+8>>2]|0;n=(m-(c[l+4>>2]|0)|0)/24|0;o=m+16|0;if((c[o>>2]|0)==0&(c[o+4>>2]|0)==(-2147483648|0)){m=(c[l+16>>2]|0)+1064|0;p=c[m+4>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=p}p=n+1|0;if(!(p>>>0<(c[l+12>>2]|0)>>>0)){q=-541478725;k=12;break}l=pF(a,p)|0;if((l|0)<0){q=l;k=12;break}}if((k|0)==7){if((j|0)<0){q=j;i=d;return q|0}a=(c[g+8>>2]|0)+8|0;g=c[h>>2]|0;h=g+1056|0;f=xrc(c[a>>2]|0,c[a+4>>2]|0,c[h>>2]|0,c[h+4>>2]|0)|0;c[e>>2]=1;c[e+4>>2]=1e6;h=XIb(f,G,e,(c[(c[g+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0)+40|0)|0;g=G;e=b+8|0;f=c[e>>2]|0;a=c[e+4>>2]|0;if(!((f|0)==0&(a|0)==(-2147483648|0))){l=wrc(f,a,h,g)|0;c[e>>2]=l;c[e+4>>2]=G}e=b+16|0;b=c[e>>2]|0;l=c[e+4>>2]|0;if((b|0)==0&(l|0)==(-2147483648|0)){q=j;i=d;return q|0}a=wrc(b,l,h,g)|0;c[e>>2]=a;c[e+4>>2]=G;q=j;i=d;return q|0}else if((k|0)==12){i=d;return q|0}return 0}function nF(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;a=b+16|0;if((c[a>>2]|0)!=0){YX(a)}a=b+12|0;d=b+4|0;if((c[a>>2]|0)==0){mJb(d);return 0}b=d;e=0;do{mJb((c[b>>2]|0)+(e*24|0)|0);e=e+1|0;}while(e>>>0<(c[a>>2]|0)>>>0);mJb(d);return 0}function oF(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+24|0;m=l|0;n=l+8|0;o=l+16|0;p=a+12|0;q=c[p>>2]|0;r=q+8|0;s=c[r>>2]|0;t=q+16|0;c[o>>2]=c[t>>2];if((c[q+24>>2]|0)==0){u=-29;i=l;return u|0}if((k&10|0)!=0){u=-38;i=l;return u|0}c[t>>2]=0;q=c[p>>2]|0;do{if((b|0)>-1){if(!((c[a+24>>2]|0)>>>0>b>>>0)){v=-22;break}w=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;x=c[w+40>>2]|0;y=c[w+44>>2]|0;c[m>>2]=1;c[m+4>>2]=1e6;c[n>>2]=x;c[n+4>>2]=y;y=XIb(f,g,n,m)|0;x=G;w=WIb(d,e,n,m,8195)|0;z=G;A=WIb(h,j,n,m,8194)|0;B=G;C=A;D=x;E=y;F=z;H=w;I=6}else{B=j;C=h;D=g;E=f;F=e;H=d;I=6}}while(0);do{if((I|0)==6){d=q+12|0;e=c[d>>2]|0;if((e|0)>1){f=c[q+4>>2]|0;g=0;h=e;while(1){e=(g+h|0)/2|0;j=f+(e*24|0)+8|0;m=c[j+4>>2]|0;n=(D|0)<(m|0)|(D|0)==(m|0)&E>>>0<(c[j>>2]|0)>>>0;j=n?g:e;m=n?e:h;if((m-j|0)>1){g=j;h=m}else{J=j;break}}}else{J=0}h=pF(a,J)|0;if((h|0)<0){v=h;break}h=qF(c[p>>2]|0,b,H,F,E,D,C,B,k)|0;if((h|0)<0){if(!(J>>>0<((c[d>>2]|0)-1|0)>>>0)){v=h;break}g=J+1|0;f=(c[q+4>>2]|0)+(g*24|0)+8|0;j=c[f+4>>2]|0;if((j|0)<(B|0)|(j|0)==(B|0)&(c[f>>2]|0)>>>0<C>>>0){f=pF(a,g)|0;if((f|0)<0){v=f;break}K=qF(c[p>>2]|0,b,H,F,E,D,C,B,k)|0}else{K=h}if((K|0)<0){v=K;break}else{L=K}}else{L=h}YX(o);u=L;i=l;return u|0}}while(0);if((c[t>>2]|0)!=0){YX(t)}c[t>>2]=c[o>>2];c[r>>2]=s;u=v;i=l;return u|0}function pF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;e=c[a+12>>2]|0;f=e+4|0;g=c[f>>2]|0;h=g+(b*24|0)|0;j=e+16|0;if((c[j>>2]|0)!=0){YX(j)}k=HR()|0;c[j>>2]=k;if((k|0)==0){l=-12;i=d;return l|0}m=a+1160|0;n=k+1160|0;k=c[m+4>>2]|0;c[n>>2]=c[m>>2];c[n+4>>2]=k;k=h|0;n=oX(j,c[k>>2]|0,0,0)|0;do{if((n|0)<0){o=n}else{m=OX(c[j>>2]|0,0)|0;if((m|0)<0){o=m;break}c[e+8>>2]=h;m=g+(b*24|0)+8|0;if(!((c[m>>2]|0)==0&(c[m+4>>2]|0)==(-2147483648|0))){l=0;i=d;return l|0}if((b|0)==0){p=0;q=0}else{r=b-1|0;s=c[f>>2]|0;t=s+(r*24|0)+8|0;u=s+(r*24|0)+16|0;r=wrc(c[u>>2]|0,c[u+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;p=G;q=r}c[m>>2]=q;c[m+4>>2]=p;l=0;i=d;return l|0}}while(0);KIb(a,16,2401160,(a=i,i=i+8|0,c[a>>2]=c[k>>2],a)|0);i=a;YX(j);l=o;i=d;return l|0}function qF(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=i;i=i+16|0;m=l|0;n=l+8|0;o=(c[a+8>>2]|0)+8|0;p=a+16|0;a=c[p>>2]|0;q=a+1056|0;r=xrc(c[o>>2]|0,c[o+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;q=G;o=xrc(f,g,r,q)|0;g=G;f=(d|0)==0&(e|0)==(-2147483648|0);s=xrc(d,e,r,q)|0;e=f?0:s;s=f?-2147483648:G;f=(h|0)==(-1|0)&(j|0)==2147483647;d=xrc(h,j,r,q)|0;q=f?-1:d;d=f?2147483647:G;do{if((b|0)>-1){if((c[a+24>>2]|0)>>>0>b>>>0){f=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;r=c[f+44>>2]|0;c[m>>2]=c[f+40>>2];c[m+4>>2]=r;c[n>>2]=1;c[n+4>>2]=1e6;r=XIb(o,g,n,m)|0;f=G;j=WIb(e,s,n,m,8195)|0;h=G;t=WIb(q,d,n,m,8194)|0;u=G;v=t;w=f;x=r;y=h;z=j;A=c[p>>2]|0;break}else{B=-5;i=l;return B|0}}else{u=d;v=q;w=g;x=o;y=s;z=e;A=a}}while(0);B=HX(A,b,z,y,x,w,v,u,k)|0;i=l;return B|0}function rF(a){a=a|0;c[c[a+12>>2]>>2]=1;return 0}function sF(a,b){a=a|0;b=b|0;var d=0;d=c[a+12>>2]|0;c[d>>2]=oFb(c[d>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0)|0;return 0}function tF(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+64|0;d=b|0;Rb(d|0,64,2401008,(e=i,i=i+8|0,c[e>>2]=c[c[a+12>>2]>>2],e)|0)|0;i=e;e=c[a+16>>2]|0;dD(e,d,lrc(d|0)|0);i=b;return 0}function uF(a){a=a|0;var b=0,d=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=65552;c[a+52>>2]=1685414244;c[a+416>>2]=6;b=a+448|0;c[b>>2]=1551;c[b+4>>2]=0;c[a+412>>2]=96e3;c[a+72>>2]=13824e3;c[a+432>>2]=18;c[a+792>>2]=24;d=0;return d|0}function vF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+16>>2]|0;if((jD(d)|0)!=0){e=-5;return e|0}a=HD(d)|0;HD(d)|0;f=fX(d,b,a)|0;c[b+32>>2]=0;e=f;return e|0}function wF(a){a=a|0;var b=0;b=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[b+416>>2]|0)==6){return((c[b+412>>2]|0)!=96e3)<<31>>31|0}else{return-1|0}return 0}function xF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=b+28|0;f=c[e>>2]|0;if((f|0)>65535){KIb(a,16,2271152,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-1;i=d;return h|0}else{g=a+16|0;tD(c[g>>2]|0,f);tD(c[g>>2]|0,32784);dD(c[g>>2]|0,c[b+24>>2]|0,c[e>>2]|0);h=0;i=d;return h|0}return 0}function yF(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<4){b=0;return b|0}e=c[a+4>>2]|0;a=e;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=1095321156){b=0;return b|0}a=e+16|0;b=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==128?100:25;return b|0}function zF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[b+16>>2]|0;if((FD(e)|0)!=1095321156){KIb(b,16,2271088,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1094995529;i=d;return g|0}h=DD(e)|0;j=DD(e)|0;k=ZX(b,0)|0;if((k|0)==0){g=-12;i=d;return g|0}l=k+8|0;m=c[l>>2]|0;c[m+8>>2]=0;c[m+48>>2]=151;m=DD(e)|0;c[(c[l>>2]|0)+120>>2]=m;m=DD(e)|0;c[(c[l>>2]|0)+124>>2]=m;m=FD(e)|0;if((m|0)==0){KIb(b,24,2222128,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;n=100}else{n=m}_X(k,24,n,1e3);hD(e,112,0)|0;e=k+56|0;c[e>>2]=j;c[e+4>>2]=(j|0)<0|0?-1:0;if((PX(c[l>>2]|0,2)|0)!=0){g=-12;i=d;return g|0}j=c[(c[l>>2]|0)+96>>2]|0;y=h&65535;a[j]=y;y=y>>8;a[j+1|0]=y;if((h|0)!=256){g=0;i=d;return g|0}c[k+80>>2]=2;c[k+84>>2]=1;g=0;i=d;return g|0}function AF(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[a+16>>2]|0;g=f+52|0;if((c[g>>2]|0)!=0){h=-541478725;i=e;return h|0}if((fX(f,b,12)|0)!=12){h=-5;i=e;return h|0}j=b+24|0;k=b+28|0;l=1;while(1){if((c[g>>2]|0)!=0){h=0;m=15;break}if((l|0)==0){n=hX(f,b,12)|0;if((n|0)<0){m=7;break}}o=c[j>>2]|0;p=c[k>>2]|0;q=o+(p-8)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;if(r>>>0>2147483643>>>0){m=9;break}q=o+(p-12)|0;if((d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)==1380339525){m=11;break}s=hX(f,b,r)|0;if((s|0)<0){m=14;break}else{l=0}}if((m|0)==7){P1(b);h=n;i=e;return h|0}else if((m|0)==9){KIb(a,16,2400896,(t=i,i=i+8|0,c[t>>2]=r,t)|0);i=t;h=-5;i=e;return h|0}else if((m|0)==11){if((r|0)==0){h=0;i=e;return h|0}KIb(a,24,2326416,(t=i,i=i+8|0,c[t>>2]=r,t)|0);i=t;hD(f,r,0)|0;h=0;i=e;return h|0}else if((m|0)==14){P1(b);h=s;i=e;return h|0}else if((m|0)==15){i=e;return h|0}return 0}function BF(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[a+4>>2]|0;e=b;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)!=1145258562){f=0;return f|0}e=b+5|0;g=je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;if(g>>>0<13>>>0){f=0;return f|0}e=wrc(g,0,13,0)|0;h=G;i=c[a+8>>2]|0;a=(i|0)<0|0?-1:0;if((h|0)>(a|0)|(h|0)==(a|0)&e>>>0>i>>>0){f=25;return f|0}i=b+g|0;f=(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)==1145258562?100:0;return f|0}function CF(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<44){b=0;return b|0}e=c[a+4>>2]|0;if((grc(e,1520392,5)|0)!=0){b=0;return b|0}a=e+26|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){b=0;return b|0}a=e+24|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){b=0;return b|0}a=e+40|0;e=((je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)-1235|0)>>>0>18>>>0;b=e?0:100;return b|0}function DF(b){b=b|0;var e=0;e=c[b+4>>2]|0;b=e;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)!=1437204480){return 0}b=e+12|0;if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)!=22050){return 0}if((a[e+16|0]|0)==16){return((a[e+17|0]|0)==0?100:0)|0}else{return 0}return 0}function EF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;if((FD(d)|0)!=1437204480){e=-1094995529;return e|0}c[b+8>>2]=FD(d)|0;f=b+12|0;c[f>>2]=DD(d)|0;g=b+16|0;c[g>>2]=DD(d)|0;h=b+20|0;c[h>>2]=FD(d)|0;i=b+24|0;c[i>>2]=zD(d)|0;j=b+28|0;c[j>>2]=zD(d)|0;c[b+32>>2]=DD(d)|0;if((c[h>>2]|0)!=22050){e=-1094995529;return e|0}if((c[i>>2]|0)!=16){e=-1094995529;return e|0}i=(c[j>>2]|0)==0;if(!i){e=i?0:-1094995529;return e|0}c[b+76>>2]=0;mrc(b+40|0,0,16)|0;i=ZX(a,0)|0;if((i|0)==0){e=-12;return e|0}_X(i,32,1,12);c[b+4>>2]=c[i>>2];j=c[i+8>>2]|0;c[j+8>>2]=0;c[j+48>>2]=95;c[j+52>>2]=0;c[j+120>>2]=c[f>>2];c[j+124>>2]=c[g>>2];g=ZX(a,0)|0;if((g|0)==0){e=-12;return e|0}_X(g,32,1,22050);c[b>>2]=c[g>>2];b=c[g+8>>2]|0;c[b+8>>2]=1;c[b+48>>2]=86042;c[b+52>>2]=0;c[b+416>>2]=1;g=b+448|0;c[g>>2]=4;c[g+4>>2]=0;c[b+412>>2]=22050;c[b+792>>2]=8;c[b+72>>2]=176400;e=0;return e|0}function FF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+12>>2]|0;f=c[b+16>>2]|0;b=e+76|0;g=c[b>>2]|0;if((g|0)!=0){h=fX(f,d,g)|0;if((h|0)<0){i=h;return i|0}c[d+32>>2]=c[e>>2];h=e+40|0;g=c[h>>2]|0;j=c[h+4>>2]|0;k=d+8|0;c[k>>2]=g;c[k+4>>2]=j;k=(c[b>>2]|0)-((g|0)==0&(j|0)==0&1)|0;c[d+48>>2]=k;j=wrc(k,(k|0)<0|0?-1:0,c[h>>2]|0,c[h+4>>2]|0)|0;c[h>>2]=j;c[h+4>>2]=G;c[b>>2]=0;i=0;return i|0}h=e+60|0;c[h>>2]=zD(f)|0;c[e+56>>2]=zD(f)|0;j=e+64|0;c[j>>2]=DD(f)|0;k=e+72|0;c[k>>2]=FD(f)|0;g=e+68|0;c[g>>2]=FD(f)|0;if((jD(f)|0)!=0){i=-5;return i|0}if((c[f+76>>2]|0)!=0){i=-5;return i|0}if(!((FD(f)|0)==-1437226411)){i=-1094995529;return i|0}l=c[k>>2]|0;if((l|0)<0){i=-1094995529;return i|0}k=c[g>>2]>>31&-1094995529;if((k|0)!=0){i=k;return i|0}k=c[j>>2]|0;m=k<<16;if((m|0)<0){n=-(m>>16)|0;c[j>>2]=n;o=1;p=n}else{o=0;p=k}k=eX(f,(ca(o+3|0,p)|0)+l|0)|0;l=K1(d,k+4|0)|0;if((l|0)<0){i=l;return i|0}c[d+32>>2]=c[e+4>>2];l=e+48|0;e=c[l>>2]|0;p=c[l+4>>2]|0;n=wrc(e,p,1,0)|0;c[l>>2]=n;c[l+4>>2]=G;l=d+8|0;c[l>>2]=e;c[l+4>>2]=p;p=d+24|0;a[c[p>>2]|0]=o;a[(c[p>>2]|0)+1|0]=c[j>>2];a[(c[p>>2]|0)+2|0]=(c[j>>2]|0)>>>8;a[(c[p>>2]|0)+3|0]=c[h>>2];h=AD(f,(c[p>>2]|0)+4|0,k)|0;if((h|0)<0){P1(d);i=h;return i|0}if((h|0)<(k|0)){M1(d,h+4|0)}c[b>>2]=c[g>>2];i=0;return i|0}function GF(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;b=i;i=i+16|0;e=b|0;mrc(e|0,0,12)|0;f=c[a+8>>2]|0;g=f-2|0;a:do{if((g|0)>0){h=c[a+4>>2]|0;j=e|0;k=e+4|0;l=e+8|0;m=h;n=-65536;o=0;p=0;q=0;r=0;s=0;while(1){t=m+2|0;u=m;v=(he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535;w=v|n;do{if((w|0)==536864768){x=t;if(!(((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&-16)<<16>>16==2032)){y=q;z=r;A=s;break}x=r+1|0;c[k>>2]=x;y=q;z=x;A=s}else if((w|0)==(-25230976|0)|(w|0)==2147385345){x=q+1|0;c[j>>2]=x;y=x;z=r;A=s}else if((w|0)==(-14745368|0)){x=t;if(!(((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&-3841)<<16>>16==-4089)){y=q;z=r;A=s;break}x=s+1|0;c[l>>2]=x;y=q;z=r;A=x}else{y=q;z=r;A=s}}while(0);if((m-h|0)>3){w=m-4|0;x=((d[u]|d[u+1|0]<<8)<<16>>16&65535)-((d[w]|d[w+1|0]<<8)<<16>>16&65535)|0;w=(x|0)>-1?x:-x|0;x=wrc(w,(w|0)<0|0?-1:0,p,o)|0;B=G;C=x}else{B=o;C=p}if(!(t>>>0<(h+g|0)>>>0)){D=B;E=C;F=y;H=z;I=A;break a}m=t;n=v<<16;o=B;p=C;q=y;r=z;s=A}}else{D=0;E=0;F=0;H=0;I=0}}while(0);A=H+F+I|0;z=(H|0)>(F|0)|0;F=c[e+(((I|0)>(c[e+(z<<2)>>2]|0)?2:z)<<2)>>2]|0;do{if((F|0)>3){if(((f|0)/(F|0)|0|0)>=32768){break}if((F<<2|0)<=(A*3|0|0)){break}z=Crc(E,D,f,(f|0)<0|0?-1:0)|0;e=G;I=0;if((e|0)>(I|0)|(e|0)==(I|0)&z>>>0>200>>>0){J=51}else{break}i=b;return J|0}}while(0);J=0;i=b;return J|0}function HF(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b|0;e=b+4|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0;a=(je(b|0)|0)==1145586770&(e|0)==1146377032;return(a?100:0)|0}function IF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=ZX(b,0)|0;if((g|0)==0){h=-12;i=d;return h|0}j=c[g+8>>2]|0;c[j+8>>2]=1;c[j+48>>2]=86020;c[g+236>>2]=1463898624;if((jD(f)|0)!=0){h=-541478725;i=d;return h|0}g=b+1140|0;a:while(1){j=OD(f)|0;k=G;l=OD(f)|0;m=G;n=0;if(m>>>0<n>>>0|m>>>0==n>>>0&l>>>0<4>>>0){o=5;break}n=536870912;if(m>>>0>n>>>0|m>>>0==n>>>0&l>>>0>0>>>0){o=7;break}n=1145132097;p=1398035021;do{if((j|0)==1229866575&(k|0)==1179208773){q=0;if(m>>>0>q>>>0|m>>>0==q>>>0&l>>>0>2147483647>>>0){o=13;break}q=l;r=hJb(q)|0;if((r|0)==0){o=13;break}AD(f,r,q)|0;q=wrc(l,m,-1,0)|0;a[r+q|0]=0;MGb(g,2270928,r,8)|0}else if((j|0)==(n|0)&(k|0)==(p|0)){o=9;break a}else{o=13}}while(0);if((o|0)==13){o=0;p=hD(f,l,m)|0;k=p;if((k|0)<0){h=k;o=15;break}}if((jD(f)|0)!=0){h=-541478725;o=15;break}}if((o|0)==5){KIb(b,16,2400688,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;h=-1094995529;i=d;return h|0}else if((o|0)==7){KIb(b,16,2326256,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;h=-1094995529;i=d;return h|0}else if((o|0)==9){s=fD(f,0,0,1)|0;f=wrc(s,G,l,m)|0;s=G;b=e;c[b>>2]=f;c[b+4>>2]=s;h=s>>>0>m>>>0|s>>>0==m>>>0&f>>>0>l>>>0?0:-1094995529;i=d;return h|0}else if((o|0)==15){i=d;return h|0}return 0}function JF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=a+16|0;a=fD(c[d>>2]|0,0,0,1)|0;g=xrc(e,f,a,G)|0;a=G;f=0;e=(a|0)>(f|0)|(a|0)==(f|0)&g>>>0>1024>>>0;f=e?1024:g;g=e?0:a;a=0;if((g|0)<(a|0)|(g|0)==(a|0)&f>>>0<1>>>0){h=-541478725;return h|0}a=fX(c[d>>2]|0,b,f)|0;if((a|0)<0){h=a;return h|0}c[b+32>>2]=0;h=a;return h|0}function KF(a){a=a|0;var b=0,d=0,e=0;b=pJb(33136)|0;if((b|0)==0){d=0;return d|0}e=ZX(a,0)|0;c[b+8>>2]=e;if((e|0)==0){kJb(b);d=0;return d|0}else{c[b+4>>2]=a;a=c[e+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=25;c[a+72>>2]=25e6;a=e+48|0;c[a>>2]=0;c[a+4>>2]=0;d=b;return d|0}return 0}function LF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+33120>>2]|0;if((d|0)>0){e=0}else{f=-1;return f|0}while(1){if((c[a+12+(e<<2)>>2]|0)!=0){g=a+32+(e*80|0)+28|0;if((c[g>>2]|0)!=0){break}}h=e+1|0;if((h|0)<(d|0)){e=h}else{f=-1;i=6;break}}if((i|0)==6){return f|0}nrc(b|0,a+32+(e*80|0)|0,80)|0;c[g>>2]=0;f=c[b+28>>2]|0;return f|0}function MF(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;k=i;i=i+48|0;l=k|0;m=k+8|0;n=k+24|0;mrc(n|0,0,20)|0;if((g|0)<480){o=-1;i=k;return o|0}p=b|0;q=Tba(c[p>>2]|0,f,g)|0;c[p>>2]=q;if((q|0)==0){o=-1;i=k;return o|0}if((c[q+8>>2]|0)>(g|0)){o=-1;i=k;return o|0}g=f+4323|0;r=(a[g]|0)==80?g:0;a:do{if((r|0)==0){c[b+33120>>2]=0;s=0;t=63}else{u=a[r+1|0]&63;v=d[r+4|0]|0;w=v>>>3&7;x=a[r+3|0]&31;y=v&7;if(w>>>0>2>>>0){KIb(c[b+4>>2]|0,16,2576224,(z=i,i=i+8|0,c[z>>2]=w,z)|0);i=z;A=0;B=c[b+33120>>2]|0}else{if(x>>>0>3>>>0){KIb(c[b+4>>2]|0,16,2557280,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z;c[b+33120>>2]=0;s=0;t=63;break}c[m>>2]=1;c[m+4>>2]=0;c[m+8>>2]=2;c[m+12>>2]=4;v=c[m+(x<<2)>>2]|0;x=(y|0)!=0&(v|0)==1&(w|0)==2?2:v;v=b+4|0;if((x|0)>0){y=1518072+(w<<2)|0;C=0;while(1){D=b+12+(C<<2)|0;E=c[D>>2]|0;if((E|0)==0){F=ZX(c[v>>2]|0,0)|0;c[D>>2]=F;if((F|0)==0){H=C;break}_X(F,64,1,3e4);F=c[(c[D>>2]|0)+8>>2]|0;c[F+8>>2]=1;c[F+48>>2]=65536;J1(b+32+(C*80|0)|0);c[b+32+(C*80|0)+28>>2]=0;c[b+32+(C*80|0)+24>>2]=b+352+(C<<13);c[b+32+(C*80|0)+32>>2]=c[c[D>>2]>>2];F=b+32+(C*80|0)+36|0;c[F>>2]=c[F>>2]|1;I=c[D>>2]|0}else{I=E}E=c[y>>2]|0;D=c[I+8>>2]|0;c[D+412>>2]=E;c[D+416>>2]=2;F=D+448|0;c[F>>2]=3;c[F+4>>2]=0;c[D+72>>2]=E<<5;E=I+48|0;c[E>>2]=0;c[E+4>>2]=0;E=C+1|0;if((E|0)<(x|0)){C=E}else{H=E;break}}J=H;K=c[p>>2]|0}else{J=0;K=q}c[b+33120>>2]=J;A=(c[K+80+(w<<2)>>2]|0)+u<<2;B=J}C=b+33120|0;if((B|0)>0){x=b+33128|0;y=0;while(1){v=b+32+(y*80|0)+64|0;c[v>>2]=h;c[v+4>>2]=j;c[b+32+(y*80|0)+28>>2]=A;v=Erc(c[x>>2]|0,c[x+4>>2]|0,24e4,0)|0;E=c[(c[(c[b+12+(y<<2)>>2]|0)+8>>2]|0)+72>>2]|0;D=Frc(v,G,E,(E|0)<0|0?-1:0)|0;E=b+32+(y*80|0)+8|0;c[E>>2]=D;c[E+4>>2]=G;c[n+(y<<2)>>2]=b+352+(y<<13);E=y+1|0;D=c[C>>2]|0;if((E|0)<(D|0)){y=E}else{L=D;break}}}else{L=B}if((L|0)==0){s=A;t=63;break}y=c[p>>2]|0;C=(a[g]|0)==80?g:0;if((C|0)==0){M=A;N=y;break}x=d[C+4|0]|0;u=x>>>3&7;w=x&7;if(w>>>0>1>>>0|u>>>0>2>>>0){s=A;t=63;break}x=(a[C+1|0]&63)+(c[y+80+(u<<2)>>2]|0)<<2;u=y+12|0;C=c[u>>2]|0;D=(C|0)/2|0;if((c[y+32>>2]|0)==720){O=(a[f+1|0]&12)!=0?0:2}else{O=0}E=y+16|0;v=c[E>>2]|0;F=(w|0)==1;if(((O&255)+v|0)>((F?2:4)|0)){KIb(0,16,2132144,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;s=A;t=63;break}if((v|0)<=0){s=A;t=63;break}P=(w|0)==0;w=y+112|0;Q=y+76|0;y=0;R=f;S=O;T=C;C=v;b:while(1){if(!((S&255)>>>0<4>>>0)){t=31;break}v=c[n+((S&255)<<2)>>2]|0;if((v|0)==0){s=A;t=63;break a}U=S+1&255;if((T|0)>0){V=0;W=R;X=v;v=U;Y=T;while(1){Z=W+480|0;if(F&(V|0)==(D|0)){if(!((v&255)>>>0<4>>>0)){t=36;break b}_=v+1&255;$=c[n+((v&255)<<2)>>2]|0;if(($|0)==0){aa=_;ba=Z;da=Y;break}else{ea=_;fa=$}}else{ea=v;fa=X}$=0;_=Z;while(1){if(P){Z=8;do{ga=(ca(c[Q>>2]|0,(Z-8|0)/2|0)|0)+(d[(c[w>>2]|0)+(V*9|0)+$|0]|0)<<1;do{if((ga|0)<(x|0)){ha=a[_+(Z|1)|0]|0;a[fa+ga|0]=ha;ia=a[_+Z|0]|0;ja=fa+(ga|1)|0;a[ja]=ia;if(!(ia<<24>>24==-128&ha<<24>>24==0)){break}a[ja]=0}}while(0);Z=Z+2|0;}while((Z|0)<80)}else{Z=(V|0)%(D|0)|0;ga=Z+D|0;ja=8;do{ha=d[_+(ja+2)|0]|0;ia=ha>>>4|d[_+ja|0]<<4;ka=ja+1|0;la=d[_+ka|0]<<4|ha&15;ha=la&65535;do{if((ia|0)==2048){ma=0;na=0}else{oa=ia&65535;pa=(oa&65535)>>>0<2048>>>0?oa:oa|-4096;oa=pa&65535;qa=(pa&65535)>>>8;ra=qa&15;if((ra-2&65535)>>>0>11>>>0){ma=qa&255;na=pa&255;break}if((ra&65535)>>>0<8>>>0){pa=ra-1&65535;qa=oa-(pa<<8)<<pa;ma=(qa&65535)>>>8&255;na=qa&255;break}else{qa=14-ra&65535;ra=((qa<<8|1)+oa<<qa)+65535|0;ma=(ra&65535)>>>8&255;na=ra&255;break}}}while(0);do{if((la|0)==2048){sa=0;ta=0}else{ia=(ha&65535)>>>0<2048>>>0?ha:ha|-4096;ra=ia&65535;qa=(ia&65535)>>>8;oa=qa&15;if((oa-2&65535)>>>0>11>>>0){sa=qa&255;ta=ia&255;break}if((oa&65535)>>>0<8>>>0){ia=oa-1&65535;qa=ra-(ia<<8)<<ia;sa=(qa&65535)>>>8&255;ta=qa&255;break}else{qa=14-oa&65535;oa=((qa<<8|1)+ra<<qa)+65535|0;sa=(oa&65535)>>>8&255;ta=oa&255;break}}}while(0);ha=(ja-8|0)/3|0;la=(ca(c[Q>>2]|0,ha)|0)+(d[(c[w>>2]|0)+(Z*9|0)+$|0]|0)<<1;if((la|0)<(x|0)){a[fa+la|0]=na;a[fa+(la|1)|0]=ma;la=(ca(c[Q>>2]|0,ha)|0)+(d[(c[w>>2]|0)+(ga*9|0)+$|0]|0)<<1;a[fa+la|0]=ta;a[fa+(la|1)|0]=sa;ua=ka}else{ua=ja}ja=ua+2|0;}while((ja|0)<80)}ja=$+1|0;if((ja|0)<9){$=ja;_=_+1280|0}else{break}}_=W+12e3|0;$=V+1|0;ja=c[u>>2]|0;if(($|0)<(ja|0)){V=$;W=_;X=fa;v=ea;Y=ja}else{aa=ea;ba=_;da=ja;break}}va=aa;wa=ba;xa=da;ya=c[E>>2]|0}else{va=U;wa=R;xa=T;ya=C}Y=y+1|0;if((Y|0)<(ya|0)){y=Y;R=wa;S=va;T=xa;C=ya}else{s=A;t=63;break a}}if((t|0)==31){KIb(0,0,2109064,(z=i,i=i+24|0,c[z>>2]=2626952,c[z+8>>2]=2601512,c[z+16>>2]=152,z)|0);i=z;Hd();return 0}else if((t|0)==36){KIb(0,0,2109064,(z=i,i=i+24|0,c[z>>2]=2626952,c[z+8>>2]=2601512,c[z+16>>2]=162,z)|0);i=z;Hd();return 0}}}while(0);if((t|0)==63){M=s;N=c[p>>2]|0}do{if((c[N+32>>2]|0)==720){if((a[f+1|0]&12)==0){c[b+140>>2]=0;c[b+60>>2]=0;s=b+33128|0;t=wrc(c[s>>2]|0,c[s+4>>2]|0,M,(M|0)<0|0?-1:0)|0;c[s>>2]=t;c[s+4>>2]=G;break}else{c[b+300>>2]=0;c[b+220>>2]=0;break}}else{s=b+33128|0;t=wrc(c[s>>2]|0,c[s+4>>2]|0,M,(M|0)<0|0?-1:0)|0;c[s>>2]=t;c[s+4>>2]=G}}while(0);M=b+8|0;if((N|0)==0){za=0}else{s=c[M>>2]|0;t=c[s+8>>2]|0;_X(s,64,c[N+20>>2]|0,c[N+24>>2]|0);N=(c[p>>2]|0)+20|0;s=t+104|0;z=c[N+4>>2]|0;c[s>>2]=c[N>>2];c[s+4>>2]=z;z=f+453|0;s=(a[z]|0)==97?z:0;z=a[f+4|0]|0;do{if((s|0)==0){Aa=0}else{N=a[s+2|0]&7;if((N|0)==2){Aa=1;break}if(!((z&7)==0)){Aa=0;break}Aa=(N|0)==7|0}}while(0);z=(c[p>>2]|0)+40+(Aa<<3)|0;Aa=(c[M>>2]|0)+80|0;s=c[z+4>>2]|0;c[Aa>>2]=c[z>>2];c[Aa+4>>2]=s;s=c[p>>2]|0;Aa=c[s+8>>2]|0;c[l>>2]=8;c[l+4>>2]=1;z=XIb(Aa,(Aa|0)<0|0?-1:0,l,s+20|0)|0;c[t+72>>2]=z;za=c[(c[p>>2]|0)+8>>2]|0}J1(e);c[e+24>>2]=f;f=e+64|0;c[f>>2]=h;c[f+4>>2]=j;c[e+28>>2]=za;j=e+36|0;c[j>>2]=c[j>>2]|1;c[e+32>>2]=c[c[M>>2]>>2];M=b+33124|0;b=c[M>>2]|0;j=e+8|0;c[j>>2]=b;c[j+4>>2]=(b|0)<0|0?-1:0;c[M>>2]=b+1;o=za;i=k;return o|0}function NF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b;c[a+33124>>2]=f;do{if((c[a+33120>>2]|0)!=0){b=c[a>>2]|0;if((b|0)==0){KIb(c[a+4>>2]|0,16,2194376,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;break}else{c[e>>2]=8;c[e+4>>2]=c[(c[(c[a+12>>2]|0)+8>>2]|0)+72>>2];g=XIb(f,(f|0)<0|0?-1:0,b+20|0,e)|0;b=a+33128|0;c[b>>2]=g;c[b+4>>2]=G;break}}}while(0);c[a+140>>2]=0;c[a+60>>2]=0;c[a+300>>2]=0;c[a+220>>2]=0;i=d;return}function OF(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[a+8>>2]|0;if((b|0)<5){e=0;return e|0}f=b-4|0;if((f|0)<=0){e=0;return e|0}g=c[a+4>>2]|0;a=0;h=0;i=0;j=0;k=0;while(1){l=g+h|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=je(m|0)|0;do{if((l&522304|0)==458752){do{if((l&-16253057|0)==520552511){n=k+1|0;if((l&-129|0)!=520552511){o=n;p=j;q=i;break}o=n;p=(h|0)==0?1:j;q=i+1|0}else{o=k;p=j;q=i}}while(0);if((l|0)==(-12646656|0)|(l|0)==4130560){r=h}else{r=a}if((m|0)!=17252351){s=o;t=p;u=q;v=r;break}s=o;t=p;u=((h-r|0)==80)+q|0;v=r}else{s=k;t=j;u=i;v=a}}while(0);m=h+1|0;if((m|0)<(f|0)){a=v;h=m;i=u;j=t;k=s}else{break}}if((u|0)==0){e=0;return e|0}if(((b|0)/(u|0)|0|0)>=1048576){e=0;return e|0}if(!((u|0)<5&(t|0)==0)){e=75;return e|0}do{if((s|0)>9){if(((b|0)/(s|0)|0|0)<24e3){e=75}else{break}return e|0}}while(0);e=25;return e|0}function PF(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0;e=i;i=i+24|0;f=e|0;g=e+16|0;h=b+12|0;j=c[h>>2]|0;k=pJb(33136)|0;l=k;do{if((k|0)!=0){m=ZX(b,0)|0;c[k+8>>2]=m;if((m|0)==0){kJb(k);break}c[k+4>>2]=b;n=c[m+8>>2]|0;c[n+8>>2]=0;c[n+48>>2]=25;c[n+72>>2]=25e6;n=m+48|0;c[n>>2]=0;c[n+4>>2]=0;n=j;c[n>>2]=l;m=b+16|0;o=JD(c[m>>2]|0)|0;a:do{if((o&-129|0)==520552511){p=o}else{q=o;r=0;while(1){if((jD(c[m>>2]|0)|0)!=0){break}if((q|0)==(-12646656|0)|(q|0)==4130560){s=fD(c[m>>2]|0,0,0,1)|0;t=s}else{t=r}if((q|0)==-12646655){s=fD(c[m>>2]|0,0,0,1)|0;u=xrc(s,G,t,0)|0;if((u|0)==80&(G|0)==0){v=12;break}}u=zD(c[m>>2]|0)|0|q<<8;if((u&-129|0)==520552511){p=u;break a}else{q=u;r=t}}if((v|0)==12){fD(c[m>>2]|0,-163,-1,1)|0;p=JD(c[m>>2]|0)|0;break}KIb(b,16,2270896,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=e;return x|0}}while(0);o=j+4|0;r=o;y=je(p|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;if((AD(c[m>>2]|0,j+8|0,476)|0)!=476){x=-5;i=e;return x|0}r=fD(c[m>>2]|0,-480,-1,1)|0;q=G;u=0;if((q|0)<(u|0)|(q|0)==(u|0)&r>>>0<0>>>0){x=-5;i=e;return x|0}r=Tba(c[c[n>>2]>>2]|0,o,480)|0;c[c[n>>2]>>2]=r;r=c[c[n>>2]>>2]|0;if((r|0)==0){KIb(b,16,2222056,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=e;return x|0}o=c[r+8>>2]|0;c[g>>2]=8;c[g+4>>2]=1;u=XIb(o,(o|0)<0|0?-1:0,g,r+20|0)|0;c[b+1072>>2]=u;u=c[m>>2]|0;if((c[u+88>>2]|0)==0){x=0;i=e;return x|0}r=f|0;o=fD(u,0,0,1)|0;u=G;q=pJb(240)|0;s=c[h>>2]|0;do{if((AD(c[m>>2]|0,q,240)|0)>=240){z=c[(c[c[s>>2]>>2]|0)+28>>2]|0;if((z|0)==25){A=1}else{A=(z|0)==50|0}z=q+86|0;B=(a[z]|0)==19?z:0;if((B|0)==0){KIb(b,16,2157352,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}else{z=B+1|0;oLb(r,je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0,A)|0;MGb(b+1140|0,2187200,r,0)|0;break}}}while(0);kJb(q);fD(c[m>>2]|0,o,u,0)|0;x=0;i=e;return x|0}}while(0);c[j>>2]=0;x=-1;i=e;return x|0}function QF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+12>>2]|0;e=d;f=c[e>>2]|0;g=c[f+33120>>2]|0;a:do{if((g|0)>0){h=0;while(1){if((c[f+12+(h<<2)>>2]|0)!=0){i=f+32+(h*80|0)+28|0;if((c[i>>2]|0)!=0){break}}j=h+1|0;if((j|0)<(g|0)){h=j}else{break a}}nrc(b|0,f+32+(h*80|0)|0,80)|0;c[i>>2]=0;j=c[b+28>>2]|0;if((j|0)<0){break}else{k=j}return k|0}}while(0);i=a+16|0;a=fD(c[i>>2]|0,0,0,1)|0;f=G;g=c[c[e>>2]>>2]|0;if((g|0)==0){k=-5;return k|0}j=c[g+8>>2]|0;g=d+4|0;if((AD(c[i>>2]|0,g,j)|0)<1){k=-5;return k|0}k=MF(c[e>>2]|0,b,g,j,a,f)|0;return k|0}function RF(a){a=a|0;kJb(c[c[a+12>>2]>>2]|0);return 0}function SF(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+8|0;b=f|0;g=c[c[a+12>>2]>>2]|0;h=Uba(c[(c[g+8>>2]|0)+8>>2]|0)|0;j=a+16|0;k=iD(c[j>>2]|0)|0;l=a+1248|0;a=c[l>>2]|0;m=c[l+4>>2]|0;l=xrc(k,G,a,m)|0;k=G;n=wrc(l,k,-1,-1)|0;o=G;p=c[h+8>>2]|0;h=p;q=(p|0)<0|0?-1:0;p=Drc(n,o,h,q)|0;r=xrc(n,o,p,G)|0;p=G;o=Erc(h,q,d,e)|0;e=G;d=-1;if(((k|0)>(d|0)|(k|0)==(d|0)&l>>>0>-1>>>0)&((e|0)>(p|0)|(e|0)==(p|0)&o>>>0>r>>>0)){s=p;t=r}else{r=0;p=(e|0)<(r|0)|(e|0)==(r|0)&o>>>0<0>>>0;s=p?0:e;t=p?0:o}o=wrc(t,s,a,m)|0;m=G;a=fD(c[j>>2]|0,o,m,0)|0;j=G;s=0;if((j|0)<(s|0)|(j|0)==(s|0)&a>>>0<0>>>0){u=-1;i=f;return u|0}a=c[g>>2]|0;s=c[a+8>>2]|0;j=Crc(o,m,s,(s|0)<0|0?-1:0)|0;s=j;c[g+33124>>2]=s;do{if((c[g+33120>>2]|0)!=0){if((a|0)==0){KIb(c[g+4>>2]|0,16,2194376,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;break}else{c[b>>2]=8;c[b+4>>2]=c[(c[(c[g+12>>2]|0)+8>>2]|0)+72>>2];j=XIb(s,(s|0)<0|0?-1:0,a+20|0,b)|0;m=g+33128|0;c[m>>2]=j;c[m+4>>2]=G;break}}}while(0);c[g+140>>2]=0;c[g+60>>2]=0;c[g+300>>2]=0;c[g+220>>2]=0;u=0;i=f;return u|0}function TF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+8|0;d=b|0;e=a+12|0;f=c[e>>2]|0;g=a+1140|0;h=LGb(c[g>>2]|0,2270880,0,0)|0;j=c[e>>2]|0;e=a+24|0;a:do{if(!((c[e>>2]|0)>>>0>3>>>0)){k=j+8|0;c[k>>2]=0;l=j+12|0;m=l;c[j+16>>2]=0;c[l>>2]=0;l=c[e>>2]|0;if((l|0)==0){break}n=a+28|0;o=0;p=0;q=l;while(1){l=c[(c[n>>2]|0)+(p<<2)>>2]|0;r=c[(c[l+8>>2]|0)+8>>2]|0;if((r|0)==1){s=c[k>>2]|0;if((s|0)>1){break a}c[k>>2]=s+1;c[m+(s<<2)>>2]=l;t=o;u=c[e>>2]|0}else if((r|0)==0){if((o|0)==0){t=l;u=q}else{break a}}else{break a}l=p+1|0;if(l>>>0<u>>>0){o=t;p=l;q=u}else{break}}if((t|0)==0){break}q=c[t+8>>2]|0;if((c[q+48>>2]|0)!=25){break}p=c[k>>2]|0;if((p|0)>0){o=0;do{l=c[m+(o<<2)>>2]|0;if((l|0)!=0){r=c[l+8>>2]|0;if((c[r+48>>2]|0)!=65536){break a}if((c[r+412>>2]|0)!=48e3){break a}if((c[r+416>>2]|0)!=2){break a}}o=o+1|0;}while((o|0)<(p|0))}p=Uba(q)|0;c[j+4>>2]=p;if((p|0)==0){break}if((c[k>>2]|0)>1){if((c[p+16>>2]|0)<2){break}}c[j+28>>2]=0;c[j+40>>2]=0;c[j+44>>2]=0;p=LGb(c[g>>2]|0,2187184,0,0)|0;if((p|0)!=0){o=pY(c[p+4>>2]|0)|0;p=j+32|0;c[p>>2]=o;c[p+4>>2]=G}p=c[k>>2]|0;b:do{if((p|0)>0){o=j+20|0;r=0;l=p;while(1){if((c[m+(r<<2)>>2]|0)==0){v=l}else{s=dHb(192e5)|0;c[o+(r<<2)>>2]=s;if((s|0)==0){break}v=c[k>>2]|0}s=r+1|0;if((s|0)<(v|0)){r=s;l=v}else{break b}}if((r|0)>0){w=r}else{break a}while(1){w=w-1|0;eHb(c[o+(w<<2)>>2]|0);if((w|0)<=0){break a}}}}while(0);if((j|0)==0){break}c[d>>2]=c[(c[f+4>>2]|0)+28>>2];c[d+4>>2]=1;c:do{if((h|0)==0){k=0;while(1){if(!(k>>>0<(c[e>>2]|0)>>>0)){break}m=LGb(c[(c[(c[n>>2]|0)+(k<<2)>>2]|0)+88>>2]|0,2270880,0,0)|0;if((m|0)==0){k=k+1|0}else{x=m;y=35;break c}}z=f+576048|0;A=a}else{x=h;y=35}}while(0);do{if((y|0)==35){n=f+576048|0;k=a;if((sLb(n,d,c[x+4>>2]|0,k)|0)>-1){B=0}else{z=n;A=k;break}i=b;return B|0}}while(0);B=rLb(z,d,0,0,A)|0;i=b;return B|0}}while(0);KIb(a,16,2221872,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;B=-1;i=b;return B|0}function UF(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=i;g=c[b+12>>2]|0;h=g;j=c[(c[b+28>>2]|0)+(c[e+32>>2]<<2)>>2]|0;k=c[e+24>>2]|0;l=c[e+28>>2]|0;e=g+48|0;m=g+4|0;n=c[m>>2]|0;o=g+28|0;p=c[o>>2]|0;q=c[n+92+(((p>>>0)%5|0)<<2)>>2]<<2;r=j+8|0;s=c[r>>2]|0;t=c[s+8>>2]|0;if((t|0)==1){u=c[g+8>>2]|0;v=0;while(1){if((v|0)>=(u|0)){break}if((c[h+12+(v<<2)>>2]|0)==(j|0)){break}else{v=v+1|0}}j=h+20+(v<<2)|0;if(((fHb(c[j>>2]|0)|0)+l|0)>19199999){KIb(c[r>>2]|0,16,2326120,(w=i,i=i+8|0,c[w>>2]=c[o>>2],w)|0);i=w}jHb(c[j>>2]|0,k,l,0)|0;l=((q|0)<=(fHb(c[j>>2]|0)|0))<<v;v=g+40|0;c[v>>2]=l|c[v>>2]}else if((t|0)==0){t=g+44|0;if((c[t>>2]|0)==0){x=n}else{KIb(s,16,2400464,(w=i,i=i+8|0,c[w>>2]=p,w)|0);i=w;x=c[m>>2]|0}nrc(e|0,k|0,c[x+8>>2]|0)|0;c[t>>2]=1}t=g+44|0;if((c[t>>2]|0)!=1){i=f;return 0}x=g+40|0;k=g+8|0;p=c[k>>2]|0;if(((c[x>>2]|0)+1|0)!=(1<<p|0)){i=f;return 0}s=c[m>>2]|0;if((c[s+8>>2]|0)>0){n=e;v=e;do{l=v-n|0;WF(19,h,v+86|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;j=v+94|0;WF(19,h,j,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;r=v+102|0;WF(19,h,r,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(19,h,v+110|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=v+118|0;WF(19,h,u,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=v+126|0;WF(19,h,y,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;z=c[m>>2]|0;A=c[z+12>>2]|0;if((((l|0)/((c[z+8>>2]|0)/(ca(c[z+16>>2]|0,A)|0)|0|0)|0|0)%(A|0)|0|0)>5){WF(98,h,j,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,r,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(98,h,u,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,y,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}WF(19,h,v+166|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=v+174|0;WF(19,h,y,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=v+182|0;WF(19,h,u,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(19,h,v+190|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;r=v+198|0;WF(19,h,r,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;j=v+206|0;WF(19,h,j,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;A=c[m>>2]|0;z=c[A+12>>2]|0;if((((l|0)/((c[A+8>>2]|0)/(ca(c[A+16>>2]|0,z)|0)|0|0)|0|0)%(z|0)|0|0)>5){WF(98,h,y,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,u,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(98,h,r,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,j,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}WF(98,h,v+253|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,v+258|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(98,h,v+298|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,v+303|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(98,h,v+333|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,v+338|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(98,h,v+378|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,v+383|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(98,h,v+413|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,v+418|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(98,h,v+458|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;WF(99,h,v+463|0,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;v=v+12e3|0;B=c[m>>2]|0;}while(v>>>0<(g+((c[B+8>>2]|0)+48)|0)>>>0);C=c[k>>2]|0;D=B}else{C=p;D=s}c[x>>2]=0;if((C|0)>0){C=0;s=D;while(1){p=c[s+92+((((c[o>>2]|0)>>>0)%5|0)<<2)>>2]<<2;B=c[s+12>>2]|0;if((B|0)>0){v=h+20+(C<<2)|0;n=0;j=g+((ca(C*12e3|0,B)|0)+48)|0;B=s;while(1){r=0;u=j+480|0;y=B;while(1){WF(c[1518088+(n*36|0)+(r<<2)>>2]|0,h,u+3|0,(w=i,i=i+8|0,c[w>>2]=(n|0)>=((c[y+12>>2]|0)/2|0|0),w)|0);i=w;z=8;do{A=c[m>>2]|0;l=(ca(c[A+76>>2]|0,(z-8|0)/2|0)|0)+(d[(c[A+112>>2]|0)+(n*9|0)+r|0]|0)<<1;if((l|0)<(p|0)){A=c[v>>2]|0;E=c[A>>2]|0;F=c[A+12>>2]|0;G=(c[A+4>>2]|0)+(l|1)|0;do{if(G>>>0<F>>>0){if(!(G>>>0<E>>>0)){H=G;break}H=F+(G-E)|0}else{H=E+(G-F)|0}}while(0);a[u+z|0]=a[H]|0;F=c[v>>2]|0;G=c[F>>2]|0;E=c[F+12>>2]|0;A=(c[F+4>>2]|0)+l|0;do{if(A>>>0<E>>>0){if(!(A>>>0<G>>>0)){I=A;break}I=E+(A-G)|0}else{I=G+(A-E)|0}}while(0);a[u+(z|1)|0]=a[I]|0}z=z+2|0;}while((z|0)<80);z=r+1|0;if((z|0)>=9){break}r=z;u=u+1280|0;y=c[m>>2]|0}y=n+1|0;u=c[m>>2]|0;if((y|0)<(c[u+12>>2]|0)){n=y;j=j+12e3|0;B=u}else{J=v;break}}}else{J=h+20+(C<<2)|0}kHb(c[J>>2]|0,q);v=((q|0)<=(fHb(c[J>>2]|0)|0))<<C;c[x>>2]=v|c[x>>2];v=C+1|0;B=c[m>>2]|0;if((v|0)<(c[k>>2]|0)){C=v;s=B}else{K=B;break}}}else{K=D}c[t>>2]=0;c[o>>2]=(c[o>>2]|0)+1;o=c[K+8>>2]|0;if((o|0)<=0){i=f;return 0}dD(c[b+16>>2]|0,e,o);i=f;return 0}function VF(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;a=b;d=b+8|0;if((c[d>>2]|0)>0){e=0}else{return 0}do{eHb(c[a+20+(e<<2)>>2]|0);e=e+1|0;}while((e|0)<(c[d>>2]|0));return 0}function WF(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+64|0;h=g|0;j=g+48|0;a[e]=b;switch(b|0){case 19:{b=e+1|0;y=je(mLb(d+576048|0,c[d+28>>2]|0)|0|8421568|0)|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;i=g;return};case 83:case 99:{b=d+32|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=c[d+28>>2]|0;m=c[d+4>>2]|0;n=c[m+20>>2]|0;o=c[m+24>>2]|0;s$(wrc(UIb(b,(b|0)<0|0?-1:0,n,(n|0)<0|0?-1:0,o,(o|0)<0|0?-1:0,2)|0,G,k,l)|0,h)|0;a[e+1|0]=-1;l=c[h>>2]|0;a[e+2|0]=(l|0)%10|0|((l|0)/10|0)<<4|128;l=c[h+4>>2]|0;a[e+3|0]=(l|0)%10|0|((l|0)/10|0)<<4|128;l=c[h+8>>2]|0;a[e+4|0]=(l|0)%10|0|((l|0)/10|0)<<4|192;i=g;return};case 82:case 98:{l=d+32|0;k=c[l>>2]|0;o=c[l+4>>2]|0;l=c[d+28>>2]|0;n=c[d+4>>2]|0;b=c[n+20>>2]|0;m=c[n+24>>2]|0;s$(wrc(UIb(l,(l|0)<0|0?-1:0,b,(b|0)<0|0?-1:0,m,(m|0)<0|0?-1:0,2)|0,G,k,o)|0,h)|0;a[e+1|0]=-1;o=c[h+12>>2]|0;a[e+2|0]=(o|0)%10|0|((o|0)/10|0)<<4|192;o=c[h+16>>2]|0;a[e+3|0]=((o|0)/10|0)<<4|((o|0)%10|0);o=c[h+20>>2]|0;a[e+4|0]=(((o|0)%100|0|0)/10|0)<<4|((o|0)%10|0);i=g;return};case 81:{a[e+1|0]=28;a[e+2|0]=-49;o=c[d+4>>2]|0;if((c[o+64>>2]|0)==0){p=-96}else{p=(c[o+28>>2]<<2|128)&255}a[e+3|0]=p;a[e+4|0]=-1;i=g;return};case 80:{p=j|0;o=j;c[o>>2]=f;c[o+4>>2]=0;o=d+4|0;f=c[o>>2]|0;a[e+1|0]=(c[f+92+((((c[d+28>>2]|0)>>>0)%5|0)<<2)>>2]|0)-(c[f+80>>2]|0)|192;a[e+2|0]=((x=c[p+4>>2]|0,c[p+4>>2]=x+8,c[(c[p>>2]|0)+x>>2]|0)|0)!=0|0;p=c[o>>2]|0;a[e+3|0]=c[p>>2]<<5|c[p+16>>2]&2|192;a[e+4|0]=-128;i=g;return};default:{p=e+1|0;y=-1;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;i=g;return}}}function XF(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[b+8>>2]|0)<15){e=0;return e|0}f=c[b+4>>2]|0;b=f+11|0;g=(d[b]|d[b+1|0]<<8)<<16>>16;b=he(g|0)|0;h=f+13|0;i=(d[h]|d[h+1|0]<<8)<<16>>16;h=he(i|0)|0;do{if((a[f]|0)==68){if((a[f+1|0]|0)!=69){break}if((a[f+2|0]|0)!=88){break}if((a[f+3|0]|0)!=65){break}if(!(g<<16>>16!=0&(b&65535)>>>0<2049>>>0)){break}if(i<<16>>16!=0&(h&65535)>>>0<2049>>>0){e=100}else{break}return e|0}}while(0);e=0;return e|0}function YF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+16>>2]|0;g=c[a+12>>2]|0;if((FD(f)|0)!=1096303940){h=-1094995529;i=b;return h|0}j=zD(f)|0;k=HD(f)|0;l=g;c[l>>2]=k;if((k|0)==0){KIb(a,16,2187136,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}k=JD(f)|0;do{if((k|0)>0){c[e>>2]=1e3;c[d>>2]=k}else{if((k|0)<0){c[e>>2]=1e5;c[d>>2]=-k;break}else{c[e>>2]=10;c[d>>2]=1;break}}}while(0);k=HD(f)|0;n=HD(f)|0;o=g+4|0;c[o>>2]=0;p=ZX(a,0)|0;if((p|0)==0){h=-12;i=b;return h|0}if((FD(f)|0)==1163280727){c[o>>2]=1;q=JD(f)|0;r=fD(f,0,0,1)|0;s=wrc(r,G,q,0)|0;q=g+24|0;c[q>>2]=s;c[q+4>>2]=G;hD(f,16,0)|0;s=FD(f)|0;r=ZX(a,0)|0;if((r|0)==0){h=-12;i=b;return h|0}t=r+8|0;u=OS(f,c[t>>2]|0,s)|0;if((u|0)<0){h=u;i=b;return h|0}u=c[(c[t>>2]|0)+412>>2]|0;if((u|0)>0){_X(r,64,1,u)}u=fD(f,0,0,1)|0;r=G;v=c[q+4>>2]|0;a:do{if((r|0)<(v|0)|(r|0)==(v|0)&u>>>0<(c[q>>2]|0)>>>0){w=s;while(1){if((jD(f)|0)!=0){x=w;break a}y=FD(f)|0;z=FD(f)|0;if((y|0)==1635017060){x=z;break a}hD(f,z,0)|0;y=fD(f,0,0,1)|0;A=G;B=c[q+4>>2]|0;if((A|0)<(B|0)|(A|0)==(B|0)&y>>>0<(c[q>>2]|0)>>>0){w=z}else{x=z;break}}}else{x=s}}while(0);s=c[l>>2]|0;u=((x-1+s|0)>>>0)/(s>>>0)|0;s=g+8|0;c[s>>2]=u;v=c[(c[t>>2]|0)+432>>2]|0;if((v|0)!=0){t=u-1+v|0;c[s>>2]=t-((t|0)%(v|0)|0)}c[g+12>>2]=x;x=fD(f,0,0,1)|0;v=g+16|0;c[v>>2]=x;c[v+4>>2]=G;fD(f,c[q>>2]|0,c[q+4>>2]|0,0)|0;}q=p+8|0;v=c[q>>2]|0;c[v+8>>2]=0;c[v+48>>2]=99;c[v+120>>2]=k;c[v+124>>2]=n;n=c[e>>2]|0;v=c[d>>2]|0;xKb(e,d,n,(n|0)<0|0?-1:0,v,(v|0)<0|0?-1:0,2147483647,0)|0;_X(p,33,c[d>>2]|0,c[e>>2]|0);if((j&192|0)!=0){j=(c[q>>2]|0)+124|0;c[j>>2]=c[j>>2]>>1}c[g+32>>2]=(c[o>>2]|0)==0;o=fD(f,0,0,1)|0;f=g+24|0;c[f>>2]=o;c[f+4>>2]=G;f=a+1056|0;c[f>>2]=0;c[f+4>>2]=0;f=c[l>>2]|0;l=Erc(f,(f|0)<0|0?-1:0,1e6,0)|0;o=c[d>>2]|0;d=Erc(l,G,o,(o|0)<0|0?-1:0)|0;o=c[e>>2]|0;e=Crc(d,G,o,(o|0)<0|0?-1:0)|0;o=a+1064|0;c[o>>2]=e;c[o+4>>2]=G;KIb(a,48,2157336,(m=i,i=i+8|0,c[m>>2]=f,m)|0);i=m;h=0;i=b;return h|0}function ZF(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+792|0;g=f|0;h=f+16|0;j=h|0;k=c[b+12>>2]|0;l=k+32|0;do{if((c[l>>2]|0)==0){if((c[k+4>>2]|0)==0){break}m=k+12|0;if((c[m>>2]|0)==0){break}c[l>>2]=1;n=b+16|0;o=k+16|0;fD(c[n>>2]|0,c[o>>2]|0,c[o+4>>2]|0,0)|0;p=c[m>>2]|0;q=c[k+8>>2]|0;r=p>>>0>q>>>0?q:p;p=fX(c[n>>2]|0,e,r)|0;c[e+32>>2]=1;if((p|0)!=(r|0)){s=-5;i=f;return s|0}c[m>>2]=(c[m>>2]|0)-r;r=fD(c[n>>2]|0,0,0,1)|0;c[o>>2]=r;c[o+4>>2]=G;s=0;i=f;return s|0}}while(0);o=b+16|0;r=k+24|0;fD(c[o>>2]|0,c[r>>2]|0,c[r+4>>2]|0,0)|0;if((jD(c[o>>2]|0)|0)!=0){s=-541478725;i=f;return s|0}n=k;k=g|0;m=g;p=h+4|0;q=0;while(1){if((c[n>>2]|0)==0){s=-541478725;t=28;break}u=AD(c[o>>2]|0,k,4)|0;if((u|0)!=4){t=10;break}v=c[m>>2]|0;if((v|0)==1280070990){t=12;break}else if((v|0)==1296126534){t=17;break}else if((v|0)!=1346456899){t=27;break}c[j>>2]=1346456899;AD(c[o>>2]|0,p,768)|0;if((jD(c[o>>2]|0)|0)==0){q=772}else{s=-541478725;t=28;break}}if((t|0)==10){KIb(b,16,2400408,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=(u|0)<0?u:-1094995529;i=f;return s|0}else if((t|0)==12){if((K1(e,q+4|0)|0)<0){s=-12;i=f;return s|0}c[e+32>>2]=0;u=e+24|0;if((q|0)!=0){nrc(c[u>>2]|0,h|0,q)|0}p=(c[u>>2]|0)+q|0;y=c[m>>2]|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[n>>2]=(c[n>>2]|0)-1;p=fD(c[o>>2]|0,0,0,1)|0;c[r>>2]=p;c[r+4>>2]=G;c[l>>2]=0;s=0;i=f;return s|0}else if((t|0)==17){p=AD(c[o>>2]|0,g+4|0,5)|0;if((p|0)!=5){KIb(b,16,2326088,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=(p|0)<0?p:-1094995529;i=f;return s|0}p=g+5|0;m=je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if(m>>>0>16777215>>>0){KIb(b,16,2270848,(w=i,i=i+8|0,c[w>>2]=m,w)|0);i=w;s=-1094995529;i=f;return s|0}p=q|9;if((K1(e,p+m|0)|0)<0){s=-12;i=f;return s|0}u=e+24|0;nrc((c[u>>2]|0)+q|0,k|0,9)|0;if((AD(c[o>>2]|0,(c[u>>2]|0)+p|0,m)|0)!=(m|0)){P1(e);s=-5;i=f;return s|0}if((q|0)!=0){nrc(c[u>>2]|0,h|0,q)|0}c[e+32>>2]=0;c[n>>2]=(c[n>>2]|0)-1;n=fD(c[o>>2]|0,0,0,1)|0;c[r>>2]=n;c[r+4>>2]=G;c[l>>2]=0;s=0;i=f;return s|0}else if((t|0)==27){l=d[g+1|0]|0;r=d[g+2|0]|0;n=d[g+3|0]|0;KIb(b,16,2221848,(w=i,i=i+32|0,c[w>>2]=v&255,c[w+8>>2]=l,c[w+16>>2]=r,c[w+24>>2]=n,w)|0);i=w;s=-1094995529;i=f;return s|0}else if((t|0)==28){i=f;return s|0}return 0}function _F(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==4){b=a[d+1|0]|0;if((b<<24>>24|0)==0|(b<<24>>24|0)==4|(b<<24>>24|0)==12|(b<<24>>24|0)==20){e=12}else{break}return e|0}}while(0);e=0;return e|0}function $F(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=HD(e)|0;if((f|0)==1036){c[d>>2]=4;g=0;h=51}else if((f|0)==1044){c[d>>2]=6;g=0;h=63}else if((f|0)==1024){c[d>>2]=1;g=0;h=0}else if((f|0)==1028){c[d>>2]=2;g=0;h=0}else{KIb(a,32,2326056,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;k=-1;i=b;return k|0}j=HD(e)|0;hD(e,(zD(e)|0)>>>3&4|11,0)|0;e=ZX(a,0)|0;if((e|0)==0){k=-12;i=b;return k|0}a=c[e+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=0;c[a+48>>2]=69657;c[a+416>>2]=c[d>>2];f=a+448|0;c[f>>2]=h;c[f+4>>2]=g;c[a+412>>2]=j;_X(e,64,1,j);c[d+4>>2]=0;k=0;i=b;return k|0}function aG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+12>>2]|0;e=fX(c[a+16>>2]|0,b,(c[d>>2]|0)*76|0)|0;if((e|0)<0){f=e;return f|0}e=d+4|0;d=c[e>>2]|0;c[e>>2]=d+1;e=b+8|0;c[e>>2]=d;c[e+4>>2]=0;f=0;return f|0}function bG(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((e|0)==1749963569|(e|0)==1816675155|(e|0)==1145128275|(e|0)==1313163347|(e|0)==1413961323|(e|0)==1799635277|(e|0)==1749241933|(e|0)==1684559437|(e|0)==1749636685)){f=0;return f|0}e=b+4|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if(b>>>0>1048575>>>0){g=je(b|0)|0}else{g=b}f=(g-8|0)>>>0>1048567>>>0?0:100;return f|0}function cG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;b=i;d=a+12|0;e=c[d>>2]|0;f=a+16|0;g=c[f>>2]|0;h=e+32|0;j=e;k=a;l=e+4|0;m=0;a:while(1){if((c[h>>2]|0)!=0){if((c[l>>2]|0)!=0){n=98;break}}o=fD(g,0,0,1)|0;p=G;q=FD(g)|0;r=FD(g)|0;if((m|0)==0){s=r>>>0>(je(r|0)|0)>>>0|0;c[j>>2]=s;t=s}else{t=c[j>>2]|0}if((t|0)==0){u=r}else{u=je(r|0)|0}if(u>>>0<8>>>0){n=10;break}b:do{if((q|0)==1749963569){if((FD(g)|0)!=1396916549){n=13;break a}r=c[d>>2]|0;s=c[f>>2]|0;if((c[r>>2]|0)==0){v=FD(s)|0}else{v=JD(s)|0}c[r+44>>2]=v;w=r+40|0;c[w>>2]=zD(s)|0;c[r+48>>2]=zD(s)|0;x=zD(s)|0;hD(s,13,0)|0;if((x|0)==0){s=c[w>>2]|0;if((s|0)==1){c[r+32>>2]=65540;break}else if((s|0)==2){c[r+32>>2]=65536;break}else{break}}else if((x|0)==1){c[r+32>>2]=65542;c[w>>2]=1;break}else if((x|0)==2){c[r+32>>2]=69656;break}else{QIb(k,2385464,(y=i,i=i+8|0,c[y>>2]=x,y)|0);i=y;break}}else if((q|0)==1413961323){c[l>>2]=121}else if((q|0)==1145263213){x=c[d>>2]|0;r=c[f>>2]|0;hD(r,4,0)|0;c[x+16>>2]=DD(r)|0;c[x+20>>2]=DD(r)|0;c[x+8>>2]=1;c[x+12>>2]=15;c[x+4>>2]=38}else if((q|0)==1749241933){c[l>>2]=2}else if((q|0)==1413960048|(q|0)==1934706516){c[l>>2]=122}else if((q|0)==1414613360){c[l>>2]=123}else if((q|0)==1799635277){c[l>>2]=130}else if((q|0)==1684559437){x=c[d>>2]|0;r=c[f>>2]|0;hD(r,8,0)|0;c[x+24>>2]=FD(r)|0;hD(r,4,0)|0;w=x+12|0;c[w>>2]=FD(r)|0;s=FD(r)|0;c[x+8>>2]=s;if((c[w>>2]|0)<1|(s|0)<1){n=96;break a}c[x+4>>2]=92}else if((q|0)==1145128275){x=c[d>>2]|0;s=c[f>>2]|0;c[x+44>>2]=FD(s)|0;c[x+40>>2]=FD(s)|0;c[x+48>>2]=FD(s)|0;c[x+32>>2]=69655}else if((q|0)==1749636685){x=c[d>>2]|0;hD(c[f>>2]|0,10,0)|0;s=DD(c[f>>2]|0)|0;if((s|0)!=0){c[x+8>>2]=1;c[x+12>>2]=s}c[x+4>>2]=119}else if((q|0)==1816675155|(q|0)==1313163347){x=FD(g)|0;if((x|0)==1381258055){hD(g,4,0)|0;}else{if((x&65535|0)!=21584){n=27;break a}}x=c[d>>2]|0;s=c[f>>2]|0;c[x+40>>2]=2;w=x+44|0;c[w>>2]=-1;r=x+48|0;c[r>>2]=1;do{if((jD(s)|0)==0){z=x+52|0;A=-1;B=-1;C=-1;D=1;c:while(1){while(1){E=(zD(s)|0)&255;if((E|0)==253){break}else if((E|0)==255){n=61;break c}F=(zD(s)|0)&255;if((F|0)==0){H=0}else{I=0;J=0;while(1){K=(zD(s)|0)&255|J<<8;L=I+1|0;if((L|0)<(F|0)){I=L;J=K}else{H=K;break}}}KIb(k,48,2425272,(y=i,i=i+16|0,c[y>>2]=E,c[y+8>>2]=H,y)|0);i=y;if((jD(s)|0)!=0){M=A;N=B;O=C;break c}}KIb(k,48,2576160,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;d:do{if((jD(s)|0)==0){J=A;I=B;F=C;K=1;L=D;while(1){P=(zD(s)|0)&255;switch(P|0){case 133:{Q=(zD(s)|0)&255;if((Q|0)==0){R=0}else{S=0;T=0;while(1){U=(zD(s)|0)&255|T<<8;V=S+1|0;if((V|0)<(Q|0)){S=V;T=U}else{R=U;break}}}c[z>>2]=R;KIb(k,48,2493928,(y=i,i=i+8|0,c[y>>2]=R,y)|0);i=y;W=L;X=K;Y=F;Z=I;_=J;break};case 128:{T=(zD(s)|0)&255;if((T|0)==0){$=0}else{S=0;Q=0;while(1){U=(zD(s)|0)&255|Q<<8;V=S+1|0;if((V|0)<(T|0)){S=V;Q=U}else{$=U;break}}}KIb(k,48,2557216,(y=i,i=i+8|0,c[y>>2]=$,y)|0);i=y;W=L;X=K;Y=F;Z=$;_=J;break};case 132:{Q=(zD(s)|0)&255;if((Q|0)==0){aa=0}else{S=0;T=0;while(1){U=(zD(s)|0)&255|T<<8;V=S+1|0;if((V|0)<(Q|0)){S=V;T=U}else{aa=U;break}}}c[w>>2]=aa;KIb(k,48,2508352,(y=i,i=i+8|0,c[y>>2]=aa,y)|0);i=y;W=L;X=K;Y=F;Z=I;_=J;break};case 130:{T=(zD(s)|0)&255;if((T|0)==0){ba=0}else{S=0;Q=0;while(1){U=(zD(s)|0)&255|Q<<8;V=S+1|0;if((V|0)<(T|0)){S=V;Q=U}else{ba=U;break}}}c[r>>2]=ba;KIb(k,48,2539896,(y=i,i=i+8|0,c[y>>2]=ba,y)|0);i=y;W=L;X=K;Y=F;Z=I;_=J;break};case 160:{Q=(zD(s)|0)&255;if((Q|0)==0){da=0}else{S=0;T=0;while(1){U=(zD(s)|0)&255|T<<8;V=S+1|0;if((V|0)<(Q|0)){S=V;T=U}else{da=U;break}}}KIb(k,48,2464448,(y=i,i=i+8|0,c[y>>2]=da,y)|0);i=y;W=L;X=K;Y=da;Z=I;_=J;break};case 255:{KIb(k,48,2450320,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;W=0;X=0;Y=F;Z=I;_=J;break};case 131:{T=(zD(s)|0)&255;if((T|0)==0){ea=0}else{S=0;Q=0;while(1){U=(zD(s)|0)&255|Q<<8;V=S+1|0;if((V|0)<(T|0)){S=V;Q=U}else{ea=U;break}}}KIb(k,48,2523088,(y=i,i=i+8|0,c[y>>2]=ea,y)|0);i=y;W=L;X=K;Y=F;Z=I;_=ea;break};case 138:{Q=(zD(s)|0)&255;if((Q|0)==0){fa=0}else{S=0;T=0;while(1){U=(zD(s)|0)&255|T<<8;V=S+1|0;if((V|0)<(Q|0)){S=V;T=U}else{fa=U;break}}}KIb(k,48,2483792,(y=i,i=i+16|0,c[y>>2]=138,c[y+8>>2]=fa,y)|0);i=y;KIb(k,48,2472552,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;W=L;X=0;Y=F;Z=I;_=J;break};default:{T=(zD(s)|0)&255;if((T|0)==0){ga=0}else{S=0;Q=0;while(1){U=(zD(s)|0)&255|Q<<8;V=S+1|0;if((V|0)<(T|0)){S=V;Q=U}else{ga=U;break}}}KIb(k,48,2483792,(y=i,i=i+16|0,c[y>>2]=P,c[y+8>>2]=ga,y)|0);i=y;W=L;X=K;Y=F;Z=I;_=J}}if((jD(s)|0)!=0|(X|0)==0){ha=_;ia=Z;ja=Y;ka=W;break d}else{J=_;I=Z;F=Y;K=X;L=W}}}else{ha=A;ia=B;ja=C;ka=D}}while(0);if((jD(s)|0)!=0|(ka|0)==0){M=ha;N=ia;O=ja;break}else{A=ha;B=ia;C=ja;D=ka}}if((n|0)==61){n=0;KIb(k,48,2434056,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;jD(s)|0;M=A;N=B;O=C}if((M|0)==0){c[x+32>>2]=65536;la=N;break}else if((M|0)==7){c[x+32>>2]=69642;la=N;break}else if((M|0)==(-1|0)){if((N|0)==(-1|0)){ma=-1}else if((N|0)==1){c[x+32>>2]=69652;ma=1}else if((N|0)==2){c[x+32>>2]=69654;ma=2}else if((N|0)==3){c[x+32>>2]=69653;ma=3}else{QIb(k,2414480,(y=i,i=i+8|0,c[y>>2]=N,y)|0);i=y;break b}if((O|0)==8){c[x+32>>2]=65554;la=ma;break}else if((O|0)==10){if((ma|0)==(-1|0)|(ma|0)==2){c[x+32>>2]=69652;la=ma;break}else if((ma|0)==3){c[x+32>>2]=69654;la=3;break}else{QIb(k,2406672,(y=i,i=i+16|0,c[y>>2]=ma,c[y+8>>2]=10,y)|0);i=y;break b}}else if((O|0)==(-1|0)){la=ma;break}else if((O|0)==16){c[x+32>>2]=86017;la=ma;break}else{c[x+32>>2]=0;QIb(k,2399136,(y=i,i=i+8|0,c[y>>2]=O,y)|0);i=y;break b}}else{QIb(k,2392072,(y=i,i=i+8|0,c[y>>2]=M,y)|0);i=y;break b}}else{la=-1}}while(0);if(!((c[w>>2]|0)==-1)){break}c[w>>2]=(la|0)==3?48e3:22050}}while(0);q=wrc(u,0,o,p)|0;fD(g,q,G,0)|0;q=m+1|0;if((q|0)<5){m=q}else{n=98;break}}if((n|0)==10){KIb(k,16,2157272,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;na=-5;i=b;return na|0}else if((n|0)==13){QIb(k,2132088,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;na=-5;i=b;return na|0}else if((n|0)==27){QIb(k,2109016,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;na=-5;i=b;return na|0}else if((n|0)==96){KIb(k,16,2601320,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;KIb(k,16,2626896,(y=i,i=i+8|0,c[y>>2]=-1094995529,y)|0);i=y;na=-5;i=b;return na|0}else if((n|0)==98){fD(g,0,0,0)|0;if((c[l>>2]|0)!=0){g=ZX(a,0)|0;if((g|0)==0){na=-12;i=b;return na|0}c[e+28>>2]=c[g>>2];n=c[g+8>>2]|0;c[n+8>>2]=0;m=c[l>>2]|0;c[n+48>>2]=m;if((m|0)==2){c[g+236>>2]=2}c[n+52>>2]=0;c[n+120>>2]=c[e+16>>2];c[n+124>>2]=c[e+20>>2];n=c[e+24>>2]|0;m=n;l=(n|0)<0|0?-1:0;n=g+64|0;c[n>>2]=m;c[n+4>>2]=l;n=g+56|0;c[n>>2]=m;c[n+4>>2]=l;l=e+8|0;n=c[l>>2]|0;m=e+12|0;if((n|0)==0){oa=0;pa=0}else{_X(g,64,n,c[m>>2]|0);oa=c[l>>2]|0;pa=0}l=g+92|0;n=pa|c[m>>2];m=oa|0;c[l>>2]=n;c[l+4>>2]=m;l=g+412|0;c[l>>2]=n;c[l+4>>2]=m}if((c[h>>2]|0)==0){na=1;i=b;return na|0}m=e+48|0;l=c[m>>2]|0;if((l-1|0)>>>0>1>>>0){KIb(k,24,2270752,(y=i,i=i+8|0,c[y>>2]=l,y)|0);i=y;c[h>>2]=0;na=1;i=b;return na|0}l=e+44|0;n=c[l>>2]|0;if((n|0)<1){KIb(k,16,2221808,(y=i,i=i+8|0,c[y>>2]=n,y)|0);i=y;c[h>>2]=0;na=1;i=b;return na|0}n=e+40|0;g=c[n>>2]|0;if((g|0)<1){KIb(k,16,2186944,(y=i,i=i+8|0,c[y>>2]=g,y)|0);i=y;c[h>>2]=0;na=1;i=b;return na|0}y=ZX(a,0)|0;if((y|0)==0){na=-12;i=b;return na|0}_X(y,33,1,c[l>>2]|0);a=c[y+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=c[h>>2];c[a+52>>2]=0;h=c[m>>2]|0;c[a+416>>2]=h;m=c[l>>2]|0;c[a+412>>2]=m;l=c[n>>2]<<3;c[a+792>>2]=l;c[a+72>>2]=(ca(ca(m,h)|0,l)|0)/4|0;c[a+432>>2]=ca(l,h)|0;c[e+36>>2]=c[y>>2];e=y+48|0;c[e>>2]=0;c[e+4>>2]=0;na=1;i=b;return na|0}return 0}function dG(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;f=c[a+12>>2]|0;g=c[a+16>>2]|0;h=f;j=f+32|0;k=f+36|0;l=b+32|0;m=f+40|0;n=f+48|0;o=b+48|0;p=b+28|0;q=b+24|0;r=a;a=f+28|0;f=b+36|0;s=0;t=0;u=0;v=0;w=0;a:while(1){x=FD(g)|0;if((c[h>>2]|0)==0){y=FD(g)|0}else{y=JD(g)|0}if(y>>>0<9>>>0){z=-1094995529;A=35;break}B=y-8|0;if((x|0)==1682854705|(x|0)==1816413011|(x|0)==1128549971|(x|0)==1313162323){C=B;A=9}else if((x|0)==1749963569){if(B>>>0<32>>>0){z=-1094995529;A=35;break}hD(g,32,0)|0;C=y-40|0;A=9}else if((x|0)==1749636685|(x|0)==1413961323|(x|0)==1413960048|(x|0)==1934706516|(x|0)==1799635277){D=1;A=25}else if((x|0)==1716082253|(x|0)==1413961318|(x|0)==1833189709|(x|0)==1698971981){D=v;A=25}else if((x|0)==1145263213){hD(g,8,0)|0;E=v;F=y-16|0;A=28}else if((x|0)==1261459021|(x|0)==1749241933|(x|0)==1414613360){E=1;F=B;A=28}else if((x|0)==1177572941){E=v;F=B;A=28}else if((x|0)==0|(x|0)==1699631921|(x|0)==1816478547|(x|0)==1145980243|(x|0)==1313162579){G=w;H=v;I=1;J=-5;K=s}else{hD(g,B,0)|0;G=w;H=v;I=u;J=t;K=s}do{if((A|0)==9){A=0;B=c[j>>2]|0;if((B|0)==65554|(B|0)==86017){L=FD(g)|0;hD(g,8,0)|0;M=L;N=C-12|0}else if((B|0)==0){hD(g,C,0)|0;G=w;H=v;I=u;J=t;K=s;break}else{M=w;N=C}if((s|0)!=0){QIb(r,2400352,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;P1(b)}B=fX(g,b,N)|0;if((B|0)<0){z=B;A=35;break a}c[l>>2]=c[k>>2];L=c[j>>2]|0;if((L|0)==69642|(L|0)==69652|(L|0)==69654|(L|0)==69656|(L|0)==69653){if((c[p>>2]|0)<4){A=17;break a}P=c[q>>2]|0;Q=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;if((L|0)==69653){c[o>>2]=je(Q|0)|0;G=M;H=v;I=1;J=B;K=0;break}else{c[o>>2]=Q;G=M;H=v;I=1;J=B;K=0;break}}else if((L|0)==69655){c[o>>2]=(B<<1|0)/(c[n>>2]|0)|0;G=M;H=v;I=1;J=B;K=0;break}else if((L|0)==65554|(L|0)==86017){c[o>>2]=M;G=M;H=v;I=1;J=B;K=0;break}else{c[o>>2]=(N>>>0)/((ca(c[n>>2]|0,c[m>>2]|0)|0)>>>0)|0;G=M;H=v;I=1;J=B;K=0;break}}else if((A|0)==25){A=0;fD(g,-8,-1,1)|0;E=D;F=y;A=28}}while(0);do{if((A|0)==28){A=0;if((s|0)==0){R=fX(g,b,F)|0}else{R=hX(g,b,F)|0}if((R|0)<0){G=w;H=E;I=1;J=R;K=s;break}c[l>>2]=c[a>>2];c[f>>2]=c[f>>2]|E;G=w;H=E;I=1;J=R;K=(x|0)==1749636685|0}}while(0);if((I|0)==0|(K|0)!=0){s=K;t=J;u=I;v=H;w=G}else{z=J;A=35;break}}if((A|0)==17){KIb(r,16,2326032,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;P1(b);z=-1094995529;i=e;return z|0}else if((A|0)==35){i=e;return z|0}return 0}function eG(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;e=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((e|0)==544235878){a=b+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1){f=4}}else if((e|0)==1717661728){e=b+8|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==0){f=4}}do{if((f|0)==4){e=b+4|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)!=0){break}e=b+12|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==0){break}e=b+20|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==0){break}else{g=75}return g|0}}while(0);g=0;return g|0}function fG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a+16|0;hD(c[d>>2]|0,4,0)|0;if((FD(c[d>>2]|0)|0)!=0){e=-1094995529;i=b;return e|0}f=FD(c[d>>2]|0)|0;g=(f|0)!=0;if(f>>>0>1>>>0){e=-1094995529;i=b;return e|0}f=c[d>>2]|0;if(g){h=FD(f)|0;j=FD(c[d>>2]|0)|0;k=FD(c[d>>2]|0)|0;l=j;m=h}else{h=JD(f)|0;f=JD(c[d>>2]|0)|0;k=JD(c[d>>2]|0)|0;l=f;m=h}if((k|0)==0|(m|0)==0){e=-1094995529;i=b;return e|0}h=ZX(a,0)|0;if((h|0)==0){e=-12;i=b;return e|0}f=h+8|0;j=c[f>>2]|0;c[j+8>>2]=1;c[j+416>>2]=k;c[j+412>>2]=m;if((l|0)==1){QIb(a,2325952,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1094995529;i=b;return e|0}else if((l|0)==0){a=g?65536:65537;c[j+48>>2]=a;n=a}else if((l|0)==2){c[j+48>>2]=65540;n=65540}else{e=-1094995529;i=b;return e|0}j=g5a(n)|0;n=c[f>>2]|0;c[n+792>>2]=j;c[n+432>>2]=(ca(c[n+416>>2]|0,j)|0)/8|0;_X(h,64,1,c[n+412>>2]|0);n=hD(c[d>>2]|0,2024,0)|0;d=G;h=0;e=(d|0)<(h|0)|(d|0)==(h|0)&n>>>0<0>>>0?-1094995529:0;i=b;return e|0}function gG(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==70){if((a[d+1|0]|0)!=70){break}if((a[d+2|0]|0)!=77){break}if(((a[d+3|0]|0)-49&255)>>>0<2>>>0){e=101}else{break}return e|0}}while(0);e=0;return e|0}function hG(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;b=i;i=i+256|0;d=b+128|0;e=a+12|0;f=c[e>>2]|0;j=a+16|0;l=c[j>>2]|0;m=FD(l)|0;a:do{if((m|0)==843925062){n=b|0;o=c[e>>2]|0;p=c[j>>2]|0;q=JD(p)|0;r=o+44|0;c[r>>2]=q;b:do{if((q|0)==4096){s=OD(p)|0;t=o;c[t>>2]=s;c[t+4>>2]=G;if((c[p+88>>2]|0)==0){t=o+8|0;c[t>>2]=-1;c[t+4>>2]=2147483647}else{t=iD(p)|0;s=o+8|0;c[s>>2]=t;c[s+4>>2]=G}c:do{if((jD(p)|0)==0){d:while(1){s=JD(p)|0;t=JD(p)|0;u=fD(p,0,0,1)|0;v=wrc(u,G,t,0)|0;t=G;do{if((s|0)==1129270605){u=ZX(a,0)|0;if((u|0)==0){break b}_X(u,64,1,1e6);w=c[u+8>>2]|0;c[w+48>>2]=JD(p)|0;c[w+8>>2]=zD(p)|0;c[w+72>>2]=JD(p)|0;u=w+88|0;c[u>>2]=JD(p)|0;c[w+92>>2]=JD(p)|0;c[w+688>>2]=JD(p)|0;if((c[u>>2]&4194304|0)!=0){if((QX(w,p,JD(p)|0)|0)<0){x=-12;break d}}fD(p,v,t,0)|0;u=JD(p)|0;y=JD(p)|0;z=fD(p,0,0,1)|0;A=wrc(z,G,y,0)|0;y=G;if((u|0)==1398036041){c[w+104>>2]=JD(p)|0;c[w+108>>2]=JD(p)|0;c[w+120>>2]=HD(p)|0;c[w+124>>2]=HD(p)|0;c[w+136>>2]=HD(p)|0;c[w+140>>2]=JD(p)|0;c[w+500>>2]=zD(p)|0;c[w+504>>2]=zD(p)|0;z=w+508|0;c[z>>2]=zD(p)|0;B=w+492|0;g[B>>2]=+((HD(p)|0)>>>0>>>0)/1.0e4;C=w+496|0;g[C>>2]=+((HD(p)|0)>>>0>>>0)/1.0e4;c[w+76>>2]=JD(p)|0;LD(p,2147483647,n,128)|0;c[w+536>>2]=rJb(n)|0;c[w+540>>2]=JD(p)|0;c[w+544>>2]=JD(p)|0;c[w+524>>2]=JD(p)|0;D=OD(p)|0;E=G;g[w+184>>2]=(c[k>>2]=D,c[k+4>>2]=E,+h[k>>3]);E=OD(p)|0;D=G;g[w+160>>2]=(c[k>>2]=E,c[k+4>>2]=D,+h[k>>3]);D=OD(p)|0;E=G;g[w+188>>2]=(c[k>>2]=D,c[k+4>>2]=E,+h[k>>3]);E=OD(p)|0;D=G;g[w+172>>2]=(c[k>>2]=E,c[k+4>>2]=D,+h[k>>3]);c[w+784>>2]=JD(p)|0;c[w+680>>2]=JD(p)|0;c[w+156>>2]=JD(p)|0;c[w+180>>2]=JD(p)|0;c[w+324>>2]=JD(p)|0;c[w+144>>2]=JD(p)|0;c[w+296>>2]=JD(p)|0;c[w+836>>2]=JD(p)|0;c[w+596>>2]=JD(p)|0;D=OD(p)|0;E=G;g[w+548>>2]=(c[k>>2]=D,c[k+4>>2]=E,+h[k>>3]);c[w+52>>2]=JD(p)|0;c[w+808>>2]=zD(p)|0;c[w+568>>2]=JD(p)|0;c[w+232>>2]=JD(p)|0;c[w+268>>2]=JD(p)|0;c[w+276>>2]=JD(p)|0;c[w+360>>2]=JD(p)|0;c[w+308>>2]=JD(p)|0;c[w+168>>2]=JD(p)|0;E=OD(p)|0;D=G;g[B>>2]=(c[k>>2]=E,c[k+4>>2]=D,+h[k>>3]);D=OD(p)|0;E=G;g[C>>2]=(c[k>>2]=D,c[k+4>>2]=E,+h[k>>3]);c[z>>2]=JD(p)|0;c[w+364>>2]=JD(p)|0;F=y;H=A;break}else if((u|0)==1398030677){c[w+412>>2]=JD(p)|0;c[w+416>>2]=DD(p)|0;c[w+424>>2]=DD(p)|0;F=y;H=A;break}else{F=y;H=A;break}}else if((s|0)==1296124238){JD(p)|0;JD(p)|0;F=t;H=v}else if((s|0)==0){break c}else{F=t;H=v}}while(0);fD(p,H,F,0)|0;if((jD(p)|0)!=0){break c}}i=b;return x|0}}while(0);v=fD(p,0,0,1)|0;t=c[r>>2]|0;s=Drc(v,G,t,(t|0)<0|0?-1:0)|0;if(!((s|0)==0&(G|0)==0)){do{zD(p)|0;s=fD(p,0,0,1)|0;t=c[r>>2]|0;v=Drc(s,G,t,(t|0)<0|0?-1:0)|0;}while(!((v|0)==0&(G|0)==0))}v=o+72|0;c[o+64>>2]=v;c[o+68>>2]=v;c[o+48>>2]=0;v=o+56|0;c[v>>2]=0;c[v+4>>2]=0;c[o+16>>2]=0;c[o+40>>2]=1;x=0;i=b;return x|0}}while(0);o=a+24|0;if((c[o>>2]|0)==0){x=-1;i=b;return x|0}r=a+28|0;p=0;while(1){mJb((c[(c[(c[r>>2]|0)+(p<<2)>>2]|0)+8>>2]|0)+536|0);n=p+1|0;if(n>>>0<(c[o>>2]|0)>>>0){p=n}else{x=-1;break}}i=b;return x|0}else if((m|0)==827147846){p=JD(l)|0;o=f+44|0;c[o>>2]=p;if((p|0)!=4096){break}p=OD(l)|0;r=f;c[r>>2]=p;c[r+4>>2]=G;if((c[l+88>>2]|0)==0){r=f+8|0;c[r>>2]=-1;c[r+4>>2]=2147483647}else{r=iD(l)|0;p=f+8|0;c[p>>2]=r;c[p+4>>2]=G}p=JD(l)|0;JD(l)|0;e:do{if((p|0)>0){r=d|0;n=0;while(1){q=ZX(a,0)|0;if((q|0)==0){break a}_X(q,64,1,1e6);v=c[q+8>>2]|0;c[v+48>>2]=JD(l)|0;q=v+8|0;c[q>>2]=zD(l)|0;c[v+72>>2]=JD(l)|0;t=v+88|0;c[t>>2]=JD(l)|0;c[v+92>>2]=JD(l)|0;c[v+688>>2]=JD(l)|0;s=c[q>>2]|0;if((s|0)==0){c[v+104>>2]=JD(l)|0;c[v+108>>2]=JD(l)|0;c[v+120>>2]=HD(l)|0;c[v+124>>2]=HD(l)|0;c[v+136>>2]=HD(l)|0;c[v+140>>2]=JD(l)|0;c[v+500>>2]=zD(l)|0;c[v+504>>2]=zD(l)|0;q=v+508|0;c[q>>2]=zD(l)|0;A=v+492|0;g[A>>2]=+((HD(l)|0)>>>0>>>0)/1.0e4;y=v+496|0;g[y>>2]=+((HD(l)|0)>>>0>>>0)/1.0e4;c[v+76>>2]=JD(l)|0;LD(l,2147483647,r,128)|0;c[v+536>>2]=rJb(r)|0;c[v+540>>2]=JD(l)|0;c[v+544>>2]=JD(l)|0;c[v+524>>2]=JD(l)|0;w=OD(l)|0;u=G;g[v+184>>2]=(c[k>>2]=w,c[k+4>>2]=u,+h[k>>3]);u=OD(l)|0;w=G;g[v+160>>2]=(c[k>>2]=u,c[k+4>>2]=w,+h[k>>3]);w=OD(l)|0;u=G;g[v+188>>2]=(c[k>>2]=w,c[k+4>>2]=u,+h[k>>3]);u=OD(l)|0;w=G;g[v+172>>2]=(c[k>>2]=u,c[k+4>>2]=w,+h[k>>3]);c[v+784>>2]=JD(l)|0;c[v+680>>2]=JD(l)|0;c[v+156>>2]=JD(l)|0;c[v+180>>2]=JD(l)|0;c[v+324>>2]=JD(l)|0;c[v+144>>2]=JD(l)|0;c[v+296>>2]=JD(l)|0;c[v+836>>2]=JD(l)|0;c[v+596>>2]=JD(l)|0;w=OD(l)|0;u=G;g[v+548>>2]=(c[k>>2]=w,c[k+4>>2]=u,+h[k>>3]);c[v+52>>2]=JD(l)|0;c[v+808>>2]=zD(l)|0;c[v+568>>2]=JD(l)|0;c[v+232>>2]=JD(l)|0;c[v+268>>2]=JD(l)|0;c[v+276>>2]=JD(l)|0;c[v+360>>2]=JD(l)|0;c[v+308>>2]=JD(l)|0;c[v+168>>2]=JD(l)|0;u=OD(l)|0;w=G;g[A>>2]=(c[k>>2]=u,c[k+4>>2]=w,+h[k>>3]);w=OD(l)|0;u=G;g[y>>2]=(c[k>>2]=w,c[k+4>>2]=u,+h[k>>3]);c[q>>2]=JD(l)|0;c[v+364>>2]=JD(l)|0}else if((s|0)==1){c[v+412>>2]=JD(l)|0;c[v+416>>2]=DD(l)|0;c[v+424>>2]=DD(l)|0}else{break a}if((c[t>>2]&4194304|0)!=0){if((QX(v,l,JD(l)|0)|0)<0){x=-12;break}}n=n+1|0;if((n|0)>=(p|0)){break e}}i=b;return x|0}}while(0);p=fD(l,0,0,1)|0;n=c[o>>2]|0;r=Drc(p,G,n,(n|0)<0|0?-1:0)|0;if(!((r|0)==0&(G|0)==0)){do{zD(l)|0;r=fD(l,0,0,1)|0;n=c[o>>2]|0;p=Drc(r,G,n,(n|0)<0|0?-1:0)|0;}while(!((p|0)==0&(G|0)==0))}o=f+72|0;c[f+64>>2]=o;c[f+68>>2]=o;c[f+48>>2]=0;o=f+56|0;c[o>>2]=0;c[o+4>>2]=0;c[f+16>>2]=0;c[f+40>>2]=1;x=0;i=b;return x|0}}while(0);f=a+24|0;if((c[f>>2]|0)==0){x=-1;i=b;return x|0}l=a+28|0;a=0;while(1){mJb((c[(c[(c[l>>2]|0)+(a<<2)>>2]|0)+8>>2]|0)+536|0);d=a+1|0;if(d>>>0<(c[f>>2]|0)>>>0){a=d}else{x=-1;break}}i=b;return x|0}function iG(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;g=b+12|0;h=c[g>>2]|0;j=h+16|0;k=c[j>>2]|0;if((k|0)==0){l=(c[h+68>>2]|0)-(c[h+64>>2]|0)|0;do{if((l|0)<20){m=fD(c[b+16>>2]|0,0,0,1)|0;n=G;o=h;p=c[o>>2]|0;q=c[o+4>>2]|0;do{if((p|0)==0&(q|0)==0){o=h+8|0;r=c[o>>2]|0;s=c[o+4>>2]|0;if((m|0)==(r|0)&(n|0)==(s|0)){t=-541478725;i=f;return t|0}else{o=xrc(r,s,m,n)|0;u=G;v=o;break}}else{if((m|0)==(p|0)&(n|0)==(q|0)){t=-11;i=f;return t|0}if((n|0)<(q|0)|(n|0)==(q|0)&m>>>0<p>>>0){o=xrc(p,q,m,n)|0;u=G;v=o;break}else{o=h+8|0;s=c[o>>2]|0;r=c[o+4>>2]|0;o=xrc(-4096,-1,m,n)|0;w=wrc(o,G,p,q)|0;o=wrc(w,G,s,r)|0;u=G;v=o;break}}}while(0);q=c[h+44>>2]|0;p=Crc(v,u,q,(q|0)<0|0?-1:0)|0;n=q-14|0;q=Erc(n,(n|0)<0|0?-1:0,p,G)|0;p=wrc(q,G,l,(l|0)<0|0?-1:0)|0;q=G;n=0;m=(q|0)<(n|0)|(q|0)==(n|0)&p>>>0<20>>>0;if(m){t=m?-11:1}else{break}i=f;return t|0}}while(0);l=h+20|0;if((lG(b,l,16,1)|0)!=16){t=-1;i=f;return t|0}do{if(!((a[h+21|0]&2)==0)){if((lG(b,h+36|0,4,1)|0)==4){break}else{t=-1}i=f;return t|0}}while(0);c[j>>2]=1;x=c[g>>2]|0;y=l}else if((k|0)==1){x=h;y=h+20|0}else{t=0;i=f;return t|0}k=(d[h+23|0]|0)<<8|(d[h+22|0]|0)<<16|(d[h+24|0]|0);l=(c[x+68>>2]|0)-(c[x+64>>2]|0)|0;do{if((l|0)<(k|0)){g=fD(c[b+16>>2]|0,0,0,1)|0;u=G;v=x;m=c[v>>2]|0;p=c[v+4>>2]|0;do{if((m|0)==0&(p|0)==0){v=x+8|0;n=c[v>>2]|0;q=c[v+4>>2]|0;if((g|0)==(n|0)&(u|0)==(q|0)){t=-541478725;i=f;return t|0}else{v=xrc(n,q,g,u)|0;z=G;A=v;break}}else{if((g|0)==(m|0)&(u|0)==(p|0)){t=-11;i=f;return t|0}if((u|0)<(p|0)|(u|0)==(p|0)&g>>>0<m>>>0){v=xrc(m,p,g,u)|0;z=G;A=v;break}else{v=x+8|0;q=c[v>>2]|0;n=c[v+4>>2]|0;v=xrc(-4096,-1,g,u)|0;o=wrc(v,G,m,p)|0;v=wrc(o,G,q,n)|0;z=G;A=v;break}}}while(0);p=c[x+44>>2]|0;m=Crc(A,z,p,(p|0)<0|0?-1:0)|0;u=p-14|0;p=Erc(u,(u|0)<0|0?-1:0,m,G)|0;m=wrc(p,G,l,(l|0)<0|0?-1:0)|0;p=G;u=0;g=(u|0)>(p|0)|(u|0)==(p|0)&k>>>0>m>>>0;if(g){t=g?-11:1}else{break}i=f;return t|0}}while(0);l=(d[h+26|0]|0)<<8|(d[h+25|0]|0)<<16|(d[h+27|0]|0);if((K1(e,k)|0)<0){t=-12;i=f;return t|0}z=d[y]|0;c[e+32>>2]=z;if(!(z>>>0<(c[b+24>>2]|0)>>>0)){KIb(b,16,2400192,(y=i,i=i+8|0,c[y>>2]=z,y)|0);i=y;P1(e);c[j>>2]=0;t=-1;i=f;return t|0}y=fD(c[b+16>>2]|0,0,0,1)|0;z=e+64|0;c[z>>2]=y;c[z+4>>2]=G;z=h+21|0;if(!((a[z]&1)==0)){y=e+36|0;c[y>>2]=c[y>>2]|1}c[j>>2]=0;if((lG(b,c[e+24>>2]|0,k,0)|0)!=(k|0)){P1(e);t=-1;i=f;return t|0}k=h+28|0;b=k|0;j=k+4|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;b=je(k|0)|0;k=j|0;j=e+8|0;c[j>>2]=b;c[j+4>>2]=k;if((a[z]&2)==0){z=e+16|0;c[z>>2]=b;c[z+4>>2]=k}else{z=h+36|0;h=xrc(b,k,je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0,0)|0;z=e+16|0;c[z>>2]=h;c[z+4>>2]=G}c[e+48>>2]=l;t=0;i=f;return t|0}function jG(a){a=a|0;var b=0,d=0;b=a+24|0;if((c[b>>2]|0)==0){return 0}d=a+28|0;a=0;do{mJb((c[(c[(c[d>>2]|0)+(a<<2)>>2]|0)+8>>2]|0)+536|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);return 0}function kG(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0,E=0,H=0,I=0,J=0;b=a+12|0;g=c[b>>2]|0;h=g;i=c[h>>2]|0;j=c[h+4>>2]|0;k=g+8|0;l=c[k>>2]|0;m=c[k+4>>2]|0;n=a+16|0;do{if(((i|0)!=0|(j|0)!=0)&((j|0)<(m|0)|(j|0)==(m|0)&i>>>0<l>>>0)){a=c[n>>2]|0;fD(a,4096,0,0)|0;hD(a,4,0)|0;o=OD(a)|0;a=G;p=c[h>>2]|0;q=c[h+4>>2]|0;if((a|0)<(e|0)|(a|0)==(e|0)&o>>>0<d>>>0){r=0;s=4096;t=q;u=p;break}r=q;s=p;t=c[k+4>>2]|0;u=c[k>>2]|0}else{r=0;s=4096;t=m;u=l}}while(0);l=r;r=s;s=t;t=u;a:while(1){v=wrc(t,s,-4096,-1)|0;w=G;x=l;y=r;while(1){if((x|0)>(w|0)|(x|0)==(w|0)&y>>>0>v>>>0){z=13;break a}u=c[n>>2]|0;m=(c[b>>2]|0)+8|0;k=wrc(c[m>>2]|0,c[m+4>>2]|0,-4096,-1)|0;m=G;h=(m|0)<(x|0)|(m|0)==(x|0)&k>>>0<y>>>0;i=h?k:y;k=h?m:x;m=0;h=(k|0)>(m|0)|(k|0)==(m|0)&i>>>0>4096>>>0;fD(u,h?i:4096,h?k:0,0)|0;hD(u,4,0)|0;k=OD(u)|0;u=G;h=c[n>>2]|0;i=(c[b>>2]|0)+8|0;m=wrc(c[i>>2]|0,c[i+4>>2]|0,-4096,-1)|0;i=G;j=(i|0)<(w|0)|(i|0)==(w|0)&m>>>0<v>>>0;p=j?m:v;m=j?i:w;i=0;j=(m|0)>(i|0)|(m|0)==(i|0)&p>>>0>4096>>>0;fD(h,j?p:4096,j?m:0,0)|0;hD(h,4,0)|0;m=OD(h)|0;h=G;A=(u|0)>(e|0)|(u|0)==(e|0)&k>>>0>d>>>0;if(!(((h|0)>(e|0)|(h|0)==(e|0)&m>>>0>d>>>0)&(A^1))){z=8;break a}j=xrc(v,w,y,x)|0;B=+(j>>>0)+ +(G|0)*4294967296.0;j=xrc(d,e,k,u)|0;C=B*(+(j>>>0)+ +(G|0)*4294967296.0);j=xrc(m,h,k,u)|0;B=C/(+(j>>>0)+ +(G|0)*4294967296.0);j=Crc(~~+B>>>0,(F=+B,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0),4096,0)|0;u=j<<12|0>>>20;k=G<<12|j>>>20;if((k|0)>(x|0)|(k|0)==(x|0)&u>>>0>y>>>0){j=(k|0)<(w|0)|(k|0)==(w|0)&u>>>0<v>>>0;D=j?k:w;E=j?u:v}else{D=x;E=y}u=c[n>>2]|0;j=(c[b>>2]|0)+8|0;k=wrc(c[j>>2]|0,c[j+4>>2]|0,-4096,-1)|0;j=G;h=(j|0)<(D|0)|(j|0)==(D|0)&k>>>0<E>>>0;m=h?k:E;k=h?j:D;j=0;h=(k|0)>(j|0)|(k|0)==(j|0)&m>>>0>4096>>>0;fD(u,h?m:4096,h?k:0,0)|0;hD(u,4,0)|0;k=OD(u)|0;u=G;if((k|0)==(d|0)&(u|0)==(e|0)){H=D;I=E;break a}h=wrc(E,D,4096,0)|0;if((u|0)>(e|0)|(u|0)==(e|0)&k>>>0>d>>>0){l=x;r=y;s=D;t=E;continue a}else{x=G;y=h}}}if((z|0)==8){H=A?x:w;I=A?y:v}else if((z|0)==13){z=(f&1|0)!=0;H=z?x:w;I=z?y:v}v=c[n>>2]|0;n=(c[b>>2]|0)+8|0;b=wrc(c[n>>2]|0,c[n+4>>2]|0,-4096,-1)|0;n=G;y=(n|0)<(H|0)|(n|0)==(H|0)&b>>>0<I>>>0;z=y?b:I;I=y?n:H;H=0;n=(I|0)>(H|0)|(I|0)==(H|0)&z>>>0>4096>>>0;H=fD(v,n?z:4096,n?I:0,0)|0;I=G;n=0;if((I|0)<(n|0)|(I|0)==(n|0)&H>>>0<0>>>0){J=-1;return J|0}c[g+16>>2]=0;H=g+72|0;c[g+64>>2]=H;c[g+68>>2]=H;c[g+40>>2]=1;J=0;return J|0}function lG(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;g=c[a+12>>2]|0;h=a+16|0;j=c[h>>2]|0;a:do{if((d|0)>0){k=g+68|0;l=g+64|0;m=g+8|0;n=g+44|0;o=j+8|0;p=g+56|0;q=g+72|0;r=g+40|0;s=a;t=e;u=d;v=b;w=c[l>>2]|0;b:while(1){x=(c[k>>2]|0)-w|0;if((x|0)<0){y=-1;z=27;break}A=(t|0)==0;B=w;C=x;while(1){D=(C|0)>(u|0)?u:C;if((D|0)!=0){break}x=fD(j,0,0,1)|0;if((x|0)==(c[m>>2]|0)&(G|0)==(c[m+4>>2]|0)){x=c[n>>2]|0;fD(j,x,(x|0)<0|0?-1:0,0)|0;}while(1){if((c[o>>2]|0)!=(c[n>>2]|0)){x=fD(j,0,0,1)|0;E=G;SD(j,c[n>>2]|0)|0;fD(j,x,E,0)|0;}E=HD(j)|0;if((E|0)!=26221){KIb(s,16,2325928,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;x=E;do{if((jD(c[h>>2]|0)|0)!=0){z=13;break b}x=zD(c[h>>2]|0)|0|x<<8;}while((x|0)!=26221)}x=HD(j)|0;E=OD(j)|0;c[p>>2]=E;c[p+4>>2]=G;H=HD(j)|0;AD(j,q,(c[n>>2]|0)-14|0)|0;E=58-x+(c[n>>2]|0)|0;I=g+E|0;c[k>>2]=I;if((E|0)<72|(H|0)<0){y=-1;z=27;break b}if((c[r>>2]|0)==0){if((H&32768|0)==0){z=23;break}}if((H|0)!=0){z=21;break}E=fD(j,0,0,1)|0;x=G;J=c[n>>2]|0;K=Erc(J,(J|0)<0|0?-1:0,3,0)|0;L=G;if((x|0)<(L|0)|(x|0)==(L|0)&E>>>0<K>>>0){y=0;z=27;break b}K=-J|0;J=K;fD(j,J<<1|0>>>31,((K|0)<0|0?-1:0)<<1|J>>>31,1)|0;}if((z|0)==21){z=0;c[r>>2]=0;J=H&32767;if(J>>>0<14>>>0){y=-1;z=27;break b}K=g+(J+58)|0;c[l>>2]=K;if(A){M=u;break a}else{N=K}}else if((z|0)==23){z=0;c[l>>2]=q;N=q}K=I-N|0;if((K|0)<0){y=-1;z=27;break b}else{B=N;C=K}}nrc(v|0,B|0,D)|0;C=(c[l>>2]|0)+D|0;c[l>>2]=C;A=u-D|0;if((A|0)>0){t=0;u=A;v=v+D|0;w=C}else{M=A;break a}}if((z|0)==13){KIb(s,16,2270608,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;y=-1;i=f;return y|0}else if((z|0)==27){i=f;return y|0}}else{M=d}}while(0);y=d-M|0;i=f;return y|0}function mG(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+40|0;d=b|0;e=b+8|0;f=b+16|0;j=b+24|0;l=b+32|0;m=c[a+12>>2]|0;n=a+16|0;c[l>>2]=c[n>>2];o=LGb(c[a+1140>>2]|0,2400168,0,0)|0;do{if((o|0)!=0){p=iKb(m+4168|0,c[o+4>>2]|0,0)|0;if((p|0)<0){q=p}else{break}i=b;return q|0}}while(0);o=m+44|0;c[o>>2]=4096;kD(c[l>>2]|0,843925062);lD(c[l>>2]|0,c[o>>2]|0);sD(c[l>>2]|0,0,0);if((_D(l)|0)<0){q=-12;i=b;return q|0}p=a+24|0;lD(c[l>>2]|0,c[p>>2]|0);r=c[p>>2]|0;if((r|0)==0){s=0}else{t=c[a+28>>2]|0;u=0;v=0;while(1){w=(c[(c[(c[t+(v<<2)>>2]|0)+8>>2]|0)+72>>2]|0)+u|0;x=v+1|0;if(x>>>0<r>>>0){u=w;v=x}else{s=w;break}}}lD(c[l>>2]|0,s);s=c[n>>2]|0;v=aE(c[l>>2]|0,j)|0;lD(s,1296124238);lD(s,v);dD(s,c[j>>2]|0,v);kJb(c[j>>2]|0);a:do{if((c[p>>2]|0)!=0){j=a+28|0;v=0;while(1){s=c[(c[j>>2]|0)+(v<<2)>>2]|0;_X(s,64,1,1e6);if((_D(l)|0)<0){q=-12;y=22;break}u=c[s+8>>2]|0;lD(c[l>>2]|0,c[u+48>>2]|0);s=u+8|0;bD(c[l>>2]|0,c[s>>2]|0);lD(c[l>>2]|0,c[u+72>>2]|0);r=u+88|0;lD(c[l>>2]|0,c[r>>2]|0);lD(c[l>>2]|0,c[u+92>>2]|0);lD(c[l>>2]|0,c[u+688>>2]|0);if((c[r>>2]&4194304|0)!=0){r=u+100|0;lD(c[l>>2]|0,c[r>>2]|0);dD(c[l>>2]|0,c[u+96>>2]|0,c[r>>2]|0)}r=c[n>>2]|0;t=aE(c[l>>2]|0,f)|0;lD(r,1129270605);lD(r,t);dD(r,c[f>>2]|0,t);kJb(c[f>>2]|0);if((_D(l)|0)<0){q=-12;y=22;break}t=c[s>>2]|0;if((t|0)==0){lD(c[l>>2]|0,c[u+104>>2]|0);lD(c[l>>2]|0,c[u+108>>2]|0);tD(c[l>>2]|0,c[u+120>>2]|0);tD(c[l>>2]|0,c[u+124>>2]|0);tD(c[l>>2]|0,c[u+136>>2]|0);lD(c[l>>2]|0,c[u+140>>2]|0);bD(c[l>>2]|0,c[u+500>>2]|0);bD(c[l>>2]|0,c[u+504>>2]|0);s=u+508|0;bD(c[l>>2]|0,c[s>>2]|0);r=u+492|0;tD(c[l>>2]|0,~~(+g[r>>2]*1.0e4));w=u+496|0;tD(c[l>>2]|0,~~(+g[w>>2]*1.0e4));lD(c[l>>2]|0,c[u+76>>2]|0);x=c[u+536>>2]|0;mD(c[l>>2]|0,(x|0)==0?2325912:x)|0;lD(c[l>>2]|0,c[u+540>>2]|0);lD(c[l>>2]|0,c[u+544>>2]|0);lD(c[l>>2]|0,c[u+524>>2]|0);h[k>>3]=+g[u+184>>2];sD(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);h[k>>3]=+g[u+160>>2];sD(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);h[k>>3]=+g[u+188>>2];sD(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);h[k>>3]=+g[u+172>>2];sD(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);lD(c[l>>2]|0,c[u+784>>2]|0);lD(c[l>>2]|0,c[u+680>>2]|0);lD(c[l>>2]|0,c[u+156>>2]|0);lD(c[l>>2]|0,c[u+180>>2]|0);lD(c[l>>2]|0,c[u+324>>2]|0);lD(c[l>>2]|0,c[u+144>>2]|0);lD(c[l>>2]|0,c[u+296>>2]|0);lD(c[l>>2]|0,c[u+836>>2]|0);lD(c[l>>2]|0,c[u+596>>2]|0);h[k>>3]=+g[u+548>>2];sD(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);lD(c[l>>2]|0,c[u+52>>2]|0);bD(c[l>>2]|0,c[u+808>>2]|0);lD(c[l>>2]|0,c[u+568>>2]|0);lD(c[l>>2]|0,c[u+232>>2]|0);lD(c[l>>2]|0,c[u+268>>2]|0);lD(c[l>>2]|0,c[u+276>>2]|0);lD(c[l>>2]|0,c[u+360>>2]|0);lD(c[l>>2]|0,c[u+308>>2]|0);lD(c[l>>2]|0,c[u+168>>2]|0);h[k>>3]=+g[r>>2];sD(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);h[k>>3]=+g[w>>2];sD(c[l>>2]|0,c[k>>2]|0,c[k+4>>2]|0);lD(c[l>>2]|0,c[s>>2]|0);lD(c[l>>2]|0,c[u+364>>2]|0);s=c[n>>2]|0;w=aE(c[l>>2]|0,e)|0;lD(s,1398036041);lD(s,w);dD(s,c[e>>2]|0,w);kJb(c[e>>2]|0)}else if((t|0)==1){lD(c[l>>2]|0,c[u+412>>2]|0);oD(c[l>>2]|0,c[u+416>>2]|0);oD(c[l>>2]|0,c[u+424>>2]|0);u=c[n>>2]|0;t=aE(c[l>>2]|0,d)|0;lD(u,1398030677);lD(u,t);dD(u,c[d>>2]|0,t);kJb(c[d>>2]|0)}else{q=-1;y=22;break}v=v+1|0;if(!(v>>>0<(c[p>>2]|0)>>>0)){break a}}if((y|0)==22){i=b;return q|0}}}while(0);y=c[n>>2]|0;c[l>>2]=y;sD(y,0,0);y=fD(c[l>>2]|0,0,0,1)|0;n=c[o>>2]|0;p=Drc(y,G,n,(n|0)<0|0?-1:0)|0;n=c[l>>2]|0;if((p|0)==0&(G|0)==0){z=n}else{p=n;while(1){bD(p,0);n=fD(c[l>>2]|0,0,0,1)|0;y=c[o>>2]|0;d=Drc(n,G,y,(y|0)<0|0?-1:0)|0;y=c[l>>2]|0;if((d|0)==0&(G|0)==0){z=y;break}else{p=y}}}eD(z);c[m+64>>2]=m+72;z=(c[o>>2]|0)+58|0;c[m+68>>2]=m+z;if((z|0)<=71){KIb(0,0,2270576,(z=i,i=i+24|0,c[z>>2]=2221688,c[z+8>>2]=2186848,c[z+16>>2]=224,z)|0);i=z;Hd();return 0}c[m+48>>2]=0;z=m+56|0;c[z>>2]=0;c[z+4>>2]=0;c[m+40>>2]=1;q=0;i=b;return q|0}function nG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+24|0;f=e|0;g=b+12|0;h=c[g>>2]|0;j=h+4168|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=d+16|0;m=c[j>>2]|0;n=c[j+4>>2]|0;j=wrc(m,n,k,l)|0;o=G;p=f|0;a[p]=c[d+32>>2];q=f+1|0;a[q]=0;if((c[d+36>>2]&1|0)==0){r=2}else{a[q]=1;r=3}s=d+28|0;t=c[s>>2]|0;a[f+4|0]=t;a[f+3|0]=t>>>8;a[f+2|0]=t>>>16;t=c[d+48>>2]|0;a[f+7|0]=t;a[f+6|0]=t>>>8;a[f+5|0]=t>>>16;t=d+8|0;u=c[t>>2]|0;v=c[t+4>>2]|0;t=wrc(u,v,k,l)|0;l=G;k=je(t|0)|0;t=f+8|0;w=t|0;y=je(l|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;w=t+4|0;y=k|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;if((u|0)==(m|0)&(v|0)==(n|0)){x=16}else{a[q]=r;r=xrc(u,v,m,n)|0;n=f+16|0;y=je(r|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;x=20}n=h+48|0;r=h+64|0;if((c[n>>2]|0)==0){c[n>>2]=14-(h+72)+(c[r>>2]|0);n=h+56|0;c[n>>2]=j;c[n+4>>2]=o}o=h+68|0;h=b+16|0;b=x;x=p;while(1){p=c[r>>2]|0;n=(c[o>>2]|0)-p|0;j=(n|0)>(b|0)?b:n;nrc(p|0,x|0,j)|0;p=(c[r>>2]|0)+j|0;c[r>>2]=p;n=b-j|0;if(!(p>>>0<(c[o>>2]|0)>>>0)){p=c[g>>2]|0;f=c[h>>2]|0;m=p+68|0;v=p+64|0;u=c[v>>2]|0;q=(c[m>>2]|0)-u|0;mrc(u|0,0,q|0)|0;tD(f,26221);tD(f,q);q=p+56|0;sD(f,c[q>>2]|0,c[q+4>>2]|0);q=p+48|0;u=c[q>>2]|0;w=p+40|0;tD(f,(c[w>>2]|0)==0?u:u|32768);u=p+72|0;dD(f,u,(c[m>>2]|0)-u|0);eD(f);c[q>>2]=0;c[v>>2]=u;c[w>>2]=0}if((n|0)>0){b=n;x=x+j|0}else{break}}x=c[s>>2]|0;s=c[g>>2]|0;if((x|0)<=0){i=e;return 0}b=s+68|0;o=s+64|0;s=x;x=c[d+24>>2]|0;while(1){d=c[o>>2]|0;r=(c[b>>2]|0)-d|0;j=(r|0)>(s|0)?s:r;nrc(d|0,x|0,j)|0;d=(c[o>>2]|0)+j|0;c[o>>2]=d;r=s-j|0;if(!(d>>>0<(c[b>>2]|0)>>>0)){d=c[g>>2]|0;n=c[h>>2]|0;w=d+68|0;u=d+64|0;v=c[u>>2]|0;q=(c[w>>2]|0)-v|0;mrc(v|0,0,q|0)|0;tD(n,26221);tD(n,q);q=d+56|0;sD(n,c[q>>2]|0,c[q+4>>2]|0);q=d+48|0;v=c[q>>2]|0;f=d+40|0;tD(n,(c[f>>2]|0)==0?v:v|32768);v=d+72|0;dD(n,v,(c[w>>2]|0)-v|0);eD(n);c[q>>2]=0;c[u>>2]=v;c[f>>2]=0}if((r|0)>0){s=r;x=x+j|0}else{break}}i=e;return 0}function oG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=b+64|0;e=c[d>>2]|0;f=b+72|0;if(!(e>>>0>f>>>0)){return 0}g=c[a+16>>2]|0;a=b+68|0;h=(c[a>>2]|0)-e|0;mrc(e|0,0,h|0)|0;tD(g,26221);tD(g,h);h=b+56|0;sD(g,c[h>>2]|0,c[h+4>>2]|0);h=b+48|0;e=c[h>>2]|0;i=b+40|0;tD(g,(c[i>>2]|0)==0?e:e|32768);dD(g,f,(c[a>>2]|0)-f|0);eD(g);c[h>>2]=0;c[d>>2]=f;c[i>>2]=0;return 0}function pG(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,2108992,11)|0)==0;return(b?100:0)|0}function qG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=i;i=i+1312|0;e=d|0;f=d+256|0;g=d+264|0;h=d+272|0;j=d+280|0;k=d+1304|0;l=b+16|0;a:do{if((jD(c[l>>2]|0)|0)==0){m=j|0;n=j;o=e|0;p=h;q=p+4|0;r=b;s=b+1132|0;t=b+1136|0;u=b+1140|0;while(1){while(1){v=c[l>>2]|0;w=0;b:while(1){x=zD(v)|0;y=x&255;do{if(!(y<<24>>24==0)){z=x&255;if((z|0)==10){break}else if((z|0)==92){if((w|0)<1023){a[j+w|0]=y;A=w+1|0}else{A=w}B=A;C=(zD(v)|0)&255}else{B=w;C=y}if((B|0)>=1023){w=B;continue b}a[j+B|0]=C;w=B+1|0;continue b}}while(0);a[j+w|0]=0;if((jD(v)|0)!=0){break}y=a[m]|0;if((y<<24>>24|0)==59|(y<<24>>24|0)==35|(y<<24>>24|0)==0){w=0}else{break}}if((grc(m,2400016,8)|0)==0){D=16;break}if((grc(m,2325872,9)|0)==0){D=19;break}else{E=m}while(1){w=a[E]|0;if((w<<24>>24|0)==92){v=E+1|0;F=v;H=a[v]|0}else if((w<<24>>24|0)==61){D=64;break}else{F=E;H=w}if(H<<24>>24==0){break}E=F+1|0}do{if((D|0)==64){D=0;w=E-n|0;v=hJb(w+1|0)|0;if((v|0)==0){break}y=j+w|0;if((w|0)>0){w=v;x=m;while(1){z=(a[x]|0)==92?x+1|0:x;I=z+1|0;J=w+1|0;a[w]=a[z]|0;if(I>>>0<y>>>0){w=J;x=I}else{break}}a[J]=0}else{a[v]=0}x=E+1|0;w=lrc(x|0)|0;y=w+1|0;I=hJb(y)|0;if((I|0)==0){kJb(v);break}z=E+y|0;if((w|0)>0){w=I;y=x;while(1){x=(a[y]|0)==92?y+1|0:y;K=x+1|0;L=w+1|0;a[w]=a[x]|0;if(K>>>0<z>>>0){w=L;y=K}else{break}}a[L]=0}else{a[I]=0}MGb(u,v,I,12)|0}}while(0);if((jD(c[l>>2]|0)|0)!=0){M=s;break a}}if((D|0)==16){D=0;y=ZX(b,0)|0;if((y|0)==0){N=-12;D=79;break}w=c[y+8>>2]|0;c[w+8>>2]=2;c[w+48>>2]=135168;O=y+88|0}else if((D|0)==19){D=0;c[h>>2]=1;c[h+4>>2]=1e9;y=c[l>>2]|0;w=0;c:while(1){z=zD(y)|0;K=z&255;do{if(!(K<<24>>24==0)){x=z&255;if((x|0)==10){break}else if((x|0)==92){if((w|0)<255){a[e+w|0]=K;P=w+1|0}else{P=w}Q=P;R=(zD(y)|0)&255}else{Q=w;R=K}if((Q|0)>=255){w=Q;continue c}a[e+Q|0]=R;w=Q+1|0;continue c}}while(0);a[e+w|0]=0;if((jD(y)|0)!=0){break}K=a[o]|0;if((K<<24>>24|0)==59|(K<<24>>24|0)==35|(K<<24>>24|0)==0){w=0}else{break}}w=Bd(o|0,2270560,(y=i,i=i+16|0,c[y>>2]=h,c[y+8>>2]=q,y)|0)|0;i=y;d:do{if((w|0)!=0){K=c[l>>2]|0;z=0;e:while(1){x=zD(K)|0;S=x&255;do{if(!(S<<24>>24==0)){T=x&255;if((T|0)==10){break}else if((T|0)==92){if((z|0)<255){a[e+z|0]=S;U=z+1|0}else{U=z}V=U;W=(zD(K)|0)&255}else{V=z;W=S}if((V|0)>=255){z=V;continue e}a[e+V|0]=W;z=V+1|0;continue e}}while(0);a[e+z|0]=0;if((jD(K)|0)!=0){break d}S=a[o]|0;if((S<<24>>24|0)==59|(S<<24>>24|0)==35|(S<<24>>24|0)==0){z=0}else{break}}}}while(0);w=Bd(o|0,2221672,(y=i,i=i+8|0,c[y>>2]=f,y)|0)|0;i=y;f:do{if((w|0)==0){KIb(r,16,2186800,(y=i,i=i+8|0,c[y>>2]=o,y)|0);i=y;z=c[s>>2]|0;if((z|0)==0){X=0;Y=0}else{K=(c[(c[t>>2]|0)+(z-1<<2)>>2]|0)+24|0;z=c[K>>2]|0;S=c[K+4>>2]|0;K=(z|0)==0&(S|0)==(-2147483648|0);X=K?0:S;Y=K?0:z}c[f>>2]=Y;c[f+4>>2]=X}else{z=c[l>>2]|0;K=0;g:while(1){S=zD(z)|0;x=S&255;do{if(!(x<<24>>24==0)){I=S&255;if((I|0)==10){break}else if((I|0)==92){if((K|0)<255){a[e+K|0]=x;Z=K+1|0}else{Z=K}_=Z;$=(zD(z)|0)&255}else{_=K;$=x}if((_|0)>=255){K=_;continue g}a[e+_|0]=$;K=_+1|0;continue g}}while(0);a[e+K|0]=0;if((jD(z)|0)!=0){break f}x=a[o]|0;if((x<<24>>24|0)==59|(x<<24>>24|0)==35|(x<<24>>24|0)==0){K=0}else{break}}}}while(0);w=Bd(o|0,2157256,(y=i,i=i+8|0,c[y>>2]=g,y)|0)|0;i=y;if((w|0)==0){KIb(r,16,2132040,(y=i,i=i+8|0,c[y>>2]=o,y)|0);i=y;c[g>>2]=0;c[g+4>>2]=-2147483648;aa=-2147483648;ba=0}else{aa=c[g+4>>2]|0;ba=c[g>>2]|0}w=aY(b,c[s>>2]|0,p,c[f>>2]|0,c[f+4>>2]|0,ba,aa,0)|0;if((w|0)==0){N=-12;D=79;break}O=w+32|0}if((jD(c[l>>2]|0)|0)==0){u=O}else{M=s;break a}}if((D|0)==79){i=d;return N|0}}else{M=b+1132|0}}while(0);D=b+1056|0;c[D>>2]=0;c[D+4>>2]=0;D=c[M>>2]|0;if((D|0)==0){N=0;i=d;return N|0}M=c[(c[b+1136>>2]|0)+(D-1<<2)>>2]|0;D=M+24|0;O=c[D>>2]|0;l=c[D+4>>2]|0;c[k>>2]=1;c[k+4>>2]=1e6;D=XIb(O,l,M+4|0,k)|0;k=b+1064|0;c[k>>2]=D;c[k+4>>2]=G;N=0;i=d;return N|0}function rG(a,b){a=a|0;b=b|0;return-541478725|0}function sG(a){a=a|0;var b=0;b=a+16|0;dD(c[b>>2]|0,2108976,11);bD(c[b>>2]|0,49);bD(c[b>>2]|0,10);eD(c[b>>2]|0);return 0}function tG(a,b){a=a|0;b=b|0;return 0}function uG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+16|0;vG(c[d>>2]|0,c[a+1140>>2]|0);e=a+24|0;if((c[e>>2]|0)!=0){f=a+28|0;g=0;do{dD(c[d>>2]|0,2325728,8);bD(c[d>>2]|0,10);vG(c[d>>2]|0,c[(c[(c[f>>2]|0)+(g<<2)>>2]|0)+88>>2]|0);g=g+1|0;}while(g>>>0<(c[e>>2]|0)>>>0)}e=a+1132|0;if((c[e>>2]|0)==0){i=b;return 0}g=a+1136|0;a=0;do{f=c[(c[g>>2]|0)+(a<<2)>>2]|0;dD(c[d>>2]|0,2270456,9);bD(c[d>>2]|0,10);h=c[f+8>>2]|0;YD(c[d>>2]|0,2221656,(j=i,i=i+16|0,c[j>>2]=c[f+4>>2],c[j+8>>2]=h,j)|0)|0;i=j;h=f+16|0;k=c[h+4>>2]|0;YD(c[d>>2]|0,2186784,(j=i,i=i+16|0,c[j>>2]=c[h>>2],c[j+8>>2]=k,j)|0)|0;i=j;k=f+24|0;h=c[k+4>>2]|0;YD(c[d>>2]|0,2157240,(j=i,i=i+16|0,c[j>>2]=c[k>>2],c[j+8>>2]=h,j)|0)|0;i=j;vG(c[d>>2]|0,c[f+32>>2]|0);a=a+1|0;}while(a>>>0<(c[e>>2]|0)>>>0);i=b;return 0}function vG(a,b){a=a|0;b=b|0;var d=0,e=0;d=LGb(b,1023e4,0,2)|0;if((d|0)==0){return}else{e=d}do{wG(a,c[e>>2]|0);bD(a,61);wG(a,c[e+4>>2]|0);bD(a,10);e=LGb(b,1023e4,e,2)|0;}while((e|0)!=0);return}function wG(b,c){b=b|0;c=c|0;var d=0,e=0;d=c;a:while(1){c=a[d]|0;switch(c<<24>>24){case 35:case 59:case 61:case 92:case 10:{bD(b,92);e=a[d]|0;break};case 0:{break a;break};default:{e=c}}bD(b,e&255);d=d+1|0}return}function xG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+88|0;f=e|0;g=e+8|0;c[f>>2]=b;h=c[a+8>>2]|0;AFb(b,2509648,f)|0;b=(d&2|0)!=0;do{if((d&1|0)==0|b^1){if(!b){j=0;break}j=(c[h+8>>2]|0)==0?65:577}else{j=(c[h+8>>2]|0)==0?66:578}}while(0);b=nHb(c[f>>2]|0,j,(j=i,i=i+8|0,c[j>>2]=438,j)|0)|0;i=j;if((b|0)==-1){k=-(c[(pd()|0)>>2]|0)|0;i=e;return k|0}c[h+4>>2]=b;if((sd(b|0,g|0)|0)==0){l=(c[g+12>>2]&61440|0)==4096|0}else{l=0}c[a+24>>2]=l;k=0;i=e;return k|0}function yG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=c[a+8>>2]|0;a=c[e+12>>2]|0;f=Bb(c[e+4>>2]|0,b|0,((a|0)<(d|0)?a:d)|0)|0;if(!((f|0)==-1)){g=f;return g|0}g=-(c[(pd()|0)>>2]|0)|0;return g|0}function zG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=c[a+8>>2]|0;a=c[e+12>>2]|0;f=Td(c[e+4>>2]|0,b|0,((a|0)<(d|0)?a:d)|0)|0;if(!((f|0)==-1)){g=f;return g|0}g=-(c[(pd()|0)>>2]|0)|0;return g|0}function AG(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;d=i;i=i+80|0;f=d|0;g=c[(c[a+8>>2]|0)+4>>2]|0;do{if((e|0)==65536){if((sd(g|0,f|0)|0)<0){h=-(c[(pd()|0)>>2]|0)|0;break}if((c[f+12>>2]&61440|0)==4096){h=0;break}h=c[f+36>>2]|0}else{a=jb(g|0,b|0,e|0)|0;if((a|0)>=0){h=a;break}h=-(c[(pd()|0)>>2]|0)|0}}while(0);i=d;return(G=(h|0)<0|0?-1:0,h)|0}function BG(a){a=a|0;return Zb(c[(c[a+8>>2]|0)+4>>2]|0)|0}function CG(a){a=a|0;return c[(c[a+8>>2]|0)+4>>2]|0}function DG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;c[e>>2]=f;AFb(f,2509648,e)|0;if((cc(c[e>>2]|0,0)|0)<0){g=-(c[(pd()|0)>>2]|0)|0;i=d;return g|0}if((b&1|0)==0){h=0}else{h=(cc(c[e>>2]|0,4)|0)>>>31^1}if((b&2|0)==0){g=h;i=d;return g|0}else{g=(cc(c[e>>2]|0,2)|0)>-1;i=d;return(g?h|2:h)|0}return 0}function EG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((c[e+88>>2]|0)==0){f=-5;i=b;return f|0}g=iD(e)|0;h=wrc(g,G,-36,-1)|0;fD(e,h,G,0)|0;if((JD(e)|0)!=1382116964){KIb(a,16,2325656,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;f=-1094995529;i=b;return f|0}h=ZX(a,0)|0;if((h|0)==0){f=-12;i=b;return f|0}g=h+64|0;c[g>>2]=JD(e)|0;c[g+4>>2]=0;if((HD(e)|0)==0){hD(e,2,0)|0;g=h+8|0;k=c[g>>2]|0;c[k+8>>2]=0;c[k+48>>2]=14;c[k+140>>2]=28;c[k+52>>2]=0;k=HD(e)|0;c[(c[g>>2]|0)+120>>2]=k;k=HD(e)|0;c[(c[g>>2]|0)+124>>2]=k;c[d>>2]=HD(e)|0;_X(h,64,1,HD(e)|0);fD(e,0,0,0)|0;f=0;i=b;return f|0}else{QIb(a,2270376,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;f=-1163346256;i=b;return f|0}return 0}function FG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+12>>2]|0;e=c[c[a+28>>2]>>2]|0;f=a+16|0;if((jD(c[f>>2]|0)|0)!=0){g=-5;return g|0}a=fD(c[f>>2]|0,0,0,1)|0;h=e+8|0;e=c[h>>2]|0;i=c[e+124>>2]|0;j=d;d=c[e+120>>2]<<2;e=ca(d,(c[j>>2]|0)+i|0)|0;k=Crc(a,G,e,(e|0)<0|0?-1:0)|0;e=b+16|0;c[e>>2]=k;c[e+4>>2]=G;e=b+28|0;c[e>>2]=fX(c[f>>2]|0,b,ca(d,i)|0)|0;i=ca(c[(c[h>>2]|0)+120>>2]<<2,c[j>>2]|0)|0;hD(c[f>>2]|0,i,(i|0)<0|0?-1:0)|0;i=c[e>>2]|0;if((i|0)<0){g=i;return g|0}i=b+36|0;c[i>>2]=c[i>>2]|1;g=0;return g|0}function GG(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;f=c[a+16>>2]|0;g=0;h=(e|0)>(g|0)|(e|0)==(g|0)&d>>>0>0>>>0;g=c[(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+8>>2]|0;b=c[g+120>>2]|0;a=c[g+124>>2]|0;g=Erc(h?d<<2|0>>>30:0,h?e<<2|d>>>30:0,b,(b|0)<0|0?-1:0)|0;b=Erc(g,G,a,(a|0)<0|0?-1:0)|0;fD(f,b,G,0)|0;b=G;((b|0)<0|0?-1:0)>>31|((b|0)<0|0?-1:0)<<1;return b>>31|((b|0)<0|0?-1:0)<<1|0}function HG(a){a=a|0;var b=0,d=0;b=i;if((c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+140>>2]|0)==28){d=0;i=b;return d|0}KIb(a,16,2325616,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;d=-1094995529;i=b;return d|0}function IG(a,b){a=a|0;b=b|0;var d=0;d=c[a+12>>2]|0;dD(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);b=d;c[b>>2]=(c[b>>2]|0)+1;return 0}function JG(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=c[c[a+28>>2]>>2]|0;lD(d,1382116964);lD(d,c[b>>2]|0);tD(d,0);tD(d,0);b=e+8|0;tD(d,c[(c[b>>2]|0)+120>>2]|0);tD(d,c[(c[b>>2]|0)+124>>2]|0);tD(d,0);e=c[b>>2]|0;tD(d,(c[e+108>>2]|0)/(c[e+104>>2]|0)|0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);bD(d,0);return 0}function KG(a){a=a|0;var b=0;if((c[a+8>>2]|0)<4){return 0}else{b=(grc(c[a+4>>2]|0,2270352,4)|0)==0;return(b?50:0)|0}return 0}function LG(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+88|0;f=e|0;g=e+8|0;h=e+16|0;j=e+32|0;k=e+40|0;l=e+72|0;c[f>>2]=0;c[j>>2]=0;m=ZX(b,0)|0;if((m|0)==0){n=-12;i=e;return n|0}o=m+8|0;p=c[o>>2]|0;c[p+8>>2]=1;c[p+48>>2]=86028;c[m+236>>2]=1463898624;p=b+16|0;q=(FD(c[p>>2]|0)|0)==1130450022;r=c[p>>2]|0;if(!q){fD(r,-4,-1,1)|0;n=0;i=e;return n|0}if((jD(r)|0)!=0){n=0;i=e;return n|0}r=e+24|0;q=b+1140|0;s=b;t=j;u=l|0;v=l+12|0;l=m+40|0;w=k|0;x=k+24|0;y=m+56|0;z=1;a:while(1){while(1){if((c[f>>2]|0)!=0){n=0;A=36;break a}AD(c[p>>2]|0,r,4)|0;mea(r,f,g,h);B=c[g>>2]|0;if((B|0)==0|(B|0)==5|(B|0)==6|(B|0)==4){B=pJb((c[h>>2]|0)+16|0)|0;c[j>>2]=B;if((B|0)==0){n=-12;A=36;break a}C=AD(c[p>>2]|0,B,c[h>>2]|0)|0;if((C|0)!=(c[h>>2]|0)){D=-5;A=34;break a}}else{C=c[h>>2]|0;B=hD(c[p>>2]|0,C,(C|0)<0|0?-1:0)|0;C=B;if((C|0)<0){n=C;A=36;break a}}C=c[g>>2]|0;if((C|0)==5){B=c[h>>2]|0;if((B|0)<431){D=-1094995529;A=34;break a}E=c[j>>2]|0;F=(d[E+395|0]|0)-1|0;if((F|0)<1){D=-1094995529;A=34;break a}else{G=E+396|0;H=1;I=E;J=B}while(1){if((G+36-I|0)>(J|0)){K=-1094995529;L=I;break a}B=G;E=B|0;M=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=B+4|0;B=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=a[G+8|0]|0;nrc(u|0,G+9|0,12)|0;a[v]=0;N=a[G+35|0]|0;if(N<<24>>24==0){K=-1094995529;L=I;break a}O=je(M|0)|0;aY(b,E&255,l,je(B|0)|0,O|0,0,-2147483648,u)|0;if((H|0)>=(F|0)){break}G=G+(((N&255)*12|0)+36)|0;H=H+1|0;I=c[j>>2]|0;J=c[h>>2]|0}mJb(t)}else if((C|0)==0){break}else if((C|0)==6){P=t$(b,c[j>>2]|0,c[h>>2]|0)|0;mJb(t);if((P|0)<0){A=28;break a}}else{if(z){D=-1094995529;A=34;break a}do{if((C|0)==4){if((sR(b,q,c[j>>2]|0,c[h>>2]|0)|0)==0){break}KIb(s,24,2325560,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q}}while(0);mJb(t)}if((jD(c[p>>2]|0)|0)!=0){n=0;A=36;break a}}if(!z){D=-1094995529;A=34;break}if((c[h>>2]|0)!=34){D=-1094995529;A=34;break}c[(c[o>>2]|0)+96>>2]=c[j>>2];c[(c[o>>2]|0)+100>>2]=34;c[j>>2]=0;C=c[o>>2]|0;lea(C,k,c[C+96>>2]|0);C=c[w>>2]|0;do{if((C|0)>0){_X(m,64,1,C);F=c[x>>2]|0;N=c[x+4>>2]|0;O=0;if(!((N|0)>(O|0)|(N|0)==(O|0)&F>>>0>0>>>0)){break}c[y>>2]=F;c[y+4>>2]=N}}while(0);if((jD(c[p>>2]|0)|0)==0){z=0}else{n=0;A=36;break}}if((A|0)==28){KIb(s,16,2399840,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;n=P;i=e;return n|0}else if((A|0)==34){K=D;L=c[j>>2]|0}else if((A|0)==36){i=e;return n|0}kJb(L);n=K;i=e;return n|0}function MG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[b+1316>>2]|0;j=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;if((c[(c[b+12>>2]|0)+4>>2]|0)==0){k=0;i=d;return k|0}if((c[b+24>>2]|0)>>>0>1>>>0){KIb(b,16,2270272,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;k=-22;i=d;return k|0}if((c[j+48>>2]|0)!=86028){KIb(b,16,2221544,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;k=-22;i=d;return k|0}l=(h|0)<0?8192:h;h=(l|0)>16777215?16777215:l;l=b+16|0;m=PG(c[l>>2]|0,j,0)|0;if((m|0)!=0){k=m;i=d;return k|0}m=c[l>>2]|0;n=b+1140|0;b=(h|0)!=0;o=(c[j+88>>2]&8388608|0)!=0?2186720:2157192;cL(n,1253608,0);j=TY(c[n>>2]|0,o,e)|0;p=j+4|0;q=hJb(p)|0;c[g>>2]=q;if((q|0)==0){r=-12}else{a[q]=b?4:-124;a[q+3|0]=j;a[q+2|0]=j>>>8;a[q+1|0]=j>>>16;c[f>>2]=q+4;UY(f,n,o,c[e>>2]|0)|0;dD(m,q,p);mJb(g);c[f>>2]=0;r=0}if((r|0)!=0|b^1){k=r;i=d;return k|0}r=c[l>>2]|0;bD(r,129);vD(r,h);cD(r,0,h);k=0;i=d;return k|0}function NG(a,b){a=a|0;b=b|0;dD(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function OG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+16|0;d=b|0;e=c[a+16>>2]|0;if((c[(c[a+12>>2]|0)+4>>2]|0)==0){f=0;i=b;return f|0}if((jea(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0,b+8|0,d)|0)==0){f=-1;i=b;return f|0}if((c[e+88>>2]|0)==0){KIb(a,24,2325488,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=0;i=b;return f|0}else{a=fD(e,0,0,1)|0;g=G;fD(e,8,0,0)|0;dD(e,c[d>>2]|0,34);fD(e,a,g,0)|0;eD(e);f=0;i=b;return f|0}return 0}function PG(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+8|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;c[g>>2]=1130450022;c[g+4>>2]=570425344;a[g+4|0]=(e|0)!=0?-128:0;if((jea(d,j,h)|0)==0){k=-1;i=f;return k|0}dD(b,g,8);dD(b,c[h>>2]|0,34);k=0;i=f;return k|0}function QG(a){a=a|0;var b=0,e=0,f=0;if((c[a+8>>2]|0)<128){return 0}b=c[a+4>>2]|0;a=b+4|0;e=(d[a]|d[a+1|0]<<8)<<16>>16;if((e+20719&65535)>>>0>1>>>0&e<<16>>16!=-20668){return 0}e=b+16|0;a=e;do{if(!((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==-3590)){f=e;if(!((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)>>>0>2e3>>>0)){break}return 0}}while(0);e=b+8|0;if(((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>0>4096>>>0){return 0}else{e=b+10|0;return(((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>0>4096>>>0?0:99)|0}return 0}function RG(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+136|0;f=e|0;g=e+128|0;h=c[a+12>>2]|0;j=c[a+16>>2]|0;c[h+8>>2]=0;k=f|0;if((AD(j,k,128)|0)!=128){l=-5;i=e;return l|0}m=f+4|0;n=(d[m]|d[m+1|0]<<8)<<16>>16;m=f+16|0;o=m;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(p|0)==0?5:p;p=ZX(a,0)|0;if((p|0)==0){l=-12;i=e;return l|0}c[h>>2]=c[p>>2];q=p+8|0;r=c[q>>2]|0;c[r+8>>2]=0;c[r+48>>2]=51;c[r+52>>2]=0;s=f+8|0;t=(d[s]|d[s+1|0]<<8)<<16>>16;c[r+120>>2]=t&65535;s=f+10|0;f=(d[s]|d[s+1|0]<<8)<<16>>16;c[r+124>>2]=f&65535;if(t<<16>>16==0|f<<16>>16==0){KIb(a,24,2399568,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;f=c[q>>2]|0;c[f+120>>2]=640;c[f+124>>2]=480;v=f}else{v=r}if((PX(v,128)|0)!=0){l=-12;i=e;return l|0}nrc(c[(c[q>>2]|0)+96>>2]|0,k|0,128)|0;if((AD(j,g|0,6)|0)!=6){KIb(a,16,2325400,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;l=-5;i=e;return l|0}fD(j,-6,-1,1)|0;if((b[g+4>>1]|0)==-21846){v=ZX(a,0)|0;if((v|0)==0){l=-12;i=e;return l|0}c[h+4>>2]=c[v>>2];h=c[g>>2]|0;g=c[v+8>>2]|0;c[g+432>>2]=h;c[g+8>>2]=1;c[g+48>>2]=65541;c[g+52>>2]=0;c[g+412>>2]=22050;c[g+416>>2]=1;c[g+72>>2]=c[(c[q>>2]|0)+412>>2]<<3;c[g+792>>2]=8;r=g+448|0;c[r>>2]=4;c[r+4>>2]=0;c[g+100>>2]=0;_X(p,64,h,22050);_X(v,64,1,22050);l=0;i=e;return l|0}v=m;if((d[v]|d[v+1|0]<<8)<<16>>16<<16>>16==-3590){_X(p,64,5,70);fD(j,12,0,0)|0;kJb(c[(c[q>>2]|0)+96>>2]|0);if((PX(c[q>>2]|0,12)|0)!=0){l=-12;i=e;return l|0}nrc(c[(c[q>>2]|0)+96>>2]|0,k|0,12)|0;l=0;i=e;return l|0}if((n<<16>>16|0)==(-20668|0)|(n<<16>>16|0)==(-20718|0)){_X(p,64,o,1e3);l=0;i=e;return l|0}else if((n<<16>>16|0)==(-20719|0)){_X(p,64,o,70);l=0;i=e;return l|0}else{KIb(a,16,2270184,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;l=-1094995529;i=e;return l|0}return 0}function SG(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+8|0;g=f|0;h=c[d+12>>2]|0;j=c[d+16>>2]|0;d=g|0;k=g;l=g+4|0;g=h;m=e+32|0;n=h+8|0;o=e+8|0;p=e+64|0;q=e+24|0;r=h+4|0;while(1){if((AD(j,d,6)|0)!=6){s=-5;t=12;break}u=c[k>>2]|0;h=b[l>>1]|0;if((h<<16>>16|0)==(-2566|0)|(h<<16>>16|0)==(-3590|0)){if(u>>>0>6>>>0){t=6;break}}else if((h<<16>>16|0)==(-21846|0)){t=9;break}hD(j,u-6|0,0)|0;}if((t|0)==6){if((K1(e,u)|0)!=0){s=-5;i=f;return s|0}c[m>>2]=c[g>>2];g=c[n>>2]|0;c[n>>2]=g+1;c[o>>2]=g;c[o+4>>2]=(g|0)<0|0?-1:0;g=fD(j,0,0,1)|0;c[p>>2]=g;c[p+4>>2]=G;g=c[q>>2]|0;a[g]=a[d]|0;a[g+1|0]=a[d+1|0]|0;a[g+2|0]=a[d+2|0]|0;a[g+3|0]=a[d+3|0]|0;a[g+4|0]=a[d+4|0]|0;a[g+5|0]=a[d+5|0]|0;d=u-6|0;if((AD(j,(c[q>>2]|0)+6|0,d)|0)==(d|0)){s=d;i=f;return s|0}P1(e);s=-5;i=f;return s|0}else if((t|0)==9){if((K1(e,u)|0)!=0){s=-5;i=f;return s|0}hD(j,10,0)|0;c[m>>2]=c[r>>2];r=fD(j,0,0,1)|0;c[p>>2]=r;c[p+4>>2]=G;if((AD(j,c[q>>2]|0,u)|0)==(u|0)){s=u;i=f;return s|0}P1(e);s=-5;i=f;return s|0}else if((t|0)==12){i=f;return s|0}return 0}function TG(b){b=b|0;var e=0,f=0,g=0;e=c[b+4>>2]|0;do{if((a[e]|0)==70){if((a[e+1|0]|0)!=76){break}if((a[e+2|0]|0)!=86){break}if(!((d[e+3|0]|0)>>>0<5>>>0)){break}b=e+5|0;if((a[b]|0)!=0){break}f=b;if((je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)>>>0>8>>>0){g=100}else{break}return g|0}}while(0);g=0;return g|0}function UG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a+16|0;hD(c[d>>2]|0,4,0)|0;e=zD(c[d>>2]|0)|0;if((e|0)==0){KIb(a,24,2336352,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;f=a+20|0;c[f>>2]=c[f>>2]|1;g=5;h=f;j=4}else{f=a+20|0;c[f>>2]=c[f>>2]|1;if((e&1|0)==0){k=e;l=f}else{g=e;h=f;j=4}}if((j|0)==4){f=ZX(a,0)|0;if((f|0)==0){m=-12;i=b;return m|0}c[(c[f+8>>2]|0)+8>>2]=0;e=c[a+24>>2]|0;do{if(e>>>0>2>>>0){j=9}else{if((e|0)!=2){break}n=c[a+28>>2]|0;if((c[(c[(c[n>>2]|0)+8>>2]|0)+8>>2]|0)==2){break}if((c[(c[(c[n+4>>2]|0)+8>>2]|0)+8>>2]|0)!=2){j=9}}}while(0);if((j|0)==9){c[h>>2]=c[h>>2]&-2}_X(f,32,1,1e3);k=g;l=h}if((k&4|0)!=0){k=ZX(a,0)|0;if((k|0)==0){m=-12;i=b;return m|0}c[(c[k+8>>2]|0)+8>>2]=1;h=c[a+24>>2]|0;do{if(h>>>0>2>>>0){j=17}else{if((h|0)!=2){break}g=c[a+28>>2]|0;if((c[(c[(c[g>>2]|0)+8>>2]|0)+8>>2]|0)==2){break}if((c[(c[(c[g+4>>2]|0)+8>>2]|0)+8>>2]|0)!=2){j=17}}}while(0);if((j|0)==17){c[l>>2]=c[l>>2]&-2}_X(k,32,1,1e3)}k=JD(c[d>>2]|0)|0;fD(c[d>>2]|0,k,(k|0)<0|0?-1:0,0)|0;hD(c[d>>2]|0,4,0)|0;d=a+1056|0;c[d>>2]=0;c[d+4>>2]=0;m=0;i=b;return m|0}function VG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;e=i;i=i+16|0;f=e|0;g=c[b+12>>2]|0;h=g;j=b+16|0;k=g+80|0;l=g+84|0;m=g+48|0;n=b;o=b+24|0;p=b+28|0;q=b+1112|0;r=b+1116|0;s=b+20|0;t=f|0;u=0;a:while(1){v=fD(c[j>>2]|0,0,0,1)|0;w=G;x=zD(c[j>>2]|0)|0;y=ID(c[j>>2]|0)|0;z=ID(c[j>>2]|0)|0;A=(zD(c[j>>2]|0)|0)<<24;B=A|z;C=((A|0)<0|0?-1:0)|0;if((jD(c[j>>2]|0)|0)!=0){D=-541478725;E=178;break}hD(c[j>>2]|0,3,0)|0;A=c[k>>2]|0;do{if((A|0)<(c[l>>2]|0)){z=m+(A<<4)+8|0;F=c[z>>2]|0;H=c[z+4>>2]|0;if(!((v|0)==(F|0)&(w|0)==(H|0))){if(!((w|0)>(H|0)|(w|0)==(H|0)&v>>>0>F>>>0)){break}KIb(n,24,2342208,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;if((c[o>>2]|0)!=0){z=0;do{J=c[(c[p>>2]|0)+(z<<2)>>2]|0;K=J+404|0;L=c[K>>2]|0;if((L|0)>0){M=J+400|0;J=0;N=0;O=L;while(1){L=c[M>>2]|0;P=L+(J*24|0)|0;Q=P|0;R=c[Q+4>>2]|0;if((R|0)<(H|0)|(R|0)==(H|0)&(c[Q>>2]|0)>>>0<F>>>0){Q=L+(N*24|0)|0;L=P;c[Q>>2]=c[L>>2];c[Q+4>>2]=c[L+4>>2];c[Q+8>>2]=c[L+8>>2];c[Q+12>>2]=c[L+12>>2];c[Q+16>>2]=c[L+16>>2];c[Q+20>>2]=c[L+20>>2];S=N+1|0;T=c[K>>2]|0}else{S=N;T=O}L=J+1|0;if((L|0)<(T|0)){J=L;N=S;O=T}else{U=S;break}}}else{U=0}c[K>>2]=U;z=z+1|0;}while(z>>>0<(c[o>>2]|0)>>>0)}c[l>>2]=0;break}z=m+(A<<4)|0;F=xrc(B,C,c[z>>2]|0,c[z+4>>2]|0)|0;z=G;H=-1;O=(z|0)>(H|0)|(z|0)==(H|0)&F>>>0>-1>>>0;H=xrc(0,0,F,z)|0;N=O?z:G;z=0;if((N|0)<(z|0)|(N|0)==(z|0)&(O?F:H)>>>0<2501>>>0){c[k>>2]=A+1;break}KIb(n,24,2342208,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;if((c[o>>2]|0)!=0){H=0;do{F=c[(c[p>>2]|0)+(H<<2)>>2]|0;O=F+404|0;z=c[O>>2]|0;if((z|0)>0){N=F+400|0;F=0;J=0;M=z;while(1){z=c[N>>2]|0;L=z+(F*24|0)|0;Q=L|0;P=c[Q+4>>2]|0;if((P|0)<(w|0)|(P|0)==(w|0)&(c[Q>>2]|0)>>>0<v>>>0){Q=z+(J*24|0)|0;z=L;c[Q>>2]=c[z>>2];c[Q+4>>2]=c[z+4>>2];c[Q+8>>2]=c[z+8>>2];c[Q+12>>2]=c[z+12>>2];c[Q+16>>2]=c[z+16>>2];c[Q+20>>2]=c[z+20>>2];V=J+1|0;W=c[O>>2]|0}else{V=J;W=M}z=F+1|0;if((z|0)<(W|0)){F=z;J=V;M=W}else{X=V;break}}}else{X=0}c[O>>2]=X;H=H+1|0;}while(H>>>0<(c[o>>2]|0)>>>0)}c[l>>2]=0}}while(0);do{if((y|0)==0){Y=u}else{A=fD(c[j>>2]|0,0,0,1)|0;H=wrc(A,G,y,(y|0)<0|0?-1:0)|0;A=G;b:do{if((x|0)==18){if(!((y|0)>18&((B|0)==0&(C|0)==0))){Z=y;_=0;$=2;break}M=fD(c[j>>2]|0,0,0,1)|0;J=G;F=c[j>>2]|0;do{if((zD(F)|0)==2){N=HD(F)|0;if((N|0)>=11){hD(F,N,(N|0)<0|0?-1:0)|0;break}AD(F,t,N)|0;a[f+N|0]=0;if((N|0)<0){break}if((irc(t,2108904)|0)==0){break}if((irc(t,2626832)|0)!=0){break}N=c[o>>2]|0;if((N|0)==0){aa=0;ba=0}else{K=c[p>>2]|0;z=0;Q=0;L=0;while(1){P=c[K+(L<<2)>>2]|0;R=c[(c[P+8>>2]|0)+8>>2]|0;if((R|0)==0){ca=P;da=z}else if((R|0)==1){ca=Q;da=P}else{ca=Q;da=z}P=L+1|0;if(P>>>0<N>>>0){z=da;Q=ca;L=P}else{aa=da;ba=ca;break}}}if((YG(b,aa,ba,t,H,A,0)|0)>-1){E=44;break b}}}while(0);fD(c[j>>2]|0,M,J,0)|0;Z=y;_=0;$=2}else if((x|0)==8){Z=y-1|0;_=zD(c[j>>2]|0)|0;$=1}else if((x|0)==9){F=zD(c[j>>2]|0)|0;if((F&240|0)==80){E=44}else{Z=y-1|0;_=F;$=0}}else{KIb(n,48,2399512,(I=i,i=i+24|0,c[I>>2]=x,c[I+8>>2]=y,c[I+16>>2]=0,I)|0);i=I;E=44}}while(0);if((E|0)==44){E=0;fD(c[j>>2]|0,H,A,0)|0;Y=u;break}if((Z|0)==0){Y=u;break}F=c[o>>2]|0;c:do{if((F|0)==0){ea=u;fa=0}else{O=c[p>>2]|0;L=_<<2&8;Q=L+8|0;z=_&240;N=z>>>4;K=(L|0)==0?65541:65536;L=_&15;if(($|0)==1){ga=0}else{P=0;while(1){R=c[O+(P<<2)>>2]|0;d:do{if(($|0)==2){if((c[(c[R+8>>2]|0)+8>>2]|0)==2){ea=R;fa=P;break c}}else if(($|0)==0){ha=c[R+8>>2]|0;if((c[ha+8>>2]|0)!=0){break}if((c[q>>2]|0)!=0){ea=R;fa=P;break c}ia=c[ha+48>>2]|0;if((ia|0)==0){if((c[ha+52>>2]|0)==0){ea=R;fa=P;break c}}switch(L|0){case 3:{if((ia|0)==87){ea=R;fa=P;break c}else{break d}break};case 6:{if((ia|0)==132){ea=R;fa=P;break c}else{break d}break};case 4:{if((ia|0)==93){ea=R;fa=P;break c}else{break d}break};case 5:{if((ia|0)==107){ea=R;fa=P;break c}else{break d}break};case 7:{if((ia|0)==28){ea=R;fa=P;break c}else{break d}break};case 2:{if((ia|0)==22){ea=R;fa=P;break c}else{break d}break};default:{if((c[ha+52>>2]|0)==(L|0)){ea=R;fa=P;break c}else{break d}}}}}while(0);ha=P+1|0;if(ha>>>0<F>>>0){P=ha}else{ea=R;fa=ha;break c}}}while(1){P=c[O+(ga<<2)>>2]|0;L=c[P+8>>2]|0;e:do{if((c[L+8>>2]|0)==1){if((c[r>>2]|0)!=0){ea=P;fa=ga;break c}J=c[L+48>>2]|0;if((J|0)==0){if((c[L+52>>2]|0)==0){ea=P;fa=ga;break c}}if((c[L+792>>2]|0)!=(Q|0)){break}switch(z|0){case 80:case 64:case 96:{if((J|0)==86050){ea=P;fa=ga;break c}else{break e}break};case 32:{if((J|0)==86017){ea=P;fa=ga;break c}else{break e}break};case 176:{if((J|0)==86052){ea=P;fa=ga;break c}else{break e}break};case 16:{if((J|0)==69645){ea=P;fa=ga;break c}else{break e}break};case 160:{if((J|0)==86018){ea=P;fa=ga;break c}else{break e}break};case 48:{if((K|0)==(J|0)){ea=P;fa=ga;break c}else{break e}break};case 0:{if((K|0)==(J|0)){ea=P;fa=ga;break c}else{break e}break};case 112:{if((c[L+412>>2]|0)==8e3&(J|0)==65543){ea=P;fa=ga;break c}else{break e}break};case 128:{if((c[L+412>>2]|0)==8e3&(J|0)==65542){ea=P;fa=ga;break c}else{break e}break};default:{if((c[L+52>>2]|0)==(N|0)){ea=P;fa=ga;break c}else{break e}}}}}while(0);L=ga+1|0;if(L>>>0<F>>>0){ga=L}else{ea=P;fa=L;break}}}}while(0);if((fa|0)==(F|0)){KIb(n,24,2325352,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;N=c[1212320+($<<2)>>2]|0;K=ZX(b,0)|0;if((K|0)==0){D=-12;E=178;break a}c[(c[K+8>>2]|0)+8>>2]=N;N=c[o>>2]|0;do{if(N>>>0>2>>>0){E=86}else{if((N|0)!=2){break}z=c[p>>2]|0;if((c[(c[(c[z>>2]|0)+8>>2]|0)+8>>2]|0)==2){break}if((c[(c[(c[z+4>>2]|0)+8>>2]|0)+8>>2]|0)!=2){E=86}}}while(0);if((E|0)==86){E=0;c[s>>2]=c[s>>2]&-2}_X(K,32,1,1e3);ja=K}else{ja=ea}N=c[ja+76>>2]|0;if((N|0)>31){if((_&240|0)==16|($|0)==1){E=91}}else{if((N|0)>15){E=91}else{E=93;break a}}if((E|0)==91){E=0;if(!((_&240|0)==48&($|0)==0|(N|0)>47)){E=93;break a}}fD(c[j>>2]|0,H,A,0)|0;Y=ja}}while(0);hD(c[j>>2]|0,4,0)|0;u=Y}if((E|0)==93){Y=_&240;u=(Y|0)==16;ea=($|0)==1;if(u|ea){xX(ja,v,w,B,C,Z,0,1)|0}w=c[j>>2]|0;do{if((c[w+88>>2]|0)!=0){v=b+1064|0;s=c[v>>2]|0;p=c[v+4>>2]|0;if(!((s|0)==0&(p|0)==0|(s|0)==0&(p|0)==(-2147483648|0))){break}p=g+88|0;if((c[p>>2]|0)!=0){break}s=fD(w,0,0,1)|0;o=G;fa=iD(c[j>>2]|0)|0;ga=G;r=fa;while(1){fa=c[j>>2]|0;q=wrc(r,ga,-4,-1)|0;fD(fa,q,G,0)|0;q=JD(c[j>>2]|0)|0;fa=c[j>>2]|0;t=wrc(r,ga,-3,-1)|0;ba=q;aa=(q|0)<0|0?-1:0;ca=xrc(t,G,ba,aa)|0;fD(fa,ca,G,0)|0;if((q|0)!=((ID(c[j>>2]|0)|0)+11|0)){break}ca=ID(c[j>>2]|0)|0;ka=(zD(c[j>>2]|0)|0)<<24|ca;if((ka|0)!=0){E=102;break}ca=0;fa=wrc(r,ga,-8,-1)|0;t=G;if((ga|0)<(ca|0)|(ga|0)==(ca|0)&r>>>0<8>>>0|((t|0)<(aa|0)|(t|0)==(aa|0)&fa>>>0<ba>>>0)){break}ba=q+4|0;q=xrc(r,ga,ba,(ba|0)<0|0?-1:0)|0;ga=G;r=q}if((E|0)==102){r=Erc(ka,0,1e6,0)|0;ga=Frc(r,G,1e3,0)|0;c[v>>2]=ga;c[v+4>>2]=G}fD(c[j>>2]|0,s,o,0)|0;c[p>>2]=1}}while(0);f:do{if(ea){ka=_&1;w=ka+1|0;ga=44100<<(_>>>2&3)>>3;r=(_<<2&8)+8|0;q=ja+8|0;ba=c[q>>2]|0;fa=ba+416|0;aa=ba+412|0;do{if((c[fa>>2]|0)==0){E=110}else{t=c[aa>>2]|0;if((t|0)==0){E=110;break}ca=c[ba+792>>2]|0;if((ca|0)==0){E=110}else{la=t;ma=ca}}}while(0);if((E|0)==110){c[fa>>2]=w;p=ba+448|0;c[p>>2]=4-ka;c[p+4>>2]=0;c[aa>>2]=ga;c[ba+792>>2]=r;la=ga;ma=r}p=ba+48|0;if((c[p>>2]|0)!=0){switch(Y|0){case 0:case 48:case 160:case 16:case 96:{na=Z;oa=ga;pa=w;qa=q;break f;break};case 176:{na=Z;oa=16e3;pa=w;qa=q;break f;break};case 32:{c[ja+236>>2]=1;na=Z;oa=ga;pa=w;qa=q;break f;break};case 80:{na=Z;oa=8e3;pa=w;qa=q;break f;break};case 64:{na=Z;oa=16e3;pa=w;qa=q;break f;break};case 128:{na=Z;oa=8e3;pa=w;qa=q;break f;break};case 112:{na=Z;oa=8e3;pa=w;qa=q;break f;break};default:{QIb(n,2131968,(I=i,i=i+8|0,c[I>>2]=Y>>>4,I)|0);i=I;na=Z;oa=ga;pa=w;qa=q;break f}}}switch(Y|0){case 0:{c[p>>2]=(ma|0)==8?65541:65536;ra=ba;sa=la;break};case 48:{c[p>>2]=(ma|0)==8?65541:65536;ra=ba;sa=la;break};case 160:{c[p>>2]=86018;ra=ba;sa=la;break};case 16:{c[p>>2]=69645;ra=ba;sa=la;break};case 176:{c[p>>2]=86052;c[ba+412>>2]=16e3;ra=ba;sa=16e3;break};case 32:{c[p>>2]=86017;c[ja+236>>2]=1;ra=ba;sa=la;break};case 80:{c[ba+412>>2]=8e3;c[p>>2]=86050;ra=ba;sa=8e3;break};case 64:{c[ba+412>>2]=16e3;c[p>>2]=86050;ra=ba;sa=16e3;break};case 96:{c[p>>2]=86050;ra=ba;sa=la;break};case 128:{c[ba+412>>2]=8e3;c[p>>2]=65542;ra=ba;sa=8e3;break};case 112:{c[ba+412>>2]=8e3;c[p>>2]=65543;ra=ba;sa=8e3;break};default:{p=Y>>>4;QIb(n,2131968,(I=i,i=i+8|0,c[I>>2]=p,I)|0);i=I;c[ba+52>>2]=p;p=c[q>>2]|0;ra=p;sa=c[p+412>>2]|0}}c[g+36>>2]=sa;p=c[ra+416>>2]|0;c[g+40>>2]=p;na=Z;oa=sa;pa=p;qa=q}else{if(($|0)!=0){na=Z;oa=0;pa=0;qa=ja+8|0;break}p=_&15;o=ja+8|0;s=c[o>>2]|0;switch(p|0){case 2:{c[s+48>>2]=22;ta=0;break};case 8:{c[s+48>>2]=5;ta=0;break};case 3:{c[s+48>>2]=87;ta=0;break};case 6:{c[s+48>>2]=132;ta=0;break};case 4:{c[s+48>>2]=93;E=143;break};case 5:{c[s+48>>2]=107;E=143;break};case 7:{c[s+48>>2]=28;c[ja+236>>2]=2;ta=3;break};case 9:{c[s+48>>2]=13;ta=3;break};default:{QIb(n,2157168,(I=i,i=i+8|0,c[I>>2]=p,I)|0);i=I;c[s+52>>2]=p;ta=0}}do{if((E|0)==143){if((c[s+100>>2]|0)!=1){PX(s,1)|0}p=s+96|0;v=c[j>>2]|0;if((c[p>>2]|0)==0){hD(v,1,0)|0;ta=1;break}else{ca=(zD(v)|0)&255;a[c[p>>2]|0]=ca;ta=1;break}}}while(0);na=Z-ta|0;oa=0;pa=0;qa=o}}while(0);ta=c[(c[qa>>2]|0)+48>>2]|0;do{if((ta|0)==86018|(ta|0)==28|(ta|0)==13){Z=zD(c[j>>2]|0)|0;_=na-1|0;sa=c[(c[qa>>2]|0)+48>>2]|0;if((sa|0)==28|(sa|0)==13){sa=(ID(c[j>>2]|0)|0)-8388608|0;ra=sa^-8388608;Y=wrc(ra,(ra|0)<0|0?-1:0,B,C)|0;ra=G;la=g+8|0;if((sa|0)>-1){c[la>>2]=1;KIb(n,24,2270128,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}sa=(c[la>>2]|0)==0;ua=sa?C:-2147483648;va=sa?B:0;wa=ra;xa=Y}else{ua=C;va=B;wa=-2147483648;xa=0}if((Z|0)!=0){ya=_;za=ua;Aa=va;Ba=wa;Ca=xa;E=166;break}Z=c[qa>>2]|0;if((c[Z+96>>2]|0)!=0){if((c[Z+48>>2]|0)!=86018){ya=_;za=ua;Aa=va;Ba=wa;Ca=xa;E=166;break}Z=c[j>>2]|0;Y=h+12+($<<2)|0;kJb(c[Y>>2]|0);ra=pJb(na+15|0)|0;c[Y>>2]=ra;if((ra|0)==0){D=-12;i=e;return D|0}else{c[h+24+($<<2)>>2]=_;AD(Z,ra,_)|0;Da=-11;break}}kJb(0);ra=(QX(c[qa>>2]|0,c[j>>2]|0,_)|0)>>31&-12;if((ra|0)<0){D=ra;i=e;return D|0}ra=LGb(c[b+1140>>2]|0,2221512,0,0)|0;_=c[qa>>2]|0;if((c[_+48>>2]|0)!=86018|(ra|0)==0){Da=-11;break}if((irc(c[ra+4>>2]|0,2186672)|0)!=0){Da=-11;break}c[_+100>>2]=2;Da=-11}else{ya=na;za=C;Aa=B;Ba=-2147483648;Ca=0;E=166}}while(0);g:do{if((E|0)==166){if((ya|0)==0){Da=-11;break}B=fX(c[j>>2]|0,d,ya)|0;if((B|0)<0){D=B;i=e;return D|0}C=d+16|0;c[C>>2]=Aa;c[C+4>>2]=za;C=(Ca|0)==0&(Ba|0)==(-2147483648|0);na=d+8|0;c[na>>2]=C?Aa:Ca;c[na+4>>2]=C?za:Ba;c[d+32>>2]=c[ja>>2];C=g+12+($<<2)|0;do{if((c[C>>2]|0)!=0){na=g+24+($<<2)|0;qa=U1(d,1,c[na>>2]|0)|0;if((qa|0)==0){break}nrc(qa|0,c[C>>2]|0,c[na>>2]|0)|0;mJb(C);c[na>>2]=0}}while(0);do{if(ea){C=g+36|0;o=g+40|0;if((oa|0)==(c[C>>2]|0)){if((pa|0)==(c[o>>2]|0)){break}}c[C>>2]=oa;c[o>>2]=pa;tY(d,pa,0,0,oa,0,0)|0}else{if(!(u|($|0)==2)){Da=B;break g}}}while(0);o=d+36|0;c[o>>2]=c[o>>2]|1;Da=B}}while(0);hD(c[j>>2]|0,4,0)|0;D=Da;i=e;return D|0}else if((E|0)==178){i=e;return D|0}return 0}function WG(a){a=a|0;var b=0;b=c[a+12>>2]|0;mJb(b+12|0);mJb(b+16|0);mJb(b+20|0);return 0}function XG(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;c[(c[a+12>>2]|0)+84>>2]=0;g=ZD(c[a+16>>2]|0,b,d,e,f)|0;return g|0}function YG(b,d,e,f,g,j,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0.0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;m=i;i=i+528|0;n=m|0;o=m+256|0;p=m+264|0;q=m+272|0;r=b+12|0;s=c[r>>2]|0;t=c[b+16>>2]|0;u=zD(t)|0;a:do{switch(u|0){case 0:{v=OD(t)|0;w=G;x=(c[k>>2]=v,c[k+4>>2]=w,+h[k>>3]);break};case 2:{w=HD(t)|0;if((w|0)<256){AD(t,q|0,w)|0;a[q+w|0]=0;if((w|0)<0){y=-1}else{x=0.0;break a}i=m;return y|0}else{hD(t,w,(w|0)<0|0?-1:0)|0;y=-1;i=m;return y|0}break};case 3:{w=(e|0)!=0;do{if(!((d|0)==0&(w^1)|(f|0)==0)){if((c[t+88>>2]|0)==0){break}if(!((irc(2601032,f)|0)==0&(l|0)==1)){break}v=w?e:d;z=n|0;A=o;B=p;C=c[r>>2]|0;c[o>>2]=0;c[p>>2]=0;D=fD(t,0,0,1)|0;E=G;do{if((c[v+404>>2]|0)>0){KIb(b,24,2378352,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;I=0}else{if((c[b+1084>>2]&2|0)!=0){I=0;break}J=fD(t,0,0,1)|0;K=G;L=wrc(g,j,-2,-1)|0;M=G;b:do{if((K|0)<(M|0)|(K|0)==(M|0)&J>>>0<L>>>0){N=wrc(g,j,-1,-1)|0;O=G;P=0;S=0;while(1){T=HD(t)|0;if((T|0)>=256){U=16;break}AD(t,z,T)|0;a[n+T|0]=0;if((T|0)<=0){V=S;W=-38;X=P;break}if((zD(t)|0)!=10){V=S;W=-38;X=P;break}Y=JD(t)|0;if(Y>>>0>268435455>>>0){V=S;W=-38;X=P;break}if((irc(2372544,z)|0)==0){if((c[o>>2]|0)==0){Z=o;_=Y;$=P}else{U=22}}else{U=22}if((U|0)==22){U=0;if((irc(2360808,z)|0)!=0){V=S;W=-38;X=P;break}if((c[p>>2]|0)==0){Z=p;_=S;$=Y}else{V=S;W=-38;X=P;break}}aa=pJb(Y<<3)|0;c[Z>>2]=aa;if((aa|0)==0){ca=-12;break b}c:do{if((Y|0)!=0){aa=0;do{da=fD(t,0,0,1)|0;ea=G;if(!((ea|0)<(O|0)|(ea|0)==(O|0)&da>>>0<N>>>0)){break c}if((zD(t)|0)!=0){fa=-38;U=41;break b}da=OD(t)|0;ea=G;ga=(c[k>>2]=da,c[k+4>>2]=ea,+h[k>>3]);ea=(F=+ga,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);da=(c[Z>>2]|0)+(aa<<3)|0;c[da>>2]=~~+ga>>>0;c[da+4>>2]=ea;aa=aa+1|0;}while(aa>>>0<Y>>>0)}}while(0);if((c[o>>2]|0)!=0){if((c[p>>2]|0)!=0){V=_;W=0;X=$;break}}Y=fD(t,0,0,1)|0;aa=G;if((aa|0)<(M|0)|(aa|0)==(M|0)&Y>>>0<L>>>0){P=$;S=_}else{V=_;W=-38;X=$;break}}if((U|0)==16){hD(t,T,(T|0)<0|0?-1:0)|0;V=S;W=-38;X=P}if(!((V|0)==(X|0)&X>>>0>1>>>0)){fa=W;U=41;break}N=c[p>>2]|0;O=c[N>>2]|0;Y=c[N+4>>2]|0;if((Y|0)<(j|0)|(Y|0)==(j|0)&O>>>0<g>>>0){fa=W;U=41;break}if((X|0)==0){ca=W;break}N=C+48|0;aa=C+84|0;ea=0;da=Y;Y=O;while(1){O=(c[o>>2]|0)+(ea<<3)|0;ia=Erc(c[O>>2]|0,c[O+4>>2]|0,1e3,0)|0;xX(v,Y,da,ia,G,0,0,1)|0;if(ea>>>0<2>>>0){ia=(c[p>>2]|0)+(ea<<3)|0;O=c[ia+4>>2]|0;ja=N+(ea<<4)+8|0;c[ja>>2]=c[ia>>2];c[ja+4>>2]=O;O=(c[o>>2]|0)+(ea<<3)|0;ja=Erc(c[O>>2]|0,c[O+4>>2]|0,1e3,0)|0;O=N+(ea<<4)|0;c[O>>2]=ja;c[O+4>>2]=G;O=ea+1|0;c[aa>>2]=O;ka=O}else{ka=ea+1|0}if(!(ka>>>0<X>>>0)){ca=W;break b}O=(c[p>>2]|0)+(ka<<3)|0;ea=ka;da=c[O+4>>2]|0;Y=c[O>>2]|0}}else{fa=-38;U=41}}while(0);if((U|0)==41){KIb(b,24,2348512,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ca=fa}mJb(A);mJb(B);fD(t,D,E,0)|0;I=ca}}while(0);if((I|0)>=0){break}KIb(b,16,2576096,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}}while(0);w=wrc(g,j,-2,-1)|0;E=G;D=q|0;B=l+1|0;while(1){A=fD(t,0,0,1)|0;v=G;if(!((v|0)<(E|0)|(v|0)==(E|0)&A>>>0<w>>>0)){break}la=HD(t)|0;if((la|0)>=256){U=48;break}AD(t,D,la)|0;a[q+la|0]=0;if((la|0)<=0){break}if((YG(b,d,e,D,g,j,B)|0)<0){y=-1;U=146;break}}if((U|0)==48){hD(t,la,(la|0)<0|0?-1:0)|0;}else if((U|0)==146){i=m;return y|0}if((zD(t)|0)==9){x=0.0;break a}else{y=-1}i=m;return y|0};case 1:{x=+(zD(t)|0);break};case 8:{hD(t,4,0)|0;B=wrc(g,j,-2,-1)|0;D=G;w=q|0;E=l+1|0;while(1){A=fD(t,0,0,1)|0;v=G;if(!((v|0)<(D|0)|(v|0)==(D|0)&A>>>0<B>>>0)){break}ma=HD(t)|0;if((ma|0)>=256){U=55;break}AD(t,w,ma)|0;a[q+ma|0]=0;if((ma|0)<=0){break}if((YG(b,d,e,w,g,j,E)|0)<0){y=-1;U=146;break}}if((U|0)==55){hD(t,ma,(ma|0)<0|0?-1:0)|0;}else if((U|0)==146){i=m;return y|0}if((zD(t)|0)==9){x=0.0;break a}else{y=-1}i=m;return y|0};case 10:{E=JD(t)|0;w=wrc(g,j,-1,-1)|0;B=G;D=l+1|0;A=0;while(1){if(!(A>>>0<E>>>0)){x=0.0;break a}v=fD(t,0,0,1)|0;C=G;if(!((C|0)<(B|0)|(C|0)==(B|0)&v>>>0<w>>>0)){x=0.0;break a}if((YG(b,0,0,0,g,j,D)|0)<0){y=-1;break}else{A=A+1|0}}i=m;return y|0};case 11:{hD(t,10,0)|0;x=0.0;break};case 5:case 6:case 13:{x=0.0;break};default:{y=-1;i=m;return y|0}}}while(0);if((l|0)!=1|(f|0)==0){y=0;i=m;return y|0}if((d|0)==0){na=0}else{na=c[d+8>>2]|0}if((e|0)==0){oa=0}else{oa=c[e+8>>2]|0}d:do{if(u>>>0<2>>>0){if((irc(f,2557136)|0)==0){ga=x*1.0e6;l=(F=+ga,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);t=b+1064|0;c[t>>2]=~~+ga>>>0;c[t+4>>2]=l;break}l=(oa|0)==0;do{if(!((irc(f,2539832)|0)!=0|l)){t=~~(x*1024.0);if(!((t|0)>-1)){break}c[oa+72>>2]=t;break d}}while(0);t=(na|0)==0;do{if(!((irc(f,2523040)|0)!=0|t)){j=~~(x*1024.0);if(!((j|0)>-1)){break}c[na+72>>2]=j;break d}}while(0);if((irc(f,2508280)|0)==0){j=ZX(b,0)|0;if((j|0)==0){y=-12;i=m;return y|0}g=j+8|0;c[(c[g>>2]|0)+8>>2]=2;ma=c[b+24>>2]|0;do{if(ma>>>0>2>>>0){U=84}else{if((ma|0)!=2){break}la=c[b+28>>2]|0;if((c[(c[(c[la>>2]|0)+8>>2]|0)+8>>2]|0)==2){break}if((c[(c[(c[la+4>>2]|0)+8>>2]|0)+8>>2]|0)!=2){U=84}}}while(0);if((U|0)==84){ma=b+20|0;c[ma>>2]=c[ma>>2]&-2}_X(j,32,1,1e3);c[(c[g>>2]|0)+48>>2]=94210;break}if((c[s+4>>2]|0)==0){break}if(!((irc(f,2493832)|0)!=0|l)){ma=~~x;la=c[e+8>>2]|0;switch(ma|0){case 2:{c[la+48>>2]=22;break d;break};case 8:{c[la+48>>2]=5;break d;break};case 3:{c[la+48>>2]=87;break d;break};case 6:{c[la+48>>2]=132;break d;break};case 4:{c[la+48>>2]=93;break d;break};case 5:{c[la+48>>2]=107;break d;break};case 7:{c[la+48>>2]=28;c[e+236>>2]=2;break d;break};case 9:{c[la+48>>2]=13;break d;break};default:{QIb(b,2157168,(H=i,i=i+8|0,c[H>>2]=ma,H)|0);i=H;c[la+52>>2]=ma;break d}}}if((irc(f,2483760)|0)!=0|t){if(!((irc(f,2472488)|0)!=0|t)){c[na+412>>2]=~~x;break}if(!((irc(f,2464408)|0)!=0|t)){c[na+792>>2]=~~x;break}if(!((irc(f,2450120)|0)!=0|t)){ma=~~(x+1.0);c[na+416>>2]=ma;la=(ma|0)==2;ma=na+448|0;c[ma>>2]=la?3:4;c[ma+4>>2]=la?0:0;break}if(!((irc(f,2434048)|0)!=0|l)){c[oa+120>>2]=~~x;break}if((irc(f,2425224)|0)!=0|l){break}c[oa+124>>2]=~~x;break}la=~~x<<4;switch(la|0){case 0:{c[na+48>>2]=(c[na+792>>2]|0)==8?65541:65536;break d;break};case 48:{c[na+48>>2]=(c[na+792>>2]|0)==8?65541:65536;break d;break};case 160:{c[na+48>>2]=86018;break d;break};case 16:{c[na+48>>2]=69645;break d;break};case 176:{c[na+48>>2]=86052;c[na+412>>2]=16e3;break d;break};case 32:{c[na+48>>2]=86017;c[d+236>>2]=1;break d;break};case 80:{c[na+412>>2]=8e3;c[na+48>>2]=86050;break d;break};case 64:{c[na+412>>2]=16e3;c[na+48>>2]=86050;break d;break};case 96:{c[na+48>>2]=86050;break d;break};case 128:{c[na+412>>2]=8e3;c[na+48>>2]=65542;break d;break};case 112:{c[na+412>>2]=8e3;c[na+48>>2]=65543;break d;break};default:{ma=la>>4;QIb(b,2131968,(H=i,i=i+8|0,c[H>>2]=ma,H)|0);i=H;c[na+52>>2]=ma;break d}}}}while(0);do{if((u|0)==3){if((c[b+24>>2]|0)!=1){break}if((na|0)==0){if((irc(f,2483760)|0)!=0){U=126}}else{U=126}if((U|0)==126){if((oa|0)!=0){break}if((irc(f,2493832)|0)!=0){break}}d=b+20|0;c[d>>2]=c[d>>2]&-2}}while(0);if((irc(f,2557136)|0)==0){y=0;i=m;return y|0}if((irc(f,2414464)|0)==0){y=0;i=m;return y|0}if((irc(f,2434048)|0)==0){y=0;i=m;return y|0}if((irc(f,2425224)|0)==0){y=0;i=m;return y|0}if((irc(f,2539832)|0)==0){y=0;i=m;return y|0}if((irc(f,2406656)|0)==0){y=0;i=m;return y|0}if((irc(f,2493832)|0)==0){y=0;i=m;return y|0}if((irc(f,2523040)|0)==0){y=0;i=m;return y|0}if((irc(f,2472488)|0)==0){y=0;i=m;return y|0}if((irc(f,2464408)|0)==0){y=0;i=m;return y|0}if((irc(f,2450120)|0)==0){y=0;i=m;return y|0}if((irc(f,2483760)|0)==0){y=0;i=m;return y|0}if((irc(f,2508280)|0)==0){y=0;i=m;return y|0}if((u|0)==1){oa=q|0;CFb(oa,x>0.0?2399112:2392040,256)|0;MGb(b+1140|0,f,oa,0)|0;y=0;i=m;return y|0}else if((u|0)==0){oa=q|0;Rb(oa|0,256,2385456,(H=i,i=i+8|0,h[H>>3]=x,H)|0)|0;i=H;MGb(b+1140|0,f,oa,0)|0;y=0;i=m;return y|0}else if((u|0)==2){MGb(b+1140|0,f,q|0,0)|0;y=0;i=m;return y|0}else{y=0;i=m;return y|0}return 0}function ZG(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0,j=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0,H=0,I=0.0,J=0,K=0,L=0,M=0;b=i;d=c[a+16>>2]|0;e=c[a+12>>2]|0;f=a+24|0;a:do{if((c[f>>2]|0)==0){g=0.0;j=0;l=0;m=0}else{n=a+28|0;o=a;p=0.0;q=0;r=0;s=0;t=0;b:while(1){u=c[(c[n>>2]|0)+(q<<2)>>2]|0;v=c[u+8>>2]|0;w=c[v+8>>2]|0;do{if((w|0)==1){if((t|0)!=0){x=13;break b}if((aH(a,v)|0)<0){y=-1094995529;x=58;break b}if((c[v+48>>2]|0)!=65537){z=v;A=s;B=r;C=p;break}KIb(o,24,2406552,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;z=v;A=s;B=r;C=p}else if((w|0)==2){E=c[v+48>>2]|0;if((E|0)==94210){z=t;A=s;B=v;C=p}else{x=18;break b}}else if((w|0)==0){F=c[u+96>>2]|0;do{if((F|0)==0){x=7}else{H=c[u+92>>2]|0;if((H|0)==0){x=7;break}I=+(H|0)/+(F|0)}}while(0);if((x|0)==7){x=0;I=1.0/(+(c[v+104>>2]|0)/+(c[v+108>>2]|0))}if((s|0)!=0){x=9;break b}if((c[v+52>>2]|0)==0){x=11;break b}else{z=t;A=v;B=r;C=I}}else{x=19;break b}}while(0);_X(c[(c[n>>2]|0)+(q<<2)>>2]|0,32,1,1e3);u=pJb(8)|0;if((u|0)==0){y=-12;x=58;break}c[(c[(c[n>>2]|0)+(q<<2)>>2]|0)+12>>2]=u;F=u;c[F>>2]=-1;c[F+4>>2]=-1;F=q+1|0;if(F>>>0<(c[f>>2]|0)>>>0){p=C;q=F;r=B;s=A;t=z}else{g=C;j=B;l=A;m=z;break a}}if((x|0)==9){KIb(o,16,2434e3,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;y=-22;i=b;return y|0}else if((x|0)==11){t=u5a(c[v+48>>2]|0)|0;KIb(o,16,2425160,(D=i,i=i+16|0,c[D>>2]=t,c[D+8>>2]=q,D)|0);i=D;y=-22;i=b;return y|0}else if((x|0)==13){KIb(o,16,2414304,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;y=-22;i=b;return y|0}else if((x|0)==18){t=u5a(E)|0;KIb(o,16,2399032,(D=i,i=i+16|0,c[D>>2]=t,c[D+8>>2]=q,D)|0);i=D;y=-1094995529;i=b;return y|0}else if((x|0)==19){t=ALb(w)|0;KIb(o,16,2391976,(D=i,i=i+16|0,c[D>>2]=t,c[D+8>>2]=q,D)|0);i=D;y=-22;i=b;return y|0}else if((x|0)==58){i=b;return y|0}}}while(0);x=e+32|0;c[x>>2]=0;c[x+4>>2]=-2147483648;dD(d,2385448,3);bD(d,1);x=(m|0)!=0;w=x&1;E=(l|0)!=0;v=E&1;bD(d,w<<2|v);lD(d,9);lD(d,0);z=c[f>>2]|0;if((z|0)!=0){A=a+28|0;B=e;t=0;s=z;while(1){if((c[(c[(c[(c[A>>2]|0)+(t<<2)>>2]|0)+8>>2]|0)+52>>2]|0)==5){bD(d,8);vD(d,0);vD(d,0);lD(d,0);lD(d,11);c[B>>2]=5;J=c[f>>2]|0}else{J=s}z=t+1|0;if(z>>>0<J>>>0){t=z;s=J}else{break}}}bD(d,18);J=fD(d,0,0,1)|0;s=G;vD(d,0);vD(d,0);lD(d,0);bD(d,2);tD(d,10);dD(d,2378336,10);bD(d,8);t=fD(d,0,0,1)|0;B=G;A=(j|0)!=0;j=(A&1|2)+(-v&5)+(-w&5)|0;lD(d,j);tD(d,8);dD(d,2372528,8);w=fD(d,0,0,1)|0;v=e+8|0;c[v>>2]=w;c[v+4>>2]=G;v=a+1064|0;w=Crc(c[v>>2]|0,c[v+4>>2]|0,1e6,0)|0;C=+(w>>>0)+ +(G|0)*4294967296.0;bD(d,0);h[k>>3]=C;sD(d,c[k>>2]|0,c[k+4>>2]|0);if(E){tD(d,5);dD(d,2360800,5);C=+(c[l+120>>2]|0);bD(d,0);h[k>>3]=C;sD(d,c[k>>2]|0,c[k+4>>2]|0);tD(d,6);dD(d,2348504,6);C=+(c[l+124>>2]|0);bD(d,0);h[k>>3]=C;sD(d,c[k>>2]|0,c[k+4>>2]|0);tD(d,13);dD(d,2342192,13);C=+(c[l+72>>2]|0)*.0009765625;bD(d,0);h[k>>3]=C;sD(d,c[k>>2]|0,c[k+4>>2]|0);tD(d,9);dD(d,2336320,9);bD(d,0);h[k>>3]=g;sD(d,c[k>>2]|0,c[k+4>>2]|0);tD(d,12);dD(d,2331040,12);g=+((c[l+52>>2]|0)>>>0>>>0);bD(d,0);h[k>>3]=g;sD(d,c[k>>2]|0,c[k+4>>2]|0)}if(x){tD(d,13);dD(d,2325024,13);g=+(c[m+72>>2]|0)*.0009765625;bD(d,0);h[k>>3]=g;sD(d,c[k>>2]|0,c[k+4>>2]|0);tD(d,15);dD(d,2319488,15);g=+(c[m+412>>2]|0);bD(d,0);h[k>>3]=g;sD(d,c[k>>2]|0,c[k+4>>2]|0);tD(d,15);dD(d,2314848,15);x=(c[m+48>>2]|0)==65541;bD(d,0);sD(d,x?0:0,x?1075838976:1076887552);tD(d,6);dD(d,2310160,6);x=(c[m+416>>2]|0)==2;bD(d,1);bD(d,x&1);tD(d,12);dD(d,2306072,12);g=+((c[m+52>>2]|0)>>>0>>>0);bD(d,0);h[k>>3]=g;sD(d,c[k>>2]|0,c[k+4>>2]|0)}if(A){tD(d,10);dD(d,2296584,10);bD(d,0);sD(d,0,0)}A=a+1140|0;m=LGb(c[A>>2]|0,10230568,0,2)|0;c:do{if((m|0)==0){K=j}else{x=a;l=j;E=m;while(1){w=E;d:while(1){L=c[w>>2]|0;do{if((irc(L,2360800)|0)!=0){if((irc(L,2348504)|0)==0){break}if((irc(L,2342192)|0)==0){break}if((irc(L,2336320)|0)==0){break}if((irc(L,2331040)|0)==0){break}if((irc(L,2325024)|0)==0){break}if((irc(L,2319488)|0)==0){break}if((irc(L,2314848)|0)==0){break}if((irc(L,2310160)|0)==0){break}if((irc(L,2306072)|0)==0){break}if((irc(L,2372528)|0)==0){break}if((irc(L,2378336)|0)!=0){break d}}}while(0);KIb(x,48,2286944,(D=i,i=i+8|0,c[D>>2]=L,D)|0);i=D;v=LGb(c[A>>2]|0,10230568,w,2)|0;if((v|0)==0){K=l;break c}else{w=v}}v=lrc(L|0)|0;tD(d,v);dD(d,L,v);bD(d,2);v=c[w+4>>2]|0;z=lrc(v|0)|0;tD(d,z);dD(d,v,z);z=l+1|0;v=LGb(c[A>>2]|0,10230568,w,2)|0;if((v|0)==0){K=z;break}else{l=z;E=v}}}}while(0);tD(d,8);dD(d,2282832,8);A=fD(d,0,0,1)|0;L=e+16|0;c[L>>2]=A;c[L+4>>2]=G;bD(d,0);sD(d,0,0);tD(d,0);dD(d,10230568,0);bD(d,9);L=fD(d,0,0,1)|0;A=xrc(L,G,J,s)|0;L=G;e=wrc(A,L,-10,0)|0;fD(d,t,B,0)|0;lD(d,K);fD(d,J,s,0)|0;vD(d,e);e=wrc(A,L,-3,-1)|0;hD(d,e,G)|0;e=wrc(A,L,1,0)|0;lD(d,e);e=c[f>>2]|0;if((e|0)==0){y=0;i=b;return y|0}L=a+28|0;A=0;s=e;while(1){e=c[(c[(c[L>>2]|0)+(A<<2)>>2]|0)+8>>2]|0;J=e+48|0;K=c[J>>2]|0;if((K|0)==86018|(K|0)==28|(K|0)==13){bD(d,(c[e+8>>2]|0)==0?9:8);vD(d,0);vD(d,0);bD(d,0);vD(d,0);K=fD(d,0,0,1)|0;B=G;if((c[J>>2]|0)==86018){bD(d,aH(a,e)|0);bD(d,0);dD(d,c[e+96>>2]|0,c[e+100>>2]|0)}else{bD(d,c[e+52>>2]|16);bD(d,0);vD(d,0);q$(d,c[e+96>>2]|0,c[e+100>>2]|0)|0}e=fD(d,0,0,1)|0;J=xrc(e,G,K,B)|0;B=G;K=xrc(-10,-1,J,B)|0;fD(d,K,G,1)|0;vD(d,J);K=wrc(J,B,7,0)|0;hD(d,K,G)|0;K=wrc(J,B,11,0)|0;lD(d,K);M=c[f>>2]|0}else{M=s}K=A+1|0;if(K>>>0<M>>>0){A=K;s=M}else{y=0;break}}i=b;return y|0}function _G(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[b+16>>2]|0;k=e+32|0;l=b+28|0;m=c[(c[l>>2]|0)+(c[k>>2]<<2)>>2]|0;n=c[m+8>>2]|0;o=c[b+12>>2]|0;p=c[m+12>>2]|0;m=e+28|0;c[g>>2]=c[m>>2];c[h>>2]=0;q=n+48|0;r=c[q>>2]|0;if((r|0)==28|(r|0)==13){s=5}else if((r|0)==93|(r|0)==107|(r|0)==92|(r|0)==86018){s=2}else{s=1}r=n+8|0;t=c[r>>2]|0;do{if((t|0)==2){bD(j,18);u=-1}else if((t|0)==1){v=aH(b,n)|0;if((c[g>>2]|0)==0){KIb(0,0,2186632,(w=i,i=i+24|0,c[w>>2]=2157160,c[w+8>>2]=2131944,c[w+16>>2]=491,w)|0);i=w;Hd();return 0}else{bD(j,8);u=v;break}}else if((t|0)==0){bD(j,9);v=c[n+52>>2]|0;if((v|0)!=0){u=(c[e+36>>2]<<4&16^16)+16|v;break}v=u5a(c[q>>2]|0)|0;KIb(b,16,2221464,(w=i,i=i+8|0,c[w>>2]=v,w)|0);i=w;x=-22;i=f;return x|0}else{x=-22;i=f;return x|0}}while(0);t=c[q>>2]|0;do{if((t|0)==86018){if((c[m>>2]|0)<=2){break}v=c[e+24>>2]|0;if(!(((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&-16)<<16>>16==-16)){break}v=(c[(c[l>>2]|0)+(c[k>>2]<<2)>>2]|0)+64|0;y=b;if(!((c[v>>2]|0)==0&(c[v+4>>2]|0)==0)){KIb(y,24,2626808,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}KIb(y,16,2108768,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1094995529;i=f;return x|0}else if((t|0)==28|(t|0)==13){if((c[n+100>>2]|0)<=0){break}if((a[c[n+96>>2]|0]|0)==1){break}y=p$(c[e+24>>2]|0,h,g)|0;if((y|0)<0){x=y}else{break}i=f;return x|0}}while(0);t=o+32|0;k=c[t>>2]|0;l=c[t+4>>2]|0;m=e+16|0;if((k|0)==0&(l|0)==(-2147483648|0)){y=xrc(0,0,c[m>>2]|0,c[m+4>>2]|0)|0;v=G;c[t>>2]=y;c[t+4>>2]=v;z=v;A=y}else{z=l;A=k}k=c[m>>2]|0;l=c[m+4>>2]|0;y=xrc(0,0,A,z)|0;v=G;if((l|0)<(v|0)|(l|0)==(v|0)&k>>>0<y>>>0){KIb(b,24,2600952,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-22;i=f;return x|0}y=wrc(A,z,k,l)|0;l=G;k=y;do{if((c[q>>2]|0)==86052){z=y|0;A=l&0;v=p;B=xrc(z,A,c[v>>2]|0,c[v+4>>2]|0)|0;C=G;D=0;if(!((C|0)>(D|0)|(C|0)==(D|0)&B>>>0>160>>>0)){E=v;F=A;H=z;break}KIb(b,24,2575992,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;E=v;F=A;H=z}else{E=p;F=l&0;H=y|0}}while(0);y=c[E+4>>2]|0;if((y|0)<(F|0)|(y|0)==(F|0)&(c[E>>2]|0)>>>0<H>>>0){c[E>>2]=H;c[E+4>>2]=F}vD(j,(c[g>>2]|0)+s|0);vD(j,k);bD(j,k>>>24&127);vD(j,c[o>>2]|0);if((c[r>>2]|0)==2){r=fD(j,0,0,1)|0;k=G;bD(j,2);tD(j,10);dD(j,2557120,10);bD(j,8);lD(j,2);tD(j,4);dD(j,2539800,4);bD(j,2);tD(j,4);dD(j,2523032,4);tD(j,4);dD(j,2508256,4);bD(j,2);F=c[e+24>>2]|0;E=lrc(F|0)|0;tD(j,E);dD(j,F,E);tD(j,0);dD(j,10230568,0);bD(j,9);E=fD(j,0,0,1)|0;F=xrc(E,G,r,k)|0;E=F;F=wrc(r,k,-10,-1)|0;fD(j,F,G,0)|0;vD(j,E);F=E+7|0;fD(j,F,(F|0)<0|0?-1:0,1)|0;lD(j,E+11|0)}else{bD(j,u);u=c[q>>2]|0;if((u|0)==92){bD(j,0);I=c[q>>2]|0}else{I=u}do{if((I|0)==86018){bD(j,1)}else if((I|0)==28|(I|0)==13){bD(j,1);u=e+8|0;q=xrc(c[u>>2]|0,c[u+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;vD(j,q)}else if((I|0)==93|(I|0)==107){if((c[n+100>>2]|0)==0){q=c[n+120>>2]|0;u=c[n+124>>2]|0;bD(j,(q+15&268435440)-q<<4|(u+15&-16)-u);break}else{bD(j,d[c[n+96>>2]|0]|0);break}}}while(0);n=c[h>>2]|0;if((n|0)==0){J=c[e+24>>2]|0}else{J=n}dD(j,J,c[g>>2]|0);lD(j,s+11+(c[g>>2]|0)|0);g=o+24|0;o=c[g>>2]|0;s=c[g+4>>2]|0;J=e+8|0;n=wrc(c[t>>2]|0,c[t+4>>2]|0,c[J>>2]|0,c[J+4>>2]|0)|0;J=c[e+48>>2]|0;e=wrc(n,G,J,(J|0)<0|0?-1:0)|0;J=G;n=(s|0)>(J|0)|(s|0)==(J|0)&o>>>0>e>>>0;c[g>>2]=n?o:e;c[g+4>>2]=n?s:J}kJb(c[h>>2]|0);x=c[j+76>>2]|0;i=f;return x|0}function $G(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0;b=i;d=c[a+16>>2]|0;e=c[a+12>>2]|0;f=a+24|0;g=c[f>>2]|0;if((g|0)!=0){j=a+28|0;l=0;m=g;while(1){g=c[(c[j>>2]|0)+(l<<2)>>2]|0;n=c[g+8>>2]|0;o=c[g+12>>2]|0;do{if((c[n+8>>2]|0)==0){g=c[n+48>>2]|0;if(!((g|0)==28|(g|0)==13)){p=m;break}g=c[o>>2]|0;bD(d,9);vD(d,5);vD(d,g);bD(d,g>>>24&127);vD(d,0);bD(d,23);bD(d,2);vD(d,0);lD(d,16);p=c[f>>2]|0}else{p=m}}while(0);o=l+1|0;if(o>>>0<p>>>0){l=o;m=p}else{break}}}p=fD(d,0,0,1)|0;m=G;l=e+8|0;f=fD(d,c[l>>2]|0,c[l+4>>2]|0,0)|0;l=G;j=0;if((l|0)<(j|0)|(l|0)==(j|0)&f>>>0<0>>>0){KIb(a,24,2325264,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}else{f=e+24|0;r=(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)/1.0e3;bD(d,0);h[k>>3]=r;sD(d,c[k>>2]|0,c[k+4>>2]|0)}f=e+16|0;e=fD(d,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=G;j=0;if((f|0)<(j|0)|(f|0)==(j|0)&e>>>0<0>>>0){KIb(a,24,2270032,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=fD(d,p,m,0)|0;t=G;i=b;return 0}else{bD(d,0);h[k>>3]=+(p>>>0)+ +(m|0)*4294967296.0;sD(d,c[k>>2]|0,c[k+4>>2]|0);s=fD(d,p,m,0)|0;t=G;i=b;return 0}return 0}function aH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=(c[b+792>>2]|0)==16?2:0;f=c[b+48>>2]|0;do{if((f|0)==86018){g=175}else{h=c[b+412>>2]|0;if((f|0)==86052){if((h|0)!=16e3){KIb(a,16,2483712,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;g=-22;break}if((c[b+416>>2]|0)==1){g=182;break}KIb(a,16,2472448,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;g=-22;break}if((h|0)==11025){k=e|4}else if((h|0)==22050){k=e|8}else if((h|0)==44100){k=e|12}else if((h|0)==16e3|(h|0)==8e3|(h|0)==5512){if((f|0)==86017){l=12}else{k=e}}else{l=12}if((l|0)==12){KIb(a,16,2464336,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;g=-22;break}m=(c[b+416>>2]|0)>1|k;if((f|0)==69645){g=m|18;break}else if((f|0)==86050){if((h|0)==8e3){g=m|82;break}else if((h|0)==16e3){g=m|66;break}else{g=m|98;break}}else if((f|0)==65543){g=114;break}else if((f|0)==65542){g=130;break}else if((f|0)==65536){g=m|50;break}else if((f|0)==86017){g=m|34;break}else if((f|0)==65537){g=m|2;break}else if((f|0)==0){g=c[b+52>>2]<<4|m;break}else if((f|0)==65541){g=m;break}else{m=u5a(f)|0;KIb(a,16,2450072,(j=i,i=i+8|0,c[j>>2]=m,j)|0);i=j;g=-22;break}}}while(0);i=d;return g|0}function bH(a){a=a|0;return c[((a|0)==0?6041816:a+24|0)>>2]|0}function cH(a){a=a|0;return c[((a|0)==0?6041808:a+40|0)>>2]|0}function dH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[253226]|0;d=a+24|0;c[d>>2]=0;e=a;a=b;while(1){b=c[a>>2]|0;if((b|0)==0){f=a;if(((E=c[f>>2]|0,(c[f>>2]|0)==0?(c[f>>2]=e)|0:0,E)|0)==0){break}g=c[a>>2]|0}else{g=b}a=g+24|0}c[253226]=d;return}function eH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[253224]|0;d=a+40|0;c[d>>2]=0;e=a;a=b;while(1){b=c[a>>2]|0;if((b|0)==0){f=a;if(((E=c[f>>2]|0,(c[f>>2]|0)==0?(c[f>>2]=e)|0:0,E)|0)==0){break}g=c[a>>2]|0}else{g=b}a=g+40|0}c[253224]=d;return}function fH(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+32|0;e=d|0;a:do{if((b|0)==0){f=0}else{g=hc(b|0,46)|0;if((g|0)==0){f=0;break}h=g+1|0;g=e|0;j=e;k=g;l=c;b:while(1){m=a[l]|0;do{if(!((m<<24>>24|0)==0|(m<<24>>24|0)==44)){if(!((k-j|0)>>>0<31>>>0)){break}a[k]=m;k=k+1|0;l=l+1|0;continue b}}while(0);a[k]=0;if((IFb(g,h)|0)==0){f=1;break a}if((a[l]|0)==0){f=0;break}else{k=g;l=l+1|0}}}}while(0);i=d;return f|0}function gH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+32|0;g=f|0;h=(b|0)!=0;j=(d|0)==0;do{if(!(h|j)){if((iX(d)|0)==0){break}if((nJ(d)|0)==0){break}k=gH(2187744,0,0)|0;i=f;return k|0}}while(0);l=c[1510452]|0;if((l|0)==0){k=0;i=f;return k|0}m=(e|0)==0;n=g|0;o=g;if(h){p=0;q=0;r=l}else{h=0;g=0;s=l;while(1){l=c[s+8>>2]|0;if((l|0)==0|m){t=0}else{u=(irc(l,e)|0)==0;t=u?10:0}do{if(j){v=t}else{u=c[s+12>>2]|0;if((u|0)==0){v=t;break}l=hc(d|0,46)|0;a:do{if((l|0)==0){w=1}else{x=l+1|0;y=n;z=u;while(1){A=a[z]|0;do{if((A<<24>>24|0)==0|(A<<24>>24|0)==44){B=12}else{if(!((y-o|0)>>>0<31>>>0)){B=12;break}a[y]=A;C=y+1|0}}while(0);if((B|0)==12){B=0;a[y]=0;if((IFb(n,x)|0)==0){w=0;break a}if((a[z]|0)==0){w=1;break a}else{C=n}}y=C;z=z+1|0}}}while(0);v=w?t:t|5}}while(0);u=(v|0)>(g|0);l=u?s:h;z=c[((s|0)==0?6041808:s+40|0)>>2]|0;if((z|0)==0){k=l;break}else{h=l;g=u?v:g;s=z}}i=f;return k|0}while(1){s=c[r>>2]|0;b:do{if((s|0)==0){D=0}else{g=lrc(b|0)|0;v=s;while(1){h=_b(v|0,44)|0;if((h|0)==0){break}t=h-v|0;if((JFb(b,v,(t|0)>(g|0)?t:g)|0)==0){D=100;break b}else{v=h+1|0}}g=(IFb(b,v)|0)==0;D=g?100:0}}while(0);s=c[r+8>>2]|0;if((s|0)==0|m){E=D}else{g=(irc(s,e)|0)==0;E=g?D|10:D}do{if(j){F=E}else{g=c[r+12>>2]|0;if((g|0)==0){F=E;break}s=hc(d|0,46)|0;c:do{if((s|0)==0){G=1}else{h=s+1|0;t=n;w=g;while(1){C=a[w]|0;do{if((C<<24>>24|0)==0|(C<<24>>24|0)==44){B=36}else{if(!((t-o|0)>>>0<31>>>0)){B=36;break}a[t]=C;H=t+1|0}}while(0);if((B|0)==36){B=0;a[t]=0;if((IFb(n,h)|0)==0){G=0;break c}if((a[w]|0)==0){G=1;break c}else{H=n}}t=H;w=w+1|0}}}while(0);F=G?E:E+5|0}}while(0);g=(F|0)>(q|0);s=g?r:p;v=c[((r|0)==0?6041808:r+40|0)>>2]|0;if((v|0)==0){k=s;break}else{p=s;q=g?F:q;r=v}}i=f;return k|0}function hH(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;e=c[a>>2]|0;if((irc(e,2508520)|0)==0){g=3}else{if((irc(e,2399280)|0)==0){g=3}else{h=a}}if((g|0)==3){h=gH(0,d,0)|0}if((f|0)==1){i=c[h+16>>2]|0;return i|0}else if((f|0)==0){a=c[h>>2]|0;if((irc(a,2187744)|0)==0){g=7}else{if((irc(a,2325112)|0)==0){g=7}}do{if((g|0)==7){a=nJ(d)|0;if((a|0)==0){break}else{i=a}return i|0}}while(0);i=c[h+20>>2]|0;return i|0}else if((f|0)==3){i=c[h+24>>2]|0;return i|0}else{i=0;return i|0}return 0}function iH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[1510454]|0;if((b|0)==0){d=0;return d|0}e=(a|0)==0;f=b;a:while(1){b=c[f>>2]|0;if(!(e|(b|0)==0)){g=lrc(a|0)|0;h=b;while(1){b=_b(h|0,44)|0;if((b|0)==0){break}i=b-h|0;if((JFb(a,h,(i|0)>(g|0)?i:g)|0)==0){d=f;j=9;break a}else{h=b+1|0}}if((IFb(a,h)|0)==0){d=f;j=9;break}}g=c[((f|0)==0?6041816:f+24|0)>>2]|0;if((g|0)==0){d=0;j=9;break}else{f=g}}if((j|0)==9){return d|0}return 0}function jH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=c[b+28>>2]|0;f=oFb(0,c[b+24>>2]|0,e)|0;g=d|0;h=b+16|0;j=c[h>>2]|0;k=c[h+4>>2]|0;h=b+8|0;l=c[h>>2]|0;m=c[h+4>>2]|0;h=c[b+48>>2]|0;Rb(g|0,256,2399168,(n=i,i=i+64|0,c[n>>2]=c[b+32>>2],c[n+8>>2]=j,c[n+16>>2]=k,c[n+24>>2]=l,c[n+32>>2]=m,c[n+40>>2]=h,c[n+48>>2]=e,c[n+56>>2]=f,n)|0)|0;i=n;f=c[b+36>>2]|0;if((f|0)!=1){EFb(g,256,2325088,(n=i,i=i+8|0,c[n>>2]=f,n)|0)|0;i=n}f=b+44|0;e=c[f>>2]|0;do{if((e|0)!=0){EFb(g,256,2269792,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;if((c[f>>2]|0)<=0){break}h=b+40|0;m=0;do{l=c[h>>2]|0;k=c[l+(m*12|0)+4>>2]|0;j=oFb(0,c[l+(m*12|0)>>2]|0,k)|0;EFb(g,256,2221344,(n=i,i=i+16|0,c[n>>2]=k,c[n+8>>2]=j,n)|0)|0;i=n;m=m+1|0;}while((m|0)<(c[f>>2]|0))}}while(0);EFb(g,256,2186576,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0)|0;i=n;n=c[a+16>>2]|0;dD(n,g,lrc(g|0)|0);i=d;return 0}function kH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+24|0;if((c[d>>2]|0)==0){i=b;return 0}do{if((c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)==0){YD(c[a+16>>2]|0,2186768,(e=i,i=i+8|0,c[e>>2]=2508336,e)|0)|0;i=e;if((c[d>>2]|0)!=0){break}i=b;return 0}}while(0);f=a+28|0;g=a+16|0;a=0;do{h=c[(c[f>>2]|0)+(a<<2)>>2]|0;j=c[h+8>>2]|0;_X(h,64,c[j+104>>2]|0,c[j+108>>2]|0);j=c[h+40>>2]|0;k=c[h+44>>2]|0;YD(c[g>>2]|0,2399120,(e=i,i=i+24|0,c[e>>2]=a,c[e+8>>2]=j,c[e+16>>2]=k,e)|0)|0;i=e;eD(c[g>>2]|0);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0);i=b;return 0}function lH(b){b=b|0;var e=0,f=0,g=0;do{if((c[b+8>>2]|0)>8){e=c[b+4>>2]|0;if((a[e]|0)!=70){break}if((a[e+1|0]|0)!=82){break}if((a[e+2|0]|0)!=77){break}f=e+4|0;if((d[f]|d[f+1|0]<<8)<<16>>16<<16>>16==0){break}f=e+6|0;if((d[f]|d[f+1|0]<<8)<<16>>16<<16>>16==0){break}else{g=25}return g|0}}while(0);g=0;return g|0}function mH(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+16>>2]|0;d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}a=d+8|0;d=c[a>>2]|0;c[d+8>>2]=0;c[d+48>>2]=14;hD(b,3,0)|0;d=Q4a(1204376,zD(b)|0)|0;f=c[a>>2]|0;c[f+140>>2]=d;if((d|0)==0){e=-1094995529;return e|0}c[f+52>>2]=0;f=DD(b)|0;c[(c[a>>2]|0)+120>>2]=f;f=DD(b)|0;c[(c[a>>2]|0)+124>>2]=f;e=0;return e|0}function nH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;f=c[b+12>>2]|0;if((c[f>>2]|0)!=0){g=-541478725;return g|0}h=e+140|0;i=c2(c[h>>2]|0,c[e+120>>2]|0,c[e+124>>2]|0)|0;if((i|0)<0){g=-1094995529;return g|0}e=fX(c[b+16>>2]|0,d,i)|0;if((e|0)<0){g=e;return g|0}do{if((c[h>>2]|0)==30){e=d+28|0;if((c[e>>2]|0)<4){break}i=d+24|0;b=3;while(1){j=(c[i>>2]|0)+b|0;a[j]=~a[j];if((b+5|0)>(c[e>>2]|0)){break}else{b=b+4|0}}}}while(0);c[d+32>>2]=0;c[f>>2]=(c[f>>2]|0)+1;g=0;return g|0}function oH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=ZX(a,0)|0;if((d|0)==0){e=-12;i=b;return e|0}a=d+8|0;f=c[a>>2]|0;c[f+8>>2]=1;c[f+48>>2]=69660;c[f+412>>2]=16e3;c[f+416>>2]=1;f=g5a(69660)|0;g=c[a>>2]|0;c[g+792>>2]=f;if((f|0)<=0){KIb(0,0,2325040,(f=i,i=i+24|0,c[f>>2]=2269712,c[f+8>>2]=2221208,c[f+16>>2]=43,f)|0);i=f;Hd();return 0}_X(d,64,1,c[g+412>>2]|0);e=0;i=b;return e|0}function pH(a){a=a|0;var b=0,d=0,e=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86069;e=a+448|0;c[e>>2]=4;c[e+4>>2]=0;c[a+416>>2]=1;c[a+412>>2]=8e3;_X(b,64,1,8e3);a=b+48|0;c[a>>2]=0;c[a+4>>2]=0;d=0;return d|0}function qH(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+16|0;b=fD(c[f>>2]|0,0,0,1)|0;g=e+64|0;c[g>>2]=b;c[g+4>>2]=G;g=zD(c[f>>2]|0)|0;b=d[1209920+(g&3)|0]|0;h=K1(e,b)|0;if((h|0)<0){i=h;return i|0}h=e+24|0;a[c[h>>2]|0]=g;c[e+48>>2]=240;c[e+32>>2]=0;g=b-1|0;b=AD(c[f>>2]|0,(c[h>>2]|0)+1|0,g)|0;if((b|0)<(g|0)){P1(e);i=(b|0)<0?b:-541478725;return i|0}else{i=c[e+28>>2]|0;return i|0}return 0}function rH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+12>>2]|0;e=ZX(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=e+8|0;h=c[g>>2]|0;c[h+8>>2]=1;c[h+48>>2]=86070;c[h+412>>2]=8e3;c[h+416>>2]=1;do{if((d|0)!=0){j=c[d+4>>2]|0;if((j|0)==0){break}c[a+1072>>2]=j}}while(0);d=a+1072|0;j=c[d>>2]|0;if((j|0)==6400){c[h+432>>2]=8;k=h;l=64}else if((j|0)==8e3){m=h;n=8}else if((j|0)==0){KIb(a,48,2398968,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[d>>2]=8e3;m=c[g>>2]|0;n=8}else{KIb(a,16,2324952,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;f=-1094995529;i=b;return f|0}if((n|0)==8){c[m+432>>2]=10;k=m;l=80}_X(e,l,1,c[k+412>>2]|0);f=0;i=b;return f|0}function sH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+28|0;e=fX(c[a+16>>2]|0,b,c[(c[(c[c[d>>2]>>2]|0)+8>>2]|0)+432>>2]|0)|0;c[b+32>>2]=0;if((e|0)<0){return e|0}a=b+64|0;f=c[(c[(c[c[d>>2]>>2]|0)+8>>2]|0)+432>>2]|0;d=Crc(c[a>>2]|0,c[a+4>>2]|0,f,(f|0)<0|0?-1:0)|0;f=G;a=b+8|0;c[a>>2]=d;c[a+4>>2]=f;a=b+16|0;c[a>>2]=d;c[a+4>>2]=f;return e|0}function tH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+1024|0;d=b|0;e=c[a+12>>2]|0;f=a+16|0;g=c[f>>2]|0;do{if((c[a+24>>2]|0)==1){h=c[c[a+28>>2]>>2]|0;j=c[h+8>>2]|0;if((c[j+8>>2]|0)!=0){break}if((c[j+48>>2]|0)!=98){break}k=c[j+120>>2]|0;l=c[j+124>>2]|0;_X(h,64,1,100);h=d|0;m=j+140|0;do{if((rIb(h,c[m>>2]|0)|0)<0){if((c[m>>2]|0)==11){xH(g,k,l,c[e+4>>2]|0,0);break}else{KIb(0,0,2221160,(n=i,i=i+24|0,c[n>>2]=2186504,c[n+8>>2]=2157080,c[n+16>>2]=101,n)|0);i=n;Hd();return 0}}else{xH(g,k,l,c[e+4>>2]|0,h)}}while(0);eD(c[f>>2]|0);o=0;i=b;return o|0}}while(0);KIb(a,16,2269640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=b;return o|0}function uH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=(c[a+12>>2]|0)+12|0;if((c[d>>2]|0)!=0){e=wH(a,b)|0;return e|0}a=hJb(80)|0;f=a;c[d>>2]=f;if((a|0)==0){e=-12;return e|0}e=S1(f,b)|0;return e|0}function vH(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;wH(a,0)|0;mJb(b+12|0);bD(d,59);return 0}function wH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=c[a+16>>2]|0;h=f+12|0;j=c[h>>2]|0;if((j|0)==0){k=0;i=d;return k|0}l=V1(j,0,e)|0;m=l;n=(l|0)!=0;if(!((c[e>>2]|0)==1024|n^1)){KIb(a,16,2324904,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-1094995529;i=d;return k|0}if(n){n=31;a=0;e=255;do{l=(c[m+(a<<2)>>2]|0)>>>24;o=l>>>0<e>>>0;n=o?a&255:n;e=o?l:e;a=a+1|0;}while(a>>>0<256>>>0);p=e>>>0<128>>>0?5:4;q=n&255}else{p=4;q=31}n=(b|0)!=0;do{if(n){e=b+8|0;a=c[e>>2]|0;m=c[e+4>>2]|0;if((a|0)==0&(m|0)==(-2147483648|0)){break}e=(c[h>>2]|0)+8|0;l=xrc(a,m,c[e>>2]|0,c[e+4>>2]|0)|0;e=l;if(e>>>0>65535>>>0){r=-e>>31&65535}else{r=l&65535}c[f+16>>2]=r&65535}else{l=c[f+8>>2]|0;if(!((l|0)>-1)){break}c[f+16>>2]=l}}while(0);bD(g,33);bD(g,249);bD(g,4);bD(g,p);oD(g,c[f+16>>2]|0);bD(g,q);bD(g,0);dD(g,c[j+24>>2]|0,c[j+28>>2]|0);P1(c[h>>2]|0);if(!n){k=0;i=d;return k|0}S1(c[h>>2]|0,b)|0;k=0;i=d;return k|0}function xH(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;dD(a,2131888,3);dD(a,2108728,3);oD(a,b);oD(a,d);if((f|0)==0){bD(a,0);bD(a,0);bD(a,0)}else{bD(a,247);bD(a,31);bD(a,0);d=0;do{vD(a,c[f+(d<<2)>>2]&16777215);d=d+1|0;}while((d|0)<256)}if(!((e|0)>-1)){return}bD(a,33);bD(a,255);bD(a,11);dD(a,2626768,11);bD(a,3);bD(a,1);oD(a,e&65535);bD(a,0);return}function yH(a){a=a|0;var b=0;b=c[a+4>>2]|0;do{if((grc(b,1147800,6)|0)!=0){if((grc(b,1147784,6)|0)==0){break}return 0}}while(0);a=b+6|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){return 0}else{a=b+8|0;return((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0?0:100)|0}return 0}function zH(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;e=c[a+16>>2]|0;f=0;while(1){if((f|0)>=6){break}g=zD(e)|0;do{if((g|0)==(d[1147800+f|0]|0|0)){h=f}else{if((g|0)==(d[1147784+f|0]|0|0)){h=f;break}h=-((g|0)!=71|0)|0}}while(0);if((jD(e)|0)==0){f=h+1|0}else{i=-541478725;j=10;break}}if((j|0)==10){return i|0}c[b+4>>2]=c[b+12>>2];b=DD(e)|0;j=DD(e)|0;if((b|0)==0|(j|0)==0){i=-1094995529;return i|0}h=ZX(a,0)|0;if((h|0)==0){i=-12;return i|0}_X(h,64,1,100);a=c[h+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=98;c[a+120>>2]=b;c[a+124>>2]=j;j=fD(e,0,0,0)|0;i=(j|0)==0&(G|0)==0?0:-5;return i|0}function AH(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+264|0;g=f|0;h=b+12|0;j=c[h>>2]|0;k=b+16|0;l=c[k>>2]|0;m=fD(l,0,0,1)|0;n=G;o=f+256|0;p=AD(l,o,6)|0;do{if((p|0)==6){if((grc(o,1147800,6)|0)==0){q=n;r=m;s=1;t=5;break}u=(grc(o,1147784,6)|0)==0;if(u){q=n;r=m;s=u&1;t=5}else{t=9}}else{if((p|0)<0){v=p}else{t=9;break}i=f;return v|0}}while(0);if((t|0)==9){o=-p|0;fD(l,o,(o|0)<0|0?-1:0,1)|0;w=n;x=m;y=-541478725;z=0}a:while(1){if((t|0)==5){t=0;m=hD(l,4,0)|0;n=m;if((n|0)<0){v=n;t=60;break}n=zD(l)|0;m=hD(l,2,0)|0;o=m;if((o|0)<0){v=o;t=60;break}if((n&128|0)==0){w=q;x=r;y=o;z=s;continue}o=3<<(n&7)+1;n=hD(l,o,(o|0)<0|0?-1:0)|0;o=n;if((o|0)<0){v=o;t=60;break}else{w=q;x=r;y=o;z=s}}o=g|0;n=g+1|0;m=y;b:while(1){p=zD(l)|0;if((p|0)==59){A=m;B=1;C=1;break a}if((jD(l)|0)!=0){A=m;B=1;C=0;break a}if((p|0)==44){t=32;break}else if((p|0)!=33){t=44;break}p=c[h>>2]|0;u=c[k>>2]|0;D=zD(u)|0;do{if((D|0)==249){E=zD(u)|0;if((E|0)<4){t=16;break b}F=hD(u,1,0)|0;if((F|0)<0){break b}F=DD(u)|0;H=p+4|0;c[H>>2]=F;if((F|0)<(c[p+8>>2]|0)){c[H>>2]=c[p+12>>2]}H=E-3|0;E=hD(u,H,(H|0)<0|0?-1:0)|0;if((E|0)<0){break b}else{I=0;t=28}}else if((D|0)==255){E=zD(u)|0;H=AD(u,o,E)|0;if((H|0)<0|(E|0)==0){J=H;break}if((E|0)!=11){I=0;t=28;break}E=zD(u)|0;H=AD(u,o,E)|0;if((H|0)<0|(E|0)==0){J=H;break}if((E|0)!=3){I=0;t=28;break}if((a[o]|0)!=1){I=0;t=28;break}E=(d[n]|d[n+1|0]<<8)<<16>>16;H=p+16|0;c[H>>2]=E&65535;if(!(E<<16>>16==0)){I=0;t=28;break}c[H>>2]=-1;I=0;t=28}else{I=0;t=28}}while(0);if((t|0)==28){while(1){t=0;p=zD(u)|0;if((p|0)==0){K=I;break}D=hD(u,p,(p|0)<0|0?-1:0)|0;p=D;if((p|0)<0){K=p;break}else{I=p;t=28}}J=(K|0)<0?K:0}if((J|0)<0){break}else{m=J}}do{if((t|0)==16){t=0;KIb(b,8,2269472,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L}else if((t|0)==32){t=0;m=hD(l,8,0)|0;n=m;if((n|0)<0){v=n;t=60;break a}n=zD(l)|0;if((n&128|0)!=0){m=3<<(n&7)+1;n=hD(l,m,(m|0)<0|0?-1:0)|0;m=n;if((m|0)<0){v=m;t=60;break a}}if((zD(l)|0)<1){KIb(b,16,2398824,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;break}do{m=zD(l)|0;if((m|0)==0){t=39;break a}n=hD(l,m,(m|0)<0|0?-1:0)|0;}while((n|0)>=0)}else if((t|0)==44){t=0;KIb(b,16,2324816,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L}}while(0);if((z|0)==0){fD(l,x,w,0)|0;M=0}else{M=0}while(1){if((M|0)>=6){break}n=zD(l)|0;do{if((n|0)==(d[1147800+M|0]|0)){N=M}else{if((n|0)==(d[1147784+M|0]|0)){N=M;break}N=-((n|0)!=71|0)|0}}while(0);if((jD(l)|0)==0){M=N+1|0}else{v=-541478725;t=60;break a}}n=fD(l,0,0,1)|0;m=wrc(n,G,-6,-1)|0;q=G;r=m;s=1;t=5}if((t|0)==39){s=fD(l,0,0,1)|0;r=G;q=fD(l,x,w,0)|0;if(!((q|0)==(x|0)&(G|0)==(w|0))){v=-5;i=f;return v|0}q=xrc(s,r,x,w)|0;w=fX(l,e,q)|0;if((w|0)<0){v=w;i=f;return v|0}if((z|0)!=0){z=e+36|0;c[z>>2]=c[z>>2]|1}c[e+32>>2]=0;z=j+4|0;c[e+48>>2]=c[z>>2];c[z>>2]=c[j+12>>2];A=w;B=0;C=0}else if((t|0)==60){i=f;return v|0}if(!((A|0)>-1&B|(A|0)==-541478725)){v=A;i=f;return v|0}if((c[j+24>>2]|0)!=0){v=-541478725;i=f;return v|0}do{if(!C){if((jD(l)|0)==0){v=-541478725}else{break}i=f;return v|0}}while(0);C=c[j+16>>2]|0;do{if((C|0)>=0){A=j+20|0;B=(c[A>>2]|0)+1|0;c[A>>2]=B;if((B|0)<(C|0)){break}else{v=-541478725}i=f;return v|0}}while(0);C=fD(l,0,0,0)|0;v=C;i=f;return v|0}function BH(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[d+8>>2]|0;c[f+8>>2]=1;c[f+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[f+416>>2]=1;a=f+448|0;c[a>>2]=4;c[a+4>>2]=0;a=b+4|0;c[f+412>>2]=c[a>>2];c[f+72>>2]=((c[a>>2]|0)*264|0|0)/160|0;_X(d,64,160,8e3);e=0;return e|0}function CH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+16|0;a=fD(c[d>>2]|0,0,0,1)|0;e=b+64|0;c[e>>2]=a;c[e+4>>2]=G;c[b+32>>2]=0;a=fX(c[d>>2]|0,b,33)|0;if((a|0)<33){P1(b);f=(a|0)<0?a:-5;return f|0}else{c[b+48>>2]=1;a=Crc(c[e>>2]|0,c[e+4>>2]|0,33,0)|0;e=b+8|0;c[e>>2]=a;c[e+4>>2]=G;f=0;return f|0}return 0}function DH(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;do{if((grc(b,1146600,6)|0)==0){if((grc(b+10|0,1146608,6)|0)==0){d=100}else{break}return d|0}}while(0);d=0;return d|0}function EH(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;b=i;i=i+152|0;e=b|0;f=b+128|0;g=b+136|0;h=b+144|0;j=c[a+16>>2]|0;k=c[a+12>>2]|0;l=(JH(j,f,g)|0)==0;if(l|(c[f>>2]|0)!=188){KIb(a,16,2156952,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=b;return n|0}l=c[g>>2]|0;c[g>>2]=l-2;do{if((zD(j)|0)==224){if((zD(j)|0)!=255){break}o=l-4|0;c[g>>2]=o;p=HD(j)|0;c[h>>2]=p;if((p|0)>(o|0)){KIb(a,16,2108568,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=b;return n|0}q=o-p|0;c[g>>2]=q;o=k;c[o>>2]=0;c[o+4>>2]=-2147483648;r=k+8|0;c[r>>2]=0;c[r+4>>2]=-2147483648;a:do{if((p|0)>1){s=p;while(1){t=zD(j)|0;u=zD(j)|0;v=s-2|0;c[h>>2]=v;if((u|0)>(v|0)){w=v;break a}x=v-u|0;c[h>>2]=x;do{if((u|0)==4){v=JD(j)|0;if((t|0)==65){c[o>>2]=v;c[o+4>>2]=0;break}else if((t|0)==66){c[r>>2]=v;c[r+4>>2]=0;break}else{break}}else{hD(j,u,(u|0)<0|0?-1:0)|0;}}while(0);if((x|0)>1){s=x}else{w=x;break}}}else{w=p}}while(0);hD(j,w,(w|0)<0|0?-1:0)|0;p=q-2|0;c[g>>2]=p;s=HD(j)|0;c[h>>2]=s;if((s|0)>(p|0)){KIb(a,16,2626656,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=b;return n|0}u=p-s|0;c[g>>2]=u;b:do{if((s|0)>0){t=a;v=k+16|0;y=v;z=k+20|0;A=k+24|0;B=k+32|0;C=v;v=a+1140|0;D=e|0;E=a+28|0;F=0;H=0;I=s;while(1){J=I;c:while(1){K=zD(j)|0;L=zD(j)|0;M=HD(j)|0;N=J-4-M|0;c[h>>2]=N;do{if((K&128|0)==0){KIb(t,16,2600680,(m=i,i=i+8|0,c[m>>2]=K,m)|0);i=m}else{O=K&127;if((L&192|0)!=192){KIb(t,16,2575888,(m=i,i=i+8|0,c[m>>2]=L,m)|0);i=m;break}P=L&63;c[y>>2]=0;c[z>>2]=0;c[A>>2]=0;c[B>>2]=-2147483648;c[B+4>>2]=0;d:do{if((M|0)>1){Q=M;while(1){R=zD(j)|0;S=zD(j)|0;T=Q-2|0;if((S|0)>(T|0)){U=T;break d}V=T-S|0;do{if((S|0)==8){if((R|0)!=77){W=36;break}T=GD(j)|0;c[B>>2]=T;c[B+4>>2]=G}else if((S|0)==4){T=JD(j)|0;if((R|0)==80){X=T-1|0;Y=1209928+((X>>>0>8>>>0?8:X)<<3)|0;X=c[Y+4>>2]|0;c[C>>2]=c[Y>>2];c[C+4>>2]=X;break}else if((R|0)!=82){break}if(!((T-1|0)>>>0<2>>>0)){break}c[A>>2]=T}else{W=36}}while(0);if((W|0)==36){W=0;hD(j,S,(S|0)<0|0?-1:0)|0;}if((V|0)>1){Q=V}else{U=V;break}}}else{U=M}}while(0);do{if((O-7|0)>>>0<2>>>0|(O|0)==24){Q=c[B>>2]|0;R=c[A>>2]|0;T=Q&255;if((R|0)==0){Z=T}else{Z=(T|0)/(R|0)|0}if((Q|0)<0){break}Rb(D|0,128,2449968,(m=i,i=i+40|0,c[m>>2]=Q>>>24&31,c[m+8>>2]=Q>>>16&255,c[m+16>>2]=Q>>>8&255,c[m+24>>2]=Q>>>29&1|58,c[m+32>>2]=Z,m)|0)|0;i=m;MGb(v,2556984,D,0)|0}}while(0);hD(j,U,(U|0)<0|0?-1:0)|0;_=LH(a,P,O)|0;if((_|0)>=0){break c}}}while(0);if((N|0)>0){J=N}else{$=N;aa=F;ba=H;break b}}J=c[(c[E>>2]|0)+(_<<2)>>2]|0;if((F|0)==0|(H|0)==0){ca=c[y>>2]<<1;da=c[z>>2]|0}else{ca=H;da=F}x=c[o+4>>2]|0;M=J+48|0;c[M>>2]=c[o>>2];c[M+4>>2]=x;x=c[o>>2]|0;M=c[o+4>>2]|0;do{if(!((x|0)==0&(M|0)==(-2147483648|0))){L=c[r>>2]|0;K=c[r+4>>2]|0;if((L|0)==0&(K|0)==(-2147483648|0)){break}Q=xrc(L,K,x,M)|0;K=J+56|0;c[K>>2]=Q;c[K+4>>2]=G}}while(0);if((N|0)>0){F=da;H=ca;I=N}else{$=N;aa=da;ba=ca;break}}}else{$=s;aa=0;ba=0}}while(0);if(($|0)<0){KIb(a,16,2539656,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}if((p|0)!=(s|0)){hD(j,u,(u|0)<0|0?-1:0)|0;}if((JH(j,f,h)|0)==0){KIb(a,16,2522880,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=b;return n|0}r=c[f>>2]|0;do{if((r|0)==252){KH(a,c[h>>2]|0);if((JH(j,f,h)|0)!=0){ea=c[f>>2]|0;break}KIb(a,16,2522880,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=b;return n|0}else{ea=r}}while(0);do{if((ea|0)==253){r=c[h>>2]|0;if((r|0)<=56){KIb(a,32,2472400,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;fa=ba;ga=aa;ha=r;break}u=r-57|0;c[h>>2]=u;hD(j,5,0)|0;hD(j,48,0)|0;s=1210760+((d[1359664+((FD(j)|0)>>>6&31)|0]|0)<<3)|0;if((aa|0)==0|(ba|0)==0){p=c[s+4>>2]|0;o=c[s>>2]|0;KIb(a,24,2508096,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;ia=o<<1;ja=p}else{ia=ba;ja=aa}if((u|0)<=23){fa=ia;ga=ja;ha=u;break}u=r-81|0;c[h>>2]=u;hD(j,16,0)|0;r=a+1140|0;p=FD(j)|0;o=k+24|0;s=c[o>>2]|0;q=e|0;I=p&255;if((s|0)==0){ka=I}else{ka=(I|0)/(s|0)|0}if((p|0)>=0){Rb(q|0,128,2449968,(m=i,i=i+40|0,c[m>>2]=p>>>24&31,c[m+8>>2]=p>>>16&255,c[m+16>>2]=p>>>8&255,c[m+24>>2]=p>>>29&1|58,c[m+32>>2]=ka,m)|0)|0;i=m;MGb(r,2493696,q,0)|0}p=FD(j)|0;s=c[o>>2]|0;o=p&255;if((s|0)==0){la=o}else{la=(o|0)/(s|0)|0}if((p|0)<0){fa=ia;ga=ja;ha=u;break}Rb(q|0,128,2449968,(m=i,i=i+40|0,c[m>>2]=p>>>24&31,c[m+8>>2]=p>>>16&255,c[m+16>>2]=p>>>8&255,c[m+24>>2]=p>>>29&1|58,c[m+32>>2]=la,m)|0)|0;i=m;MGb(r,2483616,q,0)|0;fa=ia;ga=ja;ha=u}else{KIb(a,32,2464296,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;fa=ba;ga=aa;ha=c[h>>2]|0}}while(0);hD(j,ha,(ha|0)<0|0?-1:0)|0;u=(ga|0)==0|(fa|0)==0;q=u?1001:ga;r=u?6e4:fa;u=a+24|0;if((c[u>>2]|0)==0){n=0;i=b;return n|0}p=a+28|0;s=0;while(1){_X(c[(c[p>>2]|0)+(s<<2)>>2]|0,32,q,r);o=s+1|0;if(o>>>0<(c[u>>2]|0)>>>0){s=o}else{n=0;break}}i=b;return n|0}}while(0);KIb(a,16,2131680,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=b;return n|0}function FH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=c[a+16>>2]|0;h=c[a+12>>2]|0;j=g+52|0;if((c[j>>2]|0)!=0){k=-541478725;i=d;return k|0}l=a;while(1){if((JH(g,e,f)|0)==0){m=4;break}n=c[e>>2]|0;if((n|0)==191){o=c[f>>2]|0;if((o|0)>=16){m=12;break}KIb(l,16,2324648,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}else if((n|0)==252){KH(a,c[f>>2]|0)}else{n=c[f>>2]|0;hD(g,n,(n|0)<0|0?-1:0)|0;}if((c[j>>2]|0)!=0){k=-541478725;m=22;break}}if((m|0)==4){if((jD(g)|0)!=0){k=-1;i=d;return k|0}KIb(l,16,2398696,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=-1;i=d;return k|0}else if((m|0)==12){j=o-16|0;c[f>>2]=j;o=zD(g)|0;e=LH(a,zD(g)|0,o)|0;if((e|0)<0){k=e;i=d;return k|0}o=c[(c[a+28>>2]|0)+(e<<2)>>2]|0;a=JD(g)|0;n=JD(g)|0;JD(g)|0;zD(g)|0;zD(g)|0;q=o+8|0;o=c[(c[q>>2]|0)+48>>2]|0;a:do{if((o|0)==65548|(o|0)==65536){r=n>>16;s=n&65535;t=(g5a(o)|0)>>3;do{if((r|0)<=(s|0)){u=ca(t,s)|0;if((u|0)>(j|0)){break}v=ca(t,r)|0;hD(g,v,(v|0)<0|0?-1:0)|0;v=ca(t,s-r|0)|0;c[f>>2]=v;w=fX(g,b,v)|0;if((j|0)==(u|0)){x=w;break a}v=j-u|0;hD(g,v,(v|0)<0|0?-1:0)|0;x=w;break a}}while(0);KIb(l,16,2269360,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;m=17}else{m=17}}while(0);if((m|0)==17){x=fX(g,b,j)|0}c[b+32>>2]=e;e=b+16|0;c[e>>2]=a;c[e+4>>2]=(a|0)<0|0?-1:0;if((c[(c[q>>2]|0)+48>>2]|0)!=25){k=x;i=d;return k|0}c[b+48>>2]=c[h+24>>2];k=x;i=d;return k|0}else if((m|0)==22){i=d;return k|0}return 0}function GH(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=c[a+28>>2]|0;g=c[f>>2]|0;h=(c[f+(b<<2)>>2]|0)+48|0;b=c[h>>2]|0;f=c[h+4>>2]|0;h=(f|0)>(e|0)|(f|0)==(e|0)&b>>>0>d>>>0;i=h?b:d;d=h?f:e;e=xrc(i,d,b,f)|0;f=CX(g,e,G,5)|0;if((f|0)<0){j=-1;return j|0}e=c[g+400>>2]|0;b=e+(f*24|0)|0;h=c[b>>2]|0;k=c[b+4>>2]|0;if((f|0)<((c[g+404>>2]|0)-2|0)){g=e+((f+2|0)*24|0)|0;f=xrc(c[g>>2]|0,c[g+4>>2]|0,h,k)|0;l=G;m=f}else{l=0;m=104857600}f=a+16|0;a=fD(c[f>>2]|0,h,k,0)|0;k=a;if((k|0)<0){j=k;return j|0}k=0;a=l>>>0>k>>>0|l>>>0==k>>>0&m>>>0>204800>>>0;k=IH(c[f>>2]|0,a?m:204800,a?l:0,i)|0;l=xrc(k,G,i,d)|0;d=G;i=-1;k=(d|0)>(i|0)|(d|0)==(i|0)&l>>>0>-1>>>0;i=xrc(0,0,l,d)|0;a=k?d:G;d=0;j=((a|0)>(d|0)|(a|0)==(d|0)&(k?l:i)>>>0>4>>>0)<<31>>31;return j|0}function HH(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;b=a+16|0;a=c[b>>2]|0;g=fD(a,c[d>>2]|0,c[d+4>>2]|0,0)|0;h=G;i=0;if((h|0)<(i|0)|(h|0)==(i|0)&g>>>0<0>>>0){j=-2147483648;k=0;return(G=j,k)|0}g=xrc(e,f,c[d>>2]|0,c[d+4>>2]|0)|0;f=IH(c[b>>2]|0,g,G,-1)|0;g=G;b=fD(a,0,0,1)|0;c[d>>2]=b;c[d+4>>2]=G;j=g;k=f;return(G=j,k)|0}function IH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=JD(a)|0;k=e;l=(e|0)<0|0?-1:0;a:do{if((e|0)>-1){m=d;n=b;o=-2147483648;p=0;q=j;r=0;s=0;while(1){t=m;u=n;v=q;while(1){w=wrc(u,t,-1,-1)|0;x=G;y=(u|0)!=0|(t|0)!=0;if((v|0)!=0){if(!y){z=o;A=p;B=r;C=s;break a}if((jD(a)|0)!=0){z=o;A=p;B=r;C=s;break a}t=x;u=w;v=zD(a)|0|v<<8;continue}if(!y){z=o;A=p;B=r;C=s;break a}if((jD(a)|0)!=0){z=o;A=p;B=r;C=s;break a}y=zD(a)|0;if((y|0)!=1){t=x;u=w;v=y;continue}D=fD(a,0,0,1)|0;E=G;y=fD(a,-5,-1,1)|0;F=G;H=0;if((F|0)<(H|0)|(F|0)==(H|0)&y>>>0<0>>>0){z=o;A=p;B=r;C=s;break a}y=(JH(a,h,g)|0)==0;if(!(y|(c[h>>2]|0)!=191)){break}y=fD(a,D,E,0)|0;H=G;F=0;if((H|0)<(F|0)|(H|0)==(F|0)&y>>>0<0>>>0){z=o;A=p;B=r;C=s;break a}else{t=x;u=w;v=1}}zD(a)|0;zD(a)|0;v=JD(a)|0;u=0;t=fD(a,0,0,1)|0;y=wrc(t,G,-22,-1)|0;t=G;if(!((l|0)>(u|0)|(l|0)==(u|0)&k>>>0>v>>>0)){z=u;A=v;B=t;C=y;break a}F=fD(a,D,E,0)|0;H=G;I=-1;if((H|0)>(I|0)|(H|0)==(I|0)&F>>>0>-1>>>0){m=x;n=w;o=u;p=v;q=1;r=t;s=y}else{z=u;A=v;B=t;C=y;break}}}else{s=d;r=b;q=j;while(1){p=wrc(r,s,-1,-1)|0;o=G;n=(r|0)!=0|(s|0)!=0;if((q|0)!=0){if(!n){J=-2147483648;K=0;L=28;break}if((jD(a)|0)!=0){J=-2147483648;K=0;L=28;break}s=o;r=p;q=zD(a)|0|q<<8;continue}if(!n){J=-2147483648;K=0;L=28;break}if((jD(a)|0)!=0){J=-2147483648;K=0;L=28;break}n=zD(a)|0;if((n|0)!=1){s=o;r=p;q=n;continue}n=fD(a,0,0,1)|0;m=G;y=fD(a,-5,-1,1)|0;t=G;v=0;if((t|0)<(v|0)|(t|0)==(v|0)&y>>>0<0>>>0){J=-2147483648;K=0;L=28;break}y=(JH(a,h,g)|0)==0;if(!(y|(c[h>>2]|0)!=191)){L=25;break}y=fD(a,n,m,0)|0;m=G;n=0;if((m|0)<(n|0)|(m|0)==(n|0)&y>>>0<0>>>0){J=-2147483648;K=0;L=28;break}else{s=o;r=p;q=1}}if((L|0)==25){zD(a)|0;zD(a)|0;q=JD(a)|0;r=fD(a,0,0,1)|0;s=wrc(r,G,-22,-1)|0;z=0;A=q;B=G;C=s;break}else if((L|0)==28){i=f;return(G=J,K)|0}}}while(0);if((C|0)==0&(B|0)==0){J=z;K=A;i=f;return(G=J,K)|0}fD(a,C,B,0)|0;J=z;K=A;i=f;return(G=J,K)|0}function JH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;do{if((JD(a)|0)==0){if((zD(a)|0)!=1){e=0;break}c[b>>2]=zD(a)|0;f=JD(a)|0;c[d>>2]=f;if(f>>>0>16777215>>>0|(f|0)<16){e=0;break}c[d>>2]=f-16;if((JD(a)|0)!=0){e=0;break}if((zD(a)|0)!=225){e=0;break}e=(zD(a)|0)==226|0}else{e=0}}while(0);return e|0}function KH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=c[a+16>>2]|0;f=FD(e)|0;g=FD(e)|0;h=b-8|0;do{if((c[a+1084>>2]&2|0)==0){b=c[a+28>>2]|0;if((b|0)==0){break}j=c[b>>2]|0;if(g>>>0>1e3>>>0){KIb(a,16,2221048,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=g,k)|0);i=k;l=1e3}else{l=g}b=l<<2;if(h>>>0<b>>>0){KIb(a,16,2186392,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;hD(e,h,(h|0)<0|0?-1:0)|0;i=d;return}m=h-b|0;xX(j,0,0,0,0,0,0,0)|0;if((l|0)!=0){b=f;n=0;o=0;do{p=FD(e)|0;q=Erc(o,(o|0)<0|0?-1:0,b,n)|0;r=wrc(q,G,1,0)|0;xX(j,p<<10|0>>>22,0<<10|p>>>22,r,G,0,0,0)|0;o=o+1|0;}while(o>>>0<l>>>0)}hD(e,m,(m|0)<0|0?-1:0)|0;i=d;return}}while(0);hD(e,h,(h|0)<0|0?-1:0)|0;i=d;return}function LH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=oY(a,b)|0;if((e|0)>-1){f=e;return f|0}e=ZX(a,0)|0;if((e|0)==0){f=-12;return f|0}c[e+4>>2]=b;switch(d|0){case 17:{d=c[e+8>>2]|0;c[d+8>>2]=1;c[d+48>>2]=86019;c[d+416>>2]=2;b=d+448|0;c[b>>2]=3;c[b+4>>2]=0;c[d+412>>2]=48e3;break};case 30:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=100;break};case 13:case 14:case 15:case 16:case 25:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=25;break};case 9:{d=c[e+8>>2]|0;c[d+8>>2]=1;c[d+48>>2]=65548;c[d+416>>2]=1;b=d+448|0;c[b>>2]=4;c[b+4>>2]=0;c[d+412>>2]=48e3;c[d+72>>2]=1152e3;c[d+432>>2]=3;c[d+792>>2]=24;break};case 7:case 8:case 24:{d=c[e+8>>2]|0;c[d+8>>2]=2;c[d+48>>2]=0;break};case 3:case 4:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=8;break};case 26:case 29:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=28;c[e+236>>2]=2;break};case 10:{d=c[e+8>>2]|0;c[d+8>>2]=1;c[d+48>>2]=65536;c[d+416>>2]=1;b=d+448|0;c[b>>2]=4;c[b+4>>2]=0;c[d+412>>2]=48e3;c[d+72>>2]=768e3;c[d+432>>2]=2;c[d+792>>2]=16;break};case 22:case 23:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=1;c[e+236>>2]=2;break};case 11:case 12:case 20:{d=c[e+8>>2]|0;c[d+8>>2]=0;c[d+48>>2]=2;c[e+236>>2]=2;break};default:{d=c[e+8>>2]|0;c[d+8>>2]=-1;c[d+48>>2]=0}}f=(c[a+24>>2]|0)-1|0;return f|0}function MH(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+272|0;f=e|0;g=e+8|0;h=e+264|0;j=d+16|0;k=c[j>>2]|0;l=d+12|0;m=c[l>>2]|0;mrc(g|0,0,255)|0;n=LGb(c[d+1140>>2]|0,2600664,0,0)|0;if((c[k+88>>2]|0)==0){KIb(d,16,2575824,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}q=m+52|0;c[q>>2]=c[q>>2]|524288;r=d+24|0;a:do{if((c[r>>2]|0)==0){s=n;t=0}else{u=d+28|0;v=m+8|0;w=m+44|0;x=m+48|0;y=m+10|0;z=n;A=0;B=0;C=0;b:while(1){D=c[(c[u>>2]|0)+(B<<2)>>2]|0;E=pJb(96)|0;F=E;if((E|0)==0){p=-12;G=46;break}H=D+12|0;c[H>>2]=E;I=D+8|0;J=(IX(1146616,c[(c[I>>2]|0)+48>>2]|0)|0)&65535;K=E+52|0;b[K>>1]=J;L=c[I>>2]|0;M=c[L+8>>2]|0;do{if((M|0)==1){if((c[L+48>>2]|0)!=65536){G=8;break b}N=L+412|0;if((c[N>>2]|0)!=48e3){G=10;break b}if((c[L+416>>2]|0)!=1){G=12;break b}c[E+40>>2]=2;O=c[N>>2]|0;c[E+48>>2]=O;_X(D,64,1,O);c[E+44>>2]=16;c[E+56>>2]=-2;c[E+60>>2]=-2;c[E+64>>2]=-2;b[v>>1]=(b[v>>1]|0)+1;c[q>>2]=c[q>>2]|67108864;P=C;Q=65;R=z}else if((M|0)==0){if((B|0)!=0){G=15;break b}O=c[L+124>>2]|0;if((O|0)==576|(O|0)==608){c[E+56>>2]=6;b[K>>1]=J+1;c[E+48>>2]=50;S=50;T=1;U=c[q>>2]|64}else if((O|0)==480|(O|0)==512){c[E+56>>2]=5;c[E+48>>2]=60;S=6e4;T=1001;U=c[q>>2]|128}else{G=19;break b}c[q>>2]=U;c[w>>2]=T;c[x>>2]=S;if((z|0)==0){O=LGb(c[D+88>>2]|0,2600664,0,0)|0;V=O;W=c[w>>2]|0;X=c[x>>2]|0}else{V=z;W=T;X=S}_X(D,64,W,X);O=c[H>>2]|0;N=0;while(1){if((N|0)>=6){G=26;break}Y=c[I>>2]|0;if((c[Y+124>>2]|0)==(c[1146736+(N<<3)>>2]|0)){G=25;break}else{N=N+1|0}}if((G|0)==25){G=0;c[O+60>>2]=c[1146740+(N<<3)>>2];Z=Y}else if((G|0)==26){G=0;c[E+60>>2]=-1;Z=c[I>>2]|0}c[E+44>>2]=c[Z+72>>2];c[E+64>>2]=2;_=c[Z+48>>2]|0;if((_|0)==25){if((c[Z+140>>2]|0)==4){b[K>>1]=(b[K>>1]|0)+2;c[E+40>>2]=6;c[q>>2]=c[q>>2]|8192;P=F;Q=69;R=V;break}else{c[E+40>>2]=5;c[q>>2]=c[q>>2]|4096;P=F;Q=68;R=V;break}}else if((_|0)==8){c[E+40>>2]=1;c[q>>2]=c[q>>2]|16384;P=F;Q=74;R=V;break}else if((_|0)==2){c[E+88>>2]=-1;c[E+40>>2]=4;b[y>>1]=(b[y>>1]|0)+1;c[q>>2]=c[q>>2]|32768;P=F;Q=77;R=V;break}else if((_|0)==1){c[E+40>>2]=9;b[y>>1]=(b[y>>1]|0)+1;P=F;Q=76;R=V;break}else{G=34;break b}}else{P=C;Q=A;R=z}}while(0);F=g+Q|0;K=a[F]|0;a[F]=K+1;b[E+54>>1]=(K&255)+48|Q<<8;K=c[r>>2]|0;c[E+92>>2]=K-(c[D>>2]|0);F=B+1|0;if(F>>>0<K>>>0){z=R;A=Q;B=F;C=P}else{s=R;t=P;break a}}if((G|0)==8){KIb(d,16,2556936,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==10){KIb(d,16,2539552,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==12){KIb(d,16,2522840,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==15){KIb(d,16,2508056,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==19){KIb(d,16,2493608,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==34){KIb(d,16,2483584,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((G|0)==46){i=e;return p|0}}}while(0);c[h>>2]=1;c[h+4>>2]=48e3;if((l$(d,2659104,h)|0)<0){p=-1;i=e;return p|0}h=(t|0)==0;do{if(!((s|0)==0|h)){G=c[t+64>>2]|0;P=m+184|0;R=P;Q=Bd(c[s+4>>2]|0,2472384,(o=i,i=i+40|0,c[o>>2]=m+172,c[o+8>>2]=m+176,c[o+16>>2]=m+180,c[o+24>>2]=f,c[o+32>>2]=P,o)|0)|0;i=o;if((Q|0)!=5){KIb(d,16,2464240,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}c[m+188>>2]=0;c[m+192>>2]=(a[f]|0)!=58;if((G|0)!=2){break}c[R>>2]=c[R>>2]<<1}}while(0);if(!h){h=c[t+48>>2]|0;b[m+108>>1]=(h|0)==60?7:8;c[m+104>>2]=h;b[m+110>>1]=21552;c[m+96>>2]=3;c[m+112>>2]=c[t+56>>2];c[m+116>>2]=c[t+60>>2];c[m+100>>2]=16;c[m+120>>2]=c[t+64>>2]}c[q>>2]=c[q>>2]|2097152;q=RH(d,0)|0;if((q|0)<0){p=q;i=e;return p|0}SH(c[l>>2]|0,c[j>>2]|0);TH(d);c[m+168>>2]=3;eD(k);p=0;i=e;return p|0}function NH(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;g=a+12|0;h=c[g>>2]|0;j=a+16|0;k=c[j>>2]|0;l=b+32|0;m=a+28|0;n=c[(c[m>>2]|0)+(c[l>>2]<<2)>>2]|0;o=fD(k,0,0,1)|0;p=G;q=fD(k,0,0,1)|0;r=Crc(q,G,1024,0)|0;q=r;lD(k,0);bD(k,1);bD(k,191);lD(k,0);lD(k,0);bD(k,225);bD(k,226);r=n+8|0;n=c[r>>2]|0;do{if((c[n+48>>2]|0)==2){s=c[b+28>>2]|0;t=(s|0)%4|0;if((t|0)==0){u=4;break}v=4-t|0;w=s}else{u=4}}while(0);do{if((u|0)==4){s=c[b+28>>2]|0;if((c[n+8>>2]|0)!=1){v=0;w=s;break}v=65536-s|0;w=s}}while(0);n=b+28|0;u=w+v|0;w=c[g>>2]|0;g=c[j>>2]|0;j=c[(c[m>>2]|0)+(c[l>>2]<<2)>>2]|0;l=c[j+12>>2]|0;m=j+8|0;if((c[(c[m>>2]|0)+8>>2]|0)==0){x=c[w+4>>2]|0}else{s=b+16|0;t=c[s>>2]|0;y=c[s+4>>2]|0;s=c[w+48>>2]|0;z=c[w+44>>2]|0;w=Erc(z,(z|0)<0|0?-1:0,48e3,0)|0;z=UIb(t,y,s,(s|0)<0|0?-1:0,w,G,3)|0;x=z}bD(g,e[l+52>>1]|0);bD(g,c[j>>2]|0);lD(g,x);j=c[m>>2]|0;do{if((c[j+8>>2]|0)==1){tD(g,0);tD(g,(u|0)/2|0)}else{m=c[j+48>>2]|0;if((m|0)==2){z=c[b+24>>2]|0;w=(c[n>>2]|0)-4|0;if((w|0)<1){A=1}else{s=l+88|0;y=-1;t=0;while(1){B=d[z+t|0]|0|y<<8;do{if((B|0)==440){if(!((c[s>>2]|0)==-1)){break}c[s>>2]=(d[z+(t+4)|0]|0)>>>6&1}}while(0);C=t+1|0;if((C|0)>=(w|0)|(B|0)==256){break}else{y=B;t=C}}A=t+2|0}y=(d[z+A|0]|0)>>>3&7;if((y|0)==3){bD(g,15);w=l+76|0;c[w>>2]=(c[w>>2]|0)+1}else if((y|0)==1){bD(g,13);y=l+68|0;c[y>>2]=(c[y>>2]|0)+1}else{bD(g,14);y=l+72|0;c[y>>2]=(c[y>>2]|0)+1}vD(g,u);break}else if((m|0)==25){bD(g,(u|0)/4096|0);vD(g,0);break}else{lD(g,u);break}}}while(0);lD(g,x);bD(g,1);bD(g,0);dD(k,c[b+24>>2]|0,c[n>>2]|0);if((v|0)>0){n=(v|0)<0|0?-1:0;b=v;do{bD(k,0);b=wrc(b,n,-1,-1)|0;n=G;v=0;}while((n|0)>(v|0)|(n|0)==(v|0)&b>>>0>0>>>0)}if((c[(c[r>>2]|0)+8>>2]|0)==0){r=h+156|0;b=c[r>>2]|0;n=h+152|0;do{if(((b>>>0)%500|0|0)==0){v=oJb(n,b+500|0,4)|0;if((v|0)>=0){D=c[r>>2]|0;break}c[r>>2]=0;c[h+4>>2]=0;KIb(a,16,2626616,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;E=v;i=f;return E|0}else{D=b}}while(0);c[r>>2]=D+1;c[(c[n>>2]|0)+(D<<2)>>2]=q;q=h+4|0;c[q>>2]=(c[q>>2]|0)+2}UH(k,o,p)|0;p=h+168|0;h=(c[p>>2]|0)+1|0;c[p>>2]=h;if((h|0)!=100){E=0;i=f;return E|0}h=RH(a,0)|0;if((h|0)<0){E=h;i=f;return E|0}c[p>>2]=0;E=0;i=f;return E|0}function OH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+12|0;d=c[b>>2]|0;e=a+16|0;f=c[e>>2]|0;k$(a);g=fD(f,0,0,1)|0;h=G;lD(f,0);bD(f,1);bD(f,251);lD(f,0);lD(f,0);bD(f,225);bD(f,226);UH(f,g,h)|0;h=fD(f,0,0,1)|0;g=G;fD(f,0,0,0)|0;i=RH(a,1)|0;if((i|0)<0){j=i;return j|0}SH(c[b>>2]|0,c[e>>2]|0);TH(a);eD(f);e=d+164|0;b=d+160|0;a:do{if((c[e>>2]|0)>>>0>1>>>0){i=b;k=1;while(1){l=(c[i>>2]|0)+(k<<3)|0;fD(f,c[l>>2]|0,c[l+4>>2]|0,0)|0;l=RH(a,1)|0;if((l|0)<0){j=l;break}eD(f);k=k+1|0;if(!(k>>>0<(c[e>>2]|0)>>>0)){break a}}return j|0}}while(0);fD(f,h,g,0)|0;mJb(d+152|0);mJb(b);j=0;return j|0}function PH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;do{if((d|0)!=0){if((c[(c[(c[(c[a+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+8>>2]|0)+8>>2]|0)!=0){break}c[d+48>>2]=2}}while(0);return m$(a,b,d,e,810,372)|0}function QH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[a+12>>2]|0;f=c[a+28>>2]|0;a=e+48|0;g=e+44|0;e=c[f+(c[d+32>>2]<<2)>>2]|0;h=c[e+12>>2]|0;i=d+16|0;d=c[i>>2]|0;j=c[i+4>>2]|0;if((c[(c[e+8>>2]|0)+8>>2]|0)==1){e=c[a>>2]|0;i=c[g>>2]|0;k=Erc(i,(i|0)<0|0?-1:0,48e3,0)|0;i=UIb(d,j,e,(e|0)<0|0?-1:0,k,G,3)|0;l=i&-2}else{l=d}d=c[f+(c[b+32>>2]<<2)>>2]|0;f=c[d+12>>2]|0;i=b+16|0;b=c[i>>2]|0;k=c[i+4>>2]|0;if((c[(c[d+8>>2]|0)+8>>2]|0)==1){d=c[a>>2]|0;a=c[g>>2]|0;g=Erc(a,(a|0)<0|0?-1:0,48e3,0)|0;a=UIb(b,k,d,(d|0)<0|0?-1:0,g,G,3)|0;m=a&-2}else{m=b}if((m|0)>(l|0)){n=1;return n|0}if((m|0)!=(l|0)){n=0;return n|0}n=(c[f+92>>2]|0)>>>0>(c[h+92>>2]|0)>>>0|0;return n|0}function RH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=a+12|0;f=c[e>>2]|0;g=a+16|0;h=c[g>>2]|0;j=fD(h,0,0,1)|0;k=G;if((b|0)==0){b=f+164|0;l=c[b>>2]|0;m=f+160|0;do{if(((l>>>0)%30|0|0)==0){f=oJb(m,l+30|0,8)|0;if((f|0)>=0){n=c[b>>2]|0;break}c[b>>2]=0;KIb(a,16,2269280,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=f;i=d;return p|0}else{n=l}}while(0);c[b>>2]=n+1;b=(c[m>>2]|0)+(n<<3)|0;c[b>>2]=j;c[b+4>>2]=k}lD(h,0);bD(h,1);bD(h,188);lD(h,0);lD(h,0);bD(h,225);bD(h,226);bD(h,224);bD(h,255);b=c[e>>2]|0;n=c[g>>2]|0;m=a+32|0;l=hc(m|0,47)|0;f=fD(n,0,0,1)|0;o=G;tD(n,0);q=(l|0)==0?m:l+1|0;l=lrc(q|0)|0;bD(n,64);bD(n,l+18|0);dD(n,2108544,17);dD(n,q,l);bD(n,0);bD(n,65);bD(n,4);lD(n,0);bD(n,66);bD(n,4);l=b+4|0;lD(n,c[l>>2]|0);bD(n,67);bD(n,4);lD(n,0);bD(n,68);bD(n,4);lD(n,c[l>>2]|0);bD(n,69);bD(n,4);l=iD(n)|0;b=Crc(l,G,1024,0)|0;lD(n,b);b=fD(n,0,0,1)|0;l=G;fD(n,f,o,0)|0;q=xrc(-2,0,f,o)|0;o=wrc(q,G,b,l)|0;tD(n,o);fD(n,b,l,0)|0;l=c[e>>2]|0;e=c[g>>2]|0;g=fD(e,0,0,1)|0;b=G;tD(e,0);n=a+24|0;if((c[n>>2]|0)==0){r=0}else{o=a+28|0;q=0;while(1){VH(a,c[(c[(c[o>>2]|0)+(q<<2)>>2]|0)+12>>2]|0,q);f=q+1|0;m=c[n>>2]|0;if(f>>>0<m>>>0){q=f}else{r=m;break}}}VH(a,l+56|0,r);r=fD(e,0,0,1)|0;l=G;fD(e,g,b,0)|0;a=xrc(-2,0,g,b)|0;b=wrc(a,G,r,l)|0;tD(e,b);fD(e,r,l,0)|0;l=UH(h,j,k)|0;p=l;i=d;return p|0}function SH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fD(b,0,0,1)|0;e=G;f=c[a+4>>2]|0;g=(((f+1|0)>>>0)/1e3|0)+1|0;h=(f>>>0)/(g>>>0)|0;lD(b,0);bD(b,1);bD(b,252);lD(b,0);lD(b,0);bD(b,225);bD(b,226);kD(b,g);kD(b,h);f=a+152|0;a=c[f>>2]|0;do{if((a|0)!=0&(h|0)>0){i=0;j=a;while(1){kD(b,c[j+((ca(i,g)|0)>>1<<2)>>2]|0);k=i+1|0;if((k|0)>=(h|0)){break}i=k;j=c[f>>2]|0}if((h|0)<1e3){l=h;break}m=UH(b,d,e)|0;n=G;return}else{l=0}}while(0);do{kD(b,0);l=l+1|0;}while((l|0)<1e3);m=UH(b,d,e)|0;n=G;return}function TH(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=a+12|0;f=c[d>>2]|0;g=a+16|0;h=c[g>>2]|0;i=fD(h,0,0,1)|0;j=G;lD(h,0);bD(h,1);bD(h,253);lD(h,0);lD(h,0);bD(h,225);bD(h,226);bD(h,3);k=f+36|0;lD(h,c[k>>2]|0);l=fD(h,0,0,1)|0;m=f+24|0;c[m>>2]=l;l=c[d>>2]|0;n=c[g>>2]|0;o=l+36|0;kD(n,c[o>>2]|0);kD(n,3);p=a+24|0;kD(n,(c[p>>2]|0)+1|0);kD(n,c[l+28>>2]|0);kD(n,e[l+40>>1]|0);kD(n,(c[p>>2]|0)+1|0);kD(n,c[l+32>>2]|0);kD(n,e[l+42>>1]|0);kD(n,c[o>>2]|0);kD(n,0);kD(n,0);kD(n,0);n=c[d>>2]|0;o=c[g>>2]|0;l=(c[n+48>>2]|0)==6e4?60:50;q=LGb(c[a+1140>>2]|0,2324608,0,0)|0;if((q|0)==0){r=0;s=0}else{t=pY(c[q+4>>2]|0)|0;r=G;s=t}t=c[n+192>>2]<<29|c[n+188>>2]<<30;q=c[n+172>>2]|0;u=c[n+176>>2]|0;v=c[n+180>>2]|0;w=c[n+184>>2]|0;x=n+4|0;y=l*3600|0;z=l*60|0;A=(ca(u,z)|0)+(ca(q,y)|0)+(ca(v,l)|0)+w+(c[x>>2]|0)|0;kD(o,c[n+52>>2]|0);kD(o,c[x>>2]|0);kD(o,c[x>>2]|0);kD(o,0);kD(o,c[x>>2]|0);kD(o,t|q<<24|u<<16|v<<8|w);kD(o,((((A>>>0)/(y>>>0)|0)>>>0)%24|0)<<24|t|((((A>>>0)/(z>>>0)|0)>>>0)%60|0)<<16|((((A>>>0)/(l>>>0)|0)>>>0)%60|0)<<8|((A>>>0)%(l>>>0)|0));rD(o,s,r);rD(o,s,r);oD(o,0);oD(o,0);oD(o,e[n+8>>1]|0);oD(o,1);oD(o,0);oD(o,e[n+10>>1]|0);n=c[g>>2]|0;o=c[d>>2]|0;r=fD(n,0,0,1)|0;s=G;l=xrc(r,s,c[o+24>>2]|0,0)|0;c[o+28>>2]=l;l=a+28|0;if((c[p>>2]|0)!=0){a=0;do{oD(n,e[(c[(c[(c[l>>2]|0)+(a<<2)>>2]|0)+12>>2]|0)+54>>1]|0);oD(n,1);a=a+1|0;}while(a>>>0<(c[p>>2]|0)>>>0)}oD(n,e[o+110>>1]|0);oD(n,1);o=fD(n,0,0,1)|0;n=xrc(o,G,r,s)|0;b[f+40>>1]=n;n=c[d>>2]|0;d=c[g>>2]|0;g=fD(d,0,0,1)|0;s=G;r=xrc(g,s,c[n+24>>2]|0,0)|0;c[n+32>>2]=r;r=n+56|0;o=n+4|0;a=n+192|0;n=0;A=c[p>>2]|0;do{if((n|0)==(A|0)){B=r}else{B=c[(c[(c[l>>2]|0)+(n<<2)>>2]|0)+12>>2]|0}z=fD(d,0,0,1)|0;t=G;oD(d,0);y=B+54|0;oD(d,e[y>>1]|0);oD(d,0);oD(d,0);kD(d,c[o>>2]|0);kD(d,0);kD(d,0);kD(d,c[o>>2]|0);dD(d,2398648,20);tD(d,e[y>>1]|0);y=22;do{bD(d,0);y=y+1|0;}while((y|0)<88);kD(d,c[B+40>>2]|0);kD(d,c[B+48>>2]|0);kD(d,c[B+44>>2]|0);kD(d,0);do{if((B|0)==(r|0)){kD(d,c[a>>2]|0);kD(d,0);kD(d,0);kD(d,0);kD(d,0);kD(d,0);kD(d,0);kD(d,0)}else{y=c[(c[l>>2]|0)+(n<<2)>>2]|0;w=y+8|0;v=c[w>>2]|0;u=c[v+48>>2]|0;if((u|0)==1|(u|0)==2){q=c[y+12>>2]|0;if((c[v+140>>2]|0)==4){kD(d,2)}else{kD(d,1)}kD(d,(c[q+88>>2]|0)==1|0);kD(d,3);kD(d,1);kD(d,c[q+80>>2]|0);kD(d,c[q+84>>2]|0);q=c[(c[w>>2]|0)+48>>2]|0;if((q|0)==2){kD(d,2)}else if((q|0)==1){kD(d,1)}else{kD(d,0)}kD(d,0);break}else if((u|0)==65536){rD(d,0,1072693248);rD(d,0,1072693248);kD(d,0);kD(d,0);kD(d,0);kD(d,0);break}else if((u|0)==25){kD(d,(c[v+140>>2]|0)==0?32:0);kD(d,0);kD(d,0);kD(d,0);kD(d,0);kD(d,0);kD(d,0);kD(d,0);break}else{break}}}while(0);v=fD(d,0,0,1)|0;u=G;fD(d,z,t,0)|0;q=xrc(v,u,z,t)|0;oD(d,q);fD(d,v,u,0)|0;n=n+1|0;A=c[p>>2]|0;}while(!(n>>>0>A>>>0));A=fD(d,0,0,1)|0;d=xrc(A,G,g,s)|0;b[f+42>>1]=d;d=fD(h,0,0,1)|0;f=xrc(d,G,c[m>>2]|0,0)|0;c[k>>2]=f;UH(h,i,j)|0;return}function UH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fD(a,0,0,1)|0;e=xrc(d,G,b,c)|0;d=e;e=(d|0)%4|0;if((e|0)==0){f=d}else{d=4-e|0;if((d|0)>0){e=(d|0)<0|0?-1:0;g=d;do{bD(a,0);g=wrc(g,e,-1,-1)|0;e=G;d=0;}while((e|0)>(d|0)|(e|0)==(d|0)&g>>>0>0>>>0)}g=fD(a,0,0,1)|0;e=xrc(g,G,b,c)|0;f=e}e=fD(a,0,0,1)|0;g=G;d=wrc(b,c,6,0)|0;fD(a,d,G,0)|0;lD(a,f);fD(a,e,g,0)|0;a=xrc(e,g,b,c)|0;return(G=G,a)|0}function VH(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+1024|0;g=c[a+12>>2]|0;j=c[a+16>>2]|0;bD(j,(e[b+52>>1]|0)+128|0);bD(j,d+192|0);k=fD(j,0,0,1)|0;l=G;tD(j,0);bD(j,76);bD(j,23);dD(j,2398648,20);tD(j,e[b+54>>1]|0);bD(j,0);a:do{switch(c[b+40>>2]|0){case 4:case 9:{m=c[(c[a+28>>2]|0)+(d<<2)>>2]|0;n=f|0;o=c[m+12>>2]|0;p=c[o+68>>2]|0;do{if((p|0)!=0){q=c[o+72>>2]|0;r=o+80|0;s=(((q|0)%(p|0)|0|0)!=0)+((q|0)/(p|0)|0)|0;c[r>>2]=s;do{if((q|0)!=0){t=c[o+76>>2]|0;u=(t|0)/(q|0)|0;v=o+84|0;c[v>>2]=u;if(((t|0)%(q|0)|0|0)==0){break}c[v>>2]=u+1}}while(0);if((s|0)>9){c[r>>2]=9}q=o+84|0;if((c[q>>2]|0)<=9){break}c[q>>2]=9}}while(0);p=c[m+8>>2]|0;q=c[p+124>>2]|0;if((q|0)==512|(q|0)==608){w=7}else if((q|0)==480){w=20}else{w=23}u=c[o+80>>2]|0;v=c[o+84>>2]|0;t=(c[p+140>>2]|0)==4?2:1;x=(c[o+88>>2]|0)==1|0;y=Rb(n|0,1024,2220936,(z=i,i=i+56|0,h[z>>3]=+(c[p+72>>2]|0),c[z+8>>2]=u,c[z+16>>2]=v,c[z+24>>2]=t,c[z+32>>2]=x,c[z+40>>2]=w,c[z+48>>2]=(q+15|0)/16|0,z)|0)|0;i=z;if(y>>>0<1024>>>0){bD(j,79);q=y+1|0;bD(j,q);dD(j,n,q);break a}else{KIb(0,0,2186320,(z=i,i=i+24|0,c[z>>2]=2156912,c[z+8>>2]=2131656,c[z+16>>2]=213,z)|0);i=z;Hd()}break};case 3:{z=c[g+192>>2]<<29|c[g+188>>2]<<30|c[g+172>>2]<<24|c[g+176>>2]<<16|c[g+180>>2]<<8|c[g+184>>2];bD(j,77);bD(j,8);kD(j,z);kD(j,0);break};case 5:case 6:{z=c[(c[a+28>>2]|0)+(d<<2)>>2]|0;bD(j,77);bD(j,8);q=(c[(c[z+8>>2]|0)+140>>2]|0)==0;rD(j,q?1073741825:1073741824,q?0:0);break};default:{bD(j,77);bD(j,8);rD(j,0,0)}}}while(0);bD(j,78);bD(j,4);lD(j,0);bD(j,80);bD(j,4);lD(j,c[b+56>>2]|0);bD(j,81);bD(j,4);lD(j,c[b+60>>2]|0);bD(j,82);bD(j,4);lD(j,c[b+64>>2]|0);b=fD(j,0,0,1)|0;d=G;fD(j,k,l,0)|0;a=xrc(-2,0,k,l)|0;l=wrc(a,G,b,d)|0;tD(j,l);fD(j,b,d,0)|0;i=f;return}function WH(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[a+8>>2]|0;if((b|0)>0){e=c[a+4>>2]|0;a=0;f=0;g=0;h=0;i=0;while(1){j=e+i|0;k=i+1|0;do{if((((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)-1|0)>>>0<255>>>0){l=d[1359664+(d[e+k|0]|0)|0]|0;m=i-1|0;n=e+((m|0)>0?m:0)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;m=zrc(je(n|0)|0,o|0,l+24|0)|0;l=m;if((l&-65536|0)!=65536){p=h;q=g;r=f;s=a;break}m=l>>>12&15;o=(m|0)==0?l&8:g;l=(m|0)==(f|0)|0;n=(l^1)+a|0;t=l+h|0;if((o|0)==0){p=t;q=0;r=c[1146368+(m<<2)>>2]|0;s=n;break}else{p=t;q=o;r=c[1146432+(m<<2)>>2]|0;s=n;break}}else{p=h;q=g;r=f;s=a}}while(0);if((k|0)<(b|0)){a=s;f=r;g=q;h=p;i=k}else{u=s;v=p;break}}}else{u=0;v=0}p=u<<1;if((v|0)>(p+6|0)){w=50;return w|0}w=(v|0)>(p+2|0)?25:0;return w|0}function XH(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[b+8>>2]|0;if((d|0)>0){e=c[b+4>>2]|0;b=0;f=0;g=0;h=0;i=-1;j=-256;k=-1;l=0;while(1){m=a[e+b|0]|0;n=m&255|j;o=i|0;do{if((j&-262144|0)==8388608&(i&255|0)==0){p=(m&255)>>>2&3;q=(j&768|0)!=512|(i&0|0)!=0|(p|0)==0;r=q&1;s=q?l:0;t=p;u=((p|0)!=(k|0)&(k|0)>0&(k|0)<6&1)+h|0;v=r+g|0;w=(r^1)+f|0}else{if(!((j&-8388608|0)==8388608&(i&255|0)==0)){s=l;t=k;u=h;v=g;w=f;break}r=(j>>>18|i<<14)&31;p=(r|0)<(l|0);s=p?l:r;t=k;u=h;v=(p&1)+g|0;w=f}}while(0);m=b+1|0;if((m|0)<(d|0)){b=m;f=w;g=v;h=u;i=o<<8|n>>>24;j=n<<8|0>>>24;k=t;l=s}else{x=w;y=v;z=u;break}}}else{x=0;y=0;z=0}u=y<<1;if((x|0)>(u+3+(z<<1)|0)){A=50;return A|0}A=(x|0)>(u|0)?25:0;return A|0}function YH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=c[b+8>>2]|0;do{if((e|0)>0){f=c[b+4>>2]|0;g=0;h=0;i=0;j=0;k=0;l=0;m=-256;a:while(1){n=d[f+l|0]|0;o=n|m;do{if((m|0)==256){p=n&31;if((n&128|0)!=0){q=0;r=18;break a}s=(n&96|0)==0;if(!((7744>>>(p>>>0)&1|0)==0|s)){q=0;r=18;break a}if((8608>>>(p>>>0)&1|0)!=0&s){q=0;r=18;break a}s=(-540671>>>(p>>>0)&1)+j|0;if((p|0)==8){t=k;u=s;v=i;w=h+1|0;x=g;break}else if((p|0)==7){if(!((a[f+(l+2)|0]&3)==0)){q=0;r=18;break a}t=k;u=s;v=i;w=h;x=g+1|0;break}else if((p|0)==5){t=k;u=s;v=i+1|0;w=h;x=g;break}else if((p|0)==1){t=k+1|0;u=s;v=i;w=h;x=g;break}else{t=k;u=s;v=i;w=h;x=g;break}}else{t=k;u=j;v=i;w=h;x=g}}while(0);n=l+1|0;if((n|0)<(e|0)){g=x;h=w;i=v;j=u;k=t;l=n;m=o<<8}else{r=14;break}}if((r|0)==14){if((x|0)==0|(w|0)==0){break}if(!((v|0)!=0|(t|0)>3)){break}if((u|0)<(w+x+v|0)){q=51}else{break}return q|0}else if((r|0)==18){return q|0}}}while(0);q=0;return q|0}function ZH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=i;d=c[a+12>>2]|0;e=a+32|0;do{if((ob(e|0,511)|0)==0){f=4}else{g=pd()|0;h=(c[g>>2]|0)!=17;KIb(a,h?16:40,2433968,(j=i,i=i+8|0,c[j>>2]=e,j)|0);i=j;if(!h){f=4;break}k=-(c[g>>2]|0)|0;f=39}}while(0);a:do{if((f|0)==4){g=gH(2425104,0,0)|0;if((g|0)==0){l=-1481985528;break}h=a+24|0;m=pJb((c[h>>2]|0)*33888|0)|0;n=m;o=d+20|0;c[o>>2]=n;if((m|0)==0){l=-12;break}m=d+24|0;p=c[m>>2]|0;b:do{if((c[h>>2]|0)==0){q=n;r=p}else{s=a+28|0;t=a+1160|0;u=0;v=p;w=n;x=n+(p*33888|0)|0;while(1){y=c[(c[s>>2]|0)+(u<<2)>>2]|0;z=c[y+8>>2]|0;A=z+72|0;if((c[A>>2]|0)==0){f=9;break}B=c[z+8>>2]|0;if((B|0)==0){if((c[w+(v*33888|0)+33852>>2]|0)==0){C=x}else{z=v+1|0;c[m>>2]=z;C=w+(z*33888|0)|0}c[C+33852>>2]=1;D=C}else if((B|0)==1){if((c[w+(v*33888|0)+33848>>2]|0)==0){E=x}else{B=v+1|0;c[m>>2]=B;E=w+(B*33888|0)|0}c[E+33848>>2]=1;D=E}else{f=17;break}B=D|0;c[B>>2]=(c[B>>2]|0)+(c[A>>2]|0);A=D+8|0;B=c[A>>2]|0;if((B|0)==0){c[D+4>>2]=u;z=HR()|0;if((z|0)==0){l=-12;break a}c[A>>2]=z;c[z+8>>2]=g;A=z+1160|0;F=c[t+4>>2]|0;c[A>>2]=c[t>>2];c[A+4>>2]=F;F=aD(D+16|0,32768,2,D,0,82,0)|0;c[z+16>>2]=F;if((F|0)==0){l=-12;break a}G=z;H=c[(c[s>>2]|0)+(u<<2)>>2]|0}else{G=B;H=y}c[H+4>>2]=c[m>>2];y=ZX(G,0)|0;if((y|0)==0){l=-12;break a}nWa(c[y+8>>2]|0,c[(c[(c[s>>2]|0)+(u<<2)>>2]|0)+8>>2]|0)|0;B=(c[(c[s>>2]|0)+(u<<2)>>2]|0)+80|0;z=y+80|0;y=c[B+4>>2]|0;c[z>>2]=c[B>>2];c[z+4>>2]=y;y=u+1|0;z=c[m>>2]|0;B=c[o>>2]|0;if(y>>>0<(c[h>>2]|0)>>>0){u=y;v=z;w=B;x=B+(z*33888|0)|0}else{q=B;r=z;break b}}if((f|0)==9){KIb(a,16,2414168,(j=i,i=i+8|0,c[j>>2]=u,j)|0);i=j;l=-22;break a}else if((f|0)==17){KIb(a,16,2406512,(j=i,i=i+8|0,c[j>>2]=u,j)|0);i=j;l=-22;break a}}}while(0);if((c[q+(r*33888|0)+8>>2]|0)==0){I=r}else{h=r+1|0;c[m>>2]=h;I=h}c:do{if((I|0)>0){h=d+12|0;g=a;p=a+28|0;n=0;x=q;while(1){w=x+(n*33888|0)|0;v=x+(n*33888|0)+8|0;s=TO(c[v>>2]|0,0)|0;if((s|0)<0){l=s;break a}c[x+(n*33888|0)+12>>2]=1;eD(c[(c[v>>2]|0)+16>>2]|0);s=c[v>>2]|0;if((c[s+24>>2]|0)!=0){t=x+(n*33888|0)+4|0;z=0;B=s;do{s=(c[(c[B+28>>2]|0)+(z<<2)>>2]|0)+40|0;y=(c[(c[p>>2]|0)+((c[t>>2]|0)+z<<2)>>2]|0)+40|0;F=c[s+4>>2]|0;c[y>>2]=c[s>>2];c[y+4>>2]=F;z=z+1|0;B=c[v>>2]|0;}while(z>>>0<(c[B+24>>2]|0)>>>0)}Rb(x+(n*33888|0)+32784|0,1024,2398904,(j=i,i=i+16|0,c[j>>2]=e,c[j+8>>2]=n,j)|0)|0;i=j;B=dI(a,w,0,0)|0;if((B|0)<0){l=B;break a}do{if((c[x+(n*33888|0)+33852>>2]|0)==0){if((c[h>>2]|0)>=1){break}KIb(g,24,2391904,(j=i,i=i+8|0,c[j>>2]=n,j)|0);i=j}}while(0);c[x+(n*33888|0)+33840>>2]=1;eI(a,w,0)|0;B=n+1|0;if((B|0)>=(c[m>>2]|0)){break c}n=B;x=c[o>>2]|0}}}while(0);k=bI(a,0)|0;f=39}}while(0);do{if((f|0)==39){if((k|0)==0){J=0}else{l=k;break}i=b;return J|0}}while(0);cI(a);J=l;i=b;return J|0}function _H(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=b+32|0;h=c[(c[a+28>>2]|0)+(c[g>>2]<<2)>>2]|0;j=c[h+4>>2]|0;k=c[f+20>>2]|0;l=k+(j*33888|0)|0;m=c[k+(j*33888|0)+33840>>2]|0;n=c[f+12>>2]|0;f=Erc(n,(n|0)<0|0?-1:0,m,(m|0)<0|0?-1:0)|0;m=G;n=h+200|0;o=c[n>>2]|0;p=c[n+4>>2]|0;if((o|0)==0&(p|0)==(-2147483648|0)){q=b+16|0;r=c[q>>2]|0;s=c[q+4>>2]|0;c[n>>2]=r;c[n+4>>2]=s;t=s;u=r}else{t=p;u=o}if((c[k+(j*33888|0)+33852>>2]|0)==0){v=5}else{if((c[(c[h+8>>2]|0)+8>>2]|0)==0){v=5}}do{if((v|0)==5){o=b+16|0;p=xrc(c[o>>2]|0,c[o+4>>2]|0,u,t)|0;c[e>>2]=1;c[e+4>>2]=1e6;if(!((YIb(p,G,h+40|0,f,m,e)|0)>-1)){break}if((c[b+36>>2]&1|0)==0){break}if((c[k+(j*33888|0)+33828>>2]|0)==0){break}p=aI(a,l,0,c[o>>2]|0,c[o+4>>2]|0)|0;if((p|0)<0){w=p}else{break}i=d;return w|0}}while(0);l=k+(j*33888|0)+33828|0;e=c[l>>2]|0;m=b+16|0;if((e|0)==0){f=c[m+4>>2]|0;h=k+(j*33888|0)+33808|0;c[h>>2]=c[m>>2];c[h+4>>2]=f}f=c[m+4>>2]|0;h=k+(j*33888|0)+33816|0;c[h>>2]=c[m>>2];c[h+4>>2]=f;c[l>>2]=e+1;w=aP(c[k+(j*33888|0)+8>>2]|0,(c[g>>2]|0)-(c[k+(j*33888|0)+4>>2]|0)|0,b,a)|0;i=d;return w|0}function $H(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+1024|0;d=b|0;e=c[a+12>>2]|0;f=e+24|0;if((c[f>>2]|0)>0){g=e+20|0;h=0;do{j=c[g>>2]|0;k=j+(h*33888|0)+33816|0;aI(a,j+(h*33888|0)|0,1,c[k>>2]|0,c[k+4>>2]|0)|0;h=h+1|0;}while((h|0)<(c[f>>2]|0))}bI(a,1)|0;if((c[e+16>>2]|0)==0){cI(a);i=b;return 0}e=d|0;d=a+32|0;Rb(e|0,1024,2398536,(h=i,i=i+8|0,c[h>>2]=d,h)|0)|0;i=h;be(e|0)|0;if((c[f>>2]|0)>0){g=0;do{Rb(e|0,1024,2324528,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=g,h)|0)|0;i=h;be(e|0)|0;g=g+1|0;}while((g|0)<(c[f>>2]|0))}dd(d|0)|0;cI(a);i=b;return 0}function aI(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+1024|0;h=c[a+12>>2]|0;j=b+33828|0;if((c[j>>2]|0)==0){k=0;i=g;return k|0}l=c[(c[(c[a+28>>2]|0)+(c[b+4>>2]<<2)>>2]|0)+4>>2]|0;eD(c[(c[b+8>>2]|0)+16>>2]|0);c[j>>2]=0;j=b+33824|0;m=fD(c[j>>2]|0,0,0,1)|0;fD(c[j>>2]|0,0,0,0)|0;lD(c[j>>2]|0,m);eD(c[j>>2]|0);WD(c[j>>2]|0)|0;c[j>>2]=0;j=g|0;m=b+33840|0;n=c[m>>2]|0;Rb(j|0,1024,2464208,(o=i,i=i+24|0,c[o>>2]=a+32,c[o+8>>2]=l,c[o+16>>2]=n,o)|0)|0;i=o;n=b+32784|0;if((Gc(n|0,j|0)|0)==-1){KIb(a,16,2472344,(o=i,i=i+16|0,c[o>>2]=n,c[o+8>>2]=j,o)|0);i=o;k=-(c[(pd()|0)>>2]|0)|0;i=g;return k|0}o=b+33808|0;n=c[o>>2]|0;l=c[o+4>>2]|0;o=xrc(e,f,n,l)|0;p=(n|0)==(e|0)&(l|0)==(f|0);q=p?1:o;o=p?0:G;p=b+33832|0;r=b+33836|0;s=c[r>>2]|0;do{if((c[p>>2]|0)<(s|0)){t=7}else{u=(s<<1)+2|0;c[r>>2]=u;if((oJb(b+33844|0,u,4)|0)>=0){t=7;break}c[r>>2]=0;c[p>>2]=0}}while(0);do{if((t|0)==7){r=pJb(1048)|0;if((r|0)==0){break}CFb(r,j,1024)|0;s=r+1024|0;c[s>>2]=n;c[s+4>>2]=l;s=r+1032|0;c[s>>2]=q;c[s+4>>2]=o;s=c[m>>2]|0;c[r+1040>>2]=s;u=c[p>>2]|0;c[p>>2]=u+1;c[(c[b+33844>>2]|0)+(u<<2)>>2]=r;c[m>>2]=s+1}}while(0);m=(d|0)!=0;do{if(m){v=0}else{o=dI(a,b,e,f)|0;if((o|0)<0){k=o}else{v=o;break}i=g;return k|0}}while(0);f=c[h+4>>2]|0;do{if((f|0)==0){if(!m){break}e=c[h+16>>2]|0;if((e|0)==0){break}o=c[p>>2]|0;w=o;x=o-(c[h+8>>2]|0)|0;y=e;t=17}else{e=c[p>>2]|0;o=e-f-(c[h+8>>2]|0)|0;if(!m){z=o;t=18;break}w=e;x=o;y=c[h+16>>2]|0;t=17}}while(0);if((t|0)==17){z=(y|0)==0?x:w;t=18}do{if((t|0)==18){if((z|0)<=0){break}w=b+33844|0;x=0;do{be(c[(c[w>>2]|0)+(x<<2)>>2]|0)|0;kJb(c[(c[w>>2]|0)+(x<<2)>>2]|0);x=x+1|0;}while((x|0)<(z|0));x=(c[p>>2]|0)-z|0;c[p>>2]=x;y=c[w>>2]|0;orc(y|0,y+(z<<2)|0,x<<2|0)|0}}while(0);if(!((v|0)>-1)){k=v;i=g;return k|0}k=eI(a,b,d)|0;i=g;return k|0}function bI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+2056|0;e=d|0;f=c[a+12>>2]|0;g=f+24|0;if((c[g>>2]|0)>0){j=(c[f+20>>2]|0)+33816|0;k=c[c[a+28>>2]>>2]|0;l=(+((c[j>>2]|0)>>>0)+ +(c[j+4>>2]|0)*4294967296.0)*(+(c[k+40>>2]|0)/+(c[k+44>>2]|0))}else{l=0.0}k=d+8|0;j=a+32|0;Rb(k|0,1024,2398536,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;n=d+1032|0;Rb(n|0,1024,2269224,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;o=VD(e,n,2,a+1160|0,0)|0;if((o|0)<0){KIb(a,16,2220888,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;p=o;i=d;return p|0}YD(c[e>>2]|0,2186144,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;YD(c[e>>2]|0,2156832,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;o=c[e>>2]|0;q=KFb(j)|0;YD(o,2131608,(m=i,i=i+8|0,c[m>>2]=q,m)|0)|0;i=m;q=(b|0)!=0;YD(c[e>>2]|0,2108440,(m=i,i=i+8|0,c[m>>2]=q?2626544:2600648,m)|0)|0;i=m;YD(c[e>>2]|0,2575760,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;if(q){YD(c[e>>2]|0,2556888,(m=i,i=i+8|0,h[m>>3]=l,m)|0)|0;i=m}a:do{if((c[g>>2]|0)>0){q=f+20|0;b=0;while(1){o=c[q>>2]|0;j=o+(b*33888|0)+33860|0;r=(((c[j>>2]|0)+2|0)/3|0)<<2|1;s=hJb(r)|0;if((s|0)==0){break}RFb(s,r,c[o+(b*33888|0)+33856>>2]|0,c[j>>2]|0)|0;YD(c[e>>2]|0,2539432,(m=i,i=i+16|0,c[m>>2]=b,c[m+8>>2]=b,m)|0)|0;i=m;YD(c[e>>2]|0,2522728,(m=i,i=i+24|0,c[m>>2]=(c[o+(b*33888|0)>>2]|0)/1e3|0,c[m+8>>2]=b,c[m+16>>2]=b,m)|0)|0;i=m;YD(c[e>>2]|0,2507968,(m=i,i=i+8|0,c[m>>2]=s,m)|0)|0;i=m;YD(c[e>>2]|0,2493544,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;kJb(s);b=b+1|0;if((b|0)>=(c[g>>2]|0)){break a}}WD(c[e>>2]|0)|0;p=-12;i=d;return p|0}}while(0);YD(c[e>>2]|0,2483512,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;eD(c[e>>2]|0);WD(c[e>>2]|0)|0;if(!((Gc(n|0,k|0)|0)==-1)){p=0;i=d;return p|0}KIb(a,16,2472344,(m=i,i=i+16|0,c[m>>2]=n,c[m+8>>2]=k,m)|0);i=m;p=-(c[(pd()|0)>>2]|0)|0;i=d;return p|0}function cI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(c[a+12>>2]|0)+20|0;d=b;e=c[d>>2]|0;if((e|0)==0){return}f=a+24|0;a:do{if((c[f>>2]|0)!=0){a=0;g=e;while(1){h=g+(a*33888|0)+33824|0;i=c[h>>2]|0;if((i|0)!=0){WD(i)|0}c[h>>2]=0;h=g+(a*33888|0)+8|0;i=c[h>>2]|0;do{if((i|0)!=0){if((c[g+(a*33888|0)+12>>2]|0)==0){j=i}else{$O(i)|0;k=c[h>>2]|0;if((k|0)==0){break}else{j=k}}k=c[j+16>>2]|0;if((k|0)==0){l=j}else{kJb(k);l=c[h>>2]|0}if((l|0)==0){break}pX(l)}}while(0);kJb(c[g+(a*33888|0)+33856>>2]|0);h=g+(a*33888|0)+33880|0;if((c[h>>2]|0)>0){i=0;do{kJb(c[g+(a*33888|0)+33864+(i<<2)>>2]|0);i=i+1|0;}while((i|0)<(c[h>>2]|0))}h=g+(a*33888|0)+33832|0;i=g+(a*33888|0)+33844|0;k=c[i>>2]|0;if((c[h>>2]|0)>0){m=0;n=k;while(1){kJb(c[n+(m<<2)>>2]|0);o=m+1|0;p=c[i>>2]|0;if((o|0)<(c[h>>2]|0)){m=o;n=p}else{q=p;break}}}else{q=k}kJb(q);n=a+1|0;if(!(n>>>0<(c[f>>2]|0)>>>0)){break a}a=n;g=c[d>>2]|0}}}while(0);mJb(b);return}function dI(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=d+33824|0;h=VD(g,d+32784|0,2,b+1160|0,0)|0;if((h|0)<0){i=h;return i|0}lD(c[g>>2]|0,0);kD(c[g>>2]|0,1952539757);h=d+33880|0;if((c[h>>2]|0)<=0){i=0;return i|0}b=e&255;j=(e>>>8|f<<24)&255;k=(e>>>16|f<<16)&255;l=(e>>>24|f<<8)&127;f=0;while(1){e=d+33864+(f<<2)|0;a[(c[e>>2]|0)+6|0]=b;a[(c[e>>2]|0)+5|0]=j;a[(c[e>>2]|0)+4|0]=k;a[(c[e>>2]|0)+7|0]=l;dD(c[g>>2]|0,c[e>>2]|0,c[d+33872+(f<<2)>>2]|0);e=f+1|0;if((e|0)<(c[h>>2]|0)){f=e}else{i=0;break}}return i|0}function eI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+2056|0;f=e|0;g=e+8|0;h=e+1032|0;j=c[(c[(c[a+28>>2]|0)+(c[b+4>>2]<<2)>>2]|0)+4>>2]|0;k=c[(c[a+12>>2]|0)+4>>2]|0;l=c[b+33832>>2]|0;if((k|0)==0){m=0}else{n=l-k|0;m=(n|0)>0?n:0}n=b+33832|0;k=l-m|0;o=(d|0)!=0;do{if(o){d=b+33816|0;p=c[d+4>>2]|0;q=c[d>>2]|0}else{if((l|0)==0){p=0;q=0;break}d=(c[(c[b+33844>>2]|0)+(l-1<<2)>>2]|0)+1024|0;p=c[d+4>>2]|0;q=c[d>>2]|0}}while(0);l=g|0;g=a+32|0;Rb(l|0,1024,2324528,(d=i,i=i+16|0,c[d>>2]=g,c[d+8>>2]=j,d)|0)|0;i=d;r=h|0;Rb(r|0,1024,2449944,(d=i,i=i+16|0,c[d>>2]=g,c[d+8>>2]=j,d)|0)|0;i=d;j=VD(f,r,2,a+1160|0,0)|0;if((j|0)<0){KIb(a,16,2220888,(d=i,i=i+8|0,c[d>>2]=r,d)|0);i=d;s=j;i=e;return s|0}lD(c[f>>2]|0,0);kD(c[f>>2]|0,1953718881);lD(c[f>>2]|0,0);j=b+33840|0;lD(c[f>>2]|0,(c[j>>2]|0)-1|0);bD(c[f>>2]|0,o?0:32);lD(c[f>>2]|0,1e3);sD(c[f>>2]|0,q,p);sD(c[f>>2]|0,0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,1);p=fD(c[f>>2]|0,0,0,1)|0;q=G;lD(c[f>>2]|0,0);kD(c[f>>2]|0,1953657697);lD(c[f>>2]|0,0);bD(c[f>>2]|0,0);lD(c[f>>2]|0,1);lD(c[f>>2]|0,1);if(o){t=(c[j>>2]|0)-1|0}else{t=-1}lD(c[f>>2]|0,t);t=c[f>>2]|0;j=fD(t,0,0,1)|0;o=G;fD(t,p,q,0)|0;g=xrc(j,o,p,q)|0;lD(t,g);fD(t,j,o,0)|0;bD(c[f>>2]|0,1);o=fD(c[f>>2]|0,0,0,1)|0;j=G;lD(c[f>>2]|0,0);kD(c[f>>2]|0,1953654369);lD(c[f>>2]|0,0);lD(c[f>>2]|0,1e3);bD(c[f>>2]|0,0);lD(c[f>>2]|0,k);k=c[f>>2]|0;if((m|0)<(c[n>>2]|0)){t=b+33844|0;b=m;m=k;while(1){lD(m,c[(c[(c[t>>2]|0)+(b<<2)>>2]|0)+1040>>2]|0);g=(c[(c[t>>2]|0)+(b<<2)>>2]|0)+1024|0;sD(c[f>>2]|0,c[g>>2]|0,c[g+4>>2]|0);lD(c[f>>2]|0,c[(c[(c[t>>2]|0)+(b<<2)>>2]|0)+1032>>2]|0);g=b+1|0;q=c[f>>2]|0;if((g|0)<(c[n>>2]|0)){b=g;m=q}else{u=q;break}}}else{u=k}k=fD(u,0,0,1)|0;m=G;fD(u,o,j,0)|0;b=xrc(k,m,o,j)|0;lD(u,b);fD(u,k,m,0)|0;m=c[f>>2]|0;k=fD(m,0,0,1)|0;u=G;fD(m,0,0,0)|0;lD(m,k);fD(m,k,u,0)|0;WD(c[f>>2]|0)|0;if(!((Gc(r|0,l|0)|0)==-1)){s=0;i=e;return s|0}KIb(a,16,2472344,(d=i,i=i+16|0,c[d>>2]=r,c[d+8>>2]=l,d)|0);i=d;s=-(c[(pd()|0)>>2]|0)|0;i=e;return s|0}function fI(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b;h=c[b+33824>>2]|0;do{if((h|0)==0){i=b+33860|0;if((c[i>>2]|0)!=0){break}if((f|0)<13){j=-1094995529;return j|0}if((grc(e,2385344,3)|0)!=0){j=-1094995529;return j|0}k=f-13|0;a:do{if((k|0)>14){l=b+33880|0;m=b+33856|0;n=k;o=e+13|0;b:while(1){p=a[o]|0;q=(d[o+2|0]|0)<<8|(d[o+1|0]|0)<<16|(d[o+3|0]|0);r=q+15|0;if((r|0)>(n|0)){j=-1094995529;s=21;break}do{if((p-8&255)>>>0<2>>>0){t=c[l>>2]|0;if(t>>>0>1>>>0){j=-1094995529;s=21;break b}c[g+33872+(t<<2)>>2]=r;t=hJb(r)|0;c[g+33864+(c[l>>2]<<2)>>2]=t;t=c[g+33864+(c[l>>2]<<2)>>2]|0;if((t|0)==0){j=-12;s=21;break b}nrc(t|0,o|0,r)|0;c[l>>2]=(c[l>>2]|0)+1}else{if(!(p<<24>>24==18)){break}if((c[m>>2]|0)!=0){j=-1094995529;s=21;break b}c[i>>2]=q;t=hJb(q)|0;c[m>>2]=t;if((t|0)==0){j=-12;s=21;break b}nrc(t|0,o+11|0,c[i>>2]|0)|0}}while(0);q=n-r|0;if((q|0)>14){n=q;o=o+r|0}else{u=m;break a}}if((s|0)==21){return j|0}}else{u=b+33856|0}}while(0);i=(c[u>>2]|0)==0;if(i){j=i?-1094995529:0}else{break}return j|0}else{dD(h,e,f)}}while(0);j=f;return j|0}function gI(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=(c[a+8>>2]|0)-1|0;a:do{if((b|0)>0){e=c[a+4>>2]|0;f=0;g=0;h=0;i=0;j=0;k=-256;b:while(1){l=d[e+j|0]|0;m=l|k;c:do{if((k|0)==256){if((l&129|0)!=0){n=14;break b}o=j+1|0;if((d[e+o|0]|0)>>>0>7>>>0){n=14;break b}switch(l>>>1&63|0){case 33:{p=i;q=h;r=g+1|0;s=f;t=o;break c;break};case 34:{p=i;q=h+1|0;r=g;s=f;t=o;break c;break};case 32:{p=i;q=h;r=g;s=f+1|0;t=o;break c;break};case 18:case 16:case 17:case 21:case 20:case 19:{p=i+1|0;q=h;r=g;s=f;t=o;break c;break};default:{p=i;q=h;r=g;s=f;t=o;break c}}}else{p=i;q=h;r=g;s=f;t=j+1|0}}while(0);if((t|0)<(b|0)){f=s;g=r;h=q;i=p;j=t;k=m<<8}else{u=s;v=r;w=q;x=p;break a}}if((n|0)==14){return 0}}else{u=0;v=0;w=0;x=0}}while(0);return((u|0)==0|(v|0)==0|(w|0)==0|(x|0)==0?0:51)|0}function hI(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((krc(b,2433960,7)|0)!=0){d=0;return d|0}if((Db(b|0,2425080)|0)!=0){d=100;return d|0}if((Db(b|0,2385320)|0)==0){a=(Db(b|0,2378248)|0)==0;return(a?0:100)|0}else{d=100;return d|0}return 0}function iI(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;d=i;i=i+32|0;e=d|0;f=d+8|0;do{if((c[b+1084>>2]&128|0)==0){g=b+16|0;h=c[(c[g>>2]|0)+20>>2]|0;j=c[b+12>>2]|0;k=j;c[j+52>>2]=b+1160;if((h|0)==0){l=j;m=k;n=g;break}if((c[(c[h+4>>2]|0)+56>>2]|0)==0){l=j;m=k;n=g;break}o=j+56|0;p=o;mJb(o);q=h+8|0;MJb(c[q>>2]|0,2269064,0,p)|0;h=c[p>>2]|0;do{if((h|0)!=0){if((a[h]|0)!=0){break}mJb(o)}}while(0);o=j+60|0;h=o;mJb(o);MJb(c[q>>2]|0,2220800,0,h)|0;p=c[h>>2]|0;do{if((p|0)!=0){if((a[p]|0)!=0){break}mJb(o)}}while(0);o=j+64|0;p=o;mJb(o);MJb(c[q>>2]|0,2186088,0,p)|0;h=c[p>>2]|0;if((h|0)==0){l=j;m=k;n=g;break}if((a[h]|0)!=0){l=j;m=k;n=g;break}mJb(o);l=j;m=k;n=g}else{o=c[b+12>>2]|0;c[o+52>>2]=b+1160;l=o;m=o;n=b+16|0}}while(0);o=oI(m,b+32|0,0,c[n>>2]|0)|0;a:do{if((o|0)<0){r=o}else{n=l;if((c[n>>2]|0)==0){KIb(0,24,2156792,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;r=-541478725;break}h=l+8|0;p=c[h>>2]|0;t=l+12|0;if((p|0)>1){u=19}else{if((c[(c[c[t>>2]>>2]|0)+4348>>2]|0)==0){u=19}else{v=o;w=p}}b:do{if((u|0)==19){x=o;y=0;z=p;while(1){if((y|0)>=(z|0)){v=x;w=z;break b}A=c[(c[t>>2]|0)+(y<<2)>>2]|0;B=oI(m,A|0,A,0)|0;if((B|0)<0){r=B;break a}x=B;y=y+1|0;z=c[h>>2]|0}}}while(0);t=l+4|0;p=c[c[(c[c[t>>2]>>2]|0)+8>>2]>>2]|0;g=c[p+4348>>2]|0;if((g|0)==0){KIb(0,24,2156792,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;r=-541478725;break}if((c[p+4332>>2]|0)!=0){if((g|0)>0){k=c[p+4352>>2]|0;p=0;j=0;q=0;while(1){z=c[k+(q<<2)>>2]|0;y=wrc(c[z>>2]|0,c[z+4>>2]|0,j,p)|0;z=G;x=q+1|0;if((x|0)<(g|0)){p=z;j=y;q=x}else{C=z;D=y;break}}}else{C=0;D=0}q=b+1064|0;c[q>>2]=D;c[q+4>>2]=C}c:do{if((w|0)>0){q=l+12|0;j=0;p=0;g=v;k=w;while(1){y=c[(c[q>>2]|0)+(p<<2)>>2]|0;c[e>>2]=0;z=y+4348|0;if((c[z>>2]|0)==0){E=g;F=j;H=k}else{x=HR()|0;I=y+4240|0;c[I>>2]=x;if((x|0)==0){r=-12;break a}c[y+4236>>2]=p;c[y+4356>>2]=1;c[y+4232>>2]=b;x=c[y+4344>>2]|0;B=y+4364|0;c[B>>2]=x;do{if((c[y+4332>>2]|0)==0){A=c[z>>2]|0;if((A|0)<=3){break}c[B>>2]=A-3+x}}while(0);x=hJb(32768)|0;c[y+4224>>2]=x;B=y+4096|0;$C(B,x,32768,0,y|0,300,0,0)|0;c[y+4184>>2]=0;J=y+4352|0;K=nX(B,e,(c[c[J>>2]>>2]|0)+8|0,0,0,0)|0;if((K|0)<0){break}c[(c[I>>2]|0)+16>>2]=B;c[y+4328>>2]=j;B=oX(I,(c[c[J>>2]>>2]|0)+8|0,c[e>>2]|0,0)|0;if((B|0)<0){r=B;break a}B=c[I>>2]|0;x=B+20|0;c[x>>2]=c[x>>2]&-2;x=OX(B,0)|0;if((x|0)<0){r=x;break a}if((c[(c[I>>2]|0)+24>>2]|0)==0){L=0}else{B=0;while(1){z=ZX(b,0)|0;A=c[(c[(c[I>>2]|0)+28>>2]|0)+(B<<2)>>2]|0;if((z|0)==0){r=-12;break a}c[z+4>>2]=p;_X(z,c[A+188>>2]|0,c[A+40>>2]|0,c[A+44>>2]|0);nWa(c[z+8>>2]|0,c[(c[(c[(c[I>>2]|0)+28>>2]|0)+(B<<2)>>2]|0)+8>>2]|0)|0;z=B+1|0;A=c[(c[I>>2]|0)+24>>2]|0;if(z>>>0<A>>>0){B=z}else{L=A;break}}}E=x;F=L+j|0;H=c[h>>2]|0}B=p+1|0;if((B|0)<(H|0)){j=F;p=B;g=E;k=H}else{M=E;break c}}KIb(b,16,2131544,(s=i,i=i+8|0,c[s>>2]=(c[c[J>>2]>>2]|0)+8,s)|0);i=s;pX(c[I>>2]|0);c[I>>2]=0;r=K;break a}else{M=v}}while(0);if((c[n>>2]|0)>0){h=f|0;k=m|0;g=m+4|0;p=b+28|0;j=0;do{q=c[(c[t>>2]|0)+(j<<2)>>2]|0;B=q|0;Rb(h|0,20,2108400,(s=i,i=i+8|0,c[s>>2]=c[B>>2],s)|0)|0;i=s;y=$X(b,j)|0;if((y|0)==0){r=M;break a}MGb(y+20|0,2626504,h,0)|0;y=q+4|0;A=c[y>>2]|0;if((A|0)>0){z=q+8|0;q=0;N=A;while(1){A=c[(c[z>>2]|0)+(q<<2)>>2]|0;O=c[k>>2]|0;if((O|0)>0){P=c[g>>2]|0;Q=0;R=0;while(1){S=c[P+(Q<<2)>>2]|0;T=c[S+4>>2]|0;U=S+8|0;S=0;while(1){if((S|0)>=(T|0)){V=R;break}if((c[(c[U>>2]|0)+(S<<2)>>2]|0)==(A|0)){u=56;break}else{S=S+1|0}}if((u|0)==56){u=0;V=R+1|0}S=Q+1|0;if((S|0)<(O|0)&(V|0)<2){Q=S;R=V}else{W=V;break}}}else{W=0}R=A+4240|0;if((c[(c[R>>2]|0)+24>>2]|0)==0){X=N}else{Q=A+4328|0;if((W|0)>1){O=0;do{bY(b,j,(c[Q>>2]|0)+O|0);O=O+1|0;}while(O>>>0<(c[(c[R>>2]|0)+24>>2]|0)>>>0)}else{O=0;do{A=(c[Q>>2]|0)+O|0;P=c[(c[p>>2]|0)+(A<<2)>>2]|0;bY(b,j,A);if((c[B>>2]|0)!=0){MGb(P+88|0,2626504,h,0)|0}O=O+1|0;}while(O>>>0<(c[(c[R>>2]|0)+24>>2]|0)>>>0)}X=c[y>>2]|0}R=q+1|0;if((R|0)<(X|0)){q=R;N=X}else{break}}}j=j+1|0;}while((j|0)<(c[n>>2]|0))}c[l+24>>2]=1;n=l+32|0;c[n>>2]=0;c[n+4>>2]=-2147483648;n=l+40|0;c[n>>2]=0;c[n+4>>2]=-2147483648;Y=0;i=d;return Y|0}}while(0);mI(m);l=m|0;X=m+4|0;if((c[l>>2]|0)>0){m=0;do{b=c[(c[X>>2]|0)+(m<<2)>>2]|0;mJb(b+8|0);kJb(b);m=m+1|0;}while((m|0)<(c[l>>2]|0))}mJb(X);c[l>>2]=0;Y=r;i=d;return Y|0}function jI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=f+24|0;if((c[g>>2]|0)!=0){nI(a,1)|0;c[g>>2]=0}g=f+20|0;h=f+8|0;j=f+12|0;k=f+32|0;l=e|0;m=e+4|0;n=f+40|0;o=f+48|0;f=-1;a:while(1){c[g>>2]=0;if((c[h>>2]|0)>0){p=f;q=0}else{r=f;break}while(1){s=c[(c[j>>2]|0)+(q<<2)>>2]|0;b:do{if((c[s+4356>>2]|0)==0){t=s+4272|0}else{u=s+4248|0;v=s+4272|0;if((c[v>>2]|0)!=0){t=v;break}w=s+4240|0;x=uX(c[w>>2]|0,u)|0;c:do{if((x|0)<0){y=x}else{z=s+4264|0;A=s+4280|0;B=s+4284|0;while(1){do{if((c[k>>2]|0)==0&(c[k+4>>2]|0)==(-2147483648|0)){C=c[z>>2]|0;D=c[z+4>>2]|0;if((C|0)==0&(D|0)==(-2147483648|0)){break}E=(c[(c[(c[w>>2]|0)+28>>2]|0)+(c[A>>2]<<2)>>2]|0)+40|0;c[l>>2]=1;c[m>>2]=1e6;F=XIb(C,D,E,e)|0;c[k>>2]=F;c[k+4>>2]=G}}while(0);F=c[n>>2]|0;E=c[n+4>>2]|0;if((F|0)==0&(E|0)==(-2147483648|0)){t=v;break b}D=c[z>>2]|0;C=c[z+4>>2]|0;if((D|0)==0&(C|0)==(-2147483648|0)){H=17;break}I=c[(c[(c[(c[w>>2]|0)+28>>2]|0)+(c[A>>2]<<2)>>2]|0)+44>>2]|0;J=UIb(D,C,1e6,0,I,(I|0)<0|0?-1:0,2)|0;I=xrc(J,G,F,E)|0;E=G;F=-1;if((E|0)>(F|0)|(E|0)==(F|0)&I>>>0>-1>>>0){if((c[o>>2]&4|0)!=0){H=21;break}if((c[B>>2]&1|0)!=0){H=21;break}}P1(u);J1(u);c[v>>2]=0;I=uX(c[w>>2]|0,u)|0;if((I|0)<0){y=I;break c}}if((H|0)==17){H=0;c[n>>2]=0;c[n+4>>2]=-2147483648;t=v;break b}else if((H|0)==21){H=0;c[n>>2]=0;c[n+4>>2]=-2147483648;t=v;break b}}}while(0);if(!((jD(s+4096|0)|0)!=0|(y|0)==-541478725)){K=y;H=35;break a}J1(u);c[v>>2]=0;t=v}}while(0);do{if((c[t>>2]|0)==0){L=p}else{if((p|0)<0){L=q;break}w=c[(c[j>>2]|0)+(p<<2)>>2]|0;x=c[s+4364>>2]|0;B=c[w+4364>>2]|0;if((x|0)<(B|0)){L=q;break}if((x|0)!=(B|0)){L=p;break}B=s+4264|0;x=c[B>>2]|0;A=c[B+4>>2]|0;B=w+4264|0;z=c[B>>2]|0;I=c[B+4>>2]|0;B=c[(c[(c[s+4240>>2]|0)+28>>2]|0)+(c[s+4280>>2]<<2)>>2]|0;F=c[(c[(c[w+4240>>2]|0)+28>>2]|0)+(c[w+4280>>2]<<2)>>2]|0;if((x|0)==0&(A|0)==(-2147483648|0)){L=q;break}if((z|0)==0&(I|0)==(-2147483648|0)){L=p;break}w=B+48|0;E=c[w>>2]|0;J=c[w+4>>2]|0;w=(E|0)==0&(J|0)==(-2147483648|0);C=xrc(x,A,w?0:E,w?0:J)|0;J=G;w=F+48|0;E=c[w>>2]|0;A=c[w+4>>2]|0;w=(E|0)==0&(A|0)==(-2147483648|0);x=xrc(z,I,w?0:E,w?0:A)|0;A=(YIb(C,J,B+40|0,x,G,F+40|0)|0)<0;L=A?q:p}}while(0);s=q+1|0;if((s|0)<(c[h>>2]|0)){p=L;q=s}else{break}}if((c[g>>2]|0)==0){r=L;break}if((nI(a,0)|0)==0){r=L;break}else{f=L}}if((H|0)==35){i=d;return K|0}if(!((r|0)>-1)){K=-541478725;i=d;return K|0}nrc(b|0,(c[(c[j>>2]|0)+(r<<2)>>2]|0)+4248|0,80)|0;H=c[(c[j>>2]|0)+(r<<2)>>2]|0;r=b+32|0;c[r>>2]=(c[r>>2]|0)+(c[H+4328>>2]|0);J1(H+4248|0);c[H+4272>>2]=0;K=0;i=d;return K|0}function kI(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;mI(b);a=b;d=b+4|0;b=d;if((c[a>>2]|0)>0){e=0}else{mJb(d);c[a>>2]=0;return 0}do{f=c[(c[b>>2]|0)+(e<<2)>>2]|0;mJb(f+8|0);kJb(f);e=e+1|0;}while((e|0)<(c[a>>2]|0));mJb(d);c[a>>2]=0;return 0}function lI(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=c[a+12>>2]|0;if((f&2|0)!=0){h=-38;return h|0}if((c[(c[c[(c[c[g+4>>2]>>2]|0)+8>>2]>>2]|0)+4332>>2]|0)==0){h=-38;return h|0}c[g+48>>2]=f;if((b|0)<0){i=g+40|0;c[i>>2]=d;c[i+4>>2]=e;j=0;k=1e6;l=i;m=e;n=d;o=f&1^3}else{i=c[(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+44>>2]|0;b=i;p=(i|0)<0|0?-1:0;i=f&1^3;f=UIb(d,e,1e6,0,b,p,i)|0;q=G;r=g+40|0;c[r>>2]=f;c[r+4>>2]=q;j=p;k=b;l=r;m=q;n=f;o=i}i=UIb(d,e,1e6,0,k,j,o)|0;o=G;j=a+1064|0;a=c[j+4>>2]|0;if((a|0)<(m|0)|(a|0)==(m|0)&(c[j>>2]|0)>>>0<n>>>0){c[l>>2]=0;c[l+4>>2]=-2147483648;h=-5;return h|0}n=g+8|0;if((c[n>>2]|0)<=0){h=-5;return h|0}j=g+12|0;m=g+32|0;g=0;a=-5;while(1){k=c[(c[j>>2]|0)+(g<<2)>>2]|0;e=c[m>>2]|0;d=c[m+4>>2]|0;f=(e|0)==0&(d|0)==(-2147483648|0);q=k+4228|0;r=c[q>>2]|0;if((r|0)!=0){SC(r)|0;c[q>>2]=0}q=k+4248|0;P1(q);J1(q);c[k+4272>>2]=0;c[k+4148>>2]=0;q=c[k+4100>>2]|0;c[k+4108>>2]=q;c[k+4112>>2]=q;q=k+4136|0;c[q>>2]=0;c[q+4>>2]=0;q=c[k+4348>>2]|0;a:do{if((q|0)>0){r=k+4352|0;b=0;p=f?0:d;s=f?0:e;while(1){t=c[(c[r>>2]|0)+(b<<2)>>2]|0;u=c[t>>2]|0;v=c[t+4>>2]|0;if(!((o|0)<(p|0)|(o|0)==(p|0)&i>>>0<s>>>0)){t=wrc(u,v,s,p)|0;w=G;if((o|0)<(w|0)|(o|0)==(w|0)&i>>>0<t>>>0){break}}t=wrc(u,v,s,p)|0;v=b+1|0;if((v|0)<(q|0)){b=v;p=G;s=t}else{x=18;break a}}c[k+4364>>2]=(c[k+4344>>2]|0)+b;y=0}else{x=18}}while(0);do{if((x|0)==18){x=0;if((a|0)==0){y=0;break}c[l>>2]=0;c[l+4>>2]=-2147483648;y=a}}while(0);k=g+1|0;if((k|0)<(c[n>>2]|0)){g=k;a=y}else{h=y;break}}return h|0}function mI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a+8|0;d=a+12|0;if((c[b>>2]|0)>0){e=0}else{f=d;mJb(f);g=a+60|0;h=g;mJb(h);i=a+56|0;j=i;mJb(j);c[b>>2]=0;return}do{k=c[(c[d>>2]|0)+(e<<2)>>2]|0;l=k+4348|0;m=k+4352|0;if((c[l>>2]|0)>0){n=0;do{kJb(c[(c[m>>2]|0)+(n<<2)>>2]|0);n=n+1|0;}while((n|0)<(c[l>>2]|0))}mJb(m);c[l>>2]=0;P1(k+4248|0);kJb(c[k+4100>>2]|0);n=c[k+4228>>2]|0;if((n|0)!=0){SC(n)|0}n=k+4240|0;o=c[n>>2]|0;if((o|0)!=0){c[o+16>>2]=0;YX(n)}kJb(k|0);e=e+1|0;}while((e|0)<(c[b>>2]|0));f=d;mJb(f);g=a+60|0;h=g;mJb(h);i=a+56|0;j=i;mJb(j);c[b>>2]=0;return}function nI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=c[a+12>>2]|0;f=e+8|0;g=c[f>>2]|0;if((g|0)>0){h=c[e+12>>2]|0;j=0;while(1){c[(c[h+(j<<2)>>2]|0)+4360>>2]=0;k=j+1|0;l=c[f>>2]|0;if((k|0)<(l|0)){j=k}else{m=l;break}}}else{m=g}g=a+24|0;j=c[g>>2]|0;if((j|0)==0){n=m}else{m=c[a+28>>2]|0;h=e+12|0;l=0;k=j;while(1){j=c[m+(l<<2)>>2]|0;if((c[j+76>>2]|0)<48){c[(c[(c[h>>2]|0)+(c[j+4>>2]<<2)>>2]|0)+4360>>2]=1;o=c[g>>2]|0}else{o=k}j=l+1|0;if(j>>>0<o>>>0){l=j;k=o}else{break}}n=c[f>>2]|0}if((n|0)<=0){p=0;i=d;return p|0}o=e+12|0;k=a;a=e+16|0;if((b|0)==0){b=0;e=0;l=n;while(1){n=c[(c[o>>2]|0)+(e<<2)>>2]|0;do{if((c[n+4360>>2]|0)==0){q=b;r=l}else{g=n+4356|0;if((c[g>>2]|0)!=0){q=b;r=l;break}c[g>>2]=1;c[n+4364>>2]=c[a>>2];c[n+4148>>2]=0;KIb(k,32,2398264,(s=i,i=i+8|0,c[s>>2]=e,s)|0);i=s;q=1;r=c[f>>2]|0}}while(0);n=e+1|0;if((n|0)<(r|0)){b=q;e=n;l=r}else{p=q;break}}i=d;return p|0}else{t=0;u=0}while(1){q=c[(c[o>>2]|0)+(u<<2)>>2]|0;r=q+4356|0;l=(c[r>>2]|0)==0;do{if((c[q+4360>>2]|0)==0){if(l){v=t;break}e=q+4228|0;b=c[e>>2]|0;if((b|0)!=0){SC(b)|0}c[e>>2]=0;c[r>>2]=0;KIb(k,32,2324264,(s=i,i=i+8|0,c[s>>2]=u,s)|0);i=s;v=1}else{if(!l){v=t;break}c[r>>2]=1;c[q+4364>>2]=c[a>>2];c[q+4148>>2]=0;KIb(k,32,2398264,(s=i,i=i+8|0,c[s>>2]=u,s)|0);i=s;v=1}}while(0);q=u+1|0;if((q|0)<(c[f>>2]|0)){t=v;u=q}else{p=v;break}}i=d;return p|0}function oI(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0.0,ga=0,ia=0,ja=0,ka=0,la=0;g=i;i=i+12408|0;h=g|0;j=g+4120|0;k=g+8216|0;l=g+8224|0;m=g+8232|0;n=g+8240|0;o=g+8264|0;c[h>>2]=f;p=g+8|0;mrc(p|0,0,16)|0;q=g+24|0;mrc(q|0,0,4096)|0;c[l>>2]=0;do{if((f|0)==0){c[m>>2]=0;MGb(m,2575712,2556816,0)|0;MGb(m,2269064,c[b+56>>2]|0,0)|0;MGb(m,2220800,c[b+60>>2]|0,0)|0;MGb(m,2186088,c[b+64>>2]|0,0)|0;r=VD(h,d,1,c[b+52>>2]|0,m)|0;OGb(m);if((r|0)<0){s=r;i=g;return s|0}else{t=r;u=1;v=c[h>>2]|0;break}}else{t=0;u=0;v=f}}while(0);f=(MJb(v,2449928,1,l)|0)>-1;v=f?c[l>>2]|0:d;d=j|0;f=KD(c[h>>2]|0,d,4096)|0;a:do{if((f|0)>0){m=f;do{m=m-1|0;r=j+m|0;if((OFb(a[r]|0)|0)==0){break a}a[r]=0;}while((m|0)>0)}}while(0);b:do{if((irc(d,2433960)|0)==0){if((e|0)==0){w=0}else{f=e+4348|0;m=e+4352|0;if((c[f>>2]|0)>0){r=0;do{kJb(c[(c[m>>2]|0)+(r<<2)>>2]|0);r=r+1|0;}while((r|0)<(c[f>>2]|0))}mJb(m);c[f>>2]=0;c[e+4332>>2]=0;w=e}if((jD(c[h>>2]|0)|0)==0){r=b+8|0;x=b+12|0;z=o|0;A=o+4096|0;B=o+4106|0;C=o+4108|0;D=n|0;E=0;H=0;I=0;J=0;K=0;L=0;M=0;N=w;while(1){O=KD(c[h>>2]|0,d,4096)|0;c:do{if((O|0)>0){P=O;do{P=P-1|0;S=j+P|0;if((OFb(a[S]|0)|0)==0){break c}a[S]=0;}while((P|0)>0)}}while(0);do{if((AFb(d,2425080,k)|0)==0){if((AFb(d,2414144,k)|0)!=0){mrc(z|0,0,4141)|0;nY(c[k>>2]|0,130,z);O=(irc(A,2406504)|0)==0|0;if((krc(B,2398896,2)|0)==0){T=22}else{if((krc(B,2391896,2)|0)==0){T=22}else{U=0}}if((T|0)==22){T=0;mY(p,C)|0;U=1}CFb(q,z,4096)|0;V=N;W=U;X=O;Y=J;Z=K;_=I;$=H;aa=E;break}if((AFb(d,2385320,k)|0)!=0){if((N|0)==0){if((sI(b,0,v,0)|0)==0){ca=-12;break b}da=c[(c[x>>2]|0)+((c[r>>2]|0)-1<<2)>>2]|0}else{da=N}O=(kd(c[k>>2]|0)|0)*1e6|0;P=da+4336|0;c[P>>2]=O;c[P+4>>2]=(O|0)<0|0?-1:0;V=da;W=M;X=L;Y=J;Z=K;_=I;$=H;aa=E;break}if((AFb(d,2378248,k)|0)!=0){if((N|0)==0){if((sI(b,0,v,0)|0)==0){ca=-12;break b}ea=c[(c[x>>2]|0)+((c[r>>2]|0)-1<<2)>>2]|0}else{ea=N}c[ea+4344>>2]=kd(c[k>>2]|0)|0;V=ea;W=M;X=L;Y=J;Z=K;_=I;$=H;aa=E;break}if((AFb(d,2372488,k)|0)!=0){if((N|0)==0){V=0;W=M;X=L;Y=J;Z=K;_=I;$=H;aa=E;break}c[N+4332>>2]=1;V=N;W=M;X=L;Y=J;Z=K;_=I;$=H;aa=E;break}if((AFb(d,2360656,k)|0)!=0){fa=+erc(c[k>>2]|0)*1.0e6;V=N;W=M;X=L;Y=(F=+fa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Z=~~+fa>>>0;_=I;$=H;aa=1;break}O=(AFb(d,2348456,0)|0)!=0;if(O|(a[d]|0)==0){V=N;W=M;X=L;Y=J;Z=K;_=I;$=H;aa=E;break}if((H|0)==0){ga=I}else{if((sI(b,I,d,v)|0)==0){ca=-12;break b}else{ga=0}}if((E|0)==0){V=N;W=M;X=L;Y=J;Z=K;_=ga;$=0;aa=0;break}if((N|0)==0){if((sI(b,0,v,0)|0)==0){ca=-12;break b}ia=c[(c[x>>2]|0)+((c[r>>2]|0)-1<<2)>>2]|0}else{ia=N}O=hJb(8224)|0;if((O|0)==0){ca=-12;break b}P=O;c[P>>2]=K;c[P+4>>2]=J;c[O+8200>>2]=L;if((M|0)==0){P=ia+4348|0;S=(c[P>>2]|0)+(c[ia+4344>>2]|0)|0;mrc(O+8204|0,0,12)|0;ja=O+8216|0;y=je(S|0)|0;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;ka=P}else{nrc(O+8204|0,p|0,16)|0;ka=ia+4348|0}_W(O+4104|0,4096,v,q);_W(O+8|0,4096,v,d);tJb(ia+4352|0,ka,O);V=ia;W=M;X=L;Y=J;Z=K;_=ga;$=0;aa=0}else{mrc(D|0,0,20)|0;nY(c[k>>2]|0,402,D);V=N;W=M;X=L;Y=J;Z=K;_=kd(D|0)|0;$=1;aa=E}}while(0);if((jD(c[h>>2]|0)|0)==0){E=aa;H=$;I=_;J=Y;K=Z;L=X;M=W;N=V}else{la=V;break}}}else{la=w}if((la|0)==0){ca=t;break}N=jLb()|0;M=la+4368|0;c[M>>2]=N;c[M+4>>2]=G;ca=t}else{ca=-1094995529}}while(0);kJb(c[l>>2]|0);if((u|0)==0){s=ca;i=g;return s|0}WD(c[h>>2]|0)|0;s=ca;i=g;return s|0}function pI(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;f=i;i=i+4200|0;g=f|0;h=f+8|0;j=f+16|0;k=f+56|0;l=f+4192|0;m=b;n=b+4232|0;o=c[(c[n>>2]|0)+12>>2]|0;p=o;q=b+4228|0;r=b+4348|0;s=b+4352|0;t=b+4332|0;u=b+4368|0;v=b+4336|0;w=b+4364|0;x=b+4344|0;y=o+52|0;z=j|0;A=k|0;B=f+96|0;C=o+56|0;D=o+60|0;E=o+64|0;F=b+4376|0;H=b+8472|0;I=k+32|0;k=j+32|0;j=o+20|0;J=o+16|0;o=b+4240|0;K=b+4356|0;L=b+4328|0;M=c[q>>2]|0;a:while(1){if((M|0)==0){N=c[r>>2]|0;if((N|0)>0){O=c[(c[s>>2]|0)+(N-1<<2)>>2]|0}else{O=v}N=c[O+4>>2]|0;P=c[O>>2]|0;b:while(1){do{if((c[t>>2]|0)==0){Q=jLb()|0;R=xrc(Q,G,c[u>>2]|0,c[u+4>>2]|0)|0;Q=G;if((Q|0)<(N|0)|(Q|0)==(N|0)&R>>>0<P>>>0){S=N;T=P;break}R=oI(p,b,m,0)|0;if((R|0)<0){U=R;V=45;break a}R=Crc(c[v>>2]|0,c[v+4>>2]|0,2,0)|0;S=G;T=R}else{S=N;T=P}}while(0);R=c[w>>2]|0;Q=c[x>>2]|0;if((R|0)<(Q|0)){KIb(0,24,2600528,(W=i,i=i+8|0,c[W>>2]=Q-R,W)|0);i=W;X=c[x>>2]|0;c[w>>2]=X;Y=X;Z=X}else{Y=R;Z=Q}if((Y|0)<((c[r>>2]|0)+Z|0)){break}if((c[t>>2]|0)!=0){U=-541478725;V=45;break a}Q=jLb()|0;R=xrc(Q,G,c[u>>2]|0,c[u+4>>2]|0)|0;Q=G;if(!((Q|0)<(S|0)|(Q|0)==(S|0)&R>>>0<T>>>0)){N=S;P=T;continue}while(1){if((YC(c[y>>2]|0)|0)!=0){U=-1414092869;V=45;break a}kLb(1e5)|0;R=jLb()|0;Q=xrc(R,G,c[u>>2]|0,c[u+4>>2]|0)|0;R=G;if(!((R|0)<(S|0)|(R|0)==(S|0)&Q>>>0<T>>>0)){N=S;P=T;continue b}}}c[g>>2]=0;c[h>>2]=0;P=c[(c[s>>2]|0)+(Y-Z<<2)>>2]|0;MGb(g,2269064,c[C>>2]|0,0)|0;MGb(g,2220800,c[D>>2]|0,0)|0;MGb(g,2186088,c[E>>2]|0,0)|0;MGb(g,2575712,2556816,0)|0;PGb(h,c[g>>2]|0,0);N=c[P+8200>>2]|0;do{if((N|0)==1){Q=P+4104|0;if((irc(Q,F)|0)!=0){if((RC(l,Q,1,(c[n>>2]|0)+1160|0,h)|0)==0){if((UC(c[l>>2]|0,H,16)|0)!=16){KIb(0,16,2539400,(W=i,i=i+8|0,c[W>>2]=Q,W)|0);i=W}SC(c[l>>2]|0)|0}else{KIb(0,16,2522688,(W=i,i=i+8|0,c[W>>2]=Q,W)|0);i=W}CFb(F,Q,4096)|0}lY(z,P+8204|0,16,0)|0;lY(A,H,16,0)|0;a[I]=0;a[k]=0;Q=P+8|0;if((Db(Q|0,2507960)|0)==0){Rb(B|0,4096,2483496,(W=i,i=i+8|0,c[W>>2]=Q,W)|0)|0;i=W}else{Rb(B|0,4096,2493528,(W=i,i=i+8|0,c[W>>2]=Q,W)|0)|0;i=W}Q=PC(q,B,1,(c[n>>2]|0)+1160|0)|0;if((Q|0)<0){_=Q;break}EJb(c[(c[q>>2]|0)+8>>2]|0,2472336,A,0)|0;EJb(c[(c[q>>2]|0)+8>>2]|0,2464200,z,0)|0;Q=NC(c[q>>2]|0,g)|0;if((Q|0)>=0){_=0;break}SC(c[q>>2]|0)|0;c[q>>2]=0;_=Q}else if((N|0)==0){_=RC(q,P+8|0,1,(c[n>>2]|0)+1160|0,g)|0}else{_=-38}}while(0);OGb(g);OGb(h);if((_|0)<0){U=_;V=45;break}$=c[q>>2]|0}else{$=M}P=TC($,d,e)|0;if((P|0)>0){U=P;V=45;break}SC(c[q>>2]|0)|0;c[q>>2]=0;c[w>>2]=(c[w>>2]|0)+1;c[j>>2]=1;c[J>>2]=c[w>>2];P=c[o>>2]|0;do{if((P|0)!=0){N=P+24|0;Q=c[N>>2]|0;if((Q|0)==0){break}R=c[n>>2]|0;X=c[L>>2]|0;if((c[R+24>>2]|0)>>>0<(X+Q|0)>>>0){break}c[K>>2]=0;Q=c[N>>2]|0;if(!(X>>>0<(Q+X|0)>>>0)){V=44;break a}aa=c[R+28>>2]|0;R=X;ba=Q;while(1){if((c[(c[aa+(R<<2)>>2]|0)+76>>2]|0)<48){c[K>>2]=1;ca=c[N>>2]|0}else{ca=ba}Q=R+1|0;if(Q>>>0<(ca+X|0)>>>0){R=Q;ba=ca}else{break}}}}while(0);if((c[K>>2]|0)==0){V=44;break}else{M=0}}if((V|0)==44){KIb(c[n>>2]|0,32,2324264,(W=i,i=i+8|0,c[W>>2]=c[b+4236>>2],W)|0);i=W;U=-541478725;i=f;return U|0}else if((V|0)==45){i=f;return U|0}return 0}function qI(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;if((krc(b,2324888,d)|0)!=0){return}c[e>>2]=a;c[f>>2]=20;return}function rI(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;if((krc(b,2342072,d)|0)==0){c[e>>2]=a+4096;c[f>>2]=10;return}if((krc(b,2336200,d)|0)==0){c[e>>2]=a;c[f>>2]=4096;return}if((krc(b,2330984,d)|0)!=0){return}c[e>>2]=a+4106;c[f>>2]=35;return}function sI(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=pJb(8488)|0;if((f|0)==0){g=0;return g|0}J1(f+4248|0);c[f+4272>>2]=0;_W(f,4096,e,d);tJb(a+12|0,a+8|0,f);d=pJb(12)|0;if((d|0)==0){g=0;return g|0}c[d>>2]=b;tJb(a+4|0,a|0,d);tJb(d+8|0,d+4|0,f);g=d;return g|0}function tI(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=b+12|0;f=c[e>>2]|0;h=b+32|0;j=(lrc(h|0)|0)+6|0;c[f+4>>2]=0;k=+g[f+24>>2]*1.0e6;l=(F=+k,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);m=f+40|0;c[m>>2]=~~+k>>>0;c[m+4>>2]=l;l=f+56|0;c[l>>2]=0;c[l+4>>2]=-2147483648;l=b+24|0;if((c[l>>2]|0)==0){n=c[f+48>>2]|0}else{m=c[b+28>>2]|0;o=f+48|0;p=0;q=c[o>>2]|0;while(1){r=((c[(c[(c[m+(p<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==0)+q|0;c[o>>2]=r;s=p+1|0;if(s>>>0<(c[l>>2]|0)>>>0){p=s;q=r}else{n=r;break}}}if((n|0)>1){KIb(b,24,2539328,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}n=gH(2522680,0,0)|0;c[f+16>>2]=n;a:do{if((n|0)==0){t=-1481985528;u=f+92|0}else{q=hJb(j)|0;p=f+92|0;c[p>>2]=q;if((q|0)==0){t=-12;u=p;break}prc(q|0,h|0)|0;q=c[p>>2]|0;o=hc(q|0,46)|0;if((o|0)==0){v=q}else{a[o]=0;v=c[p>>2]|0}DFb(v,2556776,j)|0;o=c[e>>2]|0;q=HR()|0;c[o+20>>2]=q;if((q|0)==0){t=-12;u=p;break}c[q+8>>2]=c[o+16>>2];o=b+1160|0;m=q+1160|0;r=c[o+4>>2]|0;c[m>>2]=c[o>>2];c[m+4>>2]=r;PGb(q+1140|0,c[b+1140>>2]|0,0);if((c[l>>2]|0)!=0){r=b+28|0;m=0;do{o=ZX(q,0)|0;if((o|0)==0){t=-12;u=p;break a}nWa(c[o+8>>2]|0,c[(c[(c[r>>2]|0)+(m<<2)>>2]|0)+8>>2]|0)|0;s=(c[(c[r>>2]|0)+(m<<2)>>2]|0)+80|0;w=o+80|0;o=c[s+4>>2]|0;c[w>>2]=c[s>>2];c[w+4>>2]=o;m=m+1|0;}while(m>>>0<(c[l>>2]|0)>>>0)}m=yI(b)|0;if((m|0)<0){t=m;u=p;break}m=TO(c[f+20>>2]|0,0)|0;if((m|0)<0){x=m;i=d;return x|0}if((m|0)==0){x=0}else{t=m;u=p;break}i=d;return x|0}}while(0);kJb(c[u>>2]|0);u=c[f+20>>2]|0;if((u|0)==0){x=t;i=d;return x|0}pX(u);x=t;i=d;return x|0}function uI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=f;h=f+20|0;j=c[h>>2]|0;k=b+32|0;l=c[(c[a+28>>2]|0)+(c[k>>2]<<2)>>2]|0;m=f+40|0;n=Erc(c[f+4>>2]|0,0,c[m>>2]|0,c[m+4>>2]|0)|0;m=G;o=f+56|0;p=c[o>>2]|0;q=c[o+4>>2]|0;if((p|0)==0&(q|0)==(-2147483648|0)){r=b+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;c[o>>2]=s;c[o+4>>2]=t;o=c[r+4>>2]|0;u=f+64|0;c[u>>2]=c[r>>2];c[u+4>>2]=o;v=t;w=s}else{v=q;w=p}if((c[f+48>>2]|0)==0){x=1;y=0}else{p=c[(c[l+8>>2]|0)+8>>2]|0;if((p|0)==0){z=c[b+36>>2]&1}else{z=0}x=z;y=(p|0)!=0}p=b+8|0;z=c[p>>2]|0;q=c[p+4>>2]|0;s=(z|0)==0&(q|0)==(-2147483648|0);if(!(s|y)){y=f+64|0;t=xrc(z,q,c[y>>2]|0,c[y+4>>2]|0)|0;y=c[l+40>>2]|0;q=c[l+44>>2]|0;z=VIb(t,G,y,(y|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;q=f+72|0;c[q>>2]=z;c[q+4>>2]=G}do{if(s|(x|0)==0){A=j}else{q=xrc(c[p>>2]|0,c[p+4>>2]|0,w,v)|0;c[e>>2]=1;c[e+4>>2]=1e6;if(!((YIb(q,G,l+40|0,n,m,e)|0)>-1)){A=j;break}q=f+72|0;z=wI(g,c[q>>2]|0,c[q+4>>2]|0)|0;if((z|0)!=0){B=z;i=d;return B|0}z=c[p+4>>2]|0;y=f+64|0;c[y>>2]=c[p>>2];c[y+4>>2]=z;c[q>>2]=0;c[q+4>>2]=0;UO(j,0)|0;WD(c[j+16>>2]|0)|0;q=yI(a)|0;if((q|0)!=0){B=q;i=d;return B|0}q=c[h>>2]|0;z=xI(a,0)|0;if((z|0)<0){B=z}else{A=q;break}i=d;return B|0}}while(0);B=aP(A,c[k>>2]|0,b,a)|0;i=d;return B|0}function vI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=c[b+20>>2]|0;$O(d)|0;XD(d+16|0)|0;pX(d);kJb(c[b+92>>2]|0);d=b+72|0;wI(b,c[d>>2]|0,c[d+4>>2]|0)|0;xI(a,1)|0;a=c[b+84>>2]|0;if((a|0)==0){e=b+96|0;f=e;g=c[f>>2]|0;h=WD(g)|0;return 0}else{i=a}while(1){a=c[i+1028>>2]|0;kJb(i|0);if((a|0)==0){break}else{i=a}}e=b+96|0;f=e;g=c[f>>2]|0;h=WD(g)|0;return 0}function wI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=hJb(1032)|0;e=d;if((d|0)==0){f=-12;return f|0}CFb(d,KFb((c[a+20>>2]|0)+32|0)|0,1024)|0;c[d+1024>>2]=b;c[d+1028>>2]=0;d=a+84|0;if((c[d>>2]|0)==0){c[d>>2]=e;g=a+88|0}else{b=a+88|0;c[(c[b>>2]|0)+1028>>2]=e;g=b}c[g>>2]=e;e=a+80|0;g=c[e>>2]|0;if((g|0)<(c[a+28>>2]|0)){c[e>>2]=g+1}else{g=c[d>>2]|0;c[d>>2]=c[g+1028>>2];kJb(g|0)}g=a+8|0;a=wrc(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=a;c[g+4>>2]=G;f=0;return f|0}function xI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+12>>2]|0;f=e+96|0;g=VD(f,a+32|0,2,a+1160|0,0)|0;if((g|0)<0){h=XD(f)|0;i=d;return g|0}a=e+84|0;j=c[a>>2]|0;if((j|0)==0){k=0}else{l=0;m=j;while(1){j=c[m+1024>>2]|0;n=(l|0)<(j|0)?j:l;j=c[m+1028>>2]|0;if((j|0)==0){k=n;break}else{l=n;m=j}}}YD(c[f>>2]|0,2324152,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;YD(c[f>>2]|0,2269016,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;YD(c[f>>2]|0,2220688,(m=i,i=i+8|0,c[m>>2]=k,m)|0)|0;i=m;k=c[f>>2]|0;l=e+8|0;j=c[e+28>>2]|0;e=xrc(c[l>>2]|0,c[l+4>>2]|0,j,(j|0)<0|0?-1:0)|0;j=G;l=0;n=(j|0)<(l|0)|(j|0)==(l|0)&e>>>0<0>>>0;YD(k,2185984,(m=i,i=i+16|0,c[m>>2]=n?0:e,c[m+8>>2]=n?0:j,m)|0)|0;i=m;j=c[a>>2]|0;if((j|0)!=0){a=j;do{YD(c[f>>2]|0,2156720,(m=i,i=i+8|0,c[m>>2]=c[a+1024>>2],m)|0)|0;i=m;YD(c[f>>2]|0,2131440,(m=i,i=i+8|0,c[m>>2]=a,m)|0)|0;i=m;a=c[a+1028>>2]|0;}while((a|0)!=0)}if((b|0)==0){h=XD(f)|0;i=d;return g|0}YD(c[f>>2]|0,2108384,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0)|0;i=m;h=XD(f)|0;i=d;return g|0}function yI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=c[a+12>>2]|0;e=c[d+20>>2]|0;f=e+32|0;g=d+92|0;h=c[d+32>>2]|0;j=d+4|0;d=c[j>>2]|0;if((h|0)==0){k=d}else{k=(d>>>0)%(h>>>0)|0}if((jX(f,1024,c[g>>2]|0,k)|0)<0){KIb(e,16,2626456,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0);i=k;l=-22;i=b;return l|0}c[j>>2]=(c[j>>2]|0)+1;j=VD(e+16|0,f,2,a+1160|0,0)|0;if((j|0)<0){l=j;i=b;return l|0}if((c[(c[e+8>>2]|0)+36>>2]|0)==0){l=0;i=b;return l|0}j=c[e+12>>2]|0;if((j|0)==0){l=0;i=b;return l|0}EJb(j,2600496,2575696,0)|0;l=0;i=b;return l|0}function zI(a){a=a|0;var b=0,e=0;if((c[a+8>>2]|0)<4){b=0;return b|0}e=c[a+4>>2]|0;b=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==877481544?100:0;return b|0}function AI(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=c[d+12>>2]|0;h=c[d+16>>2]|0;j=g+32|0;c[j>>2]=0;c[j+4>>2]=0;J1(g+48|0);c[g+72>>2]=0;c[g+76>>2]=0;c[g+40>>2]=0;hD(h,8,0)|0;j=g+2|0;b[j>>1]=DD(h)|0;k=g+4|0;b[k>>1]=DD(h)|0;c[g+8>>2]=FD(h)|0;c[g+12>>2]=FD(h)|0;c[g+16>>2]=FD(h)|0;b[g+20>>1]=DD(h)|0;b[g+22>>1]=DD(h)|0;c[g+24>>2]=FD(h)|0;hD(h,32,0)|0;c[g+28>>2]=0;h=b[j>>1]|0;l=b[k>>1]|0;do{if(!((h-320&65535)>>>0>320>>>0)){if((l-150&65535)>>>0>330>>>0){break}a[g]=h<<16>>16==640?74:64;m=ZX(d,0)|0;if((m|0)==0){n=-12;i=f;return n|0}o=m+8|0;p=c[o>>2]|0;c[p+8>>2]=0;c[p+48>>2]=174;c[p+52>>2]=0;c[p+120>>2]=e[j>>1]|0;c[p+124>>2]=e[k>>1]|0;p=pJb(1)|0;c[(c[o>>2]|0)+96>>2]=p;p=c[o>>2]|0;c[p+100>>2]=1;a[c[p+96>>2]|0]=a[g]|0;p=m+48|0;c[p>>2]=0;c[p+4>>2]=0;_X(m,33,1,24);n=0;i=f;return n|0}}while(0);KIb(d,16,2268944,(d=i,i=i+16|0,c[d>>2]=h&65535,c[d+8>>2]=l&65535,d)|0);i=d;n=-1094995529;i=f;return n|0}function BI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=e+28|0;if((c[g>>2]|0)==(c[e+12>>2]|0)){h=-541478725;i=d;return h|0}if((c[f+52>>2]|0)!=0){h=-541478725;i=d;return h|0}j=e+40|0;if((c[j>>2]|0)==0){e=ED(f)|0;hD(f,1,0)|0;c[j>>2]=e-4}e=ED(f)|0;hD(f,1,0)|0;k=DD(f)|0;hD(f,2,0)|0;if(!(e>>>0<=(c[j>>2]|0)>>>0&(e|0)!=0)){l=fD(f,0,0,1)|0;KIb(a,16,2397984,(m=i,i=i+16|0,c[m>>2]=e,c[m+8>>2]=l,m)|0);i=m;hD(f,(c[j>>2]|0)-8|0,0)|0;c[j>>2]=0}l=k&65535;if((l|0)==17491){hD(f,e-8|0,0)|0;c[j>>2]=(c[j>>2]|0)-e;h=0;i=d;return h|0}else if((l|0)==19536|(l|0)==23113|(l|0)==21833){fD(f,-8,-1,1)|0;k=fX(f,b,e)|0;c[j>>2]=(c[j>>2]|0)-e;if(!((l|0)==23113|(l|0)==21833)){h=k;i=d;return h|0}c[g>>2]=(c[g>>2]|0)+1;h=k;i=d;return h|0}else{k=fD(f,0,0,1)|0;KIb(a,24,2324048,(m=i,i=i+16|0,c[m>>2]=l,c[m+8>>2]=k,m)|0);i=m;hD(f,e-8|0,0)|0;c[j>>2]=(c[j>>2]|0)-e;h=0;i=d;return h|0}return 0}function CI(a){a=a|0;var b=0;b=c[a+12>>2]|0;if((c[b+76>>2]|0)<=0){return 0}P1(b+48|0);return 0}function DI(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0){e=b+2|0;if(!((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==1)){break}e=b+4|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0){break}else{f=25}return f|0}}while(0);f=0;return f|0}function EI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;hD(e,4,0)|0;f=DD(e)|0;g=d+4|0;c[g>>2]=f;h=hJb(f*12|0)|0;f=d+8|0;c[f>>2]=h;if((h|0)==0){j=-12;i=b;return j|0}if((c[g>>2]|0)>0){k=0}else{j=0;i=b;return j|0}a:while(1){h=k<<4|6;d=fD(e,h,(h|0)<0|0?-1:0,0)|0;h=G;l=0;if((h|0)<(l|0)|(h|0)==(l|0)&d>>>0<0>>>0){j=0;m=15;break}d=ZX(a,0)|0;if((d|0)==0){j=-12;m=15;break}l=d+8|0;c[(c[l>>2]|0)+8>>2]=0;d=zD(e)|0;c[(c[l>>2]|0)+120>>2]=d;d=zD(e)|0;c[(c[l>>2]|0)+124>>2]=d;d=zD(e)|0;c[(c[f>>2]|0)+(k*12|0)+8>>2]=(d|0)==255?0:d;hD(e,5,0)|0;d=FD(e)|0;c[(c[f>>2]|0)+(k*12|0)+4>>2]=d;d=FD(e)|0;c[(c[f>>2]|0)+(k*12|0)>>2]=d;h=fD(e,d,(d|0)<0|0?-1:0,0)|0;d=G;n=0;if((d|0)<(n|0)|(d|0)==(n|0)&h>>>0<0>>>0){j=0;m=15;break}o=FD(e)|0;do{if((o|0)==1196314761){h=c[l>>2]|0;c[h+48>>2]=62;c[h+120>>2]=0;c[h+124>>2]=0}else if((o|0)==40){if((c[(c[f>>2]|0)+(k*12|0)+4>>2]|0)<40){j=-1094995529;m=15;break a}c[(c[l>>2]|0)+48>>2]=79;h=FD(e)|0;if((h|0)!=0){c[(c[l>>2]|0)+120>>2]=h}h=FD(e)|0;if((h|0)==0){break}c[(c[l>>2]|0)+124>>2]=(h|0)/2|0}else{m=13;break a}}while(0);l=k+1|0;if((l|0)<(c[g>>2]|0)){k=l}else{j=0;m=15;break}}if((m|0)==13){QIb(a,2397960,(a=i,i=i+8|0,c[a>>2]=o,a)|0);i=a;j=-1094995529;i=b;return j|0}else if((m|0)==15){i=b;return j|0}return 0}function FI(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=c[b+12>>2]|0;g=c[b+16>>2]|0;h=b+28|0;b=c[c[h>>2]>>2]|0;i=f;j=c[i>>2]|0;if((j|0)>=(c[f+4>>2]|0)){k=-5;return k|0}l=c[f+8>>2]|0;f=c[l+(j*12|0)>>2]|0;m=fD(g,f,(f|0)<0|0?-1:0,0)|0;f=m;if((f|0)<0){k=f;return k|0}f=l+(j*12|0)+4|0;m=c[f>>2]|0;do{if((c[(c[(c[(c[h>>2]|0)+(c[i>>2]<<2)>>2]|0)+8>>2]|0)+48>>2]|0)==62){n=fX(g,e,m)|0;if((n|0)<0){k=n}else{break}return k|0}else{n=K1(e,m+14|0)|0;if((n|0)<0){k=n;return k|0}n=c[e+24>>2]|0;a[n]=66;a[n+1|0]=77;o=n+2|0;y=c[e+28>>2]|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=n+10|0;p=n+6|0;q=p|0;y=0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=AD(g,n+14|0,c[f>>2]|0)|0;if((q|0)<0){k=q;return k|0}q=n+28|0;p=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(c[b+8>>2]|0)+792|0;c[q>>2]=p;r=n+46|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;if((s|0)==0){t=p}else{c[l+(j*12|0)+8>>2]=s;t=c[q>>2]|0}q=l+(j*12|0)+8|0;do{if((t|0)<9){if((c[q>>2]|0)!=0){break}s=1<<t;c[q>>2]=s;y=s;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y}}while(0);y=(c[q>>2]<<2)+54|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;r=n+22|0;y=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>1;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y}}while(0);t=c[i>>2]|0;c[i>>2]=t+1;c[e+32>>2]=t;t=e+36|0;c[t>>2]=c[t>>2]|1;k=0;return k|0}function GI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((c[e+88>>2]|0)==0){KIb(a,16,2220560,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}c[d>>2]=0;h=a+24|0;j=d+4|0;c[j>>2]=c[h>>2];oD(e,0);oD(e,1);hD(e,2,0)|0;a:do{if((c[h>>2]|0)!=0){k=a+28|0;l=0;while(1){m=c[(c[(c[k>>2]|0)+(l<<2)>>2]|0)+8>>2]|0;n=c[m+48>>2]|0;if((n|0)==62){if((c[m+140>>2]|0)!=28){o=9;break}}else if((n|0)==79){n=c[m+140>>2]|0;if(!((n|0)==11|(n|0)==46|(n|0)==3|(n|0)==30)){o=7;break}}else{o=10;break}p=c[m+120>>2]|0;q=c[m+124>>2]|0;if((p|0)>256|(q|0)>256){o=12;break}hD(e,16,0)|0;l=l+1|0;if(!(l>>>0<(c[h>>2]|0)>>>0)){break a}}if((o|0)==7){KIb(a,16,2156632,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else if((o|0)==9){KIb(a,16,2131328,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}else if((o|0)==10){KIb(a,16,2108328,(f=i,i=i+8|0,c[f>>2]=m+16,f)|0);i=f;g=-22;i=b;return g|0}else if((o|0)==12){KIb(a,16,2626352,(f=i,i=i+16|0,c[f>>2]=p,c[f+8>>2]=q,f)|0);i=f;g=-22;i=b;return g|0}}}while(0);f=pJb((c[j>>2]|0)*12|0)|0;c[d+8>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}eD(e);g=0;i=b;return g|0}function HI(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=c[e+12>>2]|0;j=c[e+16>>2]|0;k=c[(c[(c[e+28>>2]|0)+(c[f+32>>2]<<2)>>2]|0)+8>>2]|0;l=h;m=c[l>>2]|0;if((m|0)>=(c[h+4>>2]|0)){KIb(e,16,2323888,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-5;i=g;return o|0}c[l>>2]=m+1;l=c[h+8>>2]|0;h=fD(j,0,0,1)|0;c[l+(m*12|0)>>2]=h;h=k+120|0;a[l+(m*12|0)+8|0]=c[h>>2];p=k+124|0;a[l+(m*12|0)+9|0]=c[p>>2];if((c[k+48>>2]|0)==62){b[l+(m*12|0)+10>>1]=c[k+792>>2];k=f+28|0;c[l+(m*12|0)+4>>2]=c[k>>2];dD(j,c[f+24>>2]|0,c[k>>2]|0);o=0;i=g;return o|0}k=f+24|0;q=c[k>>2]|0;r=q+14|0;s=r;if((d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)!=40){KIb(e,16,2268856,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}n=q+28|0;b[l+(m*12|0)+10>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=f+28|0;c[l+(m*12|0)+4>>2]=(c[n>>2]|0)-14+((ca((c[h>>2]|0)+7|0,c[p>>2]|0)|0)/8|0);dD(j,r,8);r=(c[k>>2]|0)+22|0;kD(j,(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24)<<1);dD(j,(c[k>>2]|0)+26|0,(c[n>>2]|0)-26|0);if((ca((c[h>>2]|0)+7|0,c[p>>2]|0)|0)>7){t=0}else{o=0;i=g;return o|0}while(1){bD(j,0);n=t+1|0;if((n|0)<((ca((c[h>>2]|0)+7|0,c[p>>2]|0)|0)/8|0|0)){t=n}else{o=0;break}}i=g;return o|0}function II(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[a+12>>2]|0;f=c[a+16>>2]|0;fD(f,4,0,0)|0;oD(f,c[e>>2]|0);g=e+4|0;h=e+8|0;if((c[g>>2]|0)<=0){mJb(h);return 0}e=h;i=a+28|0;a=0;do{bD(f,d[(c[e>>2]|0)+(a*12|0)+8|0]|0);bD(f,d[(c[e>>2]|0)+(a*12|0)+9|0]|0);j=c[(c[(c[i>>2]|0)+(a<<2)>>2]|0)+8>>2]|0;do{if((c[j+48>>2]|0)==79){if((c[j+140>>2]|0)!=11){k=8;break}l=b[(c[e>>2]|0)+(a*12|0)+10>>1]|0;if(l<<16>>16>7){m=0}else{m=1<<(l<<16>>16)}bD(f,m)}else{k=8}}while(0);if((k|0)==8){k=0;bD(f,0)}bD(f,0);oD(f,1);oD(f,b[(c[e>>2]|0)+(a*12|0)+10>>1]|0);kD(f,c[(c[e>>2]|0)+(a*12|0)+4>>2]|0);kD(f,c[(c[e>>2]|0)+(a*12|0)>>2]|0);a=a+1|0;}while((a|0)<(c[g>>2]|0));mJb(h);return 0}function JI(b,c){b=b|0;c=c|0;var e=0;if((d[b]|0)!=(a[c]|0)){e=0;return e|0}if((d[b+1|0]|0)!=(a[c+1|0]|0)){e=0;return e|0}if((d[b+2|0]|0)!=(a[c+2|0]|0)){e=0;return e|0}if((a[b+3|0]|0)==-1){e=0;return e|0}if((a[b+4|0]|0)==-1){e=0;return e|0}if(!((a[b+6|0]|0)>-1)){e=0;return e|0}if(!((a[b+7|0]|0)>-1)){e=0;return e|0}if(!((a[b+8|0]|0)>-1)){e=0;return e|0}e=(d[b+9|0]|0)>>>7^1;return e|0}function KI(b){b=b|0;return((d[b+7|0]|0)<<14&2080768|(d[b+6|0]|0)<<21&266338304|(d[b+8|0]|0)<<7&16256|a[b+9|0]&127)+((a[b+5|0]&16)==0?10:20)|0}function LI(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;j=i;i=i+216|0;k=j|0;l=j+8|0;m=j+136|0;n=j+144|0;o=j+152|0;p=j+160|0;q=j+168|0;r=j+176|0;s=j+200|0;t=s|0;u=s+1|0;v=g+1|0;w=s+2|0;x=g+2|0;y=s+3|0;z=s+4|0;A=s+6|0;B=s+7|0;C=s+8|0;D=s+9|0;E=s+5|0;s=k|0;F=m;H=o;I=f;J=k+4|0;K=k+3|0;L=b+52|0;M=(h|0)==0;N=k+1|0;while(1){O=fD(b,0,0,1)|0;P=G;if((AD(b,t,10)|0)!=10){Q=3;break}if((d[t]|0)!=(a[g]|0)){Q=83;break}if((d[u]|0)!=(a[v]|0)){Q=83;break}if((d[w]|0)!=(a[x]|0)){Q=83;break}k=a[y]|0;if(k<<24>>24==-1){Q=83;break}if((a[z]|0)==-1){Q=83;break}R=a[A]|0;if(!(R<<24>>24>-1)){Q=83;break}S=a[B]|0;if(!(S<<24>>24>-1)){Q=83;break}T=a[C]|0;if(!(T<<24>>24>-1)){Q=83;break}U=a[D]|0;if(!(U<<24>>24>-1)){Q=83;break}V=(S&255)<<14&2080768|(R&255)<<21&266338304|(T&255)<<7&16256|U&127;U=a[E]|0;T=fD(b,0,0,1)|0;R=wrc(T,G,V,0)|0;T=G;c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;c[p>>2]=0;S=k&255;W=U&255;KIb(I,48,2104264,(X=i,i=i+24|0,c[X>>2]=S,c[X+8>>2]=W,c[X+16>>2]=V,X)|0);i=X;do{if((S|0)==3|(S|0)==4){U=W&128;if((W&64|0)==0){Y=V;Z=10;_=1;$=U;aa=1;Q=19;break}ba=(zD(b)|0)<<7&16256;ca=((zD(b)|0)&127|ba)<<7;ba=(ca|(zD(b)|0)&127)<<7;ca=ba|(zD(b)|0)&127;ba=k<<24>>24==4?ca-4|0:ca;if((ba|0)<0){da=2633648;Q=82;break}hD(b,ba,(ba|0)<0|0?-1:0)|0;ca=V-4-ba|0;if((ca|0)<0){da=2631960;Q=82}else{Y=ca;Z=10;_=1;$=U;aa=1;Q=19}}else if((S|0)==2){if((W&64|0)!=0){da=2643832;Q=82;break}Y=V;Z=6;_=0;$=W&128;aa=0;Q=19}else{da=2638432;Q=82}}while(0);do{if((Q|0)==19){Q=0;a:do{if((Y|0)>=(Z|0)){V=k<<24>>24==3;U=0;ca=Y;b:while(1){ba=ca;while(1){if(aa){if((AD(b,s,4)|0)<4){break a}a[J]=0;if(V){ea=JD(b)|0}else{fa=(zD(b)|0)<<7&16256;ga=((zD(b)|0)&127|fa)<<7;fa=(ga|(zD(b)|0)&127)<<7;ea=fa|(zD(b)|0)&127}fa=HD(b)|0;ha=fa&2;ia=fa;ja=ea}else{if((AD(b,s,3)|0)<3){break a}a[K]=0;ha=0;ia=0;ja=ID(b)|0}if(ja>>>0>268435456>>>0){break a}ba=ba-Z-ja|0;if((ba|0)<0){break a}fa=fD(b,0,0,1)|0;ka=wrc(fa,G,ja,0)|0;la=G;if((ja|0)!=0){break}if((a[s]|0)!=0){KIb(I,48,2629808,(X=i,i=i+8|0,c[X>>2]=s,X)|0);i=X}if((ba|0)<(Z|0)){break a}}if((ia&1|0)==0){c[q>>2]=ja;ma=ja}else{if(ja>>>0<4>>>0){break a}c[q>>2]=JD(b)|0;ma=ja-4|0}fa=ia&8;c:do{if((ia&4|0)==0){ga=a[s]|0;do{if(ga<<24>>24==84){na=U}else{if(M){oa=U}else{pa=OI(s,_)|0;if((pa|0)==0){oa=0}else{na=pa;break}}if(ga<<24>>24==0){break b}else{qa=oa;break c}}}while(0);ga=ha|$;pa=(ga|0)==0;ra=(fa|0)==0;do{if((ga|fa|0)!=0){xJb(F,n,ma);if((c[m>>2]|0)!=0){break}KIb(I,16,2139152,(X=i,i=i+8|0,c[X>>2]=ma,X)|0);i=X;qa=na;break c}}while(0);if(pa){sa=b;ta=ma}else{ga=fD(b,0,0,1)|0;ua=wrc(ga,G,ma,0)|0;ga=G;va=c[m>>2]|0;wa=fD(b,0,0,1)|0;xa=G;d:do{if((xa|0)<(ga|0)|(xa|0)==(ga|0)&wa>>>0<ua>>>0){ya=wrc(ua,ga,-1,-1)|0;za=G;Aa=va;while(1){if(!((Aa-(c[m>>2]|0)|0)>>>0<ma>>>0)){Ba=Aa;break d}if((c[L>>2]|0)!=0){Ba=Aa;break d}Ca=zD(b)|0;Da=Aa+1|0;a[Aa]=Ca;do{if((Ca&255|0)==255){Ea=fD(b,0,0,1)|0;Fa=G;if(!((Fa|0)<(za|0)|(Fa|0)==(za|0)&Ea>>>0<ya>>>0)){Ga=Da;break}if(!((Da-(c[m>>2]|0)|0)>>>0<ma>>>0)){Ga=Da;break}if((c[L>>2]|0)!=0){Ga=Da;break}Ea=zD(b)|0;if((Ea&255|0)==0){Ha=(zD(b)|0)&255}else{Ha=Ea&255}a[Da]=Ha;Ga=Aa+2|0}else{Ga=Da}}while(0);Da=fD(b,0,0,1)|0;Ca=G;if((Ca|0)<(ga|0)|(Ca|0)==(ga|0)&Da>>>0<ua>>>0){Aa=Ga}else{Ba=Ga;break}}}else{Ba=va}}while(0);va=c[m>>2]|0;ua=Ba;$C(l,va,ua-va|0,0,0,0,0,0)|0;sa=l;ta=ua-(c[m>>2]|0)|0}do{if(ra){Ia=sa;Ja=ta}else{ua=c[q>>2]|0;KIb(I,48,2622472,(X=i,i=i+24|0,c[X>>2]=s,c[X+8>>2]=ta,c[X+16>>2]=ua,X)|0);i=X;xJb(H,p,ua);va=c[o>>2]|0;if((va|0)==0){KIb(I,16,2620848,(X=i,i=i+8|0,c[X>>2]=ua,X)|0);i=X;qa=na;break c}do{if(pa){ua=AD(b,c[m>>2]|0,ta)|0;if((ua|0)<0){KIb(I,16,2615792,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;qa=na;break c}else{Ka=ua;La=c[o>>2]|0;break}}else{Ka=ta;La=va}}while(0);va=Aqc(La,q,c[m>>2]|0,Ka)|0;if((va|0)==0){$C(l,c[o>>2]|0,c[q>>2]|0,0,0,0,0,0)|0;Ia=l;Ja=c[q>>2]|0;break}else{KIb(I,16,2609936,(X=i,i=i+8|0,c[X>>2]=va,X)|0);i=X;qa=na;break c}}}while(0);if((a[s]|0)==84){YI(f,Ia,Ja,e,s);qa=na;break}else{_e[c[na+8>>2]&511](f,Ia,Ja,s,h,_);qa=na;break}}else{KIb(I,24,2623904,(X=i,i=i+16|0,c[X>>2]=(fa|0)==0?2628016:2625136,c[X+8>>2]=s,X)|0);i=X;hD(b,ma,0)|0;qa=U}}while(0);fD(b,ka,la,0)|0;if((ba|0)<(Z|0)){break a}else{U=qa;ca=ba}}if((a[N]|0)!=0){KIb(I,24,2607336,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X}hD(b,ma,0)|0;}}while(0);if(!(k<<24>>24==4)){Ma=T;Na=R;break}ca=(W&16|0)==0;U=wrc(R,T,10,0)|0;Ma=ca?T:G;Na=ca?R:U}else if((Q|0)==82){Q=0;KIb(I,32,2604920,(X=i,i=i+16|0,c[X>>2]=S,c[X+8>>2]=da,X)|0);i=X;Ma=T;Na=R}}while(0);fD(b,Na,Ma,0)|0;kJb(c[m>>2]|0);kJb(c[o>>2]|0)}if((Q|0)==3){fD(b,O,P,0)|0;}else if((Q|0)==83){fD(b,O,P,0)|0;}cL(e,0,1373368);cL(e,0,1077096);cL(e,0,1373280);P=r|0;mrc(P|0,0,17)|0;O=LGb(c[e>>2]|0,2135384,0,1)|0;do{if((O|0)==0){Q=89}else{b=c[O+4>>2]|0;if((lrc(b|0)|0)==4){Oa=b}else{Q=89;break}while(1){Pa=a[Oa]|0;if((Pa-48&255)>>>0<10>>>0){Oa=Oa+1|0}else{break}}if(Pa<<24>>24==0){Qa=b}else{Q=89}}}while(0);do{if((Q|0)==89){Pa=LGb(c[e>>2]|0,2133776,0,1)|0;if((Pa|0)==0){i=j;return}Oa=c[Pa+4>>2]|0;if((lrc(Oa|0)|0)==4){Ra=Oa}else{i=j;return}while(1){Sa=a[Ra]|0;if((Sa-48&255)>>>0<10>>>0){Ra=Ra+1|0}else{break}}if(Sa<<24>>24==0){Qa=Oa;break}i=j;return}}while(0);CFb(P,Qa,5)|0;MGb(e,2135384,0,0)|0;MGb(e,2133776,0,0)|0;Qa=LGb(c[e>>2]|0,2131744,0,1)|0;do{if((Qa|0)==0){Q=97}else{Sa=c[Qa+4>>2]|0;if((lrc(Sa|0)|0)==4){Ta=Sa}else{Q=97;break}while(1){Ua=a[Ta]|0;if((Ua-48&255)>>>0<10>>>0){Ta=Ta+1|0}else{break}}if(Ua<<24>>24==0){Va=Sa;Q=101}else{Q=97}}}while(0);do{if((Q|0)==97){Ua=LGb(c[e>>2]|0,2130208,0,1)|0;if((Ua|0)==0){break}Ta=c[Ua+4>>2]|0;if((lrc(Ta|0)|0)==4){Wa=Ta}else{break}while(1){Xa=a[Wa]|0;if((Xa-48&255)>>>0<10>>>0){Wa=Wa+1|0}else{break}}if(Xa<<24>>24==0){Va=Ta;Q=101}}}while(0);do{if((Q|0)==101){Rb(r+4|0,13,2128880,(X=i,i=i+16|0,c[X>>2]=Va+2,c[X+8>>2]=Va,X)|0)|0;i=X;MGb(e,2131744,0,0)|0;MGb(e,2130208,0,0)|0;Xa=LGb(c[e>>2]|0,2127376,0,1)|0;do{if((Xa|0)==0){Q=105}else{Wa=c[Xa+4>>2]|0;if((lrc(Wa|0)|0)==4){Ya=Wa}else{Q=105;break}while(1){Za=a[Ya]|0;if((Za-48&255)>>>0<10>>>0){Ya=Ya+1|0}else{break}}if(Za<<24>>24==0){_a=Wa}else{Q=105}}}while(0);if((Q|0)==105){Xa=LGb(c[e>>2]|0,2125744,0,1)|0;if((Xa|0)==0){break}Ta=c[Xa+4>>2]|0;if((lrc(Ta|0)|0)==4){$a=Ta}else{break}while(1){ab=a[$a]|0;if((ab-48&255)>>>0<10>>>0){$a=$a+1|0}else{break}}if(ab<<24>>24==0){_a=Ta}else{break}}Rb(r+10|0,7,2120760,(X=i,i=i+16|0,c[X>>2]=_a,c[X+8>>2]=_a+2,X)|0)|0;i=X;MGb(e,2127376,0,0)|0;MGb(e,2125744,0,0)|0}}while(0);if((a[P]|0)==0){i=j;return}MGb(e,2378240,P,0)|0;i=j;return}function MI(a,b,d){a=a|0;b=b|0;d=d|0;LI(c[a+16>>2]|0,a+1140|0,a,b,d);return}function NI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;c[d>>2]=e;if((e|0)==0){i=b;return}a=d;f=e;do{e=c[f>>2]|0;a:do{if((e|0)==0){g=f}else{do{if((grc(e,2194088,4)|0)==0){h=1077016}else{if((grc(e,2210656,4)|0)==0){h=1077032;break}if((grc(e,2189240,4)|0)==0){h=1077048;break}j=(grc(e,2186488,4)|0)==0;if(j){h=j?1077064:0}else{g=f;break a}}}while(0);qe[c[h+12>>2]&1023](c[f+4>>2]|0);g=c[d>>2]|0}}while(0);f=c[g+8>>2]|0;mJb(a);c[d>>2]=f;}while((f|0)!=0);i=b;return}function OI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=(b|0)!=0;b=c?4:3;do{if((a|0)==0){d=0}else{if(c){if((grc(a,2194088,b)|0)==0){d=1077016;break}if((grc(a,2210656,b)|0)==0){d=1077032;break}if((grc(a,2189240,b)|0)==0){d=1077048;break}e=(grc(a,2186488,b)|0)==0;d=e?1077064:0;break}else{if((grc(a,2196848,b)|0)==0){d=1077016;break}if((grc(a,2191688,b)|0)==0){d=1077032;break}if((grc(a,2189240,b)|0)==0){d=1077048;break}e=(grc(a,2186488,b)|0)==0;return(e?1077064:0)|0}}}while(0);return d|0}function PI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[b>>2]|0;if((d|0)==0){e=0;return e|0}else{f=d}while(1){if((irc(c[f>>2]|0,2210656)|0)==0){d=c[f+4>>2]|0;b=ZX(a,0)|0;if((b|0)==0){e=-12;g=6;break}h=b+72|0;c[h>>2]=c[h>>2]|1024;h=c[b+8>>2]|0;c[h+8>>2]=0;c[h+48>>2]=c[d+12>>2];h=b+88|0;MGb(h,2600432,c[d+8>>2]|0,0)|0;MGb(h,2204e3,c[d+4>>2]|0,0)|0;h=b+104|0;J1(h);i=d;c[h>>2]=c[i>>2];c[b+128>>2]=c[(c[i>>2]|0)+4>>2];c[b+132>>2]=(c[(c[i>>2]|0)+8>>2]|0)-16;c[b+136>>2]=c[b>>2];h=b+140|0;c[h>>2]=c[h>>2]|1;c[i>>2]=0}i=c[f+8>>2]|0;if((i|0)==0){e=0;g=6;break}else{f=i}}if((g|0)==6){return e|0}return 0}function QI(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+8|0;h=g|0;c[h>>2]=d;if((d|0)<1){i=g;return}j=pJb(20)|0;if((j|0)==0){KIb(a,16,2144432,(k=i,i=i+8|0,c[k>>2]=20,k)|0);i=k;i=g;return}l=pJb(12)|0;m=l;do{if((l|0)==0){KIb(a,16,2144432,(k=i,i=i+8|0,c[k>>2]=12,k)|0);i=k;n=j+4|0}else{o=zD(b)|0;c[h>>2]=d-1;p=j+4|0;q=(XI(a,b,0,p,h)|0)<0;if(q|(c[h>>2]|0)<1){n=p;break}q=o<<24>>24;o=(XI(a,b,q,j+8|0,h)|0)<0;if(o|(c[h>>2]|0)<1){n=p;break}o=XI(a,b,q,j+12|0,h)|0;q=c[h>>2]|0;if((q|o|0)<0){n=p;break}if((q|0)==0){c[j+16>>2]=0;c[j>>2]=0}else{o=hJb(q)|0;c[j+16>>2]=o;if((o|0)==0){KIb(a,16,2139152,(k=i,i=i+8|0,c[k>>2]=q,k)|0);i=k;n=p;break}p=AD(b,o,q)|0;if(p>>>0<q>>>0){KIb(a,24,2137120,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k}c[j>>2]=p}c[l>>2]=2194088;c[l+4>>2]=j;c[l+8>>2]=c[f>>2];c[f>>2]=m;i=g;return}}while(0);KIb(a,16,2165272,(k=i,i=i+8|0,c[k>>2]=e,k)|0);i=k;kJb(c[n>>2]|0);kJb(c[j+8>>2]|0);kJb(c[j+12>>2]|0);kJb(c[j+16>>2]|0);kJb(j);kJb(l);i=g;return}function RI(a){a=a|0;kJb(c[a+4>>2]|0);kJb(c[a+8>>2]|0);kJb(c[a+12>>2]|0);kJb(c[a+16>>2]|0);kJb(a);return}function SI(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+88|0;j=f|0;k=f+8|0;l=f+16|0;m=f+80|0;c[k>>2]=e;c[m>>2]=0;n=fD(d,0,0,1)|0;o=wrc(e,(e|0)<0|0?-1:0,n,G)|0;n=G;do{if((e|0)>=5){c[m>>2]=pJb(12)|0;p=pJb(16)|0;q=(p|0)==0;a:do{if((c[m>>2]|0)==0|q){r=19}else{s=zD(d)|0;t=e-1|0;c[k>>2]=t;u=l|0;if((h|0)==0){AD(d,u,3)|0;a[l+3|0]=0;v=t}else{w=t-(LD(d,t,u,64)|0)|0;c[k>>2]=w;v=w}w=1372896;while(1){x=w+32|0;if((c[x>>2]|0)==0){break}if((JFb(w|0,u,64)|0)==0){r=9;break}else{w=w+36|0}}do{if((r|0)==9){w=c[x>>2]|0;if((w|0)==0){break}c[p+12>>2]=w;w=zD(d)|0;c[k>>2]=v-1;if((w|0)<0|w>>>0>20>>>0){KIb(b,24,2151936,(y=i,i=i+8|0,c[y>>2]=w,y)|0);i=y;z=0}else{z=w}c[p+4>>2]=c[1372808+(z<<2)>>2];w=p+8|0;if((XI(b,d,s,w,k)|0)<0){KIb(b,16,2149696,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;r=19;break a}t=c[k>>2]|0;A=cGb(t+16|0)|0;B=p;c[B>>2]=A;if((A|0)==0){C=B;D=w;break a}if((t|0)==0){r=19;break a}if((AD(d,c[A+4>>2]|0,t)|0)!=(t|0)){r=19;break a}mrc((c[(c[B>>2]|0)+4>>2]|0)+t|0,0,16)|0;c[c[m>>2]>>2]=2210656;c[(c[m>>2]|0)+4>>2]=p;c[(c[m>>2]|0)+8>>2]=c[g>>2];c[g>>2]=c[m>>2];i=f;return}}while(0);KIb(b,24,2153560,(y=i,i=i+8|0,c[y>>2]=u,y)|0);i=y;r=19}}while(0);if((r|0)==19){if(q){break}C=p;D=p+8|0}c[j>>2]=p;fGb(C);mJb(D);mJb(j)}}while(0);mJb(m);fD(d,o,n,0)|0;i=f;return}function TI(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;fGb(a);mJb(a+8|0);mJb(d);i=b;return}function UI(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+24|0;g=h|0;f=h+8|0;j=h+16|0;c[g>>2]=e;c[f>>2]=0;if((b|0)==0){KIb(0,48,2172064,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=h;return}e=(XI(b,d,0,f,g)|0)<0;k=c[g>>2]|0;if(e|(k|0)<16){i=h;return}e=JD(d)|0;l=JD(d)|0;hD(d,8,0)|0;m=aY(b,(c[b+1132>>2]|0)+1|0,682144,e,0,l,0,c[f>>2]|0)|0;if((m|0)==0){kJb(c[f>>2]|0);i=h;return}l=k-16|0;c[g>>2]=l;a:do{if((l|0)>10){k=j|0;e=j+4|0;n=m+32|0;o=l;while(1){if((AD(d,k,4)|0)<4){break a}a[e]=0;p=JD(d)|0;hD(d,2,0)|0;q=o-10|0;c[g>>2]=q;if((p|0)<0|(p|0)>(q|0)){break a}if((a[k]|0)==84){YI(b,d,p,n,k)}else{hD(d,p,(p|0)<0|0?-1:0)|0;}r=q-p|0;c[g>>2]=r;if((r|0)>10){o=r}else{s=n;t=15;break}}}else{s=m+32|0;t=15}}while(0);if((t|0)==15){cL(s,0,1373368);cL(s,0,1373280)}kJb(c[f>>2]|0);i=h;return}function VI(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+24|0;e=g|0;h=g+8|0;j=g+16|0;c[h>>2]=d;d=pJb(12)|0;c[j>>2]=d;k=pJb(12)|0;l=(k|0)==0;do{if(!((d|0)==0|l)){if((XI(a,b,0,k,h)|0)<0){break}m=c[h>>2]|0;n=hJb(m)|0;c[k+4>>2]=n;if((n|0)==0){break}o=k+8|0;c[o>>2]=m;p=AD(b,n,m)|0;if((p|0)!=(c[o>>2]|0)){break}c[c[j>>2]>>2]=2186488;c[(c[j>>2]|0)+4>>2]=k;c[(c[j>>2]|0)+8>>2]=c[f>>2];c[f>>2]=c[j>>2];i=g;return}}while(0);if(!l){c[e>>2]=k;mJb(k);mJb(k+4|0);mJb(e)}mJb(j);i=g;return}function WI(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;mJb(a);mJb(a+4|0);mJb(d);i=b;return}function XI(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+8|0;j=h|0;k=c[g>>2]|0;l=_D(j)|0;if((l|0)<0){KIb(a,16,2184104,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=l;i=h;return n|0}do{if((e|0)==1){l=k-2|0;if((l|0)<0){KIb(a,16,2181960,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;aE(c[j>>2]|0,f)|0;mJb(f);n=-1094995529;i=h;return n|0}o=HD(b)|0;if((o|0)==65279){p=l;q=2594;r=5;break}else if((o|0)==65534){p=l;q=1142;r=5;break}KIb(a,16,2179720,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;aE(c[j>>2]|0,f)|0;mJb(f);c[g>>2]=l;n=-1094995529;i=h;return n|0}else if((e|0)==0){if((k|0)==0){s=0;r=35;break}else{t=k}while(1){l=zD(b)|0;do{if(l>>>0<128>>>0){bD(c[j>>2]|0,l&255)}else{o=l>>>0>65535>>>0;u=o?l>>>16:l;v=o?16:0;if((u&65280|0)==0){w=v;x=u}else{w=v|8;x=u>>>8}u=(w+4+(d[1359664+x|0]|0)|0)/5|0;v=(u*6|0)-6|0;bD(c[j>>2]|0,(l>>>(v>>>0)|256-(256>>>(u>>>0)))&255);if((v|0)>5){y=v}else{break}do{y=y-6|0;bD(c[j>>2]|0,l>>>(y>>>0)&63|128);}while((y|0)>5)}}while(0);v=t-1|0;if((v|0)==0|(l|0)==0){z=l;A=v;r=34;break}else{t=v}}}else if((e|0)==3){if((k|0)==0){s=0;r=35;break}else{B=k}while(1){v=zD(b)|0;bD(c[j>>2]|0,v);u=B-1|0;if((u|0)==0|(v|0)==0){z=v;A=u;r=34;break}else{B=u}}}else if((e|0)==2){p=k;q=2594;r=5}else{KIb(a,24,2177984,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;s=k;r=35}}while(0);if((r|0)==5){a:do{if((p|0)<2){C=1;D=p}else{k=p;while(1){m=k-2|0;do{if((m|0)>-1){a=ve[q&4095](b)|0;e=a-55296|0;if(e>>>0<2048>>>0){B=k-4|0;if(!((B|0)>-1)){C=-56320;D=B;break a}t=(ve[q&4095](b)|0)-56320|0;if(t>>>0>1023>>>0|e>>>0>1023>>>0){C=t;D=B;break a}E=(e<<10)+65536+t|0;F=B}else{E=a;F=m}if(E>>>0<128>>>0){G=F;H=E;r=25;break}a=E>>>0>65535>>>0;B=a?E>>>16:E;t=a?16:0;if((B&65280|0)==0){I=t;J=B}else{I=t|8;J=B>>>8}B=(I+4+(d[1359664+J|0]|0)|0)/5|0;t=(B*6|0)-6|0;bD(c[j>>2]|0,(E>>>(t>>>0)|256-(256>>>(B>>>0)))&255);if((t|0)>5){K=t}else{L=E;M=F;break}while(1){t=K-6|0;bD(c[j>>2]|0,E>>>(t>>>0)&63|128);if((t|0)>5){K=t}else{L=E;M=F;break}}}else{G=m;H=0;r=25}}while(0);if((r|0)==25){r=0;bD(c[j>>2]|0,H&255);L=H;M=G}if((M|0)<2|(L|0)==0){C=L;D=M;break}else{k=M}}}}while(0);z=C;A=(D|0)<0?D+2|0:D;r=34}if((r|0)==34){if((z|0)==0){N=A}else{s=A;r=35}}if((r|0)==35){bD(c[j>>2]|0,0);N=s}aE(c[j>>2]|0,f)|0;c[g>>2]=N;n=0;i=h;return n|0}function YI(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+32|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;c[j>>2]=e;c[k>>2]=g;if((e|0)<1){i=h;return}n=zD(d)|0;c[j>>2]=e-1;if((XI(b,d,n,l,j)|0)<0){KIb(b,16,2165272,(o=i,i=i+8|0,c[o>>2]=g,o)|0);i=o;i=h;return}if((irc(g,2268848)|0)==0){p=6}else{if((irc(g,2162952)|0)==0){p=6}else{p=10}}do{if((p|0)==6){g=Bd(c[l>>2]|0,2160744,(o=i,i=i+8|0,c[o>>2]=m,o)|0)|0;i=o;if((g|0)==1){if(!((c[m>>2]|0)>>>0<148>>>0)){p=10;break}}else{g=Bd(c[l>>2]|0,2159136,(o=i,i=i+8|0,c[o>>2]=m,o)|0)|0;i=o;if(!((g|0)==1&(c[m>>2]|0)>>>0<148>>>0)){p=10;break}}mJb(l);g=rJb(c[1373488+(c[m>>2]<<2)>>2]|0)|0;c[l>>2]=g;q=24;r=g}}while(0);a:do{if((p|0)==10){m=c[k>>2]|0;do{if((irc(m,2157040)|0)==0){p=12}else{if((irc(m,2155264)|0)==0){p=12;break}g=c[l>>2]|0;if((a[g]|0)!=0){q=24;r=g;break a}mJb(l);s=24}}while(0);do{if((p|0)==12){m=c[l>>2]|0;c[k>>2]=m;if((XI(b,d,n,l,j)|0)>=0){s=28;break}KIb(b,16,2165272,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;mJb(k);i=h;return}}while(0);q=s;r=c[l>>2]|0}}while(0);if((r|0)==0){i=h;return}MGb(f,c[k>>2]|0,r,q)|0;i=h;return}function ZI(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+8>>2]|0;if((b|0)<65568){e=0;return e|0}f=c[a+4>>2]|0;a=f;g=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((g|0)==0|g>>>0>1024>>>0){e=0;return e|0}a=f+4|0;h=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if((h|0)==0|h>>>0>1024>>>0){e=0;return e|0}a=f+8|0;i=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(i|0)!=0;if(a&(i-8e3|0)>>>0>4e4>>>0){e=0;return e|0}i=f+12|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;if(j>>>0>2>>>0|a&(j|0)==0){e=0;return e|0}j=f+16|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;if(i>>>0>2>>>0|a&(i|0)==0){e=0;return e|0}i=f+65556|0;a=(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)==1?66324:65556;if((a+12|0)>(b|0)){e=1;return e|0}else{e=f+(a|8)|0;a=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==(ca(h,g)|0);return(a?50:1)|0}return 0}function _I(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=a+16|0;e=c[d>>2]|0;f=c[a+12>>2]|0;g=FD(e)|0;h=FD(e)|0;j=FD(e)|0;k=FD(e)|0;l=FD(e)|0;m=a;if((c[(c[d>>2]|0)+52>>2]|0)!=0){KIb(m,16,2268584,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=c[(c[d>>2]|0)+76>>2]|0;p=(o|0)==0?-541478725:o;i=b;return p|0}if((tIb(g,h,0,m)|0)<0){p=-1094995529;i=b;return p|0}do{if((j|0)==0){c[f+28>>2]=0}else{if(j>>>0<14>>>0|(j|0)<0){KIb(m,16,2220296,(n=i,i=i+8|0,c[n>>2]=j,n)|0);i=n;p=-1094995529;i=b;return p|0}if((k|0)==0|k>>>0>2>>>0){KIb(m,16,2185704,(n=i,i=i+8|0,c[n>>2]=k,n)|0);i=n;p=-1094995529;i=b;return p|0}if(!((l|0)==0|l>>>0>2>>>0)){c[f+28>>2]=1;break}KIb(m,16,2156512,(n=i,i=i+8|0,c[n>>2]=l,n)|0);i=n;p=-1094995529;i=b;return p|0}}while(0);n=ZX(a,0)|0;if((n|0)==0){p=-12;i=b;return p|0}_X(n,33,1,14);m=n+48|0;c[m>>2]=0;c[m+4>>2]=0;c[f>>2]=c[n>>2];m=c[n+8>>2]|0;c[m+8>>2]=0;c[m+48>>2]=48;c[m+52>>2]=0;c[m+120>>2]=g;c[m+124>>2]=h;h=QX(m,e,65536)|0;if((h|0)<0){p=h;i=b;return p|0}h=f+28|0;if((c[h>>2]|0)!=0){c[h>>2]=1;h=ZX(a,0)|0;if((h|0)==0){p=-12;i=b;return p|0}_X(h,63,1,j);a=h+48|0;c[a>>2]=0;c[a+4>>2]=0;c[f+4>>2]=c[h>>2];a=c[h+8>>2]|0;c[a+8>>2]=1;c[a+52>>2]=1;c[a+416>>2]=l;h=l>>>0>1>>>0;e=a+448|0;c[e>>2]=h?3:4;c[e+4>>2]=h?0:0;c[a+412>>2]=j;c[a+792>>2]=k<<3;c[a+72>>2]=ca(ca(j<<3,k)|0,l)|0;h=ca(l,k)|0;c[f+16>>2]=h;c[a+432>>2]=h;c[a+48>>2]=(k|0)==1?65541:65536;k=(j>>>0)/14|0;a=ca(h,k)|0;if(((j>>>0)%14|0|0)==0){c[f+12>>2]=a;c[f+8>>2]=a}else{c[f+8>>2]=a;c[f+12>>2]=ca(h,k+1|0)|0}c[f+20>>2]=0}c[f+24>>2]=1;k=fD(c[d>>2]|0,0,0,1)|0;d=f+32|0;c[d>>2]=k;c[d+4>>2]=G;p=0;i=b;return p|0}function $I(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+1792|0;f=e|0;g=e+768|0;h=c[a+12>>2]|0;j=a+16|0;k=c[j>>2]|0;if((jD(k)|0)!=0){l=c[(c[j>>2]|0)+76>>2]|0;m=(l|0)==0?-541478725:l;i=e;return m|0}l=h+24|0;do{if((c[l>>2]|0)==0){n=h+20|0;o=c[((c[n>>2]|0)==0?h+8|0:h+12|0)>>2]|0;p=fX(k,b,o)|0;if((p|0)<0){m=p;i=e;return m|0}else{c[b+32>>2]=c[h+4>>2];c[b+48>>2]=(o>>>0)/((c[h+16>>2]|0)>>>0)|0;c[n>>2]=c[n>>2]^1;break}}else{n=FD(k)|0;if((n|0)==2){m=-5;i=e;return m|0}o=(n|0)==1;if(o){n=AD(k,f|0,768)|0;if((n|0)<0){m=n;i=e;return m|0}if((n|0)==768){q=0}else{KIb(a,16,2397592,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=-5;i=e;return m|0}while(1){if((q|0)>=768){s=0;t=11;break}if((d[f+q|0]|0)>>>0>63>>>0){u=0;t=12;break}else{q=q+1|0}}if((t|0)==11){while(1){t=0;n=s*3|0;p=(d[f+(n+1)|0]|0)<<10&64512|(d[f+n|0]|0)<<18|(d[f+(n+2)|0]|0)<<2&252;c[g+(s<<2)>>2]=p>>>6&197379|(p|-16777216);p=s+1|0;if((p|0)<256){s=p;t=11}else{break}}}else if((t|0)==12){while(1){t=0;p=u*3|0;c[g+(u<<2)>>2]=(d[f+(p+1)|0]|0)<<8|(d[f+p|0]|0)<<16|(d[f+(p+2)|0]|0)|-16777216;p=u+1|0;if((p|0)<256){u=p;t=12}else{break}}}}if((c[(c[j>>2]|0)+52>>2]|0)!=0){KIb(a,16,2397592,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=c[(c[j>>2]|0)+76>>2]|0;m=(p|0)==0?-541478725:p;i=e;return m|0}p=FD(k)|0;n=p-4|0;if(n>>>0>2147483639>>>0){KIb(a,16,2323528,(r=i,i=i+8|0,c[r>>2]=p,r)|0);i=r;m=-1094995529;i=e;return m|0}hD(k,4,0)|0;if(p>>>0<4>>>0){m=-1094995529;i=e;return m|0}p=fX(k,b,n)|0;if((p|0)<0){m=p;i=e;return m|0}if((p|0)!=(n|0)){KIb(a,16,2397592,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;P1(b);m=-5;i=e;return m|0}do{if(o){n=U1(b,0,1024)|0;if((n|0)!=0){nrc(n|0,g|0,1024)|0;n=b+36|0;c[n>>2]=c[n>>2]|1;break}P1(b);m=-12;i=e;return m|0}}while(0);c[b+32>>2]=c[h>>2];c[b+48>>2]=1}}while(0);if((c[h+28>>2]|0)==0){m=0;i=e;return m|0}c[l>>2]=c[l>>2]^1;m=0;i=e;return m|0}function aJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;f=c[a+12>>2]|0;e=f+32|0;d=c[e>>2]|0;b=c[e+4>>2]|0;e=0;if(!((b|0)>(e|0)|(b|0)==(e|0)&d>>>0>0>>>0)){g=-1;return g|0}e=fD(c[a+16>>2]|0,d,b,0)|0;b=e;if((b|0)<0){g=b;return g|0}zX(a,c[(c[a+28>>2]|0)+(c[f>>2]<<2)>>2]|0,0,0);c[f+24>>2]=1;c[f+20>>2]=0;g=0;return g|0}function bJ(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==4228){a=b+2|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==-1?100:0)|0}else{return 0}return 0}function cJ(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;e=b|0;f=c[a+12>>2]|0;if((AD(c[a+16>>2]|0,e|0,8)|0)!=8){g=-5;i=b;return g|0}h=e+6|0;c[f>>2]=(d[h]|d[h+1|0]<<8)<<16>>16&65535;c[f+32>>2]=0;h=f+24|0;c[h>>2]=0;c[h+4>>2]=0;c[f+12>>2]=0;c[f+8>>2]=0;c[f+4>>2]=0;c[f+20>>2]=-1;c[f+16>>2]=-1;f=a+20|0;c[f>>2]=c[f>>2]|1;g=0;i=b;return g|0}function dJ(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;g=i;i=i+8|0;h=g|0;j=h;k=c[d+12>>2]|0;l=d+16|0;m=c[l>>2]|0;n=h;o=h+2|0;p=k+16|0;q=k;r=k+4|0;s=n+2|0;t=k+8|0;u=f+32|0;v=k+24|0;w=f+8|0;x=k+20|0;z=k+12|0;A=f+24|0;B=f+64|0;C=k+32|0;k=m;a:while(1){if((jD(k)|0)!=0){D=-5;E=30;break}if((AD(m,n,8)|0)!=8){D=-5;E=30;break}F=b[j>>1]|0;H=F&65535;I=e[o>>1]|e[o+2>>1]<<16;if((I|0)<0){D=-1094995529;E=30;break}J=eX(m,I)|0;switch(H|0){case 4098:{E=12;break a;break};case 4113:{break a;break};case 4097:{break};case 4128:case 4129:{E=16;break a;break};default:{E=29;break a}}if((c[p>>2]|0)==-1){I=ZX(d,0)|0;if((I|0)==0){D=-12;E=30;break}_X(I,63,1,c[q>>2]|0);c[p>>2]=c[I>>2];K=I+8|0;I=c[K>>2]|0;c[I+8>>2]=0;c[I+48>>2]=39;c[I+52>>2]=0;if((AD(m,n,8)|0)!=8){D=-5;E=30;break}I=e[j>>1]|0;c[r>>2]=I;L=c[K>>2]|0;c[L+120>>2]=I;I=e[s>>1]|0;c[t>>2]=I;c[L+124>>2]=I}else{hD(m,8,0)|0;}k=c[l>>2]|0}do{if((E|0)==12){if((c[p>>2]|0)<0){D=-1094995529;i=g;return D|0}l=fD(m,0,0,1)|0;k=G;hD(m,J,0)|0;if((AD(m,n,8)|0)!=8){D=-5;i=g;return D|0}t=wrc(l,k,-8,-1)|0;k=J+16+(e[o>>1]|e[o+2>>1]<<16)|0;fD(m,t,G,0)|0;if((fX(m,f,k)|0)!=(k|0)){D=-5;i=g;return D|0}c[u>>2]=c[p>>2];t=c[v>>2]|0;l=c[v+4>>2]|0;s=wrc(t,l,1,0)|0;c[v>>2]=s;c[v+4>>2]=G;c[w>>2]=t;c[w+4>>2]=l;D=k;i=g;return D|0}else if((E|0)==16){if(!((c[x>>2]|0)==-1)){break}k=ZX(d,0)|0;if((k|0)==0){D=-12;i=g;return D|0}_X(k,32,1,22050);c[x>>2]=c[k>>2];l=c[k+8>>2]|0;c[l+8>>2]=1;c[l+48>>2]=81920;c[l+52>>2]=0;k=l+416|0;if(F<<16>>16==4129){c[k>>2]=2;t=l+448|0;c[t>>2]=3;c[t+4>>2]=0;M=2}else{c[k>>2]=1;t=l+448|0;c[t>>2]=4;c[t+4>>2]=0;M=1}c[z>>2]=M;c[l+412>>2]=22050;c[l+792>>2]=16;t=c[k>>2]|0;c[l+72>>2]=t*352800|0;c[l+432>>2]=t<<4}else if((E|0)==29){KIb(d,16,2397560,(t=i,i=i+8|0,c[t>>2]=H,t)|0);i=t;D=-1094995529;i=g;return D|0}else if((E|0)==30){i=g;return D|0}}while(0);E=F<<16>>16==4113;do{if(E){if((c[p>>2]|0)<0){D=-1094995529}else{break}i=g;return D|0}}while(0);if((K1(f,J+8|0)|0)!=0){D=-5;i=g;return D|0}f=c[A>>2]|0;F=c[h+4>>2]|0;H=f|0;y=c[h>>2]|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=f+4|0;y=F;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;if(E){c[u>>2]=c[p>>2];p=c[v>>2]|0;E=c[v+4>>2]|0;H=wrc(p,E,1,0)|0;c[v>>2]=H;c[v+4>>2]=G;c[w>>2]=p;c[w+4>>2]=E}else{c[u>>2]=c[x>>2];x=c[C>>2]|0;c[w>>2]=x;c[w+4>>2]=0;c[C>>2]=x+((J>>>0)/((c[z>>2]|0)>>>0)|0)}z=fD(m,0,0,1)|0;c[B>>2]=z;c[B+4>>2]=G;B=AD(m,(c[A>>2]|0)+8|0,J)|0;D=(B|0)==(J|0)?B:-5;i=g;return D|0}function eJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;f=e;c[e>>2]=-61308;c[e+4>>2]=2031615;g=c[b+24>>2]|0;h=b+28|0;j=0;while(1){if(!(j>>>0<g>>>0)){break}k=c[(c[(c[h>>2]|0)+(j<<2)>>2]|0)+8>>2]|0;if((c[k+8>>2]|0)==0){l=4;break}else{j=j+1|0}}if((l|0)==4){if((c[k+104>>2]|0)!=1){KIb(k,16,2397528,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=d;return n|0}l=c[k+108>>2]|0;if(l>>>0>255>>>0){KIb(k,16,2323488,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=d;return n|0}if((l|0)!=30){KIb(k,24,2268528,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}a[f+6|0]=l}l=b+16|0;dD(c[l>>2]|0,e,8);eD(c[l>>2]|0);n=0;i=d;return n|0}function fJ(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1297239878){e=b+8|0;f=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if((f|0)==1482052408|(f|0)==1448293937|(f|0)==1146437965|(f|0)==541934160|(f|0)==1296188225|(f|0)==1346716996|(f|0)==1296190537|(f|0)==943867730|(f|0)==1312966482){g=100}else{break}return g|0}}while(0);g=0;return g|0}function gJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;i=i+16|0;e=c[b+12>>2]|0;f=b+16|0;g=c[f>>2]|0;h=ZX(b,0)|0;if((h|0)==0){j=-12;i=d;return j|0}k=h+8|0;l=c[k>>2]|0;c[l+416>>2]=1;m=l+448|0;c[m>>2]=4;c[m+4>>2]=0;hD(g,8,0)|0;m=FD(g)|0;c[(c[k>>2]|0)+52>>2]=m;m=e+32|0;l=e+20|0;n=l;o=e+24|0;p=e+28|0;mrc(l|0,-1|0,16)|0;l=e;a:do{if((jD(g)|0)==0){q=e+8|0;r=e+16|0;s=h+80|0;t=h+84|0;u=d|0;v=e+56|0;w=b+1140|0;x=0;z=0;A=0;b:while(1){B=FD(g)|0;C=JD(g)|0;D=fD(g,0,0,1)|0;E=G;do{if((B|0)==1279412036){c[(c[k>>2]|0)+8>>2]=0;if(C>>>0<8>>>0){j=-1094995529;F=89;break b}H=HD(g)|0;c[(c[k>>2]|0)+120>>2]=H;H=HD(g)|0;c[(c[k>>2]|0)+124>>2]=H;c[m>>2]=HD(g)|0;c[s>>2]=zD(g)|0;c[t>>2]=zD(g)|0;c[(c[k>>2]|0)+792>>2]=24;I=x;J=z;K=A}else if((B|0)==1129270340){if(C>>>0<4>>>0){j=-1094995529;F=89;break b}H=HD(g)|0;c[(c[k>>2]|0)+120>>2]=H;H=HD(g)|0;c[(c[k>>2]|0)+124>>2]=H;I=x;J=z;K=A}else if((B|0)==1145589058){c[(c[k>>2]|0)+8>>2]=0;if(C>>>0<9>>>0){j=-1094995529;F=89;break b}H=HD(g)|0;c[(c[k>>2]|0)+120>>2]=H;H=HD(g)|0;c[(c[k>>2]|0)+124>>2]=H;hD(g,4,0)|0;H=zD(g)|0;c[(c[k>>2]|0)+792>>2]=H;if(!(C>>>0>9>>>0)){I=x;J=z;K=A;break}H=zD(g)|0;if(!(C>>>0>10>>>0)){I=x;J=H;K=A;break}c[m>>2]=zD(g)|0;if(!(C>>>0>13>>>0)){I=x;J=H;K=A;break}hD(g,1,0)|0;L=HD(g)|0;if(!(C>>>0>15>>>0)){I=L;J=H;K=A;break}c[s>>2]=zD(g)|0;c[t>>2]=zD(g)|0;I=L;J=H;K=A}else if((B|0)==1380206669){c[(c[k>>2]|0)+8>>2]=1;if(C>>>0<32>>>0){j=-1094995529;F=89;break b}hD(g,4,0)|0;c[o>>2]=HD(g)|0;hD(g,2,0)|0;H=JD(g)|0;L=HD(g)|0;if((L|0)==0){j=-1094995529;F=89;break b}hD(g,2,0)|0;c[(c[k>>2]|0)+412>>2]=(H>>>0)/(L>>>0)|0;L=HD(g)|0;c[(c[k>>2]|0)+416>>2]=L;c[p>>2]=HD(g)|0;L=c[k>>2]|0;H=c[L+416>>2]|0;if((H|0)==1){M=L+448|0;c[M>>2]=4;c[M+4>>2]=0;I=x;J=z;K=A;break}else if((H|0)==2){H=L+448|0;c[H>>2]=3;c[H+4>>2]=0;I=x;J=z;K=A;break}else{I=x;J=z;K=A;break}}else if((B|0)==1414087233|(B|0)==1497648962|(B|0)==1146044996|(B|0)==1413563469){H=fD(g,0,0,1)|0;L=G;c[l>>2]=H;c[l+4>>2]=L;M=wrc(H,L,C,0)|0;c[q>>2]=M;c[q+4>>2]=G;c[r>>2]=C;I=x;J=z;K=A}else if((B|0)==1380206678){c[(c[k>>2]|0)+8>>2]=1;if(C>>>0<14>>>0){j=-1094995529;F=89;break b}hD(g,12,0)|0;M=HD(g)|0;c[(c[k>>2]|0)+412>>2]=M;if(!(C>>>0>15>>>0)){I=x;J=z;K=A;break}hD(g,1,0)|0;c[n>>2]=zD(g)|0;I=x;J=z;K=A}else if((B|0)==1346456899){if(!((C-3|0)>>>0<766>>>0&((C>>>0)%3|0|0)==0)){F=21;break b}c[(c[k>>2]|0)+100>>2]=C+41;M=hJb(C+57|0)|0;c[(c[k>>2]|0)+96>>2]=M;M=c[(c[k>>2]|0)+96>>2]|0;if((M|0)==0){j=-12;F=89;break b}if((AD(g,M+41|0,C)|0)<0){j=-5;F=89;break b}else{I=x;J=z;K=A}}else if((B|0)==1312901187){if(C>>>0<4>>>0){j=-1094995529;F=89;break b}M=(JD(g)|0)>>>0<6>>>0;L=c[k>>2]|0;H=L+416|0;if(M){c[H>>2]=1;M=L+448|0;c[M>>2]=4;c[M+4>>2]=0;I=x;J=z;K=A;break}else{c[H>>2]=2;H=L+448|0;c[H>>2]=3;c[H+4>>2]=0;I=x;J=z;K=A;break}}else if((B|0)==1196245315){if(C>>>0<4>>>0){j=-1094995529;F=89;break b}I=x;J=z;K=JD(g)|0}else if((B|0)==1279610948){if(!(C>>>0>3>>>0&(C&3|0)==0)){j=-1094995529;F=89;break b}H=AD(g,u,16)|0;if((H|0)<0){j=H;F=89;break b}if((H|0)!=16){F=43;break b}if((grc(u,1584464,16)|0)==0){c[(c[k>>2]|0)+140>>2]=2;I=x;J=z;K=A;break}if((grc(u,1584448,16)|0)==0){c[(c[k>>2]|0)+140>>2]=28;I=x;J=z;K=A;break}if((grc(u,1584480,16)|0)==0){c[(c[k>>2]|0)+140>>2]=30;I=x;J=z;K=A;break}if((grc(u,1584496,16)|0)==0){c[(c[k>>2]|0)+140>>2]=27;I=x;J=z;K=A;break}if((grc(u,1584512,16)|0)!=0){F=43;break b}c[(c[k>>2]|0)+140>>2]=29;I=x;J=z;K=A}else if((B|0)==1128552020){if(C>>>0<32>>>0){j=-1094995529;F=89;break b}H=AD(g,v,32)|0;if((H|0)<0){j=H;F=89;break b}else{I=x;J=z;K=A}}else if((B|0)==1213486401){N=2131264;F=53}else if((B|0)==539583272){N=2108104;F=53}else if((B|0)==1162690894){N=2626208;F=53}else if((B|0)==1330531905|(B|0)==1415071060){N=2156504;F=53}else{I=x;J=z;K=A}}while(0);if((F|0)==53){F=0;B=C+1|0;if((B|0)==0){O=-12;break}P=hJb(B)|0;if((P|0)==0){O=-12;break}if((AD(c[f>>2]|0,P,C)|0)!=(C|0)){F=56;break}a[P+C|0]=0;MGb(w,N,P,8)|0;I=x;J=z;K=A}B=fD(g,0,0,1)|0;H=G;L=wrc(C,0,D,E)|0;M=wrc(L,G,C&1,0)|0;L=xrc(M,G,B,H)|0;hD(g,L,G)|0;if((jD(g)|0)==0){x=I;z=J;A=K}else{Q=I;R=J;S=K;break a}}if((F|0)==21){KIb(b,16,2220264,(T=i,i=i+8|0,c[T>>2]=C,T)|0);i=T;j=-1094995529;i=d;return j|0}else if((F|0)==43){QIb(b,2185680,(T=i,i=i+8|0,c[T>>2]=u,T)|0);i=T;j=-1163346256;i=d;return j|0}else if((F|0)==56){kJb(P);O=-5}else if((F|0)==89){i=d;return j|0}KIb(b,16,2600272,(T=i,i=i+8|0,c[T>>2]=N,T)|0);i=T;j=O;i=d;return j|0}else{Q=0;R=0;S=0}}while(0);fD(g,c[l>>2]|0,c[l+4>>2]|0,0)|0;l=c[k>>2]|0;g=c[l+8>>2]|0;if((g|0)==0){O=l+792|0;N=c[O>>2]|0;P=e+36|0;c[P>>2]=N;if((S&2048|0)!=0&N>>>0<9>>>0){c[e+40>>2]=N>>>0>6>>>0?6:4;c[O>>2]=24}if((S&128|0)==0){U=0}else{U=(c[P>>2]|0)>>>0<9>>>0|0}S=e+44|0;c[S>>2]=U;U=e+52|0;c[U>>2]=R;R=e+48|0;c[R>>2]=Q;Q=c[l+96>>2]|0;do{if((Q|0)==0){c[l+100>>2]=41;O=hJb(57)|0;c[(c[k>>2]|0)+96>>2]=O;O=c[k>>2]|0;N=c[O+96>>2]|0;if((N|0)==0){j=-12}else{V=O;W=N;break}i=d;return j|0}else{V=l;W=Q}}while(0);if((c[V+100>>2]|0)<=40){KIb(0,0,2397496,(T=i,i=i+24|0,c[T>>2]=2539096,c[T+8>>2]=2268496,c[T+16>>2]=418,T)|0);i=T;Hd();return 0}V=W;y=10496;a[V]=y;y=y>>8;a[V+1|0]=y;a[W+2|0]=c[m>>2];a[W+3|0]=c[P>>2];a[W+4|0]=c[e+40>>2];a[W+5|0]=c[S>>2];S=W+6|0;y=he(c[R>>2]&65535|0)|0;a[S]=y;y=y>>8;a[S+1|0]=y;a[W+8|0]=c[U>>2];nrc(W+9|0,e+56|0,32)|0;c[(c[k>>2]|0)+48>>2]=137;j=0;i=d;return j|0}else if((g|0)==1){_X(h,32,1,c[l+412>>2]|0);l=c[k>>2]|0;h=c[l+52>>2]|0;do{if((h|0)==1448293937){c[l+48>>2]=1347637264;X=1347637264}else if((h|0)==1146437965){g=c[o>>2]|0;do{if((g|0)==8){if((c[p>>2]|0)==0){c[l+48>>2]=65541;Y=65541;F=73;break}e=c[p>>2]|0;if((e|0)==2){c[l+48>>2]=65543;Y=65543;F=73;break}else if((e|0)==3){c[l+48>>2]=65542;Y=65542;F=73;break}else{Z=e;break}}else if((g|0)==16){if((c[p>>2]|0)!=0){F=68;break}c[l+48>>2]=65537;Y=65537;F=73}else{F=68}}while(0);if((F|0)==68){Z=c[p>>2]|0}else if((F|0)==73){u=g5a(Y)|0;e=c[k>>2]|0;c[e+792>>2]=u;c[e+432>>2]=(ca(c[e+416>>2]|0,u)|0)/8|0;X=c[e+48>>2]|0;break}QIb(b,2575536,(T=i,i=i+16|0,c[T>>2]=Z,c[T+8>>2]=g,T)|0);i=T;j=-1163346256;i=d;return j|0}else{e=c[n>>2]|0;if((e|0)==0){c[l+48>>2]=65563;X=65563;break}else if((e|0)==1){c[l+48>>2]=86072;X=86072;break}else if((e|0)==2){c[l+48>>2]=86071;X=86071;break}else{KIb(b,16,2556632,(T=i,i=i+8|0,c[T>>2]=e,T)|0);i=T;j=-1;i=d;return j|0}}}while(0);T=g5a(X)|0;X=c[k>>2]|0;c[X+792>>2]=T;k=c[X+416>>2]|0;c[X+72>>2]=ca(ca(c[X+412>>2]|0,k)|0,T)|0;c[X+432>>2]=ca(T,k)|0;j=0;i=d;return j|0}else{j=-1;i=d;return j|0}return 0}function hJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=c[b+12>>2]|0;g=c[b+16>>2]|0;h=c[c[b+28>>2]>>2]|0;b=fD(g,0,0,1)|0;j=G;k=f+8|0;l=c[k>>2]|0;m=c[k+4>>2]|0;if(!((j|0)<(m|0)|(j|0)==(m|0)&b>>>0<l>>>0)){n=-541478725;i=e;return n|0}k=c[h+8>>2]|0;h=c[k+8>>2]|0;do{if((h|0)==1){if((c[k+52>>2]|0)==1146437965){o=xrc(l,m,b,j)|0;p=G;q=c[k+432>>2]<<10;r=(q|0)<0|0?-1:0;s=fX(g,d,(p|0)>(r|0)|(p|0)==(r|0)&o>>>0>q>>>0?q:o)|0;break}else{s=fX(g,d,c[f+16>>2]|0)|0;break}}else if((h|0)==0){o=f+16|0;if((K1(d,(c[o>>2]|0)+2|0)|0)<0){n=-12;i=e;return n|0}q=c[d+24>>2]|0;r=q;y=512;a[r]=y;y=y>>8;a[r+1|0]=y;r=AD(g,q+2|0,c[o>>2]|0)|0;if((r|0)<0){P1(d);s=r;break}if(!(r>>>0<(c[o>>2]|0)>>>0)){s=r;break}M1(d,r+2|0);s=r}else{KIb(0,0,2397496,(r=i,i=i+24|0,c[r>>2]=2323480,c[r+8>>2]=2268496,c[r+16>>2]=470,r)|0);i=r;Hd();return 0}}while(0);g=f;if((b|0)==(c[g>>2]|0)&(j|0)==(c[g+4>>2]|0)){g=d+36|0;c[g>>2]=c[g>>2]|1}if((s|0)<0){n=s;i=e;return n|0}c[d+32>>2]=0;n=s;i=e;return n|0}function iJ(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,830496,6)|0)==0;return(b?100:0)|0}function jJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;AD(c[a+16>>2]|0,d,9)|0;e=ZX(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=e+8|0;h=c[g>>2]|0;c[h+48>>2]=86076;c[h+412>>2]=8e3;c[h+416>>2]=1;c[h+8>>2]=1;h=e+48|0;c[h>>2]=0;c[h+4>>2]=0;_X(e,64,1,8e3);if((grc(d,830496,9)|0)==0){e=c[g>>2]|0;c[e+432>>2]=38;c[e+72>>2]=15200;f=0;i=b;return f|0}if((grc(d,830432,9)|0)==0){d=c[g>>2]|0;c[d+432>>2]=50;c[d+72>>2]=13333;f=0;i=b;return f|0}else{KIb(a,16,2156448,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-1094995529;i=b;return f|0}return 0}function kJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+432|0;e=K1(b,c[d>>2]|0)|0;if((e|0)<0){f=e;return f|0}c[b+32>>2]=0;e=a+16|0;a=fD(c[e>>2]|0,0,0,1)|0;g=b+64|0;c[g>>2]=a;c[g+4>>2]=G;c[b+48>>2]=(c[d>>2]|0)==38?160:240;g=AD(c[e>>2]|0,c[b+24>>2]|0,c[d>>2]|0)|0;if((g|0)==(c[d>>2]|0)){f=0;return f|0}P1(b);f=(g|0)<0?g:-5;return f|0}function lJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+16>>2]|0;if((c[a+24>>2]|0)!=1){KIb(a,16,2268424,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}g=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[g+48>>2]|0)!=86076){KIb(a,16,2219968,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}h=c[g+432>>2]|0;if((h|0)==38){dD(d,830496,9)}else if((h|0)==50){dD(d,830432,9)}else{KIb(a,16,2185648,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}eD(d);f=0;i=b;return f|0}function mJ(a,b){a=a|0;b=b|0;dD(c[a+16>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function nJ(a){a=a|0;var b=0,d=0,e=0,f=0;b=hc(a|0,46)|0;if((b|0)==0){d=0;return d|0}a=b+1|0;b=1072496;while(1){e=b|0;if((c[e>>2]|0)==0){d=0;f=6;break}if((IFb(a,c[b+4>>2]|0)|0)==0){break}else{b=b+8|0}}if((f|0)==6){return d|0}d=c[e>>2]|0;return d|0}function oJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=b|0;b=c[d>>2]|0;if((b|0)==0){e=0;return e|0}if((nJ(b)|0)==0){e=0;return e|0}if((iX(c[d>>2]|0)|0)!=0){e=100;return e|0}b=c[d>>2]|0;f=_b(b|0,37)|0;a:do{if((f|0)!=0){g=f;while(1){h=g+1|0;if((a[h]|0)==37){i=g+2|0}else{if((ud(h|0,2314704)|0)==0){i=h}else{e=100;break}}g=_b(i|0,37)|0;if((g|0)==0){break a}}return e|0}}while(0);if((fH(b,2310016)|0)==0){b=(fH(c[d>>2]|0,2305960)|0)==0;return(b?50:5)|0}else{e=5;return e|0}return 0}function pJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=i;i=i+1024|0;e=d|0;f=c[b+12>>2]|0;g=b+20|0;c[g>>2]=c[g>>2]|1;g=ZX(b,0)|0;if((g|0)==0){h=-12;i=d;return h|0}j=f+1060|0;k=c[j>>2]|0;do{if((k|0)==0){l=-1}else{m=nKb(k)|0;if(!((m|0)==-1)){l=m;break}KIb(b,16,2360328,(n=i,i=i+8|0,c[n>>2]=c[j>>2],n)|0);i=n;h=-22;i=d;return h|0}}while(0);j=f+36|0;CFb(j,b+32|0,1024)|0;k=f+12|0;c[k>>2]=0;c[f+24>>2]=0;m=f+28|0;if((c[(c[b+4>>2]|0)+8>>2]&1|0)==0){c[m>>2]=1;c[g+236>>2]=1}else{c[m>>2]=0}o=f+1140|0;if((c[o>>2]|0)==0){_X(g,64,c[f+1076>>2]|0,c[f+1072>>2]|0)}else{_X(g,64,1,1)}p=c[f+1064>>2]|0;do{if((p|0)!=0){q=f+1068|0;if((c[q>>2]|0)==0){break}r=c[g+8>>2]|0;c[r+120>>2]=p;c[r+124>>2]=c[q>>2]}}while(0);do{if((c[m>>2]|0)==0){p=f+1084|0;q=c[p>>2]|0;a:do{if((q|0)==0){r=_b(j|0,37)|0;b:do{if((r|0)==0){s=21}else{t=r;while(1){u=t+1|0;if((a[u]|0)==37){v=t+2|0}else{if((ud(u|0,2314704)|0)==0){v=u}else{break}}u=_b(v|0,37)|0;if((u|0)==0){s=21;break b}else{t=u}}c[f+1088>>2]=1;KIb(b,24,2348176,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;t=rJb(j)|0;u=a[t]|0;c:do{if(u<<24>>24==0){w=j}else{x=j;y=t;z=j;A=u;while(1){if((z-x|0)>>>0>1021>>>0){w=z;break c}if(A<<24>>24==37){B=y+1|0;if((ud(B|0,2341944)|0)==0){s=27}else{C=z;D=B}}else{s=27}do{if((s|0)==27){s=0;if((ud(y|0,2336008)|0)==0){C=z;D=y;break}a[z]=92;C=z+1|0;D=y}}while(0);B=D+1|0;E=C+1|0;a[C]=a[D]|0;F=a[B]|0;if(F<<24>>24==0){w=E;break}else{y=B;z=E;A=F}}}}while(0);a[w]=0;kJb(t);u=f+1092|0;if(($d(j|0,16,0,u|0)|0)==0){A=(c[u>>2]|0)-1|0;u=c[p>>2]|0;if((u|0)==0){G=A;break}else{H=A;I=u;s=33;break a}}else{h=-2;i=d;return h|0}}}while(0);if((s|0)==21){c[f+1088>>2]=0;G=0}if((c[f+1088>>2]|0)==0){s=34}else{J=G;K=0}}else{H=0;I=q;s=33}}while(0);do{if((s|0)==33){if((I|0)==2){s=34;break}else if((I|0)==0){J=H;K=0;break}else if((I|0)!=1){KIb(b,16,2324720,(n=i,i=i+8|0,c[n>>2]=I,n)|0);i=n;h=-22;i=d;return h|0}q=f+1092|0;if(($d(j|0,16,0,q|0)|0)==0){p=(c[q>>2]|0)-1|0;c[f+1088>>2]=1;J=p;K=0;break}else{h=-2;i=d;return h|0}}}while(0);d:do{if((s|0)==34){p=f+1128|0;q=c[p>>2]|0;r=f+1132|0;u=e|0;A=(c[r>>2]|0)+q|0;z=q;while(1){if((z|0)>=(A|0)){s=38;break}q=(jX(u,1024,j,z)|0)<0;L=XC(u,1)|0;if(q){s=44;break}if((L|0)>0){s=38;break}else{z=z+1|0}}e:do{if((s|0)==38){if((z|0)==(A|0)){break}else{M=z}while(1){q=0;while(1){N=(q|0)!=0;y=N?q<<1:1;if((jX(u,1024,j,y+M|0)|0)<0){break e}if((XC(u,1)|0)<1){break}if((y|0)>1073741823){break e}else{q=y}}if(N){M=q+M|0}else{J=M;K=z;break d}}}else if((s|0)==44){if((L|0)>=1){J=1;K=1;break d}}}while(0);z=c[p>>2]|0;u=z-1+(c[r>>2]|0)|0;KIb(b,16,2330824,(n=i,i=i+24|0,c[n>>2]=j,c[n+8>>2]=z,c[n+16>>2]=u,n)|0);i=n;h=-2;i=d;return h|0}}while(0);c[f+4>>2]=K;c[f+8>>2]=J;c[k>>2]=K;if((c[o>>2]|0)!=0){break}u=g+48|0;c[u>>2]=0;c[u+4>>2]=0;u=1-K+J|0;z=g+56|0;c[z>>2]=u;c[z+4>>2]=(u|0)<0|0?-1:0}}while(0);J=c[b+1112>>2]|0;do{if((J|0)==0){K=c[b+1116>>2]|0;if((K|0)!=0){o=c[g+8>>2]|0;c[o+8>>2]=1;c[o+48>>2]=K;O=o;break}o=hc(j|0,46)|0;if((o|0)==0){P=0}else{P=(IFb(o+1|0,2319392)|0)==0|0}c[f+32>>2]=P;o=g+8|0;c[(c[o>>2]|0)+8>>2]=0;K=nJ(j)|0;k=c[o>>2]|0;o=k+48|0;c[o>>2]=K;if((K|0)!=10){O=k;break}c[o>>2]=8;O=k}else{k=c[g+8>>2]|0;c[k+8>>2]=0;c[k+48>>2]=J;O=k}}while(0);if((c[O+8>>2]|0)!=0|(l|0)==-1){h=0;i=d;return h|0}c[O+140>>2]=l;h=0;i=d;return h|0}function qJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=i;i=i+1152|0;f=e+1024|0;g=e+1040|0;h=e+1056|0;j=e+1072|0;k=c[b+12>>2]|0;l=e|0;mrc(f|0,0,12)|0;mrc(g|0,0,12)|0;mrc(h|0,0,12)|0;m=b+28|0;n=c[(c[c[m>>2]>>2]|0)+8>>2]|0;o=k+28|0;a:do{if((c[o>>2]|0)==0){p=k+12|0;q=c[p>>2]|0;r=c[k+8>>2]|0;if((c[k+1080>>2]|0)!=0&(q|0)>(r|0)){s=c[k+4>>2]|0;c[p>>2]=s;t=s}else{t=q}q=k+12|0;if((t|0)>(r|0)){u=-541478725;i=e;return u|0}do{if((c[k+1088>>2]|0)==0){if((jX(l,1024,k+36|0,t)|0)>=0){v=l;break}if((c[q>>2]|0)>1){u=-5}else{v=l;break}i=e;return u|0}else{v=c[(c[k+1096>>2]|0)+(t<<2)>>2]|0}}while(0);q=b+1160|0;r=k+32|0;s=h|0;if((VD(s,v,1,q,0)|0)<0){KIb(b,16,2372408,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;u=-5;i=e;return u|0}p=iD(c[s>>2]|0)|0;s=p;c[f>>2]=s;do{if((c[r>>2]|0)==0){w=0;x=0}else{a[v+((lrc(v|0)|0)-1)|0]=85;p=h+4|0;if((VD(p,v,1,q,0)|0)<0){w=0;x=0;break}y=iD(c[p>>2]|0)|0;p=y;c[f+4>>2]=p;if((c[r>>2]|0)==0){w=p;x=0;break}a[v+((lrc(v|0)|0)-1)|0]=86;y=h+8|0;if((VD(y,v,1,q,0)|0)<0){w=p;x=0;break}z=iD(c[y>>2]|0)|0;y=z;c[f+8>>2]=y;if((c[r>>2]|0)==0){w=p;x=y;break}a[v+((lrc(v|0)|0)-1)|0]=87;w=p;x=y}}while(0);if((c[n+48>>2]|0)!=14){A=v;B=s;C=w;D=x;break}r=n+120|0;if((c[r>>2]|0)!=0){A=v;B=s;C=w;D=x;break}q=n+124|0;y=0;while(1){if(!(y>>>0<9>>>0)){A=v;B=s;C=w;D=x;break a}E=c[564488+(y<<3)>>2]|0;F=c[564492+(y<<3)>>2]|0;if((ca(F,E)|0)==(s|0)){break}else{y=y+1|0}}c[r>>2]=E;c[q>>2]=F;A=v;B=s;C=w;D=x}else{y=c[b+16>>2]|0;c[h>>2]=y;if((jD(y)|0)!=0){u=-5;i=e;return u|0}y=c[k+1136>>2]|0;p=f|0;if((y|0)>0){c[p>>2]=y;A=l;B=y;C=0;D=0;break}else{c[p>>2]=4096;A=l;B=4096;C=0;D=0;break}}}while(0);l=f|0;b=f+4|0;x=f+8|0;if((K1(d,C+B+D|0)|0)<0){u=-12;i=e;return u|0}c[d+32>>2]=0;D=d+36|0;c[D>>2]=c[D>>2]|1;do{if((c[k+1140>>2]|0)==0){if((c[o>>2]|0)!=0){break}D=k+16|0;B=c[D+4>>2]|0;C=d+8|0;c[C>>2]=c[D>>2];c[C+4>>2]=B}else{if((Tb(A|0,j|0)|0)==0){B=c[j+56>>2]|0;C=B;D=(B|0)<0|0?-1:0;B=d+8|0;c[B>>2]=C;c[B+4>>2]=D;B=c[k+12>>2]|0;xX(c[c[m>>2]>>2]|0,B,(B|0)<0|0?-1:0,C,D,0,0,1)|0;break}else{u=-5;i=e;return u|0}}}while(0);m=d+28|0;c[m>>2]=0;j=d+24|0;A=h|0;D=c[A>>2]|0;do{if((D|0)!=0){C=AD(D,c[j>>2]|0,c[l>>2]|0)|0;c[g>>2]=C;if((c[o>>2]|0)==0){WD(c[A>>2]|0)|0}if((C|0)<=0){break}c[m>>2]=(c[m>>2]|0)+C}}while(0);A=h+4|0;l=c[A>>2]|0;do{if((l|0)!=0){D=AD(l,(c[j>>2]|0)+(c[m>>2]|0)|0,c[b>>2]|0)|0;c[g+4>>2]=D;if((c[o>>2]|0)==0){WD(c[A>>2]|0)|0}if((D|0)<=0){break}c[m>>2]=(c[m>>2]|0)+D}}while(0);A=h+8|0;h=c[A>>2]|0;do{if((h|0)!=0){b=AD(h,(c[j>>2]|0)+(c[m>>2]|0)|0,c[x>>2]|0)|0;c[g+8>>2]=b;if((c[o>>2]|0)==0){WD(c[A>>2]|0)|0}if((b|0)<=0){break}c[m>>2]=(c[m>>2]|0)+b}}while(0);do{if((c[g>>2]|0)>=1){if((c[g+4>>2]|0)<0){break}if((c[g+8>>2]|0)<0){break}m=k+24|0;c[m>>2]=(c[m>>2]|0)+1;m=k+12|0;c[m>>2]=(c[m>>2]|0)+1;m=k+16|0;A=wrc(c[m>>2]|0,c[m+4>>2]|0,1,0)|0;c[m>>2]=A;c[m+4>>2]=G;u=0;i=e;return u|0}}while(0);P1(d);u=-5;i=e;return u|0}function rJ(a){a=a|0;var b=0;b=c[a+12>>2]|0;if((c[b+1088>>2]|0)==0){return 0}Gd(b+1092|0);return 0}function sJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;b=c[a+12>>2]|0;g=c[c[a+28>>2]>>2]|0;if((c[b+1140>>2]|0)!=0){a=CX(g,d,e,f)|0;if((a|0)<0){h=-1;return h|0}c[b+12>>2]=c[(c[g+400>>2]|0)+(a*24|0)>>2];h=0;return h|0}a=0;if((e|0)<(a|0)|(e|0)==(a|0)&d>>>0<0>>>0){h=-1;return h|0}a=c[b+8>>2]|0;g=c[b+4>>2]|0;do{if((c[b+1080>>2]|0)==0){f=a-g|0;i=(f|0)<0|0?-1:0;if((i|0)<(e|0)|(i|0)==(e|0)&f>>>0<d>>>0){h=-1}else{break}return h|0}}while(0);f=a+1-g|0;a=Drc(d,e,f,(f|0)<0|0?-1:0)|0;f=wrc(a,G,g,0)|0;c[b+12>>2]=f;f=b+16|0;c[f>>2]=d;c[f+4>>2]=e;h=0;return h|0}function tJ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[b+12>>2]|0;f=(c[c[b+28>>2]>>2]|0)+8|0;g=qKb(c[(c[f>>2]|0)+140>>2]|0)|0;h=e+16|0;CFb(h,b+32|0,1024)|0;c[e+8>>2]=c[(c[b+8>>2]|0)+28>>2]&1^1;i=c[(c[f>>2]|0)+48>>2]|0;if((i|0)==98){c[e+1048>>2]=2575176;return 0}else if((i|0)==14){i=hc(h|0,46)|0;do{if((i|0)==0){j=0}else{if((IFb(i+1|0,2556240)|0)!=0){j=0;break}if((c[b+24>>2]|0)!=1|(g|0)==0){j=0;break}if((a[g+7|0]&16)==0){j=0;break}j=(d[g+4|0]|0)>>>0>2>>>0|0}}while(0);c[e+12>>2]=j;return 0}else{return 0}return 0}function uJ(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+1136|0;h=g|0;j=g+16|0;k=g+1040|0;l=g+1048|0;m=g+1128|0;n=c[e+12>>2]|0;o=f+32|0;p=e+28|0;q=c[(c[(c[p>>2]|0)+(c[o>>2]<<2)>>2]|0)+8>>2]|0;r=qKb(c[q+140>>2]|0)|0;s=n+8|0;a:do{if((c[s>>2]|0)==0){do{if((c[n+1040>>2]|0)==0){if((c[n+1044>>2]|0)!=0){ie(k|0)|0;if((Fc(j|0,1024,n+16|0,Ab(k|0)|0)|0)!=0){break}KIb(e,16,2219144,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-22;i=g;return u|0}v=n+16|0;w=n+4|0;if((jX(j|0,1024,v,c[w>>2]|0)|0)>=0){break}x=c[w>>2]|0;if((x|0)<=1){break}KIb(e,16,2184992,(t=i,i=i+16|0,c[t>>2]=x,c[t+8>>2]=v,t)|0);i=t;u=-22;i=g;return u|0}else{CFb(j|0,n+16|0,1024)|0}}while(0);v=j|0;x=e+1160|0;w=n+12|0;y=r+4|0;do{if((VD(h|0,v,2,x,0)|0)>=0){if((c[w>>2]|0)==0){z=w;break a}if(!((d[y]|0)>>>0>1>>>0)){z=w;break a}a[j+((lrc(v|0)|0)-1)|0]=85;if((VD(h+4|0,v,2,x,0)|0)<0){break}if((c[w>>2]|0)==0){z=w;break a}if(!((d[y]|0)>>>0>2>>>0)){z=w;break a}a[j+((lrc(v|0)|0)-1)|0]=86;if((VD(h+8|0,v,2,x,0)|0)<0){break}if((c[w>>2]|0)==0){z=w;break a}if(!((d[y]|0)>>>0>3>>>0)){z=w;break a}a[j+((lrc(v|0)|0)-1)|0]=65;if((VD(h+12|0,v,2,x,0)|0)<0){break}if((c[w>>2]|0)==0){z=w;break a}if(!((d[y]|0)>>>0>4>>>0)){z=w;break a}a[j+((lrc(v|0)|0)-1)|0]=120;z=w;break a}}while(0);KIb(e,16,2156064,(t=i,i=i+8|0,c[t>>2]=v,t)|0);i=t;u=-5;i=g;return u|0}else{c[h>>2]=c[e+16>>2];z=n+12|0}}while(0);b:do{if((c[z>>2]|0)==0){j=n+1048|0;if((c[j>>2]|0)==0){dD(c[h>>2]|0,c[f+24>>2]|0,c[f+28>>2]|0);break}mrc(l|0,0,80)|0;c[m>>2]=0;if((c[z>>2]|0)!=0){KIb(0,0,2107704,(t=i,i=i+24|0,c[t>>2]=2625648,c[t+8>>2]=2599928,c[t+16>>2]=137,t)|0);i=t;Hd();return 0}k=SO(m,0,c[j>>2]|0,e+32|0)|0;if((k|0)<0){u=k;i=g;return u|0}k=ZX(c[m>>2]|0,0)|0;if((k|0)==0){pX(c[m>>2]|0);u=-12;i=g;return u|0}c[k+4>>2]=c[o>>2];c[(c[m>>2]|0)+16>>2]=c[h>>2];j=S1(l,f)|0;do{if((j|0)<0){A=j}else{w=Q1(l)|0;if((w|0)<0){A=w;break}w=nWa(c[k+8>>2]|0,c[(c[c[p>>2]>>2]|0)+8>>2]|0)|0;if((w|0)<0){A=w;break}w=TO(c[m>>2]|0,0)|0;if((w|0)<0){A=w;break}w=_O(c[m>>2]|0,l)|0;if((w|0)<0){A=w;break}w=$O(c[m>>2]|0)|0;if((w|0)<0){A=w;break}P1(l);pX(c[m>>2]|0);break b}}while(0);P1(l);pX(c[m>>2]|0);u=A;i=g;return u|0}else{k=c[q+120>>2]|0;j=c[q+124>>2]|0;v=ca(j,k)|0;w=ca(-j>>(d[r+6|0]|0),-k>>(d[r+5|0]|0))|0;if((b[r+8>>1]&16384)>>>0>14336>>>0){B=w<<1;C=v<<1}else{B=w;C=v}v=f+24|0;dD(c[h>>2]|0,c[v>>2]|0,C);w=h+4|0;dD(c[w>>2]|0,(c[v>>2]|0)+C|0,B);k=h+8|0;dD(c[k>>2]|0,(c[v>>2]|0)+(B+C)|0,B);WD(c[w>>2]|0)|0;WD(c[k>>2]|0)|0;if(!((d[r+4|0]|0)>>>0>3>>>0)){break}k=h+12|0;dD(c[k>>2]|0,(c[v>>2]|0)+((B<<1)+C)|0,C);WD(c[k>>2]|0)|0}}while(0);C=h|0;eD(c[C>>2]|0);if((c[s>>2]|0)==0){WD(c[C>>2]|0)|0}C=n+4|0;c[C>>2]=(c[C>>2]|0)+1;u=0;i=g;return u|0}function vJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a+16|0;if((FD(c[e>>2]|0)|0)!=1196444237){f=-5;i=d;return f|0}g=FD(c[e>>2]|0)|0;h=DD(c[e>>2]|0)|0;j=DD(c[e>>2]|0)|0;hD(c[e>>2]|0,8,0)|0;hD(c[e>>2]|0,2,0)|0;k=DD(c[e>>2]|0)|0;l=DD(c[e>>2]|0)|0;hD(c[e>>2]|0,22,0)|0;KIb(a,48,2321328,(a=i,i=i+40|0,c[a>>2]=g,c[a+8>>2]=h,c[a+16>>2]=j,c[a+24>>2]=k,c[a+32>>2]=l,a)|0);i=a;a=fX(c[e>>2]|0,b,g)|0;if((a|0)<0){f=a;i=d;return f|0}c[b+32>>2]=0;f=a;i=d;return f|0}function wJ(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[b+4>>2]|0;e=d+((c[b+8>>2]|0)-22)|0;b=d;while(1){if((a[b]|0)==73){if((grc(b,566384,22)|0)==0){f=100;g=5;break}}d=b+1|0;if(d>>>0<e>>>0){b=d}else{f=0;g=5;break}}if((g|0)==5){return f|0}return 0}function xJ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+112|0;f=e|0;g=e+80|0;h=e+88|0;j=c[b+12>>2]|0;k=j;l=c[b+16>>2]|0;m=h|0;AD(l,m,22)|0;n=h+1|0;o=h+21|0;while(1){if((grc(m,566384,22)|0)==0){break}orc(m|0,n|0,21)|0;a[o]=zD(l)|0;if((jD(l)|0)!=0){p=-541478725;q=17;break}}if((q|0)==17){i=e;return p|0}c[j+1088>>2]=0;q=j+32|0;c[q>>2]=0;c[q+4>>2]=0;q=j+1136|0;c[q>>2]=0;c[q+4>>2]=0;q=j+1120|0;c[q>>2]=0;c[q+4>>2]=0;q=j+1104|0;c[q>>2]=0;c[q+4>>2]=0;q=fD(l,0,0,1)|0;o=wrc(q,G,4,0)|0;q=j+1152|0;c[q>>2]=o;c[q+4>>2]=G;q=j+40|0;o=0;do{c[q+(o<<2)>>2]=-16777216;o=o+1|0;}while((o|0)<256);if((zJ(k,l,f)|0)!=2){p=-1094995529;i=e;return p|0}if((AD(l,g|0,4)|0)!=4){p=-5;i=e;return p|0}o=g+2|0;g=(d[o]|d[o+1|0]<<8)<<16>>16;fD(l,-4,-1,1)|0;do{if(g<<16>>16==3){c[j+1084>>2]=0}else{if((zJ(k,l,f)|0)==0){break}else{p=-1094995529}i=e;return p|0}}while(0);f=ZX(b,0)|0;if((f|0)==0){p=-12;i=e;return p|0}_X(f,63,1,1e6);c[j+1092>>2]=c[f>>2];l=c[f+8>>2]|0;c[l+8>>2]=0;c[l+48>>2]=40;c[l+52>>2]=0;c[l+120>>2]=c[j+20>>2];c[l+124>>2]=c[j+24>>2];c[l+792>>2]=c[j+16>>2];l=j+1084|0;if((c[l>>2]|0)==0){p=0;i=e;return p|0}f=ZX(b,0)|0;if((f|0)==0){p=-12;i=e;return p|0}b=j+1080|0;_X(f,32,1,c[b>>2]|0);c[j+1096>>2]=c[f>>2];k=c[f+8>>2]|0;c[k+8>>2]=1;f=c[l>>2]|0;c[k+48>>2]=f;c[k+52>>2]=0;l=c[j+1076>>2]|0;c[k+416>>2]=l;g=(l|0)==1;o=k+448|0;c[o>>2]=g?4:3;c[o+4>>2]=g?0:0;g=c[b>>2]|0;c[k+412>>2]=g;b=c[j+1072>>2]|0;c[k+792>>2]=b;j=ca(ca(g,l)|0,b)|0;if((f|0)==81921){r=(j|0)/2|0}else{r=j}c[k+72>>2]=r;c[k+432>>2]=ca(b,l)|0;p=0;i=e;return p|0}function yJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;while(1){a=zJ(d,e,b)|0;if((a|0)==3){f=4;break}else if((a|0)==65535){g=-1094995529;f=6;break}else if((a|0)==65533){f=3;break}else if((a|0)==65534){h=-5;break}if(!((a|0)==2|(a|0)==0)){g=-1;f=6;break}}if((f|0)==3){h=-12}else if((f|0)==4){h=0}else if((f|0)==6){h=g}return h|0}function zJ(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;j=i;i=i+8|0;k=j|0;l=i;i=i+4|0;i=i+7&-8;m=l|0;n=i;i=i+1024|0;o=n|0;p=n;q=n;r=n;s=AJ(f,g,h)|0;if((s|0)!=65532){t=s;i=j;return t|0}if((jD(g)|0)!=0){t=65534;i=j;return t|0}if((AD(g,k,4)|0)!=4){t=65535;i=j;return t|0}s=b[k>>1]|0;u=b[k+2>>1]|0;k=(u&65535)>>>0<6>>>0?u&65535:65535;a:do{if(!(s<<16>>16==0|(k|0)==65535)){u=l;v=l+3|0;w=l+2|0;x=n;y=n+4|0;z=f+8|0;A=f+1080|0;B=p+2|0;C=f+1076|0;D=f+1072|0;E=f+1084|0;F=f+20|0;H=f+24|0;I=f+16|0;J=p+6|0;K=f+1068|0;L=f+1104|0;M=f+1112|0;N=f+1064|0;O=f+1136|0;P=f+1144|0;Q=f+1120|0;R=f+1128|0;S=s&65535;b:while(1){if((jD(g)|0)!=0){T=65534;U=55;break}if((AD(g,u,4)|0)!=4){T=65535;U=55;break}V=b[m>>1]|0;W=V&65535;X=a[v]|0;S=S-4-W|0;if((S|0)<0){T=65535;U=55;break}c:do{switch(d[w]|0){case 6:case 14:case 16:case 18:case 19:case 20:case 21:{hD(g,V&65535,0)|0;break};case 1:{hD(g,V&65535,0)|0;break};case 9:{hD(g,V&65535,0)|0;break};case 13:{hD(g,V&65535,0)|0;break};case 15:{c[O>>2]=fD(g,0,0,1)|0;c[O+4>>2]=G;c[P>>2]=W;hD(g,V&65535,0)|0;break};case 17:{c[Q>>2]=fD(g,0,0,1)|0;c[Q+4>>2]=G;c[R>>2]=W;hD(g,V&65535,0)|0;break};case 12:{if((V-4&65535)>>>0>768>>>0){U=36;break b}if((AD(g,x,W)|0)!=(W|0)){U=36;break b}Y=b[q>>1]|0;Z=Y&65535;_=Z-1+(e[B>>1]|0)|0;if((Y&65535)>>>0>255>>>0|(_|0)>255){U=36;break b}if((((_-Z|0)*3|0)+7|0)>(W|0)){U=36;break b}if((Z|0)<=(_|0)){Y=4;$=Z;while(1){Z=(a[r+(Y+1)|0]<<2&255)<<8|(a[r+Y|0]<<2&255)<<16|a[r+(Y+2)|0]<<2&255;c[f+40+($<<2)>>2]=Z|Z>>>6&197379|-16777216;Z=$+1|0;if((Z|0)>(_|0)){break}else{Y=Y+3|0;$=Z}}}c[N>>2]=1;break};case 7:{hD(g,V&65535,0)|0;break};case 10:{hD(g,V&65535,0)|0;break};case 2:{if(!(X<<24>>24==0&V<<16>>16==6)){U=36;break b}if((AD(g,x,W)|0)!=(W|0)){U=36;break b}$=Erc(e[y>>1]|0,0,c[o>>2]|0,0)|0;c[z>>2]=$;c[z+4>>2]=G;break};case 3:{if((X&255)>>>0>1>>>0){U=36;break b}if((V-6&65535)>>>0>4>>>0){U=36;break b}if((AD(g,x,W)|0)!=(W|0)){U=36;break b}c[A>>2]=e[y>>1]|0;$=e[B>>1]|0;c[C>>2]=($&1)+1;Y=($>>>1<<3&8)+8|0;c[D>>2]=Y;do{if(X<<24>>24==1){if(($&4|0)==0){break}c[E>>2]=81921;break c}}while(0);if((Y|0)==16){c[E>>2]=65536;break c}else{c[E>>2]=65541;break c}break};case 4:{hD(g,V&65535,0)|0;break};case 0:{hD(g,V&65535,0)|0;break};case 5:{if((X&255)>>>0>2>>>0){U=36;break b}if((V-4&65535)>>>0>4>>>0){U=36;break b}if(X<<24>>24==2&(V&65535)>>>0<8>>>0){U=36;break b}if((AD(g,x,W)|0)!=(W|0)){U=36;break b}$=e[q>>1]<<3;_=e[B>>1]<<3;if(($|0)!=(c[F>>2]|0)){c[F>>2]=$;c[K>>2]=(c[K>>2]|0)+1}if((_|0)!=(c[H>>2]|0)){c[H>>2]=_;c[K>>2]=(c[K>>2]|0)+1}do{if(!((X&255)>>>0<2>>>0)){if((b[J>>1]|0)==0){break}c[I>>2]=16;break c}}while(0);c[I>>2]=8;break};case 8:{Y=fD(g,0,0,1)|0;c[L>>2]=Y;c[L+4>>2]=G;c[M>>2]=W;hD(g,V&65535,0)|0;break};case 11:{hD(g,V&65535,0)|0;break};default:{U=36;break b}}}while(0);if((S|0)<1|(k|0)==65535){break a}}if((U|0)==36){S=fD(g,0,0,1)|0;M=f+1152|0;c[M>>2]=S;c[M+4>>2]=G;t=65535;i=j;return t|0}else if((U|0)==55){M=fD(g,0,0,1)|0;S=f+1152|0;c[S>>2]=M;c[S+4>>2]=G;t=T;i=j;return t|0}}}while(0);T=fD(g,0,0,1)|0;U=f+1152|0;c[U>>2]=T;c[U+4>>2]=G;if(!((k|0)==3|(k|0)==1)){t=k;i=j;return t|0}t=AJ(f,g,h)|0;i=j;return t|0}function AJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=a+1104|0;g=c[f>>2]|0;h=c[f+4>>2]|0;do{if(!((g|0)==0&(h|0)==0)){j=a+1076|0;if((c[j>>2]|0)==0){break}k=a+1072|0;if((c[k>>2]|0)==0){break}l=a+1084|0;m=c[l>>2]|0;if((m|0)==0){KIb(0,16,2394616,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=65535;i=e;return o|0}else if((m|0)==81921){p=h;q=g;r=a+1112|0}else{m=wrc(g,h,6,0)|0;n=G;c[f>>2]=m;c[f+4>>2]=n;s=a+1112|0;c[s>>2]=(c[s>>2]|0)-6;p=n;q=m;r=s}fD(b,q,p,0)|0;c[f>>2]=0;c[f+4>>2]=0;s=c[r>>2]|0;if((s|0)!=(fX(b,d,s)|0)){o=65534;i=e;return o|0}c[d+32>>2]=c[a+1096>>2];s=a+1088|0;m=c[s>>2]|0;n=d+8|0;c[n>>2]=m;c[n+4>>2]=0;n=c[r>>2]|0;if((c[l>>2]|0)==81921){l=c[j>>2]|0;t=((n-6-l|0)>>>0)/(l>>>0)|0}else{t=(((n>>>0)/((c[j>>2]|0)>>>0)|0)>>>0)/((c[k>>2]|0)>>>3>>>0)|0}c[s>>2]=m+t;o=3;i=e;return o|0}}while(0);t=a+1136|0;if((c[t>>2]|0)==0&(c[t+4>>2]|0)==0){r=a+1152|0;fD(b,c[r>>2]|0,c[r+4>>2]|0,0)|0;o=65532;i=e;return o|0}r=a+1144|0;f=a+1128|0;if((K1(d,(c[f>>2]|0)+(c[r>>2]|0)|0)|0)!=0){o=65533;i=e;return o|0}p=a+1064|0;do{if((c[p>>2]|0)!=0){q=U1(d,0,1024)|0;if((q|0)==0){break}nrc(q|0,a+40|0,1024)|0;c[p>>2]=0}}while(0);p=a+1068|0;if((c[p>>2]|0)!=0){tY(d,0,0,0,0,c[a+20>>2]|0,c[a+24>>2]|0)|0;c[p>>2]=0}p=c[t+4>>2]|0;q=d+64|0;c[q>>2]=c[t>>2];c[q+4>>2]=p;fD(b,c[t>>2]|0,c[t+4>>2]|0,0)|0;c[t>>2]=0;c[t+4>>2]=0;t=d+24|0;p=AD(b,c[t>>2]|0,c[r>>2]|0)|0;if((p|0)!=(c[r>>2]|0)){P1(d);o=65534;i=e;return o|0}p=a+1120|0;fD(b,c[p>>2]|0,c[p+4>>2]|0,0)|0;c[p>>2]=0;c[p+4>>2]=0;p=AD(b,(c[t>>2]|0)+(c[r>>2]|0)|0,c[f>>2]|0)|0;if((p|0)==(c[f>>2]|0)){c[d+32>>2]=c[a+1092>>2];f=a+32|0;p=c[f+4>>2]|0;r=d+8|0;c[r>>2]=c[f>>2];c[r+4>>2]=p;p=a+8|0;a=wrc(c[f>>2]|0,c[f+4>>2]|0,c[p>>2]|0,c[p+4>>2]|0)|0;c[f>>2]=a;c[f+4>>2]=G;o=3;i=e;return o|0}else{P1(d);o=65534;i=e;return o|0}return 0}function BJ(b){b=b|0;var e=0,f=0,g=0;e=c[b+4>>2]|0;b=a[e]|0;do{if(b<<24>>24==100){if(!((a[e+1|0]|0)==-93)){break}if((a[e+3|0]|0)!=0){break}f=a[e+2|0]|0;if(f<<24>>24!=0&(f&255)>>>0<5>>>0){g=75}else{break}return g|0}}while(0);do{if((a[e+3|0]|0)==100){if(!((a[e+2|0]|0)==-93&b<<24>>24==0)){break}f=a[e+1|0]|0;if(!(f<<24>>24!=0&(f&255)>>>0<4>>>0)){break}f=e+4|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)==0){break}f=e+8|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)==0){break}else{g=75}return g|0}}while(0);g=0;return g|0}function CJ(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,l=0,m=0,n=0,o=0;b=i;d=a+16|0;e=FD(c[d>>2]|0)|0;f=0;while(1){if((f|0)>=7){h=-1094995529;j=12;break}if((e|0)==(c[335784+(f<<3)>>2]|0)){break}else{f=f+1|0}}if((j|0)==12){i=b;return h|0}j=c[335788+(f<<3)>>2]|0;if((j|0)==1){f=FD(c[d>>2]|0)|0;e=FD(c[d>>2]|0)|0;l=1408832;m=FD(c[d>>2]|0)|0;n=e;o=f}else if((j|0)==0){j=JD(c[d>>2]|0)|0;f=JD(c[d>>2]|0)|0;l=1408904;m=JD(c[d>>2]|0)|0;n=f;o=j}else{h=-1094995529;i=b;return h|0}j=~~(c[k>>2]=o,+g[k>>2]);if((n|0)==0|(j|0)==0){h=-1094995529;i=b;return h|0}o=ZX(a,0)|0;if((o|0)==0){h=-12;i=b;return h|0}f=o+8|0;e=c[f>>2]|0;c[e+8>>2]=1;c[e+416>>2]=n;c[e+412>>2]=j;j=JX(l,m)|0;c[(c[f>>2]|0)+48>>2]=j;if((j|0)==0){KIb(a,16,2321216,(a=i,i=i+8|0,c[a>>2]=m,a)|0);i=a;h=-1094995529;i=b;return h|0}else{a=g5a(j)|0;j=c[f>>2]|0;c[j+792>>2]=a;c[j+432>>2]=(ca(c[j+416>>2]|0,a)|0)/8|0;_X(o,64,1,c[j+412>>2]|0);hD(c[d>>2]|0,1008,0)|0;h=0;i=b;return h|0}return 0}function DJ(a){a=a|0;var b=0,d=0,e=0,f=0,h=0;b=i;d=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[a+24>>2]|0)!=1){KIb(a,16,2321080,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}h=IX(1408832,c[d+48>>2]|0)|0;if((h|0)==0){KIb(a,16,2266792,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}else{e=a+16|0;kD(c[e>>2]|0,107364);kD(c[e>>2]|0,(g[k>>2]=+(c[d+412>>2]|0),c[k>>2]|0));kD(c[e>>2]|0,c[d+416>>2]|0);kD(c[e>>2]|0,h);cD(c[e>>2]|0,0,1008);f=0;i=b;return f|0}return 0}function EJ(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=a[b]|0;e=(c|0)==0;a:do{if(d<<24>>24!=0&e){c=0;while(1){if(!(c>>>0<139>>>0)){break a}if((irc(b,822848+(c<<2)|0)|0)==0){f=c;break}else{c=c+1|0}}return f|0}}while(0);if(e){f=-1;return f|0}e=d<<24>>24==0?2165552:b;b=(a[e]|0)-96&255;if((b&255)>>>0>31>>>0){f=-1;return f|0}d=(a[e+1|0]|0)-96&255;if((d&255)>>>0>31>>>0){f=-1;return f|0}c=(a[e+2|0]|0)-96&255;if((c&255)>>>0>31>>>0){f=-1;return f|0}f=c&255|(d&255|(b&255)<<5)<<5;return f|0}function FJ(b,c){b=b|0;c=c|0;var e=0,f=0;e=c;y=0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;if(b>>>0>1023>>>0&(b|0)!=32767){a[c+2|0]=b&31|96;a[c+1|0]=b>>>5&31|96;a[c]=b>>>10&31|96;f=1;return f|0}if(b>>>0>138>>>0){f=0;return f|0}c=822848+(b<<2)|0;if((a[c|0]|0)==0){f=0;return f|0}b=c;y=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;f=1;return f|0}function GJ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=0;c=4;while(1){if((c|0)==0){d=b;e=4;break}f=zD(a)|0;g=f&127|b<<7;if((f&128|0)==0){d=g;e=4;break}else{b=g;c=c-1|0}}if((e|0)==4){return d|0}return 0}function HJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;c[d>>2]=zD(b)|0;d=0;a=4;while(1){if((a|0)==0){e=d;f=4;break}g=zD(b)|0;h=g&127|d<<7;if((g&128|0)==0){e=h;f=4;break}else{d=h;a=a-1|0}}if((f|0)==4){return e|0}return 0}function IJ(a,b){a=a|0;b=b|0;var d=0;d=HD(a)|0;if((b|0)!=0){c[b>>2]=d}d=zD(a)|0;if((d&128|0)!=0){HD(a)|0}if((d&64|0)!=0){b=zD(a)|0;hD(a,b,(b|0)<0|0?-1:0)|0;}if((d&32|0)==0){return}HD(a)|0;return}function JJ(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+48|0;g=f|0;h=zD(d)|0;zD(d)|0;ID(d)|0;JD(d)|0;JD(d)|0;j=b+8|0;if((a5a(c[j>>2]|0)|0)!=0){KIb(a,48,2499128,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;k=-1;i=f;return k|0}a=JX(1349600,h)|0;c[(c[j>>2]|0)+48>>2]=a;a=zD(d)|0;h=0;b=4;while(1){if((b|0)==0){l=h;break}m=zD(d)|0;n=m&127|h<<7;if((m&128|0)==0){l=n;break}else{h=n;b=b-1|0}}if((a|0)!=5){k=0;i=f;return k|0}if((l|0)==0|l>>>0>1073741824>>>0){k=-1;i=f;return k|0}kJb(c[(c[j>>2]|0)+96>>2]|0);a=QX(c[j>>2]|0,d,l)|0;if((a|0)<0){k=a;i=f;return k|0}a=c[j>>2]|0;if((c[a+48>>2]|0)!=86018){k=0;i=f;return k|0}mrc(g|0,0,44)|0;CRa(g,c[a+96>>2]|0,c[a+100>>2]<<3,1)|0;a=c[j>>2]|0;c[a+416>>2]=c[g+36>>2];l=g|0;do{if((c[l>>2]|0)==29){d=c[g+4>>2]|0;if((d|0)>=3){o=13;break}c[a+412>>2]=e[1965176+(d<<1)>>1]|0}else{o=13}}while(0);do{if((o|0)==13){d=c[g+28>>2]|0;if((d|0)==0){c[a+412>>2]=c[g+8>>2];break}else{c[a+412>>2]=d;break}}}while(0);a=JX(821688,c[l>>2]|0)|0;l=(c[j>>2]|0)+48|0;c[l>>2]=a;if((a|0)!=0){k=0;i=f;return k|0}c[l>>2]=86018;k=0;i=f;return k|0}function KJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=824112;while(1){f=e|0;g=c[f>>2]|0;h=c[f+4>>2]|0;if((g|0)==0&(h|0)==0){break}if((g|0)==(b|0)&(h|0)==(d|0)){i=4;break}else{e=e+16|0}}do{if((i|0)==4){d=c[e+8>>2]|0;if((d|0)==0){break}lD(a,d);lD(a,0);lD(a,0);return}}while(0);lD(a,65536);lD(a,b);lD(a,0);return}function LJ(a){a=a|0;var b=0;b=(krc(c[a+4>>2]|0,2155912,15)|0)==0;return(b?100:0)|0}function MJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;d=i;i=i+40|0;e=d|0;f=d+24|0;g=d+32|0;h=c[b+12>>2]|0;j=c[b+16>>2]|0;k=e|0;l=0;while(1){m=(zD(j)|0)&255;n=m<<24>>24!=0;if(m<<24>>24==32|n^1){o=n;p=l;break}q=l+1|0;a[e+l|0]=m;if((q|0)<19){l=q}else{r=3;break}}if((r|0)==3){while(1){r=0;l=(zD(j)|0)&255;m=l<<24>>24!=0;if(l<<24>>24==32|m^1){o=m;p=q;break}else{r=3}}}if(!o){zD(j)|0}a[e+p|0]=0;p=0;while(1){o=(zD(j)|0)&255;q=o<<24>>24!=0;if(o<<24>>24==32|q^1){s=q;t=p;break}u=p+1|0;a[e+p|0]=o;if((u|0)<19){p=u}else{r=9;break}}if((r|0)==9){while(1){r=0;p=(zD(j)|0)&255;o=p<<24>>24!=0;if(p<<24>>24==32|o^1){s=o;t=u;break}else{r=9}}}if(!s){zD(j)|0}a[e+t|0]=0;t=h;s=Bd(k|0,2394320,(u=i,i=i+8|0,c[u>>2]=h,u)|0)|0;i=u;if((s|0)==1){v=0}else{KIb(b,16,2320992,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;w=-1094995529;i=d;return w|0}while(1){s=(zD(j)|0)&255;o=s<<24>>24!=0;if(s<<24>>24==32|o^1){x=o;y=v;break}z=v+1|0;a[e+v|0]=s;if((z|0)<19){v=z}else{r=16;break}}if((r|0)==16){while(1){r=0;v=(zD(j)|0)&255;s=v<<24>>24!=0;if(v<<24>>24==32|s^1){x=s;y=z;break}else{r=16}}}if(!x){zD(j)|0}a[e+y|0]=0;y=0;while(1){x=(zD(j)|0)&255;z=x<<24>>24!=0;if(x<<24>>24==32|z^1){A=z;B=y;break}C=y+1|0;a[e+y|0]=x;if((C|0)<19){y=C}else{r=22;break}}if((r|0)==22){while(1){r=0;y=(zD(j)|0)&255;x=y<<24>>24!=0;if(y<<24>>24==32|x^1){A=x;B=C;break}else{r=22}}}if(!A){zD(j)|0}a[e+B|0]=0;B=0;while(1){A=(zD(j)|0)&255;C=A<<24>>24!=0;if(A<<24>>24==32|C^1){D=C;E=B;break}F=B+1|0;a[e+B|0]=A;if((F|0)<19){B=F}else{r=28;break}}if((r|0)==28){while(1){r=0;B=(zD(j)|0)&255;A=B<<24>>24!=0;if(B<<24>>24==32|A^1){D=A;E=F;break}else{r=28}}}if(!D){zD(j)|0}a[e+E|0]=0;E=Bd(k|0,2394320,(u=i,i=i+8|0,c[u>>2]=f,u)|0)|0;i=u;if((E|0)==1){G=0}else{KIb(b,16,2266648,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;w=-1094995529;i=d;return w|0}while(1){E=(zD(j)|0)&255;D=E<<24>>24!=0;if(E<<24>>24==32|D^1){H=D;I=G;break}J=G+1|0;a[e+G|0]=E;if((J|0)<19){G=J}else{r=35;break}}if((r|0)==35){while(1){r=0;G=(zD(j)|0)&255;E=G<<24>>24!=0;if(G<<24>>24==32|E^1){H=E;I=J;break}else{r=35}}}if(!H){zD(j)|0}a[e+I|0]=0;I=0;while(1){H=(zD(j)|0)&255;J=H<<24>>24!=0;if(H<<24>>24==32|J^1){K=J;L=I;break}M=I+1|0;a[e+I|0]=H;if((M|0)<19){I=M}else{r=41;break}}if((r|0)==41){while(1){r=0;I=(zD(j)|0)&255;H=I<<24>>24!=0;if(I<<24>>24==32|H^1){K=H;L=M;break}else{r=41}}}if(!K){zD(j)|0}a[e+L|0]=0;L=Bd(k|0,2394320,(u=i,i=i+8|0,c[u>>2]=g,u)|0)|0;i=u;if((L|0)==1){N=0}else{KIb(b,16,2218624,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;w=-1094995529;i=d;return w|0}while(1){L=(zD(j)|0)&255;k=L<<24>>24!=0;if(L<<24>>24==32|k^1){O=k;P=N;break}Q=N+1|0;a[e+N|0]=L;if((Q|0)<19){N=Q}else{r=48;break}}if((r|0)==48){while(1){r=0;N=(zD(j)|0)&255;L=N<<24>>24!=0;if(N<<24>>24==32|L^1){O=L;P=Q;break}else{r=48}}}if(!O){zD(j)|0}a[e+P|0]=0;P=0;while(1){O=(zD(j)|0)&255;Q=O<<24>>24!=0;if(O<<24>>24==32|Q^1){R=Q;S=P;break}T=P+1|0;a[e+P|0]=O;if((T|0)<19){P=T}else{r=54;break}}if((r|0)==54){while(1){r=0;P=(zD(j)|0)&255;O=P<<24>>24!=0;if(P<<24>>24==32|O^1){R=O;S=T;break}else{r=54}}}if(!R){zD(j)|0}a[e+S|0]=0;S=0;while(1){R=(zD(j)|0)&255;T=R<<24>>24!=0;if(R<<24>>24==32|T^1){U=T;V=S;break}W=S+1|0;a[e+S|0]=R;if((W|0)<19){S=W}else{r=60;break}}if((r|0)==60){while(1){r=0;S=(zD(j)|0)&255;R=S<<24>>24!=0;if(S<<24>>24==32|R^1){U=R;V=W;break}else{r=60}}}if(!U){zD(j)|0}a[e+V|0]=0;V=c[t>>2]|0;if((V|0)<1){KIb(b,16,2184688,(u=i,i=i+8|0,c[u>>2]=V,u)|0);i=u;w=-1094995529;i=d;return w|0}u=fD(j,0,0,1)|0;c[h+4>>2]=u;u=ZX(b,0)|0;if((u|0)==0){w=-12;i=d;return w|0}b=c[u+8>>2]|0;c[b+8>>2]=1;c[b+48>>2]=69659;h=b+416|0;if((c[f>>2]|0)==0){c[h>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;X=1}else{c[h>>2]=2;h=b+448|0;c[h>>2]=3;c[h+4>>2]=0;X=2}h=b+412|0;c[h>>2]=44100;f=c[g>>2]|0;if((f|0)>0){g=44100/(f|0)|0;c[h>>2]=g;Y=g}else{Y=44100}c[b+792>>2]=4;c[b+72>>2]=(ca(Y,X)|0)<<2;c[b+432>>2]=c[t>>2];_X(u,32,1,Y);w=0;i=d;return w|0}function NJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=a+16|0;f=d;g=fX(c[e>>2]|0,b,c[f>>2]|0)|0;if((g|0)!=(c[f>>2]|0)){h=-5;return h|0}c[b+32>>2]=0;f=fD(c[e>>2]|0,0,0,1)|0;e=c[d+4>>2]|0;d=xrc(f,G,e,(e|0)<0|0?-1:0)|0;e=G;f=b+8|0;c[f>>2]=d;c[f+4>>2]=e;b=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+416>>2]|0;if((b|0)<=0){h=0;return h|0}a=b<<1;b=Crc(d,e,a,(a|0)<0|0?-1:0)|0;c[f>>2]=b;c[f+4>>2]=G;h=0;return h|0}function OJ(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==1){if((a[d+1|0]|0)!=1){break}if((a[d+2|0]|0)!=3){break}if(!((a[d+3|0]|0)==-72)){break}if(!((a[d+4|0]|0)==-128)){break}if((a[d+5|0]|0)==96){e=98}else{break}return e|0}}while(0);e=0;return e|0}function PJ(a){a=a|0;var b=0,d=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=13;c[b+236>>2]=1;_X(b,64,1,9e4);d=0;return d|0}function QJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=a+16|0;f=b+8|0;g=b+64|0;h=0;j=0;a:while(1){if((h|0)!=0){break}while(1){k=HD(c[e>>2]|0)|0;l=HD(c[e>>2]|0)|0;m=HD(c[e>>2]|0)|0;HD(c[e>>2]|0)|0;n=JD(c[e>>2]|0)|0;JD(c[e>>2]|0)|0;o=l-12|0;if((o|0)<1){p=-1;q=14;break a}r=m&128;if((k|0)!=258){break}hD(c[e>>2]|0,o,(o|0)<0|0?-1:0)|0;}k=c[e>>2]|0;if((j|0)==0){m=fX(k,b,o)|0;if((m|0)<0){p=m;q=14;break}c[f>>2]=n;c[f+4>>2]=(n|0)<0|0?-1:0;l=wrc(c[g>>2]|0,c[g+4>>2]|0,-16,-1)|0;c[g>>2]=l;c[g+4>>2]=G;s=1;t=m}else{u=hX(k,b,o)|0;if((u|0)<0){q=10;break}else{s=j;t=u}}if((t|0)<(o|0)){q=12;break}else{h=r;j=s}}if((q|0)==10){KIb(a,16,2394296,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;P1(b);p=u;i=d;return p|0}else if((q|0)==12){KIb(a,16,2320952,(v=i,i=i+16|0,c[v>>2]=t,c[v+8>>2]=o,v)|0);i=v;v=b+36|0;c[v>>2]=c[v>>2]|2}else if((q|0)==14){i=d;return p|0}c[b+32>>2]=0;p=0;i=d;return p|0}function RJ(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1179208516){e=b+4|0;if(!((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==0)){break}e=b+6|0;if((d[e]|d[e+1|0]<<8)<<16>>16<<16>>16==32){f=98}else{break}return f|0}}while(0);f=0;return f|0}function SJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a+16|0;FD(c[d>>2]|0)|0;DD(c[d>>2]|0)|0;DD(c[d>>2]|0)|0;e=ZX(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=e+8|0;c[(c[g>>2]|0)+8>>2]=0;h=FD(c[d>>2]|0)|0;c[(c[g>>2]|0)+52>>2]=h;j=JX(1409152,h)|0;c[(c[g>>2]|0)+48>>2]=j;j=DD(c[d>>2]|0)|0;c[(c[g>>2]|0)+120>>2]=j;j=DD(c[d>>2]|0)|0;c[(c[g>>2]|0)+124>>2]=j;j=FD(c[d>>2]|0)|0;g=FD(c[d>>2]|0)|0;h=GD(c[d>>2]|0)|0;d=e+56|0;c[d>>2]=h;c[d+4>>2]=G;c[e+236>>2]=2;if((j|0)==0|(g|0)==0){KIb(a,16,2394168,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-1094995529;i=b;return f|0}else{_X(e,64,g,j);f=0;i=b;return f|0}return 0}function TJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+16|0;a=FD(c[d>>2]|0)|0;e=GD(c[d>>2]|0)|0;f=G;g=fX(c[d>>2]|0,b,a)|0;c[b+32>>2]=0;a=b+8|0;c[a>>2]=e;c[a+4>>2]=f;f=b+64|0;b=wrc(c[f>>2]|0,c[f+4>>2]|0,-12,-1)|0;c[f>>2]=b;c[f+4>>2]=G;return g|0}function UJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+16>>2]|0;if((c[a+24>>2]|0)!=1){KIb(a,16,2394096,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}g=a+28|0;h=c[(c[c[g>>2]>>2]|0)+8>>2]|0;do{if((c[h+8>>2]|0)==0){if((c[h+48>>2]|0)!=141){break}dD(d,2266640,4);oD(d,0);oD(d,32);j=c[h+52>>2]|0;kD(d,(j|0)==0?808996950:j);oD(d,c[h+120>>2]|0);oD(d,c[h+124>>2]|0);kD(d,c[(c[c[g>>2]>>2]|0)+44>>2]|0);kD(d,c[(c[c[g>>2]>>2]|0)+40>>2]|0);j=(c[c[g>>2]>>2]|0)+56|0;rD(d,c[j>>2]|0,c[j+4>>2]|0);f=0;i=b;return f|0}}while(0);KIb(a,16,2320896,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}function VJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=c[a+16>>2]|0;a=b+28|0;kD(d,c[a>>2]|0);e=b+8|0;rD(d,c[e>>2]|0,c[e+4>>2]|0);dD(d,c[b+24>>2]|0,c[a>>2]|0);return 0}function WJ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=c[b+4>>2]|0;k=j+(c[b+8>>2]|0)|0;b=((d[j+1|0]|0)<<8|(d[j]|0)<<16|(d[j+2|0]|0)|0)==15711167?j+3|0:j;if(b>>>0<k>>>0){l=b}else{m=0;i=e;return m|0}while(1){b=a[l]|0;if(b<<24>>24==32|(b-9&255)>>>0<5>>>0){l=l+1|0;continue}if(!(b<<24>>24==35)){break}b=mc(l|0,2463888)|0;j=a[l+b|0]|0;if(j<<24>>24==13){n=b+1|0;o=n;p=a[l+n|0]|0}else{o=b;p=j}j=l+((p<<24>>24==10)+o)|0;if(j>>>0<k>>>0){l=j}else{m=0;q=11;break}}if((q|0)==11){i=e;return m|0}q=Bd(l|0,2483128,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k;if((q|0)==1){m=51;i=e;return m|0}q=Bd(l|0,2471880,(k=i,i=i+24|0,c[k>>2]=g,c[k+8>>2]=h,c[k+16>>2]=f,k)|0)|0;i=k;if((q|0)!=3){m=0;i=e;return m|0}m=(c[g>>2]|0)<(c[h>>2]|0)?51:0;i=e;return m|0}function XJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;d=i;i=i+1680|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+72|0;p=d+80|0;q=d+88|0;r=d+96|0;s=d+104|0;t=d+112|0;u=d+120|0;v=d+128|0;w=d+136|0;x=d+144|0;y=d+1168|0;z=c[b+16>>2]|0;A=c[b+12>>2]|0;B=ZX(b,0)|0;if((B|0)==0){C=-12;i=d;return C|0}_X(B,64,1,100);b=B+8|0;B=c[b>>2]|0;c[B+8>>2]=3;c[B+48>>2]=1246975298;B=A+4|0;c[B>>2]=30;SFb(x,1040,4096);a:do{if((jD(z)|0)==0){D=y|0;E=A;F=A+8|0;H=0;I=0;b:while(1){J=fD(z,0,0,1)|0;K=G;L=KD(z,D,512)|0;M=D;while(1){N=a[M]|0;O=M+1|0;if(N<<24>>24==32|(N-9&255)>>>0<5>>>0){M=O}else{break}}c:do{if((H|0)==0){N=Bd(M|0,2483128,(P=i,i=i+8|0,c[P>>2]=j,P)|0)|0;i=P;if((N|0)==1){Q=10;break}N=Bd(M|0,2471880,(P=i,i=i+24|0,c[P>>2]=k,c[P+8>>2]=l,c[P+16>>2]=j,P)|0)|0;i=P;if((N|0)==3){if((c[k>>2]|0)<(c[l>>2]|0)){Q=10;break}}if((a[M]|0)!=35){R=I;S=0;break}N=a[O]|0;T=(N-97|0)>>>0<26>>>0?N^32:N;N=0;while(1){if(!(N>>>0<10>>>0)){R=I;S=0;break c}U=c[1703480+(N<<2)>>2]|0;if((T|0)==(a[U]|0)){break}else{N=N+1|0}}if((N|0)==-1){R=I;S=0;break}T=lrc(U|0)|0;if((JFb(O,U,T)|0)==0){V=M+(T+1)|0}else{V=M+2|0}while(1){T=a[V]|0;if(T<<24>>24==32|(T-9&255)>>>0<5>>>0){V=V+1|0}else{break}}N=a[U]|0;if((N|0)==84){T=rb(V|0,0,10)|0;c[B>>2]=T;if((T|0)==0){c[B>>2]=30;R=I;S=0;break}else{UFb(x,2266584,(P=i,i=i+8|0,c[P>>2]=V,P)|0);i=P;R=I;S=0;break}}else if((N|0)!=83){R=I;S=0;break}if((I|0)==0){N=c[B>>2]|0;c[e>>2]=0;c[f>>2]=0;c[g>>2]=0;c[h>>2]=0;T=Bd(V|0,2155856,(P=i,i=i+32|0,c[P>>2]=e,c[P+8>>2]=f,c[P+16>>2]=g,c[P+24>>2]=h,P)|0)|0;i=P;W=c[e>>2]|0;if((a[V]|0)==45|(W|0)<0){X=(W|0)>-1?W:-W|0;c[e>>2]=X;Y=-1;Z=X}else{Y=1;Z=W}if((T|0)==4){W=ca(((c[f>>2]|0)*60|0)+(Z*3600|0)+(c[g>>2]|0)|0,N)|0;_=ca(W+(c[h>>2]|0)|0,Y)|0}else if((T|0)==3){W=ca((c[f>>2]|0)+(Z*60|0)|0,N)|0;_=ca(W+(c[g>>2]|0)|0,Y)|0}else if((T|0)==2){T=ca(Z,N)|0;_=ca((c[f>>2]|0)+T|0,Y)|0}else{_=0}c[E>>2]=_;$=1}else{$=I}UFb(x,2320816,(P=i,i=i+8|0,c[P>>2]=V,P)|0);i=P;R=$;S=0}else{Q=10}}while(0);do{if((Q|0)==10){Q=0;M=IV(F,D,L,H)|0;if((M|0)==0){C=-12;break b}T=M+64|0;c[T>>2]=J;c[T+4>>2]=K;if((L|0)<=1){R=I;S=0;break}R=I;S=(irc(y+(L-2)|0,2394016)|0)==0|0}}while(0);if((jD(z)|0)==0){H=S;I=R}else{break a}}i=d;return C|0}}while(0);R=T5a(c[b>>2]|0,x)|0;if((R|0)<0){C=R;i=d;return C|0}R=A+8|0;x=A+12|0;if((c[x>>2]|0)>0){b=R;S=A;A=0;do{z=c[b>>2]|0;y=c[z+(A*80|0)+24>>2]|0;$=z+(A*80|0)+8|0;V=z+(A*80|0)+48|0;z=Bd(y|0,2218528,(P=i,i=i+72|0,c[P>>2]=n,c[P+8>>2]=o,c[P+16>>2]=p,c[P+24>>2]=q,c[P+32>>2]=r,c[P+40>>2]=s,c[P+48>>2]=t,c[P+56>>2]=u,c[P+64>>2]=m,P)|0)|0;i=P;do{if((z|0)==8){_=c[B>>2]|0;Y=ca(((c[o>>2]|0)*60|0)+((c[n>>2]|0)*3600|0)+(c[p>>2]|0)|0,_)|0;f=Y+(c[q>>2]|0)|0;c[v>>2]=f;Y=ca(((c[s>>2]|0)*60|0)+((c[r>>2]|0)*3600|0)+(c[t>>2]|0)|0,_)|0;Z=Y+(c[u>>2]|0)|0;c[w>>2]=Z;aa=f;ba=_;da=Z;Q=43}else{Z=Bd(y|0,2184656,(P=i,i=i+24|0,c[P>>2]=v,c[P+8>>2]=w,c[P+16>>2]=m,P)|0)|0;i=P;if((Z|0)!=2){break}aa=c[v>>2]|0;ba=c[B>>2]|0;da=c[w>>2]|0;Q=43}}while(0);if((Q|0)==43){Q=0;y=c[S>>2]|0;z=(((y+aa|0)*100|0)>>>0)/(ba>>>0)|0;c[v>>2]=z;Z=(((y+da|0)*100|0)>>>0)/(ba>>>0)|0;c[w>>2]=Z;c[$>>2]=z;c[$+4>>2]=(z|0)<0|0?-1:0;c[V>>2]=Z+z}A=A+1|0;}while((A|0)<(c[x>>2]|0))}JV(R);C=0;i=d;return C|0}function YJ(a,b){a=a|0;b=b|0;return MV((c[a+12>>2]|0)+8|0,b)|0}function ZJ(a){a=a|0;OV((c[a+12>>2]|0)+8|0);return 0}function _J(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV((c[a+12>>2]|0)+8|0,a,b,d,e,f,g,h,i,j)|0}function $J(a){a=a|0;var b=0,d=0,e=0;b=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;d=c[b+100>>2]|0;if((d|0)==0){return 0}e=a+16|0;dD(c[e>>2]|0,c[b+96>>2]|0,d-1|0);eD(c[e>>2]|0);return 0}function aK(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==74){if((a[d+1|0]|0)!=86){break}if(!(((c[b+8>>2]|0)-4|0)>>>0>74>>>0)){break}if((grc(d+4|0,2320448,75)|0)==0){e=100}else{break}return e|0}}while(0);e=0;return e|0}function bK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;d=a+12|0;e=c[d>>2]|0;f=c[a+16>>2]|0;hD(f,80,0)|0;g=ZX(a,0)|0;h=ZX(a,0)|0;if((g|0)==0|(h|0)==0){j=-12;i=b;return j|0}k=h+8|0;l=c[k>>2]|0;c[l+8>>2]=0;c[l+48>>2]=150;c[l+52>>2]=0;l=DD(f)|0;c[(c[k>>2]|0)+120>>2]=l;l=DD(f)|0;c[(c[k>>2]|0)+124>>2]=l;l=DD(f)|0;k=g+404|0;c[k>>2]=l;m=l;n=(l|0)<0|0?-1:0;l=h+64|0;c[l>>2]=m;c[l+4>>2]=n;l=h+56|0;c[l>>2]=m;c[l+4>>2]=n;_X(h,64,DD(f)|0,1e3);hD(f,4,0)|0;h=g+8|0;n=c[h>>2]|0;c[n+8>>2]=1;c[n+48>>2]=65541;c[n+52>>2]=0;n=DD(f)|0;l=c[h>>2]|0;c[l+412>>2]=n;c[l+416>>2]=1;h=l+448|0;c[h>>2]=4;c[h+4>>2]=0;_X(g,64,1,n);hD(f,10,0)|0;n=hJb((c[k>>2]|0)*24|0)|0;h=g+400|0;c[h>>2]=n;if((n|0)==0){j=-12;i=b;return j|0}n=hJb(c[k>>2]<<4)|0;g=n;l=e;c[l>>2]=g;if((n|0)==0){j=-12;i=b;return j|0}n=c[k>>2]|0;a:do{if((n|0)>0){m=(n<<4)+104|0;o=a+1156|0;p=a;q=(m|0)<0|0?-1:0;r=m;m=0;s=0;t=0;u=g;while(1){v=c[h>>2]|0;w=(FD(f)|0)<<2;x=v+(m*24|0)+16|0;c[x>>2]=c[x>>2]&3|w;y=v+(m*24|0)+8|0;c[y>>2]=m;c[y+4>>2]=(m|0)<0|0?-1:0;z=v+(m*24|0)|0;c[z>>2]=r;c[z+4>>2]=q;z=w>>2;w=wrc(z,(z|0)<0|0?-1:0,r,q)|0;z=G;v=u+(m<<4)|0;c[v>>2]=FD(f)|0;A=u+(m<<4)+4|0;c[A>>2]=FD(f)|0;B=(zD(f)|0)!=0;C=B?768:0;B=u+(m<<4)+8|0;c[B>>2]=C;D=c[A>>2]|0;E=c[v>>2]|0;if((E|D)>>>0>16777215>>>0){F=8}else{if(((c[x>>2]>>2)-(E+D+C)|0)<0){F=8}}if((F|0)==8){F=0;if((c[o>>2]&8|0)!=0){break}c[B>>2]=0;c[A>>2]=0;c[v>>2]=0}if((zD(f)|0)!=0){KIb(p,24,2393752,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A}A=u+(m<<4)+12|0;c[A>>2]=zD(f)|0;hD(f,1,0)|0;B=c[v>>2]|0;v=(B|0)!=0;c[y>>2]=v?t:0;c[y+4>>2]=v?s:-2147483648;c[x>>2]=c[x>>2]&-4|(c[A>>2]|0)!=1;A=m+1|0;if((A|0)>=(c[k>>2]|0)){break a}x=wrc(B,(B|0)<0|0?-1:0,t,s)|0;q=z;r=w;m=A;s=G;t=x;u=c[l>>2]|0}mJb(c[d>>2]|0);j=-1094995529;i=b;return j|0}}while(0);c[e+4>>2]=0;j=0;i=b;return j|0}function cK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0;e=c[b+12>>2]|0;f=b+16|0;g=c[f>>2]|0;h=c[c[b+28>>2]>>2]|0;a:do{if((jD(g)|0)==0){b=e+8|0;i=h+404|0;j=h+400|0;k=e;l=e+4|0;while(1){m=c[b>>2]|0;n=c[b+4>>2]|0;o=c[i>>2]|0;p=(o|0)<0|0?-1:0;if(!((n|0)<(p|0)|(n|0)==(p|0)&m>>>0<o>>>0)){break a}q=c[j>>2]|0;r=m;s=c[k>>2]|0;m=s+(r<<4)|0;o=c[l>>2]|0;if((o|0)==0){c[l>>2]=1;t=c[m>>2]|0;if((t|0)==0){u=9}else{u=7;break}}else if((o|0)==1){u=9}else if((o|0)==2){v=c[s+(r<<4)+4>>2]|0;w=c[s+(r<<4)+8>>2]|0;u=17}if((u|0)==9){u=0;c[l>>2]=2;x=s+(r<<4)+4|0;z=c[x>>2]|0;A=c[s+(r<<4)+8>>2]|0;if((z|A|0)==0){v=0;w=0;u=17}else{break}}if((u|0)==17){u=0;o=(c[q+(r*24|0)+16>>2]>>2)-(c[m>>2]|0)-v-w|0;m=(o|0)>0;hD(g,m?o:0,m?(o|0)<0|0?-1:0:0)|0;c[l>>2]=0;o=wrc(c[b>>2]|0,c[b+4>>2]|0,1,0)|0;c[b>>2]=o;c[b+4>>2]=G}if((jD(c[f>>2]|0)|0)!=0){break a}}if((u|0)==7){if((fX(c[f>>2]|0,d,t)|0)<0){B=-12;return B|0}c[d+32>>2]=0;l=q+(r*24|0)+8|0;k=c[l+4>>2]|0;j=d+8|0;c[j>>2]=c[l>>2];c[j+4>>2]=k;k=d+36|0;c[k>>2]=c[k>>2]|1;B=0;return B|0}k=A+z|0;if((K1(d,k+5|0)|0)!=0){B=-12;return B|0}j=d+24|0;l=c[j>>2]|0;y=c[x>>2]|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=s+(r<<4)+12|0;a[(c[j>>2]|0)+4|0]=c[l>>2];i=AD(g,(c[j>>2]|0)+5|0,k)|0;if((i|0)<0){B=i;return B|0}if((i|0)<(k|0)){k=i+5|0;mrc((c[j>>2]|0)+k|0,0,16)|0;j=d+36|0;c[j>>2]=c[j>>2]|2;C=k}else{C=i+5|0}c[d+28>>2]=C;c[d+32>>2]=1;i=c[b+4>>2]|0;k=d+8|0;c[k>>2]=c[b>>2];c[k+4>>2]=i;if((c[l>>2]|0)==1){B=0;return B|0}l=d+36|0;c[l>>2]=c[l>>2]|1;B=0;return B|0}}while(0);B=(c[(c[f>>2]|0)+52>>2]|0)==0?-5:-541478725;return B|0}function dK(a){a=a|0;mJb(c[a+12>>2]|0);return 0}function eK(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[a+12>>2]|0;h=c[c[a+28>>2]>>2]|0;if((f&10|0)!=0){i=-38;return i|0}if((b|0)==1){j=d}else if((b|0)==0){j=CX(h,d,e,f)|0}else{i=0;return i|0}if((j|0)<0){i=0;return i|0}if((j|0)>=(c[h+404>>2]|0)){i=0;return i|0}f=(c[h+400>>2]|0)+(j*24|0)|0;h=fD(c[a+16>>2]|0,c[f>>2]|0,c[f+4>>2]|0,0)|0;f=G;a=0;if((f|0)<(a|0)|(f|0)==(a|0)&h>>>0<0>>>0){i=-1;return i|0}c[g+4>>2]=0;h=g+8|0;c[h>>2]=j;c[h+4>>2]=(j|0)<0|0?-1:0;i=0;return i|0}function fK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+48|0;d=b|0;e=c[a+12>>2]|0;f=c[(c[c[a+28>>2]>>2]|0)+8>>2]|0;if((c[f+48>>2]|0)==86066){g=0;i=b;return g|0}a=c[f+100>>2]|0;if((a|0)<=0){g=0;i=b;return g|0}h=c[f+96>>2]|0;if((a|0)>1024){KIb(e,16,2184584,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;g=-1094995529;i=b;return g|0}f=CRa(d,h,a<<3,1)|0;c[e+4>>2]=f;if((f|0)<0){g=-1094995529;i=b;return g|0}a=e+12|0;do{if((c[a>>2]|0)==36){if((f&7|0)==0){break}KIb(e,16,2155816,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;g=-1094995529;i=b;return g|0}}while(0);f=c[d>>2]|0;if((f|0)<6|(f|0)==36){c[e+8>>2]=c[d+12>>2];c[a>>2]=f;g=0;i=b;return g|0}else{KIb(e,16,2130688,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;g=-1094995529;i=b;return g|0}return 0}function gK(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;f=i;i=i+56|0;g=f|0;h=f+24|0;j=f+48|0;k=j;l=c[b+12>>2]|0;m=c[b+16>>2]|0;c[j>>2]=57430;n=c[b+28>>2]|0;o=c[(c[n>>2]|0)+8>>2]|0;if((c[o+48>>2]|0)==86066){p=zS(b,e)|0;i=f;return p|0}q=e+28|0;r=c[q>>2]|0;s=(r|0)>2;do{if(s){t=c[e+24>>2]|0;if(!((a[t]|0)==-1)){break}if(!((a[t+1|0]&-16)<<24>>24==-16)){break}KIb(b,16,2266352,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;p=-1094995529;i=f;return p|0}}while(0);if((c[o+96>>2]|0)==0){if(!s){p=-1094995529;i=f;return p|0}s=c[e+24>>2]|0;if((a[s]|0)!=86){p=-1094995529;i=f;return p|0}o=s+1|0;if(!((a[o]&-16)<<24>>24==-32)){p=-1094995529;i=f;return p|0}s=o;if((((he((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&8191)+3|0)!=(r|0)){p=-1094995529;i=f;return p|0}p=zS(b,e)|0;i=f;return p|0}do{if((r|0)<=8191){s=l+24|0;o=r+2048|0;t=(o|0)<0;v=t?0:s;w=t?0:o;c[h+20>>2]=w<<3;o=h+8|0;c[o>>2]=v;c[h+16>>2]=v+w;w=h+12|0;c[w>>2]=v;v=h+4|0;c[v>>2]=32;t=h|0;c[t>>2]=0;x=c[(c[n>>2]|0)+8>>2]|0;z=l+16|0;A=(c[z>>2]|0)!=0|0;c[t>>2]=A;c[v>>2]=31;B=c[z>>2]|0;if((B|0)==0){c[t>>2]=A<<15|8192;c[v>>2]=16;do{if((c[l+12>>2]|0)==36){A=c[l+4>>2]>>3;_2(h,(c[x+96>>2]|0)+A|0,(c[x+100>>2]|0)-A|0)}else{A=x+96|0;C=l+4|0;_2(h,c[A>>2]|0,(c[C>>2]|0)+3|0);if((c[l+8>>2]|0)!=0){break}D=c[A>>2]|0;A=c[x+100>>2]|0;E=A>>>0>268435455>>>0?-8:A<<3;A=E>>>0>2147483639>>>0|(D|0)==0;F=A?0:D;D=A?0:E;c[g>>2]=F;c[g+12>>2]=D;E=D+8|0;c[g+16>>2]=E;c[g+4>>2]=F+(D>>3);D=g+8|0;c[D>>2]=0;F=(c[C>>2]|0)+3|0;if((F|0)<0){G=0}else{G=(E|0)<(F|0)?E:F}c[D>>2]=G;DRa(h,g)|0}}while(0);x=c[t>>2]|0;D=c[v>>2]|0;if((D|0)>3){H=D-3|0;I=x<<3}else{F=je(x<<D|0)|0;x=c[w>>2]|0;y=F;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;H=D+29|0;I=0}c[t>>2]=I;c[v>>2]=H;if((H|0)>8){J=H-8|0;K=I<<8|255}else{D=je(255>>>((8-H|0)>>>0)|I<<H|0)|0;x=c[w>>2]|0;y=D;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;J=H+24|0;K=255}c[t>>2]=K;c[v>>2]=J;if((J|0)>1){L=J-1|0;M=K<<1}else{x=je(K<<J|0)|0;D=c[w>>2]|0;y=x;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;L=J+31|0;M=0}c[t>>2]=M;c[v>>2]=L;if((L|0)>1){N=L-1|0;O=M<<1}else{D=je(M<<L|0)|0;x=c[w>>2]|0;y=D;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;N=L+31|0;O=0}c[t>>2]=O;c[v>>2]=N;P=c[z>>2]|0}else{P=B}c[z>>2]=(P+1|0)%(c[l+20>>2]|0)|0;x=c[q>>2]|0;D=c[t>>2]|0;F=c[v>>2]|0;if((x-255|0)<0){Q=0;R=x;S=D;T=F}else{E=0;C=D;D=F;F=x;while(1){if((D|0)>8){U=D-8|0;V=C<<8|255;W=F}else{x=je(255>>>((8-D|0)>>>0)|C<<D|0)|0;A=c[w>>2]|0;y=x;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;U=D+24|0;V=255;W=c[q>>2]|0}c[t>>2]=V;c[v>>2]=U;A=E+255|0;if((A|0)>(W-255|0)){Q=A;R=W;S=V;T=U;break}else{E=A;C=V;D=U;F=W}}}F=R-Q|0;if((T|0)>8){X=T-8|0;Y=S<<8|F;Z=R}else{D=je(F>>>((8-T|0)>>>0)|S<<T|0)|0;C=c[w>>2]|0;y=D;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;X=T+24|0;Y=F;Z=c[q>>2]|0}c[t>>2]=Y;c[v>>2]=X;F=e+24|0;C=c[F>>2]|0;do{if((Z|0)==0){_=48}else{D=d[C]|0;if((D&225|0)!=129){_=48;break}E=D&254;if((X|0)>8){$=X-8|0;aa=Y<<8|E;ba=C;ca=Z}else{D=je(Y<<X|E>>>((8-X|0)>>>0)|0)|0;z=c[w>>2]|0;y=D;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;$=X+24|0;aa=E;ba=c[F>>2]|0;ca=c[q>>2]|0}c[t>>2]=aa;c[v>>2]=$;_2(h,ba+1|0,(ca<<3)-8|0)}}while(0);if((_|0)==48){_2(h,C,Z<<3)}Y2(h);F=c[v>>2]|0;if((F|0)<32){E=c[t>>2]<<F;c[t>>2]=E;F=E>>>24&255;while(1){E=c[w>>2]|0;c[w>>2]=E+1;a[E]=F;E=c[t>>2]|0;c[t>>2]=E<<8;z=(c[v>>2]|0)+8|0;c[v>>2]=z;if((z|0)<32){F=E>>>16&255}else{break}}}c[v>>2]=32;c[t>>2]=0;F=(c[w>>2]|0)-(c[o>>2]|0)|0;C=F<<3;E=C>>3;if((C|0)>65528){break}C=k+1|0;a[C]=d[C]|F>>>8&31;F=k+2|0;a[F]=d[F]|E;dD(m,j,3);dD(m,s,E);p=0;i=f;return p|0}}while(0);KIb(b,16,2218368,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;p=-1094995529;i=f;return p|0}function hK(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+4>>2]|0;a=b+2|0;e=(d[a]|d[a+1|0]<<8)<<16>>16;a=he(e|0)|0;f=b+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=je(g|0)|0;h=b;do{if(f>>>0<1048577>>>0&(((a&65535)>>>0>4>>>0|(d[h]|d[h+1|0]<<8)<<16>>16<<16>>16!=0|(g|0)==0|e<<16>>16==768)^1)){i=b+8|0;if(e<<16>>16==1024){j=i;k=((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-4;l=k?33:0;return l|0}else{if(((d[b+9|0]|0)<<8|(d[i]|0)<<16|(d[b+10|0]|0)|0)==1){l=20}else{break}return l|0}}}while(0);l=0;return l|0}function iK(a){a=a|0;var b=0,d=0,e=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=0;c[e+48>>2]=13;c[b+236>>2]=2;_X(b,64,1001,3e4);b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=86016;c[b+236>>2]=2;d=0;return d|0}function jK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=c[a+16>>2]|0;HD(e)|0;f=HD(e)|0;g=JD(e)|0;if(f>>>0>4>>>0|(f|0)==3){KIb(a,16,2393576,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-5;i=d;return j|0}if((g-9|0)>>>0>1048567>>>0){KIb(a,16,2320288,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h;j=-5;i=d;return j|0}h=fX(e,b,g-8|0)|0;if((h|0)<1){j=-5;i=d;return j|0}hD(e,-g&511,0)|0;if((f|0)==4){c[b+32>>2]=1;j=h;i=d;return j|0}else if((f|0)==0){c[b+36>>2]=1}else if(!((f|0)==1|(f|0)==2)){j=h;i=d;return j|0}c[b+32>>2]=0;j=h;i=d;return j|0}function kK(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+4>>2]|0;e=(c[a+8>>2]|0)-3|0;a=b+e|0;do{if((e|0)>0){f=a;g=0;h=b;i=0;do{a:do{if(h>>>0<a>>>0){j=0;k=h;while(1){l=(d[k+1|0]|0)<<8;if((l&57344|(d[k]|0)<<16|0)!=5693440){m=j;n=k;break a}o=(d[k+2|0]|0|l&7936)+3|0;if(o>>>0<7>>>0){m=j;n=k;break a}l=f-k|0;p=k+((o|0)>(l|0)?l:o)|0;o=j+1|0;if(p>>>0<a>>>0){j=o;k=p}else{m=o;n=p;break}}}else{m=0;n=h}}while(0);i=(i|0)>(m|0)?i:m;g=(h|0)==(b|0)?m:g;h=n+1|0;}while(h>>>0<a>>>0);if((g|0)>2){q=51;return q|0}if((i|0)>100){q=50}else{r=i;break}return q|0}else{r=0}}while(0);q=(r|0)>2?25:0;return q|0}function lK(a){a=a|0;var b=0,d=0,e=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}e=c[b+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=c[(c[a+4>>2]|0)+28>>2];c[b+236>>2]=1463898624;_X(b,64,1,28224e3);d=0;return d|0}function mK(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1179014732){a=b+16|0;b=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;return((b|0)==0|b>>>0>256>>>0?12:50)|0}else{return 0}return 0}function nK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a+16|0;hD(c[d>>2]|0,16,0)|0;e=FD(c[d>>2]|0)|0;if((e|0)==0){f=-1094995529;i=b;return f|0}if(e>>>0>2>>>0){QIb(a,2393560,(g=i,i=i+8|0,c[g>>2]=e,g)|0);i=g;f=-1163346256;i=b;return f|0}hD(c[d>>2]|0,1012,0)|0;if((jD(c[d>>2]|0)|0)!=0){f=-541478725;i=b;return f|0}while(1){h=FD(c[d>>2]|0)|0;e=FD(c[d>>2]|0)|0;j=fD(c[d>>2]|0,0,0,1)|0;k=wrc(j,G,e,0)|0;e=G;if((h|0)==0){l=10;break}else if((h|0)==1835413808){j=ZX(a,0)|0;if((j|0)==0){f=-12;l=13;break}m=j+8|0;c[(c[m>>2]|0)+8>>2]=1;n=DD(c[d>>2]|0)|0;c[(c[m>>2]|0)+52>>2]=n;n=DD(c[d>>2]|0)|0;c[(c[m>>2]|0)+416>>2]=n;n=DD(c[d>>2]|0)|0;c[(c[m>>2]|0)+412>>2]=n;hD(c[d>>2]|0,8,0)|0;n=zD(c[d>>2]|0)|0;o=c[m>>2]|0;c[o+792>>2]=n;n=JX(1406408,c[o+52>>2]|0)|0;c[(c[m>>2]|0)+48>>2]=n;_X(j,32,1,1e3)}else if((h|0)==1835413552){j=ZX(a,0)|0;if((j|0)==0){f=-12;l=13;break}n=j+8|0;c[(c[n>>2]|0)+8>>2]=0;hD(c[d>>2]|0,4,0)|0;m=FD(c[d>>2]|0)|0;c[(c[n>>2]|0)+120>>2]=m;m=FD(c[d>>2]|0)|0;c[(c[n>>2]|0)+124>>2]=m;hD(c[d>>2]|0,4,0)|0;m=FD(c[d>>2]|0)|0;c[(c[n>>2]|0)+52>>2]=m;o=JX(1409152,m)|0;c[(c[n>>2]|0)+48>>2]=o;_X(j,32,1,1e3)}else{l=11;break}fD(c[d>>2]|0,k,e,0)|0;if((jD(c[d>>2]|0)|0)!=0){f=-541478725;l=13;break}}if((l|0)==10){fD(c[d>>2]|0,2056,0,0)|0;f=0;i=b;return f|0}else if((l|0)==11){QIb(a,2320280,(g=i,i=i+8|0,c[g>>2]=h,g)|0);i=g;f=-1163346256;i=b;return f|0}else if((l|0)==13){i=b;return f|0}return 0}function oK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a+16|0;a=fD(c[d>>2]|0,0,0,1)|0;e=G;while(1){if((jD(c[d>>2]|0)|0)!=0){f=-541478725;g=11;break}h=FD(c[d>>2]|0)|0;i=FD(c[d>>2]|0)|0;if((i|0)==-1){f=-541478725;g=11;break}if((h|0)==1667510320){j=0;break}else if((h|0)==1651978544){g=5;break}h=hD(c[d>>2]|0,i,0)|0;k=h;if((k|0)<0){f=k;g=11;break}}if((g|0)==5){j=1}else if((g|0)==11){return f|0}if(i>>>0<8>>>0){f=-1094995529;return f|0}g=FD(c[d>>2]|0)|0;k=FD(c[d>>2]|0)|0;h=fX(c[d>>2]|0,b,i-8|0)|0;if((k&4096|0)!=0){k=b+36|0;c[k>>2]=c[k>>2]|1}c[b+32>>2]=j;j=b+8|0;c[j>>2]=g;c[j+4>>2]=0;j=b+64|0;c[j>>2]=a;c[j+4>>2]=e;f=h;return f|0}function pK(a){a=a|0;var b=0;b=(grc(c[a+4>>2]|0,2599760,8)|0)==0;return(b?100:0)|0}function qK(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+120|0;e=b|0;f=c[a+12>>2]|0;g=a+16|0;h=c[g>>2]|0;j=sK(a)|0;if((j|0)<0){k=j;i=b;return k|0}if((j|0)!=120){KIb(a,16,2574976,(l=i,i=i+16|0,c[l>>2]=120,c[l+8>>2]=j,l)|0);i=l;k=-1094995529;i=b;return k|0}j=AD(h,e|0,120)|0;if((j|0)!=120){k=(j|0)<0?j:-541478725;i=b;return k|0}j=ZX(a,0)|0;if((j|0)==0){k=-12;i=b;return k|0}h=e+32|0;m=j+56|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=0;m=e+40|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+56|0;n=(d[m]|d[m+1|0]<<8)<<16>>16;m=e+58|0;o=(d[m]|d[m+1|0]<<8)<<16>>16;m=e+116|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+8|0;p=c[m>>2]|0;c[p+8>>2]=0;c[p+72>>2]=(h>>>14&255)*1e6|0;q=h&15;c[p+52>>2]=q;p=JX(840904,q)|0;c[(c[m>>2]|0)+48>>2]=p;c[j+236>>2]=2;j=a;p=n&65535;KIb(j,48,2556104,(l=i,i=i+32|0,c[l>>2]=p,c[l+8>>2]=(p&127)+1900,c[l+16>>2]=p>>>7&15,c[l+24>>2]=p>>>11,l)|0);i=l;p=o&65535;KIb(j,48,2538672,(l=i,i=i+32|0,c[l>>2]=p,c[l+8>>2]=(p&127)+1900,c[l+16>>2]=p>>>7&15,c[l+24>>2]=p>>>11,l)|0);i=l;if((h&4194304|0)!=0){KIb(j,24,2522208,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}l=f;c[l>>2]=1<<(e>>>4&3)+1;e=ZX(a,0)|0;if((e|0)==0){k=-12;i=b;return k|0}a=c[e+8>>2]|0;c[a+8>>2]=1;c[a+412>>2]=48e3;c[a+416>>2]=c[l>>2];_X(e,64,1,48e3);hD(c[g>>2]|0,c[f+16>>2]|0,0)|0;k=0;i=b;return k|0}function rK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a+12>>2]|0;f=c[a+16>>2]|0;g=sK(a)|0;if((g|0)<0){h=g;i=d;return h|0}j=c[e+12>>2]|0;if(j>>>0>1>>>0){KIb(a,24,2393496,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;h=-11;i=d;return h|0}do{if((j|0)==1){if(!((c[a+24>>2]|0)>>>0<2>>>0)){break}KIb(a,16,2320224,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;h=-1094995529;i=d;return h|0}}while(0);k=K1(b,g)|0;if((k|0)<0){h=k;i=d;return h|0}k=AD(f,c[b+24>>2]|0,g)|0;if((k|0)!=(g|0)){P1(b);h=(k|0)<0?k:-541478725;i=d;return h|0}c[b+32>>2]=j;if((j|0)!=0){h=g;i=d;return h|0}if((c[e+8>>2]&8388608)>>>0<8388608>>>0){j=b+36|0;c[j>>2]=c[j>>2]|1}j=e+4|0;e=c[j>>2]|0;c[j>>2]=e+1;j=b+16|0;c[j>>2]=e;c[j+4>>2]=(e|0)<0|0?-1:0;h=g;i=d;return h|0}function sK(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+264|0;f=e|0;g=e+8|0;h=g|0;j=c[b+12>>2]|0;k=b+16|0;l=c[k>>2]|0;m=g;n=g+8|0;o=n;p=f|0;q=AD(l,p,8)|0;if((q|0)!=8){r=(q|0)<0?q:-541478725;i=e;return r|0}a:do{if((grc(p,2599760,8)|0)!=0){q=f+1|0;s=f+7|0;while(1){if((jD(c[k>>2]|0)|0)!=0){r=-541478725;break}orc(p|0,q|0,7)|0;a[s]=zD(c[k>>2]|0)|0;if((grc(p,2599760,8)|0)==0){break a}}i=e;return r|0}}while(0);c[h>>2]=1414088012;c[h+4>>2]=18499;h=AD(l,o,8)|0;if((h|0)!=8){r=(h|0)<0?h:-541478725;i=e;return r|0}h=c[n>>2]|0;n=g+16|0;g=n;p=c[o+4>>2]|0;if(h>>>0>1>>>0){QIb(b,2266320,(t=i,i=i+8|0,c[t>>2]=h,t)|0);i=t}o=(h|0)!=0;if(!(p>>>0<257>>>0&p>>>0>=(o?72:60)>>>0&(p&3|0)==0)){KIb(b,16,2218336,(t=i,i=i+8|0,c[t>>2]=p,t)|0);i=t;r=-1094995529;i=e;return r|0}k=p-16|0;f=AD(l,g,k)|0;if((f|0)!=(k|0)){r=(f|0)<0?f:-541478725;i=e;return r|0}do{if((p|0)>0){f=0;s=0;do{s=(c[m+f>>2]|0)+s|0;f=f+4|0;}while((f|0)<(p|0));if((s|0)==0){break}KIb(b,16,2184568,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}}while(0);p=c[n>>2]|0;c[j+12>>2]=p;n=o?24:16;o=g+n|0;m=j+16|0;c[m>>2]=0;if((p|0)==1){if((c[b+24>>2]|0)>>>0<2>>>0){KIb(b,32,2155768,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;r=k;i=e;return r|0}k=(h|0)==0?g+(n+8)|0:o;h=c[k>>2]|0;f=k+4|0;q=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=k+8|0;k=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=b+28|0;u=c[f>>2]|0;v=h>>>6&63;w=c[(c[u+4>>2]|0)+8>>2]|0;c[w+792>>2]=v;if((v|0)!=(h&63|0)){KIb(b,24,2130640,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;r=-1163346256;i=e;return r|0}if((v|0)==32){c[w+48>>2]=542135120}else if((v|0)==16){c[w+48>>2]=65554}else if((v|0)==20){c[w+48>>2]=65561}else if((v|0)==24){c[w+48>>2]=407917392}else{KIb(b,24,2107400,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;r=-1163346256;i=e;return r|0}w=(k<<3|0)/(v|0)|0;if((w|0)==1920){x=u;y=34}else if((w|0)==8008){_X(c[u>>2]|0,64,1001,3e4)}else{KIb(b,24,2625400,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;x=c[f>>2]|0;y=34}if((y|0)==34){_X(c[x>>2]|0,64,1,25)}x=q-(q>>>1&1431655765)|0;q=(x>>>2&858993459)+(x&858993459)|0;x=(q>>>4)+q&252645135;q=(x>>>8)+x|0;r=ca((q>>>16)+q&63,k)|0;i=e;return r|0}else if((p|0)==0){p=n|4;c[j+8>>2]=c[o>>2];j=c[g+p>>2]|0;k=wrc(c[g+(p+16)>>2]|0,0,c[g+(p+8)>>2]|0,0)|0;hD(l,k,G)|0;r=j;i=e;return r|0}else{j=n|4;n=c[g+j>>2]|0;if((c[o>>2]|0)!=1){r=n;i=e;return r|0}c[m>>2]=c[g+(j+4)>>2];r=n;i=e;return r|0}return 0}function tK(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[a+8>>2]|0;if((b|0)>0){e=c[a+4>>2]|0;a=-256;f=0;g=0;h=0;i=0;j=0;k=0;while(1){l=d[e+k|0]|0|a;do{if((a|0)==256){if((l|0)==437){m=j;n=i+1|0;o=h;p=g;q=f;break}else if((l|0)==438){m=j;n=i;o=h+1|0;p=g;q=f;break}else{if(l>>>0<288>>>0){m=j;n=i;o=h;p=g;q=f+1|0;break}if(l>>>0<304>>>0){m=j;n=i;o=h;p=g+1|0;q=f;break}else{m=(((l-432|0)>>>0<7>>>0|(l-442|0)>>>0<10>>>0)&1^1)+j|0;n=i;o=h;p=g;q=f;break}}}else{m=j;n=i;o=h;p=g;q=f}}while(0);r=k+1|0;if((r|0)<(b|0)){a=l<<8;f=q;g=p;h=o;i=n;j=m;k=r}else{s=q;t=p;u=o;v=n;w=m;break}}}else{s=0;t=0;u=0;v=0;w=0}if((u|0)<(v|0)|(u|0)<(t|0)){x=0;return x|0}if(!((s|0)>=(t|0)&(t|0)>0&(w|0)==0)){x=0;return x|0}x=(u+s|0)>3?50:25;return x|0}function uK(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+4>>2]|0;e=b;if(!((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==-1545648870)){f=0;return f|0}e=d[b+4|0]|0;g=0;if((e&128|0)==0&(g&0|0)==0){do{if((e&64|0)==0&(g&0|0)==0){if(!((e&32|0)==0&(g&0|0)==0)){h=3;i=0;j=287;break}if(!((e&16|0)==0&(g&0|0)==0)){h=4;i=0;j=271;break}if(!((e&8|0)==0&(g&0|0)==0)){h=5;i=0;j=263;break}if(!((e&4|0)==0&(g&0|0)==0)){h=6;i=0;j=259;break}if(!((e&2|0)==0&(g&0|0)==0)){h=7;i=0;j=257;break}if((e&1|0)==0&(g&0|0)==0){f=0}else{h=8;i=0;j=256;break}return f|0}else{h=2;i=0;j=319}}while(0);k=i&g;i=j&e;j=1;while(1){l=j+1|0;m=d[b+(j+4)|0]|0|(i<<8|0>>>24);n=k<<8|i>>>24|0;if((l|0)<(h|0)){k=n;i=m;j=l}else{o=n;p=m;q=h;break}}}else{o=g&0;p=e&127;q=1}e=c[a+8>>2]|0;a=(e|0)<0|0?-1:0;g=q+4|0;q=wrc(p,o,g,0)|0;h=G;if(a>>>0<h>>>0|a>>>0==h>>>0&e>>>0<q>>>0){f=0;return f|0}e=0;a:do{if(!(o>>>0<e>>>0|o>>>0==e>>>0&p>>>0<8>>>0)){a=wrc(q,h,-8,-1)|0;j=G;i=g;while(1){k=(i|0)<0|0?-1:0;if(k>>>0>j>>>0|k>>>0==j>>>0&i>>>0>a>>>0){break a}if((grc(b+i|0,2189152,8)|0)==0){f=100;break}else{i=i+1|0}}return f|0}}while(0);e=0;if(o>>>0<e>>>0|o>>>0==e>>>0&p>>>0<4>>>0){f=50;return f|0}p=wrc(q,h,-4,-1)|0;h=G;q=g;while(1){g=(q|0)<0|0?-1:0;if(g>>>0>h>>>0|g>>>0==h>>>0&q>>>0>p>>>0){f=50;r=13;break}if((grc(b+q|0,2186384,4)|0)==0){f=100;r=13;break}else{q=q+1|0}}if((r|0)==13){return f|0}return 0}function vK(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0,ea=0.0,fa=0.0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0;e=i;i=i+288|0;f=e|0;g=e+32|0;j=e+40|0;k=e+80|0;l=e+208|0;m=e+216|0;n=e+248|0;o=e+256|0;p=e+264|0;q=e+272|0;r=e+280|0;s=b+12|0;t=c[s>>2]|0;u=t;v=t+320|0;w=t+328|0;x=j;mrc(x|0,0,40)|0;z=t;c[z>>2]=b;A=(AK(u,1514664,x)|0)!=0;B=j|0;C=c[B>>2]|0;D=c[B+4>>2]|0;B=0;do{if(!(A|(D>>>0>B>>>0|D>>>0==B>>>0&C>>>0>1>>>0))){E=j+8|0;H=c[E+4>>2]|0;I=0;if(H>>>0>I>>>0|H>>>0==I>>>0&(c[E>>2]|0)>>>0>8>>>0){break}E=j+16|0;I=c[E+4>>2]|0;H=0;if(I>>>0>H>>>0|I>>>0==H>>>0&(c[E>>2]|0)>>>0>4>>>0){break}E=j+32|0;H=c[E>>2]|0;I=c[E+4>>2]|0;E=0;if(I>>>0>E>>>0|I>>>0==E>>>0&H>>>0>3>>>0){break}E=j+24|0;J=c[E>>2]|0;if((J|0)==0){break}if((H|0)==3&(I|0)==0){KIb(c[z>>2]|0,24,2385032,(K=i,i=i+40|0,c[K>>2]=C,c[K+8>>2]=D,c[K+16>>2]=J,c[K+24>>2]=3,c[K+32>>2]=0,K)|0);i=K;L=c[E>>2]|0}else{L=J}J=0;while(1){if(!(J>>>0<2>>>0)){M=13;break}if((irc(L,c[836280+(J<<2)>>2]|0)|0)==0){M=12;break}else{J=J+1|0}}if((M|0)==12){if(J>>>0>1>>>0){M=13}}do{if((M|0)==13){KIb(b,24,2378016,(K=i,i=i+8|0,c[K>>2]=L,K)|0);i=K;if((c[(c[z>>2]|0)+1156>>2]&8|0)==0){break}CK(1514664,x);N=-1094995529;i=e;return N|0}}while(0);CK(1514664,x);J=fD(c[(c[z>>2]|0)+16>>2]|0,0,0,1)|0;E=G;I=(AK(u,835424,t)|0)==1;H=c[(c[z>>2]|0)+16>>2]|0;a:do{if(I){O=H}else{P=t+268|0;S=t+4|0;T=E;U=J;V=H;b:while(1){c[P>>2]=0;c[S>>2]=0;W=wrc(U,T,1,0)|0;X=fD(V,W,G,0)|0;W=G;Y=0;if((W|0)<(Y|0)|(W|0)==(Y|0)&X>>>0<0>>>0){break}X=JD(V)|0;if((jD(V)|0)==0){Z=X}else{break}while(1){if((Z|0)==524531317|(Z|0)==475249515|(Z|0)==423732329|(Z|0)==374648427|(Z|0)==357149030|(Z|0)==307544935|(Z|0)==290298740|(Z|0)==272869232){break}X=zD(V)|0|Z<<8;if((jD(V)|0)==0){Z=X}else{break b}}c[P>>2]=Z;X=fD(c[(c[z>>2]|0)+16>>2]|0,0,0,1)|0;Y=G;W=(AK(u,835472,t)|0)==1;_=c[(c[z>>2]|0)+16>>2]|0;if(W){O=_;break a}else{T=Y;U=X;V=_}}c[t+380>>2]=1;N=-541478725;i=e;return N|0}}while(0);H=fD(O,0,0,1)|0;J=G;E=c[z>>2]|0;c:do{if((c[(c[E+16>>2]|0)+88>>2]|0)!=0){if((c[E+1084>>2]&2|0)!=0){break}I=t+352|0;V=c[I>>2]|0;if((V|0)<=0){break}U=t+356|0;T=t+400|0;P=0;S=V;d:while(1){V=c[U>>2]|0;_=V+(P<<4)+8|0;X=c[_+4>>2]|0;do{if(X>>>0>J>>>0|X>>>0==J>>>0&(c[_>>2]|0)>>>0>H>>>0){Y=V+(P<<4)|0;if((c[Y>>2]|0)==475249515&(c[Y+4>>2]|0)==0){c[T>>2]=1;$=S;break}if((GK(u,P)|0)<0){break d}$=c[I>>2]|0}else{$=S}}while(0);V=P+1|0;if((V|0)<($|0)){P=V;S=$}else{break c}}c[T>>2]=-1}}while(0);H=t+272|0;J=c[H>>2]|0;E=c[H+4>>2]|0;if((J|0)==0&(E|0)==0){c[H>>2]=1e6;c[H+4>>2]=0;aa=0;da=1e6}else{aa=E;da=J}J=t+280|0;ea=+h[J>>3];if(ea!=0.0){fa=ea*(+(da>>>0)+ +(aa>>>0)*4294967296.0)*1.0e3/1.0e6;E=(F=+fa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);S=(c[z>>2]|0)+1064|0;c[S>>2]=~~+fa>>>0;c[S+4>>2]=E}E=b+1140|0;MGb(E,2372352,c[t+288>>2]|0,0)|0;MGb(E,2360256,c[t+292>>2]|0,0)|0;do{if((c[t+296>>2]|0)==8){S=c[t+300>>2]|0;P=S|0;I=S+4|0;S=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;I=je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=je(S|0)|0;S=f|0;U=Crc(P,I|0,1e9,0)|0;I=wrc(U,G,978307200,0)|0;c[g>>2]=I;I=rc(g|0)|0;if((I|0)==0){break}Fc(S|0,32,2194e3,I|0)|0;MGb(E,2191560,S,0)|0}}while(0);S=c[t+316>>2]|0;I=t+312|0;e:do{if((c[I>>2]|0)>0){U=t+432|0;P=m|0;V=b+28|0;_=p|0;X=p+4|0;Y=q|0;W=q+4|0;ga=n|0;ia=n+4|0;ja=o|0;ka=o+4|0;la=l;ma=0;f:while(1){na=S+(ma*296|0)+260|0;oa=c[na>>2]|0;c[l>>2]=0;pa=S+(ma*296|0)+16|0;qa=c[pa>>2]|0;ra=c[pa+4>>2]|0;do{if((qa|0)==1&(ra|0)==0|(qa|0)==2&(ra|0)==0|(qa|0)==17&(ra|0)==0|(qa|0)==33&(ra|0)==0){sa=S+(ma*296|0)+28|0;if((c[sa>>2]|0)==0){break}ta=1;ua=0;do{if((qa|0)==2&(ra|0)==0){va=S+(ma*296|0)+184|0;if(+h[va>>3]!=0.0){wa=0;break}h[va>>3]=+h[S+(ma*296|0)+176>>3];wa=0}else if((qa|0)==(ta|0)&(ra|0)==(ua|0)){va=S+(ma*296|0)+64|0;do{if((c[va>>2]|0)==0&(c[va+4>>2]|0)==0){fa=+h[S+(ma*296|0)+104>>3];if(!(fa>0.0)){break}ea=1.0e9/fa;xa=(F=+ea,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[va>>2]=~~+ea>>>0;c[va+4>>2]=xa}}while(0);va=S+(ma*296|0)+112|0;if((c[va>>2]|0)==(-1|0)&(c[va+4>>2]|0)==(-1|0)){xa=S+(ma*296|0)+128|0;ya=c[xa+4>>2]|0;c[va>>2]=c[xa>>2];c[va+4>>2]=ya}ya=S+(ma*296|0)+120|0;if((c[ya>>2]|0)==(-1|0)&(c[ya+4>>2]|0)==(-1|0)){va=S+(ma*296|0)+136|0;xa=c[va+4>>2]|0;c[ya>>2]=c[va>>2];c[ya+4>>2]=xa}if((c[S+(ma*296|0)+144>>2]|0)!=4){wa=0;break}xa=c[S+(ma*296|0)+148>>2]|0;wa=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0}else{wa=0}}while(0);ua=c[S+(ma*296|0)+256>>2]|0;do{if((ua|0)>1){KIb(c[z>>2]|0,16,2341840,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;za=0}else{if((ua|0)!=1){za=0;break}ta=oa+8|0;if(!((c[ta>>2]|0)==0&(c[ta+4>>2]|0)==0)){ta=oa+48|0;xa=c[ta>>2]|0;if((xa|0)<=0){ya=oa;c[ya>>2]=0;c[ya+4>>2]=0;KIb(c[z>>2]|0,16,2335952,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;za=0;break}ya=((xa+2|0)/3|0)<<2|1;xa=hJb(ya)|0;c[l>>2]=xa;if((xa|0)==0){N=-12;M=253;break f}RFb(xa,ya,c[oa+52>>2]|0,c[ta>>2]|0)|0;za=0;break}ta=oa+16|0;ya=c[ta>>2]|0;xa=c[ta+4>>2]|0;if(!((ya|0)==0&(xa|0)==0|(ya|0)==2&(xa|0)==0|(ya|0)==3&(xa|0)==0)){xa=oa;c[xa>>2]=0;c[xa+4>>2]=0;KIb(c[z>>2]|0,16,2335952,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;za=0;break}xa=S+(ma*296|0)+32|0;if((c[xa>>2]|0)==0){za=0;break}ya=oa;if((c[ya>>2]&2|0)==0&(c[ya+4>>2]&0|0)==0){za=0;break}ya=S+(ma*296|0)+36|0;ta=c[ya>>2]|0;if((DK(ya,xa,c[na>>2]|0)|0)<0){c[ya>>2]=0;c[xa>>2]=0;KIb(c[z>>2]|0,16,2330688,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}if((ta|0)==(c[ya>>2]|0)){za=0;break}kJb(ta);za=0}}while(0);while(1){ua=c[1353528+(za*28|0)>>2]|0;if((ua|0)==0){Aa=0;break}ta=1353504+(za*28|0)|0;ya=c[sa>>2]|0;if((krc(ta,ya,lrc(ta|0)|0)|0)==0){Aa=ua;break}else{za=za+1|0}}ua=ZX(b,0)|0;c[S+(ma*296|0)+264>>2]=ua;Ba=c[l>>2]|0;if((ua|0)==0){M=77;break f}if((Ba|0)!=0){MGb(ua+88|0,2324632,Ba,0)|0;mJb(la)}ta=c[sa>>2]|0;do{if((irc(ta,2319336)|0)==0){if((c[S+(ma*296|0)+32>>2]|0)<=39){M=84;break}ya=c[S+(ma*296|0)+36>>2]|0;if((ya|0)==0){M=84;break}c[S+(ma*296|0)+280>>2]=1;xa=ya+14|0;va=(d[xa]|d[xa+1|0]<<8)<<16>>16&65535;xa=ya+16|0;ya=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;Ca=JX(1409152,ya)|0;Da=va;Ea=ya;Fa=40;M=149}else{M=84}}while(0);g:do{if((M|0)==84){M=0;do{if((irc(ta,2314600)|0)==0){ya=S+(ma*296|0)+32|0;va=c[ya>>2]|0;if((va|0)<=13){break}xa=c[S+(ma*296|0)+36>>2]|0;if((xa|0)==0){break}$C(k,xa,va,0,0,0,0,0)|0;va=ua+8|0;xa=OS(k,c[va>>2]|0,c[ya>>2]|0)|0;if((xa|0)<0){N=xa;M=253;break f}xa=c[ya>>2]|0;Ca=c[(c[va>>2]|0)+48>>2]|0;Da=-1;Ea=wa;Fa=(xa|0)>18?18:xa;M=149;break g}}while(0);do{if((irc(ta,2309944)|0)==0){if((c[S+(ma*296|0)+32>>2]|0)<=85){break}xa=S+(ma*296|0)+36|0;va=c[xa>>2]|0;if((va|0)==0){break}ya=va+4|0;va=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;ya=JX(1408424,va)|0;Ga=c[xa>>2]|0;if((JX(1408424,d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)==0){Ca=ya;Da=-1;Ea=va;Fa=0;M=149;break g}va=c[xa>>2]|0;xa=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;Ca=JX(1408424,xa)|0;Da=-1;Ea=xa;Fa=0;M=149;break g}}while(0);do{if((irc(ta,2305920)|0)==0){if((c[S+(ma*296|0)+32>>2]|0)<=20){M=101;break}xa=S+(ma*296|0)+36|0;va=c[xa>>2]|0;if((va|0)==0){M=101;break}ya=va+4|0;va=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;ya=JX(1407072,va)|0;Ga=c[xa>>2]|0;if((JX(1407072,d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)==0){Ha=ya;Ia=va}else{va=c[xa>>2]|0;ya=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;Ha=JX(1407072,ya)|0;Ia=ya}if((Ha|0)!=0){Ja=Ha;Ka=Ia;break}ya=(c[xa>>2]|0)+4|0;Ca=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)==541674835?24:0;Da=-1;Ea=Ia;Fa=0;M=149;break g}else{M=101}}while(0);h:do{if((M|0)==101){M=0;do{if((Aa|0)==65557){ya=S+(ma*296|0)+192|0;if((c[ya>>2]|0)==64&(c[ya+4>>2]|0)==0){Ja=65559;Ka=wa;break h}}else if((Aa|0)==86018){if((c[S+(ma*296|0)+32>>2]|0)==0){La=0}else{break}while(1){if(!(La>>>0<3>>>0)){M=113;break}ya=La+1|0;if((Db(ta|0,c[838184+(La<<2)>>2]|0)|0)==0){La=ya}else{Ma=ya;break}}if((M|0)==113){M=0;Ma=La+1|0}ya=~~+h[S+(ma*296|0)+176>>3];xa=0;while(1){if(!(xa>>>0<16>>>0)){break}if((c[1965112+(xa<<2)>>2]|0)==(ya|0)){break}else{xa=xa+1|0}}ya=pJb(21)|0;if((ya|0)==0){N=-12;M=253;break f}a[ya]=xa>>>1&7|Ma<<3;a[ya+1|0]=c[S+(ma*296|0)+200>>2]<<3|0>>>29|xa<<7;if((Db(c[sa>>2]|0,2286792)|0)==0){Na=86018;Oa=2;Pa=ya;M=148;break}va=~~+h[S+(ma*296|0)+184>>3];Ga=0;while(1){if(!(Ga>>>0<16>>>0)){break}if((c[1965112+(Ga<<2)>>2]|0)==(va|0)){break}else{Ga=Ga+1|0}}a[ya+2|0]=86;a[ya+3|0]=-27;a[ya+4|0]=Ga<<3|128;Na=86018;Oa=5;Pa=ya;M=148}else if((Aa|0)==86032){va=S+(ma*296|0)+32|0;xa=c[va>>2]|0;if(!((xa|0)!=0&(xa|0)<2147483619)){break}Qa=xa+12|0;Ra=pJb(xa+28|0)|0;if((Ra|0)==0){N=-12;M=253;break f}xa=Ra;y=je(Qa|0)|0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=Ra+4|0;y=1667329121;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=Ra+8|0;y=0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;nrc(Ra+12|0,c[S+(ma*296|0)+36>>2]|0,c[va>>2]|0)|0;Na=86032;Oa=Qa;Pa=Ra;M=148}else if((Aa|0)==86038){Ra=pJb(46)|0;if((Ra|0)==0){N=-12;M=253;break f}$C(k,Ra,30,1,0,0,0,0)|0;dD(k,2278712,4);oD(k,1);oD(k,c[S+(ma*296|0)+200>>2]|0);oD(k,c[S+(ma*296|0)+192>>2]|0);Qa=S+(ma*296|0)+184|0;ea=+h[Qa>>3];if(ea<0.0|ea>2147483647.0){N=-1094995529;M=253;break f}kD(k,~~ea);ea=+h[J>>3]*(+((c[H>>2]|0)>>>0)+ +((c[H+4>>2]|0)>>>0)*4294967296.0);va=(F=+ea,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);fa=+h[Qa>>3];Qa=VIb(~~+ea>>>0,va,~~+fa>>>0,(F=+fa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0),1e9,0)|0;kD(k,Qa);Na=86038;Oa=30;Pa=Ra;M=148}else if((Aa|0)==65537){Ra=S+(ma*296|0)+192|0;Qa=c[Ra>>2]|0;va=c[Ra+4>>2]|0;Ra=24;xa=0;Sa=8;Ta=0;if((Qa|0)==32&(va|0)==0){Ja=65545;Ka=wa;break h}else if((Qa|0)==(Sa|0)&(va|0)==(Ta|0)){Ja=65541;Ka=wa;break h}else if((Qa|0)==(Ra|0)&(va|0)==(xa|0)){Ja=65549;Ka=wa;break h}else{Ja=65537;Ka=wa;break h}}else if((Aa|0)==65536){xa=S+(ma*296|0)+192|0;va=c[xa>>2]|0;Ra=c[xa+4>>2]|0;xa=32;Qa=0;Ta=24;Sa=0;if((va|0)==8&(Ra|0)==0){Ja=65541;Ka=wa;break h}else if((va|0)==(Ta|0)&(Ra|0)==(Sa|0)){Ja=65548;Ka=wa;break h}else if((va|0)==(xa|0)&(Ra|0)==(Qa|0)){Ja=65544;Ka=wa;break h}else{Ja=65536;Ka=wa;break h}}}while(0);if((M|0)==148){M=0;Ua=Pa;Va=Oa;Wa=0;Xa=wa;Ya=-1;Za=Na;_a=S+(ma*296|0)+32|0;break g}if((Aa-6|0)>>>0<2>>>0|(Aa|0)==69|(Aa|0)==70){Ca=Aa;Da=-1;Ea=wa;Fa=26;M=149;break g}if((Aa|0)==77824){h[S+(ma*296|0)+184>>3]=8.0e3;Qa=S+(ma*296|0)+200|0;c[Qa>>2]=1;c[Qa+4>>2]=0;Ja=77824;Ka=wa;break}else if(!((Aa|0)==86058|(Aa|0)==86047|(Aa|0)==86036|(Aa|0)==77825)){Ca=Aa;Da=-1;Ea=wa;Fa=0;M=149;break g}Qa=c[S+(ma*296|0)+36>>2]|0;if((Qa|0)==0){Ca=Aa;Da=-1;Ea=wa;Fa=0;M=149;break g}Ra=S+(ma*296|0)+32|0;$C(k,Qa,c[Ra>>2]|0,0,0,0,0,0)|0;hD(k,22,0)|0;Qa=HD(k)|0;xa=S+(ma*296|0)+208|0;c[xa>>2]=JD(k)|0;hD(k,12,0)|0;va=S+(ma*296|0)+212|0;c[va>>2]=HD(k)|0;Sa=S+(ma*296|0)+216|0;c[Sa>>2]=HD(k)|0;Ta=HD(k)|0;$a=S+(ma*296|0)+220|0;c[$a>>2]=Ta;if((Qa|0)<0){N=-1094995529;M=253;break f}if((c[xa>>2]|0)<1){N=-1094995529;M=253;break f}ab=c[va>>2]|0;if((ab|0)<1){N=-1094995529;M=253;break f}va=c[Sa>>2]|0;if((va|0)<1|(Ta|0)<1){N=-1094995529;M=253;break f}if((va|0)==0){M=140;break f}if(!((2147483647/(va>>>0)|0)>>>0>ab>>>0)){M=140;break f}Ta=hJb(ca(va,ab)|0)|0;c[S+(ma*296|0)+240>>2]=Ta;if((Ta|0)==0){N=-12;M=253;break f}if((Aa|0)==77825){c[(c[ua+8>>2]|0)+432>>2]=c[xa>>2];c[Ra>>2]=0;Ja=77825;Ka=wa;break}else if((Aa|0)==86058){M=144}do{if((M|0)==144){M=0;if((Qa|0)>=4){break}c[$a>>2]=d[1305784+Qa|0]|0;c[(c[ua+8>>2]|0)+72>>2]=c[835808+(Qa<<2)>>2]}}while(0);c[(c[ua+8>>2]|0)+432>>2]=c[$a>>2];Ca=Aa;Da=-1;Ea=wa;Fa=78;M=149;break g}}while(0);Ua=0;Va=0;Wa=0;Xa=Ka;Ya=-1;Za=Ja;_a=S+(ma*296|0)+32|0}}while(0);do{if((M|0)==149){M=0;ta=S+(ma*296|0)+32|0;c[ta>>2]=(c[ta>>2]|0)-Fa;if((Ca|0)!=0){Ua=0;Va=0;Wa=Fa;Xa=Ea;Ya=Da;Za=Ca;_a=ta;break}KIb(c[z>>2]|0,32,2274528,(K=i,i=i+8|0,c[K>>2]=c[sa>>2],K)|0);i=K;Ua=0;Va=0;Wa=Fa;Xa=Ea;Ya=Da;Za=0;_a=ta}}while(0);ta=S+(ma*296|0)+56|0;fa=+h[ta>>3];if(fa<.01){h[ta>>3]=1.0;bb=1.0}else{bb=fa}_X(ua,64,~~((+((c[H>>2]|0)>>>0)+ +((c[H+4>>2]|0)>>>0)*4294967296.0)*bb),1e9);ta=ua+8|0;c[(c[ta>>2]|0)+48>>2]=Za;Qa=c[S+(ma*296|0)+48>>2]|0;Ra=ua+88|0;if((irc(Qa,2398688)|0)!=0){MGb(Ra,2269328,Qa,0)|0}MGb(Ra,2372352,c[S+(ma*296|0)+24>>2]|0,0)|0;Qa=S+(ma*296|0)+72|0;if(!((c[Qa>>2]|0)==0&(c[Qa+4>>2]|0)==0)){Qa=ua+72|0;c[Qa>>2]=c[Qa>>2]|1}Qa=S+(ma*296|0)+80|0;if(!((c[Qa>>2]|0)==0&(c[Qa+4>>2]|0)==0)){Qa=ua+72|0;c[Qa>>2]=c[Qa>>2]|64}Qa=c[ta>>2]|0;xa=Qa+96|0;do{if((c[xa>>2]|0)==0){if((Ua|0)!=0){c[xa>>2]=Ua;c[(c[ta>>2]|0)+100>>2]=Va;break}Ta=S+(ma*296|0)+36|0;if((c[Ta>>2]|0)==0){break}ab=c[_a>>2]|0;if((ab|0)<=0){break}if((PX(Qa,ab)|0)!=0){N=-12;M=253;break f}nrc(c[(c[ta>>2]|0)+96>>2]|0,(c[Ta>>2]|0)+Wa|0,c[_a>>2]|0)|0}}while(0);Qa=c[pa>>2]|0;xa=c[pa+4>>2]|0;Ta=2;ab=0;if((Qa|0)==1&(xa|0)==0){va=c[S+(ma*296|0)+252>>2]|0;Sa=c[ta>>2]|0;c[Sa+8>>2]=0;c[Sa+52>>2]=Xa;if((Ya|0)>-1){c[Sa+792>>2]=Ya}cb=c[S+(ma*296|0)+128>>2]|0;c[Sa+120>>2]=cb;db=c[S+(ma*296|0)+136>>2]|0;c[Sa+124>>2]=db;Sa=S+(ma*296|0)+112|0;eb=Erc(db,(db|0)<0|0?-1:0,c[Sa>>2]|0,c[Sa+4>>2]|0)|0;Sa=G;db=S+(ma*296|0)+120|0;fb=Erc(cb,(cb|0)<0|0?-1:0,c[db>>2]|0,c[db+4>>2]|0)|0;xKb(ua+80|0,ua+84|0,eb,Sa,fb,G,255,0)|0;if((c[(c[ta>>2]|0)+48>>2]|0)!=1211250229){c[ua+236>>2]=2}fb=S+(ma*296|0)+64|0;Sa=c[fb>>2]|0;eb=c[fb+4>>2]|0;do{if(!((Sa|0)==0&(eb|0)==0)){fb=ua+92|0;db=fb|0;cb=ua+96|0;xKb(db,cb,1e9,0,Sa,eb,3e4,0)|0;if((c[db>>2]|0)>=((c[cb>>2]|0)*1e3|0|0)){break}cb=fb;fb=ua+412|0;db=c[cb+4>>2]|0;c[fb>>2]=c[cb>>2];c[fb+4>>2]=db}}while(0);eb=S+(ma*296|0)+160|0;Sa=c[eb>>2]|0;db=c[eb+4>>2]|0;eb=0;if(((Sa|0)!=0|(db|0)!=0)&(db>>>0<eb>>>0|db>>>0==eb>>>0&Sa>>>0<15>>>0)){MGb(Ra,2265384,c[1358760+(Sa<<2)>>2]|0,0)|0}Sa=S+(ma*296|0)+168|0;if(!((c[Sa>>2]|0)==0&(c[Sa+4>>2]|0)==0)){MGb(Ra,2261752,2257432,0)|0}Sa=S+(ma*296|0)+248|0;if((c[Sa>>2]|0)>0){gb=0}else{break}do{eb=va+(gb<<4)+8|0;db=c[eb>>2]|0;fb=c[eb+4>>2]|0;eb=0;i:do{if(!(fb>>>0>eb>>>0|fb>>>0==eb>>>0&db>>>0>2>>>0)){Rb(P|0,32,2253912,(K=i,i=i+16|0,c[K>>2]=c[1358744+(db<<2)>>2],c[K+8>>2]=ma,K)|0)|0;i=K;cb=c[I>>2]|0;hb=va+(gb<<4)|0;ib=0;while(1){if((ib|0)>=(cb|0)){break i}jb=S+(ib*296|0)+8|0;if((c[hb>>2]|0)==(c[jb>>2]|0)&(c[hb+4>>2]|0)==(c[jb+4>>2]|0)){break}else{ib=ib+1|0}}MGb((c[(c[V>>2]|0)+(ib<<2)>>2]|0)+88|0,2265384,P,0)|0}}while(0);gb=gb+1|0;}while((gb|0)<(c[Sa>>2]|0))}else if((Qa|0)==(Ta|0)&(xa|0)==(ab|0)){Sa=c[ta>>2]|0;c[Sa+8>>2]=1;va=Sa+412|0;c[va>>2]=~~+h[S+(ma*296|0)+184>>3];c[Sa+416>>2]=c[S+(ma*296|0)+200>>2];Ra=Sa+792|0;if((c[Ra>>2]|0)==0){c[Ra>>2]=c[S+(ma*296|0)+192>>2]}if((c[Sa+48>>2]|0)!=86018){c[ua+236>>2]=2}Ra=S+(ma*296|0)+88|0;db=c[Ra>>2]|0;eb=c[Ra+4>>2]|0;if((db|0)==0&(eb|0)==0){kb=Sa}else{c[ga>>2]=1;c[ia>>2]=1e9;c[ja>>2]=1;c[ka>>2]=c[va>>2];va=XIb(db,eb,n,o)|0;eb=c[ta>>2]|0;c[eb+116>>2]=va;kb=eb}eb=S+(ma*296|0)+96|0;va=c[eb>>2]|0;db=c[eb+4>>2]|0;if((va|0)==0&(db|0)==0){break}c[_>>2]=1;c[X>>2]=1e9;c[Y>>2]=1;c[W>>2]=c[kb+412>>2];eb=XIb(va,db,p,q)|0;X4a(kb,eb);break}else{if((Za|0)!=1465275476){if(!((Qa|0)==17&(xa|0)==0)){break}eb=c[ta>>2]|0;c[eb+8>>2]=3;db=c[eb+48>>2]|0;if(!((db|0)==94212|(db|0)==1095979808)){break}c[U>>2]=1;break}c[(c[ta>>2]|0)+8>>2]=3;db=c[sa>>2]|0;if((irc(db,2245232)|0)==0){eb=ua+72|0;c[eb>>2]=c[eb>>2]|65536;break}if((irc(db,2237024)|0)==0){eb=ua+72|0;c[eb>>2]=c[eb>>2]|131072;break}if((irc(db,2233248)|0)!=0){break}db=ua+72|0;c[db>>2]=c[db>>2]|262144;break}}else{KIb(c[z>>2]|0,32,2348104,(K=i,i=i+16|0,c[K>>2]=qa,c[K+8>>2]=ra,K)|0);i=K}}while(0);ra=ma+1|0;if((ra|0)<(c[I>>2]|0)){ma=ra}else{break e}}if((M|0)==77){kJb(Ba);N=-12;i=e;return N|0}else if((M|0)==140){c[S+(ma*296|0)+240>>2]=0;N=-12;i=e;return N|0}else if((M|0)==253){i=e;return N|0}}}while(0);S=c[t+324>>2]|0;I=v;j:do{if((c[I>>2]|0)>0){H=0;do{J=S+(H*40|0)+8|0;do{if((c[J>>2]|0)==0){M=209}else{U=S+(H*40|0)+12|0;if((c[U>>2]|0)==0){M=209;break}W=S+(H*40|0)+20|0;if((c[W>>2]|0)==0){M=209;break}Y=S+(H*40|0)+16|0;if((c[Y>>2]|0)<=0){M=209;break}X=ZX(b,0)|0;if((X|0)==0){break j}_=X+88|0;MGb(_,2225616,c[J>>2]|0,0)|0;MGb(_,2221032,c[U>>2]|0,0)|0;_=X+8|0;ka=c[_>>2]|0;c[ka+48>>2]=0;c[ka+8>>2]=4;if((PX(ka,c[Y>>2]|0)|0)!=0){break j}nrc(c[(c[_>>2]|0)+96>>2]|0,c[W>>2]|0,c[Y>>2]|0)|0;Y=0;while(1){lb=c[1353184+(Y*36|0)>>2]|0;if((lb|0)==0){break}W=1353152+(Y*36|0)|0;ka=c[U>>2]|0;if((krc(W,ka,lrc(W|0)|0)|0)==0){M=215;break}else{Y=Y+1|0}}if((M|0)==215){M=0;c[(c[_>>2]|0)+48>>2]=lb}c[S+(H*40|0)+32>>2]=X}}while(0);if((M|0)==209){M=0;KIb(c[z>>2]|0,16,2229360,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}H=H+1|0;}while((H|0)<(c[I>>2]|0))}}while(0);I=c[t+332>>2]|0;S=w;H=c[S>>2]|0;if((H|0)>0){ma=r|0;J=r+4|0;Y=0;U=0;ua=0;sa=H;while(1){H=I+(Y<<5)|0;ta=c[H>>2]|0;xa=c[H+4>>2]|0;do{if((ta|0)==0&(xa|0)==(-2147483648|0)){mb=U;nb=ua;ob=sa}else{Qa=I+(Y<<5)+16|0;ab=c[Qa>>2]|0;if((ab|0)==0&(c[Qa+4>>2]|0)==0){mb=U;nb=ua;ob=sa;break}if(!((ua|0)==0&(U|0)==0|(xa>>>0>U>>>0|xa>>>0==U>>>0&ta>>>0>ua>>>0))){mb=U;nb=ua;ob=sa;break}c[ma>>2]=1;c[J>>2]=1e9;Qa=I+(Y<<5)+8|0;Ta=I+(Y<<5)+24|0;W=aY(b,ab,r,ta,xa,c[Qa>>2]|0,c[Qa+4>>2]|0,c[Ta>>2]|0)|0;c[I+(Y<<5)+28>>2]=W;MGb(W+32|0,2372352,c[Ta>>2]|0,0)|0;mb=c[H+4>>2]|0;nb=c[H>>2]|0;ob=c[S>>2]|0}}while(0);H=Y+1|0;if((H|0)<(ob|0)){Y=H;U=mb;ua=nb;sa=ob}else{break}}}HK(u);sa=c[s>>2]|0;ua=c[sa+348>>2]|0;U=sa+344|0;if((c[U>>2]|0)<=0){N=0;i=e;return N|0}Y=sa+316|0;S=sa+312|0;I=sa+332|0;J=sa+328|0;ma=sa+324|0;H=sa+320|0;sa=0;while(1){xa=ua+(sa*48|0)+32|0;ta=c[xa>>2]|0;Ta=c[xa+4>>2]|0;k:do{if((ta|0)==0&(Ta|0)==0){W=ua+(sa*48|0)+24|0;Qa=c[W>>2]|0;ab=c[W+4>>2]|0;if(!((Qa|0)==0&(ab|0)==0)){ka=c[I>>2]|0;ja=c[J>>2]|0;if((ja|0)<=0){break}ia=ua+(sa*48|0)+40|0;ga=0;P=ja;ja=ab;ab=Qa;while(1){Qa=ka+(ga<<5)+16|0;do{if((c[Qa>>2]|0)==(ab|0)&(c[Qa+4>>2]|0)==(ja|0)){V=c[ka+(ga<<5)+28>>2]|0;if((V|0)==0){pb=P;break}IK(b,ia,V+32|0,0);pb=c[J>>2]|0}else{pb=P}}while(0);Qa=ga+1|0;if((Qa|0)>=(pb|0)){break k}ga=Qa;P=pb;ja=c[W+4>>2]|0;ab=c[W>>2]|0}}W=ua+(sa*48|0)+16|0;ab=c[W>>2]|0;ja=c[W+4>>2]|0;if((ab|0)==0&(ja|0)==0){IK(b,ua+(sa*48|0)+40|0,E,c[ua+(sa*48|0)>>2]|0);break}P=c[Y>>2]|0;ga=c[S>>2]|0;if((ga|0)<=0){break}ia=ua+(sa*48|0)+40|0;ka=0;Qa=ga;ga=ja;ja=ab;while(1){ab=P+(ka*296|0)+8|0;do{if((c[ab>>2]|0)==(ja|0)&(c[ab+4>>2]|0)==(ga|0)){X=c[P+(ka*296|0)+264>>2]|0;if((X|0)==0){qb=Qa;break}IK(b,ia,X+88|0,0);qb=c[S>>2]|0}else{qb=Qa}}while(0);ab=ka+1|0;if((ab|0)>=(qb|0)){break k}ka=ab;Qa=qb;ga=c[W+4>>2]|0;ja=c[W>>2]|0}}else{W=c[ma>>2]|0;ja=c[H>>2]|0;if((ja|0)<=0){break}ga=ua+(sa*48|0)+40|0;Qa=0;ka=ja;ja=Ta;ia=ta;while(1){P=W+(Qa*40|0)|0;do{if((c[P>>2]|0)==(ia|0)&(c[P+4>>2]|0)==(ja|0)){ab=c[W+(Qa*40|0)+32>>2]|0;if((ab|0)==0){rb=ka;break}IK(b,ga,ab+88|0,0);rb=c[H>>2]|0}else{rb=ka}}while(0);P=Qa+1|0;if((P|0)>=(rb|0)){break k}Qa=P;ka=rb;ja=c[xa+4>>2]|0;ia=c[xa>>2]|0}}}while(0);xa=sa+1|0;if((xa|0)<(c[U>>2]|0)){sa=xa}else{N=0;break}}i=e;return N|0}}while(0);rb=c[j+24>>2]|0;b=j+32|0;j=c[b>>2]|0;qb=c[b+4>>2]|0;KIb(c[z>>2]|0,16,2385032,(K=i,i=i+40|0,c[K>>2]=C,c[K+8>>2]=D,c[K+16>>2]=rb,c[K+24>>2]=j,c[K+32>>2]=qb,K)|0);i=K;CK(1514664,x);N=-1163346256;i=e;return N|0}function wK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[a+12>>2]|0;a=d;e=d+372|0;a:do{if((c[e>>2]|0)<=0){f=d;g=d+380|0;h=d+268|0;i=d+4|0;while(1){j=fD(c[(c[f>>2]|0)+16>>2]|0,0,0,1)|0;k=G;if((c[g>>2]|0)!=0){l=-541478725;break}b:do{if((zK(a)|0)<0){m=c[(c[f>>2]|0)+16>>2]|0;c[h>>2]=0;c[i>>2]=0;n=wrc(j,k,1,0)|0;o=fD(m,n,G,0)|0;n=G;p=0;c:do{if(!((n|0)<(p|0)|(n|0)==(p|0)&o>>>0<0>>>0)){q=JD(m)|0;if((jD(m)|0)==0){r=q}else{break}while(1){if((r|0)==524531317|(r|0)==475249515|(r|0)==423732329|(r|0)==374648427|(r|0)==357149030|(r|0)==307544935|(r|0)==290298740|(r|0)==272869232){break}q=zD(m)|0|r<<8;if((jD(m)|0)==0){r=q}else{break c}}c[h>>2]=r;break b}}while(0);c[g>>2]=1}}while(0);if((c[e>>2]|0)>0){break a}}return l|0}}while(0);r=d+368|0;a=r;nrc(b|0,c[c[a>>2]>>2]|0,80)|0;kJb(c[c[a>>2]>>2]|0);b=c[e>>2]|0;do{if((b|0)>1){g=c[a>>2]|0;orc(g|0,g+4|0,(b<<2)-4|0)|0;g=iJb(c[a>>2]|0,(c[e>>2]<<2)-4|0)|0;if((g|0)==0){break}c[a>>2]=g}else{mJb(r);c[d+376>>2]=0}}while(0);c[e>>2]=(c[e>>2]|0)-1;l=0;return l|0}function xK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+12>>2]|0;a=b+312|0;d=c[b+316>>2]|0;c[b+376>>2]=0;e=b+368|0;f=e;g=c[f>>2]|0;if((g|0)!=0){h=b+372|0;do{if((c[h>>2]|0)>0){P1(c[g>>2]|0);kJb(c[c[f>>2]>>2]|0);if((c[h>>2]|0)>1){i=1}else{break}do{P1(c[(c[f>>2]|0)+(i<<2)>>2]|0);kJb(c[(c[f>>2]|0)+(i<<2)>>2]|0);i=i+1|0;}while((i|0)<(c[h>>2]|0))}}while(0);mJb(e);c[h>>2]=0}h=a;a=c[h>>2]|0;if((a|0)>0){j=0;k=a}else{l=b+416|0;CK(836984,l);CK(835472,b);return 0}while(1){a=d+(j*296|0)+16|0;if((c[a>>2]|0)==2&(c[a+4>>2]|0)==0){kJb(c[d+(j*296|0)+240>>2]|0);m=c[h>>2]|0}else{m=k}a=j+1|0;if((a|0)<(m|0)){j=a;k=m}else{break}}l=b+416|0;CK(836984,l);CK(835472,b);return 0}function yK(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=c[a+12>>2]|0;h=g;i=g+312|0;j=c[g+316>>2]|0;k=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=g+400|0;if((c[b>>2]|0)>0){c[b>>2]=0;l=c[g+356>>2]|0;m=c[g+352>>2]|0;n=0;while(1){if((n|0)>=(m|0)){break}o=l+(n<<4)|0;if((c[o>>2]|0)==475249515&(c[o+4>>2]|0)==0){break}else{n=n+1|0}}if((GK(h,n)|0)<0){c[b>>2]=-1}HK(h)}n=k+404|0;do{if((c[n>>2]|0)==0){l=g+368|0;p=g+376|0;q=l;r=l}else{l=k+400|0;m=(c[l>>2]|0)+8|0;o=c[m>>2]|0;s=c[m+4>>2]|0;m=(s|0)<(e|0)|(s|0)==(e|0)&o>>>0<d>>>0;t=m?d:o;o=m?e:s;s=CX(k,t,o,f)|0;a:do{if((s|0)<0){m=(c[l>>2]|0)+(((c[n>>2]|0)-1|0)*24|0)|0;fD(c[a+16>>2]|0,c[m>>2]|0,c[m+4>>2]|0,0)|0;c[g+268>>2]=0;m=g+376|0;u=g+368|0;v=u;w=g+372|0;while(1){x=CX(k,t,o,f)|0;if((x|0)>=0){y=x;z=m;A=u;B=v;break a}c[m>>2]=0;C=c[v>>2]|0;if((C|0)!=0){do{if((c[w>>2]|0)>0){P1(c[C>>2]|0);kJb(c[c[v>>2]>>2]|0);if((c[w>>2]|0)>1){D=1}else{break}do{P1(c[(c[v>>2]|0)+(D<<2)>>2]|0);kJb(c[(c[v>>2]|0)+(D<<2)>>2]|0);D=D+1|0;}while((D|0)<(c[w>>2]|0))}}while(0);mJb(u);c[w>>2]=0}if((zK(h)|0)<0){y=x;z=m;A=u;B=v;break}}}else{v=g+368|0;y=s;z=g+376|0;A=v;B=v}}while(0);c[z>>2]=0;s=c[B>>2]|0;if((s|0)!=0){v=g+372|0;do{if((c[v>>2]|0)>0){P1(c[s>>2]|0);kJb(c[c[B>>2]>>2]|0);if((c[v>>2]|0)>1){E=1}else{break}do{P1(c[(c[B>>2]|0)+(E<<2)>>2]|0);kJb(c[(c[B>>2]|0)+(E<<2)>>2]|0);E=E+1|0;}while((E|0)<(c[v>>2]|0))}}while(0);mJb(A);c[v>>2]=0}if((y|0)<0){p=z;q=A;r=B;break}if((c[b>>2]|0)<0){if((y|0)==((c[n>>2]|0)-1|0)){p=z;q=A;r=B;break}}s=i;if((c[s>>2]|0)>0){u=g+272|0;m=0;w=y;while(1){c[j+(m*296|0)+228>>2]=0;c[j+(m*296|0)+224>>2]=0;C=j+(m*296|0)+232|0;c[C>>2]=0;c[C+4>>2]=-2147483648;C=j+(m*296|0)+272|0;c[C>>2]=0;c[C+4>>2]=0;C=j+(m*296|0)+16|0;b:do{if((c[C>>2]|0)==17&(c[C+4>>2]|0)==0){F=j+(m*296|0)+264|0;H=c[F>>2]|0;if((c[H+76>>2]|0)==48){I=w;break}J=(c[l>>2]|0)+(y*24|0)+8|0;K=CX(H,c[J>>2]|0,c[J+4>>2]|0,1)|0;J=w;while(1){if(!((J|K|0)>-1)){I=J;break b}H=c[(c[F>>2]|0)+400>>2]|0;L=H+(K*24|0)|0;M=c[L+4>>2]|0;N=c[l>>2]|0;O=N+(J*24|0)|0;P=c[O+4>>2]|0;if(!((M|0)<(P|0)|(M|0)==(P|0)&(c[L>>2]|0)>>>0<(c[O>>2]|0)>>>0)){I=J;break b}O=N+(y*24|0)+8|0;N=H+(K*24|0)+8|0;H=xrc(c[O>>2]|0,c[O+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;N=G;O=Frc(-64771072,6,c[u>>2]|0,c[u+4>>2]|0)|0;L=G;if(N>>>0<L>>>0|N>>>0==L>>>0&H>>>0<O>>>0){J=J-1|0}else{I=J;break}}}else{I=w}}while(0);C=m+1|0;if((C|0)<(c[s>>2]|0)){m=C;w=I}else{Q=I;break}}}else{Q=y}w=(c[l>>2]|0)+(Q*24|0)|0;fD(c[a+16>>2]|0,c[w>>2]|0,c[w+4>>2]|0,0)|0;c[g+268>>2]=0;w=k+444|0;if((f&4|0)==0){c[w>>2]=1;m=c[l>>2]|0;s=m+(y*24|0)+8|0;u=c[s+4>>2]|0;v=g+392|0;c[v>>2]=c[s>>2];c[v+4>>2]=u;R=m}else{c[w>>2]=0;w=g+392|0;c[w>>2]=t;c[w+4>>2]=o;R=c[l>>2]|0}c[g+384>>2]=1;c[g+380>>2]=0;c[g+4>>2]=0;w=R+(y*24|0)+8|0;zX(a,k,c[w>>2]|0,c[w+4>>2]|0);S=0;return S|0}}while(0);c[p>>2]=0;p=c[r>>2]|0;if((p|0)!=0){a=g+372|0;do{if((c[a>>2]|0)>0){P1(c[p>>2]|0);kJb(c[c[r>>2]>>2]|0);if((c[a>>2]|0)>1){T=1}else{break}do{P1(c[(c[r>>2]|0)+(T<<2)>>2]|0);kJb(c[(c[r>>2]|0)+(T<<2)>>2]|0);T=T+1|0;}while((T|0)<(c[a>>2]|0))}}while(0);mJb(q);c[a>>2]=0}c[g+268>>2]=0;c[g+384>>2]=0;c[k+444>>2]=0;c[g+380>>2]=0;c[g+4>>2]=0;S=-1;return S|0}function zK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+16|0;d=b|0;e=d;mrc(e|0,0,16)|0;if((c[a+432>>2]|0)!=0){f=fD(c[(c[a>>2]|0)+16>>2]|0,0,0,1)|0;g=G;c[a+376>>2]=0;h=(c[a+268>>2]|0)==0;j=wrc(f,g,-4,-1)|0;k=h?f:j;j=h?g:G;g=AK(a,836432,e)|0;h=c[d+12>>2]|0;f=d+8|0;l=c[f>>2]|0;if((l|0)>0){m=d|0;d=0;n=g;o=l;while(1){l=c[h+(d*72|0)+24>>2]|0;do{if((l|0)>0){p=c[h+(d*72|0)+28>>2]|0;if((p|0)==0){q=n;r=o;break}s=h+(d*72|0)+16|0;if((c[s>>2]|0)==0&(c[s+4>>2]|0)==0){t=-1}else{s=h+(d*72|0)+8|0;t=(c[s>>2]|0)==0&(c[s+4>>2]|0)==0&1}s=h+(d*72|0)+32|0;u=h+(d*72|0)|0;v=h+(d*72|0)+64|0;w=BK(a,p,l,c[s>>2]|0,c[s+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0,t,0,0,0,0,k,j,c[v>>2]|0,c[v+4>>2]|0)|0;q=w;r=c[f>>2]|0}else{q=n;r=o}}while(0);l=d+1|0;if((l|0)<(r|0)){d=l;n=q;o=r}else{x=q;break}}}else{x=g}CK(836984,e);y=x;i=b;return y|0}x=a+416|0;e=x;g=AK(a,836576,e)|0;do{if((g|0)==1){q=a+408|0;r=a|0;do{if(!((c[q>>2]|0)==0&(c[q+4>>2]|0)==0)){o=fD(c[(c[r>>2]|0)+16>>2]|0,0,0,1)|0;n=a+4|0;d=c[n>>2]|0;if((d|0)<=0){break}f=d-1|0;d=a+8+(f<<4)|0;j=xrc(o,G,c[d>>2]|0,c[d+4>>2]|0)|0;d=G;o=a+8+(f<<4)+8|0;k=c[o+4>>2]|0;if(d>>>0<k>>>0|d>>>0==k>>>0&j>>>0<(c[o>>2]|0)>>>0){if((c[a+268>>2]|0)==0){break}}c[n>>2]=f}}while(0);CK(836984,e);mrc(e|0,0,16)|0;c[a+404>>2]=0;f=fD(c[(c[r>>2]|0)+16>>2]|0,0,0,1)|0;n=G;c[q>>2]=f;c[q+4>>2]=n;c[a+376>>2]=0;if((c[a+268>>2]|0)!=0){o=wrc(f,n,-4,-1)|0;c[q>>2]=o;c[q+4>>2]=G}o=AK(a,836288,e)|0;if((o|0)!=1){z=o;break}z=AK(a,836576,e)|0}else{z=g}}while(0);if((z|0)!=0){y=z;i=b;return y|0}z=a+404|0;g=c[a+424>>2]|0;if((c[z>>2]|0)>=(g|0)){y=0;i=b;return y|0}e=c[a+428>>2]|0;c[z>>2]=g;z=g-1|0;g=c[e+(z*72|0)+24>>2]|0;if((g|0)<=0){y=0;i=b;return y|0}o=c[e+(z*72|0)+28>>2]|0;if((o|0)==0){y=0;i=b;return y|0}n=e+(z*72|0)+16|0;f=(c[n>>2]|0)==0&(c[n+4>>2]|0)==0;if(f){A=-1}else{n=e+(z*72|0)+8|0;A=(c[n>>2]|0)==0&(c[n+4>>2]|0)==0&1}n=c[e+(z*72|0)+48>>2]|0;if((n|0)>0){B=c[e+(z*72|0)+52>>2]|0}else{B=0}j=e+(z*72|0)|0;if(f){c[j>>2]=0;c[j+4>>2]=0;C=0;D=0}else{C=c[j+4>>2]|0;D=c[j>>2]|0}j=e+(z*72|0)+32|0;f=x|0;x=e+(z*72|0)+40|0;k=a+408|0;d=e+(z*72|0)+64|0;y=BK(a,o,g,c[j>>2]|0,c[j+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0,D,C,A,B,c[x>>2]|0,c[x+4>>2]|0,n,c[k>>2]|0,c[k+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0;i=b;return y|0}function AK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+8|0;f=e|0;g=a+268|0;h=c[g>>2]|0;do{if((h|0)==0){j=EK(a,c[(c[a>>2]|0)+16>>2]|0,4,f)|0;if((j|0)<0){k=j;i=e;return k|0}else{l=c[f>>2]|1<<(j*7|0);c[g>>2]=l;m=l;break}}else{m=h}}while(0);h=0;while(1){n=b+(h*24|0)|0;g=c[n>>2]|0;o=(g|0)==0;if(o|(g|0)==(m|0)){break}else{h=h+1|0}}do{if(o&(m|0)==524531317){h=c[a+4>>2]|0;if((h|0)<=0){break}b=a+8+(h-1<<4)+8|0;if((c[b>>2]|0)==(-1|0)&(c[b+4>>2]|0)==16777215){k=0}else{break}i=e;return k|0}}while(0);do{if(o){if((m|0)==236|(m|0)==191){break}b=a|0;KIb(c[b>>2]|0,32,2471824,(h=i,i=i+8|0,c[h>>2]=m,h)|0);i=h;if((c[(c[b>>2]|0)+1156>>2]&8|0)==0){break}else{k=-1094995529}i=e;return k|0}}while(0);k=FK(a,n,d)|0;i=e;return k|0}function BK(b,e,f,g,j,k,l,m,n,o,p,q,r,s,t,u,v,w){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;w=w|0;var x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0;x=i;i=i+448|0;z=x|0;A=x+128|0;B=x+136|0;C=x+264|0;D=x+272|0;E=x+280|0;F=x+288|0;H=x+296|0;I=x+304|0;J=x+312|0;K=x+440|0;$C(J,e,f,0,0,0,0,0)|0;L=EK(b,J,f>>>0>8>>>0?8:f,K)|0;if((L|0)<0){KIb(c[b>>2]|0,16,2393400,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=L;i=x;return N|0}J=e+L|0;O=f-L|0;f=c[K>>2]|0;P=c[K+4>>2]|0;K=f;Q=c[b+316>>2]|0;R=c[b+312>>2]|0;S=K;T=(K|0)<0|0?-1:0;U=0;while(1){if((U|0)>=(R|0)){V=6;break}W=Q+(U*296|0)|0;X=W|0;if((c[X>>2]|0)==(S|0)&(c[X+4>>2]|0)==(T|0)){V=7;break}else{U=U+1|0}}do{if((V|0)==6){KIb(c[b>>2]|0,16,2507448,(M=i,i=i+8|0,c[M>>2]=K,M)|0);i=M}else if((V|0)==7){if((W|0)==0){break}T=Q+(U*296|0)+264|0;S=c[T>>2]|0;if((S|0)==0){break}if((O|0)<4){N=0;i=x;return N|0}if((c[S+76>>2]|0)>47){N=0;i=x;return N|0}R=J;X=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=e+(L+3)|0;Y=d[e+(L+2)|0]|0;Z=O-3|0;_=(o|0)==-1?Y>>>7:o;$=(k|0)!=(-1|0)|(l|0)!=(-1|0);do{if($){if(!(X<<16>>16>-1)){aa=-(X<<16>>16)|0;ba=(aa|0)<0|0?-1:0;if(ba>>>0>l>>>0|ba>>>0==l>>>0&aa>>>0>k>>>0){da=_;ea=-2147483648;fa=0;break}}aa=wrc(X<<16>>16,X<<16>>16<0|0?-1:0,k,l)|0;ba=G;ga=Q+(U*296|0)+16|0;if((c[ga>>2]|0)==17&(c[ga+4>>2]|0)==0){ga=Q+(U*296|0)+272|0;ha=c[ga+4>>2]|0;ia=ba>>>0<ha>>>0|ba>>>0==ha>>>0&aa>>>0<(c[ga>>2]|0)>>>0?0:_}else{ia=_}if((ia|0)==0){da=0;ea=ba;fa=aa;break}xX(S,t,u,aa,ba,0,0,1)|0;da=ia;ea=ba;fa=aa}else{da=_;ea=-2147483648;fa=0}}while(0);_=b+384|0;do{if((c[_>>2]|0)!=0){aa=Q+(U*296|0)+16|0;if((c[aa>>2]|0)==17&(c[aa+4>>2]|0)==0){break}aa=b+392|0;ba=c[aa+4>>2]|0;if(ea>>>0<ba>>>0|ea>>>0==ba>>>0&fa>>>0<(c[aa>>2]|0)>>>0){N=0;i=x;return N|0}if((da|0)!=0){c[_>>2]=0;break}if((c[S+444>>2]|0)!=0){break}KIb(c[b>>2]|0,16,2266224,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;c[_>>2]=0}}while(0);_=Y>>>1&3;a:do{if((_|0)==0){aa=pJb(4)|0;ba=aa;if((aa|0)==0){ja=-12;ka=ba;break}c[ba>>2]=Z;la=R;ma=Z;na=ba;oa=1;V=56}else{if((Z|0)<=0){KIb(0,0,2556048,(M=i,i=i+24|0,c[M>>2]=2538600,c[M+8>>2]=2522144,c[M+16>>2]=2080,M)|0);i=M;Hd();return 0}ba=a[R]|0;aa=ba&255;ga=aa+1|0;ha=L+4|0;pa=e+ha|0;qa=O-4|0;ra=pJb(ga<<2)|0;sa=ra;if((ra|0)==0){ja=-12;ka=0;break}b:do{if((_|0)==1){c:do{if(ba<<24>>24==0){ta=qa;ua=pa;va=0;wa=0;xa=0}else{ra=0;ya=0;za=pa;Aa=qa;d:while(1){Ba=sa+(ya<<2)|0;Ca=ra;Da=za;Ea=Aa;while(1){if(!(Ea>>>0>Ca>>>0)){break d}Fa=a[Da]|0;Ga=Fa&255;Ha=Ga+Ca|0;c[Ba>>2]=(c[Ba>>2]|0)+Ga;Ia=Da+1|0;Ja=Ea-1|0;if(Fa<<24>>24==-1){Ca=Ha;Da=Ia;Ea=Ja}else{break}}Ba=ya+1|0;if((Ba|0)<(aa|0)){ra=Ha;ya=Ba;za=Ia;Aa=Ja}else{ta=Ja;ua=Ia;va=Ba;wa=0;xa=Ha;break c}}ta=Ea;ua=Da;va=ya+1|0;wa=-1094995529;xa=Ca}}while(0);if(!(ta>>>0>xa>>>0)){ja=-1094995529;ka=sa;break a}c[sa+(va<<2)>>2]=ta-xa;Ka=wa;La=ta;Ma=ua}else if((_|0)==3){$C(B,pa,qa,0,0,0,0,0)|0;Aa=EK(b,B,qa>>>0>8>>>0?8:qa,C)|0;za=(Aa|0)<0;do{if(!za){ra=c[C>>2]|0;Ba=c[C+4>>2]|0;Fa=0;if(Ba>>>0>Fa>>>0|Ba>>>0==Fa>>>0&ra>>>0>2147483647>>>0){break}Fa=e+(ha+Aa)|0;Ga=qa-Aa|0;c[sa>>2]=ra;Na=ra|0;ra=Ba&0;e:do{if((ba&255)>>>0>1>>>0){Ba=Ga;Oa=Fa;Pa=1;Qa=ra;Ra=Na;while(1){$C(z,Oa,Ba,0,0,0,0,0)|0;Sa=EK(b,z,Ba>>>0>8>>>0?8:Ba,A)|0;if((Sa|0)<0){Ta=Sa;break}Ua=c[A>>2]|0;Va=c[A+4>>2]|0;Wa=yrc(-1|0,-1|0,(Sa*7|0)-1|0)|0;Xa=wrc(Wa,G,1,0)|0;Wa=wrc(Xa,G,Ua,Va)|0;Va=wrc(Wa,G,c[sa+(Pa-1<<2)>>2]|0,0)|0;Wa=G;Ua=0;if(Wa>>>0>Ua>>>0|Wa>>>0==Ua>>>0&Va>>>0>2147483647>>>0){Ta=-1094995529;break}Ua=Oa+Sa|0;Xa=Ba-Sa|0;c[sa+(Pa<<2)>>2]=Va;Sa=wrc(Va|0,Wa&0,Ra,Qa)|0;Wa=G;Va=Pa+1|0;if((Va|0)<(aa|0)){Ba=Xa;Oa=Ua;Pa=Va;Qa=Wa;Ra=Sa}else{Ya=0;Za=Xa;_a=Ua;$a=Wa;ab=Sa;break e}}KIb(c[b>>2]|0,32,2393400,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;Ya=Ta;Za=Ba;_a=Oa;$a=Qa;ab=Ra}else{Ya=0;Za=Ga;_a=Fa;$a=ra;ab=Na}}while(0);Na=Za;ra=(Za|0)<0|0?-1:0;if(!(ra>>>0>$a>>>0|ra>>>0==$a>>>0&Na>>>0>ab>>>0)){ja=-1094995529;ka=sa;break a}Fa=xrc(Na,ra,ab,$a)|0;c[sa+(aa<<2)>>2]=Fa;Ka=Ya;La=Za;Ma=_a;break b}}while(0);KIb(c[b>>2]|0,32,2393400,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;Ka=za?Aa:-1094995529;La=qa;Ma=pa}else if((_|0)==2){if(((qa|0)%(ga|0)|0|0)!=0){ja=-1094995529;ka=sa;break a}Fa=(qa|0)/(ga|0)|0;ra=0;while(1){c[sa+(ra<<2)>>2]=Fa;Na=ra+1|0;if((Na|0)<(ga|0)){ra=Na}else{la=pa;ma=qa;na=sa;oa=ga;V=56;break a}}}else{la=pa;ma=qa;na=sa;oa=ga;V=56;break a}}while(0);if((Ka|0)==0){la=Ma;ma=La;na=sa;oa=ga;V=56}else{ja=Ka;ka=sa}}}while(0);f:do{if((V|0)==56){bb=+h[Q+(U*296|0)+176>>3];do{if(bb==8.0e3){_=c[S+8>>2]|0;if((c[_+48>>2]|0)!=86019){V=60;break}if(bb!=+(c[_+412>>2]|0)){cb=n;db=m;break}if((c[_+424>>2]|0)!=0&((m|0)==0&(n|0)==0)){V=61}else{cb=n;db=m}}else{V=60}}while(0);if((V|0)==60){if((m|0)==0&(n|0)==0){V=61}else{cb=n;db=m}}if((V|0)==61){sa=Q+(U*296|0)+64|0;ga=Erc(c[sa>>2]|0,c[sa+4>>2]|0,oa,(oa|0)<0|0?-1:0)|0;sa=b+272|0;_=Frc(ga,G,c[sa>>2]|0,c[sa+4>>2]|0)|0;cb=G;db=_}do{if($){if(!(X<<16>>16>-1)){_=-(X<<16>>16)|0;sa=(_|0)<0|0?-1:0;if(sa>>>0>l>>>0|sa>>>0==l>>>0&_>>>0>k>>>0){break}}_=Q+(U*296|0)+272|0;sa=c[_>>2]|0;ga=c[_+4>>2]|0;R=wrc(db,cb,fa,ea)|0;Z=G;Y=ga>>>0>Z>>>0|ga>>>0==Z>>>0&sa>>>0>R>>>0;c[_>>2]=Y?sa:R;c[_+4>>2]=Y?ga:Z}}while(0);Z=oa;ga=(oa|0)<0|0?-1:0;Y=S+8|0;_=S|0;R=b+368|0;sa=b+372|0;qa=b+376|0;pa=F;aa=Q+(U*296|0)+260|0;ba=D;ha=b|0;ra=(s|0)>0;Fa=s+8|0;Aa=je(q|0)|0;za=je(r|0)|0;Na=Aa|0;Aa=(v|0)==0&(w|0)==0;Ga=Q+(U*296|0)+280|0;ya=Q+(U*296|0)+16|0;Pa=b+272|0;Sa=H|0;Wa=H+4|0;Ua=I|0;Xa=I+4|0;Va=Q+(U*296|0)+220|0;eb=Q+(U*296|0)+208|0;fb=Q+(U*296|0)+212|0;gb=Q+(U*296|0)+224|0;hb=Q+(U*296|0)+216|0;ib=Q+(U*296|0)+228|0;jb=Q+(U*296|0)+232|0;kb=Q+(U*296|0)+240|0;lb=la;mb=ma;nb=ea;ob=fa;pb=0;g:while(1){qb=pb+1|0;rb=Erc(qb,(qb|0)<0|0?-1:0,db,cb)|0;sb=Frc(rb,G,Z,ga)|0;rb=G;tb=Erc(pb,(pb|0)<0|0?-1:0,db,cb)|0;ub=Frc(tb,G,Z,ga)|0;tb=G;vb=xrc(sb,rb,ub,tb)|0;wb=G;xb=na+(pb<<2)|0;yb=c[xb>>2]|0;if(yb>>>0>mb>>>0){V=68;break}zb=c[Y>>2]|0;Ab=c[zb+48>>2]|0;do{if((Ab|0)==1465275476){V=101}else if((Ab|0)==77825|(Ab|0)==86036|(Ab|0)==86058|(Ab|0)==86047){Bb=c[zb+432>>2]|0;if((Bb|0)==0){V=129;break}Cb=c[Va>>2]|0;if((Cb|0)==0){if((Ab|0)==1465275476){V=101;break}else{V=129;break}}Db=c[eb>>2]|0;Eb=c[fb>>2]|0;Fb=c[gb>>2]|0;Gb=c[hb>>2]|0;do{if((c[ib>>2]|0)==0){if((Fb|0)==0){c[jb>>2]=ob;c[jb+4>>2]=nb}do{if((Ab|0)==86058){if((Gb|0)>(yb|0)){V=82;break g}nrc((c[kb>>2]|0)+(ca(Gb,Fb)|0)|0,lb|0,Gb)|0}else if((Ab|0)==77825){if(((ca(Eb,Db)|0)/2|0|0)>(yb|0)){V=79;break g}Hb=(Eb|0)/2|0;if((Eb|0)<=1){break}Ib=Gb<<1;Jb=ca(Fb,Db)|0;Kb=0;do{nrc((c[kb>>2]|0)+((ca(Ib,Kb)|0)+Jb)|0,lb+(ca(Kb,Db)|0)|0,Db)|0;Kb=Kb+1|0;}while((Kb|0)<(Hb|0))}else{if((Gb|0)>(yb|0)|(Eb|0)<1){V=88;break g}if(((Gb|0)%(Cb|0)|0|0)!=0){V=88;break g}Hb=(Gb|0)/(Cb|0)|0;if((Hb|0)<=0){break}Kb=(((Eb+1|0)/2|0)&-(Fb&1))+(Fb>>1)|0;Jb=0;do{nrc((c[kb>>2]|0)+(ca(Kb+(ca(Jb,Eb)|0)|0,Cb)|0)|0,lb+(ca(Jb,Cb)|0)|0,Cb)|0;Jb=Jb+1|0;}while((Jb|0)<(Hb|0))}}while(0);Ra=(c[gb>>2]|0)+1|0;c[gb>>2]=Ra;if((Ra|0)<(Eb|0)){V=94;break}if((c[(c[Y>>2]|0)+48>>2]|0)==86058){uT(c[kb>>2]|0,Eb,Gb)}c[gb>>2]=0;Ra=(ca(Gb,Eb)|0)/(Bb|0)|0;c[ib>>2]=Ra;Lb=Ra;V=95}else{V=96}}while(0);while(1){if((V|0)==94){V=0;Lb=c[ib>>2]|0;V=95;continue}else if((V|0)==95){V=0;if((Lb|0)==0){break}else{V=96;continue}}else if((V|0)==96){V=0;Cb=pJb(80)|0;if((Cb|0)==0){Mb=0;V=98;break g}if((K1(Cb,Bb)|0)<0){Mb=Cb;V=98;break g}Fb=c[Cb+24>>2]|0;Db=c[kb>>2]|0;Ra=(ca(Gb,Eb)|0)/(Bb|0)|0;Qa=c[ib>>2]|0;c[ib>>2]=Qa-1;nrc(Fb|0,Db+(ca(Ra-Qa|0,Bb)|0)|0,Bb)|0;Qa=c[jb+4>>2]|0;Ra=Cb+8|0;c[Ra>>2]=c[jb>>2];c[Ra+4>>2]=Qa;c[jb>>2]=0;c[jb+4>>2]=-2147483648;Qa=Cb+64|0;c[Qa>>2]=g;c[Qa+4>>2]=j;c[Cb+32>>2]=c[_>>2];tJb(R,sa,Cb);V=94;continue}}}else{V=129}}while(0);if((V|0)==101){V=0;if((yb|0)<1){ja=-1094995529;ka=na;break f}Ab=lb+yb|0;zb=lb;while(1){Nb=a[zb]|0;if((Nb<<24>>24|0)==13|(Nb<<24>>24|0)==10){V=104;break}Bb=zb+1|0;if(Bb>>>0<Ab>>>0){zb=Bb}else{Ob=-1;Pb=Bb;break}}if((V|0)==104){V=0;Ob=zb-lb|0;Pb=Nb<<24>>24==13?zb+1|0:zb}if(!(Pb>>>0<Ab>>>0)){ja=-1094995529;ka=na;break f}if((a[Pb]|0)!=10){ja=-1094995529;ka=na;break f}Bb=Pb+1|0;h:do{if(Bb>>>0<Ab>>>0){Eb=Bb;while(1){Qb=a[Eb]|0;if((Qb<<24>>24|0)==13|(Qb<<24>>24|0)==10){break}Gb=Eb+1|0;if(Gb>>>0<Ab>>>0){Eb=Gb}else{Sb=-1;Tb=Gb;break h}}Sb=Eb-Bb|0;Tb=Qb<<24>>24==13?Eb+1|0:Eb}else{Sb=-1;Tb=Bb}}while(0);if(!(Tb>>>0<Ab>>>0)){ja=-1094995529;ka=na;break f}if((a[Tb]|0)!=10){ja=-1094995529;ka=na;break f}zb=Tb+1|0;Gb=Ab-zb|0;if((Gb|0)>0){Ub=Gb}else{ja=-1094995529;ka=na;break f}while(1){Gb=Ub-1|0;Cb=a[Tb+Ub|0]|0;if(!((Cb<<24>>24|0)==13|(Cb<<24>>24|0)==10)){break}if((Gb|0)>0){Ub=Gb}else{ja=-1094995529;ka=na;break f}}if((Ub|0)<1){ja=-1094995529;ka=na;break f}Vb=pJb(80)|0;Ab=Vb;Wb=K1(Ab,Ub)|0;if((Wb|0)<0){V=128;break}nrc(c[Vb+24>>2]|0,zb|0,Ub)|0;if((Ob|0)>0){Gb=U1(Ab,75,Ob)|0;if((Gb|0)==0){V=121;break}nrc(Gb|0,lb|0,Ob)|0}if((Sb|0)>0){Gb=U1(Ab,76,Sb)|0;if((Gb|0)==0){V=125;break}nrc(Gb|0,Bb|0,Sb)|0}c[Vb+32>>2]=c[_>>2];Gb=Vb+8|0;c[Gb>>2]=ob;c[Gb+4>>2]=nb;c[Vb+48>>2]=vb;Gb=Vb+64|0;c[Gb>>2]=g;c[Gb+4>>2]=j;tJb(R,sa,Vb);c[qa>>2]=Ab}else if((V|0)==129){V=0;Ab=(pb|0)!=0?0:da;c[E>>2]=yb;Gb=c[aa>>2]|0;c[F>>2]=lb;do{if((Gb|0)==0){V=133}else{Cb=Gb+8|0;if(!((c[Cb>>2]|0)==0&(c[Cb+4>>2]|0)==0)){V=133;break}Cb=Gb;if((c[Cb>>2]&1|0)==0&(c[Cb+4>>2]&0|0)==0){V=133;break}Cb=DK(F,E,Gb)|0;if((Cb|0)<0){Xb=Cb}else{V=133}}}while(0);i:do{if((V|0)==133){V=0;Gb=c[(c[Y>>2]|0)+48>>2]|0;j:do{if((Gb|0)==86041){yb=c[F>>2]|0;c[D>>2]=0;Bb=c[E>>2]|0;k:do{if((Bb|0)<12){Yb=-1094995529}else{zb=c[(c[T>>2]|0)+8>>2]|0;if((c[zb+100>>2]|0)<2){Yb=-1094995529;break}Cb=c[zb+96>>2]|0;zb=(d[Cb]|d[Cb+1|0]<<8)<<16>>16;Cb=yb;Qa=d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0;Cb=Bb-4|0;do{if((Cb|0)>7){Ra=0;Db=Cb;Fb=0;Oa=yb+4|0;while(1){Ba=Oa;Hb=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;Ba=Oa+4|0;Jb=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;Ba=Oa+8|0;Kb=Db-8|0;if((Hb&6144|0)==6144){Zb=Kb;_b=Kb;$b=Ba}else{if((Kb|0)<4){ac=-1094995529;V=146;break}Kb=Ba;Ba=d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0;Kb=Db-12|0;if(Ba>>>0>Kb>>>0){ac=-1094995529;V=146;break}Zb=Kb;_b=Ba;$b=Oa+12|0}Ba=iJb(c[D>>2]|0,Fb+32+_b|0)|0;if((Ba|0)==0){ac=-12;V=146;break}c[D>>2]=Ba;Kb=_b+32|0;bc=Kb+Fb|0;Ib=Ba+Ra|0;y=1802532471;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;y=y>>8;a[Ib+2|0]=y;y=y>>8;a[Ib+3|0]=y;Ib=(c[D>>2]|0)+(Ra+4)|0;y=_b+24|0;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;y=y>>8;a[Ib+2|0]=y;y=y>>8;a[Ib+3|0]=y;Ib=(c[D>>2]|0)+(Ra+8)|0;y=zb;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;Ib=(c[D>>2]|0)+(Ra+10)|0;y=0;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;Ib=(c[D>>2]|0)+(Ra+12)|0;y=0;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;y=y>>8;a[Ib+2|0]=y;y=y>>8;a[Ib+3|0]=y;Ib=(c[D>>2]|0)+(Ra+16)|0;y=0;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;y=y>>8;a[Ib+2|0]=y;y=y>>8;a[Ib+3|0]=y;Ib=(c[D>>2]|0)+(Ra+20)|0;y=Qa;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;y=y>>8;a[Ib+2|0]=y;y=y>>8;a[Ib+3|0]=y;Ib=(c[D>>2]|0)+(Ra+24)|0;y=Hb;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;y=y>>8;a[Ib+2|0]=y;y=y>>8;a[Ib+3|0]=y;Ib=(c[D>>2]|0)+(Ra+28)|0;y=Jb;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;y=y>>8;a[Ib+2|0]=y;y=y>>8;a[Ib+3|0]=y;nrc((c[D>>2]|0)+(Ra+32)|0,$b|0,_b)|0;Ib=Zb-_b|0;if((Ib|0)>7){Ra=Kb+Ra|0;Db=Ib;Fb=bc;Oa=$b+_b|0}else{V=145;break}}if((V|0)==145){V=0;cc=bc;dc=c[D>>2]|0;ec=c[F>>2]|0;break}else if((V|0)==146){V=0;mJb(ba);Yb=ac;break k}}else{cc=0;dc=0;ec=yb}}while(0);c[E>>2]=cc;if((ec|0)!=(lb|0)){mJb(pa)}c[F>>2]=dc;fc=c[(c[Y>>2]|0)+48>>2]|0;gc=cc;V=151;break j}}while(0);KIb(c[ha>>2]|0,16,2184528,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;hc=Yb}else{fc=Gb;gc=c[E>>2]|0;V=151}}while(0);do{if((V|0)==151){V=0;Gb=(fc|0)==149?8:0;Eb=pJb(80)|0;yb=Eb;if((K1(yb,Gb+gc|0)|0)<0){kJb(Eb);hc=-12;break}Bb=Eb+24|0;if((c[(c[Y>>2]|0)+48>>2]|0)==149){Qa=c[Bb>>2]|0;zb=Qa;y=je(gc|0)|0;a[zb]=y;y=y>>8;a[zb+1|0]=y;y=y>>8;a[zb+2|0]=y;y=y>>8;a[zb+3|0]=y;zb=Qa+4|0;y=1718641513;a[zb]=y;y=y>>8;a[zb+1|0]=y;y=y>>8;a[zb+2|0]=y;y=y>>8;a[zb+3|0]=y}nrc((c[Bb>>2]|0)+Gb|0,c[F>>2]|0,gc)|0;if((c[F>>2]|0)!=(lb|0)){mJb(pa)}c[Eb+36>>2]=Ab;c[Eb+32>>2]=c[_>>2];do{if(ra){Gb=U1(yb,74,Fa)|0;if((Gb|0)==0){P1(yb);kJb(Eb);Xb=-12;break i}else{zb=Gb;Qa=zb|0;y=za;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;Qa=zb+4|0;y=Na;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;nrc(Gb+8|0,p|0,s)|0;break}}}while(0);do{if(!Aa){Gb=U1(yb,70,10)|0;if((Gb|0)==0){P1(yb);kJb(Eb);Xb=-12;break i}else{Qa=Gb;y=0;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;c[Sa>>2]=1;c[Wa>>2]=1e9;c[Ua>>2]=1;c[Xa>>2]=c[(c[Y>>2]|0)+412>>2];Qa=XIb(v,w,H,I)|0;zb=Gb+4|0;y=Qa;a[zb]=y;y=y>>8;a[zb+1|0]=y;y=y>>8;a[zb+2|0]=y;y=y>>8;a[zb+3|0]=y;break}}}while(0);if((c[Ga>>2]|0)==0){zb=Eb+8|0;c[zb>>2]=ob;c[zb+4>>2]=nb}else{zb=Eb+16|0;c[zb>>2]=ob;c[zb+4>>2]=nb}zb=Eb+64|0;c[zb>>2]=g;c[zb+4>>2]=j;zb=c[(c[Y>>2]|0)+48>>2]|0;if((zb|0)==1397909872){Qa=Eb+72|0;c[Qa>>2]=vb;c[Qa+4>>2]=wb}Qa=0;if((c[ya>>2]|0)!=17|(c[ya+4>>2]|0)!=0|(wb>>>0<Qa>>>0|wb>>>0==Qa>>>0&vb>>>0<-2147483648>>>0)){c[Eb+48>>2]=vb}l:do{if((zb|0)==94212){Qa=c[Bb>>2]|0;Gb=Eb+28|0;Cb=c[Gb>>2]|0;Oa=Qa+(Cb-1)|0;Fb=Qa;while(1){ic=a[Fb]|0;jc=Fb+1|0;if(ic<<24>>24!=44&Fb>>>0<Oa>>>0){Fb=jc}else{break}}Db=ic<<24>>24==44?jc:Fb;Ra=Db;while(1){if((a[Ra]|0)==44){break}if(Ra>>>0<Oa>>>0){Ra=Ra+1|0}else{break l}}Oa=Ra+1|0;Fb=Eb+8|0;Ib=c[Fb>>2]|0;Kb=c[Fb+4>>2]|0;Fb=wrc(Ib,Kb,vb,wb)|0;Jb=G;Hb=c[Pa>>2]|0;Ba=c[Pa+4>>2]|0;kc=Erc(Hb,Ba,Ib,Kb)|0;Kb=Frc(kc,G,1e7,0)|0;kc=Kb;Kb=Erc(Hb,Ba,Fb,Jb)|0;Jb=Frc(Kb,G,1e7,0)|0;Kb=Jb;Jb=(kc|0)/36e4|0;Fb=(Jb*-36e4|0)+kc|0;kc=(Fb|0)/6e3|0;Ba=Fb+(kc*-6e3|0)|0;Fb=(Ba|0)/100|0;Hb=(Kb|0)/36e4|0;Ib=(Hb*-36e4|0)+Kb|0;Kb=(Ib|0)/6e3|0;lc=Ib+(Kb*-6e3|0)|0;Ib=(lc|0)/100|0;a[Ra]=0;mc=Qa+(Cb+50)-Oa+16|0;nc=cGb(mc)|0;if((nc|0)==0){break}oc=nc+4|0;Rb(c[oc>>2]|0,mc|0,2155704,(M=i,i=i+80|0,c[M>>2]=Db,c[M+8>>2]=Jb,c[M+16>>2]=kc,c[M+24>>2]=Fb,c[M+32>>2]=Ba+(Fb*-100|0),c[M+40>>2]=Hb,c[M+48>>2]=Kb,c[M+56>>2]=Ib,c[M+64>>2]=lc+(Ib*-100|0),c[M+72>>2]=Oa,M)|0)|0;i=M;Oa=Eb;fGb(Oa);c[Oa>>2]=nc;c[Bb>>2]=c[oc>>2];c[Gb>>2]=lrc(c[oc>>2]|0)|0}}while(0);zb=c[qa>>2]|0;do{if(!((zb|0)==0|(ob|0)==0&(nb|0)==(-2147483648|0))){oc=zb+8|0;if(!((c[oc>>2]|0)==(ob|0)&(c[oc+4>>2]|0)==(nb|0))){break}if((c[zb+32>>2]|0)!=(c[_>>2]|0)){break}if((c[(c[Y>>2]|0)+48>>2]|0)!=94212){break}oc=Eb+28|0;if((N1(zb,c[oc>>2]|0)|0)<0){Xb=0;break i}nc=c[oc>>2]|0;nrc((c[zb+24>>2]|0)+((c[zb+28>>2]|0)-nc)|0,c[Bb>>2]|0,nc)|0;P1(yb);kJb(Eb);Xb=0;break i}}while(0);tJb(R,sa,Eb);c[qa>>2]=yb;Xb=0;break i}}while(0);if((c[F>>2]|0)==(lb|0)){Xb=hc;break}mJb(pa);Xb=hc}}while(0);if((Xb|0)!=0){ja=Xb;ka=na;break f}}if((ob|0)==0&(nb|0)==(-2147483648|0)){pc=-2147483648;qc=0}else{Ab=(sb|0)==(ub|0)&(rb|0)==(tb|0);Bb=wrc(vb,wb,ob,nb)|0;pc=Ab?-2147483648:G;qc=Ab?0:Bb}Bb=c[xb>>2]|0;if((qb|0)>=(oa|0)){ja=0;ka=na;break f}lb=lb+Bb|0;mb=mb-Bb|0;nb=pc;ob=qc;pb=qb}if((V|0)==68){KIb(c[ha>>2]|0,16,2218296,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;ja=0;ka=na;break}else if((V|0)==79){KIb(c[ha>>2]|0,16,2625312,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;ja=-1094995529;ka=na;break}else if((V|0)==82){KIb(c[ha>>2]|0,16,2599672,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;ja=-1094995529;ka=na;break}else if((V|0)==88){KIb(c[ha>>2]|0,16,2574896,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;ja=-1094995529;ka=na;break}else if((V|0)==98){kJb(Mb);ja=-12;ka=na;break}else if((V|0)==121){kJb(Vb);ja=-12;ka=na;break}else if((V|0)==125){kJb(Vb);ja=-12;ka=na;break}else if((V|0)==128){kJb(Vb);ja=-Wb|0;ka=na;break}}}while(0);kJb(ka);N=ja;i=x;return N|0}}while(0);KIb(c[b>>2]|0,32,2320184,(M=i,i=i+24|0,c[M>>2]=f,c[M+8>>2]=P,c[M+16>>2]=O,M)|0);i=M;N=-1094995529;i=x;return N|0}function CK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[a>>2]|0)==0){return}else{d=0}do{e=c[a+(d*24|0)+12>>2]|0;f=b+e|0;g=c[a+(d*24|0)+4>>2]|0;do{if((g|0)==3|(g|0)==4){mJb(f)}else if((g|0)==5){mJb(b+(e+4)|0)}else if((g|0)==6){h=a+(d*24|0)+8|0;if((c[h>>2]|0)==0){CK(c[a+(d*24|0)+16>>2]|0,f);break}i=b+(e+4)|0;j=f;if((c[j>>2]|0)>0){k=a+(d*24|0)+16|0;l=0;m=c[i>>2]|0;while(1){CK(c[k>>2]|0,m);n=l+1|0;if((n|0)<(c[j>>2]|0)){l=n;m=m+(c[h>>2]|0)|0}else{break}}}kJb(c[i>>2]|0)}}while(0);d=d+1|0;}while((c[a+(d*24|0)>>2]|0)!=0);return}function DK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+72|0;f=e|0;g=e+8|0;h=e+16|0;j=c[a>>2]|0;k=c[b>>2]|0;c[f>>2]=k;if(k>>>0>9999999>>>0){l=-1094995529;i=e;return l|0}m=d+16|0;n=c[m>>2]|0;o=c[m+4>>2]|0;m=2;p=0;q=3;r=0;a:do{if((n|0)==0&(o|0)==0){mrc(h|0,0,56)|0;if((_pc(h,2107360,56)|0)!=0){l=-1;i=e;return l|0}c[h>>2]=j;c[h+4>>2]=c[f>>2];s=h+20|0;t=h+16|0;u=h+12|0;v=0;w=k;while(1){x=w*3|0;y=iJb(v,x)|0;if((y|0)==0){z=15;break}A=c[s>>2]|0;c[t>>2]=x-A;c[u>>2]=y+A;B=$pc(h,0)|0;if((B|0)==0&(x|0)<1e7){v=y;w=x}else{break}}if((z|0)==15){cqc(h)|0;C=v;D=0;z=20;break}w=c[s>>2]|0;cqc(h)|0;if((B|0)==1){E=y;F=w;z=19;break}else if((B|0)==(-4|0)){C=y;D=-12;z=20;break}C=y;D=-1094995529;z=20}else if((n|0)==(q|0)&(o|0)==(r|0)){w=c[d+24>>2]|0;u=c[d+28>>2]|0;t=(w|0)!=0;if(t&(u|0)==0){KIb(0,16,2130560,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;l=-1;i=e;return l|0}if(!t){l=0;i=e;return l|0}t=w+k|0;x=hJb(t)|0;if((x|0)==0){l=-12;i=e;return l|0}else{nrc(x|0,u|0,w)|0;nrc(x+w|0,j|0,c[f>>2]|0)|0;E=x;F=t;z=19;break}}else if((n|0)==(m|0)&(o|0)==(p|0)){t=0;x=k;while(1){G=x*3|0;c[g>>2]=G;H=iJb(t,G+12|0)|0;if((H|0)==0){C=t;D=-12;z=20;break a}I=SIb(H,g,j,f)|0;if((I|0)==2&(G|0)<1e7){t=H;x=G}else{break}}if((I|0)!=0){C=H;D=-1094995529;z=20;break}E=H;F=G-(c[g>>2]|0)|0;z=19}else{l=-1094995529;i=e;return l|0}}while(0);if((z|0)==19){c[a>>2]=E;c[b>>2]=F;l=0;i=e;return l|0}else if((z|0)==20){kJb(C);l=D;i=e;return l|0}return 0}function EK(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;h=zD(b)|0;if((h|0)==0){if((jD(b)|0)!=0){j=-541478725;i=g;return j|0}k=fD(b,0,0,1)|0;l=G;KIb(c[a>>2]|0,16,2493048,(m=i,i=i+32|0,c[m>>2]=k,c[m+8>>2]=l,c[m+16>>2]=k,c[m+24>>2]=l,m)|0);i=m;l=c[b+76>>2]|0;j=(l|0)==0?-5:l;i=g;return j|0}l=d[1359664+h|0]|0;k=8-l|0;if((k|0)>(e|0)){e=fD(b,0,0,1)|0;n=wrc(e,G,-1,-1)|0;e=G;KIb(c[a>>2]|0,16,2483032,(m=i,i=i+40|0,c[m>>2]=h&255,c[m+8>>2]=n,c[m+16>>2]=e,c[m+24>>2]=n,c[m+32>>2]=e,m)|0);i=m;j=-1094995529;i=g;return j|0}m=1<<l^h;h=m;l=(m|0)<0|0?-1:0;if((k|0)>1){m=1;e=l;n=h;while(1){a=m+1|0;o=zD(b)|0;p=o|(n<<8|0>>>24);q=((o|0)<0|0?-1:0)|(e<<8|n>>>24);if((a|0)<(k|0)){m=a;e=q;n=p}else{r=q;s=p;break}}}else{r=l;s=h}c[f>>2]=s;c[f+4>>2]=r;j=k;i=g;return j|0}function FK(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;f=i;i=i+8|0;j=f|0;l=b|0;m=c[(c[l>>2]|0)+16>>2]|0;n=c[d>>2]|0;o=c[d+12>>2]|0;p=e+o|0;q=d+8|0;r=c[q>>2]|0;do{if((r|0)==0){s=p}else{t=e+(o+4)|0;u=p;v=nJb(c[t>>2]|0,(c[u>>2]|0)+1|0,r)|0;if((v|0)==0){w=-12;i=f;return w|0}else{c[t>>2]=v;t=c[q>>2]|0;x=v+(ca(t,c[u>>2]|0)|0)|0;mrc(x|0,0,t|0)|0;c[u>>2]=(c[u>>2]|0)+1;s=x;break}}}while(0);q=d+4|0;r=c[q>>2]|0;do{if((r-7|0)>>>0<2>>>0){y=r}else{c[b+268>>2]=0;p=EK(b,m,8,j)|0;do{if((p|0)>0){o=wrc(c[j>>2]|0,c[j+4>>2]|0,1,0)|0;e=G;x=yrc(1,0,p*7|0|0)|0;if(!((o|0)==(x|0)&(e|0)==(G|0))){break}c[j>>2]=-1;c[j+4>>2]=16777215}else{if((p|0)<0){w=p}else{break}i=f;return w|0}}while(0);p=c[q>>2]|0;e=1514712+(p<<3)|0;x=c[e>>2]|0;o=c[e+4>>2]|0;if(!((p-1|0)>>>0<5>>>0)){y=p;break}e=c[j>>2]|0;u=c[j+4>>2]|0;if(!(u>>>0>o>>>0|u>>>0==o>>>0&e>>>0>x>>>0)){y=p;break}KIb(c[l>>2]|0,16,2463824,(z=i,i=i+40|0,c[z>>2]=e,c[z+8>>2]=u,c[z+16>>2]=x,c[z+24>>2]=o,c[z+32>>2]=p,z)|0);i=z;w=-1094995529;i=f;return w|0}}while(0);a:do{switch(y|0){case 9:{q=c[j>>2]|0;r=s;if((q|0)>8){A=60;break a}if((q|0)==0){c[r>>2]=0;c[r+4>>2]=0;w=0;i=f;return w|0}p=(zD(m)|0)<<24>>24;o=p;x=(p|0)<0|0?-1:0;c[r>>2]=o;c[r+4>>2]=x;if((q|0)>1){B=x;C=o;D=1}else{w=0;i=f;return w|0}while(1){o=D+1|0;x=zD(m)|0;p=x|(C<<8|0>>>24);u=((x|0)<0|0?-1:0)|(B<<8|C>>>24);c[r>>2]=p;c[r+4>>2]=u;if((o|0)<(q|0)){B=u;C=p;D=o}else{w=0;break}}i=f;return w|0};case 1:{q=c[j>>2]|0;r=s;if((q|0)>8){A=60;break a}c[r>>2]=0;c[r+4>>2]=0;if((q|0)>0){E=0;F=0;H=0}else{w=0;i=f;return w|0}while(1){o=H+1|0;p=zD(m)|0;u=p|(F<<8|0>>>24);x=((p|0)<0|0?-1:0)|(E<<8|F>>>24);c[r>>2]=u;c[r+4>>2]=x;if((o|0)<(q|0)){E=x;F=u;H=o}else{w=0;break}}i=f;return w|0};case 2:{q=c[j>>2]|0;r=s;if((q|0)==0){h[r>>3]=0.0;w=0;i=f;return w|0}else if((q|0)==4){o=JD(m)|0;h[r>>3]=(c[k>>2]=o,+g[k>>2]);w=0;i=f;return w|0}else if((q|0)==8){q=OD(m)|0;o=G;h[r>>3]=(c[k>>2]=q,c[k+4>>2]=o,+h[k>>3]);w=0;i=f;return w|0}else{A=60;break a}break};case 3:case 4:{o=c[j>>2]|0;q=s;r=hJb(o+1|0)|0;if((r|0)==0){w=-12;i=f;return w|0}if((AD(m,r,o)|0)!=(o|0)){kJb(r);A=61;break a}a[r+o|0]=0;kJb(c[q>>2]|0);c[q>>2]=r;w=0;i=f;return w|0};case 5:{r=c[j>>2]|0;q=s+4|0;o=q;u=s;A4a(q,u,r);if((c[o>>2]|0)==0){w=-12;i=f;return w|0}c[u>>2]=r;x=fD(m,0,0,1)|0;p=s+8|0;c[p>>2]=x;c[p+4>>2]=G;if((AD(m,c[o>>2]|0,r)|0)==(r|0)){w=0;i=f;return w|0}else{mJb(q);c[u>>2]=0;A=61;break a}break};case 6:{u=c[l>>2]|0;q=b+4|0;r=c[q>>2]|0;if((r|0)>15){KIb(u,16,2424792,(z=i,i=i+8|0,c[z>>2]=16,z)|0);i=z;w=-38;i=f;return w|0}o=c[j>>2]|0;p=c[j+4>>2]|0;x=c[u+16>>2]|0;c[q>>2]=r+1;u=fD(x,0,0,1)|0;x=b+8+(r<<4)|0;c[x>>2]=u;c[x+4>>2]=G;x=b+8+(r<<4)+8|0;c[x>>2]=o;c[x+4>>2]=p;if((n|0)==408125543){p=fD(c[(c[l>>2]|0)+16>>2]|0,0,0,1)|0;x=b+360|0;c[x>>2]=p;c[x+4>>2]=G}x=c[d+16>>2]|0;b:do{if((c[x>>2]|0)!=0){p=0;c:while(1){o=c[x+(p*24|0)+4>>2]|0;do{if((o|0)==1){r=x+(p*24|0)+16|0;u=c[r+4>>2]|0;e=s+(c[x+(p*24|0)+12>>2]|0)|0;c[e>>2]=c[r>>2];c[e+4>>2]=u}else if((o|0)==2){h[s+(c[x+(p*24|0)+12>>2]|0)>>3]=+h[x+(p*24|0)+16>>3]}else if((o|0)==3|(o|0)==4){u=c[x+(p*24|0)+16>>2]|0;if((u|0)==0){break}e=s+(c[x+(p*24|0)+12>>2]|0)|0;r=rJb(u)|0;c[e>>2]=r;if((r|0)==0){w=-12;break c}}}while(0);p=p+1|0;if((c[x+(p*24|0)>>2]|0)==0){break b}}i=f;return w|0}}while(0);p=b+268|0;while(1){o=fD(c[(c[l>>2]|0)+16>>2]|0,0,0,1)|0;r=c[q>>2]|0;if((r|0)>0){I=r-1|0;r=b+8+(I<<4)|0;e=xrc(o,G,c[r>>2]|0,c[r+4>>2]|0)|0;r=G;o=b+8+(I<<4)+8|0;u=c[o+4>>2]|0;if(!(r>>>0<u>>>0|r>>>0==u>>>0&e>>>0<(c[o>>2]|0)>>>0)){break}if((c[p>>2]|0)!=0){break}}o=AK(b,x,s)|0;if((o|0)!=0){w=o;A=62;break}}if((A|0)==62){i=f;return w|0}c[q>>2]=I;w=0;i=f;return w|0};case 7:{x=c[d+16>>2]|0;p=0;while(1){J=x+(p*24|0)|0;o=c[J>>2]|0;K=(o|0)==0;if(K|(o|0)==(n|0)){break}else{p=p+1|0}}do{if(K&(n|0)==524531317){p=c[b+4>>2]|0;if((p|0)<=0){break}x=b+8+(p-1<<4)+8|0;if((c[x>>2]|0)==(-1|0)&(c[x+4>>2]|0)==16777215){w=0}else{break}i=f;return w|0}}while(0);do{if(K){if((n|0)==236|(n|0)==191){break}KIb(c[l>>2]|0,32,2471824,(z=i,i=i+8|0,c[z>>2]=n,z)|0);i=z;if((c[(c[l>>2]|0)+1156>>2]&8|0)==0){break}else{w=-1094995529}i=f;return w|0}}while(0);w=FK(b,J,s)|0;i=f;return w|0};case 8:{w=1;i=f;return w|0};default:{x=c[j>>2]|0;p=c[j+4>>2]|0;q=eX(m,x)|0;if(!((q|0)==(x|0)&(((q|0)<0|0?-1:0)|0)==(p|0))){w=-5;i=f;return w|0}q=hD(m,x,p)|0;p=G;x=0;w=(p|0)<(x|0)|(p|0)==(x|0)&q>>>0<0>>>0?-5:0;i=f;return w|0}}}while(0);if((A|0)==60){KIb(c[l>>2]|0,16,2449496,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;w=-1094995529;i=f;return w|0}else if((A|0)==61){KIb(c[l>>2]|0,16,2433648,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;w=-5;i=f;return w|0}return 0}function GK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;e=c[a+356>>2]|0;f=a+264|0;g=c[f>>2]|0;h=a|0;j=fD(c[(c[h>>2]|0)+16>>2]|0,0,0,1)|0;k=G;l=a+268|0;m=c[l>>2]|0;if((c[a+352>>2]|0)<=(b|0)){n=0;i=d;return n|0}o=e;e=o+(b<<4)|0;p=c[e>>2]|0;q=c[e+4>>2]|0;if((p|0)==290298740&(q|0)==0|(p|0)==524531317&(q|0)==0){n=0;i=d;return n|0}q=o+(b<<4)+8|0;b=a+360|0;o=wrc(c[b>>2]|0,c[b+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;q=G;b=fD(c[(c[h>>2]|0)+16>>2]|0,o,q,0)|0;a:do{if((b|0)==(o|0)&(G|0)==(q|0)){p=a+4|0;e=c[p>>2]|0;if((e|0)==16){KIb(c[h>>2]|0,32,2406280,(r=i,i=i+8|0,c[r>>2]=16,r)|0);i=r;s=-1094995529;break}r=a+8+(e<<4)|0;c[r>>2]=0;c[r+4>>2]=0;r=a+8+(e<<4)+8|0;c[r>>2]=-1;c[r+4>>2]=-1;c[p>>2]=(c[p>>2]|0)+1;c[l>>2]=0;r=AK(a,835472,a)|0;e=c[p>>2]|0;while(1){if((e|0)==0){s=r;break a}t=e-1|0;c[p>>2]=t;u=a+8+(t<<4)+8|0;if((c[u>>2]|0)==(-1|0)&(c[u+4>>2]|0)==(-1|0)){s=r;break}else{e=t}}}else{s=0}}while(0);fD(c[(c[h>>2]|0)+16>>2]|0,j,k,0)|0;c[f>>2]=g;c[l>>2]=m;n=s;i=d;return n|0}function HK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;d=c[a+340>>2]|0;e=d;f=a+336|0;g=c[f>>2]|0;if((g|0)==0){i=b;return}h=d;d=a+272|0;if(+((c[h>>2]|0)>>>0)+ +((c[h+4>>2]|0)>>>0)*4294967296.0>1.0e14/(+((c[d>>2]|0)>>>0)+ +((c[d+4>>2]|0)>>>0)*4294967296.0)){KIb(c[a>>2]|0,24,2413880,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=c[d>>2]|0;k=(h|0)<0|0?-1:0;l=h;m=c[f>>2]|0}else{k=0;l=1;m=g}if((m|0)<=0){i=b;return}g=a+316|0;h=a+312|0;d=a+360|0;n=a|0;a=0;o=m;while(1){m=c[e+(a<<4)+12>>2]|0;p=e+(a<<4)+8|0;if((c[p>>2]|0)>0){q=e+(a<<4)|0;r=0;do{s=c[m+(r<<4)>>2]|0;t=c[g>>2]|0;u=c[h>>2]|0;v=s;w=(s|0)<0|0?-1:0;x=0;while(1){if((x|0)>=(u|0)){y=11;break}z=t+(x*296|0)|0;A=z|0;if((c[A>>2]|0)==(v|0)&(c[A+4>>2]|0)==(w|0)){y=12;break}else{x=x+1|0}}do{if((y|0)==11){y=0;KIb(c[n>>2]|0,16,2507448,(j=i,i=i+8|0,c[j>>2]=s,j)|0);i=j}else if((y|0)==12){y=0;if((z|0)==0){break}w=c[t+(x*296|0)+264>>2]|0;if((w|0)==0){break}v=m+(r<<4)+8|0;u=wrc(c[d>>2]|0,c[d+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;v=G;A=Frc(c[q>>2]|0,c[q+4>>2]|0,l,k)|0;xX(w,u,v,A,G,0,0,1)|0}}while(0);r=r+1|0;}while((r|0)<(c[p>>2]|0));B=c[f>>2]|0}else{B=o}p=a+1|0;if((p|0)<(B|0)){a=p;o=B}else{break}}i=b;return}function IK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1024|0;g=c[b+4>>2]|0;h=b|0;if((c[h>>2]|0)<=0){cL(d,0,1353480);i=f;return}b=a;j=f|0;if((e|0)==0){k=0;do{l=c[g+(k<<5)+8>>2]|0;if((l|0)==0){m=0}else{n=(irc(l,2398688)|0)==0;m=n?0:l}l=c[g+(k<<5)>>2]|0;do{if((l|0)==0){KIb(b,24,2217688,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}else{CFb(j,l,1024)|0;n=g+(k<<5)+16|0;p=(m|0)==0;do{if((c[n>>2]|0)!=0|(c[n+4>>2]|0)!=0|p){MGb(d,j,c[g+(k<<5)+4>>2]|0,0)|0;q=g+(k<<5)+24|0;if((c[q>>2]|0)==0){break}IK(a,q,d,j)}}while(0);if(p){break}DFb(j,2212392,1024)|0;DFb(j,m,1024)|0;MGb(d,j,c[g+(k<<5)+4>>2]|0,0)|0;n=g+(k<<5)+24|0;if((c[n>>2]|0)==0){break}IK(a,n,d,j)}}while(0);k=k+1|0;}while((k|0)<(c[h>>2]|0));cL(d,0,1353480);i=f;return}else{k=0;do{m=c[g+(k<<5)+8>>2]|0;if((m|0)==0){r=0}else{l=(irc(m,2398688)|0)==0;r=l?0:m}m=c[g+(k<<5)>>2]|0;do{if((m|0)==0){KIb(b,24,2217688,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}else{Rb(j|0,1024,2214872,(o=i,i=i+16|0,c[o>>2]=e,c[o+8>>2]=m,o)|0)|0;i=o;l=g+(k<<5)+16|0;n=(r|0)==0;do{if((c[l>>2]|0)!=0|(c[l+4>>2]|0)!=0|n){MGb(d,j,c[g+(k<<5)+4>>2]|0,0)|0;q=g+(k<<5)+24|0;if((c[q>>2]|0)==0){break}IK(a,q,d,j)}}while(0);if(n){break}DFb(j,2212392,1024)|0;DFb(j,r,1024)|0;MGb(d,j,c[g+(k<<5)+4>>2]|0,0)|0;l=g+(k<<5)+24|0;if((c[l>>2]|0)==0){break}IK(a,l,d,j)}}while(0);k=k+1|0;}while((k|0)<(c[h>>2]|0));cL(d,0,1353480);i=f;return}}function JK(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0.0,Rb=0.0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0;b=i;i=i+856|0;e=b|0;f=b+264|0;g=b+280|0;j=b+296|0;l=b+320|0;m=b+336|0;n=b+352|0;o=b+368|0;p=b+376|0;q=b+384|0;r=b+432|0;s=b+448|0;t=b+464|0;u=b+472|0;v=b+480|0;w=b+496|0;x=b+504|0;y=b+520|0;z=b+536|0;A=b+552|0;B=b+568|0;C=b+584|0;D=b+848|0;E=a+12|0;H=c[E>>2]|0;I=a+16|0;J=c[I>>2]|0;K=a+8|0;L=(irc(c[c[K>>2]>>2]|0,2265936)|0)==0;M=H+4|0;c[M>>2]=L?2:1;L=a+1204|0;if((c[L>>2]|0)<0){c[L>>2]=1}L=a+24|0;N=c[L>>2]|0;do{if((N|0)==0){O=0}else{P=c[a+28>>2]|0;S=0;while(1){T=c[(c[(c[P+(S<<2)>>2]|0)+8>>2]|0)+48>>2]|0;if((T|0)==86047|(T|0)==86036|(T|0)==77825|(T|0)==86058|(T|0)==6|(T|0)==7){break}U=S+1|0;if(U>>>0<N>>>0){S=U}else{V=8;break}}if((V|0)==8){O=N<<3;break}S=u5a(T)|0;KIb(a,16,2278648,(W=i,i=i+8|0,c[W>>2]=S,W)|0);i=W;X=-1163346256;i=b;return X|0}}while(0);T=pJb(O)|0;c[H+96>>2]=T;if((T|0)==0){X=-12;i=b;return X|0}TK(y,J,440786851,0,0);T=y|0;O=c[T>>2]|0;N=c[T+4>>2]|0;T=c[y+8>>2]|0;y=d[1359730]|0;S=(y+20|0)>>>0<7>>>0;do{if(S){SK(J,1,0,0);bD(J,1);V=17}else{P=(y+7|0)/7|0;while(1){bD(J,17030>>>(P<<3>>>0)&255);if((P|0)==0){break}else{P=P-1|0}}SK(J,1,0,0);bD(J,1);if(S){SK(J,1,0,0);bD(J,1);V=21;break}P=(y+7|0)/7|0;while(1){bD(J,17143>>>(P<<3>>>0)&255);if((P|0)==0){V=17;break}else{P=P-1|0}}}}while(0);do{if((V|0)==17){SK(J,1,0,0);bD(J,1);if(S){SK(J,1,0,0);bD(J,4);V=25;break}P=(y+7|0)/7|0;while(1){bD(J,17138>>>(P<<3>>>0)&255);if((P|0)==0){V=21;break}else{P=P-1|0}}}}while(0);do{if((V|0)==21){SK(J,1,0,0);bD(J,4);if(S){SK(J,1,0,0);bD(J,8);UK(J,17026,c[c[K>>2]>>2]|0);V=29;break}P=(y+7|0)/7|0;while(1){bD(J,17139>>>(P<<3>>>0)&255);if((P|0)==0){V=25;break}else{P=P-1|0}}}}while(0);do{if((V|0)==25){SK(J,1,0,0);bD(J,8);UK(J,17026,c[c[K>>2]>>2]|0);if(S){SK(J,1,0,0);bD(J,4);break}P=(y+7|0)/7|0;while(1){bD(J,17031>>>(P<<3>>>0)&255);if((P|0)==0){V=29;break}else{P=P-1|0}}}}while(0);do{if((V|0)==29){SK(J,1,0,0);bD(J,4);if(S){break}K=(y+7|0)/7|0;while(1){bD(J,17029>>>(K<<3>>>0)&255);if((K|0)==0){break}else{K=K-1|0}}}}while(0);SK(J,1,0,0);bD(J,2);y=fD(J,0,0,1)|0;S=G;K=xrc(O,N,T,(T|0)<0|0?-1:0)|0;P=fD(J,K,G,0)|0;K=G;U=0;if(!((K|0)<(U|0)|(K|0)==(U|0)&P>>>0<0>>>0)){P=xrc(y,S,O,N)|0;SK(J,P,G,T);fD(J,y,S,0)|0;}S=H+16|0;TK(z,J,408125543,0,0);y=z;c[S>>2]=c[y>>2];c[S+4>>2]=c[y+4>>2];c[S+8>>2]=c[y+8>>2];c[S+12>>2]=c[y+12>>2];y=fD(J,0,0,1)|0;S=G;z=H+32|0;c[z>>2]=y;c[z+4>>2]=S;T=pJb(32)|0;if((T|0)==0){c[H+88>>2]=0;X=-12;i=b;return X|0}P=T+8|0;c[P>>2]=y;c[P+4>>2]=S;S=fD(J,0,0,1)|0;y=T;c[y>>2]=S;c[y+4>>2]=G;c[T+16>>2]=223;y=T+20|0;c[y>>2]=10;QK(J,223,0);S=H+88|0;c[S>>2]=T;N=fD(J,0,0,1)|0;O=G;U=T+24|0;K=c[y>>2]|0;y=T+28|0;T=c[y>>2]|0;if(!((K|0)<1|(K|0)>(T|0))){X=-1;i=b;return X|0}K=nJb(c[U>>2]|0,T+1|0,16)|0;T=K;if((K|0)==0){X=-12;i=b;return X|0}c[U>>2]=T;c[T+(c[y>>2]<<4)>>2]=357149030;U=xrc(N,O,c[P>>2]|0,c[P+4>>2]|0)|0;P=c[y>>2]|0;c[y>>2]=P+1;y=T+(P<<4)+8|0;c[y>>2]=U;c[y+4>>2]=G;TK(A,J,357149030,0,0);y=A|0;U=c[y>>2]|0;P=c[y+4>>2]|0;y=c[A+8>>2]|0;A=d[1359706]|0;if(!((A+28|0)>>>0<7>>>0)){T=(A+15|0)/7|0;while(1){bD(J,2807729>>>(T<<3>>>0)&255);if((T|0)==0){break}else{T=T-1|0}}}SK(J,3,0,0);bD(J,15);bD(J,66);bD(J,64);T=a+1140|0;A=LGb(c[T>>2]|0,2377928,0,0)|0;if((A|0)!=0){UK(J,31657,c[A+4>>2]|0)}A=a+28|0;if((c[(c[(c[c[A>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)==0){AIb(C,wKb()|0);O=C+256|0;N=c[O>>2]|0;c[C+((N&63)<<2)>>2]=(c[C+((N+9&63)<<2)>>2]|0)+(c[C+((N+40&63)<<2)>>2]|0);N=c[O>>2]|0;K=N+1|0;c[O>>2]=K;c[B>>2]=c[C+((N&63)<<2)>>2];c[C+((K&63)<<2)>>2]=(c[C+((N+10&63)<<2)>>2]|0)+(c[C+((N+41&63)<<2)>>2]|0);N=c[O>>2]|0;K=N+1|0;c[O>>2]=K;c[B+4>>2]=c[C+((N&63)<<2)>>2];c[C+((K&63)<<2)>>2]=(c[C+((N+10&63)<<2)>>2]|0)+(c[C+((N+41&63)<<2)>>2]|0);N=c[O>>2]|0;K=N+1|0;c[O>>2]=K;c[B+8>>2]=c[C+((N&63)<<2)>>2];c[C+((K&63)<<2)>>2]=(c[C+((N+10&63)<<2)>>2]|0)+(c[C+((N+41&63)<<2)>>2]|0);N=c[O>>2]|0;c[O>>2]=N+1;c[B+12>>2]=c[C+((N&63)<<2)>>2];UK(J,19840,2274480);N=LGb(c[T>>2]|0,2269312,0,0)|0;if((N|0)==0){UK(J,22337,2274480)}else{UK(J,22337,c[N+4>>2]|0)}N=B;B=d[1359779]|0;if(!((B+20|0)>>>0<7>>>0)){C=(B+7|0)/7|0;while(1){bD(J,29604>>>(C<<3>>>0)&255);if((C|0)==0){break}else{C=C-1|0}}}bD(J,144);dD(J,N,16)}else{UK(J,19840,2265376);UK(J,22337,2265376)}N=LGb(c[T>>2]|0,2261712,0,0)|0;if((N|0)!=0){C=pY(c[N+4>>2]|0)|0;N=Erc(C,G,1e9,0)|0;C=wrc(N,G,-288686080,-227779896)|0;N=G;B=je(C|0)|0;C=D;c[D>>2]=je(N|0)|0;c[D+4>>2]=B;B=d[1359732]|0;if(!((B+20|0)>>>0<7>>>0)){D=(B+7|0)/7|0;while(1){bD(J,17505>>>(D<<3>>>0)&255);if((D|0)==0){break}else{D=D-1|0}}}bD(J,136);dD(J,C,8)}C=H+80|0;c[C>>2]=0;c[C+4>>2]=0;C=fD(J,0,0,1)|0;D=H+72|0;c[D>>2]=C;c[D+4>>2]=G;QK(J,11,0);D=fD(J,0,0,1)|0;C=G;B=xrc(U,P,y,(y|0)<0|0?-1:0)|0;N=fD(J,B,G,0)|0;B=G;O=0;if(!((B|0)<(O|0)|(B|0)==(O|0)&N>>>0<0>>>0)){N=xrc(D,C,U,P)|0;SK(J,N,G,y);fD(J,D,C,0)|0;}C=w;D=c[E>>2]|0;y=c[I>>2]|0;N=c[D+88>>2]|0;P=fD(y,0,0,1)|0;U=G;O=N+24|0;B=c[N+20>>2]|0;K=N+28|0;Y=c[K>>2]|0;a:do{if((B|0)<1|(B|0)>(Y|0)){Z=nJb(c[O>>2]|0,Y+1|0,16)|0;_=Z;if((Z|0)==0){$=-12;break}c[O>>2]=_;c[_+(c[K>>2]<<4)>>2]=374648427;Z=N+8|0;aa=xrc(P,U,c[Z>>2]|0,c[Z+4>>2]|0)|0;Z=c[K>>2]|0;c[K>>2]=Z+1;ca=_+(Z<<4)+8|0;c[ca>>2]=aa;c[ca+4>>2]=G;TK(r,y,374648427,0,0);ca=r|0;aa=c[ca>>2]|0;Z=c[ca+4>>2]|0;ca=c[r+8>>2]|0;_=c[L>>2]|0;b:do{if((_|0)!=0){da=c[A>>2]|0;ea=0;fa=0;do{ea=c[(c[da+(fa<<2)>>2]|0)+72>>2]&1|ea;fa=fa+1|0;}while(fa>>>0<_>>>0);fa=D+184|0;ga=a;ia=q+8|0;ja=q+28|0;ka=s|0;la=s+8|0;ma=d[1359880]|0;na=(ma+12|0)>>>0<7>>>0;oa=d[1359779]|0;pa=(oa+20|0)>>>0<7>>>0;qa=d[1359821]|0;ra=(qa+12|0)>>>0<7>>>0;sa=D+4|0;ta=(ea|0)==0;ua=t|0;va=t+4|0;wa=u|0;xa=u+4|0;ya=d[1359750]|0;za=(ya+20|0)>>>0<7>>>0;Aa=(ya+7|0)/7|0;ya=d[1359763]|0;Ba=(ya+20|0)>>>0<7>>>0;Ca=(ya+7|0)/7|0;ya=m|0;Da=n|0;Ea=n+4|0;Fa=m+4|0;Ga=m+8|0;Ha=n+8|0;Ia=d[1359796]|0;Ja=(Ia+12|0)>>>0<7>>>0;Ka=(Ia-1|0)/7|0;Ia=x|0;La=x+8|0;Ma=d[1359824]|0;Na=(Ma+12|0)>>>0<7>>>0;Oa=d[1359846]|0;Pa=(Oa+12|0)>>>0<7>>>0;Qa=(Oa-1|0)/7|0;Oa=d[1359762]|0;Ra=(Oa+20|0)>>>0<7>>>0;Sa=(Oa+7|0)/7|0;Oa=d[1359784]|0;Ta=(Oa+20|0)>>>0<7>>>0;Ua=(Oa+7|0)/7|0;Oa=(Ma-1|0)/7|0;Ma=d[1359699]|0;Va=(Ma+28|0)>>>0<7>>>0;Wa=(Ma+15|0)/7|0;Ma=v|0;Xa=v+8|0;Ya=d[1359841]|0;Za=(Ya+12|0)>>>0<7>>>0;_a=d[1359851]|0;$a=(_a+12|0)>>>0<7>>>0;ab=d[1359748]|0;bb=(ab+20|0)>>>0<7>>>0;cb=(ab+7|0)/7|0;ab=d[1359710]|0;db=(ab+28|0)>>>0<7>>>0;eb=(ab+15|0)/7|0;ab=d[1359747]|0;fb=(ab+20|0)>>>0<7>>>0;gb=(ab+7|0)/7|0;ab=(_a-1|0)/7|0;_a=(Ya-1|0)/7|0;Ya=D+96|0;hb=d[1359749]|0;ib=(hb+20|0)>>>0<7>>>0;jb=(hb+7|0)/7|0;hb=d[1359801]|0;kb=(hb+12|0)>>>0<7>>>0;lb=(hb-1|0)/7|0;hb=(qa-1|0)/7|0;qa=(oa+7|0)/7|0;oa=(ma-1|0)/7|0;ma=0;mb=da;c:while(1){nb=c[mb+(ma<<2)>>2]|0;ob=c[nb+8>>2]|0;pb=ob+48|0;qb=g5a(c[pb>>2]|0)|0;rb=ob+412|0;sb=c[rb>>2]|0;tb=ob+8|0;if((c[tb>>2]|0)==4){c[fa>>2]=1;ub=ma+1|0}else{do{if((qb|0)==0){if((c[pb>>2]|0)!=69643){vb=(QKb(c[ob+420>>2]|0)|0)<<3;if((vb|0)!=0){wb=vb;break}}wb=c[ob+792>>2]|0}else{wb=qb}}while(0);do{if((c[pb>>2]|0)==86018){if((CRa(q,c[ob+96>>2]|0,c[ob+100>>2]<<3,1)|0)<0){KIb(ga,24,2158960,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;xb=0;yb=sb;break}else{xb=c[ja>>2]|0;yb=c[ia>>2]|0;break}}else{xb=0;yb=sb}}while(0);TK(s,y,174,0,0);sb=c[ka>>2]|0;qb=c[ka+4>>2]|0;vb=c[la>>2]|0;zb=ma+1|0;Ab=zb;Bb=(zb|0)<0|0?-1:0;Cb=Bb;Db=Ab;Eb=1;while(1){Fb=Db>>>8|Cb<<24;Gb=Cb>>>8|0<<24;if((Fb|0)==0&(Gb|0)==0){break}else{Cb=Gb;Db=Fb;Eb=Eb+1|0}}if(!na){Db=oa;while(1){bD(y,215>>>(Db<<3>>>0)&255);if((Db|0)==0){break}else{Db=Db-1|0}}}SK(y,Eb,(Eb|0)<0|0?-1:0,0);if((Eb|0)>0){Db=Eb;while(1){Cb=Db-1|0;Fb=zrc(Ab|0,Bb|0,Cb<<3|0)|0;bD(y,Fb&255);if((Cb|0)>0){Db=Cb}else{Hb=Bb;Ib=Ab;Jb=1;break}}}else{Hb=Bb;Ib=Ab;Jb=1}while(1){Db=Ib>>>8|Hb<<24;Eb=Hb>>>8|0<<24;if((Db|0)==0&(Eb|0)==0){break}else{Hb=Eb;Ib=Db;Jb=Jb+1|0}}if(!pa){Db=qa;while(1){bD(y,29637>>>(Db<<3>>>0)&255);if((Db|0)==0){break}else{Db=Db-1|0}}}SK(y,Jb,(Jb|0)<0|0?-1:0,0);if((Jb|0)>0){Db=Jb;do{Db=Db-1|0;Eb=zrc(Ab|0,Bb|0,Db<<3|0)|0;bD(y,Eb&255);}while((Db|0)>0)}if(!ra){Db=hb;while(1){bD(y,156>>>(Db<<3>>>0)&255);if((Db|0)==0){break}else{Db=Db-1|0}}}bD(y,129);bD(y,0);Db=nb+88|0;Bb=LGb(c[Db>>2]|0,2377928,0,0)|0;if((Bb|0)!=0){UK(y,21358,c[Bb+4>>2]|0)}Bb=LGb(c[Db>>2]|0,2221016,0,0)|0;do{if((c[sa>>2]|0)==2){if((c[pb>>2]|0)!=1465275476){V=93;break}if((Bb|0)==0){break}Ab=c[Bb+4>>2]|0;if((Ab|0)==0){break}UK(y,2274716,Ab)}else{V=93}}while(0);if((V|0)==93){V=0;if((Bb|0)==0){Kb=2372344}else{Kb=c[Bb+4>>2]|0}UK(y,2274716,Kb)}Ab=nb+72|0;do{if(!ta){if((c[Ab>>2]&1|0)!=0){break}if(!kb){Eb=lb;while(1){bD(y,136>>>(Eb<<3>>>0)&255);if((Eb|0)==0){break}else{Eb=Eb-1|0}}}bD(y,129);bD(y,0)}}while(0);if((c[Ab>>2]&64|0)!=0){if(!ib){Bb=jb;while(1){bD(y,21930>>>(Bb<<3>>>0)&255);if((Bb|0)==0){break}else{Bb=Bb-1|0}}}bD(y,129);bD(y,1)}do{if((c[sa>>2]|0)==2){if((c[pb>>2]|0)!=1465275476){Lb=0;V=114;break}Bb=c[Ab>>2]|0;do{if((Bb&65536|0)==0){if((Bb&131072|0)!=0){Mb=2214816;Nb=33;break}Eb=Bb&262144;Mb=(Eb|0)==0?2210584:2212336;Nb=(Eb>>>14)+17|0}else{Mb=2217664;Nb=17}}while(0);UK(y,134,Mb);Ob=Nb}else{Lb=0;V=114}}while(0);d:do{if((V|0)==114){while(1){V=0;Ab=c[1353528+(Lb*28|0)>>2]|0;if((Ab|0)==0){Ob=0;break d}if((Ab|0)==(c[pb>>2]|0)){break}else{Lb=Lb+1|0;V=114}}UK(y,134,1353504+(Lb*28|0)|0);Ob=1}}while(0);if((c[pb>>2]|0)==1330664787){Ab=c[ob+116>>2]|0;c[ua>>2]=1;c[va>>2]=c[rb>>2];c[wa>>2]=1;c[xa>>2]=1e9;Bb=XIb(Ab,(Ab|0)<0|0?-1:0,t,u)|0;Ab=G;Eb=Ab;Cb=Bb;Fb=1;while(1){Gb=Cb>>>8|Eb<<24;Pb=Eb>>>8|0<<24;if((Gb|0)==0&(Pb|0)==0){break}else{Eb=Pb;Cb=Gb;Fb=Fb+1|0}}if(!za){Cb=Aa;while(1){bD(y,22186>>>(Cb<<3>>>0)&255);if((Cb|0)==0){break}else{Cb=Cb-1|0}}}SK(y,Fb,(Fb|0)<0|0?-1:0,0);if((Fb|0)>0){Cb=Fb;do{Cb=Cb-1|0;Eb=zrc(Bb|0,Ab|0,Cb<<3|0)|0;bD(y,Eb&255);}while((Cb|0)>0)}if(!za){Cb=Aa;while(1){bD(y,22203>>>(Cb<<3>>>0)&255);if((Cb|0)==0){break}else{Cb=Cb-1|0}}}bD(y,132);bD(y,4);bD(y,196);bD(y,180);bD(y,0)}Cb=(c[sa>>2]|0)==2;do{if(Cb){Ab=c[pb>>2]|0;if((Ab|0)==141|(Ab|0)==169|(Ab|0)==86021|(Ab|0)==1465275476){break}else if((Ab|0)!=1330664787){V=130;break c}if(!((c[ob+680>>2]|0)<-1)){V=130;break c}}}while(0);Ab=c[tb>>2]|0;do{if((Ab|0)==0){if(!Ja){Bb=Ka;while(1){bD(y,131>>>(Bb<<3>>>0)&255);if((Bb|0)==0){break}else{Bb=Bb-1|0}}}bD(y,129);bD(y,1);Bb=c[nb+92>>2]|0;do{if((Bb|0)==0){V=144}else{Fb=c[nb+96>>2]|0;if((Fb|0)==0){V=144;break}Qb=+(Bb|0)/+(Fb|0);if(!(1.0/Qb>+(c[ob+104>>2]|0)/+(c[ob+108>>2]|0))){V=144;break}Rb=1.0e9/Qb;Fb=~~+Rb>>>0;Eb=(F=+Rb,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);rb=Eb;Gb=Fb;Pb=1;while(1){Sb=Gb>>>8|rb<<24;Tb=rb>>>8|0<<24;if((Sb|0)==0&(Tb|0)==0){break}else{rb=Tb;Gb=Sb;Pb=Pb+1|0}}if(!Va){Gb=Wa;while(1){bD(y,2352003>>>(Gb<<3>>>0)&255);if((Gb|0)==0){break}else{Gb=Gb-1|0}}}SK(y,Pb,(Pb|0)<0|0?-1:0,0);if((Pb|0)>0){Ub=Pb}else{break}do{Ub=Ub-1|0;Gb=zrc(Fb|0,Eb|0,Ub<<3|0)|0;bD(y,Gb&255);}while((Ub|0)>0)}}while(0);do{if((V|0)==144){V=0;Rb=+(c[ob+104>>2]|0)/+(c[ob+108>>2]|0)*1.0e9;Bb=~~+Rb>>>0;Eb=(F=+Rb,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Fb=Eb;Pb=Bb;Gb=1;while(1){rb=Pb>>>8|Fb<<24;Sb=Fb>>>8|0<<24;if((rb|0)==0&(Sb|0)==0){break}else{Fb=Sb;Pb=rb;Gb=Gb+1|0}}if(!Va){Pb=Wa;while(1){bD(y,2352003>>>(Pb<<3>>>0)&255);if((Pb|0)==0){break}else{Pb=Pb-1|0}}}SK(y,Gb,(Gb|0)<0|0?-1:0,0);if((Gb|0)>0){Vb=Gb}else{break}do{Vb=Vb-1|0;Pb=zrc(Bb|0,Eb|0,Vb<<3|0)|0;bD(y,Pb&255);}while((Vb|0)>0)}}while(0);e:do{if((Ob|0)==0){do{if((IX(1407072,c[pb>>2]|0)|0)!=0){if((IX(1409152,c[pb>>2]|0)|0)!=0){Eb=c[pb>>2]|0;if(!((Eb|0)==23|(Eb|0)==24|(Eb|0)==44)){break}}UK(y,134,2196736);Wb=1;break e}}while(0);UK(y,134,2193984);c[(c[Ya>>2]|0)+(ma<<3)>>2]=1;Wb=0}else{Wb=0}}while(0);TK(v,y,224,0,0);Eb=c[Ma>>2]|0;Bb=c[Ma+4>>2]|0;Gb=c[Xa>>2]|0;Pb=ob+120|0;Fb=c[Pb>>2]|0;rb=Fb;Sb=(Fb|0)<0|0?-1:0;Fb=Sb;Tb=rb;Xb=1;while(1){Yb=Tb>>>8|Fb<<24;Zb=Fb>>>8|0<<24;if((Yb|0)==0&(Zb|0)==0){break}else{Fb=Zb;Tb=Yb;Xb=Xb+1|0}}if(!Za){Tb=_a;while(1){bD(y,176>>>(Tb<<3>>>0)&255);if((Tb|0)==0){break}else{Tb=Tb-1|0}}}SK(y,Xb,(Xb|0)<0|0?-1:0,0);if((Xb|0)>0){Tb=Xb;do{Tb=Tb-1|0;Fb=zrc(rb|0,Sb|0,Tb<<3|0)|0;bD(y,Fb&255);}while((Tb|0)>0)}Tb=ob+124|0;Sb=c[Tb>>2]|0;rb=Sb;Xb=(Sb|0)<0|0?-1:0;Sb=Xb;Fb=rb;Yb=1;while(1){Zb=Fb>>>8|Sb<<24;_b=Sb>>>8|0<<24;if((Zb|0)==0&(_b|0)==0){break}else{Sb=_b;Fb=Zb;Yb=Yb+1|0}}if(!$a){Fb=ab;while(1){bD(y,186>>>(Fb<<3>>>0)&255);if((Fb|0)==0){break}else{Fb=Fb-1|0}}}SK(y,Yb,(Yb|0)<0|0?-1:0,0);if((Yb|0)>0){Fb=Yb;do{Fb=Fb-1|0;Sb=zrc(rb|0,Xb|0,Fb<<3|0)|0;bD(y,Sb&255);}while((Fb|0)>0)}Fb=LGb(c[Db>>2]|0,2225576,0,0)|0;if((Fb|0)==0){Xb=LGb(c[T>>2]|0,2225576,0,0)|0;if((Xb|0)==0){$b=1;ac=1}else{bc=Xb;V=170}}else{bc=Fb;V=170}do{if((V|0)==170){V=0;Fb=bc+4|0;Xb=0;while(1){if((Xb|0)>=15){cc=0;dc=15;break}if((irc(c[Fb>>2]|0,c[1358760+(Xb<<2)>>2]|0)|0)==0){V=173;break}else{Xb=Xb+1|0}}if((V|0)==173){V=0;cc=(Xb|0)<0|0?-1:0;dc=Xb}if((c[sa>>2]|0)==2){Fb=0;rb=0;if((cc>>>0>Fb>>>0|cc>>>0==Fb>>>0&dc>>>0>3>>>0)&((dc|0)!=11|(cc|0)!=0)|(cc>>>0>rb>>>0|cc>>>0==rb>>>0&dc>>>0>14>>>0)){V=177;break c}else{ec=cc;fc=dc;gc=1}}else{rb=0;if(cc>>>0>rb>>>0|cc>>>0==rb>>>0&dc>>>0>14>>>0){V=177;break c}else{ec=cc;fc=dc;gc=1}}while(1){rb=fc>>>8|ec<<24;Fb=ec>>>8|0<<24;if((rb|0)==0&(Fb|0)==0){break}else{ec=Fb;fc=rb;gc=gc+1|0}}if(!fb){Xb=gb;while(1){bD(y,21432>>>(Xb<<3>>>0)&255);if((Xb|0)==0){break}else{Xb=Xb-1|0}}}SK(y,gc,(gc|0)<0|0?-1:0,0);if((gc|0)>0){Xb=gc;do{Xb=Xb-1|0;rb=zrc(dc|0,cc|0,Xb<<3|0)|0;bD(y,rb&255);}while((Xb|0)>0)}Xb=7;rb=0;Fb=6;Yb=0;Sb=3;Zb=0;_b=2;hc=0;if((dc|0)==1&(cc|0)==0|(dc|0)==8&(cc|0)==0|(dc|0)==9&(cc|0)==0|(dc|0)==11&(cc|0)==0){$b=1;ac=2;break}else if((dc|0)==(_b|0)&(cc|0)==(hc|0)|(dc|0)==(Sb|0)&(cc|0)==(Zb|0)|(dc|0)==(Fb|0)&(cc|0)==(Yb|0)|(dc|0)==(Xb|0)&(cc|0)==(rb|0)){$b=2;ac=1;break}else{$b=1;ac=1;break}}}while(0);do{if((LGb(c[Db>>2]|0,2189136,0,0)|0)==0){if((LGb(c[T>>2]|0,2189136,0,0)|0)!=0){V=189;break}if((c[ob+140>>2]|0)==35){V=189}}else{V=189}}while(0);if((V|0)==189){V=0;if(!fb){rb=gb;while(1){bD(y,21440>>>(rb<<3>>>0)&255);if((rb|0)==0){break}else{rb=rb-1|0}}}bD(y,129);bD(y,1)}rb=c[nb+80>>2]|0;do{if((rb|0)==0){if((ac|0)==1&($b|0)==1){break}Xb=(c[Pb>>2]|0)/(ac|0)|0;Yb=Xb;Fb=(Xb|0)<0|0?-1:0;Xb=Fb;Zb=Yb;Sb=1;while(1){hc=Zb>>>8|Xb<<24;_b=Xb>>>8|0<<24;if((hc|0)==0&(_b|0)==0){break}else{Xb=_b;Zb=hc;Sb=Sb+1|0}}if(!bb){Zb=cb;while(1){bD(y,21680>>>(Zb<<3>>>0)&255);if((Zb|0)==0){break}else{Zb=Zb-1|0}}}SK(y,Sb,(Sb|0)<0|0?-1:0,0);if((Sb|0)>0){Zb=Sb;do{Zb=Zb-1|0;Xb=zrc(Yb|0,Fb|0,Zb<<3|0)|0;bD(y,Xb&255);}while((Zb|0)>0)}Zb=(c[Tb>>2]|0)/($b|0)|0;Fb=Zb;Yb=(Zb|0)<0|0?-1:0;Zb=Yb;Sb=Fb;Xb=1;while(1){hc=Sb>>>8|Zb<<24;_b=Zb>>>8|0<<24;if((hc|0)==0&(_b|0)==0){break}else{Zb=_b;Sb=hc;Xb=Xb+1|0}}if(!bb){Sb=cb;while(1){bD(y,21690>>>(Sb<<3>>>0)&255);if((Sb|0)==0){break}else{Sb=Sb-1|0}}}SK(y,Xb,(Xb|0)<0|0?-1:0,0);if((Xb|0)>0){ic=Xb}else{break}do{ic=ic-1|0;Sb=zrc(Fb|0,Yb|0,ic<<3|0)|0;bD(y,Sb&255);}while((ic|0)>0)}else{Yb=c[Pb>>2]|0;Fb=c[nb+84>>2]|0;Xb=VIb(Yb,(Yb|0)<0|0?-1:0,rb,(rb|0)<0|0?-1:0,Fb,(Fb|0)<0|0?-1:0)|0;Fb=G;Yb=0;if((Fb|0)>(Yb|0)|(Fb|0)==(Yb|0)&Xb>>>0>2147483647>>>0){V=194;break c}Yb=Crc(Xb,Fb,ac,0)|0;Fb=G;Xb=Fb;Sb=Yb;Zb=1;while(1){hc=Sb>>>8|Xb<<24;_b=Xb>>>8|0<<24;if((hc|0)==0&(_b|0)==0){break}else{Xb=_b;Sb=hc;Zb=Zb+1|0}}if(!bb){Sb=cb;while(1){bD(y,21680>>>(Sb<<3>>>0)&255);if((Sb|0)==0){break}else{Sb=Sb-1|0}}}SK(y,Zb,(Zb|0)<0|0?-1:0,0);if((Zb|0)>0){Sb=Zb;do{Sb=Sb-1|0;Xb=zrc(Yb|0,Fb|0,Sb<<3|0)|0;bD(y,Xb&255);}while((Sb|0)>0)}Sb=(c[Tb>>2]|0)/($b|0)|0;Fb=Sb;Yb=(Sb|0)<0|0?-1:0;Sb=Yb;Zb=Fb;Xb=1;while(1){hc=Zb>>>8|Sb<<24;_b=Sb>>>8|0<<24;if((hc|0)==0&(_b|0)==0){break}else{Sb=_b;Zb=hc;Xb=Xb+1|0}}if(!bb){Zb=cb;while(1){bD(y,21690>>>(Zb<<3>>>0)&255);if((Zb|0)==0){break}else{Zb=Zb-1|0}}}SK(y,Xb,(Xb|0)<0|0?-1:0,0);if((Xb|0)>0){jc=Xb}else{break}do{jc=jc-1|0;Zb=zrc(Fb|0,Yb|0,jc<<3|0)|0;bD(y,Zb&255);}while((jc|0)>0)}}while(0);if((c[pb>>2]|0)==14){c[w>>2]=c[ob+52>>2];if(!db){Tb=eb;while(1){bD(y,3061028>>>(Tb<<3>>>0)&255);if((Tb|0)==0){break}else{Tb=Tb-1|0}}}bD(y,132);dD(y,C,4)}Tb=fD(y,0,0,1)|0;rb=G;Pb=xrc(Eb,Bb,Gb,(Gb|0)<0|0?-1:0)|0;Yb=fD(y,Pb,G,0)|0;Pb=G;Fb=0;if((Pb|0)<(Fb|0)|(Pb|0)==(Fb|0)&Yb>>>0<0>>>0){kc=Wb;lc=Ob;break}Yb=xrc(Tb,rb,Eb,Bb)|0;SK(y,Yb,G,Gb);fD(y,Tb,rb,0)|0;kc=Wb;lc=Ob}else if((Ab|0)==1){if(!Ja){rb=Ka;while(1){bD(y,131>>>(rb<<3>>>0)&255);if((rb|0)==0){break}else{rb=rb-1|0}}}bD(y,129);bD(y,2);if((Ob|0)==0){UK(y,134,2184016)}TK(x,y,225,0,0);rb=c[Ia>>2]|0;Gb=c[Ia+4>>2]|0;Bb=c[La>>2]|0;Eb=c[ob+416>>2]|0;Tb=Eb;Yb=(Eb|0)<0|0?-1:0;Eb=Yb;Fb=Tb;Pb=1;while(1){Xb=Fb>>>8|Eb<<24;Zb=Eb>>>8|0<<24;if((Xb|0)==0&(Zb|0)==0){break}else{Eb=Zb;Fb=Xb;Pb=Pb+1|0}}if(!Na){Fb=Oa;while(1){bD(y,159>>>(Fb<<3>>>0)&255);if((Fb|0)==0){break}else{Fb=Fb-1|0}}}SK(y,Pb,(Pb|0)<0|0?-1:0,0);if((Pb|0)>0){Fb=Pb;do{Fb=Fb-1|0;Eb=zrc(Tb|0,Yb|0,Fb<<3|0)|0;bD(y,Eb&255);}while((Fb|0)>0)}Rb=+(yb|0);if(!Pa){Fb=Qa;while(1){bD(y,181>>>(Fb<<3>>>0)&255);if((Fb|0)==0){break}else{Fb=Fb-1|0}}}bD(y,136);h[k>>3]=Rb;sD(y,c[k>>2]|0,c[k+4>>2]|0);if((xb|0)!=0){Qb=+(xb|0);if(!Ta){Fb=Ua;while(1){bD(y,30901>>>(Fb<<3>>>0)&255);if((Fb|0)==0){break}else{Fb=Fb-1|0}}}bD(y,136);h[k>>3]=Qb;sD(y,c[k>>2]|0,c[k+4>>2]|0)}do{if((wb|0)!=0){Fb=wb;Yb=(wb|0)<0|0?-1:0;Tb=Yb;Pb=Fb;Eb=1;while(1){Xb=Pb>>>8|Tb<<24;Zb=Tb>>>8|0<<24;if((Xb|0)==0&(Zb|0)==0){break}else{Tb=Zb;Pb=Xb;Eb=Eb+1|0}}if(!Ra){Pb=Sa;while(1){bD(y,25188>>>(Pb<<3>>>0)&255);if((Pb|0)==0){break}else{Pb=Pb-1|0}}}SK(y,Eb,(Eb|0)<0|0?-1:0,0);if((Eb|0)>0){mc=Eb}else{break}do{mc=mc-1|0;Pb=zrc(Fb|0,Yb|0,mc<<3|0)|0;bD(y,Pb&255);}while((mc|0)>0)}}while(0);Yb=fD(y,0,0,1)|0;Fb=G;Eb=xrc(rb,Gb,Bb,(Bb|0)<0|0?-1:0)|0;Pb=fD(y,Eb,G,0)|0;Eb=G;Tb=0;if((Eb|0)<(Tb|0)|(Eb|0)==(Tb|0)&Pb>>>0<0>>>0){kc=0;lc=Ob;break}Pb=xrc(Yb,Fb,rb,Gb)|0;SK(y,Pb,G,Bb);fD(y,Yb,Fb,0)|0;kc=0;lc=Ob}else if((Ab|0)==3){if((Ob|0)==0){V=251;break c}if(Cb){if((c[pb>>2]|0)==1465275476){nc=Ob}else{V=254}}else{V=254}if((V|0)==254){V=0;nc=17}Fb=nc;Yb=(nc|0)<0|0?-1:0;Pb=Yb;Tb=Fb;Eb=1;while(1){Xb=Tb>>>8|Pb<<24;Zb=Pb>>>8|0<<24;if((Xb|0)==0&(Zb|0)==0){break}else{Pb=Zb;Tb=Xb;Eb=Eb+1|0}}if(!Ja){Tb=Ka;while(1){bD(y,131>>>(Tb<<3>>>0)&255);if((Tb|0)==0){break}else{Tb=Tb-1|0}}}SK(y,Eb,(Eb|0)<0|0?-1:0,0);if((Eb|0)>0){oc=Eb}else{kc=0;lc=nc;break}while(1){Tb=oc-1|0;Pb=zrc(Fb|0,Yb|0,Tb<<3|0)|0;bD(y,Pb&255);if((Tb|0)>0){oc=Tb}else{kc=0;lc=nc;break}}}else{V=261;break c}}while(0);if((c[sa>>2]|0)==2){if((c[pb>>2]|0)!=1465275476){V=264}}else{V=264}if((V|0)==264){V=0;Cb=_D(o)|0;if((Cb|0)<0){$=Cb;break a}f:do{if((lc|0)==0){Ab=c[tb>>2]|0;if((Ab|0)==1){Db=IX(1406408,c[pb>>2]|0)|0;if((Db|0)==0){Yb=u5a(c[pb>>2]|0)|0;KIb(ga,16,2162880,(W=i,i=i+8|0,c[W>>2]=Yb,W)|0);i=W;pc=-22}else{pc=Cb}Yb=ob+52|0;if((c[Yb>>2]|0)==0){c[Yb>>2]=Db}US(c[o>>2]|0,ob)|0;qc=pc;break}else if((Ab|0)!=0){qc=Cb;break}if((kc|0)==0){if((IX(1409152,c[pb>>2]|0)|0)==0){Ab=u5a(c[pb>>2]|0)|0;KIb(ga,24,2171720,(W=i,i=i+8|0,c[W>>2]=Ab,W)|0);i=W}Ab=ob+52|0;do{if((c[Ab>>2]|0)==0){Db=IX(1409152,c[pb>>2]|0)|0;c[Ab>>2]=Db;if((Db|0)!=0){rc=Cb;break}Db=u5a(c[pb>>2]|0)|0;KIb(ga,16,2165096,(W=i,i=i+8|0,c[W>>2]=Db,W)|0);i=W;rc=-22}else{rc=Cb}}while(0);XS(c[o>>2]|0,ob,1409152,0,0);qc=rc;break}Ab=ob+52|0;Db=c[Ab>>2]|0;if((Db|0)==0){Yb=IX(1407072,c[pb>>2]|0)|0;c[Ab>>2]=Yb;sc=Yb}else{sc=Db}Db=ob+100|0;if((c[Db>>2]|0)==0){qc=Cb;break}Yb=JX(1407072,sc)|0;Fb=ob+96|0;do{if((Yb|0)==(c[pb>>2]|0)){Eb=(c[Fb>>2]|0)+4|0;Tb=JX(1407072,d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0;if((Tb|0)==(c[pb>>2]|0)){break}lD(c[o>>2]|0,(c[Db>>2]|0)+90|0);kD(c[o>>2]|0,c[Ab>>2]|0);Tb=0;do{bD(c[o>>2]|0,0);Tb=Tb+1|0;}while((Tb|0)<82)}}while(0);dD(c[o>>2]|0,c[Fb>>2]|0,c[Db>>2]|0);qc=Cb}else{Ab=c[pb>>2]|0;if((Ab|0)==28){qc=q$(c[o>>2]|0,c[ob+96>>2]|0,c[ob+100>>2]|0)|0;break}else if((Ab|0)==1211250229){qc=w$(c[o>>2]|0,c[ob+96>>2]|0,c[ob+100>>2]|0,0)|0;break}else if((Ab|0)==86021|(Ab|0)==31){Yb=c[o>>2]|0;if((oib(c[ob+96>>2]|0,c[ob+100>>2]|0,(Ab|0)==86021?30:42,ya,Da)|0)<0){KIb(ga,16,2160696,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;qc=-1;break}else{bD(Yb,2);Tb=c[Da>>2]|0;cD(Yb,255,(Tb|0)/255|0);bD(Yb,(Tb|0)%255|0);Tb=c[Ea>>2]|0;cD(Yb,255,(Tb|0)/255|0);bD(Yb,(Tb|0)%255|0);dD(Yb,c[ya>>2]|0,c[Da>>2]|0);dD(Yb,c[Fa>>2]|0,c[Ea>>2]|0);dD(Yb,c[Ga>>2]|0,c[Ha>>2]|0);qc=0;break}}else if((Ab|0)==86028){qc=PG(c[o>>2]|0,ob,1)|0;break}else if((Ab|0)==86041){Yb=c[o>>2]|0;Tb=c[ob+96>>2]|0;do{if((Tb|0)!=0){if((c[ob+100>>2]|0)!=2){break}dD(Yb,Tb,2);qc=0;break f}}while(0);oD(Yb,1027);qc=0;break}else{Tb=c[ob+100>>2]|0;if((Ab|0)!=86032){if((Tb|0)==0|(Ab|0)==86038){qc=Cb;break}dD(c[o>>2]|0,c[ob+96>>2]|0,Tb);qc=Cb;break}if((Tb|0)<36){KIb(ga,16,2177880,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;qc=-1094995529;break}else{dD(c[o>>2]|0,(c[ob+96>>2]|0)+12|0,Tb-12|0);qc=Cb;break}}}}while(0);Cb=aE(c[o>>2]|0,p)|0;if((Cb|0)!=0){ob=c[p>>2]|0;if(!Ba){tb=Ca;while(1){bD(y,25506>>>(tb<<3>>>0)&255);if((tb|0)==0){break}else{tb=tb-1|0}}}SK(y,Cb,(Cb|0)<0|0?-1:0,0);dD(y,ob,Cb)}kJb(c[p>>2]|0);if((qc|0)<0){$=qc;break a}}tb=fD(y,0,0,1)|0;Tb=G;Db=xrc(sb,qb,vb,(vb|0)<0|0?-1:0)|0;Fb=fD(y,Db,G,0)|0;Db=G;Eb=0;if(!((Db|0)<(Eb|0)|(Db|0)==(Eb|0)&Fb>>>0<0>>>0)){Fb=xrc(tb,Tb,sb,qb)|0;SK(y,Fb,G,vb);fD(y,tb,Tb,0)|0;}_X(nb,64,1,1e3);ub=zb}if(!(ub>>>0<(c[L>>2]|0)>>>0)){break b}ma=ub;mb=c[A>>2]|0}if((V|0)==130){KIb(ga,16,2203560,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;$=-22;break a}else if((V|0)==177){KIb(ga,16,2191496,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;$=-22;break a}else if((V|0)==194){KIb(ga,16,2186352,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;$=-22;break a}else if((V|0)==251){KIb(ga,16,2181816,(W=i,i=i+8|0,c[W>>2]=c[pb>>2],W)|0);i=W;$=-38;break a}else if((V|0)==261){KIb(ga,16,2179592,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;$=-22;break a}}}while(0);_=fD(y,0,0,1)|0;mb=G;ma=xrc(aa,Z,ca,(ca|0)<0|0?-1:0)|0;Ca=fD(y,ma,G,0)|0;ma=G;Ba=0;if((ma|0)<(Ba|0)|(ma|0)==(Ba|0)&Ca>>>0<0>>>0){$=0;break}Ca=xrc(_,mb,aa,Z)|0;SK(y,Ca,G,ca);fD(y,_,mb,0)|0;$=0}else{$=-1}}while(0);if(($|0)<0){X=$;i=b;return X|0}$=a+1132|0;if((c[$>>2]|0)!=0){y=H+216|0;pb=c[a+1136>>2]|0;ub=0;qc=c[y>>2]|0;do{p=0;o=c[c[pb+(ub<<2)>>2]>>2]|0;sc=xrc(1,0,o,(o|0)<0|0?-1:0)|0;o=G;qc=(p|0)>(o|0)|(p|0)==(o|0)&qc>>>0>sc>>>0?qc:sc;c[y>>2]=qc;ub=ub+1|0;}while(ub>>>0<(c[$>>2]|0)>>>0)}do{if((c[M>>2]|0)!=2){ub=OK(a)|0;if((ub|0)<0){X=ub;i=b;return X|0}ub=l;qc=c[E>>2]|0;c[ub>>2]=c[207674];c[ub+4>>2]=c[207675];c[ub+8>>2]=c[207676];c[ub+12>>2]=c[207677];dL(a,1353480,0);ub=c[T>>2]|0;y=LGb(ub,10230168,0,2)|0;g:do{if((y|0)!=0){pb=y;while(1){sc=pb|0;if((IFb(c[sc>>2]|0,2377928)|0)!=0){if((IFb(c[sc>>2]|0,2225576)|0)!=0){break}}pb=LGb(ub,10230168,pb,2)|0;if((pb|0)==0){break g}}pb=WK(a,c[T>>2]|0,0,0,l)|0;if((pb|0)<0){X=pb}else{break}i=b;return X|0}}while(0);h:do{if((c[L>>2]|0)!=0){ub=0;i:while(1){y=(c[(c[A>>2]|0)+(ub<<2)>>2]|0)+88|0;ca=c[y>>2]|0;Z=LGb(ca,10230168,0,2)|0;j:do{if((Z|0)!=0){aa=Z;while(1){pb=aa|0;if((IFb(c[pb>>2]|0,2377928)|0)!=0){if((IFb(c[pb>>2]|0,2225576)|0)!=0){break}}aa=LGb(ca,10230168,aa,2)|0;if((aa|0)==0){break j}}aa=WK(a,c[y>>2]|0,25541,ub+1|0,l)|0;if((aa|0)<0){X=aa;break i}}}while(0);ub=ub+1|0;if(!(ub>>>0<(c[L>>2]|0)>>>0)){break h}}i=b;return X|0}}while(0);k:do{if((c[$>>2]|0)!=0){ub=a+1136|0;y=qc+216|0;ca=0;l:while(1){Z=c[(c[ub>>2]|0)+(ca<<2)>>2]|0;zb=Z+32|0;nb=c[zb>>2]|0;vb=LGb(nb,10230168,0,2)|0;m:do{if((vb|0)!=0){qb=vb;while(1){sb=qb|0;if((IFb(c[sb>>2]|0,2377928)|0)!=0){if((IFb(c[sb>>2]|0,2225576)|0)!=0){break}}qb=LGb(nb,10230168,qb,2)|0;if((qb|0)==0){break m}}qb=WK(a,c[zb>>2]|0,25540,(c[y>>2]|0)+(c[Z>>2]|0)|0,l)|0;if((qb|0)<0){X=qb;break l}}}while(0);ca=ca+1|0;if(!(ca>>>0<(c[$>>2]|0)>>>0)){break k}}i=b;return X|0}}while(0);qc=l|0;ca=c[qc>>2]|0;y=c[qc+4>>2]|0;do{if(!((ca|0)==0&(y|0)==0)){qc=c[I>>2]|0;ub=c[l+8>>2]|0;Z=fD(qc,0,0,1)|0;zb=G;nb=xrc(ca,y,ub,(ub|0)<0|0?-1:0)|0;vb=fD(qc,nb,G,0)|0;nb=G;qb=0;if((nb|0)<(qb|0)|(nb|0)==(qb|0)&vb>>>0<0>>>0){break}vb=xrc(Z,zb,ca,y)|0;SK(qc,vb,G,ub);fD(qc,Z,zb,0)|0;}}while(0);y=j|0;ca=c[E>>2]|0;zb=c[I>>2]|0;n:do{if((c[ca+184>>2]|0)==0){tc=0}else{AIb(e,wKb()|0);Z=c[ca+88>>2]|0;qc=fD(zb,0,0,1)|0;ub=G;vb=Z+24|0;qb=c[Z+20>>2]|0;nb=Z+28|0;sb=c[nb>>2]|0;if(!((qb|0)<1|(qb|0)>(sb|0))){tc=-1;break}qb=nJb(c[vb>>2]|0,sb+1|0,16)|0;sb=qb;if((qb|0)==0){tc=-12;break}c[vb>>2]=sb;c[sb+(c[nb>>2]<<4)>>2]=423732329;vb=Z+8|0;Z=xrc(qc,ub,c[vb>>2]|0,c[vb+4>>2]|0)|0;vb=c[nb>>2]|0;c[nb>>2]=vb+1;nb=sb+(vb<<4)+8|0;c[nb>>2]=Z;c[nb+4>>2]=G;TK(f,zb,423732329,0,0);nb=f|0;Z=c[nb>>2]|0;vb=c[nb+4>>2]|0;nb=c[f+8>>2]|0;o:do{if((c[L>>2]|0)!=0){sb=g|0;ub=g+8|0;qc=e+256|0;qb=a;Cb=d[1359734]|0;ob=(Cb+20|0)>>>0<7>>>0;aa=(Cb+7|0)/7|0;Cb=j;Ab=0;p:while(1){Yb=c[(c[A>>2]|0)+(Ab<<2)>>2]|0;pb=Yb+8|0;do{if((c[(c[pb>>2]|0)+8>>2]|0)==4){TK(g,zb,24999,0,0);ga=c[sb>>2]|0;sc=c[sb+4>>2]|0;o=c[ub>>2]|0;p=Yb+88|0;rc=LGb(c[p>>2]|0,2377928,0,0)|0;if((rc|0)!=0){UK(zb,18046,c[rc+4>>2]|0)}rc=LGb(c[p>>2]|0,2257352,0,0)|0;if((rc|0)==0){V=354;break p}UK(zb,18030,c[rc+4>>2]|0);rc=LGb(c[p>>2]|0,2245096,0,0)|0;if((rc|0)==0){p=c[pb>>2]|0;kc=c[p+48>>2]|0;if((kc|0)==0){V=362;break p}else{uc=0}while(1){pc=c[1353184+(uc*36|0)>>2]|0;if((pc|0)==0){V=362;break p}if((pc|0)==(kc|0)){break}else{uc=uc+1|0}}vc=1353152+(uc*36|0)|0;wc=p}else{kc=c[rc+4>>2]|0;if((kc|0)==0){V=362;break p}vc=kc;wc=c[pb>>2]|0}if((c[wc+88>>2]&8388608|0)==0){kc=c[qc>>2]|0;c[e+((kc&63)<<2)>>2]=(c[e+((kc+9&63)<<2)>>2]|0)+(c[e+((kc+40&63)<<2)>>2]|0);kc=c[qc>>2]|0;c[qc>>2]=kc+1;xc=0;yc=c[e+((kc&63)<<2)>>2]|0}else{kc=YKb()|0;if((kc|0)==0){tc=-12;break n}ZKb(kc,160)|0;pc=c[pb>>2]|0;aLb(kc,c[pc+96>>2]|0,c[pc+100>>2]|0);bLb(kc,y);kJb(kc);xc=c[Cb+4>>2]|0;yc=c[Cb>>2]|0}KIb(qb,40,2233208,(W=i,i=i+24|0,c[W>>2]=yc,c[W+8>>2]=xc,c[W+16>>2]=Ab,W)|0);i=W;UK(zb,18016,vc);kc=c[pb>>2]|0;pc=c[kc+96>>2]|0;lc=c[kc+100>>2]|0;if(!ob){kc=aa;while(1){bD(zb,18012>>>(kc<<3>>>0)&255);if((kc|0)==0){break}else{kc=kc-1|0}}}SK(zb,lc,(lc|0)<0|0?-1:0,0);dD(zb,pc,lc);kc=xc;rc=yc;p=1;while(1){nc=rc>>>8|kc<<24;oc=kc>>>8|0<<24;if((nc|0)==0&(oc|0)==0){break}else{kc=oc;rc=nc;p=p+1|0}}if(!ob){rc=aa;while(1){bD(zb,18094>>>(rc<<3>>>0)&255);if((rc|0)==0){break}else{rc=rc-1|0}}}SK(zb,p,(p|0)<0|0?-1:0,0);if((p|0)>0){rc=p;do{rc=rc-1|0;kc=zrc(yc|0,xc|0,rc<<3|0)|0;bD(zb,kc&255);}while((rc|0)>0)}rc=fD(zb,0,0,1)|0;p=G;kc=xrc(ga,sc,o,(o|0)<0|0?-1:0)|0;lc=fD(zb,kc,G,0)|0;kc=G;pc=0;if((kc|0)<(pc|0)|(kc|0)==(pc|0)&lc>>>0<0>>>0){break}lc=xrc(rc,p,ga,sc)|0;SK(zb,lc,G,o);fD(zb,rc,p,0)|0;}}while(0);pb=Ab+1|0;if(pb>>>0<(c[L>>2]|0)>>>0){Ab=pb}else{break o}}if((V|0)==354){KIb(qb,16,2253864,(W=i,i=i+8|0,c[W>>2]=Ab,W)|0);i=W;tc=-22;break n}else if((V|0)==362){KIb(qb,16,2236920,(W=i,i=i+8|0,c[W>>2]=Ab,W)|0);i=W;tc=-22;break n}}}while(0);aa=fD(zb,0,0,1)|0;ob=G;Cb=xrc(Z,vb,nb,(nb|0)<0|0?-1:0)|0;qc=fD(zb,Cb,G,0)|0;Cb=G;ub=0;if((Cb|0)<(ub|0)|(Cb|0)==(ub|0)&qc>>>0<0>>>0){tc=0;break}qc=xrc(aa,ob,Z,vb)|0;SK(zb,qc,G,nb);fD(zb,aa,ob,0)|0;tc=0}}while(0);if((tc|0)<0){X=tc}else{break}i=b;return X|0}}while(0);if((c[(c[I>>2]|0)+88>>2]|0)==0){RK(J,c[S>>2]|0)}S=c[z>>2]|0;I=c[z+4>>2]|0;z=pJb(16)|0;if((z|0)==0){c[H+92>>2]=0;X=-12;i=b;return X|0}tc=z;c[tc>>2]=S;c[tc+4>>2]=I;c[H+92>>2]=z;z=J+88|0;do{if((c[z>>2]|0)!=0){I=H+188|0;if((c[I>>2]|0)==0){break}tc=fD(J,0,0,1)|0;S=H+200|0;c[S>>2]=tc;c[S+4>>2]=G;S=c[I>>2]|0;QK(J,S,(S|0)<0|0?-1:0)}}while(0);J1(H+104|0);c[H+132>>2]=0;S=H+56|0;c[S>>2]=-1;c[S+4>>2]=-1;eD(J);J=H+208|0;S=c[J+4>>2]|0;I=0;tc=(S|0)<(I|0)|(S|0)==(I|0)&(c[J>>2]|0)>>>0<0>>>0;if((c[z>>2]|0)==0){if(tc){c[J>>2]=1e3;c[J+4>>2]=0}z=H+192|0;if((c[z>>2]|0)>=0){X=0;i=b;return X|0}c[z>>2]=32768;X=0;i=b;return X|0}else{if(tc){c[J>>2]=5e3;c[J+4>>2]=0}J=H+192|0;if((c[J>>2]|0)>=0){X=0;i=b;return X|0}c[J>>2]=5242880;X=0;i=b;return X|0}return 0}function KK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a+12|0;h=c[g>>2]|0;j=a+16|0;k=c[j>>2]|0;l=(c[k+88>>2]|0)==0;if(l){m=c[h+8>>2]|0}else{m=k}if((b|0)==0){n=h+56|0;if((c[n>>2]|0)==(-1|0)&(c[n+4>>2]|0)==(-1|0)){o=0;i=d;return o|0}p=fD(m,0,0,1)|0;q=G;KIb(a,48,2286736,(r=i,i=i+16|0,c[r>>2]=p,c[r+8>>2]=q,r)|0);i=r;q=h+40|0;p=c[q>>2]|0;s=c[q+4>>2]|0;q=c[h+48>>2]|0;t=fD(m,0,0,1)|0;u=G;v=xrc(p,s,q,(q|0)<0|0?-1:0)|0;w=fD(m,v,G,0)|0;v=G;x=0;if(!((v|0)<(x|0)|(v|0)==(x|0)&w>>>0<0>>>0)){w=xrc(t,u,p,s)|0;SK(m,w,G,q);fD(m,t,u,0)|0;}c[n>>2]=-1;c[n+4>>2]=-1;do{if((c[h+8>>2]|0)!=0){n=(c[g>>2]|0)+8|0;u=c[n>>2]|0;if((u|0)==0){break}t=aE(u,f)|0;dD(c[j>>2]|0,c[f>>2]|0,t);kJb(c[f>>2]|0);c[n>>2]=0}}while(0);eD(c[j>>2]|0);o=0;i=d;return o|0}f=c[b+32>>2]|0;n=c[(c[(c[(c[a+28>>2]|0)+(f<<2)>>2]|0)+8>>2]|0)+8>>2]|0;t=c[b+36>>2]&1;if((c[(c[h+96>>2]|0)+(f<<3)>>2]|0)==0){f=b+8|0;u=h+64|0;m=xrc(c[f>>2]|0,c[f+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;y=G;z=m}else{m=b+16|0;u=h+64|0;f=xrc(c[m>>2]|0,c[m+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;y=G;z=f}if(l){l=c[h+8>>2]|0;f=fD(l,0,0,1)|0;u=h+56|0;A=l;B=f;C=c[u+4>>2]|0;D=c[u>>2]|0}else{u=fD(k,0,0,1)|0;f=h+56|0;l=c[f>>2]|0;m=c[f+4>>2]|0;f=xrc(u,G,l,m)|0;A=k;B=f;C=m;D=l}l=h+56|0;a:do{if(!((D|0)==(-1|0)&(C|0)==(-1|0))){do{if((B|0)<=(c[h+192>>2]|0)){m=h+208|0;f=c[m+4>>2]|0;if((y|0)>(f|0)|(y|0)==(f|0)&z>>>0>(c[m>>2]|0)>>>0){break}if(!((t|0)!=0&(n|0)==0&(B|0)>4096)){break a}}}while(0);m=fD(A,0,0,1)|0;f=G;k=b+8|0;u=c[k>>2]|0;q=c[k+4>>2]|0;k=b+16|0;w=c[k>>2]|0;s=c[k+4>>2]|0;KIb(a,48,2282560,(r=i,i=i+48|0,c[r>>2]=m,c[r+8>>2]=f,c[r+16>>2]=u,c[r+24>>2]=q,c[r+32>>2]=w,c[r+40>>2]=s,r)|0);i=r;s=h+40|0;w=c[s>>2]|0;q=c[s+4>>2]|0;s=c[h+48>>2]|0;u=fD(A,0,0,1)|0;f=G;m=xrc(w,q,s,(s|0)<0|0?-1:0)|0;k=fD(A,m,G,0)|0;m=G;p=0;if(!((m|0)<(p|0)|(m|0)==(p|0)&k>>>0<0>>>0)){k=xrc(u,f,w,q)|0;SK(A,k,G,s);fD(A,u,f,0)|0;}c[l>>2]=-1;c[l+4>>2]=-1;do{if((c[h+8>>2]|0)!=0){f=(c[g>>2]|0)+8|0;u=c[f>>2]|0;if((u|0)==0){break}s=aE(u,e)|0;dD(c[j>>2]|0,c[e>>2]|0,s);kJb(c[e>>2]|0);c[f>>2]=0}}while(0);eD(c[j>>2]|0)}}while(0);j=h+104|0;e=j;do{if((c[h+132>>2]|0)>0){g=NK(a,e)|0;P1(e);if((g|0)>=0){break}KIb(a,16,2471776,(r=i,i=i+8|0,c[r>>2]=g,r)|0);i=r;o=g;i=d;return o|0}}while(0);if((n|0)!=1){o=NK(a,b)|0;i=d;return o|0}nrc(j|0,b|0,80)|0;a=c[b>>2]|0;if((a|0)==0){E=Q1(e)|0}else{b=eGb(a)|0;c[j>>2]=b;E=(b|0)!=0?0:-12}if((c[h+148>>2]|0)<=0){o=E;i=d;return o|0}o=O1(e,e)|0;i=d;return o|0}function LK(a){a=a|0;var b=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0;b=i;i=i+8|0;e=b|0;f=a+12|0;g=c[f>>2]|0;j=a+16|0;l=c[j>>2]|0;m=g+104|0;do{if((c[g+132>>2]|0)>0){n=NK(a,m)|0;P1(m);if((n|0)>=0){break}KIb(a,16,2471776,(o=i,i=i+8|0,c[o>>2]=n,o)|0);i=o;p=n;i=b;return p|0}}while(0);m=c[g+8>>2]|0;do{if((m|0)==0){n=g+56|0;if((c[n>>2]|0)==(-1|0)&(c[n+4>>2]|0)==(-1|0)){break}n=g+40|0;q=c[n>>2]|0;r=c[n+4>>2]|0;n=c[g+48>>2]|0;s=fD(l,0,0,1)|0;t=G;u=xrc(q,r,n,(n|0)<0|0?-1:0)|0;v=fD(l,u,G,0)|0;u=G;w=0;if((u|0)<(w|0)|(u|0)==(w|0)&v>>>0<0>>>0){break}v=xrc(s,t,q,r)|0;SK(l,v,G,n);fD(l,s,t,0)|0;}else{t=g+40|0;s=c[t>>2]|0;n=c[t+4>>2]|0;t=c[g+48>>2]|0;v=fD(m,0,0,1)|0;r=G;q=xrc(s,n,t,(t|0)<0|0?-1:0)|0;w=fD(m,q,G,0)|0;q=G;u=0;if(!((q|0)<(u|0)|(q|0)==(u|0)&w>>>0<0>>>0)){w=xrc(v,r,s,n)|0;SK(m,w,G,t);fD(m,v,r,0)|0;}r=(c[f>>2]|0)+8|0;v=c[r>>2]|0;if((v|0)==0){break}t=aE(v,e)|0;dD(c[j>>2]|0,c[e>>2]|0,t);kJb(c[e>>2]|0);c[r>>2]=0}}while(0);do{if((c[g+4>>2]|0)!=2){e=OK(a)|0;if((e|0)<0){p=e}else{break}i=b;return p|0}}while(0);if((c[l+88>>2]|0)!=0){e=g+92|0;j=c[e>>2]|0;do{if((c[j+12>>2]|0)==0){x=g+88|0}else{f=g+188|0;if((c[f>>2]|0)==0){m=PK(l,j,c[g+96>>2]|0,c[a+24>>2]|0)|0;y=G;z=m}else{m=fD(l,0,0,1)|0;r=G;t=g+200|0;fD(l,c[t>>2]|0,c[t+4>>2]|0,0)|0;t=PK(l,c[e>>2]|0,c[g+96>>2]|0,c[a+24>>2]|0)|0;v=G;w=fD(l,0,0,1)|0;n=G;s=c[f>>2]|0;f=s;u=(s|0)<0|0?-1:0;q=wrc(f,u,t,v)|0;A=G;if((n|0)>(A|0)|(n|0)==(A|0)&w>>>0>q>>>0){B=xrc(w,n,t,v)|0;C=G;KIb(a,16,2463760,(o=i,i=i+24|0,c[o>>2]=s,c[o+8>>2]=B,c[o+16>>2]=C,o)|0);i=o;p=-22;i=b;return p|0}if((n|0)<(A|0)|(n|0)==(A|0)&w>>>0<q>>>0){q=xrc(t,v,w,n)|0;n=wrc(q,G,f,u)|0;QK(l,n,G)}fD(l,m,r,0)|0;y=v;z=t}t=g+88|0;v=c[t>>2]|0;r=v+24|0;m=c[v+20>>2]|0;n=v+28|0;u=c[n>>2]|0;if(!((m|0)<1|(m|0)>(u|0))){p=-1;i=b;return p|0}m=nJb(c[r>>2]|0,u+1|0,16)|0;u=m;if((m|0)==0){p=-12;i=b;return p|0}else{c[r>>2]=u;c[u+(c[n>>2]<<4)>>2]=475249515;r=v+8|0;v=xrc(z,y,c[r>>2]|0,c[r+4>>2]|0)|0;r=c[n>>2]|0;c[n>>2]=r+1;n=u+(r<<4)+8|0;c[n>>2]=v;c[n+4>>2]=G;x=t;break}}}while(0);RK(l,c[x>>2]|0);x=g+80|0;y=c[x+4>>2]|0;KIb(a,48,2449416,(o=i,i=i+16|0,c[o>>2]=c[x>>2],c[o+8>>2]=y,o)|0);i=o;o=fD(l,0,0,1)|0;y=G;a=g+72|0;fD(l,c[a>>2]|0,c[a+4>>2]|0,0)|0;D=+((c[x>>2]|0)>>>0)+ +(c[x+4>>2]|0)*4294967296.0;x=d[1359732]|0;if(!((x+20|0)>>>0<7>>>0)){a=(x+7|0)/7|0;while(1){bD(l,17545>>>(a<<3>>>0)&255);if((a|0)==0){break}else{a=a-1|0}}}bD(l,136);h[k>>3]=D;sD(l,c[k>>2]|0,c[k+4>>2]|0);fD(l,o,y,0)|0;}y=g+16|0;o=c[y>>2]|0;a=c[y+4>>2]|0;y=c[g+24>>2]|0;x=fD(l,0,0,1)|0;z=G;e=xrc(o,a,y,(y|0)<0|0?-1:0)|0;j=fD(l,e,G,0)|0;e=G;t=0;if(!((e|0)<(t|0)|(e|0)==(t|0)&j>>>0<0>>>0)){j=xrc(x,z,o,a)|0;SK(l,j,G,y);fD(l,x,z,0)|0;}mJb(g+96|0);z=g+92|0;mJb((c[z>>2]|0)+8|0);mJb(z);p=0;i=b;return p|0}function MK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=0;while(1){e=c[1353528+(d*28|0)>>2]|0;if((e|0)==0){break}if((e|0)==(a|0)){f=1;g=7;break}else{d=d+1|0}}if((g|0)==7){return f|0}do{if((b|0)<0){if((S5a(a)|0)>>>0<2>>>0){f=1}else{break}return f|0}}while(0);f=0;return f|0}function NK(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;f=i;i=i+2360|0;g=f|0;h=f+8|0;j=f+16|0;k=f+32|0;l=f+40|0;m=f+48|0;n=f+56|0;o=f+64|0;p=f+72|0;q=f+80|0;r=f+88|0;s=f+96|0;t=f+176|0;u=f+192|0;v=f+200|0;w=f+208|0;x=f+216|0;y=f+224|0;z=f+232|0;A=f+240|0;B=f+248|0;C=f+256|0;D=f+264|0;E=f+2312|0;F=f+2328|0;H=f+2344|0;I=b+12|0;J=c[I>>2]|0;K=b+16|0;L=c[K>>2]|0;M=e+32|0;N=c[M>>2]|0;O=b+28|0;P=c[(c[(c[O>>2]|0)+(N<<2)>>2]|0)+8>>2]|0;Q=c[e+36>>2]&1;R=e+48|0;S=c[R>>2]|0;T=e+16|0;U=e+8|0;V=(c[(c[J+96>>2]|0)+(N<<3)>>2]|0)==0?U:T;N=c[V>>2]|0;W=c[V+4>>2]|0;if((N|0)==0&(W|0)==(-2147483648|0)){KIb(b,16,2360168,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;Y=-22;i=f;return Y|0}do{if((c[L+88>>2]|0)==0){V=J+8|0;Z=c[V>>2]|0;if((Z|0)!=0){_=Z;break}Z=_D(V)|0;if((Z|0)>=0){_=c[V>>2]|0;break}KIb(b,16,2348056,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;Y=Z;i=f;return Y|0}else{_=L}}while(0);L=J+56|0;if((c[L>>2]|0)==(-1|0)&(c[L+4>>2]|0)==(-1|0)){Z=fD(c[K>>2]|0,0,0,1)|0;c[L>>2]=Z;c[L+4>>2]=G;Z=J+40|0;TK(F,_,524531317,0,0);V=F;c[Z>>2]=c[V>>2];c[Z+4>>2]=c[V+4>>2];c[Z+8>>2]=c[V+8>>2];c[Z+12>>2]=c[V+12>>2];V=0;F=(W|0)<(V|0)|(W|0)==(V|0)&N>>>0<0>>>0;V=F?0:N;$=F?0:W;F=$;aa=V;ba=1;while(1){da=aa>>>8|F<<24;ea=F>>>8|0<<24;if((da|0)==0&(ea|0)==0){break}else{F=ea;aa=da;ba=ba+1|0}}aa=d[1359896]|0;if(!((aa+12|0)>>>0<7>>>0)){F=(aa-1|0)/7|0;while(1){bD(_,231>>>(F<<3>>>0)&255);if((F|0)==0){break}else{F=F-1|0}}}SK(_,ba,(ba|0)<0|0?-1:0,0);if((ba|0)>0){F=ba;do{F=F-1|0;ba=zrc(V|0,$|0,F<<3|0)|0;bD(_,ba&255);}while((F|0)>0)}F=J+64|0;c[F>>2]=V;c[F+4>>2]=$;fa=Z}else{fa=J+40|0}Z=fD(c[K>>2]|0,0,0,1)|0;K=fa;fa=xrc(Z,G,c[K>>2]|0,c[K+4>>2]|0)|0;K=G;Z=P+8|0;a:do{if((c[Z>>2]|0)==3){$=c[P+48>>2]|0;if(($|0)==94212){F=D|0;V=c[I>>2]|0;c[C>>2]=0;ba=c[e+28>>2]|0;if((ba|0)==0){ga=0;break}aa=b;da=E|0;ea=E+8|0;ha=d[1359826]|0;ia=(ha+12|0)>>>0<7>>>0;ja=V+64|0;V=d[1359820]|0;ka=(V+12|0)>>>0<7>>>0;la=(V-1|0)/7|0;V=(ha-1|0)/7|0;ha=0;ma=ba;ba=c[e+24>>2]|0;while(1){na=Bd(ba|0,2305880,(X=i,i=i+64|0,c[X>>2]=u,c[X+8>>2]=v,c[X+16>>2]=w,c[X+24>>2]=x,c[X+32>>2]=y,c[X+40>>2]=z,c[X+48>>2]=A,c[X+56>>2]=B,X)|0)|0;i=X;if((na|0)==8){oa=(((c[z>>2]|0)-(c[v>>2]|0)|0)*6e4|0)+(ca((c[y>>2]|0)-(c[u>>2]|0)|0,36e5)|0)+(((c[A>>2]|0)-(c[w>>2]|0)|0)*1e3|0)+(((c[B>>2]|0)-(c[x>>2]|0)|0)*10|0)|0}else{oa=0}na=(oa|0)>(ha|0)?oa:ha;pa=Ob(ba|0,10,ma|0)|0;if((pa|0)==0){qa=0;ra=ma;sa=ba}else{ta=ba;qa=(a[pa-1|0]|0)==13?2:1;ra=1-ta+pa|0;sa=ta}ta=ra-qa|0;pa=Ob(ba|0,44,ta|0)|0;if((pa|0)==0){ga=na;break a}ua=pa+1|0;pa=ta+sa|0;ta=Ob(ua|0,44,pa-ua|0)|0;if((ta|0)==0){ga=na;break a}ua=ta+1|0;ta=Ob(ua|0,44,pa-ua|0)|0;if((ta|0)==0){ga=na;break a}ua=ta+1|0;Bd(ba|0,2319320,(X=i,i=i+8|0,c[X>>2]=C,X)|0)|0;i=X;ta=(c[(c[O>>2]|0)+(c[M>>2]<<2)>>2]|0)+64|0;va=c[ta+4>>2]|0;wa=c[C>>2]|0;xa=Rb(F|0,2048,2314584,(X=i,i=i+24|0,c[X>>2]=c[ta>>2],c[X+8>>2]=va,c[X+16>>2]=wa,X)|0)|0;i=X;wa=pa-ua+xa|0;pa=wa>>>0>2048>>>0?2048:wa;nrc(D+xa|0,ua|0,pa-xa|0)|0;xa=fD(_,0,0,1)|0;ua=G;wa=c[U>>2]|0;va=c[U+4>>2]|0;KIb(aa,48,2309848,(X=i,i=i+48|0,c[X>>2]=xa,c[X+8>>2]=ua,c[X+16>>2]=pa,c[X+24>>2]=wa,c[X+32>>2]=va,c[X+40>>2]=oa,X)|0);i=X;va=pa+4|0;wa=va;ua=(va|0)<0|0?-1:0;va=wrc(wa,ua,1,0)|0;xa=G;ta=1;while(1){ya=zrc(va|0,xa|0,ta*7|0|0)|0;if((ya|0)==0&(G|0)==0){break}else{ta=ta+1|0}}xa=pa+14+ta|0;va=wrc(xa,(xa|0)<0|0?-1:0,1,0)|0;ya=G;za=1;while(1){Aa=zrc(va|0,ya|0,za*7|0|0)|0;if((Aa|0)==0&(G|0)==0){break}else{za=za+1|0}}ya=xa+1+za|0;TK(E,_,160,ya,(ya|0)<0|0?-1:0);ya=c[da>>2]|0;va=c[da+4>>2]|0;ta=c[ea>>2]|0;if(!ia){Aa=V;while(1){bD(_,161>>>(Aa<<3>>>0)&255);if((Aa|0)==0){break}else{Aa=Aa-1|0}}}SK(_,wa,ua,0);bD(_,(c[M>>2]|0)+1|128);Aa=xrc(c[U>>2]|0,c[U+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;tD(_,Aa);bD(_,0);dD(_,F,pa);Aa=oa;za=(oa|0)<0|0?-1:0;xa=za;Ba=Aa;Ca=1;while(1){Da=Ba>>>8|xa<<24;Ea=xa>>>8|0<<24;if((Da|0)==0&(Ea|0)==0){break}else{xa=Ea;Ba=Da;Ca=Ca+1|0}}if(!ka){Ba=la;while(1){bD(_,155>>>(Ba<<3>>>0)&255);if((Ba|0)==0){break}else{Ba=Ba-1|0}}}SK(_,Ca,(Ca|0)<0|0?-1:0,0);if((Ca|0)>0){Ba=Ca;do{Ba=Ba-1|0;xa=zrc(Aa|0,za|0,Ba<<3|0)|0;bD(_,xa&255);}while((Ba|0)>0)}Ba=fD(_,0,0,1)|0;za=G;Aa=xrc(ya,va,ta,(ta|0)<0|0?-1:0)|0;Ca=fD(_,Aa,G,0)|0;Aa=G;xa=0;if(!((Aa|0)<(xa|0)|(Aa|0)==(xa|0)&Ca>>>0<0>>>0)){Ca=xrc(Ba,za,ya,va)|0;SK(_,Ca,G,ta);fD(_,Ba,za,0)|0;}if((ma|0)==(ra|0)){ga=na;break}else{ha=na;ma=ma-ra|0;ba=ba+ra|0}}}else if(($|0)==94216){nrc(s|0,e|0,80)|0;ba=s+24|0;ma=0;ha=c[ba>>2]|0;do{la=Bd(ha|0,2330616,(X=i,i=i+64|0,c[X>>2]=k,c[X+8>>2]=l,c[X+16>>2]=m,c[X+24>>2]=n,c[X+32>>2]=o,c[X+40>>2]=p,c[X+48>>2]=q,c[X+56>>2]=r,X)|0)|0;i=X;if((la|0)==8){la=(c[l>>2]|0)+((c[k>>2]|0)*60|0)|0;c[l>>2]=la;ka=(c[p>>2]|0)+((c[o>>2]|0)*60|0)|0;c[p>>2]=ka;F=(c[m>>2]|0)+(la*60|0)|0;c[m>>2]=F;la=(c[q>>2]|0)+(ka*60|0)|0;c[q>>2]=la;ka=(c[n>>2]|0)+(F*1e3|0)|0;c[n>>2]=ka;F=(c[r>>2]|0)+(la*1e3|0)|0;c[r>>2]=F;Fa=F-ka|0}else{Fa=0}ka=c[ba>>2]|0;F=mc(ka|0,2324624)|0;la=a[ka+F|0]|0;if(la<<24>>24==13){ja=F+1|0;Ga=ja;Ha=a[ka+ja|0]|0}else{Ga=F;Ha=la}ha=ka+((Ha<<24>>24==10)+Ga)|0;c[ba>>2]=ha;ma=ma+1|0;}while((ma|0)<2&(Fa|0)==0);ma=s+28|0;ba=(c[e+24>>2]|0)-ha+(c[ma>>2]|0)|0;c[ma>>2]=ba;ma=ba+4|0;ka=wrc(ma,(ma|0)<0|0?-1:0,1,0)|0;ma=G;la=1;while(1){F=zrc(ka|0,ma|0,la*7|0|0)|0;if((F|0)==0&(G|0)==0){break}else{la=la+1|0}}ma=ba+14+la|0;ka=wrc(ma,(ma|0)<0|0?-1:0,1,0)|0;ha=G;F=1;while(1){ja=zrc(ka|0,ha|0,F*7|0|0)|0;if((ja|0)==0&(G|0)==0){break}else{F=F+1|0}}ha=Fa;ka=(Fa|0)<0|0?-1:0;la=ma+1+F|0;TK(t,_,160,la,(la|0)<0|0?-1:0);la=t|0;ba=c[la>>2]|0;ja=c[la+4>>2]|0;la=c[t+8>>2]|0;VK(b,_,161,s,0);V=ka;ia=ha;ea=1;while(1){da=ia>>>8|V<<24;aa=V>>>8|0<<24;if((da|0)==0&(aa|0)==0){break}else{V=aa;ia=da;ea=ea+1|0}}ia=d[1359820]|0;if(!((ia+12|0)>>>0<7>>>0)){V=(ia-1|0)/7|0;while(1){bD(_,155>>>(V<<3>>>0)&255);if((V|0)==0){break}else{V=V-1|0}}}SK(_,ea,(ea|0)<0|0?-1:0,0);if((ea|0)>0){V=ea;do{V=V-1|0;ia=zrc(ha|0,ka|0,V<<3|0)|0;bD(_,ia&255);}while((V|0)>0)}V=fD(_,0,0,1)|0;ka=G;ha=xrc(ba,ja,la,(la|0)<0|0?-1:0)|0;ea=fD(_,ha,G,0)|0;ha=G;ia=0;if((ha|0)<(ia|0)|(ha|0)==(ia|0)&ea>>>0<0>>>0){ga=Fa;break}ea=xrc(V,ka,ba,ja)|0;SK(_,ea,G,la);fD(_,V,ka,0)|0;ga=Fa;break}else if(($|0)==1465275476){ka=c[I>>2]|0;V=(c[(c[ka+96>>2]|0)+(c[M>>2]<<3)>>2]|0)==0?U:T;ea=c[V>>2]|0;ia=c[V+4>>2]|0;c[g>>2]=0;V=V1(e,75,g)|0;c[h>>2]=0;ha=V1(e,76,h)|0;F=e+28|0;ma=(c[g>>2]|0)+2+(c[h>>2]|0)+(c[F>>2]|0)|0;da=fD(_,0,0,1)|0;aa=G;za=c[U>>2]|0;Ba=c[U+4>>2]|0;Ca=c[T>>2]|0;xa=c[T+4>>2]|0;Aa=c[R>>2]|0;KIb(b,48,2341752,(X=i,i=i+72|0,c[X>>2]=da,c[X+8>>2]=aa,c[X+16>>2]=ma,c[X+24>>2]=za,c[X+32>>2]=Ba,c[X+40>>2]=Ca,c[X+48>>2]=xa,c[X+56>>2]=Aa,c[X+64>>2]=0,X)|0);i=X;Aa=ma+4|0;xa=Aa;Ca=(Aa|0)<0|0?-1:0;Aa=wrc(xa,Ca,1,0)|0;Ba=G;za=1;while(1){aa=zrc(Aa|0,Ba|0,za*7|0|0)|0;if((aa|0)==0&(G|0)==0){break}else{za=za+1|0}}Ba=ma+14+za|0;Aa=wrc(Ba,(Ba|0)<0|0?-1:0,1,0)|0;$=G;la=1;while(1){ja=zrc(Aa|0,$|0,la*7|0|0)|0;if((ja|0)==0&(G|0)==0){break}else{la=la+1|0}}$=Ba+1+la|0;TK(j,_,160,$,($|0)<0|0?-1:0);$=j|0;Aa=c[$>>2]|0;za=c[$+4>>2]|0;$=c[j+8>>2]|0;ma=d[1359826]|0;if(!((ma+12|0)>>>0<7>>>0)){ja=(ma-1|0)/7|0;while(1){bD(_,161>>>(ja<<3>>>0)&255);if((ja|0)==0){break}else{ja=ja-1|0}}}SK(_,xa,Ca,0);bD(_,(c[M>>2]|0)+1|128);ja=ka+64|0;la=xrc(ea,ia,c[ja>>2]|0,c[ja+4>>2]|0)|0;tD(_,la);bD(_,0);la=c[h>>2]|0;ja=c[F>>2]|0;Ba=c[e+24>>2]|0;YD(_,2335912,(X=i,i=i+48|0,c[X>>2]=c[g>>2],c[X+8>>2]=V,c[X+16>>2]=la,c[X+24>>2]=ha,c[X+32>>2]=ja,c[X+40>>2]=Ba,X)|0)|0;i=X;Ba=c[R>>2]|0;ja=Ba;la=(Ba|0)<0|0?-1:0;Ba=la;ma=ja;ba=1;while(1){aa=ma>>>8|Ba<<24;da=Ba>>>8|0<<24;if((aa|0)==0&(da|0)==0){break}else{Ba=da;ma=aa;ba=ba+1|0}}ma=d[1359820]|0;if(!((ma+12|0)>>>0<7>>>0)){Ba=(ma-1|0)/7|0;while(1){bD(_,155>>>(Ba<<3>>>0)&255);if((Ba|0)==0){break}else{Ba=Ba-1|0}}}SK(_,ba,(ba|0)<0|0?-1:0,0);if((ba|0)>0){Ba=ba;do{Ba=Ba-1|0;ma=zrc(ja|0,la|0,Ba<<3|0)|0;bD(_,ma&255);}while((Ba|0)>0)}Ba=fD(_,0,0,1)|0;la=G;ja=xrc(Aa,za,$,($|0)<0|0?-1:0)|0;ba=fD(_,ja,G,0)|0;ja=G;ma=0;if(!((ja|0)<(ma|0)|(ja|0)==(ma|0)&ba>>>0<0>>>0)){ba=xrc(Ba,la,Aa,za)|0;SK(_,ba,G,$);fD(_,Ba,la,0)|0;}ga=c[R>>2]|0;break}else{la=c[e+28>>2]|0;Ba=la+4|0;ba=wrc(Ba,(Ba|0)<0|0?-1:0,1,0)|0;Ba=G;ma=1;while(1){ja=zrc(ba|0,Ba|0,ma*7|0|0)|0;if((ja|0)==0&(G|0)==0){break}else{ma=ma+1|0}}Ba=la+14+ma|0;ba=wrc(Ba,(Ba|0)<0|0?-1:0,1,0)|0;$=G;za=1;while(1){Aa=zrc(ba|0,$|0,za*7|0|0)|0;if((Aa|0)==0&(G|0)==0){break}else{za=za+1|0}}$=Ba+1+za|0;TK(H,_,160,$,($|0)<0|0?-1:0);$=e+72|0;ba=c[$>>2]|0;ma=c[$+4>>2]|0;$=0;la=(ma|0)>($|0)|(ma|0)==($|0)&ba>>>0>0>>>0?ba:S;VK(b,_,161,e,0);ba=la;$=(la|0)<0|0?-1:0;ma=$;Aa=ba;ja=1;while(1){ha=Aa>>>8|ma<<24;V=ma>>>8|0<<24;if((ha|0)==0&(V|0)==0){break}else{ma=V;Aa=ha;ja=ja+1|0}}Aa=d[1359820]|0;if(!((Aa+12|0)>>>0<7>>>0)){ma=(Aa-1|0)/7|0;while(1){bD(_,155>>>(ma<<3>>>0)&255);if((ma|0)==0){break}else{ma=ma-1|0}}}SK(_,ja,(ja|0)<0|0?-1:0,0);if((ja|0)>0){ma=ja;do{ma=ma-1|0;Aa=zrc(ba|0,$|0,ma<<3|0)|0;bD(_,Aa&255);}while((ma|0)>0)}ma=H|0;$=c[ma>>2]|0;ba=c[ma+4>>2]|0;ma=c[H+8>>2]|0;ja=fD(_,0,0,1)|0;Aa=G;za=xrc($,ba,ma,(ma|0)<0|0?-1:0)|0;Ba=fD(_,za,G,0)|0;za=G;ha=0;if((za|0)<(ha|0)|(za|0)==(ha|0)&Ba>>>0<0>>>0){ga=la;break}Ba=xrc(ja,Aa,$,ba)|0;SK(_,Ba,G,ma);fD(_,ja,Aa,0)|0;ga=la;break}}else{VK(b,_,163,e,Q<<7);ga=S}}while(0);S=c[Z>>2]|0;Z=(S|0)==3;do{if((Q|0)!=0&(S|0)==0|Z){e=c[J+92>>2]|0;_=c[M>>2]|0;b=c[L>>2]|0;H=c[L+4>>2]|0;R=ga;X=(ga|0)<0|0?-1:0;g=e+8|0;h=0;if((W|0)<(h|0)|(W|0)==(h|0)&N>>>0<0>>>0){Ia=X;Ja=R;break}h=e+12|0;j=nJb(c[g>>2]|0,(c[h>>2]|0)+1|0,40)|0;T=j;if((j|0)==0){Y=-12;i=f;return Y|0}else{c[g>>2]=T;g=c[h>>2]|0;j=T+(g*40|0)|0;c[j>>2]=N;c[j+4>>2]=W;c[T+(g*40|0)+8>>2]=_+1;_=e|0;e=xrc(b,H,c[_>>2]|0,c[_+4>>2]|0)|0;_=c[h>>2]|0;H=T+(_*40|0)+16|0;c[H>>2]=e;c[H+4>>2]=G;H=T+(_*40|0)+24|0;c[H>>2]=fa;c[H+4>>2]=K;c[h>>2]=_+1;h=T+(_*40|0)+32|0;c[h>>2]=Z?R:-1;c[h+4>>2]=Z?X:-1;Ia=X;Ja=R;break}}else{Ia=(ga|0)<0|0?-1:0;Ja=ga}}while(0);ga=J+80|0;J=c[ga>>2]|0;Z=c[ga+4>>2]|0;K=wrc(Ja,Ia,N,W)|0;W=G;N=(Z|0)>(W|0)|(Z|0)==(W|0)&J>>>0>K>>>0;c[ga>>2]=N?J:K;c[ga+4>>2]=N?Z:W;Y=0;i=f;return Y|0}function OK(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+64|0;e=b|0;f=b+16|0;g=b+32|0;h=b+48|0;j=c[a+12>>2]|0;k=c[a+16>>2]|0;l=a+1132|0;if((c[l>>2]|0)==0){m=0;i=b;return m|0}n=j+220|0;if((c[n>>2]|0)!=0){m=0;i=b;return m|0}o=c[j+88>>2]|0;p=fD(k,0,0,1)|0;q=G;r=o+24|0;s=c[o+20>>2]|0;t=o+28|0;u=c[t>>2]|0;if(!((s|0)<1|(s|0)>(u|0))){m=-1;i=b;return m|0}s=nJb(c[r>>2]|0,u+1|0,16)|0;u=s;if((s|0)==0){m=-12;i=b;return m|0}c[r>>2]=u;c[u+(c[t>>2]<<4)>>2]=272869232;r=o+8|0;o=xrc(p,q,c[r>>2]|0,c[r+4>>2]|0)|0;r=c[t>>2]|0;c[t>>2]=r+1;t=u+(r<<4)+8|0;c[t>>2]=o;c[t+4>>2]=G;TK(e,k,272869232,0,0);t=e|0;o=c[t>>2]|0;r=c[t+4>>2]|0;t=c[e+8>>2]|0;TK(f,k,17849,0,0);e=f|0;u=c[e>>2]|0;q=c[e+4>>2]|0;e=c[f+8>>2]|0;f=d[1359733]|0;p=(f+20|0)>>>0<7>>>0;do{if(p){SK(k,1,0,0);bD(k,1)}else{s=(f+7|0)/7|0;while(1){bD(k,17883>>>(s<<3>>>0)&255);if((s|0)==0){break}else{s=s-1|0}}SK(k,1,0,0);bD(k,1);if(p){break}s=(f+7|0)/7|0;while(1){bD(k,17853>>>(s<<3>>>0)&255);if((s|0)==0){break}else{s=s-1|0}}}}while(0);SK(k,1,0,0);bD(k,0);if((c[l>>2]|0)!=0){s=a+1136|0;a=g|0;v=g+8|0;w=j+216|0;j=d[1359779]|0;x=(j+20|0)>>>0<7>>>0;y=d[1359810]|0;z=(y+12|0)>>>0<7>>>0;A=d[1359811]|0;B=(A+12|0)>>>0<7>>>0;C=d[1359817]|0;D=(C+12|0)>>>0<7>>>0;E=h|0;F=h+8|0;H=(f+7|0)/7|0;f=(C-1|0)/7|0;C=(A-1|0)/7|0;A=(y-1|0)/7|0;y=(j+7|0)/7|0;j=0;do{I=c[(c[s>>2]|0)+(j<<2)>>2]|0;TK(g,k,182,0,0);J=c[a>>2]|0;K=c[a+4>>2]|0;L=c[v>>2]|0;M=(c[w>>2]|0)+(c[I>>2]|0)|0;N=0;O=N;P=M;Q=1;while(1){R=P>>>8|O<<24;S=O>>>8|0<<24;if((R|0)==0&(S|0)==0){break}else{O=S;P=R;Q=Q+1|0}}if(!x){P=y;while(1){bD(k,29636>>>(P<<3>>>0)&255);if((P|0)==0){break}else{P=P-1|0}}}SK(k,Q,(Q|0)<0|0?-1:0,0);if((Q|0)>0){P=Q;do{P=P-1|0;O=zrc(M|0,N|0,P<<3|0)|0;bD(k,O&255);}while((P|0)>0)}P=I+16|0;N=I+4|0;M=XIb(c[P>>2]|0,c[P+4>>2]|0,N,830712)|0;P=G;Q=P;O=M;R=1;while(1){S=O>>>8|Q<<24;T=Q>>>8|0<<24;if((S|0)==0&(T|0)==0){break}else{Q=T;O=S;R=R+1|0}}if(!z){O=A;while(1){bD(k,145>>>(O<<3>>>0)&255);if((O|0)==0){break}else{O=O-1|0}}}SK(k,R,(R|0)<0|0?-1:0,0);if((R|0)>0){O=R;do{O=O-1|0;Q=zrc(M|0,P|0,O<<3|0)|0;bD(k,Q&255);}while((O|0)>0)}O=I+24|0;P=XIb(c[O>>2]|0,c[O+4>>2]|0,N,830712)|0;O=G;M=O;R=P;Q=1;while(1){S=R>>>8|M<<24;T=M>>>8|0<<24;if((S|0)==0&(T|0)==0){break}else{M=T;R=S;Q=Q+1|0}}if(!B){R=C;while(1){bD(k,146>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}}SK(k,Q,(Q|0)<0|0?-1:0,0);if((Q|0)>0){R=Q;do{R=R-1|0;M=zrc(P|0,O|0,R<<3|0)|0;bD(k,M&255);}while((R|0)>0)}if(!D){R=f;while(1){bD(k,152>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}}SK(k,1,0,0);bD(k,0);if(!p){R=H;while(1){bD(k,17816>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}}SK(k,1,0,0);bD(k,1);R=LGb(c[I+32>>2]|0,2377928,0,0)|0;do{if((R|0)!=0){TK(h,k,128,0,0);O=c[E>>2]|0;P=c[E+4>>2]|0;Q=c[F>>2]|0;UK(k,133,c[R+4>>2]|0);UK(k,17276,2372344);M=fD(k,0,0,1)|0;N=G;S=xrc(O,P,Q,(Q|0)<0|0?-1:0)|0;T=fD(k,S,G,0)|0;S=G;U=0;if((S|0)<(U|0)|(S|0)==(U|0)&T>>>0<0>>>0){break}T=xrc(M,N,O,P)|0;SK(k,T,G,Q);fD(k,M,N,0)|0;}}while(0);R=fD(k,0,0,1)|0;I=G;N=xrc(J,K,L,(L|0)<0|0?-1:0)|0;M=fD(k,N,G,0)|0;N=G;Q=0;if(!((N|0)<(Q|0)|(N|0)==(Q|0)&M>>>0<0>>>0)){M=xrc(R,I,J,K)|0;SK(k,M,G,L);fD(k,R,I,0)|0;}j=j+1|0;}while(j>>>0<(c[l>>2]|0)>>>0)}l=fD(k,0,0,1)|0;j=G;F=xrc(u,q,e,(e|0)<0|0?-1:0)|0;E=fD(k,F,G,0)|0;F=G;h=0;if(!((F|0)<(h|0)|(F|0)==(h|0)&E>>>0<0>>>0)){E=xrc(l,j,u,q)|0;SK(k,E,G,e);fD(k,l,j,0)|0;}j=fD(k,0,0,1)|0;l=G;e=xrc(o,r,t,(t|0)<0|0?-1:0)|0;E=fD(k,e,G,0)|0;e=G;q=0;if(!((e|0)<(q|0)|(e|0)==(q|0)&E>>>0<0>>>0)){E=xrc(j,l,o,r)|0;SK(k,E,G,t);fD(k,j,l,0)|0;}c[n>>2]=1;m=0;i=b;return m|0}function PK(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;g=i;i=i+48|0;h=g|0;j=g+16|0;k=g+32|0;l=fD(a,0,0,1)|0;m=G;TK(h,a,475249515,0,0);n=h|0;o=c[n>>2]|0;p=c[n+4>>2]|0;n=c[h+8>>2]|0;h=b+12|0;a:do{if((c[h>>2]|0)>0){q=b+8|0;r=(f*42|0)+12|0;s=r;t=(r|0)<0|0?-1:0;r=j|0;u=j+8|0;v=d[1359844]|0;w=(v+12|0)>>>0<7>>>0;x=(f|0)>0;y=k|0;z=k+8|0;A=d[1359912]|0;B=(A+12|0)>>>0<7>>>0;C=d[1359906]|0;D=(C+12|0)>>>0<7>>>0;E=d[1359905]|0;F=(E+12|0)>>>0<7>>>0;H=d[1359843]|0;I=(H+12|0)>>>0<7>>>0;J=(H-1|0)/7|0;H=(E-1|0)/7|0;E=(C-1|0)/7|0;C=(A-1|0)/7|0;A=(v-1|0)/7|0;v=0;b:while(1){K=c[q>>2]|0;L=K+(v*40|0)|0;M=c[L>>2]|0;N=c[L+4>>2]|0;TK(j,a,187,s,t);L=c[r>>2]|0;O=c[r+4>>2]|0;P=c[u>>2]|0;Q=N;R=M;S=1;while(1){T=R>>>8|Q<<24;U=Q>>>8|0<<24;if((T|0)==0&(U|0)==0){break}else{Q=U;R=T;S=S+1|0}}if(!w){R=A;while(1){bD(a,179>>>(R<<3>>>0)&255);if((R|0)==0){break}else{R=R-1|0}}}SK(a,S,(S|0)<0|0?-1:0,0);if((S|0)>0){R=S;do{R=R-1|0;Q=zrc(M|0,N|0,R<<3|0)|0;bD(a,Q&255);}while((R|0)>0)}if(x){R=0;do{c[e+(R<<3)+4>>2]=0;R=R+1|0;}while((R|0)<(f|0))}c:do{if(((c[h>>2]|0)-v|0)>0){R=0;while(1){S=R+v|0;Q=K+(S*40|0)|0;if(!((c[Q>>2]|0)==(M|0)&(c[Q+4>>2]|0)==(N|0))){V=R;break c}Q=K+(S*40|0)+8|0;T=c[Q>>2]|0;U=T-1|0;if(!((T|0)>0&(U|0)<(f|0))){break b}T=e+(U<<3)+4|0;do{if((c[T>>2]|0)==0){c[T>>2]=1;TK(k,a,183,42,0);U=c[y>>2]|0;W=c[y+4>>2]|0;X=c[z>>2]|0;Y=c[Q>>2]|0;Z=Y;_=(Y|0)<0|0?-1:0;Y=_;$=Z;aa=1;while(1){ba=$>>>8|Y<<24;ca=Y>>>8|0<<24;if((ba|0)==0&(ca|0)==0){break}else{Y=ca;$=ba;aa=aa+1|0}}if(!B){$=C;while(1){bD(a,247>>>($<<3>>>0)&255);if(($|0)==0){break}else{$=$-1|0}}}SK(a,aa,(aa|0)<0|0?-1:0,0);if((aa|0)>0){$=aa;do{$=$-1|0;Y=zrc(Z|0,_|0,$<<3|0)|0;bD(a,Y&255);}while(($|0)>0)}$=K+(S*40|0)+16|0;_=c[$>>2]|0;Z=c[$+4>>2]|0;$=Z;aa=_;Y=1;while(1){ba=aa>>>8|$<<24;ca=$>>>8|0<<24;if((ba|0)==0&(ca|0)==0){break}else{$=ca;aa=ba;Y=Y+1|0}}if(!D){aa=E;while(1){bD(a,241>>>(aa<<3>>>0)&255);if((aa|0)==0){break}else{aa=aa-1|0}}}SK(a,Y,(Y|0)<0|0?-1:0,0);if((Y|0)>0){aa=Y;do{aa=aa-1|0;$=zrc(_|0,Z|0,aa<<3|0)|0;bD(a,$&255);}while((aa|0)>0)}aa=K+(S*40|0)+24|0;Z=c[aa>>2]|0;_=c[aa+4>>2]|0;aa=_;Y=Z;$=1;while(1){ba=Y>>>8|aa<<24;ca=aa>>>8|0<<24;if((ba|0)==0&(ca|0)==0){break}else{aa=ca;Y=ba;$=$+1|0}}if(!F){Y=H;while(1){bD(a,240>>>(Y<<3>>>0)&255);if((Y|0)==0){break}else{Y=Y-1|0}}}SK(a,$,($|0)<0|0?-1:0,0);if(($|0)>0){Y=$;do{Y=Y-1|0;aa=zrc(Z|0,_|0,Y<<3|0)|0;bD(a,aa&255);}while((Y|0)>0)}Y=K+(S*40|0)+32|0;_=c[Y>>2]|0;Z=c[Y+4>>2]|0;do{if(!((_|0)==(-1|0)&(Z|0)==(-1|0))){Y=Z;$=_;aa=1;while(1){ba=$>>>8|Y<<24;ca=Y>>>8|0<<24;if((ba|0)==0&(ca|0)==0){break}else{Y=ca;$=ba;aa=aa+1|0}}if(!I){$=J;while(1){bD(a,178>>>($<<3>>>0)&255);if(($|0)==0){break}else{$=$-1|0}}}SK(a,aa,(aa|0)<0|0?-1:0,0);if((aa|0)>0){da=aa}else{break}do{da=da-1|0;$=zrc(_|0,Z|0,da<<3|0)|0;bD(a,$&255);}while((da|0)>0)}}while(0);Z=fD(a,0,0,1)|0;_=G;aa=xrc(U,W,X,(X|0)<0|0?-1:0)|0;$=fD(a,aa,G,0)|0;aa=G;Y=0;if((aa|0)<(Y|0)|(aa|0)==(Y|0)&$>>>0<0>>>0){break}$=xrc(Z,_,U,W)|0;SK(a,$,G,X);fD(a,Z,_,0)|0;}}while(0);S=R+1|0;if((S|0)<((c[h>>2]|0)-v|0)){R=S}else{V=S;break}}}else{V=0}}while(0);K=fD(a,0,0,1)|0;N=G;M=xrc(L,O,P,(P|0)<0|0?-1:0)|0;R=fD(a,M,G,0)|0;M=G;S=0;if(!((M|0)<(S|0)|(M|0)==(S|0)&R>>>0<0>>>0)){R=xrc(K,N,L,O)|0;SK(a,R,G,P);fD(a,K,N,0)|0;}v=V+v|0;if((v|0)>=(c[h>>2]|0)){break a}}KIb(0,0,2433600,(v=i,i=i+24|0,c[v>>2]=2384944,c[v+8>>2]=2413840,c[v+16>>2]=446,v)|0);i=v;Hd();return 0}}while(0);h=fD(a,0,0,1)|0;V=G;da=xrc(o,p,n,(n|0)<0|0?-1:0)|0;k=fD(a,da,G,0)|0;da=G;e=0;if((da|0)<(e|0)|(da|0)==(e|0)&k>>>0<0>>>0){i=g;return(G=m,l)|0}k=xrc(h,V,o,p)|0;SK(a,k,G,n);fD(a,h,V,0)|0;i=g;return(G=m,l)|0}function QK(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=fD(a,0,0,1)|0;h=G;j=0;if(!(e>>>0>j>>>0|e>>>0==j>>>0&b>>>0>1>>>0)){KIb(0,0,2433600,(j=i,i=i+24|0,c[j>>2]=2391728,c[j+8>>2]=2413840,c[j+16>>2]=251,j)|0);i=j;Hd()}j=d[1359901]|0;if(!((j+12|0)>>>0<7>>>0)){k=(j-1|0)/7|0;while(1){bD(a,236>>>(k<<3>>>0)&255);if((k|0)==0){break}else{k=k-1|0}}}k=0;if(e>>>0<k>>>0|e>>>0==k>>>0&b>>>0<10>>>0){k=wrc(b,e,-1,-1)|0;SK(a,k,G,0)}else{k=wrc(b,e,-9,-1)|0;SK(a,k,G,8)}k=wrc(g,h,b,e)|0;e=G;b=fD(a,0,0,1)|0;h=xrc(k,e,b,G)|0;cD(a,0,h);i=f;return}function RK(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+32|0;f=e|0;g=e+16|0;h=fD(a,0,0,1)|0;j=G;k=b+16|0;l=c[k>>2]|0;do{if((l|0)>0){m=b|0;n=fD(a,c[m>>2]|0,c[m+4>>2]|0,0)|0;m=G;o=0;if((m|0)<(o|0)|(m|0)==(o|0)&n>>>0<0>>>0){p=b+24|0;q=p;mJb(q);r=b;kJb(r);i=e;return}else{s=c[k>>2]|0;break}}else{s=l}}while(0);TK(f,a,290298740,s,(s|0)<0|0?-1:0);s=f|0;l=c[s>>2]|0;n=c[s+4>>2]|0;s=c[f+8>>2]|0;f=b+28|0;if((c[f>>2]|0)>0){o=b+24|0;m=g|0;t=g+8|0;u=d[1359747]|0;v=(u+20|0)>>>0<7>>>0;w=(u+7|0)/7|0;u=0;do{x=c[o>>2]|0;TK(g,a,19899,21,0);y=c[m>>2]|0;z=c[m+4>>2]|0;A=c[t>>2]|0;if(!v){B=w;while(1){bD(a,21419>>>(B<<3>>>0)&255);if((B|0)==0){break}else{B=B-1|0}}}B=x+(u<<4)|0;C=(c[B>>2]|0)+1|0;D=C>>>0>65535>>>0;E=D?C>>>16:C;C=D?16:0;if((E&65280|0)==0){F=C;H=E}else{F=C|8;H=E>>>8}E=((F-1+(d[1359664+H|0]|0)|0)/7|0)+1|0;SK(a,E,(E|0)<0|0?-1:0,0);E=c[B>>2]|0;B=E+1|0;C=B>>>0>65535>>>0;D=C?B>>>16:B;B=C?16:0;if((D&65280|0)==0){I=B;J=D}else{I=B|8;J=D>>>8}D=I-1+(d[1359664+J|0]|0)|0;if(!((D+13|0)>>>0<7>>>0)){B=(D|0)/7|0;while(1){bD(a,E>>>(B<<3>>>0)&255);if((B|0)==0){break}else{B=B-1|0}}}B=x+(u<<4)+8|0;E=c[B>>2]|0;D=c[B+4>>2]|0;B=D;C=E;K=1;while(1){L=C>>>8|B<<24;M=B>>>8|0<<24;if((L|0)==0&(M|0)==0){break}else{B=M;C=L;K=K+1|0}}if(!v){C=w;while(1){bD(a,21420>>>(C<<3>>>0)&255);if((C|0)==0){break}else{C=C-1|0}}}SK(a,K,(K|0)<0|0?-1:0,0);if((K|0)>0){C=K;do{C=C-1|0;B=zrc(E|0,D|0,C<<3|0)|0;bD(a,B&255);}while((C|0)>0)}C=fD(a,0,0,1)|0;D=G;E=xrc(y,z,A,(A|0)<0|0?-1:0)|0;K=fD(a,E,G,0)|0;E=G;B=0;if(!((E|0)<(B|0)|(E|0)==(B|0)&K>>>0<0>>>0)){K=xrc(C,D,y,z)|0;SK(a,K,G,A);fD(a,C,D,0)|0;}u=u+1|0;}while((u|0)<(c[f>>2]|0))}f=fD(a,0,0,1)|0;u=G;w=xrc(l,n,s,(s|0)<0|0?-1:0)|0;v=fD(a,w,G,0)|0;w=G;J=0;if(!((w|0)<(J|0)|(w|0)==(J|0)&v>>>0<0>>>0)){v=xrc(f,u,l,n)|0;SK(a,v,G,s);fD(a,f,u,0)|0;}u=c[k>>2]|0;if((u|0)<=0){p=b+24|0;q=p;mJb(q);r=b;kJb(r);i=e;return}k=b|0;f=wrc(c[k>>2]|0,c[k+4>>2]|0,u,(u|0)<0|0?-1:0)|0;u=G;k=fD(a,0,0,1)|0;s=xrc(f,u,k,G)|0;QK(a,s,G);fD(a,h,j,0)|0;p=b+24|0;q=p;mJb(q);r=b;kJb(r);i=e;return}function SK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=wrc(b,d,1,0)|0;h=G;j=1;while(1){k=zrc(g|0,h|0,j*7|0|0)|0;if((k|0)==0&(G|0)==0){break}else{j=j+1|0}}h=16777215;if(!(d>>>0<h>>>0|d>>>0==h>>>0&b>>>0<-1>>>0)){KIb(0,0,2433600,(l=i,i=i+24|0,c[l>>2]=2424768,c[l+8>>2]=2413840,c[l+16>>2]=182,l)|0);i=l;Hd()}h=(e|0)==0?j:e;if((h|0)<(j|0)){KIb(0,0,2433600,(l=i,i=i+24|0,c[l>>2]=2406224,c[l+8>>2]=2413840,c[l+16>>2]=189,l)|0);i=l;Hd()}l=yrc(1,0,h*7|0|0)|0;j=l|b;b=G|d;if((h|0)>0){m=h}else{i=f;return}do{m=m-1|0;h=zrc(j|0,b|0,m<<3|0)|0;bD(a,h&255);}while((m|0)>0);i=f;return}function TK(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;if((f|0)==0&(g|0)==0){j=8}else{k=wrc(f,g,1,0)|0;g=G;f=1;while(1){l=zrc(k|0,g|0,f*7|0|0)|0;if((l|0)==0&(G|0)==0){j=f;break}else{f=f+1|0}}}f=e+1|0;g=f>>>0>65535>>>0;k=g?f>>>16:f;f=g?16:0;if((k&65280|0)==0){m=f;n=k}else{m=f|8;n=k>>>8}k=m-1+(d[1359664+n|0]|0)|0;if(!((k+13|0)>>>0<7>>>0)){n=(k|0)/7|0;while(1){bD(b,e>>>(n<<3>>>0)&255);if((n|0)==0){break}else{n=n-1|0}}}if((j|0)<9){bD(b,511>>>(j>>>0));cD(b,255,j-1|0);n=fD(b,0,0,1)|0;b=a|0;c[b>>2]=n;c[b+4>>2]=G;c[a+8>>2]=j;i=h;return}else{KIb(0,0,2433600,(h=i,i=i+24|0,c[h>>2]=2398672,c[h+8>>2]=2413840,c[h+16>>2]=156,h)|0);i=h;Hd()}}function UK(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=lrc(c|0)|0;f=b+1|0;g=f>>>0>65535>>>0;h=g?f>>>16:f;f=g?16:0;if((h&65280|0)==0){i=f;j=h}else{i=f|8;j=h>>>8}h=i-1+(d[1359664+j|0]|0)|0;if((h+13|0)>>>0<7>>>0){k=e;l=(e|0)<0|0?-1:0;SK(a,k,l,0);dD(a,c,e);return}j=(h|0)/7|0;while(1){bD(a,b>>>(j<<3>>>0)&255);if((j|0)==0){break}else{j=j-1|0}}k=e;l=(e|0)<0|0?-1:0;SK(a,k,l,0);dD(a,c,e);return}function VK(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;j=i;i=i+136|0;k=j|0;l=j+8|0;m=j+48|0;n=j+56|0;o=j+64|0;p=j+72|0;q=j+80|0;r=j+88|0;s=j+104|0;t=j+120|0;u=c[b+12>>2]|0;v=g+32|0;w=c[v>>2]|0;x=c[(c[(c[b+28>>2]|0)+(w<<2)>>2]|0)+8>>2]|0;c[m>>2]=0;z=g+28|0;A=c[z>>2]|0;c[n>>2]=A;c[o>>2]=0;B=g+16|0;C=g+8|0;D=(c[(c[u+96>>2]|0)+(w<<3)>>2]|0)==0?C:B;w=c[D>>2]|0;E=c[D+4>>2]|0;D=b;b=fD(e,0,0,1)|0;F=G;H=c[z>>2]|0;z=c[C>>2]|0;I=c[C+4>>2]|0;C=c[B>>2]|0;J=c[B+4>>2]|0;B=c[g+48>>2]|0;KIb(D,48,2341752,(K=i,i=i+72|0,c[K>>2]=b,c[K+8>>2]=F,c[K+16>>2]=H,c[K+24>>2]=z,c[K+32>>2]=I,c[K+40>>2]=C,c[K+48>>2]=J,c[K+56>>2]=B,c[K+64>>2]=h,K)|0);i=K;B=x+48|0;J=c[B>>2]|0;a:do{if((J|0)==28){if((c[x+100>>2]|0)<=0){L=11;break}C=c[x+96>>2]|0;do{if(((d[C+1|0]|0)<<8|(d[C]|0)<<16|(d[C+2|0]|0)|0)!=1){I=C;if((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)==16777216){break}if((J|0)==1211250229){L=7;break a}else{L=12;break a}}}while(0);p$(c[g+24>>2]|0,m,n)|0}else if((J|0)==1211250229){L=7}else{L=12}}while(0);do{if((L|0)==7){if((c[x+100>>2]|0)<=6){L=11;break}C=c[x+96>>2]|0;if(((d[C+1|0]|0)<<8|(d[C]|0)<<16|(d[C+2|0]|0)|0)!=1){I=C;if((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)!=16777216){L=12;break}}v$(c[g+24>>2]|0,m,n,0,0)|0}}while(0);b:do{if((L|0)==11){M=c[g+24>>2]|0;L=28}else if((L|0)==12){I=c[g+24>>2]|0;if((J|0)!=86041){M=I;L=28;break}C=k;z=hJb(A)|0;c[k>>2]=z;c:do{if((z|0)!=0){do{if((A|0)>31){H=l|0;F=l+28|0;b=l+20|0;N=l+24|0;O=l+32|0;P=l+16|0;Q=I;R=A;S=0;while(1){T=a_(l,Q)|0;if((T|0)<0){U=T;L=26;break}T=Q+32|0;V=R-32|0;if(V>>>0<(c[H>>2]|0)>>>0){U=-1094995529;L=26;break}if((c[F>>2]|0)==0){W=S}else{X=(c[k>>2]|0)+S|0;y=c[P>>2]|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;W=S+4|0}X=(c[k>>2]|0)+W|0;y=c[b>>2]|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=(c[k>>2]|0)+(W+4)|0;y=c[N>>2]|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=W+8|0;if((c[F>>2]|0)==0){L=22}else{if((c[O>>2]|0)==0){L=22}else{Y=X}}if((L|0)==22){L=0;Z=(c[k>>2]|0)+X|0;y=c[H>>2]|0;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;Y=W+12|0}nrc((c[k>>2]|0)+Y|0,T|0,c[H>>2]|0)|0;T=c[H>>2]|0;Z=V-T|0;_=T+Y|0;if((Z|0)>31){Q=Q+(T+32)|0;R=Z;S=_}else{L=24;break}}if((L|0)==24){$=_;aa=c[k>>2]|0;break}else if((L|0)==26){mJb(C);if((U|0)<0){break c}else{break b}}}else{$=0;aa=z}}while(0);c[m>>2]=aa;c[n>>2]=$;break b}}while(0);KIb(D,16,2296112,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;i=j;return}}while(0);if((L|0)==28){c[m>>2]=M}if((c[B>>2]|0)==149){c[n>>2]=(c[n>>2]|0)-8;ba=8}else{ba=0}B=V1(g,70,o)|0;if((B|0)!=0&(c[o>>2]|0)>9){M=B+4|0;B=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;c[p>>2]=1;c[p+4>>2]=c[x+412>>2];c[q>>2]=1;c[q+4>>2]=1e9;x=XIb(B,0,p,q)|0;ca=G;da=x}else{ca=0;da=0}x=V1(g,74,o)|0;if((x|0)==0){ea=0;fa=0;ga=c[o>>2]|0}else{q=x;p=q|0;B=q+4|0;q=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;p=je(q|0)|0;q=(c[o>>2]|0)-8|0;c[o>>2]=q;ea=(p|0)==1&(B|0)==0;fa=x+8|0;ga=q}if((da|0)==0&(ca|0)==0&((ga|0)!=0&ea^1)){ha=f;ia=0;ja=0;ka=0}else{TK(r,e,160,0,0);f=r|0;ha=161;ia=c[f+4>>2]|0;ja=c[f>>2]|0;ka=c[r+8>>2]|0}r=ha+1|0;f=r>>>0>65535>>>0;ga=f?r>>>16:r;r=f?16:0;if((ga&65280|0)==0){la=r;ma=ga}else{la=r|8;ma=ga>>>8}ga=la-1+(d[1359664+ma|0]|0)|0;if(!((ga+13|0)>>>0<7>>>0)){ma=(ga|0)/7|0;while(1){bD(e,ha>>>(ma<<3>>>0)&255);if((ma|0)==0){break}else{ma=ma-1|0}}}ma=(c[n>>2]|0)+4|0;SK(e,ma,(ma|0)<0|0?-1:0,0);bD(e,(c[v>>2]|0)+1|128);v=u+64|0;u=xrc(w,E,c[v>>2]|0,c[v+4>>2]|0)|0;tD(e,u);bD(e,h);dD(e,(c[m>>2]|0)+ba|0,c[n>>2]|0);n=c[m>>2]|0;if((n|0)!=(c[g+24>>2]|0)){kJb(n)}n=(da|0)!=0|(ca|0)!=0;do{if(n){g=(ca>>31|((ca|0)<0|0?-1:0)<<1)^da;m=((((ca|0)<0|0?-1:0)>>31|((ca|0)<0|0?-1:0)<<1)^ca)<<1|g>>>31;ba=g<<1|0>>>31;g=1;while(1){h=ba>>>8|m<<24;u=m>>>8|0<<24;if((h|0)==0&(u|0)==0){break}else{m=u;ba=h;g=g+1|0}}ba=d[1359781]|0;if(!((ba+20|0)>>>0<7>>>0)){m=(ba+7|0)/7|0;while(1){bD(e,30114>>>(m<<3>>>0)&255);if((m|0)==0){break}else{m=m-1|0}}}SK(e,g,(g|0)<0|0?-1:0,0);if((g|0)>0){na=g}else{break}do{na=na-1|0;m=Arc(da|0,ca|0,na<<3|0)|0;bD(e,m&255);}while((na|0)>0)}}while(0);do{if((c[o>>2]|0)!=0&ea){TK(s,e,30113,0,0);na=s|0;ca=c[na>>2]|0;da=c[na+4>>2]|0;na=c[s+8>>2]|0;TK(t,e,166,0,0);g=t|0;m=c[g>>2]|0;ba=c[g+4>>2]|0;g=c[t+8>>2]|0;h=d[1359903]|0;if(!((h+12|0)>>>0<7>>>0)){u=(h-1|0)/7|0;while(1){bD(e,238>>>(u<<3>>>0)&255);if((u|0)==0){break}else{u=u-1|0}}}SK(e,1,0,0);bD(e,1);u=d[1359830]|0;if(!((u+12|0)>>>0<7>>>0)){h=(u-1|0)/7|0;while(1){bD(e,165>>>(h<<3>>>0)&255);if((h|0)==0){break}else{h=h-1|0}}}h=c[o>>2]|0;SK(e,h,(h|0)<0|0?-1:0,0);dD(e,fa,c[o>>2]|0);h=fD(e,0,0,1)|0;u=G;v=xrc(m,ba,g,(g|0)<0|0?-1:0)|0;E=fD(e,v,G,0)|0;v=G;w=0;if(!((v|0)<(w|0)|(v|0)==(w|0)&E>>>0<0>>>0)){E=xrc(h,u,m,ba)|0;SK(e,E,G,g);fD(e,h,u,0)|0;}u=fD(e,0,0,1)|0;h=G;E=xrc(ca,da,na,(na|0)<0|0?-1:0)|0;w=fD(e,E,G,0)|0;E=G;v=0;if((E|0)<(v|0)|(E|0)==(v|0)&w>>>0<0>>>0){break}w=xrc(u,h,ca,da)|0;SK(e,w,G,na);fD(e,u,h,0)|0;}}while(0);if(!((c[o>>2]|0)!=0&ea|n)){i=j;return}n=fD(e,0,0,1)|0;ea=G;o=xrc(ja,ia,ka,(ka|0)<0|0?-1:0)|0;fa=fD(e,o,G,0)|0;o=G;t=0;if((o|0)<(t|0)|(o|0)==(t|0)&fa>>>0<0>>>0){i=j;return}fa=xrc(n,ea,ja,ia)|0;SK(e,fa,G,ka);fD(e,n,ea,0)|0;i=j;return}function WK(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;j=i;i=i+72|0;k=j|0;l=j+8|0;m=j+24|0;n=j+40|0;o=j+56|0;p=h|0;do{if((c[p>>2]|0)==0&(c[p+4>>2]|0)==0){q=c[(c[b+12>>2]|0)+88>>2]|0;r=b+16|0;s=fD(c[r>>2]|0,0,0,1)|0;t=G;u=q+24|0;v=c[q+20>>2]|0;w=q+28|0;x=c[w>>2]|0;if(!((v|0)<1|(v|0)>(x|0))){y=-1;i=j;return y|0}v=nJb(c[u>>2]|0,x+1|0,16)|0;x=v;if((v|0)==0){y=-12;i=j;return y|0}else{c[u>>2]=x;c[x+(c[w>>2]<<4)>>2]=307544935;u=q+8|0;q=xrc(s,t,c[u>>2]|0,c[u+4>>2]|0)|0;u=c[w>>2]|0;c[w>>2]=u+1;w=x+(u<<4)+8|0;c[w>>2]=q;c[w+4>>2]=G;TK(m,c[r>>2]|0,307544935,0,0);w=h;q=m;c[w>>2]=c[q>>2];c[w+4>>2]=c[q+4>>2];c[w+8>>2]=c[q+8>>2];c[w+12>>2]=c[q+12>>2];z=r;break}}else{z=b+16|0}}while(0);TK(n,c[z>>2]|0,29555,0,0);b=n|0;m=c[b>>2]|0;h=c[b+4>>2]|0;b=c[n+8>>2]|0;TK(o,c[z>>2]|0,25536,0,0);n=o|0;p=c[n>>2]|0;r=c[n+4>>2]|0;n=c[o+8>>2]|0;do{if((f|0)!=0){o=c[z>>2]|0;q=g;w=0;u=w;x=q;t=1;while(1){s=x>>>8|u<<24;v=u>>>8|0<<24;if((s|0)==0&(v|0)==0){break}else{u=v;x=s;t=t+1|0}}x=f+1|0;u=x>>>0>65535>>>0;s=u?x>>>16:x;x=u?16:0;if((s&65280|0)==0){A=x;B=s}else{A=x|8;B=s>>>8}s=A-1+(d[1359664+B|0]|0)|0;if(!((s+13|0)>>>0<7>>>0)){x=(s|0)/7|0;while(1){bD(o,f>>>(x<<3>>>0)&255);if((x|0)==0){break}else{x=x-1|0}}}SK(o,t,(t|0)<0|0?-1:0,0);if((t|0)>0){C=t}else{break}do{C=C-1|0;x=zrc(q|0,w|0,C<<3|0)|0;bD(o,x&255);}while((C|0)>0)}}while(0);C=c[z>>2]|0;f=fD(C,0,0,1)|0;B=G;A=xrc(p,r,n,(n|0)<0|0?-1:0)|0;g=fD(C,A,G,0)|0;A=G;o=0;if(!((A|0)<(o|0)|(A|0)==(o|0)&g>>>0<0>>>0)){g=xrc(f,B,p,r)|0;SK(C,g,G,n);fD(C,f,B,0)|0;}B=LGb(e,10230168,0,2)|0;if((B|0)!=0){f=k;C=l|0;n=l+8|0;g=B;do{B=g|0;do{if((IFb(c[B>>2]|0,2377928)|0)!=0){if((IFb(c[B>>2]|0,2225576)|0)==0){break}if((IFb(c[B>>2]|0,2269312)|0)==0){break}r=c[z>>2]|0;p=rJb(c[B>>2]|0)|0;c[k>>2]=p;o=hc(p|0,45)|0;do{if((o|0)==0){D=0}else{p=hE(o+1|0,0)|0;if((p|0)==0){D=0;break}a[o]=0;D=p}}while(0);o=c[k>>2]|0;a:while(1){p=a[o]|0;do{if((p<<24>>24|0)==0){break a}else if((p<<24>>24|0)==32){a[o]=95}else{if(!((p-97&255)>>>0<26>>>0)){break}a[o]=p-32}}while(0);o=o+1|0}TK(l,r,26568,0,0);o=c[C>>2]|0;p=c[C+4>>2]|0;A=c[n>>2]|0;UK(r,17827,c[k>>2]|0);if((D|0)!=0){UK(r,17530,D)}UK(r,17543,c[g+4>>2]|0);w=fD(r,0,0,1)|0;q=G;t=xrc(o,p,A,(A|0)<0|0?-1:0)|0;x=fD(r,t,G,0)|0;t=G;s=0;if(!((t|0)<(s|0)|(t|0)==(s|0)&x>>>0<0>>>0)){x=xrc(w,q,o,p)|0;SK(r,x,G,A);fD(r,w,q,0)|0;}mJb(f)}}while(0);g=LGb(e,10230168,g,2)|0;}while((g|0)!=0)}g=c[z>>2]|0;z=fD(g,0,0,1)|0;e=G;f=xrc(m,h,b,(b|0)<0|0?-1:0)|0;D=fD(g,f,G,0)|0;f=G;k=0;if((f|0)<(k|0)|(f|0)==(k|0)&D>>>0<0>>>0){y=0;i=j;return y|0}D=xrc(z,e,m,h)|0;SK(g,D,G,b);fD(g,z,e,0)|0;y=0;i=j;return y|0}function XK(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;a=b+4|0;d=iIb(a,c[b+8>>2]|0)|0;if((d|0)<0){e=d;return e|0}jIb(c[a>>2]|0);e=0;return e|0}function YK(a,b){a=a|0;b=b|0;kIb(c[(c[a+12>>2]|0)+4>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);return 0}function ZK(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+256|0;d=b|0;e=(c[a+12>>2]|0)+4|0;CFb(d,gIb(c[e>>2]|0)|0,56)|0;DFb(d,2507360,56)|0;bL(a,d);mIb(e);i=b;return 0}function _K(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+12>>2]|0;e=d+4|0;f=iIb(e,c[d+8>>2]|0)|0;if((f|0)<0){g=f;i=b;return g|0}f=a+16|0;YD(c[f>>2]|0,2107288,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0)|0;i=d;YD(c[f>>2]|0,2625264,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0)|0;i=d;h=c[f>>2]|0;j=gIb(c[e>>2]|0)|0;YD(h,2599320,(d=i,i=i+8|0,c[d>>2]=j,d)|0)|0;i=d;kH(a)|0;YD(c[f>>2]|0,2574736,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0)|0;i=d;g=0;i=b;return g|0}function $K(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+256|0;e=(c[a+12>>2]|0)+4|0;jIb(c[e>>2]|0);f=b+28|0;kIb(c[e>>2]|0,c[b+24>>2]|0,c[f>>2]|0);e=d|0;g=b+16|0;h=c[g>>2]|0;j=c[g+4>>2]|0;g=b+8|0;k=c[g>>2]|0;l=c[g+4>>2]|0;g=c[b+48>>2]|0;m=c[f>>2]|0;Rb(e|0,192,2265784,(f=i,i=i+56|0,c[f>>2]=c[b+32>>2],c[f+8>>2]=h,c[f+16>>2]=j,c[f+24>>2]=k,c[f+32>>2]=l,c[f+40>>2]=g,c[f+48>>2]=m,f)|0)|0;i=f;bL(a,e);i=d;return 0}function aL(a){a=a|0;mIb((c[a+12>>2]|0)+4|0);return 0}function bL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b+12>>2]|0;j=lrc(e|0)|0;k=h+4|0;h=hIb(c[k>>2]|0)|0;if(!((h|0)>0&h>>>0<65>>>0)){KIb(0,0,2217952,(l=i,i=i+24|0,c[l>>2]=2184344,c[l+8>>2]=2155616,c[l+16>>2]=41,l)|0);i=l;Hd()}lIb(c[k>>2]|0,g|0);k=j+(h<<1)|0;m=j;n=0;o=j;while(1){Rb(e+o|0,3,2130496,(l=i,i=i+8|0,c[l>>2]=d[g+n|0]|0,l)|0)|0;i=l;j=m+2|0;p=n+1|0;if((p|0)<(h|0)){m=j;n=p;o=j}else{break}}a[e+k|0]=10;a[e+(k+1)|0]=0;k=b+16|0;b=c[k>>2]|0;dD(b,e,lrc(e|0)|0);eD(c[k>>2]|0);i=f;return}function cL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;if((b|0)==(d|0)|(a|0)==0){i=e;return}g=LGb(c[a>>2]|0,10230072,0,2)|0;a:do{if((g|0)!=0){h=(b|0)==0;if((d|0)==0){j=g;while(1){k=c[j>>2]|0;b:do{if(h){l=k}else{m=b;while(1){n=m|0;if((c[n>>2]|0)==0){l=k;break b}if((IFb(k,c[m+4>>2]|0)|0)==0){break}else{m=m+8|0}}l=c[n>>2]|0}}while(0);MGb(f,l,c[j+4>>2]|0,0)|0;j=LGb(c[a>>2]|0,10230072,j,2)|0;if((j|0)==0){break a}}}if(h){j=g;while(1){k=c[j>>2]|0;m=d;while(1){o=c[m>>2]|0;if((o|0)==0){p=k;break}if((IFb(k,o)|0)==0){q=12;break}else{m=m+8|0}}if((q|0)==12){q=0;p=c[m+4>>2]|0}MGb(f,p,c[j+4>>2]|0,0)|0;j=LGb(c[a>>2]|0,10230072,j,2)|0;if((j|0)==0){break a}}}else{r=g}do{j=c[r>>2]|0;h=d;while(1){k=c[h>>2]|0;if((k|0)==0){s=j;break}if((IFb(j,k)|0)==0){q=18;break}else{h=h+8|0}}if((q|0)==18){q=0;s=c[h+4>>2]|0}j=b;while(1){t=j|0;if((c[t>>2]|0)==0){u=s;break}if((IFb(s,c[j+4>>2]|0)|0)==0){q=22;break}else{j=j+8|0}}if((q|0)==22){q=0;u=c[t>>2]|0}MGb(f,u,c[r+4>>2]|0,0)|0;r=LGb(c[a>>2]|0,10230072,r,2)|0;}while((r|0)!=0)}}while(0);OGb(a);c[a>>2]=c[f>>2];i=e;return}function dL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;cL(a+1140|0,b,d);e=a+24|0;if((c[e>>2]|0)!=0){f=a+28|0;g=0;do{cL((c[(c[f>>2]|0)+(g<<2)>>2]|0)+88|0,b,d);g=g+1|0;}while(g>>>0<(c[e>>2]|0)>>>0)}e=a+1132|0;if((c[e>>2]|0)!=0){g=a+1136|0;f=0;do{cL((c[(c[g>>2]|0)+(f<<2)>>2]|0)+32|0,b,d);f=f+1|0;}while(f>>>0<(c[e>>2]|0)>>>0)}e=a+1104|0;if((c[e>>2]|0)==0){return}f=a+1108|0;a=0;do{cL((c[(c[f>>2]|0)+(a<<2)>>2]|0)+20|0,b,d);a=a+1|0;}while(a>>>0<(c[e>>2]|0)>>>0);return}function eL(a){a=a|0;var b=0;b=c[a+4>>2]|0;a=b;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=234881024){return 0}a=b+4|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1342177280){a=b+12|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==872415232?100:0)|0}else{return 0}return 0}function fL(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,l=0,m=0;b=i;i=i+8|0;d=b|0;e=c[a+16>>2]|0;hD(e,4,0)|0;if((JD(e)|0)!=80){f=-5;i=b;return f|0}hD(e,20,0)|0;h=ZX(a,0)|0;if((h|0)==0){f=-12;i=b;return f|0}c[h+236>>2]=2;a=h+48|0;c[a>>2]=0;c[a+4>>2]=0;a=JD(e)|0;j=0;l=h+56|0;c[l>>2]=a;c[l+4>>2]=j;l=h+64|0;c[l>>2]=a;c[l+4>>2]=j;j=JD(e)|0;AKb(d,(c[k>>2]=j,+g[k>>2]),2147483647);j=c[d>>2]|0;l=c[d+4>>2]|0;d=JD(e)|0;a=h+8|0;c[(c[a>>2]|0)+120>>2]=d;d=JD(e)|0;c[(c[a>>2]|0)+124>>2]=d;hD(e,12,0)|0;c[(c[a>>2]|0)+8>>2]=0;d=JD(e)|0;c[(c[a>>2]|0)+52>>2]=d;m=JX(1409152,d)|0;c[(c[a>>2]|0)+48>>2]=m;_X(h,64,l,j);hD(e,20,0)|0;f=0;i=b;return f|0}function gL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+16>>2]|0;if((jD(d)|0)!=0){e=-541478725;return e|0}hD(d,4,0)|0;a=JD(d)|0;hD(d,4,0)|0;f=JD(d)|0;if(a>>>0<(f+16|0)>>>0){e=-5;return e|0}g=fX(d,b,f)|0;if((g|0)<0){e=g;return e|0}f=b+64|0;h=wrc(c[f>>2]|0,c[f+4>>2]|0,-16,-1)|0;c[f>>2]=h;c[f+4>>2]=G;c[b+48>>2]=1;hD(d,a-16-g|0,0)|0;e=g;return e|0}function hL(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+8|0;f=e|0;g=c[b+4>>2]|0;b=((d[g+1|0]|0)<<8|(d[g]|0)<<16|(d[g+2|0]|0)|0)==15711167?g+3|0:g;g=Bd(b|0,2107272,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;do{if((g|0)!=1){j=Bd(b|0,2625248,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((j|0)==1){break}j=Bd(b|0,2217912,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((j|0)==1){break}else{k=0}i=e;return k|0}}while(0);g=mc(b|0,2392464)|0;j=a[b+g|0]|0;if(j<<24>>24==13){l=g+1|0;m=l;n=a[b+l|0]|0}else{m=g;n=j}j=(n<<24>>24==10)+m|0;m=b+j|0;n=Bd(m|0,2107272,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;do{if((n|0)!=1){g=Bd(m|0,2625248,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((g|0)==1){break}g=Bd(m|0,2217912,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((g|0)==1){break}else{k=0}i=e;return k|0}}while(0);n=mc(m|0,2392464)|0;m=a[b+(j+n)|0]|0;if(m<<24>>24==13){g=n+1|0;o=g;p=a[b+(j+g)|0]|0}else{o=n;p=m}m=b+(j+((p<<24>>24==10)+o))|0;o=Bd(m|0,2107272,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;do{if((o|0)!=1){p=Bd(m|0,2625248,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((p|0)==1){break}p=Bd(m|0,2217912,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;if((p|0)==1){break}else{k=0}i=e;return k|0}}while(0);k=100;i=e;return k|0}function iL(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;i=i+2112|0;e=d|0;f=d+8|0;g=d+16|0;j=d+24|0;k=d+32|0;l=d+2080|0;m=d+2088|0;n=d+2096|0;o=d+2104|0;p=c[b+12>>2]|0;q=ZX(b,0)|0;if((q|0)==0){r=-12;i=d;return r|0}s=b+16|0;a:do{if((jD(c[s>>2]|0)|0)==0){t=k|0;u=o|0;v=o+4|0;w=q+8|0;x=k+11|0;y=b;z=p;A=0;B=2997;C=125;b:while(1){D=fD(c[s>>2]|0,0,0,1)|0;E=G;if((KD(c[s>>2]|0,t,2048)|0)==0){F=B;H=C;I=z;J=w;break a}a[k+(mc(t|0,2392464)|0)|0]=0;K=A+1|0;do{if((A|0)<3){L=Bd(t|0,2319728,(M=i,i=i+16|0,c[M>>2]=l,c[M+8>>2]=m,M)|0)|0;i=M;do{if((L|0)==2){if((c[l>>2]|0)>=2){N=C;O=B;break}P=+h[m>>3];if(P>3.0&P<100.0){Q=P;R=11}else{N=C;O=B}}else{S=Bd(t|0,2265696,(M=i,i=i+16|0,c[M>>2]=l,c[M+8>>2]=m,M)|0)|0;i=M;P=+h[m>>3];if((S|0)==2&(c[l>>2]|0)<2&P>3.0&P<100.0){Q=P;R=11}else{N=C;O=B}}}while(0);if((R|0)==11){R=0;AKb(o,Q,1e5);N=c[v>>2]|0;O=c[u>>2]|0}if((c[(c[w>>2]|0)+96>>2]|0)!=0){T=N;U=O;R=17;break}L=Bd(t|0,2217912,(M=i,i=i+8|0,c[M>>2]=n,M)|0)|0;i=M;if((L|0)!=1){T=N;U=O;R=17;break}L=rJb(x)|0;c[(c[w>>2]|0)+96>>2]=L;L=c[w>>2]|0;S=c[L+96>>2]|0;if((S|0)==0){r=-12;R=29;break b}c[L+100>>2]=(lrc(S|0)|0)+1;V=N;W=O}else{T=C;U=B;R=17}}while(0);do{if((R|0)==17){R=0;S=_b(t|0,125)|0;if((S|0)==0){KIb(y,24,2184312,(M=i,i=i+16|0,c[M>>2]=t,c[M+8>>2]=K,M)|0);i=M;V=T;W=U;break}L=_b(S+1|0,125)|0;if((L|0)==0){KIb(y,24,2184312,(M=i,i=i+16|0,c[M>>2]=t,c[M+8>>2]=K,M)|0);i=M;V=T;W=U;break}S=L+1|0;if((a[S]|0)==0){V=T;W=U;break}L=IV(z,S,lrc(S|0)|0,0)|0;if((L|0)==0){r=-12;R=29;break b}S=L+64|0;c[S>>2]=D;c[S+4>>2]=E;S=Bd(t|0,2130488,(M=i,i=i+16|0,c[M>>2]=g,c[M+8>>2]=j,M)|0)|0;i=M;if((S|0)==2){S=c[g>>2]|0;X=(S|0)<0|0?-1:0;Y=S}else{X=-2147483648;Y=0}S=L+8|0;c[S>>2]=Y;c[S+4>>2]=X;S=Bd(t|0,2155504,(M=i,i=i+16|0,c[M>>2]=e,c[M+8>>2]=f,M)|0)|0;i=M;if((S|0)==2){Z=(c[f>>2]|0)-(c[e>>2]|0)|0}else{Z=-1}c[L+48>>2]=Z;V=T;W=U}}while(0);if((jD(c[s>>2]|0)|0)==0){A=K;B=W;C=V}else{F=W;H=V;I=z;J=w;break a}}if((R|0)==29){i=d;return r|0}}else{F=2997;H=125;I=p;J=q+8|0}}while(0);JV(I);_X(q,64,H,F);F=c[J>>2]|0;c[F+8>>2]=3;c[F+48>>2]=1833195076;r=0;i=d;return r|0}function jL(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function kL(a){a=a|0;OV(c[a+12>>2]|0);return 0}function lL(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function mL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a+28|0;e=c[c[d>>2]>>2]|0;f=c[e+8>>2]|0;g=c[f+104>>2]|0;h=c[f+108>>2]|0;do{if((c[a+24>>2]|0)==1){if((c[f+48>>2]|0)!=1833195076){break}j=f+96|0;do{if((c[j>>2]|0)==0){k=e}else{l=f+100|0;if((c[l>>2]|0)<=0){k=e;break}m=a+16|0;dD(c[m>>2]|0,2130448,11);dD(c[m>>2]|0,c[j>>2]|0,c[l>>2]|0);eD(c[m>>2]|0);k=c[c[d>>2]>>2]|0}}while(0);_X(k,64,g,h);n=0;i=b;return n|0}}while(0);KIb(a,16,2155440,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;n=-1;i=b;return n|0}function nL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a+16|0;a=b+8|0;f=c[a+4>>2]|0;YD(c[e>>2]|0,2265688,(g=i,i=i+16|0,c[g>>2]=c[a>>2],c[g+8>>2]=f,g)|0)|0;i=g;f=c[b+48>>2]|0;h=c[e>>2]|0;if((f|0)<0){dD(h,2217896,2)}else{j=wrc(c[a>>2]|0,c[a+4>>2]|0,f,(f|0)<0|0?-1:0)|0;f=G;YD(h,2265688,(g=i,i=i+16|0,c[g>>2]=j,c[g+8>>2]=f,g)|0)|0;i=g}dD(c[e>>2]|0,c[b+24>>2]|0,c[b+28>>2]|0);dD(c[e>>2]|0,2184264,1);i=d;return 0}function oL(a){a=a|0;dD(c[a+16>>2]|0,2265592,21);_X(c[c[a+28>>2]>>2]|0,64,1,1e3);return 0}function pL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+256|0;if((c[b+32>>2]|0)!=0){KIb(a,24,2392272,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}f=d|0;g=b+16|0;b=c[g+4>>2]|0;Rb(f|0,256,2319664,(e=i,i=i+16|0,c[e>>2]=c[g>>2],c[e+8>>2]=b,e)|0)|0;i=e;e=c[a+16>>2]|0;dD(e,f,lrc(f|0)|0);i=d;return 0}function qL(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;if((c[a+8>>2]|0)<30){b=0;return b|0}e=c[a+4>>2]|0;a=e;if(!((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==0)){b=0;return b|0}a=e+2|0;f=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;if(!((f|0)==24|(f|0)==22)){b=0;return b|0}a=e+8|0;g=(d[a]|d[a+1|0]<<8)<<16>>16;a=e+12|0;h=(d[a]|d[a+1|0]<<8)<<16>>16;a=e+14|0;i=(d[a]|d[a+1|0]<<8)<<16>>16;if(g<<16>>16==0|(g&65535)>>>0>60>>>0){b=0;return b|0}if(h<<16>>16==0|(h&65535)>>>0>2048>>>0){b=0;return b|0}if(i<<16>>16==0|(i&65535)>>>0>2048>>>0){b=0;return b|0}i=e+f|0;f=(d[i]|d[i+1|0]<<8)<<16>>16;b=f<<16>>16==0|(f&65535)>>>0>49>>>0?0:50;return b|0}function rL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;d=c[a+16>>2]|0;e=DD(d)|0;f=FD(d)|0;if((e|0)!=0){g=-1094995529;return g|0}DD(d)|0;e=DD(d)|0;DD(d)|0;h=DD(d)|0;i=DD(d)|0;hD(d,f-10|0,0)|0;d=ZX(a,0)|0;if((d|0)==0){g=-12;return g|0}j=c[d+8>>2]|0;c[j+8>>2]=0;c[j+48>>2]=81;c[j+52>>2]=0;c[j+120>>2]=h;c[j+124>>2]=i;_X(d,64,1,e);do{if((f|0)==24){e=ZX(a,0)|0;if((e|0)==0){g=-12;return g|0}else{d=c[e+8>>2]|0;c[d+8>>2]=1;c[d+52>>2]=0;c[d+48>>2]=65541;c[d+416>>2]=1;i=d+448|0;c[i>>2]=4;c[i+4>>2]=0;c[d+412>>2]=8e3;_X(e,64,1,8e3);break}}}while(0);c[b>>2]=0;c[b+4>>2]=0;g=0;return g|0}function sL(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+8|0;g=f|0;h=g|0;j=c[d+12>>2]|0;k=d+16|0;l=c[k>>2]|0;m=g;if((AD(l,m,6)|0)!=6){n=-5;i=f;return n|0}o=g+2|0;g=d;a:while(1){p=b[h>>1]|0;d=p&65535;q=b[o>>1]|0;r=q&65535;switch(d|0){case 21:{s=8;break a;break};case 49:case 5:case 8:case 12:case 13:case 14:case 15:{s=4;break a;break};default:{}}KIb(g,32,2392224,(t=i,i=i+8|0,c[t>>2]=d,t)|0);i=t;hD(l,q&65535,0)|0;if((AD(l,m,6)|0)!=6){n=-5;s=11;break}}if((s|0)==4){g=r+6|0;if((K1(e,g)|0)!=0){n=-12;i=f;return n|0}o=e+24|0;h=c[o>>2]|0;a[h]=a[m]|0;a[h+1|0]=a[m+1|0]|0;a[h+2|0]=a[m+2|0]|0;a[h+3|0]=a[m+3|0]|0;a[h+4|0]=a[m+4|0]|0;a[h+5|0]=a[m+5|0]|0;if((AD(l,(c[o>>2]|0)+6|0,r)|0)!=(r|0)){n=-5;i=f;return n|0}c[e+28>>2]=g;c[e+32>>2]=0;g=j+4|0;o=c[g>>2]|0;l=e+8|0;c[l>>2]=o;c[l+4>>2]=0;if(p<<16>>16==49){n=0;i=f;return n|0}c[g>>2]=o+1;n=0;i=f;return n|0}else if((s|0)==8){if((fX(c[k>>2]|0,e,r)|0)<0){n=-12;i=f;return n|0}c[e+32>>2]=1;r=j;j=c[r>>2]|0;c[r>>2]=j+1;r=e+8|0;c[r>>2]=j;c[r+4>>2]=0;n=0;i=f;return n|0}else if((s|0)==11){i=f;return n|0}return 0}function tL(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==77){if((a[d+1|0]|0)!=77){break}if((a[d+2|0]|0)!=77){break}if((a[d+3|0]|0)!=68){break}if((a[d+8|0]|0)!=67){break}if((a[d+9|0]|0)!=78){break}if((a[d+10|0]|0)!=84){break}if((a[d+11|0]|0)==73){e=100}else{break}return e|0}}while(0);e=0;return e|0}function uL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;if((FD(e)|0)!=1145916749){f=-1094995529;i=b;return f|0}hD(e,4,0)|0;while(1){g=FD(e)|0;h=JD(e)|0;if(!((g|0)==1230261827|(g|0)==1094996047)){break}hD(e,h,0)|0;}h=g&16777215;if((h|0)==5395521){zD(e)|0;zD(e)|0;j=zD(e)|0;k=j&15;if(k>>>0>4>>>0){KIb(a,16,2482976,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;f=-1094995529;i=b;return f|0}m=c[830624+(k<<2)>>2]|0;zD(e)|0;zD(e)|0;zD(e)|0;while(1){n=FD(e)|0;o=JD(e)|0;p=0;if(!((n|0)==1903391809|(n|0)==1232106305)){break}hD(e,o,p)|0;}if((n&16777215|0)!=6387521){KIb(a,16,2471744,(l=i,i=i+8|0,c[l>>2]=n,l)|0);i=l;f=-1094995529;i=b;return f|0}n=fD(e,0,0,1)|0;e=wrc(n,G,o,p)|0;p=d+24|0;c[p>>2]=e;c[p+4>>2]=G;p=ZX(a,0)|0;if((p|0)==0){f=-12;i=b;return f|0}e=c[p+8>>2]|0;c[e+8>>2]=1;c[e+48>>2]=69646;c[e+412>>2]=m;d=j>>7;c[e+416>>2]=d+1;j=(d|0)!=0;d=e+448|0;c[d>>2]=j?3:4;c[d+4>>2]=j?0:0;c[e+792>>2]=4;c[e+72>>2]=m<<2;_X(p,64,1,m);f=0;i=b;return f|0}else if((h|0)==5395533){KIb(a,16,2507296,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;f=-1163346256;i=b;return f|0}else{KIb(a,16,2492808,(l=i,i=i+8|0,c[l>>2]=g,l)|0);i=l;f=-1163346256;i=b;return f|0}return 0}function vL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=(c[a+12>>2]|0)+24|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=a+16|0;a=fD(c[d>>2]|0,0,0,1)|0;g=xrc(e,f,a,G)|0;a=G;f=0;e=(a|0)>(f|0)|(a|0)==(f|0)&g>>>0>4096>>>0;f=e?4096:g;g=e?0:a;a=0;if((jD(c[d>>2]|0)|0)!=0|((g|0)<(a|0)|(g|0)==(a|0)&f>>>0<1>>>0)){h=-541478725;return h|0}a=fX(c[d>>2]|0,b,f)|0;if((a|0)<0){h=a;return h|0}c[b+32>>2]=0;h=a;return h|0}function wL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=a+28|0;g=c[(c[c[f>>2]>>2]|0)+8>>2]|0;h=(c[g+88>>2]&8388608|0)!=0?2217848:2184216;j=c[g+412>>2]|0;k=0;while(1){if((k|0)>=5){break}if((c[830624+(k<<2)>>2]|0)==(j|0)){l=4;break}else{k=k+1|0}}do{if((l|0)==4){if((k|0)<0){break}m=(c[g+416>>2]|0)>1;n=d+32|0;c[n>>2]=m&1;do{if(m){if(!((c[g+680>>2]|0)>-2)){break}KIb(a,16,2130368,(o=i,i=i+8|0,c[o>>2]=-2,o)|0);i=o;p=-22;i=b;return p|0}}while(0);kD(e,1145916749);lD(e,0);m=SS(e,2625208)|0;q=G;bD(e,0);bD(e,1);bD(e,1);bD(e,0);bD(e,0);r=fD(e,0,0,1)|0;s=G;t=wrc(m,q,-4,-1)|0;fD(e,t,G,0)|0;t=xrc(r,s,m,q)|0;lD(e,t);fD(e,r,s,0)|0;s=SS(e,2599120)|0;r=G;dD(e,h,lrc(h|0)|0);t=fD(e,0,0,1)|0;q=G;m=wrc(s,r,-4,-1)|0;fD(e,m,G,0)|0;m=xrc(t,q,s,r)|0;lD(e,m);fD(e,t,q,0)|0;dD(e,2574648,4);lD(e,0);q=fD(e,0,0,1)|0;t=d;c[t>>2]=q;c[t+4>>2]=G;bD(e,0);bD(e,0);bD(e,k|c[n>>2]<<7|16);bD(e,0);bD(e,2);bD(e,2);kD(e,1903391809);lD(e,16);t=fD(e,0,0,1)|0;q=d+8|0;c[q>>2]=t;c[q+4>>2]=G;dD(e,10230616,16);q=SS(e,2521928)|0;t=d+16|0;c[t>>2]=q;c[t+4>>2]=G;t=c[c[f>>2]>>2]|0;_X(t,64,1,c[(c[t+8>>2]|0)+412>>2]|0);eD(e);p=0;i=b;return p|0}}while(0);KIb(a,16,2155360,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;p=-22;i=b;return p|0}function xL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+16>>2]|0;d=c[a+12>>2]|0;if((c[b+88>>2]|0)==0){return 0}e=d+16|0;f=c[e>>2]|0;g=c[e+4>>2]|0;h=fD(b,0,0,1)|0;i=G;j=wrc(f,g,-4,-1)|0;fD(b,j,G,0)|0;j=xrc(h,i,f,g)|0;lD(b,j);fD(b,h,i,0)|0;i=d;h=c[i>>2]|0;j=c[i+4>>2]|0;i=fD(b,0,0,1)|0;g=G;f=wrc(h,j,-4,-1)|0;fD(b,f,G,0)|0;f=xrc(i,g,h,j)|0;lD(b,f);fD(b,i,g,0)|0;g=fD(b,0,0,1)|0;i=G;fD(b,4,0,0)|0;f=wrc(g,i,-8,0)|0;lD(b,f);fD(b,g,i,0)|0;i=fD(b,0,0,1)|0;g=G;f=xrc(i,g,c[e>>2]|0,c[e+4>>2]|0)|0;e=G;j=d+8|0;fD(b,c[j>>2]|0,c[j+4>>2]|0,0)|0;bD(b,0);bD(b,c[d+32>>2]<<6|1);d=Erc(f,e,500,0)|0;e=c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+412>>2]|0;a=Crc(d,G,e,(e|0)<0|0?-1:0)|0;e=a;if((e|0)<128){bD(b,e);bD(b,e)}else{a=e-128|0;e=a>>7|128;bD(b,e);d=a&127;bD(b,d);bD(b,e);bD(b,d)}dD(b,2319584,2);dD(b,10230224,4);fD(b,i,g,0)|0;eD(b);return 0}function yL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e|0;d=c[a+24>>2]|0;if((d|0)==0){i=e;return 0}g=c[(c[a+28>>2]|0)+(d-1<<2)>>2]|0;JD(b)|0;HJ(a,b,f)|0;if((c[f>>2]|0)==3){IJ(b,0)}else{HD(b)|0}HJ(a,b,f)|0;if((c[f>>2]|0)!=4){i=e;return 0}JJ(a,g,b)|0;i=e;return 0}function zL(a,b){a=a|0;b=b|0;return KX(a,b&1,b&2,b<<29>>31)|0}function AL(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;g=i;i=i+32|0;j=g|0;l=g+16|0;m=a+4|0;n=c[m>>2]|0;o=c[n+24>>2]|0;if((o|0)==0){p=0;i=g;return p|0}q=c[(c[n+28>>2]|0)+(o-1<<2)>>2]|0;o=q+12|0;n=c[o>>2]|0;r=n;s=e+52|0;a:do{if((f|0)>0){t=l|0;u=l+8|0;v=q+8|0;w=n+136|0;x=n+152|0;y=n+1200|0;z=n+140|0;A=a+40|0;B=n+128|0;C=n+124|0;D=n+64|0;E=j|0;F=j+8|0;H=n+164|0;I=n+168|0;J=0;b:while(1){if((c[s>>2]|0)!=0){break a}c[t>>2]=1685288051;c[u>>2]=0;c[u+4>>2]=0;K=fD(e,0,0,1)|0;L=G;M=JD(e)|0;N=M;O=0;P=FD(e)|0;if(M>>>0>15>>>0){JD(e)|0;HD(e)|0;Q=HD(e)|0}else{if(M>>>0<8>>>0){R=8;break}else{Q=1}}M=c[(c[v>>2]|0)+52>>2]|0;S=fD(e,0,0,1)|0;T=G;U=wrc(N,O,K,L)|0;V=G;W=xrc(U,V,S,T)|0;T=JX(1407072,P)|0;do{if((M|0)==0|(M|0)==(P|0)){R=13}else{S=c[m>>2]|0;X=c[S+1112>>2]|0;if((X|0)==0){if((M|0)==1734701162){R=16;break}}else{if((T|0)==(X|0)){R=13;break}}KIb(S,24,2623736,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;S=W;hD(e,S,(S|0)<0|0?-1:0)|0;}}while(0);do{if((R|0)==13){R=0;if(!((M|0)==828601953|(M|0)==828601960|(M|0)==829842792)){R=16;break}KIb(c[m>>2]|0,24,2609768,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;R=16}}while(0);do{if((R|0)==16){R=0;c[w>>2]=(c[(c[v>>2]|0)+52>>2]|0)!=0?-1:J;c[x>>2]=Q;M=JX(1408424,P)|0;do{if((M|0)<1){W=P&65535;if((W|0)==29549|(W|0)==21332){Z=JX(1406408,(je(P|0)|0)&65535)|0;R=20;break}else{W=c[v>>2]|0;_=M;$=W;aa=c[W+8>>2]|0;R=22;break}}else{Z=M;R=20}}while(0);do{if((R|0)==20){R=0;M=c[v>>2]|0;W=M+8|0;T=c[W>>2]|0;if(!((T|0)!=0&(Z|0)>0)){_=Z;$=M;aa=T;R=22;break}c[W>>2]=1;ba=Z;da=M}}while(0);c:do{if((R|0)==22){R=0;if((aa|0)==1){ba=_;da=$;break}if((P|0)==1932816493|(P|0)==0){ba=_;da=$;break}M=JX(1407072,P)|0;do{if((M|0)<1){W=JX(1409152,P)|0;T=c[v>>2]|0;S=T+8|0;if((W|0)>0){ea=W;fa=S;ga=T;break}X=c[S>>2]|0;if((X|0)==3){if((c[T+48>>2]|0)!=0){ba=W;da=T;break c}}else if((X|0)!=2){ba=W;da=T;break c}T=JX(1408392,P)|0;W=c[v>>2]|0;if((T|0)<=0){ba=T;da=W;break c}c[W+8>>2]=3;ba=T;da=W;break c}else{W=c[v>>2]|0;ea=M;fa=W+8|0;ga=W}}while(0);c[fa>>2]=0;ba=ea;da=ga}}while(0);c[da+52>>2]=P;M=c[da+8>>2]|0;do{if((M|0)==3){c[da+48>>2]=ba;W=fD(e,0,0,1)|0;T=xrc(U,V,W,G)|0;c[E>>2]=0;W=T;c[F>>2]=W;c[F+4>>2]=(W|0)<0|0?-1:0;W=c[v>>2]|0;if((c[W+52>>2]|0)==1932816493){ha=W}else{YL(a,e,j)|0;ha=c[v>>2]|0}c[ha+120>>2]=c[H>>2];c[ha+124>>2]=c[I>>2]}else if((M|0)==1){c[da+48>>2]=ba;W=HD(e)|0;T=LGb(c[(c[m>>2]|0)+1140>>2]|0,2111904,0,1)|0;HD(e)|0;JD(e)|0;X=HD(e)|0;c[(c[v>>2]|0)+416>>2]=X;X=HD(e)|0;c[(c[v>>2]|0)+792>>2]=X;b[z>>1]=HD(e)|0;HD(e)|0;X=(JD(e)|0)>>>16;S=c[v>>2]|0;c[S+412>>2]=X;do{if((c[A>>2]|0)==0){R=58}else{if((T|0)==0){ia=S;break}if((Db(c[T+4>>2]|0,2125736)|0)==0){ia=S}else{R=58}}}while(0);do{if((R|0)==58){R=0;T=W&65535;if((T|0)==1){c[B>>2]=JD(e)|0;JD(e)|0;c[C>>2]=JD(e)|0;JD(e)|0;ia=c[v>>2]|0;break}else if((T|0)!=2){ia=S;break}JD(e)|0;T=OD(e)|0;X=G;c[(c[v>>2]|0)+412>>2]=~~(c[k>>2]=T,c[k+4>>2]=X,+h[k>>3]);X=JD(e)|0;c[(c[v>>2]|0)+416>>2]=X;JD(e)|0;X=JD(e)|0;c[(c[v>>2]|0)+792>>2]=X;X=JD(e)|0;c[C>>2]=JD(e)|0;c[B>>2]=JD(e)|0;T=c[v>>2]|0;if((c[T+52>>2]|0)!=1835233388){ia=T;break}ja=KX(c[T+792>>2]|0,X&1,X&2,X<<29>>31)|0;X=c[v>>2]|0;c[X+48>>2]=ja;ia=X}}while(0);S=ia+48|0;W=c[S>>2]|0;do{if((W|0)==69632){c[B>>2]=64;c[C>>2]=(c[ia+416>>2]|0)*34|0;ka=69632}else if((W|0)==65540|(W|0)==65541){if((c[ia+792>>2]|0)!=16){ka=W;break}c[S>>2]=65537;ka=65537}else if((W|0)==65536|(W|0)==65537){X=c[ia+792>>2]|0;if((X|0)==8){c[S>>2]=65540;ka=65540;break}else if((X|0)==24){X=(W|0)==65537?65549:65548;c[S>>2]=X;ka=X;break}else{ka=W;break}}else if((W|0)==86025){c[B>>2]=6;c[C>>2]=c[ia+416>>2]<<1;ka=86025}else if((W|0)==86026){c[B>>2]=6;c[C>>2]=c[ia+416>>2];ka=86026}else if((W|0)==86034){c[B>>2]=160;c[C>>2]=33;ka=86034}else{ka=W}}while(0);W=g5a(ka)|0;if((W|0)==0){break}S=c[v>>2]|0;c[S+792>>2]=W;c[D>>2]=ca(c[S+416>>2]|0,W>>3)|0}else if((M|0)==0){c[da+48>>2]=ba;HD(e)|0;HD(e)|0;JD(e)|0;JD(e)|0;JD(e)|0;W=HD(e)|0;c[(c[v>>2]|0)+120>>2]=W;W=HD(e)|0;c[(c[v>>2]|0)+124>>2]=W;JD(e)|0;JD(e)|0;JD(e)|0;HD(e)|0;W=zD(e)|0;S=W>>>0>31>>>0?31:W;ML(e,S,(c[v>>2]|0)+16|0,32);if(S>>>0<31>>>0){hD(e,31-S|0,0)|0;}S=c[v>>2]|0;W=S+16|0;X=S+52|0;do{if((grc(W,2626584,25)|0)==0){c[X>>2]=808596553;ja=S+120|0;c[ja>>2]=c[ja>>2]&-2;ja=S+124|0;c[ja>>2]=c[ja>>2]&-2}else{if((c[X>>2]|0)!=859189832){break}if((grc(W,2625040,13)|0)!=0){break}c[S+48>>2]=22}}while(0);S=HD(e)|0;c[(c[v>>2]|0)+792>>2]=S;S=HD(e)|0;W=c[v>>2]|0;X=W+792|0;ja=c[X>>2]|0;T=ja&31;la=(ja&32|0)!=0;if(la){if((c[W+48>>2]|0)==44){break}}if(!((T|0)==8|(T|0)==4|(T|0)==2)){break}d:do{if(la){c[X>>2]=T;W=1<<T;ja=256/((W-1|0)>>>0)|0;ma=0;na=255;while(1){oa=na&255;c[r+176+(ma<<2)>>2]=oa|oa<<8|oa<<16|-16777216;oa=na-ja|0;pa=ma+1|0;if(pa>>>0<W>>>0){ma=pa;na=(oa|0)<0?0:oa}else{break}}}else{if((S|0)==0){na=JD(e)|0;HD(e)|0;ma=HD(e)|0;if((ma|na)>>>0>255>>>0|na>>>0>ma>>>0){break}else{qa=na}while(1){na=zD(e)|0;zD(e)|0;W=zD(e)|0;zD(e)|0;ja=zD(e)|0;zD(e)|0;oa=zD(e)|0;zD(e)|0;c[r+176+(qa<<2)>>2]=W<<16&16711680|na<<24|ja<<8&65280|oa&255;qa=qa+1|0;if(qa>>>0>ma>>>0){break d}}}ma=1<<T;if((T|0)==4){ra=1321240}else if((T|0)==2){ra=1320456}else{ra=1320472}oa=0;do{ja=oa*3|0;c[r+176+(oa<<2)>>2]=(d[ra+ja|0]|0)<<16|(d[ra+(ja+1)|0]|0)<<8|(d[ra+(ja+2)|0]|0)|-16777216;oa=oa+1|0;}while(oa>>>0<ma>>>0)}}while(0);c[y>>2]=1}else{T=fD(e,0,0,1)|0;S=xrc(U,V,T,G)|0;T=S;S=c[v>>2]|0;if((c[S+52>>2]|0)!=1684237684){hD(e,T,(T|0)<0|0?-1:0)|0;break}if((QX(S,e,T)|0)<0){p=-12;R=109;break b}if((T|0)<=16){break}T=c[o>>2]|0;S=c[v>>2]|0;X=c[S+96>>2]|0;la=X+4|0;ma=je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0;c[T+1216>>2]=ma;if((ma&1|0)!=0){ma=S+92|0;c[ma>>2]=c[ma>>2]|8192}c[S+108>>2]=d[X+16|0]|0;c[S+104>>2]=1}}while(0);M=fD(e,0,0,1)|0;S=xrc(K,L,M,G)|0;M=wrc(S,G,N,O)|0;S=G;c[u>>2]=M;c[u+4>>2]=S;X=0;if((S|0)>(X|0)|(S|0)==(X|0)&M>>>0>8>>>0){X=BL(a,e,l)|0;if((X|0)<0){p=X;R=109;break b}else{break}}X=0;if(!((S|0)>(X|0)|(S|0)==(X|0)&M>>>0>0>>>0)){break}hD(e,M,S)|0;}}while(0);J=J+1|0;if((J|0)>=(f|0)){break a}}if((R|0)==8){KIb(c[m>>2]|0,16,2493896,(Y=i,i=i+16|0,c[Y>>2]=N,c[Y+8>>2]=O,Y)|0);i=Y;p=-1094995529;i=g;return p|0}else if((R|0)==109){i=g;return p|0}}}while(0);if((c[s>>2]|0)!=0){p=-541478725;i=g;return p|0}s=q+8|0;R=c[s>>2]|0;O=R+8|0;do{if((c[O>>2]|0)==1){N=R+412|0;if((c[N>>2]|0)!=0){break}f=c[n+92>>2]|0;if((f|0)<=1){break}c[N>>2]=f}}while(0);f=c[R+48>>2]|0;if((f|0)==86022){N=HR()|0;c[a+36>>2]=N;e=KF(N)|0;c[a+32>>2]=e;if((e|0)==0){KIb(c[m>>2]|0,16,2629672,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;p=-12;i=g;return p|0}else{c[n+132>>2]=1;c[(c[s>>2]|0)+48>>2]=65536;p=0;i=g;return p|0}}else if((f|0)==86040){c[R+416>>2]=1;if((c[R+52>>2]|0)!=1886151505){c[R+412>>2]=8e3}c[n+128>>2]=160;s=n+124|0;if((c[s>>2]|0)!=0){p=0;i=g;return p|0}c[s>>2]=35;p=0;i=g;return p|0}else if((f|0)==73728){c[R+416>>2]=1;c[R+412>>2]=8e3;p=0;i=g;return p|0}else if((f|0)==73729){c[R+416>>2]=1;c[R+412>>2]=16e3;p=0;i=g;return p|0}else if((f|0)==86016|(f|0)==86017){c[O>>2]=1;c[q+236>>2]=1;p=0;i=g;return p|0}else if((f|0)==86034|(f|0)==69638|(f|0)==69633|(f|0)==86076|(f|0)==86025|(f|0)==86026|(f|0)==86035){c[R+432>>2]=c[n+124>>2];p=0;i=g;return p|0}else if((f|0)==86032){if((c[R+100>>2]|0)!=36){p=0;i=g;return p|0}n=c[R+96>>2]|0;c[R+416>>2]=d[n+21|0]|0;O=n+32|0;c[R+412>>2]=je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;p=0;i=g;return p|0}else if((f|0)==86019|(f|0)==1|(f|0)==71){c[q+236>>2]=1;p=0;i=g;return p|0}else{p=0;i=g;return p|0}return 0}function BL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+16|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e|0;g=d+8|0;h=c[g>>2]|0;j=c[g+4>>2]|0;k=0;if((j|0)<(k|0)|(j|0)==(k|0)&h>>>0<0>>>0){c[g>>2]=-1;c[g+4>>2]=2147483647;l=2147483647;m=-1;n=4}else{g=0;if((j|0)<(g|0)|(j|0)==(g|0)&h>>>0<8>>>0){o=0;p=0;q=j;r=h}else{l=j;m=h;n=4}}a:do{if((n|0)==4){h=f+8|0;j=f|0;g=0;k=(l|0)>(g|0)|(l|0)==(g|0)&m>>>0>7>>>0;g=c[d>>2]|0;s=a+24|0;t=a+4|0;u=a+28|0;v=b+88|0;w=0;x=0;y=0;z=8;b:while(1){if((jD(b)|0)!=0){o=w;p=x;q=l;r=m;break a}c[h>>2]=m;c[h+4>>2]=l;c[j>>2]=0;do{if(k){c[h>>2]=JD(b)|0;c[h+4>>2]=0;A=FD(b)|0;c[j>>2]=A;if(!((g|0)==1953460082|(g|0)==1987014509)){if((A|0)==1801548404|(A|0)==1952539757){n=9;break b}}A=c[h>>2]|0;B=c[h+4>>2]|0;if(!((A|0)==1&(B|0)==0)){C=y;D=z;E=B;F=A;break}A=OD(b)|0;B=wrc(A,G,-8,-1)|0;A=G;c[h>>2]=B;c[h+4>>2]=A;H=wrc(x,w,16,0)|0;C=G;D=H;E=A;F=B}else{C=w;D=x;E=l;F=m}}while(0);if((F|0)==0&(E|0)==0){B=xrc(8,0,D,C)|0;A=wrc(B,G,m,l)|0;B=G;c[h>>2]=A;c[h+4>>2]=B;I=B;J=A}else{I=E;J=F}A=wrc(J,I,-8,-1)|0;B=G;c[h>>2]=A;c[h+4>>2]=B;H=0;if((B|0)<(H|0)|(B|0)==(H|0)&A>>>0<0>>>0){o=C;p=D;q=l;r=m;break a}H=xrc(m,l,D,C)|0;K=G;L=(B|0)>(K|0)|(B|0)==(K|0)&A>>>0>H>>>0;M=L?H:A;A=L?K:B;c[h>>2]=M;c[h+4>>2]=A;B=c[j>>2]|0;K=0;while(1){if((K|0)==65){n=19;break}if((c[823408+(K<<3)>>2]|0)==(B|0)){n=18;break}else{K=K+1|0}}do{if((n|0)==18){n=0;N=c[823412+(K<<3)>>2]|0;n=21}else if((n|0)==19){n=0;if((g|0)==1635017845|(g|0)==1953721449){N=396;n=21;break}hD(b,M,A)|0;}}while(0);do{if((n|0)==21){n=0;O=fD(b,0,0,1)|0;P=G;A=Ee[N&511](a,b,f)|0;if((A|0)<0){Q=A;n=37;break b}do{if((c[s>>2]|0)!=0){if((c[u>>2]|0)==0){break}if((c[v>>2]|0)==0){break b}if((c[(c[t>>2]|0)+1084>>2]&2|0)!=0){n=28;break b}A=wrc(c[h>>2]|0,c[h+4>>2]|0,O,P)|0;M=G;K=iD(b)|0;if((A|0)==(K|0)&(M|0)==(G|0)){n=27;break b}}}while(0);M=c[h>>2]|0;K=c[h+4>>2]|0;A=fD(b,0,0,1)|0;B=xrc(M,K,A,G)|0;A=wrc(B,G,O,P)|0;B=G;K=0;if((B|0)>(K|0)|(B|0)==(K|0)&A>>>0>0>>>0){hD(b,A,B)|0;break}K=0;if(!((B|0)<(K|0)|(B|0)==(K|0)&A>>>0<0>>>0)){break}K=c[t>>2]|0;M=xrc(0,0,A,B)|0;L=G;KIb(K,24,2463712,(R=i,i=i+24|0,c[R>>2]=f,c[R+8>>2]=M,c[R+16>>2]=L,R)|0);i=R;fD(b,A,B,1)|0;}}while(0);B=wrc(c[h>>2]|0,c[h+4>>2]|0,D,C)|0;A=G;L=wrc(B,A,8,0)|0;M=G;if((M|0)>(l|0)|(M|0)==(l|0)&L>>>0>m>>>0){o=A;p=B;q=l;r=m;break a}else{w=A;x=B;y=M;z=L}}if((n|0)==9){KIb(c[t>>2]|0,16,2471696,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;hD(b,-8,-1)|0;Q=0;i=e;return Q|0}else if((n|0)==27){if((c[v>>2]|0)!=0){n=28}}else if((n|0)==37){i=e;return Q|0}do{if((n|0)==28){if((c[(c[t>>2]|0)+1084>>2]&2|0)==0){Q=0}else{break}i=e;return Q|0}}while(0);t=wrc(c[h>>2]|0,c[h+4>>2]|0,O,P)|0;v=a+112|0;c[v>>2]=t;c[v+4>>2]=G;Q=0;i=e;return Q|0}}while(0);a=0;if(!(((o|0)<(q|0)|(o|0)==(q|0)&p>>>0<r>>>0)&((q|0)<(a|0)|(q|0)==(a|0)&r>>>0<524287>>>0))){Q=0;i=e;return Q|0}a=xrc(r,q,p,o)|0;hD(b,a,G)|0;Q=0;i=e;return Q|0}function CL(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;e=c[a+8>>2]|0;if(e>>>0<8>>>0){f=0;i=b;return f|0}g=c[a+4>>2]|0;h=0;j=0;k=0;l=-1;a:while(1){m=h;n=j;o=k;b:while(1){p=m;q=n;while(1){r=q;s=g+(r+4)|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;if((t|0)==1987014509){u=6;break b}else if((t|0)==2003395685|(t|0)==1701079415|(t|0)==1701147238|(t|0)==1802401130|(t|0)==1952672112){u=13;break}else if((t|0)==2105508482|(t|0)==1885956979|(t|0)==1684632949|(t|0)==1818653296){u=14;break}else if((t|0)==538988650|(t|0)==1952539757|(t|0)==1953459824|(t|0)==1635017845|(t|0)==1887007846){v=l;break b}t=g+r|0;s=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=s>>>0<4>>>0;w=wrc(t?4:s,t?0:0,q,p)|0;t=G;s=wrc(w,t,8,0)|0;x=G;y=0;if((x|0)>(y|0)|(x|0)==(y|0)&s>>>0>e>>>0){z=o;A=l;break a}else{p=t;q=w}}if((u|0)==13){u=0;w=g+r|0;t=je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;w=t>>>0<4>>>0;B=(o|0)>95?o:95;C=w?0:0;D=w?4:t}else if((u|0)==14){u=0;t=g+r|0;w=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=w>>>0<4>>>0;B=(o|0)>50?o:50;C=t?0:0;D=t?4:w}w=wrc(D,C,q,p)|0;t=G;s=wrc(w,t,8,0)|0;y=G;x=0;if((y|0)>(x|0)|(y|0)==(x|0)&s>>>0>e>>>0){z=B;A=l;break a}else{m=t;n=w;o=B}}if((u|0)==6){u=0;n=wrc(q,p,4,0)|0;v=n}n=g+r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=je(m|0)|0;c:do{if(n>>>0<8>>>0){do{if((m|0)==16777216){w=wrc(q,p,12,0)|0;t=G;s=0;if((t|0)>(s|0)|(t|0)==(s|0)&w>>>0>e>>>0){break}w=g+(r+8)|0;s=w|0;t=w+4|0;w=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;if(!((je(w|0)|0)==0&(t|0)==0)){E=100;break c}}}while(0);E=(o|0)>50?o:50}else{E=100}}while(0);o=n>>>0<4>>>0;m=wrc(o?4:n,o?0:0,q,p)|0;o=G;t=wrc(m,o,8,0)|0;w=G;s=0;if((w|0)>(s|0)|(w|0)==(s|0)&t>>>0>e>>>0){z=E;A=v;break}else{h=o;j=m;k=E;l=v}}if((z|0)<51|(A|0)==-1){f=z;i=b;return f|0}v=e-16|0;if((A|0)>=(v|0)){f=z;i=b;return f|0}e=c[a+4>>2]|0;a=(A|0)<0|0?-1:0;l=A;d:while(1){A=l;E=e+A|0;do{if((d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)==1919706216){k=e+(A+8)|0;if((d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)!=1919707245){break}k=e+(A+12)|0;if((d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)==1195724877){break d}}}while(0);A=wrc(l,a,2,0)|0;E=G;n=(v|0)<0|0?-1:0;if((E|0)<(n|0)|(E|0)==(n|0)&A>>>0<v>>>0){a=E;l=A}else{f=z;u=25;break}}if((u|0)==25){i=b;return f|0}KIb(0,24,2538416,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;f=5;i=b;return f|0}function DL(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;d=i;i=i+72|0;e=d|0;f=d+24|0;g=d+40|0;h=d+48|0;j=d+56|0;k=b+12|0;l=c[k>>2]|0;m=b+16|0;n=c[m>>2]|0;c[j>>2]=1953460082;o=j+8|0;c[o>>2]=0;c[o+4>>2]=0;p=l+4|0;c[p>>2]=b;q=n+88|0;if((c[q>>2]|0)==0){r=2147483647;s=-1}else{t=iD(n)|0;r=G;s=t}c[o>>2]=s;c[o+4>>2]=r;r=BL(l,n,j)|0;if((r|0)<0){KIb(b,16,2155328,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;FL(b)|0;v=r;i=d;return v|0}if((c[l+24>>2]|0)==0){KIb(b,16,2130344,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;FL(b)|0;v=-1094995529;i=d;return v|0}do{if((c[q>>2]|0)==0){w=c[b+24>>2]|0;x=38}else{a:do{if((c[l+100>>2]|0)>0){r=h;j=b+24|0;n=c[j>>2]|0;o=b+28|0;s=(c[k>>2]|0)+100|0;t=0;while(1){if(!(t>>>0<n>>>0)){break}z=c[(c[o>>2]|0)+(t<<2)>>2]|0;if((c[z+4>>2]|0)==(c[s>>2]|0)){x=14;break}else{t=t+1|0}}do{if((x|0)==14){if((z|0)==0){break}c[z+76>>2]=48;t=c[z+12>>2]|0;s=fD(c[t>>2]|0,0,0,1)|0;o=G;n=z+404|0;A=c[n>>2]|0;b:do{if((A|0)>0){B=z+400|0;C=z+40|0;D=z+56|0;E=0;F=A;while(1){H=c[B>>2]|0;I=E+1|0;if((I|0)<(F|0)){J=H+(I*24|0)+8|0}else{J=D}K=c[J>>2]|0;L=c[J+4>>2]|0;M=H+(E*24|0)|0;N=fD(c[t>>2]|0,c[M>>2]|0,c[M+4>>2]|0,0)|0;if(!((N|0)==(c[M>>2]|0)&(G|0)==(c[M+4>>2]|0))){break}M=HD(c[t>>2]|0)|0;if((M|0)<=((c[H+(E*24|0)+16>>2]>>2)-2|0)){N=M<<1|1;O=pJb(N)|0;c[h>>2]=O;if((O|0)==0){break b}do{if((M|0)==0){a[O]=0}else{P=HD(c[t>>2]|0)|0;Q=P&65535;if((Q|0)==65279){ND(c[t>>2]|0,M,c[h>>2]|0,N)|0;break}else if((Q|0)==65534){MD(c[t>>2]|0,M,c[h>>2]|0,N)|0;break}else{Q=he(P&65535|0)|0;P=c[h>>2]|0;y=Q;a[P]=y;y=y>>8;a[P+1|0]=y;P=M-1|0;if(P>>>0<2>>>0){a[(c[h>>2]|0)+M|0]=0;break}else{LD(c[t>>2]|0,2147483647,(c[h>>2]|0)+2|0,P)|0;break}}}}while(0);M=H+(E*24|0)+8|0;aY(b,E,C,c[M>>2]|0,c[M+4>>2]|0,K,L,c[h>>2]|0)|0;mJb(r)}M=c[n>>2]|0;if((I|0)<(M|0)){E=I;F=M}else{break b}}KIb(b,16,2555792,(u=i,i=i+8|0,c[u>>2]=E,u)|0);i=u}}while(0);fD(c[t>>2]|0,s,o,0)|0;R=j;break a}}while(0);KIb(b,16,2574608,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;R=j}else{R=b+24|0}}while(0);if((c[R>>2]|0)==0){S=0;T=b+24|0;break}r=b+28|0;n=f|0;A=g|0;F=g+4|0;C=b;D=0;while(1){B=c[(c[r>>2]|0)+(D<<2)>>2]|0;M=B+8|0;do{if((c[(c[M>>2]|0)+52>>2]|0)==1684237684){N=c[B+12>>2]|0;O=N;P=fD(c[O>>2]|0,0,0,1)|0;Q=G;if((c[B+404>>2]|0)==0){break}U=c[B+400>>2]|0;fD(c[O>>2]|0,c[U>>2]|0,c[U+4>>2]|0,0)|0;U=JD(c[m>>2]|0)|0;V=c[N+1216>>2]|0;N=V&1;W=(V&2|0)==0?N:N|2;N=c[M>>2]|0;c[A>>2]=c[N+108>>2];c[F>>2]=c[N+104>>2];if((rLb(e,g,(V&4|0)==0?W:W|4,0,C)|0)>=0){MGb(B+88|0,2625192,nLb(e,n,U)|0,0)|0}fD(c[O>>2]|0,P,Q,0)|0;}}while(0);B=D+1|0;M=c[R>>2]|0;if(B>>>0<M>>>0){D=B}else{w=M;x=38;break}}}}while(0);do{if((x|0)==38){R=b+24|0;if((w|0)==0){S=0;T=R;break}e=b+28|0;g=0;m=w;do{f=c[e>>2]|0;h=c[f+(g<<2)>>2]|0;J=c[(c[h+12>>2]|0)+156>>2]|0;do{if(!((J|0)<1|(m|0)==0)){z=-1;k=0;do{z=(c[(c[f+(k<<2)>>2]|0)+4>>2]|0)==(J|0)?k:z;k=k+1|0;}while(k>>>0<m>>>0);if((z|0)<0|(z|0)==(g|0)){break}k=LGb(c[(c[f+(z<<2)>>2]|0)+88>>2]|0,2625192,0,0)|0;if((k|0)==0){break}MGb(h+88|0,2625192,c[k+4>>2]|0,0)|0}}while(0);g=g+1|0;m=c[R>>2]|0;}while(g>>>0<m>>>0);c:do{if((m|0)==0){X=0}else{g=b+28|0;e=0;h=m;f=m;d:while(1){J=c[g>>2]|0;k=c[J+(e<<2)>>2]|0;o=e+1|0;e:do{if((c[(c[k+8>>2]|0)+52>>2]|0)==1684237684){if((h|0)!=0){s=0;do{t=c[J+(s<<2)>>2]|0;if((c[(c[t+8>>2]|0)+8>>2]|0)==0){if((c[(c[t+12>>2]|0)+156>>2]|0)==(o|0)){Y=h;Z=f;break e}}s=s+1|0;}while(s>>>0<h>>>0)}_=LGb(c[k+88>>2]|0,2625192,0,0)|0;if((_|0)!=0){break d}s=c[R>>2]|0;Y=s;Z=s}else{Y=h;Z=f}}while(0);if(o>>>0<Y>>>0){e=o;h=Y;f=Z}else{X=Z;break c}}MGb(b+1140|0,2625192,c[_+4>>2]|0,0)|0;X=c[R>>2]|0}}while(0);if((X|0)==0){S=0;T=R;break}m=b+28|0;f=l+8|0;h=0;while(1){e=c[(c[m>>2]|0)+(h<<2)>>2]|0;g=c[e+12>>2]|0;k=g+92|0;do{if((c[k>>2]|0)<1){KIb(c[p>>2]|0,24,2599048,(u=i,i=i+8|0,c[u>>2]=c[g+8>>2],u)|0);i=u;J=c[f>>2]|0;c[k>>2]=J;if((J|0)>=1){break}c[k>>2]=1}}while(0);J=c[e+8>>2]|0;z=c[J+8>>2]|0;do{if((z|0)==0){x=71}else if((z|0)==1){if((c[J+48>>2]|0)!=86018){break}c[e+448>>2]=c[g+1232>>2];if((z|0)==0){x=71}}}while(0);do{if((x|0)==71){x=0;z=c[g+1244>>2]|0;if((z|0)<=0){break}J=g+1248|0;s=c[J>>2]|0;E=c[J+4>>2]|0;J=0;if(!((E|0)>(J|0)|(E|0)==(J|0)&s>>>0>0>>>0)){break}J=c[k>>2]|0;t=Erc(J,(J|0)<0|0?-1:0,z,(z|0)<0|0?-1:0)|0;xKb(e+92|0,e+96|0,t,G,s,E,2147483647,0)|0}}while(0);e=h+1|0;k=c[R>>2]|0;if(e>>>0<k>>>0){h=e}else{S=k;T=R;break}}}}while(0);if(!((c[l+88>>2]|0)==0|(S|0)==0)){x=c[b+28>>2]|0;u=0;p=S;while(1){S=c[x+(u<<2)>>2]|0;X=c[S+12>>2]|0;_=S+56|0;Z=c[_>>2]|0;Y=c[_+4>>2]|0;_=0;if((Y|0)>(_|0)|(Y|0)==(_|0)&Z>>>0>0>>>0){_=X+1208|0;w=c[_>>2]|0;R=c[X+92>>2]|0;X=Erc(w<<3|0>>>29,c[_+4>>2]<<3|w>>>29,R,(R|0)<0|0?-1:0)|0;R=Crc(X,G,Z,Y)|0;c[(c[S+8>>2]|0)+72>>2]=R;$=c[T>>2]|0}else{$=p}R=u+1|0;if(R>>>0<$>>>0){u=R;p=$}else{break}}}$=l+124|0;p=c[$>>2]|0;f:do{if((p|0)>0){u=l+120|0;x=b+28|0;R=0;S=p;while(1){if(!(R>>>0<(c[T>>2]|0)>>>0)){break f}Y=c[(c[u>>2]|0)+(R<<2)>>2]|0;if((Y|0)==0){aa=S}else{c[(c[(c[(c[x>>2]|0)+(R<<2)>>2]|0)+8>>2]|0)+72>>2]=Y;aa=c[$>>2]|0}Y=R+1|0;if((Y|0)<(aa|0)){R=Y;S=aa}else{break}}}}while(0);SX(b);v=0;i=d;return v|0}function EL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;d=i;i=i+16|0;e=d|0;f=c[a+12>>2]|0;g=f;h=f+4|0;c[h>>2]=a;j=a+24|0;k=f+28|0;l=f+112|0;m=a+16|0;n=e|0;o=e+8|0;p=a+28|0;a=b+32|0;q=b+16|0;r=b+48|0;s=b+8|0;t=f+32|0;f=b+24|0;u=b+28|0;v=b+64|0;w=0;a:while(1){x=c[j>>2]|0;do{if((x|0)==0){y=w}else{z=c[p>>2]|0;A=0;B=2147483647;C=-1;D=0;E=w;while(1){F=c[z+(A<<2)>>2]|0;H=c[F+12>>2]|0;I=c[H>>2]|0;b:do{if((I|0)==0){J=D;K=B;L=C;M=E}else{N=c[H+120>>2]|0;if((N|0)>=(c[F+404>>2]|0)){J=D;K=B;L=C;M=E;break}O=c[F+400>>2]|0;P=O+(N*24|0)|0;Q=O+(N*24|0)+8|0;N=c[H+92>>2]|0;O=VIb(c[Q>>2]|0,c[Q+4>>2]|0,1e6,0,N,(N|0)<0|0?-1:0)|0;N=G;do{if((D|0)!=0){Q=c[m>>2]|0;if((c[Q+88>>2]|0)==0){R=P|0;S=c[R+4>>2]|0;T=D|0;U=c[T+4>>2]|0;if((S|0)<(U|0)|(S|0)==(U|0)&(c[R>>2]|0)>>>0<(c[T>>2]|0)>>>0){break}else{J=D;K=B;L=C;M=E;break b}}T=(N|0)<(B|0)|(N|0)==(B|0)&O>>>0<C>>>0;if((I|0)!=(Q|0)&T){break}if((I|0)!=(Q|0)){J=D;K=B;L=C;M=E;break b}Q=xrc(C,B,O,N)|0;R=G;U=-1;S=(R|0)>(U|0)|(R|0)==(U|0)&Q>>>0>-1>>>0;U=xrc(0,0,Q,R)|0;V=S?R:G;R=0;if((V|0)<(R|0)|(V|0)==(R|0)&(S?Q:U)>>>0<1000001>>>0){U=P|0;Q=c[U+4>>2]|0;S=D|0;R=c[S+4>>2]|0;if((Q|0)<(R|0)|(Q|0)==(R|0)&(c[U>>2]|0)>>>0<(c[S>>2]|0)>>>0){break}else{J=D;K=B;L=C;M=E;break b}}else{if(T){break}else{J=D;K=B;L=C;M=E;break b}}}}while(0);J=P;K=N;L=O;M=F}}while(0);F=A+1|0;if(F>>>0<x>>>0){A=F;B=K;C=L;D=J;E=M}else{break}}if((J|0)==0){y=M;break}W=c[M+12>>2]|0;E=W+120|0;c[E>>2]=(c[E>>2]|0)+1;D=c[l>>2]|0;C=c[l+4>>2]|0;if(!((D|0)==0&(C|0)==0)){B=J|0;A=c[B>>2]|0;z=c[B+4>>2]|0;F=(z|0)>(C|0)|(z|0)==(C|0)&A>>>0>D>>>0;I=F?D:A;A=F?C:z;c[B>>2]=I;c[B+4>>2]=A;B=J+16|0;z=c[B>>2]|0;C=z>>2;F=(C|0)<0|0?-1:0;D=xrc(c[l>>2]|0,c[l+4>>2]|0,I,A)|0;A=G;c[B>>2]=((F|0)>(A|0)|(F|0)==(A|0)&C>>>0>D>>>0?D:C)<<2|z&3}z=M+76|0;do{if((c[z>>2]|0)!=48){C=W;D=J|0;A=fD(c[C>>2]|0,c[D>>2]|0,c[D+4>>2]|0,0)|0;X=c[D>>2]|0;Y=c[D+4>>2]|0;if(!((A|0)==(X|0)&(G|0)==(Y|0))){Z=24;break a}A=fX(c[C>>2]|0,b,c[J+16>>2]>>2)|0;if((A|0)<0){_=A;Z=45;break a}A=W+1200|0;do{if((c[A>>2]|0)!=0){C=U1(b,0,1024)|0;if((C|0)==0){KIb(c[h>>2]|0,16,2184176,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;break}else{nrc(C|0,W+176|0,1024)|0;c[A>>2]=0;break}}}while(0);A=c[t>>2]|0;if((A|0)==0){break}if((c[W+132>>2]|0)==0){break}MF(A,b,c[f>>2]|0,c[u>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;kJb(c[f>>2]|0);c[u>>2]=0;A=LF(c[t>>2]|0,b)|0;if((A|0)<0){_=A;Z=45;break a}}}while(0);c[a>>2]=c[W+8>>2];A=J+8|0;C=c[A>>2]|0;D=c[A+4>>2]|0;c[q>>2]=C;c[q+4>>2]=D;A=c[W+36>>2]|0;do{if((A|0)==0){Z=39}else{F=W+56|0;B=c[F>>2]|0;if(!(B>>>0<(c[W+32>>2]|0)>>>0)){Z=39;break}I=c[W+172>>2]|0;H=wrc(I,(I|0)<0|0?-1:0,C,D)|0;I=c[A+(B<<3)+4>>2]|0;T=wrc(H,G,I,(I|0)<0|0?-1:0)|0;c[s>>2]=T;c[s+4>>2]=G;T=W+60|0;I=(c[T>>2]|0)+1|0;c[T>>2]=I;if((c[A+(B<<3)>>2]|0)==(I|0)){c[F>>2]=B+1;c[T>>2]=0}if((c[W+160>>2]|0)==0){break}c[q>>2]=0;c[q+4>>2]=-2147483648}}while(0);if((Z|0)==39){Z=0;A=c[E>>2]|0;if((A|0)<(c[M+404>>2]|0)){aa=(c[M+400>>2]|0)+(A*24|0)+8|0}else{aa=M+56|0}A=xrc(c[aa>>2]|0,c[aa+4>>2]|0,C,D)|0;c[r>>2]=A;c[s>>2]=C;c[s+4>>2]=D}if((c[z>>2]|0)==48){w=M;continue a}else{Z=44;break a}}}while(0);c[k>>2]=0;x=c[l>>2]|0;A=c[l+4>>2]|0;if((x|0)==0&(A|0)==0){_=-541478725;Z=45;break}fD(c[m>>2]|0,x,A,0)|0;c[l>>2]=0;c[l+4>>2]=0;A=c[m>>2]|0;c[n>>2]=1953460082;c[o>>2]=-1;c[o+4>>2]=2147483647;if((BL(g,A,e)|0)<0){_=-541478725;Z=45;break}if((jD(c[m>>2]|0)|0)==0){w=y}else{_=-541478725;Z=45;break}}if((Z|0)==24){KIb(c[h>>2]|0,16,2217808,($=i,i=i+24|0,c[$>>2]=c[W+8>>2],c[$+8>>2]=X,c[$+16>>2]=Y,$)|0);i=$;_=-1094995529;i=d;return _|0}else if((Z|0)==44){$=b+36|0;c[$>>2]=c[$>>2]|c[J+16>>2]&1;$=J|0;J=c[$+4>>2]|0;c[v>>2]=c[$>>2];c[v+4>>2]=J;_=0;i=d;return _|0}else if((Z|0)==45){i=d;return _|0}return 0}function FL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+12>>2]|0;d=a+24|0;if((c[d>>2]|0)!=0){e=a+28|0;a=0;do{f=c[(c[(c[e>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;mJb(f+36|0);g=f+144|0;h=f+148|0;if((c[g>>2]|0)!=0){i=h;j=0;do{mJb((c[i>>2]|0)+(j*108|0)+4|0);mJb((c[i>>2]|0)+(j*108|0)+8|0);j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}mJb(h);g=f;if((c[f+4>>2]|0)==0){WD(c[g>>2]|0)|0}c[g>>2]=0;mJb(f+20|0);mJb(f+44|0);mJb(f+76|0);mJb(f+88|0);mJb(f+28|0);mJb(f+52|0);mJb(f+1240|0);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0)}d=b+32|0;if((c[d>>2]|0)==0){k=b+88|0;mJb(k);l=b+120|0;mJb(l);return 0}a=b+36|0;e=a;g=c[e>>2]|0;if((c[g+24>>2]|0)!=0){j=0;i=g;do{mJb((c[(c[i+28>>2]|0)+(j<<2)>>2]|0)+8|0);mJb((c[(c[e>>2]|0)+28>>2]|0)+(j<<2)|0);j=j+1|0;i=c[e>>2]|0;}while(j>>>0<(c[i+24>>2]|0)>>>0)}mJb(a);mJb(d);k=b+88|0;mJb(k);l=b+120|0;mJb(l);return 0}function GL(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=a+24|0;if(!((c[g>>2]|0)>>>0>b>>>0)){h=-1094995529;return h|0}i=a+28|0;a=c[(c[i>>2]|0)+(b<<2)>>2]|0;j=c[a+12>>2]|0;k=CX(a,d,e,f)|0;do{if((k|0)<0){if((c[a+404>>2]|0)==0){h=-1094995529;return h|0}l=(c[a+400>>2]|0)+8|0;m=c[l+4>>2]|0;n=(m|0)>(e|0)|(m|0)==(e|0)&(c[l>>2]|0)>>>0>d>>>0?0:k;if((n|0)<0){h=-1094995529}else{o=n;break}return h|0}else{o=k}}while(0);c[j+120>>2]=o;k=c[j+36>>2]|0;do{if((k|0)!=0){n=c[j+32>>2]|0;l=0;m=0;while(1){if(!(l>>>0<n>>>0)){break}p=(c[k+(l<<3)>>2]|0)+m|0;if((p|0)>(o|0)){q=9;break}else{l=l+1|0;m=p}}if((q|0)==9){c[j+56>>2]=l;c[j+60>>2]=o-m}if((o|0)<0){h=o}else{break}return h|0}}while(0);j=(c[a+400>>2]|0)+(o*24|0)+8|0;o=c[j>>2]|0;a=c[j+4>>2]|0;if((c[g>>2]|0)==0){h=0;return h|0}j=0;if((e|0)<(j|0)|(e|0)==(j|0)&d>>>0<1>>>0){d=0;while(1){j=c[i>>2]|0;e=c[j+(d<<2)>>2]|0;c[e+448>>2]=c[(c[e+12>>2]|0)+1232>>2];a:do{if((d|0)!=(b|0)){q=XIb(o,a,(c[j+(b<<2)>>2]|0)+40|0,e+40|0)|0;k=G;n=c[e+12>>2]|0;p=CX(e,q,k,f)|0;if((p|0)<0){if((c[e+404>>2]|0)==0){break}r=(c[e+400>>2]|0)+8|0;s=c[r+4>>2]|0;t=(s|0)>(k|0)|(s|0)==(k|0)&(c[r>>2]|0)>>>0>q>>>0?0:p;if((t|0)<0){break}else{u=t}}else{u=p}c[n+120>>2]=u;p=c[n+36>>2]|0;if((p|0)==0){break}t=c[n+32>>2]|0;q=0;r=0;while(1){if(!(q>>>0<t>>>0)){break a}k=(c[p+(q<<3)>>2]|0)+r|0;if((k|0)>(u|0)){break}else{q=q+1|0;r=k}}c[n+56>>2]=q;c[n+60>>2]=u-r}}while(0);e=d+1|0;if(e>>>0<(c[g>>2]|0)>>>0){d=e}else{h=0;break}}return h|0}else{d=0;while(1){u=c[i>>2]|0;e=c[u+(d<<2)>>2]|0;c[e+448>>2]=0;b:do{if((d|0)!=(b|0)){j=XIb(o,a,(c[u+(b<<2)>>2]|0)+40|0,e+40|0)|0;m=G;l=c[e+12>>2]|0;p=CX(e,j,m,f)|0;if((p|0)<0){if((c[e+404>>2]|0)==0){break}t=(c[e+400>>2]|0)+8|0;k=c[t+4>>2]|0;s=(k|0)>(m|0)|(k|0)==(m|0)&(c[t>>2]|0)>>>0>j>>>0?0:p;if((s|0)<0){break}else{v=s}}else{v=p}c[l+120>>2]=v;p=c[l+36>>2]|0;if((p|0)==0){break}s=c[l+32>>2]|0;j=0;t=0;while(1){if(!(j>>>0<s>>>0)){break b}m=(c[p+(j<<3)>>2]|0)+t|0;if((m|0)>(v|0)){break}else{j=j+1|0;t=m}}c[l+56>>2]=j;c[l+60>>2]=v-t}}while(0);e=d+1|0;if(e>>>0<(c[g>>2]|0)>>>0){d=e}else{h=0;break}}return h|0}return 0}function HL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;f=i;i=i+3200|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f|0;h=f+2128|0;j=f+2136|0;k=f+2144|0;l=f+2152|0;m=f+3176|0;n=f+3192|0;c[n>>2]=0;o=(c[b+96>>2]|0)==0;p=c[e>>2]|0;if((p|0)==757935405&(o^1)){q=c[b+4>>2]|0;r=e+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;r=f+80|0;u=f+1104|0;mrc(r|0,0,1024)|0;mrc(u|0,0,1024)|0;v=c[q+24>>2]|0;if((v|0)==0){w=0;i=f;return w|0}x=c[(c[(c[q+28>>2]|0)+(v-1<<2)>>2]|0)+12>>2]|0;v=0;if((t|0)<(v|0)|(t|0)==(v|0)&s>>>0<9>>>0){w=0;i=f;return w|0}v=JD(d)|0;q=FD(d)|0;if((q|0)==1701667182){JD(d)|0;y=wrc(s,t,-12,-1)|0;z=r;A=v-12|0;B=G;C=y;D=8}else if((q|0)==1635017060){JD(d)|0;JD(d)|0;q=wrc(s,t,-16,-1)|0;z=u;A=v-16|0;B=G;C=q;D=8}else{E=0;F=t;H=s;I=v-8|0}if((D|0)==8){v=A>>>0<1023>>>0;s=v?A:1023;t=v?0:0;v=(t|0)>(B|0)|(t|0)==(B|0)&s>>>0>C>>>0;q=v?C:s;v?B:t;t=q;AD(d,z,t)|0;a[z+t|0]=0;E=t;F=B;H=C;I=A}A=xrc(H,F,I,(I|0)<0|0?-1:0)|0;F=G;if((I|0)>(E|0)){H=I-E|0;hD(d,H,(H|0)<0|0?-1:0)|0;}H=JD(d)|0;E=FD(d)|0;if((E|0)==1635017060){JD(d)|0;JD(d)|0;I=wrc(A,F,-16,-1)|0;J=u;K=H-16|0;L=G;M=I;D=21}else if((E|0)==1701667182){JD(d)|0;E=wrc(A,F,-12,-1)|0;J=r;K=H-12|0;L=G;M=E;D=21}else{N=0;O=F;P=A;Q=H-8|0}if((D|0)==21){H=K>>>0<1023>>>0;A=H?K:1023;F=H?0:0;H=(F|0)>(L|0)|(F|0)==(L|0)&A>>>0>M>>>0;E=H?M:A;H?L:F;F=E;AD(d,J,F)|0;a[J+F|0]=0;N=F;O=L;P=M;Q=K}K=xrc(P,O,Q,(Q|0)<0|0?-1:0)|0;O=G;if((Q|0)>(N|0)){P=Q-N|0;hD(d,P,(P|0)<0|0?-1:0)|0;}P=JD(d)|0;N=FD(d)|0;if((N|0)==1701667182){JD(d)|0;Q=wrc(K,O,-12,-1)|0;R=r;S=P-12|0;T=G;U=Q;D=28}else if((N|0)==1635017060){JD(d)|0;JD(d)|0;N=wrc(K,O,-16,-1)|0;R=u;S=P-16|0;T=G;U=N;D=28}else{V=0;W=P-8|0}if((D|0)==28){P=S>>>0<1023>>>0;N=P?S:1023;O=P?0:0;P=(O|0)>(T|0)|(O|0)==(T|0)&N>>>0>U>>>0;K=P?U:N;P?T:O;O=K;AD(d,R,O)|0;a[R+O|0]=0;V=O;W=S}if((W|0)>(V|0)){S=W-V|0;hD(d,S,(S|0)<0|0?-1:0)|0;}do{if((a[r]|0)!=0){if((a[u]|0)==0){break}do{if((irc(r,2217640)|0)==0){S=Bd(u|0,2214800,(X=i,i=i+24|0,c[X>>2]=h,c[X+8>>2]=j,c[X+16>>2]=k,X)|0)|0;i=X;if((S|0)!=3){break}S=c[h>>2]|0;if(!((S-1|0)>>>0<16383>>>0)){w=1;i=f;return w|0}c[x+1232>>2]=S;w=1;i=f;return w|0}}while(0);if((irc(r,2212328)|0)==0){w=1}else{break}i=f;return w|0}}while(0);w=0;i=f;return w|0}if((p|0)==1297240128){r=c[e+8>>2]|0;x=hJb(r+1|0)|0;if((x|0)==0){w=-12;i=f;return w|0}AD(d,x,r)|0;a[x+r|0]=0;w=MGb((c[b+4>>2]|0)+1140|0,2261688,x,8)|0;i=f;return w|0}else if((p|0)==1364348992){x=c[e+8>>2]|0;r=hJb(x+1|0)|0;if((r|0)==0){w=-12;i=f;return w|0}AD(d,r,x)|0;a[r+x|0]=0;w=MGb((c[b+4>>2]|0)+1140|0,2257328,r,8)|0;i=f;return w|0}else if((p|0)==1668506980){Y=2324592;Z=0}else if((p|0)==1936024684){Y=2319272;Z=0}else if((p|0)==1685024169){Y=2335904;Z=0}else if((p|0)==2054781097){Y=2330592;Z=0}else if((p|0)==1802725732){Y=2286720;Z=588}else if((p|0)==1936029300){Y=2282512;Z=26}else if((p|0)==1752397428){Y=2314576;Z=0}else if((p|0)==1852143220){Y=2309832;Z=0}else if((p|0)==2036425897){Y=2372336;Z=0}else if((p|0)==1852139433){Y=2359752;Z=0}else if((p|0)==1953849769|(p|0)==1414676905){Y=2433520;Z=0}else if((p|0)==1920560297){Y=2391584;Z=0}else if((p|0)==1414676833){Y=2424624;Z=0}else if((p|0)==1953325993|(p|0)==1718512041){Y=2384936;Z=0}else if((p|0)==1651270057){Y=2377920;Z=0}else if((p|0)==1953656931|(p|0)==2037408681){Y=2406200;Z=0}else if((p|0)==1701998183){Y=2359752;Z=660}else if((p|0)==1869575337|(p|0)==1920431017){Y=2348016;Z=0}else if((p|0)==1685480552){Y=2269264;Z=598}else if((p|0)==1885431664){Y=2265328;Z=598}else if((p|0)==1953658793){Y=2413824;Z=0}else if((p|0)==1853060724){Y=2278624;Z=26}else if((p|0)==1802073203){Y=2274448;Z=598}else if((p|0)==1835101865){Y=2448928;Z=0}else if((p|0)==1852733044){Y=2305872;Z=0}else if((p|0)==1852535412){Y=2295864;Z=588}else if((p|0)==1886545833){Y=2398632;Z=0}else if((p|0)==1668179369){Y=2348016;Z=0}else if((p|0)==1801547177){Y=2341728;Z=0}else{Y=0;Z=0}r=e+8|0;x=c[r>>2]|0;h=c[r+4>>2]|0;k=0;a:do{if(((h|0)>(k|0)|(h|0)==(k|0)&x>>>0>8>>>0)&(o^1)){j=JD(d)|0;if((FD(d)|0)!=1635017060){w=0;i=f;return w|0}u=JD(d)|0;JD(d)|0;S=j-16|0;j=wrc(x,h,-16,-1)|0;V=G;c[r>>2]=j;c[r+4>>2]=V;if((p|0)!=1920364387){_=0;$=u;aa=S;ba=V;ca=j;break}W=g;if((u|0)==14){da=62}else if((u|0)==27){da=79}else if((u|0)==13){da=8}else{KIb(c[b+4>>2]|0,24,2233168,(X=i,i=i+8|0,c[X>>2]=u,X)|0);i=X;hD(d,S,(S|0)<0|0?-1:0)|0;_=0;$=u;aa=S;ba=V;ca=j;break}O=b+4|0;R=ZX(c[O>>2]|0,0)|0;do{if((R|0)==0){ea=-12}else{K=pJb(1256)|0;if((K|0)==0){ea=-12;break}c[R+12>>2]=K;K=fX(d,g,S)|0;if((K|0)<0){ea=K;break}K=R+72|0;c[K>>2]=c[K>>2]|1024;nrc(R+104|0,W|0,80)|0;c[R+136>>2]=c[R>>2];K=R+140|0;c[K>>2]=c[K>>2]|1;K=c[R+8>>2]|0;c[K+8>>2]=0;c[K+48>>2]=da;_=0;$=u;aa=S;ba=V;ca=j;break a}}while(0);KIb(c[O>>2]|0,16,2253832,(X=i,i=i+1|0,i=i+7&-8,c[X>>2]=0,X)|0);i=X;w=ea;i=f;return w|0}else{j=0;if((h|0)<(j|0)|(h|0)==(j|0)&x>>>0<5>>>0|(Y|0)==0|o^1){_=0;$=0;aa=x;ba=h;ca=x;break}else{j=e+8|0;V=HD(d)|0;S=(HD(d)|0)&65535;FJ(S,n)|0;u=wrc(x,h,-4,-1)|0;R=G;c[j>>2]=u;c[j+4>>2]=R;_=S;$=0;aa=V;ba=R;ca=u;break}}}while(0);if((Y|0)==0){w=0;i=f;return w|0}h=0;if((ba|0)<(h|0)|(ba|0)==(h|0)&ca>>>0<0>>>0){w=-1094995529;i=f;return w|0}h=aa>>>0<1023>>>0;x=h?aa:1023;aa=h?0:0;h=(aa|0)>(ba|0)|(aa|0)==(ba|0)&x>>>0>ca>>>0;h?ba:aa;aa=h?ca:x;if((Z|0)!=0){hf[Z&1023](b,d,aa,Y)|0;w=0;i=f;return w|0}if(($|0)==0){if(_>>>0<1024>>>0|(_|0)==32767){D=88}else{D=89}}else if(($|0)==3){D=88}else{D=89}do{if((D|0)==88){ML(d,aa,l|0,1024)}else if((D|0)==89){$=AD(d,l|0,aa)|0;if(($|0)==(aa|0)){a[l+aa|0]=0;break}w=($|0)<0?$:-1094995529;i=f;return w|0}}while(0);aa=b+4|0;b=l|0;MGb((c[aa>>2]|0)+1140|0,Y,b,0)|0;l=n;if((a[l]|0)==0){w=0;i=f;return w|0}if((irc(l,2244880)|0)==0){w=0;i=f;return w|0}l=m|0;Rb(l|0,16,2236872,(X=i,i=i+16|0,c[X>>2]=Y,c[X+8>>2]=n,X)|0)|0;i=X;MGb((c[aa>>2]|0)+1140|0,l,b,0)|0;w=0;i=f;return w|0}function IL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;d=i;i=i+24|0;zD(b)|0;f=(zD(b)|0)<<16;if((f-65536|0)>>>0>9568256>>>0){i=d;return 0}b=d|0;Rb(b|0,20,2220928,(g=i,i=i+8|0,c[g>>2]=c[1373488+((f>>16)-1<<2)>>2],g)|0)|0;i=g;MGb((c[a+4>>2]|0)+1140|0,e,b,0)|0;i=d;return 0}function JL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+16|0;g=f|0;HD(b)|0;h=HD(b)|0;do{if(d>>>0>5>>>0){j=(HD(b)|0)&65535;k=g|0;l=h<<16>>16;if(j<<16>>16==0){m=k;n=l;break}Rb(k|0,16,2225560,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=j<<16>>16,o)|0)|0;i=o;p=k;q=a+4|0;r=c[q>>2]|0;s=r+1140|0;t=MGb(s,e,p,0)|0;i=f;return 0}else{m=g|0;n=h<<16>>16}}while(0);Rb(m|0,16,2229344,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;p=m;q=a+4|0;r=c[q>>2]|0;s=r+1140|0;t=MGb(s,e,p,0)|0;i=f;return 0}function KL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;d=i;i=i+16|0;zD(b)|0;zD(b)|0;zD(b)|0;f=d|0;g=zD(b)|0;Rb(f|0,16,2229344,(b=i,i=i+8|0,c[b>>2]=g,b)|0)|0;i=b;MGb((c[a+4>>2]|0)+1140|0,e,f,0)|0;i=d;return 0}function LL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;d=i;i=i+16|0;f=d|0;g=zD(b)|0;Rb(f|0,16,2229344,(b=i,i=i+8|0,c[b>>2]=g,b)|0)|0;i=b;MGb((c[a+4>>2]|0)+1140|0,e,f,0)|0;i=d;return 0}function ML(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=f+(g-1)|0;if((e|0)>0){i=0;j=f}else{k=f;a[k]=0;return}while(1){f=zD(b)|0;g=f&255;l=j>>>0<h>>>0;a:do{if(g>>>0<128>>>0&l){a[j]=f;m=j+1|0}else{if(!l){m=j;break}n=c[840096+(g-128<<2)>>2]|0;o=(n&65280|0)==0;p=(((d[1359664+(o?n:n>>>8)|0]|0)+4+(o?0:8)|0)>>>0)/5|0;o=(p*6|0)-6|0;a[j]=n>>>(o>>>0)|256-(256>>>(p>>>0));p=j;q=o;while(1){r=p+1|0;if(!(r>>>0<h>>>0)){s=q;break}if((q|0)<=5){m=r;break a}o=q-6|0;a[r]=n>>>(o>>>0)&63|128;p=r;q=o}while(1){if((s|0)<=5){m=r;break a}s=s-6|0}}}while(0);g=i+1|0;if((g|0)<(e|0)){i=g;j=m}else{k=m;break}}a[k]=0;return}function NL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=JM(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,1096176969)|0;i=e;return g|0}function OL(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=c[a+4>>2]|0;h=c[g+24>>2]|0;do{if((h|0)!=0){j=c[(c[(c[g+28>>2]|0)+(h-1<<2)>>2]|0)+8>>2]|0;if((c[j+52>>2]|0)!=1852397121){break}if((c[j+48>>2]|0)!=28){break}k=e+8|0;l=c[k+4>>2]|0;m=0;if(!((l|0)>(m|0)|(l|0)==(m|0)&(c[k>>2]|0)>>>0>11>>>0)){break}hD(b,10,0)|0;if((HD(b)|0)!=3405){n=0;i=f;return n|0}c[j+120>>2]=1440;n=0;i=f;return n|0}}while(0);h=e|0;g=e+8|0;e=g|0;j=g+4|0;n=JM(a,b,d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0,d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0,d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0,1096176969)|0;i=f;return n|0}function PL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=JM(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,83)|0;i=e;return g|0}function QL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+272|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f|0;h=f+264|0;j=e+8|0;e=wrc(c[j>>2]|0,c[j+4>>2]|0,-5,-1)|0;k=G;c[j>>2]=e;c[j+4>>2]=k;l=0;if((k|0)<(l|0)|(k|0)==(l|0)&e>>>0<0>>>0){i=f;return 0}l=zD(d)|0;ID(d)|0;if((l|0)!=0){JD(d)|0}l=zD(d)|0;if((l|0)<=0){i=f;return 0}m=g|0;n=b+4|0;b=h|0;o=h+4|0;p=0;q=k;k=e;while(1){e=0;if((q|0)<(e|0)|(q|0)==(e|0)&k>>>0<9>>>0){r=9;break}e=OD(d)|0;s=G;t=zD(d)|0;u=t+9|0;v=xrc(k,q,u,(u|0)<0|0?-1:0)|0;u=G;c[j>>2]=v;c[j+4>>2]=u;w=0;if((u|0)<(w|0)|(u|0)==(w|0)&v>>>0<0>>>0){r=9;break}AD(d,m,t)|0;a[g+t|0]=0;t=c[n>>2]|0;c[b>>2]=1;c[o>>2]=1e7;aY(t,p,h,e,s,0,-2147483648,m)|0;s=p+1|0;if((s|0)<(l|0)){p=s;q=u;k=v}else{r=9;break}}if((r|0)==9){i=f;return 0}return 0}function RL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}h=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;zD(b)|0;ID(b)|0;a=JD(b)|0;if((a|0)==0){g=0;i=e;return g|0}if(a>>>0>536870910>>>0){g=-1094995529;i=e;return g|0}f=hJb(a<<3)|0;j=h+20|0;c[j>>2]=f;if((f|0)==0){g=-12;i=e;return g|0}f=h+16|0;c[f>>2]=a;h=c[d>>2]|0;a:do{if((h|0)==1868788851){d=b+52|0;k=0;while(1){if((c[d>>2]|0)!=0){l=k;break a}m=JD(b)|0;n=(c[j>>2]|0)+(k<<3)|0;c[n>>2]=m;c[n+4>>2]=0;n=k+1|0;if(n>>>0<a>>>0){k=n}else{l=n;break}}}else if((h|0)==875982691){k=b+52|0;d=0;while(1){if((c[k>>2]|0)!=0){l=d;break a}n=OD(b)|0;m=(c[j>>2]|0)+(d<<3)|0;c[m>>2]=n;c[m+4>>2]=G;m=d+1|0;if(m>>>0<a>>>0){d=m}else{l=m;break}}}else{g=-1094995529;i=e;return g|0}}while(0);c[f>>2]=l;g=(c[b+52>>2]|0)==0?0:-541478725;i=e;return g|0}function SL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;a=c[f>>2]|0;d=c[a+24>>2]|0;if((d|0)==0){g=0;i=e;return g|0}h=c[(c[(c[a+28>>2]|0)+(d-1<<2)>>2]|0)+12>>2]|0;zD(b)|0;ID(b)|0;d=JD(b)|0;if((d|0)==0){g=0;i=e;return g|0}if(d>>>0>536870910>>>0){g=-1094995529;i=e;return g|0}a=hJb(d<<3)|0;j=h+36|0;k=j;c[k>>2]=a;if((a|0)==0){g=-12;i=e;return g|0}a=b+52|0;l=h+172|0;m=0;while(1){if((c[a>>2]|0)!=0){n=m;o=12;break}p=JD(b)|0;q=JD(b)|0;r=c[k>>2]|0;c[r+(m<<3)>>2]=p;c[r+(m<<3)+4>>2]=q;r=-q|0;p=m+2|0;if((((q|0)>-1?q:r)|0)>268435456&p>>>0<d>>>0){o=8;break}if(p>>>0<d>>>0&(q|0)<0){q=c[l>>2]|0;c[l>>2]=(q|0)>(r|0)?q:r}r=m+1|0;if(r>>>0<d>>>0){m=r}else{n=r;o=12;break}}if((o|0)==8){KIb(c[f>>2]|0,24,2631896,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;mJb(j);c[h+32>>2]=0;g=0;i=e;return g|0}else if((o|0)==12){c[h+32>>2]=n;g=(c[a>>2]|0)==0?0:-541478725;i=e;return g|0}return 0}function TL(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;h=f;f=i;i=i+16|0;c[f>>2]=c[h>>2];c[f+4>>2]=c[h+4>>2];c[f+8>>2]=c[h+8>>2];c[f+12>>2]=c[h+12>>2];h=d+4|0;d=c[h>>2]|0;j=c[d+24>>2]|0;if((j|0)==0){k=0;i=g;return k|0}l=c[(c[(c[d+28>>2]|0)+(j-1<<2)>>2]|0)+12>>2]|0;JD(e)|0;j=JD(e)|0;d=(j|0)<0|0?-1:0;m=f+8|0;f=wrc(c[m>>2]|0,c[m+4>>2]|0,-1,-1)|0;m=Crc(f,G,12,0)|0;f=wrc(m,G,1,0)|0;m=G;if((d|0)>(m|0)|(d|0)==(m|0)&j>>>0>f>>>0|j>>>0>39768214>>>0){k=-1094995529;i=g;return k|0}f=l+148|0;kJb(c[f>>2]|0);m=l+144|0;c[m>>2]=0;l=pJb(j*108|0)|0;d=l;c[f>>2]=d;if((l|0)==0){k=-12;i=g;return k|0}c[m>>2]=j;if((j|0)==0){k=0;i=g;return k|0}else{n=0;o=d}a:while(1){d=JD(e)|0;j=fD(e,0,0,1)|0;l=G;p=wrc(d,0,-4,-1)|0;q=wrc(p,G,j,l)|0;l=G;if(d>>>0<12>>>0){k=-1094995529;r=33;break}j=o+(n*108|0)|0;c[j>>2]=FD(e)|0;JD(e)|0;b:do{if((c[j>>2]|0)==1936288865&d>>>0>150>>>0){hD(e,10,0)|0;p=zD(e)|0;s=(p&65532)>>>0>27>>>0?27:p&65535;p=o+(n*108|0)+12|0;AD(e,p,27)|0;a[o+(n*108|0)+12+s|0]=0;KIb(c[h>>2]|0,48,2107112,(t=i,i=i+16|0,c[t>>2]=p,c[t+8>>2]=s,t)|0);i=t;hD(e,12,0)|0;u=zD(e)|0;v=(u&65472)>>>0>63>>>0?63:u&65535;u=o+(n*108|0)+40|0;AD(e,u,63)|0;a[o+(n*108|0)+40+v|0]=0;KIb(c[h>>2]|0,48,2105736,(t=i,i=i+16|0,c[t>>2]=u,c[t+8>>2]=v,t)|0);i=t;hD(e,16,0)|0;v=o+(n*108|0)+106|0;b[v>>1]=HD(e)|0;u=(HD(e)|0)&65535;b[o+(n*108|0)+104>>1]=u;KIb(c[h>>2]|0,48,2104176,(t=i,i=i+16|0,c[t>>2]=b[v>>1]|0,c[t+8>>2]=u<<16>>16,t)|0);i=t;hD(e,16,0)|0;u=o+(n*108|0)+4|0;v=o+(n*108|0)+8|0;do{w=fD(e,0,0,1)|0;x=G;if(!((x|0)<(l|0)|(x|0)==(l|0)&w>>>0<q>>>0)){break b}if((jD(e)|0)!=0){k=-541478725;r=33;break a}w=(HD(e)|0)&65535;x=HD(e)|0;KIb(c[h>>2]|0,48,2643728,(t=i,i=i+16|0,c[t>>2]=w<<16>>16,c[t+8>>2]=x&65535,t)|0);i=t;if((x&1|0)==0){y=x&65535}else{y=x+1&65535}if((w<<16>>16|0)==0){kJb(c[v>>2]|0);x=y&65535;z=hJb(x+1|0)|0;c[v>>2]=z;if((z|0)==0){k=-12;r=33;break a}if((AD(e,z,x)|0)!=(x|0)){k=-1094995529;r=33;break a}a[(c[v>>2]|0)+x|0]=0;if(!(y<<16>>16==0)){z=0;do{A=(c[v>>2]|0)+z|0;if((a[A]|0)==58){a[A]=47}z=z+1|0;}while((z|0)<(x|0))}KIb(c[h>>2]|0,48,2633536,(t=i,i=i+8|0,c[t>>2]=c[v>>2],t)|0);i=t}else if((w<<16>>16|0)==2){kJb(c[u>>2]|0);x=y&65535;z=pJb(x+1|0)|0;c[u>>2]=z;if((z|0)==0){k=-12;r=33;break a}AD(e,z,x)|0;do{if(x>>>0>s>>>0){z=c[u>>2]|0;if((krc(z,p,s)|0)!=0){B=y;break}A=x-s|0;C=A&65535;orc(z|0,z+s|0,C|0)|0;a[(c[u>>2]|0)+C|0]=0;B=A&65535}else{B=y}}while(0);x=B&65535;if(!(B<<16>>16==0)){A=0;do{C=(c[u>>2]|0)+A|0;if((a[C]|0)==58){a[C]=47}A=A+1|0;}while((A|0)<(x|0))}KIb(c[h>>2]|0,48,2638192,(t=i,i=i+8|0,c[t>>2]=c[u>>2],t)|0);i=t}else{hD(e,y&65535,0)|0;}}while(!(w<<16>>16==-1))}}while(0);fD(e,q,l,0)|0;d=n+1|0;if(!(d>>>0<(c[m>>2]|0)>>>0)){k=0;r=33;break}n=d;o=c[f>>2]|0}if((r|0)==33){i=g;return k|0}return 0}function UL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;g=c[f>>2]|0;h=c[g+24>>2]|0;if((h|0)==0){j=0;i=e;return j|0}if((c[a+108>>2]|0)!=0){j=0;i=e;return j|0}a=c[(c[(c[g+28>>2]|0)+(h-1<<2)>>2]|0)+12>>2]|0;h=zD(b)|0;ID(b)|0;g=JD(b)|0;k=Erc(g,(g|0)<0|0?-1:0,12,0)|0;l=wrc(k,G,8,0)|0;k=G;m=d+8|0;d=c[m+4>>2]|0;if(k>>>0>d>>>0|k>>>0==d>>>0&l>>>0>(c[m>>2]|0)>>>0){j=-1094995529;i=e;return j|0}if((g|0)<=0){j=0;i=e;return j|0}m=a+96|0;l=a+104|0;if((h|0)==1){h=0;a=0;d=0;while(1){k=OD(b)|0;n=G;o=OD(b)|0;p=G;JD(b)|0;do{if((h|0)==0&((o|0)==(-1|0)&(p|0)==(-1|0))){c[m>>2]=k;c[m+4>>2]=n;q=d;r=1}else{s=-1;if(!((h|0)==(a|0)&((p|0)>(s|0)|(p|0)==(s|0)&o>>>0>-1>>>0))){q=1;r=a;break}c[l>>2]=o;c[l+4>>2]=p;q=d;r=a}}while(0);p=h+1|0;if((p|0)<(g|0)){h=p;a=r;d=q}else{t=q;break}}}else{q=0;d=0;r=0;while(1){a=JD(b)|0;h=JD(b)|0;p=h;o=(h|0)<0|0?-1:0;JD(b)|0;do{if((q|0)==0&(h|0)==-1){c[m>>2]=a;c[m+4>>2]=0;u=r;v=1}else{if(!((q|0)==(d|0)&(h|0)>-1)){u=1;v=d;break}c[l>>2]=p;c[l+4>>2]=o;u=r;v=d}}while(0);o=q+1|0;if((o|0)<(g|0)){q=o;d=v;r=u}else{t=u;break}}}if((t|0)==0){j=0;i=e;return j|0}KIb(c[f>>2]|0,24,2108472,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;j=0;i=e;return j|0}function VL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;do{if((a|0)!=0){d=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;if(((HD(b)|0)&255|0)!=1){break}g=(c[d+8>>2]|0)+48|0;d=c[g>>2]|0;if((d|0)==65549){c[g>>2]=65548;break}else if((d|0)==65556){c[g>>2]=65557;break}else if((d|0)==65558){c[g>>2]=65559;break}else if((d|0)==65545){c[g>>2]=65544;break}else{break}}}while(0);i=e;return 0}function WL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}h=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;a=d+8|0;d=c[a+4>>2]|0;f=0;if((d|0)<(f|0)|(d|0)==(f|0)&(c[a>>2]|0)>>>0<2>>>0){g=-1094995529;i=e;return g|0}a=HD(b)|0;b=a&65280;do{if((b|0)==256){j=1}else if((b|0)==512){f=a&255;if((f|0)==14){j=5;break}else if((f|0)==9){j=4;break}else if((f|0)==1){j=2;break}else if((f|0)==6){j=3;break}else{k=8;break}}else{k=8}}while(0);do{if((k|0)==8){if((a|0)==0){j=0;break}KIb(0,16,2110144,(b=i,i=i+8|0,c[b>>2]=a,b)|0);i=b;j=0}}while(0);c[(c[h+8>>2]|0)+408>>2]=j;g=0;i=e;return g|0}function XL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+32|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f+16|0;h=f+24|0;mrc(h|0,0,5)|0;AD(d,h,4)|0;if((irc(h,2125736)|0)!=0){c[b+40>>2]=1}j=b+4|0;KIb(c[j>>2]|0,48,2120368,(b=i,i=i+8|0,c[b>>2]=h,b)|0);i=b;MGb((c[j>>2]|0)+1140|0,2115664,h,0)|0;h=JD(d)|0;k=f|0;Rb(k|0,11,2229344,(b=i,i=i+8|0,c[b>>2]=h,b)|0)|0;i=b;MGb((c[j>>2]|0)+1140|0,2113728,k,0)|0;k=e+8|0;e=wrc(c[k>>2]|0,c[k+4>>2]|0,-8,0)|0;k=e;if((k|0)<0){l=-1094995529;i=f;return l|0}e=hJb(k+1|0)|0;c[g>>2]=e;if((e|0)==0){l=-12;i=f;return l|0}AD(d,e,k)|0;a[e+k|0]=0;MGb((c[j>>2]|0)+1140|0,2111904,e,0)|0;mJb(g);l=0;i=f;return l|0}function YL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;g=c[f+24>>2]|0;if((g|0)==0){h=0;i=e;return h|0}j=c[(c[f+28>>2]|0)+(g-1<<2)>>2]|0;g=d+8|0;f=c[g>>2]|0;k=c[g+4>>2]|0;g=0;if(k>>>0>g>>>0|k>>>0==g>>>0&f>>>0>1073741824>>>0){h=-1094995529;i=e;return h|0}g=0;do{if((k|0)>(g|0)|(k|0)==(g|0)&f>>>0>9>>>0){l=JD(b)|0;m=FD(b)|0;fD(b,-8,-1,1)|0;if((m|0)!=1818585446){break}if(!((l|0)==(f|0)&0==(k|0))){break}h=BL(a,b,d)|0;i=e;return h|0}}while(0);d=j+8|0;kJb(c[(c[d>>2]|0)+96>>2]|0);h=(QX(c[d>>2]|0,b,f)|0)>>31&-12;i=e;return h|0}function ZL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f|0;h=c[b+4>>2]|0;j=c[h+24>>2]|0;if((j|0)==0){k=0;i=f;return k|0}l=c[(c[h+28>>2]|0)+(j-1<<2)>>2]|0;zD(d)|0;ID(d)|0;FD(d)|0;j=FD(d)|0;if((j|0)==1853190003){c[(c[l+8>>2]|0)+8>>2]=1}else if((j|0)==1701079414){c[(c[l+8>>2]|0)+8>>2]=0}else if((j|0)==1885564003|(j|0)==1885500787){c[(c[l+8>>2]|0)+8>>2]=3}else if((j|0)==543240557){c[(c[l+8>>2]|0)+48>>2]=86016}JD(d)|0;JD(d)|0;JD(d)|0;j=e+8|0;e=wrc(c[j>>2]|0,c[j+4>>2]|0,-24,0)|0;j=e;if((j|0)<=0){k=0;i=f;return k|0}e=hJb(j+1|0)|0;c[g>>2]=e;if((e|0)==0){k=-12;i=f;return k|0}AD(d,e,j)|0;a[e+j|0]=0;d=a[e]|0;if(!(d<<24>>24==0)){if((c[b+40>>2]|0)==0){m=(d<<24>>24|0)==(j-1|0)|0}else{m=0}MGb(l+88|0,2127328,e+m|0,0)|0}mJb(g);k=0;i=f;return k|0}function _L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+96|0;c[f>>2]=1;g=BL(a,b,d)|0;c[f>>2]=0;i=e;return g|0}function $L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=JM(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,89)|0;i=e;return g|0}function aM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;d=i;i=i+16|0;c[d>>2]=c[e>>2];c[d+4>>2]=c[e+4>>2];c[d+8>>2]=c[e+8>>2];c[d+12>>2]=c[e+12>>2];e=d+8|0;if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){i=b;return 0}c[a+28>>2]=1;i=b;return 0}function bM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+48|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e+32|0;d=e+40|0;c[d>>2]=0;g=a+4|0;a=c[g>>2]|0;h=c[a+24>>2]|0;if((h|0)==0){j=0;i=e;return j|0}k=c[(c[a+28>>2]|0)+(h-1<<2)>>2]|0;h=(c[k+12>>2]|0)+92|0;if((c[h>>2]|0)!=0){KIb(a,16,2131640,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=-1094995529;i=e;return j|0}a=zD(b)|0;if((a|0)>1){QIb(c[g>>2]|0,2130168,(l=i,i=i+8|0,c[l>>2]=a,l)|0);i=l;j=-1163346256;i=e;return j|0}ID(b)|0;l=(a|0)==1;if(l){a=OD(b)|0;g=G;OD(b)|0;m=g;n=a}else{a=JD(b)|0;JD(b)|0;m=0;n=a}a=k+88|0;g=e|0;do{if(!((n|0)==0&(m|0)==0)){o=0;if((m|0)>(o|0)|(m|0)==(o|0)&n>>>0>2082844799>>>0){o=wrc(n,m,-2082844800,0)|0;p=o}else{p=n}c[f>>2]=p;o=rc(f|0)|0;if((o|0)==0){break}Fc(g|0,32,2137080,o|0)|0;MGb(a,2135344,g,0)|0}}while(0);c[h>>2]=JD(b)|0;if(l){l=OD(b)|0;q=G;r=l}else{q=0;r=JD(b)|0}l=k+56|0;c[l>>2]=r;c[l+4>>2]=q;q=d;if((FJ(HD(b)|0,q)|0)!=0){MGb(a,2128808,q,0)|0}HD(b)|0;j=0;i=e;return j|0}function cM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=c[f+4>>2]|0;h=c[f>>2]|0;while(1){j=0;if(!((g|0)>(j|0)|(g|0)==(j|0)&h>>>0>8>>>0)){k=0;l=5;break}j=FD(b)|0;m=wrc(h,g,-4,-1)|0;n=G;c[f>>2]=m;c[f+4>>2]=n;if((j|0)==1919706216){break}else{g=n;h=m}}if((l|0)==5){i=e;return k|0}fD(b,-8,-1,1)|0;l=wrc(h,g,4,0)|0;c[f>>2]=l;c[f+4>>2]=G;k=BL(a,b,d)|0;i=e;return k|0}function dM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=fD(b,0,0,1)|0;g=wrc(f,G,-8,-1)|0;f=a+64|0;c[f>>2]=g;c[f+4>>2]=G;f=BL(a,b,d)|0;i=e;return f|0}function eM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+24|0;if((c[f>>2]|0)!=0){KIb(c[a+4>>2]|0,24,2133664,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;g=d+8|0;hD(b,c[g>>2]|0,c[g+4>>2]|0)|0;h=0;i=e;return h|0}g=BL(a,b,d)|0;if((g|0)<0){h=g;i=e;return h|0}c[f>>2]=1;h=0;i=e;return h|0}function fM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+40|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e+32|0;d=zD(b)|0;ID(b)|0;g=(d|0)==1;if(g){d=OD(b)|0;h=G;OD(b)|0;j=h;k=d}else{d=JD(b)|0;JD(b)|0;j=0;k=d}d=a+4|0;h=(c[d>>2]|0)+1140|0;l=e|0;do{if(!((k|0)==0&(j|0)==0)){m=0;if((j|0)>(m|0)|(j|0)==(m|0)&k>>>0>2082844799>>>0){m=wrc(k,j,-2082844800,0)|0;n=m}else{n=k}c[f>>2]=n;m=rc(f|0)|0;if((m|0)==0){break}Fc(l|0,32,2137080,m|0)|0;MGb(h,2135344,l,0)|0}}while(0);l=a+8|0;c[l>>2]=JD(b)|0;if(g){g=OD(b)|0;o=G;p=g}else{o=0;p=JD(b)|0}g=a+16|0;c[g>>2]=p;c[g+4>>2]=o;g=c[l>>2]|0;do{if((g|0)>0){if((c[a+88>>2]|0)!=0){break}l=VIb(p,o,1e6,0,g,(g|0)<0|0?-1:0)|0;h=(c[d>>2]|0)+1064|0;c[h>>2]=l;c[h+4>>2]=G}}while(0);JD(b)|0;HD(b)|0;hD(b,10,0)|0;hD(b,36,0)|0;JD(b)|0;JD(b)|0;JD(b)|0;JD(b)|0;JD(b)|0;JD(b)|0;JD(b)|0;i=e;return 0}function gM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=JM(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,24)|0;i=e;return g|0}function hM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=JM(a,b,c[d>>2]|0,c[f>>2]|0,c[f+4>>2]|0,86032)|0;i=e;return g|0}function iM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=JD(b)|0;d=JD(b)|0;b=c[a+4>>2]|0;a=c[b+24>>2]|0;if((a|0)==0){i=e;return 0}g=c[(c[b+28>>2]|0)+(a-1<<2)>>2]|0;a=g+80|0;h=g+84|0;g=c[h>>2]|0;if((g|0)==1){if((c[a>>2]|0)!=0){j=4}}else{j=4}do{if((j|0)==4){k=c[a>>2]|0;if((d|0)==(g|0)&(f|0)==(k|0)){break}KIb(b,24,2139032,(l=i,i=i+32|0,c[l>>2]=k,c[l+8>>2]=g,c[l+16>>2]=f,c[l+24>>2]=d,l)|0);i=l;i=e;return 0}}while(0);if((d|0)==0){i=e;return 0}c[a>>2]=f;c[h>>2]=d;i=e;return 0}function jM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}d=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;JD(b)|0;a=JD(b)|0;if(a>>>0>1073741822>>>0){g=-1094995529;i=e;return g|0}f=hJb(a<<2)|0;h=d+52|0;c[h>>2]=f;if((f|0)==0){g=-12;i=e;return g|0}f=b+52|0;a:do{if((a|0)==0){j=0}else{k=0;while(1){if((c[f>>2]|0)!=0){j=k;break a}l=JD(b)|0;c[(c[h>>2]|0)+(k<<2)>>2]=l;l=k+1|0;if(l>>>0<a>>>0){k=l}else{j=l;break}}}}while(0);c[d+48>>2]=j;g=(c[f>>2]|0)==0?0:-541478725;i=e;return g|0}function kM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}h=d+8|0;d=c[h>>2]|0;j=c[h+4>>2]|0;h=0;if((j|0)<(h|0)|(j|0)==(h|0)&d>>>0<41>>>0){g=0;i=e;return g|0}h=0;if(j>>>0>h>>>0|j>>>0==h>>>0&d>>>0>1073741824>>>0){g=-1094995529;i=e;return g|0}h=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;hD(b,40,0)|0;a=h+8|0;kJb(c[(c[a>>2]|0)+96>>2]|0);h=c[a>>2]|0;a=wrc(d,j,-40,0)|0;g=(QX(h,b,a)|0)>>31&-12;i=e;return g|0}function lM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}d=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;zD(b)|0;ID(b)|0;a=JD(b)|0;if((a|0)==0){g=0;i=e;return g|0}if(a>>>0>357913940>>>0){g=-1094995529;i=e;return g|0}f=hJb(a*12|0)|0;h=d+44|0;c[h>>2]=f;if((f|0)==0){g=-12;i=e;return g|0}f=b+52|0;j=0;while(1){if((c[f>>2]|0)!=0){k=j;break}l=JD(b)|0;c[(c[h>>2]|0)+(j*12|0)>>2]=l;l=JD(b)|0;c[(c[h>>2]|0)+(j*12|0)+4>>2]=l;l=JD(b)|0;c[(c[h>>2]|0)+(j*12|0)+8>>2]=l;l=j+1|0;if(l>>>0<a>>>0){j=l}else{k=l;break}}c[d+40>>2]=k;g=(c[f>>2]|0)==0?0:-541478725;i=e;return g|0}function mM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];zD(b)|0;ID(b)|0;f=AL(a,b,JD(b)|0)|0;i=e;return f|0}function nM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}d=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;a=c[d+12>>2]|0;zD(b)|0;ID(b)|0;f=JD(b)|0;if((f|0)==0){c[a+80>>2]=1;h=d+236|0;if((c[h>>2]|0)!=0){g=0;i=e;return g|0}if((c[(c[d+8>>2]|0)+8>>2]|0)!=0){g=0;i=e;return g|0}c[h>>2]=2;g=0;i=e;return g|0}if(f>>>0>1073741822>>>0){g=-1094995529;i=e;return g|0}h=hJb(f<<2)|0;d=a+88|0;c[d>>2]=h;if((h|0)==0){g=-12;i=e;return g|0}h=b+52|0;j=0;while(1){if((c[h>>2]|0)!=0){k=j;break}l=JD(b)|0;c[(c[d>>2]|0)+(j<<2)>>2]=l;l=j+1|0;if(l>>>0<f>>>0){j=l}else{k=l;break}}c[a+84>>2]=k;g=(c[h>>2]|0)==0?0:-541478725;i=e;return g|0}function oM(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=a+4|0;a=c[g>>2]|0;h=c[a+24>>2]|0;if((h|0)==0){j=0;i=f;return j|0}k=c[(c[(c[a+28>>2]|0)+(h-1<<2)>>2]|0)+12>>2]|0;zD(b)|0;ID(b)|0;do{if((c[e>>2]|0)==2054386803){h=JD(b)|0;a=k+64|0;if((c[a>>2]|0)==0){c[a>>2]=h}c[k+68>>2]=h;a=JD(b)|0;l=k+72|0;c[l>>2]=a;if((h|0)==0){m=l;n=a;o=32;break}else{j=0}i=f;return j|0}else{ID(b)|0;a=zD(b)|0;l=JD(b)|0;h=k+72|0;c[h>>2]=l;if((a|0)==32|(a|0)==16|(a|0)==8|(a|0)==4){m=h;n=l;o=a;break}KIb(c[g>>2]|0,16,2143984,(l=i,i=i+8|0,c[l>>2]=a,l)|0);i=l;j=-1094995529;i=f;return j|0}}while(0);if((n|0)==0){j=0;i=f;return j|0}if(n>>>0>1073741822>>>0){j=-1094995529;i=f;return j|0}if(!(n>>>0<(4294967291/(o>>>0)|0)>>>0)){j=-1094995529;i=f;return j|0}g=hJb(n<<2)|0;e=k+76|0;l=e;c[l>>2]=g;if((g|0)==0){j=-12;i=f;return j|0}g=((ca(n,o)|0)+4|0)>>>3;a=hJb(g+16|0)|0;if((a|0)==0){mJb(e);j=-12;i=f;return j|0}if((AD(b,a,g)|0)>>>0<g>>>0){mJb(e);kJb(a);j=-1094995529;i=f;return j|0}e=g<<3;g=e>>>0>2147483639>>>0;h=g?0:a;p=g?8:e+8|0;e=b+52|0;b=(o|0)==0;g=k+1208|0;k=(o|0)<26;q=32-o|0;r=o-16|0;s=48-o|0;t=0;u=0;while(1){if((c[e>>2]|0)!=0){v=u;break}do{if(b){w=0;x=t}else{y=h+(t>>>3)|0;z=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(t&7);if(k){y=t+o|0;w=z>>>(q>>>0);x=p>>>0>y>>>0?y:p;break}else{y=t+16|0;A=p>>>0>y>>>0?y:p;y=h+(A>>>3)|0;B=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(A&7)>>>(s>>>0);y=A+r|0;w=B|z>>>16<<r;x=p>>>0>y>>>0?y:p;break}}}while(0);c[(c[l>>2]|0)+(u<<2)>>2]=w;y=wrc(c[g>>2]|0,c[g+4>>2]|0,w,(w|0)<0|0?-1:0)|0;c[g>>2]=y;c[g+4>>2]=G;y=u+1|0;if(y>>>0<n>>>0){t=x;u=y}else{v=y;break}}c[m>>2]=v;if((c[e>>2]|0)!=0){j=-541478725;i=f;return j|0}kJb(a);j=0;i=f;return j|0}function pM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;a=c[f>>2]|0;d=c[a+24>>2]|0;if((d|0)==0){g=0;i=e;return g|0}h=c[(c[a+28>>2]|0)+(d-1<<2)>>2]|0;d=c[h+12>>2]|0;zD(b)|0;ID(b)|0;a=JD(b)|0;if(a>>>0>536870910>>>0){g=-1;i=e;return g|0}j=d+28|0;kJb(c[j>>2]|0);k=hJb(a<<3)|0;c[j>>2]=k;if((k|0)==0){g=-12;i=e;return g|0}k=b+52|0;a:do{if((a|0)==0){l=0;m=0;n=0;o=0;p=0}else{q=0;r=0;s=0;t=0;u=0;while(1){if((c[k>>2]|0)!=0){l=q;m=r;n=s;o=t;p=u;break a}v=JD(b)|0;w=JD(b)|0;if((w|0)<0){x=c[f>>2]|0;y=(c[x+24>>2]|0)-1|0;KIb(x,16,2151848,(z=i,i=i+24|0,c[z>>2]=w,c[z+8>>2]=q,c[z+16>>2]=y,z)|0);i=z;A=1}else{A=w}if((v|0)<0){break}w=c[j>>2]|0;c[w+(q<<3)>>2]=v;c[w+(q<<3)+4>>2]=A;w=q+1|0;y=0;if((w|0)==(a|0)&(q|0)!=0&(v|0)==1&((t|0)>(y|0)|(t|0)==(y|0)&u>>>0>100>>>0)){y=(A|0)/10|0;x=(y|0)<0|0?-1:0;B=Crc(s,r,u,t)|0;C=G;D=(x|0)>(C|0)|(x|0)==(C|0)&y>>>0>B>>>0?B:A}else{D=A}B=v;y=(v|0)<0|0?-1:0;C=Erc(D,(D|0)<0|0?-1:0,B,y)|0;x=wrc(C,G,s,r)|0;C=G;E=wrc(B,y,u,t)|0;y=G;if(w>>>0<a>>>0){q=w;r=C;s=x;t=y;u=E}else{l=w;m=C;n=x;o=y;p=E;break a}}KIb(c[f>>2]|0,16,2149664,(z=i,i=i+8|0,c[z>>2]=v,z)|0);i=z;g=-1094995529;i=e;return g|0}}while(0);c[d+24>>2]=l;l=d+1248|0;z=wrc(c[l>>2]|0,c[l+4>>2]|0,n,m)|0;c[l>>2]=z;c[l+4>>2]=G;l=d+1244|0;z=wrc(c[l>>2]|0,0,p,o)|0;c[l>>2]=z;if((c[k>>2]|0)!=0){g=-541478725;i=e;return g|0}k=h+64|0;c[k>>2]=p;c[k+4>>2]=o;if(!((n|0)==0&(m|0)==0)){o=h+56|0;c[o>>2]=n;c[o+4>>2]=m}o=d+1224|0;c[o>>2]=n;c[o+4>>2]=m;g=0;i=e;return g|0}function qM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+8|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e|0;d=c[a+4>>2]|0;a=c[d+24>>2]|0;if((a|0)==0){i=e;return 0}g=c[(c[d+28>>2]|0)+(a-1<<2)>>2]|0;a=c[g+12>>2]|0;d=zD(b)|0;h=(ID(b)|0)&1;j=g+72|0;c[j>>2]=c[j>>2]|h;h=(d|0)==1;if(h){OD(b)|0;OD(b)|0;}else{JD(b)|0;JD(b)|0}c[g+4>>2]=JD(b)|0;JD(b)|0;if(h){OD(b)|0;}else{JD(b)|0}JD(b)|0;JD(b)|0;HD(b)|0;HD(b)|0;HD(b)|0;HD(b)|0;h=JD(b)|0;d=JD(b)|0;JD(b)|0;j=JD(b)|0;k=JD(b)|0;JD(b)|0;l=JD(b)|0;m=JD(b)|0;JD(b)|0;n=JD(b)|0;o=JD(b)|0;c[a+164>>2]=n>>16;c[a+168>>2]=o>>16;if((j|0)==-65536&(d|0)==65536){MGb(g+88|0,2158944,2156904,0)|0}if((h|0)==-65536&(k|0)==-65536){MGb(g+88|0,2158944,2155248,0)|0}if((j|0)==65536&(d|0)==-65536){MGb(g+88|0,2158944,2153512,0)|0}if((n|0)==0|(o|0)==0){i=e;return 0}if(!(((k|0)!=65536|(h|0)!=65536)&(d|0)==0&(j|0)==0&(l|0)==0&(m|0)==0)){i=e;return 0}m=Erc(h,(h|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;h=G;l=Erc(k,(k|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;AKb(f,+(o|0)*(+(m>>>0)+ +(h|0)*4294967296.0)/(+(n|0)*(+(l>>>0)+ +(G|0)*4294967296.0)),2147483647);l=g+80|0;g=c[f+4>>2]|0;c[l>>2]=c[f>>2];c[l+4>>2]=g;i=e;return 0}function rM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];zD(b)|0;f=ID(b)|0;d=JD(b)|0;if((d|0)==0){g=-1094995529;i=e;return g|0}c[a+48>>2]=d;h=c[a+92>>2]|0;j=a+88|0;k=0;while(1){if(!(k>>>0<h>>>0)){break}l=c[j>>2]|0;m=l+(k*20|0)|0;if((c[m>>2]|0)==(d|0)){n=5;break}else{k=k+1|0}}do{if((n|0)==5){if((m|0)==0){break}if((f&1|0)==0){d=a+64|0;o=c[d+4>>2]|0;p=c[d>>2]|0}else{d=OD(b)|0;o=G;p=d}d=a+56|0;c[d>>2]=p;c[d+4>>2]=o;if((f&2|0)==0){q=c[l+(k*20|0)+4>>2]|0}else{q=JD(b)|0}c[a+72>>2]=q;if((f&8|0)==0){r=c[l+(k*20|0)+8>>2]|0}else{r=JD(b)|0}c[a+76>>2]=r;if((f&16|0)==0){s=c[l+(k*20|0)+12>>2]|0}else{s=JD(b)|0}c[a+80>>2]=s;if((f&32|0)==0){t=c[l+(k*20|0)+16>>2]|0}else{t=JD(b)|0}c[a+84>>2]=t;g=0;i=e;return g|0}}while(0);KIb(c[a+4>>2]|0,16,2160648,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-1094995529;i=e;return g|0}function sM(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0;g=i;i=i+1032|0;h=f;f=i;i=i+16|0;c[f>>2]=c[h>>2];c[f+4>>2]=c[h+4>>2];c[f+8>>2]=c[h+8>>2];c[f+12>>2]=c[h+12>>2];h=g|0;j=g+1024|0;k=j;l=d+4|0;m=ZX(c[l>>2]|0,0)|0;if((m|0)==0){n=-12;i=g;return n|0}c[m+4>>2]=c[(c[l>>2]|0)+24>>2];o=pJb(1256)|0;if((o|0)==0){n=-12;i=g;return n|0}p=m+12|0;c[p>>2]=o;q=m+8|0;c[(c[q>>2]|0)+8>>2]=2;r=m|0;s=o+8|0;c[s>>2]=c[r>>2];t=BL(d,e,f)|0;if((t|0)<0){n=t;i=g;return n|0}a:do{if((c[o+16>>2]|0)!=0){do{if((c[o+24>>2]|0)!=0){if((c[o+40>>2]|0)==0){break}if((c[o+64>>2]|0)!=0){break a}if((c[o+72>>2]|0)!=0){break a}}}while(0);KIb(c[l>>2]|0,16,2189072,(u=i,i=i+8|0,c[u>>2]=c[r>>2],u)|0);i=u;n=0;i=g;return n|0}}while(0);t=o+92|0;f=c[t>>2]|0;do{if((f|0)<1){KIb(c[l>>2]|0,24,2599048,(u=i,i=i+8|0,c[u>>2]=c[s>>2],u)|0);i=u;e=c[d+8>>2]|0;c[t>>2]=e;if((e|0)>=1){v=e;break}c[t>>2]=1;v=1}else{v=f}}while(0);_X(m,64,1,v);v=c[p>>2]|0;p=v+96|0;f=c[p>>2]|0;s=c[p+4>>2]|0;e=(f|0)==0&(s|0)==0;if(e){w=v+104|0;if((c[w>>2]|0)==0&(c[w+4>>2]|0)==0){x=0;y=0}else{z=15}}else{z=15}do{if((z|0)==15){w=c[d+8>>2]|0;if((w|0)<=0){x=0;y=0;break}if(e){A=0;B=0}else{C=c[v+92>>2]|0;D=VIb(f,s,C,(C|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=G;c[p>>2]=D;c[p+4>>2]=w;A=w;B=D}D=v+104|0;w=xrc(c[D>>2]|0,c[D+4>>2]|0,B,A)|0;D=G;C=v+112|0;c[C>>2]=w;c[C+4>>2]=D;C=xrc(0,0,w,D)|0;D=G;if((c[v+32>>2]|0)==0){x=D;y=C;break}if((c[v+24>>2]|0)==0){x=D;y=C;break}w=c[(c[v+28>>2]|0)+4>>2]|0;if(((c[(c[v+36>>2]|0)+4>>2]|0)/(((w|0)>1?w:1)|0)|0|0)<=16){x=D;y=C;break}c[v+160>>2]=1;c[(c[q>>2]|0)+176>>2]=1;x=D;y=C}}while(0);b:do{if((c[(c[q>>2]|0)+8>>2]|0)==1){if((c[v+24>>2]|0)!=1){z=27;break}if((c[(c[v+28>>2]|0)+4>>2]|0)!=1){z=27;break}A=v+40|0;B=c[A>>2]|0;c:do{if((B|0)==0){E=0}else{p=c[v+44>>2]|0;s=v+16|0;f=B-1|0;e=c[v+128>>2]|0;C=e>>>0>159>>>0;D=e>>>0>1>>>0;w=(e|0)==0;F=0;H=0;d:while(1){I=c[p+(F*12|0)+4>>2]|0;do{if((F|0)==(f|0)){z=87}else{if(w){z=91;break}if(((I>>>0)%(e>>>0)|0|0)==0){z=87}else{break d}}}while(0);do{if((z|0)==87){z=0;if(C){J=(I>>>0)/(e>>>0)|0;break}if(!D){z=91;break}K=1024-(1024%(e>>>0)|0)|0;J=((I-1+K|0)>>>0)/(K>>>0)|0}}while(0);if((z|0)==91){z=0;J=(I+1023|0)>>>10}if(F>>>0<f>>>0){K=F+1|0;L=(c[p+(K*12|0)>>2]|0)-(c[p+(F*12|0)>>2]|0)|0;M=K}else{L=(c[s>>2]|0)+1-(c[p+(F*12|0)>>2]|0)|0;M=F+1|0}K=(ca(L,J)|0)+H|0;if(M>>>0<B>>>0){F=M;H=K}else{E=K;break c}}KIb(c[l>>2]|0,16,2165032,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break b}}while(0);B=m+404|0;H=c[B>>2]|0;if(!(E>>>0<(178956970-H|0)>>>0)){break}F=m+400|0;if((oJb(F,H+E|0,24)|0)<0){c[B>>2]=0;break}c[m+408>>2]=((c[B>>2]|0)+E|0)*24|0;H=v+16|0;p=c[H>>2]|0;if((p|0)==0){break}s=v+20|0;f=v+44|0;e=v+128|0;D=v+124|0;C=v+64|0;w=0;K=0;N=x;O=y;P=p;e:while(1){p=(c[s>>2]|0)+(w<<3)|0;Q=K+1|0;if(Q>>>0<(c[A>>2]|0)>>>0){R=c[f>>2]|0;S=(w+1|0)==(c[R+(Q*12|0)>>2]|0)?Q:K;T=R}else{S=K;T=c[f>>2]|0}R=c[T+(S*12|0)+4>>2]|0;if((R|0)==0){U=N;V=O;W=P}else{Q=R;R=N;X=O;Y=c[p+4>>2]|0;Z=c[p>>2]|0;while(1){p=c[e>>2]|0;do{if(p>>>0>159>>>0){_=p;$=c[D>>2]|0}else{if(p>>>0>1>>>0){aa=1024-(1024%(p>>>0)|0)|0;ba=aa>>>0>Q>>>0?Q:aa;_=ba;$=ca(c[D>>2]|0,(ba>>>0)/(p>>>0)|0)|0;break}else{ba=Q>>>0<1024>>>0?Q:1024;_=ba;$=ca(c[C>>2]|0,ba)|0;break}}}while(0);p=c[B>>2]|0;if(!(p>>>0<E>>>0)){break e}c[B>>2]=p+1;I=c[F>>2]|0;ba=I+(p*24|0)|0;c[ba>>2]=Z;c[ba+4>>2]=Y;ba=I+(p*24|0)+8|0;c[ba>>2]=X;c[ba+4>>2]=R;c[I+(p*24|0)+20>>2]=0;c[I+(p*24|0)+16>>2]=$<<2|1;p=wrc($,0,Z,Y)|0;I=G;da=wrc(_,0,X,R)|0;ea=G;if((Q|0)==(_|0)){break}else{Q=Q-_|0;R=ea;X=da;Y=I;Z=p}}U=ea;V=da;W=c[H>>2]|0}Z=w+1|0;if(Z>>>0<W>>>0){w=Z;K=S;N=U;O=V;P=W}else{break b}}KIb(c[l>>2]|0,16,2162824,(u=i,i=i+8|0,c[u>>2]=E,u)|0);i=u}else{z=27}}while(0);f:do{if((z|0)==27){E=v+1236|0;if((c[E>>2]|0)==0){fa=0}else{fa=(c[v+1240>>2]|0)!=0}W=v+84|0;if((c[W>>2]|0)==0){z=31}else{if((c[c[v+88>>2]>>2]|0)>0){ga=1}else{z=31}}do{if((z|0)==31){if((c[v+48>>2]|0)==0){ga=0;break}ga=(c[c[v+52>>2]>>2]|0)!=0|0}}while(0);V=c[v+172>>2]|0;U=xrc(y,x,V,(V|0)<0|0?-1:0)|0;V=G;S=v+72|0;da=c[S>>2]|0;if((da|0)==0){break}ea=m+404|0;_=c[ea>>2]|0;if(!((_|0)==0&da>>>0<(178956970-_|0)>>>0)){break}_=m+400|0;if((oJb(_,da,24)|0)<0){c[ea>>2]=0;break}c[m+408>>2]=((c[S>>2]|0)+(c[ea>>2]|0)|0)*24|0;da=v+16|0;$=c[da>>2]|0;g:do{if(($|0)==0){ha=0;ia=0}else{T=v+20|0;M=v+44|0;J=v+40|0;L=v+64|0;P=v+68|0;O=v+80|0;N=v+88|0;K=v+1240|0;w=v+76|0;H=v+136|0;F=v+28|0;B=v+24|0;C=v+48|0;D=v+52|0;e=0;f=0;A=0;s=0;Z=0;Y=0;X=0;R=0;Q=0;p=0;I=0;ba=0;aa=V;ja=U;ka=$;h:while(1){la=Z+1|0;ma=c[T>>2]|0;if(la>>>0<ka>>>0){na=ma+(la<<3)|0;oa=c[na+4>>2]|0;pa=c[na>>2]|0}else{oa=2147483647;pa=-1}na=ma+(Z<<3)|0;ma=c[na>>2]|0;qa=c[na+4>>2]|0;na=c[J>>2]|0;ra=I;while(1){sa=ra+1|0;if(!(sa>>>0<na>>>0)){break}if((la|0)==(c[(c[M>>2]|0)+(sa*12|0)>>2]|0)){ra=sa}else{break}}do{if((oa|0)>(qa|0)|(oa|0)==(qa|0)&pa>>>0>ma>>>0){na=c[L>>2]|0;if((na|0)==0){z=50;break}sa=c[P>>2]|0;if(!(na>>>0<sa>>>0)){ta=sa;break}na=c[(c[M>>2]|0)+(ra*12|0)+4>>2]|0;ua=Erc(na,(na|0)<0|0?-1:0,sa,0)|0;na=G;va=xrc(pa,oa,ma,qa)|0;wa=G;if(!((na|0)>(wa|0)|(na|0)==(wa|0)&ua>>>0>va>>>0)){z=50;break}KIb(c[l>>2]|0,24,2179520,(u=i,i=i+8|0,c[u>>2]=sa,u)|0);i=u;sa=c[L>>2]|0;c[P>>2]=sa;ta=sa}else{z=50}}while(0);if((z|0)==50){z=0;ta=c[P>>2]|0}do{if((ta|0)!=0){if(!(ta>>>0<(c[L>>2]|0)>>>0)){break}KIb(c[l>>2]|0,24,2177824,(u=i,i=i+8|0,c[u>>2]=ta,u)|0);i=u;c[P>>2]=c[L>>2]}}while(0);sa=c[M>>2]|0;i:do{if((c[sa+(ra*12|0)+4>>2]|0)==0){xa=e;ya=f;za=A;Aa=s;Ba=Y;Ca=X;Da=R;Ea=Q;Fa=p;Ga=ba;Ha=aa;Ia=ja}else{va=1;ua=e;wa=f;na=A;Ja=s;Ka=Y;La=X;Ma=R;Na=Q;Oa=p;Pa=ba;Qa=aa;Ra=ja;Sa=qa;Ta=ma;Ua=sa;while(1){if(!(na>>>0<(c[S>>2]|0)>>>0)){break h}Va=(c[O>>2]|0)==0;do{if(Va){Wa=c[W>>2]|0;if((Wa|0)!=0){if((na+ga|0)!=(c[(c[N>>2]|0)+(Oa<<2)>>2]|0)){z=61;break}}Xa=Oa+1|0;Ya=1;Za=Xa>>>0<Wa>>>0?Xa:Oa;_a=Na}else{z=61}}while(0);do{if((z|0)==61){z=0;Xa=c[C>>2]|0;if((Xa|0)==0){Ya=0;Za=Oa;_a=Na;break}if((na+ga|0)!=(c[(c[D>>2]|0)+(Na<<2)>>2]|0)){Ya=0;Za=Oa;_a=Na;break}Wa=Na+1|0;Ya=1;Za=Oa;_a=Wa>>>0<Xa>>>0?Wa:Na}}while(0);do{if(fa){if(!(La>>>0<(c[E>>2]|0)>>>0)){$a=Ya;ab=Ma;bb=La;break}Wa=c[K>>2]|0;Xa=Ma+1|0;cb=(Xa|0)==(c[Wa+(La<<3)>>2]|0);$a=(c[Wa+(La<<3)+4>>2]|0)==0?Ya:1;ab=cb?0:Xa;bb=(cb&1)+La|0}else{$a=Ya;ab=Ma;bb=La}}while(0);do{if(Va){db=$a}else{if((c[C>>2]|0)!=0|fa){db=$a;break}db=(c[(c[q>>2]|0)+8>>2]|0)==1?1:$a}}while(0);Va=(db|0)!=0;cb=Va?0:Ka;Xa=c[P>>2]|0;if((Xa|0)==0){eb=c[(c[w>>2]|0)+(na<<2)>>2]|0}else{eb=Xa}Xa=c[H>>2]|0;if((Xa|0)==-1){z=74}else{if(((c[Ua+(ra*12|0)+8>>2]|0)-1|0)==(Xa|0)){z=74}}do{if((z|0)==74){z=0;Xa=c[ea>>2]|0;c[ea>>2]=Xa+1;Wa=c[_>>2]|0;fb=Wa+(Xa*24|0)|0;c[fb>>2]=Ta;c[fb+4>>2]=Sa;fb=Wa+(Xa*24|0)+8|0;c[fb>>2]=Ra;c[fb+4>>2]=Qa;c[Wa+(Xa*24|0)+20>>2]=cb;c[Wa+(Xa*24|0)+16>>2]=eb<<2|Va&1;if((c[(c[q>>2]|0)+8>>2]|0)!=0){break}if((c[ea>>2]|0)>=100){break}RX(c[l>>2]|0,m,Ra,Qa)|0}}while(0);Va=eb;Xa=0;Wa=wrc(Va,Xa,Ta,Sa)|0;fb=G;gb=wrc(Va,Xa,wa,ua)|0;Xa=G;Va=c[F>>2]|0;hb=c[Va+(Pa<<3)+4>>2]|0;ib=wrc(hb,(hb|0)<0|0?-1:0,Ra,Qa)|0;hb=G;jb=cb+1|0;kb=Ja+1|0;lb=na+1|0;mb=Pa+1|0;if(mb>>>0<(c[B>>2]|0)>>>0){nb=(kb|0)==(c[Va+(Pa<<3)>>2]|0);ob=nb?mb:Pa;pb=nb?0:kb}else{ob=Pa;pb=kb}kb=c[M>>2]|0;if(!(va>>>0<(c[kb+(ra*12|0)+4>>2]|0)>>>0)){xa=Xa;ya=gb;za=lb;Aa=pb;Ba=jb;Ca=bb;Da=ab;Ea=_a;Fa=Za;Ga=ob;Ha=hb;Ia=ib;break i}va=va+1|0;ua=Xa;wa=gb;na=lb;Ja=pb;Ka=jb;La=bb;Ma=ab;Na=_a;Oa=Za;Pa=ob;Qa=hb;Ra=ib;Sa=fb;Ta=Wa;Ua=kb}}}while(0);sa=c[da>>2]|0;if(la>>>0<sa>>>0){e=xa;f=ya;A=za;s=Aa;Z=la;Y=Ba;X=Ca;R=Da;Q=Ea;p=Fa;I=ra;ba=Ga;aa=Ha;ja=Ia;ka=sa}else{ha=xa;ia=ya;break g}}KIb(c[l>>2]|0,16,2171488,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break f}}while(0);da=m+56|0;ea=c[da>>2]|0;_=c[da+4>>2]|0;da=0;if(!((_|0)>(da|0)|(_|0)==(da|0)&ea>>>0>0>>>0)){break}da=c[v+92>>2]|0;E=Erc(ia<<3|0>>>29,ha<<3|ia>>>29,da,(da|0)<0|0?-1:0)|0;da=Frc(E,G,ea,_)|0;c[(c[q>>2]|0)+72>>2]=da}}while(0);ia=(c[o+152>>2]|0)-1|0;j:do{if(ia>>>0<(c[o+144>>2]|0)>>>0){ha=c[o+148>>2]|0;v=ha+(ia*108|0)+4|0;ya=c[v>>2]|0;if((ya|0)==0){z=133;break}xa=o;Ia=c[l>>2]|0;Ha=Ia+32|0;Ga=Ia+1160|0;Fa=c[d+104>>2]|0;Ea=h|0;Da=ha+(ia*108|0)+104|0;Ca=b[Da>>1]|0;do{if(Ca<<16>>16>0){Ba=ha+(ia*108|0)+106|0;Aa=b[Ba>>1]|0;if(!(Aa<<16>>16>0)){z=130;break}za=hc(Ha|0,47)|0;ob=(za|0)==0?Ha:za+1|0;za=(Ca<<16>>16)-1|0;Za=lrc(ya|0)|0;_a=0;k:while(1){qb=Za;while(1){rb=qb-1|0;if(!((rb|0)>-1)){z=124;break k}if((a[ya+rb|0]|0)==47){break}else{qb=rb}}if((_a|0)==(za|0)){break}else{Za=rb;_a=_a+1|0}}if((z|0)==124){if((_a|0)!=(za|0)){break}}Za=ob-Ha|0;if(!(Za>>>0<1024>>>0)){break}nrc(Ea|0,Ha|0,Za)|0;a[h+Za|0]=0;if(Aa<<16>>16>1){Za=1;do{DFb(Ea,2183992,1024)|0;Za=Za+1|0;}while((Za|0)<(b[Ba>>1]|0));sb=c[v>>2]|0}else{sb=ya}DFb(Ea,sb+qb|0,1024)|0;if((VD(xa,Ea,1,Ga,0)|0)==0){break j}}else{z=130}}while(0);do{if((z|0)==130){if((Fa|0)==0){break}KIb(Ia,24,2181744,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;if((VD(xa,c[v>>2]|0,1,Ga,0)|0)==0){break j}}}while(0);Ga=c[v>>2]|0;xa=c[ha+(ia*108|0)+8>>2]|0;Ia=b[ha+(ia*108|0)+106>>1]|0;Fa=b[Da>>1]|0;KIb(c[l>>2]|0,16,2186208,(u=i,i=i+56|0,c[u>>2]=c[r>>2],c[u+8>>2]=Ga,c[u+16>>2]=xa,c[u+24>>2]=ha+(ia*108|0)+40,c[u+32>>2]=ha+(ia*108|0)+12,c[u+40>>2]=Ia,c[u+48>>2]=Fa,u)|0);i=u}else{z=133}}while(0);if((z|0)==133){c[o>>2]=c[(c[l>>2]|0)+16>>2];c[o+4>>2]=1}l=c[q>>2]|0;do{if((c[l+8>>2]|0)==0){z=m+80|0;do{if((c[z>>2]|0)==0){u=c[l+120>>2]|0;ia=c[o+164>>2]|0;r=c[l+124>>2]|0;qb=c[o+168>>2]|0;if((u|0)==(ia|0)&(r|0)==(qb|0)){break}AKb(k,+(r|0)*+(ia|0)/(+(u|0)*+(qb|0)),2147483647);qb=z;u=c[j+4>>2]|0;c[qb>>2]=c[j>>2];c[qb+4>>2]=u}}while(0);z=c[o+24>>2]|0;if((z|0)==1){tb=c[o+28>>2]|0}else if((z|0)==2){z=c[o+28>>2]|0;if((c[z+8>>2]|0)==1){tb=z}else{break}}else{break}z=c[t>>2]|0;ha=c[tb+4>>2]|0;xKb(m+412|0,m+416|0,z,(z|0)<0|0?-1:0,ha,(ha|0)<0|0?-1:0,2147483647,0)|0}}while(0);tb=c[q>>2]|0;do{if((c[tb+100>>2]|0)==0){if((c[tb+48>>2]|0)!=28){ub=tb;break}t=c[tb+52>>2]|0;if(!((t|0)==1882548577|(t|0)==1899325793|(t|0)==842361185|(t|0)==859138401|(t|0)==892692833|(t|0)==909470049|(t|0)==1882286433|(t|0)==1899063649|(t|0)==842099041|(t|0)==858876257|(t|0)==892430689|(t|0)==909207905|(t|0)==1852397121)){ub=tb;break}t=wY(m)|0;if((t|0)<0){n=t;i=g;return n|0}else{ub=c[q>>2]|0;break}}else{ub=tb}}while(0);tb=c[ub+48>>2]|0;if((tb|0)==4|(tb|0)==5|(tb|0)==13){c[ub+120>>2]=0;c[ub+124>>2]=0}mJb(o+20|0);mJb(o+44|0);mJb(o+76|0);mJb(o+88|0);mJb(o+28|0);mJb(o+52|0);mJb(o+1240|0);n=0;i=g;return n|0}function tM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=-1094995529;i=e;return g|0}d=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;c[d+156>>2]=JD(b)|0;g=0;i=e;return g|0}function uM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];c[a+100>>2]=JD(b)|0;i=e;return 0}function vM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+92|0;d=c[f>>2]|0;g=wrc(d,0,1,0)|0;h=G;j=0;if(h>>>0>j>>>0|h>>>0==j>>>0&g>>>0>214748363>>>0){k=-1094995529;i=e;return k|0}g=a+88|0;j=oJb(g,d+1|0,20)|0;if((j|0)<0){c[f>>2]=0;k=j;i=e;return k|0}else{j=(c[a+4>>2]|0)+1064|0;c[j>>2]=0;c[j+4>>2]=-2147483648;j=c[f>>2]|0;c[f>>2]=j+1;f=c[g>>2]|0;zD(b)|0;ID(b)|0;c[f+(j*20|0)>>2]=JD(b)|0;c[f+(j*20|0)+4>>2]=JD(b)|0;c[f+(j*20|0)+8>>2]=JD(b)|0;c[f+(j*20|0)+12>>2]=JD(b)|0;c[f+(j*20|0)+16>>2]=JD(b)|0;k=0;i=e;return k|0}return 0}function wM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+84|0;d=c[f>>2]|0;g=c[a+4>>2]|0;h=c[g+24>>2]|0;j=g+28|0;k=a+48|0;l=0;while(1){if(!(l>>>0<h>>>0)){m=5;break}n=c[(c[j>>2]|0)+(l<<2)>>2]|0;o=c[n+4>>2]|0;if((o|0)==(c[k>>2]|0)){m=4;break}else{l=l+1|0}}do{if((m|0)==4){if((n|0)==0){p=o;break}l=c[n+12>>2]|0;j=c[l+136>>2]|0;if(!((j+1|0)==(c[a+72>>2]|0)|(j|0)==-1)){q=0;i=e;return q|0}zD(b)|0;j=ID(b)|0;h=JD(b)|0;r=l+32|0;s=c[r>>2]|0;do{if((s|0)==0){t=l+72|0;if((c[t>>2]|0)==0){u=0;break}v=iJb(0,8)|0;w=v;if((v|0)==0){q=-12;i=e;return q|0}else{c[l+36>>2]=w;c[w+(c[r>>2]<<3)>>2]=c[t>>2];c[w+(c[r>>2]<<3)+4>>2]=0;w=(c[r>>2]|0)+1|0;c[r>>2]=w;u=w;break}}else{u=s}}while(0);s=wrc(u,0,h,0)|0;w=G;t=0;if(w>>>0>t>>>0|w>>>0==t>>>0&s>>>0>536870910>>>0){q=-1094995529;i=e;return q|0}s=l+36|0;t=s;w=oJb(s,u+h|0,8)|0;if((w|0)<0){c[r>>2]=0;q=w;i=e;return q|0}if((j&1|0)==0){x=0;y=0}else{w=JD(b)|0;x=(w|0)<0|0?-1:0;y=w}if((j&4|0)==0){z=d}else{z=JD(b)|0}w=l+1224|0;s=l+112|0;v=xrc(c[w>>2]|0,c[w+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;A=G;B=a+56|0;C=wrc(c[B>>2]|0,c[B+4>>2]|0,y,x)|0;B=G;D=b+52|0;a:do{if((h|0)==0){E=A;F=v;H=B;I=C}else{J=a+80|0;K=a+76|0;L=(j&256|0)==0;M=(j&512|0)==0;N=(j&1024|0)==0;O=(j&2048|0)==0;P=l+172|0;Q=n+8|0;R=l+1208|0;S=l+1248|0;T=l+1244|0;U=A;V=v;W=B;X=C;Y=0;Z=0;_=0;while(1){if((c[D>>2]|0)!=0){q=-541478725;break}$=c[J>>2]|0;if((Z|0)==0){aa=z}else{aa=c[f>>2]|0}if(L){ba=c[K>>2]|0}else{ba=JD(b)|0}if(M){ca=$}else{ca=JD(b)|0}if(N){da=aa}else{da=JD(b)|0}$=c[t>>2]|0;c[$+(c[r>>2]<<3)>>2]=1;if(O){ea=0;fa=$}else{$=JD(b)|0;ea=$;fa=c[t>>2]|0}c[fa+(c[r>>2]<<3)+4>>2]=ea;$=c[r>>2]|0;ga=c[fa+($<<3)+4>>2]|0;if((ga|0)<0){ha=c[P>>2]|0;ia=-ga|0;c[P>>2]=(ha|0)>(ia|0)?ha:ia}c[r>>2]=$+1;do{if((c[(c[Q>>2]|0)+8>>2]|0)==1){ja=1;ka=_}else{if((_|0)!=0){ja=0;ka=_;break}$=(da&16842752|0)==0;ja=$;ka=$&1}}while(0);$=ja?0:Y;xX(n,X,W,V,U,ca,$,ja&1)|0;ia=ba;ha=0;ga=wrc(ia,ha,V,U)|0;la=G;ma=ca;na=0;oa=wrc(ma,na,X,W)|0;pa=G;qa=wrc(c[R>>2]|0,c[R+4>>2]|0,ma,na)|0;c[R>>2]=qa;c[R+4>>2]=G;qa=wrc(c[S>>2]|0,c[S+4>>2]|0,ia,ha)|0;c[S>>2]=qa;c[S+4>>2]=G;c[T>>2]=(c[T>>2]|0)+1;qa=Z+1|0;if(qa>>>0<h>>>0){U=la;V=ga;W=pa;X=oa;Y=$+1|0;Z=qa;_=ka}else{E=la;F=ga;H=pa;I=oa;break a}}i=e;return q|0}}while(0);if((c[D>>2]|0)!=0){q=-541478725;i=e;return q|0}h=a+64|0;c[h>>2]=I;c[h+4>>2]=H;h=wrc(c[s>>2]|0,c[s+4>>2]|0,F,E)|0;r=G;c[w>>2]=h;c[w+4>>2]=r;t=n+56|0;c[t>>2]=h;c[t+4>>2]=r;q=0;i=e;return q|0}else if((m|0)==5){p=c[k>>2]|0}}while(0);KIb(g,16,2191448,(g=i,i=i+8|0,c[g>>2]=p,g)|0);i=g;q=-1094995529;i=e;return q|0}function xM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;g=c[f+24>>2]|0;if((g|0)==0){h=0;i=e;return h|0}j=d+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=0;if(l>>>0>j>>>0|l>>>0==j>>>0&k>>>0>1073741824>>>0){h=-1094995529;i=e;return h|0}j=(c[(c[f+28>>2]|0)+(g-1<<2)>>2]|0)+8|0;g=c[j>>2]|0;f=c[g+48>>2]|0;do{if((f|0)==86035|(f|0)==86067|(f|0)==86052){kJb(c[g+96>>2]|0);if((QX(c[j>>2]|0,b,k)|0)<0){h=-12}else{break}i=e;return h|0}else{m=0;if(!((l|0)>(m|0)|(l|0)==(m|0)&k>>>0>8>>>0)){hD(b,k,l)|0;break}m=BL(a,b,d)|0;if((m|0)<0){h=m}else{break}i=e;return h|0}}while(0);h=0;i=e;return h|0}function yM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];yL(c[a+4>>2]|0,b,d)|0;i=e;return 0}function zM(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+32|0;g=d;d=i;i=i+16|0;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];c[d+8>>2]=c[g+8>>2];c[d+12>>2]=c[g+12>>2];g=f|0;d=c[a+4>>2]|0;a=c[d+24>>2]|0;if((a|0)==0){i=f;return 0}h=c[(c[d+28>>2]|0)+(a-1<<2)>>2]|0;a=ID(b)|0;b=a>>>14&7;d=a>>>11&7;j=a>>>10&1;c[g>>2]=2;c[g+4>>2]=1;c[g+8>>2]=2;c[g+12>>2]=3;c[g+16>>2]=3;c[g+20>>2]=4;c[g+24>>2]=4;c[g+28>>2]=5;a=j+(c[g+(d<<2)>>2]|0)|0;g=c[h+8>>2]|0;c[g+416>>2]=a;h=e[1967928+(d<<1)>>1]|0;d=0;k=g+448|0;l=(j|0)==0;c[k>>2]=l?h:h|8;c[k+4>>2]=l?d:d|0;d=g+464|0;c[d>>2]=b;if(!((a|0)>1&(b|0)==7)){i=f;return 0}c[d>>2]=8;i=f;return 0}function AM(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=d;d=i;i=i+16|0;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];c[d+8>>2]=c[g+8>>2];c[d+12>>2]=c[g+12>>2];g=c[a+4>>2]|0;a=c[g+24>>2]|0;if((a|0)==0){i=f;return 0}d=c[(c[g+28>>2]|0)+(a-1<<2)>>2]|0;HD(b)|0;a=ID(b)|0;b=a>>>12&31;g=e[1967928+((a>>>9&7)<<1)>>1]|0;h=0;j=d+8|0;d=(c[j>>2]|0)+448|0;k=(a&256|0)==0;a=k?g:g|8;g=k?h:h|0;c[d>>2]=a;c[d+4>>2]=g;d=rGb(a,g)|0;g=c[j>>2]|0;c[g+416>>2]=d;j=g+464|0;c[j>>2]=b;if(!((d|0)>1&(b|0)==7)){i=f;return 0}c[j>>2]=8;i=f;return 0}function BM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=d+8|0;g=c[f>>2]|0;h=c[f+4>>2]|0;j=0;if((h|0)<(j|0)|(h|0)==(j|0)&g>>>0<8>>>0){i=e;return 0}if((JD(b)|0)!=0){j=wrc(g,h,-4,-1)|0;hD(b,j,G)|0;i=e;return 0}j=FD(b)|0;c[d>>2]=j;d=wrc(g,h,-8,-1)|0;h=G;c[f>>2]=d;c[f+4>>2]=h;if((j|0)!=1952539757){hD(b,d,h)|0;i=e;return 0}if((d|0)==0&(h|0)==0){i=e;return 0}c[a+28>>2]=1;i=e;return 0}function CM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;a=c[f>>2]|0;g=c[a+24>>2]|0;if((g|0)==0){i=e;return 0}if((OS(b,c[(c[(c[a+28>>2]|0)+(g-1<<2)>>2]|0)+8>>2]|0,c[d+8>>2]|0)|0)>=0){i=e;return 0}KIb(c[f>>2]|0,24,2193928,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=e;return 0}function DM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+136|0;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=e|0;g=e+128|0;JD(b)|0;if((FD(b)|0)!=1836016484){h=-1094995529;i=e;return h|0}if((FD(b)|0)!=1651076218){KIb(c[a+4>>2]|0,16,2196688,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-1094995529;i=e;return h|0}JD(b)|0;if((FD(b)|0)!=1685482851){h=-1094995529;i=e;return h|0}j=JD(b)|0;c[g>>2]=j;k=d+8|0;l=wrc(c[k>>2]|0,c[k+4>>2]|0,-24,0)|0;m=l;l=hJb(m)|0;if((l|0)==0){h=-12;i=e;return h|0}n=hJb(j)|0;if((n|0)==0){kJb(l);h=-12;i=e;return h|0}AD(b,l,m)|0;do{if((Aqc(n,g,l,m)|0)==0){if(($C(f,n,c[g>>2]|0,0,0,0,0,0)|0)!=0){o=-1;break}c[d>>2]=1987014509;b=c[g>>2]|0;c[k>>2]=b;c[k+4>>2]=(b|0)<0|0?-1:0;o=BL(a,f,d)|0}else{o=-1}}while(0);kJb(n);kJb(l);h=o;i=e;return h|0}function EM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=a+4|0;a=c[f>>2]|0;g=c[a+24>>2]|0;if((g|0)==0){i=e;return 0}h=d+8|0;d=c[h>>2]|0;j=c[h+4>>2]|0;h=0;if((j|0)<(h|0)|(j|0)==(h|0)&d>>>0<16>>>0){i=e;return 0}h=c[(c[a+28>>2]|0)+(g-1<<2)>>2]|0;hD(b,4,0)|0;g=c[f>>2]|0;f=wrc(d,j,-4,-1)|0;LM(g,b,h,f,G)|0;i=e;return 0}function FM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}h=c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0;a=d+8|0;d=c[a>>2]|0;f=c[a+4>>2]|0;a=wrc(d,f,-7,-1)|0;j=G;k=0;if(j>>>0>k>>>0|j>>>0==k>>>0&a>>>0>268435448>>>0){g=-1094995529;i=e;return g|0}if(((zD(b)|0)&240|0)!=192){g=0;i=e;return g|0}fD(b,6,0,1)|0;a=h+8|0;kJb(c[(c[a>>2]|0)+96>>2]|0);h=c[a>>2]|0;a=wrc(d,f,-7,0)|0;f=QX(h,b,a)|0;g=(f|0)<0?f:0;i=e;return g|0}function GM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=i;i=i+16|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];c[d+8>>2]=c[f+8>>2];c[d+12>>2]=c[f+12>>2];f=c[a+4>>2]|0;a=c[f+24>>2]|0;if((a|0)==0){g=0;i=e;return g|0}d=c[(c[(c[f+28>>2]|0)+(a-1<<2)>>2]|0)+12>>2]|0;a=zD(b)|0;ID(b)|0;if((FD(b)|0)!=544235890){g=0;i=e;return g|0}if((a&255|0)==1){JD(b)|0}a=JD(b)|0;if((a|0)==0){g=0;i=e;return g|0}if(a>>>0>536870910>>>0){g=-1094995529;i=e;return g|0}f=hJb(a<<3)|0;h=d+1240|0;c[h>>2]=f;if((f|0)==0){g=-12;i=e;return g|0}f=b+52|0;j=0;while(1){if((c[f>>2]|0)!=0){k=j;break}l=JD(b)|0;c[(c[h>>2]|0)+(j<<3)>>2]=l;l=JD(b)|0;c[(c[h>>2]|0)+(j<<3)+4>>2]=l;l=j+1|0;if(l>>>0<a>>>0){j=l}else{k=l;break}}c[d+1236>>2]=k;g=(c[f>>2]|0)!=0?-541478725:0;i=e;return g|0}function HM(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+24|0;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=f+16|0;h=e+8|0;e=c[h>>2]|0;j=c[h+4>>2]|0;h=0;if((j|0)<(h|0)|(j|0)==(h|0)&e>>>0<16>>>0|(e|0)==(-1|0)&(j|0)==2147483647){k=-1094995529;i=f;return k|0}h=f|0;l=AD(d,h,16)|0;if((l|0)<0){k=l;i=f;return k|0}if((l|0)!=16){k=-1094995529;i=f;return k|0}if((grc(h,822600,16)|0)!=0){k=0;i=f;return k|0}h=wrc(e,j,-16,0)|0;j=h;if(j>>>0<4>>>0){k=-1094995529;i=f;return k|0}hD(d,4,0)|0;h=j-4|0;e=pJb(j-3|0)|0;if((e|0)==0){k=-12;i=f;return k|0}j=AD(d,e,h)|0;if((j|0)<0){kJb(e);k=j;i=f;return k|0}if((j|0)!=(h|0)){kJb(e);k=-1094995529;i=f;return k|0}h=BFb(e,2203248)|0;a:do{if((h|0)!=0){j=b+124|0;d=b+120|0;l=h;while(1){m=l+15|0;n=(c[j>>2]|0)+1|0;c[j>>2]=n;o=jJb(c[d>>2]|0,n,4)|0;c[d>>2]=o;if((o|0)==0){break}o=pd()|0;c[o>>2]=0;n=rb(m|0,g|0,10)|0;do{if((n|0)<0){p=18}else{if((c[o>>2]|0)!=0){p=18;break}if((a[c[g>>2]|0]|0)!=34){p=18;break}c[(c[d>>2]|0)+((c[j>>2]|0)-1<<2)>>2]=n}}while(0);if((p|0)==18){p=0;c[(c[d>>2]|0)+((c[j>>2]|0)-1<<2)>>2]=0}l=BFb(m,2203248)|0;if((l|0)==0){break a}}c[j>>2]=0;kJb(e);k=-12;i=f;return k|0}}while(0);kJb(e);k=0;i=f;return k|0}function IM(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=e;e=i;i=i+16|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];c[e+12>>2]=c[g+12>>2];g=e+8|0;h=JM(a,b,c[e>>2]|0,c[g>>2]|0,c[g+4>>2]|0,1412575542)|0;if((h|0)!=0){i=f;return h|0}g=c[a+4>>2]|0;a=c[g+24>>2]|0;if((a|0)==0){i=f;return h|0}e=c[(c[(c[g+28>>2]|0)+(a-1<<2)>>2]|0)+8>>2]|0;if((c[e+100>>2]|0)<=39){i=f;return h|0}a=c[e+96>>2]|0;g=a+36|0;c[e+124>>2]=(he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;g=a+38|0;c[e+120>>2]=(he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535;i=f;return h|0}function JM(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;k=b+4|0;b=c[k>>2]|0;l=c[b+24>>2]|0;if((l|0)==0){m=0;i=j;return m|0}n=(c[(c[b+28>>2]|0)+(l-1<<2)>>2]|0)+8|0;l=c[n>>2]|0;if((c[l+48>>2]|0)!=(h|0)){m=0;i=j;return m|0}h=c[l+100>>2]|0;b=wrc(h,(h|0)<0|0?-1:0,f,g)|0;h=G;o=wrc(b,h,8,0)|0;p=wrc(b,h,24,0)|0;h=G;b=0;q=0;if(h>>>0>b>>>0|h>>>0==b>>>0&p>>>0>2147483647>>>0|(g>>>0>q>>>0|g>>>0==q>>>0&f>>>0>2147483647>>>0)){m=-1094995529;i=j;return m|0}q=lJb(l+96|0,p)|0;p=c[n>>2]|0;if((q|0)<0){c[p+100>>2]=0;m=q;i=j;return m|0}q=c[p+96>>2]|0;l=p+100|0;p=c[l>>2]|0;c[l>>2]=o;o=wrc(f,g,8,0)|0;l=q+p|0;y=je(o|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=q+(p+4)|0;y=e;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=p+8|0;p=AD(d,q+l|0,f)|0;if((p|0)<0){m=p;i=j;return m|0}d=p;e=(p|0)<0|0?-1:0;if((e|0)<(g|0)|(e|0)==(g|0)&d>>>0<f>>>0){KIb(c[k>>2]|0,24,2210560,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;k=(c[n>>2]|0)+100|0;n=c[k>>2]|0;o=xrc(d,e,f,g)|0;g=wrc(o,G,n,0)|0;c[k>>2]=g}mrc(q+(p+l)|0,0,16)|0;m=0;i=j;return m|0}function KM(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=0;while(1){if((f|0)==15){break}if((c[823936+(f<<3)>>2]|0)==(a|0)){g=4;break}else{f=f+1|0}}a:do{if((g|0)==4){a=c[823940+(f<<3)>>2]|0;h=rGb(b,d)|0;i=(h|0)>9?0:h;h=c[826264+(i<<2)>>2]|0;j=c[a>>2]|0;if((j|0)==0){break}k=h|0;l=0;m=j;b:while(1){c:do{if((m&65535|0)==(i|0)){j=c[k>>2]|0;if((j|0)==0){break}else{n=0;o=j}while(1){if((o|0)==(m|0)){j=h+(n<<4)+8|0;if((c[j>>2]|0)==(b|0)&(c[j+4>>2]|0)==(d|0)){break}}n=n+1|0;o=c[h+(n<<4)>>2]|0;if((o|0)==0){break c}}if((m|0)!=0){p=m;q=0;break b}}}while(0);l=l+1|0;m=c[a+(l<<2)>>2]|0;if((m|0)==0){break a}}c[e>>2]=q;return p|0}}while(0);o=0;n=((b|0)!=0|(d|0)!=0)&(d>>>0<o>>>0|d>>>0==o>>>0&b>>>0<262144>>>0);p=n?65536:0;q=n?b:0;c[e>>2]=q;return p|0}function LM(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=0;if((f|0)<(a|0)|(f|0)==(a|0)&e>>>0<12>>>0){g=-1094995529;return g|0}a=JD(b)|0;h=JD(b)|0;i=JD(b)|0;j=Erc(i,0,20,0)|0;k=wrc(j,G,12,0)|0;j=G;if(j>>>0>f>>>0|j>>>0==f>>>0&k>>>0>e>>>0){g=0;return g|0}a:do{if((i|0)==0){l=f;m=e;n=0;o=12}else{if((a|0)==0){p=0;q=0;r=f;s=e}else{k=0;j=f;t=e;while(1){JD(b)|0;JD(b)|0;FD(b)|0;FD(b)|0;FD(b)|0;u=wrc(t,j,-20,-1)|0;v=G;w=k+1|0;if(w>>>0<i>>>0){k=w;j=v;t=u}else{l=v;m=u;n=0;o=12;break a}}}while(1){t=JD(b)|0;JD(b)|0;FD(b)|0;FD(b)|0;FD(b)|0;j=wrc(s,r,-20,-1)|0;k=G;if((t|0)==0){x=k;y=j;break a}do{if(t>>>0<19>>>0){z=1<<t-1}else{if((t|0)==38){z=536870912;break}else if((t|0)!=39){l=k;m=j;n=0;o=12;break a}z=1073741824}}while(0);t=z|p;u=q+1|0;if(u>>>0<i>>>0){p=t;q=u;r=k;s=j}else{l=k;m=j;n=t;o=12;break}}}}while(0);do{if((o|0)==12){if((a|0)==65536){s=h>>>0<262144>>>0;A=s?0:0;B=s?h:0}else if((a|0)==0){if((n|0)==0){x=l;y=m;break}s=(c[d+8>>2]|0)+448|0;c[s>>2]=n;c[s+4>>2]=0;x=l;y=m;break}else{s=a&65535;r=c[826264+((s>>>0>9>>>0?0:s)<<2)>>2]|0;s=0;while(1){q=c[r+(s<<4)>>2]|0;if((q|0)==0|(q|0)==(a|0)){break}else{s=s+1|0}}q=r+(s<<4)+8|0;A=c[q+4>>2]|0;B=c[q>>2]|0}q=(c[d+8>>2]|0)+448|0;c[q>>2]=B;c[q+4>>2]=A;x=l;y=m}}while(0);m=wrc(y,x,-12,-1)|0;hD(b,m,G)|0;g=0;return g|0}function MM(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[b+12>>2]|0;l=c[b+16>>2]|0;m=f+32|0;n=c[m>>2]|0;o=c[k+48>>2]|0;p=c[o+(n<<8)+76>>2]|0;q=f+28|0;c[h>>2]=c[q>>2];c[j>>2]=0;r=o+(n<<8)+4|0;s=c[r>>2]|0;do{if((s|0)!=0){t=f+16|0;u=c[t>>2]|0;v=c[t+4>>2]|0;w=o+(n<<8)+88|0;x=(c[w>>2]|0)+((s-1|0)*40|0)+8|0;y=xrc(u,v,c[x>>2]|0,c[x+4>>2]|0)|0;x=G;z=0;if(!(x>>>0>z>>>0|x>>>0==z>>>0&y>>>0>2147483647>>>0)){break}KIb(b,16,2155520,(A=i,i=i+32|0,c[A>>2]=y,c[A+8>>2]=x,c[A+16>>2]=u,c[A+24>>2]=v,A)|0);i=A;v=(c[w>>2]|0)+(((c[r>>2]|0)-1|0)*40|0)+8|0;w=wrc(c[v>>2]|0,c[v+4>>2]|0,1,0)|0;c[t>>2]=w;c[t+4>>2]=G;t=f+8|0;c[t>>2]=0;c[t+4>>2]=-2147483648}}while(0);s=k+52|0;do{if((c[s>>2]&2|0)==0){B=l}else{if((c[k+72>>2]|0)>0){t=o+(n<<8)+180|0;w=c[t>>2]|0;if((w|0)!=0){B=w;break}w=_D(t)|0;if((w|0)<0){C=w;i=g;return C|0}else{B=c[t>>2]|0;break}}else{t=k+92|0;w=c[t>>2]|0;if((w|0)!=0){B=w;break}w=_D(t)|0;if((w|0)<0){C=w;i=g;return C|0}else{B=c[t>>2]|0;break}}}}while(0);l=p+48|0;t=c[l>>2]|0;do{if((t|0)==69638|(t|0)==69633){D=c[p+424>>2]|0}else if((t|0)==73728){w=c[h>>2]|0;if((w|0)<=0){D=0;break}v=c[f+24>>2]|0;u=0;x=0;do{x=(e[1351656+(((d[v+x|0]|0)>>>3&15)<<1)>>1]|0)+x|0;u=u+1|0;}while((x|0)<(w|0)&u>>>0<100>>>0);if(!(u>>>0>1>>>0)){D=u;break}KIb(b,16,2492864,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;C=-1;i=g;return C|0}else{w=c[o+(n<<8)+40>>2]|0;if((w|0)==0){D=1;break}D=(c[h>>2]|0)/(w|0)|0}}while(0);w=o+(n<<8)+80|0;do{if((c[w>>2]|0)==0){x=c[p+100>>2]|0;if((x|0)<=0){E=t;break}c[w>>2]=x;v=hJb(x)|0;c[o+(n<<8)+84>>2]=v;nrc(v|0,c[p+96>>2]|0,c[w>>2]|0)|0;E=c[l>>2]|0}else{E=t}}while(0);do{if((E|0)==86018){if((c[q>>2]|0)<=2){F=45;break}t=c[f+24>>2]|0;if(!(((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&-16)<<16>>16==-16)){F=45;break}t=(c[(c[b+28>>2]|0)+(c[m>>2]<<2)>>2]|0)+64|0;p=b;if(!((c[t>>2]|0)==0&(c[t+4>>2]|0)==0)){KIb(p,24,2319288,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;H=c[l>>2]|0;F=30;break}KIb(p,16,2391592,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;C=-1;i=g;return C|0}else{H=E;F=30}}while(0);a:do{if((F|0)==30){do{if((H|0)==28){if((c[w>>2]|0)<=0){F=45;break a}if((a[c[o+(n<<8)+84>>2]|0]|0)==1){if((H|0)==1211250229){break}else{F=45;break a}}E=c[o+(n<<8)+120>>2]|0;do{if((E|0)>-1){if((E|0)>=(c[k+16>>2]|0)){break}p$(c[f+24>>2]|0,j,h)|0;dD(B,c[j>>2]|0,c[h>>2]|0);break a}}while(0);c[h>>2]=o$(B,c[f+24>>2]|0,c[q>>2]|0)|0;break a}else if((H|0)!=1211250229){F=45;break a}}while(0);if((c[w>>2]|0)<=6){F=45;break}u=c[o+(n<<8)+84>>2]|0;if((d[u+1|0]<<8|d[u]<<16|d[u+2|0]|0)!=1){E=u;if((d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)!=16777216){F=45;break}}E=c[o+(n<<8)+120>>2]|0;do{if((E|0)>-1){if((E|0)>=(c[k+16>>2]|0)){break}v$(c[f+24>>2]|0,j,h,0,0)|0;dD(B,c[j>>2]|0,c[h>>2]|0);break a}}while(0);c[h>>2]=u$(B,c[f+24>>2]|0,c[q>>2]|0,0,0)|0}}while(0);if((F|0)==45){dD(B,c[f+24>>2]|0,c[h>>2]|0)}H=c[l>>2]|0;do{if((H|0)==100|(H|0)==86019){if((c[w>>2]|0)!=0){break}c[w>>2]=c[h>>2];E=hJb(c[h>>2]|0)|0;c[o+(n<<8)+84>>2]=E;if((E|0)==0){C=-12;i=g;return C|0}else{nrc(E|0,c[f+24>>2]|0,c[h>>2]|0)|0;break}}}while(0);w=c[r>>2]|0;H=o+(n<<8)+92|0;do{if(w>>>0<(c[H>>2]|0)>>>0){I=o+(n<<8)+88|0}else{E=(w<<1)+2048|0;u=o+(n<<8)+88|0;if((oJb(u,E,40)|0)==0){c[H>>2]=E;I=u;break}else{C=-12;i=g;return C|0}}}while(0);H=fD(B,0,0,1)|0;B=c[h>>2]|0;w=xrc(H,G,B,(B|0)<0|0?-1:0)|0;B=c[r>>2]|0;H=c[I>>2]|0;u=H+(B*40|0)|0;c[u>>2]=w;c[u+4>>2]=G;c[H+(B*40|0)+20>>2]=D;c[H+((c[r>>2]|0)*40|0)+24>>2]=0;c[H+((c[r>>2]|0)*40|0)+16>>2]=c[h>>2];c[H+((c[r>>2]|0)*40|0)+28>>2]=D;B=f+16|0;u=c[B+4>>2]|0;w=c[r>>2]|0;E=H+(w*40|0)+8|0;c[E>>2]=c[B>>2];c[E+4>>2]=u;u=o+(n<<8)+112|0;do{if((w|0)==0){E=c[u>>2]|0;m=c[u+4>>2]|0;if(!((E|0)==0&(m|0)==(-2147483648|0))){p=o+(n<<8)+24|0;t=wrc(c[p>>2]|0,c[p+4>>2]|0,E,m)|0;m=H+8|0;c[m>>2]=t;c[m+4>>2]=G;if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==(-2147483648|0))){break}}m=c[k+96>>2]|0;if((m|0)<0){if((c[s>>2]&2|0)==0){break}}else{if((m|0)>0){break}}c[u>>2]=0;c[u+4>>2]=0;m=H+8|0;c[m>>2]=0;c[m+4>>2]=0}}while(0);H=c[u>>2]|0;s=c[u+4>>2]|0;if((H|0)==0&(s|0)==(-2147483648|0)){w=c[B>>2]|0;m=c[B+4>>2]|0;c[u>>2]=w;c[u+4>>2]=m;J=m;K=w}else{J=s;K=H}H=xrc(c[B>>2]|0,c[B+4>>2]|0,K,J)|0;J=c[f+48>>2]|0;K=wrc(H,G,J,(J|0)<0|0?-1:0)|0;J=o+(n<<8)+24|0;c[J>>2]=K;c[J+4>>2]=G;c[o+(n<<8)+32>>2]=0;J=f+8|0;K=c[J>>2]|0;H=c[J+4>>2]|0;do{if((K|0)==0&(H|0)==(-2147483648|0)){KIb(b,24,2265352,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;s=c[B>>2]|0;w=c[B+4>>2]|0;c[J>>2]=s;c[J+4>>2]=w;L=w;M=s;N=w;O=s}else{s=c[B>>2]|0;w=c[B+4>>2]|0;if((s|0)==(K|0)&(w|0)==(H|0)){L=w;M=s;N=H;O=K;break}m=o+(n<<8)+52|0;c[m>>2]=c[m>>2]|1;L=w;M=s;N=H;O=K}}while(0);K=xrc(O,N,M,L)|0;L=c[I>>2]|0;c[L+((c[r>>2]|0)*40|0)+32>>2]=K;c[L+((c[r>>2]|0)*40|0)+36>>2]=0;K=c[l>>2]|0;b:do{if((K|0)==71){l=c[k+72>>2]|0;I=c[f+24>>2]|0;M=c[q>>2]|0;N=I+M|0;O=c[f+36>>2]&1;H=N;c:do{if((M|0)<4){P=0;Q=0}else{B=-1;J=I;while(1){if(!(J>>>0<N>>>0)){P=0;Q=0;break c}A=B<<8;if((A|0)==256){break}else{B=d[J]|A;J=J+1|0}}B=J-3|0;if(!(B>>>0<N>>>0)){P=0;Q=0;break}A=o+(n<<8)+248|0;s=B;B=0;w=0;while(1){m=s;u=w;d:while(1){t=m;while(1){E=t+4|0;e:do{if((H-E|0)<4){R=N}else{p=-1;v=E;while(1){if(!(v>>>0<N>>>0)){R=N;break e}x=p<<8;if((x|0)==256){break}else{p=d[v]|x;v=v+1|0}}R=v-3|0}}while(0);E=t;p=je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0;if((p|0)==271){break d}else if((p|0)==270){break}else if((p|0)==267){c[A>>2]=1}if(R>>>0<N>>>0){t=R}else{P=u;Q=B;break c}}if(R>>>0<N>>>0){m=R;u=1}else{P=1;Q=B;break c}}if(R>>>0<N>>>0){s=R;B=1;w=u}else{P=u;Q=1;break}}}}while(0);N=c[r>>2]|0;H=(l|0)==0;do{if((N|l|0)==0){c[o+(n<<8)+232>>2]=Q;c[o+(n<<8)+236>>2]=P}else{I=(Q|0)!=0;if(I){if((c[o+(n<<8)+240>>2]|0)!=0){F=88}}else{F=88}if((F|0)==88){if((P|0)==0){break}if((c[o+(n<<8)+244>>2]|0)!=0){break}}if((N|0)>0){M=0;do{w=L+(M*40|0)+36|0;c[w>>2]=c[w>>2]&-2;M=M+1|0;}while((M|0)<(c[r>>2]|0))}M=o+(n<<8)+48|0;c[M>>2]=0;if(I){c[o+(n<<8)+240>>2]=1}w=(P|0)!=0;if(w){c[o+(n<<8)+244>>2]=1}if(!H){break}if(I){if((c[o+(n<<8)+232>>2]|0)==0){break}}if(w){if((c[o+(n<<8)+236>>2]|0)==0){break}}w=L+36|0;c[w>>2]=c[w>>2]|1;c[M>>2]=1}}while(0);H=(c[o+(n<<8)+244>>2]|0)==0;do{if((c[o+(n<<8)+240>>2]|0)==0){S=H?O:P}else{if(H){S=Q;break}if((Q|0)==0){break b}else{S=P}}}while(0);if((S|0)==0){break}H=L+((c[r>>2]|0)*40|0)+36|0;c[H>>2]=c[H>>2]|1;H=o+(n<<8)+48|0;c[H>>2]=(c[H>>2]|0)+1}else{if((c[f+36>>2]&1|0)==0){break}H=c[r>>2]|0;O=L+(H*40|0)+36|0;do{if((c[k+4>>2]|0)==2&(K|0)==2&(H|0)>0){N=(c[q>>2]|0)-4|0;f:do{if((N|0)>0){l=c[f+24>>2]|0;M=0;w=0;B=-256;while(1){s=d[l+M|0]|B;if((s|0)==440){T=(d[l+(M+4)|0]|0)>>>6&1}else if((s|0)==256){break}else{T=w}A=M+1|0;if((A|0)<(N|0)){M=A;w=T;B=s<<8}else{break f}}if(((d[l+(M+2)|0]|0)>>>6|d[l+(M+1)|0]<<2|0)!=0&(w|0)==0){c[O>>2]=2;break}else{c[O>>2]=1;break}}}while(0);N=c[r>>2]|0;if((c[L+(N*40|0)+36>>2]&2|0)==0){U=N;break}I=o+(n<<8)+52|0;c[I>>2]=c[I>>2]|2;U=N}else{c[O>>2]=1;U=c[r>>2]|0}}while(0);if((c[L+(U*40|0)+36>>2]&1|0)==0){break}O=o+(n<<8)+48|0;c[O>>2]=(c[O>>2]|0)+1}}while(0);U=(c[r>>2]|0)+1|0;c[r>>2]=U;r=o+(n<<8)+36|0;c[r>>2]=(c[r>>2]|0)+D;D=c[h>>2]|0;h=k+40|0;r=wrc(c[h>>2]|0,c[h+4>>2]|0,D,(D|0)<0|0?-1:0)|0;c[h>>2]=r;c[h+4>>2]=G;h=c[o+(n<<8)+120>>2]|0;do{if((h|0)>-1){if((h|0)>=(c[k+16>>2]|0)){break}kN(b,f,h,U,c[j>>2]|0,D)|0}}while(0);kJb(c[j>>2]|0);C=0;i=g;return C|0}function NM(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0;e=i;i=i+328|0;f=e|0;g=e+152|0;h=e+160|0;j=e+168|0;k=e+176|0;l=e+200|0;m=e+280|0;n=e+288|0;o=e+296|0;p=e+320|0;q=b+16|0;r=c[q>>2]|0;s=b+12|0;t=c[s>>2]|0;u=t;v=b+1140|0;w=LGb(c[v>>2]|0,2385856,0,0)|0;x=t+4|0;c[x>>2]=1;z=c[b+8>>2]|0;do{if((z|0)==0){A=1}else{B=c[z>>2]|0;if((irc(2155256,B)|0)==0){c[x>>2]=4;A=4;break}if((irc(2482960,B)|0)==0){c[x>>2]=20;A=20;break}if((irc(2217656,B)|0)==0){c[x>>2]=2;A=2;break}if((irc(2538256,B)|0)==0){c[x>>2]=8;A=8;break}if((irc(2448872,B)|0)==0){c[x>>2]=32;A=32;break}if((irc(2406168,B)|0)==0){c[x>>2]=64;A=64;break}if((irc(2377912,B)|0)!=0){A=1;break}c[x>>2]=128;A=128}}while(0);z=t+76|0;do{if((c[z>>2]|0)==0){if((c[t+84>>2]|0)!=0){C=19;break}B=c[t+52>>2]|0;if((B&44|0)==0){D=B}else{C=19}}else{C=19}}while(0);if((C|0)==19){B=t+52|0;E=c[B>>2]|2;c[B>>2]=E;D=E}E=t+52|0;if((A|0)==64){A=D|22;c[E>>2]=A;F=A}else{F=D}a:do{if((F&128|0)==0){H=F}else{do{if((F&2|0)==0){if((c[b+1084>>2]&128|0)!=0){break}c[t+104>>2]=-1;H=F;break a}}while(0);KIb(b,24,2385352,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;D=c[E>>2]&-129;c[E>>2]=D;H=D}}while(0);F=c[t+96>>2]|0;if((F|0)<0){if((H&2|0)!=0){C=30}}else{if((F|0)<=0){C=30}}do{if((C|0)==30){F=b+1204|0;if((c[F>>2]|0)>=0){break}c[F>>2]=2}}while(0);do{if((c[(c[q>>2]|0)+88>>2]|0)==0){if((c[E>>2]&2|0)!=0){if((c[t+88>>2]|0)==0){break}}KIb(b,16,2384872,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-22;i=e;return J|0}}while(0);q=c[s>>2]|0;F=fD(r,0,0,1)|0;H=G;D=b+24|0;A=c[D>>2]|0;if((A|0)==0){K=0;L=0}else{B=c[b+28>>2]|0;M=0;N=0;O=0;while(1){P=c[(c[B+(N<<2)>>2]|0)+8>>2]|0;Q=(c[P+8>>2]|0)==0?1:M;R=(c[P+48>>2]|0)==28?1:O;P=N+1|0;if(P>>>0<A>>>0){M=Q;N=P;O=R}else{K=Q;L=R;break}}}lD(r,0);kD(r,1887007846);O=c[q+120>>2]|0;do{if((O|0)==0){C=42}else{if(!((lrc(O|0)|0)>>>0>3>>>0)){C=42;break}kD(r,d[O+1|0]<<8|d[O]|d[O+2|0]<<16|d[O+3|0]<<24);S=512;T=q+4|0}}while(0);b:do{if((C|0)==42){O=q+4|0;N=c[O>>2]|0;if((N|0)==4){M=(L|0)!=0;A=M?2336720:2336232;kD(r,d[A+1|0]<<8|d[A]|d[A+2|0]<<16|d[A+3|0]<<24);S=M?256:512;T=O;break}if((N&16|0)!=0){M=(L|0)!=0;A=M?2335880:2335424;kD(r,d[A+1|0]<<8|d[A]|d[A+2|0]<<16|d[A+3|0]<<24);S=M?131072:65536;T=O;break}switch(N|0){case 64:{kD(r,1819112297);S=512;T=O;break b;break};case 32:{N=(K|0)!=0?2333440:2332344;kD(r,d[N+1|0]<<8|d[N]|d[N+2|0]<<16|d[N+3|0]<<24);S=512;T=O;break b;break};case 1:{kD(r,1836020585);S=512;T=O;break b;break};case 128:{kD(r,544617574);S=512;T=O;break b;break};case 8:{kD(r,1447973709);S=512;T=O;break b;break};default:{kD(r,538997873);S=512;T=O;break b}}}}while(0);lD(r,S);S=c[T>>2]|0;do{if((S|0)==2){kD(r,538997873)}else if((S|0)==64){kD(r,1717987696);kD(r,846164841)}else{kD(r,1836020585);kD(r,846164841);if((L|0)==0){break}kD(r,828601953)}}while(0);S=c[T>>2]|0;do{if((S|0)==4){T=(L|0)!=0?2336720:2336232;kD(r,d[T+1|0]<<8|d[T]|d[T+2|0]<<16|d[T+3|0]<<24)}else{if((S&16|0)!=0){T=(L|0)!=0?2335880:2335424;kD(r,d[T+1|0]<<8|d[T]|d[T+2|0]<<16|d[T+3|0]<<24);break}if((S|0)==8){kD(r,1447973709);break}else if((S|0)==1){kD(r,825520237);break}else{break}}}while(0);S=fD(r,0,0,1)|0;L=G;fD(r,F,H,0)|0;T=xrc(S,L,F,H)|0;lD(r,T);fD(r,S,L,0)|0;L=c[x>>2]|0;c:do{if((L|0)==8){S=c[D>>2]|0;do{if((S|0)!=0){T=c[b+28>>2]|0;H=0;F=0;K=0;q=0;while(1){O=c[(c[(c[T+(q<<2)>>2]|0)+8>>2]|0)+8>>2]|0;if((O|0)==0){U=K+1|0;V=F;W=H}else if((O|0)==1){U=K;V=F+1|0;W=H}else{U=K;V=F;W=H+1|0}O=q+1|0;if(O>>>0<S>>>0){H=W;F=V;K=U;q=O}else{break}}if(!((U|0)==1&(V|0)==1&(W|0)==0)){break}q=c[b+28>>2]|0;K=c[(c[q>>2]|0)+8>>2]|0;F=c[(c[q+4>>2]|0)+8>>2]|0;q=c[F+412>>2]|0;H=(c[K+108>>2]<<16|0)/(c[K+104>>2]|0)|0;T=(c[F+72>>2]|0)/1e3|0;O=(c[K+72>>2]|0)/1e3|0;N=800-T|0;M=(O|0)>(N|0)?N:O;lD(r,148);kD(r,1684632949);kD(r,1179603536);lD(r,567431118);lD(r,-1148688036);lD(r,-87439552);lD(r,0);lD(r,3);lD(r,20);kD(r,1179799622);lD(r,0);lD(r,0);lD(r,0);lD(r,44);kD(r,1179799617);lD(r,0);lD(r,2);kD(r,1630826605);lD(r,527);lD(r,0);lD(r,T);lD(r,T);lD(r,q);lD(r,c[F+416>>2]|0);lD(r,52);kD(r,1179799638);lD(r,0);lD(r,1);if((c[K+48>>2]|0)==28){kD(r,828601953);tD(r,333);tD(r,21)}else{kD(r,1983148141);tD(r,0);tD(r,259)}lD(r,0);lD(r,M);lD(r,M);lD(r,H);lD(r,H);tD(r,c[K+120>>2]|0);tD(r,c[K+124>>2]|0);lD(r,65537);X=c[x>>2]|0;break c}}while(0);KIb(b,16,2384144,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-22;i=e;return J|0}else{X=L}}while(0);L=c[D>>2]|0;W=t+16|0;c[W>>2]=L;do{if((X&35|0)==0){Y=L}else{if((c[b+1132>>2]|0)==0){Y=L;break}V=L+1|0;c[W>>2]=V;c[t+24>>2]=L;Y=V}}while(0);do{if((c[E>>2]&1|0)==0){Z=0;_=Y}else{L=c[D>>2]|0;if((L|0)==0){Z=Y;_=Y;break}V=c[b+28>>2]|0;U=0;S=Y;K=L;while(1){if((c[(c[(c[V+(U<<2)>>2]|0)+8>>2]|0)+8>>2]|0)>>>0<2>>>0){L=S+1|0;c[W>>2]=L;$=L;aa=c[D>>2]|0}else{$=S;aa=K}L=U+1|0;if(L>>>0<aa>>>0){U=L;S=$;K=aa}else{Z=Y;_=$;break}}}}while(0);if((X|0)==2){if((c[D>>2]|0)==0){ba=0;da=t+20|0}else{X=b+28|0;$=(w|0)==0;Y=t+20|0;aa=0;while(1){K=c[(c[X>>2]|0)+(aa<<2)>>2]|0;do{if((c[(c[K+8>>2]|0)+8>>2]|0)==0){if($){if((LGb(c[K+88>>2]|0,2385856,0,0)|0)==0){break}}c[Y>>2]=(c[Y>>2]|0)+1}}while(0);K=aa+1|0;S=c[D>>2]|0;if(K>>>0<S>>>0){aa=K}else{ba=S;da=Y;break}}}Y=c[da>>2]|0;do{if((Y|0)==0){ea=0}else{if((ba|0)==0){ea=Y;break}aa=b+28|0;$=b;X=0;S=Y;K=ba;while(1){if((c[(c[(c[(c[aa>>2]|0)+(X<<2)>>2]|0)+8>>2]|0)+52>>2]|0)==1684237684){KIb($,24,2383712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;c[da>>2]=0;fa=0;ga=c[D>>2]|0}else{fa=S;ga=K}U=X+1|0;if(U>>>0<ga>>>0){X=U;S=fa;K=ga}else{ea=fa;break}}}}while(0);fa=(c[W>>2]|0)+ea|0;c[W>>2]=fa;ha=_;ia=fa}else{ha=0;ia=_}_=pJb((ia<<8)+256|0)|0;ia=_;fa=t+48|0;c[fa>>2]=ia;if((_|0)==0){J=-12;i=e;return J|0}d:do{if((c[D>>2]|0)==0){ja=0;C=251}else{_=b+28|0;ea=b;ga=p;da=p;ba=ga+4|0;Y=t+100|0;K=b+32|0;S=0;X=ia;e:while(1){$=c[(c[_>>2]|0)+(S<<2)>>2]|0;aa=LGb(c[$+88>>2]|0,2383440,0,0)|0;ka=$+8|0;U=X+(S<<8)+76|0;c[U>>2]=c[ka>>2];V=X+(S<<8)+72|0;c[V>>2]=$;if((aa|0)==0){la=2491992}else{la=c[aa+4>>2]|0}aa=EJ(la,(c[x>>2]|0)!=2|0)|0;c[X+(S<<8)+60>>2]=(aa|0)<0?0:aa;aa=c[x>>2]|0;L=X+(S<<8)|0;c[L>>2]=aa;f:do{if((aa|0)==32){H=c[U>>2]|0;M=c[H+52>>2]|0;if((c[H+8>>2]|0)==3){if((M|0)==1954047348|(M|0)==1731426420){ma=M}else{C=131}}else{C=131}if((C|0)==131){C=0;ma=IX(1681808,c[H+48>>2]|0)|0}if((fH(K,2342544)|0)!=0){na=ma;C=207;break}if((fH(K,2342160)|0)!=0){na=ma;C=207;break}KIb(ea,24,2341632,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;na=ma;C=207}else if((aa|0)==64){H=c[U>>2]|0;M=c[H+52>>2]|0;F=(IX(1349600,c[H+48>>2]|0)|0)==0;H=c[U>>2]|0;q=c[H+48>>2]|0;do{if(!F){if((q|0)==28){oa=828601953;C=205;break f}else if((q|0)==1211250229){oa=829842792;C=205;break f}else if((q|0)==86019){oa=858612577;C=205;break f}else if((q|0)==117){oa=1667330660;C=205;break f}else if((q|0)==94213){oa=1731426420;C=205;break f}else if((q|0)==71){oa=825058166;C=205;break f}else{T=c[H+8>>2]|0;if((T|0)==0){oa=1983148141;C=205;break f}O=(T|0)==1?1630826605:M;if((O|0)==0){break}else{oa=O;C=205;break f}}}}while(0);na=(q|0)==86054?543255927:0;C=207}else if((aa|0)==1|(aa|0)==8){M=c[U>>2]|0;H=c[M+52>>2]|0;if((IX(1349600,c[M+48>>2]|0)|0)==0){C=206;break e}M=c[U>>2]|0;F=c[M+48>>2]|0;if((F|0)==1211250229){oa=829842792;C=205;break}else if((F|0)==86019){oa=858612577;C=205;break}else if((F|0)==117){oa=1667330660;C=205;break}else if((F|0)==94213){oa=1731426420;C=205;break}else if((F|0)==71){oa=825058166;C=205;break}else if((F|0)==28){oa=828601953;C=205;break}else{F=c[M+8>>2]|0;if((F|0)==0){oa=1983148141;C=205;break}na=(F|0)==1?1630826605:H;C=207;break}}else{if((aa&4|0)!=0){na=IX(1689488,c[(c[U>>2]|0)+48>>2]|0)|0;C=207;break}H=c[U>>2]|0;if((aa|0)==128){na=IX(1681872,c[H+48>>2]|0)|0;C=207;break}F=c[H+52>>2]|0;do{if((F|0)==0){pa=H}else{if(!((c[H+680>>2]|0)>-1)){oa=F;C=205;break f}M=c[H+48>>2]|0;if((M|0)==25|(M|0)==14|(M|0)==5|(M|0)==2){pa=H;break}if((g5a(M)|0)==0){na=F;C=207;break f}pa=c[U>>2]|0}}while(0);H=c[pa+48>>2]|0;if((H|0)==25){q=c[pa+124>>2]|0;if((c[pa+120>>2]|0)!=720){if((q|0)==720){oa=(c[pa+108>>2]|0)==50?1902671460:1885894244;C=205;break}else if((q|0)==1080){oa=(c[pa+108>>2]|0)==25?896038500:912815716;C=205;break}else{C=153;break e}}M=c[pa+140>>2]|0;O=(M|0)==4;if((q|0)==480){oa=O?1848997476:543389284;C=205;break}if(O){oa=1882551908;C=205;break}oa=(M|0)==0?1885566564:1886418532;C=205;break}else if((H|0)==14){M=c[pa+52>>2]|0;O=c[pa+140>>2]|0;q=pa+792|0;T=M;N=0;while(1){if((O|0)==(c[822616+(N*12|0)>>2]|0)){A=c[822620+(N*12|0)>>2]|0;c[q>>2]=c[822624+(N*12|0)>>2];if((M|0)==(A|0)){na=M;C=207;break f}else{qa=A}}else{qa=T}A=N+1|0;if(A>>>0<15>>>0){T=qa;N=A}else{na=qa;C=207;break}}}else if((H|0)==2){N=c[pa+52>>2]|0;T=(c[pa+408>>2]|0)>>>0>1>>>0;M=c[V>>2]|0;q=c[M+8>>2]|0;c[da>>2]=c[q+108>>2];c[ba>>2]=c[q+104>>2];if((qLb(ga)|0)<0){q=c[ba>>2]|0;O=M+92|0;A=c[O>>2]|0;B=c[M+96>>2]|0;KIb(ea,48,2415320,(I=i,i=i+32|0,c[I>>2]=c[da>>2],c[I+8>>2]=q,c[I+16>>2]=A,c[I+24>>2]=B,I)|0);i=I;B=O;O=c[B>>2]|0;A=c[B+4>>2]|0;c[p>>2]=O;c[p+4>>2]=A;ra=O;sa=A}else{ra=c[p>>2]|0;sa=c[p+4>>2]|0}A=~~(+(ra|0)/+(sa|0));O=(N|0)==0?829829741:N;N=c[U>>2]|0;B=c[N+140>>2]|0;if((B|0)==4){q=c[N+120>>2]|0;if((q|0)==1280){if((c[N+124>>2]|0)!=720|T){oa=O;C=205;break}if((A|0)==25){oa=892691576;C=205;break}else if((A|0)==30){oa=825582712;C=205;break}else if((A|0)==50){oa=1630889080;C=205;break}else if((A|0)==24){oa=875914360;C=205;break}else{oa=(A|0)==60?959800440:O;C=205;break}}else if((q|0)!=1920){oa=O;C=205;break}if((c[N+124>>2]|0)!=1080){oa=O;C=205;break}if(T){if((A|0)==25){oa=1664443512;C=205;break}oa=(A|0)==30?1647666296:O;C=205;break}if((A|0)==24){oa=1681220728;C=205;break}else if((A|0)==25){oa=1697997944;C=205;break}else{oa=(A|0)==30?1714775160:O;C=205;break}}else if((B|0)!=0){oa=O;C=205;break}B=c[N+120>>2]|0;if((B|0)==1920){if((c[N+124>>2]|0)!=1080){oa=O;C=205;break}if(T){if((A|0)==25){oa=1668703352;C=205;break}oa=(A|0)==30?1651926136:O;C=205;break}if((A|0)==24){oa=1685480568;C=205;break}else if((A|0)==25){oa=1702257784;C=205;break}else{oa=(A|0)==30?1719035e3:O;C=205;break}}else if((B|0)==1280){if((c[N+124>>2]|0)!=720|T){oa=O;C=205;break}if((A|0)==24){oa=880174200;C=205;break}else if((A|0)==25){oa=896951416;C=205;break}else if((A|0)==30){oa=829842552;C=205;break}else if((A|0)==50){oa=1635148920;C=205;break}else{oa=(A|0)==60?964060280:O;C=205;break}}else if((B|0)==1440){if((c[N+124>>2]|0)!=1080){oa=O;C=205;break}if(T){if((A|0)==25){oa=863396984;C=205;break}oa=(A|0)==30?846619768:O;C=205;break}if((A|0)==24){oa=913728632;C=205;break}else if((A|0)==25){oa=930505848;C=205;break}else{oa=(A|0)==30?947283064:O;C=205;break}}else{oa=O;C=205;break}}else{O=c[pa+8>>2]|0;if((O|0)==3){na=IX(1408392,H)|0;C=207;break}else if((O|0)==1){A=IX(1408424,H)|0;if((A|0)!=0){oa=A;C=205;break}A=IX(1406408,c[(c[U>>2]|0)+48>>2]|0)|0;if((A|0)==0){C=206;break e}KIb(ea,24,2343304,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;oa=A<<24|A>>>8<<16&16711680|29549;C=205;break}else if((O|0)==0){O=IX(1407072,H)|0;if((O|0)!=0){oa=O;C=205;break}O=IX(1409152,c[(c[U>>2]|0)+48>>2]|0)|0;if((O|0)==0){C=206;break e}KIb(ea,24,2343880,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;oa=O;C=205;break}else{na=F;C=207;break}}}}while(0);if((C|0)==205){C=0;V=X+(S<<8)+68|0;c[V>>2]=oa;ta=V}else if((C|0)==207){C=0;V=X+(S<<8)+68|0;c[V>>2]=na;if((na|0)==0){break}else{ta=V}}c[X+(S<<8)+120>>2]=-1;V=X+(S<<8)+112|0;c[V>>2]=0;c[V+4>>2]=-2147483648;V=c[ka>>2]|0;aa=c[V+8>>2]|0;do{if((aa|0)==1){O=X+(S<<8)+8|0;c[O>>2]=c[V+412>>2];do{if((c[V+424>>2]|0)==0){if((g5a(c[V+48>>2]|0)|0)==0){KIb(ea,24,2379e3,(I=i,i=i+8|0,c[I>>2]=S,I)|0);i=I;c[X+(S<<8)+96>>2]=1;ua=c[ka>>2]|0;break}else{va=c[ka>>2]|0;C=226;break}}else{va=V;C=226}}while(0);do{if((C|0)==226){C=0;F=c[va+48>>2]|0;if((F|0)==69638|(F|0)==69633|(F|0)==86076){H=c[va+432>>2]|0;if((H|0)==0){C=228;break e}c[X+(S<<8)+40>>2]=H;ua=va;break}if((c[va+424>>2]|0)>1){c[X+(S<<8)+96>>2]=1;ua=va;break}else{H=(g5a(F)|0)>>3;F=c[ka>>2]|0;c[X+(S<<8)+40>>2]=ca(c[F+416>>2]|0,H)|0;ua=F;break}}}while(0);F=c[ua+48>>2]|0;if((F|0)==86076|(F|0)==69632){c[X+(S<<8)+96>>2]=1}if((c[L>>2]|0)==2){break}wa=c[U>>2]|0;if((c[wa+48>>2]|0)!=86017){break}if((c[O>>2]|0)>>>0<16e3>>>0){C=238;break e}}else if((aa|0)==0){F=c[ta>>2]|0;if((F|0)==1882421357|(F|0)==1848866925|(F|0)==1882486893|(F|0)==1848932461|(F|0)==1882552429|(F|0)==1848997997){if((c[V+120>>2]|0)!=720){C=213;break e}H=c[V+124>>2]|0;if(!((H|0)==608|(H|0)==512)){C=213;break e}c[X+(S<<8)+100>>2]=(F&-16777216|0)==1845493760?486:576}F=c[Y>>2]|0;if((F|0)==0){H=c[V+108>>2]|0;while(1){if(H>>>0<1e4>>>0){H=H<<1}else{break}}c[X+(S<<8)+8>>2]=H;xa=H}else{c[X+(S<<8)+8>>2]=F;xa=F}if(!((c[L>>2]|0)==2&xa>>>0>1e5>>>0)){break}KIb(ea,24,2379600,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}else if((aa|0)==3){c[X+(S<<8)+8>>2]=c[V+108>>2]}else if((aa|0)==2){c[X+(S<<8)+8>>2]=c[V+108>>2]}else{c[X+(S<<8)+8>>2]=1e3}}while(0);V=X+(S<<8)+100|0;if((c[V>>2]|0)==0){c[V>>2]=c[(c[ka>>2]|0)+124>>2]}V=X+(S<<8)+8|0;if((c[x>>2]|0)==64){c[V>>2]=1e7;ya=1e7}else{ya=c[V>>2]|0}_X($,64,1,ya);V=c[(c[ka>>2]|0)+100>>2]|0;if((V|0)!=0){aa=X+(S<<8)+80|0;c[aa>>2]=V;L=hJb(V)|0;c[X+(S<<8)+84>>2]=L;nrc(L|0,c[(c[ka>>2]|0)+96>>2]|0,c[aa>>2]|0)|0}aa=S+1|0;L=c[D>>2]|0;if(!(aa>>>0<L>>>0)){ja=L;C=251;break d}S=aa;X=c[fa>>2]|0}if((C|0)==153){KIb(ea,16,2342840,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;C=206}else if((C|0)==213){KIb(ea,16,2380328,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;za=-22;break}else if((C|0)==228){KIb(ea,16,2378688,(I=i,i=i+8|0,c[I>>2]=S,I)|0);i=I;za=-22;break}else if((C|0)==238){Y=c[wa+412>>2]|0;KIb(ea,16,2378288,(I=i,i=i+16|0,c[I>>2]=S,c[I+8>>2]=Y,I)|0);i=I;za=-22;break}if((C|0)==206){c[X+(S<<8)+68>>2]=0}Y=u5a(c[(c[ka>>2]|0)+48>>2]|0)|0;KIb(ea,16,2381800,(I=i,i=i+16|0,c[I>>2]=Y,c[I+8>>2]=S,I)|0);i=I;za=-22}}while(0);g:do{if((C|0)==251){ka=n|0;wa=c[s>>2]|0;mrc(ka|0,0,5)|0;mrc(o|0,-1|0,20)|0;if((ja|0)==0){Aa=wa+48|0;C=261}else{ya=c[b+28>>2]|0;xa=wa+48|0;wa=0;ta=ja;while(1){ua=c[ya+(wa<<2)>>2]|0;va=c[(c[ua+8>>2]|0)+8>>2]|0;do{if(va>>>0>4>>>0){Ba=ta}else{na=o+(va<<2)|0;if((c[na>>2]|0)<0){c[na>>2]=wa}if((c[ua+72>>2]&1|0)==0){Ba=ta;break}na=(c[xa>>2]|0)+(wa<<8)+52|0;c[na>>2]=c[na>>2]|4;a[n+va|0]=1;Ba=c[D>>2]|0}}while(0);va=wa+1|0;if(va>>>0<Ba>>>0){wa=va;ta=Ba}else{break}}if((a[ka]|0)==0){Aa=xa;C=261}else{Ca=xa}}do{if((C|0)==261){ta=c[o>>2]|0;if(!((ta|0)>-1)){Ca=Aa;break}wa=(c[Aa>>2]|0)+(ta<<8)+52|0;c[wa>>2]=c[wa>>2]|4;Ca=Aa}}while(0);do{if((a[n+1|0]|0)==0){xa=c[o+4>>2]|0;if(!((xa|0)>-1)){break}ka=(c[Ca>>2]|0)+(xa<<8)+52|0;c[ka>>2]=c[ka>>2]|4}}while(0);do{if((a[n+3|0]|0)==0){ka=c[o+12>>2]|0;if(!((ka|0)>-1)){break}xa=(c[Ca>>2]|0)+(ka<<8)+52|0;c[xa>>2]=c[xa>>2]|4}}while(0);xa=t+104|0;do{if((c[xa>>2]|0)!=0){ka=fD(r,0,0,1)|0;wa=t+112|0;c[wa>>2]=ka;c[wa+4>>2]=G;wa=c[xa>>2]|0;if((wa|0)<=0){break}hD(r,wa,(wa|0)<0|0?-1:0)|0;}}while(0);xa=c[E>>2]|0;do{if((xa&2|0)==0){if((xa&128|0)!=0){wa=fD(r,0,0,1)|0;ka=t+112|0;c[ka>>2]=wa;c[ka+4>>2]=G}lD(r,8);ka=(c[x>>2]|0)==2?2345104:2110112;kD(r,d[ka+1|0]<<8|d[ka]|d[ka+2|0]<<16|d[ka+3|0]<<24);ka=fD(r,0,0,1)|0;wa=t+32|0;c[wa>>2]=ka;c[wa+4>>2]=G;lD(r,0);kD(r,1952539757)}else{if((xa&40|0)!=0){break}if((c[z>>2]|0)!=0){break}if((c[t+84>>2]|0)!=0){break}c[E>>2]=xa|8}}while(0);xa=LGb(c[v>>2]|0,2377896,0,0)|0;if((xa|0)==0){wa=t+8|0;Da=c[wa+4>>2]|0;Ea=c[wa>>2]|0}else{wa=pY(c[xa+4>>2]|0)|0;xa=G;ka=t+8|0;c[ka>>2]=wa;c[ka+4>>2]=xa;Da=xa;Ea=wa}if(!((Ea|0)==0&(Da|0)==0)){wa=t+8|0;xa=wrc(Ea,Da,2082844800,0)|0;c[wa>>2]=xa;c[wa+4>>2]=G}wa=c[t+24>>2]|0;if((wa|0)!=0){xa=QM(b,wa)|0;if((xa|0)<0){za=xa;break}}do{if((c[E>>2]&1|0)!=0){xa=c[D>>2]|0;if((xa|0)==0){break}wa=b+28|0;ka=Z;ta=0;ya=xa;while(1){if((c[(c[(c[(c[wa>>2]|0)+(ta<<2)>>2]|0)+8>>2]|0)+8>>2]|0)>>>0<2>>>0){xa=jN(b,ka,ta)|0;if((xa|0)<0){za=xa;break g}Fa=ka+1|0;Ga=c[D>>2]|0}else{Fa=ka;Ga=ya}xa=ta+1|0;if(xa>>>0<Ga>>>0){ka=Fa;ta=xa;ya=Ga}else{break}}}}while(0);do{if((c[t+20>>2]|0)!=0){if((c[D>>2]|0)==0){break}ya=b+28|0;ta=(w|0)==0;ka=l;wa=m;xa=l+28|0;S=l+32|0;ea=l+36|0;X=j;va=j;ua=X+4|0;$=b;na=k+4|0;oa=m;pa=wa+4|0;sa=l+24|0;ra=k|0;p=ha;qa=0;while(1){ma=c[(c[ya>>2]|0)+(qa<<2)>>2]|0;do{if((c[(c[ma+8>>2]|0)+8>>2]|0)==0){if(ta){la=LGb(c[ma+88>>2]|0,2385856,0,0)|0;if((la|0)==0){Ha=p;break}Ia=la;Ja=c[(c[ya>>2]|0)+(qa<<2)>>2]|0}else{Ia=w;Ja=ma}la=c[Ia+4>>2]|0;ia=c[s>>2]|0;Y=ia+48|0;da=c[Y>>2]|0;mrc(ka|0,0,80)|0;c[xa>>2]=4;c[S>>2]=p;c[ea>>2]=1;ba=c[Ja+8>>2]|0;c[va>>2]=c[ba+108>>2];c[ua>>2]=c[ba+104>>2];if((qLb(X)|0)<0){ba=c[ua>>2]|0;ga=Ja+92|0;K=c[ga>>2]|0;_=c[Ja+96>>2]|0;KIb($,48,2415320,(I=i,i=i+32|0,c[I>>2]=c[va>>2],c[I+8>>2]=ba,c[I+16>>2]=K,c[I+24>>2]=_,I)|0);i=I;_=ga;ga=c[_>>2]|0;K=c[_+4>>2]|0;c[j>>2]=ga;c[j+4>>2]=K;Ka=K;La=ga}else{Ka=c[j+4>>2]|0;La=c[j>>2]|0}c[m>>2]=La;c[m+4>>2]=Ka;ga=sLb(k,wa,la,$)|0;if((ga|0)<0){Ma=ga}else{c[da+(p<<8)>>2]=c[ia+4>>2];ia=da+(p<<8)+68|0;c[ia>>2]=1684237684;c[da+(p<<8)+124>>2]=qa;c[da+(p<<8)+8>>2]=c[(c[Y>>2]|0)+(qa<<8)+8>>2];if((c[na>>2]&1|0)!=0){Y=da+(p<<8)+56|0;c[Y>>2]=c[Y>>2]|1}Y=mWa(0)|0;c[da+(p<<8)+76>>2]=Y;c[Y+8>>2]=2;c[Y+52>>2]=c[ia>>2];ia=Y+104|0;Y=c[oa>>2]|0;c[ia>>2]=c[pa>>2];c[ia+4>>2]=Y;Y=hJb(c[xa>>2]|0)|0;c[sa>>2]=Y;ia=Y;y=je(c[ra>>2]|0)|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=MM(b,l)|0;kJb(c[sa>>2]|0);Ma=ia}if((Ma|0)<0){za=Ma;break g}Ha=p+1|0}else{Ha=p}}while(0);ma=qa+1|0;if(ma>>>0<(c[D>>2]|0)>>>0){p=Ha;qa=ma}else{break}}}}while(0);eD(r);qa=c[E>>2]|0;if((qa&64|0)==0){Na=qa}else{qa=fD(r,0,0,1)|0;p=G;lD(r,0);kD(r,1684632949);dD(r,822488,16);lD(r,0);YD(r,2377336,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;YD(r,2376976,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;YD(r,2376672,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;YD(r,2375280,(I=i,i=i+8|0,c[I>>2]=2538216,I)|0)|0;i=I;YD(r,2374e3,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;YD(r,2373488,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;YD(r,2373080,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;sa=c[W>>2]|0;if((sa|0)>0){ra=f|0;xa=0;pa=sa;while(1){sa=xa+1|0;oa=(c[fa>>2]|0)+(xa<<8)+76|0;na=c[oa>>2]|0;$=c[na+8>>2]|0;if(($|0)==1){Oa=2372520;C=317}else if(($|0)==0){Oa=2372856;C=317}else{Pa=pa}if((C|0)==317){C=0;$=c[na+72>>2]|0;YD(r,2372280,(I=i,i=i+16|0,c[I>>2]=Oa,c[I+8>>2]=$,I)|0)|0;i=I;$=c[(c[oa>>2]|0)+72>>2]|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2371800,c[I+8>>2]=$,I)|0)|0;i=I;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2371528,c[I+8>>2]=sa,I)|0)|0;i=I;$=c[oa>>2]|0;na=c[$+48>>2]|0;if((c[$+8>>2]|0)==0){if((na|0)==71){YD(r,2347048,(I=i,i=i+16|0,c[I>>2]=2368648,c[I+8>>2]=2364664,I)|0)|0;i=I;wa=c[oa>>2]|0;va=c[wa+100>>2]|0;ua=va>>>0<74>>>0?va:74;lY(ra,c[wa+96>>2]|0,ua,0)|0;a[f+(ua<<1)|0]=0;YD(r,2347048,(I=i,i=i+16|0,c[I>>2]=2370648,c[I+8>>2]=ra,I)|0)|0;i=I}else if((na|0)==28){c[h>>2]=c[$+100>>2];if((r$(c[$+96>>2]|0,g,h)|0)==0){$=c[g>>2]|0;if(($|0)==0){Qa=c[(c[oa>>2]|0)+96>>2]|0}else{Qa=$}$=c[h>>2]|0;ua=$>>>0<74>>>0?$:74;lY(ra,Qa,ua,0)|0;a[f+(ua<<1)|0]=0;YD(r,2347048,(I=i,i=i+16|0,c[I>>2]=2370648,c[I+8>>2]=ra,I)|0)|0;i=I;kJb(c[g>>2]|0)}YD(r,2347048,(I=i,i=i+16|0,c[I>>2]=2368648,c[I+8>>2]=2366464,I)|0)|0;i=I}ua=c[(c[oa>>2]|0)+120>>2]|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2362968,c[I+8>>2]=ua,I)|0)|0;i=I;ua=c[(c[oa>>2]|0)+124>>2]|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2361808,c[I+8>>2]=ua,I)|0)|0;i=I;ua=c[(c[oa>>2]|0)+120>>2]|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2360720,c[I+8>>2]=ua,I)|0)|0;i=I;ua=c[(c[oa>>2]|0)+124>>2]|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2359720,c[I+8>>2]=ua,I)|0)|0;i=I}else{if((na|0)==86018){YD(r,2347048,(I=i,i=i+16|0,c[I>>2]=2368648,c[I+8>>2]=2358512,I)|0)|0;i=I}else if((na|0)==86054){YD(r,2347048,(I=i,i=i+16|0,c[I>>2]=2368648,c[I+8>>2]=2356472,I)|0)|0;i=I}na=c[oa>>2]|0;ua=c[na+100>>2]|0;$=ua>>>0<74>>>0?ua:74;lY(ra,c[na+96>>2]|0,$,0)|0;a[f+($<<1)|0]=0;YD(r,2347048,(I=i,i=i+16|0,c[I>>2]=2370648,c[I+8>>2]=ra,I)|0)|0;i=I;$=IX(1406408,c[(c[oa>>2]|0)+48>>2]|0)|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2355952,c[I+8>>2]=$,I)|0)|0;i=I;$=c[(c[oa>>2]|0)+416>>2]|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2353664,c[I+8>>2]=$,I)|0)|0;i=I;$=c[(c[oa>>2]|0)+412>>2]|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2351264,c[I+8>>2]=$,I)|0)|0;i=I;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2350296,c[I+8>>2]=16,I)|0)|0;i=I;$=c[(c[oa>>2]|0)+432>>2]|0;YD(r,2346528,(I=i,i=i+16|0,c[I>>2]=2349528,c[I+8>>2]=($|0)==0?4:$,I)|0)|0;i=I}YD(r,2348872,(I=i,i=i+8|0,c[I>>2]=Oa,I)|0)|0;i=I;Pa=c[W>>2]|0}if((sa|0)<(Pa|0)){xa=sa;pa=Pa}else{break}}}YD(r,2348488,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;YD(r,2348e3,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;YD(r,2347464,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;pa=fD(r,0,0,1)|0;xa=G;fD(r,qa,p,0)|0;ra=xrc(pa,xa,qa,p)|0;lD(r,ra);fD(r,pa,xa,0)|0;Na=c[E>>2]|0}if((Na&4|0)==0){J=0;i=e;return J|0}RM(r,u,b);xa=t+72|0;c[xa>>2]=(c[xa>>2]|0)+1;J=0;i=e;return J|0}}while(0);UM(c[s>>2]|0);J=za;i=e;return J|0}function OM(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+88|0;f=e|0;g=e+80|0;if((d|0)==0){SM(a);h=1;i=e;return h|0}j=c[a+12>>2]|0;if((c[d+28>>2]|0)==0){h=0;i=e;return h|0}k=j+16|0;l=c[k>>2]|0;a:do{if((l|0)>0){m=j+48|0;n=d+16|0;o=g;p=f+28|0;q=f+24|0;r=f+8|0;s=f+16|0;t=f+48|0;u=f+32|0;v=0;w=l;b:while(1){x=c[m>>2]|0;do{if((c[(c[x+(v<<8)+76>>2]|0)+48>>2]|0)==94213){y=x+(v<<8)+24|0;z=c[y>>2]|0;A=c[y+4>>2]|0;y=c[n+4>>2]|0;if(!((A|0)<(y|0)|(A|0)==(y|0)&z>>>0<(c[n>>2]|0)>>>0)){B=w;break}if((c[x+(v<<8)+4>>2]|0)!=0){if((c[x+(v<<8)+32>>2]|0)!=0){B=w;break}}b[g>>1]=0;J1(f);c[p>>2]=2;c[q>>2]=o;c[r>>2]=z;c[r+4>>2]=A;c[s>>2]=z;c[s+4>>2]=A;c[t>>2]=0;c[u>>2]=v;A=iN(a,f)|0;P1(f);if((A|0)<0){h=A;break b}c[x+(v<<8)+32>>2]=1;B=c[k>>2]|0}else{B=w}}while(0);x=v+1|0;if((x|0)<(B|0)){v=x;w=B}else{break a}}i=e;return h|0}}while(0);h=iN(a,d)|0;i=e;return h|0}function PM(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=i;i=i+136|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+120|0;m=d+128|0;n=a+12|0;o=c[n>>2]|0;p=o;q=a+16|0;r=c[q>>2]|0;s=o+16|0;t=c[s>>2]|0;if((t|0)>0){u=o+48|0;v=l;w=k+28|0;x=k+24|0;y=k+8|0;z=k+16|0;A=k+48|0;B=k+32|0;C=0;D=t;while(1){E=c[u>>2]|0;do{if((c[(c[E+(C<<8)+76>>2]|0)+48>>2]|0)==94213){F=E+(C<<8)+32|0;if((c[F>>2]|0)!=0){H=D;break}I=E+(C<<8)+24|0;J=c[I>>2]|0;K=c[I+4>>2]|0;b[l>>1]=0;J1(k);c[w>>2]=2;c[x>>2]=v;c[y>>2]=J;c[y+4>>2]=K;c[z>>2]=J;c[z+4>>2]=K;c[A>>2]=0;c[B>>2]=C;iN(a,k)|0;P1(k);c[F>>2]=1;H=c[s>>2]|0}else{H=D}}while(0);E=C+1|0;if((E|0)<(H|0)){C=E;D=H}else{L=H;break}}}else{L=t}t=o+24|0;H=o+52|0;do{if((c[t>>2]|0)==0){if((c[H>>2]&2|0)!=0){M=0;N=12;break}if((c[o+4>>2]&35|0)==0){M=0;N=12;break}if((c[a+1132>>2]|0)==0){M=0;N=12;break}c[s>>2]=L+1;c[t>>2]=L;D=QM(a,L)|0;if((D|0)<0){O=D}else{M=D;N=12}}else{M=0;N=12}}while(0);do{if((N|0)==12){do{if((c[H>>2]&2|0)==0){L=fD(r,0,0,1)|0;t=G;D=o+40|0;C=wrc(c[D>>2]|0,c[D+4>>2]|0,8,0)|0;k=G;B=1;A=o+32|0;z=c[A>>2]|0;y=c[A+4>>2]|0;if(k>>>0<B>>>0|k>>>0==B>>>0&C>>>0<0>>>0){fD(r,z,y,0)|0;C=wrc(c[D>>2]|0,c[D+4>>2]|0,8,0)|0;lD(r,C)}else{C=wrc(z,y,-8,-1)|0;fD(r,C,G,0)|0;lD(r,1);kD(r,1952539757);C=wrc(c[D>>2]|0,c[D+4>>2]|0,16,0)|0;sD(r,C,G)}C=o+104|0;if((c[C>>2]|0)>0){D=o+112|0;P=c[D+4>>2]|0;Q=c[D>>2]|0}else{P=t;Q=L}fD(r,Q,P,0)|0;if((c[H>>2]&128|0)==0){D=(c[C>>2]|0)>0;RM(r,p,a);if(!D){R=M;break}D=c[C>>2]|0;C=fD(r,0,0,1)|0;y=o+112|0;z=xrc(c[y>>2]|0,c[y+4>>2]|0,C,G)|0;C=wrc(z,G,D,(D|0)<0|0?-1:0)|0;D=G;z=0;if((D|0)<(z|0)|(D|0)==(z|0)&C>>>0<8>>>0){z=xrc(8,0,C,D)|0;y=G;KIb(a,16,2111840,(S=i,i=i+16|0,c[S>>2]=z,c[S+8>>2]=y,S)|0);i=S;T=-1;i=d;return T|0}lD(r,C);kD(r,1701147238);y=0;do{bD(r,0);y=y+1|0;z=(y|0)<0|0?-1:0;}while((z|0)<(D|0)|(z|0)==(D|0)&y>>>0<C>>>0);fD(r,L,t,0)|0;R=M;break}C=a;KIb(C,32,2113648,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;y=c[n>>2]|0;fD(c[q>>2]|0,0,0,1)|0;D=c[n>>2]|0;z=bE(f)|0;do{if((z|0)<0){U=z}else{RM(c[f>>2]|0,D,a);B=dE(c[f>>2]|0)|0;if((B|0)<0){U=B;break}k=D+16|0;A=c[k>>2]|0;if((A|0)>0){v=B;x=(B|0)<0|0?-1:0;w=c[D+48>>2]|0;l=0;do{u=w+(l<<8)+184|0;E=wrc(c[u>>2]|0,c[u+4>>2]|0,v,x)|0;c[u>>2]=E;c[u+4>>2]=G;l=l+1|0;}while((l|0)<(A|0))}A=c[n>>2]|0;l=bE(e)|0;if((l|0)<0){U=l;break}RM(c[e>>2]|0,A,a);A=dE(c[e>>2]|0)|0;l=(A|0)<0;do{if(!(l|(A|0)==(B|0))){x=c[k>>2]|0;if((x|0)<=0){break}v=A-B|0;w=v;u=(v|0)<0|0?-1:0;v=c[D+48>>2]|0;E=0;do{F=v+(E<<8)+184|0;K=wrc(c[F>>2]|0,c[F+4>>2]|0,w,u)|0;c[F>>2]=K;c[F+4>>2]=G;E=E+1|0;}while((E|0)<(x|0))}}while(0);if(l){U=A;break}B=hJb(A<<1)|0;if((B|0)==0){U=-12;break}c[g>>2]=B;k=B+A|0;c[g+4>>2]=k;eD(c[q>>2]|0);x=a+32|0;E=UD(j,x,1)|0;if((E|0)<0){KIb(C,16,2386712,(S=i,i=i+8|0,c[S>>2]=x,S)|0);i=S}else{x=fD(c[q>>2]|0,0,0,1)|0;u=G;w=c[q>>2]|0;v=y+112|0;F=wrc(c[v>>2]|0,c[v+4>>2]|0,A,(A|0)<0|0?-1:0)|0;fD(w,F,G,0)|0;fD(c[j>>2]|0,c[v>>2]|0,c[v+4>>2]|0,0)|0;v=fD(c[j>>2]|0,0,0,1)|0;F=G;c[h>>2]=AD(c[j>>2]|0,B,A)|0;w=1;K=F;F=v;v=k;do{c[h+(w<<2)>>2]=AD(c[j>>2]|0,v,A)|0;w=w^1;k=c[h+(w<<2)>>2]|0;if((k|0)<1){break}v=c[g+(w<<2)>>2]|0;dD(c[q>>2]|0,v,k);F=wrc(k,(k|0)<0|0?-1:0,F,K)|0;K=G;}while((K|0)<(u|0)|(K|0)==(u|0)&F>>>0<x>>>0);WD(c[j>>2]|0)|0}kJb(B);U=E}}while(0);if((U|0)!=0){R=U;break}y=o+112|0;fD(c[q>>2]|0,c[y>>2]|0,c[y+4>>2]|0,0)|0;RM(r,p,a);R=0}else{SM(a);y=fD(r,0,0,1)|0;C=G;lD(r,0);kD(r,1634887277);if((c[H>>2]&64|0)!=0){D=fD(r,0,0,1)|0;z=G;fD(r,y,C,0)|0;t=xrc(D,z,y,C)|0;lD(r,t);fD(r,D,z,0)|0;R=M;break}z=c[s>>2]|0;if((z|0)>0){D=o+48|0;t=0;L=z;while(1){z=c[D>>2]|0;x=z+(t<<8)+208|0;if((c[x>>2]|0)==0){V=L}else{F=fD(r,0,0,1)|0;u=G;lD(r,0);kD(r,1634887284);bD(r,1);vD(r,0);lD(r,c[z+(t<<8)+64>>2]|0);lD(r,0);lD(r,c[x>>2]|0);if((c[x>>2]|0)>0){K=z+(t<<8)+212|0;z=0;do{v=(c[K>>2]|0)+(z<<5)+8|0;sD(r,c[v>>2]|0,c[v+4>>2]|0);v=(c[K>>2]|0)+(z<<5)|0;sD(r,c[v>>2]|0,c[v+4>>2]|0);bD(r,1);bD(r,1);bD(r,1);z=z+1|0;}while((z|0)<(c[x>>2]|0))}x=fD(r,0,0,1)|0;z=G;fD(r,F,u,0)|0;K=xrc(x,z,F,u)|0;lD(r,K);fD(r,x,z,0)|0;V=c[s>>2]|0}z=t+1|0;if((z|0)<(V|0)){t=z;L=V}else{break}}}lD(r,16);kD(r,1869768301);lD(r,0);L=fD(r,0,0,1)|0;t=G;D=xrc(4,0,y,C)|0;z=wrc(D,G,L,t)|0;lD(r,z);z=fD(r,0,0,1)|0;t=G;fD(r,y,C,0)|0;L=xrc(z,t,y,C)|0;lD(r,L);fD(r,z,t,0)|0;R=M}}while(0);if((c[s>>2]|0)<=0){O=R;break}t=o+48|0;z=m|0;L=0;while(1){do{if((c[H>>2]&2|0)!=0){D=(c[t>>2]|0)+(L<<8)+224|0;if((c[D>>2]|0)==0&(c[D+4>>2]|0)==0){break}if((c[(c[q>>2]|0)+88>>2]|0)==0){break}D=fD(r,0,0,1)|0;x=G;if(!((TM((c[t>>2]|0)+(L<<8)|0,z)|0)>-1)){break}K=(c[t>>2]|0)+(L<<8)+224|0;fD(r,c[K>>2]|0,c[K+4>>2]|0,0)|0;dD(r,z,7);fD(r,D,x,0)|0;}}while(0);C=L+1|0;if((C|0)<(c[s>>2]|0)){L=C}else{O=R;break}}}}while(0);UM(c[n>>2]|0);T=O;i=d;return T|0}function QM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+112|0;f=e|0;g=e+8|0;h=e+88|0;j=e+96|0;k=e+104|0;l=c[b+12>>2]|0;m=c[l+48>>2]|0;mrc(g|0,0,80)|0;c[g+32>>2]=d;c[g+36>>2]=1;c[m+(d<<8)>>2]=c[l+4>>2];c[m+(d<<8)+68>>2]=1954047348;c[m+(d<<8)+8>>2]=1e3;l=mWa(0)|0;n=m+(d<<8)+76|0;c[n>>2]=l;if((l|0)==0){o=-12;i=e;return o|0}c[l+8>>2]=3;do{if((_D(f)|0)>-1){lD(c[f>>2]|0,1);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);tD(c[f>>2]|0,0);tD(c[f>>2]|0,0);tD(c[f>>2]|0,0);tD(c[f>>2]|0,0);tD(c[f>>2]|0,0);tD(c[f>>2]|0,0);tD(c[f>>2]|0,1);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);bD(c[f>>2]|0,0);lD(c[f>>2]|0,13);kD(c[f>>2]|0,1650553958);tD(c[f>>2]|0,1);tD(c[f>>2]|0,1);bD(c[f>>2]|0,0);l=aE(c[f>>2]|0,h)|0;if((l|0)>0){c[(c[n>>2]|0)+96>>2]=c[h>>2];c[(c[n>>2]|0)+100>>2]=l;break}else{kJb(h);break}}}while(0);h=b+1132|0;if((c[h>>2]|0)==0){o=0;i=e;return o|0}n=b+1136|0;f=j|0;l=j+4|0;d=k|0;m=k+4|0;p=g+16|0;q=g+8|0;r=g+48|0;s=g+28|0;t=g+24|0;u=t;v=0;while(1){w=c[(c[n>>2]|0)+(v<<2)>>2]|0;x=w+24|0;z=c[x>>2]|0;A=c[x+4>>2]|0;x=w+4|0;c[f>>2]=1;c[l>>2]=1e3;B=XIb(z,A,x,j)|0;A=G;z=w+16|0;C=c[z>>2]|0;D=c[z+4>>2]|0;c[d>>2]=1;c[m>>2]=1e3;z=XIb(C,D,x,k)|0;x=G;c[p>>2]=z;c[p+4>>2]=x;c[q>>2]=z;c[q+4>>2]=x;D=xrc(B,A,z,x)|0;c[r>>2]=D;D=LGb(c[w+32>>2]|0,2607144,0,0)|0;if((D|0)!=0){w=D+4|0;D=lrc(c[w>>2]|0)|0;x=D+2|0;c[s>>2]=x;z=hJb(x)|0;c[t>>2]=z;if((z|0)==0){o=-12;E=12;break}x=z;y=he(D&65535|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;nrc(z+2|0,c[w>>2]|0,D)|0;MM(b,g)|0;mJb(u)}D=v+1|0;if(D>>>0<(c[h>>2]|0)>>>0){v=D}else{o=0;E=12;break}}if((E|0)==12){i=e;return o|0}return 0}function RM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;e=i;i=i+1024|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=fD(a,0,0,1)|0;l=G;lD(a,0);kD(a,1987014509);m=b+16|0;n=c[m>>2]|0;if((n|0)>0){o=c[b+48>>2]|0;p=b+52|0;q=b+8|0;r=0;while(1){s=o+(r<<8)+4|0;t=c[s>>2]|0;do{if((t|0)<1){if((c[p>>2]&2|0)!=0){u=6;break}v=r+1|0}else{u=6}}while(0);do{if((u|0)==6){u=0;w=c[q+4>>2]|0;x=o+(r<<8)+16|0;c[x>>2]=c[q>>2];c[x+4>>2]=w;w=r+1|0;c[o+(r<<8)+64>>2]=w;if((t|0)==0){v=w;break}x=c[o+(r<<8)+88>>2]|0;y=c[x+16>>2]|0;c[x+24>>2]=1;z=o+(r<<8)+44|0;if((c[z>>2]|0)!=0){v=w;break}c[z>>2]=1;if((c[s>>2]|0)<=1){v=w;break}A=1;B=x;C=0;D=y;y=1;while(1){E=B|0;F=wrc(c[E>>2]|0,c[E+4>>2]|0,D,C)|0;E=x+(A*40|0)|0;H=c[x+(A*40|0)+16>>2]|0;do{if((F|0)==(c[E>>2]|0)&(G|0)==(c[E+4>>2]|0)){I=wrc(H,0,D,C)|0;J=G;K=0;if(!(J>>>0<K>>>0|J>>>0==K>>>0&I>>>0<1048576>>>0)){u=13;break}K=B+20|0;c[K>>2]=(c[K>>2]|0)+(c[x+(A*40|0)+28>>2]|0);L=J;M=I;N=B;O=y}else{u=13}}while(0);if((u|0)==13){u=0;c[x+(A*40|0)+24>>2]=(c[B+24>>2]|0)+1;E=y+1|0;c[z>>2]=E;L=0;M=H;N=x+(A*40|0)|0;O=E}E=A+1|0;if((E|0)<(c[s>>2]|0)){A=E;B=N;C=L;D=M;y=O}else{v=w;break}}}}while(0);s=c[m>>2]|0;if((v|0)<(s|0)){r=v}else{P=s;break}}}else{P=n}n=b+24|0;do{if((c[n>>2]|0)==0){Q=P}else{v=d+24|0;if((c[v>>2]|0)==0){Q=P;break}r=c[b+48>>2]|0;O=0;do{c[r+(O<<8)+104>>2]=1885431907;c[r+(O<<8)+108>>2]=c[r+(c[n>>2]<<8)+64>>2];O=O+1|0;}while(O>>>0<(c[v>>2]|0)>>>0);Q=c[m>>2]|0}}while(0);do{if((Q|0)>0){n=c[b+48>>2]|0;P=0;v=Q;while(1){if((c[n+(P<<8)+68>>2]|0)==544240754){c[n+(P<<8)+104>>2]=1953393e3;c[n+(P<<8)+108>>2]=c[n+(c[n+(P<<8)+124>>2]<<8)+64>>2];R=c[m>>2]|0}else{R=v}O=P+1|0;if((O|0)<(R|0)){P=O;v=R}else{break}}if((R|0)<=0){S=1;T=0;U=0;V=0;u=39;break}v=c[b+48>>2]|0;P=0;n=R;while(1){if((c[v+(P<<8)+68>>2]|0)==1684237684){O=c[v+(P<<8)+124>>2]|0;c[v+(O<<8)+104>>2]=1684237684;c[v+(O<<8)+108>>2]=c[v+(P<<8)+64>>2];r=v+(O<<8)+24|0;O=c[r+4>>2]|0;M=v+(P<<8)+24|0;c[M>>2]=c[r>>2];c[M+4>>2]=O;W=c[m>>2]|0}else{W=n}O=P+1|0;if((O|0)<(W|0)){P=O;n=W}else{break}}if((W|0)<=0){S=1;T=0;U=0;V=0;u=39;break}n=c[b+48>>2]|0;P=0;v=0;O=0;M=1;while(1){do{if((c[n+(P<<8)+4>>2]|0)>0){r=c[n+(P<<8)+8>>2]|0;if((r|0)==0){X=M;Y=v;Z=O;break}L=n+(P<<8)+24|0;N=UIb(c[L>>2]|0,c[L+4>>2]|0,1e3,0,r,0,3)|0;r=G;L=(v|0)<(r|0)|(v|0)==(r|0)&O>>>0<N>>>0;o=c[n+(P<<8)+64>>2]|0;X=(M|0)<(o|0)?o:M;Y=L?r:v;Z=L?N:O}else{X=M;Y=v;Z=O}}while(0);N=P+1|0;if((N|0)<(W|0)){P=N;v=Y;O=Z;M=X}else{break}}M=0;O=(Y|0)>(M|0)|(Y|0)==(M|0)&Z>>>0>-2>>>0;M=O&1;if(!O){S=X;T=Y;U=Z;V=M;u=39;break}lD(a,120);_=X;$=Y;aa=Z;ba=1;da=M}else{S=1;T=0;U=0;V=0;u=39}}while(0);if((u|0)==39){lD(a,108);_=S;$=T;aa=U;ba=0;da=V}kD(a,1684567661);bD(a,da);vD(a,0);da=b+8|0;V=c[da>>2]|0;if(ba){sD(a,V,c[da+4>>2]|0);sD(a,c[da>>2]|0,c[da+4>>2]|0);lD(a,1e3);sD(a,aa,$)}else{lD(a,V);lD(a,c[da>>2]|0);lD(a,1e3);lD(a,aa)}lD(a,65536);tD(a,256);tD(a,0);lD(a,0);lD(a,0);lD(a,65536);lD(a,0);lD(a,0);lD(a,0);lD(a,65536);lD(a,0);lD(a,0);lD(a,0);lD(a,1073741824);lD(a,0);lD(a,0);lD(a,0);lD(a,0);lD(a,0);lD(a,0);lD(a,_+1|0);_=b+4|0;do{if((c[_>>2]|0)!=2){if((c[b+60>>2]|0)!=0){break}aa=fD(a,0,0,1)|0;da=G;V=c[b+68>>2]|0;$=c[b+64>>2]|0;ba=c[m>>2]|0;if((ba|0)>0){U=c[b+48>>2]|0;T=0;S=0;Z=0;while(1){if((c[U+(Z<<8)+4>>2]|0)>0){Y=c[(c[U+(Z<<8)+76>>2]|0)+8>>2]|0;ea=(Y|0)==0|S;fa=(Y|0)==1|T}else{ea=S;fa=T}Y=Z+1|0;if((Y|0)<(ba|0)){T=fa;S=ea;Z=Y}else{ga=fa;ha=ea;break}}}else{ga=0;ha=0}lD(a,0);kD(a,1935961961);lD(a,0);bD(a,16);bD(a,128);bD(a,128);bD(a,128);bD(a,7);tD(a,79);bD(a,255);bD(a,255);bD(a,(V|0)<0?255-ga|0:V);bD(a,($|0)<0?255-ha|0:$);bD(a,255);Z=fD(a,0,0,1)|0;S=G;fD(a,aa,da,0)|0;T=xrc(Z,S,aa,da)|0;lD(a,T);fD(a,Z,S,0)|0;}}while(0);ha=c[m>>2]|0;a:do{if((ha|0)>0){ga=b+48|0;ea=d+24|0;fa=d+28|0;S=b+96|0;Z=b+52|0;T=j|0;ba=0;U=ha;while(1){Y=c[ga>>2]|0;X=Y+(ba<<8)+4|0;if((c[X>>2]|0)>0){u=56}else{if((c[Z>>2]&2|0)==0){ia=U}else{u=56}}if((u|0)==56){u=0;W=Y+(ba<<8)|0;if(ba>>>0<(c[ea>>2]|0)>>>0){ja=c[(c[fa>>2]|0)+(ba<<2)>>2]|0}else{ja=0}R=fD(a,0,0,1)|0;Q=G;lD(a,0);kD(a,1801548404);M=Y+(ba<<8)+24|0;O=Y+(ba<<8)+8|0;v=UIb(c[M>>2]|0,c[M+4>>2]|0,1e3,0,c[O>>2]|0,0,3)|0;P=G;n=0;N=W|0;L=(c[N>>2]|0)==64?1:((P|0)>(n|0)|(P|0)==(n|0)&v>>>0>2147483646>>>0)&1;n=(L|0)==1;if(n){lD(a,104)}else{lD(a,92)}kD(a,1684564852);bD(a,L);vD(a,(c[Y+(ba<<8)+52>>2]|0)>>>2&1|2);L=Y+(ba<<8)+16|0;r=c[L>>2]|0;if(n){sD(a,r,c[L+4>>2]|0);sD(a,c[L>>2]|0,c[L+4>>2]|0)}else{lD(a,r);lD(a,c[L>>2]|0)}r=Y+(ba<<8)+64|0;lD(a,c[r>>2]|0);lD(a,0);do{if((c[X>>2]|0)==0){if(n){sD(a,-1,-1);break}else{lD(a,-1);break}}else{if(n){sD(a,v,P);break}else{lD(a,v);break}}}while(0);lD(a,0);lD(a,0);tD(a,0);v=(ja|0)!=0;if(v){ka=c[(c[ja+8>>2]|0)+8>>2]|0}else{ka=0}tD(a,ka);P=Y+(ba<<8)+76|0;if((c[(c[P>>2]|0)+8>>2]|0)==1){tD(a,256)}else{tD(a,0)}tD(a,0);do{if(v){n=c[ja+88>>2]|0;do{if((n|0)==0){u=84}else{o=LGb(n,2390336,0,0)|0;if((o|0)==0){u=84;break}q=c[o+4>>2]|0;if((q|0)==0){u=84;break}o=kd(q|0)|0;if((o|0)==90){q=c[(c[P>>2]|0)+124>>2]|0;lD(a,0);lD(a,65536);lD(a,0);lD(a,-65536);lD(a,0);lD(a,0);lD(a,q<<16);lD(a,0);lD(a,1073741824);break}else if((o|0)==180){q=c[P>>2]|0;p=c[q+120>>2]|0;s=c[q+124>>2]|0;lD(a,-65536);lD(a,0);lD(a,0);lD(a,0);lD(a,-65536);lD(a,0);lD(a,p<<16);lD(a,s<<16);lD(a,1073741824);break}else if((o|0)==270){o=c[(c[P>>2]|0)+120>>2]|0;lD(a,0);lD(a,-65536);lD(a,0);lD(a,65536);lD(a,0);lD(a,0);lD(a,0);lD(a,o<<16);lD(a,1073741824);break}else{u=84;break}}}while(0);if((u|0)==84){u=0;lD(a,65536);lD(a,0);lD(a,0);lD(a,0);lD(a,65536);lD(a,0);lD(a,0);lD(a,0);lD(a,1073741824)}n=c[P>>2]|0;H=c[n+8>>2]|0;if(!((H|0)==0|(H|0)==3)){u=93;break}if((c[N>>2]|0)==2){lD(a,c[n+120>>2]<<16);lD(a,c[Y+(ba<<8)+100>>2]<<16);break}la=+(c[ja+80>>2]|0)/+(c[ja+84>>2]|0);H=Y+(ba<<8)+100|0;if(la!=0.0){if((c[H>>2]|0)==(c[n+124>>2]|0)){ma=la}else{u=90}}else{u=90}if((u|0)==90){u=0;ma=1.0}lD(a,~~(ma*+(c[n+120>>2]|0)*65536.0));lD(a,c[H>>2]<<16)}else{lD(a,65536);lD(a,0);lD(a,0);lD(a,0);lD(a,65536);lD(a,0);lD(a,0);lD(a,0);lD(a,1073741824);u=93}}while(0);if((u|0)==93){u=0;lD(a,0);lD(a,0)}v=c[S>>2]|0;if((v|0)<0){if((c[Z>>2]&2|0)==0){u=97}}else{if((v|0)>0){u=97}}if((u|0)==97){u=0;v=c[O>>2]|0;H=0;n=UIb(c[M>>2]|0,c[M+4>>2]|0,1e3,0,v,H,3)|0;o=G;s=0;p=Y+(ba<<8)+88|0;q=c[p>>2]|0;t=c[q+32>>2]|0;w=t;y=(t|0)<0|0?-1:0;t=q+8|0;q=wrc(c[t>>2]|0,c[t+4>>2]|0,w,y)|0;t=UIb(q,G,1e3,0,v,H,2)|0;H=G;v=0;q=((H|0)>(v|0)|(H|0)==(v|0)&t>>>0>2147483646>>>0)&1|((o|0)>(s|0)|(o|0)==(s|0)&n>>>0>2147483646>>>0)&1;s=(q|0)==1;v=0;D=(H|0)>(v|0)|(H|0)==(v|0)&t>>>0>0>>>0;v=D?2:1;C=ca(s?20:12,v)|0;lD(a,C+24|0);kD(a,1937007717);lD(a,C+16|0);kD(a,1953721445);bD(a,q);vD(a,0);lD(a,v);if(D){if(s){sD(a,t,H);sD(a,-1,-1)}else{lD(a,t);lD(a,-1)}lD(a,65536);na=y;oa=w;pa=o;qa=n}else{w=(c[p>>2]|0)+8|0;p=c[w>>2]|0;y=c[w+4>>2]|0;w=UIb(p,y,1e3,0,c[O>>2]|0,0,2)|0;D=G;v=0;if(!((D|0)<(v|0)|(D|0)==(v|0)&w>>>0<1>>>0)){break}w=0;v=(y|0)>(w|0)|(y|0)==(w|0)&p>>>0>0>>>0;w=xrc(0,0,p,y)|0;y=v?0:G;p=wrc(t,H,n,o)|0;na=y;oa=v?0:w;pa=G;qa=p}if(s){sD(a,qa,pa);sD(a,oa,na)}else{lD(a,qa);lD(a,oa)}lD(a,65536)}s=Y+(ba<<8)+104|0;if((c[s>>2]|0)!=0){lD(a,20);kD(a,1717924468);lD(a,12);kD(a,c[s>>2]|0);lD(a,c[Y+(ba<<8)+108>>2]|0)}s=fD(a,0,0,1)|0;p=G;lD(a,0);kD(a,1634296941);w=c[M+4>>2]|0;v=0;y=(c[N>>2]|0)==64?1:((w|0)>(v|0)|(w|0)==(v|0)&(c[M>>2]|0)>>>0>2147483646>>>0)&1;v=(y|0)==1;if(v){lD(a,44)}else{lD(a,32)}kD(a,1684563053);bD(a,y);vD(a,0);w=c[L>>2]|0;if(v){sD(a,w,c[L+4>>2]|0);sD(a,c[L>>2]|0,c[L+4>>2]|0)}else{lD(a,w);lD(a,c[L>>2]|0)}lD(a,c[O>>2]|0);do{if((c[X>>2]|0)==0){if(v){sD(a,-1,-1);break}else{lD(a,-1);break}}else{w=c[M>>2]|0;if(v){sD(a,w,c[M+4>>2]|0);break}else{lD(a,w);break}}}while(0);tD(a,c[Y+(ba<<8)+60>>2]|0);tD(a,0);do{if((y|0)!=0){if((c[N>>2]|0)!=2){break}KIb(0,16,2392760,(ra=i,i=i+1|0,i=i+7&-8,c[ra>>2]=0,ra)|0);i=ra}}while(0);bN(a,W);y=fD(a,0,0,1)|0;M=G;lD(a,0);kD(a,1718511981);v=c[(c[P>>2]|0)+8>>2]|0;do{if((v|0)==0){lD(a,20);kD(a,1684565366);lD(a,1);sD(a,0,0)}else if((v|0)==1){lD(a,16);kD(a,1684565363);lD(a,0);tD(a,0);tD(a,0)}else{X=c[Y+(ba<<8)+68>>2]|0;if((v|0)==3){if((X|0)==1954047348|(X|0)==942683747){cN(a,W);break}else{lD(a,12);kD(a,1684565358);lD(a,0);break}}else{if((X|0)==544240754){lD(a,28);kD(a,1684565352);lD(a,0);tD(a,0);tD(a,0);lD(a,0);lD(a,0);lD(a,0);break}else if((X|0)==1684237684){cN(a,W);break}else{break}}}}while(0);if((c[N>>2]|0)==2){bN(a,0)}v=fD(a,0,0,1)|0;X=G;lD(a,0);kD(a,1718511972);lD(a,28);kD(a,1717924452);lD(a,0);lD(a,1);lD(a,12);kD(a,543978101);lD(a,1);O=fD(a,0,0,1)|0;L=G;fD(a,v,X,0)|0;w=xrc(O,L,v,X)|0;lD(a,w);fD(a,O,L,0)|0;dN(a,W);L=fD(a,0,0,1)|0;O=G;fD(a,y,M,0)|0;w=xrc(L,O,y,M)|0;lD(a,w);fD(a,L,O,0)|0;O=fD(a,0,0,1)|0;L=G;fD(a,s,p,0)|0;w=xrc(O,L,s,p)|0;lD(a,w);fD(a,O,L,0)|0;if((c[N>>2]|0)==8){lD(a,52);kD(a,1684632949);kD(a,1414353749);lD(a,567431118);lD(a,-1148688036);lD(a,-87439552);lD(a,28);kD(a,1413764173);lD(a,65554);lD(a,10);lD(a,1438908416);lD(a,1);lD(a,0)}if((c[Y+(ba<<8)+68>>2]|0)==544240754){L=c[Y+(ba<<8)+128>>2]|0;mrc(T|0,0,1e3)|0;mU(T,1e3,c[c[L+28>>2]>>2]|0,c[Y+(ba<<8)+124>>2]|0,0,0,0,0,L);EFb(T,1e3,2473008,(ra=i,i=i+8|0,c[ra>>2]=c[r>>2],ra)|0)|0;i=ra;L=lrc(T|0)|0;lD(a,L+24|0);kD(a,1635017845);lD(a,L+16|0);kD(a,1769238120);lD(a,L+8|0);kD(a,544236659);dD(a,T,L)}L=c[P>>2]|0;do{if((c[L+8>>2]|0)==0){if((c[N>>2]|0)!=2){break}O=c[ja+80>>2]|0;if(!((O|0)!=0&+(O|0)/+(c[ja+84>>2]|0)!=1.0)){break}O=c[L+224>>2]|0;w=c[L+120>>2]|0;X=c[L+228>>2]|0;v=VIb(O,(O|0)<0|0?-1:0,w,(w|0)<0|0?-1:0,X,(X|0)<0|0?-1:0)|0;X=fD(a,0,0,1)|0;w=G;lD(a,0);kD(a,1953522036);lD(a,20);kD(a,1717922915);lD(a,0);O=v<<16;lD(a,O);lD(a,c[(c[P>>2]|0)+124>>2]<<16);lD(a,20);kD(a,1718579824);lD(a,0);lD(a,O);lD(a,c[(c[P>>2]|0)+124>>2]<<16);lD(a,20);kD(a,1718578789);lD(a,0);lD(a,c[(c[P>>2]|0)+120>>2]<<16);lD(a,c[(c[P>>2]|0)+124>>2]<<16);O=fD(a,0,0,1)|0;v=G;fD(a,X,w,0)|0;o=xrc(O,v,X,w)|0;lD(a,o);fD(a,O,v,0)|0;}}while(0);P=fD(a,0,0,1)|0;L=G;fD(a,R,Q,0)|0;N=xrc(P,L,R,Q)|0;lD(a,N);fD(a,P,L,0)|0;ia=c[m>>2]|0}L=ba+1|0;if((L|0)<(ia|0)){ba=L;U=ia}else{sa=Z;break a}}KIb(0,0,2631864,(ra=i,i=i+24|0,c[ra>>2]=2390944,c[ra+8>>2]=2627904,c[ra+16>>2]=1872,ra)|0);i=ra;Hd()}else{sa=b+52|0}}while(0);if((c[sa>>2]&2|0)!=0){sa=fD(a,0,0,1)|0;ra=G;lD(a,0);kD(a,2019915373);if((c[m>>2]|0)>0){ia=b+48|0;ja=0;do{oa=c[ia>>2]|0;lD(a,32);kD(a,2019914356);lD(a,0);lD(a,c[oa+(ja<<8)+64>>2]|0);lD(a,1);lD(a,0);lD(a,0);lD(a,0);ja=ja+1|0;}while((ja|0)<(c[m>>2]|0))}m=fD(a,0,0,1)|0;ja=G;fD(a,sa,ra,0)|0;ia=xrc(m,ja,sa,ra)|0;lD(a,ia);fD(a,m,ja,0)|0;}if((c[_>>2]|0)==8){ja=LGb(c[d+1140>>2]|0,2607144,0,0)|0;if((ja|0)==0){ta=0;ua=0;va=fD(a,ta,ua,1)|0;wa=G;xa=fD(a,k,l,0)|0;ya=G;za=xrc(va,wa,k,l)|0;Aa=G;Ba=za;Ca=Ba;lD(a,Ca);Da=fD(a,va,wa,0)|0;Ea=G;i=e;return}m=fD(a,0,0,1)|0;ia=G;lD(a,0);kD(a,1684632949);kD(a,1414353749);lD(a,567431118);lD(a,-1148688036);lD(a,-87439552);ra=fD(a,0,0,1)|0;sa=G;lD(a,0);kD(a,1413764173);tD(a,4);tD(a,12);lD(a,11);tD(a,21956);tD(a,0);tD(a,540);aN(a,2483528,2485744,4);aN(a,c[ja+4>>2]|0,2485744,1);aN(a,2482936,2491992,3);ja=fD(a,0,0,1)|0;oa=G;fD(a,ra,sa,0)|0;qa=xrc(ja,oa,ra,sa)|0;lD(a,qa);fD(a,ja,oa,0)|0;oa=fD(a,0,0,1)|0;ja=G;fD(a,m,ia,0)|0;qa=xrc(oa,ja,m,ia)|0;lD(a,qa);fD(a,oa,ja,0)|0;ta=0;ua=0;va=fD(a,ta,ua,1)|0;wa=G;xa=fD(a,k,l,0)|0;ya=G;za=xrc(va,wa,k,l)|0;Aa=G;Ba=za;Ca=Ba;lD(a,Ca);Da=fD(a,va,wa,0)|0;Ea=G;i=e;return}ja=c[d+24>>2]|0;oa=b+48|0;b=0;while(1){if(!(b>>>0<ja>>>0)){break}if((c[(c[(c[oa>>2]|0)+(b<<8)+76>>2]|0)+88>>2]&8388608|0)==0){b=b+1|0}else{u=182;break}}if((u|0)==182){ta=0;ua=0;va=fD(a,ta,ua,1)|0;wa=G;xa=fD(a,k,l,0)|0;ya=G;za=xrc(va,wa,k,l)|0;Aa=G;Ba=za;Ca=Ba;lD(a,Ca);Da=fD(a,va,wa,0)|0;Ea=G;i=e;return}if((_D(g)|0)<0){ta=0;ua=0;va=fD(a,ta,ua,1)|0;wa=G;xa=fD(a,k,l,0)|0;ya=G;za=xrc(va,wa,k,l)|0;Aa=G;Ba=za;Ca=Ba;lD(a,Ca);Da=fD(a,va,wa,0)|0;Ea=G;i=e;return}u=c[_>>2]|0;do{if((u&4|0)==0){_=c[g>>2]|0;if((u|0)==2){YM(d,_,2575816,2615296,0)|0;YM(d,c[g>>2]|0,2574520,2607144,0)|0;YM(d,c[g>>2]|0,2572912,2602672,0)|0;YM(d,c[g>>2]|0,2571520,2588336,0)|0;YM(d,c[g>>2]|0,2570544,2577288,0)|0;YM(d,c[g>>2]|0,2566904,2562720,0)|0;YM(d,c[g>>2]|0,2561136,2594520,0)|0;YM(d,c[g>>2]|0,2559456,2594520,0)|0;YM(d,c[g>>2]|0,2558272,2598856,0)|0;YM(d,c[g>>2]|0,2556928,2580960,0)|0;break}b=fD(_,0,0,1)|0;oa=G;lD(_,0);kD(_,1635018093);lD(_,0);lD(_,33);kD(_,1919706216);lD(_,0);lD(_,0);kD(_,1919509613);kD(_,1819308129);lD(_,0);lD(_,0);bD(_,0);ja=fD(_,0,0,1)|0;qa=G;lD(_,0);kD(_,1953721449);YM(d,_,2574520,2607144,1)|0;YM(d,_,2575816,2615296,1)|0;YM(d,_,2548560,2545168,1)|0;YM(d,_,2543688,2542136,1)|0;YM(d,_,2571520,2588336,1)|0;YM(d,_,2570544,2577288,1)|0;if((YM(d,_,2540736,2539536,1)|0)==0){ZM(_,2540736,2538216,0,1)|0}YM(d,_,2559456,2594520,1)|0;YM(d,_,2558272,2598856,1)|0;YM(d,_,2556928,2580960,1)|0;YM(d,_,2536592,2535352,1)|0;YM(d,_,2534504,2530800,1)|0;YM(d,_,2527472,2526176,1)|0;YM(d,_,2524848,2523776,1)|0;YM(d,_,2522832,2521736,1)|0;YM(d,_,2520656,2519688,1)|0;YM(d,_,2518824,2515488,1)|0;_M(d,_,2512304,2510912,4);_M(d,_,2509640,2508840,4);_M(d,_,2508024,2507112,1);_M(d,_,2506184,2505304,1);_M(d,_,2504632,2501576,1);ia=d+1140|0;$M(_,c[ia>>2]|0,0);$M(_,c[ia>>2]|0,1);m=LGb(c[ia>>2]|0,2498864,0,0)|0;do{if((m|0)!=0){ia=kd(c[m+4>>2]|0)|0;if((ia|0)==0){break}lD(_,26);kD(_,1869639028);lD(_,18);kD(_,1635017060);lD(_,21);lD(_,0);tD(_,ia)}}while(0);m=fD(_,0,0,1)|0;ia=G;fD(_,ja,qa,0)|0;sa=xrc(m,ia,ja,qa)|0;lD(_,sa);fD(_,m,ia,0)|0;ia=fD(_,0,0,1)|0;m=G;fD(_,b,oa,0)|0;sa=xrc(ia,m,b,oa)|0;lD(_,sa);fD(_,ia,m,0)|0;}else{XM(c[g>>2]|0,d,2620616,2615296);XM(c[g>>2]|0,d,2609760,2607144);XM(c[g>>2]|0,d,2604776,2602672);XM(c[g>>2]|0,d,2600656,2598856);XM(c[g>>2]|0,d,2597024,2594520);XM(c[g>>2]|0,d,2593208,2588336);XM(c[g>>2]|0,d,2583232,2580960);XM(c[g>>2]|0,d,2579104,2577288)}}while(0);u=d+1132|0;if((c[u>>2]|0)!=0){m=c[g>>2]|0;ia=fD(m,0,0,1)|0;sa=G;ra=c[u>>2]|0;u=ra>>>0>255>>>0?255:ra;lD(m,0);kD(m,1819306083);lD(m,16777216);lD(m,0);bD(m,u);if((u|0)>0){ra=d+1136|0;d=f|0;na=f+4|0;pa=0;do{ka=c[(c[ra>>2]|0)+(pa<<2)>>2]|0;ha=ka+16|0;j=c[ha>>2]|0;Z=c[ha+4>>2]|0;c[d>>2]=1;c[na>>2]=1e7;ha=XIb(j,Z,ka+4|0,f)|0;sD(m,ha,G);ha=LGb(c[ka+32>>2]|0,2607144,0,0)|0;if((ha|0)==0){bD(m,0)}else{ka=ha+4|0;ha=lrc(c[ka>>2]|0)|0;Z=ha>>>0>255>>>0?255:ha;bD(m,Z);dD(m,c[ka>>2]|0,Z)}pa=pa+1|0;}while((pa|0)<(u|0))}u=fD(m,0,0,1)|0;pa=G;fD(m,ia,sa,0)|0;f=xrc(u,pa,ia,sa)|0;lD(m,f);fD(m,u,pa,0)|0;}pa=aE(c[g>>2]|0,h)|0;if((pa|0)>0){lD(a,pa+8|0);kD(a,1635017845);dD(a,c[h>>2]|0,pa)}kJb(c[h>>2]|0);ta=0;ua=0;va=fD(a,ta,ua,1)|0;wa=G;xa=fD(a,k,l,0)|0;ya=G;za=xrc(va,wa,k,l)|0;Aa=G;Ba=za;Ca=Ba;lD(a,Ca);Da=fD(a,va,wa,0)|0;Ea=G;i=e;return}function SM(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=a+12|0;j=c[h>>2]|0;k=j;l=j+52|0;m=c[l>>2]|0;if((m&2|0)==0){i=b;return}do{if((m&4|0)==0){n=j+72|0;if((c[n>>2]|0)!=0){break}o=a+16|0;p=fD(c[o>>2]|0,0,0,1)|0;q=G;r=j+48|0;s=j+16|0;t=c[s>>2]|0;u=0;while(1){if((u|0)>=(t|0)){break}if((c[(c[r>>2]|0)+(u<<8)+4>>2]|0)==0){v=55;break}else{u=u+1|0}}if((v|0)==55){i=b;return}u=c[h>>2]|0;t=bE(e)|0;if((t|0)<0){w=t}else{RM(c[e>>2]|0,u,a);w=dE(c[e>>2]|0)|0}u=c[s>>2]|0;if((u|0)>0){t=wrc(p,q,8,0)|0;x=wrc(t,G,w,(w|0)<0|0?-1:0)|0;t=G;y=c[r>>2]|0;z=0;do{A=y+(z<<8)+184|0;c[A>>2]=x;c[A+4>>2]=t;z=z+1|0;}while((z|0)<(u|0))}RM(c[o>>2]|0,k,a);u=j+92|0;z=aE(c[u>>2]|0,f)|0;c[u>>2]=0;lD(c[o>>2]|0,z+8|0);kD(c[o>>2]|0,1952539757);dD(c[o>>2]|0,c[f>>2]|0,z);kJb(c[f>>2]|0);c[n>>2]=(c[n>>2]|0)+1;z=j+40|0;c[z>>2]=0;c[z+4>>2]=0;if((c[s>>2]|0)>0){z=c[r>>2]|0;u=0;do{t=z+(u<<8)+4|0;if((c[t>>2]|0)!=0){x=z+(u<<8)+112|0;y=z+(u<<8)+24|0;q=wrc(c[y>>2]|0,c[y+4>>2]|0,c[x>>2]|0,c[x+4>>2]|0)|0;x=(c[z+(u<<8)+88>>2]|0)+8|0;y=xrc(q,G,c[x>>2]|0,c[x+4>>2]|0)|0;x=z+(u<<8)+192|0;q=wrc(y,G,c[x>>2]|0,c[x+4>>2]|0)|0;c[x>>2]=q;c[x+4>>2]=G}c[t>>2]=0;u=u+1|0;}while((u|0)<(c[s>>2]|0))}eD(c[o>>2]|0);i=b;return}}while(0);f=j+16|0;if((c[f>>2]|0)<=0){i=b;return}w=j+48|0;e=0;h=0;s=-1;u=0;z=m;while(1){m=c[w>>2]|0;r=(z&16|0)==0;n=m+(u<<8)+184|0;c[n>>2]=r?h:0;c[n+4>>2]=r?e:0;r=c[m+(u<<8)+180>>2]|0;if((r|0)==0){B=s;C=e;D=h}else{m=fD(r,0,0,1)|0;r=wrc(m,G,h,e)|0;B=(s|0)<0?u:s;C=G;D=r}r=u+1|0;E=c[f>>2]|0;if((r|0)>=(E|0)){break}e=C;h=D;s=B;u=r;z=c[l>>2]|0}if((D|0)==0&(C|0)==0){i=b;return}a:do{if((E|0)>0){z=j+48|0;u=a+16|0;s=j+88|0;h=j+72|0;e=C;w=D;r=0;while(1){m=c[z>>2]|0;n=m+(r<<8)+4|0;t=c[n>>2]|0;if((t|0)==0){F=0;H=0}else{x=m+(r<<8)+112|0;q=m+(r<<8)+24|0;y=wrc(c[q>>2]|0,c[q+4>>2]|0,c[x>>2]|0,c[x+4>>2]|0)|0;x=(c[m+(r<<8)+88>>2]|0)+8|0;q=xrc(y,G,c[x>>2]|0,c[x+4>>2]|0)|0;F=G;H=q}do{if((c[l>>2]&16|0)==0){if((r|0)==(B|0)){I=e;J=w;K=-1;v=34}else{L=e;M=w;N=t;v=49}}else{q=c[m+(r<<8)+180>>2]|0;if((q|0)==0){O=e;P=w;break}x=fD(q,0,0,1)|0;I=G;J=x;K=r;v=34}}while(0);if((v|0)==34){v=0;eD(c[u>>2]|0);t=m+(r<<8)+208|0;x=c[t>>2]|0;q=x+1|0;c[t>>2]=q;y=m+(r<<8)+216|0;if(q>>>0<(c[y>>2]|0)>>>0){Q=q;R=m+(r<<8)+212|0}else{q=x+65|0;x=m+(r<<8)+212|0;if((oJb(x,q,32)|0)!=0){break}c[y>>2]=q;Q=c[t>>2]|0;R=x}x=Q-1|0;q=c[R>>2]|0;y=fD(c[u>>2]|0,0,0,1)|0;p=q+(x<<5)|0;c[p>>2]=y;c[p+4>>2]=G;p=(c[z>>2]|0)+(r<<8)+192|0;y=c[p+4>>2]|0;A=q+(x<<5)+8|0;c[A>>2]=c[p>>2];c[A+4>>2]=y;y=q+(x<<5)+16|0;c[y>>2]=H;c[y+4>>2]=F;y=c[u>>2]|0;A=fD(y,0,0,1)|0;p=G;S=c[s>>2]|0;if((S|0)>0){T=0;U=S;while(1){S=c[t>>2]|0;V=-2-T+S|0;W=S+~V|0;do{if((V|0)<0){X=U}else{S=(c[R>>2]|0)+(V<<5)+24|0;fD(y,c[S>>2]|0,c[S+4>>2]|0,0)|0;lD(y,(W<<4)+29|0);kD(y,1684632949);dD(y,822472,16);bD(y,1);vD(y,0);bD(y,W);if((W|0)>0){S=V+1|0;Y=0;do{Z=S+Y|0;_=(c[R>>2]|0)+(Z<<5)+8|0;sD(y,c[_>>2]|0,c[_+4>>2]|0);_=(c[R>>2]|0)+(Z<<5)+16|0;sD(y,c[_>>2]|0,c[_+4>>2]|0);Y=Y+1|0;}while((Y|0)<(W|0))}Y=c[s>>2]|0;if((W|0)>=(Y|0)){X=Y;break}S=Y-W<<4;lD(y,S);kD(y,1701147238);cD(y,0,S-8|0);X=c[s>>2]|0}}while(0);W=T+1|0;if((W|0)<(X|0)){T=W;U=X}else{break}}}fD(y,A,p,0)|0;U=c[u>>2]|0;if((bE(d)|0)>=0){VM(c[d>>2]|0,k,K,0)|0;VM(U,k,K,dE(c[d>>2]|0)|0)|0}U=m+(r<<8)+200|0;T=c[U+4>>2]|0;t=q+(x<<5)+24|0;c[t>>2]=c[U>>2];c[t+4>>2]=T;c[h>>2]=(c[h>>2]|0)+1;T=c[u>>2]|0;t=wrc(J,I,8,0)|0;lD(T,t);kD(c[u>>2]|0,1952539757);L=I;M=J;N=c[n>>2]|0;v=49}do{if((v|0)==49){v=0;if((N|0)!=0){t=m+(r<<8)+192|0;T=wrc(c[t>>2]|0,c[t+4>>2]|0,H,F)|0;c[t>>2]=T;c[t+4>>2]=G}c[n>>2]=0;t=m+(r<<8)+180|0;T=c[t>>2]|0;if((T|0)==0){O=L;P=M;break}U=aE(T,g)|0;c[t>>2]=0;dD(c[u>>2]|0,c[g>>2]|0,U);kJb(c[g>>2]|0);O=L;P=M}}while(0);m=r+1|0;if((m|0)<(c[f>>2]|0)){e=O;w=P;r=m}else{$=u;break a}}i=b;return}else{$=a+16|0}}while(0);a=j+40|0;c[a>>2]=0;c[a+4>>2]=0;eD(c[$>>2]|0);i=b;return}function TM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;g=b+84|0;h=c[b+80>>2]|0;j=(c[g>>2]|0)+h|0;k=c[b+240>>2]|0;l=c[b+244>>2]|0;m=c[b+248>>2]|0;n=b+112|0;o=c[n>>2]|0;p=c[n+4>>2]|0;n=pJb(h+16|0)|0;if((n|0)==0){q=-12;i=f;return q|0}h=c[g>>2]|0;g=j;a:do{if((g-h|0)>=4){r=-1;s=h;while(1){if(!(s>>>0<j>>>0)){break a}t=r<<8;if((t|0)==256){break}else{r=d[s]|t;s=s+1|0}}r=s-3|0;if(r>>>0<j>>>0){u=0;v=0;w=0;x=r}else{break}b:while(1){r=x;while(1){t=r+4|0;c:do{if((g-t|0)<4){z=j}else{A=-1;B=t;while(1){if(!(B>>>0<j>>>0)){z=j;break c}C=A<<8;if((C|0)==256){break}else{A=d[B]|C;B=B+1|0}}z=B-3|0}}while(0);A=z-r|0;C=A-4|0;if((C|0)>=1){if((C|0)<4){D=t;E=n;F=0;while(1){a[E]=a[D]|0;G=F+1|0;if((G|0)<(C|0)){D=D+1|0;E=E+1|0;F=G}else{H=C;break}}}else{F=A-5|0;E=t;D=0;G=0;while(1){I=a[E]|0;do{if(I<<24>>24==3&(G|0)>1){if((a[E-1|0]|0)!=0){J=20;break}if(!((a[E-2|0]|0)==0&(G|0)<(F|0))){J=20;break}K=E+1|0;L=a[K]|0;if(!((L&255)>>>0<4>>>0)){J=20;break}a[n+D|0]=L;M=G+1|0;N=K}else{J=20}}while(0);if((J|0)==20){J=0;a[n+D|0]=I;M=G;N=E}B=D+1|0;K=M+1|0;if((K|0)<(C|0)){E=N+1|0;D=B;G=K}else{H=B;break}}}O=H<<3;P=O>>>0>2147483639>>>0;G=r;if((d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)==251723776){break}}if(z>>>0<j>>>0){r=z}else{J=29;break b}}r=P?0:n;G=P?8:O+8|0;D=r;E=G>>>0>2>>>0?2:G;if(((d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24)&192|0)!=192){J=25;break}D=r+(E>>>3)|0;C=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&2)>>>29;D=E+3|0;E=G>>>0>D>>>0?D:G;D=-E|0;F=G-E|0;if((D|0)>35){Q=D}else{Q=(F|0)<35?F:35}F=E+1+Q|0;E=G>>>0>F>>>0?F:G;G=d[r+(E>>>3)|0]<<(E&7)>>>7&1;if(z>>>0<j>>>0){u=1;v=C;w=G;x=z}else{R=G;S=C;break}}if((J|0)==25){kJb(n);q=-38;i=f;return q|0}else if((J|0)==29){if((u|0)==0){break}else{R=w;S=v}}s=(o|0)!=0|(p|0)!=(-2147483648|0);C=c[(c[b+76>>2]|0)+108>>2]|0;G=e;y=je((((((R|((S<<4|S)<<8|393216))<<1|(k|0)==0&s&1)<<1|(l|0)==0&s&1)<<1|(m|0)==0)<<10|C>>>24)^8192|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;G=C<<8;s=C>>>16&255;C=8;E=e+4|0;while(1){a[E]=s;r=G;G=r<<8;F=C+8|0;if((F|0)<32){s=r>>>16&255;C=F;E=E+1|0}else{break}}G=0;kJb(n);q=0;i=f;return q|0}}while(0);kJb(n);q=-38;i=f;return q|0}function UM(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+24|0;d=c[b>>2]|0;e=a+48|0;if((d|0)!=0){f=e;g=c[f>>2]|0;h=c[g+(d<<8)+76>>2]|0;if((h|0)==0){i=d;j=g}else{mJb(h+96|0);i=c[b>>2]|0;j=c[f>>2]|0}mJb(j+(i<<8)+76|0)}i=a+16|0;if((c[i>>2]|0)<=0){mJb(e);return}j=e;f=a+20|0;a=0;do{b=c[j>>2]|0;h=c[b+(a<<8)+68>>2]|0;do{if((h|0)==544240754){lN(b+(a<<8)|0)}else if((h|0)==1684237684){if((c[f>>2]|0)==0){break}mJb(b+(a<<8)+76|0)}}while(0);mJb((c[j>>2]|0)+(a<<8)+88|0);mJb((c[j>>2]|0)+(a<<8)+212|0);b=c[j>>2]|0;if((c[b+(a<<8)+80>>2]|0)!=0){mJb(b+(a<<8)+84|0)}a=a+1|0;}while((a|0)<(c[i>>2]|0));mJb(e);return}function VM(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=fD(a,0,0,1)|0;g=G;lD(a,0);kD(a,1718579053);lD(a,16);kD(a,1684563565);lD(a,0);lD(a,c[b+72>>2]|0);h=b+16|0;i=c[h>>2]|0;if((i|0)<=0){j=0;k=0;l=fD(a,j,k,1)|0;m=G;n=fD(a,f,g,0)|0;o=G;p=xrc(l,m,f,g)|0;q=G;r=p;s=r;lD(a,s);t=fD(a,l,m,0)|0;u=G;return s|0}v=b+48|0;w=(d|0)<0;x=b+52|0;y=e+8|0;e=0;z=b+4|0;A=b+88|0;b=0;B=i;while(1){i=c[v>>2]|0;C=i+(b<<8)|0;do{if(w|(b|0)==(d|0)){D=i+(b<<8)+4|0;if((c[D>>2]|0)==0){E=B;break}F=fD(a,0,0,1)|0;H=G;lD(a,0);kD(a,1717662324);I=fD(a,0,0,1)|0;J=G;K=(c[D>>2]|0)==0?65561:57;L=(c[x>>2]&256|0)==0?K:K&65592;K=(c[C>>2]|0)==64?L&65568:L;lD(a,0);kD(a,1684563572);bD(a,0);vD(a,K);L=i+(b<<8)+64|0;lD(a,c[L>>2]|0);if((K&1|0)!=0){sD(a,f,g)}if((K&8|0)!=0){M=WM(C,0)|0;N=i+(b<<8)+152|0;c[N>>2]=M;c[N+4>>2]=(M|0)<0|0?-1:0;lD(a,M)}if((K&16|0)==0){c[i+(b<<8)+164>>2]=-1}else{if((c[D>>2]|0)==0){O=1}else{O=c[(c[i+(b<<8)+88>>2]|0)+16>>2]|0}c[i+(b<<8)+164>>2]=O;lD(a,O)}if((K&32|0)!=0){K=(c[(c[i+(b<<8)+76>>2]|0)+8>>2]|0)==0?16842752:33554432;c[i+(b<<8)+160>>2]=K;lD(a,K)}K=fD(a,0,0,1)|0;M=G;fD(a,I,J,0)|0;N=xrc(K,M,I,J)|0;lD(a,N);fD(a,K,M,0)|0;M=fD(a,0,0,1)|0;K=G;if((c[D>>2]|0)>0){N=i+(b<<8)+152|0;J=i+(b<<8)+88|0;I=i+(b<<8)+164|0;P=i+(b<<8)+160|0;Q=1;R=0;while(1){S=WM(C,R)|0;T=(S|0)==(c[N>>2]|0)&(((S|0)<0|0?-1:0)|0)==(c[N+4>>2]|0)?Q:Q|256;S=c[J>>2]|0;U=(c[S+(R*40|0)+16>>2]|0)==(c[I>>2]|0)?T:T|512;if((R|0)>0){V=(((c[S+(R*40|0)+36>>2]&1|0)!=0?33554432:16842752)|0)==(c[P>>2]|0)?U:U|1024}else{V=U}U=R+1|0;if((U|0)<(c[D>>2]|0)){Q=V;R=U}else{W=V;break}}}else{W=1}R=(W&1024|0)==0?W|4:W;Q=(c[i+(b<<8)+52>>2]&1|0)==0?R:R|2048;lD(a,0);kD(a,1853190772);bD(a,0);vD(a,Q);lD(a,c[D>>2]|0);do{if((c[x>>2]&272|0)==256){if((c[L>>2]|0)==1){X=24;break}lD(a,0)}else{X=24}}while(0);if((X|0)==24){X=0;L=i+(b<<8)+184|0;R=wrc(c[L>>2]|0,c[L+4>>2]|0,y,e)|0;L=c[i+(b<<8)+88>>2]|0;P=wrc(R,G,c[L>>2]|0,c[L+4>>2]|0)|0;lD(a,P)}if((Q&4|0)!=0){lD(a,(c[(c[i+(b<<8)+88>>2]|0)+36>>2]&1|0)!=0?33554432:16842752)}if((c[D>>2]|0)>0){P=(Q&256|0)==0;L=(Q&512|0)==0;R=(Q&1024|0)==0;I=(Q&2048|0)==0;J=i+(b<<8)+88|0;N=0;do{if(!P){lD(a,WM(C,N)|0)}if(!L){lD(a,c[(c[J>>2]|0)+(N*40|0)+16>>2]|0)}if(!R){lD(a,(c[(c[J>>2]|0)+(N*40|0)+36>>2]&1|0)!=0?33554432:16842752)}if(!I){lD(a,c[(c[J>>2]|0)+(N*40|0)+32>>2]|0)}N=N+1|0;}while((N|0)<(c[D>>2]|0))}D=fD(a,0,0,1)|0;N=G;fD(a,M,K,0)|0;J=xrc(D,N,M,K)|0;lD(a,J);fD(a,D,N,0)|0;do{if((c[z>>2]|0)==64){N=fD(a,0,0,1)|0;D=G;lD(a,0);kD(a,1684632949);dD(a,822456,16);bD(a,1);vD(a,0);J=i+(b<<8)+192|0;sD(a,c[J>>2]|0,c[J+4>>2]|0);J=i+(b<<8)+112|0;I=i+(b<<8)+24|0;R=wrc(c[I>>2]|0,c[I+4>>2]|0,c[J>>2]|0,c[J+4>>2]|0)|0;J=(c[i+(b<<8)+88>>2]|0)+8|0;I=xrc(R,G,c[J>>2]|0,c[J+4>>2]|0)|0;sD(a,I,G);I=fD(a,0,0,1)|0;J=G;fD(a,N,D,0)|0;R=xrc(I,J,N,D)|0;lD(a,R);fD(a,I,J,0)|0;J=c[A>>2]|0;if((J|0)==0){break}I=J<<4;J=I+21|0;R=fD(a,0,0,1)|0;D=i+(b<<8)+200|0;c[D>>2]=R;c[D+4>>2]=G;lD(a,I+29|0);kD(a,1701147238);if((J|0)>0){Y=0}else{break}do{bD(a,0);Y=Y+1|0;}while((Y|0)<(J|0))}}while(0);K=fD(a,0,0,1)|0;M=G;fD(a,F,H,0)|0;J=xrc(K,M,F,H)|0;lD(a,J);fD(a,K,M,0)|0;E=c[h>>2]|0}else{E=B}}while(0);i=b+1|0;if((i|0)<(E|0)){b=i;B=E}else{break}}j=0;k=0;l=fD(a,j,k,1)|0;m=G;n=fD(a,f,g,0)|0;o=G;p=xrc(l,m,f,g)|0;q=G;r=p;s=r;lD(a,s);t=fD(a,l,m,0)|0;u=G;return s|0}function WM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+4>>2]|0;if((e|0)<=(b|0)){f=0;i=d;return f|0}g=b+1|0;if((g|0)==(e|0)){e=a+24|0;h=a+112|0;j=wrc(c[h>>2]|0,c[h+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;k=G;l=j;m=c[a+88>>2]|0}else{j=c[a+88>>2]|0;a=j+(g*40|0)+8|0;k=c[a+4>>2]|0;l=c[a>>2]|0;m=j}j=m+(b*40|0)+8|0;b=xrc(l,k,c[j>>2]|0,c[j+4>>2]|0)|0;j=G;k=-1;if(!((j|0)>(k|0)|(j|0)==(k|0)&b>>>0>-1>>>0)){KIb(0,0,2631864,(n=i,i=i+24|0,c[n>>2]=2629656,c[n+8>>2]=2627904,c[n+16>>2]=621,n)|0);i=n;Hd();return 0}k=0;if(!((j|0)<(k|0)|(j|0)==(k|0)&b>>>0<-2147483648>>>0)){KIb(0,0,2631864,(n=i,i=i+24|0,c[n>>2]=2626560,c[n+8>>2]=2627904,c[n+16>>2]=622,n)|0);i=n;Hd();return 0}f=b;i=d;return f|0}function XM(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=fD(b,0,0,1)|0;i=G;j=e+1140|0;e=LGb(c[j>>2]|0,g,0,0)|0;if((e|0)==0){return}g=e+4|0;e=c[g>>2]|0;k=a[e]|0;if(k<<24>>24==0){return}else{l=e;m=0;n=k}a:while(1){k=n&255;e=k>>>1&64;if((k&192|0)==128|(n&255)>>>0>253>>>0){break}o=l+1|0;if((e&k|0)==0){p=o}else{q=k;k=e;e=o;while(1){o=(d[e]|0)-128|0;if(o>>>0>63>>>0){break a}r=o+(q<<6)|0;o=k<<5;s=e+1|0;if((r&o|0)==0){p=s;break}else{q=r;k=o;e=s}}}t=m+1|0;e=a[p]|0;if(e<<24>>24==0){u=8;break}else{l=p;m=t;n=e}}do{if((u|0)==8){if((t|0)!=0){break}return}}while(0);lD(b,0);kD(b,(d[f+1|0]|0)<<8|(d[f]|0)|(d[f+2|0]|0)<<16|(d[f+3|0]|0)<<24);lD(b,0);do{if((irc(f,2579104)|0)==0){tD(b,kd(c[g>>2]|0)|0)}else{tD(b,5575);t=c[g>>2]|0;dD(b,t,(lrc(t|0)|0)+1|0);if((irc(f,2593208)|0)!=0){break}t=LGb(c[j>>2]|0,2494736,0,0)|0;if((t|0)==0){break}bD(b,kd(c[t+4>>2]|0)|0)}}while(0);j=fD(b,0,0,1)|0;f=G;fD(b,h,i,0)|0;g=xrc(j,f,h,i)|0;lD(b,g);fD(b,j,f,0)|0;return}function YM(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+16|0;h=a+1140|0;a=LGb(c[h>>2]|0,e,0,0)|0;if((a|0)==0){j=0;i=g;return j|0}k=lrc(c[a>>2]|0)|0;l=g|0;Rb(l|0,16,2486640,(m=i,i=i+8|0,c[m>>2]=e,m)|0)|0;i=m;m=LGb(c[h>>2]|0,l,0,2)|0;a:do{if((m|0)==0){n=0;o=a+4|0}else{e=k+4|0;p=a+4|0;q=m;while(1){r=c[q>>2]|0;do{if((lrc(r|0)|0)==(e|0)){if((irc(c[p>>2]|0,c[q+4>>2]|0)|0)!=0){break}s=EJ(r+(k+1)|0,1)|0;if((s|0)>-1){n=s;o=p;break a}}}while(0);r=LGb(c[h>>2]|0,l,q,2)|0;if((r|0)==0){n=0;o=p;break}else{q=r}}}}while(0);j=ZM(b,d,c[o>>2]|0,n,f)|0;i=g;return j|0}function ZM(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)==0){h=0;return h|0}if((a[e]|0)==0){h=0;return h|0}i=fD(b,0,0,1)|0;j=G;lD(b,0);kD(b,d[c+1|0]<<8|d[c]|d[c+2|0]<<16|d[c+3|0]<<24);if((g|0)==0){if((f|0)==0){k=EJ(2491992,1)|0}else{k=f}tD(b,lrc(e|0)|0);tD(b,k);dD(b,e,lrc(e|0)|0)}else{lD(b,(lrc(e|0)|0)+16|0);kD(b,1635017060);lD(b,1);lD(b,0);dD(b,e,lrc(e|0)|0)}e=fD(b,0,0,1)|0;k=G;fD(b,i,j,0)|0;f=xrc(e,k,i,j)|0;j=f;lD(b,j);fD(b,e,k,0)|0;h=j;return h|0}function _M(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0;if(!((g|0)==4|(g|0)==1)){return}h=LGb(c[a+1140>>2]|0,f,0,0)|0;if((h|0)==0){return}f=kd(c[h+4>>2]|0)|0;lD(b,g+24|0);kD(b,(d[e+1|0]|0)<<8|(d[e]|0)|(d[e+2|0]|0)<<16|(d[e+3|0]|0)<<24);lD(b,g+16|0);kD(b,1635017060);lD(b,21);lD(b,0);e=f&255;if((g|0)==4){lD(b,e);return}else{bD(b,e);return}}function $M(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=(e|0)!=0;e=LGb(b,f?2495672:2494736,0,0)|0;if((e|0)==0){return}b=c[e+4>>2]|0;e=kd(b|0)|0;if((e|0)==0){return}g=_b(b|0,47)|0;if((g|0)==0){h=0}else{h=kd(g+1|0)|0}lD(a,32);g=f?2493584:2492712;kD(a,(d[g+1|0]|0)<<8|(d[g]|0)|(d[g+2|0]|0)<<16|(d[g+3|0]|0)<<24);lD(a,24);kD(a,1635017060);lD(a,0);lD(a,0);tD(a,0);tD(a,e);tD(a,h);tD(a,0);return}function aN(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=a[c]|0;do{if(g<<24>>24==0){h=0}else{i=c;j=0;k=g;a:while(1){l=k&255;m=l>>>1&64;if((l&192|0)==128|(k&255)>>>0>253>>>0){n=15;break}o=i+1|0;if((m&l|0)==0){p=o}else{q=l;l=m;m=o;while(1){o=(d[m]|0)-128|0;if(o>>>0>63>>>0){n=15;break a}r=o+(q<<6)|0;o=l<<5;s=m+1|0;if((r&o|0)==0){p=s;break}else{q=r;l=o;m=s}}}t=j+1|0;m=a[p]|0;if(m<<24>>24==0){n=7;break}else{i=p;j=t;k=m}}if((n|0)==7){if((t|0)>=0){h=t;break}return}else if((n|0)==15){return}}}while(0);tD(b,(h<<1)+12|0);lD(b,f);tD(b,((d[e+1|0]|0)<<5&992|(d[e]|0)<<10&31744|a[e+2|0]&31)&65535);tD(b,1);e=a[c]|0;b:do{if(!(e<<24>>24==0)){f=c;h=e;c:while(1){t=h&255;p=t>>>1&64;if((t&192|0)==128|(h&255)>>>0>253>>>0){n=15;break}g=f+1|0;if((p&t|0)==0){u=t;v=p;w=g}else{k=t;t=p;p=g;while(1){g=(d[p]|0)-128|0;if(g>>>0>63>>>0){n=15;break c}j=g+(k<<6)|0;g=t<<5;i=p+1|0;if((j&g|0)==0){u=j;v=g;w=i;break}else{k=j;t=g;p=i}}}tD(b,(v<<1)-1&u);p=a[w]|0;if(p<<24>>24==0){break b}else{f=w;h=p}}if((n|0)==15){return}}}while(0);tD(b,0);return}function bN(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+32|0;f=e|0;g=fD(a,0,0,1)|0;h=G;j=(b|0)!=0;do{if(j){k=(c[b>>2]|0)==2?2405056:10230408;l=b+76|0;m=c[l>>2]|0;n=c[m+8>>2]|0;if((n|0)==1){o=k;p=2400440;q=2399912;break}else if((n|0)==3){r=c[b+68>>2]|0;if((r|0)==1731426420){s=2398576}else if((r|0)==942683747){o=k;p=2399456;q=2398944;break}else{s=2408576}o=k;p=s;q=2398096;break}else if((n|0)==0){o=k;p=2402808;q=2401144;break}else{n=c[m+52>>2]|0;if((n|0)==1684237684){o=k;p=2458744;q=2395856;break}else if((n|0)==544240754){o=k;p=2397736;q=2397480;break}else{m=f|0;v5a(m,32,n)|0;n=c[l>>2]|0;l=c[n+52>>2]|0;KIb(n,24,2394232,(n=i,i=i+16|0,c[n>>2]=m,c[n+8>>2]=l,n)|0);i=n;o=k;p=2413800;q=2405472;break}}}else{o=2406160;p=2413800;q=2405472}}while(0);lD(a,0);kD(a,1919706216);lD(a,0);dD(a,o,4);kD(a,(d[p+1|0]|0)<<8|(d[p]|0)|(d[p+2|0]|0)<<16|(d[p+3|0]|0)<<24);lD(a,0);lD(a,0);lD(a,0);if(j){if((c[b>>2]|0)==2){t=12}}else{t=12}if((t|0)==12){bD(a,lrc(q|0)|0)}dD(a,q,lrc(q|0)|0);do{if(j){if((c[b>>2]|0)==2){break}bD(a,0)}}while(0);b=fD(a,0,0,1)|0;j=G;fD(a,g,h,0)|0;q=xrc(b,j,g,h)|0;lD(a,q);fD(a,b,j,0)|0;i=e;return}function cN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=fD(a,0,0,1)|0;e=G;lD(a,0);kD(a,1684565351);lD(a,24);kD(a,1852403047);lD(a,0);tD(a,64);tD(a,32768);tD(a,32768);tD(a,32768);tD(a,0);tD(a,0);if((c[b+68>>2]|0)!=942683747){lD(a,44);kD(a,1954047348);tD(a,1);lD(a,0);lD(a,0);lD(a,0);lD(a,1);lD(a,0);lD(a,0);lD(a,0);lD(a,16384);tD(a,0)}if((c[(c[b+76>>2]|0)+52>>2]|0)!=1684237684){f=0;g=0;h=fD(a,f,g,1)|0;i=G;j=fD(a,d,e,0)|0;k=G;l=xrc(h,i,d,e)|0;m=G;n=l;o=n;lD(a,o);p=fD(a,h,i,0)|0;q=G;return}b=fD(a,0,0,1)|0;r=G;lD(a,0);kD(a,1684237684);s=fD(a,0,0,1)|0;t=G;lD(a,0);kD(a,1768776564);lD(a,0);tD(a,0);tD(a,0);tD(a,12);tD(a,0);tD(a,0);tD(a,0);tD(a,0);tD(a,65535);tD(a,65535);tD(a,65535);bD(a,13);dD(a,2407928,13);u=fD(a,0,0,1)|0;v=G;fD(a,s,t,0)|0;w=xrc(u,v,s,t)|0;lD(a,w);fD(a,u,v,0)|0;v=fD(a,0,0,1)|0;u=G;fD(a,b,r,0)|0;w=xrc(v,u,b,r)|0;lD(a,w);fD(a,v,u,0)|0;f=0;g=0;h=fD(a,f,g,1)|0;i=G;j=fD(a,d,e,0)|0;k=G;l=xrc(h,i,d,e)|0;m=G;n=l;o=n;lD(a,o);p=fD(a,h,i,0)|0;q=G;return}function dN(b,f){b=b|0;f=f|0;var g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0;g=i;i=i+64|0;j=g|0;l=g+8|0;m=g+16|0;n=g+24|0;o=g+32|0;p=fD(b,0,0,1)|0;q=G;lD(b,0);kD(b,1818391667);r=fD(b,0,0,1)|0;s=G;lD(b,0);kD(b,1685288051);lD(b,0);lD(b,1);t=f+76|0;u=c[t>>2]|0;v=c[u+8>>2]|0;do{if((v|0)==1){w=fD(b,0,0,1)|0;x=G;y=f+68|0;z=c[y>>2]|0;A=f|0;a:do{if((c[A>>2]|0)==2){if((c[f+8>>2]|0)>>>0>65535>>>0){switch(c[(c[t>>2]|0)+48>>2]|0){case 65556:case 65558:case 65557:case 65559:case 65541:case 65537:case 65549:case 65545:case 65540:case 65536:case 65548:case 65544:{B=1835233388;C=2;break a;break};default:{}}B=z;C=2;break}if((c[f+96>>2]|0)==0){D=c[(c[t>>2]|0)+48>>2]|0;if(!((D|0)==65557|(D|0)==65548|(D|0)==65544|(D|0)==65559|(D|0)==65556|(D|0)==65549|(D|0)==65545|(D|0)==65558|(D|0)==69638|(D|0)==69633|(D|0)==86035)){B=z;C=0;break}}B=z;C=1}else{B=z;C=0}}while(0);lD(b,0);kD(b,B);lD(b,0);tD(b,0);tD(b,1);tD(b,C);tD(b,0);lD(b,0);if((C|0)==2){tD(b,3);tD(b,16);tD(b,65534);tD(b,0);lD(b,65536);lD(b,72);h[k>>3]=+(c[(c[t>>2]|0)+412>>2]|0);sD(b,c[k>>2]|0,c[k+4>>2]|0);lD(b,c[(c[t>>2]|0)+416>>2]|0);lD(b,2130706432);lD(b,g5a(c[(c[t>>2]|0)+48>>2]|0)|0);switch(c[(c[t>>2]|0)+48>>2]|0){case 65537:case 65549:case 65545:{E=14;break};case 65540:case 65536:case 65548:case 65544:{E=12;break};case 65556:case 65558:{E=11;break};case 65557:case 65559:{E=9;break};case 65541:{E=10;break};default:{E=0}}lD(b,E);lD(b,c[f+40>>2]|0);b:do{if((c[f+96>>2]|0)==0){F=1}else{z=f+4|0;if((c[z>>2]|0)==0){F=0;break}D=WM(f,0)|0;H=1;while(1){if((H|0)>=(c[z>>2]|0)){F=D;break b}if((WM(f,H)|0)==(D|0)){H=H+1|0}else{F=0;break}}}}while(0);lD(b,F)}else{if((c[A>>2]|0)==2){tD(b,c[(c[t>>2]|0)+416>>2]|0);if(((c[(c[t>>2]|0)+48>>2]|0)-65540|0)>>>0<2>>>0){tD(b,8)}else{tD(b,16)}tD(b,(c[f+96>>2]|0)!=0?-2:0)}else{tD(b,2);tD(b,16);tD(b,0)}tD(b,0);H=c[(c[t>>2]|0)+412>>2]|0;tD(b,(H|0)<65536?H:0);tD(b,0)}H=(C|0)==1;if(H){D=c[t>>2]|0;switch(c[D+48>>2]|0){case 65557:case 65548:case 65544:case 65559:case 65556:case 65549:case 65545:case 65558:{lD(b,1);break};default:{lD(b,c[D+424>>2]|0)}}D=f+40|0;lD(b,(c[D>>2]|0)/(c[(c[t>>2]|0)+416>>2]|0)|0);lD(b,c[D>>2]|0);lD(b,2)}do{if((c[A>>2]|0)==2){D=c[(c[t>>2]|0)+48>>2]|0;if((D|0)==65557|(D|0)==65548|(D|0)==65544|(D|0)==65559){if(!H){I=102;break}}else if((D|0)==65556|(D|0)==65549|(D|0)==65545|(D|0)==65558){if(!H){I=102;break}}else if(!((D|0)==86018|(D|0)==86019|(D|0)==73728|(D|0)==86032|(D|0)==69638|(D|0)==69633|(D|0)==86035)){I=102;break}D=fD(b,0,0,1)|0;z=G;lD(b,0);kD(b,1702257015);J=c[t>>2]|0;do{if((c[J+48>>2]|0)==86035){K=J;I=99}else{lD(b,12);kD(b,1634562662);kD(b,c[y>>2]|0);L=c[t>>2]|0;M=c[L+48>>2]|0;if((M|0)==69638|(M|0)==69633){N=fD(b,0,0,1)|0;O=G;lD(b,0);kD(b,c[y>>2]|0);P=(he((c[y>>2]|0)>>>16&65535|0)|0)&65535;Q=c[t>>2]|0;c[Q+52>>2]=P;US(b,Q)|0;Q=fD(b,0,0,1)|0;P=G;fD(b,N,O,0)|0;R=xrc(Q,P,N,O)|0;lD(b,R);fD(b,Q,P,0)|0;break}else if((M|0)==86018){lD(b,12);kD(b,1630826605);lD(b,0);fN(b,f);break}else if((M|0)==73728){gN(b,f);break}else if((M|0)==86019){hN(b,f);break}else if((M|0)==86032|(M|0)==86035){K=L;I=99;break}else if((M|0)==65557|(M|0)==65548|(M|0)==65544|(M|0)==65559){lD(b,10);kD(b,1633971813);tD(b,1);break}else if((M|0)==65556|(M|0)==65549|(M|0)==65545|(M|0)==65558){lD(b,10);kD(b,1633971813);tD(b,0);break}else{break}}}while(0);if((I|0)==99){dD(b,c[K+96>>2]|0,c[K+100>>2]|0)}lD(b,8);lD(b,0);J=fD(b,0,0,1)|0;M=G;fD(b,D,z,0)|0;L=xrc(J,M,D,z)|0;lD(b,L);fD(b,J,M,0)|0;}else{I=102}}while(0);do{if((I|0)==102){if((c[y>>2]|0)==1630826605){fN(b,f);break}H=c[t>>2]|0;M=c[H+48>>2]|0;if((M|0)==73728){gN(b,f);break}else if((M|0)==86019){hN(b,f);break}else if((M|0)==86032){dD(b,c[H+96>>2]|0,c[H+100>>2]|0);break}else if((M|0)==86054){M=fD(b,0,0,1)|0;H=G;lD(b,0);kD(b,2019911287);US(b,c[t>>2]|0)|0;J=fD(b,0,0,1)|0;L=G;fD(b,M,H,0)|0;P=xrc(J,L,M,H)|0;lD(b,P);fD(b,J,L,0)|0;break}else{L=f+80|0;J=c[L>>2]|0;if((J|0)<=0){break}lD(b,J+8|0);kD(b,1818389607);dD(b,c[f+84>>2]|0,c[L>>2]|0);break}}}while(0);do{if((c[A>>2]|0)==2){if((c[(c[t>>2]|0)+8>>2]|0)!=1){break}y=fD(b,0,0,1)|0;L=G;J=c[t>>2]|0;P=J+448|0;H=KM(c[J+48>>2]|0,c[P>>2]|0,c[P+4>>2]|0,j)|0;if((H|0)==0){KIb(c[t>>2]|0,24,2450968,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;break}else{lD(b,0);kD(b,1851877475);bD(b,0);vD(b,0);lD(b,H);lD(b,c[j>>2]|0);lD(b,0);H=fD(b,0,0,1)|0;P=G;fD(b,y,L,0)|0;J=xrc(H,P,y,L)|0;lD(b,J);fD(b,H,P,0)|0;break}}}while(0);A=fD(b,0,0,1)|0;P=G;fD(b,w,x,0)|0;H=xrc(A,P,w,x)|0;lD(b,H);fD(b,A,P,0)|0;}else if((v|0)==0){P=o|0;A=fD(b,0,0,1)|0;H=G;mrc(P|0,0,32)|0;lD(b,0);J=f+68|0;kD(b,c[J>>2]|0);lD(b,0);tD(b,0);tD(b,1);tD(b,0);tD(b,0);L=f|0;do{if((c[L>>2]|0)==2){kD(b,1347241542);if((c[(c[t>>2]|0)+48>>2]|0)==14){lD(b,0);lD(b,1024);break}else{lD(b,512);lD(b,512);break}}else{lD(b,0);lD(b,0);lD(b,0)}}while(0);tD(b,c[(c[t>>2]|0)+120>>2]|0);tD(b,c[f+100>>2]|0);lD(b,4718592);lD(b,4718592);lD(b,0);tD(b,1);x=c[t>>2]|0;w=c[x+120>>2]|0;if((w|0)==1440){if((c[x+124>>2]|0)==1080){T=0}else{I=10}}else if((w|0)==1920){T=(c[x+124>>2]|0)!=1080}else if((w|0)==1280){if((c[x+124>>2]|0)==720){T=0}else{I=10}}else{T=1}if((I|0)==10){T=1}do{if((c[L>>2]|0)==2){w=c[x+12>>2]|0;if((w|0)==0){I=16;break}y=c[w>>2]|0;if((y|0)==0){I=16;break}CFb(P,y,32)|0}else{I=16}}while(0);do{if((I|0)==16){if((c[x+48>>2]|0)!=2|T){break}y=(c[x+408>>2]|0)>>>0>1>>>0;w=c[f+72>>2]|0;M=n;Q=n;R=c[w+8>>2]|0;c[Q>>2]=c[R+108>>2];O=M+4|0;c[O>>2]=c[R+104>>2];if((qLb(M)|0)<0){M=c[O>>2]|0;O=w+92|0;R=c[O>>2]|0;N=c[w+96>>2]|0;KIb(0,48,2415320,(S=i,i=i+32|0,c[S>>2]=c[Q>>2],c[S+8>>2]=M,c[S+16>>2]=R,c[S+24>>2]=N,S)|0);i=S;N=O;O=c[N>>2]|0;R=c[N+4>>2]|0;c[n>>2]=O;c[n+4>>2]=R;U=O;V=R}else{U=c[n>>2]|0;V=c[n+4>>2]|0}R=~~(+(U|0)/+(V|0));EFb(P,32,2423984,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S;O=c[t>>2]|0;do{if((c[O+140>>2]|0)==4){EFb(P,32,2423480,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S}else{if((c[O+120>>2]|0)==1440){EFb(P,32,2422456,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S;break}else{EFb(P,32,2419568,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S;break}}}while(0);EFb(P,32,2417544,(S=i,i=i+16|0,c[S>>2]=c[(c[t>>2]|0)+124>>2],c[S+8>>2]=y?105:112,S)|0)|0;i=S;O=ca(R,y?2:1)|0;EFb(P,32,2416784,(S=i,i=i+8|0,c[S>>2]=O,S)|0)|0;i=S}}while(0);bD(b,lrc(P|0)|0);dD(b,P,31);do{if((c[L>>2]|0)==2){x=c[(c[t>>2]|0)+792>>2]|0;if((x|0)==0){I=29;break}tD(b,x)}else{I=29}}while(0);if((I|0)==29){tD(b,24)}tD(b,65535);do{if((c[J>>2]|0)==1983148141){fN(b,f)}else{P=c[t>>2]|0;x=c[P+48>>2]|0;if((x|0)==1096176969|(x|0)==24){dD(b,c[P+96>>2]|0,c[P+100>>2]|0);lD(b,0);break}else if((x|0)==100){lD(b,24);kD(b,1380729665);kD(b,1380729665);kD(b,825241648);lD(b,2);lD(b,0);lD(b,24);kD(b,1196576833);kD(b,1196576833);kD(b,825241648);lD(b,1);lD(b,0);lD(b,120);kD(b,1397051969);kD(b,1397051969);kD(b,825241648);P=f+84|0;O=(c[P>>2]|0)+40|0;lD(b,je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0);lD(b,c[(c[t>>2]|0)+120>>2]|0);O=c[(c[t>>2]|0)+124>>2]|0;do{if((a[(c[P>>2]|0)+5|0]&2)==0){lD(b,O);lD(b,1);lD(b,0);if((c[(c[t>>2]|0)+124>>2]|0)==1080){lD(b,5);break}else{lD(b,6);break}}else{lD(b,(O|0)/2|0);lD(b,2);lD(b,0);lD(b,4)}}while(0);sD(b,0,0);sD(b,0,0);sD(b,0,0);sD(b,0,0);sD(b,0,0);sD(b,0,0);sD(b,0,0);sD(b,0,0);sD(b,0,0);sD(b,0,0);lD(b,0);break}else if((x|0)==93|(x|0)==107){break}else if((x|0)==5){lD(b,15);kD(b,859189860);kD(b,1347241542);bD(b,0);bD(b,10);bD(b,0);break}else if((x|0)==1211250229){O=fD(b,0,0,1)|0;P=G;lD(b,0);kD(b,1130591848);w$(b,c[f+84>>2]|0,c[f+80>>2]|0,0)|0;y=fD(b,0,0,1)|0;R=G;fD(b,O,P,0)|0;z=xrc(y,R,O,P)|0;lD(b,z);fD(b,y,R,0)|0;break}else if((x|0)==28){R=fD(b,0,0,1)|0;y=G;lD(b,0);kD(b,1130591841);q$(b,c[f+84>>2]|0,c[f+80>>2]|0)|0;z=fD(b,0,0,1)|0;P=G;fD(b,R,y,0)|0;O=xrc(z,P,R,y)|0;lD(b,O);fD(b,z,P,0)|0;if((c[L>>2]|0)!=32){break}lD(b,28);kD(b,1684632949);lD(b,1801994482);lD(b,1596215237);lD(b,-1170627301);lD(b,-821877773);lD(b,0);break}else if((x|0)==71){P=f+80|0;if((c[P>>2]|0)<=0){break}z=m|0;mrc(z|0,0,7)|0;if((TM(f,z)|0)<0){break}lD(b,(c[P>>2]|0)+15|0);kD(b,828601956);O=fD(b,0,0,1)|0;y=f+224|0;c[y>>2]=O;c[y+4>>2]=G;dD(b,z,7);dD(b,c[f+84>>2]|0,c[P>>2]|0);break}else{P=f+80|0;z=c[P>>2]|0;if((z|0)<=0){break}lD(b,z+8|0);kD(b,1818389607);dD(b,c[f+84>>2]|0,c[P>>2]|0);break}}}while(0);L=c[t>>2]|0;J=c[L+48>>2]|0;do{if((J|0)==28|(J|0)==13|(J|0)==100){W=L}else{P=c[L+408>>2]|0;if(!((P|0)!=0&P>>>0<6>>>0)){W=L;break}z=e[1237840+(P<<1)>>1]|0;lD(b,10);kD(b,1818585446);tD(b,z);W=c[t>>2]|0}}while(0);L=c[W+228>>2]|0;do{if((L|0)!=0){J=c[W+224>>2]|0;if((J|0)==0|(L|0)==(J|0)){break}z=l|0;P=l+4|0;xKb(z,P,J,(J|0)<0|0?-1:0,L,(L|0)<0|0?-1:0,2147483647,0)|0;lD(b,16);kD(b,1886609776);lD(b,c[z>>2]|0);lD(b,c[P>>2]|0)}}while(0);L=fD(b,0,0,1)|0;P=G;fD(b,A,H,0)|0;z=xrc(L,P,A,H)|0;lD(b,z);fD(b,L,P,0)|0;}else if((v|0)==3){P=fD(b,0,0,1)|0;L=G;lD(b,0);kD(b,c[f+68>>2]|0);lD(b,0);tD(b,0);tD(b,1);z=c[t>>2]|0;J=c[z+100>>2]|0;if((J|0)!=0){dD(b,c[z+96>>2]|0,J)}J=fD(b,0,0,1)|0;z=G;fD(b,P,L,0)|0;y=xrc(J,z,P,L)|0;lD(b,y);fD(b,J,z,0)|0;}else{z=c[u+52>>2]|0;if((z|0)==544240754){J=fD(b,0,0,1)|0;y=G;lD(b,0);kD(b,544240754);lD(b,0);tD(b,0);tD(b,1);tD(b,1);tD(b,1);lD(b,c[f+144>>2]|0);lD(b,12);kD(b,1936550260);lD(b,c[f+8>>2]|0);L=fD(b,0,0,1)|0;P=G;fD(b,J,y,0)|0;O=xrc(L,P,J,y)|0;lD(b,O);fD(b,L,P,0)|0;break}else if((z|0)!=1684237684){break}z=fD(b,0,0,1)|0;P=G;L=f+8|0;O=c[t>>2]|0;y=c[O+104>>2]|0;J=c[O+108>>2]|0;O=~~(1.0/(+(y|0)/+(J|0))+.5);if((O|0)>255){KIb(0,16,2461704,(S=i,i=i+8|0,c[S>>2]=O,S)|0);i=S;break}else{R=VIb(c[L>>2]|0,0,y,(y|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;lD(b,0);kD(b,1684237684);lD(b,0);lD(b,1);lD(b,0);lD(b,c[f+56>>2]|0);lD(b,c[L>>2]|0);lD(b,R);bD(b,O);vD(b,0);O=fD(b,0,0,1)|0;R=G;fD(b,z,P,0)|0;L=xrc(O,R,z,P)|0;lD(b,L);fD(b,O,R,0)|0;break}}}while(0);S=fD(b,0,0,1)|0;u=G;fD(b,r,s,0)|0;v=xrc(S,u,r,s)|0;lD(b,v);fD(b,S,u,0)|0;do{if((c[(c[t>>2]|0)+8>>2]|0)==1){if((c[f+96>>2]|0)!=0){I=128;break}u=hJb(8)|0;c[u>>2]=c[f+36>>2];c[u+4>>2]=1;X=u;Y=1}else{I=128}}while(0);if((I|0)==128){u=f+4|0;S=c[u>>2]|0;do{if((S|0)==0){Z=-1;_=0}else{v=hJb(S<<3)|0;if((c[u>>2]|0)>0){$=-1;aa=0}else{Z=-1;_=v;break}while(1){s=WM(f,aa)|0;do{if((aa|0)==0){I=133}else{if((s|0)!=(c[v+($<<3)+4>>2]|0)){I=133;break}r=v+($<<3)|0;c[r>>2]=(c[r>>2]|0)+1;ba=$}}while(0);if((I|0)==133){I=0;x=$+1|0;c[v+(x<<3)+4>>2]=s;c[v+(x<<3)>>2]=1;ba=x}x=aa+1|0;if((x|0)<(c[u>>2]|0)){$=ba;aa=x}else{Z=ba;_=v;break}}}}while(0);X=_;Y=Z+1|0}lD(b,(Y<<3)+16|0);kD(b,1937011827);lD(b,0);lD(b,Y);if((Y|0)!=0){Z=0;do{lD(b,c[X+(Z<<3)>>2]|0);lD(b,c[X+(Z<<3)+4>>2]|0);Z=Z+1|0;}while(Z>>>0<Y>>>0)}kJb(X);X=c[t>>2]|0;if((c[X+8>>2]|0)==0){I=140}else{if((c[X+52>>2]|0)==544240754){I=140}}do{if((I|0)==140){X=c[f+48>>2]|0;if((X|0)==0){break}if((X|0)>=(c[f+4>>2]|0)){break}eN(b,f,1)}}while(0);do{if((c[f>>2]|0)==2){if((c[f+52>>2]&2|0)==0){break}eN(b,f,2)}}while(0);do{if((c[(c[t>>2]|0)+8>>2]|0)==0){if((c[f+52>>2]&1|0)==0){break}X=f+4|0;Y=hJb((c[X>>2]<<3)+8|0)|0;Z=Y;c[Y>>2]=1;_=c[f+88>>2]|0;c[Y+4>>2]=c[_+32>>2];ba=c[X>>2]|0;if((ba|0)>1){X=0;aa=1;while(1){$=c[_+(aa*40|0)+32>>2]|0;if(($|0)==(c[Z+(X<<3)+4>>2]|0)){u=Z+(X<<3)|0;c[u>>2]=(c[u>>2]|0)+1;da=X}else{u=X+1|0;c[Z+(u<<3)+4>>2]=$;c[Z+(u<<3)>>2]=1;da=u}u=aa+1|0;if((u|0)<(ba|0)){X=da;aa=u}else{ea=da;break}}}else{ea=0}aa=ea+1|0;lD(b,(aa<<3)+16|0);kD(b,1937011811);lD(b,0);lD(b,aa);if((aa|0)!=0){X=0;do{lD(b,c[Z+(X<<3)>>2]|0);lD(b,c[Z+(X<<3)+4>>2]|0);X=X+1|0;}while(X>>>0<aa>>>0)}kJb(Y)}}while(0);ea=fD(b,0,0,1)|0;da=G;lD(b,0);kD(b,1668510835);lD(b,0);t=fD(b,0,0,1)|0;aa=G;X=f+44|0;lD(b,c[X>>2]|0);Z=f+4|0;ba=c[Z>>2]|0;if((ba|0)>0){_=f+88|0;u=0;$=-1;S=0;v=c[_>>2]|0;H=ba;while(1){do{if(($|0)==(c[v+(u*40|0)+20>>2]|0)){fa=S;ga=$;ha=v;ia=H}else{ba=c[v+(u*40|0)+24>>2]|0;if((ba|0)==0){fa=S;ga=$;ha=v;ia=H;break}lD(b,ba);lD(b,c[(c[_>>2]|0)+(u*40|0)+20>>2]|0);lD(b,1);ba=c[_>>2]|0;fa=S+1|0;ga=c[ba+(u*40|0)+20>>2]|0;ha=ba;ia=c[Z>>2]|0}}while(0);Y=u+1|0;if((Y|0)<(ia|0)){u=Y;$=ga;S=fa;v=ha;H=ia}else{ja=fa;break}}}else{ja=0}fa=fD(b,0,0,1)|0;ia=G;fD(b,t,aa,0)|0;lD(b,ja);fD(b,fa,ia,0)|0;ia=fD(b,0,0,1)|0;fa=G;fD(b,ea,da,0)|0;ja=xrc(ia,fa,ea,da)|0;lD(b,ja);fD(b,ia,fa,0)|0;fa=fD(b,0,0,1)|0;ia=G;lD(b,0);kD(b,2054386803);lD(b,0);ja=c[Z>>2]|0;if((ja|0)>0){da=c[f+88>>2]|0;ea=0;aa=-1;t=0;H=1;while(1){ha=c[da+(t*40|0)+28>>2]|0;v=((c[da+(t*40|0)+16>>2]|0)>>>0)/(ha>>>0)|0;ka=(aa|0)==-1|(v|0)==(aa|0)?H:0;la=ha+ea|0;ha=t+1|0;if((ha|0)<(ja|0)){ea=la;aa=v;t=ha;H=ka}else{break}}ma=la;na=(ka|0)!=0}else{ma=0;na=1}do{if(na&(ja|0)!=0){ka=c[f+88>>2]|0;la=((c[ka+16>>2]|0)>>>0)/((c[ka+28>>2]|0)>>>0)|0;lD(b,(la|0)<1?1:la);lD(b,ma)}else{lD(b,0);lD(b,ma);la=c[Z>>2]|0;if((la|0)<=0){break}ka=f+88|0;H=0;t=c[ka>>2]|0;aa=la;while(1){la=c[t+(H*40|0)+28>>2]|0;if((la|0)==0){oa=t;pa=aa}else{ea=0;da=t;ha=la;do{lD(b,((c[da+(H*40|0)+16>>2]|0)>>>0)/(ha>>>0)|0);ea=ea+1|0;da=c[ka>>2]|0;ha=c[da+(H*40|0)+28>>2]|0;}while(ea>>>0<ha>>>0);oa=da;pa=c[Z>>2]|0}ha=H+1|0;if((ha|0)<(pa|0)){H=ha;t=oa;aa=pa}else{break}}}}while(0);pa=fD(b,0,0,1)|0;oa=G;fD(b,fa,ia,0)|0;ma=xrc(pa,oa,fa,ia)|0;lD(b,ma);fD(b,pa,oa,0)|0;oa=c[Z>>2]|0;if((oa|0)>0){pa=(c[f+88>>2]|0)+((oa-1|0)*40|0)|0;oa=f+184|0;ma=wrc(c[oa>>2]|0,c[oa+4>>2]|0,c[pa>>2]|0,c[pa+4>>2]|0)|0;pa=G;oa=0;if(pa>>>0>oa>>>0|pa>>>0==oa>>>0&ma>>>0>-1>>>0){qa=1}else{I=176}}else{I=176}if((I|0)==176){qa=0}I=fD(b,0,0,1)|0;ma=G;lD(b,0);if((qa|0)==0){kD(b,1868788851)}else{kD(b,875982691)}lD(b,0);lD(b,c[X>>2]|0);X=c[Z>>2]|0;if((X|0)<=0){ra=0;sa=0;ta=fD(b,ra,sa,1)|0;ua=G;va=fD(b,I,ma,0)|0;wa=G;xa=xrc(ta,ua,I,ma)|0;ya=G;za=xa;Aa=za;lD(b,Aa);Ba=fD(b,ta,ua,0)|0;Ca=G;Da=0;Ea=0;Fa=fD(b,Da,Ea,1)|0;Ga=G;Ha=fD(b,p,q,0)|0;Ia=G;Ja=xrc(Fa,Ga,p,q)|0;Ka=G;La=Ja;Ma=La;lD(b,Ma);Na=fD(b,Fa,Ga,0)|0;Oa=G;i=g;return}oa=f+88|0;pa=f+184|0;if((qa|0)==1){qa=0;f=X;while(1){ia=c[oa>>2]|0;if((c[ia+(qa*40|0)+24>>2]|0)==0){Pa=f}else{fa=ia+(qa*40|0)|0;ia=wrc(c[fa>>2]|0,c[fa+4>>2]|0,c[pa>>2]|0,c[pa+4>>2]|0)|0;sD(b,ia,G);Pa=c[Z>>2]|0}ia=qa+1|0;if((ia|0)<(Pa|0)){qa=ia;f=Pa}else{break}}ra=0;sa=0;ta=fD(b,ra,sa,1)|0;ua=G;va=fD(b,I,ma,0)|0;wa=G;xa=xrc(ta,ua,I,ma)|0;ya=G;za=xa;Aa=za;lD(b,Aa);Ba=fD(b,ta,ua,0)|0;Ca=G;Da=0;Ea=0;Fa=fD(b,Da,Ea,1)|0;Ga=G;Ha=fD(b,p,q,0)|0;Ia=G;Ja=xrc(Fa,Ga,p,q)|0;Ka=G;La=Ja;Ma=La;lD(b,Ma);Na=fD(b,Fa,Ga,0)|0;Oa=G;i=g;return}else{Pa=0;f=X;while(1){X=c[oa>>2]|0;if((c[X+(Pa*40|0)+24>>2]|0)==0){Qa=f}else{qa=X+(Pa*40|0)|0;X=wrc(c[qa>>2]|0,c[qa+4>>2]|0,c[pa>>2]|0,c[pa+4>>2]|0)|0;lD(b,X);Qa=c[Z>>2]|0}X=Pa+1|0;if((X|0)<(Qa|0)){Pa=X;f=Qa}else{break}}ra=0;sa=0;ta=fD(b,ra,sa,1)|0;ua=G;va=fD(b,I,ma,0)|0;wa=G;xa=xrc(ta,ua,I,ma)|0;ya=G;za=xa;Aa=za;lD(b,Aa);Ba=fD(b,ta,ua,0)|0;Ca=G;Da=0;Ea=0;Fa=fD(b,Da,Ea,1)|0;Ga=G;Ha=fD(b,p,q,0)|0;Ia=G;Ja=xrc(Fa,Ga,p,q)|0;Ka=G;La=Ja;Ma=La;lD(b,Ma);Na=fD(b,Fa,Ga,0)|0;Oa=G;i=g;return}}function eN(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=fD(a,0,0,1)|0;g=G;lD(a,0);h=(e|0)==1?2464232:2463648;kD(a,(d[h+1|0]|0)<<8|(d[h]|0)|(d[h+2|0]|0)<<16|(d[h+3|0]|0)<<24);lD(a,0);h=fD(a,0,0,1)|0;i=G;j=b+4|0;lD(a,c[j>>2]|0);k=c[j>>2]|0;if((k|0)>0){l=b+88|0;b=0;m=0;n=k;while(1){k=m+1|0;if((c[(c[l>>2]|0)+(m*40|0)+36>>2]&e|0)==0){o=b;p=n}else{lD(a,k);o=b+1|0;p=c[j>>2]|0}if((k|0)<(p|0)){b=o;m=k;n=p}else{q=o;break}}}else{q=0}o=fD(a,0,0,1)|0;p=G;fD(a,h,i,0)|0;lD(a,q);fD(a,o,p,0)|0;p=fD(a,0,0,1)|0;o=G;fD(a,f,g,0)|0;q=xrc(p,o,f,g)|0;lD(a,q);fD(a,p,o,0)|0;return}function fN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=fD(a,0,0,1)|0;e=G;f=b+80|0;g=c[f>>2]|0;h=(g|0)==0?0:g+5|0;lD(a,0);kD(a,1935962981);lD(a,0);g=h+27|0;bD(a,3);bD(a,g>>>21|128);bD(a,g>>>14|128);bD(a,g>>>7|128);bD(a,g&127);tD(a,c[b+64>>2]|0);bD(a,0);g=h+13|0;bD(a,4);bD(a,g>>>21|128);bD(a,g>>>14|128);bD(a,g>>>7|128);bD(a,g&127);g=b+76|0;h=c[g>>2]|0;i=c[h+48>>2]|0;do{if((i-86016|0)>>>0<2>>>0){if((c[h+412>>2]|0)<=24e3){j=4;break}bD(a,107)}else{j=4}}while(0);if((j|0)==4){bD(a,IX(1349600,i)|0)}if((c[(c[g>>2]|0)+8>>2]|0)==1){bD(a,21)}else{bD(a,17)}vD(a,c[(c[g>>2]|0)+524>>2]>>3);i=b+24|0;j=c[i>>2]|0;h=c[i+4>>2]|0;if((j|0)==0&(h|0)==0){k=0}else{i=c[b+4>>2]|0;if((i|0)>0){l=c[b+88>>2]|0;m=0;n=0;o=0;do{n=wrc(c[l+(o*40|0)+16>>2]|0,0,n,m)|0;m=G;o=o+1|0;}while((o|0)<(i|0));p=m<<3|n>>>29;q=n<<3|0>>>29}else{p=0;q=0}n=Erc(c[b+8>>2]|0,0,q,p)|0;p=Frc(n,G,j,h)|0;k=p}p=c[g>>2]|0;g=c[p+72>>2]|0;h=c[p+540>>2]|0;p=(g|0)>(h|0)?g:h;lD(a,p>>>0>k>>>0?p:k);lD(a,k);k=c[f>>2]|0;if((k|0)==0){bD(a,6);bD(a,128);bD(a,128);bD(a,128);bD(a,1);bD(a,2);r=0;s=0;t=fD(a,r,s,1)|0;u=G;v=fD(a,d,e,0)|0;w=G;x=xrc(t,u,d,e)|0;y=G;z=x;A=z;lD(a,A);B=fD(a,t,u,0)|0;C=G;return}bD(a,5);bD(a,k>>>21|128);bD(a,k>>>14|128);bD(a,k>>>7|128);bD(a,k&127);dD(a,c[b+84>>2]|0,c[f>>2]|0);bD(a,6);bD(a,128);bD(a,128);bD(a,128);bD(a,1);bD(a,2);r=0;s=0;t=fD(a,r,s,1)|0;u=G;v=fD(a,d,e,0)|0;w=G;x=xrc(t,u,d,e)|0;y=G;z=x;A=z;lD(a,A);B=fD(a,t,u,0)|0;C=G;return}function gN(a,b){a=a|0;b=b|0;lD(a,17);if((c[b>>2]|0)==2){kD(a,1919770995)}else{kD(a,1919770980)}kD(a,1347241542);bD(a,0);tD(a,33279);bD(a,0);bD(a,1);return}function hN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+8|0;g=f|0;h=e+80|0;if((c[h>>2]|0)<7){i=f;return}lD(b,11);kD(b,862151012);j=(c[e+84>>2]|0)+4|0;e=c[h>>2]<<3;h=(e-32|0)>>>0>2147483639>>>0|(j|0)==0;k=h?0:j;j=h?8:e-24|0;e=k;h=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>6;e=j>>>0>2>>>0?2:j;l=k+(e>>>3)|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(e&2)>>>27;l=e+6|0;e=j>>>0>l>>>0?l:j;l=k+(e>>>3)|0;n=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(e&7)>>>27;l=e+5|0;e=j>>>0>l>>>0?l:j;l=k+(e>>>3)|0;o=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(e&7)>>>29;l=e+3|0;e=j>>>0>l>>>0?l:j;l=k+(e>>>3)|0;p=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(e&7)>>>29;l=e+3|0;e=j>>>0>l>>>0?l:j;do{if((p|0)==2){l=e+2|0;q=j>>>0>l>>>0?l:j}else{if((p&1|0)!=0&(p|0)!=1){l=e+2|0;r=j>>>0>l>>>0?l:j}else{r=e}if((p&4|0)==0){q=r;break}l=r+2|0;q=j>>>0>l>>>0?l:j}}while(0);j=g|0;g=o|(n|h<<5&96)<<3;h=(((d[k+(q>>>3)|0]|0)<<(q&7)>>>7&1|(p|g<<3)<<1)<<5|m)<<13;m=g>>>2&255;g=8;p=j;while(1){a[p]=m;q=h;h=q<<8;k=g+8|0;if((k|0)<32){m=q>>>16&255;g=k;p=p+1|0}else{break}}h=0;dD(b,j,3);i=f;return}function iN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=c[b+32>>2]|0;h=c[f+48>>2]|0;j=c[h+(g<<8)+76>>2]|0;k=c[b+28>>2]|0;if((k|0)==0){l=0;i=d;return l|0}m=h+(g<<8)+4|0;do{if((c[m>>2]|0)==0){n=0;o=0}else{if(!(g>>>0<(c[a+24>>2]|0)>>>0)){n=0;o=0;break}p=b+16|0;q=(c[h+(g<<8)+88>>2]|0)+8|0;r=xrc(c[p>>2]|0,c[p+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;q=(c[(c[a+28>>2]|0)+(g<<2)>>2]|0)+40|0;c[e>>2]=1;c[e+4>>2]=1e6;p=XIb(r,G,q,e)|0;n=G;o=p}}while(0);e=c[f+76>>2]|0;g=(e|0)<0|0?-1:0;do{if((e|0)==0|((n|0)<(g|0)|(n|0)==(g|0)&o>>>0<e>>>0)){h=c[f+84>>2]|0;if((h|0)!=0){p=f+40|0;q=wrc(c[p>>2]|0,c[p+4>>2]|0,k,(k|0)<0|0?-1:0)|0;p=G;r=(h|0)<0|0?-1:0;if(!(p>>>0<r>>>0|p>>>0==r>>>0&q>>>0<h>>>0)){s=12;break}}if((c[f+52>>2]&8|0)==0){break}if((c[j+8>>2]|0)!=0){break}if((c[m>>2]|0)==0){break}if((c[b+36>>2]&1|0)!=0){s=12}}else{s=12}}while(0);do{if((s|0)==12){m=c[f+80>>2]|0;j=(m|0)<0|0?-1:0;if((n|0)<(j|0)|(n|0)==(j|0)&o>>>0<m>>>0){break}SM(a)}}while(0);l=MM(a,b)|0;i=d;return l|0}function jN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[(c[a+12>>2]|0)+48>>2]|0;g=c[(c[a+28>>2]|0)+(d<<2)>>2]|0;h=f+(b<<8)+68|0;c[h>>2]=544240754;c[f+(b<<8)+124>>2]=d;j=mWa(0)|0;k=f+(b<<8)+76|0;c[k>>2]=j;do{if((j|0)==0){l=-12}else{c[j+8>>2]=2;c[j+52>>2]=c[h>>2];m=f+(b<<8)+128|0;n=NT(m,a,g,0,1450,d)|0;if((n|0)<0){l=n;break}c[f+(b<<8)+8>>2]=c[(c[c[(c[m>>2]|0)+28>>2]>>2]|0)+44>>2];c[f+(d<<8)+120>>2]=b;o=0;i=e;return o|0}}while(0);KIb(a,24,2149912,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;mJb(k);c[f+(b<<8)+8>>2]=9e4;o=l;i=e;return o|0}function kN(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;k=i;i=i+96|0;l=k|0;m=k+8|0;n=k+16|0;o=c[(c[b+12>>2]|0)+48>>2]|0;p=c[o+(f<<8)+128>>2]|0;c[l>>2]=0;c[m>>2]=0;if((p|0)==0){q=-2;i=k;return q|0}r=p+16|0;if((c[r>>2]|0)==0){q=-12;i=k;return q|0}s=o+(f<<8)+168|0;do{if((h|0)==0){t=c[e+24>>2]|0;u=c[e+28>>2]|0;if((u|0)<15){break}v=o+(f<<8)+176|0;w=c[v>>2]|0;if((w|0)==0){x=c[s>>2]|0;y=15}else{z=c[o+(f<<8)+172>>2]|0;A=c[s>>2]|0;if((z|0)<(A|0)){B=w;C=z}else{x=A;y=15}}if((y|0)==15){A=s|0;z=nJb(w,x+10|0,20)|0;if((z|0)==0){break}w=z;c[A>>2]=(c[A>>2]|0)+10;c[v>>2]=w;B=w;C=c[o+(f<<8)+172>>2]|0}w=o+(f<<8)+172|0;c[B+(C*20|0)>>2]=t;t=c[v>>2]|0;c[t+(C*20|0)+4>>2]=u;c[t+((c[w>>2]|0)*20|0)+8>>2]=g;c[t+((c[w>>2]|0)*20|0)+12>>2]=0;c[t+((c[w>>2]|0)*20|0)+16>>2]=0;c[w>>2]=(c[w>>2]|0)+1}else{if((j|0)<15){break}w=o+(f<<8)+176|0;t=c[w>>2]|0;if((t|0)==0){D=c[s>>2]|0;y=8}else{u=c[o+(f<<8)+172>>2]|0;v=c[s>>2]|0;if((u|0)<(v|0)){E=t;F=u}else{D=v;y=8}}if((y|0)==8){v=s|0;u=nJb(t,D+10|0,20)|0;if((u|0)==0){break}t=u;c[v>>2]=(c[v>>2]|0)+10;c[w>>2]=t;E=t;F=c[o+(f<<8)+172>>2]|0}t=o+(f<<8)+172|0;c[E+(F*20|0)>>2]=h;v=c[w>>2]|0;c[v+(F*20|0)+4>>2]=j;c[v+((c[t>>2]|0)*20|0)+8>>2]=g;c[v+((c[t>>2]|0)*20|0)+12>>2]=0;c[v+((c[t>>2]|0)*20|0)+16>>2]=0;c[t>>2]=(c[t>>2]|0)+1}}while(0);aP(p,0,e,b)|0;p=aE(c[r>>2]|0,l)|0;g=$D(r,1450)|0;do{if((g|0)<0|(p|0)<1){H=g}else{r=_D(m)|0;if((r|0)<0){H=r;break}J1(n);j=c[m>>2]|0;F=c[l>>2]|0;h=n+16|0;E=fD(j,0,0,1)|0;D=G;tD(j,0);tD(j,0);a:do{if((p|0)>4){s=o+(f<<8)+144|0;C=o+(f<<8)+132|0;B=o+(f<<8)+136|0;x=o+(f<<8)+172|0;t=o+(f<<8)+176|0;v=0;w=p;u=F;while(1){A=w;z=u;while(1){I=z;J=je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0;I=A-4|0;if(J>>>0>I>>>0|J>>>0<13>>>0){K=v;break a}L=z+4|0;M=a[z+5|0]|0;if(!((M+64&255)>>>0<4>>>0|(M+56&255)>>>0<11>>>0)){break}M=I-J|0;if((M|0)>4){A=M;z=z+(J+4)|0}else{K=v;break a}}if(J>>>0>(c[s>>2]|0)>>>0){c[s>>2]=J}M=z+6|0;I=he((d[M]|d[M+1|0]<<8)<<16>>16|0)|0;M=z+8|0;N=je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0;M=c[C>>2]|0;if((M|0)==0){c[C>>2]=N;O=N}else{O=M}M=N-O|0;if((M|0)>0){P=wrc(c[B>>2]|0,c[B+4>>2]|0,M,(M|0)<0|0?-1:0)|0;c[B>>2]=P;c[B+4>>2]=G;c[C>>2]=N;Q=0}else{Q=M}if((c[h>>2]|0)==0&(c[h+4>>2]|0)==(-2147483648|0)){M=c[B+4>>2]|0;c[h>>2]=c[B>>2];c[h+4>>2]=M}M=v+1|0;lD(j,0);dD(j,L,2);tD(j,I&65535);I=(Q|0)!=0;tD(j,I?4:0);N=fD(j,0,0,1)|0;P=G;tD(j,0);if(I){lD(j,16);lD(j,12);dD(j,2491240,4);lD(j,Q)}I=A-16|0;R=J-12|0;b:do{if((R|0)>0){S=R;T=z+16|0;U=0;c:while(1){if((c[x>>2]|0)<=0){V=S;W=T;X=U;break}d:while(1){Y=c[t>>2]|0;Z=Y+12|0;_=c[Z>>2]|0;$=c[Y+4>>2]|0;do{if((_|0)==0){if(($|0)<=5){aa=0;break}c[Z>>2]=5;aa=5}else{aa=_}}while(0);ba=c[Y>>2]|0;_=0;do{ca=0;while(1){da=ca+_|0;if((da|0)>=(S|0)){break}ea=ca+aa|0;if((ea|0)>=($|0)){break}if((a[ba+ea|0]|0)==(a[T+da|0]|0)){ca=ca+1|0}else{break}}if((ca|0)>=9){fa=aa;ga=_;ha=ca;while(1){da=(ga|0)>0;if(!((fa|0)>0&da)){ia=da;break}da=fa-1|0;ea=ga-1|0;if((a[ba+da|0]|0)==(a[T+ea|0]|0)){fa=da;ga=ea;ha=ha+1|0}else{ia=1;break}}if((ha|0)>=15){break d}}_=_+1|0;}while((_|0)<(S|0));if((aa|0)<10&($|0)>20){c[Z>>2]=($|0)/2|0}else{_=c[x>>2]|0;if((_|0)<1){V=S;W=T;X=U;break c}if((c[Y+16>>2]|0)==0){ja=_;ka=Y}else{kJb(ba);ja=c[x>>2]|0;ka=c[t>>2]|0}_=ja-1|0;c[x>>2]=_;orc(ka|0,ka+20|0,_*20|0|0)|0}if((c[x>>2]|0)<=0){V=S;W=T;X=U;break c}}_=c[Y+8>>2]|0;ca=fa+ha|0;c[Z>>2]=ca+5;do{if((ca+15|0)>=($|0)){ea=c[x>>2]|0;if((ea|0)<1){break}if((c[Y+16>>2]|0)==0){la=ea;ma=Y}else{kJb(ba);la=c[x>>2]|0;ma=c[t>>2]|0}ea=la-1|0;c[x>>2]=ea;orc(ma|0,ma+20|0,ea*20|0|0)|0}}while(0);if(ia){ca=ga;ea=T;da=U;while(1){na=(ca|0)>14?14:ca;bD(j,1);bD(j,na);dD(j,ea,na);oa=ea+na|0;pa=ca-na|0;if((na|0)<14){qa=na;do{bD(j,0);qa=qa+1|0;}while((qa|0)<14)}qa=da+1|0;if((pa|0)>0){ca=pa;ea=oa;da=qa}else{ra=qa;break}}}else{ra=U}bD(j,2);bD(j,0);tD(j,ha);lD(j,_);lD(j,fa);tD(j,1);tD(j,1);da=ra+1|0;ea=S-ha-ga|0;if((ea|0)>0){S=ea;T=T+(ga+ha)|0;U=da}else{sa=da;break b}}while(1){U=(V|0)>14?14:V;bD(j,1);bD(j,U);dD(j,W,U);T=W+U|0;S=V-U|0;if((U|0)<14){da=U;do{bD(j,0);da=da+1|0;}while((da|0)<14)}da=X+1|0;if((S|0)>0){V=S;W=T;X=da}else{sa=da;break}}}else{sa=0}}while(0);R=I+(12-J)|0;A=fD(j,0,0,1)|0;da=G;fD(j,N,P,0)|0;tD(j,sa);fD(j,A,da,0)|0;if((R|0)>4){v=M;w=R;u=z+(J+4)|0}else{K=M;break}}}else{K=0}}while(0);F=fD(j,0,0,1)|0;u=G;fD(j,E,D,0)|0;tD(j,K);fD(j,F,u,0)|0;mJb(l);c[n+28>>2]=aE(c[m>>2]|0,l)|0;c[n+24>>2]=c[l>>2];u=c[h+4>>2]|0;F=n+8|0;c[F>>2]=c[h>>2];c[F+4>>2]=u;c[n+32>>2]=f;if((c[e+36>>2]&1|0)!=0){u=n+36|0;c[u>>2]=c[u>>2]|1}if((K|0)<=0){H=r;break}MM(b,n)|0;H=r}}while(0);kJb(c[l>>2]|0);l=o+(f<<8)+172|0;n=c[l>>2]|0;if((n|0)<=0){q=H;i=k;return q|0}b=o+(f<<8)+176|0;f=0;o=n;e:while(1){n=f+1|0;K=o;while(1){ta=c[b>>2]|0;ua=ta+(f*20|0)+16|0;if((c[ua>>2]|0)!=0){va=K;break}wa=ta+(f*20|0)+4|0;xa=hJb(c[wa>>2]|0)|0;if((xa|0)!=0){y=83;break}e=c[b>>2]|0;orc(e+(f*20|0)|0,e+(n*20|0)|0,(((c[l>>2]|0)-f|0)*20|0)-20|0)|0;e=(c[l>>2]|0)-1|0;c[l>>2]=e;if((f|0)<(e|0)){K=e}else{q=H;y=85;break e}}if((y|0)==83){y=0;K=ta+(f*20|0)|0;nrc(xa|0,c[K>>2]|0,c[wa>>2]|0)|0;c[K>>2]=xa;c[ua>>2]=1;va=c[l>>2]|0}if((n|0)<(va|0)){f=n;o=va}else{q=H;y=85;break}}if((y|0)==85){i=k;return q|0}return 0}function lN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=c[a+128>>2]|0;mJb(a+76|0);f=a+172|0;g=c[f>>2]|0;h=a+176|0;if((g|0)>0){j=0;k=g;while(1){g=c[h>>2]|0;if((c[g+(j*20|0)+16>>2]|0)==0){l=k}else{kJb(c[g+(j*20|0)>>2]|0);l=c[f>>2]|0}g=j+1|0;if((g|0)<(l|0)){j=g;k=l}else{break}}}mJb(h);c[f>>2]=0;c[a+168>>2]=0;if((e|0)==0){i=b;return}a=e+16|0;if((c[a>>2]|0)!=0){$O(e)|0;aE(c[a>>2]|0,d)|0;kJb(c[d>>2]|0)}pX(e);i=b;return}function mN(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+968|0;f=e|0;g=e+8|0;h=c[b+4>>2]|0;j=b+8|0;b=h+((c[j>>2]|0)-4)|0;k=h;while(1){if(!(k>>>0<b>>>0)){l=0;break}if((a[k]|0)==0){k=k+1|0}else{m=0;n=0;o=k;p=4;break}}do{if((p|0)==4){while(1){p=0;h=o;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=je(q|0)|0;if((h&-2097152|0)!=-2097152|(h&393216|0)==0|(h&61440|0)==61440|(h&3072|0)==3072){r=o;s=n;t=m}else{a:do{if(o>>>0<b>>>0){h=0;u=o;v=q;while(1){w=OSa(g,je(v|0)|0,f,f,f,f)|0;if((w|0)<0){x=h;y=u;break a}z=u+w|0;w=h+1|0;if(!(z>>>0<b>>>0)){x=w;y=z;break a}A=z;h=w;u=z;v=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0}}else{x=0;y=o}}while(0);r=y;s=(n|0)>(x|0)?n:x;t=(o|0)==(k|0)?x:m}q=r+1|0;if(q>>>0<b>>>0){m=t;n=s;o=q;p=4}else{break}}if((t|0)>3){B=51;i=e;return B|0}if((s|0)>200){B=50;i=e;return B|0}if((s|0)>3){B=25}else{l=s;break}i=e;return B|0}}while(0);do{if((JI(k,2154992)|0)!=0){s=(KI(k)|0)<<1;t=c[j>>2]|0;if((s|0)<(t|0)){break}B=(t|0)<1048576?12:48;i=e;return B|0}}while(0);B=(l|0)>0|0;i=e;return B|0}function nN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+64|0;d=b|0;e=b+40|0;f=b+48|0;g=b+56|0;h=a+12|0;j=c[h>>2]|0;k=ZX(a,0)|0;if((k|0)==0){l=-12;i=b;return l|0}m=k+8|0;n=c[m>>2]|0;c[n+8>>2]=1;c[n+48>>2]=86017;c[k+236>>2]=1463898624;n=k+48|0;c[n>>2]=0;c[n+4>>2]=0;_X(k,64,1,14112e3);o=a+16|0;p=c[o>>2]|0;q=p+96|0;c[q>>2]=-1;c[q+4>>2]=-1;q=fD(p,0,0,1)|0;p=G;if((LGb(c[a+1140>>2]|0,10230216,0,2)|0)==0){A$(a)}r=c[o>>2]|0;if((c[r+88>>2]|0)==0){s=r}else{t=iD(r)|0;r=j+8|0;c[r>>2]=t;c[r+4>>2]=G;s=c[o>>2]|0}r=c[h>>2]|0;t=JD(s)|0;do{if(!((t&-2097152|0)!=-2097152|(t&393216|0)==0|(t&61440|0)==61440|(t&3072|0)==3072)){if((MSa(d,t)|0)==0){s=c[d>>2]|0;u=(s|0)<0|0?-1:0;v=s}else{u=0;v=0}if((c[d+8>>2]|0)!=3){break}s=c[d+36>>2]|0;j=(s|0)!=0?576:1152;w=821736+(((s|0)==1)<<4)+(((c[d+24>>2]|0)==1)<<3)|0;hD(c[o>>2]|0,c[w>>2]|0,c[w+4>>2]|0)|0;w=JD(c[o>>2]|0)|0;s=(w|0)==1231971951;x=s&1;do{if((w|0)==1483304551|(w|0)==1231971951){y=JD(c[o>>2]|0)|0;if((y&1|0)==0){z=0}else{z=JD(c[o>>2]|0)|0}if((y&2|0)==0){A=0}else{A=JD(c[o>>2]|0)|0}a:do{if((y&4|0)!=0){B=A;C=0;c[e>>2]=j;c[e+4>>2]=c[d+12>>2];D=XIb(z,0,e,k+40|0)|0;E=G;F=c[h>>2]|0;if((c[F+36>>2]|0)==0){H=0}else{I=0;H=((E|0)>(I|0)|(E|0)==(I|0)&D>>>0>0>>>0)&1}do{if((A|0)==0){I=iD(c[o>>2]|0)|0;J=G;if(!((I|0)==0&(J|0)==0)){K=J;L=I;M=21;break}KIb(a,24,2183512,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;O=0}else{K=C;L=B;M=21}}while(0);do{if((M|0)==21){B=a+28|0;if((H|0)==0){O=0;break}else{P=0}do{C=zD(c[o>>2]|0)|0;I=c[c[B>>2]>>2]|0;J=VIb(C&255,0,L,K,256,0)|0;C=G;Q=VIb(P,(P|0)<0|0?-1:0,D,E,100,0)|0;xX(I,J,C,Q,G,0,0,1)|0;P=P+1|0;}while((P|0)<100);c[F+24>>2]=1;break a}}while(0);do{zD(c[o>>2]|0)|0;O=O+1|0;}while((O|0)<100)}}while(0);if((y&8|0)!=0){hD(c[o>>2]|0,4,0)|0;}F=JD(c[o>>2]|0)|0;if(!((F|0)==1281455718|(F|0)==1279348037)){R=A;S=z;break}hD(c[o>>2]|0,17,0)|0;F=ID(c[o>>2]|0)|0;E=F>>>12;D=r+28|0;c[D>>2]=E;B=r+32|0;c[B>>2]=F&4095;F=E+529|0;c[k+448>>2]=F;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){c[f>>2]=1;c[f+4>>2]=c[d+12>>2];E=XIb(F,0,f,k+40|0)|0;c[n>>2]=E;c[n+4>>2]=G}E=c[B>>2]|0;KIb(a,48,2217112,(N=i,i=i+16|0,c[N>>2]=c[D>>2],c[N+8>>2]=E,N)|0);i=N;R=A;S=z}else{R=0;S=0}}while(0);w=c[o>>2]|0;E=wrc(q,p,36,0)|0;fD(w,E,G,0)|0;do{if((JD(c[o>>2]|0)|0)==1447187017){if((HD(c[o>>2]|0)|0)!=1){T=R;U=S;break}hD(c[o>>2]|0,4,0)|0;E=JD(c[o>>2]|0)|0;T=E;U=JD(c[o>>2]|0)|0}else{T=R;U=S}}while(0);E=(U|0)!=0;w=E^1;D=(T|0)==0;if(D&w){break}B=c[o>>2]|0;F=wrc(v,u,q,p)|0;fD(B,F,G,0)|0;if(E){c[g>>2]=j;c[g+4>>2]=c[d+12>>2];E=XIb(U,0,g,k+40|0)|0;F=k+56|0;c[F>>2]=E;c[F+4>>2]=G}F=T;E=0;if(!(D|w|s)){w=c[d+12>>2]<<3;D=Erc(U,0,j,0)|0;B=VIb(F,E,w,(w|0)<0|0?-1:0,D,G)|0;c[(c[m>>2]|0)+72>>2]=B}c[r+40>>2]=x;B=r+16|0;c[B>>2]=F;c[B+4>>2]=E;l=0;i=b;return l|0}}while(0);fD(c[o>>2]|0,q,p,0)|0;l=0;i=b;return l|0}function oN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+12>>2]|0;e=a+16|0;a=fD(c[e>>2]|0,0,0,1)|0;f=G;g=d+8|0;d=c[g>>2]|0;h=c[g+4>>2]|0;g=0;if(((h|0)>(g|0)|(h|0)==(g|0)&d>>>0>128>>>0)&((f|0)<(h|0)|(f|0)==(h|0)&a>>>0<d>>>0)){g=xrc(d,h,a,f)|0;f=G;a=0;i=(f|0)<(a|0)|(f|0)==(a|0)&g>>>0<1024>>>0?g:1024}else{i=1024}g=fX(c[e>>2]|0,b,i)|0;if((g|0)<1){j=(g|0)<0?g:-541478725;return j|0}i=b+36|0;c[i>>2]=c[i>>2]&-3;c[b+32>>2]=0;if((g|0)>127){i=g-128|0;e=(grc((c[b+24>>2]|0)+i|0,2318624,3)|0)==0;k=e?i:g}else{k=g}c[b+28>>2]=k;j=k;return j|0}function pN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;b=i;i=i+64|0;g=b|0;h=b+40|0;j=c[a+12>>2]|0;k=c[c[a+28>>2]>>2]|0;l=CX(k,d,e,f)|0;m=f&1;f=(m|0)==0;n=(m<<1^2)-1|0;do{if((c[j+40>>2]|0)==0){o=7}else{m=k+56|0;p=c[m+4>>2]|0;q=0;if(!((p|0)>(q|0)|(p|0)==(q|0)&(c[m>>2]|0)>>>0>0>>>0)){o=7;break}q=j+16|0;p=c[q+4>>2]|0;r=a+1248|0;s=c[r+4>>2]|0;if(!((p|0)>(s|0)|(p|0)==(s|0)&(c[q>>2]|0)>>>0>(c[r>>2]|0)>>>0)){o=7;break}s=iD(c[a+16>>2]|0)|0;p=G;t=c[r>>2]|0;u=c[r+4>>2]|0;r=(p|0)>(u|0)|(p|0)==(u|0)&s>>>0>t>>>0;v=c[q>>2]|0;w=c[q+4>>2]|0;q=xrc(r?s:v,r?p:w,t,u)|0;p=G;r=c[m>>2]|0;s=c[m+4>>2]|0;m=xrc(v,w,t,u)|0;w=VIb(r,s,q,p,m,G)|0;m=G;s=0;if((e|0)<(s|0)|(e|0)==(s|0)&d>>>0<0>>>0){x=0;y=0}else{s=(m|0)<(e|0)|(m|0)==(e|0)&w>>>0<d>>>0;x=s?m:e;y=s?w:d}s=h+8|0;c[s>>2]=y;c[s+4>>2]=x;s=VIb(y,x,q,p,w,m)|0;m=wrc(t,u,s,G)|0;s=h|0;c[s>>2]=m;c[s+4>>2]=G;z=h}}while(0);do{if((o|0)==7){if((c[j+24>>2]|0)!=0){if((l|0)<0){A=l;i=b;return A|0}else{z=(c[k+400>>2]|0)+(l*24|0)|0;break}}h=0;if((e|0)<(h|0)|(e|0)==(h|0)&d>>>0<1>>>0){B=(c[j+28>>2]|0)+529|0}else{B=0}c[k+448>>2]=B;A=-1;i=b;return A|0}}while(0);B=a+16|0;if(f){C=z|0}else{f=c[B>>2]|0;d=z|0;e=wrc(c[d>>2]|0,c[d+4>>2]|0,-4096,-1)|0;l=G;h=0;x=(l|0)>(h|0)|(l|0)==(h|0)&e>>>0>0>>>0;fD(f,x?e:0,x?l:0,0)|0;C=d}d=fD(c[B>>2]|0,c[C>>2]|0,c[C+4>>2]|0,0)|0;l=G;x=0;if((l|0)<(x|0)|(l|0)==(x|0)&d>>>0<0>>>0){A=d;i=b;return A|0}d=g|0;x=0;l=0;a:while(1){if((l|0)>=4096){D=x;break}e=ca(l,n)|0;f=wrc(c[C>>2]|0,c[C+4>>2]|0,e,(e|0)<0|0?-1:0)|0;e=G;h=fD(c[B>>2]|0,f,e,0)|0;y=G;s=0;do{if((y|0)<(s|0)|(y|0)==(s|0)&h>>>0<0>>>0){E=h;o=25}else{m=JD(c[B>>2]|0)|0;if((m&-2097152|0)!=-2097152|(m&393216|0)==0|(m&61440|0)==61440|(m&3072|0)==3072){F=0;break}if((MSa(g,m)|0)==1){F=0;break}E=c[d>>2]|0;o=25}}while(0);do{if((o|0)==25){o=0;if((E|0)<0){F=0;break}h=wrc(E,(E|0)<0|0?-1:0,f,e)|0;s=G;y=fD(c[B>>2]|0,h,s,0)|0;m=G;u=0;if((m|0)<(u|0)|(m|0)==(u|0)&y>>>0<0>>>0){H=y}else{y=JD(c[B>>2]|0)|0;if((y&-2097152|0)!=-2097152|(y&393216|0)==0|(y&61440|0)==61440|(y&3072|0)==3072){F=1;break}if((MSa(g,y)|0)==1){F=1;break}H=c[d>>2]|0}if((H|0)<0){F=1;break}y=wrc(H,(H|0)<0|0?-1:0,h,s)|0;s=fD(c[B>>2]|0,y,G,0)|0;y=G;h=0;if((y|0)<(h|0)|(y|0)==(h|0)&s>>>0<0>>>0){I=s}else{s=JD(c[B>>2]|0)|0;if((s&-2097152|0)!=-2097152|(s&393216|0)==0|(s&61440|0)==61440|(s&3072|0)==3072){F=2;break}if((MSa(g,s)|0)==1){F=2;break}I=c[d>>2]|0}if((I|0)<0){F=2}else{D=3;break a}}}while(0);x=F;l=l+1|0}F=c[B>>2]|0;B=ca((D|0)==3?l:0,n)|0;n=wrc(B,(B|0)<0|0?-1:0,c[C>>2]|0,c[C+4>>2]|0)|0;C=fD(F,n,G,0)|0;n=G;F=0;if((n|0)<(F|0)|(n|0)==(F|0)&C>>>0<0>>>0){A=C;i=b;return A|0}C=z+8|0;zX(a,k,c[C>>2]|0,c[C+4>>2]|0);a=c[C+4>>2]|0;z=0;if((a|0)<(z|0)|(a|0)==(z|0)&(c[C>>2]|0)>>>0<1>>>0){J=(c[j+28>>2]|0)+529|0}else{J=0}c[k+448>>2]=J;A=0;i=b;return A|0}function qN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=c[a+12>>2]|0;e=d+32|0;f=c[e>>2]|0;if(!((f|0)==0|(f|0)==3|(f|0)==4)){KIb(a,16,2406040,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-22;i=b;return h|0}j=d+3288|0;c[j>>2]=-1;k=a+24|0;l=c[k>>2]|0;do{if((l|0)!=0){m=c[a+28>>2]|0;n=0;o=-1;p=l;while(1){q=c[(c[m+(n<<2)>>2]|0)+8>>2]|0;r=c[q+8>>2]|0;if((r|0)==0){s=o;t=p}else if((r|0)==1){if((o|0)>-1){u=8;break}if((c[q+48>>2]|0)!=86017){u=8;break}c[j>>2]=n;s=n;t=c[k>>2]|0}else{u=10;break}q=n+1|0;if(q>>>0<t>>>0){n=q;o=s;p=t}else{u=12;break}}if((u|0)==8){KIb(a,16,2398456,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}else if((u|0)==10){KIb(a,16,2391504,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}else if((u|0)==12){if((s|0)<0){break}p=t-1|0;o=d+3292|0;c[o>>2]=p;n=(f|0)==0;do{if((p|0)==0){if(!n){u=18}}else{if(!n){u=18;break}KIb(a,16,2377800,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}}while(0);do{if((u|0)==18){n=d+8|0;B$(n,c[a+16>>2]|0,f,2372240);p=C$(a,n)|0;if((p|0)<0){h=p;i=b;return h|0}if((c[o>>2]|0)==0){break}else{h=0}i=b;return h|0}}while(0);if((c[e>>2]|0)!=0){F$(d+8|0,c[a+16>>2]|0,c[a+1316>>2]|0)}vN(a);h=0;i=b;return h|0}}}while(0);KIb(a,16,2384832,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}function rN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;g=b+32|0;h=c[g>>2]|0;do{if((h|0)==(c[f+3288>>2]|0)){if((c[f+3292>>2]|0)==0){j=wN(a,b)|0;i=d;return j|0}k=pJb(88)|0;l=k;c[e>>2]=l;if((k|0)==0){j=-12;i=d;return j|0}m=S1(k,b)|0;if((m|0)<0){mJb(e);j=m;i=d;return j|0}m=f+3300|0;k=c[m>>2]|0;if((k|0)==0){c[f+3296>>2]=l}else{c[k+80>>2]=l}c[m>>2]=c[e>>2]}else{m=a+28|0;l=(c[(c[m>>2]|0)+(h<<2)>>2]|0)+64|0;if((c[l>>2]|0)==1&(c[l+4>>2]|0)==0){KIb(a,24,2413640,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l}l=f+3292|0;if((c[l>>2]|0)==0){j=0;i=d;return j|0}k=(c[(c[m>>2]|0)+(c[g>>2]<<2)>>2]|0)+64|0;m=c[k+4>>2]|0;n=0;if((m|0)>(n|0)|(m|0)==(n|0)&(c[k>>2]|0)>>>0>0>>>0){j=0;i=d;return j|0}k=E$(a,f+8|0,b)|0;if((k|0)<0){j=k;i=d;return j|0}k=(c[l>>2]|0)-1|0;c[l>>2]=k;if((k|0)!=0){break}k=uN(a)|0;if((k|0)<0){j=k}else{break}i=d;return j|0}}while(0);j=0;i=d;return j|0}function sN(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+128|0;e=d|0;f=b+12|0;g=c[f>>2]|0;if((c[g+3292>>2]|0)!=0){KIb(b,24,2183448,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;uN(b)|0}do{if((c[g+36>>2]|0)!=0){h=e|0;mrc(h|0,0,128)|0;a[h]=84;a[e+1|0]=65;a[e+2|0]=71;j=b+1140|0;k=LGb(c[j>>2]|0,2129904,0,0)|0;l=(k|0)!=0;if(l){CFb(e+3|0,c[k+4>>2]|0,31)|0}k=LGb(c[j>>2]|0,2106784,0,0)|0;m=(k|0)!=0;if(m){CFb(e+33|0,c[k+4>>2]|0,31)|0}k=LGb(c[j>>2]|0,2624920,0,0)|0;n=(k|0)!=0;if(n){CFb(e+63|0,c[k+4>>2]|0,31)|0}k=LGb(c[j>>2]|0,2598608,0,0)|0;o=(k|0)!=0;if(o){CFb(e+93|0,c[k+4>>2]|0,5)|0}k=LGb(c[j>>2]|0,2574176,0,0)|0;p=(k|0)!=0;if(p){CFb(e+97|0,c[k+4>>2]|0,31)|0}k=(m&1)+(l&1)+(n&1)+(o&1)+(p&1)|0;p=LGb(c[j>>2]|0,2555512,0,0)|0;if((p|0)==0){q=k}else{a[e+125|0]=0;a[e+126|0]=kd(c[p+4>>2]|0)|0;q=k+1|0}k=e+127|0;a[k]=-1;p=LGb(c[j>>2]|0,2537784,0,0)|0;a:do{if((p|0)==0){r=q}else{j=p+4|0;o=0;while(1){if((o|0)>=148){r=q;break a}if((IFb(c[j>>2]|0,c[1373488+(o<<2)>>2]|0)|0)==0){break}else{o=o+1|0}}a[k]=o;r=q+1|0}}while(0);if((r|0)<=0){break}dD(c[b+16>>2]|0,h,128)}}while(0);r=g+48|0;if((c[r>>2]|0)==0&(c[r+4>>2]|0)==0){i=d;return 0}r=c[f>>2]|0;f=b+16|0;if((c[r+3284>>2]|0)==0){b=r+48|0;fD(c[f>>2]|0,c[b>>2]|0,c[b+4>>2]|0,0)|0;kD(c[f>>2]|0,1868983881);s=b}else{s=r+48|0}b=c[f>>2]|0;g=wrc(c[s>>2]|0,c[s+4>>2]|0,8,0)|0;fD(b,g,G,0)|0;lD(c[f>>2]|0,c[r+56>>2]|0);g=r+60|0;lD(c[f>>2]|0,c[g>>2]|0);bD(c[f>>2]|0,0);b=r+72|0;s=r+80|0;r=1;do{q=s+((((ca(c[b>>2]|0,r)|0)>>>0)/100|0)<<3)|0;e=c[q>>2]|0;k=c[g>>2]|0;p=Frc(e<<8|0>>>24,c[q+4>>2]<<8|e>>>24,k,(k|0)<0|0?-1:0)|0;k=p;bD(c[f>>2]|0,(k|0)>255?255:k);r=r+1|0;}while((r|0)<100);fD(c[f>>2]|0,0,0,2)|0;i=d;return 0}function tN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;b=1372896;while(1){d=c[b+32>>2]|0;if((d|0)==0){e=-1;f=4;break}if((d|0)==(a|0)){e=1128878145;f=4;break}else{b=b+36|0}}if((f|0)==4){return e|0}return 0}function uN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+8|0;d=b|0;e=c[a+12>>2]|0;F$(e+8|0,c[a+16>>2]|0,c[a+1316>>2]|0);vN(a);f=e+3296|0;g=c[f>>2]|0;c[d>>2]=g;if((g|0)==0){h=0;j=e+3300|0;k=j;c[k>>2]=0;i=b;return h|0}l=d;m=0;n=1;o=g;while(1){if((n|0)==0){p=0;q=m;r=o}else{g=wN(a,o|0)|0;p=(g|0)<0?0:n;q=g;r=c[d>>2]|0}P1(r|0);c[f>>2]=c[r+80>>2];mJb(l);g=c[f>>2]|0;c[d>>2]=g;if((g|0)==0){h=q;break}else{m=q;n=p;o=g}}j=e+3300|0;k=j;c[k>>2]=0;i=b;return h|0}function vN(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+40|0;g=f|0;h=c[b+12>>2]|0;j=c[(c[(c[b+28>>2]|0)+(c[h+3288>>2]<<2)>>2]|0)+8>>2]|0;k=(c[j+88>>2]&8388608|0)!=0?2506968:2492560;l=b+16|0;if((c[(c[l>>2]|0)+88>>2]|0)==0){i=f;return}if((c[h+40>>2]|0)==0){i=f;return}m=j+412|0;n=0;while(1){if(!(n>>>0<3>>>0)){o=0;break}p=c[m>>2]|0;q=e[1965176+(n<<1)>>1]|0;if((p|0)==(q|0)){o=1572864;break}if((p|0)==(q>>>1|0)){o=1048576;break}if((p|0)==(q>>>2|0)){o=0;break}else{n=n+1|0}}if((n|0)==3){KIb(b,24,2482768,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;i=f;return}m=c[j+416>>2]|0;if((m|0)==1){s=192}else if((m|0)==2){s=0}else{KIb(b,24,2471520,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;i=f;return}b=n<<10|o|s|-1900544;s=g+20|0;o=j+72|0;n=2147483647;m=-1;q=1;while(1){MSa(g,q<<12|b)|0;p=(c[s>>2]|0)-(c[o>>2]|0)|0;t=(p|0)>-1?p:-p|0;p=(t|0)<(n|0);u=p?q:m;v=q+1|0;if((v|0)<15){n=p?t:n;m=u;q=v}else{break}}if(!((u|0)>-1)){KIb(0,0,2463600,(r=i,i=i+24|0,c[r>>2]=2448728,c[r+8>>2]=2433280,c[r+16>>2]=171,r)|0);i=r;Hd()}if((u|0)==15){i=f;return}r=g+24|0;q=g+36|0;m=g|0;n=b;b=u;while(1){u=b<<12;w=u|n;MSa(g,w)|0;x=d[((c[r>>2]|0)==1)+(2168+(((c[q>>2]|0)==1)<<1))|0]|0;y=x+144|0;if((y|0)<=(c[m>>2]|0)){break}o=b+1|0;if((o|0)==15){z=30;break}else{n=w^u;b=o}}if((z|0)==30){i=f;return}lD(c[l>>2]|0,w);cD(c[l>>2]|0,0,x);x=fD(c[l>>2]|0,0,0,1)|0;w=h+48|0;c[w>>2]=x;c[w+4>>2]=G;kD(c[l>>2]|0,1735289176);lD(c[l>>2]|0,7);c[h+60>>2]=c[m>>2];c[h+64>>2]=1;c[h+68>>2]=0;c[h+72>>2]=0;lD(c[l>>2]|0,0);lD(c[l>>2]|0,0);h=0;do{bD(c[l>>2]|0,((h*255|0|0)/100|0)&255);h=h+1|0;}while((h|0)<100);h=a[k]|0;if(h<<24>>24==0){A=0;B=c[l>>2]|0;z=28}else{w=1;x=h;while(1){bD(c[l>>2]|0,x<<24>>24);if(!(w>>>0<(lrc(k|0)|0)>>>0)){break}h=a[k+w|0]|0;w=w+1|0;x=h}x=c[l>>2]|0;if((w|0)<21){A=w;B=x;z=28}else{C=x}}if((z|0)==28){while(1){z=0;bD(B,0);x=A+1|0;w=c[l>>2]|0;if((x|0)<21){A=x;B=w;z=28}else{C=w;break}}}z=(c[j+116>>2]|0)-529|0;vD(C,(z|0)>0?z<<12:0);cD(c[l>>2]|0,0,(c[m>>2]|0)-y|0);i=f;return}function wN(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+40|0;f=e|0;g=c[a+12>>2]|0;h=g;j=c[b+24>>2]|0;do{if((j|0)!=0){k=b+28|0;l=c[k>>2]|0;if((l|0)<=3){break}m=j;n=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;if((n&-2097152|0)!=-2097152|(n&393216|0)==0|(n&61440|0)==61440|(n&3072|0)==3072){KIb(a,24,2521568,(m=i,i=i+16|0,c[m>>2]=l,c[m+8>>2]=n,m)|0);i=m;o=zS(a,b)|0;i=e;return o|0}MSa(f,n)|0;n=g+3280|0;m=c[n>>2]|0;l=f+20|0;if((m|0)==0){p=c[l>>2]|0;c[n>>2]=p;q=p}else{q=m}m=c[l>>2]|0;if(!((m|0)!=0&(q|0)==(m|0))){c[g+3284>>2]=1}m=g+48|0;if((c[m>>2]|0)==0&(c[m+4>>2]|0)==0){break}m=g+56|0;c[m>>2]=(c[m>>2]|0)+1;m=g+68|0;l=(c[m>>2]|0)+1|0;c[m>>2]=l;p=g+60|0;n=(c[p>>2]|0)+(c[k>>2]|0)|0;c[p>>2]=n;p=g+64|0;if((c[p>>2]|0)!=(l|0)){break}l=g+72|0;k=h+80+(c[l>>2]<<3)|0;c[k>>2]=n;c[k+4>>2]=(n|0)<0|0?-1:0;n=(c[l>>2]|0)+1|0;c[l>>2]=n;if((n|0)==400){n=1;do{k=h+80+(n<<3)|0;r=c[k+4>>2]|0;s=h+80+(n>>1<<3)|0;c[s>>2]=c[k>>2];c[s+4>>2]=r;n=n+2|0;}while((n|0)<400);c[p>>2]=c[p>>2]<<1;c[l>>2]=200}c[m>>2]=0}}while(0);o=zS(a,b)|0;i=e;return o|0}function xN(b){b=b|0;var d=0,e=0;d=c[b+4>>2]|0;do{if((a[d]|0)==77){if((a[d+1|0]|0)!=80){break}if((a[d+2|0]|0)!=43){break}b=a[d+3|0]|0;if((b<<24>>24|0)==23|(b<<24>>24|0)==7){e=100}else{break}return e|0}}while(0);e=0;return e|0}function yN(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[b+12>>2]|0;f=b+16|0;if((ED(c[f>>2]|0)|0)!=2838605){KIb(b,16,2390312,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=d;return h|0}j=zD(c[f>>2]|0)|0;c[e>>2]=j;if(!((j|0)==7|(j|0)==23)){KIb(b,16,2318488,(g=i,i=i+8|0,c[g>>2]=j,g)|0);i=g;h=-1094995529;i=d;return h|0}j=FD(c[f>>2]|0)|0;k=e+12|0;c[k>>2]=j;l=j;m=0<<4|l>>>28;n=0;if(m>>>0>n>>>0|m>>>0==n>>>0&(l<<4|0>>>28)>>>0>-2>>>0){KIb(b,16,2264592,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=d;return h|0}do{if((j|0)==0){KIb(b,24,2183384,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}else{l=hJb(j<<4)|0;c[e+16>>2]=l;if((l|0)!=0){break}KIb(b,16,2217016,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-12;i=d;return h|0}}while(0);c[e+4>>2]=0;c[e+8>>2]=-1;c[e+20>>2]=8;c[e+24>>2]=0;e=ZX(b,0)|0;if((e|0)==0){h=-12;i=d;return h|0}g=e+8|0;j=c[g>>2]|0;c[j+8>>2]=1;c[j+48>>2]=86044;c[j+416>>2]=2;l=j+448|0;c[l>>2]=3;c[l+4>>2]=0;c[j+792>>2]=16;if((QX(j,c[f>>2]|0,16)|0)<0){h=-12;i=d;return h|0}j=c[g>>2]|0;g=c[798984+((a[(c[j+96>>2]|0)+2|0]&3)<<2)>>2]|0;c[j+412>>2]=g;_X(e,32,1152,g);g=e+48|0;c[g>>2]=0;c[g+4>>2]=0;g=e+56|0;c[g>>2]=c[k>>2];c[g+4>>2]=0;g=c[f>>2]|0;if((c[g+88>>2]|0)==0){h=0;i=d;return h|0}k=fD(g,0,0,1)|0;g=G;HB(b)|0;if((LGb(c[b+1140>>2]|0,10230056,0,2)|0)==0){A$(b)}fD(c[f>>2]|0,k,g,0)|0;h=0;i=d;return h|0}function zN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[b+12>>2]|0;f=e+4|0;g=c[f>>2]|0;h=e+12|0;i=c[h>>2]|0;if(!(g>>>0<i>>>0|(i|0)==0)){j=-541478725;return j|0}i=e+8|0;if((g|0)==((c[i>>2]|0)+1|0)){k=g;l=c[e+20>>2]|0;m=b+16|0}else{n=b+16|0;o=e+16|0;p=(c[o>>2]|0)+(g<<4)|0;fD(c[n>>2]|0,c[p>>2]|0,c[p+4>>2]|0,0)|0;p=c[f>>2]|0;q=c[(c[o>>2]|0)+(p<<4)+12>>2]|0;c[e+20>>2]=q;k=p;l=q;m=n}c[i>>2]=k;c[f>>2]=k+1;k=e+20|0;i=fD(c[m>>2]|0,0,0,1)|0;n=G;q=FD(c[m>>2]|0)|0;if((l|0)<13){r=q>>>((12-l|0)>>>0)}else{r=(FD(c[m>>2]|0)|0)>>>((44-l|0)>>>0)|q<<l-12}q=l+20|0;fD(c[m>>2]|0,i,n,0)|0;p=l+51+(r&1048575)>>3&-4;o=e+24|0;do{if((g|0)==(c[o>>2]|0)){if((c[h>>2]|0)==0){break}s=c[e+16>>2]|0;t=s+(g<<4)|0;c[t>>2]=i;c[t+4>>2]=n;c[s+(g<<4)+8>>2]=p;c[s+(g<<4)+12>>2]=l;s=g;t=(g|0)<0|0?-1:0;xX(c[c[b+28>>2]>>2]|0,s,t,s,t,p,0,1)|0;c[o>>2]=(c[o>>2]|0)+1}}while(0);c[k>>2]=r+q&31;r=K1(d,p)|0;if((r|0)<0){j=r;return j|0}r=d+24|0;a[c[r>>2]|0]=q;q=c[h>>2]|0;if((c[f>>2]|0)>>>0>q>>>0){u=(q|0)!=0|0}else{u=0}a[(c[r>>2]|0)+1|0]=u;a[(c[r>>2]|0)+2|0]=0;a[(c[r>>2]|0)+3|0]=0;c[d+32>>2]=0;u=d+8|0;c[u>>2]=g;c[u+4>>2]=(g|0)<0|0?-1:0;g=AD(c[m>>2]|0,(c[r>>2]|0)+4|0,p)|0;if((c[k>>2]|0)!=0){fD(c[m>>2]|0,-4,-1,1)|0;}if((g|0)<(p|0)){P1(d);j=(g|0)<0?g:-5;return j|0}else{c[d+28>>2]=g+4;j=0;return j|0}return 0}function AN(a){a=a|0;mJb((c[a+12>>2]|0)+16|0);return 0}function BN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+80|0;h=g|0;j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[a+12>>2]|0;k=wrc(d,e,-32,-1)|0;l=G;m=0;n=(l|0)>(m|0)|(l|0)==(m|0)&k>>>0>0>>>0;m=CX(j,n?k:0,n?l:0,f)|0;do{if((m|0)>-1){f=c[j+400>>2]|0;n=f+(((c[j+404>>2]|0)-1|0)*24|0)+8|0;o=c[n+4>>2]|0;if((o|0)<(l|0)|(o|0)==(l|0)&(c[n>>2]|0)>>>0<k>>>0){break}c[b+4>>2]=c[f+(m*24|0)>>2];p=0;i=g;return p|0}}while(0);m=0;if((e|0)<(m|0)|(e|0)==(m|0)&d>>>0<0>>>0){p=-1;i=g;return p|0}m=0;if(!((m|0)>(e|0)|(m|0)==(e|0)&(c[b+12>>2]|0)>>>0>d>>>0)){p=-1;i=g;return p|0}d=b+4|0;e=c[d>>2]|0;m=c[b+24>>2]|0;if((m|0)==0){q=e}else{b=m-1|0;c[d>>2]=b;q=b}b=0;if(!((b|0)<(l|0)|(b|0)==(l|0)&q>>>0<k>>>0)){p=0;i=g;return p|0}while(1){r=uX(a,h)|0;if((r|0)<0){break}P1(h);q=0;if(!((q|0)<(l|0)|(q|0)==(l|0)&(c[d>>2]|0)>>>0<k>>>0)){p=0;s=12;break}}if((s|0)==12){i=g;return p|0}c[d>>2]=e;p=r;i=g;return p|0}function CN(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=c[b+4>>2]|0;f=c[b+8>>2]|0;b=e+(f+4)|0;if((f|0)<16){g=0;return g|0}h=e;if((d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)!=1262702669){g=0;return g|0}h=f+7|0;f=e+h|0;if((h|0)>4){i=e+4|0}else{g=0;return g|0}a:while(1){e=a[i]|0;if(e<<24>>24==83){j=(a[i+1|0]|0)==72}else{if((e-65&255)>>>0>25>>>0){g=0;k=17;break}else{j=0}}if(((a[i+1|0]|0)-65&255)>>>0>25>>>0){g=0;k=17;break}e=0;h=0;l=0;m=i+2|0;while(1){n=d[m]|0;o=m+1|0;p=n&127|(l<<7|0>>>25);q=h<<7|l>>>25|0;r=e+1|0;if((r|0)>10){g=0;k=17;break a}if((n&128|0)==0){break}else{e=r;h=q;l=p;m=o}}s=xrc(p,q,r,(r|0)<0|0?-1:0)|0;t=G;l=0;if((t|0)<(l|0)|(t|0)==(l|0)&s>>>0<2>>>0){g=0;k=17;break}if(!((m+(s-1)|0)>>>0<b>>>0)){g=49;k=17;break}if(j){k=14;break}l=wrc(s,t,-2,0)|0;h=m+(l+1)|0;if(h>>>0<f>>>0){i=h}else{g=0;k=17;break}}if((k|0)==14){i=wrc(s,t,-11,-1)|0;t=G;s=0;if(t>>>0>s>>>0|t>>>0==s>>>0&i>>>0>17>>>0){g=0;return g|0}i=o;g=(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)==0?0:100;return g|0}else if((k|0)==17){return g|0}return 0}function DN(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;e=c[a+12>>2]|0;f=a+16|0;g=c[f>>2]|0;h=fD(g,0,0,1)|0;j=e+8|0;c[j>>2]=h;c[j+4>>2]=G;if((FD(g)|0)!=1262702669){KIb(a,16,2154896,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=b;return l|0}a:do{if((jD(g)|0)==0){while(1){j=fD(g,0,0,1)|0;h=G;m=fD(g,0,0,1)|0;n=G;o=DD(g)|0;p=PD(g)|0;q=G;r=fD(g,0,0,1)|0;s=xrc(m,n,r,G)|0;t=wrc(s,G,p,q)|0;u=G;if((o|0)==18515){break}GN(a,o,j,h,t,u);if((jD(g)|0)!=0){break a}}h=fD(g,0,0,1)|0;j=G;hD(g,4,0)|0;o=zD(g)|0;c[e>>2]=o;if((o|0)!=8){KIb(a,16,2106696,(k=i,i=i+8|0,c[k>>2]=o,k)|0);i=k;l=-1163346256;i=b;return l|0}o=PD(g)|0;q=e+16|0;c[q>>2]=o;c[q+4>>2]=G;PD(g)|0;o=ZX(a,0)|0;if((o|0)==0){l=-12;i=b;return l|0}p=o+8|0;s=c[p>>2]|0;c[s+8>>2]=1;c[s+48>>2]=86051;c[s+792>>2]=16;if((QX(s,g,2)|0)<0){l=-12;i=b;return l|0}s=c[p>>2]|0;r=c[s+96>>2]|0;n=r+1|0;c[s+416>>2]=((d[n]|0)>>>4)+1;m=c[800272+((d[r]|0)>>>5<<2)>>2]|0;c[s+412>>2]=m;_X(o,32,1152<<((d[n]|0)<<1&6),m);m=o+48|0;c[m>>2]=0;c[m+4>>2]=0;m=1152<<((d[(c[(c[p>>2]|0)+96>>2]|0)+1|0]|0)<<1&6);p=Crc(c[q>>2]|0,c[q+4>>2]|0,m,(m|0)<0|0?-1:0)|0;m=o+56|0;c[m>>2]=p;c[m+4>>2]=G;m=fD(g,0,0,1)|0;p=xrc(h,j,m,G)|0;m=wrc(p,G,t,u)|0;p=G;j=0;if((p|0)>(j|0)|(p|0)==(j|0)&m>>>0>0>>>0){hD(g,m,p)|0;}if((c[g+88>>2]|0)==0){l=0;i=b;return l|0}p=fD(c[f>>2]|0,0,0,1)|0;m=G;j=HB(a)|0;h=e+24|0;c[h>>2]=j;c[h+4>>2]=G;fD(c[f>>2]|0,p,m,0)|0;l=0;i=b;return l|0}}while(0);KIb(a,16,2129824,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=b;return l|0}function EN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[a+12>>2]|0;e=a+16|0;if((jD(c[e>>2]|0)|0)!=0){f=-541478725;return f|0}g=d+24|0;while(1){d=fD(c[e>>2]|0,0,0,1)|0;h=G;i=c[g>>2]|0;j=c[g+4>>2]|0;if(!((i|0)==0&(j|0)==0|((h|0)<(j|0)|(h|0)==(j|0)&d>>>0<i>>>0))){f=-541478725;k=9;break}i=c[e>>2]|0;j=fD(i,0,0,1)|0;l=G;m=DD(i)|0;n=PD(i)|0;o=G;p=fD(i,0,0,1)|0;i=xrc(j,l,p,G)|0;q=wrc(i,G,n,o)|0;o=G;n=0;if((o|0)<(n|0)|(o|0)==(n|0)&q>>>0<0>>>0){f=-1;k=9;break}if((m|0)==17747){f=-5;k=9;break}else if((m|0)==20545){k=6;break}GN(a,m,d,h,q,o);if((jD(c[e>>2]|0)|0)!=0){f=-541478725;k=9;break}}if((k|0)==6){if((fX(c[e>>2]|0,b,q)|0)<0){f=-12;return f|0}c[b+32>>2]=0;c[b+48>>2]=1;f=0;return f|0}else if((k|0)==9){return f|0}return 0}function FN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=CX(g,d,e,f)|0;if((b|0)<0){h=-1;return h|0}f=g+400|0;e=(c[f>>2]|0)+(b*24|0)|0;d=fD(c[a+16>>2]|0,c[e>>2]|0,c[e+4>>2]|0,0)|0;e=G;i=0;if((e|0)<(i|0)|(e|0)==(i|0)&d>>>0<0>>>0){h=-1;return h|0}d=(c[f>>2]|0)+(b*24|0)+8|0;zX(a,g,c[d>>2]|0,c[d+4>>2]|0);h=0;return h|0}function GN(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;k=i;l=b+16|0;m=c[l>>2]|0;if((e|0)!=20307){hD(m,h,j)|0;i=k;return}e=fD(m,0,0,1)|0;n=wrc(e,G,h,j)|0;j=G;h=PD(m)|0;e=G;o=c[b+12>>2]|0;a:do{if((c[b+24>>2]|0)==0){KIb(b,16,2390160,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}else{q=wrc(h,e,f,g)|0;fD(c[l>>2]|0,q,G,0)|0;q=c[l>>2]|0;r=fD(q,0,0,1)|0;s=G;t=DD(q)|0;u=PD(q)|0;v=G;w=fD(q,0,0,1)|0;q=xrc(r,s,w,G)|0;w=wrc(q,G,u,v)|0;v=G;if((t|0)!=21587){KIb(b,16,2318272,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}t=wrc(w,v,-1,-1)|0;u=G;q=0;if(u>>>0>q>>>0|u>>>0==q>>>0&t>>>0>214748363>>>0){KIb(b,16,2264520,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}t=wrc(w,v,16,0)|0;q=hJb(t)|0;if((q|0)==0){break}t=w;u=AD(c[l>>2]|0,q,t)|0;if(!((u|0)==(w|0)&(((u|0)<0|0?-1:0)|0)==(v|0))){KIb(b,16,2216968,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;kJb(q);break}mrc(q+t|0,0,16)|0;t=w<<3|0>>>29;w=t>>>0>2147483639>>>0;v=w?0:q;u=w?8:t+8|0;t=(u|0)>0|0;b:do{if((a[v]|0)>-1){x=0;y=0;z=t;A=14}else{w=0;s=0;r=0;B=t;while(1){C=v+(B>>>3)|0;D=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7)>>>25;C=B+7|0;E=u>>>0>C>>>0?C:u;C=D|s;D=w|0;if((r|0)>=57){F=D;H=C;I=E;break b}J=C<<7|0>>>25;K=D<<7|C>>>25;C=((E|0)<(u|0))+E|0;if((d[v+(E>>>3)|0]&128>>>((E&7)>>>0)|0)==0){x=K;y=J;z=C;A=14;break}else{w=K;s=J;r=r+7|0;B=C}}}}while(0);if((A|0)==14){t=v+(z>>>3)|0;B=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(z&7)>>>25;t=z+7|0;F=x|0;H=B|y;I=u>>>0>t>>>0?t:u}t=0;do{if(!((F|0)>(t|0)|(F|0)==(t|0)&H>>>0>1073741823>>>0)){B=o+16|0;r=Crc(c[B>>2]|0,c[B+4>>2]|0,1152,0)|0;B=G;if((F|0)>(B|0)|(F|0)==(B|0)&H>>>0>r>>>0){break}r=v+(I>>>3)|0;B=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(I&7);r=I+4|0;s=u>>>0>r>>>0?r:u;r=o+8|0;w=b+28|0;C=((s|0)<(u|0))+s|0;c:do{if((d[v+(s>>>3)|0]&128>>>((s&7)>>>0)|0)==0){L=0;M=0;N=C;A=21}else{J=0;K=0;E=0;D=C;while(1){O=v+(D>>>3)|0;P=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(D&7)>>>25;O=D+7|0;Q=u>>>0>O>>>0?O:u;O=P|K;P=J|0;if((E|0)>=57){R=P;S=O;T=Q;break c}U=O<<7|0>>>25;V=P<<7|O>>>25;O=((Q|0)<(u|0))+Q|0;if((d[v+(Q>>>3)|0]&128>>>((Q&7)>>>0)|0)==0){L=V;M=U;N=O;A=21;break}else{J=V;K=U;E=E+7|0;D=O}}}}while(0);if((A|0)==21){C=v+(N>>>3)|0;s=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(N&7)>>>25;C=N+7|0;R=L|0;S=s|M;T=u>>>0>C>>>0?C:u}C=wrc(c[r>>2]|0,c[r+4>>2]|0,S,R)|0;s=G;xX(c[c[w>>2]>>2]|0,C,s,0,0,0,0,1)|0;D=((T|0)<(u|0))+T|0;d:do{if((d[v+(T>>>3)|0]&128>>>((T&7)>>>0)|0)==0){W=0;X=0;Y=D;A=32}else{E=0;K=0;J=0;O=D;while(1){U=v+(O>>>3)|0;V=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(O&7)>>>25;U=O+7|0;Q=u>>>0>U>>>0?U:u;U=V|K;V=E|0;if((J|0)>=57){Z=V;_=U;$=Q;break d}P=U<<7|0>>>25;aa=V<<7|U>>>25;U=((Q|0)<(u|0))+Q|0;if((d[v+(Q>>>3)|0]&128>>>((Q&7)>>>0)|0)==0){W=aa;X=P;Y=U;A=32;break}else{E=aa;K=P;J=J+7|0;O=U}}}}while(0);if((A|0)==32){D=v+(Y>>>3)|0;O=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(Y&7)>>>25;D=Y+7|0;Z=W|0;_=O|X;$=u>>>0>D>>>0?D:u}D=wrc(c[r>>2]|0,c[r+4>>2]|0,_,Z)|0;O=G;xX(c[c[w>>2]>>2]|0,D,O,1,0,0,0,1)|0;J=B>>>28;K=0;if((F|0)>(K|0)|(F|0)==(K|0)&H>>>0>2>>>0){K=$;E=2;U=O;O=D;D=s;P=C;while(1){aa=0;Q=K;while(1){if((aa|0)>=33){ba=Q;break}V=((Q|0)<(u|0))+Q|0;if((d[v+(Q>>>3)|0]&128>>>((Q&7)>>>0)|0)==0){aa=aa+1|0;Q=V}else{ba=V;break}}Q=v+(ba>>>3)|0;V=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(ba&7)>>>20;Q=ba+12|0;ca=V|aa<<12;if((V&1|0)==0){da=ca}else{da=-(ca&-2)|0}ca=da>>1;V=xrc(O<<1|0>>>31,U<<1|O>>>31,P,D)|0;ea=wrc(V,G,ca,(ca|0)<0|0?-1:0)|0;ca=G;V=E<<J;xX(c[c[w>>2]>>2]|0,ea,ca,V,(V|0)<0|0?-1:0,0,0,1)|0;V=E+1|0;fa=(V|0)<0|0?-1:0;if((fa|0)<(F|0)|(fa|0)==(F|0)&V>>>0<H>>>0){K=u>>>0>Q>>>0?Q:u;E=V;D=U;U=ca;P=O;O=ea}else{break}}}kJb(q);break a}}while(0);KIb(b,16,2183328,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);fD(m,n,j,0)|0;i=k;return}function HN(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=c[b+8>>2]|0;if((e|0)<=0){f=0;return f|0}g=c[b+4>>2]|0;b=0;h=0;i=0;j=0;k=0;l=0;m=0;n=-256;while(1){o=d[g+l|0]|0;p=o|n;a:do{if((n|0)==256){q=d[g+(l+1)|0]|0;r=q<<8|(d[g+(l+2)|0]|0);s=g+e|0;t=g+(l+3)|0;u=a[t]|0;do{if((u&-64)<<24>>24==-128){v=a[g+(l+4)|0]&192;if((v|0)==64){w=0;break}if((v|0)==0){w=1;break}w=(v>>>2|0)==(a[g+(l+6)|0]&240|0)}else{w=0}}while(0);v=t;x=u;while(1){if(!(v>>>0<s>>>0)){break}y=v+1|0;if(!(x<<24>>24==-1)){break}v=y;x=a[y]|0}s=(x&-64)<<24>>24==64?v+2|0:v;u=a[s]|0;t=u&240;if((t|0)==48){z=a[s+2|0]&u&a[s+4|0]&a[s+5|0]&a[s+7|0]&a[s+9|0]&1}else if((t|0)==32){z=a[s+2|0]&u&a[s+4|0]&1}else{z=u<<24>>24==15|0}u=w|(z|0)!=0;if((q&192|0)==64){A=1}else{A=(q&240|0)==32|0}if((p|0)==443){B=m+1|0;C=l;D=k;E=j;F=i;G=h;H=b;break}else if((p|0)==442){I=20}do{if((I|0)==20){I=0;if((A|0)==0){break}B=m;C=l;D=k;E=j;F=i;G=h;H=b+1|0;break a}}while(0);q=(o&240|0)==224;v=u^1;if(!(q^1|v)){B=m;C=l;D=k;E=j;F=i+1|0;G=h;H=b;break}x=(o&224|0)==192;if(!(x^1|v)){B=m;C=r+l|0;D=k;E=j+1|0;F=i;G=h;H=b;break}s=(p|0)==445;if(!(s^1|v)){B=m;C=r+l|0;D=k;E=j;F=i;G=h+1|0;H=b;break}if(!((p|0)!=509|v)){B=m;C=l;D=k;E=j;F=i+1|0;G=h;H=b;break}if(q&v){B=m;C=l;D=k+1|0;E=j;F=i;G=h;H=b;break}if(x&v){B=m;C=l;D=k+1|0;E=j;F=i;G=h;H=b;break}else{B=m;C=l;D=(s&v&1)+k|0;E=j;F=i;G=h;H=b;break}}else{B=m;C=l;D=k;E=j;F=i;G=h;H=b}}while(0);o=C+1|0;if((o|0)<(e|0)){b=H;h=G;i=F;j=E;k=D;l=o;m=B;n=p<<8}else{break}}n=E+F|0;m=(n|0)>(D+1|0)?25:0;do{if((B|0)>(D|0)){if((B*9|0|0)>(H*10|0|0)){break}if((E|0)>12|(F|0)>3){f=52;return f|0}f=(H|0)>2?52:25;return f|0}}while(0);do{if((H|0)>(D|0)){if(((F+G+E|0)*10|0|0)<(H*9|0|0)){break}f=(H|0)>2?52:25;return f|0}}while(0);if(!((F|0)!=0^(E|0)!=0)){f=m;return f|0}if(!(((E|0)>4|(F|0)>1)&(B|0)==0&(H|0)==0)){f=m;return f|0}if(!((e|0)>2048&(n|0)>(D|0))){f=m;return f|0}if((E|0)>12){f=52;return f|0}f=(F|0)>((D<<1)+3|0)?52:25;return f|0}function IN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;d=c[a+12>>2]|0;e=a+16|0;f=fD(c[e>>2]|0,0,0,1)|0;g=G;c[d>>2]=255;h=a+20|0;c[h>>2]=c[h>>2]|1;h=b|0;LD(c[e>>2]|0,6,h,7)|0;if((grc(2319160,h,4)|0)==0){c[d+268>>2]=1;i=b;return 0}if((grc(2314344,h,6)|0)==0){c[d+260>>2]=1;i=b;return 0}else{fD(c[e>>2]|0,f,g,0)|0;i=b;return 0}return 0}function JN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+40|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=c[b+12>>2]|0;m=QN(b,j,f,g,h)|0;if((m|0)<0){n=m;i=e;return n|0}o=b+16|0;p=b+24|0;q=b+28|0;r=l+268|0;s=k|0;t=k+6|0;u=k+7|0;k=l+260|0;v=-1;w=0;x=0;y=m;a:while(1){m=c[f>>2]|0;z=m-128|0;do{if(z>>>0<80>>>0){if((y|0)<4){A=x;B=w;C=v;D=y;break}zD(c[o>>2]|0)|0;E=HD(c[o>>2]|0)|0;if(!((m-176|0)>>>0<16>>>0)){F=E;G=y-3|0;H=7;break}zD(c[o>>2]|0)|0;F=E;G=y-4|0;H=7}else{F=v;G=y;H=7}}while(0);b:do{if((H|0)==7){H=0;E=c[p>>2]|0;I=0;while(1){if(!(I>>>0<E>>>0)){H=10;break}J=c[(c[q>>2]|0)+(I<<2)>>2]|0;if((c[J+4>>2]|0)==(m|0)){K=x;L=w;M=J;break}else{I=I+1|0}}if((H|0)==10){H=0;I=a[l+((m&255)+4)|0]|0;do{if((I-1&255)>>>0<2>>>0){N=0;O=2;P=w}else{if((I-3&255)>>>0<2>>>0){N=1;O=86017;P=w;break}if((I<<24>>24|0)==(-127|0)){N=1;O=86019;P=w;break}else if((I<<24>>24|0)==15){N=1;O=86018;P=w;break}else if((I<<24>>24|0)==16){N=0;O=13;P=w;break}else if((I<<24>>24|0)==27){N=0;O=28;P=w;break}else{if((c[r>>2]|0)!=0&I<<24>>24==-111){N=1;O=65542;P=w;break}if((m-480|0)>>>0<16>>>0){AD(c[o>>2]|0,s,8)|0;fD(c[o>>2]|0,-8,-1,1)|0;if((grc(s,794784,4)|0)==0){if((a[t]|0)!=0){N=0;O=88;P=w;break}if((a[u]|0)!=1){N=0;O=88;P=w;break}}N=0;O=x;P=1;break}if((m|0)==447){N=2;O=1145979222;P=w;break}if((m-448|0)>>>0<32>>>0){E=(c[k>>2]|0)>0;N=1;O=E?69641:86016;P=E?50:w;break}if(z>>>0<8>>>0){N=1;O=86019;P=w;break}if((m-136|0)>>>0<8>>>0|(m-152|0)>>>0<8>>>0){N=1;O=86020;P=w;break}if((m-160|0)>>>0<16>>>0){N=1;O=(F|0)==6?86045:65555;P=w;break}if((m-176|0)>>>0<16>>>0){N=1;O=86061;P=w;break}if((m-192|0)>>>0<16>>>0){N=1;O=86019;P=w;break}if((m-32|0)>>>0<32>>>0){N=3;O=94208;P=w;break}if((m-64853|0)>>>0<11>>>0){N=0;O=71;P=w;break}else{A=x;B=w;C=F;D=G;break b}}}}while(0);I=ZX(b,0)|0;if((I|0)==0){A=O;B=P;C=F;D=G;break}c[I+4>>2]=m;E=c[I+8>>2]|0;c[E+8>>2]=N;c[E+48>>2]=O;if((O|0)==65542){c[E+416>>2]=1;J=E+448|0;c[J>>2]=4;c[J+4>>2]=0;c[E+412>>2]=8e3}c[I+440>>2]=P;c[I+236>>2]=1;K=O;L=P;M=I}if((c[M+76>>2]|0)>47){A=K;B=L;C=F;D=G;break}if(!((m-160|0)>>>0<16>>>0&(F|0)==6)){Q=G;break a}if((c[(c[M+8>>2]|0)+48>>2]|0)!=86045){Q=G;break a}if((G|0)<6){A=K;B=L;C=6;D=G}else{H=42;break a}}}while(0);hD(c[o>>2]|0,D,(D|0)<0|0?-1:0)|0;m=QN(b,j,f,g,h)|0;if((m|0)<0){n=m;H=44;break}else{v=C;w=B;x=A;y=m}}if((H|0)==42){hD(c[o>>2]|0,6,0)|0;Q=G-6|0}else if((H|0)==44){i=e;return n|0}H=fX(c[o>>2]|0,d,Q)|0;Q=c[g+4>>2]|0;o=d+8|0;c[o>>2]=c[g>>2];c[o+4>>2]=Q;Q=c[h+4>>2]|0;o=d+16|0;c[o>>2]=c[h>>2];c[o+4>>2]=Q;Q=c[j+4>>2]|0;o=d+64|0;c[o>>2]=c[j>>2];c[o+4>>2]=Q;c[d+32>>2]=c[M>>2];n=(H|0)<0?H:0;i=e;return n|0}function KN(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+32|0;e=f|0;g=f+8|0;h=f+16|0;j=f+24|0;k=c[d>>2]|0;l=c[d+4>>2]|0;c[g>>2]=k;c[g+4>>2]=l;m=a+16|0;n=fD(c[m>>2]|0,k,l,0)|0;l=G;k=0;if((l|0)<(k|0)|(l|0)==(k|0)&n>>>0<0>>>0){o=-2147483648;p=0;i=f;return(G=o,p)|0}n=QN(a,g,e,h,j)|0;if((n|0)<0){o=-2147483648;p=0;i=f;return(G=o,p)|0}k=a+28|0;l=n;while(1){if((c[e>>2]|0)==(c[(c[(c[k>>2]|0)+(b<<2)>>2]|0)+4>>2]|0)){q=c[j>>2]|0;r=c[j+4>>2]|0;if(!((q|0)==0&(r|0)==(-2147483648|0))){break}}hD(c[m>>2]|0,l,(l|0)<0|0?-1:0)|0;n=QN(a,g,e,h,j)|0;if((n|0)<0){o=-2147483648;p=0;s=8;break}else{l=n}}if((s|0)==8){i=f;return(G=o,p)|0}s=c[g+4>>2]|0;c[d>>2]=c[g>>2];c[d+4>>2]=s;o=r;p=q;i=f;return(G=o,p)|0}function LN(a){a=a|0;var b=0;b=(krc(c[a+4>>2]|0,2324416,20)|0)==0;return(b?100:0)|0}function MN(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;d=i;i=i+3160|0;e=d|0;f=d+8|0;g=d+16|0;h=d+1040|0;j=d+3088|0;k=d+3096|0;l=k|0;m=i;i=i+4|0;i=i+7&-8;n=i;i=i+4|0;i=i+7&-8;o=i;i=i+4|0;i=i+7&-8;p=i;i=i+4|0;i=i+7&-8;q=i;i=i+8|0;r=i;i=i+8|0;s=i;i=i+4|0;i=i+7&-8;t=i;i=i+4|0;i=i+7&-8;u=i;i=i+4|0;i=i+7&-8;v=i;i=i+4|0;i=i+7&-8;c[e>>2]=0;w=c[b+12>>2]|0;x=b+32|0;y=rJb(x)|0;z=lrc(y|0)|0;A=y+(z-3)|0;do{if(!(z>>>0<4>>>0)){if((a[y+(z-4)|0]|0)!=46){break}B=(krc(A,2106680,3)|0)==0;C=B?2624824:2598536;a[A]=a[C]|0;a[A+1|0]=a[C+1|0]|0;a[A+2|0]=a[C+2|0]|0;C=b;KIb(C,40,2574048,(D=i,i=i+16|0,c[D>>2]=x,c[D+8>>2]=y,D)|0);i=D;B=oX(w+272|0,y,1343376,0)|0;if((B|0)<0){KIb(C,16,2555384,(D=i,i=i+8|0,c[D>>2]=y,D)|0);i=D;E=B;kJb(y);i=d;return E|0}SFb(g,0,-1);F=b+16|0;a:do{if((jD(c[F>>2]|0)|0)==0){H=h|0;I=k;J=h+6|0;K=h+8|0;L=b+24|0;M=h+10|0;N=r|0;O=r+4|0;P=w+276|0;Q=h+4|0;R=0;S=0;T=0;U=0;b:while(1){if((KD(c[F>>2]|0,H,2048)|0)==0){V=L;break a}a[h+(mc(H|0,2537576)|0)|0]=0;c:do{if((krc(H,2521496,3)|0)==0){c[j>>2]=0;mrc(I|0,0,64)|0;W=Bd(H|0,2506896,(D=i,i=i+16|0,c[D>>2]=k,c[D+8>>2]=j,D)|0)|0;i=D;if((W|0)==2){if((c[j>>2]|0)>>>0>31>>>0){X=14;break b}}else{KIb(C,24,2492456,(D=i,i=i+8|0,c[D>>2]=H,D)|0);i=D;c[l>>2]=6581877;c[j>>2]=0}W=ZX(b,0)|0;if((W|0)==0){E=-12;X=52;break b}c[W+4>>2]=c[j>>2];Y=c[W+8>>2]|0;c[Y+8>>2]=3;c[Y+48>>2]=94208;_X(W,64,1,1e3);MGb(W+88|0,2463568,I,0)|0;KIb(C,48,2448688,(D=i,i=i+16|0,c[D>>2]=c[j>>2],c[D+8>>2]=k,D)|0);i=D;Z=1;_=S;$=T;aa=W}else{do{if((R|0)!=0){if((krc(H,2433256,10)|0)!=0){if((krc(H,2391480,4)|0)==0){ba=Q}else{break}while(1){if((a[ba]|0)==32){ba=ba+1|0}else{break}}MGb(R+88|0,2384808,ba,0)|0;KIb(C,48,2377728,(D=i,i=i+16|0,c[D>>2]=c[R+4>>2],c[D+8>>2]=ba,D)|0);i=D;Z=1;_=S;$=T;aa=R;break c}if((c[L>>2]|0)==0){X=20;break b}W=Bd(M|0,2413560,(D=i,i=i+40|0,c[D>>2]=m,c[D+8>>2]=n,c[D+16>>2]=o,c[D+24>>2]=p,c[D+32>>2]=q,D)|0)|0;i=D;if((W|0)!=5){X=22;break b}W=c[m>>2]|0;Y=Erc(W,(W|0)<0|0?-1:0,3600,0)|0;W=G;ca=c[n>>2]|0;da=Erc(ca,(ca|0)<0|0?-1:0,60,0)|0;ca=wrc(da,G,Y,W)|0;W=c[o>>2]|0;Y=wrc(ca,G,W,(W|0)<0|0?-1:0)|0;W=Erc(Y,G,1e3,0)|0;Y=G;ca=c[p>>2]|0;da=wrc(ca,(ca|0)<0|0?-1:0,T,S)|0;ca=wrc(da,G,W,Y)|0;c[N>>2]=1;c[O>>2]=1e3;Y=XIb(ca,G,r,R+40|0)|0;ca=G;W=IV(P+(((c[L>>2]|0)-1|0)*20|0)|0,10230376,0,0)|0;if((W|0)==0){E=-12;X=52;break b}da=c[q+4>>2]|0;ea=W+64|0;c[ea>>2]=c[q>>2];c[ea+4>>2]=da;da=W+8|0;c[da>>2]=Y;c[da+4>>2]=ca;c[W+32>>2]=(c[L>>2]|0)-1;Z=U;_=S;$=T;aa=R;break c}}while(0);if((krc(H,2372200,6)|0)==0){c[s>>2]=0;c[t>>2]=0;c[u>>2]=0;c[v>>2]=0;W=J;while(1){fa=a[W]|0;if((fa<<24>>24|0)==45|(fa<<24>>24|0)==43){X=33;break}else if((fa<<24>>24|0)!=32){ga=W;ha=0;ia=1;break}W=W+1|0}if((X|0)==33){X=0;ca=fa<<24>>24==45;ga=W+1|0;ha=ca?-1:0;ia=ca?-1:1}Bd(ga|0,2359552,(D=i,i=i+32|0,c[D>>2]=s,c[D+8>>2]=t,c[D+16>>2]=u,c[D+24>>2]=v,D)|0)|0;i=D;ca=c[s>>2]|0;da=Erc(ca,(ca|0)<0|0?-1:0,3600,0)|0;ca=G;Y=c[t>>2]|0;ea=Erc(Y,(Y|0)<0|0?-1:0,60,0)|0;Y=wrc(ea,G,da,ca)|0;ca=c[u>>2]|0;da=wrc(Y,G,ca,(ca|0)<0|0?-1:0)|0;ca=Erc(da,G,1e3,0)|0;da=c[v>>2]|0;Y=wrc(ca,G,da,(da|0)<0|0?-1:0)|0;da=Erc(Y,G,ia,ha)|0;Z=U;_=G;$=da;aa=R;break}if((krc(H,2347816,8)|0)==0){da=Bd(K|0,2341424,(D=i,i=i+8|0,c[D>>2]=e,D)|0)|0;i=D;if((da|0)==1){Z=U;_=S;$=T;aa=R;break}KIb(C,16,2335736,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;Z=U;_=S;$=T;aa=R;break}if((U|0)!=0){Z=U;_=S;$=T;aa=R;break}da=a[H]|0;if((da<<24>>24|0)==0|(da<<24>>24|0)==35){Z=0;_=S;$=T;aa=R;break}UFb(g,2330424,(D=i,i=i+8|0,c[D>>2]=H,D)|0);i=D;Z=0;_=S;$=T;aa=R}}while(0);if((jD(c[F>>2]|0)|0)==0){R=aa;S=_;T=$;U=Z}else{V=L;break a}}if((X|0)==14){KIb(C,16,2471464,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=-22;kJb(y);i=d;return E|0}else if((X|0)==20){KIb(C,16,2424456,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=-1094995529;kJb(y);i=d;return E|0}else if((X|0)==22){KIb(C,16,2405952,(D=i,i=i+8|0,c[D>>2]=H,D)|0);i=D;V=L;break}else if((X|0)==52){kJb(y);i=d;return E|0}}else{V=b+24|0}}while(0);C=c[e>>2]|0;F=c[V>>2]|0;if(C>>>0<F>>>0){U=(c[(c[b+28>>2]|0)+(C<<2)>>2]|0)+72|0;c[U>>2]=c[U>>2]|1;ja=c[V>>2]|0}else{ja=F}if((ja|0)!=0){F=w+276|0;U=0;do{c[F+(U*20|0)+16>>2]=1;JV(F+(U*20|0)|0);U=U+1|0;}while(U>>>0<(c[V>>2]|0)>>>0)}U=g+4|0;if(!((c[U>>2]|0)>>>0<(c[g+8>>2]|0)>>>0)){_Fb(g,0)|0;E=-12;kJb(y);i=d;return E|0}_Fb(g,f)|0;if((c[V>>2]|0)!=0){F=b+28|0;C=0;do{T=c[(c[F>>2]|0)+(C<<2)>>2]|0;S=rJb(c[f>>2]|0)|0;R=T+8|0;c[(c[R>>2]|0)+96>>2]=S;c[(c[R>>2]|0)+100>>2]=c[U>>2];C=C+1|0;}while(C>>>0<(c[V>>2]|0)>>>0)}kJb(c[f>>2]|0);E=B;kJb(y);i=d;return E|0}}while(0);KIb(b,16,2129728,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=-1094995529;kJb(y);i=d;return E|0}function NN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+104|0;e=d|0;f=d+80|0;g=d+88|0;h=d+96|0;j=c[a+12>>2]|0;k=j+272|0;l=c[(c[k>>2]|0)+16>>2]|0;m=c[a+24>>2]|0;a=j+276|0;if((m|0)==0){n=0}else{j=0;o=2147483647;p=-1;q=0;while(1){r=(c[a+(q*20|0)>>2]|0)+((c[a+(q*20|0)+12>>2]|0)*80|0)+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;r=(t|0)<(o|0)|(t|0)==(o|0)&s>>>0<p>>>0;u=r?q:j;v=q+1|0;if(v>>>0<m>>>0){j=u;o=r?t:o;p=r?s:p;q=v}else{n=u;break}}}q=a+(n*20|0)|0;p=MV(q,e)|0;if((p|0)<0){w=p;i=d;return w|0}p=c[a+(n*20|0)+12>>2]|0;do{if((p|0)<(c[a+(n*20|0)+4>>2]|0)){o=(c[q>>2]|0)+(p*80|0)+64|0;j=e+64|0;m=c[j>>2]|0;u=c[j+4>>2]|0;j=xrc(c[o>>2]|0,c[o+4>>2]|0,m,u)|0;x=j;y=u;z=m}else{m=iD(l)|0;u=G;j=0;o=e+64|0;v=c[o>>2]|0;s=c[o+4>>2]|0;if((u|0)<(j|0)|(u|0)==(j|0)&m>>>0<0>>>0){x=65535;y=s;z=v;break}j=xrc(m,u,v,s)|0;x=j;y=s;z=v}}while(0);p=e+64|0;fD(l,z,y,0)|0;J1(b);y=b+28|0;c[y>>2]=0;z=b+24|0;c[z>>2]=0;q=e+32|0;n=0;while(1){a=fD(l,0,0,1)|0;v=G;A=QN(c[k>>2]|0,0,f,g,h)|0;if((A|0)<0){B=10;break}s=A&65535;j=fD(l,0,0,1)|0;u=G;m=xrc(A,0,a,v)|0;v=wrc(m,G,j,u)|0;u=v+n|0;if((u|0)>(x|0)){B=17;break}if((c[f>>2]&31|0)!=(c[q>>2]|0)){B=17;break}v=N1(b,s)|0;if((v|0)<0){C=v;B=18;break}v=AD(l,(c[z>>2]|0)+((c[y>>2]|0)-s)|0,s)|0;if((v|0)<(s|0)){c[y>>2]=v-s+(c[y>>2]|0)}if((u|0)<(x|0)){n=u}else{B=17;break}}if((B|0)==10){if((c[y>>2]|0)==0){C=A;B=18}else{B=17}}if((B|0)==17){A=e+8|0;y=c[A>>2]|0;n=c[A+4>>2]|0;A=b+16|0;c[A>>2]=y;c[A+4>>2]=n;A=b+8|0;c[A>>2]=y;c[A+4>>2]=n;n=c[p+4>>2]|0;A=b+64|0;c[A>>2]=c[p>>2];c[A+4>>2]=n;c[b+32>>2]=c[q>>2];P1(e);w=0;i=d;return w|0}else if((B|0)==18){P1(b);P1(e);w=C;i=d;return w|0}return 0}function ON(a){a=a|0;var b=0,d=0,e=0;b=c[a+12>>2]|0;d=a+24|0;if((c[d>>2]|0)!=0){a=b+276|0;e=0;do{OV(a+(e*20|0)|0);e=e+1|0;}while(e>>>0<(c[d>>2]|0)>>>0)}d=b+272|0;if((c[d>>2]|0)==0){return 0}YX(d);return 0}function PN(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;l=i;i=i+8|0;m=l|0;n=m;o=i;i=i+8|0;p=c[a+12>>2]|0;q=(b|0)==-1;do{if(q){r=a+24|0;if((c[r>>2]|0)==1){break}s=(c[c[a+28>>2]>>2]|0)+40|0;t=c[s+4>>2]|0;c[m>>2]=c[s>>2];c[m+4>>2]=t;c[o>>2]=1;c[o+4>>2]=1e6;t=XIb(f,g,o,n)|0;s=G;u=c[n+4>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=c[m>>2]|0;x=Erc(u,(u|0)<0|0?-1:0,1e6,0)|0;u=G;y=UIb(d,e,v,w,x,u,8195)|0;z=G;A=UIb(h,j,v,w,x,u,8194)|0;u=G;if((c[r>>2]|0)==0){B=0;i=l;return B|0}x=p+276|0;w=0;v=0;while(1){C=NV(x+(w*20|0)|0,a,-1,y,z,t,s,A,u,k)|0;D=(C|0)<0?C:v;C=w+1|0;if(C>>>0<(c[r>>2]|0)>>>0){w=C;v=D}else{B=D;break}}i=l;return B|0}}while(0);m=q?0:b;B=NV(p+276+(m*20|0)|0,a,m,d,e,f,g,h,j,k)|0;i=l;return B|0}function QN(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;j=i;i=i+8|0;k=j|0;l=c[b+12>>2]|0;m=l;n=b+16|0;o=fD(c[n>>2]|0,0,0,1)|0;p=l;q=(e|0)!=0;r=l+260|0;s=l+264|0;l=k|0;t=k+1|0;u=t;v=k+3|0;k=b;w=G;x=o;a:while(1){fD(c[n>>2]|0,x,w,0)|0;b:while(1){c[p>>2]=255;o=c[n>>2]|0;y=1e5;z=255;while(1){if((y|0)<=0){A=-1;B=z;break}if((jD(o)|0)!=0){A=-1;B=z;break}C=(zD(o)|0|z<<8)&16777215;if((z|0)==1){A=C;B=C;break}else{y=y-1|0;z=C}}c[p>>2]=B;D=fD(c[n>>2]|0,0,0,1)|0;E=G;if((A|0)<0){F=8;break a}if((A-442|0)>>>0<2>>>0){continue}do{if((A|0)==447){if((c[r>>2]|0)!=0){if((c[s>>2]|0)!=0){break}z=HD(c[n>>2]|0)|0;hD(c[n>>2]|0,z,(z|0)<0|0?-1:0)|0;continue b}z=HD(c[n>>2]|0)|0;y=hJb(z)|0;o=c[n>>2]|0;if((y|0)==0){hD(o,z,(z|0)<0|0?-1:0)|0;continue b}C=AD(o,y,z)|0;do{if((C|0)==(z|0)){do{if((z|0)>5){o=Ob(y|0,83,z-5|0)|0;if((o|0)==0){break}c[r>>2]=(grc(o+1|0,2216904,5)|0)==0}}while(0);o=c[r>>2]|0;H=o-((o|0)==0)|0;c[r>>2]=H;if((H|0)>=0){break}if((z|0)==1018){if((a[y]|0)!=1){break}H=d[y+29|0]|0;o=H&15;I=d[y+30|0]|0;J=I&15;K=d[y+31|0]|0;L=K&15;M=((K>>>4)*10|0)+L|0;do{if((((H>>>4)*10|0)+o&248)>>>0<24>>>0){if(!((((I>>>4)*10|0)+J&252)>>>0<60>>>0)){N=0;break}if(!((M&252)>>>0<60>>>0&o>>>0<10>>>0&J>>>0<10>>>0)){N=0;break}N=L>>>0<10>>>0|0}else{N=0}}while(0);c[s>>2]=N;break}else if((z|0)==980){if((a[y]|0)!=0){break}L=y+13|0;J=je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=y+17|0;o=je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=d[y+25|0]|0;M=L&15;I=d[y+26|0]|0;H=I&15;K=d[y+27|0]|0;O=K&15;P=((K>>>4)*10|0)+O|0;do{if((((L>>>4)*10|0)+M&248)>>>0<24>>>0){if(!((((I>>>4)*10|0)+H&252)>>>0<60>>>0)){Q=0;break}if(!((P&252)>>>0<60>>>0&M>>>0<10>>>0&H>>>0<10>>>0&O>>>0<10>>>0)){Q=0;break}Q=o>>>0>=J>>>0|0}else{Q=0}}while(0);c[s>>2]=Q;break}else{break}}else{J=z-C|0;hD(c[n>>2]|0,J,(J|0)<0|0?-1:0)|0;}}while(0);kJb(y);if((c[s>>2]|0)==0){continue b}C=-2-z|0;J=hD(c[n>>2]|0,C,(C|0)<0|0?-1:0)|0;C=G;o=0;if((C|0)<(o|0)|(C|0)==(o|0)&J>>>0<0>>>0){continue b}}else if((A|0)==446){J=c[n>>2]|0;hD(J,HD(J)|0,0)|0;continue b}else if((A|0)==444){J=c[n>>2]|0;o=HD(J)|0;zD(J)|0;zD(J)|0;C=HD(J)|0;hD(J,C,(C|0)<0|0?-1:0)|0;HD(J)|0;O=o-10-C|0;if((O|0)>3){C=O;do{O=(zD(J)|0)&255;o=zD(J)|0;H=HD(J)|0;a[(o&255)+(m+4)|0]=O;O=H&65535;hD(J,O,0)|0;C=C-4-O|0;}while((C|0)>3)}JD(J)|0;continue b}}while(0);if(!((A-448|0)>>>0<32>>>0|(A-480|0)>>>0<16>>>0)){if(!((A|0)==509|(A|0)==447|(A|0)==445)){continue}}if(q){C=fD(c[n>>2]|0,0,0,1)|0;z=wrc(C,G,-4,-1)|0;c[e>>2]=z;c[e+4>>2]=G}z=HD(c[n>>2]|0)|0;if((A|0)==447){R=z;S=447;T=-2147483648;U=0;V=-2147483648;W=0;break}else{X=z}while(1){if((X|0)<1){w=E;x=D;continue a}Y=zD(c[n>>2]|0)|0;Z=X-1|0;if((Y|0)==255){X=Z}else{break}}if((Y&192|0)==64){zD(c[n>>2]|0)|0;_=X-3|0;$=zD(c[n>>2]|0)|0}else{_=Z;$=Y}if(($&224|0)==32){F=51;break}if(($&192|0)==128){F=56;break}if(($|0)==15){aa=_;ba=A;ca=-2147483648;da=0;ea=-2147483648;fa=0;F=73;break}}do{if((F|0)==51){F=0;z=c[n>>2]|0;if(($|0)<0){ga=(zD(z)|0)&255}else{ga=$&255}a[l]=ga;AD(z,t,4)|0;z=a[l]&14;C=((he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(z<<29|0>>>3);y=C|((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;C=0<<29|z>>>3|0;if(($&16|0)==0){aa=_-4|0;ba=A;ca=C;da=y;ea=C;fa=y;F=73;break}z=c[n>>2]|0;a[l]=zD(z)|0;AD(z,t,4)|0;z=a[l]&14;O=((he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(z<<29|0>>>3);aa=_-9|0;ba=A;ca=C;da=y;ea=0<<29|z>>>3|0;fa=O|((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;F=73}else if((F|0)==56){F=0;O=zD(c[n>>2]|0)|0;z=zD(c[n>>2]|0)|0;y=_-2|0;if((z|0)>(y|0)){w=E;x=D;continue a}C=y-z|0;do{if((O&128|0)==0){ha=z;ia=-2147483648;ja=0;ka=-2147483648;la=0}else{y=c[n>>2]|0;a[l]=zD(y)|0;AD(y,t,4)|0;y=a[l]&14;H=((he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(y<<29|0>>>3);o=H|((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;H=0<<29|y>>>3|0;if((O&64|0)==0){ha=z-5|0;ia=H;ja=o;ka=H;la=o;break}y=c[n>>2]|0;a[l]=zD(y)|0;AD(y,t,4)|0;y=a[l]&14;M=((he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(y<<29|0>>>3);ha=z-10|0;ia=H;ja=o;ka=0<<29|y>>>3|0;la=M|((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)>>>1}}while(0);if((O&63|0)!=0&(ha|0)==0){KIb(k,24,2183248,(ma=i,i=i+1|0,i=i+7&-8,c[ma>>2]=0,ma)|0);i=ma;na=O&192}else{na=O}do{if((na&1|0)==0){oa=A;pa=ha}else{z=zD(c[n>>2]|0)|0;M=ha-1|0;y=z>>>4;o=(y&11)+(y&9)|0;if((z&64|0)!=0|(o|0)>(M|0)){KIb(k,24,2154840,(ma=i,i=i+8|0,c[ma>>2]=z,ma)|0);i=ma;qa=0;ra=0}else{qa=z;ra=o}hD(c[n>>2]|0,ra,(ra|0)<0|0?-1:0)|0;o=M-ra|0;if((qa&1|0)==0){oa=A;pa=o;break}if(((zD(c[n>>2]|0)|0)&127|0)==0){oa=A;pa=o-1|0;break}M=zD(c[n>>2]|0)|0;if((M&128|0)==0){sa=M|A<<8&65280}else{sa=A}oa=sa;pa=o-2|0}}while(0);if((pa|0)<0){w=E;x=D;continue a}hD(c[n>>2]|0,pa,(pa|0)<0|0?-1:0)|0;aa=C;ba=oa;ca=ia;da=ja;ea=ka;fa=la;F=73}}while(0);do{if((F|0)==73){F=0;if((ba|0)!=445){R=aa;S=ba;T=ea;U=fa;V=ca;W=da;break}R=aa-1|0;S=zD(c[n>>2]|0)|0;T=ea;U=fa;V=ca;W=da}}while(0);if((R|0)<0){w=E;x=D}else{break}}if((F|0)==8){F=(jD(c[n>>2]|0)|0)==0;ta=F?-11:-541478725;i=j;return ta|0}do{if(!((U|0)==0&(T|0)==(-2147483648|0)|q^1)){F=b+24|0;D=c[F>>2]|0;if((D|0)==0){break}x=b+28|0;E=0;w=D;while(1){do{if((S|0)==(c[(c[(c[x>>2]|0)+(E<<2)>>2]|0)+4>>2]|0)){if((c[(c[n>>2]|0)+88>>2]|0)==0){ua=w;break}wX(b,E);xX(c[(c[x>>2]|0)+(E<<2)>>2]|0,c[e>>2]|0,c[e+4>>2]|0,U,T,0,0,1)|0;ua=c[F>>2]|0}else{ua=w}}while(0);C=E+1|0;if(C>>>0<ua>>>0){E=C;w=ua}else{break}}}}while(0);c[f>>2]=S;c[g>>2]=W;c[g+4>>2]=V;c[h>>2]=U;c[h+4>>2]=T;ta=R;i=j;return ta|0}function RN(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;e=i;f=b+12|0;g=c[f>>2]|0;c[g+8>>2]=0;j=c[b+8>>2]|0;k=g+44|0;c[k>>2]=(j|0)==1346536;l=(j|0)==1345416|0;c[g+48>>2]=l;m=(j|0)==1345504;n=g+40|0;c[n>>2]=(j|0)==1345032|m?1:l;c[g+52>>2]=m&1;m=c[b+1076>>2]|0;do{if((m|0)==0){c[g+4>>2]=2048;o=8}else{if((m-20|0)>>>0>8388598>>>0){KIb(b,16,2359520,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;q=b+24|0;break}else{c[g+4>>2]=m;o=8;break}}}while(0);a:do{if((o|0)==8){m=b+1080|0;if((c[m>>2]|0)<0){c[m>>2]=7e5}m=g+64|0;l=m;j=g+32|0;c[j>>2]=0;r=g+36|0;c[r>>2]=0;s=b+24|0;t=b+28|0;u=b;mrc(m|0,0,16)|0;m=160;v=136;w=128;x=32;y=224;z=192;A=0;while(1){B=c[s>>2]|0;if(!(A>>>0<B>>>0)){o=12;break}C=c[(c[t>>2]|0)+(A<<2)>>2]|0;D=pJb(56)|0;if((D|0)==0){q=s;break a}c[C+12>>2]=D;_X(C,64,1,9e4);E=C+8|0;C=c[E>>2]|0;F=c[C+8>>2]|0;if((F|0)==1){do{if((c[n>>2]|0)==0){G=c[C+48>>2]|0;if(!((G|0)==86019|(G|0)==86020|(G|0)==65537)){H=C;break}I=u5a(G)|0;KIb(u,24,2347672,(p=i,i=i+8|0,c[p>>2]=I,p)|0);i=p;H=c[E>>2]|0}else{H=C}}while(0);C=c[H+48>>2]|0;if((C|0)==86019){a[D+4|0]=w;J=m;K=v;L=w+1|0;M=z}else if((C|0)==86020){a[D+4|0]=v;J=m;K=v+1|0;L=w;M=z}else if((C|0)==65537){C=m+1|0;a[D+4|0]=m;I=0;while(1){if((I|0)>=4){break}if((c[919048+(I<<2)>>2]|0)==(c[(c[E>>2]|0)+412>>2]|0)){break}else{I=I+1|0}}if((I|0)==4){q=s;break a}if((c[(c[E>>2]|0)+416>>2]|0)>8){N=-1;o=72;break}a[D+32|0]=12;a[D+33|0]=(c[(c[E>>2]|0)+416>>2]|0)+255|I<<4;a[D+34|0]=-128;c[D+36>>2]=c[(c[E>>2]|0)+416>>2]<<1;J=C;K=v;L=w;M=z}else{a[D+4|0]=z;J=m;K=v;L=w;M=z+1|0}c[D+8>>2]=4096;c[j>>2]=(c[j>>2]|0)+1;O=J;P=K;Q=L;R=x;S=y;T=M}else if((F|0)==3){a[D+4|0]=x;c[D+8>>2]=16384;O=m;P=v;Q=w;R=x+1|0;S=y;T=z}else if((F|0)==0){G=y+1|0;a[D+4|0]=y;U=c[(c[E>>2]|0)+524>>2]|0;do{if((U|0)==0){KIb(u,24,2341296,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;c[D+8>>2]=235520}else{V=((U|0)/8|0)+6144|0;c[D+8>>2]=V;if((V|0)<=8387584){break}KIb(u,24,2335592,(p=i,i=i+8|0,c[p>>2]=V,p)|0);i=p;c[D+8>>2]=8387584}}while(0);c[r>>2]=(c[r>>2]|0)+1;O=m;P=v;Q=w;R=x;S=G;T=z}else{N=-1;o=72;break}U=dHb(16)|0;c[D>>2]=U;if((U|0)==0){q=s;break a}else{m=O;v=P;w=Q;x=R;y=S;z=T;A=A+1|0}}if((o|0)==12){if((B|0)==0){W=0;X=0;Y=0}else{A=c[t>>2]|0;z=0;y=0;x=0;w=0;while(1){v=c[A+(y<<2)>>2]|0;m=c[v+12>>2]|0;r=c[v+8>>2]|0;v=r+540|0;if((c[v>>2]|0)==0){Z=(a[m+4|0]|0)==-32?v:r+72|0}else{Z=v}v=c[Z>>2]|0;if((v|0)==0){_=838860800/(B>>>0)|0}else{_=v}v=_+z|0;r=a[m+4|0]|0;if((r&-32)<<24>>24==-64){$=w;aa=_+x|0}else{$=(r<<24>>24==-32?_:0)+w|0;aa=x}r=y+1|0;if(r>>>0<B>>>0){z=v;y=r;x=aa;w=$}else{W=v;X=aa;Y=$;break}}}w=c[g+24>>2]|0;do{if((w|0)==0){x=((W|0)/20|0)+W|0;y=x+1e4|0;z=x+10399|0;x=(z|0)/400|0;A=g+28|0;c[A>>2]=x;if((z|0)<=1677721599){ba=y;break}KIb(u,24,2330368,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;c[A>>2]=4194303;ba=y}else{c[g+28>>2]=(w+399|0)/400|0;ba=W}}while(0);w=c[k>>2]|0;do{if((w|0)==0){if((c[n>>2]|0)!=0){ca=0;o=52;break}u=(ba<<1|0)/(c[g+4>>2]|0)|0;y=(u|0)/8|0;c[g+12>>2]=y;if(!((u+7|0)>>>0<15>>>0)){da=y;ea=0;break}c[g+12>>2]=1;da=1;ea=0}else{h[l>>3]=1394400.0-(+(ba|0)+(+(X|0)*.125/2279.0*45.0+ +(Y|0)*.125/2294.0*30.0)*8.0);ca=w;o=52}}while(0);if((o|0)==52){c[g+12>>2]=1;da=1;ea=ca}do{if((c[n>>2]|0)==0){if((ea|0)==0){c[g+16>>2]=da*5|0;break}else{c[g+16>>2]=2147483647;break}}else{c[g+16>>2]=da*40|0}}while(0);if((c[s>>2]|0)==0){fa=0}else{w=c[t>>2]|0;l=0;while(1){c[(c[(c[w+(l<<2)>>2]|0)+12>>2]|0)+28>>2]=0;y=l+1|0;u=c[s>>2]|0;if(y>>>0<u>>>0){l=y}else{fa=u;break}}}do{if((c[(c[f>>2]|0)+52>>2]|0)==0){if((fa|0)==0){ga=12;break}l=c[t>>2]|0;s=0;w=0;u=12;while(1){if((d[(c[(c[l+(s<<2)>>2]|0)+12>>2]|0)+4|0]|0)>>>0<192>>>0){if((w|0)==0){ha=1;o=68}else{ia=u;ja=w}}else{ha=w;o=68}if((o|0)==68){o=0;ia=u+3|0;ja=ha}y=s+1|0;if(y>>>0<fa>>>0){s=y;w=ja;u=ia}else{ga=ia;break}}}else{ga=18}}while(0);c[g+20>>2]=ga;t=g+56|0;c[t>>2]=0;c[t+4>>2]=-2147483648;N=0;i=e;return N|0}else if((o|0)==72){i=e;return N|0}}}while(0);if((c[q>>2]|0)==0){N=-12;i=e;return N|0}o=b+28|0;b=0;while(1){kJb(c[(c[(c[o>>2]|0)+(b<<2)>>2]|0)+12>>2]|0);g=b+1|0;if(g>>>0<(c[q>>2]|0)>>>0){b=g}else{N=-12;break}}i=e;return N|0}function SN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;e=c[a+12>>2]|0;f=c[b+28>>2]|0;g=c[b+24>>2]|0;h=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;j=c[h+12>>2]|0;if((c[(c[h+8>>2]|0)+8>>2]|0)==0){k=(c[b+36>>2]&1|0)==0}else{k=1}h=e+80|0;l=c[h>>2]|0;m=VIb(l,(l|0)<0|0?-1:0,9e4,0,1e6,0)|0;n=m;m=b+8|0;o=c[m>>2]|0;p=c[m+4>>2]|0;m=b+16|0;b=c[m>>2]|0;q=c[m+4>>2]|0;m=e+56|0;if((c[m>>2]|0)==0&(c[m+4>>2]|0)==(-2147483648|0)){a:do{if((b|0)==0&(q|0)==(-2147483648|0)){r=l;s=9}else{t=n;u=(n|0)<0|0?-1:0;if((q|0)<(u|0)|(q|0)==(u|0)&b>>>0<t>>>0){if((c[a+1204>>2]|0)==0){s=7}}else{s=7}do{if((s|0)==7){if((c[e+52>>2]|0)!=0){break}v=xrc(b,q,t,u)|0;w=G;c[m>>2]=v;c[m+4>>2]=w;c[h>>2]=0;x=0;y=w;z=v;break a}}while(0);u=xrc(0,0,b,q)|0;t=VIb(u,G,1e6,0,9e4,0)|0;u=wrc(l,0,t,G)|0;t=u;c[h>>2]=t;r=t;s=9}}while(0);if((s|0)==9){c[m>>2]=0;c[m+4>>2]=0;x=r;y=0;z=0}r=VIb(x,(x|0)<0|0?-1:0,9e4,0,1e6,0)|0;x=r;r=wrc(x,(x|0)<0|0?-1:0,b,q)|0;m=G;KIb(a,48,2372112,(s=i,i=i+32|0,c[s>>2]=z,c[s+8>>2]=y,c[s+16>>2]=r,c[s+24>>2]=m,s)|0);i=s;A=x}else{A=n}if((b|0)==0&(q|0)==(-2147483648|0)){B=-2147483648;C=0}else{n=wrc(A,(A|0)<0|0?-1:0,b,q)|0;B=G;C=n}if((o|0)==0&(p|0)==(-2147483648|0)){D=-2147483648;E=0}else{n=wrc(A,(A|0)<0|0?-1:0,o,p)|0;D=G;E=n}n=j+20|0;p=j+24|0;if((c[n>>2]|0)==0){c[p>>2]=n}n=pJb(32)|0;o=n;c[c[p>>2]>>2]=o;A=n;c[A>>2]=E;c[A+4>>2]=D;A=n+8|0;c[A>>2]=C;c[A+4>>2]=B;c[n+16>>2]=f;c[n+20>>2]=f;B=j+16|0;if((c[B>>2]|0)==0){c[B>>2]=o}c[p>>2]=n+28;n=j;p=c[n>>2]|0;if((hHb(p,(fHb(p)|0)+f|0)|0)<0){F=-1;i=d;return F|0}do{if(!((c[e+52>>2]|0)==0|k)){p=j+48|0;if((c[e+8>>2]|0)!=0){o=xrc(E,D,c[p>>2]|0,c[p+4>>2]|0)|0;B=G;A=0;if(!((B|0)>(A|0)|(B|0)==(A|0)&o>>>0>35999>>>0)){break}}c[j+40>>2]=fHb(c[n>>2]|0)|0;c[j+44>>2]=1;c[p>>2]=E;c[p+4>>2]=D}}while(0);jHb(c[n>>2]|0,g,f,0)|0;while(1){f=UN(a,0)|0;if((f|0)<1){F=f;break}}i=d;return F|0}function TN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;do{b=UN(a,1)|0;if((b|0)<0){d=b;e=9;break}}while((b|0)!=0);if((e|0)==9){return d|0}b=a+24|0;if((c[b>>2]|0)==0){d=0;return d|0}f=a+28|0;a=0;while(1){g=c[(c[(c[f>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;if((fHb(c[g>>2]|0)|0)!=0){e=7;break}eHb(c[g>>2]|0);g=a+1|0;if(g>>>0<(c[b>>2]|0)>>>0){a=g}else{d=0;e=9;break}}if((e|0)==7){Cd(2471408,2463496,1159,2651904);return 0}else if((e|0)==9){return d|0}return 0}function UN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0.0,oa=0,pa=0.0,qa=0,ra=0,sa=0;d=i;e=a+12|0;f=c[e>>2]|0;g=f+56|0;j=c[g>>2]|0;k=c[g+4>>2]|0;l=c[a+1080>>2]|0;m=VIb(l,(l|0)<0|0?-1:0,9e4,0,1e6,0)|0;l=G;n=a+24|0;o=a+28|0;p=f+4|0;q=(b|0)==0;b=a;r=0;s=-1;t=-2147483648;u=0;v=k;k=j;a:while(1){b:do{if((c[n>>2]|0)==0){w=t;x=s;y=r;z=0}else{j=(u|0)==0;if(q){A=t;B=s;C=r;D=0}else{E=t;H=s;I=r;J=0;while(1){K=c[(c[(c[o>>2]|0)+(J<<2)>>2]|0)+12>>2]|0;L=fHb(c[K>>2]|0)|0;M=c[K+8>>2]|0;N=c[K+12>>2]|0;O=M-N|0;P=O;S=Crc(P<<10|0>>>22,((O|0)<0|0?-1:0)<<10|P>>>22,M,(M|0)<0|0?-1:0)|0;M=S;S=c[K+20>>2]|0;do{if((L|0)==0){T=I;U=H;V=E}else{if((L|0)<=0){W=17;break a}if((O|0)<(c[p>>2]|0)&j){T=I;U=H;V=E;break}if((S|0)!=0){P=S+8|0;X=xrc(c[P>>2]|0,c[P+4>>2]|0,k,v)|0;P=G;if((P|0)>(l|0)|(P|0)==(l|0)&X>>>0>m>>>0){T=I;U=H;V=E;break}}X=c[K+16>>2]|0;if((X|0)==0){Y=M}else{Y=(c[X+16>>2]|0)>(N|0)?M+268435456|0:M}X=(Y|0)>(E|0);T=X?O:I;U=X?J:H;V=X?Y:E}}while(0);O=J+1|0;M=c[n>>2]|0;if(O>>>0<M>>>0){E=V;H=U;I=T;J=O}else{w=V;x=U;y=T;z=M;break b}}}while(1){J=c[(c[o>>2]|0)+(D<<2)>>2]|0;I=c[J+12>>2]|0;H=fHb(c[I>>2]|0)|0;E=c[I+8>>2]|0;M=c[I+12>>2]|0;O=E-M|0;N=O;K=Crc(N<<10|0>>>22,((O|0)<0|0?-1:0)<<10|N>>>22,E,(E|0)<0|0?-1:0)|0;E=K;K=c[I+20>>2]|0;N=c[p>>2]|0;if((N|0)>(H|0)){if((c[(c[J+8>>2]|0)+8>>2]|0)!=3){Z=0;W=61;break a}}do{if((H|0)==0){_=C;$=B;aa=A}else{if((H|0)<=0){W=17;break a}if((O|0)<(N|0)&j){_=C;$=B;aa=A;break}if((K|0)!=0){J=K+8|0;S=xrc(c[J>>2]|0,c[J+4>>2]|0,k,v)|0;J=G;if((J|0)>(l|0)|(J|0)==(l|0)&S>>>0>m>>>0){_=C;$=B;aa=A;break}}S=c[I+16>>2]|0;if((S|0)==0){ca=E}else{ca=(c[S+16>>2]|0)>(M|0)?E+268435456|0:E}S=(ca|0)>(A|0);_=S?O:C;$=S?D:B;aa=S?ca:A}}while(0);O=D+1|0;E=c[n>>2]|0;if(O>>>0<E>>>0){A=aa;B=$;C=_;D=O}else{w=aa;x=$;y=_;z=E;break}}}}while(0);if((x|0)>=0){W=35;break}if((z|0)==0){Z=0;W=61;break}j=c[o>>2]|0;E=2147483647;O=-1;M=0;while(1){I=c[(c[(c[j+(M<<2)>>2]|0)+12>>2]|0)+16>>2]|0;if((I|0)==0){da=E;ea=O}else{K=I+8|0;I=c[K>>2]|0;N=c[K+4>>2]|0;K=(N|0)<(E|0)|(N|0)==(E|0)&I>>>0<O>>>0;da=K?N:E;ea=K?I:O}I=M+1|0;if(I>>>0<z>>>0){E=da;O=ea;M=I}else{break}}if((ea|0)==(-1|0)&(da|0)==2147483647){Z=0;W=61;break}M=wrc(ea,da,1,0)|0;O=G;if((v|0)>=(O|0)&((v|0)>(O|0)|k>>>0>=M>>>0)&(u|0)==0){KIb(b,16,2424384,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;ga=1}else{ga=u}E=(O|0)>(v|0)|(O|0)==(v|0)&M>>>0>k>>>0;j=E?M:k;M=E?O:v;VN(a,j,M);r=y;s=x;t=w;u=ga;v=M;k=j}if((W|0)==17){KIb(0,0,2448616,(fa=i,i=i+24|0,c[fa>>2]=2433200,c[fa+8>>2]=2463496,c[fa+16>>2]=969,fa)|0);i=fa;Hd();return 0}else if((W|0)==35){fa=c[(c[(c[o>>2]|0)+(x<<2)>>2]|0)+12>>2]|0;o=fa;if((fHb(c[o>>2]|0)|0)<=0){Cd(2405856,2463496,1017,2651824);return 0}if((y|0)<(c[p>>2]|0)&(u|0)==0){Cd(2398360,2463496,1019,2651824);return 0}u=fa+20|0;y=c[u>>2]|0;ga=c[y+20>>2]|0;if((ga|0)==(c[y+16>>2]|0)){ia=0;ja=y}else{ia=ga;ja=c[y+28>>2]|0}do{if((ja|0)==0){if((fHb(c[o>>2]|0)|0)==(ia|0)){ka=WN(a,x,0,-2147483648,0,-2147483648,k,v,ia)|0;break}else{Cd(2391384,2463496,1036,2651824);return 0}}else{y=ja|0;ga=ja+8|0;ka=WN(a,x,c[y>>2]|0,c[y+4>>2]|0,c[ga>>2]|0,c[ga+4>>2]|0,k,v,ia)|0}}while(0);c:do{if((c[f+44>>2]|0)==0){la=c[u>>2]|0;ma=f+28|0}else{ia=a+16|0;v=f+28|0;while(1){k=c[u>>2]|0;x=k|0;ja=c[x>>2]|0;o=c[x+4>>2]|0;x=c[e>>2]|0;na=+h[x+64>>3];if(na<=0.0|(ja|0)==0&(o|0)==(-2147483648|0)){oa=0}else{pa=na*((+(ja>>>0)+ +(o|0)*4294967296.0)/9.0e4)*.125;o=(F=+pa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);ja=x+72|0;ga=xrc(~~+pa>>>0,o,c[ja>>2]|0,c[ja+4>>2]|0)|0;ja=ga;oa=(ja|0)<0?0:ja}if((oa|0)<(c[p>>2]|0)){la=k;ma=v;break c}k=x+4|0;ja=c[k>>2]|0;if((ja|0)>0){ga=0;while(1){bD(c[ia>>2]|0,0);o=ga+1|0;y=c[k>>2]|0;if((o|0)<(y|0)){ga=o}else{qa=y;break}}}else{qa=ja}ga=x+72|0;k=wrc(c[ga>>2]|0,c[ga+4>>2]|0,qa,(qa|0)<0|0?-1:0)|0;c[ga>>2]=k;c[ga+4>>2]=G;eD(c[ia>>2]|0);ga=x+8|0;c[ga>>2]=(c[ga>>2]|0)+1;ga=c[p>>2]|0;k=Erc(ga,(ga|0)<0|0?-1:0,9e4,0)|0;ga=G;y=c[v>>2]|0;o=Erc(y,(y|0)<0|0?-1:0,50,0)|0;y=Crc(k,ga,o,G)|0;o=wrc(c[g>>2]|0,c[g+4>>2]|0,y,G)|0;c[g>>2]=o;c[g+4>>2]=G}}}while(0);qa=fa+12|0;c[qa>>2]=(c[qa>>2]|0)+ka;qa=c[p>>2]|0;p=Erc(qa,(qa|0)<0|0?-1:0,9e4,0)|0;qa=G;fa=c[ma>>2]|0;ma=Erc(fa,(fa|0)<0|0?-1:0,50,0)|0;fa=Crc(p,qa,ma,G)|0;ma=wrc(c[g>>2]|0,c[g+4>>2]|0,fa,G)|0;fa=G;c[g>>2]=ma;c[g+4>>2]=fa;d:do{if((la|0)==0){ra=ka;sa=0}else{g=la;qa=ka;while(1){p=c[g+20>>2]|0;if((p|0)>(qa|0)){ra=qa;sa=g;break d}oa=qa-p|0;p=c[g+28>>2]|0;c[u>>2]=p;if((p|0)==0){ra=oa;sa=0;break}else{g=p;qa=oa}}}}while(0);if((ra|0)!=0){u=sa+20|0;c[u>>2]=(c[u>>2]|0)-ra}VN(a,ma,fa);Z=1;i=d;return Z|0}else if((W|0)==61){i=d;return Z|0}return 0}function VN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+8|0;f=e|0;g=a+24|0;if((c[g>>2]|0)==0){i=e;return}h=a+28|0;j=f;k=a;a=0;do{l=c[(c[(c[h>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;m=l+16|0;n=c[m>>2]|0;c[f>>2]=n;a:do{if((n|0)!=0){o=l+12|0;p=l+20|0;q=n;while(1){r=q+8|0;s=c[r+4>>2]|0;if(!((s|0)<(d|0)|(s|0)==(d|0)&(c[r>>2]|0)>>>0<b>>>0)){break a}t=c[o>>2]|0;u=c[q+16>>2]|0;if((t|0)<(u|0)){break}if((c[m>>2]|0)==(c[p>>2]|0)){break}c[o>>2]=t-u;c[m>>2]=c[q+28>>2];mJb(j);q=c[m>>2]|0;c[f>>2]=q;if((q|0)==0){break a}}KIb(k,16,2377648,(q=i,i=i+24|0,c[q>>2]=a,c[q+8>>2]=t,c[q+16>>2]=u,q)|0);i=q}}while(0);a=a+1|0;}while(a>>>0<(c[g>>2]|0)>>>0);i=e;return}function WN(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;n=i;i=i+128|0;o=n|0;p=b+12|0;q=c[p>>2]|0;r=c[(c[(c[b+28>>2]|0)+(e<<2)>>2]|0)+12>>2]|0;e=a[r+4|0]|0;s=e&255;t=o|0;u=q+8|0;v=q+56|0;do{if(((c[u>>2]|0)%(c[q+12>>2]|0)|0|0)==0){w=4}else{if(!((c[v>>2]|0)==(k|0)&(c[v+4>>2]|0)==(l|0))){w=4;break}x=0;y=t;z=q+44|0}}while(0);a:do{if((w|0)==4){A=XN(q,t,k,l)|0;B=o+A|0;c[v>>2]=k;c[v+4>>2]=l;C=q+44|0;if((c[C>>2]|0)!=0){if((c[r+28>>2]|0)!=0){x=0;y=B;z=C;break}x=0;y=o+((YN(b,B,s)|0)+A)|0;z=C;break}if((c[q+52>>2]|0)==0){if(((c[u>>2]|0)%(c[q+16>>2]|0)|0|0)!=0){x=0;y=B;z=C;break}x=0;y=o+((YN(b,B,0)|0)+A)|0;z=C;break}D=r+44|0;if((c[D>>2]|0)==0){if((c[u>>2]|0)!=0){x=0;y=B;z=C;break}}E=q+4|0;F=(c[E>>2]|0)-A|0;do{if((f|0)==0&(g|0)==(-2147483648|0)){H=F-10|0}else{if((h|0)==(f|0)&(j|0)==(g|0)){H=F-15|0;break}else{H=F-20|0;break}}}while(0);F=c[r+40>>2]|0;do{if((F|0)!=0){if((c[u>>2]|0)==0){break}x=(F|0)<(H|0)?H-F|0:0;y=B;z=C;break a}}while(0);F=(YN(b,B,0)|0)+A|0;I=b+16|0;dD(c[I>>2]|0,t,F);lD(c[I>>2]|0,447);tD(c[I>>2]|0,980);bD(c[I>>2]|0,0);F=0;J=c[I>>2]|0;do{bD(J,0);F=F+1|0;J=c[I>>2]|0}while((F|0)<979);lD(J,447);tD(c[I>>2]|0,1018);bD(c[I>>2]|0,1);F=0;do{bD(c[I>>2]|0,0);F=F+1|0;}while((F|0)<1017);mrc(t|0,0,128)|0;c[u>>2]=(c[u>>2]|0)+1;c[D>>2]=0;F=c[E>>2]|0;I=Erc(F,(F|0)<0|0?-1:0,9e4,0)|0;F=G;J=c[q+28>>2]|0;A=Erc(J,(J|0)<0|0?-1:0,50,0)|0;J=Crc(I,F,A,G)|0;A=wrc(J,G,k,l)|0;J=G;F=XN(c[p>>2]|0,t,A,J)|0;c[v>>2]=A;c[v+4>>2]=J;x=0;y=o+F|0;z=C}}while(0);v=y-o|0;o=b+16|0;dD(c[o>>2]|0,t,v);t=(c[q+4>>2]|0)-v|0;do{if((c[z>>2]|0)==0){K=0;w=27}else{v=(s&224|0)==192?20:0;if((c[r+28>>2]|0)!=0){K=v;w=27;break}L=v;M=c[q+48>>2]|0;w=29}}while(0);do{if((w|0)==27){z=c[q+48>>2]|0;if((z|0)==0){N=0;O=x;P=K;break}if((c[u>>2]|0)==0){L=K;M=z;w=29}else{N=0;O=x;P=K}}}while(0);if((w|0)==29){N=(M|0)!=0|0;O=t-L|0;P=L}L=t-P-O|0;do{if((L|0)>0){t=L-6|0;M=q+40|0;K=(c[M>>2]|0)==0;if(K){Q=0}else{Q=(c[r+28>>2]|0)==0?7:4}x=(f|0)!=0|(g|0)!=(-2147483648|0);do{if(x){if((h|0)==(f|0)&(j|0)==(g|0)){R=Q+5|0;break}else{R=Q+10|0;break}}else{R=(K&1)+Q|0}}while(0);K=t-R|0;do{if((e&255)>>>0<192>>>0){if(!((e&255)>>>0>63>>>0)){S=445;T=K-1|0;break}S=445;T=K+((e&255)>>>0>159>>>0?-7:-4)|0}else{S=s|256;T=K}}while(0);K=r;C=T-(fHb(c[K>>2]|0)|0)|0;do{if((T|0)>(m|0)){U=g;V=f;W=O;X=t;Y=R;Z=C;_=j;$=h;aa=T}else{if(!x){U=-2147483648;V=0;W=O;X=t;Y=R;Z=C;_=j;$=h;aa=T;break}E=((c[M>>2]|0)!=0?5:4)+((h|0)==(f|0)&(j|0)==(g|0)?0:5)|0;D=R-E|0;do{if((c[q+52>>2]|0)==0){w=47}else{if((c[r+44>>2]|0)==0){w=47;break}ba=E+O|0;ca=t-E|0;da=T}}while(0);if((w|0)==47){ba=O;ca=t;da=E+T|0}z=E+C|0;if((da|0)<=(m|0)){U=-2147483648;V=0;W=ba;X=ca;Y=D;Z=z;_=-2147483648;$=0;aa=da;break}U=-2147483648;V=0;W=ba;X=ca;Y=D;Z=z-m+da|0;_=-2147483648;$=0;aa=da}}while(0);if((W-1|0)>>>0<7>>>0){ea=0;fa=W+X|0;ga=W+((Z|0)<0?0:Z)|0;ha=W+aa|0}else{ea=W;fa=X;ga=Z;ha=aa}C=(ga|0)<0?0:ga;t=(S|0)==445;x=(e&255)>>>0>159>>>0;do{if(t&x){if((ha|0)>=(fHb(c[K>>2]|0)|0)){ia=C;break}ia=((ha|0)%(c[r+36>>2]|0)|0)+C|0}else{ia=C}}while(0);if((ia|0)>16){ja=ia+ea|0;ka=fa-ia|0;la=0;ma=ha-ia|0}else{ja=ea;ka=fa;la=ia;ma=ha}C=ma-la|0;if((C|0)>0){z=C;v=0;b=r+20|0;while(1){y=c[b>>2]|0;l=c[y+20>>2]|0;k=((c[y+16>>2]|0)==(l|0))+v|0;H=z-l|0;if((H|0)>0){z=H;v=k;b=y+28|0}else{na=k;break}}}else{na=0}lD(c[o>>2]|0,S);tD(c[o>>2]|0,ka);do{if((c[M>>2]|0)==0){if((la|0)>0){b=0;do{bD(c[o>>2]|0,255);b=b+1|0;}while((b|0)<(la|0));if((c[M>>2]|0)!=0){w=64;break}}if((V|0)==0&(U|0)==(-2147483648|0)){bD(c[o>>2]|0,15);break}b=c[o>>2]|0;D=((V>>>30|U<<2)<<1|0>>>31)&14;if(($|0)==(V|0)&(_|0)==(U|0)){bD(b,D|33);tD(b,(($>>>15|_<<17)<<1|0>>>31|1)&65535);tD(b,($<<1|0>>>31|1)&65535);break}else{bD(b,D|49);tD(b,((V>>>15|U<<17)<<1|0>>>31|1)&65535);tD(b,(V<<1|0>>>31|1)&65535);b=c[o>>2]|0;bD(b,(($>>>30|_<<2)<<1|0>>>31)&14|17);tD(b,(($>>>15|_<<17)<<1|0>>>31|1)&65535);tD(b,($<<1|0>>>31|1)&65535);break}}else{w=64}}while(0);do{if((w|0)==64){bD(c[o>>2]|0,128);if((V|0)==0&(U|0)==(-2147483648|0)){oa=0}else{oa=($|0)==(V|0)&(_|0)==(U|0)?128:192}b=(c[r+28>>2]|0)==0;bD(c[o>>2]|0,b&1|oa);bD(c[o>>2]|0,Y-3+la|0);if((oa&128|0)!=0){D=c[o>>2]|0;bD(D,((V>>>30|U<<2)<<1|0>>>31)&14|(oa>>>2|32)|1);tD(D,((V>>>15|U<<17)<<1|0>>>31|1)&65535);tD(D,(V<<1|0>>>31|1)&65535)}if((oa&64|0)!=0){D=c[o>>2]|0;bD(D,(($>>>30|_<<2)<<1|0>>>31)&14|17);tD(D,(($>>>15|_<<17)<<1|0>>>31|1)&65535);tD(D,($<<1|0>>>31|1)&65535)}if(!b){break}bD(c[o>>2]|0,16);b=c[o>>2]|0;D=c[r+8>>2]|0;if((s&224|0)==192){tD(b,(D|0)/128|0|16384);break}else{tD(b,(D|0)/1024|0|24576);break}}}while(0);do{if((c[M>>2]|0)!=0){bD(c[o>>2]|0,255);if((la|0)>0){pa=0}else{break}do{bD(c[o>>2]|0,255);pa=pa+1|0;}while((pa|0)<(la|0))}}while(0);do{if(t){bD(c[o>>2]|0,s);if(x){bD(c[o>>2]|0,7);tD(c[o>>2]|0,4);bD(c[o>>2]|0,d[r+32|0]|0);bD(c[o>>2]|0,d[r+33|0]|0);bD(c[o>>2]|0,d[r+34|0]|0);break}if(!((e&255)>>>0>63>>>0)){break}bD(c[o>>2]|0,na);tD(c[o>>2]|0,m+1|0)}}while(0);if((C|0)>(fHb(c[K>>2]|0)|0)){Cd(2384720,2463496,861,2652640);return 0}else{iHb(c[K>>2]|0,c[o>>2]|0,C,1946)|0;x=r+40|0;c[x>>2]=(c[x>>2]|0)-C;qa=ja;ra=la;sa=ma;break}}else{qa=O;ra=0;sa=0}}while(0);do{if((qa|0)>0){O=c[o>>2]|0;ma=c[p>>2]|0;lD(O,446);la=qa-6|0;tD(O,la);if((c[ma+40>>2]|0)==0){bD(O,15);ta=qa-7|0}else{ta=la}if((ta|0)>0){ua=0}else{break}do{bD(O,255);ua=ua+1|0;}while((ua|0)<(ta|0))}}while(0);ta=c[o>>2]|0;if((P|0)>0){ua=0;qa=ta;while(1){bD(qa,0);p=ua+1|0;O=c[o>>2]|0;if((p|0)<(P|0)){ua=p;qa=O}else{va=O;break}}}else{va=ta}eD(va);c[u>>2]=(c[u>>2]|0)+1;if((N|0)!=0){wa=sa-ra|0;i=n;return wa|0}N=r+28|0;c[N>>2]=(c[N>>2]|0)+1;wa=sa-ra|0;i=n;return wa|0}function XN(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;g=i;h=d;y=-1174339584;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=b+40|0;j=(c[h>>2]|0)==0;k=((j?56592:14152)|(e>>>30|f<<2)&7)<<1|1;l=k;m=(e>>>15|f<<17)&32767;if(1){n=j?9:11;o=k<<15|m;p=d+4|0}else{n=0;o=m;p=0}l=o;if((n|0)>1){q=n-1|0;r=o<<1|1;s=p}else{m=p;y=je(1>>>((1-n|0)>>>0)|o<<n|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;q=n+31|0;r=1;s=p+4|0}l=r;p=e&32767;if((q|0)>15){t=q-15|0;u=r<<15|p;v=s}else{e=s;y=je(p>>>((15-q|0)>>>0)|r<<q|0)|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;t=q+17|0;u=p;v=s+4|0}l=u;if((t|0)>1){w=t-1|0;x=u<<1|1;z=v}else{s=v;y=je(1>>>((1-t|0)>>>0)|u<<t|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;w=t+31|0;x=1;z=v+4|0}l=x;if((c[h>>2]|0)==0){A=w;B=z;C=x}else{if((w|0)>9){D=w-9|0;E=x<<9;F=z}else{v=z;y=je(x<<w|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;D=w+23|0;E=0;F=z+4|0}l=E;A=D;B=F;C=E}if((A|0)>1){G=A-1|0;H=C<<1|1;I=B}else{E=B;y=je(1>>>((1-A|0)>>>0)|C<<A|0)|0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;G=A+31|0;H=1;I=B+4|0}l=H;B=c[b+28>>2]|0;if((G|0)>22){J=G-22|0;K=B|H<<22;L=I}else{b=I;y=je(B>>>((22-G|0)>>>0)|H<<G|0)|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;J=G+10|0;K=B;L=I+4|0}l=K;if((J|0)>1){M=J-1|0;N=K<<1|1;O=L}else{I=L;y=je(1>>>((1-J|0)>>>0)|K<<J|0)|0;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;M=J+31|0;N=1;O=L+4|0}l=N;if((c[h>>2]|0)==0){P=M;Q=O;R=N}else{if((M|0)>1){S=M-1|0;T=N<<1|1;U=O}else{h=O;y=je(1>>>((1-M|0)>>>0)|N<<M|0)|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;S=M+31|0;T=1;U=O+4|0}l=T;if((S|0)>5){V=S-5|0;W=T<<5|31;X=U}else{O=U;y=je(31>>>((5-S|0)>>>0)|T<<S|0)|0;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;V=S+27|0;W=31;X=U+4|0}l=W;if((V|0)>3){Y=V-3|0;Z=W<<3;_=X}else{U=X;y=je(W<<V|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;Y=V+29|0;Z=0;_=X+4|0}l=Z;P=Y;Q=_;R=Z}if((P|0)>=32){$=Q;aa=$;ba=d;ca=aa-ba|0;i=g;return ca|0}Z=R<<P;l=Z;R=((31-P|0)>>>3)+1|0;_=Z>>>24&255;Z=P;P=Q;while(1){a[P]=_;Y=l;l=Y<<8;X=Z+8|0;if((X|0)<32){_=Y>>>16&255;Z=X;P=P+1|0}else{break}}$=Q+R|0;aa=$;ba=d;ca=aa-ba|0;i=g;return ca|0}function YN(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;f=i;g=c[b+12>>2]|0;h=d;y=-1157562368;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=d+4|0;j=58064897;k=c[g+28>>2]|0;l=h;y=je(k>>>7|32768|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=d+8|0;m=k<<1|1;j=m;k=g+44|0;if((c[k>>2]|0)!=0&(e|0)==224){n=m<<6}else{n=c[g+32>>2]|m<<6}j=n;m=n<<2|(c[k>>2]|0)!=0;j=m;do{if((c[k>>2]|0)==0){if((c[g+52>>2]|0)!=0){o=6;break}j=m<<1;p=m<<3}else{o=6}}while(0);if((o|0)==6){n=m<<1|1;j=n;p=n<<2|2}n=p|1;j=n;do{if((c[k>>2]|0)==0){o=11}else{if((e&224|0)!=192){o=11;break}q=n<<5}}while(0);if((o|0)==11){q=n<<5|c[g+36>>2]}j=q;n=g+52|0;if((c[n>>2]|0)==0){g=l;y=je(q<<8|255|0)|0;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;r=255}else{j=q<<1;g=l;y=je(q<<8|127|0)|0;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;r=127}g=d+12|0;j=r;q=b+24|0;l=c[q>>2]|0;p=(l|0)==0;if((c[n>>2]|0)!=0){if(p){s=0;t=0;u=0}else{n=c[b+28>>2]|0;m=0;v=0;w=0;x=0;while(1){z=c[(c[n+(x<<2)>>2]|0)+12>>2]|0;A=a[z+4|0]|0;do{if(A<<24>>24==-67){B=c[z+8>>2]|0;C=(B|0)>(w|0)?B:w;D=v;E=m}else{if((A+64&255)>>>0<8>>>0){B=c[z+8>>2]|0;if((B|0)>(v|0)){C=w;D=B;E=m;break}}if(!(A<<24>>24==-32)){C=w;D=v;E=m;break}B=c[z+8>>2]|0;C=w;D=v;E=(B|0)>(m|0)?B:m}}while(0);z=x+1|0;if(z>>>0<l>>>0){m=E;v=D;w=C;x=z}else{s=E;t=D;u=C;break}}}C=g;y=je(((s|0)/1024|0)<<8|-1176502088|0)|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=(u|0)/128|0;u=d+16|0;y=je(C>>>8|((t|0)==0?-1071596096:((t|0)/128|0)<<16|-1073693248)|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=d+20|0;y=je(C<<24|12574722|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;j=2;F=d+24|0;G=F;H=d;I=G-H|0;J=I+65530|0;K=J&65535;L=he(K|0)|0;M=h;y=L;a[M]=y;y=y>>8;a[M+1|0]=y;i=f;return I|0}if(p){F=g;G=F;H=d;I=G-H|0;J=I+65530|0;K=J&65535;L=he(K|0)|0;M=h;y=L;a[M]=y;y=y>>8;a[M+1|0]=y;i=f;return I|0}p=b+28|0;b=(e|0)==0;u=g;g=32;C=0;t=0;s=r;while(1){r=c[(c[(c[p>>2]|0)+(t<<2)>>2]|0)+12>>2]|0;D=a[r+4|0]|0;if((c[k>>2]|0)==0){o=30}else{if((D&255|0)==(e|0)|b){o=30}else{N=C;O=g;P=u;Q=s}}do{if((o|0)==30){o=0;E=D&255;if((D&255)>>>0<192>>>0){if((C|0)==0){R=1;S=189}else{N=C;O=g;P=u;Q=s;break}}else{R=C;S=E}if((g|0)>8){T=g-8|0;U=s<<8|S;V=u}else{E=u;y=je(s<<g|S>>>((8-g|0)>>>0)|0)|0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;T=g+24|0;U=S;V=u+4|0}j=U;if((T|0)>2){W=T-2|0;X=U<<2|3;Y=V}else{E=V;y=je(3>>>((2-T|0)>>>0)|U<<T|0)|0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;W=T+30|0;X=3;Y=V+4|0}j=X;E=(W|0)>1;if(S>>>0<224>>>0){if(E){Z=W-1|0;_=X<<1;$=Y}else{x=Y;y=je(X<<W|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;Z=W+31|0;_=0;$=Y+4|0}j=_;x=(c[r+8>>2]|0)/128|0;if((Z|0)>13){aa=Z-13|0;ba=x|_<<13;ca=$}else{w=$;y=je(x>>>((13-Z|0)>>>0)|_<<Z|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;aa=Z+19|0;ba=x;ca=$+4|0}j=ba;N=R;O=aa;P=ca;Q=ba;break}else{if(E){da=W-1|0;ea=X<<1|1;fa=Y}else{E=Y;y=je(1>>>((1-W|0)>>>0)|X<<W|0)|0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;da=W+31|0;ea=1;fa=Y+4|0}j=ea;E=(c[r+8>>2]|0)/1024|0;if((da|0)>13){ga=da-13|0;ha=E|ea<<13;ia=fa}else{x=fa;y=je(E>>>((13-da|0)>>>0)|ea<<da|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;ga=da+19|0;ha=E;ia=fa+4|0}j=ha;N=R;O=ga;P=ia;Q=ha;break}}}while(0);r=t+1|0;if(r>>>0<(c[q>>2]|0)>>>0){u=P;g=O;C=N;t=r;s=Q}else{break}}if((O|0)>=32){F=P;G=F;H=d;I=G-H|0;J=I+65530|0;K=J&65535;L=he(K|0)|0;M=h;y=L;a[M]=y;y=y>>8;a[M+1|0]=y;i=f;return I|0}s=Q<<O;j=s;Q=((31-O|0)>>>3)+1|0;t=s>>>24&255;s=O;O=P;while(1){a[O]=t;N=j;j=N<<8;C=s+8|0;if((C|0)<32){t=N>>>16&255;s=C;O=O+1|0}else{break}}F=P+Q|0;G=F;H=d;I=G-H|0;J=I+65530|0;K=J&65535;L=he(K|0)|0;M=h;y=L;a[M]=y;y=y>>8;a[M+1|0]=y;i=f;return I|0}function ZN(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;n=i;i=i+512|0;o=n|0;p=n+256|0;q=n+384|0;r=c[g>>2]|0;if(!(r>>>0<h>>>0)){s=-1;i=n;return s|0}t=r+1|0;u=d[r]|0;c[g>>2]=t;if(!(t>>>0<h>>>0)){s=-1;i=n;return s|0}v=a[t]|0;t=v&255;c[g>>2]=r+2;w=r+(t+2)|0;if(w>>>0>h>>>0){s=-1;i=n;return s|0}h=e+8|0;r=c[h>>2]|0;a:do{if((c[r+48>>2]|0)==0&(f|0)==6){if((a5a(r)|0)==0){x=2659480}else{KIb(0,48,2413408,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break}while(1){A=c[x>>2]|0;if((A|0)==0){break a}if((A|0)==(u|0)){break}else{x=x+12|0}}A=c[h>>2]|0;c[A+8>>2]=c[x+4>>2];c[A+48>>2]=c[x+8>>2];c[e+440>>2]=0}}while(0);b:do{switch(u|0){case 82:{x=c[g>>2]|0;if(x>>>0<w>>>0){r=d[x]|0;c[g>>2]=x+1;B=r+1|0}else{B=0}c[e+420>>2]=B;break};case 10:{if((v&255)>>>0<4>>>0){break b}r=e+72|0;x=(t+1|0)>>>0>8>>>0;f=0;A=4;C=c[g>>2]|0;while(1){if(C>>>0<w>>>0){D=C+1|0;E=a[C]|0;c[g>>2]=D;F=E;G=D}else{F=-1;G=C}a[o+f|0]=F;if(G>>>0<w>>>0){D=G+1|0;E=a[G]|0;c[g>>2]=D;H=E;I=D}else{H=-1;I=G}a[o+(f|1)|0]=H;if(I>>>0<w>>>0){D=I+1|0;E=a[I]|0;c[g>>2]=D;J=E;K=D}else{J=-1;K=I}a[o+(f|2)|0]=J;a[o+(f|3)|0]=44;do{if(K>>>0<w>>>0){D=K+1|0;E=d[K]|0;c[g>>2]=D;if((E|0)==1){c[r>>2]=c[r>>2]|512;L=D;break}else if((E|0)==2){c[r>>2]=c[r>>2]|128;L=D;break}else if((E|0)==3){c[r>>2]=c[r>>2]|256;L=D;break}else{L=D;break}}else{L=K}}while(0);D=A+4|0;if((D|0)>(t|0)){break}else{f=A;A=D;C=L}}C=x?t&252:4;if((C|0)==0){break b}a[o+(C-1)|0]=0;MGb(e+88|0,2142216,o|0,0)|0;break};case 38:{C=c[g>>2]|0;do{if((C+1|0)>>>0<w>>>0){A=C;f=(d[A]|d[A+1|0]<<8)<<16>>16;A=C+2|0;c[g>>2]=A;if(!(f<<16>>16==-1)){M=A;break}A=C+6|0;c[g>>2]=A;M=A}else{M=C}}while(0);if(!(M>>>0<w>>>0)){break b}C=M+1|0;x=a[M]|0;c[g>>2]=C;if(!(x<<24>>24==-1)){break b}c[g>>2]=M+5;x=C;C=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=c[h>>2]|0;c[x+52>>2]=C;if((c[x+48>>2]|0)!=0){break b}if((a5a(x)|0)==0){N=2657096}else{KIb(0,48,2413408,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break b}while(1){x=c[N>>2]|0;if((x|0)==0){break b}if((x|0)==(C|0)){break}else{N=N+12|0}}C=c[h>>2]|0;c[C+8>>2]=c[N+4>>2];c[C+48>>2]=c[N+8>>2];c[e+440>>2]=0;break};case 89:{C=t>>>3;if(!(v<<24>>24==0|(t&7|0)==0)){s=-1094995529;i=n;return s|0}if((v&255)>>>0>15>>>0){QIb(b,2488016,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}if(!((v&255)>>>0>7>>>0)){break b}x=c[h>>2]|0;A=C*5|0;do{if((c[x+96>>2]|0)==0){if((PX(x,A)|0)==0){O=c[h>>2]|0;break}else{s=-12;i=n;return s|0}}else{O=x}}while(0);if((c[O+100>>2]|0)<(A|0)){s=-1094995529;i=n;return s|0}if((C|0)==0){P=-1}else{x=e+72|0;f=(v&255)>>>0>15>>>0;r=0;D=c[O+96>>2]|0;E=c[g>>2]|0;while(1){if(E>>>0<w>>>0){Q=E+1|0;R=a[E]|0;c[g>>2]=Q;S=R;T=Q}else{S=-1;T=E}Q=r<<2;a[o+Q|0]=S;if(T>>>0<w>>>0){R=T+1|0;U=a[T]|0;c[g>>2]=R;V=U;W=R}else{V=-1;W=T}a[o+(Q|1)|0]=V;if(W>>>0<w>>>0){R=W+1|0;U=a[W]|0;c[g>>2]=R;X=U;Y=R}else{X=-1;Y=W}a[o+(Q|2)|0]=X;a[o+(Q|3)|0]=44;if(((d[Y]|0)-32|0)>>>0<6>>>0){c[x>>2]=c[x>>2]|128}if(Y>>>0<w>>>0){Q=a[Y]|0;c[g>>2]=Y+1;Z=Q}else{Z=-1}a[D+4|0]=Z;Q=c[g>>2]|0;R=D;y=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;R=(c[g>>2]|0)+4|0;c[g>>2]=R;Q=r+1|0;if((Q|0)<(C|0)){r=Q;D=D+5|0;E=R}else{break}}P=f?(C<<2)-1|0:3}a[o+P|0]=0;MGb(e+88|0,2142216,o|0,0)|0;break};case 5:{E=c[g>>2]|0;c[g>>2]=E+4;D=E;E=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=c[h>>2]|0;c[D+52>>2]=E;if((c[D+48>>2]|0)!=0){break b}if((a5a(D)|0)==0){_=2655984}else{KIb(0,48,2413408,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break b}while(1){D=c[_>>2]|0;if((D|0)==0){break b}if((D|0)==(E|0)){break}else{_=_+12|0}}E=c[h>>2]|0;c[E+8>>2]=c[_+4>>2];c[E+48>>2]=c[_+8>>2];c[e+440>>2]=0;break};case 30:{E=c[g>>2]|0;if((E+1|0)>>>0<w>>>0){C=E;f=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;c[g>>2]=E+2;$=f}else{$=-1}do{if((m|0)!=0){f=c[m+8288+(l<<2)>>2]|0;if((f|0)==0){break}c[f+4>>2]=$}}while(0);if((k|0)<=0){break b}f=e+236|0;E=m;C=m+8288+(l<<2)|0;if(l>>>0>8191>>>0){D=0;while(1){r=c[j+(D*68|0)+4>>2]|0;do{if((r|0)!=0){if((c[j+(D*68|0)>>2]|0)!=($|0)){break}$C(p,c[j+(D*68|0)+8>>2]|0,r,0,0,0,0,0)|0;JJ(b,e,p)|0;x=c[h>>2]|0;if((c[x+48>>2]|0)!=86018){break}if((c[x+100>>2]|0)<=0){break}c[f>>2]=0}}while(0);D=D+1|0;if((D|0)>=(k|0)){break b}}}else{aa=0}do{D=c[j+(aa*68|0)+4>>2]|0;do{if((D|0)!=0){if((c[j+(aa*68|0)>>2]|0)!=($|0)){break}$C(p,c[j+(aa*68|0)+8>>2]|0,D,0,0,0,0,0)|0;JJ(b,e,p)|0;r=c[h>>2]|0;x=c[r+48>>2]|0;if((x|0)==86018){if((c[r+100>>2]|0)<=0){break}c[f>>2]=0;if((x|0)!=131073){break}}else if((x|0)!=131073){break}if((c[C>>2]|0)!=0){break}x=pJb(40)|0;if((x|0)==0){break}c[C>>2]=x;c[x+12>>2]=1;c[x>>2]=l;c[x+4>>2]=-1;c[x+8>>2]=-1;c[x+32>>2]=1212;c[x+36>>2]=E;r=hJb(4096)|0;c[x+24>>2]=r;A=x+28|0;c[A>>2]=c[A>>2]|1;if((r|0)!=0){break}kJb(x)}}while(0);aa=aa+1|0;}while((aa|0)<(k|0));break};case 86:{E=((v&255)/5|0)&255;if(!(v<<24>>24==0|((v&255)%5|0)<<24>>24==0)){s=-1094995529;i=n;return s|0}if(!((v&255)>>>0>4>>>0)){break b}C=c[h>>2]|0;f=E<<1;do{if((c[C+96>>2]|0)==0){if((PX(C,f)|0)==0){ba=c[h>>2]|0;break}else{s=-12;i=n;return s|0}}else{ba=C}}while(0);if((c[ba+100>>2]|0)<(f|0)){s=-1094995529;i=n;return s|0}C=(v&255)>>>0>9>>>0;D=0;x=c[ba+96>>2]|0;r=c[g>>2]|0;while(1){if(r>>>0<w>>>0){A=r+1|0;R=a[r]|0;c[g>>2]=A;ca=R;da=A}else{ca=-1;da=r}A=D<<2;a[o+A|0]=ca;if(da>>>0<w>>>0){R=da+1|0;Q=a[da]|0;c[g>>2]=R;ea=Q;fa=R}else{ea=-1;fa=da}a[o+(A|1)|0]=ea;if(fa>>>0<w>>>0){R=fa+1|0;Q=a[fa]|0;c[g>>2]=R;ga=Q;ha=R}else{ga=-1;ha=fa}a[o+(A|2)|0]=ga;a[o+(A|3)|0]=44;A=ha;R=x;y=(d[A]|d[A+1|0]<<8)<<16>>16;a[R]=y;y=y>>8;a[R+1|0]=y;R=(c[g>>2]|0)+2|0;c[g>>2]=R;A=D+1|0;if((A|0)<(E|0)){D=A;x=x+2|0;r=R}else{break}}a[o+(C?(E<<2)-1|0:3)|0]=0;MGb(e+88|0,2142216,o|0,0)|0;break};case 31:{r=c[g>>2]|0;if((r+1|0)>>>0<w>>>0){c[g>>2]=r+2}if((k|0)<=0){break b}if((c[(c[h>>2]|0)+48>>2]|0)!=86066){if((c[e+440>>2]|0)<=0){break b}}r=c[j+4>>2]|0;if((r|0)==0){break b}if((c[j>>2]|0)!=(l|0)){break b}$C(q,c[j+8>>2]|0,r,0,0,0,0,0)|0;JJ(b,e,q)|0;r=c[h>>2]|0;if((c[r+48>>2]|0)!=86018){break b}if((c[r+100>>2]|0)<=0){break b}c[e+236>>2]=0;c[e+440>>2]=0;c[r+8>>2]=1;break};default:{}}}while(0);c[g>>2]=w;s=0;i=n;return s|0}function _N(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+1376|0;g=f|0;h=f+160|0;j=f+288|0;k=c[b+36>>2]|0;mrc(j|0,0,1088)|0;b=c[k+4>>2]|0;if((e-4|0)<=7){i=f;return}if((a[d]|0)!=5){i=f;return}l=e-12|0;e=j|0;do{if(l>>>0>1073741824>>>0){m=0}else{n=g+8|0;if(($C(n,d+8|0,l,0,0,0,0,0)|0)<0){m=0;break}c[g>>2]=b;c[g+152>>2]=0;o=g+144|0;c[o>>2]=0;c[g+136>>2]=e;c[g+140>>2]=0;c[g+148>>2]=16;p=fD(n,0,0,1)|0;a:do{if((l|0)>0){q=G;r=p;s=l;while(1){if((qO(g,r,q,s,0)|0)<0){break a}t=fD(n,0,0,1)|0;u=G;v=wrc(s,0,r,q)|0;w=xrc(v,G,t,u)|0;v=w;if((v|0)>0){q=u;r=t;s=v}else{break}}}}while(0);m=c[o>>2]|0}}while(0);g=k+8288|0;k=(m|0)>0;l=b;e=0;do{d=g+(e<<2)|0;n=c[d>>2]|0;b:do{if(!((n|0)==0|k^1)){p=0;s=n;while(1){c:do{if((c[s+4>>2]|0)==(c[j+(p*68|0)>>2]|0)){do{if((s|0)!=0){if((c[s+12>>2]|0)!=0){break}r=c[s+20>>2]|0;q=c[r+20>>2]|0;if((q|0)==0){break c}nrc(r+348|0,j+(p*68|0)+12|0,56)|0;$C(h,c[j+(p*68|0)+8>>2]|0,c[j+(p*68|0)+4>>2]|0,0,0,0,0,0)|0;JJ(b,q,h)|0;r=c[q+8>>2]|0;v=c[r+48>>2]|0;do{if((v|0)==0){break c}else if((v|0)==86018){if((c[r+100>>2]|0)<=0){x=25;break}c[q+236>>2]=0;if((v|0)==0){break c}else if((v|0)==28){x=20}else{x=22}}else if((v|0)==28){x=20}else{x=22}}while(0);do{if((x|0)==20){x=0;if((c[r+100>>2]|0)<=0){x=23;break}c[q+236>>2]=0;if((v|0)==0){break c}else{x=22}}}while(0);do{if((x|0)==22){x=0;if(v>>>0<65536>>>0){x=23;break}if(v>>>0<94208>>>0){x=25;break}if(!(v>>>0<98304>>>0)){break c}c[r+8>>2]=3;break c}}while(0);if((x|0)==23){x=0;c[r+8>>2]=0;break c}else if((x|0)==25){x=0;c[r+8>>2]=1;break c}}}while(0);KIb(l,16,2330344,(v=i,i=i+8|0,c[v>>2]=e,v)|0);i=v}}while(0);v=p+1|0;if((v|0)>=(m|0)){break b}p=v;s=c[d>>2]|0}}}while(0);e=e+1|0;}while((e|0)<8192);if(k){y=0}else{i=f;return}do{kJb(c[j+(y*68|0)+8>>2]|0);y=y+1|0;}while((y|0)<(m|0));i=f;return}function $N(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=f-4|0;f=e+g|0;if((g|0)<=0){return}if(!((g|0)>7&(a[e]|0)==66&(g|0)>9&(g|0)>10&(g|0)>12)){return}g=(c[b+36>>2]|0)+4|0;b=e+11|0;while(1){e=b;h=(he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;if(!((b+2|0)>>>0<f>>>0&(b+4|0)>>>0<f>>>0)){i=22;break}e=b+3|0;j=(he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&4095;e=j+5|0;k=b+e|0;if(k>>>0>f>>>0){i=22;break}a:do{if(e>>>0>5>>>0){l=b+5|0;while(1){m=l+1|0;if(m>>>0<k>>>0){n=d[m]|0;o=l+2|0}else{n=-1;o=m}m=o+n|0;if(m>>>0>k>>>0){break a}do{if((a[l]|0)==72&o>>>0<f>>>0){p=o+1|0;if(!(p>>>0<f>>>0)){break}q=d[p]|0;p=q+2|0;r=o+p|0;if(r>>>0>f>>>0){break}s=hJb(q+1|0)|0;if((s|0)==0){break}nrc(s|0,o+2|0,q)|0;a[s+q|0]=0;do{if(r>>>0<f>>>0){t=d[r]|0;u=t+1|0;if((o+(u+p)|0)>>>0>f>>>0){v=0;break}w=hJb(u)|0;if((w|0)==0){v=0;break}nrc(w|0,o+(q+3)|0,t)|0;a[w+t|0]=0;t=$X(c[g>>2]|0,h)|0;if((t|0)==0){v=w;break}u=t+20|0;MGb(u,2341280,w,0)|0;MGb(u,2335568,s,0)|0;v=w}else{v=0}}while(0);kJb(v);kJb(s)}}while(0);if(m>>>0<k>>>0){l=m}else{break}}}}while(0);if((b+(j+6)|0)>>>0<f>>>0){b=k}else{i=22;break}}if((i|0)==22){return}}function aO(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=c[b+36>>2]|0;b=g;h=f-4|0;f=e+h|0;if((h|0)<=4){return}if(!((h|0)>7&(a[e]|0)==0)){return}i=e+3|0;j=(he((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535;i=g+4|0;c[(c[i>>2]|0)+1184>>2]=j;j=g+92|0;k=j;mJb(j);l=g+88|0;c[l>>2]=0;a:do{if((h|0)>9){m=g+41056|0;n=g+8288|0;o=e+8|0;while(1){p=o;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=(he(q|0)|0)&65535;if(!((o+3|0)>>>0<f>>>0)){r=47;break}s=o+4|0;t=o+2|0;u=(he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&8191;if((u|0)==(c[m>>2]|0)){r=47;break}b:do{if(!(q<<16>>16==0)){t=n+(u<<2)|0;v=c[t>>2]|0;w=$X(c[i>>2]|0,p)|0;c[w+24>>2]=p;c[w+28>>2]=u;c:do{if((v|0)!=0){do{if((c[v+12>>2]|0)==1){if((c[v>>2]|0)!=(u|0)){break}if((c[v+32>>2]|0)==1064){break c}}}while(0);w=c[t>>2]|0;x=c[w>>2]|0;y=c[w+12>>2]|0;do{if((y|0)==0){z=w+20|0;A=z;fGb((c[A>>2]|0)+344|0);if((c[(c[A>>2]|0)+20>>2]|0)!=0){break}mJb(z)}else if((y|0)==1){mJb(w+24|0)}}while(0);kJb(w);c[b+8288+(x<<2)>>2]=0}}while(0);do{if((c[t>>2]|0)==0){v=pJb(40)|0;if((v|0)==0){break}c[b+8288+(u<<2)>>2]=v;c[v+12>>2]=1;c[v>>2]=u;c[v+4>>2]=-1;c[v+8>>2]=-1;c[v+32>>2]=1064;c[v+36>>2]=g;y=hJb(4096)|0;c[v+24>>2]=y;z=v+28|0;c[z>>2]=c[z>>2]|1;if((y|0)!=0){break}kJb(v)}}while(0);if((oJb(j,(c[l>>2]|0)+1|0,268)|0)<0){B=0}else{t=c[l>>2]|0;v=c[k>>2]|0;c[v+(t*268|0)>>2]=p;c[v+(t*268|0)+4>>2]=0;c[v+(t*268|0)+264>>2]=0;B=(c[l>>2]|0)+1|0}c[l>>2]=B;t=0;while(1){if(!(t>>>0<B>>>0)){C=B;break}D=c[k>>2]|0;E=D+(t*268|0)|0;if((c[E>>2]|0)==(p|0)){r=28;break}else{t=t+1|0}}do{if((r|0)==28){r=0;if((E|0)==0){C=B;break}v=D+(t*268|0)+4|0;y=c[v>>2]|0;if(y>>>0>63>>>0){C=B;break}c[v>>2]=y+1;c[D+(t*268|0)+8+(y<<2)>>2]=0;C=c[l>>2]|0}}while(0);t=0;while(1){if(!(t>>>0<C>>>0)){break b}F=c[k>>2]|0;G=F+(t*268|0)|0;if((c[G>>2]|0)==(p|0)){break}else{t=t+1|0}}if((G|0)==0){break}y=F+(t*268|0)+4|0;v=c[y>>2]|0;if(v>>>0>63>>>0){break}c[y>>2]=v+1;c[F+(t*268|0)+8+(v<<2)>>2]=u}}while(0);if((o+5|0)>>>0<f>>>0){o=s}else{break a}}if((r|0)==47){return}}}while(0);r=c[i>>2]|0;i=r+1104|0;f=c[i>>2]|0;if((f|0)==0){return}else{H=0;I=f}while(1){f=c[l>>2]|0;F=0;while(1){if(!(F>>>0<f>>>0)){break}if((c[(c[k>>2]|0)+(F*268|0)>>2]|0)==(c[c[(c[r+1108>>2]|0)+(H<<2)>>2]>>2]|0)){break}else{F=F+1|0}}d:do{if((F|0)==(f|0)){G=c[r+1108>>2]|0;C=c[c[G+(H<<2)>>2]>>2]|0;D=0;while(1){if(!(D>>>0<I>>>0)){J=I;break d}K=c[G+(D<<2)>>2]|0;if((c[K>>2]|0)==(C|0)){break}else{D=D+1|0}}if((K|0)==0){J=I;break}c[K+16>>2]=0;J=c[i>>2]|0}else{J=I}}while(0);f=H+1|0;if(f>>>0<J>>>0){H=f;I=J}else{break}}return}function bO(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=i;g=b+4|0;h=c[g>>2]|0;j=e+1|0;k=(d[j]|d[j+1|0]<<8)<<16>>16;j=(he(k|0)|0)&8191;do{if((j|0)!=0){l=c[h+1104>>2]|0;m=h+1108|0;n=0;while(1){if(!(n>>>0<l>>>0)){break}if((c[(c[(c[m>>2]|0)+(n<<2)>>2]|0)+8>>2]|0)==48){break}else{n=n+1|0}}if((n|0)==(l|0)){break}o=c[b+88>>2]|0;if((o|0)==0){break}p=c[b+92>>2]|0;q=(l|0)==0;r=0;s=0;t=0;while(1){u=c[p+(r*268|0)+4>>2]|0;do{if((u|0)==0){v=s;w=t}else{x=p+(r*268|0)|0;if(q){v=s;w=t;break}else{y=0;z=s;A=t}while(1){if((c[p+(r*268|0)+8+(y<<2)>>2]|0)==(j|0)){B=c[x>>2]|0;C=c[m>>2]|0;D=0;E=z;F=A;while(1){H=c[C+(D<<2)>>2]|0;do{if((c[H>>2]|0)==(B|0)){if((c[H+8>>2]|0)==48){I=F+1|0;J=E;break}else{I=F;J=E+1|0;break}}else{I=F;J=E}}while(0);H=D+1|0;if(H>>>0<l>>>0){D=H;E=J;F=I}else{K=I;L=J;break}}}else{K=A;L=z}F=y+1|0;if(F>>>0<u>>>0){y=F;z=L;A=K}else{v=L;w=K;break}}}}while(0);u=r+1|0;if(u>>>0<o>>>0){r=u;s=v;t=w}else{break}}if((v|0)!=0|(w|0)==0){break}else{M=0}i=f;return M|0}}while(0);w=k&64;k=b+8288+(j<<2)|0;v=c[k>>2]|0;K=(w|0)==0;if((v|0)!=0|(c[b+40>>2]|0)==0|K){N=v}else{v=pJb(416)|0;a:do{if((v|0)!=0){c[v+12>>2]=b;c[v+16>>2]=c[g>>2];c[v>>2]=j;c[v+4>>2]=-1;c[v+28>>2]=4;L=v+56|0;c[L>>2]=0;c[L+4>>2]=-2147483648;L=v+64|0;c[L>>2]=0;c[L+4>>2]=-2147483648;L=v+408|0;c[L>>2]=-1;c[L+4>>2]=-1;do{if((c[k>>2]|0)==0){L=pJb(40)|0;if((L|0)==0){break}c[k>>2]=L;c[L+12>>2]=0;c[L>>2]=j;c[L+4>>2]=-1;c[L+8>>2]=-1;c[L+16>>2]=2;c[L+20>>2]=v;break a}}while(0);kJb(v)}}while(0);N=c[k>>2]|0}if((N|0)==0){M=0;i=f;return M|0}c[b+41056>>2]=j;v=e+3|0;L=d[v]|0;A=L>>>4;if((A&3|0)==0){M=0;i=f;return M|0}z=A&1;y=(A&2|0)!=0;do{if(y){if((a[e+4|0]|0)==0){O=0;break}O=(a[e+5|0]|0)<0}else{O=0}}while(0);A=L&15;L=(z|0)!=0;z=N+8|0;J=c[z>>2]|0;if(L){P=J+1&15}else{P=J}do{if((j|0)==8191|O){c[z>>2]=A;Q=1}else{c[z>>2]=A;if((J|0)<0|(P|0)==(A|0)){Q=1;break}KIb(c[g>>2]|0,48,2471272,(R=i,i=i+24|0,c[R>>2]=j,c[R+8>>2]=P,c[R+16>>2]=A,R)|0);i=R;if((c[N+12>>2]|0)!=0){Q=0;break}I=(c[N+20>>2]|0)+36|0;c[I>>2]=c[I>>2]|2;Q=0}}while(0);if(!L){M=0;i=f;return M|0}L=e+4|0;do{if(y){A=(d[L]|0)+5|0;if(A>>>0<188>>>0){S=e+A|0;break}else{M=0;i=f;return M|0}}else{S=L}}while(0);y=e+188|0;A=fD(c[(c[g>>2]|0)+16>>2]|0,0,0,1)|0;P=G;j=-1;do{if((P|0)>(j|0)|(P|0)==(j|0)&A>>>0>-1>>>0){J=0;if((P|0)>(J|0)|(P|0)==(J|0)&A>>>0>187>>>0){J=wrc(A,P,-188,-1)|0;z=b+32|0;c[z>>2]=J;c[z+4>>2]=G;break}else{KIb(0,0,2463400,(R=i,i=i+24|0,c[R>>2]=2448560,c[R+8>>2]=2433112,c[R+16>>2]=1987,R)|0);i=R;Hd();return 0}}}while(0);do{if((c[N+12>>2]|0)==1){do{if(K){if(!Q){break}lO(c[h+12>>2]|0,N,S,y-S|0,0)}else{j=a[S]|0;z=j&255;J=S+(z+1)|0;if(J>>>0>y>>>0){M=0;i=f;return M|0}do{if(!(j<<24>>24==0|Q^1)){lO(c[h+12>>2]|0,N,S+1|0,z,0);if((c[k>>2]|0)==0){M=0}else{break}i=f;return M|0}}while(0);if(!(J>>>0<y>>>0)){break}lO(c[h+12>>2]|0,N,J,y-J|0,1)}}while(0);z=c[g>>2]|0;if((c[z+20>>2]&1|0)==0){break}j=b+92|0;O=c[b+88>>2]|0;I=0;while(1){if(!(I>>>0<O>>>0)){break}if((c[(c[j>>2]|0)+(I*268|0)+264>>2]|0)==0){break}else{I=I+1|0}}if((I|0)!=(O|0)|(O|0)==0){break}j=0;if(!((c[z+24>>2]|0)>>>0>1>>>0|((P|0)>(j|0)|(P|0)==(j|0)&A>>>0>1e5>>>0))){break}KIb(z,48,2424320,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;j=(c[g>>2]|0)+20|0;c[j>>2]=c[j>>2]&-2}else{do{if((a[v]&32)>>>0<32>>>0){T=-1;U=-1}else{j=a[L]|0;if(j<<24>>24==0){T=-1;U=-1;break}if((a[e+5|0]&16)==0){T=-1;U=-1;break}if(((j&255)-1|0)<6){T=-1;U=-1;break}j=e+6|0;t=je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;j=d[e+10|0]|0;s=j<<8&256|d[e+11|0];r=Erc(j>>>7|(t<<1|0>>>31),0<<1|t>>>31|0,300,0)|0;t=wrc(r,G,s,0)|0;T=G;U=t}}while(0);z=c[N+16>>2]|0;O=c[b+8>>2]|0;I=xrc(A,P,O,(O|0)<0|0?-1:0)|0;O=gf[z&63](N,S,y-S|0,w,I,G,U,T)|0;if((O|0)<0){M=O}else{break}i=f;return M|0}}while(0);M=0;i=f;return M|0}function cO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+816|0;e=d|0;f=c[b+8>>2]|0;g=(f|0)/204|0;if((f|0)<2040){h=-1;i=d;return h|0}f=c[b+4>>2]|0;b=e;j=0;k=0;l=0;do{m=g-j|0;n=(m|0)>100?100:m;m=j*188|0;mrc(b|0,0,752)|0;o=(n*188|0)-3|0;if((o|0)>0){p=m|3;q=0;r=0;while(1){s=r+1|0;do{if((a[f+(r+m)|0]|0)==71){if((a[f+(s+m)|0]|0)<0){t=q;break}if((a[f+(p+r)|0]|0)==71){t=q;break}u=e+(((r|0)%188|0)<<2)|0;v=(c[u>>2]|0)+1|0;c[u>>2]=v;t=(v|0)>(q|0)?v:q}else{t=q}}while(0);if((s|0)<(o|0)){q=t;r=s}else{w=t;break}}}else{w=0}r=j*192|0;mrc(b|0,0,768)|0;q=(n*192|0)-3|0;if((q|0)>0){o=r|3;p=0;m=0;while(1){v=m+1|0;do{if((a[f+(m+r)|0]|0)==71){if((a[f+(v+r)|0]|0)<0){x=p;break}if((a[f+(o+m)|0]|0)==71){x=p;break}u=e+(((m|0)%192|0)<<2)|0;y=(c[u>>2]|0)+1|0;c[u>>2]=y;x=(y|0)>(p|0)?y:p}else{x=p}}while(0);if((v|0)<(q|0)){p=x;m=v}else{z=x;break}}}else{z=0}m=j*204|0;mrc(b|0,0,816)|0;p=(n*204|0)-3|0;if((p|0)>0){q=m|3;o=0;r=0;while(1){s=r+1|0;do{if((a[f+(r+m)|0]|0)==71){if((a[f+(s+m)|0]|0)<0){A=o;break}if((a[f+(q+r)|0]|0)==71){A=o;break}y=e+(((r|0)%204|0)<<2)|0;u=(c[y>>2]|0)+1|0;c[y>>2]=u;A=(u|0)>(o|0)?u:o}else{A=o}}while(0);if((s|0)<(p|0)){o=A;r=s}else{B=A;break}}}else{B=0}r=(w|0)>(z|0)?w:z;o=(r|0)>(B|0)?r:B;k=o+k|0;l=(l|0)>(o|0)?l:o;j=j+100|0;}while((j|0)<(g|0));j=(k*10|0|0)/(g|0)|0;if((j|0)<=6){i=d;return((l*10|0|0)>699?j+40|0:-1)|0}h=j+90|0;i=d;return h|0}function dO(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+9232|0;f=e|0;g=e+816|0;h=e+9008|0;j=e+9024|0;k=e+9032|0;l=e+9224|0;m=c[b+12>>2]|0;n=m;o=b+16|0;p=c[o>>2]|0;q=g|0;mrc(q|0,0,8192)|0;r=b+1088|0;RD(p,c[r>>2]|0)|0;s=fD(p,0,0,1)|0;t=G;u=AD(p,q,8192)|0;a:do{if((u|0)<1021){q=m+8|0;c[q>>2]=-1;v=q;w=26}else{q=f;mrc(q|0,0,752)|0;x=u-3|0;if((x|0)>0){y=0;z=0}else{mrc(q|0,0,768)|0;mrc(q|0,0,816)|0;A=m+8|0;c[A>>2]=-1;v=A;w=26;break}while(1){A=z+1|0;do{if((a[g+z|0]|0)==71){if((a[g+A|0]|0)<0){B=y;break}if((a[g+(z+3)|0]|0)==71){B=y;break}C=f+(((z|0)%188|0)<<2)|0;D=(c[C>>2]|0)+1|0;c[C>>2]=D;B=(D|0)>(y|0)?D:y}else{B=y}}while(0);if((A|0)<(x|0)){y=B;z=A}else{break}}mrc(q|0,0,768)|0;D=0;C=0;while(1){E=C+1|0;do{if((a[g+C|0]|0)==71){if((a[g+E|0]|0)<0){F=D;break}if((a[g+(C+3)|0]|0)==71){F=D;break}H=f+(((C|0)%192|0)<<2)|0;I=(c[H>>2]|0)+1|0;c[H>>2]=I;F=(I|0)>(D|0)?I:D}else{F=D}}while(0);if((E|0)<(x|0)){D=F;C=E}else{break}}mrc(q|0,0,816)|0;C=0;D=0;while(1){A=D+1|0;do{if((a[g+D|0]|0)==71){if((a[g+A|0]|0)<0){J=C;break}if((a[g+(D+3)|0]|0)==71){J=C;break}I=f+(((D|0)%204|0)<<2)|0;H=(c[I>>2]|0)+1|0;c[I>>2]=H;J=(H|0)>(C|0)?H:C}else{J=C}}while(0);if((A|0)<(x|0)){C=J;D=A}else{break}}do{if((B|0)>(J|0)&(B|0)>(F|0)){K=188}else{if((F|0)>(B|0)&(F|0)>(J|0)){K=192;break}D=(B|0)<(J|0)&(F|0)<(J|0);C=m+8|0;c[C>>2]=D?204:-1;if(D){L=C;break a}else{v=C;w=26;break a}}}while(0);C=m+8|0;c[C>>2]=K;L=C}}while(0);if((w|0)==26){KIb(b,24,2537384,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;c[v>>2]=188;L=v}c[m+4>>2]=b;v=m+40|0;c[v>>2]=0;do{if((c[b+4>>2]|0)==1343296){K=fD(p,s,t,0)|0;J=G;F=0;if((J|0)<(F|0)|(J|0)==(F|0)&K>>>0<0>>>0){KIb(b,(c[p+88>>2]|0)!=0?16:32,2521296,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M}K=m+8356|0;do{if((c[K>>2]|0)==0){F=pJb(40)|0;if((F|0)==0){break}c[K>>2]=F;c[F+12>>2]=1;c[F>>2]=17;c[F+4>>2]=-1;c[F+8>>2]=-1;c[F+32>>2]=1646;c[F+36>>2]=m;J=hJb(4096)|0;c[F+24>>2]=J;B=F+28|0;c[B>>2]=c[B>>2]|1;if((J|0)!=0){break}kJb(F)}}while(0);K=m+8288|0;do{if((c[K>>2]|0)==0){F=pJb(40)|0;if((F|0)==0){break}c[K>>2]=F;c[F+12>>2]=1;c[F>>2]=0;c[F+4>>2]=-1;c[F+8>>2]=-1;c[F+32>>2]=110;c[F+36>>2]=m;J=hJb(4096)|0;c[F+24>>2]=J;B=F+28|0;c[B>>2]=c[B>>2]|1;if((J|0)!=0){break}kJb(F)}}while(0);jO(n,((c[r>>2]|0)>>>0)/((c[L>>2]|0)>>>0)|0)|0;c[v>>2]=1;K=b+20|0;c[K>>2]=c[K>>2]|1}else{K=ZX(b,0)|0;if((K|0)==0){N=-1;i=e;return N|0}_X(K,60,1,27e6);F=K+8|0;J=c[F>>2]|0;c[J+8>>2]=2;c[J+48>>2]=131072;J=k|0;if((iO(b,J,c[L>>2]|0,l)|0)<0){N=-1;i=e;return N|0}else{O=-1;P=0;Q=0}b:while(1){B=c[l>>2]|0;f=B+1|0;g=(he((d[f]|d[f+1|0]<<8)<<16>>16|0)|0)&8191;do{if((O|0)==-1|(O|0)==(g|0)){if((a[B+3|0]&32)>>>0<32>>>0){w=50;break}f=a[B+4|0]|0;if(f<<24>>24==0){w=50;break}if((a[B+5|0]&16)==0){w=50;break}if(((f&255)-1|0)<6){w=50;break}f=B+6|0;z=je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;f=d[B+10|0]|0;y=f<<8&256|d[B+11|0];u=(c[L>>2]|0)-188|0;if((u|0)>0){hD(c[o>>2]|0,u,(u|0)<0|0?-1:0)|0;}c[j+(Q<<2)>>2]=P;u=Erc(f>>>7|(z<<1|0>>>31),0<<1|z>>>31|0,300,0)|0;z=wrc(u,G,y,0)|0;y=h+(Q<<3)|0;c[y>>2]=z;c[y+4>>2]=G;if((Q|0)>0){w=53;break b}R=Q+1|0;S=g}else{w=50}}while(0);do{if((w|0)==50){w=0;g=(c[L>>2]|0)-188|0;if((g|0)<=0){R=Q;S=O;break}hD(c[o>>2]|0,g,(g|0)<0|0?-1:0)|0;R=Q;S=O}}while(0);if((iO(b,J,c[L>>2]|0,l)|0)<0){N=-1;w=56;break}else{O=S;P=P+1|0;Q=R}}if((w|0)==53){J=h+8|0;g=h|0;B=c[g>>2]|0;A=c[g+4>>2]|0;g=xrc(c[J>>2]|0,c[J+4>>2]|0,B,A)|0;J=c[j>>2]|0;y=(c[j+4>>2]|0)-J|0;z=Crc(g,G,y,(y|0)<0|0?-1:0)|0;y=z;c[m+64>>2]=y;z=ca(J,y)|0;J=xrc(B,A,z,(z|0)<0|0?-1:0)|0;z=G;A=m+56|0;c[A>>2]=J;c[A+4>>2]=z;A=~~(40608.0e6/+(y|0));c[b+1072>>2]=A;c[(c[F>>2]|0)+72>>2]=A;A=K+48|0;c[A>>2]=J;c[A+4>>2]=z;break}else if((w|0)==56){i=e;return N|0}}}while(0);w=fD(p,s,t,0)|0;t=G;s=0;if(!((t|0)<(s|0)|(t|0)==(s|0)&w>>>0<0>>>0)){N=0;i=e;return N|0}KIb(b,(c[p+88>>2]|0)!=0?16:32,2521296,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=0;i=e;return N|0}function eO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[a+12>>2]|0;a=b+28|0;c[a>>2]=-1;e=d+72|0;c[e>>2]=b;f=jO(d,0)|0;a:do{if((f|0)<0){P1(c[e>>2]|0);g=d+8288|0;h=0;b:while(1){i=c[g+(h<<2)>>2]|0;do{if((i|0)!=0){if((c[i+12>>2]|0)!=0){break}j=c[i+20>>2]|0;k=j+28|0;if((c[k>>2]|0)!=3){break}if((c[j+32>>2]|0)>0){break b}}}while(0);h=h+1|0;if((h|0)>=8192){break a}}kO(j,b);c[k>>2]=4;l=c[a>>2]|0;m=l>>31;n=m&-4;return n|0}}while(0);if((f|0)==0){l=c[a>>2]|0;m=l>>31;n=m&-4;return n|0}else{return f|0}return 0}function fO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+12>>2]|0;a=b;mJb(b+92|0);c[b+88>>2]=0;b=0;do{d=c[a+8288+(b<<2)>>2]|0;if((d|0)!=0){e=c[d>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==1){mJb(d+24|0)}else if((f|0)==0){g=d+20|0;h=g;fGb((c[h>>2]|0)+344|0);if((c[(c[h>>2]|0)+20>>2]|0)!=0){break}mJb(g)}}while(0);kJb(d);c[a+8288+(e<<2)>>2]=0}b=b+1|0;}while((b|0)<8192);return 0}function gO(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+80|0;h=g|0;j=c[a+12>>2]|0;k=j+32|0;l=c[j+8>>2]|0;j=l;m=(l|0)<0|0?-1:0;l=Drc(c[k>>2]|0,c[k+4>>2]|0,j,m)|0;k=c[d>>2]|0;n=c[d+4>>2]|0;o=l;l=o;p=(o|0)<0|0?-1:0;o=wrc(j,m,-1,-1)|0;q=wrc(o,G,k,n)|0;n=xrc(q,G,l,p)|0;q=G;k=Drc(n,q,j,m)|0;m=xrc(n,q,k,G)|0;k=wrc(m,G,l,p)|0;p=G;yX(a);l=fD(c[a+16>>2]|0,k,p,0)|0;m=G;q=-1;if(!(((m|0)>(q|0)|(m|0)==(q|0)&l>>>0>-1>>>0)&((p|0)<(f|0)|(p|0)==(f|0)&k>>>0<e>>>0))){r=-2147483648;s=0;i=g;return(G=r,s)|0}k=h+16|0;p=h+64|0;l=h+32|0;q=a+28|0;a:while(1){J1(h);if((uX(a,h)|0)<0){r=-2147483648;s=0;t=10;break}P1(h);do{if(!((c[k>>2]|0)==0&(c[k+4>>2]|0)==(-2147483648|0))){m=c[p+4>>2]|0;n=-1;if(!((m|0)>(n|0)|(m|0)==(n|0)&(c[p>>2]|0)>>>0>-1>>>0)){break}wX(a,c[l>>2]|0);xX(c[(c[q>>2]|0)+(c[l>>2]<<2)>>2]|0,c[p>>2]|0,c[p+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0,0,0,1)|0;if((c[l>>2]|0)!=(b|0)){break}u=c[p>>2]|0;v=c[p+4>>2]|0;n=c[d+4>>2]|0;if(!((v|0)<(n|0)|(v|0)==(n|0)&u>>>0<(c[d>>2]|0)>>>0)){t=8;break a}}}while(0);n=c[p+4>>2]|0;if(!((n|0)<(f|0)|(n|0)==(f|0)&(c[p>>2]|0)>>>0<e>>>0)){r=-2147483648;s=0;t=10;break}}if((t|0)==8){c[d>>2]=u;c[d+4>>2]=v;r=c[k+4>>2]|0;s=c[k>>2]|0;i=g;return(G=r,s)|0}else if((t|0)==10){i=g;return(G=r,s)|0}return 0}function hO(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+24|0;g=f|0;h=f+16|0;j=c[b+12>>2]|0;if((K1(e,188)|0)<0){k=-12;i=f;return k|0}l=b+16|0;m=fD(c[l>>2]|0,0,0,1)|0;n=e+64|0;c[n>>2]=m;c[n+4>>2]=G;n=e+24|0;m=j+8|0;o=iO(b,c[n>>2]|0,c[m>>2]|0,h)|0;if((o|0)<0){P1(e);k=o;i=f;return k|0}o=c[h>>2]|0;h=c[n>>2]|0;if((o|0)!=(h|0)){nrc(h|0,o|0,c[m>>2]|0)|0}o=(c[m>>2]|0)-188|0;if((o|0)>0){hD(c[l>>2]|0,o,(o|0)<0|0?-1:0)|0;}if((c[j+44>>2]|0)!=0){o=c[n>>2]|0;do{if(!((a[o+3|0]&32)>>>0<32>>>0)){n=a[o+4|0]|0;if(n<<24>>24==0){break}if((a[o+5|0]&16)==0){break}if(((n&255)-1|0)<6){break}n=o+6|0;h=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=d[o+10|0]|0;b=n>>>7|(h<<1|0>>>31);p=0<<1|h>>>31|0;h=n<<8&256|(d[o+11|0]|0);n=fD(c[l>>2]|0,0,0,1)|0;q=G;r=g|0;s=g+3|0;t=g+4|0;u=g+5|0;v=g+6|0;w=0;a:while(1){x=c[l>>2]|0;y=ca(c[m>>2]|0,w)|0;z=wrc(y,(y|0)<0|0?-1:0,n,q)|0;fD(x,z,G,0)|0;AD(c[l>>2]|0,r,12)|0;do{if(!((a[s]&32)>>>0<32>>>0)){z=a[t]|0;if(z<<24>>24==0){break}if((a[u]&16)==0){break}if(((z&255)-1|0)>=6){A=18;break a}}}while(0);z=w+1|0;if((z|0)<697){w=z}else{break}}if((A|0)==18){u=v;t=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=d[g+10|0]|0;s=u<<8&256|(d[g+11|0]|0);r=xrc(u>>>7|(t<<1|0>>>31),0<<1|t>>>31|0,b,p)|0;t=Erc(r,G,300,0)|0;r=s-h|0;s=wrc(t,G,r,(r|0)<0|0?-1:0)|0;r=w+1|0;t=Crc(s,G,r,(r|0)<0|0?-1:0)|0;c[j+64>>2]=t}fD(c[l>>2]|0,n,q,0)|0;t=Erc(b,p,300,0)|0;r=wrc(t,G,h,0)|0;t=j+56|0;c[t>>2]=r;c[t+4>>2]=G}}while(0);l=j+56|0;g=c[l+4>>2]|0;A=e+8|0;c[A>>2]=c[l>>2];c[A+4>>2]=g;g=j+64|0;c[e+48>>2]=c[g>>2];j=c[g>>2]|0;g=wrc(c[l>>2]|0,c[l+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[l>>2]=g;c[l+4>>2]=G}c[e+32>>2]=0;k=0;i=f;return k|0}function iO(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;h=b+16|0;j=c[h>>2]|0;k=BD(j,d,188,f)|0;a:do{if((k|0)==188){l=e;m=(e|0)<0|0?-1:0;n=b+12|0;b:while(1){if((a[c[f>>2]|0]|0)==71){o=0;p=23;break}q=fD(j,0,0,1)|0;r=G;s=m>>>0>r>>>0|m>>>0==r>>>0&l>>>0>q>>>0;t=xrc(0,0,s?q:l,s?r:m)|0;fD(j,t,G,1)|0;t=c[h>>2]|0;r=0;while(1){if((r|0)>=65536){p=22;break b}s=zD(t)|0;if((jD(t)|0)!=0){o=-11;p=23;break b}if((s|0)==71){break}else{r=r+1|0}}fD(t,-1,-1,1)|0;r=c[n>>2]|0;s=r+4|0;q=fD(c[(c[s>>2]|0)+16>>2]|0,0,0,1)|0;u=G;v=0;do{if(!((u|0)<(v|0)|(u|0)==(v|0)&q>>>0<0>>>0)){w=r+32|0;x=xrc(q,u,c[w>>2]|0,c[w+4>>2]|0)|0;w=G;y=192;z=0;A=188;B=0;if((x|0)==204&(w|0)==0){C=r+20|0;c[C>>2]=(c[C>>2]|0)+1}else if((x|0)==(y|0)&(w|0)==(z|0)){z=r+16|0;c[z>>2]=(c[z>>2]|0)+1}else if((x|0)==(A|0)&(w|0)==(B|0)){B=r+12|0;c[B>>2]=(c[B>>2]|0)+1}B=r+24|0;w=(c[B>>2]|0)+1|0;c[B>>2]=w;if((w|0)<=10){break}w=r+12|0;do{if((c[w>>2]|0)>10){D=188;p=19}else{if((c[r+16>>2]|0)>10){D=192;p=19;break}B=(c[r+20>>2]|0)>10;if(B){D=B?204:0;p=19}}}while(0);do{if((p|0)==19){p=0;B=r+8|0;if((D|0)==(c[B>>2]|0)){break}KIb(c[s>>2]|0,24,2154416,(E=i,i=i+8|0,c[E>>2]=D,E)|0);i=E;c[B>>2]=D}}while(0);mrc(w|0,0,16)|0}}while(0);s=BD(j,d,188,f)|0;if((s|0)!=188){F=s;break a}}if((p|0)==22){KIb(b,16,2182832,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;o=-11;i=g;return o|0}else if((p|0)==23){i=g;return o|0}}else{F=k}}while(0);o=(F|0)<0?F:-541478725;i=g;return o|0}function jO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+216|0;e=d|0;f=d+208|0;g=c[a+4>>2]|0;h=g+16|0;j=fD(c[h>>2]|0,0,0,1)|0;k=a+80|0;if(!((j|0)==(c[k>>2]|0)&(G|0)==(c[k+4>>2]|0))){j=0;do{l=a+8288+(j<<2)|0;m=c[l>>2]|0;if((m|0)!=0){if((c[m+12>>2]|0)==0){n=c[m+20>>2]|0;fGb(n+344|0);c[n+32>>2]=0;c[n+28>>2]=4;o=n+408|0;c[o>>2]=-1;c[o+4>>2]=-1;p=c[l>>2]|0}else{p=m}c[p+8>>2]=-1}j=j+1|0;}while((j|0)<8192)}j=a+68|0;c[j>>2]=0;p=e|0;mrc(e+188|0,0,16)|0;e=a+8|0;m=(b|0)==0;l=0;while(1){o=l+1|0;if(!(m|(o|0)<(b|0))){q=-11;break}n=c[j>>2]|0;if((n|0)>1){q=-11;break}if((n|0)>0){q=0;break}n=iO(g,p,c[e>>2]|0,f)|0;if((n|0)!=0){q=n;break}n=bO(a,c[f>>2]|0)|0;r=(c[e>>2]|0)-188|0;if((r|0)>0){hD(c[h>>2]|0,r,(r|0)<0|0?-1:0)|0;}if((n|0)==0){l=o}else{q=n;break}}l=fD(c[h>>2]|0,0,0,1)|0;c[k>>2]=l;c[k+4>>2]=G;i=d;return q|0}function kO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;J1(b);e=a+344|0;c[b>>2]=c[e>>2];f=c[(c[e>>2]|0)+4>>2]|0;g=b+24|0;c[g>>2]=f;h=a+32|0;j=c[h>>2]|0;k=b+28|0;c[k>>2]=j;l=c[a+40>>2]|0;do{if((l|0)==204800){m=f;n=j}else{if(((c[h>>2]|0)+(c[a+44>>2]|0)|0)==(l+6|0)){m=f;n=j;break}KIb(c[a+16>>2]|0,24,2555176,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;o=a+36|0;c[o>>2]=c[o>>2]|2;m=c[g>>2]|0;n=c[k>>2]|0}}while(0);mrc(m+n|0,0,16)|0;n=c[a+24>>2]|0;do{if((n|0)==0){p=8}else{if((c[a+8>>2]|0)!=131){p=8;break}if((c[a+48>>2]|0)!=118){p=8;break}c[b+32>>2]=c[n>>2]}}while(0);if((p|0)==8){c[b+32>>2]=c[c[a+20>>2]>>2]}p=a+56|0;n=c[p+4>>2]|0;m=b+8|0;c[m>>2]=c[p>>2];c[m+4>>2]=n;n=a+64|0;m=c[n+4>>2]|0;k=b+16|0;c[k>>2]=c[n>>2];c[k+4>>2]=m;m=a+72|0;k=c[m+4>>2]|0;g=b+64|0;c[g>>2]=c[m>>2];c[g+4>>2]=k;k=a+36|0;c[b+36>>2]=c[k>>2];c[p>>2]=0;c[p+4>>2]=-2147483648;c[n>>2]=0;c[n+4>>2]=-2147483648;c[e>>2]=0;c[h>>2]=0;c[k>>2]=0;i=d;return}function lO(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=e+16|0;do{if((h|0)==0){if((c[e+28>>2]&2|0)==0){j=i|0;k=c[j>>2]|0;l=4096-k|0;m=(l|0)>(g|0)?g:l;nrc((c[e+24>>2]|0)+k|0,f|0,m)|0;k=(c[j>>2]|0)+m|0;c[j>>2]=k;j=c[e+20>>2]|0;m=e+20|0;if((j|0)==-1){n=k;o=m;p=5;break}else{q=j;r=k;s=m;break}}else{return}}else{nrc(c[e+24>>2]|0,f|0,g)|0;c[i>>2]=g;c[e+20>>2]=-1;m=e+28|0;c[m>>2]=c[m>>2]&-3;n=g;o=e+20|0;p=5}}while(0);do{if((p|0)==5){do{if((n|0)>2){g=(c[e+24>>2]|0)+1|0;i=((he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&4095)+3|0;if(i>>>0>4096>>>0){return}else{c[o>>2]=i;t=i;break}}else{t=c[o>>2]|0}}while(0);if(!((t|0)==-1)){q=t;r=n;s=o;break}return}}while(0);if((r|0)<(q|0)){return}q=e+28|0;r=c[q>>2]|0;c[q>>2]=r|2;do{if((r&1|0)==0){u=e+24|0}else{q=DGb(3)|0;o=e+24|0;n=(EGb(q,-1,c[o>>2]|0,c[s>>2]|0)|0)==0;q=b+((c[e>>2]|0)+96)|0;if(n){a[q]=100;u=o;break}n=a[q]|0;if(!(n<<24>>24>-10)){u=o;break}a[q]=n-1;return}}while(0);ef[c[e+32>>2]&4095](e,c[u>>2]|0,c[s>>2]|0);return}function mO(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0;m=i;i=i+24|0;n=m|0;o=c[b+20>>2]|0;b=o;p=o+12|0;q=c[p>>2]|0;r=q+72|0;s=c[r>>2]|0;if((s|0)==0){t=0;i=m;return t|0}if(!((k|0)==(-1|0)&(l|0)==(-1|0))){u=o+408|0;c[u>>2]=k;c[u+4>>2]=l}if((g|0)==0){v=o+32|0}else{g=o+28|0;l=o+32|0;do{if((c[g>>2]|0)==3){if((c[l>>2]|0)<=0){break}kO(b,s);c[q+68>>2]=1}}while(0);c[g>>2]=0;c[l>>2]=0;g=o+72|0;c[g>>2]=h;c[g+4>>2]=j;v=l}l=o+44|0;j=q+4|0;if((f|0)<=0){t=0;i=m;return t|0}g=o+28|0;h=o+80|0;s=o+81|0;u=o+82|0;k=o+83|0;w=o+20|0;x=o;y=o+84|0;z=o+40|0;A=o+344|0;B=o+24|0;C=o+88|0;D=o+87|0;E=o+89|0;F=o+56|0;H=o+64|0;I=o+48|0;J=o+8|0;K=n|0;L=n+12|0;M=n+16|0;N=n+4|0;O=n+8|0;P=o+348|0;Q=o+352|0;R=o+380|0;S=o+368|0;T=o+360|0;U=o+400|0;V=o+392|0;W=o+388|0;X=o+376|0;Y=o+384|0;Z=o+356|0;_=o+396|0;$=o+364|0;aa=o+372|0;ba=o+16|0;ca=o+90|0;da=o+92|0;ea=o+94|0;fa=o+95|0;ga=o+97|0;ha=o+99|0;ia=q+68|0;q=e;e=f;a:while(1){b:do{switch(c[g>>2]|0){case 0:{f=c[v>>2]|0;ja=6-f|0;ka=(ja|0)>(e|0)?e:ja;nrc(o+(f+80)|0,q|0,ka)|0;f=ka+(c[v>>2]|0)|0;c[v>>2]=f;ja=q+ka|0;la=e-ka|0;if((f|0)!=6){ma=la;na=ja;break b}c:do{if((a[h]|0)==0){if((a[s]|0)!=0){break}if((a[u]|0)!=1){break}f=d[k]|256;ka=c[w>>2]|0;oa=(ka|0)==0;do{if(oa){pa=21}else{if((c[ka+76>>2]|0)!=48){pa=21;break}qa=c[B>>2]|0;if((qa|0)==0){break c}if((c[qa+76>>2]|0)==48|(f|0)==446){break c}}}while(0);if((pa|0)==21){pa=0;if((f|0)==446){break}}if(oa){ka=ZX(c[j>>2]|0,0)|0;c[w>>2]=ka;if((ka|0)==0){t=-12;pa=135;break a}c[ka+4>>2]=c[x>>2];nO(ka,b,0,0)}ka=(d[y]|d[y+1|0]<<8)<<16>>16;qa=(he(ka|0)|0)&65535;ra=ka<<16>>16==0?204800:qa;c[z>>2]=ra;qa=cGb(ra+16|0)|0;c[A>>2]=qa;if((qa|0)==0){t=-12;pa=135;break a}switch(f|0){case 511:case 504:case 498:case 497:case 496:case 447:case 444:{c[g>>2]=3;c[v>>2]=0;ma=la;na=ja;break b;break};default:{}}c[g>>2]=1;qa=c[w>>2]|0;if((c[(c[qa+8>>2]|0)+48>>2]|0)!=0){ma=la;na=ja;break b}ra=qa+440|0;if((c[ra>>2]|0)!=0){ma=la;na=ja;break b}c[ra>>2]=1;ma=la;na=ja;break b}}while(0);c[g>>2]=4;ma=la;na=ja;break};case 3:{pa=123;break a;break};case 1:{ra=c[v>>2]|0;qa=9-ra|0;if((qa|0)<0){t=-1;pa=135;break a}ka=(qa|0)>(e|0)?e:qa;nrc(o+(ra+80)|0,q|0,ka)|0;ra=(c[v>>2]|0)+ka|0;c[v>>2]=ra;qa=q+ka|0;sa=e-ka|0;if((ra|0)!=9){ma=sa;na=qa;break b}c[l>>2]=(d[C]|0)+9;c[g>>2]=2;ma=sa;na=qa;break};case 4:{t=0;pa=135;break a;break};case 2:{qa=c[v>>2]|0;sa=(c[l>>2]|0)-qa|0;if((sa|0)<0){t=-1;pa=135;break a}ra=(sa|0)>(e|0)?e:sa;nrc(o+(qa+80)|0,q|0,ra)|0;qa=(c[v>>2]|0)+ra|0;c[v>>2]=qa;sa=q+ra|0;ka=e-ra|0;if((qa|0)!=(c[l>>2]|0)){ma=ka;na=sa;break b}ta=d[D]|0;c[F>>2]=0;c[F+4>>2]=-2147483648;c[H>>2]=0;c[H+4>>2]=-2147483648;ua=ta&192;if((ua|0)==192){va=a[E]&14;wa=((he((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(va<<29|0>>>3);c[F>>2]=wa|((he((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;c[F+4>>2]=0<<29|va>>>3;va=a[ea]&14;wa=((he((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(va<<29|0>>>3);c[H>>2]=wa|((he((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;c[H+4>>2]=0<<29|va>>>3;xa=ha}else if((ua|0)==128){ua=a[E]&14;va=((he((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0)&65535)>>>1<<15|(ua<<29|0>>>3);wa=va|((he((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)>>>1;va=0<<29|ua>>>3|0;c[F>>2]=wa;c[F+4>>2]=va;c[H>>2]=wa;c[H+4>>2]=va;xa=ea}else{xa=E}c[I>>2]=-1;do{if((ta&1|0)!=0){va=d[xa]|0;wa=va>>>4;ua=(wa&11)+(wa&9)|0;if((va&65|0)!=1){break}if((xa+(ua+3)|0)>>>0>(o+(qa+80)|0)>>>0){break}if((a[xa+(ua+1)|0]&127)==0){break}va=d[xa+(ua+2)|0]|0;if((va&128|0)!=0){break}c[I>>2]=va}}while(0);c[g>>2]=3;c[v>>2]=0;ta=c[J>>2]|0;if((ta|0)==18&(ka|0)>0){ja=ka<<3;la=ja>>>0>2147483639>>>0|(sa|0)==0;va=la?0:sa;ua=la?0:ja;c[K>>2]=va;c[L>>2]=ua;ja=ua+8|0;c[M>>2]=ja;c[N>>2]=va+(ua>>3);c[O>>2]=0;ua=(c[P>>2]|0)==0;if(ua){ya=0;za=0}else{la=(d[va]|0)>>>7;wa=(ja|0)>0|0;c[O>>2]=wa;ya=la;za=wa}wa=(c[Q>>2]|0)==0;if(wa){Aa=za}else{la=((za|0)<(ja|0))+za|0;c[O>>2]=la;Aa=la}if(ua){Ba=wa?1:ya}else{Ba=ya}wa=c[R>>2]|0;if((wa|0)>0){ua=d[va+(Aa>>>3)|0]<<(Aa&7)>>>7;la=((Aa|0)<(ja|0))+Aa|0;c[O>>2]=la;Ca=ua&1;Da=la}else{Ca=0;Da=Aa}if((c[S>>2]|0)==0){Ea=0;Fa=Da}else{la=d[va+(Da>>>3)|0]<<(Da&7)>>>7;ua=((Da|0)<(ja|0))+Da|0;c[O>>2]=ua;Ea=la&1;Fa=ua}do{if((c[T>>2]|0)==0){Ga=0;Ha=0;Ia=Fa}else{ua=d[va+(Fa>>>3)|0]|0;la=((Fa|0)<(ja|0))+Fa|0;c[O>>2]=la;if((ua&128>>>((Fa&7)>>>0)|0)==0){Ga=0;Ha=0;Ia=la;break}ua=va+(la>>>3)|0;Ja=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(la&7)>>>29;ua=la+3|0;la=ja>>>0>ua>>>0?ua:ja;c[O>>2]=la;Ga=Ja;Ha=1;Ia=la}}while(0);do{if((Ea|0)==0){if(Ha&(Ga|0)==0){break}la=c[U>>2]|0;if((la|0)==0){Ka=Ia}else{Ja=-Ia|0;ua=ja-Ia|0;if((la|0)<(Ja|0)){La=Ja}else{La=(ua|0)<(la|0)?ua:la}la=La+Ia|0;c[O>>2]=la;Ka=la}la=c[V>>2]|0;do{if((la|0)==0){Ma=Ka}else{ua=d[va+(Ka>>>3)|0]|0;Ja=((Ka|0)<(ja|0))+Ka|0;c[O>>2]=Ja;if((ua&128>>>((Ka&7)>>>0)|0)==0){Ma=Ja;break}ua=Ja+la|0;Ja=ja>>>0>ua>>>0?ua:ja;c[O>>2]=Ja;Ma=Ja}}while(0);if((Ca|0)==0){Na=Ma}else{la=-Ma|0;f=ja-Ma|0;if((wa|0)<(la|0)){Oa=la}else{Oa=(f|0)<(wa|0)?f:wa}f=Oa+Ma|0;c[O>>2]=f;Na=f}do{if((Ba|0)==0){Pa=-1;Qa=-1;Ra=Na}else{if((c[Z>>2]|0)==0){Sa=Na}else{f=((Na|0)<(ja|0))+Na|0;c[O>>2]=f;Sa=f}f=c[_>>2]|0;if((f|0)>0){la=-Sa|0;oa=ja-Sa|0;if((f|0)<(la|0)){Ta=la}else{Ta=(oa|0)<(f|0)?oa:f}f=Ta+Sa|0;c[O>>2]=f;Ua=f}else{Ua=Sa}if((c[$>>2]|0)==0){Pa=-1;Qa=-1;Ra=Ua;break}f=((Ua|0)<(ja|0))+Ua|0;oa=d[va+(Ua>>>3)|0]<<(Ua&7)>>>7&1;la=d[va+(f>>>3)|0]<<(f&7)>>>7;Ja=((f|0)<(ja|0))+f|0;c[O>>2]=Ja;Pa=la&1;Qa=oa;Ra=Ja}}while(0);if((c[W>>2]|0)==0){Va=0}else{Ja=d[va+(Ra>>>3)|0]<<(Ra&7)>>>7;c[O>>2]=((Ra|0)<(ja|0))+Ra;Va=Ja&1}if((Qa|0)==1){Ja=oO(n,c[X>>2]|0)|0;Wa=G;Xa=Ja}else{Wa=-2147483648;Xa=0}if((Pa|0)==1){Ja=oO(n,c[X>>2]|0)|0;Ya=G;Za=Ja}else{Ya=-2147483648;Za=0}Ja=c[Y>>2]|0;if((Ja|0)>0){oa=c[O>>2]|0;la=-oa|0;f=(c[M>>2]|0)-oa|0;if((Ja|0)<(la|0)){_a=la}else{_a=(f|0)<(Ja|0)?f:Ja}c[O>>2]=_a+oa}if((Va|0)!=0){oa=c[W>>2]|0;Ja=c[O>>2]|0;f=-Ja|0;la=(c[M>>2]|0)-Ja|0;if((oa|0)<(f|0)){$a=f}else{$a=(la|0)<(oa|0)?la:oa}c[O>>2]=$a+Ja}if(!((Xa|0)==0&(Wa|0)==(-2147483648|0))){c[H>>2]=Xa;c[H+4>>2]=Wa}if((Za|0)==0&(Ya|0)==(-2147483648|0)){break}c[F>>2]=Za;c[F+4>>2]=Ya}}while(0);ja=c[X>>2]|0;do{if((ja|0)!=0){va=c[aa>>2]|0;if((va|0)==0){break}_X(c[w>>2]|0,ja,1,va)}}while(0);ja=(c[O>>2]|0)+7>>3;va=(c[l>>2]|0)+ja|0;c[l>>2]=va;ab=ka-ja|0;bb=q+(ja+ra)|0;cb=c[J>>2]|0;db=va}else{ab=ka;bb=sa;cb=ta;db=qa}if((cb|0)==21&(ab|0)>4){c[l>>2]=db+5;eb=ab-5|0;fb=bb+5|0}else{eb=ab;fb=bb}if((c[(c[p>>2]|0)+48>>2]|0)==0){ma=eb;na=fb;break b}va=c[w>>2]|0;if((c[(c[va+8>>2]|0)+48>>2]|0)!=94215){ma=eb;na=fb;break b}ja=VX(c[ba>>2]|0,0,c[va>>2]|0)|0;if((ja|0)==0){ma=eb;na=fb;break b}else{gb=ja}d:while(1){ja=c[gb+32>>2]|0;do{if(!((ja|0)==-1)){if((c[gb+8>>2]|0)==48){break}va=c[(c[p>>2]|0)+8288+(ja<<2)>>2]|0;if((va|0)==0){break}if((c[va+12>>2]|0)!=0){break}wa=c[va+20>>2]|0;if((wa|0)==0){break}va=wa+408|0;hb=c[va>>2]|0;ib=c[va+4>>2]|0;if((hb|0)==(-1|0)&(ib|0)==(-1|0)){break}jb=c[wa+20>>2]|0;if((jb|0)==0){break}if((c[jb+76>>2]|0)!=48){break d}}}while(0);ja=VX(c[ba>>2]|0,gb,c[c[w>>2]>>2]|0)|0;if((ja|0)==0){ma=eb;na=fb;break b}else{gb=ja}}qa=Crc(hb,ib,300,0)|0;ta=G;sa=jb+464|0;ka=c[sa+4>>2]|0;ra=c[w>>2]|0;ja=ra+464|0;c[ja>>2]=c[sa>>2];c[ja+4>>2]=ka;c[ra+472>>2]=c[jb+472>>2];ra=c[H>>2]|0;ka=c[H+4>>2]|0;if((ra|0)==0&(ka|0)==(-2147483648|0)|((ka|0)<(ta|0)|(ka|0)==(ta|0)&ra>>>0<qa>>>0)){c[H>>2]=qa;c[H+4>>2]=ta;c[F>>2]=qa;c[F+4>>2]=ta;ma=eb;na=fb;break b}ja=wrc(qa,ta,12654,0)|0;ta=G;if(!((ka|0)>(ta|0)|(ka|0)==(ta|0)&ra>>>0>ja>>>0)){ma=eb;na=fb;break b}c[H>>2]=ja;c[H+4>>2]=ta;c[F>>2]=ja;c[F+4>>2]=ta;ma=eb;na=fb;break};default:{ma=e;na=q}}}while(0);if((ma|0)>0){q=na;e=ma}else{t=0;pa=135;break}}if((pa|0)==123){ma=c[A>>2]|0;if((ma|0)!=0){na=c[v>>2]|0;do{if((na|0)>0){if((na+e|0)<=(c[z>>2]|0)){kb=e;lb=ma;mb=na;break}kO(b,c[r>>2]|0);c[z>>2]=204800;fb=cGb(204816)|0;c[A>>2]=fb;if((fb|0)==0){t=-12;i=m;return t|0}else{c[ia>>2]=1;kb=e;lb=fb;mb=c[v>>2]|0;break}}else{if((na|0)!=0){kb=e;lb=ma;mb=na;break}fb=c[z>>2]|0;kb=(e|0)>(fb|0)?fb:e;lb=ma;mb=0}}while(0);nrc((c[lb+4>>2]|0)+mb|0,q|0,kb)|0;c[v>>2]=(c[v>>2]|0)+kb}if((c[ia>>2]|0)!=0){t=0;i=m;return t|0}kb=c[z>>2]|0;if((kb|0)>=204800){t=0;i=m;return t|0}if(((c[v>>2]|0)+(c[l>>2]|0)|0)!=(kb+6|0)){t=0;i=m;return t|0}c[ia>>2]=1;kO(b,c[r>>2]|0);t=0;i=m;return t|0}else if((pa|0)==135){i=m;return t|0}return 0}function nO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+8|0;g=f|0;c[g>>2]=e;e=a+8|0;h=c[e>>2]|0;j=c[h+8>>2]|0;k=c[h+48>>2]|0;if((a5a(h)|0)!=0){KIb(c[b+16>>2]|0,48,2413408,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;i=f;return}_X(a,33,1,9e4);h=b;c[a+12>>2]=h;m=c[e>>2]|0;c[m+8>>2]=2;c[m+48>>2]=0;c[a+236>>2]=1;c[b+20>>2]=a;m=b+8|0;c[m>>2]=d;n=b+16|0;o=b|0;p=c[o>>2]|0;KIb(c[n>>2]|0,48,2405760,(l=i,i=i+32|0,c[l>>2]=c[a>>2],c[l+8>>2]=d,c[l+16>>2]=p,c[l+24>>2]=g,l)|0);i=l;p=c[e>>2]|0;c[p+52>>2]=c[m>>2];d=c[m>>2]|0;a:do{if((a5a(p)|0)==0){q=2658696;while(1){r=c[q>>2]|0;if((r|0)==0){break a}if((r|0)==(d|0)){break}else{q=q+12|0}}r=c[e>>2]|0;c[r+8>>2]=c[q+4>>2];c[r+48>>2]=c[q+8>>2];c[a+440>>2]=0}else{KIb(0,48,2413408,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}}while(0);d=c[g>>2]|0;do{if((d|0)==1447904328|(d|0)==1380992072){g=c[e>>2]|0;if((c[g+48>>2]|0)!=0){break}p=c[m>>2]|0;b:do{if((a5a(g)|0)==0){r=2658968;while(1){s=c[r>>2]|0;if((s|0)==0){break b}if((s|0)==(p|0)){break}else{r=r+12|0}}s=c[e>>2]|0;c[s+8>>2]=c[r+4>>2];c[s+48>>2]=c[r+8>>2];c[a+440>>2]=0}else{KIb(0,48,2413408,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}}while(0);if((c[m>>2]|0)!=131){break}p=hJb(416)|0;if((p|0)==0){i=f;return}nrc(p|0,h|0,416)|0;g=ZX(c[n>>2]|0,0)|0;if((g|0)!=0){c[g+4>>2]=c[o>>2];_X(g,33,1,9e4);c[g+12>>2]=p;q=c[g+8>>2]|0;c[q+8>>2]=1;c[q+48>>2]=86019;c[g+236>>2]=1;c[b+24>>2]=g;c[p+24>>2]=g;break}kJb(p);i=f;return}}while(0);b=c[e>>2]|0;c:do{if((c[b+48>>2]|0)==0){o=c[m>>2]|0;if((a5a(b)|0)==0){t=2657056}else{KIb(0,48,2413408,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}while(1){n=c[t>>2]|0;if((n|0)==0){break c}if((n|0)==(o|0)){break}else{t=t+12|0}}o=c[e>>2]|0;c[o+8>>2]=c[t+4>>2];c[o+48>>2]=c[t+8>>2];c[a+440>>2]=0}}while(0);a=c[e>>2]|0;e=a+48|0;if((c[e>>2]|0)!=0){i=f;return}c[e>>2]=k;c[a+8>>2]=j;i=f;return}function oO(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=a+8|0;f=c[e>>2]|0;if(((c[a+12>>2]|0)-f|0)<(b|0)){g=-2147483648;h=0;return(G=g,h)|0}if((b|0)<33){do{if((b|0)==0){i=0}else{j=c[a+16>>2]|0;k=c[a>>2]|0;l=k+(f>>>3)|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(f&7);if((b|0)<26){l=f+b|0;c[e>>2]=j>>>0>l>>>0?l:j;i=m>>>((32-b|0)>>>0);break}else{l=f+16|0;n=j>>>0>l>>>0?l:j;c[e>>2]=n;l=b-16|0;o=k+(n>>>3)|0;k=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(n&7)>>>((48-b|0)>>>0);o=n+l|0;c[e>>2]=j>>>0>o>>>0?o:j;i=k|m>>>16<<l;break}}}while(0);g=0;h=i;return(G=g,h)|0}i=b-32|0;do{if((i|0)==0){p=0;q=f;r=c[a+16>>2]|0;s=c[a>>2]|0}else{l=c[a+16>>2]|0;m=c[a>>2]|0;k=m+(f>>>3)|0;j=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(f&7);if((i|0)<26){k=f+i|0;o=l>>>0>k>>>0?k:l;c[e>>2]=o;p=j>>>((64-b|0)>>>0);q=o;r=l;s=m;break}else{o=f+16|0;k=l>>>0>o>>>0?o:l;c[e>>2]=k;o=b-48|0;n=m+(k>>>3)|0;t=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7)>>>((80-b|0)>>>0);n=k+o|0;k=l>>>0>n>>>0?n:l;c[e>>2]=k;p=t|j>>>16<<o;q=k;r=l;s=m;break}}}while(0);b=s+(q>>>3)|0;f=(je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(q&7)&-65536;b=q+16|0;q=r>>>0>b>>>0?b:r;c[e>>2]=q;b=s+(q>>>3)|0;s=(je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(q&7)>>>16;b=q+16|0;c[e>>2]=r>>>0>b>>>0?b:r;g=p|0;h=s|f|0;return(G=g,h)|0}function pO(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;g=i;i=i+1256|0;h=g|0;j=g+160|0;k=g+168|0;l=c[b+36>>2]|0;b=l;mrc(k|0,0,1088)|0;m=f-4|0;f=e+m|0;c[j>>2]=e;if((m|0)<=0){i=g;return}n=a[e]|0;o=e+3|0;c[j>>2]=o;if((m|0)<=4){i=g;return}p=o;o=(d[p]|d[p+1|0]<<8)<<16>>16;c[j>>2]=e+5;p=he(o|0)|0;if((m|0)<=5){i=g;return}c[j>>2]=e+6;if((m|0)<=6){i=g;return}c[j>>2]=e+7;if((m|0)<=7){i=g;return}o=e+8|0;c[j>>2]=o;if(!(n<<24>>24==2)){i=g;return}n=p&65535;p=l+4|0;q=c[p>>2]|0;r=c[q+1104>>2]|0;s=q+1108|0;q=0;while(1){if(!(q>>>0<r>>>0)){break}t=c[(c[s>>2]|0)+(q<<2)>>2]|0;if((c[t>>2]|0)==(n|0)){u=10;break}else{q=q+1|0}}do{if((u|0)==10){if((t|0)==0){break}c[t+16>>2]=0}}while(0);t=l+88|0;q=c[t>>2]|0;if((q|0)==0){v=0}else{s=c[l+92>>2]|0;r=0;w=q;while(1){if((c[s+(r*268|0)>>2]|0)==(n|0)){c[s+(r*268|0)+4>>2]=0;c[s+(r*268|0)+264>>2]=0;x=c[t>>2]|0}else{x=w}q=r+1|0;if(q>>>0<x>>>0){r=q;w=x}else{v=x;break}}}if((m|0)<=9){i=g;return}x=o;o=(d[x]|d[x+1|0]<<8)<<16>>16;x=e+10|0;c[j>>2]=x;w=(he(o|0)|0)&8191;o=l+92|0;r=0;while(1){if(!(r>>>0<v>>>0)){break}y=c[o>>2]|0;z=y+(r*268|0)|0;if((c[z>>2]|0)==(n|0)){u=21;break}else{r=r+1|0}}do{if((u|0)==21){if((z|0)==0){break}v=y+(r*268|0)+4|0;s=c[v>>2]|0;if(s>>>0>63>>>0){break}c[v>>2]=s+1;c[y+(r*268|0)+8+(s<<2)>>2]=w}}while(0);r=c[p>>2]|0;y=c[r+1104>>2]|0;z=r+1108|0;r=0;while(1){if(!(r>>>0<y>>>0)){break}A=c[(c[z>>2]|0)+(r<<2)>>2]|0;if((c[A>>2]|0)==(n|0)){u=27;break}else{r=r+1|0}}if((u|0)==27){c[A+32>>2]=w}if((m|0)<=11){i=g;return}m=x;x=(d[m]|d[m+1|0]<<8)<<16>>16;m=e+12|0;c[j>>2]=m;e=(he(x|0)|0)&4095;a:do{if(e>>>0>1>>>0){x=h+8|0;A=h|0;r=h+152|0;z=h+144|0;y=h+136|0;s=h+140|0;v=h+148|0;q=0;B=e;C=0;D=m;while(1){if(D>>>0<f>>>0){E=D+1|0;F=d[D]|0;c[j>>2]=E;H=F;I=E}else{H=255;I=D}if(I>>>0<f>>>0){E=I+1|0;F=d[I]|0;c[j>>2]=E;J=F;K=E}else{J=-1;K=I}E=J&255;F=J&255;L=B-2|0;if((F|0)>(L|0)){M=q;N=B;O=C;P=K;break a}Q=L-F|0;do{if((H|0)==29){if(K>>>0<f>>>0){L=K+1|0;c[j>>2]=L;R=L}else{R=K}if(R>>>0<f>>>0){L=R+1|0;c[j>>2]=L;S=L}else{S=R}L=J+254|0;T=L&255;U=c[p>>2]|0;V=L&255;if(($C(x,S,V,0,0,0,0,0)|0)<0){W=T;X=C;Y=q;break}c[A>>2]=U;c[r>>2]=0;c[z>>2]=0;c[y>>2]=k+(q*68|0);c[s>>2]=0;c[v>>2]=16;U=fD(x,0,0,1)|0;qO(h,U,G,V,2)|0;W=T;X=C;Y=c[z>>2]|0}else if((H|0)==5){if(!(F>>>0>3>>>0)){W=E;X=C;Y=q;break}c[j>>2]=K+4;T=K;W=J+252&255;X=d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0;Y=q}else{W=E;X=C;Y=q}}while(0);E=(c[j>>2]|0)+(W&255)|0;c[j>>2]=E;if((Q|0)>1){q=Y;B=Q;C=X;D=E}else{M=Y;N=Q;O=X;P=E;break}}}else{M=0;N=e;O=0;P=m}}while(0);m=P+N|0;c[j>>2]=m;b:do{if(m>>>0<f>>>0){if((c[(c[p>>2]|0)+24>>2]|0)==0){c[l+68>>2]=2}N=c[t>>2]|0;P=0;while(1){if(!(P>>>0<N>>>0)){break}Z=c[o>>2]|0;_=Z+(P*268|0)|0;if((c[_>>2]|0)==(n|0)){u=52;break}else{P=P+1|0}}do{if((u|0)==52){if((_|0)==0){break}c[Z+(P*268|0)+264>>2]=1}}while(0);P=l+41056|0;N=l+8288|0;e=k|0;X=(O|0)==1447904328;Y=m;c:while(1){W=Y+1|0;J=a[Y]|0;K=J&255;c[j>>2]=W;if(!((Y+2|0)>>>0<f>>>0)){break b}H=W;W=(d[H]|d[H+1|0]<<8)<<16>>16;c[j>>2]=Y+3;H=(he(W|0)|0)&8191;if((H|0)==(c[P>>2]|0)){break b}W=c[N+(H<<2)>>2]|0;h=(W|0)==0;do{if(h){u=62}else{if((c[W+12>>2]|0)!=0){u=62;break}S=c[W+20>>2]|0;R=S;I=S+20|0;if((c[I>>2]|0)!=0){$=R;aa=I;u=79;break}D=ZX(c[S+16>>2]|0,0)|0;c[I>>2]=D;if((D|0)==0){break b}c[D+4>>2]=c[S>>2];$=R;aa=I;u=79}}while(0);do{if((u|0)==62){u=0;if(J<<24>>24==19){Q=oY(c[p>>2]|0,H)|0;I=c[p>>2]|0;if((Q|0)>-1){$=0;aa=(c[I+28>>2]|0)+(Q<<2)|0;u=79;break}Q=ZX(I,0)|0;if((Q|0)==0){break b}c[Q+4>>2]=H;c[(c[Q+8>>2]|0)+8>>2]=2;ba=0;ca=Q;da=0;break}if(!h){Q=c[W>>2]|0;I=c[W+12>>2]|0;do{if((I|0)==1){mJb(W+24|0)}else if((I|0)==0){R=W+20|0;S=R;fGb((c[S>>2]|0)+344|0);if((c[(c[S>>2]|0)+20>>2]|0)!=0){break}mJb(R)}}while(0);kJb(W);c[b+8288+(Q<<2)>>2]=0}ea=pJb(416)|0;if((ea|0)==0){break b}c[ea+12>>2]=b;I=ea+16|0;c[I>>2]=c[p>>2];R=ea;c[R>>2]=H;c[ea+4>>2]=w;c[ea+28>>2]=4;S=ea+56|0;c[S>>2]=0;c[S+4>>2]=-2147483648;S=ea+64|0;c[S>>2]=0;c[S+4>>2]=-2147483648;S=ea+408|0;c[S>>2]=-1;c[S+4>>2]=-1;S=b+8288+(H<<2)|0;if((c[S>>2]|0)!=0){break c}D=pJb(40)|0;if((D|0)==0){break c}c[S>>2]=D;c[D+12>>2]=0;c[D>>2]=H;c[D+4>>2]=-1;c[D+8>>2]=-1;c[D+16>>2]=2;c[D+20>>2]=ea;D=ZX(c[I>>2]|0,0)|0;if((D|0)==0){break b}c[D+4>>2]=c[R>>2];fa=D;ga=ea;u=80}}while(0);if((u|0)==79){u=0;W=c[aa>>2]|0;if((W|0)==0){break b}else{fa=W;ga=$;u=80}}do{if((u|0)==80){u=0;if((ga|0)==0){ba=0;ca=fa;da=0;break}if((c[ga+8>>2]|0)!=0){ba=ga;ca=fa;da=1;break}nO(fa,ga,K,O);ba=ga;ca=fa;da=1}}while(0);W=c[t>>2]|0;h=0;while(1){if(!(h>>>0<W>>>0)){break}ha=c[o>>2]|0;ia=ha+(h*268|0)|0;if((c[ia>>2]|0)==(n|0)){u=86;break}else{h=h+1|0}}do{if((u|0)==86){u=0;if((ia|0)==0){break}W=ha+(h*268|0)+4|0;D=c[W>>2]|0;if(D>>>0>63>>>0){break}c[W>>2]=D+1;c[ha+(h*268|0)+8+(D<<2)>>2]=H}}while(0);bY(c[p>>2]|0,n,c[ca>>2]|0);h=c[j>>2]|0;if(!((h+1|0)>>>0<f>>>0)){break b}D=h;W=(d[D]|d[D+1|0]<<8)<<16>>16;c[j>>2]=h+2;Y=h+(((he(W|0)|0)&4095)+2)|0;if(Y>>>0>f>>>0){break b}if((ZN(c[p>>2]|0,ca,K,j,Y,e,M,H,b)|0)>=0){W=da&X&J<<24>>24==-125;h=ba+24|0;D=ca+8|0;do{do{if(W){R=c[h>>2]|0;if((R|0)==0){break}bY(c[p>>2]|0,n,c[R>>2]|0);c[(c[(c[h>>2]|0)+8>>2]|0)+52>>2]=c[(c[D>>2]|0)+52>>2]}}while(0);}while((ZN(c[p>>2]|0,ca,K,j,Y,e,M,H,b)|0)>=0)}c[j>>2]=Y;if(!(Y>>>0<f>>>0)){break b}}kJb(ea)}}while(0);if((M|0)>0){ja=0}else{i=g;return}do{kJb(c[k+(ja*68|0)+8>>2]|0);ja=ja+1|0;}while((ja|0)<(M|0));i=g;return}function qO(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=a|0;l=a+8|0;m=HJ(c[k>>2]|0,l,j)|0;n=fD(l,0,0,1)|0;o=G;p=wrc(e,0,b,d)|0;d=xrc(p,G,n,o)|0;p=d;do{if((p|0)>=0){if((m|0)>(p|0)|(m|0)<1){break}d=a+152|0;b=c[d>>2]|0;c[d>>2]=b+1;a:do{if((b|0)>3){KIb(c[k>>2]|0,16,2377552,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}else{e=c[j>>2]|0;if(!((f|0)==0|(e|0)==(f|0))){KIb(c[k>>2]|0,16,2372040,(q=i,i=i+16|0,c[q>>2]=e,c[q+8>>2]=f,q)|0);i=q;break}switch(e|0){case 1:{if((m|0)<2){break a}if(((HD(l)|0)&32|0)!=0){break a}e=fD(l,0,0,1)|0;r=G;s=xrc(wrc(m,0,n,o)|0,G,e,r)|0;if((s|0)>0){t=r;u=e;v=s}else{break a}while(1){if((qO(a,u,t,v,0)|0)<0){break a}s=fD(l,0,0,1)|0;e=G;r=wrc(v,0,u,t)|0;w=xrc(r,G,s,e)|0;r=w;if((r|0)>0){t=e;u=s;v=r}else{break}}break};case 4:{r=a+140|0;s=c[r>>2]|0;if((s|0)==0){break a}e=hJb(m)|0;c[(c[r>>2]|0)+8>>2]=e;e=c[s+8>>2]|0;if((e|0)==0){break a}c[s+4>>2]=m;AD(l,e,m)|0;break a;break};case 6:{e=c[a+140>>2]|0;if((e|0)==0){break a}if((zD(l)|0)!=0){RIb(c[k>>2]|0,2347616,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break a}s=zD(l)|0;c[e+12>>2]=s>>>7&1;c[e+16>>2]=s>>>6&1;c[e+20>>2]=s>>>5&1;c[e+24>>2]=s>>>3&1;c[e+28>>2]=s>>>2&1;c[e+32>>2]=s>>>1&1;c[e+36>>2]=JD(l)|0;JD(l)|0;s=zD(l)|0;r=e+40|0;c[r>>2]=s;if((s|0)>64){QIb(0,2359472,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[r>>2]=64;break a}else{c[e+44>>2]=zD(l)|0;c[e+48>>2]=zD(l)|0;c[e+52>>2]=zD(l)|0;r=HD(l)|0;c[e+56>>2]=r>>12;c[e+60>>2]=r>>>7&31;c[e+64>>2]=r>>>2&31;break a}break};case 2:{HD(l)|0;zD(l)|0;zD(l)|0;zD(l)|0;zD(l)|0;zD(l)|0;r=fD(l,0,0,1)|0;e=G;s=wrc(m,0,n,o)|0;w=xrc(s,G,r,e)|0;s=w;if((s|0)>0){x=e;y=r;z=s}else{break a}while(1){if((qO(a,y,x,z,0)|0)<0){break a}s=fD(l,0,0,1)|0;r=G;e=wrc(z,0,y,x)|0;w=xrc(e,G,s,r)|0;e=w;if((e|0)>0){x=r;y=s;z=e}else{break}}break};case 3:{c[h>>2]=0;e=a+144|0;if((c[e>>2]|0)>=(c[a+148>>2]|0)){break a}IJ(l,h);s=c[a+136>>2]|0;r=c[e>>2]|0;c[e>>2]=r+1;e=s+(r*68|0)|0;r=a+140|0;c[r>>2]=e;c[e>>2]=c[h>>2];e=fD(l,0,0,1)|0;s=G;w=xrc(n,o,e,s)|0;A=wrc(w,G,m,0)|0;w=G;qO(a,e,s,A,4)|0;B=fD(l,0,0,1)|0;C=G;D=xrc(e,s,B,C)|0;s=wrc(D,G,A,w)|0;w=s;if((w|0)>0){qO(a,B,C,w,6)|0}c[r>>2]=0;break a;break};default:{break a}}}}while(0);c[d>>2]=(c[d>>2]|0)-1;b=wrc(n,o,m,(m|0)<0|0?-1:0)|0;fD(l,b,G,0)|0;E=0;i=g;return E|0}}while(0);KIb(c[k>>2]|0,16,2384608,(q=i,i=i+24|0,c[q>>2]=c[j>>2],c[q+8>>2]=m,c[q+16>>2]=p,q)|0);i=q;E=-1;i=g;return E|0}function rO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;b=i;d=c[a+12>>2]|0;e=a+1080|0;if((c[e>>2]|0)<0){c[e>>2]=0}f=d+84|0;g=(c[f>>2]|0)+197|0;c[f>>2]=-14-((g|0)%184|0)+g;c[d+64>>2]=c[d+88>>2];c[d+60>>2]=c[d+92>>2];g=a+1140|0;h=LGb(c[g>>2]|0,2492304,0,0)|0;if((h|0)==0){j=LGb(c[g>>2]|0,2482544,0,0)|0;if((j|0)==0){k=2471248}else{l=j;m=5}}else{l=h;m=5}if((m|0)==5){k=c[l+4>>2]|0}l=LGb(c[g>>2]|0,2463376,0,0)|0;if((l|0)==0){n=2448520}else{n=c[l+4>>2]|0}l=c[d+96>>2]|0;g=pJb(40)|0;if((g|0)==0){o=0}else{h=d+56|0;c[g>>2]=(c[h>>2]|0)+(c[d+100>>2]|0);c[g+16>>2]=l;c[g+24>>2]=rJb(n)|0;c[g+20>>2]=rJb(k)|0;c[g+28>>2]=8191;tJb(d+36|0,h,g);o=g}c[o+8>>2]=88;g=a;c[o+12>>2]=g;c[o+4>>2]=15;c[d+4>>2]=0;c[d+8>>2]=15;c[d+12>>2]=88;c[d+16>>2]=g;c[d+20>>2]=17;c[d+24>>2]=15;c[d+28>>2]=88;c[d+32>>2]=g;h=a+24|0;k=hJb(c[h>>2]<<2)|0;n=k;if((k|0)==0){p=-12;i=b;return p|0}a:do{if((c[h>>2]|0)==0){q=0;r=o+28|0}else{l=a+28|0;j=d+104|0;s=o|0;t=o+28|0;u=d+116|0;v=0;w=0;b:while(1){x=c[(c[l>>2]|0)+(v<<2)>>2]|0;_X(x,33,1,9e4);y=pJb(56)|0;if((y|0)==0){z=-12;break}c[x+12>>2]=y;A=pJb(c[f>>2]|0)|0;c[y+44>>2]=A;if((A|0)==0){z=-12;break}c[y>>2]=o;B=c[x+4>>2]|0;if((B|0)<16){A=(c[j>>2]|0)+v|0;c[y+4>>2]=A;C=A}else{if((B|0)>=8191){m=20;break}c[y+4>>2]=B;C=B}if((C|0)==(c[s>>2]|0)){m=22;break}else{D=0}while(1){if((D|0)>=(v|0)){break}if((c[n+(D<<2)>>2]|0)==(C|0)){m=25;break b}else{D=D+1|0}}c[n+(v<<2)>>2]=C;A=y+24|0;c[A>>2]=0;c[A+4>>2]=-2147483648;A=y+32|0;c[A>>2]=0;c[A+4>>2]=-2147483648;c[y+16>>2]=1;c[y+8>>2]=15;A=x+8|0;E=c[A>>2]|0;do{if((c[E+8>>2]|0)==0){if((c[t>>2]|0)!=8191){F=w;break}c[t>>2]=C;F=x}else{F=w}}while(0);do{if((c[E+48>>2]|0)==86018){if((c[E+100>>2]|0)<=0){break}x=HR()|0;H=y+48|0;c[H>>2]=x;if((x|0)==0){z=-12;break b}x=gH((c[u>>2]&2|0)!=0?2413400:2405752,0,0)|0;c[(c[H>>2]|0)+8>>2]=x;x=c[H>>2]|0;if((c[x+8>>2]|0)==0){z=-22;break b}I=c[(ZX(x,0)|0)+8>>2]|0;x=nWa(I,c[A>>2]|0)|0;if((x|0)!=0){z=x;break b}x=TO(c[H>>2]|0,0)|0;if((x|0)<0){z=x;break b}}}while(0);A=v+1|0;if(A>>>0<(c[h>>2]|0)>>>0){v=A;w=F}else{q=F;r=t;break a}}if((m|0)==20){KIb(g,16,2433064,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J;z=-22}else if((m|0)==22){KIb(g,16,2424296,(J=i,i=i+8|0,c[J>>2]=C,J)|0);i=J;z=-22}else if((m|0)==25){KIb(g,16,2424296,(J=i,i=i+8|0,c[J>>2]=C,J)|0);i=J;z=-22}kJb(k);if((c[h>>2]|0)==0){p=z;i=b;return p|0}else{K=0}while(1){t=(c[(c[l>>2]|0)+(K<<2)>>2]|0)+12|0;w=c[t>>2]|0;do{if((w|0)!=0){mJb(w+44|0);v=w+48|0;u=c[v>>2]|0;if((u|0)==0){break}pX(u);c[v>>2]=0}}while(0);mJb(t);w=K+1|0;if(w>>>0<(c[h>>2]|0)>>>0){K=w}else{p=z;break}}i=b;return p|0}}while(0);kJb(k);do{if((c[r>>2]|0)==8191){if((c[h>>2]|0)==0){L=q;break}k=c[c[a+28>>2]>>2]|0;c[r>>2]=c[(c[k+12>>2]|0)+4>>2];L=k}else{L=q}}while(0);q=d+80|0;r=c[q>>2]|0;do{if((r|0)>1){c[o+36>>2]=(r*20|0|0)/1504e3|0;h=c[q>>2]|0;c[d+44>>2]=(h*500|0|0)/1504e3|0;c[d+52>>2]=(h*100|0|0)/1504e3|0;if((c[d+120>>2]|0)>=1){break}h=c[e>>2]|0;k=VIb(h,(h|0)<0|0?-1:0,27e6,0,1e6,0)|0;h=d+72|0;c[h>>2]=k;c[h+4>>2]=G}else{c[d+44>>2]=200;c[d+52>>2]=40;h=L+8|0;k=c[h>>2]|0;do{if((c[k+8>>2]|0)==1){z=c[k+424>>2]|0;if((z|0)==0){KIb(g,24,2398312,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=(c[(c[h>>2]|0)+412>>2]|0)/5120|0;c[o+36>>2]=K;M=K;break}else{K=(c[k+412>>2]|0)/(z*10|0|0)|0;c[o+36>>2]=K;M=K;break}}else{K=(c[k+108>>2]|0)/((c[k+104>>2]|0)*10|0|0)|0;c[o+36>>2]=K;M=K}}while(0);if((M|0)!=0){break}c[o+36>>2]=1}}while(0);M=o+36|0;c[o+32>>2]=c[M>>2];o=d+52|0;c[d+48>>2]=(c[o>>2]|0)-1;L=d+44|0;c[d+40>>2]=(c[L>>2]|0)-1;e=c[q>>2]|0;if((e|0)==1){KIb(g,40,2391312,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}else{KIb(g,40,2384584,(J=i,i=i+8|0,c[J>>2]=e,J)|0);i=J}e=c[L>>2]|0;L=c[o>>2]|0;KIb(g,40,2377496,(J=i,i=i+24|0,c[J>>2]=c[M>>2],c[J+8>>2]=e,c[J+16>>2]=L,J)|0);i=J;J=d+108|0;do{if((c[J>>2]|0)==-1){if((fH(a+32|0,2372032)|0)==0){c[J>>2]=0;break}else{c[J>>2]=1;break}}}while(0);eD(c[a+16>>2]|0);p=0;i=b;return p|0}function sO(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;f=i;i=i+96|0;g=f|0;h=f+8|0;j=f+16|0;if((e|0)==0){k=b+24|0;l=c[k>>2]|0;if((l|0)!=0){m=b+28|0;n=0;o=l;while(1){l=c[(c[m>>2]|0)+(n<<2)>>2]|0;p=c[l+12>>2]|0;q=p+12|0;r=c[q>>2]|0;if((r|0)>0){s=p+24|0;t=p+32|0;uO(b,l,c[p+44>>2]|0,r,c[s>>2]|0,c[s+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0,c[p+40>>2]&1);c[q>>2]=0;u=c[k>>2]|0}else{u=o}q=n+1|0;if(q>>>0<u>>>0){n=q;o=u}else{break}}}eD(c[b+16>>2]|0);v=1;i=f;return v|0}u=b+28|0;o=c[(c[u>>2]|0)+(c[e+32>>2]<<2)>>2]|0;n=e+28|0;k=c[n>>2]|0;m=e+24|0;q=c[m>>2]|0;c[g>>2]=0;p=c[b+12>>2]|0;t=c[o+12>>2]|0;s=c[b+1080>>2]|0;r=VIb(s,(s|0)<0|0?-1:0,9e4,0,1e6,0)|0;s=G;l=r<<1|0>>>31;w=s<<1|r>>>31;x=e+16|0;z=c[x>>2]|0;A=c[x+4>>2]|0;B=e+8|0;C=c[B>>2]|0;D=c[B+4>>2]|0;B=p+112|0;if((c[B>>2]|0)==0){E=c[p+116>>2]|0}else{KIb(b,24,2624280,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;c[B>>2]=0;B=p+116|0;H=c[B>>2]|1;c[B>>2]=H;E=H}if((E&1|0)!=0){c[p+48>>2]=(c[p+52>>2]|0)-1;c[p+40>>2]=(c[p+44>>2]|0)-1;c[p+116>>2]=E&-2}if((c[p+120>>2]|0)<1){E=(C|0)==0&(D|0)==(-2147483648|0);H=wrc(C,D,l,w)|0;B=E?-2147483648:G;I=(z|0)==0&(A|0)==(-2147483648|0);J=wrc(z,A,l,w)|0;K=B;L=E?0:H;M=I?-2147483648:G;N=I?0:J}else{K=D;L=C;M=A;N=z}z=t+16|0;if((c[z>>2]|0)!=0&((L|0)==0&(K|0)==(-2147483648|0))){KIb(b,16,2598232,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;v=-1094995529;i=f;return v|0}c[z>>2]=0;z=o+8|0;A=c[(c[z>>2]|0)+48>>2]|0;do{if((A|0)==86018){if((c[n>>2]|0)<2){KIb(b,16,2537304,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;v=-1094995529;i=f;return v|0}C=c[m>>2]|0;if(((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&-16)<<16>>16==-16){O=k;P=q;break}C=t+48|0;if((c[C>>2]|0)==0){KIb(b,16,2521184,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;v=-1094995529;i=f;return v|0}J1(j);c[j+24>>2]=c[m>>2];c[j+28>>2]=c[n>>2];if((_D((c[C>>2]|0)+16|0)|0)<0){v=-12;i=f;return v|0}D=UO(c[C>>2]|0,j)|0;J=aE(c[(c[C>>2]|0)+16>>2]|0,g)|0;c[(c[C>>2]|0)+16>>2]=0;C=c[g>>2]|0;if((D|0)>=0){O=J;P=C;break}kJb(C);v=D;i=f;return v|0}else if((A|0)==28){D=q+k|0;c[h>>2]=-1;if((c[n>>2]|0)<5){Q=20}else{C=c[m>>2]|0;if((d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)==16777216){R=q}else{Q=20}}do{if((Q|0)==20){C=o+64|0;J=b;if(!((c[C>>2]|0)==0&(c[C+4>>2]|0)==0)){KIb(J,24,2555048,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;R=q;break}KIb(J,16,2573536,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;v=-22;i=f;return v|0}}while(0);do{R=U5a(R,D,h)|0;S=c[h>>2]&31;if(!(R>>>0<D>>>0)){break}}while(!((S|0)==9|(S|0)==5|(S|0)==1));if((S|0)==9){O=k;P=q;break}D=hJb((c[n>>2]|0)+6|0)|0;c[g>>2]=D;if((D|0)==0){v=-12;i=f;return v|0}else{J=c[n>>2]|0;nrc(D+6|0,c[m>>2]|0,J)|0;C=D;y=16777216;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;a[D+4|0]=9;a[D+5|0]=-16;O=J+6|0;P=D;break}}else{O=k;P=q}}while(0);do{if(!((c[x>>2]|0)==0&(c[x+4>>2]|0)==(-2147483648|0))){q=b+24|0;k=c[q>>2]|0;if((k|0)==0){break}else{T=0;U=k}while(1){k=c[(c[u>>2]|0)+(T<<2)>>2]|0;m=c[k+12>>2]|0;n=m+12|0;S=c[n>>2]|0;do{if((S|0)==0){V=U}else{R=m+32|0;h=c[R>>2]|0;Q=c[R+4>>2]|0;if(!((h|0)==0&(Q|0)==(-2147483648|0))){R=xrc(N,M,h,Q)|0;A=G;if(!((A|0)>(s|0)|(A|0)==(s|0)&R>>>0>r>>>0)){V=U;break}}R=m+24|0;uO(b,k,c[m+44>>2]|0,S,c[R>>2]|0,c[R+4>>2]|0,h,Q,c[m+40>>2]&1);c[n>>2]=0;V=c[q>>2]|0}}while(0);n=T+1|0;if(n>>>0<V>>>0){T=n;U=V}else{break}}}}while(0);V=t+12|0;U=c[V>>2]|0;do{if((U|0)==0){W=0}else{if((U+O|0)<=(c[p+84>>2]|0)){W=U;break}T=t+24|0;r=t+32|0;uO(b,o,c[t+44>>2]|0,U,c[T>>2]|0,c[T+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0,c[t+40>>2]&1);c[V>>2]=0;W=0}}while(0);do{if((c[(c[z>>2]|0)+8>>2]|0)==1){if((O|0)>(c[p+84>>2]|0)){break}if((W|0)==0){U=t+24|0;c[U>>2]=L;c[U+4>>2]=K;U=t+32|0;c[U>>2]=N;c[U+4>>2]=M;c[t+40>>2]=c[e+36>>2]}nrc((c[t+44>>2]|0)+W|0,P|0,O)|0;c[V>>2]=(c[V>>2]|0)+O;kJb(c[g>>2]|0);v=0;i=f;return v|0}}while(0);if((W|0)!=0){KIb(0,0,2215808,(F=i,i=i+24|0,c[F>>2]=2506712,c[F+8>>2]=2154168,c[F+16>>2]=1286,F)|0);i=F;Hd();return 0}uO(b,o,P,O,L,K,N,M,c[e+36>>2]&1);kJb(c[g>>2]|0);v=0;i=f;return v|0}function tO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[a+12>>2]|0;d=a+24|0;e=c[d>>2]|0;if((e|0)!=0){f=a+28|0;g=0;h=e;while(1){e=c[(c[f>>2]|0)+(g<<2)>>2]|0;i=c[e+12>>2]|0;j=i+12|0;k=c[j>>2]|0;if((k|0)>0){l=i+24|0;m=i+32|0;uO(a,e,c[i+44>>2]|0,k,c[l>>2]|0,c[l+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0,c[i+40>>2]&1);c[j>>2]=0;n=c[d>>2]|0}else{n=h}j=g+1|0;if(j>>>0<n>>>0){g=j;h=n}else{break}}}eD(c[a+16>>2]|0);if((c[d>>2]|0)!=0){n=a+28|0;a=0;do{h=c[(c[(c[n>>2]|0)+(a<<2)>>2]|0)+12>>2]|0;mJb(h+44|0);g=h+48|0;h=c[g>>2]|0;if((h|0)!=0){pX(h);c[g>>2]=0}a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0)}d=b+56|0;a=b+36|0;b=c[a>>2]|0;if((c[d>>2]|0)>0){o=0;p=b}else{q=b;r=q;kJb(r);return 0}while(1){b=c[p+(o<<2)>>2]|0;mJb(b+24|0);mJb(b+20|0);kJb(b);b=o+1|0;n=c[a>>2]|0;if((b|0)<(c[d>>2]|0)){o=b;p=n}else{q=n;break}}r=q;kJb(r);return 0}function uO(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0;n=i;i=i+1424|0;o=n|0;p=n+8|0;q=n+16|0;r=n+24|0;s=n+216|0;t=n+1232|0;u=e+12|0;v=c[u>>2]|0;w=b+12|0;x=c[w>>2]|0;z=c[b+1080>>2]|0;A=VIb(z,(z|0)<0|0?-1:0,9e4,0,1e6,0)|0;z=G;B=e+8|0;e=(m|0)==0;if((c[(c[B>>2]|0)+8>>2]|0)!=0|e){C=0}else{C=(c[v+20>>2]|0)==0|0}if((g|0)<=0){D=b+16|0;E=c[D>>2]|0;eD(E);F=v+20|0;H=F;c[H>>2]=m;i=n;return}I=s|0;J=s+1|0;K=s+2|0;L=s+3|0;M=s;N=v+4|0;O=v;P=x+80|0;Q=(k|0)==0&(l|0)==(-2147483648|0);R=b+16|0;S=x+72|0;T=r|0;U=r+1|0;V=r+2|0;W=r+3|0;X=r+4|0;Y=p;Z=r+5|0;_=r+6|0;$=r+7|0;aa=r+8|0;ba=r+9|0;ca=r+10|0;da=r+11|0;ea=r+12|0;r=q;fa=s+4|0;s=b+24|0;ga=b+28|0;ha=M+1012|0;ia=t|0;ja=t+1|0;ka=t+2|0;la=t+3|0;ma=v+8|0;na=t+4|0;oa=(h|0)==0&(j|0)==(-2147483648|0);pa=x+108|0;x=(h|0)!=0|(j|0)!=(-2147483648|0);qa=x?5:0;ra=x?128:0;sa=Q|x^1|(k|0)==(h|0)&(l|0)==(j|0);ta=((h>>>30|j<<2)<<1|0>>>31)&14;ua=(h>>>22|j<<10)&255;va=((h>>>15|j<<17)<<1|0>>>31|1)&255;wa=(h>>>7|j<<25)&255;j=(h<<1|0>>>31|1)&255;h=(((k>>>30|l<<2)<<1|0>>>31)&14|17)&255;xa=(k>>>22|l<<10)&255;ya=((k>>>15|l<<17)<<1|0>>>31|1)&255;za=(k>>>7|l<<25)&255;Aa=(k<<1|0>>>31|1)&255;Ba=qa+5|0;Ca=ra|64;Da=t;Ea=t+5|0;Fa=t+6|0;Ga=t+187|0;Ha=o;Ia=b;b=xrc(k,l,A,z)|0;Ja=Erc(b,G,300,0)|0;b=G;Ka=1;La=0;Ma=g;g=f;f=C;while(1){C=(Ka|0)==0;Na=f;while(1){Oa=c[w>>2]|0;Pa=Oa+40|0;Qa=(c[Pa>>2]|0)+1|0;c[Pa>>2]=Qa;if((Qa|0)==(c[Oa+44>>2]|0)){c[Pa>>2]=0;Pa=c[Oa+60>>2]|0;a[I]=Pa>>>8;a[J]=Pa;a[K]=-1;Pa=Oa+56|0;if((c[Pa>>2]|0)>0){Qa=Oa+36|0;Ra=L;Sa=0;while(1){Ta=c[(c[Qa>>2]|0)+(Sa<<2)>>2]|0;Ua=c[Ta+16>>2]|0;a[Ra]=Ua>>>8;a[Ra+1|0]=Ua;Ua=Ra+3|0;a[Ra+2|0]=-4;Va=Ra+6|0;a[Ra+5|0]=72;a[Ra+7|0]=1;Wa=c[Ta+24>>2]|0;if((Wa|0)==0){Xa=0}else{Xa=lrc(Wa|0)|0}a[Ra+8|0]=Xa;nrc(Ra+9|0,Wa|0,Xa)|0;Wa=c[Ta+20>>2]|0;if((Wa|0)==0){Ya=0}else{Ya=lrc(Wa|0)|0}Ta=Xa+10|0;a[Ra+(Xa+9)|0]=Ya;nrc(Ra+Ta|0,Wa|0,Ya)|0;Wa=Ra+(Ya+Ta)|0;Ta=Wa;a[Va]=255-Va+Ta;Va=Ta-Ua-2|0;a[Ua]=Va>>>8|128;a[Ra+4|0]=Va;Va=Sa+1|0;if((Va|0)<(c[Pa>>2]|0)){Ra=Wa;Sa=Va}else{Za=Wa;break}}}else{Za=L}vO(Oa+20|0,66,c[Oa+64>>2]|0,c[Oa+124>>2]|0,I,Za-M|0)}Sa=Oa+48|0;Ra=(c[Sa>>2]|0)+1|0;c[Sa>>2]=Ra;do{if(!((Ra|0)!=(c[Oa+52>>2]|0)&(Na|0)==0)){c[Sa>>2]=0;Pa=c[w>>2]|0;Qa=Pa+56|0;if((c[Qa>>2]|0)>0){Wa=Pa+36|0;Va=I;Ua=0;while(1){Ta=c[(c[Wa>>2]|0)+(Ua<<2)>>2]|0;_a=c[Ta+16>>2]|0;a[Va]=_a>>>8;a[Va+1|0]=_a;_a=c[Ta>>2]|0;a[Va+2|0]=_a>>>8|224;Ta=Va+4|0;a[Va+3|0]=_a;_a=Ua+1|0;if((_a|0)<(c[Qa>>2]|0)){Va=Ta;Ua=_a}else{$a=Ta;break}}}else{$a=I}vO(Pa+4|0,0,c[Pa+64>>2]|0,c[Pa+124>>2]|0,I,$a-M|0);Ua=Oa+56|0;if((c[Ua>>2]|0)<=0){break}Va=Oa+36|0;Qa=0;do{Wa=c[(c[Va>>2]|0)+(Qa<<2)>>2]|0;Ta=c[w>>2]|0;_a=c[Wa+28>>2]|0;a[I]=_a>>>8|224;a[J]=_a;a[K]=-16;a[L]=0;a:do{if((c[s>>2]|0)==0){ab=fa;bb=86}else{_a=Ta+116|0;cb=fa;db=0;while(1){eb=c[(c[ga>>2]|0)+(db<<2)>>2]|0;fb=c[eb+12>>2]|0;gb=LGb(c[eb+88>>2]|0,2106248,0,0)|0;hb=eb+8|0;ib=c[(c[hb>>2]|0)+48>>2]|0;if((ib|0)==117){jb=209}else if((ib|0)==13){jb=16}else if((ib|0)==86016|(ib|0)==86017){jb=3}else if((ib|0)==1|(ib|0)==2){jb=2}else if((ib|0)==86019){jb=129}else if((ib|0)==86018){jb=(c[_a>>2]&2)+15|0}else if((ib|0)==88){jb=66}else if((ib|0)==86066){jb=17}else if((ib|0)==28){jb=27}else{jb=6}if((cb-M|0)>>>0>980>>>0){break a}a[cb]=jb;ib=c[fb+4>>2]|0;a[cb+1|0]=ib>>>8|224;fb=cb+3|0;a[cb+2|0]=ib;ib=cb+5|0;kb=c[hb>>2]|0;lb=c[kb+8>>2]|0;b:do{if((lb|0)==1){mb=c[kb+48>>2]|0;if((mb|0)==86057){a[ib]=122;a[cb+6|0]=1;a[cb+7|0]=0;nb=cb+8|0;ob=c[(c[hb>>2]|0)+48>>2]|0}else{nb=ib;ob=mb}if((ob|0)==65562){a[nb]=5;a[nb+1|0]=4;a[nb+2|0]=66;a[nb+3|0]=83;a[nb+4|0]=83;a[nb+5|0]=68;pb=nb+6|0}else{pb=nb}if((gb|0)==0){qb=pb;break}mb=gb+4|0;rb=c[mb>>2]|0;sb=pb+1|0;a[pb]=10;tb=pb+2|0;a[sb]=0;c:do{if((rb|0)==0){ub=tb;vb=0}else{wb=eb+72|0;xb=tb;yb=c[mb>>2]|0;zb=0;while(1){if(!((zb&255)>>>0<252>>>0)){qb=xb;break b}if(!((xb-M|0)>>>0<1008>>>0)){ub=xb;vb=zb;break c}Ab=_b(yb|0,44)|0;if((lrc(yb|0)|0)==3){bb=47}else{if((Ab|0)!=0&(Ab|0)==(yb+3|0)){bb=47}else{Bb=xb;Cb=zb}}if((bb|0)==47){bb=0;a[xb]=a[yb]|0;a[xb+1|0]=a[yb+1|0]|0;Db=xb+3|0;a[xb+2|0]=a[yb+2|0]|0;Eb=c[wb>>2]|0;do{if((Eb&512|0)==0){if((Eb&128|0)!=0){a[Db]=2;Fb=xb+4|0;break}Gb=xb+4|0;if((Eb&256|0)==0){a[Db]=0;Fb=Gb;break}else{a[Db]=3;Fb=Gb;break}}else{a[Db]=1;Fb=xb+4|0}}while(0);Db=(a[sb]|0)+4&255;a[sb]=Db;Bb=Fb;Cb=Db}if((Ab|0)==0){ub=Bb;vb=Cb;break}else{xb=Bb;yb=Ab+1|0;zb=Cb}}}}while(0);qb=vb<<24>>24==0?ub-2|0:ub}else if((lb|0)==0){if((jb|0)!=209){qb=ib;break}a[ib]=5;a[cb+6|0]=4;a[cb+7|0]=100;a[cb+8|0]=114;a[cb+9|0]=97;a[cb+10|0]=99;qb=cb+11|0}else if((lb|0)==2){if((c[kb+48>>2]|0)!=1263294017){qb=ib;break}a[ib]=5;a[cb+6|0]=4;a[cb+7|0]=75;a[cb+8|0]=76;a[cb+9|0]=86;a[cb+10|0]=65;qb=cb+11|0}else if((lb|0)==3){if((gb|0)==0){Hb=794536}else{sb=c[gb+4>>2]|0;mb=(lrc(sb|0)|0)>>>0>2>>>0;Hb=mb?sb:794536}sb=c[kb+48>>2]|0;if((sb|0)==94215){mb=cb+6|0;a[ib]=86;tb=cb+7|0;d:do{if((lrc(Hb|0)|0)>>>0>2>>>0){rb=tb;zb=Hb;yb=0;while(1){xb=rb;wb=zb;while(1){if(!((xb-M|0)>>>0<1006>>>0)){Ib=xb;break d}a[xb]=a[wb]|0;a[xb+1|0]=a[wb+1|0]|0;Db=wb+3|0;Jb=xb+3|0;a[xb+2|0]=a[wb+2|0]|0;Kb=(a[Db]|0)==0?Db:wb+4|0;Lb=c[hb>>2]|0;if(((c[Lb+100>>2]|0)-1|0)>(yb|0)){break}a[Jb]=8;Db=xb+5|0;a[xb+4|0]=0;if((lrc(Kb|0)|0)>>>0>2>>>0){xb=Db;wb=Kb}else{Ib=Db;break d}}wb=(c[Lb+96>>2]|0)+yb|0;Ab=Jb;y=(d[wb]|d[wb+1|0]<<8)<<16>>16;a[Ab]=y;y=y>>8;a[Ab+1|0]=y;Ab=xb+5|0;if((lrc(Kb|0)|0)>>>0>2>>>0){rb=Ab;zb=Kb;yb=yb+2|0}else{Ib=Ab;break}}}else{Ib=tb}}while(0);a[mb]=255-mb+Ib;qb=Ib;break}else if((sb|0)!=94209){qb=ib;break}tb=cb+6|0;a[ib]=89;yb=cb+7|0;e:do{if((lrc(Hb|0)|0)>>>0>2>>>0){zb=eb+72|0;rb=yb;Ab=Hb;wb=0;while(1){f:do{if((wb|0)==0){Db=rb;Eb=Ab;while(1){if(!((ha-Db|0)>>>0>7>>>0)){Mb=Db;break e}a[Db]=a[Eb]|0;a[Db+1|0]=a[Eb+1|0]|0;Gb=Eb+3|0;Nb=Db+3|0;a[Db+2|0]=a[Eb+2|0]|0;Ob=(a[Gb]|0)==0?Gb:Eb+4|0;Gb=c[hb>>2]|0;if((c[Gb+100>>2]|0)>4){Pb=Db;Qb=Nb;Rb=Ob;Sb=Gb;bb=69;break f}Tb=Db+4|0;a[Nb]=((c[zb>>2]|0)>>>3&16)+16;Ub=c[hb>>2]|0;if((c[Ub+100>>2]|0)==4){break}a[Tb]=0;a[Db+5|0]=1;a[Db+6|0]=0;Nb=Db+8|0;a[Db+7|0]=1;if((lrc(Ob|0)|0)>>>0>2>>>0){Db=Nb;Eb=Ob}else{Mb=Nb;break e}}Eb=Tb;Nb=c[Ub+96>>2]|0;y=d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0;a[Eb]=y;y=y>>8;a[Eb+1|0]=y;y=y>>8;a[Eb+2|0]=y;y=y>>8;a[Eb+3|0]=y;Vb=4;Wb=Ob;Xb=Db}else{Eb=rb;Nb=Ab;while(1){if(!((ha-Eb|0)>>>0>7>>>0)){Mb=Eb;break e}a[Eb]=a[Nb]|0;a[Eb+1|0]=a[Nb+1|0]|0;Gb=Nb+3|0;Yb=Eb+3|0;a[Eb+2|0]=a[Nb+2|0]|0;Zb=(a[Gb]|0)==0?Gb:Nb+4|0;Gb=c[hb>>2]|0;if(((c[Gb+100>>2]|0)-wb|0)>4){Pb=Eb;Qb=Yb;Rb=Zb;Sb=Gb;bb=69;break f}a[Yb]=((c[zb>>2]|0)>>>3&16)+16;a[Eb+4|0]=0;a[Eb+5|0]=1;a[Eb+6|0]=0;Yb=Eb+8|0;a[Eb+7|0]=1;if((lrc(Zb|0)|0)>>>0>2>>>0){Eb=Yb;Nb=Zb}else{Mb=Yb;break e}}}}while(0);if((bb|0)==69){bb=0;a[Qb]=a[(c[Sb+96>>2]|0)+(wb+4)|0]|0;xb=(c[(c[hb>>2]|0)+96>>2]|0)+wb|0;Nb=Pb+4|0;y=d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0;a[Nb]=y;y=y>>8;a[Nb+1|0]=y;y=y>>8;a[Nb+2|0]=y;y=y>>8;a[Nb+3|0]=y;Vb=wb+5|0;Wb=Rb;Xb=Pb}Nb=Xb+8|0;if((lrc(Wb|0)|0)>>>0>2>>>0){rb=Nb;Ab=Wb;wb=Vb}else{Mb=Nb;break}}}else{Mb=yb}}while(0);a[tb]=255-tb+Mb;qb=Mb}else{qb=ib}}while(0);ib=qb-fb-2|0;a[fb]=ib>>>8|240;a[cb+4|0]=ib;ib=db+1|0;if(ib>>>0<(c[s>>2]|0)>>>0){cb=qb;db=ib}else{ab=qb;bb=86;break}}}}while(0);if((bb|0)==86){bb=0;vO(Wa|0,2,c[Wa+16>>2]|0,c[Ta+124>>2]|0,I,ab-M|0)}Qa=Qa+1|0;}while((Qa|0)<(c[Ua>>2]|0))}}while(0);Oa=c[O>>2]|0;do{if((c[N>>2]|0)==(c[Oa+28>>2]|0)){Sa=Oa+32|0;Ra=c[Sa>>2]|0;if((c[P>>2]|0)<2&C){$b=Ra}else{Ua=Ra+1|0;c[Sa>>2]=Ua;$b=Ua}if(($b|0)<(c[Oa+36>>2]|0)){ac=0;break}c[Oa+32>>2]=0;ac=1}else{ac=0}}while(0);if((c[P>>2]|0)<2|Q){break}Oa=fD(c[R>>2]|0,0,0,1)|0;Ua=wrc(Oa,G,11,0)|0;Oa=c[P>>2]|0;Sa=VIb(Ua,G,216e6,0,Oa,(Oa|0)<0|0?-1:0)|0;Oa=wrc(c[S>>2]|0,c[S+4>>2]|0,Sa,G)|0;Sa=Crc(Oa,G,300,0)|0;Oa=xrc(k,l,Sa,G)|0;Sa=G;if(!((Sa|0)>(z|0)|(Sa|0)==(z|0)&Oa>>>0>A>>>0)){break}if((ac|0)==0){a[T]=71;a[U]=31;a[V]=-1;a[W]=16;mrc(X|0,-1|0,184)|0;Oa=c[w>>2]|0;if((c[Oa+108>>2]|0)!=0){Sa=fD(c[R>>2]|0,0,0,1)|0;Ua=wrc(Sa,G,11,0)|0;Sa=c[Oa+80>>2]|0;Ra=VIb(Ua,G,216e6,0,Sa,(Sa|0)<0|0?-1:0)|0;Sa=Oa+72|0;Oa=wrc(c[Sa>>2]|0,c[Sa+4>>2]|0,Ra,G)|0;Ra=Drc(Oa,G,1073741823,0)|0;c[p>>2]=je(Ra|0)|0;dD(c[R>>2]|0,Y,4)}dD(c[R>>2]|0,T,188);Na=0;continue}else{Ra=c[u>>2]|0;Oa=c[w>>2]|0;a[T]=71;Sa=c[Ra+4>>2]|0;a[U]=Sa>>>8;a[V]=Sa;a[W]=c[Ra+8>>2]|32;a[X]=-73;a[Z]=16;Ra=fD(c[R>>2]|0,0,0,1)|0;Sa=wrc(Ra,G,11,0)|0;Ra=c[Oa+80>>2]|0;Ua=VIb(Sa,G,216e6,0,Ra,(Ra|0)<0|0?-1:0)|0;Ra=Oa+72|0;Oa=wrc(c[Ra>>2]|0,c[Ra+4>>2]|0,Ua,G)|0;Ua=G;Ra=Drc(Oa,Ua,300,0)|0;Sa=G;Qa=Crc(Oa,Ua,300,0)|0;Ua=G;a[_]=Qa>>>25|Ua<<7;a[$]=Qa>>>17|Ua<<15;a[aa]=Qa>>>9|Ua<<23;a[ba]=Qa>>>1|Ua<<31;a[ca]=Ra>>>8|Sa<<24|(Qa<<7|0>>>25)|126;a[da]=Ra;mrc(ea|0,-1|0,176)|0;Ra=c[w>>2]|0;if((c[Ra+108>>2]|0)!=0){Qa=fD(c[R>>2]|0,0,0,1)|0;Sa=wrc(Qa,G,11,0)|0;Qa=c[Ra+80>>2]|0;Ua=VIb(Sa,G,216e6,0,Qa,(Qa|0)<0|0?-1:0)|0;Qa=Ra+72|0;Ra=wrc(c[Qa>>2]|0,c[Qa+4>>2]|0,Ua,G)|0;Ua=Drc(Ra,G,1073741823,0)|0;c[q>>2]=je(Ua|0)|0;dD(c[R>>2]|0,r,4)}dD(c[R>>2]|0,T,188);Na=0;continue}}a[ia]=71;Na=c[N>>2]>>8;C=(Ka|0)!=0;if(C){bc=(Na|64)&255}else{bc=Na&255}a[ja]=bc;a[ka]=c[N>>2];Na=(c[ma>>2]|0)+1&15;c[ma>>2]=Na;Ua=(Na|16)&255;a[la]=Ua;do{if(e|C^1|oa){cc=na;dc=ac;ec=Ua}else{Na=(c[N>>2]|0)==(c[(c[O>>2]|0)+28>>2]|0)?1:ac;Ra=Ua|32;a[la]=Ra;a[na]=1;a[Ea]=64;if(0){cc=na;dc=Na;ec=Ra;break}cc=t+((d[na]|0)+5)|0;dc=Na;ec=Ra}}while(0);if((dc|0)==0){fc=cc}else{if((ec&32)==0){Ua=ec|32;a[la]=Ua;a[na]=1;a[Ea]=0;gc=16;hc=Ua}else{gc=a[Ea]|16;hc=ec}a[Ea]=gc;if((hc&32)==0){ic=na}else{ic=t+((d[na]|0)+5)|0}if((c[P>>2]|0)>1){Ua=fD(c[R>>2]|0,0,0,1)|0;Ra=wrc(Ua,G,11,0)|0;Ua=c[P>>2]|0;Na=VIb(Ra,G,216e6,0,Ua,(Ua|0)<0|0?-1:0)|0;Ua=wrc(c[S>>2]|0,c[S+4>>2]|0,Na,G)|0;jc=G;kc=Ua}else{jc=b;kc=Ja}Ua=Crc(kc,jc,300,0)|0;Na=G;if(((Na|0)>(l|0)|(Na|0)==(l|0)&Ua>>>0>k>>>0)&(Q^1)){KIb(Ia,24,2263224,(lc=i,i=i+1|0,i=i+7&-8,c[lc>>2]=0,lc)|0);i=lc}Ra=Drc(kc,jc,300,0)|0;a[ic]=Ua>>>25|Na<<7;a[ic+1|0]=Ua>>>17|Na<<15;a[ic+2|0]=Ua>>>9|Na<<23;a[ic+3|0]=Ua>>>1|Na<<31;a[ic+4|0]=Ra>>>8|G<<24|(Ua<<7|0>>>25)|126;a[ic+5|0]=Ra;if((a[la]&32)==0){bb=118;break}Ra=(a[na]|0)+6&255;a[na]=Ra;fc=t+((Ra&255)+5)|0}do{if(C){a[fc]=0;a[fc+1|0]=0;Ra=fc+3|0;a[fc+2|0]=1;Ua=c[B>>2]|0;Na=c[Ua+8>>2]|0;do{if((Na|0)==0){Qa=fc+4|0;if((c[Ua+48>>2]|0)==117){a[Ra]=-3;mc=Qa;nc=0;oc=0;break}else{a[Ra]=-32;mc=Qa;nc=0;oc=0;break}}else if((Na|0)==1){if(((c[Ua+48>>2]|0)-86016|0)>>>0<3>>>0){a[Ra]=-64;mc=fc+4|0;nc=0;oc=0;break}if((c[Ua+48>>2]|0)!=86019){bb=130;break}if((c[pa>>2]|0)==0){bb=130;break}a[Ra]=-3;mc=fc+4|0;nc=0;oc=0}else{bb=130}}while(0);do{if((bb|0)==130){bb=0;Ua=fc+4|0;a[Ra]=-67;Na=c[B>>2]|0;if((c[Na+8>>2]|0)!=3){mc=Ua;nc=0;oc=0;break}Qa=c[Na+48>>2]|0;if((Qa|0)==94209){mc=Ua;nc=0;oc=1;break}mc=Ua;nc=(Qa|0)==94215|0;oc=0}}while(0);Ra=sa?qa:Ba;Qa=sa?ra:Ca;Ua=c[B>>2]|0;Na=c[Ua+8>>2]|0;do{if((Na|0)==0){if((c[Ua+48>>2]|0)!=117){pc=0;qc=Qa;rc=Ra;break}pc=1;qc=Qa|1;rc=Ra+3|0}else{pc=0;qc=Qa;rc=Ra}}while(0);do{if((c[pa>>2]|0)!=0&(Na|0)==1){if((c[Ua+48>>2]|0)!=86019){sc=pc;tc=qc;uc=rc;break}sc=1;tc=qc|1;uc=rc+3|0}else{sc=pc;tc=qc;uc=rc}}while(0);Ua=(nc|0)!=0;Na=Ua?36:uc;Ra=Ua?36-uc|0:0;Qa=Na+Ma|0;Sa=(oc|0)!=0;if(Sa){vc=Ma+1|0;wc=Qa+6|0}else{vc=Ma;wc=Qa+3|0}Qa=(wc|0)>65535;a[mc]=Qa?0:wc>>>8&255;a[mc+1|0]=Qa?0:wc&255;a[mc+2|0]=((c[(c[B>>2]|0)+8>>2]|0)-2|0)>>>0<2>>>0?-124:-128;a[mc+3|0]=tc;Qa=mc+5|0;a[mc+4|0]=Na;if(x){a[Qa]=ta|tc>>6<<4|1;a[mc+6|0]=ua;a[mc+7|0]=va;a[mc+8|0]=wa;a[mc+9|0]=j;xc=mc+10|0}else{xc=Qa}if(sa){yc=xc}else{a[xc]=h;a[xc+1|0]=xa;a[xc+2|0]=ya;a[xc+3|0]=za;a[xc+4|0]=Aa;yc=xc+5|0}do{if((sc|0)==0){zc=yc}else{if((c[(c[B>>2]|0)+48>>2]|0)==117){a[yc]=1;a[yc+1|0]=-127;a[yc+2|0]=96;Ac=yc+3|0}else{Ac=yc}if((c[pa>>2]|0)==0){zc=Ac;break}if((c[(c[B>>2]|0)+48>>2]|0)!=86019){zc=Ac;break}a[Ac]=1;a[Ac+1|0]=-127;a[Ac+2|0]=113;zc=Ac+3|0}}while(0);if(Sa){a[zc]=32;a[zc+1|0]=0;Bc=zc+2|0}else{Bc=zc}if(!Ua){Cc=vc;Dc=Bc;Ec=oc;break}mrc(Bc|0,-1|0,Ra|0)|0;Cc=vc;Dc=Bc+Ra|0;Ec=oc}else{Cc=Ma;Dc=fc;Ec=La}}while(0);C=Dc-Da|0;Qa=188-C|0;Na=(Qa|0)>(Cc|0)?Cc:Qa;Oa=Qa-Na|0;do{if((Oa|0)>0){if(!((a[la]&32)==0)){Qa=d[na]|0;Va=Qa+5|0;Pa=t+Va|0;orc(t+(Va+Oa)|0,Pa|0,C-5-Qa|0)|0;a[na]=(d[na]|0)+Oa;mrc(Pa|0,-1|0,Oa|0)|0;break}orc(t+(Oa+4)|0,na|0,C-4|0)|0;a[la]=a[la]|32;a[na]=Oa+255;if((Oa|0)<=1){break}a[Ea]=0;mrc(Fa|0,-1|0,Oa-2|0)|0}}while(0);Oa=t+(188-Na)|0;if((Ec|0)!=0&(Cc|0)==(Na|0)){nrc(Oa|0,g|0,Cc-1|0)|0;a[Ga]=-1}else{nrc(Oa|0,g|0,Na)|0}Oa=Cc-Na|0;C=c[w>>2]|0;if((c[C+108>>2]|0)!=0){Pa=fD(c[R>>2]|0,0,0,1)|0;Qa=wrc(Pa,G,11,0)|0;Pa=c[C+80>>2]|0;Va=VIb(Qa,G,216e6,0,Pa,(Pa|0)<0|0?-1:0)|0;Pa=C+72|0;C=wrc(c[Pa>>2]|0,c[Pa+4>>2]|0,Va,G)|0;Va=Drc(C,G,1073741823,0)|0;c[o>>2]=je(Va|0)|0;dD(c[R>>2]|0,Ha,4)}dD(c[R>>2]|0,ia,188);if((Oa|0)>0){Ka=0;La=Ec;Ma=Oa;g=g+Na|0;f=0}else{D=R;bb=166;break}}if((bb|0)==118){KIb(0,0,2215808,(lc=i,i=i+24|0,c[lc>>2]=2182568,c[lc+8>>2]=2154168,c[lc+16>>2]=899,lc)|0);i=lc;Hd()}else if((bb|0)==166){E=c[D>>2]|0;eD(E);F=v+20|0;H=F;c[H>>2]=m;i=n;return}}function vO(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+1216|0;k=j|0;l=j+192|0;m=h+12|0;if(m>>>0>1024>>>0){i=j;return}n=l|0;a[n]=d;o=h+9|0;a[l+1|0]=(o|((d|0)==66?61440:45056))>>>8;a[l+2|0]=o;a[l+3|0]=e>>>8;a[l+4|0]=e;a[l+5|0]=f<<1|193;a[l+6|0]=0;a[l+7|0]=0;nrc(l+8|0,g|0,h)|0;g=k|0;f=h+8|0;e=je(EGb(DGb(3)|0,-1,n,f)|0)|0;a[l+f|0]=e>>>24;a[l+o|0]=e>>>16;a[l+(h+10)|0]=e>>>8;a[l+(h+11)|0]=e;if((m|0)<=0){i=j;return}e=k+1|0;h=b|0;l=k+2|0;o=k+3|0;f=b+4|0;d=k+4|0;p=k+5|0;q=k;k=b+8|0;r=n;s=m;while(1){a[g]=71;m=c[h>>2]|0;t=m>>8;if((r|0)==(n|0)){u=(t|64)&255;v=1}else{u=t&255;v=0}a[e]=u;a[l]=m;m=(c[f>>2]|0)+1&15;c[f>>2]=m;a[o]=m|16;if(v){a[d]=0;w=p}else{w=d}m=q-w+188|0;t=(m|0)>(s|0)?s:m;nrc(w|0,r|0,t)|0;m=w+t|0;x=q-m+188|0;if((x|0)>0){mrc(m|0,-1|0,x|0)|0}re[c[k>>2]&1023](b,g);x=s-t|0;if((x|0)>0){r=r+t|0;s=x}else{break}}i=j;return}function wO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=c[a+12>>2]|0;a=c[f+12>>2]|0;g=f+16|0;if((c[a+108>>2]|0)==0){h=c[g>>2]|0;dD(h,b,188);i=d;return}f=fD(c[g>>2]|0,0,0,1)|0;j=wrc(f,G,11,0)|0;f=c[a+80>>2]|0;k=VIb(j,G,216e6,0,f,(f|0)<0|0?-1:0)|0;f=a+72|0;a=wrc(c[f>>2]|0,c[f+4>>2]|0,k,G)|0;k=Drc(a,G,1073741823,0)|0;c[e>>2]=je(k|0)|0;dD(c[g>>2]|0,e,4);h=c[g>>2]|0;dD(h,b,188);i=d;return}function xO(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=c[b+8>>2]|0;if((e|0)<=0){f=0;return f|0}g=c[b+4>>2]|0;b=-256;h=0;i=0;j=0;k=0;l=0;m=0;n=0;o=0;p=0;q=0;while(1){r=d[g+p|0]|0|b;a:do{if((b|0)==256){b:do{if((r|0)==438){s=n+1|0;t=k;u=i;v=h;w=j;x=o}else if((r|0)==256){s=n;t=k;u=i;v=h+1|0;w=j;x=o}else if((r|0)==435){if((a[g+(p+7)|0]&32)==0){s=n;t=k;u=i;v=h;w=j;x=o;break}y=(a[g+(p+8)|0]&2)==0?p:p+64|0;if((y|0)>=(e|0)){s=n;t=k;u=i;v=h;w=j;x=o;break}z=(a[g+(y+8)|0]&1)==0?y:y+64|0;if((z|0)>=(e|0)){s=n;t=k;u=i;v=h;w=j;x=o;break}s=n;t=k;u=(((d[g+(z+10)|0]|0)<<8|(d[g+(z+9)|0]|0)<<16|a[g+(z+11)|0]&254|0)==0)+i|0;v=h;w=j;x=o}else if((r|0)==442){s=n;t=k+1|0;u=i;v=h;w=j;x=o}else{do{if((r-257|0)>>>0<175>>>0){if((q-257|0)>>>0<175>>>0){if(r>>>0<q>>>0){A=o+1|0;B=j;break}else{A=o;B=j+1|0;break}}else{if((r|0)==257){s=n;t=k;u=i;v=h;w=j+1|0;x=o;break b}else{A=o+1|0;B=j;break}}}else{A=o;B=j}}while(0);if((r&496|0)!=480){s=n;t=k;u=i;v=h;w=B;x=A;break}C=r;D=A;E=n;F=m;G=l+1|0;H=k;I=B;J=i;K=h;break a}}while(0);C=r;D=x;E=s;F=((r&480|0)==448)+m|0;G=l;H=t;I=w;J=u;K=v}else{C=q;D=o;E=n;F=m;G=l;H=k;I=j;J=i;K=h}}while(0);z=p+1|0;if((z|0)<(e|0)){b=r<<8;h=K;i=J;j=I;k=H;l=G;m=F;n=E;o=D;p=z;q=C}else{break}}if((J|0)==0){f=0;return f|0}if((J*9|0|0)>(K*10|0|0)){f=0;return f|0}if(!((K*9|0|0)<=(I*10|0|0)&(H|0)==0&(F|0)==0&(E|0)==0&(I|0)>(D|0))){f=0;return f|0}if((G|0)!=0){f=12;return f|0}f=(K|0)>1?51:25;return f|0}function yO(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+256|0;d=b|0;Rb(d|0,256,2129216,(e=i,i=i+8|0,c[e>>2]=2154024,e)|0)|0;i=e;e=a+16|0;a=c[e>>2]|0;dD(a,d,lrc(d|0)|0);eD(c[e>>2]|0);i=b;return 0}function zO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+256|0;e=d|0;Rb(e|0,256,2262976,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0)|0;i=f;g=a+16|0;a=c[g>>2]|0;dD(a,e,lrc(e|0)|0);a=b+28|0;Rb(e|0,256,2215592,(f=i,i=i+8|0,c[f>>2]=c[a>>2],f)|0)|0;i=f;h=c[g>>2]|0;dD(h,e,lrc(e|0)|0);dD(c[g>>2]|0,c[b+24>>2]|0,c[a>>2]|0);Rb(e|0,256,2182488,(f=i,i=i+8|0,c[f>>2]=2154024,f)|0)|0;i=f;f=c[g>>2]|0;dD(f,e,lrc(e|0)|0);i=d;return 0}function AO(a){a=a|0;return 0}function BO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=c[b+4>>2]|0;j=h+(c[b+8>>2]|0)|0;b=h;h=0;while(1){if((h|0)>=2){k=100;l=8;break}m=Bd(b|0,2182448,(n=i,i=i+24|0,c[n>>2]=f,c[n+8>>2]=g,c[n+16>>2]=e,n)|0)|0;i=n;if((m|0)!=3){m=Bd(b|0,2154008,(n=i,i=i+16|0,c[n>>2]=f,c[n+8>>2]=e,n)|0)|0;i=n;if((m|0)!=2){k=0;l=8;break}}m=mc(b|0,2315840)|0;n=a[b+m|0]|0;if(n<<24>>24==13){o=m+1|0;p=o;q=a[b+o|0]|0}else{p=m;q=n}n=b+((q<<24>>24==10)+p)|0;if(n>>>0<j>>>0){b=n;h=h+1|0}else{k=0;l=8;break}}if((l|0)==8){i=d;return k|0}return 0}function CO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+4128|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+4120|0;k=c[b+12>>2]|0;l=ZX(b,0)|0;if((l|0)==0){m=-12;i=d;return m|0}_X(l,64,1,10);n=c[l+8>>2]|0;c[n+8>>2]=3;c[n+48>>2]=1297108018;n=b+16|0;a:do{if((jD(c[n>>2]|0)|0)==0){b=h|0;l=k;while(1){o=fD(c[n>>2]|0,0,0,1)|0;p=G;if((KD(c[n>>2]|0,b,4096)|0)==0){q=l;break a}a[h+(mc(b|0,2315840)|0)|0]=0;r=Bd(b|0,2262912,(s=i,i=i+24|0,c[s>>2]=j,c[s+8>>2]=e,c[s+16>>2]=f,s)|0)|0;i=s;do{if((r|0)>1){t=-1;u=10}else{v=Bd(b|0,2215536,(s=i,i=i+32|0,c[s>>2]=j,c[s+8>>2]=g,c[s+16>>2]=e,c[s+24>>2]=f,s)|0)|0;i=s;if((v|0)<=2){break}v=xrc(c[g>>2]|0,c[g+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;t=v;u=10}}while(0);if((u|0)==10){u=0;s=h+((c[f>>2]|0)-1)|0;r=IV(l,s,lrc(s|0)|0,0)|0;if((r|0)==0){m=-12;break}s=r+64|0;c[s>>2]=o;c[s+4>>2]=p;s=c[j+4>>2]|0;v=r+8|0;c[v>>2]=c[j>>2];c[v+4>>2]=s;c[r+48>>2]=t}if((jD(c[n>>2]|0)|0)!=0){q=l;break a}}i=d;return m|0}else{q=k}}while(0);JV(q);m=0;i=d;return m|0}function DO(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function EO(a){a=a|0;OV(c[a+12>>2]|0);return 0}function FO(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function GO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[b+4>>2]|0;e=c[b+8>>2]|0;b=d+e|0;if((e|0)>0){f=d}else{g=0;return g|0}while(1){if((grc(f,2182432,11)|0)==0){g=50;h=8;break}if((grc(f,2154e3,7)|0)==0){g=16;h=8;break}d=mc(f|0,2315792)|0;e=a[f+d|0]|0;if(e<<24>>24==13){i=d+1|0;j=i;k=a[f+i|0]|0}else{j=d;k=e}e=(k<<24>>24==10)+j|0;if((e|0)==0){g=0;h=8;break}d=f+e|0;if(d>>>0<b>>>0){f=d}else{g=0;h=8;break}}if((h|0)==8){return g|0}return 0}function HO(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0.0,I=0.0,J=0,K=0;d=i;i=i+2072|0;e=d|0;f=d+1024|0;h=d+2048|0;j=d+2056|0;k=d+2064|0;l=c[b+12>>2]|0;SFb(e,0,-1);m=b+16|0;a:do{if((jD(c[m>>2]|0)|0)==0){n=f|0;o=e+4|0;p=l;q=e|0;r=0.0;s=100.0;t=100;while(1){u=s;v=t;b:while(1){while(1){if((KD(c[m>>2]|0,n,1024)|0)==0){w=v;x=13;break a}a[f+(mc(n|0,2315792)|0)|0]=0;y=Bd(n|0,2262896,(z=i,i=i+8|0,c[z>>2]=k,z)|0)|0;i=z;A=c[k>>2]|0;if((y|0)==1&(A|0)>3&(A|0)<100){break}y=Bd(n|0,2215528,(z=i,i=i+16|0,c[z>>2]=h,c[z+8>>2]=j,z)|0)|0;i=z;if((y|0)==2){B=fD(c[m>>2]|0,0,0,1)|0;C=G;RV(c[m>>2]|0,e);D=c[o>>2]|0;if((D|0)!=0){break b}}if((jD(c[m>>2]|0)|0)!=0){w=v;x=13;break a}}if((jD(c[m>>2]|0)|0)==0){u=1.0;v=A}else{w=A;x=13;break a}}y=IV(p,c[q>>2]|0,D,0)|0;if((y|0)==0){E=-12;break a}H=+g[h>>2];I=r+u*H;z=(F=+I,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);J=y+8|0;c[J>>2]=~~+I>>>0;c[J+4>>2]=z;I=+g[j>>2];c[y+48>>2]=~~(u*I);z=y+64|0;c[z>>2]=B;c[z+4>>2]=C;if((jD(c[m>>2]|0)|0)==0){r=r+u*(H+I);s=u;t=v}else{w=v;x=13;break}}}else{w=100;x=13}}while(0);do{if((x|0)==13){m=ZX(b,0)|0;if((m|0)==0){K=-12;i=d;return K|0}else{_X(m,64,1,w);C=c[m+8>>2]|0;c[C+8>>2]=3;c[C+48>>2]=94210;JV(l);E=0;break}}}while(0);_Fb(e,0)|0;K=E;i=d;return K|0}function IO(a,b){a=a|0;b=b|0;return MV(c[a+12>>2]|0,b)|0}function JO(a){a=a|0;OV(c[a+12>>2]|0);return 0}function KO(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return NV(c[a+12>>2]|0,a,b,d,e,f,g,h,i,j)|0}function LO(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+8>>2]|0;if((b|0)<24){e=-1;return e|0}f=c[a+4>>2]|0;a=0;a:while(1){g=f+a|0;do{if((d[g]|d[g+1|0]<<8)<<16>>16<<16>>16==24){h=f+(a+2)|0;i=(d[h]|d[h+1|0]<<8)<<16>>16&65535;h=f+(a+4)|0;j=(d[h]|d[h+1|0]<<8)<<16>>16;if((i|0)==320){if(!(j<<16>>16==240)){break}}else if((i|0)==160){if(!(j<<16>>16==120)){break}}else{break}j=f+(a+12)|0;if((d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)==808602701){break a}}}while(0);if((a+25|0)>(b|0)){e=-1;k=11;break}else{a=a+1|0}}if((k|0)==11){return e|0}if((a|0)==0){e=100;return e|0}e=(a|0)<14?50:33;return e|0}function MO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+16>>2]|0;e=ZX(a,0)|0;if((e|0)==0){f=-12;i=b;return f|0}g=c[e+8>>2]|0;c[g+8>>2]=0;c[g+48>>2]=114;c[g+52>>2]=808602701;_X(e,32,1,1e3);do{if((zD(d)|0)==24){break}}while((jD(d)|0)==0);if((jD(d)|0)==0){f=0;i=b;return f|0}KIb(a,16,2386864,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=-1;i=b;return f|0}function NO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+16>>2]|0;hD(d,1,0)|0;hD(d,2,0)|0;hD(d,2,0)|0;a=DD(d)|0;e=FD(d)|0;hD(d,4,0)|0;hD(d,4,0)|0;f=FD(d)|0;if((e|0)==0){g=-1;return g|0}if((fX(d,b,e)|0)!=(e|0)){g=-1;return g|0}hD(d,1,0)|0;d=f;f=0;h=b+8|0;c[h>>2]=d;c[h+4>>2]=f;h=b+16|0;c[h>>2]=d;c[h+4>>2]=f;c[b+32>>2]=0;if((a&1|0)!=0){a=b+36|0;c[a>>2]=c[a>>2]|1}g=e+24|0;return g|0}function OO(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[b+8>>2]|0;if((e|0)<57){f=0;return f|0}g=c[b+4>>2]|0;if((a[g]|0)!=65){f=0;return f|0}if((a[g+1|0]|0)!=77){f=0;return f|0}if((a[g+2|0]|0)!=86){f=0;return f|0}if((a[g+43|0]|0)!=77){f=0;return f|0}if((a[g+44|0]|0)!=80){f=0;return f|0}if((a[g+45|0]|0)!=51){f=0;return f|0}b=a[g+51|0]|0;if(b<<24>>24==0){f=0;return f|0}h=g+52|0;i=(d[h]|d[h+1|0]<<8)<<16>>16;h=g+54|0;j=(d[h]|d[h+1|0]<<8)<<16>>16;if((j|i)<<16>>16==0){f=0;return f|0}if(i<<16>>16==0|j<<16>>16==0){j=g+56|0;f=(d[j]|d[j+1|0]<<8)<<16>>16<<16>>16==0?0:50;return f|0}if(!(b<<24>>24==16)){f=25;return f|0}f=(e|0)<512?50:100;return f|0}function PO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=c[a+12>>2]|0;e=c[a+16>>2]|0;hD(e,3,0)|0;c[d>>2]=FD(e)|0;c[d+4>>2]=FD(e)|0;hD(e,32,0)|0;c[d+8>>2]=ED(e)|0;f=d+12|0;c[f>>2]=DD(e)|0;c[d+16>>2]=ED(e)|0;g=d+20|0;c[g>>2]=(zD(e)|0)>>3;h=d+24|0;c[h>>2]=DD(e)|0;j=d+28|0;c[j>>2]=DD(e)|0;k=d+32|0;c[k>>2]=DD(e)|0;l=c[g>>2]|0;if((l|0)!=16){KIb(a,24,2386816,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;c[g>>2]=16}g=c[h>>2]|0;l=c[j>>2]|0;n=(l|0)==0;do{if((g|0)==0){if(n){break}o=((c[k>>2]|0)>>>4>>>0)/(l>>>0)|0;c[h>>2]=o;if((o|0)!=0){p=8}}else{if(!n){p=8;break}o=((c[k>>2]|0)>>>4>>>0)/(g>>>0)|0;c[j>>2]=o;if((o|0)!=0){p=8}}}while(0);do{if((p|0)==8){if((c[k>>2]|0)==0){break}hD(e,4,0)|0;g=DD(e)|0;if((g|0)==0){QIb(a,2262864,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;q=-1163346256;i=b;return q|0}c[d+40>>2]=(c[k>>2]|0)+(g<<9);n=d+36|0;c[n>>2]=((c[f>>2]|0)>>>2>>>0)/(g>>>0)|0;g=ZX(a,0)|0;if((g|0)==0){q=-12;i=b;return q|0}_X(g,64,1,c[n>>2]|0);l=g+8|0;g=c[l>>2]|0;c[g+8>>2]=0;c[g+48>>2]=14;c[g+140>>2]=43;c[g+120>>2]=c[h>>2];c[g+124>>2]=c[j>>2];c[g+412>>2]=c[n>>2];n=rJb(2215504)|0;c[(c[l>>2]|0)+96>>2]=n;c[(c[l>>2]|0)+100>>2]=9;l=ZX(a,0)|0;if((l|0)==0){q=-12;i=b;return q|0}_X(l,64,1,44100);n=c[l+8>>2]|0;c[n+8>>2]=1;c[n+48>>2]=86017;c[n+72>>2]=c[f>>2];c[l+236>>2]=1;l=fD(e,512,0,0)|0;q=(l|0)==512&(G|0)==0?0:-5;i=b;return q|0}}while(0);KIb(a,16,2315640,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;q=-22;i=b;return q|0}function QO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=fD(e,0,0,1)|0;g=a+1248|0;a=xrc(f,G,c[g>>2]|0,c[g+4>>2]|0)|0;g=c[d+32>>2]|0;f=wrc(a,G,g,0)|0;a=Drc(f,G,c[d+40>>2]|0,0)|0;if((a|0)==0&(G|0)==0){a=fX(e,b,g)|0;if((a|0)<0){h=a;return h|0}c[b+32>>2]=0;h=a;return h|0}else{hD(e,12,0)|0;a=fX(e,b,500)|0;if((a|0)<0){h=a;return h|0}e=b+64|0;g=wrc(c[e>>2]|0,c[e+4>>2]|0,-12,-1)|0;c[e>>2]=g;c[e+4>>2]=G;c[b+32>>2]=1;h=a;return h|0}return 0}function RO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[d+8>>2]|0;if((c[b+8>>2]|0)==1){f=b+412|0;g=1}else{f=b+108|0;g=c[b+104>>2]|0}b=c[f>>2]|0;a:do{if(((b|0)/(g|0)|0|0)<(e|0)){f=g;while(1){if((f&1|0)!=0){h=f;break a}d=(f|0)/2|0;if(((b|0)/(d|0)|0|0)<(e|0)){f=d}else{h=d;break}}}else{h=g}}while(0);b:do{if(((b|0)/(h|0)|0|0)<(e|0)){g=h;while(1){if(((g|0)%3|0|0)!=0){i=g;break b}f=(g|0)/3|0;if(((b|0)/(f|0)|0|0)<(e|0)){g=f}else{i=f;break}}}else{i=h}}while(0);c:do{if(((b|0)/(i|0)|0|0)<(e|0)){h=i;while(1){if(((h|0)%5|0|0)!=0){j=h;break c}g=(h|0)/5|0;if(((b|0)/(g|0)|0|0)<(e|0)){h=g}else{j=g;break}}}else{j=i}}while(0);d:do{if(((b|0)/(j|0)|0|0)<(e|0)){i=j;while(1){if(((i|0)%7|0|0)!=0){k=i;break d}h=(i|0)/7|0;if(((b|0)/(h|0)|0|0)<(e|0)){i=h}else{k=h;break}}}else{k=j}}while(0);e:do{if(((b|0)/(k|0)|0|0)<(e|0)){j=k;while(1){if(((j|0)%9|0|0)!=0){l=j;break e}i=(j|0)/9|0;if(((b|0)/(i|0)|0|0)<(e|0)){j=i}else{l=i;break}}}else{l=k}}while(0);f:do{if(((b|0)/(l|0)|0|0)<(e|0)){k=l;while(1){if(((k|0)%11|0|0)!=0){m=k;break f}j=(k|0)/11|0;if(((b|0)/(j|0)|0|0)<(e|0)){k=j}else{m=j;break}}}else{m=l}}while(0);g:do{if(((b|0)/(m|0)|0|0)<(e|0)){l=m;while(1){if(((l|0)%13|0|0)!=0){n=l;break g}k=(l|0)/13|0;if(((b|0)/(k|0)|0|0)<(e|0)){l=k}else{n=k;break}}}else{n=m}}while(0);m=b;while(1){if(((m|0)/(n|0)|0|0)<(e|0)&(m|0)<16777216){m=m<<1}else{break}}c[a>>2]=n;c[a+4>>2]=m;return}function SO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=HR()|0;c[a>>2]=0;a:do{if((g|0)==0){h=16}else{do{if((b|0)==0){if((d|0)==0){j=gH(0,e,0)|0;if((j|0)!=0){k=j;break}KIb(g,16,2485912,(l=i,i=i+8|0,c[l>>2]=e,l)|0);i=l;m=-22;break a}else{j=gH(d,0,0)|0;if((j|0)!=0){k=j;break}KIb(g,16,2137320,(l=i,i=i+8|0,c[l>>2]=d,l)|0);i=l;m=-22;break a}}else{k=b}}while(0);j=g+8|0;c[j>>2]=k;n=c[k+44>>2]|0;do{if((n|0)>0){o=pJb(n)|0;p=g+12|0;c[p>>2]=o;if((o|0)==0){h=16;break a}q=c[(c[j>>2]|0)+36>>2]|0;if((q|0)==0){break}c[o>>2]=q;SJb(c[p>>2]|0)}else{c[g+12>>2]=0}}while(0);if((e|0)!=0){CFb(g+32|0,e,1024)|0}c[a>>2]=g;r=0;i=f;return r|0}}while(0);if((h|0)==16){KIb(g,16,2386792,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-12}pX(g);r=m;i=f;return r|0}function TO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=i;i=i+72|0;e=d|0;f=d+8|0;g=d+40|0;c[e>>2]=0;h=a+8|0;j=c[h>>2]|0;k=(b|0)!=0;if(k){PGb(e,c[b>>2]|0,0)}l=a;m=XJb(l,e)|0;a:do{if((m|0)<0){n=m;o=60}else{p=a+12|0;q=c[p>>2]|0;do{if((q|0)!=0){r=c[(c[h>>2]|0)+36>>2]|0;if((r|0)==0){break}if((c[q>>2]|0)!=(r|0)){break}r=XJb(q,e)|0;if((r|0)<0){n=r;o=60;break a}}}while(0);q=a+24|0;b:do{if((c[q>>2]|0)==0){if((c[j+28>>2]&4096|0)!=0){break}KIb(l,16,2506584,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;o=60;break a}else{r=a+28|0;t=j+32|0;u=j+28|0;v=a+1296|0;w=0;c:while(1){x=c[(c[r>>2]|0)+(w<<2)>>2]|0;y=c[x+8>>2]|0;z=y+8|0;A=c[z>>2]|0;d:do{if((A|0)==0){if((c[y+104>>2]|0)<1){o=19;break c}if((c[y+108>>2]|0)<1){o=19;break c}if((c[y+120>>2]|0)<1){o=22}else{if((c[y+124>>2]|0)<1){o=22}}if((o|0)==22){o=0;if((c[u>>2]&2048|0)==0){o=23;break c}}B=c[x+80>>2]|0;C=c[x+84>>2]|0;D=c[y+224>>2]|0;E=c[y+228>>2]|0;F=Erc(E,(E|0)<0|0?-1:0,B,(B|0)<0|0?-1:0)|0;H=G;I=Erc(D,(D|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;do{if((F|0)==(I|0)&(H|0)==(G|0)){if(!((E|0)==0|(C|0)==0)){break d}if((B|0)==0|(D|0)==0){break}if((B>>31|0)==(D>>31|0)){break d}}}while(0);J=+(B|0)/+(C|0);K=J- +(D|0)/+(E|0);if(K<0.0){L=-0.0-K}else{L=K}if(!(L<=J*.004|(B|0)==0|(C|0)==0|(E|0)==0)){o=31;break c}}else if((A|0)==1){if((c[y+412>>2]|0)<1){o=14;break c}H=y+432|0;if((c[H>>2]|0)!=0){break}I=c[y+416>>2]|0;c[H>>2]=(ca(g5a(c[y+48>>2]|0)|0,I)|0)>>3}}while(0);A=c[t>>2]|0;e:do{if((A|0)!=0){M=y+52|0;N=y+48|0;f:do{if((c[M>>2]|0)!=0){do{if((c[N>>2]|0)==14){if((LX(A,14)|0)!=0){if((LX(c[t>>2]|0,c[N>>2]|0)|0)!=544694642){break}}if((bP(a,x)|0)!=0){break}c[M>>2]=0;break f}}while(0);if((c[M>>2]|0)==0){break}if((bP(a,x)|0)==0){o=41;break c}else{break e}}}while(0);c[M>>2]=LX(c[t>>2]|0,c[N>>2]|0)|0}}while(0);do{if((c[u>>2]&64|0)!=0){if((c[y+88>>2]&4194304|0)!=0){break}KIb(l,24,2432968,(s=i,i=i+8|0,c[s>>2]=w,s)|0);i=s}}while(0);if((c[z>>2]|0)!=4){y=c[v>>2]|0;c[y>>2]=(c[y>>2]|0)+1}w=w+1|0;if(!(w>>>0<(c[q>>2]|0)>>>0)){break b}}if((o|0)==14){KIb(l,16,2492264,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;o=60;break a}else if((o|0)==19){KIb(l,16,2482512,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;o=60;break a}else if((o|0)==23){KIb(l,16,2471224,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;o=60;break a}else if((o|0)==31){KIb(l,16,2463272,(s=i,i=i+32|0,c[s>>2]=B,c[s+8>>2]=C,c[s+16>>2]=D,c[s+24>>2]=E,s)|0);i=s;n=-22;o=60;break a}else if((o|0)==41){v5a(f,32,c[M>>2]|0)|0;v5a(g,32,LX(c[(c[h>>2]|0)+32>>2]|0,c[N>>2]|0)|0)|0;w=c[M>>2]|0;v=c[N>>2]|0;KIb(l,16,2448392,(s=i,i=i+32|0,c[s>>2]=f,c[s+8>>2]=w,c[s+16>>2]=v,c[s+24>>2]=g,s)|0);i=s;n=-1094995529;o=60;break a}}}while(0);do{if((c[p>>2]|0)==0){v=c[j+44>>2]|0;if((v|0)<=0){break}w=pJb(v)|0;c[p>>2]=w;if((w|0)==0){n=-12;o=60;break a}v=c[j+36>>2]|0;if((v|0)==0){break}c[w>>2]=v;SJb(w);w=XJb(c[p>>2]|0,e)|0;if((w|0)<0){n=w;o=60;break a}}}while(0);do{if((c[q>>2]|0)==0){o=57}else{if((c[(c[(c[c[a+28>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)!=0){o=57;break}MGb(a+1140|0,2424256,2413384,0)|0}}while(0);if((o|0)==57){MGb(a+1140|0,2424256,0,0)|0}if(!k){O=0;break}OGb(b);c[b>>2]=c[e>>2];O=0}}while(0);if((o|0)==60){OGb(e);O=n}if((O|0)!=0){P=O;i=d;return P|0}O=c[(c[h>>2]|0)+48>>2]|0;do{if((O|0)!=0){n=ve[O&4095](a)|0;if(!((n|0)>-1)){P=n;i=d;return P|0}e=c[a+16>>2]|0;if((e|0)==0){break}b=c[e+76>>2]|0;e=(b|0)<0?b:n;if((e|0)<0){P=e}else{break}i=d;return P|0}}while(0);O=c[a+24>>2]|0;g:do{if((O|0)!=0){e=c[a+28>>2]|0;n=0;h:while(1){b=c[e+(n<<2)>>2]|0;k=c[b+8>>2]|0;j=c[k+8>>2]|0;if((j|0)==1){s=c[b+40>>2]|0;g=c[k+412>>2]|0;f=Erc(g,(g|0)<0|0?-1:0,s,(s|0)<0|0?-1:0)|0;Q=G;R=f;o=71}else if((j|0)==0){j=c[b+40>>2]|0;f=c[k+108>>2]|0;k=Erc(f,(f|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;Q=G;R=k;o=71}do{if((o|0)==71){o=0;if((R|0)==0&(Q|0)==(-2147483648|0)){break}k=0;if((Q|0)<(k|0)|(Q|0)==(k|0)&R>>>0<1>>>0){P=-1094995529;break h}k=R>>>1|Q<<31;j=Q>>1|((Q|0)<0|0?-1:0)<<31;if((j|0)<(Q|0)|(j|0)==(Q|0)&k>>>0<R>>>0){S=0;T=0;U=j;V=k}else{f=Crc(k,j,R,Q)|0;s=G;g=Drc(k,j,R,Q)|0;S=s;T=f;U=G;V=g}g=b+16|0;c[g>>2]=T;c[g+4>>2]=S;g=b+24|0;c[g>>2]=V;c[g+4>>2]=U;g=b+32|0;c[g>>2]=R;c[g+4>>2]=Q}}while(0);n=n+1|0;if(!(n>>>0<O>>>0)){break g}}i=d;return P|0}}while(0);O=a+1204|0;if((c[O>>2]|0)>=0){P=0;i=d;return P|0}if((c[(c[h>>2]|0)+28>>2]&262272|0)==0){c[O>>2]=1;P=0;i=d;return P|0}else{c[O>>2]=0;P=0;i=d;return P|0}return 0}function UO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;if((b|0)==0){e=c[a+8>>2]|0;if((c[e+28>>2]&65536|0)==0){f=1;i=d;return f|0}g=We[c[e+52>>2]&2047](a,0)|0;do{if((c[a+1228>>2]|0)!=0){e=c[a+16>>2]|0;if((e|0)==0){break}if(!((c[e+76>>2]|0)>-1)){break}eD(e)}}while(0);if(!((g|0)>-1)){f=g;i=d;return f|0}e=c[a+16>>2]|0;if((e|0)==0){f=g;i=d;return f|0}else{h=c[e+76>>2]|0;i=d;return((h|0)<0?h:g)|0}}g=b+32|0;h=c[g>>2]|0;do{if((h|0)>=0){if(!(h>>>0<(c[a+24>>2]|0)>>>0)){break}e=a+28|0;j=c[(c[e>>2]|0)+(h<<2)>>2]|0;if((c[(c[j+8>>2]|0)+8>>2]|0)==4){KIb(a,16,2521056,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;f=-22;i=d;return f|0}l=VO(a,j,b)|0;do{if((l|0)<0){if((c[(c[a+8>>2]|0)+28>>2]&128|0)==0){f=l}else{break}i=d;return f|0}}while(0);l=WO(a,b)|0;if(!((l|0)>-1)){f=l;i=d;return f|0}j=c[a+16>>2]|0;do{if((j|0)==0){m=l}else{n=c[j+76>>2]|0;o=(n|0)<0?n:l;if((o|0)>-1){m=o;break}else{f=o}i=d;return f|0}}while(0);l=(c[(c[e>>2]|0)+(c[g>>2]<<2)>>2]|0)+64|0;j=wrc(c[l>>2]|0,c[l+4>>2]|0,1,0)|0;c[l>>2]=j;c[l+4>>2]=G;f=m;i=d;return f|0}}while(0);KIb(a,16,2537184,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;f=-22;i=d;return f|0}function VO(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;f=i;i=i+144|0;g=f|0;h=f+8|0;j=f+16|0;k=f+48|0;l=f+80|0;m=f+112|0;n=d+8|0;o=c[n>>2]|0;p=c[o+176>>2]|0;q=(c[o+156>>2]|0)>0|0;o=(p|0)>(q|0)?p:q;q=e+48|0;do{if((c[q>>2]|0)==0){tX(g,h,d,0,e);p=c[h>>2]|0;if((p|0)==0){break}r=c[g>>2]|0;if((r|0)==0){break}s=c[d+44>>2]|0;t=Erc(s,(s|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;r=c[(c[n>>2]|0)+112>>2]|0;s=Erc(t,G,r,(r|0)<0|0?-1:0)|0;r=G;t=c[d+40>>2]|0;u=Erc(t,(t|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;p=VIb(1,0,s,r,u,G)|0;c[q>>2]=p}}while(0);g=e+8|0;h=c[g>>2]|0;p=c[g+4>>2]|0;do{if((h|0)==0&(p|0)==(-2147483648|0)){u=e+16|0;r=c[u>>2]|0;s=c[u+4>>2]|0;if(!(((r|0)!=0|(s|0)!=(-2147483648|0))&(o|0)==0)){v=-2147483648;w=0;x=9;break}c[g>>2]=r;c[g+4>>2]=s;y=s;z=r;x=8}else{y=p;z=h;x=8}}while(0);if((x|0)==8){if((z|0)==0&(y|0)==0|(z|0)==0&(y|0)==(-2147483648|0)){v=y;w=z;x=9}else{A=y;B=z;x=14}}if((x|0)==9){z=e+16|0;if((c[z>>2]|0)==0&(c[z+4>>2]|0)==(-2147483648|0)&(o|0)==0){if(!(a[1638400]|0)){KIb(b,24,2106144,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;a[1638400]=1}y=d+16|0;h=c[y>>2]|0;p=c[y+4>>2]|0;c[g>>2]=h;c[g+4>>2]=p;c[z>>2]=h;c[z+4>>2]=p;D=p;E=h}else{D=v;E=w}if(!((E|0)==0&(D|0)==(-2147483648|0))){A=D;B=E;x=14}}do{if((x|0)==14){E=e+16|0;if(!((c[E>>2]|0)==0&(c[E+4>>2]|0)==(-2147483648|0)&(o|0)<17)){break}D=d+264|0;c[D>>2]=B;c[D+4>>2]=A;w=o+1|0;v=(o|0)>0;a:do{if(v){h=~o;p=1;do{z=d+264+(p<<3)|0;if(!((c[z>>2]|0)==0&(c[z+4>>2]|0)==(-2147483648|0))){break}y=ca(c[q>>2]|0,p+h|0)|0;r=wrc(y,(y|0)<0|0?-1:0,c[g>>2]|0,c[g+4>>2]|0)|0;c[z>>2]=r;c[z+4>>2]=G;p=p+1|0;}while((p|0)<(w|0));if(!v){break}p=c[D>>2]|0;h=c[D+4>>2]|0;z=0;while(1){r=z+1|0;y=d+264+(r<<3)|0;s=c[y>>2]|0;u=c[y+4>>2]|0;if(!((h|0)>(u|0)|(h|0)==(u|0)&p>>>0>s>>>0)){break a}t=d+264+(z<<3)|0;c[y>>2]=p;c[y+4>>2]=h;c[t>>2]=s;c[t+4>>2]=u;if((r|0)<(o|0)){z=r}else{break}}}}while(0);v=c[D+4>>2]|0;c[E>>2]=c[D>>2];c[E+4>>2]=v}}while(0);o=d+208|0;q=c[o>>2]|0;A=c[o+4>>2]|0;do{if(!((q|0)==0&(A|0)==0|(q|0)==0&(A|0)==(-2147483648|0))){B=e+16|0;x=c[B>>2]|0;v=c[B+4>>2]|0;if(!((A|0)>=(v|0)&((A|0)>(v|0)|q>>>0>=x>>>0)&(c[(c[b+8>>2]|0)+28>>2]&131072|0)==0|((A|0)>(v|0)|(A|0)==(v|0)&q>>>0>x>>>0))){break}x=c[d>>2]|0;v=j|0;mrc(v|0,0,32)|0;a[v]=0;if((q|0)==0&(A|0)==(-2147483648|0)){Rb(v|0,32,2573448,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0)|0;i=C}else{Rb(v|0,32,2555008,(C=i,i=i+16|0,c[C>>2]=q,c[C+8>>2]=A,C)|0)|0;i=C}B=k|0;mrc(B|0,0,32)|0;a[B]=0;w=e+16|0;z=c[w>>2]|0;h=c[w+4>>2]|0;if((z|0)==0&(h|0)==(-2147483648|0)){Rb(B|0,32,2573448,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0)|0;i=C}else{Rb(B|0,32,2555008,(C=i,i=i+16|0,c[C>>2]=z,c[C+8>>2]=h,C)|0)|0;i=C}KIb(b,16,2624144,(C=i,i=i+24|0,c[C>>2]=x,c[C+8>>2]=v,c[C+16>>2]=B,C)|0);i=C;F=-22;i=f;return F|0}}while(0);k=e+16|0;A=c[k>>2]|0;q=c[k+4>>2]|0;do{if(!((A|0)==0&(q|0)==(-2147483648|0))){j=c[g>>2]|0;B=c[g+4>>2]|0;if(!(((j|0)!=0|(B|0)!=(-2147483648|0))&((B|0)<(q|0)|(B|0)==(q|0)&j>>>0<A>>>0))){break}v=l|0;mrc(v|0,0,32)|0;a[v]=0;Rb(v|0,32,2555008,(C=i,i=i+16|0,c[C>>2]=j,c[C+8>>2]=B,C)|0)|0;i=C;B=m|0;mrc(B|0,0,32)|0;a[B]=0;j=c[k>>2]|0;x=c[k+4>>2]|0;if((j|0)==0&(x|0)==(-2147483648|0)){Rb(B|0,32,2573448,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0)|0;i=C}else{Rb(B|0,32,2555008,(C=i,i=i+16|0,c[C>>2]=j,c[C+8>>2]=x,C)|0)|0;i=C}x=c[d>>2]|0;KIb(b,16,2597944,(C=i,i=i+24|0,c[C>>2]=v,c[C+8>>2]=B,c[C+16>>2]=x,C)|0);i=C;F=-22;i=f;return F|0}}while(0);c[o>>2]=A;c[o+4>>2]=q;q=c[k>>2]|0;o=c[k+4>>2]|0;k=d+16|0;c[k>>2]=q;c[k+4>>2]=o;A=c[n>>2]|0;n=c[A+8>>2]|0;if((n|0)==1){if((c[e+36>>2]&8192|0)==0){H=sX(A,c[e+28>>2]|0,1)|0}else{H=c[(c[e+24>>2]|0)+76>>2]|0}if(!((H|0)>-1)){F=0;i=f;return F|0}C=d+24|0;b=c[C>>2]|0;m=c[C+4>>2]|0;C=d+32|0;l=c[C>>2]|0;g=c[C+4>>2]|0;do{if((c[e+28>>2]|0)==0){if(!((b|0)==(l>>>1|g<<31|0)&(m|0)==(g>>1|((g|0)<0|0?-1:0)<<31|0))){break}if((c[k>>2]|0)==0&(c[k+4>>2]|0)==0){F=0}else{break}i=f;return F|0}}while(0);e=c[d+44>>2]|0;C=Erc(e,(e|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;H=d+24|0;e=wrc(C,G,b,m)|0;m=G;b=0;do{if((m|0)<(b|0)|(m|0)==(b|0)&e>>>0<0>>>0){C=Crc(e,m,l,g)|0;x=wrc(c[k>>2]|0,c[k+4>>2]|0,C,G)|0;C=G;c[k>>2]=x;c[k+4>>2]=C;B=Drc(e,m,l,g)|0;v=G;j=0;if(!((v|0)<(j|0)|(v|0)==(j|0)&B>>>0<0>>>0)){I=v;J=B;break}j=wrc(B,v,l,g)|0;v=G;B=wrc(x,C,-1,-1)|0;c[k>>2]=B;c[k+4>>2]=G;I=v;J=j}else{if((m|0)<(g|0)|(m|0)==(g|0)&e>>>0<l>>>0){I=m;J=e;break}j=Crc(e,m,l,g)|0;v=wrc(c[k>>2]|0,c[k+4>>2]|0,j,G)|0;c[k>>2]=v;c[k+4>>2]=G;v=Drc(e,m,l,g)|0;I=G;J=v}}while(0);c[H>>2]=J;c[H+4>>2]=I;F=0;i=f;return F|0}else if((n|0)==0){n=c[d+44>>2]|0;I=c[A+104>>2]|0;A=Erc(I,(I|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=d+24|0;I=wrc(A,G,c[n>>2]|0,c[n+4>>2]|0)|0;A=G;H=d+32|0;d=c[H>>2]|0;J=c[H+4>>2]|0;H=0;do{if((A|0)<(H|0)|(A|0)==(H|0)&I>>>0<0>>>0){g=Crc(I,A,d,J)|0;l=wrc(g,G,q,o)|0;g=G;c[k>>2]=l;c[k+4>>2]=g;m=Drc(I,A,d,J)|0;e=G;b=0;if(!((e|0)<(b|0)|(e|0)==(b|0)&m>>>0<0>>>0)){K=e;L=m;break}b=wrc(m,e,d,J)|0;e=G;m=wrc(l,g,-1,-1)|0;c[k>>2]=m;c[k+4>>2]=G;K=e;L=b}else{if((A|0)<(J|0)|(A|0)==(J|0)&I>>>0<d>>>0){K=A;L=I;break}b=Crc(I,A,d,J)|0;e=wrc(b,G,q,o)|0;c[k>>2]=e;c[k+4>>2]=G;e=Drc(I,A,d,J)|0;K=G;L=e}}while(0);c[n>>2]=L;c[n+4>>2]=K;F=0;i=f;return F|0}else{F=0;i=f;return F|0}return 0}function WO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a+1328|0;h=c[g>>2]|0;j=c[g+4>>2]|0;do{if(!((h|0)==0&(j|0)==0)){g=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;c[e>>2]=1;c[e+4>>2]=1e6;k=XIb(h,j,e,g+40|0)|0;g=G;l=b+16|0;m=c[l>>2]|0;n=c[l+4>>2]|0;if(!((m|0)==0&(n|0)==(-2147483648|0))){o=wrc(m,n,k,g)|0;c[l>>2]=o;c[l+4>>2]=G}l=b+8|0;o=c[l>>2]|0;n=c[l+4>>2]|0;if((o|0)==0&(n|0)==(-2147483648|0)){break}m=wrc(o,n,k,g)|0;c[l>>2]=m;c[l+4>>2]=G}}while(0);e=c[a+1204>>2]|0;do{if((e|0)>0){j=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;h=j+456|0;l=c[h>>2]|0;m=c[h+4>>2]|0;g=b+16|0;k=c[g>>2]|0;n=c[g+4>>2]|0;o=-1;p=a+1280|0;q=c[p>>2]|0;r=c[p+4>>2]|0;if((q|0)==0&(r|0)==0&(((e|0)!=2&((n|0)>(o|0)|(n|0)==(o|0)&k>>>0>-1>>>0)|(k|0)==0&(n|0)==(-2147483648|0))^1)){o=xrc(0,0,k,n)|0;n=G;c[p>>2]=o;c[p+4>>2]=n;p=j+40|0;k=a+1288|0;s=c[p+4>>2]|0;c[k>>2]=c[p>>2];c[k+4>>2]=s;t=n;u=o}else{t=r;u=q}if(((u|0)!=0|(t|0)!=0)&((l|0)==0&(m|0)==0)){q=WIb(u,t,a+1288|0,j+40|0,3)|0;j=G;c[h>>2]=q;c[h+4>>2]=j;v=j;w=q}else{v=m;w=l}l=c[g>>2]|0;m=c[g+4>>2]|0;if(!((l|0)==0&(m|0)==(-2147483648|0))){q=wrc(l,m,w,v)|0;c[g>>2]=q;c[g+4>>2]=G}g=b+8|0;q=c[g>>2]|0;m=c[g+4>>2]|0;if((q|0)==0&(m|0)==(-2147483648|0)){break}l=wrc(q,m,w,v)|0;c[g>>2]=l;c[g+4>>2]=G}}while(0);v=X1(b)|0;do{if((c[b+36>>2]&8192|0)==0){x=We[c[(c[a+8>>2]|0)+52>>2]&2047](a,b)|0}else{c[f>>2]=c[b+24>>2];if((c[b+28>>2]|0)==-1431655292){w=hf[c[(c[a+8>>2]|0)+76>>2]&1023](a,c[b+32>>2]|0,f,0)|0;VHb(f);x=w;break}else{KIb(0,0,2315608,(w=i,i=i+24|0,c[w>>2]=2262800,c[w+8>>2]=2215480,c[w+16>>2]=565,w)|0);i=w;Hd();return 0}}}while(0);do{if((c[a+1228>>2]|0)!=0){f=c[a+16>>2]|0;if(!((f|0)!=0&(x|0)>-1)){break}if((c[a+1084>>2]&512|0)==0){break}eD(f)}}while(0);if((v|0)==0){i=d;return x|0}W1(b)|0;i=d;return x|0}function XO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;e=i;i=i+8|0;f=e|0;g=b+32|0;h=a+28|0;j=c[(c[h>>2]|0)+(c[g>>2]<<2)>>2]|0;k=a+1196|0;if((c[k>>2]|0)==0){l=(c[a+1192>>2]|0)!=0}else{l=1}m=pJb(88)|0;n=m;if((m|0)==0){o=-12;i=e;return o|0}p=m;nrc(m|0,b|0,80)|0;c[b+52>>2]=0;c[b>>2]=0;do{if((c[b+36>>2]&8192|0)==0){q=Q1(p)|0;if((q|0)>=0){O1(p,p)|0;break}kJb(m);o=q;i=e;return o|0}else{if(!((c[b+28>>2]|0)==-1431655292)){KIb(0,0,2315608,(r=i,i=i+24|0,c[r>>2]=2262800,c[r+8>>2]=2215480,c[r+16>>2]=655,r)|0);i=r;Hd();return 0}if(((c[b+24>>2]|0)+360|0)!=0){break}KIb(0,0,2315608,(r=i,i=i+24|0,c[r>>2]=2182384,c[r+8>>2]=2215480,c[r+16>>2]=656,r)|0);i=r;Hd();return 0}}while(0);if((c[(c[(c[h>>2]|0)+(c[g>>2]<<2)>>2]|0)+244>>2]|0)==0){s=a+1236|0}else{s=(c[j+244>>2]|0)+80|0}do{if(l){r=c[a+1192>>2]|0;c[f>>2]=1;c[f+4>>2]=1e6;p=WIb(r,(r|0)<0|0?-1:0,f,j+40|0,3)|0;r=G;q=c[b+28>>2]|0;t=j+424|0;u=wrc(c[t>>2]|0,c[t+4>>2]|0,q,(q|0)<0|0?-1:0)|0;q=G;c[t>>2]=u;c[t+4>>2]=q;v=c[b+48>>2]|0;w=j+432|0;x=wrc(c[w>>2]|0,c[w+4>>2]|0,v,(v|0)<0|0?-1:0)|0;v=G;c[w>>2]=x;c[w+4>>2]=v;y=c[k>>2]|0;z=(y|0)<0|0?-1:0;if(!((y|0)!=0&((q|0)>(z|0)|(q|0)==(z|0)&u>>>0>y>>>0))){if(!(((p|0)!=0|(r|0)!=0)&(v>>>0>r>>>0|v>>>0==r>>>0&x>>>0>p>>>0))){break}}c[t>>2]=0;c[t+4>>2]=0;t=m+36|0;c[t>>2]=c[t>>2]|4096;if(((p|0)!=0|(r|0)!=0)&(v>>>0>r>>>0|v>>>0==r>>>0&x>>>0>p>>>0)){t=xrc(0,0,(c[(c[j+8>>2]|0)+8>>2]|0)==0|0,0)|0;y=r&G;u=(p&t)>>>1|y<<31;t=y>>>1|0<<31;y=b+16|0;z=c[y>>2]|0;q=c[y+4>>2]|0;y=wrc(u,t,z,q)|0;A=VIb(y,G,1,0,p,r)|0;y=Erc(A,G,p,r)|0;A=xrc(z,q,y,G)|0;y=wrc(A,G,u,t)|0;t=Crc(y,G,8,0)|0;y=G;u=xrc(x,v,p,r)|0;r=wrc(u,G,t,y)|0;c[w>>2]=r;c[w+4>>2]=G;break}else{c[w>>2]=0;c[w+4>>2]=0;break}}}while(0);j=c[s>>2]|0;a:do{if((j|0)==0){B=s;C=a+1240|0;D=35}else{if(l){if((c[m+36>>2]&4096|0)==0){E=s;F=j;break}}k=a+1240|0;if((Ee[d&511](a,c[k>>2]|0,b)|0)==0){B=(c[k>>2]|0)+80|0;C=k;D=35;break}f=c[s>>2]|0;if((f|0)==0){B=s;C=k;D=35;break}b:do{if(l){w=s;r=f;while(1){if((c[r+36>>2]&4096|0)==0){H=r}else{y=(Ee[d&511](a,r|0,b)|0)==0;t=c[w>>2]|0;if(y){H=t}else{I=w;J=t;break b}}t=H+80|0;y=c[t>>2]|0;if((y|0)==0){B=t;C=k;D=35;break a}else{w=t;r=y}}}else{r=s;w=f;while(1){y=(Ee[d&511](a,w|0,b)|0)==0;t=c[r>>2]|0;if(!y){I=r;J=t;break b}y=t+80|0;t=c[y>>2]|0;if((t|0)==0){B=y;C=k;D=35;break a}else{r=y;w=t}}}}while(0);if((J|0)==0){B=I;C=k;D=35}else{E=I;F=J}}}while(0);if((D|0)==35){c[C>>2]=n;E=B;F=c[B>>2]|0}c[m+80>>2]=F;c[E>>2]=n;c[(c[(c[h>>2]|0)+(c[g>>2]<<2)>>2]|0)+244>>2]=n;o=0;i=e;return o|0}function YO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;do{if((d|0)!=0){k=XO(a,d,106)|0;if((k|0)<0){l=k}else{break}i=f;return l|0}}while(0);d=a+24|0;k=c[d>>2]|0;if((k|0)==0){m=0}else{n=c[a+28>>2]|0;o=0;p=0;while(1){q=p+((c[(c[n+(o<<2)>>2]|0)+244>>2]|0)!=0)|0;r=o+1|0;if(r>>>0<k>>>0){o=r;p=q}else{m=q;break}}}p=(c[c[a+1296>>2]>>2]|0)==(m|0)?1:e;e=a+1176|0;o=c[e+4>>2]|0;k=0;do{if((o|0)>(k|0)|(o|0)==(k|0)&(c[e>>2]|0)>>>0>0>>>0){n=c[a+1236>>2]|0;if(!((n|0)!=0&(p|0)==0)){s=p;t=15;break}q=n+16|0;r=c[q>>2]|0;u=c[q+4>>2]|0;q=a+28|0;v=(c[(c[q>>2]|0)+(c[n+32>>2]<<2)>>2]|0)+40|0;c[h>>2]=1;c[h+4>>2]=1e6;n=XIb(r,u,v,h)|0;v=G;u=c[d>>2]|0;if((u|0)==0){break}r=j|0;w=j+4|0;x=0;y=-2147483648;z=0;A=u;while(1){u=c[(c[q>>2]|0)+(x<<2)>>2]|0;B=c[u+244>>2]|0;if((B|0)==0){C=y;D=z;E=A}else{F=B+16|0;B=c[F>>2]|0;H=c[F+4>>2]|0;c[r>>2]=1;c[w>>2]=1e6;F=XIb(B,H,u+40|0,j)|0;u=xrc(F,G,n,v)|0;F=G;H=(y|0)>(F|0)|(y|0)==(F|0)&z>>>0>u>>>0;C=H?y:F;D=H?z:u;E=c[d>>2]|0}u=x+1|0;if(u>>>0<E>>>0){x=u;y=C;z=D;A=E}else{break}}A=c[e>>2]|0;z=c[e+4>>2]|0;if(!((C|0)>(z|0)|(C|0)==(z|0)&D>>>0>A>>>0)){break}KIb(a,48,2153896,(y=i,i=i+32|0,c[y>>2]=D,c[y+8>>2]=C,c[y+16>>2]=A,c[y+24>>2]=z,y)|0);i=y;s=1;t=15}else{s=p;t=15}}while(0);do{if((t|0)==15){if((m|0)==0|(s|0)==0){break}p=a+1236|0;C=c[p>>2]|0;c[g>>2]=C;nrc(b|0,C|0,80)|0;D=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;e=c[C+80>>2]|0;c[p>>2]=e;if((e|0)==0){c[a+1240>>2]=0}e=D+244|0;if((c[e>>2]|0)==(C|0)){c[e>>2]=0}mJb(g);l=1;i=f;return l|0}}while(0);J1(b);l=0;i=f;return l|0}function ZO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=d+32|0;j=c[a+28>>2]|0;k=c[j+(c[h>>2]<<2)>>2]|0;l=b+32|0;m=c[j+(c[l>>2]<<2)>>2]|0;j=b+16|0;b=m+40|0;n=d+16|0;d=k+40|0;o=YIb(c[j>>2]|0,c[j+4>>2]|0,b,c[n>>2]|0,c[n+4>>2]|0,d)|0;p=a+1188|0;do{if((c[p>>2]|0)==0){q=o}else{a=k+8|0;r=m+8|0;if(!((c[(c[a>>2]|0)+8>>2]|0)==1^(c[(c[r>>2]|0)+8>>2]|0)==1)){q=o;break}s=c[n>>2]|0;t=c[n+4>>2]|0;c[f>>2]=1;c[f+4>>2]=1e6;u=XIb(s,t,d,f)|0;t=c[p>>2]&-((c[(c[a>>2]|0)+8>>2]|0)==1|0);s=xrc(u,G,t,(t|0)<0|0?-1:0)|0;t=G;u=c[j>>2]|0;v=c[j+4>>2]|0;c[g>>2]=1;c[g+4>>2]=1e6;w=XIb(u,v,b,g)|0;v=c[p>>2]|0;u=(c[(c[r>>2]|0)+8>>2]|0)==1;r=v&-(u&1);x=xrc(w,G,r,(r|0)<0|0?-1:0)|0;r=G;if((s|0)==(x|0)&(t|0)==(r|0)){w=c[d>>2]|0;y=Erc(c[n>>2]|0,c[n+4>>2]|0,1e6,0)|0;z=Erc(y,G,w,(w|0)<0|0?-1:0)|0;w=G;y=v;A=(v|0)<0|0?-1:0;v=xrc(0,0,(c[(c[a>>2]|0)+8>>2]|0)==1|0,0)|0;a=c[k+44>>2]|0;B=a;C=(a|0)<0|0?-1:0;a=Erc(y&v,A&G,B,C)|0;v=xrc(z,w,a,G)|0;a=c[m+44>>2]|0;w=a;z=(a|0)<0|0?-1:0;a=Erc(v,G,w,z)|0;v=G;D=c[b>>2]|0;E=Erc(c[j>>2]|0,c[j+4>>2]|0,1e6,0)|0;F=Erc(E,G,D,(D|0)<0|0?-1:0)|0;D=G;E=xrc(0,0,u&1,0)|0;u=Erc(w,z,y&E,A&G)|0;A=xrc(F,D,u,G)|0;u=Erc(A,G,B,C)|0;C=xrc(a,v,u,G)|0;H=0;I=0;J=G;K=C}else{H=r;I=x;J=t;K=s}q=(((J|0)>(H|0)|(J|0)==(H|0)&K>>>0>I>>>0)&1)-(((J|0)<(H|0)|(J|0)==(H|0)&K>>>0<I>>>0)&1)|0}}while(0);if((q|0)==0){L=(c[h>>2]|0)<(c[l>>2]|0);M=L&1;i=e;return M|0}else{L=(q|0)>0;M=L&1;i=e;return M|0}return 0}function _O(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+80|0;e=d|0;a:do{if((b|0)==0){f=1;g=0;h=a+28|0}else{j=c[b+32>>2]|0;do{if((j|0)<0){k=5}else{if(!(j>>>0<(c[a+24>>2]|0)>>>0)){k=5;break}l=a+28|0;m=c[(c[l>>2]|0)+(j<<2)>>2]|0;n=c[(c[m+8>>2]|0)+8>>2]|0;if((n|0)==1){if((c[b+28>>2]|0)==0){o=0;break}}else if((n|0)==4){KIb(a,16,2521056,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-22;break}n=VO(a,m,b)|0;if((n|0)<0){if((c[(c[a+8>>2]|0)+28>>2]&128|0)==0){o=n;break}}n=b+16|0;if(!((c[n>>2]|0)==0&(c[n+4>>2]|0)==(-2147483648|0))){f=0;g=b;h=l;break a}if((c[(c[a+8>>2]|0)+28>>2]&128|0)==0){o=-22}else{f=0;g=b;h=l;break a}}}while(0);if((k|0)==5){KIb(a,16,2537184,(p=i,i=i+8|0,c[p>>2]=j,p)|0);i=p;o=-22}$1(b);q=o;i=d;return q|0}}while(0);o=a+8|0;b=e+32|0;p=a+16|0;l=g;while(1){g=c[(c[o>>2]|0)+60>>2]|0;do{if((g|0)==0){n=YO(a,e,l,f)|0;if((l|0)==0){r=n}else{s=n;k=18}}else{n=hf[g&1023](a,e,l,f)|0;if((l|0)==0){r=n;break}P1(l);s=n;k=18}}while(0);if((k|0)==18){k=0;mrc(l|0,0,80)|0;J1(l);r=s}if((r|0)<1){q=r;k=25;break}t=WO(a,e)|0;if(!((t|0)>-1)){k=21;break}g=(c[(c[h>>2]|0)+(c[b>>2]<<2)>>2]|0)+64|0;j=wrc(c[g>>2]|0,c[g+4>>2]|0,1,0)|0;c[g>>2]=j;c[g+4>>2]=G;P1(e);g=c[p>>2]|0;if((g|0)==0){l=0;continue}j=c[g+76>>2]|0;if((j|0)==0){l=0}else{q=j;k=25;break}}if((k|0)==21){P1(e);q=t;i=d;return q|0}else if((k|0)==25){i=d;return q|0}return 0}function $O(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+80|0;d=b|0;e=a+8|0;f=d+32|0;g=a+28|0;h=a+16|0;while(1){j=c[(c[e>>2]|0)+60>>2]|0;if((j|0)==0){k=YO(a,d,0,1)|0}else{k=hf[j&1023](a,d,0,1)|0}if((k|0)<0){l=k;break}if((k|0)==0){m=11;break}n=WO(a,d)|0;if(!((n|0)>-1)){m=8;break}j=(c[(c[g>>2]|0)+(c[f>>2]<<2)>>2]|0)+64|0;o=wrc(c[j>>2]|0,c[j+4>>2]|0,1,0)|0;c[j>>2]=o;c[j+4>>2]=G;P1(d);j=c[h>>2]|0;if((j|0)==0){continue}if((c[j+76>>2]|0)!=0){l=n;break}}do{if((m|0)==8){P1(d);l=n}else if((m|0)==11){f=c[(c[e>>2]|0)+56>>2]|0;if((f|0)==0){l=0;break}l=ve[f&4095](a)|0}}while(0);m=c[h>>2]|0;if((m|0)!=0){eD(m)}do{if((l|0)==0){m=c[h>>2]|0;if((m|0)==0){p=0;break}p=c[m+76>>2]|0}else{p=l}}while(0);l=a+24|0;if((c[l>>2]|0)!=0){h=0;do{mJb((c[(c[g>>2]|0)+(h<<2)>>2]|0)+12|0);mJb((c[(c[g>>2]|0)+(h<<2)>>2]|0)+400|0);h=h+1|0;}while(h>>>0<(c[l>>2]|0)>>>0)}l=a+12|0;if((c[(c[e>>2]|0)+36>>2]|0)==0){q=l;mJb(q);i=b;return p|0}WJb(c[l>>2]|0);q=l;mJb(q);i=b;return p|0}function aP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+80|0;g=f|0;nrc(g|0,d|0,80)|0;c[g+32>>2]=b;h=d+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;if(!((j|0)==0&(k|0)==(-2147483648|0))){h=XIb(j,k,(c[(c[e+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+40|0,(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+40|0)|0;k=g+8|0;c[k>>2]=h;c[k+4>>2]=G}k=d+16|0;h=c[k>>2]|0;j=c[k+4>>2]|0;if(!((h|0)==0&(j|0)==(-2147483648|0))){k=XIb(h,j,(c[(c[e+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+40|0,(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+40|0)|0;j=g+16|0;c[j>>2]=k;c[j+4>>2]=G}j=c[d+48>>2]|0;if((j|0)==0){l=UO(a,g)|0;i=f;return l|0}k=XIb(j,(j|0)<0|0?-1:0,(c[(c[e+28>>2]|0)+(c[d+32>>2]<<2)>>2]|0)+40|0,(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+40|0)|0;c[g+48>>2]=k;l=UO(a,g)|0;i=f;return l|0}function bP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a+8|0;a=c[d>>2]|0;e=c[c[a+32>>2]>>2]|0;do{if((e|0)!=0){f=b+8|0;g=0;h=0;i=-1;j=-1;k=e;l=a;a:while(1){m=k|0;if((c[m>>2]|0)==0){n=h;o=i;p=j;q=l}else{r=h;s=i;t=j;u=m;while(1){m=u+4|0;v=F5a(c[m>>2]|0)|0;w=(v|0)==(F5a(c[(c[f>>2]|0)+52>>2]|0)|0);v=c[u>>2]|0;x=c[(c[f>>2]|0)+48>>2]|0;if(w){if((v|0)==(x|0)){y=1;z=15;break a}else{A=v}}else{A=r}if((v|0)==(x|0)){B=0;C=c[m>>2]|0}else{B=s;C=t}m=u+8|0;if((c[m>>2]|0)==0){break}else{r=A;s=B;t=C;u=m}}n=A;o=B;p=C;q=c[d>>2]|0}u=g+1|0;t=c[(c[q+32>>2]|0)+(u<<2)>>2]|0;if((t|0)==0){break}else{g=u;h=n;i=o;j=p;k=t;l=q}}if((z|0)==15){return y|0}if((n|0)!=0){y=0;return y|0}l=-1;if(!((o|0)>(l|0)|(o|0)==(l|0)&p>>>0>-1>>>0)){break}if((c[(c[b+8>>2]|0)+680>>2]|0)>-1){y=0}else{break}return y|0}}while(0);y=1;return y|0}function cP(a){a=a|0;var b=0,e=0,f=0;b=c[a+4>>2]|0;a=b;do{if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1230393165){e=b+4|0;if(((he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535)>>>0<3>>>0){f=100}else{break}return f|0}}while(0);f=0;return f|0}function dP(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;b=i;d=c[a+12>>2]|0;e=a+16|0;f=c[e>>2]|0;hD(f,4,0)|0;g=HD(f)|0;if((g|0)==0){h=23}else if((g|0)==2){hD(f,22,0)|0;j=ZX(a,0)|0;if((j|0)==0){k=-12;i=b;return k|0}l=ZX(a,0)|0;if((l|0)==0){k=-12;i=b;return k|0}m=l+8|0;c[(c[m>>2]|0)+8>>2]=0;_X(l,64,1,15);n=l+64|0;c[n>>2]=JD(f)|0;c[n+4>>2]=0;o=JD(f)|0;if((o|0)==1){p=c[m>>2]|0;c[p+48>>2]=1297498929;q=p}else if((o|0)==2){p=c[m>>2]|0;c[p+140>>2]=27;c[p+48>>2]=14;q=p}else{QIb(a,2386656,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r;q=c[m>>2]|0}c[q+52>>2]=0;q=JD(f)|0;c[(c[m>>2]|0)+120>>2]=q;q=JD(f)|0;c[(c[m>>2]|0)+124>>2]=q;hD(f,12,0)|0;q=j+8|0;c[(c[q>>2]|0)+8>>2]=1;m=c[n+4>>2]|0;o=j+64|0;c[o>>2]=c[n>>2];c[o+4>>2]=m;m=JD(f)|0;c[(c[q>>2]|0)+412>>2]=m;_X(j,33,1,m);m=JD(f)|0;if((m|0)<1){KIb(a,16,2282352,(r=i,i=i+8|0,c[r>>2]=m,r)|0);i=r;k=-1094995529;i=b;return k|0}o=c[q>>2]|0;c[o+416>>2]=m;p=(m|0)==1;m=o+448|0;c[m>>2]=p?4:3;c[m+4>>2]=p?0:0;p=JD(f)|0;if((p|0)==401){c[(c[q>>2]|0)+48>>2]=65537}else{QIb(a,2315568,(r=i,i=i+8|0,c[r>>2]=p,r)|0);i=r}hD(f,12,0)|0;p=c[e>>2]|0;m=hJb(129)|0;if((m|0)!=0){o=LD(p,128,m,129)|0;if((o|0)<128){s=128-o|0;hD(p,s,(s|0)<0|0?-1:0)|0;}MGb(a+1140|0,2262712,m,8)|0}m=c[e>>2]|0;e=hJb(257)|0;if((e|0)!=0){s=LD(m,256,e,257)|0;if((s|0)<256){p=256-s|0;hD(m,p,(p|0)<0|0?-1:0)|0;}MGb(a+1140|0,2215432,e,8)|0}hD(f,128,0)|0;e=c[n+4>>2]|0;p=0;if((e|0)>(p|0)|(e|0)==(p|0)&(c[n>>2]|0)>>>0>0>>>0){t=0;u=0;v=0;w=0;x=0}else{k=0;i=b;return k|0}while(1){p=JD(f)|0;e=JD(f)|0;m=JD(f)|0;hD(f,8,0)|0;xX(j,p,0,v,u,e,0,1)|0;xX(l,e+p|0,0,x,w,m,0,1)|0;m=wrc((e>>>0)/(c[(c[q>>2]|0)+416>>2]<<1>>>0)|0,0,v,u)|0;e=t+1|0;p=e;s=(e|0)<0|0?-1:0;o=c[n+4>>2]|0;if((s|0)<(o|0)|(s|0)==(o|0)&p>>>0<(c[n>>2]|0)>>>0){t=e;u=G;v=m;w=s;x=p}else{k=0;break}}i=b;return k|0}do{if((h|0)==23){if((HD(f)|0)!=3){break}hD(f,4,0)|0;gP(a,0,524);x=d+4|0;w=c[x>>2]|0;if((w|0)>1){QIb(a,2182328,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=-1163346256;i=b;return k|0}do{if((w|0)==0){y=0}else{v=ZX(a,0)|0;if((v|0)==0){k=-12;i=b;return k|0}u=v+8|0;c[(c[u>>2]|0)+8>>2]=1;gP(a,v,132);t=c[u>>2]|0;n=c[t+52>>2]|0;q=t+48|0;l=c[q>>2]|0;do{if((n|0)==100&(l|0)==401){if((c[t+792>>2]|0)!=16){z=401;h=31;break}c[q>>2]=65537;A=t}else{z=l;h=31}}while(0);if((h|0)==31){l=c[t+792>>2]|0;QIb(a,2153816,(r=i,i=i+24|0,c[r>>2]=n,c[r+8>>2]=z,c[r+16>>2]=l,r)|0);i=r;l=c[u>>2]|0;c[l+48>>2]=0;A=l}c[A+52>>2]=0;if((c[A+416>>2]|0)>=1){y=v;break}KIb(a,16,2129144,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=-1094995529;i=b;return k|0}}while(0);w=d;l=c[w>>2]|0;if((l|0)>1){QIb(a,2106080,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;k=-1163346256;i=b;return k|0}do{if((l|0)==0){B=0}else{q=ZX(a,0)|0;if((q|0)==0){k=-12;i=b;return k|0}else{c[(c[q+8>>2]|0)+8>>2]=0;gP(a,q,566);B=q;break}}}while(0);do{if((c[x>>2]|0)!=0){l=y+64|0;q=c[l+4>>2]|0;j=0;if(!((q|0)>(j|0)|(q|0)==(j|0)&(c[l>>2]|0)>>>0>0>>>0)){break}j=y+8|0;q=0;p=0;s=0;while(1){m=JD(f)|0;e=JD(f)|0;hD(f,8,0)|0;xX(y,m,0,s,p,e,0,1)|0;m=c[j>>2]|0;if((c[m+8>>2]|0)==1){C=0;D=(e>>>0)/(c[m+416>>2]<<1>>>0)|0}else{C=0;D=1}m=wrc(D,C,s,p)|0;e=q+1|0;o=(e|0)<0|0?-1:0;E=c[l+4>>2]|0;if((o|0)<(E|0)|(o|0)==(E|0)&e>>>0<(c[l>>2]|0)>>>0){q=e;p=G;s=m}else{break}}}}while(0);if((c[w>>2]|0)==0){k=0;i=b;return k|0}x=B+64|0;s=c[x+4>>2]|0;p=0;if(!((s|0)>(p|0)|(s|0)==(p|0)&(c[x>>2]|0)>>>0>0>>>0)){k=0;i=b;return k|0}p=B+8|0;s=0;q=0;l=0;while(1){j=JD(f)|0;v=JD(f)|0;hD(f,8,0)|0;xX(B,j,0,l,q,v,0,1)|0;j=c[p>>2]|0;if((c[j+8>>2]|0)==1){F=0;H=(v>>>0)/(c[j+416>>2]<<1>>>0)|0}else{F=0;H=1}j=wrc(H,F,l,q)|0;v=s+1|0;u=(v|0)<0|0?-1:0;n=c[x+4>>2]|0;if((u|0)<(n|0)|(u|0)==(n|0)&v>>>0<(c[x>>2]|0)>>>0){s=v;q=G;l=j}else{k=0;break}}i=b;return k|0}}while(0);QIb(a,2624104,(r=i,i=i+8|0,c[r>>2]=g,r)|0);i=r;k=-1163346256;i=b;return k|0}function eP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=d+12|0;g=c[f>>2]|0;h=c[(c[a+28>>2]|0)+(g<<2)>>2]|0;i=d+16|0;j=c[i+(g<<2)>>2]|0;do{if((j|0)<(c[h+404>>2]|0)){k=c[h+400>>2]|0;l=fD(e,0,0,1)|0;m=G;n=k+(j*24|0)|0;o=c[n>>2]|0;p=c[n+4>>2]|0;do{if(p>>>0>m>>>0|p>>>0==m>>>0&o>>>0>l>>>0){n=xrc(o,p,l,m)|0;hD(e,n,G)|0;}else{if(!(p>>>0<m>>>0|p>>>0==m>>>0&o>>>0<l>>>0)){break}if((c[e+88>>2]|0)==0){q=-5;return q|0}n=fD(e,o,p,0)|0;r=n;if((r|0)<0){q=r}else{break}return q|0}}while(0);p=fX(e,b,c[k+(j*24|0)+16>>2]>>2)|0;if((p|0)<0){q=p;return q|0}else{c[b+32>>2]=c[f>>2];p=k+(j*24|0)+8|0;o=c[p+4>>2]|0;l=b+8|0;c[l>>2]=c[p>>2];c[l+4>>2]=o;o=b+36|0;c[o>>2]=c[o>>2]|1;o=i+(c[f>>2]<<2)|0;c[o>>2]=(c[o>>2]|0)+1;c[d+8>>2]=0;s=c[f>>2]|0;t=a+24|0;break}}else{o=d+8|0;l=(c[o>>2]|0)+1|0;c[o>>2]=l;o=a+24|0;if(l>>>0<(c[o>>2]|0)>>>0){s=g;t=o;break}else{q=-541478725}return q|0}}while(0);g=s+1|0;c[f>>2]=g;if(g>>>0<(c[t>>2]|0)>>>0){q=0;return q|0}c[f>>2]=0;q=0;return q|0}function fP(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[a+12>>2]|0;if((f&10|0)!=0){h=-38;return h|0}if((c[(c[a+16>>2]|0)+88>>2]|0)==0){h=-5;return h|0}i=CX(c[(c[a+28>>2]|0)+(b<<2)>>2]|0,d,e,f)|0;if((i|0)<0){h=-1;return h|0}f=a+24|0;if((c[f>>2]|0)==0){h=0;return h|0}a=g+16|0;g=0;while(1){c[a+(g<<2)>>2]=i;e=g+1|0;if(e>>>0<(c[f>>2]|0)>>>0){g=e}else{h=0;break}}return h|0}function gP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+24|0;g=f|0;h=c[b+16>>2]|0;hD(h,4,0)|0;j=JD(h)|0;hD(h,4,0)|0;if((j|0)<=0){i=f;return}k=g|0;l=g+16|0;g=b;m=0;do{AD(h,k,16)|0;a[l]=0;n=JD(h)|0;if((hf[e&1023](b,d,k,n)|0)<0){QIb(g,2286480,(o=i,i=i+8|0,c[o>>2]=k,o)|0);i=o;hD(h,n,(n|0)<0|0?-1:0)|0;}m=m+1|0;}while((m|0)<(j|0));i=f;return}function hP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+16|0;f=b|0;g=b+8|0;h=c[a+12>>2]|0;j=c[a+16>>2]|0;if((irc(d,2330264)|0)==0){k=e+1|0;l=hJb(k)|0;if((l|0)==0){m=0;n=6}else{o=LD(j,e,l,k)|0;if((o|0)<(e|0)){k=e-o|0;hD(j,k,(k|0)<0|0?-1:0)|0;}k=Bd(l|0,2377488,(p=i,i=i+8|0,c[p>>2]=g,p)|0)|0;i=p;if((k|0)==1){q=l}else{m=l;n=6}}if((n|0)==6){c[g>>2]=0;q=m}kJb(q);c[h>>2]=c[g>>2];r=0;i=b;return r|0}if((irc(d,2324248)|0)==0){g=e+1|0;q=hJb(g)|0;if((q|0)==0){s=0;n=13}else{m=LD(j,e,q,g)|0;if((m|0)<(e|0)){g=e-m|0;hD(j,g,(g|0)<0|0?-1:0)|0;}g=Bd(q|0,2377488,(p=i,i=i+8|0,c[p>>2]=f,p)|0)|0;i=p;if((g|0)==1){t=q}else{s=q;n=13}}if((n|0)==13){c[f>>2]=0;t=s}kJb(t);c[h+4>>2]=c[f>>2];r=0;i=b;return r|0}do{if((irc(d,2319072)|0)!=0){if((irc(d,2314224)|0)==0){break}do{if((irc(d,2309632)|0)!=0){if((irc(d,2305736)|0)==0){break}if((irc(d,2295464)|0)==0){break}else{r=-1}i=b;return r|0}}while(0);hD(j,e,(e|0)<0|0?-1:0)|0;r=0;i=b;return r|0}}while(0);f=e+1|0;h=hJb(f)|0;if((h|0)==0){r=0;i=b;return r|0}t=LD(j,e,h,f)|0;if((t|0)<(e|0)){f=e-t|0;hD(j,f,(f|0)<0|0?-1:0)|0;}MGb(a+1140|0,d,h,8)|0;r=0;i=b;return r|0}function iP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=c[a+16>>2]|0;if((irc(d,2597896)|0)==0){o=e+1|0;p=hJb(o)|0;if((p|0)==0){q=0;r=6}else{s=LD(n,e,p,o)|0;if((s|0)<(e|0)){o=e-s|0;hD(n,o,(o|0)<0|0?-1:0)|0;}o=Bd(p|0,2377488,(t=i,i=i+8|0,c[t>>2]=m,t)|0)|0;i=t;if((o|0)==1){u=p}else{q=p;r=6}}if((r|0)==6){c[m>>2]=0;u=q}kJb(u);u=c[m>>2]|0;m=b+64|0;c[m>>2]=u;c[m+4>>2]=(u|0)<0|0?-1:0;v=0;i=f;return v|0}if((irc(d,2371984)|0)==0){u=e+1|0;m=hJb(u)|0;if((m|0)==0){w=0;r=13}else{q=LD(n,e,m,u)|0;if((q|0)<(e|0)){u=e-q|0;hD(n,u,(u|0)<0|0?-1:0)|0;}u=Bd(m|0,2377488,(t=i,i=i+8|0,c[t>>2]=l,t)|0)|0;i=t;if((u|0)==1){x=m}else{w=m;r=13}}if((r|0)==13){c[l>>2]=0;x=w}kJb(x);c[(c[b+8>>2]|0)+48>>2]=c[l>>2];v=0;i=f;return v|0}if((irc(d,2573400)|0)==0){l=e+1|0;x=hJb(l)|0;if((x|0)==0){y=0;r=20}else{w=LD(n,e,x,l)|0;if((w|0)<(e|0)){l=e-w|0;hD(n,l,(l|0)<0|0?-1:0)|0;}l=Bd(x|0,2377488,(t=i,i=i+8|0,c[t>>2]=k,t)|0)|0;i=t;if((l|0)==1){z=x}else{y=x;r=20}}if((r|0)==20){c[k>>2]=0;z=y}kJb(z);c[(c[b+8>>2]|0)+52>>2]=c[k>>2];v=0;i=f;return v|0}if((irc(d,2359240)|0)==0){k=e+1|0;z=hJb(k)|0;if((z|0)==0){v=0;i=f;return v|0}y=LD(n,e,z,k)|0;if((y|0)<(e|0)){k=e-y|0;hD(n,k,(k|0)<0|0?-1:0)|0;}MGb(a+1140|0,d,z,8)|0;v=0;i=f;return v|0}if((irc(d,2347552)|0)==0){z=e+1|0;k=hJb(z)|0;if((k|0)==0){A=0;r=32}else{y=LD(n,e,k,z)|0;if((y|0)<(e|0)){z=e-y|0;hD(n,z,(z|0)<0|0?-1:0)|0;}z=Bd(k|0,2377488,(t=i,i=i+8|0,c[t>>2]=j,t)|0)|0;i=t;if((z|0)==1){B=k}else{A=k;r=32}}if((r|0)==32){c[j>>2]=0;B=A}kJb(B);B=c[j>>2]|0;if((B|0)<1){KIb(a,16,2282352,(t=i,i=i+8|0,c[t>>2]=B,t)|0);i=t;v=-1094995529;i=f;return v|0}else{a=c[b+8>>2]|0;c[a+416>>2]=B;j=(B|0)==1;B=a+448|0;c[B>>2]=j?4:3;c[B+4>>2]=j?0:0;v=0;i=f;return v|0}}if((irc(d,2341232)|0)==0){j=e+1|0;B=hJb(j)|0;if((B|0)==0){C=0;r=41}else{a=LD(n,e,B,j)|0;if((a|0)<(e|0)){j=e-a|0;hD(n,j,(j|0)<0|0?-1:0)|0;}j=Bd(B|0,2377488,(t=i,i=i+8|0,c[t>>2]=h,t)|0)|0;i=t;if((j|0)==1){D=B}else{C=B;r=41}}if((r|0)==41){c[h>>2]=0;D=C}kJb(D);D=c[h>>2]|0;c[(c[b+8>>2]|0)+412>>2]=D;_X(b,33,1,D);v=0;i=f;return v|0}if((irc(d,2335520)|0)!=0){v=-1;i=f;return v|0}d=e+1|0;D=hJb(d)|0;if((D|0)==0){E=0;r=48}else{h=LD(n,e,D,d)|0;if((h|0)<(e|0)){d=e-h|0;hD(n,d,(d|0)<0|0?-1:0)|0;}d=Bd(D|0,2377488,(t=i,i=i+8|0,c[t>>2]=g,t)|0)|0;i=t;if((d|0)==1){F=D}else{E=D;r=48}}if((r|0)==48){c[g>>2]=0;F=E}kJb(F);c[(c[b+8>>2]|0)+792>>2]=c[g>>2]<<3;v=0;i=f;return v|0}function jP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=c[a+16>>2]|0;if((irc(d,2597896)|0)==0){o=e+1|0;p=hJb(o)|0;if((p|0)==0){q=0;r=6}else{s=LD(n,e,p,o)|0;if((s|0)<(e|0)){o=e-s|0;hD(n,o,(o|0)<0|0?-1:0)|0;}o=Bd(p|0,2377488,(t=i,i=i+8|0,c[t>>2]=m,t)|0)|0;i=t;if((o|0)==1){u=p}else{q=p;r=6}}if((r|0)==6){c[m>>2]=0;u=q}kJb(u);u=c[m>>2]|0;m=u;q=(u|0)<0|0?-1:0;u=b+56|0;c[u>>2]=m;c[u+4>>2]=q;u=b+64|0;c[u>>2]=m;c[u+4>>2]=q;v=0;i=f;return v|0}if((irc(d,2573400)|0)==0){q=e+1|0;u=hJb(q)|0;if((u|0)==0){v=-1094995529;i=f;return v|0}m=LD(n,e,u,q)|0;if((m|0)<(e|0)){q=e-m|0;hD(n,q,(q|0)<0|0?-1:0)|0;}do{if((irc(u,2554976)|0)==0){c[(c[b+8>>2]|0)+48>>2]=1297498929}else{if((irc(u,2537136)|0)==0){q=c[b+8>>2]|0;c[q+140>>2]=29;c[q+48>>2]=14;break}if((irc(u,2521016)|0)==0){c[(c[b+8>>2]|0)+48>>2]=1397180754;break}if((irc(u,2506544)|0)==0){c[(c[b+8>>2]|0)+48>>2]=8;break}if((irc(u,2492256)|0)==0){c[(c[b+8>>2]|0)+48>>2]=1297498930;break}else{QIb(a,2482480,(t=i,i=i+8|0,c[t>>2]=u,t)|0);i=t;break}}}while(0);kJb(u);v=0;i=f;return v|0}if((irc(d,2471176)|0)==0){u=e+1|0;q=hJb(u)|0;if((q|0)==0){w=0;x=0}else{m=LD(n,e,q,u)|0;if((m|0)<(e|0)){u=e-m|0;hD(n,u,(u|0)<0|0?-1:0)|0;}AKb(l,+SGb(q,0),2147483647);u=c[l>>2]|0;m=c[l+4>>2]|0;kJb(q);w=u;x=m}_X(b,64,x,w);v=0;i=f;return v|0}if((irc(d,2463264)|0)==0){w=e+1|0;x=hJb(w)|0;if((x|0)==0){y=0;r=35}else{m=LD(n,e,x,w)|0;if((m|0)<(e|0)){w=e-m|0;hD(n,w,(w|0)<0|0?-1:0)|0;}w=Bd(x|0,2377488,(t=i,i=i+8|0,c[t>>2]=k,t)|0)|0;i=t;if((w|0)==1){z=x}else{y=x;r=35}}if((r|0)==35){c[k>>2]=0;z=y}kJb(z);c[(c[b+8>>2]|0)+124>>2]=c[k>>2];v=0;i=f;return v|0}if((irc(d,2448368)|0)==0){k=b+80|0;z=e+1|0;y=hJb(z)|0;if((y|0)==0){A=0;B=0;C=0;D=0}else{x=LD(n,e,y,z)|0;if((x|0)<(e|0)){z=e-x|0;hD(n,z,(z|0)<0|0?-1:0)|0;}AKb(j,+SGb(y,0),2147483647);z=c[j>>2]|0;x=c[j+4>>2]|0;kJb(y);A=x&0;B=z|0;C=x|0;D=z&0}z=k;c[z>>2]=B|D;c[z+4>>2]=A|C;A=B;xKb(k|0,b+84|0,A,(A|0)<0|0?-1:0,C,(C|0)<0|0?-1:0,2147483647,0)|0;v=0;i=f;return v|0}if((irc(d,2432928)|0)==0){C=e+1|0;A=hJb(C)|0;if((A|0)==0){E=0;r=48}else{k=LD(n,e,A,C)|0;if((k|0)<(e|0)){C=e-k|0;hD(n,C,(C|0)<0|0?-1:0)|0;}C=Bd(A|0,2377488,(t=i,i=i+8|0,c[t>>2]=h,t)|0)|0;i=t;if((C|0)==1){F=A}else{E=A;r=48}}if((r|0)==48){c[h>>2]=0;F=E}kJb(F);c[(c[b+8>>2]|0)+120>>2]=c[h>>2];v=0;i=f;return v|0}if((irc(d,2424240)|0)==0){h=e+1|0;F=hJb(h)|0;if((F|0)==0){G=0;r=55}else{E=LD(n,e,F,h)|0;if((E|0)<(e|0)){h=e-E|0;hD(n,h,(h|0)<0|0?-1:0)|0;}h=Bd(F|0,2377488,(t=i,i=i+8|0,c[t>>2]=g,t)|0)|0;i=t;if((h|0)==1){H=F}else{G=F;r=55}}if((r|0)==55){c[g>>2]=0;H=G}kJb(H);if((c[g>>2]|0)!=1101){v=0;i=f;return v|0}g=rJb(2413368)|0;H=b+8|0;c[(c[H>>2]|0)+96>>2]=g;c[(c[H>>2]|0)+100>>2]=9;v=0;i=f;return v|0}do{if((irc(d,2405720)|0)!=0){if((irc(d,2398248)|0)==0){break}do{if((irc(d,2391216)|0)!=0){if((irc(d,2384504)|0)==0){break}else{v=-1}i=f;return v|0}}while(0);hD(n,e,(e|0)<0|0?-1:0)|0;v=0;i=f;return v|0}}while(0);H=e+1|0;g=hJb(H)|0;if((g|0)==0){v=0;i=f;return v|0}b=LD(n,e,g,H)|0;if((b|0)<(e|0)){H=e-b|0;hD(n,H,(H|0)<0|0?-1:0)|0;}MGb(a+1140|0,d,g,8)|0;v=0;i=f;return v|0}function kP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=c[b+12>>2]|0;f=c[b+16>>2]|0;g=ZX(b,0)|0;if((g|0)==0){h=-12;i=d;return h|0}j=ZX(b,0)|0;if((j|0)==0){h=-12;i=d;return h|0}k=j+8|0;if((PX(c[k>>2]|0,2)|0)!=0){h=-12;i=d;return h|0}l=zD(f)|0;m=(zD(f)|0)&255;a[c[(c[k>>2]|0)+96>>2]|0]=m;m=(zD(f)|0)&255;a[(c[(c[k>>2]|0)+96>>2]|0)+1|0]=m;m=FD(f)|0;n=FD(f)|0;o=DD(f)|0;c[(c[k>>2]|0)+120>>2]=o;o=DD(f)|0;c[(c[k>>2]|0)+124>>2]=o;zD(f)|0;o=DD(f)|0;p=g+8|0;c[(c[p>>2]|0)+412>>2]=o;o=e+4|0;c[o>>2]=FD(f)|0;zD(f)|0;q=FD(f)|0;DD(f)|0;zD(f)|0;if((m|0)==0){h=-1094995529;i=d;return h|0}if((c[o>>2]|0)==0){h=-1094995529;i=d;return h|0}if((l|0)!=7|q>>>0>213>>>0){KIb(b,16,2386400,(r=i,i=i+16|0,c[r>>2]=l,c[r+8>>2]=q,r)|0);i=r;h=-1094995529;i=d;return h|0}_X(g,64,1,c[(c[p>>2]|0)+412>>2]|0);g=c[p>>2]|0;c[g+8>>2]=1;c[g+48>>2]=65541;c[g+416>>2]=1;q=g+448|0;c[q>>2]=4;c[q+4>>2]=0;c[g+792>>2]=8;c[g+72>>2]=c[g+412>>2]<<3;_X(j,64,n,1e6);n=j+92|0;g=c[j+40>>2]|0;c[n>>2]=c[j+44>>2];c[n+4>>2]=g;g=c[k>>2]|0;c[g+8>>2]=0;c[g+48>>2]=120;k=(ca(c[g+124>>2]|0,c[g+120>>2]|0)|0)<65536;c[e>>2]=k?1142:2848;k=c[o>>2]|0;o=k;g=Frc(o<<10|0>>>22,0<<10|o>>>22,m,0)|0;o=G;n=e+16|0;c[n>>2]=g;c[n+4>>2]=o;n=0;if(o>>>0<n>>>0|o>>>0==n>>>0&g>>>0<513>>>0){KIb(b,16,2315416,(r=i,i=i+16|0,c[r>>2]=k,c[r+8>>2]=m,r)|0);i=r;h=-1094995529;i=d;return h|0}else{r=(c[(c[p>>2]|0)+412>>2]|0)*830|0;p=Frc(r,(r|0)<0|0?-1:0,g,o)|0;r=wrc(p,G,-1,-1)|0;p=Erc(r,G,g,o)|0;o=e+8|0;c[o>>2]=p;c[o+4>>2]=G;c[e+24>>2]=k;h=0;i=d;return h|0}return 0}function lP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;a=d+28|0;f=c[a>>2]|0;if((f|0)!=0){g=fX(e,b,f)|0;if((g|0)<0){h=g;return h|0}c[b+32>>2]=1;c[a>>2]=0;h=0;return h|0}c[a>>2]=ve[c[d>>2]&4095](e)|0;a=d+24|0;g=c[a>>2]|0;if((g|0)==0){h=-5;return h|0}f=d+8|0;i=d+16|0;d=c[i>>2]|0;j=c[i+4>>2]|0;k=wrc(c[f>>2]|0,c[f+4>>2]|0,512,0)|0;l=wrc(k,G,d,j)|0;j=l>>>10|G<<22;l=(j|0)>(g|0)?g:j;j=fX(e,b,l)|0;if((j|0)<0){h=j;return h|0}c[b+32>>2]=0;c[a>>2]=(c[a>>2]|0)-l;a=l<<10;l=xrc(c[i>>2]|0,c[i+4>>2]|0,a,(a|0)<0|0?-1:0)|0;a=wrc(l,G,c[f>>2]|0,c[f+4>>2]|0)|0;c[f>>2]=a;c[f+4>>2]=G;h=0;return h|0}function mP(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0;b=c[a+4>>2]|0;e=c[a+8>>2]|0;if(e>>>0<14>>>0){f=0;return f|0}a=e-14|0;e=b+a|0;if((a|0)>0){g=b}else{f=0;return f|0}a:while(1){if(((d[g+13|0]|0)+255&242|0)==0){b=g;do{if((d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)==875236870){a=g+4|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=16844034){break}a=g+8|0;if((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)!=16908557){break}a=g+12|0;if((d[a]|d[a+1|0]<<8)<<16>>16<<16>>16==513){f=100;h=11;break a}}}while(0);i=g+1|0}else{i=g+10|0}if(i>>>0<e>>>0){g=i}else{f=0;h=11;break}}if((h|0)==11){return f|0}return 0}function nP(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0;e=i;i=i+120|0;f=e|0;g=e+8|0;h=e+32|0;j=e+40|0;k=e+56|0;l=e+88|0;m=b+12|0;n=c[m>>2]|0;o=n+112|0;c[o>>2]=-1;c[o+4>>2]=2147483647;c[n+136>>2]=1;p=b+16|0;q=c[p>>2]|0;a:do{if((jD(q)|0)==0){r=0;while(1){s=zD(q)|0;if((s|0)==6){t=1}else{u=(s|0)==(d[788896+r|0]|0)?r+1|0:0;if(u>>>0<14>>>0){t=u}else{break}}if((jD(q)|0)==0){r=t}else{break a}}if((u|0)!=14){break}fD(c[p>>2]|0,-14,-1,1)|0;r=n+28|0;c[r>>2]=b;s=fD(c[p>>2]|0,0,0,1)|0;v=n+100|0;c[v>>2]=s;s=k|0;w=c[m>>2]|0;x=c[p>>2]|0;if((c[x+88>>2]|0)==0){y=x}else{z=iD(x)|0;x=G;A=c[p>>2]|0;B=wrc(z,x,-4,-1)|0;fD(A,B,G,0)|0;B=JD(c[p>>2]|0)|0;b:do{if(!(B>>>0<33>>>0)){A=B;C=0;D=0;E=(x|0)>(D|0)|(x|0)==(D|0)&z>>>0>2147483647>>>0;D=E?0:x;if(!((C|0)<(D|0)|(C|0)==(D|0)&A>>>0<(E?2147483647:z)>>>0)){break}E=c[p>>2]|0;D=xrc(z,x,A,C)|0;fD(E,D,G,0)|0;D=c[p>>2]|0;if((jD(D)|0)==0){F=0}else{break}while(1){E=zD(D)|0;if((E|0)==6){H=1}else{I=(E|0)==(d[788768+F|0]|0)?F+1|0:0;if(I>>>0<4>>>0){H=I}else{break}}if((jD(D)|0)==0){F=H}else{break b}}if((I|0)!=4){break}E=fD(D,0,0,1)|0;C=wrc(E,G,-4,-1)|0;E=k+16|0;c[E>>2]=C;c[E+4>>2]=G;c[k>>2]=875236870;AD(D,k+4|0,12)|0;E=zD(D)|0;C=E;A=(E|0)<0|0?-1:0;c:do{if((C&128|0)==0&(A&0|0)==0){J=A;K=C;L=20}else{M=E&127;do{if(M>>>0>8>>>0){N=-1;O=-1094995529}else{if((M|0)==0){N=0;O=0;break}else{P=0;Q=0;R=M}while(1){S=R-1|0;T=zD(D)|0;U=T|(Q<<8|0>>>24);V=((T|0)<0|0?-1:0)|(P<<8|Q>>>24);if((S|0)==0){J=V;K=U;L=20;break c}else{P=V;Q=U;R=S}}}}while(0);M=k+24|0;c[M>>2]=O;c[M+4>>2]=N;W=N;X=O}}while(0);if((L|0)==20){D=k+24|0;c[D>>2]=K;c[D+4>>2]=J;if((K|0)==(-1|0)&(J|0)==(-1|0)){break}else{W=J;X=K}}if((grc(s,786256,16)|0)!=0){break}if(!((X|0)==(B-20|0)&(W|0)==0)){break}D=c[p>>2]|0;E=wrc(X,W,-12,-1)|0;hD(D,E,G)|0;E=OD(c[p>>2]|0)|0;D=w+48|0;c[D>>2]=E;c[D+4>>2]=G}}while(0);B=c[w+100>>2]|0;fD(c[p>>2]|0,B,(B|0)<0|0?-1:0,0)|0;y=c[p>>2]|0}do{if((jD(y)|0)==0){B=l+16|0;s=l;x=l+4|0;z=l+24|0;D=l|0;E=n+104|0;C=n+8|0;A=n+108|0;M=n+56|0;S=n+48|0;U=l+13|0;V=l+5|0;T=j|0;Y=n+40|0;Z=n+36|0;_=n+20|0;$=n+24|0;aa=-1;ba=-1;ca=0;da=1;ea=0;fa=0;d:while(1){ga=fD(c[p>>2]|0,0,0,1)|0;if((ga|0)==(ba|0)&(G|0)==(aa|0)){L=28;break}ga=wrc(da,ca,1,0)|0;ha=G;ia=Grc(0,536870912,da,ca)|0;if((ia|0)==0&(G|0)==0){ia=fD(c[p>>2]|0,0,0,1)|0;ja=G;ka=ia}else{ja=aa;ka=ba}ia=c[p>>2]|0;e:do{if((jD(ia)|0)==0){la=0;while(1){ma=zD(ia)|0;if((ma|0)==6){na=1}else{oa=(ma|0)==(d[788768+la|0]|0)?la+1|0:0;if(oa>>>0<4>>>0){na=oa}else{break}}if((jD(ia)|0)==0){la=na}else{L=42;break e}}if((oa|0)!=4){L=42;break}la=fD(ia,0,0,1)|0;ma=wrc(la,G,-4,-1)|0;c[B>>2]=ma;c[B+4>>2]=G;c[s>>2]=875236870;AD(ia,x,12)|0;ma=zD(ia)|0;la=ma;pa=(ma|0)<0|0?-1:0;f:do{if((la&128|0)==0&(pa&0|0)==0){qa=pa;ra=la;L=41}else{sa=ma&127;do{if(sa>>>0>8>>>0){ta=-1;ua=-1094995529}else{if((sa|0)==0){ta=0;ua=0;break}else{va=0;wa=0;xa=sa}while(1){ya=xa-1|0;za=zD(ia)|0;Aa=za|(wa<<8|0>>>24);Ba=((za|0)<0|0?-1:0)|(va<<8|wa>>>24);if((ya|0)==0){qa=Ba;ra=Aa;L=41;break f}else{va=Ba;wa=Aa;xa=ya}}}}while(0);c[z>>2]=ua;c[z+4>>2]=ta}}while(0);if((L|0)==41){L=0;c[z>>2]=ra;c[z+4>>2]=qa;if((ra|0)==(-1|0)&(qa|0)==(-1|0)){L=42;break}}do{if((grc(D,790816,16)|0)!=0){if((grc(D,788976,12)|0)==0){break}if((grc(D,790896,12)|0)==0){break}if((grc(D,785912,13)|0)==0){break}do{if((grc(D,788896,13)|0)==0){if(!(((a[U]|0)-2&255)>>>0<3>>>0)){Ca=786544;break}ma=c[E>>2]|0;if((ma|0)==0){Ca=786544;break}if((c[A>>2]|0)==0){Ca=786544;break}la=c[v>>2]|0;pa=ma+16|0;ma=wrc(la,(la|0)<0|0?-1:0,c[pa>>2]|0,c[pa+4>>2]|0)|0;pa=G;la=c[o+4>>2]|0;if(!(pa>>>0>la>>>0|pa>>>0==la>>>0&ma>>>0>(c[o>>2]|0)>>>0)){Da=ea;Ea=fa;break d}fD(c[(c[r>>2]|0)+16>>2]|0,ma,pa,0)|0;c[E>>2]=0;if((c[A>>2]|0)==0){Ca=786544}else{Fa=ea;Ga=fa;break e}}else{Ca=786544}}while(0);while(1){Ha=Ca+16|0;Ia=c[Ha>>2]|0;if((Ia|0)==0){break}if((grc(D,Ca|0,16)|0)==0){L=76;break}else{Ca=Ca+28|0}}if((L|0)==76){L=0;do{if((a[V]|0)==83){pa=c[Ca+20>>2]|0;ma=c[Ca+24>>2]|0;la=c[(c[r>>2]|0)+16>>2]|0;Ja=(pa|0)!=0;if(Ja){Ka=pJb(pa)|0}else{Ka=n}pa=fD(la,0,0,1)|0;sa=wrc(c[z>>2]|0,c[z+4>>2]|0,pa,G)|0;pa=G;if((Ka|0)==0){La=-12;L=121;break d}ya=fD(la,0,0,1)|0;Aa=wrc(ya,G,4,0)|0;ya=G;g:do{if(ya>>>0<pa>>>0|ya>>>0==pa>>>0&Aa>>>0<sa>>>0){if(!Ja){while(1){if((jD(la)|0)!=0){break g}Ba=HD(la)|0;za=HD(la)|0;Ma=fD(la,0,0,1)|0;Na=wrc(Ma,G,za,(za|0)<0|0?-1:0)|0;Ma=G;mrc(T|0,0,16)|0;do{if((za|0)==0){KIb(c[r>>2]|0,16,2225344,(Oa=i,i=i+8|0,c[Oa>>2]=Ba,Oa)|0);i=Oa}else{do{if((Ba|0)>32767){Pa=c[Y>>2]|0;if((Pa|0)<=0){break}Qa=c[Z>>2]|0;Ra=0;do{Sa=Ra*18|0;Ta=Qa+Sa|0;if(((he((d[Ta]|d[Ta+1|0]<<8)<<16>>16|0)|0)&65535|0)==(Ba|0)){nrc(T|0,Qa+(Sa+2)|0,16)|0}Ra=Ra+1|0;}while((Ra|0)<(Pa|0))}}while(0);Pa=me[Ia&255](Ka,la,Ba,za,T,-1,-1)|0;if((Pa|0)<0){La=Pa;L=121;break d}Pa=fD(la,0,0,1)|0;Ra=G;if(Ra>>>0>pa>>>0|Ra>>>0==pa>>>0&Pa>>>0>sa>>>0){Ua=Ba;L=110;break d}Pa=fD(la,0,0,1)|0;Ra=G;if(Ra>>>0>Ma>>>0|Ra>>>0==Ma>>>0&Pa>>>0>Na>>>0){break}fD(la,Na,Ma,0)|0;}}while(0);Ma=fD(la,0,0,1)|0;Na=wrc(Ma,G,4,0)|0;Ma=G;if(!(Ma>>>0<pa>>>0|Ma>>>0==pa>>>0&Na>>>0<sa>>>0)){break g}}}do{if((jD(la)|0)!=0){break g}Na=HD(la)|0;Ma=HD(la)|0;Ba=fD(la,0,0,1)|0;za=wrc(Ba,G,Ma,(Ma|0)<0|0?-1:0)|0;Ba=G;mrc(T|0,0,16)|0;do{if((Ma|0)==0){KIb(c[r>>2]|0,16,2225344,(Oa=i,i=i+8|0,c[Oa>>2]=Na,Oa)|0);i=Oa}else{do{if((Na|0)>32767){Pa=c[Y>>2]|0;if((Pa|0)<=0){break}Ra=c[Z>>2]|0;Qa=0;do{Sa=Qa*18|0;Ta=Ra+Sa|0;if(((he((d[Ta]|d[Ta+1|0]<<8)<<16>>16|0)|0)&65535|0)==(Na|0)){nrc(T|0,Ra+(Sa+2)|0,16)|0}Qa=Qa+1|0;}while((Qa|0)<(Pa|0))}}while(0);if((Na|0)==15370){AD(la,Ka,16)|0}else{Pa=me[Ia&255](Ka,la,Na,Ma,T,-1,-1)|0;if((Pa|0)<0){La=Pa;L=121;break d}}Pa=fD(la,0,0,1)|0;Qa=G;if(Qa>>>0>pa>>>0|Qa>>>0==pa>>>0&Pa>>>0>sa>>>0){Ua=Na;L=110;break d}Pa=fD(la,0,0,1)|0;Qa=G;if(Qa>>>0>Ba>>>0|Qa>>>0==Ba>>>0&Pa>>>0>za>>>0){break}fD(la,za,Ba,0)|0;}}while(0);Ba=fD(la,0,0,1)|0;za=wrc(Ba,G,4,0)|0;Ba=G;}while(Ba>>>0<pa>>>0|Ba>>>0==pa>>>0&za>>>0<sa>>>0)}}while(0);if(!Ja){break}c[Ka+16>>2]=ma;sa=nJb(c[_>>2]|0,(c[$>>2]|0)+1|0,4)|0;pa=sa;if((sa|0)==0){La=-12;L=121;break d}c[_>>2]=pa;sa=c[$>>2]|0;c[pa+(sa<<2)>>2]=Ka;c[$>>2]=sa+1}else{sa=fD(c[p>>2]|0,0,0,1)|0;pa=c[z>>2]|0;la=wrc(pa,c[z+4>>2]|0,sa,G)|0;sa=G;Aa=me[c[Ha>>2]&255](n,c[p>>2]|0,0,pa,D,c[B>>2]|0,c[B+4>>2]|0)|0;pa=fD(c[p>>2]|0,0,0,1)|0;ya=G;if(ya>>>0>sa>>>0|ya>>>0==sa>>>0&pa>>>0>la>>>0){L=119;break d}fD(c[p>>2]|0,la,sa,0)|0;if((Aa|0)<0){La=Aa;L=121;break d}}}while(0);if((c[Ha>>2]|0)!=0){Fa=ea;Ga=fa;break e}}hD(c[p>>2]|0,c[z>>2]|0,c[z+4>>2]|0)|0;Fa=ea;Ga=fa;break e}}while(0);Aa=c[E>>2]|0;if((Aa|0)==0){L=51;break d}sa=Aa+40|0;do{if((c[sa>>2]|0)==0&(c[sa+4>>2]|0)==0){la=Aa+32|0;pa=c[Aa+80>>2]|0;ya=wrc(pa,(pa|0)<0|0?-1:0,c[la>>2]|0,c[la+4>>2]|0)|0;la=G;pa=c[Aa+56>>2]|0;za=pa;Ba=(pa|0)<0|0?-1:0;pa=Drc(ya,la,za,Ba)|0;Na=G;Ma=Aa+64|0;Pa=c[Ma>>2]|0;Qa=c[Ma+4>>2]|0;Ma=Drc(Pa,Qa,za,Ba)|0;Ra=G;Sa=Aa+72|0;Ta=c[Sa>>2]|0;Va=c[Sa+4>>2]|0;Sa=Drc(Ta,Va,za,Ba)|0;Wa=G;if((c[C>>2]|0)==10){Xa=fD(c[p>>2]|0,0,0,1)|0;Ya=c[E>>2]|0;Za=Ya+40|0;c[Za>>2]=Xa;c[Za+4>>2]=G;Za=c[z+4>>2]|0;Xa=Ya+48|0;c[Xa>>2]=c[z>>2];c[Xa+4>>2]=Za;_a=Ya;break}else{Ya=(Sa|0)==0&(Wa|0)==0;Za=(Ma|0)==0&(Ra|0)==0;Xa=(pa|0)==0&(Na|0)==0;$a=xrc(ya,la,pa,Na)|0;Na=wrc($a,G,Pa,Qa)|0;Qa=wrc(Na,G,Xa?0:za,Xa?0:Ba)|0;Xa=xrc(Qa,G,Ma,Ra)|0;Ra=wrc(Xa,G,Ta,Va)|0;Va=wrc(Ra,G,Za?0:za,Za?0:Ba)|0;Za=xrc(Va,G,Sa,Wa)|0;Wa=wrc(Za,G,Ya?0:za,Ya?0:Ba)|0;c[sa>>2]=Wa;c[sa+4>>2]=G;_a=Aa;break}}else{_a=Aa}}while(0);Aa=(fa|0)==0&(ea|0)==0;ab=Aa?c[B>>2]|0:fa;bb=Aa?c[B+4>>2]|0:ea;Aa=c[(c[r>>2]|0)+16>>2]|0;if((c[A>>2]|0)!=0){if((_a|0)==0){Da=bb;Ea=ab;break d}sa=c[v>>2]|0;Wa=_a+16|0;Ba=wrc(sa,(sa|0)<0|0?-1:0,c[Wa>>2]|0,c[Wa+4>>2]|0)|0;Wa=G;sa=c[o+4>>2]|0;if(!(Wa>>>0>sa>>>0|Wa>>>0==sa>>>0&Ba>>>0>(c[o>>2]|0)>>>0)){Da=bb;Ea=ab;break d}fD(Aa,Ba,Wa,0)|0;c[E>>2]=0;Fa=bb;Ga=ab;break}Wa=c[M>>2]|0;Ba=c[M+4>>2]|0;if((Wa|0)==0&(Ba|0)==0){sa=c[S>>2]|0;Ya=c[S+4>>2]|0;if((sa|0)==0&(Ya|0)==0){Da=bb;Ea=ab;break d}else{cb=Ya;db=sa}}else{cb=Ba;db=Wa}Wa=fD(Aa,0,0,1)|0;c[o>>2]=Wa;c[o+4>>2]=G;if((c[Aa+88>>2]|0)==0){L=63;break d}Wa=c[v>>2]|0;Ba=wrc(Wa,(Wa|0)<0|0?-1:0,db,cb)|0;Wa=fD(Aa,Ba,G,0)|0;Ba=G;Aa=0;if((Ba|0)<(Aa|0)|(Ba|0)==(Aa|0)&Wa>>>0<0>>>0){Aa=c[r>>2]|0;sa=c[v>>2]|0;Ya=wrc(sa,(sa|0)<0|0?-1:0,db,cb)|0;sa=G;KIb(Aa,16,2143616,(Oa=i,i=i+32|0,c[Oa>>2]=Ya,c[Oa+8>>2]=sa,c[Oa+16>>2]=Wa,c[Oa+24>>2]=Ba,Oa)|0);i=Oa;if((Wa|0)<1){Da=bb;Ea=ab;break d}else{Fa=bb;Ga=ab;break}}else{c[E>>2]=0;c[A>>2]=1;Fa=bb;Ga=ab;break}}else{L=42}}while(0);do{if((L|0)==42){L=0;if((c[A>>2]|0)==0){Fa=ea;Ga=fa;break}ia=c[(c[r>>2]|0)+16>>2]|0;Wa=c[E>>2]|0;if((Wa|0)==0){Da=ea;Ea=fa;break d}Ba=c[v>>2]|0;sa=Wa+16|0;Wa=wrc(Ba,(Ba|0)<0|0?-1:0,c[sa>>2]|0,c[sa+4>>2]|0)|0;sa=G;Ba=c[o+4>>2]|0;if(!(sa>>>0>Ba>>>0|sa>>>0==Ba>>>0&Wa>>>0>(c[o>>2]|0)>>>0)){Da=ea;Ea=fa;break d}fD(ia,Wa,sa,0)|0;c[E>>2]=0;Fa=ea;Ga=fa}}while(0);if((jD(c[p>>2]|0)|0)==0){aa=ja;ba=ka;ca=ha;da=ga;ea=Fa;fa=Ga}else{Da=Fa;Ea=Ga;break}}if((L|0)==28){KIb(c[r>>2]|0,16,2506512,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}else if((L|0)==51){KIb(c[r>>2]|0,16,2492208,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}else if((L|0)==63){KIb(c[r>>2]|0,32,2149568,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Da=bb;Ea=ab}else if((L|0)==110){if(Ja){kJb(Ka)}fa=c[B>>2]|0;ea=c[B+4>>2]|0;KIb(c[r>>2]|0,16,2220744,(Oa=i,i=i+24|0,c[Oa>>2]=Ua,c[Oa+8>>2]=fa,c[Oa+16>>2]=ea,Oa)|0);i=Oa;La=-1094995529;L=121}else if((L|0)==119){ea=c[B+4>>2]|0;KIb(b,16,2482432,(Oa=i,i=i+16|0,c[Oa>>2]=c[B>>2],c[Oa+8>>2]=ea,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}if((L|0)==121){KIb(b,16,2471144,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=La;i=e;return eb|0}if((Ea|0)==0&(Da|0)==0){break}fD(c[p>>2]|0,Ea,Da,0)|0;ea=n+8|0;h:do{if((c[ea>>2]|0)!=10){fa=n+4|0;da=c[fa>>2]|0;if((da|0)==0){break}ca=n;ba=0;aa=da;while(1){da=c[ca>>2]|0;do{if((c[da+(ba*88|0)+28>>2]|0)==0){fb=aa;gb=ba+1|0}else{if(!(ba>>>0<(aa-1|0)>>>0)){break h}E=ba+1|0;A=da+(E*88|0)+32|0;S=c[A>>2]|0;M=c[A+4>>2]|0;A=da+(ba*88|0)+40|0;z=xrc(S,M,c[A>>2]|0,c[A+4>>2]|0)|0;A=G;C=da+(ba*88|0)+48|0;c[C>>2]=z;c[C+4>>2]=A;D=0;if(!((A|0)<(D|0)|(A|0)==(D|0)&z>>>0<0>>>0)){fb=aa;gb=E;break}c[C>>2]=0;c[C+4>>2]=0;KIb(c[r>>2]|0,16,2228976,(Oa=i,i=i+24|0,c[Oa>>2]=E,c[Oa+8>>2]=S,c[Oa+16>>2]=M,Oa)|0);i=Oa;fb=c[fa>>2]|0;gb=E}}while(0);if(gb>>>0<fb>>>0){ba=gb;aa=fb}else{break}}}}while(0);B=n+16|0;aa=c[B>>2]|0;i:do{if((aa|0)>0){ba=n+12|0;fa=c[ba>>2]|0;ca=n+24|0;ga=n+20|0;ha=0;j:while(1){da=fa+(ha<<4)|0;k:do{if((da|0)==0){hb=0}else{E=c[ca>>2]|0;if((E|0)<=0){hb=0;break}M=da|0;S=c[ga>>2]|0;C=0;while(1){ib=c[S+(C<<2)>>2]|0;if((grc(M,ib|0,16)|0)==0){if((c[ib+16>>2]|0)==1){break}}z=C+1|0;if((z|0)<(E|0)){C=z}else{hb=0;break k}}C=ib;if((ib|0)==0){hb=C}else{jb=C;break j}}}while(0);da=ha+1|0;if((da|0)<(aa|0)){ha=da}else{jb=hb;break}}if((jb|0)==0){L=148;break}ha=jb+40|0;l:do{if((c[ha>>2]|0)>0){fa=jb+36|0;da=j|0;C=(a[1339168]|0)==0;E=(a[1339328]|0)==0;M=h|0;S=h+4|0;z=(a[1338928]|0)==0;D=0;m:while(1){A=(c[fa>>2]|0)+(D<<4)|0;n:do{if((A|0)==0){L=156}else{$=c[ca>>2]|0;if(($|0)<=0){L=156;break}_=A|0;T=c[ga>>2]|0;Z=0;while(1){kb=c[T+(Z<<2)>>2]|0;if((grc(_,kb|0,16)|0)==0){if((c[kb+16>>2]|0)==8){break}}Y=Z+1|0;if((Y|0)<($|0)){Z=Y}else{L=156;break n}}if((kb|0)==0){L=156;break}Z=kb+24|0;o:do{if((Z|0)==0){L=169}else{_=0;do{lb=c[T+(_<<2)>>2]|0;if((grc(Z,lb|0,16)|0)==0){if((c[lb+16>>2]|0)==4){L=161;break}}_=_+1|0;}while((_|0)<($|0));do{if((L|0)==161){L=0;if((lb|0)==0){break}if((rLb(g,lb+28|0,(c[lb+20>>2]|0)==1|0,c[lb+24>>2]|0,c[r>>2]|0)|0)!=0){break}_=(c[r>>2]|0)+1140|0;MGb(_,2335480,nLb(g,da,0)|0,0)|0}}while(0);_=c[ca>>2]|0;if((_|0)<=0){L=169;break}ma=c[ga>>2]|0;Y=0;while(1){mb=c[ma+(Y<<2)>>2]|0;if((grc(Z,mb|0,16)|0)==0){if((c[mb+16>>2]|0)==5){break}}V=Y+1|0;if((V|0)<(_|0)){Y=V}else{L=169;break o}}Y=mb;_=kb+20|0;c[_>>2]=Y;if((mb|0)==0){break}p:do{if((c[mb+40>>2]|0)>0){ma=0;V=Y;q:while(1){U=(c[V+36>>2]|0)+(ma<<4)|0;r:do{if((U|0)==0){nb=V}else{x=c[ca>>2]|0;if((x|0)<=0){nb=V;break}s=U|0;sa=c[ga>>2]|0;Wa=0;while(1){ob=c[sa+(Wa<<2)>>2]|0;if((grc(s,ob|0,16)|0)==0){if((c[ob+16>>2]|0)==4){break}}ia=Wa+1|0;if((ia|0)<(x|0)){Wa=ia}else{nb=V;break r}}if((ob|0)==0){nb=V;break}if((rLb(g,ob+28|0,(c[ob+20>>2]|0)==1|0,c[ob+24>>2]|0,c[r>>2]|0)|0)==0){break q}nb=c[_>>2]|0}}while(0);U=ma+1|0;if((U|0)<(c[nb+40>>2]|0)){ma=U;V=nb}else{pb=nb;break p}}V=(c[r>>2]|0)+1140|0;MGb(V,2335480,nLb(g,da,0)|0,0)|0;pb=c[_>>2]|0}else{pb=Y}}while(0);Y=c[pb+40>>2]|0;if((Y|0)<=0){break n}V=c[pb+36>>2]|0;ma=0;U=0;Wa=0;s:while(1){x=V+(Wa<<4)|0;t:do{if((x|0)==0){qb=U;rb=ma;sb=0}else{s=c[ca>>2]|0;if((s|0)<=0){qb=U;rb=ma;sb=0;break}sa=x|0;ia=c[ga>>2]|0;Ba=0;while(1){tb=c[ia+(Ba<<2)>>2]|0;if((grc(sa,tb|0,16)|0)==0){if((c[tb+16>>2]|0)==3){break}}Ya=Ba+1|0;if((Ya|0)<(s|0)){Ba=Ya}else{qb=U;rb=ma;sb=0;break t}}Ba=tb;if((tb|0)==0){qb=U;rb=ma;sb=Ba;break}sa=c[B>>2]|0;u:do{if((sa|0)>0){Ya=c[ba>>2]|0;Aa=tb+20|0;za=0;v:while(1){Za=Ya+(za<<4)|0;w:do{if((Za|0)!=0){Sa=Za|0;Va=0;while(1){ub=c[ia+(Va<<2)>>2]|0;if((grc(Sa,ub|0,16)|0)==0){if((c[ub+16>>2]|0)==2){break}}Va=Va+1|0;if((Va|0)>=(s|0)){break w}}if((ub|0)==0){break}if((grc(ub+20|0,Aa,16)|0)==0){break v}}}while(0);Za=za+1|0;if((Za|0)<(sa|0)){za=Za}else{vb=ma;break u}}vb=ub}else{vb=ma}}while(0);if((vb|0)==0){wb=Ba;xb=0;yb=U;break s}sa=c[vb+40>>2]|0;za=vb+36|0;Aa=tb+72|0;Ya=0;while(1){if((Ya|0)>=(sa|0)){zb=U;break}Za=(c[za>>2]|0)+(Ya<<4)|0;if((Za|0)==0){L=213;break m}Va=Za|0;Za=0;while(1){Ab=c[ia+(Za<<2)>>2]|0;if((grc(Va,Ab|0,16)|0)==0){if((c[Ab+16>>2]|0)==8){break}}Sa=Za+1|0;if((Sa|0)<(s|0)){Za=Sa}else{L=213;break m}}if((Ab|0)==0){L=213;break m}if((c[Ab+40>>2]|0)==(c[Aa>>2]|0)){zb=Ab;break}else{Ya=Ya+1|0}}if((zb|0)==0){L=216;break s}else{qb=zb;rb=vb;sb=Ba}}}while(0);x=Wa+1|0;if((x|0)<(Y|0)){ma=rb;U=qb;Wa=x}else{wb=sb;xb=rb;yb=qb;break}}if((L|0)==216){L=0;KIb(c[r>>2]|0,16,2319016,(Oa=i,i=i+8|0,c[Oa>>2]=c[kb+40>>2],Oa)|0);i=Oa;break n}if((yb|0)==0|(wb|0)==0){break n}Wa=yb+24|0;if((Wa|0)==0){L=225;break m}U=c[ca>>2]|0;if((U|0)<=0){L=225;break m}ma=Wa|0;Wa=c[ga>>2]|0;Y=0;while(1){Bb=c[Wa+(Y<<2)>>2]|0;if((grc(ma,Bb|0,16)|0)==0){if((c[Bb+16>>2]|0)==5){break}}V=Y+1|0;if((V|0)<(U|0)){Y=V}else{L=225;break m}}Y=yb+20|0;c[Y>>2]=Bb;if((Bb|0)==0){break m}U=(grc((c[_>>2]|0)+20|0,Bb+20|0,16)|0)==0;ma=c[r>>2]|0;if(!U){KIb(ma,16,2309584,(Oa=i,i=i+8|0,c[Oa>>2]=c[kb+40>>2],Oa)|0);i=Oa;break n}U=ZX(ma,0)|0;if((U|0)==0){L=231;break m}ma=yb+40|0;c[U+4>>2]=c[ma>>2];c[U+12>>2]=yb;Wa=wb+56|0;V=c[Wa>>2]|0;x=c[Wa+4>>2]|0;Wa=U+56|0;c[Wa>>2]=V;c[Wa+4>>2]=x;Ya=yb+72|0;c[Ya>>2]=V;c[Ya+4>>2]=x;if((c[Wa>>2]|0)==(-1|0)&(c[Wa+4>>2]|0)==(-1|0)){c[Wa>>2]=0;c[Wa+4>>2]=-2147483648}x=wb+64|0;Ya=c[x+4>>2]|0;V=U+48|0;c[V>>2]=c[x>>2];c[V+4>>2]=Ya;Ya=kb+48|0;V=Ya;x=c[V>>2]|0;Aa=kb+52|0;s=c[Aa>>2]|0;if((x|0)<1|(s|0)<1){ia=c[U>>2]|0;KIb(c[r>>2]|0,24,2295392,(Oa=i,i=i+24|0,c[Oa>>2]=x,c[Oa+8>>2]=s,c[Oa+16>>2]=ia,Oa)|0);i=Oa;c[V>>2]=25;c[Aa>>2]=1;Cb=1;Db=25}else{Cb=s;Db=x}_X(U,64,Cb,Db);x=Ya;Ya=yb+48|0;s=c[x+4>>2]|0;c[Ya>>2]=c[x>>2];c[Ya+4>>2]=s;s=c[Y>>2]|0;x:do{if(C){Eb=1339168}else{Y=1339168;while(1){Ya=c[Y+16>>2]|0;if((Ya|0)>0){Fb=0}else{Eb=Y;break x}while(1){if((Fb|0)!=7){if((a[Y+Fb|0]|0)!=(a[s+20+Fb|0]|0)){break}}x=Fb+1|0;if((x|0)<(Ya|0)){Fb=x}else{Eb=Y;break x}}Ya=Y+24|0;if((a[Ya|0]|0)==0){Eb=Ya;break}else{Y=Ya}}}}while(0);s=U+8|0;c[(c[s>>2]|0)+8>>2]=c[Eb+20>>2];_=xb+48|0;y:do{if((_|0)==0){L=247}else{Y=c[ca>>2]|0;if((Y|0)<=0){L=247;break}Ya=_|0;Ba=c[ga>>2]|0;x=0;while(1){Gb=c[Ba+(x<<2)>>2]|0;if((grc(Ya,Gb|0,16)|0)==0){break}ia=x+1|0;if((ia|0)<(Y|0)){x=ia}else{L=247;break y}}x=Gb;Y=xb+44|0;c[Y>>2]=x;if((Gb|0)==0){break}Ya=c[Gb+16>>2]|0;if((Ya|0)==6){if((c[Gb+108>>2]|0)>0){Hb=0;Ib=x}else{break}z:while(1){Ba=(c[Ib+104>>2]|0)+(Hb<<4)|0;A:do{if((Ba|0)==0){L=258}else{ia=c[ca>>2]|0;if((ia|0)<=0){L=258;break}za=Ba|0;sa=c[ga>>2]|0;Za=0;while(1){Jb=c[sa+(Za<<2)>>2]|0;if((grc(za,Jb|0,16)|0)==0){if((c[Jb+16>>2]|0)==7){break}}Va=Za+1|0;if((Va|0)<(ia|0)){Za=Va}else{L=258;break A}}if((Jb|0)==0){L=258;break}if((c[Jb+112>>2]|0)==(c[ma>>2]|0)){break z}else{Kb=Ib}}}while(0);if((L|0)==258){L=0;KIb(c[r>>2]|0,16,2286432,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Kb=c[Y>>2]|0}Ba=Hb+1|0;if((Ba|0)<(c[Kb+108>>2]|0)){Hb=Ba;Ib=Kb}else{break y}}Lb=Jb}else if((Ya|0)==7){Lb=x}else{break}if((Lb|0)==0){break}Y=Lb+20|0;B:do{if((grc(Y|0,790832,16)|0)==0){KIb(c[r>>2]|0,32,2278344,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Ba=c[ca>>2]|0;Za=0;while(1){if((Za|0)>=(Ba|0)){Mb=Y;break B}Nb=c[(c[ga>>2]|0)+(Za<<2)>>2]|0;if((c[Nb+16>>2]|0)==9){break}else{Za=Za+1|0}}Mb=Nb+20|0}else{Mb=Y}}while(0);C:do{if(E){Ob=1339328}else{Y=1339328;while(1){x=c[Y+16>>2]|0;if((x|0)>0){Pb=0}else{Ob=Y;break C}while(1){if((Pb|0)!=7){if((a[Y+Pb|0]|0)!=(a[Lb+36+Pb|0]|0)){break}}Ya=Pb+1|0;if((Ya|0)<(x|0)){Pb=Ya}else{Ob=Y;break C}}x=Y+24|0;if((a[x|0]|0)==0){Ob=x;break}else{Y=x}}}}while(0);Y=c[Ob+20>>2]|0;c[(c[s>>2]|0)+48>>2]=Y;x=c[r>>2]|0;Ya=u5a(Y)|0;KIb(x,40,2274240,(Oa=i,i=i+8|0,c[Oa>>2]=Ya,Oa)|0);i=Oa;Ya=0;x=c[r>>2]|0;while(1){KIb(x,40,2269056,(Oa=i,i=i+8|0,c[Oa>>2]=d[Lb+36+Ya|0]|0,Oa)|0);i=Oa;Y=Ya+1|0;if((Y&19|0)==0|(Ya|0)==5){KIb(c[r>>2]|0,40,2265152,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa}Qb=c[r>>2]|0;if((Y|0)<16){Ya=Y;x=Qb}else{break}}KIb(Qb,40,2261448,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;x=c[s>>2]|0;Ya=c[x+8>>2]|0;do{if((Ya|0)==1){Y=0;while(1){if((Y|0)==7){Y=8;continue}if((a[785928+Y|0]|0)!=(a[Mb+Y|0]|0)){Rb=0;L=352;break}Za=Y+1|0;if((Za|0)<14){Y=Za}else{Sb=785928;break}}D:do{if((L|0)==352){while(1){L=0;if((Rb|0)==7){Rb=8;L=352;continue}if((a[785952+Rb|0]|0)!=(a[Mb+Rb|0]|0)){Tb=0;break}Y=Rb+1|0;if((Y|0)<14){Rb=Y;L=352}else{Sb=785952;break D}}while(1){if((Tb|0)==7){Tb=8;continue}if((a[785976+Tb|0]|0)!=(a[Mb+Tb|0]|0)){Ub=0;break}Y=Tb+1|0;if((Y|0)<14){Tb=Y}else{Sb=785976;break D}}while(1){if((Ub|0)==7){Ub=8;continue}if((a[786e3+Ub|0]|0)!=(a[Mb+Ub|0]|0)){Sb=786024;break D}Y=Ub+1|0;if((Y|0)<14){Ub=Y}else{Sb=786e3;break}}}}while(0);Y=x+48|0;Za=c[Y>>2]|0;if((Za|0)==0){Vb=c[Sb+20>>2]|0;L=327}else if((Za|0)==65543){Za=c[Sb+20>>2]|0;if((Za|0)!=0){Vb=Za;L=327}}if((L|0)==327){L=0;c[Y>>2]=Vb}c[x+416>>2]=c[Lb+84>>2];Y=Lb+88|0;c[x+792>>2]=c[Y>>2];Za=Lb+52|0;Ba=Lb+56|0;ia=c[Ba>>2]|0;if((ia|0)>0){za=Za|0;c[x+412>>2]=(c[za>>2]|0)/(ia|0)|0;_X(U,64,c[Ba>>2]|0,c[za>>2]|0)}else{za=c[U>>2]|0;KIb(c[r>>2]|0,24,2232920,(Oa=i,i=i+24|0,c[Oa>>2]=c[Za>>2],c[Oa+8>>2]=ia,c[Oa+16>>2]=za,Oa)|0);i=Oa;_X(U,64,1,48e3)}za=c[Wa>>2]|0;ia=c[Wa+4>>2]|0;if(!((za|0)==0&(ia|0)==(-2147483648|0))){Za=c[V>>2]|0;c[M>>2]=c[Aa>>2];c[S>>2]=Za;Za=XIb(za,ia,h,U+40|0)|0;c[Wa>>2]=Za;c[Wa+4>>2]=G}Za=c[s>>2]|0;ia=Za+48|0;za=c[ia>>2]|0;if((za|0)==65536){Ba=c[Y>>2]|0;if((Ba-17|0)>>>0<8>>>0){c[ia>>2]=65548;Wb=Za;break}if((Ba|0)!=32){Wb=Za;break}c[ia>>2]=65544;Wb=Za;break}else if((za|0)==65537){Ba=c[Y>>2]|0;if((Ba-17|0)>>>0<8>>>0){c[ia>>2]=65549;Wb=Za;break}if((Ba|0)!=32){Wb=Za;break}c[ia>>2]=65545;Wb=Za;break}else if((za|0)==86016){c[U+236>>2]=1;Wb=Za;break}else{Wb=Za;break}}else if((Ya|0)==0){Za=0;while(1){if((Za|0)==7){Za=8;continue}if((a[788848+Za|0]|0)!=(a[Lb+20+Za|0]|0)){Xb=788872;break}za=Za+1|0;if((za|0)<14){Za=za}else{Xb=788848;break}}if((c[Xb+20>>2]|0)==0){Za=0;while(1){if((Za|0)==7){Za=8;continue}if((a[788776+Za|0]|0)!=(a[Lb+36+Za|0]|0)){Yb=0;L=288;break}za=Za+1|0;if((za|0)<14){Za=za}else{Zb=788776;break}}E:do{if((L|0)==288){while(1){L=0;if((Yb|0)==7){Yb=8;L=288;continue}if((a[788800+Yb|0]|0)!=(a[Lb+36+Yb|0]|0)){Zb=788824;break E}Za=Yb+1|0;if((Za|0)<14){Yb=Za;L=288}else{Zb=788800;break}}}}while(0);_b=(c[Zb+20>>2]|0)!=0|0}else{_b=1}c[yb+56>>2]=_b;Za=0;while(1){if((Za|0)==7){Za=8;continue}if((a[786272+Za|0]|0)!=(a[Mb+Za|0]|0)){$b=0;L=361;break}za=Za+1|0;if((za|0)<14){Za=za}else{ac=786272;break}}F:do{if((L|0)==361){while(1){L=0;if(($b|0)==7){$b=8;L=361;continue}if((a[786296+$b|0]|0)!=(a[Mb+$b|0]|0)){bc=0;break}Za=$b+1|0;if((Za|0)<14){$b=Za;L=361}else{ac=786296;break F}}while(1){if((bc|0)==7){bc=8;continue}if((a[786320+bc|0]|0)!=(a[Mb+bc|0]|0)){ac=786344;break F}Za=bc+1|0;if((Za|0)<14){bc=Za}else{ac=786320;break}}}}while(0);Za=x+48|0;if((c[Za>>2]|0)==0){c[Za>>2]=c[ac+20>>2]}c[x+120>>2]=c[Lb+68>>2];Za=c[Lb+72>>2]|0;c[x+124>>2]=Za;za=c[Lb+76>>2]|0;switch(za|0){case 4:{KIb(c[r>>2]|0,32,2257064,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;break};case 0:{c[x+408>>2]=1;break};case 2:{KIb(c[r>>2]|0,32,2253632,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;break};case 1:{ia=c[Lb+80>>2]|0;if((ia|0)==1){c[x+408>>2]=2;cc=x;dc=Za}else if((ia|0)==2){c[x+408>>2]=3;cc=x;dc=Za}else{QIb(c[r>>2]|0,2244400,(Oa=i,i=i+8|0,c[Oa>>2]=ia,Oa)|0);i=Oa;ia=c[s>>2]|0;cc=ia;dc=c[ia+124>>2]|0}c[cc+124>>2]=dc<<1;break};case 3:{break};default:{KIb(c[r>>2]|0,32,2236648,(Oa=i,i=i+8|0,c[Oa>>2]=za,Oa)|0);i=Oa}}za=c[s>>2]|0;do{if((c[za+48>>2]|0)==14){ia=c[Lb+124>>2]|0;Za=za+140|0;c[Za>>2]=ia;if(!((ia|0)==-1)){break}G:do{if(z){ec=1338928}else{ia=1338928;while(1){Ba=c[ia+16>>2]|0;if((Ba|0)>0){fc=0}else{ec=ia;break G}while(1){if((fc|0)!=7){if((a[ia+fc|0]|0)!=(a[Lb+36+fc|0]|0)){break}}Y=fc+1|0;if((Y|0)<(Ba|0)){fc=Y}else{ec=ia;break G}}Ba=ia+24|0;if((a[Ba|0]|0)==0){ec=Ba;break}else{ia=Ba}}}}while(0);ia=c[ec+20>>2]|0;c[Za>>2]=ia;if(!((ia|0)==-1)){break}if((c[Lb+96>>2]|0)!=2){break}if((c[Lb+100>>2]|0)!=1){break}if((c[Lb+92>>2]|0)!=8){break}c[Za>>2]=17}}while(0);c[U+236>>2]=2;Wb=za}else{Wb=x}}while(0);x=Lb+116|0;do{if((c[x>>2]|0)==0){if((c[Wb+48>>2]|0)!=28){break}Ya=wY(U)|0;if((Ya|0)<0){gc=Ya;break i}}else{Ya=Lb+120|0;if((PX(Wb,c[Ya>>2]|0)|0)!=0){break}nrc(c[(c[s>>2]|0)+96>>2]|0,c[x>>2]|0,c[Ya>>2]|0)|0}}while(0);if((c[(c[s>>2]|0)+8>>2]|0)==2){break n}if(!((d[Mb+15|0]|0)>>>0>1>>>0)){break n}c[U+236>>2]=3;break n}}while(0);if((L|0)==247){L=0;c[xb+44>>2]=0}s=c[U>>2]|0;KIb(c[r>>2]|0,32,2282296,(Oa=i,i=i+16|0,c[Oa>>2]=c[ma>>2],c[Oa+8>>2]=s,Oa)|0);i=Oa;break n}}while(0);if((L|0)==169){L=0;c[kb+20>>2]=0}KIb(c[r>>2]|0,16,2330208,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa}}while(0);if((L|0)==156){L=0;KIb(c[r>>2]|0,16,2341184,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa}D=D+1|0;if((D|0)>=(c[ha>>2]|0)){break l}}if((L|0)==213){KIb(c[r>>2]|0,16,2324200,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-1094995529;break i}else if((L|0)==225){c[yb+20>>2]=0}else if((L|0)==231){KIb(c[r>>2]|0,16,2305704,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-12;break i}KIb(c[r>>2]|0,16,2314160,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-1094995529;break i}}while(0);ha=f;c[f>>2]=0;ba=c[ca>>2]|0;H:do{if((ba|0)>0){D=c[ga>>2]|0;z=0;S=0;do{z=((c[(c[D+(S<<2)>>2]|0)+16>>2]|0)==14)+z|0;S=S+1|0;}while((S|0)<(ba|0));if((z|0)==0){L=396;break}S=qJb(z,4)|0;D=S;do{if((S|0)!=0){M=qJb(z,4)|0;c[f>>2]=M;if((M|0)==0){break}M=c[ca>>2]|0;if((M|0)>0){E=c[ga>>2]|0;C=0;da=0;while(1){fa=c[E+(da<<2)>>2]|0;if((c[fa+16>>2]|0)==14){c[D+(C<<2)>>2]=fa;hc=C+1|0}else{hc=C}fa=da+1|0;if((fa|0)<(M|0)){C=hc;da=fa}else{break}}}if((z|0)>0){ic=-1;jc=-1;kc=-1;lc=0}else{kJb(S);L=396;break H}while(1){da=(lc|0)==0;C=kc;M=(kc|0)<0|0?-1:0;E=0;fa=-1;A=-1;Z=-1;$=-1;T=0;s=0;while(1){Wa=c[D+(E<<2)>>2]|0;Aa=c[Wa+28>>2]|0;V=c[Wa+24>>2]|0;if(da|(Aa|0)>(ic|0)|(V|0)>(jc|0)){L=384}else{_=Wa+40|0;x=c[_+4>>2]|0;if(x>>>0>M>>>0|x>>>0==M>>>0&(c[_>>2]|0)>>>0>C>>>0){L=384}else{mc=T;nc=s;oc=$;pc=Z;qc=A;rc=fa}}I:do{if((L|0)==384){L=0;_=Wa+40|0;x=c[_>>2]|0;Ya=c[_+4>>2]|0;do{if((fa|0)==-1|(Aa|0)<(A|0)|(V|0)<(Z|0)){sc=x}else{_=$;ia=($|0)<0|0?-1:0;if(Ya>>>0<ia>>>0|Ya>>>0==ia>>>0&x>>>0<_>>>0){sc=x;break}if(!((x|0)==(_|0)&(Ya|0)==(ia|0))){mc=T;nc=s;oc=$;pc=Z;qc=A;rc=fa;break I}ia=Wa+48|0;_=c[ia+4>>2]|0;if(_>>>0>T>>>0|_>>>0==T>>>0&(c[ia>>2]|0)>>>0>s>>>0){sc=x}else{mc=T;nc=s;oc=$;pc=Z;qc=A;rc=fa;break I}}}while(0);x=Wa+48|0;mc=c[x+4>>2]|0;nc=c[x>>2]|0;oc=sc;pc=V;qc=Aa;rc=E}}while(0);Aa=E+1|0;if((Aa|0)<(z|0)){E=Aa;fa=rc;A=qc;Z=pc;$=oc;T=mc;s=nc}else{break}}if((rc|0)==-1){tc=lc;break}s=lc+1|0;c[(c[f>>2]|0)+(lc<<2)>>2]=c[D+(rc<<2)>>2];if((s|0)<(z|0)){ic=qc;jc=pc;kc=oc;lc=s}else{tc=s;break}}kJb(S);if((tc|0)<1){L=396;break H}s=n+128|0;T=c[f>>2]|0;$=0;J:while(1){do{if(($|0)==0){L=399}else{Z=c[T+($-1<<2)>>2]|0;A=c[T+($<<2)>>2]|0;if((c[Z+24>>2]|0)!=(c[A+24>>2]|0)){L=399;break}if((c[Z+28>>2]|0)!=(c[A+28>>2]|0)){L=401;break J}}}while(0);if((L|0)==399){L=0;c[s>>2]=(c[s>>2]|0)+1}A=$+1|0;if((A|0)<(tc|0)){$=A}else{L=403;break}}K:do{if((L|0)==401){KIb(c[r>>2]|0,16,2413328,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;uc=-1094995529}else if((L|0)==403){$=c[s>>2]|0;do{if($>>>0<53687091>>>0){T=pJb($*40|0)|0;A=T;Z=n+132|0;c[Z>>2]=A;if((T|0)==0){break}T=c[f>>2]|0;fa=0;E=0;while(1){if((fa|0)==0){vc=E}else{vc=((c[(c[T+(fa-1<<2)>>2]|0)+24>>2]|0)!=(c[(c[T+(fa<<2)>>2]|0)+24>>2]|0))+E|0}C=A+(vc*40|0)+28|0;c[C>>2]=(c[C>>2]|0)+1;C=fa+1|0;if((C|0)<(tc|0)){fa=C;E=vc}else{break}}if((c[s>>2]|0)>0){wc=0;xc=0;yc=A}else{uc=0;break K}L:while(1){E=yc+(xc*40|0)+28|0;fa=c[E>>2]|0;if(!(fa>>>0<536870911>>>0)){L=413;break}T=pJb(fa<<2)|0;fa=T;C=yc+(xc*40|0)+32|0;c[C>>2]=fa;if((T|0)==0){break}T=c[f>>2]|0;M=c[T+(wc<<2)>>2]|0;da=M+40|0;Aa=c[da>>2]|0;V=c[da+4>>2]|0;if((Aa|0)==0&(V|0)==0){zc=fa;Ac=T}else{KIb(c[r>>2]|0,24,2391144,(Oa=i,i=i+24|0,c[Oa>>2]=c[M+24>>2],c[Oa+8>>2]=Aa,c[Oa+16>>2]=V,Oa)|0);i=Oa;zc=c[C>>2]|0;Ac=c[f>>2]|0}nrc(zc|0,Ac+(wc<<2)|0,c[E>>2]<<2)|0;V=c[(c[f>>2]|0)+(wc<<2)>>2]|0;Aa=yc+(xc*40|0)|0;c[Aa>>2]=c[V+24>>2];c[yc+(xc*40|0)+4>>2]=c[V+28>>2];V=c[E>>2]|0;M:do{if((V|0)>0){M=c[C>>2]|0;T=yc+(xc*40|0)+8|0;fa=0;while(1){da=c[M+(fa<<2)>>2]|0;if((c[da+68>>2]|0)==0){break}Wa=da+48|0;da=wrc(c[T>>2]|0,0,c[Wa>>2]|0,c[Wa+4>>2]|0)|0;Wa=da;c[T>>2]=Wa;da=fa+1|0;if((da|0)<(V|0)){fa=da}else{Bc=Wa;L=424;break M}}c[T>>2]=0;Cc=V}else{Bc=c[yc+(xc*40|0)+8>>2]|0;L=424}}while(0);do{if((L|0)==424){L=0;fa=yc+(xc*40|0)+8|0;if((Bc|0)<1){Cc=V;break}M=qJb(Bc,8)|0;Dc=yc+(xc*40|0)+24|0;c[Dc>>2]=M;if((M|0)==0){L=443;break L}M=qJb(c[fa>>2]|0,24)|0;za=yc+(xc*40|0)+36|0;c[za>>2]=M;if((M|0)==0){L=443;break L}M=c[fa>>2]|0;if((M|0)>0){Wa=c[Dc>>2]|0;da=0;do{ma=Wa+(da<<3)|0;c[ma>>2]=0;c[ma+4>>2]=-2147483648;da=da+1|0;}while((da|0)<(M|0))}M=c[E>>2]|0;if((M|0)>0){da=-128;Wa=0;T=0;while(1){ma=c[(c[C>>2]|0)+(T<<2)>>2]|0;U=ma+68|0;x=c[U>>2]|0;Ya=ma+48|0;ia=c[Ya>>2]|0;_=(x|0)==(ia<<1|0>>>31|1|0)&(((x|0)<0|0?-1:0)|0)==(c[Ya+4>>2]<<1|ia>>>31|0);ia=_?2:1;Ba=(_<<31>>31)+x|0;N:do{if((Ba|0)>0){x=ma+56|0;_=ma+60|0;Y=da;sa=Wa;Va=0;while(1){Sa=(a[(c[x>>2]|0)+Va|0]|0)/(ia|0)|0;Ra=Sa+sa|0;if((sa|0)>=(c[fa>>2]|0)){break}Ta=sa;Xa=(sa|0)<0|0?-1:0;Ma=c[za>>2]|0;Qa=Ma+(sa*24|0)+8|0;c[Qa>>2]=Ta;c[Qa+4>>2]=Xa;Qa=Ma+(sa*24|0)+16|0;c[Qa>>2]=(c[(c[_>>2]|0)+(Va<<2)>>2]&48|0)==0|c[Qa>>2]&-4;do{if((Ra|0)<0){L=438}else{if((Ra|0)>=(c[fa>>2]|0)){L=438;break}Qa=(c[Dc>>2]|0)+(Ra<<3)|0;c[Qa>>2]=Ta;c[Qa+4>>2]=Xa;Ec=(Y<<24>>24|0)>(Sa|0)?Y:Sa&255}}while(0);if((L|0)==438){L=0;KIb(c[r>>2]|0,16,2359168,(Oa=i,i=i+24|0,c[Oa>>2]=sa,c[Oa+8>>2]=Sa,c[Oa+16>>2]=Ra,Oa)|0);i=Oa;Ec=Y}Xa=Va+ia|0;Ta=sa+1|0;if((Xa|0)<(Ba|0)){Y=Ec;sa=Ta;Va=Xa}else{Fc=Ec;Gc=Ta;break N}}Va=c[Ya>>2]|0;_=c[Ya+4>>2]|0;KIb(c[r>>2]|0,16,2371920,(Oa=i,i=i+24|0,c[Oa>>2]=c[U>>2],c[Oa+8>>2]=Va,c[Oa+16>>2]=_,Oa)|0);i=Oa;Fc=Y;Gc=sa}else{Fc=da;Gc=Wa}}while(0);U=T+1|0;Ya=c[E>>2]|0;if((U|0)<(Ya|0)){da=Fc;Wa=Gc;T=U}else{Hc=Fc;Ic=Ya;break}}}else{Hc=-128;Ic=M}T=-(Hc<<24>>24)|0;Wa=yc+(xc*40|0)+16|0;c[Wa>>2]=T;c[Wa+4>>2]=(T|0)<0|0?-1:0;Cc=Ic}}while(0);E=0;while(1){if((E|0)>=(Cc|0)){break}V=(c[(c[C>>2]|0)+(E<<2)>>2]|0)+48|0;if((c[V>>2]|0)==0&(c[V+4>>2]|0)==0){L=446;break}else{E=E+1|0}}do{if((L|0)==446){L=0;if((Cc|0)>1){KIb(c[r>>2]|0,24,2384384,(Oa=i,i=i+16|0,c[Oa>>2]=c[Aa>>2],c[Oa+8>>2]=E,Oa)|0);i=Oa}V=c[r>>2]|0;if((c[V+24>>2]|0)==0){KIb(V,24,2377472,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;break}else{T=(c[c[V+28>>2]>>2]|0)+56|0;V=c[T+4>>2]|0;Wa=(c[(c[C>>2]|0)+(E<<2)>>2]|0)+48|0;c[Wa>>2]=c[T>>2];c[Wa+4>>2]=V;break}}}while(0);E=xc+1|0;C=c[Z>>2]|0;if((E|0)<(c[s>>2]|0)){wc=(c[C+(xc*40|0)+28>>2]|0)+wc|0;xc=E;yc=C}else{uc=0;break K}}if((L|0)==413){c[yc+(xc*40|0)+32>>2]=0}else if((L|0)==443){mJb(Dc);uc=-12;break K}KIb(c[r>>2]|0,16,2398192,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;uc=-12;break K}else{c[n+132>>2]=0}}while(0);KIb(c[r>>2]|0,16,2405672,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;uc=-12}}while(0);kJb(c[f>>2]|0);if((uc|0)<0){gc=uc;break i}else{Jc=s;break H}}}while(0);mJb(ha);kJb(S);L=396}else{L=396}}while(0);if((L|0)==396){KIb(c[r>>2]|0,24,2424216,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;Jc=n+128|0}ha=c[Jc>>2]|0;do{if((ha|0)>1){ga=c[c[n+132>>2]>>2]|0;KIb(c[r>>2]|0,32,2448296,(Oa=i,i=i+16|0,c[Oa>>2]=ha,c[Oa+8>>2]=ga,Oa)|0);i=Oa}else{if((ha|0)!=0){break}if((c[ea>>2]|0)!=10){break}KIb(c[r>>2]|0,16,2432888,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-1094995529;break i}}while(0);ha=c[m>>2]|0;if((c[ha+8>>2]|0)!=10){eb=0;i=e;return eb|0}if((c[b+24>>2]|0)!=1){eb=0;i=e;return eb|0}ga=c[(c[c[b+28>>2]>>2]|0)+8>>2]|0;if((c[ga+8>>2]|0)!=1){eb=0;i=e;return eb|0}if(!(((c[ga+48>>2]|0)-65536|0)>>>0<16>>>0)){eb=0;i=e;return eb|0}if((c[ha+128>>2]|0)!=1){eb=0;i=e;return eb|0}ga=c[ha+132>>2]|0;if((c[ga+28>>2]|0)!=1){eb=0;i=e;return eb|0}if((c[(c[c[ga+32>>2]>>2]|0)+20>>2]|0)>31){eb=0;i=e;return eb|0}c[ha+136>>2]=1920;eb=0;i=e;return eb|0}else{L=148}}while(0);if((L|0)==148){KIb(c[r>>2]|0,16,2347520,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;gc=-1094995529}pP(b)|0;eb=gc;i=e;return eb|0}}while(0);KIb(b,16,2463248,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}}while(0);KIb(b,16,2520968,(Oa=i,i=i+1|0,i=i+7&-8,c[Oa>>2]=0,Oa)|0);i=Oa;eb=-1094995529;i=e;return eb|0}function oP(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;f=i;i=i+88|0;g=f|0;h=f+8|0;j=f+24|0;k=f+40|0;l=f+72|0;m=f+80|0;n=b+12|0;o=c[n>>2]|0;p=o;if((c[o+8>>2]|0)==10){q=c[c[b+28>>2]>>2]|0;r=c[o+132>>2]|0;s=o+124|0;t=c[s>>2]|0;u=t;v=(t|0)<0|0?-1:0;t=q+56|0;w=c[t>>2]|0;x=c[t+4>>2]|0;if(!((v|0)<(x|0)|(v|0)==(x|0)&u>>>0<w>>>0)){z=-541478725;i=f;return z|0}t=c[o+136>>2]|0;A=(t|0)<0|0?-1:0;B=xrc(w,x,u,v)|0;x=G;w=(A|0)>(x|0)|(A|0)==(x|0)&t>>>0>B>>>0?B:t;t=rP(p,r,u,v,0,l,1)|0;if((t|0)<0){z=t;i=f;return z|0}t=(c[s>>2]|0)+w|0;a:do{if((rP(p,r,t,(t|0)<0|0?-1:0,0,m,0)|0)<0){v=c[r+4>>2]|0;u=c[o+4>>2]|0;b:do{if((u|0)==0){C=113}else{B=c[o>>2]|0;x=0;A=0;D=0;while(1){if((c[B+(x*88|0)+28>>2]|0)==(v|0)){E=B+(x*88|0)+48|0;F=c[E>>2]|0;H=c[E+4>>2]|0;if((F|0)==0&(H|0)==0){C=113;break b}E=B+(x*88|0)+40|0;I=wrc(c[E>>2]|0,c[E+4>>2]|0,F,H)|0;J=G;K=I}else{J=A;K=D}I=x+1|0;if(I>>>0<u>>>0){x=I;A=J;D=K}else{break}}c[m>>2]=K;c[m+4>>2]=J;D=0;if(!((J|0)<(D|0)|(J|0)==(D|0)&K>>>0<1>>>0)){L=J;M=K;break a}}}while(0);if((C|0)==113){c[m>>2]=0;c[m+4>>2]=0}KIb(b,16,2153760,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;z=-1094995529;i=f;return z|0}else{L=c[m+4>>2]|0;M=c[m>>2]|0}}while(0);m=c[l>>2]|0;K=c[l+4>>2]|0;l=xrc(M,L,m,K)|0;L=l;if((L|0)<1){KIb(b,16,2129104,(N=i,i=i+8|0,c[N>>2]=L,N)|0);i=N;z=-1094995529;i=f;return z|0}l=b+16|0;M=fD(c[l>>2]|0,m,K,0)|0;K=G;m=0;if((K|0)<(m|0)|(K|0)==(m|0)&M>>>0<0>>>0){z=M;i=f;return z|0}M=fX(c[l>>2]|0,e,L)|0;if((M|0)<0){z=M;i=f;return z|0}c[e+32>>2]=0;M=c[q+8>>2]|0;q=c[M+8>>2]|0;do{if((q|0)==0){L=c[r+24>>2]|0;if((L|0)==0){break}l=c[s>>2]|0;if(!((l|0)>-1)){break}if((l|0)<(c[r+8>>2]|0)){m=r+16|0;K=wrc(c[m>>2]|0,c[m+4>>2]|0,l,(l|0)<0|0?-1:0)|0;m=e+16|0;c[m>>2]=K;c[m+4>>2]=G;m=L+(l<<3)|0;l=c[m+4>>2]|0;L=e+8|0;c[L>>2]=c[m>>2];c[L+4>>2]=l;break}else{if((q|0)==1){C=127;break}else{break}}}else if((q|0)==1){C=127}}while(0);do{if((C|0)==127){q=(c[(c[c[(c[o+28>>2]|0)+28>>2]>>2]|0)+12>>2]|0)+64|0;r=c[q+4>>2]|0;l=e+8|0;c[l>>2]=c[q>>2];c[l+4>>2]=r;r=M+416|0;if((c[r>>2]|0)<1){z=-22;i=f;return z|0}l=M+48|0;if((g5a(c[l>>2]|0)|0)<1){z=-22;i=f;return z|0}L=c[r>>2]|0;m=g5a(c[l>>2]|0)|0;K=Erc(m,(m|0)<0|0?-1:0,L,(L|0)<0|0?-1:0)|0;L=G;m=0;if((L|0)<(m|0)|(L|0)==(m|0)&K>>>0<8>>>0){z=-22;i=f;return z|0}else{K=c[e+28>>2]|0;m=c[r>>2]|0;r=g5a(c[l>>2]|0)|0;l=Erc(r,(r|0)<0|0?-1:0,m,(m|0)<0|0?-1:0)|0;m=Crc(l,G,8,0)|0;l=Crc(K,(K|0)<0|0?-1:0,m,G)|0;m=wrc(c[q>>2]|0,c[q+4>>2]|0,l,G)|0;c[q>>2]=m;c[q+4>>2]=G;break}}}while(0);c[s>>2]=(c[s>>2]|0)+w;z=0;i=f;return z|0}w=k|0;s=b+16|0;M=k+16|0;q=k;m=k+4|0;l=k+24|0;K=b+24|0;r=b+28|0;L=k+12|0;J=b;t=L;u=c[s>>2]|0;c:do{if((jD(u)|0)==0){v=u;d:while(1){D=0;while(1){A=zD(v)|0;if((A|0)==6){O=1}else{P=(A|0)==(d[788768+D|0]|0)?D+1|0:0;if(P>>>0<4>>>0){O=P}else{break}}if((jD(v)|0)==0){D=O}else{break c}}if((P|0)!=4){break c}D=fD(v,0,0,1)|0;A=wrc(D,G,-4,-1)|0;c[M>>2]=A;c[M+4>>2]=G;c[q>>2]=875236870;AD(v,m,12)|0;A=zD(v)|0;D=A;x=(A|0)<0|0?-1:0;e:do{if((D&128|0)==0&(x&0|0)==0){Q=x;R=D;C=13}else{B=A&127;do{if(B>>>0>8>>>0){S=-1;T=-1094995529}else{if((B|0)==0){S=0;T=0;break}else{U=0;V=0;W=B}while(1){I=W-1|0;H=zD(v)|0;F=H|(V<<8|0>>>24);E=((H|0)<0|0?-1:0)|(U<<8|V>>>24);if((I|0)==0){Q=E;R=F;C=13;break e}else{U=E;V=F;W=I}}}}while(0);c[l>>2]=T;c[l+4>>2]=S;X=S;Y=T}}while(0);if((C|0)==13){C=0;c[l>>2]=R;c[l+4>>2]=Q;if((R|0)==(-1|0)&(Q|0)==(-1|0)){break c}else{X=Q;Y=R}}if((grc(w,790816,16)|0)==0){C=15;break}if((grc(w,788976,12)|0)==0){C=56}else{if((grc(w,790896,12)|0)==0){C=56}else{Z=X;_=Y}}do{if((C|0)==56){C=0;A=c[K>>2]|0;D=0;while(1){if(!(D>>>0<A>>>0)){C=59;break}if((grc(L,(c[(c[(c[r>>2]|0)+(D<<2)>>2]|0)+12>>2]|0)+44|0,4)|0)==0){$=D;break}else{D=D+1|0}}if((C|0)==59){C=0;$=((A|0)!=1)<<31>>31}if(($|0)<0){D=je(c[t>>2]|0)|0;KIb(J,16,2624072,(N=i,i=i+8|0,c[N>>2]=D,N)|0);i=N;Z=c[l+4>>2]|0;_=c[l>>2]|0;break}else{D=c[(c[r>>2]|0)+($<<2)>>2]|0;aa=c[D+12>>2]|0;if((c[D+76>>2]|0)==48){Z=X;_=Y;break}else{break d}}}}while(0);hD(c[s>>2]|0,_,Z)|0;v=c[s>>2]|0;if((jD(v)|0)!=0){break c}}if((C|0)==15){v=h|0;D=j|0;x=c[n>>2]|0;B=c[s>>2]|0;I=fD(B,0,0,1)|0;F=wrc(c[l>>2]|0,c[l+4>>2]|0,I,G)|0;I=G;E=x+32|0;do{if((c[E>>2]|0)==0){x=b+1096|0;if((c[x>>2]|0)==0){C=20;break}if((c[b+1100>>2]|0)!=16){C=20;break}H=pFb()|0;c[E>>2]=H;if((H|0)==0){break}rFb(H,c[x>>2]|0,128,1)|0;C=20}else{C=20}}while(0);do{if((C|0)==20){x=zD(B)|0;H=x;ba=(x|0)<0|0?-1:0;do{if((H&128|0)==0&(ba&0|0)==0){ca=ba;da=H}else{ea=x&127;if(ea>>>0>8>>>0){ca=-1;da=-1094995529;break}if((ea|0)==0){ca=0;da=0;break}else{fa=0;ga=0;ha=ea}while(1){ea=ha-1|0;ia=zD(B)|0;ja=ia|(ga<<8|0>>>24);ka=((ia|0)<0|0?-1:0)|(fa<<8|ga>>>24);if((ea|0)==0){ca=ka;da=ja;break}else{fa=ka;ga=ja;ha=ea}}}}while(0);hD(B,da,ca)|0;x=zD(B)|0;do{if((x&128|0)!=0){H=x&127;if(H>>>0>8>>>0|(H|0)==0){break}else{la=H}do{la=la-1|0;zD(B)|0;}while((la|0)!=0)}}while(0);x=OD(B)|0;H=G;ba=zD(B)|0;do{if((ba&128|0)!=0){A=ba&127;if(A>>>0>8>>>0|(A|0)==0){break}else{ma=A}do{ma=ma-1|0;zD(B)|0;}while((ma|0)!=0)}}while(0);AD(B,w,16)|0;if((grc(w,788976,12)|0)!=0){break}ba=c[K>>2]|0;A=0;while(1){if(!(A>>>0<ba>>>0)){C=34;break}if((grc(L,(c[(c[(c[r>>2]|0)+(A<<2)>>2]|0)+12>>2]|0)+44|0,4)|0)==0){na=A;break}else{A=A+1|0}}if((C|0)==34){na=((ba|0)!=1)<<31>>31}if((na|0)<0){break}A=zD(B)|0;do{if((A&128|0)!=0){ea=A&127;if(ea>>>0>8>>>0|(ea|0)==0){break}else{oa=ea}do{oa=oa-1|0;zD(B)|0;}while((oa|0)!=0)}}while(0);A=OD(B)|0;ba=G;if(ba>>>0<H>>>0|ba>>>0==H>>>0&A>>>0<x>>>0){break}ea=zD(B)|0;ja=ea;ka=(ea|0)<0|0?-1:0;if((ja&128|0)==0&(ka&0|0)==0){pa=ka;qa=ja}else{ja=ea&127;if(ja>>>0>8>>>0|(ja|0)==0){break}else{ra=0;sa=0;ta=ja}while(1){ja=ta-1|0;ea=zD(B)|0;ka=ea|(sa<<8|0>>>24);ia=((ea|0)<0|0?-1:0)|(ra<<8|sa>>>24);if((ja|0)==0){pa=ia;qa=ka;break}else{ra=ia;sa=ka;ta=ja}}}ja=0;if((pa|0)<(ja|0)|(pa|0)==(ja|0)&qa>>>0<32>>>0){break}ja=wrc(qa,pa,-32,-1)|0;ka=G;if(ka>>>0<ba>>>0|ka>>>0==ba>>>0&ja>>>0<A>>>0){break}AD(B,v,16)|0;AD(B,D,16)|0;ka=c[E>>2]|0;if((ka|0)!=0){qFb(ka,D,D,1,v,1)}if((grc(D,790848,16)|0)!=0){KIb(J,16,2537096,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N}ka=fX(B,e,ja)|0;ja=ka;ia=(ka|0)<0|0?-1:0;if((ka|0)<0|(ia>>>0<H>>>0|ia>>>0==H>>>0&ja>>>0<x>>>0)){break}ka=c[E>>2]|0;if((ka|0)!=0){ea=xrc(ja,ia,x,H)|0;ia=(c[e+24>>2]|0)+x|0;qFb(ka,ia,ia,ea>>>4|G<<28,v,1)}M1(e,A);c[e+32>>2]=na;ea=fD(B,0,0,1)|0;ia=xrc(F,I,ea,G)|0;hD(B,ia,G)|0;z=0;i=f;return z|0}}while(0);KIb(J,16,2106048,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;z=-1094995529;i=f;return z|0}B=fD(c[s>>2]|0,0,0,1)|0;I=wrc(c[l>>2]|0,c[l+4>>2]|0,B,G)|0;B=G;F=c[M>>2]|0;v=c[M+4>>2]|0;c[g>>2]=-1;c[g+4>>2]=-1;E=o+132|0;D=c[E>>2]|0;ia=o+128|0;f:do{if((c[ia>>2]|0)<1){ua=0}else{ea=o+124|0;ka=c[ea>>2]|0;g:do{if((ka|0)>-1){ja=-1;va=-1;wa=ka;while(1){xa=wa+1|0;if((rP(p,D,xa,(xa|0)<0|0?-1:0,0,g,0)|0)<0){ua=0;break f}xa=c[g>>2]|0;ya=c[g+4>>2]|0;if(!((ya|0)>(ja|0)|(ya|0)==(ja|0)&xa>>>0>va>>>0)){break}za=c[ea>>2]|0;if((ya|0)>(v|0)|(ya|0)==(v|0)&xa>>>0>F>>>0){Aa=za;Ba=ya;Ca=xa;break g}Da=za+1|0;c[ea>>2]=Da;if((Da|0)>-1){ja=ya;va=xa;wa=Da}else{Aa=Da;Ba=ya;Ca=xa;break g}}KIb(c[o+28>>2]|0,16,2554920,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;ua=0;break f}else{Aa=ka;Ba=-1;Ca=-1}}while(0);ka=(Aa|0)<0;ea=ka?-1:Ca;A=ka?-1:Ba;ka=-1;x=(A|0)>(ka|0)|(A|0)==(ka|0)&ea>>>0>-1>>>0;if(!(x&((B|0)>(A|0)|(B|0)==(A|0)&I>>>0>ea>>>0))){ua=x;break}QIb(J,2597808,(N=i,i=i+8|0,c[N>>2]=Aa,N)|0);i=N;x=fD(c[s>>2]|0,0,0,1)|0;ka=xrc(ea,A,x,G)|0;c[l>>2]=ka;c[l+4>>2]=G;ua=1}}while(0);h:do{if((a[L]|0)==6){if((a[k+13|0]|0)!=1){C=88;break}if((a[k+14|0]|0)!=16){C=88;break}F=c[(c[r>>2]|0)+($<<2)>>2]|0;v=c[l>>2]|0;D=c[l+4>>2]|0;ka=0;do{if(!((D|0)>(ka|0)|(D|0)==(ka|0)&v>>>0>61444>>>0)){x=fX(c[s>>2]|0,e,v)|0;if((x|0)<0){break}A=e+24|0;ea=c[A>>2]|0;H=ea+x|0;ba=F+8|0;wa=c[ba>>2]|0;va=c[wa+416>>2]|0;if((x-4|0)<(va<<2|0)){Ea=ea;Fa=ea}else{x=ea;ja=ea+4|0;ea=wa;wa=va;while(1){if((wa|0)>0){va=ja;xa=x;ya=0;Da=ea;while(1){za=va+4|0;Ga=va;Ha=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;if((c[Da+792>>2]|0)==24){a[xa]=Ha>>>4;a[xa+1|0]=Ha>>>12;a[xa+2|0]=Ha>>>20;Ia=xa+3|0}else{Ga=xa;y=Ha>>>12&65535;a[Ga]=y;y=y>>8;a[Ga+1|0]=y;Ia=xa+2|0}Ga=ya+1|0;Ha=c[ba>>2]|0;Ja=c[Ha+416>>2]|0;if((Ga|0)<(Ja|0)){va=za;xa=Ia;ya=Ga;Da=Ha}else{Ka=za;La=Ia;Ma=Ha;Na=Ja;break}}}else{Ka=ja;La=x;Ma=ea;Na=wa}Da=Na<<2;ya=Ka+(32-Da)|0;if((H-ya|0)<(Da|0)){break}else{x=La;ja=ya;ea=Ma;wa=Na}}Ea=La;Fa=c[A>>2]|0}M1(e,Ea-Fa|0);break h}}while(0);KIb(J,16,2573368,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;z=-1094995529;i=f;return z|0}else{C=88}}while(0);do{if((C|0)==88){F=fX(c[s>>2]|0,e,c[l>>2]|0)|0;if((F|0)<0){z=F}else{break}i=f;return z|0}}while(0);c[e+32>>2]=$;F=c[M+4>>2]|0;v=e+64|0;c[v>>2]=c[M>>2];c[v+4>>2]=F;F=c[(c[(c[r>>2]|0)+($<<2)>>2]|0)+8>>2]|0;v=c[F+8>>2]|0;i:do{if((v|0)!=0|ua^1){if((v|0)!=1){break}ka=(c[(c[(c[(c[o+28>>2]|0)+28>>2]|0)+($<<2)>>2]|0)+12>>2]|0)+64|0;D=c[ka+4>>2]|0;wa=e+8|0;c[wa>>2]=c[ka>>2];c[wa+4>>2]=D;D=F+416|0;if((c[D>>2]|0)<1){z=-22;i=f;return z|0}wa=F+48|0;if((g5a(c[wa>>2]|0)|0)<1){z=-22;i=f;return z|0}ea=c[D>>2]|0;ja=g5a(c[wa>>2]|0)|0;x=Erc(ja,(ja|0)<0|0?-1:0,ea,(ea|0)<0|0?-1:0)|0;ea=G;ja=0;if((ea|0)<(ja|0)|(ea|0)==(ja|0)&x>>>0<8>>>0){z=-22;i=f;return z|0}else{x=c[e+28>>2]|0;ja=c[D>>2]|0;D=g5a(c[wa>>2]|0)|0;wa=Erc(D,(D|0)<0|0?-1:0,ja,(ja|0)<0|0?-1:0)|0;ja=Crc(wa,G,8,0)|0;wa=Crc(x,(x|0)<0|0?-1:0,ja,G)|0;ja=wrc(c[ka>>2]|0,c[ka+4>>2]|0,wa,G)|0;c[ka>>2]=ja;c[ka+4>>2]=G;break}}else{ka=c[E>>2]|0;do{if((c[ia>>2]|0)>0){ja=c[o+124>>2]|0;if((ja|0)>=(c[ka+8>>2]|0)){break}wa=ka+16|0;x=wrc(c[wa>>2]|0,c[wa+4>>2]|0,ja,(ja|0)<0|0?-1:0)|0;wa=e+16|0;c[wa>>2]=x;c[wa+4>>2]=G;wa=(c[ka+24>>2]|0)+(ja<<3)|0;ja=c[wa+4>>2]|0;x=e+8|0;c[x>>2]=c[wa>>2];c[x+4>>2]=ja;break i}}while(0);if((c[aa+56>>2]|0)==0){break}ka=c[o+124>>2]|0;ja=e+8|0;c[ja>>2]=ka;c[ja+4>>2]=(ka|0)<0|0?-1:0}}while(0);fD(c[s>>2]|0,I,B,0)|0;z=0;i=f;return z|0}}while(0);e=(jD(c[s>>2]|0)|0)!=0;z=e?-541478725:-1;i=f;return z|0}function pP(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;mJb(b+12|0);d=c[a+24>>2]|0;if((d|0)!=0){e=a+28|0;a=0;do{c[(c[(c[e>>2]|0)+(a<<2)>>2]|0)+12>>2]=0;a=a+1|0;}while(a>>>0<d>>>0)}d=b+24|0;a=b+20|0;a:do{if((c[d>>2]|0)>0){e=a;f=0;while(1){g=c[(c[e>>2]|0)+(f<<2)>>2]|0;switch(c[g+16>>2]|0){case 7:{mJb(g+116|0);break};case 5:{mJb(g+36|0);break};case 2:case 1:{mJb(g+36|0);break};case 14:{mJb(g+56|0);mJb(g+60|0);mJb(g+64|0);break};case 6:{mJb(g+104|0);break};default:{}}mJb((c[e>>2]|0)+(f<<2)|0);f=f+1|0;if((f|0)>=(c[d>>2]|0)){break a}}}}while(0);mJb(b);mJb(a);mJb(b+32|0);mJb(b+36|0);a=b+132|0;d=a;f=c[d>>2]|0;if((f|0)==0){mJb(a);return 0}e=b+128|0;if((c[e>>2]|0)>0){h=0;i=f}else{mJb(a);return 0}while(1){mJb(i+(h*40|0)+32|0);mJb((c[d>>2]|0)+(h*40|0)+24|0);mJb((c[d>>2]|0)+(h*40|0)+36|0);f=h+1|0;if((f|0)>=(c[e>>2]|0)){break}h=f;i=c[d>>2]|0}mJb(a);return 0}function qP(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0.0,ea=0;g=i;i=i+64|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=g+40|0;o=g+48|0;p=g+56|0;c[n>>2]=d;c[n+4>>2]=e;q=a+28|0;r=c[(c[q>>2]|0)+(b<<2)>>2]|0;b=c[a+12>>2]|0;s=b;t=c[r+12>>2]|0;if((c[(c[r+8>>2]|0)+8>>2]|0)==1){u=c[t+48>>2]|0;c[p>>2]=c[t+52>>2];c[p+4>>2]=u;u=XIb(d,e,r+40|0,p)|0;p=G;c[n>>2]=u;c[n+4>>2]=p;v=p;w=u}else{v=e;w=d}do{if((c[b+128>>2]|0)<1){d=c[a+1072>>2]|0;if((d|0)==0){x=-1094995529;i=g;return x|0}e=0;if((v|0)<(e|0)|(v|0)==(e|0)&w>>>0<0>>>0){c[n>>2]=0;c[n+4>>2]=0;y=0;z=0}else{y=v;z=w}e=c[r+40>>2]|0;u=c[r+44>>2]|0;p=VIb(z,y,e,(e|0)<0|0?-1:0,u,(u|0)<0|0?-1:0)|0;u=c[a+16>>2]|0;e=Erc(d,(d|0)<0|0?-1:0,p,G)|0;p=G;d=fD(u,e>>>3|p<<29,p>>3|((p|0)<0|0?-1:0)<<29,0)|0;p=G;c[o>>2]=d;c[o+4>>2]=p;e=0;if(!((p|0)<(e|0)|(p|0)==(e|0)&d>>>0<0>>>0)){zX(a,r,c[n>>2]|0,c[n+4>>2]|0);c[b+124>>2]=c[n>>2];break}x=d;i=g;return x|0}else{d=c[b+132>>2]|0;e=0;p=(v|0)>(e|0)|(v|0)==(e|0)&w>>>0>0>>>0;e=p?w:0;u=p?v:0;c[n>>2]=e;c[n+4>>2]=u;p=c[d+36>>2]|0;do{if((p|0)==0){A=t+72|0;B=wrc(c[A>>2]|0,c[A+4>>2]|0,-1,-1)|0;A=G;C=(u|0)>(A|0)|(u|0)==(A|0)&e>>>0>B>>>0;D=C?B:e;B=C?A:u;c[n>>2]=D;c[n+4>>2]=B;E=B;H=D}else{D=BX(p,c[d+8>>2]|0,e,u,f)|0;B=D;A=(D|0)<0|0?-1:0;c[n>>2]=B;c[n+4>>2]=A;if((D|0)<0){x=D}else{E=A;H=B;break}i=g;return x|0}}while(0);u=rP(s,d,H,E,n,o,1)|0;if((u|0)<0){x=u;i=g;return x|0}else{zX(a,r,c[n>>2]|0,c[n+4>>2]|0);c[b+124>>2]=c[n>>2];fD(c[a+16>>2]|0,c[o>>2]|0,c[o+4>>2]|0,0)|0;break}}}while(0);o=a+24|0;a=c[o>>2]|0;if((a|0)==0){x=0;i=g;return x|0}n=b+28|0;r=h|0;E=h+4|0;H=j|0;s=j+4|0;f=b+124|0;b=l|0;t=l+4|0;v=k|0;w=k+4|0;y=0;z=a;while(1){a=c[(c[q>>2]|0)+(y<<2)>>2]|0;u=c[a+12>>2]|0;if((c[(c[a+8>>2]|0)+8>>2]|0)==1){a=c[n>>2]|0;e=c[(c[a+28>>2]|0)+(y<<2)>>2]|0;p=c[e+12>>2]|0;B=c[p+48>>2]|0;A=c[p+52>>2]|0;c[r>>2]=A;c[E>>2]=B;p=c[e+40>>2]|0;D=c[e+44>>2]|0;c[H>>2]=D;c[s>>2]=p;do{if(((D|0)/(p|0)|0|0)==48e3){e=J$(a,h)|0;if((e|0)==0){I=c[H>>2]|0;J=c[r>>2]|0;K=c[E>>2]|0;L=c[s>>2]|0;M=22;break}C=c[e+8>>2]|0;if((C|0)==0){N=0;O=0;P=0}else{S=0;T=0;U=C;do{T=T+U|0;S=S+1|0;U=c[e+8+(S<<2)>>2]|0;}while((U|0)!=0);N=S;O=(T|0)<0|0?-1:0;P=T}U=c[f>>2]|0;V=(U|0)/(N|0)|0;W=Erc(V,(V|0)<0|0?-1:0,P,O)|0;V=G;X=(U|0)%(N|0)|0;if((X|0)<=0){Y=V;Z=W;break}U=wrc(W,V,C,(C|0)<0|0?-1:0)|0;V=G;if((X|0)>1){_=1;$=V;aa=U}else{Y=V;Z=U;break}while(1){U=c[e+8+(_<<2)>>2]|0;V=_+1|0;W=wrc(aa,$,U,(U|0)<0|0?-1:0)|0;U=G;if((V|0)<(X|0)){_=V;$=U;aa=W}else{Y=U;Z=W;break}}}else{I=D;J=A;K=B;L=p;M=22}}while(0);do{if((M|0)==22){M=0;p=(ca(I,J)|0)%(ca(K,L)|0)|0;c[b>>2]=c[f>>2];c[t>>2]=1;yKb(m,j,h);yKb(k,l,m);da=+(c[v>>2]|0)/+(c[w>>2]|0);B=~~+da>>>0;A=(F=+da,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);if((p|0)==0){Y=A;Z=B;break}p=c[r>>2]|0;D=c[E>>2]|0;a=c[H>>2]|0;d=c[s>>2]|0;KIb(c[n>>2]|0,24,2386256,(X=i,i=i+40|0,c[X>>2]=y,c[X+8>>2]=p,c[X+16>>2]=D,c[X+24>>2]=a,c[X+32>>2]=d,X)|0);i=X;Y=A;Z=B}}while(0);B=u+64|0;c[B>>2]=Z;c[B+4>>2]=Y;ea=c[o>>2]|0}else{ea=z}B=y+1|0;if(B>>>0<ea>>>0){y=B;z=ea}else{x=0;break}}i=g;return x|0}function rP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;j=i;k=c[b+28>>2]|0;a:do{if((k|0)>0){l=c[b+32>>2]|0;m=e;n=d;o=0;p=0;q=0;while(1){r=c[l+(o<<2)>>2]|0;s=r+40|0;t=c[s>>2]|0;u=c[s+4>>2]|0;s=m>>>0>u>>>0|m>>>0==u>>>0&n>>>0>t>>>0;v=s?n:t;w=s?m:u;s=r+48|0;x=c[s>>2]|0;y=c[s+4>>2]|0;s=wrc(x,y,t,u)|0;z=G;if(w>>>0<z>>>0|w>>>0==z>>>0&v>>>0<s>>>0){break}s=c[r+20>>2]|0;z=Erc(s,(s|0)<0|0?-1:0,x,y)|0;s=wrc(z,G,q,p)|0;z=o+1|0;if((z|0)<(k|0)){m=w;n=v;o=z;p=G;q=s}else{A=w;B=v;break a}}o=xrc(v,w,t,u)|0;n=G;m=c[r+20>>2]|0;do{if((m|0)==0){l=c[r+68>>2]|0;if((l|0)==0){KIb(c[a+28>>2]|0,16,2262496,(C=i,i=i+24|0,c[C>>2]=c[b>>2],c[C+8>>2]=t,c[C+16>>2]=u,C)|0);i=C;D=-1094995529;i=j;return D|0}s=l;z=(l|0)<0|0?-1:0;l=yrc(o|0,n|0,(s|0)==(x<<1|0>>>31|1|0)&(z|0)==(y<<1|x>>>31|0)&1|0)|0;E=G;F=-1;if(((E|0)>(F|0)|(E|0)==(F|0)&l>>>0>-1>>>0)&((E|0)<(z|0)|(E|0)==(z|0)&l>>>0<s>>>0)){s=(c[r+64>>2]|0)+(l<<3)|0;H=c[s+4>>2]|0;I=c[s>>2]|0;break}KIb(c[a+28>>2]|0,16,2315248,(C=i,i=i+24|0,c[C>>2]=c[b>>2],c[C+8>>2]=t,c[C+16>>2]=u,C)|0);i=C;D=-1094995529;i=j;return D|0}else{s=Erc(m,(m|0)<0|0?-1:0,o,n)|0;l=wrc(s,G,q,p)|0;H=G;I=l}}while(0);if((f|0)!=0){c[f>>2]=v;c[f+4>>2]=w}p=c[b+4>>2]|0;q=c[a+4>>2]|0;b:do{if((q|0)!=0){n=c[a>>2]|0;o=0;m=H;l=I;while(1){if((c[n+(o*88|0)+28>>2]|0)==(p|0)){s=n+(o*88|0)+48|0;z=c[s>>2]|0;E=c[s+4>>2]|0;if((m|0)<(E|0)|(m|0)==(E|0)&l>>>0<z>>>0|(z|0)==0&(E|0)==0){break}s=xrc(l,m,z,E)|0;J=G;K=s}else{J=m;K=l}s=o+1|0;if(s>>>0<q>>>0){o=s;m=J;l=K}else{break b}}s=n+(o*88|0)+40|0;E=wrc(c[s>>2]|0,c[s+4>>2]|0,l,m)|0;c[g>>2]=E;c[g+4>>2]=G;D=0;i=j;return D|0}}while(0);KIb(c[a+28>>2]|0,16,2182168,(C=i,i=i+24|0,c[C>>2]=I,c[C+8>>2]=H,c[C+16>>2]=p,C)|0);i=C;D=-1094995529;i=j;return D|0}else{A=e;B=d}}while(0);if((h|0)==0){D=-1094995529;i=j;return D|0}h=c[b>>2]|0;KIb(c[a+28>>2]|0,16,2215296,(C=i,i=i+24|0,c[C>>2]=B,c[C+8>>2]=A,c[C+16>>2]=h,C)|0);i=C;D=-1094995529;i=j;return D|0}function sP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;h=i;g=JD(b)|0;f=JD(b)|0;if((f|0)!=18){QIb(b,2153400,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;k=-1163346256;i=h;return k|0}if((g|0)>65536){KIb(c[a+28>>2]|0,16,2151728,(j=i,i=i+8|0,c[j>>2]=g,j)|0);i=j;k=-1094995529;i=h;return k|0}j=qJb(g,18)|0;c[a+36>>2]=j;if((j|0)==0){k=-12;i=h;return k|0}c[a+40>>2]=g;AD(b,j,g*18|0)|0;k=0;i=h;return k|0}function tP(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+16|0;l=f|0;m=b;n=b+4|0;o=nJb(c[m>>2]|0,(c[n>>2]|0)+1|0,88)|0;p=o;if((o|0)==0){q=-12;i=f;return q|0}c[m>>2]=p;o=b+120|0;r=c[o>>2]|0;s=r+1|0;if((c[b+108>>2]|0)==0){c[o>>2]=s;t=p+((c[n>>2]|0)*88|0)|0;c[b+104>>2]=t;u=t}else{orc(p+(s*88|0)|0,p+(r*88|0)|0,((c[n>>2]|0)-r|0)*88|0|0)|0;r=(c[m>>2]|0)+((c[o>>2]|0)*88|0)|0;c[b+104>>2]=r;u=r}mrc(u|0,0,88)|0;c[n>>2]=(c[n>>2]|0)+1;n=fD(e,0,0,1)|0;r=G;o=xrc(g,0,j,k)|0;g=wrc(o,G,n,r)|0;c[u+80>>2]=g;g=d[h+13|0]|0;if((g|0)==3){c[u+8>>2]=1;v=10}else if((g|0)==2){c[u+8>>2]=0;v=10}else if((g|0)==4){c[u+8>>2]=2;w=1;x=h+14|0}else{KIb(c[b+28>>2]|0,16,2181624,(y=i,i=i+8|0,c[y>>2]=g,y)|0);i=y;q=-1094995529;i=f;return q|0}if((v|0)==10){g=h+14|0;w=(a[g]&1^1)&255;x=g}c[u>>2]=w;c[u+4>>2]=(d[x]|0)>>>0>2>>>0;hD(e,4,0)|0;x=u+56|0;c[x>>2]=JD(e)|0;w=OD(e)|0;g=u+32|0;c[g>>2]=w;c[g+4>>2]=G;g=OD(e)|0;w=u+16|0;c[w>>2]=g;c[w+4>>2]=G;g=OD(e)|0;h=G;r=OD(e)|0;n=u+64|0;c[n>>2]=r;c[n+4>>2]=G;n=OD(e)|0;r=u+72|0;c[r>>2]=n;c[r+4>>2]=G;c[u+24>>2]=JD(e)|0;hD(e,8,0)|0;c[u+28>>2]=JD(e)|0;if((AD(e,l|0,16)|0)!=16){KIb(c[b+28>>2]|0,16,2179408,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;q=-1094995529;i=f;return q|0}u=JD(e)|0;do{if(!((g|0)==0&(h|0)==0)){e=b+56|0;r=c[e>>2]|0;n=c[e+4>>2]|0;if((r|0)==0&(n|0)==0|(r|0)==(g|0)&(n|0)==(h|0)){c[e>>2]=g;c[e+4>>2]=h;break}else{KIb(c[b+28>>2]|0,16,2177704,(y=i,i=i+32|0,c[y>>2]=r,c[y+8>>2]=n,c[y+16>>2]=g,c[y+24>>2]=h,y)|0);i=y;break}}}while(0);h=c[w>>2]|0;g=c[w+4>>2]|0;do{if(!((h|0)==0&(g|0)==0)){w=c[b+100>>2]|0;n=wrc(w,(w|0)<0|0?-1:0,h,g)|0;w=G;if(w>>>0<k>>>0|w>>>0==k>>>0&n>>>0<j>>>0){break}KIb(c[b+28>>2]|0,16,2171024,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;q=-1094995529;i=f;return q|0}}while(0);j=a[l+12|0]|0;a:do{switch(j<<24>>24){case 16:{v=40;break};case 64:{v=38;break};case 3:{v=32;break};case 1:{k=a[l+13|0]|0;if((k<<24>>24|0)==1){c[b+8>>2]=1;break a}else if((k<<24>>24|0)==2){c[b+8>>2]=2;break a}else if((k<<24>>24|0)==3){c[b+8>>2]=3;break a}else{if((j<<24>>24|0)==16){v=40;break a}else if((j<<24>>24|0)==64){v=38;break a}else if((j<<24>>24|0)==3){v=32;break a}else if((j<<24>>24|0)==2){v=26;break a}else{v=45;break a}}break};case 2:{v=26;break};default:{v=45}}}while(0);do{if((v|0)==26){if((a[l+13|0]|0)==1){c[b+8>>2]=4;break}k=a[l+13|0]|0;if((k<<24>>24|0)==3){c[b+8>>2]=6;break}else if((k<<24>>24|0)==2){c[b+8>>2]=5;break}else{if((j<<24>>24|0)==16){v=40;break}else if((j<<24>>24|0)==64){v=38;break}else if((j<<24>>24|0)==3){v=32;break}else{v=45;break}}}}while(0);do{if((v|0)==32){if((a[l+13|0]|0)==1){c[b+8>>2]=7;break}k=a[l+13|0]|0;if((k<<24>>24|0)==2){c[b+8>>2]=8;break}else if((k<<24>>24|0)==3){c[b+8>>2]=9;break}else{if((j<<24>>24|0)==16){v=40;break}else if((j<<24>>24|0)==64){v=38;break}else{v=45;break}}}}while(0);do{if((v|0)==38){if((a[l+13|0]|0)!=1){v=45;break}c[b+8>>2]=11}else if((v|0)==40){if((u|0)==1){c[b+8>>2]=10;break}k=(u|0)!=0;g=b+8|0;if((c[g>>2]|0)==0){KIb(c[b+28>>2]|0,24,2164840,(y=i,i=i+16|0,c[y>>2]=u,c[y+8>>2]=k?2162744:2160544,y)|0);i=y}c[g>>2]=k?1:10}}while(0);if((v|0)==45){v=d[l+13|0]|0;KIb(c[b+28>>2]|0,16,2158752,(y=i,i=i+16|0,c[y>>2]=j&255,c[y+8>>2]=v,y)|0);i=y;c[b+8>>2]=1}v=c[x>>2]|0;if(!((v-1|0)>>>0>1048575>>>0)){q=0;i=f;return q|0}j=b+28|0;KIb(c[j>>2]|0,24,2156760,(y=i,i=i+8|0,c[y>>2]=v,y)|0);i=y;v=(c[b+8>>2]|0)==11?512:1;c[x>>2]=v;KIb(c[j>>2]|0,24,2155160,(y=i,i=i+8|0,c[y>>2]=v,y)|0);i=y;q=0;i=f;return q|0}function uP(a,b,e,f,g,h,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+72|0;h=j|0;g=j+48|0;k=j+64|0;l=c[a+28>>2]|0;a=g|0;mrc(a|0,0,16)|0;c[k>>2]=0;switch(e|0){case 15370:{AD(b,a,16)|0;e=pJb(37)|0;c[k>>2]=e;if((e|0)==0){m=-12;i=j;return m|0}else{n=0;o=e}while(1){Rb(o|0,3,2269056,(p=i,i=i+8|0,c[p>>2]=d[g+n|0]|0,p)|0)|0;i=p;e=o+2|0;if((n|0)==9|(n|0)==7|(n|0)==5|(n|0)==3){Rb(e|0,2,2183904,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0)|0;i=p;q=o+3|0}else{q=e}e=n+1|0;if(e>>>0<16>>>0){n=e;o=q}else{break}}MGb(l+1140|0,2188888,c[k>>2]|0,8)|0;m=0;i=j;return m|0};case 15362:{if((f|0)<0){m=-22;i=j;return m|0}q=f+1+((f|0)/2|0)|0;o=hJb(q)|0;c[k>>2]=o;if((o|0)==0){m=-12;i=j;return m|0}n=ND(b,f,o,q)|0;if((n|0)<0){mJb(k);m=n;i=j;return m|0}else{MGb(l+1140|0,2212168,c[k>>2]|0,8)|0;m=0;i=j;return m|0}break};case 15365:{AD(b,a,16)|0;n=pJb(37)|0;c[k>>2]=n;if((n|0)==0){m=-12;i=j;return m|0}else{r=0;s=n}while(1){Rb(s|0,3,2269056,(p=i,i=i+8|0,c[p>>2]=d[g+r|0]|0,p)|0)|0;i=p;n=s+2|0;if((r|0)==9|(r|0)==7|(r|0)==5|(r|0)==3){Rb(n|0,2,2183904,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0)|0;i=p;t=s+3|0}else{t=n}n=r+1|0;if(n>>>0<16>>>0){r=n;s=t}else{break}}MGb(l+1140|0,2202896,c[k>>2]|0,8)|0;m=0;i=j;return m|0};case 15368:{if((f|0)<0){m=-22;i=j;return m|0}t=f+1+((f|0)/2|0)|0;s=hJb(t)|0;c[k>>2]=s;if((s|0)==0){m=-12;i=j;return m|0}r=ND(b,f,s,t)|0;if((r|0)<0){mJb(k);m=r;i=j;return m|0}else{MGb(l+1140|0,2193816,c[k>>2]|0,8)|0;m=0;i=j;return m|0}break};case 15369:{AD(b,a,16)|0;a=pJb(37)|0;c[k>>2]=a;if((a|0)==0){m=-12;i=j;return m|0}else{u=0;v=a}while(1){Rb(v|0,3,2269056,(p=i,i=i+8|0,c[p>>2]=d[g+u|0]|0,p)|0)|0;i=p;a=v+2|0;if((u|0)==9|(u|0)==7|(u|0)==5|(u|0)==3){Rb(a|0,2,2183904,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0)|0;i=p;w=v+3|0}else{w=a}a=u+1|0;if(a>>>0<16>>>0){u=a;v=w}else{break}}MGb(l+1140|0,2191280,c[k>>2]|0,8)|0;m=0;i=j;return m|0};case 15361:{if((f|0)<0){m=-22;i=j;return m|0}w=f+1+((f|0)/2|0)|0;v=hJb(w)|0;c[k>>2]=v;if((v|0)==0){m=-12;i=j;return m|0}u=ND(b,f,v,w)|0;if((u|0)<0){mJb(k);m=u;i=j;return m|0}else{MGb(l+1140|0,2214624,c[k>>2]|0,8)|0;m=0;i=j;return m|0}break};case 15364:{if((f|0)<0){m=-22;i=j;return m|0}u=f+1+((f|0)/2|0)|0;w=hJb(u)|0;c[k>>2]=w;if((w|0)==0){m=-12;i=j;return m|0}v=ND(b,f,w,u)|0;if((v|0)<0){mJb(k);m=v;i=j;return m|0}else{MGb(l+1140|0,2210488,c[k>>2]|0,8)|0;m=0;i=j;return m|0}break};case 15366:{v=OD(b)|0;b=G;mrc(h|0,0,44)|0;u=wrc(b>>>16|0<<16,0>>>16|0<<16,-1900,0)|0;c[h+20>>2]=u;u=wrc((b>>>8|0<<24)&255,(0>>>8|0<<24)&0,-1,0)|0;w=u;u=b&255;c[h+8>>2]=(v>>>24|b<<8)&255;c[h+4>>2]=(v>>>16|b<<16)&255;c[h>>2]=(v>>>8|b<<24)&255;c[h+16>>2]=(w|0)>0?w:0;c[h+12>>2]=u>>>0>1>>>0?u:1;u=pJb(32)|0;c[k>>2]=u;if((u|0)==0){m=-12;i=j;return m|0}Fc(u|0,32,2186064,h|0)|0;MGb(l+1140|0,2196496,c[k>>2]|0,8)|0;m=0;i=j;return m|0};default:{m=0;i=j;return m|0}}return 0}function vP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((d|0)!=6401){i=0;return i|0}d=JD(b)|0;h=a+16|0;c[h>>2]=d;g=qJb(d,16)|0;d=a+12|0;c[d>>2]=g;if((g|0)==0){i=-12;return i|0}hD(b,4,0)|0;AD(b,c[d>>2]|0,c[h>>2]<<4)|0;i=0;return i|0}function wP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((d|0)==17411){h=JD(b)|0;g=a+40|0;c[g>>2]=h;f=qJb(h,16)|0;h=a+36|0;c[h>>2]=f;if((f|0)==0){i=-12;return i|0}hD(b,4,0)|0;AD(b,c[h>>2]|0,c[g>>2]<<4)|0;i=0;return i|0}else if((d|0)==17409){hD(b,16,0)|0;AD(b,a+20|0,16)|0;i=0;return i|0}else if((d|0)==18177){AD(b,a+48|0,16)|0;i=0;return i|0}else{i=0;return i|0}return 0}function xP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((d|0)!=17411){i=0;return i|0}d=JD(b)|0;h=a+40|0;c[h>>2]=d;g=qJb(d,16)|0;d=a+36|0;c[d>>2]=g;if((g|0)==0){i=-12;return i|0}hD(b,4,0)|0;AD(b,c[d>>2]|0,c[h>>2]<<4)|0;i=0;return i|0}function yP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((d|0)==514){h=OD(b)|0;g=a+48|0;c[g>>2]=h;c[g+4>>2]=G;i=0;return i|0}else if((d|0)==513){AD(b,a+20|0,16)|0;i=0;return i|0}else if((d|0)==4097){d=JD(b)|0;g=a+40|0;c[g>>2]=d;h=qJb(d,16)|0;d=a+36|0;c[d>>2]=h;if((h|0)==0){i=-12;return i|0}hD(b,4,0)|0;AD(b,c[d>>2]|0,c[g>>2]<<4)|0;i=0;return i|0}else{i=0;return i|0}return 0}function zP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;if((d|0)==4353){hD(b,16,0)|0;AD(b,a+20|0,16)|0;return 0}else if((d|0)==4354){c[a+72>>2]=JD(b)|0;return 0}else if((d|0)==514){h=OD(b)|0;g=a+56|0;c[g>>2]=h;c[g+4>>2]=G;return 0}else if((d|0)==4609){d=OD(b)|0;b=a+64|0;c[b>>2]=d;c[b+4>>2]=G;return 0}else{return 0}return 0}function AP(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;i=i+16|0;h=j|0;k=b+124|0;c[k>>2]=-1;a:do{switch(e|0){case 12294:{c[b+112>>2]=JD(d)|0;l=0;break};case 12802:{c[b+72>>2]=JD(d)|0;l=0;break};case 12803:{c[b+68>>2]=JD(d)|0;l=0;break};case 13058:{c[b+96>>2]=JD(d)|0;l=0;break};case 12292:{AD(d,b+20|0,16)|0;l=0;break};case 12812:{c[b+76>>2]=zD(d)|0;l=0;break};case 15617:{c[b+88>>2]=JD(d)|0;l=0;break};case 13313:{m=h|0;mrc(m|0,0,16)|0;n=0;while(1){o=zD(d)|0;p=zD(d)|0;if((n|0)>=15){break}a[h+n|0]=o;a[h+(n|1)|0]=p;if((o|0)==0){break}else{n=n+2|0}}I$(m,k)|0;l=0;break};case 13064:{c[b+100>>2]=JD(d)|0;l=0;break};case 12818:{c[b+80>>2]=zD(d)|0;l=0;break};case 12801:{AD(d,b+36|0,16)|0;l=0;break};case 13057:{c[b+92>>2]=JD(d)|0;l=0;break};case 15623:{c[b+84>>2]=JD(d)|0;l=0;break};case 15622:{AD(d,b+36|0,16)|0;l=0;break};case 12814:{c[b+60>>2]=JD(d)|0;c[b+64>>2]=JD(d)|0;l=0;break};case 16129:{n=JD(d)|0;o=b+108|0;c[o>>2]=n;p=qJb(n,16)|0;n=b+104|0;c[n>>2]=p;if((p|0)==0){l=-12;break a}hD(d,4,0)|0;AD(d,c[n>>2]|0,c[o>>2]<<4)|0;l=0;break};case 15619:{c[b+52>>2]=JD(d)|0;c[b+56>>2]=JD(d)|0;l=0;break};default:{if((grc(g,786048,16)|0)!=0){l=0;break a}o=b+116|0;if((c[o>>2]|0)==0){q=0}else{KIb(0,24,2217464,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=c[o>>2]|0}kJb(q);n=b+120|0;c[n>>2]=0;p=hJb(f)|0;c[o>>2]=p;if((p|0)==0){l=-12;break a}c[n>>2]=f;AD(d,p,f)|0;l=0}}}while(0);i=j;return l|0}function BP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;if((d|0)==19201){c[a+48>>2]=JD(b)|0;c[a+52>>2]=JD(b)|0;return 0}else if((d|0)==18435){AD(b,a+24|0,16)|0;return 0}else if((d|0)==18433){c[a+40>>2]=JD(b)|0;return 0}else if((d|0)==18436){AD(b,a+44|0,4)|0;return 0}else{return 0}return 0}function CP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;if((d|0)==5378){c[a+28>>2]=HD(b)|0;c[a+32>>2]=1;return 0}else if((d|0)==5377){h=OD(b)|0;c[a+24>>2]=h;return 0}else if((d|0)==5379){c[a+20>>2]=zD(b)|0;return 0}else{return 0}return 0}function DP(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;do{if((d|0)==16){if((grc(e,790864,16)|0)!=0){h=0;break}AD(b,a+20|0,16)|0;h=0}else{h=-1094995529}}while(0);return h|0}function EP(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;switch(e|0){case 16141:{e=b+48|0;c[e>>2]=OD(d)|0;c[e+4>>2]=G;j=0;return j|0};case 16140:{e=b+40|0;c[e>>2]=OD(d)|0;c[e+4>>2]=G;j=0;return j|0};case 16133:{c[b+20>>2]=JD(d)|0;j=0;return j|0};case 16139:{c[b+32>>2]=JD(d)|0;c[b+36>>2]=JD(d)|0;j=0;return j|0};case 16138:{e=b+68|0;c[e>>2]=JD(d)|0;i=JD(d)|0;h=qJb(c[e>>2]|0,1)|0;g=b+56|0;c[g>>2]=h;if((h|0)==0){j=-12;return j|0}h=qJb(c[e>>2]|0,4)|0;f=b+60|0;c[f>>2]=h;if((h|0)==0){j=-12;return j|0}h=qJb(c[e>>2]|0,8)|0;k=b+64|0;c[k>>2]=h;if((h|0)==0){j=-12;return j|0}if((c[e>>2]|0)<=0){j=0;return j|0}h=i-11|0;i=h;l=(h|0)<0|0?-1:0;h=0;while(1){m=(zD(d)|0)&255;a[(c[g>>2]|0)+h|0]=m;zD(d)|0;m=zD(d)|0;c[(c[f>>2]|0)+(h<<2)>>2]=m;m=OD(d)|0;n=(c[k>>2]|0)+(h<<3)|0;c[n>>2]=m;c[n+4>>2]=G;hD(d,i,l)|0;n=h+1|0;if((n|0)<(c[e>>2]|0)){h=n}else{j=0;break}}return j|0};case 16134:{c[b+24>>2]=JD(d)|0;j=0;return j|0};case 16135:{c[b+28>>2]=JD(d)|0;j=0;return j|0};default:{j=0;return j|0}}return 0}function FP(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;e=i;i=i+56|0;f=e|0;g=e+8|0;h=e+48|0;j=h;k=i;i=i+8|0;l=k;m=i;i=i+8|0;n=b+12|0;o=c[n>>2]|0;mrc(g|0,0,35)|0;p=b+1140|0;q=LGb(c[p>>2]|0,2463232,0,0)|0;r=b+24|0;if((c[r>>2]|0)==0){s=-1;i=e;return s|0}t=b+28|0;u=l+4|0;v=k;w=o+104|0;x=o+20|0;z=x;A=x;x=o+24|0;B=o+80|0;C=b;D=b+8|0;E=o+108|0;F=o+16|0;H=o+48|0;I=0;J=q;q=0;a:while(1){K=c[(c[t>>2]|0)+(q<<2)>>2]|0;L=pJb(104)|0;if((L|0)==0){s=-12;M=67;break}c[K+12>>2]=L;N=K+8|0;O=c[N>>2]|0;P=c[O+8>>2]|0;Q=(P|0)==0;if((q|0)==0^Q){M=5;break}do{if(Q){R=O+104|0;S=c[R>>2]|0;T=c[R+4>>2]|0;c[k>>2]=S;c[k+4>>2]=T;c[L+76>>2]=8;R=S;c[w>>2]=(((R|0)/2|0)+T|0)/(R|0)|0;R=J$(b,l)|0;if((R|0)==0){M=8;break a}T=R;S=c[T>>2]|0;U=c[T+4>>2]|0;c[z>>2]=S;c[z+4>>2]=U;c[h>>2]=U;c[h+4>>2]=S;_X(K,64,c[A>>2]|0,c[x>>2]|0);do{if((J|0)==0){S=LGb(c[K+88>>2]|0,2463232,0,0)|0;if((S|0)!=0){V=S;M=11;break}W=rLb(B,j,0,0,C)|0;X=0}else{V=J;M=11}}while(0);if((M|0)==11){M=0;W=sLb(B,j,c[V+4>>2]|0,C)|0;X=V}if((W|0)<0){s=W;M=67;break a}S=c[N>>2]|0;U=c[S+72>>2]|0;if((U|0)==0){Y=c[S+540>>2]|0}else{Y=U}U=L+96|0;c[U>>2]=Y;if((c[D>>2]|0)!=1339240){Z=X;_=R;break}do{if((Y|0)==3e7){S=L+56|0;if((c[x>>2]|0)==25){c[S>>2]=11;break}else{c[S>>2]=13;break}}else if((Y|0)==4e7){S=L+56|0;if((c[x>>2]|0)==25){c[S>>2]=7;break}else{c[S>>2]=9;break}}else if((Y|0)==5e7){S=L+56|0;if((c[x>>2]|0)==25){c[S>>2]=3;break}else{c[S>>2]=5;break}}else{M=27;break a}}while(0);c[E>>2]=512;S=c[U>>2]|0;T=c[A>>2]|0;$=Erc(T,(T|0)<0|0?-1:0,S,(S|0)<0|0?-1:0)|0;S=c[x>>2]<<3;T=Frc($,G,S,(S|0)<0|0?-1:0)|0;S=wrc(T,G,532,0)|0;T=xrc(512,0,S&511,G&0)|0;$=T;T=($>>>0<20>>>0?$+512|0:$&511)+S|0;c[E>>2]=T;S=T+(c[R+8>>2]<<5|24)|0;T=512-(S&511)|0;c[E>>2]=(T>>>0<20>>>0?T+512|0:T&511)+S;Z=X;_=R}else{if((P|0)!=1){Z=J;_=I;break}if((c[O+412>>2]|0)!=48e3){M=31;break a}_X(K,64,1,48e3);if((c[D>>2]|0)!=1339240){a[H]=1;Z=J;_=I;break}if((c[K>>2]|0)!=1){M=34;break a}S=c[(c[N>>2]|0)+48>>2]|0;if(!((S|0)==65536|(S|0)==65548)){KIb(C,16,2398144,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}c[L+56>>2]=(c[(c[(c[c[t>>2]>>2]|0)+12>>2]|0)+56>>2]|0)+1;Z=J;_=I}}while(0);ba=L+56|0;K=c[ba>>2]|0;if((K|0)==0){O=c[(c[N>>2]|0)+48>>2]|0;P=0;while(1){if((P|0)==5){M=42;break a}if((c[788928+(P<<3)>>2]|0)==(O|0)){break}else{P=P+1|0}}O=c[788932+(P<<3)>>2]|0;c[ba>>2]=O;ca=O}else{ca=K}c[L+60>>2]=789024+(ca*52|0);nrc(L+40|0,789008+(ca*52|0)|0,15)|0;O=a[g+ca|0]|0;a[L+55|0]=O;if(O<<24>>24==0){c[F>>2]=(c[F>>2]|0)+1;N=c[ba>>2]|0;da=N;ea=a[g+N|0]|0}else{da=ca;ea=O}a[g+da|0]=ea+1;O=q+1|0;if(O>>>0<(c[r>>2]|0)>>>0){I=_;J=Z;q=O}else{M=48;break}}if((M|0)==5){KIb(C,16,2448056,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==8){Z=c[v>>2]|0;KIb(C,16,2432840,(aa=i,i=i+16|0,c[aa>>2]=c[u>>2],c[aa+8>>2]=Z,aa)|0);i=aa;s=-22;i=e;return s|0}else if((M|0)==27){KIb(C,16,2424168,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==31){KIb(C,16,2413296,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==34){KIb(C,16,2405632,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==42){c[ba>>2]=-1;KIb(C,16,2391048,(aa=i,i=i+8|0,c[aa>>2]=q,aa)|0);i=aa;s=-1;i=e;return s|0}else if((M|0)==48){if((c[D>>2]|0)==1339240){c[o+16>>2]=1}D=b+28|0;if((c[(c[(c[c[D>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)==0){aa=c[n>>2]|0;n=wKb()|0;q=je(n|0)|0;C=aa+124|0;ba=C|0;y=879858770;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;ba=C+4|0;y=q;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;ba=je(n>>>8|872415232|0)|0;q=aa+132|0;C=q|0;y=1905545728;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=q+4|0;y=ba;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[aa+120>>2]=n&16777215}if((c[r>>2]|0)!=0){n=0;do{aa=c[(c[(c[D>>2]|0)+(n<<2)>>2]|0)+12>>2]|0;C=aa+53|0;a[C]=a[g+(c[aa+56>>2]|0)|0]|0;if((grc(aa+40|0,789788,13)|0)==0){ba=C;c[aa+64>>2]=je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0|352321536}else{ba=aa+52|0;c[aa+64>>2]=je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0}n=n+1|0;}while(n>>>0<(c[r>>2]|0)>>>0)}r=LGb(c[p>>2]|0,2384312,0,0)|0;do{if((r|0)!=0){p=pY(c[r+4>>2]|0)|0;if((p|0)==0&(G|0)==0){break}c[f>>2]=p;p=rc(f|0)|0;if((p|0)==0){fa=0;ga=0}else{n=c[p+8>>2]<<24;g=c[p+4>>2]<<16;D=c[p>>2]<<8;fa=(c[p+16>>2]|0)+1<<8|0>>>24|((c[p+20>>2]|0)+1900<<16|0>>>16)|c[p+12>>2]|((n|0)<0|0?-1:0)|((g|0)<0|0?-1:0)|((D|0)<0|0?-1:0);ga=0<<8|0>>>24|(0<<16|0>>>16)|n|g|D}D=o+40|0;c[D>>2]=ga;c[D+4>>2]=fa}}while(0);fa=o+72|0;c[fa>>2]=-1;c[fa+4>>2]=-1;fa=pJb(656)|0;ga=o+100|0;c[ga>>2]=fa;if((fa|0)==0){s=-12;i=e;return s|0}fa=pJb(104)|0;c[(c[ga>>2]|0)+12>>2]=fa;fa=c[ga>>2]|0;if((c[fa+12>>2]|0)==0){s=-12;i=e;return s|0}c[fa>>2]=-1;if((_|0)==0){c[m>>2]=1;c[m+4>>2]=25;ha=J$(b,m)|0}else{ha=_}s=(l$(b,ha+8|0,o+20|0)|0)>>31;i=e;return s|0}else if((M|0)==67){i=e;return s|0}return 0}function GP(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;g=i;h=e+12|0;j=c[h>>2]|0;k=e+16|0;l=c[k>>2]|0;m=e+28|0;n=c[(c[m>>2]|0)+(c[f+32>>2]<<2)>>2]|0;o=n+12|0;p=c[o>>2]|0;q=j+108|0;do{if((c[q>>2]|0)==0){r=j+36|0;s=c[r>>2]|0;if(((s>>>0)%250|0|0)!=0){break}t=oJb(j+32|0,s+250|0,24)|0;if((t|0)>=0){break}c[r>>2]=0;KIb(e,16,2554808,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=t;i=g;return v|0}}while(0);t=n+8|0;r=c[(c[t>>2]|0)+48>>2]|0;a:do{if((r|0)==25){s=c[o>>2]|0;w=c[h>>2]|0;if((c[w+28>>2]|0)!=0){x=0;y=0;break}if((c[f+28>>2]|0)<12e4){x=0;y=0;break}z=c[f+24>>2]|0;A=d[z+451|0]|0;B=A&31;C=A>>>5;A=C&1;D=s+84|0;if((a[z+450|0]&7)==2){c[D>>2]=16;c[s+88>>2]=9}else{c[D>>2]=4;c[s+88>>2]=3}D=(d[z+456|0]|0)>>>4&1;z=s+68|0;c[z>>2]=D;do{if((B|0)==24){E=C|6;F=(A|0)!=0?288e3:24e4;if((D|0)==0){H=E;I=F;break}KIb(e,16,2482344,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;c[z>>2]=0;H=E;I=F}else if((B|0)==20){H=A|4;I=(A|0)!=0?576e3:48e4}else if((B|0)==4){H=A|2;I=(A|0)!=0?288e3:24e4}else{H=A;I=(A|0)!=0?144e3:12e4}}while(0);A=H+16|0;c[s+56>>2]=A;c[s+60>>2]=789024+(A*52|0);A=w+108|0;c[A>>2]=512;B=e+24|0;if((c[B>>2]|0)==0){x=0;y=0;break}z=c[m>>2]|0;D=I|20;C=0;F=512;while(1){E=c[z+(C<<2)>>2]|0;J=c[(c[E+8>>2]|0)+8>>2]|0;if((J|0)==0){K=F+D|0;L=512-(K&511)|0;M=(L>>>0<20>>>0?L+512|0:L&511)+K|0;c[A>>2]=M;N=M}else if((J|0)==1){J=c[E+12>>2]|0;E=F+20+(ca(c[J+16>>2]|0,c[c[J+24>>2]>>2]|0)|0)|0;J=512-(E&511)|0;M=(J>>>0<20>>>0?J+512|0:J&511)+E|0;c[A>>2]=M;N=M}else{N=F}M=C+1|0;if(M>>>0<(c[B>>2]|0)>>>0){C=M;F=N}else{x=0;y=0;break}}}else if((r|0)==100){F=c[o>>2]|0;C=c[h>>2]|0;if((c[C+28>>2]|0)!=0){x=0;y=0;break}if((c[f+28>>2]|0)<43){x=0;y=0;break}B=c[f+24>>2]|0;A=(d[B+41|0]|0)<<16|(d[B+40|0]|0)<<24|(d[B+42|0]|0)<<8|(d[B+43|0]|0);B=h6(A)|0;if((B|0)<0){x=0;y=0;break}switch(A|0){case 1253:{c[F+56>>2]=33;O=33;break};case 1238:{c[F+56>>2]=26;O=26;break};case 1241:{c[F+56>>2]=27;c[F+76>>2]=10;O=27;break};case 1242:{c[F+56>>2]=28;O=28;break};case 1250:{c[F+56>>2]=30;c[F+76>>2]=10;O=30;break};case 1243:{c[F+56>>2]=29;O=29;break};case 1252:{c[F+56>>2]=32;O=32;break};case 1235:{c[F+56>>2]=24;c[F+76>>2]=10;O=24;break};case 1237:{c[F+56>>2]=25;O=25;break};case 1251:{c[F+56>>2]=31;O=31;break};default:{x=0;y=0;break a}}c[F+60>>2]=789024+(O*52|0);c[F+84>>2]=16;c[F+88>>2]=9;F=C+108|0;c[F>>2]=512;C=e+24|0;if((c[C>>2]|0)==0){x=0;y=0;break}A=c[m>>2]|0;D=B+20|0;B=0;z=512;while(1){w=c[A+(B<<2)>>2]|0;s=c[(c[w+8>>2]|0)+8>>2]|0;if((s|0)==1){M=c[w+12>>2]|0;w=z+20+(ca(c[M+16>>2]|0,c[c[M+24>>2]>>2]|0)|0)|0;M=512-(w&511)|0;E=(M>>>0<20>>>0?M+512|0:M&511)+w|0;c[F>>2]=E;P=E}else if((s|0)==0){s=D+z|0;E=512-(s&511)|0;w=(E>>>0<20>>>0?E+512|0:E&511)+s|0;c[F>>2]=w;P=w}else{P=z}w=B+1|0;if(w>>>0<(c[C>>2]|0)>>>0){B=w;z=P}else{x=0;y=0;break}}}else if((r|0)==2){z=c[o>>2]|0;B=f+28|0;C=c[B>>2]|0;b:do{if((C-4|0)>0){F=f+24|0;D=z+92|0;A=z+84|0;w=z+88|0;s=z+80|0;E=0;M=-256;J=C;K=0;L=0;c:while(1){Q=c[F>>2]|0;R=d[Q+E|0]|0|M;do{if((R|0)==435){S=K|64;T=(d[Q+(E+4)|0]|0)>>>4;if((T|0)==4){c[A>>2]=221;c[w>>2]=100;U=S;V=L;break}else if((T|0)==3){c[A>>2]=16;c[w>>2]=9;U=S;V=L;break}else if((T|0)==2){c[A>>2]=4;c[w>>2]=3;U=S;V=L;break}else{T=c[t>>2]|0;W=c[T+120>>2]|0;X=c[T+124>>2]|0;xKb(A,w,W,(W|0)<0|0?-1:0,X,(X|0)<0|0?-1:0,1048576,0)|0;U=S;V=L;break}}else if((R|0)==437){S=d[Q+(E+1)|0]|0;X=S&240;if((X|0)==16){W=c[t>>2]|0;c[W+840>>2]=S&7;c[W+844>>2]=(d[Q+(E+2)|0]|0)>>>4;U=K;V=L;break}else{Y=E+5|0;if((Y|0)<(J|0)&(X|0)==128){break c}else{U=K;V=L;break}}}else if((R|0)==440){if((a[Q+(E+4)|0]&64)==0){U=K;V=L;break}c[D>>2]=1;U=(K&64)==0?K:K|-128;V=L}else if((R|0)==256){X=d[Q+(E+2)|0]|0;W=X>>>3&7;S=((d[Q+(E+1)|0]|0)<<2|X>>>6)&65535;if((W|0)==3){X=((c[D>>2]|0)==0?51:19)|K;c[s>>2]=-1;U=X;V=S;break}else if((W|0)==0){Z=24;break c}else if((W|0)==2){c[D>>2]=0;U=K|34;V=S;break}else{U=K;V=S;break}}else{U=K;V=L}}while(0);S=E+1|0;W=c[B>>2]|0;if((S|0)>=(W-4|0)){_=U;$=V;Z=27;break b}E=S;M=R<<8;J=W;K=U;L=V}if((Z|0)==24){J=e;KIb(J,16,2471104,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;aa=J;break}J=a[Q+Y|0]|0;c[z+68>>2]=(J&255)>>>7&255^1;if(!(J<<24>>24>-1)){_=K;$=L;Z=27;break}c[z+72>>2]=2-((d[Q+(E+4)|0]|0)>>>7&255);_=K;$=L;Z=27}else{_=0;$=0;Z=27}}while(0);if((Z|0)==27){if((c[e+8>>2]|0)==1339240){ba=c[z+60>>2]|0}else{B=c[t>>2]|0;if((c[B+136>>2]|0)>1){da=1}else{da=(c[B+176>>2]|0)!=0|0}C=c[B+840>>2]|0;do{if((C|0)==4){J=c[B+844>>2]|0;if((J|0)==8){ea=786384+(da<<4)|0;break}else if((J|0)==4){ea=786384+((da|4)<<4)|0;break}else if((J|0)==6){ea=786384+((da|8)<<4)|0;break}else{ea=0;break}}else if((C|0)==0){J=c[B+844>>2]|0;if((J|0)==2){ea=786384+((da|6)<<4)|0;break}else if((J|0)==5){ea=786384+((da|2)<<4)|0;break}else{ea=0;break}}else{ea=0}}while(0);c[z+60>>2]=ea;ba=ea}if((ba|0)!=0){x=_;y=$;break}aa=e}KIb(aa,16,2537008,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1;i=g;return v|0}else{x=0;y=0}}while(0);aa=j+28|0;if((c[aa>>2]|0)==0){do{if((c[q>>2]|0)==0){$=LP(e,0,0,1142224,1)|0;if(($|0)<0){v=$}else{break}i=g;return v|0}else{$=LP(e,1,2,1142224,1)|0;if(($|0)<0){v=$;i=g;return v|0}$=fD(c[k>>2]|0,0,0,1)|0;_=xrc(512,0,$&511,G&0)|0;$=_;_=$>>>0<20>>>0?$+512|0:$&511;if((_|0)!=0){dD(c[k>>2]|0,1034768,16);$=_-20|0;_=c[k>>2]|0;bD(_,131);vD(_,$);cD(c[k>>2]|0,0,$)}MP(e)}}while(0);c[aa>>2]=1}aa=c[n>>2]|0;n=(c[q>>2]|0)!=0;do{if((aa|0)==0){do{if(!n){$=c[j+36>>2]|0;if(!(($|0)==0|$>>>0>250>>>0)){break}if(!((x&51)==0)){break}$=fD(c[k>>2]|0,0,0,1)|0;_=xrc(512,0,$&511,G&0)|0;$=_;_=$>>>0<20>>>0?$+512|0:$&511;if((_|0)!=0){dD(c[k>>2]|0,1034768,16);$=_-20|0;_=c[k>>2]|0;bD(_,131);vD(_,$);cD(c[k>>2]|0,0,$)}$=LP(e,1,2,1900672,0)|0;if(($|0)<0){v=$;i=g;return v|0}$=fD(c[k>>2]|0,0,0,1)|0;_=xrc(512,0,$&511,G&0)|0;$=_;_=$>>>0<20>>>0?$+512|0:$&511;if((_|0)!=0){dD(c[k>>2]|0,1034768,16);$=_-20|0;_=c[k>>2]|0;bD(_,131);vD(_,$);cD(c[k>>2]|0,0,$)}MP(e)}}while(0);z=fD(c[k>>2]|0,0,0,1)|0;$=xrc(512,0,z&511,G&0)|0;z=$;$=z>>>0<20>>>0?z+512|0:z&511;if(($|0)!=0){dD(c[k>>2]|0,1034768,16);z=$-20|0;$=c[k>>2]|0;bD($,131);vD($,z);cD(c[k>>2]|0,0,z)}z=c[h>>2]|0;$=c[k>>2]|0;_=(c[z+36>>2]|0)+(c[z+52>>2]|0)|0;dD($,522424,16);bD($,131);vD($,57);bD($,92);bD($,4);bD($,0);tD($,0);ba=z+80|0;tD($,(c[ba>>2]|0)+_&65535);if((c[z+16>>2]|0)>1){dD($,792592,16)}else{dD($,788992+((c[(c[(c[c[m>>2]>>2]|0)+12>>2]|0)+56>>2]|0)*52|0)|0,16)}bD($,0);sD($,0,0);sD($,0,0);bD($,129);lD($,mLb(ba,_)|0);lD($,0);sD($,0,0);dD($,522408,16);bD($,131);vD($,35);bD($,131);tD($,32);$=c[h>>2]|0;dD(c[k>>2]|0,284504,13);vD(c[k>>2]|0,c[$+120>>2]|0);dD(c[k>>2]|0,$+124|0,15);bD(c[k>>2]|0,1);if((c[q>>2]|0)==0){$=j+112|0;_=c[$+4>>2]|0;ba=j+36|0;z=c[ba>>2]|0;ea=j+32|0;da=c[ea>>2]|0;Q=da+(z*24|0)+8|0;c[Q>>2]=c[$>>2];c[Q+4>>2]=_;a[da+(z*24|0)|0]=x;z=c[ba>>2]|0;b[(c[ea>>2]|0)+(z*24|0)+20>>1]=y;ea=wrc(c[$>>2]|0,c[$+4>>2]|0,512,0)|0;c[$>>2]=ea;c[$+4>>2]=G;fa=z}else{fa=c[j+36>>2]|0}c[j+36>>2]=fa+1}else{if(!((aa|0)==1&(n^1))){break}z=j+112|0;$=(c[j+36>>2]|0)-1|0;ea=c[j+32>>2]|0;ba=ea+($*24|0)+8|0;da=xrc(c[z>>2]|0,c[z+4>>2]|0,c[ba>>2]|0,c[ba+4>>2]|0)|0;c[ea+($*24|0)+16>>2]=da}}while(0);n=fD(c[k>>2]|0,0,0,1)|0;aa=xrc(512,0,n&511,G&0)|0;n=aa;aa=n>>>0<20>>>0?n+512|0:n&511;if((aa|0)!=0){dD(c[k>>2]|0,1034768,16);n=aa-20|0;aa=c[k>>2]|0;bD(aa,131);vD(aa,n);cD(c[k>>2]|0,0,n)}dD(l,p+40|0,16);do{if((c[e+8>>2]|0)==1339240){p=c[t>>2]|0;if((c[p+8>>2]|0)==0){n=c[h>>2]|0;aa=c[k>>2]|0;fa=c[(c[o>>2]|0)+96>>2]|0;y=c[n+20>>2]|0;x=Erc(y,(y|0)<0|0?-1:0,fa,(fa|0)<0|0?-1:0)|0;fa=c[n+24>>2]<<3;n=Frc(x,G,fa,(fa|0)<0|0?-1:0)|0;fa=n+20|0;n=512-(fa&511)|0;x=f+28|0;y=c[x>>2]|0;bD(aa,131);vD(aa,y);dD(aa,c[f+24>>2]|0,c[x>>2]|0);aa=(n>>>0<20>>>0?n+512|0:n&511)+fa-(c[x>>2]|0)|0;x=aa-20|0;if((x|0)>20){dD(c[k>>2]|0,1034768,16);fa=aa-40|0;aa=c[k>>2]|0;bD(aa,131);vD(aa,fa);cD(c[k>>2]|0,0,fa);break}else{KIb(e,24,2492176,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;cD(c[k>>2]|0,0,x);break}}x=c[h>>2]|0;fa=c[k>>2]|0;aa=c[f+24>>2]|0;n=c[f+28>>2]|0;y=(n|0)/(c[p+432>>2]|0)|0;p=aa+n|0;bD(fa,131);vD(fa,y<<5|4);if((y|0)==1920){ga=0}else{ga=((((c[x+36>>2]|0)-1|0)>>>0)%5|0)+1|0}bD(fa,ga);oD(fa,y);bD(fa,(1<<c[(c[t>>2]|0)+416>>2])-1|0);if((n|0)>0){ha=aa}else{break}while(1){aa=c[t>>2]|0;if((c[aa+416>>2]|0)>0){n=ha;y=0;x=aa;while(1){if((c[x+48>>2]|0)==65548){ia=((d[n+1|0]|0)<<8|(d[n+2|0]|0)<<16|(d[n]|0))<<4;ja=n+3|0}else{aa=n;ia=((d[aa]|d[aa+1|0]<<8)<<16>>16&65535)<<12;ja=n+2|0}kD(fa,ia|y);ka=y+1|0;aa=c[t>>2]|0;if((ka|0)<(c[aa+416>>2]|0)){n=ja;y=ka;x=aa}else{break}}if((ka|0)<8){la=ka;ma=ja;Z=126}else{na=ja}}else{la=0;ma=ha;Z=126}if((Z|0)==126){Z=0;x=la;while(1){kD(fa,x);y=x+1|0;if((y|0)<8){x=y}else{na=ma;break}}}if(na>>>0<p>>>0){ha=na}else{break}}}else{p=f+28|0;fa=c[p>>2]|0;bD(l,131);vD(l,fa);dD(l,c[f+24>>2]|0,c[p>>2]|0);fa=(c[p>>2]|0)+20|0;p=512-(fa&511)|0;x=j+112|0;y=wrc((p>>>0<20>>>0?p+512|0:p&511)+fa|0,0,c[x>>2]|0,c[x+4>>2]|0)|0;c[x>>2]=y;c[x+4>>2]=G}}while(0);eD(l);v=0;i=g;return v|0}function HP(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=a+12|0;e=c[b>>2]|0;f=a+16|0;g=c[f>>2]|0;h=e+72|0;c[h>>2]=(c[e+36>>2]|0)+(c[e+52>>2]|0);c[h+4>>2]=0;h=fD(g,0,0,1)|0;i=xrc(512,0,h&511,G&0)|0;h=i;i=h>>>0<20>>>0?h+512|0:h&511;if((i|0)!=0){dD(c[f>>2]|0,1034768,16);h=i-20|0;i=c[f>>2]|0;bD(i,131);vD(i,h);cD(c[f>>2]|0,0,h)}h=fD(g,0,0,1)|0;i=e+8|0;c[i>>2]=h;c[i+4>>2]=G;i=e+108|0;do{if((c[i>>2]|0)==0){h=LP(a,0,2,1211816,0)|0;if((h|0)<0){j=h;return j|0}h=fD(c[f>>2]|0,0,0,1)|0;k=xrc(512,0,h&511,G&0)|0;h=k;k=h>>>0<20>>>0?h+512|0:h&511;if((k|0)!=0){dD(c[f>>2]|0,1034768,16);h=k-20|0;k=c[f>>2]|0;bD(k,131);vD(k,h);cD(c[f>>2]|0,0,h)}MP(a)}else{h=LP(a,0,0,1211816,0)|0;if((h|0)<0){j=h}else{break}return j|0}}while(0);h=fD(c[f>>2]|0,0,0,1)|0;k=xrc(512,0,h&511,G&0)|0;h=k;k=h>>>0<20>>>0?h+512|0:h&511;if((k|0)!=0){dD(c[f>>2]|0,1034768,16);h=k-20|0;k=c[f>>2]|0;bD(k,131);vD(k,h);cD(c[f>>2]|0,0,h)}h=c[b>>2]|0;b=c[f>>2]|0;k=fD(b,0,0,1)|0;l=G;dD(b,682696,16);m=h+60|0;n=Erc(c[m>>2]|0,0,12,0)|0;o=wrc(n,G,28,0)|0;n=G;p=0;q=o;do{if(n>>>0<p>>>0|n>>>0==p>>>0&o>>>0<128>>>0){bD(b,q)}else{r=q>>>0>65535>>>0;s=r?q>>>16:q;t=r?16:0;if((s&65280|0)==0){u=t;v=s}else{u=t|8;v=s>>>8}s=(d[1359664+v|0]|0)+u>>3;t=s+1|0;bD(b,s+129|0);if((t|0)==0){break}else{w=t}do{w=w-1|0;t=zrc(o|0,n|0,w<<3|0)|0;bD(b,t&255);}while((w|0)!=0)}}while(0);if((c[h+108>>2]|0)==0){lD(b,0)}else{lD(b,1)}sD(b,0,0);if((c[m>>2]|0)!=0){w=h+56|0;n=0;do{lD(b,1);o=(c[w>>2]|0)+(n<<3)|0;sD(b,c[o>>2]|0,c[o+4>>2]|0);n=n+1|0;}while(n>>>0<(c[m>>2]|0)>>>0)}lD(b,0);m=h+8|0;sD(b,c[m>>2]|0,c[m+4>>2]|0);m=fD(b,0,0,1)|0;h=G;n=xrc(4,0,k,l)|0;l=wrc(n,G,m,h)|0;lD(b,l);do{if((c[(c[f>>2]|0)+88>>2]|0)!=0){fD(g,0,0,0)|0;if((c[i>>2]|0)==0){l=LP(a,0,0,1142256,1)|0;if((l|0)<0){j=l}else{break}return j|0}l=LP(a,1,2,1142256,1)|0;if((l|0)<0){j=l;return j|0}l=fD(c[f>>2]|0,0,0,1)|0;b=xrc(512,0,l&511,G&0)|0;l=b;b=l>>>0<20>>>0?l+512|0:l&511;if((b|0)!=0){dD(c[f>>2]|0,1034768,16);l=b-20|0;b=c[f>>2]|0;bD(b,131);vD(b,l);cD(c[f>>2]|0,0,l)}MP(a)}}while(0);k$(a);mJb(e+32|0);mJb(e+56|0);f=e+100|0;mJb((c[f>>2]|0)+12|0);mJb(f);f=a+24|0;if((c[f>>2]|0)==0){j=0;return j|0}e=a+28|0;a=0;while(1){mJb((c[(c[e>>2]|0)+(a<<2)>>2]|0)+12|0);i=a+1|0;if(i>>>0<(c[f>>2]|0)>>>0){a=i}else{j=0;break}}return j|0}function IP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return m$(a,b,c,d,388,258)|0}function JP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+8|0;f=d|0;g=c[a+24>>2]|0;a:do{if((g|0)!=0){h=c[a+28>>2]|0;j=0;k=0;do{k=((c[(c[h+(j<<2)>>2]|0)+244>>2]|0)!=0)+k|0;j=j+1|0;}while(j>>>0<g>>>0);if((k|0)==0){break}if((g|0)!=(k|0)&(e|0)==0){break}j=a+1236|0;h=c[j>>2]|0;c[f>>2]=h;b:do{if((g|0)==(k|0)){l=h}else{do{if((h|0)!=0){m=k;n=0;o=h;while(1){if((c[o+32>>2]|0)==0){p=n;q=o;break}r=c[o+80>>2]|0;c[f>>2]=r;s=m-1|0;if((r|0)==0|(s|0)==0){p=o;q=r;break}else{m=s;n=o;o=r}}if((q|0)!=0){o=a+28|0;n=f;m=q;while(1){r=c[m+80>>2]|0;s=(c[(c[o>>2]|0)+(c[m+32>>2]<<2)>>2]|0)+244|0;if((c[s>>2]|0)==(m|0)){c[s>>2]=0;t=c[f>>2]|0}else{t=m}P1(t|0);mJb(n);c[f>>2]=r;if((r|0)==0){break}else{m=r}}}if((p|0)==0){break}c[p+80>>2]=0;m=c[j>>2]|0;c[f>>2]=m;l=m;break b}}while(0);c[j>>2]=0;c[a+1240>>2]=0;break a}}while(0);nrc(b|0,l|0,80)|0;h=c[l+80>>2]|0;c[j>>2]=h;k=(c[(c[a+28>>2]|0)+(c[l+32>>2]<<2)>>2]|0)+244|0;if((c[k>>2]|0)==(l|0)){c[k>>2]=0;u=c[j>>2]|0}else{u=h}if((u|0)==0){c[a+1240>>2]=0}mJb(f);v=1;i=d;return v|0}}while(0);J1(b);v=0;i=d;return v|0}function KP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+28>>2]|0;a=b+16|0;f=c[a>>2]|0;g=c[a+4>>2]|0;a=d+16|0;h=c[a>>2]|0;i=c[a+4>>2]|0;if((g|0)>(i|0)|(g|0)==(i|0)&f>>>0>h>>>0){j=1;return j|0}if(!((f|0)==(h|0)&(g|0)==(i|0))){j=0;return j|0}j=(c[(c[(c[e+(c[d+32>>2]<<2)>>2]|0)+12>>2]|0)+64>>2]|0)<(c[(c[(c[e+(c[b+32>>2]<<2)>>2]|0)+12>>2]|0)+64>>2]|0)|0;return j|0}function LP(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;i=b+12|0;j=c[i>>2]|0;k=b+16|0;l=c[k>>2]|0;m=fD(l,0,0,1)|0;n=G;o=(c[j+108>>2]|0)==0;do{if(o){p=c[j+36>>2]|0;if((p|0)==0){q=4;break}r=((c[b+24>>2]|0)*6|0)+115+(ca((d[j+48|0]<<2)+11|0,p)|0)|0}else{q=4}}while(0);if((q|0)==4){r=o|(f|0)==0?0:80}if((r|0)==0){s=0}else{if(r>>>0<128>>>0){t=17}else{o=r>>>0>65535>>>0;p=o?r>>>16:r;u=o?16:0;if((p&65280|0)==0){v=u;w=p}else{v=u|8;w=p>>>8}t=((d[1359664+w|0]|0)+v>>3)+18|0}v=t+r|0;r=512-(v&511)|0;s=(r>>>0<20>>>0?r+512|0:r&511)+v|0}do{if((grc(g,1900672,16)|0)==0){v=j+56|0;r=j+60|0;t=oJb(v,(c[r>>2]|0)+1|0,8)|0;if((t|0)>=0){w=c[r>>2]|0;c[r>>2]=w+1;p=(c[v>>2]|0)+(w<<3)|0;c[p>>2]=m;c[p+4>>2]=n;break}c[r>>2]=0;x=t;return x|0}}while(0);dD(l,g,16);t=c[j+16>>2]|0;r=((t|0)>1)+t|0;t=r;p=wrc(t<<4|0>>>28,((r|0)<0|0?-1:0)<<4|t>>>28,88,0)|0;t=G;r=0;w=p;do{if(t>>>0<r>>>0|t>>>0==r>>>0&p>>>0<128>>>0){bD(l,w)}else{v=w>>>0>65535>>>0;u=v?w>>>16:w;o=v?16:0;if((u&65280|0)==0){y=o;z=u}else{y=o|8;z=u>>>8}u=(d[1359664+z|0]|0)+y>>3;o=u+1|0;bD(l,u+129|0);if((o|0)==0){break}else{A=o}do{A=A-1|0;o=zrc(p|0,t|0,A<<3|0)|0;bD(l,o&255);}while((A|0)!=0)}}while(0);tD(l,1);tD(l,2);lD(l,512);sD(l,m,n);do{if((grc(g,1900672,16)|0)==0){n=c[j+60>>2]|0;if(!(n>>>0>1>>>0)){q=24;break}m=(c[j+56>>2]|0)+(n-2<<3)|0;sD(l,c[m>>2]|0,c[m+4>>2]|0)}else{q=24}}while(0);a:do{if((q|0)==24){do{if((grc(g,1211816,16)|0)==0){m=c[j+60>>2]|0;if((m|0)==0){break}n=(c[j+56>>2]|0)+(m-1<<3)|0;sD(l,c[n>>2]|0,c[n+4>>2]|0);break a}}while(0);sD(l,0,0)}}while(0);g=j+8|0;sD(l,c[g>>2]|0,c[g+4>>2]|0);g=fD(l,0,0,1)|0;n=G;sD(l,0,0);sD(l,s,0);lD(l,(s|0)!=0?f:0);do{if((e|0)==0){q=32}else{if((c[j+36>>2]|0)==0){q=32;break}if((c[j+60>>2]|0)==0){q=32;break}f=j+112|0;sD(l,c[f>>2]|0,c[f+4>>2]|0)}}while(0);if((q|0)==32){sD(l,0,0)}lD(l,e);dD(l,774592,16);NP(b);if((h|0)!=0){h=fD(c[k>>2]|0,0,0,1)|0;e=xrc(512,0,h&511,G&0)|0;h=e;e=h>>>0<20>>>0?h+512|0:h&511;if((e|0)!=0){dD(c[k>>2]|0,1034768,16);h=e-20|0;e=c[k>>2]|0;bD(e,131);vD(e,h);cD(c[k>>2]|0,0,h)}h=fD(c[k>>2]|0,0,0,1)|0;e=G;q=c[k>>2]|0;dD(q,699584,16);j=((d[1359668]|0)+8|0)>>>3;bD(q,j+129|0);f=j+1|0;do{f=f-1|0;j=zrc(1250,0,f<<3|0)|0;bD(q,j&255);}while((f|0)!=0);lD(q,69);lD(q,18);f=0;do{tD(q,c[787384+(f*20|0)>>2]|0);dD(q,787388+(f*20|0)|0,16);f=f+1|0;}while((f|0)<69);f=c[i>>2]|0;q=c[k>>2]|0;dD(q,1142240,13);vD(q,77568);j=f+16|0;s=c[j>>2]|0;m=((s|0)>1)+s|0;s=m;A=wrc(s<<4|0>>>28,((m|0)<0|0?-1:0)<<4|s>>>28,130,0)|0;s=G;m=0;t=A;do{if(s>>>0<m>>>0|s>>>0==m>>>0&A>>>0<128>>>0){bD(q,t)}else{p=t>>>0>65535>>>0;y=p?t>>>16:t;z=p?16:0;if((y&65280|0)==0){B=z;C=y}else{B=z|8;C=y>>>8}y=(d[1359664+C|0]|0)+B>>3;z=y+1|0;bD(q,y+129|0);if((z|0)==0){break}else{D=z}do{D=D-1|0;z=zrc(A|0,s|0,D<<3|0)|0;bD(q,z&255);}while((D|0)!=0)}}while(0);tD(q,15370);tD(q,16);dD(q,282336,12);tD(q,10);tD(q,0);tD(q,15106);tD(q,8);D=f+40|0;sD(q,c[D>>2]|0,c[D+4>>2]|0);tD(q,15109);tD(q,2);tD(q,258);tD(q,15110);tD(q,24);lD(q,1);lD(q,16);dD(q,282336,12);tD(q,11);tD(q,0);tD(q,15107);tD(q,16);dD(q,282336,12);tD(q,12);tD(q,0);tD(q,15113);tD(q,16);dD(q,774592,16);D=c[j>>2]|0;tD(q,15114);tD(q,((D|0)>1)+D<<4|8);NP(b);tD(q,15115);tD(q,8);sD(q,0,0);q=c[i>>2]|0;D=c[k>>2]|0;dD(D,1142240,13);vD(D,77824);j=(c[(c[(c[c[b+28>>2]>>2]|0)+8>>2]|0)+88>>2]&8388608|0)!=0?2624032:2597592;f=((lrc(j|0)|0)<<1)+116|0;s=f;A=(f|0)<0|0?-1:0;do{if(f>>>0<128>>>0){bD(D,f)}else{B=f>>>0>65535>>>0;C=B?f>>>16:f;t=B?16:0;if((C&65280|0)==0){E=t;F=C}else{E=t|8;F=C>>>8}C=(d[1359664+F|0]|0)+E>>3;t=C+1|0;bD(D,C+129|0);if((t|0)==0){break}else{H=t}do{H=H-1|0;t=zrc(s|0,A|0,H<<3|0)|0;bD(D,t&255);}while((H|0)!=0)}}while(0);tD(D,15370);tD(D,16);dD(D,282336,12);tD(D,11);tD(D,0);tD(D,15369);tD(D,16);dD(D,282336,12);tD(D,11);tD(D,1);tD(D,15361);tD(D,12);tD(D,70);tD(D,70);tD(D,109);tD(D,112);tD(D,101);tD(D,103);tD(D,15362);tD(D,20);tD(D,79);tD(D,80);tD(D,49);tD(D,97);tD(D,32);tD(D,77);tD(D,117);tD(D,120);tD(D,101);tD(D,114);H=lrc(j|0)|0;tD(D,15364);tD(D,H<<1);if((H|0)>0){A=0;do{tD(D,a[j+A|0]|0);A=A+1|0;}while((A|0)<(H|0))}tD(D,15365);tD(D,16);dD(D,282336,12);tD(D,11);tD(D,2);tD(D,15366);tD(D,8);H=q+40|0;sD(D,c[H>>2]|0,c[H+4>>2]|0);H=c[k>>2]|0;dD(H,1142240,13);vD(H,71680);bD(H,92);tD(H,15370);tD(H,16);dD(H,282336,12);tD(H,12);tD(H,0);tD(H,6401);tD(H,40);lD(H,2);lD(H,16);dD(H,282336,12);tD(H,1);tD(H,0);dD(H,282336,12);tD(H,2);tD(H,0);tD(H,6402);tD(H,24);lD(H,1);lD(H,16);dD(H,282336,12);tD(H,15);tD(H,0);OP(b,1);OP(b,2);b=c[k>>2]|0;dD(b,1142240,13);vD(b,74496);bD(b,72);tD(b,15370);tD(b,16);dD(b,282336,12);tD(b,15);tD(b,0);tD(b,9985);tD(b,32);H=c[i>>2]|0;dD(c[k>>2]|0,284504,13);vD(c[k>>2]|0,c[H+120>>2]|0);dD(c[k>>2]|0,H+124|0,15);bD(c[k>>2]|0,1);tD(b,16135);tD(b,4);lD(b,1);tD(b,16134);tD(b,4);lD(b,2);b=fD(c[k>>2]|0,0,0,1)|0;k=G;H=xrc(b,k,h,e)|0;e=G;h=xrc(512,0,b&511,k&0)|0;i=h;h=wrc(H,e,i>>>0<20>>>0?i+512|0:i&511,0)|0;i=G;fD(l,g,n,0)|0;sD(l,h|0,i&0);fD(l,b,k,0)|0;}eD(l);x=0;return x|0}function MP(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;g=c[b+12>>2]|0;h=c[b+16>>2]|0;j=g+64|0;k=c[j>>2]|0;l=b;m=g+36|0;KIb(l,48,2215168,(n=i,i=i+8|0,c[n>>2]=c[m>>2],n)|0);i=n;o=g+108|0;do{if((c[m>>2]|0)==0){if((c[o>>2]|0)!=0){break}i=f;return}}while(0);dD(h,1072112,16);do{if((c[o>>2]|0)==0){p=Erc(c[b+24>>2]|0,0,6,0)|0;q=wrc(p,G,115,0)|0;p=G;r=c[m>>2]|0;s=d[g+48|0]|0;t=wrc(s<<2|0>>>30,0<<2|s>>>30,11,0)|0;s=Erc(t,G,r,0)|0;r=wrc(q,p,s,G)|0;s=G;p=0;q=r;if(s>>>0<p>>>0|s>>>0==p>>>0&r>>>0<128>>>0){bD(h,q);break}p=q>>>0>65535>>>0;t=p?q>>>16:q;q=p?16:0;if((t&65280|0)==0){u=q;v=t}else{u=q|8;v=t>>>8}t=(d[1359664+v|0]|0)+u>>3;q=t+1|0;bD(h,t+129|0);if((q|0)==0){break}else{w=q}do{w=w-1|0;q=zrc(r|0,s|0,w<<3|0)|0;bD(h,q&255);}while((w|0)!=0)}else{bD(h,80)}}while(0);tD(h,15370);tD(h,16);dD(h,282336,12);tD(h,14);tD(h,0);tD(h,16139);tD(h,8);lD(h,c[g+24>>2]|0);lD(h,c[g+20>>2]|0);tD(h,16140);tD(h,8);w=g+52|0;u=c[w>>2]|0;sD(h,u,(u|0)<0|0?-1:0);tD(h,16141);tD(h,8);if((c[o>>2]|0)==0){sD(h,c[m>>2]|0,0)}else{sD(h,0,0)}tD(h,16133);tD(h,4);lD(h,c[o>>2]|0);tD(h,16134);tD(h,4);lD(h,2);tD(h,16135);tD(h,4);lD(h,1);if((c[o>>2]|0)!=0){i=f;return}tD(h,16136);tD(h,1);o=g+48|0;bD(h,d[o]|0);u=b+24|0;v=((c[u>>2]|0)*6|0)+14|0;tD(h,16137);tD(h,v);lD(h,(c[u>>2]|0)+1|0);lD(h,6);bD(h,0);bD(h,0);lD(h,0);if((c[u>>2]|0)==0){x=0}else{v=b+28|0;b=0;s=0;while(1){r=c[(c[(c[v>>2]|0)+(s<<2)>>2]|0)+12>>2]|0;q=r+80|0;bD(h,c[q>>2]|0);t=(c[q>>2]|0)==0?b:1;if((s|0)==0){bD(h,0);lD(h,512)}else{q=ca(c[r+16>>2]|0,c[c[r+24>>2]>>2]|0)|0;r=512-(q&511)|0;bD(h,1);lD(h,ca((r>>>0<20>>>0?r+512|0:r&511)+q|0,s-1|0)|0)}q=s+1|0;if(q>>>0<(c[u>>2]|0)>>>0){b=t;s=q}else{x=t;break}}}s=(ca(((d[o]|0)<<2)+11|0,c[m>>2]|0)|0)+8|0;tD(h,16138);tD(h,s);lD(h,c[m>>2]|0);lD(h,((d[o]|0)<<2)+11|0);o=c[m>>2]|0;if((o|0)==0){y=k;z=0}else{s=g+32|0;g=(x|0)==0;x=k;k=0;b=o;while(1){o=c[s>>2]|0;if((a[o+(k*24|0)|0]&51)==0){c[j>>2]=x;A=k}else{A=x}do{if(g){B=0}else{v=k-A|0;if((v|0)==(e[o+(k*24|0)+20>>1]|0|0)){B=0;break}else{C=A}while(1){if(!(C>>>0<b>>>0)){break}if((v|0)==(e[o+(C*24|0)+20>>1]|0|0)){break}else{C=C+1|0}}if((C|0)==(b|0)){KIb(l,24,2182104,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}B=C-k|0}}while(0);bD(h,B);do{if((a[(c[s>>2]|0)+(k*24|0)|0]&48)==48){bD(h,(c[j>>2]|0)-k|0);D=c[s>>2]|0}else{bD(h,A-k|0);o=c[s>>2]|0;if((a[o+(k*24|0)|0]&32)==0){D=o;break}c[j>>2]=A;D=o}}while(0);o=D+(k*24|0)|0;v=a[o]|0;if((v&115)==64&(B|0)==0){a[o]=v|-128;E=a[(c[s>>2]|0)+(k*24|0)|0]|0}else{E=v}bD(h,E&255);v=(c[s>>2]|0)+(k*24|0)+8|0;sD(h,c[v>>2]|0,c[v+4>>2]|0);if((c[u>>2]|0)>>>0>1>>>0){lD(h,c[(c[s>>2]|0)+(k*24|0)+16>>2]|0)}v=k+1|0;o=c[m>>2]|0;if(v>>>0<o>>>0){x=A;k=v;b=o}else{y=A;z=o;break}}}c[j>>2]=y-z;c[w>>2]=(c[w>>2]|0)+z;c[m>>2]=0;i=f;return}function NP(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+16>>2]|0;e=(c[a+12>>2]|0)+16|0;f=c[e>>2]|0;lD(d,((f|0)>1)+f|0);lD(d,16);KIb(a,48,2573240,(f=i,i=i+8|0,c[f>>2]=c[e>>2],f)|0);i=f;if((c[e>>2]|0)<=0){i=b;return}f=a+28|0;a=0;do{dD(d,788992+((c[(c[(c[(c[f>>2]|0)+(a<<2)>>2]|0)+12>>2]|0)+56>>2]|0)*52|0)|0,16);a=a+1|0;g=c[e>>2]|0;}while((a|0)<(g|0));if((g|0)<=1){i=b;return}dD(d,792592,16);i=b;return}function OP(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;f=a+12|0;g=c[f>>2]|0;h=a+16|0;j=c[h>>2]|0;k=a+24|0;l=(c[k>>2]|0)+1|0;m=(b|0)==1;dD(j,1142240,13);do{if(m){vD(j,79360);n=(l<<4)+92|0;o=n;p=(n|0)<0|0?-1:0;if(n>>>0<128>>>0){bD(j,n);break}q=n>>>0>65535>>>0;r=q?n>>>16:n;n=q?16:0;if((r&65280|0)==0){s=n;t=r}else{s=n|8;t=r>>>8}r=(d[1359664+t|0]|0)+s>>3;n=r+1|0;bD(j,r+129|0);if((n|0)==0){break}else{u=n}do{u=u-1|0;n=zrc(o|0,p|0,u<<3|0)|0;bD(j,n&255);}while((u|0)!=0)}else{vD(j,79616);p=(l<<4)+112|0;o=p;n=(p|0)<0|0?-1:0;if(p>>>0<128>>>0){bD(j,p);break}r=p>>>0>65535>>>0;q=r?p>>>16:p;p=r?16:0;if((q&65280|0)==0){v=p;w=q}else{v=p|8;w=q>>>8}q=(d[1359664+w|0]|0)+v>>3;p=q+1|0;bD(j,q+129|0);if((p|0)==0){break}else{x=p}do{x=x-1|0;p=zrc(o|0,n|0,x<<3|0)|0;bD(j,p&255);}while((x|0)!=0)}}while(0);tD(j,15370);tD(j,16);dD(j,282336,12);tD(j,b);tD(j,0);KIb(a,48,2153704,(x=i,i=i+8|0,c[x>>2]=b,x)|0);i=x;tD(j,17409);tD(j,32);x=(b|0)==2;v=c[f>>2]|0;dD(c[h>>2]|0,284504,13);vD(c[h>>2]|0,c[v+120>>2]|0);dD(c[h>>2]|0,v+124|0,15);bD(c[h>>2]|0,x&1);tD(j,17413);tD(j,8);v=g+40|0;sD(j,c[v>>2]|0,c[v+4>>2]|0);tD(j,17412);tD(j,8);sD(j,c[v>>2]|0,c[v+4>>2]|0);tD(j,17411);tD(j,l<<4|8);lD(j,l);lD(j,16);l=m?8:24;dD(j,282336,12);tD(j,l);tD(j,-1);if((c[k>>2]|0)!=0){v=0;do{dD(j,282336,12);tD(j,l);tD(j,v);v=v+1|0;}while(v>>>0<(c[k>>2]|0)>>>0)}do{if(x){tD(j,18177);tD(j,16);v=(c[k>>2]|0)>>>0>1>>>0;dD(j,282336,12);if(!v){tD(j,13);tD(j,0);break}tD(j,6);tD(j,0);v=c[f>>2]|0;l=c[h>>2]|0;dD(l,1142240,13);vD(l,82944);w=c[k>>2]|0;u=wrc(w<<4|0>>>28,0<<4|w>>>28,64,0)|0;w=G;s=0;t=u;do{if(w>>>0<s>>>0|w>>>0==s>>>0&u>>>0<128>>>0){bD(l,t)}else{n=t>>>0>65535>>>0;o=n?t>>>16:t;p=n?16:0;if((o&65280|0)==0){y=p;z=o}else{y=p|8;z=o>>>8}o=(d[1359664+z|0]|0)+y>>3;p=o+1|0;bD(l,o+129|0);if((p|0)==0){break}else{A=p}do{A=A-1|0;p=zrc(u|0,w|0,A<<3|0)|0;bD(l,p&255);}while((A|0)!=0)}}while(0);tD(l,15370);tD(l,16);dD(l,282336,12);tD(l,6);tD(l,0);tD(l,12289);tD(l,8);lD(l,c[v+24>>2]|0);lD(l,c[v+20>>2]|0);tD(l,12292);tD(l,16);if((c[v+16>>2]|0)>1){B=792592}else{B=788992+((c[(c[(c[c[a+28>>2]>>2]|0)+12>>2]|0)+56>>2]|0)*52|0)|0}dD(l,B,16);w=c[k>>2]<<4|8;tD(l,16129);tD(l,w);lD(l,c[k>>2]|0);lD(l,16);if((c[k>>2]|0)==0){break}else{C=0}do{dD(l,282336,12);tD(l,13);tD(l,C);C=C+1|0;}while(C>>>0<(c[k>>2]|0)>>>0)}}while(0);C=g+100|0;PP(c[f>>2]|0,c[h>>2]|0,c[C>>2]|0,b);g=c[C>>2]|0;B=c[f>>2]|0;A=c[h>>2]|0;dD(A,1142240,13);vD(A,69376);bD(A,80);tD(A,15370);tD(A,16);y=m?5:21;z=g|0;j=c[z>>2]|0;dD(A,282336,12);tD(A,y);tD(A,j);YP(c[f>>2]|0,c[h>>2]|0,g);tD(A,4097);tD(A,24);lD(A,1);lD(A,16);j=(c[B+100>>2]|0)==(g|0)?4:3;g=c[z>>2]|0;dD(A,282336,12);tD(A,x?j|16:j);tD(A,g);g=c[C>>2]|0;C=c[f>>2]|0;A=c[h>>2]|0;dD(A,1142240,13);vD(A,70656);bD(A,75);tD(A,15370);tD(A,16);j=c[g>>2]|0;dD(A,282336,12);tD(A,m?4:20);tD(A,j);YP(c[f>>2]|0,c[h>>2]|0,g);tD(A,5377);tD(A,8);g=c[C+80>>2]|0;sD(A,g,(g|0)<0|0?-1:0);tD(A,5378);tD(A,2);tD(A,c[C+104>>2]|0);tD(A,5379);tD(A,1);bD(A,c[C+84>>2]&1);if((c[k>>2]|0)==0){i=e;return}C=a+28|0;A=m?3:19;if(x){x=0;do{m=c[(c[C>>2]|0)+(x<<2)>>2]|0;PP(c[f>>2]|0,c[h>>2]|0,m,2);g=c[f>>2]|0;j=c[h>>2]|0;dD(j,1142240,13);vD(j,69376);bD(j,80);tD(j,15370);tD(j,16);z=m|0;B=c[z>>2]|0;dD(j,282336,12);tD(j,y);tD(j,B);YP(c[f>>2]|0,c[h>>2]|0,m);tD(j,4097);tD(j,24);lD(j,1);lD(j,16);B=(c[g+100>>2]|0)==(m|0)?20:19;g=c[z>>2]|0;dD(j,282336,12);tD(j,B);tD(j,g);g=c[h>>2]|0;dD(g,1142240,13);vD(g,69888);bD(g,108);tD(g,15370);tD(g,16);j=c[z>>2]|0;dD(g,282336,12);tD(g,A);tD(g,j);YP(c[f>>2]|0,c[h>>2]|0,m);tD(g,4609);tD(g,8);sD(g,0,0);tD(g,4353);tD(g,32);sD(g,0,0);sD(g,0,0);sD(g,0,0);sD(g,0,0);tD(g,4354);tD(g,4);lD(g,0);re[c[789040+((c[(c[m+12>>2]|0)+56>>2]|0)*52|0)>>2]&1023](a,m);x=x+1|0;}while(x>>>0<(c[k>>2]|0)>>>0);i=e;return}else{x=0;do{a=c[(c[C>>2]|0)+(x<<2)>>2]|0;PP(c[f>>2]|0,c[h>>2]|0,a,b);m=c[f>>2]|0;g=c[h>>2]|0;dD(g,1142240,13);vD(g,69376);bD(g,80);tD(g,15370);tD(g,16);j=a|0;z=c[j>>2]|0;dD(g,282336,12);tD(g,y);tD(g,z);YP(c[f>>2]|0,c[h>>2]|0,a);tD(g,4097);tD(g,24);lD(g,1);lD(g,16);z=(c[m+100>>2]|0)==(a|0)?4:3;m=c[j>>2]|0;dD(g,282336,12);tD(g,z);tD(g,m);m=c[h>>2]|0;dD(m,1142240,13);vD(m,69888);bD(m,108);tD(m,15370);tD(m,16);g=c[j>>2]|0;dD(m,282336,12);tD(m,A);tD(m,g);YP(c[f>>2]|0,c[h>>2]|0,a);tD(m,4609);tD(m,8);sD(m,0,0);tD(m,4353);tD(m,32);a=c[f>>2]|0;dD(c[h>>2]|0,284504,13);vD(c[h>>2]|0,c[a+120>>2]|0);dD(c[h>>2]|0,a+124|0,15);bD(c[h>>2]|0,1);tD(m,4354);tD(m,4);lD(m,(c[j>>2]|0)+2|0);x=x+1|0;}while(x>>>0<(c[k>>2]|0)>>>0);i=e;return}}function PP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[d+12>>2]|0;dD(b,1142240,13);vD(b,80640);bD(b,80);tD(b,15370);tD(b,16);g=(e|0)==1;e=d|0;d=c[e>>2]|0;dD(b,282336,12);tD(b,g?8:24);tD(b,d);tD(b,18433);tD(b,4);lD(b,(c[e>>2]|0)+2|0);tD(b,18436);tD(b,4);if(g){lD(b,0)}else{dD(b,f+52|0,4)}tD(b,19201);tD(b,8);lD(b,c[a+24>>2]|0);lD(b,c[a+20>>2]|0);tD(b,19202);tD(b,8);sD(b,0,0);tD(b,18435);tD(b,16);a=c[e>>2]|0;dD(b,282336,12);tD(b,g?5:21);tD(b,a);return}function QP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+16>>2]|0;e=c[b+12>>2]|0;f=b+8|0;g=c[f>>2]|0;h=c[g+840>>2]<<4|c[g+844>>2];XP(a,b,786368,13);tD(d,32768);tD(d,4);lD(d,c[e+96>>2]|0);tD(d,32775);tD(d,1);bD(d,(c[(c[f>>2]|0)+840>>2]|0)==0?h|128:h);return}function RP(a,b){a=a|0;b=b|0;var d=0;d=c[a+16>>2]|0;VP(c[a+12>>2]|0,d,b,790912,14);tD(d,15626);tD(d,2);a=b+8|0;tD(d,c[(c[a>>2]|0)+432>>2]|0);tD(d,15625);tD(d,4);b=c[a>>2]|0;lD(d,ca(c[b+412>>2]|0,c[b+432>>2]|0)|0);return}function SP(a,b){a=a|0;b=b|0;var d=0;d=c[a+16>>2]|0;VP(c[a+12>>2]|0,d,b,785896,14);tD(d,15626);tD(d,2);a=b+8|0;tD(d,c[(c[a>>2]|0)+432>>2]|0);tD(d,15625);tD(d,4);b=c[a>>2]|0;lD(d,ca(c[b+412>>2]|0,c[b+432>>2]|0)|0);return}function TP(a,b){a=a|0;b=b|0;XP(a,b,790880,0);return}function UP(a,b){a=a|0;b=b|0;VP(c[a+12>>2]|0,c[a+16>>2]|0,b,788912,0);return}function VP(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;WP(a,b,d,e,f+33|0);tD(b,15618);tD(b,1);bD(b,1);tD(b,15619);tD(b,8);f=d+8|0;lD(b,c[(c[f>>2]|0)+412>>2]|0);lD(b,1);tD(b,15623);tD(b,4);lD(b,c[(c[f>>2]|0)+416>>2]|0);tD(b,15617);tD(b,4);lD(b,g5a(c[(c[f>>2]|0)+48>>2]|0)|0);return}function WP(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;g=c[d+12>>2]|0;dD(b,e,16);bD(b,131);vD(b,f+60|0);tD(b,15370);tD(b,16);f=d|0;d=c[f>>2]|0;dD(b,282336,12);tD(b,13);tD(b,d);tD(b,12294);tD(b,4);lD(b,(c[f>>2]|0)+2|0);tD(b,12289);tD(b,8);lD(b,c[a+24>>2]|0);lD(b,c[a+20>>2]|0);tD(b,12292);tD(b,16);dD(b,788992+((c[g+56>>2]|0)*52|0)|0,16);return}function XP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[b+12>>2]|0;g=c[a+16>>2]|0;h=b+8|0;i=(((c[(c[h>>2]|0)+124>>2]|0)+15|0)/16|0)<<4;j=f+68|0;k=c[j>>2]|0;l=e+69+(k<<2)|0;e=l+32|0;if((k|0)==0){m=e}else{m=(c[f+72>>2]|0)==0?e:l+37|0}WP(c[a+12>>2]|0,g,b,d,m);tD(g,12803);tD(g,4);lD(g,c[(c[h>>2]|0)+120>>2]|0);tD(g,12802);tD(g,4);lD(g,i>>c[j>>2]);tD(g,12809);tD(g,4);lD(g,c[(c[h>>2]|0)+120>>2]|0);i=c[(c[h>>2]|0)+124>>2]|0;if((i|0)==608){n=576}else if((i|0)==512){n=486}else{n=i}tD(g,12808);tD(g,4);lD(g,n>>c[j>>2]);tD(g,13057);tD(g,4);lD(g,c[f+76>>2]|0);tD(g,13058);tD(g,4);lD(g,2);tD(g,12812);tD(g,1);bD(g,c[j>>2]|0);n=c[h>>2]|0;switch(c[n+124>>2]|0){case 480:{o=(c[n+48>>2]|0)==25?285:283;p=20;break};case 1080:{o=584;p=21;break};case 608:{o=320;p=7;break};case 720:{o=0;p=26;break};case 576:{o=(c[n+48>>2]|0)==25?335:336;p=23;break};case 512:{o=270;p=7;break};default:{o=0;p=0}}n=c[j>>2]|0;h=(n|0)==0;tD(g,12813);tD(g,(n<<2)+12|0);lD(g,(c[j>>2]|0)!=0?2:1);lD(g,4);lD(g,p<<(h&1));if((c[j>>2]|0)!=0){lD(g,h?0:o)}tD(g,12814);tD(g,8);lD(g,c[f+84>>2]|0);lD(g,c[f+88>>2]|0);tD(g,12801);tD(g,16);dD(g,c[f+60>>2]|0,16);if((c[j>>2]|0)==0){return}j=f+72|0;if((c[j>>2]|0)==0){return}tD(g,12818);tD(g,1);bD(g,c[j>>2]|0);return}function YP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;tD(d,513);tD(d,16);if((c[b+100>>2]|0)==(e|0)){dD(d,563416,16)}else{f=c[(c[e+8>>2]|0)+8>>2]|0;e=1339168;while(1){g=e|0;if((a[g]|0)==0){break}if((c[e+20>>2]|0)==(f|0)){break}else{e=e+24|0}}dD(d,g,16)}tD(d,514);tD(d,8);g=b+72|0;sD(d,c[g>>2]|0,c[g+4>>2]|0);return}function ZP(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+12>>2]|0;d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}f=c[d+8>>2]|0;c[f+8>>2]=0;c[f+48>>2]=147;_X(d,64,1,1e6);d=ZX(a,0)|0;if((d|0)==0){e=-12;return e|0}a=c[d+8>>2]|0;c[a+8>>2]=1;c[a+48>>2]=65543;c[a+416>>2]=1;f=a+448|0;c[f>>2]=4;c[f+4>>2]=0;c[a+412>>2]=8e3;c[a+792>>2]=8;c[a+432>>2]=1;_X(d,64,1,1e6);d=b+16|0;mrc(b|0,0,16)|0;c[d>>2]=0;c[d+4>>2]=-2147483648;c[b+24>>2]=0;e=0;return e|0}function _P(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;f=i;g=b+12|0;h=c[g>>2]|0;j=b+16|0;if((jD(c[j>>2]|0)|0)!=0){k=-541478725;i=f;return k|0}l=h+24|0;m=h+4|0;n=h+16|0;o=h+8|0;p=b;a:while(1){if((c[(c[j>>2]|0)+76>>2]|0)!=0){k=-541478725;q=63;break}b=c[l>>2]|0;do{if(b>>>0<4>>>0){r=c[g>>2]|0;s=r+4|0;t=r;u=c[t>>2]|0;v=u;w=(c[s>>2]|0)-v|0;x=qc(w|0,1027)|0;if(G){k=-12;q=63;break a}y=r+8|0;z=(c[y>>2]|0)-v|0;v=wJb(u,r+12|0,x+16|0)|0;if((v|0)==0){k=-12;q=63;break a}c[t>>2]=v;c[s>>2]=v+w;if((c[y>>2]|0)!=0){c[y>>2]=v+z}z=r+24|0;r=c[z>>2]|0;y=AD(c[j>>2]|0,v+(r+w)|0,1027-r|0)|0;if((y|0)<0){k=y;q=63;break a}c[z>>2]=(c[z>>2]|0)+y;y=c[l>>2]|0;z=c[m>>2]|0;r=z+y|0;if(y>>>0>3>>>0){A=y;B=z;C=r;q=12;break}w=y-3|0;v=z+w|0;b:do{if((w|0)>0){s=z;while(1){t=s;x=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;if((x&-2139062144&-16843010-x|0)!=0){if((x&255)<<24>>24==-1){D=s;break b}x=s+1|0;if((a[x]|0)==-1){D=x;break b}x=s+2|0;if((a[x]|0)==-1){D=x;break b}x=s+3|0;if((a[x]|0)==-1){D=x;break b}}x=s+4|0;if(x>>>0<v>>>0){s=x}else{E=x;q=28;break}}}else{E=z;q=28}}while(0);c:do{if((q|0)==28){while(1){q=0;if(!(E>>>0<r>>>0)){D=r;break c}if((a[E]|0)==-1){D=E;break}else{E=E+1|0;q=28}}}}while(0);if(!(D>>>0<(z+(y-1)|0)>>>0)){k=-541478725;q=63;break a}if((a[D+1|0]|0)==-39){F=r;H=D;I=r;q=32}else{k=-541478725;q=63;break a}}else{v=c[m>>2]|0;A=b;B=v;C=v+b|0;q=12}}while(0);d:do{if((q|0)==12){q=0;b=B+(A-3)|0;v=A-6|0;w=B+v|0;if((v|0)>0){v=B;while(1){s=v;x=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;if((x&-2139062144&-16843010-x|0)!=0){if((x&255)<<24>>24==-1){F=b;H=v;I=C;q=32;break d}x=v+1|0;if((a[x]|0)==-1){F=b;H=x;I=C;q=32;break d}x=v+2|0;if((a[x]|0)==-1){F=b;H=x;I=C;q=32;break d}x=v+3|0;if((a[x]|0)==-1){F=b;H=x;I=C;q=32;break d}}x=v+4|0;if(x>>>0<w>>>0){v=x}else{J=x;break}}}else{J=B}while(1){if(!(J>>>0<b>>>0)){K=b;q=62;break d}if((a[J]|0)==-1){F=b;H=J;I=C;q=32;break}else{J=J+1|0}}}}while(0);do{if((q|0)==32){q=0;if((H|0)==(F|0)){K=H;q=62;break}b=a[H+1|0]|0;v=H+2|0;c[m>>2]=v;w=I-v|0;c[l>>2]=w;if((b<<24>>24|0)==(-40|0)){c[o>>2]=H;break}else if((b<<24>>24|0)==(-39|0)){if((c[o>>2]|0)!=0){q=38;break a}KIb(p,24,2385896,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}else{if(!((b+64&255)>>>0<16>>>0)){if((b&255)>>>0<218>>>0|b<<24>>24==-1){break}}r=v;y=he((d[r]|d[r+1|0]<<8)<<16>>16|0)|0;L=y&65535;if((y&65535)>>>0<2>>>0){k=-22;q=63;break a}if(w>>>0<L>>>0){r=c[g>>2]|0;z=r+4|0;x=r;s=c[x>>2]|0;t=s;u=(c[z>>2]|0)-t|0;M=qc(u|0,L|0)|0;if(G){k=-12;q=63;break a}N=r+8|0;O=(c[N>>2]|0)-t|0;t=wJb(s,r+12|0,M+16|0)|0;if((t|0)==0){k=-12;q=63;break a}c[x>>2]=t;c[z>>2]=t+u;if((c[N>>2]|0)!=0){c[N>>2]=t+O}O=r+24|0;r=c[O>>2]|0;N=AD(c[j>>2]|0,t+(r+u)|0,L-r|0)|0;if((N|0)<0){k=N;q=63;break a}c[O>>2]=(c[O>>2]|0)+N;N=c[m>>2]|0;P=N-2|0;Q=0;R=N}else{P=H;Q=w-L|0;R=v}c[l>>2]=Q;c[m>>2]=R+L;if(b<<24>>24==-19&(y&65535)>>>0>15>>>0){q=55;break a}if(!(b<<24>>24==-2&(y&65535)>>>0>17>>>0)){break}if((krc(P+4|0,2315112,3)|0)!=0){break}y=P+12|0;b=y|0;v=y+4|0;y=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[n>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[n+4>>2]=y;break}}}while(0);if((q|0)==62){q=0;c[m>>2]=K;c[l>>2]=3}if((jD(c[j>>2]|0)|0)!=0){k=-541478725;q=63;break}}if((q|0)==38){j=c[n>>2]|0;K=c[n+4>>2]|0;n=e+16|0;c[n>>2]=j;c[n+4>>2]=K;n=e+8|0;c[n>>2]=j;c[n+4>>2]=K;c[e+32>>2]=0;c[e+52>>2]=0;c[e>>2]=0;K=c[o>>2]|0;n=(c[m>>2]|0)-K|0;j=e+28|0;c[j>>2]=n;c[e+24>>2]=K;K=h;R=c[K>>2]|0;Q=c[l>>2]|0;if(((c[o>>2]|0)-R|0)>>>0>Q>>>0){if((Q|0)==0){S=R;T=n}else{nrc(R|0,c[m>>2]|0,Q)|0;S=c[K>>2]|0;T=c[j>>2]|0}c[m>>2]=S;U=T}else{U=n}c[o>>2]=0;k=U;i=f;return k|0}else if((q|0)==55){U=P+8|0;o=U|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=U+4|0;U=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;c[o>>2]=n;c[o+4>>2]=U;o=e+8|0;c[o>>2]=n;c[o+4>>2]=U;c[e+32>>2]=1;c[e+52>>2]=0;c[e>>2]=0;U=L-14|0;L=e+28|0;c[L>>2]=U;c[e+24>>2]=P+16;e=h;h=c[e>>2]|0;o=c[l>>2]|0;if(!((P-h|0)>>>0>o>>>0)){k=U;i=f;return k|0}if((o|0)==0){V=h;W=U}else{nrc(h|0,c[m>>2]|0,o)|0;V=c[e>>2]|0;W=c[L>>2]|0}c[m>>2]=V;k=W;i=f;return k|0}else if((q|0)==63){i=f;return k|0}return 0}function $P(a){a=a|0;mJb(c[a+12>>2]|0);return 0}function aQ(a){a=a|0;var b=0,e=0,f=0,g=0;b=c[a+4>>2]|0;e=b;if(!((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==-1526661120)){f=0;return f|0}e=b+5|0;g=(d[e]|d[e+1|0]<<8)<<16>>16&65535;if((g+20|0)>(c[a+8>>2]|0)){f=25;return f|0}a=b+(g+16)|0;f=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==-1526661120?100:0;return f|0}function bQ(a){a=a|0;var b=0,d=0;b=ZX(a,0)|0;if((b|0)==0){d=-12;return d|0}a=c[b+8>>2]|0;c[a+8>>2]=0;c[a+48>>2]=13;c[b+236>>2]=1;_X(b,64,1,100);d=0;return d|0}function cQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a+16|0;f=-1;g=c[e>>2]|0;do{if((jD(g)|0)!=0){h=-5;j=10;break}f=(zD(c[e>>2]|0)|0)+(f<<8)|0;g=c[e>>2]|0}while((f|0)!=421);if((j|0)==10){i=d;return h|0}zD(g)|0;g=DD(c[e>>2]|0)|0;hD(c[e>>2]|0,9,0)|0;if((g|0)==0){KIb(a,48,2315080,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;h=-11;i=d;return h|0}a=fX(c[e>>2]|0,b,g)|0;if((a|0)==(g|0)){c[b+32>>2]=0;h=g;i=d;return h|0}if((a|0)<=0){h=-5;i=d;return h|0}P1(b);h=-5;i=d;return h|0}function dQ(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;a=b|0;e=b+4|0;return((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)==1414744398&(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==172044639?100:0)|0}function eQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+176|0;d=b+96|0;e=b+104|0;f=b+32|0;nrc(f|0,785240,32)|0;g=b+64|0;nrc(g|0,785208,32)|0;c[d>>2]=0;c[e>>2]=-1;h=ZX(a,0)|0;if((h|0)==0){j=-12;i=b;return j|0}k=h+8|0;c[(c[k>>2]|0)+8>>2]=1;l=a+16|0;m=b|0;KD(c[l>>2]|0,m,32)|0;KD(c[l>>2]|0,m,32)|0;Bd(m|0,2315072,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;if((c[e>>2]|0)<1){j=-1094995529;i=b;return j|0}if((jD(c[l>>2]|0)|0)!=0){j=-541478725;i=b;return j|0}o=h+56|0;p=b+112|0;q=b+144|0;r=a+1140|0;s=a;a=0;a:while(1){KD(c[l>>2]|0,m,32)|0;t=fD(c[l>>2]|0,0,0,1)|0;u=G;v=c[e>>2]|0;w=(v|0)<0|0?-1:0;if(!((u|0)<(w|0)|(u|0)==(w|0)&t>>>0<v>>>0)){j=-1094995529;x=40;break}if((grc(m,2262232,8)|0)==0){x=7;break}do{if((grc(m,2624008,13)|0)==0){Bd(m|0,2597456,(n=i,i=i+8|0,c[n>>2]=(c[k>>2]|0)+416,n)|0)|0;i=n;y=a}else{if((grc(m,2573216,18)|0)==0){Bd(m|0,2554792,(n=i,i=i+8|0,c[n>>2]=g,n)|0)|0;i=n;if((IFb(g,2536904)|0)==0){y=0;break}if((IFb(g,2520856)|0)==0){y=1;break}if((IFb(g,2506464)|0)==0){y=a;break}else{x=26;break a}}if((grc(m,2482272,13)|0)==0){Bd(m|0,2554792,(n=i,i=i+8|0,c[n>>2]=f,n)|0)|0;i=n;y=a;break}if((grc(m,2471080,12)|0)==0){Bd(m|0,2463216,(n=i,i=i+8|0,c[n>>2]=o,n)|0)|0;i=n;y=a;break}if((grc(m,2448016,14)|0)==0){Bd(m|0,2597456,(n=i,i=i+8|0,c[n>>2]=d,n)|0)|0;i=n;y=a;break}if((grc(m,2432824,11)|0)==0){Bd(m|0,2597456,(n=i,i=i+8|0,c[n>>2]=(c[k>>2]|0)+412,n)|0)|0;i=n;y=a;break}if((grc(m,2424072,15)|0)==0){Bd(m|0,2597456,(n=i,i=i+8|0,c[n>>2]=(c[k>>2]|0)+792,n)|0)|0;i=n;y=a;break}v=Bd(m|0,2413224,(n=i,i=i+16|0,c[n>>2]=p,c[n+8>>2]=q,n)|0)|0;i=n;if((v|0)==3){MGb(r,p,q,32)|0;y=a;break}else{KIb(s,16,2405568,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;y=a;break}}}while(0);if((jD(c[l>>2]|0)|0)==0){a=y}else{j=-541478725;x=40;break}}if((x|0)==7){y=(c[k>>2]|0)+792|0;if((c[y>>2]|0)==0){c[y>>2]=c[d>>2]<<3}b:do{if((IFb(f,2215152)|0)==0){d=KX(c[(c[k>>2]|0)+792>>2]|0,0,a,65535)|0;y=c[k>>2]|0;c[y+48>>2]=d;z=y}else{if((IFb(f,2182096)|0)==0){y=c[k>>2]|0;c[y+48>>2]=65543;z=y;break}do{if((IFb(f,2153696)|0)!=0){if((IFb(f,2129048)|0)==0){break}QIb(s,2105976,(n=i,i=i+8|0,c[n>>2]=f,n)|0);i=n;z=c[k>>2]|0;break b}}while(0);y=c[k>>2]|0;c[y+48>>2]=65542;z=y}}while(0);_X(h,64,1,c[z+412>>2]|0);z=c[k>>2]|0;c[z+432>>2]=(ca(c[z+416>>2]|0,c[z+792>>2]|0)|0)/8|0;z=fD(c[l>>2]|0,0,0,1)|0;k=G;h=c[e>>2]|0;e=h;f=(h|0)<0|0?-1:0;if((k|0)>(f|0)|(k|0)==(f|0)&z>>>0>e>>>0){j=-1094995529;i=b;return j|0}z=c[l>>2]|0;l=fD(z,0,0,1)|0;k=xrc(e,f,l,G)|0;hD(z,k,G)|0;j=0;i=b;return j|0}else if((x|0)==26){QIb(s,2492152,(n=i,i=i+8|0,c[n>>2]=g,n)|0);i=n;j=-1163346256;i=b;return j|0}else if((x|0)==40){i=b;return j|0}return 0}function fQ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[b+4>>2]|0;do{if((a[e]|0)==78){if((a[e+1|0]|0)!=83){break}if((a[e+2|0]|0)!=86){break}f=a[e+3|0]|0;if((f<<24>>24|0)==102|(f<<24>>24|0)==115){g=100}else{break}return g|0}}while(0);f=c[b+8>>2]|0;h=f-3|0;a:do{if((h|0)>1){i=0;j=1;b:while(1){k=e+j|0;do{if((d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)==1935037262){l=e+(j+22)|0;m=j+24+((d[l]|d[l+1|0]<<8)<<16>>16&65535)+((d[e+(j+20)|0]<<8|d[e+(j+21)|0]<<16|d[e+(j+19)|0])>>>4)|0;if((m|0)>(f-2|0)){n=20;break}l=e+m|0;if((d[l]|d[l+1|0]<<8)<<16>>16<<16>>16==-16657){g=80;break b}else{n=20}}else{n=i}}while(0);k=j+1|0;if((k|0)<(h|0)){i=n;j=k}else{o=n;break a}}return g|0}else{o=0}}while(0);n=(fH(c[b>>2]|0,2133216)|0)==0;g=n?o:50;return g|0}function gQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b+12|0;e=c[d>>2]|0;f=e+16|0;c[f>>2]=0;c[e+128>>2]=0;c[e+48>>2]=0;e=b+16|0;g=b+1140|0;h=0;a:while(1){if((h|0)>=300){break}i=c[d>>2]|0;j=c[e>>2]|0;k=0;l=0;while(1){if((jD(j)|0)!=0){m=5;break a}n=zD(j)|0|k;if((n&65535|0)==61374){m=7;break}if((n|0)==1314084467){m=10;break}else if((n|0)==1314084454){m=9;break}o=l+1|0;if((o|0)<512e3){k=n<<8;l=o}else{p=-1;m=39;break a}}if((m|0)==7){m=0;c[i+16>>2]=5}else if((m|0)==9){m=0;c[i+16>>2]=1}else if((m|0)==10){m=0;c[i+16>>2]=3}l=c[f>>2]|0;if((l|0)==1){k=c[d>>2]|0;j=c[e>>2]|0;o=k+16|0;c[o>>2]=0;n=FD(j)|0;if(n>>>0<28>>>0){p=-1;m=39;break}c[k+4>>2]=n;FD(j)|0;q=k+184|0;c[q>>2]=FD(j)|0;c[q+4>>2]=0;q=FD(j)|0;r=FD(j)|0;s=FD(j)|0;if((jD(j)|0)!=0){p=-1;m=39;break}if((q|0)>0){t=pJb(q+1|0)|0;if((t|0)==0){p=-12;m=39;break}u=t+q|0;AD(j,t,q)|0;v=t+(q-2)|0;q=t;while(1){if((a[q]|0)==32){q=q+1|0;continue}if(!(q>>>0<v>>>0)){break}w=_b(q|0,61)|0;if(!((w|0)!=0&w>>>0<v>>>0)){break}a[w]=0;x=w+2|0;y=_b(x|0,a[w+1|0]|0)|0;if(!((y|0)!=0&y>>>0<u>>>0)){break}w=y+1|0;a[y]=0;MGb(g,q,x,0)|0;if(w>>>0<u>>>0){q=w}else{break}}kJb(t)}if((jD(j)|0)!=0){p=-1;m=39;break}do{if((s|0)>0){c[k+12>>2]=s;if(s>>>0>1073741822>>>0){p=-1;m=39;break a}q=s<<2;u=hJb(q)|0;v=k+8|0;c[v>>2]=u;if((u|0)==0){p=-12;m=39;break a}else{z=0}do{u=(FD(j)|0)+n|0;c[(c[v>>2]|0)+(z<<2)>>2]=u;z=z+1|0;}while((z|0)<(s|0));if((r|0)<=(s|0)){break}if((FD(j)|0)!=843272020){break}v=hJb(q)|0;u=k+216|0;c[u>>2]=v;if((v|0)==0){p=-12;m=39;break a}else{A=0}do{v=FD(j)|0;c[(c[u>>2]|0)+(A<<2)>>2]=v;A=A+1|0;}while((A|0)<(s|0))}}while(0);fD(j,(c[k>>2]|0)+n|0,0,0)|0;if((jD(j)|0)!=0){p=-1;m=39;break}c[o>>2]=2;B=c[f>>2]|0}else{B=l}if((B|0)==3){m=36;break}else{h=h+1|0}}do{if((m|0)==5){c[i+16>>2]=0;p=-1;return p|0}else if((m|0)==36){h=lQ(b)|0;if((h|0)<0){p=h}else{break}return p|0}else if((m|0)==39){return p|0}}while(0);if((c[b+24>>2]|0)==0){p=-1;return p|0}p=kQ(b,1)|0;return p|0}function hQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[a+12>>2]|0;e=d+24|0;do{if((c[d+48>>2]|0)==0){if((c[d+128>>2]|0)!=0){f=0;break}g=kQ(a,0)|0;if((g|0)<0){h=g}else{f=0;break}return h|0}else{f=0}}while(0);while(1){if((f|0)>=2){h=-1;i=7;break}j=e+(f*80|0)+24|0;if((c[j>>2]|0)==0){f=f+1|0}else{break}}if((i|0)==7){return h|0}nrc(b|0,e+(f*80|0)|0,80)|0;c[j>>2]=0;h=c[b+28>>2]|0;return h|0}function iQ(a){a=a|0;var b=0;b=c[a+12>>2]|0;mJb(b+8|0);mJb(b+216|0);if((c[b+48>>2]|0)!=0){P1(b+24|0)}if((c[b+128>>2]|0)==0){return 0}P1(b+104|0);return 0}function jQ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[a+12>>2]|0;h=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=c[h+12>>2]|0;i=CX(h,d,e,f)|0;if((i|0)<0){j=-1;return j|0}f=h+400|0;h=(c[f>>2]|0)+(i*24|0)|0;e=fD(c[a+16>>2]|0,c[h>>2]|0,c[h+4>>2]|0,0)|0;h=G;a=0;if((h|0)<(a|0)|(h|0)==(a|0)&e>>>0<0>>>0){j=-1;return j|0}c[b>>2]=c[(c[f>>2]|0)+(i*24|0)+8>>2];c[g+16>>2]=0;j=0;return j|0}function kQ(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;e=i;i=i+8|0;f=e|0;g=f;h=a+12|0;j=c[h>>2]|0;k=a+16|0;l=c[k>>2]|0;c[f>>2]=0;c[f+4>>2]=0;m=j+24|0;if((c[j+48>>2]|0)!=0){n=0;i=e;return n|0}o=j+104|0;if((c[j+128>>2]|0)!=0){n=0;i=e;return n|0}if((jD(l)|0)!=0){n=-1;i=e;return n|0}p=j+16|0;q=0;r=0;while(1){if((c[p>>2]|0)>>>0<3>>>0&(r|0)==0){s=c[h>>2]|0;t=c[k>>2]|0;u=0;v=0;while(1){if((jD(t)|0)!=0){w=8;break}x=zD(t)|0|u;if((x&65535|0)==61374){w=10;break}if((x|0)==1314084454){w=12;break}else if((x|0)==1314084467){w=13;break}y=v+1|0;if((y|0)<512e3){u=x<<8;v=y}else{z=-1;break}}if((w|0)==8){w=0;c[s+16>>2]=0;z=-1}else if((w|0)==10){w=0;c[s+16>>2]=5;z=0}else if((w|0)==12){w=0;c[s+16>>2]=1;z=0}else if((w|0)==13){w=0;c[s+16>>2]=3;z=0}v=q+1|0;if((v|0)<300){q=v;r=z;continue}else{A=z}}else{A=r}if((A|0)<0){n=A;w=48;break}if((c[p>>2]|0)==3){B=lQ(a)|0}else{B=A}if((B|0)<0){n=B;w=48;break}if(!(((c[p>>2]|0)-4|0)>>>0<2>>>0)){n=-1;w=48;break}v=zD(l)|0;u=DD(l)|0;C=DD(l)|0;D=C&65535;t=u<<4|v>>>4&15;u=v&15;if((u|0)==0){E=t}else{v=0;y=t;while(1){t=DD(l)|0;FD(l)|0;x=t&65535;hD(l,x,0)|0;t=y-6-x|0;x=v+1|0;if((x|0)<(u|0)){v=x;y=t}else{E=t;break}}}if((jD(l)|0)!=0){n=-1;w=48;break}F=(E|0)!=0;if(!(D<<16>>16==0&(F^1))){w=26;break}c[p>>2]=0;if((jD(l)|0)==0){q=0;r=B}else{n=-1;w=48;break}}if((w|0)==26){B=c[a+24>>2]|0;do{if((B|0)!=0){r=c[a+28>>2]|0;q=c[r>>2]|0;c[g+(c[q+4>>2]<<2)>>2]=q;if(!(B>>>0>1>>>0)){break}q=c[r+4>>2]|0;c[g+(c[q+4>>2]<<2)>>2]=q}}while(0);B=c[f>>2]|0;f=(B|0)==0;do{if(F){if(f){H=0;I=1;break}q=c[B+12>>2]|0;fX(l,m,E)|0;c[j+56>>2]=c[B>>2];r=c[q>>2]|0;q=j+40|0;c[q>>2]=r;c[q+4>>2]=(r|0)<0|0?-1:0;r=j+60|0;c[r>>2]=(c[p>>2]|0)==4|c[r>>2];w=33}else{if(f){H=0;I=1}else{w=33}}}while(0);if((w|0)==33){f=c[B+12>>2]|0;c[f>>2]=(c[f>>2]|0)+1;H=B;I=0}do{if((C&65535|0)!=0){B=c[g+4>>2]|0;if((B|0)==0){break}f=c[B+12>>2]|0;E=B+8|0;do{if((c[(c[E>>2]|0)+52>>2]|0)==541934416){m=zD(l)|0;F=zD(l)|0;r=DD(l)|0;q=C+65532&65535;if((d|0)==0){J=q;break}c[B+236>>2]=0;if((F&255)<<24>>24==0){KIb(a,24,2385688,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;K=m&255}else{K=(((m&255)>>>0)/((F&255)>>>0)|0)&255}F=c[E>>2]|0;if(K<<24>>24==8){c[F+48>>2]=65541}c[F+416>>2]=1;c[F+412>>2]=r>>>2&16383;J=q}else{J=D}}while(0);fX(l,o,J&65535)|0;c[j+136>>2]=c[B>>2];E=(c[p>>2]|0)==4;q=j+140|0;c[q>>2]=E&1|c[q>>2];if(!(I|E^1)){E=(c[c[H+12>>2]>>2]|0)-1|0;q=j+120|0;r=c[j+212>>2]|0;F=Erc(r,(r|0)<0|0?-1:0,1e3,0)|0;r=Erc(F,G,E,(E|0)<0|0?-1:0)|0;E=G;F=b[j+204>>1]|0;m=c[j+208>>2]|0;A=Erc(m,(m|0)<0|0?-1:0,F<<16>>16,F<<16>>16<0|0?-1:0)|0;F=wrc(A,G,r,E)|0;c[q>>2]=F;c[q+4>>2]=G}q=f;c[q>>2]=(c[q>>2]|0)+1}}while(0);c[p>>2]=0;n=0;i=e;return n|0}else if((w|0)==48){i=e;return n|0}return 0}function lQ(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[a+12>>2]|0;e=c[a+16>>2]|0;f=FD(e)|0;g=FD(e)|0;h=DD(e)|0;i=h&65535;j=DD(e)|0;k=zD(e)|0;do{if((k&128|0)==0){l=1;m=k}else{n=k>>>2&31;o=n>>>0<16>>>0;p=o?1:n-15|0;q=o?n+1|0:1;if((k&1|0)==0){r=q;s=p}else{r=q*1001|0;s=p*1e3|0}p=k&3;if((p|0)==3){l=r;m=s*24|0;break}else if((p|0)==2){l=r;m=s*25|0;break}else{l=r;m=s*30|0;break}}}while(0);b[d+204>>1]=DD(e)|0;c[d+208>>2]=m;c[d+212>>2]=l;a:do{if((c[a+24>>2]|0)==0){c[d+192>>2]=f;c[d+196>>2]=g;b[d+200>>1]=i;b[d+202>>1]=i;do{if((f|0)==1162760014){t=18}else{e=ZX(a,0)|0;if((e|0)==0){break}c[e+4>>2]=0;s=pJb(28)|0;if((s|0)==0){break}c[e+12>>2]=s;s=e+8|0;r=c[s>>2]|0;c[r+8>>2]=0;c[r+52>>2]=f;r=JX(778104,f)|0;k=c[s>>2]|0;c[k+48>>2]=r;c[k+120>>2]=h&65535;c[k+124>>2]=j&65535;c[k+792>>2]=24;_X(e,64,l,m);k=e+48|0;c[k>>2]=0;c[k+4>>2]=0;k=d+184|0;r=m;s=(m|0)<0|0?-1:0;p=l*1e3|0;q=p;n=(p|0)<0|0?-1:0;p=VIb(c[k>>2]|0,c[k+4>>2]|0,r,s,q,n)|0;o=e+56|0;c[o>>2]=p;c[o+4>>2]=G;o=d+12|0;p=c[o>>2]|0;if((p|0)<=0){t=18;break}u=d+216|0;v=d+8|0;w=0;x=p;while(1){p=c[u>>2]|0;if((p|0)==0){y=Erc(c[k>>2]|0,c[k+4>>2]|0,w,(w|0)<0|0?-1:0)|0;z=Crc(y,G,x,(x|0)<0|0?-1:0)|0;y=VIb(z,G,r,s,q,n)|0;xX(e,c[(c[v>>2]|0)+(w<<2)>>2]|0,0,y,G,0,0,1)|0}else{xX(e,c[(c[v>>2]|0)+(w<<2)>>2]|0,0,c[p+(w<<2)>>2]|0,0,0,0,1)|0}p=w+1|0;y=c[o>>2]|0;if((p|0)<(y|0)){w=p;x=y}else{t=18;break}}}}while(0);do{if((t|0)==18){if((g|0)==1162760014){break a}x=ZX(a,0)|0;if((x|0)==0){break}c[x+4>>2]=1;w=pJb(28)|0;if((w|0)==0){break}c[x+12>>2]=w;w=x+8|0;o=c[w>>2]|0;c[o+8>>2]=1;c[o+52>>2]=g;o=JX(778208,g)|0;c[(c[w>>2]|0)+48>>2]=o;c[x+236>>2]=1;_X(x,64,1,m*1e3|0);o=x+48|0;c[o>>2]=0;c[o+4>>2]=0;o=d+184|0;w=Erc(c[o>>2]|0,c[o+4>>2]|0,m,(m|0)<0|0?-1:0)|0;o=x+56|0;c[o>>2]=w;c[o+4>>2]=G;break a}}while(0);c[d+16>>2]=0;A=-1;return A|0}}while(0);c[d+16>>2]=4;A=0;return A|0}function mQ(a,b){a=a|0;b=b|0;return 0}function nQ(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+8>>2]|0;if((b|0)<=0){e=0;return e|0}f=c[a+4>>2]|0;a=0;g=0;h=0;while(1){i=d[f+a|0]|0|h;j=g|0;if((i|0)==526320813&(j|0)==1313700438){e=100;k=5;break}l=a+1|0;if((l|0)<(b|0)){a=l;g=j<<8|i>>>24;h=i<<8|0>>>24}else{e=0;k=5;break}}if((k|0)==5){return e|0}return 0}function oQ(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+32|0;l=c[e+12>>2]|0;m=l;n=c[e+16>>2]|0;o=l;c[o>>2]=e;p=l+3780|0;q=l+3784|0;r=l+3736|0;s=l+3740|0;t=l+3756|0;u=l+940|0;v=l+3752|0;w=l+3076|0;x=l+3728|0;y=0;z=0;a:while(1){A=-1;if((y|0)>(A|0)|(y|0)==(A|0)&z>>>0>-1>>>0){fD(n,z,y,0)|0;}if((jD(n)|0)==0){B=0;C=0}else{D=9;break}while(1){A=zD(n)|0;E=A|(C<<8|0>>>24);F=((A|0)<0|0?-1:0)|(B<<8|C>>>24);if((E&0|0)==0&(F&-16777216|0)==1308622848){A=526320813;H=1313700438;if((E|0)==(-1248413064|0)&(F|0)==1313450856|(E|0)==(-288733847|0)&(F|0)==1313596589|(E|0)==1542650331&(F|0)==1314066752|(E|0)==790881870&(F|0)==1314446695){y=-1;z=-1;continue a}else if((E|0)==(A|0)&(F|0)==(H|0)){break}}if((jD(n)|0)==0){B=F;C=E}else{D=9;break a}}E=fD(n,0,0,1)|0;F=G;H=wrc(E,F,-8,-1)|0;A=G;I=0;if((A|0)<(I|0)|(A|0)==(I|0)&H>>>0<0>>>0){D=9;break}H=wrc(E,F,-7,-1)|0;F=G;J=c[o>>2]|0;E=c[J+16>>2]|0;I=uQ(E,1,526320813,1313700438)|0;A=fD(E,0,0,1)|0;K=wrc(I,(I|0)<0|0?-1:0,A,G)|0;A=G;I=PD(E)|0;L=I;c[p>>2]=L;if((L|0)>3){L=PD(E)|0;c[q>>2]=L}L=PD(E)|0;I=G;M=0;if(!(((L|0)!=0|(I|0)!=0)&(I>>>0<M>>>0|I>>>0==M>>>0&L>>>0<257>>>0))){KIb(J,16,2158720,(N=i,i=i+16|0,c[N>>2]=L,c[N+8>>2]=I,N)|0);i=N;y=F;z=H;continue}O=L;L=PD(E)|0;I=L;c[r>>2]=I;if(I>>>0>65536>>>0){KIb(J,48,2156736,(N=i,i=i+8|0,c[N>>2]=I,N)|0);i=N;c[r>>2]=65536}I=PD(E)|0;L=G;M=0;if(!(((I|0)!=0|(L|0)!=0)&(L>>>0<M>>>0|L>>>0==M>>>0&I>>>0<268435455>>>0))){KIb(J,16,2155120,(N=i,i=i+16|0,c[N>>2]=I,c[N+8>>2]=L,N)|0);i=N;y=F;z=H;continue}L=I;c[s>>2]=L;I=hJb(L<<3)|0;c[t>>2]=I;if((I|0)==0){y=F;z=H;continue}else{P=0}while(1){if(!(P>>>0<(c[s>>2]|0)>>>0)){Q=0;R=0;S=1;T=0;U=0;D=27;break}V=PD(E)|0;W=G;I=0;if(!(((V|0)!=0|(W|0)!=0)&(W>>>0<I>>>0|W>>>0==I>>>0&V>>>0<-2147483648>>>0))){D=21;break}c[(c[t>>2]|0)+(P<<3)>>2]=V;X=PD(E)|0;Y=G;I=0;if(!(((X|0)!=0|(Y|0)!=0)&(Y>>>0<I>>>0|Y>>>0==I>>>0&X>>>0<-2147483648>>>0))){D=23;break}I=X;L=c[t>>2]|0;c[L+(P<<3)+4>>2]=I;M=c[L+(P<<3)>>2]|0;L=TIb(M,(M|0)<0|0?-1:0,I,(I|0)<0|0?-1:0)|0;if((L|0)==1&(G|0)==0){P=P+1|0}else{D=25;break}}if((D|0)==21){D=0;KIb(J,16,2153320,(N=i,i=i+16|0,c[N>>2]=V,c[N+8>>2]=W,N)|0);i=N;y=F;z=H;continue}else if((D|0)==23){D=0;KIb(J,16,2151688,(N=i,i=i+16|0,c[N>>2]=X,c[N+8>>2]=Y,N)|0);i=N;y=F;z=H;continue}else if((D|0)==25){D=0;KIb(J,16,2149544,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;y=F;z=H;continue}else if((D|0)==27){while(1){D=0;L=PD(E)|0;I=PD(E)|0;M=I;do{if((M|0)>0){I=PD(E)|0;Z=wrc(I,G,1,0)|0;I=G;_=(Z&1|0)==0&(I&0|0)==0;$=Z>>>1|I<<31;Z=I>>1|((I|0)<0|0?-1:0)<<31;I=xrc(0,0,$,Z)|0;aa=G;ba=_?$:I;_?Z:aa;aa=ba&65535;if((M|0)<=1){ca=0;da=S;ea=aa;fa=R;ga=0;D=34;break}ba=PD(E)|0;Z=ba;if((M|0)<=2){ca=0;da=Z;ea=aa;fa=R;ga=0;D=34;break}ba=PD(E)|0;_=ba;if((M|0)<=3){ca=0;da=Z;ea=aa;fa=_;ga=0;D=34;break}ba=PD(E)|0;I=ba;if((M|0)<=4){ca=I;da=Z;ea=aa;fa=_;ga=0;D=34;break}ba=PD(E)|0;$=ba&255;if((M|0)<=5){ca=I;da=Z;ea=aa;fa=_;ga=$;D=34;break}ba=PD(E)|0;ha=ba;ia=I;ja=Z;ka=aa;la=_;ma=$}else{ca=0;da=S;ea=T;fa=R;ga=0;D=34}}while(0);if((D|0)==34){D=0;ha=da-ca|0;ia=ca;ja=da;ka=ea;la=fa;ma=ga}do{if((M|0)>6){PD(E)|0;if((M|0)<=7){na=U;break}$=PD(E)|0;_=$&255;if((M|0)>8){oa=M}else{na=_;break}while(1){$=oa-1|0;PD(E)|0;if(($|0)>8){oa=$}else{na=_;break}}}else{na=U}}while(0);if((ha|0)==0){pa=0;D=41;break}if((ha+Q|0)>256){pa=ha;D=41;break}if(!(la>>>0<O>>>0)){D=45;break}if((ha|0)>0){M=L&65535;_=la&255;$=ja&65535;aa=Q;Z=0;while(1){if((aa|0)==78){b[u>>1]=8192;qa=Z-1|0}else{b[m+4+(aa*12|0)>>1]=M;b[m+4+(aa*12|0)+8>>1]=ka;a[m+4+(aa*12|0)+2|0]=_;b[m+4+(aa*12|0)+4>>1]=$;b[m+4+(aa*12|0)+6>>1]=Z+ia;a[m+4+(aa*12|0)+10|0]=ma;a[m+4+(aa*12|0)+11|0]=na;qa=Z}I=qa+1|0;ba=aa+1|0;if((I|0)<(ha|0)){aa=ba;Z=I}else{ra=ba;break}}}else{ra=Q}if((ra|0)<256){Q=ra;R=la;S=ja;T=ka;U=na;D=27}else{D=50;break}}if((D|0)==41){D=0;KIb(J,16,2143408,(N=i,i=i+16|0,c[N>>2]=pa,c[N+8>>2]=Q,N)|0);i=N;y=F;z=H;continue}else if((D|0)==45){D=0;KIb(J,16,2138872,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;y=F;z=H;continue}else if((D|0)==50){D=0;if((b[u>>1]|0)!=8192){D=51;break}Z=fD(E,0,0,1)|0;aa=wrc(Z,G,4,0)|0;Z=G;if(A>>>0>Z>>>0|A>>>0==Z>>>0&K>>>0>aa>>>0){aa=PD(E)|0;Z=G;$=0;if(!(Z>>>0<$>>>0|Z>>>0==$>>>0&aa>>>0<128>>>0)){KIb(J,16,2135160,(N=i,i=i+16|0,c[N>>2]=aa,c[N+8>>2]=Z,N)|0);i=N;y=F;z=H;continue}Z=aa;c[v>>2]=Z+1;b:do{if((Z|0)>0){aa=1;$=1024;while(1){sa=PD(E)|0;ta=G;_=0;if(!(((sa|0)!=0|(ta|0)!=0)&(ta>>>0<_>>>0|ta>>>0==_>>>0&sa>>>0<256>>>0))){D=57;break}_=m+3076+aa|0;a[_]=sa;M=sa&255;$=$-M|0;if(($|0)<0){D=59;break}L=hJb(M)|0;if((L|0)==0){y=F;z=H;continue a}AD(E,L,d[_]|0)|0;c[m+3204+(aa<<2)>>2]=L;aa=aa+1|0;if((aa|0)>=(c[v>>2]|0)){break b}}if((D|0)==57){D=0;KIb(J,16,2133488,(N=i,i=i+16|0,c[N>>2]=sa,c[N+8>>2]=ta,N)|0);i=N;y=F;z=H;continue a}else if((D|0)==59){D=0;KIb(J,16,2131448,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;y=F;z=H;continue a}}}while(0);if((a[w]|0)!=0){D=63;break}}Z=fD(E,0,0,1)|0;aa=G;$=xrc(K,A,Z,aa)|0;L=G;_=0;do{if((L|0)<(_|0)|(L|0)==(_|0)&$>>>0<0>>>0){fD(E,$,L,1)|0;}else{if(!((Z|0)==(K|0)&(aa|0)==(A|0))){M=L;ba=$;do{ba=wrc(ba,M,-1,-1)|0;M=G;zD(E)|0;}while(!((ba|0)==0&(M|0)==0))}if((xD(E)|0)!=0){break}M=qJb(O,40)|0;c[x>>2]=M;if((M|0)==0){y=F;z=H;continue a}else{D=71;break a}}}while(0);KIb(J,16,2128696,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;y=F;z=H;continue}}}if((D|0)==9){KIb(e,16,2257032,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;ua=-1094995529;i=f;return ua|0}else if((D|0)==51){KIb(0,0,2314952,(N=i,i=i+24|0,c[N>>2]=2136952,c[N+8>>2]=2215072,c[N+16>>2]=320,N)|0);i=N;Hd();return 0}else if((D|0)==63){KIb(0,0,2314952,(N=i,i=i+24|0,c[N>>2]=2130088,c[N+8>>2]=2215072,c[N+16>>2]=340,N)|0);i=N;Hd();return 0}else if((D|0)==71){if((O|0)!=0){z=0;do{ZX(J,0)|0;z=z+1|0;}while(z>>>0<O>>>0)}O=e+24|0;c:do{if((c[O>>2]|0)==0){va=0;wa=0}else{z=j|0;J=j+4|0;y=j+8|0;w=k|0;ta=k+4|0;sa=k+8|0;v=0;u=0;Q=0;d:while(1){pa=u;na=Q;e:while(1){U=-1;if((pa|0)>(U|0)|(pa|0)==(U|0)&na>>>0>-1>>>0){fD(n,na,pa,0)|0;}if((jD(n)|0)==0){xa=0;ya=0}else{break d}while(1){U=zD(n)|0;ka=U|(ya<<8|0>>>24);T=((U|0)<0|0?-1:0)|(xa<<8|ya>>>24);if((ka&0|0)==0&(T&-16777216|0)==1308622848){U=1542650331;ja=1314066752;if((ka|0)==(-1248413064|0)&(T|0)==1313450856|(ka|0)==(-288733847|0)&(T|0)==1313596589|(ka|0)==526320813&(T|0)==1313700438|(ka|0)==790881870&(T|0)==1314446695){pa=-1;na=-1;continue e}else if((ka|0)==(U|0)&(T|0)==(ja|0)){break e}}if((jD(n)|0)==0){xa=T;ya=ka}else{break d}}}na=fD(n,0,0,1)|0;pa=G;ka=wrc(na,pa,-8,-1)|0;T=G;ja=wrc(na,pa,-7,-1)|0;pa=G;na=0;if((T|0)<(na|0)|(T|0)==(na|0)&ka>>>0<0>>>0){break}ka=c[o>>2]|0;na=c[ka+16>>2]|0;T=uQ(na,1,1542650331,1314066752)|0;U=fD(na,0,0,1)|0;S=wrc(T,(T|0)<0|0?-1:0,U,G)|0;U=G;T=PD(na)|0;la=G;R=0;f:do{if(la>>>0<R>>>0|la>>>0==R>>>0&T>>>0<(c[ka+24>>2]|0)>>>0){ra=T;ha=c[x>>2]|0;qa=ha+(ra*40|0)+20|0;if((c[qa>>2]|0)!=0){D=86;break}ma=ka+28|0;ia=c[(c[ma>>2]|0)+(ra<<2)>>2]|0;if((ia|0)==0){za=0;break}oa=PD(na)|0;ga=oa;oa=PD(na)|0;fa=oa;if((fa|0)==2){Aa=DD(na)|0}else if((fa|0)==4){Aa=FD(na)|0}else{KIb(0,16,2162712,(N=i,i=i+8|0,c[N>>2]=fa,N)|0);i=N;Aa=-1}fa=ia+8|0;oa=c[fa>>2]|0;c[oa+52>>2]=Aa;if((ga|0)==1){c[oa+8>>2]=1;c[w>>2]=1337024;c[ta>>2]=1406408;c[sa>>2]=0;ea=NX(w,Aa)|0;c[(c[fa>>2]|0)+48>>2]=ea;Ba=ea;D=98}else if((ga|0)==2){c[oa+8>>2]=3;ea=JX(1336560,Aa)|0;c[(c[fa>>2]|0)+48>>2]=ea;Ba=ea;D=98}else if((ga|0)==0){c[oa+8>>2]=0;c[z>>2]=1335552;c[J>>2]=1409152;c[y>>2]=0;ea=NX(z,Aa)|0;c[(c[fa>>2]|0)+48>>2]=ea;Ba=ea;D=98}else if((ga|0)==3){c[oa+8>>2]=2;oa=JX(1336976,Aa)|0;c[(c[fa>>2]|0)+48>>2]=oa}else{KIb(ka,16,2202560,(N=i,i=i+8|0,c[N>>2]=ga,N)|0);i=N;za=0;break}do{if((D|0)==98){D=0;if((Ba|0)!=0){break}KIb(ka,16,2196440,(N=i,i=i+16|0,c[N>>2]=Aa,c[N+8>>2]=ra,N)|0);i=N}}while(0);ga=PD(na)|0;oa=G;ea=0;if(!(oa>>>0<ea>>>0|oa>>>0==ea>>>0&ga>>>0<(c[s>>2]|0)>>>0)){KIb(ka,16,2193760,(N=i,i=i+16|0,c[N>>2]=ga,c[N+8>>2]=oa,N)|0);i=N;za=0;break}oa=ha+(ra*40|0)+16|0;c[oa>>2]=ga;ga=PD(na)|0;ea=G;da=0;if(!(ea>>>0<da>>>0|ea>>>0==da>>>0&ga>>>0<16>>>0)){KIb(ka,16,2191240,(N=i,i=i+16|0,c[N>>2]=ga,c[N+8>>2]=ea,N)|0);i=N;za=0;break}c[ha+(ra*40|0)+24>>2]=ga;ga=PD(na)|0;c[ha+(ra*40|0)+28>>2]=ga;ga=PD(na)|0;ea=G;da=0;if(!(ea>>>0<da>>>0|ea>>>0==da>>>0&ga>>>0<1e3>>>0)){KIb(ka,16,2188848,(N=i,i=i+16|0,c[N>>2]=ga,c[N+8>>2]=ea,N)|0);i=N;za=0;break}ea=ga;c[ha+(ra*40|0)+32>>2]=ea;c[(c[fa>>2]|0)+176>>2]=ea;PD(na)|0;ea=PD(na)|0;ga=G;da=0;if(!(ga>>>0<da>>>0|ga>>>0==da>>>0&ea>>>0<1073741824>>>0)){KIb(ka,16,2186016,(N=i,i=i+16|0,c[N>>2]=ea,c[N+8>>2]=ga,N)|0);i=N;za=0;break}ga=ea;ea=c[fa>>2]|0;c[ea+100>>2]=ga;if((ga|0)==0){Ca=ea}else{if((QX(ea,na,ga)|0)<0){za=0;break}Ca=c[fa>>2]|0}ga=c[Ca+8>>2]|0;do{if((ga|0)==0){ea=PD(na)|0;if((ea|0)==0&(G|0)==0){KIb(ka,16,2183856,(N=i,i=i+16|0,c[N>>2]=0,c[N+8>>2]=0,N)|0);i=N;za=0;break f}c[(c[fa>>2]|0)+120>>2]=ea;ea=PD(na)|0;if((ea|0)==0&(G|0)==0){KIb(ka,16,2181576,(N=i,i=i+16|0,c[N>>2]=0,c[N+8>>2]=0,N)|0);i=N;za=0;break f}c[(c[fa>>2]|0)+124>>2]=ea;ea=PD(na)|0;da=ia+80|0;c[da>>2]=ea;ea=PD(na)|0;ca=ea;c[ia+84>>2]=ca;ea=c[da>>2]|0;if((ea|0)==0^(ca|0)==0){KIb(ka,16,2179376,(N=i,i=i+16|0,c[N>>2]=ea,c[N+8>>2]=ca,N)|0);i=N;za=0;break f}else{PD(na)|0;break}}else if((ga|0)==1){ca=PD(na)|0;if((ca|0)==0&(G|0)==0){KIb(ka,16,2177664,(N=i,i=i+16|0,c[N>>2]=0,c[N+8>>2]=0,N)|0);i=N;za=0;break f}c[(c[fa>>2]|0)+412>>2]=ca;PD(na)|0;ca=PD(na)|0;if((ca|0)==0&(G|0)==0){KIb(ka,16,2170792,(N=i,i=i+16|0,c[N>>2]=0,c[N+8>>2]=0,N)|0);i=N;za=0;break f}else{c[(c[fa>>2]|0)+416>>2]=ca;break}}}while(0);fa=fD(na,0,0,1)|0;ga=G;ia=xrc(S,U,fa,ga)|0;ha=G;ca=0;do{if((ha|0)<(ca|0)|(ha|0)==(ca|0)&ia>>>0<0>>>0){fD(na,ia,ha,1)|0;}else{if(!((fa|0)==(S|0)&(ga|0)==(U|0))){ea=ha;da=ia;do{da=wrc(da,ea,-1,-1)|0;ea=G;zD(na)|0;}while(!((da|0)==0&(ea|0)==0))}if((xD(na)|0)!=0){break}ea=c[oa>>2]|0;da=c[t>>2]|0;Y=da+(ea<<3)|0;c[qa>>2]=Y;_X(c[(c[ma>>2]|0)+(ra<<2)>>2]|0,63,c[Y>>2]|0,c[da+(ea<<3)+4>>2]|0);za=1;break f}}while(0);KIb(ka,16,2164800,(N=i,i=i+8|0,c[N>>2]=ra,N)|0);i=N;za=0}else{D=86}}while(0);if((D|0)==86){D=0;KIb(ka,16,2210456,(N=i,i=i+16|0,c[N>>2]=T,c[N+8>>2]=la,N)|0);i=N;za=0}na=za+v|0;if(na>>>0<(c[O>>2]|0)>>>0){v=na;u=pa;Q=ja}else{va=0;wa=0;break c}}KIb(e,16,2253600,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;ua=-1094995529;i=f;return ua|0}}while(0);g:while(1){O=-1;if((va|0)>(O|0)|(va|0)==(O|0)&wa>>>0>-1>>>0){fD(n,wa,va,0)|0;}if((jD(n)|0)==0){Da=0;Ea=0}else{D=138;break}while(1){O=zD(n)|0;Fa=O|(Ea<<8|0>>>24);Ga=((O|0)<0|0?-1:0)|(Da<<8|Ea>>>24);if((Fa&0|0)==0&(Ga&-16777216|0)==1308622848){if((Fa|0)==526320813&(Ga|0)==1313700438|(Fa|0)==1542650331&(Ga|0)==1314066752|(Fa|0)==(-288733847|0)&(Ga|0)==1313596589|(Fa|0)==(-1248413064|0)&(Ga|0)==1313450856|(Fa|0)==790881870&(Ga|0)==1314446695){break}}if((jD(n)|0)==0){Da=Ga;Ea=Fa}else{D=138;break g}}Ha=fD(n,0,0,1)|0;Ia=G;O=-1248413064;za=1313450856;if((Fa|0)==(-288733847|0)&(Ga|0)==1313596589){break}else if(!((Fa|0)==(O|0)&(Ga|0)==(za|0))){va=Ia;wa=Ha;continue}vQ(m)|0;va=Ia;wa=Ha}if((D|0)==138){fD(n,0,0,1)|0;KIb(e,16,2244144,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;ua=-1094995529;i=f;return ua|0}wa=l+3720|0;c[wa>>2]=-288733847;c[wa+4>>2]=1313596589;l=wrc(Ha,Ia,-8,-1)|0;Ia=e+1248|0;c[Ia>>2]=l;c[Ia+4>>2]=G;if((c[n+88>>2]|0)!=0){Ia=fD(n,0,0,1)|0;l=G;Ha=c[o>>2]|0;va=c[Ha+16>>2]|0;m=iD(va)|0;Ga=G;Fa=0;do{if(!((Ga|0)<(Fa|0)|(Ga|0)==(Fa|0)&m>>>0<1>>>0)){Ea=wrc(m,Ga,-12,-1)|0;fD(va,Ea,G,0)|0;Ea=OD(va)|0;Da=xrc(m,Ga,Ea,G)|0;fD(va,Da,G,0)|0;Da=OD(va)|0;if(!((Da|0)==790881870&(G|0)==1314446695)){KIb(Ha,16,2232896,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;Da=Ha+1064|0;Ea=c[Da+4>>2]|0;za=0;if(!((Ea|0)<(za|0)|(Ea|0)==(za|0)&(c[Da>>2]|0)>>>0<1>>>0)){break}za=c[o>>2]|0;c[g>>2]=0;c[g+4>>2]=0;FX(za,-1,g,0,102)|0;Ea=c[g>>2]|0;O=c[g+4>>2]|0;Ca=0;if((O|0)>(Ca|0)|(O|0)==(Ca|0)&Ea>>>0>0>>>0){c[za+1212>>2]=0}c[Da>>2]=Ea;c[Da+4>>2]=O;break}O=uQ(va,1,790881870,1314446695)|0;Da=fD(va,0,0,1)|0;Ea=wrc(O,(O|0)<0|0?-1:0,Da,G)|0;Da=G;O=PD(va)|0;za=G;Ca=c[s>>2]|0;Aa=0;Ba=Frc(O,za,Ca,Aa)|0;x=G;ya=Grc(O,za,Ca,Aa)|0;Aa=(c[t>>2]|0)+(ya<<3)|0;c[h>>2]=1;c[h+4>>2]=1e6;ya=XIb(Ba,x,Aa,h)|0;Aa=Ha+1064|0;c[Aa>>2]=ya;c[Aa+4>>2]=G;c[Ha+1212>>2]=0;Aa=PD(va)|0;ya=G;x=0;if(!((ya>>>0<x>>>0|ya>>>0==x>>>0&Aa>>>0<268435455>>>0)&((Aa|0)!=0|(ya|0)!=0))){KIb(Ha,16,2228936,(N=i,i=i+16|0,c[N>>2]=Aa,c[N+8>>2]=ya,N)|0);i=N;break}ya=Aa;if(ya>>>0<268435455>>>0){Ja=hJb(ya<<3)|0}else{Ja=0}Aa=Ja;x=ya+1|0;h:do{if(x>>>0<2147483647>>>0){Ba=hJb(x)|0;if((Ja|0)==0|(Ba|0)==0){Ka=Ba;break}Ca=(ya|0)>0;if(Ca){za=0;do{O=PD(va)|0;xa=G;k=Aa+(za<<3)|0;c[k>>2]=O;c[k+4>>2]=xa;j=0;if((xa|0)<(j|0)|(xa|0)==(j|0)&O>>>0<1>>>0){Ka=Ba;break h}if((za|0)!=0){j=Aa+(za-1<<3)|0;Q=wrc(c[j>>2]|0,c[j+4>>2]|0,O,xa)|0;c[k>>2]=Q;c[k+4>>2]=G}za=za+1|0;}while((za|0)<(ya|0))}za=Ha+24|0;ja=c[za>>2]|0;i:do{if((ja|0)!=0){pa=Ha+28|0;la=x;T=(x|0)<0|0?-1:0;ka=0;k=ja;j:while(1){if(Ca){La=0;Q=-1;xa=-1;while(1){O=PD(va)|0;j=G;u=O>>>1|j<<31;v=j>>>1|0<<31;do{if((O&1|0)==0&(j&0|0)==0){if((u|0)==1&(v|0)==0){Ma=La;break}else{Na=v;Oa=u;Pa=La}while(1){if((Pa|0)>=(x|0)){D=172;break j}z=Pa+1|0;a[Ba+Pa|0]=Oa&1;y=Oa>>>1|Na<<31;J=Na>>>1|0<<31;if((y|0)==1&(J|0)==0){Ma=z;break}else{Na=J;Oa=y;Pa=z}}}else{z=u&1;Qa=O>>>2|j<<30;Ra=j>>>2|0<<30;y=wrc(Qa,Ra,La,(La|0)<0|0?-1:0)|0;J=G;if(!(J>>>0<T>>>0|J>>>0==T>>>0&y>>>0<la>>>0)){D=169;break j}if((Qa|0)==0&(Ra|0)==0){Sa=La}else{y=wrc(Qa,Ra,-1,0)|0;J=y;mrc(Ba+La|0,z&255|0,J+1|0)|0;Sa=La+1+J|0}a[Ba+Sa|0]=z^1;Ma=Sa+1|0}}while(0);if((a[Ba]|0)!=0){D=175;break j}if((Ma|0)>(x|0)){D=179;break j}if((La|0)<(Ma|0)&(La|0)<(ya|0)){j=La-Ma|0;O=La-ya|0;u=j>>>0>O>>>0;v=La;z=Q;J=xa;while(1){if((a[Ba+v|0]|0)==0){Ta=z;Ua=J}else{y=PD(va)|0;w=G;if((y|0)==0&(w|0)==0){sa=PD(va)|0;ta=G;H=PD(va)|0;Va=ta;Wa=sa;Xa=G;Ya=H}else{Va=w;Wa=y;Xa=0;Ya=0}y=c[(c[pa>>2]|0)+(ka<<2)>>2]|0;w=Aa+(v-1<<3)|0;H=c[w>>2]|0;sa=c[w+4>>2]<<4|H>>>28;w=wrc(Wa,Va,J,z)|0;xX(y,H<<4|0>>>28,sa,w,G,0,0,1)|0;w=wrc(Ya,Xa,J,z)|0;sa=wrc(w,G,Wa,Va)|0;Ta=G;Ua=sa}sa=v+1|0;if((sa|0)<(Ma|0)&(sa|0)<(ya|0)){v=sa;z=Ta;J=Ua}else{break}}Za=La-(u?j:O)|0;_a=Ta;$a=Ua}else{Za=La;_a=Q;$a=xa}if((Za|0)<(ya|0)){La=Za;Q=_a;xa=$a}else{break}}ab=c[za>>2]|0}else{ab=k}xa=ka+1|0;if(xa>>>0<ab>>>0){ka=xa;k=ab}else{break i}}if((D|0)==169){KIb(Ha,16,2225288,(N=i,i=i+32|0,c[N>>2]=La,c[N+8>>2]=Qa,c[N+16>>2]=Ra,c[N+24>>2]=x,N)|0);i=N;Ka=Ba;break h}else if((D|0)==172){KIb(Ha,16,2220720,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;Ka=Ba;break h}else if((D|0)==175){KIb(Ha,16,2217416,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;Ka=Ba;break h}else if((D|0)==179){KIb(0,0,2314952,(N=i,i=i+24|0,c[N>>2]=2214536,c[N+8>>2]=2215072,c[N+16>>2]=687,N)|0);i=N;Hd();return 0}}}while(0);za=fD(va,0,0,1)|0;Ca=G;ja=xrc(Ea,Da,za,Ca)|0;k=G;ka=0;if((k|0)<(ka|0)|(k|0)==(ka|0)&ja>>>0<0>>>0){fD(va,ja,k,1)|0;}else{if(!((za|0)==(Ea|0)&(Ca|0)==(Da|0))){Ca=k;k=ja;do{k=wrc(k,Ca,-1,-1)|0;Ca=G;zD(va)|0;}while(!((k|0)==0&(Ca|0)==0))}if((xD(va)|0)==0){Ka=Ba;break}}KIb(Ha,16,2212136,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;Ka=Ba}else{Ka=0}}while(0);kJb(Ja);kJb(Ka)}}while(0);fD(n,Ia,l,0)|0;}if(!((c[wa>>2]|0)==(-288733847|0)&(c[wa+4>>2]|0)==1313596589)){KIb(0,0,2314952,(N=i,i=i+24|0,c[N>>2]=2236568,c[N+8>>2]=2215072,c[N+16>>2]=774,N)|0);i=N;Hd();return 0}dL(e,0,1336696);ua=0;i=f;return ua|0}return 0}function pQ(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[e+12>>2]|0;l=k;m=c[e+16>>2]|0;n=k+3720|0;o=e;e=k+3744|0;p=k;q=k+3736|0;r=k+3728|0;s=k+3752|0;k=f+24|0;t=f+64|0;u=f+28|0;v=0;a:while(1){w=fD(m,0,0,1)|0;x=G;y=c[n>>2]|0;z=c[n+4>>2]|0;c[n>>2]=0;c[n+4>>2]=0;do{if((y|0)==0&(z|0)==0){A=zD(m)|0;if((jD(m)|0)!=0){B=-541478725;C=69;break a}if((A|0)!=78){D=A;E=x;F=w;C=12;break}A=zD(m)|0;H=A;I=wrc(H<<8|0>>>24,((A|0)<0|0?-1:0)<<8|H>>>24,5111808,0)|0;H=G;A=zD(m)|0;J=wrc(A,(A|0)<0|0?-1:0,I,H)|0;H=G<<8|J>>>24;I=zD(m)|0;A=wrc(I,(I|0)<0|0?-1:0,J<<8|0>>>24,H)|0;H=G<<8|A>>>24;J=zD(m)|0;I=wrc(J,(J|0)<0|0?-1:0,A<<8|0>>>24,H)|0;H=G<<8|I>>>24;A=zD(m)|0;J=wrc(A,(A|0)<0|0?-1:0,I<<8|0>>>24,H)|0;H=G<<8|J>>>24;I=zD(m)|0;A=wrc(I,(I|0)<0|0?-1:0,J<<8|0>>>24,H)|0;H=G<<8|A>>>24;J=zD(m)|0;I=wrc(J,(J|0)<0|0?-1:0,A<<8|0>>>24,H)|0;K=G;L=I;M=x;N=w;O=78;C=7}else{I=wrc(w,x,-8,-1)|0;K=z;L=y;M=G;N=I;O=v;C=7}}while(0);do{if((C|0)==7){C=0;y=0;z=0;x=-288733847;w=1313596589;I=-1248413064;H=1313450856;if((L|0)==526320813&(K|0)==1313700438|(L|0)==1542650331&(K|0)==1314066752|(L|0)==790881870&(K|0)==1314446695){A=uQ(m,0,L,K)|0;hD(m,A,(A|0)<0|0?-1:0)|0;v=O;continue a}else if((L|0)==(y|0)&(K|0)==(z|0)){D=O;E=M;F=N;C=12;break}else if((L|0)==(I|0)&(K|0)==(H|0)){if((vQ(l)|0)<0){P=O;Q=M;R=N;break}else{v=O;continue a}}else if((L|0)==(x|0)&(K|0)==(w|0)){if((tQ(l,h,j)|0)<0){P=O;Q=M;R=N;break}D=zD(m)|0;E=M;F=N;C=12;break}else{P=O;Q=M;R=N;break}}}while(0);b:do{if((C|0)==12){C=0;w=c[p>>2]|0;x=c[w+16>>2]|0;H=fD(x,0,0,1)|0;I=G;z=wrc(c[q>>2]|0,0,c[e>>2]|0,c[e+4>>2]|0)|0;y=G;if((I|0)>(y|0)|(I|0)==(y|0)&H>>>0>z>>>0){z=fD(x,0,0,1)|0;H=G;y=c[e>>2]|0;I=c[e+4>>2]|0;A=c[q>>2]|0;KIb(w,16,2371864,(S=i,i=i+40|0,c[S>>2]=z,c[S+8>>2]=H,c[S+16>>2]=y,c[S+24>>2]=I,c[S+32>>2]=A,S)|0);i=S;P=D;Q=E;R=F;break}A=b[l+4+(D*12|0)>>1]|0;I=A&65535;y=b[l+4+(D*12|0)+4>>1]|0;H=b[l+4+(D*12|0)+6>>1]|0;z=H&65535;J=d[l+4+(D*12|0)+2|0]|0;T=b[l+4+(D*12|0)+8>>1]|0;U=d[l+4+(D*12|0)+10|0]|0;V=a[l+4+(D*12|0)+11|0]|0;if((I&8192|0)!=0){P=D;Q=E;R=F;break}if((I&4096|0)==0){W=I}else{I=PD(x)|0;W=I^A&65535}do{if((W&16|0)==0){X=J}else{A=PD(x)|0;I=G;Y=0;if(I>>>0<Y>>>0|I>>>0==Y>>>0&A>>>0<(c[w+24>>2]|0)>>>0){X=A;break}else{KIb(w,16,2358800,(S=i,i=i+16|0,c[S>>2]=A,c[S+8>>2]=I,S)|0);i=S;P=D;Q=E;R=F;break b}}}while(0);J=c[r>>2]|0;I=J+(X*40|0)|0;do{if((W&8|0)==0){A=J+(X*40|0)+8|0;Y=wrc(c[A>>2]|0,c[A+4>>2]|0,T<<16>>16,T<<16>>16<0|0?-1:0)|0;Z=G;_=Y}else{Y=PD(x)|0;A=Y;Y=c[J+(X*40|0)+24>>2]|0;$=A;aa=(A|0)<0|0?-1:0;if((A|0)<(1<<Y|0)){A=L$(I,$,aa)|0;Z=G;_=A;break}else{A=yrc(1,0,Y|0)|0;Y=xrc($,aa,A,G)|0;Z=G;_=Y;break}}}while(0);if((W&32|0)==0){ba=z}else{T=PD(x)|0;Y=Erc(T,G,y&65535,0)|0;T=wrc(Y,G,H&65535,0)|0;ba=T}if((W&2048|0)!=0){PD(x)|0;}if((W&1024|0)==0){ca=V}else{T=PD(x)|0;ca=T&255}if((W&128|0)==0){da=U}else{T=PD(x)|0;da=T}if((da|0)>0){T=0;do{PD(x)|0;T=T+1|0;}while((T|0)<(da|0))}T=ca&255;if(!(T>>>0<(c[s>>2]|0)>>>0)){KIb(w,16,2347496,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;P=D;Q=E;R=F;break}U=(ba|0)>4096?0:T;ea=l+3076+U|0;T=ba-(d[ea]|0)|0;do{if((W&64|0)==0){if(!(T>>>0>c[q>>2]<<1>>>0)){V=J+(X*40|0)+8|0;H=xrc(c[V>>2]|0,c[V+4>>2]|0,_,Z)|0;y=G;z=-1;Y=(y|0)>(z|0)|(y|0)==(z|0)&H>>>0>-1>>>0;z=xrc(0,0,H,y)|0;A=Y?y:G;y=c[J+(X*40|0)+28>>2]|0;aa=(y|0)<0|0?-1:0;if(!((A|0)>(aa|0)|(A|0)==(aa|0)&(Y?H:z)>>>0>y>>>0)){fa=V;break}}KIb(w,16,2341136,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;P=D;Q=E;R=F;break b}else{JD(x)|0;fa=J+(X*40|0)+8|0}}while(0);c[fa>>2]=_;c[fa+4>>2]=Z;c[I>>2]=W;c:do{if((T|0)<0){ga=T}else{J=c[r>>2]|0;ha=J+(X*40|0)|0;V=(c[ha>>2]&1|0)==0;if(!V){c[J+(X*40|0)+4>>2]=0}y=c[(c[w+28>>2]|0)+(X<<2)>>2]|0;z=c[y+76>>2]|0;H=y+216|0;y=c[H>>2]|0;Y=c[H+4>>2]|0;do{if((z|0)<32|V^1){if((z|0)<16|(y|0)==0&(Y|0)==(-2147483648|0)){if((z|0)>47){break}}else{if((Y|0)>(Z|0)|(Y|0)==(Z|0)&y>>>0>_>>>0|(z|0)>47){break}}if((c[J+(X*40|0)+4>>2]|0)!=0){break}if((K1(f,(d[ea]|0)+T|0)|0)<0){P=D;Q=E;R=F;break b}nrc(c[k>>2]|0,c[l+3204+(U<<2)>>2]|0,d[ea]|0)|0;H=fD(x,0,0,1)|0;aa=G;c[t>>2]=H;c[t+4>>2]=aa;if((c[ha>>2]&256|0)==0){ia=T}else{A=T;$=(T|0)<0|0?-1:0;ja=wrc(H,aa,A,$)|0;if((wQ(w,x,f,ja,G)|0)<0){P=D;Q=E;R=F;break b}ja=wrc(c[t>>2]|0,c[t+4>>2]|0,A,$)|0;if((wQ(w,x,f,ja,G)|0)<0){P=D;Q=E;R=F;break b}ja=fD(x,0,0,1)|0;$=xrc(ja,G,c[t>>2]|0,c[t+4>>2]|0)|0;ja=$;c[u>>2]=(c[u>>2]|0)-ja;ia=T-ja|0}ka=AD(x,(c[k>>2]|0)+(d[ea]|0)|0,ia)|0;if((ka|0)!=(ia|0)&(ka|0)<0){ga=ka;break c}else{C=58;break a}}}while(0);hD(x,T,(T|0)<0|0?-1:0)|0;v=D;continue a}}while(0);if((ga|0)==1){v=D;continue a}else if((ga|0)==0){B=0;C=69;break a}else{P=D;Q=E;R=F}}}while(0);KIb(o,48,2520808,(S=i,i=i+16|0,c[S>>2]=R,c[S+8>>2]=Q,S)|0);i=S;T=wrc(c[e>>2]|0,c[e+4>>2]|0,1,0)|0;x=G;w=-1;if((x|0)>(w|0)|(x|0)==(w|0)&T>>>0>-1>>>0){fD(m,T,x,0)|0;}if((jD(m)|0)==0){la=0;ma=0}else{B=-1094995529;C=69;break}while(1){x=zD(m)|0;na=x|(ma<<8|0>>>24);oa=((x|0)<0|0?-1:0)|(la<<8|ma>>>24);if((na&0|0)==0&(oa&-16777216|0)==1308622848){if((na|0)==526320813&(oa|0)==1313700438|(na|0)==1542650331&(oa|0)==1314066752|(na|0)==(-288733847|0)&(oa|0)==1313596589|(na|0)==(-1248413064|0)&(oa|0)==1313450856|(na|0)==790881870&(oa|0)==1314446695){break}}if((jD(m)|0)==0){la=oa;ma=na}else{B=-1094995529;C=69;break a}}KIb(o,48,2506424,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;c[n>>2]=na;c[n+4>>2]=oa;v=P}if((C|0)==58){M1(f,(d[ea]|0)+ka|0);c[f+32>>2]=X;if((c[ha>>2]&1|0)!=0){ha=f+36|0;c[ha>>2]=c[ha>>2]|1}ha=f+8|0;c[ha>>2]=_;c[ha+4>>2]=Z;B=0;i=g;return B|0}else if((C|0)==69){i=g;return B|0}return 0}function qQ(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;mJb(b+3756|0);mJb(b+3728|0);P$(b);a=b+3752|0;if((c[a>>2]|0)<=1){return 0}d=b+3204|0;b=1;do{mJb(d+(b<<2)|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function rQ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0;g=i;i=i+64|0;h=g|0;j=g+24|0;k=g+48|0;l=g+56|0;m=c[a+12>>2]|0;n=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;b=h|0;o=h+16|0;mrc(h|0,0,16)|0;p=(+(d>>>0)+ +(e|0)*4294967296.0)*(+(c[n+40>>2]|0)/+(c[n+44>>2]|0))*1.0e6;q=(F=+p,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[o>>2]=~~+p>>>0;c[o+4>>2]=q;q=j;c[q>>2]=c[170526];c[q+4>>2]=c[170527];c[q+8>>2]=c[170528];c[q+12>>2]=c[170529];c[q+16>>2]=c[170530];c[q+20>>2]=c[170531];q=k|0;c[q>>2]=j;r=k+4|0;c[r>>2]=j;s=n+400|0;do{if((c[s>>2]|0)==0){t=m+3760|0;u=h;v=k;uLb(c[t>>2]|0,u,382,v)|0;w=c[q>>2]|0;x=w|0;y=c[x+4>>2]|0;z=c[r>>2]|0;A=z|0;B=c[A>>2]|0;C=c[A+4>>2]|0;A=w+16|0;w=c[A>>2]|0;D=c[A+4>>2]|0;A=z+16|0;z=c[A>>2]|0;E=c[A+4>>2]|0;KIb(a,48,2385624,(H=i,i=i+64|0,c[H>>2]=c[x>>2],c[H+8>>2]=y,c[H+16>>2]=B,c[H+24>>2]=C,c[H+32>>2]=w,c[H+40>>2]=D,c[H+48>>2]=z,c[H+56>>2]=E,H)|0);i=H;E=c[q>>2]|0;z=E|0;D=c[r>>2]|0;w=D|0;C=c[w>>2]|0;B=c[w+4>>2]|0;w=E+16|0;E=D+16|0;D=EX(a,-1,c[o>>2]|0,c[o+4>>2]|0,c[z>>2]|0,c[z+4>>2]|0,C,B,C,B,c[w>>2]|0,c[w+4>>2]|0,c[E>>2]|0,c[E+4>>2]|0,1,l,102)|0;E=G;if((f&1|0)==0){w=wrc(D,E,16,0)|0;c[b>>2]=w;c[b+4>>2]=G;c[r>>2]=j;uLb(c[t>>2]|0,u,738,v)|0;v=c[q>>2]|0;w=v|0;B=c[r>>2]|0;C=B|0;z=c[C>>2]|0;y=c[C+4>>2]|0;C=v+8|0;v=B+8|0;B=EX(a,-2,c[b>>2]|0,c[b+4>>2]|0,c[w>>2]|0,c[w+4>>2]|0,z,y,z,y,c[C>>2]|0,c[C+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0,f,l,102)|0;v=G;C=-1;y=(v|0)>(C|0)|(v|0)==(C|0)&B>>>0>-1>>>0;I=y?v:E;J=y?B:D}else{I=E;J=D}c[b>>2]=J;c[b+4>>2]=I;D=uLb(c[t>>2]|0,u,738,0)|0;if((D|0)==0){KIb(0,0,2314952,(H=i,i=i+24|0,c[H>>2]=2262088,c[H+8>>2]=2215072,c[H+16>>2]=1157,H)|0);i=H;Hd();return 0}else{u=D+8|0;D=wrc(c[u>>2]|0,c[u+4>>2]|0,-15,-1)|0;K=G;L=D;break}}else{D=CX(n,d,e,f)|0;do{if((D|0)<0){u=CX(n,d,e,f^1)|0;if((u|0)<0){M=-1}else{N=u;break}i=g;return M|0}else{N=D}}while(0);D=c[s>>2]|0;u=D+(N*24|0)|0;t=c[u>>2]|0;E=c[u+4>>2]|0;u=D+(N*24|0)+8|0;D=c[u+4>>2]|0;c[l>>2]=c[u>>2];c[l+4>>2]=D;K=E;L=t}}while(0);KIb(0,48,2182048,(H=i,i=i+16|0,c[H>>2]=L,c[H+8>>2]=K,H)|0);i=H;l=a+16|0;N=c[l>>2]|0;s=K;f=L;a:while(1){e=-1;if((s|0)>(e|0)|(s|0)==(e|0)&f>>>0>-1>>>0){fD(N,f,s,0)|0;}if((jD(N)|0)==0){O=0;P=0}else{S=-1;T=-1;break}while(1){e=zD(N)|0;d=e|(P<<8|0>>>24);n=((e|0)<0|0?-1:0)|(O<<8|P>>>24);if((d&0|0)==0&(n&-16777216|0)==1308622848){e=-288733847;I=1313596589;if((d|0)==(-1248413064|0)&(n|0)==1313450856|(d|0)==526320813&(n|0)==1313700438|(d|0)==1542650331&(n|0)==1314066752|(d|0)==790881870&(n|0)==1314446695){s=-1;f=-1;continue a}else if((d|0)==(e|0)&(n|0)==(I|0)){U=17;break a}}if((jD(N)|0)==0){O=n;P=d}else{S=-1;T=-1;break a}}}if((U|0)==17){U=fD(N,0,0,1)|0;N=wrc(U,G,-8,-1)|0;S=G;T=N}fD(c[l>>2]|0,T,S,0)|0;KIb(0,48,2153656,(H=i,i=i+16|0,c[H>>2]=T,c[H+8>>2]=S,H)|0);i=H;l=wrc(L,K,15,0)|0;N=G;if((K|0)>(S|0)|(K|0)==(S|0)&L>>>0>T>>>0|((N|0)<(S|0)|(N|0)==(S|0)&l>>>0<T>>>0)){KIb(0,16,2128968,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}H=a+24|0;if((c[H>>2]|0)==0){M=0;i=g;return M|0}a=c[m+3728>>2]|0;m=0;while(1){c[a+(m*40|0)+4>>2]=1;T=m+1|0;if(T>>>0<(c[H>>2]|0)>>>0){m=T}else{M=0;break}}i=g;return M|0}function sQ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[a+12>>2]|0;l=k;m=c[a+16>>2]|0;n=a;a=c[d>>2]|0;o=c[d+4>>2]|0;KIb(n,48,2105896,(p=i,i=i+40|0,c[p>>2]=b,c[p+8>>2]=a,c[p+16>>2]=o,c[p+24>>2]=e,c[p+32>>2]=f,p)|0);i=p;f=c[d+4>>2]|0;e=c[d>>2]|0;a:while(1){o=-1;if((f|0)>(o|0)|(f|0)==(o|0)&e>>>0>-1>>>0){fD(m,e,f,0)|0;}if((jD(m)|0)==0){q=0;r=0}else{s=9;break}while(1){o=zD(m)|0;a=o|(r<<8|0>>>24);t=((o|0)<0|0?-1:0)|(q<<8|r>>>24);if((a&0|0)==0&(t&-16777216|0)==1308622848){o=-288733847;u=1313596589;if((a|0)==(-1248413064|0)&(t|0)==1313450856|(a|0)==526320813&(t|0)==1313700438|(a|0)==1542650331&(t|0)==1314066752|(a|0)==790881870&(t|0)==1314446695){f=-1;e=-1;continue a}else if((a|0)==(o|0)&(t|0)==(u|0)){break}}if((jD(m)|0)==0){q=t;r=a}else{s=9;break a}}a=fD(m,0,0,1)|0;t=G;v=wrc(a,t,-8,-1)|0;w=G;u=0;if((w|0)<(u|0)|(w|0)==(u|0)&v>>>0<0>>>0){s=9;break}e=wrc(a,t,-7,-1)|0;f=G;if((tQ(l,h,j)|0)>=0){break}}if((s|0)==9){KIb(n,16,2623960,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;x=-2147483648;y=0;i=g;return(G=x,y)|0}c[d>>2]=v;c[d+4>>2]=w;d=k+3744|0;if(!((c[d>>2]|0)==(v|0)&(c[d+4>>2]|0)==(w|0))){KIb(0,0,2314952,(p=i,i=i+24|0,c[p>>2]=2597344,c[p+8>>2]=2215072,c[p+16>>2]=1100,p)|0);i=p;Hd();return 0}w=c[h>>2]|0;d=c[h+4>>2]|0;h=c[j>>2]|0;v=c[j+4>>2]|0;KIb(n,48,2573112,(p=i,i=i+32|0,c[p>>2]=w,c[p+8>>2]=d,c[p+16>>2]=h,c[p+24>>2]=v,p)|0);i=p;if((b|0)==(-1|0)){x=d;y=w;i=g;return(G=x,y)|0}else if((b|0)==(-2|0)){x=v;y=h;i=g;return(G=x,y)|0}else{KIb(0,0,2314952,(p=i,i=i+24|0,c[p>>2]=2554744,c[p+8>>2]=2215072,c[p+16>>2]=1105,p)|0);i=p;Hd();return 0}return 0}function tQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0;e=i;f=c[a>>2]|0;g=c[f+16>>2]|0;h=fD(g,0,0,1)|0;j=wrc(h,G,-8,-1)|0;h=a+3744|0;c[h>>2]=j;c[h+4>>2]=G;j=uQ(g,1,-288733847,1313596589)|0;k=fD(g,0,0,1)|0;l=G;m=PD(g)|0;n=G;o=c[h>>2]|0;p=c[h+4>>2]|0;q=PD(g)|0;r=xrc(o,p,q<<4|0>>>28,G<<4|q>>>28)|0;q=G;c[d>>2]=r;c[d+4>>2]=q;p=0;if((q|0)<(p|0)|(q|0)==(p|0)&r>>>0<0>>>0){s=-1094995529;i=e;return s|0}r=wrc(j,(j|0)<0|0?-1:0,k,l)|0;l=G;k=a+3740|0;j=c[k>>2]|0;p=0;q=Grc(m,n,j,p)|0;o=a+3756|0;t=(c[o>>2]|0)+(q<<3)|0;q=Frc(m,n,j,p)|0;K$(a,t,q,G);q=fD(g,0,0,1)|0;t=G;p=xrc(r,l,q,t)|0;j=G;u=0;do{if((j|0)<(u|0)|(j|0)==(u|0)&p>>>0<0>>>0){fD(g,p,j,1)|0;}else{if(!((q|0)==(r|0)&(t|0)==(l|0))){v=j;w=p;do{w=wrc(w,v,-1,-1)|0;v=G;zD(g)|0;}while(!((w|0)==0&(v|0)==0))}if((xD(g)|0)!=0){break}v=c[k>>2]|0;w=0;x=Frc(m,n,v,w)|0;y=+(x>>>0)+ +(G>>>0)*4294967296.0;x=Grc(m,n,v,w)|0;w=x;x=c[o>>2]|0;z=y*(+(c[x+(w<<3)>>2]|0)/+(c[x+(w<<3)+4>>2]|0))*1.0e6;w=~~+z>>>0;x=(F=+z,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[b>>2]=w;c[b+4>>2]=x;v=O$(a,c[h>>2]|0,c[h+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0,w,x)|0;s=(v|0)<0?v:0;i=e;return s|0}}while(0);KIb(f,16,2536816,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;s=-1094995529;i=e;return s|0}function uQ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=je(d|0)|0;c[g>>2]=je(e|0)|0;c[g+4>>2]=h;h=wD(0,g,8)|0;c[g>>2]=h;c[g+4>>2]=0;yD(a,448,h);h=PD(a)|0;g=G;e=0;d=(g|0)>(e|0)|(g|0)==(e|0)&h>>>0>4096>>>0;if(d){JD(a)|0}if(!((xD(a)|0)==0|d^1)){j=-1;i=f;return j|0}yD(a,(b|0)!=0?448:0,0);j=h;i=f;return j|0}function vQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;d=i;i=i+1536|0;e=d|0;f=d+256|0;g=d+1280|0;h=c[b>>2]|0;j=c[h+16>>2]|0;k=uQ(j,1,-1248413064,1313450856)|0;l=fD(j,0,0,1)|0;m=wrc(k,(k|0)<0|0?-1:0,l,G)|0;l=G;k=PD(j)|0;n=G;o=h+24|0;p=0;if(n>>>0>p>>>0|n>>>0==p>>>0&k>>>0>(c[o>>2]|0)>>>0){KIb(h,16,2335432,(q=i,i=i+16|0,c[q>>2]=k,c[q+8>>2]=n,q)|0);i=q;r=-1094995529;i=d;return r|0}n=k;k=PD(j)|0;p=wrc(k,G,1,0)|0;k=G;s=(p&1|0)==0&(k&0|0)==0;t=p>>>1|k<<31;p=k>>1|((k|0)<0|0?-1:0)<<31;k=xrc(0,0,t,p)|0;s?p:G;p=s?t:k;k=PD(j)|0;t=G;s=PD(j)|0;u=G;v=PD(j)|0;w=v;v=(n|0)==0;do{if((p|0)!=0&v){x=c[b+3740>>2]|0;y=0;z=Frc(k,t,x,y)|0;A=G;B=Grc(k,t,x,y)|0;y=(c[b+3756>>2]|0)+(B<<3)|0;B=wrc(z,A,s,u)|0;C=(aY(h,p,y,z,A,B,G,0)|0)+32|0;D=0}else{if(v){C=h+1140|0;D=0;break}else{B=c[(c[h+28>>2]|0)+(n-1<<2)>>2]|0;C=B+88|0;D=B;break}}}while(0);if((w|0)!=0){u=e|0;s=h;b=(p|0)==0;p=f|0;t=n-1|0;k=c[334199]|0;B=(k|0)==0;A=h+28|0;z=(C|0)==0;y=D+412|0;x=D+416|0;D=g|0;E=0;do{F=PD(j)|0;H=F;do{if((H|0)==0){I=0}else{F=H>>>0>256>>>0;AD(j,u,F?256:H)|0;if(F){J=H}else{I=H;break}while(1){zD(j)|0;F=J-1|0;if(F>>>0>256>>>0){J=F}else{I=256;break}}}}while(0);a[e+(I>>>0>255>>>0?255:I)|0]=0;H=PD(j)|0;F=wrc(H,G,1,0)|0;H=G;K=(F&1|0)==0&(H&0|0)==0;L=F>>>1|H<<31;F=H>>1|((H|0)<0|0?-1:0)<<31;H=xrc(0,0,L,F)|0;M=K?L:H;H=K?F:G;F=-4;K=-1;L=-3;N=-1;O=-2;P=-1;do{if((M|0)==(-1|0)&(H|0)==(-1|0)){Q=PD(j)|0;R=Q;do{if((R|0)==0){S=0}else{Q=R>>>0>1024>>>0;AD(j,p,Q?1024:R)|0;if(Q){T=R}else{S=R;break}while(1){zD(j)|0;Q=T-1|0;if(Q>>>0>1024>>>0){T=Q}else{S=1024;break}}}}while(0);a[f+(S>>>0>1023>>>0?1023:S)|0]=0;U=2330192}else if((M|0)==(F|0)&(H|0)==(K|0)){PD(j)|0;U=2319008}else if((M|0)==(O|0)&(H|0)==(P|0)){R=PD(j)|0;Q=R;do{if((Q|0)==0){V=0}else{R=Q>>>0>256>>>0;AD(j,D,R?256:Q)|0;if(R){W=Q}else{V=Q;break}while(1){zD(j)|0;R=W-1|0;if(R>>>0>256>>>0){W=R}else{V=256;break}}}}while(0);a[g+(V>>>0>255>>>0?255:V)|0]=0;Q=PD(j)|0;R=Q;do{if((R|0)==0){X=0}else{Q=R>>>0>1024>>>0;AD(j,p,Q?1024:R)|0;if(Q){Y=R}else{X=R;break}while(1){zD(j)|0;Q=Y-1|0;if(Q>>>0>1024>>>0){Y=Q}else{X=1024;break}}}}while(0);a[f+(X>>>0>1023>>>0?1023:X)|0]=0;U=D}else if((M|0)==(L|0)&(H|0)==(N|0)){PD(j)|0;U=2324168}else{R=-1;if(!((H|0)<(R|0)|(H|0)==(R|0)&M>>>0<-4>>>0)){U=2309576;break}PD(j)|0;U=2314120}}while(0);M=c[o>>2]|0;a:do{if(n>>>0>M>>>0){KIb(s,16,2305664,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}else{if((irc(U,2330192)|0)!=0){break}do{if(b){if((irc(u,2295120)|0)!=0){break}if(B){Z=37}else{H=0;N=0;L=k;do{P=(irc(1336784+(N<<4)|0,p)|0)==0;H=P?L:H;N=N+1|0;L=c[1336796+(N<<4)>>2]|0;}while((L|0)!=0);if((H|0)==0){Z=37}else{_=H;$=M}}if((Z|0)==37){Z=0;KIb(s,32,2261376,(q=i,i=i+8|0,c[q>>2]=p,q)|0);i=q;_=0;$=c[o>>2]|0}if(($|0)==0){break a}if(v){L=c[A>>2]|0;N=0;while(1){P=(c[L+(N<<2)>>2]|0)+72|0;c[P>>2]=c[P>>2]|_;N=N+1|0;if(!(N>>>0<(c[o>>2]|0)>>>0)){break a}}}else{aa=0;ba=$}while(1){if((aa|0)==(t|0)){N=(c[(c[A>>2]|0)+(t<<2)>>2]|0)+72|0;c[N>>2]=c[N>>2]|_;ca=c[o>>2]|0}else{ca=ba}N=aa+1|0;if(N>>>0<ca>>>0){aa=N;ba=ca}else{break a}}}}while(0);do{if(!v){if((irc(u,2286416)|0)!=0){break}Bd(p|0,2282288,(q=i,i=i+16|0,c[q>>2]=y,c[q+8>>2]=x,q)|0)|0;i=q;N=c[y>>2]|0;L=(N|0)<0|0?-1:0;H=c[x>>2]|0;P=Erc(H,(H|0)<0|0?-1:0,1e3,0)|0;H=G;if((L|0)<(H|0)|(L|0)==(H|0)&N>>>0<P>>>0){break a}c[x>>2]=0;c[y>>2]=0;break a}}while(0);if(z){break}if((IFb(u,2278336)|0)==0){break}if((IFb(u,2274192)|0)==0){break}if((IFb(u,2269040)|0)==0){break}MGb(C,u,p,0)|0}}while(0);E=E+1|0;}while(E>>>0<w>>>0)}w=fD(j,0,0,1)|0;E=G;p=xrc(m,l,w,E)|0;u=G;C=0;do{if((u|0)<(C|0)|(u|0)==(C|0)&p>>>0<0>>>0){fD(j,p,u,1)|0;}else{if(!((w|0)==(m|0)&(E|0)==(l|0))){z=u;y=p;do{y=wrc(y,z,-1,-1)|0;z=G;zD(j)|0;}while(!((y|0)==0&(z|0)==0))}if((xD(j)|0)==0){r=0}else{break}i=d;return r|0}}while(0);KIb(h,16,2265120,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=d;return r|0}function wQ(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;h=i;i=i+776|0;j=h|0;k=h+256|0;l=h+512|0;m=h+768|0;n=PD(d)|0;o=n;a:do{if((o|0)>0){n=j|0;p=b;q=k|0;r=l|0;s=0;t=0;u=0;v=0;w=0;x=0;z=0;A=0;B=0;b:while(1){C=fD(d,0,0,1)|0;D=G;if(!((D|0)<(g|0)|(D|0)==(g|0)&C>>>0<f>>>0)){E=-1094995529;F=53;break}C=PD(d)|0;D=C;do{if((D|0)==0){H=0}else{C=D>>>0>256>>>0;AD(d,n,C?256:D)|0;if(C){I=D}else{H=D;break}while(1){zD(d)|0;C=I-1|0;if(C>>>0>256>>>0){I=C}else{H=256;break}}}}while(0);a[j+(H>>>0>255>>>0?255:H)|0]=0;D=PD(d)|0;C=wrc(D,G,1,0)|0;D=G;J=(C&1|0)==0&(D&0|0)==0;K=C>>>1|D<<31;C=D>>1|((D|0)<0|0?-1:0)<<31;D=xrc(0,0,K,C)|0;J?C:G;C=J?K:D;c:do{if((C|0)==(-1|0)){D=PD(d)|0;K=D;do{if((K|0)==0){L=0}else{D=K>>>0>256>>>0;AD(d,q,D?256:K)|0;if(D){M=K}else{L=K;break}while(1){zD(d)|0;D=M-1|0;if(D>>>0>256>>>0){M=D}else{L=256;break}}}}while(0);a[k+(L>>>0>255>>>0?255:L)|0]=0;KIb(p,24,2492128,(N=i,i=i+16|0,c[N>>2]=n,c[N+8>>2]=q,N)|0);i=N;O=B;P=z;Q=x;R=w;S=u;T=v;U=t;V=s}else if((C|0)==(-2|0)){K=PD(d)|0;D=K;do{if((D|0)==0){W=0}else{K=D>>>0>256>>>0;AD(d,r,K?256:D)|0;if(K){X=D}else{W=D;break}while(1){zD(d)|0;K=X-1|0;if(K>>>0>256>>>0){X=K}else{W=256;break}}}}while(0);a[l+(W>>>0>255>>>0?255:W)|0]=0;D=PD(d)|0;K=G;J=fD(d,0,0,1)|0;Y=wrc(J,G,D,K)|0;J=G;if(!((J|0)<(g|0)|(J|0)==(g|0)&Y>>>0<f>>>0)){E=-1094995529;F=53;break b}do{if((irc(n,2482200)|0)==0){Z=U1(e,0,D)|0}else{if((irc(n,2471048)|0)==0){Z=U1(e,1,D)|0;break}Y=Bd(n|0,2463192,(N=i,i=i+8|0,c[N>>2]=m,N)|0)|0;i=N;if((Y|0)==1){Y=wrc(D,K,8,0)|0;J=U1(e,74,Y)|0;if((J|0)==0){E=-12;F=53;break b}Y=c[m+4>>2]|0;_=je(c[m>>2]|0)|0;$=J;aa=$|0;y=je(Y|0)|0;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;aa=$+4|0;y=_|0;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;Z=J+8|0;break}if((irc(n,2447984)|0)==0&((D|0)==8&(K|0)==0)){J=GD(d)|0;O=B;P=z;Q=x;R=w;S=G;T=J;U=t;V=s;break c}else{KIb(p,24,2432800,(N=i,i=i+16|0,c[N>>2]=n,c[N+8>>2]=r,N)|0);i=N;hD(d,D,K)|0;O=B;P=z;Q=x;R=w;S=u;T=v;U=t;V=s;break c}}}while(0);if((Z|0)==0){E=-12;F=53;break b}AD(d,Z,D)|0;O=B;P=z;Q=x;R=w;S=u;T=v;U=t;V=s}else if((C|0)==(-3|0)){PD(d)|0;O=B;P=z;Q=x;R=w;S=u;T=v;U=t;V=s}else if((C|0)==(-4|0)){PD(d)|0;O=B;P=z;Q=x;R=w;S=u;T=v;U=t;V=s}else{if((C|0)<-4){PD(d)|0;O=B;P=z;Q=x;R=w;S=u;T=v;U=t;V=s;break}if((irc(n,2424056)|0)==0){O=C;P=z;Q=x;R=w;S=u;T=v;U=t;V=s;break}if((irc(n,2413216)|0)==0){O=B;P=z;Q=x;R=w;S=u;T=v;U=t;V=C;break}if((irc(n,2405552)|0)==0){O=B;P=z;Q=x;R=w;S=u;T=v;U=C;V=s;break}if((irc(n,2398128)|0)==0){O=B;P=z;Q=x;R=C;S=u;T=v;U=t;V=s;break}if((irc(n,2391040)|0)==0){O=B;P=z;Q=C;R=w;S=u;T=v;U=t;V=s;break}if((irc(n,2384208)|0)==0){O=B;P=C;Q=x;R=w;S=u;T=v;U=t;V=s;break}KIb(p,24,2377448,(N=i,i=i+8|0,c[N>>2]=n,N)|0);i=N;O=B;P=z;Q=x;R=w;S=u;T=v;U=t;V=s}}while(0);C=A+1|0;if((C|0)<(o|0)){s=V;t=U;u=S;v=T;w=R;x=Q;z=P;A=C;B=O}else{ba=V;ca=U;da=S;ea=T;fa=R;ga=Q;ha=P;ia=O;break a}}if((F|0)==53){i=h;return E|0}}else{ba=0;ca=0;da=0;ea=0;fa=0;ga=0;ha=0;ia=0}}while(0);F=(ca|0)!=0;do{if(!((ea|0)==0&(da|0)==0&(F^1)&(fa|0)==0&(ga|0)==0&(ha|0)==0)){O=U1(e,2,28)|0;if((O|0)==0){E=-12;i=h;return E|0}P=(ea|0)!=0|(da|0)!=0;Q=(fa|0)!=0;R=ha|ga;T=O;y=(P&1)<<1|F&1|(Q&1)<<2|((R|0)!=0)<<3;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=O+4|0;if(F){S=T;y=ca;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;ja=O+8|0}else{ja=T}if(P){P=ja;T=P|0;y=ea;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=P+4|0;y=da;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;ka=ja+8|0}else{ka=ja}if(Q){Q=ka;y=fa;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;la=ka+4|0}else{la=ka}if((R|0)==0){break}R=la;y=ga;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;R=la+4|0;y=ha;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y}}while(0);if((ia|ba|0)==0){E=0;i=h;return E|0}ha=U1(e,70,10)|0;if((ha|0)==0){E=-12;i=h;return E|0}e=ha;y=ia;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=ha+4|0;y=ba;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;E=0;i=h;return E|0}function xQ(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;e=i;i=i+64|0;f=e|0;g=e+40|0;h=e+48|0;j=e+56|0;k=j;l=i;i=i+8|0;m=l;n=d+12|0;o=c[n>>2]|0;p=c[d+16>>2]|0;c[o>>2]=d;q=d+24|0;r=o+3728|0;s=r;c[s>>2]=qJb(c[q>>2]|0,40)|0;t=d+1132|0;u=o+3732|0;v=u;c[v>>2]=qJb(c[t>>2]|0,4)|0;w=qJb((c[t>>2]|0)+(c[q>>2]|0)|0,8)|0;x=o+3756|0;y=x;c[y>>2]=w;do{if((c[s>>2]|0)!=0){if((c[v>>2]|0)==0|(w|0)==0){break}if((c[q>>2]|0)!=0){z=d+28|0;A=k+4|0;B=j;C=j;D=o+3740|0;E=0;do{F=c[(c[z>>2]|0)+(E<<2)>>2]|0;H=F+8|0;YS(c[H>>2]|0,A,h,B);I=c[H>>2]|0;do{if((c[I+8>>2]|0)==1){H=c[I+412>>2]|0;if((H|0)==0){J=11;break}c[B>>2]=1;c[A>>2]=H;K=1;L=H}else{J=11}}while(0);if((J|0)==11){J=0;RO(m,d,F,48e3);I=c[l>>2]|0;H=c[l+4>>2]|0;c[j>>2]=I;c[j+4>>2]=H;K=I;L=H}_X(F,64,K,L);H=c[D>>2]|0;I=0;while(1){M=c[y>>2]|0;if(!(I>>>0<H>>>0)){break}if((grc(C,M+(I<<3)|0,8)|0)==0){break}else{I=I+1|0}}H=M+(I<<3)|0;F=c[j+4>>2]|0;c[H>>2]=c[j>>2];c[H+4>>2]=F;c[(c[s>>2]|0)+(E*40|0)+20>>2]=(c[y>>2]|0)+(I<<3);if((I|0)==(c[D>>2]|0)){c[D>>2]=I+1}F=c[B>>2]|0;H=Erc(F,(F|0)<0|0?-1:0,1e3,0)|0;F=G;N=c[A>>2]|0;O=(N|0)<0|0?-1:0;c[(c[s>>2]|0)+(E*40|0)+24>>2]=(F|0)<(O|0)|(F|0)==(O|0)&H>>>0<N>>>0?14:7;N=c[A>>2]|0;H=c[B>>2]|0;c[(c[s>>2]|0)+(E*40|0)+28>>2]=(((N|0)>(H|0)?N:H)|0)/(H|0)|0;E=E+1|0;}while(E>>>0<(c[q>>2]|0)>>>0)}if((c[t>>2]|0)!=0){E=d+1136|0;B=o+3740|0;A=0;D=c[B>>2]|0;while(1){C=(c[(c[E>>2]|0)+(A<<2)>>2]|0)+4|0;z=C;H=0;while(1){P=c[y>>2]|0;if(!(H>>>0<D>>>0)){break}if((grc(z,P+(H<<3)|0,8)|0)==0){break}else{H=H+1|0}}z=C;I=P+(H<<3)|0;N=c[z+4>>2]|0;c[I>>2]=c[z>>2];c[I+4>>2]=N;c[(c[v>>2]|0)+(A<<2)>>2]=(c[y>>2]|0)+(H<<3);N=c[B>>2]|0;if((H|0)==(N|0)){I=H+1|0;c[B>>2]=I;Q=I}else{Q=N}N=A+1|0;if(N>>>0<(c[t>>2]|0)>>>0){A=N;D=Q}else{break}}}c[o+3736>>2]=32767;D=c[n>>2]|0;A=D+3752|0;c[A>>2]=7;B=D+3204|0;E=1;do{N=E-1|0;a[D+(E+3076)|0]=a[1898824+(N*5|0)|0]|0;c[B+(E<<2)>>2]=1898825+(N*5|0);E=E+1|0;}while((E|0)<(c[A>>2]|0));A=c[n>>2]|0;E=c[q>>2]|0;B=E>>>0>2>>>0;D=A+4|0;N=D;b[A+16>>1]=4096;b[A+20>>1]=1;b[A+24>>1]=1;if(B){b[A+28>>1]=56;b[A+32>>1]=1;R=3;J=29}else{if((E|0)!=0){R=2;J=29}}if((J|0)==29){I=254-R|0;z=d+28|0;O=f|0;F=f+4|0;S=f+8|0;T=f+12|0;U=f+16|0;V=A+3728|0;W=g+4|0;X=g|0;Y=0;Z=E;while(1){E=(((ca(Y,I)|0)>>>0)/(Z>>>0)|0)+R|0;_=Y+1|0;$=(((ca(_,I)|0)>>>0)/(Z>>>0)|0)+R|0;aa=c[(c[(c[z>>2]|0)+(Y<<2)>>2]|0)+8>>2]|0;ba=(c[aa+8>>2]|0)==1;da=ba&1;do{if(ba){ea=B5a(aa,0)|0;fa=(c[aa+48>>2]|0)==86021&(ea|0)==0?64:ea;J=36}else{zKb(g,aa+104|0,c[(c[V>>2]|0)+(Y*40|0)+20>>2]|0);if((c[W>>2]|0)==1){ea=c[X>>2]|0;fa=(ea|0)>0?ea:0;J=36;break}else{ga=Y&255;ha=1;J=53;break}}}while(0);do{if((J|0)==36){J=0;H=(fa|0)==0?1:fa;C=Y&255;if(ba&B){b[N+(E*12|0)>>1]=41;a[N+(E*12|0)+2|0]=C;b[N+(E*12|0)+4>>1]=1;a[N+(E*12|0)+11|0]=EQ(c[n>>2]|0,aa,-1,1)|0;ia=E+1|0;ja=H;ka=C;J=38;break}if(!ba){ga=C;ha=H;J=53;break}b[N+(E*12|0)>>1]=40;a[N+(E*12|0)+2|0]=C;b[N+(E*12|0)+4>>1]=1;a[N+(E*12|0)+11|0]=EQ(c[n>>2]|0,aa,-1,0)|0;ea=E+1|0;b[N+(ea*12|0)>>1]=41;a[N+(ea*12|0)+2|0]=C;b[N+(ea*12|0)+4>>1]=1;a[N+(ea*12|0)+11|0]=EQ(c[n>>2]|0,aa,-1,1)|0;la=C;ma=H;na=E+2|0;J=39}}while(0);if((J|0)==53){J=0;b[N+(E*12|0)>>1]=40;a[N+(E*12|0)+2|0]=ga;b[N+(E*12|0)+4>>1]=1;H=E+1|0;b[N+(H*12|0)>>1]=41;a[N+(H*12|0)+2|0]=ga;b[N+(H*12|0)+4>>1]=1;ia=E+2|0;ja=ha;ka=ga;J=38}do{if((J|0)==38){J=0;if(ba){la=ka;ma=ja;na=ia;J=39;break}b[N+(ia*12|0)>>1]=33;a[N+(ia*12|0)+2|0]=ka;b[N+(ia*12|0)+4>>1]=1;b[N+(ia*12|0)+8>>1]=ja;oa=ia+1|0;pa=ka;qa=ja}}while(0);if((J|0)==39){J=0;E=c[aa+424>>2]|0;H=c[aa+72>>2]|0;C=Erc(H,(H|0)<0|0?-1:0,E,(E|0)<0|0?-1:0)|0;E=c[aa+412>>2]<<3;H=Crc(C,G,E,(E|0)<0|0?-1:0)|0;E=H;C=E+2&65535;b[N+(na*12|0)>>1]=1;a[N+(na*12|0)+2|0]=la;b[N+(na*12|0)+4>>1]=C;ea=H&65535;b[N+(na*12|0)+6>>1]=ea;b[N+(na*12|0)+8>>1]=0;a[N+(na*12|0)+11|0]=EQ(c[n>>2]|0,aa,E,da)|0;H=na+1|0;b[N+(H*12|0)>>1]=1;a[N+(H*12|0)+2|0]=la;b[N+(H*12|0)+4>>1]=C;ra=E+1|0;sa=ra&65535;b[N+(H*12|0)+6>>1]=sa;b[N+(H*12|0)+8>>1]=0;a[N+(H*12|0)+11|0]=EQ(c[n>>2]|0,aa,ra,da)|0;H=na+2|0;ta=ma&65535;b[N+(H*12|0)>>1]=1;a[N+(H*12|0)+2|0]=la;b[N+(H*12|0)+4>>1]=C;b[N+(H*12|0)+6>>1]=ea;b[N+(H*12|0)+8>>1]=ta;a[N+(H*12|0)+11|0]=EQ(c[n>>2]|0,aa,E,da)|0;E=na+3|0;b[N+(E*12|0)>>1]=1;a[N+(E*12|0)+2|0]=la;b[N+(E*12|0)+4>>1]=C;b[N+(E*12|0)+6>>1]=sa;b[N+(E*12|0)+8>>1]=ta;a[N+(E*12|0)+11|0]=EQ(c[n>>2]|0,aa,ra,da)|0;oa=na+4|0;pa=la;qa=ma}do{if((c[aa+176>>2]|0)==0){if((c[aa+48>>2]|0)==86021){c[O>>2]=2;c[F>>2]=9;c[S>>2]=16;ua=3;va=2;break}else{c[O>>2]=1;ua=1;va=1;break}}else{c[O>>2]=-2;c[F>>2]=-1;c[S>>2]=1;c[T>>2]=3;c[U>>2]=4;ua=5;va=-2}}while(0);ra=$-oa|0;E=ba&1|32;ta=0;sa=va;while(1){C=((ca(ta,ra)|0)/(ua|0)|0)+oa|0;H=ta+1|0;ea=((ca(H,ra)|0)/(ua|0)|0)+oa|0;wa=ca(sa,qa)|0;c[f+(ta<<2)>>2]=wa;if((C|0)<(ea|0)){xa=ea-C&65535;ya=wa&65535;if(ba){wa=C;do{b[N+(wa*12|0)>>1]=E;a[N+(wa*12|0)+2|0]=pa;b[N+(wa*12|0)+4>>1]=xa;b[N+(wa*12|0)+6>>1]=wa-C;b[N+(wa*12|0)+8>>1]=ya;a[N+(wa*12|0)+11|0]=EQ(c[n>>2]|0,aa,-1,da)|0;wa=wa+1|0;}while((wa|0)<(ea|0))}else{wa=C;do{b[N+(wa*12|0)>>1]=E;a[N+(wa*12|0)+2|0]=pa;b[N+(wa*12|0)+4>>1]=xa;b[N+(wa*12|0)+6>>1]=wa-C;b[N+(wa*12|0)+8>>1]=ya;wa=wa+1|0;}while((wa|0)<(ea|0))}}if((H|0)>=(ua|0)){break}ta=H;sa=c[f+(H<<2)>>2]|0}sa=c[q>>2]|0;if(_>>>0<sa>>>0){Y=_;Z=sa}else{break}}}Z=A+940|0;orc(A+952|0,Z|0,2124)|0;b[Z>>1]=8192;b[A+3064>>1]=8192;b[D>>1]=8192;if((b[o+940>>1]|0)!=8192){KIb(0,0,2261856,(Z=i,i=i+24|0,c[Z>>2]=2371816,c[Z+8>>2]=2181936,c[Z+16>>2]=753,Z)|0);i=Z;Hd();return 0}dD(p,2358704,24);bD(p,0);Z=AQ(d,p)|0;if((Z|0)<0){za=Z;i=e;return za|0}Z=d+1204|0;if((c[Z>>2]|0)<0){c[Z>>2]=1}eD(p);za=0;i=e;return za|0}}while(0);mJb(r);mJb(u);mJb(x);za=-12;i=e;return za|0}function yQ(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=c[a+12>>2]|0;m=l;n=b+32|0;o=c[n>>2]|0;p=l+3728|0;q=c[p>>2]|0;r=q+(o*40|0)|0;s=c[a+16>>2]|0;c[h>>2]=0;t=(c[b+36>>2]&1|0)==0;u=b+28|0;v=c[u>>2]|0;w=b+8|0;x=c[w>>2]|0;y=c[w+4>>2]|0;z=0;if((y|0)<(z|0)|(y|0)==(z|0)&x>>>0<0>>>0){KIb(a,16,2573016,(A=i,i=i+24|0,c[A>>2]=o,c[A+8>>2]=x,c[A+16>>2]=y,A)|0);i=A;B=-22;i=f;return B|0}do{if((c[b+44>>2]|0)==0){C=v;D=0}else{if((c[l+3780>>2]|0)<=3){C=v;D=0;break}y=_D(h)|0;if((y|0)<0){B=y;i=f;return B|0}else{y=a+28|0;CQ(c[y>>2]|0,c[h>>2]|0,b,0);CQ(c[y>>2]|0,c[h>>2]|0,b,1);y=aE(c[h>>2]|0,j)|0;C=y+v|0;D=y;break}}}while(0);v=l+3752|0;h=yrc(1,0,((c[v>>2]|0)*3|0)+20|0)|0;y=G;x=fD(s,0,0,1)|0;z=G;if(!((y|0)>(z|0)|(y|0)==(z|0)&h>>>0>x>>>0)){AQ(a,s)|0}if(t){E=1}else{E=(c[r>>2]&1|0)!=0}t=C+30|0;x=fD(s,0,0,1)|0;h=wrc(x,G,t,(t|0)<0|0?-1:0)|0;t=G;x=l+3744|0;z=wrc(c[l+3736>>2]|0,0,c[x>>2]|0,c[x+4>>2]|0)|0;y=G;a:do{if(!(((t|0)<(y|0)|(t|0)==(y|0)&h>>>0<z>>>0)&E)){F=k;c[F>>2]=c[194374];c[F+4>>2]=c[194375];c[F+8>>2]=c[194376];c[F+12>>2]=c[194377];c[F+16>>2]=c[194378];c[F+20>>2]=c[194379];H=q+(o*40|0)+20|0;I=b+16|0;K$(m,c[H>>2]|0,c[I>>2]|0,c[I+4>>2]|0);J=a+24|0;if((c[J>>2]|0)==0){K=k|0}else{L=a+28|0;M=k|0;N=0;while(1){O=c[(c[L>>2]|0)+(N<<2)>>2]|0;P=c[I>>2]|0;Q=c[I+4>>2]|0;R=c[H>>2]|0;S=c[R>>2]|0;T=c[(c[p>>2]|0)+(N*40|0)+20>>2]|0;U=c[T+4>>2]|0;V=Erc(U,(U|0)<0|0?-1:0,S,(S|0)<0|0?-1:0)|0;S=G;U=c[R+4>>2]|0;R=c[T>>2]|0;T=Erc(R,(R|0)<0|0?-1:0,U,(U|0)<0|0?-1:0)|0;U=UIb(P,Q,V,S,T,G,2)|0;T=CX(O,U,G,1)|0;if((T|0)>-1){U=c[M>>2]|0;S=c[M+4>>2]|0;V=(c[O+400>>2]|0)+(T*24|0)|0;T=c[V>>2]|0;O=c[V+4>>2]|0;V=S>>>0>O>>>0|S>>>0==O>>>0&U>>>0>T>>>0;c[M>>2]=V?T:U;c[M+4>>2]=V?O:S}S=N+1|0;if(S>>>0<(c[J>>2]|0)>>>0){N=S}else{K=M;break}}}if((c[K>>2]|0)==(-1|0)&(c[K+4>>2]|0)==2147483647){c[K>>2]=0;c[K+4>>2]=0}M=uLb(c[l+3760>>2]|0,F,738,0)|0;N=fD(s,0,0,1)|0;c[x>>2]=N;c[x+4>>2]=G;N=_D(g)|0;if((N|0)<0){B=N;i=f;return B|0}N=c[H>>2]|0;L=c[g>>2]|0;S=c[l+3756>>2]|0;O=Erc(c[l+3740>>2]|0,0,c[I>>2]|0,c[I+4>>2]|0)|0;V=N-S>>3;S=wrc(V,(V|0)<0|0?-1:0,O,G)|0;qD(L,S,G);S=c[g>>2]|0;if((M|0)==0){W=0;X=0}else{L=M;M=xrc(c[x>>2]|0,c[x+4>>2]|0,c[L>>2]|0,c[L+4>>2]|0)|0;L=G;W=L>>>4|0<<28;X=M>>>4|L<<28}qD(S,X,W);BQ(s,c[g>>2]|0,-288733847,1313596589);S=O$(m,c[x>>2]|0,c[x+4>>2]|0,0,0,c[I>>2]|0,c[I+4>>2]|0)|0;if((S|0)<0){B=S;i=f;return B|0}S=l+3764|0;L=c[S>>2]|0;M=Drc(0,268435456,L,(L|0)<0|0?-1:0)|0;if(!((M|0)==0&(G|0)==0)){break}if((c[J>>2]|0)==0){break}else{Y=0;Z=L}while(1){L=(c[p>>2]|0)+(Y*40|0)+36|0;oJb(L,Z<<1,8)|0;M=c[L>>2]|0;if((M|0)==0){B=-12;break}Z=c[S>>2]|0;L=(Z|0)==1?0:Z;O=Z<<1;if((L|0)<(O|0)){V=L;do{L=M+(V<<3)|0;c[L>>2]=0;c[L+4>>2]=-2147483648;V=V+1|0;}while((V|0)<(O|0))}Y=Y+1|0;if(!(Y>>>0<(c[J>>2]|0)>>>0)){break a}}i=f;return B|0}}while(0);Y=q+(o*40|0)+8|0;if((c[Y>>2]|0)==0&(c[Y+4>>2]|0)==(-2147483648|0)){KIb(0,0,2261856,(A=i,i=i+24|0,c[A>>2]=2554592,c[A+8>>2]=2181936,c[A+16>>2]=1020,A)|0);i=A;Hd();return 0}Z=q+(o*40|0)+24|0;p=(1<<c[Z>>2])-1|0;g=p&c[w>>2];W=((p|0)<0|0?-1:0)&c[w+4>>2];p=L$(r,g,W)|0;X=c[w>>2]|0;K=c[w+4>>2]|0;if((p|0)==(X|0)&(G|0)==(K|0)){_=W;$=g}else{g=1<<c[Z>>2];Z=wrc(g,(g|0)<0|0?-1:0,X,K)|0;_=G;$=Z}Z=c[u>>2]|0;do{if((Z|0)>4096){aa=0}else{K=c[v>>2]|0;if((K|0)<=1){aa=0;break}X=b+24|0;g=1;W=0;p=0;while(1){k=d[m+3076+g|0]|0;if((Z|0)>=(k|0)&(k|0)>(p|0)){E=(grc(c[X>>2]|0,c[m+3204+(g<<2)>>2]|0,k)|0)==0;ba=E?k:p;ca=E?g:W}else{ba=p;ca=W}E=g+1|0;if((E|0)<(K|0)){g=E;W=ca;p=ba}else{aa=ca;break}}}}while(0);ca=l+4|0;ba=l+(aa+3076)|0;Z=0;v=-1;p=2147483647;while(1){W=ca+(Z*12|0)|0;g=e[W>>1]|0;do{if((g&8192|0)==0){K=DQ(m,r,W,b)|0;X=g&4096;E=X>>>12;k=(X|0)==0?g:K;if((k&K|0)!=(K|0)){da=p;ea=v;break}if(((k^K)&1|0)!=0){da=p;ea=v;break}if((k&16|0)==0){fa=E}else{K=c[n>>2]|0;fa=(pD(K,(K|0)<0|0?-1:0)|0)+E|0}E=e[ca+(Z*12|0)+4>>1]|0;if(((C|0)%(E|0)|0|0)!=(e[ca+(Z*12|0)+6>>1]|0|0)){da=p;ea=v;break}if((k&32|0)==0){ga=fa}else{K=(C|0)/(E|0)|0;ga=(pD(K,(K|0)<0|0?-1:0)|0)+fa|0}K=(k&64|0)==0?ga:ga+4|0;if((k&8|0)==0){ha=K}else{ha=(pD($,_)|0)+K|0}if((k&4096|0)==0){ia=k}else{ia=(d[ba]|0)>>>0>((d[l+((d[ca+(Z*12|0)+11|0]|0)+3076)|0]|0)+1|0)>>>0?k|1024:k}if((ia&1024|0)==0){ja=ha-(d[l+((d[ca+(Z*12|0)+11|0]|0)+3076)|0]|0)|0}else{ja=ha+1-(d[ba]|0)|0}k=((ja<<2|ia>>>3&1)^1)+(ia>>>6&1^1)|0;K=(k|0)<(p|0);da=K?k:p;ea=K?Z:v}else{da=p;ea=v}}while(0);g=Z+1|0;if((g|0)<256){Z=g;v=ea;p=da}else{break}}if((ea|0)==-1){KIb(0,0,2261856,(A=i,i=i+24|0,c[A>>2]=2536768,c[A+8>>2]=2181936,c[A+16>>2]=1084,A)|0);i=A;Hd();return 0}A=ca+(ea*12|0)|0;da=e[A>>1]|0;p=DQ(m,r,A,b)|0;A=d[ca+(ea*12|0)+11|0]|0;yD(s,448,0);bD(s,ea);if((da&4096|0)==0){ka=da}else{m=(da^p)&-4097;qD(s,m,(m|0)<0|0?-1:0);ka=p}if((ka&16|0)!=0){p=c[n>>2]|0;qD(s,p,(p|0)<0|0?-1:0)}if((ka&8|0)!=0){qD(s,$,_)}if((ka&32|0)!=0){_=(C|0)/(e[ca+(ea*12|0)+4>>1]|0|0)|0;qD(s,_,(_|0)<0|0?-1:0)}if((ka&1024|0)==0){la=A}else{qD(s,aa,(aa|0)<0|0?-1:0);la=aa}aa=xD(s)|0;if((ka&64|0)!=0){kD(s,aa)}if((ka&256|0)!=0){dD(s,c[j>>2]|0,D);mJb(j)}j=d[l+(la+3076)|0]|0;dD(s,(c[b+24>>2]|0)+j|0,(c[u>>2]|0)-j|0);c[r>>2]=ka;r=c[w+4>>2]|0;c[Y>>2]=c[w>>2];c[Y+4>>2]=r;do{if((ka&1|0)!=0){xX(c[(c[a+28>>2]|0)+(c[n>>2]<<2)>>2]|0,c[x>>2]|0,c[x+4>>2]|0,c[w>>2]|0,c[w+4>>2]|0,0,0,1)|0;r=c[q+(o*40|0)+36>>2]|0;if((r|0)==0){break}Y=r+(c[l+3764>>2]<<3)|0;if(!((c[Y>>2]|0)==0&(c[Y+4>>2]|0)==(-2147483648|0))){break}r=c[w+4>>2]|0;c[Y>>2]=c[w>>2];c[Y+4>>2]=r}}while(0);x=l+3776|0;n=c[x>>2]|0;a=l+3768|0;do{if((n|0)==0){ma=q+(o*40|0)+20|0}else{l=q+(o*40|0)+20|0;if((YIb(c[a>>2]|0,c[a+4>>2]|0,n,c[w>>2]|0,c[w+4>>2]|0,c[l>>2]|0)|0)<0){ma=l;break}else{B=0}i=f;return B|0}}while(0);n=c[w+4>>2]|0;c[a>>2]=c[w>>2];c[a+4>>2]=n;c[x>>2]=c[ma>>2];B=0;i=f;return B|0}function zQ(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;b=i;i=i+40|0;e=b|0;f=b+24|0;g=b+32|0;h=c[a+12>>2]|0;j=h;k=c[a+16>>2]|0;l=h+3752|0;if((c[l>>2]|0)<3){do{AQ(a,k)|0;}while((c[l>>2]|0)<3)}do{if((_D(g)|0)>-1){l=h+3764|0;if((c[l>>2]|0)==0){break}m=c[g>>2]|0;n=e;mrc(n|0,0,24)|0;c[f>>2]=0;c[f+4>>2]=0;o=fD(m,0,0,1)|0;p=G;q=c[h+3776>>2]|0;r=h+3768|0;s=c[h+3756>>2]|0;t=Erc(c[h+3740>>2]|0,0,c[r>>2]|0,c[r+4>>2]|0)|0;r=q-s>>3;s=wrc(r,(r|0)<0|0?-1:0,t,G)|0;qD(m,s,G);s=c[l>>2]|0;qD(m,s,(s|0)<0|0?-1:0);s=c[l>>2]|0;if((s|0)>0){t=h+3760|0;r=f;q=f+4|0;u=e|0;v=0;while(1){uLb(c[t>>2]|0,n,738,r)|0;w=c[q>>2]|0;x=c[w+4>>2]|0;y=c[u+4>>2]|0;z=xrc((c[w>>2]|0)>>>4|x<<28,x>>>4|0<<28,(c[u>>2]|0)>>>4|y<<28,y>>>4|0<<28)|0;qD(m,z,G);z=c[q>>2]|0;y=c[z+4>>2]|0;c[u>>2]=c[z>>2];c[u+4>>2]=y;y=v+1|0;z=c[l>>2]|0;if((y|0)<(z|0)){v=y}else{A=z;break}}}else{A=s}v=h;u=c[v>>2]|0;a:do{if((c[u+24>>2]|0)!=0){q=h+3728|0;r=0;n=A;t=u;b:while(1){if((n|0)>0){z=(c[q>>2]|0)+(r*40|0)+36|0;y=-1;x=-1;w=0;B=n;while(1){C=c[z>>2]|0;do{if((w|0)==0){D=B;E=C;F=c[C+4>>2]|0;H=c[C>>2]|0}else{I=C+(w<<3)|0;J=c[I>>2]|0;K=c[I+4>>2]|0;I=C+(w-1<<3)|0;if(!((J|0)==(c[I>>2]|0)&(K|0)==(c[I+4>>2]|0))){D=B;E=C;F=K;H=J;break}KIb(c[v>>2]|0,24,2314760,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;J=c[z>>2]|0;K=J+(w<<3)|0;c[K>>2]=0;c[K+4>>2]=-2147483648;D=c[l>>2]|0;E=J;F=-2147483648;H=0}}while(0);C=(w+1|0)==(D|0);J=((H|0)!=0|(F|0)!=(-2147483648|0))^C;K=J&1;c:do{if((w|0)>=(D|0)|C){M=w;N=0}else{I=0;O=w;while(1){P=I+1|0;Q=O+1|0;if((Q|0)>=(D|0)){M=Q;N=P;break c}R=E+(Q<<3)|0;if(((c[R>>2]|0)!=0|(c[R+4>>2]|0)!=(-2147483648|0))^J){M=Q;N=P;break}else{I=P;O=Q}}}}while(0);J=K<<1|N<<2|1;qD(m,J,(J|0)<0|0?-1:0);d:do{if((N|0)<0){S=y;T=x}else{J=y;C=x;O=M-N|0;while(1){if((O|0)>=(c[l>>2]|0)){S=J;T=C;break d}I=(c[z>>2]|0)+(O<<3)|0;Q=c[I>>2]|0;P=c[I+4>>2]|0;if((Q|0)==0&(P|0)==(-2147483648|0)){U=J;V=C}else{if(!((P|0)>(J|0)|(P|0)==(J|0)&Q>>>0>C>>>0)){break b}I=xrc(Q,P,C,J)|0;qD(m,I,G);I=(c[z>>2]|0)+(O<<3)|0;U=c[I+4>>2]|0;V=c[I>>2]|0}I=O+1|0;if((I|0)>(M|0)){S=U;T=V;break}else{J=U;C=V;O=I}}}}while(0);K=M+1|0;W=c[l>>2]|0;if((K|0)<(W|0)){y=S;x=T;w=K;B=W}else{break}}X=W;Y=c[v>>2]|0}else{X=n;Y=t}B=r+1|0;if(B>>>0<(c[Y+24>>2]|0)>>>0){r=B;n=X;t=Y}else{break a}}KIb(0,0,2261856,(L=i,i=i+24|0,c[L>>2]=2214928,c[L+8>>2]=2181936,c[L+16>>2]=608,L)|0);i=L;Hd();return 0}}while(0);v=fD(m,0,0,1)|0;l=xrc(v,G,o,p)|0;v=G;u=wrc(l,v,12,0)|0;s=G;t=u;n=t>>>0>65535>>>0;r=n?t>>>16:t;t=n?16:0;if((r&65280|0)==0){Z=t;_=r}else{Z=t|8;_=r>>>8}r=((d[1359664+_|0]|0)+Z|0)/7|0;t=0;n=wrc(l,v,21,0)|0;v=wrc(n,G,(((s|0)>(t|0)|(s|0)==(t|0)&u>>>0>4096>>>0)&1)<<2,0)|0;u=wrc(v,G,r,(r|0)<0|0?-1:0)|0;sD(m,u,G);BQ(k,c[g>>2]|0,790881870,1314446695)}}while(0);P$(j);j=a+24|0;a=h+3728|0;if((c[j>>2]|0)==0){mJb(a);$=h+3732|0;mJb($);aa=h+3756|0;mJb(aa);i=b;return 0}g=a;k=0;do{mJb((c[g>>2]|0)+(k*40|0)+36|0);k=k+1|0;}while(k>>>0<(c[j>>2]|0)>>>0);mJb(a);$=h+3732|0;mJb($);aa=h+3756|0;mJb(aa);i=b;return 0}function AQ(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=i;i=i+328|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+288|0;p=h+296|0;q=h+304|0;r=h+312|0;s=h+320|0;t=f+12|0;u=c[t>>2]|0;v=u;dL(f,1336696,0);w=_D(q)|0;if((w|0)<0){x=w;i=h;return x|0}w=c[q>>2]|0;y=u+3780|0;c[y>>2]=3;qD(w,3,0);if((c[y>>2]|0)>3){y=c[u+3784>>2]|0;qD(w,y,(y|0)<0|0?-1:0)}y=u;qD(w,c[(c[y>>2]|0)+24>>2]|0,0);qD(w,c[u+3736>>2]|0,0);z=u+3740|0;qD(w,c[z>>2]|0,0);if((c[z>>2]|0)==0){A=0;B=0;C=1;D=0;E=0}else{F=u+3756|0;H=0;while(1){I=c[(c[F>>2]|0)+(H<<3)>>2]|0;qD(w,I,(I|0)<0|0?-1:0);I=c[(c[F>>2]|0)+(H<<3)+4>>2]|0;qD(w,I,(I|0)<0|0?-1:0);I=H+1|0;if(I>>>0<(c[z>>2]|0)>>>0){H=I}else{A=0;B=0;C=1;D=0;E=0;break}}}while(1){H=b[v+4+(E*12|0)+8>>1]|0;F=H<<16>>16;I=b[v+4+(E*12|0)+4>>1]|0;J=I&65535;K=a[v+4+(E*12|0)+2|0]|0;L=K&255;M=b[v+4+(E*12|0)+6>>1]|0;N=a[v+4+(E*12|0)+11|0]|0;O=N&255;P=(D|0)==(O|0)?M<<16>>16==0?(B|0)==(L|0)?(C|0)==(J|0)?(A|0)!=(F|0)|0:2:3:4:8;Q=b[v+4+(E*12|0)>>1]|0;R=M&65535;a:do{if((E|0)<256){S=0;T=E;while(1){U=T;while(1){V=U+1|0;if((U|0)==78){U=V}else{break}}if(!((b[v+4+(U*12|0)+8>>1]|0)==H<<16>>16)){W=S;X=U;break a}if(!((b[v+4+(U*12|0)>>1]|0)==Q<<16>>16)){W=S;X=U;break a}if(!((a[v+4+(U*12|0)+2|0]|0)==K<<24>>24)){W=S;X=U;break a}if(!((b[v+4+(U*12|0)+4>>1]|0)==I<<16>>16)){W=S;X=U;break a}if((e[v+4+(U*12|0)+6>>1]|0)!=(S+R|0)){W=S;X=U;break a}if(!((a[v+4+(U*12|0)+11|0]|0)==N<<24>>24)){W=S;X=U;break a}Y=S+1|0;if((V|0)<256){S=Y;T=V}else{W=Y;X=V;break}}}else{W=0;X=E}}while(0);T=(W|0)==(J-R|0)?P:6;qD(w,Q&65535,0);qD(w,T,(T|0)<0|0?-1:0);do{if((T|0)!=0){S=H<<16>>16;Y=H<<16>>16<0|0?-1:0;Z=H<<16>>16>-1;_=xrc(0,0,S,Y)|0;$=Z?S:_;_=xrc($<<1|0>>>31,(Z?Y:G)<<1|$>>>31,H<<16>>16>0|0,0)|0;qD(w,_,G);if(!(T>>>0>1>>>0)){break}qD(w,I&65535,0);if(!(T>>>0>2>>>0)){break}qD(w,K&255,0);if(!(T>>>0>3>>>0)){break}qD(w,M&65535,0);if(!(T>>>0>4>>>0)){break}qD(w,0,0);if(!(T>>>0>5>>>0)){break}qD(w,W,(W|0)<0|0?-1:0);if(!(T>>>0>6>>>0)){break}qD(w,1,-1073741824);if(!(T>>>0>7>>>0)){break}qD(w,N&255,0)}}while(0);if((X|0)<256){A=F;B=L;C=J;D=O;E=X}else{break}}X=u+3752|0;E=(c[X>>2]|0)-1|0;qD(w,E,(E|0)<0|0?-1:0);if((c[X>>2]|0)>1){E=1;do{D=v+3076+E|0;qD(w,d[D]|0,0);dD(w,c[v+3204+(E<<2)>>2]|0,d[D]|0);E=E+1|0;}while((E|0)<(c[X>>2]|0))}BQ(g,c[q>>2]|0,526320813,1313700438);E=(c[(c[y>>2]|0)+24>>2]|0)==0;v=_D(q)|0;w=(v|0)<0;b:do{if(E){aa=v;ba=w}else{D=0;C=v;B=w;while(1){if(B){x=C;ca=83;break}A=c[q>>2]|0;W=c[(c[(c[y>>2]|0)+28>>2]|0)+(D<<2)>>2]|0;V=c[t>>2]|0;N=c[W+8>>2]|0;qD(A,D,(D|0)<0|0?-1:0);T=N+8|0;M=c[T>>2]|0;if((M|0)==1){qD(A,1,0)}else if((M|0)==0){qD(A,0,0)}else if((M|0)==3){qD(A,2,0)}else{qD(A,3,0)}qD(A,4,0);M=c[N+52>>2]|0;if((M|0)==0){break}kD(A,M);M=V+3728|0;K=(c[(c[M>>2]|0)+(D*40|0)+20>>2]|0)-(c[V+3756>>2]|0)>>3;qD(A,K,(K|0)<0|0?-1:0);K=c[(c[M>>2]|0)+(D*40|0)+24>>2]|0;qD(A,K,(K|0)<0|0?-1:0);K=c[(c[M>>2]|0)+(D*40|0)+28>>2]|0;qD(A,K,(K|0)<0|0?-1:0);K=c[N+176>>2]|0;qD(A,K,(K|0)<0|0?-1:0);bD(A,0);K=N+100|0;M=c[K>>2]|0;qD(A,M,(M|0)<0|0?-1:0);dD(A,c[N+96>>2]|0,c[K>>2]|0);K=c[T>>2]|0;if((K|0)==1){T=c[N+412>>2]|0;qD(A,T,(T|0)<0|0?-1:0);qD(A,1,0);T=c[N+416>>2]|0;qD(A,T,(T|0)<0|0?-1:0)}else if((K|0)==0){K=c[N+120>>2]|0;qD(A,K,(K|0)<0|0?-1:0);K=c[N+124>>2]|0;qD(A,K,(K|0)<0|0?-1:0);K=c[W+80>>2]|0;do{if((K|0)<1){ca=41}else{N=W+84|0;if((c[N>>2]|0)<1){ca=41;break}qD(A,K,(K|0)<0|0?-1:0);T=c[N>>2]|0;qD(A,T,(T|0)<0|0?-1:0)}}while(0);if((ca|0)==41){ca=0;qD(A,0,0);qD(A,0,0)}qD(A,0,0)}BQ(g,c[q>>2]|0,1542650331,1314066752);K=D+1|0;W=K>>>0<(c[(c[y>>2]|0)+24>>2]|0)>>>0;T=_D(q)|0;N=(T|0)<0;if(W){D=K;C=T;B=N}else{aa=T;ba=N;break b}}if((ca|0)==83){i=h;return x|0}KIb(f,16,2597200,(da=i,i=i+8|0,c[da>>2]=D,da)|0);i=da;x=-22;i=h;return x|0}}while(0);if(ba){x=aa;i=h;return x|0}aa=c[q>>2]|0;ba=c[y>>2]|0;c[p>>2]=0;if((_D(o)|0)>=0){f=ba+1140|0;ba=LGb(c[f>>2]|0,10230048,0,2)|0;if((ba|0)==0){ea=0;fa=0}else{t=0;w=ba;do{ba=c[o>>2]|0;v=c[w>>2]|0;E=c[w+4>>2]|0;B=lrc(v|0)|0;qD(ba,B,(B|0)<0|0?-1:0);dD(ba,v,B);qD(ba,2,0);B=lrc(E|0)|0;qD(ba,B,(B|0)<0|0?-1:0);dD(ba,E,B);t=t+1|0;w=LGb(c[f>>2]|0,10230048,w,2)|0;}while((w|0)!=0);ea=(t|0)<0|0?-1:0;fa=t}qD(aa,0,0);qD(aa,0,0);qD(aa,0,0);qD(aa,0,0);qD(aa,fa,ea);ea=aE(c[o>>2]|0,p)|0;dD(aa,c[p>>2]|0,ea);kJb(c[p>>2]|0)}BQ(g,c[q>>2]|0,-1248413064,1313450856);p=c[y>>2]|0;c:do{if((c[p+24>>2]|0)==0){ga=p}else{ea=n|0;aa=c[334199]|0;o=(aa|0)==0;fa=0;while(1){t=_D(q)|0;if((t|0)<0){x=t;ca=83;break}t=c[q>>2]|0;w=c[(c[(c[y>>2]|0)+28>>2]|0)+(fa<<2)>>2]|0;c[m>>2]=0;f=_D(l)|0;if((f|0)<0){ha=f}else{f=w+88|0;B=LGb(c[f>>2]|0,10230048,0,2)|0;if((B|0)==0){ia=0}else{E=0;ba=B;while(1){B=c[l>>2]|0;v=c[ba>>2]|0;C=c[ba+4>>2]|0;O=lrc(v|0)|0;qD(B,O,(O|0)<0|0?-1:0);dD(B,v,O);qD(B,2,0);O=lrc(C|0)|0;qD(B,O,(O|0)<0|0?-1:0);dD(B,C,O);O=E+1|0;C=LGb(c[f>>2]|0,10230048,ba,2)|0;if((C|0)==0){ia=O;break}else{E=O;ba=C}}}if(o){ja=ia}else{ba=w+72|0;E=ia;f=0;A=aa;while(1){if((c[ba>>2]&A|0)==0){ka=E}else{C=c[l>>2]|0;O=1336784+(f<<4)|0;qD(C,11,0);dD(C,2128864,11);qD(C,2,0);B=lrc(O|0)|0;qD(C,B,(B|0)<0|0?-1:0);dD(C,O,B);ka=E+1|0}B=f+1|0;O=c[1336796+(B<<4)>>2]|0;if((O|0)==0){ja=ka;break}else{E=ka;f=B;A=O}}}A=c[w+8>>2]|0;if((c[A+8>>2]|0)==0){f=c[A+104>>2]|0;Rb(ea|0,256,2105800,(da=i,i=i+16|0,c[da>>2]=c[A+108>>2],c[da+8>>2]=f,da)|0)|0;i=da;f=c[l>>2]|0;qD(f,12,0);dD(f,2623864,12);qD(f,2,0);A=lrc(ea|0)|0;qD(f,A,(A|0)<0|0?-1:0);dD(f,ea,A);la=ja+1|0}else{la=ja}A=aE(c[l>>2]|0,m)|0;if((la|0)!=0){f=fa+1|0;qD(t,f,(f|0)<0|0?-1:0);qD(t,0,0);qD(t,0,0);qD(t,0,0);qD(t,la,(la|0)<0|0?-1:0);dD(t,c[m>>2]|0,A)}kJb(c[m>>2]|0);ha=la}if((ha|0)<0){x=ha;ca=83;break}A=c[q>>2]|0;if((ha|0)>0){BQ(g,A,-1248413064,1313450856)}else{aE(A,r)|0;kJb(c[r>>2]|0)}A=fa+1|0;f=c[y>>2]|0;if(A>>>0<(c[f+24>>2]|0)>>>0){fa=A}else{ga=f;break c}}if((ca|0)==83){i=h;return x|0}}}while(0);d:do{if((c[ga+1132>>2]|0)!=0){r=k;ha=u+3732|0;la=u+3756|0;m=0;while(1){l=_D(q)|0;if((l|0)<0){x=l;ca=83;break}l=c[q>>2]|0;c[k>>2]=0;ja=c[(c[(c[y>>2]|0)+1136>>2]|0)+(m<<2)>>2]|0;ma=_D(j)|0;if((ma|0)<0){break}qD(l,0,0);da=m+1|0;ka=da;ia=xrc(ka<<1|0>>>31,((da|0)<0|0?-1:0)<<1|ka>>>31,(da|0)>0|0,0)|0;qD(l,ia,G);ia=c[(c[ha>>2]|0)+(m<<2)>>2]|0;ka=ja+16|0;n=c[la>>2]|0;p=Erc(c[z>>2]|0,0,c[ka>>2]|0,c[ka+4>>2]|0)|0;fa=ia-n>>3;n=wrc(fa,(fa|0)<0|0?-1:0,p,G)|0;qD(l,n,G);n=ja+24|0;p=xrc(c[n>>2]|0,c[n+4>>2]|0,c[ka>>2]|0,c[ka+4>>2]|0)|0;qD(l,p,G);p=ja+32|0;ja=LGb(c[p>>2]|0,10230048,0,2)|0;if((ja|0)==0){na=0;oa=0}else{ka=0;n=ja;do{ja=c[j>>2]|0;fa=c[n>>2]|0;ia=c[n+4>>2]|0;ea=lrc(fa|0)|0;qD(ja,ea,(ea|0)<0|0?-1:0);dD(ja,fa,ea);qD(ja,2,0);ea=lrc(ia|0)|0;qD(ja,ea,(ea|0)<0|0?-1:0);dD(ja,ia,ea);ka=ka+1|0;n=LGb(c[p>>2]|0,10230048,n,2)|0;}while((n|0)!=0);na=(ka|0)<0|0?-1:0;oa=ka}qD(l,oa,na);n=aE(c[j>>2]|0,k)|0;dD(l,c[k>>2]|0,n);mJb(r);BQ(g,c[q>>2]|0,-1248413064,1313450856);if(da>>>0<(c[(c[y>>2]|0)+1132>>2]|0)>>>0){m=da}else{break d}}if((ca|0)==83){i=h;return x|0}aE(c[q>>2]|0,s)|0;mJb(s);x=ma;i=h;return x|0}}while(0);ma=u+3744|0;c[ma>>2]=-2147483648;c[ma+4>>2]=-1;c[X>>2]=(c[X>>2]|0)+1;x=0;i=h;return x|0}function BQ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;c[g>>2]=0;h=aE(b,g)|0;b=h+4|0;if((b|0)>4096){yD(a,448,0);sD(a,d,e);qD(a,b,(b|0)<0|0?-1:0);kD(a,xD(a)|0)}else{sD(a,d,e);qD(a,b,(b|0)<0|0?-1:0)}yD(a,448,0);dD(a,c[g>>2]|0,h);kD(a,xD(a)|0);kJb(c[g>>2]|0);i=f;return}function CQ(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;i=i+272|0;j=h|0;k=h+264|0;l=c[b+(c[f+32>>2]<<2)>>2]|0;if((_D(j)|0)<0){i=h;return}b=f+44|0;a:do{if((c[b>>2]|0)>0){m=f+40|0;n=(g|0)==0;o=h+8|0;p=l+8|0;q=0;r=0;b:while(1){s=c[m>>2]|0;t=c[s+(r*12|0)>>2]|0;u=c[s+(r*12|0)+4>>2]|0;v=t+u|0;w=c[s+(r*12|0)+8>>2]|0;c:do{if(n){switch(w|0){case 2:{s=t+4|0;x=t;y=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;if((y&1|0)==0){z=q;A=s}else{x=c[j>>2]|0;qD(x,8,0);dD(x,2432736,8);x=c[j>>2]|0;B=s;s=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=s;C=xrc(B<<1|0>>>31,0<<1|B>>>31,(s|0)!=0|0,0)|0;qD(x,C,G);z=q+1|0;A=t+8|0}if((y&2|0)==0){D=z;E=A}else{C=c[j>>2]|0;qD(C,13,0);dD(C,2424e3,13);qD(c[j>>2]|0,4,0);C=c[j>>2]|0;qD(C,3,0);dD(C,2413208,3);qD(e,8,0);dD(c[j>>2]|0,A,8);D=z+1|0;E=A+8|0}if((y&4|0)==0){F=D;H=E}else{C=c[j>>2]|0;qD(C,10,0);dD(C,2405512,10);C=c[j>>2]|0;x=E;s=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=s;B=xrc(x<<1|0>>>31,0<<1|x>>>31,(s|0)!=0|0,0)|0;qD(C,B,G);F=D+1|0;H=E+4|0}if((y&8|0)==0){I=F;break c}y=c[j>>2]|0;qD(y,5,0);dD(y,2398120,5);y=c[j>>2]|0;B=H;C=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=C;qD(y,xrc(B<<1|0>>>31,0<<1|B>>>31,(C|0)!=0|0,0)|0,G);C=c[j>>2]|0;qD(C,6,0);dD(C,2391032,6);C=c[j>>2]|0;B=H+4|0;y=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=y;qD(C,xrc(B<<1|0>>>31,0<<1|B>>>31,(y|0)!=0|0,0)|0,G);I=F+2|0;break c;break};case 72:case 77:{I=q;break c;break};case 70:{y=t;if((d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)==0){J=q}else{B=c[j>>2]|0;qD(B,9,0);dD(B,2384192,9);B=c[j>>2]|0;C=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=C;s=xrc(y<<1|0>>>31,0<<1|y>>>31,(C|0)!=0|0,0)|0;qD(B,s,G);J=q+1|0}s=t+4|0;if((d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)==0){I=J;break c}B=c[j>>2]|0;qD(B,7,0);dD(B,2377376,7);B=c[j>>2]|0;C=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=C;qD(B,xrc(s<<1|0>>>31,0<<1|s>>>31,(C|0)!=0|0,0)|0,G);I=J+1|0;break c;break};case 1:{C=c[j>>2]|0;qD(C,9,0);dD(C,2506344,9);break};case 0:{C=c[j>>2]|0;qD(C,7,0);dD(C,2520736,7);break};case 74:{C=t;s=C|0;B=C+4|0;C=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;s=je(C|0)|0;Rb(o|0,256,2492104,(K=i,i=i+16|0,c[K>>2]=s,c[K+8>>2]=B,K)|0)|0;i=K;B=c[j>>2]|0;s=lrc(o|0)|0;qD(B,s,(s|0)<0|0?-1:0);dD(B,o,s);break};default:{Rb(o|0,256,2482160,(K=i,i=i+16|0,c[K>>2]=(c[(c[p>>2]|0)+88>>2]&8388608|0)!=0?2471016:2463176,c[K+8>>2]=w,K)|0)|0;i=K;s=c[j>>2]|0;B=lrc(o|0)|0;qD(s,B,(B|0)<0|0?-1:0);dD(s,o,B)}}qD(c[j>>2]|0,4,0);B=c[j>>2]|0;qD(B,3,0);dD(B,2447896,3);B=c[(c[m>>2]|0)+(r*12|0)+4>>2]|0;qD(c[j>>2]|0,B,(B|0)<0|0?-1:0);dD(c[j>>2]|0,t,c[(c[m>>2]|0)+(r*12|0)+4>>2]|0);I=q+1|0}else{if(!((w|0)==77|(w|0)==72)){I=q;break}if((u|0)==0){L=31;break b}if((a[t+(u-1)|0]|0)!=0){L=31;break b}if((u|0)>0){M=t;N=q}else{I=q;break}while(1){B=lrc(M|0)|0;s=M+(B+1)|0;if(!(s>>>0<v>>>0)){L=31;break b}C=c[j>>2]|0;qD(C,B,(B|0)<0|0?-1:0);dD(C,M,B);qD(c[j>>2]|0,2,0);C=c[j>>2]|0;y=lrc(s|0)|0;qD(C,y,(y|0)<0|0?-1:0);dD(C,s,y);y=M+(B+2+(lrc(s|0)|0))|0;s=N+1|0;if(y>>>0<v>>>0){M=y;N=s}else{I=s;break}}}}while(0);v=r+1|0;if((v|0)<(c[b>>2]|0)){q=I;r=v}else{O=I;break a}}if((L|0)==31){i=h;return}}else{O=0}}while(0);qD(e,O,(O|0)<0|0?-1:0);O=aE(c[j>>2]|0,k)|0;dD(e,c[k>>2]|0,O);mJb(k);i=h;return}function DQ(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=c[i+36>>2]&1;k=(c[i+32>>2]|0)==(d[h+2|0]|0|0)?j:j|16;j=c[i+28>>2]|0;l=((j|0)/(e[h+4>>1]|0|0)|0|0)==0?k:k|32;k=i+8|0;m=g+8|0;n=xrc(c[k>>2]|0,c[k+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;m=G;k=b[h+8>>1]|0;o=(n|0)==(k<<16>>16|0)&(m|0)==((k<<16>>16<0|0?-1:0)|0)?l:l|8;if((c[i+44>>2]|0)==0){p=o}else{p=(c[f+3780>>2]|0)>3?o|256:o}o=p|64;l=j>>>0>c[f+3736>>2]<<1>>>0?o:p;p=-1;k=(m|0)>(p|0)|(m|0)==(p|0)&n>>>0>-1>>>0;p=xrc(0,0,n,m)|0;q=k?m:G;m=c[g+28>>2]|0;g=(m|0)<0|0?-1:0;r=(q|0)>(g|0)|(q|0)==(g|0)&(k?n:p)>>>0>m>>>0?o:l;l=a[h+11|0]|0;o=l&255;m=d[f+3076+o|0]|0;do{if((j|0)>=(m|0)){if(!((j|0)<4097|l<<24>>24==0)){break}if((grc(c[i+24>>2]|0,c[f+3204+(o<<2)>>2]|0,m)|0)==0){s=r}else{break}t=h|0;u=b[t>>1]|0;v=u&65535;w=v&4096;x=w|s;return x|0}}while(0);s=r|1024;t=h|0;u=b[t>>1]|0;v=u&65535;w=v&4096;x=w|s;return x|0}function EQ(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+64|0;k=j|0;l=k|0;m=k;n=k;k=c[f+412>>2]|0;do{if((g|0)>4096){o=0}else{a[m+2|0]=1;a[m+1|0]=0;a[n]=0;p=c[f+48>>2]|0;if((p|0)==13){if((h|0)!=0){o=3;break}a[n+3|0]=-74;o=4;break}else if((p|0)==86017|(p|0)==86016){q=(p|0)==86017?3:2;r=(k|0)<28e3|0;s=r+((k|0)<14e3)|0;t=k<<s;if((t|0)<38050){u=2}else{u=(t|0)>46049|0}t=q-1|0;v=(e[1965176+(u<<1)>>1]|0)>>>(s>>>0)<<r;s=2;while(1){if((s|0)>=30){break}if(((((e[1965184+(r*90|0)+(t*30|0)+(s>>1<<1)>>1]|0)*144e3|0|0)/(v|0)|0)+(s&1)|0)==(g|0)){break}else{s=s+1|0}}c[l>>2]=je(4-q<<17|r<<19^-458752|0)|0;if((g|0)<1){o=2;break}o=(s|0)==30?-1:2;break}else if((p|0)==1|(p|0)==2|(p|0)==28){o=3;break}else{o=0;break}}}while(0);g=b+3204|0;l=c[b+3752>>2]|0;if((l|0)>1){w=1}else{x=0;i=j;return x|0}while(1){if((o|0)==(d[b+(w+3076)|0]|0|0)){if((grc(n,c[g+(w<<2)>>2]|0,o)|0)==0){x=w;y=17;break}}u=w+1|0;if((u|0)<(l|0)){w=u}else{x=0;y=17;break}}if((y|0)==17){i=j;return x|0}return 0}function FQ(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((grc(b,2483104,12)|0)==0){d=100;return d|0}a=(grc(b,2261736,12)|0)==0;d=a?100:0;return d|0}function GQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;b=i;i=i+24|0;d=b+16|0;e=d;f=i;i=i+8|0;g=f;j=c[a+12>>2]|0;l=c[a+16>>2]|0;m=b|0;AD(l,m,12)|0;n=(grc(m,2261736,12)|0)==0;hD(l,5,0)|0;hD(l,3,0)|0;m=FD(l)|0;o=FD(l)|0;FD(l)|0;FD(l)|0;zD(l)|0;hD(l,3,0)|0;p=GD(l)|0;q=G;r=(c[k>>2]=p,c[k+4>>2]=q,+h[k>>3]);s=r>.9999&r<1.0001?1.3333333333333333:r;q=GD(l)|0;p=G;r=(c[k>>2]=q,c[k+4>>2]=p,+h[k>>3]);p=FD(l)|0;q=FD(l)|0;FD(l)|0;FD(l)|0;do{if((p|0)==0){c[j>>2]=-1;t=0}else{u=ZX(a,0)|0;if((u|0)==0){v=-12;i=b;return v|0}else{c[j>>2]=c[u>>2];w=c[u+8>>2]|0;c[w+8>>2]=0;c[w+48>>2]=85;c[w+120>>2]=m;c[w+124>>2]=o;c[w+792>>2]=10;AKb(e,+(o|0)*s/+(m|0),1e4);w=u+80|0;x=c[d+4>>2]|0;c[w>>2]=c[d>>2];c[w+4>>2]=x;AKb(g,r,6e4);x=u+92|0;w=c[f>>2]|0;y=c[f+4>>2]|0;c[x>>2]=w;c[x+4>>2]=y;x=u+412|0;c[x>>2]=w;c[x+4>>2]=y;_X(u,32,1,1e3);t=u;break}}}while(0);do{if((q|0)==0){c[j+4>>2]=-1;z=0}else{f=ZX(a,0)|0;if((f|0)==0){v=-12;i=b;return v|0}else{c[j+4>>2]=c[f>>2];g=c[f+8>>2]|0;c[g+8>>2]=1;c[g+48>>2]=65536;c[g+416>>2]=2;d=g+448|0;c[d>>2]=3;c[d+4>>2]=0;c[g+412>>2]=44100;c[g+72>>2]=1411200;c[g+432>>2]=4;c[g+792>>2]=16;_X(f,32,1,1e3);z=f;break}}}while(0);a=(t|0)!=0;q=n^1;a:do{if(!(q&(a^1))){if((jD(l)|0)!=0){break}f=t+8|0;b:do{if(a){c:while(1){g=zD(l)|0;do{if((g|0)==88){hD(l,7,0)|0;d=(FD(l)|0)&16777215;if((d|0)==512){break b}else{A=d}}else if((g|0)==68){d=zD(l)|0;hD(l,6,0)|0;m=(FD(l)|0)&16777215;if((d|0)!=82){A=m;break}d=c[f>>2]|0;o=d+96|0;if((c[o>>2]|0)==0){B=d}else{mJb(o);o=c[f>>2]|0;c[o+100>>2]=0;B=o}C=QX(B,l,m)|0;if((C|0)<0|q){break c}else{A=0}}else if((g|0)==82){A=11}else{hD(l,7,0)|0;A=(FD(l)|0)&16777215}}while(0);hD(l,A,0)|0;if((jD(l)|0)!=0){break a}}g=C>>31&-12;if((g|0)<0){v=g}else{break a}i=b;return v|0}else{if(n){while(1){g=zD(l)|0;if((g|0)==88){hD(l,7,0)|0;m=(FD(l)|0)&16777215;if((m|0)==512){break b}else{D=m}}else if((g|0)==68){zD(l)|0;hD(l,6,0)|0;D=(FD(l)|0)&16777215}else if((g|0)==82){D=11}else{hD(l,7,0)|0;D=(FD(l)|0)&16777215}hD(l,D,0)|0;if((jD(l)|0)!=0){break a}}}else{while(1){g=zD(l)|0;if((g|0)==68){zD(l)|0;hD(l,6,0)|0;E=(FD(l)|0)&16777215}else if((g|0)==82){E=11}else if((g|0)==88){hD(l,7,0)|0;g=(FD(l)|0)&16777215;if((g|0)==512){break b}else{E=g}}else{hD(l,7,0)|0;E=(FD(l)|0)&16777215}hD(l,E,0)|0;if((jD(l)|0)!=0){break a}}}}}while(0);FD(l)|0;do{if(a){g=FD(l)|0;c[(c[f>>2]|0)+52>>2]=g;m=JX(1409152,g)|0;g=c[f>>2]|0;o=g+48|0;c[o>>2]=m;if((c[g+52>>2]|0)!=1196444242){break}c[o>>2]=85}else{hD(l,4,0)|0;}}while(0);if((z|0)==0){hD(l,16,0)|0;}else{f=FD(l)|0;o=z+8|0;c[(c[o>>2]|0)+52>>2]=f;f=FD(l)|0;c[(c[o>>2]|0)+412>>2]=f;f=FD(l)|0;c[(c[o>>2]|0)+792>>2]=f;f=FD(l)|0;g=c[o>>2]|0;c[g+416>>2]=f;f=g+448|0;c[f>>2]=0;c[f+4>>2]=0;f=PS(c[g+52>>2]|0,c[g+792>>2]|0)|0;do{if((f|0)==0){g=JX(777472,c[(c[o>>2]|0)+52>>2]|0)|0;if((g|0)!=65536){F=g;break}F=KX(c[(c[o>>2]|0)+792>>2]|0,0,0,-2)|0}else{F=f}}while(0);c[(c[o>>2]|0)+48>>2]=F;c[z+236>>2]=1}hD(l,488,0)|0;}}while(0);if((t|0)==0){H=0}else{H=(c[(c[t+8>>2]|0)+48>>2]|0)==85|0}c[j+8>>2]=H;v=0;i=b;return v|0}function HQ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f|0;h=c[b+12>>2]|0;j=c[b+16>>2]|0;if((jD(j)|0)!=0){k=-5;i=f;return k|0}l=h+8|0;m=g|0;n=g+8|0;o=h;p=b;b=h+4|0;a:while(1){q=(c[l>>2]|0)!=0?12:0;r=fD(j,0,0,1)|0;s=G;t=AD(j,m,12)|0;if((t|0)<12){u=4;break}h=d[m]|0;v=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)&16777215;do{if((h|0)==65){if((c[b>>2]|0)>=0){u=17;break a}KIb(p,16,2314616,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;hD(j,v,0)|0;}else if((h|0)==86){u=8}else if((h|0)==68){if((c[l>>2]|0)!=0){u=8;break}hD(j,v,0)|0;}else if((h|0)!=82){hD(j,v,0)|0;}}while(0);if((u|0)==8){u=0;if((c[o>>2]|0)>=0){u=10;break}KIb(p,16,2385128,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;hD(j,v,0)|0;}if((jD(j)|0)!=0){k=-5;u=20;break}}if((u|0)==4){k=(t|0)<0?t:-5;i=f;return k|0}else if((u|0)==10){t=K1(e,v+q|0)|0;if((t|0)<0){k=t;i=f;return k|0}t=e+64|0;c[t>>2]=r;c[t+4>>2]=s;t=e+36|0;c[t>>2]=(a[g+2|0]|0)==0|c[t>>2];t=g+4|0;w=e+8|0;c[w>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[w+4>>2]=0;c[e+32>>2]=c[o>>2];o=e+24|0;nrc(c[o>>2]|0,m|0,q)|0;m=AD(j,(c[o>>2]|0)+q|0,v)|0;if((m|0)<0){P1(e);k=m;i=f;return k|0}if((m|0)>=(v|0)){k=0;i=f;return k|0}M1(e,m+q|0);k=0;i=f;return k|0}else if((u|0)==17){q=fX(j,e,v)|0;v=e+36|0;c[v>>2]=c[v>>2]|1;v=e+64|0;c[v>>2]=r;c[v+4>>2]=s;s=g+4|0;g=e+8|0;c[g>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[g+4>>2]=0;c[e+32>>2]=c[b>>2];k=(q|0)<0?q:0;i=f;return k|0}else if((u|0)==20){i=f;return k|0}return 0}function IQ(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+16|0;k=j|0;l=c[b+12>>2]|0;m=b+16|0;n=c[m>>2]|0;o=fD(n,c[f>>2]|0,c[f+4>>2]|0,0)|0;p=G;q=0;if((p|0)<(q|0)|(p|0)==(q|0)&o>>>0<0>>>0){r=-2147483648;s=0;i=j;return(G=r,s)|0}o=c[m>>2]|0;if((jD(o)|0)==0){t=0}else{r=-2147483648;s=0;i=j;return(G=r,s)|0}a:while(1){q=fD(o,0,0,1)|0;p=G;if(!((p|0)<(h|0)|(p|0)==(h|0)&q>>>0<g>>>0)){r=-2147483648;s=0;u=19;break}q=zD(o)|0|t<<8;do{if((q|0)==1381263978){p=JD(o)|0;if((p|0)!=1785358954){v=p;break}p=JD(o)|0;if((p|0)==1785358954){u=7;break a}else{v=p}}else{v=q}}while(0);if((jD(o)|0)==0){t=v}else{r=-2147483648;s=0;u=19;break}}if((u|0)==7){if((jD(n)|0)!=0){r=-2147483648;s=0;i=j;return(G=r,s)|0}v=k|0;t=k+8|0;o=k+2|0;q=l+4|0;while(1){p=fD(n,0,0,1)|0;w=G;if(!((w|0)<(h|0)|(w|0)==(h|0)&p>>>0<g>>>0)){r=-2147483648;s=0;u=19;break}if((AD(n,v,12)|0)<12){r=-2147483648;s=0;u=19;break}p=a[v]|0;w=p&255;x=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24)&16777215;if((w|0)==65|(w|0)==86){if(p<<24>>24==86){y=(a[o]|0)==0|0;z=l}else{y=1;z=q}if((c[z>>2]|0)==(e|0)){u=16;break}else{u=17}}else if((w|0)!=82){u=17}if((u|0)==17){u=0;hD(n,x,0)|0;}if((jD(n)|0)!=0){r=-2147483648;s=0;u=19;break}}if((u|0)==16){n=fD(c[m>>2]|0,0,0,1)|0;m=wrc(n,G,-12,-1)|0;n=G;z=k+4|0;k=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=0;xX(c[(c[b+28>>2]|0)+(e<<2)>>2]|0,m,n,k,z,x+12|0,0,y)|0;c[f>>2]=m;c[f+4>>2]=n;r=z;s=k;i=j;return(G=r,s)|0}else if((u|0)==19){i=j;return(G=r,s)|0}}else if((u|0)==19){i=j;return(G=r,s)|0}return 0}function JQ(a){a=a|0;var b=0,e=0;b=c[a+4>>2]|0;do{if((grc(2482152,b,5)|0)==0){if((d[b+5|0]|0)>>>0<8>>>0){e=100}else{break}return e|0}}while(0);e=0;return e|0}function KQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;b=i;i=i+8|0;d=b|0;e=a+12|0;f=c[e>>2]|0;c[f+12>>2]=-1;g=f+8|0;do{h=QQ(a,0,0,0,0)|0;if((h|0)<0){j=3;break}}while((c[g>>2]|0)==0);if((j|0)==3){g=c[e>>2]|0;k=g+4|0;if((c[k>>2]|0)>0){l=g;m=0;do{mJb((c[l>>2]|0)+(m*400|0)|0);n=c[l>>2]|0;o=c[n+(m*400|0)+84>>2]|0;do{if((o|0)==0){p=n}else{q=c[o+32>>2]|0;if((q|0)==0){p=n;break}re[q&1023](a,m);p=c[l>>2]|0}}while(0);mJb(p+(m*400|0)+392|0);mJb((c[l>>2]|0)+(m*400|0)+384|0);m=m+1|0;}while((m|0)<(c[k>>2]|0))}mJb(g);r=h;i=b;return r|0}h=f+4|0;a:do{if((c[h>>2]|0)>0){g=f;k=a;m=a+28|0;l=a+1156|0;p=0;b:while(1){n=c[g>>2]|0;do{if((c[n+(p*400|0)+88>>2]|0)<0){KIb(k,16,2506272,(s=i,i=i+8|0,c[s>>2]=p,s)|0);i=s;c[(c[g>>2]|0)+(p*400|0)+84>>2]=0}else{o=c[n+(p*400|0)+84>>2]|0;if((o|0)==0){break}q=c[n+(p*400|0)+376>>2]|0;t=c[o+28>>2]|0;if((q|0)>=(t|0)){break}KIb(k,24,2492040,(s=i,i=i+24|0,c[s>>2]=p,c[s+8>>2]=t,c[s+16>>2]=q,s)|0);i=s;if((c[l>>2]&8|0)!=0){r=-1094995529;break b}}}while(0);q=n+(p*400|0)+40|0;t=c[q>>2]|0;o=c[q+4>>2]|0;if(!((t|0)==(-1|0)&(o|0)==(-1|0))){q=c[(c[c[e>>2]>>2]|0)+(p*400|0)+84>>2]|0;do{if((q|0)==0){u=o;v=t}else{w=c[q+20>>2]|0;if((w|0)==0){u=o;v=t;break}x=Xe[w&511](a,p,t,o,0)|0;u=G;v=x}}while(0);o=(c[(c[m>>2]|0)+(p<<2)>>2]|0)+48|0;c[o>>2]=v;c[o+4>>2]=u;o=n+(p*400|0)+48|0;c[o>>2]=v;c[o+4>>2]=u}p=p+1|0;if((p|0)>=(c[h>>2]|0)){break a}}i=b;return r|0}}while(0);h=c[e>>2]|0;u=a+16|0;v=c[u>>2]|0;if((c[v+88>>2]|0)==0){r=0;i=b;return r|0}s=a+1064|0;if(!((c[s>>2]|0)==0&(c[s+4>>2]|0)==(-2147483648|0))){r=0;i=b;return r|0}s=iD(v)|0;v=G;f=0;if((v|0)<(f|0)|(v|0)==(f|0)&s>>>0<0>>>0){r=0;i=b;return r|0}f=0;p=(v|0)>(f|0)|(v|0)==(f|0)&s>>>0>65307>>>0;f=wrc(s,v,-65307,-1)|0;v=p?G:0;UQ(a);fD(c[u>>2]|0,p?f:0,v,0)|0;v=h+16|0;c[v>>2]=-1;c[v+4>>2]=-1;c:do{if((SQ(a,d)|0)==0){v=h;f=a+28|0;p=0;while(1){d:while(1){s=c[d>>2]|0;m=c[v>>2]|0;l=m+(s*400|0)+32|0;k=c[l>>2]|0;g=c[l+4>>2]|0;do{if(!((k|0)==(-1|0)&(g|0)==(-1|0)|(k|0)==0&(g|0)==0)){if((c[m+(s*400|0)+84>>2]|0)==0){break}l=c[(c[c[e>>2]>>2]|0)+(s*400|0)+84>>2]|0;do{if((l|0)==0){y=g;z=k;A=s}else{o=c[l+20>>2]|0;if((o|0)==0){y=g;z=k;A=s;break}t=Xe[o&511](a,s,k,g,0)|0;y=G;z=t;A=c[d>>2]|0}}while(0);l=c[(c[f>>2]|0)+(A<<2)>>2]|0;B=l+56|0;c[B>>2]=z;c[B+4>>2]=y;t=l+48|0;C=c[t>>2]|0;D=c[t+4>>2]|0;if(!((C|0)==0&(D|0)==(-2147483648|0))){j=37;break d}E=(c[v>>2]|0)+(A*400|0)+368|0;if((c[E>>2]|0)==0){j=40;break d}}}while(0);if((SQ(a,d)|0)!=0){F=p;break c}}if((j|0)==37){j=0;n=xrc(z,y,C,D)|0;c[B>>2]=n;c[B+4>>2]=G;n=(c[v>>2]|0)+(A*400|0)+368|0;g=p-((c[n>>2]|0)==-1)|0;c[n>>2]=1;H=g}else if((j|0)==40){j=0;c[E>>2]=-1;H=p+1|0}if((SQ(a,d)|0)==0){p=H}else{F=H;break}}}else{F=0}}while(0);VQ(c[e>>2]|0,c[u>>2]|0);UQ(a);H=a+1248|0;fD(c[u>>2]|0,c[H>>2]|0,c[H+4>>2]|0,0)|0;PQ(a);e:do{if((F|0)>0){H=a+28|0;E=h;A=F;do{if((QQ(a,d,0,0,0)|0)!=0){break e}f:while(1){B=c[d>>2]|0;g:do{if((B|0)>=0){D=c[c[e>>2]>>2]|0;C=D+(B*400|0)+48|0;y=c[C>>2]|0;z=c[C+4>>2]|0;if((y|0)==0&(z|0)==(-2147483648|0)){I=-2147483648;J=0}else{c[C>>2]=0;c[C+4>>2]=-2147483648;I=z;J=y}y=D+(B*400|0)+56|0;if(!((c[y>>2]|0)==0&(c[y+4>>2]|0)==(-2147483648|0))){c[y>>2]=0;c[y+4>>2]=-2147483648}do{if((c[D+(B*400|0)+360>>2]|0)==0){K=I;L=J;M=B}else{z=D+(B*400|0)+32|0;p=c[z>>2]|0;v=c[z+4>>2]|0;if((p|0)==(-1|0)&(v|0)==(-1|0)){K=I;L=J;M=B;break}f=c[D+(B*400|0)+84>>2]|0;do{if((f|0)==0){j=58}else{g=c[f+20>>2]|0;n=(g|0)==0;if((c[f+24>>2]|0)==0){if(n){j=58;break}k=Xe[g&511](a,B,p,v,y)|0;N=G;O=k;j=60;break}else{if(n){P=v;Q=p;break}n=Xe[g&511](a,B,p,v,0)|0;P=G;Q=n;break}}}while(0);do{if((j|0)==58){j=0;if((y|0)==0){N=v;O=p;j=60;break}c[y>>2]=p;c[y+4>>2]=v;N=v;O=p;j=60}}while(0);if((j|0)==60){j=0;c[C>>2]=O;c[C+4>>2]=N;P=I;Q=J}c[z>>2]=-1;c[z+4>>2]=-1;K=P;L=Q;M=c[d>>2]|0}}while(0);R=c[(c[H>>2]|0)+(M<<2)>>2]|0;C=R+48|0;y=(c[C>>2]|0)==0&(c[C+4>>2]|0)==(-2147483648|0);do{if((L|0)==0&(K|0)==(-2147483648|0)){if(y){break g}}else{if(!y){break}S=(c[E>>2]|0)+(M*400|0)+368|0;if((c[S>>2]|0)==0){j=67;break f}else{break g}}}while(0);T=(c[E>>2]|0)+(M*400|0)+368|0;if((c[T>>2]|0)==0){j=68;break f}}}while(0);if((QQ(a,d,0,0,0)|0)!=0){break e}}if((j|0)==67){j=0;B=R+56|0;y=xrc(c[B>>2]|0,c[B+4>>2]|0,L,K)|0;c[B>>2]=y;c[B+4>>2]=G;c[S>>2]=1}else if((j|0)==68){j=0;c[T>>2]=1}A=A-1|0;}while((A|0)>0)}}while(0);VQ(c[e>>2]|0,c[u>>2]|0);r=0;i=b;return r|0}function LQ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+40|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=b+1300|0;if((c[m>>2]|0)!=0){PQ(b);c[m>>2]=0}m=QQ(b,g,h,j,k)|0;if((m|0)<0){n=m;i=f;return n|0}m=b+28|0;o=b+12|0;p=b;a:while(1){q=c[g>>2]|0;do{if((q|0)>=0){if((c[(c[m>>2]|0)+(q<<2)>>2]|0)==0){break}r=c[c[o>>2]>>2]|0;s=RQ(b,q,l)|0;t=G;u=c[g>>2]|0;v=c[h>>2]|0;w=c[c[o>>2]>>2]|0;x=w+(u*400|0)|0;do{if((c[j>>2]|0)!=0){z=c[(c[(c[(c[m>>2]|0)+(u<<2)>>2]|0)+8>>2]|0)+48>>2]|0;if((z|0)==31){A=c[w+(u*400|0)+20>>2]|0;B=((d[(c[x>>2]|0)+v|0]|0)>>>6&1^1)&255^A&1;C=A}else if((z|0)==141){z=c[w+(u*400|0)+20>>2]|0;B=(a[(c[x>>2]|0)+v|0]&1^1)&255^z&1;C=z}else{break}if((B|0)==0){break}z=C^1;c[w+(u*400|0)+20>>2]=z;KIb(p,24,2384984,(A=i,i=i+8|0,c[A>>2]=(z&1|0)!=0?10230280:2261728,A)|0);i=A}}while(0);D=r+(q*400|0)+364|0;if((c[D>>2]|0)==0){break a}if((c[r+(q*400|0)+20>>2]&1|0)!=0){break a}}}while(0);u=QQ(b,g,h,j,k)|0;if((u|0)<0){n=u;E=24;break}}if((E|0)==24){i=f;return n|0}c[D>>2]=0;D=K1(e,c[j>>2]|0)|0;if((D|0)<0){n=D;i=f;return n|0}c[e+32>>2]=c[g>>2];nrc(c[e+24>>2]|0,(c[r+(q*400|0)>>2]|0)+(c[h>>2]|0)|0,c[j>>2]|0)|0;h=e+8|0;c[h>>2]=s;c[h+4>>2]=t;t=c[l+4>>2]|0;h=e+16|0;c[h>>2]=c[l>>2];c[h+4>>2]=t;c[e+36>>2]=c[r+(q*400|0)+20>>2];c[e+48>>2]=c[r+(q*400|0)+24>>2];t=c[k+4>>2]|0;h=e+64|0;c[h>>2]=c[k>>2];c[h+4>>2]=t;t=r+(q*400|0)+380|0;do{if((c[t>>2]|0)!=0){h=U1(e,70,10)|0;if((h|0)!=0){k=h+4|0;y=c[t>>2]|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[t>>2]=0;break}P1(e);kJb(e);n=-12;i=f;return n|0}}while(0);t=r+(q*400|0)+384|0;if((c[t>>2]|0)!=0){k=r+(q*400|0)+388|0;q=U1(e,77,c[k>>2]|0)|0;nrc(q|0,c[t>>2]|0,c[k>>2]|0)|0;mJb(t);c[k>>2]=0}n=c[j>>2]|0;i=f;return n|0}function MQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+12>>2]|0;d=b+4|0;if((c[d>>2]|0)<=0){mJb(b);return 0}e=b;f=0;do{mJb((c[e>>2]|0)+(f*400|0)|0);g=c[e>>2]|0;h=c[g+(f*400|0)+84>>2]|0;do{if((h|0)==0){i=g}else{j=c[h+32>>2]|0;if((j|0)==0){i=g;break}re[j&1023](a,f);i=c[e>>2]|0}}while(0);mJb(i+(f*400|0)+392|0);mJb((c[e>>2]|0)+(f*400|0)+384|0);f=f+1|0;}while((f|0)<(c[d>>2]|0));mJb(b);return 0}function NQ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=c[a+12>>2]|0;j=h;k=c[j>>2]|0;if((c[h+4>>2]|0)<=(b|0)){KIb(0,0,2554552,(h=i,i=i+24|0,c[h>>2]=2536672,c[h+8>>2]=2520680,c[h+16>>2]=865,h)|0);i=h;Hd();return 0}PQ(a);do{if((c[(c[(c[(c[a+28>>2]|0)+(b<<2)>>2]|0)+8>>2]|0)+8>>2]|0)==0){if((f&4|0)!=0){break}c[k+(b*400|0)+364>>2]=1}}while(0);k=DX(a,b,d,e,f)|0;if((k|0)>=0){i=g;return k|0}c[(c[j>>2]|0)+(b*400|0)+364>>2]=0;i=g;return k|0}function OQ(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;n=b+12|0;o=c[n>>2]|0;p=c[b+16>>2]|0;fD(p,c[f>>2]|0,c[f+4>>2]|0,0)|0;PQ(b);q=o;o=b+28|0;r=b;s=-1;t=-1;a:while(1){u=fD(p,0,0,1)|0;v=G;if((v|0)>(h|0)|(v|0)==(h|0)&u>>>0>g>>>0){w=-2147483648;x=0;y=37;break}u=-1;v=(s|0)>(u|0)|(s|0)==(u|0)&t>>>0>-1>>>0;while(1){if((QQ(b,k,l,m,f)|0)!=0){w=-2147483648;x=0;y=37;break a}if((c[k>>2]|0)!=(e|0)){s=s;t=t;continue a}u=c[q>>2]|0;if((c[u+(e*400|0)+80>>2]&6|0)==4){if((c[u+(e*400|0)+84>>2]|0)!=1335024){y=9}}else{y=9}if((y|0)==9){y=0;z=c[c[n>>2]>>2]|0;A=z+(e*400|0)+48|0;B=c[A>>2]|0;C=c[A+4>>2]|0;if((B|0)==0&(C|0)==(-2147483648|0)){D=-2147483648;E=0}else{c[A>>2]=0;c[A+4>>2]=-2147483648;D=C;E=B}B=z+(e*400|0)+56|0;if(!((c[B>>2]|0)==0&(c[B+4>>2]|0)==(-2147483648|0))){c[B>>2]=0;c[B+4>>2]=-2147483648}do{if((c[z+(e*400|0)+360>>2]|0)==0){F=D;H=E;I=e;J=z}else{C=z+(e*400|0)+32|0;K=c[C>>2]|0;L=c[C+4>>2]|0;if((K|0)==(-1|0)&(L|0)==(-1|0)){F=D;H=E;I=e;J=z;break}M=c[z+(e*400|0)+84>>2]|0;do{if((M|0)==0){y=21}else{N=c[M+20>>2]|0;O=(N|0)==0;if((c[M+24>>2]|0)==0){if(O){y=21;break}P=Xe[N&511](b,e,K,L,B)|0;Q=G;R=P;y=23;break}else{if(O){S=L;T=K;break}O=Xe[N&511](b,e,K,L,0)|0;S=G;T=O;break}}}while(0);do{if((y|0)==21){y=0;if((B|0)==0){Q=L;R=K;y=23;break}c[B>>2]=K;c[B+4>>2]=L;Q=L;R=K;y=23}}while(0);if((y|0)==23){y=0;c[A>>2]=R;c[A+4>>2]=Q;S=D;T=E}c[C>>2]=-1;c[C+4>>2]=-1;F=S;H=T;I=c[k>>2]|0;J=c[c[n>>2]>>2]|0}}while(0);A=c[l>>2]|0;B=J+(I*400|0)|0;do{if((c[m>>2]|0)!=0){z=c[(c[(c[(c[o>>2]|0)+(I<<2)>>2]|0)+8>>2]|0)+48>>2]|0;if((z|0)==31){K=c[J+(I*400|0)+20>>2]|0;U=((d[(c[B>>2]|0)+A|0]|0)>>>6&1^1)&255^K&1;V=K}else if((z|0)==141){z=c[J+(I*400|0)+20>>2]|0;U=(a[(c[B>>2]|0)+A|0]&1^1)&255^z&1;V=z}else{break}if((U|0)==0){break}z=V^1;c[J+(I*400|0)+20>>2]=z;KIb(r,24,2384984,(K=i,i=i+8|0,c[K>>2]=(z&1|0)!=0?10230280:2261728,K)|0);i=K}}while(0);if((c[u+(e*400|0)+20>>2]&1|0)!=0){y=32;break}if((c[u+(e*400|0)+364>>2]|0)==0){W=s;X=t;break}if(v){y=35;break}}A=fD(p,0,0,1)|0;B=G;if((B|0)>(h|0)|(B|0)==(h|0)&A>>>0>g>>>0){w=-2147483648;x=0;y=37;break a}}if((y|0)==32){y=0;W=c[f+4>>2]|0;X=c[f>>2]|0}else if((y|0)==35){y=0;c[f>>2]=t;c[f+4>>2]=s;W=s;X=t}if((H|0)==0&(F|0)==(-2147483648|0)){s=W;t=X}else{w=F;x=H;y=37;break}}if((y|0)==37){PQ(b);i=j;return(G=w,x)|0}return 0}function PQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[a+12>>2]|0;d=fD(c[a+16>>2]|0,0,0,1)|0;e=G;f=b+4|0;if((c[f>>2]|0)<=0){g=b+16|0;h=g;i=-1;j=-1;k=h|0;c[k>>2]=i;l=h+4|0;c[l>>2]=j;m=b+12|0;n=m;c[n>>2]=-1;return}o=b;p=a+1248|0;a=0;do{q=c[o>>2]|0;c[q+(a*400|0)+8>>2]=0;c[q+(a*400|0)+12>>2]=0;c[q+(a*400|0)+16>>2]=0;r=q+(a*400|0)+32|0;c[r>>2]=-1;c[r+4>>2]=-1;r=q+(a*400|0)+48|0;c[r>>2]=0;c[r+4>>2]=-2147483648;s=q+(a*400|0)+56|0;c[s>>2]=0;c[s+4>>2]=-2147483648;s=q+(a*400|0)+64|0;c[s>>2]=-1;c[s+4>>2]=-1;s=q+(a*400|0)+72|0;c[s>>2]=0;c[s+4>>2]=0;c[q+(a*400|0)+92>>2]=0;c[q+(a*400|0)+96>>2]=0;c[q+(a*400|0)+356>>2]=0;c[q+(a*400|0)+372>>2]=0;s=c[p+4>>2]|0;if(!((e|0)>(s|0)|(e|0)==(s|0)&d>>>0>(c[p>>2]|0)>>>0)){c[r>>2]=0;c[r+4>>2]=0}c[q+(a*400|0)+380>>2]=0;mJb(q+(a*400|0)+384|0);c[q+(a*400|0)+388>>2]=0;a=a+1|0;}while((a|0)<(c[f>>2]|0));g=b+16|0;h=g;i=-1;j=-1;k=h|0;c[k>>2]=i;l=h+4|0;c[l>>2]=j;m=b+12|0;n=m;c[n>>2]=-1;return}function QQ(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;j=i;i=i+8|0;k=j|0;l=c[b+12>>2]|0;m=(e|0)!=0;if(m){c[e>>2]=-1}n=l+12|0;o=l;a:while(1){p=c[n>>2]|0;c[k>>2]=p;if((p|0)<0){while(1){q=SQ(b,k)|0;if((q|0)<0){r=q;s=53;break a}q=c[k>>2]|0;if((q|0)>=0){t=q;break}}}else{t=p}u=c[o>>2]|0;v=u+(t*400|0)+84|0;if((c[v>>2]|0)==0){w=u+(t*400|0)+88|0;if((c[w>>2]|0)>=0){r=0;s=53;break}q=c[u+(t*400|0)>>2]|0;x=c[u+(t*400|0)+8>>2]|0;y=0;z=1305744;while(1){A=d[z+4|0]|0;if((A|0)<=(x|0)){if((grc(q,c[z>>2]|0,A)|0)==0){break}}A=y+1|0;if((A|0)==15){s=13;break a}else{y=A;z=c[774656+(A<<2)>>2]|0}}c[v>>2]=z;if((z|0)==0){break}}B=u+(t*400|0)+96|0;C=c[B>>2]|0;D=u+(t*400|0)+16|0;E=c[D>>2]|0;F=u+(t*400|0)+92|0;y=c[F>>2]|0;q=C;x=E;while(1){if((q|0)>=(y|0)){break}p=q+1|0;c[B>>2]=p;A=a[u+(t*400|0)+100+q|0]|0;G=x+(A&255)|0;c[D>>2]=G;if(A<<24>>24==-1){q=p;x=G}else{s=21;break a}}if((q|0)!=(y|0)){continue}c[n>>2]=-1;c[u+(t*400|0)+356>>2]=(c[D>>2]|0)!=0}if((s|0)==13){c[v>>2]=0}else if((s|0)==21){x=u+(t*400|0)+32|0;if((c[x>>2]|0)==(-1|0)&(c[x+4>>2]|0)==(-1|0)){x=u+(t*400|0)+72|0;z=c[x+4>>2]|0;KIb(b,24,2181856,(H=i,i=i+16|0,c[H>>2]=c[x>>2],c[H+8>>2]=z,H)|0);i=H}c[n>>2]=c[k>>2];c[u+(t*400|0)+356>>2]=0;z=u+(t*400|0)+88|0;do{if((c[z>>2]|0)==0){c[u+(t*400|0)+20>>2]=0;c[u+(t*400|0)+24>>2]=0;x=c[v>>2]|0;do{if((x|0)!=0){G=c[x+16>>2]|0;if((G|0)==0){break}We[G&2047](b,c[k>>2]|0)|0}}while(0);if(m){c[e>>2]=c[k>>2]}if((f|0)!=0){c[f>>2]=c[u+(t*400|0)+12>>2]}if((g|0)!=0){c[g>>2]=c[D>>2]}if((h|0)!=0){x=u+(t*400|0)+64|0;y=c[x+4>>2]|0;c[h>>2]=c[x>>2];c[h+4>>2]=y}y=u+(t*400|0)+12|0;x=(c[y>>2]|0)+(c[D>>2]|0)|0;c[y>>2]=x;c[D>>2]=0;q=u+(t*400|0)+8|0;if((x|0)==(c[q>>2]|0)){c[y>>2]=0;c[q>>2]=0}q=u+(t*400|0)+72|0;y=c[q+4>>2]|0;x=u+(t*400|0)+64|0;c[x>>2]=c[q>>2];c[x+4>>2]=y}else{y=We[c[(c[v>>2]|0)+12>>2]&2047](b,c[k>>2]|0)|0;c[z>>2]=y;if((y|0)!=0){y=u+(t*400|0)+376|0;c[y>>2]=(c[y>>2]|0)+1;y=u+(t*400|0)+12|0;c[y>>2]=(c[y>>2]|0)+(c[D>>2]|0);c[D>>2]=0;break}c[B>>2]=C;c[D>>2]=E;c[l+8>>2]=1;y=b+1248|0;x=c[y>>2]|0;q=c[y+4>>2]|0;if((x|0)==0&(q|0)==0){G=u+(t*400|0)+64|0;p=c[G>>2]|0;A=c[G+4>>2]|0;c[y>>2]=p;c[y+4>>2]=A;I=A;J=p}else{I=q;J=x}x=c[l+4>>2]|0;if((x|0)<=0){break}q=c[o>>2]|0;p=0;A=I;G=J;while(1){if((c[q+(p*400|0)+356>>2]|0)==0){K=A;L=G}else{M=q+(p*400|0)+64|0;N=c[M>>2]|0;O=c[M+4>>2]|0;M=(A|0)>(O|0)|(A|0)==(O|0)&G>>>0>N>>>0;P=M?N:G;N=M?O:A;c[y>>2]=P;c[y+4>>2]=N;K=N;L=P}P=p+1|0;if((P|0)<(x|0)){p=P;A=K;G=L}else{break}}}}while(0);L=u+(t*400|0)+360|0;c[L>>2]=1;K=c[B>>2]|0;B=c[F>>2]|0;F=K;while(1){if((F|0)>=(B|0)){break}if((a[u+(t*400|0)+100+F|0]|0)==-1){F=F+1|0}else{s=50;break}}if((s|0)==50){c[L>>2]=0}if((K|0)!=(B|0)){r=0;i=j;return r|0}c[n>>2]=-1;r=0;i=j;return r|0}else if((s|0)==53){i=j;return r|0}KIb(b,24,2214840,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[w>>2]=0;r=0;i=j;return r|0}function RQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=c[c[a+12>>2]>>2]|0;f=(d|0)!=0;if(f){c[d>>2]=0;c[d+4>>2]=-2147483648}g=e+(b*400|0)+48|0;h=c[g>>2]|0;i=c[g+4>>2]|0;if((h|0)==0&(i|0)==(-2147483648|0)){j=-2147483648;k=0}else{c[g>>2]=0;c[g+4>>2]=-2147483648;j=i;k=h}h=e+(b*400|0)+56|0;i=c[h>>2]|0;l=c[h+4>>2]|0;if(!((i|0)==0&(l|0)==(-2147483648|0))){if(f){c[d>>2]=i;c[d+4>>2]=l}c[h>>2]=0;c[h+4>>2]=-2147483648}if((c[e+(b*400|0)+360>>2]|0)==0){m=j;n=k;return(G=m,n)|0}l=e+(b*400|0)+32|0;i=c[l>>2]|0;f=c[l+4>>2]|0;if((i|0)==(-1|0)&(f|0)==(-1|0)){m=j;n=k;return(G=m,n)|0}o=c[e+(b*400|0)+84>>2]|0;do{if((o|0)==0){p=19}else{e=c[o+20>>2]|0;q=(e|0)==0;if((c[o+24>>2]|0)==0){if(q){p=19;break}r=Xe[e&511](a,b,i,f,h)|0;s=G;t=r;p=21;break}if(!q){q=Xe[e&511](a,b,i,f,d)|0;u=G;v=q;break}if((d|0)==0){u=f;v=i;break}c[d>>2]=i;c[d+4>>2]=f;u=f;v=i}}while(0);do{if((p|0)==19){if((h|0)==0){s=f;t=i;p=21;break}c[h>>2]=i;c[h+4>>2]=f;s=f;t=i;p=21}}while(0);if((p|0)==21){c[g>>2]=t;c[g+4>>2]=s;u=j;v=k}c[l>>2]=-1;c[l+4>>2]=-1;m=u;n=v;return(G=m,n)|0}function SQ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=h;k=b+16|0;l=c[k>>2]|0;m=b+12|0;n=c[m>>2]|0;o=AD(l,h,4)|0;if((o|0)<4){p=(o|0)<0?o:-541478725;i=f;return p|0}o=l+88|0;q=n+16|0;r=0;a:while(1){s=j+(r&3)|0;do{if((a[s]|0)==79){if((a[j+(r+1&3)|0]|0)!=103){break}if((a[j+(r+2&3)|0]|0)!=103){break}if((a[j+(r+3&3)|0]|0)==83){t=r;break a}}}while(0);do{if((r|0)==0){if((c[o>>2]|0)==0){break}u=c[q>>2]|0;v=c[q+4>>2]|0;w=0;if(!((v|0)>(w|0)|(v|0)==(w|0)&u>>>0>0>>>0)){break}c[h>>2]=0;w=wrc(u,v,4,0)|0;fD(l,w,G,0)|0;c[q>>2]=-1;c[q+4>>2]=-1}}while(0);w=zD(l)|0;if((jD(l)|0)!=0){p=-541478725;x=69;break}v=r+1|0;a[s]=w;if((r|0)<65307){r=v}else{t=v;break}}if((x|0)==69){i=f;return p|0}if((t|0)>65306){KIb(b,32,2153536,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;p=-1094995529;i=f;return p|0}if((zD(l)|0)!=0){KIb(b,16,2128832,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;p=-1094995529;i=f;return p|0}t=zD(l)|0;r=GD(l)|0;h=G;o=FD(l)|0;hD(l,8,0)|0;j=zD(l)|0;v=n;w=c[n+4>>2]|0;n=0;while(1){if((n|0)>=(w|0)){z=0;x=22;break}A=c[v>>2]|0;if((c[A+(n*400|0)+28>>2]|0)==(o|0)){x=21;break}else{n=n+1|0}}if((x|0)==21){if((n|0)<0){z=0;x=22}else{B=n;C=A}}b:do{if((x|0)==22){while(1){x=0;if((z|0)>=(w|0)){x=39;break}if((c[(c[v>>2]|0)+(z*400|0)+372>>2]|0)==0){z=z+1|0;x=22}else{x=24;break}}c:do{if((x|0)==24){s=g|0;A=c[m>>2]|0;n=c[k>>2]|0;d:do{if((c[n+88>>2]|0)==0){if((c[A+4>>2]|0)==1){D=0;E=c[A>>2]|0;break}else{RIb(b,2572952,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;F=-1163346256;break c}}else{u=fD(n,0,0,1)|0;H=G;hD(c[k>>2]|0,j,(j|0)<0|0?-1:0)|0;AD(c[k>>2]|0,s,8)|0;fD(c[k>>2]|0,u,H,0)|0;H=0;u=1305744;while(1){I=a[u+4|0]|0;if(!((I&255)>>>0>8>>>0)){if((grc(s,c[u>>2]|0,I&255)|0)==0){x=29;break}}I=H+1|0;if((I|0)==15){break}else{H=I;u=c[774656+(I<<2)>>2]|0}}do{if((x|0)==29){if((u|0)==0){break}H=A;I=c[A+4>>2]|0;J=0;while(1){if((J|0)>=(I|0)){break}K=c[H>>2]|0;if((c[K+(J*400|0)+84>>2]|0)==(u|0)){D=J;E=K;break d}else{J=J+1|0}}L=TQ(b,o)|0;x=40;break c}}while(0);KIb(b,16,2597048,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;F=-1094995529;break c}}while(0);c[E+(D*400|0)+28>>2]=o;L=D;x=40}else if((x|0)==39){L=TQ(b,o)|0;x=40}}while(0);do{if((x|0)==40){if((L|0)<0){F=L;break}B=L;C=c[v>>2]|0;break b}}while(0);KIb(b,16,2105760,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;p=F;i=f;return p|0}}while(0);F=C+(B*400|0)|0;y=fD(l,0,0,1)|0;b=wrc(y,G,-27,-1)|0;y=G;L=C+(B*400|0)+72|0;c[L>>2]=b;c[L+4>>2]=y;c[q>>2]=b;c[q+4>>2]=y;y=C+(B*400|0)+16|0;if((c[y>>2]|0)!=0){q=c[v>>2]|0;v=hJb((c[q+(B*400|0)+4>>2]|0)+16|0)|0;b=q+(B*400|0)+8|0;o=q+(B*400|0)+12|0;D=c[o>>2]|0;E=(c[b>>2]|0)-D|0;k=q+(B*400|0)|0;q=c[k>>2]|0;if((q|0)!=0){nrc(v|0,q+D|0,E)|0;kJb(q)}c[k>>2]=v;c[b>>2]=E;c[o>>2]=0}o=AD(l,C+(B*400|0)+100|0,j)|0;if((o|0)<(j|0)){p=(o|0)<0?o:-541478725;i=f;return p|0}c[C+(B*400|0)+92>>2]=j;o=C+(B*400|0)+96|0;c[o>>2]=0;if((j|0)>0){E=0;b=0;while(1){v=(d[C+(B*400|0)+100+b|0]|0)+E|0;k=b+1|0;if((k|0)<(j|0)){E=v;b=k}else{M=v;break}}}else{M=0}if((t&2|0)==0){c[C+(B*400|0)+372>>2]=1}do{if((t&1|0)==0){if((c[C+(B*400|0)+356>>2]|0)!=0){x=55;break}c[y>>2]=0;b=c[L+4>>2]|0;E=C+(B*400|0)+64|0;c[E>>2]=c[L>>2];c[E+4>>2]=b}else{x=55}}while(0);do{if((x|0)==55){if((c[y>>2]|0)!=0){break}b=C+(B*400|0)+12|0;E=0;while(1){if((E|0)>=(j|0)){break}v=E+1|0;c[o>>2]=v;k=a[C+(B*400|0)+100+E|0]|0;c[b>>2]=(c[b>>2]|0)+(k&255);if(k<<24>>24==-1){E=v}else{break}}E=c[L+4>>2]|0;b=C+(B*400|0)+64|0;c[b>>2]=c[L>>2];c[b+4>>2]=E}}while(0);L=C+(B*400|0)+4|0;o=c[L>>2]|0;j=C+(B*400|0)+8|0;y=c[j>>2]|0;do{if((o-y|0)>>>0<M>>>0){x=o<<1;c[L>>2]=x;E=hJb(x+16|0)|0;if((E|0)==0){p=-12;i=f;return p|0}else{x=F|0;nrc(E|0,c[x>>2]|0,c[j>>2]|0)|0;kJb(c[x>>2]|0);c[x>>2]=E;N=c[j>>2]|0;O=E;break}}else{N=y;O=c[F>>2]|0}}while(0);y=AD(l,O+N|0,M)|0;if((y|0)<(M|0)){p=(y|0)<0?y:-541478725;i=f;return p|0}y=(c[j>>2]|0)+M|0;c[j>>2]=y;j=C+(B*400|0)+32|0;c[j>>2]=r;c[j+4>>2]=h;c[C+(B*400|0)+80>>2]=t;mrc((c[F>>2]|0)+y|0,0,16)|0;if((e|0)==0){p=0;i=f;return p|0}c[e>>2]=B;p=0;i=f;return p|0}function TQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a+12>>2]|0;f=e+4|0;g=c[f>>2]|0;if((c[e+24>>2]|0)!=0){KIb(a,16,2623768,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-558323010;i=d;return j|0}h=g+1|0;k=h*400|0;do{if(h>>>0>65535>>>0){if(((k>>>0)/(h>>>0)|0|0)==400){break}else{j=-12}i=d;return j|0}}while(0);h=e;e=iJb(c[h>>2]|0,k)|0;k=e;if((e|0)==0){j=-12;i=d;return j|0}c[h>>2]=k;h=k+(g*400|0)|0;e=h;mrc(e|0,0,400)|0;c[k+(g*400|0)+28>>2]=b;c[k+(g*400|0)+4>>2]=65307;b=hJb(65323)|0;c[h>>2]=b;c[k+(g*400|0)+88>>2]=-1;h=k+(g*400|0)+40|0;c[h>>2]=-1;c[h+4>>2]=-1;if((b|0)==0){j=-12;i=d;return j|0}b=ZX(a,0)|0;if((b|0)==0){mJb(e);j=-12;i=d;return j|0}else{c[b+4>>2]=g;_X(b,64,1,1e6);c[f>>2]=(c[f>>2]|0)+1;j=g;i=d;return j|0}return 0}function UQ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+12>>2]|0;d=b+4|0;e=hJb(((c[d>>2]|0)*400|0)+24|0)|0;f=e;g=fD(c[a+16>>2]|0,0,0,1)|0;a=e;c[a>>2]=g;c[a+4>>2]=G;c[e+8>>2]=c[b+12>>2];a=b+24|0;c[e+12>>2]=c[a>>2];c[e+16>>2]=c[d>>2];g=e+24|0;e=g;h=b;nrc(g|0,c[h>>2]|0,(c[d>>2]|0)*400|0)|0;if((c[d>>2]|0)>0){i=0}else{c[a>>2]=f;return}do{g=c[h>>2]|0;b=pJb((c[g+(i*400|0)+4>>2]|0)+16|0)|0;c[g+(i*400|0)>>2]=b;nrc(b|0,c[e+(i*400|0)>>2]|0,c[g+(i*400|0)+8>>2]|0)|0;c[g+(i*400|0)+384>>2]=0;c[g+(i*400|0)+388>>2]=0;i=i+1|0;}while((i|0)<(c[d>>2]|0));c[a>>2]=f;return}function VQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+24|0;e=c[d>>2]|0;if((e|0)==0){return}c[d>>2]=c[e+12>>2];d=a+4|0;if((c[d>>2]|0)>0){f=a;g=0;do{mJb((c[f>>2]|0)+(g*400|0)|0);g=g+1|0;}while((g|0)<(c[d>>2]|0))}g=e|0;fD(b,c[g>>2]|0,c[g+4>>2]|0,0)|0;g=a+16|0;c[g>>2]=-1;c[g+4>>2]=-1;c[a+12>>2]=c[e+8>>2];g=e+16|0;b=c[g>>2]|0;c[d>>2]=b;if((oJb(a,b,400)|0)<0){c[d>>2]=0;return}else{nrc(c[a>>2]|0,e+24|0,(c[g>>2]|0)*400|0)|0;kJb(e);return}}function WQ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=i;i=i+80|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;if((c[(c[b+12>>2]|0)+8>>2]|0)!=0){KIb(b,24,2470976,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}r=b+24|0;s=b+28|0;t=b+1140|0;u=b;v=0;a:while(1){w=c[(c[s>>2]|0)+(v<<2)>>2]|0;x=w+8|0;z=c[x>>2]|0;A=c[z+8>>2]|0;do{if((A|0)==0){_X(w,64,c[z+104>>2]|0,c[z+108>>2]|0)}else if((A|0)==1){if((c[z+48>>2]|0)==1330664787){_X(w,64,1,48e3);break}else{_X(w,64,1,c[z+412>>2]|0);break}}}while(0);z=c[x>>2]|0;A=c[z+48>>2]|0;if(!((A|0)==86021|(A|0)==31|(A|0)==86052|(A|0)==86028|(A|0)==1330664787)){B=12;break}if((c[z+96>>2]|0)==0){B=15;break}if((c[z+100>>2]|0)==0){B=15;break}C=pJb(65376)|0;c[C+72>>2]=v;b:do{if((c[(c[x>>2]|0)+88>>2]&8388608|0)==0){c:while(1){z=wKb()|0;A=0;while(1){if((A|0)>=(v|0)){D=z;break b}if((z|0)==(c[(c[(c[(c[s>>2]|0)+(A<<2)>>2]|0)+12>>2]|0)+65360>>2]|0)){continue c}else{A=A+1|0}}}}else{D=v}}while(0);c[C+65360>>2]=D;A=w+88|0;PGb(A,c[t>>2]|0,16);E=w+12|0;c[E>>2]=C;z=c[x>>2]|0;F=c[z+48>>2]|0;do{if((F|0)==86028){G=c[z+88>>2]&8388608;if((jea(z,o,p)|0)==0){H=-1;B=25;break a}c[C+16>>2]=51;I=pJb(51)|0;c[C+4>>2]=I;if((I|0)==0){H=-12;B=25;break a}a[I]=127;J=I+1|0;y=1128352838;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;a[I+5|0]=1;a[I+6|0]=0;J=I+7|0;y=256;a[J]=y;y=y>>8;a[J+1|0]=y;J=I+9|0;y=1130450022;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;a[I+13|0]=0;a[I+16|0]=34;a[I+15|0]=0;a[I+14|0]=0;nrc(I+17|0,c[p>>2]|0,34)|0;I=(G|0)!=0?2377328:2371784;cL(A,1253608,0);G=TY(c[A>>2]|0,I,n)|0;J=G+4|0;K=pJb(J)|0;c[m>>2]=K;if((K|0)==0){H=-12;B=25;break a}c[m>>2]=K+4;UY(m,A,I,c[n>>2]|0)|0;c[C+20>>2]=J;c[C+8>>2]=K;a[K]=-124;a[K+3|0]=G;a[K+2|0]=G>>>8;a[K+1|0]=G>>>16}else if((F|0)==86052){G=c[z+88>>2]&8388608;if((c[z+100>>2]|0)<80){L=-1;B=30;break a}K=pJb(80)|0;if((K|0)==0){L=-12;B=30;break a}c[C+4>>2]=K;c[C+16>>2]=80;nrc(K|0,c[z+96>>2]|0,80)|0;J=K+68|0;y=0;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;J=(G|0)!=0?2377328:2371784;cL(A,1253608,0);G=TY(c[A>>2]|0,J,l)|0;K=pJb(G)|0;c[k>>2]=K;if((K|0)==0){L=-12;B=30;break a}c[k>>2]=K;UY(k,A,J,c[l>>2]|0)|0;c[C+20>>2]=G;c[C+8>>2]=K}else if((F|0)==1330664787){K=c[z+88>>2]&8388608;G=z+100|0;J=c[G>>2]|0;if((J|0)<19){M=-1;B=35;break a}I=pJb(J)|0;if((I|0)==0){M=-12;B=35;break a}c[C+4>>2]=I;c[C+16>>2]=c[G>>2];nrc(I|0,c[z+96>>2]|0,c[G>>2]|0)|0;G=(K|0)!=0?2377328:2371784;cL(A,1253608,0);K=(TY(c[A>>2]|0,G,j)|0)+8|0;I=pJb(K)|0;c[h>>2]=I;if((I|0)==0){M=-12;B=35;break a}c[h>>2]=I+8;UY(h,A,G,c[j>>2]|0)|0;c[C+20>>2]=K;c[C+8>>2]=I;K=I;I=K|0;y=1937076303;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;I=K+4|0;y=1936154964;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y}else{I=(F|0)==86021;K=I?2405464:2398088;G=C+4|0;if((oib(c[z+96>>2]|0,c[z+100>>2]|0,I?30:42,G,C+16|0)|0)<0){B=37;break a}J=C+20|0;N=(c[(c[x>>2]|0)+88>>2]&8388608|0)!=0?2377328:2371784;cL(A,1253608,0);O=TY(c[A>>2]|0,N,g)|0;P=O+(I?8:7)|0;O=pJb(P)|0;c[f>>2]=O;if((O|0)==0){Q=0}else{c[f>>2]=O+7;UY(f,A,N,c[g>>2]|0)|0;if(I){a[c[f>>2]|0]=1;c[f>>2]=(c[f>>2]|0)+1}c[J>>2]=P;Q=O}c[C+8>>2]=Q;if((Q|0)==0){R=-12;B=53;break a}a[Q]=I?3:-127;I=Q+1|0;a[I]=a[K]|0;a[I+1|0]=a[K+1|0]|0;a[I+2|0]=a[K+2|0]|0;a[I+3|0]=a[K+3|0]|0;a[I+4|0]=a[K+4|0]|0;a[I+5|0]=a[K+5|0]|0;if((c[(c[x>>2]|0)+48>>2]|0)!=31){break}K=c[G>>2]|0;G=(d[K+40|0]|0)<<3&24|(d[K+41|0]|0)>>>5;c[C+28>>2]=G;I=d[K+9|0]|0;c[C+40>>2]=I;KIb(u,48,2384080,(q=i,i=i+16|0,c[q>>2]=G,c[q+8>>2]=I,q)|0);i=q}}while(0);x=v+1|0;S=c[r>>2]|0;if(x>>>0<S>>>0){v=x}else{B=4;break}}if((B|0)==4){do{if((S|0)!=0){Q=b+28|0;f=0;do{g=c[(c[Q>>2]|0)+(f<<2)>>2]|0;j=c[g+12>>2]|0;$Q(b,c[(c[g+8>>2]|0)+48>>2]|0,j,c[j+4>>2]|0,c[j+16>>2]|0,0,0,1);g=j+76|0;a[g]=a[g]|2;ZQ(b,j);f=f+1|0;T=c[r>>2]|0;}while(f>>>0<T>>>0);if((T|0)==0){break}f=b+28|0;Q=0;do{j=c[(c[f>>2]|0)+(Q<<2)>>2]|0;g=j+12|0;h=c[g>>2]|0;l=j+8|0;j=c[h+20>>2]|0;if((j|0)!=0){$Q(b,c[(c[l>>2]|0)+48>>2]|0,h,c[h+8>>2]|0,j,0,0,1)}j=c[h+24>>2]|0;if((j|0)!=0){$Q(b,c[(c[l>>2]|0)+48>>2]|0,c[g>>2]|0,c[h+12>>2]|0,j,0,0,1)}ZQ(b,h);Q=Q+1|0;}while(Q>>>0<(c[r>>2]|0)>>>0)}}while(0);r=C+56|0;c[r>>2]=0;c[r+4>>2]=-2147483648;R=0;i=e;return R|0}else if((B|0)==12){KIb(u,16,2463136,(q=i,i=i+8|0,c[q>>2]=v,q)|0);i=q;R=-1;i=e;return R|0}else if((B|0)==15){KIb(u,16,2447792,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;R=-1;i=e;return R|0}else if((B|0)==25){KIb(u,16,2432672,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;mJb(E);R=H;i=e;return R|0}else if((B|0)==30){KIb(u,16,2423952,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;mJb(E);R=L;i=e;return R|0}else if((B|0)==35){KIb(u,16,2413168,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;mJb(E);R=M;i=e;return R|0}else if((B|0)==37){KIb(u,16,2390920,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;mJb(E);R=-1;i=e;return R|0}else if((B|0)==53){i=e;return R|0}return 0}function XQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+8|0;e=d|0;f=c[(c[a+28>>2]|0)+(c[b+32>>2]<<2)>>2]|0;g=f+12|0;h=c[g>>2]|0;j=f+8|0;k=c[j>>2]|0;l=c[k+48>>2]|0;do{if((l|0)==31){m=b+8|0;n=c[m>>2]|0;o=c[m+4>>2]|0;if((c[h+40>>2]|0)<1){p=o;q=n}else{m=c[b+48>>2]|0;r=wrc(m,(m|0)<0|0?-1:0,n,o)|0;p=G;q=r}r=h+32|0;if((c[b+36>>2]&1|0)==0){s=c[r+4>>2]|0;t=c[r>>2]|0}else{c[r>>2]=q;c[r+4>>2]=p;s=p;t=q}r=xrc(q,p,t,s)|0;o=r;r=c[h+28>>2]|0;if((o|0)<(1<<r|0)){u=o;v=s;w=t}else{n=h+32|0;m=wrc(o,(o|0)<0|0?-1:0,t,s)|0;o=G;c[n>>2]=m;c[n+4>>2]=o;u=0;v=o;w=m}m=yrc(w|0,v|0,r|0)|0;x=G|((u|0)<0|0?-1:0);y=m|u}else{m=b+8|0;r=c[b+48>>2]|0;o=wrc(r,(r|0)<0|0?-1:0,c[m>>2]|0,c[m+4>>2]|0)|0;m=G;if((l|0)!=1330664787){x=m;y=o;break}r=c[k+116>>2]|0;c[e>>2]=1;c[e+4>>2]=c[k+412>>2];n=XIb(r,(r|0)<0|0?-1:0,e,f+40|0)|0;r=wrc(n,G,o,m)|0;x=G;y=r}}while(0);f=h+56|0;if(!((c[f>>2]|0)==0&(c[f+4>>2]|0)==(-2147483648|0))){z=b+24|0;A=c[z>>2]|0;B=b+28|0;C=c[B>>2]|0;D=c[j>>2]|0;E=c[g>>2]|0;F=D+48|0;H=c[F>>2]|0;$Q(a,H,E,A,C,y,x,0);_Q(a,0);I=h+65368|0;J=I;K=J|0;c[K>>2]=y;L=J+4|0;c[L>>2]=x;i=d;return 0}e=b+8|0;k=c[e+4>>2]|0;c[f>>2]=c[e>>2];c[f+4>>2]=k;z=b+24|0;A=c[z>>2]|0;B=b+28|0;C=c[B>>2]|0;D=c[j>>2]|0;E=c[g>>2]|0;F=D+48|0;H=c[F>>2]|0;$Q(a,H,E,A,C,y,x,0);_Q(a,0);I=h+65368|0;J=I;K=J|0;c[K>>2]=y;L=J+4|0;c[L>>2]=x;i=d;return 0}function YQ(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+24|0;e=c[d>>2]|0;if((e|0)!=0){f=a+28|0;g=0;h=e;while(1){e=c[(c[(c[f>>2]|0)+(g<<2)>>2]|0)+12>>2]|0;if((b[e+65358>>1]|0)==0){i=h}else{ZQ(a,e);i=c[d>>2]|0}e=g+1|0;if(e>>>0<i>>>0){g=e;h=i}else{break}}}_Q(a,1);if((c[d>>2]|0)==0){return 0}i=a+28|0;a=0;do{h=c[(c[i>>2]|0)+(a<<2)>>2]|0;g=h+12|0;f=c[g>>2]|0;e=c[(c[h+8>>2]|0)+48>>2]|0;if((e|0)==86028|(e|0)==86052|(e|0)==1330664787){mJb(f+4|0)}mJb(f+8|0);mJb(g);a=a+1|0;}while(a>>>0<(c[d>>2]|0)>>>0);return 0}function ZQ(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[d+12>>2]|0;k=pJb(65312)|0;l=k;if((k|0)==0){i=f;return}m=j+4|0;j=e+56|0;nrc(k|0,j|0,65304)|0;n=e+64|0;o=c[n+4>>2]|0;p=j|0;c[p>>2]=c[n>>2];c[p+4>>2]=o;o=e+48|0;c[o>>2]=(c[o>>2]|0)+1;c[n>>2]=-1;c[n+4>>2]=-1;a[e+76|0]=0;a[e+77|0]=0;b[e+65358>>1]=0;e=c[m>>2]|0;a:do{if((e|0)==0){q=m;r=0}else{n=d+28|0;o=k+16|0;p=k+8|0;j=g|0;s=g+4|0;t=h|0;u=h+4|0;v=m;w=e;while(1){x=c[n>>2]|0;y=w+8|0;z=c[y>>2]|0;A=c[y+4>>2]|0;y=c[x+(c[w+16>>2]<<2)>>2]|0;B=c[x+(c[o>>2]<<2)>>2]|0;do{if((z|0)==(-1|0)&(A|0)==(-1|0)){C=w}else{if((c[p>>2]|0)==(-1|0)&(c[p+4>>2]|0)==(-1|0)){C=w;break}x=c[(c[y+12>>2]|0)+28>>2]|0;if((x|0)==0){D=A;E=z}else{F=Arc(z|0,A|0,x|0)|0;H=(1<<x)-1|0;x=wrc(H&z,((H|0)<0|0?-1:0)&A,F,G)|0;D=G;E=x}c[j>>2]=1;c[s>>2]=1e6;x=XIb(E,D,y+40|0,g)|0;F=G;H=c[p>>2]|0;I=c[p+4>>2]|0;J=c[(c[B+12>>2]|0)+28>>2]|0;if((J|0)==0){K=I;L=H}else{M=Arc(H|0,I|0,J|0)|0;N=(1<<J)-1|0;J=wrc(N&H,((N|0)<0|0?-1:0)&I,M,G)|0;K=G;L=J}c[t>>2]=1;c[u>>2]=1e6;J=XIb(L,K,B+40|0,h)|0;M=G;I=c[v>>2]|0;if((F|0)>(M|0)|(F|0)==(M|0)&x>>>0>J>>>0){q=v;r=I;break a}else{C=I}}}while(0);B=C+65304|0;y=c[B>>2]|0;if((y|0)==0){q=B;r=0;break}else{v=B;w=y}}}}while(0);c[k+65304>>2]=r;c[q>>2]=l;i=f;return}function _Q(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=(c[a+12>>2]|0)+4|0;l=c[k>>2]|0;if((l|0)==0){i=f;return}c[j>>2]=l;m=a+28|0;n=j;o=a+16|0;a:do{if((b|0)==0){a=l;while(1){p=c[(c[(c[m>>2]|0)+(c[a+16>>2]<<2)>>2]|0)+12>>2]|0;q=p+48|0;if((c[q>>2]|0)>>>0<2>>>0){r=a;break a}do{if((_D(g)|0)>=0){yD(c[g>>2]|0,448,0);kD(c[g>>2]|0,1399285583);bD(c[g>>2]|0,0);bD(c[g>>2]|0,d[a+20|0]|0);s=a+8|0;rD(c[g>>2]|0,c[s>>2]|0,c[s+4>>2]|0);kD(c[g>>2]|0,c[p+65360>>2]|0);s=c[g>>2]|0;t=p;u=c[t>>2]|0;c[t>>2]=u+1;kD(s,u);u=fD(c[g>>2]|0,0,0,1)|0;s=G;kD(c[g>>2]|0,0);t=a+21|0;bD(c[g>>2]|0,d[t]|0);dD(c[g>>2]|0,a+22|0,d[t]|0);dD(c[g>>2]|0,a+277|0,e[a+65302>>1]|0);t=c[g>>2]|0;v=fD(t,0,0,1)|0;w=G;x=xD(t)|0;fD(t,u,s,0)|0;lD(t,x);fD(t,v,w,0)|0;eD(c[g>>2]|0);w=aE(c[g>>2]|0,h)|0;if((w|0)<0){break}dD(c[o>>2]|0,c[h>>2]|0,w);eD(c[o>>2]|0);kJb(c[h>>2]|0);c[q>>2]=(c[q>>2]|0)-1}}while(0);q=c[(c[j>>2]|0)+65304>>2]|0;mJb(n);c[j>>2]=q;if((q|0)==0){r=0;break}else{a=q}}}else{a=l;while(1){q=c[(c[(c[m>>2]|0)+(c[a+16>>2]<<2)>>2]|0)+12>>2]|0;p=q+48|0;w=c[p>>2]|0;do{if((_D(g)|0)>=0){yD(c[g>>2]|0,448,0);kD(c[g>>2]|0,1399285583);bD(c[g>>2]|0,0);bD(c[g>>2]|0,d[a+20|0]|0|((w|0)==1?4:0));v=a+8|0;rD(c[g>>2]|0,c[v>>2]|0,c[v+4>>2]|0);kD(c[g>>2]|0,c[q+65360>>2]|0);v=c[g>>2]|0;t=q;x=c[t>>2]|0;c[t>>2]=x+1;kD(v,x);x=fD(c[g>>2]|0,0,0,1)|0;v=G;kD(c[g>>2]|0,0);t=a+21|0;bD(c[g>>2]|0,d[t]|0);dD(c[g>>2]|0,a+22|0,d[t]|0);dD(c[g>>2]|0,a+277|0,e[a+65302>>1]|0);t=c[g>>2]|0;s=fD(t,0,0,1)|0;u=G;y=xD(t)|0;fD(t,x,v,0)|0;lD(t,y);fD(t,s,u,0)|0;eD(c[g>>2]|0);u=aE(c[g>>2]|0,h)|0;if((u|0)<0){break}dD(c[o>>2]|0,c[h>>2]|0,u);eD(c[o>>2]|0);kJb(c[h>>2]|0);c[p>>2]=(c[p>>2]|0)-1}}while(0);p=c[(c[j>>2]|0)+65304>>2]|0;mJb(n);c[j>>2]=p;if((p|0)==0){r=0;break}else{a=p}}}}while(0);c[k>>2]=r;i=f;return}function $Q(f,g,h,j,k,l,m,n){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;o=i;i=i+16|0;p=o|0;q=o+8|0;r=h;s=c[f+12>>2]|0;t=((k>>>0)/255|0)+1|0;do{if((g|0)==31&(n|0)==0){u=c[h+28>>2]|0;if((u|0)==0){v=h+65368|0;w=c[v+4>>2]|0;x=c[v>>2]|0;y=m;z=l;A=0}else{v=u;B=Arc(l|0,m|0,v|0)|0;C=(1<<u)-1|0;D=C;E=(C|0)<0|0?-1:0;C=wrc(D&l,E&m,B,G)|0;B=G;F=h+65368|0;H=c[F>>2]|0;I=c[F+4>>2]|0;F=Arc(H|0,I|0,v|0)|0;v=wrc(D&H,E&I,F,G)|0;w=G;x=v;y=B;z=C;A=u}u=wrc(x,w,1,0)|0;C=G;if(!((y|0)>(C|0)|(y|0)==(C|0)&z>>>0>u>>>0)){if((A|0)==0){J=0;break}u=(1<<A)-1|0;if(!((u&l|0)==0&(((u|0)<0|0?-1:0)&m|0)==0)){J=0;break}}u=h+64|0;if((c[u>>2]|0)==(-1|0)&(c[u+4>>2]|0)==(-1|0)){J=1;break}ZQ(f,r);J=1}else{J=0}}while(0);A=(n|0)!=0;do{if(!A){n=b[h+65358>>1]|0;if(n<<16>>16==0){break}if(!((65025-(n&65535)|0)>>>0<k>>>0)){break}ZQ(f,r)}}while(0);n=h+77|0;z=h+76|0;y=h+65358|0;w=h+64|0;x=h+72|0;g=f+28|0;u=h+56|0;C=p|0;B=p+4|0;v=q|0;F=q+4|0;I=s+8|0;E=s+16|0;if(A){A=0;s=j;H=k;while(1){D=t-A|0;K=a[n]|0;L=K&255;M=L^255;N=(D|0)>(M|0)?M:D;if((A|0)!=0&K<<24>>24==0){a[z]=a[z]|1}K=N-1|0;mrc(h+(L+78)|0,-1|0,K|0)|0;L=(d[n]|0)+K|0;D=N*255|0;M=H>>>0>D>>>0?D:H;a[n]=(L&255)+1;a[h+((L&255)+78)|0]=M+(K*-255|0);nrc(h+((e[y>>1]|0)+333)|0,s|0,M)|0;K=N+A|0;b[y>>1]=(e[y>>1]|0)+M;if((K|0)==(t|0)){c[w>>2]=l;c[w+4>>2]=m}if((K|0)<(t|0)){A=K;s=s+M|0;H=H-M|0}else{break}}}else{H=0;s=j;j=k;do{k=t-H|0;A=a[n]|0;M=A&255;K=M^255;N=(k|0)>(K|0)?K:k;if((H|0)!=0&A<<24>>24==0){a[z]=a[z]|1}A=N-1|0;mrc(h+(M+78)|0,-1|0,A|0)|0;M=(d[n]|0)+A|0;k=N*255|0;K=j>>>0>k>>>0?k:j;a[n]=(M&255)+1;a[h+((M&255)+78)|0]=K+(A*-255|0);nrc(h+((e[y>>1]|0)+333)|0,s|0,K)|0;s=s+K|0;j=j-K|0;H=N+H|0;b[y>>1]=(e[y>>1]|0)+K;if((H|0)==(t|0)){c[w>>2]=l;c[w+4>>2]=m}K=c[u>>2]|0;N=c[u+4>>2]|0;A=(c[(c[g>>2]|0)+(c[x>>2]<<2)>>2]|0)+40|0;c[C>>2]=1;c[B>>2]=1e6;M=XIb(K,N,A,p)|0;N=G;K=c[w>>2]|0;k=c[w+4>>2]|0;c[v>>2]=1;c[F>>2]=1e6;L=XIb(K,k,A,q)|0;A=G;do{if((a[n]|0)==-1){O=30}else{k=c[I>>2]|0;if((k|0)>0){if((e[y>>1]|0)>=(k|0)){O=30;break}}k=c[E>>2]|0;K=c[E+4>>2]|0;D=0;if(!((K|0)>(D|0)|(K|0)==(D|0)&k>>>0>0>>>0)){break}D=xrc(L,A,M,N)|0;P=G;if(!((P|0)<(K|0)|(P|0)==(K|0)&D>>>0<k>>>0)){O=30}}}while(0);if((O|0)==30){O=0;ZQ(f,r)}}while((H|0)<(t|0))}if((J|0)==0){i=o;return}J=h+64|0;if((c[J>>2]|0)==(-1|0)&(c[J+4>>2]|0)==(-1|0)){i=o;return}ZQ(f,r);i=o;return}function aR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[c[b+12>>2]>>2]|0;g=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;h=f+(e*400|0)+392|0;i=c[h>>2]|0;j=c[f+(e*400|0)>>2]|0;k=c[f+(e*400|0)+12>>2]|0;l=j+k|0;m=c[f+(e*400|0)+16>>2]|0;do{if((m|0)==60){if((grc(l,2129920,8)|0)!=0){break}e=hJb(4)|0;if((e|0)==0){n=-12;return n|0}f=g+8|0;if((PX(c[f>>2]|0,8)|0)<0){n=-12;return n|0}o=j+(k+28)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+36)|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+40)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+44)|0;s=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+48)|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+(k+56)|0;u=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=c[f>>2]|0;c[o+8>>2]=1;c[o+48>>2]=86068;c[o+412>>2]=q;c[o+416>>2]=r;c[o+424>>2]=s;if((q|0)!=0){_X(g,64,1,q)}c[e>>2]=u+1;kJb(c[h>>2]|0);c[h>>2]=e;e=c[(c[f>>2]|0)+96>>2]|0;y=t;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=(c[(c[f>>2]|0)+96>>2]|0)+4|0;y=p;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;n=1;return n|0}}while(0);if((i|0)==0){n=0;return n|0}h=i;if((c[h>>2]|0)==0){n=0;return n|0}sR(b,g+88|0,l,m)|0;c[h>>2]=(c[h>>2]|0)-1;n=1;return n|0}function bR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+48|0;e=d+24|0;f=c[c[a+12>>2]>>2]|0;g=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;a=g+8|0;if((c[(c[a>>2]|0)+48>>2]|0)==117){h=0;i=d;return h|0}j=(c[f+(b*400|0)>>2]|0)+((c[f+(b*400|0)+12>>2]|0)+13)|0;k=(c[f+(b*400|0)+16>>2]<<3)-104|0;b=k>>>0>2147483639>>>0|(j|0)==0;f=b?0:j;j=b?0:k;c[e>>2]=f;c[e+12>>2]=j;c[e+16>>2]=j+8;c[e+4>>2]=f+(j>>3);c[e+8>>2]=0;if((z5(c[a>>2]|0,e,d|0)|0)<0){h=-1;i=d;return h|0}e=c[a>>2]|0;c[e+8>>2]=0;c[e+48>>2]=117;_X(g,64,c[e+104>>2]|0,c[e+108>>2]<<1);h=1;i=d;return h|0}function cR(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=d>>>31|e<<1;h=e>>31|((e|0)<0|0?-1:0)<<1;i=wrc((d>>>9|e<<23)&8191,(e>>>9|0<<23)&0,g,h)|0;j=G;if(((d>>>14|e<<18)&65280|d&255|0)==0&((e>>>14|0<<18)&0|e&0|0)==0){e=(c[c[a+12>>2]>>2]|0)+(b*400|0)+20|0;c[e>>2]=c[e>>2]|1}if((f|0)==0){return(G=j,i)|0}c[f>>2]=g;c[f+4>>2]=h;return(G=j,i)|0}function dR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[c[b+12>>2]>>2]|0;g=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;b=c[f+(e*400|0)>>2]|0;h=c[f+(e*400|0)+12>>2]|0;if((a[b+h|0]|0)!=75){i=0;return i|0}e=c[g+8>>2]|0;c[e+8>>2]=0;c[e+48>>2]=117;e=b+(h+12)|0;f=je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;e=b+(h+8)|0;_X(g,64,f,je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0);i=1;return i|0}function eR(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;f=d>>>30|e<<2;g=e>>>30|0<<2;h=d&1073741823;d=e&0;if(!((h|0)==0&(d|0)==0)){i=wrc(f,g,h,d)|0;j=G;return(G=j,i)|0}e=(c[c[a+12>>2]>>2]|0)+(b*400|0)+20|0;c[e>>2]=c[e>>2]|1;i=wrc(f,g,h,d)|0;j=G;return(G=j,i)|0}function fR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+32|0;g=f|0;h=c[c[b+12>>2]>>2]|0;j=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;k=c[h+(e*400|0)+12>>2]|0;l=c[h+(e*400|0)>>2]|0;m=l+k|0;if((a[m]|0)==-1){n=0;i=f;return n|0}o=c[h+(e*400|0)+16>>2]|0;e=o<<3;h=e>>>0>2147483639>>>0|(m|0)==0;p=h?0:m;m=h?8:e+8|0;e=m>>>0>1>>>0?1:m;h=p+(e>>>3)|0;q=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(e&1)>>>25;h=e+7|0;e=m>>>0>h>>>0?h:m;if((q|0)==4){sR(b,j+88|0,l+(k+4)|0,o-4|0)|0;n=1;i=f;return n|0}else if((q|0)==127){q=l+(k+17)|0;k=-e|0;l=m-e|0;if((k|0)>32){r=k}else{r=(l|0)<32?l:32}l=r+e|0;e=p+(l>>>3)|0;r=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(l&7);e=l+8|0;l=m>>>0>e>>>0?e:m;if((r&-16777216|0)!=16777216){n=-1;i=f;return n|0}r=-l|0;e=m-l|0;if((r|0)>24){s=r}else{s=(e|0)<24?e:24}e=s+l|0;l=-e|0;s=m-e|0;if((l|0)>32){t=l}else{t=(s|0)<32?s:32}s=t+e|0;e=p+(s>>>3)|0;t=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(s&7)&-65536;e=s+16|0;s=m>>>0>e>>>0?e:m;m=p+(s>>>3)|0;if(((je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(s&7)>>>16|t|0)!=34){n=-1;i=f;return n|0}t=j+8|0;lea(c[t>>2]|0,g,q);g=c[t>>2]|0;c[g+8>>2]=1;c[g+48>>2]=86028;c[j+236>>2]=2;if((PX(g,34)|0)<0){n=-12;i=f;return n|0}g=c[t>>2]|0;nrc(c[g+96>>2]|0,q|0,c[g+100>>2]|0)|0;_X(j,64,1,c[(c[t>>2]|0)+412>>2]|0);n=1;i=f;return n|0}else{n=1;i=f;return n|0}return 0}function gR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+16|0;e=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;f=c[c[a+12>>2]>>2]|0;a=DWa(86028)|0;if((a|0)==0){g=-1;i=d;return g|0}h=e+8|0;j=c[h>>2]|0;c[j+8>>2]=1;c[j+48>>2]=86028;c[a+176>>2]=1;FWa(a,j,d+8|0,d|0,(c[f+(b*400|0)>>2]|0)+(c[f+(b*400|0)+12>>2]|0)|0,c[f+(b*400|0)+16>>2]|0,0,-2147483648,0,-2147483648,-1,-1)|0;HWa(a);a=c[(c[h>>2]|0)+412>>2]|0;if((a|0)==0){g=1;i=d;return g|0}_X(e,64,1,a);g=0;i=d;return g|0}function hR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=i;i=i+8|0;g=f|0;h=c[c[b+12>>2]>>2]|0;j=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;k=c[h+(e*400|0)>>2]|0;l=c[h+(e*400|0)+12>>2]|0;m=h+(e*400|0)+16|0;e=c[m>>2]|0;if(!((e|0)>-1)){KIb(0,0,2214680,(n=i,i=i+24|0,c[n>>2]=2181656,c[n+8>>2]=2153432,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}h=e+l|0;o=k+h|0;if((e|0)<1){p=0;i=f;return p|0}q=a[k+l|0]|0;if((q&1)==0){p=0;i=f;return p|0}if((q<<24>>24|0)==1){r=e>>>0>1>>>0?1:e;s=r+l|0;t=e-r|0;do{if((t|0)<1){u=12}else{r=a[k+s|0]|0;if((r<<24>>24|0)==116){v=c[j+8>>2]|0;c[v+8>>2]=3;c[v+48>>2]=94210;w=k+((t>>>0>12>>>0?12:t)+s)|0;x=v;break}else if((r<<24>>24|0)!=118){u=12;break}r=j+8|0;c[(c[r>>2]|0)+8>>2]=0;v=t>>>0>8>>>0?8:t;y=v+s|0;z=k+y|0;if((h-s-v|0)<4){A=0;B=z}else{v=z;A=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;B=k+(y+4)|0}y=JX(1409152,A)|0;v=c[r>>2]|0;c[v+48>>2]=y;c[v+52>>2]=A;w=B;x=v}}while(0);do{if((u|0)==12){B=g|0;c[g>>2]=0;A=j+8|0;c[(c[A>>2]|0)+8>>2]=1;v=t>>>0>8>>>0?8:t;y=v+s|0;r=h-s-v|0;v=r>>>0>4>>>0?4:r;nrc(B|0,k+y|0,v)|0;r=k+(v+y)|0;a[g+4|0]=0;y=JX(1406408,rb(B|0,0,16)|0)|0;B=c[A>>2]|0;c[B+48>>2]=y;if((y|0)==86018){w=r;x=B;break}c[j+236>>2]=1;w=r;x=B}}while(0);if((o-w|0)<4){C=0;D=w}else{g=w;C=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;D=w+4|0}w=c[m>>2]|0;m=C>>>0>w>>>0?w:C;if((o-D|0)<8){E=0;F=0;H=D}else{C=D;w=C|0;g=C+4|0;E=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;F=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;H=D+8|0}do{if((o-H|0)>=8){D=H;w=D|0;g=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=D+4|0;D=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;if((F|0)==0&(E|0)==0|(g|0)==0&(D|0)==0){break}w=o-(H+8)|0;C=w>>>0>4>>>0?12:w+8|0;w=o-(H+C)|0;s=(w>>>0>8>>>0?8:w)+C|0;C=H+s|0;w=j+8|0;t=o-C|0;if((c[x+8>>2]|0)==0){if((t|0)<4){I=0;J=C}else{u=C;I=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;J=H+(s+4)|0}c[x+120>>2]=I;if((o-J|0)<4){K=0}else{u=J;K=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0}c[x+124>>2]=K;u=Erc(g,D,1e7,0)|0;_X(j,64,F,u);p=1;i=f;return p|0}if((t|0)<2){L=0;M=C}else{t=C;L=(d[t]|d[t+1|0]<<8)<<16>>16&65535;M=H+(s+2)|0}c[x+416>>2]=L;s=o-M|0;t=s>>>0>2>>>0?2:s;s=M+t|0;if((o-s|0)<4){N=0;O=s}else{C=s;N=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24)<<3;O=M+(t+4)|0}c[x+72>>2]=N;t=Erc(g,D,1e7,0)|0;D=Frc(t,G,F,E)|0;t=D;c[x+412>>2]=t;_X(j,64,1,t);do{if(m>>>0>55>>>0){if((c[(c[w>>2]|0)+48>>2]|0)!=86018){P=m;Q=O;break}t=o-O|0;P=m-4|0;Q=O+(t>>>0>4>>>0?4:t)|0}else{P=m;Q=O}}while(0);if(!(P>>>0>52>>>0)){p=1;i=f;return p|0}PX(c[w>>2]|0,P-52|0)|0;t=c[w>>2]|0;D=c[t+100>>2]|0;g=o-Q|0;nrc(c[t+96>>2]|0,Q|0,g>>>0>D>>>0?D:g)|0;p=1;i=f;return p|0}}while(0);KIb(b,16,2261512,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=-1094995529;i=f;return p|0}else if((q<<24>>24|0)==3){q=(e>>>0>7>>>0?7:e)+l|0;l=h-q|0;if(!(l>>>0>1>>>0)){p=1;i=f;return p|0}sR(b,j+88|0,k+q|0,l-1|0)|0;p=1;i=f;return p|0}else{p=1;i=f;return p|0}return 0}function iR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c[c[b+12>>2]>>2]|0;b=c[f+(e*400|0)>>2]|0;g=f+(e*400|0)+12|0;h=c[g>>2]|0;i=b+h|0;j=a[i]|0;if((j&8)==0){k=j}else{j=f+(e*400|0)+20|0;c[j>>2]=c[j>>2]|1;k=a[i]|0}i=k&255;k=i<<1&4|i>>>6;i=k+1|0;c[g>>2]=i+h;g=f+(e*400|0)+16|0;c[g>>2]=(c[g>>2]|0)-i;if((k|0)==0){return 0}i=f+(e*400|0)+24|0;e=k;k=c[i>>2]|0;while(1){f=e-1|0;g=((d[b+(e+h)|0]|0)<<(f<<3))+k|0;c[i>>2]=g;if((f|0)==0){break}else{e=f;k=g}}return 0}function jR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[c[b+12>>2]>>2]|0;g=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;b=c[f+(e*400|0)>>2]|0;h=c[f+(e*400|0)+12>>2]|0;i=a[b+h|0]|0;if((i&1)==0){j=0;return j|0}if(!(i<<24>>24==1)){j=1;return j|0}i=c[f+(e*400|0)+16>>2]|0;if(i>>>0<100>>>0){j=-1094995529;return j|0}e=b+(h+96)|0;f=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if((f|0)==89694081){if(i>>>0<136>>>0){j=-1094995529;return j|0}e=g+8|0;c[(c[e>>2]|0)+8>>2]=1;k=b+(h+124)|0;l=JX(1406408,(d[k]|d[k+1|0]<<8)<<16>>16&65535)|0;k=c[e>>2]|0;c[k+48>>2]=l;l=b+(h+126)|0;c[k+416>>2]=(d[l]|d[l+1|0]<<8)<<16>>16&65535;l=b+(h+128)|0;c[k+412>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(h+132)|0;c[k+72>>2]=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)<<3;j=1;return j|0}else if((f|0)==89694080){if(i>>>0<184>>>0){j=-1094995529;return j|0}i=g+8|0;c[(c[i>>2]|0)+8>>2]=0;f=b+(h+68)|0;l=JX(1409152,d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;c[(c[i>>2]|0)+48>>2]=l;l=b+(h+164)|0;_X(g,64,d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0,1e7);l=b+(h+176)|0;g=c[i>>2]|0;c[g+120>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(h+180)|0;c[g+124>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;j=1;return j|0}else{j=1;return j|0}return 0}function kR(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[c[a+12>>2]>>2]|0;f=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;g=e+(b*400|0)+392|0;h=c[g>>2]|0;i=c[e+(b*400|0)>>2]|0;j=c[e+(b*400|0)+12>>2]|0;k=i+j|0;do{if((h|0)==0){l=pJb(16)|0;c[g>>2]=l;if((l|0)==0){m=-12}else{n=l;break}return m|0}else{n=h}}while(0);if((c[e+(b*400|0)+80>>2]&2|0)==0){h=n;if((c[h>>2]|0)==0){m=0;return m|0}g=c[e+(b*400|0)+16>>2]|0;if(g>>>0<8>>>0){m=-1094995529;return m|0}if((grc(k,2314232,8)|0)!=0){m=-1094995529;return m|0}sR(a,f+88|0,i+(j+8)|0,g-8|0)|0;c[h>>2]=(c[h>>2]|0)-1;m=1;return m|0}else{h=e+(b*400|0)+16|0;if((c[h>>2]|0)>>>0<19>>>0){m=-1094995529;return m|0}if((d[i+(j+8)|0]|0)>>>0>15>>>0){m=-1094995529;return m|0}b=f+8|0;e=c[b>>2]|0;c[e+8>>2]=1;c[e+48>>2]=1330664787;c[e+416>>2]=d[i+(j+9)|0]|0;g=i+(j+10)|0;j=(d[g]|d[g+1|0]<<8)<<16>>16&65535;c[n+4>>2]=j;c[e+116>>2]=j;if((PX(e,c[h>>2]|0)|0)!=0){m=-12;return m|0}nrc(c[(c[b>>2]|0)+96>>2]|0,k|0,c[h>>2]|0)|0;h=c[b>>2]|0;c[h+412>>2]=48e3;b=VIb(80,0,48e3,0,1e3,0)|0;X4a(h,b);_X(f,64,1,48e3);c[n>>2]=1;m=1;return m|0}return 0}function lR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;f=c[c[b+12>>2]>>2]|0;g=c[(c[b+28>>2]|0)+(d<<2)>>2]|0;h=c[f+(d*400|0)+392>>2]|0;j=c[f+(d*400|0)>>2]|0;k=c[f+(d*400|0)+12>>2]|0;l=j+k|0;m=c[f+(d*400|0)+16>>2]|0;if((m|0)==0){n=-1094995529;i=e;return n|0}o=f+(d*400|0)+48|0;p=c[o>>2]|0;q=c[o+4>>2]|0;a:do{if((p|0)==0&(q|0)==0|(p|0)==0&(q|0)==(-2147483648|0)){if((c[f+(d*400|0)+80>>2]&4|0)!=0){r=q;s=p;break}t=c[f+(d*400|0)+96>>2]|0;u=a[l]|0;v=u&255;w=v>>>3;x=v&3;do{if((u&255)>>>0<96>>>0){v=(w&3)*960|0;y=v>>>0<480>>>0?480:v}else{if(u<<24>>24>-1){y=480<<(w&1);break}else{y=120<<(w&3);break}}}while(0);do{if((x|0)==3){if((m|0)<2){break}z=a[j+(k+1)|0]&63;A=13}else if((x|0)==0){z=1;A=13}else{z=2;A=13}}while(0);do{if((A|0)==13){x=ca(z,y)|0;if((x|0)<0){break}w=j+(m+k)|0;u=c[f+(d*400|0)+92>>2]|0;if((t|0)<(u|0)){v=t;B=x;C=w;D=w;while(1){w=a[f+(d*400|0)+100+v|0]|0;E=D+(w&255)|0;if(w<<24>>24==-1|(E|0)==(C|0)){F=C;H=B}else{w=E-C|0;I=a[C]|0;J=I&255;K=J>>>3;L=J&3;do{if((I&255)>>>0<96>>>0){J=(K&3)*960|0;M=J>>>0<480>>>0?480:J}else{if(I<<24>>24>-1){M=480<<(K&1);break}else{M=120<<(K&3);break}}}while(0);do{if((L|0)==3){if((w|0)<2){N=-1094995529;break}O=a[C+1|0]&63;A=26}else if((L|0)==0){O=1;A=26}else{O=2;A=26}}while(0);if((A|0)==26){A=0;N=ca(O,M)|0}F=E;H=((N|0)>0?N:0)+B|0}L=v+1|0;if((L|0)<(u|0)){v=L;B=H;C=F;D=E}else{P=H;break}}}else{P=x}D=f+(d*400|0)+32|0;C=xrc(c[D>>2]|0,c[D+4>>2]|0,P,(P|0)<0|0?-1:0)|0;D=G;B=f+(d*400|0)+56|0;c[B>>2]=C;c[B+4>>2]=D;c[o>>2]=C;c[o+4>>2]=D;r=D;s=C;break a}}while(0);t=f+(d*400|0)+20|0;c[t>>2]=c[t>>2]|2;n=0;i=e;return n|0}else{r=q;s=p}}while(0);p=a[l]|0;l=p&255;q=l>>>3;P=l&3;do{if((p&255)>>>0<96>>>0){l=(q&3)*960|0;Q=l>>>0<480>>>0?480:l}else{if(p<<24>>24>-1){Q=480<<(q&1);break}else{Q=120<<(q&3);break}}}while(0);do{if((P|0)==3){if((m|0)<2){n=-1094995529;i=e;return n|0}else{R=a[j+(k+1)|0]&63;break}}else if((P|0)==0){R=1}else{R=2}}while(0);P=ca(R,Q)|0;if((P|0)<0){n=P;i=e;return n|0}Q=f+(d*400|0)+24|0;c[Q>>2]=P;if((s|0)==0&(r|0)==(-2147483648|0)){R=h+8|0;S=c[R+4>>2]|0;T=c[R>>2]|0}else{R=g+48|0;if((c[R>>2]|0)==0&(c[R+4>>2]|0)==(-2147483648|0)){c[R>>2]=s;c[R+4>>2]=r;U=c[o+4>>2]|0;V=c[o>>2]|0}else{U=r;V=s}s=xrc(V,U,c[h+4>>2]|0,0)|0;U=G;c[o>>2]=s;c[o+4>>2]=U;o=f+(d*400|0)+56|0;c[o>>2]=s;c[o+4>>2]=U;o=h+8|0;c[o>>2]=s;c[o+4>>2]=U;S=U;T=s}s=P;P=0;U=h+8|0;o=wrc(T,S,s,P)|0;S=G;c[U>>2]=o;c[U+4>>2]=S;if((c[f+(d*400|0)+80>>2]&4|0)==0){n=0;i=e;return n|0}U=f+(d*400|0)+32|0;T=xrc(o,S,c[U>>2]|0,c[U+4>>2]|0)|0;U=wrc(c[h+4>>2]|0,0,T,G)|0;T=G;h=(T|0)>(P|0)|(T|0)==(P|0)&U>>>0>s>>>0;S=h?s:U;U=h?P:T;T=0;if(!((U|0)>(T|0)|(U|0)==(T|0)&S>>>0>0>>>0)){n=0;i=e;return n|0}if((U|0)<(P|0)|(U|0)==(P|0)&S>>>0<s>>>0){T=xrc(s,P,S,U)|0;W=T}else{W=1}c[Q>>2]=W;c[f+(d*400|0)+380>>2]=S;KIb(b,48,2384512,(b=i,i=i+8|0,c[b>>2]=W,b)|0);i=b;n=0;i=e;return n|0}function mR(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=c[a+12>>2]|0;j=h;k=c[j>>2]|0;l=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;m=c[k+(b*400|0)>>2]|0;n=c[k+(b*400|0)+12>>2]|0;o=m+n|0;p=l+8|0;nrc((c[p>>2]|0)+16|0,2482464,9)|0;c[(c[p>>2]|0)+8>>2]=2;p=c[k+(b*400|0)+16>>2]|0;if((c[k+(b*400|0)+80>>2]&4|0)!=0&(p|0)==0){q=1;i=e;return q|0}if(p>>>0<8>>>0){q=-1;i=e;return q|0}if((krc(o,2129136,8)|0)==0){if(p>>>0<64>>>0){q=-1;i=e;return q|0}r=m+(n+8)|0;s=(d[r]|d[r+1|0]<<8)<<16>>16;if((s-3&65535)>>>0>1>>>0){r=m+(n+10)|0;t=(d[r]|d[r+1|0]<<8)<<16>>16&65535;KIb(a,24,2384472,(u=i,i=i+16|0,c[u>>2]=s&65535,c[u+8>>2]=t,u)|0);i=u;q=-1;i=e;return q|0}t=m+(n+12)|0;s=t|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=t+4|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=m+(n+20)|0;v=s|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=0;x=0;if(!(((s|0)>(v|0)|(s|0)==(v|0)&w>>>0>0>>>0)&((t|0)>(x|0)|(t|0)==(x|0)&r>>>0>0>>>0))){q=1;i=e;return q|0}xKb(f,g,r,t,w,s,2147483647,0)|0;_X(l,64,1,c[g>>2]|0);g=c[f>>2]|0;f=g;s=(g|0)<0|0?-1:0;g=l+48|0;c[g>>2]=f;c[g+4>>2]=s;g=k+(b*400|0)+48|0;c[g>>2]=f;c[g+4>>2]=s;q=1;i=e;return q|0}if((krc(o,2314216,8)|0)!=0){q=1;i=e;return q|0}if(p>>>0<52>>>0){q=-1;i=e;return q|0}p=m+(n+12)|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=c[h+4>>2]|0;h=0;while(1){if((h|0)>=(p|0)){break}y=c[j>>2]|0;if((c[y+(h*400|0)+28>>2]|0)==(o|0)){z=14;break}else{h=h+1|0}}do{if((z|0)==14){o=m+(n+36)|0;j=o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=o+4|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;if((h|0)<0){break}j=y+(h*400|0)+40|0;if(!((c[j>>2]|0)==(-1|0)&(c[j+4>>2]|0)==(-1|0))){KIb(a,24,2214640,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;q=1;i=e;return q|0}if((p|0)==(-1|0)&(o|0)==(-1|0)){q=1;i=e;return q|0}c[j>>2]=p;c[j+4>>2]=o;q=1;i=e;return q|0}}while(0);KIb(a,24,2261456,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;q=1;i=e;return q|0}function nR(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;f=c[c[a+12>>2]>>2]|0;g=f+(b*400|0)+392|0;h=c[g>>2]|0;j=c[(c[a+28>>2]|0)+(b<<2)>>2]|0;k=c[f+(b*400|0)>>2]|0;l=c[f+(b*400|0)+12>>2]|0;m=k+l|0;if((h|0)==0){n=pJb(12)|0;c[g>>2]=n;o=n}else{o=h}h=o+8|0;n=c[h>>2]|0;if((n|0)>1){p=0;i=e;return p|0}do{if((n|0)==0){g=j+8|0;q=c[g>>2]|0;c[q+8>>2]=1;c[q+48>>2]=86052;r=f+(b*400|0)+16|0;if((c[r>>2]|0)>>>0<68>>>0){KIb(a,16,2482408,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;p=-1094995529;i=e;return p|0}t=k+(l+36)|0;c[q+412>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;t=k+(l+48)|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q+416>>2]=u;if((u-1|0)>>>0>1>>>0){KIb(a,16,2384328,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;p=-1094995529;i=e;return p|0}t=(u|0)==1;u=q+448|0;c[u>>2]=t?4:3;c[u+4>>2]=t?0:0;t=k+(l+56)|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=o;c[t>>2]=u;v=k+(l+64)|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if((w|0)!=0){c[t>>2]=ca(w,u)|0}if((PX(q,c[r>>2]|0)|0)<0){p=-12;i=e;return p|0}else{r=c[g>>2]|0;nrc(c[r+96>>2]|0,m|0,c[r+100>>2]|0)|0;_X(j,64,1,c[(c[g>>2]|0)+412>>2]|0);break}}else{sR(a,j+88|0,m,c[f+(b*400|0)+16>>2]|0)|0}}while(0);c[h>>2]=(c[h>>2]|0)+1;p=1;i=e;return p|0}function oR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=c[c[b+12>>2]>>2]|0;b=c[e+(d*400|0)+392>>2]|0;f=c[b>>2]|0;g=e+(d*400|0)+80|0;h=e+(d*400|0)+48|0;i=c[h>>2]|0;j=c[h+4>>2]|0;do{if((c[g>>2]&4|0)==0){k=8}else{if((i|0)==0&(j|0)==(-2147483648|0)){break}h=e+(d*400|0)+32|0;l=c[h>>2]|0;m=c[h+4>>2]|0;if((l|0)==0&(m|0)==0){k=8;break}h=xrc(l,m,i,j)|0;m=G;l=c[e+(d*400|0)+92>>2]|0;if((l|0)>0){n=0;o=0;do{o=((a[e+(d*400|0)+100+n|0]|0)!=-1)+o|0;n=n+1|0;}while((n|0)<(l|0));p=o-1|0}else{p=-1}l=xrc(h,m,ca(p,f)|0,0)|0;c[b+4>>2]=l;k=8}}while(0);do{if((k|0)==8){p=e+(d*400|0)+48|0;if(!((i|0)==0&(j|0)==0)){break}l=e+(d*400|0)+32|0;n=c[l>>2]|0;q=c[l+4>>2]|0;if((n|0)==0&(q|0)==0){break}l=c[e+(d*400|0)+92>>2]|0;if((l|0)>0){r=0;s=0;while(1){t=((a[e+(d*400|0)+100+r|0]|0)!=-1)+s|0;u=r+1|0;if((u|0)<(l|0)){r=u;s=t}else{v=t;break}}}else{v=0}s=ca(v,f)|0;r=xrc(n,q,s,(s|0)<0|0?-1:0)|0;s=G;l=e+(d*400|0)+56|0;c[l>>2]=r;c[l+4>>2]=s;c[p>>2]=r;c[p+4>>2]=s}}while(0);do{if((c[g>>2]&4|0)!=0){if((c[e+(d*400|0)+96>>2]|0)!=(c[e+(d*400|0)+92>>2]|0)){break}v=c[b+4>>2]|0;if((v|0)==0){break}c[e+(d*400|0)+24>>2]=v;return 0}}while(0);c[e+(d*400|0)+24>>2]=f;return 0}function pR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;g=c[c[b+12>>2]>>2]|0;h=c[(c[b+28>>2]|0)+(e<<2)>>2]|0;j=g+(e*400|0)+392|0;k=c[j>>2]|0;l=h+8|0;m=g+(e*400|0)+16|0;n=(c[m>>2]|0)+(c[(c[l>>2]|0)+100>>2]|0)|0;o=n+2|0;p=g+(e*400|0)+12|0;q=c[p>>2]|0;r=g+(e*400|0)|0;e=c[r>>2]|0;g=a[e+q|0]|0;if(!(g<<24>>24<0)){s=0;i=f;return s|0}do{if((k|0)==0){t=pJb(12)|0;if((t|0)==0){s=-12;i=f;return s|0}else{c[j>>2]=t;u=c[p>>2]|0;v=c[r>>2]|0;w=t;x=u;y=v;z=a[v+u|0]|0;break}}else{w=k;x=q;y=e;z=g}}while(0);g=y+x|0;e=z&255;if((e|0)==130){A=24}else if((e|0)==129){sR(b,h+88|0,y+(x+7)|0,(c[m>>2]|0)-7|0)|0;A=24}else if((e|0)==128){x=c[m>>2]<<3;y=x>>>0>2147483639>>>0|(g|0)==0;z=y?0:g;g=y?8:x+8|0;x=(g|0)<56?g:56;y=z+(x>>>3)|0;q=je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=q>>>8;k=x+24|0;x=g>>>0>k>>>0?k:g;k=w+8|0;c[k>>2]=y;if(q>>>0<50397184>>>0){KIb(b,16,2482304,(B=i,i=i+8|0,c[B>>2]=y,B)|0);i=B;s=-38;i=f;return s|0}y=z+(x>>>3)|0;q=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>16;y=x+16|0;x=g>>>0>y>>>0?y:g;y=q<<4;q=c[l>>2]|0;j=q+120|0;c[j>>2]=y;u=z+(x>>>3)|0;v=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7)>>>16;u=x+16|0;x=g>>>0>u>>>0?u:g;u=v<<4;v=q+124|0;c[v>>2]=u;q=c[k>>2]|0;if(q>>>0>197631>>>0){t=x+100|0;C=g>>>0>t>>>0?t:g;A=11}else{if(q>>>0>197119>>>0){C=x;A=11}else{D=x}}if((A|0)==11){x=z+(C>>>3)|0;q=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(C&7)>>>8;x=C+24|0;C=g>>>0>x>>>0?x:g;x=z+(C>>>3)|0;t=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(C&7)>>>8;x=C+24|0;C=g>>>0>x>>>0?x:g;do{if(q>>>0<=y>>>0&(q|0)>(y-16|0)){if(!(t>>>0<=u>>>0&(t|0)>(u-16|0))){break}c[j>>2]=q;c[v>>2]=t}}while(0);t=C+16|0;D=g>>>0>t>>>0?t:g}t=z+(D>>>3)|0;C=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(D&7)&-65536;t=D+16|0;D=g>>>0>t>>>0?t:g;t=z+(D>>>3)|0;v=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(D&7)>>>16;t=D+16|0;D=g>>>0>t>>>0?t:g;t=v|C;C=z+(D>>>3)|0;v=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)&-65536;C=D+16|0;D=g>>>0>C>>>0?C:g;C=z+(D>>>3)|0;q=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)>>>16;C=D+16|0;D=g>>>0>C>>>0?C:g;C=q|v;if((C|0)>0&(t|0)>0){E=C;F=t}else{KIb(b,24,2384256,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;E=1;F=25}_X(h,64,E,F);F=z+(D>>>3)|0;E=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>8;F=D+24|0;D=g>>>0>F>>>0?F:g;c[h+80>>2]=E;E=z+(D>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>8;E=D+24|0;D=g>>>0>E>>>0?E:g;c[h+84>>2]=F;F=c[k>>2]|0;do{if(F>>>0>197119>>>0){k=-D|0;E=g-D|0;if((k|0)>38){G=k}else{G=(E|0)<38?E:38}E=G+D|0;if(!(F>>>0>3162111>>>0)){H=E;break}k=E+2|0;H=g>>>0>k>>>0?k:g}else{H=D}}while(0);D=z+(H>>>3)|0;z=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(H&7)>>>27;c[w>>2]=z;c[w+4>>2]=(1<<z)-1;z=c[l>>2]|0;c[z+8>>2]=0;c[z+48>>2]=31;c[h+236>>2]=2;I=z}else{KIb(b,16,2314136,(B=i,i=i+8|0,c[B>>2]=e,B)|0);i=B;s=-1094995529;i=f;return s|0}do{if((A|0)==24){if((c[w+8>>2]|0)==0){s=-1094995529;i=f;return s|0}else{I=c[l>>2]|0;break}}}while(0);w=lJb(I+96|0,n+18|0)|0;n=c[l>>2]|0;if((w|0)<0){c[n+100>>2]=0;s=w;i=f;return s|0}else{mrc((c[n+96>>2]|0)+o|0,0,16)|0;n=c[l>>2]|0;w=c[n+96>>2]|0;I=c[n+100>>2]|0;a[w+I|0]=(c[m>>2]|0)>>>8;a[w+(I+1)|0]=c[m>>2];nrc(w+(I+2)|0,(c[r>>2]|0)+(c[p>>2]|0)|0,c[m>>2]|0)|0;c[(c[l>>2]|0)+100>>2]=o;s=1;i=f;return s|0}return 0}function qR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[c[b+12>>2]>>2]|0;f=e+(d*400|0)+48|0;g=c[f>>2]|0;h=c[f+4>>2]|0;do{if((g|0)==0&(h|0)==0|(g|0)==0&(h|0)==(-2147483648|0)){if((c[e+(d*400|0)+80>>2]&4|0)!=0){break}i=c[e+(d*400|0)+96>>2]|0;j=c[e+(d*400|0)+92>>2]|0;if((i|0)<(j|0)){k=1;l=i;do{k=((a[e+(d*400|0)+100+l|0]|0)!=-1)+k|0;l=l+1|0;}while((l|0)<(j|0));m=(k|0)<0|0?-1:0;n=k}else{m=0;n=1}j=e+(d*400|0)+32|0;l=c[j>>2]|0;i=c[j+4>>2]|0;j=c[e+(d*400|0)+392>>2]|0;if((j|0)==0){o=-2147483648;p=0}else{q=zrc(l|0,i|0,c[j>>2]|0)|0;r=c[j+4>>2]|0;s=r&l;l=((r|0)<0|0?-1:0)&i;i=(c[j+8>>2]|0)>>>0<197121>>>0|0;if((s|0)==0&(l|0)==0){j=e+(d*400|0)+20|0;c[j>>2]=c[j>>2]|1}j=wrc(s,l,q,G)|0;q=wrc(j,G,i,0)|0;o=G;p=q}q=xrc(p,o,n,m)|0;i=G;j=e+(d*400|0)+56|0;c[j>>2]=q;c[j+4>>2]=i;c[f>>2]=q;c[f+4>>2]=i;j=c[(c[b+28>>2]|0)+(d<<2)>>2]|0;l=j+48|0;if(!((c[l>>2]|0)==0&(c[l+4>>2]|0)==(-2147483648|0))){break}c[l>>2]=q;c[l+4>>2]=i;l=j+56|0;j=c[l>>2]|0;s=c[l+4>>2]|0;if((j|0)==0&(s|0)==0){break}r=xrc(j,s,q,i)|0;c[l>>2]=r;c[l+4>>2]=G}}while(0);if((c[e+(d*400|0)+16>>2]|0)==0){return 0}c[e+(d*400|0)+24>>2]=1;return 0}function rR(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c[c[a+12>>2]>>2]|0;a=c[g+(b*400|0)+392>>2]|0;if((a|0)==0){h=-2147483648;i=0;return(G=h,i)|0}j=zrc(d|0,e|0,c[a>>2]|0)|0;k=c[a+4>>2]|0;l=k&d;d=((k|0)<0|0?-1:0)&e;e=wrc((c[a+8>>2]|0)>>>0<197121>>>0|0,0,j,G)|0;if((l|0)==0&(d|0)==0){j=g+(b*400|0)+20|0;c[j>>2]=c[j>>2]|1}j=wrc(e,G,l,d)|0;d=G;if((f|0)==0){h=d;i=j;return(G=h,i)|0}c[f>>2]=j;c[f+4>>2]=d;h=d;i=j;return(G=h,i)|0}



function Bwb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>a>>>0){i=e<<1;j=f<<1;k=i+e|0;l=j+f|0;m=k+e|0;n=l+f|0;o=d;p=a;while(1){b[p>>1]=(c[o>>2]|0)>>>16;b[p+f>>1]=(c[o+e>>2]|0)>>>16;b[p+j>>1]=(c[o+i>>2]|0)>>>16;b[p+l>>1]=(c[o+k>>2]|0)>>>16;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=d;t=a}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){b[v>>1]=(c[u>>2]|0)>>>16;t=v+f|0;if(t>>>0<g>>>0){u=u+e|0;v=t}else{break}}return}function Cwb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){h=d<<1;i=e<<1;j=h+d|0;k=i+e|0;l=j+d|0;m=k+e|0;n=b;o=a;while(1){c[o>>2]=c[n>>2];c[o+e>>2]=c[n+d>>2];c[o+i>>2]=c[n+h>>2];c[o+k>>2]=c[n+j>>2];p=n+l|0;q=o+m|0;if(q>>>0<g>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=b;s=a}if(s>>>0<f>>>0){t=r;u=s}else{return}while(1){c[u>>2]=c[t>>2];s=u+e|0;if(s>>>0<f>>>0){t=t+d|0;u=s}else{break}}return}function Dwb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=b;p=a;while(1){g[p>>2]=+(c[o>>2]|0)*4.656612873077393e-10;g[p+e>>2]=+(c[o+d>>2]|0)*4.656612873077393e-10;g[p+j>>2]=+(c[o+i>>2]|0)*4.656612873077393e-10;g[p+l>>2]=+(c[o+k>>2]|0)*4.656612873077393e-10;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){g[v>>2]=+(c[u>>2]|0)*4.656612873077393e-10;t=v+e|0;if(t>>>0<f>>>0){u=u+d|0;v=t}else{break}}return}function Ewb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=b;p=a;while(1){h[p>>3]=+(c[o>>2]|0)*4.656612873077393e-10;h[p+e>>3]=+(c[o+d>>2]|0)*4.656612873077393e-10;h[p+j>>3]=+(c[o+i>>2]|0)*4.656612873077393e-10;h[p+l>>3]=+(c[o+k>>2]|0)*4.656612873077393e-10;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){h[v>>3]=+(c[u>>2]|0)*4.656612873077393e-10;t=v+e|0;if(t>>>0<f>>>0){u=u+d|0;v=t}else{break}}return}function Fwb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=f+(e*-3|0)|0;if(h>>>0>b>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=b;while(1){q=Lc(+(+g[o>>2]*128.0))|0;r=q+128|0;if(r>>>0>255>>>0){s=-128-q>>31&255}else{s=r&255}a[p]=s;r=Lc(+(+g[o+d>>2]*128.0))|0;q=r+128|0;if(q>>>0>255>>>0){t=-128-r>>31&255}else{t=q&255}a[p+e|0]=t;q=Lc(+(+g[o+i>>2]*128.0))|0;r=q+128|0;if(r>>>0>255>>>0){u=-128-q>>31&255}else{u=r&255}a[p+j|0]=u;r=Lc(+(+g[o+k>>2]*128.0))|0;q=r+128|0;if(q>>>0>255>>>0){v=-128-r>>31&255}else{v=q&255}a[p+l|0]=v;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{w=q;x=r;break}}}else{w=c;x=b}if(x>>>0<f>>>0){y=w;z=x}else{return}while(1){x=Lc(+(+g[y>>2]*128.0))|0;w=x+128|0;if(w>>>0>255>>>0){A=-128-x>>31&255}else{A=w&255}a[z]=A;w=z+e|0;if(w>>>0<f>>>0){y=y+d|0;z=w}else{break}}return}function Gwb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=a;while(1){q=Lc(+(+g[o>>2]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){r=(q>>31^32767)&65535}else{r=q&65535}b[p>>1]=r;q=Lc(+(+g[o+d>>2]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){s=(q>>31^32767)&65535}else{s=q&65535}b[p+e>>1]=s;q=Lc(+(+g[o+i>>2]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){t=(q>>31^32767)&65535}else{t=q&65535}b[p+j>>1]=t;q=Lc(+(+g[o+k>>2]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){u=(q>>31^32767)&65535}else{u=q&65535}b[p+l>>1]=u;q=o+m|0;v=p+n|0;if(v>>>0<h>>>0){o=q;p=v}else{w=q;x=v;break}}}else{w=c;x=a}if(x>>>0<f>>>0){y=w;z=x}else{return}while(1){x=Lc(+(+g[y>>2]*32768.0))|0;if((x+32768|0)>>>0>65535>>>0){A=(x>>31^32767)&65535}else{A=x&65535}b[z>>1]=A;x=z+e|0;if(x>>>0<f>>>0){y=y+d|0;z=x}else{break}}return}function Hwb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=b;p=a;while(1){q=ge(+(+g[o>>2]*2147483648.0))|0;r=G;s=wrc(q,r,-2147483648,0)|0;t=G;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;v=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{v=q}c[p>>2]=v;q=ge(+(+g[o+d>>2]*2147483648.0))|0;r=G;s=wrc(q,r,-2147483648,0)|0;u=G;t=0;if(u>>>0>t>>>0|u>>>0==t>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;w=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{w=q}c[p+e>>2]=w;q=ge(+(+g[o+i>>2]*2147483648.0))|0;r=G;s=wrc(q,r,-2147483648,0)|0;t=G;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;x=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{x=q}c[p+j>>2]=x;q=ge(+(+g[o+k>>2]*2147483648.0))|0;r=G;s=wrc(q,r,-2147483648,0)|0;u=G;t=0;if(u>>>0>t>>>0|u>>>0==t>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;y=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{y=q}c[p+l>>2]=y;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{z=q;A=r;break}}}else{z=b;A=a}if(A>>>0<f>>>0){B=z;C=A}else{return}while(1){A=ge(+(+g[B>>2]*2147483648.0))|0;z=G;a=wrc(A,z,-2147483648,0)|0;b=G;p=0;if(b>>>0>p>>>0|b>>>0==p>>>0&a>>>0>-1>>>0){((z|0)<0|0?-1:0)>>31|((z|0)<0|0?-1:0)<<1;D=(z>>31|((z|0)<0|0?-1:0)<<1)^2147483647}else{D=A}c[C>>2]=D;A=C+e|0;if(A>>>0<f>>>0){B=B+d|0;C=A}else{break}}return}function Iwb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=e+(d*-3|0)|0;if(f>>>0>a>>>0){h=c<<1;i=d<<1;j=h+c|0;k=i+d|0;l=j+c|0;m=k+d|0;n=b;o=a;while(1){g[o>>2]=+g[n>>2];g[o+d>>2]=+g[n+c>>2];g[o+i>>2]=+g[n+h>>2];g[o+k>>2]=+g[n+j>>2];p=n+l|0;q=o+m|0;if(q>>>0<f>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=b;s=a}if(s>>>0<e>>>0){t=r;u=s}else{return}while(1){g[u>>2]=+g[t>>2];s=u+d|0;if(s>>>0<e>>>0){t=t+c|0;u=s}else{break}}return}function Jwb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=e+(d*-3|0)|0;if(f>>>0>a>>>0){i=c<<1;j=d<<1;k=i+c|0;l=j+d|0;m=k+c|0;n=l+d|0;o=b;p=a;while(1){h[p>>3]=+g[o>>2];h[p+d>>3]=+g[o+c>>2];h[p+j>>3]=+g[o+i>>2];h[p+l>>3]=+g[o+k>>2];q=o+m|0;r=p+n|0;if(r>>>0<f>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<e>>>0){u=s;v=t}else{return}while(1){h[v>>3]=+g[u>>2];t=v+d|0;if(t>>>0<e>>>0){u=u+c|0;v=t}else{break}}return}function Kwb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=f+(e*-3|0)|0;if(g>>>0>b>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=b;while(1){q=Lc(+(+h[o>>3]*128.0))|0;r=q+128|0;if(r>>>0>255>>>0){s=-128-q>>31&255}else{s=r&255}a[p]=s;r=Lc(+(+h[o+d>>3]*128.0))|0;q=r+128|0;if(q>>>0>255>>>0){t=-128-r>>31&255}else{t=q&255}a[p+e|0]=t;q=Lc(+(+h[o+i>>3]*128.0))|0;r=q+128|0;if(r>>>0>255>>>0){u=-128-q>>31&255}else{u=r&255}a[p+j|0]=u;r=Lc(+(+h[o+k>>3]*128.0))|0;q=r+128|0;if(q>>>0>255>>>0){v=-128-r>>31&255}else{v=q&255}a[p+l|0]=v;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{w=q;x=r;break}}}else{w=c;x=b}if(x>>>0<f>>>0){y=w;z=x}else{return}while(1){x=Lc(+(+h[y>>3]*128.0))|0;w=x+128|0;if(w>>>0>255>>>0){A=-128-x>>31&255}else{A=w&255}a[z]=A;w=z+e|0;if(w>>>0<f>>>0){y=y+d|0;z=w}else{break}}return}function Lwb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=a;while(1){q=Lc(+(+h[o>>3]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){r=(q>>31^32767)&65535}else{r=q&65535}b[p>>1]=r;q=Lc(+(+h[o+d>>3]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){s=(q>>31^32767)&65535}else{s=q&65535}b[p+e>>1]=s;q=Lc(+(+h[o+i>>3]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){t=(q>>31^32767)&65535}else{t=q&65535}b[p+j>>1]=t;q=Lc(+(+h[o+k>>3]*32768.0))|0;if((q+32768|0)>>>0>65535>>>0){u=(q>>31^32767)&65535}else{u=q&65535}b[p+l>>1]=u;q=o+m|0;v=p+n|0;if(v>>>0<g>>>0){o=q;p=v}else{w=q;x=v;break}}}else{w=c;x=a}if(x>>>0<f>>>0){y=w;z=x}else{return}while(1){x=Lc(+(+h[y>>3]*32768.0))|0;if((x+32768|0)>>>0>65535>>>0){A=(x>>31^32767)&65535}else{A=x&65535}b[z>>1]=A;x=z+e|0;if(x>>>0<f>>>0){y=y+d|0;z=x}else{break}}return}function Mwb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=b;p=a;while(1){q=ge(+(+h[o>>3]*2147483648.0))|0;r=G;s=wrc(q,r,-2147483648,0)|0;t=G;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;v=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{v=q}c[p>>2]=v;q=ge(+(+h[o+d>>3]*2147483648.0))|0;r=G;s=wrc(q,r,-2147483648,0)|0;u=G;t=0;if(u>>>0>t>>>0|u>>>0==t>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;w=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{w=q}c[p+e>>2]=w;q=ge(+(+h[o+i>>3]*2147483648.0))|0;r=G;s=wrc(q,r,-2147483648,0)|0;t=G;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;x=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{x=q}c[p+j>>2]=x;q=ge(+(+h[o+k>>3]*2147483648.0))|0;r=G;s=wrc(q,r,-2147483648,0)|0;u=G;t=0;if(u>>>0>t>>>0|u>>>0==t>>>0&s>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;y=(r>>31|((r|0)<0|0?-1:0)<<1)^2147483647}else{y=q}c[p+l>>2]=y;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{z=q;A=r;break}}}else{z=b;A=a}if(A>>>0<f>>>0){B=z;C=A}else{return}while(1){A=ge(+(+h[B>>3]*2147483648.0))|0;z=G;a=wrc(A,z,-2147483648,0)|0;b=G;p=0;if(b>>>0>p>>>0|b>>>0==p>>>0&a>>>0>-1>>>0){((z|0)<0|0?-1:0)>>31|((z|0)<0|0?-1:0)<<1;D=(z>>31|((z|0)<0|0?-1:0)<<1)^2147483647}else{D=A}c[C>>2]=D;A=C+e|0;if(A>>>0<f>>>0){B=B+d|0;C=A}else{break}}return}function Nwb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=e+(d*-3|0)|0;if(f>>>0>a>>>0){i=c<<1;j=d<<1;k=i+c|0;l=j+d|0;m=k+c|0;n=l+d|0;o=b;p=a;while(1){g[p>>2]=+h[o>>3];g[p+d>>2]=+h[o+c>>3];g[p+j>>2]=+h[o+i>>3];g[p+l>>2]=+h[o+k>>3];q=o+m|0;r=p+n|0;if(r>>>0<f>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<e>>>0){u=s;v=t}else{return}while(1){g[v>>2]=+h[u>>3];t=v+d|0;if(t>>>0<e>>>0){u=u+c|0;v=t}else{break}}return}function Owb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=e+(d*-3|0)|0;if(f>>>0>a>>>0){g=c<<1;i=d<<1;j=g+c|0;k=i+d|0;l=j+c|0;m=k+d|0;n=b;o=a;while(1){h[o>>3]=+h[n>>3];h[o+d>>3]=+h[n+c>>3];h[o+i>>3]=+h[n+g>>3];h[o+k>>3]=+h[n+j>>3];p=n+l|0;q=o+m|0;if(q>>>0<f>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=b;s=a}if(s>>>0<e>>>0){t=r;u=s}else{return}while(1){h[u>>3]=+h[t>>3];s=u+d|0;if(s>>>0<e>>>0){t=t+c|0;u=s}else{break}}return}function Pwb(a,d,e,f,j){a=a|0;d=d|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0;k=i;l=a+88|0;m=+g[a+100>>2];a=e+2|0;if(a>>>0>268435454>>>0){n=0}else{n=hJb(a<<3)|0}o=n;a:do{if((a|0)>0){p=c[l>>2]|0;q=p>>>0<72>>>0;if((p|0)==1){p=f;r=0;while(1){p=(ca(p,1664525)|0)+1013904223|0;h[o+(r<<3)>>3]=+(p>>>0>>>0)/4294967295.0+-.5;r=r+1|0;if((r|0)>=(a|0)){break a}}}else{s=f;t=0}while(1){r=(ca(s,1664525)|0)+1013904223|0;if(!q){break}s=(ca(r,1664525)|0)+1013904223|0;h[o+(t<<3)>>3]=+(r>>>0>>>0)/4294967295.0- +(s>>>0>>>0)/4294967295.0;t=t+1|0;if((t|0)>=(a|0)){break a}}KIb(0,0,2417144,(u=i,i=i+24|0,c[u>>2]=2579960,c[u+8>>2]=2436552,c[u+16>>2]=39,u)|0);i=u;Hd()}}while(0);if((e|0)<=0){kJb(n);i=k;return}a=c[l>>2]|0;l=d;t=d;s=d;f=d;if((a|0)==3){d=0;while(1){v=m*((+h[o+(d+1<<3)>>3]*2.0- +h[o+(d<<3)>>3]- +h[o+(d+2<<3)>>3])/2.449489742783178);if((j|0)==6){b[l+(d<<1)>>1]=~~v}else if((j|0)==8){g[s+(d<<2)>>2]=v}else if((j|0)==7){c[t+(d<<2)>>2]=~~v}else if((j|0)==9){h[f+(d<<3)>>3]=v}else{w=25;break}q=d+1|0;if((q|0)<(e|0)){d=q}else{w=26;break}}if((w|0)==25){KIb(0,0,2417144,(u=i,i=i+24|0,c[u>>2]=2349928,c[u+8>>2]=2436552,c[u+16>>2]=68,u)|0);i=u;Hd()}else if((w|0)==26){kJb(n);i=k;return}}if(a>>>0<72>>>0){x=0}else{KIb(0,0,2417144,(u=i,i=i+24|0,c[u>>2]=2579960,c[u+8>>2]=2436552,c[u+16>>2]=53,u)|0);i=u;Hd()}while(1){v=m*+h[o+(x<<3)>>3];if((j|0)==6){b[l+(x<<1)>>1]=~~v}else if((j|0)==9){h[f+(x<<3)>>3]=v}else if((j|0)==7){c[t+(x<<2)>>2]=~~v}else if((j|0)==8){g[s+(x<<2)>>2]=v}else{w=25;break}a=x+1|0;if((a|0)<(e|0)){x=a}else{w=26;break}}if((w|0)==25){KIb(0,0,2417144,(u=i,i=i+24|0,c[u>>2]=2349928,c[u+8>>2]=2436552,c[u+16>>2]=68,u)|0);i=u;Hd()}else if((w|0)==26){kJb(n);i=k;return}}function Qwb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0;e=i;f=a+88|0;if(((c[f>>2]|0)-4|0)>>>0<61>>>0){j=-22;i=e;return j|0}k=NKb(b)|0;b=NKb(d)|0;do{if((b-3|0)>>>0<2>>>0){d=(k|0)==2;l=(k|0)==0?.0078125:(k|0)==1?30517578125.0e-15:d?-4.656612873077393e-10:0.0;m=0;n=d}else{d=(b|0)==2;o=(k|0)==2;if(!(d&o)){l=0.0;m=d;n=o;break}l=(c[a+5624>>2]&31|0)==0?0.0:1.0;m=1;n=1}}while(0);o=(k|0)==0;p=+g[a+96>>2]*((b|0)==1&o?256.0:m&o?16777216.0:m&(k|0)==1?65536.0:l);do{if(n){m=c[a+5624>>2]|0;if((m|0)==0){q=p;break}q=p*+(1<<32-m|0)}else{q=p}}while(0);c[a+116>>2]=0;p=q;n=a+100|0;g[n>>2]=p;g[a+108>>2]=p;if(q!=0.0){r=1.0/q}else{r=0.0}m=a+112|0;g[m>>2]=r;mrc(a+200|0,0,5120)|0;o=c[a+44>>2]|0;b=0;d=1224056;while(1){s=c[1224040+(b*24|0)>>2]|0;if(!(+R(+(+(o-s|0)))/+(s|0)>.05)){if((c[1224060+(b*24|0)>>2]|0)==(c[f>>2]|0)){t=14;break}}s=b+1|0;if((s|0)==15){t=19;break}else{b=s;d=1224056+(s*24|0)|0}}do{if((t|0)==14){o=c[1224048+(b*24|0)>>2]|0;c[a+104>>2]=o;if((b|0)!=15){s=c[d>>2]|0;u=0;do{g[a+120+(u<<2)>>2]=+h[s+(u<<3)>>3];u=u+1|0;}while(u>>>0<o>>>0)}r=+$(+(c[1224052+(b*24|0)>>2]|0)*2.302585092994046*.005)*2.0;q=1.0-r/+(1<<((QKb(k)|0)<<3)|0);g[m>>2]=q*+g[m>>2]}else if((t|0)==19){if(!((c[f>>2]|0)>>>0>64>>>0)){break}KIb(a,24,2288096,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;c[f>>2]=3}}while(0);if((c[a+6304>>2]|0)!=0){KIb(0,0,2417144,(v=i,i=i+24|0,c[v>>2]=2238144,c[v+8>>2]=2436552,c[v+16>>2]=122,v)|0);i=v;Hd();return 0}v=a+6164|0;nrc(a+5320|0,v|0,152)|0;nrc(a+5472|0,v|0,152)|0;if(!((c[f>>2]|0)>>>0>64>>>0)){j=0;i=e;return j|0}c[a+5456>>2]=4;c[a+5468>>2]=8;g[n>>2]=1.0;j=0;i=e;return j|0}function Rwb(a,d,e,f,h){a=a|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0,G=0.0,H=0.0,I=0,J=0;i=a+116|0;j=c[i>>2]|0;k=c[a+104>>2]|0;l=+g[a+112>>2];m=c[e+132>>2]|0;if((m|0)<=0){n=j;c[i>>2]=n;return}o=a+92|0;p=(h|0)>0;q=k-2|0;r=(q|0)>0;s=+g[a+108>>2];t=0;u=j;while(1){j=c[f+(t<<2)>>2]|0;v=c[o>>2]|0;w=c[e+(t<<2)>>2]|0;x=c[d+(t<<2)>>2]|0;if(p){y=0;z=u;while(1){A=l*+(b[w+(y<<1)>>1]|0);if(r){B=0;C=A;while(1){D=B+z|0;E=C-(+g[a+120+(B<<2)>>2]*+g[a+200+(t*160|0)+(D<<2)>>2]+ +g[a+120+((B|1)<<2)>>2]*+g[a+200+(t*160|0)+(D+1<<2)>>2]+ +g[a+120+((B|2)<<2)>>2]*+g[a+200+(t*160|0)+(D+2<<2)>>2]+ +g[a+120+((B|3)<<2)>>2]*+g[a+200+(t*160|0)+(D+3<<2)>>2]);D=B+4|0;if((D|0)<(q|0)){B=D;C=E}else{F=D;G=E;break}}}else{F=0;G=A}if((F|0)<(k|0)){H=G- +g[a+120+(F<<2)>>2]*+g[a+200+(t*160|0)+(F+z<<2)>>2]}else{H=G}B=((z|0)!=0?z:k)-1|0;C=+Lc(+(H+ +g[j+(y+v<<2)>>2]));E=C-H;g[a+200+(t*160|0)+(B<<2)>>2]=E;g[a+200+(t*160|0)+(B+k<<2)>>2]=E;E=s*C;C=E>32767.0?32767.0:E;if(C>-32768.0){I=~~C}else{I=-32768}b[x+(y<<1)>>1]=I;D=y+1|0;if((D|0)<(h|0)){y=D;z=B}else{J=B;break}}}else{J=u}z=t+1|0;if((z|0)>=(m|0)){n=J;break}t=z;u=c[i>>2]|0}c[i>>2]=n;return}function Swb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0,G=0.0,H=0.0,I=0,J=0,K=0;h=a+116|0;i=c[h>>2]|0;j=c[a+104>>2]|0;k=+g[a+112>>2];l=d+132|0;m=c[l>>2]|0;if((m|0)<=0){n=i;c[h>>2]=n;return}o=a+92|0;p=(f|0)>0;q=j-2|0;r=(q|0)>0;s=+g[a+108>>2];t=0;u=m;m=i;while(1){i=c[e+(t<<2)>>2]|0;v=c[o>>2]|0;w=c[d+(t<<2)>>2]|0;x=c[b+(t<<2)>>2]|0;if(p){y=0;z=m;do{A=k*+(c[w+(y<<2)>>2]|0);if(r){B=0;C=A;while(1){D=B+z|0;E=C-(+g[a+120+(B<<2)>>2]*+g[a+200+(t*160|0)+(D<<2)>>2]+ +g[a+120+((B|1)<<2)>>2]*+g[a+200+(t*160|0)+(D+1<<2)>>2]+ +g[a+120+((B|2)<<2)>>2]*+g[a+200+(t*160|0)+(D+2<<2)>>2]+ +g[a+120+((B|3)<<2)>>2]*+g[a+200+(t*160|0)+(D+3<<2)>>2]);D=B+4|0;if((D|0)<(q|0)){B=D;C=E}else{F=D;G=E;break}}}else{F=0;G=A}if((F|0)<(j|0)){H=G- +g[a+120+(F<<2)>>2]*+g[a+200+(t*160|0)+(F+z<<2)>>2]}else{H=G}z=((z|0)!=0?z:j)-1|0;C=+Lc(+(H+ +g[i+(y+v<<2)>>2]));E=C-H;g[a+200+(t*160|0)+(z<<2)>>2]=E;g[a+200+(t*160|0)+(z+j<<2)>>2]=E;E=s*C;C=E>2147483647.0?2147483647.0:E;if(C>-2147483648.0){I=~~C}else{I=-2147483648}c[x+(y<<2)>>2]=I;y=y+1|0;}while((y|0)<(f|0));J=z;K=c[l>>2]|0}else{J=m;K=u}y=t+1|0;if((y|0)>=(K|0)){n=J;break}t=y;u=K;m=c[h>>2]|0}c[h>>2]=n;return}function Twb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0,E=0,F=0.0,G=0.0,H=0;h=a+116|0;i=c[h>>2]|0;j=c[a+104>>2]|0;k=+g[a+112>>2];l=c[d+132>>2]|0;if((l|0)<=0){m=i;c[h>>2]=m;return}n=a+92|0;o=(f|0)>0;p=j-2|0;q=(p|0)>0;r=+g[a+108>>2];s=0;t=i;while(1){i=c[e+(s<<2)>>2]|0;u=c[n>>2]|0;v=c[d+(s<<2)>>2]|0;w=c[b+(s<<2)>>2]|0;if(o){x=0;y=t;while(1){z=k*+g[v+(x<<2)>>2];if(q){A=0;B=z;while(1){C=A+y|0;D=B-(+g[a+120+(A<<2)>>2]*+g[a+200+(s*160|0)+(C<<2)>>2]+ +g[a+120+((A|1)<<2)>>2]*+g[a+200+(s*160|0)+(C+1<<2)>>2]+ +g[a+120+((A|2)<<2)>>2]*+g[a+200+(s*160|0)+(C+2<<2)>>2]+ +g[a+120+((A|3)<<2)>>2]*+g[a+200+(s*160|0)+(C+3<<2)>>2]);C=A+4|0;if((C|0)<(p|0)){A=C;B=D}else{E=C;F=D;break}}}else{E=0;F=z}if((E|0)<(j|0)){G=F- +g[a+120+(E<<2)>>2]*+g[a+200+(s*160|0)+(E+y<<2)>>2]}else{G=F}A=((y|0)!=0?y:j)-1|0;B=+Lc(+(G+ +g[i+(x+u<<2)>>2]));D=B-G;g[a+200+(s*160|0)+(A<<2)>>2]=D;g[a+200+(s*160|0)+(A+j<<2)>>2]=D;g[w+(x<<2)>>2]=r*B;C=x+1|0;if((C|0)<(f|0)){x=C;y=A}else{H=A;break}}}else{H=t}y=s+1|0;if((y|0)>=(l|0)){m=H;break}s=y;t=c[h>>2]|0}c[h>>2]=m;return}function Uwb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0,G=0.0,H=0.0,I=0;i=a+116|0;j=c[i>>2]|0;k=c[a+104>>2]|0;l=c[d+132>>2]|0;if((l|0)<=0){m=j;c[i>>2]=m;return}n=a+92|0;o=(f|0)>0;p=+g[a+112>>2];q=k-2|0;r=(q|0)>0;s=+g[a+108>>2];t=0;u=j;while(1){j=c[e+(t<<2)>>2]|0;v=c[n>>2]|0;w=c[d+(t<<2)>>2]|0;x=c[b+(t<<2)>>2]|0;if(o){y=0;z=u;while(1){A=p*+h[w+(y<<3)>>3];if(r){B=0;C=A;while(1){D=B+z|0;E=C-(+g[a+120+(B<<2)>>2]*+g[a+200+(t*160|0)+(D<<2)>>2]+ +g[a+120+((B|1)<<2)>>2]*+g[a+200+(t*160|0)+(D+1<<2)>>2]+ +g[a+120+((B|2)<<2)>>2]*+g[a+200+(t*160|0)+(D+2<<2)>>2]+ +g[a+120+((B|3)<<2)>>2]*+g[a+200+(t*160|0)+(D+3<<2)>>2]);D=B+4|0;if((D|0)<(q|0)){B=D;C=E}else{F=D;G=E;break}}}else{F=0;G=A}if((F|0)<(k|0)){H=G- +g[a+120+(F<<2)>>2]*+g[a+200+(t*160|0)+(F+z<<2)>>2]}else{H=G}B=((z|0)!=0?z:k)-1|0;C=+Lc(+(H+ +g[j+(y+v<<2)>>2]));E=C-H;g[a+200+(t*160|0)+(B<<2)>>2]=E;g[a+200+(t*160|0)+(B+k<<2)>>2]=E;h[x+(y<<3)>>3]=s*C;D=y+1|0;if((D|0)<(f|0)){y=D;z=B}else{I=B;break}}}else{I=u}z=t+1|0;if((z|0)>=(l|0)){m=I;break}t=z;u=c[i>>2]|0}c[i>>2]=m;return}function Vwb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;j=a+24|0;k=c[j>>2]|0;l=a+28|0;m=c[l>>2]|0;n=a+20|0;o=c[n>>2]|0;p=a+32|0;q=c[p>>2]|0;r=(o|0)%(q|0)|0;s=(o|0)/(q|0)|0;t=a+36|0;u=c[t>>2]|0;v=a+8|0;a:do{if((u|0)==0){w=c[v>>2]|0;do{if((w|0)==1){if((c[a+40>>2]|0)!=0){break}x=o;y=q;z=(q|0)<0|0?-1:0;A=Crc(0,x,y,z)|0;B=G;C=(h|0)<0|0?-1:0;D=g-1-k|0;E=Erc(y,z,D,(D|0)<0|0?-1:0)|0;D=Crc(E,G,x,(o|0)<0|0?-1:0)|0;x=G;E=(C|0)>(x|0)|(C|0)==(x|0)&h>>>0>D>>>0?D:h;if((E|0)>0){D=k;x=0;C=0;while(1){b[d+(C<<1)>>1]=b[e+(D<<1)>>1]|0;F=wrc(x,D,A,B)|0;H=C+1|0;if((H|0)<(E|0)){D=G;x=F;C=H}else{I=E;break}}}else{I=0}E=(ca(I,s)|0)+k|0;C=Erc(I,(I|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;x=wrc(C,G,m,(m|0)<0|0?-1:0)|0;C=G;D=Crc(x,C,y,z)|0;B=wrc(D,G,E,0)|0;E=B;B=Drc(x,C,y,z)|0;c[f>>2]=E;J=I;K=0;L=s;M=r;N=B;O=c[a+44>>2]&E;break a}}while(0);if(!((c[a+48>>2]|0)==0&(k|0)>-1)){P=0;Q=8;break}b:do{if((h|0)>0){E=c[a+40>>2]|0;B=c[a+44>>2]|0;C=c[a+4>>2]|0;x=c[a+12>>2]|0;D=k;A=m;H=0;F=0;while(1){R=(D>>E)+H|0;S=B&D;T=ca(x,S)|0;if((w+R|0)>(g|0)){U=R;V=S;W=A;X=F;break b}do{if((w|0)>0){Y=0;Z=0;do{Z=(ca(b[C+(Y+T<<1)>>1]|0,b[e+(Y+R<<1)>>1]|0)|0)+Z|0;Y=Y+1|0;}while((Y|0)<(w|0));Y=Z+16384|0;_=Y>>15;if(!((_+32768|0)>>>0>65535>>>0)){$=_&65535;break}$=(Y>>31^32767)&65535}else{$=0}}while(0);b[d+(F<<1)>>1]=$;T=A+r|0;Y=S+s|0;if((T|0)<(q|0)){aa=T;ba=Y}else{aa=T-q|0;ba=Y+1|0}Y=F+1|0;if((Y|0)<(h|0)){D=ba;A=aa;H=R;F=Y}else{U=R;V=ba;W=aa;X=Y;break}}}else{U=0;V=k;W=m;X=0}}while(0);c[f>>2]=U;J=X;K=0;L=s;M=r;N=W;O=V}else{P=u;Q=8}}while(0);if((Q|0)==8){u=a+40|0;V=a+44|0;W=a+4|0;X=a+12|0;U=a+48|0;aa=a+16|0;a=0;ba=0;$=P;P=s;s=r;r=m;m=k;c:while(1){k=a;da=ba;ea=r;I=m;while(1){if((da|0)>=(h|0)){fa=k;ga=I;break c}ha=(I>>c[u>>2])+k|0;o=c[V>>2]&I;w=c[W>>2]|0;F=c[X>>2]|0;H=ca(F,o)|0;A=c[v>>2]|0;if(!((A+ha|0)<=(g|0)&(-ha|0)<(g|0))){fa=ha;ga=o;break c}d:do{if((ha|0)<0){if((A|0)>0){ia=0;ja=0}else{ka=0;break}while(1){D=ia+ha|0;C=(ca(b[w+(ia+H<<1)>>1]|0,b[e+(((D|0)>-1?D:-D|0)<<1)>>1]|0)|0)+ja|0;D=ia+1|0;if((D|0)<(A|0)){ia=D;ja=C}else{la=C;Q=32;break}}}else{R=(A|0)>0;if((c[U>>2]|0)==0){if(R){ma=0;na=0}else{ka=0;break}while(1){S=(ca(b[w+(ma+H<<1)>>1]|0,b[e+(ma+ha<<1)>>1]|0)|0)+na|0;C=ma+1|0;if((C|0)<(A|0)){ma=C;na=S}else{la=S;Q=32;break d}}}if(R){S=0;C=0;D=0;while(1){x=b[e+(S+ha<<1)>>1]|0;B=S+H|0;E=(ca(b[w+(B<<1)>>1]|0,x)|0)+C|0;z=(ca(b[w+(B+F<<1)>>1]|0,x)|0)+D|0;x=S+1|0;if((x|0)<(A|0)){S=x;C=E;D=z}else{oa=E;pa=z;break}}}else{oa=0;pa=0}D=pa-oa|0;C=Erc(D,(D|0)<0|0?-1:0,ea,(ea|0)<0|0?-1:0)|0;D=Crc(C,G,q,(q|0)<0|0?-1:0)|0;C=wrc(D,G,oa,0)|0;la=C;Q=32}}while(0);do{if((Q|0)==32){Q=0;A=la+16384|0;F=A>>15;if(!((F+32768|0)>>>0>65535>>>0)){ka=F&65535;break}ka=(A>>31^32767)&65535}}while(0);b[d+(da<<1)>>1]=ka;A=s+ea|0;F=o+P|0;if((A|0)<(q|0)){qa=A;ra=F}else{qa=A-q|0;ra=F+1|0}F=da+1|0;if((F|0)==($|0)){break}else{k=ha;da=F;ea=qa;I=ra}}I=c[aa>>2]|0;a=ha;ba=$;$=0;P=(I|0)/(q|0)|0;s=(I|0)%(q|0)|0;r=qa;m=ra}ra=(fa|0)>0;c[f>>2]=ra?fa:0;J=da;K=($|0)==0?0:$-da|0;L=P;M=s;N=ea;O=((ra?0:fa)<<c[u>>2])+ga|0}if((i|0)==0){return J|0}c[l>>2]=N;c[j>>2]=O;c[n>>2]=(ca(c[p>>2]|0,L)|0)+M;c[t>>2]=K;return J|0}function Wwb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;i=a+24|0;j=c[i>>2]|0;k=a+28|0;l=c[k>>2]|0;m=a+20|0;n=c[m>>2]|0;o=a+32|0;p=c[o>>2]|0;q=(n|0)%(p|0)|0;r=(n|0)/(p|0)|0;s=a+36|0;t=c[s>>2]|0;u=a+8|0;a:do{if((t|0)==0){v=c[u>>2]|0;do{if((v|0)==1){w=a+40|0;if((c[w>>2]|0)!=0){break}x=n;y=p;z=(p|0)<0|0?-1:0;A=Crc(0,x,y,z)|0;B=G;C=(g|0)<0|0?-1:0;D=f-1-j|0;E=Erc(y,z,D,(D|0)<0|0?-1:0)|0;D=Crc(E,G,x,(n|0)<0|0?-1:0)|0;x=G;E=(C|0)>(x|0)|(C|0)==(x|0)&g>>>0>D>>>0?D:g;if((E|0)>0){D=j;x=0;C=0;while(1){c[b+(C<<2)>>2]=c[d+(D<<2)>>2];z=wrc(x,D,A,B)|0;y=C+1|0;if((y|0)<(E|0)){D=G;x=z;C=y}else{break}}F=E;H=c[o>>2]|0;I=c[w>>2]|0}else{F=0;H=p;I=0}C=(ca(F,r)|0)+j|0;x=Erc(F,(F|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;D=wrc(x,G,l,(l|0)<0|0?-1:0)|0;x=G;B=H;A=(H|0)<0|0?-1:0;y=Crc(D,x,B,A)|0;z=wrc(y,G,C,0)|0;C=z;z=Drc(D,x,B,A)|0;c[e>>2]=C>>I;J=F;K=0;L=r;M=q;N=z;O=c[a+44>>2]&C;break a}}while(0);if(!((c[a+48>>2]|0)==0&(j|0)>-1)){P=0;Q=9;break}C=a+40|0;b:do{if((g|0)>0){z=a+44|0;A=c[a+4>>2]|0;B=a+12|0;x=j;D=l;y=0;R=0;S=v;while(1){T=(x>>c[C>>2])+y|0;U=c[z>>2]&x;V=ca(c[B>>2]|0,U)|0;if((S+T|0)>(f|0)){W=T;X=U;Y=D;Z=R;break b}do{if((S|0)>0){_=0;$=0;aa=0;do{ba=c[d+(_+T<<2)>>2]|0;da=c[A+(_+V<<2)>>2]|0;ea=Erc(da,(da|0)<0|0?-1:0,ba,(ba|0)<0|0?-1:0)|0;aa=wrc(ea,G,aa,$)|0;$=G;_=_+1|0;}while((_|0)<(S|0));_=wrc(aa,$,536870912,0)|0;ea=G;ba=_>>>30|ea<<2;_=wrc(ba,ea>>30|((ea|0)<0|0?-1:0)<<2,-2147483648,0)|0;da=G;fa=0;if(!(da>>>0>fa>>>0|da>>>0==fa>>>0&_>>>0>-1>>>0)){ga=ba;break}((ea|0)<0|0?-1:0)>>31|((ea|0)<0|0?-1:0)<<1;ga=(ea>>31|((ea|0)<0|0?-1:0)<<1)^2147483647}else{ga=0}}while(0);c[b+(R<<2)>>2]=ga;V=D+q|0;ea=U+r|0;ba=c[o>>2]|0;if((V|0)<(ba|0)){ha=V;ia=ea}else{ha=V-ba|0;ia=ea+1|0}ea=R+1|0;if((ea|0)>=(g|0)){W=T;X=ia;Y=ha;Z=ea;break b}x=ia;D=ha;y=T;R=ea;S=c[u>>2]|0}}else{W=0;X=j;Y=l;Z=0}}while(0);c[e>>2]=W;J=Z;K=0;L=r;M=q;N=Y;O=X}else{P=t;Q=9}}while(0);if((Q|0)==9){t=a+40|0;X=a+44|0;Y=a+4|0;Z=a+12|0;W=a+48|0;ha=a+16|0;a=0;ia=0;ga=P;P=r;r=q;q=l;l=j;j=p;c:while(1){p=a;ja=ia;ka=q;F=l;I=j;while(1){if((ja|0)>=(g|0)){la=p;ma=F;break c}na=(F>>c[t>>2])+p|0;H=c[X>>2]&F;n=c[Y>>2]|0;C=c[Z>>2]|0;v=ca(C,H)|0;S=c[u>>2]|0;if(!((S+na|0)<=(f|0)&(-na|0)<(f|0))){la=na;ma=H;break c}d:do{if((na|0)<0){if((S|0)>0){oa=0;pa=0;qa=0}else{ra=0;break}while(1){R=oa+na|0;y=c[d+(((R|0)>-1?R:-R|0)<<2)>>2]|0;R=c[n+(oa+v<<2)>>2]|0;D=Erc(R,(R|0)<0|0?-1:0,y,(y|0)<0|0?-1:0)|0;y=wrc(D,G,qa,pa)|0;D=G;R=oa+1|0;if((R|0)<(S|0)){oa=R;pa=D;qa=y}else{sa=D;ta=y;Q=34;break}}}else{T=(S|0)>0;if((c[W>>2]|0)==0){if(T){ua=0;va=0;wa=0}else{ra=0;break}while(1){U=c[d+(ua+na<<2)>>2]|0;y=c[n+(ua+v<<2)>>2]|0;D=Erc(y,(y|0)<0|0?-1:0,U,(U|0)<0|0?-1:0)|0;U=wrc(D,G,wa,va)|0;D=G;y=ua+1|0;if((y|0)<(S|0)){ua=y;va=D;wa=U}else{sa=D;ta=U;Q=34;break d}}}if(T){U=0;D=0;y=0;R=0;x=0;while(1){A=c[d+(U+na<<2)>>2]|0;B=A;z=(A|0)<0|0?-1:0;A=U+v|0;w=c[n+(A<<2)>>2]|0;E=Erc(w,(w|0)<0|0?-1:0,B,z)|0;w=wrc(E,G,y,D)|0;E=G;ea=c[n+(A+C<<2)>>2]|0;A=Erc(ea,(ea|0)<0|0?-1:0,B,z)|0;z=wrc(A,G,x,R)|0;A=G;B=U+1|0;if((B|0)<(S|0)){U=B;D=E;y=w;R=A;x=z}else{xa=E;ya=w;za=A;Aa=z;break}}}else{xa=0;ya=0;za=0;Aa=0}x=xrc(Aa,za,ya,xa)|0;R=Erc(x,G,ka,(ka|0)<0|0?-1:0)|0;x=Crc(R,G,I,(I|0)<0|0?-1:0)|0;R=wrc(x,G,ya,xa)|0;sa=G;ta=R;Q=34}}while(0);do{if((Q|0)==34){Q=0;S=wrc(ta,sa,536870912,0)|0;C=G;n=S>>>30|C<<2;S=wrc(n,C>>30|((C|0)<0|0?-1:0)<<2,-2147483648,0)|0;v=G;R=0;if(!(v>>>0>R>>>0|v>>>0==R>>>0&S>>>0>-1>>>0)){ra=n;break}((C|0)<0|0?-1:0)>>31|((C|0)<0|0?-1:0)<<1;ra=(C>>31|((C|0)<0|0?-1:0)<<1)^2147483647}}while(0);c[b+(ja<<2)>>2]=ra;C=r+ka|0;n=H+P|0;Ba=c[o>>2]|0;if((C|0)<(Ba|0)){Ca=C;Da=n}else{Ca=C-Ba|0;Da=n+1|0}n=ja+1|0;if((n|0)==(ga|0)){break}else{p=na;ja=n;ka=Ca;F=Da;I=Ba}}I=c[ha>>2]|0;a=na;ia=ga;ga=0;P=(I|0)/(Ba|0)|0;r=(I|0)%(Ba|0)|0;q=Ca;l=Da;j=Ba}Ba=(la|0)>0;c[e>>2]=Ba?la:0;J=ja;K=(ga|0)==0?0:ga-ja|0;L=P;M=r;N=ka;O=((Ba?0:la)<<c[t>>2])+ma|0}if((h|0)==0){return J|0}c[k>>2]=N;c[i>>2]=O;c[m>>2]=(ca(c[o>>2]|0,L)|0)+M;c[s>>2]=K;return J|0}function Xwb(a,b,d,e,f,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0.0,_=0.0,$=0,aa=0.0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0.0,ma=0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0,ta=0;j=a+24|0;k=c[j>>2]|0;l=a+28|0;m=c[l>>2]|0;n=a+20|0;o=c[n>>2]|0;p=a+32|0;q=c[p>>2]|0;r=(o|0)%(q|0)|0;s=(o|0)/(q|0)|0;t=a+36|0;u=c[t>>2]|0;v=a+8|0;a:do{if((u|0)==0){w=c[v>>2]|0;do{if((w|0)==1){if((c[a+40>>2]|0)!=0){break}x=o;y=q;z=(q|0)<0|0?-1:0;A=Crc(0,x,y,z)|0;B=G;C=(h|0)<0|0?-1:0;D=f-1-k|0;E=Erc(y,z,D,(D|0)<0|0?-1:0)|0;D=Crc(E,G,x,(o|0)<0|0?-1:0)|0;x=G;E=(C|0)>(x|0)|(C|0)==(x|0)&h>>>0>D>>>0?D:h;if((E|0)>0){D=k;x=0;C=0;while(1){g[b+(C<<2)>>2]=+g[d+(D<<2)>>2];F=wrc(x,D,A,B)|0;H=C+1|0;if((H|0)<(E|0)){D=G;x=F;C=H}else{I=E;break}}}else{I=0}E=(ca(I,s)|0)+k|0;C=Erc(I,(I|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;x=wrc(C,G,m,(m|0)<0|0?-1:0)|0;C=G;D=Crc(x,C,y,z)|0;B=wrc(D,G,E,0)|0;E=B;B=Drc(x,C,y,z)|0;c[e>>2]=E;J=I;K=0;L=s;M=r;N=B;O=c[a+44>>2]&E;break a}}while(0);if(!((c[a+48>>2]|0)==0&(k|0)>-1)){P=0;Q=8;break}b:do{if((h|0)>0){E=c[a+40>>2]|0;B=c[a+44>>2]|0;C=c[a+4>>2]|0;x=c[a+12>>2]|0;D=k;A=m;H=0;F=0;while(1){R=(D>>E)+H|0;S=B&D;T=ca(x,S)|0;if((w+R|0)>(f|0)){U=R;V=S;W=A;X=F;break b}if((w|0)>0){Y=0;Z=0.0;while(1){_=Z+ +g[d+(Y+R<<2)>>2]*+g[C+(Y+T<<2)>>2];$=Y+1|0;if(($|0)<(w|0)){Y=$;Z=_}else{aa=_;break}}}else{aa=0.0}g[b+(F<<2)>>2]=aa;Y=A+r|0;T=S+s|0;if((Y|0)<(q|0)){ba=Y;da=T}else{ba=Y-q|0;da=T+1|0}T=F+1|0;if((T|0)<(h|0)){D=da;A=ba;H=R;F=T}else{U=R;V=da;W=ba;X=T;break}}}else{U=0;V=k;W=m;X=0}}while(0);c[e>>2]=U;J=X;K=0;L=s;M=r;N=W;O=V}else{P=u;Q=8}}while(0);if((Q|0)==8){Q=a+40|0;u=a+44|0;V=a+4|0;W=a+12|0;X=a+48|0;U=a+16|0;a=0;ba=0;da=P;P=s;s=r;r=m;m=k;c:while(1){k=a;ea=ba;fa=r;I=m;while(1){if((ea|0)>=(h|0)){ga=k;ha=I;break c}ia=(I>>c[Q>>2])+k|0;o=c[u>>2]&I;w=c[V>>2]|0;F=c[W>>2]|0;H=ca(F,o)|0;A=c[v>>2]|0;if(!((A+ia|0)<=(f|0)&(-ia|0)<(f|0))){ga=ia;ha=o;break c}d:do{if((ia|0)<0){if((A|0)>0){ja=0;ka=0.0}else{la=0.0;break}while(1){D=ja+ia|0;aa=ka+ +g[d+(((D|0)>-1?D:-D|0)<<2)>>2]*+g[w+(ja+H<<2)>>2];D=ja+1|0;if((D|0)<(A|0)){ja=D;ka=aa}else{la=aa;break}}}else{R=(A|0)>0;if((c[X>>2]|0)==0){if(R){ma=0;na=0.0}else{la=0.0;break}while(1){aa=na+ +g[d+(ma+ia<<2)>>2]*+g[w+(ma+H<<2)>>2];S=ma+1|0;if((S|0)<(A|0)){ma=S;na=aa}else{la=aa;break d}}}if(R){S=0;aa=0.0;Z=0.0;while(1){_=+g[d+(S+ia<<2)>>2];D=S+H|0;oa=aa+_*+g[w+(D<<2)>>2];pa=Z+_*+g[w+(D+F<<2)>>2];D=S+1|0;if((D|0)<(A|0)){S=D;aa=oa;Z=pa}else{qa=oa;ra=pa;break}}}else{qa=0.0;ra=0.0}la=qa+ +(fa|0)*(ra-qa)/+(q|0)}}while(0);g[b+(ea<<2)>>2]=la;A=s+fa|0;F=o+P|0;if((A|0)<(q|0)){sa=A;ta=F}else{sa=A-q|0;ta=F+1|0}F=ea+1|0;if((F|0)==(da|0)){break}else{k=ia;ea=F;fa=sa;I=ta}}I=c[U>>2]|0;a=ia;ba=da;da=0;P=(I|0)/(q|0)|0;s=(I|0)%(q|0)|0;r=sa;m=ta}ta=(ga|0)>0;c[e>>2]=ta?ga:0;J=ea;K=(da|0)==0?0:da-ea|0;L=P;M=s;N=fa;O=((ta?0:ga)<<c[Q>>2])+ha|0}if((i|0)==0){return J|0}c[l>>2]=N;c[j>>2]=O;c[n>>2]=(ca(c[p>>2]|0,L)|0)+M;c[t>>2]=K;return J|0}function Ywb(a,b,d,e,f,g,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0.0,_=0.0,$=0,aa=0.0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0.0,ma=0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0,ta=0;j=a+24|0;k=c[j>>2]|0;l=a+28|0;m=c[l>>2]|0;n=a+20|0;o=c[n>>2]|0;p=a+32|0;q=c[p>>2]|0;r=(o|0)%(q|0)|0;s=(o|0)/(q|0)|0;t=a+36|0;u=c[t>>2]|0;v=a+8|0;a:do{if((u|0)==0){w=c[v>>2]|0;do{if((w|0)==1){if((c[a+40>>2]|0)!=0){break}x=o;y=q;z=(q|0)<0|0?-1:0;A=Crc(0,x,y,z)|0;B=G;C=(g|0)<0|0?-1:0;D=f-1-k|0;E=Erc(y,z,D,(D|0)<0|0?-1:0)|0;D=Crc(E,G,x,(o|0)<0|0?-1:0)|0;x=G;E=(C|0)>(x|0)|(C|0)==(x|0)&g>>>0>D>>>0?D:g;if((E|0)>0){D=k;x=0;C=0;while(1){h[b+(C<<3)>>3]=+h[d+(D<<3)>>3];F=wrc(x,D,A,B)|0;H=C+1|0;if((H|0)<(E|0)){D=G;x=F;C=H}else{I=E;break}}}else{I=0}E=(ca(I,s)|0)+k|0;C=Erc(I,(I|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;x=wrc(C,G,m,(m|0)<0|0?-1:0)|0;C=G;D=Crc(x,C,y,z)|0;B=wrc(D,G,E,0)|0;E=B;B=Drc(x,C,y,z)|0;c[e>>2]=E;J=I;K=0;L=s;M=r;N=B;O=c[a+44>>2]&E;break a}}while(0);if(!((c[a+48>>2]|0)==0&(k|0)>-1)){P=0;Q=8;break}b:do{if((g|0)>0){E=c[a+40>>2]|0;B=c[a+44>>2]|0;C=c[a+4>>2]|0;x=c[a+12>>2]|0;D=k;A=m;H=0;F=0;while(1){R=(D>>E)+H|0;S=B&D;T=ca(x,S)|0;if((w+R|0)>(f|0)){U=R;V=S;W=A;X=F;break b}if((w|0)>0){Y=0;Z=0.0;while(1){_=Z+ +h[d+(Y+R<<3)>>3]*+h[C+(Y+T<<3)>>3];$=Y+1|0;if(($|0)<(w|0)){Y=$;Z=_}else{aa=_;break}}}else{aa=0.0}h[b+(F<<3)>>3]=aa;Y=A+r|0;T=S+s|0;if((Y|0)<(q|0)){ba=Y;da=T}else{ba=Y-q|0;da=T+1|0}T=F+1|0;if((T|0)<(g|0)){D=da;A=ba;H=R;F=T}else{U=R;V=da;W=ba;X=T;break}}}else{U=0;V=k;W=m;X=0}}while(0);c[e>>2]=U;J=X;K=0;L=s;M=r;N=W;O=V}else{P=u;Q=8}}while(0);if((Q|0)==8){Q=a+40|0;u=a+44|0;V=a+4|0;W=a+12|0;X=a+48|0;U=a+16|0;a=0;ba=0;da=P;P=s;s=r;r=m;m=k;c:while(1){k=a;ea=ba;fa=r;I=m;while(1){if((ea|0)>=(g|0)){ga=k;ha=I;break c}ia=(I>>c[Q>>2])+k|0;o=c[u>>2]&I;w=c[V>>2]|0;F=c[W>>2]|0;H=ca(F,o)|0;A=c[v>>2]|0;if(!((A+ia|0)<=(f|0)&(-ia|0)<(f|0))){ga=ia;ha=o;break c}d:do{if((ia|0)<0){if((A|0)>0){ja=0;ka=0.0}else{la=0.0;break}while(1){D=ja+ia|0;aa=ka+ +h[d+(((D|0)>-1?D:-D|0)<<3)>>3]*+h[w+(ja+H<<3)>>3];D=ja+1|0;if((D|0)<(A|0)){ja=D;ka=aa}else{la=aa;break}}}else{R=(A|0)>0;if((c[X>>2]|0)==0){if(R){ma=0;na=0.0}else{la=0.0;break}while(1){aa=na+ +h[d+(ma+ia<<3)>>3]*+h[w+(ma+H<<3)>>3];S=ma+1|0;if((S|0)<(A|0)){ma=S;na=aa}else{la=aa;break d}}}if(R){S=0;aa=0.0;Z=0.0;while(1){_=+h[d+(S+ia<<3)>>3];D=S+H|0;oa=aa+_*+h[w+(D<<3)>>3];pa=Z+_*+h[w+(D+F<<3)>>3];D=S+1|0;if((D|0)<(A|0)){S=D;aa=oa;Z=pa}else{qa=oa;ra=pa;break}}}else{qa=0.0;ra=0.0}la=qa+ +(fa|0)*(ra-qa)/+(q|0)}}while(0);h[b+(ea<<3)>>3]=la;A=s+fa|0;F=o+P|0;if((A|0)<(q|0)){sa=A;ta=F}else{sa=A-q|0;ta=F+1|0}F=ea+1|0;if((F|0)==(da|0)){break}else{k=ia;ea=F;fa=sa;I=ta}}I=c[U>>2]|0;a=ia;ba=da;da=0;P=(I|0)/(q|0)|0;s=(I|0)%(q|0)|0;r=sa;m=ta}ta=(ga|0)>0;c[e>>2]=ta?ga:0;J=ea;K=(da|0)==0?0:da-ea|0;L=P;M=s;N=fa;O=((ta?0:ga)<<c[Q>>2])+ha|0}if((i|0)==0){return J|0}c[l>>2]=N;c[j>>2]=O;c[n>>2]=(ca(c[p>>2]|0,L)|0)+M;c[t>>2]=K;return J|0}function Zwb(a,d,e,f,j,k,l,m,n,o,p,q){a=a|0;d=d|0;e=e|0;f=f|0;j=j|0;k=k|0;l=+l;m=m|0;n=n|0;o=o|0;p=+p;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0.0,O=0,P=0,Q=0,T=0,W=0,X=0.0,Y=0,Z=0.0,_=0.0,$=0.0,aa=0,da=0.0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;q=i;p=+(d|0)*(l!=0.0?l:.97)/+(e|0);l=p>1.0?1.0:p;r=1<<j;do{if((a|0)==0){s=9}else{if((c[a+40>>2]|0)!=(j|0)){s=9;break}if((c[a+48>>2]|0)!=(k|0)){s=9;break}if(+h[a+64>>3]!=l){s=9;break}t=~~+ba(+(f|0)/l);if((c[a+8>>2]|0)!=(((t|0)>1?t:1)|0)){s=9;break}if((c[a+72>>2]|0)!=(m|0)){s=9;break}if((c[a+52>>2]|0)!=(n|0)){s=9;break}if((c[a+56>>2]|0)==(o|0)){u=a;s=57}else{s=9}}}while(0);do{if((s|0)==9){a=pJb(88)|0;t=a;if((a|0)==0){v=0;i=q;return v|0}w=a+72|0;c[w>>2]=m;x=QKb(m)|0;y=a+76|0;c[y>>2]=x;z=c[w>>2]|0;if((z|0)==6){c[a+80>>2]=15}else if((z|0)==7){c[a+80>>2]=30}else if((z|0)==8|(z|0)==9){c[a+80>>2]=0}else{KIb(0,16,2349896,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;KIb(0,0,2416976,(A=i,i=i+24|0,c[A>>2]=2288088,c[A+8>>2]=2436520,c[A+16>>2]=229,A)|0);i=A;Hd();return 0}p=+(f|0)/l;if(p>8388607.0){KIb(0,16,2238088,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;B=t;break}c[a+40>>2]=j;c[a+44>>2]=r-1;c[a+48>>2]=k;h[a+64>>3]=l;z=~~+ba(p);C=(z|0)>1?z:1;z=a+8|0;c[z>>2]=C;D=C+7&-8;C=a+12|0;c[C>>2]=D;E=qJb(D,ca(x,r+1|0)|0)|0;x=a+4|0;c[x>>2]=E;c[a+52>>2]=n;c[a+56>>2]=o;if((E|0)==0){B=t;break}D=c[z>>2]|0;z=c[C>>2]|0;F=1<<c[a+80>>2];if(D>>>0>268435454>>>0){B=t;break}a=hJb(D<<3)|0;H=a;I=(D-1|0)/2|0;if((a|0)==0){B=t;break}a:do{if((r|0)>0){J=(D|0)>0;p=+(r|0);K=l*+(D|0);L=K*3.141592653589793;M=+(o|0);N=+(F|0);O=E;P=E;Q=E;T=E;W=0;b:while(1){if(J){X=+(W|0)/p;if((n|0)==0){Y=0;Z=0.0;while(1){_=+R(+(l*(+(Y-I|0)-X)));if(_<1.0){$=1.0-_*_*3.0+_*_*_*2.0+(_*(-0.0-_)+_*_*_)*-.5}else{$=(_*_*_+(_*8.0+-4.0-_*_*5.0))*-.5}h[H+(Y<<3)>>3]=$;_=Z+$;aa=Y+1|0;if((aa|0)<(D|0)){Y=aa;Z=_}else{da=_;break}}}else if((n|0)==2){Y=0;Z=0.0;while(1){_=l*(+(Y-I|0)-X)*3.141592653589793;if(_==0.0){ea=1.0}else{ea=+V(_)/_}fa=_*2.0/L;_=1.0-fa*fa;fa=M*+S(_>0.0?_:0.0);_=fa*fa*.25;fa=1.0;ga=1.0;aa=0;while(1){ha=ga*_*+h[1954120+(aa<<3)>>3];ia=fa+ha;if(ia!=fa){fa=ia;ga=ha;aa=aa+1|0}else{break}}ga=ea*ia;h[H+(Y<<3)>>3]=ga;fa=Z+ga;aa=Y+1|0;if((aa|0)<(D|0)){Y=aa;Z=fa}else{da=fa;break}}}else{Y=0;Z=0.0;while(1){fa=l*(+(Y-I|0)-X)*3.141592653589793;if(fa==0.0){ja=1.0}else{ja=+V(fa)/fa}if((n|0)!=1){break b}ga=fa*2.0/K+3.141592653589793;fa=ja*(.3635819- +U(ga)*.4891775+ +U(ga*2.0)*.1365995- +U(ga*3.0)*.0106411);h[H+(Y<<3)>>3]=fa;ga=Z+fa;aa=Y+1|0;if((aa|0)<(D|0)){Y=aa;Z=ga}else{da=ga;break}}}}else{da=0.0}Y=c[w>>2]|0;do{if((Y|0)==9){if(!J){break}aa=ca(W,z)|0;ka=0;do{h[O+(ka+aa<<3)>>3]=N*+h[H+(ka<<3)>>3]/da;ka=ka+1|0;}while((ka|0)<(D|0))}else if((Y|0)==8){if(!J){break}ka=ca(W,z)|0;aa=0;do{g[P+(aa+ka<<2)>>2]=N*+h[H+(aa<<3)>>3]/da;aa=aa+1|0;}while((aa|0)<(D|0))}else if((Y|0)==6){if(!J){break}aa=ca(W,z)|0;ka=0;do{la=Lc(+(N*+h[H+(ka<<3)>>3]/da))|0;if((la|0)<-32768){ma=-32768}else{ma=(la|0)>32767?32767:la&65535}b[T+(ka+aa<<1)>>1]=ma;ka=ka+1|0;}while((ka|0)<(D|0))}else if((Y|0)==7){if(!J){break}ka=ca(W,z)|0;aa=0;do{la=ge(+(N*+h[H+(aa<<3)>>3]/da))|0;na=G;oa=wrc(la,na,-2147483648,0)|0;pa=G;qa=0;if(pa>>>0>qa>>>0|pa>>>0==qa>>>0&oa>>>0>-1>>>0){((na|0)<0|0?-1:0)>>31|((na|0)<0|0?-1:0)<<1;ra=(na>>31|((na|0)<0|0?-1:0)<<1)^2147483647}else{ra=la}c[Q+(aa+ka<<2)>>2]=ra;aa=aa+1|0;}while((aa|0)<(D|0))}}while(0);W=W+1|0;if((W|0)>=(r|0)){break a}}KIb(0,0,2416976,(A=i,i=i+24|0,c[A>>2]=2288088,c[A+8>>2]=2436520,c[A+16>>2]=130,A)|0);i=A;Hd();return 0}}while(0);kJb(a);D=c[x>>2]|0;H=c[C>>2]|0;z=c[y>>2]|0;nrc(D+(ca((H<<j)+1|0,z)|0)|0,D|0,ca(H-1|0,z)|0)|0;z=c[x>>2]|0;H=c[C>>2]|0;D=c[y>>2]|0;nrc(z+(ca(H<<j,D)|0)|0,z+(ca(H-1|0,D)|0)|0,D)|0;u=t;s=57}}while(0);do{if((s|0)==57){c[u+36>>2]=0;j=u+20|0;A=Erc(r,(r|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;if((xKb(u+32|0,j,d,(d|0)<0|0?-1:0,A,G,1073741823,0)|0)==0){B=u;break}c[u+16>>2]=c[j>>2];c[u+24>>2]=ca(((c[u+8>>2]|0)-1|0)/2|0,-r|0)|0;c[u+28>>2]=0;v=u;i=q;return v|0}}while(0);mJb(B+4|0);kJb(B);v=0;i=q;return v|0}function _wb(a){a=a|0;var b=0;b=c[a>>2]|0;if((b|0)==0){return}mJb(b+4|0);mJb(a);return}function $wb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;AGb()|0;h=b+132|0;i=c[h>>2]|0;if((i|0)<=0){j=-1;return j|0}k=a+72|0;l=-1;m=0;n=i;while(1){i=c[k>>2]|0;if((i|0)==7){o=m+1|0;p=Wwb(a,c[b+(m<<2)>>2]|0,c[e+(m<<2)>>2]|0,g,f,d,(o|0)==(n|0)|0)|0;q=o}else if((i|0)==6){o=m+1|0;p=Vwb(a,c[b+(m<<2)>>2]|0,c[e+(m<<2)>>2]|0,g,f,d,(o|0)==(n|0)|0)|0;q=o}else if((i|0)==9){o=m+1|0;p=Ywb(a,c[b+(m<<2)>>2]|0,c[e+(m<<2)>>2]|0,g,f,d,(o|0)==(n|0)|0)|0;q=o}else if((i|0)==8){i=m+1|0;p=Xwb(a,c[b+(m<<2)>>2]|0,c[e+(m<<2)>>2]|0,g,f,d,(i|0)==(n|0)|0)|0;q=i}else{p=l;q=m+1|0}i=c[h>>2]|0;if((q|0)<(i|0)){l=p;m=q;n=i}else{j=p;break}}return j|0}function axb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=a+6924|0;e=a+6928|0;f=awb(a+6468|0,(c[e>>2]<<1)+(c[d>>2]|0)|0)|0;if((f|0)<0){g=f;i=b;return g|0}if((c[a+6612>>2]|0)==0){KIb(0,0,2416976,(f=i,i=i+24|0,c[f>>2]=2579936,c[f+8>>2]=2436520,c[f+16>>2]=359,f)|0);i=f;Hd();return 0}f=a+6600|0;h=c[f>>2]|0;if((h|0)>0){j=a+6604|0;k=0;l=c[e>>2]|0;m=h;while(1){if((l|0)>0){h=a+6468+(k<<2)|0;n=0;o=l;do{p=c[h>>2]|0;q=(c[d>>2]|0)+o|0;r=c[j>>2]|0;nrc(p+(ca(q+n|0,r)|0)|0,p+(ca(q+~n|0,r)|0)|0,r)|0;n=n+1|0;o=c[e>>2]|0;}while((n|0)<(o|0));s=o;t=c[f>>2]|0}else{s=l;t=m}n=k+1|0;if((n|0)<(t|0)){k=n;l=s;m=t}else{u=s;break}}}else{u=c[e>>2]|0}c[e>>2]=((u+1|0)/2|0)+u;g=0;i=b;return g|0}function bxb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;c[a+36>>2]=d;e=c[a+16>>2]|0;if((d|0)==0){c[a+20>>2]=e;return 0}else{f=e;g=(e|0)<0|0?-1:0;e=Erc(f,g,b,(b|0)<0|0?-1:0)|0;b=Crc(e,G,d,(d|0)<0|0?-1:0)|0;d=xrc(f,g,b,G)|0;c[a+20>>2]=d;return 0}return 0}function cxb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+6976>>2]|0;f=(c[a+6928>>2]|0)-(((c[e+8>>2]|0)-1|0)/2|0)|0;g=c[e+40>>2]|0;h=yrc(f|0,((f|0)<0|0?-1:0)|0,g|0)|0;f=c[e+24>>2]|0;i=xrc(h,G,f,(f|0)<0|0?-1:0)|0;f=c[e+32>>2]|0;h=f;j=(f|0)<0|0?-1:0;f=Erc(i,G,h,j)|0;i=c[e+28>>2]|0;e=xrc(f,G,i,(i|0)<0|0?-1:0)|0;i=G;f=c[a+40>>2]|0;a=Erc(f,(f|0)<0|0?-1:0,h,j)|0;j=yrc(a|0,G|0,g|0)|0;g=VIb(e,i,b,d,j,G)|0;return(G=G,g)|0}function dxb(a){a=a|0;return 2182624}function exb(){return 525328}function fxb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=c[b+56>>2]|0;iAb(b,b+23892|0,b+23896|0,b+23900|0,b+23904|0,b+23908|0,b+23912|0,b+23916|0);dyb(b);f=b+68|0;g=c[f>>2]|0;do{if((c[b+72>>2]|0)==8){h=b+23956|0;if((g|0)>=15){c[h>>2]=342;c[b+23952>>2]=342;break}c[h>>2]=686;c[b+23952>>2]=686;if((c[b+2284>>2]&1|0)==0){break}c[b+23944>>2]=196;c[b+23948>>2]=132}else{h=(g|0)>14?550:618;c[b+23956>>2]=h;c[b+23952>>2]=h}}while(0);g=b+11260|0;a:do{if((c[g>>2]|0)!=(c[b+11264>>2]|0)){h=c[b+52>>2]|0;switch(h|0){case 321:case 325:case 326:case 322:case 327:case 328:case 323:case 329:case 330:case 324:case 331:case 332:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 3:case 9:{break a;break};default:{}}j=qKb(h)|0;if((j|0)==0){KIb(0,0,2288040,(h=i,i=i+24|0,c[h>>2]=2238064,c[h+8>>2]=2197496,c[h+16>>2]=674,h)|0);i=h;Hd();return 0}if(!((a[j+7|0]&32)==0)){break}j=(c[g>>2]|0)!=0;h=b+23960|0;if((c[f>>2]|0)<15){if(j){c[h>>2]=534;c[b+23964>>2]=1538;break}else{c[h>>2]=430;c[b+23964>>2]=214;break}}else{if(j){c[h>>2]=270;c[b+23964>>2]=2182;break}else{c[h>>2]=598;c[b+23964>>2]=1042;break}}}}while(0);if((e|0)==66|(e|0)==32|(e|0)==31|(e|0)==8){i=d;return 104}f=c[b+52>>2]|0;if((f|0)==8|(f|0)==66|(f|0)==31|(f|0)==32){i=d;return 104}if((e-9|0)>>>0<2>>>0){i=d;return 104}c[b+23968>>2]=1;i=d;return 104}function gxb(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0;n=i;i=i+104|0;o=n|0;p=n+8|0;q=n+16|0;r=n+24|0;s=n+32|0;t=n+40|0;u=n+48|0;v=n+56|0;w=n+72|0;x=n+88|0;z=c[f+8>>2]|0;A=c[f+19608>>2]|0;B=c[f+16>>2]|0;C=c[f+28>>2]|0;D=c[f+20>>2]|0;E=c[f+36>>2]|0;F=c[f+40>>2]|0;G=c[f+52>>2]|0;H=c[f+2284>>2]|0;I=c[f+2236>>2]|0;J=c[f+2240>>2]|0;K=c[f+2228>>2]|0;L=c[f+2232>>2]|0;M=c[f+2212>>2]|0;N=c[f+2216>>2]|0;O=f+11416|0;P=f+15512|0;Q=c[f+2252>>2]|0;R=c[f+2256>>2]|0;S=c[f+2244>>2]|0;T=c[f+2248>>2]|0;U=c[f+2168>>2]|0;V=c[f+2172>>2]|0;W=c[f+2176>>2]|0;X=c[f+2180>>2]|0;Y=c[f+2184>>2]|0;Z=c[f+2188>>2]|0;_=c[f+2208>>2]|0;$=f+120|0;c[o>>2]=c[f+23892>>2];c[p>>2]=c[f+23896>>2];c[q>>2]=c[f+23900>>2];aa=f+23904|0;c[r>>2]=c[aa>>2];ba=f+23908|0;c[s>>2]=c[ba>>2];c[t>>2]=c[f+23912>>2];c[u>>2]=c[f+23916>>2];da=f+80|0;ea=c[da>>2]|0;fa=j>>ea;ga=-k>>ea;ea=-ga|0;ha=f+56|0;ia=qKb(c[ha>>2]|0)|0;if((ia|0)==0){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=644,ja)|0);i=ja;Hd();return 0}do{if((((e[ia+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){ka=1}else{la=qKb(c[ha>>2]|0)|0;if((la|0)==0){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=637,ja)|0);i=ja;Hd();return 0}else{ka=(b[la+8>>1]&30720)==30720;break}}}while(0);ia=f+2280|0;la=c[ia>>2]|0;ma=f+2200|0;na=c[ma>>2]|0;oa=f+2204|0;pa=c[oa>>2]|0;qa=f+2192|0;ra=c[qa>>2]|0;sa=f+2196|0;ta=c[sa>>2]|0;ua=qKb(c[ha>>2]|0)|0;if((ua|0)==0){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=828,ja)|0);i=ja;Hd();return 0}va=d[ua+7|0]|0;if((va&2|0)==0){wa=(va&64|0)==0}else{wa=0}va=f+10496|0;ua=wa?va:$;switch(c[ha>>2]|0){case 11:case 1:case 17:case 66:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 3:case 9:{ha=c[g>>2]|0;c[g+12>>2]=ha;c[g+8>>2]=ha;c[g+4>>2]=ha;ha=c[h>>2]|0;c[h+12>>2]=ha;c[h+8>>2]=ha;c[h+4>>2]=ha;xa=ha;ya=ha;break};default:{xa=c[h+4>>2]|0;ya=c[h+8>>2]|0}}ha=f+92|0;$=h+4|0;c[$>>2]=xa<<c[ha>>2];xa=h+8|0;c[xa>>2]=ya<<c[ha>>2];do{if((c[m>>2]&15|0)==0){if((c[m+4>>2]&15|0)!=0){za=18;break}if((c[m+8>>2]&15|0)!=0){za=18;break}if((c[m+12>>2]&15|0)!=0){za=18}}else{za=18}}while(0);do{if((za|0)==18){if((H&4096|0)==0|a[523520]){break}KIb(f,24,2165896,(ja=i,i=i+1|0,i=i+7&-8,c[ja>>2]=0,ja)|0);i=ja;a[523520]=1}}while(0);do{if((c[l>>2]&15|0)==0){if((c[l+4>>2]&15|0)!=0){za=34;break}if((c[l+8>>2]&15|0)!=0){za=34;break}if((c[g>>2]&15|0)!=0){za=34;break}if((c[g+4>>2]&15|0)!=0){za=34;break}if((c[g+8>>2]&15|0)!=0){za=34;break}if((c[m>>2]&15|0)!=0){za=34;break}if((c[m+4>>2]&15|0)!=0){za=34;break}if((c[m+8>>2]&15|0)!=0){za=34;break}if((c[m+12>>2]&15|0)!=0){za=34;break}if((c[h>>2]&15|0)!=0){za=34;break}if((c[$>>2]&15|0)!=0){za=34;break}if((c[xa>>2]&15|0)!=0){za=34;break}if((c[h+12>>2]&15|0)!=0){za=34}}else{za=34}}while(0);if((za|0)==34){AGb()|0}H=(j|0)==0;ha=H?-1:ta;ta=H?-1:ra;ra=H?-1:pa;pa=H?-1:na;na=H?0:la;if(!ka){c[f+23820>>2]=525304;c[f+23816>>2]=525304}a:do{if((na|0)<(B|0)){la=f+88|0;H=v|0;ya=v+4|0;wa=l+4|0;Aa=m+4|0;Ba=v+8|0;Ca=l+8|0;Da=m+8|0;Ea=v+12|0;Fa=(X|0)!=0;Ga=l+12|0;Ha=m+12|0;Ia=f+23824|0;Ja=1-Q|0;Ka=B-1|0;La=1-R|0;Ma=f+12|0;Na=f+24|0;Oa=1-Y|0;Pa=1-Z|0;Qa=k+j|0;Ra=-Qa|0;Sa=fa+~ga|0;Ta=f+23816|0;Ua=f+23820|0;Va=B-2|0;Wa=f+2220|0;Xa=f+2224|0;Ya=(Q|0)==1;Za=(R|0)<3;_a=(R|0)==1;$a=(Q|0)==2;ab=(R|0)==2;bb=f+11428|0;cb=f+11424|0;db=f+15524|0;eb=f+15520|0;fb=(G|0)==11;gb=O;hb=P;ib=f+23760|0;jb=f+19656|0;kb=x|0;lb=x+4|0;mb=g+4|0;nb=x+8|0;ob=g+8|0;pb=x+12|0;qb=g+12|0;rb=h+12|0;sb=Z<<1;tb=f+23968|0;ub=f+23928|0;vb=f+23936|0;wb=_+((D<<1)+93&-16)|0;xb=f+23948|0;yb=f+23956|0;zb=f+23964|0;Ab=w|0;Bb=w+4|0;Cb=w+8|0;Db=w+12|0;Eb=Y<<1;Fb=f+23920|0;Gb=f+23960|0;Hb=f+23932|0;Ib=f+23944|0;Jb=f+23952|0;Kb=f+23924|0;Lb=f+23940|0;Mb=ha;Nb=ta;Ob=ra;Pb=pa;Qb=na;b:while(1){Rb=c[la>>2]|0;Sb=Qb>>Rb;c[H>>2]=(c[l>>2]|0)+(ca(c[m>>2]|0,Qb)|0);c[ya>>2]=(c[wa>>2]|0)+(ca(c[Aa>>2]|0,Sb)|0);c[Ba>>2]=(c[Ca>>2]|0)+(ca(c[Da>>2]|0,Sb)|0);if(Fa){Tb=(c[Ga>>2]|0)+(ca(c[Ha>>2]|0,Qb)|0)|0}else{Tb=0}c[Ea>>2]=Tb;Ub=c[Ia>>2]|0;Vb=c[I+(Qb<<2)>>2]|0;Wb=(Ja|0)>(Vb|0)?Ja:Vb;Vb=(1<<Rb)-1|Qb;Rb=c[I+(((Vb|0)>(Ka|0)?Ka:Vb)<<2)>>2]|0;Vb=c[J+(Sb<<2)>>2]|0;Xb=(La|0)>(Vb|0)?La:Vb;Vb=c[Ma>>2]|0;Yb=Wb+Q|0;Zb=(Vb|0)>(Yb|0)?Yb:Vb;Yb=((Ja|0)>(Rb|0)?Ja:Rb)+Q|0;Rb=c[Na>>2]|0;_b=Xb+R|0;$b=((Rb|0)>(_b|0)?_b:Rb)-1|0;Rb=(Wb|0)>(Nb|0)?Wb-1|0:Nb;_b=(Xb|0)>(Mb|0)?Xb-1|0:Mb;if((Wb|0)<(Oa+Rb|0)){za=42;break}if((Xb|0)<(Pa+_b|0)){za=44;break}if((((Vb|0)>(Yb|0)?Yb:Vb)-1|0)<(Qa|0)){if(($b|0)<(-(Ra>>c[da>>2])|0)){ac=Zb;bc=$b;cc=1}else{za=47}}else{za=47}if((za|0)==47){za=0;ac=Qa;bc=Sa;cc=0}$b=ac-1|0;if((Rb|0)<($b|0)){Zb=Rb;Vb=Pb;while(1){Yb=Zb+1|0;dc=Yb-j|0;ec=(c[g>>2]|0)+(ca(c[h>>2]|0,dc)|0)|0;c[Ab>>2]=ec;fc=(c[mb>>2]|0)+(ca(c[$>>2]|0,dc)|0)|0;c[Bb>>2]=fc;gc=(c[ob>>2]|0)+(ca(c[xa>>2]|0,dc)|0)|0;c[Cb>>2]=gc;c[Db>>2]=(c[qb>>2]|0)+(ca(c[rb>>2]|0,dc)|0);hc=Vb+1|0;if((hc|0)>=(Eb|0)){za=50;break b}if((dc|0)>=(k|0)){za=52;break b}if(!((dc|0)>-1)){za=54;break b}dc=c[U+(hc<<2)>>2]|0;ic=c[Fb>>2]|0;jc=c[Gb>>2]|0;do{if((ic|0)==0){kc=c[Hb>>2]|0;if((kc|0)==0){lc=ec;break}mf[kc&2047](_,Ab,z,va);lc=_}else{_e[ic&511](_,ec,fc,gc,z,ua);lc=_}}while(0);gc=c[Ib>>2]|0;if((gc|0)==0){Se[c[Jb>>2]&1023](f,dc,A,lc,M,K,S)}else{_e[gc&511](f,dc,A,lc,z,E)}if((jc|0)!=0){re[jc&1023](dc,A)}do{if(Fa){gc=c[X+(hc<<2)>>2]|0;fc=c[Kb>>2]|0;ec=c[Db>>2]|0;do{if((fc|0)==0){ic=c[Lb>>2]|0;if((ic|0)==0){mc=ec;break}mf[ic&2047](_,Ab,z,0);mc=_}else{_e[fc&511](_,ec,c[Bb>>2]|0,c[Cb>>2]|0,z,ua);mc=_}}while(0);ec=c[Ib>>2]|0;if((ec|0)==0){Se[c[Jb>>2]&1023](f,gc,A,mc,M,K,S);break}else{_e[ec&511](f,gc,A,mc,z,E);break}}}while(0);if((Yb|0)<($b|0)){Zb=Yb;Vb=hc}else{nc=Yb;oc=hc;break}}}else{nc=Rb;oc=Pb}if((_b|0)<(bc|0)){Vb=_b;Zb=Ob;while(1){$b=Vb+1|0;dc=$b-fa|0;jc=(c[g>>2]|0)+(ca(c[h>>2]|0,dc)|0)|0;c[kb>>2]=jc;ec=(c[mb>>2]|0)+(ca(c[$>>2]|0,dc)|0)|0;c[lb>>2]=ec;fc=(c[ob>>2]|0)+(ca(c[xa>>2]|0,dc)|0)|0;c[nb>>2]=fc;c[pb>>2]=(c[qb>>2]|0)+(ca(c[rb>>2]|0,dc)|0);ic=Zb+1|0;if((ic|0)>=(sb|0)){za=75;break b}if((dc|0)>=(ea|0)){za=77;break b}if(!((dc|0)>-1)){za=79;break b}do{if((c[tb>>2]|0)!=0){dc=c[V+(ic<<2)>>2]|0;kc=c[W+(ic<<2)>>2]|0;pc=c[ub>>2]|0;do{if((pc|0)==0){qc=c[vb>>2]|0;if((qc|0)==0){rc=ec;sc=fc;break}pe[qc&1023](_,wb,kb,D,va);rc=_;sc=wb}else{Se[pc&1023](_,wb,jc,ec,fc,D,ua);rc=_;sc=wb}}while(0);pc=c[xb>>2]|0;if((pc|0)==0){Se[c[yb>>2]&1023](f,dc,C,rc,N,L,T);Se[c[yb>>2]&1023](f,kc,C,sc,N,L,T)}else{Ge[pc&255](f,dc,kc,C,rc,sc,D,F)}pc=c[zb>>2]|0;if((pc|0)==0){break}ef[pc&4095](dc,kc,C)}}while(0);if(($b|0)<(bc|0)){Vb=$b;Zb=ic}else{tc=$b;uc=ic;break}}}else{tc=_b;uc=Ob}Zb=oc-((oc|0)<(Y|0)?0:Y)|0;Vb=uc-((uc|0)<(Z|0)?0:Z)|0;if(!cc){vc=Zb;wc=Vb;xc=nc;yc=tc;zc=Qb;break a}if(ka){c[Ta>>2]=1401240+((Sb&7)<<3);c[Ua>>2]=1401240+((Qb&7)<<3)}if((Qb|0)<(Va|0)){Ac=Ub}else{iAb(f,o,p,q,r,s,t,u);Ac=0}Rb=Wb+Y-nc+Zb|0;fc=U+(Rb<<2)|0;ec=Xb+Z-tc+Vb|0;jc=V+(ec<<2)|0;hc=W+(ec<<2)|0;if(Fa){Bc=X+(Rb<<2)|0}else{Bc=0}Rb=c[Wa>>2]|0;ec=c[Xa>>2]|0;Yb=qKb(G)|0;if((Yb|0)==0){za=99;break}do{if((a[Yb+7|0]&16)==0){za=105}else{pc=qKb(G)|0;if((pc|0)==0){za=102;break b}if(!((a[pc+7|0]&32)==0)){za=105;break}if((d[pc+4|0]|0)>>>0>1>>>0){za=110}else{za=105}}}while(0);c:do{if((za|0)==105){za=0;do{if((G|0)==66|(G|0)==32|(G|0)==31|(G|0)==8){Yb=qKb(G)|0;if((Yb|0)==0){za=107;break b}if(fb){break}if((a[Yb+7|0]|0)>-1){za=110;break c}}}while(0);ic=c[t>>2]|0;if((ic|0)==0){$b=Rb+((ca(Qb,Q)|0)<<1)|0;Yb=ec+((ca(Qb,R)|0)<<1)|0;af[c[u>>2]&127](f,$b,fc,Q,Yb,jc,hc,R,Bc,H,A,Qb);break}if(!((c[aa>>2]|0)!=0&Ya&Za)){if((c[ba>>2]|0)!=0&$a&ab){Yb=Qb<<1;$b=Yb|1;Xb=b[Rb+($b<<1)>>1]|0;Wb=b[ec+($b<<1)>>1]|0;$b=(b[Rb+(Yb<<1)>>1]|0)*65537|0;c[bb>>2]=$b;c[cb>>2]=$b;$b=(b[ec+(Sb<<1<<1)>>1]|0)*65537|0;c[db>>2]=$b;c[eb>>2]=$b;Ve[c[s>>2]&127](f,fc,jc,hc,Fa?Bc:0,c[H>>2]|0,A,Xb,Wb,Qb);break}else{Wb=Rb+((ca(Qb,Q)|0)<<1)|0;Xb=ec+((ca(Qb,R)|0)<<1)|0;af[ic&127](f,Wb,fc,Q,Xb,jc,hc,R,Bc,c[H>>2]|0,A,Qb);break}}if(_a){Cc=0}else{Cc=b[ec+((Qb<<1|1)<<1)>>1]|0}if(Fa){Dc=c[Bc>>2]|0}else{Dc=0}Te[c[r>>2]&255](f,c[fc>>2]|0,jc,hc,Dc,c[H>>2]|0,A,Cc,Qb)}}while(0);do{if((za|0)==110){za=0;Xb=(1<<c[la>>2])-1|0;Wb=Rb+((ca(Qb,Q)|0)<<1)|0;ic=ec+((ca(Sb,R)|0)<<1)|0;$b=(Ac|0)!=0;Yb=$b?hb:ic;if(Ya){pe[c[o>>2]&1023](c[fc>>2]|0,c[H>>2]|0,A,c[Ua>>2]|0,0)}else{Se[c[p>>2]&1023]($b?gb:Wb,Q,fc,c[H>>2]|0,A,c[Ua>>2]|0,0)}do{if((Xb&Qb|0)==0){if((G|0)==66|(G|0)==32|(G|0)==31|(G|0)==8){break}ic=c[q>>2]|0;if((ic|0)!=0){Se[ic&1023](f,Yb,R,jc,hc,c[ya>>2]|0,C);break}if(_a){pe[c[o>>2]&1023](c[jc>>2]|0,c[ya>>2]|0,C,c[Ta>>2]|0,0);pe[c[o>>2]&1023](c[hc>>2]|0,c[Ba>>2]|0,C,c[Ta>>2]|0,3);break}Se[c[p>>2]&1023](Yb,R,jc,c[ya>>2]|0,C,c[Ta>>2]|0,0);if($b){Ec=c[ib>>2]>>1}else{Ec=3}Se[c[p>>2]&1023](Yb,R,hc,c[Ba>>2]|0,C,c[Ta>>2]|0,Ec)}}while(0);if(!Fa){break}if(Ya){pe[c[o>>2]&1023](c[Bc>>2]|0,c[Ea>>2]|0,A,c[Ua>>2]|0,0);break}else{Se[c[p>>2]&1023]($b?jb:Wb,Q,Bc,c[Ea>>2]|0,A,c[Ua>>2]|0,0);break}}}while(0);hc=Qb+1|0;if((hc|0)<(B|0)){Mb=tc;Nb=nc;Ob=Vb;Pb=Zb;Qb=hc}else{vc=Zb;wc=Vb;xc=nc;yc=tc;zc=hc;break a}}if((za|0)==42){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2116280,c[ja+8>>2]=2634160,c[ja+16>>2]=484,ja)|0);i=ja;Hd();return 0}else if((za|0)==44){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2610416,c[ja+8>>2]=2634160,c[ja+16>>2]=485,ja)|0);i=ja;Hd();return 0}else if((za|0)==50){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2583952,c[ja+8>>2]=2634160,c[ja+16>>2]=513,ja)|0);i=ja;Hd();return 0}else if((za|0)==52){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2563272,c[ja+8>>2]=2634160,c[ja+16>>2]=514,ja)|0);i=ja;Hd();return 0}else if((za|0)==54){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2545744,c[ja+8>>2]=2634160,c[ja+16>>2]=515,ja)|0);i=ja;Hd();return 0}else if((za|0)==75){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2527952,c[ja+8>>2]=2634160,c[ja+16>>2]=535,ja)|0);i=ja;Hd();return 0}else if((za|0)==77){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2513e3,c[ja+8>>2]=2634160,c[ja+16>>2]=536,ja)|0);i=ja;Hd();return 0}else if((za|0)==79){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2499336,c[ja+8>>2]=2634160,c[ja+16>>2]=537,ja)|0);i=ja;Hd();return 0}else if((za|0)==99){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=667,ja)|0);i=ja;Hd();return 0}else if((za|0)==102){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=660,ja)|0);i=ja;Hd();return 0}else if((za|0)==107){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=778,ja)|0);i=ja;Hd();return 0}}else{vc=pa;wc=ra;xc=ta;yc=ha;zc=na}}while(0);ha=qKb(G)|0;if((ha|0)==0){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=806,ja)|0);i=ja;Hd();return 0}if(!((d[ha+4|0]|0)>>>0>1>>>0)){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}if((a[ha+7|0]&16)==0){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}ha=qKb(G)|0;if((ha|0)==0){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=778,ja)|0);i=ja;Hd();return 0}if((G|0)==11){Gc=1}else{Gc=(a[ha+7|0]|0)<0}if(!(Gc&(X|0)==0)){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}X=zc-na|0;Gc=qKb(G)|0;if((Gc|0)==0){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=637,ja)|0);i=ja;Hd();return 0}do{if(!((b[Gc+8>>1]&30720)==30720)){ha=qKb(G)|0;if((ha|0)==0){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=644,ja)|0);i=ja;Hd();return 0}if((((e[ha+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){break}ha=c[m+12>>2]|0;if((X|0)<=0){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}ta=0;ra=(c[l+12>>2]|0)+(ca(ha,na)|0)|0;while(1){mrc(ra|0,-1|0,A|0)|0;pa=ta+1|0;if((pa|0)<(X|0)){ta=pa;ra=ra+ha|0}else{break}}c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}}while(0);Gc=qKb(G)|0;ha=c[l+12>>2]|0;l=c[m+12>>2]|0;m=(e[Gc+14>>1]|0)>>>11&15;Gc=qKb(G)|0;if((Gc|0)==0){KIb(0,0,2288040,(ja=i,i=i+24|0,c[ja>>2]=2238064,c[ja+8>>2]=2197496,c[ja+16>>2]=653,ja)|0);i=ja;Hd();return 0}ja=ha+(ca(l,na)|0)|0;if((X|0)<=0){c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}ha=(a[Gc+7|0]&1)==0;Gc=(A|0)>0;G=65535>>>((m^15)>>>0)&65535;m=he(G|0)|0;if(ha){if(Gc){Hc=ja;Ic=0}else{c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}while(1){ha=0;do{ra=Hc+(ha<<1)|0;y=G;a[ra]=y;y=y>>8;a[ra+1|0]=y;ha=ha+1|0;}while((ha|0)<(A|0));ha=Ic+1|0;if((ha|0)<(X|0)){Hc=Hc+l|0;Ic=ha}else{break}}c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}else{if(Gc){Jc=ja;Kc=0}else{c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}while(1){ja=0;do{Gc=Jc+(ja<<1)|0;y=m;a[Gc]=y;y=y>>8;a[Gc+1|0]=y;ja=ja+1|0;}while((ja|0)<(A|0));ja=Kc+1|0;if((ja|0)<(X|0)){Jc=Jc+l|0;Kc=ja}else{break}}c[ia>>2]=zc;c[ma>>2]=vc;c[oa>>2]=wc;c[qa>>2]=xc;c[sa>>2]=yc;Fc=zc-na|0;i=n;return Fc|0}return 0}function hxb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;m=i;i=i+96|0;n=m|0;o=m+16|0;p=m+32|0;q=m+48|0;r=m+64|0;s=m+80|0;if((f|0)==0|(l|0)==0|(k|0)==0){KIb(e,16,2416432,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=0;i=m;return u|0}v=n;w=f;c[v>>2]=c[w>>2];c[v+4>>2]=c[w+4>>2];c[v+8>>2]=c[w+8>>2];c[v+12>>2]=c[w+12>>2];w=o;v=k;c[w>>2]=c[v>>2];c[w+4>>2]=c[v+4>>2];c[w+8>>2]=c[v+8>>2];c[w+12>>2]=c[v+12>>2];if((j|0)==0){u=0;i=m;return u|0}v=e+56|0;w=qKb(c[v>>2]|0)|0;x=0;while(1){if((x|0)>=4){break}z=b[w+8+(x<<1)>>1]&3;if((c[f+(z<<2)>>2]|0)==0){A=8;break}if((c[g+(z<<2)>>2]|0)==0){A=8;break}else{x=x+1|0}}if((A|0)==8){KIb(e,16,2579816,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=0;i=m;return u|0}x=e+52|0;w=qKb(c[x>>2]|0)|0;z=0;while(1){if((z|0)>=4){break}B=b[w+8+(z<<1)>>1]&3;if((c[k+(B<<2)>>2]|0)==0){A=13;break}if((c[l+(B<<2)>>2]|0)==0){A=13;break}else{z=z+1|0}}if((A|0)==13){KIb(e,16,2436440,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=0;i=m;return u|0}z=e+96|0;k=c[z>>2]|0;w=(h|0)==0;do{if((k|0)!=0|w){if((k|0)==0){A=18}}else{if((j+h|0)==(c[e+12>>2]|0)){A=18;break}KIb(e,16,2349784,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=0;i=m;return u|0}}while(0);do{if((A|0)==18){if(w){c[z>>2]=1;break}else{c[z>>2]=-1;break}}}while(0);w=qKb(c[v>>2]|0)|0;if((w|0)==0){KIb(0,0,2288040,(t=i,i=i+24|0,c[t>>2]=2238064,c[t+8>>2]=2197496,c[t+16>>2]=828,t)|0);i=t;Hd();return 0}a:do{if(!((a[w+7|0]&66)==0)){A=f+4|0;k=0;while(1){switch(c[v>>2]|0){case 19:{C=255;D=(k&7)*36|0;E=(k>>6)*85|0;F=(k>>>3&7)*36|0;break};case 24:{C=255;D=(k>>3)*255|0;E=-(k&1)&255;F=(k>>>1&3)*85|0;break};case 8:case 66:{C=255;D=k;E=k;F=k;break};case 11:{B=c[(c[A>>2]|0)+(k<<2)>>2]|0;C=B>>>24;D=B>>>16&255;E=B&255;F=B>>>8&255;break};case 22:{C=255;D=(k>>5)*36|0;E=(k&3)*85|0;F=(k>>>2&7)*36|0;break};default:{C=255;D=-(k&1)&255;E=(k>>3)*255|0;F=(k>>>1&3)*85|0}}B=(F*16519|0)+540672+(E*3208|0)+(D*8414|0)>>15;if(B>>>0>255>>>0){G=-B>>31&255}else{G=B&255}B=(F*-9528|0)+4210688+(E*14392|0)+(D*-4865|0)>>15;if(B>>>0>255>>>0){H=-B>>31&255}else{H=B&255}B=(F*-12061|0)+4210688+(E*-2332|0)+(D*14392|0)>>15;if(B>>>0>255>>>0){I=-B>>31&255}else{I=B&255}B=C<<24;c[e+120+(k<<2)>>2]=G&255|B|(H&255)<<8|(I&255)<<16;J=c[x>>2]|0;if((J|0)==29){c[e+1144+(k<<2)>>2]=(D<<24)+(F<<16)+(C|E<<8)}else if((J|0)==28|(J|0)==2){c[e+1144+(k<<2)>>2]=D+(F<<8)+(E<<16)+B}else if((J|0)==27){c[e+1144+(k<<2)>>2]=(E<<24)+(F<<16)+(C|D<<8)}else{c[e+1144+(k<<2)>>2]=E+(F<<8)+(D<<16)+B}k=k+1|0;if((k|0)>=256){break a}}}}while(0);D=e+11268|0;do{if((c[D>>2]|0)==0){K=0}else{if((c[e+11272>>2]|0)!=0){K=0;break}F=c[x>>2]|0;E=qKb(F)|0;if((E|0)==0){KIb(0,0,2288040,(t=i,i=i+24|0,c[t>>2]=2238064,c[t+8>>2]=2197496,c[t+16>>2]=778,t)|0);i=t;Hd();return 0}if((F|0)!=11){if((a[E+7|0]|0)>-1){K=0;break}}E=c[g>>2]|0;F=hJb((ca((E|0)>-1?E:-E|0,j)|0)+32|0)|0;if((F|0)==0){u=-12;i=m;return u|0}E=c[g>>2]|0;if((E|0)<0){L=F+(ca(1-j|0,E)|0)|0}else{L=F}C=n|0;if((j|0)>0){I=c[C>>2]|0;H=c[e+8>>2]|0;G=c[D>>2]|0;f=0;do{w=ca(E,f)|0;k=H<<2;nrc(L+w|0,I+w|0,k)|0;A=G-1|0;if((A|0)<(k|0)){B=A;do{a[L+(w+B)|0]=-1;B=B+4|0;}while((B|0)<(k|0))}f=f+1|0;}while((f|0)<(j|0))}c[C>>2]=L;K=F}}while(0);L=e+11276|0;b:do{if((c[L>>2]|0)==0){M=K}else{do{if((c[e+11280>>2]|0)!=0){if((c[e+8>>2]|0)!=(c[e+19608>>2]|0)){break}if((c[e+12>>2]|0)==(c[e+16>>2]|0)){M=K;break b}}}while(0);F=c[g>>2]|0;C=hJb((ca((F|0)>-1?F:-F|0,j)|0)+32|0)|0;if((C|0)==0){u=-12;i=m;return u|0}F=c[g>>2]|0;if((F|0)<0){N=C+(ca(1-j|0,F)|0)|0}else{N=C}D=n|0;f=c[D>>2]|0;G=(F|0)/2|0;I=qKb(c[v>>2]|0)|0;if((j|0)>0){H=(F|0)>5;F=I+7|0;I=e+23828|0;E=e+23844|0;k=e+23846|0;B=e+23848|0;w=e+23852|0;A=e+23854|0;J=e+23856|0;O=e+23860|0;P=e+23862|0;Q=e+23864|0;R=e+23832|0;S=0;T=f;f=N;while(1){if(H){U=0;while(1){V=(a[F]&1)==0;W=T+(U<<1)|0;X=(d[W]|d[W+1|0]<<8)<<16>>16;if(V){W=T+(U+1<<1)|0;Y=T+(U+2<<1)|0;Z=(d[Y]|d[Y+1|0]<<8)<<16>>16;_=(d[W]|d[W+1|0]<<8)<<16>>16;$=X}else{W=he(X|0)|0;X=T+(U+1<<1)|0;Y=he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0;X=T+(U+2<<1)|0;Z=he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0;_=Y;$=W}W=c[I>>2]|0;Y=b[W+(($&65535)>>>4<<1)>>1]|0;X=b[W+((_&65535)>>>4<<1)>>1]|0;aa=b[W+((Z&65535)>>>4<<1)>>1]|0;W=ca(b[E>>1]|0,Y)|0;ba=(ca(b[k>>1]|0,X)|0)+W|0;W=ba+(ca(b[B>>1]|0,aa)|0)>>12;ba=ca(b[w>>1]|0,Y)|0;da=(ca(b[A>>1]|0,X)|0)+ba|0;ba=da+(ca(b[J>>1]|0,aa)|0)>>12;da=ca(b[O>>1]|0,Y)|0;Y=(ca(b[P>>1]|0,X)|0)+da|0;da=Y+(ca(b[Q>>1]|0,aa)|0)>>12;if((W|0)<0){ea=0}else{ea=(W|0)>4095?4095:W}if((ba|0)<0){fa=0}else{fa=(ba|0)>4095?4095:ba}if((da|0)<0){ga=0}else{ga=(da|0)>4095?4095:da}da=b[(c[R>>2]|0)+(ea<<1)>>1]<<4;if(V){V=f+(U<<1)|0;y=da;a[V]=y;y=y>>8;a[V+1|0]=y;V=f+(U+1<<1)|0;y=b[(c[R>>2]|0)+(fa<<1)>>1]<<4;a[V]=y;y=y>>8;a[V+1|0]=y;V=f+(U+2<<1)|0;y=b[(c[R>>2]|0)+(ga<<1)>>1]<<4;a[V]=y;y=y>>8;a[V+1|0]=y}else{V=f+(U<<1)|0;y=he(da|0)|0;a[V]=y;y=y>>8;a[V+1|0]=y;V=f+(U+1<<1)|0;y=he(b[(c[R>>2]|0)+(fa<<1)>>1]<<4|0)|0;a[V]=y;y=y>>8;a[V+1|0]=y;V=f+(U+2<<1)|0;y=he(b[(c[R>>2]|0)+(ga<<1)>>1]<<4|0)|0;a[V]=y;y=y>>8;a[V+1|0]=y}if((U+5|0)<(G|0)){U=U+3|0}else{break}}}U=S+1|0;if((U|0)<(j|0)){S=U;T=T+(G<<1)|0;f=f+(G<<1)|0}else{break}}}c[D>>2]=N;M=C}}while(0);N=(h|0)!=0;do{if(!N){if((c[e+2284>>2]&524288|0)==0){break}if((c[e+23972>>2]|0)!=3){break}ga=c[e+11200>>2]|0;if((ga|0)==0){break}fa=e+19608|0;mrc(ga|0,0,(c[fa>>2]<<2)+8|0)|0;mrc(c[e+11204>>2]|0,0,(c[fa>>2]<<2)+8|0)|0;mrc(c[e+11208>>2]|0,0,(c[fa>>2]<<2)+8|0)|0;mrc(c[e+11212>>2]|0,0,(c[fa>>2]<<2)+8|0)|0}}while(0);if((c[z>>2]|0)==1){fa=p|0;c[fa>>2]=c[g>>2];c[p+4>>2]=c[g+4>>2];c[p+8>>2]=c[g+8>>2];c[p+12>>2]=c[g+12>>2];p=q|0;c[p>>2]=c[l>>2];c[q+4>>2]=c[l+4>>2];c[q+8>>2]=c[l+8>>2];c[q+12>>2]=c[l+12>>2];q=n|0;ixb(q,c[v>>2]|0);ga=o|0;ixb(ga,c[x>>2]|0);if((j+h|0)==(c[e+12>>2]|0)){c[z>>2]=0}ha=me[c[e+4>>2]&255](e,q,fa,h,j,ga,p)|0}else{p=r|0;ga=c[g>>2]|0;c[p>>2]=-ga;fa=g+4|0;c[r+4>>2]=-(c[fa>>2]|0);q=g+8|0;c[r+8>>2]=-(c[q>>2]|0);ea=g+12|0;c[r+12>>2]=-(c[ea>>2]|0);r=s|0;c[r>>2]=-(c[l>>2]|0);g=l+4|0;c[s+4>>2]=-(c[g>>2]|0);Z=l+8|0;c[s+8>>2]=-(c[Z>>2]|0);_=l+12|0;c[s+12>>2]=-(c[_>>2]|0);s=j-1|0;$=ca(ga,s)|0;ga=n|0;c[ga>>2]=(c[ga>>2]|0)+$;$=qKb(c[v>>2]|0)|0;if(($|0)==0){KIb(0,0,2288040,(t=i,i=i+24|0,c[t>>2]=2238064,c[t+8>>2]=2197496,c[t+16>>2]=828,t)|0);i=t;Hd();return 0}t=c[e+80>>2]|0;if((a[$+7|0]&66)==0){$=ca((j>>t)-1|0,c[fa>>2]|0)|0;fa=n+4|0;c[fa>>2]=(c[fa>>2]|0)+$}$=ca((j>>t)-1|0,c[q>>2]|0)|0;q=n+8|0;c[q>>2]=(c[q>>2]|0)+$;$=ca(c[ea>>2]|0,s)|0;s=n+12|0;c[s>>2]=(c[s>>2]|0)+$;$=c[e+16>>2]|0;s=$-1|0;n=ca(s,c[l>>2]|0)|0;ea=o|0;c[ea>>2]=(c[ea>>2]|0)+n;n=($>>c[e+88>>2])-1|0;$=ca(n,c[g>>2]|0)|0;g=o+4|0;c[g>>2]=(c[g>>2]|0)+$;$=ca(n,c[Z>>2]|0)|0;Z=o+8|0;c[Z>>2]=(c[Z>>2]|0)+$;$=ca(s,c[_>>2]|0)|0;_=o+12|0;c[_>>2]=(c[_>>2]|0)+$;ixb(ga,c[v>>2]|0);ixb(ea,c[x>>2]|0);if(!N){c[z>>2]=0}ha=me[c[e+4>>2]&255](e,ga,p,(c[e+12>>2]|0)-(j+h)|0,j,ea,r)|0}c:do{if((c[e+11280>>2]|0)!=0){do{if((c[L>>2]|0)!=0){if((c[e+8>>2]|0)!=(c[e+19608>>2]|0)){break}if((c[e+12>>2]|0)==(c[e+16>>2]|0)){break c}}}while(0);C=c[o>>2]|0;D=c[l>>2]|0;r=(D|0)/2|0;ea=qKb(c[x>>2]|0)|0;if((ha|0)<=0){break}j=(D|0)>5;D=ea+7|0;ea=e+23840|0;h=e+23868|0;p=e+23870|0;ga=e+23872|0;z=e+23876|0;N=e+23878|0;v=e+23880|0;$=e+23884|0;_=e+23886|0;s=e+23888|0;Z=e+23836|0;n=0;g=C;while(1){if(j){C=0;while(1){q=(a[D]&1)==0;t=g+(C<<1)|0;fa=(d[t]|d[t+1|0]<<8)<<16>>16;if(q){K=g+(C+1<<1)|0;G=g+(C+2<<1)|0;ia=(d[G]|d[G+1|0]<<8)<<16>>16;ja=(d[K]|d[K+1|0]<<8)<<16>>16;ka=fa}else{K=he(fa|0)|0;fa=g+(C+1<<1)|0;G=he((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0;fa=g+(C+2<<1)|0;ia=he((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0;ja=G;ka=K}K=c[ea>>2]|0;G=b[K+((ka&65535)>>>4<<1)>>1]|0;fa=b[K+((ja&65535)>>>4<<1)>>1]|0;f=b[K+((ia&65535)>>>4<<1)>>1]|0;K=ca(b[h>>1]|0,G)|0;T=(ca(b[p>>1]|0,fa)|0)+K|0;K=T+(ca(b[ga>>1]|0,f)|0)>>12;T=ca(b[z>>1]|0,G)|0;S=(ca(b[N>>1]|0,fa)|0)+T|0;T=S+(ca(b[v>>1]|0,f)|0)>>12;S=ca(b[$>>1]|0,G)|0;G=(ca(b[_>>1]|0,fa)|0)+S|0;S=G+(ca(b[s>>1]|0,f)|0)>>12;if((K|0)<0){la=0}else{la=(K|0)>4095?4095:K}if((T|0)<0){ma=0}else{ma=(T|0)>4095?4095:T}if((S|0)<0){na=0}else{na=(S|0)>4095?4095:S}S=b[(c[Z>>2]|0)+(la<<1)>>1]<<4;if(q){y=S;a[t]=y;y=y>>8;a[t+1|0]=y;q=g+(C+1<<1)|0;y=b[(c[Z>>2]|0)+(ma<<1)>>1]<<4;a[q]=y;y=y>>8;a[q+1|0]=y;q=g+(C+2<<1)|0;y=b[(c[Z>>2]|0)+(na<<1)>>1]<<4;a[q]=y;y=y>>8;a[q+1|0]=y}else{y=he(S|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;t=g+(C+1<<1)|0;y=he(b[(c[Z>>2]|0)+(ma<<1)>>1]<<4|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;t=g+(C+2<<1)|0;y=he(b[(c[Z>>2]|0)+(na<<1)>>1]<<4|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y}if((C+5|0)<(r|0)){C=C+3|0}else{break}}}C=n+1|0;if((C|0)<(ha|0)){n=C;g=g+(r<<1)|0}else{break}}}}while(0);kJb(M);u=ha;i=m;return u|0}function ixb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=qKb(e)|0;if((g|0)==0){KIb(0,0,2288040,(h=i,i=i+24|0,c[h>>2]=2238064,c[h+8>>2]=2197496,c[h+16>>2]=778,h)|0);i=h;Hd()}do{if((e|0)!=11){if(!((a[g+7|0]|0)>-1)){break}c[b+12>>2]=0}}while(0);g=qKb(e)|0;if((g|0)==0){KIb(0,0,2288040,(h=i,i=i+24|0,c[h>>2]=2238064,c[h+8>>2]=2197496,c[h+16>>2]=806,h)|0);i=h;Hd()}do{if((d[g+4|0]|0)>>>0>1>>>0){if((a[g+7|0]&16)==0){break}i=f;return}}while(0);c[b+8>>2]=0;c[b+12>>2]=0;g=qKb(e)|0;if((g|0)==0){KIb(0,0,2288040,(h=i,i=i+24|0,c[h>>2]=2238064,c[h+8>>2]=2197496,c[h+16>>2]=828,h)|0);i=h;Hd()}if(!((a[g+7|0]&66)==0)){i=f;return}c[b+4>>2]=0;i=f;return}function jxb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;if((f|0)<=0){return}a=(j|0)>0;k=0;do{l=c[i+(k<<2)>>2]|0;if(a){m=ca(k,j)|0;n=0;o=0;do{o=(ca(b[h+(n+m<<1)>>1]|0,d[g+(n+l)|0]|0)|0)+o|0;n=n+1|0;}while((n|0)<(j|0));p=o>>7}else{p=0}b[e+(k<<1)>>1]=(p|0)>32767?32767:p&65535;k=k+1|0;}while((k|0)<(f|0));return}function kxb(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;if((e|0)>0){a=0;i=0;while(1){j=a>>>16;k=d[f+j|0]|0;b[c+(i<<1)>>1]=(ca((d[f+(j+1)|0]|0)-k|0,a>>>9&127)|0)+(k<<7);k=i+1|0;if((k|0)<(e|0)){a=a+h|0;i=k}else{break}}}i=e-1|0;e=g-1|0;if(((ca(i,h)|0)>>16|0)<(e|0)){return}g=f+e|0;f=i;do{b[c+(f<<1)>>1]=(d[g]|0)<<7;f=f-1|0;}while(((ca(f,h)|0)>>16|0)>=(e|0));return}function lxb(a,c,e,f,g,h,i,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;if((f|0)>0){a=0;k=0;while(1){l=a>>>16;m=a>>>9&127;n=m^127;o=ca(d[g+l|0]|0,n)|0;p=l+1|0;b[c+(k<<1)>>1]=(ca(d[g+p|0]|0,m)|0)+o;o=ca(d[h+l|0]|0,n)|0;b[e+(k<<1)>>1]=(ca(d[h+p|0]|0,m)|0)+o;o=k+1|0;if((o|0)<(f|0)){a=a+j|0;k=o}else{break}}}k=f-1|0;f=i-1|0;if(((ca(k,j)|0)>>16|0)<(f|0)){return}i=g+f|0;g=h+f|0;h=k;do{b[c+(h<<1)>>1]=(d[i]|0)<<7;b[e+(h<<1)>>1]=(d[g]|0)<<7;h=h-1|0;}while(((ca(h,j)|0)>>16|0)>=(f|0));return}function mxb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=e;if((f|0)<=0){return}e=(j|0)>0;k=0;do{l=c[i+(k<<2)>>2]|0;if(e){m=ca(k,j)|0;n=0;o=0;do{o=(ca(b[h+(n+m<<1)>>1]|0,d[g+(n+l)|0]|0)|0)+o|0;n=n+1|0;}while((n|0)<(j|0));p=o>>3}else{p=0}c[a+(k<<2)>>2]=(p|0)>524287?524287:p;k=k+1|0;}while((k|0)<(f|0));return}function nxb(d,f,g,h,j,k,l){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;m=i;n=d+56|0;d=f;f=h;h=(qKb(c[n>>2]|0)|0)+8|0;o=((e[h>>1]|0)>>>11&15)-4|0;p=c[n>>2]|0;a:do{switch(p|0){case 321:case 325:case 326:case 322:case 327:case 328:case 323:case 329:case 330:case 324:case 331:case 332:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 3:case 9:{q=6;break};default:{r=qKb(p)|0;if((r|0)==0){KIb(0,0,2288040,(s=i,i=i+24|0,c[s>>2]=2238064,c[s+8>>2]=2197496,c[s+16>>2]=674,s)|0);i=s;Hd()}if(!((a[r+7|0]&32)==0)){q=6;break a}if((c[n>>2]|0)==11){q=6}else{t=o}}}}while(0);if((q|0)==6){t=(b[h>>1]&30720)==30720?o:9}if((g|0)<=0){i=m;return}o=(l|0)>0;h=0;do{q=c[k+(h<<2)>>2]|0;if(o){n=ca(h,l)|0;p=0;r=0;while(1){s=(ca(b[j+(p+n<<1)>>1]|0,e[f+(p+q<<1)>>1]|0)|0)+r|0;u=p+1|0;if((u|0)<(l|0)){p=u;r=s}else{v=s;break}}}else{v=0}r=v>>t;c[d+(h<<2)>>2]=(r|0)>524287?524287:r;h=h+1|0;}while((h|0)<(g|0));i=m;return}function oxb(d,f,g,h,j,k,l){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;m=i;n=d+56|0;d=h;h=(qKb(c[n>>2]|0)|0)+8|0;o=(e[h>>1]|0)>>>11&15;a:do{if(o<<16>>16==15){p=o&65535}else{q=c[n>>2]|0;switch(q|0){case 321:case 325:case 326:case 322:case 327:case 328:case 323:case 329:case 330:case 324:case 331:case 332:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 3:case 9:{p=13;break a;break};default:{}}r=qKb(q)|0;if((r|0)==0){KIb(0,0,2288040,(q=i,i=i+24|0,c[q>>2]=2238064,c[q+8>>2]=2197496,c[q+16>>2]=674,q)|0);i=q;Hd()}if(!((a[r+7|0]&32)==0)){p=13;break}if((c[n>>2]|0)==11){p=13;break}p=(e[h>>1]|0)>>>11&15}}while(0);if((g|0)<=0){i=m;return}h=(l|0)>0;n=0;do{o=c[k+(n<<2)>>2]|0;if(h){r=ca(n,l)|0;q=0;s=0;while(1){t=(ca(b[j+(q+r<<1)>>1]|0,e[d+(q+o<<1)>>1]|0)|0)+s|0;u=q+1|0;if((u|0)<(l|0)){q=u;s=t}else{v=t;break}}}else{v=0}s=v>>p;b[f+(n<<1)>>1]=(s|0)>32767?32767:s&65535;n=n+1|0;}while((n|0)<(g|0));i=m;return}function pxb(a,c){a=a|0;c=c|0;var d=0,e=0;if((c|0)>0){d=0}else{return}do{e=a+(d<<1)|0;b[e>>1]=(((b[e>>1]|0)*14071|0)+33561947|0)>>>14;d=d+1|0;}while((d|0)<(c|0));return}function qxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;if((d|0)>0){e=0}else{return}do{f=a+(e<<1)|0;b[f>>1]=(((b[f>>1]|0)*1799|0)+4081085|0)>>>11;f=c+(e<<1)|0;b[f>>1]=(((b[f>>1]|0)*1799|0)+4081085|0)>>>11;e=e+1|0;}while((e|0)<(d|0));return}function rxb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;if((c|0)>0){d=0}else{return}do{e=a+(d<<1)|0;f=b[e>>1]|0;if(f<<16>>16>30189){g=32767}else{g=(((f<<16>>16)*19077|0)+1034684463|0)>>>14&65535}b[e>>1]=g;d=d+1|0;}while((d|0)<(c|0));return}function sxb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)>0){e=0}else{return}do{f=a+(e<<1)|0;g=b[f>>1]|0;if(g<<16>>16>30775){h=32767}else{h=(((g<<16>>16)*4663|0)+259145464|0)>>>12&65535}b[f>>1]=h;f=c+(e<<1)|0;g=b[f>>1]|0;if(g<<16>>16>30775){i=32767}else{i=(((g<<16>>16)*4663|0)+259145464|0)>>>12&65535}b[f>>1]=i;e=e+1|0;}while((e|0)<(d|0));return}function txb(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;if((b|0)>0){e=0}else{return}do{a=d+(e<<2)|0;c[a>>2]=((c[a>>2]|0)*3517|0)+134247788>>12;e=e+1|0;}while((e|0)<(b|0));return}function uxb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=a;a=b;if((d|0)>0){f=0}else{return}do{b=e+(f<<2)|0;c[b>>2]=((c[b>>2]|0)*1799|0)+65297360>>11;b=a+(f<<2)|0;c[b>>2]=((c[b>>2]|0)*1799|0)+65297360>>11;f=f+1|0;}while((f|0)<(d|0));return}function vxb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a;if((b|0)>0){e=0}else{return}do{a=d+(e<<2)|0;f=c[a>>2]|0;if((f|0)>483024){g=524246}else{g=(f*4769|0)-156229444>>12}c[a>>2]=g;e=e+1|0;}while((e|0)<(b|0));return}function wxb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a;a=b;if((d|0)>0){f=0}else{return}do{b=e+(f<<2)|0;g=c[b>>2]|0;if((g|0)>492400){h=524272}else{h=(g*4663|0)-148639872>>12}c[b>>2]=h;b=a+(f<<2)|0;g=c[b>>2]|0;if((g|0)>492400){i=524272}else{i=(g*4663|0)-148639872>>12}c[b>>2]=i;f=f+1|0;}while((f|0)<(d|0));return}function xxb(){return 132454}function yxb(){return 2415536}function zxb(b){b=b|0;var c=0;if(!(b>>>0<333>>>0)){c=0;return c|0}c=a[1211384+b|0]&1;return c|0}function Axb(a){a=a|0;var b=0;if(!(a>>>0<333>>>0)){b=0;return b|0}b=(d[1211384+a|0]|0)>>>1&1;return b|0}function Bxb(a){a=a|0;var b=0;if(!(a>>>0<333>>>0)){b=0;return b|0}b=(d[1211384+a|0]|0)>>>2&1;return b|0}function Cxb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0;m=i;orc(b+11228|0,e|0,16)|0;n=g;orc(b+11244|0,n|0,16)|0;Dxb(b);o=b+52|0;p=qKb(c[o>>2]|0)|0;q=b+56|0;r=qKb(c[q>>2]|0)|0;s=qKb(c[o>>2]|0)|0;if((s|0)==0){KIb(0,0,2512944,(t=i,i=i+24|0,c[t>>2]=2284040,c[t+8>>2]=2280320,c[t+16>>2]=660,t)|0);i=t;Hd();return 0}if((a[s+7|0]&32)==0){if((d[s+4|0]|0)>>>0>1>>>0){u=h}else{v=5}}else{v=5}do{if((v|0)==5){s=c[o>>2]|0;if((s|0)==8|(s|0)==66|(s|0)==31|(s|0)==32){u=h;break}u=0}}while(0);h=qKb(c[q>>2]|0)|0;if((h|0)==0){KIb(0,0,2512944,(t=i,i=i+24|0,c[t>>2]=2284040,c[t+8>>2]=2280320,c[t+16>>2]=660,t)|0);i=t;Hd();return 0}if((a[h+7|0]&32)==0){if((d[h+4|0]|0)>>>0>1>>>0){w=f}else{v=11}}else{v=11}do{if((v|0)==11){h=c[q>>2]|0;if((h|0)==8|(h|0)==66|(h|0)==31|(h|0)==32){w=f;break}w=0}}while(0);c[b+11220>>2]=j;c[b+11216>>2]=k;c[b+11224>>2]=l;c[b+11260>>2]=w;c[b+11264>>2]=u;u=qKb(c[o>>2]|0)|0;if((u|0)==0){KIb(0,0,2512944,(t=i,i=i+24|0,c[t>>2]=2284040,c[t+8>>2]=2280320,c[t+16>>2]=660,t)|0);i=t;Hd();return 0}if((a[u+7|0]&32)==0){if((d[u+4|0]|0)>>>0>1>>>0){v=18}else{v=17}}else{v=17}if((v|0)==17){u=c[o>>2]|0;if((u|0)==8|(u|0)==66|(u|0)==31|(u|0)==32){v=18}}do{if((v|0)==18){u=qKb(c[q>>2]|0)|0;if((u|0)==0){KIb(0,0,2512944,(t=i,i=i+24|0,c[t>>2]=2284040,c[t+8>>2]=2280320,c[t+16>>2]=660,t)|0);i=t;Hd();return 0}do{if((a[u+7|0]&32)==0){if((d[u+4|0]|0)>>>0>1>>>0){x=-1}else{break}i=m;return x|0}}while(0);u=c[q>>2]|0;if((u|0)==8|(u|0)==66|(u|0)==31|(u|0)==32){x=-1}else{break}i=m;return x|0}}while(0);c[b+60>>2]=oKb(p)|0;c[b+64>>2]=oKb(r)|0;r=qKb(c[o>>2]|0)|0;if((r|0)==0){KIb(0,0,2512944,(t=i,i=i+24|0,c[t>>2]=2284040,c[t+8>>2]=2280320,c[t+16>>2]=660,t)|0);i=t;Hd();return 0}if((a[r+7|0]&32)==0){if(!((d[r+4|0]|0)>>>0>1>>>0)){v=27}}else{v=27}do{if((v|0)==27){r=c[o>>2]|0;if((r|0)==8|(r|0)==66|(r|0)==31|(r|0)==32){break}cyb(b,e,w,j,k,l)|0}}while(0);l=c[g>>2]|0;k=l;j=(l|0)<0|0?-1:0;l=c[g+4>>2]|0;w=l;e=(l|0)<0|0?-1:0;l=-(c[g+8>>2]|0)|0;(l|0)<0|0?-1:0;o=-(c[g+12>>2]|0)|0;(o|0)<0|0?-1:0;g=b+10496|0;v=0;r=l;l=0;t=(r|0)>(l|0)|(r|0)==(l|0)&v>>>0>0>>>0;l=w>>>1|e<<31;p=e>>1|((e|0)<0|0?-1:0)<<31;q=xrc(0,0,l,p)|0;u=wrc(t?l:q,t?p:G,v,r)|0;r=Crc(u,G,w,e)|0;u=G;v=0;p=o;o=0;t=(p|0)>(o|0)|(p|0)==(o|0)&v>>>0>0>>>0;o=k>>>1|j<<31;q=j>>1|((j|0)<0|0?-1:0)<<31;l=xrc(0,0,o,q)|0;f=wrc(t?o:l,t?q:G,v,p)|0;p=Crc(f,G,k,j)|0;f=G;v=xrc(0,1,r,u)|0;q=G;t=xrc(v,q,p,f)|0;l=G;o=Erc(t,l,76309,0)|0;h=G;s=0;z=(h|0)>(s|0)|(h|0)==(s|0)&o>>>0>0>>>0;s=wrc(z?32768:-32768,z?0:-1,o,h)|0;h=Crc(s,G,65536,0)|0;s=G;o=Erc(t,l,w,e)|0;e=G;w=0;z=(e|0)>(w|0)|(e|0)==(w|0)&o>>>0>0>>>0;w=wrc(z?32768:-32768,z?0:-1,o,e)|0;e=Crc(w,G,65536,0)|0;w=G;o=Erc(t,l,k,j)|0;j=G;k=0;z=(j|0)>(k|0)|(j|0)==(k|0)&o>>>0>0>>>0;k=wrc(z?32768:-32768,z?0:-1,o,j)|0;j=Crc(k,G,65536,0)|0;k=G;o=p<<15|0>>>17;z=f<<15|p>>>17;p=0;f=(z|0)>(p|0)|(z|0)==(p|0)&o>>>0>0>>>0;p=h>>>1|s<<31;A=s>>1|((s|0)<0|0?-1:0)<<31;B=xrc(0,0,p,A)|0;C=G;D=wrc(f?p:B,f?A:C,o,z)|0;E=Crc(D,G,h,s)|0;D=xrc(0,0,E,G)|0;c[g>>2]=D;D=wrc(p,A,0,32768)|0;E=Crc(D,G,h,s)|0;D=b+10500|0;c[D>>2]=E;E=r<<15|0>>>17;F=u<<15|r>>>17;H=0;I=(F|0)>(H|0)|(F|0)==(H|0)&E>>>0>0>>>0;H=wrc(I?p:B,I?A:C,E,F)|0;C=Crc(H,G,h,s)|0;s=xrc(0,0,C,G)|0;C=b+10504|0;c[C>>2]=s;s=e>>>1|w<<31;h=w>>1|((w|0)<0|0?-1:0)<<31;H=xrc(0,0,s,h)|0;A=G;B=wrc(f?s:H,f?h:A,o,z)|0;z=Crc(B,G,e,w)|0;B=b+10508|0;c[B>>2]=z;z=wrc(s,h,0,32768)|0;o=Crc(z,G,e,w)|0;z=xrc(0,0,o,G)|0;o=b+10512|0;c[o>>2]=z;z=wrc(t,l,r,u)|0;u=z<<15|0>>>17;r=G<<15|z>>>17;z=0;l=(r|0)>(z|0)|(r|0)==(z|0)&u>>>0>0>>>0;z=wrc(l?s:H,l?h:A,u,r)|0;r=Crc(z,G,e,w)|0;w=b+10516|0;c[w>>2]=r;r=v<<15|0>>>17;e=q<<15|v>>>17;v=0;q=(e|0)>(v|0)|(e|0)==(v|0)&r>>>0>0>>>0;v=j>>>1|k<<31;z=k>>1|((k|0)<0|0?-1:0)<<31;u=xrc(0,0,v,z)|0;A=G;h=wrc(q?v:u,q?z:A,r,e)|0;e=Crc(h,G,j,k)|0;h=b+10520|0;c[h>>2]=e;e=wrc(v,z,0,32768)|0;r=Crc(e,G,j,k)|0;e=xrc(0,0,r,G)|0;r=b+10524|0;c[r>>2]=e;e=wrc(I?v:u,I?z:A,E,F)|0;F=Crc(e,G,j,k)|0;k=b+10528|0;c[k>>2]=F;if((grc(n,1242872,16)|0)==0){c[C>>2]=3208;c[k>>2]=-2332;c[w>>2]=14392;c[D>>2]=16519;c[r>>2]=-12061;c[o>>2]=-9528;c[g>>2]=8414;c[h>>2]=14392;c[B>>2]=-4865}B=b+10560|0;h=0;while(1){g=a[1234376+h|0]|0;if(g<<24>>24>-1){J=c[b+10496+(g<<24>>24<<2)>>2]&65535}else{J=0}g=B+(h<<1)|0;y=J;a[g]=y;y=y>>8;a[g+1|0]=y;g=h+1|0;if(g>>>0<280>>>0){h=g}else{x=0;break}}i=m;return x|0}function Dxb(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0.0;d=a+56|0;e=c[d>>2]|0;if((e|0)==298){c[d>>2]=30;f=4;g=30}else if((e|0)==297){c[d>>2]=29;f=1;g=29}else if((e|0)==296){c[d>>2]=28;f=4;g=28}else if((e|0)==295){c[d>>2]=27;f=1;g=27}else{f=0;g=e}e=a+11268|0;c[e>>2]=c[e>>2]|f;f=a+52|0;e=c[f>>2]|0;if((e|0)==297){c[f>>2]=29;h=1;i=29}else if((e|0)==295){c[f>>2]=27;h=1;i=27}else if((e|0)==296){c[f>>2]=28;h=4;i=28}else if((e|0)==298){c[f>>2]=30;h=4;i=30}else{h=0;i=e}e=a+11272|0;c[e>>2]=c[e>>2]|h;if((g|0)==110){c[d>>2]=42;j=1}else if((g|0)==111){c[d>>2]=41;j=1}else{j=0}d=a+11276|0;g=c[d>>2]|j;c[d>>2]=g;if((i|0)==111){c[f>>2]=41;k=1}else if((i|0)==110){c[f>>2]=42;k=1}else{k=0}f=a+11280|0;i=c[f>>2]|k;c[f>>2]=i;if((g|i|0)==0){return}nrc(a+23844|0,1234328,24)|0;nrc(a+23868|0,1234352,24)|0;c[a+23828>>2]=6050056;c[a+23832>>2]=6066440;c[a+23836>>2]=6041864;c[a+23840>>2]=6058248;if((b[3037315]|0)==0){l=0}else{return}do{m=+(l|0)/4095.0;b[6050056+(l<<1)>>1]=Lc(+(+T(+m,2.5999999046325684)*4095.0))|0;b[6066440+(l<<1)>>1]=Lc(+(+T(+m,+.4545454446934474)*4095.0))|0;b[6041864+(l<<1)>>1]=Lc(+(+T(+m,+.3846153987229934)*4095.0))|0;b[6058248+(l<<1)>>1]=Lc(+(+T(+m,2.200000047683716)*4095.0))|0;l=l+1|0;}while((l|0)<4096);return}function Exb(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0;if((a|0)==0){j=-1;return j|0}c[b>>2]=a+11228;c[e>>2]=a+11244;c[d>>2]=c[a+11260>>2];c[f>>2]=c[a+11264>>2];c[g>>2]=c[a+11220>>2];c[h>>2]=c[a+11216>>2];c[i>>2]=c[a+11224>>2];j=0;return j|0}function Fxb(){var a=0,b=0;a=pJb(23984)|0;b=a;if((a|0)==0){return b|0}c[a>>2]=525328;SJb(a);return b|0}function Gxb(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=i;i=i+16|0;j=h|0;mrc(j|0,0,16)|0;k=d+8|0;l=c[k>>2]|0;m=d+12|0;n=c[m>>2]|0;o=d+19608|0;p=c[o>>2]|0;q=d+16|0;r=c[q>>2]|0;s=(p<<1)+81&-16;t=d+56|0;u=c[t>>2]|0;v=d+52|0;w=c[v>>2]|0;AGb()|0;x=d+2284|0;y=c[x>>2]|0;if((c[1352520]|0)==0){OCb()}z=(l|0)==(p|0);A=(n|0)==(r|0);B=z&A;C=c[t>>2]|0;switch(C|0){case 13:{c[t>>2]=4;D=1;E=4;break};case 320:{c[t>>2]=7;D=1;E=7;break};case 8:case 32:case 31:{D=1;E=C;break};case 12:{c[t>>2]=0;D=1;E=0;break};case 14:{c[t>>2]=5;D=1;E=5;break};case 34:{c[t>>2]=33;D=1;E=33;break};default:{D=0;E=C}}C=d+11260|0;c[C>>2]=c[C>>2]|D;D=c[v>>2]|0;switch(D|0){case 14:{c[v>>2]=5;F=1;H=5;break};case 12:{c[v>>2]=0;F=1;H=0;break};case 34:{c[v>>2]=33;F=1;H=33;break};case 8:case 32:case 31:{F=1;H=D;break};case 320:{c[v>>2]=7;F=1;H=7;break};case 13:{c[v>>2]=4;F=1;H=4;break};default:{F=0;H=D}}D=d+11264|0;c[D>>2]=c[D>>2]|F;if(!((u|0)==(E|0)&(w|0)==(H|0))){KIb(d,24,2349712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}do{if((c[d+11216>>2]|0)==0){if((c[d+11224>>2]|0)!=0){break}if((c[d+60>>2]|0)!=0){break}Cxb(d,1242872,c[C>>2]|0,1242872,c[D>>2]|0,0,65536,65536)|0}}while(0);Dxb(d);H=c[t>>2]|0;w=c[v>>2]|0;E=qKb(H)|0;u=qKb(w)|0;F=H>>>0<333>>>0;do{if(B){if(!F){J=29;break}if((H-110|0)>>>0>1>>>0){J=28;break}if((vKb(H)|0)!=(w|0)){J=28}}else{if(F){J=28}else{J=29}}}while(0);do{if((J|0)==28){if((a[1211384+H|0]&1)==0){J=29;break}if(w>>>0<333>>>0){if(!((a[1211384+w|0]&2)==0)){break}}F=mKb(w)|0;KIb(d,16,2238016,(I=i,i=i+8|0,c[I>>2]=F,I)|0);i=I;K=-22;i=h;return K|0}}while(0);if((J|0)==29){F=mKb(H)|0;KIb(d,16,2287992,(I=i,i=i+8|0,c[I>>2]=F,I)|0);i=I;K=-22;i=h;return K|0}F=y&2047;do{if((F|0)==0){B=y|4;c[x>>2]=B;L=B}else{if((y+2047&F|0)==0){L=y;break}KIb(d,16,2197440,(I=i,i=i+8|0,c[I>>2]=F,I)|0);i=I;K=-22;i=h;return K|0}}while(0);if((l|0)<1|(n|0)<1|(p|0)<1|(r|0)<1){KIb(d,16,2165848,(I=i,i=i+32|0,c[I>>2]=l,c[I+8>>2]=n,c[I+16>>2]=p,c[I+24>>2]=r,I)|0);i=I;K=-22;i=h;return K|0}F=(g|0)==0?j:g;g=(f|0)==0?j:f;f=l;j=p>>1;y=wrc(j,(j|0)<0|0?-1:0,f<<16|0>>>16,((l|0)<0|0?-1:0)<<16|f>>>16)|0;f=Crc(y,G,p,(p|0)<0|0?-1:0)|0;y=d+36|0;c[y>>2]=f;f=n;j=r>>1;B=wrc(j,(j|0)<0|0?-1:0,f<<16|0>>>16,((n|0)<0|0?-1:0)<<16|f>>>16)|0;f=r;j=(r|0)<0|0?-1:0;M=Crc(B,G,f,j)|0;B=d+44|0;c[B>>2]=M;c[d+60>>2]=oKb(u)|0;c[d+64>>2]=oKb(E)|0;M=d+19624|0;c[M>>2]=262148;c[M+4>>2]=262148;M=g+4|0;N=c[M>>2]|0;if((N|0)==0){J=41}else{if((c[N+4>>2]|0)>1){O=1}else{J=41}}do{if((J|0)==41){N=c[g+12>>2]|0;if((N|0)!=0){if((c[N+4>>2]|0)>1){O=1;break}}N=c[F+4>>2]|0;if((N|0)!=0){if((c[N+4>>2]|0)>1){O=1;break}}N=c[F+12>>2]|0;if((N|0)==0){O=0;break}O=(c[N+4>>2]|0)>1}}while(0);N=g|0;P=c[N>>2]|0;if((P|0)==0){J=49}else{if((c[P+4>>2]|0)>1){Q=1}else{J=49}}do{if((J|0)==49){P=c[g+8>>2]|0;if((P|0)!=0){if((c[P+4>>2]|0)>1){Q=1;break}}P=c[F>>2]|0;if((P|0)!=0){if((c[P+4>>2]|0)>1){Q=1;break}}P=c[F+8>>2]|0;if((P|0)==0){Q=0;break}Q=(c[P+4>>2]|0)>1}}while(0);P=d+76|0;R=d+80|0;tKb(H,P,R)|0;S=d+84|0;T=d+88|0;tKb(w,S,T)|0;U=(w|0)==64;a:do{switch(w|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{J=59;break};default:{V=qKb(w)|0;if((V|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=674,I)|0);i=I;Hd();return 0}else{if((a[V+7|0]&32)==0){W=L;break a}else{J=59;break a}}}}}while(0);do{if((J|0)==59){if((L&8192|0)!=0){W=L;break}if((p&1|0)==0){X=L}else{KIb(d,48,2139656,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;V=L|8192;c[x>>2]=V;X=V}if((c[P>>2]|0)!=0){W=X;break}if((c[R>>2]|0)!=0){W=X;break}if((c[d+23972>>2]|0)==2){W=X;break}if((c[x>>2]&1|0)!=0){W=X;break}KIb(d,48,2116200,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;V=X|8192;c[x>>2]=V;W=V}}while(0);X=d+23972|0;L=c[X>>2]|0;do{if((L|0)==1){if((W&8388608|0)==0){Y=1;break}c[X>>2]=3;Y=3}else{Y=L}}while(0);do{if((w|0)==24|(w|0)==22|(w|0)==21|(w|0)==19){if((Y|0)==1){L=W>>>13&1|2;c[X>>2]=L;Z=L}else{Z=Y}if((W&8192|0)==0&(Z|0)==3){L=mKb(w)|0;KIb(d,48,2634064,(I=i,i=i+8|0,c[I>>2]=L,I)|0);i=I;L=W|8192;c[x>>2]=L;_=L}else{_=W}if((_&8192|0)==0){$=_;break}if((c[X>>2]|0)!=2){$=_;break}L=mKb(w)|0;KIb(d,48,2610320,(I=i,i=i+8|0,c[I>>2]=L,I)|0);i=I;c[X>>2]=3;$=_}else{$=W}}while(0);W=qKb(w)|0;if((W|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=820,I)|0);i=I;Hd();return 0}do{if((a[W+7|0]&48)==48){if(($&8192|0)!=0){aa=$;break}_=mKb(w)|0;KIb(d,48,2583872,(I=i,i=i+8|0,c[I>>2]=_,I)|0);i=I;_=$|8192;c[x>>2]=_;aa=_}else{aa=$}}while(0);b:do{if((aa&8192|0)==0){ba=aa}else{c:do{switch(w|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{break};default:{$=qKb(w)|0;if(($|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=674,I)|0);i=I;Hd();return 0}else{if((a[$+7|0]&32)==0){ba=aa;break b}else{break c}}}}}while(0);$=qKb(w)|0;if(($|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=820,I)|0);i=I;Hd();return 0}if((a[$+7|0]&48)==48){ba=aa;break}switch(w|0){case 30:case 29:case 28:case 27:case 24:case 22:case 21:case 19:case 3:case 2:{ba=aa;break b;break};default:{}}$=mKb(w)|0;KIb(d,24,2563192,(I=i,i=i+8|0,c[I>>2]=$,I)|0);i=I;$=aa&-8193;c[x>>2]=$;ba=$}}while(0);d:do{switch(w|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{J=97;break};default:{x=qKb(w)|0;if((x|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=674,I)|0);i=I;Hd();return 0}else{if((a[x+7|0]&32)==0){break d}else{J=97;break d}}}}}while(0);do{if((J|0)==97){if((ba&8192|0)!=0){break}c[S>>2]=1}}while(0);x=ba>>>16&3;c[d+92>>2]=x;c[R>>2]=(c[R>>2]|0)+x;e:do{switch(H|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{J=103;break};default:{x=qKb(H)|0;if((x|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=674,I)|0);i=I;Hd();return 0}else{if((a[x+7|0]&32)==0){break e}else{J=103;break e}}}}}while(0);f:do{if((J|0)==103){if((ba&16384|0)!=0){break}switch(H|0){case 316:case 315:case 314:case 313:case 88:case 87:case 86:case 85:case 84:case 83:case 24:case 23:case 22:case 21:case 20:case 19:{break f;break};default:{}}if((p>>c[S>>2]|0)>(l>>1|0)){if((ba&1|0)==0){break}}c[P>>2]=1}}while(0);x=d+20|0;c[x>>2]=-(-l>>c[P>>2]);aa=d+24|0;c[aa>>2]=-(-n>>c[R>>2]);$=d+28|0;c[$>>2]=-(-p>>c[S>>2]);W=d+32|0;c[W>>2]=-(-r>>c[T>>2]);_=(l<<2)+186&-32;X=hJb(_)|0;c[d+2208>>2]=X;if(!((X|0)!=0|(_|0)==0)){KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}g:do{if(!(Q|z&A^1|O)){h:do{if((c[C>>2]|0)!=(c[D>>2]|0)){switch(w|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{break h;break};default:{}}_=qKb(w)|0;if((_|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=674,I)|0);i=I;Hd();return 0}else{if((a[_+7|0]&32)==0){break g}else{break}}}}while(0);PDb(d);if((c[d+4>>2]|0)==0){break}if((ba&4096|0)==0){K=0;i=h;return K|0}_=mKb(H)|0;X=mKb(w)|0;KIb(d,32,2527904,(I=i,i=i+16|0,c[I>>2]=_,c[I+8>>2]=X,I)|0);i=I;K=0;i=h;return K|0}}while(0);D=((e[E+8>>1]|0)>>>11&15)+1|0;E=d+72|0;c[E>>2]=D>>>0<8>>>0?8:D;D=u+8|0;u=((e[D>>1]|0)>>>11&15)+1|0;C=d+68|0;c[C>>2]=u>>>0<8>>>0?8:u;i:do{switch(H|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{J=123;break};default:{u=qKb(H)|0;if((u|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=674,I)|0);i=I;Hd();return 0}else{if((a[u+7|0]&32)!=0|(H|0)==11){J=123;break i}else{break i}}}}}while(0);if((J|0)==123){c[E>>2]=16}E=s<<((c[C>>2]|0)==16);c[d+2276>>2]=0;s=c[x>>2]|0;u=s;O=c[$>>2]|0;A=O>>1;z=wrc(A,(A|0)<0|0?-1:0,u<<16|0>>>16,((s|0)<0|0?-1:0)<<16|u>>>16)|0;u=Crc(z,G,O,(O|0)<0|0?-1:0)|0;O=d+40|0;c[O>>2]=u;u=c[aa>>2]|0;z=u;s=c[W>>2]|0;A=s>>1;Q=wrc(A,(A|0)<0|0?-1:0,z<<16|0>>>16,((u|0)<0|0?-1:0)<<16|z>>>16)|0;z=Crc(Q,G,s,(s|0)<0|0?-1:0)|0;s=d+48|0;c[s>>2]=z;z=(ba&64|0)!=0;Q=z?ba|4:ba;u=d+104|0;if((Hxb(d+2212|0,d+2228|0,d+2244|0,c[y>>2]|0,l,p,16384,Q,c[N>>2]|0,c[F>>2]|0,u,128,128)|0)<0){K=-1;i=h;return K|0}N=z?ba|2:ba;z=c[P>>2]|0;P=c[d+11284>>2]|0;if((P|0)<0){ca=(128<<z)-128|0}else{ca=P}P=c[S>>2]|0;S=c[d+11288>>2]|0;if((S|0)<0){da=(128<<P)-128|0}else{da=S}if((Hxb(d+2216|0,d+2232|0,d+2248|0,c[O>>2]|0,c[x>>2]|0,c[$>>2]|0,16384,N,c[g+8>>2]|0,c[F+8>>2]|0,u,ca+128>>z,da+128>>P)|0)<0){K=-1;i=h;return K|0}P=d+2236|0;da=d+2252|0;if((Hxb(d+2220|0,P,da,c[B>>2]|0,n,r,4096,Q,c[M>>2]|0,c[F+4>>2]|0,u,128,128)|0)<0){K=-1;i=h;return K|0}M=d+2240|0;Q=d+2256|0;z=c[R>>2]|0;ca=c[d+11292>>2]|0;if((ca|0)<0){ea=(128<<z)-128|0}else{ea=ca}ca=c[T>>2]|0;T=c[d+11296>>2]|0;if((T|0)<0){fa=(128<<ca)-128|0}else{fa=T}if((Hxb(d+2224|0,M,Q,c[s>>2]|0,c[aa>>2]|0,c[W>>2]|0,4096,N,c[g+12>>2]|0,c[F+12>>2]|0,u,ea+128>>z,fa+128>>ca)|0)<0){K=-1;i=h;return K|0}ca=c[da>>2]|0;da=d+2184|0;c[da>>2]=ca;fa=c[Q>>2]|0;Q=d+2188|0;c[Q>>2]=fa;if((r|0)>0){z=c[P>>2]|0;P=c[M>>2]|0;M=c[W>>2]|0;ea=c[R>>2]|0;R=0;u=ca;F=fa;while(1){g=Erc(M,(M|0)<0|0?-1:0,R,(R|0)<0|0?-1:0)|0;N=Crc(g,G,f,j)|0;g=c[z+(R<<2)>>2]|0;T=g-1+ca|0;S=P+(N<<2)|0;N=c[S>>2]|0;A=N-1+fa<<ea;X=((T|0)>(A|0)?T:A)>>ea<<ea;if((u+g|0)<(X|0)){A=X-g|0;c[da>>2]=A;ga=A;ha=c[S>>2]|0}else{ga=u;ha=N}N=X>>ea;if((F+ha|0)<(N|0)){X=N-ha|0;c[Q>>2]=X;ia=X}else{ia=F}X=R+1|0;if((X|0)<(r|0)){R=X;u=ga;F=ia}else{break}}}ia=pJb((c[o>>2]<<2)+8|0)|0;c[d+11200>>2]=ia;F=c[o>>2]|0;if((ia|0)==0){if((F&1073741823|0)==1073741822){J=146}}else{J=146}do{if((J|0)==146){ia=pJb((F<<2)+8|0)|0;c[d+11204>>2]=ia;ga=c[o>>2]|0;if((ia|0)==0){if((ga&1073741823|0)!=1073741822){break}}ia=pJb((ga<<2)+8|0)|0;c[d+11208>>2]=ia;ga=c[o>>2]|0;if((ia|0)==0){if((ga&1073741823|0)!=1073741822){break}}ia=pJb((ga<<2)+8|0)|0;c[d+11212>>2]=ia;if((ia|0)==0){if((c[o>>2]&1073741823|0)!=1073741822){break}}ia=hJb((c[da>>2]|0)*12|0)|0;ga=d+2168|0;c[ga>>2]=ia;do{if((ia|0)==0){if(((c[da>>2]|0)*12|0|0)==0){break}KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);ia=hJb((c[Q>>2]|0)*12|0)|0;u=d+2172|0;c[u>>2]=ia;R=c[Q>>2]|0;do{if((ia|0)==0){if((R*12|0|0)==0){break}KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);ia=hJb(R*12|0)|0;ha=d+2176|0;c[ha>>2]=ia;do{if((ia|0)==0){if(((c[Q>>2]|0)*12|0|0)==0){break}KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);ia=c[t>>2]|0;R=qKb(ia)|0;if((R|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=778,I)|0);i=I;Hd();return 0}if((ia|0)==11){J=159}else{if((a[R+7|0]|0)>-1){J=164}else{J=159}}do{if((J|0)==159){R=c[v>>2]|0;ia=qKb(R)|0;if((ia|0)==0){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2284040,c[I+8>>2]=2280320,c[I+16>>2]=778,I)|0);i=I;Hd();return 0}if((R|0)!=11){if((a[ia+7|0]|0)>-1){J=164;break}}ia=pJb((c[da>>2]|0)*12|0)|0;c[d+2180>>2]=ia;if((ia|0)!=0){J=164;break}ia=c[da>>2]|0;if((ia*12|0|0)==0){ja=ia;break}KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);if((J|0)==164){ja=c[da>>2]|0}ia=E+16|0;j:do{if((ja|0)>0){R=(ia|0)==0;ea=0;while(1){fa=pJb(ia)|0;P=c[da>>2]|0;ca=P+ea|0;c[(c[ga>>2]|0)+(ca<<2)>>2]=fa;fa=c[ga>>2]|0;z=c[fa+(ca<<2)>>2]|0;if(!((z|0)!=0|R)){break}c[fa+(ea<<2)>>2]=z;ea=ea+1|0;if((ea|0)>=(P|0)){break j}}KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);ga=E>>1;c[d+23752>>2]=(64/(c[C>>2]&-8|0)|0)+ga;c[d+23760>>2]=ia;ea=c[Q>>2]|0;k:do{if((ea|0)>0){R=(E<<1)+32|0;P=(R|0)==0;z=ga+8|0;fa=0;while(1){ca=hJb(R)|0;j=c[Q>>2]|0;f=j+fa|0;c[(c[u>>2]|0)+(f<<2)>>2]=ca;ca=c[u>>2]|0;M=c[ca+(f<<2)>>2]|0;if(!((M|0)!=0|P)){break}c[ca+(fa<<2)>>2]=M;M=(c[(c[u>>2]|0)+(fa<<2)>>2]|0)+(z<<1)|0;c[(c[ha>>2]|0)+(f<<2)>>2]=M;c[(c[ha>>2]|0)+(fa<<2)>>2]=M;M=fa+1|0;if((M|0)<(j|0)){fa=M}else{ka=j;break k}}KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}else{ka=ea}}while(0);ea=d+2180|0;do{if((c[ea>>2]|0)==0){la=ka}else{if((c[da>>2]|0)<=0){la=ka;break}ha=(ia|0)==0;ga=0;while(1){fa=pJb(ia)|0;z=c[da>>2]|0;P=z+ga|0;c[(c[ea>>2]|0)+(P<<2)>>2]=fa;fa=c[ea>>2]|0;R=c[fa+(P<<2)>>2]|0;if(!((R|0)!=0|ha)){break}c[fa+(ga<<2)>>2]=R;R=ga+1|0;if((R|0)<(z|0)){ga=R}else{J=180;break}}if((J|0)==180){la=c[Q>>2]|0;break}KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}}while(0);l:do{if((la|0)>0){ea=((E|0)/2|0)+1|0;ia=(ea|0)>0;ga=E|1;ha=(ga|0)>0;R=0;z=la;m:while(1){do{if((b[D>>1]&30720)==30720){if((c[C>>2]|0)<=14){break m}if(!ia){ma=z;break}fa=c[(c[u>>2]|0)+(R<<2)>>2]|0;P=0;do{c[fa+(P<<2)>>2]=262144;P=P+1|0;}while((P|0)<(ea|0));ma=c[Q>>2]|0}else{if(!ha){ma=z;break}P=c[(c[u>>2]|0)+(R<<2)>>2]|0;fa=0;while(1){b[P+(fa<<1)>>1]=16384;j=fa+1|0;if((j|0)<(ga|0)){fa=j}else{ma=z;break}}}}while(0);fa=R+1|0;if((fa|0)<(ma|0)){R=fa;z=ma}else{break l}}KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2499312,c[I+8>>2]=2486880,c[I+16>>2]=1586,I)|0);i=I;Hd();return 0}}while(0);if((c[W>>2]|0)>(r|0)){KIb(0,0,2512944,(I=i,i=i+24|0,c[I>>2]=2475224,c[I+8>>2]=2486880,c[I+16>>2]=1593,I)|0);i=I;Hd();return 0}if((ba&4096|0)!=0){u=0;while(1){if(!(u>>>0<11>>>0)){na=0;break}if((c[608768+(u*12|0)>>2]&ba|0)==0){u=u+1|0}else{J=202;break}}if((J|0)==202){na=c[608772+(u*12|0)>>2]|0}z=d;R=mKb(H)|0;switch(w|0){case 65:case 63:case 62:case 50:case 48:{oa=2439024;break};default:{oa=U?2439024:10230456}}ga=mKb(w)|0;KIb(z,32,2456240,(I=i,i=i+32|0,c[I>>2]=(na|0)==0?2466424:na,c[I+8>>2]=R,c[I+16>>2]=oa,c[I+24>>2]=ga,I)|0);i=I;KIb(z,32,2408864,(I=i,i=i+8|0,c[I>>2]=2417960,I)|0);i=I;KIb(z,40,2401392,(I=i,i=i+32|0,c[I>>2]=l,c[I+8>>2]=n,c[I+16>>2]=p,c[I+24>>2]=r,I)|0);i=I;ga=c[m>>2]|0;R=c[o>>2]|0;ha=c[q>>2]|0;ea=c[y>>2]|0;ia=c[B>>2]|0;KIb(z,48,2394464,(I=i,i=i+48|0,c[I>>2]=c[k>>2],c[I+8>>2]=ga,c[I+16>>2]=R,c[I+24>>2]=ha,c[I+32>>2]=ea,c[I+40>>2]=ia,I)|0);i=I;ia=c[aa>>2]|0;ea=c[$>>2]|0;ha=c[W>>2]|0;R=c[O>>2]|0;ga=c[s>>2]|0;KIb(z,48,2387424,(I=i,i=i+48|0,c[I>>2]=c[x>>2],c[I+8>>2]=ia,c[I+16>>2]=ea,c[I+24>>2]=ha,c[I+32>>2]=R,c[I+40>>2]=ga,I)|0);i=I}c[d+4>>2]=fxb(d)|0;K=0;i=h;return K|0}}while(0);KIb(d,16,2545712,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;K=-1;i=h;return K|0}function Hxb(a,e,f,g,j,k,l,m,n,o,p,q,r){a=a|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0,ea=0,fa=0,ga=0.0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0.0,Na=0.0,Oa=0.0,Pa=0.0,Qa=0.0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0.0,Wa=0.0,Xa=0.0,Ya=0.0,Za=0.0,_a=0.0,$a=0.0,ab=0.0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0.0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0;s=i;i=i+8|0;t=s|0;c[t>>2]=0;u=(j|0)/(k|0)|0;v=u>>>0>65535>>>0;w=v?u>>>16:u;u=v?16:0;if((w&65280|0)==0){x=u;y=w}else{x=u|8;y=w>>>8}w=(d[1359664+y|0]|0)+x|0;x=(w|0)>8;y=x?46:54-w|0;x?0:0;x=yrc(1,0,y|0)|0;w=G;u=k+3|0;v=u<<2;z=hJb(v)|0;c[e>>2]=z;a:do{if((z|0)!=0|(v|0)==0){A=g-65536|0;b:do{if((((A|0)>-1?A:65536-g|0)|0)<10&(q|0)==(r|0)){B=k<<3;C=pJb(B)|0;D=C;c[t>>2]=D;if(!((C|0)!=0|(B|0)==0)){KIb(0,16,2545712,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;H=0;break a}if((k|0)<=0){I=1;J=D;break}B=c[e>>2]|0;C=0;while(1){K=D+(C<<3)|0;c[K>>2]=x;c[K+4>>2]=w;c[B+(C<<2)>>2]=C;K=C+1|0;if((K|0)<(k|0)){C=K}else{I=1;J=D;break}}}else{if((m&16|0)!=0){D=k<<3;C=hJb(D)|0;B=C;c[t>>2]=B;if(!((C|0)!=0|(D|0)==0)){KIb(0,16,2545712,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;H=0;break a}D=g;C=(g|0)<0|0?-1:0;if((k|0)<=0){I=1;J=B;break}K=q;L=Erc(r,(r|0)<0|0?-1:0,D,C)|0;M=G;N=xrc(L>>>8|M<<24,M>>8|((M|0)<0|0?-1:0)<<24,K<<8|0>>>24,((q|0)<0|0?-1:0)<<8|K>>>24)|0;K=c[e>>2]|0;M=G;L=N;N=0;while(1){O=wrc(L,M,32768,0)|0;c[K+(N<<2)>>2]=O>>>16|G<<16;O=B+(N<<3)|0;c[O>>2]=x;c[O+4>>2]=w;O=wrc(L,M,D,C)|0;P=N+1|0;if((P|0)<(k|0)){M=G;L=O;N=P}else{I=1;J=B;break b}}}B=(g|0)<65537;if(B){if((m&33|0)!=0){S=21}}else{if((m&1|0)!=0){S=21}}if((S|0)==21){N=k<<4;L=hJb(N)|0;M=L;c[t>>2]=M;if(!((L|0)!=0|(N|0)==0)){KIb(0,16,2545712,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;H=0;break a}N=g;L=(g|0)<0|0?-1:0;if((k|0)<=0){I=2;J=M;break}C=q;D=Erc(r,(r|0)<0|0?-1:0,N,L)|0;K=G;P=xrc(D>>>8|K<<24,K>>8|((K|0)<0|0?-1:0)<<24,C<<8|0>>>24,((q|0)<0|0?-1:0)<<8|C>>>24)|0;C=c[e>>2]|0;K=x>>>16|w<<16;D=w>>16|((w|0)<0|0?-1:0)<<16;O=G;W=P;P=0;while(1){X=W>>>16|O<<16;c[C+(P<<2)>>2]=X;Y=P<<1;Z=X;_=xrc(Z<<16|0>>>16,((X|0)<0|0?-1:0)<<16|Z>>>16,W,O)|0;Z=G;$=-1;aa=(Z|0)>($|0)|(Z|0)==($|0)&_>>>0>-1>>>0;$=xrc(0,0,_,Z)|0;da=Erc(aa?_:$,aa?Z:G,K,D)|0;Z=xrc(x,w,da,G)|0;da=G;aa=0;$=(da|0)<(aa|0)|(da|0)==(aa|0)&Z>>>0<0>>>0;aa=M+(Y<<3)|0;c[aa>>2]=$?0:Z;c[aa+4>>2]=$?0:da;da=X+1|0;X=da;$=xrc(X<<16|0>>>16,((da|0)<0|0?-1:0)<<16|X>>>16,W,O)|0;X=G;da=-1;aa=(X|0)>(da|0)|(X|0)==(da|0)&$>>>0>-1>>>0;da=xrc(0,0,$,X)|0;Z=Erc(aa?$:da,aa?X:G,K,D)|0;X=xrc(x,w,Z,G)|0;Z=G;aa=0;da=(Z|0)<(aa|0)|(Z|0)==(aa|0)&X>>>0<0>>>0;aa=M+((Y|1)<<3)|0;c[aa>>2]=da?0:X;c[aa+4>>2]=da?0:Z;Z=wrc(W,O,N,L)|0;da=P+1|0;if((da|0)<(k|0)){O=G;W=Z;P=da}else{I=2;J=M;break b}}}M=(m&32|0)==0;do{if(M){if((m&4|0)!=0){ea=1;S=26;break}if((m&2|0)!=0){ea=3;S=26;break}if((m&128|0)!=0){ea=5;S=26;break}if((m&256|0)!=0){ea=8;S=26;break}if((m&1024|0)!=0){ea=9;S=26;break}if((m&8|0)==0){fa=-1}else{ea=10;S=26}}else{ea=0;S=26}}while(0);if((S|0)==26){fa=c[608776+(ea*12|0)>>2]|0}P=(m&512|0)!=0;do{if(P){ga=+h[p>>3];if(!(ga!=123456.0)){ia=6;break}ja=~~+ba(ga*2.0);S=31}else{ja=fa;S=31}}while(0);do{if((S|0)==31){if((ja|0)>0){ia=ja;break}KIb(0,0,2512944,(E=i,i=i+24|0,c[E>>2]=2276072,c[E+8>>2]=2486880,c[E+16>>2]=377,E)|0);i=E;Hd();return 0}}while(0);if(B){ka=ia}else{ka=(k-1+(ca(ia,j)|0)|0)/(k|0)|0}W=ka+1|0;O=j-2|0;L=(W|0)>(O|0)?O:W;W=(L|0)>1?L:1;L=ca(W,k<<3)|0;O=hJb(L)|0;N=O;c[t>>2]=N;if(!((O|0)!=0|(L|0)==0)){KIb(0,16,2545712,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;H=0;break a}L=g;O=(g|0)<0|0?-1:0;c:do{if((k|0)>0){D=q;K=Erc(r,(r|0)<0|0?-1:0,L,O)|0;C=G;da=xrc(K>>>7|C<<25,C>>7|((C|0)<0|0?-1:0)<<25,D<<9|0>>>23,((q|0)<0|0?-1:0)<<9|D>>>23)|0;D=G;C=(W<<16)-131072|0;K=C;Z=(C|0)<0|0?-1:0;C=(W|0)>0;aa=g<<1;X=aa;Y=(aa|0)<0|0?-1:0;aa=(g|0)>65536;$=k;_=(k|0)<0|0?-1:0;la=j;ma=(j|0)<0|0?-1:0;na=(m&4|0)==0;oa=(m&8|0)==0;pa=(m&128|0)==0;qa=(m&256|0)==0;ga=+(x>>>0)+ +(w|0)*4294967296.0;ra=(m&2|0)==0;sa=(m&1024|0)==0;ta=x>>>30|w<<2;ua=w>>30|((w|0)<0|0?-1:0)<<2;va=w>>14|((w|0)<0|0?-1:0)<<18;wa=((w|0)<0|0?-1:0)>>14|((w|0)<0|0?-1:0)<<18;xa=p+8|0;ya=zrc(0,4194304,y|0)|0;za=G;Aa=c[e>>2]|0;Ba=D;D=da;da=0;d:while(1){Ca=xrc(D,Ba,K,Z)|0;Da=Crc(Ca,G,131072,0)|0;Ca=Da;c[Aa+(da<<2)>>2]=Ca;if(C){Da=ca(da,W)|0;Ea=Ca;Ca=0;while(1){Fa=Ea;Ga=xrc(Fa<<17|0>>>15,((Ea|0)<0|0?-1:0)<<17|Fa>>>15,D,Ba)|0;Fa=G;Ha=-1;Ia=(Fa|0)>(Ha|0)|(Fa|0)==(Ha|0)&Ga>>>0>-1>>>0;Ha=xrc(0,0,Ga,Fa)|0;Ja=Ia?Ga:Ha;Ha=Ja<<13|0>>>19;Ga=(Ia?Fa:G)<<13|Ja>>>19;if(aa){Ja=Erc(Ha,Ga,$,_)|0;Fa=Crc(Ja,G,la,ma)|0;Ka=G;La=Fa}else{Ka=Ga;La=Ha}Ma=(+(La>>>0)+ +(Ka|0)*4294967296.0)*9.313225746154785e-10;do{if(na){if(!oa){Na=+h[p>>3];Oa=Na!=123456.0?Na:1.0;do{if(Ma<1.0){Na=+U(Ma*3.141592653589793);if(Na<0.0){Pa=Na;S=56;break}Qa=+T(+Na,+Oa)}else{Pa=-1.0;S=56}}while(0);if((S|0)==56){S=0;Qa=-0.0- +T(+(-0.0-Pa),+Oa)}Na=ga*(Qa*.5+.5);Ra=(F=+Na,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Sa=~~+Na>>>0;break}if(!M){Ha=wrc(La,Ka,-536870912,-1)|0;Ga=Erc(Ha,G,L,O)|0;Ha=G;Fa=-8192;do{if((Ha|0)<(Fa|0)|(Ha|0)==(Fa|0)&Ga>>>0<0>>>0){Ta=16384;Ua=0}else{Ja=8192;if(!((Ha|0)<(Ja|0)|(Ha|0)==(Ja|0)&Ga>>>0<0>>>0)){Ta=0;Ua=0;break}Ja=xrc(536870912,0,La,Ka)|0;Ia=Erc(Ja,G,L,O)|0;Ja=wrc(Ia,G,0,8192)|0;Ta=G;Ua=Ja}}while(0);Ga=Erc(Ua,Ta,va,wa)|0;Ra=G;Sa=Ga;break}if(!pa){Oa=+h[p>>3];Na=ga*+ad(+(Ma*Ma*(-0.0-(Oa!=123456.0?Oa:3.0))));Ra=(F=+Na,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Sa=~~+Na>>>0;break}if(!qa){if((La|0)==0&(Ka|0)==0){Va=1.0}else{Na=Ma*3.141592653589793;Va=+V(Na)/Na}Na=ga*Va;Ra=(F=+Na,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Sa=~~+Na>>>0;break}if(P){Na=+h[p>>3];Oa=Na!=123456.0?Na:3.0;if((La|0)==0&(Ka|0)==0){Wa=1.0}else{Na=Ma*3.141592653589793;Wa=+V(Na)*+V(Na/Oa)/(Ma*Ma*3.141592653589793*3.141592653589793/Oa)}Na=ga*Wa;Ga=(F=+Na,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);if(!(Ma>Oa)){Ra=Ga;Sa=~~+Na>>>0;break}Ra=0;Sa=0;break}if(!ra){Ga=xrc(1073741824,0,La,Ka)|0;Ha=G;Fa=0;Ja=(Ha|0)<(Fa|0)|(Ha|0)==(Fa|0)&Ga>>>0<0>>>0;Fa=Erc(Ja?0:Ga,Ja?0:Ha,ta,ua)|0;Ra=G;Sa=Fa;break}if(sa){break d}if(Ma>1.0){Na=0.0;Oa=-2.196152422706632;Xa=1.196152422706632;Ya=Ma;while(1){Za=Xa*3.0;_a=Za+(Na+Oa*2.0);$a=Oa+Za;Za=-0.0-Na-Oa*3.0-Xa*6.0;ab=Ya+-1.0;if(ab>1.0){Na=_a;Oa=$a;Xa=Za;Ya=ab}else{bb=0.0;cb=_a;db=$a;eb=Za;fb=ab;break}}}else{bb=1.0;cb=0.0;db=-2.196152422706632;eb=1.196152422706632;fb=Ma}Ya=ga*(bb+fb*(cb+fb*(db+fb*eb)));Ra=(F=+Ya,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Sa=~~+Ya>>>0}else{Ya=+h[p>>3];if(Ya!=123456.0){Xa=Ya*16777216.0;gb=(F=+Xa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);hb=~~+Xa>>>0}else{gb=0;hb=0}Xa=+h[xa>>3];if(Xa!=123456.0){Ya=Xa*16777216.0;ib=(F=+Ya,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);jb=~~+Ya>>>0}else{ib=0;jb=10066329}Fa=0;do{if((Ka|0)>(Fa|0)|(Ka|0)==(Fa|0)&La>>>0>2147483647>>>0){kb=0;lb=0}else{Ha=Erc(La,Ka,La,Ka)|0;Ja=G;Ga=Ha>>>30|Ja<<2;Ha=Ja>>>30|0<<2;Ja=Erc(Ga,Ha,La,Ka)|0;Ia=G;mb=Ja>>>30|Ia<<2;Ja=Ia>>30|((Ia|0)<0|0?-1:0)<<2;Ia=0;if((Ka|0)<(Ia|0)|(Ka|0)==(Ia|0)&La>>>0<1073741824>>>0){Ia=Erc(hb,gb,-9,-1)|0;nb=wrc(Ia,G,201326592,0)|0;Ia=G;ob=Erc(jb,ib,6,0)|0;pb=G;qb=xrc(nb,Ia,ob,pb)|0;Ia=Erc(qb,G,mb,Ja)|0;qb=G;nb=Erc(hb,gb,12,0)|0;rb=wrc(nb,G,-301989888,-1)|0;nb=wrc(rb,G,ob,pb)|0;pb=Erc(nb,G,Ga,Ha)|0;nb=G;ob=xrc(100663296,0,hb<<1|0>>>31,gb<<1|hb>>>31)|0;rb=wrc(pb,nb,ob<<30|0>>>2,G<<30|ob>>>2)|0;ob=wrc(rb,G,Ia,qb)|0;kb=G;lb=ob;break}else{ob=Erc(jb,ib,-6,-1)|0;qb=xrc(ob,G,hb,gb)|0;ob=Erc(qb,G,mb,Ja)|0;Ja=G;mb=Erc(hb,gb,6,0)|0;qb=G;Ia=Erc(jb,ib,30,0)|0;rb=wrc(Ia,G,mb,qb)|0;qb=Erc(rb,G,Ga,Ha)|0;Ha=wrc(ob,Ja,qb,G)|0;qb=G;Ja=Erc(hb,gb,-12,-1)|0;ob=G;Ga=Erc(jb,ib,-48,-1)|0;rb=wrc(Ga,G,Ja,ob)|0;ob=Erc(rb,G,La,Ka)|0;rb=wrc(Ha,qb,ob,G)|0;ob=G;qb=Erc(jb,ib,24,0)|0;Ha=wrc(qb,G,hb<<3|0>>>29,gb<<3|hb>>>29)|0;qb=wrc(rb,ob,Ha<<30|0>>>2,G<<30|Ha>>>2)|0;kb=G;lb=qb;break}}}while(0);Fa=Crc(lb,kb,ya,za)|0;Ra=G;Sa=Fa}}while(0);Fa=N+(Ca+Da<<3)|0;c[Fa>>2]=Sa;c[Fa+4>>2]=Ra;Fa=Ca+1|0;if((Fa|0)<(W|0)){Ea=Ea+1|0;Ca=Fa}else{break}}}Ca=wrc(D,Ba,X,Y)|0;Ea=da+1|0;if((Ea|0)<(k|0)){Ba=G;D=Ca;da=Ea}else{break c}}KIb(0,0,2512944,(E=i,i=i+24|0,c[E>>2]=2271440,c[E+8>>2]=2486880,c[E+16>>2]=475,E)|0);i=E;Hd();return 0}}while(0);if((W|0)>0){I=W;J=N;break}KIb(0,0,2512944,(E=i,i=i+24|0,c[E>>2]=2266848,c[E+8>>2]=2486880,c[E+16>>2]=488,E)|0);i=E;Hd();return 0}}while(0);A=(n|0)!=0;if(A){sb=I-1+(c[n+4>>2]|0)|0}else{sb=I}if((o|0)==0){tb=sb}else{tb=sb-1+(c[o+4>>2]|0)|0}if((tb|0)<=0){KIb(0,0,2512944,(E=i,i=i+24|0,c[E>>2]=2263304,c[E+8>>2]=2486880,c[E+16>>2]=494,E)|0);i=E;Hd();return 0}P=k<<3;O=ca(P,tb)|0;L=pJb(O)|0;M=L;if(!((L|0)!=0|(O|0)==0)){KIb(0,16,2545712,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;H=M;break}O=(k|0)>0;if(!O){mJb(t);KIb(0,0,2512944,(E=i,i=i+24|0,c[E>>2]=2259440,c[E+8>>2]=2486880,c[E+16>>2]=576,E)|0);i=E;Hd();return 0}L=n+4|0;B=(I|0)>0;da=n|0;D=((tb-1|0)/-2|0)+((I-1|0)/2|0)|0;Ba=c[e>>2]|0;Y=0;do{do{if(A){X=c[L>>2]|0;if((X|0)<=0){break}za=ca(Y,I)|0;ya=ca(Y,tb)|0;if(B){ub=0}else{break}do{ga=+h[(c[da>>2]|0)+(ub<<3)>>3];xa=ub+ya|0;sa=0;do{ua=J+(sa+za<<3)|0;ta=M+(xa+sa<<3)|0;Ma=+((c[ta>>2]|0)>>>0)+ +(c[ta+4>>2]|0)*4294967296.0+ga*(+((c[ua>>2]|0)>>>0)+ +(c[ua+4>>2]|0)*4294967296.0);ua=(F=+Ma,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[ta>>2]=~~+Ma>>>0;c[ta+4>>2]=ua;sa=sa+1|0;}while((sa|0)<(I|0));ub=ub+1|0;}while((ub|0)<(X|0))}else{if(!B){break}X=ca(Y,I)|0;za=ca(Y,tb)|0;ya=0;do{sa=J+(ya+X<<3)|0;xa=c[sa+4>>2]|0;ua=M+(ya+za<<3)|0;c[ua>>2]=c[sa>>2];c[ua+4>>2]=xa;ya=ya+1|0;}while((ya|0)<(I|0))}}while(0);N=Ba+(Y<<2)|0;c[N>>2]=D+(c[N>>2]|0);Y=Y+1|0;}while((Y|0)<(k|0));mJb(t);Y=k-1|0;if(!O){KIb(0,0,2512944,(E=i,i=i+24|0,c[E>>2]=2259440,c[E+8>>2]=2486880,c[E+16>>2]=576,E)|0);i=E;Hd();return 0}ga=(+(x>>>0)+ +(w|0)*4294967296.0)*.002;D=(tb|0)>1;Ba=0;B=Y;da=ca(tb,k)|0;while(1){L=ca(B,tb)|0;A=M+(L<<3)|0;N=(B|0)<(Y|0);W=B+1|0;ya=L+1|0;za=0;X=0;xa=0;while(1){ua=c[A>>2]|0;sa=c[A+4>>2]|0;ta=-1;ra=(sa|0)>(ta|0)|(sa|0)==(ta|0)&ua>>>0>-1>>>0;ta=xrc(0,0,ua,sa)|0;qa=wrc(ra?ua:ta,ra?sa:G,xa,X)|0;sa=G;if(+(qa>>>0)+ +(sa|0)*4294967296.0>ga){vb=0;wb=0;xb=tb;break}if(N){ra=c[e>>2]|0;if((c[ra+(B<<2)>>2]|0)>=(c[ra+(W<<2)>>2]|0)){vb=0;wb=0;xb=tb;break}}if(D){ra=1;ta=ya;while(1){ua=M+(ta<<3)|0;pa=c[ua+4>>2]|0;wa=M+(ta-1<<3)|0;c[wa>>2]=c[ua>>2];c[wa+4>>2]=pa;pa=ra+1|0;if((pa|0)<(tb|0)){ra=pa;ta=pa+L|0}else{yb=da;break}}}else{yb=ya}ta=M+(yb-1<<3)|0;c[ta>>2]=0;c[ta+4>>2]=0;ta=(c[e>>2]|0)+(B<<2)|0;c[ta>>2]=(c[ta>>2]|0)+1;ta=za+1|0;if((ta|0)<(tb|0)){za=ta;X=sa;xa=qa}else{vb=0;wb=0;xb=tb;break}}while(1){xa=xb-1|0;if((xa|0)<=0){break}X=M+(xa+L<<3)|0;za=c[X>>2]|0;ya=c[X+4>>2]|0;X=-1;W=(ya|0)>(X|0)|(ya|0)==(X|0)&za>>>0>-1>>>0;X=xrc(0,0,za,ya)|0;N=wrc(W?za:X,W?ya:G,wb,vb)|0;ya=G;if(+(N>>>0)+ +(ya|0)*4294967296.0>ga){break}else{vb=ya;wb=N;xb=xa}}zb=(xb|0)>(Ba|0)?xb:Ba;if((B|0)>0){Ba=zb;B=B-1|0;da=da-tb|0}else{break}}if((zb|0)<=0){KIb(0,0,2512944,(E=i,i=i+24|0,c[E>>2]=2259440,c[E+8>>2]=2486880,c[E+16>>2]=576,E)|0);i=E;Hd();return 0}da=hJb(ca(P,zb)|0)|0;c[t>>2]=da;if((zb|0)>255|(da|0)==0){KIb(0,16,2255024,(E=i,i=i+8|0,c[E>>2]=zb,E)|0);i=E;H=M;break}c[f>>2]=zb;if((m&4096|0)!=0){KIb(0,40,2249776,(E=i,i=i+16|0,c[E>>2]=tb,c[E+8>>2]=zb,E)|0);i=E}do{if(O){da=c[t>>2]|0;B=(m&524288|0)==0;Ba=0;do{D=ca(Ba,tb)|0;L=ca(Ba,zb)|0;if(B){xa=0;do{if((xa|0)<(tb|0)){N=M+(xa+D<<3)|0;ya=c[N+4>>2]|0;W=da+(xa+L<<3)|0;c[W>>2]=c[N>>2];c[W+4>>2]=ya}else{ya=da+(xa+L<<3)|0;c[ya>>2]=0;c[ya+4>>2]=0}xa=xa+1|0;}while((xa|0)<(zb|0))}else{xa=0;do{if((xa|0)<(tb|0)){qa=M+(xa+D<<3)|0;sa=c[qa+4>>2]|0;ya=da+(xa+L<<3)|0;c[ya>>2]=c[qa>>2];c[ya+4>>2]=sa}else{sa=da+(xa+L<<3)|0;c[sa>>2]=0;c[sa+4>>2]=0}xa=xa+1|0;}while((xa|0)<(zb|0))}Ba=Ba+1|0;}while((Ba|0)<(k|0));if(!O){break}Ba=c[e>>2]|0;da=zb-2|0;B=(da|0)>-1;xa=j-zb|0;L=zb-1|0;D=c[t>>2]|0;sa=(zb|0)>1;ya=0;do{qa=Ba+(ya<<2)|0;W=c[qa>>2]|0;if((W|0)<0){if(sa){N=ca(ya,zb)|0;X=1;do{za=W+X|0;A=D+(X+N<<3)|0;ta=D+(((za|0)>0?za:0)+N<<3)|0;za=wrc(c[ta>>2]|0,c[ta+4>>2]|0,c[A>>2]|0,c[A+4>>2]|0)|0;c[ta>>2]=za;c[ta+4>>2]=G;c[A>>2]=0;c[A+4>>2]=0;X=X+1|0;}while((X|0)<(zb|0))}c[qa>>2]=0;Ab=0}else{Ab=W}X=Ab+zb|0;if((X|0)>(j|0)){N=X-j|0;if(B){X=ca(ya,zb)|0;A=da;while(1){ta=A+N|0;za=D+(A+X<<3)|0;ra=D+(((ta|0)>(L|0)?L:ta)+X<<3)|0;ta=wrc(c[ra>>2]|0,c[ra+4>>2]|0,c[za>>2]|0,c[za+4>>2]|0)|0;c[ra>>2]=ta;c[ra+4>>2]=G;c[za>>2]=0;c[za+4>>2]=0;if((A|0)>0){A=A-1|0}else{break}}}c[qa>>2]=xa}ya=ya+1|0;}while((ya|0)<(k|0))}}while(0);P=pJb(ca(u<<1,c[f>>2]|0)|0)|0;c[a>>2]=P;do{if((P|0)==0){if(((ca(c[f>>2]|0,u)|0)&2147483647|0)==0){break}KIb(0,16,2545712,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;H=M;break a}}while(0);if(O){P=(l|0)/2|0;ya=P;xa=(P|0)<0|0?-1:0;P=l;L=(l|0)<0|0?-1:0;D=0;do{da=ca(D,zb)|0;B=c[t>>2]|0;sa=0;Ba=0;A=0;do{X=B+(sa+da<<3)|0;A=wrc(c[X>>2]|0,c[X+4>>2]|0,A,Ba)|0;Ba=G;sa=sa+1|0;}while((sa|0)<(zb|0));sa=wrc(ya,xa,A,Ba)|0;da=Crc(sa,G,P,L)|0;sa=G;if((da|0)==0&(sa|0)==0){KIb(0,24,2239584,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Bb=0;Cb=1}else{Bb=sa;Cb=da}da=c[f>>2]|0;if((da|0)>0){sa=ca(D,zb)|0;B=c[t>>2]|0;X=Cb>>>1|Bb<<31;N=Bb>>1|((Bb|0)<0|0?-1:0)<<31;W=xrc(0,0,X,N)|0;za=G;ra=c[a>>2]|0;ta=0;pa=0;wa=0;while(1){ua=B+(ta+sa<<3)|0;va=wrc(c[ua>>2]|0,c[ua+4>>2]|0,wa,pa)|0;ua=G;oa=0;na=(ua|0)>(oa|0)|(ua|0)==(oa|0)&va>>>0>0>>>0;oa=wrc(na?X:W,na?N:za,va,ua)|0;na=Crc(oa,G,Cb,Bb)|0;b[ra+((ca(da,D)|0)+ta<<1)>>1]=na;oa=na;na=Erc(oa,(oa|0)<0|0?-1:0,Cb,Bb)|0;oa=xrc(va,ua,na,G)|0;na=ta+1|0;if((na|0)<(da|0)){ta=na;pa=G;wa=oa}else{break}}}D=D+1|0;}while((D|0)<(k|0))}D=c[e>>2]|0;L=c[D+(Y<<2)>>2]|0;c[D+(k+2<<2)>>2]=L;c[D+(k+1<<2)>>2]=L;c[D+(k<<2)>>2]=L;L=c[f>>2]|0;if((L|0)<=0){Db=0;Eb=M;Fb=c[t>>2]|0;Gb=Fb;kJb(Gb);Hb=Eb;kJb(Hb);i=s;return Db|0}D=c[a>>2]|0;P=L<<1;xa=0;while(1){ya=(ca(L,Y)|0)+xa|0;O=b[D+(ya<<1)>>1]|0;b[D+(ya+(L*3|0)<<1)>>1]=O;b[D+(P+ya<<1)>>1]=O;b[D+(L+ya<<1)>>1]=O;O=xa+1|0;if((O|0)<(L|0)){xa=O}else{Db=0;Eb=M;break}}Fb=c[t>>2]|0;Gb=Fb;kJb(Gb);Hb=Eb;kJb(Hb);i=s;return Db|0}else{KIb(0,16,2545712,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;H=0}}while(0);KIb(0,16,2234528,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Db=-1;Eb=H;Fb=c[t>>2]|0;Gb=Fb;kJb(Gb);Hb=Eb;kJb(Hb);i=s;return Db|0}function Ixb(a,b,d,e,f,g,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=pJb(23984)|0;n=m;if((m|0)==0){o=0;return o|0}c[m>>2]=525328;SJb(m);c[m+2284>>2]=i;c[m+8>>2]=a;c[m+12>>2]=b;c[m+19608>>2]=e;c[m+16>>2]=f;c[m+56>>2]=d;c[m+52>>2]=g;if((l|0)!=0){h[m+104>>3]=+h[l>>3];h[m+112>>3]=+h[l+8>>3]}if((Gxb(n,j,k)|0)>=0){o=n;return o|0}Jxb(n);o=0;return o|0}function Jxb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;if((a|0)==0){return}b=a+2168|0;d=c[b>>2]|0;if((d|0)!=0){e=a+2184|0;a:do{if((c[e>>2]|0)>0){f=0;g=d;while(1){mJb(g+(f<<2)|0);h=f+1|0;if((h|0)>=(c[e>>2]|0)){break a}f=h;g=c[b>>2]|0}}}while(0);mJb(b)}b=a+2172|0;e=c[b>>2]|0;if((e|0)!=0){d=a+2188|0;b:do{if((c[d>>2]|0)>0){g=0;f=e;while(1){mJb(f+(g<<2)|0);h=g+1|0;if((h|0)>=(c[d>>2]|0)){break b}g=h;f=c[b>>2]|0}}}while(0);mJb(b);mJb(a+2176|0)}b=a+2180|0;d=c[b>>2]|0;if((d|0)!=0){e=a+2184|0;c:do{if((c[e>>2]|0)>0){f=0;g=d;while(1){mJb(g+(f<<2)|0);h=f+1|0;if((h|0)>=(c[e>>2]|0)){break c}f=h;g=c[b>>2]|0}}}while(0);mJb(b)}mJb(a+11200|0);mJb(a+11204|0);mJb(a+11208|0);mJb(a+11212|0);mJb(a+2220|0);mJb(a+2224|0);mJb(a+2212|0);mJb(a+2216|0);mJb(a+2236|0);mJb(a+2240|0);mJb(a+2228|0);mJb(a+2232|0);mJb(a+2288|0);mJb(a+2208|0);kJb(a);return}function Kxb(a,b){a=+a;b=+b;var d=0,e=0,f=0,g=0.0,j=0,k=0,l=0,m=0,n=0,o=0.0;d=i;i=i+8|0;e=d|0;f=~~(a*b+.5)|1;g=+(f-1|0)*.5;if(a<0.0|b<0.0){j=0;i=d;return j|0}if((f|0)<1|f>>>0>268435455>>>0){j=0;i=d;return j|0}k=hJb(8)|0;l=k;c[e>>2]=l;if((k|0)==0){j=0;i=d;return j|0}c[k+4>>2]=f;m=hJb(f<<3)|0;c[k>>2]=m;if((m|0)==0){mJb(e);n=c[e>>2]|0}else{n=l}if((n|0)==0){j=0;i=d;return j|0}if((f|0)>0){b=a*2.0;o=b*a;a=+S(b*3.141592653589793);l=c[n>>2]|0;e=0;do{b=+(e|0)-g;h[l+(e<<3)>>3]=+$(b*(-0.0-b)/o)/a;e=e+1|0;}while((e|0)<(f|0))}f=c[n+4>>2]|0;if((f|0)<=0){j=n;i=d;return j|0}e=c[n>>2]|0;l=0;a=0.0;do{a=a+ +h[e+(l<<3)>>3];l=l+1|0;}while((l|0)<(f|0));o=1.0/a;l=0;while(1){m=e+(l<<3)|0;h[m>>3]=o*+h[m>>3];m=l+1|0;if((m|0)<(f|0)){l=m}else{j=n;break}}i=d;return j|0}function Lxb(a,b){a=a|0;b=+b;var d=0,e=0,f=0;d=c[a+4>>2]|0;if((d|0)<=0){return}e=c[a>>2]|0;a=0;do{f=e+(a<<3)|0;h[f>>3]=+h[f>>3]*b;a=a+1|0;}while((a|0)<(d|0));return}function Mxb(a){a=a|0;var b=0;if((a|0)==0){return}b=a;mJb(b);c[a+4>>2]=0;kJb(b);return}function Nxb(a,b,d,e,f,g,i,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0;n=(m|0)==0?525312:m;if((a|0)!=0){do{if((c[a+8>>2]|0)==(b|0)){if((c[a+12>>2]|0)!=(d|0)){break}if((c[a+56>>2]|0)!=(e|0)){break}if((c[a+19608>>2]|0)!=(f|0)){break}if((c[a+16>>2]|0)!=(g|0)){break}if((c[a+52>>2]|0)!=(i|0)){break}if((c[a+2284>>2]|0)!=(j|0)){break}if(+h[a+104>>3]!=+h[n>>3]){break}if(+h[a+112>>3]!=+h[n+8>>3]){break}else{o=a}return o|0}}while(0);Jxb(a)}a=pJb(23984)|0;m=a;if((a|0)==0){o=0;return o|0}c[a>>2]=525328;SJb(a);c[a+8>>2]=b;c[a+12>>2]=d;c[a+56>>2]=e;c[a+19608>>2]=f;c[a+16>>2]=g;c[a+52>>2]=i;c[a+2284>>2]=j;h[a+104>>3]=+h[n>>3];h[a+112>>3]=+h[n+8>>3];if((Gxb(m,k,l)|0)>=0){o=m;return o|0}Jxb(m);o=0;return o|0}function Oxb(a){a=a|0;return 1242792+((a>>>0>7>>>0?5:a)<<4)|0}function Pxb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=b+56|0;f=mKb(c[e>>2]|0)|0;g=b+52|0;h=mKb(c[g>>2]|0)|0;KIb(b,24,2415e3,(b=i,i=i+16|0,c[b>>2]=f,c[b+8>>2]=h,b)|0);i=b;a:do{switch(c[g>>2]|0){case 22:case 19:{j=56;break};case 46:case 50:{j=98;break};case 10:{j=110;break};case 27:case 29:{h=c[e>>2]|0;f=qKb(h)|0;if((f|0)==0){KIb(0,0,2436360,(b=i,i=i+24|0,c[b>>2]=2349656,c[b+8>>2]=2287936,c[b+16>>2]=778,b)|0);i=b;Hd();return 0}if((h|0)==11){j=128;break a}if((a[f+7|0]|0)>-1){k=7}else{j=128}break};case 44:case 48:{j=114;break};case 2:{j=142;break};case 3:{j=70;break};case 41:case 42:{j=122;break};case 28:case 30:{k=7;break};case 67:case 68:{j=88;break};case 62:case 64:{j=106;break};case 23:case 20:{j=18;break};case 24:case 21:{j=90;break};default:{j=0}}}while(0);do{if((k|0)==7){g=c[e>>2]|0;f=qKb(g)|0;if((f|0)==0){KIb(0,0,2436360,(b=i,i=i+24|0,c[b>>2]=2349656,c[b+8>>2]=2287936,c[b+16>>2]=778,b)|0);i=b;Hd();return 0}if((g|0)==11){j=20;break}j=(a[f+7|0]|0)<0?20:58}}while(0);i=d;return j|0}function Qxb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=g+1|0;q=g;r=1;s=0;while(1){t=c[i>>2]|0;u=s+g|0;v=c[j>>2]|0;w=t+(ca(v,u)|0)|0;x=t+(ca(v,u+1|0)|0)|0;u=c[e>>2]|0;y=c[f>>2]|0;z=ca(y,s)|0;A=u+z|0;B=u+(z+y)|0;C=c[k>>2]|0;D=s>>1;E=ca(c[l>>2]|0,D)|0;F=C+E|0;G=c[m>>2]|0;H=ca(c[n>>2]|0,D)|0;D=G+H|0;I=c[o>>2]|0;J=I>>3;if((J|0)==0){K=D;L=F;M=B;N=A;O=x;P=w;Q=I}else{I=J*48|0;R=(ca(v,p)|0)+I|0;S=(ca(v,q)|0)+I|0;I=J<<3;v=(ca(y,r)|0)+I|0;y=z+I|0;I=J<<2;z=H+I|0;H=E+I|0;I=D;D=J;J=F;F=B;B=A;A=x;x=w;while(1){w=D-1|0;E=(d[I]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B]|0;X=a[E+U|0]|0;a[x+1|0]=X;a[x]=X;X=a[V+(U+W)|0]|0;a[x+3|0]=X;a[x+2|0]=X;X=a[T+U|0]|0;a[x+5|0]=X;a[x+4|0]=X;X=d[B+1|0]|0;U=a[E+X|0]|0;a[x+7|0]=U;a[x+6|0]=U;U=a[V+(X+W)|0]|0;a[x+9|0]=U;a[x+8|0]=U;U=a[T+X|0]|0;a[x+11|0]=U;a[x+10|0]=U;U=d[F]|0;X=a[E+U|0]|0;a[A+1|0]=X;a[A]=X;X=a[V+(U+W)|0]|0;a[A+3|0]=X;a[A+2|0]=X;X=a[T+U|0]|0;a[A+5|0]=X;a[A+4|0]=X;X=d[F+1|0]|0;U=a[E+X|0]|0;a[A+7|0]=U;a[A+6|0]=U;U=a[V+(X+W)|0]|0;a[A+9|0]=U;a[A+8|0]=U;U=a[T+X|0]|0;a[A+11|0]=U;a[A+10|0]=U;U=(d[I+1|0]|0)+128|0;X=c[b+4352+(U<<2)>>2]|0;T=(d[J+1|0]|0)+128|0;W=c[b+6400+(T<<2)>>2]|0;V=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(T<<2)>>2]|0;T=d[F+2|0]|0;E=a[U+T|0]|0;a[A+13|0]=E;a[A+12|0]=E;E=a[W+(T+V)|0]|0;a[A+15|0]=E;a[A+14|0]=E;E=a[X+T|0]|0;a[A+17|0]=E;a[A+16|0]=E;E=d[F+3|0]|0;T=a[U+E|0]|0;a[A+19|0]=T;a[A+18|0]=T;T=a[W+(E+V)|0]|0;a[A+21|0]=T;a[A+20|0]=T;T=a[X+E|0]|0;a[A+23|0]=T;a[A+22|0]=T;T=d[B+2|0]|0;E=a[U+T|0]|0;a[x+13|0]=E;a[x+12|0]=E;E=a[W+(T+V)|0]|0;a[x+15|0]=E;a[x+14|0]=E;E=a[X+T|0]|0;a[x+17|0]=E;a[x+16|0]=E;E=d[B+3|0]|0;T=a[U+E|0]|0;a[x+19|0]=T;a[x+18|0]=T;T=a[W+(E+V)|0]|0;a[x+21|0]=T;a[x+20|0]=T;T=a[X+E|0]|0;a[x+23|0]=T;a[x+22|0]=T;T=(d[I+2|0]|0)+128|0;E=c[b+4352+(T<<2)>>2]|0;X=(d[J+2|0]|0)+128|0;V=c[b+6400+(X<<2)>>2]|0;W=c[b+2304+(T<<2)>>2]|0;T=c[b+8448+(X<<2)>>2]|0;X=d[B+4|0]|0;U=a[T+X|0]|0;a[x+25|0]=U;a[x+24|0]=U;U=a[V+(X+W)|0]|0;a[x+27|0]=U;a[x+26|0]=U;U=a[E+X|0]|0;a[x+29|0]=U;a[x+28|0]=U;U=d[B+5|0]|0;X=a[T+U|0]|0;a[x+31|0]=X;a[x+30|0]=X;X=a[V+(U+W)|0]|0;a[x+33|0]=X;a[x+32|0]=X;X=a[E+U|0]|0;a[x+35|0]=X;a[x+34|0]=X;X=d[F+4|0]|0;U=a[T+X|0]|0;a[A+25|0]=U;a[A+24|0]=U;U=a[V+(X+W)|0]|0;a[A+27|0]=U;a[A+26|0]=U;U=a[E+X|0]|0;a[A+29|0]=U;a[A+28|0]=U;U=d[F+5|0]|0;X=a[T+U|0]|0;a[A+31|0]=X;a[A+30|0]=X;X=a[V+(U+W)|0]|0;a[A+33|0]=X;a[A+32|0]=X;X=a[E+U|0]|0;a[A+35|0]=X;a[A+34|0]=X;X=(d[I+3|0]|0)+128|0;U=c[b+4352+(X<<2)>>2]|0;E=(d[J+3|0]|0)+128|0;W=c[b+6400+(E<<2)>>2]|0;V=c[b+2304+(X<<2)>>2]|0;X=c[b+8448+(E<<2)>>2]|0;E=d[F+6|0]|0;T=a[X+E|0]|0;a[A+37|0]=T;a[A+36|0]=T;T=a[W+(E+V)|0]|0;a[A+39|0]=T;a[A+38|0]=T;T=a[U+E|0]|0;a[A+41|0]=T;a[A+40|0]=T;T=d[F+7|0]|0;E=a[X+T|0]|0;a[A+43|0]=E;a[A+42|0]=E;E=a[W+(T+V)|0]|0;a[A+45|0]=E;a[A+44|0]=E;E=a[U+T|0]|0;a[A+47|0]=E;a[A+46|0]=E;E=d[B+6|0]|0;T=a[X+E|0]|0;a[x+37|0]=T;a[x+36|0]=T;T=a[W+(E+V)|0]|0;a[x+39|0]=T;a[x+38|0]=T;T=a[U+E|0]|0;a[x+41|0]=T;a[x+40|0]=T;T=d[B+7|0]|0;E=a[X+T|0]|0;a[x+43|0]=E;a[x+42|0]=E;E=a[W+(T+V)|0]|0;a[x+45|0]=E;a[x+44|0]=E;E=a[U+T|0]|0;a[x+47|0]=E;a[x+46|0]=E;if((w|0)==0){break}else{I=I+4|0;D=w;J=J+4|0;F=F+8|0;B=B+8|0;A=A+48|0;x=x+48|0}}K=G+z|0;L=C+H|0;M=u+v|0;N=u+y|0;O=t+R|0;P=t+S|0;Q=c[o>>2]|0}if((Q&4|0)==0){Y=P;Z=O;_=N;$=M;aa=L;ba=K;da=Q}else{x=(d[K]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[L]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[N]|0;D=a[x+B|0]|0;a[P+1|0]=D;a[P]=D;D=a[F+(B+J)|0]|0;a[P+3|0]=D;a[P+2|0]=D;D=a[A+B|0]|0;a[P+5|0]=D;a[P+4|0]=D;D=d[N+1|0]|0;B=a[x+D|0]|0;a[P+7|0]=B;a[P+6|0]=B;B=a[F+(D+J)|0]|0;a[P+9|0]=B;a[P+8|0]=B;B=a[A+D|0]|0;a[P+11|0]=B;a[P+10|0]=B;B=d[M]|0;D=a[x+B|0]|0;a[O+1|0]=D;a[O]=D;D=a[F+(B+J)|0]|0;a[O+3|0]=D;a[O+2|0]=D;D=a[A+B|0]|0;a[O+5|0]=D;a[O+4|0]=D;D=d[M+1|0]|0;B=a[x+D|0]|0;a[O+7|0]=B;a[O+6|0]=B;B=a[F+(D+J)|0]|0;a[O+9|0]=B;a[O+8|0]=B;B=a[A+D|0]|0;a[O+11|0]=B;a[O+10|0]=B;B=(d[K+1|0]|0)+128|0;D=c[b+4352+(B<<2)>>2]|0;A=(d[L+1|0]|0)+128|0;J=c[b+6400+(A<<2)>>2]|0;F=c[b+2304+(B<<2)>>2]|0;B=c[b+8448+(A<<2)>>2]|0;A=d[M+2|0]|0;x=a[B+A|0]|0;a[O+13|0]=x;a[O+12|0]=x;x=a[J+(A+F)|0]|0;a[O+15|0]=x;a[O+14|0]=x;x=a[D+A|0]|0;a[O+17|0]=x;a[O+16|0]=x;x=d[M+3|0]|0;A=a[B+x|0]|0;a[O+19|0]=A;a[O+18|0]=A;A=a[J+(x+F)|0]|0;a[O+21|0]=A;a[O+20|0]=A;A=a[D+x|0]|0;a[O+23|0]=A;a[O+22|0]=A;A=d[N+2|0]|0;x=a[B+A|0]|0;a[P+13|0]=x;a[P+12|0]=x;x=a[J+(A+F)|0]|0;a[P+15|0]=x;a[P+14|0]=x;x=a[D+A|0]|0;a[P+17|0]=x;a[P+16|0]=x;x=d[N+3|0]|0;A=a[B+x|0]|0;a[P+19|0]=A;a[P+18|0]=A;A=a[J+(x+F)|0]|0;a[P+21|0]=A;a[P+20|0]=A;A=a[D+x|0]|0;a[P+23|0]=A;a[P+22|0]=A;Y=P+24|0;Z=O+24|0;_=N+4|0;$=M+4|0;aa=L+2|0;ba=K+2|0;da=c[o>>2]|0}if((da&2|0)!=0){A=(d[ba]|0)+128|0;x=c[b+4352+(A<<2)>>2]|0;D=(d[aa]|0)+128|0;F=c[b+6400+(D<<2)>>2]|0;J=c[b+2304+(A<<2)>>2]|0;A=c[b+8448+(D<<2)>>2]|0;D=d[_]|0;B=a[A+D|0]|0;a[Y+1|0]=B;a[Y]=B;B=a[F+(D+J)|0]|0;a[Y+3|0]=B;a[Y+2|0]=B;B=a[x+D|0]|0;a[Y+5|0]=B;a[Y+4|0]=B;B=d[_+1|0]|0;D=a[A+B|0]|0;a[Y+7|0]=D;a[Y+6|0]=D;D=a[F+(B+J)|0]|0;a[Y+9|0]=D;a[Y+8|0]=D;D=a[x+B|0]|0;a[Y+11|0]=D;a[Y+10|0]=D;D=d[$]|0;B=a[A+D|0]|0;a[Z+1|0]=B;a[Z]=B;B=a[F+(D+J)|0]|0;a[Z+3|0]=B;a[Z+2|0]=B;B=a[x+D|0]|0;a[Z+5|0]=B;a[Z+4|0]=B;B=d[$+1|0]|0;D=a[A+B|0]|0;a[Z+7|0]=D;a[Z+6|0]=D;D=a[F+(B+J)|0]|0;a[Z+9|0]=D;a[Z+8|0]=D;D=a[x+B|0]|0;a[Z+11|0]=D;a[Z+10|0]=D}D=s+2|0;if((D|0)>=(h|0)){break}p=p+2|0;q=q+2|0;r=r+2|0;s=D}return h|0}function Rxb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=g+1|0;q=g;r=1;s=0;while(1){t=c[i>>2]|0;u=s+g|0;v=c[j>>2]|0;w=t+(ca(v,u)|0)|0;x=t+(ca(v,u+1|0)|0)|0;u=c[e>>2]|0;y=c[f>>2]|0;z=ca(y,s)|0;A=u+z|0;B=u+(z+y)|0;C=c[k>>2]|0;D=s>>1;E=ca(c[l>>2]|0,D)|0;F=C+E|0;G=c[m>>2]|0;H=ca(c[n>>2]|0,D)|0;D=G+H|0;I=c[o>>2]|0;J=I>>3;if((J|0)==0){K=D;L=F;M=B;N=A;O=x;P=w;Q=I}else{I=J*48|0;R=(ca(v,p)|0)+I|0;S=(ca(v,q)|0)+I|0;I=J<<3;v=(ca(y,r)|0)+I|0;y=z+I|0;I=J<<2;z=H+I|0;H=E+I|0;I=D;D=J;J=F;F=B;B=A;A=x;x=w;while(1){w=D-1|0;E=(d[I]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B]|0;X=a[T+U|0]|0;a[x+1|0]=X;a[x]=X;X=a[V+(U+W)|0]|0;a[x+3|0]=X;a[x+2|0]=X;X=a[E+U|0]|0;a[x+5|0]=X;a[x+4|0]=X;X=d[B+1|0]|0;U=a[T+X|0]|0;a[x+7|0]=U;a[x+6|0]=U;U=a[V+(X+W)|0]|0;a[x+9|0]=U;a[x+8|0]=U;U=a[E+X|0]|0;a[x+11|0]=U;a[x+10|0]=U;U=d[F]|0;X=a[T+U|0]|0;a[A+1|0]=X;a[A]=X;X=a[V+(U+W)|0]|0;a[A+3|0]=X;a[A+2|0]=X;X=a[E+U|0]|0;a[A+5|0]=X;a[A+4|0]=X;X=d[F+1|0]|0;U=a[T+X|0]|0;a[A+7|0]=U;a[A+6|0]=U;U=a[V+(X+W)|0]|0;a[A+9|0]=U;a[A+8|0]=U;U=a[E+X|0]|0;a[A+11|0]=U;a[A+10|0]=U;U=(d[I+1|0]|0)+128|0;X=c[b+4352+(U<<2)>>2]|0;E=(d[J+1|0]|0)+128|0;W=c[b+6400+(E<<2)>>2]|0;V=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(E<<2)>>2]|0;E=d[F+2|0]|0;T=a[X+E|0]|0;a[A+13|0]=T;a[A+12|0]=T;T=a[W+(E+V)|0]|0;a[A+15|0]=T;a[A+14|0]=T;T=a[U+E|0]|0;a[A+17|0]=T;a[A+16|0]=T;T=d[F+3|0]|0;E=a[X+T|0]|0;a[A+19|0]=E;a[A+18|0]=E;E=a[W+(T+V)|0]|0;a[A+21|0]=E;a[A+20|0]=E;E=a[U+T|0]|0;a[A+23|0]=E;a[A+22|0]=E;E=d[B+2|0]|0;T=a[X+E|0]|0;a[x+13|0]=T;a[x+12|0]=T;T=a[W+(E+V)|0]|0;a[x+15|0]=T;a[x+14|0]=T;T=a[U+E|0]|0;a[x+17|0]=T;a[x+16|0]=T;T=d[B+3|0]|0;E=a[X+T|0]|0;a[x+19|0]=E;a[x+18|0]=E;E=a[W+(T+V)|0]|0;a[x+21|0]=E;a[x+20|0]=E;E=a[U+T|0]|0;a[x+23|0]=E;a[x+22|0]=E;E=(d[I+2|0]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J+2|0]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B+4|0]|0;X=a[T+U|0]|0;a[x+25|0]=X;a[x+24|0]=X;X=a[V+(U+W)|0]|0;a[x+27|0]=X;a[x+26|0]=X;X=a[E+U|0]|0;a[x+29|0]=X;a[x+28|0]=X;X=d[B+5|0]|0;U=a[T+X|0]|0;a[x+31|0]=U;a[x+30|0]=U;U=a[V+(X+W)|0]|0;a[x+33|0]=U;a[x+32|0]=U;U=a[E+X|0]|0;a[x+35|0]=U;a[x+34|0]=U;U=d[F+4|0]|0;X=a[T+U|0]|0;a[A+25|0]=X;a[A+24|0]=X;X=a[V+(U+W)|0]|0;a[A+27|0]=X;a[A+26|0]=X;X=a[E+U|0]|0;a[A+29|0]=X;a[A+28|0]=X;X=d[F+5|0]|0;U=a[T+X|0]|0;a[A+31|0]=U;a[A+30|0]=U;U=a[V+(X+W)|0]|0;a[A+33|0]=U;a[A+32|0]=U;U=a[E+X|0]|0;a[A+35|0]=U;a[A+34|0]=U;U=(d[I+3|0]|0)+128|0;X=c[b+4352+(U<<2)>>2]|0;E=(d[J+3|0]|0)+128|0;W=c[b+6400+(E<<2)>>2]|0;V=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(E<<2)>>2]|0;E=d[F+6|0]|0;T=a[X+E|0]|0;a[A+37|0]=T;a[A+36|0]=T;T=a[W+(E+V)|0]|0;a[A+39|0]=T;a[A+38|0]=T;T=a[U+E|0]|0;a[A+41|0]=T;a[A+40|0]=T;T=d[F+7|0]|0;E=a[X+T|0]|0;a[A+43|0]=E;a[A+42|0]=E;E=a[W+(T+V)|0]|0;a[A+45|0]=E;a[A+44|0]=E;E=a[U+T|0]|0;a[A+47|0]=E;a[A+46|0]=E;E=d[B+6|0]|0;T=a[X+E|0]|0;a[x+37|0]=T;a[x+36|0]=T;T=a[W+(E+V)|0]|0;a[x+39|0]=T;a[x+38|0]=T;T=a[U+E|0]|0;a[x+41|0]=T;a[x+40|0]=T;T=d[B+7|0]|0;E=a[X+T|0]|0;a[x+43|0]=E;a[x+42|0]=E;E=a[W+(T+V)|0]|0;a[x+45|0]=E;a[x+44|0]=E;E=a[U+T|0]|0;a[x+47|0]=E;a[x+46|0]=E;if((w|0)==0){break}else{I=I+4|0;D=w;J=J+4|0;F=F+8|0;B=B+8|0;A=A+48|0;x=x+48|0}}K=G+z|0;L=C+H|0;M=u+v|0;N=u+y|0;O=t+R|0;P=t+S|0;Q=c[o>>2]|0}if((Q&4|0)==0){Y=P;Z=O;_=N;$=M;aa=L;ba=K;da=Q}else{x=(d[K]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[L]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[N]|0;D=a[A+B|0]|0;a[P+1|0]=D;a[P]=D;D=a[F+(B+J)|0]|0;a[P+3|0]=D;a[P+2|0]=D;D=a[x+B|0]|0;a[P+5|0]=D;a[P+4|0]=D;D=d[N+1|0]|0;B=a[A+D|0]|0;a[P+7|0]=B;a[P+6|0]=B;B=a[F+(D+J)|0]|0;a[P+9|0]=B;a[P+8|0]=B;B=a[x+D|0]|0;a[P+11|0]=B;a[P+10|0]=B;B=d[M]|0;D=a[A+B|0]|0;a[O+1|0]=D;a[O]=D;D=a[F+(B+J)|0]|0;a[O+3|0]=D;a[O+2|0]=D;D=a[x+B|0]|0;a[O+5|0]=D;a[O+4|0]=D;D=d[M+1|0]|0;B=a[A+D|0]|0;a[O+7|0]=B;a[O+6|0]=B;B=a[F+(D+J)|0]|0;a[O+9|0]=B;a[O+8|0]=B;B=a[x+D|0]|0;a[O+11|0]=B;a[O+10|0]=B;B=(d[K+1|0]|0)+128|0;D=c[b+4352+(B<<2)>>2]|0;x=(d[L+1|0]|0)+128|0;J=c[b+6400+(x<<2)>>2]|0;F=c[b+2304+(B<<2)>>2]|0;B=c[b+8448+(x<<2)>>2]|0;x=d[M+2|0]|0;A=a[D+x|0]|0;a[O+13|0]=A;a[O+12|0]=A;A=a[J+(x+F)|0]|0;a[O+15|0]=A;a[O+14|0]=A;A=a[B+x|0]|0;a[O+17|0]=A;a[O+16|0]=A;A=d[M+3|0]|0;x=a[D+A|0]|0;a[O+19|0]=x;a[O+18|0]=x;x=a[J+(A+F)|0]|0;a[O+21|0]=x;a[O+20|0]=x;x=a[B+A|0]|0;a[O+23|0]=x;a[O+22|0]=x;x=d[N+2|0]|0;A=a[D+x|0]|0;a[P+13|0]=A;a[P+12|0]=A;A=a[J+(x+F)|0]|0;a[P+15|0]=A;a[P+14|0]=A;A=a[B+x|0]|0;a[P+17|0]=A;a[P+16|0]=A;A=d[N+3|0]|0;x=a[D+A|0]|0;a[P+19|0]=x;a[P+18|0]=x;x=a[J+(A+F)|0]|0;a[P+21|0]=x;a[P+20|0]=x;x=a[B+A|0]|0;a[P+23|0]=x;a[P+22|0]=x;Y=P+24|0;Z=O+24|0;_=N+4|0;$=M+4|0;aa=L+2|0;ba=K+2|0;da=c[o>>2]|0}if((da&2|0)!=0){x=(d[ba]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[aa]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[_]|0;D=a[A+B|0]|0;a[Y+1|0]=D;a[Y]=D;D=a[F+(B+J)|0]|0;a[Y+3|0]=D;a[Y+2|0]=D;D=a[x+B|0]|0;a[Y+5|0]=D;a[Y+4|0]=D;D=d[_+1|0]|0;B=a[A+D|0]|0;a[Y+7|0]=B;a[Y+6|0]=B;B=a[F+(D+J)|0]|0;a[Y+9|0]=B;a[Y+8|0]=B;B=a[x+D|0]|0;a[Y+11|0]=B;a[Y+10|0]=B;B=d[$]|0;D=a[A+B|0]|0;a[Z+1|0]=D;a[Z]=D;D=a[F+(B+J)|0]|0;a[Z+3|0]=D;a[Z+2|0]=D;D=a[x+B|0]|0;a[Z+5|0]=D;a[Z+4|0]=D;D=d[$+1|0]|0;B=a[A+D|0]|0;a[Z+7|0]=B;a[Z+6|0]=B;B=a[F+(D+J)|0]|0;a[Z+9|0]=B;a[Z+8|0]=B;B=a[x+D|0]|0;a[Z+11|0]=B;a[Z+10|0]=B}B=s+2|0;if((B|0)>=(h|0)){break}p=p+2|0;q=q+2|0;r=r+2|0;s=B}return h|0}function Sxb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;if((g|0)<=0){return g|0}j=e+4|0;k=e+8|0;l=a+19608|0;m=e+12|0;n=c[h>>2]|0;h=c[b>>2]|0;o=c[b+4>>2]|0;p=c[b+8>>2]|0;q=c[b+12>>2]|0;b=f+1|0;r=f;s=1;t=0;while(1){u=t+f|0;v=c[i>>2]|0;w=n+(ca(v,u)|0)|0;x=n+(ca(v,u+1|0)|0)|0;u=c[e>>2]|0;y=ca(u,t)|0;z=h+y|0;A=h+(y+u)|0;B=t>>1;C=ca(c[j>>2]|0,B)|0;D=o+C|0;E=ca(c[k>>2]|0,B)|0;B=p+E|0;F=c[l>>2]|0;G=F>>3;H=c[m>>2]|0;I=ca(H,t)|0;J=q+I|0;K=q+(I+H)|0;if((G|0)==0){L=B;M=J;N=K;O=D;P=A;Q=z;R=x;S=w;T=F}else{F=G<<5;U=n+((ca(v,b)|0)+F)|0;V=n+((ca(v,r)|0)+F)|0;F=G<<3;v=(ca(u,s)|0)+F|0;u=y+F|0;y=G<<2;W=E+y|0;E=C+y|0;y=(ca(H,s)|0)+F|0;H=I+F|0;F=B;B=J;J=K;K=G;G=D;D=A;A=z;z=x;x=w;while(1){w=K-1|0;I=(d[F]|0)+128|0;C=c[a+4352+(I<<2)>>2]|0;X=(d[G]|0)+128|0;Y=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(I<<2)>>2]|0)|0;I=c[a+8448+(X<<2)>>2]|0;X=d[A]|0;c[x>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[B]|0);X=d[A+1|0]|0;c[x+4>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[B+1|0]|0);X=d[D]|0;c[z>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[J]|0);X=d[D+1|0]|0;c[z+4>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[J+1|0]|0);X=(d[F+1|0]|0)+128|0;I=c[a+4352+(X<<2)>>2]|0;C=(d[G+1|0]|0)+128|0;Y=(c[a+6400+(C<<2)>>2]|0)+(c[a+2304+(X<<2)>>2]|0)|0;X=c[a+8448+(C<<2)>>2]|0;C=d[D+2|0]|0;c[z+8>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+(d[J+2|0]|0);C=d[D+3|0]|0;c[z+12>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+(d[J+3|0]|0);C=d[A+2|0]|0;c[x+8>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+(d[B+2|0]|0);C=d[A+3|0]|0;c[x+12>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+(d[B+3|0]|0);C=(d[F+2|0]|0)+128|0;X=c[a+4352+(C<<2)>>2]|0;I=(d[G+2|0]|0)+128|0;Y=(c[a+6400+(I<<2)>>2]|0)+(c[a+2304+(C<<2)>>2]|0)|0;C=c[a+8448+(I<<2)>>2]|0;I=d[A+4|0]|0;c[x+16>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+(d[B+4|0]|0);I=d[A+5|0]|0;c[x+20>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+(d[B+5|0]|0);I=d[D+4|0]|0;c[z+16>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+(d[J+4|0]|0);I=d[D+5|0]|0;c[z+20>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+(d[J+5|0]|0);I=(d[F+3|0]|0)+128|0;C=c[a+4352+(I<<2)>>2]|0;X=(d[G+3|0]|0)+128|0;Y=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(I<<2)>>2]|0)|0;I=c[a+8448+(X<<2)>>2]|0;X=d[D+6|0]|0;c[z+24>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[J+6|0]|0);X=d[D+7|0]|0;c[z+28>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[J+7|0]|0);X=d[A+6|0]|0;c[x+24>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[B+6|0]|0);X=d[A+7|0]|0;c[x+28>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+(d[B+7|0]|0);if((w|0)==0){break}else{F=F+4|0;B=B+8|0;J=J+8|0;K=w;G=G+4|0;D=D+8|0;A=A+8|0;z=z+32|0;x=x+32|0}}L=p+W|0;M=q+H|0;N=q+y|0;O=o+E|0;P=h+v|0;Q=h+u|0;R=U;S=V;T=c[l>>2]|0}if((T&4|0)==0){Z=S;_=R;$=Q;aa=P;ba=O;da=N;ea=M;fa=L;ga=T}else{x=(d[L]|0)+128|0;z=c[a+4352+(x<<2)>>2]|0;A=(d[O]|0)+128|0;D=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(A<<2)>>2]|0;A=d[Q]|0;c[S>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+(d[M]|0);A=d[Q+1|0]|0;c[S+4>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+(d[M+1|0]|0);A=d[P]|0;c[R>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+(d[N]|0);A=d[P+1|0]|0;c[R+4>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+(d[N+1|0]|0);A=(d[L+1|0]|0)+128|0;x=c[a+4352+(A<<2)>>2]|0;z=(d[O+1|0]|0)+128|0;D=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;A=c[a+8448+(z<<2)>>2]|0;z=d[P+2|0]|0;c[R+8>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+(d[N+2|0]|0);z=d[P+3|0]|0;c[R+12>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+(d[N+3|0]|0);z=d[Q+2|0]|0;c[S+8>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+(d[M+2|0]|0);z=d[Q+3|0]|0;c[S+12>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+(d[M+3|0]|0);Z=S+16|0;_=R+16|0;$=Q+4|0;aa=P+4|0;ba=O+2|0;da=N+4|0;ea=M+4|0;fa=L+2|0;ga=c[l>>2]|0}if((ga&2|0)!=0){z=(d[fa]|0)+128|0;A=c[a+4352+(z<<2)>>2]|0;x=(d[ba]|0)+128|0;D=(c[a+6400+(x<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;z=c[a+8448+(x<<2)>>2]|0;x=d[$]|0;c[Z>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+(d[ea]|0);x=d[$+1|0]|0;c[Z+4>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+(d[ea+1|0]|0);x=d[aa]|0;c[_>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+(d[da]|0);x=d[aa+1|0]|0;c[_+4>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+(d[da+1|0]|0)}x=t+2|0;if((x|0)>=(g|0)){break}b=b+2|0;r=r+2|0;s=s+2|0;t=x}return g|0}function Txb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;if((g|0)<=0){return g|0}j=e+4|0;k=e+8|0;l=a+19608|0;m=e+12|0;n=c[h>>2]|0;h=c[b>>2]|0;o=c[b+4>>2]|0;p=c[b+8>>2]|0;q=c[b+12>>2]|0;b=f+1|0;r=f;s=1;t=0;while(1){u=t+f|0;v=c[i>>2]|0;w=n+(ca(v,u)|0)|0;x=n+(ca(v,u+1|0)|0)|0;u=c[e>>2]|0;y=ca(u,t)|0;z=h+y|0;A=h+(y+u)|0;B=t>>1;C=ca(c[j>>2]|0,B)|0;D=o+C|0;E=ca(c[k>>2]|0,B)|0;B=p+E|0;F=c[l>>2]|0;G=F>>3;H=c[m>>2]|0;I=ca(H,t)|0;J=q+I|0;K=q+(I+H)|0;if((G|0)==0){L=B;M=J;N=K;O=D;P=A;Q=z;R=x;S=w;T=F}else{F=G<<5;U=n+((ca(v,b)|0)+F)|0;V=n+((ca(v,r)|0)+F)|0;F=G<<3;v=(ca(u,s)|0)+F|0;u=y+F|0;y=G<<2;W=E+y|0;E=C+y|0;y=(ca(H,s)|0)+F|0;H=I+F|0;F=B;B=J;J=K;K=G;G=D;D=A;A=z;z=x;x=w;while(1){w=K-1|0;I=(d[F]|0)+128|0;C=c[a+4352+(I<<2)>>2]|0;X=(d[G]|0)+128|0;Y=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(I<<2)>>2]|0)|0;I=c[a+8448+(X<<2)>>2]|0;X=d[A]|0;c[x>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[B]|0)<<24);X=d[A+1|0]|0;c[x+4>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[B+1|0]|0)<<24);X=d[D]|0;c[z>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[J]|0)<<24);X=d[D+1|0]|0;c[z+4>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[J+1|0]|0)<<24);X=(d[F+1|0]|0)+128|0;I=c[a+4352+(X<<2)>>2]|0;C=(d[G+1|0]|0)+128|0;Y=(c[a+6400+(C<<2)>>2]|0)+(c[a+2304+(X<<2)>>2]|0)|0;X=c[a+8448+(C<<2)>>2]|0;C=d[D+2|0]|0;c[z+8>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+((d[J+2|0]|0)<<24);C=d[D+3|0]|0;c[z+12>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+((d[J+3|0]|0)<<24);C=d[A+2|0]|0;c[x+8>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+((d[B+2|0]|0)<<24);C=d[A+3|0]|0;c[x+12>>2]=(c[Y+(C<<2)>>2]|0)+(c[I+(C<<2)>>2]|0)+(c[X+(C<<2)>>2]|0)+((d[B+3|0]|0)<<24);C=(d[F+2|0]|0)+128|0;X=c[a+4352+(C<<2)>>2]|0;I=(d[G+2|0]|0)+128|0;Y=(c[a+6400+(I<<2)>>2]|0)+(c[a+2304+(C<<2)>>2]|0)|0;C=c[a+8448+(I<<2)>>2]|0;I=d[A+4|0]|0;c[x+16>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+((d[B+4|0]|0)<<24);I=d[A+5|0]|0;c[x+20>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+((d[B+5|0]|0)<<24);I=d[D+4|0]|0;c[z+16>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+((d[J+4|0]|0)<<24);I=d[D+5|0]|0;c[z+20>>2]=(c[Y+(I<<2)>>2]|0)+(c[X+(I<<2)>>2]|0)+(c[C+(I<<2)>>2]|0)+((d[J+5|0]|0)<<24);I=(d[F+3|0]|0)+128|0;C=c[a+4352+(I<<2)>>2]|0;X=(d[G+3|0]|0)+128|0;Y=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(I<<2)>>2]|0)|0;I=c[a+8448+(X<<2)>>2]|0;X=d[D+6|0]|0;c[z+24>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[J+6|0]|0)<<24);X=d[D+7|0]|0;c[z+28>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[J+7|0]|0)<<24);X=d[A+6|0]|0;c[x+24>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[B+6|0]|0)<<24);X=d[A+7|0]|0;c[x+28>>2]=(c[Y+(X<<2)>>2]|0)+(c[C+(X<<2)>>2]|0)+(c[I+(X<<2)>>2]|0)+((d[B+7|0]|0)<<24);if((w|0)==0){break}else{F=F+4|0;B=B+8|0;J=J+8|0;K=w;G=G+4|0;D=D+8|0;A=A+8|0;z=z+32|0;x=x+32|0}}L=p+W|0;M=q+H|0;N=q+y|0;O=o+E|0;P=h+v|0;Q=h+u|0;R=U;S=V;T=c[l>>2]|0}if((T&4|0)==0){Z=S;_=R;$=Q;aa=P;ba=O;da=N;ea=M;fa=L;ga=T}else{x=(d[L]|0)+128|0;z=c[a+4352+(x<<2)>>2]|0;A=(d[O]|0)+128|0;D=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(A<<2)>>2]|0;A=d[Q]|0;c[S>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+((d[M]|0)<<24);A=d[Q+1|0]|0;c[S+4>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+((d[M+1|0]|0)<<24);A=d[P]|0;c[R>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+((d[N]|0)<<24);A=d[P+1|0]|0;c[R+4>>2]=(c[D+(A<<2)>>2]|0)+(c[z+(A<<2)>>2]|0)+(c[x+(A<<2)>>2]|0)+((d[N+1|0]|0)<<24);A=(d[L+1|0]|0)+128|0;x=c[a+4352+(A<<2)>>2]|0;z=(d[O+1|0]|0)+128|0;D=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;A=c[a+8448+(z<<2)>>2]|0;z=d[P+2|0]|0;c[R+8>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+((d[N+2|0]|0)<<24);z=d[P+3|0]|0;c[R+12>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+((d[N+3|0]|0)<<24);z=d[Q+2|0]|0;c[S+8>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+((d[M+2|0]|0)<<24);z=d[Q+3|0]|0;c[S+12>>2]=(c[D+(z<<2)>>2]|0)+(c[x+(z<<2)>>2]|0)+(c[A+(z<<2)>>2]|0)+((d[M+3|0]|0)<<24);Z=S+16|0;_=R+16|0;$=Q+4|0;aa=P+4|0;ba=O+2|0;da=N+4|0;ea=M+4|0;fa=L+2|0;ga=c[l>>2]|0}if((ga&2|0)!=0){z=(d[fa]|0)+128|0;A=c[a+4352+(z<<2)>>2]|0;x=(d[ba]|0)+128|0;D=(c[a+6400+(x<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;z=c[a+8448+(x<<2)>>2]|0;x=d[$]|0;c[Z>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+((d[ea]|0)<<24);x=d[$+1|0]|0;c[Z+4>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+((d[ea+1|0]|0)<<24);x=d[aa]|0;c[_>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+((d[da]|0)<<24);x=d[aa+1|0]|0;c[_+4>>2]=(c[D+(x<<2)>>2]|0)+(c[A+(x<<2)>>2]|0)+(c[z+(x<<2)>>2]|0)+((d[da+1|0]|0)<<24)}x=t+2|0;if((x|0)>=(g|0)){break}b=b+2|0;r=r+2|0;s=s+2|0;t=x}return g|0}function Uxb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;if((c[a+56>>2]|0)==4){j=e+4|0;c[j>>2]=c[j>>2]<<1;j=e+8|0;c[j>>2]=c[j>>2]<<1}if((g|0)<=0){return g|0}j=e+4|0;k=e+8|0;l=a+19608|0;m=c[h>>2]|0;h=c[b>>2]|0;n=c[b+4>>2]|0;o=c[b+8>>2]|0;b=f+1|0;p=f;q=1;r=0;while(1){s=r+f|0;t=c[i>>2]|0;u=m+(ca(t,s)|0)|0;v=m+(ca(t,s+1|0)|0)|0;s=c[e>>2]|0;w=ca(s,r)|0;x=h+w|0;y=h+(w+s)|0;z=r>>1;A=ca(c[j>>2]|0,z)|0;B=n+A|0;C=ca(c[k>>2]|0,z)|0;z=o+C|0;D=c[l>>2]|0;E=D>>3;if((E|0)==0){F=z;G=B;H=y;I=x;J=v;K=u;L=D}else{D=E<<5;M=m+((ca(t,b)|0)+D)|0;N=m+((ca(t,p)|0)+D)|0;D=E<<3;t=(ca(s,q)|0)+D|0;s=w+D|0;D=E<<2;w=C+D|0;C=A+D|0;D=z;z=E;E=B;B=y;y=x;x=v;v=u;while(1){u=z-1|0;A=(d[D]|0)+128|0;O=c[a+4352+(A<<2)>>2]|0;P=(d[E]|0)+128|0;Q=(c[a+6400+(P<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;A=c[a+8448+(P<<2)>>2]|0;P=d[y]|0;c[v>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[y+1|0]|0;c[v+4>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[B]|0;c[x>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[B+1|0]|0;c[x+4>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=(d[D+1|0]|0)+128|0;A=c[a+4352+(P<<2)>>2]|0;O=(d[E+1|0]|0)+128|0;Q=(c[a+6400+(O<<2)>>2]|0)+(c[a+2304+(P<<2)>>2]|0)|0;P=c[a+8448+(O<<2)>>2]|0;O=d[B+2|0]|0;c[x+8>>2]=(c[Q+(O<<2)>>2]|0)+(c[A+(O<<2)>>2]|0)+(c[P+(O<<2)>>2]|0);O=d[B+3|0]|0;c[x+12>>2]=(c[Q+(O<<2)>>2]|0)+(c[A+(O<<2)>>2]|0)+(c[P+(O<<2)>>2]|0);O=d[y+2|0]|0;c[v+8>>2]=(c[Q+(O<<2)>>2]|0)+(c[A+(O<<2)>>2]|0)+(c[P+(O<<2)>>2]|0);O=d[y+3|0]|0;c[v+12>>2]=(c[Q+(O<<2)>>2]|0)+(c[A+(O<<2)>>2]|0)+(c[P+(O<<2)>>2]|0);O=(d[D+2|0]|0)+128|0;P=c[a+4352+(O<<2)>>2]|0;A=(d[E+2|0]|0)+128|0;Q=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(O<<2)>>2]|0)|0;O=c[a+8448+(A<<2)>>2]|0;A=d[y+4|0]|0;c[v+16>>2]=(c[Q+(A<<2)>>2]|0)+(c[P+(A<<2)>>2]|0)+(c[O+(A<<2)>>2]|0);A=d[y+5|0]|0;c[v+20>>2]=(c[Q+(A<<2)>>2]|0)+(c[P+(A<<2)>>2]|0)+(c[O+(A<<2)>>2]|0);A=d[B+4|0]|0;c[x+16>>2]=(c[Q+(A<<2)>>2]|0)+(c[P+(A<<2)>>2]|0)+(c[O+(A<<2)>>2]|0);A=d[B+5|0]|0;c[x+20>>2]=(c[Q+(A<<2)>>2]|0)+(c[P+(A<<2)>>2]|0)+(c[O+(A<<2)>>2]|0);A=(d[D+3|0]|0)+128|0;O=c[a+4352+(A<<2)>>2]|0;P=(d[E+3|0]|0)+128|0;Q=(c[a+6400+(P<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;A=c[a+8448+(P<<2)>>2]|0;P=d[B+6|0]|0;c[x+24>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[B+7|0]|0;c[x+28>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[y+6|0]|0;c[v+24>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);P=d[y+7|0]|0;c[v+28>>2]=(c[Q+(P<<2)>>2]|0)+(c[O+(P<<2)>>2]|0)+(c[A+(P<<2)>>2]|0);if((u|0)==0){break}else{D=D+4|0;z=u;E=E+4|0;B=B+8|0;y=y+8|0;x=x+32|0;v=v+32|0}}F=o+w|0;G=n+C|0;H=h+t|0;I=h+s|0;J=M;K=N;L=c[l>>2]|0}if((L&4|0)==0){R=K;S=J;T=I;U=H;V=G;W=F;X=L}else{v=(d[F]|0)+128|0;x=c[a+4352+(v<<2)>>2]|0;y=(d[G]|0)+128|0;B=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(v<<2)>>2]|0)|0;v=c[a+8448+(y<<2)>>2]|0;y=d[I]|0;c[K>>2]=(c[B+(y<<2)>>2]|0)+(c[x+(y<<2)>>2]|0)+(c[v+(y<<2)>>2]|0);y=d[I+1|0]|0;c[K+4>>2]=(c[B+(y<<2)>>2]|0)+(c[x+(y<<2)>>2]|0)+(c[v+(y<<2)>>2]|0);y=d[H]|0;c[J>>2]=(c[B+(y<<2)>>2]|0)+(c[x+(y<<2)>>2]|0)+(c[v+(y<<2)>>2]|0);y=d[H+1|0]|0;c[J+4>>2]=(c[B+(y<<2)>>2]|0)+(c[x+(y<<2)>>2]|0)+(c[v+(y<<2)>>2]|0);y=(d[F+1|0]|0)+128|0;v=c[a+4352+(y<<2)>>2]|0;x=(d[G+1|0]|0)+128|0;B=(c[a+6400+(x<<2)>>2]|0)+(c[a+2304+(y<<2)>>2]|0)|0;y=c[a+8448+(x<<2)>>2]|0;x=d[H+2|0]|0;c[J+8>>2]=(c[B+(x<<2)>>2]|0)+(c[v+(x<<2)>>2]|0)+(c[y+(x<<2)>>2]|0);x=d[H+3|0]|0;c[J+12>>2]=(c[B+(x<<2)>>2]|0)+(c[v+(x<<2)>>2]|0)+(c[y+(x<<2)>>2]|0);x=d[I+2|0]|0;c[K+8>>2]=(c[B+(x<<2)>>2]|0)+(c[v+(x<<2)>>2]|0)+(c[y+(x<<2)>>2]|0);x=d[I+3|0]|0;c[K+12>>2]=(c[B+(x<<2)>>2]|0)+(c[v+(x<<2)>>2]|0)+(c[y+(x<<2)>>2]|0);R=K+16|0;S=J+16|0;T=I+4|0;U=H+4|0;V=G+2|0;W=F+2|0;X=c[l>>2]|0}if((X&2|0)!=0){x=(d[W]|0)+128|0;y=c[a+4352+(x<<2)>>2]|0;v=(d[V]|0)+128|0;B=(c[a+6400+(v<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(v<<2)>>2]|0;v=d[T]|0;c[R>>2]=(c[B+(v<<2)>>2]|0)+(c[y+(v<<2)>>2]|0)+(c[x+(v<<2)>>2]|0);v=d[T+1|0]|0;c[R+4>>2]=(c[B+(v<<2)>>2]|0)+(c[y+(v<<2)>>2]|0)+(c[x+(v<<2)>>2]|0);v=d[U]|0;c[S>>2]=(c[B+(v<<2)>>2]|0)+(c[y+(v<<2)>>2]|0)+(c[x+(v<<2)>>2]|0);v=d[U+1|0]|0;c[S+4>>2]=(c[B+(v<<2)>>2]|0)+(c[y+(v<<2)>>2]|0)+(c[x+(v<<2)>>2]|0)}v=r+2|0;if((v|0)>=(g|0)){break}b=b+2|0;p=p+2|0;q=q+2|0;r=v}return g|0}function Vxb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=g+1|0;q=g;r=1;s=0;while(1){t=c[i>>2]|0;u=s+g|0;v=c[j>>2]|0;w=t+(ca(v,u)|0)|0;x=t+(ca(v,u+1|0)|0)|0;u=c[e>>2]|0;y=c[f>>2]|0;z=ca(y,s)|0;A=u+z|0;B=u+(z+y)|0;C=c[k>>2]|0;D=s>>1;E=ca(c[l>>2]|0,D)|0;F=C+E|0;G=c[m>>2]|0;H=ca(c[n>>2]|0,D)|0;D=G+H|0;I=c[o>>2]|0;J=I>>3;if((J|0)==0){K=D;L=F;M=B;N=A;O=x;P=w;Q=I}else{I=J*24|0;R=(ca(v,p)|0)+I|0;S=(ca(v,q)|0)+I|0;I=J<<3;v=(ca(y,r)|0)+I|0;y=z+I|0;I=J<<2;z=H+I|0;H=E+I|0;I=D;D=J;J=F;F=B;B=A;A=x;x=w;while(1){w=D-1|0;E=(d[I]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B]|0;a[x]=a[T+U|0]|0;a[x+1|0]=a[V+(U+W)|0]|0;a[x+2|0]=a[E+U|0]|0;U=d[B+1|0]|0;a[x+3|0]=a[T+U|0]|0;a[x+4|0]=a[V+(U+W)|0]|0;a[x+5|0]=a[E+U|0]|0;U=d[F]|0;a[A]=a[T+U|0]|0;a[A+1|0]=a[V+(U+W)|0]|0;a[A+2|0]=a[E+U|0]|0;U=d[F+1|0]|0;a[A+3|0]=a[T+U|0]|0;a[A+4|0]=a[V+(U+W)|0]|0;a[A+5|0]=a[E+U|0]|0;U=(d[I+1|0]|0)+128|0;E=c[b+4352+(U<<2)>>2]|0;W=(d[J+1|0]|0)+128|0;V=c[b+6400+(W<<2)>>2]|0;T=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(W<<2)>>2]|0;W=d[F+2|0]|0;a[A+6|0]=a[E+W|0]|0;a[A+7|0]=a[V+(W+T)|0]|0;a[A+8|0]=a[U+W|0]|0;W=d[F+3|0]|0;a[A+9|0]=a[E+W|0]|0;a[A+10|0]=a[V+(W+T)|0]|0;a[A+11|0]=a[U+W|0]|0;W=d[B+2|0]|0;a[x+6|0]=a[E+W|0]|0;a[x+7|0]=a[V+(W+T)|0]|0;a[x+8|0]=a[U+W|0]|0;W=d[B+3|0]|0;a[x+9|0]=a[E+W|0]|0;a[x+10|0]=a[V+(W+T)|0]|0;a[x+11|0]=a[U+W|0]|0;W=(d[I+2|0]|0)+128|0;U=c[b+4352+(W<<2)>>2]|0;T=(d[J+2|0]|0)+128|0;V=c[b+6400+(T<<2)>>2]|0;E=c[b+2304+(W<<2)>>2]|0;W=c[b+8448+(T<<2)>>2]|0;T=d[B+4|0]|0;a[x+12|0]=a[U+T|0]|0;a[x+13|0]=a[V+(T+E)|0]|0;a[x+14|0]=a[W+T|0]|0;T=d[B+5|0]|0;a[x+15|0]=a[U+T|0]|0;a[x+16|0]=a[V+(T+E)|0]|0;a[x+17|0]=a[W+T|0]|0;T=d[F+4|0]|0;a[A+12|0]=a[U+T|0]|0;a[A+13|0]=a[V+(T+E)|0]|0;a[A+14|0]=a[W+T|0]|0;T=d[F+5|0]|0;a[A+15|0]=a[U+T|0]|0;a[A+16|0]=a[V+(T+E)|0]|0;a[A+17|0]=a[W+T|0]|0;T=(d[I+3|0]|0)+128|0;W=c[b+4352+(T<<2)>>2]|0;E=(d[J+3|0]|0)+128|0;V=c[b+6400+(E<<2)>>2]|0;U=c[b+2304+(T<<2)>>2]|0;T=c[b+8448+(E<<2)>>2]|0;E=d[F+6|0]|0;a[A+18|0]=a[W+E|0]|0;a[A+19|0]=a[V+(E+U)|0]|0;a[A+20|0]=a[T+E|0]|0;E=d[F+7|0]|0;a[A+21|0]=a[W+E|0]|0;a[A+22|0]=a[V+(E+U)|0]|0;a[A+23|0]=a[T+E|0]|0;E=d[B+6|0]|0;a[x+18|0]=a[W+E|0]|0;a[x+19|0]=a[V+(E+U)|0]|0;a[x+20|0]=a[T+E|0]|0;E=d[B+7|0]|0;a[x+21|0]=a[W+E|0]|0;a[x+22|0]=a[V+(E+U)|0]|0;a[x+23|0]=a[T+E|0]|0;if((w|0)==0){break}else{I=I+4|0;D=w;J=J+4|0;F=F+8|0;B=B+8|0;A=A+24|0;x=x+24|0}}K=G+z|0;L=C+H|0;M=u+v|0;N=u+y|0;O=t+R|0;P=t+S|0;Q=c[o>>2]|0}if((Q&4|0)==0){X=P;Y=O;Z=N;_=M;$=L;aa=K;ba=Q}else{x=(d[K]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[L]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[N]|0;a[P]=a[A+B|0]|0;a[P+1|0]=a[F+(B+J)|0]|0;a[P+2|0]=a[x+B|0]|0;B=d[N+1|0]|0;a[P+3|0]=a[A+B|0]|0;a[P+4|0]=a[F+(B+J)|0]|0;a[P+5|0]=a[x+B|0]|0;B=d[M]|0;a[O]=a[A+B|0]|0;a[O+1|0]=a[F+(B+J)|0]|0;a[O+2|0]=a[x+B|0]|0;B=d[M+1|0]|0;a[O+3|0]=a[A+B|0]|0;a[O+4|0]=a[F+(B+J)|0]|0;a[O+5|0]=a[x+B|0]|0;B=(d[K+1|0]|0)+128|0;x=c[b+4352+(B<<2)>>2]|0;J=(d[L+1|0]|0)+128|0;F=c[b+6400+(J<<2)>>2]|0;A=c[b+2304+(B<<2)>>2]|0;B=c[b+8448+(J<<2)>>2]|0;J=d[M+2|0]|0;a[O+6|0]=a[x+J|0]|0;a[O+7|0]=a[F+(J+A)|0]|0;a[O+8|0]=a[B+J|0]|0;J=d[M+3|0]|0;a[O+9|0]=a[x+J|0]|0;a[O+10|0]=a[F+(J+A)|0]|0;a[O+11|0]=a[B+J|0]|0;J=d[N+2|0]|0;a[P+6|0]=a[x+J|0]|0;a[P+7|0]=a[F+(J+A)|0]|0;a[P+8|0]=a[B+J|0]|0;J=d[N+3|0]|0;a[P+9|0]=a[x+J|0]|0;a[P+10|0]=a[F+(J+A)|0]|0;a[P+11|0]=a[B+J|0]|0;X=P+12|0;Y=O+12|0;Z=N+4|0;_=M+4|0;$=L+2|0;aa=K+2|0;ba=c[o>>2]|0}if((ba&2|0)!=0){J=(d[aa]|0)+128|0;B=c[b+4352+(J<<2)>>2]|0;A=(d[$]|0)+128|0;F=c[b+6400+(A<<2)>>2]|0;x=c[b+2304+(J<<2)>>2]|0;J=c[b+8448+(A<<2)>>2]|0;A=d[Z]|0;a[X]=a[B+A|0]|0;a[X+1|0]=a[F+(A+x)|0]|0;a[X+2|0]=a[J+A|0]|0;A=d[Z+1|0]|0;a[X+3|0]=a[B+A|0]|0;a[X+4|0]=a[F+(A+x)|0]|0;a[X+5|0]=a[J+A|0]|0;A=d[_]|0;a[Y]=a[B+A|0]|0;a[Y+1|0]=a[F+(A+x)|0]|0;a[Y+2|0]=a[J+A|0]|0;A=d[_+1|0]|0;a[Y+3|0]=a[B+A|0]|0;a[Y+4|0]=a[F+(A+x)|0]|0;a[Y+5|0]=a[J+A|0]|0}A=s+2|0;if((A|0)>=(h|0)){break}p=p+2|0;q=q+2|0;r=r+2|0;s=A}return h|0}function Wxb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=g+1|0;q=g;r=1;s=0;while(1){t=c[i>>2]|0;u=s+g|0;v=c[j>>2]|0;w=t+(ca(v,u)|0)|0;x=t+(ca(v,u+1|0)|0)|0;u=c[e>>2]|0;y=c[f>>2]|0;z=ca(y,s)|0;A=u+z|0;B=u+(z+y)|0;C=c[k>>2]|0;D=s>>1;E=ca(c[l>>2]|0,D)|0;F=C+E|0;G=c[m>>2]|0;H=ca(c[n>>2]|0,D)|0;D=G+H|0;I=c[o>>2]|0;J=I>>3;if((J|0)==0){K=D;L=F;M=B;N=A;O=x;P=w;Q=I}else{I=J*24|0;R=(ca(v,p)|0)+I|0;S=(ca(v,q)|0)+I|0;I=J<<3;v=(ca(y,r)|0)+I|0;y=z+I|0;I=J<<2;z=H+I|0;H=E+I|0;I=D;D=J;J=F;F=B;B=A;A=x;x=w;while(1){w=D-1|0;E=(d[I]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[B]|0;a[x]=a[E+U|0]|0;a[x+1|0]=a[V+(U+W)|0]|0;a[x+2|0]=a[T+U|0]|0;U=d[B+1|0]|0;a[x+3|0]=a[E+U|0]|0;a[x+4|0]=a[V+(U+W)|0]|0;a[x+5|0]=a[T+U|0]|0;U=d[F]|0;a[A]=a[E+U|0]|0;a[A+1|0]=a[V+(U+W)|0]|0;a[A+2|0]=a[T+U|0]|0;U=d[F+1|0]|0;a[A+3|0]=a[E+U|0]|0;a[A+4|0]=a[V+(U+W)|0]|0;a[A+5|0]=a[T+U|0]|0;U=(d[I+1|0]|0)+128|0;T=c[b+4352+(U<<2)>>2]|0;W=(d[J+1|0]|0)+128|0;V=c[b+6400+(W<<2)>>2]|0;E=c[b+2304+(U<<2)>>2]|0;U=c[b+8448+(W<<2)>>2]|0;W=d[F+2|0]|0;a[A+6|0]=a[U+W|0]|0;a[A+7|0]=a[V+(W+E)|0]|0;a[A+8|0]=a[T+W|0]|0;W=d[F+3|0]|0;a[A+9|0]=a[U+W|0]|0;a[A+10|0]=a[V+(W+E)|0]|0;a[A+11|0]=a[T+W|0]|0;W=d[B+2|0]|0;a[x+6|0]=a[U+W|0]|0;a[x+7|0]=a[V+(W+E)|0]|0;a[x+8|0]=a[T+W|0]|0;W=d[B+3|0]|0;a[x+9|0]=a[U+W|0]|0;a[x+10|0]=a[V+(W+E)|0]|0;a[x+11|0]=a[T+W|0]|0;W=(d[I+2|0]|0)+128|0;T=c[b+4352+(W<<2)>>2]|0;E=(d[J+2|0]|0)+128|0;V=c[b+6400+(E<<2)>>2]|0;U=c[b+2304+(W<<2)>>2]|0;W=c[b+8448+(E<<2)>>2]|0;E=d[B+4|0]|0;a[x+12|0]=a[W+E|0]|0;a[x+13|0]=a[V+(E+U)|0]|0;a[x+14|0]=a[T+E|0]|0;E=d[B+5|0]|0;a[x+15|0]=a[W+E|0]|0;a[x+16|0]=a[V+(E+U)|0]|0;a[x+17|0]=a[T+E|0]|0;E=d[F+4|0]|0;a[A+12|0]=a[W+E|0]|0;a[A+13|0]=a[V+(E+U)|0]|0;a[A+14|0]=a[T+E|0]|0;E=d[F+5|0]|0;a[A+15|0]=a[W+E|0]|0;a[A+16|0]=a[V+(E+U)|0]|0;a[A+17|0]=a[T+E|0]|0;E=(d[I+3|0]|0)+128|0;T=c[b+4352+(E<<2)>>2]|0;U=(d[J+3|0]|0)+128|0;V=c[b+6400+(U<<2)>>2]|0;W=c[b+2304+(E<<2)>>2]|0;E=c[b+8448+(U<<2)>>2]|0;U=d[F+6|0]|0;a[A+18|0]=a[E+U|0]|0;a[A+19|0]=a[V+(U+W)|0]|0;a[A+20|0]=a[T+U|0]|0;U=d[F+7|0]|0;a[A+21|0]=a[E+U|0]|0;a[A+22|0]=a[V+(U+W)|0]|0;a[A+23|0]=a[T+U|0]|0;U=d[B+6|0]|0;a[x+18|0]=a[E+U|0]|0;a[x+19|0]=a[V+(U+W)|0]|0;a[x+20|0]=a[T+U|0]|0;U=d[B+7|0]|0;a[x+21|0]=a[E+U|0]|0;a[x+22|0]=a[V+(U+W)|0]|0;a[x+23|0]=a[T+U|0]|0;if((w|0)==0){break}else{I=I+4|0;D=w;J=J+4|0;F=F+8|0;B=B+8|0;A=A+24|0;x=x+24|0}}K=G+z|0;L=C+H|0;M=u+v|0;N=u+y|0;O=t+R|0;P=t+S|0;Q=c[o>>2]|0}if((Q&4|0)==0){X=P;Y=O;Z=N;_=M;$=L;aa=K;ba=Q}else{x=(d[K]|0)+128|0;A=c[b+4352+(x<<2)>>2]|0;B=(d[L]|0)+128|0;F=c[b+6400+(B<<2)>>2]|0;J=c[b+2304+(x<<2)>>2]|0;x=c[b+8448+(B<<2)>>2]|0;B=d[N]|0;a[P]=a[x+B|0]|0;a[P+1|0]=a[F+(B+J)|0]|0;a[P+2|0]=a[A+B|0]|0;B=d[N+1|0]|0;a[P+3|0]=a[x+B|0]|0;a[P+4|0]=a[F+(B+J)|0]|0;a[P+5|0]=a[A+B|0]|0;B=d[M]|0;a[O]=a[x+B|0]|0;a[O+1|0]=a[F+(B+J)|0]|0;a[O+2|0]=a[A+B|0]|0;B=d[M+1|0]|0;a[O+3|0]=a[x+B|0]|0;a[O+4|0]=a[F+(B+J)|0]|0;a[O+5|0]=a[A+B|0]|0;B=(d[K+1|0]|0)+128|0;A=c[b+4352+(B<<2)>>2]|0;J=(d[L+1|0]|0)+128|0;F=c[b+6400+(J<<2)>>2]|0;x=c[b+2304+(B<<2)>>2]|0;B=c[b+8448+(J<<2)>>2]|0;J=d[M+2|0]|0;a[O+6|0]=a[B+J|0]|0;a[O+7|0]=a[F+(J+x)|0]|0;a[O+8|0]=a[A+J|0]|0;J=d[M+3|0]|0;a[O+9|0]=a[B+J|0]|0;a[O+10|0]=a[F+(J+x)|0]|0;a[O+11|0]=a[A+J|0]|0;J=d[N+2|0]|0;a[P+6|0]=a[B+J|0]|0;a[P+7|0]=a[F+(J+x)|0]|0;a[P+8|0]=a[A+J|0]|0;J=d[N+3|0]|0;a[P+9|0]=a[B+J|0]|0;a[P+10|0]=a[F+(J+x)|0]|0;a[P+11|0]=a[A+J|0]|0;X=P+12|0;Y=O+12|0;Z=N+4|0;_=M+4|0;$=L+2|0;aa=K+2|0;ba=c[o>>2]|0}if((ba&2|0)!=0){J=(d[aa]|0)+128|0;A=c[b+4352+(J<<2)>>2]|0;x=(d[$]|0)+128|0;F=c[b+6400+(x<<2)>>2]|0;B=c[b+2304+(J<<2)>>2]|0;J=c[b+8448+(x<<2)>>2]|0;x=d[Z]|0;a[X]=a[J+x|0]|0;a[X+1|0]=a[F+(x+B)|0]|0;a[X+2|0]=a[A+x|0]|0;x=d[Z+1|0]|0;a[X+3|0]=a[J+x|0]|0;a[X+4|0]=a[F+(x+B)|0]|0;a[X+5|0]=a[A+x|0]|0;x=d[_]|0;a[Y]=a[J+x|0]|0;a[Y+1|0]=a[F+(x+B)|0]|0;a[Y+2|0]=a[A+x|0]|0;x=d[_+1|0]|0;a[Y+3|0]=a[J+x|0]|0;a[Y+4|0]=a[F+(x+B)|0]|0;a[Y+5|0]=a[A+x|0]|0}x=s+2|0;if((x|0)>=(h|0)){break}p=p+2|0;q=q+2|0;r=r+2|0;s=x}return h|0}function Xxb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;if((c[a+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=d[1401352]|0;p=d[1401376]|0;q=d[1401360]|0;r=d[1401353]|0;s=d[1401377]|0;t=d[1401361]|0;u=d[1401384]|0;v=d[1401368]|0;w=d[1401385]|0;x=d[1401369]|0;y=d[1401362]|0;z=d[1401386]|0;A=d[1401370]|0;B=d[1401363]|0;C=d[1401387]|0;D=d[1401371]|0;E=d[1401354]|0;F=d[1401378]|0;G=d[1401355]|0;H=d[1401379]|0;I=d[1401356]|0;J=d[1401380]|0;K=d[1401364]|0;L=d[1401357]|0;M=d[1401381]|0;N=d[1401365]|0;O=d[1401388]|0;P=d[1401372]|0;Q=d[1401389]|0;R=d[1401373]|0;S=d[1401366]|0;T=d[1401390]|0;U=d[1401374]|0;V=d[1401367]|0;W=d[1401391]|0;X=d[1401375]|0;Y=d[1401358]|0;Z=d[1401382]|0;_=d[1401359]|0;$=d[1401383]|0;aa=c[i>>2]|0;i=c[j>>2]|0;j=c[e>>2]|0;e=c[f>>2]|0;f=c[a+19608>>2]|0;ba=0;do{da=ba+g|0;ea=ca(e,ba)|0;fa=ba>>1;ga=f>>3;if((ga|0)!=0){ha=ca(i,da+1|0)|0;ia=ca(i,da)|0;da=ca(c[n>>2]|0,fa)|0;ja=ca(c[l>>2]|0,fa)|0;fa=(c[m>>2]|0)+da|0;da=ga;ga=(c[k>>2]|0)+ja|0;ja=j+(ea+e)|0;ka=j+ea|0;ea=aa+ha|0;ha=aa+ia|0;while(1){ia=da-1|0;la=(d[fa]|0)+128|0;ma=c[a+4352+(la<<2)>>2]|0;na=(d[ga]|0)+128|0;oa=(c[a+6400+(na<<2)>>2]|0)+(c[a+2304+(la<<2)>>2]|0)|0;la=c[a+8448+(na<<2)>>2]|0;na=d[ka]|0;b[ha>>1]=((b[oa+(p+na<<1)>>1]|0)+(b[ma+(o+na<<1)>>1]|0)&65535)+(b[la+(q+na<<1)>>1]|0);na=d[ka+1|0]|0;b[ha+2>>1]=((b[oa+(s+na<<1)>>1]|0)+(b[ma+(r+na<<1)>>1]|0)&65535)+(b[la+(t+na<<1)>>1]|0);na=d[ja]|0;b[ea>>1]=((b[oa+(u+na<<1)>>1]|0)+(b[ma+(q+na<<1)>>1]|0)&65535)+(b[la+(v+na<<1)>>1]|0);na=d[ja+1|0]|0;b[ea+2>>1]=((b[oa+(w+na<<1)>>1]|0)+(b[ma+(t+na<<1)>>1]|0)&65535)+(b[la+(x+na<<1)>>1]|0);na=(d[fa+1|0]|0)+128|0;la=c[a+4352+(na<<2)>>2]|0;ma=(d[ga+1|0]|0)+128|0;oa=(c[a+6400+(ma<<2)>>2]|0)+(c[a+2304+(na<<2)>>2]|0)|0;na=c[a+8448+(ma<<2)>>2]|0;ma=d[ja+2|0]|0;b[ea+4>>1]=((b[oa+(z+ma<<1)>>1]|0)+(b[la+(y+ma<<1)>>1]|0)&65535)+(b[na+(A+ma<<1)>>1]|0);ma=d[ja+3|0]|0;b[ea+6>>1]=((b[oa+(C+ma<<1)>>1]|0)+(b[la+(B+ma<<1)>>1]|0)&65535)+(b[na+(D+ma<<1)>>1]|0);ma=d[ka+2|0]|0;b[ha+4>>1]=((b[oa+(F+ma<<1)>>1]|0)+(b[la+(E+ma<<1)>>1]|0)&65535)+(b[na+(y+ma<<1)>>1]|0);ma=d[ka+3|0]|0;b[ha+6>>1]=((b[oa+(H+ma<<1)>>1]|0)+(b[la+(G+ma<<1)>>1]|0)&65535)+(b[na+(B+ma<<1)>>1]|0);ma=(d[fa+2|0]|0)+128|0;na=c[a+4352+(ma<<2)>>2]|0;la=(d[ga+2|0]|0)+128|0;oa=(c[a+6400+(la<<2)>>2]|0)+(c[a+2304+(ma<<2)>>2]|0)|0;ma=c[a+8448+(la<<2)>>2]|0;la=d[ka+4|0]|0;b[ha+8>>1]=((b[oa+(J+la<<1)>>1]|0)+(b[na+(I+la<<1)>>1]|0)&65535)+(b[ma+(K+la<<1)>>1]|0);la=d[ka+5|0]|0;b[ha+10>>1]=((b[oa+(M+la<<1)>>1]|0)+(b[na+(L+la<<1)>>1]|0)&65535)+(b[ma+(N+la<<1)>>1]|0);la=d[ja+4|0]|0;b[ea+8>>1]=((b[oa+(O+la<<1)>>1]|0)+(b[na+(K+la<<1)>>1]|0)&65535)+(b[ma+(P+la<<1)>>1]|0);la=d[ja+5|0]|0;b[ea+10>>1]=((b[oa+(Q+la<<1)>>1]|0)+(b[na+(N+la<<1)>>1]|0)&65535)+(b[ma+(R+la<<1)>>1]|0);la=(d[fa+3|0]|0)+128|0;ma=c[a+4352+(la<<2)>>2]|0;na=(d[ga+3|0]|0)+128|0;oa=(c[a+6400+(na<<2)>>2]|0)+(c[a+2304+(la<<2)>>2]|0)|0;la=c[a+8448+(na<<2)>>2]|0;na=d[ja+6|0]|0;b[ea+12>>1]=((b[oa+(T+na<<1)>>1]|0)+(b[ma+(S+na<<1)>>1]|0)&65535)+(b[la+(U+na<<1)>>1]|0);na=d[ja+7|0]|0;b[ea+14>>1]=((b[oa+(W+na<<1)>>1]|0)+(b[ma+(V+na<<1)>>1]|0)&65535)+(b[la+(X+na<<1)>>1]|0);na=d[ka+6|0]|0;b[ha+12>>1]=((b[oa+(Z+na<<1)>>1]|0)+(b[ma+(Y+na<<1)>>1]|0)&65535)+(b[la+(S+na<<1)>>1]|0);na=d[ka+7|0]|0;b[ha+14>>1]=((b[oa+($+na<<1)>>1]|0)+(b[ma+(_+na<<1)>>1]|0)&65535)+(b[la+(V+na<<1)>>1]|0);if((ia|0)==0){break}else{fa=fa+4|0;da=ia;ga=ga+4|0;ja=ja+8|0;ka=ka+8|0;ea=ea+16|0;ha=ha+16|0}}}ba=ba+2|0;}while((ba|0)<(h|0));return h|0}function Yxb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;if((c[a+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=d[1401352]|0;p=d[1401353]|0;q=d[1401360]|0;r=d[1401361]|0;s=d[1401368]|0;t=d[1401369]|0;u=d[1401362]|0;v=d[1401363]|0;w=d[1401370]|0;x=d[1401371]|0;y=d[1401354]|0;z=d[1401355]|0;A=d[1401356]|0;B=d[1401357]|0;C=d[1401364]|0;D=d[1401365]|0;E=d[1401372]|0;F=d[1401373]|0;G=d[1401366]|0;H=d[1401367]|0;I=d[1401374]|0;J=d[1401375]|0;K=d[1401358]|0;L=d[1401359]|0;M=c[i>>2]|0;i=c[j>>2]|0;j=c[e>>2]|0;e=c[f>>2]|0;f=c[a+19608>>2]|0;N=0;do{O=N+g|0;P=ca(e,N)|0;Q=N>>1;R=f>>3;if((R|0)!=0){S=ca(i,O+1|0)|0;T=ca(i,O)|0;O=ca(c[n>>2]|0,Q)|0;U=ca(c[l>>2]|0,Q)|0;Q=(c[k>>2]|0)+U|0;U=(c[m>>2]|0)+O|0;O=R;R=j+(P+e)|0;V=j+P|0;P=M+S|0;S=M+T|0;while(1){T=O-1|0;W=(d[U]|0)+128|0;X=c[a+4352+(W<<2)>>2]|0;Y=(d[Q]|0)+128|0;Z=(c[a+6400+(Y<<2)>>2]|0)+(c[a+2304+(W<<2)>>2]|0)|0;W=c[a+8448+(Y<<2)>>2]|0;Y=d[V]|0;b[S>>1]=((b[Z+(p+Y<<1)>>1]|0)+(b[X+(o+Y<<1)>>1]|0)&65535)+(b[W+(q+Y<<1)>>1]|0);Y=d[V+1|0]|0;b[S+2>>1]=((b[Z+(o+Y<<1)>>1]|0)+(b[X+(p+Y<<1)>>1]|0)&65535)+(b[W+(r+Y<<1)>>1]|0);Y=d[R]|0;b[P>>1]=((b[Z+(r+Y<<1)>>1]|0)+(b[X+(q+Y<<1)>>1]|0)&65535)+(b[W+(s+Y<<1)>>1]|0);Y=d[R+1|0]|0;b[P+2>>1]=((b[Z+(q+Y<<1)>>1]|0)+(b[X+(r+Y<<1)>>1]|0)&65535)+(b[W+(t+Y<<1)>>1]|0);Y=(d[U+1|0]|0)+128|0;W=c[a+4352+(Y<<2)>>2]|0;X=(d[Q+1|0]|0)+128|0;Z=(c[a+6400+(X<<2)>>2]|0)+(c[a+2304+(Y<<2)>>2]|0)|0;Y=c[a+8448+(X<<2)>>2]|0;X=d[R+2|0]|0;b[P+4>>1]=((b[Z+(v+X<<1)>>1]|0)+(b[W+(u+X<<1)>>1]|0)&65535)+(b[Y+(w+X<<1)>>1]|0);X=d[R+3|0]|0;b[P+6>>1]=((b[Z+(u+X<<1)>>1]|0)+(b[W+(v+X<<1)>>1]|0)&65535)+(b[Y+(x+X<<1)>>1]|0);X=d[V+2|0]|0;b[S+4>>1]=((b[Z+(z+X<<1)>>1]|0)+(b[W+(y+X<<1)>>1]|0)&65535)+(b[Y+(u+X<<1)>>1]|0);X=d[V+3|0]|0;b[S+6>>1]=((b[Z+(y+X<<1)>>1]|0)+(b[W+(z+X<<1)>>1]|0)&65535)+(b[Y+(v+X<<1)>>1]|0);X=(d[U+2|0]|0)+128|0;Y=c[a+4352+(X<<2)>>2]|0;W=(d[Q+2|0]|0)+128|0;Z=(c[a+6400+(W<<2)>>2]|0)+(c[a+2304+(X<<2)>>2]|0)|0;X=c[a+8448+(W<<2)>>2]|0;W=d[V+4|0]|0;b[S+8>>1]=((b[Z+(B+W<<1)>>1]|0)+(b[Y+(A+W<<1)>>1]|0)&65535)+(b[X+(C+W<<1)>>1]|0);W=d[V+5|0]|0;b[S+10>>1]=((b[Z+(A+W<<1)>>1]|0)+(b[Y+(B+W<<1)>>1]|0)&65535)+(b[X+(D+W<<1)>>1]|0);W=d[R+4|0]|0;b[P+8>>1]=((b[Z+(D+W<<1)>>1]|0)+(b[Y+(C+W<<1)>>1]|0)&65535)+(b[X+(E+W<<1)>>1]|0);W=d[R+5|0]|0;b[P+10>>1]=((b[Z+(C+W<<1)>>1]|0)+(b[Y+(D+W<<1)>>1]|0)&65535)+(b[X+(F+W<<1)>>1]|0);W=(d[U+3|0]|0)+128|0;X=c[a+4352+(W<<2)>>2]|0;Y=(d[Q+3|0]|0)+128|0;Z=(c[a+6400+(Y<<2)>>2]|0)+(c[a+2304+(W<<2)>>2]|0)|0;W=c[a+8448+(Y<<2)>>2]|0;Y=d[R+6|0]|0;b[P+12>>1]=((b[Z+(H+Y<<1)>>1]|0)+(b[X+(G+Y<<1)>>1]|0)&65535)+(b[W+(I+Y<<1)>>1]|0);Y=d[R+7|0]|0;b[P+14>>1]=((b[Z+(G+Y<<1)>>1]|0)+(b[X+(H+Y<<1)>>1]|0)&65535)+(b[W+(J+Y<<1)>>1]|0);Y=d[V+6|0]|0;b[S+12>>1]=((b[Z+(L+Y<<1)>>1]|0)+(b[X+(K+Y<<1)>>1]|0)&65535)+(b[W+(G+Y<<1)>>1]|0);Y=d[V+7|0]|0;b[S+14>>1]=((b[Z+(K+Y<<1)>>1]|0)+(b[X+(L+Y<<1)>>1]|0)&65535)+(b[W+(H+Y<<1)>>1]|0);if((T|0)==0){break}else{Q=Q+4|0;U=U+4|0;O=T;R=R+8|0;V=V+8|0;P=P+16|0;S=S+16|0}}}N=N+2|0;}while((N|0)<(h|0));return h|0}function Zxb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;if((c[a+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=c[i>>2]|0;i=c[j>>2]|0;j=c[e>>2]|0;e=c[f>>2]|0;f=c[a+19608>>2]|0;p=0;do{q=p+g|0;r=ca(e,p)|0;s=p>>1;t=f>>3;if((t|0)!=0){u=ca(i,q+1|0)|0;v=ca(i,q)|0;q=ca(c[n>>2]|0,s)|0;w=ca(c[l>>2]|0,s)|0;s=p&2;x=d[1401312+(s<<3)|0]|0;y=d[1401313+(s<<3)|0]|0;z=d[1401320+(s<<3)|0]|0;A=d[1401321+(s<<3)|0]|0;B=d[1401322+(s<<3)|0]|0;C=d[1401323+(s<<3)|0]|0;D=d[1401314+(s<<3)|0]|0;E=d[1401315+(s<<3)|0]|0;F=d[1401316+(s<<3)|0]|0;G=d[1401317+(s<<3)|0]|0;H=d[1401324+(s<<3)|0]|0;I=d[1401325+(s<<3)|0]|0;J=d[1401326+(s<<3)|0]|0;K=d[1401327+(s<<3)|0]|0;L=d[1401318+(s<<3)|0]|0;M=d[1401319+(s<<3)|0]|0;s=j+(r+e)|0;N=(c[k>>2]|0)+w|0;w=(c[m>>2]|0)+q|0;q=t;t=j+r|0;r=o+u|0;u=o+v|0;while(1){v=q-1|0;O=(d[w]|0)+128|0;P=c[a+4352+(O<<2)>>2]|0;Q=(d[N]|0)+128|0;R=(c[a+6400+(Q<<2)>>2]|0)+(c[a+2304+(O<<2)>>2]|0)|0;O=c[a+8448+(Q<<2)>>2]|0;Q=x+(d[t]|0)|0;b[u>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=y+(d[t+1|0]|0)|0;b[u+2>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=z+(d[s]|0)|0;b[r>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=A+(d[s+1|0]|0)|0;b[r+2>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=(d[w+1|0]|0)+128|0;O=c[a+4352+(Q<<2)>>2]|0;P=(d[N+1|0]|0)+128|0;R=(c[a+6400+(P<<2)>>2]|0)+(c[a+2304+(Q<<2)>>2]|0)|0;Q=c[a+8448+(P<<2)>>2]|0;P=B+(d[s+2|0]|0)|0;b[r+4>>1]=((b[R+(P<<1)>>1]|0)+(b[O+(P<<1)>>1]|0)&65535)+(b[Q+(P<<1)>>1]|0);P=C+(d[s+3|0]|0)|0;b[r+6>>1]=((b[R+(P<<1)>>1]|0)+(b[O+(P<<1)>>1]|0)&65535)+(b[Q+(P<<1)>>1]|0);P=D+(d[t+2|0]|0)|0;b[u+4>>1]=((b[R+(P<<1)>>1]|0)+(b[O+(P<<1)>>1]|0)&65535)+(b[Q+(P<<1)>>1]|0);P=E+(d[t+3|0]|0)|0;b[u+6>>1]=((b[R+(P<<1)>>1]|0)+(b[O+(P<<1)>>1]|0)&65535)+(b[Q+(P<<1)>>1]|0);P=(d[w+2|0]|0)+128|0;Q=c[a+4352+(P<<2)>>2]|0;O=(d[N+2|0]|0)+128|0;R=(c[a+6400+(O<<2)>>2]|0)+(c[a+2304+(P<<2)>>2]|0)|0;P=c[a+8448+(O<<2)>>2]|0;O=F+(d[t+4|0]|0)|0;b[u+8>>1]=((b[R+(O<<1)>>1]|0)+(b[Q+(O<<1)>>1]|0)&65535)+(b[P+(O<<1)>>1]|0);O=G+(d[t+5|0]|0)|0;b[u+10>>1]=((b[R+(O<<1)>>1]|0)+(b[Q+(O<<1)>>1]|0)&65535)+(b[P+(O<<1)>>1]|0);O=H+(d[s+4|0]|0)|0;b[r+8>>1]=((b[R+(O<<1)>>1]|0)+(b[Q+(O<<1)>>1]|0)&65535)+(b[P+(O<<1)>>1]|0);O=I+(d[s+5|0]|0)|0;b[r+10>>1]=((b[R+(O<<1)>>1]|0)+(b[Q+(O<<1)>>1]|0)&65535)+(b[P+(O<<1)>>1]|0);O=(d[w+3|0]|0)+128|0;P=c[a+4352+(O<<2)>>2]|0;Q=(d[N+3|0]|0)+128|0;R=(c[a+6400+(Q<<2)>>2]|0)+(c[a+2304+(O<<2)>>2]|0)|0;O=c[a+8448+(Q<<2)>>2]|0;Q=J+(d[s+6|0]|0)|0;b[r+12>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=K+(d[s+7|0]|0)|0;b[r+14>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=L+(d[t+6|0]|0)|0;b[u+12>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);Q=M+(d[t+7|0]|0)|0;b[u+14>>1]=((b[R+(Q<<1)>>1]|0)+(b[P+(Q<<1)>>1]|0)&65535)+(b[O+(Q<<1)>>1]|0);if((v|0)==0){break}else{s=s+8|0;N=N+4|0;w=w+4|0;q=v;t=t+8|0;r=r+16|0;u=u+16|0}}}p=p+2|0;}while((p|0)<(h|0));return h|0}function _xb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=0;do{q=c[i>>2]|0;r=p+g|0;s=c[j>>2]|0;t=c[e>>2]|0;u=c[f>>2]|0;v=ca(u,p)|0;w=p>>1;x=c[o>>2]>>3;if((x|0)!=0){y=ca(c[n>>2]|0,w)|0;z=ca(c[l>>2]|0,w)|0;w=q+(ca(s,r+1|0)|0)|0;A=q+(ca(s,r)|0)|0;r=p&6;s=d[1401096+(r<<3)|0]|0;q=d[1401024+(r<<3)|0]|0;B=d[1401097+(r<<3)|0]|0;C=d[1401025+(r<<3)|0]|0;D=d[1401104+(r<<3)|0]|0;E=d[1401032+(r<<3)|0]|0;F=d[1401105+(r<<3)|0]|0;G=d[1401033+(r<<3)|0]|0;H=d[1401106+(r<<3)|0]|0;I=d[1401034+(r<<3)|0]|0;J=d[1401107+(r<<3)|0]|0;K=d[1401035+(r<<3)|0]|0;L=d[1401098+(r<<3)|0]|0;M=d[1401026+(r<<3)|0]|0;N=d[1401099+(r<<3)|0]|0;O=d[1401027+(r<<3)|0]|0;P=d[1401100+(r<<3)|0]|0;Q=d[1401028+(r<<3)|0]|0;R=d[1401101+(r<<3)|0]|0;S=d[1401029+(r<<3)|0]|0;T=d[1401108+(r<<3)|0]|0;U=d[1401036+(r<<3)|0]|0;V=d[1401109+(r<<3)|0]|0;W=d[1401037+(r<<3)|0]|0;X=d[1401110+(r<<3)|0]|0;Y=d[1401038+(r<<3)|0]|0;Z=d[1401111+(r<<3)|0]|0;_=d[1401039+(r<<3)|0]|0;$=d[1401102+(r<<3)|0]|0;aa=d[1401030+(r<<3)|0]|0;ba=d[1401103+(r<<3)|0]|0;da=d[1401031+(r<<3)|0]|0;r=(c[k>>2]|0)+z|0;z=(c[m>>2]|0)+y|0;y=x;x=t+(v+u)|0;u=t+v|0;v=w;w=A;while(1){A=y-1|0;t=(d[z]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[r]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[u]|0;ia=s+fa|0;a[w]=((a[ga+(ia+ha)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+(q+fa)|0]|0);fa=d[u+1|0]|0;ia=B+fa|0;a[w+1|0]=((a[ga+(ia+ha)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+(C+fa)|0]|0);fa=d[x]|0;ia=D+fa|0;a[v]=((a[ga+(ia+ha)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+(E+fa)|0]|0);fa=d[x+1|0]|0;ia=F+fa|0;a[v+1|0]=((a[ga+(ia+ha)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+(G+fa)|0]|0);fa=(d[z+1|0]|0)+128|0;t=c[b+4352+(fa<<2)>>2]|0;ia=(d[r+1|0]|0)+128|0;ea=c[b+6400+(ia<<2)>>2]|0;ha=c[b+2304+(fa<<2)>>2]|0;fa=c[b+8448+(ia<<2)>>2]|0;ia=d[x+2|0]|0;ga=H+ia|0;a[v+2|0]=((a[ea+(ga+ha)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+(I+ia)|0]|0);ia=d[x+3|0]|0;ga=J+ia|0;a[v+3|0]=((a[ea+(ga+ha)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+(K+ia)|0]|0);ia=d[u+2|0]|0;ga=L+ia|0;a[w+2|0]=((a[ea+(ga+ha)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+(M+ia)|0]|0);ia=d[u+3|0]|0;ga=N+ia|0;a[w+3|0]=((a[ea+(ga+ha)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+(O+ia)|0]|0);ia=(d[z+2|0]|0)+128|0;fa=c[b+4352+(ia<<2)>>2]|0;ga=(d[r+2|0]|0)+128|0;t=c[b+6400+(ga<<2)>>2]|0;ha=c[b+2304+(ia<<2)>>2]|0;ia=c[b+8448+(ga<<2)>>2]|0;ga=d[u+4|0]|0;ea=P+ga|0;a[w+4|0]=((a[t+(ea+ha)|0]|0)+(a[fa+ea|0]|0)&255)+(a[ia+(Q+ga)|0]|0);ga=d[u+5|0]|0;ea=R+ga|0;a[w+5|0]=((a[t+(ea+ha)|0]|0)+(a[fa+ea|0]|0)&255)+(a[ia+(S+ga)|0]|0);ga=d[x+4|0]|0;ea=T+ga|0;a[v+4|0]=((a[t+(ea+ha)|0]|0)+(a[fa+ea|0]|0)&255)+(a[ia+(U+ga)|0]|0);ga=d[x+5|0]|0;ea=V+ga|0;a[v+5|0]=((a[t+(ea+ha)|0]|0)+(a[fa+ea|0]|0)&255)+(a[ia+(W+ga)|0]|0);ga=(d[z+3|0]|0)+128|0;ia=c[b+4352+(ga<<2)>>2]|0;ea=(d[r+3|0]|0)+128|0;fa=c[b+6400+(ea<<2)>>2]|0;ha=c[b+2304+(ga<<2)>>2]|0;ga=c[b+8448+(ea<<2)>>2]|0;ea=d[x+6|0]|0;t=X+ea|0;a[v+6|0]=((a[fa+(t+ha)|0]|0)+(a[ia+t|0]|0)&255)+(a[ga+(Y+ea)|0]|0);ea=d[x+7|0]|0;t=Z+ea|0;a[v+7|0]=((a[fa+(t+ha)|0]|0)+(a[ia+t|0]|0)&255)+(a[ga+(_+ea)|0]|0);ea=d[u+6|0]|0;t=$+ea|0;a[w+6|0]=((a[fa+(t+ha)|0]|0)+(a[ia+t|0]|0)&255)+(a[ga+(aa+ea)|0]|0);ea=d[u+7|0]|0;t=ba+ea|0;a[w+7|0]=((a[fa+(t+ha)|0]|0)+(a[ia+t|0]|0)&255)+(a[ga+(da+ea)|0]|0);if((A|0)==0){break}else{r=r+4|0;z=z+4|0;y=A;x=x+8|0;u=u+8|0;v=v+8|0;w=w+8|0}}}p=p+2|0;}while((p|0)<(h|0));return h|0}function $xb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=0;do{q=c[i>>2]|0;r=p+g|0;s=c[j>>2]|0;t=c[e>>2]|0;u=c[f>>2]|0;v=ca(u,p)|0;w=p>>1;x=c[o>>2]>>3;if((x|0)!=0){y=ca(c[n>>2]|0,w)|0;z=ca(c[l>>2]|0,w)|0;w=q+(ca(s,r+1|0)|0)|0;A=q+(ca(s,r)|0)|0;r=p&6;s=d[1401168+(r<<3)|0]|0;q=d[1401024+(r<<3)|0]|0;B=d[1401169+(r<<3)|0]|0;C=d[1401025+(r<<3)|0]|0;D=d[1401176+(r<<3)|0]|0;E=d[1401032+(r<<3)|0]|0;F=d[1401177+(r<<3)|0]|0;G=d[1401033+(r<<3)|0]|0;H=d[1401178+(r<<3)|0]|0;I=d[1401034+(r<<3)|0]|0;J=d[1401179+(r<<3)|0]|0;K=d[1401035+(r<<3)|0]|0;L=d[1401170+(r<<3)|0]|0;M=d[1401026+(r<<3)|0]|0;N=d[1401171+(r<<3)|0]|0;O=d[1401027+(r<<3)|0]|0;P=d[1401172+(r<<3)|0]|0;Q=d[1401028+(r<<3)|0]|0;R=d[1401173+(r<<3)|0]|0;S=d[1401029+(r<<3)|0]|0;T=d[1401180+(r<<3)|0]|0;U=d[1401036+(r<<3)|0]|0;V=d[1401181+(r<<3)|0]|0;W=d[1401037+(r<<3)|0]|0;X=d[1401182+(r<<3)|0]|0;Y=d[1401038+(r<<3)|0]|0;Z=d[1401183+(r<<3)|0]|0;_=d[1401039+(r<<3)|0]|0;$=d[1401174+(r<<3)|0]|0;aa=d[1401030+(r<<3)|0]|0;ba=d[1401175+(r<<3)|0]|0;da=d[1401031+(r<<3)|0]|0;r=(c[m>>2]|0)+y|0;y=x;x=(c[k>>2]|0)+z|0;z=t+(v+u)|0;u=t+v|0;v=w;w=A;while(1){A=y-1|0;t=(d[r]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[x]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[u]|0;ia=s+fa|0;ja=d[u+1|0]|0;ka=B+ja|0;a[w]=(((a[ga+(ja+ha+C)|0]|0)+(a[ea+ka|0]|0)&255)+(a[t+ka|0]|0)&255)<<4|((a[ga+(fa+ha+q)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0)&255;ia=d[z]|0;fa=D+ia|0;ka=d[z+1|0]|0;ja=F+ka|0;a[v]=(((a[ga+(ka+ha+G)|0]|0)+(a[ea+ja|0]|0)&255)+(a[t+ja|0]|0)&255)<<4|((a[ga+(ia+ha+E)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0)&255;fa=(d[r+1|0]|0)+128|0;t=c[b+4352+(fa<<2)>>2]|0;ea=(d[x+1|0]|0)+128|0;ha=c[b+6400+(ea<<2)>>2]|0;ia=c[b+2304+(fa<<2)>>2]|0;fa=c[b+8448+(ea<<2)>>2]|0;ea=d[z+2|0]|0;ga=H+ea|0;ja=d[z+3|0]|0;ka=J+ja|0;a[v+1|0]=(((a[ha+(ja+ia+K)|0]|0)+(a[t+ka|0]|0)&255)+(a[fa+ka|0]|0)&255)<<4|((a[ha+(ea+ia+I)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+ga|0]|0)&255;ga=d[u+2|0]|0;ea=L+ga|0;ka=d[u+3|0]|0;ja=N+ka|0;a[w+1|0]=(((a[ha+(ka+ia+O)|0]|0)+(a[t+ja|0]|0)&255)+(a[fa+ja|0]|0)&255)<<4|((a[ha+(ga+ia+M)|0]|0)+(a[t+ea|0]|0)&255)+(a[fa+ea|0]|0)&255;ea=(d[r+2|0]|0)+128|0;fa=c[b+4352+(ea<<2)>>2]|0;t=(d[x+2|0]|0)+128|0;ia=c[b+6400+(t<<2)>>2]|0;ga=c[b+2304+(ea<<2)>>2]|0;ea=c[b+8448+(t<<2)>>2]|0;t=d[u+4|0]|0;ha=P+t|0;ja=d[u+5|0]|0;ka=R+ja|0;a[w+2|0]=(((a[ia+(ja+ga+S)|0]|0)+(a[fa+ka|0]|0)&255)+(a[ea+ka|0]|0)&255)<<4|((a[ia+(t+ga+Q)|0]|0)+(a[fa+ha|0]|0)&255)+(a[ea+ha|0]|0)&255;ha=d[z+4|0]|0;t=T+ha|0;ka=d[z+5|0]|0;ja=V+ka|0;a[v+2|0]=(((a[ia+(ka+ga+W)|0]|0)+(a[fa+ja|0]|0)&255)+(a[ea+ja|0]|0)&255)<<4|((a[ia+(ha+ga+U)|0]|0)+(a[fa+t|0]|0)&255)+(a[ea+t|0]|0)&255;t=(d[r+3|0]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[x+3|0]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[z+6|0]|0;ia=X+fa|0;ja=d[z+7|0]|0;ka=Z+ja|0;a[v+3|0]=(((a[ga+(ja+ha+_)|0]|0)+(a[ea+ka|0]|0)&255)+(a[t+ka|0]|0)&255)<<4|((a[ga+(fa+ha+Y)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0)&255;ia=d[u+6|0]|0;fa=$+ia|0;ka=d[u+7|0]|0;ja=ba+ka|0;a[w+3|0]=(((a[ga+(ka+ha+da)|0]|0)+(a[ea+ja|0]|0)&255)+(a[t+ja|0]|0)&255)<<4|((a[ga+(ia+ha+aa)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0)&255;if((A|0)==0){break}else{r=r+4|0;y=A;x=x+4|0;z=z+8|0;u=u+8|0;v=v+4|0;w=w+4|0}}}p=p+2|0;}while((p|0)<(h|0));return h|0}function ayb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=e+4|0;l=f+4|0;m=e+8|0;n=f+8|0;o=b+19608|0;p=0;do{q=c[i>>2]|0;r=p+g|0;s=c[j>>2]|0;t=c[e>>2]|0;u=c[f>>2]|0;v=ca(u,p)|0;w=p>>1;x=c[o>>2]>>3;if((x|0)!=0){y=ca(c[n>>2]|0,w)|0;z=ca(c[l>>2]|0,w)|0;w=q+(ca(s,r+1|0)|0)|0;A=q+(ca(s,r)|0)|0;r=p&6;s=d[1401168+(r<<3)|0]|0;q=d[1401024+(r<<3)|0]|0;B=d[1401169+(r<<3)|0]|0;C=d[1401025+(r<<3)|0]|0;D=d[1401176+(r<<3)|0]|0;E=d[1401032+(r<<3)|0]|0;F=d[1401177+(r<<3)|0]|0;G=d[1401033+(r<<3)|0]|0;H=d[1401178+(r<<3)|0]|0;I=d[1401034+(r<<3)|0]|0;J=d[1401179+(r<<3)|0]|0;K=d[1401035+(r<<3)|0]|0;L=d[1401170+(r<<3)|0]|0;M=d[1401026+(r<<3)|0]|0;N=d[1401171+(r<<3)|0]|0;O=d[1401027+(r<<3)|0]|0;P=d[1401172+(r<<3)|0]|0;Q=d[1401028+(r<<3)|0]|0;R=d[1401173+(r<<3)|0]|0;S=d[1401029+(r<<3)|0]|0;T=d[1401180+(r<<3)|0]|0;U=d[1401036+(r<<3)|0]|0;V=d[1401181+(r<<3)|0]|0;W=d[1401037+(r<<3)|0]|0;X=d[1401182+(r<<3)|0]|0;Y=d[1401038+(r<<3)|0]|0;Z=d[1401183+(r<<3)|0]|0;_=d[1401039+(r<<3)|0]|0;$=d[1401174+(r<<3)|0]|0;aa=d[1401030+(r<<3)|0]|0;ba=d[1401175+(r<<3)|0]|0;da=d[1401031+(r<<3)|0]|0;r=(c[k>>2]|0)+z|0;z=(c[m>>2]|0)+y|0;y=x;x=t+(v+u)|0;u=t+v|0;v=w;w=A;while(1){A=y-1|0;t=(d[z]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[r]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[u]|0;ia=s+fa|0;a[w]=((a[ga+(fa+ha+q)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0);ia=d[u+1|0]|0;fa=B+ia|0;a[w+1|0]=((a[ga+(ia+ha+C)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0);fa=d[x]|0;ia=D+fa|0;a[v]=((a[ga+(fa+ha+E)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0);ia=d[x+1|0]|0;fa=F+ia|0;a[v+1|0]=((a[ga+(ia+ha+G)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0);fa=(d[z+1|0]|0)+128|0;t=c[b+4352+(fa<<2)>>2]|0;ea=(d[r+1|0]|0)+128|0;ha=c[b+6400+(ea<<2)>>2]|0;ia=c[b+2304+(fa<<2)>>2]|0;fa=c[b+8448+(ea<<2)>>2]|0;ea=d[x+2|0]|0;ga=H+ea|0;a[v+2|0]=((a[ha+(ea+ia+I)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+ga|0]|0);ga=d[x+3|0]|0;ea=J+ga|0;a[v+3|0]=((a[ha+(ga+ia+K)|0]|0)+(a[t+ea|0]|0)&255)+(a[fa+ea|0]|0);ea=d[u+2|0]|0;ga=L+ea|0;a[w+2|0]=((a[ha+(ea+ia+M)|0]|0)+(a[t+ga|0]|0)&255)+(a[fa+ga|0]|0);ga=d[u+3|0]|0;ea=N+ga|0;a[w+3|0]=((a[ha+(ga+ia+O)|0]|0)+(a[t+ea|0]|0)&255)+(a[fa+ea|0]|0);ea=(d[z+2|0]|0)+128|0;fa=c[b+4352+(ea<<2)>>2]|0;t=(d[r+2|0]|0)+128|0;ia=c[b+6400+(t<<2)>>2]|0;ga=c[b+2304+(ea<<2)>>2]|0;ea=c[b+8448+(t<<2)>>2]|0;t=d[u+4|0]|0;ha=P+t|0;a[w+4|0]=((a[ia+(t+ga+Q)|0]|0)+(a[fa+ha|0]|0)&255)+(a[ea+ha|0]|0);ha=d[u+5|0]|0;t=R+ha|0;a[w+5|0]=((a[ia+(ha+ga+S)|0]|0)+(a[fa+t|0]|0)&255)+(a[ea+t|0]|0);t=d[x+4|0]|0;ha=T+t|0;a[v+4|0]=((a[ia+(t+ga+U)|0]|0)+(a[fa+ha|0]|0)&255)+(a[ea+ha|0]|0);ha=d[x+5|0]|0;t=V+ha|0;a[v+5|0]=((a[ia+(ha+ga+W)|0]|0)+(a[fa+t|0]|0)&255)+(a[ea+t|0]|0);t=(d[z+3|0]|0)+128|0;ea=c[b+4352+(t<<2)>>2]|0;fa=(d[r+3|0]|0)+128|0;ga=c[b+6400+(fa<<2)>>2]|0;ha=c[b+2304+(t<<2)>>2]|0;t=c[b+8448+(fa<<2)>>2]|0;fa=d[x+6|0]|0;ia=X+fa|0;a[v+6|0]=((a[ga+(fa+ha+Y)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0);ia=d[x+7|0]|0;fa=Z+ia|0;a[v+7|0]=((a[ga+(ia+ha+_)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0);fa=d[u+6|0]|0;ia=$+fa|0;a[w+6|0]=((a[ga+(fa+ha+aa)|0]|0)+(a[ea+ia|0]|0)&255)+(a[t+ia|0]|0);ia=d[u+7|0]|0;fa=ba+ia|0;a[w+7|0]=((a[ga+(ia+ha+da)|0]|0)+(a[ea+fa|0]|0)&255)+(a[t+fa|0]|0);if((A|0)==0){break}else{r=r+4|0;z=z+4|0;y=A;x=x+8|0;u=u+8|0;v=v+8|0;w=w+8|0}}}p=p+2|0;}while((p|0)<(h|0));return h|0}function byb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((c[b+56>>2]|0)==4){k=f+4|0;c[k>>2]=c[k>>2]<<1;k=f+8|0;c[k>>2]=c[k>>2]<<1}if((h|0)<=0){return h|0}k=b+19608|0;l=b+7424|0;m=b+3328|0;b=0;do{n=c[i>>2]|0;o=b+g|0;p=c[j>>2]|0;q=c[e>>2]|0;r=c[f>>2]|0;s=ca(r,b)|0;t=c[k>>2]>>3;if((t|0)!=0){u=n+(ca(p,o+1|0)|0)|0;v=n+(ca(p,o)|0)|0;o=b&6;p=d[1401168+(o<<3)|0]|0;n=d[1401169+(o<<3)|0]|0;w=d[1401176+(o<<3)|0]|0;x=d[1401177+(o<<3)|0]|0;y=d[1401178+(o<<3)|0]|0;z=d[1401179+(o<<3)|0]|0;A=d[1401170+(o<<3)|0]|0;B=d[1401171+(o<<3)|0]|0;C=d[1401172+(o<<3)|0]|0;D=d[1401173+(o<<3)|0]|0;E=d[1401180+(o<<3)|0]|0;F=d[1401181+(o<<3)|0]|0;G=d[1401182+(o<<3)|0]|0;H=d[1401183+(o<<3)|0]|0;I=d[1401174+(o<<3)|0]|0;J=d[1401175+(o<<3)|0]|0;o=q+(s+r)|0;r=t;t=q+s|0;s=u;u=v;while(1){v=r-1|0;q=c[l>>2]|0;K=c[m>>2]|0;L=(((a[q+((d[o+6|0]|0)+K+G)|0]|0)+(((a[q+((d[o+5|0]|0)+K+F)|0]|0)+(((a[q+((d[o+4|0]|0)+K+E)|0]|0)+(((a[q+((d[o+3|0]|0)+K+z)|0]|0)+(((a[q+((d[o+2|0]|0)+K+y)|0]|0)+(((a[q+((d[o+1|0]|0)+K+x)|0]|0)+(a[q+((d[o]|0)+K+w)|0]<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)+(a[q+((d[o+7|0]|0)+K+H)|0]|0)&255;a[u]=(((a[q+((d[t+6|0]|0)+K+I)|0]|0)+(((a[q+((d[t+5|0]|0)+K+D)|0]|0)+(((a[q+((d[t+4|0]|0)+K+C)|0]|0)+(((a[q+((d[t+3|0]|0)+K+B)|0]|0)+(((a[q+((d[t+2|0]|0)+K+A)|0]|0)+(((a[q+((d[t+1|0]|0)+K+n)|0]|0)+(a[q+((d[t]|0)+K+p)|0]<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)&255)<<1)+(a[q+((d[t+7|0]|0)+K+J)|0]|0);a[s]=L;if((v|0)==0){break}else{o=o+8|0;r=v;t=t+8|0;s=s+1|0;u=u+1|0}}}b=b+2|0;}while((b|0)<(h|0));return h|0}function cyb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0;l=i;m=e+52|0;n=c[m>>2]|0;switch(n|0){case 30:case 29:case 3:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:{o=1;break};default:{o=0}}switch(n|0){case 43:case 45:case 63:case 47:case 49:case 65:{p=1;break};default:{p=0}}n=c[e+60>>2]|0;q=(g|0)!=0;g=q?384:326;r=c[f>>2]|0;s=r;t=(r|0)<0|0?-1:0;r=c[f+4>>2]|0;u=r;v=(r|0)<0|0?-1:0;r=-(c[f+8>>2]|0)|0;w=r;x=(r|0)<0|0?-1:0;r=-(c[f+12>>2]|0)|0;f=r;y=(r|0)<0|0?-1:0;if(q){q=Erc(s,t,224,0)|0;r=Crc(q,G,255,0)|0;q=G;z=Erc(u,v,224,0)|0;A=Crc(z,G,255,0)|0;z=G;B=Erc(w,x,224,0)|0;C=Crc(B,G,255,0)|0;B=G;D=Erc(f,y,224,0)|0;E=Crc(D,G,255,0)|0;F=0;H=0;I=0;J=65536;K=G;L=E;M=B;N=C;O=z;P=A;Q=q;R=r}else{F=0;H=1048576;I=0;J=76309;K=y;L=f;M=x;N=w;O=v;P=u;Q=t;R=s}s=j;t=(j|0)<0|0?-1:0;j=Erc(J,I,s,t)|0;I=G;J=j>>>16|I<<16;j=I>>16|((I|0)<0|0?-1:0)<<16;I=Erc(k,(k|0)<0|0?-1:0,s,t)|0;t=G;Erc(I,t,R,Q)|0;Q=G;R=Q;s=(Q|0)<0|0?-1:0;Erc(I,t,P,O)|0;O=G;P=O;Q=(O|0)<0|0?-1:0;Erc(I,t,N,M)|0;M=G;N=M;O=(M|0)<0|0?-1:0;Erc(I,t,L,K)|0;K=G;L=K;t=(K|0)<0|0?-1:0;K=h<<8;h=xrc(H,F,K,(K|0)<0|0?-1:0)|0;K=G;F=e+11400|0;c[F>>2]=67109888;c[F+4>>2]=67109888;F=e+11408|0;c[F>>2]=67109888;c[F+4>>2]=67109888;F=wrc(J<<13|0>>>19,j<<13|J>>>19,32768,0)|0;H=G;I=F>>>16|H<<16;F=I;M=(F|0)<-32767;if(M){S=-2147450880;T=-2147450880}else{k=(F|0)>32767;u=Erc(I&65535,(H>>>16|0<<16)&0,65537,65537)|0;S=k?2147450879:G;T=k?2147450879:u}u=e+11352|0;c[u>>2]=T;c[u+4>>2]=S;S=wrc(R<<13|0>>>19,s<<13|R>>>19,32768,0)|0;u=G;T=S>>>16|u<<16;S=T;k=(S|0)<-32767;if(k){U=-2147450880;V=-2147450880}else{H=(S|0)>32767;v=Erc(T&65535,(u>>>16|0<<16)&0,65537,65537)|0;U=H?2147450879:G;V=H?2147450879:v}v=e+11360|0;c[v>>2]=V;c[v+4>>2]=U;U=wrc(P<<13|0>>>19,Q<<13|P>>>19,32768,0)|0;v=G;V=U>>>16|v<<16;U=V;H=(U|0)<-32767;if(H){W=-2147450880;X=-2147450880}else{u=(U|0)>32767;w=Erc(V&65535,(v>>>16|0<<16)&0,65537,65537)|0;W=u?2147450879:G;X=u?2147450879:w}w=e+11368|0;c[w>>2]=X;c[w+4>>2]=W;W=wrc(L<<13|0>>>19,t<<13|L>>>19,32768,0)|0;w=G;X=W>>>16|w<<16;W=X;u=(W|0)<-32767;if(u){Y=-2147450880;Z=-2147450880}else{v=(W|0)>32767;x=Erc(X&65535,(w>>>16|0<<16)&0,65537,65537)|0;Y=v?2147450879:G;Z=v?2147450879:x}x=e+11376|0;c[x>>2]=Z;c[x+4>>2]=Y;Y=wrc(N<<13|0>>>19,O<<13|N>>>19,32768,0)|0;x=G;Z=Y>>>16|x<<16;Y=Z;v=(Y|0)<-32767;if(v){_=-2147450880;$=-2147450880}else{w=(Y|0)>32767;f=Erc(Z&65535,(x>>>16|0<<16)&0,65537,65537)|0;_=w?2147450879:G;$=w?2147450879:f}f=e+11384|0;c[f>>2]=$;c[f+4>>2]=_;_=wrc(h<<3|0>>>29,K<<3|h>>>29,32768,0)|0;f=G;$=_>>>16|f<<16;_=$;if((_|0)<-32767){aa=-2147450880;ba=-2147450880}else{w=(_|0)>32767;_=Erc($&65535,(f>>>16|0<<16)&0,65537,65537)|0;aa=w?2147450879:G;ba=w?2147450879:_}_=e+11392|0;c[_>>2]=ba;c[_+4>>2]=aa;if(M){ca=-32768}else{ca=(F|0)>32767?32767:(I&65535)<<16>>16}c[e+11304>>2]=ca;ca=h>>>7|K<<25;I=ca;if((I|0)<-32767){da=-32768}else{da=(I|0)>32767?32767:(ca&65535)<<16>>16}c[e+11300>>2]=da;if(k){ea=-32768}else{ea=(S|0)>32767?32767:(T&65535)<<16>>16}c[e+11308>>2]=ea;if(u){fa=-32768}else{fa=(W|0)>32767?32767:(X&65535)<<16>>16}c[e+11312>>2]=fa;if(v){ga=-32768}else{ga=(Y|0)>32767?32767:(Z&65535)<<16>>16}c[e+11316>>2]=ga;if(H){ha=-32768}else{ha=(U|0)>32767?32767:(V&65535)<<16>>16}c[e+11320>>2]=ha;ha=0;V=(j|0)>(ha|0)|(j|0)==(ha|0)&J>>>0>1>>>0;ha=V?J:1;U=V?j:0;V=Crc(R<<16|0>>>16|32768,s<<16|R>>>16|0,ha,U)|0;R=G;s=Crc(P<<16|0>>>16|32768,Q<<16|P>>>16|0,ha,U)|0;P=G;Q=Crc(N<<16|0>>>16|32768,O<<16|N>>>16|0,ha,U)|0;N=G;O=Crc(L<<16|0>>>16|32768,t<<16|L>>>16|0,ha,U)|0;U=G;ha=e+2288|0;mJb(ha);switch(n|0){case 12:{L=o?8:0;t=o?0:8;H=hJb(6144)|0;c[ha>>2]=H;ga=H;H=xrc(-25165824,-1,h,K)|0;Z=G;Y=H;H=0;while(1){v=wrc(Y,Z,32768,0)|0;fa=v>>>16|G<<16;v=fa;if(v>>>0>255>>>0){ia=-v>>31&255}else{ia=fa&255}fa=(ia&255)>>>4;b[ga+(H<<1)>>1]=fa<<L;b[ga+(H+1024<<1)>>1]=fa<<4;b[ga+(H+2048<<1)>>1]=fa<<t;fa=wrc(Y,Z,J,j)|0;v=H+1|0;if((v|0)<1024){Z=G;Y=fa;H=v}else{break}}if(p){H=0;do{Y=ga+(H<<1)|0;b[Y>>1]=he(b[Y>>1]|0)|0;H=H+1|0;}while((H|0)<3072)}H=ga+(g<<1)|0;R>>9|((R|0)<0|0?-1:0)<<23;Y=(V>>>9|R<<23)<<1|0>>>31;Z=0;do{t=Z-128|0;if((t|0)<0){ja=0;ka=0}else{L=(t|0)>255;ja=L?0:(t|0)<0|0?-1:0;ka=L?255:t}t=Erc(ka,ja,V,R)|0;L=G;L>>16|((L|0)<0|0?-1:0)<<16;c[e+4352+(Z<<2)>>2]=H+(((t>>>16|L<<16)<<1|0>>>31)-Y);Z=Z+1|0;}while((Z|0)<512);Z=ga+((g|1024)<<1)|0;N>>9|((N|0)<0|0?-1:0)<<23;Y=(Q>>>9|N<<23)<<1|0>>>31;H=0;do{ja=H-128|0;if((ja|0)<0){la=0;ma=0}else{ka=(ja|0)>255;la=ka?0:(ja|0)<0|0?-1:0;ma=ka?255:ja}ja=Erc(ma,la,Q,N)|0;ka=G;ka>>16|((ka|0)<0|0?-1:0)<<16;c[e+6400+(H<<2)>>2]=Z+(((ja>>>16|ka<<16)<<1|0>>>31)-Y);H=H+1|0;}while((H|0)<512);H=ga+((g|2048)<<1)|0;P>>9|((P|0)<0|0?-1:0)<<23;ga=(s>>>9|P<<23)<<1|0>>>31;Y=0;do{Z=Y-128|0;if((Z|0)<0){na=0;oa=0}else{la=(Z|0)>255;na=la?0:(Z|0)<0|0?-1:0;oa=la?255:Z}Z=Erc(oa,na,s,P)|0;la=G;la>>16|((la|0)<0|0?-1:0)<<16;c[e+8448+(Y<<2)>>2]=H+(((Z>>>16|la<<16)<<1|0>>>31)-ga);Y=Y+1|0;}while((Y|0)<512);Y=xrc(0,0,O>>>9|U<<23,U>>>9|0<<23)|0;ga=Y;Y=ga;H=(ga|0)<0|0?-1:0;ga=0;while(1){na=ga-128|0;if((na|0)<0){pa=0;qa=0}else{oa=(na|0)>255;pa=oa?0:(na|0)<0|0?-1:0;qa=oa?255:na}na=Erc(qa,pa,O,U)|0;oa=G;la=wrc(na>>>16|oa<<16,oa>>16|((oa|0)<0|0?-1:0)<<16,Y,H)|0;c[e+2304+(ga<<2)>>2]=la<<1|0>>>31;la=ga+1|0;if((la|0)<512){ga=la}else{ra=0;break}}i=l;return ra|0};case 32:case 64:{ga=c[m>>2]|0;if((ga|0)==29){sa=8}else{sa=(ga|0)==27?8:0}ga=sa|(o?16:0);H=sa+8|0;Y=sa|(o?0:16);pa=c[e+56>>2]|0;qa=qKb(pa)|0;if((qa|0)==0){KIb(0,0,2436360,(ta=i,i=i+24|0,c[ta>>2]=2349656,c[ta+8>>2]=2287936,c[ta+16>>2]=778,ta)|0);i=ta;Hd();return 0}do{if((pa|0)==11){ua=0;va=1}else{if((a[qa+7|0]|0)<0){ua=0;va=1;break}ua=sa+24&24;va=0}}while(0);sa=hJb(12288)|0;c[ha>>2]=sa;qa=sa;sa=xrc(-25165824,-1,h,K)|0;pa=va?0:255<<ua;ua=G;va=sa;sa=0;while(1){la=wrc(va,ua,32768,0)|0;oa=la>>>16|G<<16;la=oa;if(la>>>0>255>>>0){wa=-la>>31&255}else{wa=oa&255}oa=wa&255;c[qa+(sa<<2)>>2]=(oa<<ga)+pa;c[qa+(sa+1024<<2)>>2]=oa<<H;c[qa+(sa+2048<<2)>>2]=oa<<Y;oa=wrc(va,ua,J,j)|0;la=sa+1|0;if((la|0)<1024){ua=G;va=oa;sa=la}else{break}}sa=qa+(g<<2)|0;R>>9|((R|0)<0|0?-1:0)<<23;va=(V>>>9|R<<23)<<2|0>>>30;ua=0;do{Y=ua-128|0;if((Y|0)<0){xa=0;ya=0}else{H=(Y|0)>255;xa=H?0:(Y|0)<0|0?-1:0;ya=H?255:Y}Y=Erc(ya,xa,V,R)|0;H=G;H>>16|((H|0)<0|0?-1:0)<<16;c[e+4352+(ua<<2)>>2]=sa+(((Y>>>16|H<<16)<<2|0>>>30)-va);ua=ua+1|0;}while((ua|0)<512);ua=qa+((g|1024)<<2)|0;N>>9|((N|0)<0|0?-1:0)<<23;va=(Q>>>9|N<<23)<<2|0>>>30;sa=0;do{xa=sa-128|0;if((xa|0)<0){za=0;Aa=0}else{ya=(xa|0)>255;za=ya?0:(xa|0)<0|0?-1:0;Aa=ya?255:xa}xa=Erc(Aa,za,Q,N)|0;ya=G;ya>>16|((ya|0)<0|0?-1:0)<<16;c[e+6400+(sa<<2)>>2]=ua+(((xa>>>16|ya<<16)<<2|0>>>30)-va);sa=sa+1|0;}while((sa|0)<512);sa=qa+((g|2048)<<2)|0;P>>9|((P|0)<0|0?-1:0)<<23;qa=(s>>>9|P<<23)<<2|0>>>30;va=0;do{ua=va-128|0;if((ua|0)<0){Ba=0;Ca=0}else{za=(ua|0)>255;Ba=za?0:(ua|0)<0|0?-1:0;Ca=za?255:ua}ua=Erc(Ca,Ba,s,P)|0;za=G;za>>16|((za|0)<0|0?-1:0)<<16;c[e+8448+(va<<2)>>2]=sa+(((ua>>>16|za<<16)<<2|0>>>30)-qa);va=va+1|0;}while((va|0)<512);va=xrc(0,0,O>>>9|U<<23,U>>>9|0<<23)|0;qa=va;va=qa;sa=(qa|0)<0|0?-1:0;qa=0;while(1){Ba=qa-128|0;if((Ba|0)<0){Da=0;Ea=0}else{Ca=(Ba|0)>255;Da=Ca?0:(Ba|0)<0|0?-1:0;Ea=Ca?255:Ba}Ba=Erc(Ea,Da,O,U)|0;Ca=G;za=wrc(Ba>>>16|Ca<<16,Ca>>16|((Ca|0)<0|0?-1:0)<<16,va,sa)|0;c[e+2304+(qa<<2)>>2]=za<<2|0>>>30;za=qa+1|0;if((za|0)<512){qa=za}else{ra=0;break}}i=l;return ra|0};case 15:case 16:{qa=n-5|0;sa=o?qa:0;va=o?0:qa;qa=hJb(6144)|0;c[ha>>2]=qa;Da=qa;qa=xrc(-25165824,-1,h,K)|0;Ea=18-n|0;za=G;Ca=qa;qa=0;while(1){Ba=wrc(Ca,za,32768,0)|0;ua=Ba>>>16|G<<16;Ba=ua;if(Ba>>>0>255>>>0){Fa=-Ba>>31&255}else{Fa=ua&255}ua=Fa&255;Ba=ua>>>3;b[Da+(qa<<1)>>1]=Ba<<sa;b[Da+(qa+1024<<1)>>1]=ua>>>(Ea>>>0)<<5;b[Da+(qa+2048<<1)>>1]=Ba<<va;Ba=wrc(Ca,za,J,j)|0;ua=qa+1|0;if((ua|0)<1024){za=G;Ca=Ba;qa=ua}else{break}}if(p){p=0;do{qa=Da+(p<<1)|0;b[qa>>1]=he(b[qa>>1]|0)|0;p=p+1|0;}while((p|0)<3072)}p=Da+(g<<1)|0;R>>9|((R|0)<0|0?-1:0)<<23;qa=(V>>>9|R<<23)<<1|0>>>31;Ca=0;do{za=Ca-128|0;if((za|0)<0){Ga=0;Ha=0}else{va=(za|0)>255;Ga=va?0:(za|0)<0|0?-1:0;Ha=va?255:za}za=Erc(Ha,Ga,V,R)|0;va=G;va>>16|((va|0)<0|0?-1:0)<<16;c[e+4352+(Ca<<2)>>2]=p+(((za>>>16|va<<16)<<1|0>>>31)-qa);Ca=Ca+1|0;}while((Ca|0)<512);Ca=Da+((g|1024)<<1)|0;N>>9|((N|0)<0|0?-1:0)<<23;qa=(Q>>>9|N<<23)<<1|0>>>31;p=0;do{Ga=p-128|0;if((Ga|0)<0){Ia=0;Ja=0}else{Ha=(Ga|0)>255;Ia=Ha?0:(Ga|0)<0|0?-1:0;Ja=Ha?255:Ga}Ga=Erc(Ja,Ia,Q,N)|0;Ha=G;Ha>>16|((Ha|0)<0|0?-1:0)<<16;c[e+6400+(p<<2)>>2]=Ca+(((Ga>>>16|Ha<<16)<<1|0>>>31)-qa);p=p+1|0;}while((p|0)<512);p=Da+((g|2048)<<1)|0;P>>9|((P|0)<0|0?-1:0)<<23;Da=(s>>>9|P<<23)<<1|0>>>31;qa=0;do{Ca=qa-128|0;if((Ca|0)<0){Ka=0;La=0}else{Ia=(Ca|0)>255;Ka=Ia?0:(Ca|0)<0|0?-1:0;La=Ia?255:Ca}Ca=Erc(La,Ka,s,P)|0;Ia=G;Ia>>16|((Ia|0)<0|0?-1:0)<<16;c[e+8448+(qa<<2)>>2]=p+(((Ca>>>16|Ia<<16)<<1|0>>>31)-Da);qa=qa+1|0;}while((qa|0)<512);qa=xrc(0,0,O>>>9|U<<23,U>>>9|0<<23)|0;Da=qa;qa=Da;p=(Da|0)<0|0?-1:0;Da=0;while(1){Ka=Da-128|0;if((Ka|0)<0){Ma=0;Na=0}else{La=(Ka|0)>255;Ma=La?0:(Ka|0)<0|0?-1:0;Na=La?255:Ka}Ka=Erc(Na,Ma,O,U)|0;La=G;Ia=wrc(Ka>>>16|La<<16,La>>16|((La|0)<0|0?-1:0)<<16,qa,p)|0;c[e+2304+(Da<<2)>>2]=Ia<<1|0>>>31;Ia=Da+1|0;if((Ia|0)<512){Da=Ia}else{ra=0;break}}i=l;return ra|0};case 8:{Da=o?5:0;p=o?2:3;qa=o?0:6;Ma=hJb(3072)|0;c[ha>>2]=Ma;Na=xrc(-25165824,-1,h,K)|0;Ia=G;La=Na;Na=0;while(1){Ka=wrc(La,Ia,32768,0)|0;Ca=Ka>>>16|G<<16;Ka=Ca;if(Ka>>>0>255>>>0){Oa=-Ka>>31&255}else{Oa=Ca&255}Ca=Oa&255;Ka=((Ca+18|0)>>>0)/36|0;a[Ma+(Na+16)|0]=Ka<<Da;a[Ma+(Na+1040)|0]=Ka<<p;a[Ma+(Na+2085)|0]=(((Ca+43|0)>>>0)/85|0)<<qa;Ca=wrc(La,Ia,J,j)|0;Ka=Na+1|0;if((Ka|0)<986){Ia=G;La=Ca;Na=Ka}else{break}}Na=g-(V>>>9|R<<23)|0;La=0;do{Ia=La-128|0;if((Ia|0)<0){Pa=0;Qa=0}else{qa=(Ia|0)>255;Pa=qa?0:(Ia|0)<0|0?-1:0;Qa=qa?255:Ia}Ia=Erc(Qa,Pa,V,R)|0;c[e+4352+(La<<2)>>2]=Ma+(Na+(Ia>>>16|G<<16));La=La+1|0;}while((La|0)<512);La=(g|1024)-(Q>>>9|N<<23)|0;Na=0;do{Pa=Na-128|0;if((Pa|0)<0){Ra=0;Sa=0}else{Qa=(Pa|0)>255;Ra=Qa?0:(Pa|0)<0|0?-1:0;Sa=Qa?255:Pa}Pa=Erc(Sa,Ra,Q,N)|0;c[e+6400+(Na<<2)>>2]=Ma+(La+(Pa>>>16|G<<16));Na=Na+1|0;}while((Na|0)<512);Na=(g|2048)-(s>>>9|P<<23)|0;La=0;do{Ra=La-128|0;if((Ra|0)<0){Ta=0;Ua=0}else{Sa=(Ra|0)>255;Ta=Sa?0:(Ra|0)<0|0?-1:0;Ua=Sa?255:Ra}Ra=Erc(Ua,Ta,s,P)|0;c[e+8448+(La<<2)>>2]=Ma+(Na+(Ra>>>16|G<<16));La=La+1|0;}while((La|0)<512);La=O>>>9|U<<23;Na=U>>>9|0<<23;Ma=0;while(1){Ta=Ma-128|0;if((Ta|0)<0){Va=0;Wa=0}else{Ua=(Ta|0)>255;Va=Ua?0:(Ta|0)<0|0?-1:0;Wa=Ua?255:Ta}Ta=Erc(Wa,Va,O,U)|0;Ua=G;Ra=xrc(Ta>>>16|Ua<<16,Ua>>>16|0<<16,La,Na)|0;c[e+2304+(Ma<<2)>>2]=Ra;Ra=Ma+1|0;if((Ra|0)<512){Ma=Ra}else{ra=0;break}}i=l;return ra|0};case 1:{Ma=hJb(1024)|0;c[ha>>2]=Ma;Na=xrc(-25165824,-1,h,K)|0;La=G;Va=Na;Na=0;while(1){Wa=wrc(Va,La,32768,0)|0;Ra=Wa>>>16|G<<16;Wa=Ra;if(Wa>>>0>255>>>0){Xa=-Wa>>31&255}else{Xa=Ra&255}a[Ma+(Na+110)|0]=(Xa&255)>>>7;Ra=wrc(Va,La,J,j)|0;Wa=Na+1|0;if((Wa|0)<914){La=G;Va=Ra;Na=Wa}else{break}}Na=g-(Q>>>9|N<<23)|0;Va=0;do{La=Va-128|0;if((La|0)<0){Ya=0;Za=0}else{Xa=(La|0)>255;Ya=Xa?0:(La|0)<0|0?-1:0;Za=Xa?255:La}La=Erc(Za,Ya,Q,N)|0;c[e+6400+(Va<<2)>>2]=Ma+(Na+(La>>>16|G<<16));Va=Va+1|0;}while((Va|0)<512);Va=O>>>9|U<<23;Na=U>>>9|0<<23;Ma=0;while(1){Ya=Ma-128|0;if((Ya|0)<0){_a=0;$a=0}else{Za=(Ya|0)>255;_a=Za?0:(Ya|0)<0|0?-1:0;$a=Za?255:Ya}Ya=Erc($a,_a,O,U)|0;Za=G;La=xrc(Ya>>>16|Za<<16,Za>>>16|0<<16,Va,Na)|0;c[e+2304+(Ma<<2)>>2]=La;La=Ma+1|0;if((La|0)<512){Ma=La}else{ra=0;break}}i=l;return ra|0};case 4:case 132:{Ma=o?3:0;Na=o?0:3;o=hJb(3072)|0;c[ha>>2]=o;Va=xrc(-25165824,-1,h,K)|0;_a=G;$a=Va;Va=0;while(1){La=wrc($a,_a,32768,0)|0;Za=La>>>16|G<<16;La=Za;if(La>>>0>255>>>0){ab=-La>>31&255}else{ab=Za&255}Za=ab&255;La=Za>>>7;a[o+(Va+110)|0]=La<<Ma;a[o+(Va+1061)|0]=(((Za+43|0)>>>0)/85|0)<<1;a[o+(Va+2158)|0]=La<<Na;La=wrc($a,_a,J,j)|0;Za=Va+1|0;if((Za|0)<914){_a=G;$a=La;Va=Za}else{break}}Va=g-(V>>>9|R<<23)|0;$a=0;do{_a=$a-128|0;if((_a|0)<0){bb=0;cb=0}else{Na=(_a|0)>255;bb=Na?0:(_a|0)<0|0?-1:0;cb=Na?255:_a}_a=Erc(cb,bb,V,R)|0;c[e+4352+($a<<2)>>2]=o+(Va+(_a>>>16|G<<16));$a=$a+1|0;}while(($a|0)<512);$a=(g|1024)-(Q>>>9|N<<23)|0;Va=0;do{bb=Va-128|0;if((bb|0)<0){db=0;eb=0}else{cb=(bb|0)>255;db=cb?0:(bb|0)<0|0?-1:0;eb=cb?255:bb}bb=Erc(eb,db,Q,N)|0;c[e+6400+(Va<<2)>>2]=o+($a+(bb>>>16|G<<16));Va=Va+1|0;}while((Va|0)<512);Va=(g|2048)-(s>>>9|P<<23)|0;$a=0;do{db=$a-128|0;if((db|0)<0){fb=0;gb=0}else{eb=(db|0)>255;fb=eb?0:(db|0)<0|0?-1:0;gb=eb?255:db}db=Erc(gb,fb,s,P)|0;c[e+8448+($a<<2)>>2]=o+(Va+(db>>>16|G<<16));$a=$a+1|0;}while(($a|0)<512);$a=O>>>9|U<<23;Va=U>>>9|0<<23;o=0;while(1){fb=o-128|0;if((fb|0)<0){hb=0;ib=0}else{gb=(fb|0)>255;hb=gb?0:(fb|0)<0|0?-1:0;ib=gb?255:fb}fb=Erc(ib,hb,O,U)|0;gb=G;db=xrc(fb>>>16|gb<<16,gb>>>16|0<<16,$a,Va)|0;c[e+2304+(o<<2)>>2]=db;db=o+1|0;if((db|0)<512){o=db}else{ra=0;break}}i=l;return ra|0};case 24:case 48:{o=hJb(1024)|0;c[ha>>2]=o;ha=xrc(-25165824,-1,h,K)|0;K=G;h=ha;ha=0;while(1){Va=wrc(h,K,32768,0)|0;$a=Va>>>16|G<<16;Va=$a;if(Va>>>0>255>>>0){jb=-Va>>31&255}else{jb=$a&255}a[o+ha|0]=jb;$a=wrc(h,K,J,j)|0;Va=ha+1|0;if((Va|0)<1024){K=G;h=$a;ha=Va}else{break}}ha=g-(V>>>9|R<<23)|0;h=0;do{K=h-128|0;if((K|0)<0){kb=0;lb=0}else{j=(K|0)>255;kb=j?0:(K|0)<0|0?-1:0;lb=j?255:K}K=Erc(lb,kb,V,R)|0;c[e+4352+(h<<2)>>2]=o+(ha+(K>>>16|G<<16));h=h+1|0;}while((h|0)<512);h=g-(Q>>>9|N<<23)|0;ha=0;do{R=ha-128|0;if((R|0)<0){mb=0;nb=0}else{V=(R|0)>255;mb=V?0:(R|0)<0|0?-1:0;nb=V?255:R}R=Erc(nb,mb,Q,N)|0;c[e+6400+(ha<<2)>>2]=o+(h+(R>>>16|G<<16));ha=ha+1|0;}while((ha|0)<512);ha=g-(s>>>9|P<<23)|0;g=0;do{h=g-128|0;if((h|0)<0){ob=0;pb=0}else{N=(h|0)>255;ob=N?0:(h|0)<0|0?-1:0;pb=N?255:h}h=Erc(pb,ob,s,P)|0;c[e+8448+(g<<2)>>2]=o+(ha+(h>>>16|G<<16));g=g+1|0;}while((g|0)<512);g=O>>>9|U<<23;ha=U>>>9|0<<23;o=0;while(1){P=o-128|0;if((P|0)<0){qb=0;rb=0}else{s=(P|0)>255;qb=s?0:(P|0)<0|0?-1:0;rb=s?255:P}P=Erc(rb,qb,O,U)|0;s=G;ob=xrc(P>>>16|s<<16,s>>>16|0<<16,g,ha)|0;c[e+2304+(o<<2)>>2]=ob;ob=o+1|0;if((ob|0)<512){o=ob}else{ra=0;break}}i=l;return ra|0};default:{o=qKb(c[m>>2]|0)|0;if((o|0)==0){KIb(0,0,2436360,(ta=i,i=i+24|0,c[ta>>2]=2349656,c[ta+8>>2]=2287936,c[ta+16>>2]=806,ta)|0);i=ta;Hd();return 0}do{if((d[o+4|0]|0)>>>0>1>>>0){if((a[o+7|0]&16)==0|(n|0)<25){break}else{ra=-1}i=l;return ra|0}}while(0);KIb(e,16,2579624,(ta=i,i=i+8|0,c[ta>>2]=n,ta)|0);i=ta;ra=-1;i=l;return ra|0}}return 0}function dyb(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;f=i;g=c[d+56>>2]|0;h=d+23928|0;c[h>>2]=0;switch(g|0){case 316:{c[d+23936>>2]=96;break};case 25:{c[h>>2]=442;break};case 17:{c[h>>2]=382;break};case 26:{c[h>>2]=470;break};case 1:{c[h>>2]=428;break};case 85:{c[d+23936>>2]=598;break};case 319:case 88:{c[d+23936>>2]=502;break};case 83:{c[d+23936>>2]=602;break};case 22:case 19:case 11:case 21:case 24:{c[h>>2]=148;break};case 314:{c[d+23936>>2]=328;break};case 313:{c[d+23936>>2]=292;break};case 317:case 82:{c[d+23936>>2]=592;break};case 75:case 79:case 69:case 77:case 73:case 71:case 309:case 305:case 301:case 311:case 307:case 303:case 55:case 57:case 59:case 95:case 93:case 91:case 101:case 99:case 97:case 103:case 105:case 107:{c[h>>2]=468;break};case 84:{c[d+23936>>2]=246;break};case 86:{c[d+23936>>2]=136;break};case 315:{c[d+23936>>2]=408;break};case 318:case 87:{c[d+23936>>2]=514;break};default:{}}a:do{if((c[d+76>>2]|0)==0){switch(g|0){case 29:{j=554;k=38;break};case 44:{l=370;k=31;break};case 46:{m=620;k=33;break};case 42:{n=278;k=42;break};case 67:{o=284;k=43;break};case 27:{p=218;k=40;break};case 63:{q=300;k=36;break};case 68:{r=338;k=44;break};case 291:{s=154;k=45;break};case 30:{t=520;k=37;break};case 3:{u=596;k=23;break};case 48:{v=500;k=24;break};case 47:{w=88;k=25;break};case 50:{x=380;k=26;break};case 49:{y=194;k=27;break};case 64:{z=90;k=28;break};case 65:{A=160;k=29;break};case 2:{B=104;k=30;break};case 41:{C=240;k=41;break};case 45:{D=430;k=34;break};case 62:{E=274;k=35;break};case 28:{F=602;k=39;break};case 43:{G=102;k=32;break};case 292:{H=506;k=46;break};default:{k=47}}}else{switch(g|0){case 29:{j=662;k=38;break a;break};case 44:{l=110;k=31;break a;break};case 46:{m=376;k=33;break a;break};case 42:{n=670;k=42;break a;break};case 67:{o=230;k=43;break a;break};case 27:{p=332;k=40;break a;break};case 63:{q=162;k=36;break a;break};case 68:{r=22;k=44;break a;break};case 291:{s=502;k=45;break a;break};case 30:{t=136;k=37;break a;break};case 317:case 82:{break};case 3:{u=312;k=23;break a;break};case 48:{v=606;k=24;break a;break};case 47:{w=78;k=25;break a;break};case 50:{x=204;k=26;break a;break};case 49:{y=134;k=27;break a;break};case 64:{z=404;k=28;break a;break};case 65:{A=598;k=29;break a;break};case 2:{B=242;k=30;break a;break};case 41:{C=202;k=41;break a;break};case 45:{D=168;k=34;break a;break};case 62:{E=142;k=35;break a;break};case 28:{F=374;k=39;break a;break};case 43:{G=210;k=32;break a;break};case 292:{H=246;k=46;break a;break};default:{k=47;break a}}c[h>>2]=584;k=47}}while(0);b:do{if((k|0)==23){c[h>>2]=u;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;K=I;L=J;k=64}else if((k|0)==24){c[h>>2]=v;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;M=J;N=I;k=65}else if((k|0)==25){c[h>>2]=w;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;O=I;P=J;k=66}else if((k|0)==26){c[h>>2]=x;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;Q=J;R=I;k=67}else if((k|0)==27){c[h>>2]=y;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;S=I;T=J;k=68}else if((k|0)==28){c[h>>2]=z;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;U=J;V=I;k=69}else if((k|0)==29){c[h>>2]=A;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;W=I;X=J;k=70}else if((k|0)==30){c[h>>2]=B;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;Y=J;Z=I;k=71}else if((k|0)==31){c[h>>2]=l;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;_=I;$=J;k=72}else if((k|0)==32){c[h>>2]=G;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;aa=J;ba=I;k=73}else if((k|0)==33){c[h>>2]=m;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;ca=I;da=J;k=74}else if((k|0)==34){c[h>>2]=D;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ea=J;fa=I;k=75}else if((k|0)==35){c[h>>2]=E;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;ga=I;ha=J;k=76}else if((k|0)==36){c[h>>2]=q;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ia=J;ja=I;k=77}else if((k|0)==37){c[h>>2]=t;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;ka=I;la=J;k=81}else if((k|0)==38){c[h>>2]=j;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ma=J;na=I;k=82}else if((k|0)==39){c[h>>2]=F;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;oa=I;pa=J;k=83}else if((k|0)==40){c[h>>2]=p;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;qa=J;ra=I;k=84}else if((k|0)==41){c[h>>2]=C;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;sa=I;ta=J;k=85}else if((k|0)==42){c[h>>2]=n;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ua=J;va=I;k=86}else if((k|0)==43){c[h>>2]=o;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;wa=I;xa=J;k=87}else if((k|0)==44){c[h>>2]=r;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;ya=J;za=I;k=88}else if((k|0)==45){c[h>>2]=s;I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;Aa=I;Ba=J;k=89}else if((k|0)==46){c[h>>2]=H;J=d+23920|0;c[J>>2]=0;I=d+23924|0;c[I>>2]=0;Ca=J;Da=I;k=90}else if((k|0)==47){I=d+23920|0;c[I>>2]=0;J=d+23924|0;c[J>>2]=0;switch(g|0){case 45:{ea=I;fa=J;k=75;break b;break};case 43:{aa=I;ba=J;k=73;break b;break};case 46:{ca=I;da=J;k=74;break b;break};case 28:{oa=I;pa=J;k=83;break b;break};case 47:{O=I;P=J;k=66;break b;break};case 83:{c[d+23932>>2]=836;Ea=J;break b;break};case 1:case 66:{c[I>>2]=338;Ea=J;break b;break};case 17:{c[I>>2]=6;Ea=J;break b;break};case 30:{ka=I;la=J;k=81;break b;break};case 29:{ma=I;na=J;k=82;break b;break};case 84:{c[d+23932>>2]=838;Ea=J;break b;break};case 314:{c[d+23932>>2]=548;Ea=J;break b;break};case 317:{c[d+23940>>2]=354;break};case 49:{S=I;T=J;k=68;break b;break};case 86:{c[d+23932>>2]=18;Ea=J;break b;break};case 62:{ga=I;ha=J;k=76;break b;break};case 44:{_=I;$=J;k=72;break b;break};case 42:{ua=I;va=J;k=86;break b;break};case 319:case 88:{c[d+23932>>2]=800;Ea=J;break b;break};case 3:{K=I;L=J;k=64;break b;break};case 48:{M=I;N=J;k=65;break b;break};case 10:{c[I>>2]=222;Ea=J;break b;break};case 9:{c[I>>2]=124;Ea=J;break b;break};case 2:{Y=I;Z=J;k=71;break b;break};case 316:{c[d+23932>>2]=276;Ea=J;break b;break};case 75:case 79:case 69:case 77:case 73:case 71:case 309:case 305:case 301:case 311:case 307:case 303:case 55:case 57:case 59:case 31:{c[I>>2]=238;Ea=J;break b;break};case 95:case 93:case 91:case 101:case 99:case 97:case 103:case 105:case 107:{c[I>>2]=238;c[J>>2]=238;Ea=J;break b;break};case 315:{c[d+23932>>2]=62;Ea=J;break b;break};case 313:{c[d+23932>>2]=144;Ea=J;break b;break};case 291:{Aa=I;Ba=J;k=89;break b;break};case 50:{Q=I;R=J;k=67;break b;break};case 82:{break};case 318:case 87:{c[d+23932>>2]=556;Ea=J;break b;break};case 67:{wa=I;xa=J;k=87;break b;break};case 68:{ya=I;za=J;k=88;break b;break};case 64:{U=I;V=J;k=69;break b;break};case 65:{W=I;X=J;k=70;break b;break};case 292:{Ca=I;Da=J;k=90;break b;break};case 27:{qa=I;ra=J;k=84;break b;break};case 41:{sa=I;ta=J;k=85;break b;break};case 85:{c[d+23932>>2]=404;Ea=J;break b;break};case 63:{ia=I;ja=J;k=77;break b;break};case 22:case 19:case 11:case 21:case 24:{c[I>>2]=120;Ea=J;break b;break};default:{Ea=J;break b}}c[d+23932>>2]=356;Ea=J}}while(0);if((k|0)==64){c[K>>2]=28;Ea=L}else if((k|0)==65){c[M>>2]=108;Ea=N}else if((k|0)==66){c[O>>2]=208;Ea=P}else if((k|0)==67){c[Q>>2]=266;Ea=R}else if((k|0)==68){c[S>>2]=148;Ea=T}else if((k|0)==69){c[U>>2]=184;Ea=V}else if((k|0)==70){c[W>>2]=38;Ea=X}else if((k|0)==71){c[Y>>2]=132;Ea=Z}else if((k|0)==72){c[_>>2]=342;Ea=$}else if((k|0)==73){c[aa>>2]=346;Ea=ba}else if((k|0)==74){c[ca>>2]=162;Ea=da}else if((k|0)==75){c[ea>>2]=60;Ea=fa}else if((k|0)==76){c[ga>>2]=210;Ea=ha}else if((k|0)==77){c[ia>>2]=182;Ea=ja}else if((k|0)==81){c[ka>>2]=194;Ea=la}else if((k|0)==82){c[ma>>2]=96;Ea=na}else if((k|0)==83){c[oa>>2]=350;Ea=pa}else if((k|0)==84){c[qa>>2]=290;Ea=ra}else if((k|0)==85){c[sa>>2]=262;Ea=ta}else if((k|0)==86){c[ua>>2]=116;Ea=va}else if((k|0)==87){c[wa>>2]=292;Ea=xa}else if((k|0)==88){c[ya>>2]=354;Ea=za}else if((k|0)==89){c[Aa>>2]=158;Ea=Ba}else if((k|0)==90){c[Ca>>2]=256;Ea=Da}if((c[d+2180>>2]|0)==0){i=f;return}d=qKb(g)|0;if((d|0)==0){KIb(0,0,2414952,(Fa=i,i=i+24|0,c[Fa>>2]=2579616,c[Fa+8>>2]=2436328,c[Fa+16>>2]=637,Fa)|0);i=Fa;Hd()}do{if((b[d+8>>1]&30720)==30720){k=98}else{Da=qKb(g)|0;if((Da|0)==0){KIb(0,0,2414952,(Fa=i,i=i+24|0,c[Fa>>2]=2579616,c[Fa+8>>2]=2436328,c[Fa+16>>2]=644,Fa)|0);i=Fa;Hd()}else{if((((e[Da+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){k=98;break}else{break}}}}while(0);do{if((k|0)==98){d=qKb(g)|0;if((d|0)==0){KIb(0,0,2414952,(Fa=i,i=i+24|0,c[Fa>>2]=2579616,c[Fa+8>>2]=2436328,c[Fa+16>>2]=653,Fa)|0);i=Fa;Hd()}if((a[d+7|0]&1)==0){break}c[Ea>>2]=238}}while(0);switch(g|0){case 29:case 27:{c[Ea>>2]=254;i=f;return};case 66:{c[Ea>>2]=6;i=f;return};case 11:{c[Ea>>2]=344;i=f;return};case 292:case 291:{c[Ea>>2]=102;i=f;return};case 30:case 28:{c[Ea>>2]=8;i=f;return};default:{i=f;return}}}function eyb(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((g|0)>0){i=0}else{return}do{h=i<<2;a[b+i|0]=a[e+(h|1)|0]|0;a[c+i|0]=a[e+(h|3)|0]|0;i=i+1|0;}while((i|0)<(g|0));return}function fyb(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((g|0)>0){i=0}else{return}do{h=i<<2;a[b+i|0]=a[e+h|0]|0;a[c+i|0]=a[e+(h|2)|0]|0;i=i+1|0;}while((i|0)<(g|0));return}function gyb(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((g|0)>0){i=0}else{return}do{h=i<<1;a[b+i|0]=a[e+h|0]|0;a[c+i|0]=a[e+(h|1)|0]|0;i=i+1|0;}while((i|0)<(g|0));return}function hyb(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((g|0)>0){i=0}else{return}do{h=i<<1;a[c+i|0]=a[e+h|0]|0;a[b+i|0]=a[e+(h|1)|0]|0;i=i+1|0;}while((i|0)<(g|0));return}function iyb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0;h=a;a=e;if((i|0)>0){k=0}else{return}do{e=c[j+((d[g+k|0]|0)<<2)>>2]|0;b[h+(k<<1)>>1]=e>>>8<<6&16320;b[a+(k<<1)>>1]=e>>>16<<6&16320;k=k+1|0;}while((k|0)<(i|0));return}function jyb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ca(t,j)|0)+8421376+(ca(q,k)|0)+(ca(r,e)|0)|0)>>>10;b[a+(p<<1)>>1]=((ca(t,m)|0)+8421376+(ca(q,n)|0)+(ca(r,l)|0)|0)>>>10;p=p+1|0;}while((p|0)<(g|0));return}function kyb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ca(t,j)|0)+16842752+(ca(q,k)|0)+(ca(r,e)|0)|0)>>>11;b[a+(p<<1)>>1]=((ca(t,m)|0)+16842752+(ca(q,n)|0)+(ca(r,l)|0)|0)>>>11;p=p+1|0;}while((p|0)<(g|0));return}function lyb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ca(t,j)|0)+67371008+(ca(q,k)|0)+(ca(r,e)|0)|0)>>>13;b[a+(p<<1)>>1]=((ca(t,m)|0)+67371008+(ca(q,n)|0)+(ca(r,l)|0)|0)>>>13;p=p+1|0;}while((p|0)<(g|0));return}function myb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ca(t,j)|0)+269484032+(ca(q,k)|0)+(ca(r,e)|0)|0)>>>15;b[a+(p<<1)>>1]=((ca(t,m)|0)+269484032+(ca(q,n)|0)+(ca(r,l)|0)|0)>>>15;p=p+1|0;}while((p|0)<(g|0));return}function nyb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=(c[h>>2]|0)+(p<<1)|0;s=(c[o>>2]|0)+(p<<1)|0;t=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=(d[s]|d[s+1|0]<<8)<<16>>16&65535;b[i+(p<<1)>>1]=((ca(t,j)|0)+1077936128+(ca(q,k)|0)+(ca(r,e)|0)|0)>>>15;b[a+(p<<1)>>1]=((ca(t,m)|0)+1077936128+(ca(q,n)|0)+(ca(r,l)|0)|0)>>>15;p=p+1|0;}while((p|0)<(g|0));return}function oyb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ca(q,j)|0)+8421376+(ca(t,k)|0)+(ca(s,e)|0)|0)>>>10;b[a+(p<<1)>>1]=((ca(q,m)|0)+8421376+(ca(t,n)|0)+(ca(s,l)|0)|0)>>>10;p=p+1|0;}while((p|0)<(g|0));return}function pyb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ca(q,j)|0)+16842752+(ca(t,k)|0)+(ca(s,e)|0)|0)>>>11;b[a+(p<<1)>>1]=((ca(q,m)|0)+16842752+(ca(t,n)|0)+(ca(s,l)|0)|0)>>>11;p=p+1|0;}while((p|0)<(g|0));return}function qyb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ca(q,j)|0)+67371008+(ca(t,k)|0)+(ca(s,e)|0)|0)>>>13;b[a+(p<<1)>>1]=((ca(q,m)|0)+67371008+(ca(t,n)|0)+(ca(s,l)|0)|0)>>>13;p=p+1|0;}while((p|0)<(g|0));return}function ryb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ca(q,j)|0)+269484032+(ca(t,k)|0)+(ca(s,e)|0)|0)>>>15;b[a+(p<<1)>>1]=((ca(q,m)|0)+269484032+(ca(t,n)|0)+(ca(s,l)|0)|0)>>>15;p=p+1|0;}while((p|0)<(g|0));return}function syb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=f+4|0;o=f+8|0;p=0;do{q=(c[f>>2]|0)+(p<<1)|0;r=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[h>>2]|0)+(p<<1)|0;s=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=(c[o>>2]|0)+(p<<1)|0;t=s&65535;s=(he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;q=r&65535;b[i+(p<<1)>>1]=((ca(q,j)|0)+1077936128+(ca(t,k)|0)+(ca(s,e)|0)|0)>>>15;b[a+(p<<1)>>1]=((ca(q,m)|0)+1077936128+(ca(t,n)|0)+(ca(s,l)|0)|0)>>>15;p=p+1|0;}while((p|0)<(g|0));return}function tyb(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=a;a=e;e=c[h+12>>2]|0;j=c[h+16>>2]|0;k=c[h+20>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;n=c[h+32>>2]|0;if((g|0)<=0){return}h=c[f>>2]|0;o=c[f+4>>2]|0;p=c[f+8>>2]|0;f=0;do{q=d[h+f|0]|0;r=d[o+f|0]|0;s=d[p+f|0]|0;b[i+(f<<1)>>1]=((ca(q,j)|0)+4194560+(ca(r,k)|0)+(ca(s,e)|0)|0)>>>9;b[a+(f<<1)>>1]=((ca(q,m)|0)+4194560+(ca(r,n)|0)+(ca(s,l)|0)|0)>>>9;f=f+1|0;}while((f|0)<(g|0));return}function uyb(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=e;e=f;f=a;a=c;if((g|0)>0){i=0}else{return}do{b[f+(i<<1)>>1]=he(b[h+(i<<1)>>1]|0)|0;b[a+(i<<1)>>1]=he(b[e+(i<<1)>>1]|0)|0;i=i+1|0;}while((i|0)<(g|0));return}function vyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(291)|0;if((l|0)==0){s=3;break}t=r<<3;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=qKb(291)|0;if((v|0)==0){s=7;break}l=g+((t|4)<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=he(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=qKb(291)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=he(y|0)|0}y=qKb(291)|0;if((y|0)==0){s=15;break}v=g+((t|5)<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=he(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=qKb(291)|0;if((y|0)==0){s=19;break}v=g+((t|2)<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=he(B|0)|0}B=qKb(291)|0;if((B|0)==0){s=23;break}y=g+((t|6)<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=he(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ca(u,f)|0)+1073758208+(ca(l,m)|0)+(ca(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(u,o)|0)+1073758208+(ca(l,p)|0)+(ca(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==7){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==11){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==15){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==19){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==23){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==27){i=j;return}}function wyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(292)|0;if((l|0)==0){s=3;break}t=r<<3;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=qKb(292)|0;if((v|0)==0){s=7;break}l=g+((t|4)<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=he(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=qKb(292)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=he(y|0)|0}y=qKb(292)|0;if((y|0)==0){s=15;break}v=g+((t|5)<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=he(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=qKb(292)|0;if((y|0)==0){s=19;break}v=g+((t|2)<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=he(B|0)|0}B=qKb(292)|0;if((B|0)==0){s=23;break}y=g+((t|6)<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=he(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ca(u,f)|0)+1073758208+(ca(l,m)|0)+(ca(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(u,o)|0)+1073758208+(ca(l,p)|0)+(ca(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==7){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==11){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==15){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==19){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==23){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==27){i=j;return}}function xyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(41)|0;if((l|0)==0){s=3;break}t=r*6|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=qKb(41)|0;if((v|0)==0){s=7;break}l=g+(t+3<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=he(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=qKb(41)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=he(y|0)|0}y=qKb(41)|0;if((y|0)==0){s=15;break}v=g+(t+4<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=he(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=qKb(41)|0;if((y|0)==0){s=19;break}v=g+(t+2<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=he(B|0)|0}B=qKb(41)|0;if((B|0)==0){s=23;break}y=g+(t+5<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=he(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ca(u,f)|0)+1073758208+(ca(l,m)|0)+(ca(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(u,o)|0)+1073758208+(ca(l,p)|0)+(ca(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==7){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==11){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==15){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==19){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==23){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==27){i=j;return}}function yyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(42)|0;if((l|0)==0){s=3;break}t=r*6|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=qKb(42)|0;if((v|0)==0){s=7;break}l=g+(t+3<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=he(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=qKb(42)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=he(y|0)|0}y=qKb(42)|0;if((y|0)==0){s=15;break}v=g+(t+4<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=he(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=qKb(42)|0;if((y|0)==0){s=19;break}v=g+(t+2<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=he(B|0)|0}B=qKb(42)|0;if((B|0)==0){s=23;break}y=g+(t+5<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=he(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ca(u,f)|0)+1073758208+(ca(l,m)|0)+(ca(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(u,o)|0)+1073758208+(ca(l,p)|0)+(ca(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==7){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==11){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==15){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==19){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==23){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==27){i=j;return}}function zyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(67)|0;if((l|0)==0){s=3;break}t=r*6|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=qKb(67)|0;if((v|0)==0){s=7;break}l=g+(t+3<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=he(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=qKb(67)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=he(y|0)|0}y=qKb(67)|0;if((y|0)==0){s=15;break}v=g+(t+4<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=he(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=qKb(67)|0;if((y|0)==0){s=19;break}v=g+(t+2<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=he(B|0)|0}B=qKb(67)|0;if((B|0)==0){s=23;break}y=g+(t+5<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=he(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ca(u,n)|0)+1073758208+(ca(l,m)|0)+(ca(t,f)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(u,q)|0)+1073758208+(ca(l,p)|0)+(ca(t,o)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==7){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==11){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==15){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==19){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==23){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==27){i=j;return}}function Ayb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(68)|0;if((l|0)==0){s=3;break}t=r*6|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=qKb(68)|0;if((v|0)==0){s=7;break}l=g+(t+3<<1)|0;u=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){x=u}else{x=he(u|0)|0}u=((w&65535)+1+(x&65535)|0)>>>1;v=qKb(68)|0;if((v|0)==0){s=11;break}l=g+((t|1)<<1)|0;y=(d[l]|d[l+1|0]<<8)<<16>>16;if((a[v+7|0]&1)==0){z=y}else{z=he(y|0)|0}y=qKb(68)|0;if((y|0)==0){s=15;break}v=g+(t+4<<1)|0;l=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){A=l}else{A=he(l|0)|0}l=((z&65535)+1+(A&65535)|0)>>>1;y=qKb(68)|0;if((y|0)==0){s=19;break}v=g+(t+2<<1)|0;B=(d[v]|d[v+1|0]<<8)<<16>>16;if((a[y+7|0]&1)==0){C=B}else{C=he(B|0)|0}B=qKb(68)|0;if((B|0)==0){s=23;break}y=g+(t+5<<1)|0;t=(d[y]|d[y+1|0]<<8)<<16>>16;if((a[B+7|0]&1)==0){D=t}else{D=he(t|0)|0}t=((C&65535)+1+(D&65535)|0)>>>1;b[h+(r<<1)>>1]=((ca(u,n)|0)+1073758208+(ca(l,m)|0)+(ca(t,f)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(u,q)|0)+1073758208+(ca(l,p)|0)+(ca(t,o)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=27;break}}if((s|0)==3){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==7){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==11){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==15){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==19){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==23){KIb(0,0,2414952,(E=i,i=i+24|0,c[E>>2]=2579616,c[E+8>>2]=2436328,c[E+16>>2]=653,E)|0);i=E;Hd()}else if((s|0)==27){i=j;return}}function Byb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=n<<3;o=c[f+i>>2]|0;p=c[f+(i|4)>>2]|0;i=(p&-16711936)+(o&-16711936)|0;q=p+o-i|0;o=q&511;p=i&130816;i=q>>>16&511;b[g+(n<<1)>>1]=((ca(p,e)|0)-2147352576+((ca(i,d)|0)+(ca(o,j)|0)<<8)|0)>>>18;b[a+(n<<1)>>1]=((ca(p,l)|0)-2147352576+((ca(i,k)|0)+(ca(o,m)|0)<<8)|0)>>>18;n=n+1|0;}while((n|0)<(h|0));return}function Cyb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=n<<3;o=(c[f+i>>2]|0)>>>8;p=(c[f+(i|4)>>2]|0)>>>8;i=(p&65280)+(o&65280)|0;q=p+o-i|0;o=q&511;p=q>>>16&511;b[g+(n<<1)>>1]=((ca(i,e)|0)-2147352576+((ca(p,d)|0)+(ca(o,j)|0)<<8)|0)>>>18;b[a+(n<<1)>>1]=((ca(i,l)|0)-2147352576+((ca(p,k)|0)+(ca(o,m)|0)<<8)|0)>>>18;n=n+1|0;}while((n|0)<(h|0));return}function Dyb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=a;a=e;e=c[j+12>>2]|0;f=c[j+16>>2]|0;k=c[j+20>>2]|0;l=c[j+24>>2]|0;m=c[j+28>>2]|0;n=c[j+32>>2]|0;if((i|0)>0){o=0}else{return}do{j=o*6|0;p=(d[g+(j+3)|0]|0)+(d[g+j|0]|0)|0;q=(d[g+(j+4)|0]|0)+(d[g+(j|1)|0]|0)|0;r=(d[g+(j+5)|0]|0)+(d[g+(j+2)|0]|0)|0;b[h+(o<<1)>>1]=((ca(p,k)|0)+8389120+(ca(q,f)|0)+(ca(r,e)|0)|0)>>>10;b[a+(o<<1)>>1]=((ca(p,n)|0)+8389120+(ca(q,m)|0)+(ca(r,l)|0)|0)>>>10;o=o+1|0;}while((o|0)<(i|0));return}function Eyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<11;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<11;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(48)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(48)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&2016)+(v&2016)|0;u=t+v-l|0;v=u&129024;t=u&63;b[g+(r<<1)>>1]=((ca(m,l)|0)-2147352576+(ca(f,t)|0)+(ca(v,n)|0)|0)>>>18;b[e+(r<<1)>>1]=((ca(p,l)|0)-2147352576+(ca(o,t)|0)+(ca(v,q)|0)|0)>>>18;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Fyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<11;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<11;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(47)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(47)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&2016)+(v&2016)|0;u=t+v-l|0;v=u&129024;t=u&63;b[g+(r<<1)>>1]=((ca(m,l)|0)-2147352576+(ca(f,t)|0)+(ca(v,n)|0)|0)>>>18;b[e+(r<<1)>>1]=((ca(p,l)|0)-2147352576+(ca(o,t)|0)+(ca(v,q)|0)|0)>>>18;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Gyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<10;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<10;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(50)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(50)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&33760)+(v&33760)|0;u=t+v-l|0;v=u&64512;t=l&2016;l=u&63;b[g+(r<<1)>>1]=((ca(m,t)|0)+1073807360+(ca(f,l)|0)+(ca(v,n)|0)|0)>>>17;b[e+(r<<1)>>1]=((ca(p,t)|0)+1073807360+(ca(o,l)|0)+(ca(v,q)|0)|0)>>>17;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Hyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<10;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<10;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(49)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(49)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&33760)+(v&33760)|0;u=t+v-l|0;v=u&64512;t=l&2016;l=u&63;b[g+(r<<1)>>1]=((ca(m,t)|0)+1073807360+(ca(f,l)|0)+(ca(v,n)|0)|0)>>>17;b[e+(r<<1)>>1]=((ca(p,t)|0)+1073807360+(ca(o,l)|0)+(ca(v,q)|0)|0)>>>17;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Iyb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=a;a=e;e=c[j+12>>2]|0;l=c[j+16>>2]|0;m=c[j+20>>2]|0;n=c[j+24>>2]|0;o=c[j+28>>2]|0;p=c[j+32>>2]|0;if((i|0)>0){q=0}else{return}do{j=q<<1;r=j|1;s=(d[f+r|0]|0)+(d[f+j|0]|0)|0;t=(d[g+r|0]|0)+(d[g+j|0]|0)|0;u=(d[h+r|0]|0)+(d[h+j|0]|0)|0;b[k+(q<<1)>>1]=((ca(s,l)|0)+8389120+(ca(t,m)|0)+(ca(u,e)|0)|0)>>>10;b[a+(q<<1)>>1]=((ca(s,o)|0)+8389120+(ca(t,p)|0)+(ca(u,n)|0)|0)>>>10;q=q+1|0;}while((q|0)<(i|0));return}function Jyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<8;m=c[l+16>>2]<<4;n=c[l+20>>2]|0;o=c[l+24>>2]<<8;p=c[l+28>>2]<<4;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(64)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(64)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&61680)+(v&61680)|0;u=t+v-l|0;v=u&7936;t=l&496;l=u&31;b[g+(r<<1)>>1]=((ca(m,t)|0)+134225920+(ca(f,l)|0)+(ca(v,n)|0)|0)>>>14;b[e+(r<<1)>>1]=((ca(p,t)|0)+134225920+(ca(o,l)|0)+(ca(v,q)|0)|0)>>>14;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Kyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]<<8;m=c[l+16>>2]<<4;n=c[l+20>>2]|0;o=c[l+24>>2]<<8;p=c[l+28>>2]<<4;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(65)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(65)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&61680)+(v&61680)|0;u=t+v-l|0;v=u&7936;t=l&496;l=u&31;b[g+(r<<1)>>1]=((ca(m,t)|0)+134225920+(ca(f,l)|0)+(ca(v,n)|0)|0)>>>14;b[e+(r<<1)>>1]=((ca(p,t)|0)+134225920+(ca(o,l)|0)+(ca(v,q)|0)|0)>>>14;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Lyb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=n<<3;o=c[f+i>>2]|0;p=c[f+(i|4)>>2]|0;i=(p&-16711936)+(o&-16711936)|0;q=p+o-i|0;o=q>>>16&511;p=i&130816;i=q&511;b[g+(n<<1)>>1]=((ca(p,e)|0)-2147352576+((ca(o,j)|0)+(ca(i,d)|0)<<8)|0)>>>18;b[a+(n<<1)>>1]=((ca(p,l)|0)-2147352576+((ca(o,m)|0)+(ca(i,k)|0)<<8)|0)>>>18;n=n+1|0;}while((n|0)<(h|0));return}function Myb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=n<<3;o=(c[f+i>>2]|0)>>>8;p=(c[f+(i|4)>>2]|0)>>>8;i=(p&65280)+(o&65280)|0;q=p+o-i|0;o=q>>>16&511;p=q&511;b[g+(n<<1)>>1]=((ca(i,e)|0)-2147352576+((ca(o,j)|0)+(ca(p,d)|0)<<8)|0)>>>18;b[a+(n<<1)>>1]=((ca(i,l)|0)-2147352576+((ca(o,m)|0)+(ca(p,k)|0)<<8)|0)>>>18;n=n+1|0;}while((n|0)<(h|0));return}function Nyb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=a;a=e;e=c[j+12>>2]|0;f=c[j+16>>2]|0;k=c[j+20>>2]|0;l=c[j+24>>2]|0;m=c[j+28>>2]|0;n=c[j+32>>2]|0;if((i|0)>0){o=0}else{return}do{j=o*6|0;p=(d[g+(j+3)|0]|0)+(d[g+j|0]|0)|0;q=(d[g+(j+4)|0]|0)+(d[g+(j|1)|0]|0)|0;r=(d[g+(j+5)|0]|0)+(d[g+(j+2)|0]|0)|0;b[h+(o<<1)>>1]=((ca(p,e)|0)+8389120+(ca(q,f)|0)+(ca(r,k)|0)|0)>>>10;b[a+(o<<1)>>1]=((ca(p,l)|0)+8389120+(ca(q,m)|0)+(ca(r,n)|0)|0)>>>10;o=o+1|0;}while((o|0)<(i|0));return}function Oyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<11;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<11;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(44)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(44)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&2016)+(v&2016)|0;u=t+v-l|0;v=u&63;t=u&129024;b[g+(r<<1)>>1]=((ca(m,l)|0)-2147352576+(ca(t,f)|0)+(ca(n,v)|0)|0)>>>18;b[e+(r<<1)>>1]=((ca(p,l)|0)-2147352576+(ca(t,o)|0)+(ca(q,v)|0)|0)>>>18;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Pyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<11;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<11;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(43)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(43)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&2016)+(v&2016)|0;u=t+v-l|0;v=u&63;t=u&129024;b[g+(r<<1)>>1]=((ca(m,l)|0)-2147352576+(ca(t,f)|0)+(ca(n,v)|0)|0)>>>18;b[e+(r<<1)>>1]=((ca(p,l)|0)-2147352576+(ca(t,o)|0)+(ca(q,v)|0)|0)>>>18;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Qyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<10;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<10;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(46)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(46)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&33760)+(v&33760)|0;u=t+v-l|0;v=u&63;t=l&2016;l=u&64512;b[g+(r<<1)>>1]=((ca(m,t)|0)+1073807360+(ca(l,f)|0)+(ca(n,v)|0)|0)>>>17;b[e+(r<<1)>>1]=((ca(p,t)|0)+1073807360+(ca(l,o)|0)+(ca(q,v)|0)|0)>>>17;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Ryb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<10;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<10;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(45)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(45)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&33760)+(v&33760)|0;u=t+v-l|0;v=u&63;t=l&2016;l=u&64512;b[g+(r<<1)>>1]=((ca(m,t)|0)+1073807360+(ca(l,f)|0)+(ca(n,v)|0)|0)>>>17;b[e+(r<<1)>>1]=((ca(p,t)|0)+1073807360+(ca(l,o)|0)+(ca(q,v)|0)|0)>>>17;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Syb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<4;n=c[l+20>>2]<<8;o=c[l+24>>2]|0;p=c[l+28>>2]<<4;q=c[l+32>>2]<<8;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(62)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(62)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&61680)+(v&61680)|0;u=t+v-l|0;v=u&31;t=l&496;l=u&7936;b[g+(r<<1)>>1]=((ca(m,t)|0)+134225920+(ca(l,f)|0)+(ca(n,v)|0)|0)>>>14;b[e+(r<<1)>>1]=((ca(p,t)|0)+134225920+(ca(l,o)|0)+(ca(q,v)|0)|0)>>>14;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Tyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<4;n=c[l+20>>2]<<8;o=c[l+24>>2]|0;p=c[l+28>>2]<<4;q=c[l+32>>2]<<8;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(63)|0;if((l|0)==0){s=3;break}t=r<<2;u=h+t|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(63)|0;if((l|0)==0){s=7;break}u=h+(t|2)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){x=t}else{x=he(t|0)|0}t=x&65535;l=(t&61680)+(v&61680)|0;u=t+v-l|0;v=u&31;t=l&496;l=u&7936;b[g+(r<<1)>>1]=((ca(m,t)|0)+134225920+(ca(l,f)|0)+(ca(n,v)|0)|0)>>>14;b[e+(r<<1)>>1]=((ca(p,t)|0)+134225920+(ca(l,o)|0)+(ca(q,v)|0)|0)>>>14;v=r+1|0;if((v|0)<(k|0)){r=v}else{s=11;break}}if((s|0)==3){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==7){KIb(0,0,2414952,(y=i,i=i+24|0,c[y>>2]=2579616,c[y+8>>2]=2436328,c[y+16>>2]=653,y)|0);i=y;Hd()}else if((s|0)==11){i=j;return}}function Uyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(291)|0;if((l|0)==0){s=3;break}t=r<<2;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(291)|0;if((l|0)==0){s=7;break}u=g+((t|1)<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=he(x|0)|0}x=y&65535;l=qKb(291)|0;if((l|0)==0){s=11;break}u=g+((t|2)<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=he(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ca(v,f)|0)+1073758208+(ca(x,m)|0)+(ca(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(v,o)|0)+1073758208+(ca(x,p)|0)+(ca(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==7){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==11){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==15){i=j;return}}function Vyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(292)|0;if((l|0)==0){s=3;break}t=r<<2;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(292)|0;if((l|0)==0){s=7;break}u=g+((t|1)<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=he(x|0)|0}x=y&65535;l=qKb(292)|0;if((l|0)==0){s=11;break}u=g+((t|2)<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=he(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ca(v,f)|0)+1073758208+(ca(x,m)|0)+(ca(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(v,o)|0)+1073758208+(ca(x,p)|0)+(ca(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==7){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==11){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==15){i=j;return}}function Wyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(41)|0;if((l|0)==0){s=3;break}t=r*3|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(41)|0;if((l|0)==0){s=7;break}u=g+(t+1<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=he(x|0)|0}x=y&65535;l=qKb(41)|0;if((l|0)==0){s=11;break}u=g+(t+2<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=he(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ca(v,f)|0)+1073758208+(ca(x,m)|0)+(ca(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(v,o)|0)+1073758208+(ca(x,p)|0)+(ca(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==7){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==11){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==15){i=j;return}}function Xyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(42)|0;if((l|0)==0){s=3;break}t=r*3|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(42)|0;if((l|0)==0){s=7;break}u=g+(t+1<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=he(x|0)|0}x=y&65535;l=qKb(42)|0;if((l|0)==0){s=11;break}u=g+(t+2<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=he(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ca(v,f)|0)+1073758208+(ca(x,m)|0)+(ca(t,n)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(v,o)|0)+1073758208+(ca(x,p)|0)+(ca(t,q)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==7){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==11){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==15){i=j;return}}function Yyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(67)|0;if((l|0)==0){s=3;break}t=r*3|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(67)|0;if((l|0)==0){s=7;break}u=g+(t+1<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=he(x|0)|0}x=y&65535;l=qKb(67)|0;if((l|0)==0){s=11;break}u=g+(t+2<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=he(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ca(v,n)|0)+1073758208+(ca(x,m)|0)+(ca(t,f)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(v,q)|0)+1073758208+(ca(x,p)|0)+(ca(t,o)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==7){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==11){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==15){i=j;return}}function Zyb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;g=h;h=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]|0;n=c[l+20>>2]|0;o=c[l+24>>2]|0;p=c[l+28>>2]|0;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(68)|0;if((l|0)==0){s=3;break}t=r*3|0;u=g+(t<<1)|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){w=v}else{w=he(v|0)|0}v=w&65535;l=qKb(68)|0;if((l|0)==0){s=7;break}u=g+(t+1<<1)|0;x=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){y=x}else{y=he(x|0)|0}x=y&65535;l=qKb(68)|0;if((l|0)==0){s=11;break}u=g+(t+2<<1)|0;t=(d[u]|d[u+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){z=t}else{z=he(t|0)|0}t=z&65535;b[h+(r<<1)>>1]=((ca(v,n)|0)+1073758208+(ca(x,m)|0)+(ca(t,f)|0)|0)>>>15;b[e+(r<<1)>>1]=((ca(v,q)|0)+1073758208+(ca(x,p)|0)+(ca(t,o)|0)|0)>>>15;t=r+1|0;if((t|0)<(k|0)){r=t}else{s=15;break}}if((s|0)==3){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==7){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==11){KIb(0,0,2414952,(A=i,i=i+24|0,c[A>>2]=2579616,c[A+8>>2]=2436328,c[A+16>>2]=653,A)|0);i=A;Hd()}else if((s|0)==15){i=j;return}}function _yb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=c[f+(n<<2)>>2]|0;o=i&255;p=i&65280;q=i>>>16&255;b[g+(n<<1)>>1]=((ca(p,e)|0)+1073807360+((ca(q,d)|0)+(ca(o,j)|0)<<8)|0)>>>17;b[a+(n<<1)>>1]=((ca(p,l)|0)+1073807360+((ca(q,k)|0)+(ca(o,m)|0)<<8)|0)>>>17;n=n+1|0;}while((n|0)<(h|0));return}function $yb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=c[f+(n<<2)>>2]|0;o=i>>>8;p=o&255;q=o&65280;o=i>>>24;b[g+(n<<1)>>1]=((ca(q,e)|0)+1073807360+((ca(p,j)|0)+(ca(o,d)|0)<<8)|0)>>>17;b[a+(n<<1)>>1]=((ca(q,l)|0)+1073807360+((ca(p,m)|0)+(ca(o,k)|0)<<8)|0)>>>17;n=n+1|0;}while((n|0)<(h|0));return}function azb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=a;a=e;e=c[j+12>>2]|0;f=c[j+16>>2]|0;k=c[j+20>>2]|0;l=c[j+24>>2]|0;m=c[j+28>>2]|0;n=c[j+32>>2]|0;if((i|0)>0){o=0}else{return}do{j=o*3|0;p=d[g+j|0]|0;q=d[g+(j+1)|0]|0;r=d[g+(j+2)|0]|0;b[h+(o<<1)>>1]=((ca(p,k)|0)+4194560+(ca(q,f)|0)+(ca(r,e)|0)|0)>>>9;b[a+(o<<1)>>1]=((ca(p,n)|0)+4194560+(ca(q,m)|0)+(ca(r,l)|0)|0)>>>9;o=o+1|0;}while((o|0)<(i|0));return}function bzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<11;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<11;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(48)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&63488;t=u&2016;w=u&31;b[g+(r<<1)>>1]=((ca(m,t)|0)+1073807360+(ca(f,w)|0)+(ca(l,n)|0)|0)>>>17;b[e+(r<<1)>>1]=((ca(p,t)|0)+1073807360+(ca(o,w)|0)+(ca(l,q)|0)|0)>>>17;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function czb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<11;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<11;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(47)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&63488;t=u&2016;w=u&31;b[g+(r<<1)>>1]=((ca(m,t)|0)+1073807360+(ca(f,w)|0)+(ca(l,n)|0)|0)>>>17;b[e+(r<<1)>>1]=((ca(p,t)|0)+1073807360+(ca(o,w)|0)+(ca(l,q)|0)|0)>>>17;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function dzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<10;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<10;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(50)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&31744;t=u&992;w=u&31;b[g+(r<<1)>>1]=((ca(m,t)|0)+536903680+(ca(f,w)|0)+(ca(l,n)|0)|0)>>>16;b[e+(r<<1)>>1]=((ca(p,t)|0)+536903680+(ca(o,w)|0)+(ca(l,q)|0)|0)>>>16;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function ezb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<10;m=c[l+16>>2]<<5;n=c[l+20>>2]|0;o=c[l+24>>2]<<10;p=c[l+28>>2]<<5;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(49)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&31744;t=u&992;w=u&31;b[g+(r<<1)>>1]=((ca(m,t)|0)+536903680+(ca(f,w)|0)+(ca(l,n)|0)|0)>>>16;b[e+(r<<1)>>1]=((ca(p,t)|0)+536903680+(ca(o,w)|0)+(ca(l,q)|0)|0)>>>16;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function fzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<8;m=c[l+16>>2]<<4;n=c[l+20>>2]|0;o=c[l+24>>2]<<8;p=c[l+28>>2]<<4;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(64)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&3840;t=u&240;w=u&15;b[g+(r<<1)>>1]=((ca(m,t)|0)+67112960+(ca(f,w)|0)+(ca(l,n)|0)|0)>>>13;b[e+(r<<1)>>1]=((ca(p,t)|0)+67112960+(ca(o,w)|0)+(ca(l,q)|0)|0)>>>13;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function gzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]<<8;m=c[l+16>>2]<<4;n=c[l+20>>2]|0;o=c[l+24>>2]<<8;p=c[l+28>>2]<<4;q=c[l+32>>2]|0;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(65)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&3840;t=u&240;w=u&15;b[g+(r<<1)>>1]=((ca(m,t)|0)+67112960+(ca(f,w)|0)+(ca(l,n)|0)|0)>>>13;b[e+(r<<1)>>1]=((ca(p,t)|0)+67112960+(ca(o,w)|0)+(ca(l,q)|0)|0)>>>13;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function hzb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=c[f+(n<<2)>>2]|0;o=i>>>16&255;p=i&65280;q=i&255;b[g+(n<<1)>>1]=((ca(p,e)|0)+1073807360+((ca(o,j)|0)+(ca(q,d)|0)<<8)|0)>>>17;b[a+(n<<1)>>1]=((ca(p,l)|0)+1073807360+((ca(o,m)|0)+(ca(q,k)|0)<<8)|0)>>>17;n=n+1|0;}while((n|0)<(h|0));return}function izb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=a;a=d;d=c[i+12>>2]|0;e=c[i+16>>2]|0;j=c[i+20>>2]|0;k=c[i+24>>2]|0;l=c[i+28>>2]|0;m=c[i+32>>2]|0;if((h|0)>0){n=0}else{return}do{i=c[f+(n<<2)>>2]|0;o=i>>>8;p=i>>>24;i=o&65280;q=o&255;b[g+(n<<1)>>1]=((ca(i,e)|0)+1073807360+((ca(q,d)|0)+(ca(p,j)|0)<<8)|0)>>>17;b[a+(n<<1)>>1]=((ca(i,l)|0)+1073807360+((ca(q,k)|0)+(ca(p,m)|0)<<8)|0)>>>17;n=n+1|0;}while((n|0)<(h|0));return}function jzb(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=a;a=e;e=c[j+12>>2]|0;f=c[j+16>>2]|0;k=c[j+20>>2]|0;l=c[j+24>>2]|0;m=c[j+28>>2]|0;n=c[j+32>>2]|0;if((i|0)>0){o=0}else{return}do{j=o*3|0;p=d[g+j|0]|0;q=d[g+(j+1)|0]|0;r=d[g+(j+2)|0]|0;b[h+(o<<1)>>1]=((ca(p,e)|0)+4194560+(ca(q,f)|0)+(ca(r,k)|0)|0)>>>9;b[a+(o<<1)>>1]=((ca(p,l)|0)+4194560+(ca(q,m)|0)+(ca(r,n)|0)|0)>>>9;o=o+1|0;}while((o|0)<(i|0));return}function kzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<11;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<11;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(44)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&31;t=u&2016;w=u&63488;b[g+(r<<1)>>1]=((ca(m,t)|0)+1073807360+(ca(w,f)|0)+(ca(n,l)|0)|0)>>>17;b[e+(r<<1)>>1]=((ca(p,t)|0)+1073807360+(ca(w,o)|0)+(ca(q,l)|0)|0)>>>17;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function lzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<11;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<11;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(43)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&31;t=u&2016;w=u&63488;b[g+(r<<1)>>1]=((ca(m,t)|0)+1073807360+(ca(w,f)|0)+(ca(n,l)|0)|0)>>>17;b[e+(r<<1)>>1]=((ca(p,t)|0)+1073807360+(ca(w,o)|0)+(ca(q,l)|0)|0)>>>17;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function mzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<10;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<10;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(46)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&31;t=u&992;w=u&31744;b[g+(r<<1)>>1]=((ca(m,t)|0)+536903680+(ca(w,f)|0)+(ca(n,l)|0)|0)>>>16;b[e+(r<<1)>>1]=((ca(p,t)|0)+536903680+(ca(w,o)|0)+(ca(q,l)|0)|0)>>>16;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function nzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<5;n=c[l+20>>2]<<10;o=c[l+24>>2]|0;p=c[l+28>>2]<<5;q=c[l+32>>2]<<10;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(45)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&31;t=u&992;w=u&31744;b[g+(r<<1)>>1]=((ca(m,t)|0)+536903680+(ca(w,f)|0)+(ca(n,l)|0)|0)>>>16;b[e+(r<<1)>>1]=((ca(p,t)|0)+536903680+(ca(w,o)|0)+(ca(q,l)|0)|0)>>>16;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function ozb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<4;n=c[l+20>>2]<<8;o=c[l+24>>2]|0;p=c[l+28>>2]<<4;q=c[l+32>>2]<<8;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(62)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&15;t=u&240;w=u&3840;b[g+(r<<1)>>1]=((ca(m,t)|0)+67112960+(ca(w,f)|0)+(ca(n,l)|0)|0)>>>13;b[e+(r<<1)>>1]=((ca(p,t)|0)+67112960+(ca(w,o)|0)+(ca(q,l)|0)|0)>>>13;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function pzb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;g=e;e=f;f=c[l+12>>2]|0;m=c[l+16>>2]<<4;n=c[l+20>>2]<<8;o=c[l+24>>2]|0;p=c[l+28>>2]<<4;q=c[l+32>>2]<<8;if((k|0)>0){r=0}else{i=j;return}while(1){l=qKb(63)|0;if((l|0)==0){s=3;break}t=h+(r<<1)|0;u=(d[t]|d[t+1|0]<<8)<<16>>16;if((a[l+7|0]&1)==0){v=u}else{v=he(u|0)|0}u=v&65535;l=u&15;t=u&240;w=u&3840;b[g+(r<<1)>>1]=((ca(m,t)|0)+67112960+(ca(w,f)|0)+(ca(n,l)|0)|0)>>>13;b[e+(r<<1)>>1]=((ca(p,t)|0)+67112960+(ca(w,o)|0)+(ca(q,l)|0)|0)>>>13;l=r+1|0;if((l|0)<(k|0)){r=l}else{s=7;break}}if((s|0)==3){KIb(0,0,2414952,(r=i,i=i+24|0,c[r>>2]=2579616,c[r+8>>2]=2436328,c[r+16>>2]=653,r)|0);i=r;Hd()}else if((s|0)==7){i=j;return}}function qzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+1081344+(ca((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ca((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>10;l=l+1|0;}while((l|0)<(f|0));return}function rzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+2162688+(ca((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ca((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>11;l=l+1|0;}while((l|0)<(f|0));return}function szb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+8650752+(ca((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ca((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>13;l=l+1|0;}while((l|0)<(f|0));return}function tzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+34603008+(ca((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ca((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>15;l=l+1|0;}while((l|0)<(f|0));return}function uzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=(c[a>>2]|0)+(l<<1)|0;o=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca((d[m]|d[m+1|0]<<8)<<16>>16&65535,i)|0)+138412032+(ca((d[n]|d[n+1|0]<<8)<<16>>16&65535,j)|0)+(ca((d[o]|d[o+1|0]<<8)<<16>>16&65535,h)|0)|0)>>>15;l=l+1|0;}while((l|0)<(f|0));return}function vzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca(n&65535,i)|0)+1081344+(ca(o&65535,j)|0)+(ca((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>10;l=l+1|0;}while((l|0)<(f|0));return}function wzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca(n&65535,i)|0)+2162688+(ca(o&65535,j)|0)+(ca((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>11;l=l+1|0;}while((l|0)<(f|0));return}function xzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca(n&65535,i)|0)+8650752+(ca(o&65535,j)|0)+(ca((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>13;l=l+1|0;}while((l|0)<(f|0));return}function yzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca(n&65535,i)|0)+34603008+(ca(o&65535,j)|0)+(ca((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>15;l=l+1|0;}while((l|0)<(f|0));return}function zzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;g=a;if((f|0)<=0){return}a=e+4|0;k=e+8|0;l=0;do{m=(c[e>>2]|0)+(l<<1)|0;n=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[a>>2]|0)+(l<<1)|0;o=he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0;m=(c[k>>2]|0)+(l<<1)|0;b[g+(l<<1)>>1]=((ca(n&65535,i)|0)+138412032+(ca(o&65535,j)|0)+(ca((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535,h)|0)|0)>>>15;l=l+1|0;}while((l|0)<(f|0));return}function Azb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;g=a;if((f|0)<=0){return}a=c[e+12>>2]|0;e=0;do{b[g+(e<<1)>>1]=(d[a+e|0]|0)<<6;e=e+1|0;}while((e|0)<(f|0));return}function Bzb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=a;a=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;if((f|0)<=0){return}g=c[e>>2]|0;k=c[e+4>>2]|0;l=c[e+8>>2]|0;e=0;do{b[h+(e<<1)>>1]=((ca(d[g+e|0]|0,i)|0)+524544+(ca(d[k+e|0]|0,j)|0)+(ca(d[l+e|0]|0,a)|0)|0)>>>9;e=e+1|0;}while((e|0)<(f|0));return}function Czb(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=c;c=a;if((f|0)>0){h=0}else{return}do{b[c+(h<<1)>>1]=he(b[g+(h<<1)>>1]|0)|0;h=h+1|0;}while((h|0)<(f|0));return}function Dzb(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;if((f|0)>0){h=0}else{return}do{a[b+h|0]=a[c+(h<<1)|0]|0;h=h+1|0;}while((h|0)<(f|0));return}function Ezb(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;if((f|0)>0){h=0}else{return}do{a[b+h|0]=a[c+(h<<1|1)|0]|0;h=h+1|0;}while((h|0)<(f|0));return}function Fzb(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;g=a;a=c[i>>2]|0;f=c[i+4>>2]|0;j=c[i+8>>2]|0;if((h|0)>0){k=0}else{return}do{i=k*3|0;b[g+(k<<1)>>1]=((ca(d[e+i|0]|0,j)|0)+524544+(ca(d[e+(i+1)|0]|0,f)|0)+(ca(d[e+(i+2)|0]|0,a)|0)|0)>>>9;k=k+1|0;}while((k|0)<(h|0));return}function Gzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<11;m=c[k+4>>2]<<5;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(48)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(m,q&2016)|0)+134283264+(ca(l,q&31)|0)+(ca(q&63488,e)|0)|0)>>>17;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Hzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<11;m=c[k+4>>2]<<5;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(47)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(m,q&2016)|0)+134283264+(ca(l,q&31)|0)+(ca(q&63488,e)|0)|0)>>>17;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Izb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<10;m=c[k+4>>2]<<5;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(50)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(m,q&992)|0)+67141632+(ca(l,q&31)|0)+(ca(q&31744,e)|0)|0)>>>16;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Jzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<10;m=c[k+4>>2]<<5;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(49)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(m,q&992)|0)+67141632+(ca(l,q&31)|0)+(ca(q&31744,e)|0)|0)>>>16;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Kzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<8;m=c[k+4>>2]<<4;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(64)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(m,q&240)|0)+8392704+(ca(l,q&15)|0)+(ca(q&3840,e)|0)|0)>>>13;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Lzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k+8>>2]|0;l=c[k>>2]<<8;m=c[k+4>>2]<<4;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(65)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(m,q&240)|0)+8392704+(ca(l,q&15)|0)+(ca(q&3840,e)|0)|0)>>>13;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Mzb(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;g=a;a=c[i>>2]|0;f=c[i+4>>2]|0;j=c[i+8>>2]|0;if((h|0)>0){k=0}else{return}do{i=k*3|0;b[g+(k<<1)>>1]=((ca(d[e+i|0]|0,a)|0)+524544+(ca(d[e+(i+1)|0]|0,f)|0)+(ca(d[e+(i+2)|0]|0,j)|0)|0)>>>9;k=k+1|0;}while((k|0)<(h|0));return}function Nzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<5;m=c[k+8>>2]<<11;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(44)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(l,q&2016)|0)+134283264+(ca(q&63488,e)|0)+(ca(m,q&31)|0)|0)>>>17;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Ozb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<5;m=c[k+8>>2]<<11;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(43)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(l,q&2016)|0)+134283264+(ca(q&63488,e)|0)+(ca(m,q&31)|0)|0)>>>17;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Pzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<5;m=c[k+8>>2]<<10;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(46)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(l,q&992)|0)+67141632+(ca(q&31744,e)|0)+(ca(m,q&31)|0)|0)>>>16;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Qzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<5;m=c[k+8>>2]<<10;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(45)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(l,q&992)|0)+67141632+(ca(q&31744,e)|0)+(ca(m,q&31)|0)|0)>>>16;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Rzb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<4;m=c[k+8>>2]<<8;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(62)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(l,q&240)|0)+8392704+(ca(q&3840,e)|0)+(ca(m,q&15)|0)|0)>>>13;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Szb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;g=e;e=c[k>>2]|0;l=c[k+4>>2]<<4;m=c[k+8>>2]<<8;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(63)|0;if((k|0)==0){o=3;break}p=f+(n<<1)|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){r=q}else{r=he(q|0)|0}q=r&65535;b[g+(n<<1)>>1]=((ca(l,q&240)|0)+8392704+(ca(q&3840,e)|0)+(ca(m,q&15)|0)|0)>>>13;q=n+1|0;if((q|0)<(j|0)){n=q}else{o=7;break}}if((o|0)==3){KIb(0,0,2414952,(n=i,i=i+24|0,c[n>>2]=2579616,c[n+8>>2]=2436328,c[n+16>>2]=653,n)|0);i=n;Hd()}else if((o|0)==7){i=h;return}}function Tzb(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0;g=a;if((h|0)>0){j=0}else{return}do{b[g+(j<<1)>>1]=c[i+((d[e+j|0]|0)<<2)>>2]<<6&16320;j=j+1|0;}while((j|0)<(h|0));return}function Uzb(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=a;a=g+7>>3;if((a|0)>0){g=0;while(1){f=d[c+g|0]|0;e=g<<3;b[h+(e<<1)>>1]=-(f>>>7)&16383;b[h+((e|1)<<1)>>1]=-(f>>>6&1)&16383;b[h+((e|2)<<1)>>1]=-(f>>>5&1)&16383;b[h+((e|3)<<1)>>1]=-(f>>>4&1)&16383;b[h+((e|4)<<1)>>1]=-(f>>>3&1)&16383;b[h+((e|5)<<1)>>1]=-(f>>>2&1)&16383;b[h+((e|6)<<1)>>1]=-(f>>>1&1)&16383;b[h+((e|7)<<1)>>1]=-(f&1)&16383;f=g+1|0;if((f|0)<(a|0)){g=f}else{i=a;break}}}else{i=0}g=a&7;if((g|0)==0){return}a=d[c+i|0]|0;c=i<<3;i=0;do{b[h+(i+c<<1)>>1]=-(a>>>((7-i|0)>>>0)&1)&16383;i=i+1|0;}while((i|0)<(g|0));return}function Vzb(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=a;a=g+7>>3;if((a|0)>0){g=0;while(1){f=~(d[c+g|0]|0);e=g<<3;b[h+(e<<1)>>1]=-(f>>>7&1)&16383;b[h+((e|1)<<1)>>1]=-(f>>>6&1)&16383;b[h+((e|2)<<1)>>1]=-(f>>>5&1)&16383;b[h+((e|3)<<1)>>1]=-(f>>>4&1)&16383;b[h+((e|4)<<1)>>1]=-(f>>>3&1)&16383;b[h+((e|5)<<1)>>1]=-(f>>>2&1)&16383;b[h+((e|6)<<1)>>1]=-(f>>>1&1)&16383;b[h+((e|7)<<1)>>1]=-(f&1)&16383;f=g+1|0;if((f|0)<(a|0)){g=f}else{i=a;break}}}else{i=0}g=a&7;if((g|0)==0){return}a=~(d[c+i|0]|0);c=i<<3;i=0;do{b[h+(i+c<<1)>>1]=-(a>>>((7-i|0)>>>0)&1)&16383;i=i+1|0;}while((i|0)<(g|0));return}function Wzb(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;f=a;a=c[h>>2]|0;e=c[h+4>>2]|0;i=c[h+8>>2]|0;if((g|0)>0){j=0}else{return}do{h=c[d+(j<<2)>>2]|0;b[f+(j<<1)>>1]=((ca(h&65280,e)|0)+134283264+((ca(h>>>16&255,a)|0)+(ca(h&255,i)|0)<<8)|0)>>>17;j=j+1|0;}while((j|0)<(g|0));return}function Xzb(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;f=a;a=c[h>>2]|0;e=c[h+4>>2]|0;i=c[h+8>>2]|0;if((g|0)>0){j=0}else{return}do{h=c[d+(j<<2)>>2]|0;k=h>>>8;b[f+(j<<1)>>1]=((ca(k&65280,e)|0)+134283264+((ca(k&255,i)|0)+(ca(h>>>24,a)|0)<<8)|0)>>>17;j=j+1|0;}while((j|0)<(g|0));return}function Yzb(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;f=a;a=c[h>>2]|0;e=c[h+4>>2]|0;i=c[h+8>>2]|0;if((g|0)>0){j=0}else{return}do{h=c[d+(j<<2)>>2]|0;b[f+(j<<1)>>1]=((ca(h&65280,e)|0)+134283264+((ca(h>>>16&255,i)|0)+(ca(h&255,a)|0)<<8)|0)>>>17;j=j+1|0;}while((j|0)<(g|0));return}function Zzb(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;f=a;a=c[h>>2]|0;e=c[h+4>>2]|0;i=c[h+8>>2]|0;if((g|0)>0){j=0}else{return}do{h=c[d+(j<<2)>>2]|0;k=h>>>8;b[f+(j<<1)>>1]=((ca(k&65280,e)|0)+134283264+((ca(k&255,a)|0)+(ca(h>>>24,i)|0)<<8)|0)>>>17;j=j+1|0;}while((j|0)<(g|0));return}function _zb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(41)|0;if((k|0)==0){o=3;break}p=n*3|0;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=he(r|0)|0}r=qKb(41)|0;if((r|0)==0){o=7;break}k=g+(p+1<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=he(q|0)|0}q=qKb(41)|0;if((q|0)==0){o=11;break}r=g+(p+2<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=he(p|0)|0}b[f+(n<<1)>>1]=((ca(s&65535,e)|0)+134234112+(ca(t&65535,l)|0)+(ca(u&65535,m)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==7){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==11){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==15){i=h;return}}function $zb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(42)|0;if((k|0)==0){o=3;break}p=n*3|0;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=he(r|0)|0}r=qKb(42)|0;if((r|0)==0){o=7;break}k=g+(p+1<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=he(q|0)|0}q=qKb(42)|0;if((q|0)==0){o=11;break}r=g+(p+2<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=he(p|0)|0}b[f+(n<<1)>>1]=((ca(s&65535,e)|0)+134234112+(ca(t&65535,l)|0)+(ca(u&65535,m)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==7){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==11){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==15){i=h;return}}function aAb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(67)|0;if((k|0)==0){o=3;break}p=n*3|0;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=he(r|0)|0}r=qKb(67)|0;if((r|0)==0){o=7;break}k=g+(p+1<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=he(q|0)|0}q=qKb(67)|0;if((q|0)==0){o=11;break}r=g+(p+2<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=he(p|0)|0}b[f+(n<<1)>>1]=((ca(s&65535,m)|0)+134234112+(ca(t&65535,l)|0)+(ca(u&65535,e)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==7){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==11){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==15){i=h;return}}function bAb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(68)|0;if((k|0)==0){o=3;break}p=n*3|0;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=he(r|0)|0}r=qKb(68)|0;if((r|0)==0){o=7;break}k=g+(p+1<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=he(q|0)|0}q=qKb(68)|0;if((q|0)==0){o=11;break}r=g+(p+2<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=he(p|0)|0}b[f+(n<<1)>>1]=((ca(s&65535,m)|0)+134234112+(ca(t&65535,l)|0)+(ca(u&65535,e)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==7){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==11){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==15){i=h;return}}function cAb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(291)|0;if((k|0)==0){o=3;break}p=n<<2;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=he(r|0)|0}r=qKb(291)|0;if((r|0)==0){o=7;break}k=g+((p|1)<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=he(q|0)|0}q=qKb(291)|0;if((q|0)==0){o=11;break}r=g+((p|2)<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=he(p|0)|0}b[f+(n<<1)>>1]=((ca(s&65535,e)|0)+134234112+(ca(t&65535,l)|0)+(ca(u&65535,m)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==7){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==11){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==15){i=h;return}}function dAb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;g=f;f=e;e=c[k>>2]|0;l=c[k+4>>2]|0;m=c[k+8>>2]|0;if((j|0)>0){n=0}else{i=h;return}while(1){k=qKb(292)|0;if((k|0)==0){o=3;break}p=n<<2;q=g+(p<<1)|0;r=(d[q]|d[q+1|0]<<8)<<16>>16;if((a[k+7|0]&1)==0){s=r}else{s=he(r|0)|0}r=qKb(292)|0;if((r|0)==0){o=7;break}k=g+((p|1)<<1)|0;q=(d[k]|d[k+1|0]<<8)<<16>>16;if((a[r+7|0]&1)==0){t=q}else{t=he(q|0)|0}q=qKb(292)|0;if((q|0)==0){o=11;break}r=g+((p|2)<<1)|0;p=(d[r]|d[r+1|0]<<8)<<16>>16;if((a[q+7|0]&1)==0){u=p}else{u=he(p|0)|0}b[f+(n<<1)>>1]=((ca(s&65535,e)|0)+134234112+(ca(t&65535,l)|0)+(ca(u&65535,m)|0)|0)>>>15;p=n+1|0;if((p|0)<(j|0)){n=p}else{o=15;break}}if((o|0)==3){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==7){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==11){KIb(0,0,2414952,(v=i,i=i+24|0,c[v>>2]=2579616,c[v+8>>2]=2436328,c[v+16>>2]=653,v)|0);i=v;Hd()}else if((o|0)==15){i=h;return}}function eAb(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=a;a=c;if((f|0)>0){h=0}else{return}do{b[g+(h<<1)>>1]=b[a+((h<<2|3)<<1)>>1]|0;h=h+1|0;}while((h|0)<(f|0));return}function fAb(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=a;if((g|0)>0){i=0}else{return}do{b[h+(i<<1)>>1]=(d[c+(i<<2|3)|0]|0)<<6;i=i+1|0;}while((i|0)<(g|0));return}function gAb(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;h=a;if((g|0)>0){i=0}else{return}do{b[h+(i<<1)>>1]=(d[c+(i<<2)|0]|0)<<6;i=i+1|0;}while((i|0)<(g|0));return}function hAb(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0;g=a;if((h|0)>0){j=0}else{return}do{b[g+(j<<1)>>1]=(c[i+((d[e+j|0]|0)<<2)>>2]|0)>>>24<<6;j=j+1|0;}while((j|0)<(h|0));return}function iAb(d,f,g,h,j,k,l,m){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=i;o=c[d+52>>2]|0;p=qKb(o)|0;q=qKb(o)|0;if((q|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=637,r)|0);i=r;Hd()}s=(b[q+8>>1]&30720)==30720;q=qKb(o)|0;t=(q|0)==0;do{if(s){if(t){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}c[g>>2]=(a[q+7|0]&1)!=0?482:678;u=qKb(o)|0;if((u|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}else{c[f>>2]=(a[u+7|0]&1)!=0?352:344;break}}else{if(t){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=644,r)|0);i=r;Hd()}if(!((((e[q+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0)){c[f>>2]=496;c[g>>2]=24;if(!((o-25|0)>>>0<2>>>0)){break}c[h>>2]=70;break}u=(e[p+8>>1]|0)>>>11&15;if((u<<16>>16|0)==9){v=qKb(o)|0;if((v|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}c[g>>2]=(a[v+7|0]&1)!=0?654:86;v=qKb(o)|0;if((v|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}else{c[f>>2]=(a[v+7|0]&1)!=0?652:450;break}}else if((u<<16>>16|0)==11){v=qKb(o)|0;if((v|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}c[g>>2]=(a[v+7|0]&1)!=0?508:112;v=qKb(o)|0;if((v|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}else{c[f>>2]=(a[v+7|0]&1)!=0?472:304;break}}else if((u<<16>>16|0)==8){v=qKb(o)|0;if((v|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}c[g>>2]=(a[v+7|0]&1)!=0?680:266;v=qKb(o)|0;if((v|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}else{c[f>>2]=(a[v+7|0]&1)!=0?646:236;break}}else if((u<<16>>16|0)==13){u=qKb(o)|0;if((u|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}c[g>>2]=(a[u+7|0]&1)!=0?288:176;u=qKb(o)|0;if((u|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}else{c[f>>2]=(a[u+7|0]&1)!=0?562:300;break}}else{KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2579600,c[r+8>>2]=2436304,c[r+16>>2]=1829,r)|0);i=r;Hd()}}}while(0);do{if((c[d+2284>>2]&8192|0)==0){w=59}else{a:do{switch(o|0){case 27:{if((c[d+2180>>2]|0)==0){c[l>>2]=82;c[k>>2]=70;c[j>>2]=68;break a}else{c[l>>2]=74;c[k>>2]=52;c[j>>2]=148;break a}break};case 21:{c[l>>2]=28;c[k>>2]=4;c[j>>2]=110;break};case 24:{c[l>>2]=2;c[k>>2]=20;c[j>>2]=64;break};case 19:{c[l>>2]=48;c[k>>2]=82;c[j>>2]=28;break};case 29:{if((c[d+2180>>2]|0)==0){c[l>>2]=50;c[k>>2]=16;c[j>>2]=58;break a}else{c[l>>2]=22;c[k>>2]=44;c[j>>2]=130;break a}break};case 30:{if((c[d+2180>>2]|0)==0){c[l>>2]=80;c[k>>2]=12;c[j>>2]=34;break a}else{c[l>>2]=6;c[k>>2]=74;c[j>>2]=20;break a}break};case 22:{c[l>>2]=56;c[k>>2]=18;c[j>>2]=14;break};case 82:case 83:case 84:case 85:case 86:case 313:case 314:case 315:case 316:case 87:case 88:case 317:{c[m>>2]=20;break};case 28:{if((c[d+2180>>2]|0)==0){c[l>>2]=34;c[k>>2]=88;c[j>>2]=94;break a}else{c[l>>2]=64;c[k>>2]=36;c[j>>2]=44;break a}break};case 2:{c[l>>2]=44;c[k>>2]=24;c[j>>2]=104;break};case 3:{c[l>>2]=8;c[k>>2]=92;c[j>>2]=60;break};default:{}}}while(0);if((c[l>>2]|0)!=0){w=84;break}if((c[m>>2]|0)==0){w=59}else{w=84}}}while(0);b:do{if((w|0)==59){switch(o|0){case 292:{if((c[d+2180>>2]|0)==0){c[j>>2]=76;c[k>>2]=84;c[l>>2]=52;w=84;break b}c[j>>2]=126;c[k>>2]=28;c[l>>2]=84;i=n;return};case 42:{c[j>>2]=70;c[k>>2]=30;c[l>>2]=36;i=n;return};case 68:{c[j>>2]=162;c[k>>2]=32;c[l>>2]=4;i=n;return};case 44:case 43:case 48:case 47:{c[j>>2]=4;c[k>>2]=38;c[l>>2]=58;w=84;break b;break};case 46:case 45:case 50:case 49:{c[j>>2]=112;c[k>>2]=26;c[l>>2]=42;w=84;break b;break};case 1:{w=87;break b;break};case 30:case 28:{if((c[d+2180>>2]|0)==0){c[j>>2]=166;c[k>>2]=90;c[l>>2]=54;w=84;break b}else{c[j>>2]=2;c[k>>2]=10;c[l>>2]=30;w=84;break b}break};case 17:{w=88;break b;break};case 291:{if((c[d+2180>>2]|0)==0){c[j>>2]=84;c[k>>2]=96;c[l>>2]=12;w=84;break b}c[j>>2]=38;c[k>>2]=100;c[l>>2]=76;i=n;return};case 29:case 27:{if((c[d+2180>>2]|0)==0){c[j>>2]=22;c[k>>2]=2;c[l>>2]=72;w=84;break b}else{c[j>>2]=124;c[k>>2]=76;c[l>>2]=32;w=84;break b}break};case 9:{w=85;break b;break};case 22:case 19:{c[j>>2]=96;c[k>>2]=68;c[l>>2]=60;w=84;break b;break};case 41:{c[j>>2]=100;c[k>>2]=48;c[l>>2]=24;i=n;return};case 23:case 20:{c[j>>2]=12;c[k>>2]=60;c[l>>2]=38;w=84;break b;break};case 67:{c[j>>2]=56;c[k>>2]=66;c[l>>2]=40;i=n;return};case 62:case 63:case 64:case 65:{c[j>>2]=144;c[k>>2]=86;c[l>>2]=10;w=84;break b;break};case 24:case 21:{c[j>>2]=62;c[k>>2]=94;c[l>>2]=46;w=84;break b;break};case 10:{w=86;break b;break};case 2:{c[j>>2]=150;c[k>>2]=46;c[l>>2]=78;i=n;return};case 3:{c[j>>2]=52;c[k>>2]=78;c[l>>2]=66;i=n;return};default:{i=n;return}}}}while(0);do{if((w|0)==84){if((o|0)==1){w=87;break}else if((o|0)==17){w=88;break}else if((o|0)==9){w=85;break}else if((o|0)==10){w=86;break}i=n;return}}while(0);if((w|0)==85){c[j>>2]=16;c[k>>2]=104;c[l>>2]=26;i=n;return}else if((w|0)==86){c[j>>2]=102;c[k>>2]=102;c[l>>2]=68;i=n;return}else if((w|0)==87){c[j>>2]=170;c[k>>2]=58;c[l>>2]=70;i=n;return}else if((w|0)==88){c[j>>2]=152;c[k>>2]=98;c[l>>2]=62;i=n;return}}function jAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;j=g;if((h|0)<=0){return}if((e|0)>0){k=0}else{mrc(g|0,0,h<<1|0)|0;return}do{g=-1073725440;i=0;do{g=(ca(b[d+(i<<1)>>1]|0,c[(c[f+(i<<2)>>2]|0)+(k<<2)>>2]|0)|0)+g|0;i=i+1|0;}while((i|0)<(e|0));i=g>>15;if((i+32768|0)>>>0>65535>>>0){l=(g>>31^32767)&65535}else{l=i&65535}i=j+(k<<1)|0;y=he(l^-32768|0)|0;a[i]=y;y=y>>8;a[i+1|0]=y;k=k+1|0;}while((k|0)<(h|0));return}function kAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;j=g;if((h|0)<=0){return}if((e|0)>0){k=0}else{mrc(g|0,0,h<<1|0)|0;return}do{g=-1073725440;i=0;do{g=(ca(b[d+(i<<1)>>1]|0,c[(c[f+(i<<2)>>2]|0)+(k<<2)>>2]|0)|0)+g|0;i=i+1|0;}while((i|0)<(e|0));i=g>>15;if((i+32768|0)>>>0>65535>>>0){l=(g>>31^32767)&65535}else{l=i&65535}i=j+(k<<1)|0;y=l^-32768;a[i]=y;y=y>>8;a[i+1|0]=y;k=k+1|0;}while((k|0)<(h|0));return}function lAb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=b;b=d;if((e|0)>0){h=0}else{return}do{d=(c[g+(h<<2)>>2]|0)+4>>3;if(d>>>0>65535>>>0){i=-d>>31&65535}else{i=d&65535}d=b+(h<<1)|0;y=he(i|0)|0;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function mAb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=b;b=d;if((e|0)>0){h=0}else{return}do{d=(c[g+(h<<2)>>2]|0)+4>>3;if(d>>>0>65535>>>0){i=-d>>31&65535}else{i=d&65535}d=b+(h<<1)|0;y=i;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function nAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=131072;l=0;do{k=(ca(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>18;if(l>>>0<512>>>0){m=l&65535;break}m=-l>>31&511}else{m=0}}while(0);l=j+(i<<1)|0;y=he(m|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;i=i+1|0;}while((i|0)<(h|0));return}function oAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=131072;l=0;do{k=(ca(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>18;if(l>>>0<512>>>0){m=l&65535;break}m=-l>>31&511}else{m=0}}while(0);l=j+(i<<1)|0;y=m;a[l]=y;y=y>>8;a[l+1|0]=y;i=i+1|0;}while((i|0)<(h|0));return}function pAb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+32>>6;if(d>>>0<512>>>0){i=d&65535}else{i=-d>>31&511}d=g+(h<<1)|0;y=he(i|0)|0;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function qAb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+32>>6;if(d>>>0<512>>>0){i=d&65535}else{i=-d>>31&511}d=g+(h<<1)|0;y=i;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function rAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=65536;l=0;do{k=(ca(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>17;if(l>>>0<1024>>>0){m=l&65535;break}m=-l>>31&1023}else{m=0}}while(0);l=j+(i<<1)|0;y=he(m|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;i=i+1|0;}while((i|0)<(h|0));return}function sAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=65536;l=0;do{k=(ca(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>17;if(l>>>0<1024>>>0){m=l&65535;break}m=-l>>31&1023}else{m=0}}while(0);l=j+(i<<1)|0;y=m;a[l]=y;y=y>>8;a[l+1|0]=y;i=i+1|0;}while((i|0)<(h|0));return}function tAb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+16>>5;if(d>>>0<1024>>>0){i=d&65535}else{i=-d>>31&1023}d=g+(h<<1)|0;y=he(i|0)|0;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function uAb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+16>>5;if(d>>>0<1024>>>0){i=d&65535}else{i=-d>>31&1023}d=g+(h<<1)|0;y=i;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function vAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=16384;l=0;do{k=(ca(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>15;if(l>>>0<4096>>>0){m=l&65535;break}m=-l>>31&4095}else{m=0}}while(0);l=j+(i<<1)|0;y=he(m|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;i=i+1|0;}while((i|0)<(h|0));return}function wAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=16384;l=0;do{k=(ca(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>15;if(l>>>0<4096>>>0){m=l&65535;break}m=-l>>31&4095}else{m=0}}while(0);l=j+(i<<1)|0;y=m;a[l]=y;y=y>>8;a[l+1|0]=y;i=i+1|0;}while((i|0)<(h|0));return}function xAb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+4>>3;if(d>>>0<4096>>>0){i=d&65535}else{i=-d>>31&4095}d=g+(h<<1)|0;y=he(i|0)|0;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function yAb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+4>>3;if(d>>>0<4096>>>0){i=d&65535}else{i=-d>>31&4095}d=g+(h<<1)|0;y=i;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function zAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=4096;l=0;do{k=(ca(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>13;if(l>>>0<16384>>>0){m=l&65535;break}m=-l>>31&16383}else{m=0}}while(0);l=j+(i<<1)|0;y=he(m|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;i=i+1|0;}while((i|0)<(h|0));return}function AAb(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;j=g;if((h|0)<=0){return}g=(e|0)>0;i=0;do{do{if(g){k=4096;l=0;do{k=(ca(b[d+(l<<1)>>1]|0,b[(c[f+(l<<2)>>2]|0)+(i<<1)>>1]|0)|0)+k|0;l=l+1|0;}while((l|0)<(e|0));l=k>>13;if(l>>>0<16384>>>0){m=l&65535;break}m=-l>>31&16383}else{m=0}}while(0);l=j+(i<<1)|0;y=m;a[l]=y;y=y>>8;a[l+1|0]=y;i=i+1|0;}while((i|0)<(h|0));return}function BAb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+1>>1;if(d>>>0<16384>>>0){i=d&65535}else{i=-d>>31&16383}d=g+(h<<1)|0;y=he(i|0)|0;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function CAb(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;g=d;if((e|0)>0){h=0}else{return}do{d=(b[c+(h<<1)>>1]|0)+1>>1;if(d>>>0<16384>>>0){i=d&65535}else{i=-d>>31&16383}d=g+(h<<1)|0;y=i;a[d]=y;y=y>>8;a[d+1|0]=y;h=h+1|0;}while((h|0)<(e|0));return}function DAb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;if((f|0)>0){i=0}else{return}do{j=(d[g+(i+h&7)|0]|0)+(b[c+(i<<1)>>1]|0)>>7;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[e+i|0]=k;i=i+1|0;}while((i|0)<(f|0));return}function EAb(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((i|0)<=0){return}l=(f|0)>0;m=0;do{n=d[j+(m+k&7)|0]<<12;if(l){o=n;p=0;while(1){q=(ca(b[e+(p<<1)>>1]|0,b[(c[g+(p<<2)>>2]|0)+(m<<1)>>1]|0)|0)+o|0;r=p+1|0;if((r|0)<(f|0)){o=q;p=r}else{s=q;break}}}else{s=n}p=s>>19;if(p>>>0>255>>>0){t=-p>>31&255}else{t=p&255}a[h+m|0]=t;m=m+1|0;}while((m|0)<(i|0));return}function FAb(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;l=c[e+23816>>2]|0;m=(k|0)>0;if((c[e+52>>2]|0)==25){if(!m){return}e=(g|0)>0;n=0;do{o=d[l+(n&7)|0]<<12;p=d[l+(n+3&7)|0]<<12;if(e){q=o;r=p;s=0;while(1){t=b[f+(s<<1)>>1]|0;u=(ca(t,b[(c[h+(s<<2)>>2]|0)+(n<<1)>>1]|0)|0)+q|0;v=(ca(b[(c[i+(s<<2)>>2]|0)+(n<<1)>>1]|0,t)|0)+r|0;t=s+1|0;if((t|0)<(g|0)){q=u;r=v;s=t}else{w=u;x=v;break}}}else{w=o;x=p}s=w>>19;if(s>>>0>255>>>0){y=-s>>31&255}else{y=s&255}s=n<<1;a[j+s|0]=y;r=x>>19;if(r>>>0>255>>>0){z=-r>>31&255}else{z=r&255}a[j+(s|1)|0]=z;n=n+1|0;}while((n|0)<(k|0));return}else{if(!m){return}m=(g|0)>0;n=0;do{z=d[l+(n&7)|0]<<12;x=d[l+(n+3&7)|0]<<12;if(m){y=z;w=x;e=0;while(1){s=b[f+(e<<1)>>1]|0;r=(ca(s,b[(c[h+(e<<2)>>2]|0)+(n<<1)>>1]|0)|0)+y|0;q=(ca(b[(c[i+(e<<2)>>2]|0)+(n<<1)>>1]|0,s)|0)+w|0;s=e+1|0;if((s|0)<(g|0)){y=r;w=q;e=s}else{A=r;B=q;break}}}else{A=z;B=x}e=B>>19;if(e>>>0>255>>>0){C=-e>>31&255}else{C=e&255}e=n<<1;a[j+e|0]=C;w=A>>19;if(w>>>0>255>>>0){D=-w>>31&255}else{D=w&255}a[j+(e|1)|0]=D;n=n+1|0;}while((n|0)<(k|0));return}}function GAb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;z=(k|0)>0;A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=m;m=0;while(1){if(o){H=0;I=512;do{I=(ca(b[e+(H<<1)>>1]|0,b[(c[f+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+I|0;H=H+1|0;}while((H|0)<(g|0));J=I>>10}else{J=0}if(z){H=0;K=-67108352;L=-67108352;do{M=b[h+(H<<1)>>1]|0;K=(ca(M,b[(c[i+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+K|0;L=(ca(b[(c[j+(H<<2)>>2]|0)+(m<<1)>>1]|0,M)|0)+L|0;H=H+1|0;}while((H|0)<(k|0));N=K>>10;O=L>>10}else{N=-65536;O=-65536}do{if(o){H=262144;I=0;do{H=(ca(b[e+(I<<1)>>1]|0,b[(c[l+(I<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;I=I+1|0;}while((I|0)<(g|0));I=H>>19;if(!((I&256|0)!=0&I>>>0>255>>>0)){P=I&255;break}P=-I>>31&255}else{P=0}}while(0);L=(ca(J-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;K=L+(ca(c[C>>2]|0,O)|0)|0;I=(ca(c[D>>2]|0,O)|0)+L|0;M=I+(ca(c[E>>2]|0,N)|0)|0;I=(ca(c[F>>2]|0,N)|0)+L|0;L=K>>>22&255;Q=M>>>22&255;R=I>>>22&255;do{if((M|K|I)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){S=L}else{S=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){T=Q}else{T=-M>>31>>>22&255}if(I>>>0<1073741824>>>0){U=R;V=T;W=S;break}U=-I>>31>>>22&255;V=T;W=S}else{U=R;V=Q;W=L}}while(0);a[G]=W;a[G+1|0]=V;a[G+2|0]=U;a[G+3|0]=P;L=m+1|0;if((L|0)<(n|0)){G=G+4|0;m=L}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function HAb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-k|0;r=4096-l|0;if((j|0)<=0){s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=0;J=i;while(1){i=ca(b[m+(I<<1)>>1]|0,h)|0;K=(ca(b[n+(I<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(I<<1)>>1]|0,r)|0;L=i-67108864+(ca(b[o+(I<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(I<<1)>>1]|0,r)|0;M=i-67108864+(ca(b[p+(I<<1)>>1]|0,l)|0)>>10;i=ca(b[g+(I<<1)>>1]|0,h)|0;N=i+262144+(ca(b[q+(I<<1)>>1]|0,k)|0)>>19;if((N&256|0)!=0&N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}N=(ca(K-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;K=N+(ca(c[E>>2]|0,M)|0)|0;i=(ca(c[F>>2]|0,M)|0)+N|0;M=i+(ca(c[G>>2]|0,L)|0)|0;i=(ca(c[H>>2]|0,L)|0)+N|0;N=K>>>22&255;L=M>>>22&255;P=i>>>22&255;do{if((M|K|i)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){Q=N}else{Q=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){R=L}else{R=-M>>31>>>22&255}if(i>>>0<1073741824>>>0){S=P;T=R;U=Q;break}S=-i>>31>>>22&255;T=R;U=Q}else{S=P;T=L;U=N}}while(0);a[J]=U;a[J+1|0]=T;a[J+2|0]=S;a[J+3|0]=O;N=I+1|0;if((N|0)<(j|0)){I=N;J=J+4|0}else{s=j;break}}t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}function IAb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}k=d+11300|0;x=d+11304|0;y=d+11308|0;z=d+11312|0;A=d+11316|0;B=d+11320|0;C=0;D=i;while(1){E=(b[l+(C<<1)>>1]<<2)-65536|0;F=(b[m+(C<<1)>>1]<<2)-65536|0;G=(b[h+(C<<1)>>1]|0)+64>>7;if((G&256|0)!=0&G>>>0>255>>>0){H=-G>>31&255}else{H=G&255}G=(ca((b[e+(C<<1)>>1]<<2)-(c[k>>2]|0)|0,c[x>>2]|0)|0)+2097152|0;I=G+(ca(c[y>>2]|0,F)|0)|0;J=(ca(c[z>>2]|0,F)|0)+G|0;F=J+(ca(c[A>>2]|0,E)|0)|0;J=(ca(c[B>>2]|0,E)|0)+G|0;G=I>>>22&255;E=F>>>22&255;K=J>>>22&255;do{if((F|I|J)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){L=G}else{L=-I>>31>>>22&255}if(F>>>0<1073741824>>>0){M=E}else{M=-F>>31>>>22&255}if(J>>>0<1073741824>>>0){N=K;O=M;P=L;break}N=-J>>31>>>22&255;O=M;P=L}else{N=K;O=E;P=G}}while(0);a[D]=P;a[D+1|0]=O;a[D+2|0]=N;a[D+3|0]=H;G=C+1|0;if((G|0)<(j|0)){C=G;D=D+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}else{D=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}g=d+11300|0;C=d+11304|0;H=d+11308|0;N=d+11312|0;O=d+11316|0;P=d+11320|0;L=0;M=i;while(1){i=((b[D+(L<<1)>>1]|0)+(b[l+(L<<1)>>1]|0)<<1)-65536|0;B=((b[f+(L<<1)>>1]|0)+(b[m+(L<<1)>>1]|0)<<1)-65536|0;A=(b[h+(L<<1)>>1]|0)+64>>7;if((A&256|0)!=0&A>>>0>255>>>0){Q=-A>>31&255}else{Q=A&255}A=(ca((b[e+(L<<1)>>1]<<2)-(c[g>>2]|0)|0,c[C>>2]|0)|0)+2097152|0;z=A+(ca(c[H>>2]|0,B)|0)|0;y=(ca(c[N>>2]|0,B)|0)+A|0;B=y+(ca(c[O>>2]|0,i)|0)|0;y=(ca(c[P>>2]|0,i)|0)+A|0;A=z>>>22&255;i=B>>>22&255;x=y>>>22&255;do{if((B|z|y)>>>0>1073741823>>>0){if(z>>>0<1073741824>>>0){R=A}else{R=-z>>31>>>22&255}if(B>>>0<1073741824>>>0){S=i}else{S=-B>>31>>>22&255}if(y>>>0<1073741824>>>0){T=x;U=S;V=R;break}T=-y>>31>>>22&255;U=S;V=R}else{T=x;U=i;V=A}}while(0);a[M]=V;a[M+1|0]=U;a[M+2|0]=T;a[M+3|0]=Q;A=L+1|0;if((A|0)<(j|0)){L=A;M=M+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}}function JAb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ca(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ca(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ca(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ca(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ca(c[B>>2]|0,N)|0)|0;L=(ca(c[C>>2]|0,N)|0)+G|0;O=L+(ca(c[D>>2]|0,M)|0)|0;L=(ca(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=V;a[F+1|0]=U;a[F+2|0]=T;a[F+3|0]=-1;G=m+1|0;if((G|0)<(n|0)){F=F+4|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function KAb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ca(b[m+(G<<1)>>1]|0,g)|0;I=(ca(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ca(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ca(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ca(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ca(K,c[C>>2]|0)|0)+i|0;L=(ca(c[D>>2]|0,K)|0)+i|0;K=L+(ca(c[E>>2]|0,J)|0)|0;L=(ca(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=R;a[H+1|0]=Q;a[H+2|0]=P;a[H+3|0]=-1;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+4|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function LAb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ca((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ca(c[p>>2]|0,w)|0)|0;z=(ca(c[q>>2]|0,w)|0)+x|0;w=z+(ca(c[r>>2]|0,v)|0)|0;z=(ca(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=F;a[u+1|0]=E;a[u+2|0]=D;a[u+3|0]=-1;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+4|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ca((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ca(z,c[q>>2]|0)|0)+w|0;G=(ca(c[p>>2]|0,z)|0)+w|0;z=G+(ca(c[o>>2]|0,A)|0)|0;G=(ca(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=M;a[v+1|0]=L;a[v+2|0]=K;a[v+3|0]=-1;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+4|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function MAb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;z=(k|0)>0;A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=m;m=0;while(1){if(o){H=0;I=512;do{I=(ca(b[e+(H<<1)>>1]|0,b[(c[f+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+I|0;H=H+1|0;}while((H|0)<(g|0));J=I>>10}else{J=0}if(z){H=0;K=-67108352;L=-67108352;do{M=b[h+(H<<1)>>1]|0;K=(ca(M,b[(c[i+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+K|0;L=(ca(b[(c[j+(H<<2)>>2]|0)+(m<<1)>>1]|0,M)|0)+L|0;H=H+1|0;}while((H|0)<(k|0));N=K>>10;O=L>>10}else{N=-65536;O=-65536}do{if(o){H=262144;I=0;do{H=(ca(b[e+(I<<1)>>1]|0,b[(c[l+(I<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;I=I+1|0;}while((I|0)<(g|0));I=H>>19;if(!((I&256|0)!=0&I>>>0>255>>>0)){P=I&255;break}P=-I>>31&255}else{P=0}}while(0);L=(ca(J-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;K=L+(ca(c[C>>2]|0,O)|0)|0;I=(ca(c[D>>2]|0,O)|0)+L|0;M=I+(ca(c[E>>2]|0,N)|0)|0;I=(ca(c[F>>2]|0,N)|0)+L|0;L=K>>>22&255;Q=M>>>22&255;R=I>>>22&255;do{if((M|K|I)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){S=L}else{S=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){T=Q}else{T=-M>>31>>>22&255}if(I>>>0<1073741824>>>0){U=R;V=T;W=S;break}U=-I>>31>>>22&255;V=T;W=S}else{U=R;V=Q;W=L}}while(0);a[G]=P;a[G+1|0]=W;a[G+2|0]=V;a[G+3|0]=U;L=m+1|0;if((L|0)<(n|0)){G=G+4|0;m=L}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function NAb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-k|0;r=4096-l|0;if((j|0)<=0){s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=0;J=i;while(1){i=ca(b[m+(I<<1)>>1]|0,h)|0;K=(ca(b[n+(I<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(I<<1)>>1]|0,r)|0;L=i-67108864+(ca(b[o+(I<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(I<<1)>>1]|0,r)|0;M=i-67108864+(ca(b[p+(I<<1)>>1]|0,l)|0)>>10;i=ca(b[g+(I<<1)>>1]|0,h)|0;N=i+262144+(ca(b[q+(I<<1)>>1]|0,k)|0)>>19;if((N&256|0)!=0&N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}N=(ca(K-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;K=N+(ca(c[E>>2]|0,M)|0)|0;i=(ca(c[F>>2]|0,M)|0)+N|0;M=i+(ca(c[G>>2]|0,L)|0)|0;i=(ca(c[H>>2]|0,L)|0)+N|0;N=K>>>22&255;L=M>>>22&255;P=i>>>22&255;do{if((M|K|i)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){Q=N}else{Q=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){R=L}else{R=-M>>31>>>22&255}if(i>>>0<1073741824>>>0){S=P;T=R;U=Q;break}S=-i>>31>>>22&255;T=R;U=Q}else{S=P;T=L;U=N}}while(0);a[J]=O;a[J+1|0]=U;a[J+2|0]=T;a[J+3|0]=S;N=I+1|0;if((N|0)<(j|0)){I=N;J=J+4|0}else{s=j;break}}t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}function OAb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}k=d+11300|0;x=d+11304|0;y=d+11308|0;z=d+11312|0;A=d+11316|0;B=d+11320|0;C=0;D=i;while(1){E=(b[l+(C<<1)>>1]<<2)-65536|0;F=(b[m+(C<<1)>>1]<<2)-65536|0;G=(b[h+(C<<1)>>1]|0)+64>>7;if((G&256|0)!=0&G>>>0>255>>>0){H=-G>>31&255}else{H=G&255}G=(ca((b[e+(C<<1)>>1]<<2)-(c[k>>2]|0)|0,c[x>>2]|0)|0)+2097152|0;I=G+(ca(c[y>>2]|0,F)|0)|0;J=(ca(c[z>>2]|0,F)|0)+G|0;F=J+(ca(c[A>>2]|0,E)|0)|0;J=(ca(c[B>>2]|0,E)|0)+G|0;G=I>>>22&255;E=F>>>22&255;K=J>>>22&255;do{if((F|I|J)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){L=G}else{L=-I>>31>>>22&255}if(F>>>0<1073741824>>>0){M=E}else{M=-F>>31>>>22&255}if(J>>>0<1073741824>>>0){N=K;O=M;P=L;break}N=-J>>31>>>22&255;O=M;P=L}else{N=K;O=E;P=G}}while(0);a[D]=H;a[D+1|0]=P;a[D+2|0]=O;a[D+3|0]=N;G=C+1|0;if((G|0)<(j|0)){C=G;D=D+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}else{D=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}g=d+11300|0;C=d+11304|0;N=d+11308|0;O=d+11312|0;P=d+11316|0;H=d+11320|0;L=0;M=i;while(1){i=((b[D+(L<<1)>>1]|0)+(b[l+(L<<1)>>1]|0)<<1)-65536|0;B=((b[f+(L<<1)>>1]|0)+(b[m+(L<<1)>>1]|0)<<1)-65536|0;A=(b[h+(L<<1)>>1]|0)+64>>7;if((A&256|0)!=0&A>>>0>255>>>0){Q=-A>>31&255}else{Q=A&255}A=(ca((b[e+(L<<1)>>1]<<2)-(c[g>>2]|0)|0,c[C>>2]|0)|0)+2097152|0;z=A+(ca(c[N>>2]|0,B)|0)|0;y=(ca(c[O>>2]|0,B)|0)+A|0;B=y+(ca(c[P>>2]|0,i)|0)|0;y=(ca(c[H>>2]|0,i)|0)+A|0;A=z>>>22&255;i=B>>>22&255;x=y>>>22&255;do{if((B|z|y)>>>0>1073741823>>>0){if(z>>>0<1073741824>>>0){R=A}else{R=-z>>31>>>22&255}if(B>>>0<1073741824>>>0){S=i}else{S=-B>>31>>>22&255}if(y>>>0<1073741824>>>0){T=x;U=S;V=R;break}T=-y>>31>>>22&255;U=S;V=R}else{T=x;U=i;V=A}}while(0);a[M]=Q;a[M+1|0]=V;a[M+2|0]=U;a[M+3|0]=T;A=L+1|0;if((A|0)<(j|0)){L=A;M=M+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}}function PAb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ca(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ca(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ca(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ca(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ca(c[B>>2]|0,N)|0)|0;L=(ca(c[C>>2]|0,N)|0)+G|0;O=L+(ca(c[D>>2]|0,M)|0)|0;L=(ca(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=-1;a[F+1|0]=V;a[F+2|0]=U;a[F+3|0]=T;G=m+1|0;if((G|0)<(n|0)){F=F+4|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function QAb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ca(b[m+(G<<1)>>1]|0,g)|0;I=(ca(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ca(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ca(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ca(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ca(K,c[C>>2]|0)|0)+i|0;L=(ca(c[D>>2]|0,K)|0)+i|0;K=L+(ca(c[E>>2]|0,J)|0)|0;L=(ca(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=-1;a[H+1|0]=R;a[H+2|0]=Q;a[H+3|0]=P;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+4|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function RAb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ca((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ca(c[p>>2]|0,w)|0)|0;z=(ca(c[q>>2]|0,w)|0)+x|0;w=z+(ca(c[r>>2]|0,v)|0)|0;z=(ca(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=-1;a[u+1|0]=F;a[u+2|0]=E;a[u+3|0]=D;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+4|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ca((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ca(z,c[q>>2]|0)|0)+w|0;G=(ca(c[p>>2]|0,z)|0)+w|0;z=G+(ca(c[o>>2]|0,A)|0)|0;G=(ca(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=-1;a[v+1|0]=M;a[v+2|0]=L;a[v+3|0]=K;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+4|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function SAb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;z=(k|0)>0;A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=m;m=0;while(1){if(o){H=0;I=512;do{I=(ca(b[e+(H<<1)>>1]|0,b[(c[f+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+I|0;H=H+1|0;}while((H|0)<(g|0));J=I>>10}else{J=0}if(z){H=0;K=-67108352;L=-67108352;do{M=b[h+(H<<1)>>1]|0;K=(ca(M,b[(c[i+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+K|0;L=(ca(b[(c[j+(H<<2)>>2]|0)+(m<<1)>>1]|0,M)|0)+L|0;H=H+1|0;}while((H|0)<(k|0));N=K>>10;O=L>>10}else{N=-65536;O=-65536}do{if(o){H=262144;I=0;do{H=(ca(b[e+(I<<1)>>1]|0,b[(c[l+(I<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;I=I+1|0;}while((I|0)<(g|0));I=H>>19;if(!((I&256|0)!=0&I>>>0>255>>>0)){P=I&255;break}P=-I>>31&255}else{P=0}}while(0);L=(ca(J-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;K=L+(ca(c[C>>2]|0,O)|0)|0;I=(ca(c[D>>2]|0,O)|0)+L|0;M=I+(ca(c[E>>2]|0,N)|0)|0;I=(ca(c[F>>2]|0,N)|0)+L|0;L=K>>>22&255;Q=M>>>22&255;R=I>>>22&255;do{if((M|K|I)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){S=L}else{S=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){T=Q}else{T=-M>>31>>>22&255}if(I>>>0<1073741824>>>0){U=R;V=T;W=S;break}U=-I>>31>>>22&255;V=T;W=S}else{U=R;V=Q;W=L}}while(0);a[G]=U;a[G+1|0]=V;a[G+2|0]=W;a[G+3|0]=P;L=m+1|0;if((L|0)<(n|0)){G=G+4|0;m=L}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function TAb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-k|0;r=4096-l|0;if((j|0)<=0){s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=0;J=i;while(1){i=ca(b[m+(I<<1)>>1]|0,h)|0;K=(ca(b[n+(I<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(I<<1)>>1]|0,r)|0;L=i-67108864+(ca(b[o+(I<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(I<<1)>>1]|0,r)|0;M=i-67108864+(ca(b[p+(I<<1)>>1]|0,l)|0)>>10;i=ca(b[g+(I<<1)>>1]|0,h)|0;N=i+262144+(ca(b[q+(I<<1)>>1]|0,k)|0)>>19;if((N&256|0)!=0&N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}N=(ca(K-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;K=N+(ca(c[E>>2]|0,M)|0)|0;i=(ca(c[F>>2]|0,M)|0)+N|0;M=i+(ca(c[G>>2]|0,L)|0)|0;i=(ca(c[H>>2]|0,L)|0)+N|0;N=K>>>22&255;L=M>>>22&255;P=i>>>22&255;do{if((M|K|i)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){Q=N}else{Q=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){R=L}else{R=-M>>31>>>22&255}if(i>>>0<1073741824>>>0){S=P;T=R;U=Q;break}S=-i>>31>>>22&255;T=R;U=Q}else{S=P;T=L;U=N}}while(0);a[J]=S;a[J+1|0]=T;a[J+2|0]=U;a[J+3|0]=O;N=I+1|0;if((N|0)<(j|0)){I=N;J=J+4|0}else{s=j;break}}t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}function UAb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}k=d+11300|0;x=d+11304|0;y=d+11308|0;z=d+11312|0;A=d+11316|0;B=d+11320|0;C=0;D=i;while(1){E=(b[l+(C<<1)>>1]<<2)-65536|0;F=(b[m+(C<<1)>>1]<<2)-65536|0;G=(b[h+(C<<1)>>1]|0)+64>>7;if((G&256|0)!=0&G>>>0>255>>>0){H=-G>>31&255}else{H=G&255}G=(ca((b[e+(C<<1)>>1]<<2)-(c[k>>2]|0)|0,c[x>>2]|0)|0)+2097152|0;I=G+(ca(c[y>>2]|0,F)|0)|0;J=(ca(c[z>>2]|0,F)|0)+G|0;F=J+(ca(c[A>>2]|0,E)|0)|0;J=(ca(c[B>>2]|0,E)|0)+G|0;G=I>>>22&255;E=F>>>22&255;K=J>>>22&255;do{if((F|I|J)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){L=G}else{L=-I>>31>>>22&255}if(F>>>0<1073741824>>>0){M=E}else{M=-F>>31>>>22&255}if(J>>>0<1073741824>>>0){N=K;O=M;P=L;break}N=-J>>31>>>22&255;O=M;P=L}else{N=K;O=E;P=G}}while(0);a[D]=N;a[D+1|0]=O;a[D+2|0]=P;a[D+3|0]=H;G=C+1|0;if((G|0)<(j|0)){C=G;D=D+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}else{D=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}g=d+11300|0;C=d+11304|0;H=d+11308|0;P=d+11312|0;O=d+11316|0;N=d+11320|0;L=0;M=i;while(1){i=((b[D+(L<<1)>>1]|0)+(b[l+(L<<1)>>1]|0)<<1)-65536|0;B=((b[f+(L<<1)>>1]|0)+(b[m+(L<<1)>>1]|0)<<1)-65536|0;A=(b[h+(L<<1)>>1]|0)+64>>7;if((A&256|0)!=0&A>>>0>255>>>0){Q=-A>>31&255}else{Q=A&255}A=(ca((b[e+(L<<1)>>1]<<2)-(c[g>>2]|0)|0,c[C>>2]|0)|0)+2097152|0;z=A+(ca(c[H>>2]|0,B)|0)|0;y=(ca(c[P>>2]|0,B)|0)+A|0;B=y+(ca(c[O>>2]|0,i)|0)|0;y=(ca(c[N>>2]|0,i)|0)+A|0;A=z>>>22&255;i=B>>>22&255;x=y>>>22&255;do{if((B|z|y)>>>0>1073741823>>>0){if(z>>>0<1073741824>>>0){R=A}else{R=-z>>31>>>22&255}if(B>>>0<1073741824>>>0){S=i}else{S=-B>>31>>>22&255}if(y>>>0<1073741824>>>0){T=x;U=S;V=R;break}T=-y>>31>>>22&255;U=S;V=R}else{T=x;U=i;V=A}}while(0);a[M]=T;a[M+1|0]=U;a[M+2|0]=V;a[M+3|0]=Q;A=L+1|0;if((A|0)<(j|0)){L=A;M=M+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}}function VAb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ca(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ca(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ca(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ca(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ca(c[B>>2]|0,N)|0)|0;L=(ca(c[C>>2]|0,N)|0)+G|0;O=L+(ca(c[D>>2]|0,M)|0)|0;L=(ca(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=T;a[F+1|0]=U;a[F+2|0]=V;a[F+3|0]=-1;G=m+1|0;if((G|0)<(n|0)){F=F+4|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function WAb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ca(b[m+(G<<1)>>1]|0,g)|0;I=(ca(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ca(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ca(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ca(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ca(K,c[C>>2]|0)|0)+i|0;L=(ca(c[D>>2]|0,K)|0)+i|0;K=L+(ca(c[E>>2]|0,J)|0)|0;L=(ca(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=P;a[H+1|0]=Q;a[H+2|0]=R;a[H+3|0]=-1;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+4|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function XAb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ca((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ca(c[p>>2]|0,w)|0)|0;z=(ca(c[q>>2]|0,w)|0)+x|0;w=z+(ca(c[r>>2]|0,v)|0)|0;z=(ca(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=D;a[u+1|0]=E;a[u+2|0]=F;a[u+3|0]=-1;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+4|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ca((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ca(z,c[q>>2]|0)|0)+w|0;G=(ca(c[p>>2]|0,z)|0)+w|0;z=G+(ca(c[o>>2]|0,A)|0)|0;G=(ca(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=K;a[v+1|0]=L;a[v+2|0]=M;a[v+3|0]=-1;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+4|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function YAb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;z=(k|0)>0;A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=m;m=0;while(1){if(o){H=0;I=512;do{I=(ca(b[e+(H<<1)>>1]|0,b[(c[f+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+I|0;H=H+1|0;}while((H|0)<(g|0));J=I>>10}else{J=0}if(z){H=0;K=-67108352;L=-67108352;do{M=b[h+(H<<1)>>1]|0;K=(ca(M,b[(c[i+(H<<2)>>2]|0)+(m<<1)>>1]|0)|0)+K|0;L=(ca(b[(c[j+(H<<2)>>2]|0)+(m<<1)>>1]|0,M)|0)+L|0;H=H+1|0;}while((H|0)<(k|0));N=K>>10;O=L>>10}else{N=-65536;O=-65536}do{if(o){H=262144;I=0;do{H=(ca(b[e+(I<<1)>>1]|0,b[(c[l+(I<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;I=I+1|0;}while((I|0)<(g|0));I=H>>19;if(!((I&256|0)!=0&I>>>0>255>>>0)){P=I&255;break}P=-I>>31&255}else{P=0}}while(0);L=(ca(J-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;K=L+(ca(c[C>>2]|0,O)|0)|0;I=(ca(c[D>>2]|0,O)|0)+L|0;M=I+(ca(c[E>>2]|0,N)|0)|0;I=(ca(c[F>>2]|0,N)|0)+L|0;L=K>>>22&255;Q=M>>>22&255;R=I>>>22&255;do{if((M|K|I)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){S=L}else{S=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){T=Q}else{T=-M>>31>>>22&255}if(I>>>0<1073741824>>>0){U=R;V=T;W=S;break}U=-I>>31>>>22&255;V=T;W=S}else{U=R;V=Q;W=L}}while(0);a[G]=P;a[G+1|0]=U;a[G+2|0]=V;a[G+3|0]=W;L=m+1|0;if((L|0)<(n|0)){G=G+4|0;m=L}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function ZAb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;m=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-k|0;r=4096-l|0;if((j|0)<=0){s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=0;J=i;while(1){i=ca(b[m+(I<<1)>>1]|0,h)|0;K=(ca(b[n+(I<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(I<<1)>>1]|0,r)|0;L=i-67108864+(ca(b[o+(I<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(I<<1)>>1]|0,r)|0;M=i-67108864+(ca(b[p+(I<<1)>>1]|0,l)|0)>>10;i=ca(b[g+(I<<1)>>1]|0,h)|0;N=i+262144+(ca(b[q+(I<<1)>>1]|0,k)|0)>>19;if((N&256|0)!=0&N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}N=(ca(K-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;K=N+(ca(c[E>>2]|0,M)|0)|0;i=(ca(c[F>>2]|0,M)|0)+N|0;M=i+(ca(c[G>>2]|0,L)|0)|0;i=(ca(c[H>>2]|0,L)|0)+N|0;N=K>>>22&255;L=M>>>22&255;P=i>>>22&255;do{if((M|K|i)>>>0>1073741823>>>0){if(K>>>0<1073741824>>>0){Q=N}else{Q=-K>>31>>>22&255}if(M>>>0<1073741824>>>0){R=L}else{R=-M>>31>>>22&255}if(i>>>0<1073741824>>>0){S=P;T=R;U=Q;break}S=-i>>31>>>22&255;T=R;U=Q}else{S=P;T=L;U=N}}while(0);a[J]=O;a[J+1|0]=S;a[J+2|0]=T;a[J+3|0]=U;N=I+1|0;if((N|0)<(j|0)){I=N;J=J+4|0}else{s=j;break}}t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=0;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=0;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=0;return}function _Ab(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}k=d+11300|0;x=d+11304|0;y=d+11308|0;z=d+11312|0;A=d+11316|0;B=d+11320|0;C=0;D=i;while(1){E=(b[l+(C<<1)>>1]<<2)-65536|0;F=(b[m+(C<<1)>>1]<<2)-65536|0;G=(b[h+(C<<1)>>1]|0)+64>>7;if((G&256|0)!=0&G>>>0>255>>>0){H=-G>>31&255}else{H=G&255}G=(ca((b[e+(C<<1)>>1]<<2)-(c[k>>2]|0)|0,c[x>>2]|0)|0)+2097152|0;I=G+(ca(c[y>>2]|0,F)|0)|0;J=(ca(c[z>>2]|0,F)|0)+G|0;F=J+(ca(c[A>>2]|0,E)|0)|0;J=(ca(c[B>>2]|0,E)|0)+G|0;G=I>>>22&255;E=F>>>22&255;K=J>>>22&255;do{if((F|I|J)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){L=G}else{L=-I>>31>>>22&255}if(F>>>0<1073741824>>>0){M=E}else{M=-F>>31>>>22&255}if(J>>>0<1073741824>>>0){N=K;O=M;P=L;break}N=-J>>31>>>22&255;O=M;P=L}else{N=K;O=E;P=G}}while(0);a[D]=H;a[D+1|0]=N;a[D+2|0]=O;a[D+3|0]=P;G=C+1|0;if((G|0)<(j|0)){C=G;D=D+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}else{D=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){n=0;o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}g=d+11300|0;C=d+11304|0;P=d+11308|0;O=d+11312|0;N=d+11316|0;H=d+11320|0;L=0;M=i;while(1){i=((b[D+(L<<1)>>1]|0)+(b[l+(L<<1)>>1]|0)<<1)-65536|0;B=((b[f+(L<<1)>>1]|0)+(b[m+(L<<1)>>1]|0)<<1)-65536|0;A=(b[h+(L<<1)>>1]|0)+64>>7;if((A&256|0)!=0&A>>>0>255>>>0){Q=-A>>31&255}else{Q=A&255}A=(ca((b[e+(L<<1)>>1]<<2)-(c[g>>2]|0)|0,c[C>>2]|0)|0)+2097152|0;z=A+(ca(c[P>>2]|0,B)|0)|0;y=(ca(c[O>>2]|0,B)|0)+A|0;B=y+(ca(c[N>>2]|0,i)|0)|0;y=(ca(c[H>>2]|0,i)|0)+A|0;A=z>>>22&255;i=B>>>22&255;x=y>>>22&255;do{if((B|z|y)>>>0>1073741823>>>0){if(z>>>0<1073741824>>>0){R=A}else{R=-z>>31>>>22&255}if(B>>>0<1073741824>>>0){S=i}else{S=-B>>31>>>22&255}if(y>>>0<1073741824>>>0){T=x;U=S;V=R;break}T=-y>>31>>>22&255;U=S;V=R}else{T=x;U=i;V=A}}while(0);a[M]=Q;a[M+1|0]=T;a[M+2|0]=U;a[M+3|0]=V;A=L+1|0;if((A|0)<(j|0)){L=A;M=M+4|0}else{n=j;break}}o=d+11200|0;p=c[o>>2]|0;q=p+(n<<2)|0;c[q>>2]=0;r=d+11204|0;s=c[r>>2]|0;t=s+(n<<2)|0;c[t>>2]=0;u=d+11208|0;v=c[u>>2]|0;w=v+(n<<2)|0;c[w>>2]=0;return}}function $Ab(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ca(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ca(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ca(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ca(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ca(c[B>>2]|0,N)|0)|0;L=(ca(c[C>>2]|0,N)|0)+G|0;O=L+(ca(c[D>>2]|0,M)|0)|0;L=(ca(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=-1;a[F+1|0]=T;a[F+2|0]=U;a[F+3|0]=V;G=m+1|0;if((G|0)<(n|0)){F=F+4|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function aBb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ca(b[m+(G<<1)>>1]|0,g)|0;I=(ca(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ca(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ca(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ca(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ca(K,c[C>>2]|0)|0)+i|0;L=(ca(c[D>>2]|0,K)|0)+i|0;K=L+(ca(c[E>>2]|0,J)|0)|0;L=(ca(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=-1;a[H+1|0]=P;a[H+2|0]=Q;a[H+3|0]=R;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+4|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function bBb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ca((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ca(c[p>>2]|0,w)|0)|0;z=(ca(c[q>>2]|0,w)|0)+x|0;w=z+(ca(c[r>>2]|0,v)|0)|0;z=(ca(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=-1;a[u+1|0]=D;a[u+2|0]=E;a[u+3|0]=F;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+4|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ca((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ca(z,c[q>>2]|0)|0)+w|0;G=(ca(c[p>>2]|0,z)|0)+w|0;z=G+(ca(c[o>>2]|0,A)|0)|0;G=(ca(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=-1;a[v+1|0]=K;a[v+2|0]=L;a[v+3|0]=M;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+4|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function cBb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ca(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ca(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ca(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ca(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ca(c[B>>2]|0,N)|0)|0;L=(ca(c[C>>2]|0,N)|0)+G|0;O=L+(ca(c[D>>2]|0,M)|0)|0;L=(ca(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=V;a[F+1|0]=U;a[F+2|0]=T;G=m+1|0;if((G|0)<(n|0)){F=F+3|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function dBb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ca(b[m+(G<<1)>>1]|0,g)|0;I=(ca(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ca(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ca(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ca(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ca(K,c[C>>2]|0)|0)+i|0;L=(ca(c[D>>2]|0,K)|0)+i|0;K=L+(ca(c[E>>2]|0,J)|0)|0;L=(ca(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=R;a[H+1|0]=Q;a[H+2|0]=P;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+3|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function eBb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ca((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ca(c[p>>2]|0,w)|0)|0;z=(ca(c[q>>2]|0,w)|0)+x|0;w=z+(ca(c[r>>2]|0,v)|0)|0;z=(ca(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=F;a[u+1|0]=E;a[u+2|0]=D;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+3|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ca((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ca(z,c[q>>2]|0)|0)+w|0;G=(ca(c[p>>2]|0,z)|0)+w|0;z=G+(ca(c[o>>2]|0,A)|0)|0;G=(ca(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=M;a[v+1|0]=L;a[v+2|0]=K;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+3|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function fBb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((n|0)<=0){p=0;q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}o=(g|0)>0;l=(k|0)>0;z=d+11300|0;A=d+11304|0;B=d+11308|0;C=d+11312|0;D=d+11316|0;E=d+11320|0;F=m;m=0;while(1){if(o){G=0;H=512;do{H=(ca(b[e+(G<<1)>>1]|0,b[(c[f+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+H|0;G=G+1|0;}while((G|0)<(g|0));I=H>>10}else{I=0}if(l){G=0;J=-67108352;K=-67108352;do{L=b[h+(G<<1)>>1]|0;J=(ca(L,b[(c[i+(G<<2)>>2]|0)+(m<<1)>>1]|0)|0)+J|0;K=(ca(b[(c[j+(G<<2)>>2]|0)+(m<<1)>>1]|0,L)|0)+K|0;G=G+1|0;}while((G|0)<(k|0));M=J>>10;N=K>>10}else{M=-65536;N=-65536}G=(ca(I-(c[z>>2]|0)|0,c[A>>2]|0)|0)+2097152|0;H=G+(ca(c[B>>2]|0,N)|0)|0;L=(ca(c[C>>2]|0,N)|0)+G|0;O=L+(ca(c[D>>2]|0,M)|0)|0;L=(ca(c[E>>2]|0,M)|0)+G|0;G=H>>>22&255;P=O>>>22&255;Q=L>>>22&255;do{if((O|H|L)>>>0>1073741823>>>0){if(H>>>0<1073741824>>>0){R=G}else{R=-H>>31>>>22&255}if(O>>>0<1073741824>>>0){S=P}else{S=-O>>31>>>22&255}if(L>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-L>>31>>>22&255;U=S;V=R}else{T=Q;U=P;V=G}}while(0);a[F]=T;a[F+1|0]=U;a[F+2|0]=V;G=m+1|0;if((G|0)<(n|0)){F=F+3|0;m=G}else{p=n;break}}q=d+11200|0;r=d+11204|0;s=d+11208|0;t=c[q>>2]|0;u=t+(p<<2)|0;c[u>>2]=0;v=c[r>>2]|0;w=v+(p<<2)|0;c[w>>2]=0;x=c[s>>2]|0;y=x+(p<<2)|0;c[y>>2]=0;return}function gBb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}A=d+11300|0;B=d+11304|0;C=d+11308|0;D=d+11312|0;E=d+11316|0;F=d+11320|0;G=0;H=i;while(1){i=ca(b[m+(G<<1)>>1]|0,g)|0;I=(ca(b[h+(G<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(G<<1)>>1]|0,p)|0;J=i-67108864+(ca(b[n+(G<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(G<<1)>>1]|0,p)|0;K=i-67108864+(ca(b[o+(G<<1)>>1]|0,l)|0)>>10;i=(ca(I-(c[A>>2]|0)|0,c[B>>2]|0)|0)+2097152|0;I=(ca(K,c[C>>2]|0)|0)+i|0;L=(ca(c[D>>2]|0,K)|0)+i|0;K=L+(ca(c[E>>2]|0,J)|0)|0;L=(ca(c[F>>2]|0,J)|0)+i|0;i=I>>>22&255;J=K>>>22&255;M=L>>>22&255;do{if((K|I|L)>>>0>1073741823>>>0){if(I>>>0<1073741824>>>0){N=i}else{N=-I>>31>>>22&255}if(K>>>0<1073741824>>>0){O=J}else{O=-K>>31>>>22&255}if(L>>>0<1073741824>>>0){P=M;Q=O;R=N;break}P=-L>>31>>>22&255;Q=O;R=N}else{P=M;Q=J;R=i}}while(0);a[H]=P;a[H+1|0]=Q;a[H+2|0]=R;i=G+1|0;if((i|0)<(j|0)){G=i;H=H+3|0}else{q=j;break}}r=d+11200|0;s=d+11204|0;t=d+11208|0;u=c[r>>2]|0;v=u+(q<<2)|0;c[v>>2]=0;w=c[s>>2]|0;x=w+(q<<2)|0;c[x>>2]=0;y=c[t>>2]|0;z=y+(q<<2)|0;c[z>>2]=0;return}function hBb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;do{if((k|0)<2048){if((j|0)<=0){m=0;break}n=d+11300|0;o=d+11304|0;p=d+11308|0;q=d+11312|0;r=d+11316|0;s=d+11320|0;t=0;u=i;while(1){v=(b[l+(t<<1)>>1]<<2)-65536|0;w=(b[h+(t<<1)>>1]<<2)-65536|0;x=(ca((b[e+(t<<1)>>1]<<2)-(c[n>>2]|0)|0,c[o>>2]|0)|0)+2097152|0;y=x+(ca(c[p>>2]|0,w)|0)|0;z=(ca(c[q>>2]|0,w)|0)+x|0;w=z+(ca(c[r>>2]|0,v)|0)|0;z=(ca(c[s>>2]|0,v)|0)+x|0;x=y>>>22&255;v=w>>>22&255;A=z>>>22&255;do{if((w|y|z)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){B=x}else{B=-y>>31>>>22&255}if(w>>>0<1073741824>>>0){C=v}else{C=-w>>31>>>22&255}if(z>>>0<1073741824>>>0){D=A;E=C;F=B;break}D=-z>>31>>>22&255;E=C;F=B}else{D=A;E=v;F=x}}while(0);a[u]=D;a[u+1|0]=E;a[u+2|0]=F;x=t+1|0;if((x|0)<(j|0)){t=x;u=u+3|0}else{m=j;break}}}else{u=c[f+4>>2]|0;t=c[g+4>>2]|0;if((j|0)<=0){m=0;break}s=d+11300|0;r=d+11304|0;q=d+11308|0;p=d+11312|0;o=d+11316|0;n=d+11320|0;x=0;v=i;while(1){A=((b[u+(x<<1)>>1]|0)+(b[l+(x<<1)>>1]|0)<<1)-65536|0;z=((b[t+(x<<1)>>1]|0)+(b[h+(x<<1)>>1]|0)<<1)-65536|0;w=(ca((b[e+(x<<1)>>1]<<2)-(c[s>>2]|0)|0,c[r>>2]|0)|0)+2097152|0;y=(ca(z,c[q>>2]|0)|0)+w|0;G=(ca(c[p>>2]|0,z)|0)+w|0;z=G+(ca(c[o>>2]|0,A)|0)|0;G=(ca(c[n>>2]|0,A)|0)+w|0;w=y>>>22&255;A=z>>>22&255;H=G>>>22&255;do{if((z|y|G)>>>0>1073741823>>>0){if(y>>>0<1073741824>>>0){I=w}else{I=-y>>31>>>22&255}if(z>>>0<1073741824>>>0){J=A}else{J=-z>>31>>>22&255}if(G>>>0<1073741824>>>0){K=H;L=J;M=I;break}K=-G>>31>>>22&255;L=J;M=I}else{K=H;L=A;M=w}}while(0);a[v]=K;a[v+1|0]=L;a[v+2|0]=M;w=x+1|0;if((w|0)<(j|0)){x=w;v=v+3|0}else{m=j;break}}}}while(0);c[(c[d+11200>>2]|0)+(m<<2)>>2]=0;c[(c[d+11204>>2]|0)+(m<<2)>>2]=0;c[(c[d+11208>>2]|0)+(m<<2)>>2]=0;return}function iBb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;if((n|0)<=0){p=0;q=0;r=0;s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}o=(g|0)>0;l=(k|0)>0;C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=d+11200|0;J=d+11204|0;K=d+11208|0;d=0;L=0;M=0;N=m;m=0;while(1){if(o){O=0;P=512;do{P=(ca(b[e+(O<<1)>>1]|0,b[(c[f+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+P|0;O=O+1|0;}while((O|0)<(g|0));Q=P>>10}else{Q=0}if(l){O=0;R=-67108352;S=-67108352;do{T=b[h+(O<<1)>>1]|0;R=(ca(T,b[(c[i+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+R|0;S=(ca(b[(c[j+(O<<2)>>2]|0)+(m<<1)>>1]|0,T)|0)+S|0;O=O+1|0;}while((O|0)<(k|0));U=R>>10;V=S>>10}else{U=-65536;V=-65536}O=(ca(Q-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;P=O+(ca(c[E>>2]|0,V)|0)|0;T=(ca(c[F>>2]|0,V)|0)+O|0;W=T+(ca(c[G>>2]|0,U)|0)|0;T=(ca(c[H>>2]|0,U)|0)+O|0;do{if((W|P|T)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){X=P}else{X=-P>>31&1073741823}if(W>>>0<1073741824>>>0){Y=W}else{Y=-W>>31&1073741823}if(T>>>0<1073741824>>>0){Z=T;_=Y;$=X;break}Z=-T>>31&1073741823;_=Y;$=X}else{Z=T;_=W;$=P}}while(0);P=c[I>>2]|0;W=P+(m<<2)|0;T=m+1|0;S=m+2|0;R=((c[W>>2]|0)+(M*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+($>>22)|0;P=c[J>>2]|0;O=P+(m<<2)|0;aa=((c[O>>2]|0)+(L*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(_>>22)|0;P=c[K>>2]|0;ba=P+(m<<2)|0;da=((c[ba>>2]|0)+(d*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(Z>>22)|0;c[W>>2]=M;c[O>>2]=L;c[ba>>2]=d;ba=R>>7;O=aa>>6;W=da>>7;if((ba|0)<0){ea=0}else{ea=(ba|0)>1?1:ba}if((O|0)<0){fa=0}else{fa=(O|0)>3?3:O}if((W|0)<0){ga=0}else{ga=(W|0)>1?1:W}W=(ea*-255|0)+R|0;R=(fa*-85|0)+aa|0;aa=(ga*-255|0)+da|0;a[N]=(fa<<1)+ea+(ga<<3);if((T|0)<(n|0)){d=aa;L=R;M=W;N=N+1|0;m=T}else{p=aa;q=R;r=W;s=n;t=I;u=J;v=K;break}}w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}function jBb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=0;s=0;t=0;u=d+11200|0;v=d+11204|0;w=d+11208|0;x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}D=d+11300|0;E=d+11304|0;F=d+11308|0;G=d+11312|0;H=d+11316|0;I=d+11320|0;J=d+11200|0;K=d+11204|0;L=d+11208|0;d=0;M=0;N=0;O=0;P=i;while(1){i=ca(b[m+(O<<1)>>1]|0,g)|0;Q=(ca(b[h+(O<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(O<<1)>>1]|0,p)|0;R=i-67108864+(ca(b[n+(O<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(O<<1)>>1]|0,p)|0;S=i-67108864+(ca(b[o+(O<<1)>>1]|0,l)|0)>>10;i=(ca(Q-(c[D>>2]|0)|0,c[E>>2]|0)|0)+2097152|0;Q=(ca(S,c[F>>2]|0)|0)+i|0;T=(ca(c[G>>2]|0,S)|0)+i|0;S=T+(ca(c[H>>2]|0,R)|0)|0;T=(ca(c[I>>2]|0,R)|0)+i|0;do{if((S|Q|T)>>>0>1073741823>>>0){if(Q>>>0<1073741824>>>0){U=Q}else{U=-Q>>31&1073741823}if(S>>>0<1073741824>>>0){V=S}else{V=-S>>31&1073741823}if(T>>>0<1073741824>>>0){W=T;X=V;Y=U;break}W=-T>>31&1073741823;X=V;Y=U}else{W=T;X=S;Y=Q}}while(0);Q=c[J>>2]|0;S=Q+(O<<2)|0;T=O+1|0;i=O+2|0;R=((c[S>>2]|0)+(N*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(Y>>22)|0;Q=c[K>>2]|0;Z=Q+(O<<2)|0;_=((c[Z>>2]|0)+(M*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(X>>22)|0;Q=c[L>>2]|0;$=Q+(O<<2)|0;aa=((c[$>>2]|0)+(d*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(W>>22)|0;c[S>>2]=N;c[Z>>2]=M;c[$>>2]=d;$=R>>7;Z=_>>6;S=aa>>7;if(($|0)<0){ba=0}else{ba=($|0)>1?1:$}if((Z|0)<0){da=0}else{da=(Z|0)>3?3:Z}if((S|0)<0){ea=0}else{ea=(S|0)>1?1:S}S=(ba*-255|0)+R|0;R=(da*-85|0)+_|0;_=(ea*-255|0)+aa|0;a[P]=(da<<1)+ba+(ea<<3);if((T|0)<(j|0)){d=_;M=R;N=S;O=T;P=P+1|0}else{q=_;r=R;s=S;t=j;u=J;v=K;w=L;break}}x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}function kBb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}k=d+11300|0;z=d+11304|0;A=d+11308|0;B=d+11312|0;C=d+11316|0;D=d+11320|0;E=d+11200|0;F=d+11204|0;G=d+11208|0;H=0;I=0;J=0;K=0;L=i;while(1){M=(b[l+(K<<1)>>1]<<2)-65536|0;N=(b[h+(K<<1)>>1]<<2)-65536|0;O=(ca((b[e+(K<<1)>>1]<<2)-(c[k>>2]|0)|0,c[z>>2]|0)|0)+2097152|0;P=O+(ca(c[A>>2]|0,N)|0)|0;Q=(ca(c[B>>2]|0,N)|0)+O|0;N=Q+(ca(c[C>>2]|0,M)|0)|0;Q=(ca(c[D>>2]|0,M)|0)+O|0;do{if((N|P|Q)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){R=P}else{R=-P>>31&1073741823}if(N>>>0<1073741824>>>0){S=N}else{S=-N>>31&1073741823}if(Q>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-Q>>31&1073741823;U=S;V=R}else{T=Q;U=N;V=P}}while(0);P=c[E>>2]|0;N=P+(K<<2)|0;Q=K+1|0;O=K+2|0;M=((c[N>>2]|0)+(J*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(V>>22)|0;P=c[F>>2]|0;W=P+(K<<2)|0;X=((c[W>>2]|0)+(I*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(U>>22)|0;P=c[G>>2]|0;Y=P+(K<<2)|0;Z=((c[Y>>2]|0)+(H*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(T>>22)|0;c[N>>2]=J;c[W>>2]=I;c[Y>>2]=H;Y=M>>7;W=X>>6;N=Z>>7;if((Y|0)<0){_=0}else{_=(Y|0)>1?1:Y}if((W|0)<0){$=0}else{$=(W|0)>3?3:W}if((N|0)<0){aa=0}else{aa=(N|0)>1?1:N}N=(_*-255|0)+M|0;M=($*-85|0)+X|0;X=(aa*-255|0)+Z|0;a[L]=($<<1)+_+(aa<<3);if((Q|0)<(j|0)){H=X;I=M;J=N;K=Q;L=L+1|0}else{m=j;n=N;o=M;p=X;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}else{L=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}g=d+11300|0;K=d+11304|0;J=d+11308|0;I=d+11312|0;H=d+11316|0;aa=d+11320|0;_=d+11200|0;$=d+11204|0;T=d+11208|0;G=0;U=0;F=0;V=0;E=i;while(1){i=((b[L+(V<<1)>>1]|0)+(b[l+(V<<1)>>1]|0)<<1)-65536|0;R=((b[f+(V<<1)>>1]|0)+(b[h+(V<<1)>>1]|0)<<1)-65536|0;S=(ca((b[e+(V<<1)>>1]<<2)-(c[g>>2]|0)|0,c[K>>2]|0)|0)+2097152|0;D=(ca(R,c[J>>2]|0)|0)+S|0;C=(ca(c[I>>2]|0,R)|0)+S|0;R=C+(ca(c[H>>2]|0,i)|0)|0;C=(ca(c[aa>>2]|0,i)|0)+S|0;do{if((R|D|C)>>>0>1073741823>>>0){if(D>>>0<1073741824>>>0){ba=D}else{ba=-D>>31&1073741823}if(R>>>0<1073741824>>>0){da=R}else{da=-R>>31&1073741823}if(C>>>0<1073741824>>>0){ea=C;fa=da;ga=ba;break}ea=-C>>31&1073741823;fa=da;ga=ba}else{ea=C;fa=R;ga=D}}while(0);D=c[_>>2]|0;R=D+(V<<2)|0;C=V+1|0;S=V+2|0;i=((c[R>>2]|0)+(F*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ga>>22)|0;D=c[$>>2]|0;B=D+(V<<2)|0;A=((c[B>>2]|0)+(U*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(fa>>22)|0;D=c[T>>2]|0;z=D+(V<<2)|0;k=((c[z>>2]|0)+(G*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ea>>22)|0;c[R>>2]=F;c[B>>2]=U;c[z>>2]=G;z=i>>7;B=A>>6;R=k>>7;if((z|0)<0){ha=0}else{ha=(z|0)>1?1:z}if((B|0)<0){ia=0}else{ia=(B|0)>3?3:B}if((R|0)<0){ja=0}else{ja=(R|0)>1?1:R}R=(ha*-255|0)+i|0;i=(ia*-85|0)+A|0;A=(ja*-255|0)+k|0;a[E]=(ia<<1)+ha+(ja<<3);if((C|0)<(j|0)){G=A;U=i;F=R;V=C;E=E+1|0}else{m=j;n=R;o=i;p=A;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}}function lBb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;if((n|0)<=0){p=0;q=0;r=0;s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}o=(g|0)>0;l=(k|0)>0;C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=d+11200|0;J=d+11204|0;K=d+11208|0;d=0;L=0;M=0;N=m;m=0;while(1){if(o){O=0;P=512;do{P=(ca(b[e+(O<<1)>>1]|0,b[(c[f+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+P|0;O=O+1|0;}while((O|0)<(g|0));Q=P>>10}else{Q=0}if(l){O=0;R=-67108352;S=-67108352;do{T=b[h+(O<<1)>>1]|0;R=(ca(T,b[(c[i+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+R|0;S=(ca(b[(c[j+(O<<2)>>2]|0)+(m<<1)>>1]|0,T)|0)+S|0;O=O+1|0;}while((O|0)<(k|0));U=R>>10;V=S>>10}else{U=-65536;V=-65536}O=(ca(Q-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;P=O+(ca(c[E>>2]|0,V)|0)|0;T=(ca(c[F>>2]|0,V)|0)+O|0;W=T+(ca(c[G>>2]|0,U)|0)|0;T=(ca(c[H>>2]|0,U)|0)+O|0;do{if((W|P|T)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){X=P}else{X=-P>>31&1073741823}if(W>>>0<1073741824>>>0){Y=W}else{Y=-W>>31&1073741823}if(T>>>0<1073741824>>>0){Z=T;_=Y;$=X;break}Z=-T>>31&1073741823;_=Y;$=X}else{Z=T;_=W;$=P}}while(0);P=c[I>>2]|0;W=P+(m<<2)|0;T=m+1|0;S=m+2|0;R=((c[W>>2]|0)+(M*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+($>>22)|0;P=c[J>>2]|0;O=P+(m<<2)|0;aa=((c[O>>2]|0)+(L*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(_>>22)|0;P=c[K>>2]|0;ba=P+(m<<2)|0;da=((c[ba>>2]|0)+(d*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(Z>>22)|0;c[W>>2]=M;c[O>>2]=L;c[ba>>2]=d;ba=R>>7;O=aa>>6;W=da>>7;if((ba|0)<0){ea=0}else{ea=(ba|0)>1?1:ba}if((O|0)<0){fa=0}else{fa=(O|0)>3?3:O}if((W|0)<0){ga=0}else{ga=(W|0)>1?1:W}W=(ea*-255|0)+R|0;R=(fa*-85|0)+aa|0;aa=(ga*-255|0)+da|0;a[N]=(fa<<1)+(ea<<3)+ga;if((T|0)<(n|0)){d=aa;L=R;M=W;N=N+1|0;m=T}else{p=aa;q=R;r=W;s=n;t=I;u=J;v=K;break}}w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}function mBb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=0;s=0;t=0;u=d+11200|0;v=d+11204|0;w=d+11208|0;x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}D=d+11300|0;E=d+11304|0;F=d+11308|0;G=d+11312|0;H=d+11316|0;I=d+11320|0;J=d+11200|0;K=d+11204|0;L=d+11208|0;d=0;M=0;N=0;O=0;P=i;while(1){i=ca(b[m+(O<<1)>>1]|0,g)|0;Q=(ca(b[h+(O<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(O<<1)>>1]|0,p)|0;R=i-67108864+(ca(b[n+(O<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(O<<1)>>1]|0,p)|0;S=i-67108864+(ca(b[o+(O<<1)>>1]|0,l)|0)>>10;i=(ca(Q-(c[D>>2]|0)|0,c[E>>2]|0)|0)+2097152|0;Q=(ca(S,c[F>>2]|0)|0)+i|0;T=(ca(c[G>>2]|0,S)|0)+i|0;S=T+(ca(c[H>>2]|0,R)|0)|0;T=(ca(c[I>>2]|0,R)|0)+i|0;do{if((S|Q|T)>>>0>1073741823>>>0){if(Q>>>0<1073741824>>>0){U=Q}else{U=-Q>>31&1073741823}if(S>>>0<1073741824>>>0){V=S}else{V=-S>>31&1073741823}if(T>>>0<1073741824>>>0){W=T;X=V;Y=U;break}W=-T>>31&1073741823;X=V;Y=U}else{W=T;X=S;Y=Q}}while(0);Q=c[J>>2]|0;S=Q+(O<<2)|0;T=O+1|0;i=O+2|0;R=((c[S>>2]|0)+(N*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(Y>>22)|0;Q=c[K>>2]|0;Z=Q+(O<<2)|0;_=((c[Z>>2]|0)+(M*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(X>>22)|0;Q=c[L>>2]|0;$=Q+(O<<2)|0;aa=((c[$>>2]|0)+(d*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(W>>22)|0;c[S>>2]=N;c[Z>>2]=M;c[$>>2]=d;$=R>>7;Z=_>>6;S=aa>>7;if(($|0)<0){ba=0}else{ba=($|0)>1?1:$}if((Z|0)<0){da=0}else{da=(Z|0)>3?3:Z}if((S|0)<0){ea=0}else{ea=(S|0)>1?1:S}S=(ba*-255|0)+R|0;R=(da*-85|0)+_|0;_=(ea*-255|0)+aa|0;a[P]=(da<<1)+(ba<<3)+ea;if((T|0)<(j|0)){d=_;M=R;N=S;O=T;P=P+1|0}else{q=_;r=R;s=S;t=j;u=J;v=K;w=L;break}}x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}function nBb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}k=d+11300|0;z=d+11304|0;A=d+11308|0;B=d+11312|0;C=d+11316|0;D=d+11320|0;E=d+11200|0;F=d+11204|0;G=d+11208|0;H=0;I=0;J=0;K=0;L=i;while(1){M=(b[l+(K<<1)>>1]<<2)-65536|0;N=(b[h+(K<<1)>>1]<<2)-65536|0;O=(ca((b[e+(K<<1)>>1]<<2)-(c[k>>2]|0)|0,c[z>>2]|0)|0)+2097152|0;P=O+(ca(c[A>>2]|0,N)|0)|0;Q=(ca(c[B>>2]|0,N)|0)+O|0;N=Q+(ca(c[C>>2]|0,M)|0)|0;Q=(ca(c[D>>2]|0,M)|0)+O|0;do{if((N|P|Q)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){R=P}else{R=-P>>31&1073741823}if(N>>>0<1073741824>>>0){S=N}else{S=-N>>31&1073741823}if(Q>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-Q>>31&1073741823;U=S;V=R}else{T=Q;U=N;V=P}}while(0);P=c[E>>2]|0;N=P+(K<<2)|0;Q=K+1|0;O=K+2|0;M=((c[N>>2]|0)+(J*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(V>>22)|0;P=c[F>>2]|0;W=P+(K<<2)|0;X=((c[W>>2]|0)+(I*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(U>>22)|0;P=c[G>>2]|0;Y=P+(K<<2)|0;Z=((c[Y>>2]|0)+(H*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(T>>22)|0;c[N>>2]=J;c[W>>2]=I;c[Y>>2]=H;Y=M>>7;W=X>>6;N=Z>>7;if((Y|0)<0){_=0}else{_=(Y|0)>1?1:Y}if((W|0)<0){$=0}else{$=(W|0)>3?3:W}if((N|0)<0){aa=0}else{aa=(N|0)>1?1:N}N=(_*-255|0)+M|0;M=($*-85|0)+X|0;X=(aa*-255|0)+Z|0;a[L]=($<<1)+(_<<3)+aa;if((Q|0)<(j|0)){H=X;I=M;J=N;K=Q;L=L+1|0}else{m=j;n=N;o=M;p=X;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}else{L=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}g=d+11300|0;K=d+11304|0;J=d+11308|0;I=d+11312|0;H=d+11316|0;aa=d+11320|0;_=d+11200|0;$=d+11204|0;T=d+11208|0;G=0;U=0;F=0;V=0;E=i;while(1){i=((b[L+(V<<1)>>1]|0)+(b[l+(V<<1)>>1]|0)<<1)-65536|0;R=((b[f+(V<<1)>>1]|0)+(b[h+(V<<1)>>1]|0)<<1)-65536|0;S=(ca((b[e+(V<<1)>>1]<<2)-(c[g>>2]|0)|0,c[K>>2]|0)|0)+2097152|0;D=(ca(R,c[J>>2]|0)|0)+S|0;C=(ca(c[I>>2]|0,R)|0)+S|0;R=C+(ca(c[H>>2]|0,i)|0)|0;C=(ca(c[aa>>2]|0,i)|0)+S|0;do{if((R|D|C)>>>0>1073741823>>>0){if(D>>>0<1073741824>>>0){ba=D}else{ba=-D>>31&1073741823}if(R>>>0<1073741824>>>0){da=R}else{da=-R>>31&1073741823}if(C>>>0<1073741824>>>0){ea=C;fa=da;ga=ba;break}ea=-C>>31&1073741823;fa=da;ga=ba}else{ea=C;fa=R;ga=D}}while(0);D=c[_>>2]|0;R=D+(V<<2)|0;C=V+1|0;S=V+2|0;i=((c[R>>2]|0)+(F*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ga>>22)|0;D=c[$>>2]|0;B=D+(V<<2)|0;A=((c[B>>2]|0)+(U*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(fa>>22)|0;D=c[T>>2]|0;z=D+(V<<2)|0;k=((c[z>>2]|0)+(G*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ea>>22)|0;c[R>>2]=F;c[B>>2]=U;c[z>>2]=G;z=i>>7;B=A>>6;R=k>>7;if((z|0)<0){ha=0}else{ha=(z|0)>1?1:z}if((B|0)<0){ia=0}else{ia=(B|0)>3?3:B}if((R|0)<0){ja=0}else{ja=(R|0)>1?1:R}R=(ha*-255|0)+i|0;i=(ia*-85|0)+A|0;A=(ja*-255|0)+k|0;a[E]=(ia<<1)+(ha<<3)+ja;if((C|0)<(j|0)){G=A;U=i;F=R;V=C;E=E+1|0}else{m=j;n=R;o=i;p=A;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}}function oBb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;if((n|0)<=0){p=0;q=0;r=0;s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}o=(g|0)>0;l=(k|0)>0;C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=d+11200|0;J=d+11204|0;K=d+11208|0;d=0;L=0;M=0;N=m;m=0;while(1){if(o){O=0;P=512;do{P=(ca(b[e+(O<<1)>>1]|0,b[(c[f+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+P|0;O=O+1|0;}while((O|0)<(g|0));Q=P>>10}else{Q=0}if(l){O=0;R=-67108352;S=-67108352;do{T=b[h+(O<<1)>>1]|0;R=(ca(T,b[(c[i+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+R|0;S=(ca(b[(c[j+(O<<2)>>2]|0)+(m<<1)>>1]|0,T)|0)+S|0;O=O+1|0;}while((O|0)<(k|0));U=R>>10;V=S>>10}else{U=-65536;V=-65536}O=(ca(Q-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;P=O+(ca(c[E>>2]|0,V)|0)|0;T=(ca(c[F>>2]|0,V)|0)+O|0;W=T+(ca(c[G>>2]|0,U)|0)|0;T=(ca(c[H>>2]|0,U)|0)+O|0;do{if((W|P|T)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){X=P}else{X=-P>>31&1073741823}if(W>>>0<1073741824>>>0){Y=W}else{Y=-W>>31&1073741823}if(T>>>0<1073741824>>>0){Z=T;_=Y;$=X;break}Z=-T>>31&1073741823;_=Y;$=X}else{Z=T;_=W;$=P}}while(0);P=c[I>>2]|0;W=P+(m<<2)|0;T=m+1|0;S=m+2|0;R=((c[W>>2]|0)+(M*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+($>>22)|0;P=c[J>>2]|0;O=P+(m<<2)|0;aa=((c[O>>2]|0)+(L*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(_>>22)|0;P=c[K>>2]|0;ba=P+(m<<2)|0;da=((c[ba>>2]|0)+(d*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(Z>>22)|0;c[W>>2]=M;c[O>>2]=L;c[ba>>2]=d;ba=R>>5;O=aa>>5;W=da>>6;if((ba|0)<0){ea=0}else{ea=(ba|0)>7?7:ba}if((O|0)<0){fa=0}else{fa=(O|0)>7?7:O}if((W|0)<0){ga=0}else{ga=(W|0)>3?3:W}W=(ea*-36|0)+R|0;R=(fa*-36|0)+aa|0;aa=(ga*-85|0)+da|0;a[N]=(fa<<3)+ea+(ga<<6);if((T|0)<(n|0)){d=aa;L=R;M=W;N=N+1|0;m=T}else{p=aa;q=R;r=W;s=n;t=I;u=J;v=K;break}}w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}function pBb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=0;s=0;t=0;u=d+11200|0;v=d+11204|0;w=d+11208|0;x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}D=d+11300|0;E=d+11304|0;F=d+11308|0;G=d+11312|0;H=d+11316|0;I=d+11320|0;J=d+11200|0;K=d+11204|0;L=d+11208|0;d=0;M=0;N=0;O=0;P=i;while(1){i=ca(b[m+(O<<1)>>1]|0,g)|0;Q=(ca(b[h+(O<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(O<<1)>>1]|0,p)|0;R=i-67108864+(ca(b[n+(O<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(O<<1)>>1]|0,p)|0;S=i-67108864+(ca(b[o+(O<<1)>>1]|0,l)|0)>>10;i=(ca(Q-(c[D>>2]|0)|0,c[E>>2]|0)|0)+2097152|0;Q=(ca(S,c[F>>2]|0)|0)+i|0;T=(ca(c[G>>2]|0,S)|0)+i|0;S=T+(ca(c[H>>2]|0,R)|0)|0;T=(ca(c[I>>2]|0,R)|0)+i|0;do{if((S|Q|T)>>>0>1073741823>>>0){if(Q>>>0<1073741824>>>0){U=Q}else{U=-Q>>31&1073741823}if(S>>>0<1073741824>>>0){V=S}else{V=-S>>31&1073741823}if(T>>>0<1073741824>>>0){W=T;X=V;Y=U;break}W=-T>>31&1073741823;X=V;Y=U}else{W=T;X=S;Y=Q}}while(0);Q=c[J>>2]|0;S=Q+(O<<2)|0;T=O+1|0;i=O+2|0;R=((c[S>>2]|0)+(N*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(Y>>22)|0;Q=c[K>>2]|0;Z=Q+(O<<2)|0;_=((c[Z>>2]|0)+(M*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(X>>22)|0;Q=c[L>>2]|0;$=Q+(O<<2)|0;aa=((c[$>>2]|0)+(d*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(W>>22)|0;c[S>>2]=N;c[Z>>2]=M;c[$>>2]=d;$=R>>5;Z=_>>5;S=aa>>6;if(($|0)<0){ba=0}else{ba=($|0)>7?7:$}if((Z|0)<0){da=0}else{da=(Z|0)>7?7:Z}if((S|0)<0){ea=0}else{ea=(S|0)>3?3:S}S=(ba*-36|0)+R|0;R=(da*-36|0)+_|0;_=(ea*-85|0)+aa|0;a[P]=(da<<3)+ba+(ea<<6);if((T|0)<(j|0)){d=_;M=R;N=S;O=T;P=P+1|0}else{q=_;r=R;s=S;t=j;u=J;v=K;w=L;break}}x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}function qBb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}k=d+11300|0;z=d+11304|0;A=d+11308|0;B=d+11312|0;C=d+11316|0;D=d+11320|0;E=d+11200|0;F=d+11204|0;G=d+11208|0;H=0;I=0;J=0;K=0;L=i;while(1){M=(b[l+(K<<1)>>1]<<2)-65536|0;N=(b[h+(K<<1)>>1]<<2)-65536|0;O=(ca((b[e+(K<<1)>>1]<<2)-(c[k>>2]|0)|0,c[z>>2]|0)|0)+2097152|0;P=O+(ca(c[A>>2]|0,N)|0)|0;Q=(ca(c[B>>2]|0,N)|0)+O|0;N=Q+(ca(c[C>>2]|0,M)|0)|0;Q=(ca(c[D>>2]|0,M)|0)+O|0;do{if((N|P|Q)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){R=P}else{R=-P>>31&1073741823}if(N>>>0<1073741824>>>0){S=N}else{S=-N>>31&1073741823}if(Q>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-Q>>31&1073741823;U=S;V=R}else{T=Q;U=N;V=P}}while(0);P=c[E>>2]|0;N=P+(K<<2)|0;Q=K+1|0;O=K+2|0;M=((c[N>>2]|0)+(J*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(V>>22)|0;P=c[F>>2]|0;W=P+(K<<2)|0;X=((c[W>>2]|0)+(I*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(U>>22)|0;P=c[G>>2]|0;Y=P+(K<<2)|0;Z=((c[Y>>2]|0)+(H*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(T>>22)|0;c[N>>2]=J;c[W>>2]=I;c[Y>>2]=H;Y=M>>5;W=X>>5;N=Z>>6;if((Y|0)<0){_=0}else{_=(Y|0)>7?7:Y}if((W|0)<0){$=0}else{$=(W|0)>7?7:W}if((N|0)<0){aa=0}else{aa=(N|0)>3?3:N}N=(_*-36|0)+M|0;M=($*-36|0)+X|0;X=(aa*-85|0)+Z|0;a[L]=($<<3)+_+(aa<<6);if((Q|0)<(j|0)){H=X;I=M;J=N;K=Q;L=L+1|0}else{m=j;n=N;o=M;p=X;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}else{L=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}g=d+11300|0;K=d+11304|0;J=d+11308|0;I=d+11312|0;H=d+11316|0;aa=d+11320|0;_=d+11200|0;$=d+11204|0;T=d+11208|0;G=0;U=0;F=0;V=0;E=i;while(1){i=((b[L+(V<<1)>>1]|0)+(b[l+(V<<1)>>1]|0)<<1)-65536|0;R=((b[f+(V<<1)>>1]|0)+(b[h+(V<<1)>>1]|0)<<1)-65536|0;S=(ca((b[e+(V<<1)>>1]<<2)-(c[g>>2]|0)|0,c[K>>2]|0)|0)+2097152|0;D=(ca(R,c[J>>2]|0)|0)+S|0;C=(ca(c[I>>2]|0,R)|0)+S|0;R=C+(ca(c[H>>2]|0,i)|0)|0;C=(ca(c[aa>>2]|0,i)|0)+S|0;do{if((R|D|C)>>>0>1073741823>>>0){if(D>>>0<1073741824>>>0){ba=D}else{ba=-D>>31&1073741823}if(R>>>0<1073741824>>>0){da=R}else{da=-R>>31&1073741823}if(C>>>0<1073741824>>>0){ea=C;fa=da;ga=ba;break}ea=-C>>31&1073741823;fa=da;ga=ba}else{ea=C;fa=R;ga=D}}while(0);D=c[_>>2]|0;R=D+(V<<2)|0;C=V+1|0;S=V+2|0;i=((c[R>>2]|0)+(F*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ga>>22)|0;D=c[$>>2]|0;B=D+(V<<2)|0;A=((c[B>>2]|0)+(U*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(fa>>22)|0;D=c[T>>2]|0;z=D+(V<<2)|0;k=((c[z>>2]|0)+(G*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ea>>22)|0;c[R>>2]=F;c[B>>2]=U;c[z>>2]=G;z=i>>5;B=A>>5;R=k>>6;if((z|0)<0){ha=0}else{ha=(z|0)>7?7:z}if((B|0)<0){ia=0}else{ia=(B|0)>7?7:B}if((R|0)<0){ja=0}else{ja=(R|0)>3?3:R}R=(ha*-36|0)+i|0;i=(ia*-36|0)+A|0;A=(ja*-85|0)+k|0;a[E]=(ia<<3)+ha+(ja<<6);if((C|0)<(j|0)){G=A;U=i;F=R;V=C;E=E+1|0}else{m=j;n=R;o=i;p=A;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}}function rBb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;if((n|0)<=0){p=0;q=0;r=0;s=0;t=d+11200|0;u=d+11204|0;v=d+11208|0;w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}o=(g|0)>0;l=(k|0)>0;C=d+11300|0;D=d+11304|0;E=d+11308|0;F=d+11312|0;G=d+11316|0;H=d+11320|0;I=d+11200|0;J=d+11204|0;K=d+11208|0;d=0;L=0;M=0;N=m;m=0;while(1){if(o){O=0;P=512;do{P=(ca(b[e+(O<<1)>>1]|0,b[(c[f+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+P|0;O=O+1|0;}while((O|0)<(g|0));Q=P>>10}else{Q=0}if(l){O=0;R=-67108352;S=-67108352;do{T=b[h+(O<<1)>>1]|0;R=(ca(T,b[(c[i+(O<<2)>>2]|0)+(m<<1)>>1]|0)|0)+R|0;S=(ca(b[(c[j+(O<<2)>>2]|0)+(m<<1)>>1]|0,T)|0)+S|0;O=O+1|0;}while((O|0)<(k|0));U=R>>10;V=S>>10}else{U=-65536;V=-65536}O=(ca(Q-(c[C>>2]|0)|0,c[D>>2]|0)|0)+2097152|0;P=O+(ca(c[E>>2]|0,V)|0)|0;T=(ca(c[F>>2]|0,V)|0)+O|0;W=T+(ca(c[G>>2]|0,U)|0)|0;T=(ca(c[H>>2]|0,U)|0)+O|0;do{if((W|P|T)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){X=P}else{X=-P>>31&1073741823}if(W>>>0<1073741824>>>0){Y=W}else{Y=-W>>31&1073741823}if(T>>>0<1073741824>>>0){Z=T;_=Y;$=X;break}Z=-T>>31&1073741823;_=Y;$=X}else{Z=T;_=W;$=P}}while(0);P=c[I>>2]|0;W=P+(m<<2)|0;T=m+1|0;S=m+2|0;R=((c[W>>2]|0)+(M*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+($>>22)|0;P=c[J>>2]|0;O=P+(m<<2)|0;aa=((c[O>>2]|0)+(L*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(_>>22)|0;P=c[K>>2]|0;ba=P+(m<<2)|0;da=((c[ba>>2]|0)+(d*7|0)+((c[P+(T<<2)>>2]|0)*5|0)+((c[P+(S<<2)>>2]|0)*3|0)>>4)+(Z>>22)|0;c[W>>2]=M;c[O>>2]=L;c[ba>>2]=d;ba=R>>5;O=aa>>5;W=da>>6;if((ba|0)<0){ea=0}else{ea=(ba|0)>7?7:ba}if((O|0)<0){fa=0}else{fa=(O|0)>7?7:O}if((W|0)<0){ga=0}else{ga=(W|0)>3?3:W}W=(ea*-36|0)+R|0;R=(fa*-36|0)+aa|0;aa=(ga*-85|0)+da|0;a[N]=(fa<<2)+(ea<<5)+ga;if((T|0)<(n|0)){d=aa;L=R;M=W;N=N+1|0;m=T}else{p=aa;q=R;r=W;s=n;t=I;u=J;v=K;break}}w=c[t>>2]|0;x=w+(s<<2)|0;c[x>>2]=r;y=c[u>>2]|0;z=y+(s<<2)|0;c[z>>2]=q;A=c[v>>2]|0;B=A+(s<<2)|0;c[B>>2]=p;return}function sBb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;if((j|0)<=0){q=0;r=0;s=0;t=0;u=d+11200|0;v=d+11204|0;w=d+11208|0;x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}D=d+11300|0;E=d+11304|0;F=d+11308|0;G=d+11312|0;H=d+11316|0;I=d+11320|0;J=d+11200|0;K=d+11204|0;L=d+11208|0;d=0;M=0;N=0;O=0;P=i;while(1){i=ca(b[m+(O<<1)>>1]|0,g)|0;Q=(ca(b[h+(O<<1)>>1]|0,k)|0)+i>>10;i=ca(b[e+(O<<1)>>1]|0,p)|0;R=i-67108864+(ca(b[n+(O<<1)>>1]|0,l)|0)>>10;i=ca(b[f+(O<<1)>>1]|0,p)|0;S=i-67108864+(ca(b[o+(O<<1)>>1]|0,l)|0)>>10;i=(ca(Q-(c[D>>2]|0)|0,c[E>>2]|0)|0)+2097152|0;Q=(ca(S,c[F>>2]|0)|0)+i|0;T=(ca(c[G>>2]|0,S)|0)+i|0;S=T+(ca(c[H>>2]|0,R)|0)|0;T=(ca(c[I>>2]|0,R)|0)+i|0;do{if((S|Q|T)>>>0>1073741823>>>0){if(Q>>>0<1073741824>>>0){U=Q}else{U=-Q>>31&1073741823}if(S>>>0<1073741824>>>0){V=S}else{V=-S>>31&1073741823}if(T>>>0<1073741824>>>0){W=T;X=V;Y=U;break}W=-T>>31&1073741823;X=V;Y=U}else{W=T;X=S;Y=Q}}while(0);Q=c[J>>2]|0;S=Q+(O<<2)|0;T=O+1|0;i=O+2|0;R=((c[S>>2]|0)+(N*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(Y>>22)|0;Q=c[K>>2]|0;Z=Q+(O<<2)|0;_=((c[Z>>2]|0)+(M*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(X>>22)|0;Q=c[L>>2]|0;$=Q+(O<<2)|0;aa=((c[$>>2]|0)+(d*7|0)+((c[Q+(T<<2)>>2]|0)*5|0)+((c[Q+(i<<2)>>2]|0)*3|0)>>4)+(W>>22)|0;c[S>>2]=N;c[Z>>2]=M;c[$>>2]=d;$=R>>5;Z=_>>5;S=aa>>6;if(($|0)<0){ba=0}else{ba=($|0)>7?7:$}if((Z|0)<0){da=0}else{da=(Z|0)>7?7:Z}if((S|0)<0){ea=0}else{ea=(S|0)>3?3:S}S=(ba*-36|0)+R|0;R=(da*-36|0)+_|0;_=(ea*-85|0)+aa|0;a[P]=(da<<2)+(ba<<5)+ea;if((T|0)<(j|0)){d=_;M=R;N=S;O=T;P=P+1|0}else{q=_;r=R;s=S;t=j;u=J;v=K;w=L;break}}x=c[u>>2]|0;y=x+(t<<2)|0;c[y>>2]=s;z=c[v>>2]|0;A=z+(t<<2)|0;c[A>>2]=r;B=c[w>>2]|0;C=B+(t<<2)|0;c[C>>2]=q;return}function tBb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}k=d+11300|0;z=d+11304|0;A=d+11308|0;B=d+11312|0;C=d+11316|0;D=d+11320|0;E=d+11200|0;F=d+11204|0;G=d+11208|0;H=0;I=0;J=0;K=0;L=i;while(1){M=(b[l+(K<<1)>>1]<<2)-65536|0;N=(b[h+(K<<1)>>1]<<2)-65536|0;O=(ca((b[e+(K<<1)>>1]<<2)-(c[k>>2]|0)|0,c[z>>2]|0)|0)+2097152|0;P=O+(ca(c[A>>2]|0,N)|0)|0;Q=(ca(c[B>>2]|0,N)|0)+O|0;N=Q+(ca(c[C>>2]|0,M)|0)|0;Q=(ca(c[D>>2]|0,M)|0)+O|0;do{if((N|P|Q)>>>0>1073741823>>>0){if(P>>>0<1073741824>>>0){R=P}else{R=-P>>31&1073741823}if(N>>>0<1073741824>>>0){S=N}else{S=-N>>31&1073741823}if(Q>>>0<1073741824>>>0){T=Q;U=S;V=R;break}T=-Q>>31&1073741823;U=S;V=R}else{T=Q;U=N;V=P}}while(0);P=c[E>>2]|0;N=P+(K<<2)|0;Q=K+1|0;O=K+2|0;M=((c[N>>2]|0)+(J*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(V>>22)|0;P=c[F>>2]|0;W=P+(K<<2)|0;X=((c[W>>2]|0)+(I*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(U>>22)|0;P=c[G>>2]|0;Y=P+(K<<2)|0;Z=((c[Y>>2]|0)+(H*7|0)+((c[P+(Q<<2)>>2]|0)*5|0)+((c[P+(O<<2)>>2]|0)*3|0)>>4)+(T>>22)|0;c[N>>2]=J;c[W>>2]=I;c[Y>>2]=H;Y=M>>5;W=X>>5;N=Z>>6;if((Y|0)<0){_=0}else{_=(Y|0)>7?7:Y}if((W|0)<0){$=0}else{$=(W|0)>7?7:W}if((N|0)<0){aa=0}else{aa=(N|0)>3?3:N}N=(_*-36|0)+M|0;M=($*-36|0)+X|0;X=(aa*-85|0)+Z|0;a[L]=($<<2)+(_<<5)+aa;if((Q|0)<(j|0)){H=X;I=M;J=N;K=Q;L=L+1|0}else{m=j;n=N;o=M;p=X;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}else{L=c[f+4>>2]|0;f=c[g+4>>2]|0;if((j|0)<=0){m=0;n=0;o=0;p=0;q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}g=d+11300|0;K=d+11304|0;J=d+11308|0;I=d+11312|0;H=d+11316|0;aa=d+11320|0;_=d+11200|0;$=d+11204|0;T=d+11208|0;G=0;U=0;F=0;V=0;E=i;while(1){i=((b[L+(V<<1)>>1]|0)+(b[l+(V<<1)>>1]|0)<<1)-65536|0;R=((b[f+(V<<1)>>1]|0)+(b[h+(V<<1)>>1]|0)<<1)-65536|0;S=(ca((b[e+(V<<1)>>1]<<2)-(c[g>>2]|0)|0,c[K>>2]|0)|0)+2097152|0;D=(ca(R,c[J>>2]|0)|0)+S|0;C=(ca(c[I>>2]|0,R)|0)+S|0;R=C+(ca(c[H>>2]|0,i)|0)|0;C=(ca(c[aa>>2]|0,i)|0)+S|0;do{if((R|D|C)>>>0>1073741823>>>0){if(D>>>0<1073741824>>>0){ba=D}else{ba=-D>>31&1073741823}if(R>>>0<1073741824>>>0){da=R}else{da=-R>>31&1073741823}if(C>>>0<1073741824>>>0){ea=C;fa=da;ga=ba;break}ea=-C>>31&1073741823;fa=da;ga=ba}else{ea=C;fa=R;ga=D}}while(0);D=c[_>>2]|0;R=D+(V<<2)|0;C=V+1|0;S=V+2|0;i=((c[R>>2]|0)+(F*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ga>>22)|0;D=c[$>>2]|0;B=D+(V<<2)|0;A=((c[B>>2]|0)+(U*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(fa>>22)|0;D=c[T>>2]|0;z=D+(V<<2)|0;k=((c[z>>2]|0)+(G*7|0)+((c[D+(C<<2)>>2]|0)*5|0)+((c[D+(S<<2)>>2]|0)*3|0)>>4)+(ea>>22)|0;c[R>>2]=F;c[B>>2]=U;c[z>>2]=G;z=i>>5;B=A>>5;R=k>>6;if((z|0)<0){ha=0}else{ha=(z|0)>7?7:z}if((B|0)<0){ia=0}else{ia=(B|0)>7?7:B}if((R|0)<0){ja=0}else{ja=(R|0)>3?3:R}R=(ha*-36|0)+i|0;i=(ia*-36|0)+A|0;A=(ja*-85|0)+k|0;a[E]=(ia<<2)+(ha<<5)+ja;if((C|0)<(j|0)){G=A;U=i;F=R;V=C;E=E+1|0}else{m=j;n=R;o=i;p=A;break}}q=d+11200|0;r=c[q>>2]|0;s=r+(m<<2)|0;c[s>>2]=n;t=d+11204|0;u=c[t>>2]|0;v=u+(m<<2)|0;c[v>>2]=o;w=d+11208|0;x=c[w>>2]|0;y=x+(m<<2)|0;c[y>>2]=p;return}}function uBb(d,f,g,h,j,k,l,m,n,o,p,q){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;q=i;r=d+52|0;s=qKb(c[r>>2]|0)|0;t=(a[s+7|0]|0)<0&(n|0)!=0;u=29-((e[s+8>>1]|0)>>>11&15)|0;s=(p|0)>0;if(s){v=(h|0)>0;w=(m|0)>0;x=d+11300|0;y=d+11304|0;z=d+11308|0;A=d+11312|0;B=d+11316|0;C=d+11320|0;d=(u|0)==22;D=o+4|0;E=o+8|0;F=o+12|0;G=0;H=0;I=0;while(1){if(v){J=0;K=512;do{K=(ca(b[f+(J<<1)>>1]|0,b[(c[g+(J<<2)>>2]|0)+(G<<1)>>1]|0)|0)+K|0;J=J+1|0;}while((J|0)<(h|0));L=K>>10}else{L=0}if(w){J=0;M=-67108352;N=-67108352;do{O=b[j+(J<<1)>>1]|0;M=(ca(O,b[(c[k+(J<<2)>>2]|0)+(G<<1)>>1]|0)|0)+M|0;N=(ca(b[(c[l+(J<<2)>>2]|0)+(G<<1)>>1]|0,O)|0)+N|0;J=J+1|0;}while((J|0)<(m|0));P=M>>10;Q=N>>10}else{P=-65536;Q=-65536}a:do{if(t){do{if(v){J=262144;K=0;do{J=(ca(b[f+(K<<1)>>1]|0,b[(c[n+(K<<2)>>2]|0)+(G<<1)>>1]|0)|0)+J|0;K=K+1|0;}while((K|0)<(h|0));K=J>>19;O=K&255;if((K&256|0)==0){R=K&65535;S=O;break}if(K>>>0>255>>>0){T=-K>>31&255}else{T=O}U=T&255;V=T;break a}else{R=0;S=0}}while(0);U=R;V=S}else{U=I;V=H}}while(0);N=(ca(L-(c[x>>2]|0)|0,c[y>>2]|0)|0)+2097152|0;M=N+(ca(c[z>>2]|0,Q)|0)|0;O=(ca(c[A>>2]|0,Q)|0)+N|0;K=O+(ca(c[B>>2]|0,P)|0)|0;O=(ca(c[C>>2]|0,P)|0)+N|0;do{if((K|M|O)>>>0>1073741823>>>0){if(M>>>0<1073741824>>>0){W=M}else{W=-M>>31&1073741823}if(K>>>0<1073741824>>>0){X=K}else{X=-K>>31&1073741823}if(O>>>0<1073741824>>>0){Y=O;Z=X;_=W;break}Y=-O>>31&1073741823;Z=X;_=W}else{Y=O;Z=K;_=M}}while(0);do{if(d){a[(c[o>>2]|0)+G|0]=Z>>>22;a[(c[D>>2]|0)+G|0]=Y>>>22;a[(c[E>>2]|0)+G|0]=_>>>22;if(!t){break}a[(c[F>>2]|0)+G|0]=V}else{b[(c[o>>2]|0)+(G<<1)>>1]=Z>>u;b[(c[D>>2]|0)+(G<<1)>>1]=Y>>u;b[(c[E>>2]|0)+(G<<1)>>1]=_>>u;if(!t){break}b[(c[F>>2]|0)+(G<<1)>>1]=U}}while(0);M=G+1|0;if((M|0)<(p|0)){G=M;H=V;I=U}else{break}}}if((u|0)==22){i=q;return}u=qKb(c[r>>2]|0)|0;if((u|0)==0){KIb(0,0,2414880,(r=i,i=i+24|0,c[r>>2]=2349608,c[r+8>>2]=2287856,c[r+16>>2]=653,r)|0);i=r;Hd()}if((a[u+7|0]&1)==0|s^1){i=q;return}s=o+4|0;u=o+8|0;r=o+12|0;U=0;do{I=(c[o>>2]|0)+(U<<1)|0;b[I>>1]=he(b[I>>1]|0)|0;I=(c[s>>2]|0)+(U<<1)|0;b[I>>1]=he(b[I>>1]|0)|0;I=(c[u>>2]|0)+(U<<1)|0;b[I>>1]=he(b[I>>1]|0)|0;if(t){I=(c[r>>2]|0)+(U<<1)|0;b[I>>1]=he(b[I>>1]|0)|0}U=U+1|0;}while((U|0)<(p|0));i=q;return}function vBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;l=i;m=d;d=g;g=h;h=c[e>>2]|0;n=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}o=b+11300|0;p=b+11304|0;q=b+11308|0;r=b+11312|0;s=b+11316|0;t=b+11320|0;u=0;v=g;while(1){w=u<<1;x=w|1;z=(c[h+(u<<2)>>2]|0)-262144>>2;A=(c[n+(u<<2)>>2]|0)-262144>>2;B=c[o>>2]|0;C=c[p>>2]|0;D=(ca((c[m+(w<<2)>>2]>>2)-B|0,C)|0)+8192|0;E=(ca((c[m+(x<<2)>>2]>>2)-B|0,C)|0)+8192|0;C=c[d+(w<<2)>>2]<<11;w=c[d+(x<<2)>>2]<<11;x=C+8192|0;B=w+8192|0;F=ca(c[q>>2]|0,A)|0;G=ca(c[r>>2]|0,A)|0;A=(ca(c[s>>2]|0,z)|0)+G|0;G=ca(c[t>>2]|0,z)|0;z=qKb(292)|0;if((z|0)==0){H=5;break}I=F+D|0;if(I>>>0<1073741824>>>0){J=I>>>14&65535}else{J=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){K=J}else{K=he(J|0)|0}y=K;a[v]=y;y=y>>8;a[v+1|0]=y;z=qKb(292)|0;if((z|0)==0){H=11;break}I=A+D|0;if(I>>>0<1073741824>>>0){L=I>>>14&65535}else{L=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+2|0;y=L;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+2|0;y=he(L|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){H=18;break}I=G+D|0;if(I>>>0<1073741824>>>0){M=I>>>14&65535}else{M=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+4|0;y=M;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+4|0;y=he(M|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){H=25;break}if(x>>>0<1073741824>>>0){N=x>>>14&65535}else{N=-8192-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+6|0;y=N;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+6|0;y=he(N|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){H=32;break}C=F+E|0;if(C>>>0<1073741824>>>0){O=C>>>14&65535}else{O=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+8|0;y=O;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+8|0;y=he(O|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){H=39;break}C=A+E|0;if(C>>>0<1073741824>>>0){P=C>>>14&65535}else{P=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+10|0;y=P;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+10|0;y=he(P|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){H=46;break}C=G+E|0;if(C>>>0<1073741824>>>0){Q=C>>>14&65535}else{Q=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+12|0;y=Q;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+12|0;y=he(Q|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){H=53;break}if(B>>>0<1073741824>>>0){R=B>>>14&65535}else{R=-8192-w>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+14|0;y=R;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+14|0;y=he(R|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=u+1|0;if((z|0)<(k|0)){u=z;v=v+16|0}else{H=118;break}}if((H|0)==5){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==11){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==18){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==25){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==32){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==39){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==46){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==53){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==118){i=l;return}}else{v=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;u=b+11304|0;k=b+11308|0;R=b+11312|0;Q=b+11316|0;P=b+11320|0;b=0;O=g;while(1){g=b<<1;N=g|1;M=(c[h+(b<<2)>>2]|0)-524288+(c[v+(b<<2)>>2]|0)>>3;L=(c[n+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;K=c[j>>2]|0;J=c[u>>2]|0;t=(ca((c[m+(g<<2)>>2]>>2)-K|0,J)|0)+8192|0;s=(ca((c[m+(N<<2)>>2]>>2)-K|0,J)|0)+8192|0;J=c[d+(g<<2)>>2]<<11;g=c[d+(N<<2)>>2]<<11;N=J+8192|0;K=g+8192|0;r=ca(c[k>>2]|0,L)|0;q=ca(c[R>>2]|0,L)|0;L=(ca(c[Q>>2]|0,M)|0)+q|0;q=ca(c[P>>2]|0,M)|0;M=qKb(292)|0;if((M|0)==0){H=63;break}p=r+t|0;if(p>>>0<1073741824>>>0){T=p>>>14&65535}else{T=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){U=T}else{U=he(T|0)|0}y=U;a[O]=y;y=y>>8;a[O+1|0]=y;M=qKb(292)|0;if((M|0)==0){H=69;break}p=L+t|0;if(p>>>0<1073741824>>>0){V=p>>>14&65535}else{V=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+2|0;y=V;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+2|0;y=he(V|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(292)|0;if((M|0)==0){H=76;break}p=q+t|0;if(p>>>0<1073741824>>>0){W=p>>>14&65535}else{W=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+4|0;y=W;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+4|0;y=he(W|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(292)|0;if((M|0)==0){H=83;break}if(N>>>0<1073741824>>>0){X=N>>>14&65535}else{X=-8192-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+6|0;y=X;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+6|0;y=he(X|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(292)|0;if((M|0)==0){H=90;break}J=r+s|0;if(J>>>0<1073741824>>>0){Y=J>>>14&65535}else{Y=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+8|0;y=Y;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+8|0;y=he(Y|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(292)|0;if((M|0)==0){H=97;break}J=L+s|0;if(J>>>0<1073741824>>>0){Z=J>>>14&65535}else{Z=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+10|0;y=Z;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+10|0;y=he(Z|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(292)|0;if((M|0)==0){H=104;break}J=q+s|0;if(J>>>0<1073741824>>>0){_=J>>>14&65535}else{_=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+12|0;y=_;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+12|0;y=he(_|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(292)|0;if((M|0)==0){H=111;break}if(K>>>0<1073741824>>>0){$=K>>>14&65535}else{$=-8192-g>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+14|0;y=$;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+14|0;y=he($|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=b+1|0;if((M|0)<(f|0)){b=M;O=O+16|0}else{H=118;break}}if((H|0)==63){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==69){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==76){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==83){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==90){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==97){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==104){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==111){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==118){i=l;return}}}function wBb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;m=i;n=c[d>>2]|0;o=c[d+4>>2]|0;d=c[e>>2]|0;p=c[e+4>>2]|0;e=c[f>>2]|0;q=c[f+4>>2]|0;f=c[g>>2]|0;r=c[g+4>>2]|0;g=4096-k|0;s=4096-l|0;t=j+1>>1;if((t|0)<=0){i=m;return}j=b+11300|0;u=b+11304|0;v=b+11308|0;w=b+11312|0;x=b+11316|0;z=b+11320|0;b=0;A=h;while(1){h=b<<1;B=ca(c[n+(h<<2)>>2]|0,g)|0;C=(ca(c[o+(h<<2)>>2]|0,k)|0)+B>>14;B=h|1;D=ca(c[n+(B<<2)>>2]|0,g)|0;E=(ca(c[o+(B<<2)>>2]|0,k)|0)+D>>14;D=ca(c[d+(b<<2)>>2]|0,s)|0;F=D-1073741824+(ca(c[p+(b<<2)>>2]|0,l)|0)>>14;D=ca(c[e+(b<<2)>>2]|0,s)|0;G=D-1073741824+(ca(c[q+(b<<2)>>2]|0,l)|0)>>14;D=c[j>>2]|0;H=c[u>>2]|0;I=(ca(C-D|0,H)|0)+8192|0;C=(ca(E-D|0,H)|0)+8192|0;H=ca(G,c[v>>2]|0)|0;D=ca(c[w>>2]|0,G)|0;G=(ca(c[x>>2]|0,F)|0)+D|0;D=ca(c[z>>2]|0,F)|0;F=ca(c[f+(h<<2)>>2]|0,g)|0;E=(ca(c[r+(h<<2)>>2]|0,k)|0)+F>>1;F=ca(c[f+(B<<2)>>2]|0,g)|0;h=(ca(c[r+(B<<2)>>2]|0,k)|0)+F>>1;F=E+8192|0;B=h+8192|0;J=qKb(292)|0;if((J|0)==0){K=4;break}L=H+I|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[A]=y;y=y>>8;a[A+1|0]=y;J=qKb(292)|0;if((J|0)==0){K=10;break}L=G+I|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+2|0;y=O;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+2|0;y=he(O|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=17;break}L=D+I|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+4|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+4|0;y=he(P|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=24;break}if(F>>>0<1073741824>>>0){Q=F>>>14&65535}else{Q=-8192-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+6|0;y=Q;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+6|0;y=he(Q|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=31;break}E=H+C|0;if(E>>>0<1073741824>>>0){R=E>>>14&65535}else{R=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+8|0;y=R;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+8|0;y=he(R|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=38;break}E=G+C|0;if(E>>>0<1073741824>>>0){S=E>>>14&65535}else{S=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+10|0;y=S;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+10|0;y=he(S|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=45;break}E=D+C|0;if(E>>>0<1073741824>>>0){T=E>>>14&65535}else{T=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+12|0;y=T;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+12|0;y=he(T|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=52;break}if(B>>>0<1073741824>>>0){U=B>>>14&65535}else{U=-8192-h>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+14|0;y=U;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+14|0;y=he(U|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=b+1|0;if((J|0)<(t|0)){b=J;A=A+16|0}else{K=59;break}}if((K|0)==4){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==10){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==17){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==24){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==31){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==38){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==45){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==52){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==59){i=m;return}}function xBb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;p=i;q=o+1>>1;if((q|0)<=0){i=p;return}o=(g|0)>0;r=(l|0)>0;s=d+11300|0;t=d+11304|0;u=d+11308|0;v=d+11312|0;w=d+11316|0;x=d+11320|0;d=0;z=n;while(1){if(o){n=d<<1;A=n|1;B=0;C=-1073741824;D=-1073741824;do{E=c[f+(B<<2)>>2]|0;F=b[e+(B<<1)>>1]|0;C=(ca(F,c[E+(n<<2)>>2]|0)|0)+C|0;D=(ca(c[E+(A<<2)>>2]|0,F)|0)+D|0;B=B+1|0;}while((B|0)<(g|0));G=(C>>14)+65536|0;H=(D>>14)+65536|0}else{G=0;H=0}if(r){B=0;A=-1073741824;n=-1073741824;do{F=b[h+(B<<1)>>1]|0;A=(ca(F,c[(c[j+(B<<2)>>2]|0)+(d<<2)>>2]|0)|0)+A|0;n=(ca(c[(c[k+(B<<2)>>2]|0)+(d<<2)>>2]|0,F)|0)+n|0;B=B+1|0;}while((B|0)<(l|0));I=A>>14;J=n>>14}else{I=-65536;J=-65536}if(o){B=d<<1;D=B|1;C=-1073741824;F=0;E=-1073741824;do{K=c[m+(F<<2)>>2]|0;L=b[e+(F<<1)>>1]|0;E=(ca(L,c[K+(B<<2)>>2]|0)|0)+E|0;C=(ca(c[K+(D<<2)>>2]|0,L)|0)+C|0;F=F+1|0;}while((F|0)<(g|0));M=(E>>1)+536879104|0;N=(C>>1)+536879104|0}else{M=8192;N=8192}F=c[s>>2]|0;D=c[t>>2]|0;B=(ca(G-F|0,D)|0)+8192|0;n=(ca(H-F|0,D)|0)+8192|0;D=ca(c[u>>2]|0,J)|0;F=ca(c[v>>2]|0,J)|0;A=(ca(c[w>>2]|0,I)|0)+F|0;F=ca(c[x>>2]|0,I)|0;L=qKb(292)|0;if((L|0)==0){O=15;break}K=D+B|0;if(K>>>0<1073741824>>>0){P=K>>>14&65535}else{P=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){Q=P}else{Q=he(P|0)|0}y=Q;a[z]=y;y=y>>8;a[z+1|0]=y;L=qKb(292)|0;if((L|0)==0){O=21;break}K=A+B|0;if(K>>>0<1073741824>>>0){R=K>>>14&65535}else{R=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+2|0;y=R;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+2|0;y=he(R|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(292)|0;if((L|0)==0){O=28;break}K=F+B|0;if(K>>>0<1073741824>>>0){S=K>>>14&65535}else{S=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+4|0;y=S;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+4|0;y=he(S|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(292)|0;if((L|0)==0){O=35;break}if(M>>>0<1073741824>>>0){T=M>>>14&65535}else{T=-M>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+6|0;y=T;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+6|0;y=he(T|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(292)|0;if((L|0)==0){O=42;break}K=D+n|0;if(K>>>0<1073741824>>>0){U=K>>>14&65535}else{U=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+8|0;y=U;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+8|0;y=he(U|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(292)|0;if((L|0)==0){O=49;break}K=A+n|0;if(K>>>0<1073741824>>>0){V=K>>>14&65535}else{V=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+10|0;y=V;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+10|0;y=he(V|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(292)|0;if((L|0)==0){O=56;break}K=F+n|0;if(K>>>0<1073741824>>>0){W=K>>>14&65535}else{W=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+12|0;y=W;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+12|0;y=he(W|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(292)|0;if((L|0)==0){O=63;break}if(N>>>0<1073741824>>>0){X=N>>>14&65535}else{X=-N>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+14|0;y=X;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+14|0;y=he(X|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=d+1|0;if((L|0)<(q|0)){d=L;z=z+16|0}else{O=70;break}}if((O|0)==15){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==21){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==28){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==35){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==42){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==49){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==56){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==63){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==70){i=p;return}}function yBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;x=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ca((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ca((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ca(c[p>>2]|0,x)|0;z=ca(c[q>>2]|0,x)|0;x=(ca(c[r>>2]|0,w)|0)+z|0;z=ca(c[s>>2]|0,w)|0;w=qKb(292)|0;if((w|0)==0){D=5;break}v=A+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=he(E|0)|0}y=F;a[u]=y;y=y>>8;a[u+1|0]=y;w=qKb(292)|0;if((w|0)==0){D=11;break}v=x+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;y=G;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+2|0;y=he(G|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(292)|0;if((w|0)==0){D=18;break}v=z+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;y=H;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+4|0;y=he(H|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}if((qKb(292)|0)==0){D=25;break}w=u+6|0;y=-1;a[w]=y;y=y>>8;a[w+1|0]=y;w=qKb(292)|0;if((w|0)==0){D=27;break}v=A+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;y=I;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+8|0;y=he(I|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(292)|0;if((w|0)==0){D=34;break}v=x+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;y=J;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+10|0;y=he(J|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(292)|0;if((w|0)==0){D=41;break}v=z+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+12|0;y=K;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+12|0;y=he(K|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}if((qKb(292)|0)==0){D=48;break}w=u+14|0;y=-1;a[w]=y;y=y>>8;a[w+1|0]=y;w=t+1|0;if((w|0)<(k|0)){t=w;u=u+16|0}else{D=98;break}}if((D|0)==5){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==11){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==18){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==25){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==27){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==34){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==41){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==48){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==98){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ca((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ca((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ca(c[k>>2]|0,F)|0;E=ca(c[K>>2]|0,F)|0;F=(ca(c[J>>2]|0,G)|0)+E|0;E=ca(c[I>>2]|0,G)|0;G=qKb(292)|0;if((G|0)==0){D=53;break}d=s+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[H]=y;y=y>>8;a[H+1|0]=y;G=qKb(292)|0;if((G|0)==0){D=59;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;y=O;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+2|0;y=he(O|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(292)|0;if((G|0)==0){D=66;break}d=E+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;y=P;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+4|0;y=he(P|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}if((qKb(292)|0)==0){D=73;break}G=H+6|0;y=-1;a[G]=y;y=y>>8;a[G+1|0]=y;G=qKb(292)|0;if((G|0)==0){D=75;break}d=s+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;y=Q;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+8|0;y=he(Q|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(292)|0;if((G|0)==0){D=82;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;y=R;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+10|0;y=he(R|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(292)|0;if((G|0)==0){D=89;break}d=E+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+12|0;y=S;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+12|0;y=he(S|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}if((qKb(292)|0)==0){D=96;break}G=H+14|0;y=-1;a[G]=y;y=y>>8;a[G+1|0]=y;G=b+1|0;if((G|0)<(f|0)){b=G;H=H+16|0}else{D=98;break}}if((D|0)==53){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==59){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==66){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==73){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==75){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==82){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==89){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==96){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==98){i=l;return}}}function zBb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;x=h;while(1){h=b<<1;z=ca(c[g+(h<<2)>>2]|0,f)|0;A=(ca(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ca(c[g+(z<<2)>>2]|0,f)|0;B=(ca(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ca(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ca(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ca(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ca(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ca(A-h|0,D)|0)+8192|0;A=(ca(B-h|0,D)|0)+8192|0;D=ca(C,c[t>>2]|0)|0;h=ca(c[u>>2]|0,C)|0;C=(ca(c[v>>2]|0,z)|0)+h|0;h=ca(c[w>>2]|0,z)|0;z=qKb(292)|0;if((z|0)==0){F=4;break}B=D+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=he(G|0)|0}y=H;a[x]=y;y=y>>8;a[x+1|0]=y;z=qKb(292)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+2|0;y=I;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+2|0;y=he(I|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){F=17;break}B=h+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+4|0;y=J;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+4|0;y=he(J|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}if((qKb(292)|0)==0){F=24;break}z=x+6|0;y=-1;a[z]=y;y=y>>8;a[z+1|0]=y;z=qKb(292)|0;if((z|0)==0){F=26;break}B=D+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+8|0;y=K;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+8|0;y=he(K|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){F=33;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+10|0;y=L;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+10|0;y=he(L|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(292)|0;if((z|0)==0){F=40;break}B=h+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+12|0;y=M;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+12|0;y=he(M|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}if((qKb(292)|0)==0){F=47;break}z=x+14|0;y=-1;a[z]=y;y=y>>8;a[z+1|0]=y;z=b+1|0;if((z|0)<(r|0)){b=z;x=x+16|0}else{F=49;break}}if((F|0)==4){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==10){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==17){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==24){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==26){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==33){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==40){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==47){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==49){i=m;return}}function ABb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;x=n;while(1){if(o){n=d<<1;z=n|1;A=0;B=-1073741824;C=-1073741824;do{D=c[f+(A<<2)>>2]|0;E=b[e+(A<<1)>>1]|0;B=(ca(E,c[D+(n<<2)>>2]|0)|0)+B|0;C=(ca(c[D+(z<<2)>>2]|0,E)|0)+C|0;A=A+1|0;}while((A|0)<(g|0));F=(B>>14)+65536|0;G=(C>>14)+65536|0}else{F=0;G=0}if(q){A=0;z=-1073741824;n=-1073741824;do{E=b[h+(A<<1)>>1]|0;z=(ca(E,c[(c[j+(A<<2)>>2]|0)+(d<<2)>>2]|0)|0)+z|0;n=(ca(c[(c[k+(A<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+n|0;A=A+1|0;}while((A|0)<(l|0));H=z>>14;I=n>>14}else{H=-65536;I=-65536}A=c[r>>2]|0;C=c[s>>2]|0;B=(ca(F-A|0,C)|0)+8192|0;E=(ca(G-A|0,C)|0)+8192|0;C=ca(c[t>>2]|0,I)|0;A=ca(c[u>>2]|0,I)|0;D=(ca(c[v>>2]|0,H)|0)+A|0;A=ca(c[w>>2]|0,H)|0;J=qKb(292)|0;if((J|0)==0){K=11;break}L=C+B|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[x]=y;y=y>>8;a[x+1|0]=y;J=qKb(292)|0;if((J|0)==0){K=17;break}L=D+B|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+2|0;y=O;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+2|0;y=he(O|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=24;break}L=A+B|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+4|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+4|0;y=he(P|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}if((qKb(292)|0)==0){K=31;break}J=x+6|0;y=-1;a[J]=y;y=y>>8;a[J+1|0]=y;J=qKb(292)|0;if((J|0)==0){K=33;break}L=C+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+8|0;y=Q;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+8|0;y=he(Q|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=40;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+10|0;y=R;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+10|0;y=he(R|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(292)|0;if((J|0)==0){K=47;break}L=A+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+12|0;y=S;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+12|0;y=he(S|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}if((qKb(292)|0)==0){K=54;break}J=x+14|0;y=-1;a[J]=y;y=y>>8;a[J+1|0]=y;J=d+1|0;if((J|0)<(m|0)){d=J;x=x+16|0}else{K=56;break}}if((K|0)==11){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==17){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==24){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==31){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==33){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==40){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==47){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==54){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==56){i=p;return}}function BBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;l=i;m=d;d=g;g=h;h=c[e>>2]|0;n=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}o=b+11300|0;p=b+11304|0;q=b+11308|0;r=b+11312|0;s=b+11316|0;t=b+11320|0;u=0;v=g;while(1){w=u<<1;x=w|1;z=(c[h+(u<<2)>>2]|0)-262144>>2;A=(c[n+(u<<2)>>2]|0)-262144>>2;B=c[o>>2]|0;C=c[p>>2]|0;D=(ca((c[m+(w<<2)>>2]>>2)-B|0,C)|0)+8192|0;E=(ca((c[m+(x<<2)>>2]>>2)-B|0,C)|0)+8192|0;C=c[d+(w<<2)>>2]<<11;w=c[d+(x<<2)>>2]<<11;x=C+8192|0;B=w+8192|0;F=ca(c[q>>2]|0,A)|0;G=ca(c[r>>2]|0,A)|0;A=(ca(c[s>>2]|0,z)|0)+G|0;G=ca(c[t>>2]|0,z)|0;z=qKb(291)|0;if((z|0)==0){H=5;break}I=F+D|0;if(I>>>0<1073741824>>>0){J=I>>>14&65535}else{J=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){K=J}else{K=he(J|0)|0}y=K;a[v]=y;y=y>>8;a[v+1|0]=y;z=qKb(291)|0;if((z|0)==0){H=11;break}I=A+D|0;if(I>>>0<1073741824>>>0){L=I>>>14&65535}else{L=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+2|0;y=L;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+2|0;y=he(L|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){H=18;break}I=G+D|0;if(I>>>0<1073741824>>>0){M=I>>>14&65535}else{M=-I>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+4|0;y=M;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+4|0;y=he(M|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){H=25;break}if(x>>>0<1073741824>>>0){N=x>>>14&65535}else{N=-8192-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+6|0;y=N;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+6|0;y=he(N|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){H=32;break}C=F+E|0;if(C>>>0<1073741824>>>0){O=C>>>14&65535}else{O=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+8|0;y=O;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+8|0;y=he(O|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){H=39;break}C=A+E|0;if(C>>>0<1073741824>>>0){P=C>>>14&65535}else{P=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+10|0;y=P;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+10|0;y=he(P|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){H=46;break}C=G+E|0;if(C>>>0<1073741824>>>0){Q=C>>>14&65535}else{Q=-C>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+12|0;y=Q;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+12|0;y=he(Q|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){H=53;break}if(B>>>0<1073741824>>>0){R=B>>>14&65535}else{R=-8192-w>>31>>>14&65535}if((a[z+7|0]&1)==0){z=v+14|0;y=R;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=v+14|0;y=he(R|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=u+1|0;if((z|0)<(k|0)){u=z;v=v+16|0}else{H=118;break}}if((H|0)==5){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==11){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==18){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==25){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==32){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==39){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==46){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==53){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==118){i=l;return}}else{v=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;u=b+11304|0;k=b+11308|0;R=b+11312|0;Q=b+11316|0;P=b+11320|0;b=0;O=g;while(1){g=b<<1;N=g|1;M=(c[h+(b<<2)>>2]|0)-524288+(c[v+(b<<2)>>2]|0)>>3;L=(c[n+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;K=c[j>>2]|0;J=c[u>>2]|0;t=(ca((c[m+(g<<2)>>2]>>2)-K|0,J)|0)+8192|0;s=(ca((c[m+(N<<2)>>2]>>2)-K|0,J)|0)+8192|0;J=c[d+(g<<2)>>2]<<11;g=c[d+(N<<2)>>2]<<11;N=J+8192|0;K=g+8192|0;r=ca(c[k>>2]|0,L)|0;q=ca(c[R>>2]|0,L)|0;L=(ca(c[Q>>2]|0,M)|0)+q|0;q=ca(c[P>>2]|0,M)|0;M=qKb(291)|0;if((M|0)==0){H=63;break}p=r+t|0;if(p>>>0<1073741824>>>0){T=p>>>14&65535}else{T=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){U=T}else{U=he(T|0)|0}y=U;a[O]=y;y=y>>8;a[O+1|0]=y;M=qKb(291)|0;if((M|0)==0){H=69;break}p=L+t|0;if(p>>>0<1073741824>>>0){V=p>>>14&65535}else{V=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+2|0;y=V;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+2|0;y=he(V|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(291)|0;if((M|0)==0){H=76;break}p=q+t|0;if(p>>>0<1073741824>>>0){W=p>>>14&65535}else{W=-p>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+4|0;y=W;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+4|0;y=he(W|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(291)|0;if((M|0)==0){H=83;break}if(N>>>0<1073741824>>>0){X=N>>>14&65535}else{X=-8192-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+6|0;y=X;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+6|0;y=he(X|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(291)|0;if((M|0)==0){H=90;break}J=r+s|0;if(J>>>0<1073741824>>>0){Y=J>>>14&65535}else{Y=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+8|0;y=Y;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+8|0;y=he(Y|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(291)|0;if((M|0)==0){H=97;break}J=L+s|0;if(J>>>0<1073741824>>>0){Z=J>>>14&65535}else{Z=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+10|0;y=Z;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+10|0;y=he(Z|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(291)|0;if((M|0)==0){H=104;break}J=q+s|0;if(J>>>0<1073741824>>>0){_=J>>>14&65535}else{_=-J>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+12|0;y=_;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+12|0;y=he(_|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=qKb(291)|0;if((M|0)==0){H=111;break}if(K>>>0<1073741824>>>0){$=K>>>14&65535}else{$=-8192-g>>31>>>14&65535}if((a[M+7|0]&1)==0){M=O+14|0;y=$;a[M]=y;y=y>>8;a[M+1|0]=y}else{M=O+14|0;y=he($|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y}M=b+1|0;if((M|0)<(f|0)){b=M;O=O+16|0}else{H=118;break}}if((H|0)==63){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==69){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==76){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==83){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==90){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==97){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==104){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==111){KIb(0,0,2414880,(S=i,i=i+24|0,c[S>>2]=2349608,c[S+8>>2]=2287856,c[S+16>>2]=653,S)|0);i=S;Hd()}else if((H|0)==118){i=l;return}}}function CBb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;m=i;n=c[d>>2]|0;o=c[d+4>>2]|0;d=c[e>>2]|0;p=c[e+4>>2]|0;e=c[f>>2]|0;q=c[f+4>>2]|0;f=c[g>>2]|0;r=c[g+4>>2]|0;g=4096-k|0;s=4096-l|0;t=j+1>>1;if((t|0)<=0){i=m;return}j=b+11300|0;u=b+11304|0;v=b+11308|0;w=b+11312|0;x=b+11316|0;z=b+11320|0;b=0;A=h;while(1){h=b<<1;B=ca(c[n+(h<<2)>>2]|0,g)|0;C=(ca(c[o+(h<<2)>>2]|0,k)|0)+B>>14;B=h|1;D=ca(c[n+(B<<2)>>2]|0,g)|0;E=(ca(c[o+(B<<2)>>2]|0,k)|0)+D>>14;D=ca(c[d+(b<<2)>>2]|0,s)|0;F=D-1073741824+(ca(c[p+(b<<2)>>2]|0,l)|0)>>14;D=ca(c[e+(b<<2)>>2]|0,s)|0;G=D-1073741824+(ca(c[q+(b<<2)>>2]|0,l)|0)>>14;D=c[j>>2]|0;H=c[u>>2]|0;I=(ca(C-D|0,H)|0)+8192|0;C=(ca(E-D|0,H)|0)+8192|0;H=ca(G,c[v>>2]|0)|0;D=ca(c[w>>2]|0,G)|0;G=(ca(c[x>>2]|0,F)|0)+D|0;D=ca(c[z>>2]|0,F)|0;F=ca(c[f+(h<<2)>>2]|0,g)|0;E=(ca(c[r+(h<<2)>>2]|0,k)|0)+F>>1;F=ca(c[f+(B<<2)>>2]|0,g)|0;h=(ca(c[r+(B<<2)>>2]|0,k)|0)+F>>1;F=E+8192|0;B=h+8192|0;J=qKb(291)|0;if((J|0)==0){K=4;break}L=H+I|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[A]=y;y=y>>8;a[A+1|0]=y;J=qKb(291)|0;if((J|0)==0){K=10;break}L=G+I|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+2|0;y=O;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+2|0;y=he(O|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=17;break}L=D+I|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+4|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+4|0;y=he(P|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=24;break}if(F>>>0<1073741824>>>0){Q=F>>>14&65535}else{Q=-8192-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+6|0;y=Q;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+6|0;y=he(Q|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=31;break}E=H+C|0;if(E>>>0<1073741824>>>0){R=E>>>14&65535}else{R=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+8|0;y=R;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+8|0;y=he(R|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=38;break}E=G+C|0;if(E>>>0<1073741824>>>0){S=E>>>14&65535}else{S=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+10|0;y=S;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+10|0;y=he(S|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=45;break}E=D+C|0;if(E>>>0<1073741824>>>0){T=E>>>14&65535}else{T=-E>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+12|0;y=T;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+12|0;y=he(T|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=52;break}if(B>>>0<1073741824>>>0){U=B>>>14&65535}else{U=-8192-h>>31>>>14&65535}if((a[J+7|0]&1)==0){J=A+14|0;y=U;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=A+14|0;y=he(U|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=b+1|0;if((J|0)<(t|0)){b=J;A=A+16|0}else{K=59;break}}if((K|0)==4){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==10){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==17){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==24){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==31){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==38){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==45){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==52){KIb(0,0,2414880,(V=i,i=i+24|0,c[V>>2]=2349608,c[V+8>>2]=2287856,c[V+16>>2]=653,V)|0);i=V;Hd()}else if((K|0)==59){i=m;return}}function DBb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;p=i;q=o+1>>1;if((q|0)<=0){i=p;return}o=(g|0)>0;r=(l|0)>0;s=d+11300|0;t=d+11304|0;u=d+11308|0;v=d+11312|0;w=d+11316|0;x=d+11320|0;d=0;z=n;while(1){if(o){n=d<<1;A=n|1;B=0;C=-1073741824;D=-1073741824;do{E=c[f+(B<<2)>>2]|0;F=b[e+(B<<1)>>1]|0;C=(ca(F,c[E+(n<<2)>>2]|0)|0)+C|0;D=(ca(c[E+(A<<2)>>2]|0,F)|0)+D|0;B=B+1|0;}while((B|0)<(g|0));G=(C>>14)+65536|0;H=(D>>14)+65536|0}else{G=0;H=0}if(r){B=0;A=-1073741824;n=-1073741824;do{F=b[h+(B<<1)>>1]|0;A=(ca(F,c[(c[j+(B<<2)>>2]|0)+(d<<2)>>2]|0)|0)+A|0;n=(ca(c[(c[k+(B<<2)>>2]|0)+(d<<2)>>2]|0,F)|0)+n|0;B=B+1|0;}while((B|0)<(l|0));I=A>>14;J=n>>14}else{I=-65536;J=-65536}if(o){B=d<<1;D=B|1;C=-1073741824;F=0;E=-1073741824;do{K=c[m+(F<<2)>>2]|0;L=b[e+(F<<1)>>1]|0;E=(ca(L,c[K+(B<<2)>>2]|0)|0)+E|0;C=(ca(c[K+(D<<2)>>2]|0,L)|0)+C|0;F=F+1|0;}while((F|0)<(g|0));M=(E>>1)+536879104|0;N=(C>>1)+536879104|0}else{M=8192;N=8192}F=c[s>>2]|0;D=c[t>>2]|0;B=(ca(G-F|0,D)|0)+8192|0;n=(ca(H-F|0,D)|0)+8192|0;D=ca(c[u>>2]|0,J)|0;F=ca(c[v>>2]|0,J)|0;A=(ca(c[w>>2]|0,I)|0)+F|0;F=ca(c[x>>2]|0,I)|0;L=qKb(291)|0;if((L|0)==0){O=15;break}K=D+B|0;if(K>>>0<1073741824>>>0){P=K>>>14&65535}else{P=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){Q=P}else{Q=he(P|0)|0}y=Q;a[z]=y;y=y>>8;a[z+1|0]=y;L=qKb(291)|0;if((L|0)==0){O=21;break}K=A+B|0;if(K>>>0<1073741824>>>0){R=K>>>14&65535}else{R=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+2|0;y=R;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+2|0;y=he(R|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(291)|0;if((L|0)==0){O=28;break}K=F+B|0;if(K>>>0<1073741824>>>0){S=K>>>14&65535}else{S=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+4|0;y=S;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+4|0;y=he(S|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(291)|0;if((L|0)==0){O=35;break}if(M>>>0<1073741824>>>0){T=M>>>14&65535}else{T=-M>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+6|0;y=T;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+6|0;y=he(T|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(291)|0;if((L|0)==0){O=42;break}K=D+n|0;if(K>>>0<1073741824>>>0){U=K>>>14&65535}else{U=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+8|0;y=U;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+8|0;y=he(U|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(291)|0;if((L|0)==0){O=49;break}K=A+n|0;if(K>>>0<1073741824>>>0){V=K>>>14&65535}else{V=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+10|0;y=V;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+10|0;y=he(V|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(291)|0;if((L|0)==0){O=56;break}K=F+n|0;if(K>>>0<1073741824>>>0){W=K>>>14&65535}else{W=-K>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+12|0;y=W;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+12|0;y=he(W|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=qKb(291)|0;if((L|0)==0){O=63;break}if(N>>>0<1073741824>>>0){X=N>>>14&65535}else{X=-N>>31>>>14&65535}if((a[L+7|0]&1)==0){L=z+14|0;y=X;a[L]=y;y=y>>8;a[L+1|0]=y}else{L=z+14|0;y=he(X|0)|0;a[L]=y;y=y>>8;a[L+1|0]=y}L=d+1|0;if((L|0)<(q|0)){d=L;z=z+16|0}else{O=70;break}}if((O|0)==15){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==21){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==28){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==35){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==42){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==49){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==56){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==63){KIb(0,0,2414880,(Y=i,i=i+24|0,c[Y>>2]=2349608,c[Y+8>>2]=2287856,c[Y+16>>2]=653,Y)|0);i=Y;Hd()}else if((O|0)==70){i=p;return}}function EBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;x=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ca((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ca((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ca(c[p>>2]|0,x)|0;z=ca(c[q>>2]|0,x)|0;x=(ca(c[r>>2]|0,w)|0)+z|0;z=ca(c[s>>2]|0,w)|0;w=qKb(291)|0;if((w|0)==0){D=5;break}v=A+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=he(E|0)|0}y=F;a[u]=y;y=y>>8;a[u+1|0]=y;w=qKb(291)|0;if((w|0)==0){D=11;break}v=x+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;y=G;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+2|0;y=he(G|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(291)|0;if((w|0)==0){D=18;break}v=z+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;y=H;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+4|0;y=he(H|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}if((qKb(291)|0)==0){D=25;break}w=u+6|0;y=-1;a[w]=y;y=y>>8;a[w+1|0]=y;w=qKb(291)|0;if((w|0)==0){D=27;break}v=A+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;y=I;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+8|0;y=he(I|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(291)|0;if((w|0)==0){D=34;break}v=x+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;y=J;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+10|0;y=he(J|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(291)|0;if((w|0)==0){D=41;break}v=z+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+12|0;y=K;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+12|0;y=he(K|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}if((qKb(291)|0)==0){D=48;break}w=u+14|0;y=-1;a[w]=y;y=y>>8;a[w+1|0]=y;w=t+1|0;if((w|0)<(k|0)){t=w;u=u+16|0}else{D=98;break}}if((D|0)==5){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==11){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==18){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==25){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==27){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==34){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==41){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==48){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==98){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ca((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ca((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ca(c[k>>2]|0,F)|0;E=ca(c[K>>2]|0,F)|0;F=(ca(c[J>>2]|0,G)|0)+E|0;E=ca(c[I>>2]|0,G)|0;G=qKb(291)|0;if((G|0)==0){D=53;break}d=s+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[H]=y;y=y>>8;a[H+1|0]=y;G=qKb(291)|0;if((G|0)==0){D=59;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;y=O;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+2|0;y=he(O|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(291)|0;if((G|0)==0){D=66;break}d=E+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;y=P;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+4|0;y=he(P|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}if((qKb(291)|0)==0){D=73;break}G=H+6|0;y=-1;a[G]=y;y=y>>8;a[G+1|0]=y;G=qKb(291)|0;if((G|0)==0){D=75;break}d=s+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;y=Q;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+8|0;y=he(Q|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(291)|0;if((G|0)==0){D=82;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;y=R;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+10|0;y=he(R|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(291)|0;if((G|0)==0){D=89;break}d=E+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+12|0;y=S;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+12|0;y=he(S|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}if((qKb(291)|0)==0){D=96;break}G=H+14|0;y=-1;a[G]=y;y=y>>8;a[G+1|0]=y;G=b+1|0;if((G|0)<(f|0)){b=G;H=H+16|0}else{D=98;break}}if((D|0)==53){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==59){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==66){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==73){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==75){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==82){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==89){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==96){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==98){i=l;return}}}function FBb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;x=h;while(1){h=b<<1;z=ca(c[g+(h<<2)>>2]|0,f)|0;A=(ca(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ca(c[g+(z<<2)>>2]|0,f)|0;B=(ca(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ca(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ca(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ca(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ca(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ca(A-h|0,D)|0)+8192|0;A=(ca(B-h|0,D)|0)+8192|0;D=ca(C,c[t>>2]|0)|0;h=ca(c[u>>2]|0,C)|0;C=(ca(c[v>>2]|0,z)|0)+h|0;h=ca(c[w>>2]|0,z)|0;z=qKb(291)|0;if((z|0)==0){F=4;break}B=D+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=he(G|0)|0}y=H;a[x]=y;y=y>>8;a[x+1|0]=y;z=qKb(291)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+2|0;y=I;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+2|0;y=he(I|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){F=17;break}B=h+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+4|0;y=J;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+4|0;y=he(J|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}if((qKb(291)|0)==0){F=24;break}z=x+6|0;y=-1;a[z]=y;y=y>>8;a[z+1|0]=y;z=qKb(291)|0;if((z|0)==0){F=26;break}B=D+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+8|0;y=K;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+8|0;y=he(K|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){F=33;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+10|0;y=L;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+10|0;y=he(L|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(291)|0;if((z|0)==0){F=40;break}B=h+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+12|0;y=M;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+12|0;y=he(M|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}if((qKb(291)|0)==0){F=47;break}z=x+14|0;y=-1;a[z]=y;y=y>>8;a[z+1|0]=y;z=b+1|0;if((z|0)<(r|0)){b=z;x=x+16|0}else{F=49;break}}if((F|0)==4){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==10){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==17){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==24){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==26){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==33){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==40){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==47){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==49){i=m;return}}function GBb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;x=n;while(1){if(o){n=d<<1;z=n|1;A=0;B=-1073741824;C=-1073741824;do{D=c[f+(A<<2)>>2]|0;E=b[e+(A<<1)>>1]|0;B=(ca(E,c[D+(n<<2)>>2]|0)|0)+B|0;C=(ca(c[D+(z<<2)>>2]|0,E)|0)+C|0;A=A+1|0;}while((A|0)<(g|0));F=(B>>14)+65536|0;G=(C>>14)+65536|0}else{F=0;G=0}if(q){A=0;z=-1073741824;n=-1073741824;do{E=b[h+(A<<1)>>1]|0;z=(ca(E,c[(c[j+(A<<2)>>2]|0)+(d<<2)>>2]|0)|0)+z|0;n=(ca(c[(c[k+(A<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+n|0;A=A+1|0;}while((A|0)<(l|0));H=z>>14;I=n>>14}else{H=-65536;I=-65536}A=c[r>>2]|0;C=c[s>>2]|0;B=(ca(F-A|0,C)|0)+8192|0;E=(ca(G-A|0,C)|0)+8192|0;C=ca(c[t>>2]|0,I)|0;A=ca(c[u>>2]|0,I)|0;D=(ca(c[v>>2]|0,H)|0)+A|0;A=ca(c[w>>2]|0,H)|0;J=qKb(291)|0;if((J|0)==0){K=11;break}L=C+B|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[x]=y;y=y>>8;a[x+1|0]=y;J=qKb(291)|0;if((J|0)==0){K=17;break}L=D+B|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+2|0;y=O;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+2|0;y=he(O|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=24;break}L=A+B|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+4|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+4|0;y=he(P|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}if((qKb(291)|0)==0){K=31;break}J=x+6|0;y=-1;a[J]=y;y=y>>8;a[J+1|0]=y;J=qKb(291)|0;if((J|0)==0){K=33;break}L=C+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+8|0;y=Q;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+8|0;y=he(Q|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=40;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+10|0;y=R;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+10|0;y=he(R|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(291)|0;if((J|0)==0){K=47;break}L=A+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+12|0;y=S;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+12|0;y=he(S|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}if((qKb(291)|0)==0){K=54;break}J=x+14|0;y=-1;a[J]=y;y=y>>8;a[J+1|0]=y;J=d+1|0;if((J|0)<(m|0)){d=J;x=x+16|0}else{K=56;break}}if((K|0)==11){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==17){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==24){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==31){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==33){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==40){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==47){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==54){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==56){i=p;return}}function HBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;x=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ca((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ca((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ca(c[p>>2]|0,x)|0;z=ca(c[q>>2]|0,x)|0;x=(ca(c[r>>2]|0,w)|0)+z|0;z=ca(c[s>>2]|0,w)|0;w=qKb(42)|0;if((w|0)==0){D=5;break}v=A+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=he(E|0)|0}y=F;a[u]=y;y=y>>8;a[u+1|0]=y;w=qKb(42)|0;if((w|0)==0){D=11;break}v=x+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;y=G;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+2|0;y=he(G|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(42)|0;if((w|0)==0){D=18;break}v=z+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;y=H;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+4|0;y=he(H|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(42)|0;if((w|0)==0){D=25;break}v=A+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+6|0;y=I;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+6|0;y=he(I|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(42)|0;if((w|0)==0){D=32;break}v=x+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;y=J;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+8|0;y=he(J|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(42)|0;if((w|0)==0){D=39;break}v=z+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;y=K;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+10|0;y=he(K|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=t+1|0;if((w|0)<(k|0)){t=w;u=u+12|0}else{D=90;break}}if((D|0)==5){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==11){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==18){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==25){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==32){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==39){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==90){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ca((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ca((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ca(c[k>>2]|0,F)|0;E=ca(c[K>>2]|0,F)|0;F=(ca(c[J>>2]|0,G)|0)+E|0;E=ca(c[I>>2]|0,G)|0;G=qKb(42)|0;if((G|0)==0){D=49;break}d=s+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[H]=y;y=y>>8;a[H+1|0]=y;G=qKb(42)|0;if((G|0)==0){D=55;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;y=O;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+2|0;y=he(O|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(42)|0;if((G|0)==0){D=62;break}d=E+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;y=P;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+4|0;y=he(P|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(42)|0;if((G|0)==0){D=69;break}d=s+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+6|0;y=Q;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+6|0;y=he(Q|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(42)|0;if((G|0)==0){D=76;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;y=R;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+8|0;y=he(R|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(42)|0;if((G|0)==0){D=83;break}d=E+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;y=S;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+10|0;y=he(S|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=b+1|0;if((G|0)<(f|0)){b=G;H=H+12|0}else{D=90;break}}if((D|0)==49){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==55){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==62){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==69){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==76){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==83){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==90){i=l;return}}}function IBb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;x=h;while(1){h=b<<1;z=ca(c[g+(h<<2)>>2]|0,f)|0;A=(ca(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ca(c[g+(z<<2)>>2]|0,f)|0;B=(ca(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ca(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ca(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ca(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ca(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ca(A-h|0,D)|0)+8192|0;A=(ca(B-h|0,D)|0)+8192|0;D=ca(C,c[t>>2]|0)|0;h=ca(c[u>>2]|0,C)|0;C=(ca(c[v>>2]|0,z)|0)+h|0;h=ca(c[w>>2]|0,z)|0;z=qKb(42)|0;if((z|0)==0){F=4;break}B=D+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=he(G|0)|0}y=H;a[x]=y;y=y>>8;a[x+1|0]=y;z=qKb(42)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+2|0;y=I;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+2|0;y=he(I|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(42)|0;if((z|0)==0){F=17;break}B=h+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+4|0;y=J;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+4|0;y=he(J|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(42)|0;if((z|0)==0){F=24;break}B=D+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+6|0;y=K;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+6|0;y=he(K|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(42)|0;if((z|0)==0){F=31;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+8|0;y=L;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+8|0;y=he(L|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(42)|0;if((z|0)==0){F=38;break}B=h+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+10|0;y=M;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+10|0;y=he(M|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=b+1|0;if((z|0)<(r|0)){b=z;x=x+12|0}else{F=45;break}}if((F|0)==4){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==10){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==17){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==24){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==31){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==38){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==45){i=m;return}}function JBb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;x=n;while(1){if(o){n=d<<1;z=n|1;A=-1073741824;B=-1073741824;C=0;do{D=c[f+(C<<2)>>2]|0;E=b[e+(C<<1)>>1]|0;A=(ca(E,c[D+(n<<2)>>2]|0)|0)+A|0;B=(ca(c[D+(z<<2)>>2]|0,E)|0)+B|0;C=C+1|0;}while((C|0)<(g|0));F=(A>>14)+65536|0;G=(B>>14)+65536|0}else{F=0;G=0}if(q){C=-1073741824;z=-1073741824;n=0;do{E=b[h+(n<<1)>>1]|0;C=(ca(E,c[(c[j+(n<<2)>>2]|0)+(d<<2)>>2]|0)|0)+C|0;z=(ca(c[(c[k+(n<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+z|0;n=n+1|0;}while((n|0)<(l|0));H=C>>14;I=z>>14}else{H=-65536;I=-65536}n=c[r>>2]|0;B=c[s>>2]|0;A=(ca(F-n|0,B)|0)+8192|0;E=(ca(G-n|0,B)|0)+8192|0;B=ca(c[t>>2]|0,I)|0;n=ca(c[u>>2]|0,I)|0;D=(ca(c[v>>2]|0,H)|0)+n|0;n=ca(c[w>>2]|0,H)|0;J=qKb(42)|0;if((J|0)==0){K=11;break}L=B+A|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[x]=y;y=y>>8;a[x+1|0]=y;J=qKb(42)|0;if((J|0)==0){K=17;break}L=D+A|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+2|0;y=O;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+2|0;y=he(O|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(42)|0;if((J|0)==0){K=24;break}L=n+A|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+4|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+4|0;y=he(P|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(42)|0;if((J|0)==0){K=31;break}L=B+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+6|0;y=Q;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+6|0;y=he(Q|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(42)|0;if((J|0)==0){K=38;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+8|0;y=R;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+8|0;y=he(R|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(42)|0;if((J|0)==0){K=45;break}L=n+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+10|0;y=S;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+10|0;y=he(S|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=d+1|0;if((J|0)<(m|0)){d=J;x=x+12|0}else{K=52;break}}if((K|0)==11){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==17){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==24){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==31){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==38){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==45){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==52){i=p;return}}function KBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;x=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ca((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ca((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ca(c[p>>2]|0,x)|0;z=ca(c[q>>2]|0,x)|0;x=(ca(c[r>>2]|0,w)|0)+z|0;z=ca(c[s>>2]|0,w)|0;w=qKb(41)|0;if((w|0)==0){D=5;break}v=A+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=he(E|0)|0}y=F;a[u]=y;y=y>>8;a[u+1|0]=y;w=qKb(41)|0;if((w|0)==0){D=11;break}v=x+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;y=G;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+2|0;y=he(G|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(41)|0;if((w|0)==0){D=18;break}v=z+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;y=H;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+4|0;y=he(H|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(41)|0;if((w|0)==0){D=25;break}v=A+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+6|0;y=I;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+6|0;y=he(I|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(41)|0;if((w|0)==0){D=32;break}v=x+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;y=J;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+8|0;y=he(J|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(41)|0;if((w|0)==0){D=39;break}v=z+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;y=K;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+10|0;y=he(K|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=t+1|0;if((w|0)<(k|0)){t=w;u=u+12|0}else{D=90;break}}if((D|0)==5){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==11){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==18){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==25){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==32){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==39){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==90){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ca((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ca((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ca(c[k>>2]|0,F)|0;E=ca(c[K>>2]|0,F)|0;F=(ca(c[J>>2]|0,G)|0)+E|0;E=ca(c[I>>2]|0,G)|0;G=qKb(41)|0;if((G|0)==0){D=49;break}d=s+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[H]=y;y=y>>8;a[H+1|0]=y;G=qKb(41)|0;if((G|0)==0){D=55;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;y=O;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+2|0;y=he(O|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(41)|0;if((G|0)==0){D=62;break}d=E+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;y=P;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+4|0;y=he(P|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(41)|0;if((G|0)==0){D=69;break}d=s+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+6|0;y=Q;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+6|0;y=he(Q|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(41)|0;if((G|0)==0){D=76;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;y=R;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+8|0;y=he(R|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(41)|0;if((G|0)==0){D=83;break}d=E+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;y=S;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+10|0;y=he(S|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=b+1|0;if((G|0)<(f|0)){b=G;H=H+12|0}else{D=90;break}}if((D|0)==49){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==55){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==62){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==69){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==76){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==83){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==90){i=l;return}}}function LBb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;x=h;while(1){h=b<<1;z=ca(c[g+(h<<2)>>2]|0,f)|0;A=(ca(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ca(c[g+(z<<2)>>2]|0,f)|0;B=(ca(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ca(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ca(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ca(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ca(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ca(A-h|0,D)|0)+8192|0;A=(ca(B-h|0,D)|0)+8192|0;D=ca(C,c[t>>2]|0)|0;h=ca(c[u>>2]|0,C)|0;C=(ca(c[v>>2]|0,z)|0)+h|0;h=ca(c[w>>2]|0,z)|0;z=qKb(41)|0;if((z|0)==0){F=4;break}B=D+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=he(G|0)|0}y=H;a[x]=y;y=y>>8;a[x+1|0]=y;z=qKb(41)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+2|0;y=I;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+2|0;y=he(I|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(41)|0;if((z|0)==0){F=17;break}B=h+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+4|0;y=J;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+4|0;y=he(J|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(41)|0;if((z|0)==0){F=24;break}B=D+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+6|0;y=K;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+6|0;y=he(K|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(41)|0;if((z|0)==0){F=31;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+8|0;y=L;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+8|0;y=he(L|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(41)|0;if((z|0)==0){F=38;break}B=h+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+10|0;y=M;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+10|0;y=he(M|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=b+1|0;if((z|0)<(r|0)){b=z;x=x+12|0}else{F=45;break}}if((F|0)==4){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==10){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==17){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==24){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==31){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==38){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==45){i=m;return}}function MBb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;x=n;while(1){if(o){n=d<<1;z=n|1;A=-1073741824;B=-1073741824;C=0;do{D=c[f+(C<<2)>>2]|0;E=b[e+(C<<1)>>1]|0;A=(ca(E,c[D+(n<<2)>>2]|0)|0)+A|0;B=(ca(c[D+(z<<2)>>2]|0,E)|0)+B|0;C=C+1|0;}while((C|0)<(g|0));F=(A>>14)+65536|0;G=(B>>14)+65536|0}else{F=0;G=0}if(q){C=-1073741824;z=-1073741824;n=0;do{E=b[h+(n<<1)>>1]|0;C=(ca(E,c[(c[j+(n<<2)>>2]|0)+(d<<2)>>2]|0)|0)+C|0;z=(ca(c[(c[k+(n<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+z|0;n=n+1|0;}while((n|0)<(l|0));H=C>>14;I=z>>14}else{H=-65536;I=-65536}n=c[r>>2]|0;B=c[s>>2]|0;A=(ca(F-n|0,B)|0)+8192|0;E=(ca(G-n|0,B)|0)+8192|0;B=ca(c[t>>2]|0,I)|0;n=ca(c[u>>2]|0,I)|0;D=(ca(c[v>>2]|0,H)|0)+n|0;n=ca(c[w>>2]|0,H)|0;J=qKb(41)|0;if((J|0)==0){K=11;break}L=B+A|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[x]=y;y=y>>8;a[x+1|0]=y;J=qKb(41)|0;if((J|0)==0){K=17;break}L=D+A|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+2|0;y=O;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+2|0;y=he(O|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(41)|0;if((J|0)==0){K=24;break}L=n+A|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+4|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+4|0;y=he(P|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(41)|0;if((J|0)==0){K=31;break}L=B+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+6|0;y=Q;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+6|0;y=he(Q|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(41)|0;if((J|0)==0){K=38;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+8|0;y=R;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+8|0;y=he(R|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(41)|0;if((J|0)==0){K=45;break}L=n+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+10|0;y=S;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+10|0;y=he(S|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=d+1|0;if((J|0)<(m|0)){d=J;x=x+12|0}else{K=52;break}}if((K|0)==11){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==17){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==24){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==31){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==38){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==45){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==52){i=p;return}}function NBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;x=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ca((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ca((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ca(c[p>>2]|0,x)|0;z=ca(c[q>>2]|0,x)|0;x=(ca(c[r>>2]|0,w)|0)+z|0;z=ca(c[s>>2]|0,w)|0;w=qKb(68)|0;if((w|0)==0){D=5;break}v=z+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=he(E|0)|0}y=F;a[u]=y;y=y>>8;a[u+1|0]=y;w=qKb(68)|0;if((w|0)==0){D=11;break}v=x+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;y=G;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+2|0;y=he(G|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(68)|0;if((w|0)==0){D=18;break}v=A+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;y=H;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+4|0;y=he(H|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(68)|0;if((w|0)==0){D=25;break}v=z+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+6|0;y=I;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+6|0;y=he(I|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(68)|0;if((w|0)==0){D=32;break}v=x+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;y=J;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+8|0;y=he(J|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(68)|0;if((w|0)==0){D=39;break}v=A+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;y=K;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+10|0;y=he(K|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=t+1|0;if((w|0)<(k|0)){t=w;u=u+12|0}else{D=90;break}}if((D|0)==5){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==11){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==18){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==25){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==32){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==39){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==90){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ca((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ca((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ca(c[k>>2]|0,F)|0;E=ca(c[K>>2]|0,F)|0;F=(ca(c[J>>2]|0,G)|0)+E|0;E=ca(c[I>>2]|0,G)|0;G=qKb(68)|0;if((G|0)==0){D=49;break}d=E+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[H]=y;y=y>>8;a[H+1|0]=y;G=qKb(68)|0;if((G|0)==0){D=55;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;y=O;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+2|0;y=he(O|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(68)|0;if((G|0)==0){D=62;break}d=s+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;y=P;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+4|0;y=he(P|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(68)|0;if((G|0)==0){D=69;break}d=E+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+6|0;y=Q;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+6|0;y=he(Q|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(68)|0;if((G|0)==0){D=76;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;y=R;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+8|0;y=he(R|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(68)|0;if((G|0)==0){D=83;break}d=s+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;y=S;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+10|0;y=he(S|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=b+1|0;if((G|0)<(f|0)){b=G;H=H+12|0}else{D=90;break}}if((D|0)==49){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==55){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==62){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==69){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==76){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==83){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==90){i=l;return}}}function OBb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;x=h;while(1){h=b<<1;z=ca(c[g+(h<<2)>>2]|0,f)|0;A=(ca(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ca(c[g+(z<<2)>>2]|0,f)|0;B=(ca(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ca(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ca(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ca(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ca(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ca(A-h|0,D)|0)+8192|0;A=(ca(B-h|0,D)|0)+8192|0;D=ca(C,c[t>>2]|0)|0;h=ca(c[u>>2]|0,C)|0;C=(ca(c[v>>2]|0,z)|0)+h|0;h=ca(c[w>>2]|0,z)|0;z=qKb(68)|0;if((z|0)==0){F=4;break}B=h+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=he(G|0)|0}y=H;a[x]=y;y=y>>8;a[x+1|0]=y;z=qKb(68)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+2|0;y=I;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+2|0;y=he(I|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(68)|0;if((z|0)==0){F=17;break}B=D+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+4|0;y=J;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+4|0;y=he(J|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(68)|0;if((z|0)==0){F=24;break}B=h+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+6|0;y=K;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+6|0;y=he(K|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(68)|0;if((z|0)==0){F=31;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+8|0;y=L;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+8|0;y=he(L|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(68)|0;if((z|0)==0){F=38;break}B=D+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+10|0;y=M;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+10|0;y=he(M|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=b+1|0;if((z|0)<(r|0)){b=z;x=x+12|0}else{F=45;break}}if((F|0)==4){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==10){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==17){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==24){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==31){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==38){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==45){i=m;return}}function PBb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;x=n;while(1){if(o){n=d<<1;z=n|1;A=-1073741824;B=-1073741824;C=0;do{D=c[f+(C<<2)>>2]|0;E=b[e+(C<<1)>>1]|0;A=(ca(E,c[D+(n<<2)>>2]|0)|0)+A|0;B=(ca(c[D+(z<<2)>>2]|0,E)|0)+B|0;C=C+1|0;}while((C|0)<(g|0));F=(A>>14)+65536|0;G=(B>>14)+65536|0}else{F=0;G=0}if(q){C=-1073741824;z=-1073741824;n=0;do{E=b[h+(n<<1)>>1]|0;C=(ca(E,c[(c[j+(n<<2)>>2]|0)+(d<<2)>>2]|0)|0)+C|0;z=(ca(c[(c[k+(n<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+z|0;n=n+1|0;}while((n|0)<(l|0));H=C>>14;I=z>>14}else{H=-65536;I=-65536}n=c[r>>2]|0;B=c[s>>2]|0;A=(ca(F-n|0,B)|0)+8192|0;E=(ca(G-n|0,B)|0)+8192|0;B=ca(c[t>>2]|0,I)|0;n=ca(c[u>>2]|0,I)|0;D=(ca(c[v>>2]|0,H)|0)+n|0;n=ca(c[w>>2]|0,H)|0;J=qKb(68)|0;if((J|0)==0){K=11;break}L=n+A|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[x]=y;y=y>>8;a[x+1|0]=y;J=qKb(68)|0;if((J|0)==0){K=17;break}L=D+A|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+2|0;y=O;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+2|0;y=he(O|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(68)|0;if((J|0)==0){K=24;break}L=B+A|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+4|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+4|0;y=he(P|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(68)|0;if((J|0)==0){K=31;break}L=n+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+6|0;y=Q;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+6|0;y=he(Q|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(68)|0;if((J|0)==0){K=38;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+8|0;y=R;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+8|0;y=he(R|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(68)|0;if((J|0)==0){K=45;break}L=B+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+10|0;y=S;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+10|0;y=he(S|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=d+1|0;if((J|0)<(m|0)){d=J;x=x+12|0}else{K=52;break}}if((K|0)==11){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==17){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==24){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==31){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==38){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==45){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==52){i=p;return}}function QBb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;g=d;d=h;h=c[e>>2]|0;m=c[f>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){i=l;return}n=b+11300|0;o=b+11304|0;p=b+11308|0;q=b+11312|0;r=b+11316|0;s=b+11320|0;t=0;u=d;while(1){v=t<<1;w=(c[h+(t<<2)>>2]|0)-262144>>2;x=(c[m+(t<<2)>>2]|0)-262144>>2;z=c[n>>2]|0;A=c[o>>2]|0;B=(ca((c[g+(v<<2)>>2]>>2)-z|0,A)|0)+8192|0;C=(ca((c[g+((v|1)<<2)>>2]>>2)-z|0,A)|0)+8192|0;A=ca(c[p>>2]|0,x)|0;z=ca(c[q>>2]|0,x)|0;x=(ca(c[r>>2]|0,w)|0)+z|0;z=ca(c[s>>2]|0,w)|0;w=qKb(67)|0;if((w|0)==0){D=5;break}v=z+B|0;if(v>>>0<1073741824>>>0){E=v>>>14&65535}else{E=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){F=E}else{F=he(E|0)|0}y=F;a[u]=y;y=y>>8;a[u+1|0]=y;w=qKb(67)|0;if((w|0)==0){D=11;break}v=x+B|0;if(v>>>0<1073741824>>>0){G=v>>>14&65535}else{G=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+2|0;y=G;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+2|0;y=he(G|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(67)|0;if((w|0)==0){D=18;break}v=A+B|0;if(v>>>0<1073741824>>>0){H=v>>>14&65535}else{H=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+4|0;y=H;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+4|0;y=he(H|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(67)|0;if((w|0)==0){D=25;break}v=z+C|0;if(v>>>0<1073741824>>>0){I=v>>>14&65535}else{I=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+6|0;y=I;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+6|0;y=he(I|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(67)|0;if((w|0)==0){D=32;break}v=x+C|0;if(v>>>0<1073741824>>>0){J=v>>>14&65535}else{J=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+8|0;y=J;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+8|0;y=he(J|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=qKb(67)|0;if((w|0)==0){D=39;break}v=A+C|0;if(v>>>0<1073741824>>>0){K=v>>>14&65535}else{K=-v>>31>>>14&65535}if((a[w+7|0]&1)==0){w=u+10|0;y=K;a[w]=y;y=y>>8;a[w+1|0]=y}else{w=u+10|0;y=he(K|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y}w=t+1|0;if((w|0)<(k|0)){t=w;u=u+12|0}else{D=90;break}}if((D|0)==5){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==11){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==18){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==25){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==32){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==39){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==90){i=l;return}}else{u=c[e+4>>2]|0;e=c[f+4>>2]|0;f=j+1>>1;if((f|0)<=0){i=l;return}j=b+11300|0;t=b+11304|0;k=b+11308|0;K=b+11312|0;J=b+11316|0;I=b+11320|0;b=0;H=d;while(1){d=b<<1;G=(c[h+(b<<2)>>2]|0)-524288+(c[u+(b<<2)>>2]|0)>>3;F=(c[m+(b<<2)>>2]|0)-524288+(c[e+(b<<2)>>2]|0)>>3;E=c[j>>2]|0;s=c[t>>2]|0;r=(ca((c[g+(d<<2)>>2]>>2)-E|0,s)|0)+8192|0;q=(ca((c[g+((d|1)<<2)>>2]>>2)-E|0,s)|0)+8192|0;s=ca(c[k>>2]|0,F)|0;E=ca(c[K>>2]|0,F)|0;F=(ca(c[J>>2]|0,G)|0)+E|0;E=ca(c[I>>2]|0,G)|0;G=qKb(67)|0;if((G|0)==0){D=49;break}d=E+r|0;if(d>>>0<1073741824>>>0){M=d>>>14&65535}else{M=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[H]=y;y=y>>8;a[H+1|0]=y;G=qKb(67)|0;if((G|0)==0){D=55;break}d=F+r|0;if(d>>>0<1073741824>>>0){O=d>>>14&65535}else{O=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+2|0;y=O;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+2|0;y=he(O|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(67)|0;if((G|0)==0){D=62;break}d=s+r|0;if(d>>>0<1073741824>>>0){P=d>>>14&65535}else{P=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+4|0;y=P;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+4|0;y=he(P|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(67)|0;if((G|0)==0){D=69;break}d=E+q|0;if(d>>>0<1073741824>>>0){Q=d>>>14&65535}else{Q=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+6|0;y=Q;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+6|0;y=he(Q|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(67)|0;if((G|0)==0){D=76;break}d=F+q|0;if(d>>>0<1073741824>>>0){R=d>>>14&65535}else{R=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+8|0;y=R;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+8|0;y=he(R|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=qKb(67)|0;if((G|0)==0){D=83;break}d=s+q|0;if(d>>>0<1073741824>>>0){S=d>>>14&65535}else{S=-d>>31>>>14&65535}if((a[G+7|0]&1)==0){G=H+10|0;y=S;a[G]=y;y=y>>8;a[G+1|0]=y}else{G=H+10|0;y=he(S|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y}G=b+1|0;if((G|0)<(f|0)){b=G;H=H+12|0}else{D=90;break}}if((D|0)==49){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==55){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==62){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==69){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==76){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==83){KIb(0,0,2414880,(L=i,i=i+24|0,c[L>>2]=2349608,c[L+8>>2]=2287856,c[L+16>>2]=653,L)|0);i=L;Hd()}else if((D|0)==90){i=l;return}}}function RBb(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;m=i;g=c[d>>2]|0;n=c[d+4>>2]|0;d=c[e>>2]|0;o=c[e+4>>2]|0;e=c[f>>2]|0;p=c[f+4>>2]|0;f=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){i=m;return}j=b+11300|0;s=b+11304|0;t=b+11308|0;u=b+11312|0;v=b+11316|0;w=b+11320|0;b=0;x=h;while(1){h=b<<1;z=ca(c[g+(h<<2)>>2]|0,f)|0;A=(ca(c[n+(h<<2)>>2]|0,k)|0)+z>>14;z=h|1;h=ca(c[g+(z<<2)>>2]|0,f)|0;B=(ca(c[n+(z<<2)>>2]|0,k)|0)+h>>14;h=ca(c[d+(b<<2)>>2]|0,q)|0;z=h-1073741824+(ca(c[o+(b<<2)>>2]|0,l)|0)>>14;h=ca(c[e+(b<<2)>>2]|0,q)|0;C=h-1073741824+(ca(c[p+(b<<2)>>2]|0,l)|0)>>14;h=c[j>>2]|0;D=c[s>>2]|0;E=(ca(A-h|0,D)|0)+8192|0;A=(ca(B-h|0,D)|0)+8192|0;D=ca(C,c[t>>2]|0)|0;h=ca(c[u>>2]|0,C)|0;C=(ca(c[v>>2]|0,z)|0)+h|0;h=ca(c[w>>2]|0,z)|0;z=qKb(67)|0;if((z|0)==0){F=4;break}B=h+E|0;if(B>>>0<1073741824>>>0){G=B>>>14&65535}else{G=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){H=G}else{H=he(G|0)|0}y=H;a[x]=y;y=y>>8;a[x+1|0]=y;z=qKb(67)|0;if((z|0)==0){F=10;break}B=C+E|0;if(B>>>0<1073741824>>>0){I=B>>>14&65535}else{I=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+2|0;y=I;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+2|0;y=he(I|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(67)|0;if((z|0)==0){F=17;break}B=D+E|0;if(B>>>0<1073741824>>>0){J=B>>>14&65535}else{J=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+4|0;y=J;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+4|0;y=he(J|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(67)|0;if((z|0)==0){F=24;break}B=h+A|0;if(B>>>0<1073741824>>>0){K=B>>>14&65535}else{K=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+6|0;y=K;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+6|0;y=he(K|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(67)|0;if((z|0)==0){F=31;break}B=C+A|0;if(B>>>0<1073741824>>>0){L=B>>>14&65535}else{L=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+8|0;y=L;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+8|0;y=he(L|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=qKb(67)|0;if((z|0)==0){F=38;break}B=D+A|0;if(B>>>0<1073741824>>>0){M=B>>>14&65535}else{M=-B>>31>>>14&65535}if((a[z+7|0]&1)==0){z=x+10|0;y=M;a[z]=y;y=y>>8;a[z+1|0]=y}else{z=x+10|0;y=he(M|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y}z=b+1|0;if((z|0)<(r|0)){b=z;x=x+12|0}else{F=45;break}}if((F|0)==4){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==10){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==17){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==24){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==31){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==38){KIb(0,0,2414880,(N=i,i=i+24|0,c[N>>2]=2349608,c[N+8>>2]=2287856,c[N+16>>2]=653,N)|0);i=N;Hd()}else if((F|0)==45){i=m;return}}function SBb(d,e,f,g,h,j,k,l,m,n,o,p){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;m=o+1>>1;if((m|0)<=0){i=p;return}o=(g|0)>0;q=(l|0)>0;r=d+11300|0;s=d+11304|0;t=d+11308|0;u=d+11312|0;v=d+11316|0;w=d+11320|0;d=0;x=n;while(1){if(o){n=d<<1;z=n|1;A=-1073741824;B=-1073741824;C=0;do{D=c[f+(C<<2)>>2]|0;E=b[e+(C<<1)>>1]|0;A=(ca(E,c[D+(n<<2)>>2]|0)|0)+A|0;B=(ca(c[D+(z<<2)>>2]|0,E)|0)+B|0;C=C+1|0;}while((C|0)<(g|0));F=(A>>14)+65536|0;G=(B>>14)+65536|0}else{F=0;G=0}if(q){C=-1073741824;z=-1073741824;n=0;do{E=b[h+(n<<1)>>1]|0;C=(ca(E,c[(c[j+(n<<2)>>2]|0)+(d<<2)>>2]|0)|0)+C|0;z=(ca(c[(c[k+(n<<2)>>2]|0)+(d<<2)>>2]|0,E)|0)+z|0;n=n+1|0;}while((n|0)<(l|0));H=C>>14;I=z>>14}else{H=-65536;I=-65536}n=c[r>>2]|0;B=c[s>>2]|0;A=(ca(F-n|0,B)|0)+8192|0;E=(ca(G-n|0,B)|0)+8192|0;B=ca(c[t>>2]|0,I)|0;n=ca(c[u>>2]|0,I)|0;D=(ca(c[v>>2]|0,H)|0)+n|0;n=ca(c[w>>2]|0,H)|0;J=qKb(67)|0;if((J|0)==0){K=11;break}L=n+A|0;if(L>>>0<1073741824>>>0){M=L>>>14&65535}else{M=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){N=M}else{N=he(M|0)|0}y=N;a[x]=y;y=y>>8;a[x+1|0]=y;J=qKb(67)|0;if((J|0)==0){K=17;break}L=D+A|0;if(L>>>0<1073741824>>>0){O=L>>>14&65535}else{O=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+2|0;y=O;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+2|0;y=he(O|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(67)|0;if((J|0)==0){K=24;break}L=B+A|0;if(L>>>0<1073741824>>>0){P=L>>>14&65535}else{P=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+4|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+4|0;y=he(P|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(67)|0;if((J|0)==0){K=31;break}L=n+E|0;if(L>>>0<1073741824>>>0){Q=L>>>14&65535}else{Q=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+6|0;y=Q;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+6|0;y=he(Q|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(67)|0;if((J|0)==0){K=38;break}L=D+E|0;if(L>>>0<1073741824>>>0){R=L>>>14&65535}else{R=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+8|0;y=R;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+8|0;y=he(R|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=qKb(67)|0;if((J|0)==0){K=45;break}L=B+E|0;if(L>>>0<1073741824>>>0){S=L>>>14&65535}else{S=-L>>31>>>14&65535}if((a[J+7|0]&1)==0){J=x+10|0;y=S;a[J]=y;y=y>>8;a[J+1|0]=y}else{J=x+10|0;y=he(S|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y}J=d+1|0;if((J|0)<(m|0)){d=J;x=x+12|0}else{K=52;break}}if((K|0)==11){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==17){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==24){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==31){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==38){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==45){KIb(0,0,2414880,(T=i,i=i+24|0,c[T>>2]=2349608,c[T+8>>2]=2287856,c[T+16>>2]=653,T)|0);i=T;Hd()}else if((K|0)==52){i=p;return}}function TBb(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=c[e>>2]|0;l=c[f>>2]|0;if((j|0)<2048){j=i+1>>1;if((j|0)<=0){return}m=h;n=0;do{o=n<<1;p=(b[d+(o<<1)>>1]|0)+64>>7;q=o|1;r=(b[d+(q<<1)>>1]|0)+64>>7;s=((b[l+(n<<1)>>1]|0)+64>>7)+128|0;t=((b[k+(n<<1)>>1]|0)+64>>7)+128|0;u=((b[g+(o<<1)>>1]|0)*255|0)+16384>>15;v=((b[g+(q<<1)>>1]|0)*255|0)+16384>>15;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}if(v>>>0>255>>>0){x=-v>>31&255}else{x=v&255}v=c[a+4352+(s<<2)>>2]|0;u=(c[a+6400+(t<<2)>>2]|0)+(c[a+2304+(s<<2)>>2]|0)|0;s=c[a+8448+(t<<2)>>2]|0;c[m+(o<<2)>>2]=(c[v+(p<<2)>>2]|0)+((w&255)<<24)+(c[u+(p<<2)>>2]|0)+(c[s+(p<<2)>>2]|0);c[m+(q<<2)>>2]=(c[v+(r<<2)>>2]|0)+((x&255)<<24)+(c[u+(r<<2)>>2]|0)+(c[s+(r<<2)>>2]|0);n=n+1|0;}while((n|0)<(j|0));return}else{j=c[e+4>>2]|0;e=c[f+4>>2]|0;f=i+1>>1;if((f|0)<=0){return}i=h;h=0;do{n=h<<1;x=(b[d+(n<<1)>>1]|0)+64>>7;m=n|1;w=(b[d+(m<<1)>>1]|0)+64>>7;r=((b[l+(h<<1)>>1]|0)+128+(b[e+(h<<1)>>1]|0)>>8)+128|0;s=((b[k+(h<<1)>>1]|0)+128+(b[j+(h<<1)>>1]|0)>>8)+128|0;u=(b[g+(n<<1)>>1]|0)+64>>7;v=(b[g+(m<<1)>>1]|0)+64>>7;if(u>>>0>255>>>0){y=-u>>31&255}else{y=u&255}if(v>>>0>255>>>0){z=-v>>31&255}else{z=v&255}v=c[a+4352+(r<<2)>>2]|0;u=(c[a+6400+(s<<2)>>2]|0)+(c[a+2304+(r<<2)>>2]|0)|0;r=c[a+8448+(s<<2)>>2]|0;c[i+(n<<2)>>2]=(c[v+(x<<2)>>2]|0)+((y&255)<<24)+(c[u+(x<<2)>>2]|0)+(c[r+(x<<2)>>2]|0);c[i+(m<<2)>>2]=(c[v+(w<<2)>>2]|0)+((z&255)<<24)+(c[u+(w<<2)>>2]|0)+(c[r+(w<<2)>>2]|0);h=h+1|0;}while((h|0)<(f|0));return}}function UBb(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;l=c[d>>2]|0;m=c[d+4>>2]|0;d=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-j|0;q=4096-k|0;r=i+1>>1;if((r|0)<=0){return}i=h;h=0;do{s=h<<1;t=ca(b[l+(s<<1)>>1]|0,g)|0;u=(ca(b[m+(s<<1)>>1]|0,j)|0)+t>>19;t=s|1;v=ca(b[l+(t<<1)>>1]|0,g)|0;w=(ca(b[m+(t<<1)>>1]|0,j)|0)+v>>19;v=ca(b[d+(h<<1)>>1]|0,q)|0;x=(ca(b[n+(h<<1)>>1]|0,k)|0)+v>>19;v=ca(b[e+(h<<1)>>1]|0,q)|0;y=((ca(b[o+(h<<1)>>1]|0,k)|0)+v>>19)+128|0;v=x+128|0;x=ca(b[f+(s<<1)>>1]|0,g)|0;z=(ca(b[p+(s<<1)>>1]|0,j)|0)+x>>19;x=ca(b[f+(t<<1)>>1]|0,g)|0;A=(ca(b[p+(t<<1)>>1]|0,j)|0)+x>>19;if(z>>>0>255>>>0){B=-z>>31&255}else{B=z&255}if(A>>>0>255>>>0){C=-A>>31&255}else{C=A&255}A=c[a+4352+(y<<2)>>2]|0;z=(c[a+6400+(v<<2)>>2]|0)+(c[a+2304+(y<<2)>>2]|0)|0;y=c[a+8448+(v<<2)>>2]|0;c[i+(s<<2)>>2]=(c[A+(u<<2)>>2]|0)+((B&255)<<24)+(c[z+(u<<2)>>2]|0)+(c[y+(u<<2)>>2]|0);c[i+(t<<2)>>2]=(c[A+(w<<2)>>2]|0)+((C&255)<<24)+(c[z+(w<<2)>>2]|0)+(c[y+(w<<2)>>2]|0);h=h+1|0;}while((h|0)<(r|0));return}function VBb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;n=m+1>>1;if((n|0)<=0){return}m=(f|0)>0;o=(j|0)>0;p=l;l=0;do{if(m){q=l<<1;r=q|1;s=262144;t=262144;u=0;do{v=c[e+(u<<2)>>2]|0;w=b[d+(u<<1)>>1]|0;s=(ca(w,b[v+(q<<1)>>1]|0)|0)+s|0;t=(ca(b[v+(r<<1)>>1]|0,w)|0)+t|0;u=u+1|0;}while((u|0)<(f|0));x=s>>19;y=t>>19}else{x=0;y=0}if(o){u=262144;r=262144;q=0;do{w=b[g+(q<<1)>>1]|0;u=(ca(w,b[(c[h+(q<<2)>>2]|0)+(l<<1)>>1]|0)|0)+u|0;r=(ca(b[(c[i+(q<<2)>>2]|0)+(l<<1)>>1]|0,w)|0)+r|0;q=q+1|0;}while((q|0)<(j|0));z=(u>>19)+128|0;A=(r>>19)+128|0}else{z=128;A=128}if(m){q=l<<1;t=q|1;s=262144;w=262144;v=0;do{B=c[k+(v<<2)>>2]|0;C=b[d+(v<<1)>>1]|0;w=(ca(C,b[B+(q<<1)>>1]|0)|0)+w|0;s=(ca(b[B+(t<<1)>>1]|0,C)|0)+s|0;v=v+1|0;}while((v|0)<(f|0));D=s>>19;E=w>>19}else{D=0;E=0}if(((D|E)&256|0)==0){F=E;G=D}else{if(E>>>0>255>>>0){H=-E>>31&255}else{H=E&255}if(D>>>0>255>>>0){I=-D>>31&255}else{I=D&255}F=H&255;G=I&255}v=c[a+4352+(A<<2)>>2]|0;t=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;q=c[a+8448+(z<<2)>>2]|0;r=l<<1;c[p+(r<<2)>>2]=(c[v+(x<<2)>>2]|0)+(F<<24)+(c[t+(x<<2)>>2]|0)+(c[q+(x<<2)>>2]|0);c[p+((r|1)<<2)>>2]=(c[v+(y<<2)>>2]|0)+(G<<24)+(c[t+(y<<2)>>2]|0)+(c[q+(y<<2)>>2]|0);l=l+1|0;}while((l|0)<(n|0));return}function WBb(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=c[e>>2]|0;g=c[f>>2]|0;if((j|0)<2048){j=i+1>>1;if((j|0)<=0){return}l=h;m=0;do{n=m<<1;o=(b[d+(n<<1)>>1]|0)+64>>7;p=n|1;q=(b[d+(p<<1)>>1]|0)+64>>7;r=((b[g+(m<<1)>>1]|0)+64>>7)+128|0;s=((b[k+(m<<1)>>1]|0)+64>>7)+128|0;t=c[a+4352+(r<<2)>>2]|0;u=(c[a+6400+(s<<2)>>2]|0)+(c[a+2304+(r<<2)>>2]|0)|0;r=c[a+8448+(s<<2)>>2]|0;c[l+(n<<2)>>2]=(c[u+(o<<2)>>2]|0)+(c[t+(o<<2)>>2]|0)+(c[r+(o<<2)>>2]|0);c[l+(p<<2)>>2]=(c[u+(q<<2)>>2]|0)+(c[t+(q<<2)>>2]|0)+(c[r+(q<<2)>>2]|0);m=m+1|0;}while((m|0)<(j|0));return}else{j=c[e+4>>2]|0;e=c[f+4>>2]|0;f=i+1>>1;if((f|0)<=0){return}i=h;h=0;do{m=h<<1;l=(b[d+(m<<1)>>1]|0)+64>>7;q=m|1;r=(b[d+(q<<1)>>1]|0)+64>>7;t=((b[g+(h<<1)>>1]|0)+128+(b[e+(h<<1)>>1]|0)>>8)+128|0;u=((b[k+(h<<1)>>1]|0)+128+(b[j+(h<<1)>>1]|0)>>8)+128|0;p=c[a+4352+(t<<2)>>2]|0;o=(c[a+6400+(u<<2)>>2]|0)+(c[a+2304+(t<<2)>>2]|0)|0;t=c[a+8448+(u<<2)>>2]|0;c[i+(m<<2)>>2]=(c[o+(l<<2)>>2]|0)+(c[p+(l<<2)>>2]|0)+(c[t+(l<<2)>>2]|0);c[i+(q<<2)>>2]=(c[o+(r<<2)>>2]|0)+(c[p+(r<<2)>>2]|0)+(c[t+(r<<2)>>2]|0);h=h+1|0;}while((h|0)<(f|0));return}}function XBb(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=c[d>>2]|0;g=c[d+4>>2]|0;d=c[e>>2]|0;m=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=4096-j|0;o=4096-k|0;p=i+1>>1;if((p|0)<=0){return}i=h;h=0;do{q=h<<1;r=ca(b[l+(q<<1)>>1]|0,f)|0;s=(ca(b[g+(q<<1)>>1]|0,j)|0)+r>>19;r=q|1;t=ca(b[l+(r<<1)>>1]|0,f)|0;u=(ca(b[g+(r<<1)>>1]|0,j)|0)+t>>19;t=ca(b[d+(h<<1)>>1]|0,o)|0;v=(ca(b[m+(h<<1)>>1]|0,k)|0)+t>>19;t=ca(b[e+(h<<1)>>1]|0,o)|0;w=((ca(b[n+(h<<1)>>1]|0,k)|0)+t>>19)+128|0;t=v+128|0;v=c[a+4352+(w<<2)>>2]|0;x=(c[a+6400+(t<<2)>>2]|0)+(c[a+2304+(w<<2)>>2]|0)|0;w=c[a+8448+(t<<2)>>2]|0;c[i+(q<<2)>>2]=(c[x+(s<<2)>>2]|0)+(c[v+(s<<2)>>2]|0)+(c[w+(s<<2)>>2]|0);c[i+(r<<2)>>2]=(c[x+(u<<2)>>2]|0)+(c[v+(u<<2)>>2]|0)+(c[w+(u<<2)>>2]|0);h=h+1|0;}while((h|0)<(p|0));return}function YBb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;n=m+1>>1;if((n|0)<=0){return}m=(f|0)>0;k=(j|0)>0;o=l;l=0;do{if(m){p=l<<1;q=p|1;r=262144;s=262144;t=0;do{u=c[e+(t<<2)>>2]|0;v=b[d+(t<<1)>>1]|0;r=(ca(v,b[u+(p<<1)>>1]|0)|0)+r|0;s=(ca(b[u+(q<<1)>>1]|0,v)|0)+s|0;t=t+1|0;}while((t|0)<(f|0));w=r>>19;x=s>>19}else{w=0;x=0}if(k){t=262144;q=262144;p=0;do{v=b[g+(p<<1)>>1]|0;t=(ca(v,b[(c[h+(p<<2)>>2]|0)+(l<<1)>>1]|0)|0)+t|0;q=(ca(b[(c[i+(p<<2)>>2]|0)+(l<<1)>>1]|0,v)|0)+q|0;p=p+1|0;}while((p|0)<(j|0));y=(t>>19)+128|0;z=(q>>19)+128|0}else{y=128;z=128}p=c[a+4352+(z<<2)>>2]|0;s=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;r=c[a+8448+(y<<2)>>2]|0;v=l<<1;c[o+(v<<2)>>2]=(c[s+(w<<2)>>2]|0)+(c[p+(w<<2)>>2]|0)+(c[r+(w<<2)>>2]|0);c[o+((v|1)<<2)>>2]=(c[s+(x<<2)>>2]|0)+(c[p+(x<<2)>>2]|0)+(c[r+(x<<2)>>2]|0);l=l+1|0;}while((l|0)<(n|0));return}function ZBb(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=c[e>>2]|0;l=c[f>>2]|0;if((j|0)<2048){j=i+1>>1;if((j|0)<=0){return}m=h;n=0;do{o=n<<1;p=(b[d+(o<<1)>>1]|0)+64>>7;q=o|1;r=(b[d+(q<<1)>>1]|0)+64>>7;s=((b[l+(n<<1)>>1]|0)+64>>7)+128|0;t=((b[k+(n<<1)>>1]|0)+64>>7)+128|0;u=((b[g+(o<<1)>>1]|0)*255|0)+16384>>15;v=((b[g+(q<<1)>>1]|0)*255|0)+16384>>15;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}if(v>>>0>255>>>0){x=-v>>31&255}else{x=v&255}v=c[a+4352+(s<<2)>>2]|0;u=(c[a+6400+(t<<2)>>2]|0)+(c[a+2304+(s<<2)>>2]|0)|0;s=c[a+8448+(t<<2)>>2]|0;c[m+(o<<2)>>2]=(c[v+(p<<2)>>2]|0)+(w&255)+(c[u+(p<<2)>>2]|0)+(c[s+(p<<2)>>2]|0);c[m+(q<<2)>>2]=(c[v+(r<<2)>>2]|0)+(x&255)+(c[u+(r<<2)>>2]|0)+(c[s+(r<<2)>>2]|0);n=n+1|0;}while((n|0)<(j|0));return}else{j=c[e+4>>2]|0;e=c[f+4>>2]|0;f=i+1>>1;if((f|0)<=0){return}i=h;h=0;do{n=h<<1;x=(b[d+(n<<1)>>1]|0)+64>>7;m=n|1;w=(b[d+(m<<1)>>1]|0)+64>>7;r=((b[l+(h<<1)>>1]|0)+128+(b[e+(h<<1)>>1]|0)>>8)+128|0;s=((b[k+(h<<1)>>1]|0)+128+(b[j+(h<<1)>>1]|0)>>8)+128|0;u=(b[g+(n<<1)>>1]|0)+64>>7;v=(b[g+(m<<1)>>1]|0)+64>>7;if(u>>>0>255>>>0){y=-u>>31&255}else{y=u&255}if(v>>>0>255>>>0){z=-v>>31&255}else{z=v&255}v=c[a+4352+(r<<2)>>2]|0;u=(c[a+6400+(s<<2)>>2]|0)+(c[a+2304+(r<<2)>>2]|0)|0;r=c[a+8448+(s<<2)>>2]|0;c[i+(n<<2)>>2]=(c[v+(x<<2)>>2]|0)+(y&255)+(c[u+(x<<2)>>2]|0)+(c[r+(x<<2)>>2]|0);c[i+(m<<2)>>2]=(c[v+(w<<2)>>2]|0)+(z&255)+(c[u+(w<<2)>>2]|0)+(c[r+(w<<2)>>2]|0);h=h+1|0;}while((h|0)<(f|0));return}}function _Bb(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;l=c[d>>2]|0;m=c[d+4>>2]|0;d=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-j|0;q=4096-k|0;r=i+1>>1;if((r|0)<=0){return}i=h;h=0;do{s=h<<1;t=ca(b[l+(s<<1)>>1]|0,g)|0;u=(ca(b[m+(s<<1)>>1]|0,j)|0)+t>>19;t=s|1;v=ca(b[l+(t<<1)>>1]|0,g)|0;w=(ca(b[m+(t<<1)>>1]|0,j)|0)+v>>19;v=ca(b[d+(h<<1)>>1]|0,q)|0;x=(ca(b[n+(h<<1)>>1]|0,k)|0)+v>>19;v=ca(b[e+(h<<1)>>1]|0,q)|0;y=((ca(b[o+(h<<1)>>1]|0,k)|0)+v>>19)+128|0;v=x+128|0;x=ca(b[f+(s<<1)>>1]|0,g)|0;z=(ca(b[p+(s<<1)>>1]|0,j)|0)+x>>19;x=ca(b[f+(t<<1)>>1]|0,g)|0;A=(ca(b[p+(t<<1)>>1]|0,j)|0)+x>>19;if(z>>>0>255>>>0){B=-z>>31&255}else{B=z&255}if(A>>>0>255>>>0){C=-A>>31&255}else{C=A&255}A=c[a+4352+(y<<2)>>2]|0;z=(c[a+6400+(v<<2)>>2]|0)+(c[a+2304+(y<<2)>>2]|0)|0;y=c[a+8448+(v<<2)>>2]|0;c[i+(s<<2)>>2]=(c[A+(u<<2)>>2]|0)+(B&255)+(c[z+(u<<2)>>2]|0)+(c[y+(u<<2)>>2]|0);c[i+(t<<2)>>2]=(c[A+(w<<2)>>2]|0)+(C&255)+(c[z+(w<<2)>>2]|0)+(c[y+(w<<2)>>2]|0);h=h+1|0;}while((h|0)<(r|0));return}function $Bb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;n=m+1>>1;if((n|0)<=0){return}m=(f|0)>0;o=(j|0)>0;p=l;l=0;do{if(m){q=l<<1;r=q|1;s=262144;t=262144;u=0;do{v=c[e+(u<<2)>>2]|0;w=b[d+(u<<1)>>1]|0;s=(ca(w,b[v+(q<<1)>>1]|0)|0)+s|0;t=(ca(b[v+(r<<1)>>1]|0,w)|0)+t|0;u=u+1|0;}while((u|0)<(f|0));x=s>>19;y=t>>19}else{x=0;y=0}if(o){u=262144;r=262144;q=0;do{w=b[g+(q<<1)>>1]|0;u=(ca(w,b[(c[h+(q<<2)>>2]|0)+(l<<1)>>1]|0)|0)+u|0;r=(ca(b[(c[i+(q<<2)>>2]|0)+(l<<1)>>1]|0,w)|0)+r|0;q=q+1|0;}while((q|0)<(j|0));z=(u>>19)+128|0;A=(r>>19)+128|0}else{z=128;A=128}if(m){q=l<<1;t=q|1;s=262144;w=262144;v=0;do{B=c[k+(v<<2)>>2]|0;C=b[d+(v<<1)>>1]|0;w=(ca(C,b[B+(q<<1)>>1]|0)|0)+w|0;s=(ca(b[B+(t<<1)>>1]|0,C)|0)+s|0;v=v+1|0;}while((v|0)<(f|0));D=s>>19;E=w>>19}else{D=0;E=0}if(((D|E)&256|0)==0){F=E;G=D}else{if(E>>>0>255>>>0){H=-E>>31&255}else{H=E&255}if(D>>>0>255>>>0){I=-D>>31&255}else{I=D&255}F=H&255;G=I&255}v=c[a+4352+(A<<2)>>2]|0;t=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(A<<2)>>2]|0)|0;q=c[a+8448+(z<<2)>>2]|0;r=l<<1;c[p+(r<<2)>>2]=(c[v+(x<<2)>>2]|0)+F+(c[t+(x<<2)>>2]|0)+(c[q+(x<<2)>>2]|0);c[p+((r|1)<<2)>>2]=(c[v+(y<<2)>>2]|0)+G+(c[t+(y<<2)>>2]|0)+(c[q+(y<<2)>>2]|0);l=l+1|0;}while((l|0)<(n|0));return}function aCb(a,d,e,f,g,h,i,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=c[e>>2]|0;g=c[f>>2]|0;if((j|0)<2048){j=i+1>>1;if((j|0)<=0){return}l=h;m=0;do{n=m<<1;o=(b[d+(n<<1)>>1]|0)+64>>7;p=n|1;q=(b[d+(p<<1)>>1]|0)+64>>7;r=((b[g+(m<<1)>>1]|0)+64>>7)+128|0;s=((b[k+(m<<1)>>1]|0)+64>>7)+128|0;t=c[a+4352+(r<<2)>>2]|0;u=(c[a+6400+(s<<2)>>2]|0)+(c[a+2304+(r<<2)>>2]|0)|0;r=c[a+8448+(s<<2)>>2]|0;c[l+(n<<2)>>2]=(c[u+(o<<2)>>2]|0)+(c[t+(o<<2)>>2]|0)+(c[r+(o<<2)>>2]|0);c[l+(p<<2)>>2]=(c[u+(q<<2)>>2]|0)+(c[t+(q<<2)>>2]|0)+(c[r+(q<<2)>>2]|0);m=m+1|0;}while((m|0)<(j|0));return}else{j=c[e+4>>2]|0;e=c[f+4>>2]|0;f=i+1>>1;if((f|0)<=0){return}i=h;h=0;do{m=h<<1;l=(b[d+(m<<1)>>1]|0)+64>>7;q=m|1;r=(b[d+(q<<1)>>1]|0)+64>>7;t=((b[g+(h<<1)>>1]|0)+128+(b[e+(h<<1)>>1]|0)>>8)+128|0;u=((b[k+(h<<1)>>1]|0)+128+(b[j+(h<<1)>>1]|0)>>8)+128|0;p=c[a+4352+(t<<2)>>2]|0;o=(c[a+6400+(u<<2)>>2]|0)+(c[a+2304+(t<<2)>>2]|0)|0;t=c[a+8448+(u<<2)>>2]|0;c[i+(m<<2)>>2]=(c[o+(l<<2)>>2]|0)+(c[p+(l<<2)>>2]|0)+(c[t+(l<<2)>>2]|0);c[i+(q<<2)>>2]=(c[o+(r<<2)>>2]|0)+(c[p+(r<<2)>>2]|0)+(c[t+(r<<2)>>2]|0);h=h+1|0;}while((h|0)<(f|0));return}}function bCb(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=c[d>>2]|0;g=c[d+4>>2]|0;d=c[e>>2]|0;m=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=4096-j|0;o=4096-k|0;p=i+1>>1;if((p|0)<=0){return}i=h;h=0;do{q=h<<1;r=ca(b[l+(q<<1)>>1]|0,f)|0;s=(ca(b[g+(q<<1)>>1]|0,j)|0)+r>>19;r=q|1;t=ca(b[l+(r<<1)>>1]|0,f)|0;u=(ca(b[g+(r<<1)>>1]|0,j)|0)+t>>19;t=ca(b[d+(h<<1)>>1]|0,o)|0;v=(ca(b[m+(h<<1)>>1]|0,k)|0)+t>>19;t=ca(b[e+(h<<1)>>1]|0,o)|0;w=((ca(b[n+(h<<1)>>1]|0,k)|0)+t>>19)+128|0;t=v+128|0;v=c[a+4352+(w<<2)>>2]|0;x=(c[a+6400+(t<<2)>>2]|0)+(c[a+2304+(w<<2)>>2]|0)|0;w=c[a+8448+(t<<2)>>2]|0;c[i+(q<<2)>>2]=(c[x+(s<<2)>>2]|0)+(c[v+(s<<2)>>2]|0)+(c[w+(s<<2)>>2]|0);c[i+(r<<2)>>2]=(c[x+(u<<2)>>2]|0)+(c[v+(u<<2)>>2]|0)+(c[w+(u<<2)>>2]|0);h=h+1|0;}while((h|0)<(p|0));return}function cCb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;n=m+1>>1;if((n|0)<=0){return}m=(f|0)>0;k=(j|0)>0;o=l;l=0;do{if(m){p=l<<1;q=p|1;r=262144;s=262144;t=0;do{u=c[e+(t<<2)>>2]|0;v=b[d+(t<<1)>>1]|0;r=(ca(v,b[u+(p<<1)>>1]|0)|0)+r|0;s=(ca(b[u+(q<<1)>>1]|0,v)|0)+s|0;t=t+1|0;}while((t|0)<(f|0));w=r>>19;x=s>>19}else{w=0;x=0}if(k){t=262144;q=262144;p=0;do{v=b[g+(p<<1)>>1]|0;t=(ca(v,b[(c[h+(p<<2)>>2]|0)+(l<<1)>>1]|0)|0)+t|0;q=(ca(b[(c[i+(p<<2)>>2]|0)+(l<<1)>>1]|0,v)|0)+q|0;p=p+1|0;}while((p|0)<(j|0));y=(t>>19)+128|0;z=(q>>19)+128|0}else{y=128;z=128}p=c[a+4352+(z<<2)>>2]|0;s=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;r=c[a+8448+(y<<2)>>2]|0;v=l<<1;c[o+(v<<2)>>2]=(c[s+(w<<2)>>2]|0)+(c[p+(w<<2)>>2]|0)+(c[r+(w<<2)>>2]|0);c[o+((v|1)<<2)>>2]=(c[s+(x<<2)>>2]|0)+(c[p+(x<<2)>>2]|0)+(c[r+(x<<2)>>2]|0);l=l+1|0;}while((l|0)<(n|0));return}function dCb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)>0){m=0}else{return}do{n=m<<1;o=(b[e+(n<<1)>>1]|0)+64>>7;p=(b[e+((n|1)<<1)>>1]|0)+64>>7;n=((b[h+(m<<1)>>1]|0)+64>>7)+128|0;q=c[d+4352+(n<<2)>>2]|0;r=((b[l+(m<<1)>>1]|0)+64>>7)+128|0;s=c[d+6400+(r<<2)>>2]|0;t=c[d+2304+(n<<2)>>2]|0;n=c[d+8448+(r<<2)>>2]|0;r=m*6|0;a[i+r|0]=a[q+o|0]|0;a[i+(r|1)|0]=a[s+(t+o)|0]|0;a[i+(r+2)|0]=a[n+o|0]|0;a[i+(r+3)|0]=a[q+p|0]|0;a[i+(r+4)|0]=a[s+(t+p)|0]|0;a[i+(r+5)|0]=a[n+p|0]|0;m=m+1|0;}while((m|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)>0){u=0}else{return}do{j=u<<1;m=(b[e+(j<<1)>>1]|0)+64>>7;p=(b[e+((j|1)<<1)>>1]|0)+64>>7;j=((b[h+(u<<1)>>1]|0)+128+(b[f+(u<<1)>>1]|0)>>8)+128|0;n=c[d+4352+(j<<2)>>2]|0;r=((b[l+(u<<1)>>1]|0)+128+(b[k+(u<<1)>>1]|0)>>8)+128|0;t=c[d+6400+(r<<2)>>2]|0;s=c[d+2304+(j<<2)>>2]|0;j=c[d+8448+(r<<2)>>2]|0;r=u*6|0;a[i+r|0]=a[n+m|0]|0;a[i+(r|1)|0]=a[t+(s+m)|0]|0;a[i+(r+2)|0]=a[j+m|0]|0;a[i+(r+3)|0]=a[n+p|0]|0;a[i+(r+4)|0]=a[t+(s+p)|0]|0;a[i+(r+5)|0]=a[j+p|0]|0;u=u+1|0;}while((u|0)<(g|0));return}}function eCb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;q=j+1>>1;if((q|0)>0){r=0}else{return}do{j=r<<1;s=ca(b[m+(j<<1)>>1]|0,g)|0;t=(ca(b[h+(j<<1)>>1]|0,k)|0)+s>>19;s=j|1;j=ca(b[m+(s<<1)>>1]|0,g)|0;u=(ca(b[h+(s<<1)>>1]|0,k)|0)+j>>19;j=ca(b[e+(r<<1)>>1]|0,p)|0;s=(ca(b[n+(r<<1)>>1]|0,l)|0)+j>>19;j=ca(b[f+(r<<1)>>1]|0,p)|0;v=((ca(b[o+(r<<1)>>1]|0,l)|0)+j>>19)+128|0;j=c[d+4352+(v<<2)>>2]|0;w=s+128|0;s=c[d+6400+(w<<2)>>2]|0;x=c[d+2304+(v<<2)>>2]|0;v=c[d+8448+(w<<2)>>2]|0;w=r*6|0;a[i+w|0]=a[j+t|0]|0;a[i+(w|1)|0]=a[s+(x+t)|0]|0;a[i+(w+2)|0]=a[v+t|0]|0;a[i+(w+3)|0]=a[j+u|0]|0;a[i+(w+4)|0]=a[s+(x+u)|0]|0;a[i+(w+5)|0]=a[v+u|0]|0;r=r+1|0;}while((r|0)<(q|0));return}function fCb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;o=n+1>>1;if((o|0)<=0){return}n=(g|0)>0;l=(k|0)>0;p=0;do{if(n){q=p<<1;r=q|1;s=262144;t=262144;u=0;do{v=c[f+(u<<2)>>2]|0;w=b[e+(u<<1)>>1]|0;s=(ca(w,b[v+(q<<1)>>1]|0)|0)+s|0;t=(ca(b[v+(r<<1)>>1]|0,w)|0)+t|0;u=u+1|0;}while((u|0)<(g|0));x=s>>19;y=t>>19}else{x=0;y=0}if(l){u=262144;r=262144;q=0;do{w=b[h+(q<<1)>>1]|0;u=(ca(w,b[(c[i+(q<<2)>>2]|0)+(p<<1)>>1]|0)|0)+u|0;r=(ca(b[(c[j+(q<<2)>>2]|0)+(p<<1)>>1]|0,w)|0)+r|0;q=q+1|0;}while((q|0)<(k|0));z=(u>>19)+128|0;A=(r>>19)+128|0}else{z=128;A=128}q=c[d+4352+(A<<2)>>2]|0;t=c[d+6400+(z<<2)>>2]|0;s=c[d+2304+(A<<2)>>2]|0;w=c[d+8448+(z<<2)>>2]|0;v=p*6|0;a[m+v|0]=a[q+x|0]|0;a[m+(v|1)|0]=a[t+(s+x)|0]|0;a[m+(v+2)|0]=a[w+x|0]|0;a[m+(v+3)|0]=a[q+y|0]|0;a[m+(v+4)|0]=a[t+(s+y)|0]|0;a[m+(v+5)|0]=a[w+y|0]|0;p=p+1|0;}while((p|0)<(o|0));return}function gCb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)>0){m=0}else{return}do{n=m<<1;o=(b[e+(n<<1)>>1]|0)+64>>7;p=(b[e+((n|1)<<1)>>1]|0)+64>>7;n=((b[h+(m<<1)>>1]|0)+64>>7)+128|0;q=c[d+4352+(n<<2)>>2]|0;r=((b[l+(m<<1)>>1]|0)+64>>7)+128|0;s=c[d+6400+(r<<2)>>2]|0;t=c[d+2304+(n<<2)>>2]|0;n=c[d+8448+(r<<2)>>2]|0;r=m*6|0;a[i+r|0]=a[n+o|0]|0;a[i+(r|1)|0]=a[s+(t+o)|0]|0;a[i+(r+2)|0]=a[q+o|0]|0;a[i+(r+3)|0]=a[n+p|0]|0;a[i+(r+4)|0]=a[s+(t+p)|0]|0;a[i+(r+5)|0]=a[q+p|0]|0;m=m+1|0;}while((m|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)>0){u=0}else{return}do{j=u<<1;m=(b[e+(j<<1)>>1]|0)+64>>7;p=(b[e+((j|1)<<1)>>1]|0)+64>>7;j=((b[h+(u<<1)>>1]|0)+128+(b[f+(u<<1)>>1]|0)>>8)+128|0;q=c[d+4352+(j<<2)>>2]|0;r=((b[l+(u<<1)>>1]|0)+128+(b[k+(u<<1)>>1]|0)>>8)+128|0;t=c[d+6400+(r<<2)>>2]|0;s=c[d+2304+(j<<2)>>2]|0;j=c[d+8448+(r<<2)>>2]|0;r=u*6|0;a[i+r|0]=a[j+m|0]|0;a[i+(r|1)|0]=a[t+(s+m)|0]|0;a[i+(r+2)|0]=a[q+m|0]|0;a[i+(r+3)|0]=a[j+p|0]|0;a[i+(r+4)|0]=a[t+(s+p)|0]|0;a[i+(r+5)|0]=a[q+p|0]|0;u=u+1|0;}while((u|0)<(g|0));return}}function hCb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;n=c[f+4>>2]|0;f=c[g>>2]|0;o=c[g+4>>2]|0;g=4096-k|0;p=4096-l|0;q=j+1>>1;if((q|0)>0){r=0}else{return}do{j=r<<1;s=ca(b[m+(j<<1)>>1]|0,g)|0;t=(ca(b[h+(j<<1)>>1]|0,k)|0)+s>>19;s=j|1;j=ca(b[m+(s<<1)>>1]|0,g)|0;u=(ca(b[h+(s<<1)>>1]|0,k)|0)+j>>19;j=ca(b[e+(r<<1)>>1]|0,p)|0;s=(ca(b[n+(r<<1)>>1]|0,l)|0)+j>>19;j=ca(b[f+(r<<1)>>1]|0,p)|0;v=((ca(b[o+(r<<1)>>1]|0,l)|0)+j>>19)+128|0;j=c[d+4352+(v<<2)>>2]|0;w=s+128|0;s=c[d+6400+(w<<2)>>2]|0;x=c[d+2304+(v<<2)>>2]|0;v=c[d+8448+(w<<2)>>2]|0;w=r*6|0;a[i+w|0]=a[v+t|0]|0;a[i+(w|1)|0]=a[s+(x+t)|0]|0;a[i+(w+2)|0]=a[j+t|0]|0;a[i+(w+3)|0]=a[v+u|0]|0;a[i+(w+4)|0]=a[s+(x+u)|0]|0;a[i+(w+5)|0]=a[j+u|0]|0;r=r+1|0;}while((r|0)<(q|0));return}function iCb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;o=n+1>>1;if((o|0)<=0){return}n=(g|0)>0;l=(k|0)>0;p=0;do{if(n){q=p<<1;r=q|1;s=262144;t=262144;u=0;do{v=c[f+(u<<2)>>2]|0;w=b[e+(u<<1)>>1]|0;s=(ca(w,b[v+(q<<1)>>1]|0)|0)+s|0;t=(ca(b[v+(r<<1)>>1]|0,w)|0)+t|0;u=u+1|0;}while((u|0)<(g|0));x=s>>19;y=t>>19}else{x=0;y=0}if(l){u=262144;r=262144;q=0;do{w=b[h+(q<<1)>>1]|0;u=(ca(w,b[(c[i+(q<<2)>>2]|0)+(p<<1)>>1]|0)|0)+u|0;r=(ca(b[(c[j+(q<<2)>>2]|0)+(p<<1)>>1]|0,w)|0)+r|0;q=q+1|0;}while((q|0)<(k|0));z=(u>>19)+128|0;A=(r>>19)+128|0}else{z=128;A=128}q=c[d+4352+(A<<2)>>2]|0;t=c[d+6400+(z<<2)>>2]|0;s=c[d+2304+(A<<2)>>2]|0;w=c[d+8448+(z<<2)>>2]|0;v=p*6|0;a[m+v|0]=a[w+x|0]|0;a[m+(v|1)|0]=a[t+(s+x)|0]|0;a[m+(v+2)|0]=a[q+x|0]|0;a[m+(v+3)|0]=a[w+y|0]|0;a[m+(v+4)|0]=a[t+(s+y)|0]|0;a[m+(v+5)|0]=a[q+y|0]|0;p=p+1|0;}while((p|0)<(o|0));return}function jCb(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){return}n=i;o=l&1;p=o^1;q=d[1401352+(o<<3)|0]|0;r=d[1401376+(o<<3)|0]|0;s=d[1401353+(o<<3)|0]|0;t=d[1401377+(o<<3)|0]|0;o=d[1401352+(p<<3)|0]|0;u=d[1401353+(p<<3)|0]|0;p=0;do{v=p<<1;w=(b[e+(v<<1)>>1]|0)+64>>7;x=v|1;y=(b[e+(x<<1)>>1]|0)+64>>7;z=((b[m+(p<<1)>>1]|0)+64>>7)+128|0;A=((b[h+(p<<1)>>1]|0)+64>>7)+128|0;B=c[a+4352+(z<<2)>>2]|0;C=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;z=c[a+8448+(A<<2)>>2]|0;b[n+(v<<1)>>1]=((b[C+(r+w<<1)>>1]|0)+(b[B+(q+w<<1)>>1]|0)&65535)+(b[z+(o+w<<1)>>1]|0);b[n+(x<<1)>>1]=((b[C+(t+y<<1)>>1]|0)+(b[B+(s+y<<1)>>1]|0)&65535)+(b[z+(u+y<<1)>>1]|0);p=p+1|0;}while((p|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)<=0){return}j=i;i=l&1;l=i^1;p=d[1401352+(i<<3)|0]|0;u=d[1401376+(i<<3)|0]|0;s=d[1401353+(i<<3)|0]|0;t=d[1401377+(i<<3)|0]|0;i=d[1401352+(l<<3)|0]|0;n=d[1401353+(l<<3)|0]|0;l=0;do{o=l<<1;q=(b[e+(o<<1)>>1]|0)+64>>7;r=o|1;y=(b[e+(r<<1)>>1]|0)+64>>7;z=((b[m+(l<<1)>>1]|0)+128+(b[f+(l<<1)>>1]|0)>>8)+128|0;B=((b[h+(l<<1)>>1]|0)+128+(b[k+(l<<1)>>1]|0)>>8)+128|0;C=c[a+4352+(z<<2)>>2]|0;x=(c[a+6400+(B<<2)>>2]|0)+(c[a+2304+(z<<2)>>2]|0)|0;z=c[a+8448+(B<<2)>>2]|0;b[j+(o<<1)>>1]=((b[x+(u+q<<1)>>1]|0)+(b[C+(p+q<<1)>>1]|0)&65535)+(b[z+(i+q<<1)>>1]|0);b[j+(r<<1)>>1]=((b[x+(t+y<<1)>>1]|0)+(b[C+(s+y<<1)>>1]|0)&65535)+(b[z+(n+y<<1)>>1]|0);l=l+1|0;}while((l|0)<(g|0));return}}function kCb(a,e,f,g,h,i,j,k,l,m){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){return}j=i;i=m&1;m=i^1;s=d[1401352+(i<<3)|0]|0;t=d[1401376+(i<<3)|0]|0;u=d[1401353+(i<<3)|0]|0;v=d[1401377+(i<<3)|0]|0;i=d[1401352+(m<<3)|0]|0;w=d[1401353+(m<<3)|0]|0;m=0;do{x=m<<1;y=ca(b[h+(x<<1)>>1]|0,g)|0;z=(ca(b[n+(x<<1)>>1]|0,k)|0)+y>>19;y=x|1;A=ca(b[h+(y<<1)>>1]|0,g)|0;B=(ca(b[n+(y<<1)>>1]|0,k)|0)+A>>19;A=ca(b[e+(m<<1)>>1]|0,q)|0;C=(ca(b[o+(m<<1)>>1]|0,l)|0)+A>>19;A=ca(b[f+(m<<1)>>1]|0,q)|0;D=((ca(b[p+(m<<1)>>1]|0,l)|0)+A>>19)+128|0;A=C+128|0;C=c[a+4352+(D<<2)>>2]|0;E=(c[a+6400+(A<<2)>>2]|0)+(c[a+2304+(D<<2)>>2]|0)|0;D=c[a+8448+(A<<2)>>2]|0;b[j+(x<<1)>>1]=((b[E+(t+z<<1)>>1]|0)+(b[C+(s+z<<1)>>1]|0)&65535)+(b[D+(i+z<<1)>>1]|0);b[j+(y<<1)>>1]=((b[E+(v+B<<1)>>1]|0)+(b[C+(u+B<<1)>>1]|0)&65535)+(b[D+(w+B<<1)>>1]|0);m=m+1|0;}while((m|0)<(r|0));return}function lCb(a,e,f,g,h,i,j,k,l,m,n,o){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;l=n+1>>1;if((l|0)<=0){return}n=(g|0)>0;p=(k|0)>0;q=m;m=o&1;o=m^1;r=d[1401352+(m<<3)|0]|0;s=d[1401376+(m<<3)|0]|0;t=d[1401353+(m<<3)|0]|0;u=d[1401377+(m<<3)|0]|0;m=d[1401352+(o<<3)|0]|0;v=d[1401353+(o<<3)|0]|0;o=0;do{if(n){w=o<<1;x=w|1;y=262144;z=262144;A=0;do{B=c[f+(A<<2)>>2]|0;C=b[e+(A<<1)>>1]|0;y=(ca(C,b[B+(w<<1)>>1]|0)|0)+y|0;z=(ca(b[B+(x<<1)>>1]|0,C)|0)+z|0;A=A+1|0;}while((A|0)<(g|0));D=y>>19;E=z>>19}else{D=0;E=0}if(p){A=262144;x=262144;w=0;do{C=b[h+(w<<1)>>1]|0;A=(ca(C,b[(c[i+(w<<2)>>2]|0)+(o<<1)>>1]|0)|0)+A|0;x=(ca(b[(c[j+(w<<2)>>2]|0)+(o<<1)>>1]|0,C)|0)+x|0;w=w+1|0;}while((w|0)<(k|0));F=(A>>19)+128|0;G=(x>>19)+128|0}else{F=128;G=128}w=c[a+4352+(G<<2)>>2]|0;z=(c[a+6400+(F<<2)>>2]|0)+(c[a+2304+(G<<2)>>2]|0)|0;y=c[a+8448+(F<<2)>>2]|0;C=o<<1;b[q+(C<<1)>>1]=((b[z+(s+D<<1)>>1]|0)+(b[w+(r+D<<1)>>1]|0)&65535)+(b[y+(m+D<<1)>>1]|0);b[q+((C|1)<<1)>>1]=((b[z+(u+E<<1)>>1]|0)+(b[w+(t+E<<1)>>1]|0)&65535)+(b[y+(v+E<<1)>>1]|0);o=o+1|0;}while((o|0)<(l|0));return}function mCb(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){return}n=i;o=l&1;p=o^1;q=d[1401352+(o<<3)|0]|0;r=d[1401353+(o<<3)|0]|0;o=d[1401352+(p<<3)|0]|0;s=d[1401353+(p<<3)|0]|0;p=0;do{t=p<<1;u=(b[e+(t<<1)>>1]|0)+64>>7;v=t|1;w=(b[e+(v<<1)>>1]|0)+64>>7;x=((b[m+(p<<1)>>1]|0)+64>>7)+128|0;y=((b[h+(p<<1)>>1]|0)+64>>7)+128|0;z=c[a+4352+(x<<2)>>2]|0;A=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(y<<2)>>2]|0;b[n+(t<<1)>>1]=((b[A+(r+u<<1)>>1]|0)+(b[z+(q+u<<1)>>1]|0)&65535)+(b[x+(o+u<<1)>>1]|0);b[n+(v<<1)>>1]=((b[A+(q+w<<1)>>1]|0)+(b[z+(r+w<<1)>>1]|0)&65535)+(b[x+(s+w<<1)>>1]|0);p=p+1|0;}while((p|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)<=0){return}j=i;i=l&1;l=i^1;p=d[1401352+(i<<3)|0]|0;s=d[1401353+(i<<3)|0]|0;i=d[1401352+(l<<3)|0]|0;r=d[1401353+(l<<3)|0]|0;l=0;do{q=l<<1;n=(b[e+(q<<1)>>1]|0)+64>>7;o=q|1;w=(b[e+(o<<1)>>1]|0)+64>>7;x=((b[m+(l<<1)>>1]|0)+128+(b[f+(l<<1)>>1]|0)>>8)+128|0;z=((b[h+(l<<1)>>1]|0)+128+(b[k+(l<<1)>>1]|0)>>8)+128|0;A=c[a+4352+(x<<2)>>2]|0;v=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(z<<2)>>2]|0;b[j+(q<<1)>>1]=((b[v+(s+n<<1)>>1]|0)+(b[A+(p+n<<1)>>1]|0)&65535)+(b[x+(i+n<<1)>>1]|0);b[j+(o<<1)>>1]=((b[v+(p+w<<1)>>1]|0)+(b[A+(s+w<<1)>>1]|0)&65535)+(b[x+(r+w<<1)>>1]|0);l=l+1|0;}while((l|0)<(g|0));return}}function nCb(a,e,f,g,h,i,j,k,l,m){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){return}j=i;i=m&1;m=i^1;s=d[1401352+(i<<3)|0]|0;t=d[1401353+(i<<3)|0]|0;i=d[1401352+(m<<3)|0]|0;u=d[1401353+(m<<3)|0]|0;m=0;do{v=m<<1;w=ca(b[h+(v<<1)>>1]|0,g)|0;x=(ca(b[n+(v<<1)>>1]|0,k)|0)+w>>19;w=v|1;y=ca(b[h+(w<<1)>>1]|0,g)|0;z=(ca(b[n+(w<<1)>>1]|0,k)|0)+y>>19;y=ca(b[e+(m<<1)>>1]|0,q)|0;A=(ca(b[o+(m<<1)>>1]|0,l)|0)+y>>19;y=ca(b[f+(m<<1)>>1]|0,q)|0;B=((ca(b[p+(m<<1)>>1]|0,l)|0)+y>>19)+128|0;y=A+128|0;A=c[a+4352+(B<<2)>>2]|0;C=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(B<<2)>>2]|0)|0;B=c[a+8448+(y<<2)>>2]|0;b[j+(v<<1)>>1]=((b[C+(t+x<<1)>>1]|0)+(b[A+(s+x<<1)>>1]|0)&65535)+(b[B+(i+x<<1)>>1]|0);b[j+(w<<1)>>1]=((b[C+(s+z<<1)>>1]|0)+(b[A+(t+z<<1)>>1]|0)&65535)+(b[B+(u+z<<1)>>1]|0);m=m+1|0;}while((m|0)<(r|0));return}function oCb(a,e,f,g,h,i,j,k,l,m,n,o){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;l=n+1>>1;if((l|0)<=0){return}n=(g|0)>0;p=(k|0)>0;q=m;m=o&1;o=m^1;r=d[1401352+(m<<3)|0]|0;s=d[1401353+(m<<3)|0]|0;m=d[1401352+(o<<3)|0]|0;t=d[1401353+(o<<3)|0]|0;o=0;do{if(n){u=o<<1;v=u|1;w=262144;x=262144;y=0;do{z=c[f+(y<<2)>>2]|0;A=b[e+(y<<1)>>1]|0;w=(ca(A,b[z+(u<<1)>>1]|0)|0)+w|0;x=(ca(b[z+(v<<1)>>1]|0,A)|0)+x|0;y=y+1|0;}while((y|0)<(g|0));B=w>>19;C=x>>19}else{B=0;C=0}if(p){y=262144;v=262144;u=0;do{A=b[h+(u<<1)>>1]|0;y=(ca(A,b[(c[i+(u<<2)>>2]|0)+(o<<1)>>1]|0)|0)+y|0;v=(ca(b[(c[j+(u<<2)>>2]|0)+(o<<1)>>1]|0,A)|0)+v|0;u=u+1|0;}while((u|0)<(k|0));D=(y>>19)+128|0;E=(v>>19)+128|0}else{D=128;E=128}u=c[a+4352+(E<<2)>>2]|0;x=(c[a+6400+(D<<2)>>2]|0)+(c[a+2304+(E<<2)>>2]|0)|0;w=c[a+8448+(D<<2)>>2]|0;A=o<<1;b[q+(A<<1)>>1]=((b[x+(s+B<<1)>>1]|0)+(b[u+(r+B<<1)>>1]|0)&65535)+(b[w+(m+B<<1)>>1]|0);b[q+((A|1)<<1)>>1]=((b[x+(r+C<<1)>>1]|0)+(b[u+(s+C<<1)>>1]|0)&65535)+(b[w+(t+C<<1)>>1]|0);o=o+1|0;}while((o|0)<(l|0));return}function pCb(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=c[f>>2]|0;m=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)<=0){return}n=i;o=l&3;p=o^3;q=d[1401312+(o<<3)|0]|0;r=d[1401313+(o<<3)|0]|0;o=d[1401312+(p<<3)|0]|0;s=d[1401313+(p<<3)|0]|0;p=0;do{t=p<<1;u=(b[e+(t<<1)>>1]|0)+64>>7;v=t|1;w=(b[e+(v<<1)>>1]|0)+64>>7;x=((b[m+(p<<1)>>1]|0)+64>>7)+128|0;y=((b[h+(p<<1)>>1]|0)+64>>7)+128|0;z=c[a+4352+(x<<2)>>2]|0;A=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(y<<2)>>2]|0;b[n+(t<<1)>>1]=((b[A+(r+u<<1)>>1]|0)+(b[z+(q+u<<1)>>1]|0)&65535)+(b[x+(o+u<<1)>>1]|0);b[n+(v<<1)>>1]=((b[A+(q+w<<1)>>1]|0)+(b[z+(r+w<<1)>>1]|0)&65535)+(b[x+(s+w<<1)>>1]|0);p=p+1|0;}while((p|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)<=0){return}j=i;i=l&3;l=i^3;p=d[1401312+(i<<3)|0]|0;s=d[1401313+(i<<3)|0]|0;i=d[1401312+(l<<3)|0]|0;r=d[1401313+(l<<3)|0]|0;l=0;do{q=l<<1;n=(b[e+(q<<1)>>1]|0)+64>>7;o=q|1;w=(b[e+(o<<1)>>1]|0)+64>>7;x=((b[m+(l<<1)>>1]|0)+128+(b[f+(l<<1)>>1]|0)>>8)+128|0;z=((b[h+(l<<1)>>1]|0)+128+(b[k+(l<<1)>>1]|0)>>8)+128|0;A=c[a+4352+(x<<2)>>2]|0;v=(c[a+6400+(z<<2)>>2]|0)+(c[a+2304+(x<<2)>>2]|0)|0;x=c[a+8448+(z<<2)>>2]|0;b[j+(q<<1)>>1]=((b[v+(s+n<<1)>>1]|0)+(b[A+(p+n<<1)>>1]|0)&65535)+(b[x+(i+n<<1)>>1]|0);b[j+(o<<1)>>1]=((b[v+(p+w<<1)>>1]|0)+(b[A+(s+w<<1)>>1]|0)&65535)+(b[x+(r+w<<1)>>1]|0);l=l+1|0;}while((l|0)<(g|0));return}}function qCb(a,e,f,g,h,i,j,k,l,m){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[e>>2]|0;n=c[e+4>>2]|0;e=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=4096-k|0;q=4096-l|0;r=j+1>>1;if((r|0)<=0){return}j=i;i=m&3;m=i^3;s=d[1401312+(i<<3)|0]|0;t=d[1401313+(i<<3)|0]|0;i=d[1401312+(m<<3)|0]|0;u=d[1401313+(m<<3)|0]|0;m=0;do{v=m<<1;w=ca(b[h+(v<<1)>>1]|0,g)|0;x=(ca(b[n+(v<<1)>>1]|0,k)|0)+w>>19;w=v|1;y=ca(b[h+(w<<1)>>1]|0,g)|0;z=(ca(b[n+(w<<1)>>1]|0,k)|0)+y>>19;y=ca(b[e+(m<<1)>>1]|0,q)|0;A=(ca(b[o+(m<<1)>>1]|0,l)|0)+y>>19;y=ca(b[f+(m<<1)>>1]|0,q)|0;B=((ca(b[p+(m<<1)>>1]|0,l)|0)+y>>19)+128|0;y=A+128|0;A=c[a+4352+(B<<2)>>2]|0;C=(c[a+6400+(y<<2)>>2]|0)+(c[a+2304+(B<<2)>>2]|0)|0;B=c[a+8448+(y<<2)>>2]|0;b[j+(v<<1)>>1]=((b[C+(t+x<<1)>>1]|0)+(b[A+(s+x<<1)>>1]|0)&65535)+(b[B+(i+x<<1)>>1]|0);b[j+(w<<1)>>1]=((b[C+(s+z<<1)>>1]|0)+(b[A+(t+z<<1)>>1]|0)&65535)+(b[B+(u+z<<1)>>1]|0);m=m+1|0;}while((m|0)<(r|0));return}function rCb(a,e,f,g,h,i,j,k,l,m,n,o){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;l=n+1>>1;if((l|0)<=0){return}n=(g|0)>0;p=(k|0)>0;q=m;m=o&3;o=m^3;r=d[1401312+(m<<3)|0]|0;s=d[1401313+(m<<3)|0]|0;m=d[1401312+(o<<3)|0]|0;t=d[1401313+(o<<3)|0]|0;o=0;do{if(n){u=o<<1;v=u|1;w=262144;x=262144;y=0;do{z=c[f+(y<<2)>>2]|0;A=b[e+(y<<1)>>1]|0;w=(ca(A,b[z+(u<<1)>>1]|0)|0)+w|0;x=(ca(b[z+(v<<1)>>1]|0,A)|0)+x|0;y=y+1|0;}while((y|0)<(g|0));B=w>>19;C=x>>19}else{B=0;C=0}if(p){y=262144;v=262144;u=0;do{A=b[h+(u<<1)>>1]|0;y=(ca(A,b[(c[i+(u<<2)>>2]|0)+(o<<1)>>1]|0)|0)+y|0;v=(ca(b[(c[j+(u<<2)>>2]|0)+(o<<1)>>1]|0,A)|0)+v|0;u=u+1|0;}while((u|0)<(k|0));D=(y>>19)+128|0;E=(v>>19)+128|0}else{D=128;E=128}u=c[a+4352+(E<<2)>>2]|0;x=(c[a+6400+(D<<2)>>2]|0)+(c[a+2304+(E<<2)>>2]|0)|0;w=c[a+8448+(D<<2)>>2]|0;A=o<<1;b[q+(A<<1)>>1]=((b[x+(s+B<<1)>>1]|0)+(b[u+(r+B<<1)>>1]|0)&65535)+(b[w+(m+B<<1)>>1]|0);b[q+((A|1)<<1)>>1]=((b[x+(r+C<<1)>>1]|0)+(b[u+(s+C<<1)>>1]|0)&65535)+(b[w+(t+C<<1)>>1]|0);o=o+1|0;}while((o|0)<(l|0));return}function sCb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;i=c[g>>2]|0;n=c[h>>2]|0;if((l|0)<2048){l=k+1>>1;if((l|0)<=0){return}o=m&7;p=0;do{q=p<<1;r=(b[f+(q<<1)>>1]|0)+64>>7;s=q|1;t=(b[f+(s<<1)>>1]|0)+64>>7;u=((b[n+(p<<1)>>1]|0)+64>>7)+128|0;v=c[e+4352+(u<<2)>>2]|0;w=((b[i+(p<<1)>>1]|0)+64>>7)+128|0;x=c[e+6400+(w<<2)>>2]|0;y=c[e+2304+(u<<2)>>2]|0;u=c[e+8448+(w<<2)>>2]|0;w=q&6;z=d[1401096+(o<<3)+w|0]|0;A=w|1;B=d[1401096+(o<<3)+A|0]|0;C=d[1401024+(o<<3)+A|0]|0;a[j+q|0]=((a[x+(y+r+z)|0]|0)+(a[v+(z+r)|0]|0)&255)+(a[u+((d[1401024+(o<<3)+w|0]|0)+r)|0]|0);a[j+s|0]=((a[x+(y+t+B)|0]|0)+(a[v+(B+t)|0]|0)&255)+(a[u+(C+t)|0]|0);p=p+1|0;}while((p|0)<(l|0));return}else{l=c[g+4>>2]|0;g=c[h+4>>2]|0;h=k+1>>1;if((h|0)<=0){return}k=m&7;m=0;do{p=m<<1;o=(b[f+(p<<1)>>1]|0)+64>>7;t=p|1;C=(b[f+(t<<1)>>1]|0)+64>>7;u=((b[n+(m<<1)>>1]|0)+128+(b[g+(m<<1)>>1]|0)>>8)+128|0;B=c[e+4352+(u<<2)>>2]|0;v=((b[i+(m<<1)>>1]|0)+128+(b[l+(m<<1)>>1]|0)>>8)+128|0;y=c[e+6400+(v<<2)>>2]|0;x=c[e+2304+(u<<2)>>2]|0;u=c[e+8448+(v<<2)>>2]|0;v=p&6;s=d[1401096+(k<<3)+v|0]|0;r=v|1;w=d[1401096+(k<<3)+r|0]|0;z=d[1401024+(k<<3)+r|0]|0;a[j+p|0]=((a[y+(x+o+s)|0]|0)+(a[B+(s+o)|0]|0)&255)+(a[u+((d[1401024+(k<<3)+v|0]|0)+o)|0]|0);a[j+t|0]=((a[y+(x+C+w)|0]|0)+(a[B+(w+C)|0]|0)&255)+(a[u+(z+C)|0]|0);m=m+1|0;}while((m|0)<(h|0));return}}function tCb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;i=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-l|0;r=4096-m|0;s=k+1>>1;if((s|0)<=0){return}k=n&7;n=0;do{t=n<<1;u=ca(b[i+(t<<1)>>1]|0,h)|0;v=(ca(b[o+(t<<1)>>1]|0,l)|0)+u>>19;u=t|1;w=ca(b[i+(u<<1)>>1]|0,h)|0;x=(ca(b[o+(u<<1)>>1]|0,l)|0)+w>>19;w=ca(b[f+(n<<1)>>1]|0,r)|0;y=(ca(b[p+(n<<1)>>1]|0,m)|0)+w>>19;w=ca(b[g+(n<<1)>>1]|0,r)|0;z=((ca(b[q+(n<<1)>>1]|0,m)|0)+w>>19)+128|0;w=c[e+4352+(z<<2)>>2]|0;A=y+128|0;y=c[e+6400+(A<<2)>>2]|0;B=c[e+2304+(z<<2)>>2]|0;z=c[e+8448+(A<<2)>>2]|0;A=t&6;C=d[1401096+(k<<3)+A|0]|0;D=A|1;E=d[1401096+(k<<3)+D|0]|0;F=d[1401024+(k<<3)+D|0]|0;a[j+t|0]=((a[y+(B+v+C)|0]|0)+(a[w+(C+v)|0]|0)&255)+(a[z+((d[1401024+(k<<3)+A|0]|0)+v)|0]|0);a[j+u|0]=((a[y+(B+x+E)|0]|0)+(a[w+(E+x)|0]|0)&255)+(a[z+(F+x)|0]|0);n=n+1|0;}while((n|0)<(s|0));return}function uCb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;m=o+1>>1;if((m|0)<=0){return}o=(h|0)>0;q=(l|0)>0;r=p&7;p=0;do{if(o){s=p<<1;t=s|1;u=262144;v=262144;w=0;do{x=c[g+(w<<2)>>2]|0;y=b[f+(w<<1)>>1]|0;u=(ca(y,b[x+(s<<1)>>1]|0)|0)+u|0;v=(ca(b[x+(t<<1)>>1]|0,y)|0)+v|0;w=w+1|0;}while((w|0)<(h|0));z=u>>19;A=v>>19}else{z=0;A=0}if(q){w=262144;t=262144;s=0;do{y=b[i+(s<<1)>>1]|0;w=(ca(y,b[(c[j+(s<<2)>>2]|0)+(p<<1)>>1]|0)|0)+w|0;t=(ca(b[(c[k+(s<<2)>>2]|0)+(p<<1)>>1]|0,y)|0)+t|0;s=s+1|0;}while((s|0)<(l|0));B=(w>>19)+128|0;C=(t>>19)+128|0}else{B=128;C=128}s=c[e+4352+(C<<2)>>2]|0;v=c[e+6400+(B<<2)>>2]|0;u=c[e+2304+(C<<2)>>2]|0;y=c[e+8448+(B<<2)>>2]|0;x=p<<1;D=x&6;E=d[1401096+(r<<3)+D|0]|0;F=D|1;G=d[1401096+(r<<3)+F|0]|0;H=d[1401024+(r<<3)+F|0]|0;a[n+x|0]=((a[v+(u+z+E)|0]|0)+(a[s+(E+z)|0]|0)&255)+(a[y+((d[1401024+(r<<3)+D|0]|0)+z)|0]|0);a[n+(x|1)|0]=((a[v+(u+A+G)|0]|0)+(a[s+(G+A)|0]|0)&255)+(a[y+(H+A)|0]|0);p=p+1|0;}while((p|0)<(m|0));return}function vCb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=c[g>>2]|0;n=c[h>>2]|0;if((l|0)<2048){l=k+1>>1;if((l|0)<=0){return}o=m&7;p=0;do{q=p<<1;r=(b[f+(q<<1)>>1]|0)+64>>7;s=(b[f+((q|1)<<1)>>1]|0)+64>>7;t=((b[n+(p<<1)>>1]|0)+64>>7)+128|0;u=c[e+4352+(t<<2)>>2]|0;v=((b[i+(p<<1)>>1]|0)+64>>7)+128|0;w=c[e+6400+(v<<2)>>2]|0;x=c[e+2304+(t<<2)>>2]|0;t=c[e+8448+(v<<2)>>2]|0;v=q&6;q=v|1;y=(d[1401168+(o<<3)+v|0]|0)+r|0;z=(d[1401168+(o<<3)+q|0]|0)+s|0;a[j+p|0]=(((a[w+(x+r+(d[1401024+(o<<3)+v|0]|0))|0]|0)+(a[u+y|0]|0)&255)+(a[t+y|0]|0)&255)+((((a[w+(x+s+(d[1401024+(o<<3)+q|0]|0))|0]|0)+(a[u+z|0]|0)&255)+(a[t+z|0]|0)&255)<<4);p=p+1|0;}while((p|0)<(l|0));return}else{l=c[g+4>>2]|0;g=c[h+4>>2]|0;h=k+1>>1;if((h|0)<=0){return}k=m&7;m=0;do{p=m<<1;o=(b[f+(p<<1)>>1]|0)+64>>7;z=(b[f+((p|1)<<1)>>1]|0)+64>>7;t=((b[n+(m<<1)>>1]|0)+128+(b[g+(m<<1)>>1]|0)>>8)+128|0;u=c[e+4352+(t<<2)>>2]|0;q=((b[i+(m<<1)>>1]|0)+128+(b[l+(m<<1)>>1]|0)>>8)+128|0;s=c[e+6400+(q<<2)>>2]|0;x=c[e+2304+(t<<2)>>2]|0;t=c[e+8448+(q<<2)>>2]|0;q=p&6;p=q|1;w=(d[1401168+(k<<3)+q|0]|0)+o|0;y=(d[1401168+(k<<3)+p|0]|0)+z|0;a[j+m|0]=(((a[s+(x+o+(d[1401024+(k<<3)+q|0]|0))|0]|0)+(a[u+w|0]|0)&255)+(a[t+w|0]|0)&255)+((((a[s+(x+z+(d[1401024+(k<<3)+p|0]|0))|0]|0)+(a[u+y|0]|0)&255)+(a[t+y|0]|0)&255)<<4);m=m+1|0;}while((m|0)<(h|0));return}}function wCb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;i=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-l|0;r=4096-m|0;s=k+1>>1;if((s|0)<=0){return}k=n&7;n=0;do{t=n<<1;u=ca(b[i+(t<<1)>>1]|0,h)|0;v=(ca(b[o+(t<<1)>>1]|0,l)|0)+u>>19;u=t|1;w=ca(b[i+(u<<1)>>1]|0,h)|0;x=(ca(b[o+(u<<1)>>1]|0,l)|0)+w>>19;w=ca(b[f+(n<<1)>>1]|0,r)|0;u=(ca(b[p+(n<<1)>>1]|0,m)|0)+w>>19;w=ca(b[g+(n<<1)>>1]|0,r)|0;y=((ca(b[q+(n<<1)>>1]|0,m)|0)+w>>19)+128|0;w=c[e+4352+(y<<2)>>2]|0;z=u+128|0;u=c[e+6400+(z<<2)>>2]|0;A=c[e+2304+(y<<2)>>2]|0;y=c[e+8448+(z<<2)>>2]|0;z=t&6;t=z|1;B=(d[1401168+(k<<3)+z|0]|0)+v|0;C=(d[1401168+(k<<3)+t|0]|0)+x|0;a[j+n|0]=(((a[u+(A+v+(d[1401024+(k<<3)+z|0]|0))|0]|0)+(a[w+B|0]|0)&255)+(a[y+B|0]|0)&255)+((((a[u+(A+x+(d[1401024+(k<<3)+t|0]|0))|0]|0)+(a[w+C|0]|0)&255)+(a[y+C|0]|0)&255)<<4);n=n+1|0;}while((n|0)<(s|0));return}function xCb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;m=o+1>>1;if((m|0)<=0){return}o=(h|0)>0;q=(l|0)>0;r=p&7;p=0;do{if(o){s=p<<1;t=s|1;u=262144;v=262144;w=0;do{x=c[g+(w<<2)>>2]|0;y=b[f+(w<<1)>>1]|0;u=(ca(y,b[x+(s<<1)>>1]|0)|0)+u|0;v=(ca(b[x+(t<<1)>>1]|0,y)|0)+v|0;w=w+1|0;}while((w|0)<(h|0));z=u>>19;A=v>>19}else{z=0;A=0}if(q){w=262144;t=262144;s=0;do{y=b[i+(s<<1)>>1]|0;w=(ca(y,b[(c[j+(s<<2)>>2]|0)+(p<<1)>>1]|0)|0)+w|0;t=(ca(b[(c[k+(s<<2)>>2]|0)+(p<<1)>>1]|0,y)|0)+t|0;s=s+1|0;}while((s|0)<(l|0));B=(w>>19)+128|0;C=(t>>19)+128|0}else{B=128;C=128}s=c[e+4352+(C<<2)>>2]|0;v=c[e+6400+(B<<2)>>2]|0;u=c[e+2304+(C<<2)>>2]|0;y=c[e+8448+(B<<2)>>2]|0;x=p<<1&6;D=x|1;E=(d[1401168+(r<<3)+x|0]|0)+z|0;F=(d[1401168+(r<<3)+D|0]|0)+A|0;a[n+p|0]=(((a[v+(u+z+(d[1401024+(r<<3)+x|0]|0))|0]|0)+(a[s+E|0]|0)&255)+(a[y+E|0]|0)&255)+((((a[v+(u+A+(d[1401024+(r<<3)+D|0]|0))|0]|0)+(a[s+F|0]|0)&255)+(a[y+F|0]|0)&255)<<4);p=p+1|0;}while((p|0)<(m|0));return}function yCb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c[g>>2]|0;n=c[h>>2]|0;if((l|0)<2048){l=k+1>>1;if((l|0)<=0){return}o=m&7;p=0;do{q=p<<1;r=(b[f+(q<<1)>>1]|0)+64>>7;s=q|1;t=(b[f+(s<<1)>>1]|0)+64>>7;u=((b[n+(p<<1)>>1]|0)+64>>7)+128|0;v=c[e+4352+(u<<2)>>2]|0;w=((b[i+(p<<1)>>1]|0)+64>>7)+128|0;x=c[e+6400+(w<<2)>>2]|0;y=c[e+2304+(u<<2)>>2]|0;u=c[e+8448+(w<<2)>>2]|0;w=q&6;z=w|1;A=d[1401168+(o<<3)+z|0]|0;B=d[1401024+(o<<3)+z|0]|0;z=(d[1401168+(o<<3)+w|0]|0)+r|0;a[j+q|0]=((a[x+(y+r+(d[1401024+(o<<3)+w|0]|0))|0]|0)+(a[v+z|0]|0)&255)+(a[u+z|0]|0);z=A+t|0;a[j+s|0]=((a[x+(y+t+B)|0]|0)+(a[v+z|0]|0)&255)+(a[u+z|0]|0);p=p+1|0;}while((p|0)<(l|0));return}else{l=c[g+4>>2]|0;g=c[h+4>>2]|0;h=k+1>>1;if((h|0)<=0){return}k=m&7;m=0;do{p=m<<1;o=(b[f+(p<<1)>>1]|0)+64>>7;z=p|1;u=(b[f+(z<<1)>>1]|0)+64>>7;v=((b[n+(m<<1)>>1]|0)+128+(b[g+(m<<1)>>1]|0)>>8)+128|0;B=c[e+4352+(v<<2)>>2]|0;t=((b[i+(m<<1)>>1]|0)+128+(b[l+(m<<1)>>1]|0)>>8)+128|0;y=c[e+6400+(t<<2)>>2]|0;x=c[e+2304+(v<<2)>>2]|0;v=c[e+8448+(t<<2)>>2]|0;t=p&6;s=t|1;A=d[1401168+(k<<3)+s|0]|0;w=d[1401024+(k<<3)+s|0]|0;s=(d[1401168+(k<<3)+t|0]|0)+o|0;a[j+p|0]=((a[y+(x+o+(d[1401024+(k<<3)+t|0]|0))|0]|0)+(a[B+s|0]|0)&255)+(a[v+s|0]|0);s=A+u|0;a[j+z|0]=((a[y+(x+u+w)|0]|0)+(a[B+s|0]|0)&255)+(a[v+s|0]|0);m=m+1|0;}while((m|0)<(h|0));return}}function zCb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;i=c[f>>2]|0;o=c[f+4>>2]|0;f=c[g>>2]|0;p=c[g+4>>2]|0;g=c[h>>2]|0;q=c[h+4>>2]|0;h=4096-l|0;r=4096-m|0;s=k+1>>1;if((s|0)<=0){return}k=n&7;n=0;do{t=n<<1;u=ca(b[i+(t<<1)>>1]|0,h)|0;v=(ca(b[o+(t<<1)>>1]|0,l)|0)+u>>19;u=t|1;w=ca(b[i+(u<<1)>>1]|0,h)|0;x=(ca(b[o+(u<<1)>>1]|0,l)|0)+w>>19;w=ca(b[f+(n<<1)>>1]|0,r)|0;y=(ca(b[p+(n<<1)>>1]|0,m)|0)+w>>19;w=ca(b[g+(n<<1)>>1]|0,r)|0;z=((ca(b[q+(n<<1)>>1]|0,m)|0)+w>>19)+128|0;w=c[e+4352+(z<<2)>>2]|0;A=y+128|0;y=c[e+6400+(A<<2)>>2]|0;B=c[e+2304+(z<<2)>>2]|0;z=c[e+8448+(A<<2)>>2]|0;A=t&6;C=A|1;D=d[1401168+(k<<3)+C|0]|0;E=d[1401024+(k<<3)+C|0]|0;C=(d[1401168+(k<<3)+A|0]|0)+v|0;a[j+t|0]=((a[y+(B+v+(d[1401024+(k<<3)+A|0]|0))|0]|0)+(a[w+C|0]|0)&255)+(a[z+C|0]|0);C=D+x|0;a[j+u|0]=((a[y+(B+x+E)|0]|0)+(a[w+C|0]|0)&255)+(a[z+C|0]|0);n=n+1|0;}while((n|0)<(s|0));return}function ACb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;m=o+1>>1;if((m|0)<=0){return}o=(h|0)>0;q=(l|0)>0;r=p&7;p=0;do{if(o){s=p<<1;t=s|1;u=262144;v=262144;w=0;do{x=c[g+(w<<2)>>2]|0;y=b[f+(w<<1)>>1]|0;u=(ca(y,b[x+(s<<1)>>1]|0)|0)+u|0;v=(ca(b[x+(t<<1)>>1]|0,y)|0)+v|0;w=w+1|0;}while((w|0)<(h|0));z=u>>19;A=v>>19}else{z=0;A=0}if(q){w=262144;t=262144;s=0;do{y=b[i+(s<<1)>>1]|0;w=(ca(y,b[(c[j+(s<<2)>>2]|0)+(p<<1)>>1]|0)|0)+w|0;t=(ca(b[(c[k+(s<<2)>>2]|0)+(p<<1)>>1]|0,y)|0)+t|0;s=s+1|0;}while((s|0)<(l|0));B=(w>>19)+128|0;C=(t>>19)+128|0}else{B=128;C=128}s=c[e+4352+(C<<2)>>2]|0;v=c[e+6400+(B<<2)>>2]|0;u=c[e+2304+(C<<2)>>2]|0;y=c[e+8448+(B<<2)>>2]|0;x=p<<1;D=x&6;E=D|1;F=d[1401168+(r<<3)+E|0]|0;G=d[1401024+(r<<3)+E|0]|0;E=(d[1401168+(r<<3)+D|0]|0)+z|0;a[n+x|0]=((a[v+(u+z+(d[1401024+(r<<3)+D|0]|0))|0]|0)+(a[s+E|0]|0)&255)+(a[y+E|0]|0);E=F+A|0;a[n+(x|1)|0]=((a[v+(u+A+G)|0]|0)+(a[s+E|0]|0)&255)+(a[y+E|0]|0);p=p+1|0;}while((p|0)<(m|0));return}function BCb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=m&7;m=1401168+(l<<3)|0;i=(k|0)>0;if((c[e+23972>>2]|0)!=3){if(!i){return}h=d[m]|0;m=d[1401169+(l<<3)|0]|0;g=d[1401170+(l<<3)|0]|0;n=d[1401171+(l<<3)|0]|0;o=d[1401172+(l<<3)|0]|0;p=d[1401173+(l<<3)|0]|0;q=d[1401174+(l<<3)|0]|0;r=d[1401175+(l<<3)|0]|0;l=0;s=j;while(1){a[s]=~((((((((((b[f+((l|1)<<1)>>1]|0)+64>>7)+m|0)>237|((((b[f+(l<<1)>>1]|0)+64>>7)+h|0)>237)<<1)<<1|(((b[f+((l|2)<<1)>>1]|0)+64>>7)+g|0)>237)<<1|(((b[f+((l|3)<<1)>>1]|0)+64>>7)+n|0)>237)<<1|(((b[f+((l|4)<<1)>>1]|0)+64>>7)+o|0)>237)<<1|(((b[f+((l|5)<<1)>>1]|0)+64>>7)+p|0)>237)<<1|(((b[f+((l|6)<<1)>>1]|0)+64>>7)+q|0)>237)<<1|(((b[f+((l|7)<<1)>>1]|0)+64>>7)+r|0)>237);t=l+8|0;if((t|0)<(k|0)){l=t;s=s+1|0}else{break}}return}s=e+11200|0;a:do{if(i){e=0;l=0;r=0;q=j;while(1){p=c[s>>2]|0;o=p+(r<<2)|0;n=r|1;g=p+(n<<2)|0;h=c[g>>2]|0;m=r+2|0;t=c[p+(m<<2)>>2]|0;u=((e*7|0)-248+(c[o>>2]|0)+(h*5|0)+(t*3|0)>>4)+((b[f+(r<<1)>>1]|0)+64>>7)|0;c[o>>2]=e;o=(u|0)>127|0;v=u-(-o&220)|0;u=(h-248+(t*5|0)+((c[p+(r+3<<2)>>2]|0)*3|0)+(v*7|0)>>4)+((b[f+(n<<1)>>1]|0)+64>>7)|0;c[g>>2]=v;v=(u|0)>127|0;g=v|(o|l)<<1;o=u-(-v&220)|0;if((r&6|0)==6){a[q]=g^255;w=q+1|0}else{w=q}if((m|0)>=(k|0)){x=o;y=m;break a}e=o;l=g<<1;r=m;q=w}}else{x=0;y=0}}while(0);c[(c[s>>2]|0)+(y<<2)>>2]=x;return}function CCb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=c[f>>2]|0;i=c[f+4>>2]|0;f=n&7;n=1401168+(f<<3)|0;h=4096-l|0;g=(k|0)>0;if((c[e+23972>>2]|0)!=3){if(!g){return}o=d[n]|0;n=d[1401169+(f<<3)|0]|0;p=d[1401170+(f<<3)|0]|0;q=d[1401171+(f<<3)|0]|0;r=d[1401172+(f<<3)|0]|0;s=d[1401173+(f<<3)|0]|0;t=d[1401174+(f<<3)|0]|0;u=d[1401175+(f<<3)|0]|0;f=0;v=j;while(1){w=ca(b[m+(f<<1)>>1]|0,h)|0;x=(((ca(b[i+(f<<1)>>1]|0,l)|0)+w>>19)+o|0)>237|0;w=f|1;y=ca(b[m+(w<<1)>>1]|0,h)|0;z=(((ca(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+n|0)>237|x<<1;x=f|2;y=ca(b[m+(x<<1)>>1]|0,h)|0;w=(((ca(b[i+(x<<1)>>1]|0,l)|0)+y>>19)+p|0)>237|z<<1;z=f|3;y=ca(b[m+(z<<1)>>1]|0,h)|0;x=(((ca(b[i+(z<<1)>>1]|0,l)|0)+y>>19)+q|0)>237|w<<1;w=f|4;y=ca(b[m+(w<<1)>>1]|0,h)|0;z=(((ca(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+r|0)>237|x<<1;x=f|5;y=ca(b[m+(x<<1)>>1]|0,h)|0;w=(((ca(b[i+(x<<1)>>1]|0,l)|0)+y>>19)+s|0)>237|z<<1;z=f|6;y=ca(b[m+(z<<1)>>1]|0,h)|0;x=(((ca(b[i+(z<<1)>>1]|0,l)|0)+y>>19)+t|0)>237|w<<1;w=f|7;y=ca(b[m+(w<<1)>>1]|0,h)|0;a[v]=~((((ca(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+u|0)>237|x<<1);x=f+8|0;if((x|0)<(k|0)){f=x;v=v+1|0}else{break}}return}v=e+11200|0;a:do{if(g){e=0;f=0;u=0;t=j;while(1){s=ca(b[m+(u<<1)>>1]|0,h)|0;r=(ca(b[i+(u<<1)>>1]|0,l)|0)+s>>19;s=c[v>>2]|0;q=s+(u<<2)|0;p=u|1;n=s+(p<<2)|0;o=c[n>>2]|0;x=u+2|0;y=c[s+(x<<2)>>2]|0;w=((f*7|0)-248+(c[q>>2]|0)+(o*5|0)+(y*3|0)>>4)+r|0;c[q>>2]=f;q=(w|0)>127|0;r=w-(-q&220)|0;w=ca(b[m+(p<<1)>>1]|0,h)|0;z=(ca(b[i+(p<<1)>>1]|0,l)|0)+w>>19;w=(o-248+(y*5|0)+((c[s+(u+3<<2)>>2]|0)*3|0)+(r*7|0)>>4)+z|0;c[n>>2]=r;r=(w|0)>127|0;n=r|(q|e)<<1;q=w-(-r&220)|0;if((u&6|0)==6){a[t]=n^255;A=t+1|0}else{A=t}if((x|0)>=(k|0)){B=q;C=x;break a}e=n<<1;f=q;u=x;t=A}}else{B=0;C=0}}while(0);c[(c[v>>2]|0)+(C<<2)>>2]=B;return}function DCb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;m=p&7;if((o|0)<=0){c[c[e+11200>>2]>>2]=0;return}p=(h|0)>0;l=e+23972|0;k=e+11200|0;e=n;n=0;j=0;i=0;while(1){if(p){q=n|1;r=0;s=262144;t=262144;do{u=c[g+(r<<2)>>2]|0;v=b[f+(r<<1)>>1]|0;s=(ca(v,b[u+(n<<1)>>1]|0)|0)+s|0;t=(ca(b[u+(q<<1)>>1]|0,v)|0)+t|0;r=r+1|0;}while((r|0)<(h|0));w=s>>19;x=t>>19}else{w=0;x=0}if(((w|x)&256|0)==0){y=x;z=w}else{if(w>>>0>255>>>0){A=-w>>31&255}else{A=w&255}if(x>>>0>255>>>0){B=-x>>31&255}else{B=x&255}y=B&255;z=A&255}if((c[l>>2]|0)==3){r=c[k>>2]|0;q=r+(n<<2)|0;v=r+((n|1)<<2)|0;u=c[v>>2]|0;C=c[r+(n+2<<2)>>2]|0;D=((i*7|0)-248+(c[q>>2]|0)+(u*5|0)+(C*3|0)>>4)+z|0;c[q>>2]=i;q=(D|0)>127|0;E=D-(-q&220)|0;D=(u-248+(C*5|0)+((c[r+(n+3<<2)>>2]|0)*3|0)+(E*7|0)>>4)+y|0;c[v>>2]=E;E=(D|0)>127|0;F=D-(-E&220)|0;G=E|(q|j<<1)<<1;H=n&6}else{q=n&6;F=i;G=(((d[1401168+(m<<3)+q|0]|0)+z|0)>237|j<<1)<<1|((d[(q|1)+(1401168+(m<<3))|0]|0)+y|0)>237;H=q}if((H|0)==6){a[e]=G^255;I=e+1|0}else{I=e}J=n+2|0;if((J|0)<(o|0)){e=I;n=J;j=G;i=F}else{break}}c[(c[k>>2]|0)+(J<<2)>>2]=F;if((J&6|0)==0){return}a[I]=G^255;return}function ECb(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=m&7;m=1401168+(l<<3)|0;i=(k|0)>0;if((c[e+23972>>2]|0)!=3){if(!i){return}h=d[m]|0;m=d[1401169+(l<<3)|0]|0;g=d[1401170+(l<<3)|0]|0;n=d[1401171+(l<<3)|0]|0;o=d[1401172+(l<<3)|0]|0;p=d[1401173+(l<<3)|0]|0;q=d[1401174+(l<<3)|0]|0;r=d[1401175+(l<<3)|0]|0;l=0;s=j;while(1){a[s]=(((((((((b[f+((l|1)<<1)>>1]|0)+64>>7)+m|0)>237|((((b[f+(l<<1)>>1]|0)+64>>7)+h|0)>237)<<1)<<1|(((b[f+((l|2)<<1)>>1]|0)+64>>7)+g|0)>237)<<1|(((b[f+((l|3)<<1)>>1]|0)+64>>7)+n|0)>237)<<1|(((b[f+((l|4)<<1)>>1]|0)+64>>7)+o|0)>237)<<1|(((b[f+((l|5)<<1)>>1]|0)+64>>7)+p|0)>237)<<1|(((b[f+((l|6)<<1)>>1]|0)+64>>7)+q|0)>237)<<1|(((b[f+((l|7)<<1)>>1]|0)+64>>7)+r|0)>237;t=l+8|0;if((t|0)<(k|0)){l=t;s=s+1|0}else{break}}return}s=e+11200|0;a:do{if(i){e=0;l=0;r=0;q=j;while(1){p=c[s>>2]|0;o=p+(r<<2)|0;n=r|1;g=p+(n<<2)|0;h=c[g>>2]|0;m=r+2|0;t=c[p+(m<<2)>>2]|0;u=((e*7|0)-248+(c[o>>2]|0)+(h*5|0)+(t*3|0)>>4)+((b[f+(r<<1)>>1]|0)+64>>7)|0;c[o>>2]=e;o=(u|0)>127|0;v=u-(-o&220)|0;u=(h-248+(t*5|0)+((c[p+(r+3<<2)>>2]|0)*3|0)+(v*7|0)>>4)+((b[f+(n<<1)>>1]|0)+64>>7)|0;c[g>>2]=v;v=(u|0)>127|0;g=v|(o|l)<<1;o=u-(-v&220)|0;if((r&6|0)==6){a[q]=g;w=q+1|0}else{w=q}if((m|0)>=(k|0)){x=o;y=m;break a}e=o;l=g<<1;r=m;q=w}}else{x=0;y=0}}while(0);c[(c[s>>2]|0)+(y<<2)>>2]=x;return}function FCb(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=c[f>>2]|0;i=c[f+4>>2]|0;f=n&7;n=1401168+(f<<3)|0;h=4096-l|0;g=(k|0)>0;if((c[e+23972>>2]|0)!=3){if(!g){return}o=d[n]|0;n=d[1401169+(f<<3)|0]|0;p=d[1401170+(f<<3)|0]|0;q=d[1401171+(f<<3)|0]|0;r=d[1401172+(f<<3)|0]|0;s=d[1401173+(f<<3)|0]|0;t=d[1401174+(f<<3)|0]|0;u=d[1401175+(f<<3)|0]|0;f=0;v=j;while(1){w=ca(b[m+(f<<1)>>1]|0,h)|0;x=(((ca(b[i+(f<<1)>>1]|0,l)|0)+w>>19)+o|0)>237|0;w=f|1;y=ca(b[m+(w<<1)>>1]|0,h)|0;z=(((ca(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+n|0)>237|x<<1;x=f|2;y=ca(b[m+(x<<1)>>1]|0,h)|0;w=(((ca(b[i+(x<<1)>>1]|0,l)|0)+y>>19)+p|0)>237|z<<1;z=f|3;y=ca(b[m+(z<<1)>>1]|0,h)|0;x=(((ca(b[i+(z<<1)>>1]|0,l)|0)+y>>19)+q|0)>237|w<<1;w=f|4;y=ca(b[m+(w<<1)>>1]|0,h)|0;z=(((ca(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+r|0)>237|x<<1;x=f|5;y=ca(b[m+(x<<1)>>1]|0,h)|0;w=(((ca(b[i+(x<<1)>>1]|0,l)|0)+y>>19)+s|0)>237|z<<1;z=f|6;y=ca(b[m+(z<<1)>>1]|0,h)|0;x=(((ca(b[i+(z<<1)>>1]|0,l)|0)+y>>19)+t|0)>237|w<<1;w=f|7;y=ca(b[m+(w<<1)>>1]|0,h)|0;a[v]=(((ca(b[i+(w<<1)>>1]|0,l)|0)+y>>19)+u|0)>237|x<<1;x=f+8|0;if((x|0)<(k|0)){f=x;v=v+1|0}else{break}}return}v=e+11200|0;a:do{if(g){e=0;f=0;u=0;t=j;while(1){s=ca(b[m+(u<<1)>>1]|0,h)|0;r=(ca(b[i+(u<<1)>>1]|0,l)|0)+s>>19;s=c[v>>2]|0;q=s+(u<<2)|0;p=u|1;n=s+(p<<2)|0;o=c[n>>2]|0;x=u+2|0;y=c[s+(x<<2)>>2]|0;w=((f*7|0)-248+(c[q>>2]|0)+(o*5|0)+(y*3|0)>>4)+r|0;c[q>>2]=f;q=(w|0)>127|0;r=w-(-q&220)|0;w=ca(b[m+(p<<1)>>1]|0,h)|0;z=(ca(b[i+(p<<1)>>1]|0,l)|0)+w>>19;w=(o-248+(y*5|0)+((c[s+(u+3<<2)>>2]|0)*3|0)+(r*7|0)>>4)+z|0;c[n>>2]=r;r=(w|0)>127|0;n=r|(q|e)<<1;q=w-(-r&220)|0;if((u&6|0)==6){a[t]=n;A=t+1|0}else{A=t}if((x|0)>=(k|0)){B=q;C=x;break a}e=n<<1;f=q;u=x;t=A}}else{B=0;C=0}}while(0);c[(c[v>>2]|0)+(C<<2)>>2]=B;return}function GCb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;m=p&7;if((o|0)<=0){c[c[e+11200>>2]>>2]=0;return}p=(h|0)>0;l=e+23972|0;k=e+11200|0;e=n;n=0;j=0;i=0;while(1){if(p){q=n|1;r=0;s=262144;t=262144;do{u=c[g+(r<<2)>>2]|0;v=b[f+(r<<1)>>1]|0;s=(ca(v,b[u+(n<<1)>>1]|0)|0)+s|0;t=(ca(b[u+(q<<1)>>1]|0,v)|0)+t|0;r=r+1|0;}while((r|0)<(h|0));w=s>>19;x=t>>19}else{w=0;x=0}if(((w|x)&256|0)==0){y=x;z=w}else{if(w>>>0>255>>>0){A=-w>>31&255}else{A=w&255}if(x>>>0>255>>>0){B=-x>>31&255}else{B=x&255}y=B&255;z=A&255}if((c[l>>2]|0)==3){r=c[k>>2]|0;q=r+(n<<2)|0;v=r+((n|1)<<2)|0;u=c[v>>2]|0;C=c[r+(n+2<<2)>>2]|0;D=((i*7|0)-248+(c[q>>2]|0)+(u*5|0)+(C*3|0)>>4)+z|0;c[q>>2]=i;q=(D|0)>127|0;E=D-(-q&220)|0;D=(u-248+(C*5|0)+((c[r+(n+3<<2)>>2]|0)*3|0)+(E*7|0)>>4)+y|0;c[v>>2]=E;E=(D|0)>127|0;F=D-(-E&220)|0;G=E|(q|j<<1)<<1;H=n&6}else{q=n&6;F=i;G=(((d[1401168+(m<<3)+q|0]|0)+z|0)>237|j<<1)<<1|((d[(q|1)+(1401168+(m<<3))|0]|0)+y|0)>237;H=q}if((H|0)==6){a[e]=G;I=e+1|0}else{I=e}J=n+2|0;if((J|0)<(o|0)){e=I;n=J;j=G;i=F}else{break}}c[(c[k>>2]|0)+(J<<2)>>2]=F;if((J&6|0)==0){return}a[I]=G;return}function HCb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)>0){m=0}else{return}do{d=m<<1;n=(b[e+(d<<1)>>1]|0)+64>>7;o=(b[e+((d|1)<<1)>>1]|0)+64>>7;d=(b[l+(m<<1)>>1]|0)+64>>7;p=(b[h+(m<<1)>>1]|0)+64>>7;q=n>>>0>255>>>0;r=n&255;do{if(((o|n|d|p)&256|0)==0){if(q){s=-n>>31&255}else{s=r}if(o>>>0>255>>>0){t=-o>>31&255}else{t=o&255}if(d>>>0>255>>>0){u=-d>>31&255}else{u=d&255}if(!(p>>>0>255>>>0)){v=p&255;w=t;x=s;y=u;break}v=-p>>31&255;w=t;x=s;y=u}else{if(q){z=-n>>31&255}else{z=r}if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}if(d>>>0>255>>>0){B=-d>>31&255}else{B=d&255}if(!(p>>>0>255>>>0)){v=p&255;w=A;x=z;y=B;break}v=-p>>31&255;w=A;x=z;y=B}}while(0);p=m<<2;a[i+p|0]=x;a[i+(p|1)|0]=y;a[i+(p|2)|0]=w;a[i+(p|3)|0]=v;m=m+1|0;}while((m|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)>0){C=0}else{return}do{j=C<<1;m=(b[e+(j<<1)>>1]|0)+64>>7;v=(b[e+((j|1)<<1)>>1]|0)+64>>7;j=(b[l+(C<<1)>>1]|0)+128+(b[k+(C<<1)>>1]|0)>>8;w=(b[h+(C<<1)>>1]|0)+128+(b[f+(C<<1)>>1]|0)>>8;y=m>>>0>255>>>0;x=m&255;do{if(((v|m|j|w)&256|0)==0){if(y){D=-m>>31&255}else{D=x}if(v>>>0>255>>>0){E=-v>>31&255}else{E=v&255}if(j>>>0>255>>>0){F=-j>>31&255}else{F=j&255}if(!(w>>>0>255>>>0)){G=w&255;H=E;I=D;J=F;break}G=-w>>31&255;H=E;I=D;J=F}else{if(y){K=-m>>31&255}else{K=x}if(v>>>0>255>>>0){L=-v>>31&255}else{L=v&255}if(j>>>0>255>>>0){M=-j>>31&255}else{M=j&255}if(!(w>>>0>255>>>0)){G=w&255;H=L;I=K;J=M;break}G=-w>>31&255;H=L;I=K;J=M}}while(0);w=C<<2;a[i+w|0]=I;a[i+(w|1)|0]=J;a[i+(w|2)|0]=H;a[i+(w|3)|0]=G;C=C+1|0;}while((C|0)<(g|0));return}}function ICb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;d=c[f+4>>2]|0;f=c[g>>2]|0;n=c[g+4>>2]|0;g=4096-k|0;o=4096-l|0;p=j+1>>1;if((p|0)>0){q=0}else{return}do{j=q<<1;r=ca(b[m+(j<<1)>>1]|0,g)|0;s=(ca(b[h+(j<<1)>>1]|0,k)|0)+r>>19;r=j|1;j=ca(b[m+(r<<1)>>1]|0,g)|0;t=(ca(b[h+(r<<1)>>1]|0,k)|0)+j>>19;j=ca(b[e+(q<<1)>>1]|0,o)|0;r=(ca(b[d+(q<<1)>>1]|0,l)|0)+j>>19;j=ca(b[f+(q<<1)>>1]|0,o)|0;u=(ca(b[n+(q<<1)>>1]|0,l)|0)+j>>19;j=s&255;v=t&255;w=r&255;x=u&255;do{if(((t|s|r|u)&256|0)==0){y=x;z=w;A=v;B=j}else{if(s>>>0>255>>>0){C=-s>>31&255}else{C=j}if(t>>>0>255>>>0){D=-t>>31&255}else{D=v}if(r>>>0>255>>>0){E=-r>>31&255}else{E=w}if(!(u>>>0>255>>>0)){y=x;z=E;A=D;B=C;break}y=-u>>31&255;z=E;A=D;B=C}}while(0);u=q<<2;a[i+u|0]=B;a[i+(u|1)|0]=z;a[i+(u|2)|0]=A;a[i+(u|3)|0]=y;q=q+1|0;}while((q|0)<(p|0));return}function JCb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;o=n+1>>1;if((o|0)<=0){return}n=(g|0)>0;l=(k|0)>0;d=0;do{if(n){p=d<<1;q=p|1;r=0;s=262144;t=262144;do{u=c[f+(r<<2)>>2]|0;v=b[e+(r<<1)>>1]|0;s=(ca(v,b[u+(p<<1)>>1]|0)|0)+s|0;t=(ca(b[u+(q<<1)>>1]|0,v)|0)+t|0;r=r+1|0;}while((r|0)<(g|0));w=s>>19;x=t>>19}else{w=0;x=0}if(l){r=0;q=262144;p=262144;do{v=b[h+(r<<1)>>1]|0;q=(ca(v,b[(c[i+(r<<2)>>2]|0)+(d<<1)>>1]|0)|0)+q|0;p=(ca(b[(c[j+(r<<2)>>2]|0)+(d<<1)>>1]|0,v)|0)+p|0;r=r+1|0;}while((r|0)<(k|0));y=q>>19;z=p>>19}else{y=0;z=0}r=w&255;t=x&255;s=y&255;v=z&255;do{if(((w|x|z|y)&256|0)==0){A=v;B=s;C=t;D=r}else{if(w>>>0>255>>>0){E=-w>>31&255}else{E=r}if(x>>>0>255>>>0){F=-x>>31&255}else{F=t}if(y>>>0>255>>>0){G=-y>>31&255}else{G=s}if(!(z>>>0>255>>>0)){A=v;B=G;C=F;D=E;break}A=-z>>31&255;B=G;C=F;D=E}}while(0);v=d<<2;a[m+v|0]=D;a[m+(v|1)|0]=B;a[m+(v|2)|0]=C;a[m+(v|3)|0]=A;d=d+1|0;}while((d|0)<(o|0));return}function KCb(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;l=c[f>>2]|0;h=c[g>>2]|0;if((k|0)<2048){k=j+1>>1;if((k|0)>0){m=0}else{return}do{d=m<<1;n=(b[e+(d<<1)>>1]|0)+64>>7;o=(b[e+((d|1)<<1)>>1]|0)+64>>7;d=(b[l+(m<<1)>>1]|0)+64>>7;p=(b[h+(m<<1)>>1]|0)+64>>7;q=n>>>0>255>>>0;r=n&255;do{if(((o|n|d|p)&256|0)==0){if(q){s=-n>>31&255}else{s=r}if(o>>>0>255>>>0){t=-o>>31&255}else{t=o&255}if(d>>>0>255>>>0){u=-d>>31&255}else{u=d&255}if(!(p>>>0>255>>>0)){v=p&255;w=t;x=s;y=u;break}v=-p>>31&255;w=t;x=s;y=u}else{if(q){z=-n>>31&255}else{z=r}if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}if(d>>>0>255>>>0){B=-d>>31&255}else{B=d&255}if(!(p>>>0>255>>>0)){v=p&255;w=A;x=z;y=B;break}v=-p>>31&255;w=A;x=z;y=B}}while(0);p=m<<2;a[i+p|0]=y;a[i+(p|1)|0]=x;a[i+(p|2)|0]=v;a[i+(p|3)|0]=w;m=m+1|0;}while((m|0)<(k|0));return}else{k=c[f+4>>2]|0;f=c[g+4>>2]|0;g=j+1>>1;if((g|0)>0){C=0}else{return}do{j=C<<1;m=(b[e+(j<<1)>>1]|0)+64>>7;w=(b[e+((j|1)<<1)>>1]|0)+64>>7;j=(b[l+(C<<1)>>1]|0)+128+(b[k+(C<<1)>>1]|0)>>8;v=(b[h+(C<<1)>>1]|0)+128+(b[f+(C<<1)>>1]|0)>>8;x=m>>>0>255>>>0;y=m&255;do{if(((w|m|j|v)&256|0)==0){if(x){D=-m>>31&255}else{D=y}if(w>>>0>255>>>0){E=-w>>31&255}else{E=w&255}if(j>>>0>255>>>0){F=-j>>31&255}else{F=j&255}if(!(v>>>0>255>>>0)){G=v&255;H=E;I=D;J=F;break}G=-v>>31&255;H=E;I=D;J=F}else{if(x){K=-m>>31&255}else{K=y}if(w>>>0>255>>>0){L=-w>>31&255}else{L=w&255}if(j>>>0>255>>>0){M=-j>>31&255}else{M=j&255}if(!(v>>>0>255>>>0)){G=v&255;H=L;I=K;J=M;break}G=-v>>31&255;H=L;I=K;J=M}}while(0);v=C<<2;a[i+v|0]=J;a[i+(v|1)|0]=I;a[i+(v|2)|0]=G;a[i+(v|3)|0]=H;C=C+1|0;}while((C|0)<(g|0));return}}function LCb(d,e,f,g,h,i,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;m=c[e>>2]|0;h=c[e+4>>2]|0;e=c[f>>2]|0;d=c[f+4>>2]|0;f=c[g>>2]|0;n=c[g+4>>2]|0;g=4096-k|0;o=4096-l|0;p=j+1>>1;if((p|0)>0){q=0}else{return}do{j=q<<1;r=ca(b[m+(j<<1)>>1]|0,g)|0;s=(ca(b[h+(j<<1)>>1]|0,k)|0)+r>>19;r=j|1;j=ca(b[m+(r<<1)>>1]|0,g)|0;t=(ca(b[h+(r<<1)>>1]|0,k)|0)+j>>19;j=ca(b[e+(q<<1)>>1]|0,o)|0;r=(ca(b[d+(q<<1)>>1]|0,l)|0)+j>>19;j=ca(b[f+(q<<1)>>1]|0,o)|0;u=(ca(b[n+(q<<1)>>1]|0,l)|0)+j>>19;j=s&255;v=t&255;w=r&255;x=u&255;do{if(((t|s|r|u)&256|0)==0){y=x;z=w;A=v;B=j}else{if(s>>>0>255>>>0){C=-s>>31&255}else{C=j}if(t>>>0>255>>>0){D=-t>>31&255}else{D=v}if(r>>>0>255>>>0){E=-r>>31&255}else{E=w}if(!(u>>>0>255>>>0)){y=x;z=E;A=D;B=C;break}y=-u>>31&255;z=E;A=D;B=C}}while(0);u=q<<2;a[i+u|0]=z;a[i+(u|1)|0]=B;a[i+(u|2)|0]=y;a[i+(u|3)|0]=A;q=q+1|0;}while((q|0)<(p|0));return}function MCb(d,e,f,g,h,i,j,k,l,m,n,o){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;o=n+1>>1;if((o|0)<=0){return}n=(g|0)>0;l=(k|0)>0;d=0;do{if(n){p=d<<1;q=p|1;r=0;s=262144;t=262144;do{u=c[f+(r<<2)>>2]|0;v=b[e+(r<<1)>>1]|0;s=(ca(v,b[u+(p<<1)>>1]|0)|0)+s|0;t=(ca(b[u+(q<<1)>>1]|0,v)|0)+t|0;r=r+1|0;}while((r|0)<(g|0));w=s>>19;x=t>>19}else{w=0;x=0}if(l){r=0;q=262144;p=262144;do{v=b[h+(r<<1)>>1]|0;q=(ca(v,b[(c[i+(r<<2)>>2]|0)+(d<<1)>>1]|0)|0)+q|0;p=(ca(b[(c[j+(r<<2)>>2]|0)+(d<<1)>>1]|0,v)|0)+p|0;r=r+1|0;}while((r|0)<(k|0));y=q>>19;z=p>>19}else{y=0;z=0}r=w&255;t=x&255;s=y&255;v=z&255;do{if(((w|x|z|y)&256|0)==0){A=v;B=s;C=t;D=r}else{if(w>>>0>255>>>0){E=-w>>31&255}else{E=r}if(x>>>0>255>>>0){F=-x>>31&255}else{F=t}if(y>>>0>255>>>0){G=-y>>31&255}else{G=s}if(!(z>>>0>255>>>0)){A=v;B=G;C=F;D=E;break}A=-z>>31&255;B=G;C=F;D=E}}while(0);v=d<<2;a[m+v|0]=B;a[m+(v|1)|0]=D;a[m+(v|2)|0]=A;a[m+(v|3)|0]=C;d=d+1|0;}while((d|0)<(o|0));return}function NCb(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;n=c[m>>2]|0;o=c[m+4>>2]|0;p=c[m+8>>2]|0;q=c[m+12>>2]|0;r=c[m+16>>2]|0;s=c[m+20>>2]|0;t=c[m+24>>2]|0;u=c[m+28>>2]|0;v=c[m+32>>2]|0;m=h>>1;if((i|0)<=0){return}h=j<<1;w=l<<1;x=l+2|0;y=l+3|0;z=l+4|0;A=l+5|0;if((m|0)>0){B=0;C=g;D=f;E=e;F=b}else{b=0;while(1){if((b|1|0)==(i|0)){G=10;break}e=b+2|0;if((e|0)<(i|0)){b=e}else{G=10;break}}if((G|0)==10){return}}while(1){b=0;do{e=b*6|0;f=d[F+e|0]|0;g=d[F+(e|1)|0]|0;H=d[F+(e+2)|0]|0;I=(((ca(g,o)|0)+(ca(f,p)|0)+(ca(H,n)|0)|0)>>>15)+16|0;J=(((ca(g,u)|0)+(ca(f,v)|0)+(ca(H,t)|0)|0)>>>15)+128|0;a[D+b|0]=(((ca(g,r)|0)+(ca(f,s)|0)+(ca(H,q)|0)|0)>>>15)+128;a[C+b|0]=J;J=b<<1;a[E+J|0]=I;a[E+(J|1)|0]=(((ca(d[F+(e+4)|0]|0,o)|0)+(ca(d[F+(e+3)|0]|0,p)|0)+(ca(d[F+(e+5)|0]|0,n)|0)|0)>>>15)+16;b=b+1|0;}while((b|0)<(m|0));if((B|1|0)==(i|0)){G=10;break}else{K=0}do{b=K*6|0;e=K<<1;a[E+(e+j)|0]=(((ca(d[F+((b|1)+l)|0]|0,o)|0)+(ca(d[F+(b+l)|0]|0,p)|0)+(ca(d[F+(x+b)|0]|0,n)|0)|0)>>>15)+16;a[E+((e|1)+j)|0]=(((ca(d[F+(z+b)|0]|0,o)|0)+(ca(d[F+(y+b)|0]|0,p)|0)+(ca(d[F+(A+b)|0]|0,n)|0)|0)>>>15)+16;K=K+1|0;}while((K|0)<(m|0));b=B+2|0;if((b|0)<(i|0)){B=b;C=C+k|0;D=D+k|0;E=E+h|0;F=F+w|0}else{G=10;break}}if((G|0)==10){return}}function OCb(){c[1352520]=504;c[1352516]=138;c[1352518]=1576;c[1352510]=1716;c[1352512]=2268;c[1352514]=1436;c[1352502]=1126;c[1352504]=476;c[1352498]=1872;c[1352494]=1616;c[1352496]=1278;c[1352488]=722;c[1352508]=634;c[1352506]=1452;c[1352500]=1790;c[1280128]=298;c[1352490]=1084;c[1352492]=2306;c[664898]=80;c[664900]=120;c[664908]=128;c[664910]=160;c[664906]=164;c[1365628]=2;c[1637278]=22;c[1474814]=52;c[2336126]=18;c[836150]=14;c[664896]=50;c[847034]=74;c[847032]=10;c[664904]=98;c[664902]=136;return}function PCb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=d>>2;if((e|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;a[c+g|0]=a[b+(d|2)|0]|0;a[c+(g+1)|0]=a[b+(d|1)|0]|0;a[c+(g+2)|0]=a[b+d|0]|0;f=f+1|0;}while((f|0)<(e|0));return}function QCb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;if((d|0)>0){e=0;f=0}else{return}do{g=e<<2;a[c+g|0]=a[b+(f+2)|0]|0;a[c+(g|1)|0]=a[b+(f+1)|0]|0;a[c+(g|2)|0]=a[b+f|0]|0;a[c+(g|3)|0]=-1;e=e+1|0;f=e*3|0;}while((f|0)<(d|0));return}function RCb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>8&248|f>>>13;d=f&2016;a[h+1|0]=d>>>3|d>>>9;a[h+2|0]=f>>>2&7|f<<3;a[h+3|0]=-1;if(c>>>0<b>>>0){g=c;h=h+4|0}else{break}}return}function SCb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=a;a=e+(((d|0)/2|0)<<1)|0;if(!(e>>>0<a>>>0)){return}d=e;e=c;while(1){c=d+2|0;f=b[d>>1]|0;g=f&15;b[e>>1]=f<<3&30720|(f&65535)>>>1&1024|(f&65535)>>>2&32|f<<2&960|(g&65535)>>>3|g<<1;if(c>>>0<a>>>0){d=c;e=e+2|0}else{break}}return}function TCb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>8&248|f>>>13;d=f&2016;a[h+1|0]=d>>>3|d>>>9;a[h+2|0]=f>>>2&7|f<<3;if(c>>>0<b>>>0){g=c;h=h+3|0}else{break}}return}function UCb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=d>>1;if((e|0)<=0){return}d=a;a=c;c=0;do{f=b[d+(c<<1)>>1]|0;b[a+(c<<1)>>1]=(f&65535)>>>11|f&2016|f<<11;c=c+1|0;}while((c|0)<(e|0));return}function VCb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=d>>1;if((e|0)<=0){return}d=a;a=c;c=0;do{f=b[d+(c<<1)>>1]|0;b[a+(c<<1)>>1]=(f&65535)>>>1&992|(f&65535)>>>11|f<<10&31744;c=c+1|0;}while((c|0)<(e|0));return}function WCb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;d=f&31744;a[h]=d>>>7|d>>>12;d=f&992;a[h+1|0]=d>>>2|d>>>7;a[h+2|0]=f>>>2&7|f<<3;a[h+3|0]=-1;if(c>>>0<b>>>0){g=c;h=h+4|0}else{break}}return}function XCb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;d=f&31744;a[h]=d>>>7|d>>>12;d=f&992;a[h+1|0]=d>>>2|d>>>7;a[h+2|0]=f>>>2&7|f<<3;if(c>>>0<b>>>0){g=c;h=h+3|0}else{break}}return}function YCb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=d>>1;if((e|0)<=0){return}d=a;a=c;c=0;do{f=b[d+(c<<1)>>1]|0;b[a+(c<<1)>>1]=f<<1&1984|f<<11|(f&65535)>>>10&31;c=c+1|0;}while((c|0)<(e|0));return}function ZCb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=d>>1;if((f|0)<=0){return}d=a;a=c;c=0;do{g=e[d+(c<<1)>>1]|0;h=g&31775;b[a+(c<<1)>>1]=h>>>10|g&992|h<<10;c=c+1|0;}while((c|0)<(f|0));return}function _Cb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=c;c=a;a=d>>1;if((a|0)>0){f=0}else{return}do{d=b[c+(f<<1)>>1]|0;b[e+(f<<1)>>1]=(d&65535)>>>8|d&240|d<<8&3840;f=f+1|0;}while((f|0)<(a|0));return}function $Cb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)>0){e=0}else{return}do{a[c+e|0]=a[b+e|0]|0;f=e|3;g=e|1;a[c+g|0]=a[b+f|0]|0;h=e|2;a[c+h|0]=a[b+h|0]|0;a[c+f|0]=a[b+g|0]|0;e=e+4|0;}while((e|0)<(d|0));return}function aDb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;if((d|0)>0){e=0}else{return}do{f=e|1;a[c+e|0]=a[b+f|0]|0;g=e|2;a[c+f|0]=a[b+g|0]|0;f=e|3;a[c+g|0]=a[b+f|0]|0;a[c+f|0]=a[b+e|0]|0;e=e+4|0;}while((e|0)<(d|0));return}function bDb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)>0){e=0}else{return}do{f=e|3;a[c+e|0]=a[b+f|0]|0;g=e|1;a[c+g|0]=a[b+e|0]|0;h=e|2;a[c+h|0]=a[b+g|0]|0;a[c+f|0]=a[b+h|0]|0;e=e+4|0;}while((e|0)<(d|0));return}function cDb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)>0){e=0}else{return}do{f=e|3;a[c+e|0]=a[b+f|0]|0;g=e|2;h=e|1;a[c+h|0]=a[b+g|0]|0;a[c+g|0]=a[b+h|0]|0;a[c+f|0]=a[b+e|0]|0;e=e+4|0;}while((e|0)<(d|0));return}function dDb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>1;if((a|0)>0){f=0}else{return}do{d=f+2|0;b[e+(f<<1)>>1]=b[c+(d<<1)>>1]|0;g=f+1|0;b[e+(g<<1)>>1]=b[c+(g<<1)>>1]|0;b[e+(d<<1)>>1]=b[c+(f<<1)>>1]|0;f=f+3|0;}while((f|0)<(a|0));return}function eDb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>1;if((a|0)>0){f=0}else{return}do{d=f+2|0;b[e+(f<<1)>>1]=he(b[c+(d<<1)>>1]|0)|0;g=f+1|0;b[e+(g<<1)>>1]=he(b[c+(g<<1)>>1]|0)|0;b[e+(d<<1)>>1]=he(b[c+(f<<1)>>1]|0)|0;f=f+3|0;}while((f|0)<(a|0));return}function fDb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>3;if((a|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;b[e+(g<<1)>>1]=b[c+((d|2)<<1)>>1]|0;b[e+(g+1<<1)>>1]=b[c+((d|1)<<1)>>1]|0;b[e+(g+2<<1)>>1]=b[c+(d<<1)>>1]|0;f=f+1|0;}while((f|0)<(a|0));return}function gDb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>3;if((a|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;b[e+(g<<1)>>1]=he(b[c+((d|2)<<1)>>1]|0)|0;b[e+(g+1<<1)>>1]=he(b[c+((d|1)<<1)>>1]|0)|0;b[e+(g+2<<1)>>1]=he(b[c+(d<<1)>>1]|0)|0;f=f+1|0;}while((f|0)<(a|0));return}function hDb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>3;if((a|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;b[e+(g<<1)>>1]=b[c+(d<<1)>>1]|0;b[e+(g+1<<1)>>1]=b[c+((d|1)<<1)>>1]|0;b[e+(g+2<<1)>>1]=b[c+((d|2)<<1)>>1]|0;f=f+1|0;}while((f|0)<(a|0));return}function iDb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=a;a=d>>3;if((a|0)>0){f=0}else{return}do{d=f<<2;g=f*3|0;b[e+(g<<1)>>1]=he(b[c+(d<<1)>>1]|0)|0;b[e+(g+1<<1)>>1]=he(b[c+((d|1)<<1)>>1]|0)|0;b[e+(g+2<<1)>>1]=he(b[c+((d|2)<<1)>>1]|0)|0;f=f+1|0;}while((f|0)<(a|0));return}function jDb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+e|0;g=e-3|0;e=a+g|0;if((g|0)>0){g=a;h=d;while(1){i=c[g>>2]|0;c[h>>2]=(i&2147450879)+(i&2145419232);i=h+4|0;j=g+4|0;if(j>>>0<e>>>0){g=j;h=i}else{k=j;l=i;break}}}else{k=a;l=d}if(!(k>>>0<f>>>0)){return}f=b[k>>1]|0;b[l>>1]=(f&32767)+(f&32736);return}function kDb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>2&7|f<<3;d=f&992;a[h+1|0]=d>>>2|d>>>7;d=f&31744;a[h+2|0]=d>>>7|d>>>12;if(c>>>0<b>>>0){g=c;h=h+3|0}else{break}}return}function lDb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>2&7|f<<3;d=f&992;a[h+1|0]=d>>>2|d>>>7;d=f&31744;a[h+2|0]=d>>>7|d>>>12;a[h+3|0]=-1;if(c>>>0<b>>>0){g=c;h=h+4|0}else{break}}return}function mDb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>2&7|f<<3;d=f&2016;a[h+1|0]=d>>>3|d>>>9;a[h+2|0]=f>>>8&248|f>>>13;if(c>>>0<b>>>0){g=c;h=h+3|0}else{break}}return}function nDb(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=b;b=f+(((d|0)/2|0)<<1)|0;if(f>>>0<b>>>0){g=f;h=c}else{return}while(1){c=g+2|0;f=e[g>>1]|0;a[h]=f>>>2&7|f<<3;d=f&2016;a[h+1|0]=d>>>3|d>>>9;a[h+2|0]=f>>>8&248|f>>>13;a[h+3|0]=-1;if(c>>>0<b>>>0){g=c;h=h+4|0}else{break}}return}function oDb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+e|0;g=e-3|0;e=a+g|0;if((g|0)>0){g=a;h=d;while(1){i=c[g>>2]|0;c[h>>2]=i>>>1&2145419232|i&2031647;i=g+4|0;j=h+4|0;if(i>>>0<e>>>0){g=i;h=j}else{k=i;l=j;break}}}else{k=a;l=d}if(!(k>>>0<f>>>0)){return}f=b[k>>1]|0;b[l>>1]=(f&65535)>>>1&32736|f&31;return}function pDb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;g=c+f|0;if((f|0)<=0){return}f=c;c=e;while(1){e=f+3|0;b[c>>1]=(d[f+1|0]|0)<<3&2016|(a[f]&255)>>>3|(d[f+2|0]|0)<<8&-2048;if(e>>>0<g>>>0){f=e;c=c+2|0}else{break}}return}function qDb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;g=c+f|0;if((f|0)<=0){return}f=c;c=e;while(1){e=f+3|0;b[c>>1]=(d[f+1|0]|0)<<2&992|(a[f]&255)>>>3|(d[f+2|0]|0)<<7&31744;if(e>>>0<g>>>0){f=e;c=c+2|0}else{break}}return}function rDb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=b+d|0;if((d|0)>0){f=b;g=c}else{return}while(1){a[g]=a[f]|0;a[g+1|0]=a[f+1|0]|0;c=f+3|0;a[g+2|0]=a[f+2|0]|0;a[g+3|0]=-1;if(c>>>0<e>>>0){f=c;g=g+4|0}else{break}}return}function sDb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0;f=a+e|0;if((e|0)<=0){return}e=a;a=d;while(1){d=c[e>>2]|0;g=e+4|0;b[a>>1]=d>>>3&31|d>>>5&2016|d>>>8&63488;if(g>>>0<f>>>0){e=g;a=a+2|0}else{break}}return}function tDb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0;f=a+e|0;if((e|0)<=0){return}e=a;a=d;while(1){d=c[e>>2]|0;g=e+4|0;b[a>>1]=d>>>3&31|d>>>6&992|d>>>9&31744;if(g>>>0<f>>>0){e=g;a=a+2|0}else{break}}return}function uDb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=b+d|0;if((d|0)>0){f=b;g=c}else{return}while(1){a[g]=a[f]|0;a[g+1|0]=a[f+1|0]|0;a[g+2|0]=a[f+2|0]|0;c=f+4|0;if(c>>>0<e>>>0){f=c;g=g+3|0}else{break}}return}function vDb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;g=c+f|0;if((f|0)<=0){return}f=c;c=e;while(1){e=f+3|0;b[c>>1]=(d[f+1|0]|0)<<2&992|(d[f]|0)<<7&31744|(a[f+2|0]&255)>>>3;if(e>>>0<g>>>0){f=e;c=c+2|0}else{break}}return}function wDb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;g=c+f|0;if((f|0)<=0){return}f=c;c=e;while(1){e=f+3|0;b[c>>1]=(d[f+1|0]|0)<<3&2016|(d[f]|0)<<8&-2048|(a[f+2|0]&255)>>>3;if(e>>>0<g>>>0){f=e;c=c+2|0}else{break}}return}function xDb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)==0){return}else{e=0}do{f=e+2|0;g=a[b+f|0]|0;h=e+1|0;a[c+h|0]=a[b+h|0]|0;a[c+f|0]=a[b+e|0]|0;a[c+e|0]=g;e=e+3|0;}while(e>>>0<d>>>0);return}function yDb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=15-d|0;if((d|0)>0){f=e}else{return}do{d=f-e|0;g=c[a+d>>2]|0;h=g&16711935;c[b+d>>2]=h>>>16|g&-16711936|h<<16;f=f+4|0;}while((f|0)<15);return}function zDb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0;f=a+e|0;if((e|0)<=0){return}e=a;a=d;while(1){d=c[e>>2]|0;g=e+4|0;b[a>>1]=d<<8&63488|d>>>5&2016|d>>>19&31;if(g>>>0<f>>>0){e=g;a=a+2|0}else{break}}return}function ADb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0;f=a+e|0;if((e|0)<=0){return}e=a;a=d;while(1){d=c[e>>2]|0;g=e+4|0;b[a>>1]=d<<7&31744|d>>>6&992|d>>>19&31;if(g>>>0<f>>>0){e=g;a=a+2|0}else{break}}return}function BDb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=g>>1;if((h|0)<=0){return}g=(l|0)>0;m=f;f=e;e=b;b=0;n=a;while(1){if(g){a=0;o=m;p=n;q=e;r=f;while(1){c[o>>2]=(d[q]|0)<<8|(d[p]|0)|(d[p+1|0]|0)<<16|(d[r]|0)<<24;s=a+1|0;if((s|0)<(l|0)){a=s;o=o+4|0;p=p+2|0;q=q+1|0;r=r+1|0}else{break}}}if((b&1|0)==0){t=e;u=f}else{t=e+j|0;u=f+j|0}r=b+1|0;if((r|0)<(h|0)){m=m+k|0;f=u;e=t;b=r;n=n+i|0}else{break}}return}function CDb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=g>>1;if((h|0)<=0){return}g=(l|0)>0;m=f;f=e;e=b;b=0;n=a;while(1){if(g){a=0;o=m;p=n;q=e;r=f;while(1){c[o>>2]=(d[p]|0)<<8|(d[q]|0)|(d[r]|0)<<16|(d[p+1|0]|0)<<24;s=a+1|0;if((s|0)<(l|0)){a=s;o=o+4|0;p=p+2|0;q=q+1|0;r=r+1|0}else{break}}}if((b&1|0)==0){t=e;u=f}else{t=e+j|0;u=f+j|0}r=b+1|0;if((r|0)<(h|0)){m=m+k|0;f=u;e=t;b=r;n=n+i|0}else{break}}return}function DDb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>1;if((h|0)<=0){return}g=(l|0)>0;m=f;f=e;e=b;b=0;n=a;while(1){if(g){a=0;o=m;p=n;q=e;r=f;while(1){c[o>>2]=(d[q]|0)<<8|(d[p]|0)|(d[p+1|0]|0)<<16|(d[r]|0)<<24;s=a+1|0;if((s|0)<(l|0)){a=s;o=o+4|0;p=p+2|0;q=q+1|0;r=r+1|0}else{break}}}r=b+1|0;if((r|0)<(h|0)){m=m+k|0;f=f+j|0;e=e+j|0;b=r;n=n+i|0}else{break}}return}function EDb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>1;if((h|0)<=0){return}g=(l|0)>0;m=f;f=e;e=b;b=0;n=a;while(1){if(g){a=0;o=m;p=n;q=e;r=f;while(1){c[o>>2]=(d[p]|0)<<8|(d[q]|0)|(d[r]|0)<<16|(d[p+1|0]|0)<<24;s=a+1|0;if((s|0)<(l|0)){a=s;o=o+4|0;p=p+2|0;q=q+1|0;r=r+1|0}else{break}}}r=b+1|0;if((r|0)<(h|0)){m=m+k|0;f=f+j|0;e=e+j|0;b=r;n=n+i|0}else{break}}return}function FDb(b,c,d,e,f,g,h,i,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=f>>1;if((g|0)<=0){return}f=(k|0)>0;l=h<<1;m=j<<1;n=e;e=d;d=c;c=0;o=b;while(1){do{if(f){b=0;do{p=b<<2;q=b<<1;a[d+q|0]=a[o+p|0]|0;a[e+b|0]=a[o+(p|1)|0]|0;a[d+(q|1)|0]=a[o+(p|2)|0]|0;a[n+b|0]=a[o+(p|3)|0]|0;b=b+1|0;}while((b|0)<(k|0));if(f){r=0}else{break}do{b=r<<2;p=r<<1;a[d+(p+h)|0]=a[o+(b+j)|0]|0;a[d+((p|1)+h)|0]=a[o+((b|2)+j)|0]|0;r=r+1|0;}while((r|0)<(k|0))}}while(0);b=c+2|0;if((b|0)<(g|0)){n=n+i|0;e=e+i|0;d=d+l|0;c=b;o=o+m|0}else{break}}return}function GDb(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;a[c]=a[b]|0;i=e-1|0;j=(i|0)>0;if(j){k=0;while(1){l=b+k|0;m=k+1|0;n=b+m|0;o=k<<1;a[c+(o|1)|0]=(((d[l]|0)*3|0)+(d[n]|0)|0)>>>2;a[c+(o+2)|0]=(((d[n]|0)*3|0)+(d[l]|0)|0)>>>2;if((m|0)<(i|0)){k=m}else{break}}}k=(e<<1)-1|0;a[c+k|0]=a[b+i|0]|0;e=c+h|0;m=a[b]|0;if((f|0)>1){l=i+g|0;n=k+h|0;o=h<<1;p=ca((f<<1)-1|0,h)|0;q=ca(f-1|0,g)|0;r=e;s=1;t=b;u=m;while(1){v=t+g|0;a[r]=((d[v]|0)+((u&255)*3|0)|0)>>>2;a[r+h|0]=(((d[v]|0)*3|0)+(d[t]|0)|0)>>>2;if(j){w=0;do{x=t+w|0;y=w+g|0;z=t+(y+1)|0;A=w<<1;a[r+(A|1)|0]=(((d[x]|0)*3|0)+(d[z]|0)|0)>>>2;B=A+h|0;a[r+(B+2)|0]=(((d[z]|0)*3|0)+(d[x]|0)|0)>>>2;w=w+1|0;x=t+w|0;z=t+y|0;a[r+(B+1)|0]=(((d[z]|0)*3|0)+(d[x]|0)|0)>>>2;a[r+(A+2)|0]=(((d[x]|0)*3|0)+(d[z]|0)|0)>>>2;}while((w|0)<(i|0))}w=t+i|0;z=t+l|0;a[r+k|0]=(((d[w]|0)*3|0)+(d[z]|0)|0)>>>2;a[r+n|0]=(((d[z]|0)*3|0)+(d[w]|0)|0)>>>2;w=s+1|0;C=a[v]|0;if((w|0)<(f|0)){r=r+o|0;s=w;t=v;u=C}else{break}}D=c+p|0;E=b+q|0;F=C}else{D=e;E=b;F=m}a[D]=F;if(j){G=0}else{H=E+i|0;I=a[H]|0;J=D+k|0;a[J]=I;return}while(1){j=E+G|0;F=G+1|0;m=E+F|0;b=G<<1;a[D+(b|1)|0]=(((d[j]|0)*3|0)+(d[m]|0)|0)>>>2;a[D+(b+2)|0]=(((d[m]|0)*3|0)+(d[j]|0)|0)>>>2;if((F|0)<(i|0)){G=F}else{break}}H=E+i|0;I=a[H]|0;J=D+k|0;a[J]=I;return}function HDb(b,c,d,e,f,g,h,i){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((f|0)<=0){return}j=(e|0)>0;k=d;d=c;c=b;b=0;while(1){if(j){l=0;do{m=l<<1;a[k+m|0]=a[c+l|0]|0;a[k+(m|1)|0]=a[d+l|0]|0;l=l+1|0;}while((l|0)<(e|0))}l=b+1|0;if((l|0)<(f|0)){k=k+i|0;d=d+h|0;c=c+g|0;b=l}else{break}}return}function IDb(b,c,d,e,f,g,h,i){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((f|0)<=0){return}j=(e|0)>0;k=d;d=c;c=b;b=0;while(1){if(j){l=0;do{m=l<<1;a[d+l|0]=a[c+m|0]|0;a[k+l|0]=a[c+(m|1)|0]|0;l=l+1|0;}while((l|0)<(e|0))}l=b+1|0;if((l|0)<(f|0)){k=k+i|0;d=d+h|0;c=c+g|0;b=l}else{break}}return}function JDb(b,c,d,e,f,g,h,i,j,k){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;l=(f|0)/2|0;m=(g|0)/2|0;n=(g|0)>1;if(!n){return}g=(f|0)>1;o=0;do{p=ca(o>>1,h)|0;q=ca(o,j)|0;if(g){r=0;do{s=a[b+(r+p)|0]|0;t=r<<1;a[d+((t|1)+q)|0]=s;a[d+(t+q)|0]=s;r=r+1|0;}while((r|0)<(l|0))}o=o+1|0;}while((o|0)<(m|0));if(!n){return}n=(f|0)>1;f=0;do{o=ca(f>>1,i)|0;d=ca(f,k)|0;if(n){b=0;do{g=a[c+(b+o)|0]|0;j=b<<1;a[e+((j|1)+d)|0]=g;a[e+(j+d)|0]=g;b=b+1|0;}while((b|0)<(l|0))}f=f+1|0;}while((f|0)<(m|0));return}function KDb(b,c,d,e,f,g,h,i,j,k){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=(f|0)/2|0;if((g|0)<=0){return}m=(f|0)>1;f=0;do{n=ca(f,h)|0;o=f>>2;p=ca(o,i)|0;q=ca(o,j)|0;o=ca(f,k)|0;if(m){r=0;do{s=r<<2;t=r<<3;a[e+(t+o)|0]=a[b+(s+n)|0]|0;u=c+(r+p)|0;a[e+((t|1)+o)|0]=a[u]|0;a[e+((t|2)+o)|0]=a[b+((s|1)+n)|0]|0;v=d+(r+q)|0;a[e+((t|3)+o)|0]=a[v]|0;a[e+((t|4)+o)|0]=a[b+((s|2)+n)|0]|0;a[e+((t|5)+o)|0]=a[u]|0;a[e+((t|6)+o)|0]=a[b+((s|3)+n)|0]|0;a[e+((t|7)+o)|0]=a[v]|0;r=r+1|0;}while((r|0)<(l|0))}f=f+1|0;}while((f|0)<(g|0));return}function LDb(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=g+1>>1;if((h|0)<=0){return}m=(g|0)>0;n=-g|0;o=l<<2;p=(l|0)>0;q=-l|0;r=f;f=e;e=c;c=0;s=b;while(1){if(m){b=n;do{t=b+g|0;a[s+t|0]=a[r+(t<<1|1)|0]|0;b=b+1|0;}while((b|0)<0)}if((c&1|0)==0){u=e;v=f}else{if(p){b=q;do{t=b<<2;w=t+o|0;x=b+l|0;a[e+x|0]=((d[r+w|0]|0)+(d[r+(w-k)|0]|0)|0)>>>1;w=(t|2)+o|0;a[f+x|0]=((d[r+w|0]|0)+(d[r+(w-k)|0]|0)|0)>>>1;b=b+1|0;}while((b|0)<0)}u=e+j|0;v=f+j|0}b=c+1|0;if((b|0)<(h|0)){r=r+k|0;f=v;e=u;c=b;s=s+i|0}else{break}}return}function MDb(b,c,d,e,f,g,h,i,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=f+1>>1;if((g|0)<=0){return}l=(f|0)>0;m=-f|0;n=k<<2;o=(k|0)>0;p=-k|0;q=e;e=d;d=c;c=0;r=b;while(1){if(l){b=m;do{s=b+f|0;a[r+s|0]=a[q+(s<<1|1)|0]|0;b=b+1|0;}while((b|0)<0)}if(o){b=p;do{s=b<<2;t=b+k|0;a[d+t|0]=a[q+(s+n)|0]|0;a[e+t|0]=a[q+((s|2)+n)|0]|0;b=b+1|0;}while((b|0)<0)}b=c+1|0;if((b|0)<(g|0)){q=q+j|0;e=e+i|0;d=d+i|0;c=b;r=r+h|0}else{break}}return}function NDb(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=g+1>>1;if((h|0)<=0){return}m=(g|0)>0;n=-g|0;o=l<<2|1;p=(l|0)>0;q=-l|0;r=f;f=e;e=c;c=0;s=b;while(1){if(m){b=n;do{t=b+g|0;a[s+t|0]=a[r+(t<<1)|0]|0;b=b+1|0;}while((b|0)<0)}if((c&1|0)==0){u=e;v=f}else{if(p){b=q;do{t=b<<2;w=t+o|0;x=b+l|0;a[e+x|0]=((d[r+w|0]|0)+(d[r+(w-k)|0]|0)|0)>>>1;w=(t|2)+o|0;a[f+x|0]=((d[r+w|0]|0)+(d[r+(w-k)|0]|0)|0)>>>1;b=b+1|0;}while((b|0)<0)}u=e+j|0;v=f+j|0}b=c+1|0;if((b|0)<(h|0)){r=r+k|0;f=v;e=u;c=b;s=s+i|0}else{break}}return}function ODb(b,c,d,e,f,g,h,i,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=f+1>>1;if((g|0)<=0){return}l=(f|0)>0;m=-f|0;n=k<<2|1;o=(k|0)>0;p=-k|0;q=e;e=d;d=c;c=0;r=b;while(1){if(l){b=m;do{s=b+f|0;a[r+s|0]=a[q+(s<<1)|0]|0;b=b+1|0;}while((b|0)<0)}if(o){b=p;do{s=b<<2;t=b+k|0;a[d+t|0]=a[q+(s+n)|0]|0;a[e+t|0]=a[q+((s|2)+n)|0]|0;b=b+1|0;}while((b|0)<0)}b=c+1|0;if((b|0)<(g|0)){q=q+j|0;e=e+i|0;d=d+i|0;c=b;r=r+h|0}else{break}}return}function PDb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;f=i;g=e+56|0;h=c[g>>2]|0;j=c[e+52>>2]|0;k=e+2284|0;l=c[k>>2]|0;m=c[e+16>>2]|0;n=(j|0)==291;o=(j|0)==292;p=(j|0)==2;q=(j|0)==67;r=(j|0)==68;s=(j|0)==293;t=(j|0)==294;u=(j|0)==28;v=(j|0)==27;w=(j|0)==3;x=(j|0)==65;y=(j|0)==64;a:do{switch(j|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{z=5;break};default:{A=qKb(j)|0;if((A|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=674,B)|0);i=B;Hd()}else{if((a[A+7|0]&32)==0){C=0;break a}else{z=5;break a}}}}}while(0);b:do{if((z|0)==5){A=c[e+60>>2]|0;if((A|0)>=24){C=0;break}if((A|0)<(c[e+64>>2]|0)){C=1;break}switch(h|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{C=0;break b;break};default:{}}A=qKb(h)|0;if((A|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=674,B)|0);i=B;Hd()}else{C=(a[A+7|0]&32)==0;break}}}while(0);A=(h|0)==0;do{if((h|0)==35|(h|0)==0){if(!((j-25|0)>>>0<2>>>0)){z=14;break}c[e+4>>2]=4;D=0}else{z=14}}while(0);do{if((z|0)==14){if((j|0)!=0){D=0;break}if(!((h-25|0)>>>0<2>>>0)){D=1;break}c[e+4>>2]=2;D=1}}while(0);E=(h|0)==4;switch(h|0){case 6:{z=27;break};case 35:case 4:case 0:{c:do{switch(j|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{z=22;break};default:{F=qKb(j)|0;if((F|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=674,B)|0);i=B;Hd()}else{if((a[F+7|0]&32)==0){break c}else{z=22;break c}}}}}while(0);do{if((z|0)==22){if((l&262144|0)!=0){break}if(!(((c[e+23972>>2]|0)-1|0)>>>0<2>>>0)){break}if((m&1|0)!=0){break}c[e+4>>2]=Pxb(e)|0}}while(0);if((h|0)==6){z=27}else if((h|0)==3){z=30}else{z=33}break};case 3:{z=30;break};default:{z=33}}do{if((z|0)==27){if(!((j|0)==35|(j|0)==0)){G=0;H=0;I=0;J=0;K=0;L=0;z=34;break}if((l&524288|0)!=0){z=33;break}c[e+4>>2]=34;z=33}else if((z|0)==30){if(!((j|0)==35|(j|0)==0)){M=0;N=0;O=0;P=0;Q=0;R=0;z=37;break}if((l&262144|0)!=0){M=0;N=0;O=0;P=0;Q=0;R=0;z=37;break}c[e+4>>2]=138;M=0;N=0;O=0;P=0;Q=0;R=0;z=37}}while(0);if((z|0)==33){l=(h|0)==291;m=(h|0)==292;F=(h|0)==67;S=(h|0)==68;T=(h|0)==293;U=(h|0)==294;switch(h|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{M=l;N=m;O=F;P=S;Q=T;R=U;z=37;break};default:{G=l;H=m;I=F;J=S;K=T;L=U;z=34}}}do{if((z|0)==34){U=qKb(h)|0;if((U|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=674,B)|0);i=B;Hd()}else{if((a[U+7|0]&32)==0){V=G;W=H;X=I;Y=J;Z=K;_=L;break}else{M=G;N=H;O=I;P=J;Q=K;R=L;z=37;break}}}}while(0);d:do{if((z|0)==37){e:do{switch(j|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:case 294:case 293:case 292:case 291:case 68:case 67:case 65:case 64:case 63:case 62:case 50:case 49:case 48:case 47:case 46:case 45:case 44:case 43:case 42:case 41:case 30:case 29:case 28:case 27:case 24:case 23:case 22:case 21:case 20:case 19:case 10:case 9:case 3:case 2:{break};default:{L=qKb(j)|0;if((L|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=674,B)|0);i=B;Hd()}else{if((a[L+7|0]&32)==0){V=M;W=N;X=O;Y=P;Z=Q;_=R;break d}else{break e}}}}}while(0);if((UDb(e)|0)==0){V=M;W=N;X=O;Y=P;Z=Q;_=R;break}if(C){if((c[k>>2]&17|0)==0){V=M;W=N;X=O;Y=P;Z=Q;_=R;break}}c[e+4>>2]=48;V=M;W=N;X=O;Y=P;Z=Q;_=R}}while(0);R=(h|0)==82;if(R&(j|0)==317){z=47}else{if((h|0)==317&(j|0)==82){z=47}}if((z|0)==47){c[e+4>>2]=76}do{if(R){Q=qKb(82)|0;if((Q|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=806,B)|0);i=B;Hd()}if(!((d[Q+4|0]|0)>>>0>1>>>0)){break}if((a[Q+7|0]&16)==0){break}if(!((j-29|0)>>>0<2>>>0|p|u|v|w)){break}c[e+4>>2]=84}}while(0);do{if((h-41|0)>>>0<2>>>0|Y|X|W|V|_|Z){if(!((j-83|0)>>>0<2>>>0|(j|0)==86|(j|0)==85|(j|0)==314|(j|0)==313|(j|0)==316|(j|0)==315|(j|0)==88|(j|0)==87|(j|0)==319|(j|0)==318)){break}c[e+4>>2]=166}}while(0);R=(h|0)==84;Q=(h|0)==83;P=(h|0)==88;O=(h|0)==87;N=(h|0)==86;M=(h|0)==85;C=(h|0)==314;L=(h|0)==313;K=(h|0)==316;J=(h|0)==315;I=(h|0)==319;H=(h|0)==318;do{if((h-83|0)>>>0<2>>>0|P|O|N|M|C|L|K|J|I|H){if(!((j-41|0)>>>0<2>>>0|r|q|o|n|t|s)){break}c[e+4>>2]=162}}while(0);do{if((b[(qKb(h)|0)+8>>1]&30720)==14336){G=qKb(h)|0;if((G|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=813,B)|0);i=B;Hd()}if(!((a[G+7|0]&48)==32&(j|0)==82)){break}c[e+4>>2]=152}}while(0);f:do{switch(h|0){case 332:case 331:case 330:case 329:case 328:case 327:case 326:case 325:case 324:case 323:case 322:case 321:{if(p){c[e+4>>2]=156}else{do{if(D){c[e+4>>2]=140}else{if((j-321|0)>>>0<12>>>0){break}KIb(e,16,2414816,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2436288,c[B+8>>2]=2349576,c[B+16>>2]=1655,B)|0);i=B;Hd()}}while(0);if(!((h|0)!=326|(j|0)!=325)){z=132;break f}if(!((h|0)!=325|(j|0)!=326)){z=132;break f}if(!((h|0)!=328|(j|0)!=327)){z=132;break f}if(!((h|0)!=327|(j|0)!=328)){z=132;break f}if(!((h|0)!=330|(j|0)!=329)){z=132;break f}if(!((h|0)!=329|(j|0)!=330)){z=132;break f}if(!((h|0)!=332|(j|0)!=331)){z=132;break f}if(!((h|0)!=331|(j|0)!=332)){z=132;break f}}if((h|0)!=65|y^1){z=83}else{z=132}break};case 64:{if(x|X&r|Y&q|Z&t|_&s){z=132}else{z=91}break};case 65:{if(y){z=132}else{z=83}break};default:{if(X&r|Y&q|Z&t|_&s){z=132}else{z=86}}}}while(0);if((z|0)==83){if(x&(h|0)==64|X&r|Y&q|Z&t|_&s){z=132}else{z=86}}do{if((z|0)==86){if(!((h|0)!=49|(j|0)!=50)){z=132;break}if(!((h|0)!=50|(j|0)!=49)){z=132;break}if(!((h|0)!=47|(j|0)!=48)){z=132;break}if(!((h|0)!=48|(j|0)!=47)){z=132;break}if((h|0)==31&(j|0)==32){z=132}else{z=91}}}while(0);do{if((z|0)==91){if((h|0)==32&(j|0)==31|Q&(j|0)==84|R&(j|0)==83|M&(j|0)==86|N&(j|0)==85|L&(j|0)==314|C&(j|0)==313|J&(j|0)==316|K&(j|0)==315|O&(j|0)==88|P&(j|0)==87|H&(j|0)==319|I&(j|0)==318){z=132;break}if(!((h|0)!=63|(j|0)!=62)){z=132;break}if(!((h|0)!=62|(j|0)!=63)){z=132;break}if(!((h|0)!=41|(j|0)!=42)){z=132;break}if((j|0)==41&(h|0)==42|V&o|W&n){z=132;break}if(!((h|0)!=45|(j|0)!=46)){z=132;break}if(!((h|0)!=46|(j|0)!=45)){z=132;break}if(!((h|0)!=43|(j|0)!=44)){z=132;break}if(!((h|0)!=44|(j|0)!=43)){z=132;break}if((h|0)==111&(j|0)==110){z=132;break}if((h|0)==110&(j|0)==111){z=132;break}if((h|0)==69&(j|0)==70){z=132;break}if((h|0)==70&(j|0)==69){z=132;break}if((h|0)==71&(j|0)==72){z=132;break}if((h|0)==72&(j|0)==71){z=132;break}if((h|0)==301&(j|0)==302){z=132;break}if((h|0)==302&(j|0)==301){z=132;break}if((h|0)==303&(j|0)==304){z=132;break}if((h|0)==304&(j|0)==303){z=132;break}if((h|0)==55&(j|0)==54){z=132;break}if((h|0)==54&(j|0)==55){z=132;break}if((h|0)==79&(j|0)==80){z=132;break}if((h|0)==80&(j|0)==79){z=132;break}if((h|0)==73&(j|0)==74){z=132;break}if((h|0)==74&(j|0)==73){z=132;break}if((h|0)==305&(j|0)==306){z=132;break}if((h|0)==306&(j|0)==305){z=132;break}if((h|0)==307&(j|0)==308){z=132;break}if((h|0)==308&(j|0)==307){z=132;break}if((h|0)==57&(j|0)==56){z=132;break}if((h|0)==56&(j|0)==57){z=132;break}if((h|0)==75&(j|0)==76){z=132;break}if((h|0)==76&(j|0)==75){z=132;break}if((h|0)==77&(j|0)==78){z=132;break}if((h|0)==78&(j|0)==77){z=132;break}if((h|0)==309&(j|0)==310){z=132;break}if((h|0)==310&(j|0)==309){z=132;break}if((h|0)==311&(j|0)==312){z=132;break}if((h|0)==312&(j|0)==311){z=132;break}if((h|0)==59&(j|0)==58){z=132;break}if((h|0)==58&(j|0)==59){z=132}}}while(0);if((z|0)==132){c[e+4>>2]=52}n=qKb(h)|0;if((n|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=828,B)|0);i=B;Hd()}do{if(!((a[n+7|0]&66)==0)){if(!((j-29|0)>>>0<2>>>0|p|u|v|w)){break}c[e+4>>2]=102}}while(0);do{if(E){if((j|0)==17){c[e+4>>2]=66;break}else if((j|0)==1){c[e+4>>2]=118;break}else{break}}}while(0);do{if((c[k>>2]&17|0)!=0){if(!((h|0)==35|(h|0)==0)){break}if((j|0)==1){c[e+4>>2]=16;break}else if((j|0)==17){c[e+4>>2]=168;break}else{break}}}while(0);k=(h|0)==1;do{if(k){if(!((j|0)==35|(j|0)==0)){$=0;z=153;break}c[e+4>>2]=74;$=0;z=153}else{if((h|0)!=17){break}if(!((j|0)==35|(j|0)==0)){$=1;z=153;break}c[e+4>>2]=96;$=1;z=153}}while(0);do{if((z|0)==153){E=(j|0)==4;if(k&E){c[e+4>>2]=22}if(!($&E)){break}c[e+4>>2]=14}}while(0);g:do{if((h|0)!=(j|0)){if(D&(h|0)==35|A&(j|0)==35){break}$=qKb(h)|0;if(($|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=667,B)|0);i=B;Hd()}do{if(!((a[$+7|0]&16)==0)){k=qKb(h)|0;if((k|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=660,B)|0);i=B;Hd()}if(!((a[k+7|0]&32)==0)){break}if(!((d[k+4|0]|0)>>>0>1>>>0)){break}if(((j|0)==8|(j|0)==66|(j|0)==31|(j|0)==32)&(j|0)!=66){break g}}}while(0);$=qKb(j)|0;if(($|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=667,B)|0);i=B;Hd()}do{if(!((a[$+7|0]&16)==0)){k=qKb(j)|0;if((k|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=660,B)|0);i=B;Hd()}if(!((a[k+7|0]&32)==0)){break}if(!((d[k+4|0]|0)>>>0>1>>>0)){break}if(((h|0)==8|(h|0)==66|(h|0)==31|(h|0)==32)&(h|0)!=66){break g}}}while(0);if(((j|0)==8|(j|0)==66|(j|0)==31|(j|0)==32)&(j|0)!=66){if(((h|0)==8|(h|0)==66|(h|0)==31|(h|0)==32)&(h|0)!=66){break}}$=qKb(h)|0;if(($|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=667,B)|0);i=B;Hd()}if((a[$+7|0]&16)==0){i=f;return}$=qKb(h)|0;if(($|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=660,B)|0);i=B;Hd()}if(!((a[$+7|0]&32)==0)){i=f;return}if(!((d[$+4|0]|0)>>>0>1>>>0)){i=f;return}$=qKb(j)|0;if(($|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=667,B)|0);i=B;Hd()}if((a[$+7|0]&16)==0){i=f;return}$=qKb(j)|0;if(($|0)==0){KIb(0,0,2579568,(B=i,i=i+24|0,c[B>>2]=2287848,c[B+8>>2]=2237984,c[B+16>>2]=660,B)|0);i=B;Hd()}if(!((a[$+7|0]&32)==0)){i=f;return}if(!((d[$+4|0]|0)>>>0>1>>>0)){i=f;return}if((c[e+84>>2]|0)!=(c[e+76>>2]|0)){i=f;return}if((c[e+88>>2]|0)!=(c[e+80>>2]|0)){i=f;return}if(!((j-25|0)>>>0>1>>>0)){i=f;return}if((h-25|0)>>>0>1>>>0){break}i=f;return}}while(0);h=c[g>>2]|0;h:do{switch(h|0){case 11:case 1:case 17:case 66:case 41:case 42:case 291:case 292:case 30:case 29:case 2:case 43:case 44:case 45:case 46:case 63:case 62:case 22:case 23:case 24:case 10:{break};default:{switch(h|0){case 294:case 293:case 68:case 67:case 65:case 64:case 50:case 49:case 48:case 47:case 28:case 27:case 21:case 20:case 19:case 10:case 9:case 3:{break h;break};default:{}}c[e+4>>2]=80;i=f;return}}}while(0);c[e+4>>2]=146;i=f;return}function QDb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=h+4|0;j=(c[g+4>>2]|0)+((ca(c[i>>2]|0,e)|0)/2|0)|0;k=c[b>>2]|0;l=c[d>>2]|0;m=a+8|0;n=c[m>>2]|0;o=c[h>>2]|0;h=(c[g>>2]|0)+(ca(o,e)|0)|0;do{if((o|0)==(l|0)&(l|0)>0){nrc(h|0,k|0,ca(l,f)|0)|0}else{if((f|0)>0){p=h;q=k;r=0}else{break}while(1){nrc(p|0,q|0,n)|0;e=r+1|0;if((e|0)<(f|0)){p=p+o|0;q=q+l|0;r=e}else{break}}}}while(0);r=c[1474814]|0;if((c[a+52>>2]|0)==25){Ge[r&255](c[b+4>>2]|0,c[b+8>>2]|0,j,(c[m>>2]|0)/2|0,(f|0)/2|0,c[d+4>>2]|0,c[d+8>>2]|0,c[i>>2]|0);return f|0}else{Ge[r&255](c[b+8>>2]|0,c[b+4>>2]|0,j,(c[m>>2]|0)/2|0,(f|0)/2|0,c[d+8>>2]|0,c[d+4>>2]|0,c[i>>2]|0);return f|0}return 0}function RDb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=h+4|0;j=(c[g+4>>2]|0)+((ca(c[i>>2]|0,e)|0)/2|0)|0;k=h+8|0;l=(c[g+8>>2]|0)+((ca(c[k>>2]|0,e)|0)/2|0)|0;m=c[b>>2]|0;n=c[d>>2]|0;o=a+8|0;p=c[o>>2]|0;q=c[h>>2]|0;h=(c[g>>2]|0)+(ca(q,e)|0)|0;do{if((q|0)==(n|0)&(n|0)>0){nrc(h|0,m|0,ca(n,f)|0)|0}else{if((f|0)>0){r=h;s=m;t=0}else{break}while(1){nrc(r|0,s|0,p)|0;e=t+1|0;if((e|0)<(f|0)){r=r+q|0;s=s+n|0;t=e}else{break}}}}while(0);t=c[2336126]|0;n=c[b+4>>2]|0;b=(c[o>>2]|0)/2|0;o=(f|0)/2|0;s=c[d+4>>2]|0;if((c[a+56>>2]|0)==25){Ge[t&255](n,j,l,b,o,s,c[i>>2]|0,c[k>>2]|0);return f|0}else{Ge[t&255](n,l,j,b,o,s,c[k>>2]|0,c[i>>2]|0);return f|0}return 0}function SDb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=c[b>>2]|0;j=c[d>>2]|0;k=a+8|0;l=c[k>>2]|0;m=c[h>>2]|0;n=(c[g>>2]|0)+(ca(m,e)|0)|0;do{if((m|0)==(j|0)&(j|0)>0){nrc(n|0,i|0,ca(j,f)|0)|0}else{if((f|0)>0){o=n;p=i;q=0}else{break}while(1){nrc(o|0,p|0,l)|0;r=q+1|0;if((r|0)<(f|0)){o=o+m|0;p=p+j|0;q=r}else{break}}}}while(0);q=c[h+4>>2]|0;j=e>>1;p=(c[g+4>>2]|0)+(ca(q,j)|0)|0;m=a+20|0;a=f>>2;_e[c[1365628]&511](c[b+4>>2]|0,p,c[m>>2]|0,a,c[d+4>>2]|0,q);q=c[h+8>>2]|0;p=(c[g+8>>2]|0)+(ca(q,j)|0)|0;_e[c[1365628]&511](c[b+8>>2]|0,p,c[m>>2]|0,a,c[d+8>>2]|0,q);q=c[g+12>>2]|0;if((q|0)==0){return f|0}g=c[h+12>>2]|0;h=c[k>>2]|0;if((f|0)<=0){return f|0}k=0;d=q+(ca(g,e)|0)|0;while(1){mrc(d|0,-1|0,h|0)|0;e=k+1|0;if((e|0)<(f|0)){k=e;d=d+g|0}else{break}}return f|0}function TDb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ca(i,e)|0)|0;k=e>>1;l=c[h+4>>2]|0;m=(c[g+4>>2]|0)+(ca(l,k)|0)|0;n=(c[g+8>>2]|0)+(ca(c[h+8>>2]|0,k)|0)|0;k=a+8|0;Ve[c[1637278]&127](c[b>>2]|0,j,m,n,c[k>>2]|0,f,i,l,c[d>>2]|0,a+10496|0);a=c[g+12>>2]|0;if((a|0)==0){return f|0}g=c[h+12>>2]|0;h=c[k>>2]|0;if((f|0)<=0){return f|0}k=0;d=a+(ca(g,e)|0)|0;while(1){mrc(d|0,-1|0,h|0)|0;e=k+1|0;if((e|0)<(f|0)){k=e;d=d+g|0}else{break}}return f|0}function UDb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[a+56>>2]|0;d=c[a+52>>2]|0;e=c[a+64>>2]|0;f=c[a+60>>2]|0;a=(b|0)==27;g=(b|0)==28;h=(b|0)==30;i=(b|0)==29;do{if((b-27|0)>>>0<2>>>0|h|i){j=(d|0)==30;k=(d|0)==29;if(!((d-27|0)>>>0<2>>>0|j|k)){break}l=i^1;m=(d|0)!=28;if(!(m|l)){n=1376;return n|0}o=a^1;p=j^1;if(!(o|p)){n=1376;return n|0}j=h^1;q=(d|0)!=27;if(!(q|j)){n=1376;return n|0}r=g^1;s=k^1;if(!(r|s)){n=1376;return n|0}if(!((q|l)&(o|s))){n=1248;return n|0}if(!((l|p)&(m|o))){n=2128;return n|0}if((m|j)&(r|p)){return((j|s)&(q|r)?0:264)|0}n=c[1280128]|0;return n|0}}while(0);r=(b-41|0)>>>0<2>>>0;q=(b|0)==68;s=(b|0)==67;do{if(r|q|s){j=(d|0)==68;p=(d|0)==67;if(!((d-41|0)>>>0<2>>>0|j|p)){break}m=(b|0)!=42;o=j^1;if(!(m|o)){n=16;return n|0}j=q^1;l=(d|0)!=42;if(!(l|j)){n=16;return n|0}k=(b|0)!=41;t=p^1;if(!(k|t)){n=16;return n|0}p=s^1;u=(d|0)!=41;if(!(u|p)){n=16;return n|0}n=(m|t)&(u|j)&(k|o)&(l|p)?0:1540;return n|0}}while(0);s=(b|0)==292;q=(b|0)==291;p=(b|0)==294;l=(b|0)==293;do{if((b-291|0)>>>0<2>>>0|p|l){o=(d|0)==68;k=(d|0)==67;if(!((d-41|0)>>>0<2>>>0|o|k)){break}j=s^1;u=o^1;if(!(j|u)){n=1868;return n|0}o=p^1;t=(d|0)!=42;if(!(t|o)){n=1868;return n|0}m=q^1;v=k^1;if(!(m|v)){n=1868;return n|0}k=l^1;w=(d|0)!=41;if(!(w|k)){n=1868;return n|0}if(!((j|v)&(w|o)&(m|u)&(t|k))){n=2158;return n|0}if(!((t|j)&(o|u)&(w|m)&(k|v))){n=2286;return n|0}n=(w|j)&(o|v)&(t|m)&(k|u)?0:648;return n|0}}while(0);u=(b|0)==10;k=(b|0)==9;m=(b-67|0)>>>0<2>>>0|l|p|g|a|(b|0)==3|(b|0)==47|(b|0)==48|(b|0)==49|(b|0)==50|(b|0)==65|(b|0)==64|(b|0)==19|(b|0)==20|(b|0)==21|u|k;if(m){if(!((d-67|0)>>>0<2>>>0|(d|0)==293|(d|0)==294|(d|0)==28|(d|0)==27|(d|0)==3|(d|0)==47|(d|0)==48|(d|0)==49|(d|0)==50|(d|0)==65|(d|0)==64|(d|0)==19|(d|0)==20|(d|0)==21|(d|0)==10|(d|0)==9)){x=30}}else{x=30}do{if((x|0)==30){a=r|q|s|h|i|(b|0)==2|(b|0)==43|(b|0)==44|(b|0)==45|(b|0)==46|(b|0)==63|(b|0)==62|(b|0)==22|(b|0)==23|(b|0)==24|u|k;if(a){if((d-41|0)>>>0<2>>>0|(d|0)==291|(d|0)==292|(d|0)==30|(d|0)==29|(d|0)==2|(d|0)==43|(d|0)==44|(d|0)==45|(d|0)==46|(d|0)==63|(d|0)==62|(d|0)==22|(d|0)==23|(d|0)==24|(d|0)==10|(d|0)==9){break}}if(m){if(!((d-41|0)>>>0<2>>>0|(d|0)==291|(d|0)==292|(d|0)==30|(d|0)==29|(d|0)==2|(d|0)==43|(d|0)==44|(d|0)==45|(d|0)==46|(d|0)==63|(d|0)==62|(d|0)==22|(d|0)==23|(d|0)==24|(d|0)==10|(d|0)==9)){x=48}}else{x=48}do{if((x|0)==48){if(!a){n=0;return n|0}if((d-67|0)>>>0<2>>>0|(d|0)==293|(d|0)==294|(d|0)==28|(d|0)==27|(d|0)==3|(d|0)==47|(d|0)==48|(d|0)==49|(d|0)==50|(d|0)==65|(d|0)==64|(d|0)==19|(d|0)==20|(d|0)==21|(d|0)==10|(d|0)==9){break}else{n=0}return n|0}}while(0);a=f<<16|e;if((a|0)==983072){n=c[1352492]|0;return n|0}else if((a|0)==1048591){n=1996;return n|0}else if((a|0)==1048592){n=1396;return n|0}else if((a|0)==2097176){n=c[1352498]|0;return n|0}else if((a|0)==786444){n=1162;return n|0}else if((a|0)==1572896){n=c[1352488]|0;return n|0}else if((a|0)==2097167){n=1660;return n|0}else if((a|0)==2097168){n=1462;return n|0}else if((a|0)==983055){n=1994;return n|0}else if((a|0)==983056){n=1394;return n|0}else if((a|0)==983064){n=c[1352504]|0;return n|0}else if((a|0)==1048600){n=c[1352502]|0;return n|0}else if((a|0)==1048608){n=c[1352490]|0;return n|0}else if((a|0)==1572879){n=c[1352516]|0;return n|0}else if((a|0)==1572880){n=c[1352510]|0;return n|0}else if((a|0)==1572888){n=c[1352500]|0;return n|0}else{n=0;return n|0}}}while(0);d=f<<16|e;if((d|0)==2097167){n=c[1352518]|0;return n|0}else if((d|0)==2097168){n=c[1352512]|0;return n|0}else if((d|0)==2097176){n=1920;return n|0}else if((d|0)==983052){n=1252;return n|0}else if((d|0)==1572879){n=2036;return n|0}else if((d|0)==1572880){n=2110;return n|0}else if((d|0)==1572896){n=246;return n|0}else if((d|0)==1048591){n=c[1352520]|0;return n|0}else if((d|0)==1048600){n=c[1352506]|0;return n|0}else if((d|0)==1048608){n=c[1352494]|0;return n|0}else if((d|0)==983056){n=c[1352514]|0;return n|0}else if((d|0)==983064){n=c[1352508]|0;return n|0}else if((d|0)==983072){n=c[1352496]|0;return n|0}else{n=0;return n|0}return 0}function VDb(d,e,f,g,h,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;l=i;m=c[d+56>>2]|0;n=d+52|0;o=c[n>>2]|0;p=qKb(m)|0;q=qKb(c[n>>2]|0)|0;n=(c[d+64>>2]|0)+7|0;r=n>>3;s=(c[d+60>>2]|0)+7|0;t=s>>3;u=UDb(d)|0;if((u|0)==0){v=mKb(m)|0;w=mKb(o)|0;KIb(d,16,2197400,(x=i,i=i+16|0,c[x>>2]=v,c[x+8>>2]=w,x)|0);i=x;i=l;return h|0}x=c[e>>2]|0;e=c[j>>2]|0;if((n&-8|0)==16){y=(a[p+7|0]&1)!=0}else{y=0}if((s&-8|0)==16){z=(a[q+7|0]&1)!=0}else{z=0}if((m|0)==29|(m|0)==27){A=(o-27|0)>>>0<2>>>0|(o|0)==30|(o|0)==29?x:x+1|0}else{A=x}do{if((o|0)==29|(o|0)==27){if((m-27|0)>>>0<2>>>0|(m|0)==30|(m|0)==29){B=e;break}if((h|0)>0){x=0;do{a[e+(ca(c[k>>2]|0,x+g|0)|0)|0]=-1;x=x+1|0;}while((x|0)<(h|0))}B=e+1|0}else{B=e}}while(0);e=c[k>>2]|0;m=ca(e,r)|0;o=c[f>>2]|0;do{if((m|0)==(ca(o,t)|0)&(o|0)>0){if(((o|0)%(r|0)|0|0)!=0|z|y){break}x=B+(ca(e,g)|0)|0;q=ca(o,h)|0;ef[u&4095](A,x,q);i=l;return h|0}}while(0);o=B+(ca(e,g)|0)|0;if((h|0)<=0){i=l;return h|0}g=d+8|0;e=d+2208|0;if(y){C=o;D=A;E=0}else{y=o;o=A;A=0;while(1){d=ca(c[g>>2]|0,r)|0;ef[u&4095](o,y,d);do{if(z){d=c[g>>2]|0;if((d|0)<=0){break}B=y;t=0;do{m=B+(t<<1)|0;b[m>>1]=he(b[m>>1]|0)|0;t=t+1|0;}while((t|0)<(d|0))}}while(0);d=A+1|0;if((d|0)<(h|0)){y=y+(c[k>>2]|0)|0;o=o+(c[f>>2]|0)|0;A=d}else{break}}i=l;return h|0}while(1){A=c[g>>2]|0;if((A|0)>0){o=D;y=c[e>>2]|0;d=y;t=0;while(1){b[d+(t<<1)>>1]=he(b[o+(t<<1)>>1]|0)|0;B=t+1|0;if((B|0)<(A|0)){t=B}else{F=y;break}}}else{F=c[e>>2]|0}y=ca(A,r)|0;ef[u&4095](F,C,y);do{if(z){y=c[g>>2]|0;if((y|0)<=0){break}t=C;o=0;do{d=t+(o<<1)|0;b[d>>1]=he(b[d>>1]|0)|0;o=o+1|0;}while((o|0)<(y|0))}}while(0);A=E+1|0;if((A|0)<(h|0)){C=C+(c[k>>2]|0)|0;D=D+(c[f>>2]|0)|0;E=A}else{break}}i=l;return h|0}function WDb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;i=c[b>>2]|0;j=c[d>>2]|0;k=a+8|0;a=c[k>>2]|0;l=c[h>>2]|0;m=(c[g>>2]|0)+(ca(l,e)|0)|0;do{if((l|0)==(j|0)&(j|0)>0){nrc(m|0,i|0,ca(j,f)|0)|0}else{if((f|0)>0){n=m;o=i;p=0}else{break}while(1){nrc(n|0,o|0,a)|0;q=p+1|0;if((q|0)<(f|0)){n=n+l|0;o=o+j|0;p=q}else{break}}}}while(0);p=c[b+4>>2]|0;j=c[d+4>>2]|0;o=c[k>>2]|0;l=c[h+4>>2]|0;n=(c[g+4>>2]|0)+(ca(l,e)|0)|0;do{if((l|0)==(j|0)&(j|0)>0){nrc(n|0,p|0,ca(j,f)|0)|0}else{if((f|0)>0){r=n;s=p;t=0}else{break}while(1){nrc(r|0,s|0,o)|0;a=t+1|0;if((a|0)<(f|0)){r=r+l|0;s=s+j|0;t=a}else{break}}}}while(0);t=c[b+8>>2]|0;b=c[d+8>>2]|0;d=c[k>>2]|0;j=c[h+8>>2]|0;s=(c[g+8>>2]|0)+(ca(j,e)|0)|0;do{if((j|0)==(b|0)&(b|0)>0){nrc(s|0,t|0,ca(b,f)|0)|0}else{if((f|0)>0){u=s;v=t;w=0}else{break}while(1){nrc(u|0,v|0,d)|0;l=w+1|0;if((l|0)<(f|0)){u=u+j|0;v=v+b|0;w=l}else{break}}}}while(0);w=c[g+12>>2]|0;if((w|0)==0){return f|0}g=c[h+12>>2]|0;h=c[k>>2]|0;if((f|0)<=0){return f|0}k=0;b=w+(ca(g,e)|0)|0;while(1){mrc(b|0,-1|0,h|0)|0;e=k+1|0;if((e|0)<(f|0)){k=e;b=b+g|0}else{break}}return f|0}function XDb(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=i;l=c[d+4>>2]|0;m=c[d>>2]|0;n=c[d+8>>2]|0;d=c[e+4>>2]|0;o=c[e>>2]|0;p=c[e+8>>2]|0;e=c[b+56>>2]|0;if((e|0)!=82){q=mKb(e)|0;e=mKb(c[b+52>>2]|0)|0;KIb(b,16,2165800,(r=i,i=i+16|0,c[r>>2]=q,c[r+8>>2]=e,r)|0);i=r;i=k;return g|0}e=b+52|0;switch(c[e>>2]|0){case 30:{s=0;t=22;break};case 28:{u=0;t=13;break};case 27:{u=1;t=13;break};case 3:{q=c[h>>2]|0;v=c[j>>2]|0;w=c[b+8>>2]|0;if((g|0)>0&(w|0)>0){x=0;y=l;z=m;A=n}else{i=k;return g|0}while(1){B=0;C=q+(ca(x+f|0,v)|0)|0;while(1){a[C]=a[y+B|0]|0;a[C+1|0]=a[z+B|0]|0;a[C+2|0]=a[A+B|0]|0;D=B+1|0;if((D|0)<(w|0)){B=D;C=C+3|0}else{break}}C=x+1|0;if((C|0)<(g|0)){x=C;y=y+d|0;z=z+o|0;A=A+p|0}else{break}}i=k;return g|0};case 29:{s=1;t=22;break};case 2:{A=c[h>>2]|0;z=c[j>>2]|0;y=c[b+8>>2]|0;if((g|0)>0&(y|0)>0){E=0;F=n;G=m;H=l}else{i=k;return g|0}while(1){x=0;w=A+(ca(E+f|0,z)|0)|0;while(1){a[w]=a[F+x|0]|0;a[w+1|0]=a[G+x|0]|0;a[w+2|0]=a[H+x|0]|0;v=x+1|0;if((v|0)<(y|0)){x=v;w=w+3|0}else{break}}w=E+1|0;if((w|0)<(g|0)){E=w;F=F+p|0;G=G+o|0;H=H+d|0}else{break}}i=k;return g|0};default:{H=mKb(82)|0;G=mKb(c[e>>2]|0)|0;KIb(b,16,2165800,(r=i,i=i+16|0,c[r>>2]=H,c[r+8>>2]=G,r)|0);i=r;i=k;return g|0}}if((t|0)==13){r=c[h>>2]|0;G=c[j>>2]|0;H=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}e=(u|0)==0;u=(H|0)>0;F=0;E=n;y=m;z=l;while(1){A=r+(ca(F+f|0,G)|0)|0;do{if(e){if(u){I=0;J=A}else{break}while(1){a[J]=a[E+I|0]|0;a[J+1|0]=a[y+I|0]|0;a[J+2|0]=a[z+I|0]|0;a[J+3|0]=-1;w=I+1|0;if((w|0)<(H|0)){I=w;J=J+4|0}else{break}}}else{if(u){K=0;L=A}else{break}while(1){a[L]=-1;a[L+1|0]=a[E+K|0]|0;a[L+2|0]=a[y+K|0]|0;a[L+3|0]=a[z+K|0]|0;w=K+1|0;if((w|0)<(H|0)){K=w;L=L+4|0}else{break}}}}while(0);A=F+1|0;if((A|0)<(g|0)){F=A;E=E+p|0;y=y+o|0;z=z+d|0}else{break}}i=k;return g|0}else if((t|0)==22){t=c[h>>2]|0;h=c[j>>2]|0;j=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}b=(s|0)==0;s=(j|0)>0;z=0;y=l;l=m;m=n;while(1){n=t+(ca(z+f|0,h)|0)|0;do{if(b){if(s){M=0;N=n}else{break}while(1){a[N]=a[y+M|0]|0;a[N+1|0]=a[l+M|0]|0;a[N+2|0]=a[m+M|0]|0;a[N+3|0]=-1;E=M+1|0;if((E|0)<(j|0)){M=E;N=N+4|0}else{break}}}else{if(s){O=0;P=n}else{break}while(1){a[P]=-1;a[P+1|0]=a[y+O|0]|0;a[P+2|0]=a[l+O|0]|0;a[P+3|0]=a[m+O|0]|0;E=O+1|0;if((E|0)<(j|0)){O=E;P=P+4|0}else{break}}}}while(0);n=z+1|0;if((n|0)<(g|0)){z=n;y=y+d|0;l=l+o|0;m=m+p|0}else{break}}i=k;return g|0}return 0}function YDb(b,f,g,h,j,k,l){b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=i;i=i+64|0;n=m|0;o=m+16|0;p=m+32|0;q=m+48|0;r=n|0;s=c[k+8>>2]|0;c[r>>2]=s;t=c[k>>2]|0;c[n+4>>2]=t;u=c[k+4>>2]|0;c[n+8>>2]=u;v=c[k+12>>2]|0;c[n+12>>2]=v;n=o|0;c[n>>2]=u;c[o+4>>2]=t;c[o+8>>2]=s;c[o+12>>2]=v;v=p|0;o=c[l+8>>2]|0;c[v>>2]=o;s=c[l>>2]|0;c[p+4>>2]=s;t=c[l+4>>2]|0;c[p+8>>2]=t;u=c[l+12>>2]|0;c[p+12>>2]=u;p=q|0;c[p>>2]=t;c[q+4>>2]=s;c[q+8>>2]=o;c[q+12>>2]=u;u=b+56|0;q=qKb(c[u>>2]|0)|0;o=qKb(c[b+52>>2]|0)|0;s=(e[o+8>>1]|0)>>>11&15;t=d[q+7|0]|0;l=t&128;k=t&1;t=a[o+7|0]|0;w=(t&1)==0?k:k|2;if((t&48)!=48|(s+1|0)>>>0<9>>>0){t=c[o>>2]|0;KIb(b,16,2139608,(x=i,i=i+16|0,c[x>>2]=c[q>>2],c[x+8>>2]=t,x)|0);i=x;i=m;return j|0}switch(c[u>>2]|0){case 42:case 41:case 292:case 291:{u=c[g>>2]|0;nFb((c[f>>2]|0)+(ca(u,h)|0)|0,u,r,v,j,l,w,s^15,c[b+8>>2]|0);i=m;return j|0};case 68:case 67:case 294:case 293:{v=c[g>>2]|0;nFb((c[f>>2]|0)+(ca(v,h)|0)|0,v,n,p,j,l,w,s^15,c[b+8>>2]|0);i=m;return j|0};default:{s=c[o>>2]|0;KIb(b,16,2139608,(x=i,i=i+16|0,c[x>>2]=c[q>>2],c[x+8>>2]=s,x)|0);i=x;i=m;return j|0}}return 0}function ZDb(b,d,f,g,h,j,k){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=i;i=i+64|0;m=l|0;n=l+16|0;o=l+32|0;p=l+48|0;q=m|0;r=c[d+4>>2]|0;c[q>>2]=r;s=c[d>>2]|0;c[m+4>>2]=s;t=c[d+8>>2]|0;c[m+8>>2]=t;u=c[d+12>>2]|0;c[m+12>>2]=u;m=n|0;c[m>>2]=t;c[n+4>>2]=s;c[n+8>>2]=r;c[n+12>>2]=u;u=o|0;n=c[f+4>>2]|0;c[u>>2]=n;r=c[f>>2]|0;c[o+4>>2]=r;s=c[f+8>>2]|0;c[o+8>>2]=s;t=c[f+12>>2]|0;c[o+12>>2]=t;o=p|0;c[o>>2]=s;c[p+4>>2]=r;c[p+8>>2]=n;c[p+12>>2]=t;t=qKb(c[b+56>>2]|0)|0;p=b+52|0;n=qKb(c[p>>2]|0)|0;r=((e[t+8>>1]|0)>>>11&15)+1|0;s=a[t+7|0]|0;f=s&1;d=(a[n+7|0]&1)==0?f:f|2;if((s&48)!=48|r>>>0<9>>>0){s=c[n>>2]|0;KIb(b,16,2165800,(v=i,i=i+16|0,c[v>>2]=c[t>>2],c[v+8>>2]=s,v)|0);i=v;i=l;return h|0}switch(c[p>>2]|0){case 292:case 291:{p=c[k>>2]|0;mFb(m,o,(c[j>>2]|0)+(ca(p,g)|0)|0,p,h,1,d,r,c[b+8>>2]|0);i=l;return h|0};case 68:case 67:{p=c[k>>2]|0;mFb(q,u,(c[j>>2]|0)+(ca(p,g)|0)|0,p,h,0,d,r,c[b+8>>2]|0);i=l;return h|0};case 294:case 293:{p=c[k>>2]|0;mFb(q,u,(c[j>>2]|0)+(ca(p,g)|0)|0,p,h,1,d,r,c[b+8>>2]|0);i=l;return h|0};case 42:case 41:{p=c[k>>2]|0;mFb(m,o,(c[j>>2]|0)+(ca(p,g)|0)|0,p,h,0,d,r,c[b+8>>2]|0);i=l;return h|0};default:{r=c[n>>2]|0;KIb(b,16,2165800,(v=i,i=i+16|0,c[v>>2]=c[t>>2],c[v+8>>2]=r,v)|0);i=v;i=l;return h|0}}return 0}function _Db(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;k=i;l=c[j+4>>2]|0;m=c[j>>2]|0;n=c[j+8>>2]|0;j=(c[h+4>>2]|0)+(ca(l,f)|0)|0;o=(c[h>>2]|0)+(ca(m,f)|0)|0;p=(c[h+8>>2]|0)+(ca(n,f)|0)|0;f=c[b+56>>2]|0;switch(f|0){case 3:{h=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}q=(h|0)>0;r=h*3|0;s=(c[e>>2]|0)-r|0;t=c[d>>2]|0;u=p;v=o;w=j;x=0;while(1){if(q){y=t;z=0;while(1){a[w+z|0]=a[y]|0;a[v+z|0]=a[y+1|0]|0;a[u+z|0]=a[y+2|0]|0;A=z+1|0;if((A|0)<(h|0)){y=y+3|0;z=A}else{break}}B=t+r|0}else{B=t}z=x+1|0;if((z|0)<(g|0)){t=B+s|0;u=u+n|0;v=v+m|0;w=w+l|0;x=z}else{break}}i=k;return g|0};case 27:{C=1;D=15;break};case 29:{E=1;D=22;break};case 30:{E=0;D=22;break};case 2:{x=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}w=(x|0)>0;v=x*3|0;u=(c[e>>2]|0)-v|0;s=c[d>>2]|0;B=j;t=o;r=p;h=0;while(1){if(w){q=s;z=0;while(1){a[r+z|0]=a[q]|0;a[t+z|0]=a[q+1|0]|0;a[B+z|0]=a[q+2|0]|0;y=z+1|0;if((y|0)<(x|0)){q=q+3|0;z=y}else{break}}F=s+v|0}else{F=s}z=h+1|0;if((z|0)<(g|0)){s=F+u|0;B=B+l|0;t=t+m|0;r=r+n|0;h=z}else{break}}i=k;return g|0};case 28:{C=0;D=15;break};default:{h=mKb(f)|0;f=mKb(c[b+52>>2]|0)|0;KIb(b,16,2165800,(r=i,i=i+16|0,c[r>>2]=h,c[r+8>>2]=f,r)|0);i=r;i=k;return g|0}}if((D|0)==15){r=c[d>>2]|0;f=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}h=(f|0)>0;t=f<<2;B=(c[e>>2]|0)-t|0;u=(C|0)==0?r:r+1|0;r=j;C=o;F=p;s=0;while(1){if(h){v=u;x=0;while(1){a[F+x|0]=a[v]|0;a[C+x|0]=a[v+1|0]|0;a[r+x|0]=a[v+2|0]|0;w=x+1|0;if((w|0)<(f|0)){v=v+4|0;x=w}else{break}}G=u+t|0}else{G=u}x=s+1|0;if((x|0)<(g|0)){u=G+B|0;r=r+l|0;C=C+m|0;F=F+n|0;s=x}else{break}}i=k;return g|0}else if((D|0)==22){D=c[d>>2]|0;d=c[b+8>>2]|0;if((g|0)<=0){i=k;return g|0}b=(d|0)>0;s=d<<2;F=(c[e>>2]|0)-s|0;e=(E|0)==0?D:D+1|0;D=p;p=o;o=j;j=0;while(1){if(b){E=e;C=0;while(1){a[o+C|0]=a[E]|0;a[p+C|0]=a[E+1|0]|0;a[D+C|0]=a[E+2|0]|0;r=C+1|0;if((r|0)<(d|0)){E=E+4|0;C=r}else{break}}H=e+s|0}else{H=e}C=j+1|0;if((C|0)<(g|0)){e=H+F|0;D=D+n|0;p=p+m|0;o=o+l|0;j=C}else{break}}i=k;return g|0}return 0}function $Db(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=c[g>>2]|0;g=c[b>>2]|0;switch(c[a+56>>2]|0){case 328:{i=660;j=506;break};case 332:{i=126;j=510;break};case 331:{i=648;j=434;break};case 330:{i=42;j=566;break};case 326:{i=8;j=522;break};case 322:{i=426;j=248;break};case 325:{i=366;j=346;break};case 329:{i=238;j=98;break};case 321:{i=612;j=242;break};case 323:{i=526;j=448;break};case 327:{i=348;j=504;break};case 324:{i=694;j=604;break};default:{k=0;return k|0}}b=a+8|0;pe[j&1023](g,c[d>>2]|0,e,c[h>>2]|0,c[b>>2]|0);a=c[d>>2]|0;l=g+(a<<1)|0;g=c[h>>2]|0;m=e+(g<<1)|0;e=f-2|0;n=c[b>>2]|0;if((e|0)>2){o=m;p=l;q=2;r=a;s=g;t=n;while(1){pe[i&1023](p,r,o,s,t);u=c[d>>2]|0;v=p+(u<<1)|0;w=c[h>>2]|0;x=o+(w<<1)|0;y=q+2|0;z=c[b>>2]|0;if((y|0)<(e|0)){o=x;p=v;q=y;r=u;s=w;t=z}else{A=x;B=v;C=u;D=w;E=z;break}}}else{A=m;B=l;C=a;D=g;E=n}pe[j&1023](B,C,A,D,E);k=f;return k|0}function aEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;e=c[b>>2]|0;b=c[g>>2]|0;i=c[g+4>>2]|0;j=c[g+8>>2]|0;switch(c[a+56>>2]|0){case 329:{k=96;l=30;break};case 325:{k=42;l=56;break};case 326:{k=98;l=122;break};case 321:{k=104;l=58;break};case 327:{k=128;l=64;break};case 331:{k=46;l=40;break};case 324:{k=26;l=34;break};case 332:{k=24;l=82;break};case 328:{k=92;l=114;break};case 323:{k=50;l=38;break};case 330:{k=48;l=130;break};case 322:{k=16;l=68;break};default:{m=0;return m|0}}g=a+8|0;n=a+10496|0;Ge[l&255](e,c[d>>2]|0,b,i,j,c[h>>2]|0,c[g>>2]|0,n);a=c[d>>2]|0;o=e+(a<<1)|0;e=c[h>>2]|0;p=b+(e<<1)|0;b=h+4|0;q=c[b>>2]|0;r=i+q|0;i=j+q|0;q=f-2|0;j=c[g>>2]|0;if((q|0)>2){s=o;t=p;u=r;v=i;w=2;x=a;y=e;z=j;while(1){Ge[k&255](s,x,t,u,v,y,z,n);A=c[d>>2]|0;B=s+(A<<1)|0;C=c[h>>2]|0;D=t+(C<<1)|0;E=c[b>>2]|0;F=u+E|0;G=v+E|0;E=w+2|0;H=c[g>>2]|0;if((E|0)<(q|0)){s=B;t=D;u=F;v=G;w=E;x=A;y=C;z=H}else{I=B;J=D;K=F;L=G;M=A;N=C;O=H;break}}}else{I=o;J=p;K=r;L=i;M=a;N=e;O=j}Ge[l&255](I,M,J,K,L,N,O,n);m=f;return m|0}function bEb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a+88|0;a=0;do{j=c[e+(a<<2)>>2]|0;k=(j|0)/2|0;l=c[i+(a<<2)>>2]|0;m=(l|0)/2|0;n=c[h+(a<<2)>>2]|0;o=n;p=c[d+(a<<2)>>2]|0;q=p;r=(j|0)>-2?k:-k|0;j=(l|0)>-2?m:-m|0;l=(r|0)>(j|0)?j:r;do{if(!((n|0)==0|(p|0)==0)){r=g>>c[f>>2];if((r|0)<=0){break}j=(l|0)>0;s=o;t=q;u=0;while(1){if(j){v=0;do{b[s+(v<<1)>>1]=he(b[t+(v<<1)>>1]|0)|0;v=v+1|0;}while((v|0)<(l|0))}v=u+1|0;if((v|0)<(r|0)){s=s+(m<<1)|0;t=t+(k<<1)|0;u=v}else{break}}}}while(0);a=a+1|0;}while((a|0)<4);return g|0}function cEb(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;l=c[b+56>>2]|0;m=c[b+52>>2]|0;n=(c[h>>2]|0)+(ca(c[j>>2]|0,f)|0)|0;f=c[d>>2]|0;a:do{if((l|0)==66){switch(m|0){case 27:{o=154;break a;break};case 2:{o=620;break a;break};case 29:{o=154;break a;break};case 3:{o=620;break a;break};case 30:case 28:{o=130;break a;break};default:{p=15;break a}}}else{d=qKb(l)|0;if((d|0)==0){KIb(0,0,2579568,(q=i,i=i+24|0,c[q>>2]=2287848,c[q+8>>2]=2237984,c[q+16>>2]=828,q)|0);i=q;Hd();return 0}if((a[d+7|0]&66)==0){p=15;break}switch(m|0){case 3:{o=704;break a;break};case 2:{o=704;break a;break};case 30:case 28:case 27:case 29:{o=210;break a;break};default:{p=15;break a}}}}while(0);if((p|0)==15){p=mKb(l)|0;l=mKb(m)|0;KIb(b,16,2197400,(q=i,i=i+16|0,c[q>>2]=p,c[q+8>>2]=l,q)|0);i=q;i=k;return g|0}if((g|0)<=0){i=k;return g|0}q=b+8|0;l=b+1144|0;b=0;p=n;n=f;while(1){mf[o&2047](n,p,c[q>>2]|0,l);f=b+1|0;if((f|0)<(g|0)){b=f;p=p+(c[j>>2]|0)|0;n=n+(c[e>>2]|0)|0}else{break}}i=k;return g|0}function dEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;i=c[h>>2]|0;h=(c[g>>2]|0)+(ca(i,e)|0)|0;Te[c[664908]&255](c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,h,c[a+8>>2]|0,f,c[d>>2]|0,c[d+4>>2]|0,i);return f|0}function eEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;i=c[h>>2]|0;h=(c[g>>2]|0)+(ca(i,e)|0)|0;Te[c[664910]&255](c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,h,c[a+8>>2]|0,f,c[d>>2]|0,c[d+4>>2]|0,i);return f|0}function fEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;i=c[h>>2]|0;h=(c[g>>2]|0)+(ca(i,e)|0)|0;Te[c[664898]&255](c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,h,c[a+8>>2]|0,f,c[d>>2]|0,c[d+4>>2]|0,i);return f|0}function gEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;i=c[h>>2]|0;h=(c[g>>2]|0)+(ca(i,e)|0)|0;Te[c[664900]&255](c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,h,c[a+8>>2]|0,f,c[d>>2]|0,c[d+4>>2]|0,i);return f|0}function hEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ca(i,e)|0)|0;k=c[h+4>>2]|0;l=(c[g+4>>2]|0)+((ca(k,e)|0)/2|0)|0;m=(c[g+8>>2]|0)+((ca(c[h+8>>2]|0,e)|0)/2|0)|0;n=a+8|0;Te[c[664904]&255](j,l,m,c[b>>2]|0,c[n>>2]|0,f,i,k,c[d>>2]|0);d=c[g+12>>2]|0;if((d|0)==0){return f|0}g=c[h+12>>2]|0;h=c[n>>2]|0;if((f|0)<=0){return f|0}n=0;k=d+(ca(g,e)|0)|0;while(1){mrc(k|0,-1|0,h|0)|0;e=n+1|0;if((e|0)<(f|0)){n=e;k=k+g|0}else{break}}return f|0}function iEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ca(i,e)|0)|0;k=c[h+4>>2]|0;l=(c[g+4>>2]|0)+((ca(k,e)|0)/2|0)|0;m=(c[g+8>>2]|0)+((ca(c[h+8>>2]|0,e)|0)/2|0)|0;n=a+8|0;Te[c[847034]&255](j,l,m,c[b>>2]|0,c[n>>2]|0,f,i,k,c[d>>2]|0);d=c[g+12>>2]|0;if((d|0)==0){return f|0}g=c[h+12>>2]|0;h=c[n>>2]|0;if((f|0)<=0){return f|0}n=0;k=d+(ca(g,e)|0)|0;while(1){mrc(k|0,-1|0,h|0)|0;e=n+1|0;if((e|0)<(f|0)){n=e;k=k+g|0}else{break}}return f|0}function jEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ca(i,e)|0)|0;k=c[h+4>>2]|0;l=(c[g+4>>2]|0)+(ca(k,e)|0)|0;m=(c[g+8>>2]|0)+(ca(c[h+8>>2]|0,e)|0)|0;Te[c[664902]&255](j,l,m,c[b>>2]|0,c[a+8>>2]|0,f,i,k,c[d>>2]|0);return f|0}function kEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=c[h>>2]|0;j=(c[g>>2]|0)+(ca(i,e)|0)|0;k=c[h+4>>2]|0;l=(c[g+4>>2]|0)+(ca(k,e)|0)|0;m=(c[g+8>>2]|0)+(ca(c[h+8>>2]|0,e)|0)|0;Te[c[847032]&255](j,l,m,c[b>>2]|0,c[a+8>>2]|0,f,i,k,c[d>>2]|0);return f|0}function lEb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[h>>2]|0;j=c[d>>2]|0;if((i|0)==(j|0)&(j|0)>0){k=(c[g>>2]|0)+(ca(i,e)|0)|0;nrc(k|0,c[b>>2]|0,ca(i,f)|0)|0;return f|0}k=c[b>>2]|0;b=(c[g>>2]|0)+(ca(i,e)|0)|0;e=c[a+8>>2]|0;a=(i|0)>-1?i:-i|0;i=0;while(1){g=e+i|0;if((g|0)>(a|0)){break}if((g|0)>(((j|0)>-1?j:-j|0)|0)){break}else{i=g}}if((f|0)>0){l=0;m=k;n=b}else{return f|0}while(1){nrc(n|0,m|0,i)|0;b=l+1|0;if((b|0)<(f|0)){l=b;m=m+(c[d>>2]|0)|0;n=n+(c[h>>2]|0)|0}else{break}}return f|0}function mEb(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;n=i;o=f+56|0;p=qKb(c[o>>2]|0)|0;q=f+52|0;r=qKb(c[q>>2]|0)|0;s=f+8|0;t=f+84|0;u=-j|0;v=f+88|0;w=-k|0;x=l+8|0;z=g+8|0;A=p+8|0;B=f+11260|0;f=0;a:while(1){C=(f|0)==3;D=c[s>>2]|0;if((f|0)==3|(f|0)==0){E=D}else{E=-(-D>>c[t>>2])|0}if((f|0)==3|(f|0)==0){F=j}else{F=-(u>>c[v>>2])|0}if((f|0)==3|(f|0)==0){G=k}else{G=-(w>>c[v>>2])|0}D=g+(f<<2)|0;H=c[D>>2]|0;I=l+(f<<2)|0;J=c[I>>2]|0;K=m+(f<<2)|0;L=J+(ca(c[K>>2]|0,F)|0)|0;M=(f|0)==1;if((f-1|0)>>>0<2>>>0){N=1}else{N=(c[B>>2]|f|0)==0}b:do{if((J|0)!=0){do{if(M){if((c[x>>2]|0)!=0){break}f=f+1|0;continue a}}while(0);do{if((H|0)!=0){if(M){if((c[z>>2]|0)==0){break}}O=qKb(c[o>>2]|0)|0;if((O|0)==0){P=40;break a}do{if(!((((e[O+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0)){Q=qKb(c[q>>2]|0)|0;if((Q|0)==0){P=43;break a}if((((e[Q+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){break}Q=qKb(c[o>>2]|0)|0;if((Q|0)==0){P=46;break a}R=b[Q+8>>1]|0;Q=qKb(c[q>>2]|0)|0;if((Q|0)==0){P=48;break a}if((R&30720)==30720^(b[Q+8>>1]&30720)==30720){break}Q=qKb(c[o>>2]|0)|0;if((Q|0)==0){P=169;break a}do{if((b[Q+8>>1]&30720)==30720){R=qKb(c[q>>2]|0)|0;if((R|0)==0){P=172;break a}if(!((b[R+8>>1]&30720)==30720)){break}R=qKb(c[o>>2]|0)|0;if((R|0)==0){P=175;break a}S=a[R+7|0]|0;R=qKb(c[q>>2]|0)|0;if((R|0)==0){P=177;break a}if(((a[R+7|0]^S)&1)==0){break}if((G|0)<=0){break b}S=(E|0)>0;R=c[h+(f<<2)>>2]|0;T=c[K>>2]|0;U=L;V=H;W=0;while(1){if(S){X=V;Y=U;Z=0;do{b[Y+(Z<<1)>>1]=he(b[X+(Z<<1)>>1]|0)|0;Z=Z+1|0;}while((Z|0)<(E|0))}Z=W+1|0;if((Z|0)<(G|0)){U=U+T|0;V=V+R|0;W=Z}else{break b}}}}while(0);Q=c[K>>2]|0;W=h+(f<<2)|0;R=c[W>>2]|0;if((Q|0)==(R|0)&(R|0)>0&(R|0)==(E|0)){R=(c[I>>2]|0)+(ca(Q,F)|0)|0;nrc(R|0,c[D>>2]|0,ca(Q,G)|0)|0;break b}Q=qKb(c[o>>2]|0)|0;if((Q|0)==0){P=188;break a}do{if((b[Q+8>>1]&30720)==30720){R=qKb(c[q>>2]|0)|0;if((R|0)==0){P=191;break a}if(!((b[R+8>>1]&30720)==30720)){P=194;break}_=E<<1}else{P=194}}while(0);if((P|0)==194){P=0;_=(b[A>>1]&30720)==0?E>>3:E}if((G|0)>0){$=L;aa=H;ba=0}else{break b}while(1){nrc($|0,aa|0,_)|0;Q=ba+1|0;if((Q|0)<(G|0)){$=$+(c[K>>2]|0)|0;aa=aa+(c[W>>2]|0)|0;ba=Q}else{break b}}}}while(0);O=(e[p+8+(f<<1)>>1]|0)>>>11&15;W=O+1|0;Q=(e[r+8+(f<<1)>>1]|0)>>>11&15;R=Q+1|0;V=H;T=L;if((R|0)==8){U=qKb(c[o>>2]|0)|0;if((U|0)==0){P=52;break a}S=b[1531568+(Q<<5)+(O<<1)>>1]|0;Z=(e[1531568+(O-1<<5)+(Q<<1)>>1]|0)+(O-7)|0;X=(G|0)>0;if((a[U+7|0]&1)==0){if(!X){break b}U=O-8|0;Y=E-7|0;da=(Y|0)>0;ea=h+(f<<2)|0;fa=S&65535;ga=V;ha=L;ia=0;while(1){ja=ia&7;if(da){ka=d[1531016+(U<<6)+(ja<<3)|0]|0;la=d[1531016+(U<<6)+(ja<<3)+1|0]|0;ma=d[1531016+(U<<6)+(ja<<3)+2|0]|0;na=d[1531016+(U<<6)+(ja<<3)+3|0]|0;oa=d[1531016+(U<<6)+(ja<<3)+4|0]|0;pa=d[1531016+(U<<6)+(ja<<3)+5|0]|0;qa=d[1531016+(U<<6)+(ja<<3)+6|0]|0;ra=d[1531016+(U<<6)+(ja<<3)+7|0]|0;sa=0;while(1){a[ha+sa|0]=(ca(ka+(e[ga+(sa<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|1;a[ha+ta|0]=(ca(la+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|2;a[ha+ta|0]=(ca(ma+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|3;a[ha+ta|0]=(ca(na+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|4;a[ha+ta|0]=(ca(oa+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|5;a[ha+ta|0]=(ca(pa+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|6;a[ha+ta|0]=(ca(qa+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa|7;a[ha+ta|0]=(ca(ra+(e[ga+(ta<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);ta=sa+8|0;if((ta|0)<(Y|0)){sa=ta}else{ua=ta;break}}}else{ua=0}if((ua|0)<(E|0)){sa=ua;do{a[ha+sa|0]=(ca((d[(sa&7)+(1531016+(U<<6)+(ja<<3))|0]|0)+(e[ga+(sa<<1)>>1]|0)|0,fa)|0)>>>(Z>>>0);sa=sa+1|0;}while((sa|0)<(E|0))}sa=ia+1|0;if((sa|0)<(G|0)){ga=ga+(((c[ea>>2]|0)/2|0)<<1)|0;ha=ha+(c[K>>2]|0)|0;ia=sa}else{break b}}}else{if(!X){break b}ia=O-8|0;ha=E-7|0;ea=(ha|0)>0;ga=h+(f<<2)|0;fa=S&65535;U=V;Y=L;da=0;while(1){sa=da&7;if(ea){ja=d[1531016+(ia<<6)+(sa<<3)|0]|0;ra=d[1531016+(ia<<6)+(sa<<3)+1|0]|0;qa=d[1531016+(ia<<6)+(sa<<3)+2|0]|0;pa=d[1531016+(ia<<6)+(sa<<3)+3|0]|0;oa=d[1531016+(ia<<6)+(sa<<3)+4|0]|0;na=d[1531016+(ia<<6)+(sa<<3)+5|0]|0;ma=d[1531016+(ia<<6)+(sa<<3)+6|0]|0;la=d[1531016+(ia<<6)+(sa<<3)+7|0]|0;ka=0;while(1){a[Y+ka|0]=(ca(ja+((he(b[U+(ka<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|1;a[Y+ta|0]=(ca(ra+((he(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|2;a[Y+ta|0]=(ca(qa+((he(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|3;a[Y+ta|0]=(ca(pa+((he(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|4;a[Y+ta|0]=(ca(oa+((he(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|5;a[Y+ta|0]=(ca(na+((he(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|6;a[Y+ta|0]=(ca(ma+((he(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka|7;a[Y+ta|0]=(ca(la+((he(b[U+(ta<<1)>>1]|0)|0)&65535)|0,fa)|0)>>>(Z>>>0);ta=ka+8|0;if((ta|0)<(ha|0)){ka=ta}else{va=ta;break}}}else{va=0}if((va|0)<(E|0)){ka=va;do{la=(he(b[U+(ka<<1)>>1]|0)|0)&65535;a[Y+ka|0]=(ca((d[(ka&7)+(1531016+(ia<<6)+(sa<<3))|0]|0)+la|0,fa)|0)>>>(Z>>>0);ka=ka+1|0;}while((ka|0)<(E|0))}ka=da+1|0;if((ka|0)<(G|0)){U=U+(((c[ga>>2]|0)/2|0)<<1)|0;Y=Y+(c[K>>2]|0)|0;da=ka}else{break b}}}}if((W|0)==8){if((G|0)<=0){break b}da=(E|0)>0;Y=Q-7|0;ga=Q^15;U=h+(f<<2)|0;Z=T;fa=H;ia=0;while(1){ha=qKb(c[q>>2]|0)|0;if((ha|0)==0){P=74;break a}do{if((a[ha+7|0]&1)==0){if(N){if(da){wa=0}else{break}do{ea=Z+(wa<<1)|0;y=(d[fa+wa|0]|0)<<Y&65535;a[ea]=y;y=y>>8;a[ea+1|0]=y;wa=wa+1|0;}while((wa|0)<(E|0))}else{if(da){xa=0}else{break}do{ea=d[fa+xa|0]|0;S=Z+(xa<<1)|0;y=(ea<<Y|ea>>>(ga>>>0))&65535;a[S]=y;y=y>>8;a[S+1|0]=y;xa=xa+1|0;}while((xa|0)<(E|0))}}else{if(N){if(da){ya=0}else{break}do{S=Z+(ya<<1)|0;y=he((d[fa+ya|0]|0)<<Y&65535|0)|0;a[S]=y;y=y>>8;a[S+1|0]=y;ya=ya+1|0;}while((ya|0)<(E|0))}else{if(da){za=0}else{break}do{S=d[fa+za|0]|0;ea=Z+(za<<1)|0;y=he((S<<Y|S>>>(ga>>>0))&65535|0)|0;a[ea]=y;y=y>>8;a[ea+1|0]=y;za=za+1|0;}while((za|0)<(E|0))}}}while(0);ha=ia+1|0;if((ha|0)<(G|0)){Z=Z+(((c[K>>2]|0)/2|0)<<1)|0;fa=fa+(c[U>>2]|0)|0;ia=ha}else{break b}}}if(W>>>0>R>>>0){ia=qKb(c[o>>2]|0)|0;if((ia|0)==0){P=130;break a}U=a[ia+7|0]|0;ia=qKb(c[q>>2]|0)|0;if((ia|0)==0){P=132;break a}fa=(a[ia+7|0]&1)==0;ia=b[1531568+(Q<<5)+(O<<1)>>1]|0;Z=(e[1531568+(O-1<<5)+(Q<<1)>>1]|0)+(W-R)|0;ga=(G|0)>0;if((U&1)==0){if(fa){if(!ga){break b}U=O-8|0;Y=E-7|0;da=(Y|0)>0;ha=h+(f<<2)|0;ea=ia&65535;S=T;X=V;ka=0;while(1){sa=ka&7;if(da){la=d[1531016+(U<<6)+(sa<<3)|0]|0;ma=d[1531016+(U<<6)+(sa<<3)+1|0]|0;na=d[1531016+(U<<6)+(sa<<3)+2|0]|0;oa=d[1531016+(U<<6)+(sa<<3)+3|0]|0;pa=d[1531016+(U<<6)+(sa<<3)+4|0]|0;qa=d[1531016+(U<<6)+(sa<<3)+5|0]|0;ra=d[1531016+(U<<6)+(sa<<3)+6|0]|0;ja=d[1531016+(U<<6)+(sa<<3)+7|0]|0;ta=0;while(1){b[S+(ta<<1)>>1]=(ca(la+(e[X+(ta<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|1;b[S+(Aa<<1)>>1]=(ca(ma+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|2;b[S+(Aa<<1)>>1]=(ca(na+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|3;b[S+(Aa<<1)>>1]=(ca(oa+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|4;b[S+(Aa<<1)>>1]=(ca(pa+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|5;b[S+(Aa<<1)>>1]=(ca(qa+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|6;b[S+(Aa<<1)>>1]=(ca(ra+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta|7;b[S+(Aa<<1)>>1]=(ca(ja+(e[X+(Aa<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);Aa=ta+8|0;if((Aa|0)<(Y|0)){ta=Aa}else{Ba=Aa;break}}}else{Ba=0}if((Ba|0)<(E|0)){ta=Ba;do{b[S+(ta<<1)>>1]=(ca((d[(ta&7)+(1531016+(U<<6)+(sa<<3))|0]|0)+(e[X+(ta<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0);ta=ta+1|0;}while((ta|0)<(E|0))}ta=ka+1|0;if((ta|0)<(G|0)){S=S+(((c[K>>2]|0)/2|0)<<1)|0;X=X+(((c[ha>>2]|0)/2|0)<<1)|0;ka=ta}else{break b}}}else{if(!ga){break b}ka=O-8|0;ha=E-7|0;X=(ha|0)>0;S=h+(f<<2)|0;ea=ia&65535;U=T;Y=V;da=0;while(1){Q=da&7;if(X){ta=d[1531016+(ka<<6)+(Q<<3)|0]|0;sa=d[1531016+(ka<<6)+(Q<<3)+1|0]|0;ja=d[1531016+(ka<<6)+(Q<<3)+2|0]|0;ra=d[1531016+(ka<<6)+(Q<<3)+3|0]|0;qa=d[1531016+(ka<<6)+(Q<<3)+4|0]|0;pa=d[1531016+(ka<<6)+(Q<<3)+5|0]|0;oa=d[1531016+(ka<<6)+(Q<<3)+6|0]|0;na=d[1531016+(ka<<6)+(Q<<3)+7|0]|0;ma=0;while(1){b[U+(ma<<1)>>1]=he((ca(ta+(e[Y+(ma<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|1;b[U+(la<<1)>>1]=he((ca(sa+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|2;b[U+(la<<1)>>1]=he((ca(ja+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|3;b[U+(la<<1)>>1]=he((ca(ra+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|4;b[U+(la<<1)>>1]=he((ca(qa+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|5;b[U+(la<<1)>>1]=he((ca(pa+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|6;b[U+(la<<1)>>1]=he((ca(oa+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma|7;b[U+(la<<1)>>1]=he((ca(na+(e[Y+(la<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;la=ma+8|0;if((la|0)<(ha|0)){ma=la}else{Ca=la;break}}}else{Ca=0}if((Ca|0)<(E|0)){ma=Ca;do{b[U+(ma<<1)>>1]=he((ca((d[(ma&7)+(1531016+(ka<<6)+(Q<<3))|0]|0)+(e[Y+(ma<<1)>>1]|0)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;ma=ma+1|0;}while((ma|0)<(E|0))}ma=da+1|0;if((ma|0)<(G|0)){U=U+(((c[K>>2]|0)/2|0)<<1)|0;Y=Y+(((c[S>>2]|0)/2|0)<<1)|0;da=ma}else{break b}}}}else{if(fa){if(!ga){break b}da=O-8|0;S=E-7|0;Y=(S|0)>0;U=h+(f<<2)|0;ea=ia&65535;ka=T;ha=V;X=0;while(1){ma=X&7;if(Y){Q=d[1531016+(da<<6)+(ma<<3)|0]|0;na=d[1531016+(da<<6)+(ma<<3)+1|0]|0;oa=d[1531016+(da<<6)+(ma<<3)+2|0]|0;pa=d[1531016+(da<<6)+(ma<<3)+3|0]|0;qa=d[1531016+(da<<6)+(ma<<3)+4|0]|0;ra=d[1531016+(da<<6)+(ma<<3)+5|0]|0;ja=d[1531016+(da<<6)+(ma<<3)+6|0]|0;sa=d[1531016+(da<<6)+(ma<<3)+7|0]|0;ta=0;while(1){b[ka+(ta<<1)>>1]=(ca(Q+((he(b[ha+(ta<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|1;b[ka+(la<<1)>>1]=(ca(na+((he(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|2;b[ka+(la<<1)>>1]=(ca(oa+((he(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|3;b[ka+(la<<1)>>1]=(ca(pa+((he(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|4;b[ka+(la<<1)>>1]=(ca(qa+((he(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|5;b[ka+(la<<1)>>1]=(ca(ra+((he(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|6;b[ka+(la<<1)>>1]=(ca(ja+((he(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta|7;b[ka+(la<<1)>>1]=(ca(sa+((he(b[ha+(la<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0);la=ta+8|0;if((la|0)<(S|0)){ta=la}else{Da=la;break}}}else{Da=0}if((Da|0)<(E|0)){ta=Da;do{sa=(he(b[ha+(ta<<1)>>1]|0)|0)&65535;b[ka+(ta<<1)>>1]=(ca((d[(ta&7)+(1531016+(da<<6)+(ma<<3))|0]|0)+sa|0,ea)|0)>>>(Z>>>0);ta=ta+1|0;}while((ta|0)<(E|0))}ta=X+1|0;if((ta|0)<(G|0)){ka=ka+(((c[K>>2]|0)/2|0)<<1)|0;ha=ha+(((c[U>>2]|0)/2|0)<<1)|0;X=ta}else{break b}}}else{if(!ga){break b}X=O-8|0;U=E-7|0;ha=(U|0)>0;ka=h+(f<<2)|0;ea=ia&65535;da=T;S=V;Y=0;while(1){fa=Y&7;if(ha){ta=d[1531016+(X<<6)+(fa<<3)|0]|0;ma=d[1531016+(X<<6)+(fa<<3)+1|0]|0;sa=d[1531016+(X<<6)+(fa<<3)+2|0]|0;ja=d[1531016+(X<<6)+(fa<<3)+3|0]|0;ra=d[1531016+(X<<6)+(fa<<3)+4|0]|0;qa=d[1531016+(X<<6)+(fa<<3)+5|0]|0;pa=d[1531016+(X<<6)+(fa<<3)+6|0]|0;oa=d[1531016+(X<<6)+(fa<<3)+7|0]|0;na=0;while(1){b[da+(na<<1)>>1]=he((ca(ta+((he(b[S+(na<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|1;b[da+(Q<<1)>>1]=he((ca(ma+((he(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|2;b[da+(Q<<1)>>1]=he((ca(sa+((he(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|3;b[da+(Q<<1)>>1]=he((ca(ja+((he(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|4;b[da+(Q<<1)>>1]=he((ca(ra+((he(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|5;b[da+(Q<<1)>>1]=he((ca(qa+((he(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|6;b[da+(Q<<1)>>1]=he((ca(pa+((he(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na|7;b[da+(Q<<1)>>1]=he((ca(oa+((he(b[S+(Q<<1)>>1]|0)|0)&65535)|0,ea)|0)>>>(Z>>>0)&65535|0)|0;Q=na+8|0;if((Q|0)<(U|0)){na=Q}else{Ea=Q;break}}}else{Ea=0}if((Ea|0)<(E|0)){na=Ea;do{oa=(he(b[S+(na<<1)>>1]|0)|0)&65535;b[da+(na<<1)>>1]=he((ca((d[(na&7)+(1531016+(X<<6)+(fa<<3))|0]|0)+oa|0,ea)|0)>>>(Z>>>0)&65535|0)|0;na=na+1|0;}while((na|0)<(E|0))}na=Y+1|0;if((na|0)<(G|0)){da=da+(((c[K>>2]|0)/2|0)<<1)|0;S=S+(((c[ka>>2]|0)/2|0)<<1)|0;Y=na}else{break b}}}}}else{if((G|0)<=0){break b}Y=N^1;ka=R-W|0;S=E-1|0;da=(S|0)>0;Z=(W<<1)-R|0;ea=h+(f<<2)|0;X=T;U=V;ha=0;while(1){ia=qKb(c[o>>2]|0)|0;if((ia|0)==0){P=91;break a}do{if((a[ia+7|0]&1)==0){O=qKb(c[q>>2]|0)|0;if((O|0)==0){P=94;break a}if((a[O+7|0]&1)!=0|Y){Fa=0;break}if((ka|0)==6){if(da){Ga=0}else{Fa=0;break}while(1){c[X+(Ga<<1)>>2]=c[U+(Ga<<1)>>2]<<6;O=Ga+2|0;if((O|0)<(S|0)){Ga=O}else{Fa=O;break}}}else if((ka|0)==7){if(da){Ha=0}else{Fa=0;break}while(1){c[X+(Ha<<1)>>2]=c[U+(Ha<<1)>>2]<<7;O=Ha+2|0;if((O|0)<(S|0)){Ha=O}else{Fa=O;break}}}else{Fa=0;break}}else{Fa=0}}while(0);ia=qKb(c[o>>2]|0)|0;if((ia|0)==0){P=102;break a}O=a[ia+7|0]|0;ia=qKb(c[q>>2]|0)|0;if((ia|0)==0){P=104;break a}ga=(a[ia+7|0]&1)!=0;ia=(Fa|0)<(E|0);do{if((O&1)==0){if(ga){if(N){if(ia){Ia=Fa}else{break}do{na=U+(Ia<<1)|0;fa=X+(Ia<<1)|0;y=he(((d[na]|d[na+1|0]<<8)<<16>>16&65535)<<ka&65535|0)|0;a[fa]=y;y=y>>8;a[fa+1|0]=y;Ia=Ia+1|0;}while((Ia|0)<(E|0))}else{if(ia){Ja=Fa}else{break}do{fa=U+(Ja<<1)|0;na=(d[fa]|d[fa+1|0]<<8)<<16>>16&65535;fa=X+(Ja<<1)|0;y=he((na<<ka|na>>>(Z>>>0))&65535|0)|0;a[fa]=y;y=y>>8;a[fa+1|0]=y;Ja=Ja+1|0;}while((Ja|0)<(E|0))}}else{if(N){if(ia){Ka=Fa}else{break}do{fa=U+(Ka<<1)|0;na=X+(Ka<<1)|0;y=((d[fa]|d[fa+1|0]<<8)<<16>>16&65535)<<ka&65535;a[na]=y;y=y>>8;a[na+1|0]=y;Ka=Ka+1|0;}while((Ka|0)<(E|0))}else{if(ia){La=Fa}else{break}do{na=U+(La<<1)|0;fa=(d[na]|d[na+1|0]<<8)<<16>>16&65535;na=X+(La<<1)|0;y=(fa<<ka|fa>>>(Z>>>0))&65535;a[na]=y;y=y>>8;a[na+1|0]=y;La=La+1|0;}while((La|0)<(E|0))}}}else{if(ga){if(N){if(ia){Ma=Fa}else{break}do{na=U+(Ma<<1)|0;fa=X+(Ma<<1)|0;y=he(((he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ka&65535|0)|0;a[fa]=y;y=y>>8;a[fa+1|0]=y;Ma=Ma+1|0;}while((Ma|0)<(E|0))}else{if(ia){Na=Fa}else{break}do{fa=U+(Na<<1)|0;na=(he((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535;fa=X+(Na<<1)|0;y=he((na<<ka|na>>>(Z>>>0))&65535|0)|0;a[fa]=y;y=y>>8;a[fa+1|0]=y;Na=Na+1|0;}while((Na|0)<(E|0))}}else{if(N){if(ia){Oa=Fa}else{break}do{fa=U+(Oa<<1)|0;na=X+(Oa<<1)|0;y=((he((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535)<<ka&65535;a[na]=y;y=y>>8;a[na+1|0]=y;Oa=Oa+1|0;}while((Oa|0)<(E|0))}else{if(ia){Pa=Fa}else{break}do{na=U+(Pa<<1)|0;fa=(he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535;na=X+(Pa<<1)|0;y=(fa<<ka|fa>>>(Z>>>0))&65535;a[na]=y;y=y>>8;a[na+1|0]=y;Pa=Pa+1|0;}while((Pa|0)<(E|0))}}}}while(0);ia=ha+1|0;if((ia|0)<(G|0)){X=X+(((c[K>>2]|0)/2|0)<<1)|0;U=U+(((c[ea>>2]|0)/2|0)<<1)|0;ha=ia}else{break b}}}}}while(0);ha=qKb(c[q>>2]|0)|0;if((ha|0)==0){P=18;break a}do{if(!((b[ha+8>>1]&30720)==30720)){ea=qKb(c[q>>2]|0)|0;if((ea|0)==0){P=21;break a}if((((e[ea+8>>1]|0)>>>11&15)-8&65535)>>>0<6>>>0){break}ea=c[K>>2]|0;U=C?-1:-128;if((G|0)<=0){break b}X=0;Z=(c[I>>2]|0)+(ca(ea,F)|0)|0;while(1){mrc(Z|0,U|0,E|0)|0;ka=X+1|0;if((ka|0)<(G|0)){X=ka;Z=Z+ea|0}else{break b}}}}while(0);ha=c[I>>2]|0;ea=c[K>>2]|0;Z=(e[r+8+(f<<1)>>1]|0)>>>11&15;X=qKb(c[q>>2]|0)|0;if((X|0)==0){P=24;break a}U=ha+(ca(ea,F)|0)|0;if(C){Qa=65535>>>((Z^15)>>>0)&65535}else{Qa=1<<Z&65535}if((G|0)<=0){break}Z=(a[X+7|0]&1)==0;X=(E|0)>0;ha=he(Qa|0)|0;ka=U;U=0;while(1){do{if(Z){if(X){Ra=0}else{break}do{S=ka+(Ra<<1)|0;y=Qa;a[S]=y;y=y>>8;a[S+1|0]=y;Ra=Ra+1|0;}while((Ra|0)<(E|0))}else{if(X){Sa=0}else{break}do{S=ka+(Sa<<1)|0;y=ha;a[S]=y;y=y>>8;a[S+1|0]=y;Sa=Sa+1|0;}while((Sa|0)<(E|0))}}while(0);S=U+1|0;if((S|0)<(G|0)){ka=ka+ea|0;U=S}else{break}}}}while(0);C=f+1|0;if((C|0)<4){f=C}else{P=198;break}}if((P|0)==18){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=637,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==21){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=644,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==24){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==40){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=644,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==43){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=644,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==46){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=637,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==48){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=637,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==52){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==74){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==91){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==94){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==102){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==104){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==130){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==132){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==169){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=637,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==172){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=637,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==175){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==177){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=653,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==188){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=637,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==191){KIb(0,0,2579568,(Ta=i,i=i+24|0,c[Ta>>2]=2287848,c[Ta+8>>2]=2237984,c[Ta+16>>2]=637,Ta)|0);i=Ta;Hd();return 0}else if((P|0)==198){i=n;return k|0}return 0}function nEb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;if((e|0)<=0){return}g=f;f=b;b=0;do{c[f+(b<<2)>>2]=c[g+((d[a+b|0]|0)<<2)>>2];b=b+1|0;}while((b|0)<(e|0));return}function oEb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)>0){g=c;h=0}else{return}while(1){c=b+h|0;a[g]=a[f+((d[c]|0)<<2)|0]|0;a[g+1|0]=a[f+((d[c]|0)<<2|1)|0]|0;a[g+2|0]=a[f+((d[c]|0)<<2|2)|0]|0;c=h+1|0;if((c|0)<(e|0)){g=g+3|0;h=c}else{break}}return}function pEb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)<=0){return}g=f;f=b;b=0;do{h=b<<1;c[f+(b<<2)>>2]=(d[a+(h|1)|0]|0)<<24|c[g+((d[a+h|0]|0)<<2)>>2];b=b+1|0;}while((b|0)<(e|0));return}function qEb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)<=0){return}g=f;f=b;b=0;do{h=b<<1;c[f+(b<<2)>>2]=d[a+(h|1)|0]|0|c[g+((d[a+h|0]|0)<<2)>>2];b=b+1|0;}while((b|0)<(e|0));return}function rEb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)>0){g=c;h=0}else{return}while(1){c=b+(h<<1)|0;a[g]=a[f+((d[c]|0)<<2)|0]|0;a[g+1|0]=a[f+((d[c]|0)<<2|1)|0]|0;a[g+2|0]=a[f+((d[c]|0)<<2|2)|0]|0;c=h+1|0;if((c|0)<(e|0)){g=g+3|0;h=c}else{break}}return}function sEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+1|0;p=n+6|0;q=n+9|0;r=n+3|0;s=n|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=a[f+o|0]|0;a[p]=B;a[q]=B;a[r]=B;a[s]=B;B=f+1|0;a[t]=a[B]|0;C=f+e|0;D=((d[C]|0)+(d[B]|0)|0)>>>1&255;a[u]=D;a[v]=D;a[w]=a[C]|0;C=a[f]|0;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ve[c[1637278]&127](s,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+2|0;b=C}else{break}}i=m;return}function tEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;m=i;i=i+16|0;n=m|0;o=e+1|0;p=a[b+o|0]|0;q=n+6|0;a[q]=p;r=n+9|0;a[r]=p;s=n+3|0;a[s]=p;t=n|0;a[t]=p;p=a[b+1|0]|0;u=n+4|0;a[u]=p;v=a[b+e|0]|0;w=((v&255)+(p&255)|0)>>>1&255;p=n+10|0;a[p]=w;x=n+1|0;a[x]=w;w=n+7|0;a[w]=v;v=a[b]|0;y=n+8|0;a[y]=v;z=n+5|0;a[z]=v;A=n+2|0;a[A]=v;B=n+11|0;a[B]=v;Ve[c[1637278]&127](t,f,h,g,2,2,j,0,6,l);v=b+2|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=~e;D=1-e|0;E=e-1|0;F=e<<1;G=e+2|0;H=F|1;I=F+2|0;J=v;K=2;L=b;M=f;N=g;while(1){O=J+D|0;P=J+E|0;Q=J+o|0;a[t]=((d[O]|0)+(d[J+C|0]|0)+(d[P]|0)+(d[Q]|0)|0)>>>2;R=J+1|0;S=J+e|0;a[x]=((d[J-1|0]|0)+(d[J+n|0]|0)+(d[R]|0)+(d[S]|0)|0)>>>2;a[A]=a[J]|0;a[s]=((d[Q]|0)+(d[O]|0)|0)>>>1;a[u]=a[R]|0;O=J+2|0;a[z]=((d[O]|0)+(d[J]|0)|0)>>>1;a[q]=((d[Q]|0)+(d[P]|0)|0)>>>1;a[w]=a[S]|0;P=J+F|0;a[y]=((d[P]|0)+(d[J]|0)|0)>>>1;a[r]=a[Q]|0;a[p]=((d[S]|0)+(d[R]|0)+(d[J+G|0]|0)+(d[J+H|0]|0)|0)>>>2;a[B]=((d[O]|0)+(d[J]|0)+(d[P]|0)+(d[J+I|0]|0)|0)>>>2;Ve[c[1637278]&127](t,L,N,M,2,2,j,0,6,l);P=K+2|0;R=L+2|0;S=M+1|0;Q=N+1|0;if((P|0)<(h|0)){J=O;K=P;L=R;M=S;N=Q}else{T=O;U=R;V=S;W=Q;break}}}else{T=v;U=b;V=f;W=g}if((k|0)<=2){i=m;return}k=a[T+o|0]|0;a[q]=k;a[r]=k;a[s]=k;a[t]=k;k=T+1|0;a[u]=a[k]|0;u=T+e|0;e=((d[u]|0)+(d[k]|0)|0)>>>1&255;a[p]=e;a[x]=e;a[w]=a[u]|0;u=a[T]|0;a[y]=u;a[z]=u;a[A]=u;a[B]=u;Ve[c[1637278]&127](t,U,W,V,2,2,j,0,6,l);i=m;return}function uEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+2|0;p=n+6|0;q=n+9|0;r=n+3|0;s=n|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+o|0;C=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[p]=C;a[q]=C;a[r]=C;a[s]=C;C=f+2|0;a[t]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;B=f+e|0;D=(((d[B]|d[B+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[u]=D;a[v]=D;a[w]=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8;B=f;D=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ve[c[1637278]&127](s,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function vEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;m=i;i=i+16|0;n=m|0;o=e+2|0;p=b+o|0;q=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8&255;p=n+6|0;a[p]=q;r=n+9|0;a[r]=q;s=n+3|0;a[s]=q;t=n|0;a[t]=q;q=b+2|0;u=(d[q]|d[q+1|0]<<8)<<16>>16;q=n+4|0;a[q]=(u&65535)>>>8;v=b+e|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=((w&65535)+(u&65535)|0)>>>9&255;u=n+10|0;a[u]=v;x=n+1|0;a[x]=v;v=n+7|0;a[v]=(w&65535)>>>8;w=b;y=((d[w]|d[w+1|0]<<8)<<16>>16&65535)>>>8&255;w=n+8|0;a[w]=y;z=n+5|0;a[z]=y;A=n+2|0;a[A]=y;B=n+11|0;a[B]=y;Ve[c[1637278]&127](t,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=-2-e|0;D=2-e|0;E=e-2|0;F=e<<1;G=e+4|0;H=F+2|0;I=F+4|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+C|0;P=J+D|0;Q=J+E|0;R=J+o|0;a[t]=(((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+n|0;S=J-2|0;T=J+2|0;U=J+e|0;a[x]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[U]|d[U+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J;a[A]=((d[O]|d[O+1|0]<<8)<<16>>16&65535)>>>8;a[s]=(((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)|0)>>>9;a[q]=((d[T]|d[T+1|0]<<8)<<16>>16&65535)>>>8;P=J+4|0;S=P;a[z]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;a[p]=(((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)|0)>>>9;a[v]=((d[U]|d[U+1|0]<<8)<<16>>16&65535)>>>8;Q=J+F|0;a[w]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;a[r]=((d[R]|d[R+1|0]<<8)<<16>>16&65535)>>>8;R=J+G|0;V=J+H|0;a[u]=(((d[U]|d[U+1|0]<<8)<<16>>16&65535)+((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)|0)>>>10;V=J+I|0;a[B]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)|0)>>>10;Ve[c[1637278]&127](t,L,N,M,2,2,j,0,6,l);V=K+2|0;Q=L+2|0;O=M+1|0;S=N+1|0;if((V|0)<(h|0)){J=P;K=V;L=Q;M=O;N=S}else{W=P;X=Q;Y=O;Z=S;break}}}else{W=y;X=b;Y=f;Z=g}if((k|0)<=2){i=m;return}k=W+o|0;o=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[p]=o;a[r]=o;a[s]=o;a[t]=o;o=W+2|0;a[q]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;q=W+e|0;e=(((d[q]|d[q+1|0]<<8)<<16>>16&65535)+((d[o]|d[o+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[u]=e;a[x]=e;a[v]=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8;q=W;W=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8&255;a[w]=W;a[z]=W;a[A]=W;a[B]=W;Ve[c[1637278]&127](t,X,Z,Y,2,2,j,0,6,l);i=m;return}function wEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+2|0;p=n+6|0;q=n+9|0;r=n+3|0;s=n|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+o|0;C=(d[B]|d[B+1|0]<<8)<<16>>16&255;a[p]=C;a[q]=C;a[r]=C;a[s]=C;C=f+2|0;a[t]=(d[C]|d[C+1|0]<<8)<<16>>16;B=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=f+e|0;D=(((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+B|0)>>>9&255;a[u]=D;a[v]=D;a[w]=(d[C]|d[C+1|0]<<8)<<16>>16;C=f;D=(d[C]|d[C+1|0]<<8)<<16>>16&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ve[c[1637278]&127](s,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function xEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;m=i;i=i+16|0;n=m|0;o=e+2|0;p=b+o|0;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;p=n+6|0;a[p]=q;r=n+9|0;a[r]=q;s=n+3|0;a[s]=q;t=n|0;a[t]=q;q=b+2|0;u=(d[q]|d[q+1|0]<<8)<<16>>16;q=n+4|0;a[q]=u;v=(he(u|0)|0)&65535;u=b+e|0;w=(d[u]|d[u+1|0]<<8)<<16>>16;u=(((he(w|0)|0)&65535)+v|0)>>>9&255;v=n+10|0;a[v]=u;x=n+1|0;a[x]=u;u=n+7|0;a[u]=w;w=b;y=(d[w]|d[w+1|0]<<8)<<16>>16&255;w=n+8|0;a[w]=y;z=n+5|0;a[z]=y;A=n+2|0;a[A]=y;B=n+11|0;a[B]=y;Ve[c[1637278]&127](t,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=-2-e|0;D=2-e|0;E=e-2|0;F=e<<1;G=e+4|0;H=F+2|0;I=F+4|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+C|0;P=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=J+D|0;Q=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)+P|0;P=J+E|0;R=Q+((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0;Q=J+o|0;a[t]=(R+((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;R=J+n|0;S=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=J-2|0;T=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=J+2|0;R=T+((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0;T=J+e|0;a[x]=(R+((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;R=J;a[A]=(d[R]|d[R+1|0]<<8)<<16>>16;U=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;a[s]=(((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[q]=(d[S]|d[S+1|0]<<8)<<16>>16;U=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;O=J+4|0;V=O;a[z]=(((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;U=(he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535;a[p]=(((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[u]=(d[T]|d[T+1|0]<<8)<<16>>16;U=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;P=J+F|0;a[w]=(((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[r]=(d[Q]|d[Q+1|0]<<8)<<16>>16;Q=(he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+Q|0;Q=J+G|0;T=S+((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0;Q=J+H|0;a[v]=(T+((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;Q=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)+Q|0;Q=R+((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0;P=J+I|0;a[B]=(Q+((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;Ve[c[1637278]&127](t,L,N,M,2,2,j,0,6,l);P=K+2|0;Q=L+2|0;R=M+1|0;V=N+1|0;if((P|0)<(h|0)){J=O;K=P;L=Q;M=R;N=V}else{W=O;X=Q;Y=R;Z=V;break}}}else{W=y;X=b;Y=f;Z=g}if((k|0)<=2){i=m;return}k=W+o|0;o=(d[k]|d[k+1|0]<<8)<<16>>16&255;a[p]=o;a[r]=o;a[s]=o;a[t]=o;o=W+2|0;a[q]=(d[o]|d[o+1|0]<<8)<<16>>16;q=(he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;o=W+e|0;e=(((he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)+q|0)>>>9&255;a[v]=e;a[x]=e;a[u]=(d[o]|d[o+1|0]<<8)<<16>>16;o=W;W=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[w]=W;a[z]=W;a[A]=W;a[B]=W;Ve[c[1637278]&127](t,X,Z,Y,2,2,j,0,6,l);i=m;return}function yEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+1|0;p=n+8|0;q=n+11|0;r=n+5|0;s=n+2|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=a[f+o|0]|0;a[p]=B;a[q]=B;a[r]=B;a[s]=B;B=f+1|0;a[t]=a[B]|0;C=f+e|0;D=((d[C]|0)+(d[B]|0)|0)>>>1&255;a[u]=D;a[v]=D;a[w]=a[C]|0;C=a[f]|0;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ve[c[1637278]&127](z,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+2|0;b=C}else{break}}i=m;return}function zEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;m=i;i=i+16|0;n=m|0;o=e+1|0;p=a[b+o|0]|0;q=n+8|0;a[q]=p;r=n+11|0;a[r]=p;s=n+5|0;a[s]=p;t=n+2|0;a[t]=p;p=a[b+1|0]|0;u=n+4|0;a[u]=p;v=a[b+e|0]|0;w=((v&255)+(p&255)|0)>>>1&255;p=n+10|0;a[p]=w;x=n+1|0;a[x]=w;w=n+7|0;a[w]=v;v=a[b]|0;y=n+6|0;a[y]=v;z=n+3|0;a[z]=v;A=n|0;a[A]=v;B=n+9|0;a[B]=v;Ve[c[1637278]&127](A,f,h,g,2,2,j,0,6,l);v=b+2|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=~e;D=1-e|0;E=e-1|0;F=e<<1;G=e+2|0;H=F|1;I=F+2|0;J=v;K=2;L=b;M=f;N=g;while(1){O=J+D|0;P=J+E|0;Q=J+o|0;a[t]=((d[O]|0)+(d[J+C|0]|0)+(d[P]|0)+(d[Q]|0)|0)>>>2;R=J+1|0;S=J+e|0;a[x]=((d[J-1|0]|0)+(d[J+n|0]|0)+(d[R]|0)+(d[S]|0)|0)>>>2;a[A]=a[J]|0;a[s]=((d[Q]|0)+(d[O]|0)|0)>>>1;a[u]=a[R]|0;O=J+2|0;a[z]=((d[O]|0)+(d[J]|0)|0)>>>1;a[q]=((d[Q]|0)+(d[P]|0)|0)>>>1;a[w]=a[S]|0;P=J+F|0;a[y]=((d[P]|0)+(d[J]|0)|0)>>>1;a[r]=a[Q]|0;a[p]=((d[S]|0)+(d[R]|0)+(d[J+G|0]|0)+(d[J+H|0]|0)|0)>>>2;a[B]=((d[O]|0)+(d[J]|0)+(d[P]|0)+(d[J+I|0]|0)|0)>>>2;Ve[c[1637278]&127](A,L,N,M,2,2,j,0,6,l);P=K+2|0;R=L+2|0;S=M+1|0;Q=N+1|0;if((P|0)<(h|0)){J=O;K=P;L=R;M=S;N=Q}else{T=O;U=R;V=S;W=Q;break}}}else{T=v;U=b;V=f;W=g}if((k|0)<=2){i=m;return}k=a[T+o|0]|0;a[q]=k;a[r]=k;a[s]=k;a[t]=k;k=T+1|0;a[u]=a[k]|0;u=T+e|0;e=((d[u]|0)+(d[k]|0)|0)>>>1&255;a[p]=e;a[x]=e;a[w]=a[u]|0;u=a[T]|0;a[y]=u;a[z]=u;a[A]=u;a[B]=u;Ve[c[1637278]&127](A,U,W,V,2,2,j,0,6,l);i=m;return}function AEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+2|0;p=n+8|0;q=n+11|0;r=n+5|0;s=n+2|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+o|0;C=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[p]=C;a[q]=C;a[r]=C;a[s]=C;C=f+2|0;a[t]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;B=f+e|0;D=(((d[B]|d[B+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[u]=D;a[v]=D;a[w]=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8;B=f;D=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ve[c[1637278]&127](z,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function BEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;m=i;i=i+16|0;n=m|0;o=e+2|0;p=b+o|0;q=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8&255;p=n+8|0;a[p]=q;r=n+11|0;a[r]=q;s=n+5|0;a[s]=q;t=n+2|0;a[t]=q;q=b+2|0;u=(d[q]|d[q+1|0]<<8)<<16>>16;q=n+4|0;a[q]=(u&65535)>>>8;v=b+e|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=((w&65535)+(u&65535)|0)>>>9&255;u=n+10|0;a[u]=v;x=n+1|0;a[x]=v;v=n+7|0;a[v]=(w&65535)>>>8;w=b;y=((d[w]|d[w+1|0]<<8)<<16>>16&65535)>>>8&255;w=n+6|0;a[w]=y;z=n+3|0;a[z]=y;A=n|0;a[A]=y;B=n+9|0;a[B]=y;Ve[c[1637278]&127](A,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=-2-e|0;D=2-e|0;E=e-2|0;F=e<<1;G=e+4|0;H=F+2|0;I=F+4|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+C|0;P=J+D|0;Q=J+E|0;R=J+o|0;a[t]=(((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+n|0;S=J-2|0;T=J+2|0;U=J+e|0;a[x]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[U]|d[U+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J;a[A]=((d[O]|d[O+1|0]<<8)<<16>>16&65535)>>>8;a[s]=(((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)|0)>>>9;a[q]=((d[T]|d[T+1|0]<<8)<<16>>16&65535)>>>8;P=J+4|0;S=P;a[z]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;a[p]=(((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)|0)>>>9;a[v]=((d[U]|d[U+1|0]<<8)<<16>>16&65535)>>>8;Q=J+F|0;a[w]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;a[r]=((d[R]|d[R+1|0]<<8)<<16>>16&65535)>>>8;R=J+G|0;V=J+H|0;a[u]=(((d[U]|d[U+1|0]<<8)<<16>>16&65535)+((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)|0)>>>10;V=J+I|0;a[B]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)|0)>>>10;Ve[c[1637278]&127](A,L,N,M,2,2,j,0,6,l);V=K+2|0;Q=L+2|0;O=M+1|0;S=N+1|0;if((V|0)<(h|0)){J=P;K=V;L=Q;M=O;N=S}else{W=P;X=Q;Y=O;Z=S;break}}}else{W=y;X=b;Y=f;Z=g}if((k|0)<=2){i=m;return}k=W+o|0;o=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[p]=o;a[r]=o;a[s]=o;a[t]=o;o=W+2|0;a[q]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;q=W+e|0;e=(((d[q]|d[q+1|0]<<8)<<16>>16&65535)+((d[o]|d[o+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[u]=e;a[x]=e;a[v]=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8;q=W;W=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8&255;a[w]=W;a[z]=W;a[A]=W;a[B]=W;Ve[c[1637278]&127](A,X,Z,Y,2,2,j,0,6,l);i=m;return}function CEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=e+2|0;p=n+8|0;q=n+11|0;r=n+5|0;s=n+2|0;t=n+4|0;u=n+10|0;v=n+1|0;w=n+7|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+o|0;C=(d[B]|d[B+1|0]<<8)<<16>>16&255;a[p]=C;a[q]=C;a[r]=C;a[s]=C;C=f+2|0;a[t]=(d[C]|d[C+1|0]<<8)<<16>>16;B=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=f+e|0;D=(((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+B|0)>>>9&255;a[u]=D;a[v]=D;a[w]=(d[C]|d[C+1|0]<<8)<<16>>16;C=f;D=(d[C]|d[C+1|0]<<8)<<16>>16&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ve[c[1637278]&127](z,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function DEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;m=i;i=i+16|0;n=m|0;o=e+2|0;p=b+o|0;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;p=n+8|0;a[p]=q;r=n+11|0;a[r]=q;s=n+5|0;a[s]=q;t=n+2|0;a[t]=q;q=b+2|0;u=(d[q]|d[q+1|0]<<8)<<16>>16;q=n+4|0;a[q]=u;v=(he(u|0)|0)&65535;u=b+e|0;w=(d[u]|d[u+1|0]<<8)<<16>>16;u=(((he(w|0)|0)&65535)+v|0)>>>9&255;v=n+10|0;a[v]=u;x=n+1|0;a[x]=u;u=n+7|0;a[u]=w;w=b;y=(d[w]|d[w+1|0]<<8)<<16>>16&255;w=n+6|0;a[w]=y;z=n+3|0;a[z]=y;A=n|0;a[A]=y;B=n+9|0;a[B]=y;Ve[c[1637278]&127](A,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=-2-e|0;D=2-e|0;E=e-2|0;F=e<<1;G=e+4|0;H=F+2|0;I=F+4|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+C|0;P=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=J+D|0;Q=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)+P|0;P=J+E|0;R=Q+((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0;Q=J+o|0;a[t]=(R+((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;R=J+n|0;S=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=J-2|0;T=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=J+2|0;R=T+((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0;T=J+e|0;a[x]=(R+((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;R=J;a[A]=(d[R]|d[R+1|0]<<8)<<16>>16;U=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;a[s]=(((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[q]=(d[S]|d[S+1|0]<<8)<<16>>16;U=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;O=J+4|0;V=O;a[z]=(((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;U=(he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535;a[p]=(((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[u]=(d[T]|d[T+1|0]<<8)<<16>>16;U=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;P=J+F|0;a[w]=(((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+U|0)>>>9;a[r]=(d[Q]|d[Q+1|0]<<8)<<16>>16;Q=(he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+Q|0;Q=J+G|0;T=S+((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0;Q=J+H|0;a[v]=(T+((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;Q=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)+Q|0;Q=R+((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0;P=J+I|0;a[B]=(Q+((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;Ve[c[1637278]&127](A,L,N,M,2,2,j,0,6,l);P=K+2|0;Q=L+2|0;R=M+1|0;V=N+1|0;if((P|0)<(h|0)){J=O;K=P;L=Q;M=R;N=V}else{W=O;X=Q;Y=R;Z=V;break}}}else{W=y;X=b;Y=f;Z=g}if((k|0)<=2){i=m;return}k=W+o|0;o=(d[k]|d[k+1|0]<<8)<<16>>16&255;a[p]=o;a[r]=o;a[s]=o;a[t]=o;o=W+2|0;a[q]=(d[o]|d[o+1|0]<<8)<<16>>16;q=(he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;o=W+e|0;e=(((he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)+q|0)>>>9&255;a[v]=e;a[x]=e;a[u]=(d[o]|d[o+1|0]<<8)<<16>>16;o=W;W=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[w]=W;a[z]=W;a[A]=W;a[B]=W;Ve[c[1637278]&127](A,X,Z,Y,2,2,j,0,6,l);i=m;return}function EEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+6|0;p=n+9|0;q=n+3|0;r=n|0;s=n+1|0;t=e+1|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=a[f+e|0]|0;a[o]=B;a[p]=B;a[q]=B;a[r]=B;a[s]=a[f]|0;B=f+t|0;a[u]=a[B]|0;C=((d[B]|0)+(d[f]|0)|0)>>>1&255;a[v]=C;a[w]=C;C=a[f+1|0]|0;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ve[c[1637278]&127](r,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+2|0;b=C}else{break}}i=m;return}function FEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;m=i;i=i+16|0;n=m|0;o=a[b+e|0]|0;p=n+6|0;a[p]=o;q=n+9|0;a[q]=o;r=n+3|0;a[r]=o;s=n|0;a[s]=o;o=a[b]|0;t=n+1|0;a[t]=o;u=e+1|0;v=a[b+u|0]|0;w=n+10|0;a[w]=v;x=((v&255)+(o&255)|0)>>>1&255;o=n+7|0;a[o]=x;v=n+4|0;a[v]=x;x=a[b+1|0]|0;y=n+8|0;a[y]=x;z=n+5|0;a[z]=x;A=n+2|0;a[A]=x;B=n+11|0;a[B]=x;Ve[c[1637278]&127](s,f,h,g,2,2,j,0,6,l);x=b+2|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=2-e|0;D=e+2|0;E=1-e|0;F=e-1|0;G=e<<1;H=G-1|0;I=G|1;J=x;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=J+e|0;a[s]=((d[P]|0)+(d[O]|0)|0)>>>1;a[t]=a[J]|0;Q=J-1|0;R=J+1|0;a[A]=((d[R]|0)+(d[Q]|0)|0)>>>1;S=J+D|0;a[r]=((d[J+C|0]|0)+(d[O]|0)+(d[P]|0)+(d[S]|0)|0)>>>2;O=J+2|0;T=J+u|0;a[v]=((d[J]|0)+(d[J+E|0]|0)+(d[O]|0)+(d[T]|0)|0)>>>2;a[z]=a[R]|0;a[p]=a[P]|0;a[o]=((d[J+F|0]|0)+(d[J]|0)+(d[T]|0)+(d[J+G|0]|0)|0)>>>2;U=J+I|0;a[y]=((d[R]|0)+(d[Q]|0)+(d[J+H|0]|0)+(d[U]|0)|0)>>>2;a[q]=((d[S]|0)+(d[P]|0)|0)>>>1;a[w]=a[T]|0;a[B]=((d[U]|0)+(d[R]|0)|0)>>>1;Ve[c[1637278]&127](s,L,N,M,2,2,j,0,6,l);R=K+2|0;U=L+2|0;T=M+1|0;P=N+1|0;if((R|0)<(h|0)){J=O;K=R;L=U;M=T;N=P}else{V=O;W=U;X=T;Y=P;break}}}else{V=x;W=b;X=f;Y=g}if((k|0)<=2){i=m;return}k=a[V+e|0]|0;a[p]=k;a[q]=k;a[r]=k;a[s]=k;a[t]=a[V]|0;t=V+u|0;a[w]=a[t]|0;w=((d[t]|0)+(d[V]|0)|0)>>>1&255;a[o]=w;a[v]=w;w=a[V+1|0]|0;a[y]=w;a[z]=w;a[A]=w;a[B]=w;Ve[c[1637278]&127](s,W,Y,X,2,2,j,0,6,l);i=m;return}function GEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+6|0;p=n+9|0;q=n+3|0;r=n|0;s=n+1|0;t=e+2|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+e|0;C=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[o]=C;a[p]=C;a[q]=C;a[r]=C;C=f;a[s]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;B=f+t|0;a[u]=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8;D=(((d[B]|d[B+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[v]=D;a[w]=D;D=f+2|0;C=((d[D]|d[D+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ve[c[1637278]&127](r,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=C}else{break}}i=m;return}function HEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;m=i;i=i+16|0;n=m|0;o=b+e|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;o=n+6|0;a[o]=p;q=n+9|0;a[q]=p;r=n+3|0;a[r]=p;s=n|0;a[s]=p;p=b;t=(d[p]|d[p+1|0]<<8)<<16>>16;p=n+1|0;a[p]=(t&65535)>>>8;u=e+2|0;v=b+u|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=n+10|0;a[v]=(w&65535)>>>8;x=((w&65535)+(t&65535)|0)>>>9&255;t=n+7|0;a[t]=x;w=n+4|0;a[w]=x;x=b+2|0;y=((d[x]|d[x+1|0]<<8)<<16>>16&65535)>>>8&255;x=n+8|0;a[x]=y;z=n+5|0;a[z]=y;A=n+2|0;a[A]=y;B=n+11|0;a[B]=y;Ve[c[1637278]&127](s,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=4-e|0;D=e+4|0;E=2-e|0;F=e-2|0;G=e<<1;H=G-2|0;I=G+2|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=J+e|0;a[s]=(((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;Q=J;a[p]=((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)>>>8;R=J-2|0;S=J+2|0;a[A]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)|0)>>>9;T=J+C|0;U=J+D|0;a[r]=(((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[U]|d[U+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+E|0;T=J+4|0;V=T;W=J+u|0;a[w]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)+((d[W]|d[W+1|0]<<8)<<16>>16&65535)|0)>>>10;a[z]=((d[S]|d[S+1|0]<<8)<<16>>16&65535)>>>8;a[o]=((d[P]|d[P+1|0]<<8)<<16>>16&65535)>>>8;V=J+F|0;O=J+G|0;a[t]=(((d[V]|d[V+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[W]|d[W+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+H|0;Q=J+I|0;a[x]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)|0)>>>10;a[q]=(((d[U]|d[U+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)|0)>>>9;a[v]=((d[W]|d[W+1|0]<<8)<<16>>16&65535)>>>8;a[B]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[S]|d[S+1|0]<<8)<<16>>16&65535)|0)>>>9;Ve[c[1637278]&127](s,L,N,M,2,2,j,0,6,l);S=K+2|0;Q=L+2|0;W=M+1|0;P=N+1|0;if((S|0)<(h|0)){J=T;K=S;L=Q;M=W;N=P}else{X=T;Y=Q;Z=W;_=P;break}}}else{X=y;Y=b;Z=f;_=g}if((k|0)<=2){i=m;return}k=X+e|0;e=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[o]=e;a[q]=e;a[r]=e;a[s]=e;e=X;a[p]=((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>8;p=X+u|0;a[v]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;v=(((d[p]|d[p+1|0]<<8)<<16>>16&65535)+((d[e]|d[e+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[t]=v;a[w]=v;v=X+2|0;X=((d[v]|d[v+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=X;a[z]=X;a[A]=X;a[B]=X;Ve[c[1637278]&127](s,Y,_,Z,2,2,j,0,6,l);i=m;return}function IEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+6|0;p=n+9|0;q=n+3|0;r=n|0;s=n+1|0;t=e+2|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+8|0;y=n+5|0;z=n+2|0;A=n+11|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+e|0;C=(d[B]|d[B+1|0]<<8)<<16>>16&255;a[o]=C;a[p]=C;a[q]=C;a[r]=C;C=f;a[s]=(d[C]|d[C+1|0]<<8)<<16>>16;B=f+t|0;a[u]=(d[B]|d[B+1|0]<<8)<<16>>16;D=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=(((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)+D|0)>>>9&255;a[v]=C;a[w]=C;C=f+2|0;D=(d[C]|d[C+1|0]<<8)<<16>>16&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ve[c[1637278]&127](r,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function JEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;m=i;i=i+16|0;n=m|0;o=b+e|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;o=n+6|0;a[o]=p;q=n+9|0;a[q]=p;r=n+3|0;a[r]=p;s=n|0;a[s]=p;p=b;t=(d[p]|d[p+1|0]<<8)<<16>>16;p=n+1|0;a[p]=t;u=e+2|0;v=b+u|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=n+10|0;a[v]=w;x=(he(t|0)|0)&65535;t=(((he(w|0)|0)&65535)+x|0)>>>9&255;x=n+7|0;a[x]=t;w=n+4|0;a[w]=t;t=b+2|0;y=(d[t]|d[t+1|0]<<8)<<16>>16&255;t=n+8|0;a[t]=y;z=n+5|0;a[z]=y;A=n+2|0;a[A]=y;B=n+11|0;a[B]=y;Ve[c[1637278]&127](s,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=4-e|0;D=e+4|0;E=2-e|0;F=e-2|0;G=e<<1;H=G-2|0;I=G+2|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;Q=J+e|0;a[s]=(((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+P|0)>>>9;P=J;a[p]=(d[P]|d[P+1|0]<<8)<<16>>16;R=J-2|0;S=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;T=J+2|0;a[A]=(((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+S|0)>>>9;S=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=J+C|0;U=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=U+((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0;U=J+D|0;a[r]=(S+((he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;S=J+E|0;O=(he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+O|0;O=J+4|0;V=O;W=S+((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0;V=J+u|0;a[w]=(W+((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;a[z]=(d[T]|d[T+1|0]<<8)<<16>>16;a[o]=(d[Q]|d[Q+1|0]<<8)<<16>>16;W=(he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535;P=J+F|0;S=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+W|0;W=S+((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0;S=J+G|0;a[x]=(W+((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;S=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=J+H|0;W=R+((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0;S=J+I|0;a[t]=(W+((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;W=(he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535;a[q]=(((he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)+W|0)>>>9;a[v]=(d[V]|d[V+1|0]<<8)<<16>>16;V=(he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535;a[B]=(((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)+V|0)>>>9;Ve[c[1637278]&127](s,L,N,M,2,2,j,0,6,l);V=K+2|0;S=L+2|0;T=M+1|0;W=N+1|0;if((V|0)<(h|0)){J=O;K=V;L=S;M=T;N=W}else{X=O;Y=S;Z=T;_=W;break}}}else{X=y;Y=b;Z=f;_=g}if((k|0)<=2){i=m;return}k=X+e|0;e=(d[k]|d[k+1|0]<<8)<<16>>16&255;a[o]=e;a[q]=e;a[r]=e;a[s]=e;e=X;a[p]=(d[e]|d[e+1|0]<<8)<<16>>16;p=X+u|0;a[v]=(d[p]|d[p+1|0]<<8)<<16>>16;v=(he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;e=(((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)+v|0)>>>9&255;a[x]=e;a[w]=e;e=X+2|0;X=(d[e]|d[e+1|0]<<8)<<16>>16&255;a[t]=X;a[z]=X;a[A]=X;a[B]=X;Ve[c[1637278]&127](s,Y,_,Z,2,2,j,0,6,l);i=m;return}function KEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+8|0;p=n+11|0;q=n+5|0;r=n+2|0;s=n+1|0;t=e+1|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=a[f+e|0]|0;a[o]=B;a[p]=B;a[q]=B;a[r]=B;a[s]=a[f]|0;B=f+t|0;a[u]=a[B]|0;C=((d[B]|0)+(d[f]|0)|0)>>>1&255;a[v]=C;a[w]=C;C=a[f+1|0]|0;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ve[c[1637278]&127](z,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+2|0;b=C}else{break}}i=m;return}function LEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;m=i;i=i+16|0;n=m|0;o=a[b+e|0]|0;p=n+8|0;a[p]=o;q=n+11|0;a[q]=o;r=n+5|0;a[r]=o;s=n+2|0;a[s]=o;o=a[b]|0;t=n+1|0;a[t]=o;u=e+1|0;v=a[b+u|0]|0;w=n+10|0;a[w]=v;x=((v&255)+(o&255)|0)>>>1&255;o=n+7|0;a[o]=x;v=n+4|0;a[v]=x;x=a[b+1|0]|0;y=n+6|0;a[y]=x;z=n+3|0;a[z]=x;A=n|0;a[A]=x;B=n+9|0;a[B]=x;Ve[c[1637278]&127](A,f,h,g,2,2,j,0,6,l);x=b+2|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=2-e|0;D=e+2|0;E=1-e|0;F=e-1|0;G=e<<1;H=G-1|0;I=G|1;J=x;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=J+e|0;a[s]=((d[P]|0)+(d[O]|0)|0)>>>1;a[t]=a[J]|0;Q=J-1|0;R=J+1|0;a[A]=((d[R]|0)+(d[Q]|0)|0)>>>1;S=J+D|0;a[r]=((d[J+C|0]|0)+(d[O]|0)+(d[P]|0)+(d[S]|0)|0)>>>2;O=J+2|0;T=J+u|0;a[v]=((d[J]|0)+(d[J+E|0]|0)+(d[O]|0)+(d[T]|0)|0)>>>2;a[z]=a[R]|0;a[p]=a[P]|0;a[o]=((d[J+F|0]|0)+(d[J]|0)+(d[T]|0)+(d[J+G|0]|0)|0)>>>2;U=J+I|0;a[y]=((d[R]|0)+(d[Q]|0)+(d[J+H|0]|0)+(d[U]|0)|0)>>>2;a[q]=((d[S]|0)+(d[P]|0)|0)>>>1;a[w]=a[T]|0;a[B]=((d[U]|0)+(d[R]|0)|0)>>>1;Ve[c[1637278]&127](A,L,N,M,2,2,j,0,6,l);R=K+2|0;U=L+2|0;T=M+1|0;P=N+1|0;if((R|0)<(h|0)){J=O;K=R;L=U;M=T;N=P}else{V=O;W=U;X=T;Y=P;break}}}else{V=x;W=b;X=f;Y=g}if((k|0)<=2){i=m;return}k=a[V+e|0]|0;a[p]=k;a[q]=k;a[r]=k;a[s]=k;a[t]=a[V]|0;t=V+u|0;a[w]=a[t]|0;w=((d[t]|0)+(d[V]|0)|0)>>>1&255;a[o]=w;a[v]=w;w=a[V+1|0]|0;a[y]=w;a[z]=w;a[A]=w;a[B]=w;Ve[c[1637278]&127](A,W,Y,X,2,2,j,0,6,l);i=m;return}function MEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+8|0;p=n+11|0;q=n+5|0;r=n+2|0;s=n+1|0;t=e+2|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+e|0;C=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8&255;a[o]=C;a[p]=C;a[q]=C;a[r]=C;C=f;a[s]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;B=f+t|0;a[u]=((d[B]|d[B+1|0]<<8)<<16>>16&65535)>>>8;D=(((d[B]|d[B+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[v]=D;a[w]=D;D=f+2|0;C=((d[D]|d[D+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=C;a[y]=C;a[z]=C;a[A]=C;Ve[c[1637278]&127](z,g,n,h,2,2,j,0,6,l);C=b+2|0;if((C|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=C}else{break}}i=m;return}function NEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;m=i;i=i+16|0;n=m|0;o=b+e|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;o=n+8|0;a[o]=p;q=n+11|0;a[q]=p;r=n+5|0;a[r]=p;s=n+2|0;a[s]=p;p=b;t=(d[p]|d[p+1|0]<<8)<<16>>16;p=n+1|0;a[p]=(t&65535)>>>8;u=e+2|0;v=b+u|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=n+10|0;a[v]=(w&65535)>>>8;x=((w&65535)+(t&65535)|0)>>>9&255;t=n+7|0;a[t]=x;w=n+4|0;a[w]=x;x=b+2|0;y=((d[x]|d[x+1|0]<<8)<<16>>16&65535)>>>8&255;x=n+6|0;a[x]=y;z=n+3|0;a[z]=y;A=n|0;a[A]=y;B=n+9|0;a[B]=y;Ve[c[1637278]&127](A,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=4-e|0;D=e+4|0;E=2-e|0;F=e-2|0;G=e<<1;H=G-2|0;I=G+2|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=J+e|0;a[s]=(((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>9;Q=J;a[p]=((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)>>>8;R=J-2|0;S=J+2|0;a[A]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)|0)>>>9;T=J+C|0;U=J+D|0;a[r]=(((d[T]|d[T+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)+((d[U]|d[U+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+E|0;T=J+4|0;V=T;W=J+u|0;a[w]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[V]|d[V+1|0]<<8)<<16>>16&65535)+((d[W]|d[W+1|0]<<8)<<16>>16&65535)|0)>>>10;a[z]=((d[S]|d[S+1|0]<<8)<<16>>16&65535)>>>8;a[o]=((d[P]|d[P+1|0]<<8)<<16>>16&65535)>>>8;V=J+F|0;O=J+G|0;a[t]=(((d[V]|d[V+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[W]|d[W+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)|0)>>>10;O=J+H|0;Q=J+I|0;a[x]=(((d[S]|d[S+1|0]<<8)<<16>>16&65535)+((d[R]|d[R+1|0]<<8)<<16>>16&65535)+((d[O]|d[O+1|0]<<8)<<16>>16&65535)+((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)|0)>>>10;a[q]=(((d[U]|d[U+1|0]<<8)<<16>>16&65535)+((d[P]|d[P+1|0]<<8)<<16>>16&65535)|0)>>>9;a[v]=((d[W]|d[W+1|0]<<8)<<16>>16&65535)>>>8;a[B]=(((d[Q]|d[Q+1|0]<<8)<<16>>16&65535)+((d[S]|d[S+1|0]<<8)<<16>>16&65535)|0)>>>9;Ve[c[1637278]&127](A,L,N,M,2,2,j,0,6,l);S=K+2|0;Q=L+2|0;W=M+1|0;P=N+1|0;if((S|0)<(h|0)){J=T;K=S;L=Q;M=W;N=P}else{X=T;Y=Q;Z=W;_=P;break}}}else{X=y;Y=b;Z=f;_=g}if((k|0)<=2){i=m;return}k=X+e|0;e=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[o]=e;a[q]=e;a[r]=e;a[s]=e;e=X;a[p]=((d[e]|d[e+1|0]<<8)<<16>>16&65535)>>>8;p=X+u|0;a[v]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;v=(((d[p]|d[p+1|0]<<8)<<16>>16&65535)+((d[e]|d[e+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[t]=v;a[w]=v;v=X+2|0;X=((d[v]|d[v+1|0]<<8)<<16>>16&65535)>>>8&255;a[x]=X;a[z]=X;a[A]=X;a[B]=X;Ve[c[1637278]&127](A,Y,_,Z,2,2,j,0,6,l);i=m;return}function OEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+16|0;n=m|0;if((k|0)<=0){i=m;return}o=n+8|0;p=n+11|0;q=n+5|0;r=n+2|0;s=n+1|0;t=e+2|0;u=n+10|0;v=n+7|0;w=n+4|0;x=n+6|0;y=n+3|0;z=n|0;A=n+9|0;n=h;h=g;g=f;f=b;b=0;while(1){B=f+e|0;C=(d[B]|d[B+1|0]<<8)<<16>>16&255;a[o]=C;a[p]=C;a[q]=C;a[r]=C;C=f;a[s]=(d[C]|d[C+1|0]<<8)<<16>>16;B=f+t|0;a[u]=(d[B]|d[B+1|0]<<8)<<16>>16;D=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=(((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)+D|0)>>>9&255;a[v]=C;a[w]=C;C=f+2|0;D=(d[C]|d[C+1|0]<<8)<<16>>16&255;a[x]=D;a[y]=D;a[z]=D;a[A]=D;Ve[c[1637278]&127](z,g,n,h,2,2,j,0,6,l);D=b+2|0;if((D|0)<(k|0)){n=n+1|0;h=h+1|0;g=g+2|0;f=f+4|0;b=D}else{break}}i=m;return}function PEb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;m=i;i=i+16|0;n=m|0;o=b+e|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;o=n+8|0;a[o]=p;q=n+11|0;a[q]=p;r=n+5|0;a[r]=p;s=n+2|0;a[s]=p;p=b;t=(d[p]|d[p+1|0]<<8)<<16>>16;p=n+1|0;a[p]=t;u=e+2|0;v=b+u|0;w=(d[v]|d[v+1|0]<<8)<<16>>16;v=n+10|0;a[v]=w;x=(he(t|0)|0)&65535;t=(((he(w|0)|0)&65535)+x|0)>>>9&255;x=n+7|0;a[x]=t;w=n+4|0;a[w]=t;t=b+2|0;y=(d[t]|d[t+1|0]<<8)<<16>>16&255;t=n+6|0;a[t]=y;z=n+3|0;a[z]=y;A=n|0;a[A]=y;B=n+9|0;a[B]=y;Ve[c[1637278]&127](A,f,h,g,2,2,j,0,6,l);y=b+4|0;b=f+2|0;f=g+1|0;g=h+1|0;h=k-2|0;if((h|0)>2){n=-e|0;C=4-e|0;D=e+4|0;E=2-e|0;F=e-2|0;G=e<<1;H=G-2|0;I=G+2|0;J=y;K=2;L=b;M=f;N=g;while(1){O=J+n|0;P=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;Q=J+e|0;a[s]=(((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)+P|0)>>>9;P=J;a[p]=(d[P]|d[P+1|0]<<8)<<16>>16;R=J-2|0;S=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;T=J+2|0;a[A]=(((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+S|0)>>>9;S=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=J+C|0;U=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=U+((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)|0;U=J+D|0;a[r]=(S+((he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;S=J+E|0;O=(he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+O|0;O=J+4|0;V=O;W=S+((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0;V=J+u|0;a[w]=(W+((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;a[z]=(d[T]|d[T+1|0]<<8)<<16>>16;a[o]=(d[Q]|d[Q+1|0]<<8)<<16>>16;W=(he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535;P=J+F|0;S=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+W|0;W=S+((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)|0;S=J+G|0;a[x]=(W+((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;S=(he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535;R=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)+S|0;S=J+H|0;W=R+((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0;S=J+I|0;a[t]=(W+((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;W=(he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535;a[q]=(((he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)+W|0)>>>9;a[v]=(d[V]|d[V+1|0]<<8)<<16>>16;V=(he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535;a[B]=(((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)+V|0)>>>9;Ve[c[1637278]&127](A,L,N,M,2,2,j,0,6,l);V=K+2|0;S=L+2|0;T=M+1|0;W=N+1|0;if((V|0)<(h|0)){J=O;K=V;L=S;M=T;N=W}else{X=O;Y=S;Z=T;_=W;break}}}else{X=y;Y=b;Z=f;_=g}if((k|0)<=2){i=m;return}k=X+e|0;e=(d[k]|d[k+1|0]<<8)<<16>>16&255;a[o]=e;a[q]=e;a[r]=e;a[s]=e;e=X;a[p]=(d[e]|d[e+1|0]<<8)<<16>>16;p=X+u|0;a[v]=(d[p]|d[p+1|0]<<8)<<16>>16;v=(he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;e=(((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)+v|0)>>>9&255;a[x]=e;a[w]=e;e=X+2|0;X=(d[e]|d[e+1|0]<<8)<<16>>16&255;a[t]=X;a[z]=X;a[A]=X;a[B]=X;Ve[c[1637278]&127](A,Y,_,Z,2,2,j,0,6,l);i=m;return}function QEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+1|0;i=f+3|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=a[e+h|0]|0;a[n+f|0]=o;a[n+i|0]=o;a[n+3|0]=o;a[n]=o;o=e+1|0;a[n+4|0]=a[o]|0;p=e+c|0;q=((d[p]|0)+(d[o]|0)|0)>>>1&255;a[n+j|0]=q;a[n+1|0]=q;a[n+k|0]=a[p]|0;p=a[e]|0;a[n+l|0]=p;a[n+5|0]=p;a[n+2|0]=p;a[n+m|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+2|0;b=p}else{break}}return}function REb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=c+1|0;i=a[b+h|0]|0;a[e+f|0]=i;a[e+(f+3)|0]=i;a[e+3|0]=i;a[e]=i;i=b+1|0;a[e+4|0]=a[i]|0;j=b+c|0;k=((d[j]|0)+(d[i]|0)|0)>>>1&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=a[j]|0;j=a[b]|0;a[e+(f+2)|0]=j;a[e+5|0]=j;a[e+2|0]=j;a[e+(f+5)|0]=j;j=b+2|0;b=e+6|0;k=g-2|0;if((k|0)>2){i=-c|0;l=~c;m=1-c|0;n=c-1|0;o=f+6|0;p=f+7|0;q=c<<1;r=f+8|0;s=f+9|0;t=c+2|0;u=q|1;v=f+10|0;w=q+2|0;x=f+11|0;y=e;z=j;A=2;B=b;while(1){C=z+m|0;D=z+n|0;E=z+h|0;a[B]=((d[C]|0)+(d[z+l|0]|0)+(d[D]|0)+(d[E]|0)|0)>>>2;F=z+1|0;G=z+c|0;a[y+7|0]=((d[z-1|0]|0)+(d[z+i|0]|0)+(d[F]|0)+(d[G]|0)|0)>>>2;a[y+8|0]=a[z]|0;a[y+9|0]=((d[E]|0)+(d[C]|0)|0)>>>1;a[y+10|0]=a[F]|0;C=z+2|0;a[y+11|0]=((d[C]|0)+(d[z]|0)|0)>>>1;a[y+o|0]=((d[E]|0)+(d[D]|0)|0)>>>1;a[y+p|0]=a[G]|0;D=z+q|0;a[y+r|0]=((d[D]|0)+(d[z]|0)|0)>>>1;a[y+s|0]=a[E]|0;a[y+v|0]=((d[G]|0)+(d[F]|0)+(d[z+t|0]|0)+(d[z+u|0]|0)|0)>>>2;a[y+x|0]=((d[C]|0)+(d[z]|0)+(d[D]|0)+(d[z+w|0]|0)|0)>>>2;D=A+2|0;F=B+6|0;if((D|0)<(k|0)){y=B;z=C;A=D;B=F}else{H=B;I=C;J=F;break}}}else{H=e;I=j;J=b}if((g|0)<=2){return}g=a[I+h|0]|0;a[H+(f+6)|0]=g;a[H+(f+9)|0]=g;a[H+9|0]=g;a[J]=g;g=I+1|0;a[H+10|0]=a[g]|0;J=I+c|0;c=((d[J]|0)+(d[g]|0)|0)>>>1&255;a[H+(f+10)|0]=c;a[H+7|0]=c;a[H+(f+7)|0]=a[J]|0;J=a[I]|0;a[H+(f+8)|0]=J;a[H+11|0]=J;a[H+8|0]=J;a[H+(f+11)|0]=J;return}function SEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+2|0;i=f+3|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=e+h|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+f|0]=p;a[n+i|0]=p;a[n+3|0]=p;a[n]=p;p=e+2|0;a[n+4|0]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;o=e+c|0;q=(((d[o]|d[o+1|0]<<8)<<16>>16&65535)+((d[p]|d[p+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[n+j|0]=q;a[n+1|0]=q;a[n+k|0]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;o=e;q=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+l|0]=q;a[n+5|0]=q;a[n+2|0]=q;a[n+m|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function TEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=c+2|0;i=b+h|0;j=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+f|0]=j;a[e+(f+3)|0]=j;a[e+3|0]=j;a[e]=j;j=b+2|0;a[e+4|0]=((d[j]|d[j+1|0]<<8)<<16>>16&65535)>>>8;i=b+c|0;k=(((d[i]|d[i+1|0]<<8)<<16>>16&65535)+((d[j]|d[j+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8;i=b;k=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+(f+2)|0]=k;a[e+5|0]=k;a[e+2|0]=k;a[e+(f+5)|0]=k;k=b+4|0;b=e+6|0;i=g-2|0;if((i|0)>2){j=-c|0;l=-2-c|0;m=2-c|0;n=c-2|0;o=f+6|0;p=f+7|0;q=c<<1;r=f+8|0;s=f+9|0;t=c+4|0;u=q+2|0;v=f+10|0;w=q+4|0;x=f+11|0;y=e;z=k;A=2;B=b;while(1){C=z+l|0;D=z+m|0;E=z+n|0;F=z+h|0;a[B]=(((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+j|0;G=z-2|0;H=z+2|0;I=z+c|0;a[y+7|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[I]|d[I+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z;a[y+8|0]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;a[y+9|0]=(((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+10|0]=((d[H]|d[H+1|0]<<8)<<16>>16&65535)>>>8;D=z+4|0;G=D;a[y+11|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+o|0]=(((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+p|0]=((d[I]|d[I+1|0]<<8)<<16>>16&65535)>>>8;E=z+q|0;a[y+r|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+s|0]=((d[F]|d[F+1|0]<<8)<<16>>16&65535)>>>8;F=z+t|0;J=z+u|0;a[y+v|0]=(((d[I]|d[I+1|0]<<8)<<16>>16&65535)+((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)|0)>>>10;J=z+w|0;a[y+x|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)|0)>>>10;J=A+2|0;E=B+6|0;if((J|0)<(i|0)){y=B;z=D;A=J;B=E}else{K=B;L=D;M=E;break}}}else{K=e;L=k;M=b}if((g|0)<=2){return}g=L+h|0;h=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[K+(f+6)|0]=h;a[K+(f+9)|0]=h;a[K+9|0]=h;a[M]=h;h=L+2|0;a[K+10|0]=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8;M=L+c|0;c=(((d[M]|d[M+1|0]<<8)<<16>>16&65535)+((d[h]|d[h+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[K+(f+10)|0]=c;a[K+7|0]=c;a[K+(f+7)|0]=((d[M]|d[M+1|0]<<8)<<16>>16&65535)>>>8;M=L;L=((d[M]|d[M+1|0]<<8)<<16>>16&65535)>>>8&255;a[K+(f+8)|0]=L;a[K+11|0]=L;a[K+8|0]=L;a[K+(f+11)|0]=L;return}function UEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+2|0;i=f+3|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=e+h|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[n+f|0]=p;a[n+i|0]=p;a[n+3|0]=p;a[n]=p;p=e+2|0;a[n+4|0]=(d[p]|d[p+1|0]<<8)<<16>>16;o=(he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=e+c|0;q=(((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)+o|0)>>>9&255;a[n+j|0]=q;a[n+1|0]=q;a[n+k|0]=(d[p]|d[p+1|0]<<8)<<16>>16;p=e;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;a[n+l|0]=q;a[n+5|0]=q;a[n+2|0]=q;a[n+m|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function VEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=c+2|0;i=b+h|0;j=(d[i]|d[i+1|0]<<8)<<16>>16&255;a[e+f|0]=j;a[e+(f+3)|0]=j;a[e+3|0]=j;a[e]=j;j=b+2|0;a[e+4|0]=(d[j]|d[j+1|0]<<8)<<16>>16;i=(he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;j=b+c|0;k=(((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)+i|0)>>>9&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=(d[j]|d[j+1|0]<<8)<<16>>16;j=b;k=(d[j]|d[j+1|0]<<8)<<16>>16&255;a[e+(f+2)|0]=k;a[e+5|0]=k;a[e+2|0]=k;a[e+(f+5)|0]=k;k=b+4|0;b=e+6|0;j=g-2|0;if((j|0)>2){i=-c|0;l=-2-c|0;m=2-c|0;n=c-2|0;o=f+6|0;p=f+7|0;q=c<<1;r=f+8|0;s=f+9|0;t=c+4|0;u=q+2|0;v=f+10|0;w=q+4|0;x=f+11|0;y=e;z=k;A=2;B=b;while(1){C=z+l|0;D=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=z+m|0;E=((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+D|0;D=z+n|0;F=E+((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0;E=z+h|0;a[B]=(F+((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;F=z+i|0;G=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=z-2|0;H=((he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=z+2|0;F=H+((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0;H=z+c|0;a[y+7|0]=(F+((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;F=z;a[y+8|0]=(d[F]|d[F+1|0]<<8)<<16>>16;I=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;a[y+9|0]=(((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+10|0]=(d[G]|d[G+1|0]<<8)<<16>>16;I=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;C=z+4|0;J=C;a[y+11|0]=(((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;I=(he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;a[y+o|0]=(((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+p|0]=(d[H]|d[H+1|0]<<8)<<16>>16;I=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;D=z+q|0;a[y+r|0]=(((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+s|0]=(d[E]|d[E+1|0]<<8)<<16>>16;E=(he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+E|0;E=z+t|0;H=G+((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0;E=z+u|0;a[y+v|0]=(H+((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;E=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)+E|0;E=F+((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0;D=z+w|0;a[y+x|0]=(E+((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;D=A+2|0;E=B+6|0;if((D|0)<(j|0)){y=B;z=C;A=D;B=E}else{K=B;L=C;M=E;break}}}else{K=e;L=k;M=b}if((g|0)<=2){return}g=L+h|0;h=(d[g]|d[g+1|0]<<8)<<16>>16&255;a[K+(f+6)|0]=h;a[K+(f+9)|0]=h;a[K+9|0]=h;a[M]=h;h=L+2|0;a[K+10|0]=(d[h]|d[h+1|0]<<8)<<16>>16;M=(he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;h=L+c|0;c=(((he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535)+M|0)>>>9&255;a[K+(f+10)|0]=c;a[K+7|0]=c;a[K+(f+7)|0]=(d[h]|d[h+1|0]<<8)<<16>>16;h=L;L=(d[h]|d[h+1|0]<<8)<<16>>16&255;a[K+(f+8)|0]=L;a[K+11|0]=L;a[K+8|0]=L;a[K+(f+11)|0]=L;return}function WEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+1|0;i=f+2|0;j=f+3|0;k=f+5|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=a[e+h|0]|0;a[n+i|0]=o;a[n+k|0]=o;a[n+5|0]=o;a[n+2|0]=o;o=e+1|0;a[n+4|0]=a[o]|0;p=e+c|0;q=((d[p]|0)+(d[o]|0)|0)>>>1&255;a[n+l|0]=q;a[n+1|0]=q;a[n+m|0]=a[p]|0;p=a[e]|0;a[n+f|0]=p;a[n+3|0]=p;a[n]=p;a[n+j|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+2|0;b=p}else{break}}return}function XEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=c+1|0;i=a[b+h|0]|0;a[e+(f+2)|0]=i;a[e+(f+5)|0]=i;a[e+5|0]=i;a[e+2|0]=i;i=b+1|0;a[e+4|0]=a[i]|0;j=b+c|0;k=((d[j]|0)+(d[i]|0)|0)>>>1&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=a[j]|0;j=a[b]|0;a[e+f|0]=j;a[e+3|0]=j;a[e]=j;a[e+(f+3)|0]=j;j=b+2|0;b=e+6|0;k=g-2|0;if((k|0)>2){i=-c|0;l=~c;m=1-c|0;n=c-1|0;o=f+8|0;p=f+7|0;q=c<<1;r=f+6|0;s=f+11|0;t=c+2|0;u=q|1;v=f+10|0;w=q+2|0;x=f+9|0;y=e;z=j;A=2;B=b;while(1){C=z+m|0;D=z+n|0;E=z+h|0;a[y+8|0]=((d[C]|0)+(d[z+l|0]|0)+(d[D]|0)+(d[E]|0)|0)>>>2;F=z+1|0;G=z+c|0;a[y+7|0]=((d[z-1|0]|0)+(d[z+i|0]|0)+(d[F]|0)+(d[G]|0)|0)>>>2;a[B]=a[z]|0;a[y+11|0]=((d[E]|0)+(d[C]|0)|0)>>>1;a[y+10|0]=a[F]|0;C=z+2|0;a[y+9|0]=((d[C]|0)+(d[z]|0)|0)>>>1;a[y+o|0]=((d[E]|0)+(d[D]|0)|0)>>>1;a[y+p|0]=a[G]|0;D=z+q|0;a[y+r|0]=((d[D]|0)+(d[z]|0)|0)>>>1;a[y+s|0]=a[E]|0;a[y+v|0]=((d[G]|0)+(d[F]|0)+(d[z+t|0]|0)+(d[z+u|0]|0)|0)>>>2;a[y+x|0]=((d[C]|0)+(d[z]|0)+(d[D]|0)+(d[z+w|0]|0)|0)>>>2;D=A+2|0;F=B+6|0;if((D|0)<(k|0)){y=B;z=C;A=D;B=F}else{H=B;I=C;J=F;break}}}else{H=e;I=j;J=b}if((g|0)<=2){return}g=a[I+h|0]|0;a[H+(f+8)|0]=g;a[H+(f+11)|0]=g;a[H+11|0]=g;a[H+8|0]=g;g=I+1|0;a[H+10|0]=a[g]|0;h=I+c|0;c=((d[h]|0)+(d[g]|0)|0)>>>1&255;a[H+(f+10)|0]=c;a[H+7|0]=c;a[H+(f+7)|0]=a[h]|0;h=a[I]|0;a[H+(f+6)|0]=h;a[H+9|0]=h;a[J]=h;a[H+(f+9)|0]=h;return}function YEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+2|0;i=f+2|0;j=f+3|0;k=f+5|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=e+h|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+i|0]=p;a[n+k|0]=p;a[n+5|0]=p;a[n+2|0]=p;p=e+2|0;a[n+4|0]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;o=e+c|0;q=(((d[o]|d[o+1|0]<<8)<<16>>16&65535)+((d[p]|d[p+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[n+l|0]=q;a[n+1|0]=q;a[n+m|0]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;o=e;q=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+f|0]=q;a[n+3|0]=q;a[n]=q;a[n+j|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function ZEb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=c+2|0;i=b+h|0;j=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+(f+2)|0]=j;a[e+(f+5)|0]=j;a[e+5|0]=j;a[e+2|0]=j;j=b+2|0;a[e+4|0]=((d[j]|d[j+1|0]<<8)<<16>>16&65535)>>>8;i=b+c|0;k=(((d[i]|d[i+1|0]<<8)<<16>>16&65535)+((d[j]|d[j+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8;i=b;k=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+f|0]=k;a[e+3|0]=k;a[e]=k;a[e+(f+3)|0]=k;k=b+4|0;b=e+6|0;i=g-2|0;if((i|0)>2){j=-c|0;l=-2-c|0;m=2-c|0;n=c-2|0;o=f+8|0;p=f+7|0;q=c<<1;r=f+6|0;s=f+11|0;t=c+4|0;u=q+2|0;v=f+10|0;w=q+4|0;x=f+9|0;y=e;z=k;A=2;B=b;while(1){C=z+l|0;D=z+m|0;E=z+n|0;F=z+h|0;a[y+8|0]=(((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+j|0;G=z-2|0;H=z+2|0;I=z+c|0;a[y+7|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[I]|d[I+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z;a[B]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>8;a[y+11|0]=(((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+10|0]=((d[H]|d[H+1|0]<<8)<<16>>16&65535)>>>8;D=z+4|0;G=D;a[y+9|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+o|0]=(((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+p|0]=((d[I]|d[I+1|0]<<8)<<16>>16&65535)>>>8;E=z+q|0;a[y+r|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+s|0]=((d[F]|d[F+1|0]<<8)<<16>>16&65535)>>>8;F=z+t|0;J=z+u|0;a[y+v|0]=(((d[I]|d[I+1|0]<<8)<<16>>16&65535)+((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)|0)>>>10;J=z+w|0;a[y+x|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)|0)>>>10;J=A+2|0;E=B+6|0;if((J|0)<(i|0)){y=B;z=D;A=J;B=E}else{K=B;L=D;M=E;break}}}else{K=e;L=k;M=b}if((g|0)<=2){return}g=L+h|0;h=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[K+(f+8)|0]=h;a[K+(f+11)|0]=h;a[K+11|0]=h;a[K+8|0]=h;h=L+2|0;a[K+10|0]=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8;g=L+c|0;c=(((d[g]|d[g+1|0]<<8)<<16>>16&65535)+((d[h]|d[h+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[K+(f+10)|0]=c;a[K+7|0]=c;a[K+(f+7)|0]=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8;g=L;L=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[K+(f+6)|0]=L;a[K+9|0]=L;a[M]=L;a[K+(f+9)|0]=L;return}function _Eb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=c+2|0;i=f+2|0;j=f+3|0;k=f+5|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=e+h|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[n+i|0]=p;a[n+k|0]=p;a[n+5|0]=p;a[n+2|0]=p;p=e+2|0;a[n+4|0]=(d[p]|d[p+1|0]<<8)<<16>>16;o=(he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=e+c|0;q=(((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)+o|0)>>>9&255;a[n+l|0]=q;a[n+1|0]=q;a[n+m|0]=(d[p]|d[p+1|0]<<8)<<16>>16;p=e;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;a[n+f|0]=q;a[n+3|0]=q;a[n]=q;a[n+j|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function $Eb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=c+2|0;i=b+h|0;j=(d[i]|d[i+1|0]<<8)<<16>>16&255;a[e+(f+2)|0]=j;a[e+(f+5)|0]=j;a[e+5|0]=j;a[e+2|0]=j;j=b+2|0;a[e+4|0]=(d[j]|d[j+1|0]<<8)<<16>>16;i=(he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;j=b+c|0;k=(((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)+i|0)>>>9&255;a[e+(f+4)|0]=k;a[e+1|0]=k;a[e+(f+1)|0]=(d[j]|d[j+1|0]<<8)<<16>>16;j=b;k=(d[j]|d[j+1|0]<<8)<<16>>16&255;a[e+f|0]=k;a[e+3|0]=k;a[e]=k;a[e+(f+3)|0]=k;k=b+4|0;b=e+6|0;j=g-2|0;if((j|0)>2){i=-c|0;l=-2-c|0;m=2-c|0;n=c-2|0;o=f+8|0;p=f+7|0;q=c<<1;r=f+6|0;s=f+11|0;t=c+4|0;u=q+2|0;v=f+10|0;w=q+4|0;x=f+9|0;y=e;z=k;A=2;B=b;while(1){C=z+l|0;D=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=z+m|0;E=((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+D|0;D=z+n|0;F=E+((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0;E=z+h|0;a[y+8|0]=(F+((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;F=z+i|0;G=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=z-2|0;H=((he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=z+2|0;F=H+((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0;H=z+c|0;a[y+7|0]=(F+((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;F=z;a[B]=(d[F]|d[F+1|0]<<8)<<16>>16;I=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;a[y+11|0]=(((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+10|0]=(d[G]|d[G+1|0]<<8)<<16>>16;I=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;C=z+4|0;J=C;a[y+9|0]=(((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;I=(he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;a[y+o|0]=(((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+p|0]=(d[H]|d[H+1|0]<<8)<<16>>16;I=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;D=z+q|0;a[y+r|0]=(((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+I|0)>>>9;a[y+s|0]=(d[E]|d[E+1|0]<<8)<<16>>16;E=(he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+E|0;E=z+t|0;H=G+((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0;E=z+u|0;a[y+v|0]=(H+((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;E=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)+E|0;E=F+((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0;D=z+w|0;a[y+x|0]=(E+((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;D=A+2|0;E=B+6|0;if((D|0)<(j|0)){y=B;z=C;A=D;B=E}else{K=B;L=C;M=E;break}}}else{K=e;L=k;M=b}if((g|0)<=2){return}g=L+h|0;h=(d[g]|d[g+1|0]<<8)<<16>>16&255;a[K+(f+8)|0]=h;a[K+(f+11)|0]=h;a[K+11|0]=h;a[K+8|0]=h;h=L+2|0;a[K+10|0]=(d[h]|d[h+1|0]<<8)<<16>>16;g=(he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;h=L+c|0;c=(((he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535)+g|0)>>>9&255;a[K+(f+10)|0]=c;a[K+7|0]=c;a[K+(f+7)|0]=(d[h]|d[h+1|0]<<8)<<16>>16;h=L;L=(d[h]|d[h+1|0]<<8)<<16>>16&255;a[K+(f+6)|0]=L;a[K+9|0]=L;a[M]=L;a[K+(f+9)|0]=L;return}function aFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)<=0){return}h=f+3|0;i=c+1|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=a[e+c|0]|0;a[n+f|0]=o;a[n+h|0]=o;a[n+3|0]=o;a[n]=o;a[n+1|0]=a[e]|0;o=e+i|0;a[n+j|0]=a[o]|0;p=((d[o]|0)+(d[e]|0)|0)>>>1&255;a[n+k|0]=p;a[n+4|0]=p;p=a[e+1|0]|0;a[n+l|0]=p;a[n+5|0]=p;a[n+2|0]=p;a[n+m|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+2|0;b=p}else{break}}return}function bFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=a[b+c|0]|0;a[e+f|0]=h;a[e+(f+3)|0]=h;a[e+3|0]=h;a[e]=h;a[e+1|0]=a[b]|0;h=c+1|0;i=b+h|0;a[e+(f+4)|0]=a[i]|0;j=((d[i]|0)+(d[b]|0)|0)>>>1&255;a[e+(f+1)|0]=j;a[e+4|0]=j;j=a[b+1|0]|0;a[e+(f+2)|0]=j;a[e+5|0]=j;a[e+2|0]=j;a[e+(f+5)|0]=j;j=b+2|0;b=e+6|0;i=g-2|0;if((i|0)>2){k=-c|0;l=2-c|0;m=c+2|0;n=1-c|0;o=f+6|0;p=c-1|0;q=c<<1;r=f+7|0;s=q-1|0;t=q|1;u=f+8|0;v=f+9|0;w=f+10|0;x=f+11|0;y=e;z=j;A=2;B=b;while(1){C=z+k|0;D=z+c|0;a[B]=((d[D]|0)+(d[C]|0)|0)>>>1;a[y+7|0]=a[z]|0;E=z-1|0;F=z+1|0;a[y+8|0]=((d[F]|0)+(d[E]|0)|0)>>>1;G=z+m|0;a[y+9|0]=((d[z+l|0]|0)+(d[C]|0)+(d[D]|0)+(d[G]|0)|0)>>>2;C=z+2|0;H=z+h|0;a[y+10|0]=((d[z]|0)+(d[z+n|0]|0)+(d[C]|0)+(d[H]|0)|0)>>>2;a[y+11|0]=a[F]|0;a[y+o|0]=a[D]|0;a[y+r|0]=((d[z+p|0]|0)+(d[z]|0)+(d[H]|0)+(d[z+q|0]|0)|0)>>>2;I=z+t|0;a[y+u|0]=((d[F]|0)+(d[E]|0)+(d[z+s|0]|0)+(d[I]|0)|0)>>>2;a[y+v|0]=((d[G]|0)+(d[D]|0)|0)>>>1;a[y+w|0]=a[H]|0;a[y+x|0]=((d[I]|0)+(d[F]|0)|0)>>>1;F=A+2|0;I=B+6|0;if((F|0)<(i|0)){y=B;z=C;A=F;B=I}else{J=B;K=C;L=I;break}}}else{J=e;K=j;L=b}if((g|0)<=2){return}g=a[K+c|0]|0;a[J+(f+6)|0]=g;a[J+(f+9)|0]=g;a[J+9|0]=g;a[L]=g;a[J+7|0]=a[K]|0;g=K+h|0;a[J+(f+10)|0]=a[g]|0;h=((d[g]|0)+(d[K]|0)|0)>>>1&255;a[J+(f+7)|0]=h;a[J+10|0]=h;h=a[K+1|0]|0;a[J+(f+8)|0]=h;a[J+11|0]=h;a[J+8|0]=h;a[J+(f+11)|0]=h;return}function cFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=f+3|0;i=c+2|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=e+c|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+f|0]=p;a[n+h|0]=p;a[n+3|0]=p;a[n]=p;p=e;a[n+1|0]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;o=e+i|0;a[n+j|0]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;q=(((d[o]|d[o+1|0]<<8)<<16>>16&65535)+((d[p]|d[p+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[n+k|0]=q;a[n+4|0]=q;q=e+2|0;p=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+l|0]=p;a[n+5|0]=p;a[n+2|0]=p;a[n+m|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+4|0;b=p}else{break}}return}function dFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=b+c|0;i=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+f|0]=i;a[e+(f+3)|0]=i;a[e+3|0]=i;a[e]=i;i=b;a[e+1|0]=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8;h=c+2|0;j=b+h|0;a[e+(f+4)|0]=((d[j]|d[j+1|0]<<8)<<16>>16&65535)>>>8;k=(((d[j]|d[j+1|0]<<8)<<16>>16&65535)+((d[i]|d[i+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[e+(f+1)|0]=k;a[e+4|0]=k;k=b+2|0;i=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+(f+2)|0]=i;a[e+5|0]=i;a[e+2|0]=i;a[e+(f+5)|0]=i;i=b+4|0;b=e+6|0;k=g-2|0;if((k|0)>2){j=-c|0;l=4-c|0;m=c+4|0;n=2-c|0;o=f+6|0;p=c-2|0;q=c<<1;r=f+7|0;s=q-2|0;t=q+2|0;u=f+8|0;v=f+9|0;w=f+10|0;x=f+11|0;y=e;z=i;A=2;B=b;while(1){C=z+j|0;D=z+c|0;a[B]=(((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;E=z;a[y+7|0]=((d[E]|d[E+1|0]<<8)<<16>>16&65535)>>>8;F=z-2|0;G=z+2|0;a[y+8|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)|0)>>>9;H=z+l|0;I=z+m|0;a[y+9|0]=(((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[I]|d[I+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+n|0;H=z+4|0;J=H;K=z+h|0;a[y+10|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)+((d[K]|d[K+1|0]<<8)<<16>>16&65535)|0)>>>10;a[y+11|0]=((d[G]|d[G+1|0]<<8)<<16>>16&65535)>>>8;a[y+o|0]=((d[D]|d[D+1|0]<<8)<<16>>16&65535)>>>8;J=z+p|0;C=z+q|0;a[y+r|0]=(((d[J]|d[J+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[K]|d[K+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+s|0;E=z+t|0;a[y+u|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)|0)>>>10;a[y+v|0]=(((d[I]|d[I+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+w|0]=((d[K]|d[K+1|0]<<8)<<16>>16&65535)>>>8;a[y+x|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[G]|d[G+1|0]<<8)<<16>>16&65535)|0)>>>9;G=A+2|0;E=B+6|0;if((G|0)<(k|0)){y=B;z=H;A=G;B=E}else{L=B;M=H;N=E;break}}}else{L=e;M=i;N=b}if((g|0)<=2){return}g=M+c|0;c=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[L+(f+6)|0]=c;a[L+(f+9)|0]=c;a[L+9|0]=c;a[N]=c;c=M;a[L+7|0]=((d[c]|d[c+1|0]<<8)<<16>>16&65535)>>>8;N=M+h|0;a[L+(f+10)|0]=((d[N]|d[N+1|0]<<8)<<16>>16&65535)>>>8;h=(((d[N]|d[N+1|0]<<8)<<16>>16&65535)+((d[c]|d[c+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[L+(f+7)|0]=h;a[L+10|0]=h;h=M+2|0;M=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8&255;a[L+(f+8)|0]=M;a[L+11|0]=M;a[L+8|0]=M;a[L+(f+11)|0]=M;return}function eFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=f+3|0;i=c+2|0;j=f+4|0;k=f+1|0;l=f+2|0;m=f+5|0;n=e;e=b;b=0;while(1){o=e+c|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[n+f|0]=p;a[n+h|0]=p;a[n+3|0]=p;a[n]=p;p=e;a[n+1|0]=(d[p]|d[p+1|0]<<8)<<16>>16;o=e+i|0;a[n+j|0]=(d[o]|d[o+1|0]<<8)<<16>>16;q=(he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=(((he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)+q|0)>>>9&255;a[n+k|0]=p;a[n+4|0]=p;p=e+2|0;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;a[n+l|0]=q;a[n+5|0]=q;a[n+2|0]=q;a[n+m|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function fFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=b+c|0;i=(d[h]|d[h+1|0]<<8)<<16>>16&255;a[e+f|0]=i;a[e+(f+3)|0]=i;a[e+3|0]=i;a[e]=i;i=b;a[e+1|0]=(d[i]|d[i+1|0]<<8)<<16>>16;h=c+2|0;j=b+h|0;a[e+(f+4)|0]=(d[j]|d[j+1|0]<<8)<<16>>16;k=(he((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535;i=(((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)+k|0)>>>9&255;a[e+(f+1)|0]=i;a[e+4|0]=i;i=b+2|0;k=(d[i]|d[i+1|0]<<8)<<16>>16&255;a[e+(f+2)|0]=k;a[e+5|0]=k;a[e+2|0]=k;a[e+(f+5)|0]=k;k=b+4|0;b=e+6|0;i=g-2|0;if((i|0)>2){j=-c|0;l=4-c|0;m=c+4|0;n=2-c|0;o=f+6|0;p=c-2|0;q=c<<1;r=f+7|0;s=q-2|0;t=q+2|0;u=f+8|0;v=f+9|0;w=f+10|0;x=f+11|0;y=e;z=k;A=2;B=b;while(1){C=z+j|0;D=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;E=z+c|0;a[B]=(((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+D|0)>>>9;D=z;a[y+7|0]=(d[D]|d[D+1|0]<<8)<<16>>16;F=z-2|0;G=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;H=z+2|0;a[y+8|0]=(((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+G|0)>>>9;G=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=z+l|0;I=((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=I+((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0;I=z+m|0;a[y+9|0]=(G+((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;G=z+n|0;C=(he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+C|0;C=z+4|0;J=C;K=G+((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0;J=z+h|0;a[y+10|0]=(K+((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;a[y+11|0]=(d[H]|d[H+1|0]<<8)<<16>>16;a[y+o|0]=(d[E]|d[E+1|0]<<8)<<16>>16;K=(he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=z+p|0;G=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+K|0;K=G+((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0;G=z+q|0;a[y+r|0]=(K+((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;G=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=z+s|0;K=F+((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0;G=z+t|0;a[y+u|0]=(K+((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;K=(he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;a[y+v|0]=(((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)+K|0)>>>9;a[y+w|0]=(d[J]|d[J+1|0]<<8)<<16>>16;J=(he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;a[y+x|0]=(((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)+J|0)>>>9;J=A+2|0;G=B+6|0;if((J|0)<(i|0)){y=B;z=C;A=J;B=G}else{L=B;M=C;N=G;break}}}else{L=e;M=k;N=b}if((g|0)<=2){return}g=M+c|0;c=(d[g]|d[g+1|0]<<8)<<16>>16&255;a[L+(f+6)|0]=c;a[L+(f+9)|0]=c;a[L+9|0]=c;a[N]=c;c=M;a[L+7|0]=(d[c]|d[c+1|0]<<8)<<16>>16;N=M+h|0;a[L+(f+10)|0]=(d[N]|d[N+1|0]<<8)<<16>>16;h=(he((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&65535;c=(((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)+h|0)>>>9&255;a[L+(f+7)|0]=c;a[L+10|0]=c;c=M+2|0;M=(d[c]|d[c+1|0]<<8)<<16>>16&255;a[L+(f+8)|0]=M;a[L+11|0]=M;a[L+8|0]=M;a[L+(f+11)|0]=M;return}function gFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)<=0){return}h=f+2|0;i=f+3|0;j=f+5|0;k=c+1|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=a[e+c|0]|0;a[n+h|0]=o;a[n+j|0]=o;a[n+5|0]=o;a[n+2|0]=o;a[n+1|0]=a[e]|0;o=e+k|0;a[n+l|0]=a[o]|0;p=((d[o]|0)+(d[e]|0)|0)>>>1&255;a[n+m|0]=p;a[n+4|0]=p;p=a[e+1|0]|0;a[n+f|0]=p;a[n+3|0]=p;a[n]=p;a[n+i|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+2|0;b=p}else{break}}return}function hFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=a[b+c|0]|0;a[e+(f+2)|0]=h;a[e+(f+5)|0]=h;a[e+5|0]=h;a[e+2|0]=h;a[e+1|0]=a[b]|0;h=c+1|0;i=b+h|0;a[e+(f+4)|0]=a[i]|0;j=((d[i]|0)+(d[b]|0)|0)>>>1&255;a[e+(f+1)|0]=j;a[e+4|0]=j;j=a[b+1|0]|0;a[e+f|0]=j;a[e+3|0]=j;a[e]=j;a[e+(f+3)|0]=j;j=b+2|0;b=e+6|0;i=g-2|0;if((i|0)>2){k=-c|0;l=2-c|0;m=c+2|0;n=1-c|0;o=f+8|0;p=c-1|0;q=c<<1;r=f+7|0;s=q-1|0;t=q|1;u=f+6|0;v=f+11|0;w=f+10|0;x=f+9|0;y=e;z=j;A=2;B=b;while(1){C=z+k|0;D=z+c|0;a[y+8|0]=((d[D]|0)+(d[C]|0)|0)>>>1;a[y+7|0]=a[z]|0;E=z-1|0;F=z+1|0;a[B]=((d[F]|0)+(d[E]|0)|0)>>>1;G=z+m|0;a[y+11|0]=((d[z+l|0]|0)+(d[C]|0)+(d[D]|0)+(d[G]|0)|0)>>>2;C=z+2|0;H=z+h|0;a[y+10|0]=((d[z]|0)+(d[z+n|0]|0)+(d[C]|0)+(d[H]|0)|0)>>>2;a[y+9|0]=a[F]|0;a[y+o|0]=a[D]|0;a[y+r|0]=((d[z+p|0]|0)+(d[z]|0)+(d[H]|0)+(d[z+q|0]|0)|0)>>>2;I=z+t|0;a[y+u|0]=((d[F]|0)+(d[E]|0)+(d[z+s|0]|0)+(d[I]|0)|0)>>>2;a[y+v|0]=((d[G]|0)+(d[D]|0)|0)>>>1;a[y+w|0]=a[H]|0;a[y+x|0]=((d[I]|0)+(d[F]|0)|0)>>>1;F=A+2|0;I=B+6|0;if((F|0)<(i|0)){y=B;z=C;A=F;B=I}else{J=B;K=C;L=I;break}}}else{J=e;K=j;L=b}if((g|0)<=2){return}g=a[K+c|0]|0;a[J+(f+8)|0]=g;a[J+(f+11)|0]=g;a[J+11|0]=g;a[J+8|0]=g;a[J+7|0]=a[K]|0;g=K+h|0;a[J+(f+10)|0]=a[g]|0;h=((d[g]|0)+(d[K]|0)|0)>>>1&255;a[J+(f+7)|0]=h;a[J+10|0]=h;h=a[K+1|0]|0;a[J+(f+6)|0]=h;a[J+9|0]=h;a[L]=h;a[J+(f+9)|0]=h;return}function iFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=f+2|0;i=f+3|0;j=f+5|0;k=c+2|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=e+c|0;p=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+h|0]=p;a[n+j|0]=p;a[n+5|0]=p;a[n+2|0]=p;p=e;a[n+1|0]=((d[p]|d[p+1|0]<<8)<<16>>16&65535)>>>8;o=e+k|0;a[n+l|0]=((d[o]|d[o+1|0]<<8)<<16>>16&65535)>>>8;q=(((d[o]|d[o+1|0]<<8)<<16>>16&65535)+((d[p]|d[p+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[n+m|0]=q;a[n+4|0]=q;q=e+2|0;p=((d[q]|d[q+1|0]<<8)<<16>>16&65535)>>>8&255;a[n+f|0]=p;a[n+3|0]=p;a[n]=p;a[n+i|0]=p;p=b+2|0;if((p|0)<(g|0)){n=n+6|0;e=e+4|0;b=p}else{break}}return}function jFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=b+c|0;i=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+(f+2)|0]=i;a[e+(f+5)|0]=i;a[e+5|0]=i;a[e+2|0]=i;i=b;a[e+1|0]=((d[i]|d[i+1|0]<<8)<<16>>16&65535)>>>8;h=c+2|0;j=b+h|0;a[e+(f+4)|0]=((d[j]|d[j+1|0]<<8)<<16>>16&65535)>>>8;k=(((d[j]|d[j+1|0]<<8)<<16>>16&65535)+((d[i]|d[i+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[e+(f+1)|0]=k;a[e+4|0]=k;k=b+2|0;i=((d[k]|d[k+1|0]<<8)<<16>>16&65535)>>>8&255;a[e+f|0]=i;a[e+3|0]=i;a[e]=i;a[e+(f+3)|0]=i;i=b+4|0;b=e+6|0;k=g-2|0;if((k|0)>2){j=-c|0;l=4-c|0;m=c+4|0;n=2-c|0;o=f+8|0;p=c-2|0;q=c<<1;r=f+7|0;s=q-2|0;t=q+2|0;u=f+6|0;v=f+11|0;w=f+10|0;x=f+9|0;y=e;z=i;A=2;B=b;while(1){C=z+j|0;D=z+c|0;a[y+8|0]=(((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>9;E=z;a[y+7|0]=((d[E]|d[E+1|0]<<8)<<16>>16&65535)>>>8;F=z-2|0;G=z+2|0;a[B]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)|0)>>>9;H=z+l|0;I=z+m|0;a[y+11|0]=(((d[H]|d[H+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)+((d[I]|d[I+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+n|0;H=z+4|0;J=H;K=z+h|0;a[y+10|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[J]|d[J+1|0]<<8)<<16>>16&65535)+((d[K]|d[K+1|0]<<8)<<16>>16&65535)|0)>>>10;a[y+9|0]=((d[G]|d[G+1|0]<<8)<<16>>16&65535)>>>8;a[y+o|0]=((d[D]|d[D+1|0]<<8)<<16>>16&65535)>>>8;J=z+p|0;C=z+q|0;a[y+r|0]=(((d[J]|d[J+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[K]|d[K+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)|0)>>>10;C=z+s|0;E=z+t|0;a[y+u|0]=(((d[G]|d[G+1|0]<<8)<<16>>16&65535)+((d[F]|d[F+1|0]<<8)<<16>>16&65535)+((d[C]|d[C+1|0]<<8)<<16>>16&65535)+((d[E]|d[E+1|0]<<8)<<16>>16&65535)|0)>>>10;a[y+v|0]=(((d[I]|d[I+1|0]<<8)<<16>>16&65535)+((d[D]|d[D+1|0]<<8)<<16>>16&65535)|0)>>>9;a[y+w|0]=((d[K]|d[K+1|0]<<8)<<16>>16&65535)>>>8;a[y+x|0]=(((d[E]|d[E+1|0]<<8)<<16>>16&65535)+((d[G]|d[G+1|0]<<8)<<16>>16&65535)|0)>>>9;G=A+2|0;E=B+6|0;if((G|0)<(k|0)){y=B;z=H;A=G;B=E}else{L=B;M=H;N=E;break}}}else{L=e;M=i;N=b}if((g|0)<=2){return}g=M+c|0;c=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8&255;a[L+(f+8)|0]=c;a[L+(f+11)|0]=c;a[L+11|0]=c;a[L+8|0]=c;c=M;a[L+7|0]=((d[c]|d[c+1|0]<<8)<<16>>16&65535)>>>8;g=M+h|0;a[L+(f+10)|0]=((d[g]|d[g+1|0]<<8)<<16>>16&65535)>>>8;h=(((d[g]|d[g+1|0]<<8)<<16>>16&65535)+((d[c]|d[c+1|0]<<8)<<16>>16&65535)|0)>>>9&255;a[L+(f+7)|0]=h;a[L+10|0]=h;h=M+2|0;M=((d[h]|d[h+1|0]<<8)<<16>>16&65535)>>>8&255;a[L+(f+6)|0]=M;a[L+9|0]=M;a[N]=M;a[L+(f+9)|0]=M;return}function kFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=0){return}h=f+2|0;i=f+3|0;j=f+5|0;k=c+2|0;l=f+4|0;m=f+1|0;n=e;e=b;b=0;while(1){o=e+c|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&255;a[n+h|0]=p;a[n+j|0]=p;a[n+5|0]=p;a[n+2|0]=p;p=e;a[n+1|0]=(d[p]|d[p+1|0]<<8)<<16>>16;o=e+k|0;a[n+l|0]=(d[o]|d[o+1|0]<<8)<<16>>16;q=(he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;p=(((he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)+q|0)>>>9&255;a[n+m|0]=p;a[n+4|0]=p;p=e+2|0;q=(d[p]|d[p+1|0]<<8)<<16>>16&255;a[n+f|0]=q;a[n+3|0]=q;a[n]=q;a[n+i|0]=q;q=b+2|0;if((q|0)<(g|0)){n=n+6|0;e=e+4|0;b=q}else{break}}return}function lFb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=b+c|0;i=(d[h]|d[h+1|0]<<8)<<16>>16&255;a[e+(f+2)|0]=i;a[e+(f+5)|0]=i;a[e+5|0]=i;a[e+2|0]=i;i=b;a[e+1|0]=(d[i]|d[i+1|0]<<8)<<16>>16;h=c+2|0;j=b+h|0;a[e+(f+4)|0]=(d[j]|d[j+1|0]<<8)<<16>>16;k=(he((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535;i=(((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)+k|0)>>>9&255;a[e+(f+1)|0]=i;a[e+4|0]=i;i=b+2|0;k=(d[i]|d[i+1|0]<<8)<<16>>16&255;a[e+f|0]=k;a[e+3|0]=k;a[e]=k;a[e+(f+3)|0]=k;k=b+4|0;b=e+6|0;i=g-2|0;if((i|0)>2){j=-c|0;l=4-c|0;m=c+4|0;n=2-c|0;o=f+8|0;p=c-2|0;q=c<<1;r=f+7|0;s=q-2|0;t=q+2|0;u=f+6|0;v=f+11|0;w=f+10|0;x=f+9|0;y=e;z=k;A=2;B=b;while(1){C=z+j|0;D=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;E=z+c|0;a[y+8|0]=(((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)+D|0)>>>9;D=z;a[y+7|0]=(d[D]|d[D+1|0]<<8)<<16>>16;F=z-2|0;G=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;H=z+2|0;a[B]=(((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+G|0)>>>9;G=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=z+l|0;I=((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=I+((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)|0;I=z+m|0;a[y+11|0]=(G+((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;G=z+n|0;C=(he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+C|0;C=z+4|0;J=C;K=G+((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0;J=z+h|0;a[y+10|0]=(K+((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;a[y+9|0]=(d[H]|d[H+1|0]<<8)<<16>>16;a[y+o|0]=(d[E]|d[E+1|0]<<8)<<16>>16;K=(he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=z+p|0;G=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)+K|0;K=G+((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)|0;G=z+q|0;a[y+r|0]=(K+((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;G=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;F=((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535)+G|0;G=z+s|0;K=F+((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0;G=z+t|0;a[y+u|0]=(K+((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)|0)>>>10;K=(he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;a[y+v|0]=(((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)+K|0)>>>9;a[y+w|0]=(d[J]|d[J+1|0]<<8)<<16>>16;J=(he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;a[y+x|0]=(((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)+J|0)>>>9;J=A+2|0;G=B+6|0;if((J|0)<(i|0)){y=B;z=C;A=J;B=G}else{L=B;M=C;N=G;break}}}else{L=e;M=k;N=b}if((g|0)<=2){return}g=M+c|0;c=(d[g]|d[g+1|0]<<8)<<16>>16&255;a[L+(f+8)|0]=c;a[L+(f+11)|0]=c;a[L+11|0]=c;a[L+8|0]=c;c=M;a[L+7|0]=(d[c]|d[c+1|0]<<8)<<16>>16;g=M+h|0;a[L+(f+10)|0]=(d[g]|d[g+1|0]<<8)<<16>>16;h=(he((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&65535;c=(((he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535)+h|0)>>>9&255;a[L+(f+7)|0]=c;a[L+10|0]=c;c=M+2|0;M=(d[c]|d[c+1|0]<<8)<<16>>16&255;a[L+(f+6)|0]=M;a[L+9|0]=M;a[N]=M;a[L+(f+9)|0]=M;return}function mFb(a,d,f,g,h,i,j,k,l){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=a+12|0;n=(c[m>>2]|0)!=0;o=16-k|0;p=(k<<1)-16|0;if((h|0)<=0){return}k=(i|0)==0;i=k|n;q=k|n^1;k=(l|0)>0;r=a+4|0;s=a+8|0;t=n?4:3;n=0;do{u=f+(ca(n,g)|0)|0;a:do{if((j|0)==2){if(!i){if(!k){v=0;break}w=c[a>>2]|0;x=c[r>>2]|0;y=c[s>>2]|0;z=0;A=u;while(1){B=e[w+(z<<1)>>1]|0;b[A>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=e[x+(z<<1)>>1]|0;b[A+2>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=e[y+(z<<1)>>1]|0;b[A+4>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;b[A+6>>1]=-1;B=z+1|0;if((B|0)<(l|0)){z=B;A=A+8|0}else{v=0;break a}}}if(q){if(!k){v=0;break}A=c[a>>2]|0;z=c[r>>2]|0;y=c[s>>2]|0;x=0;w=u;while(1){B=e[A+(x<<1)>>1]|0;b[w>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=e[z+(x<<1)>>1]|0;b[w+2>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=e[y+(x<<1)>>1]|0;b[w+4>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=x+1|0;if((B|0)<(l|0)){x=B;w=w+6|0}else{v=0;break}}}else{if(!k){v=0;break}w=c[a>>2]|0;x=c[r>>2]|0;y=c[s>>2]|0;z=c[m>>2]|0;A=0;B=u;while(1){C=e[w+(A<<1)>>1]|0;b[B>>1]=he((C<<o|C>>>(p>>>0))&65535|0)|0;C=e[x+(A<<1)>>1]|0;b[B+2>>1]=he((C<<o|C>>>(p>>>0))&65535|0)|0;C=e[y+(A<<1)>>1]|0;b[B+4>>1]=he((C<<o|C>>>(p>>>0))&65535|0)|0;C=e[z+(A<<1)>>1]|0;b[B+6>>1]=he((C<<o|C>>>(p>>>0))&65535|0)|0;C=A+1|0;if((C|0)<(l|0)){A=C;B=B+8|0}else{v=0;break}}}}else if((j|0)==1){if(!i){if(!k){v=0;break}B=c[a>>2]|0;A=c[r>>2]|0;z=c[s>>2]|0;y=0;x=u;while(1){w=(he(b[B+(y<<1)>>1]|0)|0)&65535;b[x>>1]=w<<o|w>>>(p>>>0);w=(he(b[A+(y<<1)>>1]|0)|0)&65535;b[x+2>>1]=w<<o|w>>>(p>>>0);w=(he(b[z+(y<<1)>>1]|0)|0)&65535;b[x+4>>1]=w<<o|w>>>(p>>>0);b[x+6>>1]=-1;w=y+1|0;if((w|0)<(l|0)){y=w;x=x+8|0}else{v=0;break a}}}if(q){if(!k){v=0;break}x=c[a>>2]|0;y=c[r>>2]|0;z=c[s>>2]|0;A=0;B=u;while(1){w=(he(b[x+(A<<1)>>1]|0)|0)&65535;b[B>>1]=w<<o|w>>>(p>>>0);w=(he(b[y+(A<<1)>>1]|0)|0)&65535;b[B+2>>1]=w<<o|w>>>(p>>>0);w=(he(b[z+(A<<1)>>1]|0)|0)&65535;b[B+4>>1]=w<<o|w>>>(p>>>0);w=A+1|0;if((w|0)<(l|0)){A=w;B=B+6|0}else{v=0;break}}}else{if(!k){v=0;break}B=c[a>>2]|0;A=c[r>>2]|0;z=c[s>>2]|0;y=c[m>>2]|0;x=0;w=u;while(1){C=(he(b[B+(x<<1)>>1]|0)|0)&65535;b[w>>1]=C<<o|C>>>(p>>>0);C=(he(b[A+(x<<1)>>1]|0)|0)&65535;b[w+2>>1]=C<<o|C>>>(p>>>0);C=(he(b[z+(x<<1)>>1]|0)|0)&65535;b[w+4>>1]=C<<o|C>>>(p>>>0);C=(he(b[y+(x<<1)>>1]|0)|0)&65535;b[w+6>>1]=C<<o|C>>>(p>>>0);C=x+1|0;if((C|0)<(l|0)){x=C;w=w+8|0}else{v=0;break}}}}else if((j|0)==3){if(!i){if(!k){v=0;break}w=c[a>>2]|0;x=c[r>>2]|0;y=c[s>>2]|0;z=0;A=u;while(1){B=(he(b[w+(z<<1)>>1]|0)|0)&65535;b[A>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=(he(b[x+(z<<1)>>1]|0)|0)&65535;b[A+2>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=(he(b[y+(z<<1)>>1]|0)|0)&65535;b[A+4>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;b[A+6>>1]=-1;B=z+1|0;if((B|0)<(l|0)){z=B;A=A+8|0}else{v=0;break a}}}if(q){if(!k){v=0;break}A=c[a>>2]|0;z=c[r>>2]|0;y=c[s>>2]|0;x=0;w=u;while(1){B=(he(b[A+(x<<1)>>1]|0)|0)&65535;b[w>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=(he(b[z+(x<<1)>>1]|0)|0)&65535;b[w+2>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=(he(b[y+(x<<1)>>1]|0)|0)&65535;b[w+4>>1]=he((B<<o|B>>>(p>>>0))&65535|0)|0;B=x+1|0;if((B|0)<(l|0)){x=B;w=w+6|0}else{v=0;break}}}else{if(!k){v=0;break}w=c[a>>2]|0;x=c[r>>2]|0;y=c[s>>2]|0;z=c[m>>2]|0;A=0;B=u;while(1){C=(he(b[w+(A<<1)>>1]|0)|0)&65535;b[B>>1]=he((C<<o|C>>>(p>>>0))&65535|0)|0;C=(he(b[x+(A<<1)>>1]|0)|0)&65535;b[B+2>>1]=he((C<<o|C>>>(p>>>0))&65535|0)|0;C=(he(b[y+(A<<1)>>1]|0)|0)&65535;b[B+4>>1]=he((C<<o|C>>>(p>>>0))&65535|0)|0;C=(he(b[z+(A<<1)>>1]|0)|0)&65535;b[B+6>>1]=he((C<<o|C>>>(p>>>0))&65535|0)|0;C=A+1|0;if((C|0)<(l|0)){A=C;B=B+8|0}else{v=0;break}}}}else{if(!i){if(!k){v=0;break}B=c[a>>2]|0;A=c[r>>2]|0;z=c[s>>2]|0;y=0;x=u;while(1){w=e[B+(y<<1)>>1]|0;b[x>>1]=w<<o|w>>>(p>>>0);w=e[A+(y<<1)>>1]|0;b[x+2>>1]=w<<o|w>>>(p>>>0);w=e[z+(y<<1)>>1]|0;b[x+4>>1]=w<<o|w>>>(p>>>0);b[x+6>>1]=-1;w=y+1|0;if((w|0)<(l|0)){y=w;x=x+8|0}else{v=0;break a}}}if(q){if(!k){v=0;break}x=c[a>>2]|0;y=c[r>>2]|0;z=c[s>>2]|0;A=0;B=u;while(1){w=e[x+(A<<1)>>1]|0;b[B>>1]=w<<o|w>>>(p>>>0);w=e[y+(A<<1)>>1]|0;b[B+2>>1]=w<<o|w>>>(p>>>0);w=e[z+(A<<1)>>1]|0;b[B+4>>1]=w<<o|w>>>(p>>>0);w=A+1|0;if((w|0)<(l|0)){A=w;B=B+6|0}else{v=0;break}}}else{if(!k){v=0;break}B=c[a>>2]|0;A=c[r>>2]|0;z=c[s>>2]|0;y=c[m>>2]|0;x=0;w=u;while(1){C=e[B+(x<<1)>>1]|0;b[w>>1]=C<<o|C>>>(p>>>0);C=e[A+(x<<1)>>1]|0;b[w+2>>1]=C<<o|C>>>(p>>>0);C=e[z+(x<<1)>>1]|0;b[w+4>>1]=C<<o|C>>>(p>>>0);C=e[y+(x<<1)>>1]|0;b[w+6>>1]=C<<o|C>>>(p>>>0);C=x+1|0;if((C|0)<(l|0)){x=C;w=w+8|0}else{v=0;break}}}}}while(0);do{u=a+(v<<2)|0;c[u>>2]=(c[u>>2]|0)+(c[d+(v<<2)>>2]>>1<<1);v=v+1|0;}while((v|0)<(t|0));n=n+1|0;}while((n|0)<(h|0));return}function nFb(a,d,f,g,h,i,j,k,l){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=f+12|0;n=c[m>>2]|0;o=(n|0)!=0;if((h|0)<=0){return}p=(i|0)!=0;i=p&o;q=(l|0)>0;r=f+4|0;s=f+8|0;t=0;u=n;do{n=a+(ca(t,d)|0)|0;a:do{if((j|0)==2){if(i){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=he((e[z>>1]|0)>>>(k>>>0)&65535|0)|0;b[w+(y<<1)>>1]=he((e[z+2>>1]|0)>>>(k>>>0)&65535|0)|0;b[x+(y<<1)>>1]=he((e[z+4>>1]|0)>>>(k>>>0)&65535|0)|0;b[u+(y<<1)>>1]=he((e[z+6>>1]|0)>>>(k>>>0)&65535|0)|0;A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break a}}}if(o){if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=he((e[v>>1]|0)>>>(k>>>0)&65535|0)|0;b[y+(w<<1)>>1]=he((e[v+2>>1]|0)>>>(k>>>0)&65535|0)|0;b[x+(w<<1)>>1]=he((e[v+4>>1]|0)>>>(k>>>0)&65535|0)|0;b[u+(w<<1)>>1]=-1;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break a}}}if(p){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=he((e[z>>1]|0)>>>(k>>>0)&65535|0)|0;b[w+(y<<1)>>1]=he((e[z+2>>1]|0)>>>(k>>>0)&65535|0)|0;b[x+(y<<1)>>1]=he((e[z+4>>1]|0)>>>(k>>>0)&65535|0)|0;A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break}}}else{if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=he((e[v>>1]|0)>>>(k>>>0)&65535|0)|0;b[y+(w<<1)>>1]=he((e[v+2>>1]|0)>>>(k>>>0)&65535|0)|0;b[x+(w<<1)>>1]=he((e[v+4>>1]|0)>>>(k>>>0)&65535|0)|0;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break}}}}else if((j|0)==3){if(i){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=he(((he(b[z>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[w+(y<<1)>>1]=he(((he(b[z+2>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[x+(y<<1)>>1]=he(((he(b[z+4>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[u+(y<<1)>>1]=he(((he(b[z+6>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break a}}}if(o){if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=he(((he(b[v>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[y+(w<<1)>>1]=he(((he(b[v+2>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[x+(w<<1)>>1]=he(((he(b[v+4>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[u+(w<<1)>>1]=-1;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break a}}}if(p){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=he(((he(b[z>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[w+(y<<1)>>1]=he(((he(b[z+2>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[x+(y<<1)>>1]=he(((he(b[z+4>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break}}}else{if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=he(((he(b[v>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[y+(w<<1)>>1]=he(((he(b[v+2>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;b[x+(w<<1)>>1]=he(((he(b[v+4>>1]|0)|0)&65535)>>>(k>>>0)&65535|0)|0;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break}}}}else if((j|0)==1){if(i){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=((he(b[z>>1]|0)|0)&65535)>>>(k>>>0);b[w+(y<<1)>>1]=((he(b[z+2>>1]|0)|0)&65535)>>>(k>>>0);b[x+(y<<1)>>1]=((he(b[z+4>>1]|0)|0)&65535)>>>(k>>>0);b[u+(y<<1)>>1]=((he(b[z+6>>1]|0)|0)&65535)>>>(k>>>0);A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break a}}}if(o){if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=((he(b[v>>1]|0)|0)&65535)>>>(k>>>0);b[y+(w<<1)>>1]=((he(b[v+2>>1]|0)|0)&65535)>>>(k>>>0);b[x+(w<<1)>>1]=((he(b[v+4>>1]|0)|0)&65535)>>>(k>>>0);b[u+(w<<1)>>1]=-1;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break a}}}if(p){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=((he(b[z>>1]|0)|0)&65535)>>>(k>>>0);b[w+(y<<1)>>1]=((he(b[z+2>>1]|0)|0)&65535)>>>(k>>>0);b[x+(y<<1)>>1]=((he(b[z+4>>1]|0)|0)&65535)>>>(k>>>0);A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break}}}else{if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=((he(b[v>>1]|0)|0)&65535)>>>(k>>>0);b[y+(w<<1)>>1]=((he(b[v+2>>1]|0)|0)&65535)>>>(k>>>0);b[x+(w<<1)>>1]=((he(b[v+4>>1]|0)|0)&65535)>>>(k>>>0);A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break}}}}else{if(i){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=(e[z>>1]|0)>>>(k>>>0);b[w+(y<<1)>>1]=(e[z+2>>1]|0)>>>(k>>>0);b[x+(y<<1)>>1]=(e[z+4>>1]|0)>>>(k>>>0);b[u+(y<<1)>>1]=(e[z+6>>1]|0)>>>(k>>>0);A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break a}}}if(o){if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=(e[v>>1]|0)>>>(k>>>0);b[y+(w<<1)>>1]=(e[v+2>>1]|0)>>>(k>>>0);b[x+(w<<1)>>1]=(e[v+4>>1]|0)>>>(k>>>0);b[u+(w<<1)>>1]=-1;A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break a}}}if(p){if(!q){break}v=c[f>>2]|0;w=c[r>>2]|0;x=c[s>>2]|0;y=0;z=n;while(1){b[v+(y<<1)>>1]=(e[z>>1]|0)>>>(k>>>0);b[w+(y<<1)>>1]=(e[z+2>>1]|0)>>>(k>>>0);b[x+(y<<1)>>1]=(e[z+4>>1]|0)>>>(k>>>0);A=y+1|0;if((A|0)<(l|0)){y=A;z=z+8|0}else{break}}}else{if(!q){break}z=c[f>>2]|0;y=c[r>>2]|0;x=c[s>>2]|0;w=0;v=n;while(1){b[z+(w<<1)>>1]=(e[v>>1]|0)>>>(k>>>0);b[y+(w<<1)>>1]=(e[v+2>>1]|0)>>>(k>>>0);b[x+(w<<1)>>1]=(e[v+4>>1]|0)>>>(k>>>0);A=w+1|0;if((A|0)<(l|0)){w=A;v=v+6|0}else{break}}}}}while(0);c[f>>2]=(c[f>>2]|0)+(c[g>>2]>>1<<1);c[r>>2]=(c[r>>2]|0)+(c[g+4>>2]>>1<<1);c[s>>2]=(c[s>>2]|0)+(c[g+8>>2]>>1<<1);u=u+(c[g+12>>2]>>1<<1)|0;c[m>>2]=u;t=t+1|0;}while((t|0)<(h|0));return}function oFb(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=a&65535;f=a>>>16;if((c|0)==0){g=e;h=f;i=h<<16;j=i|g;return j|0}else{k=b;l=c;m=e;n=f}while(1){f=k+1|0;e=(d[k]|0)+m|0;c=e+n|0;if(l>>>0>4>>>0){b=k;a=l;o=f;p=e;q=c;while(1){r=(d[o]|0)+p|0;s=r+(d[b+2|0]|0)|0;t=b+4|0;u=s+(d[b+3|0]|0)|0;v=r+q+s+u|0;s=a-4|0;r=b+5|0;w=(d[t]|0)+u|0;u=w+v|0;if(s>>>0>4>>>0&(v|0)>-1){b=t;a=s;o=r;p=w;q=u}else{x=s;y=r;z=w;A=u;break}}}else{x=l;y=f;z=e;A=c}q=x-1|0;p=(z>>>0)%65521|0;o=(A>>>0)%65521|0;if((q|0)==0){g=p;h=o;break}else{k=y;l=q;m=p;n=o}}i=h<<16;j=i|g;return j|0}function pFb(){return pJb(280)|0}function qFb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0;j=g-1|0;if((g|0)==0){return}g=b+272|0;k=b+256|0;l=b+264|0;m=(h|0)==0;n=b+240|0;o=n|0;p=b+248|0;q=n;r=n;s=q+4|0;t=p;u=q+12|0;q=n;v=n;n=q+4|0;w=p;x=q+12|0;z=v+1|0;A=v+5|0;B=v+9|0;C=v+13|0;D=q+2|0;E=q+10|0;F=q+6|0;G=q+14|0;q=v+3|0;H=v+15|0;I=v+11|0;J=v+7|0;K=b+240|0;L=b|0;M=b+8|0;N=h;O=h+8|0;if((i|0)==0){P=f;Q=e;R=j}else{i=f;f=e;e=j;while(1){j=c[g>>2]|0;S=i;T=S|0;U=S+4|0;S=b+(j<<4)|0;V=c[S>>2]^(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24);T=c[S+4>>2]^(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24);c[k>>2]=V;c[k+4>>2]=T;U=i+8|0;S=U|0;W=U+4|0;U=b+(j<<4)+8|0;X=c[U>>2]^(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24);S=c[U+4>>2]^(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24);c[l>>2]=X;c[l+4>>2]=S;W=V&255;U=(S>>>8|0<<24)&255;Y=(X>>>16|S<<16)&255;Z=(T>>>24|0<<8)&255;_=T&255;$=(V>>>8|T<<24)&255;aa=(S>>>16|0<<16)&255;ba=(X>>>24|S<<8)&255;ca=X&255;da=(T>>>8|0<<24)&255;ea=(V>>>16|T<<16)&255;fa=(S>>>24|0<<8)&255;ga=S&255;ha=(X>>>8|S<<24)&255;S=(T>>>16|0<<16)&255;X=(V>>>24|T<<8)&255;T=j-1|0;if((T|0)>0){j=T;T=W;V=U;ia=Y;ja=Z;ka=_;la=$;ma=aa;na=ba;oa=ca;pa=da;qa=ea;ra=fa;sa=ga;ta=ha;ua=S;va=X;while(1){c[r>>2]=c[9475208+((V&255)<<2)>>2]^c[9474184+((T&255)<<2)>>2]^c[9476232+((ia&255)<<2)>>2]^c[9477256+((ja&255)<<2)>>2];c[s>>2]=c[9475208+((la&255)<<2)>>2]^c[9474184+((ka&255)<<2)>>2]^c[9476232+((ma&255)<<2)>>2]^c[9477256+((na&255)<<2)>>2];c[t>>2]=c[9475208+((pa&255)<<2)>>2]^c[9474184+((oa&255)<<2)>>2]^c[9476232+((qa&255)<<2)>>2]^c[9477256+((ra&255)<<2)>>2];c[u>>2]=c[9475208+((ta&255)<<2)>>2]^c[9474184+((sa&255)<<2)>>2]^c[9476232+((ua&255)<<2)>>2]^c[9477256+((va&255)<<2)>>2];wa=b+(j<<4)|0;xa=c[wa>>2]^c[o>>2];ya=c[wa+4>>2]^c[o+4>>2];c[k>>2]=xa;c[k+4>>2]=ya;wa=b+(j<<4)+8|0;za=c[wa>>2]^c[p>>2];Aa=c[wa+4>>2]^c[p+4>>2];c[l>>2]=za;c[l+4>>2]=Aa;wa=j-1|0;Ba=xa&255;Ca=(Aa>>>8|0<<24)&255;Da=(za>>>16|Aa<<16)&255;Ea=(ya>>>24|0<<8)&255;Fa=ya&255;Ga=(xa>>>8|ya<<24)&255;Ha=(Aa>>>16|0<<16)&255;Ia=(za>>>24|Aa<<8)&255;Ja=za&255;Ka=(ya>>>8|0<<24)&255;La=(xa>>>16|ya<<16)&255;Ma=(Aa>>>24|0<<8)&255;Na=Aa&255;Oa=(za>>>8|Aa<<24)&255;Aa=(ya>>>16|0<<16)&255;za=(xa>>>24|ya<<8)&255;if((wa|0)>0){j=wa;T=Ba;V=Ca;ia=Da;ja=Ea;ka=Fa;la=Ga;ma=Ha;na=Ia;oa=Ja;pa=Ka;qa=La;ra=Ma;sa=Na;ta=Oa;ua=Aa;va=za}else{Pa=Ba;Qa=Fa;Ra=Ja;Sa=Na;Ta=Ea;Ua=Ia;Va=Ma;Wa=za;Xa=Da;Ya=La;Za=Ha;_a=Aa;$a=Ca;ab=Oa;bb=Ka;cb=Ga;break}}}else{Pa=W;Qa=_;Ra=ca;Sa=ga;Ta=Z;Ua=ba;Va=fa;Wa=X;Xa=Y;Ya=ea;Za=aa;_a=S;$a=U;ab=ha;bb=da;cb=$}a[v]=a[5897008+(Pa&255)|0]|0;a[n]=a[5897008+(Qa&255)|0]|0;a[w]=a[5897008+(Ra&255)|0]|0;a[x]=a[5897008+(Sa&255)|0]|0;a[q]=a[5897008+(Ta&255)|0]|0;a[J]=a[5897008+(Ua&255)|0]|0;a[I]=a[5897008+(Va&255)|0]|0;a[H]=a[5897008+(Wa&255)|0]|0;a[D]=a[5897008+(Xa&255)|0]|0;a[E]=a[5897008+(Ya&255)|0]|0;a[F]=a[5897008+(Za&255)|0]|0;a[G]=a[5897008+(_a&255)|0]|0;a[z]=a[5897008+($a&255)|0]|0;a[C]=a[5897008+(ab&255)|0]|0;a[B]=a[5897008+(bb&255)|0]|0;a[A]=a[5897008+(cb&255)|0]|0;if(!m){va=N|0;ua=N+4|0;ta=c[K+4>>2]^(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24);c[K>>2]=c[K>>2]^(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24);c[K+4>>2]=ta;ta=O|0;va=O+4|0;ua=c[p+4>>2]^(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24);c[p>>2]=c[p>>2]^(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24);c[p+4>>2]=ua;nrc(h|0,i|0,16)|0}ua=c[L+4>>2]^c[K+4>>2];ta=f;va=ta|0;y=c[L>>2]^c[K>>2];a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=ta+4|0;y=ua;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=c[M+4>>2]^c[p+4>>2];ua=f+8|0;ta=ua|0;y=c[M>>2]^c[p>>2];a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;ta=ua+4|0;y=va;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;if((e|0)==0){break}i=i+16|0;f=f+16|0;e=e-1|0}return}while(1){e=c[g>>2]|0;f=P;i=f|0;cb=f+4|0;f=b+(e<<4)|0;bb=c[f>>2]^(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24);i=c[f+4>>2]^(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24);c[k>>2]=bb;c[k+4>>2]=i;cb=P+8|0;f=cb|0;ab=cb+4|0;cb=b+(e<<4)+8|0;$a=c[cb>>2]^(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24);f=c[cb+4>>2]^(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24);c[l>>2]=$a;c[l+4>>2]=f;ab=bb&255;cb=(i>>>8|0<<24)&255;_a=($a>>>16|f<<16)&255;Za=(f>>>24|0<<8)&255;Ya=i&255;Xa=($a>>>8|f<<24)&255;Wa=(f>>>16|0<<16)&255;Va=(bb>>>24|i<<8)&255;Ua=$a&255;Ta=(f>>>8|0<<24)&255;Sa=(bb>>>16|i<<16)&255;Ra=(i>>>24|0<<8)&255;Qa=f&255;Pa=(bb>>>8|i<<24)&255;ta=(i>>>16|0<<16)&255;va=($a>>>24|f<<8)&255;if(m){ua=e-1|0;if((ua|0)>0){sa=ua;ua=ab;ra=cb;qa=_a;pa=Za;oa=Ya;na=Xa;ma=Wa;la=Va;ka=Ua;ja=Ta;ia=Sa;V=Ra;T=Qa;j=Pa;Ga=ta;Ka=va;while(1){c[r>>2]=c[8977544+((ra&255)<<2)>>2]^c[8976520+((ua&255)<<2)>>2]^c[8978568+((qa&255)<<2)>>2]^c[8979592+((pa&255)<<2)>>2];c[s>>2]=c[8977544+((na&255)<<2)>>2]^c[8976520+((oa&255)<<2)>>2]^c[8978568+((ma&255)<<2)>>2]^c[8979592+((la&255)<<2)>>2];c[t>>2]=c[8977544+((ja&255)<<2)>>2]^c[8976520+((ka&255)<<2)>>2]^c[8978568+((ia&255)<<2)>>2]^c[8979592+((V&255)<<2)>>2];c[u>>2]=c[8977544+((j&255)<<2)>>2]^c[8976520+((T&255)<<2)>>2]^c[8978568+((Ga&255)<<2)>>2]^c[8979592+((Ka&255)<<2)>>2];Oa=b+(sa<<4)|0;Ca=c[Oa>>2]^c[o>>2];Aa=c[Oa+4>>2]^c[o+4>>2];c[k>>2]=Ca;c[k+4>>2]=Aa;Oa=b+(sa<<4)+8|0;Ha=c[Oa>>2]^c[p>>2];La=c[Oa+4>>2]^c[p+4>>2];c[l>>2]=Ha;c[l+4>>2]=La;Oa=sa-1|0;Da=Ca&255;za=(Aa>>>8|0<<24)&255;Ma=(Ha>>>16|La<<16)&255;Ia=(La>>>24|0<<8)&255;Ea=Aa&255;Na=(Ha>>>8|La<<24)&255;Ja=(La>>>16|0<<16)&255;Fa=(Ca>>>24|Aa<<8)&255;Ba=Ha&255;wa=(La>>>8|0<<24)&255;ya=(Ca>>>16|Aa<<16)&255;xa=(Aa>>>24|0<<8)&255;db=La&255;eb=(Ca>>>8|Aa<<24)&255;Ca=(Aa>>>16|0<<16)&255;Aa=(Ha>>>24|La<<8)&255;if((Oa|0)>0){sa=Oa;ua=Da;ra=za;qa=Ma;pa=Ia;oa=Ea;na=Na;ma=Ja;la=Fa;ka=Ba;ja=wa;ia=ya;V=xa;T=db;j=eb;Ga=Ca;Ka=Aa}else{fb=Da;gb=Ea;hb=Ba;ib=db;jb=za;kb=Na;lb=wa;mb=eb;nb=Ma;ob=ya;pb=Ja;qb=Ca;rb=Ia;sb=Aa;tb=xa;ub=Fa;break}}}else{fb=ab;gb=Ya;hb=Ua;ib=Qa;jb=cb;kb=Xa;lb=Ta;mb=Pa;nb=_a;ob=Sa;pb=Wa;qb=ta;rb=Za;sb=va;tb=Ra;ub=Va}a[v]=a[5123728+(fb&255)|0]|0;a[n]=a[5123728+(gb&255)|0]|0;a[w]=a[5123728+(hb&255)|0]|0;a[x]=a[5123728+(ib&255)|0]|0;a[z]=a[5123728+(jb&255)|0]|0;a[A]=a[5123728+(kb&255)|0]|0;a[B]=a[5123728+(lb&255)|0]|0;a[C]=a[5123728+(mb&255)|0]|0;a[D]=a[5123728+(nb&255)|0]|0;a[E]=a[5123728+(ob&255)|0]|0;a[F]=a[5123728+(pb&255)|0]|0;a[G]=a[5123728+(qb&255)|0]|0;a[q]=a[5123728+(rb&255)|0]|0;a[H]=a[5123728+(sb&255)|0]|0;a[I]=a[5123728+(tb&255)|0]|0;a[J]=a[5123728+(ub&255)|0]|0;Ka=c[L+4>>2]^c[K+4>>2];Ga=Q;j=Ga|0;y=c[L>>2]^c[K>>2];a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=Ga+4|0;y=Ka;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=c[M+4>>2]^c[p+4>>2];Ka=Q+8|0;Ga=Ka|0;y=c[M>>2]^c[p>>2];a[Ga]=y;y=y>>8;a[Ga+1|0]=y;y=y>>8;a[Ga+2|0]=y;y=y>>8;a[Ga+3|0]=y;Ga=Ka+4|0;y=j;a[Ga]=y;y=y>>8;a[Ga+1|0]=y;y=y>>8;a[Ga+2|0]=y;y=y>>8;a[Ga+3|0]=y}else{Ga=N|0;j=N+4|0;Ka=bb^(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24);Ga=i^(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24);c[k>>2]=Ka;c[k+4>>2]=Ga;j=O|0;T=O+4|0;V=$a^(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24);j=f^(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24);c[l>>2]=V;c[l+4>>2]=j;T=e-1|0;ia=Ka&255;ja=(Ga>>>8|0<<24)&255;ka=(V>>>16|j<<16)&255;la=(j>>>24|0<<8)&255;ma=Ga&255;na=(V>>>8|j<<24)&255;oa=(j>>>16|0<<16)&255;pa=(Ka>>>24|Ga<<8)&255;qa=V&255;ra=(j>>>8|0<<24)&255;ua=(Ka>>>16|Ga<<16)&255;sa=(Ga>>>24|0<<8)&255;$=j&255;da=(Ka>>>8|Ga<<24)&255;Ka=(Ga>>>16|0<<16)&255;Ga=(V>>>24|j<<8)&255;if((T|0)>0){j=T;T=ia;V=ja;ha=ka;U=la;S=ma;aa=na;ea=oa;Y=pa;X=qa;fa=ra;ba=ua;Z=sa;ga=$;ca=da;_=Ka;W=Ga;while(1){c[r>>2]=c[8977544+((V&255)<<2)>>2]^c[8976520+((T&255)<<2)>>2]^c[8978568+((ha&255)<<2)>>2]^c[8979592+((U&255)<<2)>>2];c[s>>2]=c[8977544+((aa&255)<<2)>>2]^c[8976520+((S&255)<<2)>>2]^c[8978568+((ea&255)<<2)>>2]^c[8979592+((Y&255)<<2)>>2];c[t>>2]=c[8977544+((fa&255)<<2)>>2]^c[8976520+((X&255)<<2)>>2]^c[8978568+((ba&255)<<2)>>2]^c[8979592+((Z&255)<<2)>>2];c[u>>2]=c[8977544+((ca&255)<<2)>>2]^c[8976520+((ga&255)<<2)>>2]^c[8978568+((_&255)<<2)>>2]^c[8979592+((W&255)<<2)>>2];Fa=b+(j<<4)|0;xa=c[Fa>>2]^c[o>>2];Aa=c[Fa+4>>2]^c[o+4>>2];c[k>>2]=xa;c[k+4>>2]=Aa;Fa=b+(j<<4)+8|0;Ia=c[Fa>>2]^c[p>>2];Ca=c[Fa+4>>2]^c[p+4>>2];c[l>>2]=Ia;c[l+4>>2]=Ca;Fa=j-1|0;Ja=xa&255;ya=(Aa>>>8|0<<24)&255;Ma=(Ia>>>16|Ca<<16)&255;eb=(Ca>>>24|0<<8)&255;wa=Aa&255;Na=(Ia>>>8|Ca<<24)&255;za=(Ca>>>16|0<<16)&255;db=(xa>>>24|Aa<<8)&255;Ba=Ia&255;Ea=(Ca>>>8|0<<24)&255;Da=(xa>>>16|Aa<<16)&255;Oa=(Aa>>>24|0<<8)&255;La=Ca&255;Ha=(xa>>>8|Aa<<24)&255;xa=(Aa>>>16|0<<16)&255;Aa=(Ia>>>24|Ca<<8)&255;if((Fa|0)>0){j=Fa;T=Ja;V=ya;ha=Ma;U=eb;S=wa;aa=Na;ea=za;Y=db;X=Ba;fa=Ea;ba=Da;Z=Oa;ga=La;ca=Ha;_=xa;W=Aa}else{vb=Ja;wb=wa;xb=Ba;yb=La;zb=ya;Ab=Na;Bb=Ea;Cb=Ha;Db=Ma;Eb=Da;Fb=za;Gb=xa;Hb=eb;Ib=Aa;Jb=Oa;Kb=db;break}}}else{vb=ia;wb=ma;xb=qa;yb=$;zb=ja;Ab=na;Bb=ra;Cb=da;Db=ka;Eb=ua;Fb=oa;Gb=Ka;Hb=la;Ib=Ga;Jb=sa;Kb=pa}a[v]=a[5123728+(vb&255)|0]|0;a[n]=a[5123728+(wb&255)|0]|0;a[w]=a[5123728+(xb&255)|0]|0;a[x]=a[5123728+(yb&255)|0]|0;a[z]=a[5123728+(zb&255)|0]|0;a[A]=a[5123728+(Ab&255)|0]|0;a[B]=a[5123728+(Bb&255)|0]|0;a[C]=a[5123728+(Cb&255)|0]|0;a[D]=a[5123728+(Db&255)|0]|0;a[E]=a[5123728+(Eb&255)|0]|0;a[F]=a[5123728+(Fb&255)|0]|0;a[G]=a[5123728+(Gb&255)|0]|0;a[q]=a[5123728+(Hb&255)|0]|0;a[H]=a[5123728+(Ib&255)|0]|0;a[I]=a[5123728+(Jb&255)|0]|0;a[J]=a[5123728+(Kb&255)|0]|0;W=c[L+4>>2]^c[K+4>>2];_=Q;ca=_|0;y=c[L>>2]^c[K>>2];a[ca]=y;y=y>>8;a[ca+1|0]=y;y=y>>8;a[ca+2|0]=y;y=y>>8;a[ca+3|0]=y;ca=_+4|0;y=W;a[ca]=y;y=y>>8;a[ca+1|0]=y;y=y>>8;a[ca+2|0]=y;y=y>>8;a[ca+3|0]=y;ca=c[M+4>>2]^c[p+4>>2];W=Q+8|0;_=W|0;y=c[M>>2]^c[p>>2];a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;_=W+4|0;y=ca;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;nrc(h|0,Q|0,16)|0}if((R|0)==0){break}P=P+16|0;Q=Q+16|0;R=R-1|0}return}function rFb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+848|0;j=h|0;k=h+32|0;l=h+288|0;m=h+800|0;n=h+816|0;o=h+832|0;p=f>>5;q=p+6|0;if((c[2245153]|0)==0){r=1;s=0;while(1){t=r&255;a[l+(s+255)|0]=t;a[l+s|0]=t;a[k+r|0]=s;t=r<<1^r;u=s+1|0;if((u|0)<255){r=(t|0)>255?t^283:t;s=u}else{v=0;break}}do{if((v|0)==0){w=0}else{w=d[l+((d[k+v|0]|0)^255)|0]|0}s=w<<2^w^w<<1^w<<3^w<<4;r=(s>>>8^s)&255^99;a[5897008+r|0]=v;a[5123728+v|0]=r;v=v+1|0;}while((v|0)<256);v=m|0;c[v>>2]=14;c[m+4>>2]=9;c[m+8>>2]=13;c[m+12>>2]=11;m=k|0;k=l|0;sFb(9474184,v,m,k,5897008);v=n|0;c[v>>2]=2;c[n+4>>2]=1;c[n+8>>2]=1;c[n+12>>2]=3;sFb(8976520,v,m,k,5123728)}if(!((f|0)==256|(f|0)==192|(f|0)==128)){x=-1;i=h;return x|0}c[b+272>>2]=q;k=j|0;m=p<<2;nrc(k|0,e|0,m)|0;v=b;nrc(v|0,e|0,m)|0;e=p+7|0;n=e<<4;if((m|0)<(n|0)){l=p-1|0;w=(p|0)>1;r=(p|0)==8;s=f>>6;f=m;u=0;while(1){t=a[k]^a[5123728+(d[j+(l<<2)+1|0]|0)|0];a[k]=t;y=j+1|0;a[y]=a[y]^a[5123728+(d[j+(l<<2)+2|0]|0)|0];y=j+2|0;a[y]=a[y]^a[5123728+(d[j+(l<<2)+3|0]|0)|0];y=j+3|0;a[y]=a[y]^a[5123728+(d[j+(l<<2)|0]|0)|0];y=u+1|0;a[k]=t^a[682392+u|0];if(w){t=1;do{if(r&(t|0)==(s|0)){z=s-1|0;A=j+(s<<2)|0;a[A]=a[A]^a[5123728+(d[j+(z<<2)|0]|0)|0];A=j+(s<<2)+1|0;a[A]=a[A]^a[5123728+(d[j+(z<<2)+1|0]|0)|0];A=j+(s<<2)+2|0;a[A]=a[A]^a[5123728+(d[j+(z<<2)+2|0]|0)|0];A=j+(s<<2)+3|0;a[A]=a[A]^a[5123728+(d[j+(z<<2)+3|0]|0)|0]}else{z=t-1|0;A=j+(t<<2)|0;a[A]=a[A]^a[j+(z<<2)|0];A=j+(t<<2)+1|0;a[A]=a[A]^a[j+(z<<2)+1|0];A=j+(t<<2)+2|0;a[A]=a[A]^a[j+(z<<2)+2|0];A=j+(t<<2)+3|0;a[A]=a[A]^a[j+(z<<2)+3|0]}t=t+1|0;}while((t|0)<(p|0))}nrc(v+f|0,k|0,m)|0;t=f+m|0;if((t|0)<(n|0)){f=t;u=y}else{break}}}if((g|0)!=0){if((q|0)>1){B=1}else{x=0;i=h;return x|0}while(1){g=b+(B<<4)|0;u=g;f=u+4|0;n=b+(B<<4)+8|0;m=u+12|0;k=c[9475208+((d[5123728+(d[u+5|0]|0)|0]|0)<<2)>>2]^c[9474184+((d[5123728+(d[f]|0)|0]|0)<<2)>>2]^c[9476232+((d[5123728+(d[u+6|0]|0)|0]|0)<<2)>>2]^c[9477256+((d[5123728+(d[u+7|0]|0)|0]|0)<<2)>>2];v=c[9475208+((d[5123728+(d[u+9|0]|0)|0]|0)<<2)>>2]^c[9474184+((d[5123728+(d[n]|0)|0]|0)<<2)>>2]^c[9476232+((d[5123728+(d[u+10|0]|0)|0]|0)<<2)>>2]^c[9477256+((d[5123728+(d[u+11|0]|0)|0]|0)<<2)>>2];p=c[9475208+((d[5123728+(d[u+13|0]|0)|0]|0)<<2)>>2]^c[9474184+((d[5123728+(d[m]|0)|0]|0)<<2)>>2]^c[9476232+((d[5123728+(d[u+14|0]|0)|0]|0)<<2)>>2]^c[9477256+((d[5123728+(d[u+15|0]|0)|0]|0)<<2)>>2];c[g>>2]=c[9475208+((d[5123728+(d[u+1|0]|0)|0]|0)<<2)>>2]^c[9474184+((d[5123728+(d[u]|0)|0]|0)<<2)>>2]^c[9476232+((d[5123728+(d[u+2|0]|0)|0]|0)<<2)>>2]^c[9477256+((d[5123728+(d[u+3|0]|0)|0]|0)<<2)>>2];c[f>>2]=k;c[n>>2]=v;c[m>>2]=p;p=B+1|0;if((p|0)<(q|0)){B=p}else{x=0;break}}i=h;return x|0}B=e>>1;if((B|0)<=0){x=0;i=h;return x|0}e=o;o=0;while(1){p=b+(q-o<<4)|0;c[e>>2]=c[p>>2];c[e+4>>2]=c[p+4>>2];c[e+8>>2]=c[p+8>>2];c[e+12>>2]=c[p+12>>2];m=b+(o<<4)|0;c[p>>2]=c[m>>2];c[p+4>>2]=c[m+4>>2];c[p+8>>2]=c[m+8>>2];c[p+12>>2]=c[m+12>>2];c[m>>2]=c[e>>2];c[m+4>>2]=c[e+4>>2];c[m+8>>2]=c[e+8>>2];c[m+12>>2]=c[e+12>>2];m=o+1|0;if((m|0)<(B|0)){o=m}else{x=0;break}}i=h;return x|0}function sFb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=e+4|0;j=e+8|0;k=e+12|0;l=0;do{m=a[h+l|0]|0;if(!(m<<24>>24==0)){n=d[f+(m&255)|0]|0;m=d[g+((d[f+(c[e>>2]|0)|0]|0)+n)|0]|0;o=d[g+((d[f+(c[k>>2]|0)|0]|0)+n)|0]|0;p=(d[g+((d[f+(c[i>>2]|0)|0]|0)+n)|0]|0)<<8|m;q=p|(d[g+((d[f+(c[j>>2]|0)|0]|0)+n)|0]|0)<<16;n=o<<24|q;c[b+(l<<2)>>2]=n;c[b+1024+(l<<2)>>2]=q<<8|o;c[b+2048+(l<<2)>>2]=p<<16|n>>>16;c[b+3072+(l<<2)>>2]=m<<24|n>>>8}l=l+1|0;}while((l|0)<256);return}function tFb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){return}b=a|0;d=c[b>>2]|0;if((d|0)!=0){e=a+4|0;f=c[e>>2]|0;if((f|0)>0){g=0;h=d;i=f;while(1){f=c[h+(g<<2)>>2]|0;if((f|0)==0){j=i;k=h}else{eHb(f);j=c[e>>2]|0;k=c[b>>2]|0}f=g+1|0;if((f|0)<(j|0)){g=f;h=k;i=j}else{l=k;break}}}else{l=d}kJb(l)}kJb(a);return}function uFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+8|0;f=e|0;if((SKb(f,b,d,a,1)|0)<0){g=0;i=e;return g|0}h=pJb(28)|0;j=h;if((h|0)==0){g=0;i=e;return g|0}c[h+16>>2]=b;c[h+20>>2]=a;c[h+24>>2]=(c[f>>2]|0)/(d|0)|0;k=(RKb(a)|0)!=0;a=k?b:1;b=h+4|0;c[b>>2]=a;k=pJb(a<<2)|0;a=k;l=h;c[l>>2]=a;a:do{if((k|0)==0){m=a}else{n=0;while(1){if((n|0)>=(c[b>>2]|0)){break}o=dHb(c[f>>2]|0)|0;c[(c[l>>2]|0)+(n<<2)>>2]=o;o=c[l>>2]|0;if((c[o+(n<<2)>>2]|0)==0){m=o;break a}else{n=n+1|0}}c[h+12>>2]=d;g=j;i=e;return g|0}}while(0);if((m|0)!=0){j=c[b>>2]|0;if((j|0)>0){d=0;f=m;a=j;while(1){j=c[f+(d<<2)>>2]|0;if((j|0)==0){p=a;q=f}else{eHb(j);p=c[b>>2]|0;q=c[l>>2]|0}j=d+1|0;if((j|0)<(p|0)){d=j;f=q;a=p}else{r=q;break}}}else{r=m}kJb(r)}kJb(h);g=0;i=e;return g|0}function vFb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=SKb(e,c[a+16>>2]|0,b,c[a+20>>2]|0,1)|0;if((f|0)<0){g=f;i=d;return g|0}f=a+4|0;h=a|0;j=0;while(1){if((j|0)>=(c[f>>2]|0)){break}k=hHb(c[(c[h>>2]|0)+(j<<2)>>2]|0,c[e>>2]|0)|0;if((k|0)<0){g=k;l=6;break}else{j=j+1|0}}if((l|0)==6){i=d;return g|0}c[a+12>>2]=b;g=0;i=d;return g|0}function wFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=a+12|0;h=a+8|0;j=c[h>>2]|0;do{if(((c[g>>2]|0)-j|0)<(d|0)){if((1073741823-j|0)<(d|0)){k=-22;i=e;return k|0}l=j+d<<1;m=SKb(f,c[a+16>>2]|0,l,c[a+20>>2]|0,1)|0;if((m|0)<0){k=m;i=e;return k|0}m=a+4|0;n=a|0;o=0;while(1){if((o|0)>=(c[m>>2]|0)){p=8;break}q=hHb(c[(c[n>>2]|0)+(o<<2)>>2]|0,c[f>>2]|0)|0;if((q|0)<0){k=q;p=14;break}else{o=o+1|0}}if((p|0)==8){c[g>>2]=l;r=m;s=n;break}else if((p|0)==14){i=e;return k|0}}else{r=a+4|0;s=a|0}}while(0);g=ca(c[a+24>>2]|0,d)|0;a=0;while(1){if((a|0)>=(c[r>>2]|0)){break}if((jHb(c[(c[s>>2]|0)+(a<<2)>>2]|0,c[b+(a<<2)>>2]|0,g,0)|0)!=(g|0)){k=-558323010;p=14;break}a=a+1|0}if((p|0)==14){i=e;return k|0}c[h>>2]=(c[h>>2]|0)+d;k=d;i=e;return k|0}function xFb(a){a=a|0;return(c[a+12>>2]|0)-(c[a+8>>2]|0)|0}function yFb(a){a=a|0;return c[a+8>>2]|0}function zFb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((d|0)<0){e=-22;return e|0}f=a+8|0;g=c[f>>2]|0;h=(g|0)<(d|0)?g:d;if((h|0)==0){e=0;return e|0}d=ca(c[a+24>>2]|0,h)|0;g=a+4|0;i=a|0;a=0;while(1){if((a|0)>=(c[g>>2]|0)){break}if((iHb(c[(c[i>>2]|0)+(a<<2)>>2]|0,c[b+(a<<2)>>2]|0,d,0)|0)<0){e=-558323010;j=7;break}else{a=a+1|0}}if((j|0)==7){return e|0}c[f>>2]=(c[f>>2]|0)-h;e=h;return e|0}function AFb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a[d]|0;a:do{if(f<<24>>24==0){g=d;h=b;i=4}else{j=d;k=b;l=f;while(1){if(!(l<<24>>24==(a[k]|0))){m=l;break a}n=j+1|0;o=k+1|0;p=a[n]|0;if(p<<24>>24==0){g=n;h=o;i=4;break}else{j=n;k=o;l=p}}}}while(0);do{if((i|0)==4){if((e|0)==0){m=0;break}c[e>>2]=h;m=a[g]|0}}while(0);return m<<24>>24==0|0}function BFb(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a[c]|0;if(d<<24>>24==0){e=b;return e|0}else{f=b}a:while(1){b=c;g=f;h=d;while(1){i=h<<24>>24;j=a[g]|0;if((((i-97|0)>>>0<26>>>0?i^32:i)|0)!=(((j-97|0)>>>0<26>>>0?j^32:j)|0)){break}j=b+1|0;i=a[j]|0;if(i<<24>>24==0){e=f;k=8;break a}else{b=j;g=g+1|0;h=i}}if(h<<24>>24==0){e=f;k=8;break}if((a[f]|0)==0){e=0;k=8;break}f=f+1|0}if((k|0)==8){return e|0}return 0}function CFb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:do{if(d>>>0>1>>>0){e=c;f=b;g=1;while(1){h=a[e]|0;if(h<<24>>24==0){i=e;j=f;k=g;break a}l=e+1|0;m=f+1|0;a[f]=h;h=g+1|0;if(h>>>0<d>>>0){e=l;f=m;g=h}else{i=l;j=m;k=h;break}}}else{i=c;j=b;k=1}}while(0);if(!(k>>>0>d>>>0)){a[j]=0}return k-1+(lrc(i|0)|0)|0}function DFb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=lrc(b|0)|0;if(!((e+1|0)>>>0<d>>>0)){f=lrc(c|0)|0;g=f+e|0;return g|0}h=b+e|0;b=d-e|0;a:do{if(b>>>0>1>>>0){d=c;i=h;j=1;while(1){k=a[d]|0;if(k<<24>>24==0){l=d;m=i;n=j;break a}o=d+1|0;p=i+1|0;a[i]=k;k=j+1|0;if(k>>>0<b>>>0){d=o;i=p;j=k}else{l=o;m=p;n=k;break}}}else{l=c;m=h;n=1}}while(0);if(!(n>>>0>b>>>0)){a[m]=0}f=n-1+(lrc(l|0)|0)|0;g=f+e|0;return g|0}function EFb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f|0;h=lrc(a|0)|0;j=g;c[j>>2]=e;c[j+4>>2]=0;j=(Ad(a+h|0,(h>>>0<b>>>0?b-h|0:0)|0,d|0,g|0)|0)+h|0;i=f;return j|0}function FFb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+24|0;e=d|0;f=d+8|0;c[e>>2]=0;g=f|0;h=f;c[h>>2]=b;c[h+4>>2]=0;f=Ad(0,0,a|0,g|0)|0;do{if((f|0)>=0){j=f+1|0;k=hJb(j)|0;c[e>>2]=k;if((k|0)==0){break}c[h>>2]=b;c[h+4>>2]=0;if((Ad(k|0,j|0,a|0,g|0)|0)>=0){break}mJb(e)}}while(0);i=d;return c[e>>2]|0}function GFb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=hJb((lrc(c[b>>2]|0)|0)+1|0)|0;f=c[b>>2]|0;if((e|0)==0){g=0;return g|0}h=f+(ud(f|0,2579544)|0)|0;f=a[h]|0;a:do{if(f<<24>>24==0){i=e;j=h;k=e}else{l=e;m=e;n=h;o=f;while(1){p=l;q=n;r=o;while(1){if((ud(q|0,d|0)|0)!=0){i=p;j=q;k=m;break a}s=q+1|0;if((r<<24>>24|0)==92){t=a[s]|0;if(!(t<<24>>24==0)){u=9;break}}else if((r<<24>>24|0)==39){u=7;break}v=p+1|0;a[p]=r;w=a[s]|0;if(w<<24>>24==0){i=v;j=s;k=m;break a}else{p=v;q=s;r=w}}if((u|0)==7){u=0;r=a[s]|0;w=r<<24>>24==0;v=q+2|0;if(r<<24>>24!=39&(w^1)){x=p;y=r;r=v;while(1){z=x+1|0;a[x]=y;A=a[r]|0;B=A<<24>>24==0;C=r+1|0;if(A<<24>>24!=39&(B^1)){x=z;y=A;r=C}else{D=z;E=r;F=B;G=C;break}}}else{D=p;E=s;F=w;G=v}H=F?E:G;I=F?m:D;J=D}else if((u|0)==9){u=0;r=p+1|0;a[p]=t;H=q+2|0;I=r;J=r}r=a[H]|0;if(r<<24>>24==0){i=J;j=H;k=I;break}else{l=J;m=I;n=H;o=r}}}}while(0);H=i;while(1){i=H-1|0;a[H]=0;if(i>>>0<k>>>0){break}if((ud(i|0,2579544)|0)==0){break}else{H=i}}c[b>>2]=j;g=e;return g|0}function HFb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;do{if((b|0)==0){f=c[e>>2]|0;if((f|0)==0){g=0}else{h=f;break}return g|0}else{h=b}}while(0);b=ud(h|0,d|0)|0;f=h+b|0;if((a[f]|0)==0){c[e>>2]=0;g=0;return g|0}i=b+1|0;b=(mc(h+i|0,d|0)|0)+i|0;i=h+b|0;if((a[i]|0)==0){j=0}else{a[i]=0;j=h+(b+1)|0}c[e>>2]=j;g=f;return g|0}function IFb(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b;b=c;while(1){c=a[d]|0;e=a[b]|0;f=(e-65|0)>>>0<26>>>0?e^32:e;e=((c-65|0)>>>0<26>>>0?c^32:c)&255;if((e|0)==0){break}c=f&255;if((e|0)==(c|0)){d=d+1|0;b=b+1|0}else{g=e;h=c;i=5;break}}if((i|0)==5){j=g-h|0;return j|0}g=0;h=f&255;j=g-h|0;return j|0}function JFb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+d|0;d=b;b=c;while(1){c=d+1|0;f=a[d]|0;g=a[b]|0;h=(g-65|0)>>>0<26>>>0?g^32:g;g=((f-65|0)>>>0<26>>>0?f^32:f)&255;if(!(c>>>0<e>>>0)){i=g;break}if((g|0)==0){i=0;break}if((g|0)==(h&255|0)){d=c;b=b+1|0}else{i=g;break}}return i-(h&255)|0}function KFb(a){a=a|0;var b=0;b=hc(a|0,47)|0;return((b|0)==0?a:b+1|0)|0}function LFb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+1024|0;h=g|0;SFb(h,1,-1);$Fb(h,b,d,e,f);f=h+4|0;if((c[f>>2]|0)>>>0<(c[h+8>>2]|0)>>>0){_Fb(h,a)|0;j=c[f>>2]|0;i=g;return j|0}else{_Fb(h,0)|0;j=-12;i=g;return j|0}return 0}function MFb(a){a=a|0;var b=0;if((a|0)>47){b=(a|0)<58|0}else{b=0}return b|0}function NFb(a){a=a|0;var b=0;if((a|0)>32){b=(a|0)<127|0}else{b=0}return b|0}function OFb(a){a=a|0;var b=0;switch(a|0){case 32:case 13:case 12:case 10:case 9:{b=1;break};default:{b=(a|0)==11|0}}return b|0}function PFb(a){a=a|0;var b=0,c=0;b=(a-65|0)>>>0<26>>>0?a^32:a;do{if((b|0)>47){if((b|0)<58){c=1;break}if((b|0)<=96){c=0;break}c=(b|0)<103|0}else{c=0}}while(0);return c|0}function QFb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=b+e|0;g=f;a:do{if((e|0)>3){h=b;i=c;while(1){j=d[838432+(d[i]|0)|0]|0;if((j&128|0)!=0){k=j;l=h;break a}m=d[838432+(d[i+1|0]|0)|0]|0;if((m&128|0)!=0){k=m;l=h;break a}n=m+(j<<6)|0;o=d[838432+(d[i+2|0]|0)|0]|0;if((o&128|0)!=0){p=24;break}q=o+(n<<6)|0;r=d[838432+(d[i+3|0]|0)|0]|0;if((r&128|0)!=0){p=22;break}j=h;y=je(r+(q<<6)<<8|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=h+3|0;m=i+4|0;if((g-j|0)>3){h=j;i=m}else{s=j;t=m;p=7;break a}}if((p|0)==22){u=q>>>10&255;v=q>>>2&255;w=r;x=h;p=23;break}else if((p|0)==24){z=n>>>4&255;A=o;B=h;p=25;break}}else{s=b;t=c;p=7}}while(0);b:do{if((p|0)==7){if((f|0)==(s|0)){C=t;D=f}else{c=d[838432+(d[t]|0)|0]|0;if((c&128|0)!=0){k=c;l=s;break}o=d[838432+(d[t+1|0]|0)|0]|0;if((o&128|0)!=0){k=o;l=s;break}n=o+(c<<6)|0;c=d[838432+(d[t+2|0]|0)|0]|0;if((c&128|0)!=0){z=n>>>4&255;A=c;B=s;p=25;break}o=c+(n<<6)|0;n=d[838432+(d[t+3|0]|0)|0]|0;if((n&128|0)!=0){u=o>>>10&255;v=o>>>2&255;w=n;x=s;p=23;break}c=n+(o<<6)|0;o=s+1|0;a[s]=c>>>16;if((f|0)==(o|0)){E=f}else{a[o]=c>>>8;E=s+2|0}if((f|0)==(E|0)){F=f}else{a[E]=c;F=E+1|0}C=t+4|0;D=F}c=C;while(1){o=d[838432+(d[c]|0)|0]|0;if((o&128|0)!=0){k=o;l=D;break b}o=d[838432+(d[c+1|0]|0)|0]|0;if((o&128|0)!=0){k=o;l=D;break b}o=d[838432+(d[c+2|0]|0)|0]|0;if((o&128|0)!=0){k=o;l=D;break b}o=d[838432+(d[c+3|0]|0)|0]|0;if((o&128|0)==0){c=c+4|0}else{k=o;l=D;break}}}}while(0);if((p|0)==23){a[x]=u;z=v;A=w;B=x+1|0;p=25}if((p|0)==25){a[B]=z;k=A;l=B+1|0}if((k&1|0)!=0){G=-1094995529;return G|0}G=l-b|0;return G|0}function RFb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if(f>>>0>1073741822>>>0){g=0;return g|0}if((((f+2|0)/3|0)<<2|1|0)>(c|0)){g=0;return g|0}if((f|0)>3){c=((f-4|0)>>>0)/3|0;h=b+((c<<2)+4)|0;i=c*3|0;c=i+3|0;j=e;k=b;l=f;while(1){m=j;n=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;m=l-3|0;a[k]=a[2004352+(n>>>26)|0]|0;a[k+1|0]=a[2004352+(n>>>20&63)|0]|0;a[k+2|0]=a[2004352+(n>>>14&63)|0]|0;a[k+3|0]=a[2004352+(n>>>8&63)|0]|0;if((m|0)>3){j=j+3|0;k=k+4|0;l=m}else{break}}o=e+c|0;p=h;q=f-3-i|0}else{o=e;p=b;q=f}do{if((q|0)==0){r=p}else{f=o;e=0;i=q;while(1){s=d[f]|0|e<<8;h=i-1|0;if((h|0)==0){break}else{f=f+1|0;e=s;i=h}}i=q<<3;e=s<<6;if((i|0)<=0){r=p;break}f=(((i-1|0)>>>0)/6|0)+1|0;h=p;c=i;while(1){a[h]=a[2004352+(e>>>(c>>>0)&63)|0]|0;i=c-6|0;if((i|0)>0){h=h+1|0;c=i}else{break}}r=p+f|0}}while(0);p=b;if((r-p&3|0)==0){t=r}else{s=r;while(1){r=s+1|0;a[s]=61;if((r-p&3|0)==0){t=r;break}else{s=r}}}a[t]=0;g=b;return g|0}function SFb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b+16|0;g=(e|0)==1?1008:e;e=b|0;c[e>>2]=f;h=b+4|0;c[h>>2]=0;i=g>>>0<1008>>>0?g:1008;j=b+8|0;c[j>>2]=i;c[b+12>>2]=g;a[f]=0;if(!(i>>>0<d>>>0)){return}if((i|0)==(g|0)|(i|0)==0){return}f=(d-1|0)>>>0<4294967294>>>0?d:-1;d=i>>>0>g>>>1>>>0?g:i<<1;if(d>>>0<f>>>0){k=g>>>0>f>>>0?f:g}else{k=d}d=iJb(0,k)|0;if((d|0)==0){return}nrc(d|0,c[e>>2]|0,(c[h>>2]|0)+1|0)|0;c[e>>2]=d;c[j>>2]=k;return}function TFb(b,d,e){b=b|0;d=d|0;e=e|0;c[b>>2]=d;c[b+4>>2]=0;c[b+8>>2]=e;c[b+12>>2]=e;a[d]=0;return}function UFb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f|0;h=b+8|0;j=b+4|0;k=g|0;l=g;g=b+12|0;m=b|0;n=b+16|0;b=c[h>>2]|0;while(1){o=c[j>>2]|0;p=o>>>0>b>>>0?b:o;q=b-p|0;if((b|0)==(p|0)){r=0}else{r=(c[m>>2]|0)+o|0}c[l>>2]=e;c[l+4>>2]=0;s=Ad(r|0,q|0,d|0,k|0)|0;if((s|0)<1){t=16;break}if(s>>>0<q>>>0){break}q=c[h>>2]|0;o=c[g>>2]|0;if((q|0)==(o|0)){break}p=c[j>>2]|0;if(!(p>>>0<q>>>0)){break}u=-2-p|0;v=p+1+(u>>>0>s>>>0?s:u)|0;u=q>>>0>o>>>1>>>0?o:q<<1;if(u>>>0<v>>>0){w=o>>>0>v>>>0?v:o}else{w=u}u=c[m>>2]|0;o=(u|0)==(n|0)?0:u;u=iJb(o,w)|0;if((u|0)==0){break}if((o|0)==0){nrc(u|0,c[m>>2]|0,(c[j>>2]|0)+1|0)|0}c[m>>2]=u;c[h>>2]=w;b=w}if((t|0)==16){i=f;return}t=c[j>>2]|0;w=-6-t|0;b=(w>>>0<s>>>0?w:s)+t|0;c[j>>2]=b;j=c[h>>2]|0;if((j|0)==0){i=f;return}h=j-1|0;a[(c[m>>2]|0)+(b>>>0>h>>>0?h:b)|0]=0;i=f;return}function VFb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f|0;h=b+8|0;j=b+4|0;k=g|0;l=g;g=e;e=b+12|0;m=b|0;n=b+16|0;b=c[h>>2]|0;while(1){o=c[j>>2]|0;p=o>>>0>b>>>0?b:o;q=b-p|0;if((b|0)==(p|0)){r=0}else{r=(c[m>>2]|0)+o|0}Kc(l|0,g|0);s=Ad(r|0,q|0,d|0,k|0)|0;if((s|0)<1){t=16;break}if(s>>>0<q>>>0){break}q=c[h>>2]|0;o=c[e>>2]|0;if((q|0)==(o|0)){break}p=c[j>>2]|0;if(!(p>>>0<q>>>0)){break}u=-2-p|0;v=p+1+(u>>>0>s>>>0?s:u)|0;u=q>>>0>o>>>1>>>0?o:q<<1;if(u>>>0<v>>>0){w=o>>>0>v>>>0?v:o}else{w=u}u=c[m>>2]|0;o=(u|0)==(n|0)?0:u;u=iJb(o,w)|0;if((u|0)==0){break}if((o|0)==0){nrc(u|0,c[m>>2]|0,(c[j>>2]|0)+1|0)|0}c[m>>2]=u;c[h>>2]=w;b=w}if((t|0)==16){i=f;return}t=c[j>>2]|0;w=-6-t|0;b=(w>>>0<s>>>0?w:s)+t|0;c[j>>2]=b;j=c[h>>2]|0;if((j|0)==0){i=f;return}h=j-1|0;a[(c[m>>2]|0)+(b>>>0>h>>>0?h:b)|0]=0;i=f;return}function WFb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=b+12|0;g=b+4|0;h=b+8|0;i=c[h>>2]|0;j=c[g>>2]|0;k=j>>>0>i>>>0?i:j;l=i-k|0;a:do{if(l>>>0>e>>>0){m=i;n=k;o=l}else{p=b|0;q=b+16|0;r=i;s=k;t=l;u=j;while(1){v=c[f>>2]|0;if(!((r|0)!=(v|0)&u>>>0<r>>>0)){m=r;n=s;o=t;break a}w=-2-u|0;x=u+1+(w>>>0>e>>>0?e:w)|0;w=r>>>0>v>>>1>>>0?v:r<<1;if(w>>>0<x>>>0){y=v>>>0>x>>>0?x:v}else{y=w}w=c[p>>2]|0;v=(w|0)==(q|0)?0:w;w=iJb(v,y)|0;if((w|0)==0){m=r;n=s;o=t;break a}if((v|0)==0){nrc(w|0,c[p>>2]|0,(c[g>>2]|0)+1|0)|0}c[p>>2]=w;c[h>>2]=y;w=c[g>>2]|0;v=w>>>0>y>>>0?y:w;x=y-v|0;if(x>>>0>e>>>0){m=y;n=v;o=x;break}else{r=y;s=v;t=x;u=w}}}}while(0);if((m|0)!=(n|0)){n=o-1|0;mrc((c[b>>2]|0)+(c[g>>2]|0)|0,d|0,(n>>>0<e>>>0?n:e)|0)|0}n=c[g>>2]|0;d=-6-n|0;o=(d>>>0<e>>>0?d:e)+n|0;c[g>>2]=o;g=c[h>>2]|0;if((g|0)==0){return}h=g-1|0;a[(c[b>>2]|0)+(o>>>0>h>>>0?h:o)|0]=0;return}function XFb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=b+12|0;g=b+4|0;h=b+8|0;i=c[h>>2]|0;j=c[g>>2]|0;k=j>>>0>i>>>0?i:j;l=i-k|0;a:do{if(l>>>0>e>>>0){m=i;n=k;o=l}else{p=b|0;q=b+16|0;r=i;s=k;t=l;u=j;while(1){v=c[f>>2]|0;if(!((r|0)!=(v|0)&u>>>0<r>>>0)){m=r;n=s;o=t;break a}w=-2-u|0;x=u+1+(w>>>0>e>>>0?e:w)|0;w=r>>>0>v>>>1>>>0?v:r<<1;if(w>>>0<x>>>0){y=v>>>0>x>>>0?x:v}else{y=w}w=c[p>>2]|0;v=(w|0)==(q|0)?0:w;w=iJb(v,y)|0;if((w|0)==0){m=r;n=s;o=t;break a}if((v|0)==0){nrc(w|0,c[p>>2]|0,(c[g>>2]|0)+1|0)|0}c[p>>2]=w;c[h>>2]=y;w=c[g>>2]|0;v=w>>>0>y>>>0?y:w;x=y-v|0;if(x>>>0>e>>>0){m=y;n=v;o=x;break}else{r=y;s=v;t=x;u=w}}}}while(0);if((m|0)!=(n|0)){n=o-1|0;nrc((c[b>>2]|0)+(c[g>>2]|0)|0,d|0,n>>>0<e>>>0?n:e)|0}n=c[g>>2]|0;d=-6-n|0;o=(d>>>0<e>>>0?d:e)+n|0;c[g>>2]=o;g=c[h>>2]|0;if((g|0)==0){return}h=g-1|0;a[(c[b>>2]|0)+(o>>>0>h>>>0?h:o)|0]=0;return}function YFb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=a+8|0;g=c[f>>2]|0;h=a+4|0;i=c[h>>2]|0;do{if((g-(i>>>0>g>>>0?g:i)|0)>>>0<b>>>0){j=c[a+12>>2]|0;if(!((g|0)!=(j|0)&i>>>0<g>>>0)){k=g;break}l=-2-i|0;m=i+1+(l>>>0>b>>>0?b:l)|0;l=g>>>0>j>>>1>>>0?j:g<<1;if(l>>>0<m>>>0){n=j>>>0>m>>>0?m:j}else{n=l}l=a|0;j=c[l>>2]|0;m=(j|0)==(a+16|0)?0:j;j=iJb(m,n)|0;if((j|0)==0){k=c[f>>2]|0;break}if((m|0)==0){nrc(j|0,c[l>>2]|0,(c[h>>2]|0)+1|0)|0}c[l>>2]=j;c[f>>2]=n;k=n}else{k=g}}while(0);g=c[h>>2]|0;n=g>>>0>k>>>0?k:g;c[e>>2]=k-n;if((k|0)==(n|0)){o=0;c[d>>2]=o;return}o=(c[a>>2]|0)+(c[h>>2]|0)|0;c[d>>2]=o;return}function ZFb(b){b=b|0;var d=0;d=b+4|0;if((c[d>>2]|0)==0){return}a[c[b>>2]|0]=0;c[d>>2]=0;return}function _Fb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(c[a+4>>2]|0)+1|0;e=a+8|0;f=c[e>>2]|0;g=d>>>0>f>>>0?f:d;d=a|0;f=c[d>>2]|0;h=(f|0)!=(a+16|0);if((b|0)==0){if(!h){i=0;c[e>>2]=g;return i|0}mJb(a);i=0;c[e>>2]=g;return i|0}do{if(h){a=iJb(f,g)|0;if((a|0)==0){j=c[d>>2]|0}else{j=a}c[d>>2]=0;k=0;l=j}else{a=hJb(g)|0;if((a|0)==0){k=-12;l=0;break}nrc(a|0,c[d>>2]|0,g)|0;k=0;l=a}}while(0);c[b>>2]=l;i=k;c[e>>2]=g;return i|0}function $Fb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;if((f|0)==2){WFb(b,39,1);f=d;while(1){j=a[f]|0;if((j<<24>>24|0)==39){UFb(b,2579480,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k}else if((j<<24>>24|0)==0){break}else{WFb(b,j,1)}f=f+1|0}WFb(b,39,1);i=h;return}f=a[d]|0;if(f<<24>>24==0){i=h;return}j=(g&2|0)==0;k=(g&1|0)!=0;if((e|0)==0){g=d;l=f;do{if((g|0)==(d|0)){m=0}else{m=(a[g+1|0]|0)!=0}n=l<<24>>24;o=Ob(2436264,n|0,4)|0;p=(Ob(2349560,n|0,3)|0)!=0;n=(o|0)==0;do{if(j){if((m|n)&((p|n?p:k)^1)){q=l;break}WFb(b,92,1);q=a[g]|0}else{q=l}}while(0);WFb(b,q,1);g=g+1|0;l=a[g]|0;}while(!(l<<24>>24==0));i=h;return}if(j){r=d;s=f}else{j=d;l=f;do{if((_b(e|0,l<<24>>24|0)|0)==0){t=l}else{WFb(b,92,1);t=a[j]|0}WFb(b,t,1);j=j+1|0;l=a[j]|0;}while(!(l<<24>>24==0));i=h;return}do{if((r|0)==(d|0)){u=0}else{u=(a[r+1|0]|0)!=0}l=s<<24>>24;do{if((_b(e|0,l|0)|0)==0){j=Ob(2436264,l|0,4)|0;t=(Ob(2349560,l|0,3)|0)!=0;f=(j|0)==0;if(t|f){if((u|f)&(t^1)){v=s;break}else{w=17;break}}else{if((u|f)&(k^1)){v=s;break}else{w=17;break}}}else{w=17}}while(0);if((w|0)==17){w=0;WFb(b,92,1);v=a[r]|0}WFb(b,v,1);r=r+1|0;s=a[r]|0;}while(!(s<<24>>24==0));i=h;return}function aGb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+8|0;h=g|0;j=pJb(24)|0;c[h>>2]=j;if((j|0)==0){k=0;i=g;return k|0}c[j>>2]=a;c[j+4>>2]=b;c[j+12>>2]=(d|0)!=0?d:116;c[j+16>>2]=e;c[j+8>>2]=1;if((f&1|0)!=0){f=(c[h>>2]|0)+20|0;c[f>>2]=c[f>>2]|1}f=pJb(12)|0;if((f|0)==0){mJb(h);k=0;i=g;return k|0}else{c[f>>2]=c[h>>2];c[f+4>>2]=a;c[f+8>>2]=b;k=f;i=g;return k|0}return 0}function bGb(a,b){a=a|0;b=b|0;kJb(b);return}function cGb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=hJb(a)|0;c[e>>2]=f;if((f|0)==0){g=0;i=b;return g|0}h=d;j=pJb(24)|0;c[d>>2]=j;do{if((j|0)!=0){c[j>>2]=f;c[j+4>>2]=a;c[j+12>>2]=116;c[j+16>>2]=0;c[j+8>>2]=1;k=pJb(12)|0;if((k|0)==0){mJb(h);break}c[k>>2]=c[d>>2];c[k+4>>2]=f;c[k+8>>2]=a;g=k;i=b;return g|0}}while(0);mJb(e);g=0;i=b;return g|0}function dGb(a){a=a|0;var b=0,d=0;b=cGb(a)|0;if((b|0)==0){d=0;return d|0}mrc(c[b+4>>2]|0,0,a|0)|0;d=b;return d|0}function eGb(a){a=a|0;var b=0,d=0,e=0;b=pJb(12)|0;if((b|0)==0){d=0;return d|0}e=a;c[b>>2]=c[e>>2];c[b+4>>2]=c[e+4>>2];c[b+8>>2]=c[e+8>>2];e=(c[a>>2]|0)+8|0;E=c[e>>2]|0,c[e>>2]=E+1,E;d=b;return d|0}function fGb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;if((a|0)==0){i=b;return}e=c[a>>2]|0;if((e|0)==0){i=b;return}f=c[e>>2]|0;c[d>>2]=f;mJb(a);a=f+8|0;if(((E=c[a>>2]|0,c[a>>2]=E+ -1,E)|0)!=1){i=b;return}a=c[d>>2]|0;re[c[a+12>>2]&1023](c[a+16>>2]|0,c[a>>2]|0);mJb(d);i=b;return}function gGb(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;if((c[b+20>>2]&1|0)!=0){d=0;return d|0}d=(c[b+8>>2]|0)==1|0;return d|0}function hGb(a){a=a|0;return c[(c[a>>2]|0)+8>>2]|0}function iGb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=c[a>>2]|0;f=c[e>>2]|0;do{if((c[f+20>>2]&1|0)==0){if((c[f+8>>2]|0)==1){g=0}else{break}i=b;return g|0}}while(0);f=e+8|0;h=cGb(c[f>>2]|0)|0;if((h|0)==0){g=-12;i=b;return g|0}nrc(c[h+4>>2]|0,c[e+4>>2]|0,c[f>>2]|0)|0;f=d;do{if((a|0)!=0){e=c[a>>2]|0;if((e|0)==0){break}j=c[e>>2]|0;c[d>>2]=j;mJb(a);e=j+8|0;if(((E=c[e>>2]|0,c[e>>2]=E+ -1,E)|0)!=1){break}e=c[d>>2]|0;re[c[e+12>>2]&1023](c[e+16>>2]|0,c[e>>2]|0);mJb(f)}}while(0);c[a>>2]=h;g=0;i=b;return g|0}function jGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=c[a>>2]|0;if((j|0)==0){k=iJb(0,b)|0;c[g>>2]=k;if((k|0)==0){l=-12;i=d;return l|0}m=f;n=pJb(24)|0;c[f>>2]=n;do{if((n|0)!=0){c[n>>2]=k;c[n+4>>2]=b;c[n+12>>2]=116;c[n+16>>2]=0;c[n+8>>2]=1;o=pJb(12)|0;if((o|0)==0){mJb(m);break}p=c[f>>2]|0;c[o>>2]=p;c[o+4>>2]=k;c[o+8>>2]=b;q=p+20|0;c[q>>2]=c[q>>2]|2;c[a>>2]=o;l=0;i=d;return l|0}}while(0);mJb(g);l=-12;i=d;return l|0}g=j+8|0;if((c[g>>2]|0)==(b|0)){l=0;i=d;return l|0}k=j|0;f=c[k>>2]|0;do{if((c[f+20>>2]&3|0)==2){if((c[f+8>>2]|0)!=1){break}m=iJb(c[c[k>>2]>>2]|0,b)|0;if((m|0)==0){l=-12;i=d;return l|0}c[j+4>>2]=m;c[c[k>>2]>>2]=m;c[g>>2]=b;c[(c[k>>2]|0)+4>>2]=b;l=0;i=d;return l|0}}while(0);c[h>>2]=0;jGb(h,b)|0;k=c[h>>2]|0;if((k|0)==0){l=-12;i=d;return l|0}f=c[g>>2]|0;nrc(c[k+4>>2]|0,c[j+4>>2]|0,(f|0)<(b|0)?f:b)|0;b=e;do{if((a|0)!=0){f=c[a>>2]|0;if((f|0)==0){break}j=c[f>>2]|0;c[e>>2]=j;mJb(a);f=j+8|0;if(((E=c[f>>2]|0,c[f>>2]=E+ -1,E)|0)!=1){break}f=c[e>>2]|0;re[c[f+12>>2]&1023](c[f+16>>2]|0,c[f>>2]|0);mJb(b)}}while(0);c[a>>2]=c[h>>2];l=0;i=d;return l|0}function kGb(a,b){a=a|0;b=b|0;var d=0,e=0;d=pJb(20)|0;if((d|0)==0){e=0;return e|0}c[d+12>>2]=a;c[d+16>>2]=(b|0)!=0?b:1736;c[d+4>>2]=1;e=d;return e|0}function lGb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;e=b+8|0;if((a|0)==0){i=b;return}f=c[a>>2]|0;if((f|0)==0){i=b;return}c[a>>2]=0;a=f+4|0;if(((E=c[a>>2]|0,c[a>>2]=E+ -1,E)|0)!=1){i=b;return}a=d;g=e;c[d>>2]=f;h=f|0;if((c[h>>2]|0)!=0){f=h;do{h=c[f>>2]|0;c[e>>2]=h;c[c[d>>2]>>2]=c[h+16>>2];h=c[e>>2]|0;re[c[h+8>>2]&1023](c[h+4>>2]|0,c[h>>2]|0);mJb(g);f=c[d>>2]|0;}while((c[f>>2]|0)!=0)}mJb(a);i=b;return}function mGb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=a;h=a;j=0;k=c[g>>2]|0;while(1){l=k;if((l|0)==(j|0)){m=4;break}n=(E=c[h>>2]|0,(c[h>>2]|0)==(k|0)?(c[h>>2]=0)|0:0,E);if((n|0)==0){m=5;break}else{j=l;k=n}}if((m|0)==4){if((j|0)==0){m=5}else{o=j}}a:do{if((m|0)==5){j=a+4|0;k=a+8|0;b:do{if((c[j>>2]|0)<=(c[k>>2]|0)){KIb(0,48,2414352,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;c:while(1){if((c[j>>2]|0)>(c[k>>2]|0)){break b}n=0;l=c[g>>2]|0;while(1){p=l;if((p|0)==(n|0)){break}q=(E=c[h>>2]|0,(c[h>>2]|0)==(l|0)?(c[h>>2]=0)|0:0,E);if((q|0)==0){continue c}else{n=p;l=q}}if((n|0)!=0){o=n;break a}}}}while(0);l=ve[c[a+16>>2]&4095](c[a+12>>2]|0)|0;c[e>>2]=l;if((l|0)==0){r=0;i=b;return r|0}q=pJb(20)|0;if((q|0)!=0){p=l|0;c[q>>2]=c[c[p>>2]>>2];c[q+4>>2]=c[(c[p>>2]|0)+16>>2];c[q+8>>2]=c[(c[p>>2]|0)+12>>2];c[q+12>>2]=a;c[(c[p>>2]|0)+16>>2]=q;c[(c[c[e>>2]>>2]|0)+12>>2]=96;E=c[j>>2]|0,c[j>>2]=E+1,E;E=c[k>>2]|0,c[k>>2]=E+1,E;r=c[e>>2]|0;i=b;return r|0}q=c[l>>2]|0;c[d>>2]=q;mJb(e);l=q+8|0;if(((E=c[l>>2]|0,c[l>>2]=E+ -1,E)|0)!=1){r=0;i=b;return r|0}l=c[d>>2]|0;re[c[l+12>>2]&1023](c[l+16>>2]|0,c[l>>2]|0);mJb(d);r=0;i=b;return r|0}}while(0);d=(o|0)==0;e=o+16|0;h=c[e>>2]|0;do{if((h|0)!=0){g=c[h+12>>2]|0;m=h+16|0;if((c[m>>2]|0)==0){s=h}else{l=m;while(1){m=c[l>>2]|0;q=m+16|0;if((c[q>>2]|0)==0){s=m;break}else{l=q}}}l=g;k=h;if(((E=c[l>>2]|0,(c[l>>2]|0)==0?(c[l>>2]=k)|0:0,E)|0)==0){break}j=g;q=s;while(1){m=0;p=c[j>>2]|0;while(1){t=p;if((t|0)==(m|0)){u=m;break}v=(E=c[l>>2]|0,(c[l>>2]|0)==(p|0)?(c[l>>2]=0)|0:0,E);if((v|0)==0){u=0;break}else{m=t;p=v}}p=q+16|0;c[p>>2]=u;if((c[p>>2]|0)==0){w=q}else{m=p;while(1){p=c[m>>2]|0;v=p+16|0;if((c[v>>2]|0)==0){w=p;break}else{m=v}}}if(((E=c[l>>2]|0,(c[l>>2]|0)==0?(c[l>>2]=k)|0:0,E)|0)==0){break}else{q=w}}}}while(0);c[e>>2]=0;w=c[o>>2]|0;u=c[a+12>>2]|0;s=f;h=pJb(24)|0;c[f>>2]=h;do{if((h|0)!=0){c[h>>2]=w;c[h+4>>2]=u;c[h+12>>2]=96;c[h+16>>2]=o;c[h+8>>2]=1;q=pJb(12)|0;if((q|0)==0){mJb(s);break}c[q>>2]=c[f>>2];c[q+4>>2]=w;c[q+8>>2]=u;k=q;q=a+4|0;E=c[q>>2]|0,c[q>>2]=E+1,E;r=k;i=b;return r|0}}while(0);if(d){r=0;i=b;return r|0}d=c[o+12>>2]|0;if((c[e>>2]|0)==0){x=o}else{a=e;while(1){e=c[a>>2]|0;u=e+16|0;if((c[u>>2]|0)==0){x=e;break}else{a=u}}}a=d;u=o;if(((E=c[a>>2]|0,(c[a>>2]|0)==0?(c[a>>2]=u)|0:0,E)|0)==0){r=0;i=b;return r|0}o=d;d=x;while(1){x=0;e=c[o>>2]|0;while(1){w=e;if((w|0)==(x|0)){y=x;break}f=(E=c[a>>2]|0,(c[a>>2]|0)==(e|0)?(c[a>>2]=0)|0:0,E);if((f|0)==0){y=0;break}else{x=w;e=f}}e=d+16|0;c[e>>2]=y;if((c[e>>2]|0)==0){z=d}else{x=e;while(1){e=c[x>>2]|0;f=e+16|0;if((c[f>>2]|0)==0){z=e;break}else{x=f}}}if(((E=c[a>>2]|0,(c[a>>2]|0)==0?(c[a>>2]=u)|0:0,E)|0)==0){r=0;break}else{d=z}}i=b;return r|0}function nGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=c[a+12>>2]|0;do{if((a|0)!=0){g=a+16|0;if((c[g>>2]|0)==0){h=a}else{j=g;while(1){g=c[j>>2]|0;k=g+16|0;if((c[k>>2]|0)==0){h=g;break}else{j=k}}}j=f;k=a;if(((E=c[j>>2]|0,(c[j>>2]|0)==0?(c[j>>2]=k)|0:0,E)|0)==0){break}g=f;l=h;while(1){m=0;n=c[g>>2]|0;while(1){o=n;if((o|0)==(m|0)){p=m;break}q=(E=c[j>>2]|0,(c[j>>2]|0)==(n|0)?(c[j>>2]=0)|0:0,E);if((q|0)==0){p=0;break}else{m=o;n=q}}n=l+16|0;c[n>>2]=p;if((c[n>>2]|0)==0){r=l}else{m=n;while(1){n=c[m>>2]|0;q=n+16|0;if((c[q>>2]|0)==0){r=n;break}else{m=q}}}if(((E=c[j>>2]|0,(c[j>>2]|0)==0?(c[j>>2]=k)|0:0,E)|0)==0){break}else{l=r}}}}while(0);r=f+4|0;if(((E=c[r>>2]|0,c[r>>2]=E+ -1,E)|0)!=1){i=b;return}r=d;p=e;c[d>>2]=f;h=f|0;if((c[h>>2]|0)!=0){f=h;do{h=c[f>>2]|0;c[e>>2]=h;c[c[d>>2]>>2]=c[h+16>>2];h=c[e>>2]|0;re[c[h+8>>2]&1023](c[h+4>>2]|0,c[h>>2]|0);mJb(p);f=c[d>>2]|0;}while((c[f>>2]|0)!=0)}mJb(r);i=b;return}function oGb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+8|0;f=e|0;g=lrc(b|0)|0;h=b+g|0;if((g|0)<=0){j=0;k=0;i=e;return(G=j,k)|0}g=(d|0)==0;d=b;b=0;l=0;a:while(1){b:do{if(d>>>0<h>>>0){m=d;while(1){n=a[m]|0;if((n<<24>>24|0)==43|(n<<24>>24|0)==124){o=m;break b}n=m+1|0;if(n>>>0<h>>>0){m=n}else{o=n;break}}}else{o=d}}while(0);m=d;n=o-m|0;p=0;while(1){q=c[1712200+(p<<4)>>2]|0;if((lrc(q|0)|0)==(n|0)){if((grc(q,d,n)|0)==0){r=9;break}}q=p+1|0;if(q>>>0<27>>>0){p=q}else{s=0;r=11;break}}c:do{if((r|0)==9){r=0;q=1712208+(p<<4)|0;t=c[q+4>>2]|0;u=c[q>>2]|0;r=32}else if((r|0)==11){d:while(1){r=0;do{if((s-18|0)>>>0>10>>>0){q=c[1711912+(s<<3)>>2]|0;if((lrc(q|0)|0)!=(n|0)){break}if((grc(q,d,n)|0)==0){r=14;break d}}}while(0);q=s+1|0;if(q>>>0<36>>>0){s=q;r=11}else{break}}if((r|0)==14){r=0;q=yrc(1,0,s|0)|0;v=G;w=q;break}q=rb(d|0,f|0,10)|0;x=c[f>>2]|0;do{if(g){if((x+1-m|0)!=(n|0)){break}if((a[x]|0)==99){y=0}else{break}while(1){if(!(y>>>0<27>>>0)){j=0;k=0;r=34;break a}if((c[1712204+(y<<4)>>2]|0)==(q|0)){break}else{y=y+1|0}}z=1712208+(y<<4)|0;t=c[z+4>>2]|0;u=c[z>>2]|0;r=32;break c}else{z=(x-m|0)==(n|0);if(z){A=0}else{if((x+1-m|0)!=(n|0)){break}if((a[x]|0)==99){A=0}else{break}}while(1){if(!(A>>>0<27>>>0)){B=0;C=0;break}if((c[1712204+(A<<4)>>2]|0)==(q|0)){r=22;break}else{A=A+1|0}}if((r|0)==22){r=0;D=1712208+(A<<4)|0;B=c[D+4>>2]|0;C=c[D>>2]|0}if(!z){break}KIb(0,24,2147360,(D=i,i=i+32|0,c[D>>2]=n,c[D+8>>2]=d,c[D+16>>2]=n,c[D+24>>2]=d,D)|0);i=D;t=B;u=C;r=32;break c}}while(0);q=Jd(d|0,f|0,0)|0;x=G;if(((c[f>>2]|0)-m|0)!=(n|0)){j=0;k=0;r=34;break a}D=0;E=(x|0)>(D|0)|(x|0)==(D|0)&q>>>0>0>>>0;t=E?x:0;u=E?q:0;r=32}}while(0);if((r|0)==32){r=0;if((u|0)==0&(t|0)==0){j=0;k=0;r=34;break}else{v=t;w=u}}n=w|l;m=v|b;p=o+1|0;if(p>>>0<h>>>0){d=p;b=m;l=n}else{j=m;k=n;r=34;break}}if((r|0)==34){i=e;return(G=j,k)|0}return 0}function pGb(a){a=a|0;var b=0;b=oGb(a,1)|0;return(G=G,b)|0}function qGb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;if((b|0)<1){g=d;h=g-(g>>>1&1431655765)|0;g=(h>>>2&858993459)+(h&858993459)|0;h=(g>>>4)+g&252645135;g=(h>>>8)+h|0;h=e-((e>>>1|0<<31)&1431655765)|0;j=(h>>>2&858993459)+(h&858993459)|0;h=(j>>>4)+j&252645135;j=(h>>>8)+h|0;k=((g>>>16)+g&63)+((j>>>16)+j&63)|0}else{k=b}b=0;while(1){if((k|0)==(c[1712204+(b<<4)>>2]|0)){j=1712208+(b<<4)|0;if((c[j>>2]|0)==(d|0)&(c[j+4>>2]|0)==(e|0)){l=6;break}}j=b+1|0;if(j>>>0<27>>>0){b=j}else{break}}if((l|0)==6){UFb(a,2414160,(m=i,i=i+8|0,c[m>>2]=c[1712200+(b<<4)>>2],m)|0);i=m;i=f;return}UFb(a,2579288,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;if((d|0)==0&(e|0)==0){i=f;return}UFb(a,2436200,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;k=0;b=0;while(1){l=yrc(1,0,k|0)|0;if((l&d|0)==0&(G&e|0)==0){n=b}else{do{if(!(k>>>0>35>>>0)){l=c[1711912+(k<<3)>>2]|0;if((k-18|0)>>>0<11>>>0){break}if((b|0)>0){UFb(a,2349552,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}UFb(a,2414160,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m}}while(0);n=b+1|0}l=k+1|0;if((l|0)<64){k=l;b=n}else{break}}UFb(a,2287824,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;i=f;return}function rGb(a,b){a=a|0;b=b|0;var c=0;c=a;a=c-(c>>>1&1431655765)|0;c=(a>>>2&858993459)+(a&858993459)|0;a=(c>>>4)+c&252645135;c=(a>>>8)+a|0;a=b-((b>>>1|0<<31)&1431655765)|0;b=(a>>>2&858993459)+(a&858993459)|0;a=(b>>>4)+b&252645135;b=(a>>>8)+a|0;return((c>>>16)+c&63)+((b>>>16)+b&63)|0}function sGb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+1024|0;g=f|0;TFb(g,a,b);qGb(g,c,d,e);i=f;return}function tGb(a){a=a|0;var b=0,d=0,e=0,f=0;b=0;while(1){if(!(b>>>0<27>>>0)){d=0;e=0;f=5;break}if((c[1712204+(b<<4)>>2]|0)==(a|0)){break}else{b=b+1|0}}if((f|0)==5){return(G=d,e)|0}f=1712208+(b<<4)|0;d=c[f+4>>2]|0;e=c[f>>2]|0;return(G=d,e)|0}function uGb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((c&a|0)==0&(d&b|0)==0){e=-22;return e|0}f=c;g=f-(f>>>1&1431655765)|0;f=(g>>>2&858993459)+(g&858993459)|0;g=(f>>>4)+f&252645135;f=(g>>>8)+g|0;g=d-((d>>>1|0<<31)&1431655765)|0;h=(g>>>2&858993459)+(g&858993459)|0;g=(h>>>4)+h&252645135;h=(g>>>8)+g|0;if((((f>>>16)+f&63)+((h>>>16)+h&63)|0)!=1){e=-22;return e|0}h=wrc(c,d,-1,-1)|0;d=G&b;b=h&a;a=b-(b>>>1&1431655765)|0;b=(a>>>2&858993459)+(a&858993459)|0;a=(b>>>4)+b&252645135;b=(a>>>8)+a|0;a=d-((d>>>1|0<<31)&1431655765)|0;d=(a>>>2&858993459)+(a&858993459)|0;a=(d>>>4)+d&252645135;d=(a>>>8)+a|0;e=((b>>>16)+b&63)+((d>>>16)+d&63)|0;return e|0}function vGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=d-(d>>>1&1431655765)|0;d=(e>>>2&858993459)+(e&858993459)|0;e=(d>>>4)+d&252645135;d=(e>>>8)+e|0;e=b-((b>>>1|0<<31)&1431655765)|0;f=(e>>>2&858993459)+(e&858993459)|0;e=(f>>>4)+f&252645135;f=(e>>>8)+e|0;if((((d>>>16)+d&63)+((f>>>16)+f&63)|0)==1){g=0}else{h=0;return h|0}while(1){if((g|0)>=64){h=0;i=6;break}f=yrc(1,0,g|0)|0;if((f&a|0)==0&(G&b|0)==0){g=g+1|0}else{break}}if((i|0)==6){return h|0}if((g|0)<0|g>>>0>35>>>0){h=0;return h|0}h=c[1711912+(g<<3)>>2]|0;return h|0}function wGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=d-(d>>>1&1431655765)|0;d=(e>>>2&858993459)+(e&858993459)|0;e=(d>>>4)+d&252645135;d=(e>>>8)+e|0;e=b-((b>>>1|0<<31)&1431655765)|0;f=(e>>>2&858993459)+(e&858993459)|0;e=(f>>>4)+f&252645135;f=(e>>>8)+e|0;if((((d>>>16)+d&63)+((f>>>16)+f&63)|0)==1){g=0}else{h=0;return h|0}while(1){if(!(g>>>0<36>>>0)){h=0;i=5;break}f=yrc(1,0,g|0)|0;if((f&a|0)==0&(G&b|0)==0){g=g+1|0}else{break}}if((i|0)==5){return h|0}h=c[1711916+(g<<3)>>2]|0;return h|0}function xGb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=d-(d>>>1&1431655765)|0;d=(e>>>2&858993459)+(e&858993459)|0;e=(d>>>4)+d&252645135;d=(e>>>8)+e|0;e=b-((b>>>1|0<<31)&1431655765)|0;f=(e>>>2&858993459)+(e&858993459)|0;e=(f>>>4)+f&252645135;f=(e>>>8)+e|0;if((((d>>>16)+d&63)+((f>>>16)+f&63)|0)>(c|0)){g=c;h=0}else{i=0;j=0;return(G=i,j)|0}while(1){c=yrc(1,0,h|0)|0;f=G;if((c&a|0)==0&(f&b|0)==0){k=g}else{if((g|0)==0){i=f;j=c;l=5;break}else{k=g-1|0}}c=h+1|0;if((c|0)<64){g=k;h=c}else{i=0;j=0;l=5;break}}if((l|0)==5){return(G=i,j)|0}return 0}function yGb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;if(a>>>0>26>>>0){e=-541478725;return e|0}if((b|0)!=0){f=1712208+(a<<4)|0;g=c[f+4>>2]|0;c[b>>2]=c[f>>2];c[b+4>>2]=g}if((d|0)==0){e=0;return e|0}c[d>>2]=c[1712200+(a<<4)>>2];e=0;return e|0}function zGb(a){a=a|0;c[1510448]=a;c[2458822]=(a|0)!=-1;return}function AGb(){if((c[2458822]|0)==0){c[2458822]=1}return c[1510448]|0}function BGb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;c[e>>2]=2003896;f=HJb(e,2003800,b,a)|0;i=d;return f|0}function CGb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((d-8|0)>>>0>24>>>0){g=-1;return g|0}h=0;i=yrc(1,0,d|0)|0;j=G;if(!((h|0)<(j|0)|(h|0)==(j|0)&e>>>0<i>>>0)){g=-1;return g|0}if(!((f|0)==4096|(f|0)==1028)){g=-1;return g|0}i=e<<32-d;if((b|0)==0){b=0;do{d=b<<24>>31&i^b<<25;j=d>>31&i^d<<1;d=j>>31&i^j<<1;j=d>>31&i^d<<1;d=j>>31&i^j<<1;j=d>>31&i^d<<1;d=j>>31&i^j<<1;c[a+(b<<2)>>2]=je(d>>31&i^d<<1|0)|0;b=b+1|0;}while(b>>>0<256>>>0)}else{b=0;do{i=-(b&1)&e^b>>>1;d=-(i&1)&e^i>>>1;i=-(d&1)&e^d>>>1;d=-(i&1)&e^i>>>1;i=-(d&1)&e^d>>>1;d=-(i&1)&e^i>>>1;i=-(d&1)&e^d>>>1;c[a+(b<<2)>>2]=-(i&1)&e^i>>>1;b=b+1|0;}while(b>>>0<256>>>0)}c[a+1024>>2]=1;if(f>>>0>4095>>>0){k=0}else{g=0;return g|0}while(1){f=c[a+(k<<2)>>2]|0;b=f>>>8^c[a+((f&255)<<2)>>2];c[a+(k+256<<2)>>2]=b;f=b>>>8^c[a+((b&255)<<2)>>2];c[a+(k+512<<2)>>2]=f;c[a+(k+768<<2)>>2]=f>>>8^c[a+((f&255)<<2)>>2];f=k+1|0;if(f>>>0<256>>>0){k=f}else{g=0;break}}return g|0}function DGb(a){a=a|0;var b=0,e=0;b=9908120+(a<<12)|0;do{if((c[9912212+(a<<12)>>2]|0)==0){if((CGb(b,d[2004104+(a<<3)|0]|0,d[2004105+(a<<3)|0]|0,c[2004108+(a<<3)>>2]|0,4096)|0)<0){e=0}else{break}return e|0}}while(0);e=b;return e|0}function EGb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=e+f|0;do{if((c[a+1024>>2]|0)==0){if((e&3|0)!=0&(f|0)>0){h=e;i=b;while(1){j=h+1|0;k=c[a+(((d[h]|0)^i&255)<<2)>>2]^i>>>8;if((j&3|0)!=0&j>>>0<g>>>0){h=j;i=k}else{l=j;m=k;break}}}else{l=e;m=b}i=e+(f-3)|0;if(l>>>0<i>>>0){n=l;o=m}else{p=m;q=l;break}while(1){h=c[n>>2]^o;k=n+4|0;j=c[a+((h>>>8&255|512)<<2)>>2]^c[a+((h&255|768)<<2)>>2]^c[a+((h>>>16&255|256)<<2)>>2]^c[a+(h>>>24<<2)>>2];if(k>>>0<i>>>0){n=k;o=j}else{p=j;q=k;break}}}else{p=b;q=e}}while(0);if(q>>>0<g>>>0){r=q;s=p}else{t=p;return t|0}while(1){p=r+1|0;q=c[a+(((d[r]|0)^s&255)<<2)>>2]^s>>>8;if(p>>>0<g>>>0){r=p;s=q}else{t=q;break}}return t|0}function FGb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;if(!((e|0)==192|(e|0)==64)){g=-1;return g|0}f=a+384|0;c[f>>2]=(e|0)>64;e=b;h=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;h=je(e|0)|0;e=i|0;i=2656776;j=0;k=0;l=0;while(1){m=zrc(h|0,e|0,d[i]|0|0)|0;n=m&1|(l<<1|0>>>31);m=G&0|(k<<1|l>>>31);o=j+1|0;if((o|0)<56){i=i+1|0;j=o;k=m;l=n}else{p=0;q=m;r=n;break}}while(1){l=(r<<1|0>>>31)&-268435458|(r>>>27|q<<5)&268435457;k=q<<1|r>>>31|0|(q>>>27|0<<5)&0;do{if((p|0)>1){if((p|0)==15|(p|0)==8){s=k;t=l;break}s=k<<1|l>>>31|0|(q>>>26|0<<6)&0;t=(l<<1|0>>>31)&-268435458|(r>>>26|q<<6)&268435457}else{s=k;t=l}}while(0);l=2656728;k=0;j=0;i=0;while(1){e=zrc(t|0,s|0,d[l]|0|0)|0;u=e&1|(i<<1|0>>>31);v=G&0|(j<<1|i>>>31);e=k+1|0;if((e|0)<48){l=l+1|0;k=e;j=v;i=u}else{break}}i=a+(p<<3)|0;c[i>>2]=u;c[i+4>>2]=v;i=p+1|0;if((i|0)<16){p=i;q=s;r=t}else{break}}if((c[f>>2]|0)==0){g=0;return g|0}f=b+8|0;t=f|0;r=f+4|0;f=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=je(f|0)|0;f=r|0;r=2656776;s=0;q=0;p=0;while(1){v=zrc(t|0,f|0,d[r]|0|0)|0;u=v&1|(p<<1|0>>>31);v=G&0|(q<<1|p>>>31);i=s+1|0;if((i|0)<56){r=r+1|0;s=i;q=v;p=u}else{w=0;x=v;y=u;break}}while(1){p=(y<<1|0>>>31)&-268435458|(y>>>27|x<<5)&268435457;q=x<<1|y>>>31|0|(x>>>27|0<<5)&0;do{if((w|0)>1){if((w|0)==15|(w|0)==8){z=q;A=p;break}z=q<<1|p>>>31|0|(x>>>26|0<<6)&0;A=(p<<1|0>>>31)&-268435458|(y>>>26|x<<6)&268435457}else{z=q;A=p}}while(0);p=2656728;q=0;s=0;r=0;while(1){f=zrc(A|0,z|0,d[p]|0|0)|0;B=f&1|(r<<1|0>>>31);C=G&0|(s<<1|r>>>31);f=q+1|0;if((f|0)<48){p=p+1|0;q=f;s=C;r=B}else{break}}r=a+128+(w<<3)|0;c[r>>2]=B;c[r+4>>2]=C;r=w+1|0;if((r|0)<16){w=r;x=z;y=A}else{break}}A=b+16|0;b=A|0;y=A+4|0;A=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;b=je(A|0)|0;A=y|0;y=2656776;z=0;x=0;w=0;while(1){C=zrc(b|0,A|0,d[y]|0|0)|0;B=C&1|(w<<1|0>>>31);C=G&0|(x<<1|w>>>31);r=z+1|0;if((r|0)<56){y=y+1|0;z=r;x=C;w=B}else{D=0;E=C;F=B;break}}while(1){w=(F<<1|0>>>31)&-268435458|(F>>>27|E<<5)&268435457;x=E<<1|F>>>31|0|(E>>>27|0<<5)&0;do{if((D|0)>1){if((D|0)==15|(D|0)==8){H=x;I=w;break}H=x<<1|w>>>31|0|(E>>>26|0<<6)&0;I=(w<<1|0>>>31)&-268435458|(F>>>26|E<<6)&268435457}else{H=x;I=w}}while(0);w=2656728;x=0;z=0;y=0;while(1){A=zrc(I|0,H|0,d[w]|0|0)|0;J=A&1|(y<<1|0>>>31);K=G&0|(z<<1|y>>>31);A=x+1|0;if((A|0)<48){w=w+1|0;x=A;z=K;y=J}else{break}}y=a+256+(D<<3)|0;c[y>>2]=J;c[y+4>>2]=K;y=D+1|0;if((y|0)<16){D=y;E=H;F=I}else{g=0;break}}return g|0}function GGb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;HGb(a,b,c,d,e,f,0);return}function HGb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;k=(h|0)!=0;if(k){l=h;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;o=n|0;p=je(l|0)|0}else{o=0;p=0}l=g-1|0;n=p;m=o;a:do{if((g|0)>0){q=b|0;r=b+384|0;s=b+128|0;t=b+256|0;u=(j|0)==0;if((i|0)==0){v=f;w=o;x=p;z=e;A=l;while(1){if((v|0)==0){B=0;C=0}else{D=v;E=D|0;F=D+4|0;D=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;F=je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0;B=F|0;C=je(D|0)|0}D=JGb(C^x,B^w,q,0)|0;F=G;if((c[r>>2]|0)==0){H=F;I=D;J=F;K=D}else{E=JGb(D,F,s,1)|0;F=JGb(E,G,t,0)|0;E=G;H=E;I=F;J=E;K=F}L=k?K:0;M=k?J:0;F=je(I|0)|0;E=z;D=E|0;y=je(H|0)|0;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;D=E+4|0;y=F|0;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;if((A|0)>0){v=v+8|0;w=M;x=L;z=u?z+8|0:z;A=A-1|0}else{break}}N=M;O=L;break}if(k){P=f;Q=o;R=p;S=e;T=l}else{A=f;z=o;x=p;w=e;v=l;while(1){if((A|0)==0){U=0;V=0}else{D=A;F=D|0;E=D+4|0;D=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0;U=E|0;V=je(D|0)|0}if((c[r>>2]|0)==0){W=U;X=V}else{D=JGb(V,U,t,1)|0;E=JGb(D,G,s,0)|0;W=G;X=E}E=JGb(X,W,q,1)|0;D=G^z;F=je(E^x|0)|0;E=w;Y=E|0;y=je(D|0)|0;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;Y=E+4|0;y=F|0;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;if((v|0)>0){A=A+8|0;z=0;x=0;w=u?w+8|0:w;v=v-1|0}else{N=0;O=0;break a}}}while(1){if((P|0)==0){Z=0;_=0}else{v=P;w=v|0;x=v+4|0;v=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;Z=x|0;_=je(v|0)|0}if((c[r>>2]|0)==0){$=Z;aa=_}else{v=JGb(_,Z,t,1)|0;x=JGb(v,G,s,0)|0;$=G;aa=x}x=JGb(aa,$,q,1)|0;v=G^Q;w=je(x^R|0)|0;x=S;z=x|0;y=je(v|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;z=x+4|0;y=w|0;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;if((T|0)>0){P=P+8|0;Q=Z;R=_;S=u?S+8|0:S;T=T-1|0}else{break}}N=Z;O=_}else{N=m;O=n}}while(0);if(!k){return}k=je(O|0)|0;O=h;h=O|0;y=je(N|0)|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=O+4|0;y=k|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;return}function IGb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;c[g>>2]=0;c[g+4>>2]=0;HGb(a,b,d,e,g,0,1);i=f;return}function JGb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=(f|0)!=0;f=2658840;h=0;i=0;j=0;while(1){k=zrc(a|0,b|0,d[f]|0|0)|0;l=k&1|(j<<1|0>>>31);m=G&0|(i<<1|j>>>31);k=h+1|0;if((k|0)<64){f=f+1|0;h=k;i=m;j=l}else{break}}j=g?15:0;g=0;i=m;m=l;while(1){l=m;h=e+((g^j)<<3)|0;f=c[h>>2]|0;b=c[h+4>>2]|0;h=l<<1|l>>>31;a=l>>>3;k=a&268435440;n=(c[2655464+((((f>>>6|b<<26)^a)&255&63)<<2)>>2]|c[2655720+(((f^h)&255&63)<<2)>>2]|c[2655208+((((f>>>12|b<<20)^k>>>4)&255&63)<<2)>>2]|c[2654952+((((f>>>18|b<<14)^l>>>11)&255&63)<<2)>>2]|c[2654696+((((f>>>24|b<<8)^l>>>15)&255&63)<<2)>>2]|c[2654440+((((f>>>30|b<<2)^l>>>19)&255&63)<<2)>>2]|c[2654184+((((b>>>4|0<<28)^l>>>23)&255&63)<<2)>>2]|c[2653928+((((b>>>10|0<<22)^(h<<28|k)>>>24)&255&63)<<2)>>2])^i;o=0^m;k=g+1|0;if((k|0)<16){g=k;i=o;m=n}else{break}}m=2658903;i=n|0;n=o|0;o=0;g=0;j=0;while(1){e=yrc(n&1|0,i&0|0,d[m]|0|0)|0;p=e|j;q=G|g;e=n>>>1|i<<31;k=o+1|0;if((k|0)<64){m=m-1|0;i=i>>>1|0<<31;n=e;o=k;g=q;j=p}else{break}}return(G=q,p)|0}function KGb(a){a=a|0;var b=0;if((a|0)==0){b=0}else{b=c[a>>2]|0}return b|0}function LGb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((b|0)==0){g=0;return g|0}if((e|0)==0){h=0}else{h=(e-(c[b+4>>2]|0)>>3)+1|0}e=c[b>>2]|0;if(!(h>>>0<e>>>0)){g=0;return g|0}i=c[b+4>>2]|0;b=(f&2|0)==0;a:do{if((f&1|0)==0){j=h;while(1){k=c[i+(j<<3)>>2]|0;l=0;while(1){m=a[k+l|0]|0;n=a[d+l|0]|0;o=n<<24>>24;if((((m-97|0)>>>0<26>>>0?m^32:m)|0)!=(((o-97|0)>>>0<26>>>0?o^32:o)|0)|n<<24>>24==0){break}else{l=l+1|0}}if(n<<24>>24==0){if((a[k+l|0]|0)==0|b^1){p=j;break a}}o=j+1|0;if(o>>>0<e>>>0){j=o}else{g=0;break}}return g|0}else{if(b){q=h}else{j=h;while(1){o=c[i+(j<<3)>>2]|0;m=0;while(1){r=a[d+m|0]|0;if((a[o+m|0]|0)!=r<<24>>24|r<<24>>24==0){break}else{m=m+1|0}}if(r<<24>>24==0){p=j;break a}m=j+1|0;if(m>>>0<e>>>0){j=m}else{g=0;break}}return g|0}while(1){j=c[i+(q<<3)>>2]|0;m=0;while(1){s=a[d+m|0]|0;if((a[j+m|0]|0)!=s<<24>>24|s<<24>>24==0){break}else{m=m+1|0}}if(s<<24>>24==0){if((a[j+m|0]|0)==0){p=q;break a}}o=q+1|0;if(o>>>0<e>>>0){q=o}else{g=0;break}}return g|0}}while(0);g=i+(p<<3)|0;return g|0}function MGb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+8|0;g=f|0;h=c[a>>2]|0;j=LGb(h,b,0,e)|0;c[g>>2]=0;if((h|0)==0){k=pJb(8)|0;c[a>>2]=k;l=k}else{l=h}do{if((j|0)==0){h=l+4|0;k=iJb(c[h>>2]|0,(c[l>>2]<<3)+8|0)|0;if((k|0)==0){m=-12;i=f;return m|0}else{c[h>>2]=k;break}}else{if((e&16|0)!=0){m=0;i=f;return m|0}k=c[j+4>>2]|0;if((e&32|0)==0){kJb(k)}else{c[g>>2]=k}kJb(c[j>>2]|0);k=l|0;h=(c[k>>2]|0)-1|0;c[k>>2]=h;k=(c[l+4>>2]|0)+(h<<3)|0;h=j;n=c[k+4>>2]|0;c[h>>2]=c[k>>2];c[h+4>>2]=n}}while(0);if((d|0)==0){o=c[l>>2]|0}else{if((e&4|0)==0){j=rJb(b)|0;n=c[l>>2]|0;c[(c[l+4>>2]|0)+(n<<3)>>2]=j;p=n}else{n=c[l>>2]|0;c[(c[l+4>>2]|0)+(n<<3)>>2]=b;p=n}a:do{if((e&8|0)==0){n=c[g>>2]|0;do{if((n|0)!=0){if((e&32|0)==0){break}b=lrc(n|0)|0;j=b+1+(lrc(d|0)|0)|0;b=pJb(j)|0;if((b|0)==0){m=-12;i=f;return m|0}else{DFb(b,n,j)|0;mJb(g);DFb(b,d,j)|0;j=c[l>>2]|0;c[(c[l+4>>2]|0)+(j<<3)+4>>2]=b;q=j;break a}}}while(0);n=rJb(d)|0;j=c[l>>2]|0;c[(c[l+4>>2]|0)+(j<<3)+4>>2]=n;q=j}else{c[(c[l+4>>2]|0)+(p<<3)+4>>2]=d;q=p}}while(0);p=q+1|0;c[l>>2]=p;o=p}if((o|0)!=0){m=0;i=f;return m|0}kJb(c[l+4>>2]|0);mJb(a);m=0;i=f;return m|0}function NGb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;c[l>>2]=d;if((d|0)==0){m=0;i=h;return m|0}n=g&-13;if((a[d]|0)==0){m=0;i=h;return m|0}d=j;g=k;while(1){o=GFb(l,e)|0;c[j>>2]=o;c[k>>2]=0;do{if((o|0)==0){p=-22}else{if((a[o]|0)==0){p=-22;break}q=c[l>>2]|0;if((ud(q|0,e|0)|0)==0){r=o;s=0}else{c[l>>2]=q+1;q=GFb(l,f)|0;c[k>>2]=q;r=c[j>>2]|0;s=q}if((r|0)==0){p=-22;break}if((a[r]|0)==0|(s|0)==0){p=-22;break}if((a[s]|0)==0){p=-22;break}p=MGb(b,r,s,n)|0}}while(0);mJb(d);mJb(g);if((p|0)<0){m=p;t=15;break}o=c[l>>2]|0;if((a[o]|0)==0){m=0;t=15;break}q=o+1|0;c[l>>2]=q;if((a[q]|0)==0){m=0;t=15;break}}if((t|0)==15){i=h;return m|0}return 0}function OGb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a>>2]|0;if((b|0)==0){d=a;mJb(d);return}e=b|0;f=c[e>>2]|0;g=f-1|0;c[e>>2]=g;h=b+4|0;b=c[h>>2]|0;if((f|0)==0){i=b}else{f=g;g=b;while(1){kJb(c[g+(f<<3)>>2]|0);kJb(c[(c[h>>2]|0)+(c[e>>2]<<3)+4>>2]|0);b=c[e>>2]|0;j=b-1|0;c[e>>2]=j;k=c[h>>2]|0;if((b|0)==0){i=k;break}else{f=j;g=k}}}kJb(i);d=a;mJb(d);return}function PGb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((b|0)==0){return}e=b|0;f=b+4|0;b=0;while(1){if((b|0)==0){g=0}else{g=(b-(c[f>>2]|0)>>3)+1|0}if(!(g>>>0<(c[e>>2]|0)>>>0)){h=8;break}i=c[f>>2]|0;j=i+(g<<3)|0;if((j|0)==0){h=8;break}MGb(a,c[i+(g<<3)>>2]|0,c[i+(g<<3)+4>>2]|0,d)|0;b=j}if((h|0)==8){return}}function QGb(a){a=a|0;var b=0,d=0,e=0,f=0;b=fIb(a,4)|0;do{if((b|0)==0){d=dIb(a,4,48)|0;if((d|0)==0){e=0}else{f=d;break}return e|0}else{f=b}}while(0);e=c[f+4>>2]|0;return e|0}function RGb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=0;while(1){if(!(f>>>0<19>>>0)){break}if((c[1509744+(f*12|0)>>2]|0)==(a|0)){g=4;break}else{f=f+1|0}}if((g|0)==4){CFb(b,c[1509752+(f*12|0)>>2]|0,d)|0;h=0;i=e;return h|0}f=ee(-a|0,b|0,d|0)|0;g=-f|0;if((f|0)<=0){h=g;i=e;return h|0}Rb(b|0,d|0,2413472,(d=i,i=i+8|0,c[d>>2]=a,d)|0)|0;i=d;h=g;i=e;return h|0}function SGb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0.0,j=0,k=0.0,l=0,m=0,n=0.0,o=0,p=0.0,q=0,r=0,s=0.0;e=i;i=i+8|0;f=e|0;do{if((a[b]|0)==48){if((a[b+1|0]|32|0)!=120){g=4;break}h=+((pb(b|0,f|0,16)|0)>>>0>>>0)}else{g=4}}while(0);if((g|0)==4){h=+frc(b,f)}j=c[f>>2]|0;do{if((j|0)==(b|0)){k=h;l=b}else{m=a[j]|0;do{if(m<<24>>24==100){if((a[j+1|0]|0)!=66){g=10;break}n=+T(+10.0,+(h/20.0));o=j+2|0;c[f>>2]=o;p=n;q=o}else{if((m-69&255)>>>0<54>>>0){g=10}else{p=h;q=j}}}while(0);do{if((g|0)==10){o=a[566672+((m<<24>>24)-69)|0]|0;if(o<<24>>24==0){p=h;q=j;break}r=j+1|0;n=+(o<<24>>24|0);if((a[r]|0)==105){s=h*+ad(+(n/.3));o=j+2|0;c[f>>2]=o;p=s;q=o;break}else{s=h*+T(+10.0,+n);c[f>>2]=r;p=s;q=r;break}}}while(0);if((a[q]|0)!=66){k=p;l=q;break}m=q+1|0;c[f>>2]=m;k=p*8.0;l=m}}while(0);if((d|0)==0){i=e;return+k}c[d>>2]=l;i=e;return+k}function TGb(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;if((a|0)==0){i=b;return}TGb(c[a+20>>2]|0);TGb(c[a+24>>2]|0);TGb(c[a+28>>2]|0);mJb(a+32|0);mJb(d);i=b;return}function UGb(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=i;i=i+64|0;n=m|0;o=m+56|0;p=n;mrc(p|0,0,52)|0;c[o>>2]=0;q=hJb((lrc(d|0)|0)+1|0)|0;if((q|0)==0){r=-12;i=m;return r|0}else{s=q;t=d}a:while(1){u=t;while(1){v=a[u]|0;if(v<<24>>24==0){break a}w=u+1|0;if((OFb(v<<24>>24)|0)==0){break}else{u=w}}a[s]=a[u]|0;s=s+1|0;t=w}a[s]=0;c[n>>2]=1509672;c[n+4>>2]=100;s=n+8|0;c[s>>2]=q;c[n+16>>2]=e;c[n+20>>2]=g;c[n+24>>2]=f;c[n+28>>2]=j;c[n+32>>2]=h;c[n+40>>2]=k;c[n+44>>2]=l;l=VGb(o,n)|0;do{if((l|0)<0){x=l}else{n=c[o>>2]|0;if((a[c[s>>2]|0]|0)!=0){TGb(n);KIb(p,16,2413240,(k=i,i=i+16|0,c[k>>2]=c[s>>2],c[k+8>>2]=d,k)|0);i=k;x=-22;break}if((WGb(n)|0)==0){TGb(n);x=-22;break}else{c[n+32>>2]=pJb(80)|0;c[b>>2]=n;x=l;break}}}while(0);kJb(q);r=x;i=m;return r|0}function VGb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+16|0;f=e|0;g=e+8|0;j=d+4|0;k=c[j>>2]|0;if((k|0)<1){l=-22;i=e;return l|0}c[j>>2]=k-1;k=_Gb(f,d)|0;if((k|0)<0){l=k;i=e;return l|0}k=d+8|0;m=c[k>>2]|0;n=c[f>>2]|0;a:do{if((a[m]|0)==59){o=m;p=n;while(1){c[k>>2]=o+1;q=_Gb(g,d)|0;if((q|0)<0){r=5;break}s=c[g>>2]|0;t=pJb(40)|0;if((t|0)==0){r=7;break}u=t;c[t>>2]=22;h[t+8>>3]=1.0;c[t+20>>2]=p;c[t+24>>2]=s;c[f>>2]=u;t=c[k>>2]|0;if((a[t]|0)==59){o=t;p=u}else{v=u;break a}}if((r|0)==5){TGb(p);l=q;i=e;return l|0}else if((r|0)==7){c[f>>2]=0;TGb(p);TGb(s);l=-12;i=e;return l|0}}else{v=n}}while(0);c[j>>2]=(c[j>>2]|0)+1;c[b>>2]=v;l=0;i=e;return l|0}function WGb(a){a=a|0;var b=0,d=0;if((a|0)==0){b=0;return b|0}switch(c[a>>2]|0){case 40:{if((WGb(c[a+20>>2]|0)|0)==0){b=0;return b|0}if((WGb(c[a+24>>2]|0)|0)==0){b=0;return b|0}else{return(WGb(c[a+28>>2]|0)|0)!=0|0}break};case 2:case 3:case 5:case 7:case 6:case 8:case 9:case 27:case 28:case 29:case 30:case 31:case 32:{if((WGb(c[a+20>>2]|0)|0)==0){b=0;return b|0}b=(c[a+24>>2]|0)==0|0;return b|0};case 0:case 1:{b=1;return b|0};case 35:case 36:case 25:{if((WGb(c[a+20>>2]|0)|0)==0){b=0;return b|0}if((WGb(c[a+24>>2]|0)|0)==0){b=0;return b|0}d=c[a+28>>2]|0;if((d|0)==0){b=1;return b|0}else{return(WGb(d)|0)!=0|0}break};case 37:{if((WGb(c[a+20>>2]|0)|0)==0){b=0;return b|0}d=c[a+24>>2]|0;if((d|0)==0){b=1;return b|0}else{return(WGb(d)|0)!=0|0}break};default:{if((WGb(c[a+20>>2]|0)|0)==0){b=0;return b|0}if((WGb(c[a+24>>2]|0)|0)==0){b=0;return b|0}b=(c[a+28>>2]|0)==0|0;return b|0}}return 0}function XGb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0.0;e=i;i=i+56|0;f=e|0;mrc(f|0,0,48)|0;c[f+48>>2]=c[a+32>>2];c[f+12>>2]=b;c[f+36>>2]=d;g=+YGb(f,a);i=e;return+g}function YGb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0.0,j=0.0,l=0,m=0.0,n=0,o=0.0,p=0.0,q=0.0,s=0.0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,H=0.0,I=0.0,J=0,K=0,L=0.0,M=0.0,N=0,O=0.0,P=0.0,U=0,V=0,W=0.0,X=0.0,Y=0,Z=0;e=i;f=b|0;switch(c[f>>2]|0){case 35:{g=+h[b+8>>3];do{if(+YGb(a,c[b+20>>2]|0)!=0.0){j=+YGb(a,c[b+24>>2]|0)}else{l=c[b+28>>2]|0;if((l|0)==0){j=0.0;break}j=+YGb(a,l)}}while(0);m=g*j;i=e;return+m};case 3:{j=+h[b+8>>3];l=c[b+16>>2]|0;n=c[a+36>>2]|0;g=+YGb(a,c[b+20>>2]|0);o=j*+cf[l&15](n,g);i=e;return+o};case 26:{n=a+48|0;o=+h[c[n>>2]>>3];g=+YGb(a,c[b+24>>2]|0);l=b+20|0;j=1.7976931348623157e+308;p=-1.7976931348623157e+308;q=-1.0;s=-1.0;t=-1;while(1){if((t|0)>=1024){u=j;v=p;w=q;x=s;break}do{if((t|0)<255){h[c[n>>2]>>3]=g*+(d[1998192+(t&255)|0]|0|0)/255.0}else{y=g*+T(+.9,+(+(t-255|0)));z=c[n>>2]|0;if((t&1|0)==0){A=y}else{A=y*-1.0}h[z>>3]=A;if((t&2|0)==0){h[z>>3]=q+A;break}else{h[z>>3]=s+A;break}}}while(0);y=+YGb(a,c[l>>2]|0);if(y<=0.0&y>p){B=y;C=+h[c[n>>2]>>3]}else{B=p;C=s}if(y>=0.0&y<j){D=y;E=+h[c[n>>2]>>3]}else{D=j;E=q}if(C<0.0|E<0.0){j=D;p=B;q=E;s=C;t=t+1|0}else{H=E;I=C;J=0;K=65;break}}a:do{if((K|0)==65){while(1){K=0;if((J|0)>=1e3){u=D;v=B;w=H;x=I;break a}C=(I+H)*.5;h[c[n>>2]>>3]=C;if(I==C|H==C){u=D;v=B;w=H;x=I;break a}C=+YGb(a,c[l>>2]|0);if(C>0.0){L=I}else{L=+h[c[n>>2]>>3]}if(C<0.0){M=H}else{M=+h[c[n>>2]>>3]}h[k>>3]=C;t=c[k+4>>2]&2147483647;z=2146435072;if(t>>>0>z>>>0|t>>>0==z>>>0&(c[k>>2]|0)>>>0>0>>>0){u=D;v=B;w=C;x=C;break}else{H=M;I=L;J=J+1|0;K=65}}}}while(0);h[c[n>>2]>>3]=o;m=u>-0.0-v?x:w;i=e;return+m};case 29:{w=+h[b+8>>3];x=w*+xc(+(+YGb(a,c[b+20>>2]|0)));i=e;return+x};case 25:{x=+YGb(a,c[b+24>>2]|0);n=c[b+28>>2]|0;do{if((n|0)==0){N=0}else{K=~~+YGb(a,n);if((K|0)<0){N=0;break}N=(K|0)>9?9:K}}while(0);n=a+48|0;K=c[n>>2]|0;w=+h[K+(N<<3)>>3];J=b+20|0;l=0;v=0.0;u=1.0;z=K;while(1){h[z+(N<<3)>>3]=+(l|0);o=+YGb(a,c[J>>2]|0);O=v+u*o;if(v==O&o!=0.0){break}K=l+1|0;if((K|0)>=1e3){break}l=K;v=O;u=u*(x/+(K|0));z=c[n>>2]|0}h[(c[n>>2]|0)+(N<<3)>>3]=w;m=O;i=e;return+m};case 27:{O=+h[b+8>>3];w=O*+Q(+YGb(a,c[b+20>>2]|0));i=e;return+w};case 6:{w=+YGb(a,c[b+20>>2]|0);O=+$(w*(-0.0-w)*.5)/2.5066282746310002;i=e;return+O};case 0:{m=+h[b+8>>3];i=e;return+m};case 8:{O=+h[b+8>>3];w=+YGb(a,c[b+20>>2]|0);h[k>>3]=w;N=c[k+4>>2]&2147483647;n=2146435072;w=O*+((N>>>0>n>>>0|N>>>0==n>>>0&(c[k>>2]|0)>>>0>0>>>0)&1|0);i=e;return+w};case 24:{n=b+20|0;if(!(+YGb(a,c[n>>2]|0)!=0.0)){m=+r;i=e;return+m}N=b+24|0;while(1){w=+YGb(a,c[N>>2]|0);if(!(+YGb(a,c[n>>2]|0)!=0.0)){m=w;break}}i=e;return+m};case 2:{w=+h[b+8>>3];n=c[b+16>>2]|0;O=+YGb(a,c[b+20>>2]|0);x=w*+Oe[n&31](O);i=e;return+x};case 31:{x=+h[b+8>>3];O=x*+(+YGb(a,c[b+20>>2]|0)==0.0|0);i=e;return+O};case 1:{m=+h[b+8>>3]*+h[(c[a+12>>2]|0)+(c[b+16>>2]<<3)>>3];i=e;return+m};case 40:{O=+YGb(a,c[b+20>>2]|0);x=+h[b+8>>3];if(O<+YGb(a,c[b+24>>2]|0)){P=0.0}else{P=+(O<=+YGb(a,c[b+28>>2]|0)|0)}m=x*P;i=e;return+m};case 30:{P=+h[b+8>>3];x=P*+S(+YGb(a,c[b+20>>2]|0));i=e;return+x};case 4:{x=+h[b+8>>3];n=c[b+16>>2]|0;N=c[a+36>>2]|0;P=+YGb(a,c[b+20>>2]|0);O=+YGb(a,c[b+24>>2]|0);w=x*+Ze[n&15](N,P,O);i=e;return+w};case 9:{w=+h[b+8>>3];O=+YGb(a,c[b+20>>2]|0);h[k>>3]=O;O=w*+((c[k>>2]|0|0)==0&(c[k+4>>2]&2147483647|0)==2146435072&1|0);i=e;return+O};case 7:{O=+h[b+8>>3];N=~~+YGb(a,c[b+20>>2]|0);if((N|0)<0){U=0}else{U=(N|0)>9?9:N}m=O*+h[(c[a+48>>2]|0)+(U<<3)>>3];i=e;return+m};case 28:{O=+h[b+8>>3];w=O*+ba(+YGb(a,c[b+20>>2]|0));i=e;return+w};case 32:{U=~~+YGb(a,c[b+20>>2]|0);if((U|0)<0){V=0}else{V=(U|0)>9?9:U}U=(c[a+48>>2]|0)+(V<<3)|0;w=+h[U>>3];V=c[U+4>>2]&2147483647;N=2146435072;if(V>>>0>N>>>0|V>>>0==N>>>0&(c[U>>2]|0)>>>0>0>>>0){W=1013904223.0}else{N=Erc(~~+w>>>0,(F=+w,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0),1664525,0)|0;V=wrc(N,G,1013904223,0)|0;W=+(V>>>0)+ +(G>>>0)*4294967296.0}h[U>>3]=W;m=W*5.421010862427522e-20*+h[b+8>>3];i=e;return+m};case 5:{W=1.0/(+$(+YGb(a,c[b+20>>2]|0)*4.0)+1.0);i=e;return+W};case 36:{W=+h[b+8>>3];do{if(+YGb(a,c[b+20>>2]|0)!=0.0){U=c[b+28>>2]|0;if((U|0)==0){X=0.0;break}X=+YGb(a,U)}else{X=+YGb(a,c[b+24>>2]|0)}}while(0);m=W*X;i=e;return+m};case 37:{X=+YGb(a,c[b+20>>2]|0);U=c[b+24>>2]|0;if((U|0)==0){Y=32}else{Y=~~+YGb(a,U)}KIb(a,Y,2578952,(Y=i,i=i+8|0,h[Y>>3]=X,Y)|0);i=Y;m=X;i=e;return+m};default:{X=+YGb(a,c[b+20>>2]|0);W=+YGb(a,c[b+24>>2]|0);switch(c[f>>2]|0){case 39:{h[k>>3]=X;f=c[k+4>>2]&2147483647;Y=2146435072;if(f>>>0>Y>>>0|f>>>0==Y>>>0&(c[k>>2]|0)>>>0>0>>>0){m=+r;i=e;return+m}h[k>>3]=W;Y=c[k+4>>2]&2147483647;f=2146435072;if(Y>>>0>f>>>0|Y>>>0==f>>>0&(c[k>>2]|0)>>>0>0>>>0){m=+r;i=e;return+m}m=+(~~W|~~X|0)*+h[b+8>>3];i=e;return+m};case 11:{m=(X>W?X:W)*+h[b+8>>3];i=e;return+m};case 12:{m=(X<W?X:W)*+h[b+8>>3];i=e;return+m};case 10:{m=+h[b+8>>3]*(X-W*+Q(X/W));i=e;return+m};case 23:{w=+h[b+8>>3];f=~~X;if((f|0)<0){Z=0}else{Z=(f|0)>9?9:f}h[(c[a+48>>2]|0)+(Z<<3)>>3]=W;m=W*w;i=e;return+m};case 14:{m=(X>W?1.0:0.0)*+h[b+8>>3];i=e;return+m};case 20:{m=+h[b+8>>3]*(X/W);i=e;return+m};case 33:{m=+h[b+8>>3]*+S(X*X+W*W);i=e;return+m};case 38:{h[k>>3]=X;Z=c[k+4>>2]&2147483647;a=2146435072;if(Z>>>0>a>>>0|Z>>>0==a>>>0&(c[k>>2]|0)>>>0>0>>>0){m=+r;i=e;return+m}h[k>>3]=W;a=c[k+4>>2]&2147483647;Z=2146435072;if(a>>>0>Z>>>0|a>>>0==Z>>>0&(c[k>>2]|0)>>>0>0>>>0){m=+r;i=e;return+m}m=+(~~W&~~X|0)*+h[b+8>>3];i=e;return+m};case 34:{w=+h[b+8>>3];m=w*(+((TIb(~~+X>>>0,(F=+X,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0),~~+W>>>0,(F=+W,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0))|0)>>>0)+ +(G|0)*4294967296.0);i=e;return+m};case 13:{m=(X==W?1.0:0.0)*+h[b+8>>3];i=e;return+m};case 21:{m=(X+W)*+h[b+8>>3];i=e;return+m};case 22:{m=W*+h[b+8>>3];i=e;return+m};case 15:{m=(X>=W?1.0:0.0)*+h[b+8>>3];i=e;return+m};case 17:{m=(X<W?1.0:0.0)*+h[b+8>>3];i=e;return+m};case 16:{m=(X<=W?1.0:0.0)*+h[b+8>>3];i=e;return+m};case 18:{m=+h[b+8>>3]*+T(+X,+W);i=e;return+m};case 19:{m=X*W*+h[b+8>>3];i=e;return+m};default:{m=+r;i=e;return+m}}}}return 0.0}function ZGb(a,b,d,e,f,g,j,k,l,m,n){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,s=0,t=0;o=i;i=i+64|0;p=o|0;q=o+56|0;c[q>>2]=0;s=UGb(q,b,d,f,g,j,k,m,n)|0;if((s|0)<0){h[a>>3]=+r;t=s;i=o;return t|0}else{s=c[q>>2]|0;mrc(p|0,0,48)|0;c[p+48>>2]=c[s+32>>2];c[p+12>>2]=e;c[p+36>>2]=l;h[a>>3]=+YGb(p,s);TGb(s);s=c[a+4>>2]&2147483647;p=2146435072;t=s>>>0>p>>>0|s>>>0==p>>>0&(c[a>>2]|0)>>>0>0>>>0?-22:0;i=o;return t|0}return 0}function _Gb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+16|0;f=e|0;g=e+8|0;j=$Gb(f,d)|0;if((j|0)<0){k=j;i=e;return k|0}j=d+8|0;l=c[f>>2]|0;while(1){m=a[c[j>>2]|0]|0;if(!((m<<24>>24|0)==45|(m<<24>>24|0)==43)){n=9;break}o=$Gb(g,d)|0;if((o|0)<0){n=5;break}p=c[g>>2]|0;m=pJb(40)|0;if((m|0)==0){n=7;break}q=m;c[m>>2]=21;h[m+8>>3]=1.0;c[m+20>>2]=l;c[m+24>>2]=p;c[f>>2]=q;l=q}if((n|0)==5){TGb(l);k=o;i=e;return k|0}else if((n|0)==7){c[f>>2]=0;TGb(l);TGb(p);k=-12;i=e;return k|0}else if((n|0)==9){c[b>>2]=l;k=0;i=e;return k|0}return 0}function $Gb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+16|0;f=e|0;g=e+8|0;j=aHb(f,d)|0;if((j|0)<0){k=j;i=e;return k|0}j=d+8|0;while(1){l=c[j>>2]|0;m=a[l]|0;if(!((m<<24>>24|0)==42|(m<<24>>24|0)==47)){n=9;break}c[j>>2]=l+1;m=a[l]|0;o=c[f>>2]|0;p=aHb(g,d)|0;if((p|0)<0){n=5;break}q=c[g>>2]|0;l=pJb(40)|0;if((l|0)==0){n=7;break}c[l>>2]=m<<24>>24==42?19:20;h[l+8>>3]=1.0;c[l+20>>2]=o;c[l+24>>2]=q;c[f>>2]=l}if((n|0)==5){TGb(o);k=p;i=e;return k|0}else if((n|0)==7){c[f>>2]=0;TGb(o);TGb(q);k=-12;i=e;return k|0}else if((n|0)==9){c[b>>2]=c[f>>2];k=0;i=e;return k|0}return 0}function aHb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0;e=i;i=i+32|0;f=e|0;g=e+8|0;j=e+16|0;k=e+24|0;l=d+8|0;m=c[l>>2]|0;do{if((a[m]|0)==45){+frc(m,f);n=c[f>>2]|0;o=c[l>>2]|0;if((n|0)==(o|0)){p=n;q=6;break}if((a[n]|0)!=100){p=o;q=6;break}if((a[n+1|0]|0)!=66){p=o;q=6;break}r=bHb(j,d)|0;s=1.0}else{p=m;q=6}}while(0);if((q|0)==6){m=a[p]|0;f=(m<<24>>24==43)-(m<<24>>24==45)|0;c[l>>2]=p+(f&1);r=bHb(j,d)|0;s=+(f|1|0)}if((r|0)<0){t=r;i=e;return t|0}r=c[l>>2]|0;f=c[j>>2]|0;a:do{if((a[r]|0)==94){p=r;m=f;while(1){o=p+1|0;c[l>>2]=o;do{if((a[o]|0)==45){+frc(o,g);n=c[g>>2]|0;u=c[l>>2]|0;if((n|0)==(u|0)){v=n;q=15;break}if((a[n]|0)!=100){v=u;q=15;break}if((a[n+1|0]|0)!=66){v=u;q=15;break}w=bHb(k,d)|0;x=1.0}else{v=o;q=15}}while(0);if((q|0)==15){q=0;o=a[v]|0;u=(o<<24>>24==43)-(o<<24>>24==45)|0;c[l>>2]=v+(u&1);w=bHb(k,d)|0;x=+(u|1|0)}if((w|0)<0){q=17;break}y=c[k>>2]|0;u=pJb(40)|0;if((u|0)==0){q=19;break}o=u;c[u>>2]=18;h[u+8>>3]=1.0;c[u+20>>2]=m;c[u+24>>2]=y;c[j>>2]=o;if((y|0)!=0){u=y+8|0;h[u>>3]=x*+h[u>>3]}u=c[l>>2]|0;if((a[u]|0)==94){p=u;m=o}else{z=o;break a}}if((q|0)==17){TGb(m);t=w;i=e;return t|0}else if((q|0)==19){c[j>>2]=0;TGb(m);TGb(y);t=-12;i=e;return t|0}}else{z=f}}while(0);if((z|0)!=0){f=z+8|0;h[f>>3]=s*+h[f>>3]}c[b>>2]=z;t=0;i=e;return t|0}function bHb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0;e=i;i=i+16|0;f=e|0;g=e+8|0;j=pJb(40)|0;c[f>>2]=j;k=d+8|0;l=c[k>>2]|0;c[g>>2]=l;if((j|0)==0){m=-12;i=e;return m|0}n=+SGb(l,g);j=c[f>>2]|0;o=j+8|0;h[o>>3]=n;p=c[g>>2]|0;if((p|0)!=(c[k>>2]|0)){c[j>>2]=0;c[k>>2]=p;c[b>>2]=j;m=0;i=e;return m|0}h[o>>3]=1.0;q=c[d+16>>2]|0;a:do{if((q|0)==0){r=0}else{s=0;while(1){t=c[q+(s<<2)>>2]|0;if((t|0)==0){r=0;break a}else{u=0}while(1){v=a[t+u|0]|0;w=a[p+u|0]|0;if(v<<24>>24==0){x=8;break}if(v<<24>>24==w<<24>>24){u=u+1|0}else{break}}if((x|0)==8){x=0;v=w<<24>>24;if(!((v-48|0)>>>0<10>>>0|(v-97|0)>>>0<26>>>0|(v-65|0)>>>0<26>>>0|w<<24>>24==95)){break}}s=s+1|0}c[k>>2]=p+(lrc(t|0)|0);c[j>>2]=1;c[j+16>>2]=s;c[b>>2]=j;m=0;i=e;return m|0}}while(0);while(1){y=a[p+r|0]|0;if((r|0)==1){x=13;break}if((a[2249760+r|0]|0)==y<<24>>24){r=r+1|0}else{z=0;x=226;break}}if((x|0)==13){r=y<<24>>24;if((r-48|0)>>>0<10>>>0|(r-97|0)>>>0<26>>>0|(r-65|0)>>>0<26>>>0|y<<24>>24==95){z=0;x=226}else{A=0;B=1637848}}do{if((x|0)==226){while(1){x=0;C=a[p+z|0]|0;if((z|0)==2){x=228;break}if((a[2239464+z|0]|0)==C<<24>>24){z=z+1|0;x=226}else{D=0;break}}if((x|0)==228){s=C<<24>>24;if((s-48|0)>>>0<10>>>0|(s-97|0)>>>0<26>>>0|(s-65|0)>>>0<26>>>0|C<<24>>24==95){D=0}else{A=1;B=1637864;break}}while(1){E=a[p+D|0]|0;if((D|0)==3){x=231;break}if((a[2234512+D|0]|0)==E<<24>>24){D=D+1|0}else{break}}if((x|0)==231){s=E<<24>>24;if(!((s-48|0)>>>0<10>>>0|(s-97|0)>>>0<26>>>0|(s-65|0)>>>0<26>>>0|E<<24>>24==95)){A=2;B=1637880;break}}s=_b(p|0,40)|0;c[k>>2]=s;if((s|0)==0){KIb(d,16,2435968,(F=i,i=i+8|0,c[F>>2]=l,F)|0);i=F;c[k>>2]=c[g>>2];TGb(c[f>>2]|0);m=-22;i=e;return m|0}c[k>>2]=s+1;if((a[p]|0)==40){mJb(f);s=VGb(f,d)|0;if((s|0)<0){m=s;i=e;return m|0}s=c[k>>2]|0;if((a[s]|0)==41){c[k>>2]=s+1;c[b>>2]=c[f>>2];m=0;i=e;return m|0}else{KIb(d,16,2349472,(F=i,i=i+8|0,c[F>>2]=l,F)|0);i=F;TGb(c[f>>2]|0);m=-22;i=e;return m|0}}s=VGb(j+20|0,d)|0;if((s|0)<0){TGb(c[f>>2]|0);m=s;i=e;return m|0}s=c[k>>2]|0;y=a[s]|0;do{if(y<<24>>24==44){c[k>>2]=s+1;VGb((c[f>>2]|0)+24|0,d)|0;r=c[k>>2]|0;t=a[r]|0;if(!(t<<24>>24==44)){G=r;H=t;break}c[k>>2]=r+1;VGb((c[f>>2]|0)+28|0,d)|0;r=c[k>>2]|0;G=r;H=a[r]|0}else{G=s;H=y}}while(0);if(!(H<<24>>24==41)){KIb(d,16,2287728,(F=i,i=i+8|0,c[F>>2]=l,F)|0);i=F;TGb(c[f>>2]|0);m=-22;i=e;return m|0}c[k>>2]=G+1;y=c[f>>2]|0;s=y|0;c[s>>2]=2;r=c[g>>2]|0;t=0;while(1){I=a[r+t|0]|0;if((t|0)==4){x=31;break}if((a[2237912+t|0]|0)==I<<24>>24){t=t+1|0}else{J=0;x=33;break}}do{if((x|0)==31){t=I<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|I<<24>>24==95){J=0;x=33;break}c[y+16>>2]=24}}while(0);b:do{if((x|0)==33){while(1){x=0;K=a[r+J|0]|0;if((J|0)==4){x=35;break}if((a[2197304+J|0]|0)==K<<24>>24){J=J+1|0;x=33}else{L=0;break}}do{if((x|0)==35){t=K<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|K<<24>>24==95){L=0;break}c[y+16>>2]=16;break b}}while(0);while(1){M=a[r+L|0]|0;if((L|0)==4){x=39;break}if((a[2165752+L|0]|0)==M<<24>>24){L=L+1|0}else{N=0;break}}do{if((x|0)==39){t=M<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|M<<24>>24==95){N=0;break}c[y+16>>2]=2;break b}}while(0);while(1){O=a[r+N|0]|0;if((N|0)==3){x=43;break}if((a[2139552+N|0]|0)==O<<24>>24){N=N+1|0}else{P=0;break}}do{if((x|0)==43){t=O<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|O<<24>>24==95){P=0;break}c[y+16>>2]=22;break b}}while(0);while(1){Q=a[r+P|0]|0;if((P|0)==3){x=47;break}if((a[2116160+P|0]|0)==Q<<24>>24){P=P+1|0}else{R=0;break}}do{if((x|0)==47){t=Q<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Q<<24>>24==95){R=0;break}c[y+16>>2]=12;break b}}while(0);while(1){S=a[r+R|0]|0;if((R|0)==3){x=51;break}if((a[2634016+R|0]|0)==S<<24>>24){R=R+1|0}else{T=0;break}}do{if((x|0)==51){t=S<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|S<<24>>24==95){T=0;break}c[y+16>>2]=18;break b}}while(0);while(1){U=a[r+T|0]|0;if((T|0)==4){x=55;break}if((a[2610272+T|0]|0)==U<<24>>24){T=T+1|0}else{V=0;break}}do{if((x|0)==55){t=U<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|U<<24>>24==95){V=0;break}c[y+16>>2]=4;break b}}while(0);while(1){W=a[r+V|0]|0;if((V|0)==4){x=59;break}if((a[2583728+V|0]|0)==W<<24>>24){V=V+1|0}else{X=0;break}}do{if((x|0)==59){t=W<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|W<<24>>24==95){X=0;break}c[y+16>>2]=26;break b}}while(0);while(1){Y=a[r+X|0]|0;if((X|0)==4){x=63;break}if((a[2563144+X|0]|0)==Y<<24>>24){X=X+1|0}else{Z=0;break}}do{if((x|0)==63){t=Y<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Y<<24>>24==95){Z=0;break}c[y+16>>2]=10;break b}}while(0);while(1){_=a[r+Z|0]|0;if((Z|0)==3){x=67;break}if((a[2545640+Z|0]|0)==_<<24>>24){Z=Z+1|0}else{$=0;break}}do{if((x|0)==67){t=_<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|_<<24>>24==95){$=0;break}c[y+16>>2]=20;break b}}while(0);while(1){aa=a[r+$|0]|0;if(($|0)==3){x=71;break}if((a[2527872+$|0]|0)==aa<<24>>24){$=$+1|0}else{ba=0;break}}do{if((x|0)==71){t=aa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|aa<<24>>24==95){ba=0;break}c[y+16>>2]=8;break b}}while(0);while(1){ca=a[r+ba|0]|0;if((ba|0)==3){x=75;break}if((a[2512912+ba|0]|0)==ca<<24>>24){ba=ba+1|0}else{da=0;break}}do{if((x|0)==75){t=ca<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ca<<24>>24==95){da=0;break}c[y+16>>2]=14;break b}}while(0);while(1){ea=a[r+da|0]|0;if((da|0)==4){x=79;break}if((a[2499224+da|0]|0)==ea<<24>>24){da=da+1|0}else{fa=0;break}}do{if((x|0)==79){t=ea<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ea<<24>>24==95){fa=0;break}c[y+16>>2]=6;break b}}while(0);while(1){ga=a[r+fa|0]|0;if((fa|0)==6){x=83;break}if((a[2486784+fa|0]|0)==ga<<24>>24){fa=fa+1|0}else{ha=0;break}}do{if((x|0)==83){t=ga<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ga<<24>>24==95){ha=0;break}c[s>>2]=5;break b}}while(0);while(1){ia=a[r+ha|0]|0;if((ha|0)==5){x=87;break}if((a[2475152+ha|0]|0)==ia<<24>>24){ha=ha+1|0}else{ja=0;break}}do{if((x|0)==87){t=ia<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ia<<24>>24==95){ja=0;break}c[s>>2]=6;break b}}while(0);while(1){ka=a[r+ja|0]|0;if((ja|0)==3){x=91;break}if((a[2466344+ja|0]|0)==ka<<24>>24){ja=ja+1|0}else{la=0;break}}do{if((x|0)==91){t=ka<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ka<<24>>24==95){la=0;break}c[s>>2]=10;break b}}while(0);while(1){ma=a[r+la|0]|0;if((la|0)==3){x=95;break}if((a[2456192+la|0]|0)==ma<<24>>24){la=la+1|0}else{na=0;break}}do{if((x|0)==95){t=ma<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ma<<24>>24==95){na=0;break}c[s>>2]=11;break b}}while(0);while(1){oa=a[r+na|0]|0;if((na|0)==3){x=99;break}if((a[2438896+na|0]|0)==oa<<24>>24){na=na+1|0}else{pa=0;break}}do{if((x|0)==99){t=oa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|oa<<24>>24==95){pa=0;break}c[s>>2]=12;break b}}while(0);while(1){qa=a[r+pa|0]|0;if((pa|0)==2){x=103;break}if((a[2428352+pa|0]|0)==qa<<24>>24){pa=pa+1|0}else{ra=0;break}}do{if((x|0)==103){t=qa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|qa<<24>>24==95){ra=0;break}c[s>>2]=13;break b}}while(0);while(1){sa=a[r+ra|0]|0;if((ra|0)==3){x=107;break}if((a[2417872+ra|0]|0)==sa<<24>>24){ra=ra+1|0}else{ta=0;break}}do{if((x|0)==107){t=sa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|sa<<24>>24==95){ta=0;break}c[s>>2]=15;break b}}while(0);while(1){ua=a[r+ta|0]|0;if((ta|0)==2){x=111;break}if((a[2408784+ta|0]|0)==ua<<24>>24){ta=ta+1|0}else{va=0;break}}do{if((x|0)==111){t=ua<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ua<<24>>24==95){va=0;break}c[s>>2]=14;break b}}while(0);while(1){wa=a[r+va|0]|0;if((va|0)==3){x=115;break}if((a[2401296+va|0]|0)==wa<<24>>24){va=va+1|0}else{xa=0;break}}do{if((x|0)==115){t=wa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|wa<<24>>24==95){xa=0;break}c[s>>2]=16;break b}}while(0);while(1){ya=a[r+xa|0]|0;if((xa|0)==2){x=119;break}if((a[2394416+xa|0]|0)==ya<<24>>24){xa=xa+1|0}else{za=0;break}}do{if((x|0)==119){t=ya<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ya<<24>>24==95){za=0;break}c[s>>2]=17;break b}}while(0);while(1){Aa=a[r+za|0]|0;if((za|0)==2){x=123;break}if((a[2387376+za|0]|0)==Aa<<24>>24){za=za+1|0}else{Ba=0;break}}do{if((x|0)==123){t=Aa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Aa<<24>>24==95){Ba=0;break}c[s>>2]=7;break b}}while(0);while(1){Ca=a[r+Ba|0]|0;if((Ba|0)==5){x=127;break}if((a[2380544+Ba|0]|0)==Ca<<24>>24){Ba=Ba+1|0}else{Da=0;break}}do{if((x|0)==127){t=Ca<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ca<<24>>24==95){Da=0;break}c[s>>2]=8;break b}}while(0);while(1){Ea=a[r+Da|0]|0;if((Da|0)==5){x=131;break}if((a[2374168+Da|0]|0)==Ea<<24>>24){Da=Da+1|0}else{Fa=0;break}}do{if((x|0)==131){t=Ea<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ea<<24>>24==95){Fa=0;break}c[s>>2]=9;break b}}while(0);while(1){Ga=a[r+Fa|0]|0;if((Fa|0)==2){x=135;break}if((a[2366648+Fa|0]|0)==Ga<<24>>24){Fa=Fa+1|0}else{Ha=0;break}}do{if((x|0)==135){t=Ga<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ga<<24>>24==95){Ha=0;break}c[s>>2]=23;break b}}while(0);while(1){Ia=a[r+Ha|0]|0;if((Ha|0)==5){x=139;break}if((a[2351648+Ha|0]|0)==Ia<<24>>24){Ha=Ha+1|0}else{Ja=0;break}}do{if((x|0)==139){t=Ia<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ia<<24>>24==95){Ja=0;break}c[s>>2]=24;break b}}while(0);while(1){Ka=a[r+Ja|0]|0;if((Ja|0)==6){x=143;break}if((a[2344072+Ja|0]|0)==Ka<<24>>24){Ja=Ja+1|0}else{La=0;break}}do{if((x|0)==143){t=Ka<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ka<<24>>24==95){La=0;break}c[s>>2]=25;break b}}while(0);while(1){Ma=a[r+La|0]|0;if((La|0)==4){x=147;break}if((a[2338032+La|0]|0)==Ma<<24>>24){La=La+1|0}else{Na=0;break}}do{if((x|0)==147){t=Ma<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ma<<24>>24==95){Na=0;break}c[s>>2]=26;break b}}while(0);while(1){Oa=a[r+Na|0]|0;if((Na|0)==5){x=151;break}if((a[2332480+Na|0]|0)==Oa<<24>>24){Na=Na+1|0}else{Pa=0;break}}do{if((x|0)==151){t=Oa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Oa<<24>>24==95){Pa=0;break}c[s>>2]=27;break b}}while(0);while(1){Qa=a[r+Pa|0]|0;if((Pa|0)==4){x=155;break}if((a[2326952+Pa|0]|0)==Qa<<24>>24){Pa=Pa+1|0}else{Ra=0;break}}do{if((x|0)==155){t=Qa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Qa<<24>>24==95){Ra=0;break}c[s>>2]=28;break b}}while(0);while(1){Sa=a[r+Ra|0]|0;if((Ra|0)==5){x=159;break}if((a[2321128+Ra|0]|0)==Sa<<24>>24){Ra=Ra+1|0}else{Ta=0;break}}do{if((x|0)==159){t=Sa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Sa<<24>>24==95){Ta=0;break}c[s>>2]=29;break b}}while(0);while(1){Ua=a[r+Ta|0]|0;if((Ta|0)==4){x=163;break}if((a[2316160+Ta|0]|0)==Ua<<24>>24){Ta=Ta+1|0}else{Va=0;break}}do{if((x|0)==163){t=Ua<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ua<<24>>24==95){Va=0;break}c[s>>2]=30;break b}}while(0);while(1){Wa=a[r+Va|0]|0;if((Va|0)==3){x=167;break}if((a[2311736+Va|0]|0)==Wa<<24>>24){Va=Va+1|0}else{Xa=0;break}}do{if((x|0)==167){t=Wa<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Wa<<24>>24==95){Xa=0;break}c[s>>2]=31;break b}}while(0);while(1){Ya=a[r+Xa|0]|0;if((Xa|0)==3){x=171;break}if((a[2307072+Xa|0]|0)==Ya<<24>>24){Xa=Xa+1|0}else{Za=0;break}}do{if((x|0)==171){t=Ya<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|Ya<<24>>24==95){Za=0;break}c[s>>2]=18;break b}}while(0);while(1){_a=a[r+Za|0]|0;if((Za|0)==5){x=175;break}if((a[2301040+Za|0]|0)==_a<<24>>24){Za=Za+1|0}else{$a=0;break}}do{if((x|0)==175){t=_a<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|_a<<24>>24==95){$a=0;break}c[s>>2]=37;break b}}while(0);while(1){ab=a[r+$a|0]|0;if(($a|0)==6){x=179;break}if((a[2289904+$a|0]|0)==ab<<24>>24){$a=$a+1|0}else{bb=0;break}}do{if((x|0)==179){t=ab<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ab<<24>>24==95){bb=0;break}c[s>>2]=32;break b}}while(0);while(1){cb=a[r+bb|0]|0;if((bb|0)==5){x=183;break}if((a[2284024+bb|0]|0)==cb<<24>>24){bb=bb+1|0}else{db=0;break}}do{if((x|0)==183){t=cb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|cb<<24>>24==95){db=0;break}c[s>>2]=33;break b}}while(0);while(1){eb=a[r+db|0]|0;if((db|0)==3){x=187;break}if((a[2280264+db|0]|0)==eb<<24>>24){db=db+1|0}else{fb=0;break}}do{if((x|0)==187){t=eb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|eb<<24>>24==95){fb=0;break}c[s>>2]=34;break b}}while(0);while(1){gb=a[r+fb|0]|0;if((fb|0)==2){x=191;break}if((a[2276056+fb|0]|0)==gb<<24>>24){fb=fb+1|0}else{hb=0;break}}do{if((x|0)==191){t=gb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|gb<<24>>24==95){hb=0;break}c[s>>2]=35;break b}}while(0);while(1){ib=a[r+hb|0]|0;if((hb|0)==5){x=195;break}if((a[2271416+hb|0]|0)==ib<<24>>24){hb=hb+1|0}else{jb=0;break}}do{if((x|0)==195){t=ib<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ib<<24>>24==95){jb=0;break}c[s>>2]=36;break b}}while(0);while(1){kb=a[r+jb|0]|0;if((jb|0)==6){x=199;break}if((a[2266832+jb|0]|0)==kb<<24>>24){jb=jb+1|0}else{lb=0;break}}do{if((x|0)==199){t=kb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|kb<<24>>24==95){lb=0;break}c[s>>2]=38;break b}}while(0);while(1){mb=a[r+lb|0]|0;if((lb|0)==5){x=203;break}if((a[2263280+lb|0]|0)==mb<<24>>24){lb=lb+1|0}else{nb=0;break}}do{if((x|0)==203){t=mb<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|mb<<24>>24==95){nb=0;break}c[s>>2]=39;break b}}while(0);while(1){ob=a[r+nb|0]|0;if((nb|0)==7){x=208;break}if((a[2259392+nb|0]|0)==ob<<24>>24){nb=nb+1|0}else{break}}do{if((x|0)==208){t=ob<<24>>24;if((t-48|0)>>>0<10>>>0|(t-97|0)>>>0<26>>>0|(t-65|0)>>>0<26>>>0|ob<<24>>24==95){break}c[s>>2]=40;break b}}while(0);t=c[d+24>>2]|0;c:do{if((t|0)!=0){w=0;while(1){u=c[t+(w<<2)>>2]|0;if((u|0)==0){break c}else{pb=0}while(1){q=a[u+pb|0]|0;qb=a[r+pb|0]|0;if(q<<24>>24==0){x=214;break}if(q<<24>>24==qb<<24>>24){pb=pb+1|0}else{break}}if((x|0)==214){x=0;u=qb<<24>>24;if(!((u-48|0)>>>0<10>>>0|(u-97|0)>>>0<26>>>0|(u-65|0)>>>0<26>>>0|qb<<24>>24==95)){break}}w=w+1|0}c[y+16>>2]=c[(c[d+20>>2]|0)+(w<<2)>>2];u=c[f>>2]|0;c[u>>2]=3;c[b>>2]=u;m=0;i=e;return m|0}}while(0);t=c[d+32>>2]|0;d:do{if((t|0)!=0){u=0;while(1){q=c[t+(u<<2)>>2]|0;if((q|0)==0){break d}else{rb=0}while(1){v=a[q+rb|0]|0;sb=a[r+rb|0]|0;if(v<<24>>24==0){x=220;break}if(v<<24>>24==sb<<24>>24){rb=rb+1|0}else{break}}if((x|0)==220){x=0;q=sb<<24>>24;if(!((q-48|0)>>>0<10>>>0|(q-97|0)>>>0<26>>>0|(q-65|0)>>>0<26>>>0|sb<<24>>24==95)){break}}u=u+1|0}c[y+16>>2]=c[(c[d+28>>2]|0)+(u<<2)>>2];w=c[f>>2]|0;c[w>>2]=4;c[b>>2]=w;m=0;i=e;return m|0}}while(0);KIb(d,16,2254968,(F=i,i=i+8|0,c[F>>2]=l,F)|0);i=F;TGb(c[f>>2]|0);m=-22;i=e;return m|0}}while(0);c[b>>2]=c[f>>2];m=0;i=e;return m|0}}while(0);c[k>>2]=p+(lrc(c[B>>2]|0)|0);c[j>>2]=0;h[o>>3]=+h[1637856+(A<<4)>>3];c[b>>2]=j;m=0;i=e;return m|0}function cHb(a){a=+a;var b=0;b=jLb()|0;return+((+(b>>>0)+ +(G|0)*4294967296.0)*1.0e-6)}function dHb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;e=pJb(24)|0;f=e;c[d>>2]=f;if((e|0)==0){g=0;i=b;return g|0}h=hJb(a)|0;c[e>>2]=h;c[e+12>>2]=h+a;c[e+4>>2]=h;c[e+8>>2]=h;c[e+16>>2]=0;c[e+20>>2]=0;if((h|0)!=0){g=f;i=b;return g|0}mJb(d);g=c[d>>2]|0;i=b;return g|0}function eHb(a){a=a|0;var b=0;if((a|0)==0){return}b=a;mJb(b);kJb(b);return}function fHb(a){a=a|0;return(c[a+20>>2]|0)-(c[a+16>>2]|0)|0}function gHb(a){a=a|0;return(c[a+12>>2]|0)-(c[a>>2]|0)-(c[a+20>>2]|0)+(c[a+16>>2]|0)|0}function hHb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+8|0;e=d|0;f=a+12|0;g=a|0;if(!(((c[f>>2]|0)-(c[g>>2]|0)|0)>>>0<b>>>0)){h=0;i=d;return h|0}j=a+16|0;k=(c[a+20>>2]|0)-(c[j>>2]|0)|0;l=pJb(24)|0;m=l;c[e>>2]=m;if((l|0)==0){h=-12;i=d;return h|0}n=hJb(b)|0;c[l>>2]=n;c[l+12>>2]=n+b;c[l+4>>2]=n;c[l+8>>2]=n;c[l+16>>2]=0;c[l+20>>2]=0;if((n|0)==0){mJb(e);o=c[e>>2]|0}else{o=m}if((o|0)==0){h=-12;i=d;return h|0}m=a+4|0;e=c[o>>2]|0;n=k;l=c[f>>2]|0;b=c[m>>2]|0;while(1){p=l-b|0;q=(p|0)>(n|0)?n:p;nrc(e|0,b|0,q)|0;p=c[m>>2]|0;r=c[f>>2]|0;s=p+q|0;c[m>>2]=s;if(s>>>0<r>>>0){t=s}else{s=p+(q-r+(c[g>>2]|0))|0;c[m>>2]=s;t=s}c[j>>2]=(c[j>>2]|0)+q;s=n-q|0;if((s|0)>0){e=e+q|0;n=s;l=r;b=t}else{break}}t=o+8|0;c[t>>2]=(c[t>>2]|0)+k;t=o+20|0;c[t>>2]=(c[t>>2]|0)+k;kJb(c[g>>2]|0);g=a;a=o;c[g>>2]=c[a>>2];c[g+4>>2]=c[a+4>>2];c[g+8>>2]=c[a+8>>2];c[g+12>>2]=c[a+12>>2];c[g+16>>2]=c[a+16>>2];c[g+20>>2]=c[a+20>>2];kJb(a);h=0;i=d;return h|0}function iHb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=a+12|0;g=a+4|0;h=a+16|0;i=a|0;a=c[f>>2]|0;j=c[g>>2]|0;if((e|0)==0){k=b;l=d;m=a;n=j;while(1){o=m-n|0;p=(o|0)>(l|0)?l:o;nrc(k|0,n|0,p)|0;o=c[g>>2]|0;q=c[f>>2]|0;r=o+p|0;c[g>>2]=r;if(r>>>0<q>>>0){s=r}else{r=o+(p-q+(c[i>>2]|0))|0;c[g>>2]=r;s=r}c[h>>2]=(c[h>>2]|0)+p;r=l-p|0;if((r|0)>0){k=k+p|0;l=r;m=q;n=s}else{break}}return 0}else{s=d;d=a;a=j;while(1){j=d-a|0;n=(j|0)>(s|0)?s:j;ef[e&4095](b,a,n);j=c[g>>2]|0;m=c[f>>2]|0;l=j+n|0;c[g>>2]=l;if(l>>>0<m>>>0){t=l}else{l=j+(n-m+(c[i>>2]|0))|0;c[g>>2]=l;t=l}c[h>>2]=(c[h>>2]|0)+n;l=s-n|0;if((l|0)>0){s=l;d=m;a=t}else{break}}return 0}return 0}function jHb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=a+20|0;g=c[f>>2]|0;h=a+8|0;i=c[h>>2]|0;j=a+12|0;k=a|0;a=c[j>>2]|0;if((e|0)==0){l=b;m=i;n=g;o=d;p=a;while(1){q=p-m|0;r=(q|0)>(o|0)?o:q;nrc(m|0,l|0,r)|0;q=c[j>>2]|0;s=m+r|0;if(s>>>0<q>>>0){t=s}else{t=c[k>>2]|0}s=r+n|0;u=o-r|0;if((u|0)>0){l=l+r|0;m=t;n=s;o=u;p=q}else{v=t;w=s;x=u;break}}c[f>>2]=w;c[h>>2]=v;y=d-x|0;return y|0}else{z=i;A=g;B=d;C=a}while(1){a=C-z|0;g=(a|0)>(B|0)?B:a;if((Ee[e&511](b,z,g)|0)<1){v=z;w=A;x=B;D=9;break}a=c[j>>2]|0;i=z+g|0;if(i>>>0<a>>>0){E=i}else{E=c[k>>2]|0}i=g+A|0;t=B-g|0;if((t|0)>0){z=E;A=i;B=t;C=a}else{v=E;w=i;x=t;D=9;break}}if((D|0)==9){c[f>>2]=w;c[h>>2]=v;y=d-x|0;return y|0}return 0}function kHb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+4|0;e=c[d>>2]|0;f=e+b|0;c[d>>2]=f;g=c[a+12>>2]|0;if(!(f>>>0<g>>>0)){c[d>>2]=e+(b-g+(c[a>>2]|0))}g=a+16|0;c[g>>2]=(c[g>>2]|0)+b;return}function lHb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+224|0;h=g|0;j=g+16|0;k=g+96|0;c[h>>2]=1235056;c[h+4>>2]=e;c[h+8>>2]=f;f=nHb(a,0,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0)|0;i=e;c[b>>2]=0;if((f|0)<0){l=-(c[(pd()|0)>>2]|0)|0;m=k|0;RGb(l,m,128)|0;KIb(h,16,2412856,(e=i,i=i+16|0,c[e>>2]=a,c[e+8>>2]=m,e)|0);i=e;n=l;i=g;return n|0}if((sd(f|0,j|0)|0)<0){l=-(c[(pd()|0)>>2]|0)|0;m=k|0;RGb(l,m,128)|0;KIb(h,16,2578768,(e=i,i=i+8|0,c[e>>2]=m,e)|0);i=e;Zb(f|0)|0;n=l;i=g;return n|0}l=c[j+36>>2]|0;c[d>>2]=l;d=Cc(0,l|0,3,2,f|0,0)|0;if((d|0)==-1){l=-(c[(pd()|0)>>2]|0)|0;j=k|0;RGb(l,j,128)|0;KIb(h,16,2349440,(e=i,i=i+8|0,c[e>>2]=j,e)|0);i=e;Zb(f|0)|0;n=l;i=g;return n|0}else{c[b>>2]=d;Zb(f|0)|0;n=0;i=g;return n|0}return 0}function mHb(a,b){a=a|0;b=b|0;Jb(a|0,b|0)|0;return}function nHb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;if((b&64|0)==0){h=0}else{g=f|0;h=(x=c[g+4>>2]|0,c[g+4>>2]=x+8,c[(c[g>>2]|0)+x>>2]|0)}g=Rc(a|0,b|524288|0,(b=i,i=i+8|0,c[b>>2]=h,b)|0)|0;i=b;if((g|0)==-1){i=e;return g|0}h=kc(g|0,2,(b=i,i=i+8|0,c[b>>2]=1,b)|0)|0;i=b;if(!((h|0)==-1)){i=e;return g|0}KIb(0,48,2412808,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;i=e;return g|0}function oHb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a[d]|0;if((f|0)==114){g=d;h=0}else if((f|0)==119){g=d;h=577}else if((f|0)==97){g=d;h=1089}else{c[(pd()|0)>>2]=22;j=0;i=e;return j|0}while(1){f=g+1|0;k=a[f]|0;if((k<<24>>24|0)==0){break}else if((k<<24>>24|0)==98){g=f;h=h;continue}else if((k<<24>>24|0)!=43){l=7;break}g=f;h=h&-4|2}if((l|0)==7){c[(pd()|0)>>2]=22;j=0;i=e;return j|0}l=nHb(b,h,(h=i,i=i+8|0,c[h>>2]=438,h)|0)|0;i=h;if((l|0)==-1){j=0;i=e;return j|0}j=$c(l|0,d|0)|0;i=e;return j|0}function pHb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0.0,e=0,f=0.0,h=0.0,i=0;if((c|0)>0){d=0.0;e=0}else{f=0.0;return+f}while(1){h=d+ +g[a+(e<<2)>>2]*+g[b+(e<<2)>>2];i=e+1|0;if((i|0)<(c|0)){d=h;e=i}else{f=h;break}}return+f}function qHb(a,b){a=a|0;b=b|0;c[a>>2]=388;c[a+4>>2]=4;c[a+8>>2]=6;c[a+12>>2]=2;c[a+16>>2]=220;c[a+20>>2]=384;c[a+24>>2]=912;c[a+28>>2]=2312;c[a+32>>2]=6;return}function rHb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((d|0)>0){e=0}else{return}do{g[a+(e<<2)>>2]=+g[b+(e<<2)>>2]*+g[c+(e<<2)>>2];e=e+1|0;}while((e|0)<(d|0));return}function sHb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0;if((d|0)>0){e=0}else{return}do{f=a+(e<<2)|0;g[f>>2]=+g[f>>2]+ +g[b+(e<<2)>>2]*c;e=e+1|0;}while((e|0)<(d|0));return}function tHb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0;if((d|0)>0){e=0}else{return}do{g[a+(e<<2)>>2]=+g[b+(e<<2)>>2]*c;e=e+1|0;}while((e|0)<(d|0));return}function uHb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0;if((d|0)>0){e=0}else{return}do{h[a+(e<<3)>>3]=+h[b+(e<<3)>>3]*c;e=e+1|0;}while((e|0)<(d|0));return}function vHb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0,n=0.0;if((e|0)<=0){return}f=-e|0;h=e;do{h=h-1|0;i=f+e|0;j=+g[b+(i<<2)>>2];k=+g[c+(h<<2)>>2];l=+g[d+(i<<2)>>2];m=h+e|0;n=+g[d+(m<<2)>>2];g[a+(i<<2)>>2]=j*n-k*l;g[a+(m<<2)>>2]=j*l+k*n;f=f+1|0;}while((f|0)<0);return}function wHb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;if((e|0)>0){f=0}else{return}do{g[a+(f<<2)>>2]=+g[b+(f<<2)>>2]*+g[c+(f<<2)>>2]+ +g[d+(f<<2)>>2];f=f+1|0;}while((f|0)<(e|0));return}function xHb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=d-1|0;if((d|0)>0){f=0}else{return}do{g[a+(f<<2)>>2]=+g[b+(f<<2)>>2]*+g[c+(e-f<<2)>>2];f=f+1|0;}while((f|0)<(d|0));return}function yHb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0,i=0.0;if((c|0)>0){d=0}else{return}do{e=a+(d<<2)|0;f=+g[e>>2];h=b+(d<<2)|0;i=+g[h>>2];g[e>>2]=f+i;g[h>>2]=f-i;d=d+1|0;}while((d|0)<(c|0));return}function zHb(a){a=a|0;var b=0;b=a+416|0;return(G=c[b+4>>2]|0,c[b>>2]|0)|0}function AHb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+416|0;c[e>>2]=b;c[e+4>>2]=d;return}function BHb(a){a=a|0;var b=0;b=a+432|0;return(G=c[b+4>>2]|0,c[b>>2]|0)|0}function CHb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+432|0;c[e>>2]=b;c[e+4>>2]=d;return}function DHb(a){a=a|0;var b=0;b=a+424|0;return(G=c[b+4>>2]|0,c[b>>2]|0)|0}function EHb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+424|0;c[e>>2]=b;c[e+4>>2]=d;return}function FHb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+352|0;c[e>>2]=b;c[e+4>>2]=d;return}function GHb(a){a=a|0;return c[a+448>>2]|0}function HHb(a,b){a=a|0;b=b|0;c[a+448>>2]=b;return}function IHb(a,b){a=a|0;b=b|0;c[a+344>>2]=b;return}function JHb(a,b){a=a|0;b=b|0;c[a+440>>2]=b;return}function KHb(a,b){a=a|0;b=b|0;c[a+444>>2]=b;return}function LHb(a,b){a=a|0;b=b|0;c[a+452>>2]=b;return}function MHb(a){a=a|0;return c[a+456>>2]|0}function NHb(a,b){a=a|0;b=b|0;c[a+456>>2]=b;return}function OHb(a){a=a|0;return c[a+460>>2]|0}function PHb(a,b){a=a|0;b=b|0;c[a+460>>2]=b;return}function QHb(a){a=a|0;return a+440|0}function RHb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=a+464|0;fGb(f);c[f>>2]=b;c[a+176>>2]=c[b+4>>2];c[a+180>>2]=d;c[a+184>>2]=e;return 0}function SHb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;c[b>>2]=c[a+180>>2];c[d>>2]=c[a+184>>2];d=c[a+464>>2]|0;if((d|0)==0){e=0;return e|0}e=c[d+4>>2]|0;return e|0}function THb(a){a=a|0;var b=0;if(a>>>0>8>>>0){b=0;return b|0}b=c[2003968+(a<<2)>>2]|0;return b|0}function UHb(){var a=0,b=0,d=0,e=0;a=pJb(472)|0;if((a|0)==0){b=0;return b|0}d=a+64|0;e=d;c[e>>2]=0;mJb(d);mrc(a|0,0,472)|0;d=a+144|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+152|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+136|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+416|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=a+432|0;c[d>>2]=0;c[d+4>>2]=0;d=a+424|0;c[d>>2]=-1;c[d+4>>2]=-1;c[a+452>>2]=-1;c[a+84>>2]=1;c[a+124>>2]=0;c[a+128>>2]=1;c[a+80>>2]=-1;c[a+456>>2]=2;c[e>>2]=a;b=a;return b|0}function VHb(a){a=a|0;var b=0;if((a|0)==0){return}b=c[a>>2]|0;if((b|0)==0){return}WHb(b);mJb(a);return}function WHb(a){a=a|0;var b=0,d=0,e=0;b=a+404|0;d=a+400|0;if((c[b>>2]|0)>0){e=0;do{mJb((c[(c[d>>2]|0)+(e<<2)>>2]|0)+4|0);OGb((c[(c[d>>2]|0)+(e<<2)>>2]|0)+12|0);mJb((c[d>>2]|0)+(e<<2)|0);e=e+1|0;}while((e|0)<(c[b>>2]|0))}mJb(d);fGb(a+360|0);fGb(a+364|0);fGb(a+368|0);fGb(a+372|0);fGb(a+376|0);fGb(a+380|0);fGb(a+384|0);fGb(a+388|0);d=a+396|0;b=a+392|0;if((c[d>>2]|0)>0){e=0;do{fGb((c[b>>2]|0)+(e<<2)|0);e=e+1|0;}while((e|0)<(c[d>>2]|0))}mJb(b);OGb(a+440|0);fGb(a+464|0);b=a+64|0;d=a|0;if((c[b>>2]|0)!=(d|0)){mJb(b)}mrc(a|0,0,472)|0;e=a+144|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=a+152|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=a+136|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=a+416|0;c[e>>2]=0;c[e+4>>2]=-2147483648;e=a+432|0;c[e>>2]=0;c[e+4>>2]=0;e=a+424|0;c[e>>2]=-1;c[e+4>>2]=-1;c[a+452>>2]=-1;c[a+84>>2]=1;c[a+124>>2]=0;c[a+128>>2]=1;c[a+80>>2]=-1;c[a+456>>2]=2;c[b>>2]=d;return}function XHb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b+80|0;g=c[f>>2]|0;if((g|0)<0){h=-22;return h|0}i=b+68|0;do{if((c[i>>2]|0)>0){j=b+72|0;if((c[j>>2]|0)<=0){break}k=qKb(g)|0;if((k|0)==0){h=-22;return h|0}l=tIb(c[i>>2]|0,c[j>>2]|0,0,0)|0;if((l|0)<0){h=l;return h|0}l=b+32|0;m=c[l>>2]|0;do{if((m|0)==0){n=e-1|0;o=1;p=0;while(1){if((o|0)>(e|0)){q=p;break}r=pIb(l,c[f>>2]|0,o-1+(c[i>>2]|0)&-o)|0;if((r|0)<0){h=r;s=52;break}r=c[l>>2]|0;if((r&n|0)==0){q=r;break}else{o=o<<1;p=r}}if((s|0)==52){return h|0}p=-e|0;if((q|0)==0){s=16;break}o=q+n&p;c[l>>2]=o;r=b+36|0;t=c[r>>2]|0;do{if((t|0)!=0){c[r>>2]=t+n&p;u=b+40|0;v=c[u>>2]|0;if((v|0)==0){break}c[u>>2]=v+n&p;v=b+44|0;u=c[v>>2]|0;if((u|0)==0){break}c[v>>2]=u+n&p}}while(0);if((o|0)==0){s=16}else{w=o;s=14}}else{w=m;s=14}}while(0);do{if((s|0)==14){m=k+6|0;l=cGb(ca((c[j>>2]|0)+31&-32,w)|0|31)|0;c[b+360>>2]=l;if((l|0)==0){break}c[b>>2]=c[l+4>>2];l=c[b+36>>2]|0;if((l|0)==0){s=16;break}p=cGb(31-(ca(-((c[j>>2]|0)+31&-32)>>(d[m]|0),l)|0)|0)|0;c[b+364>>2]=p;if((p|0)==0){break}c[b+4>>2]=c[p+4>>2];p=c[b+40>>2]|0;if((p|0)==0){s=16;break}l=cGb(31-(ca(-((c[j>>2]|0)+31&-32)>>(d[m]|0),p)|0)|0)|0;c[b+368>>2]=l;if((l|0)==0){break}c[b+8>>2]=c[l+4>>2];l=c[b+44>>2]|0;if((l|0)==0){s=16;break}p=cGb(ca((c[j>>2]|0)+31&-32,l)|0|31)|0;c[b+372>>2]=p;if((p|0)==0){break}c[b+12>>2]=c[p+4>>2];s=16}}while(0);do{if((s|0)==16){if(!((a[k+7|0]&66)==0)){j=b+364|0;fGb(j);p=cGb(1024)|0;c[j>>2]=p;if((p|0)==0){break}c[b+4>>2]=c[p+4>>2]}c[b+64>>2]=b;h=0;return h|0}}while(0);WHb(b);h=-12;return h|0}}while(0);w=b+76|0;if((c[w>>2]|0)<=0){h=-22;return h|0}q=b+352|0;i=b+448|0;do{if((c[q>>2]|0)==0&(c[q+4>>2]|0)==0){if((c[i>>2]|0)>0){break}else{h=-22}return h|0}}while(0);k=RKb(g)|0;g=c[i>>2]|0;if((g|0)==0){p=rGb(c[q>>2]|0,c[q+4>>2]|0)|0;c[i>>2]=p;x=p}else{x=g}g=(k|0)!=0?x:1;k=b+32|0;do{if((c[k>>2]|0)==0){p=SKb(k,x,c[w>>2]|0,c[f>>2]|0,e)|0;if((p|0)<0){h=p}else{break}return h|0}}while(0);e=(g|0)>8;do{if(e){f=b+64|0;c[f>>2]=pJb(g<<2)|0;w=g-8|0;x=pJb(w<<2)|0;p=b+392|0;c[p>>2]=x;if(!((c[f>>2]|0)==0|(x|0)==0)){c[b+396>>2]=w;break}mJb(f);mJb(p);h=-12;return h|0}else{c[b+64>>2]=b}}while(0);p=e?8:g;a:do{if((p|0)>0){e=b+64|0;f=0;while(1){w=cGb(c[k>>2]|0)|0;c[b+360+(f<<2)>>2]=w;if((w|0)==0){break}x=c[w+4>>2]|0;c[b+(f<<2)>>2]=x;c[(c[e>>2]|0)+(f<<2)>>2]=x;f=f+1|0;if((f|0)>=(p|0)){break a}}WHb(b);h=-12;return h|0}}while(0);p=g-8|0;if((p|0)<=0){h=0;return h|0}g=b+392|0;f=b+64|0;e=0;while(1){x=cGb(c[k>>2]|0)|0;c[(c[g>>2]|0)+(e<<2)>>2]=x;x=c[(c[g>>2]|0)+(e<<2)>>2]|0;if((x|0)==0){break}c[(c[f>>2]|0)+(e+8<<2)>>2]=c[x+4>>2];x=e+1|0;if((x|0)<(p|0)){e=x}else{h=0;s=52;break}}if((s|0)==52){return h|0}WHb(b);h=-12;return h|0}function YHb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[a+80>>2]=c[b+80>>2];c[a+68>>2]=c[b+68>>2];c[a+72>>2]=c[b+72>>2];d=b+448|0;c[a+448>>2]=c[d>>2];e=b+352|0;f=c[e+4>>2]|0;g=a+352|0;c[g>>2]=c[e>>2];c[g+4>>2]=f;c[a+76>>2]=c[b+76>>2];f=ZHb(a,b)|0;if((f|0)<0){h=f;return h|0}f=c[b+360>>2]|0;if((f|0)==0){g=XHb(a,32)|0;if((g|0)<0){h=g;return h|0}g=_Hb(a,b)|0;if((g|0)>=0){h=g;return h|0}WHb(a);h=g;return h|0}g=eGb(f)|0;c[a+360>>2]=g;a:do{if((g|0)==0){i=-12}else{f=c[b+364>>2]|0;if((f|0)!=0){e=eGb(f)|0;c[a+364>>2]=e;if((e|0)==0){i=-12;break}}e=c[b+368>>2]|0;if((e|0)!=0){f=eGb(e)|0;c[a+368>>2]=f;if((f|0)==0){i=-12;break}}f=c[b+372>>2]|0;if((f|0)!=0){e=eGb(f)|0;c[a+372>>2]=e;if((e|0)==0){i=-12;break}}e=c[b+376>>2]|0;if((e|0)!=0){f=eGb(e)|0;c[a+376>>2]=f;if((f|0)==0){i=-12;break}}f=c[b+380>>2]|0;if((f|0)!=0){e=eGb(f)|0;c[a+380>>2]=e;if((e|0)==0){i=-12;break}}e=c[b+384>>2]|0;if((e|0)!=0){f=eGb(e)|0;c[a+384>>2]=f;if((f|0)==0){i=-12;break}}f=c[b+388>>2]|0;if((f|0)!=0){e=eGb(f)|0;c[a+388>>2]=e;if((e|0)==0){i=-12;break}}e=b+392|0;b:do{if((c[e>>2]|0)!=0){f=b+396|0;j=pJb(c[f>>2]<<2)|0;k=a+392|0;c[k>>2]=j;if((j|0)==0){i=-12;break a}c[a+396>>2]=c[f>>2];j=0;while(1){if((j|0)>=(c[f>>2]|0)){break b}l=eGb(c[(c[e>>2]|0)+(j<<2)>>2]|0)|0;c[(c[k>>2]|0)+(j<<2)>>2]=l;if((c[(c[k>>2]|0)+(j<<2)>>2]|0)==0){i=-12;break a}else{j=j+1|0}}}}while(0);e=b+64|0;if((c[e>>2]|0)==(b|0)){c[a+64>>2]=a}else{j=c[d>>2]|0;if((j|0)==0){i=-22;break}k=j<<2;j=hJb(k)|0;c[a+64>>2]=j;if((j|0)==0){i=-12;break}nrc(j|0,c[e>>2]|0,k)|0}nrc(a|0,b|0,32)|0;nrc(a+32|0,b+32|0,32)|0;h=0;return h|0}}while(0);WHb(a);h=i;return h|0}function ZHb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+8|0;e=d|0;c[a+84>>2]=c[b+84>>2];c[a+88>>2]=c[b+88>>2];f=b+124|0;g=a+124|0;h=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;h=b+136|0;g=c[h+4>>2]|0;f=a+136|0;c[f>>2]=c[h>>2];c[f+4>>2]=g;c[a+292>>2]=c[b+292>>2];c[a+296>>2]=c[b+296>>2];c[a+300>>2]=c[b+300>>2];c[a+304>>2]=c[b+304>>2];c[a+344>>2]=c[b+344>>2];c[a+216>>2]=c[b+216>>2];c[a+288>>2]=c[b+288>>2];g=b+144|0;f=c[g+4>>2]|0;h=a+144|0;c[h>>2]=c[g>>2];c[h+4>>2]=f;f=b+152|0;h=c[f+4>>2]|0;g=a+152|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;h=b+424|0;g=c[h+4>>2]|0;f=a+424|0;c[f>>2]=c[h>>2];c[f+4>>2]=g;c[a+452>>2]=c[b+452>>2];g=b+432|0;f=c[g+4>>2]|0;h=a+432|0;c[h>>2]=c[g>>2];c[h+4>>2]=f;f=b+320|0;h=c[f+4>>2]|0;g=a+320|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;c[a+168>>2]=c[b+168>>2];h=b+416|0;g=c[h+4>>2]|0;f=a+416|0;c[f>>2]=c[h>>2];c[f+4>>2]=g;c[a+160>>2]=c[b+160>>2];c[a+164>>2]=c[b+164>>2];c[a+408>>2]=c[b+408>>2];c[a+444>>2]=c[b+444>>2];c[a+456>>2]=c[b+456>>2];c[a+460>>2]=c[b+460>>2];PGb(a+440|0,c[b+440>>2]|0,0);nrc(a+224|0,b+224|0,64)|0;g=b+404|0;a:do{if((c[g>>2]|0)>0){f=b+400|0;h=e;j=a+404|0;k=a+400|0;l=0;while(1){m=c[(c[f>>2]|0)+(l<<2)>>2]|0;n=c[m>>2]|0;o=m+8|0;p=c[o>>2]|0;q=c[j>>2]|0;if(q>>>0>536870910>>>0){r=q;break}s=iJb(c[k>>2]|0,(q<<2)+4|0)|0;if((s|0)==0){t=9;break}c[k>>2]=s;s=pJb(16)|0;q=s;c[e>>2]=q;if((s|0)==0){t=9;break}u=hJb(p)|0;c[s+4>>2]=u;if((u|0)==0){t=7;break}c[s+8>>2]=p;c[s>>2]=n;n=c[j>>2]|0;c[j>>2]=n+1;c[(c[k>>2]|0)+(n<<2)>>2]=q;q=c[e>>2]|0;if((q|0)==0){t=9;break}nrc(c[q+4>>2]|0,c[m+4>>2]|0,c[o>>2]|0)|0;PGb(q+12|0,c[m+12>>2]|0,0);l=l+1|0;if((l|0)>=(c[g>>2]|0)){break a}}if((t|0)==7){mJb(h);t=9}if((t|0)==9){r=c[j>>2]|0}if((r|0)>0){l=0;do{mJb((c[(c[k>>2]|0)+(l<<2)>>2]|0)+4|0);mJb((c[k>>2]|0)+(l<<2)|0);OGb((c[(c[k>>2]|0)+(l<<2)>>2]|0)+12|0);l=l+1|0;}while((l|0)<(c[j>>2]|0))}mJb(k);v=-12;i=d;return v|0}}while(0);r=a+176|0;c[r>>2]=0;t=a+180|0;c[t>>2]=0;g=a+184|0;c[g>>2]=0;e=c[b+464>>2]|0;if((e|0)==0){v=0;i=d;return v|0}j=eGb(e)|0;c[a+464>>2]=j;if((j|0)==0){v=0;i=d;return v|0}c[r>>2]=c[j+4>>2];c[t>>2]=c[b+180>>2];c[g>>2]=c[b+184>>2];v=0;i=d;return v|0}function _Hb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+16|0;e=d|0;f=a+80|0;g=c[f>>2]|0;if((g|0)!=(c[b+80>>2]|0)|(g|0)<0){h=-22;i=d;return h|0}j=a+68|0;k=c[j>>2]|0;do{if((k|0)>0){l=a+72|0;m=c[l>>2]|0;if((m|0)<=0){break}n=e;if((k|0)!=(c[b+68>>2]|0)){h=-22;i=d;return h|0}if((m|0)!=(c[b+72>>2]|0)){h=-22;i=d;return h|0}m=uKb(g)|0;o=0;while(1){if((o|0)>=(m|0)){p=10;break}if((c[a+(o<<2)>>2]|0)==0){h=-22;p=21;break}if((c[b+(o<<2)>>2]|0)==0){h=-22;p=21;break}else{o=o+1|0}}if((p|0)==10){o=b;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];c[n+8>>2]=c[o+8>>2];c[n+12>>2]=c[o+12>>2];vIb(a|0,a+32|0,e|0,b+32|0,c[f>>2]|0,c[j>>2]|0,c[l>>2]|0);h=0;i=d;return h|0}else if((p|0)==21){i=d;return h|0}}}while(0);j=a+76|0;if((c[j>>2]|0)<=0){h=-22;i=d;return h|0}e=a+352|0;if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){h=-22;i=d;return h|0}k=RKb(g)|0;g=c[a+448>>2]|0;o=(k|0)!=0?g:1;k=c[j>>2]|0;if((k|0)!=(c[b+76>>2]|0)){h=-22;i=d;return h|0}if((g|0)!=(c[b+448>>2]|0)){h=-22;i=d;return h|0}j=b+352|0;if(!((c[e>>2]|0)==(c[j>>2]|0)&(c[e+4>>2]|0)==(c[j+4>>2]|0))){h=-22;i=d;return h|0}j=c[a+64>>2]|0;a=b+64|0;b=0;while(1){if((b|0)>=(o|0)){p=20;break}if((c[j+(b<<2)>>2]|0)==0){h=-22;p=21;break}if((c[(c[a>>2]|0)+(b<<2)>>2]|0)==0){h=-22;p=21;break}else{b=b+1|0}}if((p|0)==20){XKb(j,c[a>>2]|0,0,0,k,g,c[f>>2]|0)|0;h=0;i=d;return h|0}else if((p|0)==21){i=d;return h|0}return 0}function $Hb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;e=pJb(472)|0;if((e|0)==0){c[d>>2]=0;f=0;i=b;return f|0}g=e;h=e+64|0;j=h;c[j>>2]=0;mJb(h);mrc(e|0,0,472)|0;h=e+144|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=e+152|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=e+136|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=e+416|0;c[h>>2]=0;c[h+4>>2]=-2147483648;h=e+432|0;c[h>>2]=0;c[h+4>>2]=0;h=e+424|0;c[h>>2]=-1;c[h+4>>2]=-1;c[e+452>>2]=-1;c[e+84>>2]=1;c[e+124>>2]=0;c[e+128>>2]=1;c[e+80>>2]=-1;c[e+456>>2]=2;c[j>>2]=e;c[d>>2]=g;if((YHb(g,a)|0)>=0){f=g;i=b;return f|0}WHb(g);mJb(d);f=c[d>>2]|0;i=b;return f|0}function aIb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=b;nrc(a|0,d|0,472)|0;e=b+64|0;f=b|0;if((c[e>>2]|0)==(f|0)){c[a+64>>2]=a;mrc(d|0,0,472)|0}else{mrc(d|0,0,472)|0}mJb(e);mrc(d|0,0,472)|0;d=b+144|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=b+152|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=b+136|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=b+416|0;c[d>>2]=0;c[d+4>>2]=-2147483648;d=b+432|0;c[d>>2]=0;c[d+4>>2]=0;d=b+424|0;c[d>>2]=-1;c[d+4>>2]=-1;c[b+452>>2]=-1;c[b+84>>2]=1;c[b+124>>2]=0;c[b+128>>2]=1;c[b+80>>2]=-1;c[b+456>>2]=2;c[e>>2]=f;return}function bIb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+360>>2]|0;if((b|0)==0){d=0;return d|0}e=(gGb(b)|0)!=0;b=c[a+364>>2]|0;if((b|0)==0){f=e}else{f=(gGb(b)|0)!=0&e}e=c[a+368>>2]|0;if((e|0)==0){g=f}else{g=(gGb(e)|0)!=0&f}f=c[a+372>>2]|0;if((f|0)==0){h=g}else{h=(gGb(f)|0)!=0&g}g=c[a+376>>2]|0;if((g|0)==0){i=h}else{i=(gGb(g)|0)!=0&h}h=c[a+380>>2]|0;if((h|0)==0){j=i}else{j=(gGb(h)|0)!=0&i}i=c[a+384>>2]|0;if((i|0)==0){k=j}else{k=(gGb(i)|0)!=0&j}j=c[a+388>>2]|0;if((j|0)==0){l=k}else{l=(gGb(j)|0)!=0&k}k=l&1;l=a+396|0;if((c[l>>2]|0)<=0){d=k;return d|0}j=a+392|0;a=0;i=k;while(1){k=(gGb(c[(c[j>>2]|0)+(a<<2)>>2]|0)|0)!=0&i;h=a+1|0;if((h|0)<(c[l>>2]|0)){a=h;i=k}else{d=k;break}}return d|0}function cIb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+472|0;d=b|0;if((c[a+360>>2]|0)==0){e=-22;i=b;return e|0}if((bIb(a)|0)!=0){e=0;i=b;return e|0}f=d;mrc(f|0,0,472)|0;c[d+80>>2]=c[a+80>>2];c[d+68>>2]=c[a+68>>2];c[d+72>>2]=c[a+72>>2];c[d+448>>2]=c[a+448>>2];g=a+352|0;h=c[g+4>>2]|0;j=d+352|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;c[d+76>>2]=c[a+76>>2];h=XHb(d,32)|0;if((h|0)<0){e=h;i=b;return e|0}h=_Hb(d,a)|0;if((h|0)<0){WHb(d);e=h;i=b;return e|0}h=ZHb(d,a)|0;if((h|0)<0){WHb(d);e=h;i=b;return e|0}WHb(a);nrc(a|0,f|0,472)|0;if((d|0)!=(c[d+64>>2]|0)){e=0;i=b;return e|0}c[a+64>>2]=a;e=0;i=b;return e|0}function dIb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=a+404|0;h=c[g>>2]|0;if(h>>>0>536870910>>>0){j=0;i=e;return j|0}k=a+400|0;a=iJb(c[k>>2]|0,(h<<2)+4|0)|0;if((a|0)==0){j=0;i=e;return j|0}c[k>>2]=a;a=pJb(16)|0;h=a;c[f>>2]=h;if((a|0)==0){j=0;i=e;return j|0}l=hJb(d)|0;c[a+4>>2]=l;if((l|0)==0){mJb(f);j=0;i=e;return j|0}else{c[a+8>>2]=d;c[a>>2]=b;b=c[g>>2]|0;c[g>>2]=b+1;c[(c[k>>2]|0)+(b<<2)>>2]=h;j=c[f>>2]|0;i=e;return j|0}return 0}function eIb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;do{if((c[a+76>>2]|0)==0){d=4}else{e=c[a+448>>2]|0;if((e|0)==0){f=0;return f|0}else{g=(RKb(c[a+80>>2]|0)|0)!=0;d=g?e:1;break}}}while(0);if(!((b|0)>-1&(d|0)>(b|0))){f=0;return f|0}d=c[(c[a+64>>2]|0)+(b<<2)>>2]|0;if((d|0)==0){f=0;return f|0}b=c[a+360>>2]|0;do{if((b|0)!=0){e=c[b+4>>2]|0;do{if(!(d>>>0<e>>>0)){if(d>>>0<(e+(c[b+8>>2]|0)|0)>>>0){f=b}else{break}return f|0}}while(0);e=c[a+364>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+368>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+372>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+376>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+380>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+384>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;do{if(!(d>>>0<g>>>0)){if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);e=c[a+388>>2]|0;if((e|0)==0){break}g=c[e+4>>2]|0;if(d>>>0<g>>>0){break}if(d>>>0<(g+(c[e+8>>2]|0)|0)>>>0){f=e}else{break}return f|0}}while(0);b=c[a+396>>2]|0;if((b|0)<=0){f=0;return f|0}e=c[a+392>>2]|0;a=0;while(1){g=c[e+(a<<2)>>2]|0;h=c[g+4>>2]|0;if(!(d>>>0<h>>>0)){if(d>>>0<(h+(c[g+8>>2]|0)|0)>>>0){f=g;i=15;break}}g=a+1|0;if((g|0)<(b|0)){a=g}else{f=0;i=15;break}}if((i|0)==15){return f|0}return 0}function fIb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+400|0;e=c[a+404>>2]|0;a=0;while(1){if((a|0)>=(e|0)){f=0;g=4;break}h=c[(c[d>>2]|0)+(a<<2)>>2]|0;if((c[h>>2]|0)==(b|0)){f=h;g=4;break}else{a=a+1|0}}if((g|0)==4){return f|0}return 0}function gIb(a){a=a|0;return c[1142344+(c[a+4>>2]<<3)>>2]|0}function hIb(a){a=a|0;return c[1142348+(c[a+4>>2]<<3)>>2]|0}function iIb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;c[a>>2]=0;d=0;while(1){if((d|0)>=15){e=-22;f=18;break}if((IFb(b,c[1142344+(d<<3)>>2]|0)|0)==0){break}else{d=d+1|0}}if((f|0)==18){return e|0}if((d|0)>14){e=-22;return e|0}b=pJb(16)|0;g=b;if((b|0)==0){e=-12;return e|0}c[b+4>>2]=d;switch(d|0){case 1:{h=yJb()|0;c[b>>2]=h;i=h;f=15;break};case 6:case 7:case 8:{c[b>>2]=YKb()|0;f=13;break};case 2:case 3:case 4:case 5:{c[b>>2]=FKb()|0;f=13;break};case 13:{c[b+8>>2]=DGb(4)|0;break};case 9:case 10:case 11:case 12:{c[b>>2]=cLb()|0;f=13;break};case 0:{h=aJb()|0;c[b>>2]=h;i=h;f=15;break};default:{f=13}}do{if((f|0)==13){if(!((d-13|0)>>>0>1>>>0)){break}i=c[b>>2]|0;f=15}}while(0);do{if((f|0)==15){if((i|0)!=0){break}kJb(b);e=-12;return e|0}}while(0);c[a>>2]=g;e=0;return e|0}function jIb(a){a=a|0;switch(c[a+4>>2]|0){case 7:{ZKb(c[a>>2]|0,224)|0;return};case 14:{c[a+12>>2]=1;return};case 12:{dLb(c[a>>2]|0,512)|0;return};case 10:{dLb(c[a>>2]|0,256)|0;return};case 11:{dLb(c[a>>2]|0,384)|0;return};case 0:{bJb(c[a>>2]|0);return};case 4:{GKb(c[a>>2]|0,256)|0;return};case 8:{ZKb(c[a>>2]|0,256)|0;return};case 1:{zJb(c[a>>2]|0);return};case 3:{GKb(c[a>>2]|0,160)|0;return};case 9:{dLb(c[a>>2]|0,224)|0;return};case 5:{GKb(c[a>>2]|0,320)|0;return};case 13:{c[a+12>>2]=-1;return};case 2:{GKb(c[a>>2]|0,128)|0;return};case 6:{ZKb(c[a>>2]|0,160)|0;return};default:{return}}}function kIb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;switch(c[a+4>>2]|0){case 0:{cJb(c[a>>2]|0,b,d);return};case 2:case 3:case 4:case 5:{JKb(c[a>>2]|0,b,d);return};case 9:case 10:case 11:case 12:{eLb(c[a>>2]|0,b,d);return};case 6:case 7:case 8:{aLb(c[a>>2]|0,b,d);return};case 14:{e=a+12|0;c[e>>2]=oFb(c[e>>2]|0,b,d)|0;return};case 13:{e=a+12|0;c[e>>2]=EGb(c[a+8>>2]|0,c[e>>2]|0,b,d)|0;return};case 1:{AJb(c[a>>2]|0,b,d);return};default:{return}}}function lIb(b,d){b=b|0;d=d|0;var e=0;switch(c[b+4>>2]|0){case 1:{BJb(c[b>>2]|0,d);return};case 9:case 10:case 11:case 12:{gLb(c[b>>2]|0,d);return};case 2:case 3:case 4:case 5:{KKb(c[b>>2]|0,d);return};case 14:{e=d;y=je(c[b+12>>2]|0)|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;return};case 6:case 7:case 8:{bLb(c[b>>2]|0,d);return};case 13:{e=d;y=je(~c[b+12>>2]|0)|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;return};case 0:{eJb(c[b>>2]|0,d);return};default:{return}}}function mIb(a){a=a|0;var b=0;b=c[a>>2]|0;if((b|0)!=0){mJb(b)}mJb(a);return}function nIb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;mrc(a|0,0,16)|0;if((d|0)==0){f=b[e+8>>1]|0;g=((f&65535)>>>2&7)+1|0;h=a+((f&3)<<2)|0;if((g|0)>(c[h>>2]|0)){c[h>>2]=g}g=b[e+10>>1]|0;h=((g&65535)>>>2&7)+1|0;f=a+((g&3)<<2)|0;if((h|0)>(c[f>>2]|0)){c[f>>2]=h}h=b[e+12>>1]|0;f=((h&65535)>>>2&7)+1|0;g=a+((h&3)<<2)|0;if((f|0)>(c[g>>2]|0)){c[g>>2]=f}f=b[e+14>>1]|0;g=((f&65535)>>>2&7)+1|0;h=a+((f&3)<<2)|0;if((g|0)<=(c[h>>2]|0)){return}c[h>>2]=g;return}else{mrc(d|0,0,16)|0;g=e+8|0;h=b[g>>1]|0;f=((h&65535)>>>2&7)+1|0;i=a+((h&3)<<2)|0;if((f|0)>(c[i>>2]|0)){c[i>>2]=f;c[d+((b[g>>1]&3)<<2)>>2]=0}g=e+10|0;f=b[g>>1]|0;i=((f&65535)>>>2&7)+1|0;h=a+((f&3)<<2)|0;if((i|0)>(c[h>>2]|0)){c[h>>2]=i;c[d+((b[g>>1]&3)<<2)>>2]=1}g=e+12|0;i=b[g>>1]|0;h=((i&65535)>>>2&7)+1|0;f=a+((i&3)<<2)|0;if((h|0)>(c[f>>2]|0)){c[f>>2]=h;c[d+((b[g>>1]&3)<<2)>>2]=2}g=e+14|0;e=b[g>>1]|0;h=((e&65535)>>>2&7)+1|0;f=a+((e&3)<<2)|0;if((h|0)<=(c[f>>2]|0)){return}c[f>>2]=h;c[d+((b[g>>1]&3)<<2)>>2]=3;return}}function oIb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=qKb(b)|0;if(b>>>0>332>>>0){l=-22;i=g;return l|0}b=k+7|0;if(!((a[b]&8)==0)){l=-22;i=g;return l|0}nIb(h|0,j|0,k);m=c[h+(f<<2)>>2]|0;if((k|0)==0|(e|0)<0){l=-22;i=g;return l|0}if(((c[j+(f<<2)>>2]|0)-1|0)>>>0<2>>>0){n=d[k+5|0]|0}else{n=0}k=e-1+(1<<n)>>n;do{if((k|0)!=0){if((2147483647/(k|0)|0|0)<(m|0)){l=-22}else{break}i=g;return l|0}}while(0);n=ca(k,m)|0;if((a[b]&4)==0){l=n;i=g;return l|0}l=n+7>>3;i=g;return l|0}function pIb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=qKb(e)|0;mrc(b|0,0,16)|0;if((k|0)==0){l=-22;i=g;return l|0}e=k+7|0;if(!((a[e]&8)==0)){l=-22;i=g;return l|0}m=h|0;n=j|0;nIb(m,n,k);o=k+5|0;k=f-1|0;if((f|0)<0){l=-22;i=g;return l|0}f=c[m>>2]|0;if(((c[n>>2]|0)-1|0)>>>0<2>>>0){p=d[o]|0}else{p=0}n=k+(1<<p)>>p;do{if((n|0)!=0){if((2147483647/(n|0)|0|0)<(f|0)){l=-22}else{break}i=g;return l|0}}while(0);p=ca(n,f)|0;if((a[e]&4)==0){q=p}else{q=p+7>>3}if((q|0)<0){l=q;i=g;return l|0}c[b>>2]=q;q=c[h+4>>2]|0;if(((c[j+4>>2]|0)-1|0)>>>0<2>>>0){r=d[o]|0}else{r=0}p=k+(1<<r)>>r;do{if((p|0)!=0){if((2147483647/(p|0)|0|0)<(q|0)){l=-22}else{break}i=g;return l|0}}while(0);r=ca(p,q)|0;if((a[e]&4)==0){s=r}else{s=r+7>>3}if((s|0)<0){l=s;i=g;return l|0}c[b+4>>2]=s;s=c[h+8>>2]|0;if(((c[j+8>>2]|0)-1|0)>>>0<2>>>0){t=d[o]|0}else{t=0}r=k+(1<<t)>>t;do{if((r|0)!=0){if((2147483647/(r|0)|0|0)<(s|0)){l=-22}else{break}i=g;return l|0}}while(0);t=ca(r,s)|0;if((a[e]&4)==0){u=t}else{u=t+7>>3}if((u|0)<0){l=u;i=g;return l|0}c[b+8>>2]=u;u=c[h+12>>2]|0;if(((c[j+12>>2]|0)-1|0)>>>0<2>>>0){v=d[o]|0}else{v=0}o=k+(1<<v)>>v;do{if((o|0)!=0){if((2147483647/(o|0)|0|0)<(u|0)){l=-22}else{break}i=g;return l|0}}while(0);v=ca(o,u)|0;if((a[e]&4)==0){w=v}else{w=v+7>>3}if((w|0)<0){l=w;i=g;return l|0}c[b+12>>2]=w;l=0;i=g;return l|0}function qIb(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=i;i=i+16|0;l=k|0;mrc(l|0,0,16)|0;m=qKb(f)|0;mrc(e|0,0,16)|0;if((m|0)==0){n=-22;i=k;return n|0}f=m+7|0;if(!((a[f]&8)==0)){n=-22;i=k;return n|0}c[e>>2]=h;o=c[j>>2]|0;if((o|0)>(2147482623/(g|0)|0|0)){n=-22;i=k;return n|0}p=ca(o,g)|0;if(!((a[f]&66)==0)){f=p+3&-4;c[e+4>>2]=h+f;n=f+1024|0;i=k;return n|0}c[l+((b[m+8>>1]&3)<<2)>>2]=1;c[l+((b[m+10>>1]&3)<<2)>>2]=1;c[l+((b[m+12>>1]&3)<<2)>>2]=1;c[l+((b[m+14>>1]&3)<<2)>>2]=1;f=g-1|0;o=m+6|0;if((c[l+4>>2]|0)==0){n=p;i=k;return n|0}m=d[o]|0;c[e+4>>2]=h+p;q=f+(1<<m)>>m;m=c[j+4>>2]|0;if((m|0)>(2147483647/(q|0)|0|0)){n=-22;i=k;return n|0}r=ca(q,m)|0;if((p|0)>(2147483647-r|0)){n=-22;i=k;return n|0}m=r+p|0;if((c[l+8>>2]|0)==0){n=m;i=k;return n|0}q=d[o]|0;o=p+r|0;c[e+8>>2]=h+o;r=f+(1<<q)>>q;q=c[j+8>>2]|0;if((q|0)>(2147483647/(r|0)|0|0)){n=-22;i=k;return n|0}f=ca(r,q)|0;if((m|0)>(2147483647-f|0)){n=-22;i=k;return n|0}q=f+m|0;if((c[l+12>>2]|0)==0){n=q;i=k;return n|0}c[e+12>>2]=h+(o+f);f=c[j+12>>2]|0;if((f|0)>(2147483647/(g|0)|0|0)){n=-22;i=k;return n|0}else{n=ca(f,g)|0;i=k;return((q|0)>(2147483647-n|0)?-22:n+q|0)|0}return 0}function rIb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==22){d=0;while(1){c[a+(d<<2)>>2]=(ca(d>>5,2359296)|0)-16777216|((d>>>2&7)*9216|0)|((d&3)*85|0);e=d+1|0;if((e|0)<256){d=e}else{f=0;break}}return f|0}else{g=0}while(1){if((b|0)==21){h=(g>>3)*255|0;i=(g>>>1&3)*85|0;j=-(g&1)&255}else if((b|0)==8){h=g;i=g;j=g}else if((b|0)==19){h=(g>>6)*85|0;i=(g>>>3&7)*36|0;j=(g&7)*36|0}else if((b|0)==24){h=-(g&1)&255;i=(g>>>1&3)*85|0;j=(g>>3)*255|0}else{f=-22;k=8;break}c[a+(g<<2)>>2]=(j<<16)-16777216+(i<<8)+h;d=g+1|0;if((d|0)<256){g=d}else{f=0;k=8;break}}if((k|0)==8){return f|0}return 0}function sIb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+16|0;k=j|0;l=qKb(g)|0;if((l|0)==0){m=-22;i=j;return m|0}n=k;c[k>>2]=1072448;c[k+4>>2]=0;c[k+8>>2]=0;do{if((e|0)>0&(f|0)>0){k=Erc(f+128|0,0,e+128|0,0)|0;o=G;p=0;if(!(o>>>0<p>>>0|o>>>0==p>>>0&k>>>0<268435455>>>0)){break}if((h|0)>7){q=e+7&-8}else{q=e}k=pIb(d,g,q)|0;if((k|0)<0){m=k;i=j;return m|0}k=h-1|0;p=-h|0;c[d>>2]=k+(c[d>>2]|0)&p;o=d+4|0;c[o>>2]=k+(c[o>>2]|0)&p;o=d+8|0;c[o>>2]=k+(c[o>>2]|0)&p;o=d+12|0;c[o>>2]=k+(c[o>>2]|0)&p;p=qIb(b,g,f,0,d)|0;if((p|0)<0){m=p;i=j;return m|0}o=hJb(p+h|0)|0;if((o|0)==0){m=-12;i=j;return m|0}p=qIb(b,g,f,o,d)|0;if((p|0)<0){kJb(o);m=p;i=j;return m|0}if((a[l+7|0]&66)==0){m=p;i=j;return m|0}o=c[b+4>>2]|0;if((g|0)==22){k=0;while(1){c[o+(k<<2)>>2]=(k>>>2&7)*9216|0|((k&3)*85|0)|(ca(k>>5,2359296)|0)-16777216;r=k+1|0;if((r|0)<256){k=r}else{m=p;break}}i=j;return m|0}else{s=0}while(1){if((g|0)==19){t=(s>>6)*85|0;u=(s>>>3&7)*36|0;v=(s&7)*36|0}else if((g|0)==24){t=-(s&1)&255;u=(s>>>1&3)*85|0;v=(s>>3)*255|0}else if((g|0)==8){t=s;u=s;v=s}else if((g|0)==21){t=(s>>3)*255|0;u=(s>>>1&3)*85|0;v=-(s&1)&255}else{m=p;w=20;break}c[o+(s<<2)>>2]=(v<<16)-16777216+(u<<8)+t;k=s+1|0;if((k|0)<256){s=k}else{m=p;w=20;break}}if((w|0)==20){i=j;return m|0}}}while(0);KIb(n,16,2412240,(n=i,i=i+16|0,c[n>>2]=e,c[n+8>>2]=f,n)|0);i=n;m=-22;i=j;return m|0}function tIb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f|0;c[g>>2]=1072448;c[g+4>>2]=d;c[g+8>>2]=e;do{if((a|0)>0&(b|0)>0){e=Erc(b+128|0,0,a+128|0,0)|0;d=G;h=0;if(d>>>0<h>>>0|d>>>0==h>>>0&e>>>0<268435455>>>0){j=0}else{break}i=f;return j|0}}while(0);KIb(g,16,2412240,(g=i,i=i+16|0,c[g>>2]=a,c[g+8>>2]=b,g)|0);i=g;j=-22;i=f;return j|0}function uIb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;if((a|0)==0|(d|0)==0){i=h;return}if((((e|0)>-1?e:-e|0)|0)<(f|0)){KIb(0,0,2578472,(j=i,i=i+24|0,c[j>>2]=2435792,c[j+8>>2]=2349328,c[j+16>>2]=248,j)|0);i=j;Hd()}if((((b|0)>-1?b:-b|0)|0)<(f|0)){KIb(0,0,2578472,(j=i,i=i+24|0,c[j>>2]=2287632,c[j+8>>2]=2349328,c[j+16>>2]=249,j)|0);i=j;Hd()}if((g|0)>0){k=d;l=a;m=g}else{i=h;return}while(1){nrc(l|0,k|0,f)|0;g=m-1|0;if((g|0)>0){k=k+e|0;l=l+b|0;m=g}else{break}}i=h;return}function vIb(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;m=i;i=i+32|0;n=m|0;o=m+16|0;p=qKb(j)|0;if((p|0)==0){i=m;return}q=d[p+7|0]|0;if((q&8|0)!=0){i=m;return}if((q&66|0)!=0){q=c[e>>2]|0;r=c[f>>2]|0;s=c[g>>2]|0;t=c[h>>2]|0;do{if(!((q|0)==0|(s|0)==0)){if((((t|0)>-1?t:-t|0)|0)<(k|0)){KIb(0,0,2578472,(u=i,i=i+24|0,c[u>>2]=2435792,c[u+8>>2]=2349328,c[u+16>>2]=248,u)|0);i=u;Hd()}if((((r|0)>-1?r:-r|0)|0)<(k|0)){KIb(0,0,2578472,(u=i,i=i+24|0,c[u>>2]=2287632,c[u+8>>2]=2349328,c[u+16>>2]=249,u)|0);i=u;Hd()}if((l|0)>0){v=s;w=q;x=l}else{break}while(1){nrc(w|0,v|0,k)|0;y=x-1|0;if((y|0)>0){v=v+t|0;w=w+r|0;x=y}else{break}}}}while(0);nrc(c[e+4>>2]|0,c[g+4>>2]|0,1024)|0;i=m;return}x=a[p+4|0]|0;if(x<<24>>24==0){i=m;return}r=x&255;x=0;w=0;do{t=(b[p+8+(w<<1)>>1]&3)+1|0;x=(x|0)>(t|0)?x:t;w=w+1|0;}while((w|0)<(r|0));if((x|0)<=0){i=m;return}r=j>>>0>332>>>0;w=n|0;t=o|0;v=(k|0)<0;q=k-1|0;k=-l|0;s=p+6|0;p=0;a:while(1){y=qKb(j)|0;if(r){z=27;break}A=y+7|0;if(!((a[A]&8)==0)){z=27;break}nIb(w,t,y);B=c[n+(p<<2)>>2]|0;if((y|0)==0|v){z=27;break}if(((c[o+(p<<2)>>2]|0)-1|0)>>>0<2>>>0){C=d[y+5|0]|0}else{C=0}y=q+(1<<C)>>C;if((y|0)!=0){if((2147483647/(y|0)|0|0)<(B|0)){z=27;break}}D=ca(y,B)|0;if((a[A]&4)==0){E=D}else{E=D+7>>3}if((E|0)<0){z=27;break}if((p-1|0)>>>0<2>>>0){F=-(k>>(d[s]|0))|0}else{F=l}D=c[e+(p<<2)>>2]|0;A=c[f+(p<<2)>>2]|0;B=c[g+(p<<2)>>2]|0;y=c[h+(p<<2)>>2]|0;do{if(!((D|0)==0|(B|0)==0)){if((((y|0)>-1?y:-y|0)|0)<(E|0)){z=32;break a}if((((A|0)>-1?A:-A|0)|0)<(E|0)){z=35;break a}if((F|0)>0){G=B;H=D;I=F}else{break}while(1){nrc(H|0,G|0,E)|0;J=I-1|0;if((J|0)>0){G=G+y|0;H=H+A|0;I=J}else{break}}}}while(0);A=p+1|0;if((A|0)<(x|0)){p=A}else{z=38;break}}if((z|0)==27){KIb(0,16,2237808,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;i=m;return}else if((z|0)==32){KIb(0,0,2578472,(u=i,i=i+24|0,c[u>>2]=2435792,c[u+8>>2]=2349328,c[u+16>>2]=248,u)|0);i=u;Hd()}else if((z|0)==35){KIb(0,0,2578472,(u=i,i=i+24|0,c[u>>2]=2287632,c[u+8>>2]=2349328,c[u+16>>2]=249,u)|0);i=u;Hd()}else if((z|0)==38){i=m;return}}function wIb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;i=i+16|0;k=j|0;l=k;c[k>>2]=1072448;c[k+4>>2]=0;c[k+8>>2]=0;do{if((f|0)>0&(g|0)>0){k=Erc(g+128|0,0,f+128|0,0)|0;m=G;n=0;if(!(m>>>0<n>>>0|m>>>0==n>>>0&k>>>0<268435455>>>0)){break}k=pIb(b,e,f)|0;if((k|0)<0){o=k;i=j;return o|0}k=h-1|0;n=-h|0;c[b>>2]=k+(c[b>>2]|0)&n;m=b+4|0;c[m>>2]=k+(c[m>>2]|0)&n;m=b+8|0;c[m>>2]=k+(c[m>>2]|0)&n;m=b+12|0;c[m>>2]=k+(c[m>>2]|0)&n;n=qIb(a,e,f,0,b)|0;if((n|0)<0){o=n;i=j;return o|0}o=qIb(a,e,g,d,b)|0;i=j;return o|0}}while(0);KIb(l,16,2412240,(l=i,i=i+16|0,c[l>>2]=f,c[l+8>>2]=g,l)|0);i=l;o=-22;i=j;return o|0}function xIb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+48|0;h=g|0;j=g+16|0;k=g+32|0;l=qKb(b)|0;if((l|0)==0){m=-22;i=g;return m|0}n=h;c[h>>2]=1072448;c[h+4>>2]=0;c[h+8>>2]=0;do{if((d|0)>0&(e|0)>0){h=Erc(e+128|0,0,d+128|0,0)|0;o=G;p=0;if(!(o>>>0<p>>>0|o>>>0==p>>>0&h>>>0<268435455>>>0)){break}if((a[l+7|0]&64)==0){m=wIb(j|0,k|0,0,b,d,e,f)|0;i=g;return m|0}else{m=ca(e,d)|0;i=g;return m|0}}}while(0);KIb(n,16,2412240,(n=i,i=i+16|0,c[n>>2]=d,c[n+8>>2]=e,n)|0);i=n;m=-22;i=g;return m|0}function yIb(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;n=i;i=i+64|0;o=n|0;p=n+16|0;q=n+32|0;r=n+48|0;s=qKb(j)|0;t=qKb(j)|0;a:do{if((t|0)==0){u=-22}else{v=o;c[o>>2]=1072448;c[o+4>>2]=0;c[o+8>>2]=0;do{if((k|0)>0&(l|0)>0){w=Erc(l+128|0,0,k+128|0,0)|0;x=G;y=0;if(!(x>>>0<y>>>0|x>>>0==y>>>0&w>>>0<268435455>>>0)){break}if((a[t+7|0]&64)==0){u=wIb(p|0,q|0,0,j,k,l,m)|0;break a}else{u=ca(l,k)|0;break a}}}while(0);KIb(v,16,2412240,(w=i,i=i+16|0,c[w>>2]=k,c[w+8>>2]=l,w)|0);i=w;u=-22}}while(0);if((u|0)>(f|0)|(u|0)<0){z=-22;i=n;return z|0}f=a[s+4|0]|0;if(f<<24>>24==0){pIb(r|0,j,k)|0;A=1;B=14}else{q=f&255;f=0;p=0;do{t=b[s+8+(p<<1)>>1]&3;f=(t|0)>(f|0)?t:f;p=p+1|0;}while((p|0)<(q|0));q=f+1|0;pIb(r|0,j,k)|0;if((q|0)>0){A=q;B=14}else{C=e}}if((B|0)==14){B=s+6|0;q=l-1|0;l=m-1|0;k=-m|0;m=0;j=e;while(1){if((m-1|0)>>>0<2>>>0){D=d[B]|0}else{D=0}e=q+(1<<D)>>D;if((e|0)>0){f=r+(m<<2)|0;p=h+(m<<2)|0;t=0;o=j;w=c[g+(m<<2)>>2]|0;y=c[f>>2]|0;while(1){nrc(o|0,w|0,y)|0;x=c[f>>2]|0;E=o+(l+x&k)|0;F=t+1|0;if((F|0)<(e|0)){t=F;o=E;w=w+(c[p>>2]|0)|0;y=x}else{H=E;break}}}else{H=j}y=m+1|0;if((y|0)<(A|0)){m=y;j=H}else{C=H;break}}}if((a[s+7|0]&2)==0){z=u;i=n;return z|0}s=C+3&-4;C=g+4|0;g=0;while(1){H=(c[C>>2]|0)+(g<<2)|0;c[s+(g<<2)>>2]=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24;H=g+1|0;if((H|0)<256){g=H}else{z=u;break}}i=n;return z|0}function zIb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a&1|0)!=0){b=0;return b|0}c=(a&65535|0)==0;d=c?a>>16:a;a=c?17:1;if((d&255|0)==0){e=a|8;f=d>>8}else{e=a;f=d}if((f&15|0)==0){g=e+4|0;h=f>>4}else{g=e;h=f}if((h&3|0)==0){i=g+2|0;j=h>>2}else{i=g;j=h}b=i-(j&1)|0;return b|0}function AIb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;mrc(h|0,0,16)|0;j=f+4|0;k=j;l=f+8|0;m=f+12|0;f=8;do{c[g>>2]=d;a[k]=f;fJb(h,h,16);c[b+(f<<2)>>2]=c[g>>2];c[b+((f|1)<<2)>>2]=c[j>>2];c[b+((f|2)<<2)>>2]=c[l>>2];c[b+((f|3)<<2)>>2]=c[m>>2];f=f+4|0;}while((f|0)<64);c[b+256>>2]=0;i=e;return}function BIb(a,b,d){a=a|0;b=+b;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0.0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0.0;e=a+296|0;f=a|0;g=c[a+18816>>2]|0;i=(g|0)>0;do{if(i){j=0;while(1){k=j+1|0;l=a+(k*288|0)+(j<<3)|0;if((j|0)>0){m=j;while(1){n=m+1|0;o=+h[e+(j*288|0)+(m<<3)>>3];p=j;do{p=p-1|0;o=o- +h[a+(k*288|0)+(p<<3)>>3]*+h[a+(n*288|0)+(p<<3)>>3];}while((p|0)>0);if((j|0)==(m|0)){h[l>>3]=+S(o<b?1.0:o);q=m+1|0}else{p=m+1|0;h[a+(p*288|0)+(j<<3)>>3]=o/+h[l>>3];q=p}if((q|0)<(g|0)){m=q}else{break}}}else{m=j;while(1){r=+h[e+(j*288|0)+(m<<3)>>3];if((j|0)==(m|0)){h[l>>3]=+S(r<b?1.0:r);s=m+1|0}else{p=m+1|0;h[a+(p*288|0)+(j<<3)>>3]=r/+h[l>>3];s=p}if((s|0)<(g|0)){m=s}else{break}}}if((k|0)<(g|0)){j=k}else{break}}if(i){t=0}else{break}while(1){j=t+1|0;r=+h[a+(j<<3)>>3];if((t|0)>0){u=r;m=t;while(1){l=m-1|0;v=u- +h[a+(j*288|0)+(l<<3)>>3]*+h[a+10368+(l<<3)>>3];if((l|0)>0){u=v;m=l}else{w=v;break}}}else{w=r}h[a+10368+(t<<3)>>3]=w/+h[a+(j*288|0)+(t<<3)>>3];if((j|0)<(g|0)){t=j}else{break}}}}while(0);t=g-1|0;g=d&65535;if((t|0)<(g|0)){return}else{x=t}do{t=x;while(1){w=+h[a+10368+(t<<3)>>3];d=t+1|0;if((d|0)>(x|0)){y=w}else{i=t;b=w;s=d;while(1){w=b- +h[a+((i+2|0)*288|0)+(t<<3)>>3]*+h[a+10368+(x<<8)+(s<<3)>>3];q=s+1|0;if((q|0)>(x|0)){y=w;break}else{i=s;b=w;s=q}}}h[a+10368+(x<<8)+(t<<3)>>3]=y/+h[a+(d*288|0)+(t<<3)>>3];if((t|0)>0){t=t-1|0}else{break}}b=+h[f>>3];t=a+18560+(x<<3)|0;h[t>>3]=b;s=0;r=b;while(1){b=+h[a+10368+(x<<8)+(s<<3)>>3];i=s+1|0;w=b*+h[e+(s*288|0)+(s<<3)>>3]- +h[a+(i<<3)>>3]*2.0;if((s|0)>0){j=0;u=w;while(1){v=u+ +h[a+10368+(x<<8)+(j<<3)>>3]*2.0*+h[e+(j*288|0)+(s<<3)>>3];q=j+1|0;if((q|0)<(s|0)){j=q;u=v}else{z=v;break}}}else{z=w}u=r+z*b;h[t>>3]=u;if((i|0)>(x|0)){break}else{s=i;r=u}}x=x-1|0;}while((x|0)>=(g|0));return}function CIb(a,b){a=a|0;b=b|0;mrc(a|0,0,18848)|0;c[a+18816>>2]=b;c[a+18820>>2]=530;c[a+18824>>2]=2;return}function DIb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;d=a+18816|0;e=c[d>>2]|0;if((e|0)<0){return}else{f=0;g=e}while(1){if((f|0)>(g|0)){i=g}else{e=b+(f<<3)|0;j=f;while(1){k=a+(f*288|0)+(j<<3)|0;h[k>>3]=+h[k>>3]+ +h[e>>3]*+h[b+(j<<3)>>3];k=j+1|0;l=c[d>>2]|0;if((k|0)>(l|0)){i=l;break}else{j=k}}}j=f+1|0;if((j|0)>(i|0)){break}else{f=j;g=i}}return}function EIb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0.0,e=0,f=0.0,g=0.0,i=0;if((c|0)<0){d=0.0;return+d}else{e=0;f=0.0}while(1){g=f+ +h[b+(e<<3)>>3]*+h[a+10368+(c<<8)+(e<<3)>>3];i=e+1|0;if((i|0)>(c|0)){d=g;break}else{e=i;f=g}}return+d}function FIb(a){a=a|0;return c[c[a>>2]>>2]|0}function GIb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0;b=i;i=i+3072|0;j=b|0;HIb(a,d,e,j|0,h,0);h=c[j+1024>>2]|0;e=c[j+2048>>2]|0;Rb(f|0,g|0,2411848,(g=i,i=i+24|0,c[g>>2]=c[j>>2],c[g+8>>2]=h,c[g+16>>2]=e,g)|0)|0;i=g;_Fb(j+2048|0,0)|0;i=b;return}function HIb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;if((b|0)==0){k=0}else{k=c[b>>2]|0}SFb(f,0,1);l=f+1024|0;SFb(l,0,1);m=f+2048|0;SFb(m,0,65536);n=(h|0)!=0;if(n){c[h+4>>2]=16;c[h>>2]=16}a:do{if(!((c[g>>2]|0)==0|(k|0)==0)){o=c[k+20>>2]|0;do{if((o|0)!=0){p=c[b+o>>2]|0;if((p|0)==0){break}q=c[p>>2]|0;if((q|0)==0){break}r=p;s=ve[c[q+4>>2]&4095](r)|0;UFb(f,2583640,(t=i,i=i+16|0,c[t>>2]=s,c[t+8>>2]=p,t)|0);i=t;if(!n){s=ve[c[k+4>>2]&4095](b)|0;UFb(l,2583640,(t=i,i=i+16|0,c[t>>2]=s,c[t+8>>2]=b,t)|0);i=t;break a}s=c[p>>2]|0;do{if((s|0)==0){u=16}else{p=c[s+12>>2]|0;if((p&252)>>>0<100>>>0|(p|0)<3357440){u=16;break}p=c[s+32>>2]|0;if(p>>>0>10>>>0){u=16;break}q=c[s+36>>2]|0;if((q|0)==0){u=p+16|0;break}else{u=(ve[q&4095](r)|0)+16|0;break}}}while(0);c[h>>2]=u}}while(0);o=ve[c[k+4>>2]&4095](b)|0;UFb(l,2583640,(t=i,i=i+16|0,c[t>>2]=o,c[t+8>>2]=b,t)|0);i=t;if(!n){break}o=c[b>>2]|0;do{if((o|0)==0){v=16}else{r=c[o+12>>2]|0;if((r&252)>>>0<100>>>0|(r|0)<3357440){v=16;break}r=c[o+32>>2]|0;if(r>>>0>10>>>0){v=16;break}s=c[o+36>>2]|0;if((s|0)==0){v=r+16|0;break}else{v=(ve[s&4095](b)|0)+16|0;break}}}while(0);c[h+4>>2]=v}}while(0);VFb(m,d,e);do{if((a[c[f>>2]|0]|0)==0){if((a[c[l>>2]|0]|0)!=0){break}if((a[c[m>>2]|0]|0)!=0){break}i=j;return}}while(0);l=c[f+2052>>2]|0;do{if((l|0)==0){w=0;x=32}else{if(l>>>0>(c[f+2056>>2]|0)>>>0){w=0;x=32;break}e=a[(c[m>>2]|0)+(l-1)|0]|0;if(e<<24>>24==10){y=1}else{w=e<<24>>24;x=32}}}while(0);if((x|0)==32){y=(w|0)==13|0}c[g>>2]=y;i=j;return}function IIb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+4104|0;h=g|0;j=g+3072|0;k=g+4096|0;if((c[500986]|0)<(d|0)){i=g;return}l=k|0;HIb(b,e,f,h|0,2003952,l);f=j|0;e=h|0;b=h+1024|0;m=c[b>>2]|0;n=h+2048|0;o=c[n>>2]|0;Rb(f|0,1024,2411848,(p=i,i=i+24|0,c[p>>2]=c[e>>2],c[p+8>>2]=m,c[p+16>>2]=o,p)|0)|0;i=p;o=c[2477024]|0;if((o|0)==0){m=(gd(2)|0)!=0;r=m?1:-1;c[2477024]=r;s=r}else{s=o}do{if((c[500988]|0)==0){t=10}else{if((c[1510446]&1|0)==0){t=10;break}o=(irc(f,9907072)|0)!=0;if(o|(a[f]|0)==0){t=10;break}if((a[j+((lrc(f|0)|0)-1)|0]|0)==13){t=10;break}o=(c[2477026]|0)+1|0;c[2477026]=o;if((s|0)!=1){break}Id(c[q>>2]|0,2578352,(p=i,i=i+8|0,c[p>>2]=o,p)|0)|0;i=p}}while(0);if((t|0)==10){t=c[2477026]|0;if((t|0)>0){Id(c[q>>2]|0,2435752,(p=i,i=i+8|0,c[p>>2]=t,p)|0)|0;i=p;c[2477026]=0}prc(9907072,f|0)|0;f=c[e>>2]|0;p=a[f]|0;if(p<<24>>24==0){u=f}else{t=f;f=p;do{if((f&255)>>>0<8>>>0|(f-14&255)>>>0<18>>>0){a[t]=63}t=t+1|0;f=a[t]|0;}while(!(f<<24>>24==0));u=c[e>>2]|0}JIb(c[l>>2]|0,u);u=c[b>>2]|0;l=a[u]|0;if(l<<24>>24==0){v=u}else{e=u;u=l;do{if((u&255)>>>0<8>>>0|(u-14&255)>>>0<18>>>0){a[e]=63}e=e+1|0;u=a[e]|0;}while(!(u<<24>>24==0));v=c[b>>2]|0}JIb(c[k+4>>2]|0,v);v=c[n>>2]|0;k=a[v]|0;if(!(k<<24>>24==0)){b=v;v=k;do{if((v&255)>>>0<8>>>0|(v-14&255)>>>0<18>>>0){a[b]=63}b=b+1|0;v=a[b]|0;}while(!(v<<24>>24==0))}v=d>>3;if((v|0)<0){w=0}else{w=(v|0)>6?6:v}JIb(w,c[n>>2]|0)}_Fb(h+2048|0,0)|0;i=g;return}function JIb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;if((a[d]|0)==0){i=e;return}f=c[70588]|0;do{if((f|0)<0){do{if((id(2237792)|0)==0){if((id(2197136)|0)!=0){g=0;break}if((id(2165640)|0)!=0){if((gd(2)|0)!=0){g=1;break}}g=(id(2139488)|0)!=0|0}else{g=0}}while(0);c[70588]=g;if((id(2116072)|0)==0){h=g;break}j=g<<8;c[70588]=j;h=j}else{h=f}}while(0);f=(b|0)==4;if(!((h|0)!=1|f)){g=c[1644368+(b<<2)>>2]|0;Id(c[q>>2]|0,2633952,(k=i,i=i+24|0,c[k>>2]=g>>>4&15,c[k+8>>2]=g&15,c[k+16>>2]=d,k)|0)|0;i=k;i=e;return}g=c[q>>2]|0;if((h|0)!=256|f){xb(d|0,g|0)|0;i=e;return}else{f=c[1644368+(b<<2)>>2]|0;Id(g|0,2610192,(k=i,i=i+24|0,c[k>>2]=f>>>16&255,c[k+8>>2]=f>>>8&255,c[k+16>>2]=d,k)|0)|0;i=k;i=e;return}}function KIb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;do{if((a|0)==0){h=g;c[h>>2]=e;c[h+4>>2]=0;j=b;k=g|0;l=h}else{h=c[a>>2]|0;m=g|0;n=g;c[n>>2]=e;c[n+4>>2]=0;if((h|0)==0){j=b;k=m;l=n;break}if((c[h+12>>2]|0)<=3280641){j=b;k=m;l=n;break}o=c[h+16>>2]|0;if(!((o|0)!=0&(b|0)>7)){j=b;k=m;l=n;break}j=(c[a+o>>2]|0)+b|0;k=m;l=n}}while(0);l=c[500990]|0;if((l|0)==0){i=f;return}mf[l&2047](a,j,d,k);i=f;return}function LIb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=c[500990]|0;if((f|0)==0){return}mf[f&2047](a,b,d,e);return}function MIb(){return c[500986]|0}function NIb(a){a=a|0;c[500986]=a;return}function OIb(a){a=a|0;c[1510446]=a;return}function PIb(a){a=a|0;c[500990]=a;return}function QIb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=c[500990]|0;if((g|0)!=0){mf[g&2047](a,24,b,f|0)}KIb(a,24,2349152,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;KIb(a,24,2287488,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=e;return}function RIb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=c[500990]|0;if((g|0)!=0){mf[g&2047](a,24,b,f|0)}KIb(a,24,2349152,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=e;return}function SIb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;h=c[e>>2]|0;i=(h|0)<1;j=c[g>>2]|0;if(i|(j|0)<1){k=(j|0)<1|(i?2:0);return k|0}i=f+j|0;j=b+h|0;l=f+1|0;m=a[f]|0;n=m&255;if((m&255)>>>0>17>>>0){m=n-17|0;o=i-l|0;if((o|0)<(m|0)){p=(o|0)>0?o:0;q=1}else{p=m;q=0}if((p|0)>(h|0)){r=(h|0)>0?h:0;s=q|2}else{r=p;s=q}q=l;p=b;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r-4|0;if((p|0)>0){nrc(b+4|0,f+5|0,p)|0}p=a[f+(r+1)|0]|0;t=p&255;u=f+(r+2)|0;v=b+r|0;w=(p&255)>>>0<16>>>0?s|8:s}else{t=n;u=l;v=b;w=0}l=i;n=j;j=b;b=t;t=1;s=u;p=v;v=w|u>>>0>i>>>0;a:while(1){b:do{if(t){u=b;w=s;r=p;f=v;while(1){if((f|0)!=0){x=w;z=f;A=r;break a}if((u|0)>15){B=r;C=w;D=u;E=29;break b}q=u&15;if((q|0)==0){h=0;m=w;while(1){if(!(m>>>0<i>>>0)){F=1;G=m;H=1;break}I=m+1|0;J=a[m]|0;if(J<<24>>24==0){h=h+255|0;m=I}else{E=19;break}}if((E|0)==19){E=0;F=J&255;G=I;H=0}K=h+15+F|0;L=G;M=H}else{K=q;L=w;M=0}m=K+3|0;o=l-L|0;if((o|0)<(m|0)){N=(o|0)>0?o:0;O=1}else{N=m;O=M}m=n-r|0;if((N|0)>(m|0)){P=(m|0)>0?m:0;Q=O|2}else{P=N;Q=O}m=L;o=r;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=P-4|0;if((o|0)>0){nrc(r+4|0,L+4|0,o)|0}R=r+P|0;S=L+(P+1)|0;o=a[L+P|0]|0;T=o&255;if((o&255)>>>0>15>>>0){u=T;w=S;r=R;f=Q}else{break}}U=(T>>>2)+1+((d[S]|0)<<2|2048)|0;V=1;W=T;X=L+(P+2)|0;Y=R;Z=Q}else{if((v|0)!=0){x=s;z=v;A=p;break a}if((b|0)>15){B=p;C=s;D=b;E=29;break}U=(b>>2)+1+((d[s]|0)<<2)|0;V=0;W=b;X=s+1|0;Y=p;Z=v}}while(0);do{if((E|0)==29){E=0;if((D|0)>63){U=((d[C]|0)<<3|D>>>2&7)+1|0;V=(D>>5)-1|0;W=D;X=C+1|0;Y=B;Z=0;break}if((D|0)>31){f=D&31;if((f|0)==0){r=0;w=C;while(1){if(!(w>>>0<i>>>0)){_=1;$=w;aa=1;break}ba=w+1|0;ca=a[w]|0;if(ca<<24>>24==0){r=r+255|0;w=ba}else{E=35;break}}if((E|0)==35){E=0;_=ca&255;$=ba;aa=0}da=r+31+_|0;ea=$;fa=aa}else{da=f;ea=C;fa=0}w=d[ea]|0;U=((d[ea+1|0]|0)<<6|w>>>2)+1|0;V=da;W=w;X=ea+2|0;Y=B;Z=fa;break}else{w=D&7;if((w|0)==0){u=0;o=C;while(1){if(!(o>>>0<i>>>0)){ga=1;ha=o;ia=1;break}ja=o+1|0;ka=a[o]|0;if(ka<<24>>24==0){u=u+255|0;o=ja}else{E=41;break}}if((E|0)==41){E=0;ga=ka&255;ha=ja;ia=0}la=u+7+ga|0;ma=ha;na=ia}else{la=w;ma=C;na=0}o=d[ma]|0;oa=ma+2|0;f=o>>>2|(D<<11&16384)+16384|(d[ma+1|0]|0)<<6;if((f|0)==16384){E=44;break a}else{U=f;V=la;W=o;X=oa;Y=B;Z=na;break}}}}while(0);o=V+2|0;f=Y;if((f-j|0)<(U|0)){pa=Y;qa=Z|4}else{r=n-f|0;if((r|0)<(o|0)){ra=(r|0)>0?r:0;sa=Z|2}else{ra=o;sa=Z}vJb(Y,U,ra);pa=Y+ra|0;qa=sa}o=W&3;r=l-X|0;if((r|0)<(o|0)){ta=(r|0)>0?r:0;ua=qa|1}else{ta=o;ua=qa}r=n-pa|0;if((ta|0)>(r|0)){va=(r|0)>0?r:0;wa=ua|2}else{va=ta;wa=ua}r=X;f=pa;y=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=va-4|0;if((f|0)>0){nrc(pa+4|0,X+4|0,f)|0}b=d[X+va|0]|0;t=(o|0)==0;s=X+(va+1)|0;p=pa+va|0;v=wa}if((E|0)==44){x=oa;z=(la|0)==1?na:na|8;A=B}c[g>>2]=x>>>0>i>>>0?0:l-x|0;c[e>>2]=n-A;k=z;return k|0}function TIb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((c|0)==0&(d|0)==0){e=b;f=a;return(G=e,f)|0}else{g=b;h=a;i=d;j=c}while(1){c=Drc(h,g,j,i)|0;d=G;if((c|0)==0&(d|0)==0){e=i;f=j;break}else{g=i;h=j;i=d;j=c}}return(G=e,f)|0}function UIb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=0;i=0;if((f|0)<(h|0)|(f|0)==(h|0)&e>>>0<1>>>0|((d|0)<(i|0)|(d|0)==(i|0)&c>>>0<0>>>0)){j=-2147483648;k=0;return(G=j,k)|0}i=g&-8193;if(i>>>0>5>>>0|(i|0)==4){j=-2147483648;k=0;return(G=j,k)|0}do{if((g&8192|0)==0){l=g}else{i=wrc(a,b,1,-2147483648)|0;h=G;m=0;if(h>>>0<m>>>0|h>>>0==m>>>0&i>>>0<2>>>0){j=b;k=a;return(G=j,k)|0}else{l=g-8192|0;break}}}while(0);g=0;if(((b|0)<(g|0)|(b|0)==(g|0)&a>>>0<0>>>0)&((a|0)!=0|(b|0)!=(-2147483648|0))){g=xrc(0,0,a,b)|0;i=UIb(g,G,c,d,e,f,l>>>1&1^l)|0;g=xrc(0,0,i,G)|0;return(G=G,g)|0}if((l|0)==5){g=Crc(e,f,2,0)|0;n=G;o=g}else{g=(l&1|0)==0;l=wrc(e,f,-1,-1)|0;n=g?0:G;o=g?0:l}l=0;g=0;if(((d|0)<(l|0)|(d|0)==(l|0)&c>>>0<-2147483648>>>0)&((f|0)<(g|0)|(f|0)==(g|0)&e>>>0<-2147483648>>>0)){g=0;if((b|0)<(g|0)|(b|0)==(g|0)&a>>>0<-2147483648>>>0){g=Erc(c,d,a,b)|0;l=wrc(o,n,g,G)|0;g=Crc(l,G,e,f)|0;j=G;k=g;return(G=j,k)|0}else{g=Crc(a,b,e,f)|0;l=Erc(g,G,c,d)|0;g=G;i=Drc(a,b,e,f)|0;m=Erc(i,G,c,d)|0;i=wrc(m,G,o,n)|0;m=Crc(i,G,e,f)|0;i=wrc(m,G,l,g)|0;j=G;k=i;return(G=j,k)|0}}else{i=a|0;a=b&0;g=b;l=(b|0)<0|0?-1:0;b=c|0;c=d&0;m=d;h=(d|0)<0|0?-1:0;d=Erc(m,h,i,a)|0;p=G;q=Erc(b,c,g,l)|0;r=wrc(d,p,q,G)|0;q=G;p=Erc(b,c,i,a)|0;a=qrc(p|0,G|0,0,r|0)|0;p=H;i=G;c=Erc(m,h,g,l)|0;l=wrc(q,0,c,G)|0;c=wrc(l,G,p&1,0)|0;p=G;l=qrc(a|0,i|0,o|0,n|0)|0;n=l;l=G;o=wrc(c,p,H&1,0)|0;p=G;c=o;o=q;q=r;r=63;while(1){i=zrc(n|0,l|0,r|0)|0;a=c<<1|0>>>31|i&1;i=p<<1|c>>>31|G&0;g=q<<1|0>>>31;h=o<<1|q>>>31;if(i>>>0<f>>>0|i>>>0==f>>>0&a>>>0<e>>>0){s=h;t=g;u=i;v=a}else{m=xrc(a,i,e,f)|0;s=h|0;t=g|1;u=G;v=m}if((r|0)>0){p=u;c=v;o=s;q=t;r=r-1|0}else{j=s;k=t;break}}return(G=j,k)|0}return 0}function VIb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=UIb(a,b,c,d,e,f,5)|0;return(G=G,g)|0}function WIb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=d;d=i;i=i+8|0;c[d>>2]=c[h>>2];c[d+4>>2]=c[h+4>>2];h=e;e=i;i=i+8|0;c[e>>2]=c[h>>2];c[e+4>>2]=c[h+4>>2];h=c[d>>2]|0;j=c[e+4>>2]|0;k=Erc(j,(j|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=G;j=c[e>>2]|0;e=c[d+4>>2]|0;d=Erc(e,(e|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=UIb(a,b,k,h,d,G,f)|0;f=G;i=g;return(G=f,j)|0}function XIb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=d;d=i;i=i+8|0;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];g=e;e=i;i=i+8|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];g=c[d>>2]|0;h=c[e+4>>2]|0;j=Erc(h,(h|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;g=G;h=c[e>>2]|0;e=c[d+4>>2]|0;d=Erc(e,(e|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=UIb(a,b,j,g,d,G,5)|0;d=G;i=f;return(G=d,h)|0}function YIb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=d;d=i;i=i+8|0;c[d>>2]=c[j>>2];c[d+4>>2]=c[j+4>>2];j=g;g=i;i=i+8|0;c[g>>2]=c[j>>2];c[g+4>>2]=c[j+4>>2];j=c[d>>2]|0;k=c[g+4>>2]|0;l=Erc(k,(k|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=G;k=c[g>>2]|0;g=c[d+4>>2]|0;d=Erc(g,(g|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=G;g=-1;m=(b|0)>(g|0)|(b|0)==(g|0)&a>>>0>-1>>>0;g=xrc(0,0,a,b)|0;n=m?b:G;o=-1;p=(f|0)>(o|0)|(f|0)==(o|0)&e>>>0>-1>>>0;o=xrc(0,0,e,f)|0;q=(p?f:G)|n|j|k;n=0;if((q|0)<(n|0)|(q|0)==(n|0)&((p?e:o)|(m?a:g)|l|d)>>>0<-2147483648>>>0){g=Erc(l,j,a,b)|0;m=G;o=Erc(d,k,e,f)|0;p=G;r=(((m|0)>(p|0)|(m|0)==(p|0)&g>>>0>o>>>0)&1)-(((m|0)<(p|0)|(m|0)==(p|0)&g>>>0<o>>>0)&1)|0;i=h;return r|0}o=UIb(a,b,l,j,d,k,2)|0;g=G;if((g|0)<(f|0)|(g|0)==(f|0)&o>>>0<e>>>0){r=-1;i=h;return r|0}o=UIb(e,f,d,k,l,j,2)|0;j=G;r=((j|0)<(b|0)|(j|0)==(b|0)&o>>>0<a>>>0)&1;i=h;return r|0}function ZIb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=xrc(a,b,c,d)|0;d=G;c=wrc(e,f,-1,-1)|0;b=c&g;g=G&d;d=f>>>1|0<<31;c=g>>>0>d>>>0|g>>>0==d>>>0&b>>>0>(e>>>1|f<<31)>>>0;d=xrc(b,g,c?e:0,c?f:0)|0;return(G=G,d)|0}function _Ib(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=i;k=a;a=i;i=i+8|0;c[a>>2]=c[k>>2];c[a+4>>2]=c[k+4>>2];k=e;e=i;i=i+8|0;c[e>>2]=c[k>>2];c[e+4>>2]=c[k+4>>2];k=h;h=i;i=i+8|0;c[h>>2]=c[k>>2];c[h+4>>2]=c[k+4>>2];if((b|0)==0&(d|0)==(-2147483648|0)){KIb(0,0,2410992,(l=i,i=i+24|0,c[l>>2]=2578176,c[l+8>>2]=2435696,c[l+16>>2]=158,l)|0);i=l;Hd();return 0}if(!((f|0)>-1)){KIb(0,0,2410992,(l=i,i=i+24|0,c[l>>2]=2349120,c[l+8>>2]=2435696,c[l+16>>2]=159,l)|0);i=l;Hd();return 0}l=c[g>>2]|0;k=c[g+4>>2]|0;m=c[a>>2]|0;do{if((l|0)==0&(k|0)==(-2147483648|0)|(f|0)==0){n=c[a+4>>2]|0;o=c[h+4>>2]|0;p=c[h>>2]|0}else{q=m;r=(m|0)<0|0?-1:0;s=c[h+4>>2]|0;t=s;u=(s|0)<0|0?-1:0;v=Erc(t,u,q,r)|0;w=G;x=c[h>>2]|0;y=x;z=(x|0)<0|0?-1:0;A=c[a+4>>2]|0;B=A;C=(A|0)<0|0?-1:0;D=Erc(B,C,y,z)|0;E=G;if(!((w|0)>(E|0)|(w|0)==(E|0)&v>>>0>D>>>0)){n=A;o=s;p=x;break}D=b<<1|0>>>31;v=d<<1|b>>>31;E=wrc(D,v,-1,-1)|0;w=G;F=c[e+4>>2]|0;H=F;I=(F|0)<0|0?-1:0;F=Erc(H,I,q,r)|0;r=G;q=c[e>>2]|0;J=q;K=(q|0)<0|0?-1:0;q=Erc(J,K,B,C)|0;C=G;B=UIb(E,w,F,r,q,C,2)|0;w=G;E=B>>>1|w<<31;B=w>>1|((w|0)<0|0?-1:0)<<31;w=UIb(D|1,v|0,F,r,q,C,3)|0;C=wrc(w,G,1,0)|0;w=G;q=C>>>1|w<<31;C=w>>1|((w|0)<0|0?-1:0)<<31;w=xrc(E<<1|0>>>31,B<<1|E>>>31,q,C)|0;r=G;if((k|0)<(r|0)|(k|0)==(r|0)&l>>>0<w>>>0){n=A;o=s;p=x;break}w=xrc(q<<1|0>>>31,C<<1|q>>>31,E,B)|0;r=G;if((k|0)>(r|0)|(k|0)==(r|0)&l>>>0>w>>>0){n=A;o=s;p=x;break}if((k|0)<(B|0)|(k|0)==(B|0)&l>>>0<E>>>0){L=B;M=E}else{E=(k|0)>(C|0)|(k|0)==(C|0)&l>>>0>q>>>0;L=E?C:k;M=E?q:l}q=wrc(M,L,f,(f|0)<0|0?-1:0)|0;c[g>>2]=q;c[g+4>>2]=G;q=Erc(t,u,J,K)|0;K=G;J=Erc(H,I,y,z)|0;z=UIb(M,L,q,K,J,G,5)|0;N=G;O=z;i=j;return(G=N,O)|0}}while(0);L=m;M=(m|0)<0|0?-1:0;m=c[e+4>>2]|0;l=Erc(m,(m|0)<0|0?-1:0,L,M)|0;m=G;k=c[e>>2]|0;e=n;a=(n|0)<0|0?-1:0;n=Erc(e,a,k,(k|0)<0|0?-1:0)|0;k=UIb(b,d,l,m,n,G,5)|0;n=wrc(k,G,f,(f|0)<0|0?-1:0)|0;c[g>>2]=n;c[g+4>>2]=G;g=Erc(o,(o|0)<0|0?-1:0,L,M)|0;M=G;L=Erc(e,a,p,(p|0)<0|0?-1:0)|0;p=UIb(b,d,g,M,L,G,5)|0;N=G;O=p;i=j;return(G=N,O)|0}function $Ib(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+16|0;h=a;a=i;i=i+8|0;c[a>>2]=c[h>>2];c[a+4>>2]=c[h+4>>2];h=e;e=i;i=i+8|0;c[e>>2]=c[h>>2];c[e+4>>2]=c[h+4>>2];h=g|0;j=g+8|0;c[j>>2]=f;c[j+4>>2]=1;yKb(h,e,j);j=c[h>>2]|0;e=c[h+4>>2]|0;h=c[a>>2]|0;f=c[a+4>>2]|0;a=Erc(f,(f|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;k=G;l=Erc(h,(h|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;m=G;do{if((a|0)==(l|0)&(k|0)==(m|0)){if(!((f|0)==0|(e|0)==0)){break}if((j|0)==0|(h|0)==0){n=d;o=b;i=g;return(G=n,o)|0}else{p=(j>>31)-(h>>31)|0;q=6;break}}else{xrc(a,k,l,m)|0;r=G^((f^e|0)<0|0?-1:0);((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;p=r>>31|((r|0)<0|0?-1:0)<<1|1;q=6}}while(0);do{if((q|0)==6){if((p|0)<0){n=d;o=b}else{break}i=g;return(G=n,o)|0}}while(0);p=UIb(b,d,l,m,a,k,5)|0;q=G;e=UIb(p,q,a,k,l,m,5)|0;f=G;h=wrc(p,q,1,0)|0;q=UIb(h,G,a,k,l,m,5)|0;m=G;l=xrc(b,d,e,f)|0;f=wrc(l,G,q,m)|0;n=G;o=f;i=g;return(G=n,o)|0}function aJb(){return pJb(88)|0}function bJb(a){a=a|0;var b=0;b=a|0;c[b>>2]=0;c[b+4>>2]=0;c[a+72>>2]=271733878;c[a+76>>2]=-1732584194;c[a+80>>2]=-271733879;c[a+84>>2]=1732584193;return}function cJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a|0;f=c[e>>2]|0;g=f&63;h=wrc(f,c[e+4>>2]|0,d,(d|0)<0|0?-1:0)|0;c[e>>2]=h;c[e+4>>2]=G;do{if((g|0)==0){i=b;j=d}else{e=64-g|0;h=(e|0)<(d|0)?e:d;nrc(a+8+g|0,b|0,h)|0;if((h+g|0)<64){return}else{dJb(a+72|0,a+8|0,1);i=b+h|0;j=d-h|0;break}}}while(0);d=j&-64;b=i+d|0;do{if((i&3|0)==0){dJb(a+72|0,i,(j|0)/64|0);k=b}else{if((d|0)<=0){k=i;break}g=a+8|0;h=g|0;e=a+72|0;f=g;g=i;while(1){nrc(h|0,g|0,64)|0;dJb(e,f,1);l=g+64|0;if(l>>>0<b>>>0){g=l}else{k=l;break}}}}while(0);b=j&63;if((b|0)==0){return}nrc(a+8|0,k|0,b)|0;return}function dJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((d|0)<=0){return}e=a+12|0;f=a+8|0;g=a+4|0;h=0;i=c[e>>2]|0;j=c[f>>2]|0;k=c[g>>2]|0;l=c[a>>2]|0;do{m=h<<4;n=c[b+(m<<2)>>2]|0;o=i-680876936+n+((l^k)&j^l)|0;p=(o<<7|o>>>25)+j|0;o=c[b+((m|1)<<2)>>2]|0;q=l-389564586+o+(p&(k^j)^k)|0;r=(q<<12|q>>>20)+p|0;q=c[b+((m|2)<<2)>>2]|0;s=k+606105819+q+(r&(p^j)^j)|0;t=(s<<17|s>>>15)+r|0;s=c[b+((m|3)<<2)>>2]|0;u=j-1044525330+s+(t&(r^p)^p)|0;v=(u<<22|u>>>10)+t|0;u=c[b+((m|4)<<2)>>2]|0;w=u-176418897+p+(v&(t^r)^r)|0;p=(w<<7|w>>>25)+v|0;w=c[b+((m|5)<<2)>>2]|0;x=w+1200080426+r+(p&(v^t)^t)|0;r=(x<<12|x>>>20)+p|0;x=c[b+((m|6)<<2)>>2]|0;y=x-1473231341+t+(r&(p^v)^v)|0;t=(y<<17|y>>>15)+r|0;y=c[b+((m|7)<<2)>>2]|0;z=y-45705983+v+(t&(r^p)^p)|0;v=(z<<22|z>>>10)+t|0;z=c[b+((m|8)<<2)>>2]|0;A=z+1770035416+p+(v&(t^r)^r)|0;p=(A<<7|A>>>25)+v|0;A=c[b+((m|9)<<2)>>2]|0;B=A-1958414417+r+(p&(v^t)^t)|0;r=(B<<12|B>>>20)+p|0;B=c[b+((m|10)<<2)>>2]|0;C=B-42063+t+(r&(p^v)^v)|0;t=(C<<17|C>>>15)+r|0;C=c[b+((m|11)<<2)>>2]|0;D=C-1990404162+v+(t&(r^p)^p)|0;v=(D<<22|D>>>10)+t|0;D=c[b+((m|12)<<2)>>2]|0;E=D+1804603682+p+(v&(t^r)^r)|0;p=(E<<7|E>>>25)+v|0;E=c[b+((m|13)<<2)>>2]|0;F=E-40341101+r+(p&(v^t)^t)|0;r=(F<<12|F>>>20)+p|0;F=c[b+((m|14)<<2)>>2]|0;G=F-1502002290+t+(r&(p^v)^v)|0;t=(G<<17|G>>>15)+r|0;G=c[b+((m|15)<<2)>>2]|0;m=G+1236535329+v+(t&(r^p)^p)|0;v=(m<<22|m>>>10)+t|0;m=o-165796510+p+(v&r|t&~r)|0;p=(m<<5|m>>>27)+v|0;m=x-1069501632+r+(p&t|v&~t)|0;r=(m<<9|m>>>23)+p|0;m=C+643717713+t+(r&v|p&~v)|0;t=(m<<14|m>>>18)+r|0;m=n-373897302+v+(t&p|r&~p)|0;v=(m<<20|m>>>12)+t|0;m=w-701558691+p+(v&r|t&~r)|0;p=(m<<5|m>>>27)+v|0;m=B+38016083+r+(p&t|v&~t)|0;r=(m<<9|m>>>23)+p|0;m=G-660478335+t+(r&v|p&~v)|0;t=(m<<14|m>>>18)+r|0;m=u-405537848+v+(t&p|r&~p)|0;v=(m<<20|m>>>12)+t|0;m=A+568446438+p+(v&r|t&~r)|0;p=(m<<5|m>>>27)+v|0;m=F-1019803690+r+(p&t|v&~t)|0;r=(m<<9|m>>>23)+p|0;m=s-187363961+t+(r&v|p&~v)|0;t=(m<<14|m>>>18)+r|0;m=z+1163531501+v+(t&p|r&~p)|0;v=(m<<20|m>>>12)+t|0;m=E-1444681467+p+(v&r|t&~r)|0;p=(m<<5|m>>>27)+v|0;m=q-51403784+r+(p&t|v&~t)|0;r=(m<<9|m>>>23)+p|0;m=y+1735328473+t+(r&v|p&~v)|0;t=(m<<14|m>>>18)+r|0;m=D-1926607734+v+(t&p|r&~p)|0;v=(m<<20|m>>>12)+t|0;m=w-378558+p+(t^r^v)|0;p=(m<<4|m>>>28)+v|0;m=z-2022574463+r+(v^t^p)|0;r=(m<<11|m>>>21)+p|0;m=C+1839030562+t+(p^v^r)|0;t=(m<<16|m>>>16)+r|0;m=F-35309556+v+(r^p^t)|0;v=(m<<23|m>>>9)+t|0;m=o-1530992060+p+(t^r^v)|0;p=(m<<4|m>>>28)+v|0;m=u+1272893353+r+(v^t^p)|0;r=(m<<11|m>>>21)+p|0;m=y-155497632+t+(p^v^r)|0;t=(m<<16|m>>>16)+r|0;m=B-1094730640+v+(r^p^t)|0;v=(m<<23|m>>>9)+t|0;m=E+681279174+p+(t^r^v)|0;p=(m<<4|m>>>28)+v|0;m=n-358537222+r+(v^t^p)|0;r=(m<<11|m>>>21)+p|0;m=s-722521979+t+(p^v^r)|0;t=(m<<16|m>>>16)+r|0;m=x+76029189+v+(r^p^t)|0;v=(m<<23|m>>>9)+t|0;m=A-640364487+p+(t^r^v)|0;p=(m<<4|m>>>28)+v|0;m=D-421815835+r+(v^t^p)|0;r=(m<<11|m>>>21)+p|0;m=G+530742520+t+(p^v^r)|0;t=(m<<16|m>>>16)+r|0;m=q-995338651+v+(r^p^t)|0;v=(m<<23|m>>>9)+t|0;m=n-198630844+p+((v|~r)^t)|0;p=(m<<6|m>>>26)+v|0;m=y+1126891415+r+((p|~t)^v)|0;r=(m<<10|m>>>22)+p|0;m=F-1416354905+t+((r|~v)^p)|0;t=(m<<15|m>>>17)+r|0;m=w-57434055+v+((t|~p)^r)|0;v=(m<<21|m>>>11)+t|0;m=D+1700485571+p+((v|~r)^t)|0;p=(m<<6|m>>>26)+v|0;m=s-1894986606+r+((p|~t)^v)|0;r=(m<<10|m>>>22)+p|0;m=B-1051523+t+((r|~v)^p)|0;t=(m<<15|m>>>17)+r|0;m=o-2054922799+v+((t|~p)^r)|0;v=(m<<21|m>>>11)+t|0;m=z+1873313359+p+((v|~r)^t)|0;p=(m<<6|m>>>26)+v|0;m=G-30611744+r+((p|~t)^v)|0;r=(m<<10|m>>>22)+p|0;m=x-1560198380+t+((r|~v)^p)|0;t=(m<<15|m>>>17)+r|0;m=E+1309151649+v+((t|~p)^r)|0;v=(m<<21|m>>>11)+t|0;m=u-145523070+p+((v|~r)^t)|0;p=(m<<6|m>>>26)+v|0;m=C-1120210379+r+((p|~t)^v)|0;r=(m<<10|m>>>22)+p|0;m=q+718787259+t+((r|~v)^p)|0;t=(m<<15|m>>>17)+r|0;m=A-343485551+v+((t|~p)^r)|0;l=r+l|0;c[a>>2]=l;k=t+(c[g>>2]|0)|0;c[g>>2]=k;j=t+(c[f>>2]|0)+(m<<21|m>>>11)|0;c[f>>2]=j;i=p+(c[e>>2]|0)|0;c[e>>2]=i;h=h+1|0;}while((h|0)<(d|0));return}function eJb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=b|0;h=c[g>>2]|0;j=c[g+4>>2]<<3|h>>>29;c[f>>2]=h<<3|0>>>29;c[f+4>>2]=j;cJb(b,2410448,1);if(!((c[g>>2]&63|0)==56&(c[g+4>>2]&0|0)==0)){do{cJb(b,10230696,1);}while(!((c[g>>2]&63|0)==56&(c[g+4>>2]&0|0)==0))}cJb(b,f,8);f=d;y=c[b+84>>2]|0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=d+4|0;y=c[b+80>>2]|0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=d+8|0;y=c[b+76>>2]|0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=d+12|0;y=c[b+72>>2]|0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;i=e;return}function fJb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+96|0;g=f|0;h=f+8|0;j=h|0;c[j>>2]=0;c[j+4>>2]=0;k=h+72|0;c[k>>2]=271733878;l=h+76|0;c[l>>2]=-1732584194;m=h+80|0;c[m>>2]=-271733879;n=h+84|0;c[n>>2]=1732584193;cJb(h,d,e);e=g;d=c[j>>2]|0;o=c[j+4>>2]<<3|d>>>29;c[g>>2]=d<<3|0>>>29;c[g+4>>2]=o;cJb(h,2410448,1);if(!((c[j>>2]&63|0)==56&(c[j+4>>2]&0|0)==0)){do{cJb(h,10230696,1);}while(!((c[j>>2]&63|0)==56&(c[j+4>>2]&0|0)==0))}cJb(h,e,8);e=b;y=c[n>>2]|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=b+4|0;y=c[m>>2]|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=b+8|0;y=c[l>>2]|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=b+12|0;y=c[k>>2]|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;i=f;return}function gJb(a){a=a|0;c[208290]=a;return}function hJb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[e>>2]=0;f=c[208290]|0;if((f-32|0)>>>0<a>>>0){g=0;i=b;return g|0}if((a|0)!=0){if((Wqc(e,16,a)|0)==0){g=c[e>>2]|0;i=b;return g|0}else{c[e>>2]=0;g=0;i=b;return g|0}}c[d>>2]=0;do{if((f|0)==32){h=0}else{if((Wqc(d,16,1)|0)==0){h=c[d>>2]|0;break}else{c[d>>2]=0;h=0;break}}}while(0);c[e>>2]=h;g=h;i=b;return g|0}function iJb(a,b){a=a|0;b=b|0;var d=0;if(((c[208290]|0)-32|0)>>>0<b>>>0){d=0;return d|0}d=Sqc(a,((b|0)==0)+b|0)|0;return d|0}function jJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=ca(d,b)|0;do{if((d|b)>>>0>65535>>>0&(d|0)!=0){if(((e>>>0)/(d>>>0)|0|0)==(b|0)){break}Qqc(a);f=0;return f|0}}while(0);if(((c[208290]|0)-32|0)>>>0<e>>>0){g=0}else{g=Sqc(a,((e|0)==0)+e|0)|0}if((g|0)!=0|(e|0)==0){f=g;return f|0}Qqc(a);f=0;return f|0}function kJb(a){a=a|0;Qqc(a);return}function lJb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a;a=c[d>>2]|0;if((b|0)==0){Qqc(a);c[d>>2]=0;e=0;return e|0}do{if(((c[208290]|0)-32|0)>>>0<b>>>0){f=a}else{g=Sqc(a,b)|0;if((g|0)==0){f=c[d>>2]|0;break}c[d>>2]=g;e=0;return e|0}}while(0);Qqc(f);c[d>>2]=0;e=-12;return e|0}function mJb(a){a=a|0;var b=0;b=a;Qqc(c[b>>2]|0);c[b>>2]=0;return}function nJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;if((d|0)==0){e=0;return e|0}if(!((2147483647/(d>>>0)|0)>>>0>b>>>0)){e=0;return e|0}f=ca(d,b)|0;if(((c[208290]|0)-32|0)>>>0<f>>>0){e=0;return e|0}e=Sqc(a,((f|0)==0)+f|0)|0;return e|0}function oJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a;a=c[e>>2]|0;f=ca(d,b)|0;do{if((d|b)>>>0>65535>>>0&(d|0)!=0){if(((f>>>0)/(d>>>0)|0|0)==(b|0)){g=4;break}Qqc(a);h=0}else{g=4}}while(0);do{if((g|0)==4){if(((c[208290]|0)-32|0)>>>0<f>>>0){i=0}else{i=Sqc(a,((f|0)==0)+f|0)|0}if((i|0)!=0|(f|0)==0){h=i;break}Qqc(a);h=0}}while(0);c[e>>2]=h;return((h|0)!=0|(b|0)==0|(d|0)==0?0:-12)|0}function pJb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+16|0;d=b|0;e=b+8|0;c[e>>2]=0;f=c[208290]|0;if((f-32|0)>>>0<a>>>0){g=0;i=b;return g|0}do{if((a|0)==0){c[d>>2]=0;do{if((f|0)==32){h=0}else{if((Wqc(d,16,1)|0)==0){h=c[d>>2]|0;break}else{c[d>>2]=0;h=0;break}}}while(0);c[e>>2]=h;j=h}else{if((Wqc(e,16,a)|0)==0){j=c[e>>2]|0;break}c[e>>2]=0;g=0;i=b;return g|0}}while(0);if((j|0)==0){g=0;i=b;return g|0}mrc(j|0,0,a|0)|0;g=j;i=b;return g|0}function qJb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+16|0;e=d|0;f=d+8|0;a:do{if((b|0)==0){g=0}else{if(!((2147483647/(b>>>0)|0)>>>0>a>>>0)){g=0;break}h=ca(b,a)|0;c[f>>2]=0;j=c[208290]|0;if((j-32|0)>>>0<h>>>0){g=0;break}do{if((h|0)==0){c[e>>2]=0;do{if((j|0)==32){k=0}else{if((Wqc(e,16,1)|0)==0){k=c[e>>2]|0;break}else{c[e>>2]=0;k=0;break}}}while(0);c[f>>2]=k;l=k}else{if((Wqc(f,16,h)|0)==0){l=c[f>>2]|0;break}else{c[f>>2]=0;g=0;break a}}}while(0);if((l|0)==0){g=0;break}mrc(l|0,0,h|0)|0;g=l}}while(0);i=d;return g|0}function rJb(a){a=a|0;var b=0,d=0,e=0;do{if((a|0)==0){b=0}else{d=(lrc(a|0)|0)+1|0;if(((c[208290]|0)-32|0)>>>0<d>>>0){b=0;break}e=Sqc(0,((d|0)==0)+d|0)|0;if((e|0)==0){b=0;break}nrc(e|0,a|0,d)|0;b=e}}while(0);return b|0}function sJb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;e=d|0;f=d+8|0;a:do{if((a|0)==0){g=0}else{c[f>>2]=0;h=c[208290]|0;if((h-32|0)>>>0<b>>>0){g=0;break}do{if((b|0)==0){c[e>>2]=0;do{if((h|0)==32){j=0}else{if((Wqc(e,16,1)|0)==0){j=c[e>>2]|0;break}else{c[e>>2]=0;j=0;break}}}while(0);c[f>>2]=j;k=j}else{if((Wqc(f,16,b)|0)==0){k=c[f>>2]|0;break}else{c[f>>2]=0;g=0;break a}}}while(0);if((k|0)==0){g=0;break}nrc(k|0,a|0,b)|0;g=k}}while(0);i=d;return g|0}function tJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[b>>2]|0;f=a;g=c[f>>2]|0;h=g;a:do{if((e-1&e|0)==0){do{if((e|0)==0){i=4;j=5}else{if(e>>>0>268435455>>>0){k=h;break}i=e<<3;j=5}}while(0);do{if((j|0)==5){if(((c[208290]|0)-32|0)>>>0<i>>>0){k=h;break}l=Sqc(g,(i|0)==0|i)|0;m=l;if((l|0)==0){k=c[a>>2]|0;break}else{c[f>>2]=m;n=m;break a}}}while(0);Qqc(k);c[a>>2]=0;o=0;c[b>>2]=o;return}else{n=g}}while(0);c[n+(e<<2)>>2]=d;o=e+1|0;c[b>>2]=o;return}function uJb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[b>>2]|0;g=c[a>>2]|0;a:do{if((f-1&f|0)==0){do{if((f|0)==0){h=1;i=5}else{if(f>>>0>(2147483647/(d<<1>>>0)|0)>>>0){j=g;break}h=f<<1;i=5}}while(0);do{if((i|0)==5){k=ca(h,d)|0;if(((c[208290]|0)-32|0)>>>0<k>>>0){j=g;break}l=Sqc(g,((k|0)==0)+k|0)|0;if((l|0)==0){j=c[a>>2]|0;break}else{c[a>>2]=l;m=l;break a}}}while(0);Qqc(j);c[a>>2]=0;c[b>>2]=0;n=0;return n|0}else{m=g}}while(0);c[b>>2]=f+1;b=m+(ca(f,d)|0)|0;if((e|0)==0){n=b;return n|0}nrc(b|0,e|0,d)|0;n=b;return n|0}function vJb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=b+(-c|0)|0;switch(c|0){case 2:{g=b-2|0;h=(d[g]|d[g+1|0]<<8)<<16>>16&65535;g=h<<16|h;if((e|0)>3){h=e-4|0;i=h&-4;j=b;k=e;while(1){l=j;y=g;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=k-4|0;if((l|0)>3){j=j+4|0;k=l}else{break}}m=b+(i+4)|0;n=h-i|0}else{m=b;n=e}if((n|0)==0){return}else{o=m;p=n}while(1){n=p-1|0;a[o]=a[o-2|0]|0;if((n|0)==0){break}else{o=o+1|0;p=n}}return};case 1:{mrc(b|0,a[f]|0,e|0)|0;return};case 3:{p=d[b-1|0]|0;o=(d[b-2|0]|0)<<8|p<<16;n=d[b-3|0]|0;m=o|n;i=m|n<<24;n=m<<16|o>>>8;o=m<<8|p;if((e|0)>11){p=((e-12|0)>>>0)%12|0;m=e;h=b;while(1){k=h;y=i;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+4|0;y=n;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+8|0;y=o;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m-12|0;if((k|0)>11){m=k;h=h+12|0}else{break}}q=p;r=b+(e-p)|0}else{q=e;r=b}do{if((q|0)>3){p=r;y=i;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;h=q-4|0;if((h|0)<=3){s=p;t=h;break}h=p;y=n;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;s=r+8|0;t=q-8|0}else{s=r;t=q}}while(0);if((t|0)==0){return}else{u=t;v=s}while(1){s=u-1|0;a[v]=a[v-3|0]|0;if((s|0)==0){break}else{u=s;v=v+1|0}}return};case 4:{v=b-4|0;u=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if((e|0)>3){v=e-4|0;s=v&-4;t=e;q=b;while(1){r=q;y=u;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=t-4|0;if((r|0)>3){t=r;q=q+4|0}else{break}}w=v-s|0;x=b+(s+4)|0}else{w=e;x=b}if((w|0)==0){return}else{z=w;A=x}while(1){x=z-1|0;a[A]=a[A-4|0]|0;if((x|0)==0){break}else{z=x;A=A+1|0}}return};case 0:{return};default:{if((e|0)>15){if((e|0)>(c|0)){A=b;z=e;x=c;while(1){nrc(A|0,f|0,x)|0;w=A+x|0;s=z-x|0;v=x<<1;if((s|0)>(v|0)){A=w;z=s;x=v}else{B=w;C=s;break}}}else{B=b;C=e}nrc(B|0,f|0,C)|0;return}if((e|0)>7){C=f;B=b;y=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;B=b+(4-c)|0;C=b+4|0;y=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;D=b+(8-c)|0;E=e-8|0;F=b+8|0}else{D=f;E=e;F=b}if((E|0)>3){b=D;e=F;y=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;G=D+4|0;H=E-4|0;I=F+4|0}else{G=D;H=E;I=F}if((H|0)>1){F=G;E=I;y=(d[F]|d[F+1|0]<<8)<<16>>16;a[E]=y;y=y>>8;a[E+1|0]=y;J=G+2|0;K=H-2|0;L=I+2|0}else{J=G;K=H;L=I}if((K|0)==0){return}a[L]=a[J]|0;return}}}function wJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((c[b>>2]|0)>>>0>d>>>0){e=a;return e|0}f=((d*17|0)>>>4)+32|0;g=f>>>0>d>>>0?f:d;if(((c[208290]|0)-32|0)>>>0<g>>>0){h=0}else{h=Sqc(a,((g|0)==0)+g|0)|0}c[b>>2]=(h|0)==0?0:g;e=h;return e|0}function xJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a;if((c[b>>2]|0)>>>0>d>>>0){i=e;return}a=((d*17|0)>>>4)+32|0;j=a>>>0>d>>>0?a:d;Qqc(c[h>>2]|0);c[g>>2]=0;d=c[208290]|0;do{if((d-32|0)>>>0<j>>>0){k=0}else{if((j|0)!=0){if((Wqc(g,16,j)|0)==0){k=c[g>>2]|0;break}else{c[g>>2]=0;k=0;break}}c[f>>2]=0;do{if((d|0)==32){l=0}else{if((Wqc(f,16,1)|0)==0){l=c[f>>2]|0;break}else{c[f>>2]=0;l=0;break}}}while(0);c[g>>2]=l;k=l}}while(0);c[h>>2]=k;c[b>>2]=(k|0)==0?0:j;i=e;return}function yJb(){return pJb(48)|0}function zJb(a){a=a|0;var b=0;mrc(a|0,0,48)|0;b=a+8|0;c[b>>2]=-622998955;c[b+4>>2]=1918553173;b=a|0;c[b>>2]=-622998955;c[b+4>>2]=1918553173;return}function AJb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;g=b|0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=b+8|0;k=c[j>>2]|0;l=c[j+4>>2]|0;if((f|0)<1){return}m=b+40|0;n=wrc(c[m>>2]|0,c[m+4>>2]|0,f,(f|0)<0|0?-1:0)|0;c[m>>2]=n;c[m+4>>2]=G;m=b+32|0;n=c[m>>2]|0;if((n|0)>0){a:do{if((n|0)<16){o=n;p=f;q=e;while(1){r=a[q]|0;c[m>>2]=o+1;a[b+16+o|0]=r;r=p-1|0;if((r|0)<1){break}s=q+1|0;t=c[m>>2]|0;if((t|0)<16){o=t;p=r;q=s}else{u=r;v=s;break a}}return}else{u=f;v=e}}while(0);c[m>>2]=0;n=b+16|0;q=n|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;Erc(p,n,289559509,-2017231983)|0;q=G;o=Erc(p,n,-2147483648,-2002703894)|0;n=Erc(q>>>1|0<<31|o,0>>>1|0<<31|G,658871167,1291169091)|0;o=G;q=b+24|0;p=q|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=Erc(s,q,658871167,1291169091)|0;r=G;t=Erc(s,q,0,1317742334)|0;q=Erc(p>>>31|r<<1|t,r>>>31|0<<1|G,289559509,-2017231983)|0;r=G;t=n^h;n=o^i;o=wrc(t<<27|0>>>5|(n>>>5|0<<27),n<<27|t>>>5|(0>>>5|0<<27),k,l)|0;t=Erc(o,G,5,0)|0;o=wrc(t,G,1390208809,0)|0;t=G;n=q^k;q=r^l;r=wrc(o,t,n<<31|0>>>1|(q>>>1|0<<31),q<<31|n>>>1|(0>>>1|0<<31))|0;n=Erc(r,G,5,0)|0;r=wrc(n,G,944331445,0)|0;w=G;x=r;y=t;z=o;A=v;B=u}else{w=l;x=k;y=i;z=h;A=e;B=f}f=B&-16;e=A+f|0;if((f|0)>0){f=A;h=y;i=z;k=w;l=x;while(1){u=f;v=u|0;o=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=u+4|0;u=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;Erc(o,u,289559509,-2017231983)|0;v=G;t=Erc(o,u,-2147483648,-2002703894)|0;u=Erc(v>>>1|0<<31|t,0>>>1|0<<31|G,658871167,1291169091)|0;t=G;v=f+8|0;o=v|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=v+4|0;v=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=Erc(r,v,658871167,1291169091)|0;n=G;q=Erc(r,v,0,1317742334)|0;v=Erc(o>>>31|n<<1|q,n>>>31|0<<1|G,289559509,-2017231983)|0;n=G;q=u^i;u=t^h;t=wrc(q<<27|0>>>5|(u>>>5|0<<27),u<<27|q>>>5|(0>>>5|0<<27),l,k)|0;q=Erc(t,G,5,0)|0;t=wrc(q,G,1390208809,0)|0;q=G;u=v^l;v=n^k;n=wrc(t,q,u<<31|0>>>1|(v>>>1|0<<31),v<<31|u>>>1|(0>>>1|0<<31))|0;u=Erc(n,G,5,0)|0;n=wrc(u,G,944331445,0)|0;u=G;v=f+16|0;if(v>>>0<e>>>0){f=v;h=q;i=t;k=u;l=n}else{C=v;D=q;E=t;F=u;H=n;break}}}else{C=A;D=y;E=z;F=w;H=x}c[g>>2]=E;c[g+4>>2]=D;c[j>>2]=H;c[j+4>>2]=F;F=B&15;if((F|0)==0){return}nrc(b+16|0,C|0,F)|0;c[m>>2]=F;return}function BJb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b|0;g=c[f>>2]|0;h=c[f+4>>2]|0;f=b+8|0;i=c[f>>2]|0;j=c[f+4>>2]|0;f=c[b+32>>2]|0;mrc(b+16+f|0,0,16-f|0)|0;f=b+16|0;k=f|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=f+4|0;f=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;Erc(l,f,289559509,-2017231983)|0;k=G;m=Erc(l,f,-2147483648,-2002703894)|0;f=Erc(k>>>1|0<<31|m,0>>>1|0<<31|G,658871167,1291169091)|0;m=b+40|0;k=c[m>>2]|0;l=c[m+4>>2]|0;m=l^h^G;h=b+24|0;b=h|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+4|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=Erc(n,h,658871167,1291169091)|0;o=G;p=Erc(n,h,0,1317742334)|0;h=Erc(b>>>31|o<<1|p,o>>>31|0<<1|G,289559509,-2017231983)|0;o=k^i^h;h=l^j^G;j=wrc(o,h,k^g^f,m)|0;m=G;f=wrc(j,m,o,h)|0;h=G;o=Erc((m>>>1|0<<31)^j,(0>>>1|0<<31)^m,-313160499,-11423785)|0;m=G;j=Erc((m>>>1|0<<31)^o,(0>>>1|0<<31)^m,444984403,-993084930)|0;m=G;o=Erc((h>>>1|0<<31)^f,(0>>>1|0<<31)^h,-313160499,-11423785)|0;h=G;f=Erc((h>>>1|0<<31)^o,(0>>>1|0<<31)^h,444984403,-993084930)|0;h=G;o=(h>>>1|0<<31)^f;f=(0>>>1|0<<31)^h;h=wrc(o,f,(m>>>1|0<<31)^j,(0>>>1|0<<31)^m)|0;m=G;j=wrc(h,m,o,f)|0;f=G;o=e;g=o|0;y=h;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;g=o+4|0;y=m;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;g=e+8|0;e=g|0;y=j;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=g+4|0;y=f;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;return}function CJb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a>>2]|0;a=(b|0)!=0;do{if(!(a|(d|0)==0)){e=c[d+8>>2]|0;if((e|0)==0){break}if((c[e>>2]|0)==0){break}else{f=e}return f|0}}while(0);do{if(a){d=b+48|0;if((c[d>>2]|0)==0){break}else{f=d}return f|0}}while(0);f=0;return f|0}function DJb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FJb(a,b,c,d,e,0)|0}function EJb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;i=i+24|0;j=g|0;k=g+8|0;l=g+16|0;m=FJb(b,d,0,0,f,l)|0;f=c[l>>2]|0;if((m|0)==0|(f|0)==0){n=-1414549496;i=g;return n|0}l=(e|0)!=0;do{if(!l){d=c[m+12>>2]|0;if((d|0)==5|(d|0)==1346784596|(d|0)==1397116244|(d|0)==1397316165|(d|0)==1448231252|(d|0)==1146442272|(d|0)==1129270354|(d|0)==1128811585){break}else{n=-22}i=g;return n|0}}while(0);if((c[m+40>>2]&128|0)!=0){n=-22;i=g;return n|0}d=c[m+8>>2]|0;o=f+d|0;p=c[m+12>>2]|0;if((p|0)==1397116244){do{if((e|0)==0){q=-1}else{if((irc(e,2577856)|0)==0){q=-1;break}r=MKb(e)|0;if(!((r|0)==-1)){q=r;break}r=rb(e|0,j|0,0)|0;if((a[c[j>>2]|0]|0)==0&r>>>0<10>>>0){q=r;break}KIb(b,16,2136016,(s=i,i=i+16|0,c[s>>2]=e,c[s+8>>2]=2137728,s)|0);i=s;n=-22;i=g;return n|0}}while(0);t=+h[m+24>>3];if(t>-1.0){u=~~t}else{u=-1}t=+h[m+32>>3];j=t>9.0?9:~~t;r=(j|u|0)==0;v=r?-1:u;u=r?9:j;if((q|0)<(v|0)|(q|0)>(u|0)){j=c[m>>2]|0;KIb(b,16,2147296,(s=i,i=i+40|0,c[s>>2]=q,c[s+8>>2]=j,c[s+16>>2]=2137728,c[s+24>>2]=v,c[s+32>>2]=u,s)|0);i=s;n=-34;i=g;return n|0}else{c[o>>2]=q;n=0;i=g;return n|0}}else if((p|0)==1448231252){do{if((e|0)==0){w=-22}else{q=cKb(o,e)|0;if((q|0)<0){w=q;break}else{n=q}i=g;return n|0}}while(0);KIb(b,16,2132280,(s=i,i=i+8|0,c[s>>2]=e,s)|0);i=s;n=w;i=g;return n|0}else if((p|0)==1346784596){do{if((e|0)==0){x=-1}else{if((irc(e,2577856)|0)==0){x=-1;break}w=nKb(e)|0;if(!((w|0)==-1)){x=w;break}w=rb(e|0,k|0,0)|0;if((a[c[k>>2]|0]|0)==0&w>>>0<333>>>0){x=w;break}KIb(b,16,2136016,(s=i,i=i+16|0,c[s>>2]=e,c[s+8>>2]=2134136,s)|0);i=s;n=-22;i=g;return n|0}}while(0);t=+h[m+24>>3];if(t>-1.0){y=~~t}else{y=-1}t=+h[m+32>>3];k=t>332.0?332:~~t;w=(k|y|0)==0;q=w?-1:y;y=w?332:k;if((x|0)<(q|0)|(x|0)>(y|0)){k=c[m>>2]|0;KIb(b,16,2147296,(s=i,i=i+40|0,c[s>>2]=x,c[s+8>>2]=k,c[s+16>>2]=2134136,c[s+24>>2]=q,c[s+32>>2]=y,s)|0);i=s;n=-34;i=g;return n|0}else{c[o>>2]=x;n=0;i=g;return n|0}}else if((p|0)==5){mJb(o);c[o>>2]=rJb(e)|0;n=0;i=g;return n|0}else if((p|0)==1128811585){do{if(l){if((irc(e,2577856)|0)==0){break}x=oGb(e,0)|0;y=G;if((x|0)==0&(y|0)==0){KIb(b,16,2435576,(s=i,i=i+8|0,c[s>>2]=e,s)|0);i=s;z=-22}else{z=0}q=o;c[q>>2]=x;c[q+4>>2]=y;n=z;i=g;return n|0}}while(0);z=o;c[z>>2]=0;c[z+4>>2]=0}else if((p|0)==7){z=o;y=f+(d+4)|0;q=lrc(e|0)|0;mJb(o);c[y>>2]=0;if((q&1|0)!=0){n=-22;i=g;return n|0}x=(q|0)/2|0;q=hJb(x)|0;k=a[e]|0;a:do{if(!(k<<24>>24==0)){w=q;u=e;v=k;while(1){j=u+1|0;r=v<<24>>24;do{if((v-48&255)>>>0<10>>>0){A=r-48|0}else{if((v-97&255)>>>0<6>>>0){A=r-87|0;break}else{A=(v-65&255)>>>0<6>>>0?r-55|0:-1;break}}}while(0);r=u+2|0;B=a[j]|0;C=B<<24>>24;do{if((B-48&255)>>>0<10>>>0){D=C-48|0}else{if((B-97&255)>>>0<6>>>0){D=C-87|0;break}else{D=(B-65&255)>>>0<6>>>0?C-55|0:-1;break}}}while(0);if((D|A|0)<0){break}a[w]=D|A<<4;C=a[r]|0;if(C<<24>>24==0){break a}else{w=w+1|0;u=r;v=C}}kJb(q);n=-22;i=g;return n|0}}while(0);c[z>>2]=q;c[y>>2]=x;n=0;i=g;return n|0}else if((p|0)==1146442272){x=o;if(!l){c[x>>2]=0;c[x+4>>2]=0;n=0;i=g;return n|0}l=iKb(x,e,1)|0;if((l|0)>=0){n=l;i=g;return n|0}KIb(b,16,2409120,(s=i,i=i+8|0,c[s>>2]=e,s)|0);i=s;n=l;i=g;return n|0}else if((p|0)==1397316165){l=o;do{if((e|0)!=0){if((irc(e,2577856)|0)==0){break}x=bKb(l,f+(d+4)|0,e)|0;if((x|0)>=0){n=x;i=g;return n|0}KIb(b,16,2130808,(s=i,i=i+8|0,c[s>>2]=e,s)|0);i=s;n=x;i=g;return n|0}}while(0);c[f+(d+4)>>2]=0;c[l>>2]=0;n=0;i=g;return n|0}else if((p|0)==1129270354){if((e|0)==0){n=0;i=g;return n|0}l=dKb(o,e,-1,b)|0;if((l|0)>=0){n=l;i=g;return n|0}KIb(b,16,2140576,(s=i,i=i+8|0,c[s>>2]=e,s)|0);i=s;n=l;i=g;return n|0}else if((p|0)==0|(p|0)==1|(p|0)==2|(p|0)==4|(p|0)==3|(p|0)==6){n=GJb(b,f,m,e,o)|0;i=g;return n|0}KIb(b,16,2348976,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;n=-22;i=g;return n|0}function FJb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+8|0;j=h|0;if((a|0)==0){k=0;i=h;return k|0}l=a;m=c[l>>2]|0;if((m|0)==0){k=0;i=h;return k|0}a:do{if((f&1|0)!=0){if((f&2|0)==0){n=0;o=m;while(1){p=c[o+24>>2]|0;if((p|0)==0){break a}q=We[p&2047](a,n)|0;if((q|0)==0){break a}p=FJb(q,b,d,e,f,g)|0;if((p|0)!=0){k=p;break}n=q;o=c[l>>2]|0}i=h;return k|0}c[j>>2]=0;o=m+28|0;n=j;while(1){q=c[o>>2]|0;if((q|0)==0){r=7;break}p=ve[q&4095](c[j>>2]|0)|0;c[j>>2]=p;if((p|0)==0){break a}p=FJb(n,b,d,e,f,0)|0;if((p|0)!=0){k=p;r=31;break}}if((r|0)==7){c[j>>2]=0;break}else if((r|0)==31){i=h;return k|0}}}while(0);j=c[l>>2]|0;l=(j|0)==0;m=(d|0)==0;n=j+8|0;j=0;while(1){o=(j|0)!=0;do{if(o|l){r=18}else{p=c[n>>2]|0;if((p|0)==0){r=18;break}q=c[p>>2]|0;if((q|0)==0){r=18}else{s=p;t=q}}}while(0);if((r|0)==18){r=0;if(!o){k=0;r=31;break}q=j+48|0;p=c[q>>2]|0;if((p|0)==0|(q|0)==0){k=0;r=31;break}else{s=q;t=p}}if((irc(t,b)|0)!=0){j=s;continue}if((c[s+40>>2]&e|0)!=(e|0)){j=s;continue}p=(c[s+12>>2]|0)==128;if(m){if(p){j=s;continue}else{r=27;break}}if(!p){j=s;continue}p=c[s+44>>2]|0;if((p|0)==0){j=s;continue}if((irc(p,d)|0)==0){r=27;break}else{j=s}}if((r|0)==27){if((g|0)==0){k=s;i=h;return k|0}if((f&2|0)==0){c[g>>2]=a;k=s;i=h;return k|0}else{c[g>>2]=0;k=s;i=h;return k|0}}else if((r|0)==31){i=h;return k|0}return 0}function GJb(b,d,e,f,j){b=b|0;d=d|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0.0;k=i;i=i+288|0;l=k|0;m=k+8|0;n=k+24|0;o=k+280|0;p=Bd(f|0,2129288,(q=i,i=i+24|0,c[q>>2]=l,c[q+8>>2]=m,c[q+16>>2]=k+16,q)|0)|0;i=q;do{if((p|0)==2){r=c[l>>2]|0;s=UJb(b,e,j,1.0,c[m>>2]|0,r,(r|0)<0|0?-1:0)|0;if((s|0)>-1){t=s}else{break}i=k;return t|0}}while(0);m=e+12|0;l=n|0;p=e+44|0;s=(d|0)==0;r=e+16|0;u=e+16|0;v=e+32|0;w=e+24|0;x=j;y=j;z=j;A=j;B=j+4|0;C=d;d=f;D=0;E=a[f]|0;a:while(1){do{if((E<<24>>24|0)==43|(E<<24>>24|0)==45){if((c[m>>2]|0)==0){G=d+1|0;H=E<<24>>24;I=0;break}if((D|0)!=0){G=d;H=0;I=0;break}a[l]=E;G=d;H=0;I=1}else{G=d;H=0;I=0}}while(0);f=I;while(1){J=a[G+f|0]|0;if((J<<24>>24|0)==0|(J<<24>>24|0)==43|(J<<24>>24|0)==45){K=f;break}a[n+f|0]=J;J=f+1|0;if(J>>>0<255>>>0){f=J}else{K=J;break}}a[n+K|0]=0;f=c[p>>2]|0;b:do{if(s){L=28}else{J=c[C>>2]|0;if((J|0)==0){L=28;break}M=(f|0)==0;N=J+8|0;J=0;while(1){O=(J|0)!=0;do{if(O){L=19}else{P=c[N>>2]|0;if((P|0)==0){L=28;break b}S=c[P>>2]|0;if((S|0)!=0){T=P;U=S;break}if(O){L=19}else{L=28;break b}}}while(0);if((L|0)==19){L=0;O=J+48|0;S=c[O>>2]|0;if((S|0)==0|(O|0)==0){L=28;break b}else{T=O;U=S}}if((irc(U,l)|0)!=0){J=T;continue}V=(c[T+12>>2]|0)==128;if(M){if(V){J=T;continue}else{break}}if(!V){J=T;continue}S=c[T+44>>2]|0;if((S|0)==0){J=T;continue}if((irc(S,f)|0)==0){break}else{J=T}}if((T|0)==0|V^1){L=28;break}J=T+16|0;h[o>>3]=+((c[J>>2]|0)>>>0)+ +(c[J+4>>2]|0)*4294967296.0}}while(0);do{if((L|0)==28){L=0;if((irc(l,2127792)|0)==0){f=c[m>>2]|0;if((f|0)==2|(f|0)==128|(f|0)==0|(f|0)==1){W=+((c[u>>2]|0)>>>0)+ +(c[u+4>>2]|0)*4294967296.0}else{W=+h[r>>3]}h[o>>3]=W;break}if((irc(l,2125944)|0)==0){h[o>>3]=+h[v>>3];break}if((irc(l,2123512)|0)==0){h[o>>3]=+h[w>>3];break}if((irc(l,2577856)|0)==0){h[o>>3]=0.0;break}if((irc(l,2117160)|0)==0){h[o>>3]=-1.0;break}else{X=ZGb(o,l,1637928,1637896,0,0,0,0,0,0,b)|0;if((X|0)<0){L=42;break a}else{break}}}}while(0);f=c[m>>2]|0;do{if((f|0)==128){Y=0;Z=1;_=+h[r>>3];$=1.0;L=53}else if((f|0)==1346784596|(f|0)==1397116244|(f|0)==1){J=c[x>>2]|0;Y=(J|0)<0|0?-1:0;Z=J;_=1.0;$=1.0;L=53}else if((f|0)==1128811585|(f|0)==1146442272|(f|0)==2){Y=c[y+4>>2]|0;Z=c[y>>2]|0;_=1.0;$=1.0;L=53}else if((f|0)==4){Y=0;Z=1;_=+g[z>>2];$=1.0;L=53}else if((f|0)==3){Y=0;Z=1;_=+h[A>>3];$=1.0;L=53}else if((f|0)==6){J=c[x>>2]|0;Y=(J|0)<0|0?-1:0;Z=J;_=1.0;$=+(c[B>>2]|0);L=53}else if((f|0)==0){J=c[x>>2]|0;M=0;if((H|0)==43){aa=+h[o>>3];h[o>>3]=+((~~+aa>>>0|J)>>>0)+ +((F=+aa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0)|M|0)*4294967296.0;break}else if((H|0)==45){aa=+h[o>>3];h[o>>3]=+((J&~(~~+aa>>>0))>>>0)+ +(M&~(F=+aa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0)|0)*4294967296.0;break}else{break}}else{Y=0;Z=1;_=1.0;$=1.0;L=53}}while(0);do{if((L|0)==53){L=0;if((H|0)==43){h[o>>3]=+(D|0)*_*(+(Z>>>0)+ +(Y|0)*4294967296.0)/$+ +h[o>>3];break}else if((H|0)==45){h[o>>3]=+(D|0)*_*(+(Z>>>0)+ +(Y|0)*4294967296.0)/$- +h[o>>3];break}else{break}}}while(0);f=UJb(b,e,j,+h[o>>3],1,1,0)|0;if((f|0)<0){t=f;L=58;break}f=G+K|0;M=a[f]|0;if(M<<24>>24==0){t=0;L=58;break}else{d=f;D=1;E=M}}if((L|0)==42){KIb(b,16,2114328,(q=i,i=i+8|0,c[q>>2]=G,q)|0);i=q;t=X;i=k;return t|0}else if((L|0)==58){i=k;return t|0}return 0}function HJb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;do{if((b|0)==0){f=-22}else{if((c[b+12>>2]|0)!=0){f=-22;break}if((c[b+40>>2]&128|0)!=0){f=-22;break}f=GJb(a,a,b,d,e)|0}}while(0);return f|0}function IJb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+8|0;h=g|0;j=FJb(a,b,0,0,f,h)|0;do{if((j|0)==0){k=-1414549496}else{f=c[h>>2]|0;if((f|0)==0){k=-1414549496;break}if((c[j+40>>2]&128|0)!=0){k=-22;break}k=UJb(a,j,f+(c[j+8>>2]|0)|0,1.0,1,d,e)|0}}while(0);i=g;return k|0}function JJb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+8|0;h=g|0;j=FJb(a,b,0,0,f,h)|0;f=c[h>>2]|0;do{if((j|0)==0|(f|0)==0){k=-1414549496}else{if((c[j+12>>2]|0)!=7){k=-22;break}if((c[j+40>>2]&128|0)!=0){k=-22;break}b=(e|0)!=0;if(b){a=hJb(e)|0;if((a|0)==0){k=-12;break}l=a;m=c[h>>2]|0}else{l=0;m=f}a=c[j+8>>2]|0;n=m+a|0;kJb(c[n>>2]|0);c[n>>2]=l;c[m+(a+4)>>2]=e;if(!b){k=0;break}nrc(l|0,d|0,e)|0;k=0}}while(0);i=g;return k|0}function KJb(a,b,d,e,f,g,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0.0;k=i;i=i+8|0;l=k|0;m=FJb(a,b,0,0,e,l)|0;e=c[a>>2]|0;n=c[l>>2]|0;if((m|0)==0|(n|0)==0){o=-1414549496;i=k;return o|0}if((c[m+12>>2]|0)!=(f|0)){KIb(a,16,2150096,(p=i,i=i+16|0,c[p>>2]=b,c[p+8>>2]=g,p)|0);i=p;o=-22;i=k;return o|0}f=c[e+12>>2]|0;if((f|0)!=0&(f|0)<3410788){q=j-1|0;r=-1}else{s=+h[m+24>>3];if(s>-1.0){t=~~s}else{t=-1}s=+h[m+32>>3];u=+(j-1|0);q=~~(s>u?u:s);r=t}if((r|0)>(d|0)|(q|0)<(d|0)){KIb(a,16,2147296,(p=i,i=i+40|0,c[p>>2]=d,c[p+8>>2]=b,c[p+16>>2]=g,c[p+24>>2]=r,c[p+32>>2]=q,p)|0);i=p;o=-34;i=k;return o|0}else{c[n+(c[m+8>>2]|0)>>2]=d;o=0;i=k;return o|0}return 0}function LJb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return KJb(a,b,c,d,1397116244,2139472,10)|0}function MJb(b,e,f,j){b=b|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=i;i=i+136|0;l=k|0;m=k+8|0;n=FJb(b,e,0,0,f,l)|0;f=c[l>>2]|0;if((n|0)==0|(f|0)==0){o=-1414549496;i=k;return o|0}l=c[n+8>>2]|0;e=n+12|0;do{if((l|0)<1){if((c[e>>2]|0)==128){break}else{o=-1414549496}i=k;return o|0}}while(0);b=f+l|0;p=m|0;a[p]=0;m=c[e>>2]|0;if((m|0)==1146442272){e=b;q=c[e>>2]|0;r=c[e+4>>2]|0;e=Crc(q,r,-694967296,0)|0;s=G;t=Crc(q,r,6e7,0)|0;u=Drc(t,G,60,0)|0;t=Crc(q,r,1e6,0)|0;v=Drc(t,G,60,0)|0;t=Drc(q,r,1e6,0)|0;r=Rb(p|0,128,2475128,(w=i,i=i+40|0,c[w>>2]=e,c[w+8>>2]=s,c[w+16>>2]=u,c[w+24>>2]=v,c[w+32>>2]=t,w)|0)|0;i=w;x=r}else if((m|0)==1346784596){r=mKb(c[b>>2]|0)|0;t=Rb(p|0,128,2486776,(w=i,i=i+8|0,c[w>>2]=(r|0)!=0?r:2577856,w)|0)|0;i=w;x=t}else if((m|0)==1128811585){t=b;r=c[t+4>>2]|0;v=Rb(p|0,128,2456184,(w=i,i=i+16|0,c[w>>2]=c[t>>2],c[w+8>>2]=r,w)|0)|0;i=w;x=v}else if((m|0)==7){v=c[f+(l+4)>>2]|0;r=v;t=((v|0)<0|0?-1:0)<<1|r>>>31;u=0;if(t>>>0>u>>>0|t>>>0==u>>>0&(r<<1|0>>>31)>>>0>2147483647>>>0){o=-22;i=k;return o|0}r=hJb(v<<1|1)|0;c[j>>2]=r;if((r|0)==0){o=-12;i=k;return o|0}u=c[b>>2]|0;if((v|0)>0){y=0;z=r}else{o=0;i=k;return o|0}while(1){Rb(z+(y<<1)|0,3,2527792,(w=i,i=i+8|0,c[w>>2]=d[u+y|0]|0,w)|0)|0;i=w;r=y+1|0;if((r|0)>=(v|0)){o=0;break}y=r;z=c[j>>2]|0}i=k;return o|0}else if((m|0)==1129270354){z=c[f+(l+4)>>2]|0;y=c[f+(l+8)>>2]|0;v=c[f+(l+12)>>2]|0;u=Rb(p|0,128,2466320,(w=i,i=i+32|0,c[w>>2]=c[b>>2],c[w+8>>2]=z,c[w+16>>2]=y,c[w+24>>2]=v,w)|0)|0;i=w;x=u}else if((m|0)==1397116244){u=LKb(c[b>>2]|0)|0;v=Rb(p|0,128,2486776,(w=i,i=i+8|0,c[w>>2]=(u|0)!=0?u:2577856,w)|0)|0;i=w;x=v}else if((m|0)==1397316165){v=c[f+(l+4)>>2]|0;u=Rb(p|0,128,2499192,(w=i,i=i+16|0,c[w>>2]=c[b>>2],c[w+8>>2]=v,w)|0)|0;i=w;x=u}else if((m|0)==0){u=Rb(p|0,128,2633936,(w=i,i=i+8|0,c[w>>2]=c[b>>2],w)|0)|0;i=w;x=u}else if((m|0)==2){u=b;v=c[u+4>>2]|0;y=Rb(p|0,128,2583632,(w=i,i=i+16|0,c[w>>2]=c[u>>2],c[w+8>>2]=v,w)|0)|0;i=w;x=y}else if((m|0)==1){y=Rb(p|0,128,2610184,(w=i,i=i+8|0,c[w>>2]=c[b>>2],w)|0)|0;i=w;x=y}else if((m|0)==128){y=Rb(p|0,128,2563080,(w=i,i=i+8|0,h[w>>3]=+h[n+16>>3],w)|0)|0;i=w;x=y}else if((m|0)==5){y=c[b>>2]|0;if((y|0)==0){A=rJb(10230608)|0}else{A=rJb(y)|0}c[j>>2]=A;o=0;i=k;return o|0}else if((m|0)==1448231252|(m|0)==6){A=c[f+(l+4)>>2]|0;l=Rb(p|0,128,2545560,(w=i,i=i+16|0,c[w>>2]=c[b>>2],c[w+8>>2]=A,w)|0)|0;i=w;x=l}else if((m|0)==4){l=Rb(p|0,128,2563080,(w=i,i=i+8|0,h[w>>3]=+g[b>>2],w)|0)|0;i=w;x=l}else if((m|0)==3){m=Rb(p|0,128,2563080,(w=i,i=i+8|0,h[w>>3]=+h[b>>3],w)|0)|0;i=w;x=m}else{o=-22;i=k;return o|0}if(x>>>0>127>>>0){o=-22;i=k;return o|0}c[j>>2]=rJb(p)|0;o=0;i=k;return o|0}function NJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0,v=0.0;if((a|0)==0){e=-1;f=-1;return(G=e,f)|0}i=c[a>>2]|0;if((i|0)==0){e=-1;f=-1;return(G=e,f)|0}j=i+8|0;i=0;a:while(1){k=(i|0)!=0;do{if(k){l=8}else{m=c[j>>2]|0;if((m|0)==0){e=-1;f=-1;l=23;break a}n=c[m>>2]|0;if((n|0)!=0){o=m;p=n;break}if(k){l=8}else{e=-1;f=-1;l=23;break a}}}while(0);if((l|0)==8){l=0;k=i+48|0;n=c[k>>2]|0;if((n|0)==0|(k|0)==0){e=-1;f=-1;l=23;break}else{o=k;p=n}}if((irc(p,b)|0)!=0){i=o;continue}q=c[o+12>>2]|0;if((q|0)==128){i=o}else{l=11;break}}if((l|0)==11){if((o|0)==0){e=-1;f=-1;return(G=e,f)|0}i=c[o+8>>2]|0;b=a+i|0;if((d|0)!=0){c[d>>2]=o}if((q|0)==6){d=c[b>>2]|0;r=+(c[a+(i+4)>>2]|0);s=1.0;t=(d|0)<0|0?-1:0;u=d}else if((q|0)==1346784596|(q|0)==1397116244|(q|0)==1){d=c[b>>2]|0;r=1.0;s=1.0;t=(d|0)<0|0?-1:0;u=d}else if((q|0)==1128811585|(q|0)==1146442272|(q|0)==2){d=b;r=1.0;s=1.0;t=c[d+4>>2]|0;u=c[d>>2]|0}else if((q|0)==0){r=1.0;s=1.0;t=0;u=c[b>>2]|0}else if((q|0)==4){r=1.0;s=+g[b>>2];t=0;u=1}else if((q|0)==3){r=1.0;s=+h[b>>3];t=0;u=1}else if((q|0)==128){r=1.0;s=+h[o+16>>3];t=0;u=1}else{e=-1;f=-1;return(G=e,f)|0}v=s*(+(u>>>0)+ +(t|0)*4294967296.0)/r;e=(F=+v,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);f=~~+v>>>0;return(G=e,f)|0}else if((l|0)==23){return(G=e,f)|0}return 0}function OJb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0,q=0,r=0.0;f=i;i=i+8|0;j=f|0;k=FJb(a,b,0,0,d,j)|0;if((k|0)==0){l=-1;i=f;return l|0}d=c[j>>2]|0;if((d|0)==0){l=-1;i=f;return l|0}j=c[k+8>>2]|0;b=d+j|0;a=c[k+12>>2]|0;if((a|0)==1346784596|(a|0)==1397116244|(a|0)==1){m=c[b>>2]|0;n=1.0;o=1.0;p=(m|0)<0|0?-1:0;q=m}else if((a|0)==4){n=1.0;o=+g[b>>2];p=0;q=1}else if((a|0)==1128811585|(a|0)==1146442272|(a|0)==2){m=b;n=1.0;o=1.0;p=c[m+4>>2]|0;q=c[m>>2]|0}else if((a|0)==0){n=1.0;o=1.0;p=0;q=c[b>>2]|0}else if((a|0)==128){n=1.0;o=+h[k+16>>3];p=0;q=1}else if((a|0)==3){n=1.0;o=+h[b>>3];p=0;q=1}else if((a|0)==6){a=c[b>>2]|0;n=+(c[d+(j+4)>>2]|0);o=1.0;p=(a|0)<0|0?-1:0;q=a}else{l=-22;i=f;return l|0}r=o*(+(q>>>0)+ +(p|0)*4294967296.0)/n;p=(F=+r,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[e>>2]=~~+r>>>0;c[e+4>>2]=p;l=0;i=f;return l|0}function PJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0,D=0,E=0.0;if((a|0)==0){e=0;return e|0}f=c[a>>2]|0;i=(f|0)==0;if(i){e=0;return e|0}j=f+8|0;k=0;a:while(1){l=(k|0)!=0;do{if(l){m=8}else{n=c[j>>2]|0;if((n|0)==0){o=1;p=0;break a}q=c[n>>2]|0;if((q|0)!=0){r=n;s=q;break}if(l){m=8}else{o=1;p=0;break a}}}while(0);if((m|0)==8){m=0;l=k+48|0;q=c[l>>2]|0;if((q|0)==0|(l|0)==0){o=1;p=0;break}else{r=l;s=q}}if((irc(s,b)|0)!=0){k=r;continue}if((c[r+12>>2]|0)==128){k=r}else{m=11;break}}do{if((m|0)==11){if((r|0)==0){o=1;p=0;break}o=0;p=c[r+44>>2]|0}}while(0);if(i){e=0;return e|0}i=(p|0)==0;r=f+8|0;f=0;b:while(1){k=(f|0)!=0;do{if(k){m=19}else{s=c[r>>2]|0;if((s|0)==0){e=0;m=43;break b}j=c[s>>2]|0;if((j|0)!=0){t=s;u=j;break}if(k){m=19}else{e=0;m=43;break b}}}while(0);if((m|0)==19){m=0;k=f+48|0;j=c[k>>2]|0;if((j|0)==0|(k|0)==0){e=0;m=43;break}else{t=k;u=j}}if((irc(u,d)|0)!=0){f=t;continue}v=c[t+12>>2]|0;j=(v|0)==128;if(i){if(j){f=t;continue}else{m=26;break}}if(!j){f=t;continue}j=c[t+44>>2]|0;if((j|0)==0){f=t;continue}if((irc(j,p)|0)==0){m=26;break}else{f=t}}if((m|0)==26){if((v|0)==128&(((t|0)==0|o)^1)){w=0}else{e=0;return e|0}c:while(1){o=(w|0)!=0;do{if(o){m=31}else{v=c[r>>2]|0;if((v|0)==0){e=0;m=43;break c}f=c[v>>2]|0;if((f|0)!=0){x=v;y=f;break}if(o){m=31}else{e=0;m=43;break c}}}while(0);if((m|0)==31){m=0;o=w+48|0;f=c[o>>2]|0;if((f|0)==0|(o|0)==0){e=0;m=43;break}else{x=o;y=f}}if((irc(y,b)|0)!=0){w=x;continue}z=c[x+12>>2]|0;if((z|0)==128){w=x}else{m=34;break}}if((m|0)==34){if((x|0)==0){e=0;return e|0}w=c[x+8>>2]|0;x=a+w|0;if((z|0)==4){A=1.0;B=+g[x>>2];C=0;D=1}else if((z|0)==3){A=1.0;B=+h[x>>3];C=0;D=1}else if((z|0)==6){b=c[x>>2]|0;A=+(c[a+(w+4)>>2]|0);B=1.0;C=(b|0)<0|0?-1:0;D=b}else if((z|0)==1128811585|(z|0)==1146442272|(z|0)==2){b=x;A=1.0;B=1.0;C=c[b+4>>2]|0;D=c[b>>2]|0}else if((z|0)==0){A=1.0;B=1.0;C=0;D=c[x>>2]|0}else if((z|0)==1346784596|(z|0)==1397116244|(z|0)==1){z=c[x>>2]|0;A=1.0;B=1.0;C=(z|0)<0|0?-1:0;D=z}else{e=0;return e|0}E=B*(+(D>>>0)+ +(C|0)*4294967296.0)/A;C=~~+E>>>0;F=+E,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0;e=C&c[t+16>>2];return e|0}else if((m|0)==43){return e|0}}else if((m|0)==43){return e|0}return 0}function QJb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;if((a|0)==0){g=-1;i=f;return g|0}KIb(b,32,2417848,(h=i,i=i+8|0,c[h>>2]=c[c[a>>2]>>2],h)|0);i=h;RJb(a,b,0,d,e);g=0;i=f;return g|0}function RJb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;j=g|0;k=g+8|0;l=a;m=(d|0)==0;n=j;o=k|0;p=k+4|0;q=0;while(1){r=c[l>>2]|0;s=(q|0)!=0;do{if(s|(r|0)==0){t=5}else{u=c[r+8>>2]|0;if((u|0)==0){t=5;break}v=c[u>>2]|0;if((v|0)==0){t=5}else{w=u;x=v}}}while(0);if((t|0)==5){t=0;if(!s){t=62;break}r=q+48|0;v=c[r>>2]|0;if((v|0)==0|(r|0)==0){t=62;break}else{w=r;x=v}}v=w+40|0;r=c[v>>2]|0;if((r&e|0)==0){q=w;continue}if((r&f|0)!=0){q=w;continue}u=w+12|0;y=(c[u>>2]|0)==128;if(m){if(y){q=w;continue}KIb(b,32,2316128,(z=i,i=i+16|0,c[z>>2]=(r&65536|0)!=0?10230608:2311728,c[z+8>>2]=x,z)|0);i=z}else{if(!y){q=w;continue}if((irc(d,c[w+44>>2]|0)|0)!=0){q=w;continue}KIb(b,32,2321112,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z}y=c[u>>2]|0;if((y|0)==1129270354){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2230968,z)|0);i=z}else if((y|0)==1128811585){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2227104,z)|0);i=z}else if((y|0)==1397116244){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2239376,z)|0);i=z}else if((y|0)==5){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2271400,z)|0);i=z}else if((y|0)==1346784596){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2249744,z)|0);i=z}else if((y|0)==1448231252){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2254952,z)|0);i=z}else if((y|0)==6){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2266816,z)|0);i=z}else if((y|0)==7){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2263256,z)|0);i=z}else if((y|0)==1397316165){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2259376,z)|0);i=z}else if((y|0)==1146442272){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2234480,z)|0);i=z}else if((y|0)==0){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2301032,z)|0);i=z}else if((y|0)==3){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2280248,z)|0);i=z}else if((y|0)==2){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2284008,z)|0);i=z}else if((y|0)==4){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2276048,z)|0);i=z}else if((y|0)==1){KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=2289896,z)|0);i=z}else{KIb(b,32,2307064,(z=i,i=i+8|0,c[z>>2]=10230608,z)|0);i=z}KIb(b,32,2222400,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&1|0)!=0?69:46,z)|0);i=z;KIb(b,32,2222400,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&2|0)!=0?68:46,z)|0);i=z;KIb(b,32,2222400,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&65536|0)!=0?70:46,z)|0);i=z;KIb(b,32,2222400,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&16|0)!=0?86:46,z)|0);i=z;KIb(b,32,2222400,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&8|0)!=0?65:46,z)|0);i=z;KIb(b,32,2222400,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&32|0)!=0?83:46,z)|0);i=z;KIb(b,32,2222400,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&64|0)!=0?88:46,z)|0);i=z;KIb(b,32,2222400,(z=i,i=i+8|0,c[z>>2]=(c[v>>2]&128|0)!=0?82:46,z)|0);i=z;v=c[w+4>>2]|0;if((v|0)!=0){KIb(b,32,2218768,(z=i,i=i+8|0,c[z>>2]=v,z)|0);i=z}v=c[l>>2]|0;if((c[v+12>>2]|0)>3410688){A=c[v+40>>2]|0}else{A=0}if((hf[((A|0)==0?492:A)&1023](j,a,c[w>>2]|0,2)|0)>-1){a:do{switch(c[u>>2]|0){case 1:case 2:case 3:case 4:case 6:{v=c[j>>2]|0;if((c[v+4>>2]|0)>0){B=0}else{C=v;break a}while(1){KIb(b,32,2215840,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;$Jb(b,+h[(c[(c[c[j>>2]>>2]|0)+(B<<2)>>2]|0)+8>>3]);KIb(b,32,2213184,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;$Jb(b,+h[(c[(c[c[j>>2]>>2]|0)+(B<<2)>>2]|0)+16>>3]);KIb(b,32,2211e3,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;v=B+1|0;y=c[j>>2]|0;if((v|0)<(c[y+4>>2]|0)){B=v}else{C=y;break}}break};default:{C=c[j>>2]|0}}}while(0);s=C+4|0;y=c[s>>2]|0;if((y|0)>0){v=C|0;r=0;D=y;while(1){y=c[(c[v>>2]|0)+(r<<2)>>2]|0;if((y|0)==0){E=D}else{mJb(y);mJb((c[v>>2]|0)+(r<<2)|0);E=c[s>>2]|0}y=r+1|0;if((y|0)<(E|0)){r=y;D=E}else{break}}}mJb(C);mJb(n)}D=c[u>>2]|0;if((D|0)==1129270354|(D|0)==1397316165|(D|0)==5|(D|0)==1448231252){if((c[w+16>>2]|0)!=0){t=49}}else if(!((D|0)==128|(D|0)==7)){t=49}if((t|0)==49){t=0;KIb(b,32,2207328,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=c[u>>2]|0;if((D|0)==1146442272|(D|0)==1|(D|0)==2){r=w+16|0;$Jb(b,+((c[r>>2]|0)>>>0)+ +(c[r+4>>2]|0)*4294967296.0)}else if((D|0)==1129270354|(D|0)==1397316165|(D|0)==5|(D|0)==1448231252){KIb(b,32,2194832,(z=i,i=i+8|0,c[z>>2]=c[w+16>>2],z)|0);i=z}else if((D|0)==6){AKb(k,+h[w+16>>3],2147483647);r=c[p>>2]|0;KIb(b,32,2545560,(z=i,i=i+16|0,c[z>>2]=c[o>>2],c[z+8>>2]=r,z)|0);i=z}else if((D|0)==1346784596){r=mKb(c[w+16>>2]|0)|0;KIb(b,32,2486776,(z=i,i=i+8|0,c[z>>2]=(r|0)!=0?r:2577856,z)|0);i=z}else if((D|0)==1397116244){r=LKb(c[w+16>>2]|0)|0;KIb(b,32,2486776,(z=i,i=i+8|0,c[z>>2]=(r|0)!=0?r:2577856,z)|0);i=z}else if((D|0)==0){r=w+16|0;s=c[r+4>>2]|0;KIb(b,32,2198568,(z=i,i=i+16|0,c[z>>2]=c[r>>2],c[z+8>>2]=s,z)|0);i=z}else if((D|0)==3|(D|0)==4){$Jb(b,+h[w+16>>3])}else if((D|0)==1128811585){D=w+16|0;s=c[D+4>>2]|0;KIb(b,32,2456184,(z=i,i=i+16|0,c[z>>2]=c[D>>2],c[z+8>>2]=s,z)|0);i=z}KIb(b,32,2211e3,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}KIb(b,32,2192416,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;s=c[w+44>>2]|0;if((s|0)==0){q=w;continue}if((c[u>>2]|0)==128){q=w;continue}RJb(a,b,s,e,f);q=w}if((t|0)==62){i=g;return}}function SJb(a){a=a|0;TJb(a,0,0);return}function TJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+8|0;f=e|0;g=a;j=c[g>>2]|0;k=f|0;l=f+4|0;m=j+12|0;n=0;o=j;while(1){j=(n|0)!=0;do{if(j|(o|0)==0){p=5}else{q=c[o+8>>2]|0;if((q|0)==0){p=5;break}r=c[q>>2]|0;if((r|0)==0){p=5}else{s=q;t=r}}}while(0);if((p|0)==5){p=0;if(!j){p=32;break}r=n+48|0;q=c[r>>2]|0;if((q|0)==0|(r|0)==0){p=32;break}else{s=r;t=q}}q=c[s+8>>2]|0;r=a+q|0;u=c[s+40>>2]|0;a:do{if((u&b|0)==(d|0)&(u&128|0)==0){v=c[s+12>>2]|0;if((v|0)==5){w=c[s+16>>2]|0;mJb(r);c[r>>2]=rJb(w)|0;break}else if((v|0)==0|(v|0)==1|(v|0)==2|(v|0)==1146442272|(v|0)==1128811585){w=s+16|0;UJb(a,s,r,1.0,1,c[w>>2]|0,c[w+4>>2]|0)|0;break}else if((v|0)==1346784596){w=c[m>>2]|0;if((w|0)!=0&(w|0)<3410532){EJb(a,t,c[s+16>>2]|0,0)|0;break}else{w=s+16|0;UJb(a,s,r,1.0,1,c[w>>2]|0,c[w+4>>2]|0)|0;break}}else if((v|0)==1397116244){w=c[m>>2]|0;if((w|0)!=0&(w|0)<3410532){EJb(a,t,c[s+16>>2]|0,0)|0;break}else{w=s+16|0;UJb(a,s,r,1.0,1,c[w>>2]|0,c[w+4>>2]|0)|0;break}}else if((v|0)==128|(v|0)==7){break}else if((v|0)==1129270354){w=c[s+16>>2]|0;if((w|0)==0){break}if((dKb(r,w,-1,a)|0)>=0){break}KIb(a,16,2140576,(x=i,i=i+8|0,c[x>>2]=w,x)|0);i=x;break}else if((v|0)==1397316165){w=c[s+16>>2]|0;y=r;do{if((w|0)!=0){if((irc(w,2577856)|0)==0){break}if((bKb(y,a+(q+4)|0,w)|0)>=0){break a}KIb(a,16,2130808,(x=i,i=i+8|0,c[x>>2]=w,x)|0);i=x;break a}}while(0);c[a+(q+4)>>2]=0;c[y>>2]=0;break}else if((v|0)==3|(v|0)==4){UJb(a,s,r,+h[s+16>>3],1,1,0)|0;break}else if((v|0)==6){AKb(f,+h[s+16>>3],2147483647);w=c[k>>2]|0;UJb(a,s,r,1.0,c[l>>2]|0,w,(w|0)<0|0?-1:0)|0;break}else if((v|0)==1448231252){w=c[s+16>>2]|0;if((w|0)!=0){if((cKb(r,w)|0)>=0){break}}KIb(a,16,2132280,(x=i,i=i+8|0,c[x>>2]=w,x)|0);i=x;break}else{KIb(a,48,2408728,(x=i,i=i+16|0,c[x>>2]=v,c[x+8>>2]=t,x)|0);i=x;break}}}while(0);n=s;o=c[g>>2]|0}if((p|0)==32){i=e;return}}function UJb(a,b,d,e,f,j,k){a=a|0;b=b|0;d=d|0;e=+e;f=f|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0.0;l=i;i=i+8|0;m=l|0;n=m;o=b+12|0;p=c[o>>2]|0;a:do{if((p|0)==0){q=(+(j>>>0)+ +(k|0)*4294967296.0)*e/+(f|0);do{if(!(q<-1.5|q>4294967295.5)){r=ge(+(q*256.0))|0;if(!((r&255|0)==0&(G&0|0)==0)){break}s=c[o>>2]|0;break a}}while(0);r=c[b>>2]|0;KIb(a,16,2326880,(t=i,i=i+16|0,h[t>>3]=q,c[t+8>>2]=r,t)|0);i=t;u=-34;i=l;return u|0}else{v=+h[b+32>>3];w=+(f|0);x=(+(j>>>0)+ +(k|0)*4294967296.0)*e;y=+h[b+24>>3];if(!(w*v<x)){if(!(w*y>x)){s=p;break}}r=c[b>>2]|0;KIb(a,16,2332424,(t=i,i=i+32|0,h[t>>3]=x/w,c[t+8>>2]=r,h[t+16>>3]=y,h[t+24>>3]=v,t)|0);i=t;u=-34;i=l;return u|0}}while(0);if((s|0)==6){v=(+(j>>>0)+ +(k|0)*4294967296.0)*e;if(+(~~e|0)==e){c[d>>2]=~~v;c[d+4>>2]=f;u=0;i=l;return u|0}else{AKb(n,v/+(f|0),16777216);n=d;t=c[m+4>>2]|0;c[n>>2]=c[m>>2];c[n+4>>2]=t;u=0;i=l;return u|0}}else if((s|0)==0|(s|0)==1346784596|(s|0)==1397116244|(s|0)==1){t=ge(+(e/+(f|0)))|0;n=Erc(t,G,j,k)|0;c[d>>2]=n;u=0;i=l;return u|0}else if((s|0)==4){g[d>>2]=(+(j>>>0)+ +(k|0)*4294967296.0)*e/+(f|0);u=0;i=l;return u|0}else if((s|0)==1146442272|(s|0)==1128811585|(s|0)==2){n=ge(+(e/+(f|0)))|0;t=Erc(n,G,j,k)|0;n=d;c[n>>2]=t;c[n+4>>2]=G;u=0;i=l;return u|0}else if((s|0)==3){h[d>>3]=(+(j>>>0)+ +(k|0)*4294967296.0)*e/+(f|0);u=0;i=l;return u|0}else{u=-22;i=l;return u|0}return 0}function VJb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+8|0;k=j|0;l=c[b>>2]|0;c[k>>2]=l;m=l+(ud(l|0,2366640)|0)|0;l=m;while(1){n=a[l]|0;o=n<<24>>24;if(!(((o|32)-97|0)>>>0<26>>>0|(o-48|0)>>>0<10>>>0)){if(!((n<<24>>24|0)==95|(n<<24>>24|0)==47|(n<<24>>24|0)==45|(n<<24>>24|0)==46)){break}}l=l+1|0}n=ud(l|0,2366640)|0;o=a[l+n|0]|0;do{if(o<<24>>24==0){p=9}else{if((_b(d|0,o<<24>>24|0)|0)==0){p=9;break}q=l-m|0;r=hJb(q+1|0)|0;if((r|0)==0){p=9;break}nrc(r|0,m|0,q)|0;a[r+q|0]=0;c[k>>2]=l+(n+1);s=r}}while(0);do{if((p|0)==9){if((f&1|0)==0){t=-22}else{s=0;break}i=j;return t|0}}while(0);f=GFb(k,e)|0;if((f|0)==0){kJb(s);t=-12;i=j;return t|0}else{c[b>>2]=c[k>>2];c[g>>2]=s;c[h>>2]=f;t=0;i=j;return t|0}return 0}function WJb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a;d=0;while(1){e=c[b>>2]|0;f=(d|0)!=0;do{if(f|(e|0)==0){g=5}else{h=c[e+8>>2]|0;if((h|0)==0){g=5;break}if((c[h>>2]|0)==0){g=5}else{i=h}}}while(0);if((g|0)==5){g=0;if(!f){g=9;break}e=d+48|0;if((c[e>>2]|0)==0|(e|0)==0){g=9;break}else{i=e}}e=c[i+12>>2]|0;if(!((e|0)==5|(e|0)==7)){d=i;continue}mJb(a+(c[i+8>>2]|0)|0);d=i}if((g|0)==9){return}}function XJb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;c[e>>2]=0;f=LGb(c[b>>2]|0,10230608,0,2)|0;a:do{if((f|0)==0){g=0}else{h=f;while(1){j=h|0;k=h+4|0;l=EJb(a,c[j>>2]|0,c[k>>2]|0,0)|0;if((l|0)==-1414549496){MGb(e,c[j>>2]|0,c[k>>2]|0,0)|0}else{if((l|0)<0){break}}m=LGb(c[b>>2]|0,10230608,h,2)|0;if((m|0)==0){g=0;break a}else{h=m}}h=c[k>>2]|0;KIb(a,16,2374128,(m=i,i=i+16|0,c[m>>2]=c[j>>2],c[m+8>>2]=h,m)|0);i=m;g=l}}while(0);OGb(b);c[b>>2]=c[e>>2];i=d;return g|0}function YJb(a,b){a=a|0;b=b|0;var d=0,e=0;d=c[a+28>>2]|0;if((d|0)==0){e=0;return e|0}e=ve[d&4095](b)|0;return e|0}function ZJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){e=0;return e|0}f=a+8|0;a=0;a:while(1){g=(a|0)!=0;do{if(g){h=7}else{i=c[f>>2]|0;if((i|0)==0){e=0;h=12;break a}j=c[i>>2]|0;if((j|0)!=0){k=i;l=j;break}if(g){h=7}else{e=0;h=12;break a}}}while(0);if((h|0)==7){h=0;g=a+48|0;j=c[g>>2]|0;if((j|0)==0|(g|0)==0){e=0;h=12;break}else{k=g;l=j}}if((irc(l,d)|0)!=0){a=k;continue}if((c[k+12>>2]|0)==128){a=k}else{h=10;break}}if((h|0)==10){if((k|0)==0){e=0;return e|0}e=b+(c[k+8>>2]|0)|0;return e|0}else if((h|0)==12){return e|0}return 0}function _Jb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;f=pJb(8)|0;g=f;i=pJb(4)|0;j=i;k=pJb(48)|0;l=FJb(b,d,0,0,e,0)|0;c[a>>2]=0;do{if((f|0)==0|(k|0)==0|(i|0)==0|(l|0)==0){m=-12}else{c[f>>2]=j;c[j>>2]=k;c[f+4>>2]=1;c[k+40>>2]=1;e=k+8|0;h[e>>3]=+h[l+24>>3];d=k+16|0;h[d>>3]=+h[l+32>>3];b=c[l+12>>2]|0;if((b|0)==5){h[k+24>>3]=0.0;h[k+32>>3]=1114111.0;h[e>>3]=-1.0;h[d>>3]=2147483647.0}else if((b|0)==1397316165){h[k+24>>3]=0.0;h[k+32>>3]=2097151.0;h[e>>3]=0.0;h[d>>3]=268435455.0}else if((b|0)==1448231252){h[k+24>>3]=1.0;h[k+32>>3]=2147483647.0;h[e>>3]=1.0;h[d>>3]=2147483647.0}else if((b|0)==6){h[k+24>>3]=-2147483648.0;h[k+32>>3]=2147483647.0}else if(!((b|0)==1|(b|0)==2|(b|0)==1346784596|(b|0)==1397116244|(b|0)==4|(b|0)==3|(b|0)==1146442272|(b|0)==1129270354|(b|0)==1128811585)){m=-38;break}c[a>>2]=g;n=0;return n|0}}while(0);kJb(f);kJb(k);kJb(i);n=m;return n|0}function $Jb(a,b){a=a|0;b=+b;var d=0,e=0;d=i;if(b==2147483647.0){KIb(a,32,2189928,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-2147483648.0){KIb(a,32,2187384,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==4294967295.0){KIb(a,32,2184840,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==9223372036854776000.0){KIb(a,32,2182600,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-9223372036854776000.0){KIb(a,32,2180528,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==3.4028234663852886e+38){KIb(a,32,2178368,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==1.1754943508222875e-38){KIb(a,32,2175048,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-3.4028234663852886e+38){KIb(a,32,2167048,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-1.1754943508222875e-38){KIb(a,32,2163632,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==1.7976931348623157e+308){KIb(a,32,2161616,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==2.2250738585072014e-308){KIb(a,32,2159568,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-1.7976931348623157e+308){KIb(a,32,2157552,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}if(b==-2.2250738585072014e-308){KIb(a,32,2155968,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}else{KIb(a,32,2154208,(e=i,i=i+8|0,h[e>>3]=b,e)|0);i=e;i=d;return}}function aKb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+24|0;j=g+8|0;k=g+16|0;l=a|0;m=a+4|0;n=Bd(b|0,2407952,(o=i,i=i+24|0,c[o>>2]=l,c[o+8>>2]=m,c[o+16>>2]=g,o)|0)|0;i=o;if((n|0)==2){n=c[l>>2]|0;o=c[m>>2]|0;xKb(l,m,n,(n|0)<0|0?-1:0,o,(o|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;p=0;i=g;return p|0}o=ZGb(j,b,0,0,0,0,0,0,0,e,f)|0;if((o|0)<0){p=o;i=g;return p|0}AKb(k,+h[j>>3],d);d=a;a=c[k+4>>2]|0;c[d>>2]=c[k>>2];c[d+4>>2]=a;p=0;i=g;return p|0}function bKb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+8|0;g=f|0;h=0;while(1){if((h|0)>=49){j=5;break}if((irc(c[257408+(h*12|0)>>2]|0,e)|0)==0){j=4;break}else{h=h+1|0}}do{if((j|0)==4){k=c[257416+(h*12|0)>>2]|0;l=c[257412+(h*12|0)>>2]|0}else if((j|0)==5){if((h|0)!=49){m=-22;i=f;return m|0}n=rb(e|0,g|0,10)|0;o=c[g>>2]|0;if((a[o]|0)==0){p=o}else{q=o+1|0;c[g>>2]=q;p=q}q=rb(p|0,g|0,10)|0;if((a[c[g>>2]|0]|0)==0){k=q;l=n;break}else{m=-22}i=f;return m|0}}while(0);if((l|0)<1|(k|0)<1){m=-22;i=f;return m|0}c[b>>2]=l;c[d>>2]=k;m=0;i=f;return m|0}function cKb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=0;while(1){if((d|0)>=8){break}if((irc(c[258e3+(d*12|0)>>2]|0,b)|0)==0){e=4;break}else{d=d+1|0}}if((e|0)==4){e=258004+(d*12|0)|0;d=a;f=c[e+4>>2]|0;c[d>>2]=c[e>>2];c[d+4>>2]=f;g=0;return g|0}f=aKb(a,b,1001e3,56,0)|0;if((f|0)<0){g=f;return g|0}if((c[a>>2]|0)<1){g=-22;return g|0}else{return((c[a+4>>2]|0)<1?-22:0)|0}return 0}function dKb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0;g=i;i=i+144|0;h=g|0;j=g+136|0;if((a[d]|0)==35){k=1}else{l=(krc(d,2577664,2)|0)==0;k=l?2:0}if((e|0)<0){m=lrc(d|0)|0}else{m=e}e=g+8|0;l=m-k+1|0;CFb(e,d+k|0,l>>>0>128>>>0?128:l)|0;l=_b(e|0,64)|0;c[h>>2]=l;if((l|0)==0){n=0}else{m=l+1|0;c[h>>2]=m;a[l]=0;n=m}m=lrc(e|0)|0;l=b+3|0;a[l]=-1;a:do{if((IFb(e,2435512)|0)==0){o=9}else{if((IFb(e,2348960)|0)==0){o=9;break}do{if((k|0)==0){if((ud(e|0,2287304)|0)==(m|0)){break}p=Bc(e|0,1642568,140,8,218)|0;if((p|0)!=0){q=p+4|0;a[b]=a[q]|0;a[b+1|0]=a[q+1|0]|0;a[b+2|0]=a[q+2|0]|0;break a}KIb(f,16,2197072,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;s=-22;i=g;return s|0}}while(0);q=pb(e|0,j|0,16)|0;do{if((a[c[j>>2]|0]|0)==0){if(!((m|0)==8|(m|0)==6)){break}p=q&255;t=q>>>8&255;u=q>>>16&255;if((m|0)==8){a[l]=p;v=q>>>24&255;w=u;x=t}else{v=u;w=t;x=p}a[b]=v;a[b+1|0]=w;a[b+2|0]=x;break a}}while(0);KIb(f,16,2237648,(r=i,i=i+8|0,c[r>>2]=e,r)|0);i=r;s=-22;i=g;return s|0}}while(0);if((o|0)==9){o=wKb()|0;a[b]=o>>>24;a[b+1|0]=o>>>16;a[b+2|0]=o>>>8;a[l]=o}if((n|0)==0){s=0;i=g;return s|0}do{if((krc(n,2577664,2)|0)==0){y=+((pb(n|0,h|0,16)|0)>>>0>>>0)}else{z=+frc(n,h);if(z<0.0|z>1.0){y=256.0;break}y=z*255.0}}while(0);o=c[h>>2]|0;do{if((o|0)!=(n|0)){if((a[o]|0)!=0){break}if(y>255.0|y<0.0){break}a[l]=~~y;s=0;i=g;return s|0}}while(0);KIb(f,16,2165560,(r=i,i=i+16|0,c[r>>2]=n,c[r+8>>2]=d,r)|0);i=r;s=-22;i=g;return s|0}function eKb(a,b){a=a|0;b=b|0;return IFb(a,c[b>>2]|0)|0}function fKb(a,b){a=a|0;b=b|0;var d=0;if(a>>>0>139>>>0){d=0;return d|0}if((b|0)!=0){c[b>>2]=1642572+(a<<3)}d=c[1642568+(a<<3)>>2]|0;return d|0}function gKb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=e+8|0;g=e+12|0;h=e+16|0;i=e+20|0;j=e|0;k=e+4|0;e=d;d=b;a:while(1){if((OFb(a[e]|0)|0)!=0){b=d;while(1){if((OFb(a[b]|0)|0)==0){break}else{b=b+1|0}}e=e+1|0;d=b;continue}l=e+1|0;m=a[e]|0;if(m<<24>>24==0){n=d;o=34;break}p=m<<24>>24;b:do{if(m<<24>>24==37){q=e+2|0;r=a[l]|0;switch(r<<24>>24|0){case 77:{s=a[d]|0;if((MFb(s)|0)==0){n=0;o=34;break a}t=s-48|0;s=d+1|0;u=a[s]|0;if((MFb(u)|0)==0){v=t;w=s}else{v=(t*10|0)-48+u|0;w=d+2|0}if((w|0)==(d|0)|v>>>0>59>>>0){n=0;o=34;break a}c[k>>2]=v;e=q;d=w;continue a;break};case 89:{u=a[d]|0;if((MFb(u)|0)==0){n=0;o=34;break a}t=u-48|0;u=d+1|0;s=a[u]|0;do{if((MFb(s)|0)==0){x=t;y=u}else{z=(t*10|0)-48+s|0;A=d+2|0;B=a[A]|0;if((MFb(B)|0)==0){x=z;y=A;break}A=(z*10|0)-48+B|0;B=d+3|0;z=a[B]|0;if((MFb(z)|0)==0){x=A;y=B;break}x=(A*10|0)-48+z|0;y=d+4|0}}while(0);if((y|0)==(d|0)|x>>>0>9999>>>0){n=0;o=34;break a}c[i>>2]=x-1900;e=q;d=y;continue a;break};case 100:{s=a[d]|0;if((MFb(s)|0)==0){n=0;o=34;break a}t=s-48|0;s=d+1|0;u=a[s]|0;if((MFb(u)|0)==0){C=t;D=s}else{C=(t*10|0)-48+u|0;D=d+2|0}if((C-1|0)>>>0>30>>>0|(C|0)==-1){n=0;o=34;break a}c[g>>2]=C;e=q;d=D;continue a;break};case 109:{u=a[d]|0;if((MFb(u)|0)==0){n=0;o=34;break a}t=u-48|0;u=d+1|0;s=a[u]|0;if((MFb(s)|0)==0){E=t;F=u}else{E=(t*10|0)-48+s|0;F=d+2|0}s=E-1|0;if(s>>>0>11>>>0|(E|0)==-1){n=0;o=34;break a}c[h>>2]=s;e=q;d=F;continue a;break};case 83:{s=a[d]|0;if((MFb(s)|0)==0){n=0;o=34;break a}t=s-48|0;s=d+1|0;u=a[s]|0;if((MFb(u)|0)==0){G=t;H=s}else{G=(t*10|0)-48+u|0;H=d+2|0}if((H|0)==(d|0)|G>>>0>59>>>0){n=0;o=34;break a}c[j>>2]=G;e=q;d=H;continue a;break};case 37:{I=37;J=q;break b;break};case 72:case 74:{u=a[d]|0;if((MFb(u)|0)==0){n=0;o=34;break a}t=u-48|0;u=d+1|0;s=a[u]|0;if((MFb(s)|0)==0){K=t;L=u}else{K=(t*10|0)-48+s|0;L=d+2|0}if((K|0)<0|(K|0)>((r<<24>>24==72?23:2147483647)|0)|(K|0)==-1){n=0;o=34;break a}c[f>>2]=K;e=q;d=L;continue a;break};default:{n=0;o=34;break a}}}else{I=p;J=l}}while(0);if((I|0)!=(a[d]|0)){n=0;o=34;break}e=J;d=d+1|0}if((o|0)==34){return n|0}return 0}function hKb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+20>>2]|0;d=c[a+16>>2]|0;e=d+1|0;if((e|0)<3){f=b+1899|0;g=d+13|0}else{f=b+1900|0;g=e}return((c[a+8>>2]|0)*3600|0)-2032579456+(((((g*153|0)-457|0)/5|0)+(c[a+12>>2]|0)+(f*365|0)+((f|0)/4|0)+((f|0)/-100|0)+((f|0)/400|0)|0)*86400|0)+((c[a+4>>2]|0)*60|0)+(c[a>>2]|0)|0}function iKb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;f=i;i=i+96|0;g=f|0;h=f+8|0;j=f+56|0;k=f+64|0;mrc(h|0,0,44)|0;c[b>>2]=0;c[b+4>>2]=-2147483648;l=(e|0)!=0;a:do{if(l){e=(a[d]|0)==45;m=e?d+1|0:d;n=e&1;e=gKb(m,2563048,h)|0;if((e|0)!=0){o=e;p=0;q=n;break}e=gKb(m,2545544,h)|0;r=h+8|0;c[r>>2]=0;if((e|0)!=0){o=e;p=0;q=n;break}c[h>>2]=rb(m|0,j|0,10)|0;e=c[j>>2]|0;if((e|0)==(m|0)){s=-22;i=f;return s|0}else{c[h+4>>2]=0;c[r>>2]=0;t=n;u=0;v=e;w=15;break}}else{c[g>>2]=ie(0)|0;if((IFb(d,2583616)|0)==0){e=c[g>>2]|0;n=Erc(e,(e|0)<0|0?-1:0,1e6,0)|0;c[b>>2]=n;c[b+4>>2]=G;s=0;i=f;return s|0}else{x=0}while(1){if(!(x>>>0<2>>>0)){y=0;break}n=gKb(d,c[2003792+(x<<2)>>2]|0,h)|0;if((n|0)==0){x=x+1|0}else{y=n;break}}n=(y|0)==0;e=n?d:y;r=n&1;n=a[e]|0;if((n<<24>>24|0)==84|(n<<24>>24|0)==116|(n<<24>>24|0)==32){z=e+1|0}else{z=e}n=0;m=e;while(1){if(!(n>>>0<2>>>0)){t=0;u=r;v=m;w=15;break a}e=gKb(z,c[2003784+(n<<2)>>2]|0,h)|0;if((e|0)==0){n=n+1|0;m=0}else{o=e;p=r;q=0;break}}}}while(0);do{if((w|0)==15){if((v|0)==0){s=-22}else{o=v;p=u;q=t;break}i=f;return s|0}}while(0);if((a[o]|0)==46){t=o+1|0;do{if((MFb(a[t]|0)|0)==0){A=0;B=t}else{u=((a[t]|0)*1e5|0)-48e5|0;v=o+2|0;if((MFb(a[v]|0)|0)==0){A=u;B=v;break}w=((a[v]|0)*1e4|0)-48e4+u|0;u=o+3|0;if((MFb(a[u]|0)|0)==0){A=w;B=u;break}v=((a[u]|0)*1e3|0)-48e3+w|0;w=o+4|0;if((MFb(a[w]|0)|0)==0){A=v;B=w;break}u=((a[w]|0)*100|0)-4800+v|0;v=o+5|0;if((MFb(a[v]|0)|0)==0){A=u;B=v;break}w=((a[v]|0)*10|0)-480+u|0;u=o+6|0;if((MFb(a[u]|0)|0)==0){A=w;B=u;break}A=(a[u]|0)-48+w|0;B=o+7|0}}while(0);t=B;while(1){if((MFb(a[t]|0)|0)==0){C=A;D=t;break}else{t=t+1|0}}}else{C=0;D=o}do{if(l){E=((c[h+4>>2]|0)*60|0)+((c[h+8>>2]|0)*3600|0)+(c[h>>2]|0)|0;F=D}else{o=a[D]|0;t=D+((o<<24>>24==90|o<<24>>24==122)&1)|0;if((p|0)!=0){if((o<<24>>24|0)==122|(o<<24>>24|0)==90){nrc(k|0,(rc(g|0)|0)+12|0,32)|0}else{nrc(k|0,(Ab(g|0)|0)+12|0,32)|0}nrc(h+12|0,k|0,32)|0}if(!((o<<24>>24|0)==122|(o<<24>>24|0)==90)){E=_c(h|0)|0;F=t;break}o=c[h+20>>2]|0;A=c[h+16>>2]|0;B=A+1|0;if((B|0)<3){H=o+1899|0;I=A+13|0}else{H=o+1900|0;I=B}E=((c[h+8>>2]|0)*3600|0)-2032579456+(((((I*153|0)-457|0)/5|0)+(c[h+12>>2]|0)+(H*365|0)+((H|0)/4|0)+((H|0)/-100|0)+((H|0)/400|0)|0)*86400|0)+((c[h+4>>2]|0)*60|0)+(c[h>>2]|0)|0;F=t}}while(0);if((a[F]|0)!=0){s=-22;i=f;return s|0}F=Erc(E,(E|0)<0|0?-1:0,1e6,0)|0;E=wrc(F,G,C,(C|0)<0|0?-1:0)|0;C=G;F=(q|0)!=0;q=xrc(0,0,E,C)|0;c[b>>2]=F?q:E;c[b+4>>2]=F?G:C;s=0;i=f;return s|0}function jKb(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+128|0;g=f|0;h=g|0;j=g;g=b;k=c-1|0;c=h;l=(a[e]|0)==63?e+1|0:e;while(1){e=a[l]|0;if(!((e<<24>>24|0)==0|(e<<24>>24|0)==61|(e<<24>>24|0)==38)){if((c-j|0)>>>0<127>>>0){a[c]=e;m=c+1|0}else{m=c}c=m;l=l+1|0;continue}a[c]=0;a:do{if((a[l]|0)==61){e=b;n=l;while(1){if((e-g|0)>=(k|0)){o=n;break}p=n+1|0;q=a[p]|0;if((q<<24>>24|0)==38|(q<<24>>24|0)==0){r=e;s=p;break a}a[e]=q<<24>>24==43?32:q;e=e+1|0;n=p}while(1){n=o+1|0;p=a[n]|0;if((p<<24>>24|0)==38|(p<<24>>24|0)==0){r=e;s=n;break}else{o=n}}}else{r=b;s=l}}while(0);a[r]=0;if((irc(h,d)|0)==0){t=1;u=13;break}if((a[s]|0)==38){c=h;l=s+1|0}else{t=0;u=13;break}}if((u|0)==13){i=f;return t|0}return 0}function kKb(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;m=b[g+8+(j<<1)>>1]|0;n=m&3;o=(m&65535)>>>11&15;p=o+1|0;q=(1<<p)-1|0;r=(m&65535)>>>8&7;s=((m&65535)>>>2&7)+1|0;t=d[g+7|0]|0;if((t&4|0)!=0){g=((m&65535)>>>5&7)-1+(ca(s,h)|0)|0;u=(c[e+(n<<2)>>2]|0)+((ca(c[f+(n<<2)>>2]|0,i)|0)+(g>>3))|0;v=7-o-(g&7)|0;g=k-1|0;if((k|0)==0){return}o=e+4|0;if((l|0)==0){w=u;x=v;y=a;z=g;while(1){A=x-s|0;b[y>>1]=(d[w]|0)>>>(x>>>0)&q;if((z|0)==0){break}else{w=w+(-(A>>3)|0)|0;x=A&7;y=y+2|0;z=z-1|0}}return}else{z=u;u=v;v=a;y=g;while(1){g=u-s|0;b[v>>1]=d[(c[o>>2]|0)+((((d[z]|0)>>>(u>>>0)&q)<<2)+j)|0]|0;if((y|0)==0){break}else{z=z+(-(g>>3)|0)|0;u=g&7;v=v+2|0;y=y-1|0}}return}}y=((m&65535)>>>5&7)-1+(ca(s,h)|0)+(ca(c[f+(n<<2)>>2]|0,i)|0)|0;i=(p+r|0)<9;if(i){B=y+(t&1)|0}else{B=y}y=(c[e+(n<<2)>>2]|0)+B|0;B=k-1|0;if((k|0)==0){return}k=(l|0)==0;l=e+4|0;e=(t&1|0)==0;if(i){if(e){i=y;t=a;n=B;while(1){p=(d[i]|0)>>>(r>>>0)&q;if(k){C=p&65535}else{C=d[(c[l>>2]|0)+((p<<2)+j)|0]|0}b[t>>1]=C;if((n|0)==0){break}else{i=i+s|0;t=t+2|0;n=n-1|0}}return}else{n=y;t=a;i=B;while(1){C=(d[n]|0)>>>(r>>>0)&q;if(k){D=C&65535}else{D=d[(c[l>>2]|0)+((C<<2)+j)|0]|0}b[t>>1]=D;if((i|0)==0){break}else{n=n+s|0;t=t+2|0;i=i-1|0}}return}}else{if(e){e=y;i=a;t=B;while(1){n=e;D=((d[n]|d[n+1|0]<<8)<<16>>16&65535)>>>(r>>>0)&q;if(k){E=D&65535}else{E=d[(c[l>>2]|0)+((D<<2)+j)|0]|0}b[i>>1]=E;if((t|0)==0){break}else{e=e+s|0;i=i+2|0;t=t-1|0}}return}else{t=y;y=a;a=B;while(1){B=t;i=((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)>>>(r>>>0)&q;if(k){F=i&65535}else{F=d[(c[l>>2]|0)+((i<<2)+j)|0]|0}b[y>>1]=F;if((a|0)==0){break}else{t=t+s|0;y=y+2|0;a=a-1|0}}return}}}function lKb(f,g,h,i,j,k,l,m){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=b[i+8+(l<<1)>>1]|0;l=n&3;o=(n&65535)>>>11&15;p=((n&65535)>>>2&7)+1|0;q=d[i+7|0]|0;if((q&4|0)!=0){i=((n&65535)>>>5&7)-1+(ca(p,j)|0)|0;if((m|0)==0){return}r=(ca(c[h+(l<<2)>>2]|0,k)|0)+(i>>3)|0;s=7-o-(i&7)|0;i=(c[g+(l<<2)>>2]|0)+r|0;r=m;t=f;while(1){u=r-1|0;a[i]=d[i]|0|(e[t>>1]|0)<<s;v=s-p|0;if((u|0)==0){break}else{s=v&7;i=i+(-(v>>3)|0)|0;r=u;t=t+2|0}}return}t=(n&65535)>>>8&7;r=c[g+(l<<2)>>2]|0;g=((n&65535)>>>5&7)-1+(ca(p,j)|0)+(ca(c[h+(l<<2)>>2]|0,k)|0)|0;k=r+g|0;l=(m|0)==0;if((o+1+t|0)<9){if(l){return}o=r+(g+(q&1))|0;g=m;r=f;while(1){h=g-1|0;a[o]=d[o]|0|(e[r>>1]|0)<<t;if((h|0)==0){break}else{o=o+p|0;g=h;r=r+2|0}}return}if(l){return}l=(q&1|0)==0;q=k;k=f;f=m;while(1){m=f-1|0;r=q;g=(d[r]|d[r+1|0]<<8)<<16>>16;if(l){w=((e[k>>1]|0)<<t|g&65535)&65535}else{o=(he(g|0)|0)&65535;w=he(((e[k>>1]|0)<<t|o)&65535|0)|0}y=w;a[r]=y;y=y>>8;a[r+1|0]=y;if((m|0)==0){break}else{q=q+p|0;k=k+2|0;f=m}}return}function mKb(a){a=a|0;var b=0;if(!(a>>>0<333>>>0)){b=0;return b|0}b=c[1998456+(a<<4)>>2]|0;return b|0}function nKb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+32|0;d=b|0;if((irc(a,2524200)|0)==0){e=2374104}else{f=(irc(a,2523224)|0)==0;e=f?2387336:a}a=0;while(1){f=c[1998456+(a<<4)>>2]|0;if((f|0)!=0){if((irc(f,e)|0)==0){g=7;break}}f=a+1|0;if((f|0)<333){a=f}else{break}}do{if((g|0)==7){if((a|0)==-1){break}else{h=a}i=b;return h|0}}while(0);a=d|0;Rb(a|0,32,2522312,(d=i,i=i+16|0,c[d>>2]=e,c[d+8>>2]=2521240,d)|0)|0;i=d;d=0;while(1){e=c[1998456+(d<<4)>>2]|0;if((e|0)!=0){if((irc(e,a)|0)==0){h=d;g=12;break}}e=d+1|0;if((e|0)<333){d=e}else{h=-1;g=12;break}}if((g|0)==12){i=b;return h|0}return 0}function oKb(b){b=b|0;var c=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=(d[b+6|0]|0)+(d[b+5|0]|0)|0;f=a[b+4|0]|0;if(f<<24>>24==0){g=0;h=g>>c;return h|0}i=f&255;f=0;j=0;while(1){k=(((e[b+8+(j<<1)>>1]|0)>>>11&15)+1<<((j-1|0)>>>0<2>>>0?0:c))+f|0;l=j+1|0;if((l|0)<(i|0)){f=k;j=l}else{g=k;break}}h=g>>c;return h|0}function pKb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+16|0;g=f|0;h=(d[e+6|0]|0)+(d[e+5|0]|0)|0;mrc(g|0,0,16)|0;j=a[e+4|0]|0;if(j<<24>>24==0){k=0;l=0;m=0;n=0;o=l+k|0;p=m+o|0;q=n+p|0;r=e+7|0;s=a[r]|0;t=s&4;u=t<<24>>24==0;v=q<<3;w=u?v:q;x=w>>h;i=f;return x|0}y=j&255;j=0;do{z=b[e+8+(j<<1)>>1]|0;c[g+((z&3)<<2)>>2]=((z&65535)>>>2&7)+1<<((j-1|0)>>>0<2>>>0?0:h);j=j+1|0;}while((j|0)<(y|0));k=c[g>>2]|0;l=c[g+4>>2]|0;m=c[g+8>>2]|0;n=c[g+12>>2]|0;o=l+k|0;p=m+o|0;q=n+p|0;r=e+7|0;s=a[r]|0;t=s&4;u=t<<24>>24==0;v=q<<3;w=u?v:q;x=w>>h;i=f;return x|0}function qKb(a){a=a|0;var b=0;if(a>>>0>332>>>0){b=0}else{b=1998456+(a<<4)|0}return b|0}function rKb(a){a=a|0;var b=0,d=0,e=0;a:do{if((a|0)==0){b=1998456}else{d=a;while(1){if(!(d-1998456>>4>>>0<332>>>0)){b=0;break a}e=d+16|0;if((c[e>>2]|0)==0){d=e}else{b=e;break}}}}while(0);return b|0}function sKb(a){a=a|0;var b=0;if(a>>>0<1998456>>>0|a>>>0>=2003784>>>0){b=-1;return b|0}b=a-1998456>>4;return b|0}function tKb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;if(a>>>0>332>>>0){f=-38;return f|0}c[b>>2]=d[1998461+(a<<4)|0]|0;c[e>>2]=d[1998462+(a<<4)|0]|0;f=0;return f|0}function uKb(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e|0;mrc(f|0,0,16)|0;if(d>>>0>332>>>0){g=-22;i=e;return g|0}h=a[1998460+(d<<4)|0]|0;if(h<<24>>24==0){j=0;k=0;l=0;m=0}else{n=h&255;h=0;do{c[f+((b[1998464+(d<<4)+(h<<1)>>1]&3)<<2)>>2]=1;h=h+1|0;}while((h|0)<(n|0));j=c[f>>2]|0;k=c[f+4>>2]|0;l=c[f+8>>2]|0;m=c[f+12>>2]|0}g=m+(l+(k+j))|0;i=e;return g|0}function vKb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+16|0;e=d|0;if(b>>>0>332>>>0){f=-1;i=d;return f|0}g=c[1998456+(b<<4)>>2]|0;if((lrc(g|0)|0)>>>0<2>>>0){f=-1;i=d;return f|0}b=e|0;CFb(b,g,16)|0;g=e+((lrc(b|0)|0)-2)|0;do{if((irc(g,2497368)|0)!=0){if((irc(g,2521240)|0)==0){break}else{f=-1}i=d;return f|0}}while(0);a[g]=a[g]^14;g=0;while(1){e=c[1998456+(g<<4)>>2]|0;if((e|0)!=0){if((irc(e,b)|0)==0){f=g;h=9;break}}e=g+1|0;if((e|0)<333){g=e}else{f=-1;h=9;break}}if((h|0)==9){i=d;return f|0}return 0}function wKb(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;i=i+152|0;b=a|0;d=a+120|0;e=a+144|0;f=nHb(2406144,0,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0)|0;i=g;do{if(!((f|0)==-1)){h=Bb(f|0,e|0,4)|0;Zb(f|0)|0;if((h|0)!=4){break}j=c[e>>2]|0;i=a;return j|0}}while(0);f=nHb(2577296,0,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0)|0;i=g;do{if(!((f|0)==-1)){h=Bb(f|0,e|0,4)|0;Zb(f|0)|0;if((h|0)!=4){break}j=c[e>>2]|0;i=a;return j|0}}while(0);e=d;f=d|0;h=b;b=c[1507816]|0;k=c[1507817]|0;if(!((c[499546]|0)>>>0<121>>>0)){KIb(0,0,2435344,(g=i,i=i+24|0,c[g>>2]=2348880,c[g+8>>2]=2287248,c[g+16>>2]=72,g)|0);i=g;Hd();return 0}if((b|0)==0&(k|0)==0){g=0;while(1){l=ac()|0;if((g|0)==(l|0)){m=6031272+((c[1507816]&511)<<2)|0;c[m>>2]=(c[m>>2]|0)+1;g=l;continue}else{m=wrc(c[1507816]|0,c[1507817]|0,1,0)|0;n=G;c[1507816]=m;c[1507817]=n;o=6031272+((m&511)<<2)|0;c[o>>2]=(c[o>>2]|0)+(((l-g|0)>>>0)%3294638521|0);o=0;if(n>>>0>o>>>0|n>>>0==o>>>0&m>>>0>64>>>0){break}else{g=l;continue}}}}else{g=0;while(1){l=ac()|0;if((g|0)==(l|0)){m=6031272+((c[1507816]&511)<<2)|0;c[m>>2]=(c[m>>2]|0)+1;g=l;continue}else{m=wrc(c[1507816]|0,c[1507817]|0,1,0)|0;o=G;c[1507816]=m;c[1507817]=o;n=6031272+((m&511)<<2)|0;c[n>>2]=(c[n>>2]|0)+(((l-g|0)>>>0)%3294638521|0);n=xrc(m,o,b,k)|0;o=G;m=0;if(o>>>0>m>>>0|o>>>0==m>>>0&n>>>0>4>>>0){break}else{g=l;continue}}}}ZKb(h,160)|0;aLb(h,6031272,2048);bLb(h,e);e=je(c[f>>2]|0)|0;j=(je(c[d+16>>2]|0)|0)+e|0;i=a;return j|0}function xKb(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=f^d;k=g^e;l=-1;m=(e|0)>(l|0)|(e|0)==(l|0)&d>>>0>-1>>>0;l=xrc(0,0,d,e)|0;n=m?d:l;l=m?e:G;m=-1;o=(g|0)>(m|0)|(g|0)==(m|0)&f>>>0>-1>>>0;m=xrc(0,0,f,g)|0;p=o?f:m;m=o?g:G;o=TIb(n,l,p,m)|0;q=G;if((o|0)==0&(q|0)==0){r=e;s=d;t=g;u=f}else{f=Crc(n,l,o,q)|0;l=G;n=Crc(p,m,o,q)|0;r=l;s=f;t=G;u=n}a:do{if((r|0)>(i|0)|(r|0)==(i|0)&s>>>0>h>>>0|((t|0)>(i|0)|(t|0)==(i|0)&u>>>0>h>>>0)){if((u|0)==0&(t|0)==0){v=0;w=1;x=1;break}else{y=1;z=0;A=0;B=1;C=t;D=u;E=r;F=s}while(1){H=Crc(F,E,D,C)|0;I=G;J=y;K=(y|0)<0|0?-1:0;n=Erc(H,I,J,K)|0;L=A;M=(A|0)<0|0?-1:0;f=wrc(n,G,L,M)|0;n=G;N=z;O=(z|0)<0|0?-1:0;l=Erc(H,I,N,O)|0;P=B;Q=(B|0)<0|0?-1:0;q=wrc(l,G,P,Q)|0;l=G;if((n|0)>(i|0)|(n|0)==(i|0)&f>>>0>h>>>0|((l|0)>(i|0)|(l|0)==(i|0)&q>>>0>h>>>0)){break}l=Erc(H,I,D,C)|0;n=G;o=xrc(F,E,l,n)|0;m=f;f=q;if((F|0)==(l|0)&(E|0)==(n|0)){v=f;w=m;x=1;break a}else{A=y;y=m;B=z;z=f;E=C;C=G;F=D;D=o}}if((y|0)==0){R=I;S=H}else{o=xrc(h,i,L,M)|0;f=Crc(o,G,J,K)|0;R=G;S=f}if((z|0)==0){T=R;U=S}else{f=xrc(h,i,P,Q)|0;o=Crc(f,G,N,O)|0;f=G;m=R>>>0>f>>>0|R>>>0==f>>>0&S>>>0>o>>>0;T=m?f:R;U=m?o:S}o=Erc(N<<1|0>>>31,O<<1|N>>>31,U,T)|0;m=wrc(o,G,P,Q)|0;o=Erc(m,G,D,C)|0;m=G;f=Erc(F,E,N,O)|0;n=G;if(!(m>>>0>n>>>0|m>>>0==n>>>0&o>>>0>f>>>0)){v=z;w=y;x=0;break}f=Erc(U,T,J,K)|0;o=wrc(f,G,L,M)|0;f=Erc(U,T,N,O)|0;n=wrc(f,G,P,Q)|0;v=n;w=o;x=0}else{v=u;w=s;x=1}}while(0);s=0;c[a>>2]=(k|0)<(s|0)|(k|0)==(s|0)&j>>>0<0>>>0?-w|0:w;c[b>>2]=v;return x|0}function yKb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b;b=i;i=i+8|0;c[b>>2]=c[f>>2];c[b+4>>2]=c[f+4>>2];f=d;d=i;i=i+8|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];f=b|0;g=b+4|0;h=c[f>>2]|0;j=c[d>>2]|0;k=Erc(j,(j|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=G;j=c[g>>2]|0;l=c[d+4>>2]|0;d=Erc(l,(l|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;xKb(f,g,k,h,d,G,2147483647,0)|0;d=b;b=a;a=c[d+4>>2]|0;c[b>>2]=c[d>>2];c[b+4>>2]=a;i=e;return}function zKb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+8|0;g=b;b=i;i=i+8|0;c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];g=e;e=i;i=i+8|0;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];g=f|0;h=c[e+4>>2]|0;j=c[e>>2]|0;e=b;b=e|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[g>>2]=k;c[g+4>>2]=e;b=k;k=Erc(b,(b|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=G;b=Erc(e,(e|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;xKb(g,g+4|0,k,h,b,G,2147483647,0)|0;b=a;a=c[g+4>>2]|0;c[b>>2]=c[g>>2];c[b+4>>2]=a;i=f;return}function AKb(a,b,d){a=a|0;b=+b;d=d|0;var e=0,f=0,g=0,j=0,l=0.0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+8|0;f=e|0;h[k>>3]=b;g=c[k+4>>2]&2147483647;j=2146435072;if(g>>>0>j>>>0|g>>>0==j>>>0&(c[k>>2]|0)>>>0>0>>>0){c[a>>2]=0;c[a+4>>2]=0;i=e;return}l=+R(+b);if(l>2147483650.0){c[a>>2]=b<0.0?-1:1;c[a+4>>2]=0;i=e;return}j=~~(+aa(l+1.0e-20)/.6931471805599453);g=(j|0)>0;m=yrc(1,0,61-j|0)|0;j=g?m:0;m=g?G:536870912;g=f;n=f+4|0;l=+Q((+(j>>>0)+ +(m|0)*4294967296.0)*b+.5);o=~~+l>>>0;p=(F=+l,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);xKb(g,n,o,p,j,m,d,(d|0)<0|0?-1:0)|0;if((c[g>>2]|0)==0){if(b!=0.0){q=8}}else{if((c[n>>2]|0)==0&b!=0.0){q=8}}do{if((q|0)==8){if(!((d|0)>0&(d|0)!=2147483647)){break}xKb(g,n,o,p,j,m,2147483647,0)|0}}while(0);m=a;a=c[f+4>>2]|0;c[m>>2]=c[f>>2];c[m+4>>2]=a;i=e;return}function BKb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;f=a;a=i;i=i+8|0;c[a>>2]=c[f>>2];c[a+4>>2]=c[f+4>>2];f=b;b=i;i=i+8|0;c[b>>2]=c[f>>2];c[b+4>>2]=c[f+4>>2];f=d;d=i;i=i+8|0;c[d>>2]=c[f>>2];c[d+4>>2]=c[f+4>>2];f=c[b>>2]|0;g=c[d+4>>2]|0;h=g;j=(g|0)<0|0?-1:0;k=Erc(h,j,f,(f|0)<0|0?-1:0)|0;l=G;m=c[d>>2]|0;d=c[b+4>>2]|0;b=d;n=(d|0)<0|0?-1:0;o=Erc(b,n,m,(m|0)<0|0?-1:0)|0;p=G;q=wrc(o,p,k,l)|0;r=G;s=Erc(b<<1|0>>>31,n<<1|b>>>31,h,j)|0;j=G;h=c[a+4>>2]|0;b=h;n=(h|0)<0|0?-1:0;h=UIb(q,r,b,n,s,j,3)|0;t=G;u=UIb(q,r,b,n,s,j,2)|0;j=G;s=c[a>>2]|0;a=s;n=(s|0)<0|0?-1:0;s=(((t|0)>(n|0)|(t|0)==(n|0)&h>>>0>a>>>0)&1)-(((j|0)<(n|0)|(j|0)==(n|0)&u>>>0<a>>>0)&1)|0;if(!((o|0)==(k|0)&(p|0)==(l|0))){xrc(o,p,k,l)|0;l=G^((d^g|0)<0|0?-1:0);((l|0)<0|0?-1:0)>>31|((l|0)<0|0?-1:0)<<1;v=l>>31|((l|0)<0|0?-1:0)<<1|1;w=ca(v,s)|0;i=e;return w|0}if(!((d|0)==0|(g|0)==0)){v=0;w=ca(v,s)|0;i=e;return w|0}if((m|0)==0|(f|0)==0){v=-2147483648;w=ca(v,s)|0;i=e;return w|0}v=(m>>31)-(f>>31)|0;w=ca(v,s)|0;i=e;return w|0}function CKb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;e=a;a=i;i=i+8|0;c[a>>2]=c[e>>2];c[a+4>>2]=c[e+4>>2];e=c[b+4>>2]|0;if((e|0)==0){f=0;i=d;return f|0}g=c[a+4>>2]|0;h=g;j=(g|0)<0|0?-1:0;g=c[a>>2]|0;a=g;k=(g|0)<0|0?-1:0;g=0;l=0;m=e;n=e;while(1){e=c[b+(g<<3)>>2]|0;o=n;p=(n|0)<0|0?-1:0;q=Erc(o,p,e,(e|0)<0|0?-1:0)|0;r=G;s=c[b+(l<<3)>>2]|0;t=m;u=(m|0)<0|0?-1:0;v=Erc(t,u,s,(s|0)<0|0?-1:0)|0;w=G;x=wrc(v,w,q,r)|0;y=G;z=Erc(t<<1|0>>>31,u<<1|t>>>31,o,p)|0;p=G;o=UIb(x,y,h,j,z,p,3)|0;t=G;u=UIb(x,y,h,j,z,p,2)|0;p=G;z=(((t|0)>(k|0)|(t|0)==(k|0)&o>>>0>a>>>0)&1)-(((p|0)<(k|0)|(p|0)==(k|0)&u>>>0<a>>>0)&1)|0;do{if((v|0)==(q|0)&(w|0)==(r|0)){if(!((m|0)==0|(n|0)==0)){A=0;break}if((s|0)==0|(e|0)==0){A=-2147483648;break}A=(s>>31)-(e>>31)|0}else{xrc(v,w,q,r)|0;u=G^((m^n|0)<0|0?-1:0);((u|0)<0|0?-1:0)>>31|((u|0)<0|0?-1:0)<<1;A=u>>31|((u|0)<0|0?-1:0)<<1|1}}while(0);r=(ca(A,z)|0)>0;q=r?g:l;r=g+1|0;w=c[b+(r<<3)+4>>2]|0;if((w|0)==0){f=q;break}g=r;l=q;m=w;n=c[b+(q<<3)+4>>2]|0}i=d;return f|0}function DKb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=f>>3;if((f&7|0)==0){h=0}else{i=-1;return i|0}while(1){a[b+h|0]=h;f=h+1|0;if((f|0)<256){h=f}else{j=0;k=0;l=0;break}}while(1){h=(k|0)==(g|0)?0:k;f=b+l|0;m=a[f]|0;n=(m+j&255)+(a[e+h|0]|0)&255;o=b+(n&255)|0;p=a[o]|0;a[o]=m;a[f]=p;p=l+1|0;if((p|0)<256){j=n;k=h+1|0;l=p}else{break}}c[b+256>>2]=1;c[b+260>>2]=d[b+1|0]|0;i=0;return i|0}function EKb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=b+256|0;g=c[h>>2]|0;i=b+260|0;j=c[i>>2]&255;k=g&255;if((f|0)<=0){l=j;m=k;c[h>>2]=m;n=l&255;c[i>>2]=n;return}o=g&255;g=(o+(f+255&255)&255)+1&255;p=o;o=j;j=e;e=d;d=f;f=k;q=a[b+k|0]|0;while(1){k=d-1|0;r=b+(o&255)|0;s=a[r]|0;t=s+q&255;a[r]=q;a[b+f|0]=s;if((j|0)==0){u=a[b+(t&255)|0]|0;v=0}else{u=a[b+(t&255)|0]^a[j];v=j+1|0}a[e]=u;t=p+1&255;s=t&255;r=a[b+s|0]|0;w=r+o&255;if((k|0)>0){p=t;o=w;j=v;e=e+1|0;d=k;f=s;q=r}else{break}}l=w;m=g&255;c[h>>2]=m;n=l&255;c[i>>2]=n;return}function FKb(){return pJb(128)|0}function GKb(b,d){b=b|0;d=d|0;var e=0;a[b|0]=d>>>5;if((d|0)==128){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+124>>2]=2058;a[b+120|0]=0}else if((d|0)==320){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+96>>2]=-1009589776;c[b+100>>2]=1985229328;c[b+104>>2]=-19088744;c[b+108>>2]=-1985229329;c[b+112>>2]=19088743;c[b+116>>2]=1009589775;c[b+124>>2]=2316;a[b+120|0]=1}else if((d|0)==256){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+96>>2]=1985229328;c[b+100>>2]=-19088744;c[b+104>>2]=-1985229329;c[b+108>>2]=19088743;c[b+124>>2]=2058;a[b+120|0]=1}else if((d|0)==160){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+96>>2]=-1009589776;c[b+124>>2]=2316;a[b+120|0]=0}else{e=-1;return e|0}d=b+8|0;c[d>>2]=0;c[d+4>>2]=0;e=0;return e|0}function HKb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+64|0;f=e|0;g=(d|0)!=0;d=c[a>>2]|0;h=a+4|0;j=c[h>>2]|0;k=a+8|0;l=c[k>>2]|0;m=a+12|0;n=c[m>>2]|0;if(g){o=c[a+28>>2]|0;p=c[a+24>>2]|0;q=c[a+20>>2]|0;r=c[a+16>>2]|0}else{o=n;p=l;q=j;r=d}nrc(f|0,b|0,64)|0;b=l^j;s=c[f>>2]|0;t=(b^n)+d+s|0;d=t<<11|t>>>21;t=c[f+20>>2]|0;u=r+1352829926+((p^q)&o^p)+t|0;r=u<<8|u>>>24;u=c[f+4>>2]|0;v=u+n+(b^d)|0;b=v<<14|v>>>18;v=c[f+56>>2]|0;n=o+1352829926+v+((r^q)&p^q)|0;o=n<<9|n>>>23;n=c[f+8>>2]|0;w=n+l+(d^j^b)|0;l=w<<15|w>>>17;w=c[f+28>>2]|0;x=p+1352829926+w+((o^r)&q^r)|0;p=x<<9|x>>>23;x=c[f+12>>2]|0;y=x+j+(b^d^l)|0;j=y<<12|y>>>20;y=q+1352829926+s+((p^o)&r^o)|0;q=y<<11|y>>>21;y=c[f+16>>2]|0;z=y+d+(l^b^j)|0;d=z<<5|z>>>27;z=c[f+36>>2]|0;A=r+1352829926+z+((q^p)&o^p)|0;r=A<<13|A>>>19;A=b+t+(j^l^d)|0;b=A<<8|A>>>24;A=n+1352829926+o+((r^q)&p^q)|0;o=A<<15|A>>>17;A=c[f+24>>2]|0;B=l+A+(d^j^b)|0;l=B<<7|B>>>25;B=c[f+44>>2]|0;C=B+1352829926+p+((o^r)&q^r)|0;p=C<<15|C>>>17;C=j+w+(b^d^l)|0;j=C<<9|C>>>23;C=y+1352829926+q+((p^o)&r^o)|0;q=C<<5|C>>>27;C=c[f+32>>2]|0;D=d+C+(l^b^j)|0;d=D<<11|D>>>21;D=c[f+52>>2]|0;E=D+1352829926+r+((q^p)&o^p)|0;r=E<<7|E>>>25;E=b+z+(j^l^d)|0;b=E<<13|E>>>19;E=A+1352829926+o+((r^q)&p^q)|0;o=E<<7|E>>>25;E=c[f+40>>2]|0;F=l+E+(d^j^b)|0;l=F<<14|F>>>18;F=c[f+60>>2]|0;G=F+1352829926+p+((o^r)&q^r)|0;p=G<<8|G>>>24;G=j+B+(b^d^l)|0;j=G<<15|G>>>17;G=C+1352829926+q+((p^o)&r^o)|0;q=G<<11|G>>>21;G=c[f+48>>2]|0;f=d+G+(l^b^j)|0;d=f<<6|f>>>26;f=u+1352829926+r+((q^p)&o^p)|0;r=f<<14|f>>>18;f=b+D+(j^l^d)|0;b=f<<7|f>>>25;f=E+1352829926+o+((r^q)&p^q)|0;o=f<<14|f>>>18;f=l+v+(d^j^b)|0;l=f<<9|f>>>23;f=x+1352829926+p+((o^r)&q^r)|0;p=f<<12|f>>>20;f=l^b;H=j+F+(f^d)|0;j=H<<8|H>>>24;H=G+1352829926+q+((p^o)&r^o)|0;q=H<<6|H>>>26;H=w+1518500249+(j&f^b)+(g?r:d)|0;f=H<<7|H>>>25;H=A+1548603684+(g?d:r)+((q|~p)^o)|0;r=H<<9|H>>>23;H=y+1518500249+b+(f&(j^l)^l)|0;b=H<<6|H>>>26;H=B+1548603684+o+((r|~q)^p)|0;o=H<<13|H>>>19;H=D+1518500249+l+(b&(f^j)^j)|0;l=H<<8|H>>>24;H=x+1548603684+p+((o|~r)^q)|0;p=H<<15|H>>>17;H=u+1518500249+j+(l&(b^f)^f)|0;j=H<<13|H>>>19;H=w+1548603684+q+((p|~o)^r)|0;q=H<<7|H>>>25;H=E+1518500249+f+(j&(l^b)^b)|0;f=H<<11|H>>>21;H=s+1548603684+r+((q|~p)^o)|0;r=H<<12|H>>>20;H=A+1518500249+b+(f&(j^l)^l)|0;b=H<<9|H>>>23;H=D+1548603684+o+((r|~q)^p)|0;o=H<<8|H>>>24;H=F+1518500249+l+(b&(f^j)^j)|0;l=H<<7|H>>>25;H=t+1548603684+p+((o|~r)^q)|0;p=H<<9|H>>>23;H=x+1518500249+j+(l&(b^f)^f)|0;j=H<<15|H>>>17;H=E+1548603684+q+((p|~o)^r)|0;q=H<<11|H>>>21;H=G+1518500249+f+(j&(l^b)^b)|0;f=H<<7|H>>>25;H=v+1548603684+r+((q|~p)^o)|0;r=H<<7|H>>>25;H=s+1518500249+b+(f&(j^l)^l)|0;b=H<<12|H>>>20;H=F+1548603684+o+((r|~q)^p)|0;o=H<<7|H>>>25;H=z+1518500249+l+(b&(f^j)^j)|0;l=H<<15|H>>>17;H=C+1548603684+p+((o|~r)^q)|0;p=H<<12|H>>>20;H=t+1518500249+j+(l&(b^f)^f)|0;j=H<<9|H>>>23;H=G+1548603684+q+((p|~o)^r)|0;q=H<<7|H>>>25;H=n+1518500249+f+(j&(l^b)^b)|0;f=H<<11|H>>>21;H=y+1548603684+r+((q|~p)^o)|0;r=H<<6|H>>>26;H=v+1518500249+b+(f&(j^l)^l)|0;b=H<<7|H>>>25;H=z+1548603684+o+((r|~q)^p)|0;o=H<<15|H>>>17;H=B+1518500249+l+(b&(f^j)^j)|0;l=H<<13|H>>>19;H=u+1548603684+p+((o|~r)^q)|0;p=H<<13|H>>>19;H=C+1518500249+j+(l&(b^f)^f)|0;j=H<<12|H>>>20;H=n+1548603684+q+((p|~o)^r)|0;q=H<<11|H>>>21;H=g?q:j;d=g?j:q;q=x+1859775393+f+((H|~l)^b)|0;f=q<<11|q>>>21;q=F+1836072691+r+(d&(p^o)^o)|0;r=q<<9|q>>>23;q=E+1859775393+b+((f|~H)^l)|0;b=q<<13|q>>>19;q=t+1836072691+o+(r&(d^p)^p)|0;o=q<<7|q>>>25;q=v+1859775393+l+((b|~f)^H)|0;l=q<<6|q>>>26;q=u+1836072691+p+(o&(r^d)^d)|0;p=q<<15|q>>>17;q=y+1859775393+H+((l|~b)^f)|0;H=q<<7|q>>>25;q=x+1836072691+d+(p&(o^r)^r)|0;d=q<<11|q>>>21;q=z+1859775393+f+((H|~l)^b)|0;f=q<<14|q>>>18;q=w+1836072691+r+(d&(p^o)^o)|0;r=q<<8|q>>>24;q=F+1859775393+b+((f|~H)^l)|0;b=q<<9|q>>>23;q=v+1836072691+o+(r&(d^p)^p)|0;o=q<<6|q>>>26;q=C+1859775393+l+((b|~f)^H)|0;l=q<<13|q>>>19;q=A+1836072691+p+(o&(r^d)^d)|0;p=q<<6|q>>>26;q=u+1859775393+H+((l|~b)^f)|0;H=q<<15|q>>>17;q=z+1836072691+d+(p&(o^r)^r)|0;d=q<<14|q>>>18;q=n+1859775393+f+((H|~l)^b)|0;f=q<<14|q>>>18;q=B+1836072691+r+(d&(p^o)^o)|0;r=q<<12|q>>>20;q=w+1859775393+b+((f|~H)^l)|0;b=q<<8|q>>>24;q=C+1836072691+o+(r&(d^p)^p)|0;o=q<<13|q>>>19;q=s+1859775393+l+((b|~f)^H)|0;l=q<<13|q>>>19;q=G+1836072691+p+(o&(r^d)^d)|0;p=q<<5|q>>>27;q=A+1859775393+H+((l|~b)^f)|0;H=q<<6|q>>>26;q=n+1836072691+d+(p&(o^r)^r)|0;d=q<<14|q>>>18;q=D+1859775393+f+((H|~l)^b)|0;f=q<<5|q>>>27;q=E+1836072691+r+(d&(p^o)^o)|0;r=q<<13|q>>>19;q=B+1859775393+b+((f|~H)^l)|0;b=q<<12|q>>>20;q=s+1836072691+o+(r&(d^p)^p)|0;o=q<<13|q>>>19;q=t+1859775393+l+((b|~f)^H)|0;l=q<<7|q>>>25;q=y+1836072691+p+(o&(r^d)^d)|0;p=q<<7|q>>>25;q=G+1859775393+H+((l|~b)^f)|0;H=q<<5|q>>>27;q=D+1836072691+d+(p&(o^r)^r)|0;d=q<<5|q>>>27;q=g?p:l;j=g?l:p;p=u-1894007588+f+((H^q)&b^q)|0;f=p<<11|p>>>21;p=r+C+(j^o^d)|0;r=p<<15|p>>>17;p=z-1894007588+b+((f^H)&q^H)|0;b=p<<12|p>>>20;p=o+A+(d^j^r)|0;o=p<<5|p>>>27;p=B-1894007588+q+((b^f)&H^f)|0;q=p<<14|p>>>18;p=j+y+(r^d^o)|0;j=p<<8|p>>>24;p=E-1894007588+H+((q^b)&f^b)|0;H=p<<15|p>>>17;p=d+u+(o^r^j)|0;u=p<<11|p>>>21;p=s-1894007588+f+((H^q)&b^q)|0;f=p<<14|p>>>18;p=r+x+(j^o^u)|0;r=p<<14|p>>>18;p=C-1894007588+b+((f^H)&q^H)|0;b=p<<15|p>>>17;p=o+B+(u^j^r)|0;B=p<<14|p>>>18;p=G-1894007588+q+((b^f)&H^f)|0;q=p<<9|p>>>23;p=j+F+(r^u^B)|0;j=p<<6|p>>>26;p=y-1894007588+H+((q^b)&f^b)|0;H=p<<8|p>>>24;p=u+s+(B^r^j)|0;s=p<<14|p>>>18;p=D-1894007588+f+((H^q)&b^q)|0;f=p<<9|p>>>23;p=r+t+(j^B^s)|0;r=p<<6|p>>>26;p=x-1894007588+b+((f^H)&q^H)|0;b=p<<14|p>>>18;p=B+G+(s^j^r)|0;G=p<<9|p>>>23;p=w-1894007588+q+((b^f)&H^f)|0;q=p<<5|p>>>27;p=j+n+(r^s^G)|0;j=p<<12|p>>>20;p=F-1894007588+H+((q^b)&f^b)|0;H=p<<6|p>>>26;p=s+D+(G^r^j)|0;D=p<<9|p>>>23;p=v-1894007588+f+((H^q)&b^q)|0;f=p<<8|p>>>24;p=r+z+(j^G^D)|0;z=p<<12|p>>>20;p=t-1894007588+b+((f^H)&q^H)|0;b=p<<6|p>>>26;p=G+w+(D^j^z)|0;w=p<<5|p>>>27;p=A-1894007588+q+((b^f)&H^f)|0;q=p<<5|p>>>27;p=j+E+(z^D^w)|0;E=p<<15|p>>>17;p=n-1894007588+H+((q^b)&f^b)|0;H=p<<12|p>>>20;p=D+v+(w^z^E)|0;v=p<<8|p>>>24;p=g?w:b;D=g?b:w;if(g){c[a>>2]=(c[a>>2]|0)+f;c[h>>2]=(c[h>>2]|0)+H;c[k>>2]=(c[k>>2]|0)+q;c[m>>2]=(c[m>>2]|0)+p;g=a+16|0;c[g>>2]=(c[g>>2]|0)+z;g=a+20|0;c[g>>2]=(c[g>>2]|0)+v;g=a+24|0;c[g>>2]=(c[g>>2]|0)+E;g=a+28|0;c[g>>2]=(c[g>>2]|0)+D;i=e;return}else{g=q+D+(c[h>>2]|0)|0;c[h>>2]=p+z+(c[k>>2]|0);c[k>>2]=f+v+(c[m>>2]|0);c[m>>2]=H+E+(c[a>>2]|0);c[a>>2]=g;i=e;return}}function IKb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;i=i+64|0;f=e|0;g=(d|0)!=0;d=c[a>>2]|0;h=a+4|0;j=c[h>>2]|0;k=a+8|0;l=c[k>>2]|0;m=a+12|0;n=c[m>>2]|0;o=a+16|0;p=c[o>>2]|0;if(g){q=c[a+36>>2]|0;r=c[a+32>>2]|0;s=c[a+28>>2]|0;t=c[a+24>>2]|0;u=c[a+20>>2]|0}else{q=p;r=n;s=l;t=j;u=d}nrc(f|0,b|0,64)|0;b=c[f>>2]|0;v=(l^j^n)+d+b|0;d=(v<<11|v>>>21)+p|0;v=c[f+20>>2]|0;w=u+1352829926+((s|~r)^t)+v|0;u=(w<<8|w>>>24)+q|0;w=l<<10|l>>>22;l=s<<10|s>>>22;s=c[f+4>>2]|0;x=s+p+(w^j^d)|0;p=(x<<14|x>>>18)+n|0;x=c[f+56>>2]|0;y=q+1352829926+x+(u^(t|~l))|0;q=(y<<9|y>>>23)+r|0;y=j<<10|j>>>22;j=t<<10|t>>>22;t=c[f+8>>2]|0;z=t+n+(d^y^p)|0;n=(z<<15|z>>>17)+w|0;z=c[f+28>>2]|0;A=r+1352829926+z+(q^(u|~j))|0;r=(A<<9|A>>>23)+l|0;A=d<<10|d>>>22;d=u<<10|u>>>22;u=c[f+12>>2]|0;B=u+w+(p^A^n)|0;w=(B<<12|B>>>20)+y|0;B=l+1352829926+b+(r^(q|~d))|0;l=(B<<11|B>>>21)+j|0;B=p<<10|p>>>22;p=q<<10|q>>>22;q=c[f+16>>2]|0;C=q+y+(n^B^w)|0;y=(C<<5|C>>>27)+A|0;C=c[f+36>>2]|0;D=j+1352829926+C+(l^(r|~p))|0;j=(D<<13|D>>>19)+d|0;D=n<<10|n>>>22;n=r<<10|r>>>22;r=A+v+(w^D^y)|0;A=(r<<8|r>>>24)+B|0;r=t+1352829926+d+(j^(l|~n))|0;d=(r<<15|r>>>17)+p|0;r=w<<10|w>>>22;w=l<<10|l>>>22;l=c[f+24>>2]|0;E=B+l+(y^r^A)|0;B=(E<<7|E>>>25)+D|0;E=c[f+44>>2]|0;F=E+1352829926+p+(d^(j|~w))|0;p=(F<<15|F>>>17)+n|0;F=y<<10|y>>>22;y=j<<10|j>>>22;j=D+z+(A^F^B)|0;D=(j<<9|j>>>23)+r|0;j=q+1352829926+n+(p^(d|~y))|0;n=(j<<5|j>>>27)+w|0;j=A<<10|A>>>22;A=d<<10|d>>>22;d=c[f+32>>2]|0;G=r+d+(B^j^D)|0;r=(G<<11|G>>>21)+F|0;G=c[f+52>>2]|0;H=G+1352829926+w+(n^(p|~A))|0;w=(H<<7|H>>>25)+y|0;H=B<<10|B>>>22;B=p<<10|p>>>22;p=F+C+(D^H^r)|0;F=(p<<13|p>>>19)+j|0;p=l+1352829926+y+(w^(n|~B))|0;y=(p<<7|p>>>25)+A|0;p=D<<10|D>>>22;D=n<<10|n>>>22;n=c[f+40>>2]|0;I=j+n+(r^p^F)|0;j=(I<<14|I>>>18)+H|0;I=c[f+60>>2]|0;J=I+1352829926+A+(y^(w|~D))|0;A=(J<<8|J>>>24)+B|0;J=r<<10|r>>>22;r=w<<10|w>>>22;w=H+E+(F^J^j)|0;H=(w<<15|w>>>17)+p|0;w=d+1352829926+B+(A^(y|~r))|0;B=(w<<11|w>>>21)+D|0;w=F<<10|F>>>22;F=y<<10|y>>>22;y=c[f+48>>2]|0;f=p+y+(j^w^H)|0;p=(f<<6|f>>>26)+J|0;f=s+1352829926+D+(B^(A|~F))|0;D=(f<<14|f>>>18)+r|0;f=j<<10|j>>>22;j=A<<10|A>>>22;A=J+G+(H^f^p)|0;J=(A<<7|A>>>25)+w|0;A=n+1352829926+r+(D^(B|~j))|0;r=(A<<14|A>>>18)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=w+x+(p^A^J)|0;w=(B<<9|B>>>23)+f|0;B=u+1352829926+F+(r^(D|~H))|0;F=(B<<12|B>>>20)+j|0;B=p<<10|p>>>22;p=D<<10|D>>>22;D=f+I+(J^B^w)|0;f=(D<<8|D>>>24)+A|0;D=y+1352829926+j+(F^(r|~p))|0;j=(D<<6|D>>>26)+H|0;D=J<<10|J>>>22;J=r<<10|r>>>22;r=g?j:f;K=g?f:j;j=z+1518500249+A+(r&(w^D)^D)|0;A=(j<<7|j>>>25)+B|0;j=l+1548603684+H+((K^F)&J^F)|0;H=(j<<9|j>>>23)+p|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=q+1518500249+B+(A&(r^j)^j)|0;B=(F<<6|F>>>26)+D|0;F=E+1548603684+p+((H^K)&w^K)|0;p=(F<<13|F>>>19)+J|0;F=r<<10|r>>>22;r=K<<10|K>>>22;K=G+1518500249+D+(B&(A^F)^F)|0;D=(K<<8|K>>>24)+j|0;K=u+1548603684+J+((p^H)&r^H)|0;J=(K<<15|K>>>17)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=s+1518500249+j+(D&(B^K)^K)|0;j=(H<<13|H>>>19)+F|0;H=z+1548603684+w+((J^p)&A^p)|0;w=(H<<7|H>>>25)+r|0;H=B<<10|B>>>22;B=p<<10|p>>>22;p=n+1518500249+F+(j&(D^H)^H)|0;F=(p<<11|p>>>21)+K|0;p=b+1548603684+r+((w^J)&B^J)|0;r=(p<<12|p>>>20)+A|0;p=D<<10|D>>>22;D=J<<10|J>>>22;J=l+1518500249+K+(F&(j^p)^p)|0;K=(J<<9|J>>>23)+H|0;J=G+1548603684+A+((r^w)&D^w)|0;A=(J<<8|J>>>24)+B|0;J=j<<10|j>>>22;j=w<<10|w>>>22;w=I+1518500249+H+(K&(F^J)^J)|0;H=(w<<7|w>>>25)+p|0;w=v+1548603684+B+((A^r)&j^r)|0;B=(w<<9|w>>>23)+D|0;w=F<<10|F>>>22;F=r<<10|r>>>22;r=u+1518500249+p+(H&(K^w)^w)|0;p=(r<<15|r>>>17)+J|0;r=n+1548603684+D+((B^A)&F^A)|0;D=(r<<11|r>>>21)+j|0;r=K<<10|K>>>22;K=A<<10|A>>>22;A=y+1518500249+J+(p&(H^r)^r)|0;J=(A<<7|A>>>25)+w|0;A=x+1548603684+j+((D^B)&K^B)|0;j=(A<<7|A>>>25)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=b+1518500249+w+(J&(p^A)^A)|0;w=(B<<12|B>>>20)+r|0;B=I+1548603684+F+((j^D)&H^D)|0;F=(B<<7|B>>>25)+K|0;B=p<<10|p>>>22;p=D<<10|D>>>22;D=C+1518500249+r+(w&(J^B)^B)|0;r=(D<<15|D>>>17)+A|0;D=d+1548603684+K+((F^j)&p^j)|0;K=(D<<12|D>>>20)+H|0;D=J<<10|J>>>22;J=j<<10|j>>>22;j=v+1518500249+A+(r&(w^D)^D)|0;A=(j<<9|j>>>23)+B|0;j=y+1548603684+H+((K^F)&J^F)|0;H=(j<<7|j>>>25)+p|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=t+1518500249+B+(A&(r^j)^j)|0;B=(F<<11|F>>>21)+D|0;F=q+1548603684+p+((H^K)&w^K)|0;p=(F<<6|F>>>26)+J|0;F=r<<10|r>>>22;r=K<<10|K>>>22;K=x+1518500249+D+(B&(A^F)^F)|0;D=(K<<7|K>>>25)+j|0;K=C+1548603684+J+((p^H)&r^H)|0;J=(K<<15|K>>>17)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=E+1518500249+j+(D&(B^K)^K)|0;j=(H<<13|H>>>19)+F|0;H=s+1548603684+w+((J^p)&A^p)|0;w=(H<<13|H>>>19)+r|0;H=B<<10|B>>>22;B=p<<10|p>>>22;p=d+1518500249+F+(j&(D^H)^H)|0;F=(p<<12|p>>>20)+K|0;p=t+1548603684+r+((w^J)&B^J)|0;r=(p<<11|p>>>21)+A|0;p=D<<10|D>>>22;D=J<<10|J>>>22;J=g?D:p;f=g?p:D;D=u+1859775393+K+(J^(F|~j))|0;K=(D<<11|D>>>21)+H|0;D=I+1836072691+A+((r|~w)^f)|0;A=(D<<9|D>>>23)+B|0;D=j<<10|j>>>22;j=w<<10|w>>>22;w=n+1859775393+H+((K|~F)^D)|0;H=(w<<13|w>>>19)+J|0;w=v+1836072691+B+((A|~r)^j)|0;B=(w<<7|w>>>25)+f|0;w=F<<10|F>>>22;F=r<<10|r>>>22;r=x+1859775393+J+((H|~K)^w)|0;J=(r<<6|r>>>26)+D|0;r=s+1836072691+f+((B|~A)^F)|0;f=(r<<15|r>>>17)+j|0;r=K<<10|K>>>22;K=A<<10|A>>>22;A=q+1859775393+D+((J|~H)^r)|0;D=(A<<7|A>>>25)+w|0;A=u+1836072691+j+((f|~B)^K)|0;j=(A<<11|A>>>21)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=C+1859775393+w+((D|~J)^A)|0;w=(B<<14|B>>>18)+r|0;B=z+1836072691+F+((j|~f)^H)|0;F=(B<<8|B>>>24)+K|0;B=J<<10|J>>>22;J=f<<10|f>>>22;f=I+1859775393+r+((w|~D)^B)|0;r=(f<<9|f>>>23)+A|0;f=x+1836072691+K+((F|~j)^J)|0;K=(f<<6|f>>>26)+H|0;f=D<<10|D>>>22;D=j<<10|j>>>22;j=d+1859775393+A+((r|~w)^f)|0;A=(j<<13|j>>>19)+B|0;j=l+1836072691+H+((K|~F)^D)|0;H=(j<<6|j>>>26)+J|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=s+1859775393+B+((A|~r)^j)|0;B=(F<<15|F>>>17)+f|0;F=C+1836072691+J+((H|~K)^w)|0;J=(F<<14|F>>>18)+D|0;F=r<<10|r>>>22;r=K<<10|K>>>22;K=t+1859775393+f+((B|~A)^F)|0;f=(K<<14|K>>>18)+j|0;K=E+1836072691+D+((J|~H)^r)|0;D=(K<<12|K>>>20)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=z+1859775393+j+((f|~B)^K)|0;j=(H<<8|H>>>24)+F|0;H=d+1836072691+w+((D|~J)^A)|0;w=(H<<13|H>>>19)+r|0;H=B<<10|B>>>22;B=J<<10|J>>>22;J=b+1859775393+F+((j|~f)^H)|0;F=(J<<13|J>>>19)+K|0;J=y+1836072691+r+((w|~D)^B)|0;r=(J<<5|J>>>27)+A|0;J=f<<10|f>>>22;f=D<<10|D>>>22;D=l+1859775393+K+((F|~j)^J)|0;K=(D<<6|D>>>26)+H|0;D=t+1836072691+A+((r|~w)^f)|0;A=(D<<14|D>>>18)+B|0;D=j<<10|j>>>22;j=w<<10|w>>>22;w=G+1859775393+H+((K|~F)^D)|0;H=(w<<5|w>>>27)+J|0;w=n+1836072691+B+((A|~r)^j)|0;B=(w<<13|w>>>19)+f|0;w=F<<10|F>>>22;F=r<<10|r>>>22;r=E+1859775393+J+((H|~K)^w)|0;J=(r<<12|r>>>20)+D|0;r=b+1836072691+f+((B|~A)^F)|0;f=(r<<13|r>>>19)+j|0;r=K<<10|K>>>22;K=A<<10|A>>>22;A=v+1859775393+D+((J|~H)^r)|0;D=(A<<7|A>>>25)+w|0;A=q+1836072691+j+((f|~B)^K)|0;j=(A<<7|A>>>25)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=y+1859775393+w+((D|~J)^A)|0;w=(B<<5|B>>>27)+r|0;B=G+1836072691+F+((j|~f)^H)|0;F=(B<<5|B>>>27)+K|0;B=J<<10|J>>>22;J=f<<10|f>>>22;f=s-1894007588+(g?K:r)+((w^D)&B^D)|0;p=(f<<11|f>>>21)+A|0;f=d+2053994217+(g?r:K)+(F&(j^J)^J)|0;K=(f<<15|f>>>17)+H|0;f=D<<10|D>>>22;D=j<<10|j>>>22;j=C-1894007588+A+((p^w)&f^w)|0;A=(j<<12|j>>>20)+B|0;j=l+2053994217+H+(K&(F^D)^D)|0;H=(j<<5|j>>>27)+J|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=E-1894007588+B+((A^p)&j^p)|0;B=(F<<14|F>>>18)+f|0;F=q+2053994217+J+(H&(K^w)^w)|0;J=(F<<8|F>>>24)+D|0;F=p<<10|p>>>22;p=K<<10|K>>>22;K=n-1894007588+f+((B^A)&F^A)|0;f=(K<<15|K>>>17)+j|0;K=s+2053994217+D+(J&(H^p)^p)|0;D=(K<<11|K>>>21)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=b-1894007588+j+((f^B)&K^B)|0;j=(H<<14|H>>>18)+F|0;H=u+2053994217+w+(D&(J^A)^A)|0;w=(H<<14|H>>>18)+p|0;H=B<<10|B>>>22;B=J<<10|J>>>22;J=d-1894007588+F+((j^f)&H^f)|0;F=(J<<15|J>>>17)+K|0;J=E+2053994217+p+(w&(D^B)^B)|0;p=(J<<14|J>>>18)+A|0;J=f<<10|f>>>22;f=D<<10|D>>>22;D=y-1894007588+K+((F^j)&J^j)|0;K=(D<<9|D>>>23)+H|0;D=I+2053994217+A+(p&(w^f)^f)|0;A=(D<<6|D>>>26)+B|0;D=j<<10|j>>>22;j=w<<10|w>>>22;w=q-1894007588+H+((K^F)&D^F)|0;H=(w<<8|w>>>24)+J|0;w=b+2053994217+B+(A&(p^j)^j)|0;B=(w<<14|w>>>18)+f|0;w=F<<10|F>>>22;F=p<<10|p>>>22;p=G-1894007588+J+((H^K)&w^K)|0;J=(p<<9|p>>>23)+D|0;p=v+2053994217+f+(B&(A^F)^F)|0;f=(p<<6|p>>>26)+j|0;p=K<<10|K>>>22;K=A<<10|A>>>22;A=u-1894007588+D+((J^H)&p^H)|0;D=(A<<14|A>>>18)+w|0;A=y+2053994217+j+(f&(B^K)^K)|0;j=(A<<9|A>>>23)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=z-1894007588+w+((D^J)&A^J)|0;w=(B<<5|B>>>27)+p|0;B=t+2053994217+F+(j&(f^H)^H)|0;F=(B<<12|B>>>20)+K|0;B=J<<10|J>>>22;J=f<<10|f>>>22;f=I-1894007588+p+((w^D)&B^D)|0;p=(f<<6|f>>>26)+A|0;f=G+2053994217+K+(F&(j^J)^J)|0;K=(f<<9|f>>>23)+H|0;f=D<<10|D>>>22;D=j<<10|j>>>22;j=x-1894007588+A+((p^w)&f^w)|0;A=(j<<8|j>>>24)+B|0;j=C+2053994217+H+(K&(F^D)^D)|0;H=(j<<12|j>>>20)+J|0;j=w<<10|w>>>22;w=F<<10|F>>>22;F=v-1894007588+B+((A^p)&j^p)|0;B=(F<<6|F>>>26)+f|0;F=z+2053994217+J+(H&(K^w)^w)|0;J=(F<<5|F>>>27)+D|0;F=p<<10|p>>>22;p=K<<10|K>>>22;K=l-1894007588+f+((B^A)&F^A)|0;f=(K<<5|K>>>27)+j|0;K=n+2053994217+D+(J&(H^p)^p)|0;D=(K<<15|K>>>17)+w|0;K=A<<10|A>>>22;A=H<<10|H>>>22;H=t-1894007588+j+((f^B)&K^B)|0;j=(H<<12|H>>>20)+F|0;H=x+2053994217+w+(D&(J^A)^A)|0;w=(H<<8|H>>>24)+p|0;H=B<<10|B>>>22;B=J<<10|J>>>22;J=g?D:f;r=g?f:D;D=q-1454113458+F+(j^(J|~H))|0;F=(D<<9|D>>>23)+K|0;D=p+y+(r^B^w)|0;p=(D<<8|D>>>24)+A|0;D=J<<10|J>>>22;J=r<<10|r>>>22;r=b-1454113458+K+(F^(j|~D))|0;K=(r<<15|r>>>17)+H|0;r=A+I+(J^w^p)|0;A=(r<<5|r>>>27)+B|0;r=j<<10|j>>>22;j=w<<10|w>>>22;w=v-1454113458+H+(K^(F|~r))|0;H=(w<<5|w>>>27)+D|0;w=B+n+(p^j^A)|0;B=(w<<12|w>>>20)+J|0;w=F<<10|F>>>22;F=p<<10|p>>>22;p=C-1454113458+D+(H^(K|~w))|0;D=(p<<11|p>>>21)+r|0;p=J+q+(A^F^B)|0;q=(p<<9|p>>>23)+j|0;p=K<<10|K>>>22;K=A<<10|A>>>22;A=z-1454113458+r+(D^(H|~p))|0;r=(A<<6|A>>>26)+w|0;A=j+s+(B^K^q)|0;j=(A<<12|A>>>20)+F|0;A=H<<10|H>>>22;H=B<<10|B>>>22;B=y-1454113458+w+(r^(D|~A))|0;w=(B<<8|B>>>24)+p|0;B=F+v+(q^H^j)|0;v=(B<<5|B>>>27)+K|0;B=D<<10|D>>>22;D=q<<10|q>>>22;q=t-1454113458+p+(w^(r|~B))|0;p=(q<<13|q>>>19)+A|0;q=K+d+(j^D^v)|0;K=(q<<14|q>>>18)+H|0;q=r<<10|r>>>22;r=j<<10|j>>>22;j=n-1454113458+A+(p^(w|~q))|0;A=(j<<12|j>>>20)+B|0;j=H+z+(v^r^K)|0;z=(j<<6|j>>>26)+D|0;j=w<<10|w>>>22;w=v<<10|v>>>22;v=x-1454113458+B+(A^(p|~j))|0;B=(v<<5|v>>>27)+q|0;v=D+l+(K^w^z)|0;D=(v<<8|v>>>24)+r|0;v=p<<10|p>>>22;p=K<<10|K>>>22;K=s-1454113458+q+(B^(A|~v))|0;q=(K<<12|K>>>20)+j|0;K=r+t+(z^p^D)|0;t=(K<<13|K>>>19)+w|0;K=A<<10|A>>>22;A=z<<10|z>>>22;z=u-1454113458+j+(q^(B|~K))|0;j=(z<<13|z>>>19)+v|0;z=w+G+(D^A^t)|0;w=(z<<6|z>>>26)+p|0;z=B<<10|B>>>22;B=D<<10|D>>>22;D=d-1454113458+v+(j^(q|~z))|0;v=(D<<14|D>>>18)+K|0;D=p+x+(t^B^w)|0;x=(D<<5|D>>>27)+A|0;D=q<<10|q>>>22;q=t<<10|t>>>22;t=E-1454113458+K+(v^(j|~D))|0;K=(t<<11|t>>>21)+z|0;t=A+b+(w^q^x)|0;b=(t<<15|t>>>17)+B|0;t=j<<10|j>>>22;j=w<<10|w>>>22;w=l-1454113458+z+(K^(v|~t))|0;z=(w<<8|w>>>24)+D|0;w=B+u+(x^j^b)|0;u=(w<<13|w>>>19)+q|0;w=v<<10|v>>>22;v=x<<10|x>>>22;x=I-1454113458+D+(z^(K|~w))|0;D=(x<<5|x>>>27)+t|0;x=q+C+(b^v^u)|0;C=(x<<11|x>>>21)+j|0;x=K<<10|K>>>22;K=b<<10|b>>>22;b=G-1454113458+t+(D^(z|~x))|0;t=(b<<6|b>>>26)+w|0;b=j+E+(u^K^C)|0;E=(b<<11|b>>>21)+v|0;b=z<<10|z>>>22;z=u<<10|u>>>22;u=g?K:x;j=g?x:K;if(g){c[a>>2]=(c[a>>2]|0)+w;c[h>>2]=(c[h>>2]|0)+t;c[k>>2]=(c[k>>2]|0)+D;c[m>>2]=(c[m>>2]|0)+b;c[o>>2]=(c[o>>2]|0)+u;g=a+20|0;c[g>>2]=(c[g>>2]|0)+v;g=a+24|0;c[g>>2]=(c[g>>2]|0)+E;g=a+28|0;c[g>>2]=(c[g>>2]|0)+C;g=a+32|0;c[g>>2]=(c[g>>2]|0)+z;g=a+36|0;c[g>>2]=(c[g>>2]|0)+j;i=e;return}else{g=D+z+(c[h>>2]|0)|0;c[h>>2]=b+j+(c[k>>2]|0);c[k>>2]=u+v+(c[m>>2]|0);c[m>>2]=E+w+(c[o>>2]|0);c[o>>2]=t+C+(c[a>>2]|0);c[a>>2]=g;i=e;return}}function JKb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+8|0;g=c[f>>2]|0;h=g&63;i=wrc(g,c[f+4>>2]|0,e,0)|0;c[f>>2]=i;c[f+4>>2]=G;do{if((h+e|0)>>>0>63>>>0){f=64-h|0;nrc(a+16+h|0,b|0,f)|0;i=a+124|0;g=a+80|0;j=a+120|0;ef[c[i>>2]&4095](g,a+16|0,d[j]|0);if((f+63|0)>>>0<e>>>0){k=f}else{l=0;m=f;break}while(1){ef[c[i>>2]&4095](g,b+k|0,d[j]|0);f=k+64|0;if((k+127|0)>>>0<e>>>0){k=f}else{l=0;m=f;break}}}else{l=h;m=0}}while(0);nrc(a+16+l|0,b+m|0,e-m|0)|0;return}function KKb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;f=i;i=i+8|0;g=f|0;h=b+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;c[g>>2]=j<<3|0>>>29;c[g+4>>2]=k<<3|j>>>29;l=j&63;m=wrc(j,k,1,0)|0;c[h>>2]=m;c[h+4>>2]=G;if((l+1|0)>>>0>63>>>0){m=64-l|0;nrc(b+16+l|0,2406120,m)|0;ef[c[b+124>>2]&4095](b+80|0,b+16|0,d[b+120|0]|0);n=0;o=m}else{n=l;o=0}nrc(b+16+n|0,2406120+o|0,1-o|0)|0;o=c[h>>2]|0;n=c[h+4>>2]|0;if((o&63|0)==56&(n&0|0)==0){p=n;q=o}else{l=b+124|0;m=b+80|0;k=b+16|0;j=b+120|0;r=n;n=o;while(1){o=n&63;s=wrc(n,r,1,0)|0;c[h>>2]=s;c[h+4>>2]=G;if((o+1|0)>>>0>63>>>0){s=64-o|0;nrc(b+16+o|0,10230688,s)|0;ef[c[l>>2]&4095](m,k,d[j]|0);t=0;u=s}else{t=o;u=0}nrc(b+16+t|0,10230688+u|0,1-u|0)|0;o=c[h>>2]|0;s=c[h+4>>2]|0;if((o&63|0)==56&(s&0|0)==0){p=s;q=o;break}else{r=s;n=o}}}n=g;g=q&63;r=wrc(q,p,8,0)|0;c[h>>2]=r;c[h+4>>2]=G;do{if((g+8|0)>>>0>63>>>0){h=64-g|0;nrc(b+16+g|0,n|0,h)|0;r=b+124|0;p=b+80|0;q=b+120|0;ef[c[r>>2]&4095](p,b+16|0,d[q]|0);if((h+63|0)>>>0<8>>>0){v=h}else{w=0;x=h;break}while(1){ef[c[r>>2]&4095](p,n+v|0,d[q]|0);h=v+64|0;if((v+127|0)>>>0<8>>>0){v=h}else{w=0;x=h;break}}}else{w=g;x=0}}while(0);nrc(b+16+w|0,n+x|0,8-x|0)|0;x=b|0;if((a[x]|0)==0){i=f;return}else{z=0}do{n=e+(z<<2)|0;y=c[b+80+(z<<2)>>2]|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;z=z+1|0;}while((z|0)<(d[x]|0));i=f;return}function LKb(a){a=a|0;var b=0;if(a>>>0>9>>>0){b=0}else{b=612168+(a*20|0)|0}return b|0}function MKb(a){a=a|0;var b=0,c=0,d=0;b=0;while(1){if((b|0)>=10){c=-1;d=4;break}if((irc(612168+(b*20|0)|0,a)|0)==0){c=b;d=4;break}else{b=b+1|0}}if((d|0)==4){return c|0}return 0}function NKb(a){a=a|0;var b=0;do{if(a>>>0>9>>>0){b=-1}else{if(!((a-5|0)>>>0<5>>>0)){b=a;break}b=c[612184+(a*20|0)>>2]|0}}while(0);return b|0}function OKb(a){a=a|0;var b=0;do{if(a>>>0>9>>>0){b=-1}else{if((a-5|0)>>>0<5>>>0){b=a;break}b=c[612184+(a*20|0)>>2]|0}}while(0);return b|0}function PKb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+24|0;f=e|0;if((d|0)<0){Rb(a|0,b|0,2405888,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0)|0;i=g;i=e;return a|0}if((d|0)>=10){i=e;return a|0}h=f|0;j=612168+(d*20|0)|0;c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];c[h+16>>2]=c[j+16>>2];j=c[f+8>>2]|0;Rb(a|0,b|0,2577240,(g=i,i=i+16|0,c[g>>2]=h,c[g+8>>2]=j,g)|0)|0;i=g;i=e;return a|0}function QKb(a){a=a|0;var b=0;if(a>>>0>9>>>0){b=0;return b|0}b=c[612176+(a*20|0)>>2]>>3;return b|0}function RKb(a){a=a|0;var b=0;if(a>>>0>9>>>0){b=0;return b|0}b=c[612180+(a*20|0)>>2]|0;return b|0}function SKb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(e>>>0>9>>>0){g=-22;return g|0}h=c[612176+(e*20|0)>>2]>>3;if((h|0)==0|(d|0)<1|(b|0)<1){g=-22;return g|0}do{if((f|0)==0){if((d|0)>2147483616){g=-22;return g|0}else{i=d+31&-32;j=1;break}}else{i=d;j=f}}while(0);if((2147483647/(j|0)|0|0)<(b|0)){g=-22;return g|0}f=Erc(i,(i|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;d=G;k=(2147483647-(ca(j,b)|0)|0)/(h|0)|0;l=(k|0)<0|0?-1:0;if((d|0)>(l|0)|(d|0)==(l|0)&f>>>0>k>>>0){g=-22;return g|0}k=(e-5|0)>>>0<5>>>0;e=ca(i,h)|0;if(k){m=j-1+e&-j}else{m=j-1+(ca(e,b)|0)&-j}if((a|0)!=0){c[a>>2]=m}if(!k){g=m;return g|0}g=ca(m,b)|0;return g|0}function TKb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if(g>>>0>9>>>0){i=-22;return i|0}j=c[612176+(g*20|0)>>2]>>3;if((j|0)==0|(f|0)<1|(e|0)<1){i=-22;return i|0}do{if((h|0)==0){if((f|0)>2147483616){i=-22;return i|0}else{k=f+31&-32;l=1;break}}else{k=f;l=h}}while(0);if((2147483647/(l|0)|0|0)<(e|0)){i=-22;return i|0}h=Erc(k,(k|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;f=G;m=(2147483647-(ca(l,e)|0)|0)/(j|0)|0;n=(m|0)<0|0?-1:0;if((f|0)>(n|0)|(f|0)==(n|0)&h>>>0>m>>>0){i=-22;return i|0}m=(g-5|0)>>>0<5>>>0;g=ca(k,j)|0;if(m){j=l-1+g&-l;o=ca(j,e)|0;p=j}else{j=l-1+(ca(g,e)|0)&-l;o=j;p=j}if((o|0)<0){i=o;return i|0}c[a>>2]=d;if(m&(e|0)>1){m=1;o=d;do{o=o+p|0;c[a+(m<<2)>>2]=o;m=m+1|0;}while((m|0)<(e|0))}if((b|0)==0){i=0;return i|0}c[b>>2]=p;i=0;return i|0}function UKb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(f>>>0>9>>>0){h=-22;return h|0}i=c[612176+(f*20|0)>>2]>>3;if((i|0)==0|(e|0)<1|(d|0)<1){h=-22;return h|0}do{if((g|0)==0){if((e|0)>2147483616){h=-22;return h|0}else{j=e+31&-32;k=1;break}}else{j=e;k=g}}while(0);if((2147483647/(k|0)|0|0)<(d|0)){h=-22;return h|0}l=Erc(j,(j|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;m=G;n=(2147483647-(ca(k,d)|0)|0)/(i|0)|0;o=(n|0)<0|0?-1:0;if((m|0)>(o|0)|(m|0)==(o|0)&l>>>0>n>>>0){h=-22;return h|0}n=(f-5|0)>>>0<5>>>0;l=ca(j,i)|0;if(n){p=ca(k-1+l&-k,d)|0}else{p=k-1+(ca(l,d)|0)&-k}if((p|0)<0){h=p;return h|0}k=hJb(p)|0;if((k|0)==0){h=-12;return h|0}p=TKb(a,b,k,d,e,f,g)|0;if((p|0)<0){kJb(k);h=p;return h|0}p=n?d:1;k=ca(ca(n?1:d,e)|0,i)|0;if((f|0)==0){q=-128}else{q=(f|0)==5?-128:0}if((p|0)>0){r=0}else{h=0;return h|0}while(1){mrc(c[a+(r<<2)>>2]|0,q|0,k|0)|0;f=r+1|0;if((f|0)<(p|0)){r=f}else{h=0;break}}return h|0}function VKb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(f>>>0>9>>>0){g=1;h=0;i=0;j=3}else{k=(f-5|0)>>>0<5>>>0;l=k?e:1;m=ca(c[612176+(f*20|0)>>2]>>3,k?1:e)|0;e=ca(m,d)|0;if((f|0)==0){n=-128;o=l;p=m;q=e}else{g=l;h=m;i=e;j=3}}if((j|0)==3){n=(f|0)==5?-128:0;o=g;p=h;q=i}i=ca(p,b)|0;if((o|0)>0){r=0}else{return 0}do{mrc((c[a+(r<<2)>>2]|0)+i|0,n|0,q|0)|0;r=r+1|0;}while((r|0)<(o|0));return 0}function WKb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if(f>>>0>9>>>0){h=1}else{h=(f-5|0)>>>0<5>>>0?d:1}i=qJb(h,4)|0;h=i;c[a>>2]=h;if((i|0)==0){j=-12;return j|0}i=UKb(h,b,d,e,f,g)|0;if((i|0)>=0){j=i;return j|0}mJb(a);j=i;return j|0}function XKb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if(h>>>0>9>>>0){i=0;j=g;k=1}else{l=(h-5|0)>>>0<5>>>0;i=c[612176+(h*20|0)>>2]>>3;j=l?1:g;k=l?g:1}g=ca(i,j)|0;j=ca(g,f)|0;f=ca(g,d)|0;d=ca(g,e)|0;e=c[a>>2]|0;g=c[b>>2]|0;if(e>>>0<g>>>0){m=g-e|0}else{m=e-g|0}i=(k|0)>0;if((m|0)<(j|0)){if(i){n=1;o=e;p=g}else{return 0}while(1){orc(o+f|0,p+d|0,j|0)|0;if((n|0)>=(k|0)){break}m=c[a+(n<<2)>>2]|0;l=c[b+(n<<2)>>2]|0;n=n+1|0;o=m;p=l}return 0}else{if(i){q=1;r=e;s=g}else{return 0}while(1){nrc(r+f|0,s+d|0,j)|0;if((q|0)>=(k|0)){break}g=c[a+(q<<2)>>2]|0;e=c[b+(q<<2)>>2]|0;q=q+1|0;r=g;s=e}return 0}return 0}function YKb(){return pJb(120)|0}function ZKb(b,d){b=b|0;d=d|0;var e=0;a[b|0]=d>>>5;if((d|0)==224){c[b+80>>2]=-1056596264;c[b+84>>2]=914150663;c[b+88>>2]=812702999;c[b+92>>2]=-150054599;c[b+96>>2]=-4191439;c[b+100>>2]=1750603025;c[b+104>>2]=1694076839;c[b+108>>2]=-1090891868;c[b+112>>2]=220}else if((d|0)==160){c[b+80>>2]=1732584193;c[b+84>>2]=-271733879;c[b+88>>2]=-1732584194;c[b+92>>2]=271733878;c[b+96>>2]=-1009589776;c[b+112>>2]=528}else if((d|0)==256){c[b+80>>2]=1779033703;c[b+84>>2]=-1150833019;c[b+88>>2]=1013904242;c[b+92>>2]=-1521486534;c[b+96>>2]=1359893119;c[b+100>>2]=-1694144372;c[b+104>>2]=528734635;c[b+108>>2]=1541459225;c[b+112>>2]=220}else{e=-1;return e|0}d=b+8|0;c[d>>2]=0;c[d+4>>2]=0;e=0;return e|0}function _Kb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=c[a>>2]|0;f=a+4|0;g=c[f>>2]|0;h=a+8|0;i=c[h>>2]|0;j=a+12|0;k=c[j>>2]|0;l=a+16|0;m=c[l>>2]|0;n=b;o=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=(e<<5|e>>>27)+1518500249+m+o+((k^i)&g^k)|0;m=g<<30|g>>>2;g=b+4|0;p=je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=k+1518500249+((m^i)&e^i)+p+(n<<5|n>>>27)|0;k=e<<30|e>>>2;q=b+8|0;r=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=i+1518500249+r+(n&(m^k)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+12|0;s=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=m+1518500249+s+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b+16|0;t=je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=k+1518500249+t+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b+20|0;u=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=i+1518500249+u+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+24|0;v=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=m+1518500249+v+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b+28|0;w=je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=k+1518500249+w+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b+32|0;x=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=i+1518500249+x+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+36|0;y=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=m+1518500249+y+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b+40|0;z=je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=k+1518500249+z+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b+44|0;A=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=A+1518500249+i+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+48|0;B=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=B+1518500249+m+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b+52|0;C=je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0;g=C+1518500249+k+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b+56|0;D=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=D+1518500249+i+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b+60|0;b=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=b+1518500249+m+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=r^o^x^C;o=g<<1|g>>>31;g=o+1518500249+k+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=s^p^y^D;p=q<<1|q>>>31;q=p+1518500249+i+(n&(k^m)^m)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=t^r^z^b;r=n<<1|n>>>31;n=r+1518500249+m+(g&(i^k)^k)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=u^s^A^o;s=g<<1|g>>>31;g=s+1518500249+k+(q&(m^i)^i)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=v^t^B^p;t=q<<1|q>>>31;q=t+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=w^u^C^r;u=n<<1|n>>>31;n=u+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=x^v^D^s;v=g<<1|g>>>31;g=v+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=y^w^b^t;w=q<<1|q>>>31;q=w+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=z^x^o^u;x=n<<1|n>>>31;n=x+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=A^y^p^v;y=g<<1|g>>>31;g=y+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=B^z^r^w;z=q<<1|q>>>31;q=z+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=C^A^s^x;A=n<<1|n>>>31;n=A+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=D^B^t^y;B=g<<1|g>>>31;g=B+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b^C^u^z;C=q<<1|q>>>31;q=C+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=o^D^v^A;D=n<<1|n>>>31;n=D+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=p^b^w^B;b=g<<1|g>>>31;g=b+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=r^o^x^C;o=q<<1|q>>>31;q=o+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=s^p^y^D;p=n<<1|n>>>31;n=p+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=t^r^z^b;r=g<<1|g>>>31;g=r+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=u^s^A^o;s=q<<1|q>>>31;q=s+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=v^t^B^p;t=n<<1|n>>>31;n=t+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=w^u^C^r;u=g<<1|g>>>31;g=u+1859775393+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=x^v^D^s;v=q<<1|q>>>31;q=v+1859775393+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=y^w^b^t;w=n<<1|n>>>31;n=w+1859775393+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=z^x^o^u;x=g<<1|g>>>31;g=x-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=A^y^p^v;y=q<<1|q>>>31;q=y-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=B^z^r^w;z=n<<1|n>>>31;n=z-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=C^A^s^x;A=g<<1|g>>>31;g=A-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=D^B^t^y;B=q<<1|q>>>31;q=B-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=b^C^u^z;C=n<<1|n>>>31;n=C-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=o^D^v^A;D=g<<1|g>>>31;g=D-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=p^b^w^B;b=q<<1|q>>>31;q=b-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=r^o^x^C;o=n<<1|n>>>31;n=o-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=s^p^y^D;p=g<<1|g>>>31;g=p-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=t^r^z^b;r=q<<1|q>>>31;q=r-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=u^s^A^o;s=n<<1|n>>>31;n=s-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=v^t^B^p;t=g<<1|g>>>31;g=t-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=w^u^C^r;u=q<<1|q>>>31;q=u-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=x^v^D^s;v=n<<1|n>>>31;n=v-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=y^w^b^t;w=g<<1|g>>>31;g=w-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=z^x^o^u;x=q<<1|q>>>31;q=x-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=A^y^p^v;y=n<<1|n>>>31;n=y-1894007588+m+((g|i)&k|g&i)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=B^z^r^w;z=g<<1|g>>>31;g=z-1894007588+k+((q|m)&i|q&m)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=C^A^s^x;A=q<<1|q>>>31;q=A-1894007588+i+((n|k)&m|n&k)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=D^B^t^y;B=n<<1|n>>>31;n=B-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=b^C^u^z;C=g<<1|g>>>31;g=C-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=o^D^v^A;D=q<<1|q>>>31;q=D-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=p^b^w^B;b=n<<1|n>>>31;n=b-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=r^o^x^C;o=g<<1|g>>>31;g=o-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=s^p^y^D;p=q<<1|q>>>31;q=p-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=t^r^z^b;r=n<<1|n>>>31;n=r-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=u^s^A^o;s=g<<1|g>>>31;g=s-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=v^t^B^p;t=q<<1|q>>>31;q=t-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=w^u^C^r;u=n<<1|n>>>31;n=u-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=x^v^D^s;v=g<<1|g>>>31;g=v-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=y^w^b^t;w=q<<1|q>>>31;q=w-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=z^x^o^u;x=n<<1|n>>>31;n=x-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=A^y^p^v;y=g<<1|g>>>31;g=y-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=B^z^r^w;r=q<<1|q>>>31;q=r-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=C^A^s^x;x=n<<1|n>>>31;n=x-899497514+m+(i^k^g)+(q<<5|q>>>27)|0;m=g<<30|g>>>2;g=D^B^t^y;y=g<<1|g>>>31;g=y-899497514+k+(m^i^q)+(n<<5|n>>>27)|0;k=q<<30|q>>>2;q=b^C^u^r;r=(q<<1|q>>>31)-899497514+i+(k^m^n)+(g<<5|g>>>27)|0;i=n<<30|n>>>2;n=o^D^v^x;x=(n<<1|n>>>31)-899497514+m+(i^k^g)+(r<<5|r>>>27)|0;m=g<<30|g>>>2;g=p^b^w^y;c[a>>2]=e-899497514+(g<<1|g>>>31)+k+(m^i^r)+(x<<5|x>>>27);c[f>>2]=x+(c[f>>2]|0);c[h>>2]=(r<<30|r>>>2)+(c[h>>2]|0);c[j>>2]=m+(c[j>>2]|0);c[l>>2]=i+(c[l>>2]|0);return}function $Kb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=c[a>>2]|0;f=a+4|0;g=c[f>>2]|0;h=a+8|0;i=c[h>>2]|0;j=a+12|0;k=c[j>>2]|0;l=a+16|0;m=c[l>>2]|0;n=a+20|0;o=c[n>>2]|0;p=a+24|0;q=c[p>>2]|0;r=a+28|0;s=c[r>>2]|0;t=b;u=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=s+1116352408+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))+((q^o)&m^q)+u|0;s=t+k|0;k=((i|g)&e|i&g)+((e<<30|e>>>2)^(e<<19|e>>>13)^(e<<10|e>>>22))+t|0;t=b+4|0;v=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=q+1899447441+v+(s&(o^m)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(g|e)|g&e)+t|0;t=b+8|0;w=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=o-1245643825+w+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=t+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|e)|k&e)+t|0;t=b+12|0;x=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=m-373957723+x+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=t+e|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+t|0;t=b+16|0;z=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=s+961987163+z+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=b+20|0;A=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=q+1508970993+A+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=b+24|0;B=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=B-1841331548+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=t+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+t|0;t=b+28|0;C=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=C-1424204075+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=t+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+t|0;t=b+32|0;D=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=D-670586216+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=b+36|0;E=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=E+310598401+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=b+40|0;F=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=F+607225278+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=t+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+t|0;t=b+44|0;G=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=G+1426881987+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=t+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+t|0;t=b+48|0;H=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=H+1925078388+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=b+52|0;I=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=I-2132889090+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=b+56|0;J=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=J-1680079193+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=t+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+t|0;t=b+60|0;b=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=b-1046744716+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=t+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+t|0;t=((v<<14|v>>>18)^v>>>3^(v<<25|v>>>7))+u+E+((J<<13|J>>>19)^J>>>10^(J<<15|J>>>17))|0;u=t-459576895+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=u+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+u|0;u=((w<<14|w>>>18)^w>>>3^(w<<25|w>>>7))+v+F+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))|0;v=u-272742522+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=v+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+v|0;v=((x<<14|x>>>18)^x>>>3^(x<<25|x>>>7))+w+G+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))|0;w=v+264347078+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=w+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+w|0;w=((z<<14|z>>>18)^z>>>3^(z<<25|z>>>7))+x+H+((u<<13|u>>>19)^u>>>10^(u<<15|u>>>17))|0;x=w+604807628+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=x+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+x|0;x=((A<<14|A>>>18)^A>>>3^(A<<25|A>>>7))+z+I+((v<<13|v>>>19)^v>>>10^(v<<15|v>>>17))|0;z=x+770255983+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=z+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+z|0;z=((B<<14|B>>>18)^B>>>3^(B<<25|B>>>7))+A+J+((w<<13|w>>>19)^w>>>10^(w<<15|w>>>17))|0;A=z+1249150122+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=A+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+A|0;A=((C<<14|C>>>18)^C>>>3^(C<<25|C>>>7))+B+b+((x<<13|x>>>19)^x>>>10^(x<<15|x>>>17))|0;B=A+1555081692+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=B+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+B|0;B=((D<<14|D>>>18)^D>>>3^(D<<25|D>>>7))+C+t+((z<<13|z>>>19)^z>>>10^(z<<15|z>>>17))|0;C=B+1996064986+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=C+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+C|0;C=((E<<14|E>>>18)^E>>>3^(E<<25|E>>>7))+D+u+((A<<13|A>>>19)^A>>>10^(A<<15|A>>>17))|0;D=C-1740746414+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=D+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+D|0;D=((F<<14|F>>>18)^F>>>3^(F<<25|F>>>7))+E+v+((B<<13|B>>>19)^B>>>10^(B<<15|B>>>17))|0;E=D-1473132947+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=E+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+E|0;E=((G<<14|G>>>18)^G>>>3^(G<<25|G>>>7))+F+w+((C<<13|C>>>19)^C>>>10^(C<<15|C>>>17))|0;F=E-1341970488+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=F+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+F|0;F=((H<<14|H>>>18)^H>>>3^(H<<25|H>>>7))+G+x+((D<<13|D>>>19)^D>>>10^(D<<15|D>>>17))|0;G=F-1084653625+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=G+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+G|0;G=((I<<14|I>>>18)^I>>>3^(I<<25|I>>>7))+H+z+((E<<13|E>>>19)^E>>>10^(E<<15|E>>>17))|0;H=G-958395405+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=H+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+H|0;H=((J<<14|J>>>18)^J>>>3^(J<<25|J>>>7))+I+A+((F<<13|F>>>19)^F>>>10^(F<<15|F>>>17))|0;I=H-710438585+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=I+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+I|0;I=((b<<14|b>>>18)^b>>>3^(b<<25|b>>>7))+J+B+((G<<13|G>>>19)^G>>>10^(G<<15|G>>>17))|0;J=I+113926993+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=J+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+J|0;J=((t<<14|t>>>18)^t>>>3^(t<<25|t>>>7))+b+C+((H<<13|H>>>19)^H>>>10^(H<<15|H>>>17))|0;b=J+338241895+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=b+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+b|0;b=((u<<14|u>>>18)^u>>>3^(u<<25|u>>>7))+t+D+((I<<13|I>>>19)^I>>>10^(I<<15|I>>>17))|0;t=b+666307205+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=((v<<14|v>>>18)^v>>>3^(v<<25|v>>>7))+u+E+((J<<13|J>>>19)^J>>>10^(J<<15|J>>>17))|0;u=t+773529912+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=u+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+u|0;u=((w<<14|w>>>18)^w>>>3^(w<<25|w>>>7))+v+F+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))|0;v=u+1294757372+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=v+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+v|0;v=((x<<14|x>>>18)^x>>>3^(x<<25|x>>>7))+w+G+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))|0;w=v+1396182291+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=w+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+w|0;w=((z<<14|z>>>18)^z>>>3^(z<<25|z>>>7))+x+H+((u<<13|u>>>19)^u>>>10^(u<<15|u>>>17))|0;x=w+1695183700+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=x+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+x|0;x=((A<<14|A>>>18)^A>>>3^(A<<25|A>>>7))+z+I+((v<<13|v>>>19)^v>>>10^(v<<15|v>>>17))|0;z=x+1986661051+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=z+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+z|0;z=((B<<14|B>>>18)^B>>>3^(B<<25|B>>>7))+A+J+((w<<13|w>>>19)^w>>>10^(w<<15|w>>>17))|0;A=z-2117940946+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=A+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+A|0;A=((C<<14|C>>>18)^C>>>3^(C<<25|C>>>7))+B+b+((x<<13|x>>>19)^x>>>10^(x<<15|x>>>17))|0;B=A-1838011259+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=B+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+B|0;B=((D<<14|D>>>18)^D>>>3^(D<<25|D>>>7))+C+t+((z<<13|z>>>19)^z>>>10^(z<<15|z>>>17))|0;C=B-1564481375+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=C+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+C|0;C=((E<<14|E>>>18)^E>>>3^(E<<25|E>>>7))+D+u+((A<<13|A>>>19)^A>>>10^(A<<15|A>>>17))|0;D=C-1474664885+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=D+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+D|0;D=((F<<14|F>>>18)^F>>>3^(F<<25|F>>>7))+E+v+((B<<13|B>>>19)^B>>>10^(B<<15|B>>>17))|0;E=D-1035236496+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=E+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+E|0;E=((G<<14|G>>>18)^G>>>3^(G<<25|G>>>7))+F+w+((C<<13|C>>>19)^C>>>10^(C<<15|C>>>17))|0;F=E-949202525+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=F+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+F|0;F=((H<<14|H>>>18)^H>>>3^(H<<25|H>>>7))+G+x+((D<<13|D>>>19)^D>>>10^(D<<15|D>>>17))|0;G=F-778901479+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=G+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+G|0;G=((I<<14|I>>>18)^I>>>3^(I<<25|I>>>7))+H+z+((E<<13|E>>>19)^E>>>10^(E<<15|E>>>17))|0;H=G-694614492+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=H+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+H|0;H=((J<<14|J>>>18)^J>>>3^(J<<25|J>>>7))+I+A+((F<<13|F>>>19)^F>>>10^(F<<15|F>>>17))|0;I=H-200395387+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=I+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+I|0;I=((b<<14|b>>>18)^b>>>3^(b<<25|b>>>7))+J+B+((G<<13|G>>>19)^G>>>10^(G<<15|G>>>17))|0;J=I+275423344+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=J+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+J|0;J=((t<<14|t>>>18)^t>>>3^(t<<25|t>>>7))+b+C+((H<<13|H>>>19)^H>>>10^(H<<15|H>>>17))|0;b=J+430227734+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=b+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+b|0;b=((u<<14|u>>>18)^u>>>3^(u<<25|u>>>7))+t+D+((I<<13|I>>>19)^I>>>10^(I<<15|I>>>17))|0;t=b+506948616+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=((v<<14|v>>>18)^v>>>3^(v<<25|v>>>7))+u+E+((J<<13|J>>>19)^J>>>10^(J<<15|J>>>17))|0;u=t+659060556+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=u+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+u|0;u=((w<<14|w>>>18)^w>>>3^(w<<25|w>>>7))+v+F+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))|0;v=u+883997877+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=v+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+v|0;v=((x<<14|x>>>18)^x>>>3^(x<<25|x>>>7))+w+G+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))|0;w=v+958139571+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=w+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+w|0;w=((z<<14|z>>>18)^z>>>3^(z<<25|z>>>7))+x+H+((u<<13|u>>>19)^u>>>10^(u<<15|u>>>17))|0;x=w+1322822218+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=x+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+x|0;x=((A<<14|A>>>18)^A>>>3^(A<<25|A>>>7))+z+I+((v<<13|v>>>19)^v>>>10^(v<<15|v>>>17))|0;z=x+1537002063+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=z+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+z|0;z=((B<<14|B>>>18)^B>>>3^(B<<25|B>>>7))+A+J+((w<<13|w>>>19)^w>>>10^(w<<15|w>>>17))|0;A=z+1747873779+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=A+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+A|0;A=((C<<14|C>>>18)^C>>>3^(C<<25|C>>>7))+B+b+((x<<13|x>>>19)^x>>>10^(x<<15|x>>>17))|0;b=A+1955562222+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=b+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+b|0;b=((D<<14|D>>>18)^D>>>3^(D<<25|D>>>7))+C+t+((z<<13|z>>>19)^z>>>10^(z<<15|z>>>17))|0;t=b+2024104815+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=t+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+t|0;t=((E<<14|E>>>18)^E>>>3^(E<<25|E>>>7))+D+u+((A<<13|A>>>19)^A>>>10^(A<<15|A>>>17))|0;u=t-2067236844+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=u+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+u|0;u=((F<<14|F>>>18)^F>>>3^(F<<25|F>>>7))+E+v+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))|0;b=u-1933114872+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;m=b+y|0;y=((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+(g&(i|k)|i&k)+b|0;b=((G<<14|G>>>18)^G>>>3^(G<<25|G>>>7))+F+w+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))|0;t=b-1866530822+s+(m&(o^q)^q)+((m<<26|m>>>6)^(m<<21|m>>>11)^(m<<7|m>>>25))|0;s=t+k|0;k=((y<<30|y>>>2)^(y<<19|y>>>13)^(y<<10|y>>>22))+(y&(g|i)|g&i)+t|0;t=((H<<14|H>>>18)^H>>>3^(H<<25|H>>>7))+G+x+((u<<13|u>>>19)^u>>>10^(u<<15|u>>>17))|0;u=t-1538233109+q+(s&(m^o)^o)+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))|0;q=u+i|0;i=((k<<30|k>>>2)^(k<<19|k>>>13)^(k<<10|k>>>22))+(k&(y|g)|y&g)+u|0;u=H-1090935817+((I<<14|I>>>18)^I>>>3^(I<<25|I>>>7))+z+((b<<13|b>>>19)^b>>>10^(b<<15|b>>>17))+o+(q&(s^m)^m)+((q<<26|q>>>6)^(q<<21|q>>>11)^(q<<7|q>>>25))|0;o=u+g|0;g=((i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22))+(i&(k|y)|k&y)+u|0;u=I-965641998+((J<<14|J>>>18)^J>>>3^(J<<25|J>>>7))+A+((t<<13|t>>>19)^t>>>10^(t<<15|t>>>17))+m+(o&(q^s)^s)+((o<<26|o>>>6)^(o<<21|o>>>11)^(o<<7|o>>>25))|0;c[a>>2]=(g&(i|k)|i&k)+e+((g<<30|g>>>2)^(g<<19|g>>>13)^(g<<10|g>>>22))+u;c[f>>2]=g+(c[f>>2]|0);c[h>>2]=i+(c[h>>2]|0);c[j>>2]=k+(c[j>>2]|0);c[l>>2]=y+(c[l>>2]|0)+u;c[n>>2]=o+(c[n>>2]|0);c[p>>2]=q+(c[p>>2]|0);c[r>>2]=s+(c[r>>2]|0);return}function aLb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a+8|0;f=c[e>>2]|0;g=f&63;h=wrc(f,c[e+4>>2]|0,d,0)|0;c[e>>2]=h;c[e+4>>2]=G;do{if((g+d|0)>>>0>63>>>0){e=64-g|0;nrc(a+16+g|0,b|0,e)|0;h=a+112|0;f=a+80|0;re[c[h>>2]&1023](f,a+16|0);if((e+63|0)>>>0<d>>>0){i=e}else{j=0;k=e;break}while(1){re[c[h>>2]&1023](f,b+i|0);e=i+64|0;if((i+127|0)>>>0<d>>>0){i=e}else{j=0;k=e;break}}}else{j=g;k=0}}while(0);nrc(a+16+j|0,b+k|0,d-k|0)|0;return}function bLb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+8|0;g=f|0;h=b+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;l=je(j<<3|0>>>29|0)|0;c[g>>2]=je(j>>>29|k<<3|0)|0;c[g+4>>2]=l;l=j&63;m=wrc(j,k,1,0)|0;c[h>>2]=m;c[h+4>>2]=G;if((l+1|0)>>>0>63>>>0){m=64-l|0;nrc(b+16+l|0,2405712,m)|0;re[c[b+112>>2]&1023](b+80|0,b+16|0);n=0;o=m}else{n=l;o=0}nrc(b+16+n|0,2405712+o|0,1-o|0)|0;o=c[h>>2]|0;n=c[h+4>>2]|0;if((o&63|0)==56&(n&0|0)==0){p=n;q=o}else{l=b+112|0;m=b+80|0;k=b+16|0;j=n;n=o;while(1){o=n&63;r=wrc(n,j,1,0)|0;c[h>>2]=r;c[h+4>>2]=G;if((o+1|0)>>>0>63>>>0){r=64-o|0;nrc(b+16+o|0,10230680,r)|0;re[c[l>>2]&1023](m,k);s=0;t=r}else{s=o;t=0}nrc(b+16+s|0,10230680+t|0,1-t|0)|0;o=c[h>>2]|0;r=c[h+4>>2]|0;if((o&63|0)==56&(r&0|0)==0){p=r;q=o;break}else{j=r;n=o}}}n=g;g=q&63;j=wrc(q,p,8,0)|0;c[h>>2]=j;c[h+4>>2]=G;do{if((g+8|0)>>>0>63>>>0){h=64-g|0;nrc(b+16+g|0,n|0,h)|0;j=b+112|0;p=b+80|0;re[c[j>>2]&1023](p,b+16|0);if((h+63|0)>>>0<8>>>0){u=h}else{v=0;w=h;break}while(1){re[c[j>>2]&1023](p,n+u|0);h=u+64|0;if((u+127|0)>>>0<8>>>0){u=h}else{v=0;w=h;break}}}else{v=g;w=0}}while(0);nrc(b+16+v|0,n+w|0,8-w|0)|0;w=b|0;if((a[w]|0)==0){i=f;return}else{x=0}do{n=e+(x<<2)|0;y=je(c[b+80+(x<<2)>>2]|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;x=x+1|0;}while((x|0)<(d[w]|0));i=f;return}function cLb(){return pJb(208)|0}function dLb(b,d){b=b|0;d=d|0;var e=0,f=0;a[b|0]=d>>>6;if((d|0)==384){e=b+144|0;c[e>>2]=-1056596264;c[e+4>>2]=-876896931;e=b+152|0;c[e>>2]=914150663;c[e+4>>2]=1654270250;e=b+160|0;c[e>>2]=812702999;c[e+4>>2]=-1856437926;e=b+168|0;c[e>>2]=-150054599;c[e+4>>2]=355462360;e=b+176|0;c[e>>2]=-4191439;c[e+4>>2]=1731405415;e=b+184|0;c[e>>2]=1750603025;c[e+4>>2]=-1900787065;e=b+192|0;c[e>>2]=1694076839;c[e+4>>2]=-619958771;e=b+200|0;c[e>>2]=-1090891868;c[e+4>>2]=1203062813}else if((d|0)==512){e=b+144|0;c[e>>2]=-205731576;c[e+4>>2]=1779033703;e=b+152|0;c[e>>2]=-2067093701;c[e+4>>2]=-1150833019;e=b+160|0;c[e>>2]=-23791573;c[e+4>>2]=1013904242;e=b+168|0;c[e>>2]=1595750129;c[e+4>>2]=-1521486534;e=b+176|0;c[e>>2]=-1377402159;c[e+4>>2]=1359893119;e=b+184|0;c[e>>2]=725511199;c[e+4>>2]=-1694144372;e=b+192|0;c[e>>2]=-79577749;c[e+4>>2]=528734635;e=b+200|0;c[e>>2]=327033209;c[e+4>>2]=1541459225}else if((d|0)==256){e=b+144|0;c[e>>2]=-64227540;c[e+4>>2]=573645204;e=b+152|0;c[e>>2]=-934517566;c[e+4>>2]=-1621794909;e=b+160|0;c[e>>2]=1867755857;c[e+4>>2]=596883563;e=b+168|0;c[e>>2]=1497426621;c[e+4>>2]=-1774684391;e=b+176|0;c[e>>2]=-1467023389;c[e+4>>2]=-1775747358;e=b+184|0;c[e>>2]=1401305490;c[e+4>>2]=-1101128155;e=b+192|0;c[e>>2]=746961066;c[e+4>>2]=721525244;e=b+200|0;c[e>>2]=-2117784414;c[e+4>>2]=246885852}else if((d|0)==224){d=b+144|0;c[d>>2]=424955298;c[d+4>>2]=-1942145080;d=b+152|0;c[d>>2]=-1982016298;c[d+4>>2]=1944164710;d=b+160|0;c[d>>2]=855612546;c[d+4>>2]=502970286;d=b+168|0;c[d>>2]=1479516111;c[d+4>>2]=1738396948;d=b+176|0;c[d>>2]=2077511080;c[d+4>>2]=258812777;d=b+184|0;c[d>>2]=79989058;c[d+4>>2]=2011393907;d=b+192|0;c[d>>2]=1780299464;c[d+4>>2]=1067287976;d=b+200|0;c[d>>2]=-1848208735;c[d+4>>2]=286451373}else{f=-1;return f|0}d=b+8|0;c[d>>2]=0;c[d+4>>2]=0;f=0;return f|0}function eLb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a+8|0;f=c[e>>2]|0;g=f&127;h=wrc(f,c[e+4>>2]|0,d,0)|0;c[e>>2]=h;c[e+4>>2]=G;do{if((g+d|0)>>>0>127>>>0){e=128-g|0;nrc(a+16+g|0,b|0,e)|0;h=a+144|0;fLb(h,a+16|0);if((e+127|0)>>>0<d>>>0){i=e}else{j=0;k=e;break}while(1){fLb(h,b+i|0);e=i+128|0;if((i+255|0)>>>0<d>>>0){i=e}else{j=0;k=e;break}}}else{j=g;k=0}}while(0);nrc(a+16+j|0,b+k|0,d-k|0)|0;return}function fLb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;e=c[a>>2]|0;f=c[a+4>>2]|0;g=a+8|0;h=c[g>>2]|0;i=c[g+4>>2]|0;j=a+16|0;k=c[j>>2]|0;l=c[j+4>>2]|0;m=a+24|0;n=c[m>>2]|0;o=c[m+4>>2]|0;p=a+32|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=a+40|0;t=c[s>>2]|0;u=c[s+4>>2]|0;v=a+48|0;w=c[v>>2]|0;x=c[v+4>>2]|0;y=a+56|0;z=c[y>>2]|0;A=c[y+4>>2]|0;B=b;C=B|0;D=B+4|0;B=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=je(B|0)|0;B=D|0;D=wrc(z,A,-685199838,1116352408)|0;A=wrc(D,G,(q>>>14|r<<18|(0<<18|0>>>14))^(q>>>18|r<<14|(0<<14|0>>>18))^(r>>>9|0<<23|(q<<23|0>>>9)),(r>>>14|0<<18|(q<<18|0>>>14))^(r>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(r<<23|q>>>9)))|0;D=wrc(A,G,(w^t)&q^w,(x^u)&r^x)|0;A=wrc(D,G,C,B)|0;D=G;z=wrc(A,D,n,o)|0;o=G;n=wrc((k|h)&e|k&h,(l|i)&f|l&i,(e>>>28|f<<4|(0<<4|0>>>28))^(f>>>2|0<<30|(e<<30|0>>>2))^(f>>>7|0<<25|(e<<25|0>>>7)),(f>>>28|0<<4|(e<<4|0>>>28))^(0>>>2|0<<30|(f<<30|e>>>2))^(0>>>7|0<<25|(f<<25|e>>>7)))|0;E=wrc(n,G,A,D)|0;D=G;A=b+8|0;n=A|0;F=A+4|0;A=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;F=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=je(A|0)|0;A=n|0;H=F|0;F=wrc(w,x,602891725,1899447441)|0;x=wrc(F,G,A,H)|0;F=wrc(x,G,z&(t^q)^t,o&(u^r)^u)|0;x=wrc(F,G,(z>>>14|o<<18|(0<<18|0>>>14))^(z>>>18|o<<14|(0<<14|0>>>18))^(o>>>9|0<<23|(z<<23|0>>>9)),(o>>>14|0<<18|(z<<18|0>>>14))^(o>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(o<<23|z>>>9)))|0;F=G;w=wrc(x,F,k,l)|0;l=G;k=wrc((E>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(E<<30|0>>>2))^(D>>>7|0<<25|(E<<25|0>>>7)),(D>>>28|0<<4|(E<<4|0>>>28))^(0>>>2|0<<30|(D<<30|E>>>2))^(0>>>7|0<<25|(D<<25|E>>>7)),E&(h|e)|h&e,D&(i|f)|i&f)|0;I=wrc(k,G,x,F)|0;F=G;x=b+16|0;k=x|0;J=x+4|0;x=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;J=je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0;k=je(x|0)|0;x=k|0;K=J|0;J=wrc(t,u,-330482897,-1245643825)|0;u=wrc(J,G,x,K)|0;J=wrc(u,G,w&(z^q)^q,l&(o^r)^r)|0;u=wrc(J,G,(w>>>14|l<<18|(0<<18|0>>>14))^(w>>>18|l<<14|(0<<14|0>>>18))^(l>>>9|0<<23|(w<<23|0>>>9)),(l>>>14|0<<18|(w<<18|0>>>14))^(l>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(l<<23|w>>>9)))|0;J=G;t=wrc(u,J,h,i)|0;i=G;h=wrc((I>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(I<<30|0>>>2))^(F>>>7|0<<25|(I<<25|0>>>7)),(F>>>28|0<<4|(I<<4|0>>>28))^(0>>>2|0<<30|(F<<30|I>>>2))^(0>>>7|0<<25|(F<<25|I>>>7)),I&(E|e)|E&e,F&(D|f)|D&f)|0;L=wrc(h,G,u,J)|0;J=G;u=b+24|0;h=u|0;M=u+4|0;u=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;M=je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0;h=je(u|0)|0;u=h|0;N=M|0;M=wrc(q,r,-2121671748,-373957723)|0;r=wrc(M,G,u,N)|0;M=wrc(r,G,t&(w^z)^z,i&(l^o)^o)|0;r=wrc(M,G,(t>>>14|i<<18|(0<<18|0>>>14))^(t>>>18|i<<14|(0<<14|0>>>18))^(i>>>9|0<<23|(t<<23|0>>>9)),(i>>>14|0<<18|(t<<18|0>>>14))^(i>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(i<<23|t>>>9)))|0;M=G;q=wrc(r,M,e,f)|0;O=G;P=wrc((L>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(L<<30|0>>>2))^(J>>>7|0<<25|(L<<25|0>>>7)),(J>>>28|0<<4|(L<<4|0>>>28))^(0>>>2|0<<30|(J<<30|L>>>2))^(0>>>7|0<<25|(J<<25|L>>>7)),L&(I|E)|I&E,J&(F|D)|F&D)|0;Q=wrc(P,G,r,M)|0;M=G;r=b+32|0;P=r|0;R=r+4|0;r=d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0;R=je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=je(r|0)|0;r=P|0;S=R|0;R=wrc(z,o,-213338824,961987163)|0;o=wrc(R,G,r,S)|0;R=wrc(o,G,q&(t^w)^w,O&(i^l)^l)|0;o=wrc(R,G,(q>>>14|O<<18|(0<<18|0>>>14))^(q>>>18|O<<14|(0<<14|0>>>18))^(O>>>9|0<<23|(q<<23|0>>>9)),(O>>>14|0<<18|(q<<18|0>>>14))^(O>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(O<<23|q>>>9)))|0;R=G;z=wrc(o,R,E,D)|0;D=G;E=wrc((Q>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(Q<<30|0>>>2))^(M>>>7|0<<25|(Q<<25|0>>>7)),(M>>>28|0<<4|(Q<<4|0>>>28))^(0>>>2|0<<30|(M<<30|Q>>>2))^(0>>>7|0<<25|(M<<25|Q>>>7)),Q&(L|I)|L&I,M&(J|F)|J&F)|0;T=wrc(E,G,o,R)|0;R=G;o=b+40|0;E=o|0;U=o+4|0;o=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;U=je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0;E=je(o|0)|0;o=E|0;V=U|0;U=wrc(w,l,-1241133031,1508970993)|0;l=wrc(U,G,o,V)|0;U=wrc(l,G,z&(q^t)^t,D&(O^i)^i)|0;l=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(l,U,I,F)|0;F=G;I=wrc((T>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(T<<30|0>>>2))^(R>>>7|0<<25|(T<<25|0>>>7)),(R>>>28|0<<4|(T<<4|0>>>28))^(0>>>2|0<<30|(R<<30|T>>>2))^(0>>>7|0<<25|(R<<25|T>>>7)),T&(Q|L)|Q&L,R&(M|J)|M&J)|0;W=wrc(I,G,l,U)|0;U=G;l=b+48|0;I=l|0;X=l+4|0;l=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;X=je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0;I=je(l|0)|0;l=I|0;Y=X|0;X=wrc(t,i,-1357295717,-1841331548)|0;i=wrc(X,G,l,Y)|0;X=wrc(i,G,w&(z^q)^q,F&(D^O)^O)|0;i=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(i,X,L,J)|0;J=G;L=wrc((W>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(W<<30|0>>>2))^(U>>>7|0<<25|(W<<25|0>>>7)),(U>>>28|0<<4|(W<<4|0>>>28))^(0>>>2|0<<30|(U<<30|W>>>2))^(0>>>7|0<<25|(U<<25|W>>>7)),W&(T|Q)|T&Q,U&(R|M)|R&M)|0;Z=wrc(L,G,i,X)|0;X=G;i=b+56|0;L=i|0;_=i+4|0;i=d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0;_=je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=je(i|0)|0;i=L|0;$=_|0;_=wrc(q,O,-630357736,-1424204075)|0;O=wrc(_,G,i,$)|0;_=wrc(O,G,t&(w^z)^z,J&(F^D)^D)|0;O=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(O,_,Q,M)|0;M=G;Q=wrc((Z>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(Z<<30|0>>>2))^(X>>>7|0<<25|(Z<<25|0>>>7)),(X>>>28|0<<4|(Z<<4|0>>>28))^(0>>>2|0<<30|(X<<30|Z>>>2))^(0>>>7|0<<25|(X<<25|Z>>>7)),Z&(W|T)|W&T,X&(U|R)|U&R)|0;aa=wrc(Q,G,O,_)|0;_=G;O=b+64|0;Q=O|0;ba=O+4|0;O=d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0;ba=je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Q=je(O|0)|0;O=Q|0;ca=ba|0;ba=wrc(O,ca,-1560083902,-670586216)|0;da=wrc(ba,G,z,D)|0;D=wrc(da,G,q&(t^w)^w,M&(J^F)^F)|0;da=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(da,D,T,R)|0;R=G;T=wrc((aa>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(aa<<30|0>>>2))^(_>>>7|0<<25|(aa<<25|0>>>7)),(_>>>28|0<<4|(aa<<4|0>>>28))^(0>>>2|0<<30|(_<<30|aa>>>2))^(0>>>7|0<<25|(_<<25|aa>>>7)),aa&(Z|W)|Z&W,_&(X|U)|X&U)|0;ba=wrc(T,G,da,D)|0;D=G;da=b+72|0;T=da|0;ea=da+4|0;da=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0;ea=je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0;T=je(da|0)|0;da=T|0;fa=ea|0;ea=wrc(da,fa,1164996542,310598401)|0;ga=wrc(ea,G,w,F)|0;F=wrc(ga,G,z&(q^t)^t,R&(M^J)^J)|0;ga=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(ga,F,W,U)|0;U=G;W=wrc((ba>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(ba<<30|0>>>2))^(D>>>7|0<<25|(ba<<25|0>>>7)),(D>>>28|0<<4|(ba<<4|0>>>28))^(0>>>2|0<<30|(D<<30|ba>>>2))^(0>>>7|0<<25|(D<<25|ba>>>7)),ba&(aa|Z)|aa&Z,D&(_|X)|_&X)|0;ea=wrc(W,G,ga,F)|0;F=G;ga=b+80|0;W=ga|0;ha=ga+4|0;ga=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;ha=je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0;W=je(ga|0)|0;ga=W|0;ia=ha|0;ha=wrc(ga,ia,1323610764,607225278)|0;ja=wrc(ha,G,t,J)|0;J=wrc(ja,G,w&(z^q)^q,U&(R^M)^M)|0;ja=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(ja,J,Z,X)|0;X=G;Z=wrc((ea>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(ea<<30|0>>>2))^(F>>>7|0<<25|(ea<<25|0>>>7)),(F>>>28|0<<4|(ea<<4|0>>>28))^(0>>>2|0<<30|(F<<30|ea>>>2))^(0>>>7|0<<25|(F<<25|ea>>>7)),ea&(ba|aa)|ba&aa,F&(D|_)|D&_)|0;ha=wrc(Z,G,ja,J)|0;J=G;ja=b+88|0;Z=ja|0;ka=ja+4|0;ja=d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0;ka=je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0;Z=je(ja|0)|0;ja=Z|0;la=ka|0;ka=wrc(ja,la,-704662302,1426881987)|0;ma=wrc(ka,G,q,M)|0;M=wrc(ma,G,t&(w^z)^z,X&(U^R)^R)|0;ma=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(ma,M,aa,_)|0;_=G;aa=wrc((ha>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(ha<<30|0>>>2))^(J>>>7|0<<25|(ha<<25|0>>>7)),(J>>>28|0<<4|(ha<<4|0>>>28))^(0>>>2|0<<30|(J<<30|ha>>>2))^(0>>>7|0<<25|(J<<25|ha>>>7)),ha&(ea|ba)|ea&ba,J&(F|D)|F&D)|0;ka=wrc(aa,G,ma,M)|0;M=G;ma=b+96|0;aa=ma|0;na=ma+4|0;ma=d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0;na=je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0;aa=je(ma|0)|0;ma=aa|0;oa=na|0;na=wrc(ma,oa,-226784913,1925078388)|0;pa=wrc(na,G,z,R)|0;R=wrc(pa,G,q&(t^w)^w,_&(X^U)^U)|0;pa=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(pa,R,ba,D)|0;D=G;ba=wrc((ka>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(ka<<30|0>>>2))^(M>>>7|0<<25|(ka<<25|0>>>7)),(M>>>28|0<<4|(ka<<4|0>>>28))^(0>>>2|0<<30|(M<<30|ka>>>2))^(0>>>7|0<<25|(M<<25|ka>>>7)),ka&(ha|ea)|ha&ea,M&(J|F)|J&F)|0;na=wrc(ba,G,pa,R)|0;R=G;pa=b+104|0;ba=pa|0;qa=pa+4|0;pa=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;qa=je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0;ba=je(pa|0)|0;pa=ba|0;ra=qa|0;qa=wrc(pa,ra,991336113,-2132889090)|0;sa=wrc(qa,G,w,U)|0;U=wrc(sa,G,z&(q^t)^t,D&(_^X)^X)|0;sa=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(sa,U,ea,F)|0;F=G;ea=wrc((na>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(na<<30|0>>>2))^(R>>>7|0<<25|(na<<25|0>>>7)),(R>>>28|0<<4|(na<<4|0>>>28))^(0>>>2|0<<30|(R<<30|na>>>2))^(0>>>7|0<<25|(R<<25|na>>>7)),na&(ka|ha)|ka&ha,R&(M|J)|M&J)|0;qa=wrc(ea,G,sa,U)|0;U=G;sa=b+112|0;ea=sa|0;ta=sa+4|0;sa=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;ta=je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0;ea=0;ua=je(sa|0)|0;sa=ua|0;va=ta|0;wa=wrc(sa,va,633803317,-1680079193)|0;xa=wrc(wa,G,t,X)|0;X=wrc(xa,G,w&(z^q)^q,F&(D^_)^_)|0;xa=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(xa,X,ha,J)|0;J=G;ha=wrc((qa>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(qa<<30|0>>>2))^(U>>>7|0<<25|(qa<<25|0>>>7)),(U>>>28|0<<4|(qa<<4|0>>>28))^(0>>>2|0<<30|(U<<30|qa>>>2))^(0>>>7|0<<25|(U<<25|qa>>>7)),qa&(na|ka)|na&ka,U&(R|M)|R&M)|0;wa=wrc(ha,G,xa,X)|0;X=G;xa=b+120|0;b=xa|0;ha=xa+4|0;xa=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;ha=je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;b=0;ya=je(xa|0)|0;xa=ya|0;za=ha|0;Aa=wrc(xa,za,-815192428,-1046744716)|0;Ba=wrc(Aa,G,q,_)|0;_=wrc(Ba,G,t&(w^z)^z,J&(F^D)^D)|0;Ba=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(Ba,_,ka,M)|0;M=G;ka=wrc((wa>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(wa<<30|0>>>2))^(X>>>7|0<<25|(wa<<25|0>>>7)),(X>>>28|0<<4|(wa<<4|0>>>28))^(0>>>2|0<<30|(X<<30|wa>>>2))^(0>>>7|0<<25|(X<<25|wa>>>7)),wa&(qa|na)|qa&na,X&(U|R)|U&R)|0;Aa=wrc(ka,G,Ba,_)|0;_=G;Ba=wrc((A>>>8|H<<24|(0<<24|0>>>8))^(A>>>7|H<<25)^(A>>>1|H<<31|(0<<31|0>>>1)),(H>>>8|0<<24|(n<<24|0>>>8))^(H>>>7|0<<25)^(H>>>1|0<<31|(n<<31|0>>>1)),C,B)|0;B=wrc(Ba,G,da,fa)|0;Ba=wrc(B,G,(sa<<3|0>>>29|(ta>>>29|ea<<3))^(sa>>>6|va<<26)^(sa>>>19|va<<13|(0<<13|0>>>19)),(va<<3|sa>>>29|(ea>>>29|0<<3))^(va>>>6|0<<26)^(va>>>19|0<<13|(ua<<13|0>>>19)))|0;ea=G;ta=wrc(Ba,ea,-1628353838,-459576895)|0;B=wrc(ta,G,z,D)|0;D=wrc(B,G,q&(t^w)^w,M&(J^F)^F)|0;B=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(B,D,na,R)|0;R=G;na=wrc((Aa>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(Aa<<30|0>>>2))^(_>>>7|0<<25|(Aa<<25|0>>>7)),(_>>>28|0<<4|(Aa<<4|0>>>28))^(0>>>2|0<<30|(_<<30|Aa>>>2))^(0>>>7|0<<25|(_<<25|Aa>>>7)),Aa&(wa|qa)|wa&qa,_&(X|U)|X&U)|0;ta=wrc(na,G,B,D)|0;D=G;B=wrc((x>>>8|K<<24|(0<<24|0>>>8))^(x>>>7|K<<25)^(x>>>1|K<<31|(0<<31|0>>>1)),(K>>>8|0<<24|(k<<24|0>>>8))^(K>>>7|0<<25)^(K>>>1|0<<31|(k<<31|0>>>1)),A,H)|0;H=wrc(B,G,ga,ia)|0;B=wrc(H,G,(xa<<3|0>>>29|(ha>>>29|b<<3))^(xa>>>6|za<<26)^(xa>>>19|za<<13|(0<<13|0>>>19)),(za<<3|xa>>>29|(b>>>29|0<<3))^(za>>>6|0<<26)^(za>>>19|0<<13|(ya<<13|0>>>19)))|0;b=G;ha=wrc(B,b,944711139,-272742522)|0;H=wrc(ha,G,w,F)|0;F=wrc(H,G,z&(q^t)^t,R&(M^J)^J)|0;H=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(H,F,qa,U)|0;U=G;qa=wrc((ta>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(ta<<30|0>>>2))^(D>>>7|0<<25|(ta<<25|0>>>7)),(D>>>28|0<<4|(ta<<4|0>>>28))^(0>>>2|0<<30|(D<<30|ta>>>2))^(0>>>7|0<<25|(D<<25|ta>>>7)),ta&(Aa|wa)|Aa&wa,D&(_|X)|_&X)|0;ha=wrc(qa,G,H,F)|0;F=G;H=wrc((u>>>8|N<<24|(0<<24|0>>>8))^(u>>>7|N<<25)^(u>>>1|N<<31|(0<<31|0>>>1)),(N>>>8|0<<24|(h<<24|0>>>8))^(N>>>7|0<<25)^(N>>>1|0<<31|(h<<31|0>>>1)),x,K)|0;K=wrc(H,G,ja,la)|0;H=wrc(K,G,(ea>>>29|0<<3|(Ba<<3|0>>>29))^(Ba>>>6|ea<<26)^(Ba>>>19|ea<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ea<<3|Ba>>>29))^(ea>>>6|0<<26)^(ea>>>19|0<<13|(Ba<<13|0>>>19)))|0;K=G;x=wrc(H,K,-1953704523,264347078)|0;h=wrc(x,G,t,J)|0;J=wrc(h,G,w&(z^q)^q,U&(R^M)^M)|0;h=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(h,J,wa,X)|0;X=G;wa=wrc((ha>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(ha<<30|0>>>2))^(F>>>7|0<<25|(ha<<25|0>>>7)),(F>>>28|0<<4|(ha<<4|0>>>28))^(0>>>2|0<<30|(F<<30|ha>>>2))^(0>>>7|0<<25|(F<<25|ha>>>7)),ha&(ta|Aa)|ta&Aa,F&(D|_)|D&_)|0;x=wrc(wa,G,h,J)|0;J=G;h=wrc((r>>>8|S<<24|(0<<24|0>>>8))^(r>>>7|S<<25)^(r>>>1|S<<31|(0<<31|0>>>1)),(S>>>8|0<<24|(P<<24|0>>>8))^(S>>>7|0<<25)^(S>>>1|0<<31|(P<<31|0>>>1)),u,N)|0;N=wrc(h,G,ma,oa)|0;h=wrc(N,G,(b>>>29|0<<3|(B<<3|0>>>29))^(B>>>6|b<<26)^(B>>>19|b<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(b<<3|B>>>29))^(b>>>6|0<<26)^(b>>>19|0<<13|(B<<13|0>>>19)))|0;N=G;u=wrc(h,N,2007800933,604807628)|0;P=wrc(u,G,q,M)|0;M=wrc(P,G,t&(w^z)^z,X&(U^R)^R)|0;P=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(P,M,Aa,_)|0;_=G;Aa=wrc((x>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(x<<30|0>>>2))^(J>>>7|0<<25|(x<<25|0>>>7)),(J>>>28|0<<4|(x<<4|0>>>28))^(0>>>2|0<<30|(J<<30|x>>>2))^(0>>>7|0<<25|(J<<25|x>>>7)),x&(ha|ta)|ha&ta,J&(F|D)|F&D)|0;u=wrc(Aa,G,P,M)|0;M=G;P=wrc((o>>>8|V<<24|(0<<24|0>>>8))^(o>>>7|V<<25)^(o>>>1|V<<31|(0<<31|0>>>1)),(V>>>8|0<<24|(E<<24|0>>>8))^(V>>>7|0<<25)^(V>>>1|0<<31|(E<<31|0>>>1)),r,S)|0;S=wrc(P,G,pa,ra)|0;P=wrc(S,G,(K>>>29|0<<3|(H<<3|0>>>29))^(H>>>6|K<<26)^(H>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|H>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(H<<13|0>>>19)))|0;S=G;r=wrc(P,S,1495990901,770255983)|0;E=wrc(r,G,z,R)|0;R=wrc(E,G,q&(t^w)^w,_&(X^U)^U)|0;E=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(E,R,ta,D)|0;D=G;ta=wrc((u>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(u<<30|0>>>2))^(M>>>7|0<<25|(u<<25|0>>>7)),(M>>>28|0<<4|(u<<4|0>>>28))^(0>>>2|0<<30|(M<<30|u>>>2))^(0>>>7|0<<25|(M<<25|u>>>7)),u&(x|ha)|x&ha,M&(J|F)|J&F)|0;r=wrc(ta,G,E,R)|0;R=G;E=wrc((l>>>8|Y<<24|(0<<24|0>>>8))^(l>>>7|Y<<25)^(l>>>1|Y<<31|(0<<31|0>>>1)),(Y>>>8|0<<24|(I<<24|0>>>8))^(Y>>>7|0<<25)^(Y>>>1|0<<31|(I<<31|0>>>1)),o,V)|0;V=wrc(E,G,sa,va)|0;E=wrc(V,G,(N>>>29|0<<3|(h<<3|0>>>29))^(h>>>6|N<<26)^(h>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|h>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(h<<13|0>>>19)))|0;V=G;o=wrc(E,V,1856431235,1249150122)|0;I=wrc(o,G,w,U)|0;U=wrc(I,G,z&(q^t)^t,D&(_^X)^X)|0;I=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(I,U,ha,F)|0;F=G;ha=wrc((r>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(r<<30|0>>>2))^(R>>>7|0<<25|(r<<25|0>>>7)),(R>>>28|0<<4|(r<<4|0>>>28))^(0>>>2|0<<30|(R<<30|r>>>2))^(0>>>7|0<<25|(R<<25|r>>>7)),r&(u|x)|u&x,R&(M|J)|M&J)|0;o=wrc(ha,G,I,U)|0;U=G;I=wrc((i>>>8|$<<24|(0<<24|0>>>8))^(i>>>7|$<<25)^(i>>>1|$<<31|(0<<31|0>>>1)),($>>>8|0<<24|(L<<24|0>>>8))^($>>>7|0<<25)^($>>>1|0<<31|(L<<31|0>>>1)),l,Y)|0;Y=wrc(I,G,xa,za)|0;I=wrc(Y,G,(S>>>29|0<<3|(P<<3|0>>>29))^(P>>>6|S<<26)^(P>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|P>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(P<<13|0>>>19)))|0;Y=G;l=wrc(I,Y,-1119749164,1555081692)|0;L=wrc(l,G,t,X)|0;X=wrc(L,G,w&(z^q)^q,F&(D^_)^_)|0;L=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(L,X,x,J)|0;J=G;x=wrc((o>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(o<<30|0>>>2))^(U>>>7|0<<25|(o<<25|0>>>7)),(U>>>28|0<<4|(o<<4|0>>>28))^(0>>>2|0<<30|(U<<30|o>>>2))^(0>>>7|0<<25|(U<<25|o>>>7)),o&(r|u)|r&u,U&(R|M)|R&M)|0;l=wrc(x,G,L,X)|0;X=G;L=wrc((O>>>8|ca<<24|(0<<24|0>>>8))^(O>>>7|ca<<25)^(O>>>1|ca<<31|(0<<31|0>>>1)),(ca>>>8|0<<24|(Q<<24|0>>>8))^(ca>>>7|0<<25)^(ca>>>1|0<<31|(Q<<31|0>>>1)),i,$)|0;$=wrc(L,G,Ba,ea)|0;L=wrc($,G,(V>>>29|0<<3|(E<<3|0>>>29))^(E>>>6|V<<26)^(E>>>19|V<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(V<<3|E>>>29))^(V>>>6|0<<26)^(V>>>19|0<<13|(E<<13|0>>>19)))|0;$=G;i=wrc(L,$,-2096016459,1996064986)|0;Q=wrc(i,G,q,_)|0;_=wrc(Q,G,t&(w^z)^z,J&(F^D)^D)|0;Q=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(Q,_,u,M)|0;M=G;u=wrc((l>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(l<<30|0>>>2))^(X>>>7|0<<25|(l<<25|0>>>7)),(X>>>28|0<<4|(l<<4|0>>>28))^(0>>>2|0<<30|(X<<30|l>>>2))^(0>>>7|0<<25|(X<<25|l>>>7)),l&(o|r)|o&r,X&(U|R)|U&R)|0;i=wrc(u,G,Q,_)|0;_=G;Q=wrc((da>>>8|fa<<24|(0<<24|0>>>8))^(da>>>7|fa<<25)^(da>>>1|fa<<31|(0<<31|0>>>1)),(fa>>>8|0<<24|(T<<24|0>>>8))^(fa>>>7|0<<25)^(fa>>>1|0<<31|(T<<31|0>>>1)),O,ca)|0;ca=wrc(Q,G,B,b)|0;Q=wrc(ca,G,(Y>>>29|0<<3|(I<<3|0>>>29))^(I>>>6|Y<<26)^(I>>>19|Y<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(Y<<3|I>>>29))^(Y>>>6|0<<26)^(Y>>>19|0<<13|(I<<13|0>>>19)))|0;ca=G;O=wrc(Q,ca,-295247957,-1740746414)|0;T=wrc(O,G,z,D)|0;D=wrc(T,G,q&(t^w)^w,M&(J^F)^F)|0;T=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(T,D,r,R)|0;R=G;r=wrc((i>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(i<<30|0>>>2))^(_>>>7|0<<25|(i<<25|0>>>7)),(_>>>28|0<<4|(i<<4|0>>>28))^(0>>>2|0<<30|(_<<30|i>>>2))^(0>>>7|0<<25|(_<<25|i>>>7)),i&(l|o)|l&o,_&(X|U)|X&U)|0;O=wrc(r,G,T,D)|0;D=G;T=wrc((ga>>>8|ia<<24|(0<<24|0>>>8))^(ga>>>7|ia<<25)^(ga>>>1|ia<<31|(0<<31|0>>>1)),(ia>>>8|0<<24|(W<<24|0>>>8))^(ia>>>7|0<<25)^(ia>>>1|0<<31|(W<<31|0>>>1)),da,fa)|0;fa=wrc(T,G,H,K)|0;T=wrc(fa,G,($>>>29|0<<3|(L<<3|0>>>29))^(L>>>6|$<<26)^(L>>>19|$<<13|(0<<13|0>>>19)),(0>>>29|0<<3|($<<3|L>>>29))^($>>>6|0<<26)^($>>>19|0<<13|(L<<13|0>>>19)))|0;fa=G;da=wrc(T,fa,766784016,-1473132947)|0;W=wrc(da,G,w,F)|0;F=wrc(W,G,z&(q^t)^t,R&(M^J)^J)|0;W=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(W,F,o,U)|0;U=G;o=wrc((O>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(O<<30|0>>>2))^(D>>>7|0<<25|(O<<25|0>>>7)),(D>>>28|0<<4|(O<<4|0>>>28))^(0>>>2|0<<30|(D<<30|O>>>2))^(0>>>7|0<<25|(D<<25|O>>>7)),O&(i|l)|i&l,D&(_|X)|_&X)|0;da=wrc(o,G,W,F)|0;F=G;W=wrc((ja>>>8|la<<24|(0<<24|0>>>8))^(ja>>>7|la<<25)^(ja>>>1|la<<31|(0<<31|0>>>1)),(la>>>8|0<<24|(Z<<24|0>>>8))^(la>>>7|0<<25)^(la>>>1|0<<31|(Z<<31|0>>>1)),ga,ia)|0;ia=wrc(W,G,h,N)|0;W=wrc(ia,G,(ca>>>29|0<<3|(Q<<3|0>>>29))^(Q>>>6|ca<<26)^(Q>>>19|ca<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ca<<3|Q>>>29))^(ca>>>6|0<<26)^(ca>>>19|0<<13|(Q<<13|0>>>19)))|0;ia=G;ga=wrc(W,ia,-1728372417,-1341970488)|0;Z=wrc(ga,G,t,J)|0;J=wrc(Z,G,w&(z^q)^q,U&(R^M)^M)|0;Z=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(Z,J,l,X)|0;X=G;l=wrc((da>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(da<<30|0>>>2))^(F>>>7|0<<25|(da<<25|0>>>7)),(F>>>28|0<<4|(da<<4|0>>>28))^(0>>>2|0<<30|(F<<30|da>>>2))^(0>>>7|0<<25|(F<<25|da>>>7)),da&(O|i)|O&i,F&(D|_)|D&_)|0;ga=wrc(l,G,Z,J)|0;J=G;Z=wrc((ma>>>8|oa<<24|(0<<24|0>>>8))^(ma>>>7|oa<<25)^(ma>>>1|oa<<31|(0<<31|0>>>1)),(oa>>>8|0<<24|(aa<<24|0>>>8))^(oa>>>7|0<<25)^(oa>>>1|0<<31|(aa<<31|0>>>1)),ja,la)|0;la=wrc(Z,G,P,S)|0;Z=wrc(la,G,(fa>>>29|0<<3|(T<<3|0>>>29))^(T>>>6|fa<<26)^(T>>>19|fa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(fa<<3|T>>>29))^(fa>>>6|0<<26)^(fa>>>19|0<<13|(T<<13|0>>>19)))|0;la=G;ja=wrc(Z,la,-1091629340,-1084653625)|0;aa=wrc(ja,G,q,M)|0;M=wrc(aa,G,t&(w^z)^z,X&(U^R)^R)|0;aa=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(aa,M,i,_)|0;_=G;i=wrc((ga>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(ga<<30|0>>>2))^(J>>>7|0<<25|(ga<<25|0>>>7)),(J>>>28|0<<4|(ga<<4|0>>>28))^(0>>>2|0<<30|(J<<30|ga>>>2))^(0>>>7|0<<25|(J<<25|ga>>>7)),ga&(da|O)|da&O,J&(F|D)|F&D)|0;ja=wrc(i,G,aa,M)|0;M=G;aa=wrc((pa>>>8|ra<<24|(0<<24|0>>>8))^(pa>>>7|ra<<25)^(pa>>>1|ra<<31|(0<<31|0>>>1)),(ra>>>8|0<<24|(ba<<24|0>>>8))^(ra>>>7|0<<25)^(ra>>>1|0<<31|(ba<<31|0>>>1)),ma,oa)|0;oa=wrc(aa,G,E,V)|0;aa=wrc(oa,G,(ia>>>29|0<<3|(W<<3|0>>>29))^(W>>>6|ia<<26)^(W>>>19|ia<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ia<<3|W>>>29))^(ia>>>6|0<<26)^(ia>>>19|0<<13|(W<<13|0>>>19)))|0;oa=G;ma=wrc(aa,oa,1034457026,-958395405)|0;ba=wrc(ma,G,z,R)|0;R=wrc(ba,G,q&(t^w)^w,_&(X^U)^U)|0;ba=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(ba,R,O,D)|0;D=G;O=wrc((ja>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(ja<<30|0>>>2))^(M>>>7|0<<25|(ja<<25|0>>>7)),(M>>>28|0<<4|(ja<<4|0>>>28))^(0>>>2|0<<30|(M<<30|ja>>>2))^(0>>>7|0<<25|(M<<25|ja>>>7)),ja&(ga|da)|ga&da,M&(J|F)|J&F)|0;ma=wrc(O,G,ba,R)|0;R=G;ba=wrc((sa>>>8|va<<24|(0<<24|0>>>8))^(sa>>>7|va<<25)^(sa>>>1|va<<31|(0<<31|0>>>1)),(va>>>8|0<<24|(ua<<24|0>>>8))^(va>>>7|0<<25)^(va>>>1|0<<31|(ua<<31|0>>>1)),pa,ra)|0;ra=wrc(ba,G,I,Y)|0;ba=wrc(ra,G,(la>>>29|0<<3|(Z<<3|0>>>29))^(Z>>>6|la<<26)^(Z>>>19|la<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(la<<3|Z>>>29))^(la>>>6|0<<26)^(la>>>19|0<<13|(Z<<13|0>>>19)))|0;ra=G;pa=wrc(ba,ra,-1828018395,-710438585)|0;ua=wrc(pa,G,w,U)|0;U=wrc(ua,G,z&(q^t)^t,D&(_^X)^X)|0;ua=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(ua,U,da,F)|0;F=G;da=wrc((ma>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(ma<<30|0>>>2))^(R>>>7|0<<25|(ma<<25|0>>>7)),(R>>>28|0<<4|(ma<<4|0>>>28))^(0>>>2|0<<30|(R<<30|ma>>>2))^(0>>>7|0<<25|(R<<25|ma>>>7)),ma&(ja|ga)|ja&ga,R&(M|J)|M&J)|0;pa=wrc(da,G,ua,U)|0;U=G;ua=wrc((xa>>>8|za<<24|(0<<24|0>>>8))^(xa>>>7|za<<25)^(xa>>>1|za<<31|(0<<31|0>>>1)),(za>>>8|0<<24|(ya<<24|0>>>8))^(za>>>7|0<<25)^(za>>>1|0<<31|(ya<<31|0>>>1)),sa,va)|0;va=wrc(ua,G,L,$)|0;ua=wrc(va,G,(oa>>>29|0<<3|(aa<<3|0>>>29))^(aa>>>6|oa<<26)^(aa>>>19|oa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(oa<<3|aa>>>29))^(oa>>>6|0<<26)^(oa>>>19|0<<13|(aa<<13|0>>>19)))|0;va=G;sa=wrc(ua,va,-536640913,113926993)|0;ya=wrc(sa,G,t,X)|0;X=wrc(ya,G,w&(z^q)^q,F&(D^_)^_)|0;ya=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(ya,X,ga,J)|0;J=G;ga=wrc((pa>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(pa<<30|0>>>2))^(U>>>7|0<<25|(pa<<25|0>>>7)),(U>>>28|0<<4|(pa<<4|0>>>28))^(0>>>2|0<<30|(U<<30|pa>>>2))^(0>>>7|0<<25|(U<<25|pa>>>7)),pa&(ma|ja)|ma&ja,U&(R|M)|R&M)|0;sa=wrc(ga,G,ya,X)|0;X=G;ya=wrc((Ba>>>8|ea<<24|(0<<24|0>>>8))^(Ba>>>7|ea<<25)^(Ba>>>1|ea<<31|(0<<31|0>>>1)),(ea>>>8|0<<24|(Ba<<24|0>>>8))^(ea>>>7|0<<25)^(ea>>>1|0<<31|(Ba<<31|0>>>1)),xa,za)|0;za=wrc(ya,G,Q,ca)|0;ya=wrc(za,G,(ra>>>29|0<<3|(ba<<3|0>>>29))^(ba>>>6|ra<<26)^(ba>>>19|ra<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ra<<3|ba>>>29))^(ra>>>6|0<<26)^(ra>>>19|0<<13|(ba<<13|0>>>19)))|0;za=G;xa=wrc(ya,za,168717936,338241895)|0;ga=wrc(xa,G,q,_)|0;_=wrc(ga,G,t&(w^z)^z,J&(F^D)^D)|0;ga=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(ga,_,ja,M)|0;M=G;ja=wrc((sa>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(sa<<30|0>>>2))^(X>>>7|0<<25|(sa<<25|0>>>7)),(X>>>28|0<<4|(sa<<4|0>>>28))^(0>>>2|0<<30|(X<<30|sa>>>2))^(0>>>7|0<<25|(X<<25|sa>>>7)),sa&(pa|ma)|pa&ma,X&(U|R)|U&R)|0;xa=wrc(ja,G,ga,_)|0;_=G;ga=wrc((B>>>8|b<<24|(0<<24|0>>>8))^(B>>>7|b<<25)^(B>>>1|b<<31|(0<<31|0>>>1)),(b>>>8|0<<24|(B<<24|0>>>8))^(b>>>7|0<<25)^(b>>>1|0<<31|(B<<31|0>>>1)),Ba,ea)|0;ea=wrc(ga,G,T,fa)|0;ga=wrc(ea,G,(va>>>29|0<<3|(ua<<3|0>>>29))^(ua>>>6|va<<26)^(ua>>>19|va<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(va<<3|ua>>>29))^(va>>>6|0<<26)^(va>>>19|0<<13|(ua<<13|0>>>19)))|0;ea=G;Ba=wrc(ga,ea,1188179964,666307205)|0;ja=wrc(Ba,G,z,D)|0;D=wrc(ja,G,q&(t^w)^w,M&(J^F)^F)|0;ja=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(ja,D,ma,R)|0;R=G;ma=wrc((xa>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(xa<<30|0>>>2))^(_>>>7|0<<25|(xa<<25|0>>>7)),(_>>>28|0<<4|(xa<<4|0>>>28))^(0>>>2|0<<30|(_<<30|xa>>>2))^(0>>>7|0<<25|(_<<25|xa>>>7)),xa&(sa|pa)|sa&pa,_&(X|U)|X&U)|0;Ba=wrc(ma,G,ja,D)|0;D=G;ja=wrc((H>>>8|K<<24|(0<<24|0>>>8))^(H>>>7|K<<25)^(H>>>1|K<<31|(0<<31|0>>>1)),(K>>>8|0<<24|(H<<24|0>>>8))^(K>>>7|0<<25)^(K>>>1|0<<31|(H<<31|0>>>1)),B,b)|0;b=wrc(ja,G,W,ia)|0;ja=wrc(b,G,(za>>>29|0<<3|(ya<<3|0>>>29))^(ya>>>6|za<<26)^(ya>>>19|za<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(za<<3|ya>>>29))^(za>>>6|0<<26)^(za>>>19|0<<13|(ya<<13|0>>>19)))|0;b=G;B=wrc(ja,b,1546045734,773529912)|0;ma=wrc(B,G,w,F)|0;F=wrc(ma,G,z&(q^t)^t,R&(M^J)^J)|0;ma=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(ma,F,pa,U)|0;U=G;pa=wrc((Ba>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(Ba<<30|0>>>2))^(D>>>7|0<<25|(Ba<<25|0>>>7)),(D>>>28|0<<4|(Ba<<4|0>>>28))^(0>>>2|0<<30|(D<<30|Ba>>>2))^(0>>>7|0<<25|(D<<25|Ba>>>7)),Ba&(xa|sa)|xa&sa,D&(_|X)|_&X)|0;B=wrc(pa,G,ma,F)|0;F=G;ma=wrc((h>>>8|N<<24|(0<<24|0>>>8))^(h>>>7|N<<25)^(h>>>1|N<<31|(0<<31|0>>>1)),(N>>>8|0<<24|(h<<24|0>>>8))^(N>>>7|0<<25)^(N>>>1|0<<31|(h<<31|0>>>1)),H,K)|0;K=wrc(ma,G,Z,la)|0;ma=wrc(K,G,(ea>>>29|0<<3|(ga<<3|0>>>29))^(ga>>>6|ea<<26)^(ga>>>19|ea<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ea<<3|ga>>>29))^(ea>>>6|0<<26)^(ea>>>19|0<<13|(ga<<13|0>>>19)))|0;K=G;H=wrc(ma,K,1522805485,1294757372)|0;pa=wrc(H,G,t,J)|0;J=wrc(pa,G,w&(z^q)^q,U&(R^M)^M)|0;pa=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(pa,J,sa,X)|0;X=G;sa=wrc((B>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(B<<30|0>>>2))^(F>>>7|0<<25|(B<<25|0>>>7)),(F>>>28|0<<4|(B<<4|0>>>28))^(0>>>2|0<<30|(F<<30|B>>>2))^(0>>>7|0<<25|(F<<25|B>>>7)),B&(Ba|xa)|Ba&xa,F&(D|_)|D&_)|0;H=wrc(sa,G,pa,J)|0;J=G;pa=wrc((P>>>8|S<<24|(0<<24|0>>>8))^(P>>>7|S<<25)^(P>>>1|S<<31|(0<<31|0>>>1)),(S>>>8|0<<24|(P<<24|0>>>8))^(S>>>7|0<<25)^(S>>>1|0<<31|(P<<31|0>>>1)),h,N)|0;N=wrc(pa,G,aa,oa)|0;pa=wrc(N,G,(b>>>29|0<<3|(ja<<3|0>>>29))^(ja>>>6|b<<26)^(ja>>>19|b<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(b<<3|ja>>>29))^(b>>>6|0<<26)^(b>>>19|0<<13|(ja<<13|0>>>19)))|0;N=G;h=wrc(pa,N,-1651133473,1396182291)|0;sa=wrc(h,G,q,M)|0;M=wrc(sa,G,t&(w^z)^z,X&(U^R)^R)|0;sa=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(sa,M,xa,_)|0;_=G;xa=wrc((H>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(H<<30|0>>>2))^(J>>>7|0<<25|(H<<25|0>>>7)),(J>>>28|0<<4|(H<<4|0>>>28))^(0>>>2|0<<30|(J<<30|H>>>2))^(0>>>7|0<<25|(J<<25|H>>>7)),H&(B|Ba)|B&Ba,J&(F|D)|F&D)|0;h=wrc(xa,G,sa,M)|0;M=G;sa=wrc((E>>>8|V<<24|(0<<24|0>>>8))^(E>>>7|V<<25)^(E>>>1|V<<31|(0<<31|0>>>1)),(V>>>8|0<<24|(E<<24|0>>>8))^(V>>>7|0<<25)^(V>>>1|0<<31|(E<<31|0>>>1)),P,S)|0;S=wrc(sa,G,ba,ra)|0;sa=wrc(S,G,(K>>>29|0<<3|(ma<<3|0>>>29))^(ma>>>6|K<<26)^(ma>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|ma>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(ma<<13|0>>>19)))|0;S=G;P=wrc(sa,S,-1951439906,1695183700)|0;xa=wrc(P,G,z,R)|0;R=wrc(xa,G,q&(t^w)^w,_&(X^U)^U)|0;xa=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(xa,R,Ba,D)|0;D=G;Ba=wrc((h>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(h<<30|0>>>2))^(M>>>7|0<<25|(h<<25|0>>>7)),(M>>>28|0<<4|(h<<4|0>>>28))^(0>>>2|0<<30|(M<<30|h>>>2))^(0>>>7|0<<25|(M<<25|h>>>7)),h&(H|B)|H&B,M&(J|F)|J&F)|0;P=wrc(Ba,G,xa,R)|0;R=G;xa=wrc((I>>>8|Y<<24|(0<<24|0>>>8))^(I>>>7|Y<<25)^(I>>>1|Y<<31|(0<<31|0>>>1)),(Y>>>8|0<<24|(I<<24|0>>>8))^(Y>>>7|0<<25)^(Y>>>1|0<<31|(I<<31|0>>>1)),E,V)|0;V=wrc(xa,G,ua,va)|0;xa=wrc(V,G,(N>>>29|0<<3|(pa<<3|0>>>29))^(pa>>>6|N<<26)^(pa>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|pa>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(pa<<13|0>>>19)))|0;V=G;E=wrc(xa,V,1014477480,1986661051)|0;Ba=wrc(E,G,w,U)|0;U=wrc(Ba,G,z&(q^t)^t,D&(_^X)^X)|0;Ba=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(Ba,U,B,F)|0;F=G;B=wrc((P>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(P<<30|0>>>2))^(R>>>7|0<<25|(P<<25|0>>>7)),(R>>>28|0<<4|(P<<4|0>>>28))^(0>>>2|0<<30|(R<<30|P>>>2))^(0>>>7|0<<25|(R<<25|P>>>7)),P&(h|H)|h&H,R&(M|J)|M&J)|0;E=wrc(B,G,Ba,U)|0;U=G;Ba=wrc((L>>>8|$<<24|(0<<24|0>>>8))^(L>>>7|$<<25)^(L>>>1|$<<31|(0<<31|0>>>1)),($>>>8|0<<24|(L<<24|0>>>8))^($>>>7|0<<25)^($>>>1|0<<31|(L<<31|0>>>1)),I,Y)|0;Y=wrc(Ba,G,ya,za)|0;Ba=wrc(Y,G,(S>>>29|0<<3|(sa<<3|0>>>29))^(sa>>>6|S<<26)^(sa>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|sa>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(sa<<13|0>>>19)))|0;Y=G;I=wrc(Ba,Y,1206759142,-2117940946)|0;B=wrc(I,G,t,X)|0;X=wrc(B,G,w&(z^q)^q,F&(D^_)^_)|0;B=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(B,X,H,J)|0;J=G;H=wrc((E>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(E<<30|0>>>2))^(U>>>7|0<<25|(E<<25|0>>>7)),(U>>>28|0<<4|(E<<4|0>>>28))^(0>>>2|0<<30|(U<<30|E>>>2))^(0>>>7|0<<25|(U<<25|E>>>7)),E&(P|h)|P&h,U&(R|M)|R&M)|0;I=wrc(H,G,B,X)|0;X=G;B=wrc((Q>>>8|ca<<24|(0<<24|0>>>8))^(Q>>>7|ca<<25)^(Q>>>1|ca<<31|(0<<31|0>>>1)),(ca>>>8|0<<24|(Q<<24|0>>>8))^(ca>>>7|0<<25)^(ca>>>1|0<<31|(Q<<31|0>>>1)),L,$)|0;$=wrc(B,G,ga,ea)|0;B=wrc($,G,(V>>>29|0<<3|(xa<<3|0>>>29))^(xa>>>6|V<<26)^(xa>>>19|V<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(V<<3|xa>>>29))^(V>>>6|0<<26)^(V>>>19|0<<13|(xa<<13|0>>>19)))|0;$=G;L=wrc(B,$,344077627,-1838011259)|0;H=wrc(L,G,q,_)|0;_=wrc(H,G,t&(w^z)^z,J&(F^D)^D)|0;H=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(H,_,h,M)|0;M=G;h=wrc((I>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(I<<30|0>>>2))^(X>>>7|0<<25|(I<<25|0>>>7)),(X>>>28|0<<4|(I<<4|0>>>28))^(0>>>2|0<<30|(X<<30|I>>>2))^(0>>>7|0<<25|(X<<25|I>>>7)),I&(E|P)|E&P,X&(U|R)|U&R)|0;L=wrc(h,G,H,_)|0;_=G;H=wrc((T>>>8|fa<<24|(0<<24|0>>>8))^(T>>>7|fa<<25)^(T>>>1|fa<<31|(0<<31|0>>>1)),(fa>>>8|0<<24|(T<<24|0>>>8))^(fa>>>7|0<<25)^(fa>>>1|0<<31|(T<<31|0>>>1)),Q,ca)|0;ca=wrc(H,G,ja,b)|0;H=wrc(ca,G,(Y>>>29|0<<3|(Ba<<3|0>>>29))^(Ba>>>6|Y<<26)^(Ba>>>19|Y<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(Y<<3|Ba>>>29))^(Y>>>6|0<<26)^(Y>>>19|0<<13|(Ba<<13|0>>>19)))|0;ca=G;Q=wrc(H,ca,1290863460,-1564481375)|0;h=wrc(Q,G,z,D)|0;D=wrc(h,G,q&(t^w)^w,M&(J^F)^F)|0;h=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(h,D,P,R)|0;R=G;P=wrc((L>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(L<<30|0>>>2))^(_>>>7|0<<25|(L<<25|0>>>7)),(_>>>28|0<<4|(L<<4|0>>>28))^(0>>>2|0<<30|(_<<30|L>>>2))^(0>>>7|0<<25|(_<<25|L>>>7)),L&(I|E)|I&E,_&(X|U)|X&U)|0;Q=wrc(P,G,h,D)|0;D=G;h=wrc((W>>>8|ia<<24|(0<<24|0>>>8))^(W>>>7|ia<<25)^(W>>>1|ia<<31|(0<<31|0>>>1)),(ia>>>8|0<<24|(W<<24|0>>>8))^(ia>>>7|0<<25)^(ia>>>1|0<<31|(W<<31|0>>>1)),T,fa)|0;fa=wrc(h,G,ma,K)|0;h=wrc(fa,G,($>>>29|0<<3|(B<<3|0>>>29))^(B>>>6|$<<26)^(B>>>19|$<<13|(0<<13|0>>>19)),(0>>>29|0<<3|($<<3|B>>>29))^($>>>6|0<<26)^($>>>19|0<<13|(B<<13|0>>>19)))|0;fa=G;T=wrc(h,fa,-1136513023,-1474664885)|0;P=wrc(T,G,w,F)|0;F=wrc(P,G,z&(q^t)^t,R&(M^J)^J)|0;P=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(P,F,E,U)|0;U=G;E=wrc((Q>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(Q<<30|0>>>2))^(D>>>7|0<<25|(Q<<25|0>>>7)),(D>>>28|0<<4|(Q<<4|0>>>28))^(0>>>2|0<<30|(D<<30|Q>>>2))^(0>>>7|0<<25|(D<<25|Q>>>7)),Q&(L|I)|L&I,D&(_|X)|_&X)|0;T=wrc(E,G,P,F)|0;F=G;P=wrc((Z>>>8|la<<24|(0<<24|0>>>8))^(Z>>>7|la<<25)^(Z>>>1|la<<31|(0<<31|0>>>1)),(la>>>8|0<<24|(Z<<24|0>>>8))^(la>>>7|0<<25)^(la>>>1|0<<31|(Z<<31|0>>>1)),W,ia)|0;ia=wrc(P,G,pa,N)|0;P=wrc(ia,G,(ca>>>29|0<<3|(H<<3|0>>>29))^(H>>>6|ca<<26)^(H>>>19|ca<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ca<<3|H>>>29))^(ca>>>6|0<<26)^(ca>>>19|0<<13|(H<<13|0>>>19)))|0;ia=G;W=wrc(P,ia,-789014639,-1035236496)|0;E=wrc(W,G,t,J)|0;J=wrc(E,G,w&(z^q)^q,U&(R^M)^M)|0;E=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(E,J,I,X)|0;X=G;I=wrc((T>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(T<<30|0>>>2))^(F>>>7|0<<25|(T<<25|0>>>7)),(F>>>28|0<<4|(T<<4|0>>>28))^(0>>>2|0<<30|(F<<30|T>>>2))^(0>>>7|0<<25|(F<<25|T>>>7)),T&(Q|L)|Q&L,F&(D|_)|D&_)|0;W=wrc(I,G,E,J)|0;J=G;E=wrc((aa>>>8|oa<<24|(0<<24|0>>>8))^(aa>>>7|oa<<25)^(aa>>>1|oa<<31|(0<<31|0>>>1)),(oa>>>8|0<<24|(aa<<24|0>>>8))^(oa>>>7|0<<25)^(oa>>>1|0<<31|(aa<<31|0>>>1)),Z,la)|0;la=wrc(E,G,sa,S)|0;E=wrc(la,G,(fa>>>29|0<<3|(h<<3|0>>>29))^(h>>>6|fa<<26)^(h>>>19|fa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(fa<<3|h>>>29))^(fa>>>6|0<<26)^(fa>>>19|0<<13|(h<<13|0>>>19)))|0;la=G;Z=wrc(E,la,106217008,-949202525)|0;I=wrc(Z,G,q,M)|0;M=wrc(I,G,t&(w^z)^z,X&(U^R)^R)|0;I=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(I,M,L,_)|0;_=G;L=wrc((W>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(W<<30|0>>>2))^(J>>>7|0<<25|(W<<25|0>>>7)),(J>>>28|0<<4|(W<<4|0>>>28))^(0>>>2|0<<30|(J<<30|W>>>2))^(0>>>7|0<<25|(J<<25|W>>>7)),W&(T|Q)|T&Q,J&(F|D)|F&D)|0;Z=wrc(L,G,I,M)|0;M=G;I=wrc((ba>>>8|ra<<24|(0<<24|0>>>8))^(ba>>>7|ra<<25)^(ba>>>1|ra<<31|(0<<31|0>>>1)),(ra>>>8|0<<24|(ba<<24|0>>>8))^(ra>>>7|0<<25)^(ra>>>1|0<<31|(ba<<31|0>>>1)),aa,oa)|0;oa=wrc(I,G,xa,V)|0;I=wrc(oa,G,(ia>>>29|0<<3|(P<<3|0>>>29))^(P>>>6|ia<<26)^(P>>>19|ia<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ia<<3|P>>>29))^(ia>>>6|0<<26)^(ia>>>19|0<<13|(P<<13|0>>>19)))|0;oa=G;aa=wrc(I,oa,-688958952,-778901479)|0;L=wrc(aa,G,z,R)|0;R=wrc(L,G,q&(t^w)^w,_&(X^U)^U)|0;L=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(L,R,Q,D)|0;D=G;Q=wrc((Z>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(Z<<30|0>>>2))^(M>>>7|0<<25|(Z<<25|0>>>7)),(M>>>28|0<<4|(Z<<4|0>>>28))^(0>>>2|0<<30|(M<<30|Z>>>2))^(0>>>7|0<<25|(M<<25|Z>>>7)),Z&(W|T)|W&T,M&(J|F)|J&F)|0;aa=wrc(Q,G,L,R)|0;R=G;L=wrc((ua>>>8|va<<24|(0<<24|0>>>8))^(ua>>>7|va<<25)^(ua>>>1|va<<31|(0<<31|0>>>1)),(va>>>8|0<<24|(ua<<24|0>>>8))^(va>>>7|0<<25)^(va>>>1|0<<31|(ua<<31|0>>>1)),ba,ra)|0;ra=wrc(L,G,Ba,Y)|0;L=wrc(ra,G,(la>>>29|0<<3|(E<<3|0>>>29))^(E>>>6|la<<26)^(E>>>19|la<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(la<<3|E>>>29))^(la>>>6|0<<26)^(la>>>19|0<<13|(E<<13|0>>>19)))|0;ra=G;ba=wrc(L,ra,1432725776,-694614492)|0;Q=wrc(ba,G,w,U)|0;U=wrc(Q,G,z&(q^t)^t,D&(_^X)^X)|0;Q=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(Q,U,T,F)|0;F=G;T=wrc((aa>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(aa<<30|0>>>2))^(R>>>7|0<<25|(aa<<25|0>>>7)),(R>>>28|0<<4|(aa<<4|0>>>28))^(0>>>2|0<<30|(R<<30|aa>>>2))^(0>>>7|0<<25|(R<<25|aa>>>7)),aa&(Z|W)|Z&W,R&(M|J)|M&J)|0;ba=wrc(T,G,Q,U)|0;U=G;Q=wrc((ya>>>8|za<<24|(0<<24|0>>>8))^(ya>>>7|za<<25)^(ya>>>1|za<<31|(0<<31|0>>>1)),(za>>>8|0<<24|(ya<<24|0>>>8))^(za>>>7|0<<25)^(za>>>1|0<<31|(ya<<31|0>>>1)),ua,va)|0;va=wrc(Q,G,B,$)|0;Q=wrc(va,G,(oa>>>29|0<<3|(I<<3|0>>>29))^(I>>>6|oa<<26)^(I>>>19|oa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(oa<<3|I>>>29))^(oa>>>6|0<<26)^(oa>>>19|0<<13|(I<<13|0>>>19)))|0;va=G;ua=wrc(Q,va,1467031594,-200395387)|0;T=wrc(ua,G,t,X)|0;X=wrc(T,G,w&(z^q)^q,F&(D^_)^_)|0;T=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(T,X,W,J)|0;J=G;W=wrc((ba>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(ba<<30|0>>>2))^(U>>>7|0<<25|(ba<<25|0>>>7)),(U>>>28|0<<4|(ba<<4|0>>>28))^(0>>>2|0<<30|(U<<30|ba>>>2))^(0>>>7|0<<25|(U<<25|ba>>>7)),ba&(aa|Z)|aa&Z,U&(R|M)|R&M)|0;ua=wrc(W,G,T,X)|0;X=G;T=wrc((ga>>>8|ea<<24|(0<<24|0>>>8))^(ga>>>7|ea<<25)^(ga>>>1|ea<<31|(0<<31|0>>>1)),(ea>>>8|0<<24|(ga<<24|0>>>8))^(ea>>>7|0<<25)^(ea>>>1|0<<31|(ga<<31|0>>>1)),ya,za)|0;za=wrc(T,G,H,ca)|0;T=wrc(za,G,(ra>>>29|0<<3|(L<<3|0>>>29))^(L>>>6|ra<<26)^(L>>>19|ra<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ra<<3|L>>>29))^(ra>>>6|0<<26)^(ra>>>19|0<<13|(L<<13|0>>>19)))|0;za=G;ya=wrc(T,za,851169720,275423344)|0;W=wrc(ya,G,q,_)|0;_=wrc(W,G,t&(w^z)^z,J&(F^D)^D)|0;W=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(W,_,Z,M)|0;M=G;Z=wrc((ua>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(ua<<30|0>>>2))^(X>>>7|0<<25|(ua<<25|0>>>7)),(X>>>28|0<<4|(ua<<4|0>>>28))^(0>>>2|0<<30|(X<<30|ua>>>2))^(0>>>7|0<<25|(X<<25|ua>>>7)),ua&(ba|aa)|ba&aa,X&(U|R)|U&R)|0;ya=wrc(Z,G,W,_)|0;_=G;W=wrc((ja>>>8|b<<24|(0<<24|0>>>8))^(ja>>>7|b<<25)^(ja>>>1|b<<31|(0<<31|0>>>1)),(b>>>8|0<<24|(ja<<24|0>>>8))^(b>>>7|0<<25)^(b>>>1|0<<31|(ja<<31|0>>>1)),ga,ea)|0;ea=wrc(W,G,h,fa)|0;W=wrc(ea,G,(va>>>29|0<<3|(Q<<3|0>>>29))^(Q>>>6|va<<26)^(Q>>>19|va<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(va<<3|Q>>>29))^(va>>>6|0<<26)^(va>>>19|0<<13|(Q<<13|0>>>19)))|0;ea=G;ga=wrc(W,ea,-1194143544,430227734)|0;Z=wrc(ga,G,z,D)|0;D=wrc(Z,G,q&(t^w)^w,M&(J^F)^F)|0;Z=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(Z,D,aa,R)|0;R=G;aa=wrc((ya>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(ya<<30|0>>>2))^(_>>>7|0<<25|(ya<<25|0>>>7)),(_>>>28|0<<4|(ya<<4|0>>>28))^(0>>>2|0<<30|(_<<30|ya>>>2))^(0>>>7|0<<25|(_<<25|ya>>>7)),ya&(ua|ba)|ua&ba,_&(X|U)|X&U)|0;ga=wrc(aa,G,Z,D)|0;D=G;Z=wrc((ma>>>8|K<<24|(0<<24|0>>>8))^(ma>>>7|K<<25)^(ma>>>1|K<<31|(0<<31|0>>>1)),(K>>>8|0<<24|(ma<<24|0>>>8))^(K>>>7|0<<25)^(K>>>1|0<<31|(ma<<31|0>>>1)),ja,b)|0;b=wrc(Z,G,P,ia)|0;Z=wrc(b,G,(za>>>29|0<<3|(T<<3|0>>>29))^(T>>>6|za<<26)^(T>>>19|za<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(za<<3|T>>>29))^(za>>>6|0<<26)^(za>>>19|0<<13|(T<<13|0>>>19)))|0;b=G;ja=wrc(Z,b,1363258195,506948616)|0;aa=wrc(ja,G,w,F)|0;F=wrc(aa,G,z&(q^t)^t,R&(M^J)^J)|0;aa=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(aa,F,ba,U)|0;U=G;ba=wrc((ga>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(ga<<30|0>>>2))^(D>>>7|0<<25|(ga<<25|0>>>7)),(D>>>28|0<<4|(ga<<4|0>>>28))^(0>>>2|0<<30|(D<<30|ga>>>2))^(0>>>7|0<<25|(D<<25|ga>>>7)),ga&(ya|ua)|ya&ua,D&(_|X)|_&X)|0;ja=wrc(ba,G,aa,F)|0;F=G;aa=wrc((pa>>>8|N<<24|(0<<24|0>>>8))^(pa>>>7|N<<25)^(pa>>>1|N<<31|(0<<31|0>>>1)),(N>>>8|0<<24|(pa<<24|0>>>8))^(N>>>7|0<<25)^(N>>>1|0<<31|(pa<<31|0>>>1)),ma,K)|0;K=wrc(aa,G,E,la)|0;aa=wrc(K,G,(ea>>>29|0<<3|(W<<3|0>>>29))^(W>>>6|ea<<26)^(W>>>19|ea<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ea<<3|W>>>29))^(ea>>>6|0<<26)^(ea>>>19|0<<13|(W<<13|0>>>19)))|0;K=G;ma=wrc(aa,K,-544281703,659060556)|0;ba=wrc(ma,G,t,J)|0;J=wrc(ba,G,w&(z^q)^q,U&(R^M)^M)|0;ba=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(ba,J,ua,X)|0;X=G;ua=wrc((ja>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(ja<<30|0>>>2))^(F>>>7|0<<25|(ja<<25|0>>>7)),(F>>>28|0<<4|(ja<<4|0>>>28))^(0>>>2|0<<30|(F<<30|ja>>>2))^(0>>>7|0<<25|(F<<25|ja>>>7)),ja&(ga|ya)|ga&ya,F&(D|_)|D&_)|0;ma=wrc(ua,G,ba,J)|0;J=G;ba=wrc((sa>>>8|S<<24|(0<<24|0>>>8))^(sa>>>7|S<<25)^(sa>>>1|S<<31|(0<<31|0>>>1)),(S>>>8|0<<24|(sa<<24|0>>>8))^(S>>>7|0<<25)^(S>>>1|0<<31|(sa<<31|0>>>1)),pa,N)|0;N=wrc(ba,G,I,oa)|0;ba=wrc(N,G,(b>>>29|0<<3|(Z<<3|0>>>29))^(Z>>>6|b<<26)^(Z>>>19|b<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(b<<3|Z>>>29))^(b>>>6|0<<26)^(b>>>19|0<<13|(Z<<13|0>>>19)))|0;N=G;pa=wrc(ba,N,-509917016,883997877)|0;ua=wrc(pa,G,q,M)|0;M=wrc(ua,G,t&(w^z)^z,X&(U^R)^R)|0;ua=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(ua,M,ya,_)|0;_=G;ya=wrc((ma>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(ma<<30|0>>>2))^(J>>>7|0<<25|(ma<<25|0>>>7)),(J>>>28|0<<4|(ma<<4|0>>>28))^(0>>>2|0<<30|(J<<30|ma>>>2))^(0>>>7|0<<25|(J<<25|ma>>>7)),ma&(ja|ga)|ja&ga,J&(F|D)|F&D)|0;pa=wrc(ya,G,ua,M)|0;M=G;ua=wrc((xa>>>8|V<<24|(0<<24|0>>>8))^(xa>>>7|V<<25)^(xa>>>1|V<<31|(0<<31|0>>>1)),(V>>>8|0<<24|(xa<<24|0>>>8))^(V>>>7|0<<25)^(V>>>1|0<<31|(xa<<31|0>>>1)),sa,S)|0;S=wrc(ua,G,L,ra)|0;ua=wrc(S,G,(K>>>29|0<<3|(aa<<3|0>>>29))^(aa>>>6|K<<26)^(aa>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|aa>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(aa<<13|0>>>19)))|0;S=G;sa=wrc(ua,S,-976659869,958139571)|0;ya=wrc(sa,G,z,R)|0;R=wrc(ya,G,q&(t^w)^w,_&(X^U)^U)|0;ya=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(ya,R,ga,D)|0;D=G;ga=wrc((pa>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(pa<<30|0>>>2))^(M>>>7|0<<25|(pa<<25|0>>>7)),(M>>>28|0<<4|(pa<<4|0>>>28))^(0>>>2|0<<30|(M<<30|pa>>>2))^(0>>>7|0<<25|(M<<25|pa>>>7)),pa&(ma|ja)|ma&ja,M&(J|F)|J&F)|0;sa=wrc(ga,G,ya,R)|0;R=G;ya=wrc((Ba>>>8|Y<<24|(0<<24|0>>>8))^(Ba>>>7|Y<<25)^(Ba>>>1|Y<<31|(0<<31|0>>>1)),(Y>>>8|0<<24|(Ba<<24|0>>>8))^(Y>>>7|0<<25)^(Y>>>1|0<<31|(Ba<<31|0>>>1)),xa,V)|0;V=wrc(ya,G,Q,va)|0;ya=wrc(V,G,(N>>>29|0<<3|(ba<<3|0>>>29))^(ba>>>6|N<<26)^(ba>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|ba>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(ba<<13|0>>>19)))|0;V=G;xa=wrc(ya,V,-482243893,1322822218)|0;ga=wrc(xa,G,w,U)|0;U=wrc(ga,G,z&(q^t)^t,D&(_^X)^X)|0;ga=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(ga,U,ja,F)|0;F=G;ja=wrc((sa>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(sa<<30|0>>>2))^(R>>>7|0<<25|(sa<<25|0>>>7)),(R>>>28|0<<4|(sa<<4|0>>>28))^(0>>>2|0<<30|(R<<30|sa>>>2))^(0>>>7|0<<25|(R<<25|sa>>>7)),sa&(pa|ma)|pa&ma,R&(M|J)|M&J)|0;xa=wrc(ja,G,ga,U)|0;U=G;ga=wrc((B>>>8|$<<24|(0<<24|0>>>8))^(B>>>7|$<<25)^(B>>>1|$<<31|(0<<31|0>>>1)),($>>>8|0<<24|(B<<24|0>>>8))^($>>>7|0<<25)^($>>>1|0<<31|(B<<31|0>>>1)),Ba,Y)|0;Y=wrc(ga,G,T,za)|0;ga=wrc(Y,G,(S>>>29|0<<3|(ua<<3|0>>>29))^(ua>>>6|S<<26)^(ua>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|ua>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(ua<<13|0>>>19)))|0;Y=G;Ba=wrc(ga,Y,2003034995,1537002063)|0;ja=wrc(Ba,G,t,X)|0;X=wrc(ja,G,w&(z^q)^q,F&(D^_)^_)|0;ja=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(ja,X,ma,J)|0;J=G;ma=wrc((xa>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(xa<<30|0>>>2))^(U>>>7|0<<25|(xa<<25|0>>>7)),(U>>>28|0<<4|(xa<<4|0>>>28))^(0>>>2|0<<30|(U<<30|xa>>>2))^(0>>>7|0<<25|(U<<25|xa>>>7)),xa&(sa|pa)|sa&pa,U&(R|M)|R&M)|0;Ba=wrc(ma,G,ja,X)|0;X=G;ja=wrc((H>>>8|ca<<24|(0<<24|0>>>8))^(H>>>7|ca<<25)^(H>>>1|ca<<31|(0<<31|0>>>1)),(ca>>>8|0<<24|(H<<24|0>>>8))^(ca>>>7|0<<25)^(ca>>>1|0<<31|(H<<31|0>>>1)),B,$)|0;$=wrc(ja,G,W,ea)|0;ja=wrc($,G,(V>>>29|0<<3|(ya<<3|0>>>29))^(ya>>>6|V<<26)^(ya>>>19|V<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(V<<3|ya>>>29))^(V>>>6|0<<26)^(V>>>19|0<<13|(ya<<13|0>>>19)))|0;$=G;B=wrc(ja,$,-692930397,1747873779)|0;ma=wrc(B,G,q,_)|0;_=wrc(ma,G,t&(w^z)^z,J&(F^D)^D)|0;ma=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(ma,_,pa,M)|0;M=G;pa=wrc((Ba>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(Ba<<30|0>>>2))^(X>>>7|0<<25|(Ba<<25|0>>>7)),(X>>>28|0<<4|(Ba<<4|0>>>28))^(0>>>2|0<<30|(X<<30|Ba>>>2))^(0>>>7|0<<25|(X<<25|Ba>>>7)),Ba&(xa|sa)|xa&sa,X&(U|R)|U&R)|0;B=wrc(pa,G,ma,_)|0;_=G;ma=wrc((h>>>8|fa<<24|(0<<24|0>>>8))^(h>>>7|fa<<25)^(h>>>1|fa<<31|(0<<31|0>>>1)),(fa>>>8|0<<24|(h<<24|0>>>8))^(fa>>>7|0<<25)^(fa>>>1|0<<31|(h<<31|0>>>1)),H,ca)|0;ca=wrc(ma,G,Z,b)|0;ma=wrc(ca,G,(Y>>>29|0<<3|(ga<<3|0>>>29))^(ga>>>6|Y<<26)^(ga>>>19|Y<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(Y<<3|ga>>>29))^(Y>>>6|0<<26)^(Y>>>19|0<<13|(ga<<13|0>>>19)))|0;ca=G;H=wrc(ma,ca,1575990012,1955562222)|0;pa=wrc(H,G,z,D)|0;D=wrc(pa,G,q&(t^w)^w,M&(J^F)^F)|0;pa=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(pa,D,sa,R)|0;R=G;sa=wrc((B>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(B<<30|0>>>2))^(_>>>7|0<<25|(B<<25|0>>>7)),(_>>>28|0<<4|(B<<4|0>>>28))^(0>>>2|0<<30|(_<<30|B>>>2))^(0>>>7|0<<25|(_<<25|B>>>7)),B&(Ba|xa)|Ba&xa,_&(X|U)|X&U)|0;H=wrc(sa,G,pa,D)|0;D=G;pa=wrc((P>>>8|ia<<24|(0<<24|0>>>8))^(P>>>7|ia<<25)^(P>>>1|ia<<31|(0<<31|0>>>1)),(ia>>>8|0<<24|(P<<24|0>>>8))^(ia>>>7|0<<25)^(ia>>>1|0<<31|(P<<31|0>>>1)),h,fa)|0;fa=wrc(pa,G,aa,K)|0;pa=wrc(fa,G,($>>>29|0<<3|(ja<<3|0>>>29))^(ja>>>6|$<<26)^(ja>>>19|$<<13|(0<<13|0>>>19)),(0>>>29|0<<3|($<<3|ja>>>29))^($>>>6|0<<26)^($>>>19|0<<13|(ja<<13|0>>>19)))|0;fa=G;h=wrc(pa,fa,1125592928,2024104815)|0;sa=wrc(h,G,w,F)|0;F=wrc(sa,G,z&(q^t)^t,R&(M^J)^J)|0;sa=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(sa,F,xa,U)|0;U=G;xa=wrc((H>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(H<<30|0>>>2))^(D>>>7|0<<25|(H<<25|0>>>7)),(D>>>28|0<<4|(H<<4|0>>>28))^(0>>>2|0<<30|(D<<30|H>>>2))^(0>>>7|0<<25|(D<<25|H>>>7)),H&(B|Ba)|B&Ba,D&(_|X)|_&X)|0;h=wrc(xa,G,sa,F)|0;F=G;sa=wrc((E>>>8|la<<24|(0<<24|0>>>8))^(E>>>7|la<<25)^(E>>>1|la<<31|(0<<31|0>>>1)),(la>>>8|0<<24|(E<<24|0>>>8))^(la>>>7|0<<25)^(la>>>1|0<<31|(E<<31|0>>>1)),P,ia)|0;ia=wrc(sa,G,ba,N)|0;sa=wrc(ia,G,(ca>>>29|0<<3|(ma<<3|0>>>29))^(ma>>>6|ca<<26)^(ma>>>19|ca<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ca<<3|ma>>>29))^(ca>>>6|0<<26)^(ca>>>19|0<<13|(ma<<13|0>>>19)))|0;ia=G;P=wrc(sa,ia,-1578062990,-2067236844)|0;xa=wrc(P,G,t,J)|0;J=wrc(xa,G,w&(z^q)^q,U&(R^M)^M)|0;xa=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(xa,J,Ba,X)|0;X=G;Ba=wrc((h>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(h<<30|0>>>2))^(F>>>7|0<<25|(h<<25|0>>>7)),(F>>>28|0<<4|(h<<4|0>>>28))^(0>>>2|0<<30|(F<<30|h>>>2))^(0>>>7|0<<25|(F<<25|h>>>7)),h&(H|B)|H&B,F&(D|_)|D&_)|0;P=wrc(Ba,G,xa,J)|0;J=G;xa=wrc((I>>>8|oa<<24|(0<<24|0>>>8))^(I>>>7|oa<<25)^(I>>>1|oa<<31|(0<<31|0>>>1)),(oa>>>8|0<<24|(I<<24|0>>>8))^(oa>>>7|0<<25)^(oa>>>1|0<<31|(I<<31|0>>>1)),E,la)|0;la=wrc(xa,G,ua,S)|0;xa=wrc(la,G,(fa>>>29|0<<3|(pa<<3|0>>>29))^(pa>>>6|fa<<26)^(pa>>>19|fa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(fa<<3|pa>>>29))^(fa>>>6|0<<26)^(fa>>>19|0<<13|(pa<<13|0>>>19)))|0;la=G;E=wrc(xa,la,442776044,-1933114872)|0;Ba=wrc(E,G,q,M)|0;M=wrc(Ba,G,t&(w^z)^z,X&(U^R)^R)|0;Ba=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(Ba,M,B,_)|0;_=G;B=wrc((P>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(P<<30|0>>>2))^(J>>>7|0<<25|(P<<25|0>>>7)),(J>>>28|0<<4|(P<<4|0>>>28))^(0>>>2|0<<30|(J<<30|P>>>2))^(0>>>7|0<<25|(J<<25|P>>>7)),P&(h|H)|h&H,J&(F|D)|F&D)|0;E=wrc(B,G,Ba,M)|0;M=G;Ba=wrc((L>>>8|ra<<24|(0<<24|0>>>8))^(L>>>7|ra<<25)^(L>>>1|ra<<31|(0<<31|0>>>1)),(ra>>>8|0<<24|(L<<24|0>>>8))^(ra>>>7|0<<25)^(ra>>>1|0<<31|(L<<31|0>>>1)),I,oa)|0;oa=wrc(Ba,G,ya,V)|0;Ba=wrc(oa,G,(ia>>>29|0<<3|(sa<<3|0>>>29))^(sa>>>6|ia<<26)^(sa>>>19|ia<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ia<<3|sa>>>29))^(ia>>>6|0<<26)^(ia>>>19|0<<13|(sa<<13|0>>>19)))|0;oa=G;I=wrc(Ba,oa,593698344,-1866530822)|0;B=wrc(I,G,z,R)|0;R=wrc(B,G,q&(t^w)^w,_&(X^U)^U)|0;B=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(B,R,H,D)|0;D=G;H=wrc((E>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(E<<30|0>>>2))^(M>>>7|0<<25|(E<<25|0>>>7)),(M>>>28|0<<4|(E<<4|0>>>28))^(0>>>2|0<<30|(M<<30|E>>>2))^(0>>>7|0<<25|(M<<25|E>>>7)),E&(P|h)|P&h,M&(J|F)|J&F)|0;I=wrc(H,G,B,R)|0;R=G;B=wrc((Q>>>8|va<<24|(0<<24|0>>>8))^(Q>>>7|va<<25)^(Q>>>1|va<<31|(0<<31|0>>>1)),(va>>>8|0<<24|(Q<<24|0>>>8))^(va>>>7|0<<25)^(va>>>1|0<<31|(Q<<31|0>>>1)),L,ra)|0;ra=wrc(B,G,ga,Y)|0;B=wrc(ra,G,(la>>>29|0<<3|(xa<<3|0>>>29))^(xa>>>6|la<<26)^(xa>>>19|la<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(la<<3|xa>>>29))^(la>>>6|0<<26)^(la>>>19|0<<13|(xa<<13|0>>>19)))|0;ra=G;L=wrc(B,ra,-561857047,-1538233109)|0;H=wrc(L,G,w,U)|0;U=wrc(H,G,z&(q^t)^t,D&(_^X)^X)|0;H=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(H,U,h,F)|0;F=G;h=wrc((I>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(I<<30|0>>>2))^(R>>>7|0<<25|(I<<25|0>>>7)),(R>>>28|0<<4|(I<<4|0>>>28))^(0>>>2|0<<30|(R<<30|I>>>2))^(0>>>7|0<<25|(R<<25|I>>>7)),I&(E|P)|E&P,R&(M|J)|M&J)|0;L=wrc(h,G,H,U)|0;U=G;H=wrc((T>>>8|za<<24|(0<<24|0>>>8))^(T>>>7|za<<25)^(T>>>1|za<<31|(0<<31|0>>>1)),(za>>>8|0<<24|(T<<24|0>>>8))^(za>>>7|0<<25)^(za>>>1|0<<31|(T<<31|0>>>1)),Q,va)|0;va=wrc(H,G,ja,$)|0;H=wrc(va,G,(oa>>>29|0<<3|(Ba<<3|0>>>29))^(Ba>>>6|oa<<26)^(Ba>>>19|oa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(oa<<3|Ba>>>29))^(oa>>>6|0<<26)^(oa>>>19|0<<13|(Ba<<13|0>>>19)))|0;va=G;Q=wrc(H,va,-1295615723,-1090935817)|0;h=wrc(Q,G,t,X)|0;X=wrc(h,G,w&(z^q)^q,F&(D^_)^_)|0;h=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(h,X,P,J)|0;J=G;P=wrc((L>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(L<<30|0>>>2))^(U>>>7|0<<25|(L<<25|0>>>7)),(U>>>28|0<<4|(L<<4|0>>>28))^(0>>>2|0<<30|(U<<30|L>>>2))^(0>>>7|0<<25|(U<<25|L>>>7)),L&(I|E)|I&E,U&(R|M)|R&M)|0;Q=wrc(P,G,h,X)|0;X=G;h=wrc((W>>>8|ea<<24|(0<<24|0>>>8))^(W>>>7|ea<<25)^(W>>>1|ea<<31|(0<<31|0>>>1)),(ea>>>8|0<<24|(W<<24|0>>>8))^(ea>>>7|0<<25)^(ea>>>1|0<<31|(W<<31|0>>>1)),T,za)|0;za=wrc(h,G,ma,ca)|0;h=wrc(za,G,(ra>>>29|0<<3|(B<<3|0>>>29))^(B>>>6|ra<<26)^(B>>>19|ra<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ra<<3|B>>>29))^(ra>>>6|0<<26)^(ra>>>19|0<<13|(B<<13|0>>>19)))|0;za=G;T=wrc(h,za,-479046869,-965641998)|0;P=wrc(T,G,q,_)|0;_=wrc(P,G,t&(w^z)^z,J&(F^D)^D)|0;P=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(P,_,E,M)|0;M=G;E=wrc((Q>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(Q<<30|0>>>2))^(X>>>7|0<<25|(Q<<25|0>>>7)),(X>>>28|0<<4|(Q<<4|0>>>28))^(0>>>2|0<<30|(X<<30|Q>>>2))^(0>>>7|0<<25|(X<<25|Q>>>7)),Q&(L|I)|L&I,X&(U|R)|U&R)|0;T=wrc(E,G,P,_)|0;_=G;P=wrc((Z>>>8|b<<24|(0<<24|0>>>8))^(Z>>>7|b<<25)^(Z>>>1|b<<31|(0<<31|0>>>1)),(b>>>8|0<<24|(Z<<24|0>>>8))^(b>>>7|0<<25)^(b>>>1|0<<31|(Z<<31|0>>>1)),W,ea)|0;ea=wrc(P,G,pa,fa)|0;P=wrc(ea,G,(va>>>29|0<<3|(H<<3|0>>>29))^(H>>>6|va<<26)^(H>>>19|va<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(va<<3|H>>>29))^(va>>>6|0<<26)^(va>>>19|0<<13|(H<<13|0>>>19)))|0;ea=G;W=wrc(P,ea,-366583396,-903397682)|0;E=wrc(W,G,z,D)|0;D=wrc(E,G,q&(t^w)^w,M&(J^F)^F)|0;E=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(E,D,I,R)|0;R=G;I=wrc((T>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(T<<30|0>>>2))^(_>>>7|0<<25|(T<<25|0>>>7)),(_>>>28|0<<4|(T<<4|0>>>28))^(0>>>2|0<<30|(_<<30|T>>>2))^(0>>>7|0<<25|(_<<25|T>>>7)),T&(Q|L)|Q&L,_&(X|U)|X&U)|0;W=wrc(I,G,E,D)|0;D=G;E=wrc((aa>>>8|K<<24|(0<<24|0>>>8))^(aa>>>7|K<<25)^(aa>>>1|K<<31|(0<<31|0>>>1)),(K>>>8|0<<24|(aa<<24|0>>>8))^(K>>>7|0<<25)^(K>>>1|0<<31|(aa<<31|0>>>1)),Z,b)|0;b=wrc(E,G,sa,ia)|0;E=wrc(b,G,(za>>>29|0<<3|(h<<3|0>>>29))^(h>>>6|za<<26)^(h>>>19|za<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(za<<3|h>>>29))^(za>>>6|0<<26)^(za>>>19|0<<13|(h<<13|0>>>19)))|0;b=G;Z=wrc(E,b,566280711,-779700025)|0;I=wrc(Z,G,w,F)|0;F=wrc(I,G,z&(q^t)^t,R&(M^J)^J)|0;I=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(I,F,L,U)|0;U=G;L=wrc((W>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(W<<30|0>>>2))^(D>>>7|0<<25|(W<<25|0>>>7)),(D>>>28|0<<4|(W<<4|0>>>28))^(0>>>2|0<<30|(D<<30|W>>>2))^(0>>>7|0<<25|(D<<25|W>>>7)),W&(T|Q)|T&Q,D&(_|X)|_&X)|0;Z=wrc(L,G,I,F)|0;F=G;I=wrc((ba>>>8|N<<24|(0<<24|0>>>8))^(ba>>>7|N<<25)^(ba>>>1|N<<31|(0<<31|0>>>1)),(N>>>8|0<<24|(ba<<24|0>>>8))^(N>>>7|0<<25)^(N>>>1|0<<31|(ba<<31|0>>>1)),aa,K)|0;K=wrc(I,G,xa,la)|0;I=wrc(K,G,(ea>>>29|0<<3|(P<<3|0>>>29))^(P>>>6|ea<<26)^(P>>>19|ea<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ea<<3|P>>>29))^(ea>>>6|0<<26)^(ea>>>19|0<<13|(P<<13|0>>>19)))|0;K=G;aa=wrc(I,K,-840897762,-354779690)|0;L=wrc(aa,G,t,J)|0;J=wrc(L,G,w&(z^q)^q,U&(R^M)^M)|0;L=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(L,J,Q,X)|0;X=G;Q=wrc((Z>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(Z<<30|0>>>2))^(F>>>7|0<<25|(Z<<25|0>>>7)),(F>>>28|0<<4|(Z<<4|0>>>28))^(0>>>2|0<<30|(F<<30|Z>>>2))^(0>>>7|0<<25|(F<<25|Z>>>7)),Z&(W|T)|W&T,F&(D|_)|D&_)|0;aa=wrc(Q,G,L,J)|0;J=G;L=wrc((ua>>>8|S<<24|(0<<24|0>>>8))^(ua>>>7|S<<25)^(ua>>>1|S<<31|(0<<31|0>>>1)),(S>>>8|0<<24|(ua<<24|0>>>8))^(S>>>7|0<<25)^(S>>>1|0<<31|(ua<<31|0>>>1)),ba,N)|0;N=wrc(L,G,Ba,oa)|0;L=wrc(N,G,(b>>>29|0<<3|(E<<3|0>>>29))^(E>>>6|b<<26)^(E>>>19|b<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(b<<3|E>>>29))^(b>>>6|0<<26)^(b>>>19|0<<13|(E<<13|0>>>19)))|0;N=G;ba=wrc(L,N,-294727304,-176337025)|0;Q=wrc(ba,G,q,M)|0;M=wrc(Q,G,t&(w^z)^z,X&(U^R)^R)|0;Q=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(Q,M,T,_)|0;_=G;T=wrc((aa>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(aa<<30|0>>>2))^(J>>>7|0<<25|(aa<<25|0>>>7)),(J>>>28|0<<4|(aa<<4|0>>>28))^(0>>>2|0<<30|(J<<30|aa>>>2))^(0>>>7|0<<25|(J<<25|aa>>>7)),aa&(Z|W)|Z&W,J&(F|D)|F&D)|0;ba=wrc(T,G,Q,M)|0;M=G;Q=wrc((ya>>>8|V<<24|(0<<24|0>>>8))^(ya>>>7|V<<25)^(ya>>>1|V<<31|(0<<31|0>>>1)),(V>>>8|0<<24|(ya<<24|0>>>8))^(V>>>7|0<<25)^(V>>>1|0<<31|(ya<<31|0>>>1)),ua,S)|0;S=wrc(Q,G,B,ra)|0;Q=wrc(S,G,(K>>>29|0<<3|(I<<3|0>>>29))^(I>>>6|K<<26)^(I>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|I>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(I<<13|0>>>19)))|0;S=G;ua=wrc(Q,S,1914138554,116418474)|0;T=wrc(ua,G,z,R)|0;R=wrc(T,G,q&(t^w)^w,_&(X^U)^U)|0;T=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(T,R,W,D)|0;D=G;W=wrc((ba>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(ba<<30|0>>>2))^(M>>>7|0<<25|(ba<<25|0>>>7)),(M>>>28|0<<4|(ba<<4|0>>>28))^(0>>>2|0<<30|(M<<30|ba>>>2))^(0>>>7|0<<25|(M<<25|ba>>>7)),ba&(aa|Z)|aa&Z,M&(J|F)|J&F)|0;ua=wrc(W,G,T,R)|0;R=G;T=wrc((ga>>>8|Y<<24|(0<<24|0>>>8))^(ga>>>7|Y<<25)^(ga>>>1|Y<<31|(0<<31|0>>>1)),(Y>>>8|0<<24|(ga<<24|0>>>8))^(Y>>>7|0<<25)^(Y>>>1|0<<31|(ga<<31|0>>>1)),ya,V)|0;V=wrc(T,G,H,va)|0;T=wrc(V,G,(N>>>29|0<<3|(L<<3|0>>>29))^(L>>>6|N<<26)^(L>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|L>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(L<<13|0>>>19)))|0;V=G;ya=wrc(T,V,-1563912026,174292421)|0;W=wrc(ya,G,w,U)|0;U=wrc(W,G,z&(q^t)^t,D&(_^X)^X)|0;W=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(W,U,Z,F)|0;F=G;Z=wrc((ua>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(ua<<30|0>>>2))^(R>>>7|0<<25|(ua<<25|0>>>7)),(R>>>28|0<<4|(ua<<4|0>>>28))^(0>>>2|0<<30|(R<<30|ua>>>2))^(0>>>7|0<<25|(R<<25|ua>>>7)),ua&(ba|aa)|ba&aa,R&(M|J)|M&J)|0;ya=wrc(Z,G,W,U)|0;U=G;W=wrc((ja>>>8|$<<24|(0<<24|0>>>8))^(ja>>>7|$<<25)^(ja>>>1|$<<31|(0<<31|0>>>1)),($>>>8|0<<24|(ja<<24|0>>>8))^($>>>7|0<<25)^($>>>1|0<<31|(ja<<31|0>>>1)),ga,Y)|0;Y=wrc(W,G,h,za)|0;W=wrc(Y,G,(S>>>29|0<<3|(Q<<3|0>>>29))^(Q>>>6|S<<26)^(Q>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|Q>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(Q<<13|0>>>19)))|0;Y=G;ga=wrc(W,Y,-1090974290,289380356)|0;Z=wrc(ga,G,t,X)|0;X=wrc(Z,G,w&(z^q)^q,F&(D^_)^_)|0;Z=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(Z,X,aa,J)|0;J=G;aa=wrc((ya>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(ya<<30|0>>>2))^(U>>>7|0<<25|(ya<<25|0>>>7)),(U>>>28|0<<4|(ya<<4|0>>>28))^(0>>>2|0<<30|(U<<30|ya>>>2))^(0>>>7|0<<25|(U<<25|ya>>>7)),ya&(ua|ba)|ua&ba,U&(R|M)|R&M)|0;ga=wrc(aa,G,Z,X)|0;X=G;Z=wrc((ma>>>8|ca<<24|(0<<24|0>>>8))^(ma>>>7|ca<<25)^(ma>>>1|ca<<31|(0<<31|0>>>1)),(ca>>>8|0<<24|(ma<<24|0>>>8))^(ca>>>7|0<<25)^(ca>>>1|0<<31|(ma<<31|0>>>1)),ja,$)|0;$=wrc(Z,G,P,ea)|0;Z=wrc($,G,(V>>>29|0<<3|(T<<3|0>>>29))^(T>>>6|V<<26)^(T>>>19|V<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(V<<3|T>>>29))^(V>>>6|0<<26)^(V>>>19|0<<13|(T<<13|0>>>19)))|0;$=G;ja=wrc(Z,$,320620315,460393269)|0;aa=wrc(ja,G,q,_)|0;_=wrc(aa,G,t&(w^z)^z,J&(F^D)^D)|0;aa=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc(aa,_,ba,M)|0;M=G;ba=wrc((ga>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|(ga<<30|0>>>2))^(X>>>7|0<<25|(ga<<25|0>>>7)),(X>>>28|0<<4|(ga<<4|0>>>28))^(0>>>2|0<<30|(X<<30|ga>>>2))^(0>>>7|0<<25|(X<<25|ga>>>7)),ga&(ya|ua)|ya&ua,X&(U|R)|U&R)|0;ja=wrc(ba,G,aa,_)|0;_=G;aa=wrc((pa>>>8|fa<<24|(0<<24|0>>>8))^(pa>>>7|fa<<25)^(pa>>>1|fa<<31|(0<<31|0>>>1)),(fa>>>8|0<<24|(pa<<24|0>>>8))^(fa>>>7|0<<25)^(fa>>>1|0<<31|(pa<<31|0>>>1)),ma,ca)|0;ca=wrc(aa,G,E,b)|0;b=wrc(ca,G,(Y>>>29|0<<3|(W<<3|0>>>29))^(W>>>6|Y<<26)^(W>>>19|Y<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(Y<<3|W>>>29))^(Y>>>6|0<<26)^(Y>>>19|0<<13|(W<<13|0>>>19)))|0;ca=G;E=wrc(b,ca,587496836,685471733)|0;aa=wrc(E,G,z,D)|0;D=wrc(aa,G,q&(t^w)^w,M&(J^F)^F)|0;aa=wrc(D,G,(q>>>14|M<<18|(0<<18|0>>>14))^(q>>>18|M<<14|(0<<14|0>>>18))^(M>>>9|0<<23|(q<<23|0>>>9)),(M>>>14|0<<18|(q<<18|0>>>14))^(M>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(M<<23|q>>>9)))|0;D=G;z=wrc(aa,D,ua,R)|0;R=G;ua=wrc((ja>>>28|_<<4|(0<<4|0>>>28))^(_>>>2|0<<30|(ja<<30|0>>>2))^(_>>>7|0<<25|(ja<<25|0>>>7)),(_>>>28|0<<4|(ja<<4|0>>>28))^(0>>>2|0<<30|(_<<30|ja>>>2))^(0>>>7|0<<25|(_<<25|ja>>>7)),ja&(ga|ya)|ga&ya,_&(X|U)|X&U)|0;E=wrc(ua,G,aa,D)|0;D=G;aa=wrc((sa>>>8|ia<<24|(0<<24|0>>>8))^(sa>>>7|ia<<25)^(sa>>>1|ia<<31|(0<<31|0>>>1)),(ia>>>8|0<<24|(sa<<24|0>>>8))^(ia>>>7|0<<25)^(ia>>>1|0<<31|(sa<<31|0>>>1)),pa,fa)|0;fa=wrc(aa,G,I,K)|0;K=wrc(fa,G,($>>>29|0<<3|(Z<<3|0>>>29))^(Z>>>6|$<<26)^(Z>>>19|$<<13|(0<<13|0>>>19)),(0>>>29|0<<3|($<<3|Z>>>29))^($>>>6|0<<26)^($>>>19|0<<13|(Z<<13|0>>>19)))|0;fa=G;I=wrc(K,fa,1086792851,852142971)|0;aa=wrc(I,G,w,F)|0;F=wrc(aa,G,z&(q^t)^t,R&(M^J)^J)|0;aa=wrc(F,G,(z>>>14|R<<18|(0<<18|0>>>14))^(z>>>18|R<<14|(0<<14|0>>>18))^(R>>>9|0<<23|(z<<23|0>>>9)),(R>>>14|0<<18|(z<<18|0>>>14))^(R>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(R<<23|z>>>9)))|0;F=G;w=wrc(aa,F,ya,U)|0;U=G;ya=wrc((E>>>28|D<<4|(0<<4|0>>>28))^(D>>>2|0<<30|(E<<30|0>>>2))^(D>>>7|0<<25|(E<<25|0>>>7)),(D>>>28|0<<4|(E<<4|0>>>28))^(0>>>2|0<<30|(D<<30|E>>>2))^(0>>>7|0<<25|(D<<25|E>>>7)),E&(ja|ga)|ja&ga,D&(_|X)|_&X)|0;I=wrc(ya,G,aa,F)|0;F=G;aa=wrc((xa>>>8|la<<24|(0<<24|0>>>8))^(xa>>>7|la<<25)^(xa>>>1|la<<31|(0<<31|0>>>1)),(la>>>8|0<<24|(xa<<24|0>>>8))^(la>>>7|0<<25)^(la>>>1|0<<31|(xa<<31|0>>>1)),sa,ia)|0;ia=wrc(aa,G,L,N)|0;N=wrc(ia,G,(ca>>>29|0<<3|(b<<3|0>>>29))^(b>>>6|ca<<26)^(b>>>19|ca<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ca<<3|b>>>29))^(ca>>>6|0<<26)^(ca>>>19|0<<13|(b<<13|0>>>19)))|0;ia=G;L=wrc(N,ia,365543100,1017036298)|0;aa=wrc(L,G,t,J)|0;J=wrc(aa,G,w&(z^q)^q,U&(R^M)^M)|0;aa=wrc(J,G,(w>>>14|U<<18|(0<<18|0>>>14))^(w>>>18|U<<14|(0<<14|0>>>18))^(U>>>9|0<<23|(w<<23|0>>>9)),(U>>>14|0<<18|(w<<18|0>>>14))^(U>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(U<<23|w>>>9)))|0;J=G;t=wrc(aa,J,ga,X)|0;X=G;ga=wrc((I>>>28|F<<4|(0<<4|0>>>28))^(F>>>2|0<<30|(I<<30|0>>>2))^(F>>>7|0<<25|(I<<25|0>>>7)),(F>>>28|0<<4|(I<<4|0>>>28))^(0>>>2|0<<30|(F<<30|I>>>2))^(0>>>7|0<<25|(F<<25|I>>>7)),I&(E|ja)|E&ja,F&(D|_)|D&_)|0;L=wrc(ga,G,aa,J)|0;J=G;aa=wrc((Ba>>>8|oa<<24|(0<<24|0>>>8))^(Ba>>>7|oa<<25)^(Ba>>>1|oa<<31|(0<<31|0>>>1)),(oa>>>8|0<<24|(Ba<<24|0>>>8))^(oa>>>7|0<<25)^(oa>>>1|0<<31|(Ba<<31|0>>>1)),xa,la)|0;la=wrc(aa,G,Q,S)|0;S=wrc(la,G,(fa>>>29|0<<3|(K<<3|0>>>29))^(K>>>6|fa<<26)^(K>>>19|fa<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(fa<<3|K>>>29))^(fa>>>6|0<<26)^(fa>>>19|0<<13|(K<<13|0>>>19)))|0;K=G;fa=wrc(S,K,-1676669620,1126000580)|0;la=wrc(fa,G,q,M)|0;M=wrc(la,G,t&(w^z)^z,X&(U^R)^R)|0;la=wrc(M,G,(t>>>14|X<<18|(0<<18|0>>>14))^(t>>>18|X<<14|(0<<14|0>>>18))^(X>>>9|0<<23|(t<<23|0>>>9)),(X>>>14|0<<18|(t<<18|0>>>14))^(X>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(X<<23|t>>>9)))|0;M=G;q=wrc(la,M,ja,_)|0;_=G;ja=wrc((L>>>28|J<<4|(0<<4|0>>>28))^(J>>>2|0<<30|(L<<30|0>>>2))^(J>>>7|0<<25|(L<<25|0>>>7)),(J>>>28|0<<4|(L<<4|0>>>28))^(0>>>2|0<<30|(J<<30|L>>>2))^(0>>>7|0<<25|(J<<25|L>>>7)),L&(I|E)|I&E,J&(F|D)|F&D)|0;fa=wrc(ja,G,la,M)|0;M=G;la=wrc((B>>>8|ra<<24|(0<<24|0>>>8))^(B>>>7|ra<<25)^(B>>>1|ra<<31|(0<<31|0>>>1)),(ra>>>8|0<<24|(B<<24|0>>>8))^(ra>>>7|0<<25)^(ra>>>1|0<<31|(B<<31|0>>>1)),Ba,oa)|0;oa=wrc(la,G,T,V)|0;V=wrc(oa,G,(ia>>>29|0<<3|(N<<3|0>>>29))^(N>>>6|ia<<26)^(N>>>19|ia<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(ia<<3|N>>>29))^(ia>>>6|0<<26)^(ia>>>19|0<<13|(N<<13|0>>>19)))|0;N=G;ia=wrc(V,N,-885112138,1288033470)|0;oa=wrc(ia,G,z,R)|0;R=wrc(oa,G,q&(t^w)^w,_&(X^U)^U)|0;oa=wrc(R,G,(q>>>14|_<<18|(0<<18|0>>>14))^(q>>>18|_<<14|(0<<14|0>>>18))^(_>>>9|0<<23|(q<<23|0>>>9)),(_>>>14|0<<18|(q<<18|0>>>14))^(_>>>18|0<<14|(q<<14|0>>>18))^(0>>>9|0<<23|(_<<23|q>>>9)))|0;R=G;z=wrc(oa,R,E,D)|0;D=G;E=wrc((fa>>>28|M<<4|(0<<4|0>>>28))^(M>>>2|0<<30|(fa<<30|0>>>2))^(M>>>7|0<<25|(fa<<25|0>>>7)),(M>>>28|0<<4|(fa<<4|0>>>28))^(0>>>2|0<<30|(M<<30|fa>>>2))^(0>>>7|0<<25|(M<<25|fa>>>7)),fa&(L|I)|L&I,M&(J|F)|J&F)|0;ia=wrc(E,G,oa,R)|0;R=G;oa=wrc((H>>>8|va<<24|(0<<24|0>>>8))^(H>>>7|va<<25)^(H>>>1|va<<31|(0<<31|0>>>1)),(va>>>8|0<<24|(H<<24|0>>>8))^(va>>>7|0<<25)^(va>>>1|0<<31|(H<<31|0>>>1)),B,ra)|0;ra=wrc(oa,G,W,Y)|0;Y=wrc(ra,G,(K>>>29|0<<3|(S<<3|0>>>29))^(S>>>6|K<<26)^(S>>>19|K<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(K<<3|S>>>29))^(K>>>6|0<<26)^(K>>>19|0<<13|(S<<13|0>>>19)))|0;S=G;K=wrc(Y,S,-60457430,1501505948)|0;ra=wrc(K,G,w,U)|0;U=wrc(ra,G,z&(q^t)^t,D&(_^X)^X)|0;ra=wrc(U,G,(z>>>14|D<<18|(0<<18|0>>>14))^(z>>>18|D<<14|(0<<14|0>>>18))^(D>>>9|0<<23|(z<<23|0>>>9)),(D>>>14|0<<18|(z<<18|0>>>14))^(D>>>18|0<<14|(z<<14|0>>>18))^(0>>>9|0<<23|(D<<23|z>>>9)))|0;U=G;w=wrc(ra,U,I,F)|0;F=G;I=wrc((ia>>>28|R<<4|(0<<4|0>>>28))^(R>>>2|0<<30|(ia<<30|0>>>2))^(R>>>7|0<<25|(ia<<25|0>>>7)),(R>>>28|0<<4|(ia<<4|0>>>28))^(0>>>2|0<<30|(R<<30|ia>>>2))^(0>>>7|0<<25|(R<<25|ia>>>7)),ia&(fa|L)|fa&L,R&(M|J)|M&J)|0;K=wrc(I,G,ra,U)|0;U=G;ra=wrc(H,va,987167468,1607167915)|0;va=wrc(ra,G,(h>>>8|za<<24|(0<<24|0>>>8))^(h>>>7|za<<25)^(h>>>1|za<<31|(0<<31|0>>>1)),(za>>>8|0<<24|(h<<24|0>>>8))^(za>>>7|0<<25)^(za>>>1|0<<31|(h<<31|0>>>1)))|0;ra=wrc(va,G,Z,$)|0;$=wrc(ra,G,(N>>>29|0<<3|(V<<3|0>>>29))^(V>>>6|N<<26)^(V>>>19|N<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(N<<3|V>>>29))^(N>>>6|0<<26)^(N>>>19|0<<13|(V<<13|0>>>19)))|0;V=wrc($,G,t,X)|0;X=wrc(V,G,w&(z^q)^q,F&(D^_)^_)|0;V=wrc(X,G,(w>>>14|F<<18|(0<<18|0>>>14))^(w>>>18|F<<14|(0<<14|0>>>18))^(F>>>9|0<<23|(w<<23|0>>>9)),(F>>>14|0<<18|(w<<18|0>>>14))^(F>>>18|0<<14|(w<<14|0>>>18))^(0>>>9|0<<23|(F<<23|w>>>9)))|0;X=G;t=wrc(V,X,L,J)|0;J=G;L=wrc((K>>>28|U<<4|(0<<4|0>>>28))^(U>>>2|0<<30|(K<<30|0>>>2))^(U>>>7|0<<25|(K<<25|0>>>7)),(U>>>28|0<<4|(K<<4|0>>>28))^(0>>>2|0<<30|(U<<30|K>>>2))^(0>>>7|0<<25|(U<<25|K>>>7)),K&(ia|fa)|ia&fa,U&(R|M)|R&M)|0;$=wrc(L,G,V,X)|0;X=G;V=wrc(h,za,1246189591,1816402316)|0;za=wrc(V,G,(P>>>8|ea<<24|(0<<24|0>>>8))^(P>>>7|ea<<25)^(P>>>1|ea<<31|(0<<31|0>>>1)),(ea>>>8|0<<24|(P<<24|0>>>8))^(ea>>>7|0<<25)^(ea>>>1|0<<31|(P<<31|0>>>1)))|0;P=wrc(za,G,b,ca)|0;ca=wrc(P,G,(S>>>29|0<<3|(Y<<3|0>>>29))^(Y>>>6|S<<26)^(Y>>>19|S<<13|(0<<13|0>>>19)),(0>>>29|0<<3|(S<<3|Y>>>29))^(S>>>6|0<<26)^(S>>>19|0<<13|(Y<<13|0>>>19)))|0;Y=wrc(ca,G,q,_)|0;_=wrc(Y,G,t&(w^z)^z,J&(F^D)^D)|0;Y=wrc(_,G,(t>>>14|J<<18|(0<<18|0>>>14))^(t>>>18|J<<14|(0<<14|0>>>18))^(J>>>9|0<<23|(t<<23|0>>>9)),(J>>>14|0<<18|(t<<18|0>>>14))^(J>>>18|0<<14|(t<<14|0>>>18))^(0>>>9|0<<23|(J<<23|t>>>9)))|0;_=G;q=wrc($&(K|ia)|K&ia,X&(U|R)|U&R,e,f)|0;f=wrc(q,G,($>>>28|X<<4|(0<<4|0>>>28))^(X>>>2|0<<30|($<<30|0>>>2))^(X>>>7|0<<25|($<<25|0>>>7)),(X>>>28|0<<4|($<<4|0>>>28))^(0>>>2|0<<30|(X<<30|$>>>2))^(0>>>7|0<<25|(X<<25|$>>>7)))|0;q=wrc(f,G,Y,_)|0;c[a>>2]=q;c[a+4>>2]=G;a=wrc($,X,c[g>>2]|0,c[g+4>>2]|0)|0;c[g>>2]=a;c[g+4>>2]=G;g=wrc(K,U,c[j>>2]|0,c[j+4>>2]|0)|0;c[j>>2]=g;c[j+4>>2]=G;j=wrc(ia,R,c[m>>2]|0,c[m+4>>2]|0)|0;c[m>>2]=j;c[m+4>>2]=G;m=wrc(fa,M,c[p>>2]|0,c[p+4>>2]|0)|0;M=wrc(m,G,Y,_)|0;c[p>>2]=M;c[p+4>>2]=G;p=wrc(t,J,c[s>>2]|0,c[s+4>>2]|0)|0;c[s>>2]=p;c[s+4>>2]=G;s=wrc(w,F,c[v>>2]|0,c[v+4>>2]|0)|0;c[v>>2]=s;c[v+4>>2]=G;v=wrc(z,D,c[y>>2]|0,c[y+4>>2]|0)|0;c[y>>2]=v;c[y+4>>2]=G;return}function gLb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+16|0;f=e|0;g=e+8|0;c[f>>2]=0;c[f+4>>2]=0;h=b+8|0;j=c[h>>2]|0;k=c[h+4>>2]|0;l=je(j<<3|0>>>29|0)|0;c[g>>2]=je(j>>>29|k<<3|0)|0;c[g+4>>2]=l;l=j&127;m=wrc(j,k,1,0)|0;c[h>>2]=m;c[h+4>>2]=G;if((l+1|0)>>>0>127>>>0){m=128-l|0;nrc(b+16+l|0,2405624,m)|0;fLb(b+144|0,b+16|0);n=0;o=m}else{n=l;o=0}nrc(b+16+n|0,2405624+o|0,1-o|0)|0;o=c[h>>2]|0;n=c[h+4>>2]|0;if((o&127|0)==112&(n&0|0)==0){p=n;q=o}else{l=b+144|0;m=b+16|0;k=n;n=o;while(1){o=n&127;j=wrc(n,k,1,0)|0;c[h>>2]=j;c[h+4>>2]=G;if((o+1|0)>>>0>127>>>0){j=128-o|0;nrc(b+16+o|0,10230672,j)|0;fLb(l,m);r=0;s=j}else{r=o;s=0}nrc(b+16+r|0,10230672+s|0,1-s|0)|0;o=c[h>>2]|0;j=c[h+4>>2]|0;if((o&127|0)==112&(j&0|0)==0){p=j;q=o;break}else{k=j;n=o}}}n=f;k=q&127;s=wrc(q,p,8,0)|0;c[h>>2]=s;c[h+4>>2]=G;do{if((k+8|0)>>>0>127>>>0){s=128-k|0;nrc(b+16+k|0,n|0,s)|0;p=b+144|0;fLb(p,b+16|0);if((s+127|0)>>>0<8>>>0){t=s}else{u=0;v=s;break}while(1){fLb(p,n+t|0);s=t+128|0;if((t+255|0)>>>0<8>>>0){t=s}else{u=0;v=s;break}}}else{u=k;v=0}}while(0);nrc(b+16+u|0,n+v|0,8-v|0)|0;v=g;g=c[h>>2]|0;n=g&127;u=wrc(g,c[h+4>>2]|0,8,0)|0;c[h>>2]=u;c[h+4>>2]=G;do{if((n+8|0)>>>0>127>>>0){h=128-n|0;nrc(b+16+n|0,v|0,h)|0;u=b+144|0;fLb(u,b+16|0);if((h+127|0)>>>0<8>>>0){w=h}else{x=0;z=h;break}while(1){fLb(u,v+w|0);h=w+128|0;if((w+255|0)>>>0<8>>>0){w=h}else{x=0;z=h;break}}}else{x=n;z=0}}while(0);nrc(b+16+x|0,v+z|0,8-z|0)|0;c[f>>2]=0;c[f+4>>2]=0;z=b|0;if((a[z]|0)==0){i=e;return}else{A=0;B=0}while(1){v=b+144+(B<<3)|0;x=c[v+4>>2]|0;n=je(c[v>>2]|0)|0;v=je(x|0)|0;x=d+(B<<3|0>>>29)|0;w=x|0;y=v;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;w=x+4|0;y=n|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;C=wrc(B,A,1,0)|0;D=G;E=a[z]|0;w=0;if(D>>>0<w>>>0|D>>>0==w>>>0&C>>>0<(E&255)>>>0){A=D;B=C}else{break}}c[f>>2]=C;c[f+4>>2]=D;if((E&1)==0){i=e;return}E=je(c[b+144+(C<<3)+4>>2]|0)|0;b=d+(C<<3|0>>>29)|0;y=E;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;i=e;return}function hLb(){return pJb(8)|0}function iLb(a){a=a|0;var b=0,d=0;b=dIb(a,2,8)|0;if((b|0)==0){d=0;return d|0}d=c[b+4>>2]|0;return d|0}function jLb(){var a=0,b=0,d=0,e=0;a=i;i=i+8|0;b=a|0;jd(b|0,0)|0;d=c[b>>2]|0;e=Erc(d,(d|0)<0|0?-1:0,1e6,0)|0;d=c[b+4>>2]|0;b=wrc(e,G,d,(d|0)<0|0?-1:0)|0;d=G;i=a;return(G=d,b)|0}function kLb(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+8|0;d=b|0;c[d>>2]=(a>>>0)/1e6|0;c[d+4>>2]=((a>>>0)%1e6|0)*1e3|0;while(1){if((Ec(d|0,d|0)|0)>=0){e=4;break}if((c[(pd()|0)>>2]|0)!=4){e=4;break}}if((e|0)==4){i=b;return 0}return 0}function lLb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)==60){c=35964;d=4}else if((b|0)==30){c=17982;d=2}else{e=a;return e|0}e=(ca(((((a|0)%(c|0)|0)-d|0)/((c>>>0)/10|0|0)|0)+(((a|0)/(c|0)|0)*9|0)|0,d)|0)+a|0;return e|0}function mLb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+16>>2]|0;e=c[a+4>>2]&1;f=(c[a>>2]|0)+b|0;do{if((e|0)==0){g=f}else{if((d|0)==30){h=17982;i=2}else if((d|0)==60){h=35964;i=4}else{g=f;break}g=(ca(((((f|0)%(h|0)|0)-i|0)/((h>>>0)/10|0|0)|0)+(((f|0)/(h|0)|0)*9|0)|0,i)|0)+f|0}}while(0);f=(g>>>0)%(d>>>0)|0;i=(((g>>>0)/(d>>>0)|0)>>>0)%60|0;h=(((g>>>0)/((d*60|0)>>>0)|0)>>>0)%60|0;b=(((g>>>0)/((d*3600|0)>>>0)|0)>>>0)%24|0;return((f|0)/10|0)<<28|e<<30|((f|0)%10|0)<<24|((i>>>0)/10|0)<<20|((i>>>0)%10|0)<<16|((h>>>0)/10|0)<<12|((h>>>0)%10|0)<<8|((b>>>0)/10|0)<<4|((b>>>0)%10|0)|0}function nLb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=c[a+16>>2]|0;g=c[a+4>>2]|0;h=g&1;j=(c[a>>2]|0)+d|0;do{if((h|0)==0){k=j}else{if((f|0)==60){l=35964;m=4}else if((f|0)==30){l=17982;m=2}else{k=j;break}k=(ca(((((j|0)%(l|0)|0)-m|0)/((l>>>0)/10|0|0)|0)+(((j|0)/(l|0)|0)*9|0)|0,m)|0)+j|0}}while(0);if((k|0)<0){n=g&4;o=-k|0}else{n=0;o=k}k=(o|0)/(f*3600|0|0)|0;if((g&2|0)==0){p=k}else{p=(k|0)%24|0}Rb(b|0,16,2405488,(k=i,i=i+48|0,c[k>>2]=(n|0)!=0?2577208:10230464,c[k+8>>2]=p,c[k+16>>2]=((o|0)/(f*60|0|0)|0|0)%60|0,c[k+24>>2]=((o|0)/(f|0)|0|0)%60|0,c[k+32>>2]=h|58,c[k+40>>2]=(o|0)%(f|0)|0,k)|0)|0;i=k;i=e;return b|0}function oLb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b&15;if(f>>>0>9>>>0){g=0}else{g=((b>>>4&3)*10|0)+f|0}f=b>>>8&15;if(f>>>0>9>>>0){h=0}else{h=((b>>>12&7)*10|0)+f|0}f=b>>>16&15;if(f>>>0>9>>>0){j=0}else{j=((b>>>20&7)*10|0)+f|0}f=b>>>24&15;if(f>>>0>9>>>0){k=0}else{k=((b>>>28&3)*10|0)+f|0}if((b&1073741824|0)==0){l=58}else{l=(d|0)!=0?58:59}Rb(a|0,16,2348824,(d=i,i=i+40|0,c[d>>2]=g,c[d+8>>2]=h,c[d+16>>2]=j,c[d+24>>2]=l,c[d+32>>2]=k,d)|0)|0;i=d;i=e;return a|0}function pLb(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;Rb(a|0,16,2348824,(e=i,i=i+40|0,c[e>>2]=b>>>19&31,c[e+8>>2]=b>>>13&63,c[e+16>>2]=b>>>6&63,c[e+24>>2]=b>>>24&1|58,c[e+32>>2]=b&63,e)|0)|0;i=e;i=d;return a|0}function qLb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a;a=i;i=i+8|0;c[a>>2]=c[d>>2];c[a+4>>2]=c[d+4>>2];d=c[a>>2]|0;e=c[a+4>>2]|0;if((e|0)==0|(d|0)==0){f=-1}else{f=(((e|0)/2|0)+d|0)/(e|0)|0}e=0;while(1){if(!(e>>>0<5>>>0)){g=-1;h=6;break}if((c[1707488+(e<<2)>>2]|0)==(f|0)){g=0;h=6;break}else{e=e+1|0}}if((h|0)==6){i=b;return g|0}return 0}function rLb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=b;b=i;i=i+8|0;c[b>>2]=c[h>>2];c[b+4>>2]=c[h+4>>2];mrc(a|0,0,20)|0;c[a>>2]=e;c[a+4>>2]=d;e=b;h=a+8|0;j=c[e>>2]|0;k=c[e+4>>2]|0;c[h>>2]=j;c[h+4>>2]=k;h=j;j=c[b+4>>2]|0;b=k;do{if((j|0)==0|(h|0)==0){c[a+16>>2]=-1;l=-1}else{k=(((j|0)/2|0)+h|0)/(j|0)|0;c[a+16>>2]=k;if((k|0)!=0){l=k;break}KIb(f,16,2197008,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=g;return n|0}}while(0);if((d&1|0)==0|(l|0)==30|(l|0)==60){o=0}else{KIb(f,16,2165472,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=g;return n|0}while(1){if(!(o>>>0<5>>>0)){break}if((c[1707488+(o<<2)>>2]|0)==(l|0)){n=0;p=10;break}else{o=o+1|0}}if((p|0)==10){i=g;return n|0}KIb(f,16,2139360,(m=i,i=i+16|0,c[m>>2]=h,c[m+8>>2]=b,m)|0);i=m;n=-1163346256;i=g;return n|0}function sLb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+40|0;h=d;d=i;i=i+8|0;c[d>>2]=c[h>>2];c[d+4>>2]=c[h+4>>2];h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=Bd(e|0,2287224,(e=i,i=i+40|0,c[e>>2]=j,c[e+8>>2]=k,c[e+16>>2]=l,c[e+24>>2]=h,c[e+32>>2]=m,e)|0)|0;i=e;if((n|0)!=5){KIb(f,16,2237528,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;o=-1094995529;i=g;return o|0}mrc(b|0,0,20)|0;n=(a[h]|0)!=58;c[b+4>>2]=n&1;h=d;p=b+8|0;q=c[h>>2]|0;r=c[h+4>>2]|0;c[p>>2]=q;c[p+4>>2]=r;p=q;q=c[d+4>>2]|0;d=r;do{if((q|0)==0|(p|0)==0){c[b+16>>2]=-1;s=-1}else{r=(((q|0)/2|0)+p|0)/(q|0)|0;c[b+16>>2]=r;if((r|0)!=0){s=r;break}KIb(f,16,2197008,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;o=-22;i=g;return o|0}}while(0);do{if(n){if((s|0)==60|(s|0)==30){t=0;break}KIb(f,16,2165472,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;o=-22;i=g;return o|0}else{t=0}}while(0);while(1){if(!(t>>>0<5>>>0)){u=12;break}if((c[1707488+(t<<2)>>2]|0)==(s|0)){break}else{t=t+1|0}}if((u|0)==12){KIb(f,16,2139360,(e=i,i=i+16|0,c[e>>2]=p,c[e+8>>2]=d,e)|0);i=e;o=-1163346256;i=g;return o|0}e=c[j>>2]|0;j=c[k>>2]|0;k=ca((j*60|0)+(e*3600|0)+(c[l>>2]|0)|0,s)|0;s=k+(c[m>>2]|0)|0;m=b|0;c[m>>2]=s;if(!n){o=0;i=g;return o|0}n=(e*60|0)+j|0;c[m>>2]=s-(n-((n|0)/10|0)<<1);o=0;i=g;return o|0}function tLb(){return pJb(16)|0}function uLb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){f=0;return f|0}g=(e|0)!=0;a:do{if(g){h=a;while(1){i=h+8|0;j=We[d&2047](b,c[i>>2]|0)|0;if((j|0)==0){k=h;l=i;break a}m=j>>>31;c[e+(m<<2)>>2]=c[i>>2];i=c[h+((m^1)<<2)>>2]|0;if((i|0)==0){f=0;break}else{h=i}}return f|0}else{h=a;while(1){i=h+8|0;m=We[d&2047](b,c[i>>2]|0)|0;if((m|0)==0){k=h;l=i;break a}i=c[h+((m>>>31^1)<<2)>>2]|0;if((i|0)==0){f=0;break}else{h=i}}return f|0}}while(0);if(g){uLb(c[k>>2]|0,b,d,e)|0;uLb(c[k+4>>2]|0,b,d,e)|0}f=c[l>>2]|0;return f|0}function vLb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+8|0;g=f|0;h=c[a>>2]|0;if((h|0)==0){c[a>>2]=c[e>>2];c[e>>2]=0;j=c[a>>2]|0;if((j|0)==0){k=b;i=f;return k|0}c[j+8>>2]=b;k=0;i=f;return k|0}j=h+8|0;l=We[d&2047](c[j>>2]|0,b)|0;if((l|0)==0){if((c[e>>2]|0)!=0){k=c[j>>2]|0;i=f;return k|0}m=(c[h>>2]|0)==0;do{if(m){if((c[h+4>>2]|0)!=0){break}c[e>>2]=h;c[a>>2]=0;k=0;i=f;return k|0}}while(0);n=m&1;uLb(c[h+(n<<2)>>2]|0,b,d,g|0)|0;m=c[g+(n<<2)>>2]|0;c[j>>2]=m;o=m;p=-n|0}else{o=b;p=l}l=p>>>31;p=vLb(h+(l<<2)|0,o,d,e)|0;do{if((p|0)==0){d=(c[e>>2]|0)!=0^l;b=h+(d<<2)|0;n=h+12|0;m=(c[n>>2]|0)-1+(d<<1)|0;c[n>>2]=m;if((m&1|0)!=0|(m|0)==0){q=c[(c[a>>2]|0)+12>>2]|0}else{j=c[b>>2]|0;if((c[j+12>>2]<<1|0)==(-m|0)){m=d^1;g=c[j+(m<<2)>>2]|0;c[a>>2]=g;c[(c[b>>2]|0)+(m<<2)>>2]=c[g+(d<<2)>>2];c[(c[a>>2]|0)+(d<<2)>>2]=c[b>>2];c[b>>2]=c[(c[a>>2]|0)+(m<<2)>>2];c[(c[a>>2]|0)+(m<<2)>>2]=h;m=c[a>>2]|0;g=m+12|0;c[(c[m>>2]|0)+12>>2]=-((c[g>>2]|0)>0|0);c[(c[m+4>>2]|0)+12>>2]=(c[g>>2]|0)>>>31;c[g>>2]=0;if((c[e>>2]|0)==0){k=o}else{break}i=f;return k|0}c[a>>2]=j;j=d^1;c[b>>2]=c[(c[b>>2]|0)+(j<<2)>>2];c[(c[a>>2]|0)+(j<<2)>>2]=h;if((c[(c[a>>2]|0)+12>>2]|0)==0){r=c[n>>2]>>1}else{r=0}c[n>>2]=r;n=-r|0;c[(c[a>>2]|0)+12>>2]=n;q=n}if((q|0)==0^(c[e>>2]|0)!=0){k=o}else{break}i=f;return k|0}}while(0);k=p;i=f;return k|0}function wLb(a){a=a|0;if((a|0)==0){return}else{wLb(c[a>>2]|0);wLb(c[a+4>>2]|0);kJb(a);return}}function xLb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((a|0)==0){return}if((d|0)==0){f=a;do{xLb(c[f>>2]|0,b,0,e);We[e&2047](b,c[f+8>>2]|0)|0;f=c[f+4>>2]|0;}while((f|0)!=0);return}else{g=a}while(1){a=We[d&2047](b,c[g+8>>2]|0)|0;if((a|0)>-1){xLb(c[g>>2]|0,b,d,e);if((a|0)!=0){h=8;break}We[e&2047](b,c[g+8>>2]|0)|0}a=c[g+4>>2]|0;if((a|0)==0){h=8;break}else{g=a}}if((h|0)==8){return}}function yLb(){var b=0,d=0;b=i;if(a[1961008]|0){i=b;return 3424868}d=ge(+1152921504606847000.0)|0;if(!((d|0)==0&(G|0)==268435456)){KIb(0,16,2577088,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d}a[1961008]=1;i=b;return 3424868}function zLb(){return 2434536}function ALb(a){a=a|0;var b=0;switch(a|0){case 4:{b=2139344;break};case 3:{b=2165456;break};case 1:{b=2237520;break};case 2:{b=2197e3;break};case 0:{b=2287216;break};default:{b=0}}return b|0}function BLb(a){a=a|0;var b=0;switch(a|0){case 4:{b=83;break};case 5:{b=105;break};case 7:{b=98;break};case 6:{b=112;break};case 2:{b=80;break};case 1:{b=73;break};case 3:{b=66;break};default:{b=63}}return b|0}function CLb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;if((e|0)==0){j=0;i=h;return j|0}if((d|0)==4){k=f;l=e;m=0;while(1){if((c[l+(m<<2)>>2]|0)==(k|0)){j=m;break}else{m=m+1|0}}i=h;return j|0}else if((d|0)==2){m=e;k=f&65535;l=0;while(1){if((b[m+(l<<1)>>1]|0)==k<<16>>16){j=l;break}else{l=l+1|0}}i=h;return j|0}else if((d|0)==8){l=e;k=0;while(1){m=l+(k<<3)|0;if((c[m>>2]|0)==(f|0)&(c[m+4>>2]|0)==(g|0)){j=k;break}else{k=k+1|0}}i=h;return j|0}else if((d|0)==1){d=f&255;f=0;while(1){if((a[e+f|0]|0)==d<<24>>24){j=f;break}else{f=f+1|0}}i=h;return j|0}else{KIb(0,0,2115992,(j=i,i=i+24|0,c[j>>2]=2633872,c[j+8>>2]=2610104,c[j+16>>2]=112,j)|0);i=j;Hd();return 0}return 0}function DLb(a){a=a|0;mrc(a|0,0,860)|0;c[a>>2]=SLb()|0;c[a+4>>2]=0;c[a+8>>2]=0;c[a+16>>2]=1;c[a+24>>2]=-1;c[a+36>>2]=1;c[a+28>>2]=0;c[a+32>>2]=0;c[a+56>>2]=0;c[a+52>>2]=0;c[a+60>>2]=0;c[a+64>>2]=5;c[a+68>>2]=-1;c[a+72>>2]=2;c[a+76>>2]=2;c[a+80>>2]=-1;c[a+84>>2]=0;c[a+784>>2]=25;c[a+788>>2]=1;c[a+40>>2]=-1;c[a+832>>2]=0;c[a+836>>2]=0;c[a+844>>2]=0;c[a+88>>2]=3;c[a+96>>2]=250;c[a+100>>2]=0;c[a+112>>2]=3;c[a+104>>2]=40;c[a+116>>2]=1;c[a+120>>2]=0;c[a+124>>2]=2;c[a+160>>2]=0;c[a+164>>2]=0;c[a+140>>2]=1;c[a+144>>2]=0;c[a+148>>2]=0;c[a+152>>2]=1;c[a+156>>2]=0;c[a+624>>2]=1;c[a+644>>2]=0;g[a+656>>2]=1.0;c[a+660>>2]=0;c[a+664>>2]=0;g[a+668>>2]=.8999999761581421;c[a+628>>2]=23;g[a+648>>2]=23.0;c[a+632>>2]=0;c[a+636>>2]=69;c[a+640>>2]=4;g[a+672>>2]=1.399999976158142;g[a+676>>2]=1.2999999523162842;c[a+684>>2]=1;g[a+688>>2]=1.0;c[a+696>>2]=40;c[a+700>>2]=0;c[a+704>>2]=2492288;c[a+708>>2]=0;c[a+712>>2]=2492288;g[a+716>>2]=.6000000238418579;g[a+720>>2]=.5;g[a+724>>2]=20.0;c[a+732>>2]=0;c[a+692>>2]=1;c[a+496>>2]=576;c[a+500>>2]=0;c[a+504>>2]=2;c[a+516>>2]=3;c[a+520>>2]=275;c[a+536>>2]=1;c[a+544>>2]=1;g[a+588>>2]=1.0;c[a+596>>2]=1;g[a+592>>2]=0.0;c[a+548>>2]=16;c[a+560>>2]=7;c[a+568>>2]=1;c[a+564>>2]=1;c[a+556>>2]=-1;c[a+552>>2]=-1;c[a+540>>2]=0;c[a+576>>2]=1;c[a+532>>2]=1;c[a+528>>2]=2;c[a+580>>2]=1;c[a+524>>2]=1;c[a+572>>2]=1;c[a+608>>2]=21;c[a+612>>2]=11;c[a+616>>2]=0;c[a+620>>2]=0;c[a+168>>2]=0;mrc(a+176|0,16,320)|0;c[a+764>>2]=1;c[a+768>>2]=1;c[a+760>>2]=0;c[a+776>>2]=1;c[a+48>>2]=0;c[a+800>>2]=1;c[a+804>>2]=0;c[a+808>>2]=0;c[a+756>>2]=-1;mrc(a+816|0,0,16)|0;return}function ELb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;a=i;if((b|0)==3){f=2415128}else if((b|0)==0){f=2418440}else if((b|0)==1){f=2417208}else if((b|0)==2){f=2416520}else{f=2414536}b=c[q>>2]|0;Id(b|0,2413920,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;ld(b|0,d|0,e|0)|0;i=a;return}function FLb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=i;i=i+8|0;h=f|0;DLb(b);do{if((d|0)!=0){j=rb(d|0,h|0,10)|0;do{if((a[c[h>>2]|0]|0)==0){if(!((j|0)>-1&j>>>0<10>>>0)){k=d;break}k=c[19424+(j<<2)>>2]|0}else{k=d}}while(0);if((hrc(k,2372632)|0)==0){c[b+88>>2]=1;c[b+104>>2]=0;c[b+140>>2]=0;c[b+152>>2]=0;c[b+112>>2]=0;c[b+544>>2]=0;c[b+560>>2]=0;c[b+684>>2]=0;c[b+568>>2]=0;c[b+572>>2]=0;c[b+116>>2]=0;c[b+692>>2]=0;c[b+696>>2]=0;mrc(b+516|0,0,20)|0;break}if((hrc(k,2372360)|0)==0){c[b+520>>2]=3;c[b+544>>2]=0;c[b+560>>2]=1;c[b+88>>2]=1;c[b+568>>2]=0;c[b+572>>2]=0;c[b+692>>2]=0;c[b+528>>2]=1;c[b+696>>2]=0;break}if((hrc(k,2372072)|0)==0){c[b+544>>2]=1;c[b+560>>2]=2;c[b+88>>2]=1;c[b+568>>2]=0;c[b+572>>2]=0;c[b+528>>2]=1;c[b+696>>2]=10;break}if((hrc(k,2371640)|0)==0){c[b+568>>2]=0;c[b+88>>2]=2;c[b+560>>2]=4;c[b+528>>2]=1;c[b+696>>2]=20;break}if((hrc(k,2371056)|0)==0){c[b+88>>2]=2;c[b+560>>2]=6;c[b+528>>2]=1;c[b+696>>2]=30;break}if((hrc(k,2369808)|0)==0){break}if((hrc(k,2367400)|0)==0){c[b+544>>2]=2;c[b+560>>2]=8;c[b+88>>2]=5;c[b+116>>2]=2;c[b+536>>2]=3;c[b+696>>2]=50;break}if((hrc(k,2365672)|0)==0){c[b+544>>2]=2;c[b+560>>2]=9;c[b+88>>2]=8;c[b+116>>2]=2;c[b+536>>2]=3;j=b+520|0;c[j>>2]=c[j>>2]|32;c[b+572>>2]=2;c[b+696>>2]=60;break}if((hrc(k,2363864)|0)==0){c[b+544>>2]=2;c[b+560>>2]=10;c[b+548>>2]=24;c[b+88>>2]=16;c[b+116>>2]=2;c[b+536>>2]=3;j=b+520|0;c[j>>2]=c[j>>2]|32;c[b+572>>2]=2;c[b+112>>2]=8;c[b+696>>2]=60;break}if((hrc(k,2362408)|0)==0){c[b+544>>2]=4;c[b+560>>2]=11;c[b+548>>2]=24;c[b+88>>2]=16;c[b+116>>2]=2;c[b+536>>2]=3;j=b+520|0;c[j>>2]=c[j>>2]|32;c[b+576>>2]=0;c[b+572>>2]=2;c[b+112>>2]=16;c[b+696>>2]=60;break}ILb(0,0,2361192,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;m=-1;i=f;return m|0}}while(0);if((e|0)==0){m=0;i=f;return m|0}k=lrc(e|0)|0;d=k+1|0;do{if((d|0)>1835007){h=Uqc(2097152,d)|0;if((h|0)==0){n=30;break}nd(h|0,k+262145&-2097152|0,14)|0;o=h}else{h=Uqc(32,d)|0;if((h|0)==0){n=30}else{o=h}}}while(0);if((n|0)==30){ILb(0,0,2496360,(l=i,i=i+8|0,c[l>>2]=d,l)|0);i=l;m=-1;i=f;return m|0}d=prc(o|0,e|0)|0;e=tb(d|0,2378072)|0;a:do{if((e|0)!=0){o=b+144|0;k=b+148|0;h=b+592|0;j=b+88|0;p=b+588|0;q=b+688|0;r=b+112|0;s=b+580|0;t=b+676|0;u=b+672|0;v=b+608|0;w=b+612|0;x=b+716|0;y=b+684|0;z=b+596|0;A=b+140|0;B=b+152|0;C=b+532|0;D=b+528|0;E=b+696|0;F=b+24|0;G=b+12|0;H=b+776|0;I=b+692|0;J=b+520|0;K=e;L=0;b:while(1){do{if((jrc(K,2391328,4)|0)==0){M=L+1|0;if((L|0)!=0){N=M;n=61;break}c[o>>2]=-1;c[k>>2]=-1;g[h>>2]=.15000000596046448;O=M}else{if((jrc(K,2377592,9)|0)==0){M=L+1|0;if((L|0)!=0){N=M;n=61;break}P=c[j>>2]|0;c[j>>2]=(P|0)>1?P<<1:1;c[o>>2]=1;c[k>>2]=1;g[p>>2]=.4000000059604645;g[q>>2]=.6000000238418579;c[r>>2]=(c[r>>2]|0)+2;O=M;break}if((jrc(K,2377096,5)|0)==0){M=L+1|0;if((L|0)!=0){N=M;n=61;break}c[o>>2]=-2;c[k>>2]=-2;g[h>>2]=.25;c[s>>2]=0;g[t>>2]=1.100000023841858;g[u>>2]=1.100000023841858;g[q>>2]=.5;c[v>>2]=6;c[w>>2]=6;g[x>>2]=.800000011920929;O=M;break}if((jrc(K,2376680,10)|0)==0){M=L+1|0;if((L|0)!=0){N=M;n=61;break}c[o>>2]=-3;c[k>>2]=-3;g[p>>2]=2.0;g[h>>2]=.699999988079071;g[q>>2]=1.2000000476837158;O=M;break}if((jrc(K,2522432,4)|0)==0){M=L+1|0;if((L|0)!=0){N=M;n=61;break}c[y>>2]=0;c[z>>2]=0;O=M;break}if((jrc(K,2521384,4)|0)==0){M=L+1|0;if((L|0)!=0){N=M;n=61;break}c[y>>2]=2;c[z>>2]=0;O=M;break}if((jrc(K,2376352,10)|0)==0){c[A>>2]=0;c[B>>2]=0;c[C>>2]=0;c[D>>2]=0;O=L;break}if((jrc(K,2374624,11)|0)==0){c[E>>2]=0;c[F>>2]=0;c[r>>2]=0;c[G>>2]=1;c[H>>2]=0;c[I>>2]=0;O=L;break}if((jrc(K,2373696,6)|0)!=0){break b}M=L+1|0;if((L|0)!=0){N=M;n=61;break}P=c[j>>2]|0;c[j>>2]=(P|0)>1?P<<1:1;c[o>>2]=-1;c[k>>2]=-1;g[h>>2]=.20000000298023224;g[q>>2]=1.2999999523162842;P=c[J>>2]|0;if((P&16|0)==0){O=M;break}c[J>>2]=P|32;O=M}}while(0);if((n|0)==61){n=0;ILb(0,1,2372960,(l=i,i=i+8|0,c[l>>2]=K,l)|0);i=l;O=N}M=tb(0,2378072)|0;if((M|0)==0){break a}else{K=M;L=O}}ILb(0,0,2373336,(l=i,i=i+8|0,c[l>>2]=K,l)|0);i=l;if((d|0)==0){m=-1;i=f;return m|0}Qqc(d);m=-1;i=f;return m|0}}while(0);if((d|0)==0){m=0;i=f;return m|0}Qqc(d);m=0;i=f;return m|0}function GLb(a){a=a|0;var b=0,d=0;if((c[a+700>>2]|0)==0){return}if((c[a+708>>2]|0)!=0){return}c[a+88>>2]=1;c[a+524>>2]=0;c[a+520>>2]=0;c[a+544>>2]=0;b=a+560|0;d=c[b>>2]|0;c[b>>2]=(d|0)>2?2:d;c[a+572>>2]=0;c[a+576>>2]=1;return}function HLb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0;d=i;if((b|0)==0){e=0;i=d;return e|0}do{if((hrc(b,2383080)|0)==0){f=66;h=9}else{if((hrc(b,2380984)|0)==0){f=77;h=9;break}if((hrc(b,2379960)|0)==0){f=100;h=9;break}if((hrc(b,2379352)|0)==0){f=110;h=9;break}if((hrc(b,2378896)|0)==0){f=122;h=9;break}j=(hrc(b,2378504)|0)==0;if(j){k=j?244:-1;break}ILb(0,0,2598720,(l=i,i=i+8|0,c[l>>2]=b,l)|0);i=l;e=-1;i=d;return e|0}}while(0);do{if((h|0)==9){j=c[a+624>>2]|0;if((j|0)==0){if((c[a+628>>2]|0)<1){h=12}}else if((j|0)==1){if((~~(+g[a+648>>2]+0.0)|0)<1){h=12}}if((h|0)==12){ILb(0,0,2448832,(l=i,i=i+8|0,c[l>>2]=b,l)|0);i=l;e=-1;i=d;return e|0}j=c[a+36>>2]|0;if((j&248)>>>0>7>>>0){ILb(0,0,2359680,(l=i,i=i+8|0,c[l>>2]=b,l)|0);i=l;e=-1;i=d;return e|0}if(!(f>>>0<122>>>0)){k=f;break}if(!((j&252)>>>0>3>>>0)){k=f;break}ILb(0,0,2295752,(l=i,i=i+8|0,c[l>>2]=b,l)|0);i=l;e=-1;i=d;return e|0}}while(0);if((k|0)==77){c[a+524>>2]=0;c[a+168>>2]=0;c[a+172>>2]=0;e=0;i=d;return e|0}else if((k|0)==66){c[a+524>>2]=0;c[a+152>>2]=0;c[a+168>>2]=0;c[a+172>>2]=0;c[a+112>>2]=0;c[a+528>>2]=0;if((c[a+160>>2]|0)!=0){ILb(0,0,2203168,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;e=-1;i=d;return e|0}if((c[a+808>>2]|0)==0){e=0;i=d;return e|0}ILb(0,0,2171400,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;e=-1;i=d;return e|0}else{e=0;i=d;return e|0}return 0}function ILb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f|0;do{if((a|0)==0){h=g|0;j=g;c[j>>2]=e;c[j+4>>2]=0;if((b|0)==3){k=2415128}else if((b|0)==2){k=2416520}else if((b|0)==0){k=2418440}else if((b|0)==1){k=2417208}else{k=2414536}l=c[q>>2]|0;Id(l|0,2413920,(m=i,i=i+8|0,c[m>>2]=k,m)|0)|0;i=m;ld(l|0,d|0,h|0)|0;n=j}else{if((c[a+504>>2]|0)<(b|0)){i=f;return}else{j=g;c[j>>2]=e;c[j+4>>2]=0;mf[c[a+496>>2]&2047](c[a+500>>2]|0,b,d,g|0);n=j;break}}}while(0);i=f;return}function JLb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0.0,ib=0.0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0.0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0;f=i;i=i+656|0;h=f|0;j=f+8|0;k=f+16|0;l=f+24|0;m=f+32|0;n=f+40|0;o=f+48|0;p=f+56|0;q=f+64|0;r=f+72|0;s=f+80|0;t=f+88|0;u=f+96|0;v=f+104|0;w=f+112|0;x=f+120|0;y=f+128|0;z=f+136|0;A=f+144|0;B=f+152|0;C=f+160|0;D=f+168|0;E=f+176|0;F=f+184|0;G=f+192|0;H=f+200|0;I=f+208|0;J=f+216|0;K=f+224|0;L=f+232|0;M=f+240|0;N=f+248|0;O=f+256|0;P=f+264|0;Q=f+272|0;R=f+280|0;S=f+288|0;T=f+296|0;U=f+304|0;V=f+312|0;W=f+320|0;X=f+328|0;Y=f+336|0;Z=f+344|0;_=f+352|0;$=f+360|0;aa=f+368|0;ba=f+376|0;ca=f+384|0;da=f+392|0;ea=f+400|0;fa=f+408|0;ga=f+416|0;ha=f+424|0;ia=f+432|0;ja=f+440|0;ka=f+448|0;la=f+456|0;ma=f+464|0;na=f+472|0;oa=f+480|0;pa=f+488|0;qa=f+496|0;ra=f+504|0;sa=f+512|0;ta=f+520|0;ua=f+528|0;va=f+536|0;wa=f+544|0;xa=f+552|0;ya=f+560|0;za=f+568|0;Aa=f+576|0;Ba=f+584|0;Ca=f+592|0;Da=f+600|0;Ea=f+608|0;Fa=f+616|0;Ga=f+624|0;Ha=f+632|0;Ia=f+640|0;Ja=f+648|0;c[Ia>>2]=0;Ka=(e|0)!=0;if((d|0)==0){La=-1;i=f;return La|0}Ma=Ka?e:2143960;e=(a[Ma]|0)==61?Ma+1|0:Ma;do{if((_b(d|0,95)|0)==0){Na=d;Oa=0}else{Ma=ed(d|0)|0;Pa=_b(Ma|0,95)|0;if((Pa|0)==0){Na=Ma;Oa=Ma;break}else{Qa=Pa}while(1){a[Qa]=45;Pa=_b(Ma|0,95)|0;if((Pa|0)==0){Na=Ma;Oa=Ma;break}else{Qa=Pa}}}}while(0);if((krc(Na,2120344,3)|0)==0){Ra=3;Sa=7}else{if((krc(Na,2638184,2)|0)==0){Ra=2;Sa=7}else{Ta=Na;Ua=e}}if((Sa|0)==7){Qa=(KLb(e,Ia)|0)!=0;Ta=Na+Ra|0;Ua=Qa?2615288:2143960}a:do{if((irc(Ta,2588272)|0)==0){do{if(((a[Ua]|0)-48|0)>>>0<10>>>0){Qa=rb(Ua|0,Ha|0,0)|0;Ra=c[Ha>>2]|0;if((Ra|0)!=(Ua|0)){if((a[Ra]|0)==0){Va=Qa;Wa=0;break}}c[Ia>>2]=1;Va=Qa;Wa=0}else{if((irc(Ua,2566896)|0)==0){Xa=0}else{if((KLb(Ua,Ia)|0)==0){Va=0;Wa=1;break}else{Xa=1}}Va=SLb()|0;Wa=Xa}}while(0);Qa=b|0;c[Qa>>2]=Va;if((c[Ia>>2]|0)==0){Ya=Wa;break}Ra=ed(Ua|0)|0;c[Ja>>2]=0;c[Ia>>2]=0;c[Qa>>2]=0;Na=Fd(Ra|0,2548552,Ja|0)|0;if((Na|0)!=0){e=Na;do{Na=0;while(1){Za=c[3038784+(Na*20|0)>>2]|0;if((Za|0)==0){Sa=23;break}if((hrc(e,3038768+(Na*20|0)|0)|0)==0){Sa=21;break}else{Na=Na+1|0}}if((Sa|0)==21){Sa=0;c[Qa>>2]=c[Qa>>2]|Za}else if((Sa|0)==23){Sa=0;c[Qa>>2]=c[Qa>>2]|Za;c[Ia>>2]=1}e=Fd(0,2548552,Ja|0)|0;}while((e|0)!=0)}Qqc(Ra);e=c[Qa>>2]|0;if((e&524352|0)!=64){Ya=Wa;break}c[Qa>>2]=e|1048576;Ya=Wa}else{if((irc(Ta,2530792)|0)==0){if((irc(Ua,2566896)|0)==0){c[b+4>>2]=0;Ya=0;break}e=rb(Ua|0,Ga|0,0)|0;Na=c[Ga>>2]|0;if((Na|0)==(Ua|0)){Sa=31}else{if((a[Na]|0)!=0){Sa=31}}if((Sa|0)==31){c[Ia>>2]=1}c[b+4>>2]=e;Ya=0;break}if((irc(Ta,2515464)|0)==0){if((irc(Ua,2566896)|0)==0){c[b+8>>2]=0;Ya=0;break}e=rb(Ua|0,Fa|0,0)|0;Na=c[Fa>>2]|0;if((Na|0)==(Ua|0)){Sa=38}else{if((a[Na]|0)!=0){Sa=38}}if((Sa|0)==38){c[Ia>>2]=1}c[b+8>>2]=e;Ya=0;break}if((irc(Ta,2501536)|0)==0){c[b+12>>2]=KLb(Ua,Ia)|0;Ya=1;break}if((irc(Ta,2488680)|0)==0){if((irc(Ua,2566896)|0)==0){c[b+24>>2]=-1;Ya=0;break}e=rb(Ua|0,Ea|0,0)|0;Na=c[Ea>>2]|0;if((Na|0)==(Ua|0)){Sa=47}else{if((a[Na]|0)!=0){Sa=47}}if((Sa|0)==47){c[Ia>>2]=1}c[b+24>>2]=e;Ya=0;break}do{if((irc(Ta,2477728)|0)!=0){if((irc(Ta,2468240)|0)==0){break}if((irc(Ta,2458728)|0)==0){c[b+20>>2]=KLb(Ua,Ia)|0;Ya=1;break a}do{if((irc(Ta,2441872)|0)!=0){if((irc(Ta,2430008)|0)==0){break}if((irc(Ta,2410408)|0)==0){c[b+132>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2402792)|0)==0){e=rb(Ua|0,Aa|0,0)|0;Na=c[Aa>>2]|0;if((Na|0)==(Ua|0)){Sa=75}else{if((a[Na]|0)!=0){Sa=75}}if((Sa|0)==75){c[Ia>>2]=1}c[b+136>>2]=e;Ya=0;break a}if((irc(Ta,2395848)|0)==0){e=b+56|0;Na=b+52|0;d=Bd(Ua|0,2388592,(_a=i,i=i+16|0,c[_a>>2]=e,c[_a+8>>2]=Na,_a)|0)|0;i=_a;if((d|0)==2){$a=0}else{d=Bd(Ua|0,2381792,(_a=i,i=i+16|0,c[_a>>2]=e,c[_a+8>>2]=Na,_a)|0)|0;i=_a;$a=(d|0)!=2|0}c[Ia>>2]=$a;Ya=0;break a}if((irc(Ta,2375264)|0)==0){d=b+60|0;Na=0;while(1){if((Na|0)==3){ab=-1;break}if((irc(Ua,c[19552+(Na<<2)>>2]|0)|0)==0){Sa=85;break}else{Na=Na+1|0}}if((Sa|0)==85){c[d>>2]=Na;ab=0}c[Ia>>2]=c[Ia>>2]|ab;Ya=0;break a}if((irc(Ta,2368632)|0)==0){e=b+64|0;Ma=0;while(1){if((Ma|0)==6){bb=-1;break}if((irc(Ua,c[16136+(Ma<<2)>>2]|0)|0)==0){Sa=91;break}else{Ma=Ma+1|0}}if((Sa|0)==91){c[e>>2]=Ma;bb=0}c[Ia>>2]=c[Ia>>2]|bb;Ya=0;break a}if((irc(Ta,2353608)|0)==0){Na=b+68|0;d=0;while(1){if((d|0)==2){cb=-1;break}if((irc(Ua,c[97752+(d<<2)>>2]|0)|0)==0){Sa=97;break}else{d=d+1|0}}if((Sa|0)==97){c[Na>>2]=d;cb=0}c[Ia>>2]=c[Ia>>2]|cb;Ya=0;break a}if((irc(Ta,2345088)|0)==0){Ma=b+72|0;e=0;while(1){if((e|0)==10){db=-1;break}if((irc(Ua,c[99304+(e<<2)>>2]|0)|0)==0){Sa=103;break}else{e=e+1|0}}if((Sa|0)==103){c[Ma>>2]=e;db=0}c[Ia>>2]=c[Ia>>2]|db;Ya=0;break a}if((irc(Ta,2339024)|0)==0){d=b+76|0;Na=0;while(1){if((Na|0)==16){eb=-1;break}if((irc(Ua,c[17960+(Na<<2)>>2]|0)|0)==0){Sa=109;break}else{Na=Na+1|0}}if((Sa|0)==109){c[d>>2]=Na;eb=0}c[Ia>>2]=c[Ia>>2]|eb;Ya=0;break a}if((irc(Ta,2333424)|0)==0){e=b+80|0;Ma=0;while(1){if((Ma|0)==11){fb=-1;break}if((irc(Ua,c[99352+(Ma<<2)>>2]|0)|0)==0){Sa=115;break}else{Ma=Ma+1|0}}if((Sa|0)==115){c[e>>2]=Ma;fb=0}c[Ia>>2]=c[Ia>>2]|fb;Ya=0;break a}if((irc(Ta,2327944)|0)==0){Na=rb(Ua|0,za|0,0)|0;d=c[za>>2]|0;if((d|0)==(Ua|0)){Sa=120}else{if((a[d]|0)!=0){Sa=120}}if((Sa|0)==120){c[Ia>>2]=1}c[b+84>>2]=Na;if((Na|0)<0){gb=1}else{gb=(Na|0)>5|0}c[Ia>>2]=gb;Ya=0;break a}if((irc(Ta,2322168)|0)==0){Na=b+784|0;d=b+788|0;Pa=Bd(Ua|0,2317048,(_a=i,i=i+16|0,c[_a>>2]=Na,c[_a+8>>2]=d,_a)|0)|0;i=_a;if((Pa|0)==2){Ya=0;break a}hb=+frc(Ua,ya);Pa=c[ya>>2]|0;if((Pa|0)==(Ua|0)){Sa=128}else{if((a[Pa]|0)!=0){Sa=128}}if((Sa|0)==128){c[Ia>>2]=1}ib=hb;if(ib>0.0&ib<=2147483.0){c[Na>>2]=~~(ib*1.0e3+.5);c[d>>2]=1e3;Ya=0;break a}Pa=rb(Ua|0,xa|0,0)|0;jb=c[xa>>2]|0;if((jb|0)==(Ua|0)){Sa=133}else{if((a[jb]|0)!=0){Sa=133}}if((Sa|0)==133){c[Ia>>2]=1}c[Na>>2]=Pa;c[d>>2]=1;Ya=0;break a}do{if((irc(Ta,2312632)|0)!=0){if((irc(Ta,2307944)|0)==0){break}if((irc(Ta,2302800)|0)==0){d=rb(Ua|0,va|0,0)|0;Pa=c[va>>2]|0;if((Pa|0)==(Ua|0)){Sa=144}else{if((a[Pa]|0)!=0){Sa=144}}if((Sa|0)==144){c[Ia>>2]=1}c[b+92>>2]=d;Ya=0;break a}if((irc(Ta,2291560)|0)==0){if((Db(Ua|0,2284744)|0)!=0){c[b+96>>2]=1073741824;Ya=0;break a}d=rb(Ua|0,ua|0,0)|0;Pa=c[ua>>2]|0;if((Pa|0)==(Ua|0)){Sa=151}else{if((a[Pa]|0)!=0){Sa=151}}if((Sa|0)==151){c[Ia>>2]=1}c[b+96>>2]=d;Ya=0;break a}do{if((irc(Ta,2280896)|0)!=0){if((irc(Ta,2276728)|0)==0){break}if((irc(Ta,2272328)|0)==0){d=KLb(Ua,Ia)|0;Pa=b+104|0;c[Pa>>2]=d;if((c[Ia>>2]|d|0)==0){Ya=1;break a}c[Ia>>2]=0;d=rb(Ua|0,sa|0,0)|0;Na=c[sa>>2]|0;if((Na|0)==(Ua|0)){Sa=164}else{if((a[Na]|0)!=0){Sa=164}}if((Sa|0)==164){c[Ia>>2]=1}c[Pa>>2]=d;Ya=1;break a}if((irc(Ta,2267560)|0)==0){c[b+108>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2263960)|0)==0){d=rb(Ua|0,ra|0,0)|0;Pa=c[ra>>2]|0;if((Pa|0)==(Ua|0)){Sa=171}else{if((a[Pa]|0)!=0){Sa=171}}if((Sa|0)==171){c[Ia>>2]=1}c[b+112>>2]=d;Ya=0;break a}if((irc(Ta,2259984)|0)==0){d=b+116|0;c[d>>2]=KLb(Ua,Ia)|0;if((c[Ia>>2]|0)==0){Ya=1;break a}c[Ia>>2]=0;Pa=rb(Ua|0,qa|0,0)|0;Na=c[qa>>2]|0;if((Na|0)==(Ua|0)){Sa=177}else{if((a[Na]|0)!=0){Sa=177}}if((Sa|0)==177){c[Ia>>2]=1}c[d>>2]=Pa;Ya=1;break a}if((irc(Ta,2255680)|0)==0){Pa=rb(Ua|0,pa|0,0)|0;d=c[pa>>2]|0;if((d|0)==(Ua|0)){Sa=182}else{if((a[d]|0)!=0){Sa=182}}if((Sa|0)==182){c[Ia>>2]=1}c[b+120>>2]=Pa;Ya=0;break a}if((irc(Ta,2251336)|0)==0){Pa=b+124|0;d=0;while(1){if((d|0)==3){kb=-1;break}if((irc(Ua,c[109736+(d<<2)>>2]|0)|0)==0){Sa=188;break}else{d=d+1|0}}if((Sa|0)==188){c[Pa>>2]=d;kb=0}Na=c[Ia>>2]|kb;c[Ia>>2]=Na;if((Na|0)==0){Ya=0;break a}c[Ia>>2]=0;Na=rb(Ua|0,oa|0,0)|0;jb=c[oa>>2]|0;if((jb|0)==(Ua|0)){Sa=192}else{if((a[jb]|0)!=0){Sa=192}}if((Sa|0)==192){c[Ia>>2]=1}c[Pa>>2]=Na;Ya=0;break a}if((irc(Ta,2240768)|0)==0){c[b+128>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2235120)|0)==0){c[b+140>>2]=(KLb(Ua,Ia)|0)==0;Ya=1;break a}do{if((irc(Ta,2231528)|0)!=0){if((irc(Ta,2227760)|0)==0){break}if((irc(Ta,2216344)|0)==0){Na=rb(Ua|0,na|0,0)|0;jb=c[na>>2]|0;if((jb|0)==(Ua|0)){Sa=209}else{if((a[jb]|0)!=0){Sa=209}}if((Sa|0)==209){c[Ia>>2]=1}c[b+832>>2]=Na;Ya=0;break a}if((irc(Ta,2213736)|0)==0){Na=rb(Ua|0,ma|0,0)|0;jb=c[ma>>2]|0;if((jb|0)==(Ua|0)){Sa=214}else{if((a[jb]|0)!=0){Sa=214}}if((Sa|0)==214){c[Ia>>2]=1}c[b+836>>2]=Na;Ya=0;break a}if((irc(Ta,2211400)|0)==0){Na=rb(Ua|0,la|0,0)|0;jb=c[la>>2]|0;if((jb|0)==(Ua|0)){Sa=219}else{if((a[jb]|0)!=0){Sa=219}}if((Sa|0)==219){c[Ia>>2]=1}c[b+840>>2]=Na;Ya=0;break a}if((irc(Ta,2208536)|0)==0){Na=rb(Ua|0,ka|0,0)|0;jb=c[ka>>2]|0;if((jb|0)==(Ua|0)){Sa=224}else{if((a[jb]|0)!=0){Sa=224}}if((Sa|0)==224){c[Ia>>2]=1}c[b+844>>2]=Na;Ya=0;break a}if((irc(Ta,2199728)|0)==0){Na=rb(Ua|0,ja|0,0)|0;jb=c[ja>>2]|0;if((jb|0)==(Ua|0)){Sa=229}else{if((a[jb]|0)!=0){Sa=229}}if((Sa|0)==229){c[Ia>>2]=1}c[b+848>>2]=Na;Ya=0;break a}if((irc(Ta,2195392)|0)==0){c[b+152>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2192888)|0)==0){Na=rb(Ua|0,ia|0,0)|0;jb=c[ia>>2]|0;if((jb|0)==(Ua|0)){Sa=236}else{if((a[jb]|0)!=0){Sa=236}}if((Sa|0)==236){c[Ia>>2]=1}c[b+156>>2]=Na;Ya=0;break a}if((irc(Ta,2190344)|0)==0){c[b+160>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2187808)|0)==0){Na=KLb(Ua,Ia)|0;c[b+800>>2]=Na;c[b+160>>2]=Na;Ya=1;break a}if((irc(Ta,2185248)|0)==0){Na=KLb(Ua,Ia)|0;c[b+160>>2]=Na;c[b+800>>2]=(Na|0)==0;Ya=1;break a}if((irc(Ta,2182952)|0)==0){c[b+164>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2180928)|0)==0){if((Db(Ua|0,2178584)|0)!=0){c[b+168>>2]=0;Ya=0;break a}if((Db(Ua|0,2175944)|0)==0){c[b+172>>2]=ed(Ua|0)|0;Ya=0;break a}else{c[b+168>>2]=1;Ya=0;break a}}if((irc(Ta,2168088)|0)==0){c[b+172>>2]=ed(Ua|0)|0;Ya=0;break a}if((irc(Ta,2163952)|0)==0){c[b+168>>2]=2;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=ha,_a)|0)|0;i=_a;mb=c[ha>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){nb=-1;break}ob=Na+1|0;a[b+176+Na|0]=mb;if((ob|0)>=16){Sa=259;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=259;break}else{Na=ob;jb=mb+1|0}}if((Sa|0)==259){nb=((ob|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|nb;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=ga,_a)|0)|0;i=_a;lb=c[ga>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){pb=-1;break}qb=jb+1|0;a[b+192+jb|0]=lb;if((qb|0)>=16){Sa=264;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=264;break}else{jb=qb;Na=lb+1|0}}if((Sa|0)==264){pb=((qb|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|pb;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=fa,_a)|0)|0;i=_a;mb=c[fa>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){sb=-1;break}tb=Na+1|0;a[b+208+Na|0]=mb;if((tb|0)>=16){Sa=269;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=269;break}else{Na=tb;jb=mb+1|0}}if((Sa|0)==269){sb=((tb|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|sb;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=ea,_a)|0)|0;i=_a;lb=c[ea>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){ub=-1;break}vb=jb+1|0;a[b+224+jb|0]=lb;if((vb|0)>=16){Sa=274;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=274;break}else{jb=vb;Na=lb+1|0}}if((Sa|0)==274){ub=((vb|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|ub;Ya=0;break a}if((irc(Ta,2161768)|0)==0){c[b+168>>2]=2;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=da,_a)|0)|0;i=_a;mb=c[da>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){wb=-1;break}xb=Na+1|0;a[b+240+Na|0]=mb;if((xb|0)>=64){Sa=281;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=281;break}else{Na=xb;jb=mb+1|0}}if((Sa|0)==281){wb=((xb|0)!=64)<<31>>31}c[Ia>>2]=c[Ia>>2]|wb;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=ca,_a)|0)|0;i=_a;lb=c[ca>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){yb=-1;break}zb=jb+1|0;a[b+304+jb|0]=lb;if((zb|0)>=64){Sa=286;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=286;break}else{jb=zb;Na=lb+1|0}}if((Sa|0)==286){yb=((zb|0)!=64)<<31>>31}c[Ia>>2]=c[Ia>>2]|yb;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=ba,_a)|0)|0;i=_a;mb=c[ba>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){Ab=-1;break}Bb=Na+1|0;a[b+368+Na|0]=mb;if((Bb|0)>=64){Sa=291;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=291;break}else{Na=Bb;jb=mb+1|0}}if((Sa|0)==291){Ab=((Bb|0)!=64)<<31>>31}c[Ia>>2]=c[Ia>>2]|Ab;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=aa,_a)|0)|0;i=_a;lb=c[aa>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){Cb=-1;break}Eb=jb+1|0;a[b+432+jb|0]=lb;if((Eb|0)>=64){Sa=296;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=296;break}else{jb=Eb;Na=lb+1|0}}if((Sa|0)==296){Cb=((Eb|0)!=64)<<31>>31}c[Ia>>2]=c[Ia>>2]|Cb;Ya=0;break a}if((irc(Ta,2159816)|0)==0){c[b+168>>2]=2;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=$,_a)|0)|0;i=_a;mb=c[$>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){Fb=-1;break}Gb=Na+1|0;a[b+176+Na|0]=mb;if((Gb|0)>=16){Sa=303;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=303;break}else{Na=Gb;jb=mb+1|0}}if((Sa|0)==303){Fb=((Gb|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|Fb;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=_,_a)|0)|0;i=_a;lb=c[_>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){Hb=-1;break}Ib=jb+1|0;a[b+208+jb|0]=lb;if((Ib|0)>=16){Sa=308;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=308;break}else{jb=Ib;Na=lb+1|0}}if((Sa|0)==308){Hb=((Ib|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|Hb;Ya=0;break a}if((irc(Ta,2158008)|0)==0){c[b+168>>2]=2;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=Z,_a)|0)|0;i=_a;mb=c[Z>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){Jb=-1;break}Kb=Na+1|0;a[b+192+Na|0]=mb;if((Kb|0)>=16){Sa=315;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=315;break}else{Na=Kb;jb=mb+1|0}}if((Sa|0)==315){Jb=((Kb|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|Jb;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=Y,_a)|0)|0;i=_a;lb=c[Y>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){Lb=-1;break}Mb=jb+1|0;a[b+224+jb|0]=lb;if((Mb|0)>=16){Sa=320;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=320;break}else{jb=Mb;Na=lb+1|0}}if((Sa|0)==320){Lb=((Mb|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|Lb;Ya=0;break a}if((irc(Ta,2156152)|0)==0){c[b+168>>2]=2;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=X,_a)|0)|0;i=_a;mb=c[X>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){Nb=-1;break}Ob=Na+1|0;a[b+176+Na|0]=mb;if((Ob|0)>=16){Sa=327;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=327;break}else{Na=Ob;jb=mb+1|0}}if((Sa|0)==327){Nb=((Ob|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|Nb;Ya=0;break a}if((irc(Ta,2154504)|0)==0){c[b+168>>2]=2;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=W,_a)|0)|0;i=_a;lb=c[W>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){Pb=-1;break}Qb=jb+1|0;a[b+208+jb|0]=lb;if((Qb|0)>=16){Sa=334;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=334;break}else{jb=Qb;Na=lb+1|0}}if((Sa|0)==334){Pb=((Qb|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|Pb;Ya=0;break a}if((irc(Ta,2152632)|0)==0){c[b+168>>2]=2;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=V,_a)|0)|0;i=_a;mb=c[V>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){Rb=-1;break}Sb=Na+1|0;a[b+192+Na|0]=mb;if((Sb|0)>=16){Sa=341;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=341;break}else{Na=Sb;jb=mb+1|0}}if((Sa|0)==341){Rb=((Sb|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|Rb;Ya=0;break a}if((irc(Ta,2150344)|0)==0){c[b+168>>2]=2;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=U,_a)|0)|0;i=_a;lb=c[U>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){Tb=-1;break}Ub=jb+1|0;a[b+224+jb|0]=lb;if((Ub|0)>=16){Sa=348;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=348;break}else{jb=Ub;Na=lb+1|0}}if((Sa|0)==348){Tb=((Ub|0)!=16)<<31>>31}c[Ia>>2]=c[Ia>>2]|Tb;Ya=0;break a}if((irc(Ta,2148088)|0)==0){c[b+168>>2]=2;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=T,_a)|0)|0;i=_a;mb=c[T>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){Vb=-1;break}Wb=Na+1|0;a[b+240+Na|0]=mb;if((Wb|0)>=64){Sa=355;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=355;break}else{Na=Wb;jb=mb+1|0}}if((Sa|0)==355){Vb=((Wb|0)!=64)<<31>>31}c[Ia>>2]=c[Ia>>2]|Vb;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=S,_a)|0)|0;i=_a;lb=c[S>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){Xb=-1;break}Yb=jb+1|0;a[b+368+jb|0]=lb;if((Yb|0)>=64){Sa=360;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=360;break}else{jb=Yb;Na=lb+1|0}}if((Sa|0)==360){Xb=((Yb|0)!=64)<<31>>31}c[Ia>>2]=c[Ia>>2]|Xb;Ya=0;break a}if((irc(Ta,2141416)|0)==0){c[b+168>>2]=2;Na=0;jb=Ua;while(1){lb=Bd(jb|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=R,_a)|0)|0;i=_a;mb=c[R>>2]|0;if((lb|0)==0|(mb|0)<1|(mb|0)>255){Zb=-1;break}$b=Na+1|0;a[b+304+Na|0]=mb;if(($b|0)>=64){Sa=367;break}mb=_b(jb|0,44)|0;if((mb|0)==0){Sa=367;break}else{Na=$b;jb=mb+1|0}}if((Sa|0)==367){Zb=(($b|0)!=64)<<31>>31}c[Ia>>2]=c[Ia>>2]|Zb;jb=0;Na=Ua;while(1){mb=Bd(Na|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=Q,_a)|0)|0;i=_a;lb=c[Q>>2]|0;if((mb|0)==0|(lb|0)<1|(lb|0)>255){ac=-1;break}bc=jb+1|0;a[b+432+jb|0]=lb;if((bc|0)>=64){Sa=372;break}lb=_b(Na|0,44)|0;if((lb|0)==0){Sa=372;break}else{jb=bc;Na=lb+1|0}}if((Sa|0)==372){ac=((bc|0)!=64)<<31>>31}c[Ia>>2]=c[Ia>>2]|ac;Ya=0;break a}if((irc(Ta,2137976)|0)==0){Na=rb(Ua|0,P|0,0)|0;jb=c[P>>2]|0;if((jb|0)==(Ua|0)){Sa=377}else{if((a[jb]|0)!=0){Sa=377}}if((Sa|0)==377){c[Ia>>2]=1}c[b+504>>2]=Na;Ya=0;break a}if((irc(Ta,2136352)|0)==0){c[b+512>>2]=ed(Ua|0)|0;Ya=0;break a}do{if((irc(Ta,2134376)|0)!=0){if((irc(Ta,2132544)|0)==0){break}if((irc(Ta,2112912)|0)==0){c[b+524>>2]=KLb(Ua,Ia)|0;Ya=1;break a}do{if((irc(Ta,2111016)|0)!=0){if((irc(Ta,2109376)|0)==0){break}if((irc(Ta,2107824)|0)==0){Na=rb(Ua|0,O|0,0)|0;jb=c[O>>2]|0;if((jb|0)==(Ua|0)){Sa=405}else{if((a[jb]|0)!=0){Sa=405}}if((Sa|0)==405){c[Ia>>2]=1}c[b+528>>2]=Na;Ya=0;break a}do{if((irc(Ta,2106504)|0)!=0){if((irc(Ta,2104952)|0)==0){break}if((irc(Ta,2644248)|0)==0){Na=rb(Ua|0,N|0,0)|0;jb=c[N>>2]|0;if((jb|0)==(Ua|0)){Sa=417}else{if((a[jb]|0)!=0){Sa=417}}if((Sa|0)==417){c[Ia>>2]=1}c[b+540>>2]=Na;Ya=0;break a}if((irc(Ta,2642336)|0)==0){Na=b+544|0;jb=0;while(1){if((jb|0)==5){cc=-1;break}if((irc(Ua,c[94520+(jb<<2)>>2]|0)|0)==0){Sa=423;break}else{jb=jb+1|0}}if((Sa|0)==423){c[Na>>2]=jb;cc=0}c[Ia>>2]=c[Ia>>2]|cc;Ya=0;break a}do{if((irc(Ta,2635880)|0)!=0){if((irc(Ta,2632736)|0)==0){break}do{if((irc(Ta,2630600)|0)!=0){if((irc(Ta,2628680)|0)==0){break}do{if((irc(Ta,2627216)|0)!=0){if((irc(Ta,2625800)|0)==0){break}do{if((irc(Ta,2624616)|0)!=0){if((irc(Ta,2623072)|0)==0){break}if((irc(Ta,2621552)|0)==0){lb=b+588|0;mb=b+592|0;dc=Bd(Ua|0,2619040,(_a=i,i=i+16|0,c[_a>>2]=lb,c[_a+8>>2]=mb,_a)|0)|0;i=_a;if((dc|0)==2){Ya=0;break a}dc=Bd(Ua|0,2612360,(_a=i,i=i+16|0,c[_a>>2]=lb,c[_a+8>>2]=mb,_a)|0)|0;i=_a;if((dc|0)==2){Ya=0;break a}dc=Bd(Ua|0,2608920,(_a=i,i=i+16|0,c[_a>>2]=lb,c[_a+8>>2]=mb,_a)|0)|0;i=_a;if((dc|0)==2){Ya=0;break a}dc=Bd(Ua|0,2605960,(_a=i,i=i+8|0,c[_a>>2]=lb,_a)|0)|0;i=_a;if((dc|0)==0){g[lb>>2]=0.0;g[mb>>2]=0.0;Ya=0;break a}else{g[mb>>2]=0.0;Ya=0;break a}}if((irc(Ta,2603752)|0)==0){c[b+596>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2601808)|0)==0){c[b+564>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2599992)|0)==0){c[b+568>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2598448)|0)==0){mb=rb(Ua|0,I|0,0)|0;lb=c[I>>2]|0;if((lb|0)==(Ua|0)){Sa=465}else{if((a[lb]|0)!=0){Sa=465}}if((Sa|0)==465){c[Ia>>2]=1}c[b+572>>2]=mb;Ya=0;break a}if((irc(Ta,2595864)|0)==0){c[b+576>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2593976)|0)==0){c[b+580>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2591632)|0)==0){mb=rb(Ua|0,H|0,0)|0;lb=c[H>>2]|0;if((lb|0)==(Ua|0)){Sa=474}else{if((a[lb]|0)!=0){Sa=474}}if((Sa|0)==474){c[Ia>>2]=1}c[b+608>>2]=mb;Ya=0;break a}if((irc(Ta,2585704)|0)==0){mb=rb(Ua|0,G|0,0)|0;lb=c[G>>2]|0;if((lb|0)==(Ua|0)){Sa=479}else{if((a[lb]|0)!=0){Sa=479}}if((Sa|0)==479){c[Ia>>2]=1}c[b+612>>2]=mb;Ya=0;break a}if((irc(Ta,2582256)|0)==0){mb=rb(Ua|0,F|0,0)|0;lb=c[F>>2]|0;if((lb|0)==(Ua|0)){Sa=484}else{if((a[lb]|0)!=0){Sa=484}}if((Sa|0)==484){c[Ia>>2]=1}c[b+584>>2]=mb;Ya=0;break a}if((irc(Ta,2580280)|0)==0){mb=rb(Ua|0,E|0,0)|0;lb=c[E>>2]|0;if((lb|0)==(Ua|0)){Sa=489}else{if((a[lb]|0)!=0){Sa=489}}if((Sa|0)==489){c[Ia>>2]=1}c[b+644>>2]=mb;c[b+624>>2]=2;Ya=0;break a}do{if((irc(Ta,2577968)|0)!=0){if((irc(Ta,2576560)|0)==0){break}if((irc(Ta,2575232)|0)==0){ib=+frc(Ua,C);mb=c[C>>2]|0;if((mb|0)==(Ua|0)){Sa=500}else{if((a[mb]|0)!=0){Sa=500}}if((Sa|0)==500){c[Ia>>2]=1}g[b+648>>2]=ib;c[b+624>>2]=1;Ya=0;break a}if((irc(Ta,2573952)|0)==0){ib=+frc(Ua,B);mb=c[B>>2]|0;if((mb|0)==(Ua|0)){Sa=505}else{if((a[mb]|0)!=0){Sa=505}}if((Sa|0)==505){c[Ia>>2]=1}g[b+652>>2]=ib;Ya=0;break a}if((irc(Ta,2572424)|0)==0){mb=rb(Ua|0,A|0,0)|0;lb=c[A>>2]|0;if((lb|0)==(Ua|0)){Sa=510}else{if((a[lb]|0)!=0){Sa=510}}if((Sa|0)==510){c[Ia>>2]=1}c[b+696>>2]=mb;Ya=0;break a}do{if((irc(Ta,2571032)|0)!=0){if((irc(Ta,2569472)|0)==0){break}do{if((irc(Ta,2564840)|0)!=0){if((irc(Ta,2561952)|0)==0){break}do{if((irc(Ta,2560392)|0)!=0){if((irc(Ta,2558752)|0)==0){break}if((irc(Ta,2557584)|0)==0){if((krc(2556296,Ua,3)|0)==0){ec=1.0e9}else{ib=+frc(Ua,w);mb=c[w>>2]|0;if((mb|0)==(Ua|0)){Sa=534}else{if((a[mb]|0)!=0){Sa=534}}if((Sa|0)==534){c[Ia>>2]=1}ec=ib}g[b+656>>2]=ec;Ya=0;break a}if((irc(Ta,2555248)|0)==0){mb=rb(Ua|0,v|0,0)|0;lb=c[v>>2]|0;if((lb|0)==(Ua|0)){Sa=540}else{if((a[lb]|0)!=0){Sa=540}}if((Sa|0)==540){c[Ia>>2]=1}c[b+660>>2]=mb;Ya=0;break a}if((irc(Ta,2553944)|0)==0){mb=rb(Ua|0,u|0,0)|0;lb=c[u>>2]|0;if((lb|0)==(Ua|0)){Sa=545}else{if((a[lb]|0)!=0){Sa=545}}if((Sa|0)==545){c[Ia>>2]=1}c[b+664>>2]=mb;Ya=0;break a}if((irc(Ta,2553088)|0)==0){ib=+frc(Ua,t);mb=c[t>>2]|0;if((mb|0)==(Ua|0)){Sa=550}else{if((a[mb]|0)!=0){Sa=550}}if((Sa|0)==550){c[Ia>>2]=1}g[b+668>>2]=ib;Ya=0;break a}do{if((irc(Ta,2551344)|0)!=0){if((irc(Ta,2546752)|0)==0){break}do{if((irc(Ta,2544440)|0)!=0){if((irc(Ta,2543032)|0)==0){break}if((irc(Ta,2541368)|0)==0){mb=rb(Ua|0,q|0,0)|0;lb=c[q>>2]|0;if((lb|0)==(Ua|0)){Sa=567}else{if((a[lb]|0)!=0){Sa=567}}if((Sa|0)==567){c[Ia>>2]=1}c[b+684>>2]=mb;Ya=0;break a}if((irc(Ta,2540184)|0)==0){ib=+frc(Ua,p);mb=c[p>>2]|0;if((mb|0)==(Ua|0)){Sa=572}else{if((a[mb]|0)!=0){Sa=572}}if((Sa|0)==572){c[Ia>>2]=1}g[b+688>>2]=ib;Ya=0;break a}if((irc(Ta,2538872)|0)==0){mb=rb(Ua|0,o|0,0)|0;lb=c[o>>2]|0;if((lb|0)==(Ua|0)){Sa=577}else{if((a[lb]|0)!=0){Sa=577}}if((Sa|0)==577){c[Ia>>2]=1}if((mb|0)<0){fc=0}else{fc=(mb|0)>3?3:mb}c[b+700>>2]=fc&1;c[b+708>>2]=fc&2;Ya=0;break a}if((irc(Ta,2537488)|0)==0){c[b+712>>2]=ed(Ua|0)|0;c[b+704>>2]=ed(Ua|0)|0;Ya=0;break a}if((irc(Ta,2536144)|0)==0){ib=+frc(Ua,n);mb=c[n>>2]|0;if((mb|0)==(Ua|0)){Sa=586}else{if((a[mb]|0)!=0){Sa=586}}if((Sa|0)==586){c[Ia>>2]=1}g[b+716>>2]=ib;Ya=0;break a}if((irc(Ta,2534912)|0)==0){c[b+692>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2533192)|0)==0){ib=+frc(Ua,m);mb=c[m>>2]|0;if((mb|0)==(Ua|0)){Sa=593}else{if((a[mb]|0)!=0){Sa=593}}if((Sa|0)==593){c[Ia>>2]=1}g[b+720>>2]=ib;Ya=0;break a}do{if((irc(Ta,2529088)|0)!=0){if((irc(Ta,2526824)|0)==0){break}if((irc(Ta,2525672)|0)==0){c[b+736>>2]=ed(Ua|0)|0;Ya=0;break a}if((irc(Ta,2524320)|0)==0){mb=Bd(Ua|0,2523328,(_a=i,i=i+32|0,c[_a>>2]=b+740,c[_a+8>>2]=b+744,c[_a+16>>2]=b+748,c[_a+24>>2]=b+752,_a)|0)|0;i=_a;c[Ia>>2]=(mb|0)!=4|c[Ia>>2];Ya=0;break a}if((irc(Ta,2522432)|0)==0){c[b+616>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2521384)|0)==0){c[b+620>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2520144)|0)==0){c[b+760>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2519256)|0)==0){mb=rb(Ua|0,k|0,0)|0;lb=c[k>>2]|0;if((lb|0)==(Ua|0)){Sa=614}else{if((a[lb]|0)!=0){Sa=614}}if((Sa|0)==614){c[Ia>>2]=1}c[b+772>>2]=mb;Ya=0;break a}if((irc(Ta,2517736)|0)==0){c[b+764>>2]=(KLb(Ua,Ia)|0)==0;Ya=1;break a}if((irc(Ta,2513888)|0)==0){c[b+764>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2511712)|0)==0){c[b+768>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2510496)|0)==0){c[b+776>>2]=(KLb(Ua,Ia)|0)==0;Ya=1;break a}if((irc(Ta,2509248)|0)==0){mb=b+48|0;lb=0;while(1){if((lb|0)==3){gc=-1;break}if((irc(Ua,c[94504+(lb<<2)>>2]|0)|0)==0){Sa=628;break}else{lb=lb+1|0}}if((Sa|0)==628){c[mb>>2]=lb;gc=0}c[Ia>>2]=c[Ia>>2]|gc;Ya=0;break a}if((irc(Ta,2508592)|0)==0){c[b+680>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2507656)|0)==0){c[b+804>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2506808)|0)==0){c[b+808>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2505752)|0)==0){dc=rb(Ua|0,j|0,0)|0;hc=c[j>>2]|0;if((hc|0)==(Ua|0)){Sa=639}else{if((a[hc]|0)!=0){Sa=639}}if((Sa|0)==639){c[Ia>>2]=1}c[b+756>>2]=dc;Ya=0;break a}if((irc(Ta,2504912)|0)==0){c[b+812>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2503824)|0)==0){c[b+816>>2]=KLb(Ua,Ia)|0;Ya=1;break a}if((irc(Ta,2500208)|0)==0){c[b+828>>2]=ed(Ua|0)|0;Ya=0;break a}if((irc(Ta,2497616)|0)!=0){La=-1;i=f;return La|0}dc=rb(Ua|0,h|0,0)|0;hc=c[h>>2]|0;if((hc|0)==(Ua|0)){Sa=650}else{if((a[hc]|0)!=0){Sa=650}}if((Sa|0)==650){c[Ia>>2]=1}c[b+820>>2]=dc;Ya=0;break a}}while(0);ib=+frc(Ua,l);dc=c[l>>2]|0;if((dc|0)==(Ua|0)){Sa=599}else{if((a[dc]|0)!=0){Sa=599}}if((Sa|0)==599){c[Ia>>2]=1}g[b+724>>2]=ib;Ya=0;break a}}while(0);ib=+frc(Ua,r);dc=c[r>>2]|0;if((dc|0)==(Ua|0)){Sa=562}else{if((a[dc]|0)!=0){Sa=562}}if((Sa|0)==562){c[Ia>>2]=1}g[b+676>>2]=ib;Ya=0;break a}}while(0);ib=+frc(Ua,s);dc=c[s>>2]|0;if((dc|0)==(Ua|0)){Sa=556}else{if((a[dc]|0)!=0){Sa=556}}if((Sa|0)==556){c[Ia>>2]=1}g[b+672>>2]=ib;Ya=0;break a}}while(0);dc=rb(Ua|0,x|0,0)|0;hc=c[x>>2]|0;if((hc|0)==(Ua|0)){Sa=528}else{if((a[hc]|0)!=0){Sa=528}}if((Sa|0)==528){c[Ia>>2]=1}c[b+640>>2]=dc;Ya=0;break a}}while(0);dc=rb(Ua|0,y|0,0)|0;hc=c[y>>2]|0;if((hc|0)==(Ua|0)){Sa=522}else{if((a[hc]|0)!=0){Sa=522}}if((Sa|0)==522){c[Ia>>2]=1}c[b+636>>2]=dc;Ya=0;break a}}while(0);dc=rb(Ua|0,z|0,0)|0;hc=c[z>>2]|0;if((hc|0)==(Ua|0)){Sa=516}else{if((a[hc]|0)!=0){Sa=516}}if((Sa|0)==516){c[Ia>>2]=1}c[b+632>>2]=dc;Ya=0;break a}}while(0);dc=rb(Ua|0,D|0,0)|0;hc=c[D>>2]|0;if((hc|0)==(Ua|0)){Sa=495}else{if((a[hc]|0)!=0){Sa=495}}if((Sa|0)==495){c[Ia>>2]=1}c[b+628>>2]=dc;c[b+624>>2]=0;Ya=0;break a}}while(0);dc=rb(Ua|0,J|0,0)|0;hc=c[J>>2]|0;if((hc|0)==(Ua|0)){Sa=447}else{if((a[hc]|0)!=0){Sa=447}}if((Sa|0)==447){c[Ia>>2]=1}c[b+560>>2]=dc;Ya=0;break a}}while(0);dc=rb(Ua|0,K|0,0)|0;hc=c[K>>2]|0;if((hc|0)==(Ua|0)){Sa=441}else{if((a[hc]|0)!=0){Sa=441}}if((Sa|0)==441){c[Ia>>2]=1}c[b+556>>2]=dc;Ya=0;break a}}while(0);dc=rb(Ua|0,L|0,0)|0;hc=c[L>>2]|0;if((hc|0)==(Ua|0)){Sa=435}else{if((a[hc]|0)!=0){Sa=435}}if((Sa|0)==435){c[Ia>>2]=1}c[b+552>>2]=dc;Ya=0;break a}}while(0);jb=rb(Ua|0,M|0,0)|0;Na=c[M>>2]|0;if((Na|0)==(Ua|0)){Sa=429}else{if((a[Na]|0)!=0){Sa=429}}if((Sa|0)==429){c[Ia>>2]=1}c[b+548>>2]=jb;Ya=0;break a}}while(0);jb=b+536|0;Na=0;while(1){if((Na|0)==4){ic=-1;break}if((irc(Ua,c[97856+(Na<<2)>>2]|0)|0)==0){Sa=412;break}else{Na=Na+1|0}}if((Sa|0)==412){c[jb>>2]=Na;ic=0}c[Ia>>2]=c[Ia>>2]|ic;Ya=0;break a}}while(0);c[b+532>>2]=KLb(Ua,Ia)|0;Ya=1;break a}}while(0);dc=b+520|0;c[dc>>2]=0;if((Db(Ua|0,2130984)|0)!=0){c[dc>>2]=0}if((Db(Ua|0,2129560)|0)==0){jc=0}else{c[dc>>2]=-1;jc=-1}if((Db(Ua|0,2128016)|0)==0){kc=jc}else{hc=jc|1;c[dc>>2]=hc;kc=hc}if((Db(Ua|0,2126816)|0)==0){lc=kc}else{hc=kc|2;c[dc>>2]=hc;lc=hc}if((Db(Ua|0,2124088)|0)==0){mc=lc}else{hc=lc|16;c[dc>>2]=hc;mc=hc}if((Db(Ua|0,2117832)|0)==0){nc=mc}else{hc=mc|32;c[dc>>2]=hc;nc=hc}if((Db(Ua|0,2114640)|0)==0){Ya=0;break a}c[dc>>2]=nc|256;Ya=0;break a}}while(0);Pa=b+144|0;d=b+148|0;dc=Bd(Ua|0,2388592,(_a=i,i=i+16|0,c[_a>>2]=Pa,c[_a+8>>2]=d,_a)|0)|0;i=_a;do{if((dc|0)!=2){hc=Bd(Ua|0,2222952,(_a=i,i=i+16|0,c[_a>>2]=Pa,c[_a+8>>2]=d,_a)|0)|0;i=_a;if((hc|0)==2){break}hc=Bd(Ua|0,2219360,(_a=i,i=i+8|0,c[_a>>2]=Pa,_a)|0)|0;i=_a;if((hc|0)==0){c[b+140>>2]=KLb(Ua,Ia)|0;Ya=1;break a}else{c[b+140>>2]=1;c[d>>2]=c[Pa>>2];Ya=0;break a}}}while(0);c[b+140>>2]=1;Ya=0;break a}}while(0);Pa=rb(Ua|0,ta|0,0)|0;d=c[ta>>2]|0;if((d|0)==(Ua|0)){Sa=157}else{if((a[d]|0)!=0){Sa=157}}if((Sa|0)==157){c[Ia>>2]=1}c[b+100>>2]=Pa;d=b+96|0;if((c[d>>2]|0)>=(Pa|0)){Ya=0;break a}c[d>>2]=Pa;Ya=0;break a}}while(0);Ma=rb(Ua|0,wa|0,0)|0;e=c[wa>>2]|0;if((e|0)==(Ua|0)){Sa=139}else{if((a[e]|0)!=0){Sa=139}}if((Sa|0)==139){c[Ia>>2]=1}c[b+88>>2]=Ma;Ya=0;break a}}while(0);if((irc(Ua,2419480)|0)==0){c[b+40>>2]=9;Ya=0;break a}ib=+frc(Ua,Da);Ma=c[Da>>2]|0;if((Ma|0)==(Ua|0)){Sa=60}else{if((a[Ma]|0)!=0){Sa=60}}if((Sa|0)==60){c[Ia>>2]=1}if(ib<6.0){ib=+frc(Ua,Ca);Ma=c[Ca>>2]|0;if((Ma|0)==(Ua|0)){Sa=64}else{if((a[Ma]|0)!=0){Sa=64}}if((Sa|0)==64){c[Ia>>2]=1}c[b+40>>2]=~~(ib*10.0+.5);Ya=0;break a}else{Ma=rb(Ua|0,Ba|0,0)|0;e=c[Ba>>2]|0;if((e|0)==(Ua|0)){Sa=68}else{if((a[e]|0)!=0){Sa=68}}if((Sa|0)==68){c[Ia>>2]=1}c[b+40>>2]=Ma;Ya=0;break a}}}while(0);c[b+16>>2]=KLb(Ua,Ia)|0;Ya=1}}while(0);if((Oa|0)!=0){Qqc(Oa)}if(Ka){oc=0}else{oc=(Ya|0)==0|0}Ya=c[Ia>>2]|oc;c[Ia>>2]=Ya;La=(Ya|0)!=0?-2:0;i=f;return La|0}function KLb(a,b){a=a|0;b=b|0;var d=0;do{if((irc(a,2383912)|0)==0){d=1}else{if((irc(a,2143960)|0)==0){d=1;break}if((irc(a,2383520)|0)==0){d=1;break}if((irc(a,2462224)|0)==0){d=0;break}if((irc(a,2615288)|0)==0){d=0;break}if((irc(a,2638184)|0)==0){d=0;break}c[b>>2]=1;d=0}}while(0);return d|0}function LLb(a){a=a|0;mrc(a|0,0,192)|0;c[a>>2]=0;c[a+4>>2]=0;c[a+8>>2]=0;return}function MLb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;do{if((a|0)>1835007){d=Uqc(2097152,a)|0;if((d|0)==0){e=5;break}nd(d|0,a+262144&-2097152|0,14)|0;f=d}else{d=Uqc(32,a)|0;if((d|0)==0){e=5}else{f=d}}}while(0);if((e|0)==5){ILb(0,0,2496360,(e=i,i=i+8|0,c[e>>2]=a,e)|0);i=e;f=0}i=b;return f|0}function NLb(a){a=a|0;if((a|0)!=0){Qqc(a)}return}function OLb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[a>>2]|0;e=c[b>>2]|0;if((d|0)==0|(e|0)==0){return}f=(d>>>0)%(e>>>0)|0;if((f|0)==0){g=e}else{h=e;e=f;while(1){f=(h>>>0)%(e>>>0)|0;if((f|0)==0){g=e;break}else{h=e;e=f}}}c[a>>2]=(d>>>0)/(g>>>0)|0;c[b>>2]=((c[b>>2]|0)>>>0)/(g>>>0)|0;return}function PLb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[a>>2]|0;e=c[a+4>>2]|0;f=c[b>>2]|0;g=c[b+4>>2]|0;if((d|0)==0&(e|0)==0|(f|0)==0&(g|0)==0){return}h=Grc(d,e,f,g)|0;i=G;if((h|0)==0&(i|0)==0){j=g;k=f}else{l=g;g=f;f=i;i=h;while(1){h=Grc(g,l,i,f)|0;m=G;if((h|0)==0&(m|0)==0){j=f;k=i;break}else{l=f;g=i;f=m;i=h}}}i=Frc(d,e,k,j)|0;c[a>>2]=i;c[a+4>>2]=G;a=Frc(c[b>>2]|0,c[b+4>>2]|0,k,j)|0;c[b>>2]=a;c[b+4>>2]=G;return}function QLb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=Qc(b|0,2495256)|0;if((e|0)==0){f=0;i=d;return f|0}b=(Rd(e|0,0,2)|0)>>>31;g=dc(e|0)|0;do{if(((g|0)==0|b|(Rd(e|0,0,0)|0)>>>31|0)==0){h=g+2|0;do{if((h|0)>1835007){j=Uqc(2097152,h)|0;if((j|0)==0){k=7;break}nd(j|0,g+262146&-2097152|0,14)|0;l=j}else{j=Uqc(32,h)|0;if((j|0)==0){k=7}else{l=j}}}while(0);if((k|0)==7){ILb(0,0,2496360,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;break}j=(Ed(l|0,1,g|0,e|0)|0)!=(g|0);if((a[l+(g-1)|0]|0)==10){m=g}else{a[l+g|0]=10;m=g+1|0}a[l+m|0]=0;nb(e|0)|0;if((l|0)==0|j^1){f=j?0:l;i=d;return f|0}Qqc(l);f=0;i=d;return f|0}}while(0);nb(e|0)|0;f=0;i=d;return f|0}function RLb(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;e=i;f=b+736|0;j=c[f>>2]|0;do{if((j|0)==0){k=1e3;l=5}else{m=lrc(j|0)|0;n=m+1e3|0;if((n|0)<=1835007){k=n;l=5;break}o=Uqc(2097152,n)|0;if((o|0)==0){p=n;l=6;break}nd(o|0,m+263144&-2097152|0,14)|0;q=o}}while(0);if((l|0)==5){j=Uqc(32,k)|0;if((j|0)==0){p=k;l=6}else{q=j}}if((l|0)==6){ILb(0,0,2496360,(r=i,i=i+8|0,c[r>>2]=p,r)|0);i=r;s=0;i=e;return s|0}if((d|0)==0){t=q}else{d=c[b+32>>2]|0;p=gc(q|0,2494152,(r=i,i=i+16|0,c[r>>2]=c[b+28>>2],c[r+8>>2]=d,r)|0)|0;i=r;d=c[b+788>>2]|0;j=gc(q+p|0,2493224,(r=i,i=i+16|0,c[r>>2]=c[b+784>>2],c[r+8>>2]=d,r)|0)|0;i=r;d=j+p|0;p=c[b+796>>2]|0;j=gc(q+d|0,2492408,(r=i,i=i+16|0,c[r>>2]=c[b+792>>2],c[r+8>>2]=p,r)|0)|0;i=r;p=j+d|0;d=gc(q+p|0,2491768,(r=i,i=i+8|0,c[r>>2]=8,r)|0)|0;i=r;t=q+(p+d)|0}d=c[b+816>>2]|0;if((d|0)==0){u=t}else{p=gc(t|0,2491280,(r=i,i=i+8|0,c[r>>2]=d,r)|0)|0;i=r;u=t+p|0}p=gc(u|0,2490344,(r=i,i=i+8|0,c[r>>2]=c[b+152>>2],r)|0)|0;i=r;t=gc(u+p|0,2487544,(r=i,i=i+8|0,c[r>>2]=c[b+88>>2],r)|0)|0;i=r;d=t+p|0;p=c[b+144>>2]|0;t=c[b+148>>2]|0;j=gc(u+d|0,2486240,(r=i,i=i+24|0,c[r>>2]=c[b+140>>2],c[r+8>>2]=p,c[r+16>>2]=t,r)|0)|0;i=r;t=j+d|0;d=c[b+520>>2]|0;j=gc(u+t|0,2485344,(r=i,i=i+16|0,c[r>>2]=c[b+516>>2],c[r+8>>2]=d,r)|0)|0;i=r;d=j+t|0;t=gc(u+d|0,2484664,(r=i,i=i+8|0,c[r>>2]=c[94520+(c[b+544>>2]<<2)>>2],r)|0)|0;i=r;j=t+d|0;d=gc(u+j|0,2483888,(r=i,i=i+8|0,c[r>>2]=c[b+560>>2],r)|0)|0;i=r;t=d+j|0;j=b+596|0;d=gc(u+t|0,2483216,(r=i,i=i+8|0,c[r>>2]=c[j>>2],r)|0)|0;i=r;p=d+t|0;t=u+p|0;if((c[j>>2]|0)==0){v=t}else{w=+g[b+592>>2];j=gc(t|0,2482640,(r=i,i=i+16|0,h[r>>3]=+g[b+588>>2],h[r+8>>3]=w,r)|0)|0;i=r;v=u+(j+p)|0}p=gc(v|0,2480952,(r=i,i=i+8|0,c[r>>2]=c[b+568>>2],r)|0)|0;i=r;j=gc(v+p|0,2480400,(r=i,i=i+8|0,c[r>>2]=c[b+548>>2],r)|0)|0;i=r;u=j+p|0;p=gc(v+u|0,2479520,(r=i,i=i+8|0,c[r>>2]=c[b+564>>2],r)|0)|0;i=r;j=p+u|0;u=gc(v+j|0,2476320,(r=i,i=i+8|0,c[r>>2]=c[b+572>>2],r)|0)|0;i=r;p=u+j|0;j=gc(v+p|0,2474512,(r=i,i=i+8|0,c[r>>2]=c[b+524>>2],r)|0)|0;i=r;u=j+p|0;p=gc(v+u|0,2473872,(r=i,i=i+8|0,c[r>>2]=c[b+168>>2],r)|0)|0;i=r;j=p+u|0;u=c[b+612>>2]|0;p=gc(v+j|0,2473280,(r=i,i=i+16|0,c[r>>2]=c[b+608>>2],c[r+8>>2]=u,r)|0)|0;i=r;u=p+j|0;j=gc(v+u|0,2472696,(r=i,i=i+8|0,c[r>>2]=c[b+576>>2],r)|0)|0;i=r;p=j+u|0;u=gc(v+p|0,2471992,(r=i,i=i+8|0,c[r>>2]=c[b+540>>2],r)|0)|0;i=r;j=u+p|0;p=gc(v+j|0,2471352,(r=i,i=i+8|0,c[r>>2]=c[b+4>>2],r)|0)|0;i=r;u=p+j|0;j=gc(v+u|0,2470712,(r=i,i=i+8|0,c[r>>2]=c[b+8>>2],r)|0)|0;i=r;p=j+u|0;u=gc(v+p|0,2470264,(r=i,i=i+8|0,c[r>>2]=c[b+12>>2],r)|0)|0;i=r;j=u+p|0;p=v+j|0;u=c[b+844>>2]|0;if((u|0)==0){x=p}else{t=gc(p|0,2469704,(r=i,i=i+8|0,c[r>>2]=u,r)|0)|0;i=r;x=v+(t+j)|0}j=c[b+848>>2]|0;if((j|0)==0){y=x}else{t=gc(x|0,2467080,(r=i,i=i+8|0,c[r>>2]=j,r)|0)|0;i=r;y=x+t|0}t=c[b+832>>2]|0;if((t|0)==0){z=y}else{x=gc(y|0,2465840,(r=i,i=i+8|0,c[r>>2]=t,r)|0)|0;i=r;z=y+x|0}x=c[b+836>>2]|0;if((x|0)==0){A=z}else{y=gc(z|0,2465312,(r=i,i=i+8|0,c[r>>2]=x,r)|0)|0;i=r;A=z+y|0}y=c[b+840>>2]|0;if((y|0)==0){B=A}else{z=gc(A|0,2464928,(r=i,i=i+8|0,c[r>>2]=y,r)|0)|0;i=r;B=A+z|0}z=gc(B|0,2464528,(r=i,i=i+8|0,c[r>>2]=c[b+584>>2],r)|0)|0;i=r;A=gc(B+z|0,2463936,(r=i,i=i+8|0,c[r>>2]=c[b+580>>2],r)|0)|0;i=r;y=A+z|0;if((c[b+160>>2]|0)==0){C=(c[b+808>>2]|0)!=0?2463e3:2462224}else{C=(c[b+800>>2]|0)!=0?2187808:2185248}z=gc(B+y|0,2463480,(r=i,i=i+8|0,c[r>>2]=C,r)|0)|0;i=r;C=z+y|0;y=gc(B+C|0,2460608,(r=i,i=i+8|0,c[r>>2]=c[b+132>>2],r)|0)|0;i=r;z=y+C|0;C=B+z|0;y=c[b+812>>2]|0;if((y|0)==0){D=C}else{A=gc(C|0,2457280,(r=i,i=i+8|0,c[r>>2]=y,r)|0)|0;i=r;D=B+(A+z)|0}z=gc(D|0,2455232,(r=i,i=i+8|0,c[r>>2]=c[b+164>>2],r)|0)|0;i=r;A=b+112|0;B=gc(D+z|0,2453144,(r=i,i=i+8|0,c[r>>2]=c[A>>2],r)|0)|0;i=r;y=B+z|0;z=D+y|0;if((c[A>>2]|0)==0){E=z}else{B=c[b+116>>2]|0;C=c[b+120>>2]|0;x=c[b+536>>2]|0;t=c[b+532>>2]|0;j=c[b+128>>2]|0;v=gc(z|0,2451744,(r=i,i=i+48|0,c[r>>2]=c[b+124>>2],c[r+8>>2]=B,c[r+16>>2]=C,c[r+24>>2]=x,c[r+32>>2]=t,c[r+40>>2]=j,r)|0)|0;i=r;E=D+(v+y)|0}y=c[b+528>>2]|0;v=gc(E|0,2450512,(r=i,i=i+8|0,c[r>>2]=(y|0)>0?y:0,r)|0)|0;i=r;y=E+v|0;D=c[b+96>>2]|0;if((D|0)==1073741824){nrc(y|0,2449624,17)|0;F=16}else{j=gc(y|0,2448600,(r=i,i=i+8|0,c[r>>2]=D,r)|0)|0;i=r;F=j}j=F+v|0;v=c[b+104>>2]|0;F=c[b+108>>2]|0;D=gc(E+j|0,2446776,(r=i,i=i+24|0,c[r>>2]=c[b+100>>2],c[r+8>>2]=v,c[r+16>>2]=F,r)|0)|0;i=r;F=D+j|0;j=E+F|0;D=b+692|0;if((c[D>>2]|0)==0){if((c[b+664>>2]|0)==0){G=j}else{l=35}}else{l=35}if((l|0)==35){v=gc(j|0,2445544,(r=i,i=i+8|0,c[r>>2]=c[b+696>>2],r)|0)|0;i=r;G=E+(F+v)|0}v=b+624|0;F=c[v>>2]|0;do{if((F|0)==2){if((c[b+708>>2]|0)!=0){H=2440160;break}H=(c[b+660>>2]|0)==(c[b+644>>2]|0)?2438072:2436680}else{H=(F|0)==1?2575232:2435640}}while(0);F=c[D>>2]|0;E=gc(G|0,2443944,(r=i,i=i+16|0,c[r>>2]=H,c[r+8>>2]=F,r)|0)|0;i=r;F=G+E|0;H=c[v>>2]|0;if((H|0)==2){w=+g[b+656>>2];j=gc(F|0,2433736,(r=i,i=i+16|0,c[r>>2]=c[b+644>>2],h[r+8>>3]=w,r)|0)|0;i=r;I=j;l=43}else if((H|0)==0){j=gc(F|0,2428992,(r=i,i=i+8|0,c[r>>2]=c[b+628>>2],r)|0)|0;i=r;J=G+(j+E)|0}else if((H|0)==1){H=gc(F|0,2434096,(r=i,i=i+8|0,h[r>>3]=+g[b+648>>2],r)|0)|0;i=r;I=H;l=43}else{J=F}do{if((l|0)==43){F=I+E|0;H=c[b+632>>2]|0;j=c[b+636>>2]|0;y=c[b+640>>2]|0;t=gc(G+F|0,2433136,(r=i,i=i+32|0,h[r>>3]=+g[b+716>>2],c[r+8>>2]=H,c[r+16>>2]=j,c[r+24>>2]=y,r)|0)|0;i=r;y=t+F|0;F=G+y|0;if((c[b+708>>2]|0)==0){K=F}else{w=+g[b+720>>2];t=gc(F|0,2432368,(r=i,i=i+16|0,h[r>>3]=+g[b+724>>2],h[r+8>>3]=w,r)|0)|0;i=r;K=G+(y+t)|0}t=c[b+664>>2]|0;if((t|0)==0){J=K;break}y=gc(K|0,2431760,(r=i,i=i+16|0,c[r>>2]=c[b+660>>2],c[r+8>>2]=t,r)|0)|0;i=r;t=K+y|0;if((c[v>>2]|0)!=1){J=t;break}F=gc(t|0,2431280,(r=i,i=i+8|0,h[r>>3]=+g[b+652>>2],r)|0)|0;i=r;J=K+(F+y)|0}}while(0);if((c[b+664>>2]|0)==0){L=J}else{K=c[b+680>>2]|0;G=gc(J|0,2427368,(r=i,i=i+16|0,c[r>>2]=c[94504+(c[b+48>>2]<<2)>>2],c[r+8>>2]=K,r)|0)|0;i=r;L=J+G|0}G=c[b+740>>2]|0;J=c[b+744>>2]|0;K=c[b+748>>2]|0;E=c[b+752>>2]|0;if((J|G|K|E|0)==0){M=L}else{I=gc(L|0,2426624,(r=i,i=i+32|0,c[r>>2]=G,c[r+8>>2]=J,c[r+16>>2]=K,c[r+24>>2]=E,r)|0)|0;i=r;M=L+I|0}I=c[b+756>>2]|0;if((I|0)>-1){L=gc(M|0,2425880,(r=i,i=i+8|0,c[r>>2]=I,r)|0)|0;i=r;N=M+L|0}else{N=M}do{if((c[v>>2]|0)==0){if((c[b+628>>2]|0)==0){s=q}else{break}i=e;return s|0}}while(0);v=gc(N|0,2425376,(r=i,i=i+8|0,h[r>>3]=+g[b+672>>2],r)|0)|0;i=r;M=N+v|0;do{if((c[A>>2]|0)==0){O=M}else{if((c[D>>2]|0)!=0){O=M;break}L=gc(M|0,2424872,(r=i,i=i+8|0,h[r>>3]=+g[b+676>>2],r)|0)|0;i=r;O=N+(L+v)|0}}while(0);v=b+684|0;N=gc(O|0,2424360,(r=i,i=i+8|0,c[r>>2]=c[v>>2],r)|0)|0;i=r;M=O+N|0;if((c[v>>2]|0)==0){P=M}else{v=gc(M|0,2423672,(r=i,i=i+8|0,h[r>>3]=+g[b+688>>2],r)|0)|0;i=r;P=O+(v+N)|0}N=c[f>>2]|0;if((N|0)!=0){gc(P|0,2423272,(r=i,i=i+8|0,c[r>>2]=N,r)|0)|0;i=r;s=q;i=e;return s|0}if((c[b+732>>2]|0)==0){s=q;i=e;return s|0}a[P]=a[2421792]|0;a[P+1|0]=a[2421793]|0;a[P+2|0]=a[2421794]|0;a[P+3|0]=a[2421795]|0;a[P+4|0]=a[2421796]|0;a[P+5|0]=a[2421797]|0;a[P+6|0]=a[2421798]|0;s=q;i=e;return s|0}function SLb(){return 0}function TLb(){return 1}function ULb(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0.0,aa=0.0,ba=0.0,da=0.0,ea=0.0,fa=0,ga=0.0,ha=0.0,ia=0,ja=0,ka=0,la=0;e=i;i=i+1088|0;f=e|0;h=e+80|0;j=e+1080|0;k=MLb(50496)|0;l=k;a:do{if((k|0)!=0){mrc(k|0,0,50496)|0;m=k;n=d;nrc(k|0,n|0,860)|0;o=c[d+852>>2]|0;if((o|0)!=0){qe[o&1023](n)}if((VLb(l,1)|0)<0){break}n=c[k+172>>2]|0;if((n|0)!=0){if((PTb(l,n)|0)<0){break}}n=k+624|0;o=k+704|0;p=c[o>>2]|0;if((p|0)!=0){c[o>>2]=ed(p|0)|0}p=k+712|0;o=c[p>>2]|0;if((o|0)!=0){c[p>>2]=ed(o|0)|0}o=k+784|0;p=k+788|0;OLb(o,p);q=k+796|0;OLb(k+792|0,q);c[k+1540>>2]=-1;c[k+1544>>2]=0;c[k+1648>>2]=0;r=c[q>>2]|0;q=r;s=0<<1|q>>>31;t=0;if(s>>>0>t>>>0|s>>>0==t>>>0&(q<<1|0>>>31)>>>0>-1>>>0){ILb(l,0,2459328,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;break}WLb(l,m,1);r=k+8368|0;q=k+772|0;YMb(r,c[q>>2]|0,m);_Mb(k+8636|0,c[q>>2]|0,m,r);kNb(l,1)|0;c[k+3216>>2]=(c[k+8680>>2]|0)+1078116;if((NTb(l)|0)<0){break}r=c[k+8416>>2]|0;c[k+18560>>2]=r;m=c[k+8420>>2]|0;c[k+18564>>2]=m;c[k+18568>>2]=ca(r,m)|0;m=k+8632|0;r=c[m>>2]|0;q=(r|0)==1;if(q){v=1}else{v=(r|0)==2|0}c[k+18572>>2]=v;c[k+18576>>2]=q&1;q=k+160|0;if((c[q>>2]|0)==0){w=0}else{w=(c[k+560>>2]|0)!=0|0}c[k+18664>>2]=w;r=c[k+116>>2]|0;do{if((r|0)==2){if((c[k+708>>2]|0)!=0){x=21;break}t=c[k+112>>2]|0;s=(t|0)>3?t<<2:12;c[k+15076>>2]=s;y=s;z=t}else{x=21}}while(0);if((x|0)==21){t=c[k+112>>2]|0;c[k+15076>>2]=t;y=t;z=t}t=(c[k+692>>2]|0)==0;do{if(t){if((c[k+664>>2]|0)!=0){x=25;break}A=y;B=k+15076|0}else{x=25}}while(0);if((x|0)==25){s=k+15076|0;C=c[k+696>>2]|0;D=(y|0)>(C|0)?y:C;c[s>>2]=D;A=D;B=s}s=k+14960|0;D=k+1548|0;C=A-1+(c[D>>2]|0)|0;c[B>>2]=C;E=k+24|0;F=C+(c[E>>2]|0)|0;c[B>>2]=F;C=F+(c[k+776>>2]|0)|0;c[B>>2]=C;F=k+112|0;if((z|0)==0){H=0}else{H=(c[k+124>>2]|0)!=0?2:1}c[k+15080>>2]=H;I=c[k+88>>2]|0;c[k+15068>>2]=I;J=c[k+8620>>2]|0;c[k+15072>>2]=(J|0)<(I|0)?J:I;c[k+15064>>2]=c[k+8624>>2];I=(c[k+708>>2]|0)==0;do{if(I){if(!(((c[n>>2]|0)-1|0)>>>0>1>>>0&(r|0)==0)){J=k+15136|0;c[J>>2]=1;K=0;L=1;M=J;break}if((c[k+104>>2]|0)!=0|t^1){N=1}else{N=(c[k+528>>2]|0)!=0|0}J=k+15136|0;c[J>>2]=N;if(I){K=0;L=N;M=J}else{O=N;P=J;x=35}}else{J=k+15136|0;c[J>>2]=0;O=0;P=J;x=35}}while(0);if((x|0)==35){K=(c[k+664>>2]|0)>0|0;L=O;M=P}c[M>>2]=L|K;c[k+15140>>2]=(c[k+520>>2]|0)>>>5&1;I=-(c[k+96>>2]|0)|0;c[k+15048>>2]=I;c[k+15052>>2]=I;c[k+15060>>2]=0;c[k+15056>>2]=-1;mrc(k+15120|0,-1|0,16)|0;I=MLb((C<<2)+12|0)|0;c[k+14964>>2]=I;if((I|0)==0){break}mrc(I|0,0,(c[B>>2]<<2)+12|0)|0;I=MLb((c[D>>2]<<2)+80|0)|0;c[k+14968>>2]=I;if((I|0)==0){break}mrc(I|0,0,(c[D>>2]<<2)+80|0)|0;I=MLb(((c[F>>2]|0)+(c[E>>2]|0)+(c[D>>2]|0)<<2)+12|0)|0;c[s>>2]=I;if((I|0)==0){break}mrc(I|0,0,((c[F>>2]|0)+(c[E>>2]|0)+(c[D>>2]|0)<<2)+12|0)|0;if((c[k+528>>2]|0)>0){I=MLb(c[D>>2]<<4)|0;c[k+14972>>2]=I;if((I|0)==0){break}mrc(I|0,0,c[D>>2]<<4|0)|0}c[k+15156>>2]=0;c[k+15152>>2]=0;I=k+1560|0;c[I>>2]=0;c[I+4>>2]=0;mrc(k+1584|0,0,16)|0;I=Erc(c[k+8528>>2]|0,0,c[p>>2]|0,0)|0;t=G;r=Erc(c[k+8524>>2]|0,0,c[o>>2]|0,0)|0;J=Frc(I,t,r,G)|0;r=k+1576|0;c[r>>2]=J;c[r+4>>2]=G;c[k+1568>>2]=-1;XTb();r=k;nSb(c[r>>2]|0,k+36532|0);J=k+36684|0;rSb(c[r>>2]|0,J);t=k+36712|0;vSb(c[r>>2]|0,t);zSb(c[r>>2]|0,k+36560|0,k+36740|0);KSb(c[r>>2]|0,k+36608|0);I=k+36744|0;NQb(c[r>>2]|0,I);xNb(c[r>>2]|0,k+37572|0);Q=k+37688|0;R=k+37664|0;PNb(c[r>>2]|0,Q,R);S=k+37640|0;U=(c[q>>2]|0)!=0?R:Q;c[S>>2]=c[U>>2];c[S+4>>2]=c[U+4>>2];c[S+8>>2]=c[U+8>>2];c[S+12>>2]=c[U+12>>2];c[S+16>>2]=c[U+16>>2];c[S+20>>2]=c[U+20>>2];U=k+20|0;oPb(c[r>>2]|0,k+37376|0,c[U>>2]|0);USb(l,c[r>>2]|0,k+37712|0);cOb(c[r>>2]|0,k+37924|0,c[q>>2]|0);mNb(c[r>>2]|0,k+38008|0);if((c[k+152>>2]|0)==0){RTb(l)}else{oNb(l)}S=(c[k+28836>>2]|0)==0;if(S){V=(c[k+560>>2]|0)>1}else{V=0}Q=k+36808|0;nrc(k+36884|0,(V?Q:k+37036|0)|0,32)|0;R=I;nrc(k+36916|0,(V?Q:R)|0,32)|0;c[k+37280>>2]=c[(V?k+37284|0:k+37288|0)>>2];I=c[(V?k+37320|0:k+37324|0)>>2]|0;c[k+37316>>2]=I;W=c[(V?k+37332|0:k+37336|0)>>2]|0;c[k+37328>>2]=W;c[k+37340>>2]=c[(V?k+37344|0:k+37348|0)>>2];c[k+37292>>2]=c[(V?k+37296|0:k+37300|0)>>2];do{if((c[U>>2]|0)==0){do{if(S){if(V){c[k+37352>>2]=c[k+37356>>2];break}else{X=c[k+37360>>2]|0;x=52;break}}else{X=0;x=52}}while(0);if((x|0)==52){c[k+37352>>2]=X}if(!S){Y=0;break}if(V){Y=c[k+37368>>2]|0;break}else{Y=c[k+37372>>2]|0;break}}else{c[k+37352>>2]=0;Y=0}}while(0);c[k+37364>>2]=Y;S=V&(c[k+544>>2]|0)==4;nrc(k+36948|0,(S?Q:R)|0,32)|0;U=k+36980|0;q=S?k+37196|0:k+37140|0;c[U>>2]=c[q>>2];c[U+4>>2]=c[q+4>>2];c[U+8>>2]=c[q+8>>2];c[U+12>>2]=c[q+12>>2];c[U+16>>2]=c[q+16>>2];c[U+20>>2]=c[q+20>>2];c[U+24>>2]=c[q+24>>2];q=k+37008|0;U=S?k+37224|0:k+37168|0;c[q>>2]=c[U>>2];c[q+4>>2]=c[U+4>>2];c[q+8>>2]=c[U+8>>2];c[q+12>>2]=c[U+12>>2];c[q+16>>2]=c[U+16>>2];c[q+20>>2]=c[U+20>>2];c[q+24>>2]=c[U+24>>2];U=k+36448|0;q=c[m>>2]|0;S=95520+(q*7|0)|0;a[U]=a[S]|0;a[U+1|0]=a[S+1|0]|0;a[U+2|0]=a[S+2|0]|0;a[U+3|0]=a[S+3|0]|0;a[U+4|0]=a[S+4|0]|0;a[U+5|0]=a[S+5|0]|0;a[U+6|0]=a[S+6|0]|0;if((q|0)==1){S=k+36656|0;c[S>>2]=c[J>>2];c[S+4>>2]=c[J+4>>2];c[S+8>>2]=c[J+8>>2];c[S+12>>2]=c[J+12>>2];c[S+16>>2]=c[J+16>>2];c[S+20>>2]=c[J+20>>2];c[S+24>>2]=c[J+24>>2];c[k+37504>>2]=c[k+37508>>2];c[k+37932>>2]=c[k+37940>>2];c[k+37956>>2]=c[k+37964>>2];c[k+37976>>2]=c[k+37980>>2];c[k+37992>>2]=c[k+37996>>2];c[k+37304>>2]=W;c[k+37788>>2]=c[k+37832>>2];c[k+37852>>2]=c[k+37892>>2]}else if((q|0)==2){S=k+36656|0;c[S>>2]=c[t>>2];c[S+4>>2]=c[t+4>>2];c[S+8>>2]=c[t+8>>2];c[S+12>>2]=c[t+12>>2];c[S+16>>2]=c[t+16>>2];c[S+20>>2]=c[t+20>>2];c[S+24>>2]=c[t+24>>2];c[k+37504>>2]=c[k+37512>>2];c[k+37932>>2]=c[k+37944>>2];c[k+37956>>2]=c[k+37968>>2];c[k+37976>>2]=c[k+37984>>2];c[k+37992>>2]=c[k+38e3>>2];c[k+37304>>2]=I;c[k+37788>>2]=c[k+37836>>2];c[k+37852>>2]=c[k+37896>>2]}else if((q|0)==3){c[k+37504>>2]=c[k+37512>>2];c[k+37976>>2]=c[k+37972>>2];c[k+37992>>2]=c[k+37988>>2]}q=h|0;nrc(q|0,2591840,24)|0;S=h+23|0;U=c[759696]|0;if((U|0)==0){Z=S}else{o=0;p=S;S=U;while(1){U=3038768+(o*20|0)|0;if((irc(U,2444184)|0)==0){if((c[r>>2]&16|0)==0){x=65}else{_=p}}else{x=65}do{if((x|0)==65){x=0;if((irc(U,2355288)|0)==0){if((c[r>>2]&1572864|0)!=0){_=p;break}}if((irc(U,2292736)|0)==0){if((c[r>>2]&262208|0)!=262144){_=p;break}}if((irc(U,2241744)|0)==0){if((c[r>>2]&256|0)!=0){_=p;break}}D=(irc(U,2200632)|0)==0;F=c[r>>2]|0;if(D){if((F&65536|0)!=0){_=p;break}}if((S&F|0)!=(S|0)){_=p;break}if((o|0)!=0){if((S|0)==(c[3038784+((o-1|0)*20|0)>>2]|0)){_=p;break}}F=gc(p|0,2168832,(u=i,i=i+8|0,c[u>>2]=U,u)|0)|0;i=u;_=p+F|0}}while(0);U=o+1|0;F=c[3038784+(U*20|0)>>2]|0;if((F|0)==0){Z=_;break}else{o=U;p=_;S=F}}}if((c[r>>2]|0)==0){a[Z]=a[2142008]|0;a[Z+1|0]=a[2142009]|0;a[Z+2|0]=a[2142010]|0;a[Z+3|0]=a[2142011]|0;a[Z+4|0]=a[2142012]|0;a[Z+5|0]=a[2142013]|0;a[Z+6|0]=a[2142014]|0}ILb(l,2,2118504,(u=i,i=i+8|0,c[u>>2]=q,u)|0);i=u;S=aUb(l)|0;if((S|0)==0){break}p=k+632|0;o=c[p>>2]|0;I=k+636|0;t=(o|0)<51?o:51;while(1){if((t|0)>(c[I>>2]|0)){break}if((bUb(l,S,t)|0)==0){t=t+1|0}else{break a}}if((bUb(l,S,12)|0)!=0){break}NLb(S);if((b[(c[k+1864>>2]|0)+4026>>1]|0)!=24){ILb(l,0,2636384,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break}if((rrc(392)|0)!=23){ILb(l,0,2613080,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;ILb(l,0,2586288,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;ILb(l,0,2565408,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break}c[k+1480>>2]=0;$=+(ca(c[k+28>>2]<<2,c[k+32>>2]|0)|0);t=(c[n>>2]|0)==2;if(t){aa=+T(+.95,+(+(c[p>>2]|0)))}else{ba=+T(+.95,+(+(c[k+628>>2]|0)));da=+g[k+672>>2];if(da<1.0){ea=1.0}else{ea=da}aa=ba*ea}if($*aa<1.0e6){fa=1e6}else{if(t){ga=+T(+.95,+(+(c[p>>2]|0)))}else{ba=+T(+.95,+(+(c[k+628>>2]|0)));da=+g[k+672>>2];if(da<1.0){ha=1.0}else{ha=da}ga=ba*ha}fa=~~($*ga)}t=k+1492|0;c[t>>2]=fa;I=((fa*3|0|0)/2|0)+68|0;c[k+1528>>2]=I;q=MLb(I)|0;c[k+1524>>2]=q;if((q|0)==0){break}q=MLb(50496)|0;I=k+1532|0;c[I>>2]=q;if((q|0)==0){break}q=k+4|0;if((c[q>>2]|0)>1){break}r=k+8|0;if((c[r>>2]|0)>1){break}o=k+816|0;do{if((c[o>>2]|0)!=0){W=iQb()|0;c[k+38028>>2]=W;if((W|0)!=0){break}ILb(l,1,2547256,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;c[o>>2]=0}}while(0);p=k+860|0;n=p;S=p;c[S>>2]=l;p=1;while(1){if((p|0)>=(((c[E>>2]|0)!=0)+(c[q>>2]|0)|0)){break}W=MLb(50496)|0;c[n+(p<<2)>>2]=W;if((W|0)==0){break a}p=p+1|0}if((c[r>>2]|0)>1){p=k+1376|0;E=0;do{W=MLb(50496)|0;c[p+(E<<2)>>2]=W;if((W|0)==0){break a}nrc(W|0,k|0,50496)|0;E=E+1|0;}while((E|0)<(c[r>>2]|0))}nrc(c[I>>2]|0,k|0,50496)|0;if((c[q>>2]|0)>0){r=k+844|0;E=k+12|0;p=0;do{W=(c[r>>2]|0)+3|0;J=(c[E>>2]|0)==0|(p|0)==0;if((p|0)>0){nrc(c[n+(p<<2)>>2]|0,k|0,50496)|0}if(J){R=MOb(l,1)|0;Q=n+(p<<2)|0;c[(c[Q>>2]|0)+15148>>2]=R;if((c[(c[Q>>2]|0)+15148>>2]|0)==0){break a}}else{c[(c[n+(p<<2)>>2]|0)+15148>>2]=c[(c[S>>2]|0)+15148>>2]}Q=MLb(c[t>>2]|0)|0;R=n+(p<<2)|0;c[(c[R>>2]|0)+1496>>2]=Q;if((c[(c[R>>2]|0)+1496>>2]|0)==0){break a}Q=MLb(W<<5)|0;c[(c[R>>2]|0)+1488>>2]=Q;Q=c[R>>2]|0;if((c[Q+1488>>2]|0)==0){break a}c[Q+1484>>2]=W;if(J){if((ZOb(Q)|0)<0){break a}}p=p+1|0;}while((p|0)<(c[q>>2]|0))}do{if((c[o>>2]|0)!=0){if((kQb(l)|0)>=0){break}c[o>>2]=0}}while(0);if((kMb(l,A)|0)==0){ia=0}else{break}while(1){if((ia|0)>=(c[q>>2]|0)){break}if(($Ob(c[n+(ia<<2)>>2]|0,0)|0)<0){break a}else{ia=ia+1|0}}if((EMb(l)|0)<0){break}if((c[k+48>>2]|0)!=0){ILb(l,3,2529552,(u=i,i=i+8|0,c[u>>2]=c[k+8564>>2],u)|0);i=u;ILb(l,3,2514296,(u=i,i=i+8|0,c[u>>2]=c[k+8568>>2],u)|0);i=u}n=k+512|0;q=c[n>>2]|0;if((q|0)!=0){o=Qc(q|0,2500600)|0;if((o|0)==0){ILb(l,0,2487840,(u=i,i=i+8|0,c[u>>2]=c[n>>2],u)|0);i=u;break}do{if((sd(Fb(o|0)|0,f|0)|0)==0){if((c[f+12>>2]&61440|0)==32768){break}ILb(l,0,2476840,(u=i,i=i+8|0,c[u>>2]=c[n>>2],u)|0);i=u;break a}}while(0);nb(o|0)|0}n=k+8372|0;q=c[n>>2]|0;do{if((q|0)==66){ja=2467488}else{if((q|0)==77){ja=2457704;break}if((q|0)==110){ja=(c[k+8392>>2]|0)==1?2429224:2418760;break}else if((q|0)==100){ja=2440944;break}p=(c[k+8392>>2]|0)==1;if((q|0)==122){ja=p?2409784:2402024;break}else{ja=p?2395264:2388112;break}}}while(0);q=j|0;o=k+8376|0;p=c[o>>2]|0;Rb(q|0,4,2381160,(u=i,i=i+16|0,c[u>>2]=(p|0)/10|0,c[u+8>>2]=(p|0)%10|0,u)|0)|0;i=u;p=c[o>>2]|0;do{if((p|0)==11){if((c[k+8392>>2]|0)==0){x=155;break}o=c[n>>2]|0;if((o|0)==66|(o|0)==77){x=154}else{ka=o}}else if((p|0)==9){x=154}else{x=155}}while(0);if((x|0)==154){a[q]=a[2374800]|0;a[q+1|0]=a[2374801]|0;a[q+2|0]=a[2374802]|0;x=155}if((x|0)==155){ka=c[n>>2]|0}if((ka|0)<110){ILb(l,2,2367616,(u=i,i=i+16|0,c[u>>2]=ja,c[u+8>>2]=q,u)|0);i=u;la=l;i=e;return la|0}else{p=c[97832+(c[m>>2]<<2)>>2]|0;ILb(l,2,2327600,(u=i,i=i+32|0,c[u>>2]=ja,c[u+8>>2]=q,c[u+16>>2]=p,c[u+24>>2]=8,u)|0);i=u;la=l;i=e;return la|0}}}while(0);NLb(k);la=0;i=e;return la|0}function VLb(a,b){a=a|0;b=b|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0.0,Q=0,S=0,T=0,U=0,V=0.0,W=0,X=0.0,Y=0,Z=0,_=0,$=0.0,aa=0.0,ba=0.0,da=0.0,ea=0.0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0.0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0.0,Ta=0.0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0.0,jb=0,kb=0.0,lb=0,mb=0.0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0;e=i;f=a|0;h=a+160|0;j=(c[h>>2]|0)!=0;c[h>>2]=j&1;k=a+28|0;l=c[k>>2]|0;m=a+32|0;n=c[m>>2]|0;if((l|0)<1|(n|0)<1){ILb(a,0,2130896,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=n,o)|0);i=o;p=-1;i=e;return p|0}q=c[a+36>>2]&255;if((q|0)==0|q>>>0>12>>>0){ILb(a,0,2129376,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}do{if(q>>>0<8>>>0){if((l&1|0)!=0){ILb(a,0,2127920,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=n,o)|0);i=o;p=-1;i=e;return p|0}if(!(q>>>0<4>>>0)){r=12;break}if(!j){r=13;break}if((n&3|0)==0){r=13;break}ILb(a,0,2125992,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=n,o)|0);i=o;p=-1;i=e;return p|0}else{r=12}}while(0);if((r|0)==12){if(j){r=13}}do{if((r|0)==13){if((n&1|0)==0){break}ILb(a,0,2123888,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=n,o)|0);i=o;p=-1;i=e;return p|0}}while(0);j=c[a+740>>2]|0;s=c[a+748>>2]|0;t=c[a+744>>2]|0;u=c[a+752>>2]|0;do{if((s+j|0)>>>0<l>>>0){if(!((u+t|0)>>>0<n>>>0)){break}v=a+56|0;w=a+52|0;if((c[v>>2]|0)<1){r=20}else{if((c[w>>2]|0)<1){r=20}}if((r|0)==20){c[v>>2]=0;c[w>>2]=0}w=a+4|0;v=c[w>>2]|0;if((v|0)==0){x=TLb()|0;y=(ca((c[a+12>>2]|0)!=0?2:3,x)|0)/2|0;c[w>>2]=y;z=c[m>>2]|0;A=y}else{z=n;A=v}v=z+15|0;if((v|0)<64){B=1}else{B=(v|0)/64|0}do{if((A|0)>1){ILb(a,1,2114464,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[w>>2]=1;if((c[a+12>>2]|0)==0){C=1;r=30;break}v=(B|0)>1?1:B;c[w>>2]=v;D=v;r=28}else{D=A;r=28}}while(0);do{if((r|0)==28){if((D|0)>=1){C=D;r=30;break}c[w>>2]=1;r=31}}while(0);do{if((r|0)==30){v=(C|0)>128?128:C;c[w>>2]=v;if((v|0)==1){r=31;break}y=a+12|0;x=a+1548|0;if((c[a+12>>2]|0)!=0){c[x>>2]=1;E=x;F=y;break}c[x>>2]=v;if((v|0)<=1){E=x;F=y;break}c[a+856>>2]=0;E=x;F=y}}while(0);if((r|0)==31){c[a+12>>2]=0;c[a+8>>2]=1;y=a+1548|0;c[y>>2]=1;E=y;F=a+12|0}y=a+816|0;do{if((c[y>>2]|0)!=0){if((c[k>>2]|0)<32){r=39}else{if((c[m>>2]|0)<32){r=39}}if((r|0)==39){ILb(a,1,2112736,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[y>>2]=0}if((c[a+824>>2]|0)==0){break}x=a+820|0;if((c[x>>2]|0)==0){break}ILb(a,1,2110768,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[x>>2]=0}}while(0);x=a+96|0;v=c[x>>2]|0;if((v|0)<1){c[x>>2]=1;r=46}else{G=(v|0)>1073741824?1073741824:v;c[x>>2]=G;if((G|0)==1){r=46}else{H=G}}if((r|0)==46){c[a+108>>2]=0;c[a+528>>2]=0;c[a+88>>2]=1;c[a+92>>2]=1;H=1}G=a+756|0;v=c[G>>2]|0;if((v|0)<-1){I=-1}else{I=(v|0)>5?5:v}c[G>>2]=I;G=(b|0)!=0;do{if(G){v=((c[a+640>>2]|0)==3)+((c[a+548>>2]|0)==0)+((H|0)==12)+((c[a+632>>2]|0)==2)+((c[a+636>>2]|0)==31)+(+g[a+716>>2]==.5)+(+R(+(+g[a+672>>2]+ -1.25))<.01)|0;J=v+(+R(+(+g[a+676>>2]+ -1.25))<.01)|0;if((c[a+520>>2]|0)==0){K=(c[a+560>>2]|0)==8|0}else{K=0}if((J+K|0)<=4){break}ILb(a,0,2109264,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ILb(a,0,2107656,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ILb(a,0,2106376,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ILb(a,0,2104832,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ILb(a,0,2644104,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);J=a+624|0;v=c[J>>2]|0;if(v>>>0>2>>>0){ILb(a,0,2641328,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}if((c[h>>2]|0)!=0){c[a+804>>2]=1}L=a+136|0;if((c[L>>2]|0)!=0){ILb(a,0,2635224,(o=i,i=i+8|0,c[o>>2]=8,o)|0);i=o;ILb(a,0,2632544,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}M=a+648|0;N=+g[M>>2];if(N<0.0){O=0.0}else{O=N>51.0?51.0:N}g[M>>2]=O;M=a+652|0;N=+g[M>>2];if(N<0.0){P=0.0}else{P=N>51.0?51.0:N}g[M>>2]=P;M=a+628|0;Q=c[M>>2]|0;if((Q|0)<0){S=0}else{S=(Q|0)>69?69:Q}c[M>>2]=S;Q=a+560|0;T=c[Q>>2]|0;if((T|0)<0){U=0}else{U=(T|0)>11?11:T}c[Q>>2]=U;T=a+672|0;N=+g[T>>2];V=N>.009999999776482582?N:.009999999776482582;g[T>>2]=V;W=a+676|0;N=+g[W>>2];X=N>.009999999776482582?N:.009999999776482582;g[W>>2]=X;if((v|0)==1){Y=~~(O+0.0);c[M>>2]=Y;c[a+644>>2]=0;Z=Y}else{Z=S}do{if(G){if(!(v>>>0<2>>>0)){_=v;break}if((Z|0)!=0){r=75;break}c[a+28836>>2]=1;c[a+168>>2]=0;c[a+172>>2]=0;c[J>>2]=0;g[T>>2]=1.0;g[W>>2]=1.0;c[a+616>>2]=0;c[a+620>>2]=0;c[a+540>>2]=0;c[a+572>>2]=0;c[a+576>>2]=0;c[a+584>>2]=0;c[a+596>>2]=0;c[a+112>>2]=0;if(!((c[a+152>>2]|0)==0&(U|0)<6)){$=1.0;aa=1.0;r=76;break}c[a+524>>2]=0;$=1.0;aa=1.0;r=76}else{r=75}}while(0);if((r|0)==75){if((v|0)==0){$=X;aa=V;r=76}else{_=v}}if((r|0)==76){N=+(Z|0);ba=N- +lc(+aa)*6.0;da=N+ +lc(+$)*6.0;ea=ba<da?ba:da;W=~~(N<ea?N:ea);if((W|0)<0){fa=0}else{fa=(W|0)>69?69:W}c[a+632>>2]=fa;ea=ba>da?ba:da;W=~~((N>ea?N:ea)+.999);if((W|0)<0){ga=0}else{ga=(W|0)>69?69:W}c[a+636>>2]=ga;c[a+684>>2]=0;c[a+692>>2]=0;c[a+644>>2]=0;_=0}W=a+636|0;T=c[W>>2]|0;if((T|0)<0){ha=0}else{ha=(T|0)>69?69:T}c[W>>2]=ha;W=a+632|0;T=c[W>>2]|0;if((T|0)<0){ia=0}else{ia=(T|0)>(ha|0)?ha:T}c[W>>2]=ia;W=a+640|0;T=c[W>>2]|0;if((T|0)<2){ja=2}else{ja=(T|0)>69?69:T}c[W>>2]=ja;W=a+644|0;T=c[W>>2]|0;if((T|0)<0){ka=0}else{ka=(T|0)>2e6?2e6:T}c[W>>2]=ka;T=(_|0)==2;if(T&(ka|0)==0){ILb(a,0,2630464,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}Y=a+664|0;M=c[Y>>2]|0;if((M|0)<0){la=0}else{la=(M|0)>2e6?2e6:M}c[Y>>2]=la;M=a+660|0;ma=c[M>>2]|0;if((ma|0)<0){na=0}else{na=(ma|0)>2e6?2e6:ma}c[M>>2]=na;ma=a+668|0;ea=+g[ma>>2];if(ea<0.0){oa=0.0}else{oa=ea>2.0e6?2.0e6:ea}g[ma>>2]=oa;do{if((la|0)==0){if((na|0)==0){break}ILb(a,1,2622928,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[M>>2]=0}else{if((_|0)==0){ILb(a,1,2628480,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[M>>2]=0;c[Y>>2]=0;break}if((na|0)!=0){if(!((na|0)<(ka|0)&T)){break}ILb(a,1,2624424,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[W>>2]=c[M>>2];break}if(T){ILb(a,1,2627088,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[M>>2]=c[W>>2];break}else{ILb(a,1,2625592,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[Y>>2]=0;break}}}while(0);T=a+832|0;v=c[T>>2]|0;ma=(v|0)>0?v:0;c[T>>2]=ma;v=a+836|0;pa=c[v>>2]|0;qa=(pa|0)>0?pa:0;c[v>>2]=qa;pa=a+840|0;ra=c[pa>>2]|0;sa=(ra|0)>0?ra:0;c[pa>>2]=sa;do{if((qa|0)==0){if((ma|0)!=0){ta=sa;break}c[pa>>2]=0;ta=0}else{ra=(qa|0)/2|0;ua=(sa|0)<(ra|0)?sa:ra;c[pa>>2]=ua;ta=ua}}while(0);do{if((c[h>>2]|0)==0){va=ta}else{if((ta|0)==0){va=0;break}ILb(a,1,2621368,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[pa>>2]=0;va=0}}while(0);sa=((c[k>>2]|0)+15|0)/16|0;if((va|0)>(sa|0)){ILb(a,1,2618680,(o=i,i=i+8|0,c[o>>2]=sa,o)|0);i=o;c[pa>>2]=sa}sa=16<<c[h>>2];qa=((c[m>>2]|0)-1+sa|0)/(sa|0)|0;do{if((c[F>>2]|0)==0){sa=a+844|0;ma=c[sa>>2]|0;if((ma|0)<0){wa=0}else{wa=(ma|0)>(qa|0)?qa:ma}c[sa>>2]=wa;if((c[v>>2]|0)==0){if((c[T>>2]|0)==0){xa=wa;break}}c[sa>>2]=0;xa=0}else{sa=c[w>>2]|0;if((sa|0)<0){ya=0}else{ya=(sa|0)>(qa|0)?qa:sa}c[a+844>>2]=ya;xa=ya}}while(0);qa=a+848|0;pa=c[qa>>2]|0;if((pa|0)>0){c[qa>>2]=(xa|0)>(pa|0)?xa:pa}pa=a+132|0;do{if((c[pa>>2]|0)==0){za=c[a+88>>2]|0}else{qa=a+124|0;sa=c[qa>>2]|0;c[qa>>2]=(sa|0)>1?1:sa;sa=a+112|0;qa=c[sa>>2]|0;c[sa>>2]=(qa|0)<3?qa:3;c[a+760>>2]=1;qa=a+48|0;sa=c[qa>>2]|0;c[qa>>2]=(sa|0)>1?sa:1;c[T>>2]=0;c[v>>2]=0;c[a+108>>2]=0;sa=a+88|0;qa=c[sa>>2]|0;ma=(qa|0)<6?qa:6;c[sa>>2]=ma;sa=a+92|0;qa=c[sa>>2]|0;c[sa>>2]=(qa|0)<6?qa:6;c[a+100>>2]=1;qa=a+528|0;sa=c[qa>>2]|0;c[qa>>2]=(sa|0)<1?sa:1;if((c[a+808>>2]|0)==0){za=ma;break}c[a+804>>2]=1;za=ma}}while(0);v=a+88|0;if((za|0)<1){Aa=1}else{Aa=(za|0)>16?16:za}c[v>>2]=Aa;T=a+92|0;ma=c[T>>2]|0;if((ma|0)<1){Ba=1}else{Ba=(ma|0)>16?16:ma}c[T>>2]=Ba;ma=a+104|0;if((c[ma>>2]|0)<0){c[ma>>2]=0}ma=a+536|0;sa=c[ma>>2]|0;do{if((sa|0)<0){c[ma>>2]=0}else{qa=(sa|0)>3?3:sa;c[ma>>2]=qa;if(!((c[Q>>2]|0)==0&(qa|0)>1)){break}ILb(a,1,2611816,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[ma>>2]=1}}while(0);sa=a+112|0;qa=c[sa>>2]|0;ua=(c[x>>2]|0)-1|0;ra=(ua|0)>16?16:ua;if((qa|0)<0){Ca=0}else{Ca=(qa|0)>(ra|0)?ra:qa}c[sa>>2]=Ca;qa=a+120|0;ra=c[qa>>2]|0;if((ra|0)<-90){Da=-90}else{Da=(ra|0)>100?100:ra}c[qa>>2]=Da;qa=a+124|0;if((Ca|0)<2){c[qa>>2]=0;Ea=0;Fa=a+124|0;r=149}else{ra=c[qa>>2]|0;qa=a+124|0;if((ra|0)<0){Ga=0;Ha=qa}else{Ea=ra;Fa=qa;r=149}}if((r|0)==149){Ga=(Ea|0)>2?2:Ea;Ha=Fa}c[Ha>>2]=Ga;qa=a+116|0;ra=c[qa>>2]|0;if((ra|0)<0){Ia=0}else{Ia=(ra|0)>2?2:ra}c[qa>>2]=Ia;if((Ca|0)==0){c[qa>>2]=0;c[ma>>2]=0;c[a+532>>2]=0;c[a+128>>2]=0}ra=a+108|0;ua=c[ra>>2]|0;do{if((ua|0)!=0){if((Ga|0)==2){ILb(a,1,2608736,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[Ha>>2]=1;Ja=c[ra>>2]|0;if((Ja|0)==0){break}else{Ka=Ja}}else{Ka=ua}if((c[v>>2]|0)>1){r=159}else{if((c[T>>2]|0)>1){r=159}else{La=Ka}}if((r|0)==159){ILb(a,1,2605848,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[v>>2]=1;c[T>>2]=1;La=c[ra>>2]|0}if((La|0)==0){break}Ja=a+128|0;if((c[Ja>>2]|0)==0){break}ILb(a,1,2603608,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[Ja>>2]=0}}while(0);T=a+784|0;ua=c[T>>2]|0;ma=a+788|0;if((ua|0)==0){r=165}else{Ja=c[ma>>2]|0;if((Ja|0)==0){r=165}else{Ma=ua;Na=Ja}}if((r|0)==165){c[T>>2]=25;c[ma>>2]=1;Ma=25;Na=1}V=+(Ma>>>0>>>0)/+(Na>>>0>>>0);ma=a+100|0;T=c[ma>>2]|0;Ja=c[x>>2]|0;if((T|0)==0){X=+((Ja|0)/10|0|0);ua=~~(X<V?X:V);c[ma>>2]=ua;Oa=ua}else{Oa=T}T=((Ja|0)/2|0)+1|0;if((Oa|0)<1){Pa=1}else{Pa=(Oa|0)>(T|0)?T:Oa}c[ma>>2]=Pa;ma=a+696|0;T=c[ma>>2]|0;if((T|0)<0){Qa=0}else{Qa=(T|0)>250?250:T}c[ma>>2]=Qa;T=c[M>>2]|0;ua=c[W>>2]|0;Ra=(T|0)>(ua|0)?T:ua;if((Ra|0)==0){Sa=0.0}else{Sa=+(c[Y>>2]|0)/+(Ra|0)}X=+(Qa|0);ea=+(Ja|0);N=V*Sa;V=ea>N?ea:N;Ra=~~(X<V?X:V);c[ma>>2]=Ra;ua=a+792|0;T=a+796|0;do{if((c[ua>>2]|0)==0){r=178}else{if((c[T>>2]|0)==0){r=178;break}if((c[a+776>>2]|0)!=0){break}if((c[a+780>>2]|0)==0){r=178}}}while(0);if((r|0)==178){c[ua>>2]=Na;c[T>>2]=Ma}x=a+716|0;V=+g[x>>2];if(V<0.0){Ta=0.0}else{Ta=V>1.0?1.0:V}g[x>>2]=Ta;if((Ja|0)==1|Ta==1.0){c[a+692>>2]=0}do{if((Ja|0)!=1073741824&(c[ra>>2]|0)==0&(Ra|0)==0){x=a+692|0;if((c[x>>2]|0)==0){break}ILb(a,1,2601672,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[x>>2]=0}}while(0);do{if(G){if((c[a+708>>2]|0)==0){break}c[ma>>2]=0}}while(0);c[a+24>>2]=0;ma=a+144|0;Ra=c[ma>>2]|0;if((Ra|0)<-6){Ua=-6}else{Ua=(Ra|0)>6?6:Ra}c[ma>>2]=Ua;ma=a+148|0;Ra=c[ma>>2]|0;if((Ra|0)<-6){Va=-6}else{Va=(Ra|0)>6?6:Ra}c[ma>>2]=Va;ma=a+608|0;Ra=c[ma>>2]|0;if((Ra|0)<0){Wa=0}else{Wa=(Ra|0)>32?32:Ra}c[ma>>2]=Wa;ma=a+612|0;Ra=c[ma>>2]|0;if((Ra|0)<0){Xa=0}else{Xa=(Ra|0)>32?32:Ra}c[ma>>2]=Xa;ma=a+156|0;Ra=c[ma>>2]|0;if((Ra|0)<0){Ya=0}else{Ya=(Ra|0)>2?2:Ra}c[ma>>2]=Ya;ma=a+168|0;if((c[ma>>2]|0)>>>0>2>>>0){c[ma>>2]=0}ma=a+544|0;Ra=c[ma>>2]|0;if(Ra>>>0>4>>>0){c[ma>>2]=1;Za=1}else{Za=Ra}Ra=a+548|0;Ja=c[Ra>>2]|0;do{if((Ja|0)<4){c[Ra>>2]=4}else{T=(Ja|0)>1024?1024:Ja;c[Ra>>2]=T;if(!((T|0)>16&(Za|0)<2)){break}c[Ra>>2]=16}}while(0);do{if((Za|0)==4){if((c[a+28836>>2]|0)==0){if((c[Q>>2]|0)>=2){break}}c[ma>>2]=3}}while(0);Ja=a+568|0;if((c[Ja>>2]|0)==0){_a=0}else{_a=(c[v>>2]|0)>1|0}c[Ja>>2]=_a;T=a+520|0;ua=c[T>>2]|0;x=ua&307;c[T>>2]=x;$a=a+516|0;ab=c[$a>>2]|0;c[$a>>2]=ab&3;if((ua&16|0)==0){bb=ua&275;c[T>>2]=bb;cb=bb}else{cb=x}x=a+524|0;if((c[x>>2]|0)==0){c[T>>2]=cb&305;c[$a>>2]=ab&1}ab=a+572|0;$a=c[ab>>2]|0;if(($a|0)<0){db=0}else{db=($a|0)>2?2:$a}c[ab>>2]=db;$a=a+684|0;T=c[$a>>2]|0;if((T|0)<0){eb=0}else{eb=(T|0)>2?2:T}c[$a>>2]=eb;T=a+688|0;V=+g[T>>2];if(V<0.0){g[T>>2]=0.0;r=224}else{X=V>3.0?3.0:V;g[T>>2]=X;if(X==0.0){r=224}else{fb=eb}}if((r|0)==224){c[$a>>2]=0;fb=0}if((c[a+504>>2]|0)<2){c[a+616>>2]=0;c[a+620>>2]=0}a:do{if(G){bb=c[a+616>>2]|0;ua=(bb|0)==0;if(ua){if((c[a+620>>2]|0)==0){break}}do{if((c[a+596>>2]|0)==0){if((fb|0)==0){if((c[a+620>>2]|0)==0){break a}ILb(a,1,2593872,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;gb=2598392;break}else{if(ua){break a}ILb(a,1,2591304,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;gb=2599920;break}}else{hb=(bb|0)!=0?2599920:2598392;ILb(a,1,2595736,(o=i,i=i+8|0,c[o>>2]=hb,o)|0);i=o;gb=hb}}while(0);ILb(a,1,2585192,(o=i,i=i+16|0,c[o>>2]=gb,c[o+8>>2]=gb,o)|0);i=o}}while(0);v=a+596|0;bb=(c[v>>2]|0)==0;ua=a+588|0;if(bb){g[ua>>2]=0.0;g[a+592>>2]=0.0;ib=0.0;jb=a+588|0;r=241}else{X=+g[ua>>2];ua=a+588|0;if(X<0.0){kb=0.0;lb=ua}else{ib=X;jb=ua;r=241}}if((r|0)==241){kb=ib>10.0?10.0:ib;lb=jb}g[lb>>2]=kb;ua=a+592|0;X=+g[ua>>2];if(X<0.0){mb=0.0}else{mb=X>10.0?10.0:X}g[ua>>2]=mb;ua=c[Q>>2]|0;if((ua|0)>5){nb=~~(kb*256.0+.5)}else{nb=0}c[a+18652>>2]=nb;hb=c[ab>>2]|0;if((hb|0)==0){ob=0}else{ob=~~(mb*.25*256.0+.5)}c[a+18656>>2]=ob;pb=a+540|0;qb=c[pb>>2]|0;if((qb|0)<-32){rb=-32}else{rb=(qb|0)>32?32:qb}c[pb>>2]=rb;do{if(G){if((q-8|0)>>>0>1>>>0|bb){sb=rb}else{qb=rb+6|0;c[pb>>2]=qb;sb=qb}do{if((nb|0)==0){tb=sb}else{if((c[L>>2]|0)!=0){tb=sb;break}qb=sb-(kb<.25?1:2)|0;c[pb>>2]=qb;tb=qb}}while(0);if((ob|0)==0){ub=tb;break}if((c[L>>2]|0)!=0){ub=tb;break}qb=tb-(mb<.25?1:2)|0;c[pb>>2]=qb;ub=qb}else{ub=rb}}while(0);if((ub|0)<-12){vb=-12}else{vb=(ub|0)>12?12:ub}c[pb>>2]=vb;L=c[$a>>2]|0;do{if((L|0)==0){if((c[a+692>>2]|0)==0){wb=0;break}c[$a>>2]=1;g[T>>2]=0.0;wb=1}else{wb=L}}while(0);L=a+584|0;T=c[L>>2]|0;if((T|0)<0){xb=0}else{xb=(T|0)>65536?65536:T}c[L>>2]=xb;do{if((ua|0)>9){if(!((hb|0)!=2|(wb|0)==0)){break}c[Q>>2]=9}}while(0);hb=a+40|0;ua=c[hb>>2]|0;b:do{if((ua|0)<0){L=c[M>>2]|0;do{if((c[J>>2]|0)==2){if((c[Y>>2]|0)>=1){break}c[M>>2]=c[W>>2]<<1}}while(0);YMb(a+8368|0,c[a+772>>2]|0,f);T=96192;while(1){c[hb>>2]=c[T>>2];$a=T+52|0;if((c[$a>>2]|0)==0){yb=T;break}if((kNb(a,0)|0)==0){yb=T;break}if((T|0)==0){yb=$a;break}else{T=$a}}c[M>>2]=L;zb=yb}else{T=96192;while(1){$a=c[T>>2]|0;if(($a|0)==0){break}if(($a|0)==(ua|0)){zb=T;break b}else{T=T+52|0}}ILb(a,0,2582056,(o=i,i=i+8|0,c[o>>2]=ua,o)|0);i=o;p=-1;i=e;return p|0}}while(0);ua=a+552|0;hb=c[ua>>2]|0;do{if((hb|0)<1){J=c[h>>2]|0;Ab=c[zb+24>>2]>>J;Bb=J}else{J=c[h>>2]|0;T=512>>>(J>>>0);if((hb|0)<32){Ab=32;Bb=J;break}Ab=(hb|0)>(T|0)?T:hb;Bb=J}}while(0);c[ua>>2]=Ab;hb=a+528|0;J=c[hb>>2]|0;if((J|0)<0){Cb=0}else{Cb=(J|0)>2?2:J}c[hb>>2]=Cb;J=a+8|0;T=c[J>>2]|0;do{if((T|0)==0){if((c[F>>2]|0)!=0){L=c[w>>2]|0;c[J>>2]=L;Db=L;break}L=c[Q>>2]|0;if((L|0)<9){Eb=(L|0)/3|0}else{Eb=3}$a=(c[sa>>2]|0)-1|0;if(($a|0)<9){Fb=($a|0)/3|0}else{Fb=3}$a=(c[w>>2]|0)/(d[16168+(((c[qa>>2]|0)==2|0)*20|0)+(((L|0)>1)+Eb<<2)+Fb|0]|0|0)|0;L=(c[m>>2]|0)/128|0;pb=($a|0)<(L|0)?$a:L;c[J>>2]=pb;Db=pb}else{Db=T}}while(0);T=(B|0)<16?B:16;if((Db|0)<1){Gb=1}else{Gb=(Db|0)>(T|0)?T:Db}c[J>>2]=Gb;do{if((Bb|0)==0){Hb=Cb;r=302}else{if((c[ma>>2]|0)>2){ILb(a,1,2580184,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[ma>>2]=2;Ib=c[hb>>2]|0}else{Ib=Cb}if((Ib|0)<=0){Hb=Ib;r=302;break}ILb(a,1,2577864,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[hb>>2]=0;r=303}}while(0);if((r|0)==302){if((Hb|0)==0){r=303}}do{if((r|0)==303){if((c[a+692>>2]|0)==0){break}if((c[v>>2]|0)==0){break}c[hb>>2]=-1}}while(0);hb=c[E>>2]|0;if((hb|0)>1){ma=a+556|0;J=c[ma>>2]|0;if((J|0)<1){Jb=((((c[m>>2]|0)+24|0)/(hb|0)|0)-24|0)/2|0}else{Jb=J}J=c[Ra>>2]|0;hb=(Jb|0)>(J|0)?Jb:J;J=c[ua>>2]|0;T=(hb|0)<(J|0)?hb:J;J=T&-16|8;hb=(J|0)<(T|0)?J+16|0:J;ILb(a,3,2576472,(o=i,i=i+8|0,c[o>>2]=hb,o)|0);i=o;c[ma>>2]=hb}hb=a+656|0;if(+g[hb>>2]<0.0){g[hb>>2]=0.0}hb=a+720|0;if(+g[hb>>2]<0.0){g[hb>>2]=0.0}hb=a+724|0;if(+g[hb>>2]<0.0){g[hb>>2]=0.0}hb=a+772|0;c[hb>>2]=c[hb>>2]&31;hb=a+48|0;ma=c[hb>>2]|0;do{if((ma|0)<0){c[hb>>2]=0}else{J=(ma|0)>2?2:ma;c[hb>>2]=J;if((J|0)==0){break}if((c[Y>>2]|0)==0){ILb(a,1,2575128,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[hb>>2]=0;break}if((J|0)!=2){break}J=c[M>>2]|0;if((c[W>>2]|0)!=(J|0)|(J|0)==0){ILb(a,1,2573816,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[hb>>2]=1;break}else{c[a+680>>2]=1;break}}}while(0);hb=a+152|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+164|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+140|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+16|0;c[hb>>2]=(c[hb>>2]|0)!=0;c[F>>2]=(c[F>>2]|0)!=0;c[h>>2]=(c[h>>2]|0)!=0;c[ra>>2]=(c[ra>>2]|0)!=0;hb=a+760|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+764|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+768|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+776|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+780|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+800|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+804|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+808|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+128|0;c[hb>>2]=(c[hb>>2]|0)!=0;c[pa>>2]=(c[pa>>2]|0)!=0;hb=a+812|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+508|0;c[hb>>2]=(c[hb>>2]|0)!=0;c[y>>2]=(c[y>>2]|0)!=0;c[x>>2]=(c[x>>2]|0)!=0;hb=a+532|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+564|0;c[hb>>2]=(c[hb>>2]|0)!=0;c[Ja>>2]=(c[Ja>>2]|0)!=0;hb=a+576|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+580|0;c[hb>>2]=(c[hb>>2]|0)!=0;c[v>>2]=(c[v>>2]|0)!=0;hb=a+616|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+620|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+700|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+708|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+692|0;c[hb>>2]=(c[hb>>2]|0)!=0;hb=a+680|0;c[hb>>2]=(c[hb>>2]|0)!=0;p=0;i=e;return p|0}}while(0);ILb(a,0,2117448,(o=i,i=i+32|0,c[o>>2]=j,c[o+8>>2]=t,c[o+16>>2]=s,c[o+24>>2]=u,o)|0);i=o;p=-1;i=e;return p|0}function WLb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=c[b+56>>2]|0;if((h|0)<=0){i=e;return}j=c[b+52>>2]|0;if((j|0)<=0){i=e;return}c[f>>2]=h;c[g>>2]=j;j=a+56|0;h=c[j>>2]|0;b=a+52|0;k=c[b>>2]|0;OLb(f,g);l=c[f>>2]|0;while(1){m=c[g>>2]|0;if(!(l>>>0>65535>>>0|m>>>0>65535>>>0)){break}n=l>>>1;c[f>>2]=n;c[g>>2]=m>>>1;l=n}OLb(f,g);l=c[f>>2]|0;do{if((l|0)==(h|0)){if(!((c[g>>2]|0)==(k|0)&(d|0)==0)){break}i=e;return}}while(0);c[j>>2]=0;c[b>>2]=0;do{if((l|0)!=0){k=c[g>>2]|0;if((k|0)==0){break}ILb(a,(d|0)!=0?2:3,2132416,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=k,o)|0);i=o;c[j>>2]=c[f>>2];c[b>>2]=c[g>>2];i=e;return}}while(0);ILb(a,1,2134264,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;i=e;return}function XLb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=YLb(a,b,e)|0;b=(c[a+28836>>2]|0)==0;if(b){g=(c[a+560>>2]|0)>1}else{g=0}h=a+36808|0;nrc(a+36884|0,(g?h:a+37036|0)|0,32)|0;j=a+36744|0;nrc(a+36916|0,(g?h:j)|0,32)|0;c[a+37280>>2]=c[(g?a+37284|0:a+37288|0)>>2];c[a+37316>>2]=c[(g?a+37320|0:a+37324|0)>>2];c[a+37328>>2]=c[(g?a+37332|0:a+37336|0)>>2];c[a+37340>>2]=c[(g?a+37344|0:a+37348|0)>>2];c[a+37292>>2]=c[(g?a+37296|0:a+37300|0)>>2];do{if((c[a+20>>2]|0)==0){do{if(b){if(g){c[a+37352>>2]=c[a+37356>>2];break}else{k=c[a+37360>>2]|0;l=8;break}}else{k=0;l=8}}while(0);if((l|0)==8){c[a+37352>>2]=k}if(!b){m=0;break}if(g){m=c[a+37368>>2]|0;break}else{m=c[a+37372>>2]|0;break}}else{c[a+37352>>2]=0;m=0}}while(0);c[a+37364>>2]=m;m=g&(c[a+544>>2]|0)==4;nrc(a+36948|0,(m?h:j)|0,32)|0;j=a+36980|0;h=m?a+37196|0:a+37140|0;c[j>>2]=c[h>>2];c[j+4>>2]=c[h+4>>2];c[j+8>>2]=c[h+8>>2];c[j+12>>2]=c[h+12>>2];c[j+16>>2]=c[h+16>>2];c[j+20>>2]=c[h+20>>2];c[j+24>>2]=c[h+24>>2];h=a+37008|0;j=m?a+37224|0:a+37168|0;c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];c[h+16>>2]=c[j+16>>2];c[h+20>>2]=c[j+20>>2];c[h+24>>2]=c[j+24>>2];if((f|0)!=0){i=d;return f|0}YMb(a+8368|0,c[a+772>>2]|0,a|0);if((c[e>>2]|0)==0){i=d;return f|0}DMb(a,0);i=d;return f|0}function YLb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0.0;c[d>>2]=0;WLb(a,b,0);c[a+88>>2]=c[b+88>>2];c[a+120>>2]=c[b+120>>2];e=a+104|0;if((c[e>>2]|0)!=0){c[e>>2]=c[b+104>>2]}c[a+140>>2]=c[b+140>>2];c[a+144>>2]=c[b+144>>2];c[a+148>>2]=c[b+148>>2];c[a+756>>2]=c[b+756>>2];e=c[b+520>>2]|0;f=a+520|0;c[f>>2]=e;c[a+516>>2]=c[b+516>>2];c[a+536>>2]=c[b+536>>2];h=a+544|0;i=c[h>>2]|0;j=c[b+548>>2]|0;k=a+548|0;if((i|0)<3){l=5}else{if((j|0)<(c[k>>2]|0)){l=5}}if((l|0)==5){c[k>>2]=j}c[a+584>>2]=c[b+584>>2];j=a+560|0;if((c[j>>2]|0)!=0){c[j>>2]=c[b+560>>2]}c[a+572>>2]=c[b+572>>2];c[a+564>>2]=c[b+564>>2];c[a+580>>2]=c[b+580>>2];c[a+576>>2]=c[b+576>>2];c[a+568>>2]=c[b+568>>2];g[a+588>>2]=+g[b+588>>2];g[a+592>>2]=+g[b+592>>2];j=a+740|0;k=b+740|0;c[j>>2]=c[k>>2];c[j+4>>2]=c[k+4>>2];c[j+8>>2]=c[k+8>>2];c[j+12>>2]=c[k+12>>2];k=c[b+544>>2]|0;if((i|0)>2|(k|0)<3){c[h>>2]=k;m=k}else{m=i}do{if((m|0)>2){if((c[a+15140>>2]|0)!=0){break}c[f>>2]=e&-33}}while(0);if((c[a+8696>>2]|0)!=0){c[a+524>>2]=c[b+524>>2]}if((c[a+15072>>2]|0)>1){c[a+124>>2]=c[b+124>>2]}c[a+832>>2]=c[b+832>>2];c[a+836>>2]=c[b+836>>2];c[a+840>>2]=c[b+840>>2];c[a+844>>2]=c[b+844>>2];c[a+848>>2]=c[b+848>>2];c[a+800>>2]=c[b+800>>2];e=a+660|0;f=c[e>>2]|0;do{if((f|0)>0){m=a+664|0;if((c[m>>2]|0)<=0){break}i=b+660|0;k=c[i>>2]|0;if((k|0)<=0){break}h=b+664|0;if((c[h>>2]|0)<=0){break}j=c[d>>2]|(f|0)!=(k|0);c[d>>2]=j;k=(c[m>>2]|0)!=(c[h>>2]|0)|j;c[d>>2]=k;j=a+644|0;l=b+644|0;c[d>>2]=(c[j>>2]|0)!=(c[l>>2]|0)|k;c[e>>2]=c[i>>2];c[m>>2]=c[h>>2];c[j>>2]=c[l>>2]}}while(0);e=a+648|0;n=+g[b+648>>2];f=a+652|0;l=b+652|0;c[d>>2]=+g[f>>2]!=+g[l>>2]|(+g[e>>2]!=n|c[d>>2]);g[e>>2]=n;g[f>>2]=+g[l>>2];return VLb(a,0)|0}function ZLb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+872|0;e=c[a+860+(c[(c[a+860>>2]|0)+1444>>2]<<2)>>2]|0;a=e+1532|0;f=d|0;g=c[a>>2]|0;nrc(f|0,g|0,860)|0;nrc(g|0,e|0,860)|0;g=YLb(c[a>>2]|0,b,d+864|0)|0;if((g|0)==0){c[e+1536>>2]=1;i=d;return g|0}else{nrc(c[a>>2]|0,f|0,860)|0;i=d;return g|0}return 0}function _Lb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=a+1480|0;c[e>>2]=0;f=a+1500|0;g=a+1496|0;h=c[g>>2]|0;i=c[a+1492>>2]|0;j=h&3;k=h+(-j|0)|0;c[f>>2]=k;l=a+1504|0;c[l>>2]=k;c[a+1508>>2]=h+i;i=4-j<<3;j=a+1516|0;c[j>>2]=i;c[a+1512>>2]=(je(c[k>>2]|0)|0)>>>(i>>>0);i=a+1488|0;k=c[i>>2]|0;c[k>>2]=3;c[k+4>>2]=7;c[k+8>>2]=1;c[k+20>>2]=0;m=a+1500|0;c[k+24>>2]=h+((32-(c[j>>2]|0)|0)/8|0);c[k+28>>2]=0;k=a+8368|0;ZMb(f,k);h=c[e>>2]|0;n=c[i>>2]|0;o=(c[g>>2]|0)+((32-(c[j>>2]|0)+((c[l>>2]|0)-(c[m>>2]|0)<<3)|0)/8|0)|0;c[n+(h<<5)+20>>2]=o-(c[n+(h<<5)+24>>2]|0);mrc(o|0,-1|0,64)|0;o=a+856|0;p=c[o>>2]|0;if((p|0)!=0){ef[p&4095](a,n+(h<<5)|0,c[(c[a+15144>>2]|0)+12008>>2]|0)}h=(c[e>>2]|0)+1|0;c[e>>2]=h;n=a+1484|0;p=c[n>>2]|0;do{if((h|0)<(p|0)){q=h;r=c[i>>2]|0}else{s=MLb(p<<6)|0;if((s|0)==0){t=-1;return t|0}else{u=s;nrc(s|0,c[i>>2]|0,c[n>>2]<<5)|0;NLb(c[i>>2]|0);c[i>>2]=u;c[n>>2]=c[n>>2]<<1;q=c[e>>2]|0;r=u;break}}}while(0);c[r+(q<<5)>>2]=3;c[r+(q<<5)+4>>2]=8;c[r+(q<<5)+8>>2]=1;c[r+(q<<5)+20>>2]=0;c[r+(q<<5)+24>>2]=(c[g>>2]|0)+((32-(c[j>>2]|0)+((c[l>>2]|0)-(c[m>>2]|0)<<3)|0)/8|0);c[r+(q<<5)+28>>2]=0;$Mb(f,k,a+8636|0);k=c[e>>2]|0;q=c[i>>2]|0;r=(c[g>>2]|0)+((32-(c[j>>2]|0)+((c[l>>2]|0)-(c[m>>2]|0)<<3)|0)/8|0)|0;c[q+(k<<5)+20>>2]=r-(c[q+(k<<5)+24>>2]|0);mrc(r|0,-1|0,64)|0;r=c[o>>2]|0;if((r|0)!=0){ef[r&4095](a,q+(k<<5)|0,c[(c[a+15144>>2]|0)+12008>>2]|0)}k=(c[e>>2]|0)+1|0;c[e>>2]=k;q=c[n>>2]|0;do{if((k|0)<(q|0)){v=k;w=c[i>>2]|0}else{r=MLb(q<<6)|0;if((r|0)==0){t=-1;return t|0}else{p=r;nrc(r|0,c[i>>2]|0,c[n>>2]<<5)|0;NLb(c[i>>2]|0);c[i>>2]=p;c[n>>2]=c[n>>2]<<1;v=c[e>>2]|0;w=p;break}}}while(0);c[w+(v<<5)>>2]=0;c[w+(v<<5)+4>>2]=6;c[w+(v<<5)+8>>2]=1;c[w+(v<<5)+20>>2]=0;c[w+(v<<5)+24>>2]=(c[g>>2]|0)+((32-(c[j>>2]|0)+((c[l>>2]|0)-(c[m>>2]|0)<<3)|0)/8|0);c[w+(v<<5)+28>>2]=0;if((cNb(a,f)|0)!=0){t=-1;return t|0}f=c[e>>2]|0;v=c[i>>2]|0;w=(c[g>>2]|0)+((32-(c[j>>2]|0)+((c[l>>2]|0)-(c[m>>2]|0)<<3)|0)/8|0)|0;c[v+(f<<5)+20>>2]=w-(c[v+(f<<5)+24>>2]|0);mrc(w|0,-1|0,64)|0;w=c[o>>2]|0;if((w|0)!=0){ef[w&4095](a,v+(f<<5)|0,c[(c[a+15144>>2]|0)+12008>>2]|0)}f=(c[e>>2]|0)+1|0;c[e>>2]=f;v=c[n>>2]|0;do{if((f|0)>=(v|0)){w=MLb(v<<6)|0;if((w|0)==0){t=-1;return t|0}else{nrc(w|0,c[i>>2]|0,c[n>>2]<<5)|0;NLb(c[i>>2]|0);c[i>>2]=w;c[n>>2]=c[n>>2]<<1;break}}}while(0);n=$Lb(a,0)|0;if((n|0)<0){t=-1;return t|0}c[d>>2]=c[e>>2];c[b>>2]=c[i>>2];c[e>>2]=0;t=n;return t|0}function $Lb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[a+860>>2]|0;if((c[a+856>>2]|0)!=0){e=c[a+1480>>2]|0;if((e|0)<=(b|0)){f=0;return f|0}g=c[a+1488>>2]|0;h=0;i=b;while(1){j=(c[g+(i<<5)+20>>2]|0)+h|0;k=i+1|0;if((k|0)<(e|0)){h=j;i=k}else{f=j;break}}return f|0}i=(b|0)>0;if(i){h=c[a+1488>>2]|0;e=0;g=0;while(1){j=(c[h+(g<<5)+20>>2]|0)+e|0;k=g+1|0;if((k|0)<(b|0)){e=j;g=k}else{l=j;break}}}else{l=0}g=a+1480|0;e=c[g>>2]|0;h=(e|0)>(b|0);do{if(h){j=c[a+1488>>2]|0;k=0;m=b;do{k=(c[j+(m<<5)+20>>2]|0)+k|0;m=m+1|0;}while((m|0)<(e|0));m=l+68+(e<<2)+((k*3|0|0)/2|0)|0;if(!h){n=m;break}j=c[a+1488>>2]|0;o=m;m=b;while(1){p=(c[j+(m<<5)+28>>2]|0)+o|0;q=m+1|0;if((q|0)<(e|0)){o=p;m=q}else{n=p;break}}}else{n=l+68+(e<<2)|0}}while(0);h=d+1528|0;if((c[h>>2]|0)<(n|0)){m=n<<1;n=MLb(m)|0;if((n|0)==0){f=-1;return f|0}o=d+1524|0;if((l|0)!=0){nrc(n|0,c[o>>2]|0,l)|0}j=c[o>>2]|0;k=n-j|0;if(i){i=a+1488|0;p=0;do{q=(c[i>>2]|0)+(p<<5)+24|0;c[q>>2]=(c[q>>2]|0)+k;p=p+1|0;}while((p|0)<(b|0));r=c[o>>2]|0}else{r=j}NLb(r);c[o>>2]=n;c[h>>2]=m;s=c[g>>2]|0;t=n}else{s=e;t=c[d+1524>>2]|0}e=d+1524|0;d=t+l|0;if((s|0)>(b|0)){s=a+1488|0;n=a+136|0;m=d;h=b;b=c[s>>2]|0;while(1){o=c[b+(h<<5)+20>>2]|0;do{if((h|0)==0){u=1}else{if(((c[b+(h<<5)+4>>2]|0)-7|0)>>>0<2>>>0){u=1;break}u=(c[n>>2]|0)!=0|0}}while(0);c[b+(h<<5)+8>>2]=u;lNb(a,m,b+(h<<5)|0);r=c[s>>2]|0;j=c[r+(h<<5)+20>>2]|0;p=m+j|0;if((c[n>>2]|0)==0){v=p;w=r}else{k=r+(h<<5)+28|0;i=o+5-j+(c[k>>2]|0)|0;c[k>>2]=i;if((i|0)>0){mrc(p|0,0,i|0)|0;k=c[s>>2]|0;q=c[k+(h<<5)+28>>2]|0;x=k+(h<<5)+20|0;c[x>>2]=(c[x>>2]|0)+q;y=m+(q+j)|0;z=k;A=q}else{y=p;z=r;A=i}c[z+(h<<5)+28>>2]=(A|0)>0?A:0;v=y;w=z}i=h+1|0;if((i|0)<(c[g>>2]|0)){m=v;h=i;b=w}else{break}}B=v;C=c[e>>2]|0}else{B=d;C=t}f=B-(C+l)|0;return f|0}function aMb(b,d,e,f,j){b=b|0;d=d|0;e=e|0;f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0.0,Ea=0.0,Fa=0.0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0;k=i;i=i+152|0;l=k|0;m=k+8|0;if((c[b+50360>>2]|0)!=0){n=-1;i=k;return n|0}o=c[b+1548>>2]|0;if((o|0)>1){p=b+1444|0;q=c[p>>2]|0;r=c[b+860+(q<<2)>>2]|0;s=(q+1|0)%(o|0)|0;c[p>>2]=s;p=c[b+860+(s<<2)>>2]|0;q=c[b+860+(((s+1|0)%(o|0)|0)<<2)>>2]|0;if((p|0)!=(r|0)){o=r+14976|0;s=c[o>>2]|0;if((s|0)!=0){t=o;o=s;do{s=o+11960|0;c[s>>2]=(c[s>>2]|0)+1;t=t+4|0;o=c[t>>2]|0;}while((o|0)!=0)}o=p+14976|0;t=c[o>>2]|0;if((t|0)!=0){s=o;o=t;do{LOb(r,o);s=s+4|0;o=c[s>>2]|0;}while((o|0)!=0)}o=(c[r+15148>>2]|0)+11960|0;c[o>>2]=(c[o>>2]|0)+1;LOb(r,c[p+15148>>2]|0);nrc(p+1540|0,r+1540|0,17412)|0;nrc(p|0,r|0,860)|0;nrc(p+30504|0,r+30504|0,3312)|0;nrc(p+36744|0,r+36744|0,632)|0;c[p+1536>>2]=c[r+1536>>2]}TMb(p,r,q);u=p;v=q}else{u=b;v=b}b=u+1624|0;q=c[b+4>>2]|0;p=u+1616|0;c[p>>2]=c[b>>2];c[p+4>>2]=q;c[e>>2]=0;c[d>>2]=0;do{if((f|0)==0){a[c[u+38024>>2]|0]=1}else{q=MOb(u,0)|0;if((q|0)==0){n=-1;i=k;return n|0}if((vOb(u,q,f)|0)<0){n=-1;i=k;return n|0}if((c[u+28>>2]|0)==(c[u+18560>>2]<<4|0)){if((c[u+32>>2]|0)!=(c[u+18564>>2]<<4|0)){w=15}}else{w=15}if((w|0)==15){AOb(u,q)}p=u+15060|0;r=c[p>>2]|0;c[p>>2]=r+1;c[q+92>>2]=r;if((r|0)==0){o=q+24|0;s=c[o+4>>2]|0;t=u+15096|0;c[t>>2]=c[o>>2];c[t+4>>2]=s}s=c[u+15080>>2]|0;if((s|0)!=0&(r|0)==(s|0)){s=q+24|0;r=u+15096|0;t=xrc(c[s>>2]|0,c[s+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0)|0;r=u+15088|0;c[r>>2]=t;c[r+4>>2]=G}do{if((c[u+776>>2]|0)==0){x=u+15120|0;y=q+24|0}else{r=q+24|0;t=c[r+4>>2]|0;s=u+15120|0;o=c[s+4>>2]|0;if((t|0)>(o|0)|(t|0)==(o|0)&(c[r>>2]|0)>>>0>(c[s>>2]|0)>>>0){x=s;y=r;break}ILb(u,1,2312192,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;x=s;y=r}}while(0);r=c[x+4>>2]|0;s=u+15128|0;c[s>>2]=c[x>>2];c[s+4>>2]=r;r=c[y+4>>2]|0;c[x>>2]=c[y>>2];c[x+4>>2]=r;r=q+120|0;s=c[r>>2]|0;if(s>>>0>9>>>0){c[r>>2]=0;w=27}else{if((s|0)==0){w=27}}do{if((w|0)==27){s=c[q+88>>2]|0;o=(s|0)==0;if((c[(o?u+160|0:s+160|0)>>2]|0)==0){c[r>>2]=1;break}else{c[r>>2]=(c[(o?u+800|0:s+800|0)>>2]|0)!=0?4:5;break}}}while(0);do{if((c[u+692>>2]|0)==0){w=33}else{if((c[u+708>>2]|0)==0){w=33;break}if((BMb(u,q,c[f+80>>2]|0)|0)==0){break}else{n=-1}i=k;return n|0}}while(0);if((w|0)==33){zMb(u,q,c[f+80>>2]|0)}r=c[f+84>>2]|0;if((r|0)!=0){qe[r&1023](c[f+80>>2]|0)}if((c[u+15136>>2]|0)!=0){nPb(u,q)}mMb(u,q);if((c[p>>2]|0)>((c[u+15076>>2]|0)+1-(c[u+1548>>2]|0)|0)){break}c[j>>2]=0;n=0;i=k;return n|0}}while(0);f=u+1540|0;c[f>>2]=(c[f>>2]|0)+1;x=u+14960|0;y=c[x>>2]|0;do{if((c[y>>2]|0)==0){oMb(u);r=c[x>>2]|0;if((c[r>>2]|0)!=0){z=r;break}if((nMb(u)|0)==0){z=c[x>>2]|0;break}n=bMb(v,u,d,e,j)|0;i=k;return n|0}else{z=y}}while(0);y=KOb(z)|0;z=u+15144|0;c[z>>2]=y;x=u+12|0;do{if((c[x>>2]|0)!=0){r=u+4|0;s=c[r>>2]|0;if((s|0)>0){A=0;B=s}else{break}while(1){s=(c[u+860+(A<<2)>>2]|0)+1440|0;if((c[s>>2]|0)==0){C=B}else{c[s>>2]=0;C=c[r>>2]|0}s=A+1|0;if((s|0)<(C|0)){A=s;B=C}else{break}}}}while(0);C=u+1548|0;if((c[f>>2]|0)==((c[C>>2]|0)-1|0)){B=y+40|0;A=c[B+4>>2]|0;r=u+15336|0;c[r>>2]=c[B>>2];c[r+4>>2]=A}A=u+1536|0;if((c[A>>2]|0)==0){D=y}else{XLb(u,c[u+1532>>2]|0)|0;c[A>>2]=0;D=c[z>>2]|0}A=c[D+88>>2]|0;do{if((A|0)!=0){XLb(u,A)|0;D=c[(c[z>>2]|0)+88>>2]|0;y=c[D+852>>2]|0;if((y|0)==0){break}qe[y&1023](D);c[(c[z>>2]|0)+88>>2]=0}}while(0);A=u+15148|0;D=c[A>>2]|0;do{if((c[D+116>>2]|0)==0){if((c[C>>2]|0)<=1){E=D;break}LOb(u,D);y=MOb(u,1)|0;c[A>>2]=y;if((y|0)==0){n=-1}else{E=y;break}i=k;return n|0}else{y=u+8196|0;r=c[y>>2]|0;B=u+14976|0;if((r|0)>0){p=0;q=r;while(1){r=c[B>>2]|0;if((r|0)==0){F=q}else{s=u+8200+(p<<3)+4|0;o=1;t=B;H=r;while(1){if((c[H+4>>2]|0)==(c[s>>2]|0)){LOb(u,KOb(t)|0)}r=u+14976+(o<<2)|0;I=c[r>>2]|0;if((I|0)==0){break}o=o+1|0;t=r;H=I}F=c[y>>2]|0}H=p+1|0;if((H|0)<(F|0)){p=H;q=F}else{break}}J=c[A>>2]|0}else{J=D}HOb(B,J);if((c[u+14976+(c[u+8408>>2]<<2)>>2]|0)!=0){LOb(u,KOb(B)|0)}q=MOb(u,1)|0;c[A>>2]=q;if((q|0)==0){n=-1}else{E=q;break}i=k;return n|0}}while(0);c[E+11952>>2]=-1;J=c[z>>2]|0;D=J+16|0;do{if(!(((c[D>>2]|0)-1|0)>>>0<2>>>0)){F=c[u+14976>>2]|0;if((F|0)!=0){q=0;p=0;y=F;do{q=((c[y+11992>>2]|0)==0)+q|0;p=p+1|0;y=c[u+14976+(p<<2)>>2]|0;}while((y|0)!=0);if((q|0)!=0){break}}c[J+124>>2]=1;c[D>>2]=1}}while(0);y=J+92|0;do{if((c[J+124>>2]|0)!=0){c[u+15048>>2]=c[y>>2];if((c[D>>2]|0)!=1){break}c[u+1544>>2]=0;c[u+15052>>2]=c[y>>2]}}while(0);p=u+8192|0;c[p>>2]=0;B=u+8196|0;c[B>>2]=0;c[u+15324>>2]=0;F=u+15320|0;c[F>>2]=0;H=c[u+15052>>2]|0;t=(c[y>>2]|0)-((H|0)>0?H:0)<<1;c[J+4>>2]=t;c[E+4>>2]=t;t=c[D>>2]|0;do{if((t|0)==3){c[u+3240>>2]=0;cMb(u);c[u+15056>>2]=-1;K=1;L=2}else if((t|0)==1){c[u+3240>>2]=2;D=u+14976|0;if((c[D>>2]|0)==0){M=J;N=E}else{do{LOb(u,IOb(D)|0);}while((c[D>>2]|0)!=0);M=c[z>>2]|0;N=c[A>>2]|0}c[M+4>>2]=0;c[N+4>>2]=0;c[u+15056>>2]=-1;K=5;L=3}else if((t|0)==4){D=(c[u+124>>2]|0)==1?1:2;c[u+3240>>2]=1;cMb(u);K=1;L=D}else if((t|0)==2){c[u+3240>>2]=2;cMb(u);if((c[u+128>>2]|0)==0){K=1;L=2;break}D=c[z>>2]|0;if((c[D+124>>2]|0)==0){O=-1}else{O=c[D+4>>2]|0}c[u+15056>>2]=O;K=1;L=2}else{c[u+3240>>2]=1;K=1;L=0}}while(0);O=c[z>>2]|0;t=c[A>>2]|0;c[t+16>>2]=c[O+16>>2];c[t+92>>2]=c[O+92>>2];N=(L|0)!=0;if(N){P=(c[u+96>>2]|0)>1|0}else{P=0}c[t+116>>2]=P;c[O+116>>2]=P;c[t+12012>>2]=c[O+12012>>2];c[(c[A>>2]|0)+12016>>2]=c[(c[z>>2]|0)+12016>>2];c[(c[z>>2]|0)+12012>>2]=0;c[(c[z>>2]|0)+12016>>2]=0;O=c[z>>2]|0;t=O+24|0;P=c[t+4>>2]|0;M=c[A>>2]|0;E=M+24|0;c[E>>2]=c[t>>2];c[E+4>>2]=P;P=c[u+15080>>2]|0;if((P|0)==0){E=O+40|0;t=c[E+4>>2]|0;J=M+32|0;c[J>>2]=c[E>>2];c[J+4>>2]=t;Q=O}else{t=c[f>>2]|0;if((t|0)>(P|0)){J=u+15104+(((t-P|0)%(P|0)|0)<<3)|0;R=c[J+4>>2]|0;S=c[J>>2]|0;T=O+40|0}else{J=O+40|0;O=u+15088|0;E=xrc(c[J>>2]|0,c[J+4>>2]|0,c[O>>2]|0,c[O+4>>2]|0)|0;R=G;S=E;T=J}J=M+32|0;c[J>>2]=S;c[J+4>>2]=R;R=c[T+4>>2]|0;J=u+15104+(((t|0)%(P|0)|0)<<3)|0;c[J>>2]=c[T>>2];c[J+4>>2]=R;Q=c[z>>2]|0}R=c[A>>2]|0;if((c[Q+16>>2]|0)==1){Q=R+24|0;J=c[Q+4>>2]|0;T=u+1640|0;c[T>>2]=c[Q>>2];c[T+4>>2]=J}J=c[R+4>>2]|0;R=m;T=u+15152|0;c[T>>2]=0;Q=u+24580|0;c[Q>>2]=0;P=u+15156|0;c[P>>2]=0;t=u+24584|0;c[t>>2]=0;S=u+3240|0;do{if((c[S>>2]|0)!=2){M=c[u+14976>>2]|0;if((M|0)!=0){E=0;O=M;do{do{if((c[O+11992>>2]|0)==0){M=c[O+4>>2]|0;if((M|0)<(J|0)){D=c[T>>2]|0;c[T>>2]=D+1;c[u+15160+(D<<2)>>2]=O;break}if((M|0)<=(J|0)){break}M=c[P>>2]|0;c[P>>2]=M+1;c[u+15236+(M<<2)>>2]=O}}while(0);E=E+1|0;O=c[u+14976+(E<<2)>>2]|0;}while((O|0)!=0)}O=u+756|0;E=0;do{M=c[u+15160+(E*76|0)>>2]|0;D=u+15312+(E<<2)|0;c[D>>2]=M;q=u+15152+(E<<2)|0;H=c[q>>2]|0;a:do{if((H-1|0)>0){y=(E|0)==0;o=0;s=H;I=M;while(1){r=o+1|0;U=u+15160+(E*76|0)+(r<<2)|0;V=c[U>>2]|0;W=c[V+4>>2]|0;X=c[I+4>>2]|0;if(y){if((W|0)>(X|0)){w=118}}else{if((W|0)<(X|0)){w=118}}if((w|0)==118){w=0;c[D>>2]=V}V=u+15160+(E*76|0)+(o<<2)|0;X=c[V>>2]|0;W=c[(c[z>>2]|0)+92>>2]|0;if((c[O>>2]|0)==5){Y=W&-2;Z=c[X+92>>2]|0;_=Y-(Z&-2)|0;$=c[U>>2]|0;aa=c[$+92>>2]|0;ba=Y-(aa&-2)|0;da=((ba|0)>-1?ba:-ba|0)|(aa^W)&1;ea=((_|0)>-1?_:-_|0)|(Z^W)&1;fa=$}else{$=W-(c[X+92>>2]|0)|0;Z=c[U>>2]|0;_=W-(c[Z+92>>2]|0)|0;da=(_|0)>-1?_:-_|0;ea=($|0)>-1?$:-$|0;fa=Z}if((ea|0)>(da|0)){c[V>>2]=fa;c[U>>2]=X;ga=0;ha=c[q>>2]|0}else{ga=r;ha=s}if((ga|0)>=(ha-1|0)){break a}o=ga;s=ha;I=c[D>>2]|0}}}while(0);E=E+1|0;}while((E|0)<2);E=c[p>>2]|0;do{if((E|0)!=0){O=c[T>>2]|0;D=O-1|0;if((D|0)<(O-E|0)){break}O=u+1544|0;q=D;D=c[B>>2]|0;do{M=c[u+15160+(q<<2)>>2]|0;H=(c[O>>2]|0)-(c[M+112>>2]|0)|0;c[u+8200+(D<<3)+4>>2]=c[M+4>>2];M=c[B>>2]|0;D=M+1|0;c[B>>2]=D;c[u+8200+(M<<3)>>2]=H;q=q-1|0;}while((q|0)>=((c[T>>2]|0)-(c[p>>2]|0)|0))}}while(0);dMb(u);E=c[P>>2]|0;q=c[u+15072>>2]|0;D=(E|0)<(q|0)?E:q;c[P>>2]=D;q=c[T>>2]|0;E=c[u+15068>>2]|0;O=(q|0)<(E|0)?q:E;E=c[u+88>>2]|0;q=(O|0)<(E|0)?O:E;c[T>>2]=q;E=c[z>>2]|0;O=E+16|0;H=c[O>>2]|0;do{if((H-4|0)>>>0<2>>>0){if((c[u+132>>2]|0)==0){ia=q;ja=D;break}M=c[(c[u+15160>>2]|0)+16>>2]|0;if((M|0)==5){ka=(q|0)<2?q:2}else{I=(M|0)==4?2:1;ka=(q|0)<(I|0)?q:I}c[T>>2]=ka;la=c[O>>2]|0;ma=ka;w=137}else{la=H;ma=q;w=137}}while(0);do{if((w|0)==137){if((la|0)!=3){ia=ma;ja=D;break}q=u+528|0;do{if((c[q>>2]|0)>0){c[m+140>>2]=0;c[m+92>>2]=0;if((c[u+708>>2]|0)==0){na=E}else{OMb(u,E);na=c[z>>2]|0}if((c[na+444>>2]|0)==0){c[na+432>>2]=0;c[m+36>>2]=1;c[m+32>>2]=0;c[m+40>>2]=-1;re[c[u+37560>>2]&1023](u,m|0);if((c[T>>2]|0)<2){oa=-1;break}if((c[q>>2]|0)!=2){oa=-1;break}H=OOb(u)|0;if((H|0)==0){oa=-1;break}O=u+15160|0;nrc(H|0,c[O>>2]|0,12080)|0;c[H+11960>>2]=1;c[H+2772>>2]=c[O>>2];c[H+2768>>2]=1;nrc((c[z>>2]|0)+544|0,R|0,144)|0;c[F>>2]=1;O=c[T>>2]|0;if((O|0)<16){c[T>>2]=O+1}c[u+15220>>2]=0;JOb(u+15164|0,H);oa=1;break}H=na+436|0;O=na+432|0;if((c[H>>2]|0)==(1<<c[O>>2]|0)){c[H>>2]=1;c[O>>2]=0;re[c[u+37560>>2]&1023](u,na+400|0)}do{if((c[T>>2]|0)>=2){if((c[q>>2]|0)!=2){break}O=OOb(u)|0;if((O|0)==0){break}H=u+15160|0;nrc(O|0,c[H>>2]|0,12080)|0;c[O+11960>>2]=1;c[O+2772>>2]=c[H>>2];c[O+2768>>2]=1;nrc((c[z>>2]|0)+544|0,2772248,144)|0;c[F>>2]=1;H=c[T>>2]|0;if((H|0)<16){c[T>>2]=H+1}c[u+15220>>2]=0;JOb(u+15164|0,O)}}while(0);O=c[z>>2]|0;if(!((c[O+440>>2]|0)>-128)){oa=-1;break}H=O+400|0;c[R>>2]=c[H>>2];c[R+4>>2]=c[H+4>>2];c[R+8>>2]=c[H+8>>2];c[R+12>>2]=c[H+12>>2];c[R+16>>2]=c[H+16>>2];c[R+20>>2]=c[H+20>>2];c[R+24>>2]=c[H+24>>2];c[R+28>>2]=c[H+28>>2];c[R+32>>2]=c[H+32>>2];c[R+36>>2]=c[H+36>>2];c[R+40>>2]=c[H+40>>2];c[R+44>>2]=c[H+44>>2];H=m+40|0;c[H>>2]=(c[H>>2]|0)-1;re[c[u+37560>>2]&1023](u,m|0);if((c[T>>2]|0)<2){oa=-1;break}if((c[q>>2]|0)!=2){oa=-1;break}H=OOb(u)|0;if((H|0)==0){oa=-1;break}O=u+15160|0;nrc(H|0,c[O>>2]|0,12080)|0;c[H+11960>>2]=1;c[H+2772>>2]=c[O>>2];c[H+2768>>2]=1;nrc((c[z>>2]|0)+544|0,R|0,144)|0;c[F>>2]=1;O=c[T>>2]|0;if((O|0)<16){c[T>>2]=O+1}c[u+15220>>2]=0;JOb(u+15164|0,H);oa=1}else{oa=-1}}while(0);c[u+30436>>2]=oa;ia=c[T>>2]|0;ja=c[P>>2]|0}}while(0);if((ia+ja|0)<17){c[Q>>2]=ia;c[t>>2]=ja;break}else{Cd(2136240,2302024,2233,2649208);return 0}}}while(0);do{if((c[x>>2]|0)==0){ja=c[u+1496>>2]|0;t=c[u+1492>>2]|0;ia=ja&3;Q=ja+(-ia|0)|0;c[u+1500>>2]=Q;c[u+1504>>2]=Q;c[u+1508>>2]=ja+t;t=4-ia<<3;c[u+1516>>2]=t;c[u+1512>>2]=(je(c[Q>>2]|0)|0)>>>(t>>>0);c[u+1480>>2]=0}else{t=u+4|0;if((c[t>>2]|0)>0){pa=0}else{break}do{Q=u+860+(pa<<2)|0;ia=c[Q>>2]|0;ja=c[ia+1496>>2]|0;oa=c[ia+1492>>2]|0;F=ja&3;R=ja+(-F|0)|0;c[ia+1500>>2]=R;c[ia+1504>>2]=R;c[ia+1508>>2]=ja+oa;oa=4-F<<3;c[ia+1516>>2]=oa;c[ia+1512>>2]=(je(c[R>>2]|0)|0)>>>(oa>>>0);c[(c[Q>>2]|0)+1480>>2]=0;pa=pa+1|0;}while((pa|0)<(c[t>>2]|0))}}while(0);if((c[u+760>>2]|0)==0){qa=5}else{pa=c[S>>2]|0;if((pa|0)==2){ra=0}else if((pa|0)==0){ra=1}else if((pa|0)==1){ra=2}else{ra=7}pa=u+1480|0;t=c[pa>>2]|0;Q=u+1488|0;oa=c[Q>>2]|0;c[oa+(t<<5)>>2]=0;c[oa+(t<<5)+4>>2]=9;c[oa+(t<<5)+8>>2]=1;c[oa+(t<<5)+20>>2]=0;R=u+1500|0;ia=u+1504|0;F=u+1516|0;ja=u+1496|0;c[oa+(t<<5)+24>>2]=(c[ja>>2]|0)+((32-(c[F>>2]|0)+((c[ia>>2]|0)-(c[R>>2]|0)<<3)|0)/8|0);c[oa+(t<<5)+28>>2]=0;t=c[F>>2]|0;if((t|0)>3){oa=u+1512|0;m=c[oa>>2]<<3|ra;c[oa>>2]=m;sa=t-3|0;ta=m}else{m=3-t|0;oa=u+1512|0;na=je(c[oa>>2]<<t|ra>>>(m>>>0)|0)|0;c[c[ia>>2]>>2]=na;c[ia>>2]=(c[ia>>2]|0)+4;c[oa>>2]=ra;sa=32-m|0;ta=ra}ra=u+1512|0;m=ta<<1|1;c[ra>>2]=m;ta=sa-1|0;c[F>>2]=ta;do{if((ta|0)==0){oa=je(m|0)|0;c[c[ia>>2]>>2]=oa;oa=(c[ia>>2]|0)+4|0;c[ia>>2]=oa;c[F>>2]=32;ua=c[ra>>2]|0;va=32;wa=0;xa=oa;w=183}else{oa=ta&7;if((ta|0)>(oa|0)){ua=m;va=ta;wa=oa;xa=c[ia>>2]|0;w=183;break}else{na=je(m<<ta|0)|0;c[c[ia>>2]>>2]=na;na=(c[ia>>2]|0)+4|0;c[ia>>2]=na;c[ra>>2]=0;ya=sa+31|0;za=oa;Aa=na;break}}}while(0);if((w|0)==183){c[ra>>2]=ua<<wa;ya=va;za=wa;Aa=xa}xa=ya-za|0;c[F>>2]=xa;F=c[pa>>2]|0;za=c[Q>>2]|0;ya=(c[ja>>2]|0)+((32-xa+(Aa-(c[R>>2]|0)<<3)|0)/8|0)|0;c[za+(F<<5)+20>>2]=ya-(c[za+(F<<5)+24>>2]|0);mrc(ya|0,-1|0,64)|0;ya=c[u+856>>2]|0;if((ya|0)!=0){ef[ya&4095](u,za+(F<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}F=(c[pa>>2]|0)+1|0;c[pa>>2]=F;za=u+1484|0;ya=c[za>>2]|0;do{if((F|0)<(ya|0)){Ba=F;Ca=c[Q>>2]|0}else{R=MLb(ya<<6)|0;if((R|0)==0){n=-1;i=k;return n|0}else{Aa=R;nrc(R|0,c[Q>>2]|0,c[za>>2]<<5)|0;NLb(c[Q>>2]|0);c[Q>>2]=Aa;c[za>>2]=c[za>>2]<<1;Ba=c[pa>>2]|0;Ca=Aa;break}}}while(0);qa=(c[Ca+(Ba-1<<5)+20>>2]|0)+10|0}c[u+1552>>2]=K;c[u+1556>>2]=L;L=u+108|0;Ba=c[z>>2]|0;do{if((c[L>>2]|0)!=0){Ca=c[Ba+16>>2]|0;if((Ca|0)==2|(Ca|0)==1){pa=c[A>>2]|0;c[pa+11988>>2]=0;c[u+1632>>2]=0;g[pa+11976>>2]=+(c[u+18560>>2]|0);break}else if((Ca|0)!=3){break}Ca=c[A>>2]|0;pa=c[u+15160>>2]|0;za=((c[Ca+4>>2]|0)-(c[pa+4>>2]|0)|0)/2|0;Q=u+18560|0;ya=u+96|0;Da=(+(c[Q>>2]|0)+-1.0)/+(c[ya>>2]|0);Ea=Da>1.0?Da:1.0;Da=+g[pa+11976>>2];F=Ca+11976|0;g[F>>2]=Da;Aa=(c[pa+11988>>2]|0)+za|0;pa=Ca+11988|0;c[pa>>2]=Aa;R=u+1632|0;do{if((Aa|0)<(c[ya>>2]|0)){if((c[R>>2]|0)==0){Fa=Da;break}if(Da+.5<+(c[Q>>2]|0)){Fa=Da}else{w=198}}else{w=198}}while(0);if((w|0)==198){g[F>>2]=0.0;c[pa>>2]=0;c[R>>2]=0;c[Ba+124>>2]=1;Fa=0.0}c[Ca+11980>>2]=~~(Fa+.5);Da=+(za|0)*Ea+Fa;g[F>>2]=Da;ya=~~(Da+.5);Aa=Ca+11984|0;c[Aa>>2]=ya;xa=c[Q>>2]|0;ja=xa-1|0;if((ya|0)<(ja|0)){break}g[F>>2]=+(xa|0);c[Aa>>2]=ja}}while(0);do{if((c[Ba+124>>2]|0)==0){Ga=qa}else{if((c[u+764>>2]|0)==0){Ha=qa}else{ja=u+1480|0;Aa=c[ja>>2]|0;xa=u+1488|0;ya=c[xa>>2]|0;c[ya+(Aa<<5)>>2]=3;c[ya+(Aa<<5)+4>>2]=7;c[ya+(Aa<<5)+8>>2]=1;c[ya+(Aa<<5)+20>>2]=0;wa=u+1500|0;va=u+1504|0;ua=u+1516|0;ra=u+1496|0;c[ya+(Aa<<5)+24>>2]=(c[ra>>2]|0)+((32-(c[ua>>2]|0)+((c[va>>2]|0)-(c[wa>>2]|0)<<3)|0)/8|0);c[ya+(Aa<<5)+28>>2]=0;Aa=u+1480|0;ya=u+1500|0;sa=u+8368|0;ZMb(ya,sa);ia=c[ja>>2]|0;ta=c[xa>>2]|0;m=(c[ra>>2]|0)+((32-(c[ua>>2]|0)+((c[va>>2]|0)-(c[wa>>2]|0)<<3)|0)/8|0)|0;c[ta+(ia<<5)+20>>2]=m-(c[ta+(ia<<5)+24>>2]|0);mrc(m|0,-1|0,64)|0;m=u+856|0;na=c[m>>2]|0;if((na|0)!=0){ef[na&4095](u,ta+(ia<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}ia=(c[ja>>2]|0)+1|0;c[ja>>2]=ia;ta=u+1484|0;na=c[ta>>2]|0;do{if((ia|0)>=(na|0)){oa=MLb(na<<6)|0;if((oa|0)==0){n=-1;i=k;return n|0}else{nrc(oa|0,c[xa>>2]|0,c[ta>>2]<<5)|0;NLb(c[xa>>2]|0);c[xa>>2]=oa;c[ta>>2]=c[ta>>2]<<1;break}}}while(0);na=u+136|0;if((c[na>>2]|0)==0){Ia=c[xa>>2]|0;Ja=c[wa>>2]|0;Ka=c[va>>2]|0;La=Aa|0}else{ia=c[ya>>2]|0;F=c[va>>2]|0;Q=Aa|0;Ca=c[xa>>2]|0;c[Ca+((c[Q>>2]|0)-1<<5)+28>>2]=((32-(c[ua>>2]|0)+(F-ia<<3)|0)/-8|0)+246;Ia=Ca;Ja=ia;Ka=F;La=Q}Q=c[La>>2]|0;F=Q-1|0;ia=c[Ia+(F<<5)+20>>2]|0;Ca=c[Ia+(F<<5)+28>>2]|0;c[Ia+(Q<<5)>>2]=3;c[Ia+(Q<<5)+4>>2]=8;c[Ia+(Q<<5)+8>>2]=1;c[Ia+(Q<<5)+20>>2]=0;c[Ia+(Q<<5)+24>>2]=(c[ra>>2]|0)+((32-(c[ua>>2]|0)+(Ka-Ja<<3)|0)/8|0);c[Ia+(Q<<5)+28>>2]=0;$Mb(ya,sa,u+8636|0);Q=c[ja>>2]|0;F=c[xa>>2]|0;za=(c[ra>>2]|0)+((32-(c[ua>>2]|0)+((c[va>>2]|0)-(c[wa>>2]|0)<<3)|0)/8|0)|0;c[F+(Q<<5)+20>>2]=za-(c[F+(Q<<5)+24>>2]|0);mrc(za|0,-1|0,64)|0;za=c[m>>2]|0;if((za|0)!=0){ef[za&4095](u,F+(Q<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}Q=(c[ja>>2]|0)+1|0;c[ja>>2]=Q;F=c[ta>>2]|0;do{if((Q|0)>=(F|0)){za=MLb(F<<6)|0;if((za|0)==0){n=-1;i=k;return n|0}else{nrc(za|0,c[xa>>2]|0,c[ta>>2]<<5)|0;NLb(c[xa>>2]|0);c[xa>>2]=za;c[ta>>2]=c[ta>>2]<<1;break}}}while(0);if((c[na>>2]|0)==0){Ma=c[xa>>2]|0}else{ta=(c[La>>2]|0)-1|0;F=c[xa>>2]|0;c[F+(ta<<5)+28>>2]=251-(c[F+(ta<<5)+20>>2]|0);Ma=F}F=(c[La>>2]|0)-1|0;Ha=qa+10+ia+Ca+(c[Ma+(F<<5)+20>>2]|0)+(c[Ma+(F<<5)+28>>2]|0)|0}if((c[C>>2]|0)!=1){Ga=Ha;break}if((c[u+8536>>2]|0)==0){Ga=Ha;break}QMb(u);F=u+1480|0;ta=c[F>>2]|0;Q=u+1488|0;ja=c[Q>>2]|0;c[ja+(ta<<5)>>2]=0;c[ja+(ta<<5)+4>>2]=6;c[ja+(ta<<5)+8>>2]=1;c[ja+(ta<<5)+20>>2]=0;m=u+1500|0;wa=u+1504|0;va=u+1516|0;ua=u+1496|0;c[ja+(ta<<5)+24>>2]=(c[ua>>2]|0)+((32-(c[va>>2]|0)+((c[wa>>2]|0)-(c[m>>2]|0)<<3)|0)/8|0);c[ja+(ta<<5)+28>>2]=0;dNb(u,u+1500|0);ta=c[F>>2]|0;ja=c[Q>>2]|0;ra=(c[ua>>2]|0)+((32-(c[va>>2]|0)+((c[wa>>2]|0)-(c[m>>2]|0)<<3)|0)/8|0)|0;c[ja+(ta<<5)+20>>2]=ra-(c[ja+(ta<<5)+24>>2]|0);mrc(ra|0,-1|0,64)|0;ra=c[u+856>>2]|0;if((ra|0)!=0){ef[ra&4095](u,ja+(ta<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}ta=(c[F>>2]|0)+1|0;c[F>>2]=ta;ja=u+1484|0;ra=c[ja>>2]|0;do{if((ta|0)<(ra|0)){Na=ta;Oa=c[Q>>2]|0}else{m=MLb(ra<<6)|0;if((m|0)==0){n=-1;i=k;return n|0}else{wa=m;nrc(m|0,c[Q>>2]|0,c[ja>>2]<<5)|0;NLb(c[Q>>2]|0);c[Q>>2]=wa;c[ja>>2]=c[ja>>2]<<1;Na=c[F>>2]|0;Oa=wa;break}}}while(0);F=Na-1|0;ja=c[Oa+(F<<5)+20>>2]|0;do{if((c[u+768>>2]|0)==0){Pa=0}else{if((c[u+136>>2]|0)!=0){Pa=0;break}Pa=(F|0)!=0|0}}while(0);Ga=Ha+5+ja-Pa|0}}while(0);Pa=c[z>>2]|0;b:do{if((c[Pa+11996>>2]|0)>0){Ha=u+1480|0;Oa=u+1488|0;Na=u+1500|0;Ma=u+1504|0;qa=u+1516|0;La=u+1496|0;Ia=u+1500|0;Ja=u+856|0;Ka=u+1484|0;Ba=u+768|0;F=u+136|0;Q=Ga;ra=0;while(1){ta=c[Ha>>2]|0;Ca=c[Oa>>2]|0;c[Ca+(ta<<5)>>2]=0;c[Ca+(ta<<5)+4>>2]=6;c[Ca+(ta<<5)+8>>2]=1;c[Ca+(ta<<5)+20>>2]=0;c[Ca+(ta<<5)+24>>2]=(c[La>>2]|0)+((32-(c[qa>>2]|0)+((c[Ma>>2]|0)-(c[Na>>2]|0)<<3)|0)/8|0);c[Ca+(ta<<5)+28>>2]=0;ta=c[(c[z>>2]|0)+12e3>>2]|0;XMb(Ia,c[ta+(ra*12|0)+8>>2]|0,c[ta+(ra*12|0)>>2]|0,c[ta+(ra*12|0)+4>>2]|0);ta=c[Ha>>2]|0;Ca=c[Oa>>2]|0;ia=(c[La>>2]|0)+((32-(c[qa>>2]|0)+((c[Ma>>2]|0)-(c[Na>>2]|0)<<3)|0)/8|0)|0;c[Ca+(ta<<5)+20>>2]=ia-(c[Ca+(ta<<5)+24>>2]|0);mrc(ia|0,-1|0,64)|0;ia=c[Ja>>2]|0;if((ia|0)!=0){ef[ia&4095](u,Ca+(ta<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}ta=(c[Ha>>2]|0)+1|0;c[Ha>>2]=ta;Ca=c[Ka>>2]|0;if((ta|0)<(Ca|0)){Qa=ta;Ra=c[Oa>>2]|0}else{ta=MLb(Ca<<6)|0;if((ta|0)==0){n=-1;break}Ca=ta;nrc(ta|0,c[Oa>>2]|0,c[Ka>>2]<<5)|0;NLb(c[Oa>>2]|0);c[Oa>>2]=Ca;c[Ka>>2]=c[Ka>>2]<<1;Qa=c[Ha>>2]|0;Ra=Ca}Ca=Qa-1|0;ta=c[Ra+(Ca<<5)+20>>2]|0;do{if((c[Ba>>2]|0)==0){Sa=0}else{if((c[F>>2]|0)!=0){Sa=0;break}Sa=(Ca|0)!=0|0}}while(0);Ca=Q+5+ta-Sa|0;ia=c[z>>2]|0;xa=c[ia+12004>>2]|0;if((xa|0)==0){Ta=ia}else{qe[xa&1023](c[(c[ia+12e3>>2]|0)+(ra*12|0)+8>>2]|0);c[(c[(c[z>>2]|0)+12e3>>2]|0)+(ra*12|0)+8>>2]=0;Ta=c[z>>2]|0}ia=ra+1|0;if((ia|0)<(c[Ta+11996>>2]|0)){Q=Ca;ra=ia}else{Ua=Ca;Va=Ta;break b}}i=k;return n|0}else{Ua=Ga;Va=Pa}}while(0);Pa=c[Va+12004>>2]|0;if((Pa|0)==0){Wa=Va}else{qe[Pa&1023](c[Va+12e3>>2]|0);c[(c[z>>2]|0)+12e3>>2]=0;c[(c[z>>2]|0)+12004>>2]=0;Wa=c[z>>2]|0}do{if((c[Wa+124>>2]|0)==0){Xa=Ua}else{do{if((c[u+764>>2]|0)==0){Ya=Ua;Za=Wa}else{if((c[Wa+92>>2]|0)!=0){Ya=Ua;Za=Wa;break}Va=u+136|0;if((c[Va>>2]|0)!=0){Ya=Ua;Za=Wa;break}Pa=u+1480|0;Ga=c[Pa>>2]|0;Ta=u+1488|0;Sa=c[Ta>>2]|0;c[Sa+(Ga<<5)>>2]=0;c[Sa+(Ga<<5)+4>>2]=6;c[Sa+(Ga<<5)+8>>2]=1;c[Sa+(Ga<<5)+20>>2]=0;Ra=u+1500|0;Qa=u+1504|0;ra=u+1516|0;Q=u+1496|0;c[Sa+(Ga<<5)+24>>2]=(c[Q>>2]|0)+((32-(c[ra>>2]|0)+((c[Qa>>2]|0)-(c[Ra>>2]|0)<<3)|0)/8|0);c[Sa+(Ga<<5)+28>>2]=0;if((cNb(u,u+1500|0)|0)!=0){n=-1;i=k;return n|0}Ga=c[Pa>>2]|0;Sa=c[Ta>>2]|0;F=(c[Q>>2]|0)+((32-(c[ra>>2]|0)+((c[Qa>>2]|0)-(c[Ra>>2]|0)<<3)|0)/8|0)|0;c[Sa+(Ga<<5)+20>>2]=F-(c[Sa+(Ga<<5)+24>>2]|0);mrc(F|0,-1|0,64)|0;F=c[u+856>>2]|0;if((F|0)!=0){ef[F&4095](u,Sa+(Ga<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}Ga=(c[Pa>>2]|0)+1|0;c[Pa>>2]=Ga;Sa=u+1484|0;F=c[Sa>>2]|0;do{if((Ga|0)<(F|0)){_a=Ga;$a=c[Ta>>2]|0}else{Ra=MLb(F<<6)|0;if((Ra|0)==0){n=-1;i=k;return n|0}else{Qa=Ra;nrc(Ra|0,c[Ta>>2]|0,c[Sa>>2]<<5)|0;NLb(c[Ta>>2]|0);c[Ta>>2]=Qa;c[Sa>>2]=c[Sa>>2]<<1;_a=c[Pa>>2]|0;$a=Qa;break}}}while(0);Pa=_a-1|0;Sa=c[$a+(Pa<<5)+20>>2]|0;do{if((c[u+768>>2]|0)==0){ab=0}else{if((c[Va>>2]|0)!=0){ab=0;break}ab=(Pa|0)!=0|0}}while(0);Ya=Ua+5+Sa-ab|0;Za=c[z>>2]|0}}while(0);if((c[Za+16>>2]|0)==1){bb=Ya}else{if((c[u+128>>2]|0)==0){Pa=(c[u+18560>>2]|0)-1|0;Va=c[u+96>>2]|0;cb=(c[u+112>>2]|0)-1+((Pa|0)<(Va|0)?Pa:Va)|0}else{cb=0}Va=u+1480|0;Pa=c[Va>>2]|0;Ta=u+1488|0;F=c[Ta>>2]|0;c[F+(Pa<<5)>>2]=0;c[F+(Pa<<5)+4>>2]=6;c[F+(Pa<<5)+8>>2]=1;c[F+(Pa<<5)+20>>2]=0;Ga=u+1500|0;ta=u+1504|0;Qa=u+1516|0;Ra=u+1496|0;c[F+(Pa<<5)+24>>2]=(c[Ra>>2]|0)+((32-(c[Qa>>2]|0)+((c[ta>>2]|0)-(c[Ga>>2]|0)<<3)|0)/8|0);c[F+(Pa<<5)+28>>2]=0;bNb(u,u+1500|0,cb);Pa=c[Va>>2]|0;F=c[Ta>>2]|0;ra=(c[Ra>>2]|0)+((32-(c[Qa>>2]|0)+((c[ta>>2]|0)-(c[Ga>>2]|0)<<3)|0)/8|0)|0;c[F+(Pa<<5)+20>>2]=ra-(c[F+(Pa<<5)+24>>2]|0);mrc(ra|0,-1|0,64)|0;ra=c[u+856>>2]|0;if((ra|0)!=0){ef[ra&4095](u,F+(Pa<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}Pa=(c[Va>>2]|0)+1|0;c[Va>>2]=Pa;F=u+1484|0;ra=c[F>>2]|0;do{if((Pa|0)<(ra|0)){db=Pa;eb=c[Ta>>2]|0}else{Ga=MLb(ra<<6)|0;if((Ga|0)==0){n=-1;i=k;return n|0}else{ta=Ga;nrc(Ga|0,c[Ta>>2]|0,c[F>>2]<<5)|0;NLb(c[Ta>>2]|0);c[Ta>>2]=ta;c[F>>2]=c[F>>2]<<1;db=c[Va>>2]|0;eb=ta;break}}}while(0);Va=db-1|0;F=c[eb+(Va<<5)+20>>2]|0;do{if((c[u+768>>2]|0)==0){fb=0}else{if((c[u+136>>2]|0)!=0){fb=0;break}fb=(Va|0)!=0|0}}while(0);bb=Ya+5+F-fb|0}if(!((c[u+756>>2]|0)>-1)){Xa=bb;break}Va=u+1480|0;Ta=c[Va>>2]|0;ra=u+1488|0;Pa=c[ra>>2]|0;c[Pa+(Ta<<5)>>2]=0;c[Pa+(Ta<<5)+4>>2]=6;c[Pa+(Ta<<5)+8>>2]=1;c[Pa+(Ta<<5)+20>>2]=0;ta=u+1500|0;Ga=u+1504|0;Qa=u+1516|0;Ra=u+1496|0;c[Pa+(Ta<<5)+24>>2]=(c[Ra>>2]|0)+((32-(c[Qa>>2]|0)+((c[Ga>>2]|0)-(c[ta>>2]|0)<<3)|0)/8|0);c[Pa+(Ta<<5)+28>>2]=0;fNb(u,u+1500|0);Ta=c[Va>>2]|0;Pa=c[ra>>2]|0;Q=(c[Ra>>2]|0)+((32-(c[Qa>>2]|0)+((c[Ga>>2]|0)-(c[ta>>2]|0)<<3)|0)/8|0)|0;c[Pa+(Ta<<5)+20>>2]=Q-(c[Pa+(Ta<<5)+24>>2]|0);mrc(Q|0,-1|0,64)|0;Q=c[u+856>>2]|0;if((Q|0)!=0){ef[Q&4095](u,Pa+(Ta<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}Ta=(c[Va>>2]|0)+1|0;c[Va>>2]=Ta;Pa=u+1484|0;Q=c[Pa>>2]|0;do{if((Ta|0)<(Q|0)){gb=Ta;hb=c[ra>>2]|0}else{ta=MLb(Q<<6)|0;if((ta|0)==0){n=-1;i=k;return n|0}else{Ga=ta;nrc(ta|0,c[ra>>2]|0,c[Pa>>2]<<5)|0;NLb(c[ra>>2]|0);c[ra>>2]=Ga;c[Pa>>2]=c[Pa>>2]<<1;gb=c[Va>>2]|0;hb=Ga;break}}}while(0);Va=gb-1|0;Pa=c[hb+(Va<<5)+20>>2]|0;do{if((c[u+768>>2]|0)==0){ib=0}else{if((c[u+136>>2]|0)!=0){ib=0;break}ib=(Va|0)!=0|0}}while(0);Xa=bb+5+Pa-ib|0}}while(0);if((c[u+8592>>2]|0)==0){if((c[u+8536>>2]|0)==0){jb=Xa}else{w=289}}else{w=289}if((w|0)==289){ib=u+1480|0;bb=c[ib>>2]|0;hb=u+1488|0;gb=c[hb>>2]|0;c[gb+(bb<<5)>>2]=0;c[gb+(bb<<5)+4>>2]=6;c[gb+(bb<<5)+8>>2]=1;c[gb+(bb<<5)+20>>2]=0;fb=u+1500|0;Ya=u+1504|0;eb=u+1516|0;db=u+1496|0;c[gb+(bb<<5)+24>>2]=(c[db>>2]|0)+((32-(c[eb>>2]|0)+((c[Ya>>2]|0)-(c[fb>>2]|0)<<3)|0)/8|0);c[gb+(bb<<5)+28>>2]=0;eNb(u,u+1500|0);bb=c[ib>>2]|0;gb=c[hb>>2]|0;cb=(c[db>>2]|0)+((32-(c[eb>>2]|0)+((c[Ya>>2]|0)-(c[fb>>2]|0)<<3)|0)/8|0)|0;c[gb+(bb<<5)+20>>2]=cb-(c[gb+(bb<<5)+24>>2]|0);mrc(cb|0,-1|0,64)|0;cb=c[u+856>>2]|0;if((cb|0)!=0){ef[cb&4095](u,gb+(bb<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}bb=(c[ib>>2]|0)+1|0;c[ib>>2]=bb;gb=u+1484|0;cb=c[gb>>2]|0;do{if((bb|0)<(cb|0)){kb=bb;lb=c[hb>>2]|0}else{fb=MLb(cb<<6)|0;if((fb|0)==0){n=-1;i=k;return n|0}else{Ya=fb;nrc(fb|0,c[hb>>2]|0,c[gb>>2]<<5)|0;NLb(c[hb>>2]|0);c[hb>>2]=Ya;c[gb>>2]=c[gb>>2]<<1;kb=c[ib>>2]|0;lb=Ya;break}}}while(0);ib=kb-1|0;kb=c[lb+(ib<<5)+20>>2]|0;do{if((c[u+768>>2]|0)==0){mb=0}else{if((c[u+136>>2]|0)!=0){mb=0;break}mb=(ib|0)!=0|0}}while(0);jb=Xa+5+kb-mb|0}mb=c[z>>2]|0;do{if(((c[mb+16>>2]|0)-4|0)>>>0<2>>>0){nb=jb;ob=mb}else{kb=u+8736|0;if((c[kb>>2]|0)==0){nb=jb;ob=mb;break}c[kb>>2]=0;kb=u+1480|0;Xa=c[kb>>2]|0;ib=u+1488|0;lb=c[ib>>2]|0;c[lb+(Xa<<5)>>2]=0;c[lb+(Xa<<5)+4>>2]=6;c[lb+(Xa<<5)+8>>2]=1;c[lb+(Xa<<5)+20>>2]=0;gb=u+1500|0;hb=u+1504|0;cb=u+1516|0;bb=u+1496|0;c[lb+(Xa<<5)+24>>2]=(c[bb>>2]|0)+((32-(c[cb>>2]|0)+((c[hb>>2]|0)-(c[gb>>2]|0)<<3)|0)/8|0);c[lb+(Xa<<5)+28>>2]=0;hNb(u,u+1500|0);Xa=c[kb>>2]|0;lb=c[ib>>2]|0;Ya=(c[bb>>2]|0)+((32-(c[cb>>2]|0)+((c[hb>>2]|0)-(c[gb>>2]|0)<<3)|0)/8|0)|0;c[lb+(Xa<<5)+20>>2]=Ya-(c[lb+(Xa<<5)+24>>2]|0);mrc(Ya|0,-1|0,64)|0;Ya=c[u+856>>2]|0;if((Ya|0)!=0){ef[Ya&4095](u,lb+(Xa<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}Xa=(c[kb>>2]|0)+1|0;c[kb>>2]=Xa;lb=u+1484|0;Ya=c[lb>>2]|0;do{if((Xa|0)<(Ya|0)){pb=Xa;qb=c[ib>>2]|0}else{gb=MLb(Ya<<6)|0;if((gb|0)==0){n=-1;i=k;return n|0}else{hb=gb;nrc(gb|0,c[ib>>2]|0,c[lb>>2]<<5)|0;NLb(c[ib>>2]|0);c[ib>>2]=hb;c[lb>>2]=c[lb>>2]<<1;pb=c[kb>>2]|0;qb=hb;break}}}while(0);kb=pb-1|0;lb=c[qb+(kb<<5)+20>>2]|0;do{if((c[u+768>>2]|0)==0){rb=0}else{if((c[u+136>>2]|0)!=0){rb=0;break}rb=(kb|0)!=0|0}}while(0);nb=jb+5+lb-rb|0;ob=c[z>>2]|0}}while(0);do{if((c[ob+124>>2]|0)!=0){if((c[L>>2]|0)==0){break}rb=ob+72|0;jb=c[rb+4>>2]|0;c[b>>2]=c[rb>>2];c[b+4>>2]=jb}}while(0);b=u+136|0;if((c[b>>2]|0)==0){sb=nb;tb=ob}else{ob=u+1480|0;L=c[ob>>2]|0;jb=u+1488|0;rb=c[jb>>2]|0;c[rb+(L<<5)>>2]=0;c[rb+(L<<5)+4>>2]=12;c[rb+(L<<5)+8>>2]=1;c[rb+(L<<5)+20>>2]=0;qb=u+1500|0;pb=u+1504|0;mb=u+1516|0;kb=u+1496|0;c[rb+(L<<5)+24>>2]=(c[kb>>2]|0)+((32-(c[mb>>2]|0)+((c[pb>>2]|0)-(c[qb>>2]|0)<<3)|0)/8|0);c[rb+(L<<5)+28>>2]=0;L=u+1500|0;gNb(u,L,0);rb=c[ob>>2]|0;ib=c[jb>>2]|0;Ya=(c[kb>>2]|0)+((32-(c[mb>>2]|0)+((c[pb>>2]|0)-(c[qb>>2]|0)<<3)|0)/8|0)|0;c[ib+(rb<<5)+20>>2]=Ya-(c[ib+(rb<<5)+24>>2]|0);mrc(Ya|0,-1|0,64)|0;Ya=u+856|0;Xa=c[Ya>>2]|0;if((Xa|0)!=0){ef[Xa&4095](u,ib+(rb<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}rb=(c[ob>>2]|0)+1|0;c[ob>>2]=rb;ib=u+1484|0;Xa=c[ib>>2]|0;do{if((rb|0)<(Xa|0)){ub=rb;vb=c[jb>>2]|0}else{Pa=MLb(Xa<<6)|0;if((Pa|0)==0){n=-1;i=k;return n|0}else{hb=Pa;nrc(Pa|0,c[jb>>2]|0,c[ib>>2]<<5)|0;NLb(c[jb>>2]|0);c[jb>>2]=hb;c[ib>>2]=c[ib>>2]<<1;ub=c[ob>>2]|0;vb=hb;break}}}while(0);Xa=c[vb+(ub-1<<5)+20>>2]|0;c[vb+(ub<<5)>>2]=0;c[vb+(ub<<5)+4>>2]=6;c[vb+(ub<<5)+8>>2]=1;c[vb+(ub<<5)+20>>2]=0;c[vb+(ub<<5)+24>>2]=(c[kb>>2]|0)+((32-(c[mb>>2]|0)+((c[pb>>2]|0)-(c[qb>>2]|0)<<3)|0)/8|0);c[vb+(ub<<5)+28>>2]=0;if((iNb(u,L)|0)<0){n=-1;i=k;return n|0}ub=c[ob>>2]|0;vb=c[jb>>2]|0;rb=(c[kb>>2]|0)+((32-(c[mb>>2]|0)+((c[pb>>2]|0)-(c[qb>>2]|0)<<3)|0)/8|0)|0;c[vb+(ub<<5)+20>>2]=rb-(c[vb+(ub<<5)+24>>2]|0);mrc(rb|0,-1|0,64)|0;rb=c[Ya>>2]|0;if((rb|0)!=0){ef[rb&4095](u,vb+(ub<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}ub=(c[ob>>2]|0)+1|0;c[ob>>2]=ub;vb=c[ib>>2]|0;do{if((ub|0)<(vb|0)){wb=ub;xb=c[jb>>2]|0}else{rb=MLb(vb<<6)|0;if((rb|0)==0){n=-1;i=k;return n|0}else{hb=rb;nrc(rb|0,c[jb>>2]|0,c[ib>>2]<<5)|0;NLb(c[jb>>2]|0);c[jb>>2]=hb;c[ib>>2]=c[ib>>2]<<1;wb=c[ob>>2]|0;xb=hb;break}}}while(0);vb=wb-1|0;ub=c[xb+(vb<<5)+20>>2]|0;hb=u+768|0;do{if((c[hb>>2]|0)==0){yb=0}else{if((c[b>>2]|0)!=0){yb=0;break}yb=(vb|0)!=0|0}}while(0);vb=(c[u+32>>2]|0)==1080;rb=vb?8704:4608;c[xb+(wb<<5)>>2]=0;c[xb+(wb<<5)+4>>2]=6;c[xb+(wb<<5)+8>>2]=1;c[xb+(wb<<5)+20>>2]=0;c[xb+(wb<<5)+24>>2]=(c[kb>>2]|0)+((32-(c[mb>>2]|0)+((c[pb>>2]|0)-(c[qb>>2]|0)<<3)|0)/8|0);c[xb+(wb<<5)+28>>2]=0;if((jNb(u,L,vb?5780:2900)|0)<0){n=-1;i=k;return n|0}vb=c[ob>>2]|0;L=c[jb>>2]|0;wb=(c[kb>>2]|0)+((32-(c[mb>>2]|0)+((c[pb>>2]|0)-(c[qb>>2]|0)<<3)|0)/8|0)|0;c[L+(vb<<5)+20>>2]=wb-(c[L+(vb<<5)+24>>2]|0);mrc(wb|0,-1|0,64)|0;wb=c[Ya>>2]|0;if((wb|0)!=0){ef[wb&4095](u,L+(vb<<5)|0,c[(c[z>>2]|0)+12008>>2]|0)}vb=(c[ob>>2]|0)+1|0;c[ob>>2]=vb;L=c[ib>>2]|0;do{if((vb|0)<(L|0)){zb=vb;Ab=c[jb>>2]|0}else{wb=MLb(L<<6)|0;if((wb|0)==0){n=-1;i=k;return n|0}else{Ya=wb;nrc(wb|0,c[jb>>2]|0,c[ib>>2]<<5)|0;NLb(c[jb>>2]|0);c[jb>>2]=Ya;c[ib>>2]=c[ib>>2]<<1;zb=c[ob>>2]|0;Ab=Ya;break}}}while(0);ib=zb-1|0;zb=rb-(c[Ab+(ib<<5)+20>>2]|0)|0;do{if((c[hb>>2]|0)==0){Bb=-5}else{if((c[b>>2]|0)!=0){Bb=-5;break}Bb=(ib|0)!=0?-4:-5}}while(0);c[Ab+(ib<<5)+28>>2]=zb+Bb;Bb=(c[ob>>2]|0)-1|0;ob=c[Ab+(Bb<<5)+20>>2]|0;zb=c[Ab+(Bb<<5)+28>>2]|0;do{if((c[hb>>2]|0)==0){Cb=0}else{if((c[b>>2]|0)!=0){Cb=0;break}Cb=(Bb|0)!=0|0}}while(0);sb=nb+15+Xa+ub-yb+ob+zb-Cb|0;tb=c[z>>2]|0}HMb(u,c[tb+20>>2]|0,sb<<3);sb=LMb(u)|0;tb=sb+1|0;c[(c[A>>2]|0)+20>>2]=tb;c[j+4>>2]=tb;do{if((c[u+708>>2]|0)!=0){if((c[S>>2]|0)==2){break}CMb(u)|0;dMb(u)}}while(0);if((c[T>>2]|0)!=0){c[(c[A>>2]|0)+144>>2]=c[(c[u+15160>>2]|0)+4>>2]}tb=u+3232|0;Cb=u+8368|0;zb=u+8636|0;do{if((K|0)==5){ob=u+1648|0;jMb(u,tb,Cb,zb,c[ob>>2]|0,c[u+1544>>2]|0,sb);c[ob>>2]=c[ob>>2]^1}else{jMb(u,tb,Cb,zb,-1,c[u+1544>>2]|0,sb);ob=c[T>>2]|0;yb=(ob|0)<1?1:ob;c[u+3304>>2]=yb;ob=c[P>>2]|0;ub=(ob|0)<1?1:ob;c[u+3308>>2]=ub;if((yb|0)==(c[u+8656>>2]|0)){if((c[S>>2]|0)!=1){break}if((ub|0)==(c[u+8660>>2]|0)){break}}c[u+3300>>2]=1}}while(0);do{if((c[(c[z>>2]|0)+16>>2]|0)==4){if((c[u+132>>2]|0)==0){break}if((c[B>>2]|0)==0){break}c[u+8736>>2]=1;nrc(u+8752|0,tb|0,5136)|0}}while(0);tb=c[A>>2]|0;c[tb+112>>2]=c[u+3256>>2];if((c[u+8400>>2]|0)==0){B=c[tb+4>>2]|0;P=u+3276|0;c[P>>2]=B;if((c[u+160>>2]|0)==0){c[u+3280>>2]=0;Db=0}else{sb=(c[u+800>>2]|0)!=0;c[u+3280>>2]=sb?1:-1;zb=sb&1^1;c[P>>2]=zb+B;Db=zb}c[tb+8>>2]=Db;c[tb+12>>2]=(c[u+3280>>2]|0)==1}bPb(u);if((c[S>>2]|0)==1){jPb(u)}tb=l;Db=c[T>>2]|0;if((Db|0)>0){zb=0;do{c[(c[z>>2]|0)+2704+(zb<<2)>>2]=c[(c[u+15160+(zb<<2)>>2]|0)+228>>2];zb=zb+1|0;}while((zb|0)<(Db|0))}c[(c[z>>2]|0)+11956>>2]=0;Db=c[T>>2]|0;zb=u+3260|0;if((Db<<c[zb>>2]|0)>0){B=0;do{c[u+3584+(B*144|0)+44>>2]=0;c[u+3584+(B*144|0)+92>>2]=0;c[u+3584+(B*144|0)+140>>2]=0;B=B+1|0;}while((B|0)<(Db<<c[zb>>2]|0))}do{if((c[S>>2]|0)==0){if((c[u+528>>2]|0)<1){break}B=32<<c[u+160>>2];c[l>>2]=0;c[l+4>>2]=0;P=u+4|0;sb=B<<1;Cb=0;K=0;ub=-1;yb=Db;c:while(1){if((yb|0)>0){ob=(Cb|0)!=0;Xa=ob&1;nb=tb+(Xa<<2)|0;Bb=u+3584+(Xa*48|0)+32|0;Xa=0;b=K;hb=ub;while(1){Ab=c[z>>2]|0;d:do{if((c[Ab+400+(Xa*144|0)+(Cb*48|0)+44>>2]|0)==0){Eb=hb;Fb=b}else{ib=u+3584+(Xa*144|0)+(Cb*48|0)|0;rb=Ab+400+(Xa*144|0)+(Cb*48|0)|0;c[ib>>2]=c[rb>>2];c[ib+4>>2]=c[rb+4>>2];c[ib+8>>2]=c[rb+8>>2];c[ib+12>>2]=c[rb+12>>2];c[ib+16>>2]=c[rb+16>>2];c[ib+20>>2]=c[rb+20>>2];c[ib+24>>2]=c[rb+24>>2];c[ib+28>>2]=c[rb+28>>2];c[ib+32>>2]=c[rb+32>>2];c[ib+36>>2]=c[rb+36>>2];c[ib+40>>2]=c[rb+40>>2];c[ib+44>>2]=c[rb+44>>2];rb=u+3584+(Xa*144|0)+(Cb*48|0)+32|0;ib=c[rb>>2]|0;do{if((c[u+3584+(Xa*144|0)+(Cb*48|0)+36>>2]|0)==(1<<ib|0)){if((c[u+3584+(Xa*144|0)+(Cb*48|0)+40>>2]|0)!=0){break}c[u+3584+(Xa*144|0)+(Cb*48|0)+44>>2]=0;Eb=hb;Fb=b;break d}}while(0);if((c[nb>>2]|0)==0){c[nb>>2]=1;c[Bb>>2]=ib;if((ib|0)<0){Gb=0}else{Gb=(ib|0)>7?7:ib}if((Gb|0)!=(ib|0)){w=385;break c}Hb=ib;Ib=c[rb>>2]|0}else{Hb=hb;Ib=ib}if((Ib|0)!=(Hb|0)){w=387;break c}if(ob){Eb=Ib;Fb=b;break}jb=b+1|0;L=c[z>>2]|0;c[L+2704+(Xa<<2)>>2]=(c[u+19280+(b<<2)>>2]|0)+((ca(c[L+156>>2]|0,B)|0)+32);if((c[P>>2]|0)!=1){Eb=Ib;Fb=jb;break}L=c[u+15160+(Xa<<2)>>2]|0;vb=(c[L+228>>2]|0)+(-32-(ca(c[L+156>>2]|0,B)|0))|0;L=c[z>>2]|0;Ya=c[L+156>>2]|0;wb=(c[L+2704+(Xa<<2)>>2]|0)+(-32-(ca(Ya,B)|0))|0;qb=(c[L+180>>2]|0)+sb|0;POb(u,wb,Ya,vb,Ya,(c[L+168>>2]|0)+64|0,qb,u+3584+(Xa*144|0)|0);c[(c[z>>2]|0)+11956>>2]=qb;Eb=Ib;Fb=jb}}while(0);Ab=Xa+1|0;jb=c[T>>2]|0;if((Ab|0)<(jb|0)){Xa=Ab;b=Fb;hb=Eb}else{Jb=Fb;Kb=Eb;Lb=jb;break}}}else{Jb=K;Kb=ub;Lb=yb}hb=Cb+1|0;if((hb|0)<3){Cb=hb;K=Jb;ub=Kb;yb=Lb}else{w=393;break}}if((w|0)==385){Cd(2141016,2302024,2082,2649136);return 0}else if((w|0)==387){Cd(2137816,2302024,2085,2649136);return 0}else if((w|0)==393){yb=(c[tb+4>>2]|0)==0;if((Lb|0)>0&(yb^1)){ub=u+3664|0;K=0;do{Cb=(c[u+3584+(K*144|0)+140>>2]|0)==0;do{if((c[u+3584+(K*144|0)+92>>2]|0)==0){if(Cb){break}c[u+3584+(K*144|0)+84>>2]=1<<c[ub>>2];c[u+3584+(K*144|0)+88>>2]=0}else{if(!Cb){break}c[u+3584+(K*144|0)+132>>2]=1<<c[ub>>2];c[u+3584+(K*144|0)+136>>2]=0}}while(0);K=K+1|0;}while((K|0)<(Lb|0))}if((c[l>>2]|0)==0){c[u+3616>>2]=0}K=u+3664|0;if(yb){c[K>>2]=0;Mb=0}else{Mb=c[K>>2]|0}c[u+3712>>2]=Mb;break}}}while(0);if(N){N=u+1544|0;c[N>>2]=(c[N>>2]|0)+1}c[u+1452>>2]=0;N=u+18564|0;Mb=c[N>>2]|0;c[u+1456>>2]=Mb;e:do{if((c[C>>2]|0)>1){c[u+1440>>2]=1}else{if((c[x>>2]|0)!=0){l=u+4|0;Lb=c[l>>2]|0;if((Lb|0)>0){tb=u+160|0;Kb=u+844|0;Jb=u+18560|0;Eb=u;Fb=f;T=0;Ib=Lb;do{Lb=c[u+860+(T<<2)>>2]|0;if((T|0)==0){Nb=Ib}else{nrc(Lb|0,Eb|0,860)|0;nrc(Lb+1540|0,Fb|0,28956)|0;Nb=c[l>>2]|0}z=c[tb>>2]|0;Hb=c[N>>2]>>z;Gb=ca(Hb,T)|0;Db=((Gb+((c[Kb>>2]|0)/2|0)|0)/(Nb|0)|0)<<z;c[Lb+1452>>2]=Db;T=T+1|0;z=ca(Hb,T)|0;Hb=((((c[Kb>>2]|0)/2|0)+z|0)/(c[l>>2]|0)|0)<<c[tb>>2];c[Lb+1456>>2]=Hb;c[Lb+3244>>2]=ca(c[Jb>>2]|0,Db)|0;c[Lb+3248>>2]=(ca(c[Jb>>2]|0,Hb)|0)-1;Ib=c[l>>2]|0;}while((T|0)<(Ib|0));Ob=c[N>>2]|0}else{Ob=Mb}dUb(u,(Ob<<4)+16|0);RMb(u);do{if((c[l>>2]|0)>0){Ib=0;do{T=c[u+860+(Ib<<2)>>2]|0;c[T+1448>>2]=Ib;c[T+1440>>2]=1;EOb(T,0);Ib=Ib+1|0;Pb=c[l>>2]|0;}while((Ib|0)<(Pb|0));if((Pb|0)>0){Qb=0}else{break}do{FOb(c[u+860+(Qb<<2)>>2]|0,1);Qb=Qb+1|0;}while((Qb|0)<(c[l>>2]|0))}}while(0);SMb(u);if((c[l>>2]|0)<=1){break}Ib=u+30504|0;T=u+31216|0;Jb=u+31224|0;tb=u+1480|0;Kb=u+1488|0;Fb=u+1484|0;Eb=u+31192|0;yb=u+31200|0;Hb=u+31208|0;Lb=1;while(1){Db=c[u+860+(Lb<<2)>>2]|0;z=Db+1480|0;if((c[z>>2]|0)>0){Gb=Db+1488|0;S=0;do{nrc((c[Kb>>2]|0)+(c[tb>>2]<<5)|0,(c[Gb>>2]|0)+(S<<5)|0,32)|0;K=(c[tb>>2]|0)+1|0;c[tb>>2]=K;ub=c[Fb>>2]|0;do{if((K|0)>=(ub|0)){Cb=MLb(ub<<6)|0;if((Cb|0)==0){break}nrc(Cb|0,c[Kb>>2]|0,c[Fb>>2]<<5)|0;NLb(c[Kb>>2]|0);c[Kb>>2]=Cb;c[Fb>>2]=c[Fb>>2]<<1}}while(0);S=S+1|0;}while((S|0)<(c[z>>2]|0))}z=Db+30504|0;S=0;do{Gb=Ib+(S<<2)|0;c[Gb>>2]=(c[Gb>>2]|0)+(c[z+(S<<2)>>2]|0);S=S+1|0;}while(S>>>0<172>>>0);S=Db+31192|0;z=wrc(c[Eb>>2]|0,c[Eb+4>>2]|0,c[S>>2]|0,c[S+4>>2]|0)|0;c[Eb>>2]=z;c[Eb+4>>2]=G;z=Db+31200|0;S=wrc(c[yb>>2]|0,c[yb+4>>2]|0,c[z>>2]|0,c[z+4>>2]|0)|0;c[yb>>2]=S;c[yb+4>>2]=G;S=Db+31208|0;z=wrc(c[Hb>>2]|0,c[Hb+4>>2]|0,c[S>>2]|0,c[S+4>>2]|0)|0;c[Hb>>2]=z;c[Hb+4>>2]=G;h[T>>3]=+h[Db+31216>>3]+ +h[T>>3];c[Jb>>2]=(c[Jb>>2]|0)+(c[Db+31224>>2]|0);Lb=Lb+1|0;if((Lb|0)>=(c[l>>2]|0)){break e}}}l=u+3248|0;Lb=c[l>>2]|0;mrc(u+30504|0,0,728)|0;c[u+19384>>2]=0;Jb=u+3244|0;T=u+18580|0;if(((ca(c[T>>2]|0,c[zb>>2]|0)|0)+(c[Jb>>2]|0)|0)>(Lb|0)){break}Hb=u+836|0;yb=u+844|0;Eb=u+160|0;Ib=u+18560|0;Fb=u+840|0;Kb=0;while(1){c[l>>2]=Lb;if((Kb|0)==0){w=437}else{if((GOb(u,c[A>>2]|0)|0)==0){w=437}else{Rb=Kb}}do{if((w|0)==437){w=0;tb=c[Hb>>2]|0;if((tb|0)==0){z=c[yb>>2]|0;if((z|0)==0){Rb=Kb;break}if((c[x>>2]|0)!=0){Rb=Kb;break}S=c[Eb>>2]|0;Gb=Kb+1|0;c[l>>2]=(ca(((ca(c[N>>2]>>S,Gb)|0)+((z|0)/2|0)|0)/(z|0)|0,c[Ib>>2]<<S)|0)-1;Rb=Gb;break}Gb=c[Jb>>2]|0;do{if((c[zb>>2]|0)==0){S=tb-1+Gb|0;c[l>>2]=S;if((S|0)>=(Lb|0)){break}z=c[Fb>>2]|0;if((Lb-S|0)>=(z|0)){break}c[l>>2]=Lb-z}else{z=c[Ib>>2]|0;S=(Gb|0)%(z|0)|0;ub=tb-1+Gb-S+(S<<1)|0;S=z<<1;c[l>>2]=(ca(((ub|0)/(S|0)|0)<<1|1,c[T>>2]|0)|0)+(((ub|0)%(S|0)|0|0)/2|0)}}while(0);Rb=Kb+1|0}}while(0);Db=c[l>>2]|0;c[l>>2]=(Db|0)<(Lb|0)?Db:Lb;if((hMb(u)|0)!=0){break}Db=(c[l>>2]|0)+1|0;c[Jb>>2]=Db;Gb=c[zb>>2]|0;do{if((Gb|0)==0){Sb=Db}else{if(((Db|0)%(c[Ib>>2]|0)|0|0)==0){Sb=Db;break}tb=Db-(c[T>>2]|0)|0;c[Jb>>2]=tb;Sb=tb}}while(0);if(((ca(c[T>>2]|0,Gb)|0)+Sb|0)>(Lb|0)){break e}else{Kb=Rb}}if((c[x>>2]|0)==0){n=-1;i=k;return n|0}EOb(u,2);n=-1;i=k;return n|0}}while(0);n=bMb(v,u,d,e,j)|0;i=k;return n|0}function bMb(b,e,f,j,k){b=b|0;e=e|0;f=f|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ba=0.0,da=0.0,ea=0.0,fa=0.0,ga=0.0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;l=i;i=i+120|0;m=l|0;n=l+80|0;o=l+112|0;p=b+12|0;do{if((c[p>>2]|0)==0){q=b+1440|0;if((c[q>>2]|0)==0){break}c[q>>2]=0}}while(0);q=b+1480|0;if((c[q>>2]|0)==0){c[k>>2]=0;r=0;i=l;return r|0}do{if((c[b+1548>>2]|0)>1){s=b+15144|0;if((c[(c[s>>2]|0)+124>>2]|0)==0){break}if((c[b+8536>>2]|0)==0){break}QMb(b);t=c[q>>2]|0;u=b+1488|0;v=c[u>>2]|0;c[v+(t<<5)>>2]=0;c[v+(t<<5)+4>>2]=6;c[v+(t<<5)+8>>2]=1;c[v+(t<<5)+20>>2]=0;w=b+1500|0;x=b+1504|0;y=b+1516|0;z=b+1496|0;c[v+(t<<5)+24>>2]=(c[z>>2]|0)+((32-(c[y>>2]|0)+((c[x>>2]|0)-(c[w>>2]|0)<<3)|0)/8|0);c[v+(t<<5)+28>>2]=0;dNb(b,b+1500|0);t=c[q>>2]|0;v=c[u>>2]|0;A=(c[z>>2]|0)+((32-(c[y>>2]|0)+((c[x>>2]|0)-(c[w>>2]|0)<<3)|0)/8|0)|0;c[v+(t<<5)+20>>2]=A-(c[v+(t<<5)+24>>2]|0);mrc(A|0,-1|0,64)|0;A=c[b+856>>2]|0;if((A|0)!=0){ef[A&4095](b,v+(t<<5)|0,c[(c[s>>2]|0)+12008>>2]|0)}s=(c[q>>2]|0)+1|0;c[q>>2]=s;t=b+1484|0;v=c[t>>2]|0;do{if((s|0)<(v|0)){B=c[u>>2]|0}else{A=MLb(v<<6)|0;if((A|0)==0){r=-1;i=l;return r|0}else{w=A;nrc(A|0,c[u>>2]|0,c[t>>2]<<5)|0;NLb(c[u>>2]|0);c[u>>2]=w;c[t>>2]=c[t>>2]<<1;B=w;break}}}while(0);t=0;while(1){C=t+1|0;if(((c[B+(t<<5)+4>>2]|0)-7|0)>>>0<3>>>0){t=C}else{break}}v=c[q>>2]|0;s=n;nrc(s|0,B+(v-1<<5)|0,32)|0;orc(B+(C<<5)|0,B+(t<<5)|0,(v-t<<5)-32|0)|0;nrc((c[u>>2]|0)+(t<<5)|0,s|0,32)|0}}while(0);B=$Lb(b,0)|0;if((B|0)<0){r=-1;i=l;return r|0}C=b+15144|0;n=c[C>>2]|0;c[k>>2]=c[n+16>>2];c[k+12>>2]=c[n+124>>2];c[k+8>>2]=c[n+120>>2];s=b+15148|0;v=c[s>>2]|0;w=v+24|0;A=c[w>>2]|0;x=c[w+4>>2]|0;w=k+16|0;c[w>>2]=A;c[w+4>>2]=x;w=v+32|0;v=c[w>>2]|0;y=c[w+4>>2]|0;w=k+24|0;c[w>>2]=v;c[w+4>>2]=y;if((x|0)<(y|0)|(x|0)==(y|0)&A>>>0<v>>>0){ILb(b,1,2159672,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=c[C>>2]|0}else{E=n}c[k+188>>2]=c[E+12008>>2];E=c[s>>2]|0;c[k+36>>2]=c[E+148>>2];n=c[E+152>>2]|0;v=k+40|0;c[v>>2]=n;a:do{if((n|0)>0){A=0;y=E;while(1){c[k+44+(A<<2)>>2]=c[y+156+(A<<2)>>2];c[k+60+(A<<2)>>2]=c[y+204+(A<<2)>>2];x=A+1|0;if((x|0)>=(c[v>>2]|0)){break a}A=x;y=c[s>>2]|0}}}while(0);LOb(e,c[C>>2]|0);c[o>>2]=0;if((PMb(b,B<<3,o)|0)<0){r=-1;i=l;return r|0}v=k+144|0;E=(c[C>>2]|0)+8640|0;c[v>>2]=c[E>>2];c[v+4>>2]=c[E+4>>2];c[v+8>>2]=c[E+8>>2];c[v+12>>2]=c[E+12>>2];c[v+16>>2]=c[E+16>>2];c[v+20>>2]=c[E+20>>2];c[v+24>>2]=c[E+24>>2];c[v+28>>2]=c[E+28>>2];h[k+136>>3]=+g[(c[s>>2]|0)+140>>2];if((c[b+136>>2]|0)==0){E=c[o>>2]|0;b:do{if((E|0)>0){v=b+768|0;n=b+832|0;y=b+1488|0;A=b+1500|0;t=b+1504|0;u=b+1516|0;x=b+1496|0;w=b+1500|0;z=b+856|0;F=b+1484|0;H=E;I=B;while(1){J=6-(c[v>>2]|0)|0;K=c[n>>2]|0;if((K|0)!=0&(H|0)>(K|0)){L=K-H+J|0;M=K-J+((L|0)>0?-L|0:0)|0}else{L=H-J|0;M=(L|0)<0?0:L}if((gMb(b,M+32|0,0,-1)|0)!=0){r=-1;N=108;break}L=c[q>>2]|0;J=c[y>>2]|0;c[J+(L<<5)>>2]=0;c[J+(L<<5)+4>>2]=12;c[J+(L<<5)+8>>2]=1;c[J+(L<<5)+20>>2]=0;c[J+(L<<5)+24>>2]=(c[x>>2]|0)+((32-(c[u>>2]|0)+((c[t>>2]|0)-(c[A>>2]|0)<<3)|0)/8|0);c[J+(L<<5)+28>>2]=0;gNb(b,w,M);L=c[q>>2]|0;J=c[y>>2]|0;K=(c[x>>2]|0)+((32-(c[u>>2]|0)+((c[t>>2]|0)-(c[A>>2]|0)<<3)|0)/8|0)|0;c[J+(L<<5)+20>>2]=K-(c[J+(L<<5)+24>>2]|0);mrc(K|0,-1|0,64)|0;K=c[z>>2]|0;if((K|0)!=0){ef[K&4095](b,J+(L<<5)|0,c[(c[C>>2]|0)+12008>>2]|0)}L=(c[q>>2]|0)+1|0;c[q>>2]=L;J=c[F>>2]|0;if((L|0)<(J|0)){O=L}else{L=MLb(J<<6)|0;if((L|0)==0){r=-1;N=108;break}nrc(L|0,c[y>>2]|0,c[F>>2]<<5)|0;NLb(c[y>>2]|0);c[y>>2]=L;c[F>>2]=c[F>>2]<<1;O=c[q>>2]|0}L=$Lb(b,O-1|0)|0;if((L|0)<0){r=-1;N=108;break}J=L+I|0;K=(c[o>>2]|0)-L|0;c[o>>2]=K;if((K|0)>0){H=K;I=J}else{P=J;Q=y;break b}}if((N|0)==108){i=l;return r|0}}else{P=B;Q=b+1488|0}}while(0);R=P;S=c[Q>>2]|0;T=b+860|0}else{Q=b+860|0;P=c[Q>>2]|0;O=c[q>>2]|0;M=c[o>>2]|0;E=M+B|0;y=P+1528|0;if((c[y>>2]|0)<(E|0)){I=E<<1;E=MLb(I)|0;if((E|0)==0){r=-1;i=l;return r|0}H=P+1524|0;if((B|0)!=0){nrc(E|0,c[H>>2]|0,B)|0}P=c[H>>2]|0;F=E-P|0;if((O|0)>0){z=b+1488|0;A=0;do{t=(c[z>>2]|0)+(A<<5)+24|0;c[t>>2]=(c[t>>2]|0)+F;A=A+1|0;}while((A|0)<(O|0));U=c[H>>2]|0}else{U=P}NLb(U);c[H>>2]=E;c[y>>2]=I;V=c[o>>2]|0}else{V=M}M=b+1488|0;mrc((c[(c[M>>2]|0)+24>>2]|0)+B|0,0,V|0)|0;V=c[M>>2]|0;M=V+((c[q>>2]|0)-1<<5)+20|0;c[M>>2]=(c[M>>2]|0)+(c[o>>2]|0);c[V+((c[q>>2]|0)-1<<5)+28>>2]=c[o>>2];R=(c[o>>2]|0)+B|0;S=V;T=Q}c[j>>2]=c[q>>2];c[f>>2]=S;c[q>>2]=0;wMb(b);q=c[T>>2]|0;if((q|0)!=(b|0)){nrc(b+31232|0,q+31232|0,2584)|0}q=b+3240|0;S=b+31232+(c[q>>2]<<2)|0;c[S>>2]=(c[S>>2]|0)+1;S=b+31248+(c[q>>2]<<3)|0;f=wrc(c[S>>2]|0,c[S+4>>2]|0,R,(R|0)<0|0?-1:0)|0;c[S>>2]=f;c[S+4>>2]=G;S=b+31272+(c[q>>2]<<3)|0;h[S>>3]=+g[(c[s>>2]|0)+136>>2]+ +h[S>>3];S=0;while(1){f=c[b+30516+(S<<2)>>2]|0;j=b+31536+((c[q>>2]|0)*152|0)+(S<<3)|0;Q=wrc(c[j>>2]|0,c[j+4>>2]|0,f,(f|0)<0|0?-1:0)|0;c[j>>2]=Q;c[j+4>>2]=G;j=S+1|0;if((j|0)<19){S=j}else{W=0;break}}do{S=c[b+30868+(W<<2)>>2]|0;j=b+31992+((c[q>>2]|0)*136|0)+(W<<3)|0;Q=wrc(c[j>>2]|0,c[j+4>>2]|0,S,(S|0)<0|0?-1:0)|0;c[j>>2]=Q;c[j+4>>2]=G;W=W+1|0;}while((W|0)<17);W=c[b+30604>>2]|0;j=b+32264|0;Q=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=Q;c[j+4>>2]=G;j=c[b+30608>>2]|0;Q=b+32272|0;W=wrc(c[Q>>2]|0,c[Q+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[Q>>2]=W;c[Q+4>>2]=G;Q=c[b+30936>>2]|0;W=b+33304|0;j=wrc(c[W>>2]|0,c[W+4>>2]|0,Q,(Q|0)<0|0?-1:0)|0;c[W>>2]=j;c[W+4>>2]=G;W=c[b+30940>>2]|0;j=b+33312|0;Q=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=Q;c[j+4>>2]=G;j=c[b+30944>>2]|0;Q=b+33320|0;W=wrc(c[Q>>2]|0,c[Q+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[Q>>2]=W;c[Q+4>>2]=G;Q=c[b+30948>>2]|0;W=b+33328|0;j=wrc(c[W>>2]|0,c[W+4>>2]|0,Q,(Q|0)<0|0?-1:0)|0;c[W>>2]=j;c[W+4>>2]=G;W=c[b+30952>>2]|0;j=b+33336|0;Q=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=Q;c[j+4>>2]=G;j=c[b+30956>>2]|0;Q=b+33344|0;W=wrc(c[Q>>2]|0,c[Q+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[Q>>2]=W;c[Q+4>>2]=G;Q=0;do{W=c[b+30960+(Q*52|0)>>2]|0;j=b+33352+(Q*104|0)|0;S=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=S;c[j+4>>2]=G;j=c[b+30960+(Q*52|0)+4>>2]|0;S=b+33352+(Q*104|0)+8|0;W=wrc(c[S>>2]|0,c[S+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[S>>2]=W;c[S+4>>2]=G;S=c[b+30960+(Q*52|0)+8>>2]|0;W=b+33352+(Q*104|0)+16|0;j=wrc(c[W>>2]|0,c[W+4>>2]|0,S,(S|0)<0|0?-1:0)|0;c[W>>2]=j;c[W+4>>2]=G;W=c[b+30960+(Q*52|0)+12>>2]|0;j=b+33352+(Q*104|0)+24|0;S=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=S;c[j+4>>2]=G;j=c[b+30960+(Q*52|0)+16>>2]|0;S=b+33352+(Q*104|0)+32|0;W=wrc(c[S>>2]|0,c[S+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[S>>2]=W;c[S+4>>2]=G;S=c[b+30960+(Q*52|0)+20>>2]|0;W=b+33352+(Q*104|0)+40|0;j=wrc(c[W>>2]|0,c[W+4>>2]|0,S,(S|0)<0|0?-1:0)|0;c[W>>2]=j;c[W+4>>2]=G;W=c[b+30960+(Q*52|0)+24>>2]|0;j=b+33352+(Q*104|0)+48|0;S=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=S;c[j+4>>2]=G;j=c[b+30960+(Q*52|0)+28>>2]|0;S=b+33352+(Q*104|0)+56|0;W=wrc(c[S>>2]|0,c[S+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[S>>2]=W;c[S+4>>2]=G;S=c[b+30960+(Q*52|0)+32>>2]|0;W=b+33352+(Q*104|0)+64|0;j=wrc(c[W>>2]|0,c[W+4>>2]|0,S,(S|0)<0|0?-1:0)|0;c[W>>2]=j;c[W+4>>2]=G;W=c[b+30960+(Q*52|0)+36>>2]|0;j=b+33352+(Q*104|0)+72|0;S=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=S;c[j+4>>2]=G;j=c[b+30960+(Q*52|0)+40>>2]|0;S=b+33352+(Q*104|0)+80|0;W=wrc(c[S>>2]|0,c[S+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[S>>2]=W;c[S+4>>2]=G;S=c[b+30960+(Q*52|0)+44>>2]|0;W=b+33352+(Q*104|0)+88|0;j=wrc(c[W>>2]|0,c[W+4>>2]|0,S,(S|0)<0|0?-1:0)|0;c[W>>2]=j;c[W+4>>2]=G;W=c[b+30960+(Q*52|0)+48>>2]|0;j=b+33352+(Q*104|0)+96|0;S=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=S;c[j+4>>2]=G;Q=Q+1|0;}while((Q|0)<4);Q=c[q>>2]|0;if((Q|0)==2){X=2}else{j=0;S=Q;while(1){Q=c[b+30612+(j<<2)>>2]|0;W=b+32280+(S<<9)+(j<<3)|0;f=wrc(c[W>>2]|0,c[W+4>>2]|0,Q,(Q|0)<0|0?-1:0)|0;c[W>>2]=f;c[W+4>>2]=G;W=j+1|0;if((W|0)>=32){Y=0;break}j=W;S=c[q>>2]|0}do{S=c[b+30740+(Y<<2)>>2]|0;j=b+32280+(c[q>>2]<<9)+256+(Y<<3)|0;W=wrc(c[j>>2]|0,c[j+4>>2]|0,S,(S|0)<0|0?-1:0)|0;c[j>>2]=W;c[j+4>>2]=G;Y=Y+1|0;}while((Y|0)<32);X=c[q>>2]|0}Y=c[b+31168>>2]|0;j=b+33768|0;W=wrc(c[j>>2]|0,c[j+4>>2]|0,Y,(Y|0)<0|0?-1:0)|0;c[j>>2]=W;c[j+4>>2]=G;j=c[b+31172>>2]|0;W=b+33776|0;Y=wrc(c[W>>2]|0,c[W+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[W>>2]=Y;c[W+4>>2]=G;W=c[b+31176>>2]|0;Y=b+33784|0;j=wrc(c[Y>>2]|0,c[Y+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[Y>>2]=j;c[Y+4>>2]=G;do{if((X|0)==0){if((c[b+528>>2]|0)<=0){N=70;break}Y=b+33808|0;c[Y>>2]=((c[b+3628>>2]|0)!=0)+(c[Y>>2]|0);if((c[b+3676>>2]|0)==0){Z=(c[b+3724>>2]|0)!=0|0}else{Z=1}Y=b+33812|0;c[Y>>2]=(c[Y>>2]|0)+Z;if((X|0)==1){N=66}else{N=70}}else if((X|0)==1){N=66}else{N=70}}while(0);do{if((N|0)==66){X=b+33800+(c[b+3296>>2]<<2)|0;c[X>>2]=(c[X>>2]|0)+1;if((c[b+28844>>2]|0)==0){break}X=b+33792|0;Z=c[X>>2]|0;Y=b+33796|0;j=c[Y>>2]|0;if((j+Z|0)>(c[b+18568>>2]|0)){W=(Z*9|0|0)/10|0;c[X>>2]=W;S=(j*9|0|0)/10|0;c[Y>>2]=S;_=W;$=S}else{_=Z;$=j}c[X>>2]=_+(c[b+31180>>2]|0);c[Y>>2]=$+(c[b+31184>>2]|0)}else if((N|0)==70){Y=b+31296+((d[(c[C>>2]|0)+130|0]|0)<<2)|0;c[Y>>2]=(c[Y>>2]|0)+1}}while(0);N=m|0;a[N]=0;aa=+g[(c[C>>2]|0)+56>>2];C=b+31512+(c[q>>2]<<3)|0;h[C>>3]=aa+ +h[C>>3];if((c[b+616>>2]|0)!=0){C=b+31192|0;$=c[C>>2]|0;_=c[C+4>>2]|0;C=b+31200|0;Y=c[C>>2]|0;X=c[C+4>>2]|0;C=b+31208|0;j=c[C>>2]|0;Z=c[C+4>>2]|0;C=ca(c[b+32>>2]|0,c[b+28>>2]|0)|0;S=C>>(c[b+18576>>2]|0)+(c[b+18572>>2]|0);ba=(+($>>>0)+ +(_|0)*4294967296.0)/(+(C|0)*65025.0);if(ba>1.0e-10){da=+fd(+ba)*-10.0}else{da=100.0}W=k+112|0;h[W>>3]=da;da=+(S|0)*65025.0;ba=(+(Y>>>0)+ +(X|0)*4294967296.0)/da;if(ba>1.0e-10){ea=+fd(+ba)*-10.0}else{ea=100.0}f=k+120|0;h[f>>3]=ea;ea=(+(j>>>0)+ +(Z|0)*4294967296.0)/da;if(ea>1.0e-10){fa=+fd(+ea)*-10.0}else{fa=100.0}Q=k+128|0;h[Q>>3]=fa;V=wrc(Y,X,$,_)|0;_=wrc(V,G,j,Z)|0;fa=+(_>>>0)+ +(G|0)*4294967296.0;ea=fa/(+((S<<1)+C|0)*65025.0);if(ea>1.0e-10){ga=+fd(+ea)*-10.0}else{ga=100.0}C=k+104|0;h[C>>3]=ga;S=b+31368+(c[q>>2]<<3)|0;h[S>>3]=aa*fa+ +h[S>>3];S=b+31392+(c[q>>2]<<3)|0;h[S>>3]=aa*+h[C>>3]+ +h[S>>3];S=b+31416+(c[q>>2]<<3)|0;h[S>>3]=aa*+h[W>>3]+ +h[S>>3];S=b+31440+(c[q>>2]<<3)|0;h[S>>3]=aa*+h[f>>3]+ +h[S>>3];S=b+31464+(c[q>>2]<<3)|0;h[S>>3]=aa*+h[Q>>3]+ +h[S>>3];fa=+h[f>>3];ga=+h[Q>>3];Rb(N|0,80,2157760,(D=i,i=i+24|0,h[D>>3]=+h[W>>3],h[D+8>>3]=fa,h[D+16>>3]=ga,D)|0)|0;i=D}if((c[b+620>>2]|0)!=0){ga=+h[b+31216>>3]/+(c[b+31224>>2]|0);W=k+96|0;h[W>>3]=ga;k=b+31488+(c[q>>2]<<3)|0;h[k>>3]=aa*ga+ +h[k>>3];k=lrc(N|0)|0;Rb(m+k|0,80-k|0,2156048,(D=i,i=i+8|0,h[D>>3]=+h[W>>3],D)|0)|0;i=D}a[m+79|0]=0;m=c[s>>2]|0;ga=+g[m+136>>2];W=c[b+1556>>2]|0;k=c[q>>2]|0;if((k|0)==2){ha=73}else{ha=(k|0)==0?80:66}k=c[m+4>>2]|0;m=c[b+30592>>2]|0;q=c[b+30596>>2]|0;Q=c[b+30600>>2]|0;ILb(b,3,2154328,(D=i,i=i+80|0,c[D>>2]=c[b+1540>>2],h[D+8>>3]=ga,c[D+16>>2]=W,c[D+24>>2]=ha,c[D+32>>2]=k,c[D+40>>2]=m,c[D+48>>2]=q,c[D+56>>2]=Q,c[D+64>>2]=R,c[D+72>>2]=N,D)|0);i=D;D=c[T>>2]|0;if((D|0)!=(b|0)){nrc(D+31232|0,b+31232|0,2584)|0}if((e|0)!=(b|0)){nrc(e+31232|0,b+31232|0,2584)|0}e=b+15152|0;D=c[e>>2]|0;if((D|0)>0){T=0;N=D;while(1){D=b+15160+(T<<2)|0;Q=c[D>>2]|0;do{if((Q|0)==0){ia=N}else{if((c[Q+2768>>2]|0)==0){ia=N;break}NOb(b,Q);c[D>>2]=0;ia=c[e>>2]|0}}while(0);D=T+1|0;if((D|0)<(ia|0)){T=D;N=ia}else{break}}}ia=c[b+512>>2]|0;if((ia|0)==0){r=R;i=l;return r|0}N=Qc(ia|0,2152568)|0;if((N|0)==0){r=R;i=l;return r|0}do{if((c[p>>2]|0)!=0){ia=b+4|0;T=c[ia>>2]|0;if((T|0)>0){ja=0;ka=T}else{break}while(1){T=(c[b+860+(ja<<2)>>2]|0)+1440|0;if((c[T>>2]|0)==0){la=ka}else{c[T>>2]=0;la=c[ia>>2]|0}T=ja+1|0;if((T|0)<(la|0)){ja=T;ka=la}else{break}}}}while(0);la=b+32|0;ka=b+28|0;ja=ca(c[ka>>2]|0,c[la>>2]|0)|0;p=b+18576|0;Rd(N|0,ca((ja>>>(((c[p>>2]|0)+(c[b+18572>>2]|0)|0)>>>0)<<1)+ja|0,c[(c[s>>2]|0)+92>>2]|0)|0,0)|0;ja=b+8632|0;ia=0;T=c[la>>2]|0;while(1){if((T|0)>0){e=0;while(1){D=c[s>>2]|0;Q=ca(c[D+156+(ia<<2)>>2]|0,e)|0;ub((c[D+204+(ia<<2)>>2]|0)+Q|0,1,c[ka>>2]|0,N|0)|0;Q=e+1|0;D=c[la>>2]|0;if((Q|0)<(D|0)){e=Q}else{ma=D;break}}}else{ma=T}e=ia+1|0;na=(c[ja>>2]|0)==3;if((e|0)<((na?3:1)|0)){ia=e;T=ma}else{break}}if(!na){na=c[ka>>2]>>1;ka=ma>>c[p>>2];p=ca(ka,na)|0;ma=MLb((p<<1)+32|0)|0;T=ma+(p+16)|0;ia=c[s>>2]|0;Ge[c[b+37488>>2]&255](ma,na,T,na,c[ia+208>>2]|0,c[ia+160>>2]|0,na,ka);ub(ma|0,1,p|0,N|0)|0;ub(T|0,1,p|0,N|0)|0;NLb(ma)}nb(N|0)|0;r=R;i=l;return r|0}function cMb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[a+14960>>2]|0;d=c[b>>2]|0;a:do{if((d|0)==0){e=0}else{f=a+8620|0;g=0;h=0;i=d;while(1){if((c[i+16>>2]|0)!=5){e=g;break a}j=(c[i+96>>2]|0)!=((c[f>>2]|0)+(c[i+92>>2]|0)|0)|g;k=h+1|0;l=c[b+(k<<2)>>2]|0;if((l|0)==0){e=j;break}else{g=j;h=k;i=l}}}}while(0);b=a+124|0;d=c[b>>2]|0;do{if((d|0)!=1&(e|0)==0){if(!((c[a+15056>>2]|0)==-1)){m=0;n=d;break}return}else{m=0;n=d}}while(0);while(1){d=a+14976+(m<<2)|0;e=c[d>>2]|0;if((e|0)==0){break}if((n|0)==1){if((c[e+16>>2]|0)==4){o=12}else{o=10}}else{o=10}do{if((o|0)==10){o=0;if((c[e+4>>2]|0)>=(c[a+15056>>2]|0)){p=m;q=n;break}if((c[a+3240>>2]|0)==1){p=m;q=n}else{o=12}}}while(0);if((o|0)==12){o=0;i=a+8196|0;h=c[i>>2]|0;c[a+8200+(h<<3)>>2]=(c[a+1544>>2]|0)-(c[e+112>>2]|0);g=c[(c[d>>2]|0)+4>>2]|0;c[i>>2]=h+1;c[a+8200+(h<<3)+4>>2]=g;LOb(a,KOb(d)|0);c[a+15320>>2]=1;p=m-1|0;q=c[b>>2]|0}m=p+1|0;n=q}if((n|0)==0){return}n=m+2-(c[a+15064>>2]|0)|0;c[a+8192>>2]=(n|0)>0?n:0;return}function dMb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=0;while(1){d=c[a+14976+(b<<2)>>2]|0;if((d|0)==0){break}if((c[d+11992>>2]|0)==0){b=b+1|0}else{e=5;break}}if((e|0)==5){c[a+15320>>2]=1;return}b=a+3240|0;d=0;a:while(1){f=(c[a+15152+(d<<2)>>2]|0)-1|0;b:do{if((f|0)>0){g=(d|0)==1;if((c[b>>2]|0)==0){if(g){h=0;while(1){i=h+1|0;if(((c[(c[a+15236+(i<<2)>>2]|0)+112>>2]|0)-(c[(c[a+15236+(h<<2)>>2]|0)+112>>2]|0)|0)>0){j=1;break a}if((i|0)<(f|0)){h=i}else{break b}}}else{h=0;while(1){i=h+1|0;if(((c[(c[a+15160+(d*76|0)+(i<<2)>>2]|0)+112>>2]|0)-(c[(c[a+15160+(d*76|0)+(h<<2)>>2]|0)+112>>2]|0)|0)>0){j=d;break a}if((i|0)<(f|0)){h=i}else{break b}}}}if(g){h=0;i=c[(c[a+15236>>2]|0)+4>>2]|0;while(1){k=h+1|0;l=c[(c[a+15236+(k<<2)>>2]|0)+4>>2]|0;if((l-i|0)<0){j=1;break a}if((k|0)<(f|0)){h=k;i=l}else{break}}}else{i=0;h=c[(c[a+15160+(d*76|0)>>2]|0)+4>>2]|0;while(1){g=i+1|0;l=c[(c[a+15160+(d*76|0)+(g<<2)>>2]|0)+4>>2]|0;if((l-h|0)>0){j=d;break a}if((g|0)<(f|0)){i=g;h=l}else{break}}}}}while(0);f=d+1|0;if((f|0)>((c[b>>2]|0)==1|0)){e=22;break}else{d=f}}if((e|0)==22){return}c[a+15320+(j<<2)>>2]=1;return}function eMb(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0.0,ga=0.0,ha=0.0,ia=0,ja=0,ka=0,la=0,ma=0,na=0.0,oa=0.0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;e=i;i=i+656|0;f=e|0;g=e+112|0;j=e+312|0;k=e+336|0;l=e+624|0;m=ca(c[b+32>>2]|0,c[b+28>>2]|0)|0;n=(m>>(c[b+18576>>2]|0)+(c[b+18572>>2]|0)<<1)+m|0;mrc(f|0,0,112)|0;m=b+31536|0;o=b+31840|0;p=b+31864|0;do{if((c[p>>2]|0)==0&(c[p+4>>2]|0)==0){q=b+31560|0;if(!((c[q>>2]|0)==0&(c[q+4>>2]|0)==0)){r=1;break}q=b+31712|0;r=((c[q>>2]|0)!=0|(c[q+4>>2]|0)!=0)&1}else{r=1}}while(0);lMb(b);mQb(b);q=c[b+38028>>2]|0;do{if((c[b+12>>2]|0)!=0){s=b+4|0;t=c[s>>2]|0;if((t|0)>0){u=0;v=t}else{break}while(1){t=(c[b+860+(u<<2)>>2]|0)+1440|0;if((c[t>>2]|0)==0){w=v}else{c[t>>2]=0;w=c[s>>2]|0}t=u+1|0;if((t|0)<(w|0)){u=t;v=w}else{break}}}}while(0);w=b+1548|0;v=c[w>>2]|0;do{if((v|0)>1){u=0;s=v;while(1){t=c[b+860+(u<<2)>>2]|0;if((c[t+1440>>2]|0)==0){x=s}else{y=c[t+15144>>2]|0;if((c[y+11960>>2]|0)!=1){z=13;break}uOb(y);x=c[w>>2]|0}y=u+1|0;if((y|0)<(x|0)){u=y;s=x}else{z=16;break}}if((z|0)==13){Cd(2307656,2302024,3974,2649584)}else if((z|0)==16){s=c[b+860+(c[b+1444>>2]<<2)>>2]|0;TMb(b,s,b);TMb(s,s,b);u=(c[s+1540>>2]|0)+1-(c[w>>2]|0)|0;c[b+1540>>2]=u;A=u;break}}else{A=c[b+1540>>2]|0}}while(0);c[b+1540>>2]=A+1;A=b+616|0;B=+(n|0);n=0;do{x=d[97848+n|0]|0;v=c[b+31232+(x<<2)>>2]|0;do{if((v|0)>0){C=+h[b+31512+(x<<3)>>3];u=a[564416+x|0]|0;D=+(v|0);E=+h[b+31272+(x<<3)>>3]/D;s=b+31248+(x<<3)|0;F=(+((c[s>>2]|0)>>>0)+ +(c[s+4>>2]|0)*4294967296.0)/D;if((c[A>>2]|0)==0){ILb(b,2,2284424,(H=i,i=i+32|0,c[H>>2]=u,c[H+8>>2]=v,h[H+16>>3]=E,h[H+24>>3]=F,H)|0);i=H;break}D=+h[b+31416+(x<<3)>>3]/C;I=+h[b+31440+(x<<3)>>3]/C;J=+h[b+31464+(x<<3)>>3]/C;K=+h[b+31392+(x<<3)>>3]/C;L=+h[b+31368+(x<<3)>>3]/(B*C*65025.0);if(L>1.0e-10){M=+fd(+L)*-10.0}else{M=100.0}ILb(b,2,2290832,(H=i,i=i+72|0,c[H>>2]=u,c[H+8>>2]=v,h[H+16>>3]=E,h[H+24>>3]=F,h[H+32>>3]=D,h[H+40>>3]=I,h[H+48>>3]=J,h[H+56>>3]=K,h[H+64>>3]=M,H)|0);i=H}}while(0);n=n+1|0;}while((n|0)<3);n=b+112|0;v=c[n>>2]|0;do{if((v|0)==0){N=0}else{if((c[b+31236>>2]|0)==0){N=0;break}x=g|0;u=(v|0)<0;do{if(!u){s=0;y=0;while(1){t=s+1|0;O=(ca(c[b+31296+(s<<2)>>2]|0,t)|0)+y|0;if((t|0)>(v|0)){break}else{s=t;y=O}}M=+(O|0);if(u){break}else{P=0;Q=x}while(1){y=P+1|0;s=gc(Q|0,2280712,(H=i,i=i+8|0,h[H>>3]=+(y|0)*100.0*+(c[b+31296+(P<<2)>>2]|0)/M,H)|0)|0;i=H;if((y|0)>(c[n>>2]|0)){break}else{P=y;Q=Q+s|0}}}}while(0);ILb(b,2,2276440,(H=i,i=i+8|0,c[H>>2]=x,H)|0);i=H;N=0}}while(0);while(1){if((N|0)==12){N=N+1|0;continue}else{Q=b+31992+(N<<3)|0;P=f+(d[95192+N|0]<<3)|0;n=wrc(c[P>>2]|0,c[P+4>>2]|0,c[Q>>2]|0,c[Q+4>>2]|0)|0;c[P>>2]=n;c[P+4>>2]=G;P=N+1|0;if((P|0)<17){N=P;continue}else{R=0;break}}}while(1){if((R|0)==12){R=R+1|0;continue}else{N=b+32128+(R<<3)|0;P=f+56+(d[95192+R|0]<<3)|0;n=wrc(c[P>>2]|0,c[P+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;c[P>>2]=n;c[P+4>>2]=G;P=R+1|0;if((P|0)<17){R=P;continue}else{break}}}R=b+31240|0;P=c[R>>2]|0;if((P|0)>0){n=o|0;M=+(ca(c[b+18568>>2]|0,P)|0)/100.0;P=g|0;N=(r|0)!=0;Q=b+31856|0;K=(+((c[Q>>2]|0)>>>0)+ +(c[Q+4>>2]|0)*4294967296.0)/M;Q=b+31848|0;J=(+((c[Q>>2]|0)>>>0)+ +(c[Q+4>>2]|0)*4294967296.0)/M;I=(+((c[n>>2]|0)>>>0)+ +(c[n+4>>2]|0)*4294967296.0)/M;n=gc(P|0,2167576,(H=i,i=i+32|0,c[H>>2]=N?2163816:10230080,h[H+8>>3]=K,h[H+16>>3]=J,h[H+24>>3]=I,H)|0)|0;i=H;if(N){gc(g+n|0,2280712,(H=i,i=i+8|0,h[H>>3]=(+((c[p>>2]|0)>>>0)+ +(c[p+4>>2]|0)*4294967296.0)/M,H)|0)|0;i=H}ILb(b,2,2272056,(H=i,i=i+8|0,c[H>>2]=P,H)|0);i=H}P=b+31232|0;n=c[P>>2]|0;if((n|0)>0){N=m|0;M=+(ca(c[b+18568>>2]|0,n)|0)/100.0;n=f|0;Q=g|0;O=(r|0)!=0;v=b+31552|0;I=(+((c[v>>2]|0)>>>0)+ +(c[v+4>>2]|0)*4294967296.0)/M;v=b+31544|0;J=(+((c[v>>2]|0)>>>0)+ +(c[v+4>>2]|0)*4294967296.0)/M;K=(+((c[N>>2]|0)>>>0)+ +(c[N+4>>2]|0)*4294967296.0)/M;N=gc(Q|0,2167576,(H=i,i=i+32|0,c[H>>2]=O?2163816:10230080,h[H+8>>3]=I,h[H+16>>3]=J,h[H+24>>3]=K,H)|0)|0;i=H;if(O){O=b+31560|0;gc(g+N|0,2280712,(H=i,i=i+8|0,h[H>>3]=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)/M,H)|0)|0;i=H}K=M*4.0;J=(+((c[n>>2]|0)>>>0)+ +(c[n+4>>2]|0)*4294967296.0)/K;n=f+8|0;O=f+16|0;N=wrc(c[O>>2]|0,c[O+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0)|0;I=(+(N>>>0)+ +(G|0)*4294967296.0)/K;N=f+24|0;D=(+((c[N>>2]|0)>>>0)+ +(c[N+4>>2]|0)*4294967296.0)/K;N=f+32|0;n=f+40|0;O=wrc(c[n>>2]|0,c[n+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;F=(+(O>>>0)+ +(G|0)*4294967296.0)/K;O=f+48|0;E=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)/K;O=b+31584|0;K=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)/M;ILb(b,2,2267184,(H=i,i=i+56|0,c[H>>2]=Q,h[H+8>>3]=J,h[H+16>>3]=I,h[H+24>>3]=D,h[H+32>>3]=F,h[H+40>>3]=E,h[H+48>>3]=K,H)|0);i=H}Q=b+31236|0;O=c[Q>>2]|0;if((O|0)>0){N=b+31688|0;K=+(ca(c[b+18568>>2]|0,O)|0)/100.0;O=f+56|0;mrc(j|0,0,24)|0;n=g|0;v=(r|0)!=0;r=b+31704|0;E=(+((c[r>>2]|0)>>>0)+ +(c[r+4>>2]|0)*4294967296.0)/K;r=b+31696|0;F=(+((c[r>>2]|0)>>>0)+ +(c[r+4>>2]|0)*4294967296.0)/K;D=(+((c[N>>2]|0)>>>0)+ +(c[N+4>>2]|0)*4294967296.0)/K;N=gc(n|0,2167576,(H=i,i=i+32|0,c[H>>2]=v?2163816:10230080,h[H+8>>3]=E,h[H+16>>3]=F,h[H+24>>3]=D,H)|0)|0;i=H;if(v){v=b+31712|0;gc(g+N|0,2280712,(H=i,i=i+8|0,h[H>>3]=(+((c[v>>2]|0)>>>0)+ +(c[v+4>>2]|0)*4294967296.0)/K,H)|0)|0;i=H;S=0}else{S=0}do{v=b+31688+(S<<3)|0;N=a[95e3+(S<<2)|0]|0;r=a[95002+(S<<2)|0]|0;u=r&255;if(!((r|N)<<24>>24==0)){r=c[v>>2]|0;s=j+((ca(u,N&255)|0)+u<<3)|0;u=wrc(c[s>>2]|0,c[s+4>>2]|0,r<<1|0>>>31,c[v+4>>2]<<1|r>>>31)|0;c[s>>2]=u;c[s+4>>2]=G}s=a[95001+(S<<2)|0]|0;u=a[95003+(S<<2)|0]|0;r=u&255;if(!((u|s)<<24>>24==0)){u=c[v>>2]|0;N=j+((ca(r,s&255)|0)+r<<3)|0;r=wrc(c[N>>2]|0,c[N+4>>2]|0,u<<1|0>>>31,c[v+4>>2]<<1|u>>>31)|0;c[N>>2]=r;c[N+4>>2]=G}S=S+1|0;}while((S|0)<17);S=b+32152|0;N=j|0;r=wrc(c[N>>2]|0,c[N+4>>2]|0,c[S>>2]|0,c[S+4>>2]|0)|0;S=G;c[N>>2]=r;c[N+4>>2]=S;N=b+32184|0;u=j+8|0;v=wrc(c[u>>2]|0,c[u+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;N=G;c[u>>2]=v;c[u+4>>2]=N;u=b+32216|0;s=j+16|0;j=wrc(c[s>>2]|0,c[s+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;u=G;c[s>>2]=j;c[s+4>>2]=u;s=b+32224|0;y=wrc(c[s>>2]|0,c[s+4>>2]|0,2,0)|0;s=Crc(y,G,4,0)|0;y=b+31744|0;t=wrc(c[y>>2]|0,c[y+4>>2]|0,s,G)|0;s=G;c[y>>2]=t;c[y+4>>2]=s;y=wrc(v,N,r,S)|0;T=wrc(y,G,j,u)|0;D=(+(T>>>0)+ +(G|0)*4294967296.0)/100.0;T=g+(lrc(n|0)|0)|0;F=K*4.0;E=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)/F;O=f+64|0;y=f+72|0;U=wrc(c[y>>2]|0,c[y+4>>2]|0,c[O>>2]|0,c[O+4>>2]|0)|0;I=(+(U>>>0)+ +(G|0)*4294967296.0)/F;U=f+80|0;J=(+((c[U>>2]|0)>>>0)+ +(c[U+4>>2]|0)*4294967296.0)/F;U=b+31832|0;F=(+((c[U>>2]|0)>>>0)+ +(c[U+4>>2]|0)*4294967296.0)/K;gc(T|0,2263648,(H=i,i=i+40|0,h[H>>3]=E,h[H+8>>3]=I,h[H+16>>3]=J,h[H+24>>3]=(+(t>>>0)+ +(s|0)*4294967296.0)/K,h[H+32>>3]=F,H)|0)|0;i=H;if(D!=0.0){gc(g+(lrc(n|0)|0)|0,2259720,(H=i,i=i+24|0,h[H>>3]=(+(r>>>0)+ +(S|0)*4294967296.0)/D,h[H+8>>3]=(+(v>>>0)+ +(N|0)*4294967296.0)/D,h[H+16>>3]=(+(j>>>0)+ +(u|0)*4294967296.0)/D,H)|0)|0;i=H}ILb(b,2,2255424,(H=i,i=i+8|0,c[H>>2]=n,H)|0);i=H}FMb(b);n=(c[P>>2]|0)+(c[R>>2]|0)+(c[Q>>2]|0)|0;do{if((n|0)>0){R=b+31848|0;u=b+31544|0;j=wrc(c[u>>2]|0,c[u+4>>2]|0,c[R>>2]|0,c[R+4>>2]|0)|0;R=b+31696|0;u=wrc(j,G,c[R>>2]|0,c[R+4>>2]|0)|0;R=G;j=o|0;N=m|0;v=c[N>>2]|0;S=c[N+4>>2]|0;N=b+31688|0;r=c[N>>2]|0;s=c[N+4>>2]|0;N=b+31856|0;t=c[N>>2]|0;T=c[N+4>>2]|0;N=b+31552|0;U=c[N>>2]|0;f=c[N+4>>2]|0;N=b+31704|0;O=c[N>>2]|0;y=c[N+4>>2]|0;N=wrc(u,R,c[j>>2]|0,c[j+4>>2]|0)|0;j=wrc(N,G,v,S)|0;S=wrc(j,G,r,s)|0;s=wrc(S,G,t,T)|0;T=wrc(s,G,U,f)|0;f=wrc(T,G,O,y)|0;y=G;O=b+31560|0;T=c[O>>2]|0;U=c[O+4>>2]|0;O=b+31712|0;s=c[O>>2]|0;t=c[O+4>>2]|0;O=wrc(f,y,c[p>>2]|0,c[p+4>>2]|0)|0;S=wrc(O,G,T,U)|0;U=wrc(S,G,s,t)|0;t=G;s=b+31888|0;S=b+31584|0;T=b+31736|0;O=c[T>>2]|0;r=c[T+4>>2]|0;T=b+31984|0;j=c[T>>2]|0;v=c[T+4>>2]|0;T=b+31680|0;N=c[T>>2]|0;V=c[T+4>>2]|0;T=b+31832|0;W=c[T>>2]|0;X=c[T+4>>2]|0;T=wrc(c[S>>2]|0,c[S+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;s=wrc(T,G,O,r)|0;r=wrc(s,G,j,v)|0;v=wrc(r,G,N,V)|0;V=wrc(v,G,W,X)|0;X=G;W=c[b+18568>>2]|0;v=Erc(W,(W|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;W=G;N=xrc(v,W,V,X)|0;r=G;j=xrc(N,r,f,y)|0;s=G;D=+h[b+31528>>3]+ +h[b+31512>>3]+ +h[b+31520>>3];O=b+31264|0;T=b+31248|0;S=wrc(c[T>>2]|0,c[T+4>>2]|0,c[O>>2]|0,c[O+4>>2]|0)|0;O=b+31256|0;T=wrc(S,G,c[O>>2]|0,c[O+4>>2]|0)|0;F=(+(T>>>0)+ +(G|0)*4294967296.0)/D/125.0;if((c[b+160>>2]|0)!=0){T=g|0;a[T]=0;if((N|0)==(f|0)&(r|0)==(y|0)){Y=T}else{r=b+33776|0;N=gc(T|0,2250496,(H=i,i=i+8|0,h[H>>3]=(+((c[r>>2]|0)>>>0)+ +(c[r+4>>2]|0)*4294967296.0)*100.0/(+(j>>>0)+ +(s|0)*4294967296.0),H)|0)|0;i=H;Y=g+N|0}if(!((V|0)==0&(X|0)==0)){N=b+33784|0;gc(Y|0,2240184,(H=i,i=i+8|0,h[H>>3]=(+((c[N>>2]|0)>>>0)+ +(c[N+4>>2]|0)*4294967296.0)*100.0/(+(V>>>0)+ +(X|0)*4294967296.0),H)|0)|0;i=H}X=b+33768|0;ILb(b,2,2234904,(H=i,i=i+16|0,h[H>>3]=(+((c[X>>2]|0)>>>0)+ +(c[X+4>>2]|0)*4294967296.0)*100.0/(+(f>>>0)+ +(y|0)*4294967296.0),c[H+8>>2]=T,H)|0);i=H}if((c[b+8696>>2]|0)!=0){T=g|0;a[T]=0;X=b+32264|0;V=c[X>>2]|0;N=c[X+4>>2]|0;if(!((V|0)==0&(N|0)==0)){X=b+32272|0;gc(T|0,2250496,(H=i,i=i+8|0,h[H>>3]=(+((c[X>>2]|0)>>>0)+ +(c[X+4>>2]|0)*4294967296.0)*100.0/(+(V>>>0)+ +(N|0)*4294967296.0),H)|0)|0;i=H}ILb(b,2,2231216,(H=i,i=i+16|0,h[H>>3]=(+(u>>>0)+ +(R|0)*4294967296.0)*100.0/(+(f>>>0)+ +(y|0)*4294967296.0),c[H+8>>2]=T,H)|0);i=H}do{if((c[b+536>>2]|0)==3){z=65}else{if((c[b+33800>>2]|0)==0){break}if((c[b+33804>>2]|0)!=0){z=65}}}while(0);do{if((z|0)==65){x=c[Q>>2]|0;if((x|0)==0){break}K=+(x|0);J=+(c[b+33800>>2]|0)*100.0/K;ILb(b,2,2227400,(H=i,i=i+16|0,h[H>>3]=+(c[b+33804>>2]|0)*100.0/K,h[H+8>>3]=J,H)|0);i=H}}while(0);x=g|0;a[x]=0;T=b+8632|0;y=c[T>>2]|0;f=(y|0)==3?4:1;if((v|0)==(U|0)&(W|0)==(t|0)){Z=y;_=0;$=f}else{y=b+33312|0;J=(+((c[y>>2]|0)>>>0)+ +(c[y+4>>2]|0)*4294967296.0)*100.0;y=xrc(v,W,U,t)|0;R=G;u=b+33328|0;K=(+((c[u>>2]|0)>>>0)+ +(c[u+4>>2]|0)*4294967296.0)*100.0;u=f;f=0;N=Erc(u,f,y,R)|0;I=+(N>>>0)+ +(G|0)*4294967296.0;N=b+33344|0;E=(+((c[N>>2]|0)>>>0)+ +(c[N+4>>2]|0)*4294967296.0)*100.0/I;gc(x|0,2222768,(H=i,i=i+24|0,h[H>>3]=J/(+((y<<2|0>>>30)>>>0)+ +(R<<2|y>>>30|0)*4294967296.0),h[H+8>>3]=K/I,h[H+16>>3]=E,H)|0)|0;i=H;Z=c[T>>2]|0;_=f;$=u}u=(Z|0)==3;f=b+33304|0;E=(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)*100.0/(+((U<<2|0>>>30)>>>0)+ +(t<<2|U>>>30|0)*4294967296.0);f=b+33320|0;I=(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)*100.0;f=Erc($,_,U,t)|0;K=+(f>>>0)+ +(G|0)*4294967296.0;f=b+33336|0;J=(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0)*100.0/K;ILb(b,2,2219032,(H=i,i=i+48|0,c[H>>2]=u?2216096:2213496,c[H+8>>2]=u?2211248:2208024,h[H+16>>3]=E,h[H+24>>3]=I/K,h[H+32>>3]=J,c[H+40>>2]=x,H)|0);i=H;mrc(k|0,0,288)|0;mrc(l|0,0,32)|0;u=l|0;f=b+33352|0;y=c[f>>2]|0;R=c[f+4>>2]|0;f=k|0;c[f>>2]=y;c[f+4>>2]=R;f=b+33360|0;N=c[f>>2]|0;V=c[f+4>>2]|0;f=k+8|0;c[f>>2]=N;c[f+4>>2]=V;f=wrc(y,R,N,V)|0;X=b+33368|0;s=c[X>>2]|0;j=c[X+4>>2]|0;X=k+16|0;r=wrc(f,G,s,j)|0;f=b+33376|0;O=c[f>>2]|0;S=c[f+4>>2]|0;f=k+24|0;c[f>>2]=O;c[f+4>>2]=S;f=wrc(r,G,O,S)|0;r=G;aa=b+33384|0;ba=c[aa>>2]|0;da=c[aa+4>>2]|0;aa=wrc(s,j,ba,da)|0;j=G;s=wrc(f,r,ba,da)|0;da=G;ba=b+33392|0;r=c[ba>>2]|0;f=c[ba+4>>2]|0;ba=wrc(aa,j,r,f)|0;j=G;aa=wrc(s,da,r,f)|0;f=G;r=b+33400|0;da=c[r>>2]|0;s=c[r+4>>2]|0;r=wrc(ba,j,da,s)|0;j=G;c[X>>2]=r;c[X+4>>2]=j;X=wrc(aa,f,da,s)|0;s=G;c[u>>2]=X;c[u+4>>2]=s;if((X|0)==0&(s|0)==0){ea=1}else{J=+(X>>>0)+ +(s|0)*4294967296.0;ILb(b,2,2199208,(H=i,i=i+32|0,h[H>>3]=(+(y>>>0)+ +(R|0)*4294967296.0)*100.0/J,h[H+8>>3]=(+(N>>>0)+ +(V|0)*4294967296.0)*100.0/J,h[H+16>>3]=(+(r>>>0)+ +(j|0)*4294967296.0)*100.0/J,h[H+24>>3]=(+(O>>>0)+ +(S|0)*4294967296.0)*100.0/J,H)|0);i=H;ea=1}do{S=l+(ea<<3)|0;O=0;j=c[S+4>>2]|0;r=c[S>>2]|0;do{V=b+33352+(ea*104|0)+(O<<3)|0;N=c[V>>2]|0;R=c[V+4>>2]|0;O=O+1|0;V=k+(ea*72|0)+(a[95152+O|0]<<3)|0;y=wrc(c[V>>2]|0,c[V+4>>2]|0,N,R)|0;c[V>>2]=y;c[V+4>>2]=G;r=wrc(r,j,N,R)|0;j=G;}while((O|0)<12);c[S>>2]=r;c[S+4>>2]=j;if(!((r|0)==0&(j|0)==0)){O=k+(ea*72|0)|0;J=+(r>>>0)+ +(j|0)*4294967296.0;K=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;O=k+(ea*72|0)+8|0;I=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;O=k+(ea*72|0)+16|0;E=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;O=k+(ea*72|0)+24|0;M=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;O=k+(ea*72|0)+32|0;L=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;O=k+(ea*72|0)+40|0;C=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;O=k+(ea*72|0)+48|0;fa=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;O=k+(ea*72|0)+56|0;ga=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;O=k+(ea*72|0)+64|0;ha=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*100.0/J;ILb(b,2,2195104,(H=i,i=i+80|0,c[H>>2]=3-ea<<2,h[H+8>>3]=K,h[H+16>>3]=I,h[H+24>>3]=E,h[H+32>>3]=M,h[H+40>>3]=L,h[H+48>>3]=C,h[H+56>>3]=fa,h[H+64>>3]=ga,h[H+72>>3]=ha,H)|0);i=H}ea=ea+1|0;}while((ea|0)<3);t=l+24|0;U=c[t>>2]|0;W=c[t+4>>2]|0;v=b+33664|0;O=c[v>>2]|0;R=c[v+4>>2]|0;v=k+216|0;N=wrc(c[v>>2]|0,c[v+4>>2]|0,O,R)|0;V=G;y=wrc(U,W,O,R)|0;R=G;O=b+33672|0;W=c[O>>2]|0;U=c[O+4>>2]|0;O=k+224|0;s=wrc(c[O>>2]|0,c[O+4>>2]|0,W,U)|0;X=G;c[O>>2]=s;c[O+4>>2]=X;O=wrc(y,R,W,U)|0;U=G;W=b+33680|0;R=c[W>>2]|0;y=c[W+4>>2]|0;W=k+232|0;u=wrc(c[W>>2]|0,c[W+4>>2]|0,R,y)|0;da=G;c[W>>2]=u;c[W+4>>2]=da;W=wrc(O,U,R,y)|0;y=G;R=b+33688|0;U=c[R>>2]|0;O=c[R+4>>2]|0;R=k+240|0;f=wrc(c[R>>2]|0,c[R+4>>2]|0,U,O)|0;aa=G;c[R>>2]=f;c[R+4>>2]=aa;R=wrc(W,y,U,O)|0;O=G;U=b+33696|0;y=c[U>>2]|0;W=c[U+4>>2]|0;U=wrc(N,V,y,W)|0;V=G;N=wrc(R,O,y,W)|0;W=G;y=b+33704|0;O=c[y>>2]|0;R=c[y+4>>2]|0;y=wrc(U,V,O,R)|0;V=G;U=wrc(N,W,O,R)|0;R=G;O=b+33712|0;W=c[O>>2]|0;N=c[O+4>>2]|0;O=wrc(y,V,W,N)|0;V=G;c[v>>2]=O;c[v+4>>2]=V;v=wrc(U,R,W,N)|0;N=G;c[t>>2]=v;c[t+4>>2]=N;do{if(!((v|0)==0&(N|0)==0)){if((c[T>>2]|0)==3){break}ha=+(v>>>0)+ +(N|0)*4294967296.0;ILb(b,2,2192672,(H=i,i=i+32|0,h[H>>3]=(+(O>>>0)+ +(V|0)*4294967296.0)*100.0/ha,h[H+8>>3]=(+(s>>>0)+ +(X|0)*4294967296.0)*100.0/ha,h[H+16>>3]=(+(u>>>0)+ +(da|0)*4294967296.0)*100.0/ha,h[H+24>>3]=(+(f>>>0)+ +(aa|0)*4294967296.0)*100.0/ha,H)|0);i=H}}while(0);do{if((c[b+528>>2]|0)>0){aa=c[P>>2]|0;if((aa|0)<=0){ia=0;break}ha=+(aa|0);ga=+(c[b+33812>>2]|0)*100.0/ha;ILb(b,2,2190168,(H=i,i=i+16|0,h[H>>3]=+(c[b+33808>>2]|0)*100.0/ha,h[H+8>>3]=ga,H)|0);i=H;ia=0}else{ia=0}}while(0);do{aa=0;f=0;da=0;u=0;do{X=b+32280+(ia<<8)+(u<<3)|0;s=c[X>>2]|0;V=c[X+4>>2]|0;f=wrc(s,V,f,aa)|0;aa=G;da=(s|0)==0&(V|0)==0?da:u;u=u+1|0;}while((u|0)<32);if((da|0)==0){ja=0;ka=0;la=0;ma=0}else{if((da|0)>=0){ga=+(f>>>0)+ +(aa|0)*4294967296.0;u=x;j=0;while(1){r=b+32280+(ia<<8)+(j<<3)|0;S=gc(u|0,2280712,(H=i,i=i+8|0,h[H>>3]=(+((c[r>>2]|0)>>>0)+ +(c[r+4>>2]|0)*4294967296.0)*100.0/ga,H)|0)|0;i=H;r=j+1|0;if((r|0)>(da|0)){break}else{u=u+S|0;j=r}}}ILb(b,2,2187656,(H=i,i=i+24|0,c[H>>2]=80,c[H+8>>2]=ia,c[H+16>>2]=x,H)|0);i=H;ja=0;ka=0;la=0;ma=0}do{j=b+32792+(ia<<8)+(ma<<3)|0;u=c[j>>2]|0;da=c[j+4>>2]|0;ka=wrc(u,da,ka,ja)|0;ja=G;la=(u|0)==0&(da|0)==0?la:ma;ma=ma+1|0;}while((ma|0)<32);if((la|0)!=0){if((la|0)>=0){ga=+(ka>>>0)+ +(ja|0)*4294967296.0;da=x;u=0;while(1){j=b+32792+(ia<<8)+(u<<3)|0;aa=gc(da|0,2280712,(H=i,i=i+8|0,h[H>>3]=(+((c[j>>2]|0)>>>0)+ +(c[j+4>>2]|0)*4294967296.0)*100.0/ga,H)|0)|0;i=H;j=u+1|0;if((j|0)>(la|0)){break}else{da=da+aa|0;u=j}}}ILb(b,2,2187656,(H=i,i=i+24|0,c[H>>2]=66,c[H+8>>2]=ia,c[H+16>>2]=x,H)|0);i=H}ia=ia+1|0;}while((ia|0)<2);if((c[b+620>>2]|0)!=0){ga=(+h[b+31504>>3]+ +h[b+31488>>3]+ +h[b+31496>>3])/D;ha=1.0-ga;if(ha>1.0e-10){na=+fd(+ha)*-10.0}else{na=100.0}ILb(b,2,2182800,(H=i,i=i+16|0,h[H>>3]=ga,h[H+8>>3]=na,H)|0);i=H}if((c[A>>2]|0)==0){ILb(b,2,2178520,(H=i,i=i+8|0,h[H>>3]=F,H)|0);i=H;break}ga=(+h[b+31432>>3]+ +h[b+31416>>3]+ +h[b+31424>>3])/D;ha=(+h[b+31456>>3]+ +h[b+31440>>3]+ +h[b+31448>>3])/D;fa=(+h[b+31480>>3]+ +h[b+31464>>3]+ +h[b+31472>>3])/D;C=(+h[b+31408>>3]+ +h[b+31392>>3]+ +h[b+31400>>3])/D;L=(+h[b+31384>>3]+ +h[b+31368>>3]+ +h[b+31376>>3])/(B*D*65025.0);if(L>1.0e-10){oa=+fd(+L)*-10.0}else{oa=100.0}ILb(b,2,2180784,(H=i,i=i+48|0,h[H>>3]=ga,h[H+8>>3]=ha,h[H+16>>3]=fa,h[H+24>>3]=C,h[H+32>>3]=oa,h[H+40>>3]=F,H)|0);i=H}}while(0);GMb(b);H=c[b+704>>2]|0;if((H|0)!=0){Qqc(H)}H=c[b+712>>2]|0;if((H|0)!=0){Qqc(H)}OTb(b);NLb(c[b+1524>>2]|0);NLb(c[b+1532>>2]|0);cUb(b);if((c[w>>2]|0)>1){pa=c[b+860+(c[b+1444>>2]<<2)>>2]|0}else{pa=b}QOb(c[pa+14964>>2]|0);QOb(c[pa+14968>>2]|0);QOb(c[pa+14960>>2]|0);QOb(c[pa+14972>>2]|0);b=c[pa+860>>2]|0;pa=b+1548|0;w=c[pa>>2]|0;if((w|0)>0){H=0;A=w;while(1){w=b+860+(H<<2)|0;ia=c[w>>2]|0;do{if((c[ia+1440>>2]|0)==0){qa=A}else{if((c[ia+15152>>2]|0)>0){ra=0;sa=ia}else{qa=A;break}while(1){la=c[sa+15160+(ra<<2)>>2]|0;do{if((la|0)==0){ta=sa}else{if((c[la+2768>>2]|0)==0){ta=sa;break}uOb(la);ta=c[w>>2]|0}}while(0);la=ra+1|0;if((la|0)<(c[ta+15152>>2]|0)){ra=la;sa=ta}else{break}}qa=c[pa>>2]|0}}while(0);w=H+1|0;if((w|0)<(qa|0)){H=w;A=qa}else{break}}}qa=b+8|0;if((c[qa>>2]|0)>1){A=0;do{NLb(c[b+1376+(A<<2)>>2]|0);A=A+1|0;}while((A|0)<(c[qa>>2]|0))}qa=c[b+4>>2]|0;if((qa|0)<=0){jQb(q);i=e;return}A=b+12|0;H=qa;a:while(1){qa=H-1|0;pa=b+860+(qa<<2)|0;if((c[A>>2]|0)==0|(qa|0)==0){ta=c[pa>>2]|0;sa=ta+14976|0;ra=c[sa>>2]|0;if((ra|0)==0){ua=ta}else{ta=sa;sa=ra;do{ra=sa+11960|0;w=c[ra>>2]|0;if((w|0)<=0){z=121;break a}ia=w-1|0;c[ra>>2]=ia;if((ia|0)==0){uOb(sa)}ta=ta+4|0;sa=c[ta>>2]|0;}while((sa|0)!=0);ua=c[pa>>2]|0}sa=c[ua+15148>>2]|0;do{if((sa|0)==0){va=ua}else{ta=sa+11960|0;ia=c[ta>>2]|0;if((ia|0)<=0){z=128;break a}ra=ia-1|0;c[ta>>2]=ra;if((ra|0)!=0){va=ua;break}uOb(sa);va=c[pa>>2]|0}}while(0);_Ob(va)}aPb(c[pa>>2]|0,0);NLb(c[(c[pa>>2]|0)+1496>>2]|0);NLb(c[(c[pa>>2]|0)+1488>>2]|0);NLb(c[pa>>2]|0);if((qa|0)>0){H=qa}else{z=133;break}}if((z|0)==121){Cd(2175560,2302024,4291,2649584)}else if((z|0)==128){Cd(2175560,2302024,4299,2649584)}else if((z|0)==133){jQb(q);i=e;return}}function fMb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+1548>>2]|0;if((b|0)>1){d=0;e=0;do{d=(c[(c[a+860+(e<<2)>>2]|0)+1440>>2]|0)+d|0;e=e+1|0;}while((e|0)<(b|0));f=d;g=c[a+860+(c[a+1444>>2]<<2)>>2]|0}else{f=0;g=a}a=c[g+14960>>2]|0;if((c[a>>2]|0)==0){h=f}else{d=f;f=0;while(1){b=d+1|0;e=f+1|0;if((c[a+(e<<2)>>2]|0)==0){h=b;break}else{d=b;f=e}}}f=c[g+38024>>2]|0;return(c[f+28>>2]|0)+h+(c[f+52>>2]|0)+(c[f+76>>2]|0)|0}function gMb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d|0)==0){f=3}else{if(((c[a+13912>>2]|0)-(c[a+13908>>2]|0)|0)>=(b|0)){f=3}}do{if((f|0)==3){if(((c[a+1508>>2]|0)-(c[a+1504>>2]|0)|0)<(b|0)){break}else{g=0}return g|0}}while(0);f=a+1492|0;d=(c[f>>2]|0)+b|0;b=MLb(d)|0;if((b|0)==0){g=-1;return g|0}h=c[f>>2]&-16;i=a+1496|0;Ee[c[a+37520>>2]&511](b,c[i>>2]|0,h)|0;nrc(b+h|0,(c[i>>2]|0)+h|0,(c[f>>2]|0)-h|0)|0;h=c[i>>2]|0;j=b-h|0;k=a+1500|0;c[k>>2]=(c[k>>2]|0)+j;k=a+1504|0;c[k>>2]=(c[k>>2]|0)+j;k=b+d|0;c[a+1508>>2]=k;l=a+13904|0;c[l>>2]=(c[l>>2]|0)+j;l=a+13908|0;c[l>>2]=(c[l>>2]|0)+j;c[a+13912>>2]=k;if((e|0)<0){m=h}else{h=a+1488|0;a=0;do{k=(c[h>>2]|0)+(a<<5)+24|0;c[k>>2]=(c[k>>2]|0)+j;a=a+1|0;}while((a|0)<=(e|0));m=c[i>>2]|0}NLb(m);c[i>>2]=b;c[f>>2]=d;g=0;return g|0}function hMb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0;f=i;i=i+1992|0;g=f|0;h=f+24|0;j=f+56|0;k=f+80|0;l=f+112|0;m=f+136|0;n=f+168|0;o=f+192|0;p=f+1264|0;if((c[e+768>>2]|0)==0){q=-11}else{q=(c[e+1480>>2]|0)!=0?-10:-11}r=e+152|0;s=c[e+832>>2]|0;t=c[r>>2]|0;if((s|0)>0){u=q+s-t<<3}else{u=0}if((t|0)==0){v=(c[e+8372>>2]|0)<100}else{v=0}t=v|(u|0)!=0;s=e+1500|0;q=s|0;w=e+1504|0;x=c[w>>2]|0;y=e+1516|0;z=c[y>>2]|0;A=x;B=c[q>>2]|0;C=A-B<<3;D=e+3232|0;E=e+8348|0;F=(c[E>>2]|0)!=1|0;G=e+15148|0;H=e+3248|0;I=c[H>>2]|0;J=e+1456|0;K=e+18560|0;L=ca(c[K>>2]|0,c[J>>2]|0)|0;M=L-1|0;do{if((c[(c[G>>2]|0)+116>>2]|0)==0){if((c[e+508>>2]|0)!=0){N=1;break}N=(c[e+512>>2]|0)!=0|0}else{N=1}}while(0);O=N&F;F=A&3;if((F|0)==0){P=x}else{A=x+(-F|0)|0;c[w>>2]=A;x=4-F<<3;c[y>>2]=x;c[e+1512>>2]=(je(c[A>>2]|0)|0)>>>(x>>>0);P=A}A=c[e+1552>>2]|0;x=e+1556|0;F=e+1480|0;N=c[F>>2]|0;Q=e+1488|0;R=c[Q>>2]|0;c[R+(N<<5)>>2]=c[x>>2];c[R+(N<<5)+4>>2]=A;c[R+(N<<5)+8>>2]=1;c[R+(N<<5)+20>>2]=0;A=e+1500|0;S=e+1496|0;c[R+(N<<5)+24>>2]=(c[S>>2]|0)+((32-(c[y>>2]|0)+(P-B<<3)|0)/8|0);c[R+(N<<5)+28>>2]=0;N=e+3244|0;c[(c[Q>>2]|0)+(c[F>>2]<<5)+12>>2]=c[N>>2];cPb(e);c[e+18616>>2]=c[N>>2];R=MMb(e)|0;B=e+8332|0;P=(R|0)<51?R:51;c[B>>2]=P;R=e+8336|0;c[R>>2]=P-(c[e+8672>>2]|0);P=c[x>>2]|0;x=e+3260|0;T=c[N>>2]|0;do{if((c[x>>2]|0)==0){U=T+1|0;V=(U|0)>65535;W=V?32:0;X=V?U>>16:U;if((X|0)>255){Y=X>>8;Z=W|16}else{Y=X;Z=W}W=(d[16976+Y|0]|0)+Z>>1;X=c[y>>2]|0;V=e+1512|0;_=c[V>>2]|0;if((X|0)>(W|0)){$=_<<W;c[V>>2]=$;aa=X;ba=$}else{$=je(_<<X|0)|0;c[c[w>>2]>>2]=$;c[w>>2]=(c[w>>2]|0)+4;c[V>>2]=0;aa=X+32|0;ba=0}X=aa-W|0;c[y>>2]=X;$=W+1|0;if((X|0)>($|0)){W=ba<<$|U;c[V>>2]=W;da=W;ea=X-$|0;break}else{W=$-X|0;$=je(U>>>(W>>>0)|ba<<X|0)|0;c[c[w>>2]>>2]=$;c[w>>2]=(c[w>>2]|0)+4;c[V>>2]=U;da=U;ea=32-W|0;break}}else{W=c[(c[D>>2]|0)+48>>2]|0;U=(T|0)/(W|0)|0;if((U&1|0)!=0){Cd(2147896,2302024,207,2649184);return 0}V=((((T|0)%(W|0)|0)<<1)+(ca(U&-2,W)|0)>>1)+1|0;W=(V|0)>65535;U=W?32:0;$=W?V>>16:V;if(($|0)>255){fa=$>>8;ga=U|16}else{fa=$;ga=U}U=(d[16976+fa|0]|0)+ga>>1;$=c[y>>2]|0;W=e+1512|0;X=c[W>>2]|0;if(($|0)>(U|0)){_=X<<U;c[W>>2]=_;ha=$;ia=_}else{_=je(X<<$|0)|0;c[c[w>>2]>>2]=_;c[w>>2]=(c[w>>2]|0)+4;c[W>>2]=0;ha=$+32|0;ia=0}$=ha-U|0;c[y>>2]=$;_=U+1|0;if(($|0)>(_|0)){U=ia<<_|V;c[W>>2]=U;da=U;ea=$-_|0;break}else{U=_-$|0;_=je(V>>>(U>>>0)|ia<<$|0)|0;c[c[w>>2]>>2]=_;c[w>>2]=(c[w>>2]|0)+4;c[W>>2]=V;da=V;ea=32-U|0;break}}}while(0);c[y>>2]=ea;ia=e+3240|0;ha=(c[ia>>2]|0)+6|0;ga=(ha|0)>65535;fa=ga?32:0;T=ga?ha>>16:ha;if((T|0)>255){ja=T>>8;ka=fa|16}else{ja=T;ka=fa}fa=(d[16976+ja|0]|0)+ka>>1;ka=e+1512|0;if((ea|0)>(fa|0)){ja=da<<fa;c[ka>>2]=ja;la=ea;ma=ja}else{ja=je(da<<ea|0)|0;c[c[w>>2]>>2]=ja;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;la=ea+32|0;ma=0}ea=la-fa|0;c[y>>2]=ea;la=fa+1|0;if((ea|0)>(la|0)){fa=ma<<la|ha;c[ka>>2]=fa;na=ea-la|0;oa=fa}else{fa=la-ea|0;la=je(ha>>>(fa>>>0)|ma<<ea|0)|0;c[c[w>>2]>>2]=la;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=ha;na=32-fa|0;oa=ha}c[y>>2]=na;ha=(c[e+3252>>2]|0)+1|0;fa=(ha|0)>65535;la=fa?32:0;ea=fa?ha>>16:ha;if((ea|0)>255){pa=ea>>8;qa=la|16}else{pa=ea;qa=la}la=(d[16976+pa|0]|0)+qa>>1;if((na|0)>(la|0)){qa=oa<<la;c[ka>>2]=qa;ra=na;sa=qa}else{qa=je(oa<<na|0)|0;c[c[w>>2]>>2]=qa;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;ra=na+32|0;sa=0}na=ra-la|0;c[y>>2]=na;ra=la+1|0;if((na|0)>(ra|0)){la=sa<<ra|ha;c[ka>>2]=la;ta=na-ra|0;ua=la}else{la=ra-na|0;ra=je(ha>>>(la>>>0)|sa<<na|0)|0;c[c[w>>2]>>2]=ra;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=ha;ta=32-la|0;ua=ha}c[y>>2]=ta;ha=D|0;D=c[ha>>2]|0;la=c[D+28>>2]|0;ra=(1<<la)-1&c[e+3256>>2];if((ta|0)>(la|0)){na=ra|ua<<la;c[ka>>2]=na;va=ta-la|0;wa=na;xa=D}else{D=la-ta|0;la=je(ra>>>(D>>>0)|ua<<ta|0)|0;c[c[w>>2]>>2]=la;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=ra;va=32-D|0;wa=ra;xa=c[ha>>2]|0}c[y>>2]=va;do{if((c[xa+56>>2]|0)==0){ra=e+3264|0;D=c[ra>>2]|0;la=D|wa<<1;c[ka>>2]=la;ta=va-1|0;c[y>>2]=ta;if((ta|0)==0){ua=je(la|0)|0;c[c[w>>2]>>2]=ua;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;ya=32;za=c[ra>>2]|0}else{ya=ta;za=D}if((za|0)==0){Aa=ya;break}D=c[ka>>2]<<1|c[e+3268>>2];c[ka>>2]=D;ta=ya-1|0;c[y>>2]=ta;if((ta|0)!=0){Aa=ta;break}ta=je(D|0)|0;c[c[w>>2]>>2]=ta;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;Aa=32}else{Aa=va}}while(0);va=e+3272|0;ya=c[va>>2]|0;if((ya|0)>-1){za=ya+1|0;ya=(za|0)>65535;wa=ya?32:0;xa=ya?za>>16:za;if((xa|0)>255){Ba=xa>>8;Ca=wa|16}else{Ba=xa;Ca=wa}wa=(d[16976+Ba|0]|0)+Ca>>1;Ca=c[ka>>2]|0;if((Aa|0)>(wa|0)){Ba=Ca<<wa;c[ka>>2]=Ba;Da=Aa;Ea=Ba}else{Ba=je(Ca<<Aa|0)|0;c[c[w>>2]>>2]=Ba;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Da=Aa+32|0;Ea=0}Ba=Da-wa|0;c[y>>2]=Ba;Da=wa+1|0;if((Ba|0)>(Da|0)){c[ka>>2]=Ea<<Da|za;Fa=Ba-Da|0}else{wa=Da-Ba|0;Da=je(za>>>(wa>>>0)|Ea<<Ba|0)|0;c[c[w>>2]>>2]=Da;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=za;Fa=32-wa|0}c[y>>2]=Fa;Ga=Fa}else{Ga=Aa}Aa=c[ha>>2]|0;do{if((c[Aa+32>>2]|0)==0){ha=c[Aa+36>>2]|0;Fa=(1<<ha)-1&c[e+3276>>2];if((Ga|0)>(ha|0)){wa=c[ka>>2]<<ha|Fa;c[ka>>2]=wa;Ha=Ga-ha|0;Ia=wa}else{wa=ha-Ga|0;ha=je(c[ka>>2]<<Ga|Fa>>>(wa>>>0)|0)|0;c[c[w>>2]>>2]=ha;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Fa;Ha=32-wa|0;Ia=Fa}c[y>>2]=Ha;Fa=e+3236|0;if((c[(c[Fa>>2]|0)+12>>2]|0)==0){Ja=Ha;Ka=Fa;break}if((c[e+3264>>2]|0)!=0){Ja=Ha;Ka=Fa;break}wa=c[e+3280>>2]<<1;ha=1-wa|0;za=(ha|0)<0?wa:ha;ha=(za|0)>255;wa=(ha?16:0)+(d[16976+(ha?za>>8:za)|0]|0)|0;if((Ha|0)>(wa|0)){c[ka>>2]=Ia<<wa|za;La=Ha-wa|0}else{ha=wa-Ha|0;wa=je(za>>>(ha>>>0)|Ia<<Ha|0)|0;c[c[w>>2]>>2]=wa;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=za;La=32-ha|0}c[y>>2]=La;Ja=La;Ka=Fa}else{Ja=Ga;Ka=e+3236|0}}while(0);if((c[(c[Ka>>2]|0)+56>>2]|0)==0){Ma=Ja}else{Ga=(c[e+3292>>2]|0)+1|0;La=(Ga|0)>65535;Ha=La?32:0;Ia=La?Ga>>16:Ga;if((Ia|0)>255){Na=Ia>>8;Oa=Ha|16}else{Na=Ia;Oa=Ha}Ha=(d[16976+Na|0]|0)+Oa>>1;Oa=c[ka>>2]|0;if((Ja|0)>(Ha|0)){Na=Oa<<Ha;c[ka>>2]=Na;Pa=Ja;Qa=Na}else{Na=je(Oa<<Ja|0)|0;c[c[w>>2]>>2]=Na;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Pa=Ja+32|0;Qa=0}Ja=Pa-Ha|0;c[y>>2]=Ja;Pa=Ha+1|0;if((Ja|0)>(Pa|0)){c[ka>>2]=Qa<<Pa|Ga;Ra=Ja-Pa|0}else{Ha=Pa-Ja|0;Pa=je(Ga>>>(Ha>>>0)|Qa<<Ja|0)|0;c[c[w>>2]>>2]=Pa;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Ga;Ra=32-Ha|0}c[y>>2]=Ra;Ma=Ra}Ra=c[ia>>2]|0;do{if((Ra|0)==1){Ha=c[ka>>2]<<1|c[e+3296>>2];c[ka>>2]=Ha;Ga=Ma-1|0;c[y>>2]=Ga;if((Ga|0)!=0){Sa=Ga;Ta=91;break}Ga=je(Ha|0)|0;c[c[w>>2]>>2]=Ga;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;Ua=c[ia>>2]|0;Va=32;Ta=90}else{Ua=Ra;Va=Ma;Ta=90}}while(0);if((Ta|0)==90){if(Ua>>>0<2>>>0){Sa=Va;Ta=91}else{Wa=Va;Ta=112}}do{if((Ta|0)==91){Va=e+3300|0;Ua=c[Va>>2]|0;Ma=c[ka>>2]<<1|Ua;c[ka>>2]=Ma;Ra=Sa-1|0;c[y>>2]=Ra;if((Ra|0)==0){Ga=je(Ma|0)|0;c[c[w>>2]>>2]=Ga;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;Xa=32;Ya=c[Va>>2]|0}else{Xa=Ra;Ya=Ua}if((Ya|0)==0){Wa=Xa;Ta=112;break}Ua=c[e+3304>>2]|0;Ra=(Ua|0)>65535;Va=Ra?32:0;Ga=Ra?Ua>>16:Ua;if((Ga|0)>255){Za=Ga>>8;_a=Va|16}else{Za=Ga;_a=Va}Va=(d[16976+Za|0]|0)+_a>>1;Ga=c[ka>>2]|0;if((Xa|0)>(Va|0)){Ra=Ga<<Va;c[ka>>2]=Ra;$a=Xa;ab=Ra}else{Ra=je(Ga<<Xa|0)|0;c[c[w>>2]>>2]=Ra;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;$a=Xa+32|0;ab=0}Ra=$a-Va|0;c[y>>2]=Ra;Ga=Va+1|0;if((Ra|0)>(Ga|0)){Va=ab<<Ga|Ua;c[ka>>2]=Va;bb=Ra-Ga|0;cb=Va}else{Va=Ga-Ra|0;Ga=je(Ua>>>(Va>>>0)|ab<<Ra|0)|0;c[c[w>>2]>>2]=Ga;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Ua;bb=32-Va|0;cb=Ua}c[y>>2]=bb;Ua=c[ia>>2]|0;if((Ua|0)!=1){db=Ua;eb=bb;break}Ua=c[e+3308>>2]|0;Va=(Ua|0)>65535;Ga=Va?32:0;Ra=Va?Ua>>16:Ua;if((Ra|0)>255){fb=Ra>>8;gb=Ga|16}else{fb=Ra;gb=Ga}Ga=(d[16976+fb|0]|0)+gb>>1;if((bb|0)>(Ga|0)){Ra=cb<<Ga;c[ka>>2]=Ra;hb=bb;ib=Ra}else{Ra=je(cb<<bb|0)|0;c[c[w>>2]>>2]=Ra;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;hb=bb+32|0;ib=0}Ra=hb-Ga|0;c[y>>2]=Ra;Va=Ga+1|0;if((Ra|0)>(Va|0)){c[ka>>2]=ib<<Va|Ua;jb=Ra-Va|0}else{Ga=Va-Ra|0;Va=je(Ua>>>(Ga>>>0)|ib<<Ra|0)|0;c[c[w>>2]>>2]=Va;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Ua;jb=32-Ga|0}c[y>>2]=jb;Wa=jb;Ta=112}}while(0);if((Ta|0)==112){db=c[ia>>2]|0;eb=Wa}do{if((db|0)==2){kb=eb}else{Wa=e+3312|0;jb=c[Wa>>2]|0;ib=c[ka>>2]<<1|jb;c[ka>>2]=ib;hb=eb-1|0;c[y>>2]=hb;if((hb|0)==0){bb=je(ib|0)|0;c[c[w>>2]>>2]=bb;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;lb=32;mb=c[Wa>>2]|0}else{lb=hb;mb=jb}if((mb|0)==0){kb=lb;break}jb=e+3304|0;if((c[jb>>2]|0)>0){hb=0;Wa=lb;while(1){bb=(c[e+3320+(hb<<3)>>2]|0)+1|0;ib=(bb|0)>65535;cb=ib?32:0;gb=ib?bb>>16:bb;if((gb|0)>255){nb=gb>>8;ob=cb|16}else{nb=gb;ob=cb}cb=(d[16976+nb|0]|0)+ob>>1;gb=c[ka>>2]|0;if((Wa|0)>(cb|0)){ib=gb<<cb;c[ka>>2]=ib;pb=Wa;qb=ib}else{ib=je(gb<<Wa|0)|0;c[c[w>>2]>>2]=ib;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;pb=Wa+32|0;qb=0}ib=pb-cb|0;c[y>>2]=ib;gb=cb+1|0;if((ib|0)>(gb|0)){cb=qb<<gb|bb;c[ka>>2]=cb;rb=ib-gb|0;sb=cb}else{cb=gb-ib|0;gb=je(bb>>>(cb>>>0)|qb<<ib|0)|0;c[c[w>>2]>>2]=gb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=bb;rb=32-cb|0;sb=bb}c[y>>2]=rb;bb=(c[e+3320+(hb<<3)+4>>2]|0)+1|0;cb=(bb|0)>65535;gb=cb?32:0;ib=cb?bb>>16:bb;if((ib|0)>255){tb=ib>>8;ub=gb|16}else{tb=ib;ub=gb}gb=(d[16976+tb|0]|0)+ub>>1;if((rb|0)>(gb|0)){ib=sb<<gb;c[ka>>2]=ib;vb=rb;wb=ib}else{ib=je(sb<<rb|0)|0;c[c[w>>2]>>2]=ib;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;vb=rb+32|0;wb=0}ib=vb-gb|0;c[y>>2]=ib;cb=gb+1|0;if((ib|0)>(cb|0)){gb=wb<<cb|bb;c[ka>>2]=gb;xb=ib-cb|0;yb=gb}else{gb=cb-ib|0;cb=je(bb>>>(gb>>>0)|wb<<ib|0)|0;c[c[w>>2]>>2]=cb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=bb;xb=32-gb|0;yb=bb}c[y>>2]=xb;bb=hb+1|0;if((bb|0)<(c[jb>>2]|0)){hb=bb;Wa=xb}else{zb=xb;Ab=yb;break}}}else{zb=lb;Ab=c[ka>>2]|0}if((zb|0)>2){Wa=Ab<<2;c[ka>>2]=Wa;Bb=zb;Cb=Wa}else{Wa=je(Ab<<zb|0)|0;c[c[w>>2]>>2]=Wa;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Bb=zb+32|0;Cb=0}Wa=Bb-2|0;c[y>>2]=Wa;if((Wa|0)>3){c[ka>>2]=Cb<<3|4;Db=Bb-5|0}else{hb=5-Bb|0;jb=je(Cb<<Wa|4>>>(hb>>>0)|0)|0;c[c[w>>2]>>2]=jb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=4;Db=32-hb|0}c[y>>2]=Db;kb=Db}}while(0);do{if((c[ia>>2]|0)==1){Db=e+3316|0;Cb=c[Db>>2]|0;Bb=c[ka>>2]<<1|Cb;c[ka>>2]=Bb;zb=kb-1|0;c[y>>2]=zb;if((zb|0)==0){Ab=je(Bb|0)|0;c[c[w>>2]>>2]=Ab;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;Eb=32;Fb=c[Db>>2]|0}else{Eb=zb;Fb=Cb}if((Fb|0)==0){Gb=Eb;break}Cb=e+3308|0;if((c[Cb>>2]|0)>0){zb=0;Db=Eb;while(1){Ab=(c[e+3448+(zb<<3)>>2]|0)+1|0;Bb=(Ab|0)>65535;lb=Bb?32:0;yb=Bb?Ab>>16:Ab;if((yb|0)>255){Hb=yb>>8;Ib=lb|16}else{Hb=yb;Ib=lb}lb=(d[16976+Hb|0]|0)+Ib>>1;yb=c[ka>>2]|0;if((Db|0)>(lb|0)){Bb=yb<<lb;c[ka>>2]=Bb;Jb=Db;Kb=Bb}else{Bb=je(yb<<Db|0)|0;c[c[w>>2]>>2]=Bb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Jb=Db+32|0;Kb=0}Bb=Jb-lb|0;c[y>>2]=Bb;yb=lb+1|0;if((Bb|0)>(yb|0)){lb=Kb<<yb|Ab;c[ka>>2]=lb;Lb=Bb-yb|0;Mb=lb}else{lb=yb-Bb|0;yb=je(Ab>>>(lb>>>0)|Kb<<Bb|0)|0;c[c[w>>2]>>2]=yb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Ab;Lb=32-lb|0;Mb=Ab}c[y>>2]=Lb;Ab=(c[e+3448+(zb<<3)+4>>2]|0)+1|0;lb=(Ab|0)>65535;yb=lb?32:0;Bb=lb?Ab>>16:Ab;if((Bb|0)>255){Nb=Bb>>8;Ob=yb|16}else{Nb=Bb;Ob=yb}yb=(d[16976+Nb|0]|0)+Ob>>1;if((Lb|0)>(yb|0)){Bb=Mb<<yb;c[ka>>2]=Bb;Pb=Lb;Qb=Bb}else{Bb=je(Mb<<Lb|0)|0;c[c[w>>2]>>2]=Bb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Pb=Lb+32|0;Qb=0}Bb=Pb-yb|0;c[y>>2]=Bb;lb=yb+1|0;if((Bb|0)>(lb|0)){yb=Qb<<lb|Ab;c[ka>>2]=yb;Rb=Bb-lb|0;Sb=yb}else{yb=lb-Bb|0;lb=je(Ab>>>(yb>>>0)|Qb<<Bb|0)|0;c[c[w>>2]>>2]=lb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Ab;Rb=32-yb|0;Sb=Ab}c[y>>2]=Rb;Ab=zb+1|0;if((Ab|0)<(c[Cb>>2]|0)){zb=Ab;Db=Rb}else{Tb=Rb;Ub=Sb;break}}}else{Tb=Eb;Ub=c[ka>>2]|0}if((Tb|0)>2){Db=Ub<<2;c[ka>>2]=Db;Vb=Tb;Wb=Db}else{Db=je(Ub<<Tb|0)|0;c[c[w>>2]>>2]=Db;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Vb=Tb+32|0;Wb=0}Db=Vb-2|0;c[y>>2]=Db;if((Db|0)>3){c[ka>>2]=Wb<<3|4;Xb=Vb-5|0}else{zb=5-Vb|0;Cb=je(Wb<<Db|4>>>(zb>>>0)|0)|0;c[c[w>>2]>>2]=Cb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=4;Xb=32-zb|0}c[y>>2]=Xb;Gb=Xb}else{Gb=kb}}while(0);kb=e+3576|0;c[kb>>2]=0;do{if((c[(c[Ka>>2]|0)+28>>2]|0)==0){Yb=Gb}else{if((c[ia>>2]|0)!=0){Yb=Gb;break}do{if((c[e+3628>>2]|0)==0){if((c[e+3676>>2]|0)!=0){Zb=1;break}Zb=(c[e+3724>>2]|0)!=0|0}else{Zb=1}}while(0);c[kb>>2]=Zb;Xb=(c[e+3616>>2]|0)+1|0;Wb=(Xb|0)>65535;Vb=Wb?32:0;Tb=Wb?Xb>>16:Xb;if((Tb|0)>255){_b=Tb>>8;$b=Vb|16}else{_b=Tb;$b=Vb}Vb=(d[16976+_b|0]|0)+$b>>1;Tb=c[ka>>2]|0;if((Gb|0)>(Vb|0)){Wb=Tb<<Vb;c[ka>>2]=Wb;ac=Gb;bc=Wb}else{Wb=je(Tb<<Gb|0)|0;c[c[w>>2]>>2]=Wb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;ac=Gb+32|0;bc=0}Wb=ac-Vb|0;c[y>>2]=Wb;Tb=Vb+1|0;if((Wb|0)>(Tb|0)){Vb=bc<<Tb|Xb;c[ka>>2]=Vb;cc=Wb-Tb|0;dc=Vb}else{Vb=Tb-Wb|0;Tb=je(Xb>>>(Vb>>>0)|bc<<Wb|0)|0;c[c[w>>2]>>2]=Tb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Xb;cc=32-Vb|0;dc=Xb}c[y>>2]=cc;Xb=(c[e+3664>>2]|0)+1|0;Vb=(Xb|0)>65535;Tb=Vb?32:0;Wb=Vb?Xb>>16:Xb;if((Wb|0)>255){ec=Wb>>8;fc=Tb|16}else{ec=Wb;fc=Tb}Tb=(d[16976+ec|0]|0)+fc>>1;if((cc|0)>(Tb|0)){Wb=dc<<Tb;c[ka>>2]=Wb;gc=cc;hc=Wb}else{Wb=je(dc<<cc|0)|0;c[c[w>>2]>>2]=Wb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;gc=cc+32|0;hc=0}Wb=gc-Tb|0;c[y>>2]=Wb;Vb=Tb+1|0;if((Wb|0)>(Vb|0)){c[ka>>2]=hc<<Vb|Xb;ic=Wb-Vb|0}else{Tb=Vb-Wb|0;Vb=je(Xb>>>(Tb>>>0)|hc<<Wb|0)|0;c[c[w>>2]>>2]=Vb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Xb;ic=32-Tb|0}c[y>>2]=ic;Tb=e+3304|0;if((c[Tb>>2]|0)>0){jc=0;kc=ic}else{Yb=ic;break}while(1){Xb=(c[e+3584+(jc*144|0)+44>>2]|0)!=0;if((c[e+3584+(jc*144|0)+92>>2]|0)==0){lc=(c[e+3584+(jc*144|0)+140>>2]|0)!=0}else{lc=1}Vb=lc&1;Wb=c[ka>>2]<<1|Xb&1;c[ka>>2]=Wb;Ub=kc-1|0;c[y>>2]=Ub;if((Ub|0)==0){Eb=je(Wb|0)|0;c[c[w>>2]>>2]=Eb;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;mc=32}else{mc=Ub}if(Xb){Xb=c[e+3584+(jc*144|0)+36>>2]<<1;Ub=1-Xb|0;Eb=(Ub|0)<0?Xb:Ub;Ub=(Eb|0)>255;Xb=(Ub?16:0)+(d[16976+(Ub?Eb>>8:Eb)|0]|0)|0;if((mc|0)>(Xb|0)){Ub=c[ka>>2]<<Xb|Eb;c[ka>>2]=Ub;nc=mc-Xb|0;oc=Ub}else{Ub=Xb-mc|0;Xb=je(c[ka>>2]<<mc|Eb>>>(Ub>>>0)|0)|0;c[c[w>>2]>>2]=Xb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Eb;nc=32-Ub|0;oc=Eb}c[y>>2]=nc;Eb=c[e+3584+(jc*144|0)+40>>2]<<1;Ub=1-Eb|0;Xb=(Ub|0)<0?Eb:Ub;Ub=(Xb|0)>255;Eb=(Ub?16:0)+(d[16976+(Ub?Xb>>8:Xb)|0]|0)|0;if((nc|0)>(Eb|0)){Ub=oc<<Eb|Xb;c[ka>>2]=Ub;pc=nc-Eb|0;qc=Ub}else{Ub=Eb-nc|0;Eb=je(Xb>>>(Ub>>>0)|oc<<nc|0)|0;c[c[w>>2]>>2]=Eb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Xb;pc=32-Ub|0;qc=Xb}c[y>>2]=pc;rc=pc;sc=qc}else{rc=mc;sc=c[ka>>2]|0}Xb=sc<<1|Vb;c[ka>>2]=Xb;Vb=rc-1|0;c[y>>2]=Vb;if((Vb|0)==0){Ub=je(Xb|0)|0;c[c[w>>2]>>2]=Ub;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;tc=32}else{tc=Vb}if(lc){Vb=c[e+3584+(jc*144|0)+84>>2]<<1;Ub=1-Vb|0;Xb=(Ub|0)<0?Vb:Ub;Ub=(Xb|0)>255;Vb=(Ub?16:0)+(d[16976+(Ub?Xb>>8:Xb)|0]|0)|0;if((tc|0)>(Vb|0)){Ub=c[ka>>2]<<Vb|Xb;c[ka>>2]=Ub;uc=tc-Vb|0;vc=Ub}else{Ub=Vb-tc|0;Vb=je(c[ka>>2]<<tc|Xb>>>(Ub>>>0)|0)|0;c[c[w>>2]>>2]=Vb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Xb;uc=32-Ub|0;vc=Xb}c[y>>2]=uc;Xb=c[e+3584+(jc*144|0)+88>>2]<<1;Ub=1-Xb|0;Vb=(Ub|0)<0?Xb:Ub;Ub=(Vb|0)>255;Xb=(Ub?16:0)+(d[16976+(Ub?Vb>>8:Vb)|0]|0)|0;if((uc|0)>(Xb|0)){Ub=vc<<Xb|Vb;c[ka>>2]=Ub;wc=uc-Xb|0;xc=Ub}else{Ub=Xb-uc|0;Xb=je(Vb>>>(Ub>>>0)|vc<<uc|0)|0;c[c[w>>2]>>2]=Xb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Vb;wc=32-Ub|0;xc=Vb}c[y>>2]=wc;Vb=c[e+3584+(jc*144|0)+132>>2]<<1;Ub=1-Vb|0;Xb=(Ub|0)<0?Vb:Ub;Ub=(Xb|0)>255;Vb=(Ub?16:0)+(d[16976+(Ub?Xb>>8:Xb)|0]|0)|0;if((wc|0)>(Vb|0)){Ub=xc<<Vb|Xb;c[ka>>2]=Ub;yc=wc-Vb|0;zc=Ub}else{Ub=Vb-wc|0;Vb=je(xc<<wc|Xb>>>(Ub>>>0)|0)|0;c[c[w>>2]>>2]=Vb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Xb;yc=32-Ub|0;zc=Xb}c[y>>2]=yc;Xb=c[e+3584+(jc*144|0)+136>>2]<<1;Ub=1-Xb|0;Vb=(Ub|0)<0?Xb:Ub;Ub=(Vb|0)>255;Xb=(Ub?16:0)+(d[16976+(Ub?Vb>>8:Vb)|0]|0)|0;if((yc|0)>(Xb|0)){c[ka>>2]=zc<<Xb|Vb;Ac=yc-Xb|0}else{Ub=Xb-yc|0;Xb=je(Vb>>>(Ub>>>0)|zc<<yc|0)|0;c[c[w>>2]>>2]=Xb;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Vb;Ac=32-Ub|0}c[y>>2]=Ac;Bc=Ac}else{Bc=tc}Ub=jc+1|0;if((Ub|0)<(c[Tb>>2]|0)){jc=Ub;kc=Bc}else{Yb=Bc;break}}}}while(0);do{if((P|0)==0){Cc=Yb}else{if((c[va>>2]|0)>-1){Bc=c[ka>>2]|0;kc=Bc<<1;c[ka>>2]=kc;jc=Yb-1|0;c[y>>2]=jc;if((jc|0)==0){jc=je(kc|0)|0;c[c[w>>2]>>2]=jc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=c[ka>>2]<<1;c[y>>2]=31;Cc=31;break}jc=Bc<<2;c[ka>>2]=jc;Bc=Yb-2|0;c[y>>2]=Bc;if((Bc|0)!=0){Cc=Bc;break}Bc=je(jc|0)|0;c[c[w>>2]>>2]=Bc;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;Cc=32;break}Bc=e+8196|0;jc=c[Bc>>2]|0;kc=c[ka>>2]<<1|(jc|0)>0;c[ka>>2]=kc;tc=Yb-1|0;c[y>>2]=tc;if((tc|0)==0){Ac=je(kc|0)|0;c[c[w>>2]>>2]=Ac;c[w>>2]=(c[w>>2]|0)+4;c[y>>2]=32;Dc=32;Ec=c[Bc>>2]|0}else{Dc=tc;Ec=jc}if((Ec|0)<=0){Cc=Dc;break}jc=0;tc=Dc;Ac=c[ka>>2]|0;while(1){if((tc|0)>1){kc=Ac<<1;c[ka>>2]=kc;Fc=tc;Gc=kc}else{kc=je(Ac<<tc|0)|0;c[c[w>>2]>>2]=kc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Fc=tc+32|0;Gc=0}kc=Fc-1|0;c[y>>2]=kc;if((kc|0)>2){yc=Gc<<2|2;c[ka>>2]=yc;Hc=Fc-3|0;Ic=yc}else{yc=3-Fc|0;zc=je(Gc<<kc|2>>>(yc>>>0)|0)|0;c[c[w>>2]>>2]=zc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=2;Hc=32-yc|0;Ic=2}c[y>>2]=Hc;yc=c[e+8200+(jc<<3)>>2]|0;zc=(yc|0)>65535;kc=zc?32:0;wc=zc?yc>>16:yc;if((wc|0)>255){Jc=wc>>8;Kc=kc|16}else{Jc=wc;Kc=kc}kc=(d[16976+Jc|0]|0)+Kc>>1;if((Hc|0)>(kc|0)){wc=Ic<<kc;c[ka>>2]=wc;Lc=Hc;Mc=wc}else{wc=je(Ic<<Hc|0)|0;c[c[w>>2]>>2]=wc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Lc=Hc+32|0;Mc=0}wc=Lc-kc|0;c[y>>2]=wc;zc=kc+1|0;if((wc|0)>(zc|0)){kc=Mc<<zc|yc;c[ka>>2]=kc;Nc=wc-zc|0;Oc=kc}else{kc=zc-wc|0;zc=je(yc>>>(kc>>>0)|Mc<<wc|0)|0;c[c[w>>2]>>2]=zc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=yc;Nc=32-kc|0;Oc=yc}c[y>>2]=Nc;yc=jc+1|0;if((yc|0)<(c[Bc>>2]|0)){jc=yc;tc=Nc;Ac=Oc}else{break}}if((Nc|0)>0){c[ka>>2]=Oc;Pc=Nc;Qc=Oc}else{Ac=je(Oc<<Nc|0)|0;c[c[w>>2]>>2]=Ac;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Pc=Nc+32|0;Qc=0}c[y>>2]=Pc;if((Pc|0)>1){c[ka>>2]=Qc<<1|1;Rc=Pc-1|0}else{Ac=1-Pc|0;tc=je(1>>>(Ac>>>0)|Qc<<Pc|0)|0;c[c[w>>2]>>2]=tc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=1;Rc=32-Ac|0}c[y>>2]=Rc;Cc=Rc}}while(0);do{if((c[(c[Ka>>2]|0)+8>>2]|0)==0){Sc=Cc}else{if((c[ia>>2]|0)==2){Sc=Cc;break}Rc=(c[e+8328>>2]|0)+1|0;Pc=(Rc|0)>65535;Qc=Pc?32:0;Nc=Pc?Rc>>16:Rc;if((Nc|0)>255){Tc=Nc>>8;Uc=Qc|16}else{Tc=Nc;Uc=Qc}Qc=(d[16976+Tc|0]|0)+Uc>>1;Nc=c[ka>>2]|0;if((Cc|0)>(Qc|0)){Pc=Nc<<Qc;c[ka>>2]=Pc;Vc=Cc;Wc=Pc}else{Pc=je(Nc<<Cc|0)|0;c[c[w>>2]>>2]=Pc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Vc=Cc+32|0;Wc=0}Pc=Vc-Qc|0;c[y>>2]=Pc;Nc=Qc+1|0;if((Pc|0)>(Nc|0)){c[ka>>2]=Wc<<Nc|Rc;Xc=Pc-Nc|0}else{Qc=Nc-Pc|0;Nc=je(Rc>>>(Qc>>>0)|Wc<<Pc|0)|0;c[c[w>>2]>>2]=Nc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Rc;Xc=32-Qc|0}c[y>>2]=Xc;Sc=Xc}}while(0);Xc=c[R>>2]<<1;R=1-Xc|0;Wc=(R|0)<0?Xc:R;R=(Wc|0)>255;Xc=(R?16:0)+(d[16976+(R?Wc>>8:Wc)|0]|0)|0;if((Sc|0)>(Xc|0)){R=c[ka>>2]<<Xc|Wc;c[ka>>2]=R;Yc=Sc-Xc|0;Zc=R}else{R=Xc-Sc|0;Xc=je(c[ka>>2]<<Sc|Wc>>>(R>>>0)|0)|0;c[c[w>>2]>>2]=Xc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Wc;Yc=32-R|0;Zc=Wc}c[y>>2]=Yc;do{if((c[(c[Ka>>2]|0)+48>>2]|0)==0){_c=Yc;$c=Zc}else{Wc=(c[E>>2]|0)+1|0;R=(Wc|0)>65535;Xc=R?32:0;Sc=R?Wc>>16:Wc;if((Sc|0)>255){ad=Sc>>8;bd=Xc|16}else{ad=Sc;bd=Xc}Xc=(d[16976+ad|0]|0)+bd>>1;if((Yc|0)>(Xc|0)){Sc=Zc<<Xc;c[ka>>2]=Sc;cd=Yc;dd=Sc}else{Sc=je(Zc<<Yc|0)|0;c[c[w>>2]>>2]=Sc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;cd=Yc+32|0;dd=0}Sc=cd-Xc|0;c[y>>2]=Sc;R=Xc+1|0;if((Sc|0)>(R|0)){Xc=dd<<R|Wc;c[ka>>2]=Xc;ed=Sc-R|0;fd=Xc}else{Xc=R-Sc|0;R=je(Wc>>>(Xc>>>0)|dd<<Sc|0)|0;c[c[w>>2]>>2]=R;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Wc;ed=32-Xc|0;fd=Wc}c[y>>2]=ed;if((c[E>>2]|0)==1){_c=ed;$c=fd;break}Wc=c[e+8352>>2]>>1<<1;Xc=1-Wc|0;R=(Xc|0)<0?Wc:Xc;Xc=(R|0)>255;Wc=(Xc?16:0)+(d[16976+(Xc?R>>8:R)|0]|0)|0;if((ed|0)>(Wc|0)){Xc=fd<<Wc|R;c[ka>>2]=Xc;gd=ed-Wc|0;hd=Xc}else{Xc=Wc-ed|0;Wc=je(R>>>(Xc>>>0)|fd<<ed|0)|0;c[c[w>>2]>>2]=Wc;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=R;gd=32-Xc|0;hd=R}c[y>>2]=gd;R=c[e+8356>>2]>>1<<1;Xc=1-R|0;Wc=(Xc|0)<0?R:Xc;Xc=(Wc|0)>255;R=(Xc?16:0)+(d[16976+(Xc?Wc>>8:Wc)|0]|0)|0;if((gd|0)>(R|0)){Xc=hd<<R|Wc;c[ka>>2]=Xc;id=gd-R|0;jd=Xc}else{Xc=R-gd|0;R=je(Wc>>>(Xc>>>0)|hd<<gd|0)|0;c[c[w>>2]>>2]=R;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=Wc;id=32-Xc|0;jd=Wc}c[y>>2]=id;_c=id;$c=jd}}while(0);if((c[r>>2]|0)==0){kd=w;ld=e+13888|0;md=e+13908|0}else{jd=_c&7;id=(1<<jd)-1|0;if((_c|0)>(jd|0)){gd=$c<<jd|id;c[ka>>2]=gd;nd=_c-jd|0;od=gd;pd=c[w>>2]|0}else{gd=jd-_c|0;jd=je($c<<_c|id>>>(gd>>>0)|0)|0;c[c[w>>2]>>2]=jd;jd=(c[w>>2]|0)+4|0;c[w>>2]=jd;c[ka>>2]=id;nd=32-gd|0;od=id;pd=jd}c[y>>2]=nd;c[pd>>2]=je(od<<(nd&31)|0)|0;c[w>>2]=(c[w>>2]|0)+(4-(c[y>>2]>>3));c[y>>2]=32;nd=e+13888|0;od=c[B>>2]|0;if((od|0)<0){qd=0}else{qd=(od|0)>51?51:od}pNb(e,nd,c[ia>>2]|0,qd,c[e+8328>>2]|0);rNb(nd,c[w>>2]|0,c[e+1508>>2]|0);qd=e+13908|0;kd=qd;ld=nd;md=qd}qd=c[kd>>2]|0;kd=e+28824|0;c[kd>>2]=c[B>>2];B=e+28828|0;c[B>>2]=0;nd=e+18948|0;c[nd>>2]=0;od=c[N>>2]|0;pd=c[K>>2]|0;jd=e+13904|0;id=e+13900|0;gd=e+13896|0;_c=e+664|0;$c=e+30504|0;hd=p;p=s;s=n;n=ld;ed=o;o=e+19384|0;fd=e+30504|0;E=e+30508|0;dd=j;j=k;k=g;g=e+840|0;cd=l;l=m;m=h;h=e+160|0;Yc=e+18580|0;Zc=e+18896|0;bd=e+19344|0;ad=e+504|0;Ka=e+19348|0;Wc=e+88|0;Xc=e+19360|0;R=e+19364|0;Sc=e+19372|0;Vc=e+18660|0;Cc=e+19368|0;Uc=e+30604|0;Tc=e+19356|0;Qc=e+30608|0;Rc=e+8632|0;Nc=(O|0)==0;O=e+700|0;Pc=z-32-C|0;C=e+1540|0;z=e+19396|0;Oc=e+28816|0;Mc=e+3216|0;Lc=e+28820|0;Hc=e+19376|0;Ic=e+19380|0;Kc=e+18664|0;Jc=e+19276|0;Gc=e+37640|0;Fc=e+37664|0;Dc=e+37688|0;Ec=e+18564|0;Yb=(od|0)%(pd|0)|0;va=(od|0)/(pd|0)|0;od=u;u=qd;qd=0;P=0;Ac=0;tc=0;jc=0;Bc=0;yc=0;kc=0;zc=0;wc=0;xc=0;uc=0;vc=0;lc=0;rc=0;sc=0;mc=0;qc=0;pc=pd;a:while(1){rd=(ca(pc,va)|0)+Yb|0;pd=c[y>>2]|0;nc=(c[w>>2]|0)-(c[q>>2]|0)<<3;oc=(c[md>>2]|0)-(c[jd>>2]|0)+(c[id>>2]|0)<<3;ic=c[gd>>2]|0;sd=(Yb|0)==0;do{if(sd){hc=ca(2500<<c[x>>2],pc)|0;if((gMb(e,hc,c[r>>2]|0,c[F>>2]|0)|0)!=0){td=-1;Ta=464;break a}do{if((c[x>>2]&va|0)==0){if((c[_c>>2]|0)==0){ud=vc;vd=lc;wd=rc;xd=sc;yd=mc;break}nrc(hd|0,$c|0,728)|0;hc=c[kd>>2]|0;gc=c[B>>2]|0;cc=c[nd>>2]|0;if((c[r>>2]|0)==0){c[s>>2]=c[p>>2];c[s+4>>2]=c[p+4>>2];c[s+8>>2]=c[p+8>>2];c[s+12>>2]=c[p+12>>2];c[s+16>>2]=c[p+16>>2];c[s+20>>2]=c[p+20>>2];ud=qc;vd=lc;wd=hc;xd=gc;yd=cc;break}else{nrc(ed|0,n|0,1072)|0;ud=vc;vd=a[(c[md>>2]|0)-1|0]|0;wd=hc;xd=gc;yd=cc;break}}else{ud=vc;vd=lc;wd=rc;xd=sc;yd=mc}}while(0);if((c[o>>2]|0)!=0){zd=ud;Ad=vd;Bd=wd;Dd=xd;Ed=yd;break}iMb(e,va,0);zd=ud;Ad=vd;Bd=wd;Dd=xd;Ed=yd}else{zd=vc;Ad=lc;Bd=rc;Dd=sc;Ed=mc}}while(0);do{if(t){do{if(v){cc=c[fd>>2]|0;gc=c[E>>2]|0;if((c[r>>2]|0)==0){c[dd>>2]=c[p>>2];c[dd+4>>2]=c[p+4>>2];c[dd+8>>2]=c[p+8>>2];c[dd+12>>2]=c[p+12>>2];c[dd+16>>2]=c[p+16>>2];c[dd+20>>2]=c[p+20>>2];Fd=qc;Gd=Bc;Hd=cc;Id=gc;break}else{c[j>>2]=c[n>>2];c[j+4>>2]=c[n+4>>2];c[j+8>>2]=c[n+8>>2];c[j+12>>2]=c[n+12>>2];c[j+16>>2]=c[n+16>>2];c[j+20>>2]=c[n+20>>2];c[j+24>>2]=c[n+24>>2];c[j+28>>2]=c[n+28>>2];Fd=jc;Gd=a[(c[md>>2]|0)-1|0]|0;Hd=cc;Id=gc;break}}else{Fd=jc;Gd=Bc;Hd=yc;Id=kc}}while(0);if((od|0)==0){Jd=qd;Kd=P;Ld=Ac;Md=tc;Nd=Fd;Od=Gd;Pd=Hd;Qd=Id;Rd=zc;Sd=wc;Td=xc;Ud=uc;break}if((c[x>>2]&va|0)!=0){Jd=qd;Kd=P;Ld=Ac;Md=tc;Nd=Fd;Od=Gd;Pd=Hd;Qd=Id;Rd=zc;Sd=wc;Td=xc;Ud=uc;break}gc=c[fd>>2]|0;cc=c[E>>2]|0;hc=(c[r>>2]|0)==0;if(hc){c[k>>2]=c[p>>2];c[k+4>>2]=c[p+4>>2];c[k+8>>2]=c[p+8>>2];c[k+12>>2]=c[p+12>>2];c[k+16>>2]=c[p+16>>2];c[k+20>>2]=c[p+20>>2];Vd=qc;Wd=P}else{c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];c[m+8>>2]=c[n+8>>2];c[m+12>>2]=c[n+12>>2];c[m+16>>2]=c[n+16>>2];c[m+20>>2]=c[n+20>>2];c[m+24>>2]=c[n+24>>2];c[m+28>>2]=c[n+28>>2];Vd=qd;Wd=a[(c[md>>2]|0)-1|0]|0}if((L-rd|0)!=(c[g>>2]|0)){Jd=Vd;Kd=Wd;Ld=gc;Md=cc;Nd=Fd;Od=Gd;Pd=Hd;Qd=Id;Rd=zc;Sd=wc;Td=xc;Ud=uc;break}if(hc){c[cd>>2]=c[p>>2];c[cd+4>>2]=c[p+4>>2];c[cd+8>>2]=c[p+8>>2];c[cd+12>>2]=c[p+12>>2];c[cd+16>>2]=c[p+16>>2];c[cd+20>>2]=c[p+20>>2];Jd=Vd;Kd=Wd;Ld=gc;Md=cc;Nd=Fd;Od=Gd;Pd=Hd;Qd=Id;Rd=qc;Sd=wc;Td=gc;Ud=cc;break}else{c[l>>2]=c[n>>2];c[l+4>>2]=c[n+4>>2];c[l+8>>2]=c[n+8>>2];c[l+12>>2]=c[n+12>>2];c[l+16>>2]=c[n+16>>2];c[l+20>>2]=c[n+20>>2];c[l+24>>2]=c[n+24>>2];c[l+28>>2]=c[n+28>>2];Jd=Vd;Kd=Wd;Ld=gc;Md=cc;Nd=Fd;Od=Gd;Pd=Hd;Qd=Id;Rd=zc;Sd=a[(c[md>>2]|0)-1|0]|0;Td=gc;Ud=cc;break}}else{Jd=qd;Kd=P;Ld=Ac;Md=tc;Nd=jc;Od=Bc;Pd=yc;Qd=kc;Rd=zc;Sd=wc;Td=xc;Ud=uc}}while(0);if((c[h>>2]|0)!=0){do{if((c[Kc>>2]|0)!=0){if((va&1|0)!=0){break}cc=MQb(e,Yb,va)|0;c[Vc>>2]=cc;gc=(cc|0)!=0?Fc:Dc;c[Gc>>2]=c[gc>>2];c[Gc+4>>2]=c[gc+4>>2];c[Gc+8>>2]=c[gc+8>>2];c[Gc+12>>2]=c[gc+12>>2];c[Gc+16>>2]=c[gc+16>>2];c[Gc+20>>2]=c[gc+20>>2];if((cc|0)!=0){break}if((va+2|0)!=(c[Ec>>2]|0)){break}BOb(e,Yb,va)}}while(0);a[(c[Jc>>2]|0)+rd|0]=c[Vc>>2]}if((c[x>>2]|0)==0){fPb(e,Yb,va)}else{gPb(e,Yb,va)}eUb(e);uMb(e);b:do{if((c[r>>2]|0)==0){cc=qc;while(1){gc=c[bd>>2]|0;if((gc|0)==6|(gc|0)==18){break}if((c[ia>>2]|0)==2){Xd=cc}else{gc=cc+1|0;hc=(gc|0)>65535;dc=hc?32:0;fc=hc?gc>>16:gc;if((fc|0)>255){Yd=fc>>8;Zd=dc|16}else{Yd=fc;Zd=dc}dc=(d[16976+Yd|0]|0)+Zd>>1;fc=c[y>>2]|0;hc=c[ka>>2]|0;if((fc|0)>(dc|0)){ec=hc<<dc;c[ka>>2]=ec;_d=fc;$d=ec}else{ec=je(hc<<fc|0)|0;c[c[w>>2]>>2]=ec;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;_d=fc+32|0;$d=0}fc=_d-dc|0;c[y>>2]=fc;ec=dc+1|0;if((fc|0)>(ec|0)){c[ka>>2]=$d<<ec|gc;ae=fc-ec|0}else{dc=ec-fc|0;ec=je(gc>>>(dc>>>0)|$d<<fc|0)|0;c[c[w>>2]>>2]=ec;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=gc;ae=32-dc|0}c[y>>2]=ae;Xd=0}iVb(e);if((c[z>>2]|0)==0){be=Xd;break b}dc=(c[Oc>>2]|0)+1|0;c[Oc>>2]=dc;c[Lc>>2]=d[(c[Mc>>2]|0)+dc|0]|0;c[Hc>>2]=0;c[Ic>>2]=0;c[z>>2]=0;c[fd>>2]=Pd;c[E>>2]=Qd;if((c[r>>2]|0)==0){c[p>>2]=c[dd>>2];c[p+4>>2]=c[dd+4>>2];c[p+8>>2]=c[dd+8>>2];c[p+12>>2]=c[dd+12>>2];c[p+16>>2]=c[dd+16>>2];c[p+20>>2]=c[dd+20>>2];ce=Nd}else{c[n>>2]=c[j>>2];c[n+4>>2]=c[j+4>>2];c[n+8>>2]=c[j+8>>2];c[n+12>>2]=c[j+12>>2];c[n+16>>2]=c[j+16>>2];c[n+20>>2]=c[j+20>>2];c[n+24>>2]=c[j+24>>2];c[n+28>>2]=c[j+28>>2];a[(c[md>>2]|0)-1|0]=Od;ce=Xd}uMb(e);if((c[r>>2]|0)==0){cc=ce}else{de=ce;Ta=325;break b}}be=cc+1|0}else{de=qc;Ta=325}}while(0);do{if((Ta|0)==325){Ta=0;do{if((rd|0)>(c[N>>2]|0)){if((c[x>>2]|0)!=0){if((va&1|0)!=0){break}}vNb(ld)}}while(0);cc=c[bd>>2]|0;if((cc|0)==6|(cc|0)==18){aVb(e,1);be=de;break}if((c[ia>>2]|0)!=2){aVb(e,0)}cVb(e,ld);be=de}}while(0);cc=32-(c[y>>2]|0)+(c[gd>>2]|0)+((c[w>>2]|0)-(c[q>>2]|0)+(c[md>>2]|0)-(c[jd>>2]|0)+(c[id>>2]|0)<<3)|0;dc=pd-32-nc-ic-oc+cc|0;c:do{if((od|0)==0){ee=0;fe=u}else{if((c[x>>2]|0)!=0){if((va&1|0)==0){ee=od;fe=u;break}}gc=(c[r>>2]|0)==0;if(gc){ec=be+1|0;if(be>>>0<255>>>0){ge=d[16976+ec|0]|0}else{ge=(d[16976+(ec>>>8)|0]|0)+16|0}he=ge+cc|0}else{he=cc}ec=(c[(gc?w:md)>>2]|0)-2|0;if(u>>>0<ec>>>0){gc=u;fc=od;while(1){do{if((a[gc]|0)==0){hc=gc+1|0;if((a[hc]|0)!=0){ie=fc;ke=gc;break}bc=(d[gc+2|0]|0)>>>0<4>>>0;ie=bc?fc-8|0:fc;ke=bc?hc:gc}else{ie=fc;ke=gc}}while(0);hc=ke+1|0;if(hc>>>0<ec>>>0){gc=hc;fc=ie}else{le=hc;me=ie;break}}}else{le=u;me=od}if((Pc+he|0)<=(me|0)){ee=me;fe=le;break}if((c[o>>2]|0)!=0){ee=me;fe=le;break}if((GOb(e,c[G>>2]|0)|0)!=0){ee=0;fe=le;break}do{if((rd|0)<=(M|0)){ne=c[g>>2]|0;if((L-rd|0)>=(ne|0)){break}if((M-ne|0)>=((c[N>>2]|0)+ne|0)){Ta=371;break a}ILb(e,1,2150224,(fc=i,i=i+8|0,c[fc>>2]=c[C>>2],fc)|0);i=fc;ee=0;fe=le;break c}}while(0);oe=c[x>>2]|0;fc=rd-(ca(c[Yc>>2]|0,oe)|0)|0;if((fc|0)!=(c[N>>2]|0)){Ta=376;break a}c[H>>2]=rd;ee=me;fe=le}}while(0);c[o>>2]=0;iPb(e);if((JMb(e,dc)|0)<0){nrc($c|0,hd|0,728)|0;c[kd>>2]=Bd;c[B>>2]=Dd;c[nd>>2]=Ed;if((c[r>>2]|0)==0){c[p>>2]=c[s>>2];c[p+4>>2]=c[s+4>>2];c[p+8>>2]=c[s+8>>2];c[p+12>>2]=c[s+12>>2];c[p+16>>2]=c[s+16>>2];c[p+20>>2]=c[s+20>>2];pe=zd}else{nrc(n|0,ed|0,1072)|0;a[(c[md>>2]|0)-1|0]=Ad;pe=be}c[o>>2]=1;cc=va-(c[x>>2]|0)|0;c[Zc>>2]=(ca(cc,c[Yc>>2]|0)|0)-1;c[H>>2]=I;Yb=0;va=cc;od=ee;u=fe;qd=Jd;P=Kd;Ac=Ld;tc=Md;jc=Nd;Bc=Od;yc=Pd;kc=Qd;zc=Rd;wc=Sd;xc=Td;uc=Ud;vc=zd;lc=Ad;rc=Bd;sc=Dd;mc=Ed;qc=pe;pc=c[K>>2]|0;continue}cc=e+30516+(c[bd>>2]<<2)|0;c[cc>>2]=(c[cc>>2]|0)+1;cc=c[bd>>2]|0;oc=cc>>>0<4>>>0;ic=(cc|0)==6|(cc|0)==18;if((c[ad>>2]|0)>1){switch(cc|0){case 18:case 6:case 3:case 2:case 1:case 0:case 7:{break};default:{Ta=393}}}else{if(!((c[O>>2]|0)==0|oc|ic|(cc|0)==7)){Ta=393}}do{if((Ta|0)==393){Ta=0;cc=c[Ka>>2]|0;if((cc|0)==13){nc=e+30868+(d[e+19352|0]<<2)|0;c[nc>>2]=(c[nc>>2]|0)+1;nc=e+30868+(d[e+19353|0]<<2)|0;c[nc>>2]=(c[nc>>2]|0)+1;nc=e+30868+(d[e+19354|0]<<2)|0;c[nc>>2]=(c[nc>>2]|0)+1;nc=e+30868+(d[e+19355|0]<<2)|0;c[nc>>2]=(c[nc>>2]|0)+1}else{nc=e+30868+(cc<<2)|0;c[nc>>2]=(c[nc>>2]|0)+4}if((c[Wc>>2]|0)>1){re=0}else{break}do{nc=a[e+28104+(re*40|0)+12|0]|0;if(nc<<24>>24>-1){cc=e+30612+(re<<7)+(nc<<24>>24<<2)|0;c[cc>>2]=(c[cc>>2]|0)+1}cc=a[e+28104+(re*40|0)+14|0]|0;if(cc<<24>>24>-1){nc=e+30612+(re<<7)+(cc<<24>>24<<2)|0;c[nc>>2]=(c[nc>>2]|0)+1}nc=a[e+28104+(re*40|0)+28|0]|0;if(nc<<24>>24>-1){cc=e+30612+(re<<7)+(nc<<24>>24<<2)|0;c[cc>>2]=(c[cc>>2]|0)+1}cc=a[e+28104+(re*40|0)+30|0]|0;if(cc<<24>>24>-1){nc=e+30612+(re<<7)+(cc<<24>>24<<2)|0;c[nc>>2]=(c[nc>>2]|0)+1}re=re+1|0;}while((re|0)<=((c[ia>>2]|0)==1|0))}}while(0);if((c[ad>>2]|0)>1){dc=c[Xc>>2]|0;d:do{if((c[R>>2]|dc|0)!=0){if((c[Rc>>2]|0)!=3){nc=oc&1^1;cc=e+30936+(nc<<2)|0;c[cc>>2]=(dc>>3)+(dc&1)+(dc>>>1&1)+(dc>>>2&1)+(c[cc>>2]|0);cc=e+30936+((nc|2)<<2)|0;c[cc>>2]=((c[R>>2]|0)!=0)+(c[cc>>2]|0);cc=e+30936+((nc|4)<<2)|0;c[cc>>2]=(c[cc>>2]|0)+(c[R>>2]>>1);break}cc=oc&1;nc=0;pd=dc;while(1){if((pd&1<<nc|0)!=0){fc=nc<<2;gc=d[19336+fc|0]|0;ec=e+30936+((cc^1)<<2)|0;c[ec>>2]=((b[gc+8+(e+27984)>>1]|b[e+27984+gc>>1])<<16>>16!=0)+(c[ec>>2]|0);ec=d[fc+19352|0]|0;gc=e+30936+((cc^3)<<2)|0;c[gc>>2]=((b[ec+8+(e+27984)>>1]|b[e+27984+ec>>1])<<16>>16!=0)+(c[gc>>2]|0);gc=d[fc+19368|0]|0;fc=e+30936+((cc^5)<<2)|0;c[fc>>2]=((b[gc+8+(e+27984)>>1]|b[e+27984+gc>>1])<<16>>16!=0)+(c[fc>>2]|0)}fc=nc+1|0;if((fc|0)>=4){break d}nc=fc;pd=c[Xc>>2]|0}}}while(0);if(!((c[Xc>>2]|0)==0|oc)){c[Uc>>2]=(c[Uc>>2]|0)+1;c[Qc>>2]=(c[Qc>>2]|0)+(c[Tc>>2]|0)}do{if(oc){dc=c[bd>>2]|0;if((dc|0)==1){pd=e+31012+(a[e+27948|0]<<2)|0;c[pd>>2]=(c[pd>>2]|0)+1;pd=e+31012+(a[e+27950|0]<<2)|0;c[pd>>2]=(c[pd>>2]|0)+1;pd=e+31012+(a[e+27964|0]<<2)|0;c[pd>>2]=(c[pd>>2]|0)+1;pd=e+31012+(a[e+27966|0]<<2)|0;c[pd>>2]=(c[pd>>2]|0)+1}else if((dc|0)==3){se=0;break}else if((dc|0)==2){dc=e+30960+(c[Cc>>2]<<2)|0;c[dc>>2]=(c[dc>>2]|0)+1}else{dc=0;do{pd=e+31064+(a[(d[19336+dc|0]|0)+(e+27936)|0]<<2)|0;c[pd>>2]=(c[pd>>2]|0)+1;dc=dc+1|0;}while((dc|0)<16)}dc=e+31116+(d[95368+(c[Sc>>2]|0)|0]<<2)|0;c[dc>>2]=(c[dc>>2]|0)+1;se=0}else{se=ic?2:1}}while(0);ic=e+31168+(se<<2)|0;c[ic>>2]=(c[ic>>2]|0)+(c[Vc>>2]|0)}if(!Nc){hPb(e)}if((rd|0)==(c[H>>2]|0)){te=be;ue=rd;break}if((c[x>>2]|0)==0){ve=Yb+1|0;we=va;xe=c[K>>2]|0}else{ic=Yb+(va&1)|0;oc=c[K>>2]|0;ve=ic;we=(ic|0)<(oc|0)^va;xe=oc}if((ve|0)!=(xe|0)){Yb=ve;va=we;od=ee;u=fe;qd=Jd;P=Kd;Ac=Ld;tc=Md;jc=Nd;Bc=Od;yc=Pd;kc=Qd;zc=Rd;wc=Sd;xc=Td;uc=Ud;vc=zd;lc=Ad;rc=Bd;sc=Dd;mc=Ed;qc=be;pc=xe;continue}Yb=0;va=we+1|0;od=ee;u=fe;qd=Jd;P=Kd;Ac=Ld;tc=Md;jc=Nd;Bc=Od;yc=Pd;kc=Qd;zc=Rd;wc=Sd;xc=Td;uc=Ud;vc=zd;lc=Ad;rc=Bd;sc=Dd;mc=Ed;qc=be;pc=xe}do{if((Ta|0)==371){c[fd>>2]=Td;c[E>>2]=Ud;if((c[r>>2]|0)==0){c[p>>2]=c[cd>>2];c[p+4>>2]=c[cd+4>>2];c[p+8>>2]=c[cd+8>>2];c[p+12>>2]=c[cd+12>>2];c[p+16>>2]=c[cd+16>>2];c[p+20>>2]=c[cd+20>>2];ye=Rd;ze=ne}else{c[n>>2]=c[l>>2];c[n+4>>2]=c[l+4>>2];c[n+8>>2]=c[l+8>>2];c[n+12>>2]=c[l+12>>2];c[n+16>>2]=c[l+16>>2];c[n+20>>2]=c[l+20>>2];c[n+24>>2]=c[l+24>>2];c[n+28>>2]=c[l+28>>2];a[(c[md>>2]|0)-1|0]=Sd;ye=be;ze=c[g>>2]|0}c[o>>2]=1;xe=M-ze|0;c[H>>2]=xe;te=ye;ue=xe}else if((Ta|0)==376){c[fd>>2]=Ld;c[E>>2]=Md;if((c[r>>2]|0)==0){c[p>>2]=c[k>>2];c[p+4>>2]=c[k+4>>2];c[p+8>>2]=c[k+8>>2];c[p+12>>2]=c[k+12>>2];c[p+16>>2]=c[k+16>>2];c[p+20>>2]=c[k+20>>2];Ae=Jd;Be=oe}else{c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];c[n+16>>2]=c[m+16>>2];c[n+20>>2]=c[m+20>>2];c[n+24>>2]=c[m+24>>2];c[n+28>>2]=c[m+28>>2];a[(c[md>>2]|0)-1|0]=Kd;Ae=be;Be=c[x>>2]|0}c[o>>2]=1;if((Be|0)==0){xe=rd-1|0;c[H>>2]=xe;te=Ae;ue=xe;break}if(sd){xe=ca(c[Yc>>2]|0,va-2+(va&1^1)|0)|0;pc=(c[K>>2]|0)-1+xe|0;c[H>>2]=pc;te=Ae;ue=pc;break}else{pc=rd-1+(c[Yc>>2]&-(va&1^1))|0;c[H>>2]=pc;te=Ae;ue=pc;break}}else if((Ta|0)==464){i=f;return td|0}}while(0);if((ue|0)<(c[N>>2]|0)){td=0;i=f;return td|0}c[(c[Q>>2]|0)+(c[F>>2]<<5)+16>>2]=ue;if((c[r>>2]|0)==0){if((te|0)>0){r=te+1|0;te=(r|0)>65535;ue=te?32:0;N=te?r>>16:r;if((N|0)>255){Ce=N>>8;De=ue|16}else{Ce=N;De=ue}ue=(d[16976+Ce|0]|0)+De>>1;De=c[y>>2]|0;Ce=c[ka>>2]|0;if((De|0)>(ue|0)){N=Ce<<ue;c[ka>>2]=N;Ee=De;Fe=N}else{N=je(Ce<<De|0)|0;c[c[w>>2]>>2]=N;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=0;Ee=De+32|0;Fe=0}De=Ee-ue|0;c[y>>2]=De;Ee=ue+1|0;if((De|0)>(Ee|0)){ue=Fe<<Ee|r;c[ka>>2]=ue;Ge=De-Ee|0;He=ue}else{ue=Ee-De|0;Ee=je(r>>>(ue>>>0)|Fe<<De|0)|0;c[c[w>>2]>>2]=Ee;c[w>>2]=(c[w>>2]|0)+4;c[ka>>2]=r;Ge=32-ue|0;He=r}c[y>>2]=Ge;Ie=He;Je=Ge}else{Ie=c[ka>>2]|0;Je=c[y>>2]|0}Ge=Ie<<1|1;c[ka>>2]=Ge;Ie=Je-1|0;c[y>>2]=Ie;do{if((Ie|0)==0){He=je(Ge|0)|0;c[c[w>>2]>>2]=He;He=(c[w>>2]|0)+4|0;c[w>>2]=He;c[y>>2]=32;Ke=c[ka>>2]|0;Le=32;Me=0;Ne=He;Ta=446}else{He=Ie&7;if((Ie|0)>(He|0)){Ke=Ge;Le=Ie;Me=He;Ne=c[w>>2]|0;Ta=446;break}else{r=je(Ge<<Ie|0)|0;c[c[w>>2]>>2]=r;r=(c[w>>2]|0)+4|0;c[w>>2]=r;c[ka>>2]=0;Oe=Je+31|0;Pe=He;Qe=0;Re=r;break}}}while(0);if((Ta|0)==446){Ta=Ke<<Me;c[ka>>2]=Ta;Oe=Le;Pe=Me;Qe=Ta;Re=Ne}Ne=Oe-Pe|0;c[y>>2]=Ne;c[Re>>2]=je(Qe<<(Ne&31)|0)|0;Ne=(c[w>>2]|0)+(4-(c[y>>2]>>3))|0;c[w>>2]=Ne;c[y>>2]=32;Se=Ne;Te=32}else{wNb(e,ld);ld=c[md>>2]|0;c[w>>2]=ld;Se=ld;Te=c[y>>2]|0}ld=c[F>>2]|0;md=c[Q>>2]|0;Ne=(c[S>>2]|0)+((32-Te+(Se-(c[A>>2]|0)<<3)|0)/8|0)|0;c[md+(ld<<5)+20>>2]=Ne-(c[md+(ld<<5)+24>>2]|0);mrc(Ne|0,-1|0,64)|0;Ne=c[e+856>>2]|0;if((Ne|0)!=0){ef[Ne&4095](e,md+(ld<<5)|0,c[(c[e+15144>>2]|0)+12008>>2]|0)}ld=(c[F>>2]|0)+1|0;c[F>>2]=ld;md=e+1484|0;Ne=c[md>>2]|0;do{if((ld|0)>=(Ne|0)){A=MLb(Ne<<6)|0;if((A|0)==0){td=-1;i=f;return td|0}else{nrc(A|0,c[Q>>2]|0,c[md>>2]<<5)|0;NLb(c[Q>>2]|0);c[Q>>2]=A;c[md>>2]=c[md>>2]<<1;break}}}while(0);md=c[J>>2]|0;if((c[H>>2]|0)!=((ca(c[K>>2]|0,md)|0)-1|0)){td=0;i=f;return td|0}c[e+30512>>2]=32-(c[y>>2]|0)+((c[w>>2]|0)-(c[q>>2]|0)<<3)+((c[F>>2]|0)*40|0)-(c[E>>2]|0)-(c[fd>>2]|0);iMb(e,md,0);md=e+12|0;do{if((c[md>>2]|0)!=0){EOb(e,1);fd=e+1452|0;E=c[fd>>2]|0;if((E|0)<=(c[J>>2]|0)){F=E;do{iMb(e,F,1);F=F+1|0;}while((F|0)<=(c[J>>2]|0))}EOb(e,2);F=c[e+1448>>2]|0;if((F|0)<=0){break}FOb(c[e+860+(F-1<<2)>>2]|0,2);iMb(e,(1<<c[x>>2])+(c[fd>>2]|0)|0,2)}}while(0);x=c[G>>2]|0;J=c[x+12016>>2]|0;if((J|0)==0){td=0;i=f;return td|0}do{if((c[md>>2]|0)!=0){if((c[e+1448>>2]|0)==((c[e+4>>2]|0)-1|0)){break}else{td=0}i=f;return td|0}}while(0);qe[J&1023](c[x+12012>>2]|0);c[(c[G>>2]|0)+12012>>2]=0;c[(c[G>>2]|0)+12016>>2]=0;td=0;i=f;return td|0}function iMb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0.0;e=i;i=i+24|0;f=e|0;g=e+8|0;j=e+16|0;k=a+15148|0;l=c[(c[k>>2]|0)+116>>2]|0;m=(c[a+8348>>2]|0)!=1|0;n=(c[a+1456>>2]|0)==(b|0);o=a+3260|0;p=c[o>>2]|0;q=1<<p;r=b-q|0;s=c[a+1452>>2]|0;t=(r|0)==(s|0);u=(r<<4)-((t&1)<<2^4)|0;v=b<<4;w=v-((n&1)<<2^4)|0;do{if((l|0)==0){if((c[a+508>>2]|0)!=0){x=1;break}x=(c[a+512>>2]|0)!=0|0}else{x=1}}while(0);y=x&m;m=a+12|0;do{if((c[m>>2]|0)==0){z=l;A=y;B=1}else{if((d|0)==2){z=l;A=0;B=0;break}else if((d|0)!=1){z=0;A=c[a+508>>2]&y;B=1;break}if(t){C=(r|0)<1|0}else{C=1}z=C&l;A=(c[a+508>>2]|0)==0&y;B=0}}while(0);if((p&b|0)!=0|(r|0)<(s|0)){i=e;return}if((A|0)!=0&(q|0)>0){q=r;do{aOb(a,q);q=(1<<c[o>>2])+q|0;}while((q|0)<(b|0))}do{if((c[a+160>>2]|0)!=0){if(!((c[m>>2]|0)==0|(d|0)==1)){break}if((c[(c[k>>2]|0)+152>>2]|0)<=0){break}q=a+18576|0;A=a+18560|0;s=0;p=c[q>>2]|0;while(1){if((p|0)==0){D=0}else{D=(s|0)!=0|0}y=(s|0)!=0|0;l=u>>D;C=p;while(1){if((l|0)>=(w>>((C|0)==0?0:y)|0)){break}x=c[k>>2]|0;E=ca(c[x+156+(s<<2)>>2]|0,l)|0;nrc((c[x+216+(s<<2)>>2]|0)+E|0,(c[x+204+(s<<2)>>2]|0)+E|0,c[A>>2]<<4)|0;l=l+1|0;C=c[q>>2]|0}l=s+1|0;if((l|0)<(c[(c[k>>2]|0)+152>>2]|0)){s=l;p=C}else{break}}}}while(0);D=c[k>>2]|0;do{if((c[D+116>>2]|0)!=0){if(!((c[m>>2]|0)==0|(d|0)==1)){break}wOb(a,D,r)}}while(0);do{if((z|0)!=0){D=(c[a+18564>>2]|0)==(b|0)|0;if((c[a+560>>2]|0)==0){break}YPb(a,c[k>>2]|0,r,D);xOb(a,c[k>>2]|0,r,D)}}while(0);r=c[o>>2]|0;if((r|0)!=0&(d|0)==0){d=a+36464|0;o=c[d>>2]|0;b=a+36500|0;c[d>>2]=c[b>>2];c[b>>2]=o;o=a+36476|0;b=c[o>>2]|0;d=a+36512|0;c[o>>2]=c[d>>2];c[d>>2]=b;b=a+36468|0;d=c[b>>2]|0;o=a+36504|0;c[b>>2]=c[o>>2];c[o>>2]=d;d=a+36480|0;o=c[d>>2]|0;b=a+36516|0;c[d>>2]=c[b>>2];c[b>>2]=o;o=a+36472|0;b=c[o>>2]|0;d=a+36508|0;c[o>>2]=c[d>>2];c[d>>2]=b;b=a+36484|0;d=c[b>>2]|0;o=a+36520|0;c[b>>2]=c[o>>2];c[o>>2]=d}do{if((c[a+1548>>2]|0)>1){d=c[k>>2]|0;if((c[d+116>>2]|0)==0){break}COb(d,(n?1e4:-24<<r)+v|0)}}while(0);if((B|0)==0){i=e;return}B=c[a+32>>2]|0;v=(w|0)<(B|0)?w:B;do{if((c[a+616>>2]|0)!=0){B=a+8632|0;w=a+36744|0;r=a+15144|0;n=a+28|0;d=v-u|0;o=0;do{b=c[k>>2]|0;z=c[b+156+(o<<2)>>2]|0;D=(c[b+204+(o<<2)>>2]|0)+(ca(z,u)|0)|0;b=c[r>>2]|0;m=c[b+156+(o<<2)>>2]|0;p=(c[b+204+(o<<2)>>2]|0)+(ca(m,u)|0)|0;b=pQb(w,D,z,p,m,c[n>>2]|0,d)|0;m=a+31192+(o<<3)|0;p=wrc(c[m>>2]|0,c[m+4>>2]|0,b,G)|0;c[m>>2]=p;c[m+4>>2]=G;o=o+1|0;F=(c[B>>2]|0)==3;}while((o|0)<((F?3:1)|0));if(F){break}o=c[a+18576>>2]|0;B=c[k>>2]|0;m=u>>o;p=c[B+160>>2]|0;b=(c[B+208>>2]|0)+(ca(p,m)|0)|0;B=c[r>>2]|0;z=c[B+160>>2]|0;D=(c[B+208>>2]|0)+(ca(z,m)|0)|0;qQb(w,b,p,D,z,c[n>>2]>>1,d>>o,f,g);o=a+31200|0;z=wrc(c[o>>2]|0,c[o+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;c[o>>2]=z;c[o+4>>2]=G;o=a+31208|0;z=wrc(c[o>>2]|0,c[o+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;c[o>>2]=z;c[o+4>>2]=G}}while(0);if((c[a+620>>2]|0)==0){i=e;return}g=u+(t?2:-6)|0;t=c[k>>2]|0;k=c[t+156>>2]|0;u=(c[t+204>>2]|0)+((ca(k,g)|0)+2)|0;t=c[a+15144>>2]|0;f=c[t+156>>2]|0;F=(c[t+204>>2]|0)+((ca(f,g)|0)+2)|0;H=+LQb(a+36744|0,u,k,F,f,(c[a+28>>2]|0)-2|0,v-g|0,c[a+36456>>2]|0,j);g=a+31216|0;h[g>>3]=+h[g>>3]+H;g=a+31224|0;c[g>>2]=(c[g>>2]|0)+(c[j>>2]|0);i=e;return}function jMb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[b>>2]=d;c[b+4>>2]=e;c[b+12>>2]=0;c[b+16>>2]=(c[a+18568>>2]|0)-1;c[b+20>>2]=c[e>>2];c[b+24>>2]=g;c[b+28>>2]=c[a+160>>2];c[b+32>>2]=0;c[b+36>>2]=0;c[b+40>>2]=f;mrc(b+44|0,0,20)|0;f=c[a+536>>2]|0;do{if((f|0)==3){if((c[a+112>>2]|0)==0){i=0;break}if((c[a+700>>2]|0)!=0){i=1;break}i=(c[a+708>>2]|0)==0}else{i=0}}while(0);j=a+28844|0;c[j>>2]=i&1;do{if((c[a+28840>>2]|0)==0){if((c[b+8>>2]|0)!=1){break}if((c[(c[a+15236>>2]|0)+144>>2]|0)!=(c[(c[a+15160>>2]|0)+4>>2]|0)){c[j>>2]=0;c[b+64>>2]=1;break}if(i){c[b+64>>2]=(c[a+33796>>2]|0)>(c[a+33792>>2]|0);break}else{c[b+64>>2]=(f|0)==1;break}}}while(0);c[b+68>>2]=0;c[b+72>>2]=1;c[b+76>>2]=1;f=c[a+15320>>2]|0;c[b+80>>2]=f;i=c[a+15324>>2]|0;j=b+84|0;c[j>>2]=i;k=d+28|0;do{if((f|0)==0){l=i}else{d=a+15152|0;if((c[d>>2]|0)>0){m=0;n=g}else{l=i;break}while(1){o=(c[a+15160+(m<<2)>>2]|0)+112|0;p=(c[o>>2]|0)-n|0;c[b+88+(m<<3)>>2]=(p|0)>0;c[b+88+(m<<3)+4>>2]=((p|0)>-1?p:-p|0)-1&(1<<c[k>>2])-1;p=m+1|0;if((p|0)>=(c[d>>2]|0)){break}m=p;n=c[o>>2]|0}l=c[j>>2]|0}}while(0);a:do{if((l|0)!=0){j=a+15156|0;if((c[j>>2]|0)>0){q=0;r=g}else{break}while(1){n=(c[a+15236+(q<<2)>>2]|0)+112|0;m=(c[n>>2]|0)-r|0;c[b+216+(q<<3)>>2]=(m|0)>0;c[b+216+(q<<3)+4>>2]=((m|0)>-1?m:-m|0)-1&(1<<c[k>>2])-1;m=q+1|0;if((m|0)>=(c[j>>2]|0)){break a}q=m;r=c[n>>2]|0}}}while(0);c[b+5096>>2]=c[a+156>>2];r=(h|0)<51?h:51;c[b+5100>>2]=r;c[b+5104>>2]=r-(c[e+36>>2]|0);c[b+5108>>2]=0;c[b+5112>>2]=0;e=a+144|0;r=c[e>>2]|0;q=a+148|0;k=c[q>>2]|0;do{if((c[a+140>>2]|0)!=0){if(!((c[a+28832>>2]|0)!=0|((((r|0)<(k|0)?r:k)<<1)+h|0)>15)){break}c[b+5116>>2]=(c[a+12>>2]|0)!=0?2:0;s=c[e>>2]|0;t=s<<1;u=b+5120|0;c[u>>2]=t;v=c[q>>2]|0;w=v<<1;x=b+5124|0;c[x>>2]=w;return}}while(0);c[b+5116>>2]=1;s=c[e>>2]|0;t=s<<1;u=b+5120|0;c[u>>2]=t;v=c[q>>2]|0;w=v<<1;x=b+5124|0;c[x>>2]=w;return}function kMb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=MLb(92)|0;f=e;do{if((e|0)!=0){mrc(e|0,0,92)|0;g=b+4|0;h=c[g>>2]|0;if((h|0)>0){i=0;do{c[(c[b+860+(i<<2)>>2]|0)+38024>>2]=f;i=i+1|0;}while((i|0)<(h|0))}c[e+4>>2]=-(c[b+96>>2]|0);do{if((c[b+692>>2]|0)==0){if((c[b+664>>2]|0)==0){j=0;break}if((c[b+696>>2]|0)==0){j=0}else{k=7}}else{k=7}}while(0);if((k|0)==7){j=(c[b+708>>2]|0)==0|0}a[e+2|0]=j;c[e+8>>2]=d;h=b+24|0;if((ROb(e+20|0,(c[h>>2]|0)+3|0)|0)!=0){break}i=b+15076|0;if((ROb(e+44|0,(c[i>>2]|0)+3|0)|0)!=0){break}if((ROb(e+68|0,(c[i>>2]|0)+3|0)|0)!=0){break}if((c[h>>2]|0)==0){l=0;return l|0}h=c[b+860+(c[g>>2]<<2)>>2]|0;nrc(h|0,b|0,50496)|0;if((ZOb(h)|0)!=0){break}if(($Ob(h,1)|0)<0){break}a[e+1|0]=1;l=0;return l|0}}while(0);NLb(e);l=-1;return l|0}function lMb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b+38024|0;if((c[b+24>>2]|0)!=0){a[c[d>>2]|0]=1;e=b+4|0;_Ob(c[b+860+(c[e>>2]<<2)>>2]|0);aPb(c[b+860+(c[e>>2]<<2)>>2]|0,1);NLb(c[b+860+(c[e>>2]<<2)>>2]|0)}SOb((c[d>>2]|0)+20|0);SOb((c[d>>2]|0)+44|0);e=c[d>>2]|0;f=c[e+12>>2]|0;if((f|0)==0){g=e;h=g+68|0;SOb(h);i=c[d>>2]|0;j=i|0;NLb(j);return}LOb(b,f);g=c[d>>2]|0;h=g+68|0;SOb(h);i=c[d>>2]|0;j=i|0;NLb(j);return}function mMb(a,b){a=a|0;b=b|0;var d=0;d=c[a+38024>>2]|0;if((c[a+24>>2]|0)==0){TOb(d+44|0,b);return}else{TOb(d+20|0,b);return}}function nMb(a){a=a|0;var b=0,d=0;b=c[a+38024>>2]|0;if((c[b+52>>2]|0)!=0){d=0;return d|0}d=(c[b+76>>2]|0)==0|0;return d|0}function oMb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[b+24>>2]|0)!=0){e=b+38024|0;f=c[e>>2]|0;g=(c[f+76>>2]|0)==0;do{if(g){h=a[f+1|0]|0;do{}while(!(h<<24>>24==0));if(!g){break}return}}while(0);g=c[f+68>>2]|0;f=a[(c[g>>2]|0)+130|0]|0;h=b+14960|0;i=c[h>>2]|0;HOb(i,KOb(g)|0);g=c[e>>2]|0;i=g+76|0;c[i>>2]=(c[i>>2]|0)-1;if(f<<24>>24==0){return}i=f&255;f=g;do{i=i-1|0;g=c[h>>2]|0;HOb(g,KOb(c[f+68>>2]|0)|0);f=c[e>>2]|0;g=f+76|0;c[g>>2]=(c[g>>2]|0)-1;}while((i|0)!=0);return}i=b+14960|0;if((c[c[i>>2]>>2]|0)!=0){return}f=b+38024|0;if((c[(c[f>>2]|0)+52>>2]|0)==0){return}zUb(b);e=c[f>>2]|0;h=c[c[e+44>>2]>>2]|0;g=c[e+12>>2]|0;if((g|0)==0){j=e}else{LOb(b,g);j=c[f>>2]|0}c[j+12>>2]=h;j=h+11960|0;c[j>>2]=(c[j>>2]|0)+1;j=c[f>>2]|0;h=j+44|0;g=(d[(c[c[h>>2]>>2]|0)+130|0]|0)+1|0;e=j+76|0;k=j+72|0;l=j+52|0;m=j+68|0;j=g;n=c[e>>2]|0;while(1){o=j-1|0;if((n|0)>=(c[k>>2]|0)){p=15;break}if((c[l>>2]|0)==0){p=17;break}q=KOb(c[h>>2]|0)|0;r=c[e>>2]|0;s=r+1|0;c[e>>2]=s;c[(c[m>>2]|0)+(r<<2)>>2]=q;c[l>>2]=(c[l>>2]|0)-1;if((o|0)==0){p=19;break}else{j=o;n=s}}if((p|0)==15){Cd(2435384,2583528,47,2649464)}else if((p|0)==17){Cd(2438808,2583528,48,2649464)}else if((p|0)==19){p=c[f>>2]|0;do{if((a[p+2|0]|0)==0){t=p}else{if(!(((c[(c[p+12>>2]|0)+16>>2]|0)-1|0)>>>0<2>>>0)){t=p;break}xUb(b,g);t=c[f>>2]|0}}while(0);if((c[t+76>>2]|0)==0){return}g=c[t+68>>2]|0;t=a[(c[g>>2]|0)+130|0]|0;b=c[i>>2]|0;HOb(b,KOb(g)|0);g=c[f>>2]|0;b=g+76|0;c[b>>2]=(c[b>>2]|0)-1;if(t<<24>>24==0){return}b=t&255;t=g;do{b=b-1|0;g=c[i>>2]|0;HOb(g,KOb(c[t+68>>2]|0)|0);t=c[f>>2]|0;g=t+76|0;c[g>>2]=(c[g>>2]|0)-1;}while((b|0)!=0);return}}function pMb(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;j=i;i=i+312|0;k=j|0;l=j+16|0;m=j+24|0;n=(g|0)!=0;if((c[f+8632>>2]|0)==1){if(n){o=(c[f+18648>>2]|0)!=0}else{o=0}p=g+2|0;q=c[f+1652+(p<<2)>>2]|0;r=f+19364|0;c[r>>2]=0;s=f+18644|0;t=(c[f+33824>>2]|0)+8|0;c[t>>2]=(c[t>>2]|0)+(c[s>>2]<<2);b[f+28036>>1]=0;b[f+28044>>1]=0;b[f+28076>>1]=0;b[f+28084>>1]=0;t=f+18640|0;do{if(o){if((((c[t>>2]|0)!=0?12:18)|0)>(h|0)){break}if((c[s>>2]|0)!=0){break}u=(c[97424+(h<<2)>>2]|0)+32>>6;v=f+37108|0;w=Xe[c[v>>2]&511](c[f+24548>>2]|0,16,c[f+24572>>2]|0,32,l|0)|0;x=u<<2;if((w|0)<(x|0)){y=(Xe[c[v>>2]&511](c[f+24552>>2]|0,16,c[f+24576>>2]|0,32,l+4|0)|0)+w|0}else{y=w}if((y|0)>=(x|0)){break}a[f+28024|0]=0;a[f+28064|0]=0;x=k|0;w=q+(((h|0)%6|0)<<6)|0;v=(h|0)/6|0;z=k+4|0;A=k+2|0;B=k+6|0;C=f+37592|0;D=f+37752|0;E=n&1^1;F=f+37728|0;G=f+1716+(p<<2)|0;H=f+1748+(p<<2)|0;I=f+37584|0;J=0;while(1){K=J+1|0;do{if((c[l+(J<<2)>>2]|0)>(u|0)){L=c[f+24568+(K<<2)>>2]|0;ef[c[I>>2]&4095](x,c[f+24544+(K<<2)>>2]|0,L);if((c[t>>2]|0)==0){M=Ee[c[F>>2]&511](x,(e[(c[G>>2]|0)+(h<<5)>>1]|0)>>>1,e[(c[H>>2]|0)+(h<<5)>>1]<<1)|0}else{M=ZTb(f,x,h,E,J+49|0)|0}if((M|0)==0){break}N=c[w>>2]<<v;if((N|0)<=2048){if((We[c[D>>2]&2047](x,N)|0)==0){break}}a[(d[J+19329|0]|0)+(f+27984)|0]=1;N=b[x>>1]|0;b[f+15456+(J<<4)>>1]=N;O=b[z>>1]|0;b[f+15456+(J<<4)+2>>1]=O;P=b[A>>1]|0;b[f+15456+(J<<4)+4>>1]=P;Q=b[B>>1]|0;b[f+15456+(J<<4)+6>>1]=Q;R=N<<16>>16;N=P<<16>>16;P=N+R|0;S=O<<16>>16;O=Q<<16>>16;Q=O+S|0;T=R-N|0;N=S-O|0;O=c[w>>2]<<v;b[x>>1]=(ca(Q+P|0,O)|0)>>>5;b[A>>1]=(ca(P-Q|0,O)|0)>>>5;b[z>>1]=(ca(N+T|0,O)|0)>>>5;b[B>>1]=(ca(T-N|0,O)|0)>>>5;re[c[C>>2]&1023](L,x);c[r>>2]=1}}while(0);if((K|0)<2){J=K}else{break}}i=j;return}}while(0);M=o?0:7;o=m+31&-32;y=f+28836|0;J=f+37656|0;x=k|0;C=o|0;B=o+32|0;z=o+64|0;A=o+96|0;v=k+4|0;w=k+2|0;D=k+6|0;E=f+37720|0;H=f+1716+(p<<2)|0;G=f+1748+(p<<2)|0;F=f+37644|0;I=f+37736|0;u=f+37764|0;L=n&1^1;O=q+(((h|0)%6|0)<<6)|0;N=(h|0)/6|0;T=f+37592|0;Q=f+37752|0;P=f+37588|0;S=f+37728|0;R=f+37760|0;U=f+33820|0;V=f+33816|0;W=f+37580|0;X=0;while(1){Y=X+1|0;Z=c[f+24544+(Y<<2)>>2]|0;_=c[f+24568+(Y<<2)>>2]|0;a:do{if((c[y>>2]|0)==0){ef[c[W>>2]&4095](o,Z,_);if((c[s>>2]|0)!=0){mf[c[R>>2]&2047](C,(c[U>>2]|0)+512|0,(c[V>>2]|0)+256|0,16);mf[c[R>>2]&2047](B,(c[U>>2]|0)+512|0,(c[V>>2]|0)+256|0,16);mf[c[R>>2]&2047](z,(c[U>>2]|0)+512|0,(c[V>>2]|0)+256|0,16);mf[c[R>>2]&2047](A,(c[U>>2]|0)+512|0,(c[V>>2]|0)+256|0,16)}$=b[C>>1]|0;aa=b[B>>1]|0;ba=aa+$|0;da=b[z>>1]|0;ea=b[A>>1]|0;fa=ea+da|0;ga=$-aa|0;aa=da-ea|0;b[x>>1]=fa+ba;b[v>>1]=aa+ga;b[w>>1]=ba-fa;b[D>>1]=ga-aa;b[C>>1]=0;b[B>>1]=0;b[z>>1]=0;b[A>>1]=0;aa=X<<4;ga=aa+16|0;do{if((c[t>>2]|0)==0){fa=Ee[c[E>>2]&511](o,(c[H>>2]|0)+(h<<5)|0,(c[G>>2]|0)+(h<<5)|0)|0;if((fa|0)==0){ha=0;ia=M;break}else{ja=M;ka=0;la=fa}while(1){ba=d[98856+la|0]|0;ea=ba+ka|0;da=la>>ba+1;ba=ga+ea|0;$=f+17024+(ba<<5)|0;ma=o+(ea<<5)|0;re[c[F>>2]&1023]($,ma);ef[c[I>>2]&4095](ma,q,h);if((ja|0)<7){na=(ve[c[u>>2]&4095]($)|0)+ja|0}else{na=ja}a[(d[19280+ba|0]|0)+(f+27984)|0]=1;if((da|0)==0){ha=fa;ia=na;break}else{ja=na;ka=ea+1|0;la=da}}}else{fa=M;da=0;ea=0;while(1){ba=o+(ea<<5)|0;if((_Tb(f,ba,p,h,4,L,1,0)|0)==0){oa=da;pa=fa}else{$=ga+ea|0;ma=f+17024+($<<5)|0;re[c[F>>2]&1023](ma,ba);ef[c[I>>2]&4095](ba,q,h);if((fa|0)<7){qa=(ve[c[u>>2]&4095](ma)|0)+fa|0}else{qa=fa}a[(d[19280+$|0]|0)+(f+27984)|0]=1;oa=1;pa=qa}$=ea+1|0;if(($|0)<4){fa=pa;da=oa;ea=$}else{ha=oa;ia=pa;break}}}}while(0);if((c[t>>2]|0)==0){ra=Ee[c[S>>2]&511](x,(e[(c[H>>2]|0)+(h<<5)>>1]|0)>>>1,e[(c[G>>2]|0)+(h<<5)>>1]<<1)|0;sa=X+49|0}else{K=X+49|0;ra=ZTb(f,x,h,L,K)|0;sa=K}K=(d[19280+sa|0]|0)+(f+27984)|0;a[K]=ra;if(!((ia|0)<7|(ha|0)==0)){c[r>>2]=1;if((ra|0)!=0){ea=b[x>>1]|0;b[f+15456+(X<<4)>>1]=ea;da=b[v>>1]|0;b[f+15456+(X<<4)+2>>1]=da;fa=b[w>>1]|0;b[f+15456+(X<<4)+4>>1]=fa;$=b[D>>1]|0;b[f+15456+(X<<4)+6>>1]=$;ma=ea<<16>>16;ea=fa<<16>>16;fa=ea+ma|0;ba=da<<16>>16;da=$<<16>>16;$=da+ba|0;ta=ma-ea|0;ea=ba-da|0;da=c[O>>2]<<N;b[C>>1]=(ca($+fa|0,da)|0)>>>5;b[B>>1]=(ca(fa-$|0,da)|0)>>>5;b[z>>1]=(ca(ea+ta|0,da)|0)>>>5;b[A>>1]=(ca(ta-ea|0,da)|0)>>>5}re[c[P>>2]&1023](_,o);break}b[(d[19280+ga|0]|0)+(f+27984)>>1]=0;b[(d[aa+19298|0]|0)+(f+27984)>>1]=0;if((ra|0)==0){break}da=c[O>>2]|0;ea=da<<N;do{if((ea|0)>2048){ua=da}else{if((We[c[Q>>2]&2047](x,ea)|0)==0){a[K]=0;break a}else{ua=c[O>>2]|0;break}}}while(0);K=b[x>>1]|0;b[f+15456+(X<<4)>>1]=K;ea=b[v>>1]|0;b[f+15456+(X<<4)+2>>1]=ea;da=b[w>>1]|0;b[f+15456+(X<<4)+4>>1]=da;aa=b[D>>1]|0;b[f+15456+(X<<4)+6>>1]=aa;ga=K<<16>>16;K=da<<16>>16;da=K+ga|0;ta=ea<<16>>16;ea=aa<<16>>16;aa=ea+ta|0;$=ga-K|0;K=ta-ea|0;ea=ua<<N;b[x>>1]=(ca(aa+da|0,ea)|0)>>>5;b[w>>1]=(ca(da-aa|0,ea)|0)>>>5;b[v>>1]=(ca(K+$|0,ea)|0)>>>5;b[D>>1]=(ca($-K|0,ea)|0)>>>5;re[c[T>>2]&1023](_,x)}else{ea=X<<4;K=ea+16|0;$=hf[c[J>>2]&1023](f+17024+(K<<5)|0,Z,_,f+15456+(X<<4)|0)|0;a[(d[19280+K|0]|0)+(f+27984)|0]=$;c[r>>2]=c[r>>2]|$;$=ea+17|0;K=hf[c[J>>2]&1023](f+17024+($<<5)|0,Z+4|0,_+4|0,f+15456+(X<<4)+2|0)|0;a[(d[19280+$|0]|0)+(f+27984)|0]=K;c[r>>2]=c[r>>2]|K;K=ea+18|0;$=hf[c[J>>2]&1023](f+17024+(K<<5)|0,Z+64|0,_+128|0,f+15456+(X<<4)+4|0)|0;a[(d[19280+K|0]|0)+(f+27984)|0]=$;c[r>>2]=c[r>>2]|$;$=ea+19|0;ea=hf[c[J>>2]&1023](f+17024+($<<5)|0,Z+68|0,_+132|0,f+15456+(X<<4)+6|0)|0;a[(d[19280+$|0]|0)+(f+27984)|0]=ea;c[r>>2]=c[r>>2]|ea;ea=0;while(1){if((ea|0)>=4){va=0;break}if((c[f+15456+(X<<4)+(ea<<1)>>2]|0)==0){ea=ea+2|0}else{va=1;break}}a[(d[X+19329|0]|0)+(f+27984)|0]=va}}while(0);if((Y|0)<2){X=Y}else{break}}X=c[r>>2]|0;c[r>>2]=((a[f+28064|0]|a[f+28024|0])&255|X)+X;i=j;return}if(n){wa=(c[f+18648>>2]|0)!=0}else{wa=0}X=g+2|0;g=c[f+1652+(X<<2)>>2]|0;r=f+19364|0;c[r>>2]=0;va=f+18644|0;J=(c[f+33824>>2]|0)+8|0;c[J>>2]=(c[J>>2]|0)+(c[va>>2]<<2);b[f+28036>>1]=0;b[f+28044>>1]=0;b[f+28076>>1]=0;b[f+28084>>1]=0;b[f+28052>>1]=0;b[f+28060>>1]=0;b[f+28092>>1]=0;b[f+28100>>1]=0;J=f+18640|0;do{if(wa){if((((c[J>>2]|0)!=0?12:18)|0)>(h|0)){break}if((c[va>>2]|0)!=0){break}x=(c[97424+(h<<2)>>2]|0)+16>>5;T=f+37104|0;D=Xe[c[T>>2]&511](c[f+24548>>2]|0,16,c[f+24572>>2]|0,32,l|0)|0;v=x<<2;if((D|0)<(v|0)){xa=(Xe[c[T>>2]&511](c[f+24552>>2]|0,16,c[f+24576>>2]|0,32,l+4|0)|0)+D|0}else{xa=D}if((xa|0)>=(v|0)){break}a[f+28024|0]=0;a[f+28064|0]=0;v=f+37596|0;D=k|0;T=h+3|0;w=g+(((T|0)%6|0)<<6)|0;N=(T|0)/6|0;ua=k+4|0;O=k+2|0;Q=k+8|0;ra=k+12|0;o=k+6|0;P=k+10|0;A=k+14|0;z=f+37748|0;B=f+37592|0;C=f+37756|0;ha=n&1^1;ia=f+37728|0;sa=f+1716+(X<<2)|0;L=f+1748+(X<<2)|0;G=0;while(1){H=G+1|0;do{if((c[l+(G<<2)>>2]|0)>(x|0)){S=c[f+24568+(H<<2)>>2]|0;ef[c[v>>2]&4095](D,c[f+24544+(H<<2)>>2]|0,S);if((c[J>>2]|0)==0){t=Ee[c[ia>>2]&511](D,(e[(c[sa>>2]|0)+(T<<5)>>1]|0)>>>1,e[(c[L>>2]|0)+(T<<5)>>1]<<1)|0;ya=Ee[c[ia>>2]&511](Q,(e[(c[sa>>2]|0)+(T<<5)>>1]|0)>>>1,e[(c[L>>2]|0)+(T<<5)>>1]<<1)|0|t}else{ya=ZTb(f,D,T,ha,G+49|0)|0}if((ya|0)==0){break}t=c[w>>2]<<N;if((t|0)<=2048){if((We[c[C>>2]&2047](D,t)|0)==0){break}}a[(d[G+19329|0]|0)+(f+27984)|0]=1;b[f+15456+(G<<4)>>1]=b[D>>1]|0;b[f+15456+(G<<4)+2>>1]=b[ua>>1]|0;b[f+15456+(G<<4)+4>>1]=b[O>>1]|0;b[f+15456+(G<<4)+6>>1]=b[Q>>1]|0;b[f+15456+(G<<4)+8>>1]=b[ra>>1]|0;b[f+15456+(G<<4)+10>>1]=b[o>>1]|0;b[f+15456+(G<<4)+12>>1]=b[P>>1]|0;b[f+15456+(G<<4)+14>>1]=b[A>>1]|0;ef[c[z>>2]&4095](D,g,T);re[c[B>>2]&1023](S,D);re[c[B>>2]&1023](S+256|0,Q);c[r>>2]=1}}while(0);if((H|0)<2){G=H}else{break}}i=j;return}}while(0);ya=wa?0:7;wa=m+31&-32;m=f+28836|0;l=f+37656|0;xa=f+37636|0;G=k|0;Q=k+4|0;B=k+2|0;D=k+6|0;T=f+37720|0;z=f+1716+(X<<2)|0;A=f+1748+(X<<2)|0;P=f+37644|0;o=f+37736|0;ra=f+37764|0;O=n&1^1;n=h+3|0;ua=g+(((n|0)%6|0)<<6)|0;C=(n|0)/6|0;N=k+8|0;w=k+12|0;ha=k+10|0;L=k+14|0;k=f+37748|0;sa=f+37592|0;ia=f+37756|0;v=f+37744|0;x=f+37588|0;Y=f+37728|0;S=f+37760|0;t=f+33820|0;pa=f+33816|0;oa=f+37580|0;qa=0;while(1){u=qa+1|0;q=c[f+24544+(u<<2)>>2]|0;I=c[f+24568+(u<<2)>>2]|0;b:do{if((c[m>>2]|0)==0){ef[c[oa>>2]&4095](wa,q,I);F=wa+128|0;p=I+256|0;ef[c[oa>>2]&4095](F,q+128|0,p);if((c[va>>2]|0)!=0){mf[c[S>>2]&2047](wa|0,(c[t>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16);mf[c[S>>2]&2047](wa+32|0,(c[t>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16);mf[c[S>>2]&2047](wa+64|0,(c[t>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16);mf[c[S>>2]&2047](wa+96|0,(c[t>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16);mf[c[S>>2]&2047](wa+128|0,(c[t>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16);mf[c[S>>2]&2047](wa+160|0,(c[t>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16);mf[c[S>>2]&2047](wa+192|0,(c[t>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16);mf[c[S>>2]&2047](wa+224|0,(c[t>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16)}re[c[xa>>2]&1023](G,wa);M=qa<<4;la=M+16|0;ka=ya;na=0;ja=0;E=(c[J>>2]|0)!=0;while(1){do{if(E){V=ja<<2;U=(ja<<3)+la|0;R=ka;s=na;W=0;while(1){y=wa+(W+V<<5)|0;if((_Tb(f,y,X,h,4,O,1,0)|0)==0){za=s;Aa=R}else{_=U+W|0;Z=f+17024+(_<<5)|0;re[c[P>>2]&1023](Z,y);ef[c[o>>2]&4095](y,g,h);if((R|0)<7){Ba=(ve[c[ra>>2]&4095](Z)|0)+R|0}else{Ba=R}a[(d[19280+_|0]|0)+(f+27984)|0]=1;za=1;Aa=Ba}_=W+1|0;if((_|0)<4){R=Aa;s=za;W=_}else{Ca=za;Da=Aa;break}}}else{W=ja<<2;s=Ee[c[T>>2]&511](wa+(W<<5)|0,(c[z>>2]|0)+(h<<5)|0,(c[A>>2]|0)+(h<<5)|0)|0;R=s|na;if((s|0)==0){Ca=R;Da=ka;break}U=(ja<<3)+la|0;V=ka;_=0;Z=s;while(1){s=d[98856+Z|0]|0;y=s+_|0;ea=Z>>s+1;s=U+y|0;$=f+17024+(s<<5)|0;K=wa+(y+W<<5)|0;re[c[P>>2]&1023]($,K);ef[c[o>>2]&4095](K,g,h);if((V|0)<7){Ea=(ve[c[ra>>2]&4095]($)|0)+V|0}else{Ea=V}a[(d[19280+s|0]|0)+(f+27984)|0]=1;if((ea|0)==0){Ca=R;Da=Ea;break}else{V=Ea;_=y+1|0;Z=ea}}}}while(0);Z=ja+1|0;Fa=(c[J>>2]|0)!=0;if((Z|0)<2){ka=Da;na=Ca;ja=Z;E=Fa}else{break}}if(Fa){E=qa+49|0;Ga=ZTb(f,G,n,O,E)|0;Ha=E}else{E=Ee[c[Y>>2]&511](G,(e[(c[z>>2]|0)+(n<<5)>>1]|0)>>>1,e[(c[A>>2]|0)+(n<<5)>>1]<<1)|0;Ga=Ee[c[Y>>2]&511](N,(e[(c[z>>2]|0)+(n<<5)>>1]|0)>>>1,e[(c[A>>2]|0)+(n<<5)>>1]<<1)|0|E;Ha=qa+49|0}E=(d[19280+Ha|0]|0)+(f+27984)|0;a[E]=Ga;if(!((Da|0)<7|(Ca|0)==0)){c[r>>2]=1;if((Ga|0)!=0){b[f+15456+(qa<<4)>>1]=b[G>>1]|0;b[f+15456+(qa<<4)+2>>1]=b[Q>>1]|0;b[f+15456+(qa<<4)+4>>1]=b[B>>1]|0;b[f+15456+(qa<<4)+6>>1]=b[N>>1]|0;b[f+15456+(qa<<4)+8>>1]=b[w>>1]|0;b[f+15456+(qa<<4)+10>>1]=b[D>>1]|0;b[f+15456+(qa<<4)+12>>1]=b[ha>>1]|0;b[f+15456+(qa<<4)+14>>1]=b[L>>1]|0;mf[c[v>>2]&2047](G,wa,g,n)}re[c[x>>2]&1023](I,wa);re[c[x>>2]&1023](p,F);break}b[(d[19280+la|0]|0)+(f+27984)>>1]=0;b[(d[M+19298|0]|0)+(f+27984)>>1]=0;b[(d[M+19304|0]|0)+(f+27984)>>1]=0;b[(d[M+19306|0]|0)+(f+27984)>>1]=0;if((Ga|0)==0){break}ja=c[ua>>2]<<C;do{if((ja|0)<=2048){if((We[c[ia>>2]&2047](G,ja)|0)!=0){break}a[E]=0;break b}}while(0);b[f+15456+(qa<<4)>>1]=b[G>>1]|0;b[f+15456+(qa<<4)+2>>1]=b[Q>>1]|0;b[f+15456+(qa<<4)+4>>1]=b[B>>1]|0;b[f+15456+(qa<<4)+6>>1]=b[N>>1]|0;b[f+15456+(qa<<4)+8>>1]=b[w>>1]|0;b[f+15456+(qa<<4)+10>>1]=b[D>>1]|0;b[f+15456+(qa<<4)+12>>1]=b[ha>>1]|0;b[f+15456+(qa<<4)+14>>1]=b[L>>1]|0;ef[c[k>>2]&4095](G,g,n);re[c[sa>>2]&1023](I,G);re[c[sa>>2]&1023](p,N)}else{E=(qa<<4)+16|0;ja=0;while(1){M=ja<<2&4;la=ja>>1;F=E+ja+(ja&4)|0;na=hf[c[l>>2]&1023](f+17024+(F<<5)|0,q+(M|la<<6)|0,I+(M|la<<7)|0,f+15456+(qa<<4)+(d[95336+ja|0]<<1)|0)|0;a[(d[19280+F|0]|0)+(f+27984)|0]=na;c[r>>2]=c[r>>2]|na;na=ja+1|0;if((na|0)<8){ja=na}else{Ia=0;break}}while(1){if((Ia|0)>=8){Ja=0;break}if((c[f+15456+(qa<<4)+(Ia<<1)>>2]|0)==0){Ia=Ia+2|0}else{Ja=1;break}}a[(d[qa+19329|0]|0)+(f+27984)|0]=Ja}}while(0);if((u|0)<2){qa=u}else{break}}qa=c[r>>2]|0;c[r>>2]=((a[f+28064|0]|a[f+28024|0])&255|qa)+qa;i=j;return}function qMb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=16>>>((c[b+18576>>2]|0)>>>0);if((e|0)==2){g=b+37448|0;h=b+24572|0;pe[c[g>>2]&1023](c[h>>2]|0,32,(c[b+24548>>2]|0)-16|0,16,f);i=b+24576|0;pe[c[g>>2]&1023](c[i>>2]|0,32,(c[b+24552>>2]|0)-16|0,16,f);g=c[h>>2]|0;h=g-32|0;j=g;g=h|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j|0;y=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+4|0;y=h;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=c[i>>2]|0;i=k-32|0;h=k;k=i|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=h+4|0;y=i;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;return}else if((e|0)==1){j=b+37448|0;i=b+24572|0;pe[c[j>>2]&1023](c[i>>2]|0,32,(c[b+24548>>2]|0)-1|0,16,f);h=b+24576|0;pe[c[j>>2]&1023](c[h>>2]|0,32,(c[b+24552>>2]|0)-1|0,16,f);f=c[i>>2]|0;ePb(f+128|0,f+127|0);f=c[h>>2]|0;ePb(f+128|0,f+127|0);if((c[b+8632>>2]|0)!=2){return}f=c[i>>2]|0;ePb(f+384|0,f+383|0);f=c[h>>2]|0;ePb(f+384|0,f+383|0);return}else{f=b+36656+(e<<2)|0;qe[c[f>>2]&1023](c[b+24572>>2]|0);qe[c[f>>2]&1023](c[b+24576>>2]|0);return}}function rMb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=c[(c[a+15144>>2]|0)+156+(e<<2)>>2]<<c[a+18660>>2];i=c[a+24556+(e<<2)>>2]|0;e=(ca(h<<2,d[1901384+f|0]|0)|0)+((d[1901592+f|0]|0)<<2)|0;if((g|0)==1){pe[c[a+37460>>2]&1023](b,32,i+(e-1)|0,h,4);return}else if((g|0)==0){pe[c[a+37460>>2]&1023](b,32,i+(e-h)|0,h,4);return}else{qe[c[a+36608+(g<<2)>>2]&1023](b);return}}function sMb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=c[(c[a+15144>>2]|0)+156+(d<<2)>>2]<<c[a+18660>>2];i=c[a+24556+(d<<2)>>2]|0;d=(ca(e>>>1<<3,h)|0)+(e<<3&8)|0;if((f|0)==0){pe[c[a+37448>>2]&1023](b,32,i+(d-h)|0,h,8);return}else if((f|0)==1){pe[c[a+37448>>2]&1023](b,32,i+(d-1)|0,h,8);return}else{re[c[a+36560+(f<<2)>>2]&1023](b,g);return}}function tMb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[(c[a+15144>>2]|0)+156+(b<<2)>>2]<<c[a+18660>>2];if((d|0)==1){pe[c[a+37464>>2]&1023](c[a+24568+(b<<2)>>2]|0,32,(c[a+24556+(b<<2)>>2]|0)-1|0,e,16);return}else if((d|0)==0){pe[c[a+37436>>2]&1023](c[a+24568+(b<<2)>>2]|0,32,(c[a+24556+(b<<2)>>2]|0)+(-e|0)|0,e,16);return}else{qe[c[a+36532+(d<<2)>>2]&1023](c[a+24568+(b<<2)>>2]|0);return}}



function W4(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;f=i;i=i+32|0;h=f|0;j=(e|0)!=0;e=a+290776|0;k=c[e>>2]|0;l=c[a+290784>>2]|0;m=c[a+290768>>2]|0;if(j){n=m+(k>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7)>>>25;n=k+7|0;p=l>>>0>n>>>0?n:l;c[e>>2]=p;q=k;r=(o<<3)+8|0;s=p}else{q=0;r=0;s=k}k=a+290776|0;p=a+290784|0;o=a+290768|0;e=m+(s>>>3)|0;n=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(s&7)>>>29;e=s+3|0;s=l>>>0>e>>>0?e:l;c[k>>2]=s;e=n+1|0;n=e+b|0;c[a+116>>2]=n;t=a+120|0;c[t>>2]=n;do{if(j){u=a+290816|0;v=c[u>>2]|0;w=m+(s>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(s&7)>>>((38-v|0)>>>0);w=v-6+s|0;c[k>>2]=l>>>0>w>>>0?w:l;w=a+290812|0;c[a+290824+(c[w>>2]<<2)>>2]=x<<6;c[a+290840+(c[w>>2]<<2)>>2]=e;x=c[k>>2]|0;v=c[o>>2]|0;y=d[v+(x>>>3)|0]|0;z=c[p>>2]|0;A=((x|0)<(z|0))+x|0;c[k>>2]=A;if((y&128>>>((x&7)>>>0)|0)==0){B=c[t>>2]|0;break}x=(d[v+(A>>>3)|0]|0)<<(A&7)>>>7;y=((A|0)<(z|0))+A|0;c[k>>2]=y;A=x&1;x=v+(y>>>3)|0;v=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7)>>>26;x=y+6|0;c[k>>2]=z>>>0>x>>>0?x:z;g[a+290856+(c[w>>2]<<2)>>2]=1.0/+g[1611888+((v<<2)-4<<2)>>2];v=c[t>>2]|0;z=(v|0)>(b|0);if(!z){B=v;break}x=c[u>>2]|0;y=c[p>>2]|0;C=c[o>>2]|0;D=b;E=c[k>>2]|0;do{F=C+(E>>>3)|0;G=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>((32-x|0)>>>0);F=E+x|0;E=y>>>0>F>>>0?F:y;c[k>>2]=E;c[h+(D<<2)>>2]=G;D=D+1|0;}while((D|0)<(v|0));if(!z){B=v;break}D=a+290872|0;E=a+4|0;y=a+290820|0;x=b;while(1){mrc(a+290876+(x<<7)|0,0,128)|0;c[D>>2]=c[D>>2]|A<<x;if((c[u>>2]|0)>0){C=c[h+(x<<2)>>2]|0;G=0;do{F=1<<G;do{if((C&F|0)!=0){if((F|0)==32){KIb(c[E>>2]|0,24,2382904,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;break}H=c[k>>2]|0;I=c[p>>2]|0;J=(c[o>>2]|0)+(H>>>3)|0;K=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>25;J=H+7|0;c[k>>2]=I>>>0>J>>>0?J:I;L=(K&64|0)!=0?1.0:-1.0;M=+g[1611888+((K<<2&252)-4<<2)>>2];K=c[y>>2]&-33;I=c[w>>2]|0;a:do{if((I|0)<-1){N=0;O=K}else{J=-1;H=0;P=K;while(1){if((P&F|0)!=0){N=H;O=P;break a}Q=P-(P>>>1&1431655765)|0;R=(Q>>>2&858993459)+(Q&858993459)|0;Q=(R>>>4)+R&252645135;R=(Q>>>8)+Q|0;Q=((R>>>16)+R&63)+H|0;R=J+1|0;S=c[a+290824+(R<<2)>>2]|0;if((R|0)>(I|0)){N=Q;O=S;break}else{J=R;H=Q;P=S}}}}while(0);I=O&F-1;K=I-(I>>>1&1431655765)|0;I=(K>>>2&858993459)+(K&858993459)|0;K=(I>>>4)+I&252645135;I=(K>>>8)+K|0;g[a+290876+(x<<7)+(((I>>>16)+I&63)+N<<2)>>2]=M*L}}while(0);G=G+1|0;}while((G|0)<(c[u>>2]|0))}G=x+1|0;C=c[t>>2]|0;if((G|0)<(C|0)){x=G}else{B=C;break}}}else{B=n}}while(0);if((B|0)>7){c[t>>2]=7;T=7}else{T=B}if((T|0)>(b|0)){B=b;while(1){n=c[k>>2]|0;N=c[p>>2]|0;O=(c[o>>2]|0)+(n>>>3)|0;h=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(n&7)>>>27;O=n+5|0;c[k>>2]=N>>>0>O>>>0?O:N;c[a+124+(B<<2)>>2]=h+2;h=B+1|0;N=c[t>>2]|0;if((h|0)<(N|0)){B=h}else{U=N;break}}}else{U=T}if((U|0)>(b|0)){T=b;while(1){B=c[k>>2]|0;N=c[p>>2]|0;h=(c[o>>2]|0)+(B>>>3)|0;O=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(B&7)>>>27;h=B+5|0;c[k>>2]=N>>>0>h>>>0?h:N;c[a+152+(T<<2)>>2]=O+1;O=T+1|0;N=c[t>>2]|0;if((O|0)<(N|0)){T=O}else{V=N;break}}}else{V=U}if((V|0)==(b|0)){W=V}else{U=c[o>>2]|0;T=V-b|0;V=a+180+(b<<2)|0;while(1){N=T-1|0;O=c[k>>2]|0;h=c[p>>2]|0;B=U+(O>>>3)|0;n=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(O&7)>>>29;B=O+3|0;c[k>>2]=h>>>0>B>>>0?B:h;c[V>>2]=n;if((N|0)==0){break}T=N;V=V+4|0}W=c[t>>2]|0}b:do{if((W|0)!=(b|0)){V=c[o>>2]|0;T=W-b|0;U=a+208+(b<<2)|0;while(1){N=T-1|0;n=c[k>>2]|0;h=c[p>>2]|0;B=V+(n>>>3)|0;O=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(n&7)>>>30;B=n+2|0;c[k>>2]=h>>>0>B>>>0?B:h;c[U>>2]=O;if((N|0)==0){break}T=N;U=U+4|0}U=c[t>>2]|0;if((U|0)==(b|0)){break}T=c[o>>2]|0;V=U-b|0;U=a+236+(b<<2)|0;while(1){N=V-1|0;O=c[k>>2]|0;h=c[p>>2]|0;B=T+(O>>>3)|0;n=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(O&7)>>>29;B=O+3|0;c[k>>2]=h>>>0>B>>>0?B:h;c[U>>2]=n;if((N|0)==0){break}V=N;U=U+4|0}U=c[t>>2]|0;if((U|0)==(b|0)){break}V=c[o>>2]|0;T=U-b|0;U=a+264+(b<<2)|0;while(1){N=T-1|0;n=c[k>>2]|0;h=c[p>>2]|0;B=V+(n>>>3)|0;O=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(n&7)>>>29;B=n+3|0;c[k>>2]=h>>>0>B>>>0?B:h;c[U>>2]=O;if((N|0)==0){break b}T=N;U=U+4|0}}}while(0);if((b|0)==0){mrc(a+292|0,0,896)|0}W=1;U=c[t>>2]|0;while(1){if((U|0)>(b|0)){T=c[1611768+(W<<2)>>2]|0;V=32-T|0;N=b;while(1){O=c[k>>2]|0;h=c[p>>2]|0;B=(c[o>>2]|0)+(O>>>3)|0;n=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(O&7)>>>(V>>>0);B=O+T|0;c[k>>2]=h>>>0>B>>>0?B:h;c[a+292+(N<<7)+(W<<2)>>2]=n;n=N+1|0;h=c[t>>2]|0;if((n|0)<(h|0)){N=n}else{X=h;break}}}else{X=U}N=W+1|0;if((N|0)<11){W=N;U=X}else{Y=0;Z=X;break}}while(1){if((Z|0)>(b|0)){X=b;while(1){g[a+1188+(X<<7)+(Y<<2)>>2]=1.0;U=X+1|0;W=c[t>>2]|0;if((U|0)<(W|0)){X=U}else{_=W;break}}}else{_=Z}X=Y+1|0;if((X|0)<11){Y=X;Z=_}else{$=1;aa=_;break}}while(1){if((aa|0)>(b|0)){_=c[1611720+($<<2)>>2]|0;Z=b;Y=aa;while(1){if((c[a+292+(Z<<7)+($<<2)>>2]|0)<(_|0)){X=c[k>>2]|0;W=c[p>>2]|0;U=(c[o>>2]|0)+(X>>>3)|0;N=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(X&7)>>>30;U=X+2|0;c[k>>2]=W>>>0>U>>>0?U:W;g[a+1188+(Z<<7)+($<<2)>>2]=+g[1611816+(N<<2)>>2];ba=c[t>>2]|0}else{ba=Y}N=Z+1|0;if((N|0)<(ba|0)){Z=N;Y=ba}else{ca=ba;break}}}else{ca=aa}Y=$+1|0;if((Y|0)<11){$=Y;aa=ca}else{break}}if(!j){if((c[a+16>>2]|0)==0){da=a+290788|0;c[da>>2]=0;ea=a+290792|0;c[ea>>2]=0;i=f;return}j=c[p>>2]|0;ca=(c[k>>2]|0)+16|0;c[k>>2]=j>>>0>ca>>>0?ca:j;da=a+290788|0;c[da>>2]=0;ea=a+290792|0;c[ea>>2]=0;i=f;return}j=c[k>>2]|0;ca=q+r|0;if((ca|0)<=(j|0)){da=a+290788|0;c[da>>2]=0;ea=a+290792|0;c[ea>>2]=0;i=f;return}r=ca-j|0;ca=-j|0;q=(c[p>>2]|0)-j|0;if((r|0)<(ca|0)){fa=ca}else{fa=(q|0)<(r|0)?q:r}c[k>>2]=fa+j;da=a+290788|0;c[da>>2]=0;ea=a+290792|0;c[ea>>2]=0;i=f;return}function X4(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+32|0;e=b|0;f=a+290776|0;g=c[f>>2]|0;h=a+290784|0;j=c[h>>2]|0;k=c[a+290768>>2]|0;l=k+(g>>>3)|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(g&7)>>>26;l=g+6|0;n=(j>>>0>l>>>0?l:j)+1|0;l=j>>>0>n>>>0?n:j;c[f>>2]=l;n=k+(l>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(l&7)>>>27;n=l+5|0;l=j>>>0>n>>>0?n:j;c[f>>2]=l;n=o+1|0;p=k+(l>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(l&7)>>>30;p=l+2|0;l=j>>>0>p>>>0?p:j;c[f>>2]=l;p=q+1|0;q=k+(l>>>3)|0;r=0;s=l;t=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(l&7);do{l=s+14|0;s=j>>>0>l>>>0?l:j;c[f>>2]=s;c[e+(r<<2)>>2]=(t>>>18)+1;r=r+1|0;l=k+(s>>>3)|0;t=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(s&7)}while((r|0)<(p|0));r=s+n|0;s=j>>>0>r>>>0?r:j;c[f>>2]=s;c[a+290820>>2]=t>>>((o^31)>>>0);c[a+290816>>2]=n;c[a+290872>>2]=0;n=g-24+(m<<3)|0;if((n|0)>(s|0)){m=n-s|0;n=-s|0;g=j-s|0;if((m|0)<(n|0)){u=n}else{u=(g|0)<(m|0)?g:m}m=u+s|0;c[f>>2]=m;v=m}else{v=s}s=a+120|0;m=a+290812|0;u=a+20|0;g=a+4|0;n=0;j=v;while(1){v=c[s>>2]|0;c[m>>2]=n;W4(a,v,1);if((c[u>>2]|0)>7){o=0;do{if((V4(a,v,o)|0)!=0){KIb(c[g>>2]|0,16,2389840,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}o=o+1|0;}while((o|0)<((c[u>>2]|0)/8|0|0))}o=c[f>>2]|0;v=(c[e+(n<<2)>>2]<<3)+j|0;if((v|0)>(o|0)){t=v-o|0;v=-o|0;r=(c[h>>2]|0)-o|0;if((t|0)<(v|0)){w=v}else{w=(r|0)<(t|0)?r:t}t=w+o|0;c[f>>2]=t;x=t}else{x=o}o=n+1|0;if((o|0)<(p|0)){n=o;j=x}else{break}}c[m>>2]=p;i=b;return}function Y4(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((e|0)<5){h=c[9677340+(e*20|0)>>2]|0;i=c[9677336+(e*20|0)>>2]|0;j=c[2419333]|0;k=a+8|0;l=c[k>>2]|0;m=c[a+16>>2]|0;n=c[a>>2]|0;o=n+(l>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>((32-i|0)>>>0);o=b[h+(p<<2)>>1]|0;q=b[h+(p<<2)+2>>1]|0;p=q<<16>>16;do{if((j|0)>1&q<<16>>16<0){r=l+i|0;s=m>>>0>r>>>0?r:m;r=n+(s>>>3)|0;t=((je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((p+32|0)>>>0))+o|0;r=b[h+(t<<2)>>1]|0;u=b[h+(t<<2)+2>>1]|0;t=u<<16>>16;if(!((j|0)>2&u<<16>>16<0)){v=t;w=r;x=s;break}u=s-p|0;s=m>>>0>u>>>0?u:m;u=n+(s>>>3)|0;y=((je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(s&7)>>>((t+32|0)>>>0))+r|0;v=b[h+(y<<2)+2>>1]|0;w=b[h+(y<<2)>>1]|0;x=s}else{v=p;w=o;x=l}}while(0);l=v+x|0;c[k>>2]=m>>>0>l>>>0?l:m;m=w+f+(c[2419324]|0)|0;w=(1<<g)-1|0;if((m|0)<0){z=0;return z|0}z=(m|0)>(w|0)?w:m;return z|0}else{if((e|0)>=8){z=f;return z|0}f=e+1|0;if((f|0)>(g|0)){m=a+8|0;w=c[a+16>>2]|0;l=(c[m>>2]|0)+(f-g)|0;k=w>>>0>l>>>0?l:w;c[m>>2]=k;l=(c[a>>2]|0)+(k>>>3)|0;x=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(k&7)>>>((32-g|0)>>>0);l=k+g|0;c[m>>2]=w>>>0>l>>>0?l:w;z=x;return z|0}else{x=a+8|0;w=c[x>>2]|0;l=c[a+16>>2]|0;m=(c[a>>2]|0)+(w>>>3)|0;a=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(w&7)>>>((31-e|0)>>>0);e=w+f|0;c[x>>2]=l>>>0>e>>>0?e:l;z=a;return z|0}}return 0}function Z4(a){a=a|0;c[a>>2]=660;c[a+4>>2]=994;c[a+8>>2]=2;c[a+12>>2]=10;return}function _4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0;d=c;c=a+252|0;e=a;a=0;while(1){f=+g[b>>2];h=+g[d>>2];i=+g[b-28>>2];j=+g[b-4>>2];k=+g[d+4>>2];l=+g[b-24>>2];m=+g[b-8>>2];n=+g[d+8>>2];o=+g[b-20>>2];p=+g[b-12>>2];q=+g[d+12>>2];r=+g[b-16>>2];s=+g[d+16>>2];t=+g[d+20>>2];u=+g[d+24>>2];v=+g[d+28>>2];g[e>>2]=f*h+0.0+j*k+m*n+p*q+r*s+o*t+l*u+i*v;g[c>>2]=h*i+0.0+k*l+n*o+q*r+s*p+t*m+u*j+v*f;w=a+1|0;if((w|0)<32){d=d+32|0;c=c-4|0;e=e+4|0;a=w}else{break}}return}function $4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0;d=c;c=a+508|0;e=a;a=0;while(1){f=+g[b>>2];h=+g[d>>2];i=+g[b-12>>2];j=+g[b-4>>2];k=+g[d+4>>2];l=+g[b-8>>2];m=+g[d+8>>2];n=+g[d+12>>2];g[e>>2]=f*h+0.0+j*k+l*m+i*n;g[c>>2]=h*i+0.0+k*l+m*j+n*f;o=a+1|0;if((o|0)<64){d=d+16|0;c=c-4|0;e=e+4|0;a=o}else{break}}return}function a5(a,b,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=+l;var m=0,n=0;do{if((b|0)<32){mrc(k+(b<<2)|0,0,128-(b<<2)|0)|0;m=d|0;if((b|0)>0){n=m;break}He[c[m>>2]&3](e,f,g,h,i,j,k,l);He[c[m>>2]&3](e,f,g,h,i,j+128|0,k,l);He[c[m>>2]&3](e,f,g,h,i,j+256|0,k,l);He[c[m>>2]&3](e,f,g,h,i,j+384|0,k,l);He[c[m>>2]&3](e,f,g,h,i,j+512|0,k,l);He[c[m>>2]&3](e,f,g,h,i,j+640|0,k,l);He[c[m>>2]&3](e,f,g,h,i,j+768|0,k,l);He[c[m>>2]&3](e,f,g,h,i,j+896|0,k,l);return}else{n=d|0}}while(0);d=0;m=j;while(1){j=0;do{c[k+(j<<2)>>2]=c[a+(j<<5)+(d<<2)>>2]^(j<<30)-1073741824&-2147483648;j=j+1|0;}while((j|0)<(b|0));He[c[n>>2]&3](e,f,g,h,i,m,k,l);j=d+1|0;if((j|0)<8){d=j;m=m+128|0}else{break}}return}function b5(b,d,e,f,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0,l=0.0;if((i|0)<(j|0)){k=i}else{return}do{i=c[d+(k<<2)>>2]|0;l=+(c[h+(k<<3)>>2]|0)*.0625;g[b+(k<<5)>>2]=l*+(a[e+(i<<5)+f|0]|0);g[b+(k<<5)+4>>2]=l*+(a[f+1+(e+(i<<5))|0]|0);g[b+(k<<5)+8>>2]=l*+(a[f+2+(e+(i<<5))|0]|0);g[b+(k<<5)+12>>2]=l*+(a[f+3+(e+(i<<5))|0]|0);g[b+(k<<5)+16>>2]=l*+(a[f+4+(e+(i<<5))|0]|0);g[b+(k<<5)+20>>2]=l*+(a[f+5+(e+(i<<5))|0]|0);g[b+(k<<5)+24>>2]=l*+(a[f+6+(e+(i<<5))|0]|0);g[b+(k<<5)+28>>2]=l*+(a[f+7+(e+(i<<5))|0]|0);k=k+1|0;}while((k|0)<(j|0));return}function c5(a){a=a|0;var b=0,d=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0.0,D=0.0,E=0.0,F=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0,N=0;b=i;d=c[a+60>>2]|0;f=a+448|0;h=c[f>>2]|0;j=c[f+4>>2]|0;f=a+416|0;k=c[f>>2]|0;c[d+36>>2]=k;l=d+32|0;c[l>>2]=k;k=c[f>>2]|0;if((k|0)==3){m=1}else{m=(k|0)==6|0}k=d+40|0;c[k>>2]=m;c[d+56>>2]=9901104;c[d+60>>2]=9899024;c[d+44016>>2]=-2047;c[d+44020>>2]=-2047;if((h|0)==0&(j|0)==0){KIb(a,24,2123280,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=tGb(c[f>>2]|0)|0;o=G;p=m}else{o=j;p=h}h=1543;j=0;m=1539;f=0;q=3;r=0;s=4;t=0;if((p|0)==1551&(o|0)==0){c[d+52>>2]=9}else if((p|0)==(h|0)&(o|0)==(j|0)){c[d+52>>2]=9}else if((p|0)==(m|0)&(o|0)==(f|0)){c[d+52>>2]=8}else if((p|0)==(s|0)&(o|0)==(t|0)){c[d+52>>2]=0}else if((p|0)==(q|0)&(o|0)==(r|0)){c[d+52>>2]=2}else{KIb(a,16,2640936,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;u=-1163346256;i=b;return u|0}if((c[k>>2]|0)!=0){c[l>>2]=(c[l>>2]|0)-1}r=a+412|0;o=0;while(1){if((o|0)>=9){break}if((c[612080+(o<<2)>>2]|0)==(c[r>>2]|0)){break}else{o=o+1|0}}if((o|0)==9){u=-22;i=b;return u|0}c[d+44>>2]=o;o=a+72|0;q=c[o>>2]|0;if((q-32e3|0)>>>0>3808e3>>>0){KIb(a,16,2618184,(n=i,i=i+8|0,c[n>>2]=q,n)|0);i=n;u=-22;i=b;return u|0}else{v=0}while(1){w=c[1614120+(v<<2)>>2]|0;if(w>>>0<q>>>0){v=v+1|0}else{break}}c[d+48>>2]=v;c[o>>2]=w;o=c[r>>2]|0;r=((o-1+(w<<9)|0)/(o|0)|0)+31&-32;c[d+28>>2]=r;if((r|0)<(((c[l>>2]|0)*1389|0)+132+((c[k>>2]|0)*72|0)|0)|(r|0)>131072){u=-22;i=b;return u|0}c[d+24>>2]=(r|7|0)/8|0;c[a+424>>2]=512;if((c[2446240]|0)==0){x=0}else{u=0;i=b;return u|0}while(1){y=+(x|0);c[9784960+(x<<2)>>2]=~~(+U(y*3.141592653589793*.0009765625)*2147483647.0);c[9868184+(x<<2)>>2]=~~(+T(+10.0,+(y*-.005))*2147483647.0);a=x+1|0;if((a|0)<2048){x=a}else{z=0;break}}while(1){x=~~(+g[1006584+(z<<2)>>2]*33554432.0);c[5825120+(z<<2)>>2]=x;c[5825120+(511-z<<2)>>2]=x;x=z+1|0;if((x|0)<256){z=x}else{A=0;break}}while(1){c[9899056+(A<<2)>>2]=~~(+g[1215512+(A<<2)>>2]*68719476736.0);c[9901104+(A<<2)>>2]=~~(+g[1219608+(A<<2)>>2]*68719476736.0);z=A+1|0;if((z|0)<512){A=z}else{B=0;break}}while(1){y=+(c[612080+(B<<2)>>2]|0);A=0;do{C=+(e[1480928+(A<<1)>>1]|0|0);D=+(e[1509976+(A<<1)>>1]|0|0);z=0;do{E=(+(z|0)+.5)*y*.001953125;F=E/1.0e3;H=F+ -3.4;I=F+ -8.7;J=F*F;K=+T(+F,+-.8)*-3.64+ +$(H*H*-.6)*6.8- +$(I*I*-.15)*6.0-J*J*6.0e-4;J=(E-C)/D;E=J*J+1.0;c[9961368+(B*25600|0)+(A<<10)+(z<<2)>>2]=~~((K+ +fd(+(1.0/(E*E)))*20.0)*10.0);z=z+1|0;}while((z|0)<256);A=A+1|0;}while((A|0)<25);A=B+1|0;if((A|0)<9){B=A}else{L=0;break}}while(1){c[9876376+(L<<2)>>2]=~~(+fd(+(+T(+10.0,+(+(L|0)*-.01))+1.0))*100.0);B=L+1|0;if((B|0)<256){L=B}else{M=0;break}}while(1){y=+(M|0)+.5;L=0;D=0.0;do{D=D+ +U(y*(+(L|0)+.5+-256.0)*6.283185307179586*.001953125)*+((L>>>5&2^2)-1|0)*+g[1215512+(L<<2)>>2];L=L+1|0;}while((L|0)<512);c[9898992+(M<<2)>>2]=~~(+fd(+D)*200.0);L=M+1|0;if((L|0)<8){M=L}else{N=0;break}}while(1){y=+(N|0)+.5;M=0;C=0.0;do{C=C+ +U(y*(+(M|0)+.5+-256.0)*6.283185307179586*.001953125)*+((M>>>5&2^2)-1|0)*+g[1219608+(M<<2)>>2];M=M+1|0;}while((M|0)<512);c[9899024+(N<<2)>>2]=~~(+fd(+C)*200.0);M=N+1|0;if((M|0)<8){N=M}else{u=0;break}}i=b;return u|0}function d5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0;h=i;i=i+12552|0;j=h|0;k=h+2048|0;l=h+4096|0;m=h+6144|0;n=h+7168|0;o=h+9216|0;p=h+10240|0;q=h+10248|0;r=h+12296|0;s=c[b+60>>2]|0;t=s;u=s+24|0;v=c[u>>2]|0;w=d5a(b,e,v,(v|0)<0|0?-1:0)|0;if((w|0)<0){x=w;i=h;return x|0}w=c[f>>2]|0;v=r;z=s+32|0;if((c[z>>2]|0)>0){A=s+56|0;B=s+36|0;C=0;do{D=0;while(1){c[q+(D<<2)>>2]=c[t+80+(D*24|0)+(C<<2)>>2];E=D+1|0;if((E|0)<512){D=E}else{F=0;H=0;break}}while(1){mrc(v|0,0,256)|0;D=c[A>>2]|0;E=H;I=0;J=0;while(1){K=c[q+(E<<2)>>2]|0;L=c[D+(J<<2)>>2]|0;M=Erc(L,(L|0)<0|0?-1:0,K,(K|0)<0|0?-1:0)|0;wrc(M,G,-2147483648,0)|0;M=r+(I<<2)|0;c[M>>2]=G+(c[M>>2]|0);N=I+1&63;M=E+1|0;if((M|0)<512){E=M;I=N;J=J+1|0}else{break}}if((H|0)==0){O=16}else{J=0;I=N;E=512-H|0;while(1){M=c[q+(J<<2)>>2]|0;K=c[D+(E<<2)>>2]|0;L=Erc(K,(K|0)<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;wrc(L,G,-2147483648,0)|0;L=r+(I<<2)|0;c[L>>2]=G+(c[L>>2]|0);L=J+1|0;if((L|0)<(H|0)){J=L;I=I+1&63;E=E+1|0}else{O=16;break}}}while(1){E=r+(O<<2)|0;c[E>>2]=(c[E>>2]|0)-(c[r+(31-O<<2)>>2]|0);E=O+1|0;if((E|0)<32){O=E}else{P=32;break}}while(1){E=r+(P<<2)|0;c[E>>2]=(c[r+(95-P<<2)>>2]|0)+(c[E>>2]|0);E=P+1|0;if((E|0)<48){P=E}else{Q=0;break}}while(1){E=Q<<4|8;I=16;J=0;do{D=c[r+(I<<2)>>2]|0;L=c[9784960+(((ca((I<<1)+33|0,E)|0)&2040)<<2)>>2]|0;M=Erc(L,(L|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;wrc(M,G,-2147483648,0)|0;J=(G>>3)+J|0;I=I+1|0;}while((I|0)<48);I=Q+1|0;c[t+12368+(F*768|0)+(Q*24|0)+(C<<2)>>2]=(I&2|0)!=0?-J|0:J;if((I|0)<32){Q=I}else{break}}I=F<<5;E=c[B>>2]|0;M=0;do{c[q+(M+H<<2)>>2]=c[w+((ca(M+I|0,E)|0)+C<<2)>>2];M=M+1|0;}while((M|0)<32);M=F+1|0;if((M|0)<16){F=M;H=H+32&511}else{break}}C=C+1|0;}while((C|0)<(c[z>>2]|0))}C=s+40|0;if((c[C>>2]|0)==0){R=0}else{H=s+36|0;F=(c[H>>2]|0)-1|0;B=0;while(1){c[q+(B<<2)>>2]=c[t+80+(B*24|0)+(F<<2)>>2];Q=B+1|0;if((Q|0)<512){B=Q}else{S=0;T=0;break}}while(1){B=T;F=0;Q=0;while(1){r=c[q+(B<<2)>>2]|0;P=c[5825120+(F<<2)>>2]|0;O=Erc(P,(P|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;wrc(O,G,-2147483648,0)|0;U=G+Q|0;O=B+1|0;if((O|0)<512){B=O;F=F+1|0;Q=U}else{break}}if((T|0)==0){V=U}else{Q=0;F=512-T|0;B=U;while(1){O=c[q+(Q<<2)>>2]|0;r=c[5825120+(F<<2)>>2]|0;P=Erc(r,(r|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;wrc(P,G,-2147483648,0)|0;P=G+B|0;O=Q+1|0;if((O|0)<(T|0)){Q=O;F=F+1|0;B=P}else{V=P;break}}}c[t+37712+(S<<2)>>2]=V;B=S<<6;F=c[H>>2]|0;Q=F-1|0;P=0;do{c[q+(P+T<<2)>>2]=c[w+(Q+(ca(P+B|0,F)|0)<<2)>>2];P=P+1|0;}while((P|0)<64);P=S+1|0;if((P|0)<8){S=P;T=T+64&511}else{R=0;break}}}do{c[t+37744+(R<<2)>>2]=-2047;c[t+38768+(R<<2)>>2]=-2047;R=R+1|0;}while((R|0)<256);R=s+44|0;T=s+36|0;S=0;H=384;V=c[z>>2]|0;while(1){if((V|0)>0){U=S<<8|128;P=0;while(1){F=0;B=U;while(1){c[q+(F<<2)>>2]=c[t+80+(B*24|0)+(P<<2)>>2];Q=B+1|0;if((Q|0)<512){F=F+1|0;B=Q}else{break}}B=c[T>>2]|0;F=H;Q=0;while(1){c[q+(F<<2)>>2]=c[w+((ca(Q,B)|0)+P<<2)>>2];O=F+1|0;if((O|0)<512){F=O;Q=Q+1|0}else{break}}Q=c[R>>2]|0;F=0;while(1){B=F<<1;O=c[q+(B<<2)>>2]|0;r=F<<3;N=1073741823-(c[9784960+((r|2)<<2)>>2]>>1)|0;A=Erc(N,(N|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;wrc(A,G,-2147483648,0)|0;c[k+(F<<3)>>2]=G;A=c[q+((B|1)<<2)>>2]|0;B=1073741823-(c[9784960+((r|6)<<2)>>2]>>1)|0;r=Erc(B,(B|0)<0|0?-1:0,A,(A|0)<0|0?-1:0)|0;wrc(r,G,-2147483648,0)|0;c[k+(F<<3)+4>>2]=G;r=F+1|0;if((r|0)<256){F=r}else{W=0;break}}while(1){F=W<<2|2;r=c[9784960+(F<<2)>>2]|0;A=c[k+(W<<3)>>2]|0;B=r;O=(r|0)<0|0?-1:0;r=A;N=(A|0)<0|0?-1:0;A=Erc(r,N,B,O)|0;wrc(A,G,-2147483648,0)|0;A=G;v=c[9784960+((F+1536&2046)<<2)>>2]|0;F=c[k+(W<<3)+4>>2]|0;M=v;E=(v|0)<0|0?-1:0;v=F;I=(F|0)<0|0?-1:0;F=Erc(v,I,M,E)|0;wrc(F,G,-2147483648,0)|0;c[j+(W<<3)>>2]=A-G;A=Erc(v,I,B,O)|0;wrc(A,G,-2147483648,0)|0;A=G;O=Erc(M,E,r,N)|0;wrc(O,G,-2147483648,0)|0;c[j+(W<<3)+4>>2]=A+G;A=W+1|0;if((A|0)<256){W=A}else{X=1;Y=256;break}}while(1){A=(Y|0)/2|0;O=X<<3;if((Y|0)>1){N=0;do{r=N+A|0;E=N;do{M=ca(E,O)|0;B=j+(E<<3)|0;I=c[B>>2]|0;v=E+A|0;F=j+(v<<3)|0;D=c[F>>2]|0;L=j+(E<<3)+4|0;K=c[L>>2]|0;Z=j+(v<<3)+4|0;v=c[Z>>2]|0;_=I-D|0;$=K-v|0;c[B>>2]=I+1+D>>1;c[L>>2]=K+1+v>>1;v=c[9784960+((M&2040)<<2)>>2]|0;K=_;L=(_|0)<0|0?-1:0;_=v;D=(v|0)<0|0?-1:0;v=Erc(_,D,K,L)|0;wrc(v,G,-2147483648,0)|0;v=G;I=c[9784960+((M+1536&2040)<<2)>>2]|0;M=$;B=($|0)<0|0?-1:0;$=I;aa=(I|0)<0|0?-1:0;I=Erc($,aa,M,B)|0;wrc(I,G,-2147483648,0)|0;c[F>>2]=v-G;v=Erc(_,D,M,B)|0;wrc(v,G,-2147483648,0)|0;v=G;B=Erc($,aa,K,L)|0;wrc(B,G,-2147483648,0)|0;c[Z>>2]=G+v;E=E+1|0;}while((E|0)<(r|0));N=N+Y|0;}while((N|0)<256)}else{N=0;do{N=N+Y|0;}while((N|0)<256)}N=Y>>1;if((N|0)==1){ba=0;break}else{X=X<<1;Y=N}}while(1){N=d[1316536+ba|0]|0;A=c[j+(N<<3)>>2]|0;O=ba<<2;J=c[9784960+(O<<2)>>2]|0;r=A;E=(A|0)<0|0?-1:0;A=J;v=(J|0)<0|0?-1:0;J=Erc(A,v,r,E)|0;wrc(J,G,-2147483648,0)|0;J=G;Z=c[j+(N<<3)+4>>2]|0;N=c[9784960+((O+1536&2044)<<2)>>2]|0;O=Z;B=(Z|0)<0|0?-1:0;Z=N;L=(N|0)<0|0?-1:0;N=Erc(Z,L,O,B)|0;wrc(N,G,-2147483648,0)|0;c[l+(ba<<3)>>2]=J-G;J=Erc(O,B,A,v)|0;wrc(J,G,-2147483648,0)|0;J=G;v=Erc(Z,L,r,E)|0;wrc(v,G,-2147483648,0)|0;c[l+(ba<<3)+4>>2]=G+J;J=ba+1|0;if((J|0)<256){ba=J}else{da=0;break}}do{J=c[l+(da<<3)>>2]|0;v=255-da|0;E=c[l+(v<<3)>>2]|0;r=J-E|0;L=c[l+(da<<3)+4>>2]|0;Z=c[l+(v<<3)+4>>2]|0;v=Z+L|0;A=L-Z|0;Z=E+J|0;J=A+r|0;E=da<<1|1;L=c[9784960+(E<<2)>>2]|0;B=L;O=(L|0)<0|0?-1:0;L=Erc(J,(J|0)<0|0?-1:0,B,O)|0;wrc(L,G,-2147483648,0)|0;L=G;J=v+Z|0;N=c[9784960+(E+1536<<2)>>2]|0;E=N;K=(N|0)<0|0?-1:0;N=Erc(E,K,J,(J|0)<0|0?-1:0)|0;wrc(N,G,-2147483648,0)|0;c[n+(da<<3)>>2]=L+G;L=v-Z|0;Z=Erc(L,(L|0)<0|0?-1:0,B,O)|0;wrc(Z,G,-2147483648,0)|0;Z=G;O=A-r|0;r=Erc(E,K,O,(O|0)<0|0?-1:0)|0;wrc(r,G,-2147483648,0)|0;c[n+(da<<3)+4>>2]=G+Z;da=da+1|0;}while((da|0)<256);Z=c[2468070]|0;r=0;while(1){O=c[n+(r<<3)>>2]|0;K=(O|0)<0?-O|0:O;O=(Z|0)<(K|0)?0:1024;E=O|512;A=(c[9868184+(E<<2)>>2]|0)<(K|0)?O:E;E=A|256;O=(c[9868184+(E<<2)>>2]|0)<(K|0)?A:E;E=O|128;A=(c[9868184+(E<<2)>>2]|0)<(K|0)?O:E;E=A+64|0;O=(c[9868184+(E<<2)>>2]|0)<(K|0)?A:E;E=O+32|0;A=(c[9868184+(E<<2)>>2]|0)<(K|0)?O:E;E=A+16|0;O=(c[9868184+(E<<2)>>2]|0)<(K|0)?A:E;E=O+8|0;A=(c[9868184+(E<<2)>>2]|0)<(K|0)?O:E;E=A+4|0;O=(c[9868184+(E<<2)>>2]|0)<(K|0)?A:E;E=O+2|0;A=(c[9868184+(E<<2)>>2]|0)<(K|0)?O:E;E=A+1|0;O=-((c[9868184+(E<<2)>>2]|0)<(K|0)?A:E)|0;E=c[n+(r<<3)+4>>2]|0;A=(E|0)<0?-E|0:E;E=(Z|0)<(A|0)?0:1024;K=E|512;B=(c[9868184+(K<<2)>>2]|0)<(A|0)?E:K;K=B|256;E=(c[9868184+(K<<2)>>2]|0)<(A|0)?B:K;K=E|128;B=(c[9868184+(K<<2)>>2]|0)<(A|0)?E:K;K=B+64|0;E=(c[9868184+(K<<2)>>2]|0)<(A|0)?B:K;K=E+32|0;B=(c[9868184+(K<<2)>>2]|0)<(A|0)?E:K;K=B+16|0;E=(c[9868184+(K<<2)>>2]|0)<(A|0)?B:K;K=E+8|0;B=(c[9868184+(K<<2)>>2]|0)<(A|0)?E:K;K=B+4|0;E=(c[9868184+(K<<2)>>2]|0)<(A|0)?B:K;K=E+2|0;B=(c[9868184+(K<<2)>>2]|0)<(A|0)?E:K;K=B+1|0;E=-((c[9868184+(K<<2)>>2]|0)<(A|0)?B:K)|0;K=(O|0)<(E|0);B=K?E:O;A=B-(K?O:E)|0;if((A|0)>255){ea=B}else{ea=(c[9876376+(A<<2)>>2]|0)+B|0}c[m+(r<<2)>>2]=ea;c[o+(r<<2)>>2]=-2047;B=r+1|0;if((B|0)<256){r=B}else{fa=0;break}}while(1){r=-1114;Z=0;while(1){B=(c[9961368+(Q*25600|0)+(fa<<10)+(Z<<2)>>2]|0)+(c[m+(Z<<2)>>2]|0)|0;A=(r|0)<(B|0);E=A?B:r;O=E-(A?r:B)|0;if((O|0)>255){ga=E}else{ga=(c[9876376+(O<<2)>>2]|0)+E|0}E=Z+1|0;if((E|0)<256){r=ga;Z=E}else{ha=0;break}}do{Z=o+(ha<<2)|0;r=c[Z>>2]|0;E=(c[9961368+(Q*25600|0)+(fa<<10)+(ha<<2)>>2]|0)-ga|0;O=(r|0)<(E|0);B=O?E:r;A=B-(O?r:E)|0;if((A|0)>255){ia=B}else{ia=(c[9876376+(A<<2)>>2]|0)+B|0}c[Z>>2]=ia;ha=ha+1|0;}while((ha|0)<256);Z=fa+1|0;if((Z|0)<25){fa=Z}else{ja=0;break}}do{Q=t+37744+(S<<10)+(ja<<2)|0;Z=c[Q>>2]|0;B=1114-(c[o+(ja<<2)>>2]|0)-928|0;A=(Z|0)<(B|0);E=A?B:Z;r=E-(A?Z:B)|0;if((r|0)>255){ka=E}else{ka=(c[9876376+(r<<2)>>2]|0)+E|0}c[Q>>2]=ka;ja=ja+1|0;}while((ja|0)<256);Q=P+1|0;E=c[z>>2]|0;if((Q|0)<(E|0)){P=Q}else{la=E;break}}}else{la=V}P=S+1|0;if((P|0)<2){S=P;H=H-256|0;V=la}else{ma=0;break}}do{la=c[t+37744+(ma<<2)>>2]|0;V=(la|0)<2048?la:2048;la=c[t+38768+(ma<<2)>>2]|0;c[t+42864+(ma<<2)>>2]=(la|0)<(V|0)?la:V;ma=ma+1|0;}while((ma|0)<256);ma=s+43888|0;V=s+42864|0;la=s+42868|0;H=s+42872|0;S=s+42876|0;ja=s+44012|0;ka=s+43872|0;o=s+43876|0;fa=s+43880|0;ha=s+43884|0;ia=s+60|0;ga=0;do{m=t+43888+(ga<<2)|0;c[m>>2]=2048;do{if((ga|0)==0){ea=c[V>>2]|0;n=c[ma>>2]|0;if((ea|0)<(n|0)){c[ma>>2]=ea;na=ea}else{na=n}n=c[la>>2]|0;if((n|0)<(na|0)){c[ma>>2]=n;oa=n}else{oa=na}n=c[H>>2]|0;if((n|0)<(oa|0)){c[ma>>2]=n;pa=n}else{pa=oa}n=c[S>>2]|0;if((n|0)>=(pa|0)){break}c[ma>>2]=n}else{n=ga<<3;ea=c[ia>>2]|0;da=(c[t+42864+(n-4<<2)>>2]|0)-(c[ea+28>>2]|0)|0;if((da|0)<2048){c[m>>2]=da;qa=c[ia>>2]|0;ra=da}else{qa=ea;ra=2048}ea=(c[t+42864+(n-3<<2)>>2]|0)-(c[qa+24>>2]|0)|0;if((ea|0)<(ra|0)){c[m>>2]=ea;sa=c[ia>>2]|0;ta=ea}else{sa=qa;ta=ra}ea=(c[t+42864+(n-2<<2)>>2]|0)-(c[sa+20>>2]|0)|0;if((ea|0)<(ta|0)){c[m>>2]=ea;ua=c[ia>>2]|0;va=ea}else{ua=sa;va=ta}ea=(c[t+42864+(n-1<<2)>>2]|0)-(c[ua+16>>2]|0)|0;if((ea|0)<(va|0)){c[m>>2]=ea;wa=c[ia>>2]|0;xa=ea}else{wa=ua;xa=va}ea=(c[t+42864+(n<<2)>>2]|0)-(c[wa+12>>2]|0)|0;if((ea|0)<(xa|0)){c[m>>2]=ea;ya=c[ia>>2]|0;za=ea}else{ya=wa;za=xa}ea=(c[t+42864+((n|1)<<2)>>2]|0)-(c[ya+8>>2]|0)|0;if((ea|0)<(za|0)){c[m>>2]=ea;Aa=c[ia>>2]|0;Ba=ea}else{Aa=ya;Ba=za}ea=(c[t+42864+((n|2)<<2)>>2]|0)-(c[Aa+4>>2]|0)|0;if((ea|0)<(Ba|0)){c[m>>2]=ea;Ca=c[ia>>2]|0;Da=ea}else{Ca=Aa;Da=Ba}ea=(c[t+42864+((n|3)<<2)>>2]|0)-(c[Ca>>2]|0)|0;if((ea|0)>=(Da|0)){break}c[m>>2]=ea}}while(0);do{if((ga|0)==31){ea=c[ka>>2]|0;n=c[ja>>2]|0;if((ea|0)<(n|0)){c[ja>>2]=ea;Ea=ea}else{Ea=n}n=c[o>>2]|0;if((n|0)<(Ea|0)){c[ja>>2]=n;Fa=n}else{Fa=Ea}n=c[fa>>2]|0;if((n|0)<(Fa|0)){c[ja>>2]=n;Ga=n}else{Ga=Fa}n=c[ha>>2]|0;if((n|0)>=(Ga|0)){break}c[ja>>2]=n}else{n=ga<<3;ea=n|4;da=c[ia>>2]|0;l=(c[t+42864+(ea<<2)>>2]|0)-(c[da>>2]|0)|0;ba=c[m>>2]|0;if((l|0)<(ba|0)){c[m>>2]=l;Ha=c[ia>>2]|0;Ia=l}else{Ha=da;Ia=ba}ba=(c[t+42864+((n|5)<<2)>>2]|0)-(c[Ha+4>>2]|0)|0;if((ba|0)<(Ia|0)){c[m>>2]=ba;Ja=c[ia>>2]|0;Ka=ba}else{Ja=Ha;Ka=Ia}ba=(c[t+42864+((n|6)<<2)>>2]|0)-(c[Ja+8>>2]|0)|0;if((ba|0)<(Ka|0)){c[m>>2]=ba;La=c[ia>>2]|0;Ma=ba}else{La=Ja;Ma=Ka}ba=(c[t+42864+((n|7)<<2)>>2]|0)-(c[La+12>>2]|0)|0;if((ba|0)<(Ma|0)){c[m>>2]=ba;Na=c[ia>>2]|0;Oa=ba}else{Na=La;Oa=Ma}ba=(c[t+42864+(ea+4<<2)>>2]|0)-(c[Na+16>>2]|0)|0;if((ba|0)<(Oa|0)){c[m>>2]=ba;Pa=c[ia>>2]|0;Qa=ba}else{Pa=Na;Qa=Oa}ba=(c[t+42864+(ea+5<<2)>>2]|0)-(c[Pa+20>>2]|0)|0;if((ba|0)<(Qa|0)){c[m>>2]=ba;Ra=c[ia>>2]|0;Sa=ba}else{Ra=Pa;Sa=Qa}ba=(c[t+42864+(ea+6<<2)>>2]|0)-(c[Ra+24>>2]|0)|0;if((ba|0)<(Sa|0)){c[m>>2]=ba;Ta=c[ia>>2]|0;Ua=ba}else{Ta=Ra;Ua=Sa}ba=(c[t+42864+(ea+7<<2)>>2]|0)-(c[Ta+28>>2]|0)|0;if((ba|0)>=(Ua|0)){break}c[m>>2]=ba}}while(0);ga=ga+1|0;}while((ga|0)<32);ga=0;Ua=c[z>>2]|0;while(1){if((Ua|0)>0){Ta=0;while(1){Sa=0;Ra=0;do{ia=c[t+12368+(Sa*768|0)+(ga*24|0)+(Ta<<2)>>2]|0;Qa=(ia|0)>-1?ia:-ia|0;Ra=(Ra|0)<(Qa|0)?Qa:Ra;Sa=Sa+1|0;}while((Sa|0)<16);Sa=(Ra|0)<0?-Ra|0:Ra;Qa=(c[2468070]|0)<(Sa|0)?0:1024;ia=Qa|512;Pa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa|256;Qa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia;ia=Qa|128;Pa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa+64|0;Qa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia;ia=Qa+32|0;Pa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa+16|0;Qa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia;ia=Qa+8|0;Pa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa+4|0;Qa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia;ia=Qa+2|0;Pa=(c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Qa:ia;ia=Pa+1|0;c[t+36944+(ga*24|0)+(Ta<<2)>>2]=-((c[9868184+(ia<<2)>>2]|0)<(Sa|0)?Pa:ia);ia=Ta+1|0;Pa=c[z>>2]|0;if((ia|0)<(Pa|0)){Ta=ia}else{Va=Pa;break}}}else{Va=Ua}Ta=ga+1|0;if((Ta|0)<32){ga=Ta;Ua=Va}else{break}}if((c[C>>2]|0)!=0){Va=c[s+37712>>2]|0;Ua=(Va|0)>-1?Va:-Va|0;Va=(Ua|0)>0?Ua:0;Ua=c[s+37716>>2]|0;ga=(Ua|0)>-1?Ua:-Ua|0;Ua=(Va|0)<(ga|0)?ga:Va;Va=c[s+37720>>2]|0;ga=(Va|0)>-1?Va:-Va|0;Va=(Ua|0)<(ga|0)?ga:Ua;Ua=c[s+37724>>2]|0;ga=(Ua|0)>-1?Ua:-Ua|0;Ua=(Va|0)<(ga|0)?ga:Va;Va=c[s+37728>>2]|0;ga=(Va|0)>-1?Va:-Va|0;Va=(Ua|0)<(ga|0)?ga:Ua;Ua=c[s+37732>>2]|0;ga=(Ua|0)>-1?Ua:-Ua|0;Ua=(Va|0)<(ga|0)?ga:Va;Va=c[s+37736>>2]|0;ga=(Va|0)>-1?Va:-Va|0;Va=(Ua|0)<(ga|0)?ga:Ua;Ua=c[s+37740>>2]|0;ga=(Ua|0)>-1?Ua:-Ua|0;Ua=(Va|0)<(ga|0)?ga:Va;Va=(Ua|0)<0?-Ua|0:Ua;Ua=(c[2468070]|0)<(Va|0)?0:1024;ga=Ua|512;Ta=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta|256;Ua=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ta:ga;ga=Ua|128;Ta=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta+64|0;Ua=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ta:ga;ga=Ua+32|0;Ta=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta+16|0;Ua=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ta:ga;ga=Ua+8|0;Ta=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta+4|0;Ua=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ta:ga;ga=Ua+2|0;Ta=(c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ua:ga;ga=Ta+1|0;c[s+76>>2]=-((c[9868184+(ga<<2)>>2]|0)<(Va|0)?Ta:ga)}ga=s+44016|0;f5(t,c[ga>>2]|0)|0;Ta=c[ga>>2]|0;Va=s+44024|0;Ua=s+28|0;a:do{if((c[Va>>2]|0)>(c[Ua>>2]|0)){Pa=Ta;ia=0;while(1){if((ia|0)==1){break}Sa=Pa+128|0;Qa=f5(t,Sa)|0;if((c[Va>>2]|0)>(c[Ua>>2]|0)){Pa=Sa;ia=Qa}else{Wa=Sa;Xa=129;break a}}KIb(0,0,2365904,(ia=i,i=i+24|0,c[ia>>2]=2147104,c[ia+8>>2]=2249336,c[ia+16>>2]=601,ia)|0);i=ia;Hd();return 0}else{ia=Ta;Pa=0;while(1){if((Pa|0)==4){Ya=ia;break a}Sa=ia-128|0;Qa=f5(t,Sa)|0;if((c[Va>>2]|0)>(c[Ua>>2]|0)){Wa=ia;Xa=129;break}else{ia=Sa;Pa=Qa}}}}while(0);if((Xa|0)==129){Xa=Wa-64|0;f5(t,Xa)|0;Ta=(c[Va>>2]|0)>(c[Ua>>2]|0)?Wa:Xa;Xa=Ta-32|0;f5(t,Xa)|0;Wa=(c[Va>>2]|0)>(c[Ua>>2]|0)?Ta:Xa;Xa=Wa-16|0;f5(t,Xa)|0;Ta=(c[Va>>2]|0)>(c[Ua>>2]|0)?Wa:Xa;Xa=Ta-8|0;f5(t,Xa)|0;Wa=(c[Va>>2]|0)>(c[Ua>>2]|0)?Ta:Xa;Xa=Wa-4|0;f5(t,Xa)|0;Ta=(c[Va>>2]|0)>(c[Ua>>2]|0)?Wa:Xa;Xa=Ta-2|0;f5(t,Xa)|0;Wa=(c[Va>>2]|0)>(c[Ua>>2]|0)?Ta:Xa;Xa=Wa-1|0;f5(t,Xa)|0;Ta=(c[Va>>2]|0)>(c[Ua>>2]|0)?Wa:Xa;f5(t,Ta)|0;Ya=Ta}c[ga>>2]=Ya;ga=s+44020|0;if((Ya|0)>(c[ga>>2]|0)){c[ga>>2]=Ya}Ya=0;ga=c[z>>2]|0;while(1){if((ga|0)>0){Ta=0;while(1){c[t+40560+(Ya*24|0)+(Ta<<2)>>2]=e5(c[t+36944+(Ya*24|0)+(Ta<<2)>>2]|0,c[t+39792+(Ya*24|0)+(Ta<<2)>>2]|0,t+41328+(Ya*48|0)+(Ta<<3)|0)|0;Xa=Ta+1|0;Wa=c[z>>2]|0;if((Xa|0)<(Wa|0)){Ta=Xa}else{Za=Wa;break}}}else{Za=ga}Ta=Ya+1|0;if((Ta|0)<32){Ya=Ta;ga=Za}else{break}}if((c[C>>2]|0)==0){_a=0;$a=Za}else{c[s+64>>2]=e5(c[s+76>>2]|0,11,s+68|0)|0;_a=0;$a=c[z>>2]|0}while(1){Za=0;ga=$a;while(1){if((ga|0)>0){Ya=0;while(1){Ta=c[t+12368+(_a*768|0)+(Za*24|0)+(Ya<<2)>>2]|0;Wa=c[t+41328+(Za*48|0)+(Ya<<3)>>2]|0;Xa=c[t+41328+(Za*48|0)+(Ya<<3)+4>>2]|0;Ua=Erc(Wa,(Wa|0)<0|0?-1:0,Ta,(Ta|0)<0|0?-1:0)|0;wrc(Ua,G,-2147483648,0)|0;c[t+24656+(_a*768|0)+(Za*24|0)+(Ya<<2)>>2]=G+(1<<Xa-1)>>Xa;Xa=Ya+1|0;Ua=c[z>>2]|0;if((Xa|0)<(Ua|0)){Ya=Xa}else{ab=Ua;break}}}else{ab=ga}Ya=Za+1|0;if((Ya|0)<32){Za=Ya;ga=ab}else{break}}ga=_a+1|0;if((ga|0)<16){_a=ga;$a=ab}else{break}}ab=0;$a=c[T>>2]|0;while(1){if(($a|0)>0){_a=0;ga=$a;while(1){c[t+80+(ab*24|0)+(_a<<2)>>2]=c[w+((ca(ga,ab)|0)+_a<<2)>>2];Za=_a+1|0;Ya=c[T>>2]|0;if((Za|0)<(Ya|0)){_a=Za;ga=Ya}else{bb=Ya;break}}}else{bb=$a}ga=ab+1|0;if((ga|0)<512){ab=ga;$a=bb}else{break}}bb=e+28|0;$a=c[bb>>2]|0;ab=($a|0)<0;T=ab?0:c[e+24>>2]|0;w=ab?0:$a;c[s+20>>2]=w<<3;c[s+8>>2]=T;c[s+16>>2]=T+w;w=s+12|0;c[w>>2]=T;$a=s+4|0;ab=s;ga=T;y=25230975;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;ga=(c[w>>2]|0)+4|0;c[w>>2]=ga;T=c[s+52>>2]|0;_a=ga;y=je(T>>>2|((c[u>>2]<<4)+67108848|-63176704)|0)|0;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;_a=(c[w>>2]|0)+4|0;c[w>>2]=_a;ga=_a;y=je(((c[C>>2]|0)!=0?1024:0)|(c[s+48>>2]|(d[1904944+(c[R>>2]|0)|0]|0|T<<4)<<5)<<21|312|0)|0;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;ga=(c[w>>2]|0)+4|0;c[w>>2]=ga;T=c[z>>2]|0;R=T-1|0;c[ab>>2]=R;c[$a>>2]=17;do{if((T|0)>0){_a=0;Ya=R;Za=17;Ra=T;Ua=ga;while(1){if((Za|0)>5){cb=Za-5|0;db=Ya<<5|30;eb=Ra;fb=Ua}else{Xa=Ua;y=je(30>>>((5-Za|0)>>>0)|Ya<<Za|0)|0;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;Xa=(c[w>>2]|0)+4|0;c[w>>2]=Xa;cb=Za+27|0;db=30;eb=c[z>>2]|0;fb=Xa}c[ab>>2]=db;c[$a>>2]=cb;Xa=_a+1|0;if((Xa|0)<(eb|0)){_a=Xa;Ya=db;Za=cb;Ra=eb;Ua=fb}else{break}}if((eb|0)>0){gb=0;hb=db;ib=cb;jb=eb;kb=fb}else{lb=1;mb=eb;nb=db;ob=cb;pb=fb;break}while(1){if((ib|0)>5){qb=ib-5|0;rb=hb<<5|31;sb=jb;tb=kb}else{Ua=kb;y=je(31>>>((5-ib|0)>>>0)|hb<<ib|0)|0;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;qb=ib+27|0;rb=31;sb=c[z>>2]|0;tb=Ua}c[ab>>2]=rb;c[$a>>2]=qb;Ua=gb+1|0;if((Ua|0)<(sb|0)){gb=Ua;hb=rb;ib=qb;jb=sb;kb=tb}else{break}}if((sb|0)>0){ub=0;vb=rb;wb=qb;xb=sb;yb=tb}else{lb=1;mb=sb;nb=rb;ob=qb;pb=tb;break}while(1){if((wb|0)>3){zb=wb-3|0;Ab=vb<<3;Bb=xb;Cb=yb}else{Ua=yb;y=je(vb<<wb|0)|0;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;zb=wb+29|0;Ab=0;Bb=c[z>>2]|0;Cb=Ua}c[ab>>2]=Ab;c[$a>>2]=zb;Ua=ub+1|0;if((Ua|0)<(Bb|0)){ub=Ua;vb=Ab;wb=zb;xb=Bb;yb=Cb}else{break}}if((Bb|0)>0){Db=0;Eb=Ab;Fb=zb;Gb=Bb;Hb=Cb}else{lb=1;mb=Bb;nb=Ab;ob=zb;pb=Cb;break}while(1){if((Fb|0)>2){Ib=Fb-2|0;Jb=Eb<<2;Kb=Gb;Lb=Hb}else{Ua=Hb;y=je(Eb<<Fb|0)|0;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;Ib=Fb+30|0;Jb=0;Kb=c[z>>2]|0;Lb=Ua}c[ab>>2]=Jb;c[$a>>2]=Ib;Ua=Db+1|0;if((Ua|0)<(Kb|0)){Db=Ua;Eb=Jb;Fb=Ib;Gb=Kb;Hb=Lb}else{break}}if((Kb|0)>0){Mb=0;Nb=Jb;Ob=Ib;Pb=Kb;Qb=Lb}else{lb=1;mb=Kb;nb=Jb;ob=Ib;pb=Lb;break}while(1){if((Ob|0)>3){Rb=Ob-3|0;Sb=Nb<<3|6;Tb=Pb;Ub=Qb}else{Ua=Qb;y=je(6>>>((3-Ob|0)>>>0)|Nb<<Ob|0)|0;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;Rb=Ob+29|0;Sb=6;Tb=c[z>>2]|0;Ub=Ua}c[ab>>2]=Sb;c[$a>>2]=Rb;Ua=Mb+1|0;if((Ua|0)<(Tb|0)){Mb=Ua;Nb=Sb;Ob=Rb;Pb=Tb;Qb=Ub}else{break}}if((Tb|0)>0){Vb=0;Wb=Sb;Xb=Rb;Yb=Tb;Zb=Ub}else{lb=1;mb=Tb;nb=Sb;ob=Rb;pb=Ub;break}while(1){if((Xb|0)>3){_b=Xb-3|0;$b=Wb<<3|6;ac=Yb;bc=Zb}else{Ua=Zb;y=je(6>>>((3-Xb|0)>>>0)|Wb<<Xb|0)|0;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;Ua=(c[w>>2]|0)+4|0;c[w>>2]=Ua;_b=Xb+29|0;$b=6;ac=c[z>>2]|0;bc=Ua}c[ab>>2]=$b;c[$a>>2]=_b;Ua=Vb+1|0;if((Ua|0)<(ac|0)){Vb=Ua;Wb=$b;Xb=_b;Yb=ac;Zb=bc}else{lb=1;mb=ac;nb=$b;ob=_b;pb=bc;break}}}else{lb=1;mb=T;nb=R;ob=17;pb=ga}}while(0);while(1){if((mb|0)>0){ga=c[696432+(lb<<2)>>2]|0;R=c[696384+(lb<<2)>>2]|0;T=32-ga|0;bc=0;_b=nb;$b=ob;ac=mb;Zb=pb;while(1){if(($b|0)>(ga|0)){cc=$b-ga|0;dc=_b<<ga|R;ec=ac;fc=Zb}else{Yb=Zb;y=je(R>>>((ga-$b|0)>>>0)|_b<<$b|0)|0;a[Yb]=y;y=y>>8;a[Yb+1|0]=y;y=y>>8;a[Yb+2|0]=y;y=y>>8;a[Yb+3|0]=y;Yb=(c[w>>2]|0)+4|0;c[w>>2]=Yb;cc=T+$b|0;dc=R;ec=c[z>>2]|0;fc=Yb}c[ab>>2]=dc;c[$a>>2]=cc;Yb=bc+1|0;if((Yb|0)<(ec|0)){bc=Yb;_b=dc;$b=cc;ac=ec;Zb=fc}else{gc=ec;hc=dc;ic=cc;jc=fc;break}}}else{gc=mb;hc=nb;ic=ob;jc=pb}Zb=lb+1|0;if((Zb|0)<11){lb=Zb;mb=gc;nb=hc;ob=ic;pb=jc}else{break}}pb=s+68|0;ob=s+72|0;nb=s+64|0;if((ic|0)>2){kc=ic-2|0;lc=hc<<2|1;mc=jc}else{s=jc;y=je(1>>>((2-ic|0)>>>0)|hc<<ic|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=(c[w>>2]|0)+4|0;c[w>>2]=s;kc=ic+30|0;lc=1;mc=s}c[ab>>2]=lc;c[$a>>2]=kc;if((kc|0)>3){nc=kc-3|0;oc=lc<<3;pc=mc}else{s=mc;y=je(lc<<kc|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=(c[w>>2]|0)+4|0;c[w>>2]=s;nc=kc+29|0;oc=0;pc=s}c[ab>>2]=oc;c[$a>>2]=nc;s=c[z>>2]|0;do{if((s|0)>0){kc=0;lc=oc;mc=nc;ic=pc;while(1){hc=0;jc=lc;gc=mc;mb=ic;while(1){if((gc|0)>1){qc=gc-1|0;rc=jc<<1;sc=mb}else{lb=mb;y=je(jc<<gc|0)|0;a[lb]=y;y=y>>8;a[lb+1|0]=y;y=y>>8;a[lb+2|0]=y;y=y>>8;a[lb+3|0]=y;lb=(c[w>>2]|0)+4|0;c[w>>2]=lb;qc=gc+31|0;rc=0;sc=lb}c[ab>>2]=rc;c[$a>>2]=qc;lb=hc+1|0;if((lb|0)<32){hc=lb;jc=rc;gc=qc;mb=sc}else{break}}mb=kc+1|0;tc=c[z>>2]|0;if((mb|0)<(tc|0)){kc=mb;lc=rc;mc=qc;ic=sc}else{break}}if((tc|0)>0){uc=0;vc=rc;wc=qc;xc=sc}else{yc=rc;zc=qc;Ac=tc;Bc=sc;break}while(1){ic=0;mc=vc;lc=wc;kc=xc;while(1){mb=c[t+39792+(ic*24|0)+(uc<<2)>>2]|0;if((lc|0)>5){Cc=lc-5|0;Dc=mb|mc<<5;Ec=kc}else{gc=kc;y=je(mb>>>((5-lc|0)>>>0)|mc<<lc|0)|0;a[gc]=y;y=y>>8;a[gc+1|0]=y;y=y>>8;a[gc+2|0]=y;y=y>>8;a[gc+3|0]=y;gc=(c[w>>2]|0)+4|0;c[w>>2]=gc;Cc=lc+27|0;Dc=mb;Ec=gc}c[ab>>2]=Dc;c[$a>>2]=Cc;gc=ic+1|0;if((gc|0)<32){ic=gc;mc=Dc;lc=Cc;kc=Ec}else{break}}kc=uc+1|0;Fc=c[z>>2]|0;if((kc|0)<(Fc|0)){uc=kc;vc=Dc;wc=Cc;xc=Ec}else{break}}if((Fc|0)>0){Gc=0;Hc=Dc;Ic=Cc;Jc=Ec}else{yc=Dc;zc=Cc;Ac=Fc;Bc=Ec;break}while(1){kc=0;lc=Hc;mc=Ic;ic=Jc;while(1){if((mc|0)>1){Kc=mc-1|0;Lc=lc<<1;Mc=ic}else{gc=ic;y=je(lc<<mc|0)|0;a[gc]=y;y=y>>8;a[gc+1|0]=y;y=y>>8;a[gc+2|0]=y;y=y>>8;a[gc+3|0]=y;gc=(c[w>>2]|0)+4|0;c[w>>2]=gc;Kc=mc+31|0;Lc=0;Mc=gc}c[ab>>2]=Lc;c[$a>>2]=Kc;gc=kc+1|0;if((gc|0)<32){kc=gc;lc=Lc;mc=Kc;ic=Mc}else{break}}ic=Gc+1|0;Nc=c[z>>2]|0;if((ic|0)<(Nc|0)){Gc=ic;Hc=Lc;Ic=Kc;Jc=Mc}else{break}}if((Nc|0)>0){Oc=0;Pc=Lc;Qc=Kc;Rc=Mc}else{yc=Lc;zc=Kc;Ac=Nc;Bc=Mc;break}while(1){ic=0;mc=Pc;lc=Qc;kc=Rc;while(1){gc=c[t+40560+(ic*24|0)+(Oc<<2)>>2]|0;if((lc|0)>7){Sc=lc-7|0;Tc=gc|mc<<7;Uc=kc}else{mb=kc;y=je(gc>>>((7-lc|0)>>>0)|mc<<lc|0)|0;a[mb]=y;y=y>>8;a[mb+1|0]=y;y=y>>8;a[mb+2|0]=y;y=y>>8;a[mb+3|0]=y;mb=(c[w>>2]|0)+4|0;c[w>>2]=mb;Sc=lc+25|0;Tc=gc;Uc=mb}c[ab>>2]=Tc;c[$a>>2]=Sc;mb=ic+1|0;if((mb|0)<32){ic=mb;mc=Tc;lc=Sc;kc=Uc}else{break}}kc=Oc+1|0;lc=c[z>>2]|0;if((kc|0)<(lc|0)){Oc=kc;Pc=Tc;Qc=Sc;Rc=Uc}else{yc=Tc;zc=Sc;Ac=lc;Bc=Uc;break}}}else{yc=oc;zc=nc;Ac=s;Bc=pc}}while(0);if((c[C>>2]|0)==0){Vc=0;Wc=yc;Xc=zc;Yc=Ac;Zc=Bc}else{Ac=0;C=yc;yc=zc;zc=Bc;while(1){Bc=c[t+37712+(Ac<<2)>>2]|0;pc=c[pb>>2]|0;s=c[ob>>2]|0;nc=Erc(pc,(pc|0)<0|0?-1:0,Bc,(Bc|0)<0|0?-1:0)|0;wrc(nc,G,-2147483648,0)|0;nc=G+(1<<s-1)>>s&255;if((yc|0)>8){_c=yc-8|0;$c=nc|C<<8;ad=zc}else{s=zc;y=je(nc>>>((8-yc|0)>>>0)|C<<yc|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=(c[w>>2]|0)+4|0;c[w>>2]=s;_c=yc+24|0;$c=nc;ad=s}c[ab>>2]=$c;c[$a>>2]=_c;s=Ac+1|0;if((s|0)<8){Ac=s;C=$c;yc=_c;zc=ad}else{break}}zc=c[nb>>2]|0;if((_c|0)>8){bd=_c-8|0;cd=zc|$c<<8;dd=ad}else{nb=ad;y=je(zc>>>((8-_c|0)>>>0)|$c<<_c|0)|0;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=(c[w>>2]|0)+4|0;c[w>>2]=nb;bd=_c+24|0;cd=zc;dd=nb}c[ab>>2]=cd;c[$a>>2]=bd;Vc=0;Wc=cd;Xc=bd;Yc=c[z>>2]|0;Zc=dd}while(1){if((Yc|0)>0){dd=Vc<<3;bd=dd|3;cd=dd|2;nb=dd|1;zc=dd|4;_c=dd|7;$c=dd|6;ad=dd|5;yc=0;C=Wc;Ac=Xc;ob=Zc;while(1){pb=0;s=C;nc=Ac;Bc=ob;while(1){pc=t+39792+(pb*24|0)+(yc<<2)|0;oc=c[pc>>2]|0;b:do{if((oc|0)<8){Uc=c[688192+(oc<<2)>>2]|0;Sc=(Uc-1|0)/2|0;Tc=ca(Sc+(c[t+24656+(bd*768|0)+(pb*24|0)+(yc<<2)>>2]|0)|0,Uc)|0;Rc=ca((c[t+24656+(cd*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Sc+Tc|0,Uc)|0;Tc=ca((c[t+24656+(nb*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Sc+Rc|0,Uc)|0;Uc=(c[t+24656+(dd*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Sc+Tc|0;Tc=(c[1914008+(oc<<2)>>2]|0)/4|0;if((nc|0)>(Tc|0)){ed=nc;fd=Uc|s<<Tc;gd=Bc}else{Sc=Bc;y=je(Uc>>>((Tc-nc|0)>>>0)|s<<nc|0)|0;a[Sc]=y;y=y>>8;a[Sc+1|0]=y;y=y>>8;a[Sc+2|0]=y;y=y>>8;a[Sc+3|0]=y;Sc=(c[w>>2]|0)+4|0;c[w>>2]=Sc;ed=nc+32|0;fd=Uc;gd=Sc}Sc=ed-Tc|0;c[ab>>2]=fd;c[$a>>2]=Sc;Tc=c[pc>>2]|0;Uc=c[688192+(Tc<<2)>>2]|0;Rc=(Uc-1|0)/2|0;Qc=ca(Rc+(c[t+24656+(_c*768|0)+(pb*24|0)+(yc<<2)>>2]|0)|0,Uc)|0;Pc=ca((c[t+24656+($c*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Rc+Qc|0,Uc)|0;Qc=ca((c[t+24656+(ad*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Rc+Pc|0,Uc)|0;Uc=(c[t+24656+(zc*768|0)+(pb*24|0)+(yc<<2)>>2]|0)+Rc+Qc|0;Qc=(c[1914008+(Tc<<2)>>2]|0)/4|0;if((Sc|0)>(Qc|0)){hd=Sc;id=Uc|fd<<Qc;jd=gd}else{Tc=gd;y=je(Uc>>>((Qc-Sc|0)>>>0)|fd<<Sc|0)|0;a[Tc]=y;y=y>>8;a[Tc+1|0]=y;y=y>>8;a[Tc+2|0]=y;y=y>>8;a[Tc+3|0]=y;Tc=(c[w>>2]|0)+4|0;c[w>>2]=Tc;hd=Sc+32|0;id=Uc;jd=Tc}Tc=hd-Qc|0;c[ab>>2]=id;c[$a>>2]=Tc;kd=id;ld=Tc;md=jd}else{Tc=0;Qc=s;Uc=nc;Sc=oc;Rc=Bc;while(1){Pc=(c[1914008+(Sc<<2)>>2]|0)/16|0;Oc=(1<<Pc)-1&c[t+24656+((Tc+dd|0)*768|0)+(pb*24|0)+(yc<<2)>>2];if((Uc|0)>(Pc|0)){nd=Uc;od=Oc|Qc<<Pc;pd=Rc}else{Mc=Rc;y=je(Oc>>>((Pc-Uc|0)>>>0)|Qc<<Uc|0)|0;a[Mc]=y;y=y>>8;a[Mc+1|0]=y;y=y>>8;a[Mc+2|0]=y;y=y>>8;a[Mc+3|0]=y;Mc=(c[w>>2]|0)+4|0;c[w>>2]=Mc;nd=Uc+32|0;od=Oc;pd=Mc}Mc=nd-Pc|0;c[ab>>2]=od;c[$a>>2]=Mc;Pc=Tc+1|0;if((Pc|0)>=8){kd=od;ld=Mc;md=pd;break b}Tc=Pc;Qc=od;Uc=Mc;Sc=c[pc>>2]|0;Rc=pd}}}while(0);pc=pb+1|0;if((pc|0)<32){pb=pc;s=kd;nc=ld;Bc=md}else{break}}Bc=yc+1|0;nc=c[z>>2]|0;if((Bc|0)<(nc|0)){yc=Bc;C=kd;Ac=ld;ob=md}else{qd=kd;rd=ld;sd=nc;td=md;break}}}else{qd=Wc;rd=Xc;sd=Yc;td=Zc}ob=Vc+1|0;if((ob|0)<2){Vc=ob;Wc=qd;Xc=rd;Yc=sd;Zc=td}else{break}}if((rd|0)>16){ud=rd-16|0;vd=qd<<16|65535;wd=td}else{Zc=td;y=je(65535>>>((16-rd|0)>>>0)|qd<<rd|0)|0;a[Zc]=y;y=y>>8;a[Zc+1|0]=y;y=y>>8;a[Zc+2|0]=y;y=y>>8;a[Zc+3|0]=y;Zc=(c[w>>2]|0)+4|0;c[w>>2]=Zc;ud=rd+16|0;vd=65535;wd=Zc}c[ab>>2]=vd;c[$a>>2]=ud;c:do{if((ud|0)<32){Zc=vd<<ud;c[ab>>2]=Zc;rd=Zc>>>24&255;Zc=wd;while(1){c[w>>2]=Zc+1;a[Zc]=rd;qd=c[ab>>2]|0;c[ab>>2]=qd<<8;td=(c[$a>>2]|0)+8|0;c[$a>>2]=td;if((td|0)>=32){break c}rd=qd>>>16&255;Zc=c[w>>2]|0}}}while(0);c[$a>>2]=32;c[ab>>2]=0;ab=f+136|0;$a=c[ab+4>>2]|0;w=e+8|0;c[w>>2]=c[ab>>2];c[w+4>>2]=$a;$a=c[f+76>>2]|0;c[p>>2]=1;c[p+4>>2]=c[b+412>>2];f=XIb($a,($a|0)<0|0?-1:0,p,b+104|0)|0;c[e+48>>2]=f;c[bb>>2]=(c[u>>2]|0)+1;c[g>>2]=1;x=0;i=h;return x|0}function e5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;if((a|0)>=1){KIb(0,0,2365904,(f=i,i=i+24|0,c[f>>2]=2300568,c[f+8>>2]=2249336,c[f+16>>2]=653,f)|0);i=f;Hd();return 0}if(!((a|0)>-2048)){KIb(0,0,2365904,(f=i,i=i+24|0,c[f>>2]=2207072,c[f+8>>2]=2249336,c[f+16>>2]=654,f)|0);i=f;Hd();return 0}g=c[9868184+(-a<<2)>>2]|0;a=c[556788+(b<<3)>>2]|0;h=556784+(b<<3)|0;j=688192+(b<<2)|0;b=g;k=(g|0)<0|0?-1:0;g=127;l=64;while(1){m=g-l|0;n=a+(c[604340+(m<<3)>>2]|0)|0;if((n|0)<18){o=g}else{p=c[604336+(m<<3)>>2]|0;q=c[h>>2]|0;r=Erc(q,(q|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;wrc(r,G,-2147483648,0)|0;r=G;p=((c[j>>2]|0)-1|0)/2|0;q=Erc(r,(r|0)<0|0?-1:0,b,k)|0;wrc(q,G,-2147483648,0)|0;o=(p|0)<(G+(1<<n-18)>>n-17|0)?g:m}m=l>>1;if((m|0)>0){g=o;l=m}else{break}}l=(o|0)>124?124:o;o=c[604336+(l<<3)>>2]|0;g=c[h>>2]|0;h=Erc(g,(g|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;wrc(h,G,-2147483648,0)|0;h=G;c[d>>2]=h;o=(c[604340+(l<<3)>>2]|0)-17+a|0;c[d+4>>2]=o;d=((c[j>>2]|0)-1|0)/2|0;j=Erc(h,(h|0)<0|0?-1:0,b,k)|0;wrc(j,G,-2147483648,0)|0;if((d|0)<(G+(1<<o-1)>>o|0)){KIb(0,0,2365904,(f=i,i=i+24|0,c[f>>2]=2174648,c[f+8>>2]=2249336,c[f+16>>2]=674,f)|0);i=f;Hd();return 0}else{i=e;return l|0}return 0}function f5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a+32|0;e=c[d>>2]|0;f=e*493|0;g=a+44024|0;c[g>>2]=f+132;if((c[a+40>>2]|0)!=0){c[g>>2]=f+204}if((e|0)>0){f=0;h=0;while(1){i=0;j=f;while(1){k=(c[a+36944+(i*24|0)+(h<<2)>>2]|0)-(c[a+43888+(i<<2)>>2]|0)-b|0;do{if((k|0)>1311){c[a+39792+(i*24|0)+(h<<2)>>2]=26;l=j|4}else{if((k|0)>221){m=k-222|0;n=Erc(m,(m|0)<0|0?-1:0,69e6,0)|0;wrc(n,G,-2147483648,0)|0;c[a+39792+(i*24|0)+(h<<2)>>2]=G+8;l=j|2;break}if((k|0)>-1){n=Erc(k,(k|0)<0|0?-1:0,106e6,0)|0;wrc(n,G,-2147483648,0)|0;c[a+39792+(i*24|0)+(h<<2)>>2]=G+2;l=j|2;break}else{c[a+39792+(i*24|0)+(h<<2)>>2]=1;l=j|1;break}}}while(0);k=i+1|0;if((k|0)<32){i=k;j=l}else{break}}j=h+1|0;i=c[d>>2]|0;if((j|0)<(i|0)){f=l;h=j}else{o=l;p=i;break}}}else{o=0;p=e}e=0;do{if((p|0)>0){l=0;h=c[g>>2]|0;do{h=h+(c[1914008+(c[a+39792+(e*24|0)+(l<<2)>>2]<<2)>>2]|0)|0;c[g>>2]=h;l=l+1|0;}while((l|0)<(p|0))}e=e+1|0;}while((e|0)<32);return o|0}function g5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0.0,k=0;e=1<<b;mrc(a|0,0,112)|0;c[a>>2]=b;c[a+4>>2]=d;do{if((d|0)==0&(b|0)==5){c[a+104>>2]=22}else{f=b+2|0;oda(f);c[a+96>>2]=c[1405944+(f<<2)>>2];f=(e|0)/2|0;h=a+100|0;c[h>>2]=hJb(f<<2)|0;if((nZa(a+8|0,b,(d|0)==1|0)|0)<0){kJb(c[h>>2]|0);i=-1;return i|0}if((e|0)>1){j=3.141592653589793/+(e<<1|0);k=c[h>>2]|0;h=0;do{g[k+(h<<2)>>2]=.5/+V(+(h<<1|1|0)*j);h=h+1|0;}while((h|0)<(f|0))}if((d|0)==2){c[a+104>>2]=204;break}else if((d|0)==1){c[a+104>>2]=268;break}else if((d|0)==3){c[a+104>>2]=612;break}else if((d|0)==0){c[a+104>>2]=262;break}else{break}}}while(0);c[a+108>>2]=506;i=0;return i|0}function h5(a,b){a=a|0;b=b|0;re[c[a+108>>2]&1023](b,b);return}function i5(a,b){a=a|0;b=b|0;var d=0,e=0.0,f=0,h=0.0,i=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0.0;d=1<<c[a>>2];e=+g[b>>2];f=b+(d<<2)|0;h=(e- +g[f>>2])*-.5;i=(d|0)/2|0;a:do{if((d|0)>1){j=c[a+96>>2]|0;k=h;l=0;m=e;while(1){n=b+(d-l<<2)|0;o=+g[n>>2];p=l<<1;q=m-o;r=q*+g[j+(d-p<<2)>>2];s=k+q*+g[j+(p<<2)>>2];q=(m+o)*.5;g[b+(l<<2)>>2]=q-r;g[n>>2]=q+r;n=l+1|0;if((n|0)>=(i|0)){t=s;break a}k=s;l=n;m=+g[b+(n<<2)>>2]}}else{t=h}}while(0);re[c[a+92>>2]&1023](a+8|0,b);a=b+4|0;g[f>>2]=+g[a>>2];g[a>>2]=t;if((d|0)<3){return}else{u=3;v=t}do{a=b+(u<<2)|0;v=v- +g[a>>2];g[a>>2]=v;u=u+2|0;}while((u|0)<=(d|0));return}function j5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0.0,l=0,m=0.0,n=0.0,o=0.0,p=0.0;d=1<<c[a>>2];e=(d|0)/2|0;if((d|0)>1){f=d-1|0;h=c[a+96>>2]|0;i=0;do{j=b+(i<<2)|0;k=+g[j>>2];l=b+(f-i<<2)|0;m=+g[l>>2];n=(k-m)*+g[h+(d-(i<<1|1)<<2)>>2];o=(k+m)*.5;g[j>>2]=o+n;g[l>>2]=o-n;i=i+1|0;}while((i|0)<(e|0))}re[c[a+92>>2]&1023](a+8|0,b);e=b+4|0;n=+g[e>>2];g[e>>2]=n*-1.0;e=d-2|0;if(!((e|0)>-1)){return}i=c[a+96>>2]|0;o=n*.5;a=d;h=e;while(1){e=b+(h<<2)|0;n=+g[e>>2];f=b+(a-1<<2)|0;m=+g[f>>2];k=+g[i+(h<<2)>>2];p=+g[i+(d-h<<2)>>2];g[e>>2]=n*k+m*p;g[f>>2]=o;f=h-2|0;if((f|0)>-1){o=o+(n*p-m*k);a=h;h=f}else{break}}return}function k5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0.0,h=0.0,i=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0,p=0.0,q=0.0;d=1<<c[a>>2];e=d-1|0;f=+g[b+(e<<2)>>2];h=1.0/+(d|0);i=d-2|0;if((i|0)>1){j=c[a+96>>2]|0;k=d;l=i;while(1){i=b+(l<<2)|0;m=+g[i>>2];n=b+(k-1<<2)|0;o=+g[b+(k-3<<2)>>2]- +g[n>>2];p=+g[j+(l<<2)>>2];q=+g[j+(d-l<<2)>>2];g[i>>2]=m*p+o*q;g[n>>2]=m*q-o*p;n=l-2|0;if((n|0)>1){k=l;l=n}else{break}}}g[b+4>>2]=f*2.0;re[c[a+92>>2]&1023](a+8|0,b);l=(d|0)/2|0;if((d|0)<=1){return}d=c[a+100>>2]|0;a=0;do{k=b+(a<<2)|0;f=h*+g[k>>2];j=b+(e-a<<2)|0;p=h*+g[j>>2];o=+g[d+(a<<2)>>2]*(f-p);q=f+p;g[k>>2]=q+o;g[j>>2]=q-o;a=a+1|0;}while((a|0)<(l|0));return}function l5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0.0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0.0,q=0,r=0;d=1<<c[a>>2];g[b>>2]=0.0;e=(d|0)/2|0;if((d|0)>3){f=c[a+96>>2]|0;h=1;do{i=b+(h<<2)|0;j=+g[i>>2];k=b+(d-h<<2)|0;l=+g[k>>2];m=(j+l)*+g[f+(d-(h<<1)<<2)>>2];n=(j-l)*.5;g[i>>2]=n+m;g[k>>2]=m-n;h=h+1|0;}while((h|0)<(e|0))}h=b+(e<<2)|0;g[h>>2]=+g[h>>2]*2.0;re[c[a+92>>2]&1023](a+8|0,b);n=+g[b>>2]*.5;g[b>>2]=n;a=d-2|0;if((a|0)>1){o=1;p=n}else{q=d-1|0;r=b+(q<<2)|0;g[r>>2]=0.0;return}while(1){h=b+(o+1<<2)|0;n=p+ +g[h>>2];g[h>>2]=n;h=o+2|0;g[b+(o<<2)>>2]=-0.0- +g[b+(h<<2)>>2];if((h|0)<(a|0)){o=h;p=n}else{break}}q=d-1|0;r=b+(q<<2)|0;g[r>>2]=0.0;return}function m5(a){a=a|0;pZa(a+8|0);kJb(c[a+100>>2]|0);return}function n5(a,b){a=a|0;b=b|0;var c=0.0,d=0.0,e=0.0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0;c=+g[b>>2];d=+g[b+124>>2];e=c+d;f=(c-d)*.5006030201911926;d=+g[b+60>>2];c=+g[b+64>>2];h=d+c;i=(d-c)*10.190008163452148;c=e+h;d=(e-h)*.5024192929267883;h=f+i;e=(i-f)*-.5024192929267883;f=+g[b+28>>2];i=+g[b+96>>2];j=f+i;k=(f-i)*.6748083233833313;i=+g[b+32>>2];f=+g[b+92>>2];l=i+f;m=(i-f)*.744536280632019;f=j+l;i=(j-l)*5.10114860534668;l=k+m;j=(m-k)*-5.10114860534668;k=c+f;m=(c-f)*.509795606136322;f=d+i;c=(i-d)*-.509795606136322;d=h+l;i=(h-l)*.509795606136322;l=e+j;h=(j-e)*-.509795606136322;e=+g[b+12>>2];j=+g[b+112>>2];n=e+j;o=(e-j)*.5310425758361816;j=+g[b+48>>2];e=+g[b+76>>2];p=j+e;q=(j-e)*1.4841645956039429;e=n+p;j=(n-p)*.6468217968940735;p=o+q;n=(q-o)*-.6468217968940735;o=+g[b+16>>2];q=+g[b+108>>2];r=o+q;s=(o-q)*.5531039237976074;q=+g[b+44>>2];o=+g[b+80>>2];t=q+o;u=(q-o)*1.1694399118423462;o=r+t;q=(r-t)*.7881546020507812;t=s+u;r=(u-s)*-.7881546020507812;s=e+o;u=(e-o)*2.562915563583374;o=j+q;e=(q-j)*-2.562915563583374;j=p+t;q=(p-t)*2.562915563583374;t=n+r;p=(r-n)*-2.562915563583374;n=k+s;r=(k-s)*.5411961078643799;s=m+u;k=(u-m)*-.5411961078643799;m=f+o;u=(f-o)*.5411961078643799;o=c+e;f=(e-c)*-.5411961078643799;c=d+j;e=(d-j)*.5411961078643799;j=i+q;d=(q-i)*-.5411961078643799;i=l+t;q=(l-t)*.5411961078643799;t=h+p;l=(p-h)*-.5411961078643799;h=+g[b+4>>2];p=+g[b+120>>2];v=h+p;w=(h-p)*.5054709315299988;p=+g[b+56>>2];h=+g[b+68>>2];x=p+h;y=(p-h)*3.4076085090637207;h=v+x;p=(v-x)*.522498607635498;x=w+y;v=(y-w)*-.522498607635498;w=+g[b+24>>2];y=+g[b+100>>2];z=w+y;A=(w-y)*.6225041151046753;y=+g[b+36>>2];w=+g[b+88>>2];B=y+w;C=(y-w)*.839349627494812;w=z+B;y=(z-B)*1.722447156906128;B=A+C;z=(C-A)*-1.722447156906128;A=h+w;C=(h-w)*.601344883441925;w=p+y;h=(y-p)*-.601344883441925;p=x+B;y=(x-B)*.601344883441925;B=v+z;x=(z-v)*-.601344883441925;v=+g[b+8>>2];z=+g[b+116>>2];D=v+z;E=(v-z)*.5154473185539246;z=+g[b+52>>2];v=+g[b+72>>2];F=z+v;G=(z-v)*2.0577809810638428;v=D+F;z=(D-F)*.5669440627098083;F=E+G;D=(G-E)*-.5669440627098083;E=+g[b+20>>2];G=+g[b+104>>2];H=E+G;I=(E-G)*.5829349756240845;G=+g[b+40>>2];E=+g[b+84>>2];J=G+E;K=(G-E)*.9725682139396667;E=H+J;G=(H-J)*1.0606776475906372;J=I+K;H=(K-I)*-1.0606776475906372;I=v+E;K=(v-E)*.8999761939048767;E=z+G;v=(G-z)*-.8999761939048767;z=F+J;G=(F-J)*.8999761939048767;J=D+H;F=(H-D)*-.8999761939048767;D=A+I;H=(A-I)*1.3065630197525024;I=C+K;A=(K-C)*-1.3065630197525024;C=w+E;K=(w-E)*1.3065630197525024;E=h+v;w=(v-h)*-1.3065630197525024;h=p+z;v=(p-z)*1.3065630197525024;z=y+G;p=(G-y)*-1.3065630197525024;y=B+J;G=(B-J)*1.3065630197525024;J=x+F;B=(F-x)*-1.3065630197525024;x=(H-r)*-.7071067690849304;F=(s-I)*.7071067690849304;L=(A-k)*-.7071067690849304;M=k+A+L;A=(m-C)*.7071067690849304;k=(K-u)*-.7071067690849304;N=u+K+k;K=(o-E)*.7071067690849304;u=(w-f)*-.7071067690849304;O=f+w+u;w=o+E+O;E=K+O;O=K+u;K=(c-h)*.7071067690849304;o=(v-e)*-.7071067690849304;f=e+v+o;v=(j-z)*.7071067690849304;e=(p-d)*-.7071067690849304;P=d+p+e;p=j+z+P;z=v+P;P=v+e;v=(i-y)*.7071067690849304;j=(G-q)*-.7071067690849304;d=q+G+j;G=(t-J)*.7071067690849304;q=(B-l)*-.7071067690849304;Q=l+B+q;B=t+J+Q;J=G+Q;Q=G+q;g[a>>2]=n+D;g[a+64>>2]=(n-D)*.7071067690849304;g[a+32>>2]=r+H+x;g[a+96>>2]=x;g[a+16>>2]=s+I+M;g[a+80>>2]=F+L;g[a+48>>2]=F+M;g[a+112>>2]=L;g[a+8>>2]=m+C+w;g[a+72>>2]=A+O;g[a+40>>2]=N+E;g[a+104>>2]=k+u;g[a+24>>2]=N+w;g[a+88>>2]=k+O;g[a+56>>2]=A+E;g[a+120>>2]=u;u=i+y+B;y=d+B;B=d+J;d=v+J;J=v+Q;v=j+Q;Q=j+q;g[a+4>>2]=c+h+u;g[a+68>>2]=K+J;g[a+36>>2]=f+B;g[a+100>>2]=o+Q;g[a+20>>2]=p+y;g[a+84>>2]=P+v;g[a+52>>2]=z+d;g[a+116>>2]=e+q;g[a+12>>2]=p+u;g[a+76>>2]=P+J;g[a+44>>2]=z+B;g[a+108>>2]=e+Q;g[a+28>>2]=f+y;g[a+92>>2]=o+v;g[a+60>>2]=K+d;g[a+124>>2]=q;return}function o5(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+60>>2]|0;c[a+140>>2]=11;e=a+120|0;f=c[e>>2]|0;if((f|0)==0){g=-1094995529;i=b;return g|0}h=a+124|0;j=c[h>>2]|0;if((j|0)==0){g=-1094995529;i=b;return g|0}if(!((tIb(f,j,0,a)|0)>-1)){KIb(0,0,2590800,(a=i,i=i+24|0,c[a>>2]=2532648,c[a+8>>2]=2517408,c[a+16>>2]=45,a)|0);i=a;Hd();return 0}a=pJb(ca(c[h>>2]|0,c[e>>2]|0)|0)|0;c[d+1024>>2]=a;g=(a|0)==0?-12:0;i=b;return g|0}function p5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;i=i+16|0;j=h|0;k=c[b+60>>2]|0;if((c[b+100>>2]|0)==2){l=c[b+96>>2]|0;m=(d[l]|d[l+1|0]<<8)<<16>>16&65535}else{m=0}l=M4a(b,e,0)|0;if((l|0)<0){n=l;i=h;return n|0}l=c[g+24>>2]|0;o=g+28|0;g=c[o>>2]|0;if(!((g|0)>-1)){KIb(0,0,2590800,(p=i,i=i+24|0,c[p>>2]=2568976,c[p+8>>2]=2550952,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}q=j|0;c[q>>2]=l;c[j+8>>2]=l;r=l+g|0;s=j+4|0;c[s>>2]=r;t=k+1024|0;a:do{if((g|0)==0){u=b+124|0}else{v=b+120|0;w=b+124|0;x=b;y=e+304|0;z=k;A=r;B=l;b:while(1){C=A;D=C-B|0;E=D>>>0>4>>>0?4:D;D=B+E|0;c[q>>2]=D;if((C-D|0)<4){F=0;G=D}else{H=B+(E+4)|0;c[q>>2]=H;E=D;F=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;G=H}if((C-G|0)<4){u=w;break a}H=G+4|0;c[q>>2]=H;E=G;D=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;do{if((D|0)==1){if(F>>>0>770>>>0){I=256;J=15}else{if(!(F>>>0<3>>>0)){I=(F>>>0)/3|0;J=15}}if((J|0)==15){J=0;E=0;K=H;while(1){if((C-K|0)<3){L=0;M=K}else{N=K+3|0;c[q>>2]=N;L=(d[K+1|0]|0)<<8|(d[K]|0)<<16|(d[K+2|0]|0);M=N}c[z+(E<<2)>>2]=L<<2|L>>>4&197379|-16777216;N=E+1|0;if((N|0)<(I|0)){E=N;K=M}else{break}}}c[y>>2]=1}else if((D|0)==0){u=w;break a}else{if(D>>>0<10>>>0){O=D-2|0;if((hf[c[1584712+(O<<2)>>2]&1023](j,c[t>>2]|0,c[v>>2]|0,c[w>>2]|0)|0)==0){break}else{break b}}else{KIb(x,24,2365872,(p=i,i=i+8|0,c[p>>2]=D,p)|0);i=p;break}}}while(0);D=c[q>>2]|0;C=c[s>>2]|0;if((C|0)==(D|0)){u=w;break a}else{A=C;B=D}}KIb(x,16,2455312,(p=i,i=i+8|0,c[p>>2]=c[1704952+(O<<2)>>2],p)|0);i=p;n=-1094995529;i=h;return n|0}}while(0);p=c[t>>2]|0;t=c[e>>2]|0;O=c[u>>2]|0;c:do{if((O|0)>0){s=e+32|0;q=b+120|0;if((m|0)==256){P=t;Q=0;R=O}else{j=t;M=0;I=p;while(1){nrc(j|0,I|0,c[q>>2]|0)|0;L=M+1|0;if((L|0)<(c[u>>2]|0)){j=j+(c[s>>2]|0)|0;M=L;I=I+(c[q>>2]|0)|0}else{break c}}}while(1){I=c[q>>2]|0;if((I|0)>0){M=Q&3;j=(Q|0)/4|0;x=0;L=I;I=R;while(1){a[P+x|0]=a[p+((ca((L|0)/4|0,M)|0)+((x|0)/4|0)+(ca((ca((I|0)/4|0,x&3)|0)+j|0,L)|0))|0]|0;J=x+1|0;F=c[q>>2]|0;G=c[u>>2]|0;if((J|0)<(F|0)){x=J;L=F;I=G}else{S=G;break}}}else{S=R}I=Q+1|0;if((I|0)<(S|0)){P=P+(c[s>>2]|0)|0;Q=I;R=S}else{break}}}}while(0);nrc(c[e+4>>2]|0,k|0,1024)|0;c[f>>2]=1;n=c[o>>2]|0;i=h;return n|0}function q5(a){a=a|0;mJb((c[a+60>>2]|0)+1024|0);return 0}function r5(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=ca(e,d)|0;d=a|0;e=c[d>>2]|0;g=(c[a+4>>2]|0)-e|0;a=g>>>0>f>>>0?f:g;nrc(b|0,e|0,a)|0;c[d>>2]=(c[d>>2]|0)+a;return((a|0)==(f|0)?0:-1094995529)|0}function s5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=ca(g,f)|0;f=b+4|0;g=c[f>>2]|0;i=b|0;b=c[i>>2]|0;j=g;if((j-b|0)<4){k=0;l=b}else{m=b+4|0;c[i>>2]=m;n=b;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;l=m}if((j-l|0)<4){o=0;p=l}else{j=l+4|0;c[i>>2]=j;m=l;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;p=j}j=(k|0)==0;if(j&(o|0)==(h|0)){q=0;return q|0}m=e+h|0;l=e;n=h>>>0<=o>>>0;if(n|j){q=n?-1094995529:0;return q|0}n=65536;j=0;h=e+o|0;o=k;k=p;p=g;while(1){g=o-1|0;e=p;if((e-k|0)>>>0<2>>>0){q=-1094995529;r=24;break}if((n|0)==65536){b=k+2|0;c[i>>2]=b;s=k;t=(d[s]|d[s+1|0]<<8)<<16>>16&65535;u=1;v=b}else{t=j;u=n;v=k}b=h;s=m-b|0;if((s|0)<2){q=-1094995529;r=24;break}w=e-v|0;if((t&u|0)==0){if((w|0)<1){x=0}else{c[i>>2]=v+1;x=a[v]|0}a[h]=x;e=c[i>>2]|0;if(((c[f>>2]|0)-e|0)<1){y=0}else{c[i>>2]=e+1;y=a[e]|0}a[h+1|0]=y;z=h+2|0}else{if((w|0)<2){A=0}else{c[i>>2]=v+2;w=v;A=(d[w]|d[w+1|0]<<8)<<16>>16&65535}w=A<<1&16382;e=(A>>>13<<1)+4|0;if((b-l|0)>>>0<w>>>0|(s|0)<(e|0)){q=-1094995529;r=24;break}vJb(h,w,e);z=h+e|0}if((g|0)==0){q=0;r=24;break}n=u<<1;j=t;h=z;o=g;k=c[i>>2]|0;p=c[f>>2]|0}if((r|0)==24){return q|0}return 0}function t5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=b+4|0;i=c[h>>2]|0;j=b|0;b=c[j>>2]|0;k=i;if((k-b|0)<2){l=0;m=b}else{n=b+2|0;c[j>>2]=n;o=b;l=(d[o]|d[o+1|0]<<8)<<16>>16&65535;m=n}if((l|0)>=(g|0)){p=-1094995529;return p|0}n=e+(ca(l,f)|0)|0;if((k-m|0)<2){q=0;r=m}else{k=m+2|0;c[j>>2]=k;e=m;q=(d[e]|d[e+1|0]<<8)<<16>>16&65535;r=k}if((q+l|0)>(g|0)){p=-1094995529;return p|0}if((q|0)==0){p=0;return p|0}else{s=n;t=q;u=r;v=i}a:while(1){i=t-1|0;if((v|0)==(u|0)){p=-1094995529;w=28;break}r=s+f|0;q=u+1|0;c[j>>2]=q;n=a[u]|0;b:do{if(!(n<<24>>24==0)){g=r;l=s;k=n&255;e=q;m=v;while(1){o=k-1|0;b=m;x=(b-e|0)<1;if(x){y=0}else{y=d[e]|0}if(!((g-l|0)>>>0>y>>>0)){p=-1094995529;w=28;break a}if(x){z=0;A=e}else{x=e+1|0;c[j>>2]=x;z=d[e]|0;A=x}x=l+z|0;do{if((b-A|0)<1){B=0;C=A;w=20}else{D=A+1|0;c[j>>2]=D;E=a[A]|0;F=E<<24>>24;if(((E&255)<<24|0)>-16777216){B=F;C=D;w=20;break}E=-F|0;if((g-x|0)<(E|0)){p=-1094995529;w=28;break a}if((b-D|0)<1){G=0}else{c[j>>2]=A+2;G=a[D]|0}mrc(x|0,G|0,E|0)|0;H=E}}while(0);if((w|0)==20){w=0;if((g-x|0)<(B|0)){p=-1094995529;w=28;break a}E=b-C|0;D=E>>>0>B>>>0?B:E;nrc(x|0,C|0,D)|0;c[j>>2]=(c[j>>2]|0)+D;if((D|0)==(B|0)){H=B}else{p=-1094995529;w=28;break a}}if((o|0)==0){break b}l=l+(H+z)|0;k=o;e=c[j>>2]|0;m=c[h>>2]|0}}}while(0);if((i|0)==0){p=0;w=28;break}s=r;t=i;u=c[j>>2]|0;v=c[h>>2]|0}if((w|0)==28){return p|0}return 0}function u5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=e+(ca(g,f)|0)|0;i=b+4|0;j=c[i>>2]|0;k=b|0;b=c[k>>2]|0;if((j-b|0)<2){l=0;m=b}else{n=b+2|0;c[k>>2]=n;o=b;l=(d[o]|d[o+1|0]<<8)<<16>>16&65535;m=n}if((l|0)>(g|0)){p=-1094995529;return p|0}if((l|0)==0){p=0;return p|0}n=h;o=f-1|0;b=-f|0;q=0;r=e;e=l;l=m;m=j;a:while(1){j=e-1|0;s=m;if((s-l|0)>>>0<2>>>0){p=-1094995529;t=40;break}u=l+2|0;c[k>>2]=u;v=l;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;b:do{if((w&49152|0)==49152){v=w;x=q;z=r;A=u;while(1){B=v<<16>>16;C=ca(B,b)|0;if(!((n-z|0)>>>0>C>>>0)){p=-1094995529;t=40;break a}if((x+j-B|0)>>>0>g>>>0){p=-1094995529;t=40;break a}D=z+C|0;C=x-B|0;if((s-A|0)<2){E=0;F=C;G=D;H=A;break b}B=A+2|0;c[k>>2]=B;I=A;J=(d[I]|d[I+1|0]<<8)<<16>>16&65535;if((J&49152|0)==49152){v=J;x=C;z=D;A=B}else{E=J;F=C;G=D;H=B;break}}}else{E=w;F=q;G=r;H=u}}while(0);if(!(h>>>0>G>>>0)){p=-1094995529;t=40;break}do{if((E&32768|0)==0){K=E;L=H;M=m}else{a[G+o|0]=E;u=c[i>>2]|0;w=c[k>>2]|0;if((u-w|0)<2){K=0;L=w;M=u;break}s=w+2|0;c[k>>2]=s;A=w;K=(d[A]|d[A+1|0]<<8)<<16>>16&65535;L=s;M=u}}while(0);if((n-G|0)<(f|0)){p=-1094995529;t=40;break}u=G+f|0;s=F+1|0;c:do{if((K|0)!=0){A=u;w=G;z=K;x=L;v=M;while(1){B=z-1|0;D=v;C=(D-x|0)<1;if(C){N=0}else{N=d[x]|0}if(!((A-w|0)>>>0>N>>>0)){p=-1094995529;t=40;break a}if(C){O=0;P=x}else{C=x+1|0;c[k>>2]=C;O=d[x]|0;P=C}C=w+O|0;do{if((D-P|0)<1){Q=0;R=P;t=29}else{J=P+1|0;c[k>>2]=J;I=a[P]|0;S=(I&255)<<24;if((S|0)>-16777216){Q=S;R=J;t=29;break}S=I<<24>>24;T=-S|0;if((A-C|0)<(T<<1|0)){p=-1094995529;t=40;break a}if((D-J|0)<2){U=0}else{c[k>>2]=P+3;V=J;U=(d[V]|d[V+1|0]<<8)<<16>>16}if(!(I<<24>>24<0)){W=C;break}I=-S|0;S=O+((I|0)>1?I<<1:2)|0;I=C;V=0;while(1){J=I;y=U;a[J]=y;y=y>>8;a[J+1|0]=y;J=V+1|0;if((J|0)<(T|0)){I=I+2|0;V=J}else{break}}W=w+S|0}}while(0);if((t|0)==29){t=0;V=Q>>23;if((A-C|0)<(V|0)){p=-1094995529;t=40;break a}I=D-R|0;T=I>>>0>V>>>0?V:I;nrc(C|0,R|0,T)|0;c[k>>2]=(c[k>>2]|0)+T;if((T|0)!=(V|0)){p=-1094995529;t=40;break a}W=w+(V+O)|0}if((B|0)==0){break c}w=W;z=B;x=c[k>>2]|0;v=c[i>>2]|0}}}while(0);if((j|0)==0){p=0;t=40;break}q=s;r=u;e=j;l=c[k>>2]|0;m=c[i>>2]|0}if((t|0)==40){return p|0}return 0}function v5(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=b+(ca(f,e)|0)|0;e=a+4|0;f=c[e>>2]|0;h=a|0;a=c[h>>2]|0;if((f-a|0)<4){i=0;return i|0}j=a+4|0;c[h>>2]=j;k=a;a=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;if((a|0)==0){i=0;return i|0}k=g;g=b;b=a;a=j;j=f;while(1){f=b-1|0;l=j;if((l-a|0)>>>0<2>>>0){i=-1094995529;m=9;break}n=a+1|0;c[h>>2]=n;o=(d[a]|0)<<1;p=a+2|0;c[h>>2]=p;q=(d[n]|0)<<1;n=q+o|0;if((k-g|0)<(n|0)){i=-1094995529;m=9;break}r=l-p|0;if(r>>>0<o>>>0){i=-1094995529;m=9;break}l=r>>>0>o>>>0?o:r;nrc(g+q|0,p|0,l)|0;p=(c[h>>2]|0)+l|0;c[h>>2]=p;if((f|0)==0){i=0;m=9;break}g=g+n|0;b=f;a=p;j=c[e>>2]|0}if((m|0)==9){return i|0}return 0}function w5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=e+(ca(g,f)|0)|0;f=b+4|0;g=c[f>>2]|0;i=b|0;b=c[i>>2]|0;if((g-b|0)<2){j=0;return j|0}k=b+2|0;c[i>>2]=k;l=b;b=(d[l]|d[l+1|0]<<8)<<16>>16;if(b<<16>>16==0){j=0;return j|0}l=h;h=e;m=0;n=65536;o=e;e=b&65535;b=k;k=g;a:while(1){g=e-1|0;p=k;if((p-b|0)>>>0<2>>>0){j=-1094995529;q=24;break}if((n|0)==65536){r=b+2|0;c[i>>2]=r;s=b;t=1;u=(d[s]|d[s+1|0]<<8)<<16>>16&65535;v=r}else{t=n;u=m;v=b}r=o;s=l-r|0;if((s|0)<2){j=-1094995529;q=24;break}do{if((t&u|0)==0){w=p-v|0;if((t<<1&u|0)!=0){if((w|0)<2){x=0}else{c[i>>2]=v+2;y=v;x=(d[y]|d[y+1|0]<<8)<<16>>16&65535}z=o+x|0;break}if((w|0)<1){A=0}else{c[i>>2]=v+1;A=a[v]|0}a[o]=A;w=c[i>>2]|0;if(((c[f>>2]|0)-w|0)<1){B=0}else{c[i>>2]=w+1;B=a[w]|0}a[o+1|0]=B;z=o+2|0}else{if((p-v|0)<2){C=0}else{c[i>>2]=v+2;w=v;C=(d[w]|d[w+1|0]<<8)<<16>>16&65535}w=C<<1&16382;y=(C>>>13<<1)+4|0;if((r-h|0)<(w|0)|(s|0)<(y|0)){j=-1094995529;q=24;break a}vJb(o,w,y);z=o+y|0}}while(0);if((g|0)==0){j=0;q=24;break}m=u;n=t<<2;o=z;e=g;b=c[i>>2]|0;k=c[f>>2]|0}if((q|0)==24){return j|0}return 0}function x5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mrc(b|0,0,ca(d,c)|0)|0;return 0}function y5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=b+4|0;i=c[h>>2]|0;j=b|0;b=c[j>>2]|0;if((i-b|0)<2){k=0;return k|0}l=e+(ca(g,f)|0)|0;g=b+2|0;c[j>>2]=g;m=b;b=(d[m]|d[m+1|0]<<8)<<16>>16;m=l;if(b<<16>>16==0){k=0;return k|0}l=f+3|0;n=f+1|0;o=f+2|0;p=e;q=65536;r=0;s=e;e=b&65535;b=g;g=i;a:while(1){i=e-1|0;t=g;if((t-b|0)>>>0<2>>>0){k=-1094995529;u=28;break}if((q|0)==65536){v=b+2|0;c[j>>2]=v;w=b;x=(d[w]|d[w+1|0]<<8)<<16>>16&65535;y=1;z=v}else{x=r;y=q;z=b}do{if((x&y|0)==0){if((x&y<<1|0)!=0){if((t-z|0)<2){A=0}else{c[j>>2]=z+2;v=z;A=((d[v]|d[v+1|0]<<8)<<16>>16&65535)<<1}if((s-m|0)<(A|0)){k=-1094995529;u=28;break a}B=s+A|0;break}if((m-s|0)<(l|0)){k=-1094995529;u=28;break a}if((t-z|0)<1){C=0}else{c[j>>2]=z+1;C=a[z]|0}a[s+n|0]=C;a[s+f|0]=C;a[s+1|0]=C;a[s]=C;v=c[j>>2]|0;if(((c[h>>2]|0)-v|0)<1){D=0}else{c[j>>2]=v+1;D=a[v]|0}a[s+l|0]=D;a[s+o|0]=D;a[s+3|0]=D;a[s+2|0]=D;B=s+4|0}else{if((t-z|0)<2){E=0}else{c[j>>2]=z+2;v=z;E=(d[v]|d[v+1|0]<<8)<<16>>16&65535}v=E<<2&32764;w=E>>>13;F=(w<<1)+4|0;G=s;if((G-p|0)<(v|0)){k=-1094995529;u=28;break a}if((m-G|0)<((F<<1)+f|0)){k=-1094995529;u=28;break a}G=-v|0;v=w<<2;w=0;H=s;while(1){I=a[H+G|0]|0;a[H+n|0]=I;a[H+f|0]=I;a[H+1|0]=I;a[H]=I;I=w+1|0;if((I|0)<(F|0)){w=I;H=H+2|0}else{break}}B=s+(v+8)|0}}while(0);if((i|0)==0){k=0;u=28;break}q=y<<2;r=x;s=B;e=i;b=c[j>>2]|0;g=c[h>>2]|0}if((u|0)==28){return k|0}return 0}function z5(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=f+8|0;m=c[l>>2]|0;n=f+16|0;o=c[n>>2]|0;p=f|0;f=c[p>>2]|0;q=f+(m>>>3)|0;r=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(m&7);if((r&-1434451968|0)==0){q=1;s=m;t=r;while(1){u=t>>>24;v=a[1369728+u|0]|0;w=v&255;x=((v&255)>>>0>8>>>0?8:w)+s|0;y=o>>>0>x>>>0;z=y?x:o;if(!(v<<24>>24==9)){A=4;break}v=d[1369984+u|0]|q<<4;if(!(v>>>0<134217728>>>0)){B=v;break}x=f+(z>>>3)|0;C=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7);if(y){q=v;s=z;t=C}else{B=v;break}}if((A|0)==4){B=d[1369984+u|0]|q<<(w-1>>1)}c[l>>2]=z;D=B-1|0;E=z}else{z=r>>>24;r=(d[1369728+z|0]|0)+m|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;D=d[1369216+z|0]|0;E=m}m=f+(E>>>3)|0;z=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(E&7);a:do{if((z&-1434451968|0)==0){m=1;r=E;B=z;while(1){w=B>>>24;q=a[1369728+w|0]|0;u=((q&255)>>>0>8>>>0?8:q&255)+r|0;t=o>>>0>u>>>0;s=t?u:o;if(!(q<<24>>24==9)){F=s;break a}q=d[1369984+w|0]|m<<4;if(!(q>>>0<134217728>>>0)){F=s;break a}w=f+(s>>>3)|0;u=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(s&7);if(t){m=q;r=s;B=u}else{F=s;break}}}else{B=(d[1369728+(z>>>24)|0]|0)+E|0;F=o>>>0>B>>>0?B:o}}while(0);c[l>>2]=F;E=f+(F>>>3)|0;z=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(F&7);if((z&-1434451968|0)==0){E=1;B=F;r=z;while(1){G=r>>>24;m=a[1369728+G|0]|0;H=m&255;s=((m&255)>>>0>8>>>0?8:H)+B|0;u=o>>>0>s>>>0;I=u?s:o;if(!(m<<24>>24==9)){A=16;break}m=d[1369984+G|0]|E<<4;if(!(m>>>0<134217728>>>0)){J=m;break}s=f+(I>>>3)|0;q=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(I&7);if(u){E=m;B=I;r=q}else{J=m;break}}if((A|0)==16){J=d[1369984+G|0]|E<<(H-1>>1)}c[l>>2]=I;K=J-1|0}else{J=z>>>24;z=(d[1369728+J|0]|0)+F|0;c[l>>2]=o>>>0>z>>>0?z:o;K=d[1369216+J|0]|0}c[e+840>>2]=K;K=c[l>>2]|0;J=c[n>>2]|0;o=f+(K>>>3)|0;z=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(K&7);if((z&-1434451968|0)==0){o=1;F=K;I=z;while(1){L=I>>>24;H=a[1369728+L|0]|0;M=H&255;E=((H&255)>>>0>8>>>0?8:M)+F|0;G=J>>>0>E>>>0;N=G?E:J;if(!(H<<24>>24==9)){A=23;break}H=d[1369984+L|0]|o<<4;if(!(H>>>0<134217728>>>0)){O=H;break}E=f+(N>>>3)|0;r=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(N&7);if(G){o=H;F=N;I=r}else{O=H;break}}if((A|0)==23){O=d[1369984+L|0]|o<<(M-1>>1)}c[l>>2]=N;P=O-1|0}else{O=z>>>24;z=(d[1369728+O|0]|0)+K|0;c[l>>2]=J>>>0>z>>>0?z:J;P=d[1369216+O|0]|0}c[e+844>>2]=P;P=c[l>>2]|0;O=c[n>>2]|0;J=f+(P>>>3)|0;z=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(P&7);if((z&-1434451968|0)==0){J=1;K=P;N=z;while(1){Q=N>>>24;M=a[1369728+Q|0]|0;R=M&255;o=((M&255)>>>0>8>>>0?8:R)+K|0;L=O>>>0>o>>>0;S=L?o:O;if(!(M<<24>>24==9)){A=30;break}M=d[1369984+Q|0]|J<<4;if(!(M>>>0<134217728>>>0)){T=M;break}o=f+(S>>>3)|0;I=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(S&7);if(L){J=M;K=S;N=I}else{T=M;break}}if((A|0)==30){T=d[1369984+Q|0]|J<<(R-1>>1)}c[l>>2]=S;U=T-1|0}else{T=z>>>24;z=(d[1369728+T|0]|0)+P|0;c[l>>2]=O>>>0>z>>>0?z:O;U=d[1369216+T|0]|0}do{if(D>>>0<2>>>0){KIb(e,24,2566584,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}else{if(!(D>>>0>2>>>0)){break}KIb(e,24,2608928,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}}while(0);if(U>>>0>20>>>0){W=-1094995529;i=h;return W|0}D=g;T=1532448+(U*24|0)|0;c[D>>2]=c[T>>2];c[D+4>>2]=c[T+4>>2];c[D+8>>2]=c[T+8>>2];c[D+12>>2]=c[T+12>>2];c[D+16>>2]=c[T+16>>2];c[D+20>>2]=c[T+20>>2];T=c[l>>2]|0;D=c[p>>2]|0;U=d[D+(T>>>3)|0]|0;O=c[n>>2]|0;z=((T|0)<(O|0))+T|0;c[l>>2]=z;if((U&128>>>((T&7)>>>0)|0)==0){X=z;Y=O}else{T=D+(z>>>3)|0;U=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(z&7);if((U&-1434451968|0)==0){T=1;P=z;S=U;while(1){Z=S>>>24;R=a[1369728+Z|0]|0;_=R&255;J=((R&255)>>>0>8>>>0?8:_)+P|0;Q=O>>>0>J>>>0;$=Q?J:O;if(!(R<<24>>24==9)){A=43;break}R=d[1369984+Z|0]|T<<4;if(!(R>>>0<134217728>>>0)){aa=R;break}J=D+($>>>3)|0;N=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<($&7);if(Q){T=R;P=$;S=N}else{aa=R;break}}if((A|0)==43){aa=d[1369984+Z|0]|T<<(_-1>>1)}c[l>>2]=$;ba=aa-1|0}else{aa=U>>>24;U=(d[1369728+aa|0]|0)+z|0;c[l>>2]=O>>>0>U>>>0?U:O;ba=d[1369216+aa|0]|0}c[g>>2]=ba;ba=c[l>>2]|0;aa=c[n>>2]|0;O=D+(ba>>>3)|0;U=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(ba&7);if((U&-1434451968|0)==0){O=1;z=ba;$=U;while(1){ca=$>>>24;_=a[1369728+ca|0]|0;da=_&255;T=((_&255)>>>0>8>>>0?8:da)+z|0;Z=aa>>>0>T>>>0;ea=Z?T:aa;if(!(_<<24>>24==9)){A=50;break}_=d[1369984+ca|0]|O<<4;if(!(_>>>0<134217728>>>0)){fa=_;break}T=D+(ea>>>3)|0;S=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(ea&7);if(Z){O=_;z=ea;$=S}else{fa=_;break}}if((A|0)==50){fa=d[1369984+ca|0]|O<<(da-1>>1)}c[l>>2]=ea;ga=fa-1|0}else{fa=U>>>24;U=(d[1369728+fa|0]|0)+ba|0;c[l>>2]=aa>>>0>U>>>0?U:aa;ga=d[1369216+fa|0]|0}c[g+4>>2]=ga;X=c[l>>2]|0;Y=c[n>>2]|0}ga=d[D+(X>>>3)|0]|0;fa=((X|0)<(Y|0))+X|0;c[l>>2]=fa;if((ga&128>>>((X&7)>>>0)|0)==0){ha=a[g+8|0]|0}else{X=D+(fa>>>3)|0;ga=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(fa&7);if((ga&-1434451968|0)==0){X=1;aa=fa;U=ga;while(1){ia=U>>>24;ba=a[1369728+ia|0]|0;ja=ba&255;ea=((ba&255)>>>0>8>>>0?8:ja)+aa|0;da=Y>>>0>ea>>>0;ka=da?ea:Y;if(!(ba<<24>>24==9)){A=60;break}ba=d[1369984+ia|0]|X<<4;if(!(ba>>>0<134217728>>>0)){la=ba;break}ea=D+(ka>>>3)|0;O=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ka&7);if(da){X=ba;aa=ka;U=O}else{la=ba;break}}if((A|0)==60){la=d[1369984+ia|0]|X<<(ja-1>>1)}c[l>>2]=ka;ma=la+255&255}else{la=ga>>>24;ga=(d[1369728+la|0]|0)+fa|0;c[l>>2]=Y>>>0>ga>>>0?ga:Y;ma=a[1369216+la|0]|0}a[g+8|0]=ma;ha=ma}ma=g+8|0;if((ha&255)>>>0>2>>>0){KIb(e,16,2365808,(V=i,i=i+8|0,c[V>>2]=ha&255,V)|0);i=V;W=-1094995529;i=h;return W|0}ha=c[l>>2]|0;la=c[p>>2]|0;Y=d[la+(ha>>>3)|0]|0;ga=c[n>>2]|0;fa=((ha|0)<(ga|0))+ha|0;c[l>>2]=fa;if((Y&128>>>((ha&7)>>>0)|0)==0){na=a[g+9|0]|0}else{ha=la+(fa>>>3)|0;Y=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(fa&7);if((Y&-1434451968|0)==0){ha=1;ka=fa;ja=Y;while(1){oa=ja>>>24;X=a[1369728+oa|0]|0;pa=X&255;ia=((X&255)>>>0>8>>>0?8:pa)+ka|0;U=ga>>>0>ia>>>0;qa=U?ia:ga;if(!(X<<24>>24==9)){A=72;break}X=d[1369984+oa|0]|ha<<4;if(!(X>>>0<134217728>>>0)){ra=X;break}ia=la+(qa>>>3)|0;aa=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(qa&7);if(U){ha=X;ka=qa;ja=aa}else{ra=X;break}}if((A|0)==72){ra=d[1369984+oa|0]|ha<<(pa-1>>1)}c[l>>2]=qa;sa=ra+255&255}else{ra=Y>>>24;Y=(d[1369728+ra|0]|0)+fa|0;c[l>>2]=ga>>>0>Y>>>0?Y:ga;sa=a[1369216+ra|0]|0}a[g+9|0]=sa;na=sa}if((na&255)>>>0>1>>>0){W=-1094995529;i=h;return W|0}na=c[l>>2]|0;sa=c[p>>2]|0;ra=d[sa+(na>>>3)|0]|0;ga=c[n>>2]|0;Y=((na|0)<(ga|0))+na|0;c[l>>2]=Y;do{if((ra&128>>>((na&7)>>>0)|0)==0){ta=0;ua=0;va=g+11|0}else{fa=sa+(Y>>>3)|0;qa=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Y&7);if((qa&-1434451968|0)==0){fa=1;pa=Y;ha=qa;while(1){wa=ha>>>24;oa=a[1369728+wa|0]|0;xa=oa&255;ja=((oa&255)>>>0>8>>>0?8:xa)+pa|0;ka=ga>>>0>ja>>>0;ya=ka?ja:ga;if(!(oa<<24>>24==9)){A=83;break}oa=d[1369984+wa|0]|fa<<4;if(!(oa>>>0<134217728>>>0)){za=oa;break}ja=sa+(ya>>>3)|0;la=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ya&7);if(ka){fa=oa;pa=ya;ha=la}else{za=oa;break}}if((A|0)==83){za=d[1369984+wa|0]|fa<<(xa-1>>1)}c[l>>2]=ya;Aa=za-1|0}else{ha=qa>>>24;pa=(d[1369728+ha|0]|0)+Y|0;c[l>>2]=ga>>>0>pa>>>0?pa:ga;Aa=d[1369216+ha|0]|0}ha=Aa&255;pa=g+11|0;a[pa]=ha;if((Aa&255)>>>0>10>>>0){W=-1094995529;i=h;return W|0}if(!(ha<<24>>24==0)){ta=0;ua=0;va=pa;break}ha=c[l>>2]|0;oa=c[n>>2]|0;la=c[p>>2]|0;ka=la+(ha>>>3)|0;ja=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ha&7);if((ja&-1434451968|0)==0){ka=1;X=ha;aa=ja;while(1){Ba=aa>>>24;U=a[1369728+Ba|0]|0;Ca=U&255;ia=((U&255)>>>0>8>>>0?8:Ca)+X|0;D=oa>>>0>ia>>>0;Da=D?ia:oa;if(!(U<<24>>24==9)){A=92;break}U=d[1369984+Ba|0]|ka<<4;if(!(U>>>0<134217728>>>0)){Ea=U;break}ia=la+(Da>>>3)|0;ba=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(Da&7);if(D){ka=U;X=Da;aa=ba}else{Ea=U;break}}if((A|0)==92){Ea=d[1369984+Ba|0]|ka<<(Ca-1>>1)}c[l>>2]=Da;Fa=Ea-1|0;Ga=Da}else{aa=ja>>>24;X=(d[1369728+aa|0]|0)+ha|0;qa=oa>>>0>X>>>0?X:oa;c[l>>2]=qa;Fa=d[1369216+aa|0]|0;Ga=qa}qa=la+(Ga>>>3)|0;aa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Ga&7);if((aa&-1434451968|0)==0){Ha=1;Ia=Ga;Ja=aa}else{qa=aa>>>24;aa=(d[1369728+qa|0]|0)+Ga|0;c[l>>2]=oa>>>0>aa>>>0?aa:oa;ta=Fa;ua=d[1369216+qa|0]|0;va=pa;break}while(1){Ka=Ja>>>24;qa=a[1369728+Ka|0]|0;La=qa&255;aa=((qa&255)>>>0>8>>>0?8:La)+Ia|0;X=oa>>>0>aa>>>0;Ma=X?aa:oa;if(!(qa<<24>>24==9)){A=99;break}qa=d[1369984+Ka|0]|Ha<<4;if(!(qa>>>0<134217728>>>0)){Na=qa;break}aa=la+(Ma>>>3)|0;fa=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(Ma&7);if(X){Ha=qa;Ia=Ma;Ja=fa}else{Na=qa;break}}if((A|0)==99){Na=d[1369984+Ka|0]|Ha<<(La-1>>1)}c[l>>2]=Ma;ta=Fa;ua=Na-1|0;va=pa}}while(0);Na=a[va]|0;va=Na&255;do{if(Na<<24>>24==0){Oa=ta;Pa=ua}else{if((Na&255)>>>0<9>>>0){Oa=c[1347880+(va<<3)>>2]|0;Pa=c[1347884+(va<<3)>>2]|0;break}else{Fa=va-9|0;Oa=c[1533040+(Fa<<3)>>2]|0;Pa=c[1533044+(Fa<<3)>>2]|0;break}}}while(0);xKb(e+104|0,e+108|0,Pa,(Pa|0)<0|0?-1:0,Oa,(Oa|0)<0|0?-1:0,1073741824,0)|0;Oa=c[l>>2]|0;Pa=c[p>>2]|0;va=d[Pa+(Oa>>>3)|0]|0;Na=c[n>>2]|0;ua=((Oa|0)<(Na|0))+Oa|0;c[l>>2]=ua;do{if((va&128>>>((Oa&7)>>>0)|0)==0){Qa=g+12|0}else{ta=Pa+(ua>>>3)|0;Fa=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(ua&7);if((Fa&-1434451968|0)==0){ta=1;Ma=ua;La=Fa;while(1){Ra=La>>>24;Ha=a[1369728+Ra|0]|0;Sa=Ha&255;Ka=((Ha&255)>>>0>8>>>0?8:Sa)+Ma|0;Ja=Na>>>0>Ka>>>0;Ta=Ja?Ka:Na;if(!(Ha<<24>>24==9)){A=112;break}Ha=d[1369984+Ra|0]|ta<<4;if(!(Ha>>>0<134217728>>>0)){Ua=Ha;break}Ka=Pa+(Ta>>>3)|0;Ia=(je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ta&7);if(Ja){ta=Ha;Ma=Ta;La=Ia}else{Ua=Ha;break}}if((A|0)==112){Ua=d[1369984+Ra|0]|ta<<(Sa-1>>1)}c[l>>2]=Ta;Va=Ua-1|0}else{La=Fa>>>24;Ma=(d[1369728+La|0]|0)+ua|0;c[l>>2]=Na>>>0>Ma>>>0?Ma:Na;Va=d[1369216+La|0]|0}La=Va&255;Ma=g+12|0;a[Ma]=La;if((Va&255)>>>0>6>>>0){W=-1094995529;i=h;return W|0}if(!(La<<24>>24==0)){Qa=Ma;break}La=c[l>>2]|0;pa=c[n>>2]|0;Ha=c[p>>2]|0;Ia=Ha+(La>>>3)|0;Ja=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(La&7);if((Ja&-1434451968|0)==0){Ia=1;Ka=La;Ga=Ja;while(1){Wa=Ga>>>24;Da=a[1369728+Wa|0]|0;Xa=Da&255;Ea=((Da&255)>>>0>8>>>0?8:Xa)+Ka|0;Ca=pa>>>0>Ea>>>0;Ya=Ca?Ea:pa;if(!(Da<<24>>24==9)){A=121;break}Da=d[1369984+Wa|0]|Ia<<4;if(!(Da>>>0<134217728>>>0)){Za=Da;break}Ea=Ha+(Ya>>>3)|0;Ba=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ya&7);if(Ca){Ia=Da;Ka=Ya;Ga=Ba}else{Za=Da;break}}if((A|0)==121){Za=d[1369984+Wa|0]|Ia<<(Xa-1>>1)}c[l>>2]=Ya;_a=Za-1|0}else{Ga=Ja>>>24;Ka=(d[1369728+Ga|0]|0)+La|0;c[l>>2]=pa>>>0>Ka>>>0?Ka:pa;_a=d[1369216+Ga|0]|0}c[e+224>>2]=_a;Ga=c[l>>2]|0;Ka=c[n>>2]|0;Fa=Ha+(Ga>>>3)|0;ta=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ga&7);if((ta&-1434451968|0)==0){Fa=1;Da=Ga;Ba=ta;while(1){$a=Ba>>>24;Ca=a[1369728+$a|0]|0;ab=Ca&255;Ea=((Ca&255)>>>0>8>>>0?8:ab)+Da|0;Aa=Ka>>>0>Ea>>>0;bb=Aa?Ea:Ka;if(!(Ca<<24>>24==9)){A=128;break}Ca=d[1369984+$a|0]|Fa<<4;if(!(Ca>>>0<134217728>>>0)){cb=Ca;break}Ea=Ha+(bb>>>3)|0;ga=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(bb&7);if(Aa){Fa=Ca;Da=bb;Ba=ga}else{cb=Ca;break}}if((A|0)==128){cb=d[1369984+$a|0]|Fa<<(ab-1>>1)}c[l>>2]=bb;db=cb-1|0}else{Ba=ta>>>24;Da=(d[1369728+Ba|0]|0)+Ga|0;c[l>>2]=Ka>>>0>Da>>>0?Da:Ka;db=d[1369216+Ba|0]|0}c[e+228>>2]=db;Qa=Ma}}while(0);db=a[Qa]|0;if(!(db<<24>>24==0)){Qa=1532968+((db&255)-1<<3)|0;db=e+224|0;cb=c[Qa+4>>2]|0;c[db>>2]=c[Qa>>2];c[db+4>>2]=cb}cb=c[l>>2]|0;db=c[p>>2]|0;Qa=d[db+(cb>>>3)|0]|0;bb=c[n>>2]|0;ab=((cb|0)<(bb|0))+cb|0;c[l>>2]=ab;if((Qa&128>>>((cb&7)>>>0)|0)==0){eb=ab}else{cb=db+(ab>>>3)|0;Qa=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(ab&7);if((Qa&-1434451968|0)==0){cb=1;$a=ab;_a=Qa;while(1){fb=_a>>>24;Za=a[1369728+fb|0]|0;gb=Za&255;Ya=((Za&255)>>>0>8>>>0?8:gb)+$a|0;Xa=bb>>>0>Ya>>>0;hb=Xa?Ya:bb;if(!(Za<<24>>24==9)){A=139;break}Za=d[1369984+fb|0]|cb<<4;if(!(Za>>>0<134217728>>>0)){ib=Za;break}Ya=db+(hb>>>3)|0;Wa=(je(d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0)|0)<<(hb&7);if(Xa){cb=Za;$a=hb;_a=Wa}else{ib=Za;break}}if((A|0)==139){ib=d[1369984+fb|0]|cb<<(gb-1>>1)}c[l>>2]=hb;jb=ib+65535&65535;kb=hb}else{hb=Qa>>>24;Qa=(d[1369728+hb|0]|0)+ab|0;ab=bb>>>0>Qa>>>0?Qa:bb;c[l>>2]=ab;jb=d[1369216+hb|0]|0;kb=ab}b[g+14>>1]=jb;jb=db+(kb>>>3)|0;ab=(je(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(kb&7);if((ab&-1434451968|0)==0){jb=1;hb=kb;Qa=ab;while(1){lb=Qa>>>24;ib=a[1369728+lb|0]|0;mb=ib&255;gb=((ib&255)>>>0>8>>>0?8:mb)+hb|0;cb=bb>>>0>gb>>>0;nb=cb?gb:bb;if(!(ib<<24>>24==9)){A=146;break}ib=d[1369984+lb|0]|jb<<4;if(!(ib>>>0<134217728>>>0)){ob=ib;break}gb=db+(nb>>>3)|0;fb=(je(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(nb&7);if(cb){jb=ib;hb=nb;Qa=fb}else{ob=ib;break}}if((A|0)==146){ob=d[1369984+lb|0]|jb<<(mb-1>>1)}c[l>>2]=nb;pb=ob+65535&65535;qb=nb}else{nb=ab>>>24;ab=(d[1369728+nb|0]|0)+kb|0;kb=bb>>>0>ab>>>0?ab:bb;c[l>>2]=kb;pb=d[1369216+nb|0]|0;qb=kb}b[g+16>>1]=pb;pb=db+(qb>>>3)|0;kb=(je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(qb&7);if((kb&-1434451968|0)==0){pb=1;nb=qb;ab=kb;while(1){rb=ab>>>24;ob=a[1369728+rb|0]|0;sb=ob&255;mb=((ob&255)>>>0>8>>>0?8:sb)+nb|0;jb=bb>>>0>mb>>>0;tb=jb?mb:bb;if(!(ob<<24>>24==9)){A=153;break}ob=d[1369984+rb|0]|pb<<4;if(!(ob>>>0<134217728>>>0)){ub=ob;break}mb=db+(tb>>>3)|0;lb=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(tb&7);if(jb){pb=ob;nb=tb;ab=lb}else{ub=ob;break}}if((A|0)==153){ub=d[1369984+rb|0]|pb<<(sb-1>>1)}c[l>>2]=tb;vb=ub+65535&65535;wb=tb}else{tb=kb>>>24;kb=(d[1369728+tb|0]|0)+qb|0;qb=bb>>>0>kb>>>0?kb:bb;c[l>>2]=qb;vb=d[1369216+tb|0]|0;wb=qb}b[g+18>>1]=vb;vb=db+(wb>>>3)|0;qb=(je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(wb&7);if((qb&-1434451968|0)==0){vb=1;tb=wb;kb=qb;while(1){xb=kb>>>24;ub=a[1369728+xb|0]|0;yb=ub&255;sb=((ub&255)>>>0>8>>>0?8:yb)+tb|0;pb=bb>>>0>sb>>>0;zb=pb?sb:bb;if(!(ub<<24>>24==9)){A=160;break}ub=d[1369984+xb|0]|vb<<4;if(!(ub>>>0<134217728>>>0)){Ab=ub;break}sb=db+(zb>>>3)|0;rb=(je(d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)|0)<<(zb&7);if(pb){vb=ub;tb=zb;kb=rb}else{Ab=ub;break}}if((A|0)==160){Ab=d[1369984+xb|0]|vb<<(yb-1>>1)}c[l>>2]=zb;Bb=Ab+65535&65535;Cb=zb}else{zb=qb>>>24;qb=(d[1369728+zb|0]|0)+wb|0;wb=bb>>>0>qb>>>0?qb:bb;c[l>>2]=wb;Bb=d[1369216+zb|0]|0;Cb=wb}b[g+20>>1]=Bb;eb=Cb}Cb=d[db+(eb>>>3)|0]|0;Bb=((eb|0)<(bb|0))+eb|0;c[l>>2]=Bb;do{if((Cb&128>>>((eb&7)>>>0)|0)==0){Db=16;Eb=8;Fb=g+22|0}else{wb=db+(Bb>>>3)|0;zb=(je(d[wb]|d[wb+1|0]<<8|d[wb+2|0]<<16|d[wb+3|0]<<24|0)|0)<<(Bb&7);if((zb&-1434451968|0)==0){wb=1;qb=Bb;Ab=zb;while(1){Gb=Ab>>>24;yb=a[1369728+Gb|0]|0;Hb=yb&255;vb=((yb&255)>>>0>8>>>0?8:Hb)+qb|0;xb=bb>>>0>vb>>>0;Ib=xb?vb:bb;if(!(yb<<24>>24==9)){A=170;break}yb=d[1369984+Gb|0]|wb<<4;if(!(yb>>>0<134217728>>>0)){Jb=yb;break}vb=db+(Ib>>>3)|0;kb=(je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(Ib&7);if(xb){wb=yb;qb=Ib;Ab=kb}else{Jb=yb;break}}if((A|0)==170){Jb=d[1369984+Gb|0]|wb<<(Hb-1>>1)}c[l>>2]=Ib;Kb=Jb-1|0}else{Ab=zb>>>24;qb=(d[1369728+Ab|0]|0)+Bb|0;c[l>>2]=bb>>>0>qb>>>0?qb:bb;Kb=d[1369216+Ab|0]|0}Ab=Kb&255;qb=g+22|0;a[qb]=Ab;if((Kb&255)>>>0>4>>>0){W=-1094995529;i=h;return W|0}if(!(Ab<<24>>24==0)){Db=16;Eb=8;Fb=qb;break}Ab=c[l>>2]|0;Ma=c[n>>2]|0;Ka=c[p>>2]|0;Ga=Ka+(Ab>>>3)|0;ta=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ab&7);if((ta&-1434451968|0)==0){Ga=1;Fa=Ab;yb=ta;while(1){Lb=yb>>>24;kb=a[1369728+Lb|0]|0;Mb=kb&255;xb=((kb&255)>>>0>8>>>0?8:Mb)+Fa|0;vb=Ma>>>0>xb>>>0;Nb=vb?xb:Ma;if(!(kb<<24>>24==9)){A=179;break}kb=d[1369984+Lb|0]|Ga<<4;if(!(kb>>>0<134217728>>>0)){Ob=kb;break}xb=Ka+(Nb>>>3)|0;tb=(je(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(Nb&7);if(vb){Ga=kb;Fa=Nb;yb=tb}else{Ob=kb;break}}if((A|0)==179){Ob=d[1369984+Lb|0]|Ga<<(Mb-1>>1)}c[l>>2]=Nb;Pb=Ob-1|0;Qb=Nb}else{yb=ta>>>24;Fa=(d[1369728+yb|0]|0)+Ab|0;zb=Ma>>>0>Fa>>>0?Fa:Ma;c[l>>2]=zb;Pb=d[1369216+yb|0]|0;Qb=zb}zb=Ka+(Qb>>>3)|0;yb=(je(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)|0)<<(Qb&7);if((yb&-1434451968|0)==0){zb=1;Fa=Qb;wb=yb;while(1){Rb=wb>>>24;kb=a[1369728+Rb|0]|0;Sb=kb&255;tb=((kb&255)>>>0>8>>>0?8:Sb)+Fa|0;vb=Ma>>>0>tb>>>0;Tb=vb?tb:Ma;if(!(kb<<24>>24==9)){A=186;break}kb=d[1369984+Rb|0]|zb<<4;if(!(kb>>>0<134217728>>>0)){Ub=kb;break}tb=Ka+(Tb>>>3)|0;xb=(je(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(Tb&7);if(vb){zb=kb;Fa=Tb;wb=xb}else{Ub=kb;break}}if((A|0)==186){Ub=d[1369984+Rb|0]|zb<<(Sb-1>>1)}c[l>>2]=Tb;Vb=Ub-1|0;Wb=Tb}else{wb=yb>>>24;Fa=(d[1369728+wb|0]|0)+Qb|0;Ab=Ma>>>0>Fa>>>0?Fa:Ma;c[l>>2]=Ab;Vb=d[1369216+wb|0]|0;Wb=Ab}Ab=Vb>>>0>65535>>>0;wb=Ab?Vb>>>16:Vb;Fa=Ab?16:0;if((wb&65280|0)==0){Xb=Fa;Yb=wb}else{Xb=Fa|8;Yb=wb>>>8}wb=Xb+1+(d[1359664+Yb|0]|0)|0;Fa=Ka+(Wb>>>3)|0;Ab=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Wb&7);b:do{if((Ab&-1434451968|0)==0){Fa=1;ta=Wb;Ga=Ab;while(1){kb=Ga>>>24;xb=a[1369728+kb|0]|0;vb=((xb&255)>>>0>8>>>0?8:xb&255)+ta|0;tb=Ma>>>0>vb>>>0;ub=tb?vb:Ma;if(!(xb<<24>>24==9)){Zb=ub;break b}xb=d[1369984+kb|0]|Fa<<4;if(!(xb>>>0<134217728>>>0)){Zb=ub;break b}kb=Ka+(ub>>>3)|0;vb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(ub&7);if(tb){Fa=xb;ta=ub;Ga=vb}else{Zb=ub;break}}}else{Ga=(d[1369728+(Ab>>>24)|0]|0)+Wb|0;Zb=Ma>>>0>Ga>>>0?Ga:Ma}}while(0);c[l>>2]=Zb;Ab=Ka+(Zb>>>3)|0;yb=(je(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(Zb&7);c:do{if((yb&-1434451968|0)==0){Ab=1;zb=Zb;Ga=yb;while(1){ta=Ga>>>24;Fa=a[1369728+ta|0]|0;ub=((Fa&255)>>>0>8>>>0?8:Fa&255)+zb|0;vb=Ma>>>0>ub>>>0;xb=vb?ub:Ma;if(!(Fa<<24>>24==9)){_b=xb;break c}Fa=d[1369984+ta|0]|Ab<<4;if(!(Fa>>>0<134217728>>>0)){_b=xb;break c}ta=Ka+(xb>>>3)|0;ub=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(xb&7);if(vb){Ab=Fa;zb=xb;Ga=ub}else{_b=xb;break}}}else{Ga=(d[1369728+(yb>>>24)|0]|0)+Zb|0;_b=Ma>>>0>Ga>>>0?Ga:Ma}}while(0);c[l>>2]=_b;c[e+396>>2]=(Pb|0)!=0?1:2;Db=Pb;Eb=wb;Fb=qb}}while(0);Pb=a[Fb]|0;if(Pb<<24>>24==0){$b=Eb}else{Eb=(Pb&255)-1|0;Pb=d[728896+(Eb<<3)|0]|0;c[e+396>>2]=c[728900+(Eb<<3)>>2];$b=Pb}if($b>>>0>8>>>0){KIb(e,24,2300448,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}$b=c[1533016+(((Db|0)==0|0)*12|0)+(d[ma]<<2)>>2]|0;c[e+140>>2]=$b;vLa($b,j,k);$b=g|0;do{if(((1<<c[j>>2])-1&c[$b>>2]|0)==0){ma=g+4|0;if(((1<<c[k>>2])-1&c[ma>>2]|0)!=0){break}Db=c[l>>2]|0;Pb=c[p>>2]|0;Eb=d[Pb+(Db>>>3)|0]|0;Fb=c[n>>2]|0;_b=((Db|0)<(Fb|0))+Db|0;c[l>>2]=_b;do{if((Eb&128>>>((Db&7)>>>0)|0)==0){Zb=d[g+23|0]|0;c[e+384>>2]=c[1533104+(Zb*12|0)>>2];c[e+392>>2]=c[1533108+(Zb*12|0)>>2];c[e+388>>2]=c[1533112+(Zb*12|0)>>2]}else{Zb=Pb+(_b>>>3)|0;Wb=(je(d[Zb]|d[Zb+1|0]<<8|d[Zb+2|0]<<16|d[Zb+3|0]<<24|0)|0)<<(_b&7);if((Wb&-1434451968|0)==0){Zb=1;Yb=_b;Xb=Wb;while(1){ac=Xb>>>24;Vb=a[1369728+ac|0]|0;bc=Vb&255;Qb=((Vb&255)>>>0>8>>>0?8:bc)+Yb|0;Tb=Fb>>>0>Qb>>>0;cc=Tb?Qb:Fb;if(!(Vb<<24>>24==9)){A=214;break}Vb=d[1369984+ac|0]|Zb<<4;if(!(Vb>>>0<134217728>>>0)){dc=Vb;break}Qb=Pb+(cc>>>3)|0;Ub=(je(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(cc&7);if(Tb){Zb=Vb;Yb=cc;Xb=Ub}else{dc=Vb;break}}if((A|0)==214){dc=d[1369984+ac|0]|Zb<<(bc-1>>1)}c[l>>2]=cc;ec=dc-1|0}else{Xb=Wb>>>24;Yb=(d[1369728+Xb|0]|0)+_b|0;c[l>>2]=Fb>>>0>Yb>>>0?Yb:Fb;ec=d[1369216+Xb|0]|0}Xb=g+23|0;a[Xb]=ec;Yb=ec&255;if(Yb>>>0>4>>>0){W=-1094995529;i=h;return W|0}Vb=e+384|0;c[Vb>>2]=c[1533104+(Yb*12|0)>>2];Ub=e+392|0;c[Ub>>2]=c[1533108+(Yb*12|0)>>2];Tb=e+388|0;c[Tb>>2]=c[1533112+(Yb*12|0)>>2];if((a[Xb]|0)!=0){break}Xb=c[l>>2]|0;Yb=c[p>>2]|0;Qb=d[Yb+(Xb>>>3)|0]|0;Sb=c[n>>2]|0;Rb=((Xb|0)<(Sb|0))+Xb|0;c[l>>2]=Rb;do{if((Qb&128>>>((Xb&7)>>>0)|0)==0){fc=Rb}else{Nb=Yb+(Rb>>>3)|0;Ob=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Rb&7);if((Ob&-1434451968|0)==0){Nb=1;Mb=Rb;Lb=Ob;while(1){gc=Lb>>>24;Kb=a[1369728+gc|0]|0;hc=Kb&255;bb=((Kb&255)>>>0>8>>>0?8:hc)+Mb|0;Bb=Sb>>>0>bb>>>0;ic=Bb?bb:Sb;if(!(Kb<<24>>24==9)){A=224;break}Kb=d[1369984+gc|0]|Nb<<4;if(!(Kb>>>0<134217728>>>0)){jc=Kb;break}bb=Yb+(ic>>>3)|0;Jb=(je(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(ic&7);if(Bb){Nb=Kb;Mb=ic;Lb=Jb}else{jc=Kb;break}}if((A|0)==224){jc=d[1369984+gc|0]|Nb<<(hc-1>>1)}c[l>>2]=ic;kc=jc-1|0;lc=ic}else{Lb=Ob>>>24;Mb=(d[1369728+Lb|0]|0)+Rb|0;Kb=Sb>>>0>Mb>>>0?Mb:Sb;c[l>>2]=Kb;kc=d[1369216+Lb|0]|0;lc=Kb}if(!(kc>>>0<3>>>0)){fc=lc;break}c[Vb>>2]=c[1532952+(kc<<2)>>2];fc=lc}}while(0);Vb=d[Yb+(fc>>>3)|0]|0;Rb=((fc|0)<(Sb|0))+fc|0;c[l>>2]=Rb;do{if((Vb&128>>>((fc&7)>>>0)|0)==0){mc=Rb}else{Xb=Yb+(Rb>>>3)|0;Qb=(je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Rb&7);if((Qb&-1434451968|0)==0){Xb=1;Wb=Rb;Zb=Qb;while(1){nc=Zb>>>24;Kb=a[1369728+nc|0]|0;oc=Kb&255;Lb=((Kb&255)>>>0>8>>>0?8:oc)+Wb|0;Mb=Sb>>>0>Lb>>>0;pc=Mb?Lb:Sb;if(!(Kb<<24>>24==9)){A=234;break}Kb=d[1369984+nc|0]|Xb<<4;if(!(Kb>>>0<134217728>>>0)){qc=Kb;break}Lb=Yb+(pc>>>3)|0;Jb=(je(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(pc&7);if(Mb){Xb=Kb;Wb=pc;Zb=Jb}else{qc=Kb;break}}if((A|0)==234){qc=d[1369984+nc|0]|Xb<<(oc-1>>1)}c[l>>2]=pc;rc=qc-1|0;sc=pc}else{Zb=Qb>>>24;Wb=(d[1369728+Zb|0]|0)+Rb|0;Ob=Sb>>>0>Wb>>>0?Wb:Sb;c[l>>2]=Ob;rc=d[1369216+Zb|0]|0;sc=Ob}if((rc|0)==0){c[Ub>>2]=1;mc=sc;break}else if((rc|0)==1){c[Ub>>2]=5;mc=sc;break}else{mc=sc;break}}}while(0);Ub=d[Yb+(mc>>>3)|0]|0;Rb=((mc|0)<(Sb|0))+mc|0;c[l>>2]=Rb;if((Ub&128>>>((mc&7)>>>0)|0)==0){break}Ub=Yb+(Rb>>>3)|0;Vb=(je(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Rb&7);if((Vb&-1434451968|0)==0){Ub=1;Ob=Rb;Zb=Vb;while(1){tc=Zb>>>24;Wb=a[1369728+tc|0]|0;uc=Wb&255;Nb=((Wb&255)>>>0>8>>>0?8:uc)+Ob|0;Kb=Sb>>>0>Nb>>>0;vc=Kb?Nb:Sb;if(!(Wb<<24>>24==9)){A=245;break}Wb=d[1369984+tc|0]|Ub<<4;if(!(Wb>>>0<134217728>>>0)){wc=Wb;break}Nb=Yb+(vc>>>3)|0;Jb=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(vc&7);if(Kb){Ub=Wb;Ob=vc;Zb=Jb}else{wc=Wb;break}}if((A|0)==245){wc=d[1369984+tc|0]|Ub<<(uc-1>>1)}c[l>>2]=vc;xc=wc-1|0}else{Zb=Vb>>>24;Ob=(d[1369728+Zb|0]|0)+Rb|0;c[l>>2]=Sb>>>0>Ob>>>0?Ob:Sb;xc=d[1369216+Zb|0]|0}if((xc|0)!=0){break}c[Tb>>2]=1}}while(0);Fb=H4a(e,c[$b>>2]|0,c[ma>>2]|0)|0;if((Fb|0)<0){W=Fb;i=h;return W|0}Fb=c[l>>2]|0;_b=c[n>>2]|0;Pb=c[p>>2]|0;Db=Pb+(Fb>>>3)|0;Eb=(je(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)|0)<<(Fb&7);if((Eb&-1434451968|0)==0){Db=1;qb=Fb;wb=Eb;while(1){yc=wb>>>24;Zb=a[1369728+yc|0]|0;zc=Zb&255;Ob=((Zb&255)>>>0>8>>>0?8:zc)+qb|0;Yb=_b>>>0>Ob>>>0;Ac=Yb?Ob:_b;if(!(Zb<<24>>24==9)){A=256;break}Zb=d[1369984+yc|0]|Db<<4;if(!(Zb>>>0<134217728>>>0)){Bc=Zb;break}Ob=Pb+(Ac>>>3)|0;Wb=(je(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Ac&7);if(Yb){Db=Zb;qb=Ac;wb=Wb}else{Bc=Zb;break}}if((A|0)==256){Bc=d[1369984+yc|0]|Db<<(zc-1>>1)}c[l>>2]=Ac;Cc=Bc-1|0}else{wb=Eb>>>24;qb=(d[1369728+wb|0]|0)+Fb|0;c[l>>2]=_b>>>0>qb>>>0?qb:_b;Cc=d[1369216+wb|0]|0}if((Cc|0)==0){W=0;i=h;return W|0}KIb(e,16,2455256,(V=i,i=i+8|0,c[V>>2]=Cc,V)|0);i=V;W=-1094995529;i=h;return W|0}}while(0);KIb(e,16,2249240,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V;W=-1094995529;i=h;return W|0}function A5(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;j=b|0;k=c[j>>2]|0;c[f>>2]=0;c[g>>2]=0;a:do{if((c[b+176>>2]&1|0)==0){l=k;m=c[l>>2]|0;n=k+4|0;o=c[n>>2]|0;b:do{if((o|0)==0){p=0;q=m;while(1){if((p|0)>=(i|0)){r=q;s=0;t=14;break b}u=d[h+p|0]|q<<8;if((u|0)==1111638852){break}else{p=p+1|0;q=u}}c[n>>2]=1;c[k+12>>2]=9;q=k+8|0;c[q>>2]=p;v=-1;w=p;x=1;y=q;t=8}else{v=m;w=0;x=o;y=k+8|0;t=8}}while(0);c:do{if((t|0)==8){c[y>>2]=0;if((w|0)<(i|0)){z=v;A=w}else{r=v;s=x;t=14;break}while(1){if((z|0)==1111638852){break}o=d[h+A|0]|z<<8;m=A+1|0;if((m|0)<(i|0)){z=o;A=m}else{r=o;s=x;t=14;break c}}p=i-A|0;o=k+12|0;m=c[o>>2]|0;if((p|0)<(m|0)){c[o>>2]=9-p;r=1111638852;s=x;t=14;break}else{c[l>>2]=-1;B=m+A|0;C=x;break}}}while(0);if((t|0)==14){c[l>>2]=r;B=-1;C=s}m=(B|0)==-1;if((C|0)==0&m){D=i;return D|0}p=b+40|0;if((c[p>>2]|0)==0&(c[p+4>>2]|0)==(-2147483648|0)){o=b+48|0;E=(c[o>>2]|0)==0&(c[o+4>>2]|0)==(-2147483648|0)}else{E=0}o=c[j>>2]|0;n=o+16|0;q=c[n>>2]|0;do{if((q|0)==0){F=c[o+24>>2]|0;H=o+28|0}else{u=o+28|0;I=c[u>>2]|0;J=o+24|0;nrc(I|0,I+q|0,(c[J>>2]|0)-q|0)|0;I=(c[J>>2]|0)-(c[n>>2]|0)|0;c[J>>2]=I;c[n>>2]=0;if((i|0)!=0){F=I;H=u;break}J=c[u>>2]|0;if((a[J+4|0]|0)==16){K=B;L=I;M=J;break a}else{F=I;H=u}}}while(0);q=c[H>>2]|0;l=o+20|0;u=o+24|0;if(m){I=o+8|0;J=wJb(q,l,F+i-(c[I>>2]|0)|0)|0;c[H>>2]=J;N=c[I>>2]|0;nrc(J+(c[u>>2]|0)|0,h+N|0,i-N|0)|0;c[u>>2]=i-(c[I>>2]|0)+(c[u>>2]|0);D=i;return D|0}I=wJb(q,l,F+B|0)|0;c[H>>2]=I;nrc(I+(c[u>>2]|0)|0,h|0,B)|0;I=(c[u>>2]|0)+B|0;c[u>>2]=I;l=c[H>>2]|0;do{if((I-13|0)>=0){q=l+(I-4)|0;N=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;q=-13-N+I|0;if((q|0)<0){break}J=q+13|0;if((J|0)>(I|0)){break}O=l+(q+4)|0;P=a[O]|0;Q=l+(q+5)|0;R=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=je(R|0)|0;if(((P<<24>>24==16&(R|0)==0?13:Q)|0)!=(N|0)){break}Q=(I|0)<0|0?-1:0;R=o+32|0;S=c[R>>2]|0;T=wrc(N,(N|0)<0|0?-1:0,13,0)|0;U=wrc(T,G,S,(S|0)<0|0?-1:0)|0;T=G;if((Q|0)<(T|0)|(Q|0)==(T|0)&I>>>0<U>>>0){break}U=l+(q-S)|0;c[o+36>>2]=U;c[R>>2]=S+N;if((P&8)==0){c[o+12>>2]=9;D=B;return D|0}do{if(E){P=l+J|0;N=je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=b+56|0;S=b+64|0;q=c[S>>2]|0;T=c[S+4>>2]|0;if((q|c[P>>2]|0)==0&(T|c[P+4>>2]|0)==0){P=N-1|0;S=P;Q=(P|0)<0|0?-1:0;P=b+48|0;c[P>>2]=S;c[P+4>>2]=Q;V=Q;W=S}else{S=wrc(q,T,1,0)|0;T=G;q=b+48|0;c[q>>2]=S;c[q+4>>2]=T;V=T;W=S}S=N;T=(N|0)<0|0?-1:0;c[p>>2]=S;c[p+4>>2]=T;N=e+176|0;if((c[N>>2]|0)!=0){X=T;Y=S;Z=V;_=W;t=41;break}if((a[O]&3)==0){break}c[N>>2]=1;X=T;Y=S;Z=V;_=W;t=41}else{if((c[e+176>>2]|0)==0){break}S=b+48|0;X=c[p+4>>2]|0;Y=c[p>>2]|0;Z=c[S+4>>2]|0;_=c[S>>2]|0;t=41}}while(0);do{if((t|0)==41){if(!((Y|0)==(_|0)&(X|0)==(Z|0))){break}c[b+32>>2]=3}}while(0);O=c[R>>2]|0;c[R>>2]=0;c[n>>2]=(c[u>>2]|0)-13;c[o+12>>2]=9;if((B|0)<0){D=O}else{K=B;L=O;M=U;break a}return D|0}}while(0);c[u>>2]=I-9;c[o+12>>2]=9;D=B-9|0;return D|0}else{c[f>>2]=h;c[g>>2]=i;K=i;L=i;M=h}}while(0);c[f>>2]=M;c[g>>2]=L;D=K;return D|0}function B5(a){a=a|0;var b=0;b=c[a>>2]|0;if((c[b+20>>2]|0)<=0){return}kJb(c[b+28>>2]|0);return}function C5(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+1444>>2]=-1;l8(b+4|0,a);P5(b+1248|0);a=b+7444|0;b=0;while(1){if((b|0)>=14){d=0;e=6;break}f=UHb()|0;c[a+(b*112|0)>>2]=f;if((f|0)==0){break}else{b=b+1|0}}if((e|0)==6){return d|0}if((b|0)>0){g=b}else{d=-12;return d|0}while(1){b=g-1|0;VHb(a+(b*112|0)|0);if((b|0)>0){g=b}else{d=-12;break}}return d|0}function D5(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0;k=i;i=i+440|0;l=k|0;m=k+8|0;n=k+16|0;o=k+80|0;p=k+424|0;q=f+60|0;r=c[q>>2]|0;s=r;t=c[j+24>>2]|0;u=c[j+28>>2]|0;j=r+7444|0;v=0;do{w=c[j+(v*112|0)>>2]|0;do{if((c[w>>2]|0)!=0){if((c[w+172>>2]|0)!=0){break}WHb(w);mrc(j+(v*112|0)+4|0,0,12)|0}}while(0);v=v+1|0;}while((v|0)<14);v=g;j=r+7372|0;c[j>>2]=0;c[h>>2]=0;if((u|0)==0){w=c[r+7420>>2]|0;x=c[r+7424>>2]|0;if((x|0)==0){y=w;z=0;A=w}else{B=w;w=1;C=0;D=x;do{x=(c[(c[D>>2]|0)+164>>2]|0)<(c[(c[B>>2]|0)+164>>2]|0);B=x?D:B;C=x?w:C;w=w+1|0;D=c[s+7420+(w<<2)>>2]|0;}while((D|0)!=0);y=B;z=C;A=c[s+7420+(C<<2)>>2]|0}if((A|0)!=0){A=z;C=s+7420+(z<<2)|0;while(1){z=A+1|0;B=s+7420+(z<<2)|0;c[C>>2]=c[B>>2];if((c[B>>2]|0)==0){break}else{A=z;C=B}}}do{if((y|0)!=0){C=c[y>>2]|0;A=C+172|0;c[A>>2]=c[A>>2]^4;c[h>>2]=1;A=YHb(v,C)|0;if((A|0)<0){E=A}else{break}i=k;return E|0}}while(0);E=0;i=k;return E|0}a:do{if((u|0)>13){y=f+140|0;A=f+120|0;C=f+124|0;s=n;B=p|0;z=p+4|0;D=p+8|0;w=r;x=0;b:while(1){F=x+1|0;do{if((a[t+x|0]|0)==66){if((a[t+F|0]|0)!=66){G=F;break}if((a[t+(x+2)|0]|0)!=67){G=F;break}if((a[t+(x+3)|0]|0)!=68){G=F;break}H=t+(x+5)|0;I=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=je(I|0)|0;J=H+x|0;if(!((J|0)<=(u|0)&(I|0)!=0)){if((J|0)>(u|0)){KIb(c[w>>2]|0,16,2455152,(K=i,i=i+8|0,c[K>>2]=H,K)|0);i=K}G=x+4|0;break}I=c[q>>2]|0;L=I;M=a[t+(x+4)|0]|0;N=M&255;if((H|0)<13){break b}O=I+1396|0;P=O;Q=t+(x+13)|0;R=(H<<3)-104|0;H=R>>>0>2147483639>>>0|(Q|0)==0;S=H?0:Q;T=H?0:R;R=O;c[R>>2]=S;O=I+1408|0;c[O>>2]=T;H=I+1412|0;c[H>>2]=T+8;c[I+1400>>2]=S+(T>>3);T=I+1404|0;c[T>>2]=0;if((M<<24>>24|0)==0){S=I+1440|0;if((c[S>>2]|0)!=0){G=J;break}U=I+1416|0;if((z5(f,P,U)|0)!=0){break b}P=I+3980|0;V=I+3984|0;vLa(c[y>>2]|0,P,V);W=U;U=((c[W>>2]|0)+3|0)>>>2;X=I+1420|0;Y=((c[X>>2]|0)+3|0)>>>2;Z=0;while(1){if((Z|0)>=3){break}if((Z|0)==0){_=0;$=32;aa=32;ba=c[W>>2]|0}else{da=c[P>>2]|0;ea=c[V>>2]|0;_=ea;$=32>>>(ea>>>0);aa=32>>>(da>>>0);ba=(c[W>>2]|0)>>>(da>>>0)}da=($|0)/2|0;ea=($|0)<64?32:da;fa=(ba+31&-32|8)-1&-8;ga=L+1448+(Z*844|0)+28|0;c[ga>>2]=pJb(ca(fa+aa<<1,ea+da+(((c[X>>2]|0)>>>(_>>>0))+31&-32)|0)|0)|0;da=hJb((fa<<1)+32|0)|0;c[L+1448+(Z*844|0)+32>>2]=da;ha=c[ga>>2]|0;c[L+1448+(Z*844|0)+24>>2]=ha+((ca(ea,fa)|0)<<1);if((ha|0)==0){break b}if((da|0)==0){break b}else{Z=Z+1|0}}Z=c[W>>2]|0;V=c[X>>2]|0;P=ca(Y,U)|0;da=I+4216|0;c[da>>2]=hJb(P)|0;ha=I+4220|0;c[ha>>2]=hJb(P*160|0)|0;P=(Z<<5)+2048|0;c[I+4240>>2]=hJb(P)|0;fa=I+4244|0;c[fa>>2]=hJb(ca((Z<<1)+192|0,V+32|0)|0)|0;V=hJb(P)|0;c[I+4248>>2]=V;if((c[da>>2]|0)==0){break b}if((c[ha>>2]|0)==0){break b}if(!((V|0)!=0&(c[fa>>2]|0)!=0)){break b}c[S>>2]=1;G=J;break}else if((M<<24>>24|0)==32){if((a[Q]|0)!=1){G=J;break}fa=Bd(t+(x+14)|0,2249184,(K=i,i=i+24|0,c[K>>2]=B,c[K+8>>2]=z,c[K+16>>2]=D,K)|0)|0;i=K;if(!((fa|0)==3&(c[B>>2]|0)==1&(c[z>>2]|0)==0)){G=J;break}if((c[D>>2]|0)>=8){G=J;break}c[I+4016>>2]=1;G=J;break}else if((M<<24>>24|0)==16){G5(L);c[I+1440>>2]=0;G=J;break}else{if((N&8|0)==0){G=J;break}if((c[I+1440>>2]|0)==0){ia=50;break b}fa=I+7444|0;V=I+7556|0;ha=I+7668|0;da=I+7780|0;P=I+7892|0;Z=I+8004|0;ea=I+8116|0;ga=I+8228|0;ja=I+8340|0;ka=I+8452|0;la=I+8564|0;ma=I+8676|0;na=I+8788|0;oa=I+8900|0;pa=(c[c[oa>>2]>>2]|0)==0?oa:(c[c[na>>2]>>2]|0)==0?na:(c[c[ma>>2]>>2]|0)==0?ma:(c[c[la>>2]>>2]|0)==0?la:(c[c[ka>>2]>>2]|0)==0?ka:(c[c[ja>>2]>>2]|0)==0?ja:(c[c[ga>>2]>>2]|0)==0?ga:(c[c[ea>>2]>>2]|0)==0?ea:(c[c[Z>>2]>>2]|0)==0?Z:(c[c[P>>2]>>2]|0)==0?P:(c[c[da>>2]>>2]|0)==0?da:(c[c[ha>>2]>>2]|0)==0?ha:(c[c[V>>2]>>2]|0)==0?V:(c[c[fa>>2]>>2]|0)==0?fa:0;if((pa|0)==0){ia=51;break b}fa=pa|0;WHb(c[fa>>2]|0);V=N&3;if((V|0)==3){ia=53;break b}ha=I+4004|0;c[ha>>2]=V;V=I+3992|0;c[V>>2]=(N&72|0)==8;da=I+3996|0;c[da>>2]=(N&136|0)==136;P=(N&12|0)==12|0;Z=c[fa>>2]|0;c[Z+172>>2]=P;c[Z+84>>2]=(c[ha>>2]|0)==0;c[Z+88>>2]=(c[ha>>2]|0)+1;vLa(c[y>>2]|0,l,m);ea=Z+68|0;c[ea>>2]=(c[A>>2]|0)+32;ga=Z+72|0;c[ga>>2]=(c[C>>2]|0)+34;if((M4a(f,Z,P)|0)<0){break b}P=Z|0;ja=c[P>>2]|0;if((ja|0)!=0){ka=16>>>((c[m>>2]|0)>>>0);la=0;ma=P;P=ja;do{c[ma>>2]=P+((ca((la|0)!=0&(la|0)<3?ka:16,c[Z+32+(la<<2)>>2]|0)|0)+32);la=la+1|0;ma=Z+(la<<2)|0;P=c[ma>>2]|0;}while((P|0)!=0)}c[ea>>2]=c[A>>2];c[ga>>2]=c[C>>2];P=I+7372|0;c[P>>2]=pa;ma=c[fa>>2]|0;c[I+1456>>2]=c[ma+32>>2];c[I+2300>>2]=c[ma+36>>2];c[I+3144>>2]=c[ma+40>>2];if((H5(L)|0)!=0){break b}do{if((c[da>>2]|0)==0){qa=I+3988|0}else{mrc(c[I+1472>>2]|0,0,ca(c[I+1468>>2]<<1,c[I+1464>>2]|0)|0)|0;mrc(c[I+2316>>2]|0,0,ca(c[I+2312>>2]<<1,c[I+2308>>2]|0)|0)|0;mrc(c[I+3160>>2]|0,0,ca(c[I+3156>>2]<<1,c[I+3152>>2]|0)|0)|0;ma=I+3988|0;if((c[ma>>2]|0)!=0){qa=ma;break}la=c[I>>2]|0;Z=I+4072|0;ka=I+4076|0;N=pJb(ca(c[Z>>2]<<5,c[ka>>2]|0)|0)|0;M=N;Q=c[T>>2]|0;S=-Q&7;if((S|0)==0){ra=Q}else{U=c[H>>2]|0;Y=S+Q|0;Q=U>>>0>Y>>>0?Y:U;c[T>>2]=Q;ra=Q}Q=(c[O>>2]|0)-ra|0;c:do{if((Q|0)>0){U=c[ka>>2]|0;Y=I+4080|0;S=I+4084|0;X=0;W=Q;ja=(c[R>>2]|0)+((ra|0)/8|0)|0;na=0;while(1){if(!(X>>>0<U>>>0&(W|0)>0)){sa=na;break c}oa=c[Z>>2]|0;ta=W;ua=ja;va=0;wa=na;while(1){if(!(va>>>0<oa>>>0)){break}xa=wa+1|0;ya=c[Y>>2]|0;za=ca(ya,xa)|0;Aa=c[S>>2]|0;Ba=((za|0)/(Aa|0)|0)-((ca(ya,wa)|0)/(Aa|0)|0)|0;c[M+(wa<<5)+28>>2]=Ba;c[M+(wa<<5)+20>>2]=va;c[M+(wa<<5)+24>>2]=X;Aa=ta>>>0>2147483639>>>0|(ua|0)==0;ya=Aa?0:ua;za=Aa?0:ta;c[M+(wa<<5)>>2]=ya;c[M+(wa<<5)+12>>2]=za;c[M+(wa<<5)+16>>2]=za+8;c[M+(wa<<5)+4>>2]=ya+(za+7>>3);c[M+(wa<<5)+8>>2]=0;za=ta-(Ba<<3)|0;if((za|0)>0){ta=za;ua=ua+Ba|0;va=va+1|0;wa=xa}else{sa=xa;break c}}if((ta|0)>0){X=X+1|0;W=ta;ja=ua;na=wa}else{sa=wa;break}}}else{sa=0}}while(0);se[c[la+824>>2]&127](la,672,N,0,sa,32)|0;M=c[I+1516>>2]|0;Z=c[I+1504>>2]|0;Q=(Z|0)>1;if(Q){ka=1;na=b[M>>1]|0;do{ja=M+(ka<<1)|0;na=(b[ja>>1]|0)+na&65535;b[ja>>1]=na;ka=ka+1|0;}while((ka|0)<(Z|0))}ka=c[I+1500>>2]|0;na=M+(ka<<1)|0;la=c[I+1508>>2]|0;d:do{if((la|0)>1){ja=-ka|0;if(Q){Ca=1;Da=na}else{W=1;X=na;while(1){b[X>>1]=(b[X>>1]|0)+(b[X+(ja<<1)>>1]|0);S=W+1|0;if((S|0)<(la|0)){W=S;X=X+(ka<<1)|0}else{break d}}}while(1){X=(b[Da>>1]|0)+(b[Da+(ja<<1)>>1]|0)&65535;b[Da>>1]=X;W=1;S=X;do{X=W-ka|0;Y=Da+(W<<1)|0;S=(((((b[Da+(X<<1)>>1]|0)+(S<<16>>16)+(b[Da+(X-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[Y>>1]|0)&65535;b[Y>>1]=S;W=W+1|0;}while((W|0)<(Z|0));W=Ca+1|0;if((W|0)<(la|0)){Ca=W;Da=Da+(ka<<1)|0}else{break}}}}while(0);ka=c[I+2360>>2]|0;la=c[I+2348>>2]|0;Z=(la|0)>1;if(Z){na=1;Q=b[ka>>1]|0;do{M=ka+(na<<1)|0;Q=(b[M>>1]|0)+Q&65535;b[M>>1]=Q;na=na+1|0;}while((na|0)<(la|0))}na=c[I+2344>>2]|0;Q=ka+(na<<1)|0;M=c[I+2352>>2]|0;e:do{if((M|0)>1){ja=-na|0;if(Z){Ea=1;Fa=Q}else{W=1;S=Q;while(1){b[S>>1]=(b[S>>1]|0)+(b[S+(ja<<1)>>1]|0);wa=W+1|0;if((wa|0)<(M|0)){W=wa;S=S+(na<<1)|0}else{break e}}}while(1){S=(b[Fa>>1]|0)+(b[Fa+(ja<<1)>>1]|0)&65535;b[Fa>>1]=S;W=1;wa=S;do{S=W-na|0;ua=Fa+(W<<1)|0;wa=(((((b[Fa+(S<<1)>>1]|0)+(wa<<16>>16)+(b[Fa+(S-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[ua>>1]|0)&65535;b[ua>>1]=wa;W=W+1|0;}while((W|0)<(la|0));W=Ea+1|0;if((W|0)<(M|0)){Ea=W;Fa=Fa+(na<<1)|0}else{break}}}}while(0);na=c[I+3204>>2]|0;M=c[I+3192>>2]|0;la=(M|0)>1;if(la){Q=1;Z=b[na>>1]|0;do{ka=na+(Q<<1)|0;Z=(b[ka>>1]|0)+Z&65535;b[ka>>1]=Z;Q=Q+1|0;}while((Q|0)<(M|0))}Q=c[I+3188>>2]|0;Z=na+(Q<<1)|0;ka=c[I+3196>>2]|0;f:do{if((ka|0)>1){ja=-Q|0;if(la){Ga=1;Ha=Z}else{W=1;wa=Z;while(1){b[wa>>1]=(b[wa>>1]|0)+(b[wa+(ja<<1)>>1]|0);ua=W+1|0;if((ua|0)<(ka|0)){W=ua;wa=wa+(Q<<1)|0}else{break f}}}while(1){wa=(b[Ha>>1]|0)+(b[Ha+(ja<<1)>>1]|0)&65535;b[Ha>>1]=wa;W=1;ua=wa;do{wa=W-Q|0;S=Ha+(W<<1)|0;ua=(((((b[Ha+(wa<<1)>>1]|0)+(ua<<16>>16)+(b[Ha+(wa-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[S>>1]|0)&65535;b[S>>1]=ua;W=W+1|0;}while((W|0)<(M|0));W=Ga+1|0;if((W|0)<(ka|0)){Ga=W;Ha=Ha+(Q<<1)|0}else{break}}}}while(0);kJb(N);qa=ma}}while(0);fa=I+4240|0;pa=I;ga=I+4008|0;ea=I+4012|0;Q=I+7328|0;ka=I+7344|0;M=I+7360|0;Z=I+4196|0;la=I+7364|0;na=I+7368|0;ja=I+4190|0;W=I+4192|0;ua=I+4244|0;S=I+4204|0;wa=I+4220|0;ta=I+4200|0;Y=I+4256|0;X=I+5280|0;U=I+6304|0;va=I+1356|0;oa=I+1208|0;xa=I+4188|0;Ba=I+1248|0;za=I+1348|0;ya=I+4224|0;Aa=I+4228|0;Ia=I+4232|0;Ja=I+4236|0;Ka=0;while(1){La=L+1448+(Ka*844|0)|0;Ma=c[(c[c[P>>2]>>2]|0)+(Ka<<2)>>2]|0;Na=La|0;Oa=c[fa>>2]|0;c[ya>>2]=Oa;c[Aa>>2]=Oa+((c[Na>>2]|0)+15&-16);c[Ia>>2]=Oa+((c[Na>>2]<<1)+30&-32);c[Ja>>2]=Oa+(((c[Na>>2]|0)+15&-16)*3|0);do{if((c[qa>>2]|0)==0){if((c[da>>2]|0)!=0){break}mrc(c[L+1448+(Ka*844|0)+24>>2]|0,0,ca(c[L+1448+(Ka*844|0)+20>>2]<<1,c[L+1448+(Ka*844|0)+16>>2]|0)|0)|0;Oa=c[pa>>2]|0;if((c[ga>>2]|0)==0){Pa=0}else{Qa=Oa+824|0;Ra=0;Sa=0;while(1){Ta=(Ra|0)!=0|0;Ua=Sa;Va=Ta;while(1){Wa=Ua+1|0;c[n+(Ua<<2)>>2]=L+1448+(Ka*844|0)+44+(Ra*160|0)+(Va*40|0);Xa=c[T>>2]|0;Ya=-Xa&7;Za=c[H>>2]|0;if((Ya|0)==0){_a=Xa}else{$a=Ya+Xa|0;Xa=Za>>>0>$a>>>0?$a:Za;c[T>>2]=Xa;_a=Xa}Xa=c[R>>2]|0;$a=Xa+(_a>>>3)|0;Ya=(je(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(_a&7);if((Ya&-1434451968|0)==0){$a=1;ab=_a;bb=Ya;while(1){cb=bb>>>24;db=a[1369728+cb|0]|0;eb=db&255;fb=((db&255)>>>0>8>>>0?8:eb)+ab|0;gb=Za>>>0>fb>>>0;hb=gb?fb:Za;if(!(db<<24>>24==9)){ia=110;break}db=d[1369984+cb|0]|$a<<4;if(!(db>>>0<134217728>>>0)){ib=db;break}fb=Xa+(hb>>>3)|0;jb=(je(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(hb&7);if(gb){$a=db;ab=hb;bb=jb}else{ib=db;break}}if((ia|0)==110){ia=0;ib=d[1369984+cb|0]|$a<<(eb-1>>1)}c[T>>2]=hb;kb=ib-1|0}else{bb=Ya>>>24;ab=(d[1369728+bb|0]|0)+_a|0;c[T>>2]=Za>>>0>ab>>>0?ab:Za;kb=d[1369216+bb|0]|0}bb=L+1448+(Ka*844|0)+44+(Ra*160|0)+(Va*40|0)+32|0;c[bb>>2]=kb;if((kb|0)!=0){ab=c[T>>2]|0;Xa=c[H>>2]|0;db=c[R>>2]|0;jb=db+(ab>>>3)|0;gb=(je(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(ab&7);if((gb&-1434451968|0)==0){jb=1;fb=ab;lb=gb;while(1){mb=lb>>>24;nb=a[1369728+mb|0]|0;ob=nb&255;pb=((nb&255)>>>0>8>>>0?8:ob)+fb|0;qb=Xa>>>0>pb>>>0;rb=qb?pb:Xa;if(!(nb<<24>>24==9)){ia=118;break}nb=d[1369984+mb|0]|jb<<4;if(!(nb>>>0<134217728>>>0)){sb=nb;break}pb=db+(rb>>>3)|0;tb=(je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(rb&7);if(qb){jb=nb;fb=rb;lb=tb}else{sb=nb;break}}if((ia|0)==118){ia=0;sb=d[1369984+mb|0]|jb<<(ob-1>>1)}c[T>>2]=rb;ub=sb-1|0}else{lb=gb>>>24;fb=(d[1369728+lb|0]|0)+ab|0;c[T>>2]=Xa>>>0>fb>>>0?fb:Xa;ub=d[1369216+lb|0]|0}c[L+1448+(Ka*844|0)+44+(Ra*160|0)+(Va*40|0)+20>>2]=ub;lb=c[T>>2]|0;fb=-lb&7;if((fb|0)==0){vb=lb}else{db=c[H>>2]|0;Za=fb+lb|0;lb=db>>>0>Za>>>0?Za:db;c[T>>2]=lb;vb=lb}c[L+1448+(Ka*844|0)+44+(Ra*160|0)+(Va*40|0)+36>>2]=(c[R>>2]|0)+((vb|0)/8|0);lb=c[bb>>2]|0;db=(c[O>>2]|0)-(c[T>>2]|0)|0;if((db|0)>7){Za=(db|0)/8|0;wb=lb>>>0<=Za>>>0?lb:Za}else{wb=0}c[bb>>2]=wb;Za=wb<<3;lb=c[T>>2]|0;db=-lb|0;fb=(c[H>>2]|0)-lb|0;if((Za|0)<(db|0)){xb=db}else{xb=(fb|0)<(Za|0)?fb:Za}c[T>>2]=xb+lb}lb=Va+1|0;if(lb>>>0<4>>>0){Ua=Wa;Va=lb}else{break}}Va=Sa+4-Ta|0;if((c[V>>2]|0)!=0){se[c[Qa>>2]&127](Oa,160,L+1448+(Ka*844|0)+44+(Ra*160|0)+(Ta*40|0)|0,0,4-Ta|0,40)|0}Ua=Ra+1|0;if(Ua>>>0<(c[ga>>2]|0)>>>0){Ra=Ua;Sa=Va}else{Pa=Va;break}}}if((c[V>>2]|0)!=0){break}se[c[Oa+824>>2]&127](Oa,856,s,0,Pa,4)|0}}while(0);ma=L+1448+(Ka*844|0)+24|0;N=L+1448+(Ka*844|0)+20|0;if((Tob(o,c[ma>>2]|0,c[L+1448+(Ka*844|0)+12>>2]|0,c[L+1448+(Ka*844|0)+16>>2]|0,c[N>>2]|0,(c[ea>>2]|0)+2|0,c[ga>>2]|0,c[L+1448+(Ka*844|0)+32>>2]|0)|0)!=0){break b}Sa=c[ha>>2]|0;g:do{if((Sa|0)==0){Ra=L+1448+(Ka*844|0)+4|0;if((c[Ra>>2]|0)<=0){break}Qa=L+1448+(Ka*844|0)+8|0;Va=0;while(1){Ua=Va+16|0;qpb(o,Ua);lb=c[Qa>>2]|0;Za=Ma+(ca(lb,Va)|0)|0;fb=c[N>>2]|0;db=(c[ma>>2]|0)+((ca(fb,Va)|0)<<1)|0;_e[c[za>>2]&511](Za,lb,db,fb,c[Na>>2]|0,16);if((Ua|0)<(c[Ra>>2]|0)){Va=Ua}else{break}}}else{Va=L+1448+(Ka*844|0)+39|0;Ra=L+1448+(Ka*844|0)+8|0;Qa=ca(d[Va]|0,c[Ra>>2]|0)|0;Oa=L+1448+(Ka*844|0)+4|0;Ua=a[L+1448+(Ka*844|0)+36|0]|0;fb=(Ua&255)>>>0>16>>>0?2:(Ua&255)>>>0>8>>>0|0;Ua=L+1252+(fb<<4)|0;c[Q>>2]=c[Ua>>2];c[Q+4>>2]=c[Ua+4>>2];c[Q+8>>2]=c[Ua+8>>2];c[Q+12>>2]=c[Ua+12>>2];Ua=L+1300+(fb<<4)|0;c[ka>>2]=c[Ua>>2];c[ka+4>>2]=c[Ua+4>>2];c[ka+8>>2]=c[Ua+8>>2];c[ka+12>>2]=c[Ua+12>>2];c[M>>2]=c[L+1360+(fb<<2)>>2];do{if((c[Z>>2]|0)>>>0>1>>>0){ia=143}else{if((b[ja>>1]|0)!=1){ia=143;break}if((b[W>>1]|0)!=1){ia=143;break}c[la>>2]=0;yb=0}}while(0);if((ia|0)==143){ia=0;c[la>>2]=c[L+1372+(fb<<2)>>2];yb=c[L+1384+(fb<<2)>>2]|0}c[na>>2]=yb;if((Sa|0)>0){Ua=0;do{db=c[L+7376+(Ua<<2)>>2]|0;lb=c[Na>>2]|0;Za=c[Oa>>2]|0;Ya=db|0;$a=c[(c[Ya>>2]|0)+(Ka<<2)>>2]|0;nb=db+16+(Ka<<4)|0;c[nb>>2]=$a;Se[c[oa>>2]&1023]($a,c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,lb,Za,8,8,3);if((a[xa]|0)!=0){$a=Za+16|0;tb=db+64+(Ka<<4)+4|0;qb=c[tb>>2]|0;if((qb|0)==0){pb=hJb((ca(c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,$a)|0)+32|0)|0;c[tb>>2]=pb;zb=pb}else{zb=qb}qb=c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0;pb=db+16+(Ka<<4)+4|0;c[pb>>2]=zb+((qb<<3)+16);tb=db+64+(Ka<<4)+8|0;Ab=c[tb>>2]|0;if((Ab|0)==0){Bb=hJb((ca(qb,$a)|0)+32|0)|0;c[tb>>2]=Bb;Cb=Bb;Db=c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0}else{Cb=Ab;Db=qb}qb=db+16+(Ka<<4)+8|0;c[qb>>2]=Cb+((Db<<3)+16);Ab=db+64+(Ka<<4)+12|0;Bb=c[Ab>>2]|0;if((Bb|0)==0){tb=hJb((ca(Db,$a)|0)+32|0)|0;c[Ab>>2]=tb;Eb=tb;Fb=c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0}else{Eb=Bb;Fb=Db}Bb=Eb+((Fb<<3)+16)|0;tb=db+16+(Ka<<4)+12|0;c[tb>>2]=Bb;Ab=db+4+(Ka<<2)|0;if((c[Ab>>2]|0)==0){Se[c[Ba>>2]&1023](c[pb>>2]|0,c[qb>>2]|0,Bb,c[nb>>2]|0,Fb,lb,Za);Se[c[oa>>2]&1023](c[pb>>2]|0,c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,lb,Za,8,8,3);Se[c[oa>>2]&1023](c[qb>>2]|0,c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,lb,Za,8,8,3);Se[c[oa>>2]&1023](c[tb>>2]|0,c[(c[Ya>>2]|0)+32+(Ka<<2)>>2]|0,lb,Za,8,8,3)}c[Ab>>2]=1}Ua=Ua+1|0;}while((Ua|0)<(c[ha>>2]|0))}Ua=L+1448+(Ka*844|0)+41|0;mrc(c[ua>>2]|0,0,ca(d[Ua]<<2,c[Ra>>2]|0)|0)|0;fb=c[S>>2]|0;if((fb|0)<=0){break}Ab=Qa<<1;Za=L+1448+(Ka*844|0)+38|0;lb=L+1448+(Ka*844|0)+40|0;Ya=-(d[Ua]|0)|0;tb=0;qb=fb;while(1){fb=(Ya|0)>0?Ya:0;pb=c[ua>>2]|0;nb=ca(tb,Qa)|0;Bb=pb+(nb<<1)|0;db=c[wa>>2]|0;$a=ca(c[ta>>2]|0,tb)|0;Gb=db+($a*10|0)|0;Hb=(tb|0)==0|0;Ib=(qb-1|0)==(tb|0);Jb=Ib&1;if(Ib|tb>>>0<2>>>0){K5(La,Y,1,0,Hb,Jb);K5(La,X,0,0,Hb,Jb);K5(La,U,0,1,Hb,Jb);Kb=c[S>>2]|0}else{Kb=qb}do{if((tb|0)==(Kb-1|0)){Lb=c[Oa>>2]|0;ia=164}else{Jb=d[Va]|0;Hb=c[Oa>>2]|0;if((Jb+fb|0)>(Hb|0)){Lb=Hb;ia=164;break}Mb=Ya-fb+Jb|0}}while(0);if((ia|0)==164){ia=0;Mb=Lb-fb|0}if((Mb|0)<0){break g}mrc(pb+((ca(d[Ua]<<1,c[Ra>>2]|0)|0)+nb<<1)|0,0,Ab|0)|0;Ta=d[lb]|0;Jb=(d[Za]|0)-Ta|0;I5(L,Gb,Bb,Y,Ka,-Ta|0,Ya);Ta=pb+((d[Za]|0)+nb<<1)|0;Hb=db+(($a+1|0)*10|0)|0;if(((c[ta>>2]|0)-1|0)>1){Ib=Ta;Nb=1;Ob=Jb;Pb=Hb;while(1){I5(L,Pb,Ib,X,Ka,Ob,Ya);Qb=d[Za]|0;Rb=Qb+Ob|0;Sb=Ib+(Qb<<1)|0;Qb=Nb+1|0;Tb=db+((Qb+$a|0)*10|0)|0;if((Qb|0)<((c[ta>>2]|0)-1|0)){Ib=Sb;Nb=Qb;Ob=Rb;Pb=Tb}else{Ub=Sb;Vb=Rb;Wb=Tb;break}}}else{Ub=Ta;Vb=Jb;Wb=Hb}I5(L,Wb,Ub,U,Ka,Vb,Ya);Pb=ca(c[Ra>>2]|0,fb-Ya|0)|0;Ob=pb+(Pb+nb+(d[lb]|0)<<1)|0;qpb(o,Mb+fb|0);Pb=c[Ra>>2]|0;Nb=Ma+(ca(Pb,fb)|0)|0;Ib=c[N>>2]|0;$a=(c[ma>>2]|0)+((ca(Ib,fb)|0)<<1)|0;Se[c[va>>2]&1023](Nb,Ob,Pb,$a,Ib,c[Na>>2]|0,Mb);Ib=tb+1|0;$a=c[S>>2]|0;if((Ib|0)<($a|0)){Ya=(d[Va]|0)+Ya|0;tb=Ib;qb=$a}else{break}}}}while(0);Na=Ka+1|0;if((Na|0)<3){Ka=Na}else{G=J;break}}}}else{G=F}}while(0);if((G+13|0)<(u|0)){x=G}else{Xb=G;break a}}if((ia|0)==50){KIb(f,48,2206992,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}else if((ia|0)==51){KIb(f,16,2174592,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}else if((ia|0)==53){KIb(f,16,2147048,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K}KIb(c[w>>2]|0,16,2365680,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;E=-1;i=k;return E|0}else{Xb=0}}while(0);G=c[j>>2]|0;if((G|0)==0){E=u;i=k;return E|0}u=c[G>>2]|0;Mb=c[u+164>>2]|0;o=r+1444|0;Vb=c[o>>2]|0;do{if((Mb|0)>(Vb|0)){Ub=r+7420|0;Wb=Ub;Lb=Ub;Ub=c[Lb>>2]|0;do{if((Ub|0)==0){Yb=0;Zb=G;_b=u}else{Kb=0;Fb=0;Eb=-1;Db=Ub;do{Cb=(c[(c[Db>>2]|0)+164>>2]|0)==(Vb|0);Kb=Cb?Db:Kb;Eb=Cb?Fb:Eb;Fb=Fb+1|0;Db=c[Lb+(Fb<<2)>>2]|0;}while((Db|0)!=0);if((Kb|0)==0){Yb=0;Zb=G;_b=u;break}Db=Lb+(Eb<<2)|0;if((c[Db>>2]|0)==0){Yb=Kb;Zb=G;_b=u;break}else{$b=Eb;ac=Db}while(1){Db=$b+1|0;Fb=Lb+(Db<<2)|0;c[ac>>2]=c[Fb>>2];if((c[Fb>>2]|0)==0){break}else{$b=Db;ac=Fb}}Eb=c[j>>2]|0;Yb=Kb;Zb=Eb;_b=c[Eb>>2]|0}}while(0);Ub=_b+172|0;c[Ub>>2]=c[Ub>>2]|4;Ub=0;while(1){if((Ub|0)>=5){ia=184;break}bc=Lb+(Ub<<2)|0;if((c[bc>>2]|0)==0){ia=183;break}else{Ub=Ub+1|0}}h:do{if((ia|0)==183){c[bc>>2]=Zb;cc=Yb}else if((ia|0)==184){Ub=c[(c[c[Lb>>2]>>2]|0)+164>>2]|0;KIb(f,16,2300392,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;w=c[r+7424>>2]|0;if((w|0)==0){dc=Ub}else{Eb=1;Fb=Ub;Ub=w;while(1){w=c[(c[Ub>>2]|0)+164>>2]|0;Db=(w|0)<(Fb|0)?w:Fb;w=Eb+1|0;Cb=c[Wb+(w<<2)>>2]|0;if((Cb|0)==0){dc=Db;break}else{Eb=w;Fb=Db;Ub=Cb}}}Ub=c[Lb>>2]|0;do{if((Ub|0)==0){ec=0}else{Fb=0;Eb=0;Kb=-1;Cb=Ub;do{Db=(c[(c[Cb>>2]|0)+164>>2]|0)==(dc|0);Fb=Db?Cb:Fb;Kb=Db?Eb:Kb;Eb=Eb+1|0;Cb=c[Lb+(Eb<<2)>>2]|0;}while((Cb|0)!=0);if((Fb|0)==0){ec=0;break}Cb=Lb+(Kb<<2)|0;if((c[Cb>>2]|0)==0){ec=Fb;break}else{fc=Kb;gc=Cb}while(1){Cb=fc+1|0;Eb=Lb+(Cb<<2)|0;c[gc>>2]=c[Eb>>2];if((c[Eb>>2]|0)==0){ec=Fb;break}else{fc=Cb;gc=Eb}}}}while(0);Ub=c[j>>2]|0;Fb=0;while(1){if((Fb|0)>=5){cc=ec;break h}hc=Lb+(Fb<<2)|0;if((c[hc>>2]|0)==0){break}else{Fb=Fb+1|0}}c[hc>>2]=Ub;cc=ec}}while(0);if((cc|0)==0){ia=201;break}Lb=c[cc>>2]|0;Wb=Lb+172|0;c[Wb>>2]=c[Wb>>2]^4;Wb=YHb(v,Lb)|0;if((Wb|0)<0){E=Wb;i=k;return E|0}else{c[h>>2]=1;break}}else{if((Mb|0)!=(Vb|0)){ia=201;break}Wb=YHb(v,u)|0;if((Wb|0)<0){E=Wb;i=k;return E|0}else{c[h>>2]=1;break}}}while(0);do{if((ia|0)==201){if((c[h>>2]|0)==0){E=Xb}else{break}i=k;return E|0}}while(0);c[o>>2]=(c[g+164>>2]|0)+1;E=Xb;i=k;return E|0}function E5(a){a=a|0;var b=0;b=c[a+60>>2]|0;G5(b);c[b+1440>>2]=0;c[b+1444>>2]=-1;VHb(b+7444|0);VHb(b+7556|0);VHb(b+7668|0);VHb(b+7780|0);VHb(b+7892|0);VHb(b+8004|0);VHb(b+8116|0);VHb(b+8228|0);VHb(b+8340|0);VHb(b+8452|0);VHb(b+8564|0);VHb(b+8676|0);VHb(b+8788|0);VHb(b+8900|0);return 0}function F5(a){a=a|0;var b=0;b=c[a+60>>2]|0;G5(b);c[b+1440>>2]=0;c[b+1444>>2]=-1;return}function G5(a){a=a|0;var b=0,d=0;b=0;do{d=c[a+7444+(b*112|0)>>2]|0;if((c[d>>2]|0)!=0){WHb(d);mrc(a+7444+(b*112|0)+4|0,0,12)|0}mJb(a+7444+(b*112|0)+68|0);mJb(a+7444+(b*112|0)+72|0);mJb(a+7444+(b*112|0)+76|0);mJb(a+7444+(b*112|0)+84|0);mJb(a+7444+(b*112|0)+88|0);mJb(a+7444+(b*112|0)+92|0);mJb(a+7444+(b*112|0)+100|0);mJb(a+7444+(b*112|0)+104|0);mJb(a+7444+(b*112|0)+108|0);b=b+1|0;}while((b|0)<14);mrc(a+7384|0,0,60)|0;mJb(a+1476|0);mJb(a+1480|0);mJb(a+2320|0);mJb(a+2324|0);mJb(a+3164|0);mJb(a+3168|0);mJb(a+4216|0);mJb(a+4220|0);mJb(a+4240|0);mJb(a+4244|0);mJb(a+4248|0);return}function H5(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0,$i=0,aj=0,bj=0,cj=0,dj=0,ej=0,fj=0,gj=0,hj=0,ij=0,jj=0,kj=0,lj=0,mj=0,nj=0,oj=0,pj=0,qj=0,rj=0,sj=0,tj=0,uj=0,vj=0,wj=0,xj=0,yj=0,zj=0,Aj=0,Bj=0,Cj=0,Dj=0,Ej=0,Fj=0,Gj=0,Hj=0,Ij=0,Jj=0,Kj=0,Lj=0,Mj=0,Nj=0,Oj=0,Pj=0;g=i;i=i+512|0;h=g|0;j=g+16|0;k=g+496|0;l=g+504|0;m=f+1396|0;n=f+1404|0;o=c[n>>2]|0;p=f+1412|0;q=c[p>>2]|0;r=m|0;s=c[r>>2]|0;t=s+(o>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(o&7)&-65536;t=o+16|0;o=q>>>0>t>>>0?t:q;c[n>>2]=o;t=s+(o>>>3)|0;s=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(o&7)>>>16;t=o+16|0;c[n>>2]=q>>>0>t>>>0?t:q;q=s|u;u=f+7372|0;c[(c[c[u>>2]>>2]|0)+164>>2]=q;s=f|0;KIb(c[s>>2]|0,48,2640904,(t=i,i=i+8|0,c[t>>2]=q,t)|0);i=t;o=f+1444|0;if((c[o>>2]|0)<0){c[o>>2]=q}c[f+7380>>2]=0;c[f+7376>>2]=0;o=f+4004|0;v=c[o>>2]|0;if((v|0)>0){w=0;while(1){x=c[n>>2]|0;y=c[p>>2]|0;z=c[r>>2]|0;A=z+(x>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(x&7);if((B&-1434451968|0)==0){A=1;C=x;D=B;while(1){E=D>>>24;F=a[1369728+E|0]|0;G=F&255;H=((F&255)>>>0>8>>>0?8:G)+C|0;I=y>>>0>H>>>0;J=I?H:y;if(!(F<<24>>24==9)){K=8;break}F=d[1369984+E|0]|A<<4;if(!(F>>>0<134217728>>>0)){L=F;break}H=z+(J>>>3)|0;M=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7);if(I){A=F;C=J;D=M}else{L=F;break}}if((K|0)==8){K=0;L=d[1369984+E|0]|A<<(G-1>>1)}c[n>>2]=J;N=L-1|0;O=J}else{D=B>>>24;C=(d[1369728+D|0]|0)+x|0;F=y>>>0>C>>>0?C:y;c[n>>2]=F;N=d[1369216+D|0]|0;O=F}if((N|0)==0){P=0}else{F=z+(O>>>3)|0;D=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(O&7)>>31;F=O+1|0;c[n>>2]=y>>>0>F>>>0?F:y;P=(D^N)-D|0}D=P+q|0;F=f+7376+(w<<2)|0;C=0;M=2147483647;while(1){I=f+7384+(C<<2)|0;H=c[I>>2]|0;do{if((H|0)==0){Q=M}else{R=(c[(c[H>>2]|0)+164>>2]|0)-D|0;if((((R|0)>-1?R:-R|0)|0)>=(M|0)){Q=M;break}c[F>>2]=H;R=(c[(c[c[I>>2]>>2]|0)+164>>2]|0)-D|0;Q=(R|0)>-1?R:-R|0}}while(0);I=C+1|0;S=(Q|0)==0;if((I|0)>7|S){break}else{C=I;M=Q}}M=c[F>>2]|0;if((M|0)!=0&S){T=M}else{KIb(c[s>>2]|0,48,2618152,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;T=c[F>>2]|0}a:do{if((T|0)==0){M=0;while(1){if((M|0)>=14){break a}U=f+7444+(M*112|0)|0;V=U|0;if((c[c[V>>2]>>2]|0)==0){break}else{M=M+1|0}}c[F>>2]=U;M=c[s>>2]|0;C=c[V>>2]|0;vLa(c[M+140>>2]|0,k,l);D=M+120|0;y=C+68|0;c[y>>2]=(c[D>>2]|0)+32;z=M+124|0;x=C+72|0;c[x>>2]=(c[z>>2]|0)+34;if((M4a(M,C,1)|0)<0){break}M=C|0;B=c[M>>2]|0;if((B|0)!=0){A=16>>>((c[l>>2]|0)>>>0);I=0;H=M;M=B;do{c[H>>2]=M+((ca((I|0)!=0&(I|0)<3?A:16,c[C+32+(I<<2)>>2]|0)|0)+32);I=I+1|0;H=C+(I<<2)|0;M=c[H>>2]|0;}while((M|0)!=0)}c[y>>2]=c[D>>2];c[x>>2]=c[z>>2]}}while(0);F=w+1|0;M=c[o>>2]|0;if((F|0)<(M|0)){w=F}else{W=M;break}}}else{W=v}if((c[(c[c[u>>2]>>2]|0)+172>>2]|0)==0){X=W}else{W=c[n>>2]|0;v=c[p>>2]|0;w=c[r>>2]|0;l=w+(W>>>3)|0;k=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(W&7);if((k&-1434451968|0)==0){l=1;V=W;U=k;while(1){Y=U>>>24;T=a[1369728+Y|0]|0;Z=T&255;S=((T&255)>>>0>8>>>0?8:Z)+V|0;Q=v>>>0>S>>>0;_=Q?S:v;if(!(T<<24>>24==9)){K=34;break}T=d[1369984+Y|0]|l<<4;if(!(T>>>0<134217728>>>0)){$=T;break}S=w+(_>>>3)|0;P=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(_&7);if(Q){l=T;V=_;U=P}else{$=T;break}}if((K|0)==34){$=d[1369984+Y|0]|l<<(Z-1>>1)}c[n>>2]=_;aa=$-1|0;ba=_}else{_=k>>>24;k=(d[1369728+_|0]|0)+W|0;W=v>>>0>k>>>0?k:v;c[n>>2]=W;aa=d[1369216+_|0]|0;ba=W}b:do{if((aa|0)==0){da=f+7384|0}else{W=w+(ba>>>3)|0;_=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ba&7);W=ba+1|0;c[n>>2]=v>>>0>W>>>0?W:v;W=(_>>>31)+q+(_>>31^aa)|0;_=f+7384|0;k=c[_>>2]|0;do{if((k|0)!=0){$=0;Z=0;l=-1;Y=k;do{U=(c[(c[Y>>2]|0)+164>>2]|0)==(W|0);$=U?Y:$;l=U?Z:l;Z=Z+1|0;Y=c[f+7384+(Z<<2)>>2]|0;}while((Y|0)!=0);if(($|0)==0){break}Y=f+7384+(l<<2)|0;if((c[Y>>2]|0)!=0){Z=l;z=Y;while(1){Y=Z+1|0;x=f+7384+(Y<<2)|0;c[z>>2]=c[x>>2];if((c[x>>2]|0)==0){break}else{Z=Y;z=x}}}z=(c[$>>2]|0)+172|0;c[z>>2]=c[z>>2]&4;da=_;break b}}while(0);KIb(c[s>>2]|0,48,2590768,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;da=_}}while(0);c:while(1){ea=c[u>>2]|0;aa=0;while(1){if((aa|0)>=8){break}fa=f+7384+(aa<<2)|0;if((c[fa>>2]|0)==0){break c}else{aa=aa+1|0}}KIb(c[s>>2]|0,16,2568944,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;aa=c[da>>2]|0;_=c[(c[aa>>2]|0)+164>>2]|0;q=0;v=0;ba=-1;w=aa;aa=_;while(1){W=(aa|0)==(_|0);ga=W?w:q;ha=W?v:ba;W=v+1|0;k=c[f+7384+(W<<2)>>2]|0;if((k|0)==0){break}q=ga;v=W;ba=ha;w=k;aa=c[(c[k>>2]|0)+164>>2]|0}aa=f+7384+(ha<<2)|0;if((c[aa>>2]|0)!=0){w=ha;ba=aa;while(1){aa=w+1|0;v=f+7384+(aa<<2)|0;c[ba>>2]=c[v>>2];if((c[v>>2]|0)==0){break}else{w=aa;ba=v}}}ba=(c[ga>>2]|0)+172|0;c[ba>>2]=c[ba>>2]&4}c[fa>>2]=ea;X=c[o>>2]|0}d:do{if((X|0)!=0){ea=c[n>>2]|0;fa=-ea&7;ga=c[p>>2]|0;if((fa|0)==0){ia=ea}else{ha=fa+ea|0;ea=ga>>>0>ha>>>0?ha:ga;c[n>>2]=ea;ia=ea}ea=f+1396|0;ha=c[ea>>2]|0;fa=ha+(ia>>>3)|0;da=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ia&7);if((da&-1434451968|0)==0){fa=1;u=ia;ba=da;while(1){ja=ba>>>24;w=a[1369728+ja|0]|0;ka=w&255;v=((w&255)>>>0>8>>>0?8:ka)+u|0;aa=ga>>>0>v>>>0;la=aa?v:ga;if(!(w<<24>>24==9)){K=64;break}w=d[1369984+ja|0]|fa<<4;if(!(w>>>0<134217728>>>0)){ma=w;break}v=ha+(la>>>3)|0;q=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(la&7);if(aa){fa=w;u=la;ba=q}else{ma=w;break}}if((K|0)==64){ma=d[1369984+ja|0]|fa<<(ka-1>>1)}c[n>>2]=la;na=ma-1|0;oa=la}else{ba=da>>>24;u=(d[1369728+ba|0]|0)+ia|0;w=ga>>>0>u>>>0?u:ga;c[n>>2]=w;na=d[1369216+ba|0]|0;oa=w}if(na>>>0>4>>>0){KIb(c[s>>2]|0,16,2443624,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}if((na|0)==0){w=ha+(oa>>>3)|0;ba=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(oa&7);if((ba&-1434451968|0)==0){w=1;u=oa;q=ba;while(1){qa=q>>>24;aa=a[1369728+qa|0]|0;ra=aa&255;v=((aa&255)>>>0>8>>>0?8:ra)+u|0;_=ga>>>0>v>>>0;sa=_?v:ga;if(!(aa<<24>>24==9)){K=74;break}aa=d[1369984+qa|0]|w<<4;if(!(aa>>>0<134217728>>>0)){ta=aa;break}v=ha+(sa>>>3)|0;k=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(sa&7);if(_){w=aa;u=sa;q=k}else{ta=aa;break}}if((K|0)==74){ta=d[1369984+qa|0]|w<<(ra-1>>1)}c[n>>2]=sa;ua=ta+255&255;va=sa}else{q=ba>>>24;u=(d[1369728+q|0]|0)+oa|0;da=ga>>>0>u>>>0?u:ga;c[n>>2]=da;ua=a[1369216+q|0]|0;va=da}a[f+1484|0]=ua;da=ha+(va>>>3)|0;q=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(va&7);if((q&-1434451968|0)==0){da=1;u=va;fa=q;while(1){wa=fa>>>24;aa=a[1369728+wa|0]|0;xa=aa&255;k=((aa&255)>>>0>8>>>0?8:xa)+u|0;_=ga>>>0>k>>>0;ya=_?k:ga;if(!(aa<<24>>24==9)){K=81;break}aa=d[1369984+wa|0]|da<<4;if(!(aa>>>0<134217728>>>0)){za=aa;break}k=ha+(ya>>>3)|0;v=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(ya&7);if(_){da=aa;u=ya;fa=v}else{za=aa;break}}if((K|0)==81){za=d[1369984+wa|0]|da<<(xa-1>>1)}c[n>>2]=ya;Aa=za+255&255;Ba=ya}else{fa=q>>>24;u=(d[1369728+fa|0]|0)+va|0;ba=ga>>>0>u>>>0?u:ga;c[n>>2]=ba;Aa=a[1369216+fa|0]|0;Ba=ba}a[f+1485|0]=Aa;ba=ha+(Ba>>>3)|0;fa=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(Ba&7);if((fa&-1434451968|0)==0){ba=1;u=Ba;w=fa;while(1){Ca=w>>>24;aa=a[1369728+Ca|0]|0;Da=aa&255;v=((aa&255)>>>0>8>>>0?8:Da)+u|0;_=ga>>>0>v>>>0;Ea=_?v:ga;if(!(aa<<24>>24==9)){K=88;break}aa=d[1369984+Ca|0]|ba<<4;if(!(aa>>>0<134217728>>>0)){Fa=aa;break}v=ha+(Ea>>>3)|0;k=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(Ea&7);if(_){ba=aa;u=Ea;w=k}else{Fa=aa;break}}if((K|0)==88){Fa=d[1369984+Ca|0]|ba<<(Da-1>>1)}c[n>>2]=Ea;Ga=Fa+255&255;Ha=Ea}else{w=fa>>>24;u=(d[1369728+w|0]|0)+Ba|0;q=ga>>>0>u>>>0?u:ga;c[n>>2]=q;Ga=a[1369216+w|0]|0;Ha=q}a[f+1486|0]=Ga;q=ha+(Ha>>>3)|0;w=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(Ha&7);if((w&-1434451968|0)==0){q=1;u=Ha;da=w;while(1){Ia=da>>>24;aa=a[1369728+Ia|0]|0;Ja=aa&255;k=((aa&255)>>>0>8>>>0?8:Ja)+u|0;_=ga>>>0>k>>>0;Ka=_?k:ga;if(!(aa<<24>>24==9)){K=95;break}aa=d[1369984+Ia|0]|q<<4;if(!(aa>>>0<134217728>>>0)){La=aa;break}k=ha+(Ka>>>3)|0;v=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Ka&7);if(_){q=aa;u=Ka;da=v}else{La=aa;break}}if((K|0)==95){La=d[1369984+Ia|0]|q<<(Ja-1>>1)}c[n>>2]=Ka;Ma=La+255&255;Na=Ka}else{da=w>>>24;u=(d[1369728+da|0]|0)+Ha|0;fa=ga>>>0>u>>>0?u:ga;c[n>>2]=fa;Ma=a[1369216+da|0]|0;Na=fa}a[f+1487|0]=Ma;Oa=Ga;Pa=Ma;Qa=ua;Ra=Aa;Sa=Na}else{fa=na-1|0;da=a[1532440+fa|0]|0;a[f+1484|0]=da;a[f+1485|0]=da;u=a[1532432+fa|0]|0;a[f+1486|0]=u;a[f+1487|0]=u;Oa=u;Pa=u;Qa=da;Ra=da;Sa=oa}do{if(!(Oa<<24>>24==0|Pa<<24>>24==0)){if((Oa&255)>>>0<(Qa&255)>>>1>>>0){break}if((Pa&255)>>>0<(Ra&255)>>>1>>>0){break}if((Oa&255)>>>0>(Qa&255)>>>0|(Pa&255)>>>0>(Ra&255)>>>0){KIb(c[s>>2]|0,16,2420864,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}if((((Qa&255)>>>0>(Ra&255)>>>0?Qa:Ra)&255)>>>0>32>>>0){KIb(c[s>>2]|0,16,2411608,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}da=ha+(Sa>>>3)|0;u=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Sa&7);if((u&-1434451968|0)==0){da=1;fa=Sa;ba=u;while(1){Ta=ba>>>24;aa=a[1369728+Ta|0]|0;Ua=aa&255;v=((aa&255)>>>0>8>>>0?8:Ua)+fa|0;_=ga>>>0>v>>>0;Va=_?v:ga;if(!(aa<<24>>24==9)){K=112;break}aa=d[1369984+Ta|0]|da<<4;if(!(aa>>>0<134217728>>>0)){Wa=aa;break}v=ha+(Va>>>3)|0;k=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(Va&7);if(_){da=aa;fa=Va;ba=k}else{Wa=aa;break}}if((K|0)==112){Wa=d[1369984+Ta|0]|da<<(Ua-1>>1)}c[n>>2]=Va;Xa=Wa-1|0;Ya=Va}else{ba=u>>>24;fa=(d[1369728+ba|0]|0)+Sa|0;$=ga>>>0>fa>>>0?fa:ga;c[n>>2]=$;Xa=d[1369216+ba|0]|0;Ya=$}a[f+4188|0]=Xa;if((Xa&252)>>>0>3>>>0){KIb(c[s>>2]|0,16,2404016,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}$=d[ha+(Ya>>>3)|0]<<(Ya&7)>>>7;ba=((Ya|0)<(ga|0))+Ya|0;c[n>>2]=ba;fa=$&1;$=f+4e3|0;c[$>>2]=fa;if((fa|0)==0){Za=ba;_a=ga;$a=ha;ab=X}else{mrc(f+4108|0,0,80)|0;fa=0;aa=ba;ba=ga;k=ha;while(1){_=d[k+(aa>>>3)|0]|0;v=((aa|0)<(ba|0))+aa|0;c[n>>2]=v;if((_&128>>>((aa&7)>>>0)|0)==0){bb=v;cb=ba;db=k}else{_=k+(v>>>3)|0;W=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(v&7);if((W&-1434451968|0)==0){_=1;z=v;Z=W;while(1){eb=Z>>>24;l=a[1369728+eb|0]|0;fb=l&255;x=((l&255)>>>0>8>>>0?8:fb)+z|0;Y=ba>>>0>x>>>0;gb=Y?x:ba;if(!(l<<24>>24==9)){K=124;break}l=d[1369984+eb|0]|_<<4;if(!(l>>>0<134217728>>>0)){hb=l;break}x=k+(gb>>>3)|0;D=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(gb&7);if(Y){_=l;z=gb;Z=D}else{hb=l;break}}if((K|0)==124){K=0;hb=d[1369984+eb|0]|_<<(fb-1>>1)}c[n>>2]=gb;ib=hb-1|0;jb=gb}else{Z=W>>>24;z=(d[1369728+Z|0]|0)+v|0;l=ba>>>0>z>>>0?z:ba;c[n>>2]=l;ib=d[1369216+Z|0]|0;jb=l}if((ib|0)==0){kb=0}else{l=k+(jb>>>3)|0;Z=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(jb&7)>>31;l=jb+1|0;c[n>>2]=ba>>>0>l>>>0?l:ba;kb=(Z^ib)-Z|0}c[f+4108+(fa*40|0)>>2]=kb;Z=c[n>>2]|0;l=c[p>>2]|0;z=c[ea>>2]|0;D=z+(Z>>>3)|0;Y=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(Z&7);if((Y&-1434451968|0)==0){D=1;x=Z;y=Y;while(1){lb=y>>>24;U=a[1369728+lb|0]|0;mb=U&255;V=((U&255)>>>0>8>>>0?8:mb)+x|0;T=l>>>0>V>>>0;nb=T?V:l;if(!(U<<24>>24==9)){K=133;break}U=d[1369984+lb|0]|D<<4;if(!(U>>>0<134217728>>>0)){ob=U;break}V=z+(nb>>>3)|0;P=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(nb&7);if(T){D=U;x=nb;y=P}else{ob=U;break}}if((K|0)==133){K=0;ob=d[1369984+lb|0]|D<<(mb-1>>1)}c[n>>2]=nb;pb=ob-1|0;qb=nb}else{y=Y>>>24;x=(d[1369728+y|0]|0)+Z|0;v=l>>>0>x>>>0?x:l;c[n>>2]=v;pb=d[1369216+y|0]|0;qb=v}if((pb|0)==0){rb=0;sb=qb}else{v=z+(qb>>>3)|0;y=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(qb&7)>>31;v=qb+1|0;x=l>>>0>v>>>0?v:l;c[n>>2]=x;rb=(y^pb)-y|0;sb=x}c[f+4108+(fa*40|0)+4>>2]=rb;bb=sb;cb=l;db=z}x=d[db+(bb>>>3)|0]|0;y=((bb|0)<(cb|0))+bb|0;c[n>>2]=y;if((x&128>>>((bb&7)>>>0)|0)==0){c[f+4108+(fa*40|0)+8>>2]=1;c[f+4108+(fa*40|0)+20>>2]=1;tb=c[n>>2]|0;ub=c[p>>2]|0;vb=c[ea>>2]|0}else{x=db+(y>>>3)|0;v=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7);if((v&-1434451968|0)==0){x=1;W=y;_=v;while(1){wb=_>>>24;U=a[1369728+wb|0]|0;xb=U&255;P=((U&255)>>>0>8>>>0?8:xb)+W|0;T=cb>>>0>P>>>0;yb=T?P:cb;if(!(U<<24>>24==9)){K=144;break}U=d[1369984+wb|0]|x<<4;if(!(U>>>0<134217728>>>0)){zb=U;break}P=db+(yb>>>3)|0;V=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(yb&7);if(T){x=U;W=yb;_=V}else{zb=U;break}}if((K|0)==144){K=0;zb=d[1369984+wb|0]|x<<(xb-1>>1)}c[n>>2]=yb;Ab=zb-1|0}else{_=v>>>24;W=(d[1369728+_|0]|0)+y|0;c[n>>2]=cb>>>0>W>>>0?W:cb;Ab=d[1369216+_|0]|0}c[f+4108+(fa*40|0)+32>>2]=Ab;_=c[n>>2]|0;W=c[p>>2]|0;z=c[ea>>2]|0;l=z+(_>>>3)|0;Z=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(_&7);if((Z&-1434451968|0)==0){l=1;Y=_;D=Z;while(1){Bb=D>>>24;U=a[1369728+Bb|0]|0;Cb=U&255;V=((U&255)>>>0>8>>>0?8:Cb)+Y|0;T=W>>>0>V>>>0;Db=T?V:W;if(!(U<<24>>24==9)){K=151;break}U=d[1369984+Bb|0]|l<<4;if(!(U>>>0<134217728>>>0)){Eb=U;break}V=z+(Db>>>3)|0;P=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Db&7);if(T){l=U;Y=Db;D=P}else{Eb=U;break}}if((K|0)==151){K=0;Eb=d[1369984+Bb|0]|l<<(Cb-1>>1)}c[n>>2]=Db;Fb=Eb-1|0;Gb=Db}else{D=Z>>>24;Y=(d[1369728+D|0]|0)+_|0;y=W>>>0>Y>>>0?Y:W;c[n>>2]=y;Fb=d[1369216+D|0]|0;Gb=y}if((Fb|0)==0){Hb=0}else{y=z+(Gb>>>3)|0;D=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(Gb&7)>>31;y=Gb+1|0;c[n>>2]=W>>>0>y>>>0?y:W;Hb=(D^Fb)-D|0}c[f+4108+(fa*40|0)+8>>2]=Hb;D=c[n>>2]|0;y=c[p>>2]|0;Y=c[ea>>2]|0;v=Y+(D>>>3)|0;x=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(D&7);if((x&-1434451968|0)==0){v=1;U=D;P=x;while(1){Ib=P>>>24;T=a[1369728+Ib|0]|0;Jb=T&255;V=((T&255)>>>0>8>>>0?8:Jb)+U|0;Q=y>>>0>V>>>0;Kb=Q?V:y;if(!(T<<24>>24==9)){K=160;break}T=d[1369984+Ib|0]|v<<4;if(!(T>>>0<134217728>>>0)){Lb=T;break}V=Y+(Kb>>>3)|0;S=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Kb&7);if(Q){v=T;U=Kb;P=S}else{Lb=T;break}}if((K|0)==160){K=0;Lb=d[1369984+Ib|0]|v<<(Jb-1>>1)}c[n>>2]=Kb;Mb=Lb-1|0;Nb=Kb}else{P=x>>>24;U=(d[1369728+P|0]|0)+D|0;W=y>>>0>U>>>0?U:y;c[n>>2]=W;Mb=d[1369216+P|0]|0;Nb=W}if((Mb|0)==0){Ob=0;Pb=Nb}else{W=Y+(Nb>>>3)|0;P=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Nb&7)>>31;W=Nb+1|0;U=y>>>0>W>>>0?W:y;c[n>>2]=U;Ob=(P^Mb)-P|0;Pb=U}c[f+4108+(fa*40|0)+12>>2]=Ob;U=Y+(Pb>>>3)|0;P=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(Pb&7);if((P&-1434451968|0)==0){U=1;W=Pb;z=P;while(1){Qb=z>>>24;_=a[1369728+Qb|0]|0;Rb=_&255;Z=((_&255)>>>0>8>>>0?8:Rb)+W|0;l=y>>>0>Z>>>0;Sb=l?Z:y;if(!(_<<24>>24==9)){K=169;break}_=d[1369984+Qb|0]|U<<4;if(!(_>>>0<134217728>>>0)){Tb=_;break}Z=Y+(Sb>>>3)|0;T=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Sb&7);if(l){U=_;W=Sb;z=T}else{Tb=_;break}}if((K|0)==169){K=0;Tb=d[1369984+Qb|0]|U<<(Rb-1>>1)}c[n>>2]=Sb;Ub=Tb-1|0;Vb=Sb}else{z=P>>>24;W=(d[1369728+z|0]|0)+Pb|0;D=y>>>0>W>>>0?W:y;c[n>>2]=D;Ub=d[1369216+z|0]|0;Vb=D}if((Ub|0)==0){Wb=0}else{D=Y+(Vb>>>3)|0;z=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(Vb&7)>>31;D=Vb+1|0;c[n>>2]=y>>>0>D>>>0?D:y;Wb=(z^Ub)-z|0}c[f+4108+(fa*40|0)+16>>2]=Wb;z=c[n>>2]|0;D=c[p>>2]|0;W=c[ea>>2]|0;x=W+(z>>>3)|0;v=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7);if((v&-1434451968|0)==0){x=1;_=z;T=v;while(1){Xb=T>>>24;l=a[1369728+Xb|0]|0;Yb=l&255;Z=((l&255)>>>0>8>>>0?8:Yb)+_|0;S=D>>>0>Z>>>0;Zb=S?Z:D;if(!(l<<24>>24==9)){K=178;break}l=d[1369984+Xb|0]|x<<4;if(!(l>>>0<134217728>>>0)){_b=l;break}Z=W+(Zb>>>3)|0;Q=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Zb&7);if(S){x=l;_=Zb;T=Q}else{_b=l;break}}if((K|0)==178){K=0;_b=d[1369984+Xb|0]|x<<(Yb-1>>1)}c[n>>2]=Zb;$b=_b-1|0;ac=Zb}else{T=v>>>24;_=(d[1369728+T|0]|0)+z|0;y=D>>>0>_>>>0?_:D;c[n>>2]=y;$b=d[1369216+T|0]|0;ac=y}if(($b|0)==0){bc=0;cc=ac}else{y=W+(ac>>>3)|0;T=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(ac&7)>>31;y=ac+1|0;_=D>>>0>y>>>0?y:D;c[n>>2]=_;bc=(T^$b)-T|0;cc=_}c[f+4108+(fa*40|0)+20>>2]=bc;tb=cc;ub=D;vb=W}_=d[vb+(tb>>>3)|0]|0;T=((tb|0)<(ub|0))+tb|0;c[n>>2]=T;if((_&128>>>((tb&7)>>>0)|0)==0){dc=T;ec=ub;fc=vb}else{_=vb+(T>>>3)|0;y=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(T&7);if((y&-1434451968|0)==0){_=1;Y=T;P=y;while(1){gc=P>>>24;U=a[1369728+gc|0]|0;hc=U&255;l=((U&255)>>>0>8>>>0?8:hc)+Y|0;Q=ub>>>0>l>>>0;ic=Q?l:ub;if(!(U<<24>>24==9)){K=190;break}U=d[1369984+gc|0]|_<<4;if(!(U>>>0<134217728>>>0)){jc=U;break}l=vb+(ic>>>3)|0;S=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(ic&7);if(Q){_=U;Y=ic;P=S}else{jc=U;break}}if((K|0)==190){K=0;jc=d[1369984+gc|0]|_<<(hc-1>>1)}c[n>>2]=ic;kc=jc-1|0;lc=ic}else{P=y>>>24;Y=(d[1369728+P|0]|0)+T|0;W=ub>>>0>Y>>>0?Y:ub;c[n>>2]=W;kc=d[1369216+P|0]|0;lc=W}c[f+4108+(fa*40|0)+36>>2]=kc;W=vb+(lc>>>3)|0;P=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(lc&7);if((P&-1434451968|0)==0){W=1;Y=lc;D=P;while(1){mc=D>>>24;z=a[1369728+mc|0]|0;nc=z&255;v=((z&255)>>>0>8>>>0?8:nc)+Y|0;x=ub>>>0>v>>>0;oc=x?v:ub;if(!(z<<24>>24==9)){K=197;break}z=d[1369984+mc|0]|W<<4;if(!(z>>>0<134217728>>>0)){pc=z;break}v=vb+(oc>>>3)|0;U=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(oc&7);if(x){W=z;Y=oc;D=U}else{pc=z;break}}if((K|0)==197){K=0;pc=d[1369984+mc|0]|W<<(nc-1>>1)}c[n>>2]=oc;qc=pc-1|0;rc=oc}else{D=P>>>24;Y=(d[1369728+D|0]|0)+lc|0;T=ub>>>0>Y>>>0?Y:ub;c[n>>2]=T;qc=d[1369216+D|0]|0;rc=T}if((qc|0)==0){sc=0}else{T=vb+(rc>>>3)|0;D=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(rc&7)>>31;T=rc+1|0;c[n>>2]=ub>>>0>T>>>0?T:ub;sc=(D^qc)-D|0}c[f+4108+(fa*40|0)+24>>2]=sc;D=c[n>>2]|0;T=c[p>>2]|0;Y=c[ea>>2]|0;y=Y+(D>>>3)|0;_=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(D&7);if((_&-1434451968|0)==0){y=1;z=D;U=_;while(1){tc=U>>>24;x=a[1369728+tc|0]|0;uc=x&255;v=((x&255)>>>0>8>>>0?8:uc)+z|0;S=T>>>0>v>>>0;vc=S?v:T;if(!(x<<24>>24==9)){K=206;break}x=d[1369984+tc|0]|y<<4;if(!(x>>>0<134217728>>>0)){wc=x;break}v=Y+(vc>>>3)|0;Q=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(vc&7);if(S){y=x;z=vc;U=Q}else{wc=x;break}}if((K|0)==206){K=0;wc=d[1369984+tc|0]|y<<(uc-1>>1)}c[n>>2]=vc;xc=wc-1|0;yc=vc}else{U=_>>>24;z=(d[1369728+U|0]|0)+D|0;P=T>>>0>z>>>0?z:T;c[n>>2]=P;xc=d[1369216+U|0]|0;yc=P}if((xc|0)==0){zc=0;Ac=yc}else{P=Y+(yc>>>3)|0;U=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(yc&7)>>31;P=yc+1|0;z=T>>>0>P>>>0?P:T;c[n>>2]=z;zc=(U^xc)-U|0;Ac=z}c[f+4108+(fa*40|0)+28>>2]=zc;dc=Ac;ec=T;fc=Y}z=fa+1|0;U=c[o>>2]|0;if(z>>>0<U>>>0){fa=z;aa=dc;ba=ec;k=fc}else{Za=dc;_a=ec;$a=fc;ab=U;break}}}k=$a+(Za>>>3)|0;ba=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Za&7);if((ba&-1434451968|0)==0){k=1;aa=Za;fa=ba;while(1){Bc=fa>>>24;u=a[1369728+Bc|0]|0;Cc=u&255;da=((u&255)>>>0>8>>>0?8:Cc)+aa|0;U=_a>>>0>da>>>0;Dc=U?da:_a;if(!(u<<24>>24==9)){K=217;break}u=d[1369984+Bc|0]|k<<4;if(!(u>>>0<134217728>>>0)){Ec=u;break}da=$a+(Dc>>>3)|0;z=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Dc&7);if(U){k=u;aa=Dc;fa=z}else{Ec=u;break}}if((K|0)==217){Ec=d[1369984+Bc|0]|k<<(Cc-1>>1)}c[n>>2]=Dc;Fc=Ec-1|0;Gc=Dc}else{fa=ba>>>24;aa=(d[1369728+fa|0]|0)+Za|0;u=_a>>>0>aa>>>0?aa:_a;c[n>>2]=u;Fc=d[1369216+fa|0]|0;Gc=u}if((Fc|0)!=0){KIb(c[s>>2]|0,16,2396816,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}u=f+4196|0;c[u>>2]=1;fa=f+4190|0;b[fa>>1]=1;aa=f+4192|0;b[aa>>1]=1;z=d[$a+(Gc>>>3)|0]|0;U=((Gc|0)<(_a|0))+Gc|0;c[n>>2]=U;do{if((z&128>>>((Gc&7)>>>0)|0)==0){Hc=U}else{da=$a+(U>>>3)|0;P=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(U&7);if((P&-1434451968|0)==0){da=1;W=U;x=P;while(1){Ic=x>>>24;Q=a[1369728+Ic|0]|0;Jc=Q&255;S=((Q&255)>>>0>8>>>0?8:Jc)+W|0;v=_a>>>0>S>>>0;Kc=v?S:_a;if(!(Q<<24>>24==9)){K=227;break}Q=d[1369984+Ic|0]|da<<4;if(!(Q>>>0<134217728>>>0)){Lc=Q;break}S=$a+(Kc>>>3)|0;l=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Kc&7);if(v){da=Q;W=Kc;x=l}else{Lc=Q;break}}if((K|0)==227){Lc=d[1369984+Ic|0]|da<<(Jc-1>>1)}c[n>>2]=Kc;Mc=Lc-1|0;Nc=Kc}else{x=P>>>24;W=(d[1369728+x|0]|0)+U|0;Y=_a>>>0>W>>>0?W:_a;c[n>>2]=Y;Mc=d[1369216+x|0]|0;Nc=Y}c[u>>2]=Mc;Y=$a+(Nc>>>3)|0;x=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(Nc&7);if((x&-1434451968|0)==0){Y=1;W=Nc;T=x;while(1){Oc=T>>>24;D=a[1369728+Oc|0]|0;Pc=D&255;_=((D&255)>>>0>8>>>0?8:Pc)+W|0;y=_a>>>0>_>>>0;Qc=y?_:_a;if(!(D<<24>>24==9)){K=234;break}D=d[1369984+Oc|0]|Y<<4;if(!(D>>>0<134217728>>>0)){Rc=D;break}_=$a+(Qc>>>3)|0;Q=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Qc&7);if(y){Y=D;W=Qc;T=Q}else{Rc=D;break}}if((K|0)==234){Rc=d[1369984+Oc|0]|Y<<(Pc-1>>1)}c[n>>2]=Qc;Sc=Rc-1|0;Tc=Qc}else{T=x>>>24;W=(d[1369728+T|0]|0)+Nc|0;P=_a>>>0>W>>>0?W:_a;c[n>>2]=P;Sc=d[1369216+T|0]|0;Tc=P}if((Sc|0)==0){Uc=0;Vc=Tc}else{P=$a+(Tc>>>3)|0;T=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Tc&7)>>31;P=Tc+1|0;W=_a>>>0>P>>>0?P:_a;c[n>>2]=W;Uc=(T^Sc)-T&65535;Vc=W}b[fa>>1]=Uc;if((ab|0)!=2){Hc=Vc;break}W=$a+(Vc>>>3)|0;T=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Vc&7);if((T&-1434451968|0)==0){W=1;P=Vc;da=T;while(1){Wc=da>>>24;D=a[1369728+Wc|0]|0;Xc=D&255;Q=((D&255)>>>0>8>>>0?8:Xc)+P|0;y=_a>>>0>Q>>>0;Yc=y?Q:_a;if(!(D<<24>>24==9)){K=244;break}D=d[1369984+Wc|0]|W<<4;if(!(D>>>0<134217728>>>0)){Zc=D;break}Q=$a+(Yc>>>3)|0;_=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(Yc&7);if(y){W=D;P=Yc;da=_}else{Zc=D;break}}if((K|0)==244){Zc=d[1369984+Wc|0]|W<<(Xc-1>>1)}c[n>>2]=Yc;_c=Zc-1|0;$c=Yc}else{da=T>>>24;P=(d[1369728+da|0]|0)+Vc|0;x=_a>>>0>P>>>0?P:_a;c[n>>2]=x;_c=d[1369216+da|0]|0;$c=x}if((_c|0)==0){ad=0;bd=$c}else{x=$a+($c>>>3)|0;da=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<($c&7)>>31;x=$c+1|0;P=_a>>>0>x>>>0?x:_a;c[n>>2]=P;ad=(da^_c)-da&65535;bd=P}b[aa>>1]=ad;Hc=bd}}while(0);aa=f+4216|0;fa=c[aa>>2]|0;u=-Hc&7;if((u|0)==0){cd=Hc}else{U=u+Hc|0;u=_a>>>0>U>>>0?U:_a;c[n>>2]=u;cd=u}u=d[f+1486|0]<<2;U=(((c[f+1416>>2]|0)-1+u|0)>>>0)/(u>>>0)|0;u=f+4208|0;c[u>>2]=U;z=d[f+1487|0]<<2;ba=(((c[f+1420>>2]|0)-1+z|0)>>>0)/(z>>>0)|0;z=f+4212|0;c[z>>2]=ba;k=f+4200|0;c[k>>2]=U<<2;c[f+4204>>2]=ba<<2;ba=j|0;U=$a+(cd>>>3)|0;P=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(cd&7);if((P&-1434451968|0)==0){U=1;da=cd;x=P;while(1){dd=x>>>24;Y=a[1369728+dd|0]|0;ed=Y&255;D=((Y&255)>>>0>8>>>0?8:ed)+da|0;_=_a>>>0>D>>>0;fd=_?D:_a;if(!(Y<<24>>24==9)){K=256;break}Y=d[1369984+dd|0]|U<<4;if(!(Y>>>0<134217728>>>0)){gd=Y;break}D=$a+(fd>>>3)|0;y=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(fd&7);if(_){U=Y;da=fd;x=y}else{gd=Y;break}}if((K|0)==256){gd=d[1369984+dd|0]|U<<(ed-1>>1)}c[n>>2]=fd;hd=gd-1|0}else{x=P>>>24;da=(d[1369728+x|0]|0)+cd|0;c[n>>2]=_a>>>0>da>>>0?da:_a;hd=d[1369216+x|0]|0}Sob(ba,m,hd);x=c[z>>2]|0;e:do{if((x|0)>0){da=j+30|0;Y=j|0;y=j+4|0;_=j+6|0;D=j+8|0;Q=j+12|0;l=j+16|0;v=0;S=fa;Z=c[u>>2]|0;V=x;f:while(1){if((Z|0)>0){N=(v|0)==0;O=0;J=Z;do{L=b[da>>1]|0;G=L&65535;E=c[Y>>2]|0;M=e[y>>1]|0;F=(ca(M,G)|0)>>>16;H=E>>>16>>>0>=F>>>0;if(H){id=E-(F<<16)|0;jd=M-F&65535}else{id=E;jd=F&65535}b[da>>1]=(b[8378640+(G>>>8<<2)+((H&1)<<1)>>1]|0)+L;c[Y>>2]=id;b[y>>1]=jd;L=b[_>>1]|0;if((jd&65535)>>>0<16385>>>0){G=id;F=jd;E=L;do{G=G<<1;F=F<<1;E=E+1&65535;}while((F&65535)>>>0<16385>>>0);c[Y>>2]=G;b[y>>1]=F;b[_>>1]=E;kd=G;ld=E;md=F}else{kd=id;ld=L;md=jd}M=ld<<16>>16;if(ld<<16>>16>-1){I=c[D>>2]|0;C=I+2|0;c[D>>2]=C;A=I;I=(he((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535;A=c[Q>>2]|0;if(C>>>0>A>>>0){c[D>>2]=A;nd=C>>>0>(A+1|0)>>>0?65535:I|255}else{nd=I}I=(nd<<M)+kd|0;c[Y>>2]=I;od=ld-16&65535;pd=I}else{od=ld;pd=kd}b[_>>1]=od;if(H){qd=0}else{I=7;M=1;A=pd;C=md;B=od;while(1){R=M<<1;rd=b[l>>1]|0;sd=rd&65535;td=C&65535;ud=(ca(sd,td)|0)>>>16;vd=A>>>16>>>0>=ud>>>0;wd=vd&1;if(vd){xd=A-(ud<<16)|0;yd=td-ud&65535}else{xd=A;yd=ud&65535}b[l>>1]=(b[8378640+(sd>>>8<<2)+(wd<<1)>>1]|0)+rd;c[Y>>2]=xd;b[y>>1]=yd;if((yd&65535)>>>0<16385>>>0){rd=xd;sd=yd;ud=B;do{rd=rd<<1;sd=sd<<1;ud=ud+1&65535;}while((sd&65535)>>>0<16385>>>0);c[Y>>2]=rd;b[y>>1]=sd;b[_>>1]=ud;zd=rd;Ad=ud;Bd=sd}else{zd=xd;Ad=B;Bd=yd}td=Ad<<16>>16;if(Ad<<16>>16>-1){vd=c[D>>2]|0;Cd=vd+2|0;c[D>>2]=Cd;Dd=vd;vd=(he((d[Dd]|d[Dd+1|0]<<8)<<16>>16|0)|0)&65535;Dd=c[Q>>2]|0;if(Cd>>>0>Dd>>>0){c[D>>2]=Dd;Ed=Cd>>>0>(Dd+1|0)>>>0?65535:vd|255}else{Ed=vd}vd=(Ed<<td)+zd|0;c[Y>>2]=vd;Fd=Ad-16&65535;Gd=vd}else{Fd=Ad;Gd=zd}b[_>>1]=Fd;Hd=wd|R;vd=d[1401960+I|0]|0;td=j+16+(vd<<1)|0;Dd=b[td>>1]|0;Cd=Dd&65535;Id=Bd&65535;Jd=(ca(Cd,Id)|0)>>>16;Kd=Gd>>>16>>>0>=Jd>>>0;if(Kd){Ld=Gd-(Jd<<16)|0;Md=Id-Jd&65535}else{Ld=Gd;Md=Jd&65535}b[td>>1]=(b[8378640+(Cd>>>8<<2)+((Kd&1)<<1)>>1]|0)+Dd;c[Y>>2]=Ld;b[y>>1]=Md;Dd=b[_>>1]|0;if((Md&65535)>>>0<16385>>>0){Cd=Ld;td=Md;Jd=Dd;do{Cd=Cd<<1;td=td<<1;Jd=Jd+1&65535;}while((td&65535)>>>0<16385>>>0);c[Y>>2]=Cd;b[y>>1]=td;b[_>>1]=Jd;Nd=Cd;Od=Jd;Pd=td}else{Nd=Ld;Od=Dd;Pd=Md}R=Od<<16>>16;if(Od<<16>>16>-1){wd=c[D>>2]|0;sd=wd+2|0;c[D>>2]=sd;ud=wd;wd=(he((d[ud]|d[ud+1|0]<<8)<<16>>16|0)|0)&65535;ud=c[Q>>2]|0;if(sd>>>0>ud>>>0){c[D>>2]=ud;Qd=sd>>>0>(ud+1|0)>>>0?65535:wd|255}else{Qd=wd}wd=(Qd<<R)+Nd|0;c[Y>>2]=wd;Rd=Od-16&65535;Sd=wd}else{Rd=Od;Sd=Nd}b[_>>1]=Rd;if(Kd){break}else{I=vd;M=Hd;A=Sd;C=Pd;B=Rd}}B=Hd-1|0;if(B>>>0>2>>>0){pa=-1;break f}else{qd=B}}B=S+O|0;do{if((O|v|0)==0){Td=0}else{if(N){Td=d[S+(O-1)|0]|0;break}if((O|0)==0){Td=d[S+(-J|0)|0]|0;break}else{Td=d[699896+((d[S+(O-J)|0]|0)+(d[S+(O-1)|0]|0)+(d[S+(O+~J)|0]|0))|0]|0;break}}}while(0);a[B]=((Td+qd|0)>>>0)%3|0;O=O+1|0;J=c[u>>2]|0;}while((O|0)<(J|0));Ud=J;Vd=c[z>>2]|0}else{Ud=Z;Vd=V}O=v+1|0;if((O|0)<(Vd|0)){v=O;S=S+Ud|0;Z=Ud;V=Vd}else{break e}}i=g;return pa|0}}while(0);x=c[n>>2]|0;fa=c[p>>2]|0;P=c[r>>2]|0;U=P+(x>>>3)|0;V=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(x&7);if((V&-1434451968|0)==0){U=1;Z=x;S=V;while(1){Wd=S>>>24;v=a[1369728+Wd|0]|0;Xd=v&255;_=((v&255)>>>0>8>>>0?8:Xd)+Z|0;Y=fa>>>0>_>>>0;Yd=Y?_:fa;if(!(v<<24>>24==9)){K=306;break}v=d[1369984+Wd|0]|U<<4;if(!(v>>>0<134217728>>>0)){Zd=v;break}_=P+(Yd>>>3)|0;D=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Yd&7);if(Y){U=v;Z=Yd;S=D}else{Zd=v;break}}if((K|0)==306){Zd=d[1369984+Wd|0]|U<<(Xd-1>>1)}c[n>>2]=Yd;_d=Zd-1|0}else{S=V>>>24;Z=(d[1369728+S|0]|0)+x|0;c[n>>2]=fa>>>0>Z>>>0?Z:fa;_d=d[1369216+S|0]|0}Sob(ba,m,_d);if((c[o>>2]|0)>0){S=0;while(1){Z=S<<1;P=j+((Z+4|0)*60|0)|0;v=c[n>>2]|0;D=c[p>>2]|0;Y=c[r>>2]|0;_=Y+(v>>>3)|0;Q=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(v&7);if((Q&-1434451968|0)==0){_=1;y=v;l=Q;while(1){$d=l>>>24;da=a[1369728+$d|0]|0;ae=da&255;T=((da&255)>>>0>8>>>0?8:ae)+y|0;W=D>>>0>T>>>0;be=W?T:D;if(!(da<<24>>24==9)){K=314;break}da=d[1369984+$d|0]|_<<4;if(!(da>>>0<134217728>>>0)){ce=da;break}T=Y+(be>>>3)|0;O=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(be&7);if(W){_=da;y=be;l=O}else{ce=da;break}}if((K|0)==314){K=0;ce=d[1369984+$d|0]|_<<(ae-1>>1)}c[n>>2]=be;de=ce-1|0}else{l=Q>>>24;y=(d[1369728+l|0]|0)+v|0;c[n>>2]=D>>>0>y>>>0?y:D;de=d[1369216+l|0]|0}Sob(P,m,de);l=j+((Z+5|0)*60|0)|0;y=c[n>>2]|0;Y=c[p>>2]|0;da=c[r>>2]|0;O=da+(y>>>3)|0;W=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(y&7);if((W&-1434451968|0)==0){O=1;T=y;N=W;while(1){ee=N>>>24;C=a[1369728+ee|0]|0;fe=C&255;A=((C&255)>>>0>8>>>0?8:fe)+T|0;M=Y>>>0>A>>>0;ge=M?A:Y;if(!(C<<24>>24==9)){K=321;break}C=d[1369984+ee|0]|O<<4;if(!(C>>>0<134217728>>>0)){ie=C;break}A=da+(ge>>>3)|0;I=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(ge&7);if(M){O=C;T=ge;N=I}else{ie=C;break}}if((K|0)==321){K=0;ie=d[1369984+ee|0]|O<<(fe-1>>1)}c[n>>2]=ge;ke=ie-1|0}else{N=W>>>24;T=(d[1369728+N|0]|0)+y|0;c[n>>2]=Y>>>0>T>>>0?T:Y;ke=d[1369216+N|0]|0}Sob(l,m,ke);N=S+1|0;if((N|0)<(c[o>>2]|0)){S=N}else{le=0;break}}}else{le=0}do{le=le+1|0;S=j+(le*60|0)|0;ba=c[n>>2]|0;fa=c[p>>2]|0;x=c[r>>2]|0;V=x+(ba>>>3)|0;U=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(ba&7);if((U&-1434451968|0)==0){V=1;N=ba;T=U;while(1){me=T>>>24;da=a[1369728+me|0]|0;ne=da&255;Z=((da&255)>>>0>8>>>0?8:ne)+N|0;P=fa>>>0>Z>>>0;oe=P?Z:fa;if(!(da<<24>>24==9)){K=331;break}da=d[1369984+me|0]|V<<4;if(!(da>>>0<134217728>>>0)){pe=da;break}Z=x+(oe>>>3)|0;D=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(oe&7);if(P){V=da;N=oe;T=D}else{pe=da;break}}if((K|0)==331){K=0;pe=d[1369984+me|0]|V<<(ne-1>>1)}c[n>>2]=oe;qe=pe-1|0}else{T=U>>>24;N=(d[1369728+T|0]|0)+ba|0;c[n>>2]=fa>>>0>N>>>0?N:fa;qe=d[1369216+T|0]|0}Sob(S,m,qe);}while((le|0)<3);T=c[z>>2]|0;if((T|0)<=0){break d}N=f+4220|0;x=j+16|0;l=j|0;Y=j+4|0;y=j+6|0;W=j+8|0;O=j+12|0;da=j+18|0;D=h|0;P=h+4|0;Z=h+8|0;v=j+20|0;Q=0;_=c[u>>2]|0;C=T;while(1){if((_|0)>0){T=Q<<2;I=0;M=_;while(1){A=(ca(M,Q)|0)+I|0;H=d[(c[aa>>2]|0)+A|0]|0;A=1<<H;L=4>>>(H>>>0);if((A|0)>0){H=I<<2;F=(L|0)>1;E=0;do{G=(ca(E,L)|0)+T|0;wd=(G|0)==0;R=0;do{ud=(ca(R,L)|0)+H|0;sd=c[k>>2]|0;rd=(ca(sd,G)|0)+ud|0;Id=c[N>>2]|0;re=Id+(rd*10|0)|0;se=(ud|G|0)==0;do{if(se){te=0}else{if(wd){te=a[Id+((rd-1|0)*10|0)+8|0]&1;break}if((ud|0)==0){te=a[Id+((rd-sd|0)*10|0)+8|0]&1;break}else{te=((a[Id+((rd-sd|0)*10|0)+8|0]&1)+(a[Id+((rd-1|0)*10|0)+8|0]&1)+(a[Id+((rd+~sd|0)*10|0)+8|0]&1)|0)>>>1&1;break}}}while(0);vd=Id+(rd*10|0)+8|0;a[vd]=te;Kd=b[x>>1]|0;Dd=Kd&65535;td=c[l>>2]|0;Jd=e[Y>>1]|0;Cd=(ca(Jd,Dd)|0)>>>16;ue=td>>>16>>>0>=Cd>>>0;ve=ue&1;if(ue){we=td-(Cd<<16)|0;xe=Jd-Cd&65535}else{we=td;xe=Cd&65535}b[x>>1]=(b[8378640+(Dd>>>8<<2)+(ve<<1)>>1]|0)+Kd;c[l>>2]=we;b[Y>>1]=xe;Kd=b[y>>1]|0;if((xe&65535)>>>0<16385>>>0){Dd=we;Cd=xe;td=Kd;do{Dd=Dd<<1;Cd=Cd<<1;td=td+1&65535;}while((Cd&65535)>>>0<16385>>>0);c[l>>2]=Dd;b[Y>>1]=Cd;b[y>>1]=td;ye=Dd;ze=td}else{ye=we;ze=Kd}Jd=ze<<16>>16;if(ze<<16>>16>-1){ue=c[W>>2]|0;Ae=ue+2|0;c[W>>2]=Ae;Be=ue;ue=(he((d[Be]|d[Be+1|0]<<8)<<16>>16|0)|0)&65535;Be=c[O>>2]|0;if(Ae>>>0>Be>>>0){c[W>>2]=Be;Ce=Ae>>>0>(Be+1|0)>>>0?65535:ue|255}else{Ce=ue}c[l>>2]=(Ce<<Jd)+ye;De=ze-16&65535}else{De=ze}b[y>>1]=De;Jd=d[vd]^ve;ue=Jd&255;a[vd]=ue;if((c[o>>2]|0)==2){do{if(se){Ee=0}else{if(wd){Ee=a[Id+((rd-1|0)*10|0)+8|0]&2;break}if((ud|0)==0){Ee=a[Id+((rd-sd|0)*10|0)+8|0]&2;break}else{Ee=((a[Id+((rd-sd|0)*10|0)+8|0]&2)+(a[Id+((rd-1|0)*10|0)+8|0]&2)+(a[Id+((rd+~sd|0)*10|0)+8|0]&2)|0)>>>1&2;break}}}while(0);a[vd]=Ee|Jd;ve=b[da>>1]|0;Kd=ve&65535;td=c[l>>2]|0;Dd=e[Y>>1]|0;Cd=(ca(Dd,Kd)|0)>>>16;Be=td>>>16>>>0>=Cd>>>0;Ae=Be&1;if(Be){Fe=td-(Cd<<16)|0;Ge=Dd-Cd&65535}else{Fe=td;Ge=Cd&65535}b[da>>1]=(b[8378640+(Kd>>>8<<2)+(Ae<<1)>>1]|0)+ve;c[l>>2]=Fe;b[Y>>1]=Ge;ve=b[y>>1]|0;if((Ge&65535)>>>0<16385>>>0){Kd=Fe;Cd=Ge;td=ve;do{Kd=Kd<<1;Cd=Cd<<1;td=td+1&65535;}while((Cd&65535)>>>0<16385>>>0);c[l>>2]=Kd;b[Y>>1]=Cd;b[y>>1]=td;He=Kd;Ie=td}else{He=Fe;Ie=ve}Jd=Ie<<16>>16;if(Ie<<16>>16>-1){Dd=c[W>>2]|0;Be=Dd+2|0;c[W>>2]=Be;Je=Dd;Dd=(he((d[Je]|d[Je+1|0]<<8)<<16>>16|0)|0)&65535;Je=c[O>>2]|0;if(Be>>>0>Je>>>0){c[W>>2]=Je;Ke=Be>>>0>(Je+1|0)>>>0?65535:Dd|255}else{Ke=Dd}c[l>>2]=(Ke<<Jd)+He;Le=Ie-16&65535}else{Le=Ie}b[y>>1]=Le;Jd=(d[vd]^Ae<<1)&255;a[vd]=Jd;Me=Jd}else{Me=ue}g:do{if(Me<<24>>24==0){mrc(re|0,0,6)|0;Jd=(ud|0)!=0;do{if(Jd){Dd=rd-1|0;if(!((a[Id+(Dd*10|0)+8|0]&3)==0)){Ne=0;Oe=0;Pe=0;Qe=0;break}Je=b[Id+(Dd*10|0)>>1]|0;b[re>>1]=Je;Be=b[Id+(Dd*10|0)+2>>1]|0;b[Id+(rd*10|0)+2>>1]=Be;Re=b[Id+(Dd*10|0)+4>>1]|0;b[Id+(rd*10|0)+4>>1]=Re;Ne=1;Oe=Je;Pe=Be;Qe=Re}else{Ne=0;Oe=0;Pe=0;Qe=0}}while(0);do{if(wd){Se=Ne;Te=Oe;Ue=Pe;Ve=Qe}else{Re=rd-sd|0;if((a[Id+(Re*10|0)+8|0]&3)==0){Be=(b[Id+(Re*10|0)>>1]|0)+Oe&65535;b[re>>1]=Be;Je=(b[Id+(Re*10|0)+2>>1]|0)+Pe&65535;b[Id+(rd*10|0)+2>>1]=Je;Dd=(b[Id+(Re*10|0)+4>>1]|0)+Qe&65535;b[Id+(rd*10|0)+4>>1]=Dd;We=Ne+1|0;Xe=Be;Ye=Je;Ze=Dd}else{We=Ne;Xe=Oe;Ye=Pe;Ze=Qe}if(!Jd){Se=We;Te=Xe;Ue=Ye;Ve=Ze;break}Dd=rd+~sd|0;if(!((a[Id+(Dd*10|0)+8|0]&3)==0)){Se=We;Te=Xe;Ue=Ye;Ve=Ze;break}Je=(b[Id+(Dd*10|0)>>1]|0)+Xe&65535;b[re>>1]=Je;Be=(b[Id+(Dd*10|0)+2>>1]|0)+Ye&65535;b[Id+(rd*10|0)+2>>1]=Be;Re=(b[Id+(Dd*10|0)+4>>1]|0)+Ze&65535;b[Id+(rd*10|0)+4>>1]=Re;Se=We+1|0;Te=Je;Ue=Be;Ve=Re}}while(0);if((Se|0)==3){b[re>>1]=(((Te<<16>>16)*21845|0)+32767|0)>>>16;b[Id+(rd*10|0)+2>>1]=(((Ue<<16>>16)*21845|0)+32767|0)>>>16;b[Id+(rd*10|0)+4>>1]=(((Ve<<16>>16)*21845|0)+32767|0)>>>16}else if((Se|0)==2){b[re>>1]=((Te<<16>>16)+1|0)>>>1;b[Id+(rd*10|0)+2>>1]=((Ue<<16>>16)+1|0)>>>1;b[Id+(rd*10|0)+4>>1]=((Ve<<16>>16)+1|0)>>>1}Jd=re;Re=0;while(1){Be=Re+1|0;Je=j+(Be*60|0)+30|0;Dd=b[Je>>1]|0;_e=Dd&65535;$e=j+(Be*60|0)|0;af=c[$e>>2]|0;bf=j+(Be*60|0)+4|0;cf=e[bf>>1]|0;df=(ca(cf,_e)|0)>>>16;ef=af>>>16>>>0>=df>>>0;if(ef){ff=af-(df<<16)|0;gf=cf-df&65535}else{ff=af;gf=df&65535}b[Je>>1]=(b[8378640+(_e>>>8<<2)+((ef&1)<<1)>>1]|0)+Dd;c[$e>>2]=ff;b[bf>>1]=gf;Dd=j+(Be*60|0)+6|0;_e=b[Dd>>1]|0;if((gf&65535)>>>0<16385>>>0){Je=ff;df=gf;af=_e;do{Je=Je<<1;df=df<<1;af=af+1&65535;}while((df&65535)>>>0<16385>>>0);c[$e>>2]=Je;b[bf>>1]=df;b[Dd>>1]=af;hf=Je;jf=af;kf=df}else{hf=ff;jf=_e;kf=gf}cf=jf<<16>>16;if(jf<<16>>16>-1){lf=j+(Be*60|0)+8|0;mf=c[lf>>2]|0;nf=mf+2|0;c[lf>>2]=nf;of=mf;mf=(he((d[of]|d[of+1|0]<<8)<<16>>16|0)|0)&65535;of=c[j+(Be*60|0)+12>>2]|0;if(nf>>>0>of>>>0){c[lf>>2]=of;pf=nf>>>0>(of+1|0)>>>0?65535:mf|255}else{pf=mf}mf=(pf<<cf)+hf|0;c[$e>>2]=mf;qf=jf-16&65535;rf=mf}else{qf=jf;rf=hf}b[Dd>>1]=qf;do{if(ef){sf=0}else{mf=j+(Be*60|0)+16|0;cf=j+(Be*60|0)+8|0;of=j+(Be*60|0)+12|0;nf=7;lf=1;tf=rf;uf=kf;vf=qf;while(1){wf=lf<<1;xf=b[mf>>1]|0;yf=xf&65535;zf=uf&65535;Af=(ca(yf,zf)|0)>>>16;Bf=tf>>>16>>>0>=Af>>>0;Cf=Bf&1;if(Bf){Df=tf-(Af<<16)|0;Ef=zf-Af&65535}else{Df=tf;Ef=Af&65535}b[mf>>1]=(b[8378640+(yf>>>8<<2)+(Cf<<1)>>1]|0)+xf;c[$e>>2]=Df;b[bf>>1]=Ef;if((Ef&65535)>>>0<16385>>>0){xf=Df;yf=Ef;Af=vf;do{xf=xf<<1;yf=yf<<1;Af=Af+1&65535;}while((yf&65535)>>>0<16385>>>0);c[$e>>2]=xf;b[bf>>1]=yf;b[Dd>>1]=Af;Ff=xf;Gf=Af;Hf=yf}else{Ff=Df;Gf=vf;Hf=Ef}zf=Gf<<16>>16;if(Gf<<16>>16>-1){Bf=c[cf>>2]|0;If=Bf+2|0;c[cf>>2]=If;Jf=Bf;Bf=(he((d[Jf]|d[Jf+1|0]<<8)<<16>>16|0)|0)&65535;Jf=c[of>>2]|0;if(If>>>0>Jf>>>0){c[cf>>2]=Jf;Kf=If>>>0>(Jf+1|0)>>>0?65535:Bf|255}else{Kf=Bf}Bf=(Kf<<zf)+Ff|0;c[$e>>2]=Bf;Lf=Gf-16&65535;Mf=Bf}else{Lf=Gf;Mf=Ff}b[Dd>>1]=Lf;Nf=Cf|wf;Bf=d[1401960+nf|0]|0;zf=j+(Be*60|0)+16+(Bf<<1)|0;Jf=b[zf>>1]|0;If=Jf&65535;Of=Hf&65535;Pf=(ca(If,Of)|0)>>>16;Qf=Mf>>>16>>>0>=Pf>>>0;if(Qf){Rf=Mf-(Pf<<16)|0;Sf=Of-Pf&65535}else{Rf=Mf;Sf=Pf&65535}b[zf>>1]=(b[8378640+(If>>>8<<2)+((Qf&1)<<1)>>1]|0)+Jf;c[$e>>2]=Rf;b[bf>>1]=Sf;Jf=b[Dd>>1]|0;if((Sf&65535)>>>0<16385>>>0){If=Rf;zf=Sf;Pf=Jf;do{If=If<<1;zf=zf<<1;Pf=Pf+1&65535;}while((zf&65535)>>>0<16385>>>0);c[$e>>2]=If;b[bf>>1]=zf;b[Dd>>1]=Pf;Tf=If;Uf=Pf;Vf=zf}else{Tf=Rf;Uf=Jf;Vf=Sf}wf=Uf<<16>>16;if(Uf<<16>>16>-1){Cf=c[cf>>2]|0;yf=Cf+2|0;c[cf>>2]=yf;Af=Cf;Cf=(he((d[Af]|d[Af+1|0]<<8)<<16>>16|0)|0)&65535;Af=c[of>>2]|0;if(yf>>>0>Af>>>0){c[cf>>2]=Af;Wf=yf>>>0>(Af+1|0)>>>0?65535:Cf|255}else{Wf=Cf}Cf=(Wf<<wf)+Tf|0;c[$e>>2]=Cf;Xf=Uf-16&65535;Yf=Cf}else{Xf=Uf;Yf=Tf}b[Dd>>1]=Xf;if(Qf){break}else{nf=Bf;lf=Nf;tf=Yf;uf=Vf;vf=Xf}}vf=Nf-1|0;if((vf|0)==0){sf=0;break}uf=j+(Be*60|0)+18|0;tf=b[uf>>1]|0;lf=tf&65535;nf=Vf&65535;mf=(ca(lf,nf)|0)>>>16;Cf=Yf>>>16>>>0>=mf>>>0;if(Cf){Zf=Yf-(mf<<16)|0;_f=nf-mf&65535}else{Zf=Yf;_f=mf&65535}b[uf>>1]=(b[8378640+(lf>>>8<<2)+((Cf&1)<<1)>>1]|0)+tf;c[$e>>2]=Zf;b[bf>>1]=_f;if((_f&65535)>>>0<16385>>>0){tf=Zf;lf=_f;uf=Xf;do{tf=tf<<1;lf=lf<<1;uf=uf+1&65535;}while((lf&65535)>>>0<16385>>>0);c[$e>>2]=tf;b[bf>>1]=lf;b[Dd>>1]=uf;$f=tf;ag=uf}else{$f=Zf;ag=Xf}mf=ag<<16>>16;if(ag<<16>>16>-1){nf=c[cf>>2]|0;wf=nf+2|0;c[cf>>2]=wf;Af=nf;nf=(he((d[Af]|d[Af+1|0]<<8)<<16>>16|0)|0)&65535;Af=c[of>>2]|0;if(wf>>>0>Af>>>0){c[cf>>2]=Af;bg=wf>>>0>(Af+1|0)>>>0?65535:nf|255}else{bg=nf}c[$e>>2]=(bg<<mf)+$f;cg=ag-16&65535}else{cg=ag}b[Dd>>1]=cg;sf=Cf?1-Nf|0:vf}}while(0);Dd=Jd+(Re<<1)|0;b[Dd>>1]=(e[Dd>>1]|0)+sf;if((Be|0)<3){Re=Be}else{break}}}else{if((c[$>>2]|0)==0){dg=Me}else{do{if(se){eg=0}else{if(wd){eg=a[Id+((rd-1|0)*10|0)+8|0]&4;break}if((ud|0)==0){eg=a[Id+((rd-sd|0)*10|0)+8|0]&4;break}else{eg=((a[Id+((rd-sd|0)*10|0)+8|0]&4)+(a[Id+((rd-1|0)*10|0)+8|0]&4)+(a[Id+((rd+~sd|0)*10|0)+8|0]&4)|0)>>>1&4;break}}}while(0);a[vd]=eg|Me&255;Re=b[v>>1]|0;Jd=Re&65535;Dd=c[l>>2]|0;$e=e[Y>>1]|0;bf=(ca($e,Jd)|0)>>>16;ef=Dd>>>16>>>0>=bf>>>0;_e=ef&1;if(ef){fg=Dd-(bf<<16)|0;gg=$e-bf&65535}else{fg=Dd;gg=bf&65535}b[v>>1]=(b[8378640+(Jd>>>8<<2)+(_e<<1)>>1]|0)+Re;c[l>>2]=fg;b[Y>>1]=gg;Re=b[y>>1]|0;if((gg&65535)>>>0<16385>>>0){Jd=fg;bf=gg;Dd=Re;do{Jd=Jd<<1;bf=bf<<1;Dd=Dd+1&65535;}while((bf&65535)>>>0<16385>>>0);c[l>>2]=Jd;b[Y>>1]=bf;b[y>>1]=Dd;hg=Jd;ig=Dd}else{hg=fg;ig=Re}$e=ig<<16>>16;if(ig<<16>>16>-1){ef=c[W>>2]|0;df=ef+2|0;c[W>>2]=df;af=ef;ef=(he((d[af]|d[af+1|0]<<8)<<16>>16|0)|0)&65535;af=c[O>>2]|0;if(df>>>0>af>>>0){c[W>>2]=af;jg=df>>>0>(af+1|0)>>>0?65535:ef|255}else{jg=ef}c[l>>2]=(jg<<$e)+hg;kg=ig-16&65535}else{kg=ig}b[y>>1]=kg;$e=(d[vd]^_e<<2)&255;a[vd]=$e;dg=$e}$e=c[o>>2]|0;if(($e|0)<=0){break}ef=(ud|0)!=0;af=rd-1|0;df=Id+(af*10|0)+8|0;Je=rd-sd|0;mf=Id+(Je*10|0)+8|0;nf=rd+~sd|0;Af=Id+(nf*10|0)+8|0;wf=0;yf=dg;while(1){xf=yf&255;Of=wf+1|0;do{if((Of&xf|0)!=0){if((xf&4|0)!=0){lg=c[f+4108+(wf*40|0)+32>>2]|0;mg=c[f+4108+(wf*40|0)+36>>2]|0;ng=ca(c[f+4108+(wf*40|0)+24>>2]|0,ud)|0;og=(1<<mg)-ng-(ca(c[f+4108+(wf*40|0)+28>>2]|0,G)|0)|0;ng=ca(c[f+4108+(wf*40|0)+8>>2]|0,ud)|0;pg=(ca(c[f+4108+(wf*40|0)+12>>2]|0,G)|0)+ng|0;ng=ca(pg+(c[f+4108+(wf*40|0)>>2]<<lg)|0,og)|0;pg=ca(c[f+4108+(wf*40|0)+16>>2]|0,ud)|0;qg=(ca(c[f+4108+(wf*40|0)+20>>2]|0,G)|0)+pg|0;pg=ca(qg+(c[f+4108+(wf*40|0)+4>>2]<<lg)|0,og)|0;og=mg+lg|0;lg=1<<og;b[Id+(rd*10|0)+(wf<<2)>>1]=ng+lg>>og;b[Id+(rd*10|0)+(wf<<2)+2>>1]=pg+lg>>og;break}og=Of|4;do{if(ef){if((d[df]&og|0)!=(Of|0)){rg=0;break}c[D>>2]=Id+(af*10|0)+(wf<<2);rg=1}else{rg=0}}while(0);do{if(wd){sg=rg}else{if((d[mf]&og|0)==(Of|0)){c[h+(rg<<2)>>2]=Id+(Je*10|0)+(wf<<2);tg=rg+1|0}else{tg=rg}if(!ef){sg=tg;break}if((d[Af]&og|0)!=(Of|0)){sg=tg;break}c[h+(tg<<2)>>2]=Id+(nf*10|0)+(wf<<2);sg=tg+1|0}}while(0);if((sg|0)==0){b[Id+(rd*10|0)+(wf<<2)>>1]=0;b[Id+(rd*10|0)+(wf<<2)+2>>1]=0}else if((sg|0)==1){og=c[D>>2]|0;b[Id+(rd*10|0)+(wf<<2)>>1]=b[og>>1]|0;b[Id+(rd*10|0)+(wf<<2)+2>>1]=b[og+2>>1]|0}else if((sg|0)==2){og=c[D>>2]|0;vf=c[P>>2]|0;b[Id+(rd*10|0)+(wf<<2)>>1]=((b[og>>1]|0)+1+(b[vf>>1]|0)|0)>>>1;b[Id+(rd*10|0)+(wf<<2)+2>>1]=((b[og+2>>1]|0)+1+(b[vf+2>>1]|0)|0)>>>1}else if((sg|0)==3){vf=c[D>>2]|0;og=b[vf>>1]|0;Cf=c[P>>2]|0;cf=b[Cf>>1]|0;of=c[Z>>2]|0;uf=b[of>>1]|0;do{if(og<<16>>16>cf<<16>>16){if(!(uf<<16>>16>cf<<16>>16)){ug=cf;break}ug=uf<<16>>16>og<<16>>16?og:uf}else{if(!(cf<<16>>16>uf<<16>>16)){ug=cf;break}ug=uf<<16>>16>og<<16>>16?uf:og}}while(0);b[Id+(rd*10|0)+(wf<<2)>>1]=ug;og=b[vf+2>>1]|0;uf=b[Cf+2>>1]|0;cf=b[of+2>>1]|0;do{if(og<<16>>16>uf<<16>>16){if(!(cf<<16>>16>uf<<16>>16)){vg=uf;break}vg=cf<<16>>16>og<<16>>16?og:cf}else{if(!(uf<<16>>16>cf<<16>>16)){vg=uf;break}vg=cf<<16>>16>og<<16>>16?cf:og}}while(0);b[Id+(rd*10|0)+(wf<<2)+2>>1]=vg}og=wf<<1;cf=og+4|0;uf=j+(cf*60|0)+24|0;of=b[uf>>1]|0;Cf=of&65535;vf=j+(cf*60|0)|0;tf=c[vf>>2]|0;lf=j+(cf*60|0)+4|0;lg=e[lf>>1]|0;pg=(ca(lg,Cf)|0)>>>16;ng=tf>>>16>>>0>=pg>>>0;if(ng){wg=tf-(pg<<16)|0;xg=lg-pg&65535}else{wg=tf;xg=pg&65535}b[uf>>1]=(b[8378640+(Cf>>>8<<2)+((ng&1)<<1)>>1]|0)+of;c[vf>>2]=wg;b[lf>>1]=xg;of=j+(cf*60|0)+6|0;Cf=b[of>>1]|0;if((xg&65535)>>>0<16385>>>0){uf=wg;pg=xg;tf=Cf;do{uf=uf<<1;pg=pg<<1;tf=tf+1&65535;}while((pg&65535)>>>0<16385>>>0);c[vf>>2]=uf;b[lf>>1]=pg;b[of>>1]=tf;yg=uf;zg=tf;Ag=pg}else{yg=wg;zg=Cf;Ag=xg}lg=zg<<16>>16;if(zg<<16>>16>-1){mg=j+(cf*60|0)+8|0;qg=c[mg>>2]|0;Bg=qg+2|0;c[mg>>2]=Bg;Cg=qg;qg=(he((d[Cg]|d[Cg+1|0]<<8)<<16>>16|0)|0)&65535;Cg=c[j+(cf*60|0)+12>>2]|0;if(Bg>>>0>Cg>>>0){c[mg>>2]=Cg;Dg=Bg>>>0>(Cg+1|0)>>>0?65535:qg|255}else{Dg=qg}qg=(Dg<<lg)+yg|0;c[vf>>2]=qg;Eg=zg-16&65535;Fg=qg}else{Eg=zg;Fg=yg}b[of>>1]=Eg;do{if(ng){Gg=0}else{qg=j+(cf*60|0)+16|0;lg=j+(cf*60|0)+8|0;Cg=j+(cf*60|0)+12|0;Bg=4;mg=1;Hg=Fg;Ig=Ag;Jg=Eg;while(1){Kg=mg<<1;Lg=b[qg>>1]|0;Mg=Lg&65535;Ng=Ig&65535;Og=(ca(Mg,Ng)|0)>>>16;Pg=Hg>>>16>>>0>=Og>>>0;Qg=Pg&1;if(Pg){Rg=Hg-(Og<<16)|0;Sg=Ng-Og&65535}else{Rg=Hg;Sg=Og&65535}b[qg>>1]=(b[8378640+(Mg>>>8<<2)+(Qg<<1)>>1]|0)+Lg;c[vf>>2]=Rg;b[lf>>1]=Sg;if((Sg&65535)>>>0<16385>>>0){Lg=Rg;Mg=Sg;Og=Jg;do{Lg=Lg<<1;Mg=Mg<<1;Og=Og+1&65535;}while((Mg&65535)>>>0<16385>>>0);c[vf>>2]=Lg;b[lf>>1]=Mg;b[of>>1]=Og;Tg=Lg;Ug=Og;Vg=Mg}else{Tg=Rg;Ug=Jg;Vg=Sg}Ng=Ug<<16>>16;if(Ug<<16>>16>-1){Pg=c[lg>>2]|0;Wg=Pg+2|0;c[lg>>2]=Wg;Xg=Pg;Pg=(he((d[Xg]|d[Xg+1|0]<<8)<<16>>16|0)|0)&65535;Xg=c[Cg>>2]|0;if(Wg>>>0>Xg>>>0){c[lg>>2]=Xg;Yg=Wg>>>0>(Xg+1|0)>>>0?65535:Pg|255}else{Yg=Pg}Pg=(Yg<<Ng)+Tg|0;c[vf>>2]=Pg;Zg=Ug-16&65535;_g=Pg}else{Zg=Ug;_g=Tg}b[of>>1]=Zg;$g=Qg|Kg;Pg=d[1401960+Bg|0]|0;Ng=j+(cf*60|0)+16+(Pg<<1)|0;Xg=b[Ng>>1]|0;Wg=Xg&65535;ah=Vg&65535;bh=(ca(Wg,ah)|0)>>>16;ch=_g>>>16>>>0>=bh>>>0;if(ch){dh=_g-(bh<<16)|0;eh=ah-bh&65535}else{dh=_g;eh=bh&65535}b[Ng>>1]=(b[8378640+(Wg>>>8<<2)+((ch&1)<<1)>>1]|0)+Xg;c[vf>>2]=dh;b[lf>>1]=eh;Xg=b[of>>1]|0;if((eh&65535)>>>0<16385>>>0){Wg=dh;Ng=eh;bh=Xg;do{Wg=Wg<<1;Ng=Ng<<1;bh=bh+1&65535;}while((Ng&65535)>>>0<16385>>>0);c[vf>>2]=Wg;b[lf>>1]=Ng;b[of>>1]=bh;fh=Wg;gh=bh;hh=Ng}else{fh=dh;gh=Xg;hh=eh}Kg=gh<<16>>16;if(gh<<16>>16>-1){Qg=c[lg>>2]|0;Mg=Qg+2|0;c[lg>>2]=Mg;Og=Qg;Qg=(he((d[Og]|d[Og+1|0]<<8)<<16>>16|0)|0)&65535;Og=c[Cg>>2]|0;if(Mg>>>0>Og>>>0){c[lg>>2]=Og;ih=Mg>>>0>(Og+1|0)>>>0?65535:Qg|255}else{ih=Qg}Qg=(ih<<Kg)+fh|0;c[vf>>2]=Qg;jh=gh-16&65535;kh=Qg}else{jh=gh;kh=fh}b[of>>1]=jh;if(ch){break}else{Bg=Pg;mg=$g;Hg=kh;Ig=hh;Jg=jh}}Jg=$g-1|0;if((Jg|0)==0){Gg=0;break}Ig=j+(cf*60|0)+18|0;Hg=b[Ig>>1]|0;mg=Hg&65535;Bg=hh&65535;qg=(ca(mg,Bg)|0)>>>16;Bf=kh>>>16>>>0>=qg>>>0;if(Bf){lh=kh-(qg<<16)|0;mh=Bg-qg&65535}else{lh=kh;mh=qg&65535}b[Ig>>1]=(b[8378640+(mg>>>8<<2)+((Bf&1)<<1)>>1]|0)+Hg;c[vf>>2]=lh;b[lf>>1]=mh;if((mh&65535)>>>0<16385>>>0){Hg=lh;mg=mh;Ig=jh;do{Hg=Hg<<1;mg=mg<<1;Ig=Ig+1&65535;}while((mg&65535)>>>0<16385>>>0);c[vf>>2]=Hg;b[lf>>1]=mg;b[of>>1]=Ig;nh=Hg;oh=Ig}else{nh=lh;oh=jh}qg=oh<<16>>16;if(oh<<16>>16>-1){Bg=c[lg>>2]|0;Qf=Bg+2|0;c[lg>>2]=Qf;Jf=Bg;Bg=(he((d[Jf]|d[Jf+1|0]<<8)<<16>>16|0)|0)&65535;Jf=c[Cg>>2]|0;if(Qf>>>0>Jf>>>0){c[lg>>2]=Jf;ph=Qf>>>0>(Jf+1|0)>>>0?65535:Bg|255}else{ph=Bg}c[vf>>2]=(ph<<qg)+nh;qh=oh-16&65535}else{qh=oh}b[of>>1]=qh;Gg=Bf?1-$g|0:Jg}}while(0);of=Id+(rd*10|0)+(wf<<2)|0;b[of>>1]=(e[of>>1]|0)+Gg;of=og+5|0;vf=j+(of*60|0)+24|0;lf=b[vf>>1]|0;cf=lf&65535;ng=j+(of*60|0)|0;Cf=c[ng>>2]|0;pg=j+(of*60|0)+4|0;tf=e[pg>>1]|0;uf=(ca(tf,cf)|0)>>>16;qg=Cf>>>16>>>0>=uf>>>0;if(qg){rh=Cf-(uf<<16)|0;sh=tf-uf&65535}else{rh=Cf;sh=uf&65535}b[vf>>1]=(b[8378640+(cf>>>8<<2)+((qg&1)<<1)>>1]|0)+lf;c[ng>>2]=rh;b[pg>>1]=sh;lf=j+(of*60|0)+6|0;cf=b[lf>>1]|0;if((sh&65535)>>>0<16385>>>0){vf=rh;uf=sh;Cf=cf;do{vf=vf<<1;uf=uf<<1;Cf=Cf+1&65535;}while((uf&65535)>>>0<16385>>>0);c[ng>>2]=vf;b[pg>>1]=uf;b[lf>>1]=Cf;th=vf;uh=Cf;vh=uf}else{th=rh;uh=cf;vh=sh}og=uh<<16>>16;if(uh<<16>>16>-1){tf=j+(of*60|0)+8|0;Bg=c[tf>>2]|0;Jf=Bg+2|0;c[tf>>2]=Jf;Qf=Bg;Bg=(he((d[Qf]|d[Qf+1|0]<<8)<<16>>16|0)|0)&65535;Qf=c[j+(of*60|0)+12>>2]|0;if(Jf>>>0>Qf>>>0){c[tf>>2]=Qf;wh=Jf>>>0>(Qf+1|0)>>>0?65535:Bg|255}else{wh=Bg}Bg=(wh<<og)+th|0;c[ng>>2]=Bg;xh=uh-16&65535;yh=Bg}else{xh=uh;yh=th}b[lf>>1]=xh;do{if(qg){zh=0}else{Bg=j+(of*60|0)+16|0;og=j+(of*60|0)+8|0;Qf=j+(of*60|0)+12|0;Jf=4;tf=1;zf=yh;Pf=vh;If=xh;while(1){Qg=tf<<1;Kg=b[Bg>>1]|0;Og=Kg&65535;Mg=Pf&65535;Lg=(ca(Og,Mg)|0)>>>16;ah=zf>>>16>>>0>=Lg>>>0;Ah=ah&1;if(ah){Bh=zf-(Lg<<16)|0;Ch=Mg-Lg&65535}else{Bh=zf;Ch=Lg&65535}b[Bg>>1]=(b[8378640+(Og>>>8<<2)+(Ah<<1)>>1]|0)+Kg;c[ng>>2]=Bh;b[pg>>1]=Ch;if((Ch&65535)>>>0<16385>>>0){Kg=Bh;Og=Ch;Lg=If;do{Kg=Kg<<1;Og=Og<<1;Lg=Lg+1&65535;}while((Og&65535)>>>0<16385>>>0);c[ng>>2]=Kg;b[pg>>1]=Og;b[lf>>1]=Lg;Dh=Kg;Eh=Lg;Fh=Og}else{Dh=Bh;Eh=If;Fh=Ch}Pg=Eh<<16>>16;if(Eh<<16>>16>-1){ch=c[og>>2]|0;Xg=ch+2|0;c[og>>2]=Xg;Ng=ch;ch=(he((d[Ng]|d[Ng+1|0]<<8)<<16>>16|0)|0)&65535;Ng=c[Qf>>2]|0;if(Xg>>>0>Ng>>>0){c[og>>2]=Ng;Gh=Xg>>>0>(Ng+1|0)>>>0?65535:ch|255}else{Gh=ch}ch=(Gh<<Pg)+Dh|0;c[ng>>2]=ch;Hh=Eh-16&65535;Ih=ch}else{Hh=Eh;Ih=Dh}b[lf>>1]=Hh;Jh=Ah|Qg;ch=d[1401960+Jf|0]|0;Pg=j+(of*60|0)+16+(ch<<1)|0;Ng=b[Pg>>1]|0;Xg=Ng&65535;bh=Fh&65535;Wg=(ca(Xg,bh)|0)>>>16;Mg=Ih>>>16>>>0>=Wg>>>0;if(Mg){Kh=Ih-(Wg<<16)|0;Lh=bh-Wg&65535}else{Kh=Ih;Lh=Wg&65535}b[Pg>>1]=(b[8378640+(Xg>>>8<<2)+((Mg&1)<<1)>>1]|0)+Ng;c[ng>>2]=Kh;b[pg>>1]=Lh;Ng=b[lf>>1]|0;if((Lh&65535)>>>0<16385>>>0){Xg=Kh;Pg=Lh;Wg=Ng;do{Xg=Xg<<1;Pg=Pg<<1;Wg=Wg+1&65535;}while((Pg&65535)>>>0<16385>>>0);c[ng>>2]=Xg;b[pg>>1]=Pg;b[lf>>1]=Wg;Mh=Xg;Nh=Wg;Oh=Pg}else{Mh=Kh;Nh=Ng;Oh=Lh}Qg=Nh<<16>>16;if(Nh<<16>>16>-1){Ah=c[og>>2]|0;Og=Ah+2|0;c[og>>2]=Og;Lg=Ah;Ah=(he((d[Lg]|d[Lg+1|0]<<8)<<16>>16|0)|0)&65535;Lg=c[Qf>>2]|0;if(Og>>>0>Lg>>>0){c[og>>2]=Lg;Ph=Og>>>0>(Lg+1|0)>>>0?65535:Ah|255}else{Ph=Ah}Ah=(Ph<<Qg)+Mh|0;c[ng>>2]=Ah;Qh=Nh-16&65535;Rh=Ah}else{Qh=Nh;Rh=Mh}b[lf>>1]=Qh;if(Mg){break}else{Jf=ch;tf=Jh;zf=Rh;Pf=Oh;If=Qh}}If=Jh-1|0;if((If|0)==0){zh=0;break}Pf=j+(of*60|0)+18|0;zf=b[Pf>>1]|0;tf=zf&65535;Jf=Oh&65535;Bg=(ca(tf,Jf)|0)>>>16;Jg=Rh>>>16>>>0>=Bg>>>0;if(Jg){Sh=Rh-(Bg<<16)|0;Th=Jf-Bg&65535}else{Sh=Rh;Th=Bg&65535}b[Pf>>1]=(b[8378640+(tf>>>8<<2)+((Jg&1)<<1)>>1]|0)+zf;c[ng>>2]=Sh;b[pg>>1]=Th;if((Th&65535)>>>0<16385>>>0){zf=Sh;tf=Th;Pf=Qh;do{zf=zf<<1;tf=tf<<1;Pf=Pf+1&65535;}while((tf&65535)>>>0<16385>>>0);c[ng>>2]=zf;b[pg>>1]=tf;b[lf>>1]=Pf;Uh=zf;Vh=Pf}else{Uh=Sh;Vh=Qh}Bg=Vh<<16>>16;if(Vh<<16>>16>-1){Jf=c[og>>2]|0;Bf=Jf+2|0;c[og>>2]=Bf;lg=Jf;Jf=(he((d[lg]|d[lg+1|0]<<8)<<16>>16|0)|0)&65535;lg=c[Qf>>2]|0;if(Bf>>>0>lg>>>0){c[og>>2]=lg;Wh=Bf>>>0>(lg+1|0)>>>0?65535:Jf|255}else{Wh=Jf}c[ng>>2]=(Wh<<Bg)+Uh;Xh=Vh-16&65535}else{Xh=Vh}b[lf>>1]=Xh;zh=Jg?1-Jh|0:If}}while(0);lf=Id+(rd*10|0)+(wf<<2)+2|0;b[lf>>1]=(e[lf>>1]|0)+zh}}while(0);if((Of|0)>=($e|0)){break g}wf=Of;yf=a[vd]|0}}}while(0);vd=c[k>>2]|0;if(F){ud=re;sd=1;while(1){se=Id+((sd+rd|0)*10|0)|0;b[se>>1]=b[ud>>1]|0;b[se+2>>1]=b[ud+2>>1]|0;b[se+4>>1]=b[ud+4>>1]|0;b[se+6>>1]=b[ud+6>>1]|0;b[se+8>>1]=b[ud+8>>1]|0;se=sd+1|0;if((se|0)<(L|0)){sd=se}else{Yh=1;Zh=re;break}}while(1){re=0;do{sd=Zh+((re+vd|0)*10|0)|0;b[sd>>1]=b[ud>>1]|0;b[sd+2>>1]=b[ud+2>>1]|0;b[sd+4>>1]=b[ud+4>>1]|0;b[sd+6>>1]=b[ud+6>>1]|0;b[sd+8>>1]=b[ud+8>>1]|0;re=re+1|0;}while((re|0)<(L|0));re=Yh+1|0;if((re|0)<(L|0)){Yh=re;Zh=Zh+(vd*10|0)|0}else{break}}}R=R+1|0;}while((R|0)<(A|0));E=E+1|0;}while((E|0)<(A|0));_h=c[u>>2]|0}else{_h=M}A=I+1|0;if((A|0)<(_h|0)){I=A;M=_h}else{break}}$h=_h;ai=c[z>>2]|0}else{$h=_;ai=C}M=Q+1|0;if((M|0)<(ai|0)){Q=M;_=$h;C=ai}else{break d}}}}while(0);KIb(c[s>>2]|0,16,2431128,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}}while(0);ai=c[n>>2]|0;$h=-ai&7;if(($h|0)==0){bi=ai}else{_h=c[p>>2]|0;Zh=$h+ai|0;ai=_h>>>0>Zh>>>0?Zh:_h;c[n>>2]=ai;bi=ai}do{if((c[o>>2]|0)==0){c[f+3988>>2]=0;ci=bi;di=c[p>>2]|0;ei=c[r>>2]|0;K=578}else{ai=c[r>>2]|0;_h=d[ai+(bi>>>3)|0]<<(bi&7)>>>7;Zh=c[p>>2]|0;$h=((bi|0)<(Zh|0))+bi|0;c[n>>2]=$h;Yh=_h&1;c[f+3988>>2]=Yh;if((Yh|0)==0){ci=$h;di=Zh;ei=ai;K=578;break}fi=f+4008|0}}while(0);h:do{if((K|0)==578){bi=ei+(ci>>>3)|0;o=(je(d[bi]|d[bi+1|0]<<8|d[bi+2|0]<<16|d[bi+3|0]<<24|0)|0)<<(ci&7);if((o&-1434451968|0)==0){bi=1;ai=ci;Zh=o;while(1){gi=Zh>>>24;$h=a[1369728+gi|0]|0;hi=$h&255;Yh=(($h&255)>>>0>8>>>0?8:hi)+ai|0;_h=di>>>0>Yh>>>0;ii=_h?Yh:di;if(!($h<<24>>24==9)){K=581;break}$h=d[1369984+gi|0]|bi<<4;if(!($h>>>0<134217728>>>0)){ji=$h;break}Yh=ei+(ii>>>3)|0;zh=(je(d[Yh]|d[Yh+1|0]<<8|d[Yh+2|0]<<16|d[Yh+3|0]<<24|0)|0)<<(ii&7);if(_h){bi=$h;ai=ii;Zh=zh}else{ji=$h;break}}if((K|0)==581){ji=d[1369984+gi|0]|bi<<(hi-1>>1)}c[n>>2]=ii;ki=ji-1|0;li=ii}else{Zh=o>>>24;ai=(d[1369728+Zh|0]|0)+ci|0;$h=di>>>0>ai>>>0?ai:di;c[n>>2]=$h;ki=d[1369216+Zh|0]|0;li=$h}if(ki>>>0>6>>>0){KIb(c[s>>2]|0,16,2550928,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}$h=f+4012|0;c[$h>>2]=ki;Zh=ei+(li>>>3)|0;ai=(je(d[Zh]|d[Zh+1|0]<<8|d[Zh+2|0]<<16|d[Zh+3|0]<<24|0)|0)<<(li&7);if((ai&-1434451968|0)==0){Zh=1;zh=li;_h=ai;while(1){mi=_h>>>24;Yh=a[1369728+mi|0]|0;ni=Yh&255;Jh=((Yh&255)>>>0>8>>>0?8:ni)+zh|0;Xh=di>>>0>Jh>>>0;oi=Xh?Jh:di;if(!(Yh<<24>>24==9)){K=590;break}Yh=d[1369984+mi|0]|Zh<<4;if(!(Yh>>>0<134217728>>>0)){pi=Yh;break}Jh=ei+(oi>>>3)|0;Vh=(je(d[Jh]|d[Jh+1|0]<<8|d[Jh+2|0]<<16|d[Jh+3|0]<<24|0)|0)<<(oi&7);if(Xh){Zh=Yh;zh=oi;_h=Vh}else{pi=Yh;break}}if((K|0)==590){pi=d[1369984+mi|0]|Zh<<(ni-1>>1)}c[n>>2]=oi;qi=pi-1|0;ri=oi}else{_h=ai>>>24;zh=(d[1369728+_h|0]|0)+li|0;o=di>>>0>zh>>>0?zh:di;c[n>>2]=o;qi=d[1369216+_h|0]|0;ri=o}if(qi>>>0>5>>>0|(qi|0)==0){KIb(c[s>>2]|0,16,2532608,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}o=f+4008|0;c[o>>2]=qi;_h=ei+(ri>>>3)|0;if((c[f+3996>>2]|0)==0){zh=d[_h]|0;bi=((ri|0)<(di|0))+ri|0;c[n>>2]=bi;if((zh&128>>>((ri&7)>>>0)|0)==0){zh=0;while(1){c[f+4024+(zh<<3)+4>>2]=1;c[f+4024+(zh<<3)>>2]=1;Yh=zh+1|0;if(Yh>>>0>(c[o>>2]|0)>>>0){fi=o;break h}else{zh=Yh}}}else{si=0;ti=qi;ui=bi;vi=di;wi=ei}while(1){zh=si>>>0>ti>>>0;ai=wi+(ui>>>3)|0;Zh=(je(d[ai]|d[ai+1|0]<<8|d[ai+2|0]<<16|d[ai+3|0]<<24|0)|0)<<(ui&7);if((Zh&-1434451968|0)==0){ai=1;Yh=ui;Vh=Zh;while(1){xi=Vh>>>24;Xh=a[1369728+xi|0]|0;yi=Xh&255;Jh=((Xh&255)>>>0>8>>>0?8:yi)+Yh|0;Uh=vi>>>0>Jh>>>0;zi=Uh?Jh:vi;if(!(Xh<<24>>24==9)){K=601;break}Xh=d[1369984+xi|0]|ai<<4;if(!(Xh>>>0<134217728>>>0)){Ai=Xh;break}Jh=wi+(zi>>>3)|0;Wh=(je(d[Jh]|d[Jh+1|0]<<8|d[Jh+2|0]<<16|d[Jh+3|0]<<24|0)|0)<<(zi&7);if(Uh){ai=Xh;Yh=zi;Vh=Wh}else{Ai=Xh;break}}if((K|0)==601){K=0;Ai=d[1369984+xi|0]|ai<<(yi-1>>1)}c[n>>2]=zi;Bi=Ai-1|0;Ci=zi}else{Vh=Zh>>>24;Yh=(d[1369728+Vh|0]|0)+ui|0;Xh=vi>>>0>Yh>>>0?Yh:vi;c[n>>2]=Xh;Bi=d[1369216+Vh|0]|0;Ci=Xh}if(zh){K=618;break}if((Bi|0)==0){K=607;break}c[f+4024+(si<<3)>>2]=Bi;Xh=wi+(Ci>>>3)|0;Vh=(je(d[Xh]|d[Xh+1|0]<<8|d[Xh+2|0]<<16|d[Xh+3|0]<<24|0)|0)<<(Ci&7);if((Vh&-1434451968|0)==0){Xh=1;Yh=Ci;Wh=Vh;while(1){Di=Wh>>>24;Uh=a[1369728+Di|0]|0;Ei=Uh&255;Jh=((Uh&255)>>>0>8>>>0?8:Ei)+Yh|0;Qh=vi>>>0>Jh>>>0;Fi=Qh?Jh:vi;if(!(Uh<<24>>24==9)){K=611;break}Uh=d[1369984+Di|0]|Xh<<4;if(!(Uh>>>0<134217728>>>0)){Gi=Uh;break}Jh=wi+(Fi>>>3)|0;Sh=(je(d[Jh]|d[Jh+1|0]<<8|d[Jh+2|0]<<16|d[Jh+3|0]<<24|0)|0)<<(Fi&7);if(Qh){Xh=Uh;Yh=Fi;Wh=Sh}else{Gi=Uh;break}}if((K|0)==611){K=0;Gi=d[1369984+Di|0]|Xh<<(Ei-1>>1)}c[n>>2]=Fi;Hi=Gi-1|0}else{Wh=Vh>>>24;Yh=(d[1369728+Wh|0]|0)+Ci|0;c[n>>2]=vi>>>0>Yh>>>0?Yh:vi;Hi=d[1369216+Wh|0]|0}if((Hi|0)==0){K=616;break}c[f+4024+(si<<3)+4>>2]=Hi;si=si+1|0;ti=c[o>>2]|0;ui=c[n>>2]|0;vi=c[p>>2]|0;wi=c[r>>2]|0}if((K|0)==607){KIb(c[s>>2]|0,16,2517376,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}else if((K|0)==616){KIb(c[s>>2]|0,16,2503416,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}else if((K|0)==618){if(!(Bi>>>0>1>>>0)){c[f+4020>>2]=Bi;fi=o;break}KIb(c[s>>2]|0,16,2490184,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}}bi=_h;Wh=(je(d[bi]|d[bi+1|0]<<8|d[bi+2|0]<<16|d[bi+3|0]<<24|0)|0)<<(ri&7);if((Wh&-1434451968|0)==0){bi=1;Yh=ri;zh=Wh;while(1){Ii=zh>>>24;Zh=a[1369728+Ii|0]|0;Ji=Zh&255;ai=((Zh&255)>>>0>8>>>0?8:Ji)+Yh|0;Uh=di>>>0>ai>>>0;Ki=Uh?ai:di;if(!(Zh<<24>>24==9)){K=625;break}Zh=d[1369984+Ii|0]|bi<<4;if(!(Zh>>>0<134217728>>>0)){Li=Zh;break}ai=ei+(Ki>>>3)|0;Sh=(je(d[ai]|d[ai+1|0]<<8|d[ai+2|0]<<16|d[ai+3|0]<<24|0)|0)<<(Ki&7);if(Uh){bi=Zh;Yh=Ki;zh=Sh}else{Li=Zh;break}}if((K|0)==625){Li=d[1369984+Ii|0]|bi<<(Ji-1>>1)}c[n>>2]=Ki;Mi=Li-1|0;Ni=Ki}else{zh=Wh>>>24;Yh=(d[1369728+zh|0]|0)+ri|0;_h=di>>>0>Yh>>>0?Yh:di;c[n>>2]=_h;Mi=d[1369216+zh|0]|0;Ni=_h}c[f+4072>>2]=Mi;_h=ei+(Ni>>>3)|0;zh=(je(d[_h]|d[_h+1|0]<<8|d[_h+2|0]<<16|d[_h+3|0]<<24|0)|0)<<(Ni&7);if((zh&-1434451968|0)==0){_h=1;Yh=Ni;Zh=zh;while(1){Oi=Zh>>>24;Sh=a[1369728+Oi|0]|0;Pi=Sh&255;Uh=((Sh&255)>>>0>8>>>0?8:Pi)+Yh|0;ai=di>>>0>Uh>>>0;Qi=ai?Uh:di;if(!(Sh<<24>>24==9)){K=632;break}Sh=d[1369984+Oi|0]|_h<<4;if(!(Sh>>>0<134217728>>>0)){Ri=Sh;break}Uh=ei+(Qi>>>3)|0;Qh=(je(d[Uh]|d[Uh+1|0]<<8|d[Uh+2|0]<<16|d[Uh+3|0]<<24|0)|0)<<(Qi&7);if(ai){_h=Sh;Yh=Qi;Zh=Qh}else{Ri=Sh;break}}if((K|0)==632){Ri=d[1369984+Oi|0]|_h<<(Pi-1>>1)}c[n>>2]=Qi;Si=Ri-1|0;Ti=Qi}else{Zh=zh>>>24;Yh=(d[1369728+Zh|0]|0)+Ni|0;Wh=di>>>0>Yh>>>0?Yh:di;c[n>>2]=Wh;Si=d[1369216+Zh|0]|0;Ti=Wh}c[f+4076>>2]=Si;Wh=ei+(Ti>>>3)|0;Zh=(je(d[Wh]|d[Wh+1|0]<<8|d[Wh+2|0]<<16|d[Wh+3|0]<<24|0)|0)<<(Ti&7);if((Zh&-1434451968|0)==0){Wh=1;Yh=Ti;bi=Zh;while(1){Ui=bi>>>24;Sh=a[1369728+Ui|0]|0;Vi=Sh&255;Qh=((Sh&255)>>>0>8>>>0?8:Vi)+Yh|0;ai=di>>>0>Qh>>>0;Wi=ai?Qh:di;if(!(Sh<<24>>24==9)){K=639;break}Sh=d[1369984+Ui|0]|Wh<<4;if(!(Sh>>>0<134217728>>>0)){Xi=Sh;break}Qh=ei+(Wi>>>3)|0;Uh=(je(d[Qh]|d[Qh+1|0]<<8|d[Qh+2|0]<<16|d[Qh+3|0]<<24|0)|0)<<(Wi&7);if(ai){Wh=Sh;Yh=Wi;bi=Uh}else{Xi=Sh;break}}if((K|0)==639){Xi=d[1369984+Ui|0]|Wh<<(Vi-1>>1)}c[n>>2]=Wi;Yi=Xi-1|0;Zi=Wi}else{bi=Zh>>>24;Yh=(d[1369728+bi|0]|0)+Ti|0;zh=di>>>0>Yh>>>0?Yh:di;c[n>>2]=zh;Yi=d[1369216+bi|0]|0;Zi=zh}c[f+4080>>2]=Yi;zh=ei+(Zi>>>3)|0;bi=(je(d[zh]|d[zh+1|0]<<8|d[zh+2|0]<<16|d[zh+3|0]<<24|0)|0)<<(Zi&7);if((bi&-1434451968|0)==0){zh=1;Yh=Zi;_h=bi;while(1){_i=_h>>>24;Sh=a[1369728+_i|0]|0;$i=Sh&255;Uh=((Sh&255)>>>0>8>>>0?8:$i)+Yh|0;ai=di>>>0>Uh>>>0;aj=ai?Uh:di;if(!(Sh<<24>>24==9)){K=646;break}Sh=d[1369984+_i|0]|zh<<4;if(!(Sh>>>0<134217728>>>0)){bj=Sh;break}Uh=ei+(aj>>>3)|0;Qh=(je(d[Uh]|d[Uh+1|0]<<8|d[Uh+2|0]<<16|d[Uh+3|0]<<24|0)|0)<<(aj&7);if(ai){zh=Sh;Yh=aj;_h=Qh}else{bj=Sh;break}}if((K|0)==646){bj=d[1369984+_i|0]|zh<<($i-1>>1)}c[n>>2]=aj;cj=bj-1|0;dj=aj}else{_h=bi>>>24;Yh=(d[1369728+_h|0]|0)+Zi|0;Zh=di>>>0>Yh>>>0?Yh:di;c[n>>2]=Zh;cj=d[1369216+_h|0]|0;dj=Zh}c[f+4084>>2]=cj;if((cj|0)<1){KIb(c[s>>2]|0,16,2479280,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;pa=-1;i=g;return pa|0}Zh=d[ei+(dj>>>3)|0]|0;c[n>>2]=((dj|0)<(di|0))+dj;if((Zh&128>>>((dj&7)>>>0)|0)==0){if(qi>>>0>4>>>0){KIb(c[s>>2]|0,16,2460288,(t=i,i=i+8|0,c[t>>2]=qi,t)|0);i=t;pa=-1;i=g;return pa|0}else{ej=0;fj=ki}while(1){Zh=63-ej|0;_h=a[1576240+(fj<<4)+(ej<<2)|0]|0;Yh=f+4088+(ej<<2)|0;a[Yh]=_h;Wh=c[$h>>2]|0;if((Wh|0)==3){a[Yh]=((c[o>>2]|0)+Zh<<2)+(_h&255);gj=c[$h>>2]|0}else{gj=Wh}Wh=a[1576240+(gj<<4)+(ej<<2)+1|0]|0;_h=f+4088+(ej<<2)+1|0;a[_h]=Wh;Yh=c[$h>>2]|0;if((Yh|0)==3){a[_h]=((c[o>>2]|0)+Zh<<2)+(Wh&255);hj=c[$h>>2]|0}else{hj=Yh}Yh=a[1576240+(hj<<4)+(ej<<2)+2|0]|0;Wh=f+4088+(ej<<2)+2|0;a[Wh]=Yh;_h=c[$h>>2]|0;if((_h|0)==3){a[Wh]=((c[o>>2]|0)+Zh<<2)+(Yh&255);ij=c[$h>>2]|0}else{ij=_h}_h=a[1576240+(ij<<4)+(ej<<2)+3|0]|0;Yh=f+4088+(ej<<2)+3|0;a[Yh]=_h;if((c[$h>>2]|0)==3){a[Yh]=((c[o>>2]|0)+Zh<<2)+(_h&255)}_h=ej+1|0;if(!(_h>>>0<(c[o>>2]|0)>>>0)){fi=o;break h}ej=_h;fj=c[$h>>2]|0}}KIb(c[s>>2]|0,48,2469480,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;$h=c[n>>2]|0;bi=c[p>>2]|0;zh=c[r>>2]|0;_h=zh+($h>>>3)|0;Zh=(je(d[_h]|d[_h+1|0]<<8|d[_h+2|0]<<16|d[_h+3|0]<<24|0)|0)<<($h&7);if((Zh&-1434451968|0)==0){_h=1;Yh=$h;Wh=Zh;while(1){jj=Wh>>>24;Sh=a[1369728+jj|0]|0;kj=Sh&255;Qh=((Sh&255)>>>0>8>>>0?8:kj)+Yh|0;ai=bi>>>0>Qh>>>0;lj=ai?Qh:bi;if(!(Sh<<24>>24==9)){K=656;break}Sh=d[1369984+jj|0]|_h<<4;if(!(Sh>>>0<134217728>>>0)){mj=Sh;break}Qh=zh+(lj>>>3)|0;Uh=(je(d[Qh]|d[Qh+1|0]<<8|d[Qh+2|0]<<16|d[Qh+3|0]<<24|0)|0)<<(lj&7);if(ai){_h=Sh;Yh=lj;Wh=Uh}else{mj=Sh;break}}if((K|0)==656){mj=d[1369984+jj|0]|_h<<(kj-1>>1)}c[n>>2]=lj;nj=mj+255&255;oj=lj}else{Wh=Zh>>>24;Yh=(d[1369728+Wh|0]|0)+$h|0;Sh=bi>>>0>Yh>>>0?Yh:bi;c[n>>2]=Sh;nj=a[1369216+Wh|0]|0;oj=Sh}a[f+4088|0]=nj;if((c[o>>2]|0)==0){fi=o;break}else{pj=0;qj=oj;rj=bi;sj=zh}while(1){Sh=sj+(qj>>>3)|0;Wh=(je(d[Sh]|d[Sh+1|0]<<8|d[Sh+2|0]<<16|d[Sh+3|0]<<24|0)|0)<<(qj&7);if((Wh&-1434451968|0)==0){Sh=1;Yh=qj;Uh=Wh;while(1){tj=Uh>>>24;ai=a[1369728+tj|0]|0;uj=ai&255;Qh=((ai&255)>>>0>8>>>0?8:uj)+Yh|0;Jh=rj>>>0>Qh>>>0;vj=Jh?Qh:rj;if(!(ai<<24>>24==9)){K=664;break}ai=d[1369984+tj|0]|Sh<<4;if(!(ai>>>0<134217728>>>0)){wj=ai;break}Qh=sj+(vj>>>3)|0;Th=(je(d[Qh]|d[Qh+1|0]<<8|d[Qh+2|0]<<16|d[Qh+3|0]<<24|0)|0)<<(vj&7);if(Jh){Sh=ai;Yh=vj;Uh=Th}else{wj=ai;break}}if((K|0)==664){K=0;wj=d[1369984+tj|0]|Sh<<(uj-1>>1)}c[n>>2]=vj;xj=wj+255&255}else{Uh=Wh>>>24;Yh=(d[1369728+Uh|0]|0)+qj|0;c[n>>2]=rj>>>0>Yh>>>0?Yh:rj;xj=a[1369216+Uh|0]|0}a[f+4088+(pj<<2)+1|0]=xj;Uh=c[n>>2]|0;Yh=c[p>>2]|0;Vh=c[r>>2]|0;Xh=Vh+(Uh>>>3)|0;ai=(je(d[Xh]|d[Xh+1|0]<<8|d[Xh+2|0]<<16|d[Xh+3|0]<<24|0)|0)<<(Uh&7);if((ai&-1434451968|0)==0){Xh=1;Th=Uh;Jh=ai;while(1){yj=Jh>>>24;Qh=a[1369728+yj|0]|0;zj=Qh&255;Rh=((Qh&255)>>>0>8>>>0?8:zj)+Th|0;Oh=Yh>>>0>Rh>>>0;Aj=Oh?Rh:Yh;if(!(Qh<<24>>24==9)){K=671;break}Qh=d[1369984+yj|0]|Xh<<4;if(!(Qh>>>0<134217728>>>0)){Bj=Qh;break}Rh=Vh+(Aj>>>3)|0;j=(je(d[Rh]|d[Rh+1|0]<<8|d[Rh+2|0]<<16|d[Rh+3|0]<<24|0)|0)<<(Aj&7);if(Oh){Xh=Qh;Th=Aj;Jh=j}else{Bj=Qh;break}}if((K|0)==671){K=0;Bj=d[1369984+yj|0]|Xh<<(zj-1>>1)}c[n>>2]=Aj;Cj=Bj+255&255}else{Jh=ai>>>24;Th=(d[1369728+Jh|0]|0)+Uh|0;c[n>>2]=Yh>>>0>Th>>>0?Th:Yh;Cj=a[1369216+Jh|0]|0}a[f+4088+(pj<<2)+2|0]=Cj;Jh=c[n>>2]|0;Th=c[p>>2]|0;Vh=c[r>>2]|0;Wh=Vh+(Jh>>>3)|0;Sh=(je(d[Wh]|d[Wh+1|0]<<8|d[Wh+2|0]<<16|d[Wh+3|0]<<24|0)|0)<<(Jh&7);if((Sh&-1434451968|0)==0){Wh=1;Qh=Jh;j=Sh;while(1){Dj=j>>>24;Oh=a[1369728+Dj|0]|0;Ej=Oh&255;Rh=((Oh&255)>>>0>8>>>0?8:Ej)+Qh|0;Mh=Th>>>0>Rh>>>0;Fj=Mh?Rh:Th;if(!(Oh<<24>>24==9)){K=678;break}Oh=d[1369984+Dj|0]|Wh<<4;if(!(Oh>>>0<134217728>>>0)){Gj=Oh;break}Rh=Vh+(Fj>>>3)|0;Nh=(je(d[Rh]|d[Rh+1|0]<<8|d[Rh+2|0]<<16|d[Rh+3|0]<<24|0)|0)<<(Fj&7);if(Mh){Wh=Oh;Qh=Fj;j=Nh}else{Gj=Oh;break}}if((K|0)==678){K=0;Gj=d[1369984+Dj|0]|Wh<<(Ej-1>>1)}c[n>>2]=Fj;Hj=Gj+255&255}else{j=Sh>>>24;Qh=(d[1369728+j|0]|0)+Jh|0;c[n>>2]=Th>>>0>Qh>>>0?Qh:Th;Hj=a[1369216+j|0]|0}a[f+4088+(pj<<2)+3|0]=Hj;j=pj+1|0;if(!(j>>>0<(c[o>>2]|0)>>>0)){fi=o;break h}pj=j;qj=c[n>>2]|0;rj=c[p>>2]|0;sj=c[r>>2]|0}}}while(0);r=f+1416|0;sj=f+1420|0;p=f+1484|0;rj=f+3980|0;n=f+1485|0;qj=f+3984|0;pj=f+1486|0;Hj=f+1487|0;Gj=f+1448|0;Fj=0;while(1){Ej=c[r>>2]|0;if((Fj|0)==0){c[Gj>>2]=Ej;Ij=0;Jj=Gj}else{Dj=f+1448+(Fj*844|0)|0;c[Dj>>2]=Ej>>>((c[rj>>2]|0)>>>0);Ij=c[qj>>2]|0;Jj=Dj}Dj=(c[sj>>2]|0)>>>(Ij>>>0);c[f+1448+(Fj*844|0)+4>>2]=Dj;Ej=c[fi>>2]|0;K=(c[Jj>>2]|0)-1+(1<<Ej)>>Ej<<Ej;c[f+1448+(Fj*844|0)+12>>2]=K;Ej=c[fi>>2]|0;Cj=Dj-1+(1<<Ej)>>Ej<<Ej;c[f+1448+(Fj*844|0)+16>>2]=Cj;Ej=f+1448+(Fj*844|0)+20|0;c[Ej>>2]=K+7&-8;Dj=c[fi>>2]|0;Bj=Dj-1|0;if((Bj|0)>-1){Aj=f+1448+(Fj*844|0)+24|0;zj=Cj;Cj=Dj;Dj=K;K=Bj;while(1){Bj=Dj>>1;yj=zj>>1;xj=(K|0)!=0;wj=xj&1;vj=Cj-2|0;if(xj){xj=wj;do{uj=c[Aj>>2]|0;tj=f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+24|0;c[tj>>2]=uj;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)>>2]=K;oj=c[Ej>>2]<<(c[fi>>2]|0)-K;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+8>>2]=oj;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+12>>2]=Bj;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+16>>2]=yj;c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+4>>2]=xj;if((xj&1|0)==0){Kj=uj}else{nj=uj+(Bj<<1)|0;c[tj>>2]=nj;Kj=nj}if((xj|0)>1){c[tj>>2]=Kj+(oj>>1<<1)}c[f+1448+(Fj*844|0)+44+(K*160|0)+(xj*40|0)+28>>2]=f+1448+(Fj*844|0)+44+(vj*160|0)+(xj*40|0);xj=xj+1|0;}while((xj|0)<4)}else{xj=wj;do{vj=c[Aj>>2]|0;Th=f+1448+(Fj*844|0)+44+(xj*40|0)+24|0;c[Th>>2]=vj;c[f+1448+(Fj*844|0)+44+(xj*40|0)>>2]=0;Jh=c[Ej>>2]<<c[fi>>2];c[f+1448+(Fj*844|0)+44+(xj*40|0)+8>>2]=Jh;c[f+1448+(Fj*844|0)+44+(xj*40|0)+12>>2]=Bj;c[f+1448+(Fj*844|0)+44+(xj*40|0)+16>>2]=yj;c[f+1448+(Fj*844|0)+44+(xj*40|0)+4>>2]=xj;if((xj&1|0)==0){Lj=vj}else{Sh=vj+(Bj<<1)|0;c[Th>>2]=Sh;Lj=Sh}if((xj|0)>1){c[Th>>2]=Lj+(Jh>>1<<1)}xj=xj+1|0;}while((xj|0)<4)}xj=K-1|0;if((xj|0)>-1){zj=yj;Cj=K;Dj=Bj;K=xj}else{break}}}if((Fj|0)>0){K=(d[p]|0)>>>((c[rj>>2]|0)>>>0)&255;a[f+1448+(Fj*844|0)+36|0]=K;Dj=(d[n]|0)>>>((c[qj>>2]|0)>>>0)&255;a[f+1448+(Fj*844|0)+37|0]=Dj;Cj=(d[pj]|0)>>>((c[rj>>2]|0)>>>0)&255;a[f+1448+(Fj*844|0)+38|0]=Cj;zj=(d[Hj]|0)>>>((c[qj>>2]|0)>>>0)&255;a[f+1448+(Fj*844|0)+39|0]=zj;Mj=K;Nj=Cj;Oj=Dj;Pj=zj}else{Mj=a[f+1448+(Fj*844|0)+36|0]|0;Nj=a[f+1448+(Fj*844|0)+38|0]|0;Oj=a[f+1448+(Fj*844|0)+37|0]|0;Pj=a[f+1448+(Fj*844|0)+39|0]|0}a[f+1448+(Fj*844|0)+40|0]=((Mj&255)-(Nj&255)|0)/2|0;a[f+1448+(Fj*844|0)+41|0]=((Oj&255)-(Pj&255)|0)/2|0;zj=Fj+1|0;if((zj|0)<3){Fj=zj}else{pa=0;break}}i=g;return pa|0}function I5(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;n=i;i=i+24|0;o=n|0;p=a[g+8|0]&3;do{if((p|0)==0){q=c[f+1448+(k*844|0)+8>>2]|0;r=a[f+1448+(k*844|0)+36|0]|0;s=r&255;t=a[f+1448+(k*844|0)+37|0]|0;u=t&255;v=(b[g+(k<<1)>>1]|0)+128|0;if(t<<24>>24==0){i=n;return}t=r<<24>>24==0;r=j;w=h;x=0;while(1){if(!t){y=0;do{z=ca(d[r+y|0]|0,v)|0;A=w+(y<<1)|0;b[A>>1]=(e[A>>1]|0)+z;z=y|1;A=ca(d[r+z|0]|0,v)|0;B=w+(z<<1)|0;b[B>>1]=(e[B>>1]|0)+A;y=y+2|0;}while((y|0)<(s|0))}y=x+1|0;if((y|0)<(u|0)){r=r+32|0;w=w+(q<<1)|0;x=y}else{break}}i=n;return}else if((p|0)==1|(p|0)==2){x=o|0;q=c[f+7328+((J5(f,g,x,l,m,p-1|0,k)|0)<<2)>>2]|0;w=f+4248|0;r=f+1448+(k*844|0)+8|0;u=f+1448+(k*844|0)+37|0;mf[q&2047](c[w>>2]|0,x,c[r>>2]|0,d[u]|0);x=c[f+7364>>2]|0;if((x|0)==0){C=w;D=r;E=u;break}pe[x&1023](c[w>>2]|0,c[r>>2]|0,c[f+4196>>2]|0,(b[f+4192>>1]|0)+(b[f+4190>>1]|0)|0,d[u]|0);C=w;D=r;E=u}else if((p|0)==3){u=o|0;r=c[f+7328+((J5(f,g,u,l,m,0,k)|0)<<2)>>2]|0;w=f+4248|0;x=f+1448+(k*844|0)+8|0;q=f+1448+(k*844|0)+37|0;mf[r&2047](c[w>>2]|0,u,c[x>>2]|0,d[q]|0);r=J5(f,g,u,l,m,1,k)|0;s=f+7368|0;if((c[s>>2]|0)==0){mf[c[f+7344+(r<<2)>>2]&2047](c[w>>2]|0,u,c[x>>2]|0,d[q]|0);C=w;D=x;E=q;break}else{mf[c[f+7328+(r<<2)>>2]&2047]((c[w>>2]|0)+32|0,u,c[x>>2]|0,d[q]|0);u=c[w>>2]|0;Se[c[s>>2]&1023](u,u+32|0,c[x>>2]|0,c[f+4196>>2]|0,b[f+4190>>1]|0,b[f+4192>>1]|0,d[q]|0);C=w;D=x;E=q;break}}else{C=f+4248|0;D=f+1448+(k*844|0)+8|0;E=f+1448+(k*844|0)+37|0}}while(0);pe[c[f+7360>>2]&1023](h,c[C>>2]|0,c[D>>2]|0,j,d[E]|0);i=n;return}function J5(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=c[e+7376+(j<<2)>>2]|0;m=b[f+(j<<2)>>1]|0;n=b[f+(j<<2)+2>>1]|0;if((k|0)==0){o=m;p=n}else{o=m>>c[e+3980>>2];p=n>>c[e+3984>>2]}n=d[e+4188|0]|0;m=~(-1<<n);j=3-n|0;f=(o&m)<<j;q=(p&m)<<j;j=(o>>n)+h|0;h=(p>>n)+i|0;i=f|q;n=i&1;do{if((i&3|0)==0){p=c[e+1448+(k*844|0)+8>>2]|0;c[g>>2]=(c[l+16+(k<<4)+((q>>1)+(f>>2)<<2)>>2]|0)+((ca(p,h)|0)+j);r=j;s=h;t=1;u=p}else{p=c[e+1448+(k*844|0)+8>>2]|0;o=(ca(p,h)|0)+j|0;m=c[l+16+(k<<4)>>2]|0;v=m+o|0;c[g>>2]=v;w=c[l+16+(k<<4)+4>>2]|0;x=w+o|0;y=g+4|0;c[y>>2]=x;z=c[l+16+(k<<4)+8>>2]|0;A=z+o|0;B=g+8|0;c[B>>2]=A;C=(c[l+16+(k<<4)+12>>2]|0)+o|0;D=g+12|0;c[D>>2]=C;E=(f|0)>4;if(E){F=m+(o+1)|0;c[g>>2]=F;m=z+(o+1)|0;c[B>>2]=m;G=j+1|0;H=F;I=m}else{G=j;H=v;I=A}A=(q|0)>4;if(A){v=H+p|0;c[g>>2]=v;m=w+(o+p)|0;c[y>>2]=m;J=h+1|0;K=m;L=v}else{J=h;K=x;L=H}if((n|0)==0){if((f&3|0)==0){x=(f|0)!=0|0;c[g+((x^1)<<2)>>2]=c[g+((x|2)<<2)>>2];r=G;s=J;t=2;u=p;break}if((q&3|0)!=0){r=G;s=J;t=4;u=p;break}x=q>>1;c[g>>2]=c[g+(x<<2)>>2];c[y>>2]=c[g+(x+1<<2)>>2];r=G;s=J;t=2;u=p;break}if(E){c[y>>2]=L;c[g>>2]=K;c[D>>2]=I;c[B>>2]=C;M=C;N=K;O=I;P=L}else{M=I;N=L;O=C;P=K}if(A){c[B>>2]=N;c[g>>2]=M;c[D>>2]=P;c[y>>2]=O}c[g+16>>2]=1510656+((q&3)<<4)+((f&3)<<2);r=G;s=J;t=4;u=p}}while(0);J=e+1448+(k*844|0)+36|0;G=a[J]|0;f=e+1448+(k*844|0)|0;q=c[f>>2]|0;O=e+1448+(k*844|0)+37|0;do{if(((G&255)+r|0)>(q+8|0)){Q=e+1448+(k*844|0)+4|0}else{P=e+1448+(k*844|0)+4|0;if(((d[O]|0)+s|0)>((c[P>>2]|0)+8|0)|(r|0)<0|(s|0)<0){Q=P;break}R=t>>>1;S=R+n|0;return S|0}}while(0);P=e+1448+(k*844|0)+8|0;k=0;M=u;u=G;G=q;while(1){q=e+4224+(k<<2)|0;N=g+(k<<2)|0;E8a(c[q>>2]|0,c[N>>2]|0,M,M,u&255,d[O]|0,r,s,G+8|0,(c[Q>>2]|0)+8|0);c[N>>2]=c[q>>2];q=k+1|0;if((q|0)>=(t|0)){break}k=q;M=c[P>>2]|0;u=a[J]|0;G=c[f>>2]|0}R=t>>>1;S=R+n|0;return S|0}function K5(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;i=b+37|0;a:do{if((g|0)==0){j=0;k=c}else{l=b+36|0;m=(e|0)!=0;n=b+40|0;o=0;p=c;while(1){if((o|0)>=((d[i]|0)>>>1|0)){j=o;k=p;break a}q=a[l]|0;if(m&(q&255)>>>0>1>>>0){r=0;while(1){a[p+r|0]=64;s=r+1|0;t=a[l]|0;if((s|0)<((t&255)>>>1|0)){r=s}else{u=s;v=t;break}}}else{u=0;v=q}r=v&255;if((u|0)<(r>>>(f>>>0)|0)){t=u;s=r;while(1){r=a[n]|0;w=r&255;x=w<<1;do{if((x|0)>(t|0)){if(r<<24>>24==1){y=(t|0)!=0?5:3;break}else{y=(((t*6|0)-1+w|0)/(x-1|0)|0)+1|0;break}}else{z=s-1|0;if((z-x|0)>=(t|0)){y=8;break}if(r<<24>>24==1){y=(z|0)!=(t|0)?5:3;break}else{y=((w-1+((z-t|0)*6|0)|0)/(x-1|0)|0)+1|0;break}}}while(0);a[p+t|0]=y<<3;x=t+1|0;w=a[l]|0;r=w&255;if((x|0)<(r>>>(f>>>0)|0)){t=x;s=r}else{A=x;B=w;break}}}else{A=u;B=v}if((A|0)<(B&255|0)){s=A;while(1){a[p+s|0]=64;t=s+1|0;if((t|0)<(d[l]|0|0)){s=t}else{C=t;break}}}else{C=A}if((C|0)<32){mrc(p+C|0,0,32-C|0)|0}o=o+1|0;p=p+32|0}}}while(0);C=a[i]|0;A=C&255;if((j|0)<(A>>>(h>>>0)|0)){B=b+41|0;v=b+36|0;u=(e|0)==0;y=b+40|0;c=j;g=k;p=A;while(1){A=a[B]|0;o=A&255;l=o<<1;do{if((l|0)>(c|0)){if(A<<24>>24==1){D=(c|0)!=0?5:3;break}else{D=(((c*6|0)-1+o|0)/(l-1|0)|0)+1|0;break}}else{n=p-1|0;if((n-l|0)>=(c|0)){D=8;break}if(A<<24>>24==1){D=(n|0)!=(c|0)?5:3;break}else{D=((((n-c|0)*6|0)-1+o|0)/(l-1|0)|0)+1|0;break}}}while(0);do{if(u){E=0;F=a[v]|0}else{l=D<<3&255;o=a[v]|0;if((o&255)>>>0>1>>>0){G=0}else{E=0;F=o;break}while(1){a[g+G|0]=l;o=G+1|0;A=a[v]|0;if((o|0)<((A&255)>>>1|0)){G=o}else{E=o;F=A;break}}}}while(0);l=F&255;if((E|0)<(l>>>(f>>>0)|0)){A=E;o=l;while(1){l=a[y]|0;n=l&255;m=n<<1;do{if((m|0)>(A|0)){if(l<<24>>24==1){H=(A|0)!=0?5:3;break}else{H=(((A*6|0)-1+n|0)/(m-1|0)|0)+1|0;break}}else{s=o-1|0;if((s-m|0)>=(A|0)){H=8;break}if(l<<24>>24==1){H=(s|0)!=(A|0)?5:3;break}else{H=((n-1+((s-A|0)*6|0)|0)/(m-1|0)|0)+1|0;break}}}while(0);a[g+A|0]=ca(H,D)|0;m=A+1|0;n=a[v]|0;l=n&255;if((m|0)<(l>>>(f>>>0)|0)){A=m;o=l}else{I=m;J=n;break}}}else{I=E;J=F}if((I|0)<(J&255|0)){o=D<<3&255;A=I;while(1){a[g+A|0]=o;n=A+1|0;if((n|0)<(d[v]|0|0)){A=n}else{K=n;break}}}else{K=I}if((K|0)<32){mrc(g+K|0,0,32-K|0)|0}A=g+32|0;o=c+1|0;n=a[i]|0;m=n&255;if((o|0)<(m>>>(h>>>0)|0)){c=o;g=A;p=m}else{L=o;M=A;N=n;break}}}else{L=j;M=k;N=C}if((L|0)>=(N&255|0)){return}N=b+36|0;C=(e|0)!=0;e=b+40|0;b=L;L=M;while(1){M=a[N]|0;if(C&(M&255)>>>0>1>>>0){k=0;while(1){a[L+k|0]=64;j=k+1|0;p=a[N]|0;if((j|0)<((p&255)>>>1|0)){k=j}else{O=j;P=p;break}}}else{O=0;P=M}k=P&255;if((O|0)<(k>>>(f>>>0)|0)){p=O;j=k;while(1){k=a[e]|0;g=k&255;c=g<<1;do{if((c|0)>(p|0)){if(k<<24>>24==1){Q=(p|0)!=0?5:3;break}else{Q=(((p*6|0)-1+g|0)/(c-1|0)|0)+1|0;break}}else{h=j-1|0;if((h-c|0)>=(p|0)){Q=8;break}if(k<<24>>24==1){Q=(h|0)!=(p|0)?5:3;break}else{Q=((g-1+((h-p|0)*6|0)|0)/(c-1|0)|0)+1|0;break}}}while(0);a[L+p|0]=Q<<3;c=p+1|0;g=a[N]|0;k=g&255;if((c|0)<(k>>>(f>>>0)|0)){p=c;j=k}else{R=c;S=g;break}}}else{R=O;S=P}if((R|0)<(S&255|0)){j=R;while(1){a[L+j|0]=64;p=j+1|0;if((p|0)<(d[N]|0|0)){j=p}else{T=p;break}}}else{T=R}if((T|0)<32){mrc(L+T|0,0,32-T|0)|0}j=b+1|0;if((j|0)<(d[i]|0|0)){b=j;L=L+32|0}else{break}}return}function L5(a,f){a=a|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0;g=i;i=i+88|0;h=g|0;j=g+64|0;k=c[a+60>>2]|0;a=k;l=f+4|0;m=((c[l>>2]|0)!=0)+(c[f>>2]|0)|0;n=c[a+4024+(m<<3)>>2]|0;o=c[a+4024+(m<<3)+4>>2]|0;m=(o+n|0)==2;a=c[f+32>>2]|0;if((a|0)==0){i=g;return 0}p=c[f+36>>2]|0;q=a>>>0>268435455>>>0?-8:a<<3;r=q>>>0>2147483639>>>0|(p|0)==0;s=r?0:p;p=r?0:q;c[j>>2]=s;c[j+12>>2]=p;c[j+16>>2]=p+8;c[j+4>>2]=s+(p>>3);c[j+8>>2]=0;Sob(h,j,a);a:do{if((o|0)>0){a=f+16|0;j=(n|0)>0;p=f+12|0;s=k+4020|0;q=f+20|0;r=f+8|0;t=k+4004|0;u=f+24|0;v=f+28|0;w=h|0;x=h+4|0;y=h+6|0;z=h+8|0;A=h+12|0;B=h+44|0;C=k+4016|0;D=m^1;E=k;F=h+54|0;G=h+56|0;H=h+58|0;I=h+52|0;J=0;K=1;while(1){L=(ca(c[a>>2]|0,K)|0)/(o|0)|0;b:do{if(j){M=(J|0)<(L|0);N=0;O=1;while(1){P=(ca(c[p>>2]|0,O)|0)/(n|0)|0;if(m){Q=21}else{R=b[I>>1]|0;S=R&65535;T=c[w>>2]|0;U=e[x>>1]|0;V=(ca(U,S)|0)>>>16;W=T>>>16>>>0>=V>>>0;if(W){X=T-(V<<16)|0;Y=U-V&65535}else{X=T;Y=V&65535}b[I>>1]=(b[8378640+(S>>>8<<2)+((W&1)<<1)>>1]|0)+R;c[w>>2]=X;b[x>>1]=Y;R=b[y>>1]|0;if((Y&65535)>>>0<16385>>>0){S=X;V=Y;T=R;do{S=S<<1;V=V<<1;T=T+1&65535;}while((V&65535)>>>0<16385>>>0);c[w>>2]=S;b[x>>1]=V;b[y>>1]=T;Z=S;_=T}else{Z=X;_=R}U=_<<16>>16;if(_<<16>>16>-1){$=c[z>>2]|0;aa=$+2|0;c[z>>2]=aa;ba=$;$=(he((d[ba]|d[ba+1|0]<<8)<<16>>16|0)|0)&65535;ba=c[A>>2]|0;if(aa>>>0>ba>>>0){c[z>>2]=ba;da=aa>>>0>(ba+1|0)>>>0?65535:$|255}else{da=$}c[w>>2]=(da<<U)+Z;ea=_-16&65535}else{ea=_}b[y>>1]=ea;if(!W){Q=21}}c:do{if((Q|0)==21){Q=0;do{if((c[s>>2]|0)!=0){if(!((c[C>>2]|0)==0|D)){break}U=c[q>>2]|0;$=b[F>>1]|0;ba=$&65535;aa=c[w>>2]|0;fa=e[x>>1]|0;ga=(ca(fa,ba)|0)>>>16;ha=aa>>>16>>>0>=ga>>>0;if(ha){ia=aa-(ga<<16)|0;ja=fa-ga&65535}else{ia=aa;ja=ga&65535}b[F>>1]=(b[8378640+(ba>>>8<<2)+((ha&1)<<1)>>1]|0)+$;c[w>>2]=ia;b[x>>1]=ja;$=b[y>>1]|0;if((ja&65535)>>>0<16385>>>0){ba=ia;ga=ja;aa=$;do{ba=ba<<1;ga=ga<<1;aa=aa+1&65535;}while((ga&65535)>>>0<16385>>>0);c[w>>2]=ba;b[x>>1]=ga;b[y>>1]=aa;ka=ba;la=aa;ma=ga}else{ka=ia;la=$;ma=ja}fa=la<<16>>16;if(la<<16>>16>-1){na=c[z>>2]|0;oa=na+2|0;c[z>>2]=oa;pa=na;na=(he((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535;pa=c[A>>2]|0;if(oa>>>0>pa>>>0){c[z>>2]=pa;qa=oa>>>0>(pa+1|0)>>>0?65535:na|255}else{qa=na}na=(qa<<fa)+ka|0;c[w>>2]=na;ra=la-16&65535;sa=na}else{ra=la;sa=ka}b[y>>1]=ra;do{if(ha){ta=0}else{na=19;fa=2;pa=sa;oa=ma;ua=ra;while(1){va=b[G>>1]|0;wa=va&65535;xa=oa&65535;ya=(ca(wa,xa)|0)>>>16;za=pa>>>16>>>0>=ya>>>0;Aa=za&1;if(za){Ba=pa-(ya<<16)|0;Ca=xa-ya&65535}else{Ba=pa;Ca=ya&65535}b[G>>1]=(b[8378640+(wa>>>8<<2)+(Aa<<1)>>1]|0)+va;c[w>>2]=Ba;b[x>>1]=Ca;if((Ca&65535)>>>0<16385>>>0){va=Ba;wa=Ca;ya=ua;do{va=va<<1;wa=wa<<1;ya=ya+1&65535;}while((wa&65535)>>>0<16385>>>0);c[w>>2]=va;b[x>>1]=wa;b[y>>1]=ya;Da=va;Ea=ya;Fa=wa}else{Da=Ba;Ea=ua;Fa=Ca}xa=Ea<<16>>16;if(Ea<<16>>16>-1){za=c[z>>2]|0;Ga=za+2|0;c[z>>2]=Ga;Ha=za;za=(he((d[Ha]|d[Ha+1|0]<<8)<<16>>16|0)|0)&65535;Ha=c[A>>2]|0;if(Ga>>>0>Ha>>>0){c[z>>2]=Ha;Ia=Ga>>>0>(Ha+1|0)>>>0?65535:za|255}else{Ia=za}za=(Ia<<xa)+Da|0;c[w>>2]=za;Ja=Ea-16&65535;Ka=za}else{Ja=Ea;Ka=Da}b[y>>1]=Ja;La=Aa|fa;za=d[1401960+na|0]|0;xa=h+16+(za<<1)|0;Ha=b[xa>>1]|0;Ga=Ha&65535;Ma=Fa&65535;Na=(ca(Ga,Ma)|0)>>>16;Oa=Ka>>>16>>>0>=Na>>>0;if(Oa){Pa=Ka-(Na<<16)|0;Qa=Ma-Na&65535}else{Pa=Ka;Qa=Na&65535}b[xa>>1]=(b[8378640+(Ga>>>8<<2)+((Oa&1)<<1)>>1]|0)+Ha;c[w>>2]=Pa;b[x>>1]=Qa;Ha=b[y>>1]|0;if((Qa&65535)>>>0<16385>>>0){Ga=Pa;xa=Qa;Na=Ha;do{Ga=Ga<<1;xa=xa<<1;Na=Na+1&65535;}while((xa&65535)>>>0<16385>>>0);c[w>>2]=Ga;b[x>>1]=xa;b[y>>1]=Na;Ra=Ga;Sa=Na;Ta=xa}else{Ra=Pa;Sa=Ha;Ta=Qa}Aa=Sa<<16>>16;if(Sa<<16>>16>-1){wa=c[z>>2]|0;ya=wa+2|0;c[z>>2]=ya;va=wa;wa=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)&65535;va=c[A>>2]|0;if(ya>>>0>va>>>0){c[z>>2]=va;Ua=ya>>>0>(va+1|0)>>>0?65535:wa|255}else{Ua=wa}wa=(Ua<<Aa)+Ra|0;c[w>>2]=wa;Va=Sa-16&65535;Wa=wa}else{Va=Sa;Wa=Ra}b[y>>1]=Va;if(Oa){break}else{na=za;fa=La<<1;pa=Wa;oa=Ta;ua=Va}}ua=La-1|0;if((ua|0)==0){ta=0;break}oa=b[H>>1]|0;pa=oa&65535;fa=Ta&65535;na=(ca(pa,fa)|0)>>>16;wa=Wa>>>16>>>0>=na>>>0;if(wa){Xa=Wa-(na<<16)|0;Ya=fa-na&65535}else{Xa=Wa;Ya=na&65535}b[H>>1]=(b[8378640+(pa>>>8<<2)+((wa&1)<<1)>>1]|0)+oa;c[w>>2]=Xa;b[x>>1]=Ya;if((Ya&65535)>>>0<16385>>>0){oa=Xa;pa=Ya;na=Va;do{oa=oa<<1;pa=pa<<1;na=na+1&65535;}while((pa&65535)>>>0<16385>>>0);c[w>>2]=oa;b[x>>1]=pa;b[y>>1]=na;Za=oa;_a=na}else{Za=Xa;_a=Va}fa=_a<<16>>16;if(_a<<16>>16>-1){Aa=c[z>>2]|0;va=Aa+2|0;c[z>>2]=va;ya=Aa;Aa=(he((d[ya]|d[ya+1|0]<<8)<<16>>16|0)|0)&65535;ya=c[A>>2]|0;if(va>>>0>ya>>>0){c[z>>2]=ya;$a=va>>>0>(ya+1|0)>>>0?65535:Aa|255}else{$a=Aa}c[w>>2]=($a<<fa)+Za;ab=_a-16&65535}else{ab=_a}b[y>>1]=ab;ta=wa?1-La|0:ua}}while(0);ha=ta+U|0;if((ha|0)<0){KIb(c[E>>2]|0,16,2123256,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;break c}else{c[q>>2]=ha;break}}}while(0);ha=c[q>>2]|0;$=(ha|0)>68?68:ha;c[q>>2]=$;ha=c[690776+($<<2)>>2]|0;if(!M){break}ga=c[r>>2]|0;aa=ca(ga,J)|0;ba=(N|0)<(P|0);fa=(c[((c[t>>2]|0)==0?692288:692568)+($<<2)>>2]|0)+2|0;$=-ga|0;Aa=~ga;ya=J;va=(c[u>>2]|0)+(aa<<1)|0;while(1){if(ba){aa=ya>>1;Ma=va+($<<1)|0;bb=c[v>>2]|0;cb=N;do{db=va+(cb<<1)|0;if((bb|0)==0){eb=0}else{fb=(ca(c[bb+8>>2]|0,aa)|0)+(cb>>1)|0;eb=((b[(c[bb+24>>2]|0)+(fb<<1)>>1]|0)!=0)<<1}fb=c[l>>2]|0;if((fb|0)==1){gb=b[va+(cb-ga<<1)>>1]|0}else{gb=0}do{if((cb|0)==0){hb=(b[Ma>>1]|0)==0|eb;ib=gb}else{jb=b[va+(cb-1<<1)>>1]|0;kb=(b[va+(cb-ga<<1)>>1]|jb|b[va+(cb+Aa<<1)>>1])<<16>>16==0|eb;if((fb|0)!=2){hb=kb;ib=gb;break}hb=kb;ib=jb<<16>>16}}while(0);fb=h+16+(hb<<1)|0;ua=b[fb>>1]|0;wa=ua&65535;na=c[w>>2]|0;oa=e[x>>1]|0;pa=(ca(oa,wa)|0)>>>16;jb=na>>>16>>>0>=pa>>>0;if(jb){lb=na-(pa<<16)|0;mb=oa-pa&65535}else{lb=na;mb=pa&65535}b[fb>>1]=(b[8378640+(wa>>>8<<2)+((jb&1)<<1)>>1]|0)+ua;c[w>>2]=lb;b[x>>1]=mb;ua=b[y>>1]|0;if((mb&65535)>>>0<16385>>>0){wa=lb;fb=mb;pa=ua;do{wa=wa<<1;fb=fb<<1;pa=pa+1&65535;}while((fb&65535)>>>0<16385>>>0);c[w>>2]=wa;b[x>>1]=fb;b[y>>1]=pa;nb=wa;ob=pa;pb=fb}else{nb=lb;ob=ua;pb=mb}na=ob<<16>>16;if(ob<<16>>16>-1){oa=c[z>>2]|0;kb=oa+2|0;c[z>>2]=kb;qb=oa;oa=(he((d[qb]|d[qb+1|0]<<8)<<16>>16|0)|0)&65535;qb=c[A>>2]|0;if(kb>>>0>qb>>>0){c[z>>2]=qb;rb=kb>>>0>(qb+1|0)>>>0?65535:oa|255}else{rb=oa}oa=(rb<<na)+nb|0;c[w>>2]=oa;sb=ob-16&65535;tb=oa}else{sb=ob;tb=nb}b[y>>1]=sb;do{if(jb){ub=0}else{oa=hb;na=1;qb=tb;kb=pb;vb=sb;while(1){wb=na<<1;xb=b[B>>1]|0;yb=xb&65535;zb=kb&65535;Ab=(ca(yb,zb)|0)>>>16;Bb=qb>>>16>>>0>=Ab>>>0;Cb=Bb&1;if(Bb){Db=qb-(Ab<<16)|0;Eb=zb-Ab&65535}else{Db=qb;Eb=Ab&65535}b[B>>1]=(b[8378640+(yb>>>8<<2)+(Cb<<1)>>1]|0)+xb;c[w>>2]=Db;b[x>>1]=Eb;if((Eb&65535)>>>0<16385>>>0){xb=Db;yb=Eb;Ab=vb;do{xb=xb<<1;yb=yb<<1;Ab=Ab+1&65535;}while((yb&65535)>>>0<16385>>>0);c[w>>2]=xb;b[x>>1]=yb;b[y>>1]=Ab;Fb=xb;Gb=Ab;Hb=yb}else{Fb=Db;Gb=vb;Hb=Eb}zb=Gb<<16>>16;if(Gb<<16>>16>-1){Bb=c[z>>2]|0;Ib=Bb+2|0;c[z>>2]=Ib;Jb=Bb;Bb=(he((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535;Jb=c[A>>2]|0;if(Ib>>>0>Jb>>>0){c[z>>2]=Jb;Kb=Ib>>>0>(Jb+1|0)>>>0?65535:Bb|255}else{Kb=Bb}Bb=(Kb<<zb)+Fb|0;c[w>>2]=Bb;Lb=Gb-16&65535;Mb=Bb}else{Lb=Gb;Mb=Fb}b[y>>1]=Lb;Nb=Cb|wb;Bb=d[1401960+oa|0]|0;zb=h+16+(Bb<<1)|0;Jb=b[zb>>1]|0;Ib=Jb&65535;Ob=Hb&65535;Pb=(ca(Ib,Ob)|0)>>>16;Qb=Mb>>>16>>>0>=Pb>>>0;if(Qb){Rb=Mb-(Pb<<16)|0;Sb=Ob-Pb&65535}else{Rb=Mb;Sb=Pb&65535}b[zb>>1]=(b[8378640+(Ib>>>8<<2)+((Qb&1)<<1)>>1]|0)+Jb;c[w>>2]=Rb;b[x>>1]=Sb;Jb=b[y>>1]|0;if((Sb&65535)>>>0<16385>>>0){Ib=Rb;zb=Sb;Pb=Jb;do{Ib=Ib<<1;zb=zb<<1;Pb=Pb+1&65535;}while((zb&65535)>>>0<16385>>>0);c[w>>2]=Ib;b[x>>1]=zb;b[y>>1]=Pb;Tb=Ib;Ub=Pb;Vb=zb}else{Tb=Rb;Ub=Jb;Vb=Sb}wb=Ub<<16>>16;if(Ub<<16>>16>-1){Cb=c[z>>2]|0;yb=Cb+2|0;c[z>>2]=yb;Ab=Cb;Cb=(he((d[Ab]|d[Ab+1|0]<<8)<<16>>16|0)|0)&65535;Ab=c[A>>2]|0;if(yb>>>0>Ab>>>0){c[z>>2]=Ab;Wb=yb>>>0>(Ab+1|0)>>>0?65535:Cb|255}else{Wb=Cb}Cb=(Wb<<wb)+Tb|0;c[w>>2]=Cb;Xb=Ub-16&65535;Yb=Cb}else{Xb=Ub;Yb=Tb}b[y>>1]=Xb;if(Qb){break}else{oa=Bb;na=Nb;qb=Yb;kb=Vb;vb=Xb}}vb=Nb-1|0;if((vb|0)==0){ub=vb&65535;break}kb=(fa+(ca(vb,ha)|0)|0)>>>2;vb=h+16+(((ib|0)>0|16)-(ib>>>31)<<1)|0;qb=b[vb>>1]|0;na=qb&65535;oa=Vb&65535;za=(ca(na,oa)|0)>>>16;Oa=Yb>>>16>>>0>=za>>>0;Ha=Oa&1;if(Oa){Zb=Yb-(za<<16)|0;_b=oa-za&65535}else{Zb=Yb;_b=za&65535}b[vb>>1]=(b[8378640+(na>>>8<<2)+(Ha<<1)>>1]|0)+qb;c[w>>2]=Zb;b[x>>1]=_b;qb=b[y>>1]|0;if((_b&65535)>>>0<16385>>>0){na=Zb;vb=_b;za=qb;do{na=na<<1;vb=vb<<1;za=za+1&65535;}while((vb&65535)>>>0<16385>>>0);c[w>>2]=na;b[x>>1]=vb;b[y>>1]=za;$b=na;ac=za}else{$b=Zb;ac=qb}oa=ac<<16>>16;if(ac<<16>>16>-1){Oa=c[z>>2]|0;xa=Oa+2|0;c[z>>2]=xa;Na=Oa;Oa=(he((d[Na]|d[Na+1|0]<<8)<<16>>16|0)|0)&65535;Na=c[A>>2]|0;if(xa>>>0>Na>>>0){c[z>>2]=Na;bc=xa>>>0>(Na+1|0)>>>0?65535:Oa|255}else{bc=Oa}c[w>>2]=(bc<<oa)+$b;cc=ac-16&65535}else{cc=ac}b[y>>1]=cc;ub=(kb^-Ha)+Ha&65535}}while(0);b[db>>1]=ub;cb=cb+1|0;}while((cb|0)<(P|0))}cb=ya+1|0;if((cb|0)<(L|0)){ya=cb;va=va+(ga<<1)|0}else{break}}}}while(0);if((O|0)>=(n|0)){break b}N=P;O=O+1|0}}}while(0);if((K|0)>=(o|0)){break a}J=L;K=K+1|0}}}while(0);if((c[l>>2]|0)!=0){i=g;return 0}if((c[k+4004>>2]|0)!=0){i=g;return 0}k=c[f+24>>2]|0;l=c[f+12>>2]|0;o=(l|0)>1;if(o){n=1;ub=b[k>>1]|0;do{cc=k+(n<<1)|0;ub=(b[cc>>1]|0)+ub&65535;b[cc>>1]=ub;n=n+1|0;}while((n|0)<(l|0))}n=c[f+8>>2]|0;ub=k+(n<<1)|0;k=c[f+16>>2]|0;if((k|0)<=1){i=g;return 0}f=-n|0;if(o){dc=1;ec=ub}else{o=1;cc=ub;while(1){b[cc>>1]=(b[cc>>1]|0)+(b[cc+(f<<1)>>1]|0);ub=o+1|0;if((ub|0)<(k|0)){o=ub;cc=cc+(n<<1)|0}else{break}}i=g;return 0}while(1){cc=(b[ec>>1]|0)+(b[ec+(f<<1)>>1]|0)&65535;b[ec>>1]=cc;o=1;ub=cc;do{cc=o-n|0;ac=ec+(o<<1)|0;ub=(((((b[ec+(cc<<1)>>1]|0)+(ub<<16>>16)+(b[ec+(cc-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[ac>>1]|0)&65535;b[ac>>1]=ub;o=o+1|0;}while((o|0)<(l|0));o=dc+1|0;if((o|0)<(k|0)){dc=o;ec=ec+(n<<1)|0}else{break}}i=g;return 0}function M5(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;h=i;j=c[f+60>>2]|0;f=j;k=c[g>>2]|0;g=k+4|0;l=c[g>>2]|0;m=((l|0)!=0)+(c[k>>2]|0)|0;n=c[f+4024+(m<<3)>>2]|0;o=c[f+4024+(m<<3)+4>>2]|0;m=(o+n|0)==2;f=c[k+32>>2]|0;if((f|0)==0){i=h;return 0}p=c[k+36>>2]|0;q=f>>>0>268435455>>>0?-8:f<<3;f=q>>>0>2147483639>>>0|(p|0)==0;r=f?0:p;p=f?8:q+8|0;if((o|0)>0){q=k+16|0;f=(n|0)>0;s=k+12|0;t=j+4020|0;u=k+20|0;v=k+8|0;w=j+4004|0;x=k+24|0;y=j+4016|0;z=m^1;A=j;B=0;C=1;D=0;while(1){E=(ca(c[q>>2]|0,C)|0)/(o|0)|0;a:do{if(f){F=(B|0)<(E|0);G=0;H=1;I=D;while(1){J=(ca(c[s>>2]|0,H)|0)/(n|0)|0;if(m){K=I;L=12}else{M=((I|0)<(p|0))+I|0;if((d[r+(I>>>3)|0]&128>>>((I&7)>>>0)|0)==0){K=M;L=12}else{N=M}}b:do{if((L|0)==12){L=0;do{if((c[t>>2]|0)==0){O=K}else{if(!((c[y>>2]|0)==0|z)){O=K;break}M=c[u>>2]|0;P=r+(K>>>3)|0;Q=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(K&7);if((Q&-1434451968|0)==0){P=1;R=K;S=Q;while(1){T=S>>>24;U=a[1369728+T|0]|0;V=U&255;W=((U&255)>>>0>8>>>0?8:V)+R|0;X=p>>>0>W>>>0;Y=X?W:p;if(!(U<<24>>24==9)){L=17;break}U=d[1369984+T|0]|P<<4;if(!(U>>>0<134217728>>>0)){Z=U;break}W=r+(Y>>>3)|0;_=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Y&7);if(X){P=U;R=Y;S=_}else{Z=U;break}}if((L|0)==17){L=0;Z=d[1369984+T|0]|P<<(V-1>>1)}$=Z-1|0;aa=Y}else{S=Q>>>24;R=(d[1369728+S|0]|0)+K|0;$=d[1369216+S|0]|0;aa=p>>>0>R>>>0?R:p}if(($|0)==0){ba=0;da=aa}else{R=r+(aa>>>3)|0;S=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(aa&7)>>31;R=aa+1|0;ba=(S^$)-S|0;da=p>>>0>R>>>0?R:p}R=ba+M|0;if((R|0)<0){KIb(c[A>>2]|0,16,2123256,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;N=da;break b}else{c[u>>2]=R;O=da;break}}}while(0);R=c[u>>2]|0;S=(R|0)>68?68:R;c[u>>2]=S;R=c[690776+(S<<2)>>2]|0;if(!F){N=O;break}U=c[v>>2]|0;_=ca(U,B)|0;X=(G|0)<(J|0);W=(c[((c[w>>2]|0)==0?692288:692568)+(S<<2)>>2]|0)+2|0;S=B;ea=(c[x>>2]|0)+(_<<1)|0;_=O;while(1){if(X){fa=G;ga=_;while(1){ha=r+(ga>>>3)|0;ia=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ga&7);if((ia&-1434451968|0)==0){ha=1;ja=ga;ka=ia;while(1){la=ka>>>24;ma=a[1369728+la|0]|0;na=ma&255;oa=((ma&255)>>>0>8>>>0?8:na)+ja|0;pa=p>>>0>oa>>>0;qa=pa?oa:p;if(!(ma<<24>>24==9)){L=32;break}ma=d[1369984+la|0]|ha<<4;if(!(ma>>>0<134217728>>>0)){ra=ma;break}oa=r+(qa>>>3)|0;sa=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(qa&7);if(pa){ha=ma;ja=qa;ka=sa}else{ra=ma;break}}if((L|0)==32){L=0;ra=d[1369984+la|0]|ha<<(na-1>>1)}ta=ra-1|0;ua=qa}else{ka=ia>>>24;ja=(d[1369728+ka|0]|0)+ga|0;ta=d[1369216+ka|0]|0;ua=p>>>0>ja>>>0?ja:p}if((ta|0)==0){va=0;wa=ua}else{ja=(W+(ca(ta,R)|0)|0)>>>2;ka=d[r+(ua>>>3)|0]<<(ua&7)>>>7&1;va=(ja^-ka)+ka&65535;wa=((ua|0)<(p|0))+ua|0}b[ea+(fa<<1)>>1]=va;ka=fa+1|0;if((ka|0)<(J|0)){fa=ka;ga=wa}else{xa=wa;break}}}else{xa=_}ga=S+1|0;if((ga|0)<(E|0)){S=ga;ea=ea+(U<<1)|0;_=xa}else{N=xa;break}}}}while(0);if((H|0)>=(n|0)){ya=N;break a}G=J;H=H+1|0;I=N}}else{ya=D}}while(0);if((C|0)>=(o|0)){break}B=E;C=C+1|0;D=ya}za=c[g>>2]|0}else{za=l}if((za|0)!=0){i=h;return 0}if((c[j+4004>>2]|0)!=0){i=h;return 0}j=c[k+24>>2]|0;za=c[k+12>>2]|0;l=(za|0)>1;if(l){g=1;ya=b[j>>1]|0;do{D=j+(g<<1)|0;ya=(b[D>>1]|0)+ya&65535;b[D>>1]=ya;g=g+1|0;}while((g|0)<(za|0))}g=c[k+8>>2]|0;ya=j+(g<<1)|0;j=c[k+16>>2]|0;if((j|0)<=1){i=h;return 0}k=-g|0;if(l){Aa=1;Ba=ya}else{l=1;D=ya;while(1){b[D>>1]=(b[D>>1]|0)+(b[D+(k<<1)>>1]|0);ya=l+1|0;if((ya|0)<(j|0)){l=ya;D=D+(g<<1)|0}else{break}}i=h;return 0}while(1){D=(b[Ba>>1]|0)+(b[Ba+(k<<1)>>1]|0)&65535;b[Ba>>1]=D;l=1;ya=D;do{D=l-g|0;C=Ba+(l<<1)|0;ya=(((((b[Ba+(D<<1)>>1]|0)+(ya<<16>>16)+(b[Ba+(D-1<<1)>>1]|0)|0)*21845|0)+32767|0)>>>16)+(e[C>>1]|0)&65535;b[C>>1]=ya;l=l+1|0;}while((l|0)<(za|0));l=Aa+1|0;if((l|0)<(j|0)){Aa=l;Ba=Ba+(g<<1)|0}else{break}}i=h;return 0}function N5(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=c[a+60>>2]|0;a=b;f=b+8|0;g=c[f>>2]|0;h=b+16|0;i=c[h>>2]|0;j=c[b>>2]|0;k=j+(g>>>3)|0;l=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(g&7)>>>25;k=g+7|0;g=i>>>0>k>>>0?k:i;c[f>>2]=g;k=b+28|0;m=c[k>>2]|0;n=m<<3;o=n>>>0>65535>>>0;p=o?m>>>13&65535:n;n=o?16:0;if((p&65280|0)==0){q=n;r=p}else{q=n|8;r=p>>>8}p=(d[1359664+r|0]|0)+q|0;q=p+1|0;do{if((q|0)==0){s=0;t=g}else{r=j+(g>>>3)|0;n=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(g&7);if((q|0)<26){r=g+q|0;o=i>>>0>r>>>0?r:i;c[f>>2]=o;s=n>>>((31-p|0)>>>0);t=o;break}else{o=g+16|0;r=i>>>0>o>>>0?o:i;c[f>>2]=r;o=p-15|0;m=j+(r>>>3)|0;u=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(r&7)>>>((47-p|0)>>>0);m=r+o|0;r=i>>>0>m>>>0?m:i;c[f>>2]=r;s=u|n>>>16<<o;t=r;break}}}while(0);j=b+12|0;g=(c[j>>2]|0)-t|0;q=((s|0)>(g|0)?g:s)+t|0;g=e+4008|0;if((c[g>>2]|0)==0){v=t;w=i}else{i=e+4088|0;t=b+20|0;r=b+24|0;o=e+1492|0;n=e+4072|0;u=e+4076|0;m=0;do{x=(m|0)!=0|0;do{y=l-(d[i+(m<<2)+x|0]|0)|0;O5(c[n>>2]|0,c[u>>2]|0,a,(y|0)>0?y:0,c[t>>2]|0,c[r>>2]|0,q,o+(m*160|0)+(x*40|0)|0,0);x=x+1|0;}while(x>>>0<4>>>0);m=m+1|0;}while(m>>>0<(c[g>>2]|0)>>>0);v=c[f>>2]|0;w=c[h>>2]|0}h=v-q|0;q=-v|0;m=w-v|0;if((h|0)<(q|0)){z=q}else{z=(m|0)<(h|0)?m:h}h=z+v|0;c[f>>2]=h;f=-8-p-s+(c[k>>2]<<3)|0;k=(c[j>>2]|0)-h|0;j=((f|0)>(k|0)?k:f)+h|0;if((c[g>>2]|0)==0){return 0}h=e+4088|0;f=b+20|0;k=b+24|0;b=e+2336|0;s=e+3180|0;p=e+4072|0;v=e+4076|0;e=0;do{z=(e|0)!=0|0;do{m=l-(d[h+(e<<2)+z|0]|0)|0;O5(c[p>>2]|0,c[v>>2]|0,a,(m|0)>0?m:0,c[f>>2]|0,c[k>>2]|0,j,b+(e*160|0)+(z*40|0)|0,s+(e*160|0)+(z*40|0)|0);z=z+1|0;}while(z>>>0<4>>>0);e=e+1|0;}while(e>>>0<(c[g>>2]|0)>>>0);return 0}function O5(e,f,g,h,i,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;n=c[l+12>>2]|0;o=((ca(n,i)|0)>>>0)/(e>>>0)|0;p=((ca(n,i+1|0)|0)>>>0)/(e>>>0)|0;e=c[l+16>>2]|0;i=((ca(e,j)|0)>>>0)/(f>>>0)|0;n=((ca(e,j+1|0)|0)>>>0)/(f>>>0)|0;f=(h|0)>68?68:h;h=c[690776+(f<<2)>>2]|0;j=l+8|0;e=c[j>>2]|0;q=(c[l+24>>2]|0)+((ca(e,i)|0)<<1)|0;if((m|0)==0){r=0}else{r=(c[m+24>>2]|0)+((ca(c[m+8>>2]|0,i)|0)<<1)|0}l=g+8|0;s=c[l>>2]|0;if(!((s|0)<(k|0)&(i|0)<(n|0))){return}t=(o|0)<(p|0);u=m+8|0;m=g+16|0;v=g|0;g=(c[692288+(f<<2)>>2]|0)+2|0;f=q;q=r;r=i;i=e;e=s;a:while(1){if(t){s=(q|0)==0;w=c[m>>2]|0;x=c[v>>2]|0;y=o;z=e;while(1){A=x+(z>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7);if((B&-1434451968|0)==0){A=1;C=z;D=B;while(1){E=D>>>24;F=a[1369728+E|0]|0;G=F&255;H=((F&255)>>>0>8>>>0?8:G)+C|0;I=w>>>0>H>>>0;J=I?H:w;if(!(F<<24>>24==9)){K=10;break}F=d[1369984+E|0]|0|A<<4;if(!(F>>>0<134217728>>>0)){L=F;break}H=x+(J>>>3)|0;M=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7);if(I){A=F;C=J;D=M}else{L=F;break}}if((K|0)==10){K=0;L=d[1369984+E|0]|0|A<<(G-1>>1)}c[l>>2]=J;N=L-1|0;O=J}else{D=B>>>24;C=(d[1369728+D|0]|0)+z|0;F=w>>>0>C>>>0?C:w;c[l>>2]=F;N=d[1369216+D|0]|0;O=F}if((N|0)==0){P=0;Q=O}else{F=(g+(ca(N,h)|0)|0)>>>2;D=(d[x+(O>>>3)|0]|0)<<(O&7)>>>7;C=((O|0)<(w|0))+O|0;c[l>>2]=C;M=D&1;P=(F^-M)+M&65535;Q=C}b[f+(y<<1)>>1]=P;if((Q|0)>=(k|0)){K=33;break a}if(s){R=Q}else{C=x+(Q>>>3)|0;M=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(Q&7);if((M&-1434451968|0)==0){C=1;F=Q;D=M;while(1){S=D>>>24;I=a[1369728+S|0]|0;T=I&255;H=((I&255)>>>0>8>>>0?8:T)+F|0;U=w>>>0>H>>>0;V=U?H:w;if(!(I<<24>>24==9)){K=21;break}I=d[1369984+S|0]|0|C<<4;if(!(I>>>0<134217728>>>0)){W=I;break}H=x+(V>>>3)|0;X=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(V&7);if(U){C=I;F=V;D=X}else{W=I;break}}if((K|0)==21){K=0;W=d[1369984+S|0]|0|C<<(T-1>>1)}c[l>>2]=V;Y=W-1|0;Z=V}else{D=M>>>24;F=(d[1369728+D|0]|0)+Q|0;B=w>>>0>F>>>0?F:w;c[l>>2]=B;Y=d[1369216+D|0]|0;Z=B}if((Y|0)==0){_=0;$=Z}else{B=(g+(ca(Y,h)|0)|0)>>>2;D=(d[x+(Z>>>3)|0]|0)<<(Z&7)>>>7;F=((Z|0)<(w|0))+Z|0;c[l>>2]=F;A=D&1;_=(B^-A)+A&65535;$=F}b[q+(y<<1)>>1]=_;if(($|0)<(k|0)){R=$}else{K=33;break a}}F=y+1|0;if((F|0)<(p|0)){y=F;z=R}else{break}}aa=c[j>>2]|0;ba=R}else{aa=i;ba=e}if((q|0)==0){da=0}else{da=q+(c[u>>2]<<1)|0}z=r+1|0;if((z|0)<(n|0)){f=f+(aa<<1)|0;q=da;r=z;i=aa;e=ba}else{K=33;break}}if((K|0)==33){return}}function P5(a){a=a|0;c[a>>2]=276;c[a+108>>2]=492;c[a+100>>2]=252;c[a+112>>2]=310;c[a+116>>2]=128;c[a+120>>2]=442;c[a+124>>2]=464;c[a+128>>2]=146;c[a+132>>2]=546;c[a+136>>2]=92;c[a+140>>2]=54;c[a+144>>2]=326;c[a+4>>2]=90;c[a+8>>2]=68;c[a+12>>2]=282;c[a+16>>2]=420;c[a+20>>2]=956;c[a+24>>2]=808;c[a+28>>2]=38;c[a+32>>2]=360;c[a+36>>2]=340;c[a+40>>2]=830;c[a+44>>2]=554;c[a+48>>2]=562;c[a+52>>2]=112;c[a+56>>2]=568;c[a+60>>2]=854;c[a+64>>2]=174;c[a+68>>2]=84;c[a+72>>2]=430;c[a+76>>2]=182;c[a+80>>2]=168;c[a+84>>2]=640;c[a+88>>2]=540;c[a+92>>2]=802;c[a+96>>2]=680;return}function Q5(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;if((i|0)<=0){return}j=h+5|0;k=(h|0)>0;l=g<<1;m=g*-2|0;n=g*3|0;o=g*-3|0;p=g<<2;if((j|0)>-3){q=f;r=e;s=c;t=b;u=0}else{v=f;f=e;e=c;c=b;b=0;while(1){do{if(k){w=0;while(1){x=w+1|0;y=(((d[e+x|0]|0)+(d[e+w|0]|0)|0)*21|0)+16+(((d[e+(w+2)|0]|0)+(d[e+(w-1)|0]|0)|0)*-7|0)-(d[e+(w-3)|0]|0)+(((d[e+(w+3)|0]|0)+(d[e+(w-2)|0]|0)|0)*3|0)-(d[e+(w+4)|0]|0)>>5;if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}a[f+w|0]=z;if((x|0)<(h|0)){w=x}else{break}}if(k){A=0}else{break}while(1){w=A+1|0;x=(((d[v+w|0]|0)+(d[v+A|0]|0)|0)*21|0)+16+(((d[v+(A+2)|0]|0)+(d[v+(A-1)|0]|0)|0)*-7|0)-(d[v+(A-3)|0]|0)+(((d[v+(A+3)|0]|0)+(d[v+(A-2)|0]|0)|0)*3|0)-(d[v+(A+4)|0]|0)>>5;if(x>>>0>255>>>0){B=-x>>31&255}else{B=x&255}a[c+A|0]=B;if((w|0)<(h|0)){A=w}else{break}}}}while(0);w=b+1|0;if((w|0)<(i|0)){v=v+g|0;f=f+g|0;e=e+g|0;c=c+g|0;b=w}else{break}}return}while(1){b=-3;do{c=(((d[q+(b+g)|0]|0)+(d[q+b|0]|0)|0)*21|0)+16+(((d[q+(b+l)|0]|0)+(d[q+(b-g)|0]|0)|0)*-7|0)-(d[q+(b+o)|0]|0)+(((d[q+(b+n)|0]|0)+(d[q+(b+m)|0]|0)|0)*3|0)-(d[q+(b+p)|0]|0)>>5;if(c>>>0>255>>>0){C=-c>>31&255}else{C=c&255}a[s+b|0]=C;b=b+1|0;}while((b|0)<(j|0));do{if(k){b=0;while(1){c=b+1|0;e=(((d[s+c|0]|0)+(d[s+b|0]|0)|0)*21|0)+16+(((d[s+(b+2)|0]|0)+(d[s+(b-1)|0]|0)|0)*-7|0)-(d[s+(b-3)|0]|0)+(((d[s+(b+3)|0]|0)+(d[s+(b-2)|0]|0)|0)*3|0)-(d[s+(b+4)|0]|0)>>5;if(e>>>0>255>>>0){D=-e>>31&255}else{D=e&255}a[r+b|0]=D;if((c|0)<(h|0)){b=c}else{break}}if(k){E=0}else{break}while(1){b=E+1|0;c=(((d[q+b|0]|0)+(d[q+E|0]|0)|0)*21|0)+16+(((d[q+(E+2)|0]|0)+(d[q+(E-1)|0]|0)|0)*-7|0)-(d[q+(E-3)|0]|0)+(((d[q+(E+3)|0]|0)+(d[q+(E-2)|0]|0)|0)*3|0)-(d[q+(E+4)|0]|0)>>5;if(c>>>0>255>>>0){F=-c>>31&255}else{F=c&255}a[t+E|0]=F;if((b|0)<(h|0)){E=b}else{break}}}}while(0);b=u+1|0;if((b|0)<(i|0)){q=q+g|0;r=r+g|0;s=s+g|0;t=t+g|0;u=b}else{break}}return}function R5(c,d,f,g,h,i,j){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((j|0)<=0){return}k=(i|0)>0;l=g;g=d;d=c;c=0;while(1){if(k){m=0;do{n=(((e[g+(m<<1)>>1]|0)+32|0)>>>6)+(b[l+(m<<1)>>1]|0)|0;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[d+m|0]=o;n=m|1;p=(((e[g+(n<<1)>>1]|0)+32|0)>>>6)+(b[l+(n<<1)>>1]|0)|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[d+n|0]=q;m=m+2|0;}while((m|0)<(i|0))}m=c+1|0;if((m|0)<(j|0)){l=l+(h<<1)|0;g=g+(f<<1)|0;d=d+f|0;c=m}else{break}}return}function S5(c,d,e,f,g,h){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((h|0)<=0){return}i=(g|0)>0;j=e;e=c;c=0;while(1){if(i){k=0;do{l=b[j+(k<<1)>>1]|0;m=l+128|0;if(m>>>0>255>>>0){n=-128-l>>31&255}else{n=m&255}a[e+k|0]=n;m=k|1;l=b[j+(m<<1)>>1]|0;o=l+128|0;if(o>>>0>255>>>0){p=-128-l>>31&255}else{p=o&255}a[e+m|0]=p;m=k|2;o=b[j+(m<<1)>>1]|0;l=o+128|0;if(l>>>0>255>>>0){q=-128-o>>31&255}else{q=l&255}a[e+m|0]=q;m=k|3;l=b[j+(m<<1)>>1]|0;o=l+128|0;if(o>>>0>255>>>0){r=-128-l>>31&255}else{r=o&255}a[e+m|0]=r;k=k+4|0;}while((k|0)<(g|0))}k=c+1|0;if((k|0)<(h|0)){j=j+(f<<1)|0;e=e+d|0;c=k}else{break}}return}function T5(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=c;i=a;j=f;k=g}while(1){g=ca(d[j]|0,d[h]|0)|0;b[i>>1]=g+(b[i>>1]|0);g=ca(d[j+1|0]|0,d[h+1|0]|0)|0;f=i+2|0;b[f>>1]=g+(b[f>>1]|0);f=ca(d[j+2|0]|0,d[h+2|0]|0)|0;g=i+4|0;b[g>>1]=f+(b[g>>1]|0);g=ca(d[j+3|0]|0,d[h+3|0]|0)|0;f=i+6|0;b[f>>1]=g+(b[f>>1]|0);f=ca(d[j+4|0]|0,d[h+4|0]|0)|0;g=i+8|0;b[g>>1]=f+(b[g>>1]|0);g=ca(d[j+5|0]|0,d[h+5|0]|0)|0;f=i+10|0;b[f>>1]=g+(b[f>>1]|0);f=ca(d[j+6|0]|0,d[h+6|0]|0)|0;g=i+12|0;b[g>>1]=f+(b[g>>1]|0);g=ca(d[j+7|0]|0,d[h+7|0]|0)|0;f=i+14|0;b[f>>1]=g+(b[f>>1]|0);f=k-1|0;if((f|0)==0){break}else{h=h+e|0;i=i+(e<<1)|0;j=j+32|0;k=f}}return}function U5(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=c;i=a;j=f;k=g}while(1){g=0;do{f=ca(d[j+g|0]|0,d[h+g|0]|0)|0;a=i+(g<<1)|0;b[a>>1]=f+(b[a>>1]|0);a=g|1;f=ca(d[j+a|0]|0,d[h+a|0]|0)|0;c=i+(a<<1)|0;b[c>>1]=f+(b[c>>1]|0);g=g+2|0;}while((g|0)<16);g=k-1|0;if((g|0)==0){break}else{h=h+e|0;i=i+(e<<1)|0;j=j+32|0;k=g}}return}function V5(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=c;i=a;j=f;k=g}while(1){g=0;do{f=ca(d[j+g|0]|0,d[h+g|0]|0)|0;a=i+(g<<1)|0;b[a>>1]=f+(b[a>>1]|0);a=g|1;f=ca(d[j+a|0]|0,d[h+a|0]|0)|0;c=i+(a<<1)|0;b[c>>1]=f+(b[c>>1]|0);g=g+2|0;}while((g|0)<32);g=k-1|0;if((g|0)==0){break}else{h=h+e|0;i=i+(e<<1)|0;j=j+32|0;k=g}}return}function W5(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((g|0)==0){return}h=1<<e-1;i=b;b=g;while(1){g=0;j=a[i]|0;while(1){k=(ca(j&255,f)|0)+h>>e;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i+g|0]=l;k=g+1|0;m=i+k|0;n=(ca(d[m]|0,f)|0)+h>>e;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[m]=o;if((k|0)<8){g=k;j=o}else{break}}j=b-1|0;if((j|0)==0){break}else{i=i+c|0;b=j}}return}function X5(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((g|0)==0){return}h=1<<e-1;i=b;b=g;while(1){g=0;j=a[i]|0;while(1){k=(ca(j&255,f)|0)+h>>e;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i+g|0]=l;k=g+1|0;m=i+k|0;n=(ca(d[m]|0,f)|0)+h>>e;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[m]=o;if((k|0)<16){g=k;j=o}else{break}}j=b-1|0;if((j|0)==0){break}else{i=i+c|0;b=j}}return}function Y5(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((g|0)==0){return}h=1<<e-1;i=b;b=g;while(1){g=0;j=a[i]|0;while(1){k=(ca(j&255,f)|0)+h>>e;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i+g|0]=l;k=g+1|0;m=i+k|0;n=(ca(d[m]|0,f)|0)+h>>e;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[m]=o;if((k|0)<32){g=k;j=o}else{break}}j=b-1|0;if((j|0)==0){break}else{i=i+c|0;b=j}}return}function Z5(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==0){return}j=1<<f-1;k=c;c=b;b=i;while(1){i=0;l=a[c]|0;while(1){m=(ca(d[k+i|0]|0,h)|0)+j+(ca(l&255,g)|0)>>f;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[c+i|0]=n;m=i+1|0;o=ca(d[k+m|0]|0,h)|0;p=c+m|0;q=o+j+(ca(d[p]|0,g)|0)>>f;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[p]=r;if((m|0)<8){i=m;l=r}else{break}}l=b-1|0;if((l|0)==0){break}else{k=k+e|0;c=c+e|0;b=l}}return}function _5(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==0){return}j=1<<f-1;k=c;c=b;b=i;while(1){i=0;l=a[c]|0;while(1){m=(ca(d[k+i|0]|0,h)|0)+j+(ca(l&255,g)|0)>>f;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[c+i|0]=n;m=i+1|0;o=ca(d[k+m|0]|0,h)|0;p=c+m|0;q=o+j+(ca(d[p]|0,g)|0)>>f;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[p]=r;if((m|0)<16){i=m;l=r}else{break}}l=b-1|0;if((l|0)==0){break}else{k=k+e|0;c=c+e|0;b=l}}return}function $5(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==0){return}j=1<<f-1;k=c;c=b;b=i;while(1){i=0;l=a[c]|0;while(1){m=(ca(d[k+i|0]|0,h)|0)+j+(ca(l&255,g)|0)>>f;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[c+i|0]=n;m=i+1|0;o=ca(d[k+m|0]|0,h)|0;p=c+m|0;q=o+j+(ca(d[p]|0,g)|0)>>f;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[p]=r;if((m|0)<32){i=m;l=r}else{break}}l=b-1|0;if((l|0)==0){break}else{k=k+e|0;c=c+e|0;b=l}}return}function a6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=ca(d[h]|0,d[l+g|0]|0)|0;q=ca(d[i]|0,d[m+g|0]|0)|0;r=ca(d[j]|0,d[n+g|0]|0)|0;a[e+g|0]=(p+8+q+r+(ca(d[k]|0,d[o+g|0]|0)|0)|0)>>>4;g=g+1|0;}while((g|0)<8);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function b6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=ca(d[h]|0,d[l+g|0]|0)|0;q=ca(d[i]|0,d[m+g|0]|0)|0;r=ca(d[j]|0,d[n+g|0]|0)|0;a[e+g|0]=(p+8+q+r+(ca(d[k]|0,d[o+g|0]|0)|0)|0)>>>4;g=g+1|0;}while((g|0)<16);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function c6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=ca(d[h]|0,d[l+g|0]|0)|0;q=ca(d[i]|0,d[m+g|0]|0)|0;r=ca(d[j]|0,d[n+g|0]|0)|0;a[e+g|0]=(p+8+q+r+(ca(d[k]|0,d[o+g|0]|0)|0)|0)>>>4;g=g+1|0;}while((g|0)<32);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function d6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=e+g|0;q=ca(d[h]|0,d[l+g|0]|0)|0;r=ca(d[i]|0,d[m+g|0]|0)|0;s=ca(d[j]|0,d[n+g|0]|0)|0;a[p]=((d[p]|0)+1+((q+8+r+s+(ca(d[k]|0,d[o+g|0]|0)|0)|0)>>>4)|0)>>>1;g=g+1|0;}while((g|0)<8);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function e6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=e+g|0;q=ca(d[h]|0,d[l+g|0]|0)|0;r=ca(d[i]|0,d[m+g|0]|0)|0;s=ca(d[j]|0,d[n+g|0]|0)|0;a[p]=((d[p]|0)+1+((q+8+r+s+(ca(d[k]|0,d[o+g|0]|0)|0)|0)>>>4)|0)>>>1;g=g+1|0;}while((g|0)<16);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function f6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=c[e+16>>2]|0;if((g|0)==0){return}i=h+1|0;j=h+2|0;k=h+3|0;l=c[e>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+12>>2]|0;e=b;b=g;while(1){g=0;do{p=e+g|0;q=ca(d[h]|0,d[l+g|0]|0)|0;r=ca(d[i]|0,d[m+g|0]|0)|0;s=ca(d[j]|0,d[n+g|0]|0)|0;a[p]=((d[p]|0)+1+((q+8+r+s+(ca(d[k]|0,d[o+g|0]|0)|0)|0)>>>4)|0)>>>1;g=g+1|0;}while((g|0)<32);g=b-1|0;if((g|0)==0){break}else{l=l+f|0;m=m+f|0;n=n+f|0;o=o+f|0;e=e+f|0;b=g}}return}function g6(a){a=a|0;var b=0,d=0,e=0;b=0;while(1){if(!(b>>>0<11>>>0)){d=-1;e=4;break}if((c[1399480+(b*140|0)>>2]|0)==(a|0)){d=b;e=4;break}else{b=b+1|0}}if((e|0)==4){return d|0}return 0}function h6(a){a=a|0;var b=0,d=0,e=0;b=0;while(1){if(!(b>>>0<11>>>0)){d=-1;e=6;break}if((c[1399480+(b*140|0)>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==6){return d|0}if((b|0)<0){d=b;return d|0}d=c[1399496+(b*140|0)>>2]|0;return d|0}function i6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+72>>2]|0;e=(d|0)/1e6|0;if(!((d+999999|0)>>>0>1999998>>>0)){f=0;return f|0}d=c[a+120>>2]|0;g=a+124|0;h=a+88|0;a=0;a:while(1){b:do{if((c[1399484+(a*140|0)>>2]|0)==(d|0)){if((c[1399488+(a*140|0)>>2]|0)!=(c[g>>2]|0)){break}if((c[1399492+(a*140|0)>>2]|0)!=((c[h>>2]|0)>>>18&1|0)){break}if((c[1399508+(a*140|0)>>2]|0)==(b|0)){i=0}else{break}while(1){if(!(i>>>0<5>>>0)){break b}if((c[1399560+(a*140|0)+(i<<2)>>2]|0)==(e|0)){break a}else{i=i+1|0}}}}while(0);j=a+1|0;if(j>>>0<11>>>0){a=j}else{f=0;k=11;break}}if((k|0)==11){return f|0}f=c[1399480+(a*140|0)>>2]|0;return f|0}function j6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;a=0;do{f=(a-3|0)>>>0<3>>>0?105:112;g=(1097>>>(a>>>0)&1|0)!=0?2608720:2455120;h=c[1399560+(a*140|0)>>2]|0;j=c[1399484+(a*140|0)>>2]|0;k=c[1399488+(a*140|0)>>2]|0;l=c[1399580+(a*140|0)>>2]|0;m=c[1399584+(a*140|0)>>2]|0;KIb(e,b,2563904,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=h,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=m,n)|0);i=n;m=c[1399564+(a*140|0)>>2]|0;l=c[1399588+(a*140|0)>>2]|0;h=c[1399592+(a*140|0)>>2]|0;KIb(e,b,2563904,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=m,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=h,n)|0);i=n;do{if(!((a-3|0)>>>0<3>>>0)){h=c[1399568+(a*140|0)>>2]|0;l=c[1399596+(a*140|0)>>2]|0;m=c[1399600+(a*140|0)>>2]|0;KIb(e,b,2563904,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=h,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=m,n)|0);i=n;if((a-3|0)>>>0<3>>>0){break}m=c[1399572+(a*140|0)>>2]|0;l=c[1399604+(a*140|0)>>2]|0;h=c[1399608+(a*140|0)>>2]|0;KIb(e,b,2563904,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=m,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=h,n)|0);i=n;if((121>>>(a>>>0)&1|0)!=0){break}h=c[1399576+(a*140|0)>>2]|0;l=c[1399612+(a*140|0)>>2]|0;m=c[1399616+(a*140|0)>>2]|0;KIb(e,b,2563904,(n=i,i=i+56|0,c[n>>2]=j,c[n+8>>2]=k,c[n+16>>2]=f,c[n+24>>2]=h,c[n+32>>2]=g,c[n+40>>2]=l,c[n+48>>2]=m,n)|0);i=n}}while(0);a=a+1|0;}while(a>>>0<11>>>0);i=d;return}function k6(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;a=b+24|0;c[a>>2]=-1;c[a+4>>2]=-1;return 0}function l6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;h=i;i=i+16|0;j=h|0;k=c[g+24>>2]|0;l=g+28|0;g=c[l>>2]|0;m=c[b+60>>2]|0;n=m;o=e;c[j>>2]=o;c[j+4>>2]=0;c[j+8>>2]=0;if((g|0)<640){p=-1094995529;i=h;return p|0}q=m+36|0;r=m+32|0;s=m+3324|0;t=m;u=m+3320|0;v=m+396|0;w=m+3328|0;x=m+24|0;y=m+3316|0;z=m+40|0;A=m+44|0;B=e+296|0;C=b+120|0;D=b+124|0;E=e+88|0;F=e+84|0;H=b;I=m+324|0;J=m+344|0;K=m+364|0;L=m+1524|0;M=m+3184|0;N=m+320|0;m=e+300|0;e=g;g=k;k=1;a:while(1){if((grc(g,1520472,5)|0)!=0){if((grc(g,1520464,5)|0)!=0){O=5;break}}P=g+5|0;Q=d[P]|0;if((Q&2|0)!=0){c[N>>2]=Q&1;c[B>>2]=1;c[m>>2]=c[N>>2]^k;Q=c[N>>2]|0;KIb(c[t>>2]|0,48,2300360,(R=i,i=i+16|0,c[R>>2]=a[P]&3,c[R+8>>2]=Q,R)|0);i=R}Q=g+24|0;c[q>>2]=(he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535;Q=g+26|0;c[r>>2]=(he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535;c[s>>2]=0;do{if((a[g+4|0]|0)==2){Q=c[t>>2]|0;c[Q+140>>2]=78;c[Q+796>>2]=10;if((c[u>>2]|0)!=10){l8(v,Q);c[u>>2]=10;c[w>>2]=296}c[s>>2]=1}else{Q=c[t>>2]|0;P=Q+140|0;if((a[g+33|0]&64)==0){c[P>>2]=4;c[Q+796>>2]=8;if((c[u>>2]|0)==8){break}l8(v,Q);c[u>>2]=8;c[w>>2]=806;break}else{c[P>>2]=74;c[Q+796>>2]=10;if((c[u>>2]|0)==10){break}l8(v,Q);c[u>>2]=10;c[w>>2]=4;break}}}while(0);Q=g+40|0;S=je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;Q=S;P=0;if(!((Q|0)==(c[x>>2]|0)&(P|0)==(c[x+4>>2]|0))){T=g6(S)|0;if((T|0)<0){O=19;break}U=c[1399508+(T*140|0)>>2]|0;V=c[u>>2]|0;if((U|0)!=(V|0)){O=21;break}c[y>>2]=1399480+(T*140|0);c3(I);c3(J);c3(K);T=c[y>>2]|0;$2(I,9,257,c[T+56>>2]|0,1,1,c[T+52>>2]|0,2,2,0,0,0,0)|0;T=c[y>>2]|0;$2(J,7,(c[u>>2]|0)+4|0,c[T+48>>2]|0,1,1,c[T+44>>2]|0,1,1,0,0,0,0)|0;T=c[y>>2]|0;$2(K,9,62,c[T+72>>2]|0,1,1,c[T+68>>2]|0,2,2,0,0,0,0)|0;L6(L,M,1242080);c[x>>2]=Q;c[x+4>>2]=P}if((c[(c[y>>2]|0)+20>>2]|0)>>>0>e>>>0){O=24;break}c[z>>2]=(c[r>>2]|0)>>>4;P=a[g+365|0]|0;W=P&255;c[A>>2]=W;Q=c[q>>2]|0;do{if(((Q+15|0)>>>4|0)==(W|0)){if((c[B>>2]|0)==0){X=Q;break}T=Q<<1;c[q>>2]=T;X=T}else{X=Q}}while(0);if((P&255)>>>0>68>>>0){O=31;break}if(W<<c[B>>2]>>>0>(X+15|0)>>>4>>>0){O=31;break}Q=e;T=(e|0)<0|0?-1:0;if(!(P<<24>>24==0)){Y=0;do{Z=g+((Y<<2)+368)|0;_=je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0;c[n+48+(Y<<2)>>2]=_;Z=wrc(_,0,640,0)|0;_=G;if((T|0)<(_|0)|(T|0)==(_|0)&Q>>>0<Z>>>0){O=34;break a}Y=Y+1|0;}while(Y>>>0<(c[A>>2]|0)>>>0)}Y=c[C>>2]|0;if((Y|0)==0){if((c[D>>2]|0)==0){$=k}else{O=37}}else{O=37}do{if((O|0)==37){O=0;Q=c[r>>2]|0;if((Q|0)==(Y|0)){T=c[q>>2]|0;P=c[D>>2]|0;if((T|0)==(P|0)){$=k;break}else{aa=P;ba=T}}else{aa=c[D>>2]|0;ba=c[q>>2]|0}KIb(H,24,2455080,(R=i,i=i+32|0,c[R>>2]=Y,c[R+8>>2]=aa,c[R+16>>2]=Q,c[R+24>>2]=ba,R)|0);i=R;$=1}}while(0);Y=H4a(b,c[r>>2]|0,c[q>>2]|0)|0;if((Y|0)<0){p=Y;O=48;break}if(($|0)==0){O=46;break}Y=J5a(b,j,0)|0;if((Y|0)<0){p=Y;O=48;break}c[E>>2]=1;c[F>>2]=1;n6(n,o,g+640|0,e-640|0);if((c[B>>2]|0)==0){break}Y=c[(c[y>>2]|0)+20>>2]|0;Q=e-Y|0;if((Q|0)<640){p=-1094995529;O=48;break}else{e=Q;g=g+Y|0;k=0}}if((O|0)==5){KIb(c[t>>2]|0,16,2365648,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==19){KIb(c[t>>2]|0,16,2147024,(R=i,i=i+8|0,c[R>>2]=S,R)|0);i=R;p=-38;i=h;return p|0}else if((O|0)==21){KIb(c[t>>2]|0,16,2123224,(R=i,i=i+16|0,c[R>>2]=U,c[R+8>>2]=V,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==24){KIb(c[t>>2]|0,16,2249160,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==31){KIb(c[t>>2]|0,16,2206968,(R=i,i=i+8|0,c[R>>2]=W,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==34){KIb(c[t>>2]|0,16,2174568,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;p=-1094995529;i=h;return p|0}else if((O|0)==46){n6(n,o,g+640|0,e-640|0)}else if((O|0)==48){i=h;return p|0}c[f>>2]=1;p=c[l>>2]|0;i=h;return p|0}function m6(a){a=a|0;var b=0;b=c[a+60>>2]|0;c3(b+324|0);c3(b+344|0);c3(b+364|0);return 0}function n6(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;g=a+44|0;h=c[g>>2]|0;if((h|0)==0){return}i=a+3320|0;j=a+392|0;k=a+388|0;l=a+384|0;m=a+4|0;n=a+16|0;o=a+20|0;p=a+8|0;q=a+12|0;r=a+40|0;s=b+32|0;t=b+36|0;u=a+3332|0;v=a+432|0;w=a+3328|0;x=a+1648|0;y=a+1776|0;z=a+1904|0;A=a+2032|0;B=a+2160|0;C=a+2288|0;D=a+2416|0;E=a+2544|0;F=a+3324|0;G=b+296|0;H=b|0;I=b+4|0;J=b+8|0;K=a+320|0;L=a+1516|0;M=a|0;N=a+2672|0;O=a+2800|0;P=a+2928|0;Q=a+3056|0;R=b+40|0;b=a+3316|0;S=0;T=c[r>>2]|0;U=h;while(1){h=c[i>>2]|0;V=1<<h+2;c[j>>2]=V;c[k>>2]=V;c[l>>2]=V;V=c[a+48+(S<<2)>>2]|0;W=e+V|0;X=f-V<<3;V=X>>>0>2147483639>>>0|(W|0)==0;Y=V?0:W;W=V?0:X;c[m>>2]=Y;c[n>>2]=W;X=W+8|0;c[o>>2]=X;c[p>>2]=Y+(W>>3);c[q>>2]=0;if((T|0)==0){Z=0;_=U}else{W=S<<4;V=0;$=h;h=0;aa=X;X=Y;while(1){Y=($|0)==10;ba=Y&1;da=c[s>>2]|0;ea=c[t>>2]|0;fa=X+(h>>>3)|0;ga=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(h&7)>>>21;fa=h+11|0;ha=(aa>>>0>fa>>>0?fa:aa)+1|0;c[q>>2]=aa>>>0>ha>>>0?ha:aa;if((ga|0)!=(c[u>>2]|0)){ha=0;do{c[a+3336+(ha<<2)>>2]=ca(d[(c[(c[b>>2]|0)+36>>2]|0)+ha|0]|0,ga)|0;c[a+3592+(ha<<2)>>2]=ca(d[(c[(c[b>>2]|0)+40>>2]|0)+ha|0]|0,ga)|0;ha=ha+1|0;}while((ha|0)<64);c[u>>2]=ga}qe[c[v>>2]&1023](x);mf[c[w>>2]&2047](a,x,0,ga);qe[c[v>>2]&1023](y);mf[c[w>>2]&2047](a,y,1,ga);qe[c[v>>2]&1023](z);mf[c[w>>2]&2047](a,z,2,ga);qe[c[v>>2]&1023](A);mf[c[w>>2]&2047](a,A,3,ga);qe[c[v>>2]&1023](B);mf[c[w>>2]&2047](a,B,4,ga);qe[c[v>>2]&1023](C);mf[c[w>>2]&2047](a,C,5,ga);qe[c[v>>2]&1023](D);mf[c[w>>2]&2047](a,D,6,ga);qe[c[v>>2]&1023](E);mf[c[w>>2]&2047](a,E,7,ga);if((c[F>>2]|0)!=0){qe[c[v>>2]&1023](N);mf[c[w>>2]&2047](a,N,8,ga);qe[c[v>>2]&1023](O);mf[c[w>>2]&2047](a,O,9,ga);qe[c[v>>2]&1023](P);mf[c[w>>2]&2047](a,P,10,ga);qe[c[v>>2]&1023](Q);mf[c[w>>2]&2047](a,Q,11,ga)}if((c[G>>2]|0)==0){ia=da;ja=ea}else{ia=da<<1;ja=ea<<1}ha=c[H>>2]|0;fa=(ca(ia,W)|0)+(V<<(ba|4))|0;ka=c[I>>2]|0;la=ca(ja,W)|0;ma=c[F>>2]|0;na=(V<<ma+(Y?4:3))+la|0;la=c[J>>2]|0;if((c[K>>2]|0)==0){oa=na;pa=na;qa=fa}else{oa=(c[R>>2]|0)+na|0;pa=(c[t>>2]|0)+na|0;qa=(c[s>>2]|0)+fa|0}fa=la+oa|0;na=ka+pa|0;ra=ia<<3;sa=8<<ba;ef[c[L>>2]&4095](ha+qa|0,ia,x);ef[c[L>>2]&4095](ha+(qa+sa)|0,ia,y);ta=c[L>>2]|0;ua=ha+(qa+ra)|0;do{if((ma|0)==0){ef[ta&4095](ua,ia,B);ef[c[L>>2]&4095](ha+(ra+sa+qa)|0,ia,C);if((c[(c[M>>2]|0)+88>>2]&8192|0)!=0){break}va=ja<<3;ef[c[L>>2]&4095](na,ja,z);ef[c[L>>2]&4095](fa,ja,A);ef[c[L>>2]&4095](ka+(pa+va)|0,ja,D);ef[c[L>>2]&4095](la+(oa+va)|0,ja,E)}else{ef[ta&4095](ua,ia,D);ef[c[L>>2]&4095](ha+(ra+sa+qa)|0,ia,E);if((c[(c[M>>2]|0)+88>>2]&8192|0)!=0){break}va=ja<<3;ef[c[L>>2]&4095](na,ja,z);ef[c[L>>2]&4095](ka+(pa+sa)|0,ja,A);ef[c[L>>2]&4095](ka+(pa+va)|0,ja,N);wa=va+sa|0;ef[c[L>>2]&4095](ka+(pa+wa)|0,ja,O);ef[c[L>>2]&4095](fa,ja,B);ef[c[L>>2]&4095](la+(oa+sa)|0,ja,C);ef[c[L>>2]&4095](la+(oa+va)|0,ja,P);ef[c[L>>2]&4095](la+(oa+wa)|0,ja,Q)}}while(0);la=V+1|0;xa=c[r>>2]|0;if(!(la>>>0<xa>>>0)){break}V=la;$=c[i>>2]|0;h=c[q>>2]|0;aa=c[o>>2]|0;X=c[m>>2]|0}Z=xa;_=c[g>>2]|0}X=S+1|0;if(X>>>0<_>>>0){S=X;T=Z;U=_}else{break}}return}function o6(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;j=e+3316|0;k=c[j>>2]|0;l=c[k+60>>2]|0;m=c[k+64>>2]|0;n=c[k+32>>2]|0;o=e+12|0;p=c[o>>2]|0;q=c[e+20>>2]|0;do{if((c[e+3324>>2]|0)==0){if((g&2|0)==0){r=0;s=e+3336|0;t=k+36|0;break}else{r=(g&1)+1|0;s=e+3592|0;t=k+40|0;break}}else{u=(g>>1|0)%3|0;if((u|0)==0){r=0;s=e+3336|0;t=k+36|0;break}else{r=u;s=e+3592|0;t=k+40|0;break}}}while(0);k=c[t>>2]|0;t=e+4|0;u=c[t>>2]|0;v=u+(p>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(p&7);v=w>>>25;x=c[e+348>>2]|0;y=b[x+(v<<2)>>1]|0;z=y<<16>>16;A=b[x+(v<<2)+2>>1]|0;v=w<<A;w=A+p|0;p=q>>>0>w>>>0?w:q;if(y<<16>>16==0){B=p;C=u;D=c[e+384+(r<<2)>>2]&65535}else{u=p+z|0;p=v^-2147483648;y=p>>31;w=e+384+(r<<2)|0;r=((y^v)>>>((32-z|0)>>>0)^y)+(p>>>31)+(c[w>>2]|0)|0;c[w>>2]=r;B=q>>>0>u>>>0?u:q;C=c[t>>2]|0;D=r&65535}b[f>>1]=D;D=C+(B>>>3)|0;r=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7);D=r>>>23;t=c[e+328>>2]|0;u=b[t+(D<<2)>>1]|0;w=b[t+(D<<2)+2>>1]|0;D=w<<16>>16;if(w<<16>>16<0){w=B+9|0;p=q>>>0>w>>>0?w:q;w=C+(p>>>3)|0;y=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(p&7);w=(y>>>((D+32|0)>>>0))+u|0;E=b[t+(w<<2)>>1]|0;F=b[t+(w<<2)+2>>1]|0;G=y;H=p}else{E=u;F=D;G=r;H=B}B=F+H|0;H=q>>>0>B>>>0?B:q;if((E|0)==(n|0)){I=H;c[o>>2]=I;i=h;return}B=e+368|0;r=H;H=G<<F;F=E;E=0;while(1){G=d[l+F|0]|0;D=d[m+F|0]|0;u=H>>31;p=r+1|0;y=q>>>0>p>>>0?p:q;if((D&1|0)==0){J=G;K=y}else{p=y+6|0;J=G+(H>>>25<<7&8064)|0;K=q>>>0>p>>>0?p:q}if((D&2|0)==0){L=E;M=K}else{D=C+(K>>>3)|0;p=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7)>>>23;D=c[B>>2]|0;G=b[D+(p<<2)>>1]|0;y=b[D+(p<<2)+2>>1]|0;p=y<<16>>16;if(y<<16>>16<0){y=K+9|0;w=q>>>0>y>>>0?y:q;y=C+(w>>>3)|0;z=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>((p+32|0)>>>0))+G|0;N=b[D+(z<<2)+2>>1]|0;O=b[D+(z<<2)>>1]|0;P=w}else{N=p;O=G;P=K}G=N+P|0;L=(d[(c[(c[j>>2]|0)+76>>2]|0)+O|0]|0)+E|0;M=q>>>0>G>>>0?G:q}Q=L+1|0;if((Q|0)>63){break}G=ca(c[s+(Q<<2)>>2]|0,J)|0;b[f+(d[e+3188+Q|0]<<1)>>1]=((((a[k+Q|0]|0)==32?0:32)+G|0)>>>6^u)-u;u=C+(M>>>3)|0;G=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(M&7);u=G>>>23;p=b[t+(u<<2)>>1]|0;w=b[t+(u<<2)+2>>1]|0;u=w<<16>>16;if(w<<16>>16<0){w=M+9|0;z=q>>>0>w>>>0?w:q;w=C+(z>>>3)|0;D=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(z&7);w=(D>>>((u+32|0)>>>0))+p|0;R=b[t+(w<<2)+2>>1]|0;S=b[t+(w<<2)>>1]|0;T=D;U=z}else{R=u;S=p;T=G;U=M}G=R+U|0;p=q>>>0>G>>>0?G:q;if((S|0)==(n|0)){I=p;V=26;break}else{r=p;H=T<<R;F=S;E=Q}}if((V|0)==26){c[o>>2]=I;i=h;return}KIb(c[e>>2]|0,16,2640880,(e=i,i=i+16|0,c[e>>2]=g,c[e+8>>2]=Q,e)|0);i=e;I=M;c[o>>2]=I;i=h;return}function p6(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;h=a+3316|0;j=c[h>>2]|0;k=c[j+60>>2]|0;l=c[j+64>>2]|0;m=c[j+32>>2]|0;j=a+12|0;n=c[j>>2]|0;o=c[a+20>>2]|0;do{if((c[a+3324>>2]|0)==0){if((f&2|0)==0){p=0;q=a+3336|0;break}else{p=(f&1)+1|0;q=a+3592|0;break}}else{r=(f>>1|0)%3|0;if((r|0)==0){p=0;q=a+3336|0;break}else{p=r;q=a+3592|0;break}}}while(0);r=a+4|0;s=c[r>>2]|0;t=s+(n>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(n&7);t=u>>>25;v=c[a+348>>2]|0;w=b[v+(t<<2)>>1]|0;x=w<<16>>16;y=b[v+(t<<2)+2>>1]|0;t=u<<y;u=y+n|0;n=o>>>0>u>>>0?u:o;if(w<<16>>16==0){z=n;A=s;B=c[a+384+(p<<2)>>2]&65535}else{s=n+x|0;n=t^-2147483648;w=n>>31;u=a+384+(p<<2)|0;p=((w^t)>>>((32-x|0)>>>0)^w)+(n>>>31)+(c[u>>2]|0)|0;c[u>>2]=p;z=o>>>0>s>>>0?s:o;A=c[r>>2]|0;B=p&65535}b[e>>1]=B;B=A+(z>>>3)|0;p=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7);B=p>>>23;r=c[a+328>>2]|0;s=b[r+(B<<2)>>1]|0;u=b[r+(B<<2)+2>>1]|0;B=u<<16>>16;if(u<<16>>16<0){u=z+9|0;n=o>>>0>u>>>0?u:o;u=A+(n>>>3)|0;w=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(n&7);u=(w>>>((B+32|0)>>>0))+s|0;C=b[r+(u<<2)>>1]|0;D=b[r+(u<<2)+2>>1]|0;E=w;F=n}else{C=s;D=B;E=p;F=z}z=D+F|0;F=o>>>0>z>>>0?z:o;if((C|0)==(m|0)){G=F;c[j>>2]=G;i=g;return}z=a+368|0;p=F;F=E<<D;D=C;C=0;while(1){E=d[k+D|0]|0;B=d[l+D|0]|0;s=F>>31;n=p+1|0;w=o>>>0>n>>>0?n:o;if((B&1|0)==0){H=E;I=w}else{n=w+6|0;H=E+(F>>>25<<7&8064)|0;I=o>>>0>n>>>0?n:o}if((B&2|0)==0){J=C;K=I}else{B=A+(I>>>3)|0;n=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(I&7)>>>23;B=c[z>>2]|0;E=b[B+(n<<2)>>1]|0;w=b[B+(n<<2)+2>>1]|0;n=w<<16>>16;if(w<<16>>16<0){w=I+9|0;u=o>>>0>w>>>0?w:o;w=A+(u>>>3)|0;x=((je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>((n+32|0)>>>0))+E|0;L=b[B+(x<<2)+2>>1]|0;M=b[B+(x<<2)>>1]|0;N=u}else{L=n;M=E;N=I}E=L+N|0;J=(d[(c[(c[h>>2]|0)+76>>2]|0)+M|0]|0)+C|0;K=o>>>0>E>>>0?E:o}O=J+1|0;if((O|0)>63){break}b[e+(d[a+3188+O|0]<<1)>>1]=(((ca(c[q+(O<<2)>>2]|0,H)|0)+8|0)>>>4^s)-s;s=A+(K>>>3)|0;E=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(K&7);s=E>>>23;n=b[r+(s<<2)>>1]|0;u=b[r+(s<<2)+2>>1]|0;s=u<<16>>16;if(u<<16>>16<0){u=K+9|0;x=o>>>0>u>>>0?u:o;u=A+(x>>>3)|0;B=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7);u=(B>>>((s+32|0)>>>0))+n|0;P=b[r+(u<<2)+2>>1]|0;Q=b[r+(u<<2)>>1]|0;R=B;S=x}else{P=s;Q=n;R=E;S=K}E=P+S|0;n=o>>>0>E>>>0?E:o;if((Q|0)==(m|0)){G=n;T=26;break}else{p=n;F=R<<P;D=Q;C=O}}if((T|0)==26){c[j>>2]=G;i=g;return}KIb(c[a>>2]|0,16,2640880,(a=i,i=i+16|0,c[a>>2]=f,c[a+8>>2]=O,a)|0);i=a;G=K;c[j>>2]=G;i=g;return}function q6(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;j=e+3316|0;k=c[j>>2]|0;l=c[k+60>>2]|0;m=c[k+64>>2]|0;n=c[k+32>>2]|0;o=e+12|0;p=c[o>>2]|0;q=c[e+20>>2]|0;do{if((c[e+3324>>2]|0)==0){if((g&2|0)==0){r=0;s=e+3336|0;t=k+36|0;break}else{r=(g&1)+1|0;s=e+3592|0;t=k+40|0;break}}else{u=(g>>1|0)%3|0;if((u|0)==0){r=0;s=e+3336|0;t=k+36|0;break}else{r=u;s=e+3592|0;t=k+40|0;break}}}while(0);k=c[t>>2]|0;t=e+4|0;u=c[t>>2]|0;v=u+(p>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(p&7);v=w>>>25;x=c[e+348>>2]|0;y=b[x+(v<<2)>>1]|0;z=y<<16>>16;A=b[x+(v<<2)+2>>1]|0;v=w<<A;w=A+p|0;p=q>>>0>w>>>0?w:q;if(y<<16>>16==0){B=p;C=u;D=c[e+384+(r<<2)>>2]&65535}else{u=p+z|0;p=v^-2147483648;y=p>>31;w=e+384+(r<<2)|0;r=((y^v)>>>((32-z|0)>>>0)^y)+(p>>>31)+(c[w>>2]|0)|0;c[w>>2]=r;B=q>>>0>u>>>0?u:q;C=c[t>>2]|0;D=r&65535}b[f>>1]=D;D=C+(B>>>3)|0;r=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7);D=r>>>23;t=c[e+328>>2]|0;u=b[t+(D<<2)>>1]|0;w=b[t+(D<<2)+2>>1]|0;D=w<<16>>16;if(w<<16>>16<0){w=B+9|0;p=q>>>0>w>>>0?w:q;w=C+(p>>>3)|0;y=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(p&7);w=(y>>>((D+32|0)>>>0))+u|0;E=b[t+(w<<2)>>1]|0;F=b[t+(w<<2)+2>>1]|0;G=y;H=p}else{E=u;F=D;G=r;H=B}B=F+H|0;H=q>>>0>B>>>0?B:q;if((E|0)==(n|0)){I=H;c[o>>2]=I;i=h;return}B=e+368|0;r=H;H=G<<F;F=E;E=0;while(1){G=d[l+F|0]|0;D=d[m+F|0]|0;u=H>>31;p=r+1|0;y=q>>>0>p>>>0?p:q;if((D&1|0)==0){J=G;K=y}else{p=y+4|0;J=G+(H>>>27<<7&1920)|0;K=q>>>0>p>>>0?p:q}if((D&2|0)==0){L=E;M=K}else{D=C+(K>>>3)|0;p=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7)>>>23;D=c[B>>2]|0;G=b[D+(p<<2)>>1]|0;y=b[D+(p<<2)+2>>1]|0;p=y<<16>>16;if(y<<16>>16<0){y=K+9|0;w=q>>>0>y>>>0?y:q;y=C+(w>>>3)|0;z=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>((p+32|0)>>>0))+G|0;N=b[D+(z<<2)+2>>1]|0;O=b[D+(z<<2)>>1]|0;P=w}else{N=p;O=G;P=K}G=N+P|0;L=(d[(c[(c[j>>2]|0)+76>>2]|0)+O|0]|0)+E|0;M=q>>>0>G>>>0?G:q}Q=L+1|0;if((Q|0)>63){break}G=ca(c[s+(Q<<2)>>2]|0,J)|0;b[f+(d[e+3188+Q|0]<<1)>>1]=((((a[k+Q|0]|0)==32?0:32)+G|0)>>>6^u)-u;u=C+(M>>>3)|0;G=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(M&7);u=G>>>23;p=b[t+(u<<2)>>1]|0;w=b[t+(u<<2)+2>>1]|0;u=w<<16>>16;if(w<<16>>16<0){w=M+9|0;z=q>>>0>w>>>0?w:q;w=C+(z>>>3)|0;D=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(z&7);w=(D>>>((u+32|0)>>>0))+p|0;R=b[t+(w<<2)+2>>1]|0;S=b[t+(w<<2)>>1]|0;T=D;U=z}else{R=u;S=p;T=G;U=M}G=R+U|0;p=q>>>0>G>>>0?G:q;if((S|0)==(n|0)){I=p;V=26;break}else{r=p;H=T<<R;F=S;E=Q}}if((V|0)==26){c[o>>2]=I;i=h;return}KIb(c[e>>2]|0,16,2640880,(e=i,i=i+16|0,c[e>>2]=g,c[e+8>>2]=Q,e)|0);i=e;I=M;c[o>>2]=I;i=h;return}function r6(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;g=i;i=i+128|0;h=g|0;j=c[f+60>>2]|0;k=j;l=c[f+140>>2]|0;if((l|0)==4){m=8}else if((l|0)==74){m=10}else{KIb(f,16,2365600,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}l=i6(f,m)|0;m=j+14680|0;c[m>>2]=l;p=f;if((l|0)==0){KIb(p,16,2300288,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j6(f,16);o=-22;i=g;return o|0}KIb(p,48,2249152,(n=i,i=i+8|0,c[n>>2]=l,n)|0);i=n;l=g6(c[m>>2]|0)|0;if(!((l|0)>-1)){KIb(0,0,2206936,(n=i,i=i+24|0,c[n>>2]=2174552,c[n+8>>2]=2147e3,c[n+16>>2]=277,n)|0);i=n;Hd();return 0}m=j+14684|0;c[m>>2]=1399480+(l*140|0);q=j+8|0;r=j+12|0;c[r>>2]=f;c[j+12496>>2]=1;c[j+236>>2]=1;c[f+796>>2]=c[1399508+(l*140|0)>>2];cTa(q)|0;ZTa(q)|0;q=j+14400|0;if((c[q>>2]|0)==0){c[q>>2]=4}if((c[(c[m>>2]|0)+28>>2]|0)==10){c[q>>2]=174;c[j+15964>>2]=1520;c[j+14836>>2]=4}else{c[j+15964>>2]=1802;c[j+14836>>2]=3}q=(c[f+124>>2]|0)+15|0;l=(q|0)/16|0;s=j+128|0;c[s>>2]=l;t=((c[f+120>>2]|0)+15|0)/16|0;c[j+124>>2]=t;if((c[f+88>>2]&262144|0)==0){u=l}else{c[j+14840>>2]=1;l=(q|0)/32|0;c[s>>2]=l;u=l}l=j+152|0;c[l>>2]=ca(t,u)|0;u=c[f+280>>2]|0;if((u|0)!=999999){c[j+13080>>2]=u}mrc(h|0,0,128)|0;u=h|0;b[u>>1]=1;t=c[m>>2]|0;q=c[t+36>>2]|0;v=c[t+40>>2]|0;t=pJb((c[(c[r>>2]|0)+504>>2]<<8)+256|0)|0;w=j+15892|0;c[w>>2]=t;x=c[r>>2]|0;y=c[x+504>>2]|0;do{if((t|0)==0){if((y&16777215|0)==16777215){break}KIb(x,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);x=pJb((y<<8)+256|0)|0;y=j+15888|0;c[y>>2]=x;t=c[r>>2]|0;z=c[t+504>>2]|0;do{if((x|0)==0){if((z&16777215|0)==16777215){break}KIb(t,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);t=pJb((z<<8)+256|0)|0;z=j+15896|0;c[z>>2]=t;x=c[r>>2]|0;A=c[x+504>>2]|0;do{if((t|0)==0){if((A&16777215|0)==16777215){break}KIb(x,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);x=pJb((A<<8)+256|0)|0;A=x;t=j+15900|0;c[t>>2]=A;do{if((x|0)==0){B=c[r>>2]|0;if((c[B+504>>2]&16777215|0)==16777215){break}KIb(B,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);x=c[m>>2]|0;do{if((c[x+28>>2]|0)==8){B=c[x+36>>2]|0;C=1;do{b[h+((d[(d[1242080+C|0]|0)+(k+11192)|0]|0)<<1)>>1]=d[B+C|0]|0;C=C+1|0;}while((C|0)<64);C=j+10064|0;B=j+13080|0;WTa(C,c[w>>2]|0,c[z>>2]|0,u,c[B>>2]|0,1,c[(c[r>>2]|0)+504>>2]|0,1);D=c[(c[m>>2]|0)+40>>2]|0;E=1;do{b[h+((d[(d[1242080+E|0]|0)+(k+11192)|0]|0)<<1)>>1]=d[D+E|0]|0;E=E+1|0;}while((E|0)<64);WTa(C,c[y>>2]|0,c[t>>2]|0,u,c[B>>2]|0,1,c[(c[r>>2]|0)+504>>2]|0,1);E=(c[r>>2]|0)+504|0;if((c[E>>2]|0)<1){F=c[t>>2]|0;break}D=c[w>>2]|0;G=c[y>>2]|0;H=c[z>>2]|0;I=c[t>>2]|0;J=1;while(1){K=0;do{L=D+(J<<8)+(K<<2)|0;c[L>>2]=c[L>>2]<<2;L=G+(J<<8)+(K<<2)|0;c[L>>2]=c[L>>2]<<2;L=H+(J<<8)+(K<<1)|0;b[L>>1]=b[L>>1]<<2;L=H+(J<<8)+128+(K<<1)|0;b[L>>1]=b[L>>1]<<2;L=I+(J<<8)+(K<<1)|0;b[L>>1]=b[L>>1]<<2;L=I+(J<<8)+128+(K<<1)|0;b[L>>1]=b[L>>1]<<2;K=K+1|0;}while((K|0)<64);K=J+1|0;if((K|0)>(c[E>>2]|0)){F=I;break}else{J=K}}}else{J=(c[r>>2]|0)+504|0;if((c[J>>2]|0)<1){F=A;break}I=c[w>>2]|0;E=c[y>>2]|0;H=1;while(1){G=1;do{D=d[(d[1242080+G|0]|0)+(k+11192)|0]|0;c[I+(H<<8)+(D<<2)>>2]=524288/(ca(d[q+G|0]|0,H)|0)|0;c[E+(H<<8)+(D<<2)>>2]=524288/(ca(d[v+G|0]|0,H)|0)|0;G=G+1|0;}while((G|0)<64);G=H+1|0;if((G|0)>(c[J>>2]|0)){F=A;break}else{H=G}}}}while(0);c[j+13184>>2]=F;c[j+13172>>2]=c[y>>2];c[j+13180>>2]=c[z>>2];c[j+13168>>2]=c[w>>2];if((c[j+14848>>2]|0)!=0){c[j+14852>>2]=1600}w=1<<(c[(c[m>>2]|0)+28>>2]|0)+2;z=w<<4;y=pJb(z)|0;F=j+15920|0;c[F>>2]=y;if(!((y|0)!=0|(z|0)==0)){KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}z=pJb(w<<2)|0;y=j+15924|0;c[y>>2]=z;if((z|0)==0){KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}z=pJb(126)|0;A=j+15928|0;c[A>>2]=z;if((z|0)==0){KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}z=pJb(63)|0;v=j+15932|0;c[v>>2]=z;if((z|0)==0){KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}z=w<<1;c[F>>2]=(c[F>>2]|0)+(z<<2);c[y>>2]=(c[y>>2]|0)+z;z=-w|0;a:do{if((w|0)>(z|0)){q=z;b:while(1){t=q<<1;u=q>>31;h=(u^q)-u|0;x=(h|0)>64;H=h-1>>6;J=u&1;u=x?H:0;E=x?H<<6:0;H=h-E|0;x=(u|0)==0;I=(h|0)==(E|0);E=0;do{h=E|t;G=c[m>>2]|0;D=c[G+60>>2]|0;B=G+64|0;C=(E|0)!=0;K=C^1;c:do{if(x){L=0;while(1){if(((d[D+L|0]|0)>>>1|0)==(H|0)){if(!C){M=L;N=70;break c}if(!((a[(c[B>>2]|0)+L|0]&2)==0|K)){M=L;N=70;break c}}O=L+1|0;if((O|0)<257){L=O}else{N=73;break}}}else{if(C){P=0}else{L=0;while(1){if(((d[D+L|0]|0)>>>1|0)==(H|0)){if(!((a[(c[B>>2]|0)+L|0]&1)==0)){M=L;N=70;break c}}O=L+1|0;if((O|0)<257){L=O}else{N=73;break c}}}while(1){do{if(((d[D+P|0]|0)>>>1|0)==(H|0)){L=a[(c[B>>2]|0)+P|0]|0;if((L&1)==0){break}if(!((L&2)==0|K)){M=P;N=70;break c}}}while(0);L=P+1|0;if((L|0)<257){P=L}else{N=73;break}}}}while(0);do{if((N|0)==70){N=0;K=e[(c[G+52>>2]|0)+(M<<1)>>1]|0;if(I){c[(c[F>>2]|0)+(h<<2)>>2]=K;a[(c[y>>2]|0)+h|0]=a[(c[G+56>>2]|0)+M|0]|0;break}else{c[(c[F>>2]|0)+(h<<2)>>2]=K<<1|J;a[(c[y>>2]|0)+h|0]=(a[(c[G+56>>2]|0)+M|0]|0)+1;break}}else if((N|0)==73){N=0;if(!I){break b}}}while(0);if(!x){G=(c[F>>2]|0)+(h<<2)|0;K=(c[m>>2]|0)+24|0;c[G>>2]=c[G>>2]<<c[K>>2]|u;G=(c[y>>2]|0)+h|0;a[G]=(d[G]|0)+(c[K>>2]|0)}E=E+1|0;}while((E|0)<2);E=q+1|0;if((E|0)<(w|0)){q=E}else{Q=0;break a}}KIb(0,0,2206936,(n=i,i=i+24|0,c[n>>2]=2590744,c[n+8>>2]=2147e3,c[n+16>>2]=155,n)|0);i=n;Hd();return 0}else{Q=0}}while(0);do{w=c[m>>2]|0;y=a[(c[w+76>>2]|0)+Q|0]|0;F=y&255;if(!((y&255)>>>0<63>>>0)){N=80;break}b[(c[A>>2]|0)+(F<<1)>>1]=b[(c[w+68>>2]|0)+(Q<<1)>>1]|0;a[(c[v>>2]|0)+F|0]=a[(c[w+72>>2]|0)+Q|0]|0;Q=Q+1|0;}while((Q|0)<62);if((N|0)==80){KIb(0,0,2206936,(n=i,i=i+24|0,c[n>>2]=2568928,c[n+8>>2]=2147e3,c[n+16>>2]=164,n)|0);i=n;Hd();return 0}N=pJb(((c[(c[r>>2]|0)+504>>2]|0)*65280|0)+65280|0)|0;c[j+15960>>2]=N;Q=c[r>>2]|0;do{if((N|0)==0){if(((c[Q+504>>2]|0)*65280|0|0)==-65280){break}KIb(Q,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);do{if((c[Q+296>>2]|0)!=2){N=pJb(c[l>>2]<<3)|0;c[j+15956>>2]=N;if((N|0)!=0){break}if((c[l>>2]&536870911|0)==0){break}KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);c[j+15904>>2]=(c[(c[m>>2]|0)+20>>2]|0)+536870268-(c[j+14852>>2]|0)<<3;c[j+15940>>2]=1;c[j+15944>>2]=2048;m=pJb(c[s>>2]<<2)|0;c[j+14692>>2]=m;Q=c[s>>2]|0;do{if((m|0)==0){if((Q&1073741823|0)==0){break}KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);m=pJb(Q<<2)|0;c[j+14696>>2]=m;do{if((m|0)==0){if((c[s>>2]&1073741823|0)==0){break}KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);s=pJb(c[l>>2]<<1)|0;c[j+15948>>2]=s;m=c[l>>2]|0;do{if((s|0)==0){if((m&2147483647|0)==0){break}KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);s=pJb(m)|0;c[j+15952>>2]=s;do{if((s|0)==0){if((c[l>>2]|0)==0){break}KIb(c[r>>2]|0,16,2123192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=g;return o|0}}while(0);r=UHb()|0;c[f+804>>2]=r;if((r|0)==0){o=-12;i=g;return o|0}c[r+84>>2]=1;c[r+88>>2]=1;r=f+808|0;l=c[r>>2]|0;if((l|0)>32){KIb(p,16,2640856,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}if((c[f+504>>2]|0)<2){KIb(p,16,2618120,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}n=j+14700|0;p=n;c[n>>2]=k;if((l|0)>1){R=1}else{o=0;i=g;return o|0}while(1){l=hJb(15968)|0;c[p+(R<<2)>>2]=l;nrc(l|0,j|0,15968)|0;l=R+1|0;if((l|0)<(c[r>>2]|0)){R=l}else{o=0;break}}i=g;return o|0}function s6(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0;j=i;i=i+4096|0;k=j|0;l=d+60|0;m=c[l>>2]|0;n=m;o=m+14684|0;p=d5a(d,f,c[(c[o>>2]|0)+16>>2]|0,0)|0;if((p|0)<0){q=p;i=j;return q|0}p=c[f+24>>2]|0;r=m+12|0;s=c[r>>2]|0;t=s+808|0;if((c[t>>2]|0)>0){u=g+32|0;v=m+14840|0;w=g+36|0;x=m+156|0;z=m+160|0;A=0;do{B=c[n+14700+(A<<2)>>2]|0;c[B+156>>2]=c[u>>2]<<c[v>>2];c[B+160>>2]=c[w>>2]<<c[v>>2];c[B+14828>>2]=c[x>>2]<<3;c[B+14832>>2]=c[z>>2]<<3;A=A+1|0;}while((A|0)<(c[t>>2]|0))}t=g+296|0;c[(c[s+804>>2]|0)+296>>2]=c[t>>2];if((c[t>>2]|0)==0){C=0}else{C=(c[g+300>>2]|0)==0|0}t=m+14844|0;c[t>>2]=C;s=m+15908|0;A=m+14840|0;z=d+124|0;x=d+120|0;v=d+296|0;w=d+504|0;u=m+15940|0;n=d+828|0;B=m+128|0;D=m+15944|0;E=m+124|0;F=m+15904|0;H=m+15960|0;I=m+15952|0;J=m+15948|0;K=m+14696|0;L=m+14692|0;M=m+14688|0;N=m+15956|0;O=m+152|0;P=k;Q=k+3068|0;R=k+4092|0;S=p;p=1;T=c[A>>2]|0;U=C;a:while(1){C=c[g>>2]|0;V=s;c[V>>2]=C;do{if((T|0)==0){c[m+15912>>2]=c[g+4>>2];c[m+15916>>2]=c[g+8>>2]}else{if((U|0)==0){c[m+15912>>2]=c[g+4>>2];c[m+15916>>2]=c[g+8>>2];break}else{c[V>>2]=C+(c[g+32>>2]|0);c[m+15912>>2]=(c[g+4>>2]|0)+(c[g+36>>2]|0);c[m+15916>>2]=(c[g+8>>2]|0)+(c[g+40>>2]|0);break}}}while(0);C=c[l>>2]|0;mrc(S|0,0,640)|0;a[S]=a[1520376]|0;a[S+1|0]=a[1520377]|0;a[S+2|0]=a[1520378]|0;a[S+3|0]=a[1520379]|0;a[S+4|0]=a[1520380]|0;V=C+14840|0;if((c[V>>2]|0)==0){W=1}else{W=(c[C+14844>>2]|0)+2&255}a[S+5|0]=W;a[S+6|0]=-128;a[S+7|0]=-96;X=S+24|0;y=he(c[z>>2]>>c[V>>2]&65535|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;X=S+26|0;y=he(c[x>>2]&65535|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;X=S+29|0;y=he(c[z>>2]>>c[V>>2]&65535|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;a[S+33|0]=(c[(c[C+14684>>2]|0)+28>>2]|0)==10?88:56;a[S+34|0]=(c[V>>2]<<2)+136;X=S+40|0;y=je(c[C+14680>>2]|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;a[S+44|0]=(c[V>>2]|0)!=0?0:-128;a[S+95|0]=1;a[S+359|0]=2;V=C+128|0;X=S+362|0;y=he((c[V>>2]<<2)+4&65535|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;a[S+365|0]=c[V>>2];a[S+367|0]=16;c[C+14688>>2]=S+368;b:do{if((c[v>>2]|0)==2){if((c[w>>2]|0)>1){C=1;do{c[u>>2]=C;Xe[c[n>>2]&511](d,790,0,0,c[B>>2]|0)|0;C=C+1|0;}while((C|0)<(c[w>>2]|0))}C=c[D>>2]|0;V=0;X=2147483647;Y=2048;Z=2048;c:while(1){_=(X|0)==2147483647;$=C;aa=V;ba=Y;da=Z;while(1){ea=($|0)==(aa|0);fa=(ea&1)+$|0;ga=0;ha=0;while(1){if((ha|0)>=(c[B>>2]|0)){ia=19;break}ja=c[E>>2]|0;if((ja|0)>0){ka=0;la=ga;ma=ja;ja=c[H>>2]|0;while(1){na=ka+(ca(ma,ha)|0)|0;oa=c[w>>2]|0;if((oa|0)>1){pa=1;qa=-1;ra=1;while(1){sa=ca(c[ja+(pa*65280|0)+(na<<3)+4>>2]|0,fa)|0;ta=(c[ja+(pa*65280|0)+(na<<3)>>2]<<10)+sa|0;sa=ta>>>0<qa>>>0;ua=sa?pa:ra;va=pa+1|0;if((va|0)<(oa|0)){pa=va;qa=sa?ta:qa;ra=ua}else{wa=ua;break}}}else{wa=1}ra=(c[ja+(wa*65280|0)+(na<<3)+4>>2]|0)+la|0;a[(c[I>>2]|0)+na|0]=wa;qa=c[H>>2]|0;b[(c[J>>2]|0)+(na<<1)>>1]=c[qa+(wa*65280|0)+(na<<3)+4>>2];pa=ka+1|0;oa=c[E>>2]|0;if((pa|0)<(oa|0)){ka=pa;la=ra;ma=oa;ja=qa}else{xa=ra;break}}}else{xa=ga}ja=xa+31&-32;ma=c[F>>2]|0;if(ja>>>0>ma>>>0){ya=ja;za=ma;break}ga=ja;ha=ha+1|0}if((ia|0)==19){ia=0;ya=ga;za=c[F>>2]|0}if(ea){ia=28;break c}if(ya>>>0<za>>>0){break}ha=(fa|0)>(aa|0)?fa:aa;if(_){ja=da;ma=(da|0)<0|0?-1:0;la=wrc(fa,(fa|0)<0|0?-1:0,ja,ma)|0;ka=G;ra=0;if((ka|0)>(ra|0)|(ka|0)==(ra|0)&la>>>0>2147483647>>>0){ia=88;break a}Aa=fa+da|0;Ba=ma;Ca=ja}else{Aa=fa+X>>1;Ba=(da|0)<0|0?-1:0;Ca=da}ja=Erc(Ca,Ba,5,0)|0;ma=G;la=0;$=Aa;aa=ha;ba=1024;da=(ma|0)>(la|0)|(ma|0)==(la|0)&ja>>>0>2147483647>>>0?2147483647:ja}da=(fa|0)>(X|0)?X:fa;if((aa|0)==0){Da=fa-ba|0}else{Da=fa+aa>>1}$=Erc(ba,(ba|0)<0|0?-1:0,5,0)|0;_=G;ja=0;la=(Da|0)<1?1:Da;if((la|0)==(da|0)){Ea=da;break}else{C=la;V=aa;X=da;Y=(_|0)>(ja|0)|(_|0)==(ja|0)&$>>>0>2147483647>>>0?2147483647:$;Z=1024}}if((ia|0)==28){ia=0;if(ya>>>0>za>>>0){ia=88;break a}else{Ea=fa}}c[D>>2]=Ea}else{Z=c[u>>2]|0;Y=2147483647;X=0;V=1;C=c[B>>2]|0;d:while(1){$=(X|0)==0;ja=Z;_=Y;da=1;la=V;ma=C;while(1){c[u>>2]=ja;ha=c[r>>2]|0;Xe[c[ha+828>>2]&511](ha,790,0,0,ma)|0;Fa=c[B>>2]|0;ha=0;ra=0;while(1){if((ha|0)>=(Fa|0)){ia=44;break}ka=c[E>>2]|0;if((ka|0)>0){qa=c[H>>2]|0;oa=ca(ka,ha)|0;pa=ra;ua=0;while(1){ta=(c[qa+(ja*65280|0)+(ua+oa<<3)+4>>2]|0)+pa|0;sa=ua+1|0;if((sa|0)<(ka|0)){pa=ta;ua=sa}else{Ga=ta;break}}}else{Ga=ra}ua=Ga+31&-32;pa=c[F>>2]|0;if(ua>>>0>pa>>>0){Ha=ua;Ia=pa;break}else{ha=ha+1|0;ra=ua}}if((ia|0)==44){ia=0;Ha=ra;Ia=c[F>>2]|0}if(!(Ha>>>0<Ia>>>0)){break}if((ja|0)==1){Ja=1;break d}if((X|0)==(ja-1|0)){Ka=X;ia=61;break d}ha=(ja|0)>(_|0)?_:ja;if($){La=ja-da|0;Ma=da+1|0}else{La=ja+X>>1;Ma=da}ja=(La|0)<1?1:La;_=ha;da=Ma;la=1;ma=Fa}if((_|0)==(ja+1|0)){Ka=ja;ia=61;break}if((_|0)==2147483647){Na=ja+la|0;Oa=la+1|0}else{Na=ja+_>>1;Oa=la}if((Na|0)<(c[(c[r>>2]|0)+504>>2]|0)){Z=Na;Y=_;X=(ja|0)>(X|0)?ja:X;V=Oa;C=Fa}else{ia=88;break a}}if((ia|0)==61){ia=0;c[u>>2]=Ka;Ja=0}if((Fa|0)>0){C=0;V=0;X=c[E>>2]|0;Y=Fa;while(1){if((X|0)>0){Z=0;ma=V;da=X;$=c[u>>2]&255;while(1){aa=Z+(ca(da,C)|0)|0;a[(c[I>>2]|0)+aa|0]=$;ba=c[u>>2]|0;ha=c[(c[H>>2]|0)+(ba*65280|0)+(aa<<3)+4>>2]|0;b[(c[J>>2]|0)+(aa<<1)>>1]=ha;Pa=ha+ma|0;ha=Z+1|0;Qa=c[E>>2]|0;if((ha|0)<(Qa|0)){Z=ha;ma=Pa;da=Qa;$=ba&255}else{break}}Ra=Pa;Sa=Qa;Ta=c[B>>2]|0}else{Ra=V;Sa=X;Ta=Y}$=Ra+31|0;da=C+1|0;if((da|0)<(Ta|0)){C=da;V=$;X=Sa;Y=Ta}else{Ua=$;Va=Ta;break}}}else{Ua=0;Va=Fa}if((Ja|0)!=0){break}Xe[c[n>>2]&511](d,4,0,0,Va)|0;Y=c[N>>2]|0;X=c[O>>2]|0;V=hJb(X<<3)|0;C=V;mrc(P|0,0,4096)|0;$=(X|0)>0;if($){da=0;while(1){ma=c[Y+(da<<3)+4>>2]|0;Z=k+((ma&255^255)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;Z=k+1024+((ma>>>8&255^255)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;Z=k+2048+((ma>>>16&255^255)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;Z=k+3072+((ma>>>24^255)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;Z=da+1|0;if((Z|0)<(X|0)){da=Z}else{Wa=255;Xa=X;break}}}else{Wa=255;Xa=X}while(1){da=k+(Wa<<2)|0;Z=Xa-(c[da>>2]|0)|0;c[da>>2]=Z;if((Wa|0)>0){Wa=Wa-1|0;Xa=Z}else{Ya=255;Za=X;break}}while(1){Z=k+1024+(Ya<<2)|0;da=Za-(c[Z>>2]|0)|0;c[Z>>2]=da;if((Ya|0)>0){Ya=Ya-1|0;Za=da}else{_a=255;$a=X;break}}while(1){da=k+2048+(_a<<2)|0;Z=$a-(c[da>>2]|0)|0;c[da>>2]=Z;if((_a|0)>0){_a=_a-1|0;$a=Z}else{ab=255;bb=X;break}}while(1){Z=k+3072+(ab<<2)|0;da=bb-(c[Z>>2]|0)|0;c[Z>>2]=da;if((ab|0)>0){ab=ab-1|0;bb=da}else{break}}if($){da=0;while(1){Z=k+((c[Y+(da<<3)+4>>2]&255^255)<<2)|0;ma=c[Z>>2]|0;c[Z>>2]=ma+1;Z=Y+(da<<3)|0;ja=C+(ma<<3)|0;ma=c[Z+4>>2]|0;c[ja>>2]=c[Z>>2];c[ja+4>>2]=ma;ma=da+1|0;if((ma|0)<(X|0)){da=ma}else{cb=0;break}}do{da=k+1024+(((c[C+(cb<<3)+4>>2]|0)>>>8&255^255)<<2)|0;ma=c[da>>2]|0;c[da>>2]=ma+1;da=C+(cb<<3)|0;ja=Y+(ma<<3)|0;ma=c[da+4>>2]|0;c[ja>>2]=c[da>>2];c[ja+4>>2]=ma;cb=cb+1|0;}while((cb|0)<(X|0))}if((c[Q>>2]|0)==0){if(!((c[R>>2]|0)==0|$^1)){db=0;ia=82}}else{if($){db=0;ia=82}}do{if((ia|0)==82){while(1){ia=0;ma=k+2048+(((c[Y+(db<<3)+4>>2]|0)>>>16&255^255)<<2)|0;ja=c[ma>>2]|0;c[ma>>2]=ja+1;ma=Y+(db<<3)|0;da=C+(ja<<3)|0;ja=c[ma+4>>2]|0;c[da>>2]=c[ma>>2];c[da+4>>2]=ja;ja=db+1|0;if((ja|0)<(X|0)){db=ja;ia=82}else{break}}if($){eb=0}else{break}do{ja=k+3072+(((c[C+(eb<<3)+4>>2]|0)>>>24^255)<<2)|0;da=c[ja>>2]|0;c[ja>>2]=da+1;ja=C+(eb<<3)|0;ma=Y+(da<<3)|0;da=c[ja+4>>2]|0;c[ma>>2]=c[ja>>2];c[ma+4>>2]=da;eb=eb+1|0;}while((eb|0)<(X|0))}}while(0);kJb(V);if((c[O>>2]|0)>0){fb=0;gb=Ua}else{break}do{if(!(gb>>>0>(c[F>>2]|0)>>>0)){break b}X=e[(c[N>>2]|0)+(fb<<3)>>1]|0;Y=c[u>>2]|0;C=c[H>>2]|0;$=Y+1|0;gb=gb-(c[C+(Y*65280|0)+(X<<3)+4>>2]|0)+(c[C+($*65280|0)+(X<<3)+4>>2]|0)|0;a[(c[I>>2]|0)+X|0]=$;b[(c[J>>2]|0)+(X<<1)>>1]=c[(c[H>>2]|0)+(((c[u>>2]|0)+1|0)*65280|0)+(X<<3)+4>>2];fb=fb+1|0;}while((fb|0)<(c[O>>2]|0))}}while(0);V=c[B>>2]|0;do{if((V|0)>0){X=c[K>>2]|0;$=c[L>>2]|0;C=0;Y=0;while(1){c[X+(Y<<2)>>2]=C;da=$+(Y<<2)|0;c[da>>2]=0;ma=c[E>>2]|0;if((ma|0)>0){ja=c[J>>2]|0;Z=0;_=ma;ma=0;do{ma=(e[ja+((ca(_,Y)|0)+Z<<1)>>1]|0)+ma|0;c[da>>2]=ma;Z=Z+1|0;_=c[E>>2]|0;}while((Z|0)<(_|0));hb=(ma+31|0)>>>3&536870908}else{hb=0}c[da>>2]=hb;_=Y+1|0;ib=c[B>>2]|0;if((_|0)<(ib|0)){C=hb+C|0;Y=_}else{break}}if((ib|0)>0){jb=0;kb=0}else{lb=0;mb=ib;break}while(1){Y=je(jb|0)|0;C=(c[M>>2]|0)+(kb<<2)|0;y=Y;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=(c[(c[L>>2]|0)+(kb<<2)>>2]|0)+jb|0;Y=kb+1|0;$=c[B>>2]|0;if((Y|0)<($|0)){jb=C;kb=Y}else{lb=C;mb=$;break}}}else{lb=0;mb=V}}while(0);Xe[c[n>>2]&511](d,670,S,0,mb)|0;mrc(S+(lb+640)|0,0,-644-lb+(c[(c[o>>2]|0)+20>>2]|0)|0)|0;V=S+((c[(c[o>>2]|0)+20>>2]|0)-4)|0;y=-557839008;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=c[A>>2]|0;if((V|0)==0|(p|0)==0){ia=100;break}$=c[t>>2]^1;c[t>>2]=$;S=S+(c[(c[o>>2]|0)+20>>2]|0)|0;p=0;T=V;U=$}if((ia|0)==88){KIb(d,16,2455016,(U=i,i=i+1|0,i=i+7&-8,c[U>>2]=0,U)|0);i=U;q=-22;i=j;return q|0}else if((ia|0)==100){c[(c[d+804>>2]|0)+168>>2]=(c[u>>2]|0)*118|0;u=f+36|0;c[u>>2]=c[u>>2]|1;c[h>>2]=1;q=0;i=j;return q|0}return 0}function t6(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;d=-2<<(c[(c[b+14684>>2]|0)+28>>2]|0)+2;kJb((c[b+15920>>2]|0)+(d<<2)|0);kJb((c[b+15924>>2]|0)+d|0);mJb(b+15928|0);mJb(b+15932|0);mJb(b+15948|0);mJb(b+15952|0);mJb(b+15960|0);mJb(b+15956|0);mJb(b+14692|0);mJb(b+14696|0);mJb(b+15888|0);mJb(b+15892|0);mJb(b+15900|0);mJb(b+15896|0);d=a+808|0;if((c[d>>2]|0)<=1){e=a+804|0;VHb(e);return 0}f=b+14700|0;b=1;do{mJb(f+(b<<2)|0);b=b+1|0;}while((b|0)<(c[d>>2]|0));e=a+804|0;VHb(e);return 0}function u6(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;k=i;i=i+8|0;l=k|0;m=c[(c[f+60>>2]|0)+14700+(j<<2)>>2]|0;j=m+8|0;f=c[(c[m+14692>>2]|0)+(h<<2)>>2]|0;n=(f|0)<0;o=n?0:g+((c[(c[m+14696>>2]|0)+(h<<2)>>2]|0)+640)|0;g=n?0:f;c[m+812>>2]=g<<3;f=m+800|0;c[f>>2]=o;c[m+808>>2]=o+g;g=m+804|0;c[g>>2]=o;n=m+796|0;c[n>>2]=32;p=m+792|0;c[p>>2]=0;q=m+14684|0;r=1<<(c[(c[q>>2]|0)+28>>2]|0)+2;c[m+9876>>2]=r;c[m+9872>>2]=r;c[m+9868>>2]=r;r=m+124|0;s=c[r>>2]|0;if((s|0)>0){t=m+15952|0;u=m+14836|0;v=m+14700|0;w=h<<4;x=m+156|0;z=m+160|0;A=m+10064|0;B=m+14864|0;C=m+14992|0;D=m+15120|0;E=m+15248|0;F=h+1|0;G=m+128|0;H=m+12|0;I=m+14840|0;J=m+10100|0;K=m+15376|0;L=m+15504|0;M=m+15632|0;N=m+15760|0;O=m+15964|0;P=m+14828|0;Q=m+14832|0;R=m+14400|0;S=m+15924|0;T=m+15920|0;U=m+15932|0;V=m+15928|0;W=0;X=s;s=0;Y=32;while(1){Z=(ca(X,h)|0)+W|0;_=d[(c[t>>2]|0)+Z|0]|0;Z=_<<1;if((Y|0)>12){$=Y-12|0;aa=s<<12|Z}else{ba=je(Z>>>((12-Y|0)>>>0)|s<<Y|0)|0;da=c[g>>2]|0;y=ba;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;$=Y+20|0;aa=Z}c[p>>2]=aa;c[n>>2]=$;Z=c[u>>2]|0;da=c[v>>2]|0;ba=c[da+15908>>2]|0;ea=c[x>>2]|0;fa=(ca(ea,w)|0)+(W<<Z+1)|0;ga=c[da+15912>>2]|0;ha=(ca(c[z>>2]|0,w)|0)+(W<<Z)|0;ia=c[da+15916>>2]|0;ef[c[A>>2]&4095](B,ba+fa|0,ea);ea=fa+(1<<Z)|0;ef[c[A>>2]&4095](C,ba+ea|0,c[x>>2]|0);ef[c[A>>2]&4095](D,ga+ha|0,c[z>>2]|0);ef[c[A>>2]&4095](E,ia+ha|0,c[z>>2]|0);do{if((F|0)==(c[G>>2]|0)){if((c[(c[H>>2]|0)+124>>2]|0)!=1080){ja=11;break}if((c[I>>2]|0)==0){qe[c[J>>2]&1023](K);qe[c[J>>2]&1023](L);qe[c[J>>2]&1023](M);qe[c[J>>2]&1023](N);ka=0;break}else{ef[c[O>>2]&4095](K,ba+((c[P>>2]|0)+fa)|0,c[x>>2]|0);ef[c[O>>2]&4095](L,ba+((c[P>>2]|0)+ea)|0,c[x>>2]|0);ef[c[O>>2]&4095](M,ga+((c[Q>>2]|0)+ha)|0,c[z>>2]|0);ef[c[O>>2]&4095](N,ia+((c[Q>>2]|0)+ha)|0,c[z>>2]|0);ka=0;break}}else{ja=11}}while(0);if((ja|0)==11){ja=0;ef[c[A>>2]&4095](K,ba+((c[P>>2]|0)+fa)|0,c[x>>2]|0);ef[c[A>>2]&4095](L,ba+((c[P>>2]|0)+ea)|0,c[x>>2]|0);ef[c[A>>2]&4095](M,ga+((c[Q>>2]|0)+ha)|0,c[z>>2]|0);ef[c[A>>2]&4095](N,ia+((c[Q>>2]|0)+ha)|0,c[z>>2]|0);ka=0}do{Z=m+14864+(ka<<7)|0;da=d[1520384+ka|0]|0;la=Xe[c[R>>2]&511](j,Z,ka<<1&4,_,l)|0;ma=b[Z>>1]|0;na=m+9868+(da<<2)|0;da=(ma<<16>>16)-(c[na>>2]|0)|0;if((da|0)<0){oa=da*-2|0;pa=(oa&65280|0)==0;qa=(d[1359664+(pa?oa:oa>>>8)|0]|0)+(pa?0:8)|0;ra=da-1|0}else{pa=da<<1;oa=(pa&65280|0)==0;qa=(d[1359664+(oa?pa:da>>>7&16777215)|0]|0)+(oa?0:8)|0;ra=da}da=c[q>>2]|0;oa=(d[(c[da+48>>2]|0)+qa|0]|0)+qa|0;pa=((d[(c[da+44>>2]|0)+qa|0]|0)<<qa)+((1<<qa)-1&ra)|0;da=c[p>>2]|0;sa=c[n>>2]|0;if((sa|0)>(oa|0)){ta=sa-oa|0;ua=pa|da<<oa;va=ma}else{ma=je(pa>>>((oa-sa|0)>>>0)|da<<sa|0)|0;da=c[g>>2]|0;y=ma;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;ta=32-oa+sa|0;ua=pa;va=b[Z>>1]|0}c[p>>2]=ua;c[n>>2]=ta;c[na>>2]=va<<16>>16;if((la|0)>=1){na=1;Z=0;while(1){pa=b[m+14864+(ka<<7)+((d[m+376+na|0]|0)<<1)>>1]|0;do{if(pa<<16>>16==0){wa=Z}else{sa=na-Z-1|0;oa=(sa|0)!=0;da=pa<<16>>16<<1|oa&1;ma=d[(c[S>>2]|0)+da|0]|0;xa=c[(c[T>>2]|0)+(da<<2)>>2]|0;da=c[p>>2]|0;ya=c[n>>2]|0;if((ya|0)>(ma|0)){za=ya-ma|0;Aa=da<<ma|xa}else{Ba=je(xa>>>((ma-ya|0)>>>0)|da<<ya|0)|0;da=c[g>>2]|0;y=Ba;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;za=32-ma+ya|0;Aa=xa}c[p>>2]=Aa;c[n>>2]=za;if(!oa){wa=na;break}oa=d[(c[U>>2]|0)+sa|0]|0;xa=e[(c[V>>2]|0)+(sa<<1)>>1]|0;if((za|0)>(oa|0)){Ca=za;Da=xa|Aa<<oa}else{sa=je(xa>>>((oa-za|0)>>>0)|Aa<<za|0)|0;ya=c[g>>2]|0;y=sa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;Ca=za+32|0;Da=xa}c[p>>2]=Da;c[n>>2]=Ca-oa;wa=na}}while(0);pa=na+1|0;if((pa|0)>(la|0)){break}else{na=pa;Z=wa}}}Z=d[c[S>>2]|0]|0;na=c[c[T>>2]>>2]|0;la=c[p>>2]|0;pa=c[n>>2]|0;if((pa|0)>(Z|0)){Ea=pa-Z|0;Fa=la<<Z|na}else{oa=je(na>>>((Z-pa|0)>>>0)|la<<pa|0)|0;la=c[g>>2]|0;y=oa;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;Ea=32-Z+pa|0;Fa=na}c[p>>2]=Fa;c[n>>2]=Ea;ka=ka+1|0;}while((ka|0)<8);_=W+1|0;ha=c[r>>2]|0;if((_|0)<(ha|0)){W=_;X=ha;s=Fa;Y=Ea}else{break}}Ga=Ea;Ha=c[f>>2]|0;Ia=c[g>>2]|0;Ja=Fa}else{Ga=32;Ha=o;Ia=o;Ja=0}o=32-Ga+(Ia-Ha<<3)&31;if((o|0)==0){Ka=Ga;La=Ja;Ma=Ia}else{Ha=32-o|0;if((Ga|0)>(Ha|0)){Na=Ga-Ha|0;Oa=Ja<<Ha;Pa=Ia}else{Ha=Ia;y=je(Ja<<Ga|0)|0;a[Ha]=y;y=y>>8;a[Ha+1|0]=y;y=y>>8;a[Ha+2|0]=y;y=y>>8;a[Ha+3|0]=y;Ha=(c[g>>2]|0)+4|0;c[g>>2]=Ha;Na=Ga+o|0;Oa=0;Pa=Ha}c[p>>2]=Oa;c[n>>2]=Na;Ka=Na;La=Oa;Ma=Pa}if((Ka|0)>=32){c[n>>2]=32;c[p>>2]=0;i=k;return 0}Pa=La<<Ka;c[p>>2]=Pa;Ka=Pa>>>24&255;Pa=Ma;while(1){c[g>>2]=Pa+1;a[Pa]=Ka;Ma=c[p>>2]|0;c[p>>2]=Ma<<8;La=(c[n>>2]|0)+8|0;c[n>>2]=La;if((La|0)>=32){break}Ka=Ma>>>16&255;Pa=c[g>>2]|0}c[n>>2]=32;c[p>>2]=0;i=k;return 0}function v6(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=c[a+60>>2]|0;if(((c[f+128>>2]|0)-1|0)==(g|0)){i=(c[a+124>>2]>>c[f+14840>>2]&15|0)!=0}else{i=0}j=c[f+14700+(h<<2)>>2]|0;h=j+156|0;if((c[(c[j+14684>>2]|0)+28>>2]|0)!=8){f=c[h>>2]>>1;k=j+124|0;l=c[k>>2]|0;if((l|0)<=0){return 0}m=c[(c[j+14700>>2]|0)+15908>>2]|0;n=ca(f,g)|0;o=c[j+15956>>2]|0;p=0;q=l;do{l=ca(q,g)|0;r=m+(p+n<<4<<1)|0;s=0;t=0;u=0;while(1){v=s;w=t;x=0;do{y=(e[r+(x<<1)>>1]|0)>>>6;v=y+v|0;w=(ca(y,y)|0)+w|0;x=x+1|0;}while((x|0)<16);x=u+1|0;if((x|0)<16){r=r+(f<<1)|0;s=v;t=w;u=x}else{break}}u=l+p|0;t=v>>8;c[o+(u<<3)+4>>2]=(w>>8)-(ca(t,t)|0);b[o+(u<<3)>>1]=u;p=p+1|0;q=c[k>>2]|0;}while((p|0)<(q|0));return 0}q=j+124|0;p=c[q>>2]|0;if((p|0)<=0){return 0}k=g<<4;o=ca(k,c[h>>2]|0)|0;w=a+120|0;v=a+124|0;a=j+14840|0;f=j+15956|0;n=j+10108|0;m=j+10112|0;u=(c[(c[j+14700>>2]|0)+15908>>2]|0)+o|0;o=0;j=p;while(1){p=(ca(j,g)|0)+o|0;do{if(i){z=c[w>>2]|0;A=o<<4;B=10}else{t=o<<4;s=c[w>>2]|0;if((t|0)>(s-16|0)){z=s;A=t;B=10;break}t=We[c[n>>2]&2047](u,c[h>>2]|0)|0;C=t;D=We[c[m>>2]&2047](u,c[h>>2]|0)|0}}while(0);do{if((B|0)==10){B=0;l=z-A|0;t=(l|0)>16?16:l;l=(c[v>>2]>>c[a>>2])-k|0;s=(l|0)>16?16:l;if((s|0)<=0){C=0;D=0;break}l=(t|0)>0;r=0;x=0;y=0;while(1){if(l){E=ca(c[h>>2]|0,y)|0;F=r;G=x;H=0;while(1){I=d[u+(E+H)|0]|0;J=I+G|0;K=(ca(I,I)|0)+F|0;I=H+1|0;if((I|0)<(t|0)){F=K;G=J;H=I}else{L=K;M=J;break}}}else{L=r;M=x}H=y+1|0;if((H|0)<(s|0)){r=L;x=M;y=H}else{C=M;D=L;break}}}}while(0);y=(D+128-((ca(C,C)|0)>>>8)|0)>>>8;x=c[f>>2]|0;c[x+(p<<3)+4>>2]=y;b[x+(p<<3)>>1]=p;x=o+1|0;y=c[q>>2]|0;if((x|0)<(y|0)){u=u+16|0;o=x;j=y}else{break}}return 0}function w6(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;f=i;i=i+136|0;j=f|0;k=f+128|0;l=c[e+60>>2]|0;m=c[l+15940>>2]|0;n=j|0;o=c[l+14700+(h<<2)>>2]|0;h=o+14684|0;l=1<<(c[(c[h>>2]|0)+28>>2]|0)+2;p=o+8|0;c[o+9876>>2]=l;c[o+9872>>2]=l;c[o+9868>>2]=l;l=o+124|0;q=c[l>>2]|0;if((q|0)<=0){i=f;return 0}r=o+14836|0;s=o+14700|0;t=g<<4;u=o+156|0;v=o+160|0;w=o+10064|0;x=o+14864|0;y=o+14992|0;z=o+15120|0;A=o+15248|0;B=g+1|0;C=o+128|0;D=o+12|0;E=o+14840|0;F=o+10100|0;G=o+15376|0;H=o+15504|0;I=o+15632|0;J=o+15760|0;K=o+15964|0;L=o+14828|0;M=o+14832|0;N=j;O=o+14400|0;P=e+296|0;e=o+11180|0;Q=o+15924|0;R=o+15932|0;S=o+15960|0;T=0;U=q;do{q=(ca(U,g)|0)+T|0;V=c[r>>2]|0;W=c[s>>2]|0;X=c[W+15908>>2]|0;Y=c[u>>2]|0;Z=(ca(Y,t)|0)+(T<<V+1)|0;_=c[W+15912>>2]|0;$=(ca(c[v>>2]|0,t)|0)+(T<<V)|0;aa=c[W+15916>>2]|0;ef[c[w>>2]&4095](x,X+Z|0,Y);Y=Z+(1<<V)|0;ef[c[w>>2]&4095](y,X+Y|0,c[u>>2]|0);ef[c[w>>2]&4095](z,_+$|0,c[v>>2]|0);ef[c[w>>2]&4095](A,aa+$|0,c[v>>2]|0);do{if((B|0)==(c[C>>2]|0)){if((c[(c[D>>2]|0)+124>>2]|0)!=1080){ba=8;break}if((c[E>>2]|0)==0){qe[c[F>>2]&1023](G);qe[c[F>>2]&1023](H);qe[c[F>>2]&1023](I);qe[c[F>>2]&1023](J);da=0;ea=0;fa=0;ga=0;break}else{ef[c[K>>2]&4095](G,X+((c[L>>2]|0)+Z)|0,c[u>>2]|0);ef[c[K>>2]&4095](H,X+((c[L>>2]|0)+Y)|0,c[u>>2]|0);ef[c[K>>2]&4095](I,_+((c[M>>2]|0)+$)|0,c[v>>2]|0);ef[c[K>>2]&4095](J,aa+((c[M>>2]|0)+$)|0,c[v>>2]|0);da=0;ea=0;fa=0;ga=0;break}}else{ba=8}}while(0);if((ba|0)==8){ba=0;ef[c[w>>2]&4095](G,X+((c[L>>2]|0)+Z)|0,c[u>>2]|0);ef[c[w>>2]&4095](H,X+((c[L>>2]|0)+Y)|0,c[u>>2]|0);ef[c[w>>2]&4095](I,_+((c[M>>2]|0)+$)|0,c[v>>2]|0);ef[c[w>>2]&4095](J,aa+((c[M>>2]|0)+$)|0,c[v>>2]|0);da=0;ea=0;fa=0;ga=0}while(1){V=d[1520384+ea|0]|0;nrc(N|0,o+14864+(ea<<7)|0,128)|0;W=Xe[c[O>>2]&511](p,n,ea<<1&4,m,k)|0;ha=(W|0)<1;if(ha){ia=0}else{ja=1;ka=0;la=0;while(1){ma=b[j+(d[o+376+ja|0]<<1)>>1]|0;if(ma<<16>>16==0){na=la;oa=ka}else{pa=ja-la-1|0;na=ja;oa=(d[(c[Q>>2]|0)+(ma<<16>>16<<1|(pa|0)!=0)|0]|0)+ka+(d[(c[R>>2]|0)+pa|0]|0)|0}pa=ja+1|0;if((pa|0)>(W|0)){ia=oa;break}else{ja=pa;ka=oa;la=na}}}qa=ia+fa|0;la=b[n>>1]|0;ka=o+9868+(V<<2)|0;ja=la-(c[ka>>2]|0)|0;if((ja|0)<0){ra=ja*-2|0}else{ra=ja<<1}ja=(ra&65280|0)==0;pa=(ja?0:8)+(d[1359664+(ja?ra:ra>>>8)|0]|0)|0;sa=pa+da+(d[(c[(c[h>>2]|0)+48>>2]|0)+pa|0]|0)|0;c[ka>>2]=la;if((c[P>>2]|0)==2){la=c[h>>2]|0;ka=c[((ea&2|0)==0?la+36|0:la+40|0)>>2]|0;if(!ha){pa=la+28|0;la=1;do{ja=j+(d[o+376+la|0]<<1)|0;ma=b[ja>>1]|0;if(!(ma<<16>>16==0)){ta=ma<<16>>16<<1;do{if(ma<<16>>16<0){ua=ca(1-ta|0,m)|0;va=a[ka+la|0]|0;wa=ca(ua,va&255)|0;if((c[pa>>2]|0)==10){xa=(va<<24>>24==8?wa:wa+8|0)>>4}else{xa=(va<<24>>24==32?wa:wa+32|0)>>6}ya=-xa&65535}else{wa=ca(ta|1,m)|0;va=a[ka+la|0]|0;ua=ca(wa,va&255)|0;if((c[pa>>2]|0)==10){if(va<<24>>24==8){ya=ua>>>4&65535;break}ya=(ua+8|0)>>>4&65535;break}else{if(va<<24>>24==32){ya=ua>>>6&65535;break}ya=(ua+32|0)>>>6&65535;break}}}while(0);b[ja>>1]=ya}la=la+1|0;}while((la|0)<=(W|0))}qe[c[e>>2]&1023](n);W=0;la=0;do{pa=(b[o+14864+(ea<<7)+(la<<1)>>1]|0)-(b[j+(la<<1)>>1]|0)|0;W=(ca(pa,pa)|0)+W|0;la=la+1|0;}while((la|0)<64);za=W+ga|0}else{za=ga}la=ea+1|0;if((la|0)<8){da=sa;ea=la;fa=qa;ga=za}else{break}}$=c[S>>2]|0;c[$+(m*65280|0)+(q<<3)>>2]=za;c[$+(m*65280|0)+(q<<3)+4>>2]=sa+12+qa+(d[c[Q>>2]|0]<<3);T=T+1|0;U=c[l>>2]|0;}while((T|0)<(U|0));i=f;return 0}function x6(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;h=c[a+364>>2]|0;i=c[((f|0)<4?a+13160|0:a+13164|0)>>2]|0;qe[c[a+11164>>2]&1023](e);b[e>>1]=((b[e>>1]|0)+2|0)>>>2;a=1;f=0;do{j=d[h+a|0]|0;k=e+(j<<1)|0;l=b[k>>1]|0;m=l>>31;n=(ca((m^l)-m|0,c[i+(g<<8)+(j<<2)>>2]|0)|0)>>18;b[k>>1]=(n^m)-m;f=(n|0)==0?f:a;a=a+1|0;}while((a|0)<64);return f|0}function y6(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=c;f=d>>1;b[a>>1]=b[e>>1]|0;b[a+2>>1]=b[c+2>>1]|0;b[a+4>>1]=b[c+4>>1]|0;b[a+6>>1]=b[c+6>>1]|0;b[a+8>>1]=b[c+8>>1]|0;b[a+10>>1]=b[c+10>>1]|0;b[a+12>>1]=b[c+12>>1]|0;b[a+14>>1]=b[c+14>>1]|0;b[a+16>>1]=b[e+(f<<1)>>1]|0;b[a+18>>1]=b[e+(f+1<<1)>>1]|0;b[a+20>>1]=b[e+(f+2<<1)>>1]|0;b[a+22>>1]=b[e+(f+3<<1)>>1]|0;b[a+24>>1]=b[e+(f+4<<1)>>1]|0;b[a+26>>1]=b[e+(f+5<<1)>>1]|0;b[a+28>>1]=b[e+(f+6<<1)>>1]|0;b[a+30>>1]=b[e+(f+7<<1)>>1]|0;c=f<<1;b[a+32>>1]=b[e+(c<<1)>>1]|0;b[a+34>>1]=b[e+((c|1)<<1)>>1]|0;b[a+36>>1]=b[e+(c+2<<1)>>1]|0;b[a+38>>1]=b[e+(c+3<<1)>>1]|0;b[a+40>>1]=b[e+(c+4<<1)>>1]|0;b[a+42>>1]=b[e+(c+5<<1)>>1]|0;b[a+44>>1]=b[e+(c+6<<1)>>1]|0;b[a+46>>1]=b[e+(c+7<<1)>>1]|0;d=c+f|0;b[a+48>>1]=b[e+(d<<1)>>1]|0;b[a+50>>1]=b[e+(d+1<<1)>>1]|0;b[a+52>>1]=b[e+(d+2<<1)>>1]|0;b[a+54>>1]=b[e+(d+3<<1)>>1]|0;b[a+56>>1]=b[e+(d+4<<1)>>1]|0;b[a+58>>1]=b[e+(d+5<<1)>>1]|0;b[a+60>>1]=b[e+(d+6<<1)>>1]|0;b[a+62>>1]=b[e+(d+7<<1)>>1]|0;nrc(a+64|0,a+48|0,16)|0;nrc(a+80|0,a+32|0,16)|0;nrc(a+96|0,a+16|0,16)|0;nrc(a+112|0,a|0,16)|0;return}function z6(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0;b[a>>1]=d[c]|0;b[a+2>>1]=d[c+1|0]|0;b[a+4>>1]=d[c+2|0]|0;b[a+6>>1]=d[c+3|0]|0;b[a+8>>1]=d[c+4|0]|0;b[a+10>>1]=d[c+5|0]|0;b[a+12>>1]=d[c+6|0]|0;b[a+14>>1]=d[c+7|0]|0;b[a+16>>1]=d[c+e|0]|0;b[a+18>>1]=d[c+(e+1)|0]|0;b[a+20>>1]=d[c+(e+2)|0]|0;b[a+22>>1]=d[c+(e+3)|0]|0;b[a+24>>1]=d[c+(e+4)|0]|0;b[a+26>>1]=d[c+(e+5)|0]|0;b[a+28>>1]=d[c+(e+6)|0]|0;b[a+30>>1]=d[c+(e+7)|0]|0;f=e<<1;b[a+32>>1]=d[c+f|0]|0;b[a+34>>1]=d[c+(f|1)|0]|0;b[a+36>>1]=d[c+(f+2)|0]|0;b[a+38>>1]=d[c+(f+3)|0]|0;b[a+40>>1]=d[c+(f+4)|0]|0;b[a+42>>1]=d[c+(f+5)|0]|0;b[a+44>>1]=d[c+(f+6)|0]|0;b[a+46>>1]=d[c+(f+7)|0]|0;g=f+e|0;b[a+48>>1]=d[c+g|0]|0;b[a+50>>1]=d[c+(g+1)|0]|0;b[a+52>>1]=d[c+(g+2)|0]|0;b[a+54>>1]=d[c+(g+3)|0]|0;b[a+56>>1]=d[c+(g+4)|0]|0;b[a+58>>1]=d[c+(g+5)|0]|0;b[a+60>>1]=d[c+(g+6)|0]|0;b[a+62>>1]=d[c+(g+7)|0]|0;nrc(a+64|0,a+48|0,16)|0;nrc(a+80|0,a+32|0,16)|0;nrc(a+96|0,a+16|0,16)|0;nrc(a+112|0,a|0,16)|0;return}function A6(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[a+60>>2]|0;if(((c[a+416>>2]|0)-1|0)>>>0>1>>>0){KIb(a,16,2568896,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=d;return g|0}h=e+516|0;c[h>>2]=0;j=e+512|0;c[j>>2]=0;k=a+12|0;l=c[(c[k>>2]|0)+12>>2]|0;do{if((l|0)==81923){m=c[a+52>>2]|0;if((m|0)==3){break}else if((m|0)==1){c[e+520>>2]=562784;c[h>>2]=128;c[j>>2]=128;break}else if((m|0)==2){c[e+520>>2]=562800;c[h>>2]=128;c[j>>2]=128;break}else{KIb(a,16,2550896,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1;i=d;return g|0}}else if((l|0)==81920){m=e;n=0;do{o=(ca(n,n)|0)&65535;b[m+(n<<1)>>1]=o;b[m+(n+128<<1)>>1]=-o;n=n+1|0;}while((n|0)<128)}}while(0);do{if((c[(c[k>>2]|0)+12>>2]|0)==81923){if((c[a+52>>2]|0)==3){break}c[a+420>>2]=0;g=0;i=d;return g|0}}while(0);c[a+420>>2]=1;g=0;i=d;return g|0}function B6(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=l;n=h+28|0;o=c[n>>2]|0;p=c[e+60>>2]|0;q=f;r=e+416|0;s=c[r>>2]|0;t=s-1|0;u=(t|0)!=0;if(u){v=(o<<31>>31)+o|0}else{v=o}o=c[h+24>>2]|0;if(!((v|0)>-1)){KIb(0,0,2640824,(w=i,i=i+24|0,c[w>>2]=2618104,c[w+8>>2]=2590720,c[w+16>>2]=135,w)|0);i=w;Hd();return 0}h=e+12|0;x=c[(c[h>>2]|0)+12>>2]|0;if((x|0)==81922){y=v-(s<<1)|0;z=10}else if((x|0)==81923){y=v<<((c[e+52>>2]|0)!=3);z=10}else if((x|0)==81921){y=v-6-s|0;z=10}else if((x|0)==81920){y=v-8|0;z=10}do{if((z|0)==10){if((y|0)<1){break}if(((y|0)%(s|0)|0|0)==0){A=s}else{KIb(e,24,2123144,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;A=c[r>>2]|0}c[f+76>>2]=(y-1+A|0)/(A|0)|0;v=M4a(e,q,0)|0;if((v|0)<0){B=v;i=j;return B|0}v=c[f>>2]|0;x=v;C=x+(y<<1)|0;D=c[(c[h>>2]|0)+12>>2]|0;a:do{if((D|0)==81921){E=o+6|0;F=c[r>>2]|0;if((F|0)>0){G=E;H=x;I=0;while(1){J=G+2|0;K=G;L=(d[K]|d[K+1|0]<<8)<<16>>16;c[k+(I<<2)>>2]=L<<16>>16;K=H+2|0;b[H>>1]=L;L=I+1|0;if((L|0)<(F|0)){G=J;H=K;I=L}else{M=J;N=K;break}}}else{M=E;N=x}if(N>>>0<C>>>0){O=M;P=N;Q=0}else{break}while(1){I=k+(Q<<2)|0;H=(c[I>>2]|0)+(b[1066200+(d[O]<<1)>>1]|0)|0;if((H+32768|0)>>>0>65535>>>0){R=(H>>31^32767)&65535}else{R=H&65535}c[I>>2]=R<<16>>16;I=P+2|0;b[P>>1]=R;if(!(I>>>0<C>>>0)){break a}O=O+1|0;P=I;Q=Q^t}}else if((D|0)==81920){E=o+6|0;if(u){c[k+4>>2]=d[E]<<24>>16;I=d[o+7|0]<<24>>16;c[k>>2]=I;S=I}else{I=E;E=(d[I]|d[I+1|0]<<8)<<16>>16<<16>>16;c[k>>2]=E;S=E}if(!(x>>>0<C>>>0)){break}E=p;I=o+8|0;H=x;G=0;F=S;while(1){K=F+(b[E+(d[I]<<1)>>1]|0)|0;if((K+32768|0)>>>0>65535>>>0){T=(K>>31^32767)&65535}else{T=K&65535}c[k+(G<<2)>>2]=T<<16>>16;K=H+2|0;b[H>>1]=T;J=G^t;if(!(K>>>0<C>>>0)){break a}I=I+1|0;H=K;G=J;F=c[k+(J<<2)>>2]|0}}else if((D|0)==81923){if((c[e+52>>2]|0)==3){if(!(x>>>0<C>>>0)){break}F=p+512|0;G=o;H=x;I=0;while(1){E=d[G]|0;J=b[562816+((E&127)<<1)>>1]|0;K=F+(I<<2)|0;L=((E&128|0)==0?J:-J|0)+(c[K>>2]|0)|0;if((L+32768|0)>>>0>65535>>>0){U=(L>>31^32767)&65535}else{U=L&65535}c[K>>2]=U<<16>>16;K=H+2|0;b[H>>1]=U;if(K>>>0<C>>>0){G=G+1|0;H=K;I=I^t}else{break a}}}I=v+y|0;if((y|0)<=0){break}H=p+520|0;G=p+512|0;F=G;K=G+(t<<2)|0;G=o;L=v;while(1){J=d[G]|0;E=(c[F>>2]|0)+(a[(c[H>>2]|0)+(J>>>4)|0]|0)|0;if(E>>>0>255>>>0){V=-E>>31&255}else{V=E&255}c[F>>2]=V&255;a[L]=V;E=(c[K>>2]|0)+(a[(c[H>>2]|0)+(J&15)|0]|0)|0;if(E>>>0>255>>>0){W=-E>>31&255}else{W=E&255}c[K>>2]=W&255;E=L+2|0;a[L+1|0]=W;if(E>>>0<I>>>0){G=G+1|0;L=E}else{break}}}else if((D|0)==81922){c[l>>2]=4;c[l+4>>2]=4;L=c[r>>2]|0;if((L|0)>0){G=o;I=0;while(1){K=G+2|0;H=G;c[k+(I<<2)>>2]=(d[H]|d[H+1|0]<<8)<<16>>16<<16>>16;H=I+1|0;if((H|0)<(L|0)){G=K;I=H}else{X=K;break}}}else{X=o}if(x>>>0<C>>>0){Y=X;Z=x;_=0}else{break}while(1){I=d[Y]|0;G=I&3;if((G|0)==3){L=m+(_<<2)|0;K=(c[L>>2]|0)+1|0;c[L>>2]=K;$=K}else{K=m+(_<<2)|0;L=(c[K>>2]|0)-(G<<1)|0;c[K>>2]=L;$=L}if(($|0)<0){c[m+(_<<2)>>2]=0;aa=0}else{aa=$}L=k+(_<<2)|0;K=(c[L>>2]|0)+((I<<24>>16&-1024)>>aa)|0;if((K+32768|0)>>>0>65535>>>0){ba=(K>>31^32767)&65535}else{ba=K&65535}c[L>>2]=ba<<16>>16;L=Z+2|0;b[Z>>1]=ba;if(L>>>0<C>>>0){Y=Y+1|0;Z=L;_=_^t}else{break}}}}while(0);c[g>>2]=1;B=c[n>>2]|0;i=j;return B|0}}while(0);KIb(e,16,2146976,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;B=-22;i=j;return B|0}function C6(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;h=i;i=i+32|0;j=h|0;k=j;l=g+24|0;m=c[l>>2]|0;n=g+28|0;g=c[n>>2]|0;o=e;if((g|0)<1635){KIb(a,16,2454952,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}r=m;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=m+4|0;if((s|0)==1481655379){t=r;u=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;v=1;w=0}else if((s|0)==1396985944){s=r;u=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;v=0;w=1}else{KIb(a,16,2300248,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}if(!(g>>>0>u>>>0)){KIb(a,16,2249104,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}s=m+772|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;if(w){s=m+776|0;t=s;x=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;y=r;z=s}else{s=je(r|0)|0;r=m+776|0;m=r;x=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;y=s;z=r}r=H4a(a,y,x)|0;if((r|0)<0){q=r;i=h;return q|0}r=d[z+24|0]|0;x=d[z+27|0]|0;c[a+796>>2]=x;y=z+28|0;s=(d[y]|d[y+1|0]<<8)<<16>>16;if(w){y=z+30|0;m=y;A=(d[m]|d[m+1|0]<<8)<<16>>16;B=s;C=y}else{y=he(s|0)|0;s=z+30|0;z=s;A=he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0;B=y;C=s}if((B&65535)>>>0>1>>>0){RIb(a,2206904,(p=i,i=i+8|0,c[p>>2]=B&65535,p)|0);i=p;q=-1163346256;i=h;return q|0}if(!(A<<16>>16==0)){RIb(a,2174520,(p=i,i=i+8|0,c[p>>2]=A&65535,p)|0);i=p;q=-1163346256;i=h;return q|0}A=C+822|0;s=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;if(w){A=a+224|0;c[A>>2]=s;y=C+826|0;D=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;E=A}else{A=a+224|0;c[A>>2]=je(s|0)|0;s=C+826|0;D=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;E=A}A=a+228|0;c[A>>2]=D;s=c[E>>2]|0;if((s|0)>0&(D|0)>0){xKb(E,A,s,(s|0)<0|0?-1:0,D,(D|0)<0|0?-1:0,65536,0)|0}else{c[E>>2]=0;c[A>>2]=1}if((r|0)==52|(r|0)==51){F=4}else if((r|0)==6){F=1}else if((r|0)==50){F=3}else{RIb(a,2146960,(p=i,i=i+8|0,c[p>>2]=r,p)|0);i=p;q=-1163346256;i=h;return q|0}a:do{switch(x|0){case 1:case 32:case 64:{RIb(a,2618088,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=-1163346256;i=h;return q|0};case 16:{H=ca(ca(F<<1,c[a+120>>2]|0)|0,c[a+124>>2]|0)|0;break};case 12:{if(!(B<<16>>16==0)){H=ca(ca(F<<1,c[a+120>>2]|0)|0,c[a+124>>2]|0)|0;break a}KIb(a,16,2640792,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0};case 8:{H=ca(ca(c[a+120>>2]|0,F)|0,c[a+124>>2]|0)|0;break};case 10:{if(!(B<<16>>16==0)){A=(((ca(c[a+120>>2]|0,F)|0)+2|0)/3|0)<<2;H=ca(A,c[a+124>>2]|0)|0;break a}KIb(a,16,2123112,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0};default:{q=-1094995529;i=h;return q|0}}}while(0);B=(x*10|0)+(r*1e3|0)|v;if((B|0)==50160){c[a+140>>2]=42}else if((B|0)==50100|(B|0)==51100|(B|0)==50101|(B|0)==51101){c[a+140>>2]=86}else if((B|0)==6081|(B|0)==6080){c[a+140>>2]=8}else if((B|0)==51160){c[a+140>>2]=292}else if((B|0)==52081|(B|0)==52080){c[a+140>>2]=29}else if((B|0)==50161){c[a+140>>2]=41}else if((B|0)==51161){c[a+140>>2]=291}else if((B|0)==50120|(B|0)==51120|(B|0)==50121|(B|0)==51121){c[a+140>>2]=314}else if((B|0)==50081|(B|0)==50080){c[a+140>>2]=2}else if((B|0)==51081|(B|0)==51080){c[a+140>>2]=28}else if((B|0)==6160){c[a+140>>2]=32}else if((B|0)==6161){c[a+140>>2]=31}else{KIb(a,16,2590696,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1163346256;i=h;return q|0}B=M4a(a,o,0)|0;if((B|0)<0){q=B;i=h;return q|0}B=c[l>>2]|0;nrc(k|0,e|0,32)|0;k=B+u|0;B=wrc(H,(H|0)<0|0?-1:0,u,0)|0;u=G;H=c[n>>2]|0;n=(H|0)<0|0?-1:0;if((u|0)>(n|0)|(u|0)==(n|0)&B>>>0>H>>>0){KIb(a,16,2568856,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}do{if((x|0)==10){p=c[a+124>>2]|0;if((p|0)<=0){break}H=j|0;B=j+4|0;n=j+8|0;u=(F|0)==4;l=e+32|0;o=c[a+120>>2]|0;v=k;r=0;A=0;E=c[H>>2]|0;D=c[B>>2]|0;s=c[n>>2]|0;while(1){C=E;y=D;z=s;if((o|0)>0){if(w){m=v;t=r;I=0;J=0;K=z;L=y;M=C;while(1){do{if((I|0)==0){N=m;O=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;N=O>>>22;b[K>>1]=N;P=m+4|0;Q=O;R=2;S=N;T=K+2|0;U=68}else{N=I-1|0;O=t>>>22;V=K+2|0;b[K>>1]=O;if((N|0)!=0){P=m;Q=t;R=N;S=O;T=V;U=68;break}O=m;N=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=N>>>22;b[M>>1]=O;W=V;X=m+4|0;Y=N;Z=2;_=O;$=M+2|0;U=69}}while(0);do{if((U|0)==68){U=0;O=R-1|0;N=Q>>>12&1023;V=M+2|0;b[M>>1]=N;if((O|0)!=0){W=T;X=P;Y=Q<<10|S;Z=O;_=N;$=V;U=69;break}N=P;aa=2;ba=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;da=P+4|0;ea=T;fa=V}}while(0);if((U|0)==69){U=0;aa=Z-1|0;ba=Y<<10|_;da=X;ea=W;fa=$}V=ba>>>22;N=ba<<10|V;O=L+2|0;b[L>>1]=V;if(u){if((aa|0)==0){V=da;ga=2;ha=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;ia=da+4|0}else{ga=aa-1|0;ha=N;ia=da}ja=ga;ka=ha<<10|ha>>>22;la=ia}else{ja=aa;ka=N;la=da}N=J+1|0;if((N|0)<(o|0)){m=la;t=ka;I=ja;J=N;K=ea;L=O;M=fa}else{ma=la;na=ka;break}}}else{M=v;L=r;K=0;J=0;I=z;t=y;m=C;while(1){do{if((K|0)==0){O=M;N=je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;O=N>>>22;b[I>>1]=O;oa=M+4|0;pa=N;qa=2;ra=O;sa=I+2|0;U=81}else{O=K-1|0;N=L>>>22;V=I+2|0;b[I>>1]=N;if((O|0)!=0){oa=M;pa=L;qa=O;ra=N;sa=V;U=81;break}N=M;O=je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0;N=O>>>22;b[m>>1]=N;ta=V;ua=M+4|0;va=O;wa=2;xa=N;ya=m+2|0;U=82}}while(0);do{if((U|0)==81){U=0;N=qa-1|0;O=pa>>>12&1023;V=m+2|0;b[m>>1]=O;if((N|0)!=0){ta=sa;ua=oa;va=pa<<10|ra;wa=N;xa=O;ya=V;U=82;break}O=oa;za=2;Aa=je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;Ba=oa+4|0;Ca=sa;Da=V}}while(0);if((U|0)==82){U=0;za=wa-1|0;Aa=va<<10|xa;Ba=ua;Ca=ta;Da=ya}V=Aa>>>22;O=Aa<<10|V;N=t+2|0;b[t>>1]=V;if(u){if((za|0)==0){V=Ba;Ea=2;Fa=je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0;Ga=Ba+4|0}else{Ea=za-1|0;Fa=O;Ga=Ba}Ha=Ea;Ia=Fa<<10|Fa>>>22;Ja=Ga}else{Ha=za;Ia=O;Ja=Ba}O=J+1|0;if((O|0)<(o|0)){M=Ja;L=Ia;K=Ha;J=O;I=Ca;t=N;m=Da}else{ma=Ja;na=Ia;break}}}}else{ma=v;na=r}m=E+(c[l>>2]|0)|0;c[H>>2]=m;t=D+(c[e+36>>2]|0)|0;c[B>>2]=t;I=s+(c[e+40>>2]|0)|0;c[n>>2]=I;J=A+1|0;if((J|0)<(p|0)){v=ma;r=na;A=J;E=m;D=t;s=I}else{break}}}else if((x|0)==12){s=c[a+124>>2]|0;if((s|0)<=0){break}D=j|0;E=j+4|0;A=j+8|0;r=(F|0)==4;v=e+32|0;p=c[a+120>>2]|0;n=k;B=0;H=c[D>>2]|0;l=c[E>>2]|0;o=c[A>>2]|0;while(1){u=H;I=l;t=o;if((p|0)>0){if(w){m=n;J=0;K=t;L=I;M=u;while(1){C=m;b[K>>1]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>4;C=m+2|0;b[M>>1]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>4;C=m+4|0;b[L>>1]=((d[C]|d[C+1|0]<<8)<<16>>16&65535)>>>4;C=r?m+8|0:m+6|0;y=J+1|0;if((y|0)<(p|0)){m=C;J=y;K=K+2|0;L=L+2|0;M=M+2|0}else{Ka=C;break}}}else{M=n;L=0;K=t;J=I;m=u;while(1){C=M;b[K>>1]=((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;C=M+2|0;b[m>>1]=((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;C=M+4|0;b[J>>1]=((he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;C=r?M+8|0:M+6|0;y=L+1|0;if((y|0)<(p|0)){M=C;L=y;K=K+2|0;J=J+2|0;m=m+2|0}else{Ka=C;break}}}}else{Ka=n}m=H+(c[v>>2]|0)|0;c[D>>2]=m;J=l+(c[e+36>>2]|0)|0;c[E>>2]=J;K=o+(c[e+40>>2]|0)|0;c[A>>2]=K;L=B+1|0;if((L|0)<(s|0)){n=Ka;B=L;H=m;l=J;o=K}else{break}}}else if((x|0)==16){La=F<<1;U=97}else if((x|0)==8){La=F;U=97}}while(0);if((U|0)==97){U=ca(c[a+120>>2]|0,La)|0;uIb(c[j>>2]|0,c[e+32>>2]|0,k,U,U,c[a+124>>2]|0)}c[f>>2]=1;q=g;i=h;return q|0}function D6(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=c[b+60>>2]|0;h=b+140|0;j=qKb(c[h>>2]|0)|0;k=j+7|0;c[g>>2]=a[k]&1;l=g+4|0;c[l>>2]=((e[j+8>>1]|0)>>>11&15)+1;j=g+8|0;c[j>>2]=(a[k]|0)<0?51:50;c[g+12>>2]=(d[k]|0)>>>4&1;switch(c[h>>2]|0){case 31:case 32:case 8:{c[j>>2]=6;m=0;i=f;return m|0};case 85:case 86:case 313:case 314:case 2:case 291:case 292:case 28:{m=0;i=f;return m|0};case 29:{c[j>>2]=52;m=0;i=f;return m|0};case 42:case 41:{j=c[b+796>>2]|0;if((j|0)==0){m=0;i=f;return m|0}c[l>>2]=j;m=0;i=f;return m|0};default:{KIb(b,32,2249072,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;m=-1;i=f;return m|0}}return 0}function E6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;h=i;j=b+60|0;k=c[j>>2]|0;l=k+4|0;if((c[l>>2]|0)==10){m=ca(c[b+124>>2]<<2,c[b+120>>2]|0)|0}else{m=c2(c[b+140>>2]|0,c[b+120>>2]|0,c[b+124>>2]|0)|0}n=m+1664|0;o=d5a(b,e,n,(n|0)<0|0?-1:0)|0;if((o|0)<0){p=o;i=h;return p|0}o=c[e+24>>2]|0;mrc(o|0,0,1664)|0;n=k;q=o;y=(c[n>>2]|0)==0?1396985944:1481655379;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=o+4|0;y=(c[n>>2]|0)==0?1664:-2147090432;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=o+8|0;y=808333654;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=o+20|0;y=(c[n>>2]|0)==0?1:16777216;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=o+24|0;y=(c[n>>2]|0)==0?1664:-2147090432;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;if((c[b+88>>2]&8388608|0)==0){nrc(o+160|0,2365520,14)|0}q=o+660|0;y=-1;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=o+768|0;y=0;a[q]=y;y=y>>8;a[q+1|0]=y;q=o+770|0;y=(c[n>>2]|0)==0?1:256;a[q]=y;y=y>>8;a[q+1|0]=y;q=b+120|0;r=c[q>>2]|0;if((c[n>>2]|0)==0){s=o+772|0;y=r;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y}else{s=o+772|0;y=je(r|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y}s=b+124|0;r=c[s>>2]|0;if((c[n>>2]|0)==0){t=o+776|0;y=r;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y}else{t=o+776|0;y=je(r|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y}a[o+800|0]=c[k+8>>2];a[o+801|0]=2;a[o+802|0]=2;a[o+803|0]=c[l>>2];t=c[l>>2]|0;r=(t|0)==10;if((c[n>>2]|0)==0){if(r){u=1}else{u=(t|0)==12|0}v=o+804|0;y=u;a[v]=y;y=y>>8;a[v+1|0]=y}else{if(r){w=1}else{w=(t|0)==12|0}t=o+804|0;y=he(w|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y}t=o+808|0;y=(c[n>>2]|0)==0?1664:-2147090432;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=c[b+224>>2]|0;if((c[n>>2]|0)==0){w=o+1628|0;y=t;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y}else{w=o+1628|0;y=je(t|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y}w=c[b+228>>2]|0;if((c[n>>2]|0)==0){t=o+1632|0;y=w;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y}else{t=o+1632|0;y=je(w|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y}t=c[l>>2]|0;do{if((t|0)==12){l=c[s>>2]|0;if((l|0)<=0){x=m;break}w=c[j>>2]|0;r=f+32|0;v=f+36|0;u=f+40|0;z=o+1664|0;A=0;B=c[q>>2]|0;C=c[f>>2]|0;D=c[f+4>>2]|0;E=c[f+8>>2]|0;F=l;while(1){if((B|0)>0){l=z;G=0;do{H=C+(G<<1)|0;I=(d[H]|d[H+1|0]<<8)<<16>>16;if((c[w>>2]|0)==0){H=D+(G<<1)|0;J=E+(G<<1)|0;K=(d[J]|d[J+1|0]<<8)<<16>>16<<4;L=I;M=(d[H]|d[H+1|0]<<8)<<16>>16}else{H=he(I|0)|0;I=D+(G<<1)|0;J=he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0;I=E+(G<<1)|0;K=he((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)<<4|0)|0;L=H;M=J}J=L<<4;H=M<<4;y=K;a[l]=y;y=y>>8;a[l+1|0]=y;I=l+2|0;if((c[w>>2]|0)==0){N=J}else{N=he(J|0)|0}y=N;a[I]=y;y=y>>8;a[I+1|0]=y;I=l+4|0;if((c[w>>2]|0)==0){O=H}else{O=he(H|0)|0}y=O;a[I]=y;y=y>>8;a[I+1|0]=y;l=l+6|0;G=G+1|0;P=c[q>>2]|0;}while((G|0)<(P|0));Q=l;R=P;S=c[s>>2]|0}else{Q=z;R=B;S=F}G=A+1|0;if((G|0)<(S|0)){z=Q;A=G;B=R;C=C+(((c[r>>2]|0)/2|0)<<1)|0;D=D+(((c[v>>2]|0)/2|0)<<1)|0;E=E+(((c[u>>2]|0)/2|0)<<1)|0;F=S}else{x=m;break}}}else if((t|0)==8|(t|0)==16){F=b2(f,c[b+140>>2]|0,c[q>>2]|0,c[s>>2]|0,o+1664|0,(c[e+28>>2]|0)-1664|0)|0;if((F|0)<0){p=F}else{x=F;break}i=h;return p|0}else if((t|0)==10){F=o+1664|0;u=c[s>>2]|0;E=(u|0)>0;if((c[k+12>>2]|0)==0){if(!E){x=m;break}v=f+32|0;D=c[j>>2]|0;r=F;C=c[f>>2]|0;B=0;A=c[q>>2]|0;z=u;while(1){if((A|0)>0){w=r;G=0;do{I=G*6|0;H=C+I|0;J=C+(I+4)|0;T=(d[J]|d[J+1|0]<<8)<<16>>16;if((c[D>>2]|0)==0){J=C+(I+2)|0;U=H;V=w;y=((d[J]|d[J+1|0]<<8)<<16>>16&65535)<<6&4190208|(T&65535)>>>4&4092|((d[U]|d[U+1|0]<<8)<<16>>16&65535)<<16&-4194304;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y}else{V=((he(T|0)|0)&65535)>>>4&4092;T=C+(I+2)|0;I=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<6&4190208|V;V=H;H=w;y=je(I|((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<16&-4194304|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y}w=w+4|0;G=G+1|0;W=c[q>>2]|0;}while((G|0)<(W|0));X=w;Y=W;Z=c[s>>2]|0}else{X=r;Y=A;Z=z}G=B+1|0;if((G|0)<(Z|0)){r=X;C=C+(c[v>>2]|0)|0;B=G;A=Y;z=Z}else{x=m;break}}}else{if(!E){x=m;break}z=c[j>>2]|0;A=f+32|0;B=f+36|0;v=f+40|0;C=F;r=0;D=c[q>>2]|0;G=c[f>>2]|0;l=c[f+4>>2]|0;H=c[f+8>>2]|0;V=u;while(1){if((D|0)>0){I=C;T=0;do{U=T<<1;J=G+U|0;_=(d[J]|d[J+1|0]<<8)<<16>>16;if((c[z>>2]|0)==0){J=l+U|0;$=H+U|0;aa=I;y=((d[J]|d[J+1|0]<<8)<<16>>16&65535)<<2|(_&65535)<<12|((d[$]|d[$+1|0]<<8)<<16>>16&65535)<<22;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y}else{aa=((he(_|0)|0)&65535)<<12;_=l+U|0;$=((he((d[_]|d[_+1|0]<<8)<<16>>16|0)|0)&65535)<<2|aa;aa=H+U|0;U=I;y=je($|((he((d[aa]|d[aa+1|0]<<8)<<16>>16|0)|0)&65535)<<22|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y}I=I+4|0;T=T+1|0;ba=c[q>>2]|0;}while((T|0)<(ba|0));da=I;ea=ba;fa=c[s>>2]|0}else{da=C;ea=D;fa=V}T=r+1|0;if((T|0)<(fa|0)){C=da;r=T;D=ea;G=G+(c[A>>2]|0)|0;l=l+(c[B>>2]|0)|0;H=H+(c[v>>2]|0)|0;V=fa}else{x=m;break}}}}else{KIb(b,16,2300208,(V=i,i=i+8|0,c[V>>2]=t,V)|0);i=V;p=-1;i=h;return p|0}}while(0);t=x+1664|0;if((c[n>>2]|0)==0){n=o+16|0;y=t;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y}else{n=o+16|0;y=je(t|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y}n=e+36|0;c[n>>2]=c[n>>2]|1;c[g>>2]=1;p=0;i=h;return p|0}function F6(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+60>>2]|0;e=d;c[e>>2]=a;c[a+140>>2]=11;f=UHb()|0;c[d+4>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}f=d;h=d+8|0;c[h>>2]=ca(c[a+124>>2]|0,c[a+120>>2]|0)|0;a=0;while(1){if((a|0)>=3){g=0;j=6;break}k=pJb(c[h>>2]|0)|0;c[f+1036+(a<<2)>>2]=k;if((k|0)==0){break}else{a=a+1|0}}if((j|0)==6){i=b;return g|0}KIb(c[e>>2]|0,16,2249040,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;mJb(d+1036|0);mJb(d+1040|0);mJb(d+1044|0);g=-12;i=b;return g|0}function G6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;h=i;i=i+16|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=a[k]|0;n=k+1|0;o=(d[n]|d[n+1|0]<<8)<<16>>16;n=o&65535;p=d[k+3|0]|0;q=k+4|0;r=l-4|0;if((r|0)<(ca(n,m<<24>>24!=0?4:3)|0)){s=-1094995529;i=h;return s|0}do{if(m<<24>>24==0){if((o&65535)>>>0>256>>>0){s=-1094995529;i=h;return s|0}if(o<<16>>16==0){t=r;u=q;break}v=g+12|0;w=(o&65535)>>>0>1>>>0?n*3|0:3;x=w+4|0;y=q;z=0;while(1){c[v+(z<<2)>>2]=(d[y+2|0]|0)<<16|(d[y+1|0]|0)<<8|(d[y]|0)|-16777216;A=z+1|0;if((A|0)<(n|0)){y=y+3|0;z=A}else{break}}t=r-w|0;u=k+x|0}else{if(o<<16>>16==0){t=r;u=q;break}z=g+12|0;y=(o&65535)>>>0>1>>>0?n<<2:4;v=y+4|0;A=q;B=0;while(1){c[z+((d[A]|0)<<2)>>2]=(d[A+3|0]|0)<<16|(d[A+2|0]|0)<<8|(d[A+1|0]|0)|-16777216;C=B+1|0;if((C|0)<(n|0)){A=A+4|0;B=C}else{break}}t=r-y|0;u=k+v|0}}while(0);a:do{switch(p|0){case 35:{k=g+1036|0;r=g+1044|0;n=c[r>>2]|0;q=g+8|0;o=n+(c[q>>2]|0)|0;m=u+t|0;nrc(j|0,u|0,15)|0;B=u+15|0;A=n;while(1){if(!(B>>>0<m>>>0)){D=A;break}z=B+1|0;x=a[B]|0;w=x&255;C=w>>>4;if((C|0)==15){E=a[z]|0;F=B+2|0;G=E&255;H=(E&255)>>>4|x<<4}else{F=z;G=w;H=a[j+C|0]|0}C=A+1|0;a[A]=H;if(!(C>>>0<o>>>0)){D=C;break}w=G&15;if((w|0)==15){I=F+1|0;J=F}else{I=F;J=j+w|0}w=A+2|0;a[C]=a[J]|0;if(w>>>0<o>>>0){B=I;A=w}else{D=w;break}}A=D-n|0;B=c[r>>2]|0;o=c[k>>2]|0;m=c[q>>2]|0;v=o+m|0;y=B+A|0;if(!((A|0)>1&(m|0)>0)){break a}m=y;A=v;w=o;o=B;C=B+1|0;while(1){B=d[o]|0;if((B&128|0)==0){z=B+1|0;x=m-C|0;if((z|0)>(x|0)){break}E=A-w|0;K=(z|0)>(E|0)?E:z;nrc(w|0,C|0,(K|0)>(x|0)?x:K)|0;L=o+(B+2)|0;M=z}else{z=B-127|0;B=A-w|0;mrc(w|0,a[C]|0,((z|0)>(B|0)?B:z)|0)|0;L=o+2|0;M=z}z=w+M|0;B=L+1|0;if(B>>>0<y>>>0&z>>>0<v>>>0){w=z;o=L;C=B}else{break a}}KIb(0,16,2300192,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;break};case 36:{C=g+1036|0;o=g+1044|0;w=c[o>>2]|0;v=g+8|0;y=w+(c[v>>2]|0)|0;A=u+t|0;nrc(j|0,u|0,15)|0;m=u+15|0;q=w;while(1){if(!(m>>>0<A>>>0)){O=q;break}k=m+1|0;r=a[m]|0;n=r&255;B=n>>>4;if((B|0)==15){z=a[k]|0;P=m+2|0;Q=z&255;R=(z&255)>>>4|r<<4}else{P=k;Q=n;R=a[j+B|0]|0}B=q+1|0;a[q]=R;if(!(B>>>0<y>>>0)){O=B;break}n=Q&15;if((n|0)==15){S=P+1|0;T=P}else{S=P;T=j+n|0}n=q+2|0;a[B]=a[T]|0;if(n>>>0<y>>>0){m=S;q=n}else{O=n;break}}q=O-w|0;m=c[o>>2]|0;y=C;A=c[y>>2]|0;n=c[v>>2]|0;B=A+n|0;k=m+q|0;b:do{if((q|0)>1&(n|0)>0){r=k;z=B;K=A;x=m;E=m+1|0;while(1){U=d[x]|0;if((U&128|0)==0){V=U+1|0;W=r-E|0;if((V|0)>(W|0)){break}X=z-K|0;Y=(V|0)>(X|0)?X:V;nrc(K|0,E|0,(Y|0)>(W|0)?W:Y)|0;Z=x+(U+2)|0;_=V}else{V=U-127|0;U=z-K|0;mrc(K|0,a[E]|0,((V|0)>(U|0)?U:V)|0)|0;Z=x+2|0;_=V}V=K+_|0;U=Z+1|0;if(U>>>0<k>>>0&V>>>0<B>>>0){K=V;x=Z;E=U}else{break b}}KIb(0,16,2300192,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N}}while(0);B=c[v>>2]|0;if((B|0)==0){break a}k=c[g+1040>>2]|0;m=c[y>>2]|0;A=B;while(1){B=A-1|0;a[m]=(a[m]|0)+(a[k]|0);if((B|0)==0){break}else{k=k+1|0;m=m+1|0;A=B}}break};case 38:{A=K6(u,t,c[g+1036>>2]|0,c[g+8>>2]|0)|0;if((A|0)<0){s=A}else{break a}i=h;return s|0};case 39:{A=g+1036|0;m=g+8|0;k=K6(u,t,c[A>>2]|0,c[m>>2]|0)|0;if((k|0)<0){s=k;i=h;return s|0}k=c[m>>2]|0;if((k|0)==0){break a}m=c[g+1040>>2]|0;y=c[A>>2]|0;A=k;while(1){k=A-1|0;a[y]=(a[y]|0)+(a[m]|0);if((k|0)==0){break}else{m=m+1|0;y=y+1|0;A=k}}break};case 34:{A=g+1036|0;y=c[A>>2]|0;m=g+8|0;k=c[m>>2]|0;v=y+k|0;B=u+t|0;c:do{if((t|0)>1&(k|0)>0){n=B;q=v;C=y;o=u;w=u+1|0;while(1){E=d[o]|0;if((E&128|0)==0){x=E+1|0;K=n-w|0;if((x|0)>(K|0)){break}z=q-C|0;r=(x|0)>(z|0)?z:x;nrc(C|0,w|0,(r|0)>(K|0)?K:r)|0;$=o+(E+2)|0;aa=x}else{x=E-127|0;E=q-C|0;mrc(C|0,a[w]|0,((x|0)>(E|0)?E:x)|0)|0;$=o+2|0;aa=x}x=C+aa|0;E=$+1|0;if(E>>>0<B>>>0&x>>>0<v>>>0){C=x;o=$;w=E}else{break c}}KIb(0,16,2300192,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N}}while(0);v=c[m>>2]|0;if((v|0)==0){break a}B=c[g+1040>>2]|0;y=c[A>>2]|0;k=v;while(1){v=k-1|0;a[y]=(a[y]|0)+(a[B]|0);if((v|0)==0){break}else{B=B+1|0;y=y+1|0;k=v}}break};case 9:{k=c[g+1036>>2]|0;y=c[g+8>>2]|0;B=k+y|0;A=u+t|0;if(!((t|0)>1&(y|0)>0)){break a}y=A;m=B;v=k;k=u;w=u+1|0;while(1){o=d[k]|0;if((o&128|0)==0){C=o+1|0;q=y-w|0;if((C|0)>(q|0)){break}n=m-v|0;E=(C|0)>(n|0)?n:C;nrc(v|0,w|0,(E|0)>(q|0)?q:E)|0;ba=k+(o+2)|0;da=C}else{C=o-127|0;o=m-v|0;mrc(v|0,a[w]|0,((C|0)>(o|0)?o:C)|0)|0;ba=k+2|0;da=C}C=v+da|0;o=ba+1|0;if(o>>>0<A>>>0&C>>>0<B>>>0){v=C;k=ba;w=o}else{break a}}KIb(0,16,2300192,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;break};case 37:{w=c[g+1036>>2]|0;k=w+(c[g+8>>2]|0)|0;v=u+t|0;nrc(j|0,u|0,15)|0;B=u+15|0;A=w;while(1){if(!(B>>>0<v>>>0)){break a}w=B+1|0;m=a[B]|0;y=m&255;o=y>>>4;if((o|0)==15){C=a[w]|0;ea=B+2|0;fa=C&255;ga=(C&255)>>>4|m<<4}else{ea=w;fa=y;ga=a[j+o|0]|0}o=A+1|0;a[A]=ga;if(!(o>>>0<k>>>0)){break a}y=fa&15;if((y|0)==15){ha=ea+1|0;ia=ea}else{ha=ea;ia=j+y|0}y=A+2|0;a[o]=a[ia]|0;if(y>>>0<k>>>0){B=ha;A=y}else{break}}break};default:{}}}while(0);ha=g+4|0;ia=N4a(b,c[ha>>2]|0)|0;if((ia|0)<0){s=ia;i=h;return s|0}nrc(c[(c[ha>>2]|0)+4>>2]|0,g+12|0,1024)|0;ia=c[ha>>2]|0;c[ia+304>>2]=1;b=g;j=c[b>>2]|0;ea=c[j+124>>2]|0;fa=g+1036|0;if((ea|0)>0){ga=0;u=j;j=ea;ea=ia;while(1){t=(c[ea>>2]|0)+(ca(c[ea+32>>2]|0,j+~ga|0)|0)|0;N=c[u+120>>2]|0;nrc(t|0,(c[fa>>2]|0)+(ca(N,ga)|0)|0,N)|0;N=ga+1|0;t=c[b>>2]|0;ba=c[t+124>>2]|0;da=c[ha>>2]|0;if((N|0)<(ba|0)){ga=N;u=t;j=ba;ea=da}else{ja=da;break}}}else{ja=ia}ia=g+1040|0;g=c[ia>>2]|0;c[ia>>2]=c[fa>>2];c[fa>>2]=g;g=YHb(e,ja)|0;if((g|0)<0){s=g;i=h;return s|0}c[f>>2]=1;s=l;i=h;return s|0}function H6(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+1036|0);mJb(b+1040|0);mJb(b+1044|0);return 0}function I6(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=1;c[b+4>>2]=0;c[a+420>>2]=1;c[a+416>>2]=1;b=a+448|0;c[b>>2]=4;c[b+4>>2]=0;return 0}function J6(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[g+24>>2]|0;i=c[a+60>>2]|0;j=g+28|0;g=c[j>>2]|0;k=h+g|0;l=i;c[e+76>>2]=g-(c[l>>2]|0);g=M4a(a,e,0)|0;if((g|0)<0){m=g;return m|0}g=c[e>>2]|0;e=g;a=i+4|0;if((c[l>>2]|0)==0){n=c[a>>2]|0;o=e;p=h}else{c[l>>2]=0;l=h;i=(d[l]|d[l+1|0]<<8)<<16>>16;b[e>>1]=i;n=i<<16>>16;o=g+2|0;p=h+2|0}if(p>>>0<k>>>0){h=p;p=o;o=n;while(1){g=h+1|0;i=(b[1704376+(d[h]<<1)>>1]|0)+o|0;if((i+32768|0)>>>0>65535>>>0){q=(i>>31^32767)&65535}else{q=i&65535}i=q<<16>>16;b[p>>1]=q;if(g>>>0<k>>>0){h=g;p=p+2|0;o=i}else{r=i;break}}}else{r=n}c[a>>2]=r;c[f>>2]=1;m=c[j>>2]|0;return m|0}function K6(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=e+f|0;h=b+c|0;if(!((c|0)>0&(f|0)>0)){i=0;return i|0}f=e;c=g;j=~c;k=e;e=b;a:while(1){b=e+1|0;l=d[e]|0;if(b>>>0<h>>>0&k>>>0<g>>>0){m=0;n=k;o=b;while(1){do{if((1<<m&l|0)==0){p=o;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=o+2|0;r=q&65535;s=r>>>4;t=n;if((t-f|0)<(s+1|0)){i=-1094995529;u=13;break a}v=(r&15)+2|0;r=c-t|0;w=(v|0)>(r|0)?r:v;if((w|0)==0){x=p;y=n;break}v=~s;s=t+j|0;t=-3-(q&15)|0;q=(s|0)>(t|0)?s:t;t=w;w=n;while(1){s=t-1|0;a[w]=a[w+v|0]|0;if((s|0)==0){break}else{t=s;w=w+1|0}}x=p;y=n+~q|0}else{a[n]=a[o]|0;x=o+1|0;y=n+1|0}}while(0);w=m+1|0;if((w|0)<8&x>>>0<h>>>0&y>>>0<g>>>0){m=w;n=y;o=x}else{z=y;A=x;break}}}else{z=k;A=b}if(A>>>0<h>>>0&z>>>0<g>>>0){k=z;e=A}else{i=0;u=13;break}}if((u|0)==13){return i|0}return 0}function L6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;c[e>>2]=f;g=0;while(1){a[e+4+g|0]=a[b+(d[f+g|0]|0)|0]|0;h=g+1|0;if((h|0)<64){g=h}else{i=-1;j=0;break}}do{g=d[e+4+j|0]|0;i=(g|0)>(i|0)?g:i;a[e+68+j|0]=i;j=j+1|0;}while((j|0)<64);return}function M6(b,e){b=b|0;e=e|0;var f=0;f=i;switch(e|0){case 5:{e=0;do{a[b+e|0]=e<<3&24|e&36|e>>>3&3;e=e+1|0;}while((e|0)<64);i=f;return};case 4:{e=0;do{a[b+e|0]=e<<3&56|e>>>3;e=e+1|0;}while((e|0)<64);i=f;return};case 1:{e=0;do{a[b+e|0]=e;e=e+1|0;}while((e|0)<64);i=f;return};case 6:{e=0;do{a[b+e|0]=d[1077008+(e&7)|0]|0|e&56;e=e+1|0;}while((e|0)<64);i=f;return};case 3:{e=0;do{a[b+e|0]=a[565776+e|0]|0;e=e+1|0;}while((e|0)<64);i=f;return};case 2:{e=0;do{a[b+e|0]=e>>>1&3|e&56|e<<2&4;e=e+1|0;}while((e|0)<64);i=f;return};default:{KIb(0,16,2561592,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=f;return}}}function N6(b,c,e,f,g,h,i,j,k,l,m,n,o,p){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;q=1<<m;r=o-1|0;o=p-1|0;if((f|0)<=0){return}p=q-1|0;s=m<<1;t=0;u=h;h=g;while(1){g=ca(t,e)|0;v=h;w=u;x=0;while(1){y=v>>16;z=w>>16;A=y&p;B=z&p;C=y>>m;y=z>>m;z=y>>>0<o>>>0;do{if(C>>>0<r>>>0){if(z){D=(ca(y,e)|0)+C|0;E=q-A|0;F=ca(d[c+D|0]|0,E)|0;G=ca((ca(d[c+(D+1)|0]|0,A)|0)+F|0,q-B|0)|0;F=D+e|0;D=ca(d[c+F|0]|0,E)|0;a[b+(x+g)|0]=G+n+(ca((ca(d[c+(F+1)|0]|0,A)|0)+D|0,B)|0)>>s;break}if((y|0)<0){H=0}else{H=(y|0)>(o|0)?o:y}D=(ca(H,e)|0)+C|0;F=ca(d[c+D|0]|0,q-A|0)|0;a[b+(x+g)|0]=((ca(d[c+(D+1)|0]|0,A)|0)+F<<m)+n>>s}else{if((C|0)<0){I=0}else{I=(C|0)>(r|0)?r:C}if(z){F=I+(ca(y,e)|0)|0;D=ca(d[c+F|0]|0,q-B|0)|0;a[b+(x+g)|0]=((ca(d[c+(F+e)|0]|0,B)|0)+D<<m)+n>>s;break}if((y|0)<0){J=0}else{J=(y|0)>(o|0)?o:y}a[b+(x+g)|0]=a[c+((ca(J,e)|0)+I)|0]|0}}while(0);y=x+1|0;if((y|0)<8){v=v+i|0;w=w+k|0;x=y}else{break}}x=t+1|0;if((x|0)<(f|0)){t=x;u=u+l|0;h=h+j|0}else{break}}return}function O6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;P6(o,n,8,16,9);k=l|0;Q6(k,n,8,16);l=m|0;Q6(l,o,8,8);R6(b,n,o,k,l,f,16,8,8,8,8);i=g;return}function P6(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=d[h]|0;c=h+1|0;k=d[c]|0;l=h+2|0;m=d[l]|0;n=h+3|0;o=h+4|0;a[i]=a[(16-m+((k+b|0)*20|0)+((m+b|0)*-6|0)-(d[o]|0)+(((d[n]|0)+k|0)*3|0)>>5)+1404400|0]|0;k=d[c]|0;b=d[h]|0;m=h+5|0;a[i+1|0]=a[(16-k+(((d[l]|0)+k|0)*20|0)+(((d[n]|0)+b|0)*-6|0)-(d[m]|0)+(((d[o]|0)+b|0)*3|0)>>5)+1404400|0]|0;b=d[h]|0;k=h+6|0;a[i+2|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+16-b+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+b|0)*3|0)>>5)+1404400|0]|0;b=h+7|0;a[i+3|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+16+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1404400|0]|0;p=h+8|0;a[i+4|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+16+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1404400|0]|0;c=d[p]|0;a[i+5|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+16+(((d[b]|0)+(d[o]|0)|0)*-6|0)-c-(d[l]|0)+((c+(d[n]|0)|0)*3|0)>>5)+1404400|0]|0;c=d[b]|0;l=d[p]|0;a[i+6|0]=a[(16-c+((c+(d[k]|0)|0)*20|0)+((l+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[o]|0)+l|0)*3|0)>>5)+1404400|0]|0;l=d[b]|0;b=d[p]|0;p=d[k]|0;a[i+7|0]=a[(16-p+((b+l|0)*20|0)+((p+b|0)*-6|0)-(d[o]|0)+(((d[m]|0)+l|0)*3|0)>>5)+1404400|0]|0;l=j+1|0;if((l|0)<(g|0)){h=h+f|0;i=i+e|0;j=l}else{break}}return}function Q6(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=e<<1;o=e*3|0;p=e<<2;q=e*5|0;r=e*6|0;s=e*7|0;t=0;u=c;c=b;while(1){b=d[u]|0;v=d[u+f|0]|0;w=d[u+g|0]|0;x=d[u+h|0]|0;y=d[u+i|0]|0;z=d[u+j|0]|0;A=d[u+k|0]|0;B=d[u+l|0]|0;C=d[u+m|0]|0;D=16-w|0;a[c]=a[(D+((v+b|0)*20|0)+((w+b|0)*-6|0)-y+((x+v|0)*3|0)>>5)+1404400|0]|0;E=16-v|0;a[c+e|0]=a[(E+((w+v|0)*20|0)+((x+b|0)*-6|0)-z+((y+b|0)*3|0)>>5)+1404400|0]|0;F=16-b|0;a[c+n|0]=a[(F+((x+w|0)*20|0)+((y+v|0)*-6|0)-A+((z+b|0)*3|0)>>5)+1404400|0]|0;a[c+o|0]=a[(F+((y+x|0)*20|0)+((z+w|0)*-6|0)-B+((A+v|0)*3|0)>>5)+1404400|0]|0;a[c+p|0]=a[(E+((z+y|0)*20|0)+((A+x|0)*-6|0)-C+((B+w|0)*3|0)>>5)+1404400|0]|0;a[c+q|0]=a[(D+((A+z|0)*20|0)-C+((B+y|0)*-6|0)+((C+x|0)*3|0)>>5)+1404400|0]|0;a[c+r|0]=a[(16-x-B+((B+A|0)*20|0)+((C+z|0)*-6|0)+((C+y|0)*3|0)>>5)+1404400|0]|0;a[c+s|0]=a[(16-y-A+((B+z|0)*3|0)+((C+A|0)*-6|0)+((C+B|0)*20|0)>>5)+1404400|0]|0;B=t+1|0;if((B|0)<8){t=B;u=u+1|0;c=c+1|0}else{break}}return}function R6(a,b,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((m|0)>0){n=0}else{return}do{o=ca(n,i)|0;p=b+o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(n,j)|0;r=e+p|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ca(n,k)|0;t=f+r|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=ca(n,l)|0;v=g+t|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=ca(n,h)|0;c[a+v>>2]=(s>>>2&1061109567)+(q>>>2&1061109567)+(u>>>2&1061109567)+(w>>>2&1061109567)+(((q&50529027)+33686018+(s&50529027)+(u&50529027)+(w&50529027)|0)>>>2&252645135);w=b+(o+4)|0;o=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=e+(p+4)|0;p=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=f+(r+4)|0;r=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=g+(t+4)|0;t=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[a+(v+4)>>2]=(p>>>2&1061109567)+(o>>>2&1061109567)+(r>>>2&1061109567)+(t>>>2&1061109567)+(((o&50529027)+33686018+(p&50529027)+(r&50529027)+(t&50529027)|0)>>>2&252645135);n=n+1|0;}while((n|0)<(m|0));return}function S6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;P6(n,h,8,16,9);k=l|0;l=h+1|0;Q6(k,l,8,16);h=m|0;Q6(h,n,8,8);R6(b,l,n,k,h,f,16,8,8,8,8);i=g;return}function T6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;p=f<<1;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+40|0]=a[e+(p+8)|0]|0;q=h+48|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+56|0]=a[e+(j+8)|0]|0;p=h+64|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+72|0]=a[e+(q+8)|0]|0;j=h+80|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+88|0]=a[e+(p+8)|0]|0;q=h+96|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+104|0]=a[e+(j+8)|0]|0;p=h+112|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+120|0]=a[e+(q+8)|0]|0;j=h+128|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+136|0]=a[e+(p+8)|0]|0;p=k|0;P6(p,n,8,16,9);e=l|0;Q6(e,n,8,16);n=m|0;Q6(n,p,8,8);R6(b,o,k+8|0,e,n,f,16,8,8,8,8);i=g;return}function U6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=i;i=i+64|0;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=l|0;P6(o,h,8,16,9);h=m|0;Q6(h,k+1|0,8,16);m=n|0;Q6(m,o,8,8);R6(b,k+17|0,l+8|0,h,m,f,16,8,8,8,8);i=g;return}function V6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;P6(o,n,8,16,9);Q6(l|0,n,8,16);Q6(m|0,o,8,8);o=0;do{n=o<<3;k=l+n|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+n|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(o,f)|0;c[b+k>>2]=(h|e)-((h^e)>>>1&2139062143);e=n|4;n=l+e|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+e|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(k+4)>>2]=(e|h)-((e^h)>>>1&2139062143);o=o+1|0;}while((o|0)<8);i=g;return}function W6(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;P6(n,h,8,16,9);Q6(l|0,h+1|0,8,16);Q6(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;c[b+k>>2]=(o|e)-((o^e)>>>1&2139062143);e=h|4;h=l+e|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=(e|o)-((e^o)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function X6(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);c=j|0;Z6(c,l,16,24);m=k|0;Z6(m,n,16,16);R6(b,l,n,c,m,e,24,16,16,16,16);R6(b+8|0,g+8|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function Y6(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=d[h]|0;c=h+1|0;k=d[c]|0;l=h+2|0;m=d[l]|0;n=h+3|0;o=h+4|0;a[i]=a[(16-m+((k+b|0)*20|0)+((m+b|0)*-6|0)-(d[o]|0)+(((d[n]|0)+k|0)*3|0)>>5)+1404400|0]|0;k=d[c]|0;b=d[h]|0;m=h+5|0;a[i+1|0]=a[(16-k+(((d[l]|0)+k|0)*20|0)+(((d[n]|0)+b|0)*-6|0)-(d[m]|0)+(((d[o]|0)+b|0)*3|0)>>5)+1404400|0]|0;b=d[h]|0;k=h+6|0;a[i+2|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+16-b+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+b|0)*3|0)>>5)+1404400|0]|0;b=h+7|0;a[i+3|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+16+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1404400|0]|0;p=h+8|0;a[i+4|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+16+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1404400|0]|0;c=h+9|0;a[i+5|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+16+(((d[b]|0)+(d[o]|0)|0)*-6|0)-(d[l]|0)+(((d[p]|0)+(d[n]|0)|0)*3|0)-(d[c]|0)>>5)+1404400|0]|0;l=h+10|0;a[i+6|0]=a[((((d[b]|0)+(d[k]|0)|0)*20|0)+16+(((d[p]|0)+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[c]|0)+(d[o]|0)|0)*3|0)-(d[l]|0)>>5)+1404400|0]|0;n=h+11|0;a[i+7|0]=a[((((d[p]|0)+(d[b]|0)|0)*20|0)+16+(((d[c]|0)+(d[k]|0)|0)*-6|0)-(d[o]|0)+(((d[l]|0)+(d[m]|0)|0)*3|0)-(d[n]|0)>>5)+1404400|0]|0;o=h+12|0;a[i+8|0]=a[((((d[c]|0)+(d[p]|0)|0)*20|0)+16+(((d[l]|0)+(d[b]|0)|0)*-6|0)-(d[m]|0)+(((d[n]|0)+(d[k]|0)|0)*3|0)-(d[o]|0)>>5)+1404400|0]|0;m=h+13|0;a[i+9|0]=a[((((d[l]|0)+(d[c]|0)|0)*20|0)+16+(((d[n]|0)+(d[p]|0)|0)*-6|0)-(d[k]|0)+(((d[o]|0)+(d[b]|0)|0)*3|0)-(d[m]|0)>>5)+1404400|0]|0;k=h+14|0;a[i+10|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+16+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[b]|0)+(((d[m]|0)+(d[p]|0)|0)*3|0)-(d[k]|0)>>5)+1404400|0]|0;b=h+15|0;a[i+11|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+16+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[p]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1404400|0]|0;p=h+16|0;a[i+12|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+16+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1404400|0]|0;c=d[p]|0;a[i+13|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+16+(((d[b]|0)+(d[o]|0)|0)*-6|0)-c-(d[l]|0)+((c+(d[n]|0)|0)*3|0)>>5)+1404400|0]|0;c=d[b]|0;l=d[p]|0;a[i+14|0]=a[(16-c+((c+(d[k]|0)|0)*20|0)+((l+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[o]|0)+l|0)*3|0)>>5)+1404400|0]|0;l=d[b]|0;b=d[p]|0;p=d[k]|0;a[i+15|0]=a[(16-p+((b+l|0)*20|0)+((p+b|0)*-6|0)-(d[o]|0)+(((d[m]|0)+l|0)*3|0)>>5)+1404400|0]|0;l=j+1|0;if((l|0)<(g|0)){h=h+f|0;i=i+e|0;j=l}else{break}}return}function Z6(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=f*9|0;o=f*10|0;p=f*11|0;q=f*12|0;r=f*13|0;s=f*14|0;t=f*15|0;u=f<<4;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=e<<3;C=e*9|0;D=e*10|0;E=e*11|0;F=e*12|0;G=e*13|0;H=e*14|0;I=e*15|0;J=0;K=c;c=b;while(1){b=d[K]|0;L=d[K+f|0]|0;M=d[K+g|0]|0;N=d[K+h|0]|0;O=d[K+i|0]|0;P=d[K+j|0]|0;Q=d[K+k|0]|0;R=d[K+l|0]|0;S=d[K+m|0]|0;T=d[K+n|0]|0;U=d[K+o|0]|0;V=d[K+p|0]|0;W=d[K+q|0]|0;X=d[K+r|0]|0;Y=d[K+s|0]|0;Z=d[K+t|0]|0;_=d[K+u|0]|0;$=16-M|0;a[c]=a[($+((L+b|0)*20|0)+((M+b|0)*-6|0)-O+((N+L|0)*3|0)>>5)+1404400|0]|0;aa=16-L|0;a[c+e|0]=a[(aa+((M+L|0)*20|0)+((N+b|0)*-6|0)-P+((O+b|0)*3|0)>>5)+1404400|0]|0;ba=16-b|0;a[c+v|0]=a[(ba+((N+M|0)*20|0)+((O+L|0)*-6|0)-Q+((P+b|0)*3|0)>>5)+1404400|0]|0;a[c+w|0]=a[(ba+((O+N|0)*20|0)+((P+M|0)*-6|0)-R+((Q+L|0)*3|0)>>5)+1404400|0]|0;a[c+x|0]=a[(aa+((P+O|0)*20|0)+((Q+N|0)*-6|0)-S+((R+M|0)*3|0)>>5)+1404400|0]|0;a[c+y|0]=a[($+((Q+P|0)*20|0)+((R+O|0)*-6|0)-T+((S+N|0)*3|0)>>5)+1404400|0]|0;a[c+z|0]=a[(16-N+((R+Q|0)*20|0)+((S+P|0)*-6|0)-U+((T+O|0)*3|0)>>5)+1404400|0]|0;a[c+A|0]=a[(16-O+((S+R|0)*20|0)+((T+Q|0)*-6|0)-V+((U+P|0)*3|0)>>5)+1404400|0]|0;a[c+B|0]=a[(16-P+((T+S|0)*20|0)+((U+R|0)*-6|0)-W+((V+Q|0)*3|0)>>5)+1404400|0]|0;a[c+C|0]=a[(16-Q+((U+T|0)*20|0)+((V+S|0)*-6|0)-X+((W+R|0)*3|0)>>5)+1404400|0]|0;a[c+D|0]=a[(16-R+((V+U|0)*20|0)+((W+T|0)*-6|0)-Y+((X+S|0)*3|0)>>5)+1404400|0]|0;a[c+E|0]=a[(16-S+((W+V|0)*20|0)+((X+U|0)*-6|0)-Z+((Y+T|0)*3|0)>>5)+1404400|0]|0;a[c+F|0]=a[(16-T+((X+W|0)*20|0)+((Y+V|0)*-6|0)-_+((Z+U|0)*3|0)>>5)+1404400|0]|0;a[c+G|0]=a[(16-U+((Y+X|0)*20|0)-_+((Z+W|0)*-6|0)+((_+V|0)*3|0)>>5)+1404400|0]|0;a[c+H|0]=a[(16-V-Z+((Z+Y|0)*20|0)+((_+X|0)*-6|0)+((_+W|0)*3|0)>>5)+1404400|0]|0;a[c+I|0]=a[(16-W-Y+((Z+X|0)*3|0)+((_+Y|0)*-6|0)+((_+Z|0)*20|0)>>5)+1404400|0]|0;Z=J+1|0;if((Z|0)<16){J=Z;K=K+1|0;c=c+1|0}else{break}}return}function _6(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);l=j|0;c=g+1|0;Z6(l,c,16,24);m=k|0;Z6(m,n,16,16);R6(b,c,n,l,m,e,24,16,16,16,16);R6(b+8|0,g+9|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function $6(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);c=j|0;Z6(c,l,16,24);l=k|0;Z6(l,n,16,16);R6(b,g+24|0,h+16|0,c,l,e,24,16,16,16,16);R6(b+8|0,g+32|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function a7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);l=j|0;Z6(l,g+1|0,16,24);c=k|0;Z6(c,n,16,16);R6(b,g+25|0,h+16|0,l,c,e,24,16,16,16,16);R6(b+8|0,g+33|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function b7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1192|0;h=g+408|0;j=g+680|0;k=g+936|0;l=g|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);Z6(j|0,l,16,24);Z6(k|0,n,16,16);n=0;while(1){l=n<<4;h=j+l|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=(m|e)-((m^e)>>>1&2139062143);e=l|4;l=j+e|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+e|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(h+4)>>2]=(e|m)-((e^m)>>>1&2139062143);m=n+1|0;if((m|0)<16){n=m}else{s=0;break}}do{n=s<<4;m=n|8;e=j+m|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(s,f)|0;c[b+(e+8)>>2]=(m|h)-((m^h)>>>1&2139062143);h=n|12;n=j+h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(e+12)>>2]=(h|m)-((h^m)>>>1&2139062143);s=s+1|0;}while((s|0)<16);i=g;return}function c7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+1192|0;h=g|0;j=g+408|0;k=g+680|0;l=g+936|0;m=h|0;n=e;e=m;o=0;while(1){p=n;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=n+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;a[e+16|0]=a[n+16|0]|0;q=o+1|0;if((q|0)<17){n=n+f|0;e=e+24|0;o=q}else{break}}o=j|0;Y6(o,m,16,24,17);Z6(k|0,h+1|0,16,24);Z6(l|0,o,16,16);o=0;while(1){h=o<<4;m=k+h|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(o,f)|0;c[b+m>>2]=(e|j)-((e^j)>>>1&2139062143);j=h|4;h=k+j|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(m+4)>>2]=(j|e)-((j^e)>>>1&2139062143);e=o+1|0;if((e|0)<16){o=e}else{t=0;break}}do{o=t<<4;e=o|8;j=k+e|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+e|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ca(t,f)|0;c[b+(j+8)>>2]=(e|m)-((e^m)>>>1&2139062143);m=o|12;o=k+m|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+m|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[b+(j+12)>>2]=(m|e)-((m^e)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function d7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;e7(o,n,8,16,9);k=l|0;f7(k,n,8,16);l=m|0;f7(l,o,8,8);g7(b,n,o,k,l,f,16,8,8,8,8);i=g;return}function e7(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=d[h]|0;c=h+1|0;k=d[c]|0;l=h+2|0;m=d[l]|0;n=h+3|0;o=h+4|0;a[i]=a[(15-m+((k+b|0)*20|0)+((m+b|0)*-6|0)-(d[o]|0)+(((d[n]|0)+k|0)*3|0)>>5)+1404400|0]|0;k=d[c]|0;b=d[h]|0;m=h+5|0;a[i+1|0]=a[(15-k+(((d[l]|0)+k|0)*20|0)+(((d[n]|0)+b|0)*-6|0)-(d[m]|0)+(((d[o]|0)+b|0)*3|0)>>5)+1404400|0]|0;b=d[h]|0;k=h+6|0;a[i+2|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+15-b+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+b|0)*3|0)>>5)+1404400|0]|0;b=h+7|0;a[i+3|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+15+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1404400|0]|0;p=h+8|0;a[i+4|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+15+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1404400|0]|0;c=d[p]|0;a[i+5|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+15+(((d[b]|0)+(d[o]|0)|0)*-6|0)-c-(d[l]|0)+((c+(d[n]|0)|0)*3|0)>>5)+1404400|0]|0;c=d[b]|0;l=d[p]|0;a[i+6|0]=a[(15-c+((c+(d[k]|0)|0)*20|0)+((l+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[o]|0)+l|0)*3|0)>>5)+1404400|0]|0;l=d[b]|0;b=d[p]|0;p=d[k]|0;a[i+7|0]=a[(15-p+((b+l|0)*20|0)+((p+b|0)*-6|0)-(d[o]|0)+(((d[m]|0)+l|0)*3|0)>>5)+1404400|0]|0;l=j+1|0;if((l|0)<(g|0)){h=h+f|0;i=i+e|0;j=l}else{break}}return}function f7(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=e<<1;o=e*3|0;p=e<<2;q=e*5|0;r=e*6|0;s=e*7|0;t=0;u=c;c=b;while(1){b=d[u]|0;v=d[u+f|0]|0;w=d[u+g|0]|0;x=d[u+h|0]|0;y=d[u+i|0]|0;z=d[u+j|0]|0;A=d[u+k|0]|0;B=d[u+l|0]|0;C=d[u+m|0]|0;D=15-w|0;a[c]=a[(D+((v+b|0)*20|0)+((w+b|0)*-6|0)-y+((x+v|0)*3|0)>>5)+1404400|0]|0;E=15-v|0;a[c+e|0]=a[(E+((w+v|0)*20|0)+((x+b|0)*-6|0)-z+((y+b|0)*3|0)>>5)+1404400|0]|0;F=15-b|0;a[c+n|0]=a[(F+((x+w|0)*20|0)+((y+v|0)*-6|0)-A+((z+b|0)*3|0)>>5)+1404400|0]|0;a[c+o|0]=a[(F+((y+x|0)*20|0)+((z+w|0)*-6|0)-B+((A+v|0)*3|0)>>5)+1404400|0]|0;a[c+p|0]=a[(E+((z+y|0)*20|0)+((A+x|0)*-6|0)-C+((B+w|0)*3|0)>>5)+1404400|0]|0;a[c+q|0]=a[(D+((A+z|0)*20|0)-C+((B+y|0)*-6|0)+((C+x|0)*3|0)>>5)+1404400|0]|0;a[c+r|0]=a[(15-x-B+((B+A|0)*20|0)+((C+z|0)*-6|0)+((C+y|0)*3|0)>>5)+1404400|0]|0;a[c+s|0]=a[(15-y-A+((B+z|0)*3|0)+((C+A|0)*-6|0)+((C+B|0)*20|0)>>5)+1404400|0]|0;B=t+1|0;if((B|0)<8){t=B;u=u+1|0;c=c+1|0}else{break}}return}function g7(a,b,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((m|0)>0){n=0}else{return}do{o=ca(n,i)|0;p=b+o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(n,j)|0;r=e+p|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ca(n,k)|0;t=f+r|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=ca(n,l)|0;v=g+t|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=ca(n,h)|0;c[a+v>>2]=(s>>>2&1061109567)+(q>>>2&1061109567)+(u>>>2&1061109567)+(w>>>2&1061109567)+(((q&50529027)+16843009+(s&50529027)+(u&50529027)+(w&50529027)|0)>>>2&252645135);w=b+(o+4)|0;o=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=e+(p+4)|0;p=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=f+(r+4)|0;r=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=g+(t+4)|0;t=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[a+(v+4)>>2]=(p>>>2&1061109567)+(o>>>2&1061109567)+(r>>>2&1061109567)+(t>>>2&1061109567)+(((o&50529027)+16843009+(p&50529027)+(r&50529027)+(t&50529027)|0)>>>2&252645135);n=n+1|0;}while((n|0)<(m|0));return}function h7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;e7(n,h,8,16,9);k=l|0;l=h+1|0;f7(k,l,8,16);h=m|0;f7(h,n,8,8);g7(b,l,n,k,h,f,16,8,8,8,8);i=g;return}function i7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;p=f<<1;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+40|0]=a[e+(p+8)|0]|0;q=h+48|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+56|0]=a[e+(j+8)|0]|0;p=h+64|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+72|0]=a[e+(q+8)|0]|0;j=h+80|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+88|0]=a[e+(p+8)|0]|0;q=h+96|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+104|0]=a[e+(j+8)|0]|0;p=h+112|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+120|0]=a[e+(q+8)|0]|0;j=h+128|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+136|0]=a[e+(p+8)|0]|0;p=k|0;e7(p,n,8,16,9);e=l|0;f7(e,n,8,16);n=m|0;f7(n,p,8,8);g7(b,o,k+8|0,e,n,f,16,8,8,8,8);i=g;return}function j7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=i;i=i+64|0;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=l|0;e7(o,h,8,16,9);h=m|0;f7(h,k+1|0,8,16);m=n|0;f7(m,o,8,8);g7(b,k+17|0,l+8|0,h,m,f,16,8,8,8,8);i=g;return}function k7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;e7(o,n,8,16,9);f7(l|0,n,8,16);f7(m|0,o,8,8);o=0;do{n=o<<3;k=l+n|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+n|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(o,f)|0;c[b+k>>2]=((h^e)>>>1&2139062143)+(h&e);e=n|4;n=l+e|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+e|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(k+4)>>2]=((e^h)>>>1&2139062143)+(e&h);o=o+1|0;}while((o|0)<8);i=g;return}function l7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;e7(n,h,8,16,9);f7(l|0,h+1|0,8,16);f7(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;c[b+k>>2]=((o^e)>>>1&2139062143)+(o&e);e=h|4;h=l+e|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=((e^o)>>>1&2139062143)+(e&o);n=n+1|0;}while((n|0)<8);i=g;return}function m7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;n7(n,l,16,24,17);c=j|0;o7(c,l,16,24);m=k|0;o7(m,n,16,16);g7(b,l,n,c,m,e,24,16,16,16,16);g7(b+8|0,g+8|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function n7(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=d[h]|0;c=h+1|0;k=d[c]|0;l=h+2|0;m=d[l]|0;n=h+3|0;o=h+4|0;a[i]=a[(15-m+((k+b|0)*20|0)+((m+b|0)*-6|0)-(d[o]|0)+(((d[n]|0)+k|0)*3|0)>>5)+1404400|0]|0;k=d[c]|0;b=d[h]|0;m=h+5|0;a[i+1|0]=a[(15-k+(((d[l]|0)+k|0)*20|0)+(((d[n]|0)+b|0)*-6|0)-(d[m]|0)+(((d[o]|0)+b|0)*3|0)>>5)+1404400|0]|0;b=d[h]|0;k=h+6|0;a[i+2|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+15-b+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+b|0)*3|0)>>5)+1404400|0]|0;b=h+7|0;a[i+3|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+15+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1404400|0]|0;p=h+8|0;a[i+4|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+15+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1404400|0]|0;c=h+9|0;a[i+5|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+15+(((d[b]|0)+(d[o]|0)|0)*-6|0)-(d[l]|0)+(((d[p]|0)+(d[n]|0)|0)*3|0)-(d[c]|0)>>5)+1404400|0]|0;l=h+10|0;a[i+6|0]=a[((((d[b]|0)+(d[k]|0)|0)*20|0)+15+(((d[p]|0)+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[c]|0)+(d[o]|0)|0)*3|0)-(d[l]|0)>>5)+1404400|0]|0;n=h+11|0;a[i+7|0]=a[((((d[p]|0)+(d[b]|0)|0)*20|0)+15+(((d[c]|0)+(d[k]|0)|0)*-6|0)-(d[o]|0)+(((d[l]|0)+(d[m]|0)|0)*3|0)-(d[n]|0)>>5)+1404400|0]|0;o=h+12|0;a[i+8|0]=a[((((d[c]|0)+(d[p]|0)|0)*20|0)+15+(((d[l]|0)+(d[b]|0)|0)*-6|0)-(d[m]|0)+(((d[n]|0)+(d[k]|0)|0)*3|0)-(d[o]|0)>>5)+1404400|0]|0;m=h+13|0;a[i+9|0]=a[((((d[l]|0)+(d[c]|0)|0)*20|0)+15+(((d[n]|0)+(d[p]|0)|0)*-6|0)-(d[k]|0)+(((d[o]|0)+(d[b]|0)|0)*3|0)-(d[m]|0)>>5)+1404400|0]|0;k=h+14|0;a[i+10|0]=a[((((d[n]|0)+(d[l]|0)|0)*20|0)+15+(((d[o]|0)+(d[c]|0)|0)*-6|0)-(d[b]|0)+(((d[m]|0)+(d[p]|0)|0)*3|0)-(d[k]|0)>>5)+1404400|0]|0;b=h+15|0;a[i+11|0]=a[((((d[o]|0)+(d[n]|0)|0)*20|0)+15+(((d[m]|0)+(d[l]|0)|0)*-6|0)-(d[p]|0)+(((d[k]|0)+(d[c]|0)|0)*3|0)-(d[b]|0)>>5)+1404400|0]|0;p=h+16|0;a[i+12|0]=a[((((d[m]|0)+(d[o]|0)|0)*20|0)+15+(((d[k]|0)+(d[n]|0)|0)*-6|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*3|0)-(d[p]|0)>>5)+1404400|0]|0;c=d[p]|0;a[i+13|0]=a[((((d[k]|0)+(d[m]|0)|0)*20|0)+15+(((d[b]|0)+(d[o]|0)|0)*-6|0)-c-(d[l]|0)+((c+(d[n]|0)|0)*3|0)>>5)+1404400|0]|0;c=d[b]|0;l=d[p]|0;a[i+14|0]=a[(15-c+((c+(d[k]|0)|0)*20|0)+((l+(d[m]|0)|0)*-6|0)-(d[n]|0)+(((d[o]|0)+l|0)*3|0)>>5)+1404400|0]|0;l=d[b]|0;b=d[p]|0;p=d[k]|0;a[i+15|0]=a[(15-p+((b+l|0)*20|0)+((p+b|0)*-6|0)-(d[o]|0)+(((d[m]|0)+l|0)*3|0)>>5)+1404400|0]|0;l=j+1|0;if((l|0)<(g|0)){h=h+f|0;i=i+e|0;j=l}else{break}}return}function o7(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=f*9|0;o=f*10|0;p=f*11|0;q=f*12|0;r=f*13|0;s=f*14|0;t=f*15|0;u=f<<4;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=e<<3;C=e*9|0;D=e*10|0;E=e*11|0;F=e*12|0;G=e*13|0;H=e*14|0;I=e*15|0;J=0;K=c;c=b;while(1){b=d[K]|0;L=d[K+f|0]|0;M=d[K+g|0]|0;N=d[K+h|0]|0;O=d[K+i|0]|0;P=d[K+j|0]|0;Q=d[K+k|0]|0;R=d[K+l|0]|0;S=d[K+m|0]|0;T=d[K+n|0]|0;U=d[K+o|0]|0;V=d[K+p|0]|0;W=d[K+q|0]|0;X=d[K+r|0]|0;Y=d[K+s|0]|0;Z=d[K+t|0]|0;_=d[K+u|0]|0;$=15-M|0;a[c]=a[($+((L+b|0)*20|0)+((M+b|0)*-6|0)-O+((N+L|0)*3|0)>>5)+1404400|0]|0;aa=15-L|0;a[c+e|0]=a[(aa+((M+L|0)*20|0)+((N+b|0)*-6|0)-P+((O+b|0)*3|0)>>5)+1404400|0]|0;ba=15-b|0;a[c+v|0]=a[(ba+((N+M|0)*20|0)+((O+L|0)*-6|0)-Q+((P+b|0)*3|0)>>5)+1404400|0]|0;a[c+w|0]=a[(ba+((O+N|0)*20|0)+((P+M|0)*-6|0)-R+((Q+L|0)*3|0)>>5)+1404400|0]|0;a[c+x|0]=a[(aa+((P+O|0)*20|0)+((Q+N|0)*-6|0)-S+((R+M|0)*3|0)>>5)+1404400|0]|0;a[c+y|0]=a[($+((Q+P|0)*20|0)+((R+O|0)*-6|0)-T+((S+N|0)*3|0)>>5)+1404400|0]|0;a[c+z|0]=a[(15-N+((R+Q|0)*20|0)+((S+P|0)*-6|0)-U+((T+O|0)*3|0)>>5)+1404400|0]|0;a[c+A|0]=a[(15-O+((S+R|0)*20|0)+((T+Q|0)*-6|0)-V+((U+P|0)*3|0)>>5)+1404400|0]|0;a[c+B|0]=a[(15-P+((T+S|0)*20|0)+((U+R|0)*-6|0)-W+((V+Q|0)*3|0)>>5)+1404400|0]|0;a[c+C|0]=a[(15-Q+((U+T|0)*20|0)+((V+S|0)*-6|0)-X+((W+R|0)*3|0)>>5)+1404400|0]|0;a[c+D|0]=a[(15-R+((V+U|0)*20|0)+((W+T|0)*-6|0)-Y+((X+S|0)*3|0)>>5)+1404400|0]|0;a[c+E|0]=a[(15-S+((W+V|0)*20|0)+((X+U|0)*-6|0)-Z+((Y+T|0)*3|0)>>5)+1404400|0]|0;a[c+F|0]=a[(15-T+((X+W|0)*20|0)+((Y+V|0)*-6|0)-_+((Z+U|0)*3|0)>>5)+1404400|0]|0;a[c+G|0]=a[(15-U+((Y+X|0)*20|0)-_+((Z+W|0)*-6|0)+((_+V|0)*3|0)>>5)+1404400|0]|0;a[c+H|0]=a[(15-V-Z+((Z+Y|0)*20|0)+((_+X|0)*-6|0)+((_+W|0)*3|0)>>5)+1404400|0]|0;a[c+I|0]=a[(15-W-Y+((Z+X|0)*3|0)+((_+Y|0)*-6|0)+((_+Z|0)*20|0)>>5)+1404400|0]|0;Z=J+1|0;if((Z|0)<16){J=Z;K=K+1|0;c=c+1|0}else{break}}return}function p7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;n7(n,l,16,24,17);l=j|0;c=g+1|0;o7(l,c,16,24);m=k|0;o7(m,n,16,16);g7(b,c,n,l,m,e,24,16,16,16,16);g7(b+8|0,g+9|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function q7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;n7(n,l,16,24,17);c=j|0;o7(c,l,16,24);l=k|0;o7(l,n,16,16);g7(b,g+24|0,h+16|0,c,l,e,24,16,16,16,16);g7(b+8|0,g+32|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function r7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;n7(n,l,16,24,17);l=j|0;o7(l,g+1|0,16,24);c=k|0;o7(c,n,16,16);g7(b,g+25|0,h+16|0,l,c,e,24,16,16,16,16);g7(b+8|0,g+33|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function s7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1192|0;h=g+408|0;j=g+680|0;k=g+936|0;l=g|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=h|0;n7(n,l,16,24,17);o7(j|0,l,16,24);o7(k|0,n,16,16);n=0;while(1){l=n<<4;h=j+l|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=((m^e)>>>1&2139062143)+(m&e);e=l|4;l=j+e|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+e|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(h+4)>>2]=((e^m)>>>1&2139062143)+(e&m);m=n+1|0;if((m|0)<16){n=m}else{s=0;break}}do{n=s<<4;m=n|8;e=j+m|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(s,f)|0;c[b+(e+8)>>2]=((m^h)>>>1&2139062143)+(m&h);h=n|12;n=j+h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(e+12)>>2]=((h^m)>>>1&2139062143)+(h&m);s=s+1|0;}while((s|0)<16);i=g;return}function t7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+1192|0;h=g|0;j=g+408|0;k=g+680|0;l=g+936|0;m=h|0;n=e;e=m;o=0;while(1){p=n;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=n+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;a[e+16|0]=a[n+16|0]|0;q=o+1|0;if((q|0)<17){n=n+f|0;e=e+24|0;o=q}else{break}}o=j|0;n7(o,m,16,24,17);o7(k|0,h+1|0,16,24);o7(l|0,o,16,16);o=0;while(1){h=o<<4;m=k+h|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(o,f)|0;c[b+m>>2]=((e^j)>>>1&2139062143)+(e&j);j=h|4;h=k+j|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(m+4)>>2]=((j^e)>>>1&2139062143)+(j&e);e=o+1|0;if((e|0)<16){o=e}else{t=0;break}}do{o=t<<4;e=o|8;j=k+e|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+e|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ca(t,f)|0;c[b+(j+8)>>2]=((e^m)>>>1&2139062143)+(e&m);m=o|12;o=k+m|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+m|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[b+(j+12)>>2]=((m^e)>>>1&2139062143)+(m&e);t=t+1|0;}while((t|0)<16);i=g;return}function u7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;P6(o,n,8,16,9);k=l|0;Q6(k,n,8,16);l=m|0;Q6(l,o,8,8);v7(b,n,o,k,l,f,16,8,8,8,8);i=g;return}function v7(a,b,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((m|0)>0){n=0}else{return}do{o=ca(n,i)|0;p=b+o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(n,j)|0;r=e+p|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ca(n,k)|0;t=f+r|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=ca(n,l)|0;v=g+t|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=ca(n,h)|0;x=a+v|0;y=c[x>>2]|0;z=(s>>>2&1061109567)+(q>>>2&1061109567)+(u>>>2&1061109567)+(w>>>2&1061109567)+(((q&50529027)+33686018+(s&50529027)+(u&50529027)+(w&50529027)|0)>>>2&252645135)|0;c[x>>2]=(z|y)-((z^y)>>>1&2139062143);y=b+(o+4)|0;o=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=e+(p+4)|0;p=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=f+(r+4)|0;r=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=g+(t+4)|0;t=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=a+(v+4)|0;v=c[y>>2]|0;z=(p>>>2&1061109567)+(o>>>2&1061109567)+(r>>>2&1061109567)+(t>>>2&1061109567)+(((o&50529027)+33686018+(p&50529027)+(r&50529027)+(t&50529027)|0)>>>2&252645135)|0;c[y>>2]=(z|v)-((z^v)>>>1&2139062143);n=n+1|0;}while((n|0)<(m|0));return}function w7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;P6(n,h,8,16,9);k=l|0;l=h+1|0;Q6(k,l,8,16);h=m|0;Q6(h,n,8,8);v7(b,l,n,k,h,f,16,8,8,8,8);i=g;return}function x7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;p=f<<1;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+40|0]=a[e+(p+8)|0]|0;q=h+48|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+56|0]=a[e+(j+8)|0]|0;p=h+64|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+72|0]=a[e+(q+8)|0]|0;j=h+80|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+88|0]=a[e+(p+8)|0]|0;q=h+96|0;j=p+f|0;p=e+j|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;a[h+104|0]=a[e+(j+8)|0]|0;p=h+112|0;q=j+f|0;j=e+q|0;r=j|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=j;a[h+120|0]=a[e+(q+8)|0]|0;j=h+128|0;p=q+f|0;q=e+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[j>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[j+4>>2]=q;a[h+136|0]=a[e+(p+8)|0]|0;p=k|0;P6(p,n,8,16,9);e=l|0;Q6(e,n,8,16);n=m|0;Q6(n,p,8,8);v7(b,o,k+8|0,e,n,f,16,8,8,8,8);i=g;return}function y7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=i;i=i+64|0;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=l|0;P6(o,h,8,16,9);h=m|0;Q6(h,k+1|0,8,16);m=n|0;Q6(m,o,8,8);v7(b,k+17|0,l+8|0,h,m,f,16,8,8,8,8);i=g;return}function z7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=h;o=e;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+8|0]=a[e+8|0]|0;o=h+16|0;j=e+f|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;o=f<<1;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+40|0]=a[e+(o+8)|0]|0;p=h+48|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+56|0]=a[e+(j+8)|0]|0;o=h+64|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+72|0]=a[e+(p+8)|0]|0;j=h+80|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+88|0]=a[e+(o+8)|0]|0;p=h+96|0;j=o+f|0;o=e+j|0;q=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=o;a[h+104|0]=a[e+(j+8)|0]|0;o=h+112|0;p=j+f|0;j=e+p|0;q=j|0;r=j+4|0;j=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=j;a[h+120|0]=a[e+(p+8)|0]|0;j=h+128|0;o=p+f|0;p=e+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[j+4>>2]=p;a[h+136|0]=a[e+(o+8)|0]|0;o=k|0;P6(o,n,8,16,9);Q6(l|0,n,8,16);Q6(m|0,o,8,8);o=0;do{n=o<<3;k=l+n|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+n|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(o,f)|0;p=b+k|0;j=c[p>>2]|0;q=(h|e)-((h^e)>>>1&2139062143)|0;c[p>>2]=(q|j)-((q^j)>>>1&2139062143);j=n|4;n=l+j|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+j|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(k+4)|0;k=c[n>>2]|0;p=(j|q)-((j^q)>>>1&2139062143)|0;c[n>>2]=(p|k)-((p^k)>>>1&2139062143);o=o+1|0;}while((o|0)<8);i=g;return}function A7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;P6(n,h,8,16,9);Q6(l|0,h+1|0,8,16);Q6(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;j=b+k|0;p=c[j>>2]|0;q=(o|e)-((o^e)>>>1&2139062143)|0;c[j>>2]=(q|p)-((q^p)>>>1&2139062143);p=h|4;h=l+p|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(k+4)|0;k=c[h>>2]|0;j=(p|q)-((p^q)>>>1&2139062143)|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function B7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);c=j|0;Z6(c,l,16,24);m=k|0;Z6(m,n,16,16);v7(b,l,n,c,m,e,24,16,16,16,16);v7(b+8|0,g+8|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function C7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);l=j|0;c=g+1|0;Z6(l,c,16,24);m=k|0;Z6(m,n,16,16);v7(b,c,n,l,m,e,24,16,16,16,16);v7(b+8|0,g+9|0,h+8|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function D7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);c=j|0;Z6(c,l,16,24);l=k|0;Z6(l,n,16,16);v7(b,g+24|0,h+16|0,c,l,e,24,16,16,16,16);v7(b+8|0,g+32|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function E7(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+1192|0;g=f|0;h=f+408|0;j=f+680|0;k=f+936|0;l=g|0;m=c;c=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=c+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[c+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+e|0;c=c+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);l=j|0;Z6(l,g+1|0,16,24);c=k|0;Z6(c,n,16,16);v7(b,g+25|0,h+16|0,l,c,e,24,16,16,16,16);v7(b+8|0,g+33|0,h+24|0,j+8|0,k+8|0,e,24,16,16,16,16);i=f;return}function F7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1192|0;h=g+408|0;j=g+680|0;k=g+936|0;l=g|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=h|0;Y6(n,l,16,24,17);Z6(j|0,l,16,24);Z6(k|0,n,16,16);n=0;while(1){l=n<<4;h=j+l|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;p=b+h|0;r=c[p>>2]|0;q=(m|e)-((m^e)>>>1&2139062143)|0;c[p>>2]=(q|r)-((q^r)>>>1&2139062143);r=l|4;l=j+r|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+r|0;r=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(h+4)|0;h=c[l>>2]|0;p=(r|q)-((r^q)>>>1&2139062143)|0;c[l>>2]=(p|h)-((p^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{s=0;break}}do{n=s<<4;h=n|8;p=j+h|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(s,f)|0;q=b+(p+8)|0;r=c[q>>2]|0;e=(h|l)-((h^l)>>>1&2139062143)|0;c[q>>2]=(e|r)-((e^r)>>>1&2139062143);r=n|12;n=j+r|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+r|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(p+12)|0;p=c[n>>2]|0;q=(r|e)-((r^e)>>>1&2139062143)|0;c[n>>2]=(q|p)-((q^p)>>>1&2139062143);s=s+1|0;}while((s|0)<16);i=g;return}function G7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+1192|0;h=g|0;j=g+408|0;k=g+680|0;l=g+936|0;m=h|0;n=e;e=m;o=0;while(1){p=n;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=n+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=e+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;a[e+16|0]=a[n+16|0]|0;q=o+1|0;if((q|0)<17){n=n+f|0;e=e+24|0;o=q}else{break}}o=j|0;Y6(o,m,16,24,17);Z6(k|0,h+1|0,16,24);Z6(l|0,o,16,16);o=0;while(1){h=o<<4;m=k+h|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(o,f)|0;n=b+m|0;q=c[n>>2]|0;s=(e|j)-((e^j)>>>1&2139062143)|0;c[n>>2]=(s|q)-((s^q)>>>1&2139062143);q=h|4;h=k+q|0;s=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+q|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(m+4)|0;m=c[h>>2]|0;n=(q|s)-((q^s)>>>1&2139062143)|0;c[h>>2]=(n|m)-((n^m)>>>1&2139062143);m=o+1|0;if((m|0)<16){o=m}else{t=0;break}}do{o=t<<4;m=o|8;n=k+m|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+m|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(t,f)|0;s=b+(n+8)|0;q=c[s>>2]|0;j=(m|h)-((m^h)>>>1&2139062143)|0;c[s>>2]=(j|q)-((j^q)>>>1&2139062143);q=o|12;o=k+q|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+q|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+12)|0;n=c[o>>2]|0;s=(q|j)-((q^j)>>>1&2139062143)|0;c[o>>2]=(s|n)-((s^n)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function H7(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(e+4)|0;c[a+(e+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=e<<1;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;e=b+g|0;c[a+h>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=b+(g+4)|0;c[a+(h+4)>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function I7(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=f;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[g>>2]=(j|h)-((j^h)>>>1&2139062143);h=b+4|0;j=c[h>>2]|0;g=f+4|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[h>>2]=(i|j)-((i^j)>>>1&2139062143);j=a+1|0;if((j|0)<8){f=f+e|0;b=b+e|0;a=j}else{break}}return}function J7(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(e+4)|0;c[a+(e+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=e<<1;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+8|0;c[a+8>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+12|0;c[a+12>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=e+8|0;f=e+8|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(e+12)|0;c[a+(e+12)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;g=b+f|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(f+4)|0;c[a+(h+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=h+e|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(g+4)|0;c[a+(f+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;g=b+f|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(f+4)|0;c[a+(h+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=h+e|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(g+4)|0;c[a+(f+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;g=b+f|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(f+4)|0;c[a+(h+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=h+e|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(g+4)|0;c[a+(f+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;g=b+f|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(f+4)|0;c[a+(h+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=h+e|0;h=b+g|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(g+4)|0;c[a+(f+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=f+e|0;f=b+h|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(h+4)|0;c[a+(g+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=g+e|0;e=b+f|0;c[a+h>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=b+(f+4)|0;c[a+(h+4)>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function K7(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=f;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[i>>2]=(l|j)-((l^j)>>>1&2139062143);j=g+4|0;l=c[j>>2]|0;i=f+4|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[j>>2]=(k|l)-((k^l)>>>1&2139062143);l=h+1|0;if((l|0)<16){f=f+e|0;g=g+e|0;h=l}else{break}}h=b+8|0;b=a+8|0;a=0;while(1){g=b;f=c[g>>2]|0;l=h;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[g>>2]=(k|f)-((k^f)>>>1&2139062143);f=b+4|0;k=c[f>>2]|0;g=h+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[f>>2]=(l|k)-((l^k)>>>1&2139062143);k=a+1|0;if((k|0)<16){h=h+e|0;b=b+e|0;a=k}else{break}}return}function L7(a,b,c){a=a|0;b=b|0;c=c|0;O7(a,b,c,16);O7(a+8|0,b+8|0,c,16);return}function M7(a,b,c){a=a|0;b=b|0;c=c|0;Q7(a,b,c,16);Q7(a+8|0,b+8|0,c,16);return}function N7(a,b,c){a=a|0;b=b|0;c=c|0;O7(a,b,c,8);return}function O7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=e+4-(ca(f+1|0,e)|0)|0;h=4-(ca(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+33686018+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;c[b>>2]=r+o+((a+l|0)>>>2&252645135);p=n+j|0;q=p;s=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+k|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=(s&50529027)+33686018+(t&50529027)|0;u=(t>>>2&1061109567)+(s>>>2&1061109567)|0;c[b+e>>2]=u+r+((q+a|0)>>>2&252645135);a=m+2|0;if((a|0)<(f|0)){l=q;o=u;m=a;n=p;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+33686018+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(p&50529027)+(b&50529027)|0;a=(p>>>2&1061109567)+(b>>>2&1061109567)|0;c[m>>2]=a+n+((h+o|0)>>>2&252645135);b=g+j|0;p=b;u=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+k|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=(u&50529027)+33686018+(q&50529027)|0;r=(q>>>2&1061109567)+(u>>>2&1061109567)|0;c[m+e>>2]=r+a+((p+h|0)>>>2&252645135);h=l+2|0;if((h|0)<(f|0)){o=p;n=r;l=h;g=b;m=m+j|0}else{break}}return}function P7(a,b,c){a=a|0;b=b|0;c=c|0;Q7(a,b,c,8);return}function Q7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=e+4-(ca(f+1|0,e)|0)|0;h=4-(ca(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+33686018+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;p=b;q=c[p>>2]|0;s=r+o+((a+l|0)>>>2&252645135)|0;c[p>>2]=(s|q)-((s^q)>>>1&2139062143);q=n+j|0;s=q;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+k|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=(p&50529027)+33686018+(t&50529027)|0;u=(t>>>2&1061109567)+(p>>>2&1061109567)|0;p=b+e|0;t=c[p>>2]|0;v=u+r+((s+a|0)>>>2&252645135)|0;c[p>>2]=(v|t)-((v^t)>>>1&2139062143);t=m+2|0;if((t|0)<(f|0)){l=s;o=u;m=t;n=q;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+33686018+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(q&50529027)+(b&50529027)|0;t=(q>>>2&1061109567)+(b>>>2&1061109567)|0;b=m;q=c[b>>2]|0;u=t+n+((h+o|0)>>>2&252645135)|0;c[b>>2]=(u|q)-((u^q)>>>1&2139062143);q=g+j|0;u=q;b=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=g+k|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=(b&50529027)+33686018+(s&50529027)|0;v=(s>>>2&1061109567)+(b>>>2&1061109567)|0;b=m+e|0;s=c[b>>2]|0;p=v+t+((u+h|0)>>>2&252645135)|0;c[b>>2]=(p|s)-((p^s)>>>1&2139062143);s=l+2|0;if((s|0)<(f|0)){o=u;n=v;l=s;g=q;m=m+j|0}else{break}}return}function R7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;if((f|0)<=0){return}g=c[b>>2]|0;b=a;a=0;while(1){h=g;c[b>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+4|0;c[b+4>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=a+1|0;if((h|0)<(f|0)){g=g+e|0;b=b+e|0;a=h}else{break}}return}function S7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[b>>2]|0;if((f|0)>0){h=g;i=a;j=0}else{return}while(1){b=h;c[i>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=h+4|0;c[i+4>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=j+1|0;if((b|0)<(f|0)){h=h+e|0;i=i+e|0;j=b}else{break}}j=g+8|0;g=a+8|0;a=0;while(1){i=j;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=j+4|0;c[g+4>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=a+1|0;if((i|0)<(f|0)){j=j+e|0;g=g+e|0;a=i}else{break}}return}function T7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[b>>2]|0;if((f|0)>0){h=g;i=a;j=0}else{return}while(1){b=h;c[i>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=h+4|0;c[i+4>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=j+1|0;if((b|0)<(f|0)){h=h+e|0;i=i+e|0;j=b}else{break}}j=g+8|0;i=a+8|0;h=0;while(1){b=j;c[i>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=j+4|0;c[i+4>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=h+1|0;if((b|0)<(f|0)){j=j+e|0;i=i+e|0;h=b}else{break}}h=g+16|0;i=a+16|0;j=0;while(1){b=h;c[i>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=h+4|0;c[i+4>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;b=j+1|0;if((b|0)<(f|0)){h=h+e|0;i=i+e|0;j=b}else{break}}j=g+24|0;g=a+24|0;a=0;while(1){i=j;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=j+4|0;c[g+4>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;i=a+1|0;if((i|0)<(f|0)){j=j+e|0;g=g+e|0;a=i}else{break}}return}function U7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}do{b=ca(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+b>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+4|0;b=g+k|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+k|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+k>>2]=(j|l)-((j^l)>>>1&2139062143);i=i+1|0;}while((i|0)<(f|0));return}function V7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}while(1){b=ca(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+b>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+4|0;b=g+k|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+k|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+k>>2]=(j|l)-((j^l)>>>1&2139062143);l=i+1|0;if((l|0)<(f|0)){i=l}else{m=0;break}}do{i=ca(m,e)|0;l=i+8|0;j=g+l|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+l|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(b|k)-((b^k)>>>1&2139062143);k=i+12|0;i=g+k|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=h+k|0;l=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+k>>2]=(l|b)-((l^b)>>>1&2139062143);m=m+1|0;}while((m|0)<(f|0));return}function W7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}while(1){b=ca(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+b>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+4|0;b=g+k|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+k|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+k>>2]=(j|l)-((j^l)>>>1&2139062143);l=i+1|0;if((l|0)<(f|0)){i=l}else{m=0;break}}while(1){i=ca(m,e)|0;l=i+8|0;j=g+l|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+l|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(b|k)-((b^k)>>>1&2139062143);k=i+12|0;i=g+k|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=h+k|0;l=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+k>>2]=(l|b)-((l^b)>>>1&2139062143);b=m+1|0;if((b|0)<(f|0)){m=b}else{n=0;break}}while(1){m=ca(n,e)|0;b=m+16|0;l=g+b|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+b|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+b>>2]=(i|k)-((i^k)>>>1&2139062143);k=m+20|0;m=g+k|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+k|0;b=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+k>>2]=(b|i)-((b^i)>>>1&2139062143);i=n+1|0;if((i|0)<(f|0)){n=i}else{o=0;break}}do{n=ca(o,e)|0;i=n+24|0;b=g+i|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+i|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+i>>2]=(m|k)-((m^k)>>>1&2139062143);k=n+28|0;n=g+k|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+k|0;i=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[a+k>>2]=(i|m)-((i^m)>>>1&2139062143);o=o+1|0;}while((o|0)<(f|0));return}function X7(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;R6(a,c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,c[b+12>>2]|0,d,d,d,d,d,e);return}function Y7(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[b>>2]|0;g=c[b+4>>2]|0;h=c[b+8>>2]|0;i=c[b+12>>2]|0;R6(a,f,g,h,i,d,d,d,d,d,e);R6(a+8|0,f+8|0,g+8|0,h+8|0,i+8|0,d,d,d,d,d,e);return}function Z7(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[b>>2]|0;g=b+4|0;h=c[g>>2]|0;i=b+8|0;j=c[i>>2]|0;k=b+12|0;l=c[k>>2]|0;R6(a,f,h,j,l,d,d,d,d,d,e);R6(a+8|0,f+8|0,h+8|0,j+8|0,l+8|0,d,d,d,d,d,e);l=c[b>>2]|0;b=c[g>>2]|0;g=c[i>>2]|0;i=c[k>>2]|0;R6(a+16|0,l+16|0,b+16|0,g+16|0,i+16|0,d,d,d,d,d,e);R6(a+24|0,l+24|0,b+24|0,g+24|0,i+24|0,d,d,d,d,d,e);return}function _7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)<=0){return}g=c[b>>2]|0;b=a;a=0;while(1){h=b;i=c[h>>2]|0;j=g;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[h>>2]=(k|i)-((k^i)>>>1&2139062143);i=b+4|0;k=c[i>>2]|0;h=g+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[i>>2]=(j|k)-((j^k)>>>1&2139062143);k=a+1|0;if((k|0)<(f|0)){g=g+e|0;b=b+e|0;a=k}else{break}}return}function $7(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c[b>>2]|0;if((f|0)>0){h=g;i=a;j=0}else{return}while(1){b=i;k=c[b>>2]|0;l=h;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b>>2]=(m|k)-((m^k)>>>1&2139062143);k=i+4|0;m=c[k>>2]|0;b=h+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<(f|0)){h=h+e|0;i=i+e|0;j=m}else{break}}j=g+8|0;g=a+8|0;a=0;while(1){i=g;h=c[i>>2]|0;m=j;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[i>>2]=(l|h)-((l^h)>>>1&2139062143);h=g+4|0;l=c[h>>2]|0;i=j+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);l=a+1|0;if((l|0)<(f|0)){j=j+e|0;g=g+e|0;a=l}else{break}}return}function a8(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c[b>>2]|0;if((f|0)>0){h=g;i=a;j=0}else{return}while(1){b=i;k=c[b>>2]|0;l=h;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b>>2]=(m|k)-((m^k)>>>1&2139062143);k=i+4|0;m=c[k>>2]|0;b=h+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<(f|0)){h=h+e|0;i=i+e|0;j=m}else{break}}j=g+8|0;i=a+8|0;h=0;while(1){m=i;l=c[m>>2]|0;k=j;b=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[m>>2]=(b|l)-((b^l)>>>1&2139062143);l=i+4|0;b=c[l>>2]|0;m=j+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[l>>2]=(k|b)-((k^b)>>>1&2139062143);b=h+1|0;if((b|0)<(f|0)){j=j+e|0;i=i+e|0;h=b}else{break}}h=g+16|0;i=a+16|0;j=0;while(1){b=i;k=c[b>>2]|0;l=h;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b>>2]=(m|k)-((m^k)>>>1&2139062143);k=i+4|0;m=c[k>>2]|0;b=h+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<(f|0)){h=h+e|0;i=i+e|0;j=m}else{break}}j=g+24|0;g=a+24|0;a=0;while(1){i=g;h=c[i>>2]|0;m=j;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[i>>2]=(l|h)-((l^h)>>>1&2139062143);h=g+4|0;l=c[h>>2]|0;i=j+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);l=a+1|0;if((l|0)<(f|0)){j=j+e|0;g=g+e|0;a=l}else{break}}return}function b8(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}do{b=ca(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+b|0;m=c[j>>2]|0;n=(l|k)-((l^k)>>>1&2139062143)|0;c[j>>2]=(n|m)-((n^m)>>>1&2139062143);m=b+4|0;b=g+m|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+m|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+m|0;m=c[b>>2]|0;k=(j|n)-((j^n)>>>1&2139062143)|0;c[b>>2]=(k|m)-((k^m)>>>1&2139062143);i=i+1|0;}while((i|0)<(f|0));return}function c8(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b>>2]|0;h=c[b+4>>2]|0;if((f|0)>0){i=0}else{return}while(1){b=ca(i,e)|0;j=g+b|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+b|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+b|0;m=c[j>>2]|0;n=(l|k)-((l^k)>>>1&2139062143)|0;c[j>>2]=(n|m)-((n^m)>>>1&2139062143);m=b+4|0;b=g+m|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+m|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+m|0;m=c[b>>2]|0;k=(j|n)-((j^n)>>>1&2139062143)|0;c[b>>2]=(k|m)-((k^m)>>>1&2139062143);m=i+1|0;if((m|0)<(f|0)){i=m}else{o=0;break}}do{i=ca(o,e)|0;m=i+8|0;k=g+m|0;b=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+m|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+m|0;m=c[k>>2]|0;j=(n|b)-((n^b)>>>1&2139062143)|0;c[k>>2]=(j|m)-((j^m)>>>1&2139062143);m=i+12|0;i=g+m|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=h+m|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+m|0;m=c[i>>2]|0;b=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(b|m)-((b^m)>>>1&2139062143);o=o+1|0;}while((o|0)<(f|0));return}function d8(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=(f|0)>0;if(b){i=0}else{return}while(1){j=ca(i,e)|0;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+j|0;n=c[k>>2]|0;o=(m|l)-((m^l)>>>1&2139062143)|0;c[k>>2]=(o|n)-((o^n)>>>1&2139062143);n=j+4|0;j=g+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+n|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+n|0;n=c[j>>2]|0;l=(k|o)-((k^o)>>>1&2139062143)|0;c[j>>2]=(l|n)-((l^n)>>>1&2139062143);n=i+1|0;if((n|0)<(f|0)){i=n}else{p=0;break}}while(1){i=ca(p,e)|0;n=i+8|0;l=g+n|0;j=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+n|0;n=c[l>>2]|0;k=(o|j)-((o^j)>>>1&2139062143)|0;c[l>>2]=(k|n)-((k^n)>>>1&2139062143);n=i+12|0;i=g+n|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=h+n|0;l=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+n|0;n=c[i>>2]|0;j=(l|k)-((l^k)>>>1&2139062143)|0;c[i>>2]=(j|n)-((j^n)>>>1&2139062143);n=p+1|0;if((n|0)<(f|0)){p=n}else{q=0;break}}do{p=ca(q,e)|0;n=p+16|0;j=g+n|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+n|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+n|0;n=c[j>>2]|0;l=(k|i)-((k^i)>>>1&2139062143)|0;c[j>>2]=(l|n)-((l^n)>>>1&2139062143);n=p+20|0;p=g+n|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+n|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+n|0;n=c[p>>2]|0;i=(j|l)-((j^l)>>>1&2139062143)|0;c[p>>2]=(i|n)-((i^n)>>>1&2139062143);q=q+1|0;}while((q|0)<(f|0));if(b){r=0}else{return}do{b=ca(r,e)|0;q=b+24|0;n=g+q|0;i=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+q|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+q|0;q=c[n>>2]|0;l=(p|i)-((p^i)>>>1&2139062143)|0;c[n>>2]=(l|q)-((l^q)>>>1&2139062143);q=b+28|0;b=g+q|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+q|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+q|0;q=c[b>>2]|0;i=(n|l)-((n^l)>>>1&2139062143)|0;c[b>>2]=(i|q)-((i^q)>>>1&2139062143);r=r+1|0;}while((r|0)<(f|0));return}function e8(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;v7(a,c[b>>2]|0,c[b+4>>2]|0,c[b+8>>2]|0,c[b+12>>2]|0,d,d,d,d,d,e);return}function f8(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[b>>2]|0;g=c[b+4>>2]|0;h=c[b+8>>2]|0;i=c[b+12>>2]|0;v7(a,f,g,h,i,d,d,d,d,d,e);v7(a+8|0,f+8|0,g+8|0,h+8|0,i+8|0,d,d,d,d,d,e);return}function g8(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[b>>2]|0;g=b+4|0;h=c[g>>2]|0;i=b+8|0;j=c[i>>2]|0;k=b+12|0;l=c[k>>2]|0;v7(a,f,h,j,l,d,d,d,d,d,e);v7(a+8|0,f+8|0,h+8|0,j+8|0,l+8|0,d,d,d,d,d,e);l=c[b>>2]|0;b=c[g>>2]|0;g=c[i>>2]|0;i=c[k>>2]|0;v7(a+16|0,l+16|0,b+16|0,g+16|0,i+16|0,d,d,d,d,d,e);v7(a+24|0,l+24|0,b+24|0,g+24|0,i+24|0,d,d,d,d,d,e);return}function h8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;mrc(b|0,0,24)|0;f=d&255;d=0;do{switch(f|0){case 9:{c[b+(d<<2)>>2]=c[a+244+(d<<2)>>2];break};case 3:{c[b+(d<<2)>>2]=c[a+124+(d<<2)>>2];break};case 14:{c[b+(d<<2)>>2]=c[a+364+(d<<2)>>2];break};case 8:{c[b+(d<<2)>>2]=c[a+220+(d<<2)>>2];break};case 7:{c[b+(d<<2)>>2]=116;break};case 12:{c[b+(d<<2)>>2]=c[a+316+(d<<2)>>2];break};case 2:{c[b+(d<<2)>>2]=c[a+100+(d<<2)>>2];break};case 11:{c[b+(d<<2)>>2]=c[a+292+(d<<2)>>2];break};case 1:{c[b+(d<<2)>>2]=c[a+76+(d<<2)>>2];break};case 6:{c[b+(d<<2)>>2]=c[a+196+(d<<2)>>2];break};case 10:{c[b+(d<<2)>>2]=c[a+268+(d<<2)>>2];break};case 4:{c[b+(d<<2)>>2]=c[a+148+(d<<2)>>2];break};case 5:{c[b+(d<<2)>>2]=c[a+172+(d<<2)>>2];break};case 13:{c[b+(d<<2)>>2]=c[a+340+(d<<2)>>2];break};case 0:{c[b+(d<<2)>>2]=c[a+52+(d<<2)>>2];break};default:{KIb(0,16,2608280,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}}d=d+1|0;}while((d|0)<6);i=e;return}function i8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function j8(){var a=0,b=0;a=0;do{b=a-256|0;c[6219288+(a<<2)>>2]=ca(b,b)|0;a=a+1|0;}while((a|0)<512);return}function k8(){return 0}function l8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+796|0;e=c[d>>2]|0;do{if((e|0)==10){c[a+1108>>2]=102;c[a+1112>>2]=94}else{f=c[b+784>>2]|0;if((f|0)==1){c[a+1108>>2]=8;c[a+1112>>2]=372;break}g=a+1108|0;if((f|0)==6){c[g>>2]=350;c[a+1112>>2]=502;break}else{c[g>>2]=128;c[a+1112>>2]=566;break}}}while(0);g=c[b+800>>2]|0;do{if((g|0)==3){c[a+1120>>2]=270;c[a+1124>>2]=874;c[a+1116>>2]=190;c[a+1192>>2]=1}else if((g|0)==2){c[a+1120>>2]=2396;c[a+1124>>2]=1640;c[a+1116>>2]=192;c[a+1192>>2]=1}else if((g|0)==1){c[a+1120>>2]=726;c[a+1124>>2]=116;c[a+1116>>2]=188;c[a+1192>>2]=1}else{if((e|0)==10){c[a+1120>>2]=222;c[a+1124>>2]=106;c[a+1116>>2]=58;c[a+1192>>2]=1;break}else if((e|0)==12){c[a+1120>>2]=220;c[a+1124>>2]=2044;c[a+1116>>2]=60;c[a+1192>>2]=1;break}else{f=c[b+788>>2]|0;if((f|0)==1){c[a+1120>>2]=1032;c[a+1124>>2]=2020;c[a+1116>>2]=536;c[a+1192>>2]=2;break}h=a+1120|0;if((f|0)==20){c[h>>2]=1104;c[a+1124>>2]=830;c[a+1116>>2]=276;c[a+1192>>2]=1;break}else{c[h>>2]=2194;c[a+1124>>2]=240;c[a+1116>>2]=386;c[a+1192>>2]=1;break}}}}while(0);c[a+4>>2]=748;c[a+8>>2]=1938;c[a+12>>2]=1164;c[a+16>>2]=1122;c[a+24>>2]=1304;c[a+28>>2]=480;c[a+32>>2]=2;c[a+44>>2]=560;c[a+48>>2]=1002;c[a+1236>>2]=152;c[a+1240>>2]=904;c[a+1040>>2]=164;c[a+1044>>2]=238;c[a+1048>>2]=300;c[a+1052>>2]=82;c[a+1056>>2]=272;c[a+1060>>2]=198;c[a+1064>>2]=284;c[a+1068>>2]=84;c[a+536>>2]=594;c[a+540>>2]=22;c[a+544>>2]=374;c[a+552>>2]=302;c[a+556>>2]=640;c[a+560>>2]=538;c[a+568>>2]=50;c[a+572>>2]=476;c[a+576>>2]=616;c[a+580>>2]=212;c[a+584>>2]=86;c[a+588>>2]=182;c[a+596>>2]=508;c[a+600>>2]=172;c[a+604>>2]=272;c[a+612>>2]=412;c[a+616>>2]=600;c[a+620>>2]=458;c[a+624>>2]=962;c[a+628>>2]=1046;c[a+632>>2]=90;c[a+636>>2]=1878;c[a+640>>2]=1454;c[a+644>>2]=190;c[a+648>>2]=408;c[a+652>>2]=2402;c[a+656>>2]=1782;c[a+660>>2]=1112;c[a+664>>2]=690;c[a+668>>2]=1264;c[a+672>>2]=328;c[a+676>>2]=776;c[a+680>>2]=1026;c[a+684>>2]=942;c[a+880>>2]=962;c[a+884>>2]=730;c[a+888>>2]=210;c[a+892>>2]=2408;c[a+896>>2]=2168;c[a+900>>2]=1446;c[a+904>>2]=1434;c[a+908>>2]=324;c[a+912>>2]=1852;c[a+916>>2]=650;c[a+920>>2]=2324;c[a+924>>2]=576;c[a+928>>2]=356;c[a+932>>2]=428;c[a+936>>2]=500;c[a+940>>2]=918;c[a+752>>2]=532;c[a+756>>2]=540;c[a+760>>2]=18;c[a+764>>2]=998;c[a+768>>2]=1074;c[a+772>>2]=2372;c[a+776>>2]=960;c[a+780>>2]=1344;c[a+784>>2]=2014;c[a+788>>2]=276;c[a+792>>2]=1864;c[a+796>>2]=1598;c[a+800>>2]=236;c[a+804>>2]=1752;c[a+808>>2]=370;c[a+812>>2]=1936;c[a+688>>2]=1828;c[a+692>>2]=1824;c[a+696>>2]=34;c[a+700>>2]=1934;c[a+704>>2]=2034;c[a+708>>2]=902;c[a+712>>2]=972;c[a+716>>2]=2266;c[a+720>>2]=806;c[a+724>>2]=6;c[a+728>>2]=636;c[a+732>>2]=1342;c[a+736>>2]=1738;c[a+740>>2]=1480;c[a+744>>2]=1586;c[a+748>>2]=1672;c[a+944>>2]=1828;c[a+948>>2]=584;c[a+952>>2]=1438;c[a+956>>2]=1986;c[a+960>>2]=1548;c[a+964>>2]=272;c[a+968>>2]=474;c[a+972>>2]=1624;c[a+976>>2]=1884;c[a+980>>2]=1202;c[a+984>>2]=1712;c[a+988>>2]=892;c[a+992>>2]=946;c[a+996>>2]=866;c[a+1e3>>2]=1116;c[a+1004>>2]=1034;c[a+816>>2]=1912;c[a+820>>2]=1332;c[a+824>>2]=68;c[a+828>>2]=286;c[a+832>>2]=1136;c[a+836>>2]=2278;c[a+840>>2]=2430;c[a+844>>2]=1526;c[a+848>>2]=232;c[a+852>>2]=1952;c[a+856>>2]=672;c[a+860>>2]=2086;c[a+864>>2]=526;c[a+868>>2]=430;c[a+872>>2]=1004;c[a+876>>2]=1230;c[a+1008>>2]=1828;c[a+1012>>2]=1990;c[a+1016>>2]=1574;c[a+1020>>2]=928;c[a+1024>>2]=836;c[a+1028>>2]=182;c[a+1032>>2]=2176;c[a+1036>>2]=1914;c[a+100>>2]=288;c[a+104>>2]=56;c[a+116>>2]=80;c[a+120>>2]=244;c[a+124>>2]=146;c[a+128>>2]=86;c[a+340>>2]=302;c[a+344>>2]=22;c[a+364>>2]=220;c[a+368>>2]=10;c[a+52>>2]=164;c[a+56>>2]=272;c[a+76>>2]=160;c[a+80>>2]=156;c[a+84>>2]=124;c[a+148>>2]=186;c[a+152>>2]=14;c[a+196>>2]=172;c[a+200>>2]=126;c[a+172>>2]=276;c[a+176>>2]=46;c[a+220>>2]=42;c[a+236>>2]=222;c[a+240>>2]=122;c[a+244>>2]=112;c[a+260>>2]=304;c[a+264>>2]=110;c[a+268>>2]=166;c[a+272>>2]=6;n1a(a);c[a+532>>2]=280;c[a+1072>>2]=770;c[a+1076>>2]=132;c[a+1084>>2]=160;c[a+1080>>2]=328;c[a+1088>>2]=436;c[a+1092>>2]=580;c[a+1096>>2]=804;c[a+1100>>2]=514;c[a+1196>>2]=334;c[a+1200>>2]=170;c[a+1104>>2]=2;c[a+1224>>2]=118;c[a+1228>>2]=32;c[a+1232>>2]=150;c[a+1208>>2]=68;c[a+1212>>2]=336;c[a+1216>>2]=112;c[a+1220>>2]=240;c[a+20>>2]=1102;c[a+1204>>2]=556;c[a+36>>2]=522;c[a+40>>2]=408;e=c[d>>2]|0;if((e|0)==9|(e|0)==10|(e|0)==12|(e|0)==14){c[a>>2]=1744;i=a+1128|0;j=a+1192|0;k=c[j>>2]|0;M6(i,k);return}do{if((e|0)>=9){if((c[b+8>>2]|0)!=0){break}i=a+1128|0;j=a+1192|0;k=c[j>>2]|0;M6(i,k);return}}while(0);c[a>>2]=912;i=a+1128|0;j=a+1192|0;k=c[j>>2]|0;M6(i,k);return}function m8(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;pOa(e);f=c;c=e;e=0;while(1){g=b[c>>1]|0;if((g&65535)>>>0>255>>>0){h=-(g<<16>>16)>>31&255}else{h=g&255}a[f]=h;g=b[c+2>>1]|0;if((g&65535)>>>0>255>>>0){i=-(g<<16>>16)>>31&255}else{i=g&255}a[f+1|0]=i;g=b[c+4>>1]|0;if((g&65535)>>>0>255>>>0){j=-(g<<16>>16)>>31&255}else{j=g&255}a[f+2|0]=j;g=b[c+6>>1]|0;if((g&65535)>>>0>255>>>0){k=-(g<<16>>16)>>31&255}else{k=g&255}a[f+3|0]=k;g=e+1|0;if((g|0)<4){f=f+d|0;c=c+16|0;e=g}else{break}}return}function n8(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;pOa(f);g=c;c=f;f=0;while(1){h=(b[c>>1]|0)+(d[g]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[g]=i;h=g+1|0;j=(b[c+2>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=g+2|0;j=(b[c+4>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=g+3|0;j=(b[c+6>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=f+1|0;if((h|0)<4){g=g+e|0;c=c+16|0;f=h}else{break}}return}function o8(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;qOa(e);f=b[e>>1]|0;if((f&65535)>>>0>255>>>0){g=-(f<<16>>16)>>31&255}else{g=f&255}a[c]=g;g=b[e+2>>1]|0;if((g&65535)>>>0>255>>>0){h=-(g<<16>>16)>>31&255}else{h=g&255}a[c+1|0]=h;h=b[e+16>>1]|0;if((h&65535)>>>0>255>>>0){i=-(h<<16>>16)>>31&255}else{i=h&255}a[c+d|0]=i;i=b[e+18>>1]|0;if(!((i&65535)>>>0>255>>>0)){j=i&255;k=d+1|0;l=c+k|0;a[l]=j;return}j=-(i<<16>>16)>>31&255;k=d+1|0;l=c+k|0;a[l]=j;return}function p8(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;qOa(f);g=(b[f>>1]|0)+(d[c]|0)|0;if(g>>>0>255>>>0){h=-g>>31&255}else{h=g&255}a[c]=h;h=c+1|0;g=(b[f+2>>1]|0)+(d[h]|0)|0;if(g>>>0>255>>>0){i=-g>>31&255}else{i=g&255}a[h]=i;i=c+e|0;h=(b[f+16>>1]|0)+(d[i]|0)|0;if(h>>>0>255>>>0){j=-h>>31&255}else{j=h&255}a[i]=j;j=c+(e+1)|0;e=(b[f+18>>1]|0)+(d[j]|0)|0;if(!(e>>>0>255>>>0)){k=e&255;a[j]=k;return}k=-e>>31&255;a[j]=k;return}function q8(c,d,e){c=c|0;d=d|0;e=e|0;var f=0;d=(b[e>>1]|0)+4>>3;if(!(d>>>0>255>>>0)){f=d&255;a[c]=f;return}f=-d>>31&255;a[c]=f;return}function r8(c,e,f){c=c|0;e=e|0;f=f|0;var g=0;e=((b[f>>1]|0)+4>>3)+(d[c]|0)|0;if(!(e>>>0>255>>>0)){g=e&255;a[c]=g;return}g=-e>>31&255;a[c]=g;return}function s8(a,b,c){a=a|0;b=b|0;c=c|0;oOa(c);v8(c,a,b);return}function t8(a,b,c){a=a|0;b=b|0;c=c|0;oOa(c);x8(c,a,b);return}function u8(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0;g=c;c=e;e=a;a=0;while(1){b[e>>1]=(d[g]|0)-(d[c]|0);b[e+2>>1]=(d[g+1|0]|0)-(d[c+1|0]|0);b[e+4>>1]=(d[g+2|0]|0)-(d[c+2|0]|0);b[e+6>>1]=(d[g+3|0]|0)-(d[c+3|0]|0);b[e+8>>1]=(d[g+4|0]|0)-(d[c+4|0]|0);b[e+10>>1]=(d[g+5|0]|0)-(d[c+5|0]|0);b[e+12>>1]=(d[g+6|0]|0)-(d[c+6|0]|0);b[e+14>>1]=(d[g+7|0]|0)-(d[c+7|0]|0);h=a+1|0;if((h|0)<8){g=g+f|0;c=c+f|0;e=e+16|0;a=h}else{break}}return}function v8(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=d;d=c;c=0;while(1){g=b[d>>1]|0;if((g&65535)>>>0>255>>>0){h=-(g<<16>>16)>>31&255}else{h=g&255}a[f]=h;g=b[d+2>>1]|0;if((g&65535)>>>0>255>>>0){i=-(g<<16>>16)>>31&255}else{i=g&255}a[f+1|0]=i;g=b[d+4>>1]|0;if((g&65535)>>>0>255>>>0){j=-(g<<16>>16)>>31&255}else{j=g&255}a[f+2|0]=j;g=b[d+6>>1]|0;if((g&65535)>>>0>255>>>0){k=-(g<<16>>16)>>31&255}else{k=g&255}a[f+3|0]=k;g=b[d+8>>1]|0;if((g&65535)>>>0>255>>>0){l=-(g<<16>>16)>>31&255}else{l=g&255}a[f+4|0]=l;g=b[d+10>>1]|0;if((g&65535)>>>0>255>>>0){m=-(g<<16>>16)>>31&255}else{m=g&255}a[f+5|0]=m;g=b[d+12>>1]|0;if((g&65535)>>>0>255>>>0){n=-(g<<16>>16)>>31&255}else{n=g&255}a[f+6|0]=n;g=b[d+14>>1]|0;if((g&65535)>>>0>255>>>0){o=-(g<<16>>16)>>31&255}else{o=g&255}a[f+7|0]=o;g=c+1|0;if((g|0)<8){f=f+e|0;d=d+16|0;c=g}else{break}}return}function w8(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d;d=c;c=0;while(1){g=d+16|0;h=b[d>>1]|0;i=h&255;do{if(h<<16>>16<-128){a[f]=0}else{if(h<<16>>16>127){a[f]=-1;break}else{a[f]=i^-128;break}}}while(0);i=f+1|0;h=b[d+2>>1]|0;j=h&255;do{if(h<<16>>16<-128){a[i]=0}else{if(h<<16>>16>127){a[i]=-1;break}else{a[i]=j^-128;break}}}while(0);j=f+2|0;i=b[d+4>>1]|0;h=i&255;do{if(i<<16>>16<-128){a[j]=0}else{if(i<<16>>16>127){a[j]=-1;break}else{a[j]=h^-128;break}}}while(0);h=f+3|0;j=b[d+6>>1]|0;i=j&255;do{if(j<<16>>16<-128){a[h]=0}else{if(j<<16>>16>127){a[h]=-1;break}else{a[h]=i^-128;break}}}while(0);i=f+4|0;h=b[d+8>>1]|0;j=h&255;do{if(h<<16>>16<-128){a[i]=0}else{if(h<<16>>16>127){a[i]=-1;break}else{a[i]=j^-128;break}}}while(0);j=f+5|0;i=b[d+10>>1]|0;h=i&255;do{if(i<<16>>16<-128){a[j]=0}else{if(i<<16>>16>127){a[j]=-1;break}else{a[j]=h^-128;break}}}while(0);h=f+6|0;j=b[d+12>>1]|0;i=j&255;do{if(j<<16>>16<-128){a[h]=0}else{if(j<<16>>16>127){a[h]=-1;break}else{a[h]=i^-128;break}}}while(0);i=f+7|0;h=b[d+14>>1]|0;j=h&255;do{if(h<<16>>16<-128){a[i]=0}else{if(h<<16>>16>127){a[i]=-1;break}else{a[i]=j^-128;break}}}while(0);j=c+1|0;if((j|0)<8){f=f+e|0;d=g;c=j}else{break}}return}function x8(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=e;e=c;c=0;while(1){h=(b[e>>1]|0)+(d[g]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[g]=i;h=g+1|0;j=(b[e+2>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=g+2|0;j=(b[e+4>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=g+3|0;j=(b[e+6>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=g+4|0;j=(b[e+8>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[h]=n;h=g+5|0;j=(b[e+10>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[h]=o;h=g+6|0;j=(b[e+12>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;h=g+7|0;j=(b[e+14>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[h]=q;h=c+1|0;if((h|0)<8){g=g+f|0;e=e+16|0;c=h}else{break}}return}function y8(a){a=a|0;var c=0,d=0,e=0,f=0;c=0;d=0;do{e=b[a+(d<<1)>>1]|0;f=e<<16>>16;c=(e<<16>>16>-1?f:-f|0)+c|0;d=d+1|0;}while((d|0)<64);return c|0}function z8(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=16-g|0;k=16-h|0;l=ca(k,j)|0;m=ca(k,g)|0;k=ca(j,h)|0;j=ca(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;n=e+3|0;o=e+4|0;p=e+5|0;q=e+6|0;r=e+7|0;s=e+8|0;t=c;c=b;b=0;while(1){u=ca(d[t]|0,l)|0;v=t+1|0;w=ca(d[v]|0,m)|0;x=t+e|0;y=ca(d[x]|0,k)|0;z=t+g|0;a[c]=(u+i+w+y+(ca(d[z]|0,j)|0)|0)>>>8;y=ca(d[v]|0,l)|0;v=t+2|0;w=ca(d[v]|0,m)|0;u=ca(d[z]|0,k)|0;z=t+h|0;a[c+1|0]=(y+i+w+u+(ca(d[z]|0,j)|0)|0)>>>8;u=ca(d[v]|0,l)|0;v=t+3|0;w=ca(d[v]|0,m)|0;y=ca(d[z]|0,k)|0;z=t+n|0;a[c+2|0]=(u+i+w+y+(ca(d[z]|0,j)|0)|0)>>>8;y=ca(d[v]|0,l)|0;v=t+4|0;w=ca(d[v]|0,m)|0;u=ca(d[z]|0,k)|0;z=t+o|0;a[c+3|0]=(y+i+w+u+(ca(d[z]|0,j)|0)|0)>>>8;u=ca(d[v]|0,l)|0;v=t+5|0;w=ca(d[v]|0,m)|0;y=ca(d[z]|0,k)|0;z=t+p|0;a[c+4|0]=(u+i+w+y+(ca(d[z]|0,j)|0)|0)>>>8;y=ca(d[v]|0,l)|0;v=t+6|0;w=ca(d[v]|0,m)|0;u=ca(d[z]|0,k)|0;z=t+q|0;a[c+5|0]=(y+i+w+u+(ca(d[z]|0,j)|0)|0)>>>8;u=ca(d[v]|0,l)|0;v=t+7|0;w=ca(d[v]|0,m)|0;y=ca(d[z]|0,k)|0;z=t+r|0;a[c+6|0]=(u+i+w+y+(ca(d[z]|0,j)|0)|0)>>>8;y=ca(d[v]|0,l)|0;v=ca(d[t+8|0]|0,m)|0;w=ca(d[z]|0,k)|0;a[c+7|0]=(y+i+v+w+(ca(d[t+s|0]|0,j)|0)|0)>>>8;w=b+1|0;if((w|0)<(f|0)){t=x;c=c+e|0;b=w}else{break}}return}function A8(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0;c=a;a=0;e=0;while(1){f=(d[c+8|0]|0)+((d[c]|0)+a+(d[c+1|0]|0)+(d[c+2|0]|0)+(d[c+3|0]|0)+(d[c+4|0]|0)+(d[c+5|0]|0)+(d[c+6|0]|0)+(d[c+7|0]|0))+(d[c+9|0]|0)+(d[c+10|0]|0)+(d[c+11|0]|0)+(d[c+12|0]|0)+(d[c+13|0]|0)+(d[c+14|0]|0)+(d[c+15|0]|0)|0;g=e+1|0;if((g|0)<16){c=c+b|0;a=f;e=g}else{break}}return f|0}function B8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=0;e=0;f=a;while(1){a=c[f>>2]|0;g=c[f+4>>2]|0;h=c[f+8>>2]|0;i=c[f+12>>2]|0;j=(c[6219288+((h&255|256)<<2)>>2]|0)+((c[6219288+((a&255|256)<<2)>>2]|0)+e+(c[6219288+((a>>>8&255|256)<<2)>>2]|0)+(c[6219288+((a>>>16&255|256)<<2)>>2]|0)+(c[6219288+((a>>>24|256)<<2)>>2]|0)+(c[6219288+((g&255|256)<<2)>>2]|0)+(c[6219288+((g>>>8&255|256)<<2)>>2]|0)+(c[6219288+((g>>>16&255|256)<<2)>>2]|0)+(c[6219288+((g>>>24|256)<<2)>>2]|0))+(c[6219288+((h>>>8&255|256)<<2)>>2]|0)+(c[6219288+((h>>>16&255|256)<<2)>>2]|0)+(c[6219288+((h>>>24|256)<<2)>>2]|0)+(c[6219288+((i&255|256)<<2)>>2]|0)+(c[6219288+((i>>>8&255|256)<<2)>>2]|0)+(c[6219288+((i>>>16&255|256)<<2)>>2]|0)+(c[6219288+((i>>>24|256)<<2)>>2]|0)|0;i=d+1|0;if((i|0)<16){d=i;e=j;f=f+b|0}else{break}}return j|0}function C8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((d|0)>0){e=a;f=0}else{return}while(1){mrc(e|0,b|0,16)|0;a=f+1|0;if((a|0)<(d|0)){e=e+c|0;f=a}else{break}}return}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((d|0)>0){e=a;f=0}else{return}while(1){mrc(e|0,b|0,8)|0;a=f+1|0;if((a|0)<(d|0)){e=e+c|0;f=a}else{break}}return}function E8(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((f|0)>0){g=c;h=b;i=0;j=0}else{k=0;return k|0}while(1){b=(d[h]|0)-(d[g]|0)|0;c=(d[h+1|0]|0)-(d[g+1|0]|0)|0;a=(d[h+2|0]|0)-(d[g+2|0]|0)|0;l=(d[h+3|0]|0)-(d[g+3|0]|0)|0;m=(d[h+4|0]|0)-(d[g+4|0]|0)|0;n=(d[h+5|0]|0)-(d[g+5|0]|0)|0;o=(d[h+6|0]|0)-(d[g+6|0]|0)|0;p=(d[h+7|0]|0)-(d[g+7|0]|0)|0;q=(d[h+8|0]|0)-(d[g+8|0]|0)|0;r=(d[h+9|0]|0)-(d[g+9|0]|0)|0;s=(d[h+10|0]|0)-(d[g+10|0]|0)|0;t=(d[h+11|0]|0)-(d[g+11|0]|0)|0;u=(d[h+12|0]|0)-(d[g+12|0]|0)|0;v=(d[h+13|0]|0)-(d[g+13|0]|0)|0;w=(d[h+14|0]|0)-(d[g+14|0]|0)|0;x=(d[h+15|0]|0)-(d[g+15|0]|0)|0;y=((b|0)>-1?b:-b|0)+i+((c|0)>-1?c:-c|0)+((a|0)>-1?a:-a|0)+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)+((q|0)>-1?q:-q|0)+((r|0)>-1?r:-r|0)+((s|0)>-1?s:-s|0)+((t|0)>-1?t:-t|0)+((u|0)>-1?u:-u|0)+((v|0)>-1?v:-v|0)+((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)|0;x=j+1|0;if((x|0)<(f|0)){g=g+e|0;h=h+e|0;i=y;j=x}else{k=y;break}}return k|0}function F8(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((f|0)>0){g=c;h=b;i=0;j=0}else{k=0;return k|0}while(1){b=d[g+1|0]|0;c=(d[h]|0)-(((d[g]|0)+1+b|0)>>>1)|0;a=d[g+2|0]|0;l=(d[h+1|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+3|0]|0;m=(d[h+2|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+4|0]|0;n=(d[h+3|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+5|0]|0;o=(d[h+4|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+6|0]|0;p=(d[h+5|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+7|0]|0;q=(d[h+6|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+8|0]|0;r=(d[h+7|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+9|0]|0;s=(d[h+8|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+10|0]|0;t=(d[h+9|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+11|0]|0;u=(d[h+10|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+12|0]|0;v=(d[h+11|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+13|0]|0;w=(d[h+12|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+14|0]|0;x=(d[h+13|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+15|0]|0;y=(d[h+14|0]|0)-((a+1+b|0)>>>1)|0;a=(d[h+15|0]|0)-((b+1+(d[g+16|0]|0)|0)>>>1)|0;b=((c|0)>-1?c:-c|0)+i+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)+((q|0)>-1?q:-q|0)+((r|0)>-1?r:-r|0)+((s|0)>-1?s:-s|0)+((t|0)>-1?t:-t|0)+((u|0)>-1?u:-u|0)+((v|0)>-1?v:-v|0)+((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)+((y|0)>-1?y:-y|0)+((a|0)>-1?a:-a|0)|0;a=j+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=b;j=a}else{k=b;break}}return k|0}function G8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;if((g|0)<=0){h=0;return h|0}b=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=f+9|0;q=f+10|0;r=f+11|0;s=f+12|0;t=f+13|0;u=f+14|0;v=f+15|0;w=c;c=0;x=0;y=e;z=a[e]|0;while(1){e=y+f|0;A=a[e]|0;B=(d[w]|0)-(((z&255)+1+(A&255)|0)>>>1)|0;C=(d[w+1|0]|0)-(((d[y+1|0]|0)+1+(d[y+b|0]|0)|0)>>>1)|0;D=(d[w+2|0]|0)-(((d[y+2|0]|0)+1+(d[y+i|0]|0)|0)>>>1)|0;E=(d[w+3|0]|0)-(((d[y+3|0]|0)+1+(d[y+j|0]|0)|0)>>>1)|0;F=(d[w+4|0]|0)-(((d[y+4|0]|0)+1+(d[y+k|0]|0)|0)>>>1)|0;G=(d[w+5|0]|0)-(((d[y+5|0]|0)+1+(d[y+l|0]|0)|0)>>>1)|0;H=(d[w+6|0]|0)-(((d[y+6|0]|0)+1+(d[y+m|0]|0)|0)>>>1)|0;I=(d[w+7|0]|0)-(((d[y+7|0]|0)+1+(d[y+n|0]|0)|0)>>>1)|0;J=(d[w+8|0]|0)-(((d[y+8|0]|0)+1+(d[y+o|0]|0)|0)>>>1)|0;K=(d[w+9|0]|0)-(((d[y+9|0]|0)+1+(d[y+p|0]|0)|0)>>>1)|0;L=(d[w+10|0]|0)-(((d[y+10|0]|0)+1+(d[y+q|0]|0)|0)>>>1)|0;M=(d[w+11|0]|0)-(((d[y+11|0]|0)+1+(d[y+r|0]|0)|0)>>>1)|0;N=(d[w+12|0]|0)-(((d[y+12|0]|0)+1+(d[y+s|0]|0)|0)>>>1)|0;O=(d[w+13|0]|0)-(((d[y+13|0]|0)+1+(d[y+t|0]|0)|0)>>>1)|0;P=(d[w+14|0]|0)-(((d[y+14|0]|0)+1+(d[y+u|0]|0)|0)>>>1)|0;Q=(d[w+15|0]|0)-(((d[y+15|0]|0)+1+(d[y+v|0]|0)|0)>>>1)|0;R=((B|0)>-1?B:-B|0)+c+((C|0)>-1?C:-C|0)+((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)+((F|0)>-1?F:-F|0)+((G|0)>-1?G:-G|0)+((H|0)>-1?H:-H|0)+((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)+((K|0)>-1?K:-K|0)+((L|0)>-1?L:-L|0)+((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)+((O|0)>-1?O:-O|0)+((P|0)>-1?P:-P|0)+((Q|0)>-1?Q:-Q|0)|0;Q=x+1|0;if((Q|0)<(g|0)){w=w+f|0;c=R;x=Q;y=e;z=A}else{h=R;break}}return h|0}function H8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;if((g|0)<=0){h=0;return h|0}b=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=f+9|0;q=f+10|0;r=f+11|0;s=f+12|0;t=f+13|0;u=f+14|0;v=f+15|0;w=f+16|0;x=c;c=0;y=0;z=e;A=a[e]|0;while(1){e=z+f|0;B=d[z+1|0]|0;C=a[e]|0;D=d[z+b|0]|0;E=(d[x]|0)-(((A&255)+2+B+(C&255)+D|0)>>>2)|0;F=d[z+2|0]|0;G=d[z+i|0]|0;H=(d[x+1|0]|0)-((B+2+F+D+G|0)>>>2)|0;D=d[z+3|0]|0;B=d[z+j|0]|0;I=(d[x+2|0]|0)-((F+2+D+G+B|0)>>>2)|0;G=d[z+4|0]|0;F=d[z+k|0]|0;J=(d[x+3|0]|0)-((D+2+G+B+F|0)>>>2)|0;B=d[z+5|0]|0;D=d[z+l|0]|0;K=(d[x+4|0]|0)-((G+2+B+F+D|0)>>>2)|0;F=d[z+6|0]|0;G=d[z+m|0]|0;L=(d[x+5|0]|0)-((B+2+F+D+G|0)>>>2)|0;D=d[z+7|0]|0;B=d[z+n|0]|0;M=(d[x+6|0]|0)-((F+2+D+G+B|0)>>>2)|0;G=d[z+8|0]|0;F=d[z+o|0]|0;N=(d[x+7|0]|0)-((D+2+G+B+F|0)>>>2)|0;B=d[z+9|0]|0;D=d[z+p|0]|0;O=(d[x+8|0]|0)-((G+2+B+F+D|0)>>>2)|0;F=d[z+10|0]|0;G=d[z+q|0]|0;P=(d[x+9|0]|0)-((B+2+F+D+G|0)>>>2)|0;D=d[z+11|0]|0;B=d[z+r|0]|0;Q=(d[x+10|0]|0)-((F+2+D+G+B|0)>>>2)|0;G=d[z+12|0]|0;F=d[z+s|0]|0;R=(d[x+11|0]|0)-((D+2+G+B+F|0)>>>2)|0;B=d[z+13|0]|0;D=d[z+t|0]|0;S=(d[x+12|0]|0)-((G+2+B+F+D|0)>>>2)|0;F=d[z+14|0]|0;G=d[z+u|0]|0;T=(d[x+13|0]|0)-((B+2+F+D+G|0)>>>2)|0;D=d[z+15|0]|0;B=d[z+v|0]|0;U=(d[x+14|0]|0)-((F+2+D+G+B|0)>>>2)|0;G=(d[x+15|0]|0)-((D+2+(d[z+16|0]|0)+B+(d[z+w|0]|0)|0)>>>2)|0;B=((E|0)>-1?E:-E|0)+c+((H|0)>-1?H:-H|0)+((I|0)>-1?I:-I|0)+((J|0)>-1?J:-J|0)+((K|0)>-1?K:-K|0)+((L|0)>-1?L:-L|0)+((M|0)>-1?M:-M|0)+((N|0)>-1?N:-N|0)+((O|0)>-1?O:-O|0)+((P|0)>-1?P:-P|0)+((Q|0)>-1?Q:-Q|0)+((R|0)>-1?R:-R|0)+((S|0)>-1?S:-S|0)+((T|0)>-1?T:-T|0)+((U|0)>-1?U:-U|0)+((G|0)>-1?G:-G|0)|0;G=y+1|0;if((G|0)<(g|0)){x=x+f|0;c=B;y=G;z=e;A=C}else{h=B;break}}return h|0}function I8(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f|0)>0){g=c;h=b;i=0;j=0}else{k=0;return k|0}while(1){b=(d[h]|0)-(d[g]|0)|0;c=(d[h+1|0]|0)-(d[g+1|0]|0)|0;a=(d[h+2|0]|0)-(d[g+2|0]|0)|0;l=(d[h+3|0]|0)-(d[g+3|0]|0)|0;m=(d[h+4|0]|0)-(d[g+4|0]|0)|0;n=(d[h+5|0]|0)-(d[g+5|0]|0)|0;o=(d[h+6|0]|0)-(d[g+6|0]|0)|0;p=(d[h+7|0]|0)-(d[g+7|0]|0)|0;q=((b|0)>-1?b:-b|0)+i+((c|0)>-1?c:-c|0)+((a|0)>-1?a:-a|0)+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)|0;p=j+1|0;if((p|0)<(f|0)){g=g+e|0;h=h+e|0;i=q;j=p}else{k=q;break}}return k|0}function J8(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f|0)>0){g=c;h=b;i=0;j=0}else{k=0;return k|0}while(1){b=d[g+1|0]|0;c=(d[h]|0)-(((d[g]|0)+1+b|0)>>>1)|0;a=d[g+2|0]|0;l=(d[h+1|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+3|0]|0;m=(d[h+2|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+4|0]|0;n=(d[h+3|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+5|0]|0;o=(d[h+4|0]|0)-((a+1+b|0)>>>1)|0;a=d[g+6|0]|0;p=(d[h+5|0]|0)-((b+1+a|0)>>>1)|0;b=d[g+7|0]|0;q=(d[h+6|0]|0)-((a+1+b|0)>>>1)|0;a=(d[h+7|0]|0)-((b+1+(d[g+8|0]|0)|0)>>>1)|0;b=((c|0)>-1?c:-c|0)+i+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)+((q|0)>-1?q:-q|0)+((a|0)>-1?a:-a|0)|0;a=j+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=b;j=a}else{k=b;break}}return k|0}function K8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((g|0)<=0){h=0;return h|0}b=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=c;c=0;p=0;q=e;r=a[e]|0;while(1){e=q+f|0;s=a[e]|0;t=(d[o]|0)-(((r&255)+1+(s&255)|0)>>>1)|0;u=(d[o+1|0]|0)-(((d[q+1|0]|0)+1+(d[q+b|0]|0)|0)>>>1)|0;v=(d[o+2|0]|0)-(((d[q+2|0]|0)+1+(d[q+i|0]|0)|0)>>>1)|0;w=(d[o+3|0]|0)-(((d[q+3|0]|0)+1+(d[q+j|0]|0)|0)>>>1)|0;x=(d[o+4|0]|0)-(((d[q+4|0]|0)+1+(d[q+k|0]|0)|0)>>>1)|0;y=(d[o+5|0]|0)-(((d[q+5|0]|0)+1+(d[q+l|0]|0)|0)>>>1)|0;z=(d[o+6|0]|0)-(((d[q+6|0]|0)+1+(d[q+m|0]|0)|0)>>>1)|0;A=(d[o+7|0]|0)-(((d[q+7|0]|0)+1+(d[q+n|0]|0)|0)>>>1)|0;B=((t|0)>-1?t:-t|0)+c+((u|0)>-1?u:-u|0)+((v|0)>-1?v:-v|0)+((w|0)>-1?w:-w|0)+((x|0)>-1?x:-x|0)+((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)+((A|0)>-1?A:-A|0)|0;A=p+1|0;if((A|0)<(g|0)){o=o+f|0;c=B;p=A;q=e;r=s}else{h=B;break}}return h|0}function L8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((g|0)<=0){h=0;return h|0}b=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=c;c=0;q=0;r=e;s=a[e]|0;while(1){e=r+f|0;t=d[r+1|0]|0;u=a[e]|0;v=d[r+b|0]|0;w=(d[p]|0)-(((s&255)+2+t+(u&255)+v|0)>>>2)|0;x=d[r+2|0]|0;y=d[r+i|0]|0;z=(d[p+1|0]|0)-((t+2+x+v+y|0)>>>2)|0;v=d[r+3|0]|0;t=d[r+j|0]|0;A=(d[p+2|0]|0)-((x+2+v+y+t|0)>>>2)|0;y=d[r+4|0]|0;x=d[r+k|0]|0;B=(d[p+3|0]|0)-((v+2+y+t+x|0)>>>2)|0;t=d[r+5|0]|0;v=d[r+l|0]|0;C=(d[p+4|0]|0)-((y+2+t+x+v|0)>>>2)|0;x=d[r+6|0]|0;y=d[r+m|0]|0;D=(d[p+5|0]|0)-((t+2+x+v+y|0)>>>2)|0;v=d[r+7|0]|0;t=d[r+n|0]|0;E=(d[p+6|0]|0)-((x+2+v+y+t|0)>>>2)|0;y=(d[p+7|0]|0)-((v+2+(d[r+8|0]|0)+t+(d[r+o|0]|0)|0)>>>2)|0;t=((w|0)>-1?w:-w|0)+c+((z|0)>-1?z:-z|0)+((A|0)>-1?A:-A|0)+((B|0)>-1?B:-B|0)+((C|0)>-1?C:-C|0)+((D|0)>-1?D:-D|0)+((E|0)>-1?E:-E|0)+((y|0)>-1?y:-y|0)|0;y=q+1|0;if((y|0)<(g|0)){p=p+f|0;c=t;q=y;r=e;s=u}else{h=t;break}}return h|0}function M8(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((g|0)==8){if((h|0)>0){i=e;j=a;k=0}else{return}while(1){l=i;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=i+4|0;c[j+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=k+1|0;if((l|0)<(h|0)){i=i+f|0;j=j+f|0;k=l}else{break}}return}else if((g|0)==2){if((h|0)>0){m=e;n=a;o=0}else{return}while(1){k=m;b[n>>1]=(d[k]|d[k+1|0]<<8)<<16>>16;k=o+1|0;if((k|0)<(h|0)){m=m+f|0;n=n+f|0;o=k}else{break}}return}else if((g|0)==16){if((h|0)>0){p=e;q=a;r=0}else{return}while(1){o=p;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+4|0;c[q+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=r+1|0;if((o|0)<(h|0)){p=p+f|0;q=q+f|0;r=o}else{break}}r=e+8|0;q=a+8|0;p=0;while(1){o=r;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=r+4|0;c[q+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+1|0;if((o|0)<(h|0)){r=r+f|0;q=q+f|0;p=o}else{break}}return}else if((g|0)==4){if((h|0)>0){s=e;t=a;u=0}else{return}while(1){a=s;c[t>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=u+1|0;if((a|0)<(h|0)){s=s+f|0;t=t+f|0;u=a}else{break}}return}else{return}}function N8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)>0&(f|0)>0){h=c;i=b;j=0}else{return}while(1){b=0;while(1){c=b+1|0;a[i+b|0]=(((((d[h+b|0]|0)<<1)+(d[h+c|0]|0)|0)*683|0)+683|0)>>>11;if((c|0)<(f|0)){b=c}else{break}}b=j+1|0;if((b|0)<(g|0)){h=h+e|0;i=i+e|0;j=b}else{break}}return}function O8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)>0&(f|0)>0){h=c;i=b;j=0}else{return}while(1){b=0;while(1){c=b+1|0;a[i+b|0]=(((((d[h+c|0]|0)<<1)+(d[h+b|0]|0)|0)*683|0)+683|0)>>>11;if((c|0)<(f|0)){b=c}else{break}}b=j+1|0;if((b|0)<(g|0)){h=h+e|0;i=i+e|0;j=b}else{break}}return}function P8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;do{a[c+j|0]=(((((d[i+j|0]|0)<<1)+(d[i+(j+e)|0]|0)|0)*683|0)+683|0)>>>11;j=j+1|0;}while((j|0)<(f|0))}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function Q8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=j+1|0;l=j+e|0;a[c+j|0]=(((((d[i+(l+1)|0]|0)<<1)+((d[i+j|0]|0)<<2)+(((d[i+l|0]|0)+(d[i+k|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15;if((k|0)<(f|0)){j=k}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function R8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=j+1|0;l=j+e|0;a[c+j|0]=(((((d[i+l|0]|0)<<1)+((d[i+k|0]|0)<<2)+(((d[i+(l+1)|0]|0)+(d[i+j|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15;if((k|0)<(f|0)){j=k}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function S8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;do{a[c+j|0]=(((((d[i+(j+e)|0]|0)<<1)+(d[i+j|0]|0)|0)*683|0)+683|0)>>>11;j=j+1|0;}while((j|0)<(f|0))}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function T8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=j+1|0;l=j+e|0;a[c+j|0]=(((((d[i+l|0]|0)<<2)+((d[i+k|0]|0)<<1)+(((d[i+(l+1)|0]|0)+(d[i+j|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15;if((k|0)<(f|0)){j=k}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function U8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=j+1|0;l=j+e|0;a[c+j|0]=(((((d[i+(l+1)|0]|0)<<2)+((d[i+j|0]|0)<<1)+(((d[i+l|0]|0)+(d[i+k|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15;if((k|0)<(f|0)){j=k}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function V8(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((g|0)==2){if((h|0)>0){i=e;j=a;k=0}else{return}while(1){l=j;m=b[l>>1]|0;n=i;o=(d[n]|d[n+1|0]<<8)<<16>>16;b[l>>1]=(o|m)-(((o^m)&65535)>>>1&32639);m=k+1|0;if((m|0)<(h|0)){i=i+f|0;j=j+f|0;k=m}else{break}}return}else if((g|0)==16){if((h|0)>0){p=e;q=a;r=0}else{return}while(1){k=q;j=c[k>>2]|0;i=p;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[k>>2]=(m|j)-((m^j)>>>1&2139062143);j=q+4|0;m=c[j>>2]|0;k=p+4|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[j>>2]=(i|m)-((i^m)>>>1&2139062143);m=r+1|0;if((m|0)<(h|0)){p=p+f|0;q=q+f|0;r=m}else{break}}r=e+8|0;q=a+8|0;p=0;while(1){m=q;i=c[m>>2]|0;j=r;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[m>>2]=(k|i)-((k^i)>>>1&2139062143);i=q+4|0;k=c[i>>2]|0;m=r+4|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[i>>2]=(j|k)-((j^k)>>>1&2139062143);k=p+1|0;if((k|0)<(h|0)){r=r+f|0;q=q+f|0;p=k}else{break}}return}else if((g|0)==8){if((h|0)>0){s=e;t=a;u=0}else{return}while(1){p=t;q=c[p>>2]|0;r=s;k=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=(k|q)-((k^q)>>>1&2139062143);q=t+4|0;k=c[q>>2]|0;p=s+4|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=(r|k)-((r^k)>>>1&2139062143);k=u+1|0;if((k|0)<(h|0)){s=s+f|0;t=t+f|0;u=k}else{break}}return}else if((g|0)==4){if((h|0)>0){v=e;w=a;x=0}else{return}while(1){a=w;e=c[a>>2]|0;g=v;u=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[a>>2]=(u|e)-((u^e)>>>1&2139062143);e=x+1|0;if((e|0)<(h|0)){v=v+f|0;w=w+f|0;x=e}else{break}}return}else{return}}function W8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;a[k]=((d[k]|0)+1+((((((d[i+j|0]|0)<<1)+(d[i+l|0]|0)|0)*683|0)+683|0)>>>11)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function X8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;a[k]=((d[k]|0)+1+((((((d[i+l|0]|0)<<1)+(d[i+j|0]|0)|0)*683|0)+683|0)>>>11)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function Y8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;do{k=c+j|0;a[k]=((d[k]|0)+1+((((((d[i+j|0]|0)<<1)+(d[i+(j+e)|0]|0)|0)*683|0)+683|0)>>>11)|0)>>>1;j=j+1|0;}while((j|0)<(f|0))}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function Z8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;m=j+e|0;a[k]=((d[k]|0)+1+((((((d[i+(m+1)|0]|0)<<1)+((d[i+j|0]|0)<<2)+(((d[i+m|0]|0)+(d[i+l|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function _8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;m=j+e|0;a[k]=((d[k]|0)+1+((((((d[i+m|0]|0)<<1)+((d[i+l|0]|0)<<2)+(((d[i+(m+1)|0]|0)+(d[i+j|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function $8(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;do{k=c+j|0;a[k]=((d[k]|0)+1+((((((d[i+(j+e)|0]|0)<<1)+(d[i+j|0]|0)|0)*683|0)+683|0)>>>11)|0)>>>1;j=j+1|0;}while((j|0)<(f|0))}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function a9(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;m=j+e|0;a[k]=((d[k]|0)+1+((((((d[i+m|0]|0)<<2)+((d[i+l|0]|0)<<1)+(((d[i+(m+1)|0]|0)+(d[i+j|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function b9(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)<=0){return}h=(f|0)>0;i=c;c=b;b=0;while(1){if(h){j=0;while(1){k=c+j|0;l=j+1|0;m=j+e|0;a[k]=((d[k]|0)+1+((((((d[i+(m+1)|0]|0)<<2)+((d[i+j|0]|0)<<1)+(((d[i+m|0]|0)+(d[i+l|0]|0)|0)*3|0)|0)*2731|0)+16386|0)>>>15)|0)>>>1;if((l|0)<(f|0)){j=l}else{break}}}j=b+1|0;if((j|0)<(g|0)){i=i+e|0;c=c+e|0;b=j}else{break}}return}function c9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;Y6(g|0,b,16,e,16);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ca(o,e)|0;n=h+8|0;k=b+n|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=o<<4;j=g+(k|8)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+n>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+12|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(k|12)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+l>>2]=(k|m)-((k^m)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function d9(a,b,c){a=a|0;b=b|0;c=c|0;Y6(a,b,c,c,16);return}function e9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;Y6(g|0,b,16,e,16);h=0;while(1){j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ca(o,e)|0;n=b+(h+9)|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o<<4;j=g+(n|8)|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(h+8)>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(n|12)|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+(h+12)>>2]=(n|l)-((n^l)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function f9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}Z6(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(k,f)|0;c[b+o>>2]=(q|l)-((q^l)>>>1&2139062143);l=h+(m|4)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+(e|4)|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(o+4)>>2]=(e|m)-((e^m)>>>1&2139062143);m=k+1|0;if((m|0)<16){k=m}else{r=0;break}}do{k=r*24|0;m=h+(k+8)|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r<<4;o=j+(m|8)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(r,f)|0;c[b+(o+8)>>2]=(l|e)-((l^e)>>>1&2139062143);e=h+(k+12)|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+(m|12)|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+12)>>2]=(m|k)-((m^k)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function g9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;Y6(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);Z6(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=(p|l)-((p^l)>>>1&2139062143);l=s|4;s=j+l|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=(l|p)-((l^p)>>>1&2139062143);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+p|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(t,f)|0;c[b+(l+8)>>2]=(p|h)-((p^h)>>>1&2139062143);h=n|12;n=j+h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=(h|p)-((h^p)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function h9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;Y6(j,b,16,e,17);Z6(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=g+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<16){j=m}else{n=0;break}}do{j=n<<4;m=j|8;l=g+m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(n,e)|0;c[a+(l+8)>>2]=(m|k)-((m^k)>>>1&2139062143);k=j|12;j=g+k|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+k|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(l+12)>>2]=(k|m)-((k^m)>>>1&2139062143);n=n+1|0;}while((n|0)<16);i=f;return}function i9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;Y6(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);Z6(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=(p|l)-((p^l)>>>1&2139062143);l=s|4;s=j+l|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=(l|p)-((l^p)>>>1&2139062143);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+p|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(t,f)|0;c[b+(l+8)>>2]=(p|h)-((p^h)>>>1&2139062143);h=n|12;n=j+h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=(h|p)-((h^p)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function j9(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+408|0;g=f|0;h=c;c=g;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;a[c+16|0]=a[h+16|0]|0;l=j+1|0;if((l|0)<17){h=h+e|0;c=c+24|0;j=l}else{break}}Z6(b,g,e,24);i=f;return}function k9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;Y6(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+q|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=(n|o)-((n^o)>>>1&2139062143);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|4)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=(q|e)-((q^e)>>>1&2139062143);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+8)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=(l|q)-((l^q)>>>1&2139062143);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+12)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=(o|k)-((o^k)>>>1&2139062143);r=r+1|0;}while((r|0)<17);Z6(b,m,f,16);i=g;return}function l9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+272|0;e=d|0;Y6(e,b,16,c,17);Z6(a,e,c,16);i=d;return}function m9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;Y6(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+(q|1)|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=(n|o)-((n^o)>>>1&2139062143);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|5)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=(q|e)-((q^e)>>>1&2139062143);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+9)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=(l|q)-((l^q)>>>1&2139062143);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+13)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=(o|k)-((o^k)>>>1&2139062143);r=r+1|0;}while((r|0)<17);Z6(b,m,f,16);i=g;return}function n9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}Z6(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+(m+24)|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(k,f)|0;c[b+o>>2]=(q|l)-((q^l)>>>1&2139062143);l=h+((m|4)+24)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+(e|4)|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(o+4)>>2]=(e|m)-((e^m)>>>1&2139062143);m=k+1|0;if((m|0)<16){k=m}else{r=0;break}}do{k=r*24|0;m=h+(k+32)|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r<<4;o=j+(m|8)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(r,f)|0;c[b+(o+8)>>2]=(l|e)-((l^e)>>>1&2139062143);e=h+(k+36)|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+(m|12)|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+12)>>2]=(m|k)-((m^k)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function o9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;Y6(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);Z6(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=(p|l)-((p^l)>>>1&2139062143);l=s|4;s=j+(l+16)|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=(l|p)-((l^p)>>>1&2139062143);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+(p+16)|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(t,f)|0;c[b+(l+8)>>2]=(p|h)-((p^h)>>>1&2139062143);h=n|12;n=j+(h+16)|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=(h|p)-((h^p)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function p9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;Y6(j,b,16,e,17);Z6(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+(b+16)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=g+(l+16)|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+1|0;if((m|0)<16){j=m}else{n=0;break}}do{j=n<<4;m=j|8;l=g+(m+16)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(n,e)|0;c[a+(l+8)>>2]=(m|k)-((m^k)>>>1&2139062143);k=j|12;j=g+(k+16)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+k|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(l+12)>>2]=(k|m)-((k^m)>>>1&2139062143);n=n+1|0;}while((n|0)<16);i=f;return}function q9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;Y6(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);Z6(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=(p|l)-((p^l)>>>1&2139062143);l=s|4;s=j+(l+16)|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=(l|p)-((l^p)>>>1&2139062143);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+(p+16)|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(t,f)|0;c[b+(l+8)>>2]=(p|h)-((p^h)>>>1&2139062143);h=n|12;n=j+(h+16)|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=(h|p)-((h^p)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function r9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;n7(g|0,b,16,e,16);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=((n^l)>>>1&2139062143)+(n&l);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=((k^n)>>>1&2139062143)+(k&n);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ca(o,e)|0;n=h+8|0;k=b+n|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=o<<4;j=g+(k|8)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+n>>2]=((m^l)>>>1&2139062143)+(m&l);l=h+12|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(k|12)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+l>>2]=((k^m)>>>1&2139062143)+(k&m);o=o+1|0;}while((o|0)<16);i=f;return}function s9(a,b,c){a=a|0;b=b|0;c=c|0;n7(a,b,c,c,16);return}function t9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;n7(g|0,b,16,e,16);h=0;while(1){j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=((n^l)>>>1&2139062143)+(n&l);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=((k^n)>>>1&2139062143)+(k&n);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ca(o,e)|0;n=b+(h+9)|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o<<4;j=g+(n|8)|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(h+8)>>2]=((l^k)>>>1&2139062143)+(l&k);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(n|12)|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+(h+12)>>2]=((n^l)>>>1&2139062143)+(n&l);o=o+1|0;}while((o|0)<16);i=f;return}function u9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}o7(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(k,f)|0;c[b+o>>2]=((q^l)>>>1&2139062143)+(q&l);l=h+(m|4)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+(e|4)|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(o+4)>>2]=((e^m)>>>1&2139062143)+(e&m);m=k+1|0;if((m|0)<16){k=m}else{r=0;break}}do{k=r*24|0;m=h+(k+8)|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r<<4;o=j+(m|8)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(r,f)|0;c[b+(o+8)>>2]=((l^e)>>>1&2139062143)+(l&e);e=h+(k+12)|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+(m|12)|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+12)>>2]=((m^k)>>>1&2139062143)+(m&k);r=r+1|0;}while((r|0)<16);i=g;return}function v9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;n7(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=((o^p)>>>1&2139062143)+(o&p);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=((r^e)>>>1&2139062143)+(r&e);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=((m^r)>>>1&2139062143)+(m&r);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=((p^l)>>>1&2139062143)+(p&l);s=s+1|0;}while((s|0)<17);o7(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=((p^l)>>>1&2139062143)+(p&l);l=s|4;s=j+l|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=((l^p)>>>1&2139062143)+(l&p);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+p|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(t,f)|0;c[b+(l+8)>>2]=((p^h)>>>1&2139062143)+(p&h);h=n|12;n=j+h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=((h^p)>>>1&2139062143)+(h&p);t=t+1|0;}while((t|0)<16);i=g;return}function w9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;n7(j,b,16,e,17);o7(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;c[a+k>>2]=((m^l)>>>1&2139062143)+(m&l);l=b|4;b=g+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=((l^m)>>>1&2139062143)+(l&m);m=j+1|0;if((m|0)<16){j=m}else{n=0;break}}do{j=n<<4;m=j|8;l=g+m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(n,e)|0;c[a+(l+8)>>2]=((m^k)>>>1&2139062143)+(m&k);k=j|12;j=g+k|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+k|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(l+12)>>2]=((k^m)>>>1&2139062143)+(k&m);n=n+1|0;}while((n|0)<16);i=f;return}function x9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;n7(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=((o^p)>>>1&2139062143)+(o&p);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=((r^e)>>>1&2139062143)+(r&e);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=((m^r)>>>1&2139062143)+(m&r);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=((p^l)>>>1&2139062143)+(p&l);s=s+1|0;}while((s|0)<17);o7(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=((p^l)>>>1&2139062143)+(p&l);l=s|4;s=j+l|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=((l^p)>>>1&2139062143)+(l&p);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+p|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(t,f)|0;c[b+(l+8)>>2]=((p^h)>>>1&2139062143)+(p&h);h=n|12;n=j+h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=((h^p)>>>1&2139062143)+(h&p);t=t+1|0;}while((t|0)<16);i=g;return}function y9(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+408|0;g=f|0;h=c;c=g;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;a[c+16|0]=a[h+16|0]|0;l=j+1|0;if((l|0)<17){h=h+e|0;c=c+24|0;j=l}else{break}}o7(b,g,e,24);i=f;return}function z9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;n7(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+q|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=((n^o)>>>1&2139062143)+(n&o);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|4)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=((q^e)>>>1&2139062143)+(q&e);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+8)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=((l^q)>>>1&2139062143)+(l&q);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+12)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=((o^k)>>>1&2139062143)+(o&k);r=r+1|0;}while((r|0)<17);o7(b,m,f,16);i=g;return}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+272|0;e=d|0;n7(e,b,16,c,17);o7(a,e,c,16);i=d;return}function B9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;n7(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+(q|1)|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=((n^o)>>>1&2139062143)+(n&o);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|5)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=((q^e)>>>1&2139062143)+(q&e);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+9)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=((l^q)>>>1&2139062143)+(l&q);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+13)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=((o^k)>>>1&2139062143)+(o&k);r=r+1|0;}while((r|0)<17);o7(b,m,f,16);i=g;return}function C9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}o7(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+(m+24)|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(k,f)|0;c[b+o>>2]=((q^l)>>>1&2139062143)+(q&l);l=h+((m|4)+24)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+(e|4)|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(o+4)>>2]=((e^m)>>>1&2139062143)+(e&m);m=k+1|0;if((m|0)<16){k=m}else{r=0;break}}do{k=r*24|0;m=h+(k+32)|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r<<4;o=j+(m|8)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(r,f)|0;c[b+(o+8)>>2]=((l^e)>>>1&2139062143)+(l&e);e=h+(k+36)|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+(m|12)|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+12)>>2]=((m^k)>>>1&2139062143)+(m&k);r=r+1|0;}while((r|0)<16);i=g;return}function D9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;n7(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=((o^p)>>>1&2139062143)+(o&p);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=((r^e)>>>1&2139062143)+(r&e);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=((m^r)>>>1&2139062143)+(m&r);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=((p^l)>>>1&2139062143)+(p&l);s=s+1|0;}while((s|0)<17);o7(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=((p^l)>>>1&2139062143)+(p&l);l=s|4;s=j+(l+16)|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=((l^p)>>>1&2139062143)+(l&p);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+(p+16)|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(t,f)|0;c[b+(l+8)>>2]=((p^h)>>>1&2139062143)+(p&h);h=n|12;n=j+(h+16)|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=((h^p)>>>1&2139062143)+(h&p);t=t+1|0;}while((t|0)<16);i=g;return}function E9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;n7(j,b,16,e,17);o7(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+(b+16)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;c[a+k>>2]=((m^l)>>>1&2139062143)+(m&l);l=b|4;b=g+(l+16)|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=((l^m)>>>1&2139062143)+(l&m);m=j+1|0;if((m|0)<16){j=m}else{n=0;break}}do{j=n<<4;m=j|8;l=g+(m+16)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(n,e)|0;c[a+(l+8)>>2]=((m^k)>>>1&2139062143)+(m&k);k=j|12;j=g+(k+16)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+k|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(l+12)>>2]=((k^m)>>>1&2139062143)+(k&m);n=n+1|0;}while((n|0)<16);i=f;return}function F9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;n7(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=((o^p)>>>1&2139062143)+(o&p);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=((r^e)>>>1&2139062143)+(r&e);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=((m^r)>>>1&2139062143)+(m&r);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=((p^l)>>>1&2139062143)+(p&l);s=s+1|0;}while((s|0)<17);o7(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;c[b+h>>2]=((p^l)>>>1&2139062143)+(p&l);l=s|4;s=j+(l+16)|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+l|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[b+(h+4)>>2]=((l^p)>>>1&2139062143)+(l&p);p=n+1|0;if((p|0)<16){n=p}else{t=0;break}}do{n=t<<4;p=n|8;l=j+(p+16)|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(t,f)|0;c[b+(l+8)>>2]=((p^h)>>>1&2139062143)+(p&h);h=n|12;n=j+(h+16)|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+h|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[b+(l+12)>>2]=((h^p)>>>1&2139062143)+(h&p);t=t+1|0;}while((t|0)<16);i=g;return}function G9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;Y6(g|0,b,16,e,16);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=j+4|0;j=b+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+o|0;o=c[j>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[j>>2]=(m|o)-((m^o)>>>1&2139062143);o=h+1|0;if((o|0)<16){h=o}else{q=0;break}}do{h=ca(q,e)|0;o=h+8|0;m=b+o|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q<<4;p=g+(m|8)|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+o|0;o=c[p>>2]|0;l=(k|j)-((k^j)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=h+12|0;h=b+o|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(m|12)|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+o|0;o=c[h>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[h>>2]=(p|o)-((p^o)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function H9(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c;c=b;b=0;while(1){g=d[f]|0;h=f+1|0;i=d[h]|0;j=f+2|0;k=d[j]|0;l=f+3|0;m=f+4|0;a[c]=((d[c]|0)+1+(d[(16-k+((i+g|0)*20|0)+((k+g|0)*-6|0)-(d[m]|0)+(((d[l]|0)+i|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;i=c+1|0;g=d[h]|0;k=d[f]|0;n=f+5|0;a[i]=((d[i]|0)+1+(d[(16-g+(((d[j]|0)+g|0)*20|0)+(((d[l]|0)+k|0)*-6|0)-(d[n]|0)+(((d[m]|0)+k|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;k=c+2|0;g=d[f]|0;i=f+6|0;a[k]=((d[k]|0)+1+(d[((((d[l]|0)+(d[j]|0)|0)*20|0)+16-g+(((d[m]|0)+(d[h]|0)|0)*-6|0)-(d[i]|0)+(((d[n]|0)+g|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;g=c+3|0;k=f+7|0;a[g]=((d[g]|0)+1+(d[((((d[m]|0)+(d[l]|0)|0)*20|0)+16+(((d[n]|0)+(d[j]|0)|0)*-6|0)-(d[f]|0)+(((d[i]|0)+(d[h]|0)|0)*3|0)-(d[k]|0)>>5)+1404400|0]|0)|0)>>>1;g=c+4|0;o=f+8|0;a[g]=((d[g]|0)+1+(d[((((d[n]|0)+(d[m]|0)|0)*20|0)+16+(((d[i]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[j]|0)|0)*3|0)-(d[o]|0)>>5)+1404400|0]|0)|0)>>>1;h=c+5|0;g=f+9|0;a[h]=((d[h]|0)+1+(d[((((d[i]|0)+(d[n]|0)|0)*20|0)+16+(((d[k]|0)+(d[m]|0)|0)*-6|0)-(d[j]|0)+(((d[o]|0)+(d[l]|0)|0)*3|0)-(d[g]|0)>>5)+1404400|0]|0)|0)>>>1;j=c+6|0;h=f+10|0;a[j]=((d[j]|0)+1+(d[((((d[k]|0)+(d[i]|0)|0)*20|0)+16+(((d[o]|0)+(d[n]|0)|0)*-6|0)-(d[l]|0)+(((d[g]|0)+(d[m]|0)|0)*3|0)-(d[h]|0)>>5)+1404400|0]|0)|0)>>>1;l=c+7|0;j=f+11|0;a[l]=((d[l]|0)+1+(d[((((d[o]|0)+(d[k]|0)|0)*20|0)+16+(((d[g]|0)+(d[i]|0)|0)*-6|0)-(d[m]|0)+(((d[h]|0)+(d[n]|0)|0)*3|0)-(d[j]|0)>>5)+1404400|0]|0)|0)>>>1;m=c+8|0;l=f+12|0;a[m]=((d[m]|0)+1+(d[((((d[g]|0)+(d[o]|0)|0)*20|0)+16+(((d[h]|0)+(d[k]|0)|0)*-6|0)-(d[n]|0)+(((d[j]|0)+(d[i]|0)|0)*3|0)-(d[l]|0)>>5)+1404400|0]|0)|0)>>>1;n=c+9|0;m=f+13|0;a[n]=((d[n]|0)+1+(d[((((d[h]|0)+(d[g]|0)|0)*20|0)+16+(((d[j]|0)+(d[o]|0)|0)*-6|0)-(d[i]|0)+(((d[l]|0)+(d[k]|0)|0)*3|0)-(d[m]|0)>>5)+1404400|0]|0)|0)>>>1;i=c+10|0;n=f+14|0;a[i]=((d[i]|0)+1+(d[((((d[j]|0)+(d[h]|0)|0)*20|0)+16+(((d[l]|0)+(d[g]|0)|0)*-6|0)-(d[k]|0)+(((d[m]|0)+(d[o]|0)|0)*3|0)-(d[n]|0)>>5)+1404400|0]|0)|0)>>>1;k=c+11|0;i=f+15|0;a[k]=((d[k]|0)+1+(d[((((d[l]|0)+(d[j]|0)|0)*20|0)+16+(((d[m]|0)+(d[h]|0)|0)*-6|0)-(d[o]|0)+(((d[n]|0)+(d[g]|0)|0)*3|0)-(d[i]|0)>>5)+1404400|0]|0)|0)>>>1;o=c+12|0;k=f+16|0;a[o]=((d[o]|0)+1+(d[((((d[m]|0)+(d[l]|0)|0)*20|0)+16+(((d[n]|0)+(d[j]|0)|0)*-6|0)-(d[g]|0)+(((d[i]|0)+(d[h]|0)|0)*3|0)-(d[k]|0)>>5)+1404400|0]|0)|0)>>>1;g=c+13|0;o=d[k]|0;a[g]=((d[g]|0)+1+(d[((((d[n]|0)+(d[m]|0)|0)*20|0)+16+(((d[i]|0)+(d[l]|0)|0)*-6|0)-o-(d[h]|0)+((o+(d[j]|0)|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;o=c+14|0;h=d[i]|0;g=d[k]|0;a[o]=((d[o]|0)+1+(d[(16-h+((h+(d[n]|0)|0)*20|0)+((g+(d[m]|0)|0)*-6|0)-(d[j]|0)+(((d[l]|0)+g|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;g=c+15|0;j=d[i]|0;i=d[k]|0;k=d[n]|0;a[g]=((d[g]|0)+1+(d[(16-k+((i+j|0)*20|0)+((k+i|0)*-6|0)-(d[l]|0)+(((d[m]|0)+j|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;j=b+1|0;if((j|0)<16){f=f+e|0;c=c+e|0;b=j}else{break}}return}function I9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;Y6(g|0,b,16,e,16);h=0;while(1){j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=b+(j+5)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+(k|4)|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(j+4)|0;j=c[o>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[o>>2]=(m|j)-((m^j)>>>1&2139062143);j=h+1|0;if((j|0)<16){h=j}else{q=0;break}}do{h=ca(q,e)|0;j=b+(h+9)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=q<<4;o=g+(j|8)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(h+8)|0;k=c[o>>2]|0;l=(p|m)-((p^m)>>>1&2139062143)|0;c[o>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(j|12)|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+(h+12)|0;h=c[k>>2]|0;o=(j|l)-((j^l)>>>1&2139062143)|0;c[k>>2]=(o|h)-((o^h)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function J9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}Z6(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(k,f)|0;p=b+o|0;n=c[p>>2]|0;r=(q|l)-((q^l)>>>1&2139062143)|0;c[p>>2]=(r|n)-((r^n)>>>1&2139062143);n=h+(m|4)|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+(e|4)|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(o+4)|0;o=c[n>>2]|0;r=(e|m)-((e^m)>>>1&2139062143)|0;c[n>>2]=(r|o)-((r^o)>>>1&2139062143);o=k+1|0;if((o|0)<16){k=o}else{s=0;break}}do{k=s*24|0;o=h+(k+8)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=s<<4;n=j+(o|8)|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(s,f)|0;e=b+(n+8)|0;p=c[e>>2]|0;l=(m|r)-((m^r)>>>1&2139062143)|0;c[e>>2]=(l|p)-((l^p)>>>1&2139062143);p=h+((k|4)+8)|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+(o|12)|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(n+12)|0;n=c[p>>2]|0;l=(o|k)-((o^k)>>>1&2139062143)|0;c[p>>2]=(l|n)-((l^n)>>>1&2139062143);s=s+1|0;}while((s|0)<16);i=g;return}function K9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;Y6(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);Z6(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;r=b+h|0;m=c[r>>2]|0;e=(p|l)-((p^l)>>>1&2139062143)|0;c[r>>2]=(e|m)-((e^m)>>>1&2139062143);m=s|4;s=j+m|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+m|0;m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=b+(h+4)|0;h=c[s>>2]|0;r=(m|e)-((m^e)>>>1&2139062143)|0;c[s>>2]=(r|h)-((r^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{t=0;break}}do{n=t<<4;h=n|8;r=j+h|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=k+h|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ca(t,f)|0;e=b+(r+8)|0;m=c[e>>2]|0;l=(h|s)-((h^s)>>>1&2139062143)|0;c[e>>2]=(l|m)-((l^m)>>>1&2139062143);m=n|12;n=j+m|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+m|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(r+12)|0;r=c[n>>2]|0;e=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(e|r)-((e^r)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function L9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;Y6(j,b,16,e,17);Z6(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=g+o|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(k+4)|0;k=c[b>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(n|k)-((n^k)>>>1&2139062143);k=j+1|0;if((k|0)<16){j=k}else{q=0;break}}do{j=q<<4;k=j|8;n=g+k|0;b=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+k|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(q,e)|0;p=a+(n+8)|0;o=c[p>>2]|0;l=(k|b)-((k^b)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=j|12;j=g+o|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+(n+12)|0;n=c[j>>2]|0;p=(o|l)-((o^l)>>>1&2139062143)|0;c[j>>2]=(p|n)-((p^n)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function M9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;Y6(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);Z6(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+s|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;r=b+h|0;m=c[r>>2]|0;e=(p|l)-((p^l)>>>1&2139062143)|0;c[r>>2]=(e|m)-((e^m)>>>1&2139062143);m=s|4;s=j+m|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+m|0;m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=b+(h+4)|0;h=c[s>>2]|0;r=(m|e)-((m^e)>>>1&2139062143)|0;c[s>>2]=(r|h)-((r^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{t=0;break}}do{n=t<<4;h=n|8;r=j+h|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=k+h|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=ca(t,f)|0;e=b+(r+8)|0;m=c[e>>2]|0;l=(h|s)-((h^s)>>>1&2139062143)|0;c[e>>2]=(l|m)-((l^m)>>>1&2139062143);m=n|12;n=j+m|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+m|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(r+12)|0;r=c[n>>2]|0;e=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(e|r)-((e^r)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function N9(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+408|0;g=f|0;h=c;c=g;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;a[c+16|0]=a[h+16|0]|0;l=j+1|0;if((l|0)<17){h=h+e|0;c=c+24|0;j=l}else{break}}Rba(b,g,e,24);i=f;return}function O9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;Y6(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+q|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=(n|o)-((n^o)>>>1&2139062143);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|4)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=(q|e)-((q^e)>>>1&2139062143);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+8)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=(l|q)-((l^q)>>>1&2139062143);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+12)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=(o|k)-((o^k)>>>1&2139062143);r=r+1|0;}while((r|0)<17);Rba(b,m,f,16);i=g;return}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+272|0;e=d|0;Y6(e,b,16,c,17);Rba(a,e,c,16);i=d;return}function Q9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+680|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}m=j|0;Y6(m,k,16,24,17);k=0;while(1){e=k<<4;l=j+e|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;q=k*24|0;p=h+(q|1)|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=(n|o)-((n^o)>>>1&2139062143);o=j+(e|4)|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=h+(q|5)|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[o>>2]=(q|e)-((q^e)>>>1&2139062143);e=k+1|0;if((e|0)<17){k=e}else{r=0;break}}do{k=r<<4;e=j+(k|8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;o=r*24|0;n=h+(o+9)|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[e>>2]=(l|q)-((l^q)>>>1&2139062143);q=j+(k|12)|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;l=h+(o+13)|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[q>>2]=(o|k)-((o^k)>>>1&2139062143);r=r+1|0;}while((r|0)<17);Rba(b,m,f,16);i=g;return}function R9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+664|0;h=g|0;j=g+408|0;k=h|0;l=e;e=k;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;a[e+16|0]=a[l+16|0]|0;o=m+1|0;if((o|0)<17){l=l+f|0;e=e+24|0;m=o}else{break}}Z6(j|0,k,16,24);k=0;while(1){m=k*24|0;e=h+(m+24)|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k<<4;o=j+e|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(k,f)|0;p=b+o|0;n=c[p>>2]|0;r=(q|l)-((q^l)>>>1&2139062143)|0;c[p>>2]=(r|n)-((r^n)>>>1&2139062143);n=h+((m|4)+24)|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+(e|4)|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(o+4)|0;o=c[n>>2]|0;r=(e|m)-((e^m)>>>1&2139062143)|0;c[n>>2]=(r|o)-((r^o)>>>1&2139062143);o=k+1|0;if((o|0)<16){k=o}else{s=0;break}}do{k=s*24|0;o=h+(k+32)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=s<<4;n=j+(o|8)|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(s,f)|0;e=b+(n+8)|0;p=c[e>>2]|0;l=(m|r)-((m^r)>>>1&2139062143)|0;c[e>>2]=(l|p)-((l^p)>>>1&2139062143);p=h+((k|4)+32)|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+(o|12)|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(n+12)|0;n=c[p>>2]|0;l=(o|k)-((o^k)>>>1&2139062143)|0;c[p>>2]=(l|n)-((l^n)>>>1&2139062143);s=s+1|0;}while((s|0)<16);i=g;return}function S9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;Y6(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+r|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|4)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+8)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+12)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);Z6(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;r=b+h|0;m=c[r>>2]|0;e=(p|l)-((p^l)>>>1&2139062143)|0;c[r>>2]=(e|m)-((e^m)>>>1&2139062143);m=s|4;s=j+(m+16)|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+m|0;m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=b+(h+4)|0;h=c[s>>2]|0;r=(m|e)-((m^e)>>>1&2139062143)|0;c[s>>2]=(r|h)-((r^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{t=0;break}}do{n=t<<4;h=j+(n+24)|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+(n|8)|0;s=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(t,f)|0;e=b+(h+8)|0;m=c[e>>2]|0;l=(s|r)-((s^r)>>>1&2139062143)|0;c[e>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+((n|4)+24)|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+(n|12)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+12)|0;h=c[m>>2]|0;e=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(e|h)-((e^h)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function T9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+528|0;g=f|0;h=f+272|0;j=g|0;Y6(j,b,16,e,17);Z6(h|0,j,16,16);j=0;while(1){b=j<<4;k=g+(b+16)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=g+(o+16)|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(k+4)|0;k=c[b>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(n|k)-((n^k)>>>1&2139062143);k=j+1|0;if((k|0)<16){j=k}else{q=0;break}}do{j=q<<4;k=g+(j+24)|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+(j|8)|0;b=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(q,e)|0;p=a+(k+8)|0;o=c[p>>2]|0;l=(b|n)-((b^n)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=g+((j|4)+24)|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+(j|12)|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(k+12)|0;k=c[o>>2]|0;p=(j|l)-((j^l)>>>1&2139062143)|0;c[o>>2]=(p|k)-((p^k)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function U9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+936|0;h=g|0;j=g+408|0;k=g+680|0;l=h|0;m=e;e=l;n=0;while(1){o=m;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e;r=q|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=o;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=m+8|0;o=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+8|0;p=q|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=q+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;a[e+16|0]=a[m+16|0]|0;p=n+1|0;if((p|0)<17){m=m+f|0;e=e+24|0;n=p}else{break}}n=j|0;Y6(n,l,16,24,17);l=0;while(1){e=l<<4;m=j+e|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;r=l*24|0;q=h+(r|1)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=(o|p)-((o^p)>>>1&2139062143);p=j+(e|4)|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;o=h+(r|5)|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[p>>2]=(r|e)-((r^e)>>>1&2139062143);e=l+1|0;if((e|0)<17){l=e}else{s=0;break}}do{l=s<<4;e=j+(l|8)|0;r=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;p=s*24|0;o=h+(p+9)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[e>>2]=(m|r)-((m^r)>>>1&2139062143);r=j+(l|12)|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;m=h+(p+13)|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[r>>2]=(p|l)-((p^l)>>>1&2139062143);s=s+1|0;}while((s|0)<17);Z6(k|0,n,16,16);n=0;while(1){s=n<<4;h=j+(s+16)|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+s|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(n,f)|0;r=b+h|0;m=c[r>>2]|0;e=(p|l)-((p^l)>>>1&2139062143)|0;c[r>>2]=(e|m)-((e^m)>>>1&2139062143);m=s|4;s=j+(m+16)|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k+m|0;m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=b+(h+4)|0;h=c[s>>2]|0;r=(m|e)-((m^e)>>>1&2139062143)|0;c[s>>2]=(r|h)-((r^h)>>>1&2139062143);h=n+1|0;if((h|0)<16){n=h}else{t=0;break}}do{n=t<<4;h=j+(n+24)|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+(n|8)|0;s=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(t,f)|0;e=b+(h+8)|0;m=c[e>>2]|0;l=(s|r)-((s^r)>>>1&2139062143)|0;c[e>>2]=(l|m)-((l^m)>>>1&2139062143);m=j+((n|4)+24)|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+(n|12)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+12)|0;h=c[m>>2]|0;e=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(e|h)-((e^h)>>>1&2139062143);t=t+1|0;}while((t|0)<16);i=g;return}function V9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;P6(g|0,b,8,e,8);h=0;do{j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function W9(a,b,c){a=a|0;b=b|0;c=c|0;P6(a,b,c,c,8);return}function X9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;P6(g|0,b,8,e,8);h=0;do{j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function Y9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;Q6(k|0,l,8,16);m=0;do{e=m<<4;h=c[l+e>>2]|0;n=m<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ca(m,f)|0;c[b+j>>2]=(o|h)-((o^h)>>>1&2139062143);h=c[l+(e|4)>>2]|0;e=k+(n|4)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(j+4)>>2]=(n|h)-((n^h)>>>1&2139062143);m=m+1|0;}while((m|0)<8);i=g;return}function Z9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;P6(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=(q|j)-((q^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=(q|h)-((q^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);Q6(l|0,n,8,8);n=0;do{e=n<<3;m=k+e|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(n,f)|0;c[b+m>>2]=(q|h)-((q^h)>>>1&2139062143);h=e|4;e=k+h|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(m+4)>>2]=(h|q)-((h^q)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function _9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;P6(j,b,8,e,9);Q6(h|0,j,8,8);j=0;do{b=j<<3;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=g+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function $9(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;P6(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=(r|j)-((r^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=(p|e)-((p^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);Q6(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;c[b+k>>2]=(p|e)-((p^e)>>>1&2139062143);e=h|4;h=l+e|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=(e|p)-((e^p)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function aaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+144|0;h=g|0;j=h|0;k=e;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=k;a[h+8|0]=a[e+8|0]|0;k=h+16|0;j=e+f|0;l=j|0;m=j+4|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[k>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[k+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;k=f<<1;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+40|0]=a[e+(k+8)|0]|0;l=h+48|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+56|0]=a[e+(j+8)|0]|0;k=h+64|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+72|0]=a[e+(l+8)|0]|0;j=h+80|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+88|0]=a[e+(k+8)|0]|0;l=h+96|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+104|0]=a[e+(j+8)|0]|0;k=h+112|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+120|0]=a[e+(l+8)|0]|0;j=h+128|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+136|0]=a[e+(k+8)|0]|0;Q6(b,h,f,16);i=g;return}function baa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=k|0;P6(m,l,8,16,9);e=0;do{h=e<<3;n=k+h|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=e<<4;p=c[l+o>>2]|0;c[n>>2]=(p|j)-((p^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;p=c[l+(o|4)>>2]|0;c[j>>2]=(p|h)-((p^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);Q6(b,m,f,8);i=g;return}function caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+72|0;e=d|0;P6(e,b,8,c,9);Q6(a,e,c,8);i=d;return}function daa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=l|0;P6(m,h,8,16,9);h=0;do{e=h<<3;n=l+e|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=h<<4;p=k+(o|1)|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=(q|j)-((q^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=k+(o|5)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=(o|e)-((o^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);Q6(b,m,f,8);i=g;return}function eaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=e;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+8|0]=a[e+8|0]|0;l=h+16|0;j=e+f|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;Q6(k|0,h,8,16);h=l;l=0;do{m=l<<4;e=c[h+m>>2]|0;n=l<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ca(l,f)|0;c[b+j>>2]=(o|e)-((o^e)>>>1&2139062143);e=c[h+(m|4)>>2]|0;m=k+(n|4)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[b+(j+4)>>2]=(n|e)-((n^e)>>>1&2139062143);l=l+1|0;}while((l|0)<8);i=g;return}function faa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;P6(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=(q|j)-((q^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=(q|h)-((q^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);Q6(l|0,n,8,8);n=0;do{e=n<<3;m=k+(e+8)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(n,f)|0;c[b+m>>2]=(q|h)-((q^h)>>>1&2139062143);h=e|4;e=k+(h+8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(m+4)>>2]=(h|q)-((h^q)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function gaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;P6(j,b,8,e,9);Q6(h|0,j,8,8);j=0;do{b=j<<3;k=g+(b+8)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=g+(l+8)|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function haa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;P6(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=(r|j)-((r^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=(p|e)-((p^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);Q6(m|0,n,8,8);n=0;do{h=n<<3;k=l+(h+8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;c[b+k>>2]=(p|e)-((p^e)>>>1&2139062143);e=h|4;h=l+(e+8)|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=(e|p)-((e^p)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function iaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;e7(g|0,b,8,e,8);h=0;do{j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=((n^l)>>>1&2139062143)+(n&l);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=((k^n)>>>1&2139062143)+(k&n);h=h+1|0;}while((h|0)<8);i=f;return}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;e7(a,b,c,c,8);return}function kaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;e7(g|0,b,8,e,8);h=0;do{j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=((n^l)>>>1&2139062143)+(n&l);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=((k^n)>>>1&2139062143)+(k&n);h=h+1|0;}while((h|0)<8);i=f;return}function laa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;f7(k|0,l,8,16);m=0;do{e=m<<4;h=c[l+e>>2]|0;n=m<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ca(m,f)|0;c[b+j>>2]=((o^h)>>>1&2139062143)+(o&h);h=c[l+(e|4)>>2]|0;e=k+(n|4)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(j+4)>>2]=((n^h)>>>1&2139062143)+(n&h);m=m+1|0;}while((m|0)<8);i=g;return}function maa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;e7(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=((q^j)>>>1&2139062143)+(q&j);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=((q^h)>>>1&2139062143)+(q&h);e=e+1|0;}while((e|0)<9);f7(l|0,n,8,8);n=0;do{e=n<<3;m=k+e|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(n,f)|0;c[b+m>>2]=((q^h)>>>1&2139062143)+(q&h);h=e|4;e=k+h|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(m+4)>>2]=((h^q)>>>1&2139062143)+(h&q);n=n+1|0;}while((n|0)<8);i=g;return}function naa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;e7(j,b,8,e,9);f7(h|0,j,8,8);j=0;do{b=j<<3;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;c[a+k>>2]=((m^l)>>>1&2139062143)+(m&l);l=b|4;b=g+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=((l^m)>>>1&2139062143)+(l&m);j=j+1|0;}while((j|0)<8);i=f;return}function oaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;e7(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=((r^j)>>>1&2139062143)+(r&j);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=((p^e)>>>1&2139062143)+(p&e);h=h+1|0;}while((h|0)<9);f7(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;c[b+k>>2]=((p^e)>>>1&2139062143)+(p&e);e=h|4;h=l+e|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=((e^p)>>>1&2139062143)+(e&p);n=n+1|0;}while((n|0)<8);i=g;return}function paa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+144|0;h=g|0;j=h|0;k=e;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=k;a[h+8|0]=a[e+8|0]|0;k=h+16|0;j=e+f|0;l=j|0;m=j+4|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[k>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[k+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;k=f<<1;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+40|0]=a[e+(k+8)|0]|0;l=h+48|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+56|0]=a[e+(j+8)|0]|0;k=h+64|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+72|0]=a[e+(l+8)|0]|0;j=h+80|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+88|0]=a[e+(k+8)|0]|0;l=h+96|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+104|0]=a[e+(j+8)|0]|0;k=h+112|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+120|0]=a[e+(l+8)|0]|0;j=h+128|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+136|0]=a[e+(k+8)|0]|0;f7(b,h,f,16);i=g;return}function qaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=k|0;e7(m,l,8,16,9);e=0;do{h=e<<3;n=k+h|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=e<<4;p=c[l+o>>2]|0;c[n>>2]=((p^j)>>>1&2139062143)+(p&j);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;p=c[l+(o|4)>>2]|0;c[j>>2]=((p^h)>>>1&2139062143)+(p&h);e=e+1|0;}while((e|0)<9);f7(b,m,f,8);i=g;return}function raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+72|0;e=d|0;e7(e,b,8,c,9);f7(a,e,c,8);i=d;return}function saa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=l|0;e7(m,h,8,16,9);h=0;do{e=h<<3;n=l+e|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=h<<4;p=k+(o|1)|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=((q^j)>>>1&2139062143)+(q&j);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=k+(o|5)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=((o^e)>>>1&2139062143)+(o&e);h=h+1|0;}while((h|0)<9);f7(b,m,f,8);i=g;return}function taa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=e;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+8|0]=a[e+8|0]|0;l=h+16|0;j=e+f|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;f7(k|0,h,8,16);h=l;l=0;do{m=l<<4;e=c[h+m>>2]|0;n=l<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ca(l,f)|0;c[b+j>>2]=((o^e)>>>1&2139062143)+(o&e);e=c[h+(m|4)>>2]|0;m=k+(n|4)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[b+(j+4)>>2]=((n^e)>>>1&2139062143)+(n&e);l=l+1|0;}while((l|0)<8);i=g;return}function uaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;e7(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=((q^j)>>>1&2139062143)+(q&j);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=((q^h)>>>1&2139062143)+(q&h);e=e+1|0;}while((e|0)<9);f7(l|0,n,8,8);n=0;do{e=n<<3;m=k+(e+8)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(n,f)|0;c[b+m>>2]=((q^h)>>>1&2139062143)+(q&h);h=e|4;e=k+(h+8)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(m+4)>>2]=((h^q)>>>1&2139062143)+(h&q);n=n+1|0;}while((n|0)<8);i=g;return}function vaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;e7(j,b,8,e,9);f7(h|0,j,8,8);j=0;do{b=j<<3;k=g+(b+8)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;c[a+k>>2]=((m^l)>>>1&2139062143)+(m&l);l=b|4;b=g+(l+8)|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=((l^m)>>>1&2139062143)+(l&m);j=j+1|0;}while((j|0)<8);i=f;return}function waa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;e7(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=((r^j)>>>1&2139062143)+(r&j);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=((p^e)>>>1&2139062143)+(p&e);h=h+1|0;}while((h|0)<9);f7(m|0,n,8,8);n=0;do{h=n<<3;k=l+(h+8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;c[b+k>>2]=((p^e)>>>1&2139062143)+(p&e);e=h|4;h=l+(e+8)|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(k+4)>>2]=((e^p)>>>1&2139062143)+(e&p);n=n+1|0;}while((n|0)<8);i=g;return}function xaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;P6(g|0,b,8,e,8);h=0;do{j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=j+4|0;j=b+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+o|0;o=c[j>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[j>>2]=(m|o)-((m^o)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function yaa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c;c=b;b=0;while(1){g=d[f]|0;h=f+1|0;i=d[h]|0;j=f+2|0;k=d[j]|0;l=f+3|0;m=f+4|0;a[c]=((d[c]|0)+1+(d[(16-k+((i+g|0)*20|0)+((k+g|0)*-6|0)-(d[m]|0)+(((d[l]|0)+i|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;i=c+1|0;g=d[h]|0;k=d[f]|0;n=f+5|0;a[i]=((d[i]|0)+1+(d[(16-g+(((d[j]|0)+g|0)*20|0)+(((d[l]|0)+k|0)*-6|0)-(d[n]|0)+(((d[m]|0)+k|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;k=c+2|0;g=d[f]|0;i=f+6|0;a[k]=((d[k]|0)+1+(d[((((d[l]|0)+(d[j]|0)|0)*20|0)+16-g+(((d[m]|0)+(d[h]|0)|0)*-6|0)-(d[i]|0)+(((d[n]|0)+g|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;g=c+3|0;k=f+7|0;a[g]=((d[g]|0)+1+(d[((((d[m]|0)+(d[l]|0)|0)*20|0)+16+(((d[n]|0)+(d[j]|0)|0)*-6|0)-(d[f]|0)+(((d[i]|0)+(d[h]|0)|0)*3|0)-(d[k]|0)>>5)+1404400|0]|0)|0)>>>1;g=c+4|0;o=f+8|0;a[g]=((d[g]|0)+1+(d[((((d[n]|0)+(d[m]|0)|0)*20|0)+16+(((d[i]|0)+(d[l]|0)|0)*-6|0)-(d[h]|0)+(((d[k]|0)+(d[j]|0)|0)*3|0)-(d[o]|0)>>5)+1404400|0]|0)|0)>>>1;h=c+5|0;g=d[o]|0;a[h]=((d[h]|0)+1+(d[((((d[i]|0)+(d[n]|0)|0)*20|0)+16+(((d[k]|0)+(d[m]|0)|0)*-6|0)-g-(d[j]|0)+((g+(d[l]|0)|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;g=c+6|0;j=d[k]|0;h=d[o]|0;a[g]=((d[g]|0)+1+(d[(16-j+((j+(d[i]|0)|0)*20|0)+((h+(d[n]|0)|0)*-6|0)-(d[l]|0)+(((d[m]|0)+h|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;h=c+7|0;l=d[k]|0;k=d[o]|0;o=d[i]|0;a[h]=((d[h]|0)+1+(d[(16-o+((k+l|0)*20|0)+((o+k|0)*-6|0)-(d[m]|0)+(((d[n]|0)+l|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;l=b+1|0;if((l|0)<8){f=f+e|0;c=c+e|0;b=l}else{break}}return}function zaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;P6(g|0,b,8,e,8);h=0;do{j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=b+(j+5)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+(k|4)|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(j+4)|0;j=c[o>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[o>>2]=(m|j)-((m^j)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function Aaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;Q6(k|0,l,8,16);m=0;do{e=m<<4;h=c[l+e>>2]|0;n=m<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ca(m,f)|0;p=b+j|0;q=c[p>>2]|0;r=(o|h)-((o^h)>>>1&2139062143)|0;c[p>>2]=(r|q)-((r^q)>>>1&2139062143);q=c[l+(e|4)>>2]|0;e=k+(n|4)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(j+4)|0;j=c[e>>2]|0;r=(n|q)-((n^q)>>>1&2139062143)|0;c[e>>2]=(r|j)-((r^j)>>>1&2139062143);m=m+1|0;}while((m|0)<8);i=g;return}function Baa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;P6(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=(q|j)-((q^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=(q|h)-((q^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);Q6(l|0,n,8,8);n=0;do{e=n<<3;m=k+e|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(n,f)|0;j=b+m|0;p=c[j>>2]|0;o=(q|h)-((q^h)>>>1&2139062143)|0;c[j>>2]=(o|p)-((o^p)>>>1&2139062143);p=e|4;e=k+p|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(m+4)|0;m=c[e>>2]|0;j=(p|o)-((p^o)>>>1&2139062143)|0;c[e>>2]=(j|m)-((j^m)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function Caa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;P6(j,b,8,e,9);Q6(h|0,j,8,8);j=0;do{b=j<<3;k=g+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=g+o|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(k+4)|0;k=c[b>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(n|k)-((n^k)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function Daa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;P6(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=(r|j)-((r^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=(p|e)-((p^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);Q6(m|0,n,8,8);n=0;do{h=n<<3;k=l+h|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;j=b+k|0;r=c[j>>2]|0;o=(p|e)-((p^e)>>>1&2139062143)|0;c[j>>2]=(o|r)-((o^r)>>>1&2139062143);r=h|4;h=l+r|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+r|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(k+4)|0;k=c[h>>2]|0;j=(r|o)-((r^o)>>>1&2139062143)|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function Eaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+144|0;h=g|0;j=h|0;k=e;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=k;a[h+8|0]=a[e+8|0]|0;k=h+16|0;j=e+f|0;l=j|0;m=j+4|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[k>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[k+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;k=f<<1;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+40|0]=a[e+(k+8)|0]|0;l=h+48|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+56|0]=a[e+(j+8)|0]|0;k=h+64|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+72|0]=a[e+(l+8)|0]|0;j=h+80|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+88|0]=a[e+(k+8)|0]|0;l=h+96|0;j=k+f|0;k=e+j|0;m=k|0;n=k+4|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=k;a[h+104|0]=a[e+(j+8)|0]|0;k=h+112|0;l=j+f|0;j=e+l|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[k>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[k+4>>2]=j;a[h+120|0]=a[e+(l+8)|0]|0;j=h+128|0;k=l+f|0;l=e+k|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+136|0]=a[e+(k+8)|0]|0;Qba(b,h,f,16);i=g;return}function Faa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=h;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=k|0;P6(m,l,8,16,9);e=0;do{h=e<<3;n=k+h|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=e<<4;p=c[l+o>>2]|0;c[n>>2]=(p|j)-((p^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;p=c[l+(o|4)>>2]|0;c[j>>2]=(p|h)-((p^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);Qba(b,m,f,8);i=g;return}function Gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+72|0;e=d|0;P6(e,b,8,c,9);Qba(a,e,c,8);i=d;return}function Haa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=e;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[j+4>>2]=m;a[h+8|0]=a[e+8|0]|0;m=h+16|0;j=e+f|0;n=j|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;m=l|0;P6(m,h,8,16,9);h=0;do{e=h<<3;n=l+e|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;o=h<<4;p=k+(o|1)|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=(q|j)-((q^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=k+(o|5)|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=(o|e)-((o^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);Qba(b,m,f,8);i=g;return}function Iaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+64|0;l=e;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=l;a[h+8|0]=a[e+8|0]|0;l=h+16|0;j=e+f|0;m=j|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;m=f<<1;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+40|0]=a[e+(m+8)|0]|0;n=h+48|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+56|0]=a[e+(j+8)|0]|0;m=h+64|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+72|0]=a[e+(n+8)|0]|0;j=h+80|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+88|0]=a[e+(m+8)|0]|0;n=h+96|0;j=m+f|0;m=e+j|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;a[h+104|0]=a[e+(j+8)|0]|0;m=h+112|0;n=j+f|0;j=e+n|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=j;a[h+120|0]=a[e+(n+8)|0]|0;j=h+128|0;m=n+f|0;n=e+m|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+136|0]=a[e+(m+8)|0]|0;Q6(k|0,h,8,16);h=l;l=0;do{m=l<<4;e=c[h+m>>2]|0;n=l<<3;j=k+n|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=ca(l,f)|0;p=b+j|0;q=c[p>>2]|0;r=(o|e)-((o^e)>>>1&2139062143)|0;c[p>>2]=(r|q)-((r^q)>>>1&2139062143);q=c[h+(m|4)>>2]|0;m=k+(n|4)|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(j+4)|0;j=c[m>>2]|0;r=(n|q)-((n^q)>>>1&2139062143)|0;c[m>>2]=(r|j)-((r^j)>>>1&2139062143);l=l+1|0;}while((l|0)<8);i=g;return}function Jaa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+144|0;h=g|0;j=h|0;k=i;i=i+72|0;l=i;i=i+64|0;m=h;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=k|0;P6(n,m,8,16,9);e=0;do{h=e<<3;o=k+h|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=e<<4;q=c[m+p>>2]|0;c[o>>2]=(q|j)-((q^j)>>>1&2139062143);j=k+(h|4)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;q=c[m+(p|4)>>2]|0;c[j>>2]=(q|h)-((q^h)>>>1&2139062143);e=e+1|0;}while((e|0)<9);Q6(l|0,n,8,8);n=0;do{e=n<<3;m=k+(e+8)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(n,f)|0;j=b+m|0;p=c[j>>2]|0;o=(q|h)-((q^h)>>>1&2139062143)|0;c[j>>2]=(o|p)-((o^p)>>>1&2139062143);p=e|4;e=k+(p+8)|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(m+4)|0;m=c[e>>2]|0;j=(p|o)-((p^o)>>>1&2139062143)|0;c[e>>2]=(j|m)-((j^m)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function Kaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+136|0;g=f|0;h=f+72|0;j=g|0;P6(j,b,8,e,9);Q6(h|0,j,8,8);j=0;do{b=j<<3;k=g+(b+8)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(j,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=g+(o+8)|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=h+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(k+4)|0;k=c[b>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(n|k)-((n^k)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function Laa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+144|0;h=g|0;j=h|0;k=h;l=i;i=i+72|0;m=i;i=i+64|0;n=e;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[j>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[j+4>>2]=n;a[h+8|0]=a[e+8|0]|0;n=h+16|0;j=e+f|0;o=j|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=j;a[h+24|0]=a[e+(f+8)|0]|0;j=h+32|0;n=f<<1;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+40|0]=a[e+(n+8)|0]|0;o=h+48|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+56|0]=a[e+(j+8)|0]|0;n=h+64|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+72|0]=a[e+(o+8)|0]|0;j=h+80|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+88|0]=a[e+(n+8)|0]|0;o=h+96|0;j=n+f|0;n=e+j|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;a[h+104|0]=a[e+(j+8)|0]|0;n=h+112|0;o=j+f|0;j=e+o|0;p=j|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=j;a[h+120|0]=a[e+(o+8)|0]|0;j=h+128|0;n=o+f|0;o=e+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[j>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[j+4>>2]=o;a[h+136|0]=a[e+(n+8)|0]|0;n=l|0;P6(n,h,8,16,9);h=0;do{e=h<<3;o=l+e|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;p=h<<4;q=k+(p|1)|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=(r|j)-((r^j)>>>1&2139062143);j=l+(e|4)|0;e=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;r=k+(p|5)|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[j>>2]=(p|e)-((p^e)>>>1&2139062143);h=h+1|0;}while((h|0)<9);Q6(m|0,n,8,8);n=0;do{h=n<<3;k=l+(h+8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=m+h|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(n,f)|0;j=b+k|0;r=c[j>>2]|0;o=(p|e)-((p^e)>>>1&2139062143)|0;c[j>>2]=(o|r)-((o^r)>>>1&2139062143);r=h|4;h=l+(r+8)|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+r|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(k+4)|0;k=c[h>>2]|0;j=(r|o)-((r^o)>>>1&2139062143)|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);n=n+1|0;}while((n|0)<8);i=g;return}function Maa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;Oba(g|0,b,8,e,8);h=0;do{j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function Naa(a,b,c){a=a|0;b=b|0;c=c|0;Oba(a,b,c,c,8);return}function Oaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;Oba(g|0,b,8,e,8);h=0;do{j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function Paa(a,b,c){a=a|0;b=b|0;c=c|0;Pba(a,b,c,c);return}function Qaa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+216|0;g=f|0;h=f+88|0;j=f+152|0;Oba(g|0,b+(-e|0)|0,8,e,11);Pba(h|0,b,8,e);Pba(j|0,g+8|0,8,8);g=0;do{b=g<<3;k=h+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(g,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=h+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);g=g+1|0;}while((g|0)<8);i=f;return}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+88|0;e=d|0;Oba(e|0,b+(-c|0)|0,8,c,11);Pba(a,e+8|0,c,8);i=d;return}function Saa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+216|0;g=f|0;h=f+88|0;j=f+152|0;Oba(g|0,b+(-e|0)|0,8,e,11);Pba(h|0,b+1|0,8,e);Pba(j|0,g+8|0,8,8);g=0;do{b=g<<3;k=h+b|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(g,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b|4;b=h+l|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);g=g+1|0;}while((g|0)<8);i=f;return}function Taa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=Uaa(a,b,c,d,8)|0;g=(Uaa(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(Uaa(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(Uaa(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function Uaa(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+256|0;a=g|0;h=0;while(1){j=ca(h,f)|0;k=j+1|0;l=d[e+k|0]|0;m=d[b+k|0]|0;k=(d[e+j|0]|0)-(d[b+j|0]|0)|0;n=k+l-m|0;o=h<<3;p=k-l+m|0;m=j+2|0;l=j+3|0;k=d[e+l|0]|0;q=d[b+l|0]|0;l=(d[e+m|0]|0)-(d[b+m|0]|0)|0;m=l+k-q|0;r=l-k+q|0;q=j+4|0;k=j+5|0;l=d[e+k|0]|0;s=d[b+k|0]|0;k=(d[e+q|0]|0)-(d[b+q|0]|0)|0;q=k+l-s|0;t=k-l+s|0;s=j+6|0;l=j+7|0;j=d[e+l|0]|0;k=d[b+l|0]|0;l=(d[e+s|0]|0)-(d[b+s|0]|0)|0;s=l+j-k|0;u=l-j+k|0;k=m+n|0;j=n-m|0;m=r+p|0;n=p-r|0;r=s+q|0;p=q-s|0;s=u+t|0;q=t-u|0;c[a+(o<<2)>>2]=r+k;c[a+((o|4)<<2)>>2]=k-r;c[a+((o|1)<<2)>>2]=s+m;c[a+((o|5)<<2)>>2]=m-s;c[a+((o|2)<<2)>>2]=p+j;c[a+((o|6)<<2)>>2]=j-p;c[a+((o|3)<<2)>>2]=q+n;c[a+((o|7)<<2)>>2]=n-q;q=h+1|0;if((q|0)<8){h=q}else{v=0;w=0;break}}do{h=a+(w<<2)|0;b=c[h>>2]|0;e=a+(w+8<<2)|0;f=c[e>>2]|0;q=f+b|0;n=b-f|0;f=a+(w+16<<2)|0;b=c[f>>2]|0;o=a+(w+24<<2)|0;p=c[o>>2]|0;j=p+b|0;s=b-p|0;p=a+(w+32<<2)|0;b=c[p>>2]|0;m=a+(w+40<<2)|0;r=c[m>>2]|0;k=r+b|0;u=b-r|0;r=a+(w+48<<2)|0;b=c[r>>2]|0;t=a+(w+56<<2)|0;l=c[t>>2]|0;x=l+b|0;y=b-l|0;l=j+q|0;c[h>>2]=l;h=q-j|0;c[f>>2]=h;f=s+n|0;c[e>>2]=f;e=n-s|0;c[o>>2]=e;o=x+k|0;c[p>>2]=o;p=k-x|0;c[r>>2]=p;r=y+u|0;c[m>>2]=r;m=u-y|0;c[t>>2]=m;t=o+l|0;y=l-o|0;o=r+f|0;l=f-r|0;r=p+h|0;f=h-p|0;p=e+m|0;h=e-m|0;v=((y|0)>-1?y:-y|0)+v+((t|0)>-1?t:-t|0)+((l|0)>-1?l:-l|0)+((o|0)>-1?o:-o|0)+((f|0)>-1?f:-f|0)+((r|0)>-1?r:-r|0)+((h|0)>-1?h:-h|0)+((p|0)>-1?p:-p|0)|0;w=w+1|0;}while((w|0)<8);i=g;return v|0}function Vaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=Waa(a,b,c,d,8)|0;g=(Waa(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(Waa(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(Waa(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function Waa(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+256|0;e=g|0;a=0;while(1){h=ca(a,f)|0;j=d[b+h|0]|0;k=d[b+(h+1)|0]|0;l=k+j|0;m=a<<3;n=j-k|0;k=d[b+(h+2)|0]|0;j=d[b+(h+3)|0]|0;o=j+k|0;p=k-j|0;j=d[b+(h+4)|0]|0;k=d[b+(h+5)|0]|0;q=k+j|0;r=j-k|0;k=d[b+(h+6)|0]|0;j=d[b+(h+7)|0]|0;h=j+k|0;s=k-j|0;j=o+l|0;k=l-o|0;o=p+n|0;l=n-p|0;p=h+q|0;n=q-h|0;h=s+r|0;q=r-s|0;c[e+(m<<2)>>2]=p+j;c[e+((m|4)<<2)>>2]=j-p;c[e+((m|1)<<2)>>2]=h+o;c[e+((m|5)<<2)>>2]=o-h;c[e+((m|2)<<2)>>2]=n+k;c[e+((m|6)<<2)>>2]=k-n;c[e+((m|3)<<2)>>2]=q+l;c[e+((m|7)<<2)>>2]=l-q;q=a+1|0;if((q|0)<8){a=q}else{t=0;u=0;break}}do{a=e+(u<<2)|0;b=c[a>>2]|0;f=e+(u+8<<2)|0;q=c[f>>2]|0;l=q+b|0;m=b-q|0;q=e+(u+16<<2)|0;b=c[q>>2]|0;n=e+(u+24<<2)|0;k=c[n>>2]|0;h=k+b|0;o=b-k|0;k=e+(u+32<<2)|0;b=c[k>>2]|0;p=e+(u+40<<2)|0;j=c[p>>2]|0;s=j+b|0;r=b-j|0;j=e+(u+48<<2)|0;b=c[j>>2]|0;v=e+(u+56<<2)|0;w=c[v>>2]|0;x=w+b|0;y=b-w|0;w=h+l|0;c[a>>2]=w;a=l-h|0;c[q>>2]=a;q=o+m|0;c[f>>2]=q;f=m-o|0;c[n>>2]=f;n=x+s|0;c[k>>2]=n;k=s-x|0;c[j>>2]=k;j=y+r|0;c[p>>2]=j;p=r-y|0;c[v>>2]=p;v=n+w|0;y=w-n|0;n=j+q|0;w=q-j|0;j=k+a|0;q=a-k|0;k=f+p|0;a=f-p|0;t=((y|0)>-1?y:-y|0)+t+((v|0)>-1?v:-v|0)+((w|0)>-1?w:-w|0)+((n|0)>-1?n:-n|0)+((q|0)>-1?q:-q|0)+((j|0)>-1?j:-j|0)+((a|0)>-1?a:-a|0)+((k|0)>-1?k:-k|0)|0;u=u+1|0;}while((u|0)<8);u=(c[e+128>>2]|0)+(c[e>>2]|0)|0;i=g;return t-((u|0)>-1?u:-u|0)|0}function Xaa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+128|0;h=g|0;j=a+10060|0;mf[c[j>>2]&2047](h,b,d,e);k=a+11164|0;qe[c[k>>2]&1023](h);l=a+10080|0;a=ve[c[l>>2]&4095](h)|0;mf[c[j>>2]&2047](h,b+8|0,d+8|0,e);qe[c[k>>2]&1023](h);m=(ve[c[l>>2]&4095](h)|0)+a|0;if((f|0)!=16){n=m;i=g;return n|0}f=e<<3;mf[c[j>>2]&2047](h,b+f|0,d+f|0,e);qe[c[k>>2]&1023](h);a=(ve[c[l>>2]&4095](h)|0)+m|0;m=f+8|0;mf[c[j>>2]&2047](h,b+m|0,d+m|0,e);qe[c[k>>2]&1023](h);n=a+(ve[c[l>>2]&4095](h)|0)|0;i=g;return n|0}function Yaa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;f=i;i=i+128|0;g=f|0;mf[c[a+10060>>2]&2047](g,b,d,e);qe[c[a+11164>>2]&1023](g);e=ve[c[a+10080>>2]&4095](g)|0;i=f;return e|0}function Zaa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+128|0;j=h|0;k=j|0;l=a+10060|0;mf[c[l>>2]&2047](k,d,e,f);m=a+11164|0;qe[c[m>>2]&1023](k);a=0;n=0;do{o=b[j+(n<<1)>>1]|0;p=o<<16>>16;q=o<<16>>16>-1?p:-p|0;a=(a|0)>(q|0)?a:q;n=n+1|0;}while((n|0)<64);mf[c[l>>2]&2047](k,d+8|0,e+8|0,f);qe[c[m>>2]&1023](k);n=0;q=0;do{p=b[j+(q<<1)>>1]|0;o=p<<16>>16;r=p<<16>>16>-1?o:-o|0;n=(n|0)>(r|0)?n:r;q=q+1|0;}while((q|0)<64);q=n+a|0;if((g|0)!=16){s=q;i=h;return s|0}g=f<<3;mf[c[l>>2]&2047](k,d+g|0,e+g|0,f);qe[c[m>>2]&1023](k);a=0;n=0;do{r=b[j+(n<<1)>>1]|0;o=r<<16>>16;p=r<<16>>16>-1?o:-o|0;a=(a|0)>(p|0)?a:p;n=n+1|0;}while((n|0)<64);n=g+8|0;mf[c[l>>2]&2047](k,d+n|0,e+n|0,f);qe[c[m>>2]&1023](k);k=0;m=0;do{f=b[j+(m<<1)>>1]|0;n=f<<16>>16;e=f<<16>>16>-1?n:-n|0;k=(k|0)>(e|0)?k:e;m=m+1|0;}while((m|0)<64);s=a+q+k|0;i=h;return s|0}function _aa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;g=i;i=i+128|0;h=g|0;j=h|0;mf[c[a+10060>>2]&2047](j,d,e,f);qe[c[a+11164>>2]&1023](j);j=0;a=0;do{f=b[h+(a<<1)>>1]|0;e=f<<16>>16;d=f<<16>>16>-1?e:-e|0;j=(j|0)>(d|0)?j:d;a=a+1|0;}while((a|0)<64);i=g;return j|0}function $aa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=aba(a,b,c,d,8)|0;g=(aba(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(aba(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(aba(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function aba(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+128|0;h=g|0;mf[c[a+10060>>2]&2047](h|0,d,e,f);f=0;while(1){e=h+(f<<4)|0;d=b[e>>1]|0;a=h+(f<<4)+14|0;j=b[a>>1]|0;k=j+d|0;l=h+(f<<4)+2|0;m=b[l>>1]|0;n=h+(f<<4)+12|0;o=b[n>>1]|0;p=o+m|0;q=h+(f<<4)+4|0;r=b[q>>1]|0;s=h+(f<<4)+10|0;t=b[s>>1]|0;u=t+r|0;v=h+(f<<4)+6|0;w=b[v>>1]|0;x=h+(f<<4)+8|0;y=b[x>>1]|0;z=y+w|0;A=z+k|0;B=u+p|0;C=k-z|0;z=p-u|0;u=d-j|0;j=m-o|0;o=r-t|0;t=w-y|0;y=(u>>1)+u+j+o|0;w=u-t-((o>>1)+o)|0;r=u-j-(j>>1)+t|0;u=t+(j-o)+(t>>1)|0;b[e>>1]=A+B;b[l>>1]=(u>>>2)+y;b[q>>1]=C+(z>>>1);b[v>>1]=w+(r>>>2);b[x>>1]=A-B;b[s>>1]=r-(w>>>2);b[n>>1]=(C>>>1)-z;b[a>>1]=(y>>>2)-u;u=f+1|0;if((u|0)<8){f=u}else{D=0;E=0;break}}do{f=b[h+(E<<1)>>1]|0;u=b[h+112+(E<<1)>>1]|0;y=u+f|0;a=b[h+16+(E<<1)>>1]|0;z=b[h+96+(E<<1)>>1]|0;C=z+a|0;n=b[h+32+(E<<1)>>1]|0;w=b[h+80+(E<<1)>>1]|0;r=w+n|0;s=b[h+48+(E<<1)>>1]|0;B=b[h+64+(E<<1)>>1]|0;A=B+s|0;x=A+y|0;v=r+C|0;q=y-A|0;A=C-r|0;r=f-u|0;u=a-z|0;z=n-w|0;w=s-B|0;B=(r>>1)+r+u+z|0;s=r-w-((z>>1)+z)|0;n=r-u-(u>>1)+w|0;r=w+(u-z)+(w>>1)|0;w=x+v|0;z=(r>>2)+B|0;u=q+(A>>1)|0;a=s+(n>>2)|0;f=x-v|0;v=n-(s>>2)|0;s=(q>>1)-A|0;A=(B>>2)-r|0;D=((w|0)>-1?w:-w|0)+D+((u|0)>-1?u:-u|0)+((f|0)>-1?f:-f|0)+((a|0)>-1?a:-a|0)+((s|0)>-1?s:-s|0)+((A|0)>-1?A:-A|0)+((z|0)>-1?z:-z|0)+((v|0)>-1?v:-v|0)|0;E=E+1|0;}while((E|0)<8);i=g;return D|0}function bba(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=e;i=0;j=0;k=b}else{l=0;return l|0}while(1){b=(c[6219288+((d[k]|0|256)-(d[h]|0)<<2)>>2]|0)+i+(c[6219288+((d[k+1|0]|0|256)-(d[h+1|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+2|0]|0|256)-(d[h+2|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+3|0]|0|256)-(d[h+3|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+4|0]|0|256)-(d[h+4|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+5|0]|0|256)-(d[h+5|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+6|0]|0|256)-(d[h+6|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+7|0]|0|256)-(d[h+7|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+8|0]|0|256)-(d[h+8|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+9|0]|0|256)-(d[h+9|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+10|0]|0|256)-(d[h+10|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+11|0]|0|256)-(d[h+11|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+12|0]|0|256)-(d[h+12|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+13|0]|0|256)-(d[h+13|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+14|0]|0|256)-(d[h+14|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+15|0]|0|256)-(d[h+15|0]|0)<<2)>>2]|0)|0;e=j+1|0;if((e|0)<(g|0)){h=h+f|0;i=b;j=e;k=k+f|0}else{l=b;break}}return l|0}function cba(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=e;i=0;j=0;k=b}else{l=0;return l|0}while(1){b=(c[6219288+((d[k]|0|256)-(d[h]|0)<<2)>>2]|0)+i+(c[6219288+((d[k+1|0]|0|256)-(d[h+1|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+2|0]|0|256)-(d[h+2|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+3|0]|0|256)-(d[h+3|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+4|0]|0|256)-(d[h+4|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+5|0]|0|256)-(d[h+5|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+6|0]|0|256)-(d[h+6|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+7|0]|0|256)-(d[h+7|0]|0)<<2)>>2]|0)|0;e=j+1|0;if((e|0)<(g|0)){h=h+f|0;i=b;j=e;k=k+f|0}else{l=b;break}}return l|0}function dba(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=e;i=0;j=0;k=b}else{l=0;return l|0}while(1){b=(c[6219288+((d[k]|0|256)-(d[h]|0)<<2)>>2]|0)+i+(c[6219288+((d[k+1|0]|0|256)-(d[h+1|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+2|0]|0|256)-(d[h+2|0]|0)<<2)>>2]|0)+(c[6219288+((d[k+3|0]|0|256)-(d[h+3|0]|0)<<2)>>2]|0)|0;e=j+1|0;if((e|0)<(g|0)){h=h+f|0;i=b;j=e;k=k+f|0}else{l=b;break}}return l|0}function eba(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+288|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+280|0;o=m;p=a;q=m|0;r=a+12488|0;c[r>>2]=0;s=a+10060|0;mf[c[s>>2]&2047](q,d,e,f);t=m+128|0;nrc(t|0,o|0,128)|0;u=a+14396|0;v=a+9960|0;w=a+180|0;c[w>>2]=Xe[c[u>>2]&511](p,q,0,c[v>>2]|0,n)|0;x=a+14388|0;mf[c[x>>2]&2047](p,q,0,c[v>>2]|0);q0a(q);c[n>>2]=0;n=0;a=0;do{y=(b[m+(n<<1)>>1]|0)-(b[m+(n+64<<1)>>1]|0)|0;a=(ca(y,y)|0)+a|0;n=n+1|0;}while((n|0)<64);c[r>>2]=0;mf[c[s>>2]&2047](q,d+8|0,e+8|0,f);nrc(t|0,o|0,128)|0;c[w>>2]=Xe[c[u>>2]&511](p,q,0,c[v>>2]|0,l)|0;mf[c[x>>2]&2047](p,q,0,c[v>>2]|0);q0a(q);c[l>>2]=0;l=0;n=0;do{y=(b[m+(l<<1)>>1]|0)-(b[m+(l+64<<1)>>1]|0)|0;n=(ca(y,y)|0)+n|0;l=l+1|0;}while((l|0)<64);l=n+a|0;if((g|0)!=16){z=l;i=h;return z|0}g=f<<3;c[r>>2]=0;mf[c[s>>2]&2047](q,d+g|0,e+g|0,f);nrc(t|0,o|0,128)|0;c[w>>2]=Xe[c[u>>2]&511](p,q,0,c[v>>2]|0,k)|0;mf[c[x>>2]&2047](p,q,0,c[v>>2]|0);q0a(q);c[k>>2]=0;k=0;a=0;do{n=(b[m+(k<<1)>>1]|0)-(b[m+(k+64<<1)>>1]|0)|0;a=(ca(n,n)|0)+a|0;k=k+1|0;}while((k|0)<64);k=g+8|0;c[r>>2]=0;mf[c[s>>2]&2047](q,d+k|0,e+k|0,f);nrc(t|0,o|0,128)|0;c[w>>2]=Xe[c[u>>2]&511](p,q,0,c[v>>2]|0,j)|0;mf[c[x>>2]&2047](p,q,0,c[v>>2]|0);q0a(q);c[j>>2]=0;j=0;q=0;do{v=(b[m+(j<<1)>>1]|0)-(b[m+(j+64<<1)>>1]|0)|0;q=(ca(v,v)|0)+q|0;j=j+1|0;}while((j|0)<64);z=a+l+q|0;i=h;return z|0}function fba(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+264|0;h=g|0;j=g+256|0;k=a;l=h|0;c[a+12488>>2]=0;mf[c[a+10060>>2]&2047](l,d,e,f);nrc(h+128|0,h|0,128)|0;f=a+9960|0;c[a+180>>2]=Xe[c[a+14396>>2]&511](k,l,0,c[f>>2]|0,j)|0;mf[c[a+14388>>2]&2047](k,l,0,c[f>>2]|0);q0a(l);c[j>>2]=0;j=0;l=0;do{f=(b[h+(j<<1)>>1]|0)-(b[h+(j+64<<1)>>1]|0)|0;l=(ca(f,f)|0)+l|0;j=j+1|0;}while((j|0)<64);i=g;return l|0}function gba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hba(a,b,c,d,8)|0;g=(hba(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(hba(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(hba(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function hba(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;i=i+192|0;j=h|0;k=h+128|0;l=k|0;m=i;i=i+64|0;n=m|0;o=i;i=i+4|0;i=i+7&-8;p=a;q=j|0;r=k;s=m;t=c[a+13088>>2]|0;u=e;v=u|0;w=u+4|0;u=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[l>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24;c[l+4>>2]=u;u=k+8|0;l=e+g|0;v=l|0;w=l+4|0;l=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[u>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24;c[u+4>>2]=l;l=k+16|0;u=g<<1;v=e+u|0;w=v|0;x=v+4|0;v=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;c[l>>2]=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24;c[l+4>>2]=v;v=k+24|0;l=u+g|0;w=e+l|0;x=w|0;y=w+4|0;w=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;c[v>>2]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;c[v+4>>2]=w;w=k+32|0;v=l+g|0;x=e+v|0;y=x|0;z=x+4|0;x=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;c[w>>2]=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24;c[w+4>>2]=x;x=k+40|0;w=v+g|0;y=e+w|0;z=y|0;A=y+4|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;c[x>>2]=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24;c[x+4>>2]=y;y=k+48|0;x=w+g|0;z=e+x|0;A=z|0;B=z+4|0;z=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;c[y>>2]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;c[y+4>>2]=z;z=k+56|0;k=x+g|0;y=e+k|0;e=y|0;A=y+4|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;c[z>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;c[z+4>>2]=y;y=f;z=y|0;e=y+4|0;y=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[n>>2]=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24;c[n+4>>2]=y;y=m+8|0;n=f+g|0;g=n|0;z=n+4|0;n=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;c[y>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[y+4>>2]=n;n=m+16|0;y=f+u|0;u=y|0;g=y+4|0;y=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[n>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[n+4>>2]=y;y=m+24|0;n=f+l|0;l=n|0;u=n+4|0;n=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[y>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[y+4>>2]=n;n=m+32|0;y=f+v|0;v=y|0;l=y+4|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[n>>2]=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24;c[n+4>>2]=y;y=m+40|0;n=f+w|0;w=n|0;v=n+4|0;n=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[y>>2]=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24;c[y+4>>2]=n;n=m+48|0;y=f+x|0;x=y|0;w=y+4|0;y=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;c[n>>2]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;c[n+4>>2]=y;y=m+56|0;m=f+k|0;k=m|0;f=m+4|0;m=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[y>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[y+4>>2]=m;mf[c[a+10060>>2]&2047](q,r,s,8);m=a+9960|0;y=Xe[c[a+14396>>2]&511](p,q,0,c[m>>2]|0,o)|0;c[a+180>>2]=y;k=(c[a+12488>>2]|0)==0;if(k){C=a+13104|0;D=a+13100|0;E=0;F=0}else{C=a+13096|0;D=a+13092|0;E=d[(c[a+13108>>2]|0)+((b[q>>1]|0)+256)|0]|0;F=1}f=c[C>>2]|0;C=c[D>>2]|0;do{if((y|0)<(F|0)){G=E}else{c[o>>2]=F;if((F|0)<(y|0)){D=F;n=E;x=0;while(1){w=b[j+(d[a+(D+368)|0]<<1)>>1]|0;if(w<<16>>16==0){H=x+1|0;I=n}else{v=(w<<16>>16)+64|0;if(v>>>0<128>>>0){J=d[C+(v+(x<<7))|0]|0}else{J=t}H=0;I=J+n|0}v=D+1|0;c[o>>2]=v;if((v|0)<(y|0)){D=v;n=I;x=H}else{K=I;L=H;break}}}else{K=E;L=0}x=d[a+(y+368)|0]|0;c[o>>2]=x;n=(b[j+(x<<1)>>1]|0)+64|0;if(n>>>0<128>>>0){G=(d[f+(n+(L<<7))|0]|0)+K|0;break}else{G=K+t|0;break}}}while(0);if(!((y|0)>-1)){M=a+11180|0;N=M;O=c[N>>2]|0;ef[O&4095](s,8,q);P=a+10136|0;Q=P;R=c[Q>>2]|0;S=Xe[R&511](0,s,r,8,8)|0;T=c[m>>2]|0;U=G*109|0;V=ca(U,T)|0;W=ca(V,T)|0;X=W+64|0;Y=X>>7;Z=Y+S|0;i=h;return Z|0}if(k){mf[c[a+14388>>2]&2047](p,q,0,c[m>>2]|0);M=a+11180|0;N=M;O=c[N>>2]|0;ef[O&4095](s,8,q);P=a+10136|0;Q=P;R=c[Q>>2]|0;S=Xe[R&511](0,s,r,8,8)|0;T=c[m>>2]|0;U=G*109|0;V=ca(U,T)|0;W=ca(V,T)|0;X=W+64|0;Y=X>>7;Z=Y+S|0;i=h;return Z|0}else{mf[c[a+14384>>2]&2047](p,q,0,c[m>>2]|0);M=a+11180|0;N=M;O=c[N>>2]|0;ef[O&4095](s,8,q);P=a+10136|0;Q=P;R=c[Q>>2]|0;S=Xe[R&511](0,s,r,8,8)|0;T=c[m>>2]|0;U=G*109|0;V=ca(U,T)|0;W=ca(V,T)|0;X=W+64|0;Y=X>>7;Z=Y+S|0;i=h;return Z|0}return 0}function iba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jba(a,b,c,d,8)|0;g=(jba(a,b+8|0,c+8|0,d,8)|0)+f|0;if((e|0)!=16){h=g;return h|0}e=d<<3;f=(jba(a,b+e|0,c+e|0,d,8)|0)+g|0;g=e+8|0;h=f+(jba(a,b+g|0,c+g|0,d,8)|0)|0;return h|0}function jba(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+136|0;j=h|0;k=h+128|0;l=j|0;m=c[a+13088>>2]|0;mf[c[a+10060>>2]&2047](l,e,f,g);g=Xe[c[a+14396>>2]&511](a,l,0,c[a+9960>>2]|0,k)|0;c[a+180>>2]=g;if((c[a+12488>>2]|0)==0){n=a+13104|0;o=a+13100|0;p=0;q=0}else{n=a+13096|0;o=a+13092|0;p=d[(c[a+13108>>2]|0)+((b[l>>1]|0)+256)|0]|0;q=1}l=c[n>>2]|0;n=c[o>>2]|0;if((g|0)<(q|0)){r=p;i=h;return r|0}c[k>>2]=q;if((q|0)<(g|0)){o=q;q=p;f=0;while(1){e=b[j+(d[a+(o+368)|0]<<1)>>1]|0;if(e<<16>>16==0){s=f+1|0;t=q}else{u=(e<<16>>16)+64|0;if(u>>>0<128>>>0){v=d[n+(u+(f<<7))|0]|0}else{v=m}s=0;t=v+q|0}u=o+1|0;c[k>>2]=u;if((u|0)<(g|0)){o=u;q=t;f=s}else{w=t;x=s;break}}}else{w=p;x=0}p=d[a+(g+368)|0]|0;c[k>>2]=p;k=(b[j+(p<<1)>>1]|0)+64|0;if(k>>>0<128>>>0){r=(d[l+(k+(x<<7))|0]|0)+w|0;i=h;return r|0}else{r=w+m|0;i=h;return r|0}return 0}function kba(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>1){g=c;h=b;i=0;j=1}else{k=0;return k|0}while(1){b=i;c=0;do{a=c+e|0;l=(d[h+c|0]|0)-(d[g+c|0]|0)-(d[h+a|0]|0)+(d[g+a|0]|0)|0;b=((l|0)>-1?l:-l|0)+b|0;c=c+1|0;}while((c|0)<16);c=j+1|0;if((c|0)<(f|0)){g=g+e|0;h=h+e|0;i=b;j=c}else{k=b;break}}return k|0}function lba(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>1){g=b;h=0;i=1}else{j=0;return j|0}while(1){b=h;c=0;do{a=(d[g+c|0]|0)-(d[g+(c+e)|0]|0)|0;k=c|1;l=(d[g+k|0]|0)-(d[g+(k+e)|0]|0)|0;k=c|2;m=(d[g+k|0]|0)-(d[g+(k+e)|0]|0)|0;k=c|3;n=(d[g+k|0]|0)-(d[g+(k+e)|0]|0)|0;b=((a|0)>-1?a:-a|0)+b+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)|0;c=c+4|0;}while((c|0)<16);c=i+1|0;if((c|0)<(f|0)){g=g+e|0;h=b;i=c}else{j=b;break}}return j|0}function mba(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((g|0)<=1){h=0;return h|0}e=c;b=0;i=1;j=a[c]|0;while(1){c=e+f|0;k=a[c]|0;l=(j&255)-(k&255)|0;m=(d[e+1|0]|0)-(d[e+(f+1)|0]|0)|0;n=(d[e+2|0]|0)-(d[e+(f+2)|0]|0)|0;o=(d[e+3|0]|0)-(d[e+(f+3)|0]|0)|0;p=(d[e+4|0]|0)-(d[e+(f+4)|0]|0)|0;q=(d[e+5|0]|0)-(d[e+(f+5)|0]|0)|0;r=(d[e+6|0]|0)-(d[e+(f+6)|0]|0)|0;s=(d[e+7|0]|0)-(d[e+(f+7)|0]|0)|0;t=((p|0)>-1?p:-p|0)+(((l|0)>-1?l:-l|0)+b+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0))+((q|0)>-1?q:-q|0)+((r|0)>-1?r:-r|0)+((s|0)>-1?s:-s|0)|0;s=i+1|0;if((s|0)<(g|0)){e=c;b=t;i=s;j=k}else{h=t;break}}return h|0}function nba(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>1){g=c;h=b;i=0;j=1}else{k=0;return k|0}while(1){b=i;c=0;do{a=c+e|0;l=(d[h+c|0]|0)-(d[g+c|0]|0)-(d[h+a|0]|0)+(d[g+a|0]|0)|0;b=(ca(l,l)|0)+b|0;c=c+1|0;}while((c|0)<16);c=j+1|0;if((c|0)<(f|0)){g=g+e|0;h=h+e|0;i=b;j=c}else{k=b;break}}return k|0}function oba(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>1){g=b;h=0;i=1}else{j=0;return j|0}while(1){b=h;c=0;do{a=(d[g+c|0]|0)-(d[g+(c+e)|0]|0)|0;k=ca(a,a)|0;a=c|1;l=(d[g+a|0]|0)-(d[g+(a+e)|0]|0)|0;a=ca(l,l)|0;l=c|2;m=(d[g+l|0]|0)-(d[g+(l+e)|0]|0)|0;l=ca(m,m)|0;m=c|3;n=(d[g+m|0]|0)-(d[g+(m+e)|0]|0)|0;b=k+b+a+l+(ca(n,n)|0)|0;c=c+4|0;}while((c|0)<16);c=i+1|0;if((c|0)<(f|0)){g=g+e|0;h=b;i=c}else{j=b;break}}return j|0}function pba(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)<=1){h=0;return h|0}e=c;b=0;i=1;j=a[c]|0;while(1){c=e+f|0;k=a[c]|0;l=(j&255)-(k&255)|0;m=ca(l,l)|0;l=(d[e+1|0]|0)-(d[e+(f+1)|0]|0)|0;n=ca(l,l)|0;l=(d[e+2|0]|0)-(d[e+(f+2)|0]|0)|0;o=ca(l,l)|0;l=(d[e+3|0]|0)-(d[e+(f+3)|0]|0)|0;p=m+b+n+o+(ca(l,l)|0)|0;l=(d[e+4|0]|0)-(d[e+(f+4)|0]|0)|0;o=ca(l,l)|0;l=(d[e+5|0]|0)-(d[e+(f+5)|0]|0)|0;n=ca(l,l)|0;l=(d[e+6|0]|0)-(d[e+(f+6)|0]|0)|0;m=ca(l,l)|0;l=(d[e+7|0]|0)-(d[e+(f+7)|0]|0)|0;q=o+p+n+m+(ca(l,l)|0)|0;l=i+1|0;if((l|0)<(g|0)){e=c;b=q;i=l;j=k}else{h=q;break}}return h|0}function qba(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a:do{if((h|0)>0){i=f;j=e;k=0;l=0;m=0;while(1){n=k;o=0;do{p=(d[j+o|0]|0)-(d[i+o|0]|0)|0;n=(ca(p,p)|0)+n|0;o=o+1|0;}while((o|0)<16);o=m+1|0;p=(o|0)<(h|0);if(!p){q=n;r=l;break a}s=l;t=0;u=a[j]|0;v=a[i]|0;while(1){w=t+g|0;x=t+1|0;y=a[j+x|0]|0;z=x+g|0;A=(u&255)-(d[j+w|0]|0)-(y&255)+(d[j+z|0]|0)|0;B=a[i+x|0]|0;C=(v&255)-(d[i+w|0]|0)-(B&255)+(d[i+z|0]|0)|0;D=((A|0)>-1?A:-A|0)+s-((C|0)>-1?C:-C|0)|0;if((x|0)<15){s=D;t=x;u=y;v=B}else{break}}if(p){i=i+g|0;j=j+g|0;k=n;l=D;m=o}else{q=n;r=D;break}}}else{q=0;r=0}}while(0);D=(r|0)>-1?r:-r|0;if((b|0)==0){E=D<<3;F=E+q|0;return F|0}else{E=ca(c[(c[b+4>>2]|0)+836>>2]|0,D)|0;F=E+q|0;return F|0}return 0}function rba(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a:do{if((h|0)>0){i=f;j=e;k=0;l=0;m=0;while(1){n=a[j]|0;o=a[i]|0;p=(n&255)-(o&255)|0;q=(ca(p,p)|0)+k|0;p=(d[j+1|0]|0)-(d[i+1|0]|0)|0;r=(ca(p,p)|0)+q|0;q=(d[j+2|0]|0)-(d[i+2|0]|0)|0;p=(ca(q,q)|0)+r|0;r=(d[j+3|0]|0)-(d[i+3|0]|0)|0;q=(ca(r,r)|0)+p|0;p=(d[j+4|0]|0)-(d[i+4|0]|0)|0;r=(ca(p,p)|0)+q|0;q=(d[j+5|0]|0)-(d[i+5|0]|0)|0;p=(ca(q,q)|0)+r|0;r=(d[j+6|0]|0)-(d[i+6|0]|0)|0;q=(ca(r,r)|0)+p|0;p=(d[j+7|0]|0)-(d[i+7|0]|0)|0;r=(ca(p,p)|0)+q|0;q=m+1|0;p=(q|0)<(h|0);if(p){s=l;t=0;u=n;v=o}else{w=r;x=l;break a}while(1){o=t+g|0;n=t+1|0;y=a[j+n|0]|0;z=n+g|0;A=(u&255)-(d[j+o|0]|0)-(y&255)+(d[j+z|0]|0)|0;B=a[i+n|0]|0;C=(v&255)-(d[i+o|0]|0)-(B&255)+(d[i+z|0]|0)|0;D=((A|0)>-1?A:-A|0)+s-((C|0)>-1?C:-C|0)|0;if((n|0)<7){s=D;t=n;u=y;v=B}else{break}}if(p){i=i+g|0;j=j+g|0;k=r;l=D;m=q}else{w=r;x=D;break}}}else{w=0;x=0}}while(0);D=(x|0)>-1?x:-x|0;if((b|0)==0){E=D<<3;F=E+w|0;return F|0}else{E=ca(c[(c[b+4>>2]|0)+836>>2]|0,D)|0;F=E+w|0;return F|0}return 0}function sba(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((e|0)>0){f=0;g=0}else{h=0;return h|0}while(1){i=(a[c+g|0]|0)-(b[d+(g<<1)>>1]|0)|0;j=(ca(i,i)|0)+f|0;i=g+1|0;if((i|0)<(e|0)){f=j;g=i}else{h=j;break}}return h|0}function tba(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=e-4|0;if((f|0)<0){g=0}else{h=0;while(1){i=c[d+h>>2]|0;j=b+h|0;k=c[j>>2]|0;c[j>>2]=(k&2139062143)+(i&2139062143)^(k^i)&-2139062144;i=h+4|0;if((i|0)>(f|0)){g=i;break}else{h=i}}}if((g|0)<(e|0)){l=g}else{return}do{g=b+l|0;a[g]=(a[g]|0)+(a[d+l|0]|0);l=l+1|0;}while((l|0)<(e|0));return}function uba(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;do{if((e&3|0)==0){g=f-4|0;if((g|0)<0){h=0;break}else{i=0}while(1){j=c[d+i>>2]|0;k=c[e+i>>2]|0;c[b+i>>2]=(k^j)&-2139062144^-2139062144^(j|-2139062144)-(k&2139062143);k=i+4|0;if((k|0)>(g|0)){h=k;break}else{i=k}}}else{if((f|0)>7){l=0;m=7}else{h=0;break}while(1){a[b+l|0]=(a[d+l|0]|0)-(a[e+l|0]|0);g=l|1;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|2;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|3;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|4;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|5;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);g=l|6;a[b+g|0]=(a[d+g|0]|0)-(a[e+g|0]|0);a[b+m|0]=(a[d+m|0]|0)-(a[e+m|0]|0);g=l+8|0;k=g|7;if((k|0)<(f|0)){l=g;m=k}else{h=g;break}}}}while(0);if((h|0)<(f|0)){n=h}else{return}do{a[b+n|0]=(a[d+n|0]|0)-(a[e+n|0]|0);n=n+1|0;}while((n|0)<(f|0));return}function vba(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=c[h>>2]|0;k=c[i>>2]&255;l=j&255;if((g|0)<=0){m=k;n=l;c[h>>2]=n;o=m&255;c[i>>2]=o;return}p=0;q=j&255;j=k;k=l;while(1){l=a[e+p|0]|0;r=l&255;s=k-(j&255)+r&255;do{if((q&255)>>>0>(l&255)>>>0){if(!(s>>>0>r>>>0)){t=r;break}t=s>>>0>k>>>0?k:s}else{if(!(r>>>0>s>>>0)){t=r;break}t=s>>>0>k>>>0?s:k}}while(0);s=(d[f+p|0]|0)+t|0;r=s&255;a[b+p|0]=r;u=p+1|0;v=s&255;if((u|0)<(g|0)){p=u;q=r;j=l;k=v}else{m=l;n=v;break}}c[h>>2]=n;o=m&255;c[i>>2]=o;return}function wba(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c[g>>2]|0;j=c[h>>2]&255;k=i&255;if((f|0)<=0){l=j;m=k;c[g>>2]=m;n=l&255;c[h>>2]=n;return}o=i&255;i=j;j=0;p=k;while(1){k=a[d+j|0]|0;q=k&255;r=p-(i&255)+q&255;do{if((o&255)>>>0>(k&255)>>>0){if(!(r>>>0>q>>>0)){s=q;break}s=r>>>0>p>>>0?p:r}else{if(!(q>>>0>r>>>0)){s=q;break}s=r>>>0>p>>>0?r:p}}while(0);r=a[e+j|0]|0;q=r&255;a[b+j|0]=q-s;t=j+1|0;if((t|0)<(f|0)){o=r;i=k;j=t;p=q}else{l=k;m=q;break}}c[g>>2]=m;n=l&255;c[h>>2]=n;return}function xba(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=e-1|0;if((g|0)>0){h=f;i=0;while(1){j=(d[c+i|0]|0)+h|0;a[b+i|0]=j;k=i|1;l=j+(d[c+k|0]|0)|0;a[b+k|0]=l;k=i+2|0;if((k|0)<(g|0)){h=l;i=k}else{m=l;n=k;break}}}else{m=f;n=0}if((n|0)<(e|0)){o=m;p=n}else{q=m;return q|0}while(1){m=(d[c+p|0]|0)+o|0;a[b+p|0]=m;n=p+1|0;if((n|0)<(e|0)){o=m;p=n}else{q=m;break}}return q|0}function yba(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=c[g>>2]|0;l=c[h>>2]|0;m=c[i>>2]|0;n=c[j>>2]|0;if((f|0)>0){o=0;p=k;q=l;r=m;s=n}else{t=k;u=l;v=m;w=n;c[g>>2]=t;c[h>>2]=u;c[i>>2]=v;c[j>>2]=w;return}while(1){n=o<<2;m=(d[e+n|0]|0)+r|0;l=n|1;k=(d[e+l|0]|0)+q|0;x=n|2;y=(d[e+x|0]|0)+p|0;z=n|3;A=(d[e+z|0]|0)+s|0;a[b+n|0]=m;a[b+l|0]=k;a[b+x|0]=y;a[b+z|0]=A;z=o+1|0;if((z|0)<(f|0)){o=z;p=y;q=k;r=m;s=A}else{t=y;u=k;v=m;w=A;break}}c[g>>2]=t;c[h>>2]=u;c[i>>2]=v;c[j>>2]=w;return}function zba(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)<8){e=0}else{f=0;g=8;while(1){c[a+(f<<2)>>2]=je(c[b+(f<<2)>>2]|0)|0;h=f|1;c[a+(h<<2)>>2]=je(c[b+(h<<2)>>2]|0)|0;h=f|2;c[a+(h<<2)>>2]=je(c[b+(h<<2)>>2]|0)|0;h=f|3;c[a+(h<<2)>>2]=je(c[b+(h<<2)>>2]|0)|0;h=f|4;c[a+(h<<2)>>2]=je(c[b+(h<<2)>>2]|0)|0;h=f|5;c[a+(h<<2)>>2]=je(c[b+(h<<2)>>2]|0)|0;h=f|6;c[a+(h<<2)>>2]=je(c[b+(h<<2)>>2]|0)|0;h=f|7;c[a+(h<<2)>>2]=je(c[b+(h<<2)>>2]|0)|0;h=g+8|0;if((h|0)>(d|0)){e=g;break}else{f=g;g=h}}}if((e|0)<(d|0)){i=e}else{return}do{c[a+(i<<2)>>2]=je(c[b+(i<<2)>>2]|0)|0;i=i+1|0;}while((i|0)<(d|0));return}function Aba(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;if((d|0)==0){return}else{e=a;f=c;g=d}while(1){d=g-1|0;b[e>>1]=he(b[f>>1]|0)|0;if((d|0)==0){break}else{e=e+2|0;f=f+2|0;g=d}}return}function Bba(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=0;g=0;do{h=((ca(b[d+(g<<1)>>1]|0,e)|0)+512>>10)+(b[a+(g<<1)>>1]|0)|0;i=ca(h>>6,b[c+(g<<1)>>1]|0)|0;f=((ca(i,i)|0)>>>4)+f|0;g=g+1|0;}while((g|0)<64);return f>>>2|0}function Cba(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=0;do{g=((ca(b[c+(f<<1)>>1]|0,d)|0)+512|0)>>>10;h=a+(f<<1)|0;b[h>>1]=g+(e[h>>1]|0);f=f+1|0;}while((f|0)<64);return}function Dba(a,b,d,e,f){a=a|0;b=b|0;d=+d;e=+e;f=f|0;var h=0,i=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0;h=(g[k>>2]=d,c[k>>2]|0);i=(g[k>>2]=e,c[k>>2]|0);if(d<0.0&e>0.0){j=i^-2147483648;if((f|0)>0){l=0}else{return}do{m=c[b+(l<<2)>>2]|0;if(m>>>0>h>>>0){n=h}else{n=(m^-2147483648)>>>0>j>>>0?i:m}c[a+(l<<2)>>2]=n;m=l|1;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){p=h}else{p=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=p;m=l|2;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){q=h}else{q=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=q;m=l|3;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){r=h}else{r=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=r;m=l|4;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){s=h}else{s=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=s;m=l|5;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){t=h}else{t=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=t;m=l|6;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){u=h}else{u=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=u;m=l|7;o=c[b+(m<<2)>>2]|0;if(o>>>0>h>>>0){v=h}else{v=(o^-2147483648)>>>0>j>>>0?i:o}c[a+(m<<2)>>2]=v;l=l+8|0;}while((l|0)<(f|0));return}else{if((f|0)>0){w=0}else{return}do{x=+g[b+(w<<2)>>2];if(x<d){y=d}else{y=x>e?e:x}g[a+(w<<2)>>2]=y;l=w|1;x=+g[b+(l<<2)>>2];if(x<d){z=d}else{z=x>e?e:x}g[a+(l<<2)>>2]=z;l=w|2;x=+g[b+(l<<2)>>2];if(x<d){A=d}else{A=x>e?e:x}g[a+(l<<2)>>2]=A;l=w|3;x=+g[b+(l<<2)>>2];if(x<d){B=d}else{B=x>e?e:x}g[a+(l<<2)>>2]=B;l=w|4;x=+g[b+(l<<2)>>2];if(x<d){C=d}else{C=x>e?e:x}g[a+(l<<2)>>2]=C;l=w|5;x=+g[b+(l<<2)>>2];if(x<d){D=d}else{D=x>e?e:x}g[a+(l<<2)>>2]=D;l=w|6;x=+g[b+(l<<2)>>2];if(x<d){E=d}else{E=x>e?e:x}g[a+(l<<2)>>2]=E;l=w|7;x=+g[b+(l<<2)>>2];if(x<d){F=d}else{F=x>e?e:x}g[a+(l<<2)>>2]=F;w=w+8|0;}while((w|0)<(f|0));return}}function Eba(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)==0){e=0;return e|0}else{f=a;g=c;h=d;i=0}while(1){d=h-1|0;c=(ca(b[g>>1]|0,b[f>>1]|0)|0)+i|0;if((d|0)==0){e=c;break}else{f=f+2|0;g=g+2|0;h=d;i=c}}return e|0}function Fba(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e|0)==0){g=0;return g|0}else{h=c;i=d;j=e;k=a;l=0}while(1){a=j-1|0;e=b[k>>1]|0;d=(ca(b[h>>1]|0,e)|0)+l|0;b[k>>1]=(ca(b[i>>1]|0,f)|0)+e;if((a|0)==0){g=d;break}else{h=h+2|0;i=i+2|0;j=a;k=k+2|0;l=d}}return g|0}function Gba(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f;f=a;a=b;while(1){b=c[a>>2]|0;if((b|0)<(d|0)){h=d}else{h=(b|0)>(e|0)?e:b}c[f>>2]=h;b=c[a+4>>2]|0;if((b|0)<(d|0)){i=d}else{i=(b|0)>(e|0)?e:b}c[f+4>>2]=i;b=c[a+8>>2]|0;if((b|0)<(d|0)){j=d}else{j=(b|0)>(e|0)?e:b}c[f+8>>2]=j;b=c[a+12>>2]|0;if((b|0)<(d|0)){k=d}else{k=(b|0)>(e|0)?e:b}c[f+12>>2]=k;b=c[a+16>>2]|0;if((b|0)<(d|0)){l=d}else{l=(b|0)>(e|0)?e:b}c[f+16>>2]=l;b=c[a+20>>2]|0;if((b|0)<(d|0)){m=d}else{m=(b|0)>(e|0)?e:b}c[f+20>>2]=m;b=c[a+24>>2]|0;if((b|0)<(d|0)){n=d}else{n=(b|0)>(e|0)?e:b}c[f+24>>2]=n;b=c[a+28>>2]|0;if((b|0)<(d|0)){o=d}else{o=(b|0)>(e|0)?e:b}c[f+28>>2]=o;b=g-8|0;if((b|0)==0){break}else{g=b;f=f+32|0;a=a+32|0}}return}function Hba(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d;d=c;c=0;while(1){a[d]=(a[d]|0)+(b[f>>1]&255);g=d+1|0;a[g]=(a[g]|0)+(b[f+2>>1]&255);g=d+2|0;a[g]=(a[g]|0)+(b[f+4>>1]&255);g=d+3|0;a[g]=(a[g]|0)+(b[f+6>>1]&255);g=d+4|0;a[g]=(a[g]|0)+(b[f+8>>1]&255);g=d+5|0;a[g]=(a[g]|0)+(b[f+10>>1]&255);g=d+6|0;a[g]=(a[g]|0)+(b[f+12>>1]&255);g=d+7|0;a[g]=(a[g]|0)+(b[f+14>>1]&255);g=c+1|0;if((g|0)<8){f=f+16|0;d=d+e|0;c=g}else{break}}return}function Iba(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=-f|0;if((e|0)>0){j=d-1|0;k=b;l=0;while(1){mrc(k+i|0,a[k]|0,f|0)|0;mrc(k+d|0,a[k+j|0]|0,f|0)|0;m=l+1|0;if((m|0)<(e|0)){k=k+c|0;l=m}else{break}}}l=b+i|0;i=(ca(e-1|0,c)|0)-f|0;e=b+i|0;if((h&1|0)!=0&(g|0)>0){k=(f<<1)+d|0;j=0;do{j=j+1|0;nrc(b+(-((ca(j,c)|0)+f|0)|0)|0,l|0,k)|0;}while((j|0)<(g|0))}if(!((h&2|0)!=0&(g|0)>0)){return}h=(f<<1)+d|0;d=0;do{d=d+1|0;nrc(b+((ca(d,c)|0)+i)|0,e|0,h)|0;}while((d|0)<(g|0));return}function Jba(a){a=a|0;mrc(a|0,0,128)|0;return}function Kba(a){a=a|0;mrc(a|0,0,768)|0;return}function Lba(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=d>>>1;d=a;a=c;c=0;while(1){b[d>>1]=b[a>>1]|0;b[d+2>>1]=b[a+2>>1]|0;b[d+4>>1]=b[a+4>>1]|0;b[d+6>>1]=b[a+6>>1]|0;b[d+8>>1]=b[a+8>>1]|0;b[d+10>>1]=b[a+10>>1]|0;b[d+12>>1]=b[a+12>>1]|0;b[d+14>>1]=b[a+14>>1]|0;f=c+1|0;if((f|0)<8){d=d+16|0;a=a+(e<<1)|0;c=f}else{break}}return}function Mba(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0;f=a;a=c;c=0;while(1){b[f>>1]=d[a]|0;b[f+2>>1]=d[a+1|0]|0;b[f+4>>1]=d[a+2|0]|0;b[f+6>>1]=d[a+3|0]|0;b[f+8>>1]=d[a+4|0]|0;b[f+10>>1]=d[a+5|0]|0;b[f+12>>1]=d[a+6|0]|0;b[f+14>>1]=d[a+7|0]|0;g=c+1|0;if((g|0)<8){f=f+16|0;a=a+e|0;c=g}else{break}}return}function Nba(a,b){a=a|0;b=b|0;l8(a,b);return}function Oba(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=c;i=b;j=0}else{return}while(1){b=h+1|0;c=h+2|0;a[i]=a[(8-(d[h-1|0]|0)-(d[c]|0)+(((d[b]|0)+(d[h]|0)|0)*9|0)>>4)+1404400|0]|0;k=h+3|0;a[i+1|0]=a[(8-(d[h]|0)-(d[k]|0)+(((d[c]|0)+(d[b]|0)|0)*9|0)>>4)+1404400|0]|0;l=h+4|0;a[i+2|0]=a[(8-(d[b]|0)-(d[l]|0)+(((d[k]|0)+(d[c]|0)|0)*9|0)>>4)+1404400|0]|0;b=h+5|0;a[i+3|0]=a[(8-(d[c]|0)-(d[b]|0)+(((d[l]|0)+(d[k]|0)|0)*9|0)>>4)+1404400|0]|0;c=h+6|0;a[i+4|0]=a[(8-(d[k]|0)-(d[c]|0)+(((d[b]|0)+(d[l]|0)|0)*9|0)>>4)+1404400|0]|0;k=h+7|0;a[i+5|0]=a[(8-(d[l]|0)-(d[k]|0)+(((d[c]|0)+(d[b]|0)|0)*9|0)>>4)+1404400|0]|0;l=h+8|0;a[i+6|0]=a[(8-(d[b]|0)-(d[l]|0)+(((d[k]|0)+(d[c]|0)|0)*9|0)>>4)+1404400|0]|0;a[i+7|0]=a[(8-(d[c]|0)-(d[h+9|0]|0)+(((d[l]|0)+(d[k]|0)|0)*9|0)>>4)+1404400|0]|0;k=j+1|0;if((k|0)<(g|0)){h=h+f|0;i=i+e|0;j=k}else{break}}return}function Pba(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=e<<1;q=e*3|0;r=e<<2;s=e*5|0;t=e*6|0;u=e*7|0;v=0;w=c;c=b;while(1){b=d[w]|0;x=d[w+f|0]|0;y=d[w+h|0]|0;z=d[w+i|0]|0;A=d[w+j|0]|0;B=d[w+k|0]|0;C=d[w+l|0]|0;D=d[w+m|0]|0;E=d[w+n|0]|0;F=d[w+o|0]|0;a[c]=a[(8-(d[w+g|0]|0)-y+((x+b|0)*9|0)>>4)+1404400|0]|0;a[c+e|0]=a[(8-b-z+((y+x|0)*9|0)>>4)+1404400|0]|0;a[c+p|0]=a[(8-x-A+((z+y|0)*9|0)>>4)+1404400|0]|0;a[c+q|0]=a[(8-y-B+((A+z|0)*9|0)>>4)+1404400|0]|0;a[c+r|0]=a[(8-z-C+((B+A|0)*9|0)>>4)+1404400|0]|0;a[c+s|0]=a[(8-A-D+((C+B|0)*9|0)>>4)+1404400|0]|0;a[c+t|0]=a[(8-B-E+((D+C|0)*9|0)>>4)+1404400|0]|0;a[c+u|0]=a[(8-C-F+((E+D|0)*9|0)>>4)+1404400|0]|0;D=v+1|0;if((D|0)<8){v=D;w=w+1|0;c=c+1|0}else{break}}return}function Qba(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=e<<1;o=e*3|0;p=e<<2;q=e*5|0;r=e*6|0;s=e*7|0;t=0;u=c;c=b;while(1){b=d[u]|0;v=d[u+f|0]|0;w=d[u+g|0]|0;x=d[u+h|0]|0;y=d[u+i|0]|0;z=d[u+j|0]|0;A=d[u+k|0]|0;B=d[u+l|0]|0;C=d[u+m|0]|0;D=16-w|0;a[c]=((d[c]|0)+1+(d[(D+((v+b|0)*20|0)+((w+b|0)*-6|0)-y+((x+v|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;E=c+e|0;F=16-v|0;a[E]=((d[E]|0)+1+(d[(F+((w+v|0)*20|0)+((x+b|0)*-6|0)-z+((y+b|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;E=c+n|0;G=16-b|0;a[E]=((d[E]|0)+1+(d[(G+((x+w|0)*20|0)+((y+v|0)*-6|0)-A+((z+b|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;b=c+o|0;a[b]=((d[b]|0)+1+(d[(G+((y+x|0)*20|0)+((z+w|0)*-6|0)-B+((A+v|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;v=c+p|0;a[v]=((d[v]|0)+1+(d[(F+((z+y|0)*20|0)+((A+x|0)*-6|0)-C+((B+w|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;w=c+q|0;a[w]=((d[w]|0)+1+(d[(D+((A+z|0)*20|0)-C+((B+y|0)*-6|0)+((C+x|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;D=c+r|0;a[D]=((d[D]|0)+1+(d[(16-x-B+((B+A|0)*20|0)+((C+z|0)*-6|0)+((C+y|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;x=c+s|0;a[x]=((d[x]|0)+1+(d[(16-y-A+((B+z|0)*3|0)+((C+A|0)*-6|0)+((C+B|0)*20|0)>>5)+1404400|0]|0)|0)>>>1;B=t+1|0;if((B|0)<8){t=B;u=u+1|0;c=c+1|0}else{break}}return}function Rba(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;g=f<<1;h=f*3|0;i=f<<2;j=f*5|0;k=f*6|0;l=f*7|0;m=f<<3;n=f*9|0;o=f*10|0;p=f*11|0;q=f*12|0;r=f*13|0;s=f*14|0;t=f*15|0;u=f<<4;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=e<<3;C=e*9|0;D=e*10|0;E=e*11|0;F=e*12|0;G=e*13|0;H=e*14|0;I=e*15|0;J=0;K=c;c=b;while(1){b=d[K]|0;L=d[K+f|0]|0;M=d[K+g|0]|0;N=d[K+h|0]|0;O=d[K+i|0]|0;P=d[K+j|0]|0;Q=d[K+k|0]|0;R=d[K+l|0]|0;S=d[K+m|0]|0;T=d[K+n|0]|0;U=d[K+o|0]|0;V=d[K+p|0]|0;W=d[K+q|0]|0;X=d[K+r|0]|0;Y=d[K+s|0]|0;Z=d[K+t|0]|0;_=d[K+u|0]|0;$=16-M|0;a[c]=((d[c]|0)+1+(d[($+((L+b|0)*20|0)+((M+b|0)*-6|0)-O+((N+L|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;aa=c+e|0;ba=16-L|0;a[aa]=((d[aa]|0)+1+(d[(ba+((M+L|0)*20|0)+((N+b|0)*-6|0)-P+((O+b|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;aa=c+v|0;ca=16-b|0;a[aa]=((d[aa]|0)+1+(d[(ca+((N+M|0)*20|0)+((O+L|0)*-6|0)-Q+((P+b|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;b=c+w|0;a[b]=((d[b]|0)+1+(d[(ca+((O+N|0)*20|0)+((P+M|0)*-6|0)-R+((Q+L|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;L=c+x|0;a[L]=((d[L]|0)+1+(d[(ba+((P+O|0)*20|0)+((Q+N|0)*-6|0)-S+((R+M|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;M=c+y|0;a[M]=((d[M]|0)+1+(d[($+((Q+P|0)*20|0)+((R+O|0)*-6|0)-T+((S+N|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;$=c+z|0;a[$]=((d[$]|0)+1+(d[(16-N+((R+Q|0)*20|0)+((S+P|0)*-6|0)-U+((T+O|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;N=c+A|0;a[N]=((d[N]|0)+1+(d[(16-O+((S+R|0)*20|0)+((T+Q|0)*-6|0)-V+((U+P|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;O=c+B|0;a[O]=((d[O]|0)+1+(d[(16-P+((T+S|0)*20|0)+((U+R|0)*-6|0)-W+((V+Q|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;P=c+C|0;a[P]=((d[P]|0)+1+(d[(16-Q+((U+T|0)*20|0)+((V+S|0)*-6|0)-X+((W+R|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;Q=c+D|0;a[Q]=((d[Q]|0)+1+(d[(16-R+((V+U|0)*20|0)+((W+T|0)*-6|0)-Y+((X+S|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;R=c+E|0;a[R]=((d[R]|0)+1+(d[(16-S+((W+V|0)*20|0)+((X+U|0)*-6|0)-Z+((Y+T|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;S=c+F|0;a[S]=((d[S]|0)+1+(d[(16-T+((X+W|0)*20|0)+((Y+V|0)*-6|0)-_+((Z+U|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;T=c+G|0;a[T]=((d[T]|0)+1+(d[(16-U+((Y+X|0)*20|0)-_+((Z+W|0)*-6|0)+((_+V|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;U=c+H|0;a[U]=((d[U]|0)+1+(d[(16-V-Z+((Z+Y|0)*20|0)+((_+X|0)*-6|0)+((_+W|0)*3|0)>>5)+1404400|0]|0)|0)>>>1;V=c+I|0;a[V]=((d[V]|0)+1+(d[(16-W-Y+((Z+X|0)*3|0)+((_+Y|0)*-6|0)+((_+Z|0)*20|0)>>5)+1404400|0]|0)|0)>>>1;Z=J+1|0;if((Z|0)<16){J=Z;K=K+1|0;c=c+1|0}else{break}}return}function Sba(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:do{if(f>>>0<480>>>0){g=0}else{h=a[e+3|0]|0;i=(h&255)>>>7;j=a[e+451|0]|0;k=j&31;l=(i|0)==1;m=(k|0)==0;if(l&m){if(!((a[e+4|0]&7)==0)){g=1516648;break}}n=(b|0)==0;do{if(!((k|0)!=31|n)){if((c[b+52>>2]|0)!=892488787){break}if((c[b+128>>2]|0)!=720){break}if((c[b+132>>2]|0)==576){g=1516648;break a}}}while(0);do{if(!((k|0)!=0|n)){o=c[b+52>>2]|0;if(!((o|0)==1685288548|(o|0)==1129727043)){break}if((c[b+128>>2]|0)!=720){break}if((c[b+132>>2]|0)==576){g=1516532;break a}}}while(0);n=(i|0)==0;if((i|k|0)==0){g=1516416;break}if(l&m){g=1516532;break}if(n&(k|0)==4){g=1516764;break}if(l&(k|0)==4){g=1516880;break}if(n&(k|0)==20){g=1516996;break}if(l&(k|0)==20){g=1517112;break}if(n&(k|0)==24){g=1517228;break}if(l){if((k|0)==24){g=1517344;break}if((k|0)==1){g=1517460;break}}if((d|0)!=0){if((c[d+8>>2]|0)==(f|0)){g=d;break}}if(!((h&127)==63&j<<24>>24==-1)){g=0;break}g=1516416+(i*116|0)|0}}while(0);return g|0}function Tba(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;do{if(e>>>0<480>>>0){f=0}else{g=a[d+3|0]|0;h=(g&255)>>>7;i=a[d+451|0]|0;j=i&31;k=(h|0)==1;l=k&(j|0)==0;if(l){if(!((a[d+4|0]&7)==0)){f=1516648;break}f=(j|h|0)==0?1516416:1516532;break}m=(h|0)==0;n=(j|h|0)==0;if(n|l){f=n?1516416:1516532;break}n=(j|0)==4;if(m&n){f=1516764;break}if(k&n){f=1516880;break}n=(j|0)==20;if(m&n){f=1516996;break}if(k&n){f=1517112;break}n=(j|0)==24;if(m&n){f=1517228;break}if(k){if(n){f=1517344;break}if((j|0)==1){f=1517460;break}}if((b|0)!=0){if((c[b+8>>2]|0)==(e|0)){f=b;break}}if(!((g&127)==63&i<<24>>24==-1)){f=0;break}f=1516416+(h*116|0)|0}}while(0);return f|0}function Uba(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+128|0;d=a+132|0;do{if((c[b>>2]|0)==0){if((c[d>>2]|0)!=0){e=d;f=b;break}e=a+124|0;f=a+120|0}else{e=d;f=b}}while(0);b=c[e>>2]|0;e=c[f>>2]|0;f=a+140|0;a=0;a:while(1){d=1516416+(a*116|0)|0;do{if((b|0)==(c[1516448+(a*116|0)>>2]|0)){if((c[f>>2]|0)!=(c[1516480+(a*116|0)>>2]|0)){break}if((e|0)==(c[1516452+(a*116|0)>>2]|0)){g=d;h=9;break a}}}while(0);d=a+1|0;if(d>>>0<10>>>0){a=d}else{g=0;h=9;break}}if((h|0)==9){return g|0}return 0}function Vba(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=0;do{f=c[1516452+(e*116|0)>>2]|0;g=c[1516448+(e*116|0)>>2]|0;h=mKb(c[1516480+(e*116|0)>>2]|0)|0;j=c[1516440+(e*116|0)>>2]|0;k=c[1516436+(e*116|0)>>2]|0;KIb(a,b,2365408,(l=i,i=i+40|0,c[l>>2]=f,c[l+8>>2]=g,c[l+16>>2]=h,c[l+24>>2]=j,c[l+32>>2]=k,l)|0);i=l;e=e+1|0;}while(e>>>0<10>>>0);i=d;return}function Wba(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0;e=i;i=i+8|0;g=e|0;h=c[b+60>>2]|0;c[g>>2]=d;b=f+12|0;do{if((c[b>>2]|0)!=0){if((c[f+16>>2]|0)==0){j=-1}else{break}i=e;return j|0}}while(0);a[d]=15;a[d+1|0]=16;k=d+2|0;y=256;a[k]=y;y=y>>8;a[k+1|0]=y;k=d+4|0;a[d+6|0]=30;l=h;h=(c[l>>2]<<4|11)&255;m=d+8|0;c[g>>2]=m;a[d+7|0]=h;if((c[b>>2]|0)==0){n=m}else{h=f+16|0;o=0;p=m;while(1){c[g>>2]=p+1;a[p]=o;m=c[g>>2]|0;c[g>>2]=m+1;a[m]=-1;m=he(c[c[(c[h>>2]|0)+(o<<2)>>2]>>2]&65535|0)|0;q=c[g>>2]|0;y=m;a[q]=y;y=y>>8;a[q+1|0]=y;q=(c[g>>2]|0)+2|0;c[g>>2]=q;m=q;y=he(c[(c[(c[h>>2]|0)+(o<<2)>>2]|0)+4>>2]&65535|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[g>>2]|0)+2|0;c[g>>2]=m;q=o+1|0;if(q>>>0<(c[b>>2]|0)>>>0){o=q;p=m}else{n=m;break}}}p=k;y=he(65534-k+n&65535|0)|0;a[p]=y;y=y>>8;a[p+1|0]=y;a:do{if((c[b>>2]|0)!=0){p=f+16|0;n=0;b:do{k=c[(c[(c[p>>2]|0)+(n<<2)>>2]|0)+16>>2]|0;do{if((k|0)<5){r=7}else{if((k|0)<17){r=6;break}if((k|0)<257){r=5}else{j=-1;s=25;break b}}}while(0);k=c[g>>2]|0;c[g>>2]=k+1;a[k]=15;k=c[g>>2]|0;c[g>>2]=k+1;a[k]=18;k=c[g>>2]|0;y=256;a[k]=y;y=y>>8;a[k+1|0]=y;k=c[g>>2]|0;o=k+2|0;c[g>>2]=k+5;a[k+4|0]=n;k=c[g>>2]|0;c[g>>2]=k+1;a[k]=15;if((c[(c[(c[p>>2]|0)+(n<<2)>>2]|0)+16>>2]|0)>0){k=(1<<r|31)&255;h=0;do{m=c[g>>2]|0;c[g>>2]=m+1;a[m]=h;m=c[g>>2]|0;c[g>>2]=m+1;a[m]=k;m=c[(c[(c[(c[p>>2]|0)+(n<<2)>>2]|0)+24>>2]|0)+(h<<2)>>2]|0;q=m>>>16&255;t=m>>>8&255;u=m&255;v=c[g>>2]|0;c[g>>2]=v+1;a[v]=((u*100|0)+16896+(t*516|0)+(q*263|0)|0)>>>10;v=c[g>>2]|0;c[g>>2]=v+1;a[v]=(((u*-73|0)+511+(t*-377|0)+(q*450|0)|0)>>>10)+128;v=c[g>>2]|0;c[g>>2]=v+1;a[v]=(((u*450|0)+511+(t*-298|0)+(q*-152|0)|0)>>>10)+128;q=c[g>>2]|0;c[g>>2]=q+1;a[q]=m>>>24^255;h=h+1|0;}while((h|0)<(c[(c[(c[p>>2]|0)+(n<<2)>>2]|0)+16>>2]|0))}h=o;y=he(65534-o+(c[g>>2]|0)&65535|0)|0;a[h]=y;y=y>>8;a[h+1|0]=y;n=n+1|0;w=c[b>>2]|0;}while(n>>>0<w>>>0);if((s|0)==25){i=e;return j|0}if((w|0)==0){break}else{x=0}do{n=c[(c[(c[p>>2]|0)+(x<<2)>>2]|0)+16>>2]|0;if((n|0)<5){z=1}else{if((n|0)<17){z=2}else{j=-1;s=25;break}}n=c[g>>2]|0;c[g>>2]=n+1;a[n]=15;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=17;n=c[g>>2]|0;y=256;a[n]=y;y=y>>8;a[n+1|0]=y;n=c[g>>2]|0;h=n+2|0;k=x&255;c[g>>2]=n+5;a[n+4|0]=k;n=(c[l>>2]<<4|7)&255;m=c[g>>2]|0;c[g>>2]=m+1;a[m]=n;n=he(c[(c[(c[p>>2]|0)+(x<<2)>>2]|0)+8>>2]&65535|0)|0;m=c[g>>2]|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[g>>2]|0)+2|0;c[g>>2]=m;n=m;y=he(c[(c[(c[p>>2]|0)+(x<<2)>>2]|0)+12>>2]&65535|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;n=c[g>>2]|0;c[g>>2]=n+3;a[n+2|0]=z<<5|z<<2|3;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=k;k=c[g>>2]|0;c[g>>2]=k+1;a[k]=0;k=c[g>>2]|0;c[g>>2]=k+1;a[k]=3;k=he(x&65535|0)|0;n=c[g>>2]|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;n=c[g>>2]|0;c[g>>2]=n+3;a[n+2|0]=0;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=0;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=-16;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=0;n=h;y=he(65534-h+(c[g>>2]|0)&65535|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;x=x+1|0;A=c[b>>2]|0;}while(x>>>0<A>>>0);if((s|0)==25){i=e;return j|0}if((A|0)==0){break}else{B=0}c:while(1){n=c[(c[(c[p>>2]|0)+(B<<2)>>2]|0)+16>>2]|0;do{if((n|0)<5){C=254}else{if((n|0)<17){C=252;break}if((n|0)<257){C=250}else{j=-1;break c}}}while(0);n=c[g>>2]|0;c[g>>2]=n+1;a[n]=15;n=c[g>>2]|0;c[g>>2]=n+1;a[n]=19;n=c[g>>2]|0;y=256;a[n]=y;y=y>>8;a[n+1|0]=y;n=c[g>>2]|0;o=n+2|0;h=n+4|0;c[g>>2]=h;n=h;y=he(B&65535|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;n=c[g>>2]|0;h=(c[l>>2]<<4|1)&255;c[g>>2]=n+3;a[n+2|0]=h;h=c[g>>2]|0;n=h+4|0;c[g>>2]=n;k=c[(c[p>>2]|0)+(B<<2)>>2]|0;m=c[k+8>>2]|0;pe[C&1023](g,c[k+20>>2]|0,m<<1,m,c[k+12>>2]>>1);k=c[g>>2]|0;m=c[(c[p>>2]|0)+(B<<2)>>2]|0;q=c[m+8>>2]|0;pe[C&1023](g,(c[m+20>>2]|0)+q|0,q<<1,q,c[m+12>>2]>>1);m=k;k=h;y=he(m-n&65535|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;k=h+2|0;y=he((c[g>>2]|0)-m&65535|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;k=o;y=he(65534-o+(c[g>>2]|0)&65535|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;B=B+1|0;if(!(B>>>0<(c[b>>2]|0)>>>0)){break a}}i=e;return j|0}}while(0);b=c[g>>2]|0;c[g>>2]=b+1;a[b]=15;b=c[g>>2]|0;c[g>>2]=b+1;a[b]=-128;b=c[g>>2]|0;y=256;a[b]=y;y=y>>8;a[b+1|0]=y;b=c[g>>2]|0;c[g>>2]=b+4;B=b+2|0;y=0;a[B]=y;y=y>>8;a[B+1|0]=y;c[l>>2]=(c[l>>2]|0)+1&15;j=(c[g>>2]|0)-d|0;i=e;return j|0}function Xba(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=c[b>>2]|0;if((g|0)<=0){i=h;c[b>>2]=i;return}j=(f|0)>0;k=h;h=0;l=d;while(1){d=k+1|0;a[k]=16;do{if(j){m=d;n=0;o=6;p=0;while(1){q=a[l+p|0]|0;r=q&255;s=p;do{s=s+1|0;if((s|0)>=(f|0)){break}}while((a[l+s|0]|0)==q<<24>>24);t=s-p|0;u=q<<24>>24==0;a:do{if(u&(t|0)==2){do{if((o-2|0)<0){v=4}else{w=o-4|0;if((w|0)<0){v=6;break}x=1<<w|n;w=o-6|0;if((w|0)>=0){y=2;z=w;A=x;B=m;break a}a[m]=x;y=2;z=6;A=0;B=m+1|0;break a}}while(0);a[m]=n;y=2;z=v-2|0;A=1<<v;B=m+1|0}else{x=t-3|0;if(x>>>0<8>>>0){w=o-2|0;do{if((w|0)<0){a[m]=n;C=4;D=x>>>2<<6|128;E=18}else{F=(x>>2|2)<<w|n;G=o-4|0;if((G|0)<0){a[m]=F;C=6;D=0;E=18;break}H=F|(x&3)<<G;G=o-6|0;if((G|0)>=0){I=G;J=H;K=m;break}a[m]=H;y=t;z=4;A=r<<6;B=m+1|0;break a}}while(0);if((E|0)==18){E=0;I=C-2|0;J=(x&3)<<C|D;K=m+1|0}w=r<<I|J;H=I-2|0;if((H|0)>=0){y=t;z=H;A=w;B=K;break}a[K]=w;y=t;z=6;A=0;B=K+1|0;break}w=t-12|0;if(w>>>0<16>>>0){do{if((o-2|0)<0){L=4;E=26}else{H=o-4|0;if((H|0)<0){L=6;E=26;break}G=2<<H|n;H=o-6|0;if((H|0)>=0){M=H;N=G;O=m;E=29;break}a[m]=G;P=4;Q=w>>>2<<6;R=m;E=31}}while(0);if((E|0)==26){E=0;a[m]=n;M=L-2|0;N=2<<L;O=m+1|0;E=29}do{if((E|0)==29){E=0;x=w>>2<<M|N;G=M-2|0;if((G|0)<0){a[O]=x;P=6;Q=0;R=O;E=31;break}H=x|(w&3)<<G;G=M-4|0;if((G|0)>=0){S=G;T=H;U=O;break}a[O]=H;y=t;z=4;A=r<<6;B=O+1|0;break a}}while(0);if((E|0)==31){E=0;S=P-2|0;T=(w&3)<<P|Q;U=R+1|0}H=r<<S|T;G=S-2|0;if((G|0)>=0){y=t;z=G;A=H;B=U;break}a[U]=H;y=t;z=6;A=0;B=U+1|0;break}if((t|0)<=28){H=r<<o|n;G=o-2|0;if((G|0)<0){a[m]=H;V=6;W=0;X=m+1|0}else{V=G;W=H;X=m}if(!u){y=1;z=V;A=W;B=X;break}H=1<<V|W;G=V-2|0;if((G|0)>=0){y=1;z=G;A=H;B=X;break}a[X]=H;y=1;z=6;A=0;B=X+1|0;break}H=(t|0)>284?284:t;G=H-29|0;do{if((o-2|0)<0){Y=4;E=39}else{x=o-4|0;if((x|0)<0){Y=6;E=39;break}F=3<<x|n;x=o-6|0;if((x|0)>=0){Z=x;_=F;$=m;E=42;break}a[m]=F;aa=4;ba=G&-64;ca=m;E=44}}while(0);if((E|0)==39){E=0;a[m]=n;Z=Y-2|0;_=3<<Y;$=m+1|0;E=42}do{if((E|0)==42){E=0;w=G>>6<<Z|_;F=Z-2|0;if((F|0)<0){a[$]=w;aa=6;ba=0;ca=$;E=44;break}x=w|(G>>>4&3)<<F;F=Z-4|0;if((F|0)>=0){da=F;ea=x;fa=$;E=47;break}a[$]=x;ga=4;ha=G>>>2<<6&192;ia=$;E=49}}while(0);if((E|0)==44){E=0;da=aa-2|0;ea=(G>>>4&3)<<aa|ba;fa=ca+1|0;E=47}do{if((E|0)==47){E=0;x=(G>>>2&3)<<da|ea;F=da-2|0;if((F|0)<0){a[fa]=x;ga=6;ha=0;ia=fa;E=49;break}w=x|(G&3)<<F;F=da-4|0;if((F|0)>=0){ja=F;ka=w;la=fa;break}a[fa]=w;y=H;z=4;A=r<<6;B=fa+1|0;break a}}while(0);if((E|0)==49){E=0;ja=ga-2|0;ka=(G&3)<<ga|ha;la=ia+1|0}w=r<<ja|ka;F=ja-2|0;if((F|0)>=0){y=H;z=F;A=w;B=la;break}a[la]=w;y=H;z=6;A=0;B=la+1|0}}while(0);r=y+p|0;if((r|0)<(f|0)){m=B;n=A;o=z;p=r}else{break}}p=A&255;if((z-2|z-4|0)<0){a[B]=p;ma=B+1|0;na=0;E=65;break}o=z-6|0;if((o|0)<0){a[B]=p;oa=B+1|0;break}else{if((o|0)==6){oa=B;break}else{ma=B;na=p;E=65;break}}}else{ma=d;na=0;E=65}}while(0);if((E|0)==65){E=0;a[ma]=na;oa=ma+1|0}d=oa+1|0;a[oa]=-16;p=h+1|0;if((p|0)<(g|0)){k=d;h=p;l=l+e|0}else{i=d;break}}c[b>>2]=i;return}function Yba(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;h=c[b>>2]|0;if((g|0)<=0){i=h;c[b>>2]=i;return}j=(f|0)>0;k=0;l=h;h=d;while(1){d=l+1|0;a[l]=17;do{if(j){m=0;n=4;o=0;p=d;while(1){q=a[h+o|0]|0;r=q&255;s=o;do{s=s+1|0;if((s|0)>=(f|0)){break}}while((a[h+s|0]|0)==q<<24>>24);t=s-o|0;u=q<<24>>24==0;a:do{if(u&(t|0)==2){v=n-4|0;if((v|0)<0){a[p]=m;w=p+1|0;x=2;y=0;z=208;break}A=13<<v|m;v=n-8|0;if((v|0)>=0){w=p;x=2;y=v;z=A;break}a[p]=A;w=p+1|0;x=2;y=4;z=0}else{do{if(u){if(!((t-3|0)>>>0<7>>>0)){break}A=n-4|0;if((A|0)<0){a[p]=m;w=p+1|0;x=t;y=0;z=(t<<4)-32|0;break a}v=t-2<<A|m;A=n-8|0;if((A|0)>=0){w=p;x=t;y=A;z=v;break a}a[p]=v;w=p+1|0;x=t;y=4;z=0;break a}}while(0);if((t-4|0)>>>0<4>>>0){v=n-4|0;do{if((v|0)<0){a[p]=m;B=p+1|0;C=((t<<4)+64|r)&255}else{A=t+4<<v|m;D=n-8|0;if((D|0)<0){a[p]=A;w=p+1|0;x=t;y=0;z=r<<4;break a}else{E=A|r<<D;D=n-12|0;if((D|0)<0){B=p;C=E&255;break}else{w=p;x=t;y=D;z=E;break a}}}}while(0);a[B]=C;w=B+1|0;x=t;y=4;z=0;break}v=t-9|0;if(v>>>0<16>>>0){E=n-4|0;do{if((E|0)<0){a[p]=m;F=p+1|0;G=(t+23|224)&255}else{D=14<<E|m;A=n-8|0;if((A|0)<0){a[p]=D;H=p+1|0;I=((t<<4)+112|r)&255}else{J=v<<A|D;D=n-12|0;if((D|0)<0){F=p;G=J&255;break}A=J|r<<D;D=n-16|0;if((D|0)<0){H=p;I=A&255}else{w=p;x=t;y=D;z=A;break a}}a[H]=I;w=H+1|0;x=t;y=4;z=0;break a}}while(0);a[F]=G;w=F+1|0;x=t;y=0;z=r<<4;break}if((t|0)<=24){v=r<<n|m;E=n-4|0;if((E|0)<0){a[p]=v;K=p+1|0;L=4;M=0}else{K=p;L=E;M=v}if(!u){w=K;x=1;y=L;z=M;break}v=12<<L|M;E=L-4|0;if((E|0)>=0){w=K;x=1;y=E;z=v;break}a[K]=v;w=K+1|0;x=1;y=4;z=0;break}v=(t|0)>280?280:t;E=v-25|0;A=n-4|0;b:do{if((A|0)<0){a[p]=m;N=p+1|0;O=(E>>>4|240)&255;P=40}else{D=15<<A|m;J=n-8|0;do{if((J|0)<0){a[p]=D;Q=p+1|0;R=E&255}else{S=E>>4<<J|D;T=n-12|0;if((T|0)<0){N=p;O=S&255;P=40;break b}U=S|(E&15)<<T;T=n-16|0;if((T|0)<0){Q=p;R=U&255;break}S=U|r<<T;T=n-20|0;if((T|0)<0){V=p;W=S&255;break b}else{w=p;x=v;y=T;z=S;break a}}}while(0);a[Q]=R;w=Q+1|0;x=v;y=0;z=r<<4;break a}}while(0);if((P|0)==40){P=0;a[N]=O;V=N+1|0;W=(E<<4|r)&255}a[V]=W;w=V+1|0;x=v;y=4;z=0}}while(0);r=x+o|0;if((r|0)<(f|0)){m=z;n=y;o=r;p=w}else{break}}p=z&255;if((y-4|0)<0){a[w]=p;X=0;Y=w+1|0}else{o=y-8|0;if((o|0)<0){Z=p;_=w;P=54;break}if((o|0)==4){$=w;break}else{X=p;Y=w}}a[Y]=X;$=Y+1|0}else{Z=0;_=d;P=54}}while(0);if((P|0)==54){P=0;a[_]=Z;$=_+1|0}d=$+1|0;a[$]=-16;p=k+1|0;if((p|0)<(g|0)){k=p;l=d;h=h+e|0}else{i=d;break}}c[b>>2]=i;return}function Zba(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=c[b>>2]|0;if((g|0)<=0){i=h;c[b>>2]=i;return}if((f|0)>0){j=h;k=0;l=d}else{d=g*3|0;m=h;n=0;while(1){a[m]=18;a[m+1|0]=0;a[m+2|0]=0;o=n+1|0;if((o|0)<(g|0)){m=m+3|0;n=o}else{break}}i=h+d|0;c[b>>2]=i;return}while(1){a[j]=18;d=j+1|0;h=0;while(1){n=a[l+h|0]|0;m=h;do{m=m+1|0;if((m|0)>=(f|0)){break}}while((a[l+m|0]|0)==n<<24>>24);o=m-h|0;p=n<<24>>24==0;do{if((o|0)!=1|p){if(p){q=(o|0)>127?127:o;a[d]=0;a[d+1|0]=q;r=q;s=d+2|0;break}if((o|0)>2){q=(o|0)>127?127:o;a[d]=0;a[d+1|0]=q+128;a[d+2|0]=n;r=q;s=d+3|0;break}q=d+1|0;a[d]=n;if((o|0)!=2){r=1;s=q;break}a[q]=n;r=2;s=d+2|0}else{a[d]=n;r=1;s=d+1|0}}while(0);n=r+h|0;if((n|0)<(f|0)){d=s;h=n}else{break}}a[s]=0;h=s+2|0;a[s+1|0]=0;d=k+1|0;if((d|0)<(g|0)){j=h;k=d;l=l+e|0}else{i=h;break}}c[b>>2]=i;return}function _ba(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;e=c[a+60>>2]|0;f=a+96|0;g=c[f>>2]|0;do{if((g|0)==0){h=4}else{j=c[a+100>>2]|0;if((j|0)<4){h=4;break}if(!(((j|0)%5|0|0)==0|(j|0)==4)){h=4;break}if((j|0)>5){KIb(a,24,2590648,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=c[f>>2]|0}else{l=g}j=l;c[e>>2]=(he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535;j=l+2|0;c[e+4>>2]=(he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535}}while(0);if((h|0)==4){KIb(a,24,2618040,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;c[e>>2]=-1;c[e+4>>2]=-1}c[e+8>>2]=-1;c[2355932]=-1;c[2356210]=0;c[2355934]=0;c[2355935]=-1;c[2355936]=-16777216;c[2355937]=-8421505;c[2355938]=0;e=1;do{k=(e&1|0)!=0;if((e|0)<8){m=(e&4|0)!=0?255:0;n=(e&2|0)!=0?255:0;o=k?255:0}else{m=(e&4|0)!=0?127:0;n=(e&2|0)!=0?127:0;o=k?127:0}c[9423752+(e<<2)>>2]=o<<16|n<<8|m|-16777216;e=e+1|0;}while((e|0)<16);c[2355954]=0;e=o;o=n;n=m;m=0;k=1;while(1){do{if((k|0)<8){p=63;q=(k&4|0)!=0?255:0;r=(k&2|0)!=0?255:0;s=(k&1|0)!=0?255:0}else{a=k&136;if((a|0)==136){p=255;q=((k&4|0)!=0?43:0)+((k&64|0)!=0?85:0)|0;r=((k&2|0)!=0?43:0)+((k&32|0)!=0?85:0)|0;s=((k&1|0)!=0?43:0)+((k&16|0)!=0?85:0)|0;break}else if((a|0)==128){p=255;q=((k&4|0)!=0?170:127)+((k&64|0)!=0?85:0)|0;r=((k&2|0)!=0?170:127)+((k&32|0)!=0?85:0)|0;s=((k&1|0)!=0?170:127)+((k&16|0)!=0?85:0)|0;break}else if((a|0)==8){p=127;q=((k&4|0)!=0?85:0)|((k&64|0)!=0?170:0);r=((k&2|0)!=0?85:0)|((k&32|0)!=0?170:0);s=((k&1|0)!=0?85:0)|((k&16|0)!=0?170:0);break}else if((a|0)==0){p=255;q=((k&4|0)!=0?85:0)|((k&64|0)!=0?170:0);r=((k&2|0)!=0?85:0)|((k&32|0)!=0?170:0);s=((k&1|0)!=0?85:0)|((k&16|0)!=0?170:0);break}else{p=m;q=n;r=o;s=e;break}}}while(0);c[9423816+(k<<2)>>2]=r<<8|s<<16|q|p<<24;a=k+1|0;if((a|0)<256){e=s;o=r;n=q;m=p;k=a}else{break}}i=b;return 0}function $ba(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;h=i;i=i+8|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=b+60|0;m=c[g>>2]|0;n=e;if((l|0)<7){o=-1;i=h;return o|0}if((a[k]|0)!=15){o=-1;i=h;return o|0}p=k+l|0;l=k;q=m;r=b;s=b+680|0;t=b+120|0;u=b+124|0;v=m+4|0;m=k;k=0;w=l;x=1;a:while(1){if(!x){y=k;z=w;A=126;break}B=d[m+1|0]|0;C=m+2|0;D=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;C=m+4|0;E=(d[C]|d[C+1|0]<<8)<<16>>16;C=he(E|0)|0;F=C&65535;G=m+6|0;if((p-G|0)<(F|0)){o=-1;A=129;break}H=c[q>>2]|0;if((D|0)==(H|0)){A=8}else{I=c[v>>2]|0;if((D|0)==(I|0)|(H|0)==-1|(I|0)==-1){A=8}else{J=k}}b:do{if((A|0)==8){A=0;switch(B|0){case 18:{I=m+(F+6)|0;H=d[G]|0;D=(d[m+7|0]|0)>>>4;K=m+8|0;L=(c[g>>2]|0)+20|0;M=L;while(1){N=c[M>>2]|0;if((N|0)==0){A=83;break}if((c[N>>2]|0)==(H|0)){O=N;break}else{M=N+1112|0}}if((A|0)==83){A=0;M=hJb(1116)|0;N=M;nrc(M|0,9423728,1116)|0;c[M>>2]=H;c[M+4>>2]=-1;c[M+1112>>2]=c[L>>2];c[L>>2]=N;O=N}N=O+4|0;c:do{if((c[N>>2]|0)!=(D|0)){c[N>>2]=D;if(!((C&65535)>>>0>6>>>0)){break}M=K;P=m+12|0;while(1){Q=d[M]|0;R=d[M+1|0]|0;if((R&224|0)==0){break}S=M+2|0;if((R&1|0)==0){T=d[S]|0;U=d[M+3|0]|0;V=P;W=T&252;X=(T<<2&12|U>>>6)<<4;Y=U<<6&192;Z=U<<2&240}else{V=M+6|0;W=d[S]|0;X=d[M+3|0]|0;Y=d[M+5|0]|0;Z=d[P]|0}S=(W|0)==0?255:Y;U=Z-128|0;T=X-128|0;_=(W*1192|0)-19072|0;$=d[((T*1634|0)+512+_>>10)+1404400|0]|0;aa=d[((U*-401|0)+512+(T*-832|0)+_>>10)+1404400|0]|0;T=d[((U*2066|0)+512+_>>10)+1404400|0]|0;_=(R&128|0)==0;U=R&64;ba=(U|0)==0;da=R&32;ea=(da|0)==0;if(((U>>>6)+(R>>>7)+(da>>>5)|0)>1){if((c[s>>2]|0)>0){o=-1094995529;A=129;break a}}do{if(_){if(!ba){c[O+24+(Q<<2)>>2]=($<<16|S<<24|aa<<8|T)^-16777216;break}if(ea){break}c[O+88+(Q<<2)>>2]=($<<16|S<<24|aa<<8|T)^-16777216}else{c[O+8+(Q<<2)>>2]=($<<16|S<<24|aa<<8|T)^-16777216}}while(0);T=V+4|0;if(T>>>0<I>>>0){M=V;P=T}else{break c}}KIb(r,16,2123080,(fa=i,i=i+8|0,c[fa>>2]=R,fa)|0);i=fa}}while(0);J=k|4;break b;break};case 16:{I=c[g>>2]|0;K=m+(F+6)|0;do{if(!(E<<16>>16==0)){D=d[m+7|0]|0;N=D>>>4;L=I+8|0;if((c[L>>2]|0)==(N|0)){break}c[I+12>>2]=d[G]|0;c[L>>2]=N;do{if(((D>>>2&3)-1|0)>>>0<2>>>0){N=I+16|0;L=c[N>>2]|0;H=I+24|0;if((L|0)!=0){P=L;do{c[N>>2]=c[P+44>>2];L=P+40|0;M=c[L>>2]|0;if((M|0)!=0){T=M;do{M=c[T>>2]|0;aa=H;while(1){ga=c[aa>>2]|0;if((ga|0)==0){break}if((c[ga>>2]|0)==(M|0)){A=17;break}else{aa=ga+16|0}}do{if((A|0)==17){A=0;aa=ga+12|0;M=aa;while(1){S=c[M>>2]|0;ha=(S|0)!=0;ia=S+28|0;if(ha&(S|0)!=(T|0)){M=ia}else{break}}if(!ha){break}c[M>>2]=c[ia>>2];if((c[aa>>2]|0)==0){ja=H}else{break}while(1){S=c[ja>>2]|0;ka=S+16|0;if((S|0)==(ga|0)){break}else{ja=ka}}c[ja>>2]=c[ka>>2];kJb(ga)}}while(0);c[L>>2]=c[T+24>>2];kJb(T);T=c[L>>2]|0;}while((T|0)!=0)}kJb(c[P+28>>2]|0);kJb(P);P=c[N>>2]|0;}while((P|0)!=0)}P=c[H>>2]|0;if((P|0)!=0){N=P;do{c[H>>2]=c[N+16>>2];kJb(N);N=c[H>>2]|0;}while((N|0)!=0)}N=I+20|0;H=c[N>>2]|0;if((H|0)==0){break}else{la=H}do{c[N>>2]=c[la+1112>>2];kJb(la);la=c[N>>2]|0;}while((la|0)!=0)}}while(0);D=I+28|0;N=c[D>>2]|0;c[j>>2]=N;c[D>>2]=0;if((C&65535)>>>0>7>>>0){H=G;while(1){P=d[H+2|0]|0;T=H+4|0;L=j;while(1){aa=c[L>>2]|0;if((aa|0)==0){A=36;break}if((c[aa>>2]|0)==(P|0)){ma=aa;break}L=aa+12|0}if((A|0)==36){A=0;ma=pJb(16)|0}c[ma>>2]=P;aa=T;c[ma+4>>2]=(he((d[aa]|d[aa+1|0]<<8)<<16>>16|0)|0)&65535;aa=H+6|0;M=aa;c[ma+8>>2]=(he((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535;M=ma+12|0;c[L>>2]=c[M>>2];c[M>>2]=c[D>>2];c[D>>2]=ma;if((H+13|0)>>>0<K>>>0){H=aa}else{break}}na=c[j>>2]|0}else{na=N}if((na|0)==0){break}else{oa=na}while(1){H=c[oa+12>>2]|0;kJb(oa);if((H|0)==0){break}else{oa=H}}c[j>>2]=0}}while(0);J=k|1;break b;break};case 19:{K=c[g>>2]|0;I=G;N=(he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535;I=K+24|0;while(1){pa=c[I>>2]|0;if((pa|0)==0){break}if((c[pa>>2]|0)==(N|0)){A=105;break}else{I=pa+16|0}}do{if((A|0)==105){A=0;I=d[m+8|0]|0;N=I>>>2&3;K=I>>>1&1;if((N|0)!=0){KIb(r,16,2365376,(fa=i,i=i+8|0,c[fa>>2]=N,fa)|0);i=fa;break}N=m+9|0;I=(he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535;N=m+11|0;H=(d[N]|d[N+1|0]<<8)<<16>>16;N=(he(H|0)|0)&65535;D=m+13|0;if((I+7+N|0)>(F|0)){KIb(r,16,2454888,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;break}aa=c[pa+12>>2]|0;if((aa|0)==0){break}M=H<<16>>16==0;H=M?D:m+(I+13)|0;S=M?I:N;N=aa;do{cca(b,N,D,I,0,K);cca(b,N,H,S,1,K);N=c[N+28>>2]|0;}while((N|0)!=0)}}while(0);J=k|8;break b;break};case 128:{bca(c[g>>2]|0,n);c[f>>2]=1;J=k|16;break b;break};case 17:{N=c[g>>2]|0;K=m+(F+6)|0;do{if(!((C&65535)>>>0<10>>>0)){S=m+7|0;H=d[G]|0;I=N+16|0;D=I;while(1){aa=c[D>>2]|0;if((aa|0)==0){A=45;break}if((c[aa>>2]|0)==(H|0)){qa=aa;break}else{D=aa+44|0}}if((A|0)==45){A=0;D=pJb(48)|0;aa=D;c[D>>2]=H;c[D+4>>2]=-1;c[D+44>>2]=c[I>>2];c[I>>2]=aa;qa=aa}aa=(d[S]|0)>>>3&1;D=m+8|0;M=(he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=qa+8|0;c[D>>2]=M;$=m+10|0;Q=(he((d[$]|d[$+1|0]<<8)<<16>>16|0)|0)&65535;$=qa+12|0;c[$>>2]=Q;ea=ca(Q,M)|0;M=qa+32|0;if((ea|0)==(c[M>>2]|0)){ra=aa}else{aa=qa+28|0;kJb(c[aa>>2]|0);ea=ca(c[$>>2]|0,c[D>>2]|0)|0;c[M>>2]=ea;c[aa>>2]=hJb(ea)|0;c[qa+36>>2]=0;ra=1}ea=m+13|0;aa=1<<((d[m+12|0]|0)>>>2&7);D=qa+16|0;c[D>>2]=aa;do{if((aa-2|0)>>>0>6>>>0){KIb(r,16,2640760,(fa=i,i=i+8|0,c[fa>>2]=aa,fa)|0);i=fa;c[D>>2]=4;c[qa+20>>2]=d[ea]|0;sa=m+16|0;ta=d[m+15|0]|0;A=53}else{c[qa+20>>2]=d[ea]|0;if((aa|0)==8){$=a[m+14|0]|0;c[qa+24>>2]=$&255;ua=m+16|0;va=$;break}$=m+16|0;Q=d[m+15|0]|0;if((aa|0)==4){sa=$;ta=Q;A=53;break}ba=Q>>>2&3;c[qa+24>>2]=ba;ua=$;va=ba&255}}while(0);if((A|0)==53){A=0;aa=ta>>>4;c[qa+24>>2]=aa;ua=sa;va=aa&255}if((ra|0)!=0){mrc(c[qa+28>>2]|0,va|0,c[M>>2]|0)|0}aa=qa+40|0;ea=c[aa>>2]|0;if((ea|0)!=0){D=N+24|0;S=ea;do{ea=c[S>>2]|0;I=D;while(1){wa=c[I>>2]|0;if((wa|0)==0){break}if((c[wa>>2]|0)==(ea|0)){A=62;break}else{I=wa+16|0}}do{if((A|0)==62){A=0;I=wa+12|0;ea=I;while(1){L=c[ea>>2]|0;xa=(L|0)!=0;ya=L+28|0;if(xa&(L|0)!=(S|0)){ea=ya}else{break}}if(!xa){break}c[ea>>2]=c[ya>>2];if((c[I>>2]|0)==0){za=D}else{break}while(1){L=c[za>>2]|0;Aa=L+16|0;if((L|0)==(wa|0)){break}else{za=Aa}}c[za>>2]=c[Aa>>2];kJb(wa)}}while(0);c[aa>>2]=c[S+24>>2];kJb(S);S=c[aa>>2]|0;}while((S|0)!=0)}if(!((ua+5|0)>>>0<K>>>0)){break}S=N+24|0;D=ua;while(1){M=D;I=(he((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535;M=D+2|0;ea=S;while(1){L=c[ea>>2]|0;if((L|0)==0){A=74;break}if((c[L>>2]|0)==(I|0)){Ba=L;break}else{ea=L+16|0}}if((A|0)==74){A=0;ea=pJb(20)|0;L=ea;c[ea>>2]=I;c[ea+16>>2]=c[S>>2];c[S>>2]=L;Ba=L}L=Ba+8|0;c[L>>2]=(d[M]|0)>>>6;ea=pJb(32)|0;T=ea;c[ea>>2]=I;c[ea+4>>2]=H;P=M;c[ea+8>>2]=(he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&4095;P=D+4|0;c[ea+12>>2]=(he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&4095;P=D+6|0;do{if(((c[L>>2]|0)-1|0)>>>0<2>>>0){ba=D+7|0;if(!(ba>>>0<K>>>0)){Ca=P;break}c[ea+16>>2]=d[P]|0;c[ea+20>>2]=d[ba]|0;Ca=D+8|0}else{Ca=P}}while(0);c[ea+24>>2]=c[aa>>2];c[aa>>2]=T;P=Ba+12|0;c[ea+28>>2]=c[P>>2];c[P>>2]=T;if((Ca+5|0)>>>0<K>>>0){D=Ca}else{break}}}}while(0);J=k|2;break b;break};case 20:{K=(c[g>>2]|0)+32|0;N=c[K>>2]|0;if((C&65535)>>>0<5>>>0){J=k;break b}D=m+7|0;aa=d[G]|0;H=aa>>>4;if((N|0)==0){S=pJb(20)|0;P=S;c[K>>2]=P;if((S|0)==0){J=k;break b}else{Da=P}}else{if((c[N>>2]|0)==(H|0)){J=k;break b}else{Da=N}}c[Da>>2]=H;H=Da+4|0;c[H>>2]=0;N=Da+8|0;c[N>>2]=0;P=D;D=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)+1|0;P=Da+12|0;c[P>>2]=D;S=m+11|0;K=m+9|0;L=Da+16|0;c[L>>2]=((he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535)+1;if((c[t>>2]|0)==0){A=119}else{if((c[u>>2]|0)==0){A=119}}if((A|0)==119){A=0;c[t>>2]=D;c[u>>2]=c[L>>2]}if((C&65535)>>>0<13>>>0){J=k;break b}if((aa&8|0)==0){J=k;break b}aa=S;S=(he((d[aa]|d[aa+1|0]<<8)<<16>>16|0)|0)&65535;c[H>>2]=S;H=m+13|0;c[P>>2]=1-S+((he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535);H=m+15|0;S=(he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;c[N>>2]=S;N=m+17|0;c[L>>2]=1-S+((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535);J=k;break b;break};default:{J=k;break b}}}}while(0);C=m+(F+6)|0;G=C;if((p-G|0)<=5){y=J;z=G;A=126;break}m=C;k=J;w=G;x=(a[C]|0)==15}if((A|0)==126){if(!((y|0)!=15|(e|0)==0)){bca(c[g>>2]|0,n);c[f>>2]=1}o=z-l|0;i=h;return o|0}else if((A|0)==129){i=h;return o|0}return 0}function aca(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[a+60>>2]|0;a=b+16|0;d=c[a>>2]|0;e=b+24|0;if((d|0)!=0){f=d;do{c[a>>2]=c[f+44>>2];d=f+40|0;g=c[d>>2]|0;if((g|0)!=0){h=g;do{g=c[h>>2]|0;i=e;while(1){j=c[i>>2]|0;if((j|0)==0){break}if((c[j>>2]|0)==(g|0)){k=6;break}else{i=j+16|0}}do{if((k|0)==6){k=0;i=j+12|0;g=i;while(1){l=c[g>>2]|0;m=(l|0)!=0;n=l+28|0;if(m&(l|0)!=(h|0)){g=n}else{break}}if(!m){break}c[g>>2]=c[n>>2];if((c[i>>2]|0)==0){o=e}else{break}while(1){l=c[o>>2]|0;p=l+16|0;if((l|0)==(j|0)){break}else{o=p}}c[o>>2]=c[p>>2];kJb(j)}}while(0);c[d>>2]=c[h+24>>2];kJb(h);h=c[d>>2]|0;}while((h|0)!=0)}kJb(c[f+28>>2]|0);kJb(f);f=c[a>>2]|0;}while((f|0)!=0)}f=c[e>>2]|0;if((f|0)!=0){a=f;do{c[e>>2]=c[a+16>>2];kJb(a);a=c[e>>2]|0;}while((a|0)!=0)}a=b+20|0;e=c[a>>2]|0;if((e|0)!=0){f=e;do{c[a>>2]=c[f+1112>>2];kJb(f);f=c[a>>2]|0;}while((f|0)!=0)}mJb(b+32|0);f=b+28|0;b=c[f>>2]|0;if((b|0)==0){return 0}else{q=b}do{c[f>>2]=c[q+12>>2];kJb(q);q=c[f>>2]|0;}while((q|0)!=0);return 0}function bca(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[a+32>>2]|0;c[b+8>>2]=(c[a+12>>2]|0)*1e3|0;if((d|0)==0){e=0;f=0}else{e=c[d+8>>2]|0;f=c[d+4>>2]|0}d=b+12|0;c[d>>2]=0;g=a+28|0;h=c[g>>2]|0;if((h|0)==0){return}i=a+16|0;j=h;h=0;while(1){k=c[j>>2]|0;l=i;while(1){m=c[l>>2]|0;if((m|0)==0){n=h;break}if((c[m>>2]|0)==(k|0)){o=8;break}else{l=m+44|0}}do{if((o|0)==8){o=0;if((c[m+36>>2]|0)==0){n=h;break}l=h+1|0;c[d>>2]=l;n=l}}while(0);l=c[j+12>>2]|0;if((l|0)==0){break}else{j=l;h=n}}if((n|0)==0){return}h=b+16|0;c[h>>2]=pJb(n<<2)|0;if((c[d>>2]|0)!=0){n=0;do{b=pJb(100)|0;c[(c[h>>2]|0)+(n<<2)>>2]=b;n=n+1|0;}while(n>>>0<(c[d>>2]|0)>>>0)}d=c[g>>2]|0;if((d|0)==0){return}g=a+16|0;n=a+20|0;a=0;b=d;while(1){d=c[b>>2]|0;j=g;while(1){p=c[j>>2]|0;if((p|0)==0){q=a;break}if((c[p>>2]|0)==(d|0)){o=19;break}else{j=p+44|0}}do{if((o|0)==19){o=0;if((c[p+36>>2]|0)==0){q=a;break}j=c[(c[h>>2]|0)+(a<<2)>>2]|0;c[j>>2]=(c[b+4>>2]|0)+f;c[j+4>>2]=(c[b+8>>2]|0)+e;d=p+8|0;c[j+8>>2]=c[d>>2];c[j+12>>2]=c[p+12>>2];m=p+16|0;c[j+16>>2]=1<<c[m>>2];c[j+84>>2]=1;c[j+52>>2]=c[d>>2];d=c[p+20>>2]|0;i=n;while(1){l=c[i>>2]|0;if((l|0)==0){r=0;break}if((c[l>>2]|0)==(d|0)){r=l;break}else{i=l+1112|0}}i=(r|0)==0?9423728:r;d=c[m>>2]|0;if((d|0)==2){s=i+8|0}else if((d|0)==8){s=i+88|0}else{s=i+24|0}i=pJb(1024)|0;c[j+24>>2]=i;nrc(i|0,s|0,4<<c[m>>2])|0;i=p+32|0;d=hJb(c[i>>2]|0)|0;c[j+20>>2]=d;nrc(d|0,c[p+28>>2]|0,c[i>>2]|0)|0;q=a+1|0}}while(0);i=c[b+12>>2]|0;if((i|0)==0){break}else{a=q;b=i}}return}function cca(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;k=i;i=i+8|0;l=k|0;m=l;n=i;i=i+4|0;i=i+7&-8;o=n;p=n;q=i;i=i+16|0;r=c[e+4>>2]|0;s=(c[b+60>>2]|0)+16|0;while(1){t=c[s>>2]|0;if((t|0)==0){u=0;break}if((c[t>>2]|0)==(r|0)){u=t;break}else{s=t+44|0}}s=f+g|0;c[l>>2]=252184320;c[n>>2]=-7833856;r=q|0;nrc(r|0,1515888,16)|0;if((u|0)==0){i=k;return}t=c[u+28>>2]|0;c[u+36>>2]=1;v=e+8|0;if((g|0)<=0){i=k;return}g=u+12|0;w=b;b=u+16|0;x=u+8|0;u=s;y=(j|0)==1;j=l;l=m+1|0;z=m+2|0;A=m+3|0;m=f;f=c[v>>2]|0;B=(c[e+12>>2]|0)+h|0;a:while(1){C=a[m]|0;if(!(C<<24>>24==-16)){D=c[x>>2]|0;if((f|0)>=(D|0)){E=9;break}}F=c[g>>2]|0;if((B|0)>=(F|0)){E=11;break}h=m+1|0;e=C&255;b:do{switch(e|0){case 16:{G=c[b>>2]|0;if((G|0)==4){H=j}else if((G|0)==8){H=o}else{H=0}G=c[x>>2]|0;I=u-h<<3;J=I>>>0>2147483639>>>0|(h|0)==0;K=J?0:h;L=J?8:I+8|0;J=K;M=je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0;c:do{if((I|0)>0&(f|0)<(G|0)){J=(H|0)==0;N=0;O=t+((ca(G,B)|0)+f)|0;P=f;Q=M;d:while(1){R=Q>>>30;S=N+2|0;T=L>>>0>S>>>0?S:L;do{if((R|0)==0){S=((T|0)<(L|0))+T|0;U=K+(S>>>3)|0;if(((d[K+(T>>>3)|0]|0)&128>>>((T&7)>>>0)|0)!=0){V=U;W=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(S&7)>>>29;V=S+3|0;X=L>>>0>V>>>0?V:L;V=K+(X>>>3)|0;Y=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(X&7)>>>30;V=X+2|0;X=L>>>0>V>>>0?V:L;if(y&(Y|0)==1){Z=P+3+W|0;_=O;$=X;break}if(J){aa=Y&255}else{aa=a[H+Y|0]|0}if((P|0)>=(G|0)){Z=P;_=O;$=X;break}Y=P-G|0;V=-3-W|0;ba=((V|0)>-1?-4-V|0:-3)-W|0;W=Y>>>0>ba>>>0?Y:ba;ba=-W|0;mrc(O|0,aa|0,ba|0)|0;Z=P-W|0;_=O+ba|0;$=X;break}X=((S|0)<(L|0))+S|0;if(((d[U]|0)&128>>>((S&7)>>>0)|0)!=0){if(J){da=0}else{da=a[H]|0}a[O]=da;Z=P+1|0;_=O+1|0;$=X;break}S=K+(X>>>3)|0;U=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(X&7)>>>30;S=X+2|0;ea=L>>>0>S>>>0?S:L;if((U|0)==2){S=K+(ea>>>3)|0;X=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(ea&7)>>>28;S=ea+4|0;ba=L>>>0>S>>>0?S:L;S=K+(ba>>>3)|0;W=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(ba&7)>>>30;S=ba+2|0;ba=L>>>0>S>>>0?S:L;if(y&(W|0)==1){Z=P+12+X|0;_=O;$=ba;break}if(J){fa=W&255}else{fa=a[H+W|0]|0}if((P|0)>=(G|0)){Z=P;_=O;$=ba;break}W=P-G|0;S=-12-X|0;Y=((S|0)>-1?-13-S|0:-12)-X|0;X=W>>>0>Y>>>0?W:Y;Y=-X|0;mrc(O|0,fa|0,Y|0)|0;Z=P-X|0;_=O+Y|0;$=ba;break}else if((U|0)==1){if(J){ga=0}else{ga=a[H]|0}if((P|0)>=(G|0)){Z=P;_=O;$=ea;break}ba=(P-G|0)==-1?-1:-2;Y=-ba|0;mrc(O|0,ga|0,Y|0)|0;Z=P-ba|0;_=O+Y|0;$=ea;break}else if((U|0)==3){U=K+(ea>>>3)|0;Y=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(ea&7)>>>24;U=ea+8|0;ba=L>>>0>U>>>0?U:L;U=K+(ba>>>3)|0;X=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(ba&7)>>>30;U=ba+2|0;ba=L>>>0>U>>>0?U:L;if(y&(X|0)==1){Z=P+29+Y|0;_=O;$=ba;break}if(J){ha=X&255}else{ha=a[H+X|0]|0}if((P|0)>=(G|0)){Z=P;_=O;$=ba;break}X=P-G|0;U=-29-Y|0;W=((U|0)>-1?-30-U|0:-29)-Y|0;Y=X>>>0>W>>>0?X:W;W=-Y|0;mrc(O|0,ha|0,W|0)|0;Z=P-Y|0;_=O+W|0;$=ba;break}else{break d}}else{do{if(y&(R|0)==1){ia=O}else{if(J){a[O]=R;ia=O+1|0;break}else{a[O]=a[H+R|0]|0;ia=O+1|0;break}}}while(0);Z=P+1|0;_=ia;$=T}}while(0);T=K+($>>>3)|0;R=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<($&7);if(($|0)<(I|0)&(Z|0)<(G|0)){N=$;O=_;P=Z;Q=R}else{ja=$;ka=Z;la=R;break c}}ma=B;na=P;oa=m+((ea+7>>3)+1)|0;break b}else{ja=0;ka=f;la=M}}while(0);M=ja+6|0;if(!(la>>>0<67108864>>>0)){KIb(0,16,2146928,(pa=i,i=i+1|0,i=i+7&-8,c[pa>>2]=0,pa)|0);i=pa}ma=B;na=ka;oa=m+(((L>>>0>M>>>0?M:L)+7>>3)+1)|0;break};case 34:{a[r]=a[h]|0;a[q+1|0]=a[m+2|0]|0;a[q+2|0]=a[m+3|0]|0;a[q+3|0]=a[m+4|0]|0;a[q+4|0]=a[m+5|0]|0;a[q+5|0]=a[m+6|0]|0;a[q+6|0]=a[m+7|0]|0;a[q+7|0]=a[m+8|0]|0;a[q+8|0]=a[m+9|0]|0;a[q+9|0]=a[m+10|0]|0;a[q+10|0]=a[m+11|0]|0;a[q+11|0]=a[m+12|0]|0;a[q+12|0]=a[m+13|0]|0;a[q+13|0]=a[m+14|0]|0;a[q+14|0]=a[m+15|0]|0;a[q+15|0]=a[m+16|0]|0;ma=B;na=f;oa=m+17|0;break};case 32:{a[j]=(d[h]|0)>>>4;M=m+2|0;a[l]=a[h]&15;a[z]=(d[M]|0)>>>4;a[A]=a[M]&15;ma=B;na=f;oa=m+3|0;break};case 240:{ma=B+2|0;na=c[v>>2]|0;oa=h;break};case 17:{qa=c[b>>2]|0;if((qa|0)<4){E=61;break a}M=(qa|0)==8;G=M?r:0;I=c[x>>2]|0;K=u-h<<3;Q=K>>>0>2147483639>>>0|(h|0)==0;O=Q?0:h;N=Q?8:K+8|0;Q=O;J=je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;e:do{if((K|0)>0&(f|0)<(I|0)){Q=(G|0)==0;R=0;T=t+((ca(I,B)|0)+f)|0;ba=f;W=J;f:while(1){Y=W>>>28;X=R+4|0;U=N>>>0>X>>>0?X:N;do{if((Y|0)==0){X=((U|0)<(N|0))+U|0;S=O+(X>>>3)|0;if(((d[O+(U>>>3)|0]|0)&128>>>((U&7)>>>0)|0)==0){V=S;ra=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(X&7)>>>29;V=X+3|0;sa=N>>>0>V>>>0?V:N;if((ra|0)==0){break f}if(Q){ta=0}else{ta=a[G]|0}if((ba|0)>=(I|0)){ua=ba;va=T;wa=sa;break}V=ba-I|0;xa=-2-ra|0;ya=((xa|0)>-1?-3-xa|0:-2)-ra|0;ra=V>>>0>ya>>>0?V:ya;ya=-ra|0;mrc(T|0,ta|0,ya|0)|0;ua=ba-ra|0;va=T+ya|0;wa=sa;break}ya=((X|0)<(N|0))+X|0;ra=((d[S]|0)&128>>>((X&7)>>>0)|0)==0;X=O+(ya>>>3)|0;S=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(ya&7)>>>30;X=ya+2|0;ya=N>>>0>X>>>0?X:N;if(ra){ra=S|4;X=O+(ya>>>3)|0;V=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(ya&7)>>>28;X=ya+4|0;xa=N>>>0>X>>>0?X:N;if(y&(V|0)==1){ua=ra+ba|0;va=T;wa=xa;break}if(Q){za=V&255}else{za=a[G+V|0]|0}if((ba|0)>=(I|0)){ua=ba;va=T;wa=xa;break}V=ba-I|0;X=-ra|0;Aa=~(((X|0)>-1?X:-1)+ra);ra=V>>>0>Aa>>>0?V:Aa;Aa=-ra|0;mrc(T|0,za|0,Aa|0)|0;ua=ba-ra|0;va=T+Aa|0;wa=xa;break}if((S|0)==3){xa=O+(ya>>>3)|0;Aa=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(ya&7)>>>24;xa=ya+8|0;ra=N>>>0>xa>>>0?xa:N;xa=O+(ra>>>3)|0;V=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(ra&7)>>>28;xa=ra+4|0;ra=N>>>0>xa>>>0?xa:N;if(y&(V|0)==1){ua=ba+25+Aa|0;va=T;wa=ra;break}if(Q){Ba=V&255}else{Ba=a[G+V|0]|0}if((ba|0)>=(I|0)){ua=ba;va=T;wa=ra;break}V=ba-I|0;xa=-25-Aa|0;X=((xa|0)>-1?-26-xa|0:-25)-Aa|0;Aa=V>>>0>X>>>0?V:X;X=-Aa|0;mrc(T|0,Ba|0,X|0)|0;ua=ba-Aa|0;va=T+X|0;wa=ra;break}else if((S|0)==2){ra=O+(ya>>>3)|0;X=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ya&7)>>>28;ra=ya+4|0;Aa=N>>>0>ra>>>0?ra:N;ra=O+(Aa>>>3)|0;V=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(Aa&7)>>>28;ra=Aa+4|0;Aa=N>>>0>ra>>>0?ra:N;if(y&(V|0)==1){ua=ba+9+X|0;va=T;wa=Aa;break}if(Q){Ca=V&255}else{Ca=a[G+V|0]|0}if((ba|0)>=(I|0)){ua=ba;va=T;wa=Aa;break}V=ba-I|0;ra=-9-X|0;xa=((ra|0)>-1?-10-ra|0:-9)-X|0;X=V>>>0>xa>>>0?V:xa;xa=-X|0;mrc(T|0,Ca|0,xa|0)|0;ua=ba-X|0;va=T+xa|0;wa=Aa;break}else if((S|0)==1){if(M){Da=a[G]|0}else{Da=0}if((ba|0)>=(I|0)){ua=ba;va=T;wa=ya;break}S=(ba-I|0)==-1?-1:-2;Aa=-S|0;mrc(T|0,Da|0,Aa|0)|0;ua=ba-S|0;va=T+Aa|0;wa=ya;break}else{if(M){Ea=a[G]|0}else{Ea=0}a[T]=Ea;ua=ba+1|0;va=T+1|0;wa=ya;break}}else{do{if(y&(Y|0)==1){Fa=T}else{if(Q){a[T]=Y;Fa=T+1|0;break}else{a[T]=a[G+Y|0]|0;Fa=T+1|0;break}}}while(0);ua=ba+1|0;va=Fa;wa=U}}while(0);U=O+(wa>>>3)|0;Y=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(wa&7);if((wa|0)<(K|0)&(ua|0)<(I|0)){R=wa;T=va;ba=ua;W=Y}else{Ga=wa;Ha=ua;Ia=Y;break e}}ma=B;na=ba;oa=m+((sa+7>>3)+1)|0;break b}else{Ga=0;Ha=f;Ia=J}}while(0);J=Ga+8|0;if(!(Ia>>>0<16777216>>>0)){KIb(0,16,2146928,(pa=i,i=i+1|0,i=i+7&-8,c[pa>>2]=0,pa)|0);i=pa}ma=B;na=Ha;oa=m+(((N>>>0>J>>>0?J:N)+7>>3)+1)|0;break};case 18:{Ja=c[b>>2]|0;if((Ja|0)<8){E=109;break a}J=c[x>>2]|0;I=u-h|0;K=m+(I+1)|0;O=t+((ca(J,B)|0)+f)|0;G=m+2|0;M=a[h]|0;L=M<<24>>24==0;g:do{if((I|0)>0&(f|0)<(J|0)){if(y){Ka=O;La=f;Ma=h;Na=G;Oa=M;Pa=L}else{W=O;T=f;R=h;Q=G;P=M;Y=L;while(1){do{if(Y){U=R+2|0;ya=a[Q]|0;Aa=ya&255;S=Aa&127;if((Aa&128|0)!=0){Aa=R+3|0;if(!((S|0)!=0&(T|0)<(J|0))){Qa=T;Ra=W;Sa=Aa;break}xa=T-J|0;X=ya&127;V=-X|0;ra=~(((V|0)>-1?V:-1)+X);X=xa>>>0>ra>>>0?xa:ra;ra=-X|0;mrc(W|0,a[U]|0,ra|0)|0;Qa=T-X|0;Ra=W+ra|0;Sa=Aa;break}if((S|0)==0){ma=B;na=T;oa=U;break b}if((T|0)>=(J|0)){Qa=T;Ra=W;Sa=U;break}S=T-J|0;Aa=ya&127;ya=-Aa|0;ra=~(((ya|0)>-1?ya:-1)+Aa);Aa=S>>>0>ra>>>0?S:ra;ra=-Aa|0;mrc(W|0,0,ra|0)|0;Qa=T-Aa|0;Ra=W+ra|0;Sa=U}else{a[W]=P;Qa=T+1|0;Ra=W+1|0;Sa=Q}}while(0);U=Sa+1|0;ra=a[Sa]|0;Aa=ra<<24>>24==0;if(Sa>>>0<K>>>0&(Qa|0)<(J|0)){W=Ra;T=Qa;R=Sa;Q=U;P=ra;Y=Aa}else{Ta=Qa;Ua=Aa;Va=U;break g}}}while(1){do{if(Pa){Y=Ma+2|0;P=a[Na]|0;Q=P&255;R=Q&127;if((Q&128|0)!=0){Q=Ma+3|0;T=a[Y]|0;W=T<<24>>24==1?R:0;ba=W+La|0;if(!((R|0)!=0&(ba|0)<(J|0))){Wa=ba;Xa=Ka;Ya=Q;break}U=W-J+La|0;W=P&127;Aa=-W|0;ra=~(((Aa|0)>-1?Aa:-1)+W);W=U>>>0>ra>>>0?U:ra;ra=-W|0;mrc(Ka|0,T|0,ra|0)|0;Wa=ba-W|0;Xa=Ka+ra|0;Ya=Q;break}if((R|0)==0){ma=B;na=La;oa=Y;break b}if((La|0)>=(J|0)){Wa=La;Xa=Ka;Ya=Y;break}R=La-J|0;Q=P&127;P=-Q|0;ra=~(((P|0)>-1?P:-1)+Q);Q=R>>>0>ra>>>0?R:ra;ra=-Q|0;mrc(Ka|0,0,ra|0)|0;Wa=La-Q|0;Xa=Ka+ra|0;Ya=Y}else{if(Oa<<24>>24==1){Za=Ka}else{a[Ka]=Oa;Za=Ka+1|0}Wa=La+1|0;Xa=Za;Ya=Na}}while(0);Y=Ya+1|0;ra=a[Ya]|0;Q=ra<<24>>24==0;if(Ya>>>0<K>>>0&(Wa|0)<(J|0)){Ka=Xa;La=Wa;Ma=Ya;Na=Y;Oa=ra;Pa=Q}else{Ta=Wa;Ua=Q;Va=Y;break}}}else{Ta=f;Ua=L;Va=G}}while(0);if(Ua){ma=B;na=Ta;oa=Va;break b}KIb(0,16,2146928,(pa=i,i=i+1|0,i=i+7&-8,c[pa>>2]=0,pa)|0);i=pa;ma=B;na=Ta;oa=Va;break};case 33:{a[n]=a[h]|0;a[p+1|0]=a[m+2|0]|0;a[p+2|0]=a[m+3|0]|0;a[p+3|0]=a[m+4|0]|0;ma=B;na=f;oa=m+5|0;break};default:{KIb(w,32,2174480,(pa=i,i=i+8|0,c[pa>>2]=e,pa)|0);i=pa;ma=B;na=f;oa=h}}}while(0);if(oa>>>0<s>>>0){m=oa;f=na;B=ma}else{E=138;break}}if((E|0)==9){_a=D;$a=c[g>>2]|0}else if((E|0)==11){_a=c[x>>2]|0;$a=F}else if((E|0)==61){KIb(w,16,2249e3,(pa=i,i=i+8|0,c[pa>>2]=qa,pa)|0);i=pa;i=k;return}else if((E|0)==109){KIb(w,16,2206864,(pa=i,i=i+8|0,c[pa>>2]=Ja,pa)|0);i=pa;i=k;return}else if((E|0)==138){i=k;return}KIb(w,16,2300128,(pa=i,i=i+40|0,c[pa>>2]=f,c[pa+8>>2]=_a,c[pa+16>>2]=B,c[pa+24>>2]=$a,c[pa+32>>2]=C&255,pa)|0);i=pa;i=k;return}function dca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=g;m=Sba(b,c[l>>2]|0,j,k)|0;c[l>>2]=m;do{if((m|0)!=0){if((k|0)<(c[m+8>>2]|0)){break}if((rpb(m)|0)!=0){break}n=g+4|0;c[n>>2]=e;c[e+84>>2]=1;c[e+88>>2]=1;o=c[l>>2]|0;c[b+140>>2]=c[o+64>>2];p=o+20|0;o=b+104|0;q=c[p+4>>2]|0;c[o>>2]=c[p>>2];c[o+4>>2]=q;q=c[l>>2]|0;o=H4a(b,c[q+36>>2]|0,c[q+32>>2]|0)|0;if((o|0)<0){r=o;i=h;return r|0}o=M4a(b,c[n>>2]|0,0)|0;if((o|0)<0){r=o;i=h;return r|0}o=c[n>>2]|0;c[o+296>>2]=1;c[o+300>>2]=0;if((a[j+453|0]|0)==97){o=a[j+455|0]&7;do{if((o|0)==2){s=1}else{if(!((a[j+4|0]&7)==0)){s=0;break}s=(o|0)==7|0}}while(0);o=(c[l>>2]|0)+40+(s<<3)|0;q=b+224|0;p=c[o+4>>2]|0;c[q>>2]=c[o>>2];c[q+4>>2]=p;c[(c[n>>2]|0)+300>>2]=((d[j+456|0]|0)>>>6&1^1)&255}c[g+12>>2]=j;p=c[b+824>>2]|0;q=c[l>>2]|0;o=c[q+56>>2]|0;t=ca((c[q+16>>2]|0)*27|0,c[q+12>>2]|0)|0;u=c[q+4>>2]|0;if((u|0)==20){v=(c[q>>2]|0)==1?t-81|0:t}else if((u|0)==24){v=(c[q>>2]|0)==1?t-108|0:t}else{v=t}se[p&127](b,636,o,0,v,12)|0;c[f>>2]=1;r=c[(c[l>>2]|0)+8>>2]|0;i=h;return r|0}}while(0);KIb(b,16,2454840,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;r=-1;i=h;return r|0}function eca(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0;h=i;i=i+6912|0;j=h|0;k=h+24|0;l=h+48|0;m=h+1192|0;n=h+6312|0;o=h+6408|0;p=h+6824|0;q=h+6848|0;r=c[f+60>>2]|0;s=n|0;t=o|0;u=c[(c[r+8>>2]|0)+800>>2]|0;mrc(m|0,0,5120)|0;v=r+12|0;w=(c[v>>2]|0)+((e[g>>1]|0)*80|0)|0;x=m|0;m=h+72|0;c[k+20>>2]=3200;z=k+8|0;c[z>>2]=t;c[k+16>>2]=o+400;o=k+12|0;c[o>>2]=t;A=k+4|0;c[A>>2]=32;B=k|0;c[B>>2]=0;C=j+20|0;D=j+8|0;E=n+80|0;n=j+16|0;F=j+12|0;G=j+4|0;H=j|0;I=r;J=l|0;K=l+12|0;L=l+16|0;M=l+4|0;N=l+8|0;O=r+156|0;P=O;Q=r+16|0;R=Q;S=(u|0)==0|0;T=O;O=c[I>>2]|0;U=x;V=w;w=m;W=0;X=O;Y=c[O+68>>2]|0;while(1){O=a[V+3|0]&15;Z=V+4|0;c[C>>2]=640;c[D>>2]=s;c[n>>2]=E;c[F>>2]=s;c[G>>2]=32;c[H>>2]=0;_=p+(W<<2)|0;c[_>>2]=0;if((Y|0)>0){$=O<<6;aa=Z;ba=w;da=U;ea=0;fa=X;while(1){ga=d[(c[fa+72>>2]|0)+ea|0]|0;ha=(aa|0)==0?0:ga;c[J>>2]=aa;c[K>>2]=ha;ia=ha+8|0;c[L>>2]=ia;c[M>>2]=aa+((ha+7|0)>>>3);c[N>>2]=0;ha=aa;ja=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)>>23;ha=ia>>>0>9>>>0;ka=ha?9:ia;c[N>>2]=ka;la=(d[aa+(ka>>>3)|0]|0)<<(ka&7)>>>7;ma=(ha&1)+ka|0;c[N>>2]=ma;ka=la&1;la=aa+(ma>>>3)|0;ha=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>30;la=ma+2|0;c[N>>2]=ia>>>0>la>>>0?la:ia;if((c[fa+4>>2]&16|0)==0){c[ba+12>>2]=c[P+(((ka|0)==0?0:S)<<2)>>2];c[ba+4>>2]=R+(ka<<6);c[ba>>2]=(c[(c[I>>2]|0)+60>>2]|0)+((-((ha|0)==3|0)<<6&2816)+(-ka&1408)+((d[1396648+ha|0]|0)+O<<6)<<2)}else{c[ba+12>>2]=c[T>>2];c[ba+4>>2]=Q;c[ba>>2]=(c[(c[I>>2]|0)+60>>2]|0)+((((ea|0)>3)<<12|$|ha<<10)<<2);c[_>>2]=c[_>>2]|((ea|0)==0?ka:0)}b[da>>1]=(ja<<2)+1024;na=aa+(ga>>>3)|0;ga=ba+8|0;a[ga]=0;a[ba+16|0]=0;gca(l,ba,da);if((d[ga]|0)>>>0>63>>>0){hca(j,l)}ga=ea+1|0;ja=c[I>>2]|0;if((ga|0)<(c[ja+68>>2]|0)){aa=na;ba=ba+28|0;da=da+128|0;ea=ga;fa=ja}else{break}}oa=na;pa=c[G>>2]|0;qa=c[D>>2]|0;ra=c[F>>2]|0;sa=c[H>>2]|0}else{oa=Z;pa=32;qa=s;ra=s;sa=0}fa=(ra-qa<<3)+(32-pa)|0;ea=fa>>>0>2147483639>>>0;da=ea?0:s;ba=ea?0:fa;c[J>>2]=da;c[K>>2]=ba;c[L>>2]=ba+8;c[M>>2]=da+(ba+7>>3);c[N>>2]=0;if((pa|0)>16){ta=pa-16|0;ua=sa<<16;va=ra}else{ba=ra;y=je(sa<<pa|0)|0;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;ba=ra+4|0;c[F>>2]=ba;ta=pa+16|0;ua=0;va=ba}c[H>>2]=ua;c[G>>2]=ta;if((ta|0)>16){wa=ta-16|0;xa=va}else{ba=va;y=je(ua<<ta|0)|0;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;ba=(c[F>>2]|0)+4|0;c[F>>2]=ba;wa=ta+16|0;xa=ba}c[H>>2]=0;c[G>>2]=wa;if((wa|0)<32){c[H>>2]=0;ba=wa+8|0;da=(((ba|0)>32?wa+7|0:31)-wa|0)>>>3;fa=da<<3;ea=xa;aa=wa;while(1){a[ea]=0;_=aa+8|0;if((_|0)<32){ea=ea+1|0;aa=_}else{break}}c[F>>2]=xa+(da+1);c[H>>2]=0;c[G>>2]=ba+fa}c[G>>2]=32;c[H>>2]=0;aa=c[I>>2]|0;ea=c[aa+68>>2]|0;a:do{if((ea|0)>0){Z=w;_=U;$=0;O=aa;b:while(1){ja=Z+8|0;do{if((d[ja]|0)>>>0<64>>>0){if(((c[K>>2]|0)-(c[N>>2]|0)|0)<=0){ya=O;break}gca(l,Z,_);za=c[I>>2]|0;if((d[ja]|0)>>>0<64>>>0){break b}else{ya=za}}else{ya=O}}while(0);ja=$+1|0;ga=c[ya+68>>2]|0;if((ja|0)<(ga|0)){Z=Z+28|0;_=_+128|0;$=ja;O=ya}else{Aa=ja;Ba=ya;Ca=ga;break a}}Aa=$;Ba=za;Ca=c[za+68>>2]|0}else{Aa=0;Ba=aa;Ca=ea}}while(0);if((Aa|0)<(Ca|0)){Da=Ba;Ea=Ca}else{hca(k,l);ea=c[I>>2]|0;Da=ea;Ea=c[ea+68>>2]|0}ea=W+1|0;if((ea|0)<5){U=U+(Ea<<6<<1)|0;V=oa;w=w+(Ea*28|0)|0;W=ea;X=Da;Y=Ea}else{break}}Ea=g;g=3-u|0;u=c[A>>2]|0;Y=c[o>>2]|0;Da=(Y-(c[z>>2]|0)<<3)+(32-u)|0;z=Da>>>0>2147483639>>>0;X=z?0:t;t=z?0:Da;c[J>>2]=X;c[K>>2]=t;c[L>>2]=t+8;c[M>>2]=X+(t+7>>3);c[N>>2]=0;t=c[B>>2]|0;if((u|0)>16){Fa=u-16|0;Ga=t<<16;Ha=Y}else{X=Y;y=je(t<<u|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=Y+4|0;c[o>>2]=X;Fa=u+16|0;Ga=0;Ha=X}c[B>>2]=Ga;c[A>>2]=Fa;if((Fa|0)>16){Ia=Fa-16|0;Ja=Ha}else{X=Ha;y=je(Ga<<Fa|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=Ha+4|0;c[o>>2]=X;Ia=Fa+16|0;Ja=X}c[B>>2]=0;c[A>>2]=Ia;if((Ia|0)<32){c[B>>2]=0;X=(((Ia+8|0)>32?Ia+7|0:31)-Ia|0)>>>3;Fa=Ia+(X<<3)|0;Ha=X+1|0;X=Ja;Ga=Ia;while(1){a[X]=0;Ia=Ga+8|0;if((Ia|0)<32){X=X+1|0;Ga=Ia}else{break}}c[o>>2]=Ja+Ha;c[B>>2]=0;c[A>>2]=Fa+8}c[A>>2]=32;c[B>>2]=0;B=f;f=m;A=x;Fa=0;Ha=c[I>>2]|0;while(1){if((c[Ha+68>>2]|0)>0){Ja=f;o=A;Ga=0;while(1){X=Ja+8|0;Ia=a[X]|0;do{if((Ia&255)>>>0<64>>>0){if(((c[K>>2]|0)-(c[N>>2]|0)|0)<=0){Ka=Ia;break}gca(l,Ja,o);Ka=a[X]|0}else{Ka=Ia}}while(0);if((Ka-64&255)>>>0<63>>>0){KIb(B,16,2365344,(Ia=i,i=i+8|0,c[Ia>>2]=Ka&255,Ia)|0);i=Ia}Ia=o+128|0;X=Ja+28|0;$=Ga+1|0;u=c[I>>2]|0;if(($|0)<(c[u+68>>2]|0)){Ja=X;o=Ia;Ga=$}else{La=X;Ma=Ia;Na=u;break}}}else{La=f;Ma=A;Na=Ha}Ga=Fa+1|0;if((Ga|0)<5){f=La;A=Ma;Fa=Ga;Ha=Na}else{break}}Ha=2<<g;Fa=r+4|0;r=1<<g;Ma=q;q=r>>1;A=g-1|0;La=(A|0)>0?1<<A:1;A=m;m=x;x=0;f=Na;while(1){Na=b[Ea+2+(x<<1)>>1]|0;Ka=Na&65535;B=Ka&255;l=Ka>>>8;Ka=c[f+32>>2]|0;do{if((Ka|0)==720){if(!((a[(c[v>>2]|0)+1|0]&12)==0)){Oa=l;break}Oa=l-((Na&65535)>>>0>4607>>>0?18:-72)|0}else{Oa=l}}while(0);l=c[f+64>>2]|0;if((l|0)==0){Pa=56}else if((l|0)==7){if(B>>>0>87>>>0){Pa=56}else{Pa=55}}else{Pa=55}do{if((Pa|0)==55){Pa=0;if(!((Ka|0)<720|(Oa|0)==134)){Pa=56;break}l=c[Fa>>2]|0;Qa=Ha;Ra=l;Sa=c[l+32>>2]|0;Ta=c[p+(x<<2)>>2]|0}}while(0);if((Pa|0)==56){Pa=0;Ka=c[Fa>>2]|0;l=c[Ka+32>>2]|0;Na=c[p+(x<<2)>>2]|0;Qa=l<<(g&-((Na|0)==0|0));Ra=Ka;Sa=l;Ta=Na}Na=c[Ra>>2]|0;l=(ca(Sa,Oa)|0)+B<<g;Ka=p+(x<<2)|0;N=Sa<<Ta;ef[c[A+12>>2]&4095](Na+l|0,N,m);if((c[(c[I>>2]|0)+4>>2]|0)==4){ef[c[A+68>>2]&4095](Na+(l+r)|0,N,m+256|0)}else{K=l+r|0;ef[c[A+40>>2]&4095](Na+K|0,N,m+128|0);ef[c[A+68>>2]&4095](Na+(l+Qa)|0,N,m+256|0);ef[c[A+96>>2]&4095](Na+(K+Qa)|0,N,m+384|0)}N=c[(c[I>>2]|0)+64>>2]|0;K=c[Fa>>2]|0;Na=ca(Oa>>((N|0)==0),c[K+36>>2]|0)|0;l=Na+(B>>>(((N|0)==7?2:1)>>>0))<<g;Na=B>>>0>87>>>0;Ga=(Oa|0)==134;o=A+112|0;Ja=m+512|0;u=2;Ia=K;K=N;while(1){N=c[Ia+(u<<2)>>2]|0;X=N+l|0;do{if((K|0)==7&Na){ef[c[o+12>>2]&4095](Ma,8,Ja);if(!((r|0)<1|(La|0)<1)){$=X;Y=Ma;t=0;M=c[(c[Fa>>2]|0)+32+(u<<2)>>2]|0;while(1){L=M<<g;J=0;do{a[$+J|0]=a[Y+J|0]|0;a[$+(J+L)|0]=a[Y+(J+q)|0]|0;J=J+1|0;}while((J|0)<(La|0));J=c[(c[Fa>>2]|0)+32+(u<<2)>>2]|0;L=t+1|0;if((L|0)<(r|0)){$=$+J|0;Y=Y+8|0;t=L;M=J}else{break}}}Ua=Ja+128|0;Va=o+28|0}else{M=c[Ia+32+(u<<2)>>2]|0;t=c[Ka>>2]|0;if(Ga){Wa=r}else{Wa=M<<(g&-((t|0)==0|0))}Y=M<<t;ef[c[o+12>>2]&4095](X,Y,Ja);t=Ja+128|0;if((c[(c[I>>2]|0)+68>>2]|0)!=8){Ua=t;Va=o+28|0;break}ef[c[o+40>>2]&4095](N+(Wa+l)|0,Y,t);Ua=Ja+256|0;Va=o+56|0}}while(0);N=u-1|0;if((N|0)==0){break}o=Va;Ja=Ua;u=N;Ia=c[Fa>>2]|0;K=c[(c[I>>2]|0)+64>>2]|0}K=x+1|0;if((K|0)>=5){break}A=Va;m=Ua;x=K;f=c[I>>2]|0}i=h;return 0}function fca(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(f>>>3)|0;a=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(f&7)>>>((32-b|0)>>>0);h=f+b|0;c[e>>2]=g>>>0>h>>>0?h:g;return a|0}function gca(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=c[e+12>>2]|0;i=c[f+4>>2]|0;j=c[f>>2]|0;k=f+8|0;l=d[k]|0;m=f+16|0;n=a[m]|0;o=n&255;p=e+8|0;q=c[p>>2]|0;r=e|0;e=(c[r>>2]|0)+(q>>>3)|0;s=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(q&7);if(n<<24>>24==0){t=l;u=s;v=q}else{n=c[f+20>>2]|s>>>(o>>>0);a[m]=0;t=l;u=n;v=q-o|0}while(1){o=u>>>23;q=a[8373906+(o<<2)|0]|0;n=q<<24>>24;if(q<<24>>24<0){w=(b[8373904+(o<<2)>>1]|0)+(u<<9>>>((n+32|0)>>>0))|0;x=9-n|0}else{w=o;x=n}n=x+v|0;if(n>>>0>h>>>0){break}o=(d[8373907+(w<<2)|0]|0)+t|0;if((o|0)>63){y=n;z=o&255;A=9;break}q=((ca(c[j+(o<<2)>>2]|0,b[8373904+(w<<2)>>1]|0)|0)+8192|0)>>>14&65535;b[g+(d[i+o|0]<<1)>>1]=q;q=(c[r>>2]|0)+(n>>>3)|0;t=o;u=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(n&7);v=n}if((A|0)==9){c[p>>2]=y;a[k]=z;return}A=h-v|0;a[m]=A;c[f+20>>2]=u&~(-1>>>((A&255)>>>0));y=h;z=t&255;c[p>>2]=y;a[k]=z;return}function hca(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e+8|0;g=c[f>>2]|0;h=c[e+12>>2]|0;i=h-g|0;if((i|0)>24){j=((h-25-g|0)>>>0)%25|0;g=i;while(1){ica(b,25,fca(e,25)|0);h=g-25|0;if((h|0)>24){g=h}else{k=j;break}}}else{k=i}if((k|0)<=0){return}i=c[f>>2]|0;j=c[e+16>>2]|0;g=(c[e>>2]|0)+(i>>>3)|0;e=32-k|0;h=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(i&7)>>>(e>>>0);g=i+k|0;c[f>>2]=j>>>0>g>>>0?g:j;j=b|0;g=c[j>>2]|0;f=b+4|0;i=c[f>>2]|0;if((i|0)>(k|0)){l=i-k|0;m=g<<k|h}else{n=je(h>>>((k-i|0)>>>0)|g<<i|0)|0;g=b+12|0;b=c[g>>2]|0;y=n;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;l=e+i|0;m=h}c[j>>2]=m;c[f>>2]=l;return}function ica(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b|0;g=c[f>>2]|0;h=b+4|0;i=c[h>>2]|0;if((i|0)>(d|0)){j=i-d|0;k=g<<d|e;c[f>>2]=k;c[h>>2]=j;return}else{l=je(e>>>((d-i|0)>>>0)|g<<i|0)|0;g=b+12|0;b=c[g>>2]|0;y=l;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;j=32-d+i|0;k=e;c[f>>2]=k;c[h>>2]=j;return}}function jca(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=c[b+60>>2]|0;k=j;l=b+96|0;do{if((c[l>>2]|0)!=0){m=b+100|0;n=c[m>>2]|0;if((n|0)==0){break}o=hJb(n+1|0)|0;if((o|0)==0){p=-12;i=d;return p|0}n=c[m>>2]|0;nrc(o|0,c[l>>2]|0,n)|0;a[o+n|0]=0;n=j+72|0;m=o;a:while(1){q=mc(m|0,2174472)|0;if((q|0)==0){if((a[m]|0)==0){r=19;break}}do{if((krc(2300112,m,8)|0)==0){s=m+8|0;c[f>>2]=s;c[n>>2]=1;t=0;u=s;while(1){c[k+4+(t<<2)>>2]=pb(u|0,f|0,16)|0;s=c[f>>2]|0;while(1){v=a[s]|0;if(!(v<<24>>24==44)){if((OFb(v<<24>>24)|0)==0){break}}v=s+1|0;c[f>>2]=v;s=v}v=t+1|0;if((v|0)<16){t=v;u=s}else{break}}}else{if((krc(2146920,m,5)|0)!=0){break}u=Bd(m+5|0,2123072,(w=i,i=i+16|0,c[w>>2]=g,c[w+8>>2]=h,w)|0)|0;i=w;if((u|0)!=2){break}x=H4a(b,c[g>>2]|0,c[h>>2]|0)|0;if((x|0)<0){break a}}}while(0);m=m+((ud(m+q|0,2174472)|0)+q)|0}if((r|0)==19){kJb(o);break}kJb(o);p=x;i=d;return p|0}}while(0);x=c[j+68>>2]|0;if((x|0)==0){y=j+72|0}else{c[e>>2]=x;r=j+72|0;c[r>>2]=1;h=0;g=x;while(1){c[k+4+(h<<2)>>2]=pb(g|0,e|0,16)|0;x=c[e>>2]|0;while(1){f=a[x]|0;if(!(f<<24>>24==44)){if((OFb(f<<24>>24)|0)==0){break}}f=x+1|0;c[e>>2]=f;x=f}o=h+1|0;if((o|0)<16){h=o;g=x}else{y=r;break}}}if((c[y>>2]|0)==0){p=1;i=d;return p|0}y=b;KIb(y,48,2300112,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;b=j+4|0;j=0;do{KIb(y,48,2248992,(w=i,i=i+8|0,c[w>>2]=c[b+(j<<2)>>2],w)|0);i=w;j=j+1|0;}while((j|0)<16);KIb(y,48,2206856,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;p=1;i=d;return p|0}function kca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0;h=i;i=i+272|0;j=h|0;k=h+256|0;l=b+60|0;m=c[l>>2]|0;n=m;o=c[g+24>>2]|0;p=c[g+28>>2]|0;g=m+336|0;q=g;r=c[q>>2]|0;a:do{if((r|0)==0){s=o;t=p}else{u=m+340|0;v=c[u>>2]|0;do{if((v|0)>(65535-p|0)){KIb(b,24,2365288,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;mJb(g);x=-1094995529}else{y=iJb(r,v+p|0)|0;c[q>>2]=y;if((y|0)==0){x=-12;break}nrc(y+(c[u>>2]|0)|0,o|0,p)|0;y=(c[u>>2]|0)+p|0;c[u>>2]=y;s=c[q>>2]|0;t=y;break a}}while(0);c[f>>2]=0;z=x;i=h;return z|0}}while(0);x=m+76|0;q=m+80|0;b:do{if((t|0)>=10){p=s;o=(d[p]|d[p+1|0]<<8)<<16>>16<<16>>16==0;p=o?4:2;r=s+(o?6:2)|0;if(o){u=r;v=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;if((v|0)>=0){A=v;B=11}}else{v=r;A=(he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535;B=11}c:do{if((B|0)==11){v=t-2-p|0;if((A|0)>(v|0)){break}r=p+2|0;u=e+16|0;y=u;C=e+12|0;D=k|0;E=m+72|0;F=m+81|0;G=m+82|0;H=m+83|0;I=m+79|0;J=m+78|0;K=m+77|0;L=e+4|0;M=e+8|0;N=0;O=A;P=0;Q=0;d:while(1){if(!((O|0)>0&(O|0)<(v|0))){R=N;B=75;break}S=s+O|0;T=(he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535;S=s+(O+2)|0;if(o){U=S;V=je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0}else{U=S;V=(he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535}U=r+O|0;do{if((U|0)<(t|0)){S=(T<<10>>>0)/90|0;W=0;X=0;Y=-1;Z=-1;_=0;$=Q;aa=P;ba=0;da=U;ea=N;e:while(1){fa=da+1|0;ga=d[s+da|0]|0;switch(ga|0){case 132:{if((t-fa|0)<256){break d}else{ha=0}do{a[n+80+ha|0]=~a[s+(ha+fa)|0];ha=ha+1|0;}while((ha|0)<256);ia=ea;ja=da+257|0;ka=ba;la=aa;ma=$;na=_;oa=Z;pa=Y;qa=X;ra=W;break};case 6:{if((t-fa|0)<4){break d}sa=s+fa|0;ta=(he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535;sa=s+(da+3)|0;ia=ea;ja=da+5|0;ka=ba;la=aa;ma=$;na=_;oa=(he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535;pa=ta;qa=X;ra=W;break};case 1:{c[L>>2]=S;ia=ea;ja=fa;ka=ba;la=aa;ma=$;na=_;oa=Z;pa=Y;qa=X;ra=W;break};case 5:case 133:{if((t-fa|0)<6){break d}ta=d[s+(da+2)|0]|0;sa=d[s+(da+5)|0]|0;ia=ea;ja=da+7|0;ka=ta>>>4|d[s+fa|0]<<4;la=aa;ma=(ga&128|0)==0?$:1;na=sa>>>4|d[s+(da+4)|0]<<4;oa=Z;pa=Y;qa=sa<<8&3840|d[s+(da+6)|0];ra=ta<<8&3840|d[s+(da+3)|0];break};case 3:{if((t-fa|0)<2){break d}ta=s+fa|0;a[I]=(d[ta]|0)>>>4;a[J]=a[ta]&15;ta=s+(da+2)|0;a[K]=(d[ta]|0)>>>4;a[x]=a[ta]&15;ia=ea;ja=da+3|0;ka=ba;la=aa;ma=$;na=_;oa=Z;pa=Y;qa=X;ra=W;break};case 4:{if((t-fa|0)<2){break d}ta=s+fa|0;a[H]=(d[ta]|0)>>>4;a[G]=a[ta]&15;ta=s+(da+2)|0;a[F]=(d[ta]|0)>>>4;a[q]=a[ta]&15;ia=ea;ja=da+3|0;ka=ba;la=aa;ma=$;na=_;oa=Z;pa=Y;qa=X;ra=W;break};case 2:{c[M>>2]=S;ia=ea;ja=fa;ka=ba;la=aa;ma=$;na=_;oa=Z;pa=Y;qa=X;ra=W;break};case 131:{if((t-fa|0)<768){break d}ia=ea;ja=da+769|0;ka=ba;la=s+fa|0;ma=$;na=_;oa=Z;pa=Y;qa=X;ra=W;break};case 134:{if((t-fa|0)<8){break d}ta=s+fa|0;sa=je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0;ta=s+(da+5)|0;ia=ea;ja=da+9|0;ka=ba;la=aa;ma=$;na=_;oa=je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0;pa=sa;qa=X;ra=W;break};case 0:{ia=1;ja=fa;ka=ba;la=aa;ma=$;na=_;oa=Z;pa=Y;qa=X;ra=W;break};default:{ua=W;va=X;wa=Y;xa=Z;ya=_;za=$;Aa=aa;Ba=ba;Ca=ea;break e}}if((ja|0)<(t|0)){W=ra;X=qa;Y=pa;Z=oa;_=na;$=ma;aa=la;ba=ka;da=ja;ea=ia}else{ua=ra;va=qa;wa=pa;xa=oa;ya=na;za=ma;Aa=la;Ba=ka;Ca=ia;break}}if(!((wa|0)>-1)){Da=Ca;Ea=Aa;Fa=za;break}ea=ua-Ba+1|0;da=(ea|0)<0?0:ea;ea=va-ya|0;ba=(ea|0)<0?0:ea;if(!((da|0)>0&(ba|0)>0)){Da=Ca;Ea=Aa;Fa=za;break}ea=c[y>>2]|0;if((ea|0)!=0){f:do{if((c[C>>2]|0)!=0){aa=0;$=ea;while(1){mJb((c[$+(aa<<2)>>2]|0)+20|0);mJb((c[(c[y>>2]|0)+(aa<<2)>>2]|0)+24|0);mJb((c[y>>2]|0)+(aa<<2)|0);_=aa+1|0;if(!(_>>>0<(c[C>>2]|0)>>>0)){break f}aa=_;$=c[y>>2]|0}}}while(0);mJb(u);c[C>>2]=0}ea=hJb(ca(da,ba)|0)|0;c[y>>2]=pJb(4)|0;$=pJb(100)|0;c[c[y>>2]>>2]=$;c[C>>2]=1;c[(c[c[y>>2]>>2]|0)+20>>2]=ea;$=da<<1;mca(ea,$,da,(ba+1|0)/2|0,s,wa,t,za);mca(ea+da|0,$,da,(ba|0)/2|0,s,xa,t,za);$=pJb(1024)|0;c[(c[c[y>>2]>>2]|0)+24>>2]=$;g:do{if((za|0)==0){$=c[c[y>>2]>>2]|0;c[$+16>>2]=4;ea=c[$+24>>2]|0;$=ea;mrc(D|0,0,16)|0;if((c[E>>2]|0)!=0){c[$>>2]=ca(d[q]|0,285212672)|0|c[n+4+(d[x]<<2)>>2]&16777215;c[ea+4>>2]=ca(d[F]|0,285212672)|0|c[n+4+(d[K]<<2)>>2]&16777215;c[ea+8>>2]=ca(d[G]|0,285212672)|0|c[n+4+(d[J]<<2)>>2]&16777215;c[ea+12>>2]=ca(d[H]|0,285212672)|0|c[n+4+(d[I]<<2)>>2]&16777215;break}mrc(ea|0,0,16)|0;ea=a[q]|0;do{if(ea<<24>>24==0){Ga=0}else{aa=k+(d[x]|0)|0;if((a[aa]|0)!=0){Ga=0;break}a[aa]=1;Ga=1}}while(0);do{if((a[F]|0)==0){Ha=Ga}else{aa=k+(d[K]|0)|0;if((a[aa]|0)!=0){Ha=Ga;break}a[aa]=1;Ha=Ga+1|0}}while(0);do{if((a[G]|0)==0){Ia=Ha}else{aa=k+(d[J]|0)|0;if((a[aa]|0)!=0){Ia=Ha;break}a[aa]=1;Ia=Ha+1|0}}while(0);do{if((a[H]|0)==0){Ja=Ia}else{aa=k+(d[I]|0)|0;if((a[aa]|0)!=0){Ja=Ia;break}a[aa]=1;Ja=Ia+1|0}}while(0);if((Ja|0)==0){break}mrc(D|0,0,16)|0;aa=0;fa=0;ga=ea;while(1){_=ga&255;do{if(ga<<24>>24==0){Ka=aa}else{Z=n+76+fa|0;Y=a[k+(d[Z]|0)|0]|0;if(Y<<24>>24==0){X=(d[1146832+(Ja<<2)+aa|0]|0)*255|0;c[$+(fa<<2)>>2]=X&65280|(ca(_,285212672)|0)|X>>>8<<16;a[k+(d[Z]|0)|0]=fa+1;Ka=aa+1|0;break}else{c[$+(fa<<2)>>2]=c[$+((Y&255)-1<<2)>>2]&16777215|(ca(_,285212672)|0);Ka=aa;break}}}while(0);_=fa+1|0;if((_|0)>=4){break g}aa=Ka;fa=_;ga=a[n+80+_|0]|0}}else{if((Aa|0)==0){break d}ga=c[c[y>>2]>>2]|0;c[ga+16>>2]=256;fa=256;aa=c[ga+24>>2]|0;ga=q;$=Aa;while(1){ea=(d[$+2|0]|0)-128|0;_=(d[$+1|0]|0)-128|0;Y=((d[$]|0)*1192|0)-18560|0;c[aa>>2]=d[((_*-832|0)+Y+(ea*-401|0)>>10)+1404400|0]<<8|d[((_*1634|0)+Y>>10)+1404400|0]<<16|d[((ea*2066|0)+Y>>10)+1404400|0]|d[ga]<<24;Y=fa-1|0;if((Y|0)>0){fa=Y;aa=aa+4|0;ga=ga+1|0;$=$+3|0}else{break}}}}while(0);$=c[c[y>>2]>>2]|0;c[$>>2]=Ba;c[$+4>>2]=ya;c[$+8>>2]=da;c[$+12>>2]=ba;c[$+84>>2]=1;c[$+52>>2]=da;c[$+96>>2]=(Ca|0)!=0;Da=Ca;Ea=Aa;Fa=za}else{Da=N;Ea=P;Fa=Q}}while(0);if((V|0)<(O|0)){B=73;break}if((V|0)==(O|0)){R=Da;B=75;break}else{N=Da;O=V;P=Ea;Q=Fa}}if((B|0)==73){KIb(0,16,2454776,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;R=Da;B=75}do{if((B|0)==75){if((c[C>>2]|0)==0){break}if((R|0)==-11){break c}if((R|0)<0){break b}do{if((R|0)==0){mrc(j|0,0,256)|0;Q=c[y>>2]|0;if((Q|0)==0){break b}P=c[Q>>2]|0;Q=c[P+8>>2]|0;if((Q|0)<1){break b}O=c[P+12>>2]|0;if((O|0)<1){break b}N=c[P+16>>2]|0;if((N|0)>0){D=c[P+24>>2]|0;I=0;do{if((c[D+(I<<2)>>2]|0)>>>0<16777216>>>0){a[j+I|0]=1}I=I+1|0;}while((I|0)<(N|0));if((O|0)>0){B=95}else{La=0;Ma=0}}else{B=95}h:do{if((B|0)==95){N=(Q|0)>0;I=P+52|0;D=P+20|0;da=0;while(1){if(N){ba=ca(c[I>>2]|0,da)|0;H=(c[D>>2]|0)+ba|0;ba=0;while(1){if((a[j+(d[H]|0)|0]|0)==0){La=da;Ma=1;break h}J=ba+1|0;if((J|0)<(Q|0)){H=H+1|0;ba=J}else{break}}}ba=da+1|0;if((ba|0)<(O|0)){da=ba}else{La=ba;Ma=1;break}}}}while(0);if((La|0)==(O|0)){mJb(P+20|0);da=c[c[y>>2]>>2]|0;c[da+12>>2]=0;c[da+8>>2]=0;break b}da=O-1|0;i:do{if((da|0)>0){D=c[P+20>>2]|0;I=c[P+52>>2]|0;if((Q|0)>0){Na=da}else{Oa=0;break}while(1){N=D+(ca(Na,I)|0)|0;ba=0;while(1){if((a[j+(d[N]|0)|0]|0)==0){Oa=Na;break i}H=ba+1|0;if((H|0)<(Q|0)){N=N+1|0;ba=H}else{break}}ba=Na-1|0;if((ba|0)>0){Na=ba}else{Oa=ba;break}}}else{Oa=da}}while(0);da=Q-1|0;j:do{if((da|0)>0){I=c[P+52>>2]|0;D=P+20|0;ba=0;k:while(1){if(Ma){N=(c[D>>2]|0)+ba|0;H=0;while(1){if((a[j+(d[N]|0)|0]|0)==0){Pa=ba;break k}J=H+1|0;if((J|0)<(O|0)){N=N+I|0;H=J}else{break}}}H=ba+1|0;if((H|0)<(da|0)){ba=H}else{Pa=H;break}}ba=c[D>>2]|0;if(Ma){Qa=da}else{Ra=0;Sa=Pa;break}while(1){H=ba+Qa|0;N=0;while(1){if((a[j+(d[H]|0)|0]|0)==0){Ra=Qa;Sa=Pa;break j}J=N+1|0;if((J|0)<(O|0)){H=H+I|0;N=J}else{break}}N=Qa-1|0;if((N|0)>0){Qa=N}else{Ra=N;Sa=Pa;break}}}else{Ra=da;Sa=0}}while(0);da=Ra-Sa+1|0;O=Oa-La+1|0;P=hJb(ca(da,O)|0)|0;if((P|0)==0){break}Q=c[y>>2]|0;if((O|0)>0){I=0;do{ba=P+(ca(I,da)|0)|0;D=c[Q>>2]|0;nrc(ba|0,(c[D+20>>2]|0)+((ca(c[D+52>>2]|0,I+La|0)|0)+Sa)|0,da)|0;I=I+1|0;}while((I|0)<(O|0))}mJb((c[Q>>2]|0)+20|0);c[(c[c[y>>2]>>2]|0)+20>>2]=P;I=c[c[y>>2]>>2]|0;c[I+52>>2]=da;c[I+8>>2]=da;c[I+12>>2]=O;D=I|0;c[D>>2]=(c[D>>2]|0)+Sa;D=I+4|0;c[D>>2]=(c[D>>2]|0)+La}}while(0);mJb(g);c[m+340>>2]=0;c[f>>2]=1;z=t;i=h;return z|0}}while(0);D=c[y>>2]|0;if((D|0)==0){break b}l:do{if((c[C>>2]|0)!=0){I=0;ba=D;while(1){mJb((c[ba+(I<<2)>>2]|0)+20|0);mJb((c[(c[y>>2]|0)+(I<<2)>>2]|0)+24|0);mJb((c[y>>2]|0)+(I<<2)|0);N=I+1|0;if(!(N>>>0<(c[C>>2]|0)>>>0)){break l}I=N;ba=c[y>>2]|0}}}while(0);mJb(u);c[C>>2]=0;break b}}while(0);c[f>>2]=0;o=c[l>>2]|0;p=o+340|0;y=c[p>>2]|0;if((y|0)>(65535-t|0)){KIb(b,24,2365288,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;mJb(o+336|0);z=-1094995529;i=h;return z|0}D=o+336|0;o=iJb(c[D>>2]|0,y+t|0)|0;c[D>>2]=o;if((o|0)==0){z=-12;i=h;return z|0}nrc(o+(c[p>>2]|0)|0,s|0,t)|0;c[p>>2]=(c[p>>2]|0)+t;z=0;i=h;return z|0}}while(0);c[f>>2]=0;z=t;i=h;return z|0}function lca(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+336|0);c[b+340>>2]=0;return 0}function mca(a,b,c,e,f,g,h,i){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=h-g<<3;h=f+g|0;g=j>>>0>2147483639>>>0|(h|0)==0;f=g?0:h;h=g?8:j+8|0;g=(i|0)==0;i=a;a=1;k=0;a:while(1){if(g){l=0;m=k;while(1){if((m|0)>(j|0)){n=19;break a}else{o=0;p=1;q=m}do{r=f+(q>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>28;r=q+4|0;q=h>>>0>r>>>0?r:h;o=s|o<<4;p=p<<2;}while(o>>>0<p>>>0&p>>>0<65>>>0);r=o>>>0<4>>>0?2147483647:o>>>2;t=c-l|0;u=(r|0)>(t|0)?t:r;mrc(i+l|0,s&3|0,u|0)|0;r=u+l|0;if((r|0)<(c|0)){l=r;m=q}else{v=q;break}}}else{m=0;l=k;while(1){if((l|0)>(j|0)){n=19;break a}r=d[f+(l>>>3)|0]|0;u=((l|0)<(h|0))+l|0;t=((u|0)<(h|0))+u|0;w=((d[f+(u>>>3)|0]|0)&128>>>((u&7)>>>0)|0)==0;u=f+(t>>>3)|0;x=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7);if(w){w=t+2|0;y=h>>>0>w>>>0?w:h;z=x>>>30&255}else{w=t+8|0;y=h>>>0>w>>>0?w:h;z=x>>>24&255}do{if((r&128>>>((l&7)>>>0)|0)==0){A=1;B=y}else{x=((y|0)<(h|0))+y|0;w=((d[f+(y>>>3)|0]|0)&128>>>((y&7)>>>0)|0)==0;t=f+(x>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7);if(w){w=x+3|0;A=(u>>>29)+2|0;B=h>>>0>w>>>0?w:h;break}else{w=u>>>25;u=x+7|0;A=(w|0)==0?2147483647:w+9|0;B=h>>>0>u>>>0?u:h;break}}}while(0);r=c-m|0;u=(A|0)>(r|0)?r:A;mrc(i+m|0,z|0,u|0)|0;r=u+m|0;if((r|0)<(c|0)){m=r;l=B}else{v=B;break}}}if((a|0)>=(e|0)){n=19;break}l=-v&7;if((l|0)==0){C=v}else{m=l+v|0;C=h>>>0>m>>>0?m:h}i=i+b|0;a=a+1|0;k=C}if((n|0)==19){return}}function nca(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+1024|0;d=b|0;e=c[a+60>>2]|0;f=e;nrc(e|0,1515728,64)|0;SFb(d,0,1);e=c[a+120>>2]|0;do{if((e|0)!=0){g=c[a+124>>2]|0;if((g|0)==0){break}UFb(d,2618016,(h=i,i=i+16|0,c[h>>2]=e,c[h+8>>2]=g,h)|0);i=h}}while(0);UFb(d,2590608,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;e=0;do{UFb(d,2568848,(h=i,i=i+16|0,c[h>>2]=c[f+(e<<2)>>2]&16777215,c[h+8>>2]=(e|0)<15?44:10,h)|0);i=h;e=e+1|0;}while((e|0)<16);e=T5a(a,d)|0;i=b;return((e|0)<0?e:0)|0}function oca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;h=i;i=i+2376|0;j=h|0;k=h+16|0;l=h+152|0;m=h+1176|0;n=h+1184|0;o=h+1320|0;p=h+2344|0;q=h+2360|0;r=b+60|0;s=c[r>>2]|0;t=c[g+12>>2]|0;mrc(n|0,0,132)|0;if((t|0)==0){u=-22;i=h;return u|0}v=g+16|0;w=c[v>>2]|0;if((w|0)==0){u=-22;i=h;return u|0}else{x=0}while(1){if((x|0)>=(t|0)){break}if((c[(c[w+(x<<2)>>2]|0)+84>>2]|0)==1){x=x+1|0}else{z=5;break}}if((z|0)==5){KIb(b,16,2454744,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;u=-22;i=h;return u|0}x=c[w>>2]|0;B=c[x>>2]|0;C=c[x+4>>2]|0;D=c[x+8>>2]|0;E=c[x+12>>2]|0;F=c[x+20>>2]|0;x=(t|0)>1;do{if(x){G=1;H=B;I=D+B|0;J=C;K=E+C|0;do{L=c[w+(G<<2)>>2]|0;M=c[L>>2]|0;H=(H|0)>(M|0)?M:H;N=c[L+4>>2]|0;J=(J|0)>(N|0)?N:J;O=(c[L+8>>2]|0)+M|0;I=(I|0)>(O|0)?I:O;O=(c[L+12>>2]|0)+N|0;K=(K|0)>(O|0)?K:O;G=G+1|0;}while((G|0)<(t|0));G=I-H|0;O=K-J|0;N=tIb(G,O,0,b)|0;if((N|0)<0){u=N;i=h;return u|0}N=ca(O,G)|0;L=n|0;c[L>>2]=N;if((t|0)<=0){P=N;Q=O;R=G;S=J;T=H;U=L;z=10;break}M=c[v>>2]|0;V=0;W=N;do{N=c[M+(V<<2)>>2]|0;W=W-(ca(c[N+12>>2]|0,c[N+8>>2]|0)|0)|0;V=V+1|0;}while((V|0)<(t|0));c[L>>2]=W;X=H;Y=J;Z=G;_=O;$=W;aa=M;z=8}else{X=B;Y=C;Z=D;_=E;$=0;aa=w;z=8}}while(0);do{if((z|0)==8){if((t|0)<=0){P=$;Q=_;R=Z;S=Y;T=X;U=n|0;z=10;break}w=l;E=c[r>>2]|0;D=E;C=0;do{B=c[aa+(C<<2)>>2]|0;mrc(w|0,0,1024)|0;V=c[B+24>>2]|0;K=c[B+12>>2]|0;do{if((K|0)>0){I=B+52|0;N=c[B+8>>2]|0;if((N|0)<=0){ba=0;da=0;break}ea=0;fa=c[B+20>>2]|0;while(1){ga=0;ha=fa;while(1){ia=l+((d[ha]|0)<<2)|0;c[ia>>2]=(c[ia>>2]|0)+1;ia=ga+1|0;if((ia|0)<(N|0)){ga=ia;ha=ha+1|0}else{break}}ha=ea+1|0;if((ha|0)<(K|0)){ea=ha;fa=fa+(c[I>>2]|0)|0}else{ba=0;da=0;break}}}else{ba=0;da=0}}while(0);while(1){K=c[l+(ba<<2)>>2]|0;if((K|0)==0){ja=da}else{B=c[V+(ba<<2)>>2]|0;if(B>>>0<855638016>>>0){ka=da;la=0}else{I=B>>>16&255;fa=B>>>8&255;ea=B&255;N=0;ha=2147483647;ga=da;while(1){ia=c[D+(N<<2)>>2]|0;ma=(I-(ia>>>16&255)|0)*15|0;na=(fa-(ia>>>8&255)|0)*15|0;oa=(ea-(ia&255)|0)*15|0;ia=(ca(ma,ma)|0)+(ca(oa,oa)|0)+(ca(na,na)|0)|0;na=(ia|0)<(ha|0);pa=na?N:ga;oa=N+1|0;if((oa|0)<16){N=oa;ha=na?ia:ha;ga=pa}else{break}}ka=pa;la=pa+(B>>>0<3422552064>>>0?1:17)|0}ga=n+(la<<2)|0;c[ga>>2]=(c[ga>>2]|0)+K;ja=ka}ga=ba+1|0;if((ga|0)<256){ba=ga;da=ja}else{break}}C=C+1|0;}while((C|0)<(t|0));C=n|0;qa=c[C>>2]|0;ra=E;sa=C;ta=_;ua=Z;va=Y;wa=X;xa=1}}while(0);if((z|0)==10){qa=P;ra=c[r>>2]|0;sa=U;ta=Q;ua=R;va=S;wa=T;xa=0}mrc(j|0,0,16)|0;mrc(k|0,0,132)|0;c[sa>>2]=qa<<4;qa=ra;sa=0;while(1){T=sa+1|0;S=n+(T<<2)|0;R=c[S>>2]|0;Q=n+(sa+17<<2)|0;U=c[Q>>2]|0;if((R|0)!=(-U|0)){P=c[qa+(sa<<2)>>2]|0;z=P&255;if(z>>>0<64>>>0){ya=1}else{ya=z>>>0>191>>>0|0}z=P>>>8&255;if(z>>>0<64>>>0){za=1}else{za=z>>>0>191>>>0|0}z=P>>>16&255;if(z>>>0<64>>>0){Aa=1}else{Aa=z>>>0>191>>>0|0}z=za+ya+Aa|0;P=(z|0)>2?4:z+2|0;c[S>>2]=ca(P,R)|0;c[Q>>2]=ca(P,U)|0}if((T|0)<16){sa=T}else{break}}sa=p|0;Aa=j|0;ya=0;za=0;while(1){if((c[n+(ya<<2)>>2]|0)>>>0>(c[n+(za<<2)>>2]|0)>>>0){c[Aa>>2]=ya;Ba=ya}else{Ba=za}T=ya+1|0;if((T|0)<33){ya=T;za=Ba}else{break}}za=q|0;c[n+(Ba<<2)>>2]=0;ya=j+4|0;T=0;U=0;while(1){if((c[n+(T<<2)>>2]|0)>>>0>(c[n+(U<<2)>>2]|0)>>>0){c[ya>>2]=T;Ca=T}else{Ca=U}P=T+1|0;if((P|0)<33){T=P;U=Ca}else{break}}c[n+(Ca<<2)>>2]=0;Ca=j+8|0;U=0;T=0;while(1){if((c[n+(U<<2)>>2]|0)>>>0>(c[n+(T<<2)>>2]|0)>>>0){c[Ca>>2]=U;Da=U}else{Da=T}P=U+1|0;if((P|0)<33){U=P;T=Da}else{break}}c[n+(Da<<2)>>2]=0;Da=j+12|0;T=0;U=0;while(1){if((c[n+(T<<2)>>2]|0)>>>0>(c[n+(U<<2)>>2]|0)>>>0){c[Da>>2]=T;Ea=T}else{Ea=U}P=T+1|0;if((P|0)<33){T=P;U=Ea}else{break}}c[n+(Ea<<2)>>2]=0;Ea=0;while(1){n=c[qa+(Ea<<2)>>2]|0;U=Ea+1|0;c[k+(U<<2)>>2]=n|-2147483648;c[k+(Ea+17<<2)>>2]=n|-16777216;if((U|0)<16){Ea=U}else{Fa=0;Ga=Ba;break}}while(1){Ba=c[601520+(Fa<<2)>>2]|0;Ea=j+(Fa<<2)|0;qa=c[k+(Ga<<2)>>2]|0;U=Ba>>>28;n=qa>>>28;T=Ba>>>24<<3;P=T-(qa>>>24<<3)|0;Q=ca(Ba>>>16&255,U)|0;R=Q-(ca(qa>>>16&255,n)|0)|0;S=ca(Ba>>>8&255,U)|0;z=S-(ca(qa>>>8&255,n)|0)|0;X=ca(Ba&255,U)|0;U=X-(ca(n,qa&255)|0)|0;qa=Fa+1|0;n=(ca(U,U)|0)+(ca(P,P)|0)+(ca(R,R)|0)+(ca(z,z)|0)|0;z=qa;R=Ga;while(1){P=j+(z<<2)|0;U=c[P>>2]|0;Ba=c[k+(U<<2)>>2]|0;Y=Ba>>>28;Z=T-(Ba>>>24<<3)|0;_=Q-(ca(Ba>>>16&255,Y)|0)|0;ja=S-(ca(Ba>>>8&255,Y)|0)|0;da=X-(ca(Y,Ba&255)|0)|0;Ba=(ca(da,da)|0)+(ca(Z,Z)|0)+(ca(_,_)|0)+(ca(ja,ja)|0)|0;if((Ba|0)<(n|0)){c[P>>2]=R;c[Ea>>2]=U;Ha=Ba;Ia=U}else{Ha=n;Ia=R}U=z+1|0;if((U|0)<4){n=Ha;z=U;R=Ia}else{break}}if((qa|0)>=3){break}Fa=qa;Ga=c[j+(qa<<2)>>2]|0}j=c[Aa>>2]|0;if((j|0)==0){c[sa>>2]=0;Ja=0}else{c[sa>>2]=j+15&15;Ja=(j|0)<17?128:255}c[za>>2]=Ja;Ja=c[ya>>2]|0;if((Ja|0)==0){c[p+4>>2]=0;Ka=0}else{c[p+4>>2]=Ja+15&15;Ka=(Ja|0)<17?128:255}Ja=q+4|0;c[Ja>>2]=Ka;Ka=c[Ca>>2]|0;if((Ka|0)==0){c[p+8>>2]=0;La=0}else{c[p+8>>2]=Ka+15&15;La=(Ka|0)<17?128:255}Ka=q+8|0;c[Ka>>2]=La;La=c[Da>>2]|0;if((La|0)==0){c[p+12>>2]=0;Ma=0}else{c[p+12>>2]=La+15&15;Ma=(La|0)<17?128:255}La=q+12|0;c[La>>2]=Ma;if(x){x=qJb(ua,ta)|0;if((x|0)==0){u=-12;i=h;return u|0}Ma=o|0;if(xa){xa=0;do{pca(c[r>>2]|0,Ma,c[(c[(c[v>>2]|0)+(xa<<2)>>2]|0)+24>>2]|0,sa,za);q=c[(c[v>>2]|0)+(xa<<2)>>2]|0;Da=q+12|0;Ca=c[Da>>2]|0;if((Ca|0)>0){ya=x+((c[q>>2]|0)-wa+(ca((c[q+4>>2]|0)-va|0,ua)|0))|0;j=q+8|0;Aa=q+52|0;Ga=0;Fa=c[q+20>>2]|0;q=ya;ya=c[j>>2]|0;Ia=ua;Ha=Ca;while(1){if((ya|0)>0){Ca=0;k=Fa;R=q;while(1){Na=k+1|0;Oa=R+1|0;a[R]=c[o+((d[k]|0)<<2)>>2];z=Ca+1|0;Pa=c[j>>2]|0;if((z|0)<(Pa|0)){Ca=z;k=Na;R=Oa}else{break}}Qa=Na;Ra=Oa;Sa=Pa;Ta=ua;Ua=c[Da>>2]|0}else{Qa=Fa;Ra=q;Sa=ya;Ta=Ia;Ua=Ha}R=Ga+1|0;if((R|0)<(Ua|0)){Ga=R;Fa=Qa+((c[Aa>>2]|0)-Sa)|0;q=Ra+(Ta-Sa)|0;ya=Sa;Ia=Ta;Ha=Ua}else{break}}}xa=xa+1|0;}while((xa|0)<(t|0))}c[Ma>>2]=0;c[o+4>>2]=1;c[o+8>>2]=2;c[o+12>>2]=3;Va=x;Wa=x}else{pca(ra,o|0,c[(c[c[v>>2]>>2]|0)+24>>2]|0,sa,za);Va=0;Wa=F}F=b;KIb(F,48,2365224,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;b=s;s=c[sa>>2]|0;v=c[za>>2]|0;KIb(F,48,2300080,(A=i,i=i+32|0,c[A>>2]=c[b+(s<<2)>>2],c[A+8>>2]=v,c[A+16>>2]=s,c[A+24>>2]=v>>4,A)|0);i=A;v=p+4|0;s=c[v>>2]|0;ra=c[Ja>>2]|0;KIb(F,48,2300080,(A=i,i=i+32|0,c[A>>2]=c[b+(s<<2)>>2],c[A+8>>2]=ra,c[A+16>>2]=s,c[A+24>>2]=ra>>4,A)|0);i=A;ra=p+8|0;s=c[ra>>2]|0;x=c[Ka>>2]|0;KIb(F,48,2300080,(A=i,i=i+32|0,c[A>>2]=c[b+(s<<2)>>2],c[A+8>>2]=x,c[A+16>>2]=s,c[A+24>>2]=x>>4,A)|0);i=A;x=p+12|0;p=c[x>>2]|0;s=c[La>>2]|0;KIb(F,48,2300080,(A=i,i=i+32|0,c[A>>2]=c[b+(p<<2)>>2],c[A+8>>2]=s,c[A+16>>2]=p,c[A+24>>2]=s>>4,A)|0);i=A;KIb(F,48,2248984,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;c[m>>2]=e+4;F=e;if((((ca(ta,ua)|0)/2|0)+42|0)>(f|0)){KIb(0,16,2206832,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;Xa=-1397118274}else{f=ua<<1;s=o|0;qca(m,Wa,f,ua,ta+1>>1,s);o=(c[m>>2]|0)-F|0;qca(m,Wa+ua|0,f,ua,ta>>1,s);s=c[m>>2]|0;f=e+2|0;y=he(s-F&65535|0)|0;a[f]=y;y=y>>8;a[f+1|0]=y;f=s;y=he(((c[g+4>>2]|0)*90|0)>>>10&65535|0)|0;a[f]=y;y=y>>8;a[f+1|0]=y;f=(c[m>>2]|0)+2|0;c[m>>2]=f;s=f;y=he(22-F+f&65535|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;s=c[m>>2]|0;c[m>>2]=s+3;a[s+2|0]=3;s=(c[x>>2]<<4|c[ra>>2])&255;ra=c[m>>2]|0;c[m>>2]=ra+1;a[ra]=s;s=(c[v>>2]<<4|c[sa>>2])&255;sa=c[m>>2]|0;c[m>>2]=sa+1;a[sa]=s;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=4;s=((c[Ka>>2]|0)>>>4|c[La>>2]&240)&255;La=c[m>>2]|0;c[m>>2]=La+1;a[La]=s;s=((c[za>>2]|0)>>>4|c[Ja>>2]&240)&255;Ja=c[m>>2]|0;c[m>>2]=Ja+1;a[Ja]=s;s=wa-1+ua|0;ua=va-1+ta|0;ta=c[m>>2]|0;c[m>>2]=ta+1;a[ta]=5;ta=c[m>>2]|0;c[m>>2]=ta+1;a[ta]=wa>>>4;ta=c[m>>2]|0;c[m>>2]=ta+1;a[ta]=s>>>8&15|wa<<4;wa=c[m>>2]|0;c[m>>2]=wa+1;a[wa]=s;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=va>>>4;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=ua>>>8&15|va<<4;va=c[m>>2]|0;c[m>>2]=va+1;a[va]=ua;ua=c[m>>2]|0;c[m>>2]=ua+1;a[ua]=6;ua=c[m>>2]|0;y=1024;a[ua]=y;y=y>>8;a[ua+1|0]=y;ua=(c[m>>2]|0)+2|0;c[m>>2]=ua;va=ua;y=he(o&65535|0)|0;a[va]=y;y=y>>8;a[va+1|0]=y;va=c[m>>2]|0;c[m>>2]=va+3;a[va+2|0]=1;va=c[m>>2]|0;c[m>>2]=va+1;a[va]=-1;va=he(((c[g+8>>2]|0)*90|0)>>>10&65535|0)|0;g=c[m>>2]|0;y=va;a[g]=y;y=y>>8;a[g+1|0]=y;g=(c[m>>2]|0)+2|0;c[m>>2]=g;va=g;y=he(65534-F+g&65535|0)|0;a[va]=y;y=y>>8;a[va+1|0]=y;va=c[m>>2]|0;c[m>>2]=va+3;a[va+2|0]=2;va=c[m>>2]|0;c[m>>2]=va+1;a[va]=-1;va=(c[m>>2]|0)-F|0;g=e;y=he(va&65535|0)|0;a[g]=y;y=y>>8;a[g+1|0]=y;KIb(0,48,2174440,(A=i,i=i+8|0,c[A>>2]=va,A)|0);i=A;Xa=(c[m>>2]|0)-F|0}kJb(Va);u=Xa;i=h;return u|0}function pca(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g|0;j=a;c[h>>2]=c[j+(c[e>>2]<<2)>>2]|c[f>>2]<<24;c[h+4>>2]=c[j+(c[e+4>>2]<<2)>>2]|c[f+4>>2]<<24;c[h+8>>2]=c[j+(c[e+8>>2]<<2)>>2]|c[f+8>>2]<<24;c[h+12>>2]=c[j+(c[e+12>>2]<<2)>>2]|c[f+12>>2]<<24;f=0;do{e=d+(f<<2)|0;j=b+(f<<2)|0;a=0;k=2147483647;while(1){l=c[h+(a<<2)>>2]|0;m=c[e>>2]|0;n=l>>>28;o=m>>>28;p=(l>>>24<<3)-(m>>>24<<3)|0;q=(ca(l>>>16&255,n)|0)-(ca(m>>>16&255,o)|0)|0;r=(ca(l>>>8&255,n)|0)-(ca(m>>>8&255,o)|0)|0;s=(ca(l&255,n)|0)-(ca(o,m&255)|0)|0;m=(ca(s,s)|0)+(ca(p,p)|0)+(ca(q,q)|0)+(ca(r,r)|0)|0;if((m|0)<(k|0)){c[j>>2]=a;t=m}else{t=k}m=a+1|0;if((m|0)<4){a=m;k=t}else{break}}f=f+1|0;}while((f|0)<256);i=g;return}function qca(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=i;k=c[b>>2]|0;if((g|0)<=0){l=k;c[b>>2]=l;i=j;return}m=(f|0)>0;n=d;d=k;k=0;o=0;a:while(1){do{if(m){p=d;q=k;r=0;s=0;while(1){t=a[n+s|0]|0;u=t&255;v=1;while(1){w=v+s|0;if((w|0)>=(f|0)){break}if((a[n+w|0]|0)==t<<24>>24){v=v+1|0}else{break}}t=c[h+(u<<2)>>2]|0;if((t|0)>=4){x=8;break a}do{if((v|0)<4){y=r+1|0;z=t|v<<2;if((r&1|0)==0){A=v;B=y;C=z<<4;D=p;break}else{a[p]=z&15|q;A=v;B=y;C=q;D=p+1|0;break}}else{if((v|0)<16){y=v>>>2;if((r&1|0)==0){z=y<<4;a[p]=(t|v<<2)&15|z;A=v;B=r+2|0;C=z;D=p+1|0;break}else{a[p]=y&15|q;A=v;B=r+2|0;C=(t|v<<2)<<4;D=p+1|0;break}}if((v|0)<64){if((r&1|0)==0){a[p]=v>>>2&15;A=v;B=r+3|0;C=(t|v<<2)<<4;D=p+1|0;break}else{a[p]=q;y=v>>>2<<4;a[p+1|0]=(t|v<<2)&15|y;A=v;B=r+3|0;C=y;D=p+2|0;break}}if((w|0)==(f|0)){if((r&1|0)==0){a[p]=0;a[p+1|0]=t&15;A=v;B=r+4|0;C=0;D=p+2|0;break}else{a[p]=q;a[p+1|0]=0;A=v;B=r+4|0;C=t<<4;D=p+2|0;break}}else{y=(v|0)>255?255:v;if((r&1|0)==0){a[p]=y>>>6&15;z=y>>>2<<4;a[p+1|0]=(t|y<<2)&15|z;A=y;B=r+4|0;C=z;D=p+2|0;break}else{a[p]=q;a[p+1|0]=y>>6<<4|y>>>2&15;A=y;B=r+4|0;C=(t|y<<2)<<4;D=p+2|0;break}}}}while(0);t=A+s|0;if((t|0)<(f|0)){p=D;q=C;r=B;s=t}else{break}}if((B&1|0)==0){E=D;F=C;break}a[D]=C;E=D+1|0;F=C}else{E=d;F=k}}while(0);s=o+1|0;if((s|0)<(g|0)){n=n+e|0;d=E;k=F;o=s}else{l=E;x=32;break}}if((x|0)==8){KIb(0,0,2146888,(E=i,i=i+24|0,c[E>>2]=2123056,c[E+8>>2]=2640720,c[E+16>>2]=61,E)|0);i=E;Hd()}else if((x|0)==32){c[b>>2]=l;i=j;return}}function rca(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;if((Uba(b)|0)==0){g=b;h=c[b+120>>2]|0;j=c[b+124>>2]|0;k=mKb(c[b+140>>2]|0)|0;KIb(g,16,2299968,(l=i,i=i+24|0,c[l>>2]=h,c[l+8>>2]=j,c[l+16>>2]=k,l)|0);i=l;Vba(g,16);m=-22;i=f;return m|0}if((c[b+124>>2]|0)>576){KIb(b,16,2248944,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1163346256;i=f;return m|0}l=UHb()|0;c[b+804>>2]=l;if((l|0)==0){m=-12;i=f;return m|0}else{n=0}while(1){l=a[1394488+n|0]|0;do{if(!((l&255)>>>0>63>>>0)){g=l&255;k=a[1394904+n|0]|0;j=k&255;h=8984712+(g<<12)+(j<<3)+4|0;if((c[h>>2]|0)!=0){break}o=k<<24>>24!=0|0;c[8984712+(g<<12)+(j<<3)>>2]=(e[1395736+(n<<1)>>1]|0)<<o;c[h>>2]=(d[1395320+n|0]|0)+o}}while(0);l=n+1|0;if((l|0)<408){n=l}else{p=0;break}}do{n=p-1|0;l=8984712+(n<<12)|0;o=8984716+(n<<12)|0;n=1;do{h=8984712+(p<<12)+(n<<3)|0;j=8984712+(p<<12)+(n<<3)+4|0;g=c[j>>2]|0;if((g|0)==0){k=c[8984716+(n<<3)>>2]|0;q=c[l>>2]<<k|c[8984712+(n<<3)>>2];c[h>>2]=q;r=(c[o>>2]|0)+k|0;c[j>>2]=r;s=r;t=q}else{s=g;t=c[h>>2]|0}h=-n&511;c[8984712+(p<<12)+(h<<3)>>2]=t|1;c[8984712+(p<<12)+(h<<3)+4>>2]=s;n=n+1|0;}while((n|0)<256);p=p+1|0;}while((p|0)<64);m=spb(b)|0;i=f;return m|0}function sca(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c[b+60>>2]|0;h=Uba(b)|0;i=g;c[i>>2]=h;if((h|0)==0){j=-1;return j|0}if((rpb(h)|0)!=0){j=-1;return j|0}h=c[(c[i>>2]|0)+8>>2]|0;k=d5a(b,d,h,(h|0)<0|0?-1:0)|0;if((k|0)<0){j=k;return j|0}k=c[i>>2]|0;c[b+140>>2]=c[k+64>>2];h=g+4|0;c[h>>2]=e;e=c[b+804>>2]|0;c[e+84>>2]=1;c[e+88>>2]=1;e=d+24|0;c[g+12>>2]=c[e>>2];l=c[b+824>>2]|0;m=c[k+56>>2]|0;n=ca((c[k+16>>2]|0)*27|0,c[k+12>>2]|0)|0;o=c[k+4>>2]|0;if((o|0)==24){p=(c[k>>2]|0)==1?n-108|0:n}else if((o|0)==20){p=(c[k>>2]|0)==1?n-81|0:n}else{p=n}se[l&127](b,778,m,0,p,12)|0;p=c[i>>2]|0;if((c[p+16>>2]|0)>0){m=g+8|0;g=c[e>>2]|0;e=0;b=p;while(1){if((c[b+12>>2]|0)>0){p=(e&255)<<3;l=g;n=0;while(1){mrc(l|0,-1|0,480)|0;a[l]=31;k=p|(n&255)<<4|7;a[l+1|0]=k;a[l+2|0]=0;o=c[i>>2]|0;q=(c[o+64>>2]|0)!=0|0;a[l+3|0]=(c[o>>2]|0)!=0?-65:63;a[l+4|0]=q|248;o=(q|120)&255;a[l+5|0]=o;a[l+6|0]=o;a[l+7|0]=o;a[l+80|0]=63;a[l+81|0]=k;a[l+82|0]=0;o=l+83|0;q=0;while(1){r=q&255;s=(n|0)<((c[(c[i>>2]|0)+12>>2]|0)/2|0|0);do{if((r<<24>>24|0)==0|(r<<24>>24|0)==6){a[o]=(s&1)<<7|15}else{t=(s&1)<<7;if(r<<24>>24==11){a[o]=t|127;break}else{a[o]=t|15;break}}}while(0);a[o+1|0]=r|-16;a[o+2|0]=-1;s=q+1|0;if((s|0)<6){o=o+8|0;q=s}else{break}}a[l+160|0]=63;a[l+161|0]=k;a[l+162|0]=1;q=l+163|0;o=0;while(1){s=o&255;t=(n|0)<((c[(c[i>>2]|0)+12>>2]|0)/2|0|0);do{if((s<<24>>24|0)==0|(s<<24>>24|0)==6){a[q]=(t&1)<<7|15}else{u=(t&1)<<7;if(s<<24>>24==11){a[q]=u|127;break}else{a[q]=u|15;break}}}while(0);a[q+1|0]=s|-16;a[q+2|0]=-1;t=o+1|0;if((t|0)<6){q=q+8|0;o=t}else{break}}o=l+240|0;q=0;while(1){a[o]=86;a[o+1|0]=k;a[o+2|0]=q;a[o+3|0]=96;a[o+4|0]=-1;a[o+5|0]=-1;t=c[i>>2]|0;a[o+6|0]=c[t+4>>2]|c[t>>2]<<5|192;a[o+7|0]=-1;t=c[(c[h>>2]|0)+300>>2]|0;r=c[m>>2]|0;u=c[r+224>>2]|0;v=c[r+228>>2]|0;w=c[r+120>>2]|0;x=c[r+124>>2]|0;a[o+8|0]=97;a[o+9|0]=63;a[o+10|0]=(~~(+(w|0)*(+(u|0)/+(v|0))/+(x|0)*10.0)|0)>16?-54:-56;a[o+11|0]=(t|0)!=0?-68:-4;a[o+12|0]=-1;a[o+48|0]=96;a[o+49|0]=-1;a[o+50|0]=-1;t=c[i>>2]|0;a[o+51|0]=c[t+4>>2]|c[t>>2]<<5|192;a[o+52|0]=-1;t=c[(c[h>>2]|0)+300>>2]|0;x=c[m>>2]|0;v=c[x+224>>2]|0;u=c[x+228>>2]|0;w=c[x+120>>2]|0;r=c[x+124>>2]|0;a[o+53|0]=97;a[o+54|0]=63;a[o+55|0]=(~~(+(w|0)*(+(v|0)/+(u|0))/+(r|0)*10.0)|0)>16?-54:-56;a[o+56|0]=(t|0)!=0?-68:-4;a[o+57|0]=-1;t=q+1|0;if((t|0)<3){o=o+80|0;q=t}else{break}}q=l+480|0;o=0;do{if(((o|0)%15|0|0)==0){mrc(q|0,-1|0,80)|0;a[q]=118;a[q+1|0]=k;a[q+2|0]=(o|0)/15|0;y=q+80|0}else{y=q}a[y]=-106;a[y+1|0]=k;a[y+2|0]=o;q=y+80|0;o=o+1|0;}while((o|0)<135);o=n+1|0;k=c[i>>2]|0;if((o|0)<(c[k+12>>2]|0)){l=q;n=o}else{z=q;A=k;break}}}else{z=g;A=b}n=e+1|0;if((n|0)<(c[A+16>>2]|0)){g=z;e=n;b=A}else{break}}}A=d+36|0;c[A>>2]=c[A>>2]|1;c[f>>2]=1;j=0;return j|0}function tca(a){a=a|0;VHb(a+804|0);return 0}function uca(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0;h=i;i=i+14384|0;j=h|0;k=h+128|0;l=h+280|0;m=h+13400|0;n=h+14360|0;o=c[f+60>>2]|0;p=o;q=g;r=h+152|0;s=n;c[s>>2]=c[379398];c[s+4>>2]=c[379399];c[s+8>>2]=c[379400];c[s+12>>2]=c[379401];c[s+16>>2]=c[379402];s=e[g>>1]|0;g=o+12|0;t=c[g>>2]|0;u=l|0;v=o;w=o+4|0;x=j;z=j|0;A=o+8|0;B=o+144|0;C=o+164|0;o=u;D=0;E=0;while(1){F=b[q+2+(E<<1)>>1]|0;G=F&65535;H=G&255;I=G>>>8;G=c[v>>2]|0;J=c[G+32>>2]|0;do{if((J|0)==720){if(!((a[(c[g>>2]|0)+1|0]&12)==0)){K=I;break}K=I-((F&65535)>>>0>4607>>>0?18:-72)|0}else{K=I}}while(0);I=c[G+64>>2]|0;if((I|0)==7){if(H>>>0>87>>>0){L=9}else{L=7}}else if((I|0)==0){L=9}else{L=7}do{if((L|0)==7){L=0;if((J|0)<=719){M=16;N=K;break}if((K|0)==134){M=16;N=134}else{L=9}}}while(0);if((L|0)==9){L=0;M=c[(c[w>>2]|0)+32>>2]<<3;N=K}J=c[w>>2]|0;I=c[J>>2]|0;F=c[J+32>>2]|0;J=(ca(F,N)|0)+H<<3;O=I+J|0;P=(c[G+4>>2]|0)==4;a[o+320|0]=0;c[o+324>>2]=0;c[o+52>>2]=0;mrc(o|0,0,16)|0;if((O|0)==0){mrc(x|0,0,128)|0;c[o+60>>2]=0;Q=0;R=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){S=0}else{T=(Xe[c[C>>2]&511](0,O,0,F,8)|0)-400|0;if((T|0)<=0){S=0;break}U=F<<1;V=Xe[c[C>>2]&511](0,O,0,U,4)|0;S=(T|0)>((Xe[c[C>>2]&511](0,I+(J+F)|0,0,U,4)|0)+V|0)|0}}while(0);G=o+60|0;c[G>>2]=S;ef[c[B>>2]&4095](z,O,F);qe[c[p+148+(c[G>>2]<<2)>>2]&1023](z);Q=b[z>>1]|0;R=(c[G>>2]|0)!=0}b[o+64>>1]=Q;G=R?1242144:1242080;V=R?1516160:1515904;U=0;T=-1;W=0;X=1;while(1){c[o+32+(U<<2)>>2]=W;Y=o+16+(U<<2)|0;c[Y>>2]=1;Z=U+1|0;_=c[833e3+(Z<<2)>>2]|0;$=X&255;if((X|0)<(_|0)){aa=X+1|0;ba=X;da=T;ea=W;while(1){fa=b[j+(d[G+ba|0]<<1)>>1]|0;ga=fa<<16>>16;if((ga+15|0)>>>0>30>>>0){a[o+256+ba|0]=ga>>>31;ha=(ca(c[V+(ba<<2)>>2]|0,fa<<16>>16>-1?ga:-ga|0)|0)+2097152>>22;b[o+64+(ba<<1)>>1]=ha;c[Y>>2]=(c[Y>>2]|0)+(c[8984712+(ba+~ea<<12)+(ha<<3)+4>>2]|0);a[o+192+ea|0]=ba;ia=ba;ja=(ha|0)>(da|0)?ha:da}else{ia=ea;ja=da}ha=ba+1|0;if((ha|0)<(_|0)){ba=ha;da=ja;ea=ia}else{break}}ka=((_|0)>(aa|0)?_:aa)&255;la=ja;ma=ia}else{ka=$;la=T;ma=W}if((Z|0)<4){U=Z;T=la;W=ma;X=_}else{break}}a[o+192+ma|0]=ka;X=o+56|0;W=0;while(1){c[X>>2]=W;if((la|0)>(c[1517576+(W<<2)>>2]|0)){W=W+1|0}else{break}}c[X>>2]=W;if((W|0)>2){c[X>>2]=3;T=d[o+192|0]|0;U=0;V=0;while(1){c[o+32+(U<<2)>>2]=V;G=o+16+(U<<2)|0;c[G>>2]=1;O=U+1|0;ea=c[833e3+(O<<2)>>2]|0;if((T|0)<(ea|0)){da=T;ba=V;while(1){Y=o+64+(da<<1)|0;ha=(b[Y>>1]|0)>>>1&65535;b[Y>>1]=ha;if(ha<<16>>16==0){na=ba}else{c[G>>2]=(c[G>>2]|0)+(c[8984712+(da+~ba<<12)+(ha<<16>>16<<3)+4>>2]|0);a[o+192+ba|0]=da;na=da}ha=d[o+192+da|0]|0;if((ha|0)<(ea|0)){da=ha;ba=na}else{oa=ha;pa=na;break}}}else{oa=T;pa=V}if((O|0)<4){T=oa;U=O;V=pa}else{break}}a[o+192+pa|0]=oa}V=(c[o+20>>2]|0)+(c[o+16>>2]|0)+(c[o+24>>2]|0)+(c[o+28>>2]|0)|0;U=o+328|0;if(P){a[o+648|0]=0;c[o+652>>2]=0;c[o+380>>2]=0;mrc(U|0,0,16)|0;mrc(x|0,0,128)|0;c[o+388>>2]=0;b[o+392>>1]=0;T=0;X=-1;W=0;ba=1;while(1){c[o+360+(T<<2)>>2]=W;da=o+344+(T<<2)|0;c[da>>2]=1;ea=T+1|0;G=c[833e3+(ea<<2)>>2]|0;_=ba&255;if((ba|0)<(G|0)){Z=ba+1|0;$=ba;aa=X;ha=W;while(1){Y=b[j+(d[1242080+$|0]<<1)>>1]|0;ga=Y<<16>>16;if((ga+15|0)>>>0>30>>>0){a[o+584+$|0]=ga>>>31;fa=(ca(c[1515904+($<<2)>>2]|0,Y<<16>>16>-1?ga:-ga|0)|0)+2097152>>22;b[o+392+($<<1)>>1]=fa;c[da>>2]=(c[da>>2]|0)+(c[8984712+($+~ha<<12)+(fa<<3)+4>>2]|0);a[o+520+ha|0]=$;qa=$;ra=(fa|0)>(aa|0)?fa:aa}else{qa=ha;ra=aa}fa=$+1|0;if((fa|0)<(G|0)){$=fa;aa=ra;ha=qa}else{break}}sa=((G|0)>(Z|0)?G:Z)&255;ta=ra;ua=qa}else{sa=_;ta=X;ua=W}if((ea|0)<4){T=ea;X=ta;W=ua;ba=G}else{break}}a[o+520+ua|0]=sa;ba=o+384|0;W=0;while(1){c[ba>>2]=W;if((ta|0)>(c[1517576+(W<<2)>>2]|0)){W=W+1|0}else{break}}c[ba>>2]=W;if((W|0)>2){c[ba>>2]=3;X=d[o+520|0]|0;T=0;P=0;while(1){c[o+360+(T<<2)>>2]=P;ha=o+344+(T<<2)|0;c[ha>>2]=1;aa=T+1|0;$=c[833e3+(aa<<2)>>2]|0;if((X|0)<($|0)){da=X;O=P;while(1){fa=o+392+(da<<1)|0;ga=(b[fa>>1]|0)>>>1&65535;b[fa>>1]=ga;if(ga<<16>>16==0){va=O}else{c[ha>>2]=(c[ha>>2]|0)+(c[8984712+(da+~O<<12)+(ga<<16>>16<<3)+4>>2]|0);a[o+520+O|0]=da;va=da}ga=d[o+520+da|0]|0;if((ga|0)<($|0)){da=ga;O=va}else{wa=ga;xa=va;break}}}else{wa=X;xa=P}if((aa|0)<4){X=wa;T=aa;P=xa}else{break}}a[o+520+xa|0]=wa}P=c[o+344>>2]|0;T=c[o+348>>2]|0;X=c[o+352>>2]|0;ba=c[o+356>>2]|0;W=J+8|0;O=I+W|0;a[o+976|0]=0;c[o+980>>2]=0;c[o+708>>2]=0;mrc(o+656|0,0,16)|0;if((O|0)==0){mrc(x|0,0,128)|0;c[o+716>>2]=0;ya=0;za=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){Aa=0}else{da=(Xe[c[C>>2]&511](0,O,0,F,8)|0)-400|0;if((da|0)<=0){Aa=0;break}$=F<<1;ha=Xe[c[C>>2]&511](0,O,0,$,4)|0;Aa=(da|0)>((Xe[c[C>>2]&511](0,I+(W+F)|0,0,$,4)|0)+ha|0)|0}}while(0);W=o+716|0;c[W>>2]=Aa;ef[c[B>>2]&4095](z,O,F);qe[c[p+148+(c[W>>2]<<2)>>2]&1023](z);ya=b[z>>1]|0;za=(c[W>>2]|0)!=0}b[o+720>>1]=ya;W=za?1242144:1242080;ha=za?1516160:1515904;$=0;da=-1;G=0;ea=1;while(1){c[o+688+($<<2)>>2]=G;_=o+672+($<<2)|0;c[_>>2]=1;Z=$+1|0;ga=c[833e3+(Z<<2)>>2]|0;fa=ea&255;if((ea|0)<(ga|0)){Y=ea+1|0;Ba=ea;Ca=da;Da=G;while(1){Ea=b[j+(d[W+Ba|0]<<1)>>1]|0;Fa=Ea<<16>>16;if((Fa+15|0)>>>0>30>>>0){a[o+912+Ba|0]=Fa>>>31;Ga=(ca(c[ha+(Ba<<2)>>2]|0,Ea<<16>>16>-1?Fa:-Fa|0)|0)+2097152>>22;b[o+720+(Ba<<1)>>1]=Ga;c[_>>2]=(c[_>>2]|0)+(c[8984712+(Ba+~Da<<12)+(Ga<<3)+4>>2]|0);a[o+848+Da|0]=Ba;Ha=Ba;Ia=(Ga|0)>(Ca|0)?Ga:Ca}else{Ha=Da;Ia=Ca}Ga=Ba+1|0;if((Ga|0)<(ga|0)){Ba=Ga;Ca=Ia;Da=Ha}else{break}}Ja=((ga|0)>(Y|0)?ga:Y)&255;Ka=Ia;La=Ha}else{Ja=fa;Ka=da;La=G}if((Z|0)<4){$=Z;da=Ka;G=La;ea=ga}else{break}}a[o+848+La|0]=Ja;ea=o+712|0;G=0;while(1){c[ea>>2]=G;if((Ka|0)>(c[1517576+(G<<2)>>2]|0)){G=G+1|0}else{break}}c[ea>>2]=G;if((G|0)>2){c[ea>>2]=3;da=d[o+848|0]|0;$=0;ha=0;while(1){c[o+688+($<<2)>>2]=ha;W=o+672+($<<2)|0;c[W>>2]=1;O=$+1|0;Da=c[833e3+(O<<2)>>2]|0;if((da|0)<(Da|0)){Ca=da;Ba=ha;while(1){_=o+720+(Ca<<1)|0;aa=(b[_>>1]|0)>>>1&65535;b[_>>1]=aa;if(aa<<16>>16==0){Ma=Ba}else{c[W>>2]=(c[W>>2]|0)+(c[8984712+(Ca+~Ba<<12)+(aa<<16>>16<<3)+4>>2]|0);a[o+848+Ba|0]=Ca;Ma=Ca}aa=d[o+848+Ca|0]|0;if((aa|0)<(Da|0)){Ca=aa;Ba=Ma}else{Na=aa;Oa=Ma;break}}}else{Na=da;Oa=ha}if((O|0)<4){da=Na;$=O;ha=Oa}else{break}}a[o+848+Oa|0]=Na}ha=c[o+672>>2]|0;$=c[o+676>>2]|0;da=c[o+680>>2]|0;ea=c[o+684>>2]|0;a[o+1304|0]=0;c[o+1308>>2]=0;c[o+1036>>2]=0;mrc(o+984|0,0,16)|0;mrc(x|0,0,128)|0;c[o+1044>>2]=0;b[o+1048>>1]=0;G=0;Ba=-1;Ca=0;Da=1;while(1){c[o+1016+(G<<2)>>2]=Ca;W=o+1e3+(G<<2)|0;c[W>>2]=1;ga=G+1|0;Z=c[833e3+(ga<<2)>>2]|0;fa=Da&255;if((Da|0)<(Z|0)){Y=Da+1|0;aa=Da;_=Ba;Ga=Ca;while(1){Fa=b[j+(d[1242080+aa|0]<<1)>>1]|0;Ea=Fa<<16>>16;if((Ea+15|0)>>>0>30>>>0){a[o+1240+aa|0]=Ea>>>31;Pa=(ca(c[1515904+(aa<<2)>>2]|0,Fa<<16>>16>-1?Ea:-Ea|0)|0)+2097152>>22;b[o+1048+(aa<<1)>>1]=Pa;c[W>>2]=(c[W>>2]|0)+(c[8984712+(aa+~Ga<<12)+(Pa<<3)+4>>2]|0);a[o+1176+Ga|0]=aa;Qa=aa;Ra=(Pa|0)>(_|0)?Pa:_}else{Qa=Ga;Ra=_}Pa=aa+1|0;if((Pa|0)<(Z|0)){aa=Pa;_=Ra;Ga=Qa}else{break}}Sa=((Z|0)>(Y|0)?Z:Y)&255;Ta=Ra;Ua=Qa}else{Sa=fa;Ta=Ba;Ua=Ca}if((ga|0)<4){G=ga;Ba=Ta;Ca=Ua;Da=Z}else{break}}a[o+1176+Ua|0]=Sa;Da=o+1040|0;Ca=0;while(1){c[Da>>2]=Ca;if((Ta|0)>(c[1517576+(Ca<<2)>>2]|0)){Ca=Ca+1|0}else{break}}c[Da>>2]=Ca;if((Ca|0)>2){c[Da>>2]=3;Ba=d[o+1176|0]|0;G=0;Ga=0;while(1){c[o+1016+(G<<2)>>2]=Ga;_=o+1e3+(G<<2)|0;c[_>>2]=1;aa=G+1|0;W=c[833e3+(aa<<2)>>2]|0;if((Ba|0)<(W|0)){O=Ba;Pa=Ga;while(1){Ea=o+1048+(O<<1)|0;Fa=(b[Ea>>1]|0)>>>1&65535;b[Ea>>1]=Fa;if(Fa<<16>>16==0){Va=Pa}else{c[_>>2]=(c[_>>2]|0)+(c[8984712+(O+~Pa<<12)+(Fa<<16>>16<<3)+4>>2]|0);a[o+1176+Pa|0]=O;Va=O}Fa=d[o+1176+O|0]|0;if((Fa|0)<(W|0)){O=Fa;Pa=Va}else{Wa=Fa;Xa=Va;break}}}else{Wa=Ba;Xa=Ga}if((aa|0)<4){Ba=Wa;G=aa;Ga=Xa}else{break}}a[o+1176+Xa|0]=Wa}Ya=P+V+T+X+ba+ha+$+da+ea+(c[o+1e3>>2]|0)+(c[o+1004>>2]|0)+(c[o+1008>>2]|0)+(c[o+1012>>2]|0)|0}else{Ga=J+8|0;G=I+Ga|0;a[o+648|0]=0;c[o+652>>2]=0;c[o+380>>2]=0;mrc(U|0,0,16)|0;if((G|0)==0){mrc(x|0,0,128)|0;c[o+388>>2]=0;Za=0;_a=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){$a=0}else{Ba=(Xe[c[C>>2]&511](0,G,0,F,8)|0)-400|0;if((Ba|0)<=0){$a=0;break}Da=F<<1;Ca=Xe[c[C>>2]&511](0,G,0,Da,4)|0;$a=(Ba|0)>((Xe[c[C>>2]&511](0,I+(Ga+F)|0,0,Da,4)|0)+Ca|0)|0}}while(0);U=o+388|0;c[U>>2]=$a;ef[c[B>>2]&4095](z,G,F);qe[c[p+148+(c[U>>2]<<2)>>2]&1023](z);Za=b[z>>1]|0;_a=(c[U>>2]|0)!=0}b[o+392>>1]=Za;U=_a?1242144:1242080;ea=_a?1516160:1515904;da=0;$=-1;ha=0;ba=1;while(1){c[o+360+(da<<2)>>2]=ha;X=o+344+(da<<2)|0;c[X>>2]=1;T=da+1|0;P=c[833e3+(T<<2)>>2]|0;Ca=ba&255;if((ba|0)<(P|0)){Da=ba+1|0;Ba=ba;Pa=$;O=ha;while(1){W=b[j+(d[U+Ba|0]<<1)>>1]|0;_=W<<16>>16;if((_+15|0)>>>0>30>>>0){a[o+584+Ba|0]=_>>>31;Z=(ca(c[ea+(Ba<<2)>>2]|0,W<<16>>16>-1?_:-_|0)|0)+2097152>>22;b[o+392+(Ba<<1)>>1]=Z;c[X>>2]=(c[X>>2]|0)+(c[8984712+(Ba+~O<<12)+(Z<<3)+4>>2]|0);a[o+520+O|0]=Ba;ab=Ba;bb=(Z|0)>(Pa|0)?Z:Pa}else{ab=O;bb=Pa}Z=Ba+1|0;if((Z|0)<(P|0)){Ba=Z;Pa=bb;O=ab}else{break}}cb=((P|0)>(Da|0)?P:Da)&255;db=bb;eb=ab}else{cb=Ca;db=$;eb=ha}if((T|0)<4){da=T;$=db;ha=eb;ba=P}else{break}}a[o+520+eb|0]=cb;ba=o+384|0;ha=0;while(1){c[ba>>2]=ha;if((db|0)>(c[1517576+(ha<<2)>>2]|0)){ha=ha+1|0}else{break}}c[ba>>2]=ha;if((ha|0)>2){c[ba>>2]=3;$=d[o+520|0]|0;da=0;ea=0;while(1){c[o+360+(da<<2)>>2]=ea;U=o+344+(da<<2)|0;c[U>>2]=1;G=da+1|0;O=c[833e3+(G<<2)>>2]|0;if(($|0)<(O|0)){Pa=$;Ba=ea;while(1){X=o+392+(Pa<<1)|0;aa=(b[X>>1]|0)>>>1&65535;b[X>>1]=aa;if(aa<<16>>16==0){fb=Ba}else{c[U>>2]=(c[U>>2]|0)+(c[8984712+(Pa+~Ba<<12)+(aa<<16>>16<<3)+4>>2]|0);a[o+520+Ba|0]=Pa;fb=Pa}aa=d[o+520+Pa|0]|0;if((aa|0)<(O|0)){Pa=aa;Ba=fb}else{gb=aa;hb=fb;break}}}else{gb=$;hb=ea}if((G|0)<4){$=gb;da=G;ea=hb}else{break}}a[o+520+hb|0]=gb}ea=c[o+344>>2]|0;da=c[o+348>>2]|0;$=c[o+352>>2]|0;ba=c[o+356>>2]|0;ha=J+M|0;Ba=I+ha|0;a[o+976|0]=0;c[o+980>>2]=0;c[o+708>>2]=0;mrc(o+656|0,0,16)|0;if((Ba|0)==0){mrc(x|0,0,128)|0;c[o+716>>2]=0;ib=0;jb=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){kb=0}else{Pa=(Xe[c[C>>2]&511](0,Ba,0,F,8)|0)-400|0;if((Pa|0)<=0){kb=0;break}O=F<<1;U=Xe[c[C>>2]&511](0,Ba,0,O,4)|0;kb=(Pa|0)>((Xe[c[C>>2]&511](0,I+(ha+F)|0,0,O,4)|0)+U|0)|0}}while(0);ha=o+716|0;c[ha>>2]=kb;ef[c[B>>2]&4095](z,Ba,F);qe[c[p+148+(c[ha>>2]<<2)>>2]&1023](z);ib=b[z>>1]|0;jb=(c[ha>>2]|0)!=0}b[o+720>>1]=ib;ha=jb?1242144:1242080;J=jb?1516160:1515904;U=0;O=-1;Pa=0;P=1;while(1){c[o+688+(U<<2)>>2]=Pa;T=o+672+(U<<2)|0;c[T>>2]=1;Ca=U+1|0;Da=c[833e3+(Ca<<2)>>2]|0;aa=P&255;if((P|0)<(Da|0)){X=P+1|0;Z=P;_=O;W=Pa;while(1){ga=b[j+(d[ha+Z|0]<<1)>>1]|0;fa=ga<<16>>16;if((fa+15|0)>>>0>30>>>0){a[o+912+Z|0]=fa>>>31;Y=(ca(c[J+(Z<<2)>>2]|0,ga<<16>>16>-1?fa:-fa|0)|0)+2097152>>22;b[o+720+(Z<<1)>>1]=Y;c[T>>2]=(c[T>>2]|0)+(c[8984712+(Z+~W<<12)+(Y<<3)+4>>2]|0);a[o+848+W|0]=Z;lb=Z;mb=(Y|0)>(_|0)?Y:_}else{lb=W;mb=_}Y=Z+1|0;if((Y|0)<(Da|0)){Z=Y;_=mb;W=lb}else{break}}nb=((Da|0)>(X|0)?Da:X)&255;ob=mb;pb=lb}else{nb=aa;ob=O;pb=Pa}if((Ca|0)<4){U=Ca;O=ob;Pa=pb;P=Da}else{break}}a[o+848+pb|0]=nb;P=o+712|0;Pa=0;while(1){c[P>>2]=Pa;if((ob|0)>(c[1517576+(Pa<<2)>>2]|0)){Pa=Pa+1|0}else{break}}c[P>>2]=Pa;if((Pa|0)>2){c[P>>2]=3;O=d[o+848|0]|0;U=0;J=0;while(1){c[o+688+(U<<2)>>2]=J;ha=o+672+(U<<2)|0;c[ha>>2]=1;Ba=U+1|0;W=c[833e3+(Ba<<2)>>2]|0;if((O|0)<(W|0)){_=O;Z=J;while(1){T=o+720+(_<<1)|0;G=(b[T>>1]|0)>>>1&65535;b[T>>1]=G;if(G<<16>>16==0){qb=Z}else{c[ha>>2]=(c[ha>>2]|0)+(c[8984712+(_+~Z<<12)+(G<<16>>16<<3)+4>>2]|0);a[o+848+Z|0]=_;qb=_}G=d[o+848+_|0]|0;if((G|0)<(W|0)){_=G;Z=qb}else{rb=G;sb=qb;break}}}else{rb=O;sb=J}if((Ba|0)<4){O=rb;U=Ba;J=sb}else{break}}a[o+848+sb|0]=rb}J=c[o+672>>2]|0;U=c[o+676>>2]|0;O=c[o+680>>2]|0;P=c[o+684>>2]|0;Pa=Ga+M|0;Z=I+Pa|0;a[o+1304|0]=0;c[o+1308>>2]=0;c[o+1036>>2]=0;mrc(o+984|0,0,16)|0;if((Z|0)==0){mrc(x|0,0,128)|0;c[o+1044>>2]=0;tb=0;ub=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){vb=0}else{_=(Xe[c[C>>2]&511](0,Z,0,F,8)|0)-400|0;if((_|0)<=0){vb=0;break}W=F<<1;ha=Xe[c[C>>2]&511](0,Z,0,W,4)|0;vb=(_|0)>((Xe[c[C>>2]&511](0,I+(Pa+F)|0,0,W,4)|0)+ha|0)|0}}while(0);Pa=o+1044|0;c[Pa>>2]=vb;ef[c[B>>2]&4095](z,Z,F);qe[c[p+148+(c[Pa>>2]<<2)>>2]&1023](z);tb=b[z>>1]|0;ub=(c[Pa>>2]|0)!=0}b[o+1048>>1]=tb;Pa=ub?1242144:1242080;I=ub?1516160:1515904;Ga=0;ha=-1;W=0;_=1;while(1){c[o+1016+(Ga<<2)>>2]=W;Da=o+1e3+(Ga<<2)|0;c[Da>>2]=1;Ca=Ga+1|0;aa=c[833e3+(Ca<<2)>>2]|0;X=_&255;if((_|0)<(aa|0)){G=_+1|0;T=_;Y=ha;fa=W;while(1){ga=b[j+(d[Pa+T|0]<<1)>>1]|0;Fa=ga<<16>>16;if((Fa+15|0)>>>0>30>>>0){a[o+1240+T|0]=Fa>>>31;Ea=(ca(c[I+(T<<2)>>2]|0,ga<<16>>16>-1?Fa:-Fa|0)|0)+2097152>>22;b[o+1048+(T<<1)>>1]=Ea;c[Da>>2]=(c[Da>>2]|0)+(c[8984712+(T+~fa<<12)+(Ea<<3)+4>>2]|0);a[o+1176+fa|0]=T;wb=T;xb=(Ea|0)>(Y|0)?Ea:Y}else{wb=fa;xb=Y}Ea=T+1|0;if((Ea|0)<(aa|0)){T=Ea;Y=xb;fa=wb}else{break}}yb=((aa|0)>(G|0)?aa:G)&255;zb=xb;Ab=wb}else{yb=X;zb=ha;Ab=W}if((Ca|0)<4){Ga=Ca;ha=zb;W=Ab;_=aa}else{break}}a[o+1176+Ab|0]=yb;_=o+1040|0;W=0;while(1){c[_>>2]=W;if((zb|0)>(c[1517576+(W<<2)>>2]|0)){W=W+1|0}else{break}}c[_>>2]=W;if((W|0)>2){c[_>>2]=3;ha=d[o+1176|0]|0;Ga=0;I=0;while(1){c[o+1016+(Ga<<2)>>2]=I;Pa=o+1e3+(Ga<<2)|0;c[Pa>>2]=1;F=Ga+1|0;Z=c[833e3+(F<<2)>>2]|0;if((ha|0)<(Z|0)){fa=ha;Y=I;while(1){T=o+1048+(fa<<1)|0;Da=(b[T>>1]|0)>>>1&65535;b[T>>1]=Da;if(Da<<16>>16==0){Bb=Y}else{c[Pa>>2]=(c[Pa>>2]|0)+(c[8984712+(fa+~Y<<12)+(Da<<16>>16<<3)+4>>2]|0);a[o+1176+Y|0]=fa;Bb=fa}Da=d[o+1176+fa|0]|0;if((Da|0)<(Z|0)){fa=Da;Y=Bb}else{Cb=Da;Db=Bb;break}}}else{Cb=ha;Db=I}if((F|0)<4){ha=Cb;Ga=F;I=Db}else{break}}a[o+1176+Db|0]=Cb}Ya=ea+V+da+$+ba+J+U+O+P+(c[o+1e3>>2]|0)+(c[o+1004>>2]|0)+(c[o+1008>>2]|0)+(c[o+1012>>2]|0)|0}I=c[(c[v>>2]|0)+64>>2]|0;Ga=c[w>>2]|0;ha=ca(N>>((I|0)==0),c[Ga+36>>2]|0)|0;_=ha+(H>>>(((I|0)==7?2:1)>>>0))<<3;ha=(N|0)==134;W=H>>>0>87>>>0;Y=o+1312|0;fa=Ya+D|0;Z=2;Pa=Ga;Ga=I;while(1){I=(c[Pa+(Z<<2)>>2]|0)+_|0;aa=c[Pa+32+(Z<<2)>>2]|0;Ca=aa<<3;X=ha?8:Ca;if((Ga|0)==7&W){G=Ca|1;Da=Ca|2;T=Ca|3;Ba=I;Ea=r;Fa=0;while(1){a[Ea]=a[Ba]|0;a[Ea+1|0]=a[Ba+1|0]|0;a[Ea+2|0]=a[Ba+2|0]|0;a[Ea+3|0]=a[Ba+3|0]|0;a[Ea+4|0]=a[Ba+Ca|0]|0;a[Ea+5|0]=a[Ba+G|0]|0;a[Ea+6|0]=a[Ba+Da|0]|0;a[Ea+7|0]=a[Ba+T|0]|0;ga=Fa+1|0;if((ga|0)<8){Ba=Ba+aa|0;Ea=Ea+16|0;Fa=ga}else{Eb=16;Fb=r;break}}}else{Eb=aa;Fb=I}Fa=Y+328|0;a[Y+320|0]=0;c[Y+324>>2]=0;c[Y+52>>2]=0;mrc(Y|0,0,16)|0;if((Fb|0)==0){mrc(x|0,0,128)|0;c[Y+60>>2]=0;Gb=0;Hb=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){Ib=0}else{Ea=(Xe[c[C>>2]&511](0,Fb,0,Eb,8)|0)-400|0;if((Ea|0)<=0){Ib=0;break}Ba=Eb<<1;T=Xe[c[C>>2]&511](0,Fb,0,Ba,4)|0;Ib=(Ea|0)>((Xe[c[C>>2]&511](0,Fb+Eb|0,0,Ba,4)|0)+T|0)|0}}while(0);I=Y+60|0;c[I>>2]=Ib;ef[c[B>>2]&4095](z,Fb,Eb);qe[c[p+148+(c[I>>2]<<2)>>2]&1023](z);Gb=b[z>>1]|0;Hb=(c[I>>2]|0)!=0}b[Y+64>>1]=Gb;I=Hb?1242144:1242080;aa=Hb?1516160:1515904;T=0;Ba=-1;Ea=0;Da=1;while(1){c[Y+32+(T<<2)>>2]=Ea;G=Y+16+(T<<2)|0;c[G>>2]=1;Ca=T+1|0;F=c[833e3+(Ca<<2)>>2]|0;ga=Da&255;if((Da|0)<(F|0)){Jb=Da+1|0;Kb=Da;Lb=Ba;Mb=Ea;while(1){Nb=b[j+(d[I+Kb|0]<<1)>>1]|0;Ob=Nb<<16>>16;if((Ob+15|0)>>>0>30>>>0){a[Y+256+Kb|0]=Ob>>>31;Pb=(ca(c[aa+(Kb<<2)>>2]|0,Nb<<16>>16>-1?Ob:-Ob|0)|0)+2097152>>22;b[Y+64+(Kb<<1)>>1]=Pb;c[G>>2]=(c[G>>2]|0)+(c[8984712+(Kb+~Mb<<12)+(Pb<<3)+4>>2]|0);a[Y+192+Mb|0]=Kb;Qb=Kb;Rb=(Pb|0)>(Lb|0)?Pb:Lb}else{Qb=Mb;Rb=Lb}Pb=Kb+1|0;if((Pb|0)<(F|0)){Kb=Pb;Lb=Rb;Mb=Qb}else{break}}Sb=((F|0)>(Jb|0)?F:Jb)&255;Tb=Rb;Ub=Qb}else{Sb=ga;Tb=Ba;Ub=Ea}if((Ca|0)<4){T=Ca;Ba=Tb;Ea=Ub;Da=F}else{break}}a[Y+192+Ub|0]=Sb;Da=Y+56|0;Ea=0;while(1){c[Da>>2]=Ea;Vb=Ea+1|0;if((Tb|0)>(c[1517576+(Ea<<2)>>2]|0)){Ea=Vb}else{break}}c[Da>>2]=Vb;if((Vb|0)>2){c[Da>>2]=3;Ea=d[Y+192|0]|0;Ba=0;T=0;while(1){c[Y+32+(Ba<<2)>>2]=T;aa=Y+16+(Ba<<2)|0;c[aa>>2]=1;I=Ba+1|0;Mb=c[833e3+(I<<2)>>2]|0;if((Ea|0)<(Mb|0)){Lb=Ea;Kb=T;while(1){G=Y+64+(Lb<<1)|0;Pb=(b[G>>1]|0)>>>1&65535;b[G>>1]=Pb;if(Pb<<16>>16==0){Wb=Kb}else{c[aa>>2]=(c[aa>>2]|0)+(c[8984712+(Lb+~Kb<<12)+(Pb<<16>>16<<3)+4>>2]|0);a[Y+192+Kb|0]=Lb;Wb=Lb}Pb=d[Y+192+Lb|0]|0;if((Pb|0)<(Mb|0)){Lb=Pb;Kb=Wb}else{Xb=Pb;Yb=Wb;break}}}else{Xb=Ea;Yb=T}if((I|0)<4){Ea=Xb;Ba=I;T=Yb}else{break}}a[Y+192+Yb|0]=Xb}T=(c[Y+16>>2]|0)+fa+(c[Y+20>>2]|0)+(c[Y+24>>2]|0)+(c[Y+28>>2]|0)|0;if((c[(c[v>>2]|0)+68>>2]|0)==8){Ba=Y+656|0;Ea=Fb+X|0;a[Y+648|0]=0;c[Y+652>>2]=0;c[Y+380>>2]=0;mrc(Fa|0,0,16)|0;if((Ea|0)==0){mrc(x|0,0,128)|0;c[Y+388>>2]=0;Zb=0;_b=0}else{do{if((c[(c[A>>2]|0)+88>>2]&262144|0)==0){$b=0}else{Da=(Xe[c[C>>2]&511](0,Ea,0,Eb,8)|0)-400|0;if((Da|0)<=0){$b=0;break}Kb=Eb<<1;Lb=Xe[c[C>>2]&511](0,Ea,0,Kb,4)|0;$b=(Da|0)>((Xe[c[C>>2]&511](0,Fb+(Eb+X)|0,0,Kb,4)|0)+Lb|0)|0}}while(0);X=Y+388|0;c[X>>2]=$b;ef[c[B>>2]&4095](z,Ea,Eb);qe[c[p+148+(c[X>>2]<<2)>>2]&1023](z);Zb=b[z>>1]|0;_b=(c[X>>2]|0)!=0}b[Y+392>>1]=Zb;X=_b?1242144:1242080;Lb=_b?1516160:1515904;Kb=0;Da=-1;Mb=0;aa=1;while(1){c[Y+360+(Kb<<2)>>2]=Mb;F=Y+344+(Kb<<2)|0;c[F>>2]=1;Ca=Kb+1|0;ga=c[833e3+(Ca<<2)>>2]|0;Jb=aa&255;if((aa|0)<(ga|0)){Pb=aa+1|0;G=aa;Ob=Da;Nb=Mb;while(1){ac=b[j+(d[X+G|0]<<1)>>1]|0;bc=ac<<16>>16;if((bc+15|0)>>>0>30>>>0){a[Y+584+G|0]=bc>>>31;cc=(ca(c[Lb+(G<<2)>>2]|0,ac<<16>>16>-1?bc:-bc|0)|0)+2097152>>22;b[Y+392+(G<<1)>>1]=cc;c[F>>2]=(c[F>>2]|0)+(c[8984712+(G+~Nb<<12)+(cc<<3)+4>>2]|0);a[Y+520+Nb|0]=G;dc=G;ec=(cc|0)>(Ob|0)?cc:Ob}else{dc=Nb;ec=Ob}cc=G+1|0;if((cc|0)<(ga|0)){G=cc;Ob=ec;Nb=dc}else{break}}fc=((ga|0)>(Pb|0)?ga:Pb)&255;gc=ec;hc=dc}else{fc=Jb;gc=Da;hc=Mb}if((Ca|0)<4){Kb=Ca;Da=gc;Mb=hc;aa=ga}else{break}}a[Y+520+hc|0]=fc;aa=Y+384|0;Mb=0;while(1){c[aa>>2]=Mb;ic=Mb+1|0;if((gc|0)>(c[1517576+(Mb<<2)>>2]|0)){Mb=ic}else{break}}c[aa>>2]=ic;if((ic|0)>2){c[aa>>2]=3;Mb=d[Y+520|0]|0;Da=0;Kb=0;while(1){c[Y+360+(Da<<2)>>2]=Kb;Lb=Y+344+(Da<<2)|0;c[Lb>>2]=1;X=Da+1|0;Ea=c[833e3+(X<<2)>>2]|0;if((Mb|0)<(Ea|0)){Nb=Mb;Ob=Kb;while(1){G=Y+392+(Nb<<1)|0;F=(b[G>>1]|0)>>>1&65535;b[G>>1]=F;if(F<<16>>16==0){jc=Ob}else{c[Lb>>2]=(c[Lb>>2]|0)+(c[8984712+(Nb+~Ob<<12)+(F<<16>>16<<3)+4>>2]|0);a[Y+520+Ob|0]=Nb;jc=Nb}F=d[Y+520+Nb|0]|0;if((F|0)<(Ea|0)){Nb=F;Ob=jc}else{kc=F;lc=jc;break}}}else{kc=Mb;lc=Kb}if((X|0)<4){Mb=kc;Da=X;Kb=lc}else{break}}a[Y+520+lc|0]=kc}mc=(c[Y+344>>2]|0)+T+(c[Y+348>>2]|0)+(c[Y+352>>2]|0)+(c[Y+356>>2]|0)|0;nc=Ba}else{mc=T;nc=Fa}Kb=Z-1|0;if((Kb|0)==0){break}Y=nc;fa=mc;Z=Kb;Pa=c[w>>2]|0;Ga=c[(c[v>>2]|0)+64>>2]|0}Ga=E+1|0;if((Ga|0)<5){o=nc;D=mc;E=Ga}else{break}}E=n|0;D=t+(s*80|0)|0;a:do{if((mc|0)>2680){s=k+16|0;c[s>>2]=16777216;t=k+12|0;c[t>>2]=16777216;nc=k+8|0;c[nc>>2]=16777216;o=k+4|0;c[o>>2]=16777216;w=k|0;c[w>>2]=16777216;kc=n+4|0;lc=n+8|0;jc=n+12|0;ic=n+16|0;gc=u;fc=0;while(1){if((fc|0)>=5){if((c[kc>>2]|c[E>>2]|c[lc>>2]|c[jc>>2]|c[ic>>2]|0)==0){oc=2;break}else{gc=u;fc=0;continue}}hc=n+(fc<<2)|0;dc=c[hc>>2]|0;if((dc|0)==0){pc=gc}else{c[hc>>2]=dc-1;dc=k+(fc<<2)|0;c[dc>>2]=0;ec=0;j=gc;_b=0;while(1){Zb=j+56|0;z=0;p=_b;while(1){Eb=j+(z<<2)|0;B=c[Eb>>2]|0;$b=j+16+(z<<2)|0;if((B|0)==(d[1396560+((d[1396648+(c[Zb>>2]|0)|0]|0)+(c[hc>>2]|0)<<2)+z|0]|0)){qc=p;rc=z+1|0}else{c[$b>>2]=1;c[Eb>>2]=B+1;B=c[j+32+(z<<2)>>2]|0;Eb=d[j+192+B|0]|0;Fb=z+1|0;C=c[833e3+(Fb<<2)>>2]|0;b:do{if((Eb|0)<(C|0)){A=z+2|0;x=833e3+(A<<2)|0;Xb=B;Yb=Eb;while(1){Wb=j+192+Xb|0;Vb=~Xb;Tb=Yb;while(1){Sb=j+64+(Tb<<1)|0;sc=(b[Sb>>1]|0)>>>1&65535;b[Sb>>1]=sc;if(!(sc<<16>>16==0)){break}Sb=j+192+Tb|0;Ub=a[Sb]|0;Qb=Ub&255;if((Qb|0)>=(C|0)&(Ub&255)>>>0<64>>>0){if((Qb|0)<(c[x>>2]|0)){tc=Fb;uc=Qb}else{Qb=Fb;Rb=A;while(1){c[j+32+(Qb<<2)>>2]=Xb;Hb=d[Sb]|0;Gb=Rb+1|0;if((Hb|0)<(c[833e3+(Gb<<2)>>2]|0)){tc=Rb;uc=Hb;break}else{Qb=Rb;Rb=Gb}}}Rb=b[j+64+(uc<<1)>>1]|0;Qb=j+16+(tc<<2)|0;c[Qb>>2]=(c[8984712+(uc+Vb<<12)+(Rb<<3)+4>>2]|0)-(c[8984712+(uc+~Tb<<12)+(Rb<<3)+4>>2]|0)+(c[Qb>>2]|0);c[j+32+(tc<<2)>>2]=Xb;vc=a[Sb]|0}else{vc=Ub}a[Wb]=vc;Qb=d[Sb]|0;if((Qb|0)<(C|0)){Tb=Qb}else{wc=Xb;break b}}c[$b>>2]=(c[$b>>2]|0)+(c[8984712+(Tb+Vb<<12)+(sc<<16>>16<<3)+4>>2]|0);Wb=d[j+192+Tb|0]|0;if((Wb|0)<(C|0)){Xb=Tb;Yb=Wb}else{wc=Tb;break}}}else{wc=B}}while(0);c[j+32+(Fb<<2)>>2]=wc;qc=c[dc>>2]|0;rc=Fb}xc=(c[$b>>2]|0)+qc|0;c[dc>>2]=xc;if((rc|0)<4){z=rc;p=xc}else{break}}p=ec+1|0;if((p|0)<6){ec=p;j=j+328|0;_b=xc}else{break}}if(((c[o>>2]|0)+(c[w>>2]|0)+(c[nc>>2]|0)+(c[t>>2]|0)+(c[s>>2]|0)|0)<2681){break a}else{pc=gc+1968|0}}gc=pc;fc=fc+1|0}while(1){if((oc|0)!=2){if((c[w>>2]|0)<=2680){break a}}c[w>>2]=120;fc=-oc|0;gc=0;s=u;while(1){t=c[s+32>>2]|0;nc=a[s+192+t|0]|0;c:do{if((nc&255)>>>0<64>>>0){o=t;ic=nc;while(1){jc=s+192+o|0;lc=ic;while(1){yc=lc&255;zc=b[s+64+(yc<<1)>>1]|0;if(!((zc|0)<(oc|0)&(zc|0)>(fc|0))){break}kc=s+192+yc|0;a[jc]=a[kc]|0;lc=a[kc]|0;if(!((lc&255)>>>0<64>>>0)){break c}}c[w>>2]=(c[w>>2]|0)+(c[8984712+(yc+~o<<12)+(zc<<3)+4>>2]|0);lc=a[s+192+yc|0]|0;if((lc&255)>>>0<64>>>0){o=yc;ic=lc}else{break}}}}while(0);nc=gc+1|0;if((nc|0)<30){gc=nc;s=s+328|0}else{break}}oc=oc<<1}}}while(0);oc=c[(c[v>>2]|0)+68>>2]|0;if((oc*5|0|0)>0){yc=D;D=E;E=0;while(1){zc=D+4|0;a[yc+3|0]=c[D>>2];u=yc+4|0;pc=c[v>>2]|0;xc=c[pc+68>>2]|0;do{if((xc|0)>0){rc=u;qc=E;wc=0;sc=pc;while(1){vc=(d[(c[sc+72>>2]|0)+wc|0]|0)>>>3;tc=m+(qc*24|0)|0;c[m+(qc*24|0)+20>>2]=vc<<3;c[m+(qc*24|0)+8>>2]=rc;Ac=rc+vc|0;c[m+(qc*24|0)+16>>2]=Ac;c[m+(qc*24|0)+12>>2]=rc;c[tc>>2]=((((e[l+(qc*328|0)+64>>1]|0)>>>3)+1026|0)>>>2<<1&1022|c[l+(qc*328|0)+60>>2])<<2|c[l+(qc*328|0)+56>>2];c[m+(qc*24|0)+4>>2]=20;Bc=qc+1|0;vc=m+(Bc*24|0)|0;uc=l+(qc*328|0)+320|0;k=d[uc]|0;n=l+(qc*328|0)+324|0;mc=c[n>>2]|0;c[n>>2]=0;a[uc]=0;w=l+(qc*328|0)+52|0;s=k;k=tc;tc=mc;d:while(1){mc=k+4|0;gc=c[mc>>2]|0;fc=k+12|0;nc=c[fc>>2]|0;t=k+16|0;ic=gc-32+((c[t>>2]|0)-nc<<3)|0;if((s|0)>(ic|0)){Cc=tc;Dc=s;Ec=ic;Fc=gc;Gc=nc}else{ic=k|0;o=tc;$b=s;Fb=gc;gc=nc;while(1){nc=c[ic>>2]|0;if((Fb|0)>($b|0)){Hc=Fb;Ic=nc<<$b|o;Jc=gc}else{lc=gc;y=je(nc<<Fb|o>>>(($b-Fb|0)>>>0)|0)|0;a[lc]=y;y=y>>8;a[lc+1|0]=y;y=y>>8;a[lc+2|0]=y;y=y>>8;a[lc+3|0]=y;lc=(c[fc>>2]|0)+4|0;c[fc>>2]=lc;Hc=Fb+32|0;Ic=o;Jc=lc}c[ic>>2]=Ic;c[mc>>2]=Hc-$b;lc=c[w>>2]|0;if((lc|0)>63){break d}nc=a[l+(qc*328|0)+192+lc|0]|0;jc=nc&255;c[w>>2]=jc;if((nc&255)>>>0<64>>>0){nc=jc-lc-1|0;lc=b[l+(qc*328|0)+64+(jc<<1)>>1]|0;Kc=c[8984712+(nc<<12)+(lc<<3)+4>>2]|0;Lc=c[8984712+(nc<<12)+(lc<<3)>>2]|d[l+(qc*328|0)+256+jc|0]}else{Kc=4;Lc=6}jc=c[mc>>2]|0;lc=jc-32+((c[t>>2]|0)-Jc<<3)|0;if((Kc|0)>(lc|0)){Cc=Lc;Dc=Kc;Ec=lc;Fc=jc;Gc=Jc;break}else{o=Lc;$b=Kc;Fb=jc;gc=Jc}}}if((Ec|0)==0){Mc=Dc;Nc=Cc}else{gc=Dc-Ec|0;Fb=Cc>>>(gc>>>0);$b=k|0;o=c[$b>>2]|0;if((Fc|0)>(Ec|0)){Oc=Fc;Pc=o<<Ec|Fb}else{t=Gc;y=je(o<<Fc|Fb>>>((Ec-Fc|0)>>>0)|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[fc>>2]=(c[fc>>2]|0)+4;Oc=Fc+32|0;Pc=Fb}c[$b>>2]=Pc;c[mc>>2]=Oc-Ec;Mc=gc;Nc=(1<<gc)-1&Cc}gc=k+24|0;if(gc>>>0<vc>>>0){s=Mc;k=gc;tc=Nc}else{L=272;break}}if((L|0)==272){L=0;a[uc]=Mc;c[n>>2]=Nc}tc=wc+1|0;k=c[v>>2]|0;Qc=c[k+68>>2]|0;if((tc|0)<(Qc|0)){rc=Ac;qc=Bc;wc=tc;sc=k}else{break}}if((Qc|0)<=0){Rc=Qc;Sc=Bc;Tc=Ac;break}sc=m+(E*24|0)|0;wc=0;qc=Qc;while(1){rc=wc+E|0;k=l+(rc*328|0)+320|0;tc=a[k]|0;e:do{if(tc<<24>>24==0){Uc=sc}else{s=m+((qc+E|0)*24|0)|0;vc=l+(rc*328|0)+324|0;w=c[vc>>2]|0;c[vc>>2]=0;a[k]=0;gc=l+(rc*328|0)+52|0;$b=tc&255;Fb=sc;t=w;while(1){w=Fb+4|0;o=c[w>>2]|0;ic=Fb+12|0;jc=c[ic>>2]|0;lc=Fb+16|0;nc=o-32+((c[lc>>2]|0)-jc<<3)|0;if(($b|0)>(nc|0)){Vc=t;Wc=$b;Xc=nc;Yc=o;Zc=jc}else{nc=Fb|0;kc=t;_b=$b;j=o;o=jc;while(1){jc=c[nc>>2]|0;if((j|0)>(_b|0)){_c=j;$c=jc<<_b|kc;ad=o}else{ec=o;y=je(jc<<j|kc>>>((_b-j|0)>>>0)|0)|0;a[ec]=y;y=y>>8;a[ec+1|0]=y;y=y>>8;a[ec+2|0]=y;y=y>>8;a[ec+3|0]=y;ec=(c[ic>>2]|0)+4|0;c[ic>>2]=ec;_c=j+32|0;$c=kc;ad=ec}c[nc>>2]=$c;c[w>>2]=_c-_b;ec=c[gc>>2]|0;if((ec|0)>63){Uc=Fb;break e}jc=a[l+(rc*328|0)+192+ec|0]|0;dc=jc&255;c[gc>>2]=dc;if((jc&255)>>>0<64>>>0){jc=dc-ec-1|0;ec=b[l+(rc*328|0)+64+(dc<<1)>>1]|0;bd=c[8984712+(jc<<12)+(ec<<3)+4>>2]|0;cd=c[8984712+(jc<<12)+(ec<<3)>>2]|d[l+(rc*328|0)+256+dc|0]}else{bd=4;cd=6}dc=c[w>>2]|0;ec=dc-32+((c[lc>>2]|0)-ad<<3)|0;if((bd|0)>(ec|0)){Vc=cd;Wc=bd;Xc=ec;Yc=dc;Zc=ad;break}else{kc=cd;_b=bd;j=dc;o=ad}}}if((Xc|0)==0){dd=Wc;ed=Vc}else{o=Wc-Xc|0;j=Vc>>>(o>>>0);_b=Fb|0;kc=c[_b>>2]|0;if((Yc|0)>(Xc|0)){fd=Yc;gd=kc<<Xc|j}else{lc=Zc;y=je(kc<<Yc|j>>>((Xc-Yc|0)>>>0)|0)|0;a[lc]=y;y=y>>8;a[lc+1|0]=y;y=y>>8;a[lc+2|0]=y;y=y>>8;a[lc+3|0]=y;c[ic>>2]=(c[ic>>2]|0)+4;fd=Yc+32|0;gd=j}c[_b>>2]=gd;c[w>>2]=fd-Xc;dd=o;ed=(1<<o)-1&Vc}o=Fb+24|0;if(o>>>0<s>>>0){$b=dd;Fb=o;t=ed}else{break}}a[k]=dd;c[vc>>2]=ed;Uc=Fb}}while(0);k=wc+1|0;rc=c[(c[v>>2]|0)+68>>2]|0;if((k|0)<(rc|0)){sc=Uc;wc=k;qc=rc}else{Rc=rc;Sc=Bc;Tc=Ac;break}}}else{Rc=xc;Sc=E;Tc=u}}while(0);if((Sc|0)<(Rc*5|0|0)){yc=Tc;D=zc;E=Sc}else{hd=Rc;break}}}else{hd=oc}oc=hd*5|0;if((oc|0)>0){Rc=f;Sc=m|0;E=0;D=oc;while(1){oc=l+(E*328|0)+320|0;Tc=a[oc]|0;do{if(Tc<<24>>24==0){id=Sc}else{yc=m+(D*24|0)|0;Ac=l+(E*328|0)+324|0;Bc=c[Ac>>2]|0;c[Ac>>2]=0;a[oc]=0;Uc=l+(E*328|0)+52|0;ed=Tc&255;dd=Sc;Vc=Bc;f:while(1){Bc=dd+4|0;Xc=c[Bc>>2]|0;fd=dd+12|0;gd=c[fd>>2]|0;Yc=dd+16|0;Zc=Xc-32+((c[Yc>>2]|0)-gd<<3)|0;if((ed|0)>(Zc|0)){jd=Vc;kd=ed;ld=Zc;md=Xc;nd=gd}else{Zc=dd|0;Wc=Vc;ad=ed;bd=Xc;Xc=gd;while(1){gd=c[Zc>>2]|0;if((bd|0)>(ad|0)){od=bd;pd=gd<<ad|Wc;qd=Xc}else{cd=Xc;y=je(gd<<bd|Wc>>>((ad-bd|0)>>>0)|0)|0;a[cd]=y;y=y>>8;a[cd+1|0]=y;y=y>>8;a[cd+2|0]=y;y=y>>8;a[cd+3|0]=y;cd=(c[fd>>2]|0)+4|0;c[fd>>2]=cd;od=bd+32|0;pd=Wc;qd=cd}c[Zc>>2]=pd;c[Bc>>2]=od-ad;cd=c[Uc>>2]|0;if((cd|0)>63){L=323;break f}gd=a[l+(E*328|0)+192+cd|0]|0;_c=gd&255;c[Uc>>2]=_c;if((gd&255)>>>0<64>>>0){gd=_c-cd-1|0;cd=b[l+(E*328|0)+64+(_c<<1)>>1]|0;rd=c[8984712+(gd<<12)+(cd<<3)+4>>2]|0;sd=c[8984712+(gd<<12)+(cd<<3)>>2]|d[l+(E*328|0)+256+_c|0]}else{rd=4;sd=6}_c=c[Bc>>2]|0;cd=_c-32+((c[Yc>>2]|0)-qd<<3)|0;if((rd|0)>(cd|0)){jd=sd;kd=rd;ld=cd;md=_c;nd=qd;break}else{Wc=sd;ad=rd;bd=_c;Xc=qd}}}if((ld|0)==0){td=kd;ud=jd}else{Xc=kd-ld|0;bd=jd>>>(Xc>>>0);ad=dd|0;Wc=c[ad>>2]|0;if((md|0)>(ld|0)){vd=md;wd=Wc<<ld|bd}else{Yc=nd;y=je(Wc<<md|bd>>>((ld-md|0)>>>0)|0)|0;a[Yc]=y;y=y>>8;a[Yc+1|0]=y;y=y>>8;a[Yc+2|0]=y;y=y>>8;a[Yc+3|0]=y;c[fd>>2]=(c[fd>>2]|0)+4;vd=md+32|0;wd=bd}c[ad>>2]=wd;c[Bc>>2]=vd-ld;td=Xc;ud=(1<<Xc)-1&jd}Xc=dd+24|0;if(Xc>>>0<yc>>>0){ed=td;dd=Xc;Vc=ud}else{L=315;break}}if((L|0)==315){L=0;Vc=td&255;a[oc]=Vc;c[Ac>>2]=ud;xd=Vc}else if((L|0)==323){L=0;xd=a[oc]|0}if(xd<<24>>24==0){id=dd;break}KIb(Rc,16,2454672,(yd=i,i=i+1|0,i=i+7&-8,c[yd>>2]=0,yd)|0);i=yd;id=dd}}while(0);oc=E+1|0;Tc=c[(c[v>>2]|0)+68>>2]|0;zc=Tc*5|0;if((oc|0)<(zc|0)){Sc=id;E=oc;D=zc}else{zd=Tc;break}}}else{zd=hd}if((zd*5|0|0)>0){Ad=0}else{Bd=0;i=h;return Bd|0}while(1){zd=c[m+(Ad*24|0)+20>>2]>>3;hd=m+(Ad*24|0)+4|0;D=c[hd>>2]|0;E=m+(Ad*24|0)|0;if((D|0)<32){id=c[E>>2]<<D;c[E>>2]=id;D=m+(Ad*24|0)+12|0;Sc=id>>>24&255;while(1){id=c[D>>2]|0;c[D>>2]=id+1;a[id]=Sc;id=c[E>>2]|0;c[E>>2]=id<<8;Rc=(c[hd>>2]|0)+8|0;c[hd>>2]=Rc;if((Rc|0)<32){Sc=id>>>16&255}else{Cd=D;break}}}else{Cd=m+(Ad*24|0)+12|0}c[hd>>2]=32;c[E>>2]=0;D=c[m+(Ad*24|0)+8>>2]|0;Sc=(c[Cd>>2]|0)-D<<3>>3;if((Sc|0)>(zd|0)){break}mrc(D+Sc|0,-1|0,zd-Sc|0)|0;Sc=Ad+1|0;if((Sc|0)<((c[(c[v>>2]|0)+68>>2]|0)*5|0|0)){Ad=Sc}else{Bd=0;L=334;break}}if((L|0)==334){i=h;return Bd|0}KIb(f,16,2365120,(yd=i,i=i+1|0,i=i+7&-8,c[yd>>2]=0,yd)|0);i=yd;Bd=-1;i=h;return Bd|0}function vca(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;e=UHb()|0;f=d;c[f>>2]=e;if((e|0)==0){g=-12;i=b;return g|0}c[a+140>>2]=11;e=ca(c[a+120>>2]<<1,c[a+124>>2]|0)|0;c[d+4>>2]=e;h=hJb(e+16|0)|0;c[d+8>>2]=h;if((h|0)!=0){g=0;i=b;return g|0}VHb(f);KIb(a,16,2590568,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-12;i=b;return g|0}function wca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0;h=i;i=i+8|0;j=h|0;k=e;l=c[b+60>>2]|0;m=g+24|0;n=c[m>>2]|0;o=g+28|0;g=c[o>>2]|0;if(!((g|0)>-1)){KIb(0,0,2123024,(p=i,i=i+24|0,c[p>>2]=2640704,c[p+8>>2]=2617992,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}q=n+g|0;r=n;do{if((g|0)<4){s=0;t=n}else{u=n;if((d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)!=1346456899){s=0;t=n;break}u=l+12|0;v=n+(g>>>0>4>>>0?4:g)|0;w=0;while(1){if((q-v|0)<3){x=-16777216;z=v}else{x=(d[v]|0)<<16|(d[v+1|0]|0)<<8|(d[v+2|0]|0)|-16777216;z=v+3|0}c[u+(w<<2)>>2]=x;A=w+1|0;if((A|0)<256){v=z;w=A}else{s=1;t=z;break}}}}while(0);z=M4a(b,k,1)|0;if((z|0)<0){B=z;i=h;return B|0}nrc(c[e+4>>2]|0,l+12|0,1024)|0;c[e+304>>2]=s;s=e;z=c[s>>2]|0;x=l+8|0;g=c[x>>2]|0;n=l;w=c[c[n>>2]>>2]|0;v=e+32|0;u=c[v>>2]|0;do{if((q-t|0)<4){C=t;D=13}else{A=t;if((d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)!=1280070990){C=t+4|0;D=13;break}A=c[l+4>>2]|0;c[j>>2]=A;E=-1;F=A}}while(0);do{if((D|0)==13){if((q-C|0)<1){c[j>>2]=c[l+4>>2];H=C;I=0}else{t=a[C]|0;A=t&255;J=c[l+4>>2]|0;c[j>>2]=J;if(t<<24>>24==4){E=A;F=J;break}else{H=C+1|0;I=A}}A=q-H|0;J=H+(A>>>0>4>>>0?4:A)|0;if((Aqc(g,j,(c[m>>2]|0)+(J-r)|0,q-J|0)|0)==0){J=c[j>>2]|0;mrc((c[x>>2]|0)+J|0,0,16)|0;E=I;F=J;break}KIb(b,16,2454648,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;B=-1313558101;i=h;return B|0}}while(0);if((c[b+688>>2]&1|0)!=0){KIb(b,48,2365096,(p=i,i=i+16|0,c[p>>2]=E,c[p+8>>2]=F,p)|0);i=p}a:do{switch(E|0){case-1:{F=e+84|0;c[F>>2]=0;I=e+88|0;c[I>>2]=2;x=c[c[n>>2]>>2]|0;q=c[s>>2]|0;r=ca(c[b+124>>2]|0,c[v>>2]|0)|0;if((x|0)==0){mrc(q|0,0,r|0)|0;c[F>>2]=1;c[I>>2]=1;break a}else{nrc(q|0,x|0,r)|0;break a}break};case 2:case 4:{c[e+84>>2]=1;c[e+88>>2]=1;r=b+124|0;if((c[r>>2]|0)<=0){break a}x=b+120|0;q=z;I=g;F=0;m=c[x>>2]|0;while(1){nrc(q|0,I|0,m)|0;H=c[x>>2]|0;C=F+1|0;if((C|0)<(c[r>>2]|0)){q=q+u|0;I=I+H|0;F=C;m=H}else{break}}break};case 3:case 5:{do{if((w|0)==0){KIb(b,16,2299880,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;if((c[b+92>>2]&4194304|0)==0){B=-1094995529}else{break}i=h;return B|0}}while(0);c[e+84>>2]=0;c[e+88>>2]=2;m=b+124|0;if((c[m>>2]|0)<=0){break a}F=b+120|0;I=z;q=g;r=w;x=0;while(1){H=c[F>>2]|0;if((r|0)==0){nrc(I|0,q|0,H)|0;K=0;L=c[F>>2]|0}else{if((H|0)>0){C=0;while(1){a[I+C|0]=a[r+C|0]^a[q+C|0];l=C+1|0;J=c[F>>2]|0;if((l|0)<(J|0)){C=l}else{M=J;break}}}else{M=H}K=r+u|0;L=M}C=x+1|0;if((C|0)<(c[m>>2]|0)){I=I+u|0;q=q+L|0;r=K;x=C}else{break}}break};case 12:case 13:{c[e+84>>2]=0;c[e+88>>2]=2;x=c[c[n>>2]>>2]|0;if((x|0)==0){KIb(b,16,2248912,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;B=-1094995529;i=h;return B|0}r=c[s>>2]|0;q=c[v>>2]|0;I=c[j>>2]|0;m=g+I|0;F=b+120|0;C=c[F>>2]|0;J=b+124|0;l=c[J>>2]|0;A=((ca(l,C)|0)>>4)+12|0;t=g;N=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=wrc(A,(A|0)<0|0?-1:0,N,0)|0;O=G;P=g+4|0;Q=je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=wrc(t,O,Q,0)|0;O=G;t=(I|0)<0|0?-1:0;if(O>>>0>t>>>0|O>>>0==t>>>0&P>>>0>I>>>0){break a}I=A+N|0;if((l|0)<=0){break a}N=q<<2;P=q+1|0;t=q<<1;O=t+q|0;R=g+12|0;S=g+A|0;A=g+I|0;T=g+(I+Q)|0;Q=x;x=0;I=r;r=0;U=C;C=l;b:while(1){if((U|0)>0){l=r-4|0;V=r-2|0;W=R;X=S;Y=A;Z=T;_=0;$=0;aa=U;while(1){if(X>>>0>m>>>0|Y>>>0>m>>>0|Z>>>0>m>>>0){break a}ba=I+_|0;da=Q+_|0;ea=W+1|0;fa=a[W]|0;ga=fa&255;switch(ga|0){case 33:case 34:{ha=Z;ia=je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0;a[ba]=a[X+(ia&3)|0]|0;a[I+(_|1)|0]=a[X+(ia>>>2&3)|0]|0;a[I+(_|2)|0]=a[X+(ia>>>4&3)|0]|0;a[I+(_|3)|0]=a[X+(ia>>>6&3)|0]|0;ha=_+q|0;a[I+ha|0]=a[X+(ia>>>8&3)|0]|0;a[I+(ha+1)|0]=a[X+(ia>>>10&3)|0]|0;a[I+(ha+2)|0]=a[X+(ia>>>12&3)|0]|0;a[I+(ha+3)|0]=a[X+(ia>>>14&3)|0]|0;ja=ha+q|0;a[I+ja|0]=a[X+(ia>>>16&3)|0]|0;a[I+(ja+1)|0]=a[X+(ia>>>18&3)|0]|0;a[I+(ja+2)|0]=a[X+(ia>>>20&3)|0]|0;a[I+(ja+3)|0]=a[X+(ia>>>22&3)|0]|0;ha=ja+q|0;a[I+ha|0]=a[X+(ia>>>24&3)|0]|0;a[I+(ha+1)|0]=a[X+(ia>>>26&3)|0]|0;a[I+(ha+2)|0]=a[X+(ia>>>28&3)|0]|0;a[I+(ha+3)|0]=a[X+(ia>>>30)|0]|0;ka=Z+4|0;la=Y;ma=X+(ga-30)|0;break};case 2:{mrc(ba|0,a[X]|0,4)|0;ia=_+q|0;mrc(I+ia|0,a[X]|0,4)|0;ha=ia+q|0;mrc(I+ha|0,a[X]|0,4)|0;mrc(I+(ha+q)|0,a[X]|0,4)|0;ka=Z;la=Y;ma=X+1|0;break};case 3:{ha=X;ia=ba;y=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=_+q|0;ha=X+4|0;ja=I+ia|0;y=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;ja=ia+q|0;ia=X+8|0;ha=I+ja|0;y=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;ha=X+12|0;ia=I+(ja+q)|0;y=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ka=Z;la=Y;ma=X+16|0;break};case 4:{ia=d[Y]|0;ha=ia>>>4;na=(ha&8|0)==0?ha:8-ha|0;ha=ia&15;oa=(ia&8|0)==0?ha:8-ha|0;if((_|0)<(-na|0)){D=53;break b}if((aa-4+$|0)<(na|0)){D=53;break b}if((x|0)<(-oa|0)){D=53;break b}if((l+(c[J>>2]|0)|0)<(oa|0)){D=53;break b}pa=Q+((ca(oa,q)|0)+_+na)|0;qa=Y+1|0;D=55;break};case 0:case 5:{pa=da;qa=Y;D=55;break};case 1:case 10:case 11:case 12:case 13:case 14:case 15:{if(fa<<24>>24==1){fa=Z;ra=(he((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535;sa=Z+2|0}else{fa=ga-10|0;ha=d[Z]|0;ra=(ha&240)<<c[572936+(fa<<2)>>2]|(ha&15)<<c[572912+(fa<<2)>>2];sa=Z+1|0}fa=(ra&32768|0)==0;ha=fa?X:X+1|0;a[ba]=a[fa?da:X]|0;da=(ra&16384|0)==0;fa=da?ha:ha+1|0;a[I+(_|1)|0]=a[da?Q+(_|1)|0:ha]|0;ha=(ra&8192|0)==0;da=ha?fa:fa+1|0;a[I+(_|2)|0]=a[ha?Q+(_|2)|0:fa]|0;fa=(ra&4096|0)==0;ha=fa?da:da+1|0;a[I+(_|3)|0]=a[fa?Q+(_|3)|0:da]|0;da=ra<<4;fa=_+q|0;ia=_+q|0;ja=(da&32768|0)==0;ta=ja?ha:ha+1|0;a[I+fa|0]=a[ja?Q+ia|0:ha]|0;ha=(da&16384|0)==0;ja=ha?ta:ta+1|0;a[I+(fa+1)|0]=a[ha?Q+(ia+1)|0:ta]|0;ta=(da&8192|0)==0;ha=ta?ja:ja+1|0;a[I+(fa+2)|0]=a[ta?Q+(ia+2)|0:ja]|0;ja=(da&4096|0)==0;da=ja?ha:ha+1|0;a[I+(fa+3)|0]=a[ja?Q+(ia+3)|0:ha]|0;ha=ra<<8;ja=fa+q|0;fa=ia+q|0;ia=(ha&32768|0)==0;ta=ia?da:da+1|0;a[I+ja|0]=a[ia?Q+fa|0:da]|0;da=(ha&16384|0)==0;ia=da?ta:ta+1|0;a[I+(ja+1)|0]=a[da?Q+(fa+1)|0:ta]|0;ta=(ha&8192|0)==0;da=ta?ia:ia+1|0;a[I+(ja+2)|0]=a[ta?Q+(fa+2)|0:ia]|0;ia=(ha&4096|0)==0;ha=ia?da:da+1|0;a[I+(ja+3)|0]=a[ia?Q+(fa+3)|0:da]|0;da=ra<<12;ia=ja+q|0;ja=fa+q|0;fa=(da&32768|0)==0;ta=fa?ha:ha+1|0;a[I+ia|0]=a[fa?Q+ja|0:ha]|0;ha=(da&16384|0)==0;fa=ha?ta:ta+1|0;a[I+(ia+1)|0]=a[ha?Q+(ja+1)|0:ta]|0;ta=(da&8192|0)==0;ha=ta?fa:fa+1|0;a[I+(ia+2)|0]=a[ta?Q+(ja+2)|0:fa]|0;fa=(da&4096|0)==0;a[I+(ia+3)|0]=a[fa?Q+(ja+3)|0:ha]|0;ka=sa;la=Y;ma=fa?ha:ha+1|0;break};case 8:{ha=Z+1|0;fa=$-2|0;ja=_+q|0;ia=X;da=Y;ta=0;ua=d[Z]|0;while(1){va=ta<<1&2;wa=ta&2;xa=va+(ca(wa,q)|0)|0;ya=xa+_|0;za=ua&192;if((za|0)==128){Aa=d[da]|0;Ba=Aa>>>4;Ca=(Ba&8|0)==0?Ba:8-Ba|0;Ba=Aa&15;Da=(Aa&8|0)==0?Ba:8-Ba|0;if((va|_|0)<(-Ca|0)){D=66;break b}if((fa-va+(c[F>>2]|0)|0)<(Ca|0)){D=66;break b}if((wa|x|0)<(-Da|0)){D=66;break b}if((V-wa+(c[J>>2]|0)|0)<(Da|0)){D=66;break b}Ea=(ca(Da,q)|0)+ya+Ca|0;Fa=da+1|0;D=68}else if((za|0)==0){Ea=ya;Fa=da;D=68}else if((za|0)==64){a[I+ya|0]=a[ia]|0;wa=xa|1;a[I+(wa+_)|0]=a[ia]|0;a[I+(xa+ja)|0]=a[ia]|0;a[I+(wa+ja)|0]=a[ia]|0;Ga=da;Ha=ia+1|0}else if((za|0)==192){a[I+ya|0]=a[ia]|0;za=xa|1;a[I+(za+_)|0]=a[ia+1|0]|0;a[I+(xa+ja)|0]=a[ia+2|0]|0;a[I+(za+ja)|0]=a[ia+3|0]|0;Ga=da;Ha=ia+4|0}else{Ga=da;Ha=ia}if((D|0)==68){D=0;a[I+ya|0]=a[Q+Ea|0]|0;ya=xa|1;a[I+(ya+_)|0]=a[Q+(Ea+1)|0]|0;a[I+(xa+ja)|0]=a[Q+(Ea+q)|0]|0;a[I+(ya+ja)|0]=a[Q+(P+Ea)|0]|0;Ga=Fa;Ha=ia}ya=ta+1|0;if((ya|0)<4){ia=Ha;da=Ga;ta=ya;ua=ua<<2}else{ka=ha;la=Ga;ma=Ha;break}}break};case 32:{ha=Z;ua=(he((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535;a[ba]=a[X+(ua&1)|0]|0;a[I+(_|1)|0]=a[X+(ua>>>1&1)|0]|0;a[I+(_|2)|0]=a[X+(ua>>>2&1)|0]|0;a[I+(_|3)|0]=a[X+(ua>>>3&1)|0]|0;ha=_+q|0;a[I+ha|0]=a[X+(ua>>>4&1)|0]|0;a[I+(ha+1)|0]=a[X+(ua>>>5&1)|0]|0;a[I+(ha+2)|0]=a[X+(ua>>>6&1)|0]|0;a[I+(ha+3)|0]=a[X+(ua>>>7&1)|0]|0;ta=ha+q|0;a[I+ta|0]=a[X+(ua>>>8&1)|0]|0;a[I+(ta+1)|0]=a[X+(ua>>>9&1)|0]|0;a[I+(ta+2)|0]=a[X+(ua>>>10&1)|0]|0;a[I+(ta+3)|0]=a[X+(ua>>>11&1)|0]|0;ha=ta+q|0;a[I+ha|0]=a[X+(ua>>>12&1)|0]|0;a[I+(ha+1)|0]=a[X+(ua>>>13&1)|0]|0;a[I+(ha+2)|0]=a[X+(ua>>>14&1)|0]|0;a[I+(ha+3)|0]=a[X+(ua>>>15)|0]|0;ka=Z+2|0;la=Y;ma=X+2|0;break};default:{D=74;break b}}if((D|0)==55){D=0;ua=pa;ha=ba;y=d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;ha=_+q|0;ua=pa+q|0;ta=I+ha|0;y=d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;ta=ha+q|0;ha=pa+t|0;ua=I+ta|0;y=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y;ua=pa+O|0;ha=I+(ta+q)|0;y=d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;ka=Z;la=qa;ma=X}ha=_+4|0;ua=-4-_|0;Ia=c[F>>2]|0;if((ha|0)<(Ia|0)){W=ea;X=ma;Y=la;Z=ka;_=ha;$=ua;aa=Ia}else{break}}Ja=ea;Ka=ma;La=la;Ma=ka;Na=Ia;Oa=c[J>>2]|0}else{Ja=R;Ka=S;La=A;Ma=T;Na=U;Oa=C}aa=x+4|0;$=-4-x|0;if((aa|0)<(Oa|0)){R=Ja;S=Ka;A=La;T=Ma;Q=Q+N|0;x=aa;I=I+N|0;r=$;U=Na;C=Oa}else{break a}}if((D|0)==53){KIb(b,16,2174416,(p=i,i=i+16|0,c[p>>2]=na,c[p+8>>2]=oa,p)|0);i=p;break a}else if((D|0)==66){KIb(b,16,2174416,(p=i,i=i+16|0,c[p>>2]=Ca,c[p+8>>2]=Da,p)|0);i=p;break a}else if((D|0)==74){KIb(b,16,2146864,(p=i,i=i+8|0,c[p>>2]=ga,p)|0);i=p;break a}break};default:{KIb(b,16,2206784,(p=i,i=i+8|0,c[p>>2]=E,p)|0);i=p;B=-1094995529;i=h;return B|0}}}while(0);WHb(c[n>>2]|0);p=YHb(c[n>>2]|0,k)|0;if((p|0)<0){B=p;i=h;return B|0}c[f>>2]=1;B=c[o>>2]|0;i=h;return B|0}function xca(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+8|0);VHb(b);return 0}function yca(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0;j=i;i=i+24|0;k=j|0;l=f;m=c[h+24>>2]|0;n=h+28|0;h=c[n>>2]|0;if((h|0)<16){KIb(e,16,2454624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}q=m;r=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;a:do{if((r|0)==16777225){q=m+16|0;s=h-16|0;if(!((s|0)>-1)){KIb(0,0,2122992,(o=i,i=i+24|0,c[o>>2]=2640688,c[o+8>>2]=2617968,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}t=m+h|0;if((s|0)<2){u=0;v=q}else{w=q;u=(d[w]|d[w+1|0]<<8)<<16>>16&65535;v=m+18|0}w=(u<<2|2)+15&524272;if(w>>>0>s>>>0){KIb(e,16,2299864,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}q=c[e+124>>2]|0;do{if((u|0)!=0){if(((q|0)%(u|0)|0|0)!=0){break}x=(q|0)/(u|0)|0;c[e+140>>2]=3;y=M4a(e,l,0)|0;if((y|0)<0){p=y;i=j;return p|0}y=e+120|0;z=f+32|0;A=k;B=k|0;C=k;D=k+8|0;E=D;F=k+16|0;H=F;I=(x|0)>0;J=C+1|0;K=C+9|0;L=C+17|0;M=e;N=v;O=w;P=0;Q=c[f>>2]|0;while(1){if((t-N|0)<4){R=0;S=25;break}T=N+4|0;U=N;V=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;W=s-O|0;if(V>>>0>W>>>0){S=23;break}if(V>>>0<17>>>0){R=V;S=25;break}U=m+(O+16)|0;X=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;U=V-16|0;if((X|0)!=(U|0)){KIb(M,16,2146816,(o=i,i=i+16|0,c[o>>2]=X,c[o+8>>2]=U,o)|0);i=o}X=m+(O+32)|0;Y=U<<3;U=Y>>>0>2147483639>>>0|(X|0)==0;Z=U?0:X;X=U?8:Y+8|0;Y=c[y>>2]|0;U=c[z>>2]|0;c[B>>2]=1614815232;c[B+4>>2]=-4153216;c[D>>2]=1614815232;c[D+4>>2]=-4153216;c[F>>2]=1614815232;c[F+4>>2]=-4153216;if(I){_=(Y|0)>0;$=Q;aa=0;ba=0;while(1){if(_){da=0;ea=ba;while(1){fa=0;ga=ea;while(1){if((fa|0)>=8){ha=ga;break}ia=((ga|0)<(X|0))+ga|0;if(((d[Z+(ga>>>3)|0]|0)&1<<(ga&7)|0)==0){ha=ia;break}else{fa=fa+1|0;ga=ia}}if((fa&255)<<24>>24==0){ga=Z+(ha>>>3)|0;ia=ha+8|0;ja=(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((ha&7)>>>0)&255;orc(J|0,A|0,7)|0;ka=ja;la=X>>>0>ia>>>0?ia:X}else{ia=(fa&255)-1|0;ja=a[C+ia|0]|0;orc(J|0,A|0,ia|0)|0;ka=ja;la=ha}a[A]=ka;ja=da*3|0;a[$+ja|0]=ka;ia=0;ga=la;while(1){if((ia|0)>=8){ma=ga;break}na=((ga|0)<(X|0))+ga|0;if(((d[Z+(ga>>>3)|0]|0)&1<<(ga&7)|0)==0){ma=na;break}else{ia=ia+1|0;ga=na}}if((ia&255)<<24>>24==0){ga=Z+(ma>>>3)|0;fa=ma+8|0;na=(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((ma&7)>>>0)&255;orc(K|0,E|0,7)|0;oa=na;pa=X>>>0>fa>>>0?fa:X}else{fa=(ia&255)-1|0;na=a[C+8+fa|0]|0;orc(K|0,E|0,fa|0)|0;oa=na;pa=ma}a[E]=oa;a[$+(ja+1)|0]=oa;na=0;fa=pa;while(1){if((na|0)>=8){qa=fa;break}ga=((fa|0)<(X|0))+fa|0;if(((d[Z+(fa>>>3)|0]|0)&1<<(fa&7)|0)==0){qa=ga;break}else{na=na+1|0;fa=ga}}if((na&255)<<24>>24==0){fa=Z+(qa>>>3)|0;ia=qa+8|0;ga=(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)>>>((qa&7)>>>0)&255;orc(L|0,H|0,7)|0;ra=ga;sa=X>>>0>ia>>>0?ia:X}else{ia=(na&255)-1|0;ga=a[C+16+ia|0]|0;orc(L|0,H|0,ia|0)|0;ra=ga;sa=qa}a[H]=ra;a[$+(ja+2)|0]=ra;ga=da+1|0;if((ga|0)<(Y|0)){da=ga;ea=sa}else{ta=sa;break}}}else{ta=ba}ea=aa+1|0;if((ea|0)<(x|0)){$=$+U|0;aa=ea;ba=ta}else{break}}ua=c[z>>2]|0}else{ua=U}ba=Q+(ca(ua,x)|0)|0;aa=P+1|0;if((aa|0)<(u|0)){N=T;O=V+O|0;P=aa;Q=ba}else{break a}}if((S|0)==23){KIb(M,16,2206736,(o=i,i=i+16|0,c[o>>2]=V,c[o+8>>2]=W,o)|0);i=o;p=-1094995529;i=j;return p|0}else if((S|0)==25){KIb(M,16,2174392,(o=i,i=i+8|0,c[o>>2]=R,o)|0);i=o;p=-1094995529;i=j;return p|0}}}while(0);s=c[e+120>>2]|0;QIb(e,2248840,(o=i,i=i+24|0,c[o>>2]=u,c[o+8>>2]=s,c[o+16>>2]=q,o)|0);i=o;p=-1163346256;i=j;return p|0}else if((r|0)==402653193|(r|0)==419430409){va=zca(e,l,m+16|0,h-16|0,0)|0;S=251}else if((r|0)==385875977){va=zca(e,l,m+16|0,h-16|0,1)|0;S=251}else if((r|0)==402653185|(r|0)==419430401){s=h-16|0;t=(s|0)<0|0?-1:0;w=e+120|0;Q=e+124|0;P=ca(c[Q>>2]|0,c[w>>2]|0)|0;O=P;N=((P|0)<0|0?-1:0)<<1|O>>>31;if((t|0)<(N|0)|(t|0)==(N|0)&s>>>0<(O<<1|0>>>31)>>>0){KIb(e,16,2454624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=46;O=M4a(e,l,0)|0;if((O|0)<0){p=O;i=j;return p|0}if((c[Q>>2]|0)<=0){break}O=f+32|0;s=m+16|0;N=0;t=c[f>>2]|0;P=c[w>>2]|0;while(1){nrc(t|0,s|0,P<<1)|0;x=c[w>>2]|0;z=N+1|0;if((z|0)<(c[Q>>2]|0)){s=s+(x<<1)|0;N=z;t=t+(c[O>>2]|0)|0;P=x}else{break}}}else if((r|0)==33554433){P=e+120|0;O=e+124|0;if(((ca((c[P>>2]|0)*3|0,c[O>>2]|0)|0)/2|0|0)>(h-16|0)){KIb(e,16,2454624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=0;t=M4a(e,l,0)|0;if((t|0)<0){p=t;i=j;return p|0}t=c[f>>2]|0;N=f+32|0;s=c[O>>2]|0;if((s|0)<=0){break}Q=c[N>>2]|0;w=f+36|0;q=f+40|0;x=m+16|0;z=0;H=t;L=t+Q|0;t=c[f+4>>2]|0;C=c[f+8>>2]|0;E=c[P>>2]|0;K=Q;Q=s;while(1){if((E|0)>0){s=x;A=0;do{b[H+A>>1]=b[s>>1]|0;b[L+A>>1]=b[s+2>>1]|0;J=A>>1;a[t+J|0]=a[s+4|0]^-128;a[C+J|0]=a[s+5|0]^-128;s=s+6|0;A=A+2|0;wa=c[P>>2]|0;}while((A|0)<(wa|0));xa=s;ya=wa;za=c[N>>2]|0;Aa=c[O>>2]|0}else{xa=x;ya=E;za=K;Aa=Q}A=za<<1;M=z+2|0;if((M|0)<(Aa|0)){x=xa;z=M;H=H+A|0;L=L+A|0;t=t+(c[w>>2]|0)|0;C=C+(c[q>>2]|0)|0;E=ya;K=za;Q=Aa}else{break}}}else if((r|0)==50331649){Q=e+120|0;K=e+124|0;if(((ca((c[Q>>2]|0)*9|0,c[K>>2]|0)|0)/8|0|0)>(h-16|0)){KIb(e,16,2454624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=6;E=M4a(e,l,0)|0;if((E|0)<0){p=E;i=j;return p|0}E=c[f>>2]|0;q=f+32|0;C=c[q>>2]|0;w=c[K>>2]|0;if((w|0)<=0){break}t=f+36|0;L=f+40|0;H=m+16|0;z=0;x=E;O=E+C|0;N=E+(C<<1)|0;P=E+(C*3|0)|0;E=c[f+4>>2]|0;A=c[f+8>>2]|0;M=c[Q>>2]|0;J=C;C=w;while(1){if((M|0)>0){w=H;I=0;do{c[x+I>>2]=c[w>>2];c[O+I>>2]=c[w+4>>2];c[N+I>>2]=c[w+8>>2];c[P+I>>2]=c[w+12>>2];F=I>>2;a[E+F|0]=a[w+16|0]^-128;a[A+F|0]=a[w+17|0]^-128;w=w+18|0;I=I+4|0;Ba=c[Q>>2]|0;}while((I|0)<(Ba|0));Ca=w;Da=Ba;Ea=c[q>>2]|0;Fa=c[K>>2]|0}else{Ca=H;Da=M;Ea=J;Fa=C}I=Ea<<2;s=z+4|0;if((s|0)<(Fa|0)){H=Ca;z=s;x=x+I|0;O=O+I|0;N=N+I|0;P=P+I|0;E=E+(c[t>>2]|0)|0;A=A+(c[L>>2]|0)|0;M=Da;J=Ea;C=Fa}else{break}}}else if((r|0)==33554441){C=m+16|0;J=h-16|0;if(!((J|0)>-1)){KIb(0,0,2122992,(o=i,i=i+24|0,c[o>>2]=2640688,c[o+8>>2]=2617968,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}M=m+h|0;if((J|0)<2){Ga=0;Ha=C}else{L=C;Ga=(d[L]|d[L+1|0]<<8)<<16>>16&65535;Ha=m+18|0}L=(Ga<<2|2)+15&524272;if(L>>>0>J>>>0){KIb(e,16,2299864,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}C=c[e+124>>2]|0;do{if((Ga|0)!=0){if(((C|0)%(Ga|0)|0|0)!=0){break}A=(C|0)/(Ga|0)|0;t=e+120|0;E=c[t>>2]|0;if((E&1|0)==0){if((C&1|0)!=0){S=73}}else{S=73}if((S|0)==73){QIb(e,2590544,(o=i,i=i+16|0,c[o>>2]=E,c[o+8>>2]=C,o)|0);i=o}c[e+140>>2]=0;E=M4a(e,l,0)|0;if((E|0)<0){p=E;i=j;return p|0}E=f+32|0;P=f+36|0;N=f+40|0;O=k;x=k|0;z=k;H=k+8|0;K=H;q=k+16|0;Q=q;I=z+1|0;s=z+9|0;F=z+17|0;D=e;B=Ha;y=0;ba=A;aa=L;$=0;Y=c[f>>2]|0;X=c[f+4>>2]|0;Z=c[f+8>>2]|0;while(1){if((M-B|0)<4){Ia=0;S=80;break}_=B+4|0;ea=B;Ja=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0;ea=(ba&-2)-(y&-2)|0;Ka=J-aa|0;if(Ja>>>0>Ka>>>0){S=78;break}if(Ja>>>0<17>>>0){Ia=Ja;S=80;break}da=m+(aa+16)|0;ga=d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0;da=Ja-16|0;if((ga|0)!=(da|0)){KIb(D,16,2146816,(o=i,i=i+16|0,c[o>>2]=ga,c[o+8>>2]=da,o)|0);i=o}ga=m+(aa+32)|0;ia=da<<3;da=ia>>>0>2147483639>>>0|(ga|0)==0;fa=da?0:ga;ga=da?8:ia+8|0;ia=c[t>>2]|0;da=c[E>>2]|0;La=c[P>>2]|0;Ma=c[N>>2]|0;c[x>>2]=1614815232;c[x+4>>2]=-4153216;c[H>>2]=1614815232;c[H+4>>2]=-4153216;c[q>>2]=1614815232;c[q+4>>2]=-4153216;if((ea|0)>0){Na=(ia|0)>0;Oa=da<<1;Pa=Z;Qa=X;Ra=Y;Sa=0;Ta=0;while(1){if(Na){Ua=0;Va=Ta;while(1){Wa=0;Xa=Va;while(1){if((Wa|0)>=8){Ya=Xa;break}Za=((Xa|0)<(ga|0))+Xa|0;if(((d[fa+(Xa>>>3)|0]|0)&1<<(Xa&7)|0)==0){Ya=Za;break}else{Wa=Wa+1|0;Xa=Za}}if((Wa&255)<<24>>24==0){Xa=fa+(Ya>>>3)|0;ja=Ya+8|0;na=(d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0)>>>((Ya&7)>>>0)&255;orc(I|0,O|0,7)|0;_a=na;$a=ga>>>0>ja>>>0?ja:ga}else{ja=(Wa&255)-1|0;na=a[z+ja|0]|0;orc(I|0,O|0,ja|0)|0;_a=na;$a=Ya}a[O]=_a;a[Ra+Ua|0]=_a;na=0;ja=$a;while(1){if((na|0)>=8){ab=ja;break}Xa=((ja|0)<(ga|0))+ja|0;if(((d[fa+(ja>>>3)|0]|0)&1<<(ja&7)|0)==0){ab=Xa;break}else{na=na+1|0;ja=Xa}}if((na&255)<<24>>24==0){ja=fa+(ab>>>3)|0;Wa=ab+8|0;Xa=(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)>>>((ab&7)>>>0)&255;orc(I|0,O|0,7)|0;bb=Xa;cb=ga>>>0>Wa>>>0?Wa:ga}else{Wa=(na&255)-1|0;Xa=a[z+Wa|0]|0;orc(I|0,O|0,Wa|0)|0;bb=Xa;cb=ab}a[O]=bb;Xa=Ua|1;a[Ra+Xa|0]=bb;Wa=0;ja=cb;while(1){if((Wa|0)>=8){db=ja;break}Za=((ja|0)<(ga|0))+ja|0;if(((d[fa+(ja>>>3)|0]|0)&1<<(ja&7)|0)==0){db=Za;break}else{Wa=Wa+1|0;ja=Za}}if((Wa&255)<<24>>24==0){ja=fa+(db>>>3)|0;na=db+8|0;Za=(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)>>>((db&7)>>>0)&255;orc(I|0,O|0,7)|0;eb=Za;fb=ga>>>0>na>>>0?na:ga}else{na=(Wa&255)-1|0;Za=a[z+na|0]|0;orc(I|0,O|0,na|0)|0;eb=Za;fb=db}a[O]=eb;a[Ra+(Ua+da)|0]=eb;Za=0;na=fb;while(1){if((Za|0)>=8){gb=na;break}ja=((na|0)<(ga|0))+na|0;if(((d[fa+(na>>>3)|0]|0)&1<<(na&7)|0)==0){gb=ja;break}else{Za=Za+1|0;na=ja}}if((Za&255)<<24>>24==0){na=fa+(gb>>>3)|0;Wa=gb+8|0;ja=(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)>>>((gb&7)>>>0)&255;orc(I|0,O|0,7)|0;hb=ja;ib=ga>>>0>Wa>>>0?Wa:ga}else{Wa=(Za&255)-1|0;ja=a[z+Wa|0]|0;orc(I|0,O|0,Wa|0)|0;hb=ja;ib=gb}a[O]=hb;a[Ra+(Xa+da)|0]=hb;ja=0;Wa=ib;while(1){if((ja|0)>=8){jb=Wa;break}na=((Wa|0)<(ga|0))+Wa|0;if(((d[fa+(Wa>>>3)|0]|0)&1<<(Wa&7)|0)==0){jb=na;break}else{ja=ja+1|0;Wa=na}}if((ja&255)<<24>>24==0){Wa=fa+(jb>>>3)|0;Xa=jb+8|0;Za=(d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0)>>>((jb&7)>>>0)&255;orc(s|0,K|0,7)|0;kb=Za;lb=ga>>>0>Xa>>>0?Xa:ga}else{Xa=(ja&255)-1|0;Za=a[z+8+Xa|0]|0;orc(s|0,K|0,Xa|0)|0;kb=Za;lb=jb}a[K]=kb;Za=Ua>>1;a[Qa+Za|0]=kb^-128;Xa=0;Wa=lb;while(1){if((Xa|0)>=8){mb=Wa;break}na=((Wa|0)<(ga|0))+Wa|0;if(((d[fa+(Wa>>>3)|0]|0)&1<<(Wa&7)|0)==0){mb=na;break}else{Xa=Xa+1|0;Wa=na}}if((Xa&255)<<24>>24==0){Wa=fa+(mb>>>3)|0;ja=mb+8|0;na=(d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0)>>>((mb&7)>>>0)&255;orc(F|0,Q|0,7)|0;nb=na;ob=ga>>>0>ja>>>0?ja:ga}else{ja=(Xa&255)-1|0;na=a[z+16+ja|0]|0;orc(F|0,Q|0,ja|0)|0;nb=na;ob=mb}a[Q]=nb;a[Pa+Za|0]=nb^-128;na=Ua+2|0;if((na|0)<(ia|0)){Ua=na;Va=ob}else{pb=ob;break}}}else{pb=Ta}Va=Sa+2|0;if((Va|0)<(ea|0)){Pa=Pa+Ma|0;Qa=Qa+La|0;Ra=Ra+Oa|0;Sa=Va;Ta=pb}else{break}}qb=c[E>>2]|0;rb=c[P>>2]|0;sb=c[N>>2]|0}else{qb=da;rb=La;sb=Ma}Ta=Y+(ca(qb,ea)|0)|0;Sa=ea>>1;Oa=X+(ca(rb,Sa)|0)|0;Ra=Z+(ca(sb,Sa)|0)|0;Sa=$+1|0;if((Sa|0)<(Ga|0)){B=_;y=ba;ba=ba+A|0;aa=Ja+aa|0;$=Sa;Y=Ta;X=Oa;Z=Ra}else{break a}}if((S|0)==78){KIb(D,16,2206736,(o=i,i=i+16|0,c[o>>2]=Ja,c[o+8>>2]=Ka,o)|0);i=o;p=-1094995529;i=j;return p|0}else if((S|0)==80){KIb(D,16,2174392,(o=i,i=i+8|0,c[o>>2]=Ia,o)|0);i=o;p=-1094995529;i=j;return p|0}}}while(0);J=c[e+120>>2]|0;QIb(e,2248840,(o=i,i=i+24|0,c[o>>2]=Ga,c[o+8>>2]=J,c[o+16>>2]=C,o)|0);i=o;p=-1163346256;i=j;return p|0}else if((r|0)==50331657){J=m+16|0;M=h-16|0;if(!((M|0)>-1)){KIb(0,0,2122992,(o=i,i=i+24|0,c[o>>2]=2640688,c[o+8>>2]=2617968,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}L=m+h|0;if((M|0)<2){tb=0;ub=J}else{Z=J;tb=(d[Z]|d[Z+1|0]<<8)<<16>>16&65535;ub=m+18|0}Z=(tb<<2|2)+15&524272;if(Z>>>0>M>>>0){KIb(e,16,2299864,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}J=c[e+124>>2]|0;do{if((tb|0)!=0){if(((J|0)%(tb|0)|0|0)!=0){break}X=(J|0)/(tb|0)|0;Y=e+120|0;$=c[Y>>2]|0;if(($&3|0)==0){if((J&3|0)!=0){S=146}}else{S=146}if((S|0)==146){QIb(e,2590544,(o=i,i=i+16|0,c[o>>2]=$,c[o+8>>2]=J,o)|0);i=o}c[e+140>>2]=6;$=M4a(e,l,0)|0;if(($|0)<0){p=$;i=j;return p|0}$=f+32|0;aa=f+36|0;A=f+40|0;ba=k;y=k|0;B=k;N=k+8|0;P=N;E=k+16|0;Q=E;F=B+1|0;z=B+9|0;K=B+17|0;s=e;O=ub;I=0;q=X;H=Z;x=0;t=c[f>>2]|0;w=c[f+4>>2]|0;Ra=c[f+8>>2]|0;while(1){if((L-O|0)<4){vb=0;S=153;break}Oa=O+4|0;Ta=O;wb=d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0;Ta=(q&-4)-(I&-4)|0;xb=M-H|0;if(wb>>>0>xb>>>0){S=151;break}if(wb>>>0<17>>>0){vb=wb;S=153;break}Sa=m+(H+16)|0;Qa=d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0;Sa=wb-16|0;if((Qa|0)!=(Sa|0)){KIb(s,16,2146816,(o=i,i=i+16|0,c[o>>2]=Qa,c[o+8>>2]=Sa,o)|0);i=o}Qa=m+(H+32)|0;Pa=Sa<<3;Sa=Pa>>>0>2147483639>>>0|(Qa|0)==0;ia=Sa?0:Qa;Qa=Sa?8:Pa+8|0;Pa=c[Y>>2]|0;Sa=c[$>>2]|0;ga=c[aa>>2]|0;fa=c[A>>2]|0;c[y>>2]=1614815232;c[y+4>>2]=-4153216;c[N>>2]=1614815232;c[N+4>>2]=-4153216;c[E>>2]=1614815232;c[E+4>>2]=-4153216;if((Ta|0)>0){Na=(Pa|0)>0;T=Sa<<2;U=Ra;Va=w;Ua=t;na=0;ja=0;while(1){if(Na){Wa=0;yb=ja;while(1){zb=0;Ab=yb;while(1){Bb=(ca(zb,Sa)|0)+Wa|0;Cb=0;Db=Ab;while(1){Eb=0;Fb=Db;while(1){if((Eb|0)>=8){Gb=Fb;break}Hb=((Fb|0)<(Qa|0))+Fb|0;if(((d[ia+(Fb>>>3)|0]|0)&1<<(Fb&7)|0)==0){Gb=Hb;break}else{Eb=Eb+1|0;Fb=Hb}}if((Eb&255)<<24>>24==0){Fb=ia+(Gb>>>3)|0;Hb=Gb+8|0;Ib=(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)>>>((Gb&7)>>>0)&255;orc(F|0,ba|0,7)|0;Jb=Ib;Kb=Qa>>>0>Hb>>>0?Hb:Qa}else{Hb=(Eb&255)-1|0;Ib=a[B+Hb|0]|0;orc(F|0,ba|0,Hb|0)|0;Jb=Ib;Kb=Gb}a[ba]=Jb;a[Ua+(Bb+Cb)|0]=Jb;Ib=Cb+1|0;if((Ib|0)<4){Cb=Ib;Db=Kb}else{break}}Db=zb+1|0;if((Db|0)<4){zb=Db;Ab=Kb}else{Lb=0;Mb=Kb;break}}while(1){if((Lb|0)>=8){Nb=Mb;break}Ab=((Mb|0)<(Qa|0))+Mb|0;if(((d[ia+(Mb>>>3)|0]|0)&1<<(Mb&7)|0)==0){Nb=Ab;break}else{Lb=Lb+1|0;Mb=Ab}}if((Lb&255)<<24>>24==0){Ab=ia+(Nb>>>3)|0;zb=Nb+8|0;Za=(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)>>>((Nb&7)>>>0)&255;orc(z|0,P|0,7)|0;Ob=Za;Pb=Qa>>>0>zb>>>0?zb:Qa}else{zb=(Lb&255)-1|0;Za=a[B+8+zb|0]|0;orc(z|0,P|0,zb|0)|0;Ob=Za;Pb=Nb}a[P]=Ob;Za=Wa>>2;a[Va+Za|0]=Ob^-128;zb=0;Ab=Pb;while(1){if((zb|0)>=8){Qb=Ab;break}Xa=((Ab|0)<(Qa|0))+Ab|0;if(((d[ia+(Ab>>>3)|0]|0)&1<<(Ab&7)|0)==0){Qb=Xa;break}else{zb=zb+1|0;Ab=Xa}}if((zb&255)<<24>>24==0){Ab=ia+(Qb>>>3)|0;Xa=Qb+8|0;Db=(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)>>>((Qb&7)>>>0)&255;orc(K|0,Q|0,7)|0;Rb=Db;Sb=Qa>>>0>Xa>>>0?Xa:Qa}else{Xa=(zb&255)-1|0;Db=a[B+16+Xa|0]|0;orc(K|0,Q|0,Xa|0)|0;Rb=Db;Sb=Qb}a[Q]=Rb;a[U+Za|0]=Rb^-128;Db=Wa+4|0;if((Db|0)<(Pa|0)){Wa=Db;yb=Sb}else{Tb=Sb;break}}}else{Tb=ja}yb=na+4|0;if((yb|0)<(Ta|0)){U=U+fa|0;Va=Va+ga|0;Ua=Ua+T|0;na=yb;ja=Tb}else{break}}Ub=c[$>>2]|0;Vb=c[aa>>2]|0;Wb=c[A>>2]|0}else{Ub=Sa;Vb=ga;Wb=fa}ja=t+(ca(Ub,Ta)|0)|0;na=Ta>>2;T=w+(ca(Vb,na)|0)|0;Ua=Ra+(ca(Wb,na)|0)|0;na=x+1|0;if((na|0)<(tb|0)){O=Oa;I=q;q=q+X|0;H=wb+H|0;x=na;t=ja;w=T;Ra=Ua}else{break a}}if((S|0)==151){KIb(s,16,2206736,(o=i,i=i+16|0,c[o>>2]=wb,c[o+8>>2]=xb,o)|0);i=o;p=-1094995529;i=j;return p|0}else if((S|0)==153){KIb(s,16,2174392,(o=i,i=i+8|0,c[o>>2]=vb,o)|0);i=o;p=-1094995529;i=j;return p|0}}}while(0);M=c[e+120>>2]|0;QIb(e,2248840,(o=i,i=i+24|0,c[o>>2]=tb,c[o+8>>2]=M,c[o+16>>2]=J,o)|0);i=o;p=-1163346256;i=j;return p|0}else if((r|0)==16777217){M=h-16|0;L=(M|0)<0|0?-1:0;Z=e+120|0;C=e+124|0;Ra=ca(c[C>>2]|0,c[Z>>2]|0)|0;w=Erc(Ra,(Ra|0)<0|0?-1:0,3,0)|0;Ra=G;if((L|0)<(Ra|0)|(L|0)==(Ra|0)&M>>>0<w>>>0){KIb(e,16,2454624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=3;w=M4a(e,l,0)|0;if((w|0)<0){p=w;i=j;return p|0}if((c[C>>2]|0)<=0){break}w=f+32|0;M=m+16|0;Ra=0;L=c[f>>2]|0;t=c[Z>>2]|0;while(1){nrc(L|0,M|0,t*3|0)|0;x=c[Z>>2]|0;H=Ra+1|0;if((H|0)<(c[C>>2]|0)){M=M+(x*3|0)|0;Ra=H;L=L+(c[w>>2]|0)|0;t=x}else{break}}}else if((r|0)==385875969){t=h-16|0;w=(t|0)<0|0?-1:0;L=e+120|0;Ra=e+124|0;M=ca(c[Ra>>2]|0,c[L>>2]|0)|0;C=M;Z=((M|0)<0|0?-1:0)<<1|C>>>31;if((w|0)<(Z|0)|(w|0)==(Z|0)&t>>>0<(C<<1|0>>>31)>>>0){KIb(e,16,2454624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=44;C=M4a(e,l,0)|0;if((C|0)<0){p=C;i=j;return p|0}if((c[Ra>>2]|0)<=0){break}C=f+32|0;t=m+16|0;Z=0;w=c[f>>2]|0;M=c[L>>2]|0;while(1){nrc(w|0,t|0,M<<1)|0;J=c[L>>2]|0;x=Z+1|0;if((x|0)<(c[Ra>>2]|0)){t=t+(J<<1)|0;Z=x;w=w+(c[C>>2]|0)|0;M=J}else{break}}}else if((r|0)==67108865){M=e+120|0;C=e+124|0;if((ca((c[M>>2]|0)*3|0,c[C>>2]|0)|0)>(h-16|0)){KIb(e,16,2454624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}c[e+140>>2]=5;w=M4a(e,l,0)|0;if((w|0)<0){p=w;i=j;return p|0}w=c[C>>2]|0;if((w|0)<=0){break}Z=f+32|0;t=f+36|0;Ra=f+40|0;L=m+16|0;J=0;x=c[f>>2]|0;H=c[f+4>>2]|0;X=c[f+8>>2]|0;q=c[M>>2]|0;I=w;while(1){if((q|0)>0){w=L;O=0;while(1){a[x+O|0]=a[w]|0;a[H+O|0]=a[w+1|0]^-128;Xb=w+3|0;a[X+O|0]=a[w+2|0]^-128;A=O+1|0;Yb=c[M>>2]|0;if((A|0)<(Yb|0)){w=Xb;O=A}else{break}}Zb=Xb;_b=Yb;$b=c[C>>2]|0}else{Zb=L;_b=q;$b=I}O=J+1|0;if((O|0)<($b|0)){L=Zb;J=O;x=x+(c[Z>>2]|0)|0;H=H+(c[t>>2]|0)|0;X=X+(c[Ra>>2]|0)|0;q=_b;I=$b}else{break}}}else if((r|0)==67108873){I=m+16|0;q=h-16|0;if(!((q|0)>-1)){KIb(0,0,2122992,(o=i,i=i+24|0,c[o>>2]=2640688,c[o+8>>2]=2617968,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}Ra=m+h|0;if((q|0)<2){ac=0;bc=I}else{X=I;ac=(d[X]|d[X+1|0]<<8)<<16>>16&65535;bc=m+18|0}X=(ac<<2|2)+15&524272;if(X>>>0>q>>>0){KIb(e,16,2299864,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}I=c[e+124>>2]|0;do{if((ac|0)!=0){if(((I|0)%(ac|0)|0|0)!=0){break}t=(I|0)/(ac|0)|0;c[e+140>>2]=5;H=M4a(e,l,0)|0;if((H|0)<0){p=H;i=j;return p|0}H=e+120|0;Z=f+32|0;x=f+36|0;J=f+40|0;L=k;C=k|0;M=k;O=k+8|0;w=O;s=k+16|0;A=s;aa=(t|0)>0;$=M+1|0;Q=M+9|0;K=M+17|0;B=e;P=bc;z=X;ba=0;F=c[f>>2]|0;E=c[f+4>>2]|0;N=c[f+8>>2]|0;while(1){if((Ra-P|0)<4){cc=0;S=208;break}y=P+4|0;Y=P;dc=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;ec=q-z|0;if(dc>>>0>ec>>>0){S=206;break}if(dc>>>0<17>>>0){cc=dc;S=208;break}Y=m+(z+16)|0;D=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;Y=dc-16|0;if((D|0)!=(Y|0)){KIb(B,16,2146816,(o=i,i=i+16|0,c[o>>2]=D,c[o+8>>2]=Y,o)|0);i=o}D=m+(z+32)|0;Ua=Y<<3;Y=Ua>>>0>2147483639>>>0|(D|0)==0;T=Y?0:D;D=Y?8:Ua+8|0;Ua=c[H>>2]|0;Y=c[Z>>2]|0;ja=c[x>>2]|0;na=c[J>>2]|0;c[C>>2]=1614815232;c[C+4>>2]=-4153216;c[O>>2]=1614815232;c[O+4>>2]=-4153216;c[s>>2]=1614815232;c[s+4>>2]=-4153216;if(aa){Va=(Ua|0)>0;U=N;Pa=E;Qa=F;ia=0;Na=0;while(1){if(Va){_=0;ea=Na;while(1){Ma=0;La=ea;while(1){if((Ma|0)>=8){fc=La;break}da=((La|0)<(D|0))+La|0;if(((d[T+(La>>>3)|0]|0)&1<<(La&7)|0)==0){fc=da;break}else{Ma=Ma+1|0;La=da}}if((Ma&255)<<24>>24==0){La=T+(fc>>>3)|0;Za=fc+8|0;zb=(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0)>>>((fc&7)>>>0)&255;orc($|0,L|0,7)|0;gc=zb;hc=D>>>0>Za>>>0?Za:D}else{Za=(Ma&255)-1|0;zb=a[M+Za|0]|0;orc($|0,L|0,Za|0)|0;gc=zb;hc=fc}a[L]=gc;a[Qa+_|0]=gc;zb=0;Za=hc;while(1){if((zb|0)>=8){ic=Za;break}La=((Za|0)<(D|0))+Za|0;if(((d[T+(Za>>>3)|0]|0)&1<<(Za&7)|0)==0){ic=La;break}else{zb=zb+1|0;Za=La}}if((zb&255)<<24>>24==0){Za=T+(ic>>>3)|0;Ma=ic+8|0;La=(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)>>>((ic&7)>>>0)&255;orc(Q|0,w|0,7)|0;jc=La;kc=D>>>0>Ma>>>0?Ma:D}else{Ma=(zb&255)-1|0;La=a[M+8+Ma|0]|0;orc(Q|0,w|0,Ma|0)|0;jc=La;kc=ic}a[w]=jc;a[Pa+_|0]=jc^-128;La=0;Ma=kc;while(1){if((La|0)>=8){lc=Ma;break}Za=((Ma|0)<(D|0))+Ma|0;if(((d[T+(Ma>>>3)|0]|0)&1<<(Ma&7)|0)==0){lc=Za;break}else{La=La+1|0;Ma=Za}}if((La&255)<<24>>24==0){Ma=T+(lc>>>3)|0;zb=lc+8|0;Za=(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)>>>((lc&7)>>>0)&255;orc(K|0,A|0,7)|0;mc=Za;nc=D>>>0>zb>>>0?zb:D}else{zb=(La&255)-1|0;Za=a[M+16+zb|0]|0;orc(K|0,A|0,zb|0)|0;mc=Za;nc=lc}a[A]=mc;a[U+_|0]=mc^-128;Za=_+1|0;if((Za|0)<(Ua|0)){_=Za;ea=nc}else{oc=nc;break}}}else{oc=Na}ea=ia+1|0;if((ea|0)<(t|0)){U=U+na|0;Pa=Pa+ja|0;Qa=Qa+Y|0;ia=ea;Na=oc}else{break}}pc=c[Z>>2]|0;qc=c[x>>2]|0;rc=c[J>>2]|0}else{pc=Y;qc=ja;rc=na}Na=F+(ca(pc,t)|0)|0;ia=E+(ca(qc,t)|0)|0;Qa=N+(ca(rc,t)|0)|0;Pa=ba+1|0;if((Pa|0)<(ac|0)){P=y;z=dc+z|0;ba=Pa;F=Na;E=ia;N=Qa}else{break a}}if((S|0)==206){KIb(B,16,2206736,(o=i,i=i+16|0,c[o>>2]=dc,c[o+8>>2]=ec,o)|0);i=o;p=-1094995529;i=j;return p|0}else if((S|0)==208){KIb(B,16,2174392,(o=i,i=i+8|0,c[o>>2]=cc,o)|0);i=o;p=-1094995529;i=j;return p|0}}}while(0);q=c[e+120>>2]|0;QIb(e,2248840,(o=i,i=i+24|0,c[o>>2]=ac,c[o+8>>2]=q,c[o+16>>2]=I,o)|0);i=o;p=-1163346256;i=j;return p|0}else{QIb(e,2365080,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;p=-1163346256;i=j;return p|0}}while(0);do{if((S|0)==251){if((va|0)==0){break}else{p=va}i=j;return p|0}}while(0);c[f+88>>2]=1;c[f+84>>2]=1;c[g>>2]=1;p=c[n>>2]|0;i=j;return p|0}function zca(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;j=i;i=i+24|0;k=j|0;if(!((g|0)>-1)){KIb(0,0,2122992,(l=i,i=i+24|0,c[l>>2]=2640688,c[l+8>>2]=2617968,c[l+16>>2]=135,l)|0);i=l;Hd();return 0}m=f+g|0;if((g|0)<2){n=0;o=f}else{p=f;n=(d[p]|d[p+1|0]<<8)<<16>>16&65535;o=f+2|0}p=(n<<2|2)+15&524272;if(p>>>0>g>>>0){KIb(b,16,2299864,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;q=-1094995529;i=j;return q|0}r=c[b+124>>2]|0;do{if((n|0)!=0){if(((r|0)%(n|0)|0|0)!=0){break}s=(r|0)/(n|0)|0;c[b+140>>2]=2;t=M4a(b,e,0)|0;if((t|0)<0){q=t;i=j;return q|0}t=b+120|0;u=e+32|0;v=k;w=k|0;x=k+8|0;y=(h|0)!=0;z=y?537921536:403703808;A=y?16176:31;B=k+16|0;C=(s|0)>0;D=v+1|0;E=x;F=y?6:5;G=32-F|0;H=E+1|0;I=B;J=I+1|0;K=b;L=o;M=p;N=0;O=c[e>>2]|0;while(1){if((m-L|0)<4){P=0;Q=16;break}R=L+4|0;S=L;T=d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0;U=g-M|0;if(T>>>0>U>>>0){Q=14;break}if(T>>>0<17>>>0){P=T;Q=16;break}S=f+M|0;V=d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0;S=T-16|0;if((V|0)!=(S|0)){KIb(K,16,2146816,(l=i,i=i+16|0,c[l>>2]=V,c[l+8>>2]=S,l)|0);i=l}V=f+(M+16)|0;W=S<<3;S=W>>>0>2147483639>>>0|(V|0)==0;X=S?0:V;V=S?8:W+8|0;W=c[t>>2]|0;S=c[u>>2]|0;c[w>>2]=403703808;c[w+4>>2]=31;c[x>>2]=z;c[x+4>>2]=A;c[B>>2]=403703808;c[B+4>>2]=31;if(C){Y=(W|0)>0;Z=0;_=O;$=0;while(1){if(Y){aa=0;ba=$;while(1){da=0;ea=ba;while(1){if((da|0)>=5){fa=ea;break}ga=((ea|0)<(V|0))+ea|0;if(((d[X+(ea>>>3)|0]|0)&1<<(ea&7)|0)==0){fa=ga;break}else{da=da+1|0;ea=ga}}if((da&255)<<24>>24==0){ea=X+(fa>>>3)|0;ga=fa+5|0;ha=(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)>>>((fa&7)>>>0)&31;orc(D|0,v|0,5)|0;ia=ha;ja=V>>>0>ga>>>0?ga:V}else{ga=(da&255)-1|0;ha=a[v+ga|0]|0;orc(D|0,v|0,ga|0)|0;ia=ha;ja=fa}a[v]=ia;ha=0;ga=ja;while(1){if((ha|0)>=(F|0)){ka=ga;break}ea=((ga|0)<(V|0))+ga|0;if(((d[X+(ga>>>3)|0]|0)&1<<(ga&7)|0)==0){ka=ea;break}else{ha=ha+1|0;ga=ea}}if((ha&255)<<24>>24==0){ga=X+(ka>>>3)|0;da=ka+F|0;ea=(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((ka&7)>>>0)<<G>>>(G>>>0)&255;orc(H|0,E|0,5)|0;la=ea;ma=V>>>0>da>>>0?da:V}else{da=(ha&255)-1|0;ea=a[E+da|0]|0;orc(H|0,E|0,da|0)|0;la=ea;ma=ka}a[E]=la;ea=0;da=ma;while(1){if((ea|0)>=5){na=da;break}ga=((da|0)<(V|0))+da|0;if(((d[X+(da>>>3)|0]|0)&1<<(da&7)|0)==0){na=ga;break}else{ea=ea+1|0;da=ga}}if((ea&255)<<24>>24==0){da=X+(na>>>3)|0;ha=na+5|0;ga=(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((na&7)>>>0)&31;orc(J|0,I|0,5)|0;oa=ga;pa=V>>>0>ha>>>0?ha:V}else{ha=(ea&255)-1|0;ga=a[I+ha|0]|0;orc(J|0,I|0,ha|0)|0;oa=ga;pa=na}a[I]=oa;ga=aa*3|0;a[_+ga|0]=oa<<3|(oa&255)>>>2;if(y){qa=la<<2|(la&255)>>>4}else{qa=la<<3|(la&255)>>>2}a[_+(ga+1)|0]=qa;a[_+(ga+2)|0]=ia<<3|(ia&255)>>>2;ga=aa+1|0;if((ga|0)<(W|0)){aa=ga;ba=pa}else{ra=pa;break}}}else{ra=$}ba=Z+1|0;if((ba|0)<(s|0)){Z=ba;_=_+S|0;$=ra}else{break}}sa=c[u>>2]|0}else{sa=S}$=O+(ca(sa,s)|0)|0;_=N+1|0;if((_|0)<(n|0)){L=R;M=T+M|0;N=_;O=$}else{q=0;Q=47;break}}if((Q|0)==14){KIb(K,16,2206736,(l=i,i=i+16|0,c[l>>2]=T,c[l+8>>2]=U,l)|0);i=l;q=-1094995529;i=j;return q|0}else if((Q|0)==16){KIb(K,16,2174392,(l=i,i=i+8|0,c[l>>2]=P,l)|0);i=l;q=-1094995529;i=j;return q|0}else if((Q|0)==47){i=j;return q|0}}}while(0);Q=c[b+120>>2]|0;QIb(b,2248840,(l=i,i=i+24|0,c[l>>2]=n,c[l+8>>2]=Q,c[l+16>>2]=r,l)|0);i=l;q=-1163346256;i=j;return q|0}function Aca(){var b=0;mrc(8980616,-1|0,3072)|0;b=0;do{a[(d[1392837+(b*6|0)|0]|0)+(8980616+((d[1392832+(b*6|0)|0]|0)-1<<10)+((d[1392833+(b*6|0)|0]|0)<<8)+((d[1392834+(b*6|0)|0]|0)<<6)+((d[1392835+(b*6|0)|0]|0)<<4)+((d[1392836+(b*6|0)|0]|0)<<2))|0]=b;b=b+1|0;}while((b|0)<32);return}function Bca(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b+2740|0;if((c[b+2332>>2]|0)<6){c[e>>2]=0;return}c[e>>2]=1;f=(c[b+2464>>2]|0)==0|0;g=b+2368|0;if((f|0)>(c[g>>2]|0)){return}else{h=f}while(1){f=a[(d[b+2688+(h*6|0)+5|0]|0)+(8980616+((d[b+2688+(h*6|0)|0]|0)-1<<10)+((d[b+2688+(h*6|0)+1|0]|0)<<8)+((d[b+2688+(h*6|0)+2|0]|0)<<6)+((d[b+2688+(h*6|0)+3|0]|0)<<4)+((d[b+2688+(h*6|0)+4|0]|0)<<2))|0]|0;if(f<<24>>24<0){break}a[b+2730+h|0]=f;f=h+1|0;if((f|0)>(c[g>>2]|0)){i=7;break}else{h=f}}if((i|0)==7){return}c[e>>2]=0;return}function Cca(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+32|0;e=d|0;f=b+2368|0;g=c[f>>2]|0;if((g|0)>=1){h=1;do{c[e+(h<<2)>>2]=1;h=h+1|0;}while((h|0)<=(g|0))}h=b+2332|0;j=c[h>>2]|0;if((j|0)>0){k=0;l=g;g=j;while(1){if((l|0)<1){m=l;n=g}else{o=1;p=l;while(1){q=e+(o<<2)|0;do{if((a[b+1536+(k<<7)+64+o|0]|0)==0){c[q>>2]=1;r=p}else{if((c[q>>2]|0)==0){r=p;break}a[b+1536+(k<<7)+76+o|0]=2;c[q>>2]=0;r=c[f>>2]|0}}while(0);q=o+1|0;if((q|0)>(r|0)){break}else{o=q;p=r}}m=r;n=c[h>>2]|0}p=k+1|0;if((p|0)<(n|0)){k=p;l=m;g=n}else{s=n;break}}}else{s=j}j=0;while(1){if((j|0)>=(s|0)){t=16;break}if((c[b+1536+(j<<7)+60>>2]|0)==0){j=j+1|0}else{break}}if((t|0)==16){i=d;return}c[b+1536+(j<<7)+96>>2]=2;i=d;return}function Dca(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0;e=b+112|0;f=c[e>>2]|0;g=b+116|0;h=c[g>>2]|0;if((h|0)>16){i=h-16|0;j=f<<16|2935}else{k=je(2935>>>((16-h|0)>>>0)|f<<h|0)|0;f=b+124|0;l=c[f>>2]|0;y=k;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;i=h+16|0;j=2935}c[e>>2]=j;c[g>>2]=i;if((i|0)>2){m=i-2|0;n=j<<2}else{h=je(j<<i|0)|0;j=b+124|0;f=c[j>>2]|0;y=h;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;m=i+30|0;n=0}c[e>>2]=n;c[g>>2]=m;if((m|0)>3){o=m-3|0;p=n<<3}else{i=je(n<<m|0)|0;n=b+124|0;j=c[n>>2]|0;y=i;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;o=m+29|0;p=0}c[e>>2]=p;c[g>>2]=o;m=((c[b+2340>>2]|0)/2|0)-1|0;if((o|0)>11){q=o-11|0;r=p<<11|m}else{n=je(m>>>((11-o|0)>>>0)|p<<o|0)|0;p=b+124|0;j=c[p>>2]|0;y=n;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;q=o+21|0;r=m}c[e>>2]=r;c[g>>2]=q;m=b+2524|0;do{if((c[b+2528>>2]|0)==0){o=c[m>>2]|0;if((q|0)>2){s=q-2|0;t=r<<2|o}else{p=je(r<<q|o>>>((2-q|0)>>>0)|0)|0;j=b+124|0;n=c[j>>2]|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;s=q+30|0;t=o}c[e>>2]=t;c[g>>2]=s;o=c[b+2328>>2]|0;if((s|0)>2){u=s-2|0;v=t<<2|o;break}else{j=je(t<<s|o>>>((2-s|0)>>>0)|0)|0;n=b+124|0;p=c[n>>2]|0;y=j;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;u=s+30|0;v=o;break}}else{if((q|0)>2){w=q-2|0;x=r<<2|3}else{o=je(r<<q|3>>>((2-q|0)>>>0)|0)|0;n=b+124|0;p=c[n>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;w=q+30|0;x=3}c[e>>2]=x;c[g>>2]=w;n=c[m>>2]|0;if((w|0)>2){u=w-2|0;v=x<<2|n;break}else{p=je(x<<w|n>>>((2-w|0)>>>0)|0)|0;o=b+124|0;j=c[o>>2]|0;y=p;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;u=w+30|0;v=n;break}}}while(0);c[e>>2]=v;c[g>>2]=u;w=b+2392|0;x=c[w>>2]|0;if((u|0)>3){z=u-3|0;A=v<<3|x}else{m=je(v<<u|x>>>((3-u|0)>>>0)|0)|0;v=b+124|0;q=c[v>>2]|0;y=m;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;z=u+29|0;A=x}c[e>>2]=A;c[g>>2]=z;x=b+2376|0;u=c[x>>2]|0;if((z|0)>1){B=z-1|0;C=A<<1|u}else{v=je(A<<z|u>>>((1-z|0)>>>0)|0)|0;A=b+124|0;q=c[A>>2]|0;y=v;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;B=z+31|0;C=u}c[e>>2]=C;c[g>>2]=B;u=c[b+2312>>2]|0;if((B|0)>5){D=B-5|0;E=C<<5|u}else{z=je(C<<B|u>>>((5-B|0)>>>0)|0)|0;C=b+124|0;A=c[C>>2]|0;y=z;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;D=B+27|0;E=u}c[e>>2]=E;c[g>>2]=D;u=-(c[b+4>>2]|0)|0;if((D|0)>5){F=D-5|0;G=E<<5|u}else{B=je(E<<D|u>>>((5-D|0)>>>0)|0)|0;E=b+124|0;C=c[E>>2]|0;y=B;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;F=D+27|0;G=u}c[e>>2]=G;c[g>>2]=F;if((F|0)>1){H=F-1|0;I=G<<1}else{u=je(G<<F|0)|0;G=b+124|0;D=c[G>>2]|0;y=u;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;H=F+31|0;I=0}c[e>>2]=I;c[g>>2]=H;F=b+84|0;G=c[F>>2]|0;if((H|0)>1){J=H-1|0;K=I<<1|G;L=G}else{D=je(I<<H|G>>>((1-H|0)>>>0)|0)|0;I=b+124|0;u=c[I>>2]|0;y=D;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;J=H+31|0;K=G;L=c[F>>2]|0}c[e>>2]=K;c[g>>2]=J;if((L|0)==0){M=J;N=K}else{if((c[w>>2]|0)>2){L=c[b+48>>2]|0;if((J|0)>2){O=J-2|0;P=K<<2|L}else{F=je(K<<J|L>>>((2-J|0)>>>0)|0)|0;G=b+124|0;H=c[G>>2]|0;y=F;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;O=J+30|0;P=L}c[e>>2]=P;c[g>>2]=O;Q=O;R=P}else{Q=J;R=K}if((c[b+2384>>2]|0)==0){S=Q;T=R}else{K=c[b+2408>>2]|0;if((Q|0)>3){U=Q-3|0;V=R<<3|K}else{J=je(K>>>((3-Q|0)>>>0)|R<<Q|0)|0;R=b+124|0;P=c[R>>2]|0;y=J;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[R>>2]=(c[R>>2]|0)+4;U=Q+29|0;V=K}c[e>>2]=V;c[g>>2]=U;K=c[b+2416>>2]|0;if((U|0)>3){W=U-3|0;X=V<<3|K}else{Q=je(V<<U|K>>>((3-U|0)>>>0)|0)|0;V=b+124|0;R=c[V>>2]|0;y=Q;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[V>>2]=(c[V>>2]|0)+4;W=U+29|0;X=K}c[e>>2]=X;c[g>>2]=W;S=W;T=X}if((c[b+2388>>2]|0)==0){Y=S;Z=T}else{X=c[b+2412>>2]|0;if((S|0)>3){_=S-3|0;$=T<<3|X}else{W=je(X>>>((3-S|0)>>>0)|T<<S|0)|0;T=b+124|0;K=c[T>>2]|0;y=W;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[T>>2]=(c[T>>2]|0)+4;_=S+29|0;$=X}c[e>>2]=$;c[g>>2]=_;X=c[b+2420>>2]|0;if((_|0)>3){aa=_-3|0;ba=$<<3|X}else{S=je($<<_|X>>>((3-_|0)>>>0)|0)|0;$=b+124|0;T=c[$>>2]|0;y=S;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;aa=_+29|0;ba=X}c[e>>2]=ba;c[g>>2]=aa;Y=aa;Z=ba}if((c[x>>2]|0)==0){ca=Y;da=Z}else{if((Y|0)>1){ea=Y-1|0;fa=Z<<1}else{ba=je(Z<<Y|0)|0;Z=b+124|0;aa=c[Z>>2]|0;y=ba;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;c[Z>>2]=(c[Z>>2]|0)+4;ea=Y+31|0;fa=0}c[e>>2]=fa;c[g>>2]=ea;ca=ea;da=fa}if((ca|0)>1){ga=ca-1|0;ha=da<<1}else{fa=je(da<<ca|0)|0;da=b+124|0;ea=c[da>>2]|0;y=fa;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;c[da>>2]=(c[da>>2]|0)+4;ga=ca+31|0;ha=0}c[e>>2]=ha;c[g>>2]=ga;if((ga|0)>1){ia=ga-1|0;ja=ha<<1}else{ca=je(ha<<ga|0)|0;ha=b+124|0;da=c[ha>>2]|0;y=ca;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;ia=ga+31|0;ja=0}c[e>>2]=ja;c[g>>2]=ia;if((ia|0)>2){ka=ia-2|0;la=ja<<2}else{ga=je(ja<<ia|0)|0;ja=b+124|0;ha=c[ja>>2]|0;y=ga;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;ka=ia+30|0;la=0}c[e>>2]=la;c[g>>2]=ka;if((c[w>>2]|0)<2){if((ka|0)>1){ma=ka-1|0;na=la<<1}else{ia=je(la<<ka|0)|0;ja=b+124|0;ha=c[ja>>2]|0;y=ia;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;ma=ka+31|0;na=0}c[e>>2]=na;c[g>>2]=ma;oa=ma;pa=na}else{oa=ka;pa=la}if((oa|0)>1){qa=oa-1|0;ra=pa<<1}else{la=je(pa<<oa|0)|0;pa=b+124|0;ka=c[pa>>2]|0;y=la;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;c[pa>>2]=(c[pa>>2]|0)+4;qa=oa+31|0;ra=0}c[e>>2]=ra;c[g>>2]=qa;M=qa;N=ra}ra=b+88|0;qa=c[ra>>2]|0;if((M|0)>1){sa=M-1|0;ta=N<<1|qa;ua=qa}else{oa=je(N<<M|qa>>>((1-M|0)>>>0)|0)|0;N=b+124|0;pa=c[N>>2]|0;y=oa;a[pa]=y;y=y>>8;a[pa+1|0]=y;y=y>>8;a[pa+2|0]=y;y=y>>8;a[pa+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;sa=M+31|0;ta=qa;ua=c[ra>>2]|0}c[e>>2]=ta;c[g>>2]=sa;if((ua|0)==0){va=sa;wa=ta}else{ua=c[b+2316>>2]|0;if((sa|0)>3){xa=sa-3|0;ya=ta<<3|ua}else{ra=je(ta<<sa|ua>>>((3-sa|0)>>>0)|0)|0;ta=b+124|0;qa=c[ta>>2]|0;y=ra;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;c[ta>>2]=(c[ta>>2]|0)+4;xa=sa+29|0;ya=ua}c[e>>2]=ya;c[g>>2]=xa;ua=c[b+36>>2]|0;if((xa|0)>1){za=xa-1|0;Aa=ya<<1|ua}else{sa=je(ya<<xa|ua>>>((1-xa|0)>>>0)|0)|0;ya=b+124|0;ta=c[ya>>2]|0;y=sa;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;c[ya>>2]=(c[ya>>2]|0)+4;za=xa+31|0;Aa=ua}c[e>>2]=Aa;c[g>>2]=za;ua=c[b+40>>2]|0;if((za|0)>1){Ba=za-1|0;Ca=Aa<<1|ua}else{xa=je(Aa<<za|ua>>>((1-za|0)>>>0)|0)|0;Aa=b+124|0;ya=c[Aa>>2]|0;y=xa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;Ba=za+31|0;Ca=ua}c[e>>2]=Ca;c[g>>2]=Ba;ua=c[w>>2]|0;if((ua|0)==2){za=c[b+20>>2]|0;if((Ba|0)>2){Da=Ba-2|0;Ea=Ca<<2|za}else{Aa=je(Ca<<Ba|za>>>((2-Ba|0)>>>0)|0)|0;ya=b+124|0;xa=c[ya>>2]|0;y=Aa;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[ya>>2]=(c[ya>>2]|0)+4;Da=Ba+30|0;Ea=za}c[e>>2]=Ea;c[g>>2]=Da;za=c[b+76>>2]|0;if((Da|0)>2){Fa=Da-2|0;Ga=Ea<<2|za}else{ya=je(Ea<<Da|za>>>((2-Da|0)>>>0)|0)|0;Ea=b+124|0;xa=c[Ea>>2]|0;y=ya;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[Ea>>2]=(c[Ea>>2]|0)+4;Fa=Da+30|0;Ga=za}c[e>>2]=Ga;c[g>>2]=Fa;Ha=c[w>>2]|0;Ia=Ga;Ja=Fa}else{Ha=ua;Ia=Ca;Ja=Ba}if((Ha|0)>5){Ha=c[b+72>>2]|0;if((Ja|0)>2){Ka=Ja-2|0;La=Ia<<2|Ha}else{Ba=je(Ha>>>((2-Ja|0)>>>0)|Ia<<Ja|0)|0;Ca=b+124|0;ua=c[Ca>>2]|0;y=Ba;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y;c[Ca>>2]=(c[Ca>>2]|0)+4;Ka=Ja+30|0;La=Ha}c[e>>2]=La;c[g>>2]=Ka;Ma=Ka;Na=La}else{Ma=Ja;Na=Ia}Ia=b+24|0;Ja=c[Ia>>2]|0;if((Ma|0)>1){Oa=Ma-1|0;Pa=Na<<1|Ja;Qa=Ja}else{La=je(Na<<Ma|Ja>>>((1-Ma|0)>>>0)|0)|0;Na=b+124|0;Ka=c[Na>>2]|0;y=La;a[Ka]=y;y=y>>8;a[Ka+1|0]=y;y=y>>8;a[Ka+2|0]=y;y=y>>8;a[Ka+3|0]=y;c[Na>>2]=(c[Na>>2]|0)+4;Oa=Ma+31|0;Pa=Ja;Qa=c[Ia>>2]|0}c[e>>2]=Pa;c[g>>2]=Oa;if((Qa|0)==0){Ra=Oa;Sa=Pa}else{Qa=(c[b+28>>2]|0)-80|0;if((Oa|0)>5){Ta=Oa-5|0;Ua=Pa<<5|Qa}else{Ia=je(Qa>>>((5-Oa|0)>>>0)|Pa<<Oa|0)|0;Pa=b+124|0;Ja=c[Pa>>2]|0;y=Ia;a[Ja]=y;y=y>>8;a[Ja+1|0]=y;y=y>>8;a[Ja+2|0]=y;y=y>>8;a[Ja+3|0]=y;c[Pa>>2]=(c[Pa>>2]|0)+4;Ta=Oa+27|0;Ua=Qa}c[e>>2]=Ua;c[g>>2]=Ta;Qa=c[b+32>>2]|0;if((Ta|0)>2){Va=Ta-2|0;Wa=Ua<<2|Qa}else{Oa=je(Ua<<Ta|Qa>>>((2-Ta|0)>>>0)|0)|0;Ua=b+124|0;Pa=c[Ua>>2]|0;y=Oa;a[Pa]=y;y=y>>8;a[Pa+1|0]=y;y=y>>8;a[Pa+2|0]=y;y=y>>8;a[Pa+3|0]=y;c[Ua>>2]=(c[Ua>>2]|0)+4;Va=Ta+30|0;Wa=Qa}c[e>>2]=Wa;c[g>>2]=Va;Qa=c[b+80>>2]|0;if((Va|0)>1){Xa=Va-1|0;Ya=Wa<<1|Qa}else{Ta=je(Wa<<Va|Qa>>>((1-Va|0)>>>0)|0)|0;Wa=b+124|0;Ua=c[Wa>>2]|0;y=Ta;a[Ua]=y;y=y>>8;a[Ua+1|0]=y;y=y>>8;a[Ua+2|0]=y;y=y>>8;a[Ua+3|0]=y;c[Wa>>2]=(c[Wa>>2]|0)+4;Xa=Va+31|0;Ya=Qa}c[e>>2]=Ya;c[g>>2]=Xa;Ra=Xa;Sa=Ya}if((Ra|0)>1){Za=Ra-1|0;_a=Sa<<1}else{Ya=je(Sa<<Ra|0)|0;Sa=b+124|0;Xa=c[Sa>>2]|0;y=Ya;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;c[Sa>>2]=(c[Sa>>2]|0)+4;Za=Ra+31|0;_a=0}c[e>>2]=_a;c[g>>2]=Za;va=Za;wa=_a}_a=b+2332|0;if((c[_a>>2]|0)==6){$a=va;ab=wa}else{Za=((c[(c[b+108>>2]|0)+428>>2]|0)%6|0|0)==0|0;if((va|0)>1){bb=va-1|0;cb=wa<<1|Za}else{Ra=je(Za>>>((1-va|0)>>>0)|wa<<va|0)|0;wa=b+124|0;Sa=c[wa>>2]|0;y=Ra;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;c[wa>>2]=(c[wa>>2]|0)+4;bb=va+31|0;cb=Za}c[e>>2]=cb;c[g>>2]=bb;$a=bb;ab=cb}if(($a|0)>1){db=$a-1|0;eb=ab<<1}else{cb=je(ab<<$a|0)|0;ab=b+124|0;bb=c[ab>>2]|0;y=cb;a[bb]=y;y=y>>8;a[bb+1|0]=y;y=y>>8;a[bb+2|0]=y;y=y>>8;a[bb+3|0]=y;c[ab>>2]=(c[ab>>2]|0)+4;db=$a+31|0;eb=0}c[e>>2]=eb;c[g>>2]=db;if((c[_a>>2]|0)==6){$a=(c[b+2740>>2]|0)==0|0;if((db|0)>1){fb=db-1|0;gb=eb<<1|$a}else{ab=je($a>>>((1-db|0)>>>0)|eb<<db|0)|0;bb=b+124|0;cb=c[bb>>2]|0;y=ab;a[cb]=y;y=y>>8;a[cb+1|0]=y;y=y>>8;a[cb+2|0]=y;y=y>>8;a[cb+3|0]=y;c[bb>>2]=(c[bb>>2]|0)+4;fb=db+31|0;gb=$a}c[e>>2]=gb;c[g>>2]=fb;if((fb|0)>1){hb=fb-1|0;ib=gb<<1}else{$a=je(gb<<fb|0)|0;gb=b+124|0;bb=c[gb>>2]|0;y=$a;a[bb]=y;y=y>>8;a[bb+1|0]=y;y=y>>8;a[bb+2|0]=y;y=y>>8;a[bb+3|0]=y;c[gb>>2]=(c[gb>>2]|0)+4;hb=fb+31|0;ib=0}c[e>>2]=ib;c[g>>2]=hb;jb=hb;kb=ib}else{jb=db;kb=eb}if((jb|0)>2){lb=jb-2|0;mb=kb<<2}else{eb=je(kb<<jb|0)|0;kb=b+124|0;db=c[kb>>2]|0;y=eb;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;c[kb>>2]=(c[kb>>2]|0)+4;lb=jb+30|0;mb=0}c[e>>2]=mb;c[g>>2]=lb;if((lb|0)>1){nb=lb-1|0;ob=mb<<1}else{jb=je(mb<<lb|0)|0;mb=b+124|0;kb=c[mb>>2]|0;y=jb;a[kb]=y;y=y>>8;a[kb+1|0]=y;y=y>>8;a[kb+2|0]=y;y=y>>8;a[kb+3|0]=y;c[mb>>2]=(c[mb>>2]|0)+4;nb=lb+31|0;ob=0}c[e>>2]=ob;c[g>>2]=nb;if((nb|0)>1){pb=nb-1|0;qb=ob<<1}else{lb=je(ob<<nb|0)|0;ob=b+124|0;mb=c[ob>>2]|0;y=lb;a[mb]=y;y=y>>8;a[mb+1|0]=y;y=y>>8;a[mb+2|0]=y;y=y>>8;a[mb+3|0]=y;c[ob>>2]=(c[ob>>2]|0)+4;pb=nb+31|0;qb=0}c[e>>2]=qb;c[g>>2]=pb;if((pb|0)>1){rb=pb-1|0;sb=qb<<1}else{nb=je(qb<<pb|0)|0;qb=b+124|0;ob=c[qb>>2]|0;y=nb;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;c[qb>>2]=(c[qb>>2]|0)+4;rb=pb+31|0;sb=0}c[e>>2]=sb;c[g>>2]=rb;if((rb|0)>1){tb=rb-1|0;ub=sb<<1}else{pb=je(sb<<rb|0)|0;sb=b+124|0;qb=c[sb>>2]|0;y=pb;a[qb]=y;y=y>>8;a[qb+1|0]=y;y=y>>8;a[qb+2|0]=y;y=y>>8;a[qb+3|0]=y;c[sb>>2]=(c[sb>>2]|0)+4;tb=rb+31|0;ub=0}c[e>>2]=ub;c[g>>2]=tb;if((tb|0)>1){vb=tb-1|0;wb=ub<<1}else{rb=je(ub<<tb|0)|0;ub=b+124|0;sb=c[ub>>2]|0;y=rb;a[sb]=y;y=y>>8;a[sb+1|0]=y;y=y>>8;a[sb+2|0]=y;y=y>>8;a[sb+3|0]=y;c[ub>>2]=(c[ub>>2]|0)+4;vb=tb+31|0;wb=0}c[e>>2]=wb;c[g>>2]=vb;if((vb|0)>1){xb=vb-1|0;yb=wb<<1}else{tb=je(wb<<vb|0)|0;wb=b+124|0;ub=c[wb>>2]|0;y=tb;a[ub]=y;y=y>>8;a[ub+1|0]=y;y=y>>8;a[ub+2|0]=y;y=y>>8;a[ub+3|0]=y;c[wb>>2]=(c[wb>>2]|0)+4;xb=vb+31|0;yb=0}c[e>>2]=yb;c[g>>2]=xb;if((xb|0)>1){zb=xb-1|0;Ab=yb<<1}else{vb=je(yb<<xb|0)|0;yb=b+124|0;wb=c[yb>>2]|0;y=vb;a[wb]=y;y=y>>8;a[wb+1|0]=y;y=y>>8;a[wb+2|0]=y;y=y>>8;a[wb+3|0]=y;c[yb>>2]=(c[yb>>2]|0)+4;zb=xb+31|0;Ab=0}c[e>>2]=Ab;c[g>>2]=zb;if((zb|0)>1){Bb=zb-1|0;Cb=Ab<<1}else{xb=je(Ab<<zb|0)|0;Ab=b+124|0;yb=c[Ab>>2]|0;y=xb;a[yb]=y;y=y>>8;a[yb+1|0]=y;y=y>>8;a[yb+2|0]=y;y=y>>8;a[yb+3|0]=y;c[Ab>>2]=(c[Ab>>2]|0)+4;Bb=zb+31|0;Cb=0}c[e>>2]=Cb;c[g>>2]=Bb;do{if((c[w>>2]|0)>1){zb=c[b+1596>>2]|0;if((Bb|0)>1){Db=Bb-1|0;Eb=Cb<<1|zb}else{Ab=je(Cb<<Bb|zb>>>((1-Bb|0)>>>0)|0)|0;yb=b+124|0;xb=c[yb>>2]|0;y=Ab;a[xb]=y;y=y>>8;a[xb+1|0]=y;y=y>>8;a[xb+2|0]=y;y=y>>8;a[xb+3|0]=y;c[yb>>2]=(c[yb>>2]|0)+4;Db=Bb+31|0;Eb=zb}c[e>>2]=Eb;c[g>>2]=Db;if((c[_a>>2]|0)<=1){Fb=Eb;Gb=Db;break}zb=b+124|0;yb=1;xb=Eb;Ab=Db;while(1){wb=b+1536+(yb<<7)+56|0;vb=c[wb>>2]|0;if((Ab|0)>1){Hb=Ab-1|0;Ib=xb<<1|vb;Jb=vb}else{ub=je(vb>>>((1-Ab|0)>>>0)|xb<<Ab|0)|0;tb=c[zb>>2]|0;y=ub;a[tb]=y;y=y>>8;a[tb+1|0]=y;y=y>>8;a[tb+2|0]=y;y=y>>8;a[tb+3|0]=y;c[zb>>2]=(c[zb>>2]|0)+4;Hb=Ab+31|0;Ib=vb;Jb=c[wb>>2]|0}c[e>>2]=Ib;c[g>>2]=Hb;if((Jb|0)==0){Kb=Ib;Lb=Hb}else{wb=c[b+1536+(yb<<7)+60>>2]|0;if((Hb|0)>1){Mb=Hb-1|0;Nb=Ib<<1|wb}else{vb=je(Ib<<Hb|wb>>>((1-Hb|0)>>>0)|0)|0;tb=c[zb>>2]|0;y=vb;a[tb]=y;y=y>>8;a[tb+1|0]=y;y=y>>8;a[tb+2|0]=y;y=y>>8;a[tb+3|0]=y;c[zb>>2]=(c[zb>>2]|0)+4;Mb=Hb+31|0;Nb=wb}c[e>>2]=Nb;c[g>>2]=Mb;Kb=Nb;Lb=Mb}wb=yb+1|0;if((wb|0)<(c[_a>>2]|0)){yb=wb;xb=Kb;Ab=Lb}else{Fb=Kb;Gb=Lb;break}}}else{Fb=Cb;Gb=Bb}}while(0);Bb=b+2740|0;do{if((c[Bb>>2]|0)==0){Cb=c[_a>>2]|0;if((Cb|0)<=0){Ob=Fb;Pb=Gb;break}Lb=b+2368|0;Kb=b+124|0;Mb=0;Nb=Fb;Hb=Gb;Ib=c[Lb>>2]|0;Jb=Cb;while(1){Cb=(c[b+1536+(Mb<<7)+60>>2]|0)==0|0;if((Cb|0)>(Ib|0)){Qb=Nb;Rb=Hb;Sb=Ib;Tb=Jb}else{Db=Cb;Cb=Nb;Eb=Hb;w=Ib;while(1){Ab=d[b+2688+(Db*6|0)+Mb|0]|0;if((Eb|0)>2){Ub=Eb-2|0;Vb=Cb<<2|Ab;Wb=w}else{xb=je(Ab>>>((2-Eb|0)>>>0)|Cb<<Eb|0)|0;yb=c[Kb>>2]|0;y=xb;a[yb]=y;y=y>>8;a[yb+1|0]=y;y=y>>8;a[yb+2|0]=y;y=y>>8;a[yb+3|0]=y;c[Kb>>2]=(c[Kb>>2]|0)+4;Ub=Eb+30|0;Vb=Ab;Wb=c[Lb>>2]|0}c[e>>2]=Vb;c[g>>2]=Ub;Ab=Db+1|0;if((Ab|0)>(Wb|0)){break}else{Db=Ab;Cb=Vb;Eb=Ub;w=Wb}}Qb=Vb;Rb=Ub;Sb=Wb;Tb=c[_a>>2]|0}w=Mb+1|0;if((w|0)<(Tb|0)){Mb=w;Nb=Qb;Hb=Rb;Ib=Sb;Jb=Tb}else{Ob=Qb;Pb=Rb;break}}}else{Jb=(c[b+2464>>2]|0)==0|0;Ib=b+2368|0;Hb=c[Ib>>2]|0;if((Jb|0)>(Hb|0)){Ob=Fb;Pb=Gb;break}Nb=b+124|0;Mb=Jb;Jb=Fb;Lb=Gb;Kb=Hb;while(1){Hb=d[b+2730+Mb|0]|0;if((Lb|0)>5){Xb=Lb-5|0;Yb=Jb<<5|Hb;Zb=Kb}else{w=je(Hb>>>((5-Lb|0)>>>0)|Jb<<Lb|0)|0;Eb=c[Nb>>2]|0;y=w;a[Eb]=y;y=y>>8;a[Eb+1|0]=y;y=y>>8;a[Eb+2|0]=y;y=y>>8;a[Eb+3|0]=y;c[Nb>>2]=(c[Nb>>2]|0)+4;Xb=Lb+27|0;Yb=Hb;Zb=c[Ib>>2]|0}c[e>>2]=Yb;c[g>>2]=Xb;Hb=Mb+1|0;if((Hb|0)>(Zb|0)){Ob=Yb;Pb=Xb;break}else{Mb=Hb;Jb=Yb;Lb=Xb;Kb=Zb}}}}while(0);Zb=c[_a>>2]|0;do{if((c[x>>2]|0)==0){_b=Zb;$b=Ob;ac=Pb;bc=214}else{if((Zb|0)<=0){cc=Pb;dc=Ob;bc=217;break}Xb=b+2380|0;Yb=b+124|0;Gb=0;Fb=Ob;Rb=Pb;Qb=Zb;while(1){Tb=d[b+2688+((c[Xb>>2]|0)*6|0)+Gb|0]|0;if((Rb|0)>1){ec=Rb-1|0;fc=Fb<<1|Tb;gc=Qb}else{Sb=je(Tb>>>((1-Rb|0)>>>0)|Fb<<Rb|0)|0;Wb=c[Yb>>2]|0;y=Sb;a[Wb]=y;y=y>>8;a[Wb+1|0]=y;y=y>>8;a[Wb+2|0]=y;y=y>>8;a[Wb+3|0]=y;c[Yb>>2]=(c[Yb>>2]|0)+4;ec=Rb+31|0;fc=Tb;gc=c[_a>>2]|0}c[e>>2]=fc;c[g>>2]=ec;Tb=Gb+1|0;if((Tb|0)<(gc|0)){Gb=Tb;Fb=fc;Rb=ec;Qb=gc}else{_b=gc;$b=fc;ac=ec;bc=214;break}}}}while(0);do{if((bc|0)==214){if((_b|0)!=6){cc=ac;dc=$b;bc=217;break}ec=b+2368|0;if((c[ec>>2]|0)<1){hc=ac;ic=$b;break}fc=b+124|0;gc=1;Zb=$b;Pb=ac;while(1){do{if((c[Bb>>2]|0)==0){if((Pb|0)>5){jc=Pb-5|0;kc=Zb<<5;break}else{Ob=je(Zb<<Pb|0)|0;x=c[fc>>2]|0;y=Ob;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[fc>>2]=(c[fc>>2]|0)+4;jc=Pb+27|0;kc=0;break}}else{x=d[b+2730+gc|0]|0;if((Pb|0)>5){jc=Pb-5|0;kc=Zb<<5|x;break}else{Ob=je(x>>>((5-Pb|0)>>>0)|Zb<<Pb|0)|0;Qb=c[fc>>2]|0;y=Ob;a[Qb]=y;y=y>>8;a[Qb+1|0]=y;y=y>>8;a[Qb+2|0]=y;y=y>>8;a[Qb+3|0]=y;c[fc>>2]=(c[fc>>2]|0)+4;jc=Pb+27|0;kc=x;break}}}while(0);c[e>>2]=kc;c[g>>2]=jc;x=gc+1|0;if((x|0)>(c[ec>>2]|0)){hc=jc;ic=kc;break}else{gc=x;Zb=kc;Pb=jc}}}}while(0);if((bc|0)==217){if((cc|0)>1){lc=cc-1|0;mc=dc<<1}else{bc=je(dc<<cc|0)|0;dc=b+124|0;jc=c[dc>>2]|0;y=bc;a[jc]=y;y=y>>8;a[jc+1|0]=y;y=y>>8;a[jc+2|0]=y;y=y>>8;a[jc+3|0]=y;c[dc>>2]=(c[dc>>2]|0)+4;lc=cc+31|0;mc=0}c[e>>2]=mc;c[g>>2]=lc;hc=lc;ic=mc}mc=c[b+2560>>2]|0;if((hc|0)>6){nc=hc-6|0;oc=ic<<6|mc}else{lc=je(ic<<hc|mc>>>((6-hc|0)>>>0)|0)|0;ic=b+124|0;cc=c[ic>>2]|0;y=lc;a[cc]=y;y=y>>8;a[cc+1|0]=y;y=y>>8;a[cc+2|0]=y;y=y>>8;a[cc+3|0]=y;c[ic>>2]=(c[ic>>2]|0)+4;nc=hc+26|0;oc=mc}c[e>>2]=oc;c[g>>2]=nc;mc=c[b+2596>>2]|0;if((nc|0)>4){pc=nc-4|0;qc=oc<<4|mc}else{hc=je(oc<<nc|mc>>>((4-nc|0)>>>0)|0)|0;oc=b+124|0;ic=c[oc>>2]|0;y=hc;a[ic]=y;y=y>>8;a[ic+1|0]=y;y=y>>8;a[ic+2|0]=y;y=y>>8;a[ic+3|0]=y;c[oc>>2]=(c[oc>>2]|0)+4;pc=nc+28|0;qc=mc}c[e>>2]=qc;c[g>>2]=pc;if((c[_a>>2]|0)<=1){return}if((pc|0)>1){rc=pc-1|0;sc=qc<<1}else{_a=je(qc<<pc|0)|0;qc=b+124|0;b=c[qc>>2]|0;y=_a;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[qc>>2]=(c[qc>>2]|0)+4;rc=pc+31|0;sc=0}c[e>>2]=sc;c[g>>2]=rc;return}function Eca(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;a=b+4|0;c[a>>2]=UHb()|0;d=UHb()|0;e=b+8|0;c[e>>2]=d;if(!((c[a>>2]|0)==0|(d|0)==0)){f=0;return f|0}VHb(a);VHb(e);f=-12;return f|0}function Fca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=g;m=j+k|0;n=e;if((k|0)<8){o=-1094995529;i=h;return o|0}p=j;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;do{if((q|0)==1749636685|(q|0)==1297500520){p=j+4|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m;if((p-(j+8)|0)<16){KIb(c[g>>2]|0,24,2454512,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;o=-1094995529;i=h;return o|0}s=j+12|0;t=(d[s]|d[s+1|0]<<8)<<16>>16&65535;s=g+12|0;c[s>>2]=t;u=j+14|0;v=(d[u]|d[u+1|0]<<8)<<16>>16&65535;u=g+16|0;c[u>>2]=v;w=g;x=c[w>>2]|0;if((t|0)==(c[x+120>>2]|0)){if((v|0)==(c[x+124>>2]|0)){z=x;A=t;B=v}else{C=8}}else{C=8}if((C|0)==8){WHb(c[g+4>>2]|0);WHb(c[g+8>>2]|0);z=c[w>>2]|0;A=c[s>>2]|0;B=c[u>>2]|0}v=H4a(z,A,B)|0;if((v|0)<0){o=v;i=h;return o|0}v=j+18|0;t=(d[v]|d[v+1|0]<<8)<<16>>16;if(!(t<<16>>16==0)){v=c[w>>2]|0;c[v+104>>2]=1;c[v+108>>2]=t&65535}t=j+20|0;v=(d[t]|d[t+1|0]<<8)<<16>>16;t=v&65535;x=j+22|0;D=(d[x]|d[x+1|0]<<8)<<16>>16;x=(D&65535)+t|0;a:do{if(D<<16>>16!=0&(v&65535)>>>0<256>>>0){E=t;F=j+24|0;while(1){if((p-F|0)<=2){break a}c[l+20+(E<<2)>>2]=d[F]<<16|d[F+1|0]<<8|d[F+2|0]|-16777216;G=E+1|0;if((G|0)<(x|0)&(G|0)<256){E=G;F=F+3|0}else{break}}}}while(0);if(r>>>0>(k-8|0)>>>0){o=-1;i=h;return o|0}else{H=j+r|0;I=s;J=u;K=w;break}}else{H=j;I=g+12|0;J=g+16|0;K=g}}while(0);if((tIb(c[I>>2]|0,c[J>>2]|0,0,c[K>>2]|0)|0)!=0){o=-1;i=h;return o|0}J=M4a(b,n,1)|0;if((J|0)<0){o=J;i=h;return o|0}nrc(c[e+4>>2]|0,g+20|0,1024)|0;b:do{if((a[H+8|0]&1)==0){c[e+84>>2]=1;c[e+88>>2]=1;J=m;b=c[K>>2]|0;if((c[b+124>>2]|0)<=0){break}I=e+32|0;j=H+10|0;l=c[e>>2]|0;B=0;A=c[b+120>>2]|0;while(1){if((J-j|0)<(A|0)){break b}nrc(l|0,j|0,A)|0;b=c[K>>2]|0;z=c[b+120>>2]|0;C=B+1|0;if((C|0)<(c[b+124>>2]|0)){j=j+z|0;l=l+(c[I>>2]|0)|0;B=C;A=z}else{break}}}else{A=c[K>>2]|0;B=c[A+124>>2]|0;if((B|0)>3){I=c[A+120>>2]|0;l=m-(H+10)|0;j=e;J=e+32|0;w=g+8|0;u=g+4|0;s=0;r=0;z=H+(((ca(I,B)|0)/16|0)+10)|0;B=A;A=I;while(1){I=r<<2;if((A|0)>3&(l|0)>(s|0)){C=I+4|0;b=s;q=0;x=z;p=B;t=A;while(1){v=q<<2;D=v+4|0;F=v|1;E=((D|0)>(F|0)?D:F)+(q*-4|0)|0;F=a[H+(b+10)|0]|0;G=F&255;c:do{if(F<<24>>24==-1){L=c[j>>2]|0;M=c[J>>2]|0;N=(ca(M,I)|0)+v|0;O=L+N|0;do{if((x+16|0)>>>0<m>>>0){if(!((a[x]|0)==-1)){break}P=x+1|0;Q=O;y=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=x+5|0;P=L+((c[J>>2]|0)+N)|0;y=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;P=x+9|0;Q=L+((c[J>>2]<<1)+N)|0;y=d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=x+13|0;P=L+(((c[J>>2]|0)*3|0)+N)|0;y=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;R=x+17|0;break c}}while(0);if(!(x>>>0<m>>>0)){R=x;break}N=d[x]|0;O=c[w>>2]|0;P=c[O>>2]|0;if((P|0)!=0){Q=(N>>>4)-7|0;S=(N&15)-7|0;N=c[O+32>>2]|0;O=c[p+124>>2]|0;T=I;U=0;while(1){V=Q+T|0;W=(ca(V,N)|0)+S|0;X=ca(T,M)|0;if((V|0)>-1&(V|0)<(O|0)){V=v;do{Y=V+S|0;if((Y|0)>-1&(Y|0)<(t|0)){a[L+(V+X)|0]=a[P+(W+V)|0]|0}else{a[L+(V+X)|0]=0}V=V+1|0;}while((V|0)<(D|0))}else{mrc(L+((ca(U+I|0,M)|0)+v)|0,0,E|0)|0}V=T+1|0;if((V|0)<(C|0)){T=V;U=U+1|0}else{break}}}R=x+1|0}else{U=c[u>>2]|0;T=c[U>>2]|0;if((T|0)==0){R=x;break}M=(G>>>4)-7|0;L=(G&15)-7|0;P=c[j>>2]|0;S=c[J>>2]|0;O=c[U+32>>2]|0;U=c[p+124>>2]|0;N=I;Q=0;while(1){V=M+N|0;X=(ca(V,O)|0)+L|0;W=ca(N,S)|0;if((V|0)>-1&(V|0)<(U|0)){V=v;do{Y=V+L|0;if((Y|0)>-1&(Y|0)<(t|0)){a[P+(V+W)|0]=a[T+(X+V)|0]|0}else{a[P+(V+W)|0]=0}V=V+1|0;}while((V|0)<(D|0))}else{mrc(P+((ca(Q+I|0,S)|0)+v)|0,0,E|0)|0}V=N+1|0;if((V|0)<(C|0)){N=V;Q=Q+1|0}else{R=x;break}}}}while(0);E=b+1|0;v=q+1|0;D=c[K>>2]|0;G=c[D+120>>2]|0;if((v|0)<((G|0)/4|0|0)&(l|0)>(E|0)){b=E;q=v;x=R;p=D;t=G}else{Z=E;_=R;$=D;aa=G;break}}}else{Z=s;_=z;$=B;aa=A}t=r+1|0;if((t|0)<((c[$+124>>2]|0)/4|0|0)){s=Z;r=t;z=_;B=$;A=aa}else{break}}}c[e+84>>2]=0;c[e+88>>2]=2}}while(0);e=g+8|0;WHb(c[e>>2]|0);aa=g+4|0;aIb(c[e>>2]|0,c[aa>>2]|0);e=YHb(c[aa>>2]|0,n)|0;if((e|0)<0){o=e;i=h;return o|0}c[f>>2]=1;o=k;i=h;return o|0}function Gca(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);VHb(b+8|0);return 0}function Hca(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=0;l8(b+4|0,a);a=b+1132|0;M6(a,1);L6(a,b+1408|0,1242080);jRa();a=UHb()|0;c[b+1248>>2]=a;return((a|0)==0?-12:0)|0}function Ica(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;k=i;l=c[j+24>>2]|0;m=c[j+28>>2]|0;j=l+m|0;n=c[f+60>>2]|0;o=n;p=g;if((m|0)<26){KIb(f,16,2454472,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[h>>2]=0;r=-1094995529;i=k;return r|0}s=l;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+14|0;xKb(f+104|0,f+108|0,(d[s]|d[s+1|0]<<8)<<16>>16&65535,0,1e3,0,1073741824,0)|0;s=l+16|0;u=(d[s]|d[s+1|0]<<8)<<16>>16;s=l+18|0;v=(d[s]|d[s+1|0]<<8)<<16>>16;s=d[l+21|0]|0;w=n+1540|0;b[w>>1]=(ca(e[673424]|0,e[684440]|0)|0)>>>11;x=1;do{b[o+1540+(x<<1)>>1]=((ca(ca(e[1368880+(x<<1)>>1]|0,s)|0,e[1346848+(x<<1)>>1]|0)|0)+32|0)>>>10;x=x+1|0;}while((x|0)<64);x=(t|0)==1698971981;s=u&65535;y=v&65535;z=l+24|0;if((u&65535)>>>0<16>>>0|(v&65535)>>>0<16>>>0){KIb(f,16,2365040,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=k;return r|0}v=f+120|0;if((c[v>>2]|0)==(s|0)){if((c[f+124>>2]|0)!=(y|0)){A=9}}else{A=9}do{if((A|0)==9){WHb(c[n+1248>>2]|0);if((((ca(y,s)|0)>>>11)*7|0|0)>(j-z|0)){r=-1094995529;i=k;return r|0}u=H4a(f,s,y)|0;if((u|0)<0){r=u}else{break}i=k;return r|0}}while(0);y=M4a(f,p,1)|0;if((y|0)<0){r=y;i=k;return r|0}do{if((t|0)==1833189709|(t|0)==1698971981){y=n+1248|0;if((c[c[y>>2]>>2]|0)!=0){break}KIb(f,24,2299784,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;s=M4a(f,c[y>>2]|0,1)|0;if((s|0)<0){r=s;i=k;return r|0}else{s=c[y>>2]|0;mrc(c[s>>2]|0,0,ca(c[s+32>>2]|0,c[s+72>>2]|0)|0)|0;s=c[y>>2]|0;mrc(c[s+4>>2]|0,-128|0,ca(c[s+36>>2]|0,(c[s+72>>2]|0)/2|0)|0)|0;s=c[y>>2]|0;mrc(c[s+8>>2]|0,-128|0,ca(c[s+40>>2]|0,(c[s+72>>2]|0)/2|0)|0)|0;break}}}while(0);s=n+1272|0;y=s;A=j-z|0;A4a(s,n+1276|0,A);s=c[y>>2]|0;if((s|0)==0){r=-12;i=k;return r|0}ef[c[n+1104>>2]&4095](s,z,(A|0)/2|0);mrc((c[y>>2]|0)+A|0,0,16)|0;z=c[y>>2]|0;y=A<<3;A=y>>>0>2147483639>>>0|(z|0)==0;s=A?0:z;z=A?0:y;y=n+1252|0;c[y>>2]=s;c[n+1264>>2]=z;A=n+1268|0;c[A>>2]=z+8;c[n+1256>>2]=s+(z>>3);z=n+1260|0;c[z>>2]=0;s=n+1672|0;c[s>>2]=0;j=f+124|0;a:do{if((c[j>>2]|0)>0){f=n+1668|0;u=n+40|0;l=n+1280|0;B=g;C=g+32|0;D=n;E=n+1248|0;F=0;b:while(1){c[f>>2]=0;if((c[v>>2]|0)>0){do{do{if((t|0)==1833189709|(t|0)==1698971981){G=c[z>>2]|0;H=c[y>>2]|0;I=d[H+(G>>>3)|0]|0;J=c[A>>2]|0;K=((G|0)<(J|0))+G|0;c[z>>2]=K;if((I&128>>>((G&7)>>>0)|0)==0){G=d[H+(K>>>3)|0]<<(K&7)>>>7;I=((K|0)<(J|0))+K|0;c[z>>2]=I;if(!((2-(G&1)|0)>>>0<2>>>0)){L=0;M=0;N=0;break}G=H+(I>>>3)|0;O=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(I&7)>>>26;G=I+6|0;I=J>>>0>G>>>0?G:J;c[z>>2]=I;P=O;Q=I}else{P=63;Q=K}K=d[H+(Q>>>3)|0]|0;I=((Q|0)<(J|0))+Q|0;c[z>>2]=I;if((K&128>>>((Q&7)>>>0)|0)==0){R=0;S=I}else{K=d[H+(I>>>3)|0]|0;O=((I|0)<(J|0))+I|0;c[z>>2]=O;G=H+(O>>>3)|0;T=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(O&7)>>>28;G=O+4|0;O=J>>>0>G>>>0?G:J;c[z>>2]=O;R=((K&128>>>((I&7)>>>0)|0)==0?1:-16)+T|0;S=O}O=d[H+(S>>>3)|0]|0;T=((S|0)<(J|0))+S|0;c[z>>2]=T;if((O&128>>>((S&7)>>>0)|0)==0){L=P;M=0;N=R;break}O=d[H+(T>>>3)|0]|0;I=((T|0)<(J|0))+T|0;c[z>>2]=I;K=H+(I>>>3)|0;H=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(I&7)>>>28;K=I+4|0;c[z>>2]=J>>>0>K>>>0?K:J;L=P;M=((O&128>>>((T&7)>>>0)|0)==0?1:-16)+H|0;N=R}else{L=0;M=0;N=0}}while(0);H=(M|0)/2|0;T=(N|0)/2|0;O=0;do{do{if((1<<O&L|0)==0){qe[c[u>>2]&1023](l);J=c[z>>2]|0;K=c[A>>2]|0;I=c[y>>2]|0;G=I+(J>>>3)|0;U=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>24;G=J+8|0;J=K>>>0>G>>>0?G:K;c[z>>2]=J;b[l>>1]=ca(U+128|0,b[w>>1]|0)|0;U=c[328980]|0;G=J;J=0;c:while(1){V=I+(G>>>3)|0;W=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(G&7);V=W>>>23;X=b[U+(V<<2)>>1]|0;Y=a[U+(V<<2)+2|0]|0;Z=Y<<24>>24;if(Y<<24>>24<0){Y=W<<9;_=G+9|0;$=(Y>>>((Z+32|0)>>>0))+X|0;aa=$;ba=a[U+($<<2)+2|0]|0;da=b[U+($<<2)>>1]|0;ea=Y;fa=K>>>0>_>>>0?_:K}else{aa=V;ba=Z;da=X;ea=W;fa=G}W=ba+fa|0;ga=K>>>0>W>>>0?W:K;do{if((da|0)==0){W=I+(ga>>>3)|0;X=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ga&7)>>22;W=ga+10|0;Z=K>>>0>W>>>0?W:K;W=I+(Z>>>3)|0;V=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Z&7)>>>26;W=Z+6|0;Z=K>>>0>W>>>0?W:K;W=J+1+V|0;V=d[o+1412+W|0]|0;if((X|0)<0){ha=-(((ca(b[o+1540+(V<<1)>>1]|0,-X|0)|0)>>>4)+65535|1)&65535;ia=Z;ja=W;ka=V;break}else{ha=(((ca(b[o+1540+(V<<1)>>1]|0,X)|0)>>>4)+65535|1)&65535;ia=Z;ja=W;ka=V;break}}else if((da|0)==127){break c}else{V=(d[U+(aa<<2)+3|0]|0)+J|0;W=d[o+1412+V|0]|0;Z=ea<<ba>>31;X=((((ca(b[o+1540+(W<<1)>>1]|0,da)|0)>>>4)+65535|1)^Z)-Z|0;Z=ga+1|0;ha=X&65535;ia=K>>>0>Z>>>0?Z:K;ja=V;ka=W}}while(0);if((ja|0)>63){break b}b[o+1280+(ka<<1)>>1]=ha;G=ia;J=ja}c[z>>2]=ga;J=c[f>>2]|0;G=c[s>>2]|0;if((O|0)<4){K=c[C>>2]|0;wpb((c[B>>2]|0)+((ca(K,G<<4|O<<2&8)|0)+(J<<4|O<<3&8))|0,K,l);break}if((c[(c[D>>2]|0)+88>>2]&8192|0)!=0){break}K=O-3|0;U=c[p+32+(K<<2)>>2]|0;wpb((c[p+(K<<2)>>2]|0)+((ca(U,G)|0)+J<<3)|0,U,l)}else{U=c[z>>2]|0;J=c[y>>2]|0;G=d[J+(U>>>3)|0]|0;K=c[A>>2]|0;I=((U|0)<(K|0))+U|0;c[z>>2]=I;if((G&128>>>((U&7)>>>0)|0)==0){la=0}else{U=d[J+(I>>>3)|0]|0;G=((I|0)<(K|0))+I|0;c[z>>2]=G;W=J+(G>>>3)|0;J=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(G&7)>>>28;W=G+4|0;c[z>>2]=K>>>0>W>>>0?W:K;la=((U&128>>>((I&7)>>>0)|0)==0?1:2147483632)+J<<1}J=c[E>>2]|0;I=c[J>>2]|0;if((I|0)==0){break}U=c[f>>2]|0;K=c[s>>2]|0;if((O|0)<4){W=K<<4|O<<2&8;G=c[J+32>>2]|0;V=U<<4;Z=O<<3&8;X=Z+N+V+(ca(G,W+M|0)|0)|0;if(!(X>>>0<((ca((c[(c[D>>2]|0)+124>>2]|0)-7|0,G)|0)-7|0)>>>0)){break}_=c[C>>2]|0;Kca((c[B>>2]|0)+((ca(_,W)|0)+(V|Z))|0,_,I+X|0,G,la);break}G=c[D>>2]|0;if((c[G+88>>2]&8192|0)!=0){break}X=O-3|0;I=K<<3;K=c[J+32+(X<<2)>>2]|0;_=U<<3;U=_+T+(ca(K,I+H|0)|0)|0;if(!(U>>>0<((ca(((c[G+124>>2]|0)/2|0)-7|0,K)|0)-7|0)>>>0)){break}G=c[p+32+(X<<2)>>2]|0;Z=(c[p+(X<<2)>>2]|0)+((ca(G,I)|0)+_)|0;Kca(Z,G,(c[J+(X<<2)>>2]|0)+U|0,K,la)}}while(0);O=O+1|0;}while((O|0)<6);O=(c[f>>2]|0)+1|0;c[f>>2]=O;}while((O|0)<(((c[v>>2]|0)+15|0)/16|0|0));ma=c[s>>2]|0}else{ma=F}F=ma+1|0;c[s>>2]=F;if((F|0)>=(((c[j>>2]|0)+15|0)/16|0|0)){break a}}F=c[s>>2]|0;KIb(c[D>>2]|0,16,2248760,(q=i,i=i+16|0,c[q>>2]=c[f>>2],c[q+8>>2]=F,q)|0);i=q;r=-1094995529;i=k;return r|0}}while(0);c[h>>2]=1;do{if(!x){h=n+1248|0;WHb(c[h>>2]|0);q=YHb(c[h>>2]|0,p)|0;if((q|0)<0){r=q}else{break}i=k;return r|0}}while(0);r=m;i=k;return r|0}function Jca(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+1248|0);kJb(c[b+1272>>2]|0);return 0}function Kca(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=0;do{i=ca(h,f)|0;j=ca(h,c)|0;k=(d[e+i|0]|0)+g|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[b+j|0]=l;k=(d[e+(i+1)|0]|0)+g|0;if(k>>>0>255>>>0){m=-k>>31&255}else{m=k&255}a[b+(j+1)|0]=m;k=(d[e+(i+2)|0]|0)+g|0;if(k>>>0>255>>>0){n=-k>>31&255}else{n=k&255}a[b+(j+2)|0]=n;k=(d[e+(i+3)|0]|0)+g|0;if(k>>>0>255>>>0){o=-k>>31&255}else{o=k&255}a[b+(j+3)|0]=o;k=(d[e+(i+4)|0]|0)+g|0;if(k>>>0>255>>>0){p=-k>>31&255}else{p=k&255}a[b+(j+4)|0]=p;k=(d[e+(i+5)|0]|0)+g|0;if(k>>>0>255>>>0){q=-k>>31&255}else{q=k&255}a[b+(j+5)|0]=q;k=(d[e+(i+6)|0]|0)+g|0;if(k>>>0>255>>>0){r=-k>>31&255}else{r=k&255}a[b+(j+6)|0]=r;k=(d[e+(i+7)|0]|0)+g|0;if(k>>>0>255>>>0){s=-k>>31&255}else{s=k&255}a[b+(j+7)|0]=s;h=h+1|0;}while((h|0)<8);return}function Lca(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+64|0;d=c[a+60>>2]|0;c[d>>2]=a;e=b|0;M6(e,1);L6(e,d+12|0,1242080);c[a+104>>2]=1;c[a+108>>2]=15;c[a+140>>2]=0;i=b;return 0}function Mca(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0;k=i;i=i+8|0;l=k|0;m=c[j+24>>2]|0;n=j+28|0;j=c[n>>2]|0;o=c[f+60>>2]|0;p=o;q=g;if((j|0)<16){KIb(f,24,2454440,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=k;return s|0}t=m+8|0;if(!((j-8|0)>-1)){KIb(0,0,2299752,(r=i,i=i+24|0,c[r>>2]=2248744,c[r+8>>2]=2206664,c[r+16>>2]=135,r)|0);i=r;Hd();return 0}u=m+4|0;v=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>0>1048575>>>0;u=o+1168|0;c[o+1176>>2]=t;w=o+1172|0;c[w>>2]=m+j;j=m+10|0;c[u>>2]=j;x=t;t=(d[x]|d[x+1|0]<<8)<<16>>16;if(v){v=(he(t|0)|0)&65535;c[o+4>>2]=v;c[u>>2]=m+12;x=j;y=(he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535;c[o+8>>2]=y;z=v;A=y}else{y=t&65535;c[o+4>>2]=y;c[u>>2]=m+12;m=j;j=(d[m]|d[m+1|0]<<8)<<16>>16&65535;c[o+8>>2]=j;z=y;A=j}j=o;y=H4a(c[j>>2]|0,z,A)|0;if((y|0)<0){s=y;i=k;return s|0}y=c[u>>2]|0;c[u>>2]=y+1;A=100-(d[y]|0)|0;y=((A*14|0|0)/100|0)+1|0;z=((A*11|0|0)/100|0)+4|0;A=0;while(1){m=A<<3;t=((ca(A,y)|0)/14|0)+z|0;c[p+144+(m<<2)>>2]=(ca(e[1368880+(m<<1)>>1]|0,t)|0)>>10;t=A+1|0;v=((ca(t,y)|0)/14|0)+z|0;x=m|1;c[p+144+(x<<2)>>2]=(ca(e[1368880+(x<<1)>>1]|0,v)|0)>>10;v=((ca(A+2|0,y)|0)/14|0)+z|0;x=m|2;c[p+144+(x<<2)>>2]=(ca(e[1368880+(x<<1)>>1]|0,v)|0)>>10;v=((ca(A+3|0,y)|0)/14|0)+z|0;x=m|3;c[p+144+(x<<2)>>2]=(ca(e[1368880+(x<<1)>>1]|0,v)|0)>>10;v=((ca(A+4|0,y)|0)/14|0)+z|0;x=m|4;c[p+144+(x<<2)>>2]=(ca(e[1368880+(x<<1)>>1]|0,v)|0)>>10;v=((ca(A+5|0,y)|0)/14|0)+z|0;x=m|5;c[p+144+(x<<2)>>2]=(ca(e[1368880+(x<<1)>>1]|0,v)|0)>>10;v=((ca(A+6|0,y)|0)/14|0)+z|0;x=m|6;c[p+144+(x<<2)>>2]=(ca(e[1368880+(x<<1)>>1]|0,v)|0)>>10;v=((ca(A+7|0,y)|0)/14|0)+z|0;x=m|7;c[p+144+(x<<2)>>2]=(ca(e[1368880+(x<<1)>>1]|0,v)|0)>>10;if((t|0)<8){A=t}else{break}}A=c[u>>2]|0;z=(c[w>>2]|0)-A|0;c[u>>2]=A+(z>>>0>3>>>0?3:z);z=M4a(f,q,0)|0;if((z|0)<0){s=z;i=k;return s|0}c[g+84>>2]=1;c[g+88>>2]=1;z=f+124|0;q=c[z>>2]|0;a:do{if((q+15>>4|0)>0){A=f+120|0;y=l|0;t=o+144|0;v=g+32|0;x=g;m=g+4|0;B=g+36|0;C=g+8|0;D=g+40|0;E=o+400|0;F=o+528|0;G=o+656|0;H=o+784|0;I=o+912|0;J=o+1040|0;K=l+4|0;L=l+5|0;M=l+1|0;N=l+2|0;O=l+3|0;P=0;Q=c[A>>2]|0;R=q;b:while(1){if((Q+15>>4|0)>0){S=P<<4;T=P<<3;U=0;do{V=c[u>>2]|0;W=c[w>>2]|0;if((W-V|0)<1){X=0;break b}Y=V+1|0;c[u>>2]=Y;Z=a[V]|0;_=Z&255;do{if((Z&255)>>>0>12>>>0){$=W-Y|0;aa=$>>>0>_>>>0?_:$;$=aa>>>0>268435455>>>0?-8:aa<<3;aa=$>>>0>2147483639>>>0|(Y|0)==0;ba=aa?0:Y;da=aa?8:$+8|0;$=0;aa=0;while(1){ea=p+400+(aa<<7)|0;fa=ba+($>>>3)|0;ga=$+8|0;b[ea>>1]=ca((d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)>>>(($&7)>>>0)<<24>>24,c[t>>2]|0)|0;fa=1;ha=da>>>0>ga>>>0?ga:da;while(1){ga=ba+(ha>>>3)|0;c:do{switch((d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((ha&7)>>>0)&7|0){case 0:{ia=fa;ja=23;break};case 2:{ka=ha+3|0;la=d[p+16+fa|0]|0;b[p+400+(aa<<7)+(la<<1)>>1]=c[p+144+(la<<2)>>2];ma=fa+1|0;na=da>>>0>ka>>>0?ka:da;break};case 5:case 1:{ka=ha+2|0;la=da>>>0>ka>>>0?ka:da;ka=ba+(la>>>3)|0;oa=(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)>>>((la&7)>>>0)&63;ka=la+6|0;la=da>>>0>ka>>>0?ka:da;if((oa|0)==0){ma=fa;na=la;break c}else{pa=0;qa=fa}while(1){b[p+400+(aa<<7)+(d[p+16+qa|0]<<1)>>1]=0;ka=pa+1|0;if((ka|0)<(oa|0)){pa=ka;qa=qa+1|0}else{break}}ma=(oa>>>0>1>>>0?oa:1)+fa|0;na=la;break};case 4:{b[p+400+(aa<<7)+(d[p+16+fa|0]<<1)>>1]=0;ia=fa+1|0;ja=23;break};case 7:case 3:{ka=ha+2|0;ra=da>>>0>ka>>>0?ka:da;ka=ba+(ra>>>3)|0;sa=(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)>>>((ra&7)>>>0);if((sa&63|0)==63){ka=ra+6|0;ta=da>>>0>ka>>>0?ka:da;ka=ba+(ta>>>3)|0;ua=ta+8|0;va=d[p+16+fa|0]|0;b[p+400+(aa<<7)+(va<<1)>>1]=ca((d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)>>>((ta&7)>>>0)<<24>>24,c[p+144+(va<<2)>>2]|0)|0;wa=da>>>0>ua>>>0?ua:da}else{ua=ra+6|0;ra=d[p+16+fa|0]|0;b[p+400+(aa<<7)+(ra<<1)>>1]=ca(c[p+144+(ra<<2)>>2]|0,sa<<26>>26)|0;wa=da>>>0>ua>>>0?ua:da}ma=fa+1|0;na=wa;break};case 6:{ua=ha+3|0;sa=d[p+16+fa|0]|0;b[p+400+(aa<<7)+(sa<<1)>>1]=-(c[p+144+(sa<<2)>>2]|0);ma=fa+1|0;na=da>>>0>ua>>>0?ua:da;break};default:{ja=73;break b}}}while(0);if((ja|0)==23){ja=0;b[p+400+(aa<<7)+(d[p+16+ia|0]<<1)>>1]=0;ga=ha+3|0;ma=ia+1|0;na=da>>>0>ga>>>0?ga:da}if((ma|0)<64){fa=ma;ha=na}else{break}}b[ea>>1]=(b[ea>>1]|0)+2048;ha=aa+1|0;if((ha|0)<6){$=na;aa=ha}else{break}}aa=c[v>>2]|0;$=c[x>>2]|0;da=(ca(S,aa)|0)+(U<<4)|0;ba=c[m>>2]|0;ha=c[B>>2]|0;fa=U<<3;ga=c[C>>2]|0;ua=c[D>>2]|0;wpb($+da|0,aa,E);wpb($+(da|8)|0,aa,F);sa=da+(aa<<3)|0;wpb($+sa|0,aa,G);wpb($+(sa+8)|0,aa,H);if((c[(c[j>>2]|0)+88>>2]&8192|0)==0){aa=ga+((ca(ua,T)|0)+fa)|0;ua=ba+((ca(ha,T)|0)+fa)|0;wpb(ua,c[B>>2]|0,I);wpb(aa,c[D>>2]|0,J)}aa=c[u>>2]|0;ua=(c[w>>2]|0)-aa|0;c[u>>2]=aa+(ua>>>0>_>>>0?_:ua)}else{if((_|0)==6){ua=W-Y|0;aa=ua>>>0>6>>>0?6:ua;nrc(y|0,Y|0,aa)|0;c[u>>2]=V+(aa+1);xa=a[y]|0}else if((_|0)==12){if((W-Y|0)<1){ya=0;za=Y}else{aa=V+2|0;c[u>>2]=aa;ya=a[Y]|0;za=aa}a[y]=ya;aa=W-za|0;ua=aa>>>0>1>>>0?1:aa;aa=za+ua|0;c[u>>2]=aa;if((W-aa|0)<1){Aa=0;Ba=aa}else{fa=za+(ua+1)|0;c[u>>2]=fa;Aa=a[aa]|0;Ba=fa}a[M]=Aa;fa=W-Ba|0;aa=fa>>>0>1>>>0?1:fa;fa=Ba+aa|0;c[u>>2]=fa;if((W-fa|0)<1){Ca=0;Da=fa}else{ua=Ba+(aa+1)|0;c[u>>2]=ua;Ca=a[fa]|0;Da=ua}a[N]=Ca;ua=W-Da|0;fa=ua>>>0>1>>>0?1:ua;ua=Da+fa|0;c[u>>2]=ua;if((W-ua|0)<1){Ea=0;Fa=ua}else{aa=Da+(fa+1)|0;c[u>>2]=aa;Ea=a[ua]|0;Fa=aa}a[O]=Ea;aa=W-Fa|0;ua=aa>>>0>1>>>0?1:aa;aa=Fa+ua|0;c[u>>2]=aa;if((W-aa|0)<1){Ga=0;Ha=aa}else{fa=Fa+(ua+1)|0;c[u>>2]=fa;Ga=a[aa]|0;Ha=fa}a[K]=Ga;fa=W-Ha|0;aa=fa>>>0>1>>>0?1:fa;fa=Ha+aa|0;c[u>>2]=fa;if((W-fa|0)<1){Ia=0;Ja=fa}else{ua=Ha+(aa+1)|0;c[u>>2]=ua;Ia=a[fa]|0;Ja=ua}a[L]=Ia;ua=W-Ja|0;c[u>>2]=Ja+(ua>>>0>1>>>0?1:ua);xa=ya}else if((_|0)==3){if((W-Y|0)<1){Ka=0;La=Y}else{ua=V+2|0;c[u>>2]=ua;Ka=a[Y]|0;La=ua}mrc(y|0,Ka|0,4)|0;if((W-La|0)<1){Ma=0;Na=La}else{ua=La+1|0;c[u>>2]=ua;Ma=a[La]|0;Na=ua}a[K]=Ma;if((W-Na|0)<1){Oa=0}else{c[u>>2]=Na+1;Oa=a[Na]|0}a[L]=Oa;xa=Ka}else{X=_;break b}ua=c[v>>2]|0;fa=c[x>>2]|0;aa=(ca(S,ua)|0)+(U<<4)|0;ha=c[m>>2]|0;ba=c[B>>2]|0;ga=U<<3;sa=c[C>>2]|0;$=c[D>>2]|0;da=(ca(c[t>>2]|0,xa<<24>>24)|0)+2056>>4;if(da>>>0>255>>>0){Pa=-da>>31&255}else{Pa=da&255}mrc(fa+aa|0,Pa|0,8)|0;mrc(fa+(aa+ua)|0,Pa|0,8)|0;da=ua<<1;mrc(fa+(aa+da)|0,Pa|0,8)|0;ra=ua*3|0;mrc(fa+(aa+ra)|0,Pa|0,8)|0;va=ua<<2;mrc(fa+(aa+va)|0,Pa|0,8)|0;ta=ua*5|0;mrc(fa+(aa+ta)|0,Pa|0,8)|0;ka=ua*6|0;mrc(fa+(aa+ka)|0,Pa|0,8)|0;Qa=ua*7|0;mrc(fa+(aa+Qa)|0,Pa|0,8)|0;Ra=aa|8;Sa=(ca(a[M]|0,c[t>>2]|0)|0)+2056>>4;if(Sa>>>0>255>>>0){Ta=-Sa>>31&255}else{Ta=Sa&255}mrc(fa+Ra|0,Ta|0,8)|0;mrc(fa+(Ra+ua)|0,Ta|0,8)|0;mrc(fa+(Ra+da)|0,Ta|0,8)|0;mrc(fa+(Ra+ra)|0,Ta|0,8)|0;mrc(fa+(Ra+va)|0,Ta|0,8)|0;mrc(fa+(Ra+ta)|0,Ta|0,8)|0;mrc(fa+(Ra+ka)|0,Ta|0,8)|0;mrc(fa+(Ra+Qa)|0,Ta|0,8)|0;Ra=aa+(ua<<3)|0;aa=(ca(a[N]|0,c[t>>2]|0)|0)+2056>>4;if(aa>>>0>255>>>0){Ua=-aa>>31&255}else{Ua=aa&255}mrc(fa+Ra|0,Ua|0,8)|0;mrc(fa+(Ra+ua)|0,Ua|0,8)|0;mrc(fa+(Ra+da)|0,Ua|0,8)|0;mrc(fa+(Ra+ra)|0,Ua|0,8)|0;mrc(fa+(Ra+va)|0,Ua|0,8)|0;mrc(fa+(Ra+ta)|0,Ua|0,8)|0;mrc(fa+(Ra+ka)|0,Ua|0,8)|0;mrc(fa+(Ra+Qa)|0,Ua|0,8)|0;aa=Ra+8|0;Ra=(ca(a[O]|0,c[t>>2]|0)|0)+2056>>4;if(Ra>>>0>255>>>0){Va=-Ra>>31&255}else{Va=Ra&255}mrc(fa+aa|0,Va|0,8)|0;mrc(fa+(aa+ua)|0,Va|0,8)|0;mrc(fa+(aa+da)|0,Va|0,8)|0;mrc(fa+(aa+ra)|0,Va|0,8)|0;mrc(fa+(aa+va)|0,Va|0,8)|0;mrc(fa+(aa+ta)|0,Va|0,8)|0;mrc(fa+(aa+ka)|0,Va|0,8)|0;mrc(fa+(aa+Qa)|0,Va|0,8)|0;if((c[(c[j>>2]|0)+88>>2]&8192|0)!=0){break}Qa=(ca($,T)|0)+ga|0;$=(ca(ba,T)|0)+ga|0;ga=c[B>>2]|0;ba=(ca(a[K]|0,c[t>>2]|0)|0)+2056>>4;if(ba>>>0>255>>>0){Wa=-ba>>31&255}else{Wa=ba&255}mrc(ha+$|0,Wa|0,8)|0;mrc(ha+(ga+$)|0,Wa|0,8)|0;mrc(ha+((ga<<1)+$)|0,Wa|0,8)|0;mrc(ha+((ga*3|0)+$)|0,Wa|0,8)|0;mrc(ha+((ga<<2)+$)|0,Wa|0,8)|0;mrc(ha+((ga*5|0)+$)|0,Wa|0,8)|0;mrc(ha+((ga*6|0)+$)|0,Wa|0,8)|0;mrc(ha+((ga*7|0)+$)|0,Wa|0,8)|0;$=c[D>>2]|0;ga=(ca(a[L]|0,c[t>>2]|0)|0)+2056>>4;if(ga>>>0>255>>>0){Xa=-ga>>31&255}else{Xa=ga&255}mrc(sa+Qa|0,Xa|0,8)|0;mrc(sa+($+Qa)|0,Xa|0,8)|0;mrc(sa+(($<<1)+Qa)|0,Xa|0,8)|0;mrc(sa+(($*3|0)+Qa)|0,Xa|0,8)|0;mrc(sa+(($<<2)+Qa)|0,Xa|0,8)|0;mrc(sa+(($*5|0)+Qa)|0,Xa|0,8)|0;mrc(sa+(($*6|0)+Qa)|0,Xa|0,8)|0;mrc(sa+(($*7|0)+Qa)|0,Xa|0,8)|0}}while(0);U=U+1|0;Ya=c[A>>2]|0;}while((U|0)<(Ya+15>>4|0));Za=Ya;_a=c[z>>2]|0}else{Za=Q;_a=R}U=P+1|0;if((U|0)<(_a+15>>4|0)){P=U;Q=Za;R=_a}else{break a}}if((ja|0)==73){while(1){ja=0;ja=73}}KIb(c[j>>2]|0,16,2365016,(r=i,i=i+8|0,c[r>>2]=X,r)|0);i=r;s=-1094995529;i=k;return s|0}}while(0);c[h>>2]=1;s=c[n>>2]|0;i=k;return s|0}function Nca(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+104>>2]=1;c[a+108>>2]=15;c[a+140>>2]=11;a=UHb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function Oca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;h=i;i=i+16|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=k+l|0;n=e;o=m;if((l|0)<8){p=-1094995529;i=h;return p|0}q=k;r=k+8|0;s=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)==1413961323;a:do{if(s){if((o-r|0)<12){KIb(b,24,2454416,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;p=-1094995529;i=h;return p|0}q=r;u=(d[q]|d[q+1|0]<<8)<<16>>16&65535;q=g+12|0;c[q>>2]=u;v=k+10|0;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;v=g+16|0;c[v>>2]=w;x=g;y=c[x>>2]|0;if((c[y+120>>2]|0)==(u|0)){if((c[y+124>>2]|0)!=(w|0)){z=7}}else{z=7}do{if((z|0)==7){mJb(g+8|0);WHb(c[g+4>>2]|0);w=H4a(c[x>>2]|0,c[q>>2]|0,c[v>>2]|0)|0;if((w|0)<0){p=w}else{break}i=h;return p|0}}while(0);v=k+14|0;q=(d[v]|d[v+1|0]<<8)<<16>>16;v=q&65535;x=k+20|0;if(q<<16>>16==0){A=x;break}q=g+20|0;w=x;x=0;while(1){if((o-w|0)<=2){A=w;break a}c[q+(x<<2)>>2]=(d[w]|0)<<16|(d[w+1|0]|0)<<8|(d[w+2|0]|0)|-16777216;y=w+3|0;u=x+1|0;if((u|0)<(v|0)&(u|0)<256){w=y;x=u}else{A=y;break}}}else{A=r}}while(0);r=M4a(b,n,1)|0;if((r|0)<0){p=r;i=h;return p|0}nrc(c[e+4>>2]|0,g+20|0,1024)|0;b:do{if(s){c[e+84>>2]=1;c[e+88>>2]=1;r=g+8|0;k=c[r>>2]|0;do{if((k|0)==0){x=pJb(ca(c[g+16>>2]|0,c[g+12>>2]|0)|0)|0;c[r>>2]=x;if((x|0)==0){p=-12}else{B=x;break}i=h;return p|0}else{B=k}}while(0);k=c[g>>2]|0;x=B+(ca(c[k+124>>2]|0,c[k+120>>2]|0)|0)|0;k=(a[A]&1)==0?A+2|0:A+5|0;if((o-k|0)<3){KIb(b,24,2364992,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;p=-1094995529;i=h;return p|0}w=(d[k+1|0]|0)<<8|(d[k]|0)<<16|(d[k+2|0]|0);v=k+3|0;c:do{if((w|0)!=0&v>>>0<m>>>0){k=x;q=B;y=B;u=v;C=w;D=0;while(1){E=a[u]|0;F=E&255;G=F&3;do{if((F&128|0)==0){H=(d[u+1|0]|0|F<<3&768)+1|0;I=(F>>>2&7)+3|0;J=G;K=u+2|0}else{if((F&64|0)==0){L=u+1|0;M=(d[L]|0)>>>6;N=L;H=((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&16383)+1|0;I=(F&63)+4|0;J=M;K=u+3|0;break}if((F&32|0)==0){M=u+1|0;N=((he((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535|F<<12&65536)+1|0;H=N;I=(d[u+3|0]|0|F<<6&768)+5|0;J=G;K=u+4|0;break}if((E&255)>>>0<252>>>0){O=(F<<2&124)+4|0}else{O=G}H=D;I=0;J=O;K=u+1|0}}while(0);if((J|0)>(o-K|0)){break c}if((J|0)>0){G=k-y|0;F=(J|0)>(G|0)?G:J;nrc(y|0,K|0,F)|0;P=C-J|0;Q=K+F|0;R=y+F|0}else{P=C;Q=K;R=y}if((I|0)>0){F=R;if((F-q|0)<(H|0)){break c}G=k-F|0;F=(I|0)>(G|0)?G:I;vJb(R,H,F);S=P-I|0;T=R+F|0}else{S=P;T=R}if((S|0)>0&Q>>>0<m>>>0){y=T;u=Q;C=S;D=H}else{break}}}}while(0);w=g+16|0;if((c[w>>2]|0)>0){v=e;x=e+32|0;D=g+12|0;C=0;do{u=(c[v>>2]|0)+(ca(c[x>>2]|0,C)|0)|0;y=c[D>>2]|0;nrc(u|0,(c[r>>2]|0)+(ca(y,C)|0)|0,y)|0;C=C+1|0;}while((C|0)<(c[w>>2]|0))}U=g+4|0}else{w=g+4|0;if((c[c[w>>2]>>2]|0)==0){KIb(b,24,2299704,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;p=l;i=h;return p|0}c[e+84>>2]=0;c[e+88>>2]=2;d:do{if((o-A|0)>=12){C=A;r=(d[C]|d[C+1|0]<<8)<<16>>16;C=r&65535;D=A+2|0;x=(d[D]|d[D+1|0]<<8)<<16>>16&65535;D=A+4|0;v=(d[D]|d[D+1|0]<<8)<<16>>16;D=v&65535;y=A+6|0;u=(d[y]|d[y+1|0]<<8)<<16>>16;y=u&65535;k=A+12|0;if(!((u&65535)>>>0<26>>>0&u<<16>>16!=0)){KIb(c[g>>2]|0,16,2206616,(t=i,i=i+8|0,c[t>>2]=y,t)|0);i=t;break}u=g+1052|0;do{if((C|0)>(c[u>>2]|0)){if((oJb(g+1044|0,C,8)|0)==0){c[u>>2]=C;break}else{c[u>>2]=0;break d}}}while(0);u=g+1056|0;do{if((D|0)>(c[u>>2]|0)){if((lJb(g+1048|0,D<<4)|0)<0){c[u>>2]=0;break d}else{c[u>>2]=D;break}}}while(0);u=(C*20|0)+31&4194272;q=u>>>3;F=x<<4;if((o-k|0)<((D<<3)+F+q|0)){break}G=(k|0)==0?8:u|8;if(!(r<<16>>16==0)){u=c[g+1044>>2]|0;E=0;N=0;while(1){M=A+((E>>>3)+12)|0;L=E+10|0;V=G>>>0>L>>>0?L:G;c[u+(N<<3)>>2]=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((E&7)>>>0)<<22>>22;M=A+((V>>>3)+12)|0;L=V+10|0;c[u+(N<<3)+4>>2]=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((V&7)>>>0)<<22>>22;V=N+1|0;if((V|0)<(C|0)){E=G>>>0>L>>>0?L:G;N=V}else{break}}}N=q+12|0;G=A+(N+F)|0;E=o-G<<3;u=E>>>0>2147483639>>>0|(G|0)==0;r=u?0:G;G=u?0:E;E=G+8|0;if(v<<16>>16==0){W=0}else{u=g+1048|0;k=j|0;V=j+4|0;L=j+8|0;M=j+12|0;X=0;Y=0;while(1){Z=r+(X>>>3)|0;_=X+8|0;$=E>>>0>_>>>0?_:E;c[k>>2]=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((X&7)>>>0)&255;Z=r+($>>>3)|0;_=$+8|0;aa=E>>>0>_>>>0?_:E;c[V>>2]=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>(($&7)>>>0)&255;$=r+(aa>>>3)|0;Z=aa+8|0;_=E>>>0>Z>>>0?Z:E;c[L>>2]=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((aa&7)>>>0)&255;aa=r+(_>>>3)|0;$=_+8|0;c[M>>2]=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((_&7)>>>0)&255;_=E>>>0>$>>>0?$:E;$=0;while(1){aa=r+(_>>>3)|0;Z=_+2|0;ba=E>>>0>Z>>>0?Z:E;a[15-$+((c[u>>2]|0)+(Y<<4))|0]=c[j+(((d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((_&7)>>>0)&3)<<2)>>2];aa=$+1|0;if((aa|0)<16){_=ba;$=aa}else{break}}$=Y+1|0;if(($|0)<(D|0)){X=ba;Y=$}else{W=ba;break}}}Y=g;X=c[Y>>2]|0;u=c[X+124>>2]|0;M=ca((u|0)/4|0,y)|0;L=c[X+120>>2]|0;if((G-W|0)<(ca(M,(L|0)/4|0)|0)){break}if((u|0)<=3){U=w;break b}u=32-y|0;M=g+1044|0;V=e+32|0;k=e;v=g+1048|0;F=W;q=0;$=X;X=L;while(1){if((X|0)>3){L=q<<2;_=F;aa=0;Z=$;da=X;while(1){ea=r+(_>>>3)|0;fa=(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)>>>((_&7)>>>0)<<u>>>(u>>>0);ea=_+y|0;ga=E>>>0>ea>>>0?ea:E;e:do{if(fa>>>0<C>>>0){ea=c[M>>2]|0;ha=(c[ea+(fa<<3)>>2]|0)+(aa<<2)|0;ia=(c[ea+(fa<<3)+4>>2]|0)+L|0;do{if((ha|0)>=0){if((ha+4|0)>(da|0)|(ia|0)<0){break}if((ia+4|0)>(c[Z+124>>2]|0)){break}ea=c[w>>2]|0;ja=c[ea+32>>2]|0;ka=ja;la=(c[ea>>2]|0)+((ca(ja,ia)|0)+ha)|0;z=76;break e}}while(0);KIb(Z,16,2174336,(t=i,i=i+16|0,c[t>>2]=ha,c[t+8>>2]=ia,t)|0);i=t}else{ja=fa-C|0;if((ja|0)<(x|0)){ka=4;la=A+((ja<<4)+N)|0;z=76;break}ea=ja-x|0;if((ea|0)>=(D|0)){break}ka=4;la=(c[v>>2]|0)+(ea<<4)|0;z=76}}while(0);if((z|0)==76){z=0;fa=aa<<2;ea=fa|1;ja=fa|2;ma=fa|3;na=0;do{oa=ca(na,ka)|0;pa=na+L|0;qa=(ca(c[V>>2]|0,pa)|0)+fa|0;a[(c[k>>2]|0)+qa|0]=a[la+oa|0]|0;qa=(ca(c[V>>2]|0,pa)|0)+ea|0;a[(c[k>>2]|0)+qa|0]=a[la+(oa+1)|0]|0;qa=(ca(c[V>>2]|0,pa)|0)+ja|0;a[(c[k>>2]|0)+qa|0]=a[la+(oa+2)|0]|0;qa=(ca(c[V>>2]|0,pa)|0)+ma|0;a[(c[k>>2]|0)+qa|0]=a[la+(oa+3)|0]|0;na=na+1|0;}while((na|0)<4)}na=aa+1|0;ma=c[Y>>2]|0;ja=c[ma+120>>2]|0;if((na|0)<((ja|0)/4|0|0)){_=ga;aa=na;Z=ma;da=ja}else{ra=ga;sa=ma;ta=ja;break}}}else{ra=F;sa=$;ta=X}da=q+1|0;if((da|0)<((c[sa+124>>2]|0)/4|0|0)){F=ra;q=da;$=sa;X=ta}else{U=w;break b}}}}while(0);KIb(b,24,2248720,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;p=-1094995529;i=h;return p|0}}while(0);WHb(c[U>>2]|0);t=YHb(c[U>>2]|0,n)|0;if((t|0)<0){p=t;i=h;return p|0}c[f>>2]=1;p=l;i=h;return p|0}function Pca(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+8|0);kJb(c[b+1044>>2]|0);kJb(c[b+1048>>2]|0);return 0}function Qca(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b+4>>2]=a;l8(b+10056|0,a);d=b+11184|0;M6(d,1);L6(d,b+364|0,1242080);c[b+9960>>2]=1;c[a+104>>2]=1;c[a+108>>2]=15;c[a+140>>2]=0;jRa();return 0}function Rca(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;i=c[h+24>>2]|0;j=c[h+28>>2]|0;h=c[a+60>>2]|0;k=h;l=i;m=h+8|0;c[m>>2]=(d[l]|d[l+1|0]<<8)<<16>>16&65535;l=i+2|0;n=h+12|0;c[n>>2]=(d[l]|d[l+1|0]<<8)<<16>>16&65535;l=(215-((d[i+4|0]|0)<<1)|0)*5|0;b[h+12560>>1]=(ca(e[673424]|0,e[684440]|0)|0)>>>11;o=1;do{b[k+12560+(o<<1)>>1]=((ca(ca(l,e[1368880+(o<<1)>>1]|0)|0,e[1346848+(o<<1)>>1]|0)|0)+32|0)>>>14;o=o+1|0;}while((o|0)<64);o=h+4|0;l=H4a(c[o>>2]|0,c[m>>2]|0,c[n>>2]|0)|0;if((l|0)<0){p=l;return p|0}l=M4a(a,f,0)|0;if((l|0)<0){p=l;return p|0}l=h+14672|0;n=l;m=j-8|0;A4a(l,h+14676|0,m);l=c[n>>2]|0;if((l|0)==0){p=-12;return p|0}ef[c[h+11152>>2]&4095](l,i+8|0,(m|0)/4|0);i=c[n>>2]|0;n=m<<3;m=n>>>0>2147483639>>>0|(i|0)==0;l=m?0:i;i=m?0:n;c[h+14120>>2]=l;c[h+14132>>2]=i;c[h+14136>>2]=i+8;c[h+14124>>2]=l+(i>>3);c[h+14128>>2]=0;c[h+9868>>2]=0;c[h+9864>>2]=0;c[h+9860>>2]=0;i=h+12480|0;c[i>>2]=0;l=a+124|0;a:do{if((c[l>>2]|0)>0){n=h+12476|0;m=a+120|0;q=h+14688|0;r=q;s=h+10096|0;t=q;q=f+32|0;u=f;v=f+4|0;w=f+36|0;x=f+8|0;y=f+40|0;z=h+14816|0;A=h+14944|0;B=h+15072|0;C=h+15200|0;D=h+15328|0;E=0;do{c[n>>2]=0;if((c[m>>2]|0)>0){do{qe[c[s>>2]&1023](t);F=0;while(1){if((F|0)>=6){break}if((lRa(k,r+(F<<7)|0,F)|0)<0){break a}else{F=F+1|0}}F=c[q>>2]|0;G=c[u>>2]|0;H=c[i>>2]|0;I=ca(F<<4,H)|0;J=c[n>>2]|0;K=(J<<4)+I|0;I=c[v>>2]|0;L=H<<3;H=c[w>>2]|0;M=J<<3;J=c[x>>2]|0;N=c[y>>2]|0;wpb(G+K|0,F,t);wpb(G+(K|8)|0,F,z);O=K+(F<<3)|0;wpb(G+O|0,F,A);wpb(G+(O+8)|0,F,B);if((c[(c[o>>2]|0)+88>>2]&8192|0)==0){F=J+((ca(N,L)|0)+M)|0;N=I+((ca(H,L)|0)+M)|0;wpb(N,c[w>>2]|0,C);wpb(F,c[y>>2]|0,D)}F=(c[n>>2]|0)+1|0;c[n>>2]=F;}while((F|0)<(((c[m>>2]|0)+15|0)/16|0|0));P=c[i>>2]|0}else{P=E}E=P+1|0;c[i>>2]=E;}while((E|0)<(((c[l>>2]|0)+15|0)/16|0|0))}}while(0);c[g>>2]=1;p=j;return p|0}function Sca(a){a=a|0;kJb(c[(c[a+60>>2]|0)+14672>>2]|0);return 0}function Tca(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((e*24|0|0)<(c|0)){i=(c|0)/8|0;j=b<<2;k=hJb(ca(j,i)|0)|0;l=k;if((c|0)<=7){m=f<<1;Tca(l,b,i,d,e,m,g,h);Uca(l,b,i,d,e,m,g,h);kJb(k);return}n=c;o=(c|0)<0|0?-1:0;p=0;do{q=Erc(p,(p|0)<0|0?-1:0,433494437,0)|0;r=Drc(q,G,n,o)|0;nrc(l+((ca(p,b)|0)<<2)|0,a+((ca(r,b)|0)<<2)|0,j)|0;p=p+1|0;}while((p|0)<(i|0));m=f<<1;Tca(l,b,i,d,e,m,g,h);Uca(l,b,i,d,e,m,g,h);kJb(k);return}else{if((e|0)<=0){return}k=c;h=(c|0)<0|0?-1:0;c=b;g=(b|0)<0|0?-1:0;m=b<<2;i=0;do{l=d+((ca(i,b)|0)<<2)|0;f=Erc(i,(i|0)<0|0?-1:0,433494437,0)|0;p=Drc(f,G,k,h)|0;f=Erc(p,G,c,g)|0;nrc(l|0,a+(f<<2)|0,m)|0;i=i+1|0;}while((i|0)<(e|0));return}}function Uca(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0;k=i;i=i+56|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+40|0;q=hJb(d<<2)|0;r=q;s=f<<2;t=hJb(s)|0;u=t;v=hJb(d<<3)|0;w=v;x=hJb(s)|0;y=x;z=hJb(s)|0;A=z;B=hJb(s)|0;C=B;D=hJb(b*20|0)|0;E=D;F=(d|0)>0;G=(f|0)>0;H=e;I=b<<2;J=ca(I,f)|0;K=(b|0)>0;L=p|0;M=p+4|0;N=p+8|0;O=o+8|0;P=o|0;Q=l;R=m|0;S=m+4|0;T=o+4|0;U=Q+4|0;V=n|0;W=n+4|0;X=l;Y=C+(f-1<<2)|0;Z=j+256|0;_=b<<1;$=E+(_<<2)|0;aa=b*3|0;ba=E+(aa<<2)|0;da=E+(I<<2)|0;ea=ba;fa=b<<3;ga=(E|0)==(ba|0);ha=(I|0)==(b|0);ia=E+(b<<2)|0;ja=da;ka=(b|0)>1;la=0;ma=0;na=2147483647;while(1){oa=ma+1|0;mrc(z|0,0,s|0)|0;mrc(x|0,0,s|0)|0;if(F){pa=0;qa=0;ra=w;sa=la;while(1){ta=ca(qa,b)|0;ua=ca(sa,b)|0;if(K){va=0;wa=0;while(1){xa=(c[a+(va+ta<<2)>>2]|0)-(c[e+(va+ua<<2)>>2]|0)|0;ya=(ca(xa,xa)|0)+wa|0;xa=va+1|0;if((xa|0)<(b|0)){va=xa;wa=ya}else{za=ya;break}}}else{za=0}if(G){wa=0;va=za;ua=sa;while(1){ya=ca(wa,b)|0;xa=0;Aa=0;while(1){if((Aa|0)>=(b|0)){Ba=xa;break}Ca=(c[a+(Aa+ta<<2)>>2]|0)-(c[e+(Aa+ya<<2)>>2]|0)|0;Da=(ca(Ca,Ca)|0)+xa|0;if((Da|0)>(va|0)){Ba=2147483647;break}else{xa=Da;Aa=Aa+1|0}}Aa=(Ba|0)<(va|0);xa=Aa?Ba:va;ya=Aa?wa:ua;Aa=wa+1|0;if((Aa|0)<(f|0)){wa=Aa;va=xa;ua=ya}else{Ea=xa;Fa=ya;break}}}else{Ea=za;Fa=sa}ua=h+(qa<<2)|0;c[ua>>2]=Fa;c[r+(qa<<2)>>2]=Ea;va=Ea+pa|0;wa=A+(Fa<<2)|0;c[wa>>2]=(c[wa>>2]|0)+Ea;c[ra>>2]=qa;wa=y+(c[ua>>2]<<2)|0;c[ra+4>>2]=c[wa>>2];c[wa>>2]=ra;wa=qa+1|0;if((wa|0)<(d|0)){pa=va;qa=wa;ra=ra+8|0;sa=Fa}else{Ga=va;Ha=Fa;break}}}else{Ga=0;Ha=la}a:do{if(G){sa=0;ra=0;do{qa=c[A+(sa<<2)>>2]|0;pa=(ca(qa,f)|0)>(Ga|0);ra=(pa?qa:0)+ra|0;c[C+(sa<<2)>>2]=ra;sa=sa+1|0;}while((sa|0)<(f|0));c[L>>2]=0;sa=0;ra=Ga;while(1){qa=A+(sa<<2)|0;pa=c[qa>>2]|0;do{if((ca(pa,f)|0)<(ra|0)){va=c[Y>>2]|0;if((va|0)==0){Ia=ra;break a}wa=c[Z>>2]|0;c[j+((wa&63)<<2)>>2]=(c[j+((wa+9&63)<<2)>>2]|0)+(c[j+((wa+40&63)<<2)>>2]|0);wa=c[Z>>2]|0;c[Z>>2]=wa+1;ua=(((c[j+((wa&63)<<2)>>2]|0)>>>0)%(va>>>0)|0)+1|0;va=0;while(1){if((c[C+(va<<2)>>2]|0)<(ua|0)){va=va+1|0}else{break}}c[M>>2]=va;ua=ca(sa,b)|0;wa=0;ta=0;ya=2147483647;while(1){if((ta|0)==(sa|0)){Ja=ya;Ka=wa}else{xa=ca(ta,b)|0;Aa=0;Da=0;while(1){if((Da|0)>=(b|0)){La=Aa;break}Ca=(c[e+(Da+xa<<2)>>2]|0)-(c[e+(Da+ua<<2)>>2]|0)|0;Ma=(ca(Ca,Ca)|0)+Aa|0;if((Ma|0)>(ya|0)){La=2147483647;break}else{Aa=Ma;Da=Da+1|0}}Da=(La|0)<(ya|0);Ja=Da?La:ya;Ka=Da?ta:wa}Da=ta+1|0;if((Da|0)<(f|0)){wa=Ka;ta=Da;ya=Ja}else{break}}c[N>>2]=Ka;if((va|0)==(sa|0)|(va|0)==(Ka|0)){Na=ra;break}ya=A+(va<<2)|0;ta=A+(Ka<<2)|0;wa=(c[ya>>2]|0)+pa+(c[ta>>2]|0)|0;mrc($|0,0,I|0)|0;ua=y+(sa<<2)|0;Da=c[ua>>2]|0;Aa=(Da|0)==0;if(Aa){Oa=0}else{xa=0;Ma=Da;while(1){Ca=xa+1|0;if(K){Pa=Ma|0;Qa=0;do{Ra=c[a+((ca(c[Pa>>2]|0,b)|0)+Qa<<2)>>2]|0;Sa=E+(Qa+_<<2)|0;c[Sa>>2]=(c[Sa>>2]|0)+Ra;Qa=Qa+1|0;}while((Qa|0)<(b|0))}Qa=c[Ma+4>>2]|0;if((Qa|0)==0){Oa=Ca;break}else{xa=Ca;Ma=Qa}}}Ma=y+(Ka<<2)|0;xa=c[Ma>>2]|0;Qa=(xa|0)==0;if(Qa){Ta=Oa}else{Pa=Oa;Ra=xa;while(1){Sa=Pa+1|0;if(K){Ua=Ra|0;Va=0;do{Wa=c[a+((ca(c[Ua>>2]|0,b)|0)+Va<<2)>>2]|0;Xa=E+(Va+_<<2)|0;c[Xa>>2]=(c[Xa>>2]|0)+Wa;Va=Va+1|0;}while((Va|0)<(b|0))}Va=c[Ra+4>>2]|0;if((Va|0)==0){Ta=Sa;break}else{Pa=Sa;Ra=Va}}}do{if((Ta|0)>1){if(!K){break}Ra=Ta>>1;Pa=-Ra|0;Va=0;while(1){Ua=E+(Va+_<<2)|0;Ca=c[Ua>>2]|0;c[Ua>>2]=(((Ca|0)>0?Ra:Pa)+Ca|0)/(Ta|0)|0;Ca=Va+1|0;if((Ca|0)<(b|0)){Va=Ca}else{Ya=36;break}}}else{Ya=36}}while(0);do{if((Ya|0)==36){Ya=0;if(K){Za=0}else{break}do{c[E+(Za<<2)>>2]=2147483647;c[E+(Za+b<<2)>>2]=0;Za=Za+1|0;}while((Za|0)<(b|0))}}while(0);Va=y+(va<<2)|0;Pa=c[Va>>2]|0;Ra=(Pa|0)==0;if(!Ra){Sa=Pa;do{if(K){Ca=Sa|0;Ua=0;do{Wa=E+(Ua<<2)|0;Xa=c[Wa>>2]|0;_a=c[a+((ca(c[Ca>>2]|0,b)|0)+Ua<<2)>>2]|0;c[Wa>>2]=(Xa|0)>(_a|0)?_a:Xa;Xa=E+(Ua+b<<2)|0;_a=c[Xa>>2]|0;Wa=c[a+((ca(c[Ca>>2]|0,b)|0)+Ua<<2)>>2]|0;c[Xa>>2]=(_a|0)>(Wa|0)?_a:Wa;Ua=Ua+1|0;}while((Ua|0)<(b|0))}Sa=c[Sa+4>>2]|0;}while((Sa|0)!=0)}if(K){Sa=0;do{Ua=E+(Sa<<2)|0;Ca=c[Ua>>2]|0;Wa=E+(Sa+b<<2)|0;_a=(c[Wa>>2]|0)-Ca|0;c[Ua>>2]=((_a|0)/3|0)+Ca;c[Wa>>2]=((_a<<1|0)/3|0)+Ca;Sa=Sa+1|0;}while((Sa|0)<(b|0))}b:do{if(Aa){$a=0}else{if(K){ab=Da;bb=0}else{Sa=Da;while(1){Ca=c[Sa+4>>2]|0;if((Ca|0)==0){$a=0;break b}else{Sa=Ca}}}while(1){Sa=ca(c[ab>>2]|0,b)|0;Ca=0;_a=0;do{Wa=(c[E+(Ca+_<<2)>>2]|0)-(c[a+(Ca+Sa<<2)>>2]|0)|0;_a=(ca(Wa,Wa)|0)+_a|0;Ca=Ca+1|0;}while((Ca|0)<(b|0));Ca=_a+bb|0;Sa=c[ab+4>>2]|0;if((Sa|0)==0){$a=Ca;break}else{ab=Sa;bb=Ca}}}}while(0);c[O>>2]=$a;c:do{if(Qa){cb=0}else{if(K){db=xa;eb=0}else{Da=xa;while(1){Aa=c[Da+4>>2]|0;if((Aa|0)==0){cb=0;break c}else{Da=Aa}}}while(1){Da=ca(c[db>>2]|0,b)|0;Aa=0;Ca=0;do{Sa=(c[E+(Aa+_<<2)>>2]|0)-(c[a+(Aa+Da<<2)>>2]|0)|0;Ca=(ca(Sa,Sa)|0)+Ca|0;Aa=Aa+1|0;}while((Aa|0)<(b|0));Aa=Ca+eb|0;Da=c[db+4>>2]|0;if((Da|0)==0){cb=Aa;break}else{db=Da;eb=Aa}}}}while(0);xa=cb+$a|0;c[O>>2]=xa;c[l>>2]=0;c[l+4>>2]=0;c[R>>2]=ba;c[S>>2]=da;mrc(ea|0,0,fa|0)|0;c[T>>2]=0;c[P>>2]=0;do{if(Ra){Ya=69}else{Qa=Pa;do{Aa=Qa|0;Da=ca(c[Aa>>2]|0,b)|0;do{if(K){_a=0;Sa=0;while(1){Wa=(c[E+(_a<<2)>>2]|0)-(c[a+(_a+Da<<2)>>2]|0)|0;fb=(ca(Wa,Wa)|0)+Sa|0;Wa=_a+1|0;if((Wa|0)<(b|0)){_a=Wa;Sa=fb}else{gb=0;hb=0;break}}do{Sa=(c[E+(gb+b<<2)>>2]|0)-(c[a+(gb+Da<<2)>>2]|0)|0;hb=(ca(Sa,Sa)|0)+hb|0;gb=gb+1|0;}while((gb|0)<(b|0));Sa=(fb|0)>=(hb|0)|0;_a=Q+(Sa<<2)|0;c[_a>>2]=(c[_a>>2]|0)+1;_a=c[m+(Sa<<2)>>2]|0;c[_a>>2]=(c[_a>>2]|0)+(c[a+(Da<<2)>>2]|0);if(ka){ib=1}else{break}do{Sa=c[a+((ca(c[Aa>>2]|0,b)|0)+ib<<2)>>2]|0;Wa=_a+(ib<<2)|0;c[Wa>>2]=(c[Wa>>2]|0)+Sa;ib=ib+1|0;}while((ib|0)<(b|0))}else{c[U>>2]=(c[U>>2]|0)+1}}while(0);Qa=c[Qa+4>>2]|0;}while((Qa|0)!=0);Qa=c[X>>2]|0;if((Qa|0)<=1){Ya=69;break}if(!K){break}Aa=Qa>>1;Da=-Aa|0;Ca=0;do{_a=c[E+(Ca+aa<<2)>>2]|0;c[E+(Ca<<2)>>2]=(((_a|0)>0?Aa:Da)+_a|0)/(Qa|0)|0;Ca=Ca+1|0;}while((Ca|0)<(b|0))}}while(0);do{if((Ya|0)==69){Ya=0;if(ga){break}nrc(D|0,ea|0,I)|0}}while(0);Ca=c[U>>2]|0;do{if((Ca|0)>1){if(!K){break}Qa=Ca>>1;Da=-Qa|0;Aa=0;do{_a=c[E+(Aa+I<<2)>>2]|0;c[E+(Aa+b<<2)>>2]=(((_a|0)>0?Qa:Da)+_a|0)/(Ca|0)|0;Aa=Aa+1|0;}while((Aa|0)<(b|0))}else{if(ha){break}nrc(ia|0,ja|0,I)|0}}while(0);do{if(Ra){jb=0;kb=0}else{if(K){lb=Pa}else{Ca=Pa;do{Ca=c[Ca+4>>2]|0;}while((Ca|0)!=0);c[V>>2]=0;c[W>>2]=0;c[P>>2]=0;jb=0;kb=0;break}do{Ca=ca(c[lb>>2]|0,b)|0;Aa=0;Da=0;do{Qa=(c[E+(Aa<<2)>>2]|0)-(c[a+(Aa+Ca<<2)>>2]|0)|0;Da=(ca(Qa,Qa)|0)+Da|0;Aa=Aa+1|0;}while((Aa|0)<(b|0));c[V>>2]=Da;Aa=0;Qa=0;do{_a=(c[E+(Aa+b<<2)>>2]|0)-(c[a+(Aa+Ca<<2)>>2]|0)|0;Qa=(ca(_a,_a)|0)+Qa|0;Aa=Aa+1|0;}while((Aa|0)<(b|0));c[W>>2]=Qa;Aa=(Da|0)>(Qa|0)|0;Ca=o+(Aa<<2)|0;c[Ca>>2]=(c[Ca>>2]|0)+(c[n+(Aa<<2)>>2]|0);lb=c[lb+4>>2]|0;}while((lb|0)!=0);jb=c[P>>2]|0;kb=c[T>>2]|0}}while(0);Pa=kb+xa+jb|0;if((wa|0)>(Pa|0)){mb=Ma}else{Na=ra;break}while(1){Ra=c[mb>>2]|0;if((Ra|0)==0){break}mb=Ra+4|0}c[mb>>2]=c[ua>>2];c[ua>>2]=0;xa=c[Va>>2]|0;c[Va>>2]=0;d:do{if((xa|0)!=0){if(K){nb=xa}else{Ra=xa;Aa=c[ua>>2]|0;while(1){Ca=Ra+4|0;_a=c[Ca>>2]|0;c[Ca>>2]=Aa;c[ua>>2]=Ra;if((_a|0)==0){break d}else{Aa=Ra;Ra=_a}}}while(1){Ra=nb+4|0;Aa=c[Ra>>2]|0;_a=ca(c[nb>>2]|0,b)|0;Ca=0;Sa=0;while(1){Wa=(c[a+(Ca+_a<<2)>>2]|0)-(c[E+(Ca<<2)>>2]|0)|0;ob=(ca(Wa,Wa)|0)+Sa|0;Wa=Ca+1|0;if((Wa|0)<(b|0)){Ca=Wa;Sa=ob}else{pb=0;qb=0;break}}do{Sa=(c[a+(pb+_a<<2)>>2]|0)-(c[E+(pb+b<<2)>>2]|0)|0;qb=(ca(Sa,Sa)|0)+qb|0;pb=pb+1|0;}while((pb|0)<(b|0));_a=y+(c[p+(((ob|0)>(qb|0))<<2)>>2]<<2)|0;c[Ra>>2]=c[_a>>2];c[_a>>2]=nb;if((Aa|0)==0){break}else{nb=Aa}}}}while(0);xa=Pa-wa+ra|0;c[qa>>2]=jb;_a=c[ua>>2]|0;if((_a|0)!=0){Sa=_a;do{c[h+(c[Sa>>2]<<2)>>2]=sa;Sa=c[Sa+4>>2]|0;}while((Sa|0)!=0)}c[ya>>2]=kb;Sa=c[Va>>2]|0;if((Sa|0)!=0){ua=Sa;do{c[h+(c[ua>>2]<<2)>>2]=va;ua=c[ua+4>>2]|0;}while((ua|0)!=0)}c[ta>>2]=c[O>>2];ua=c[Ma>>2]|0;if((ua|0)==0){rb=0;sb=0}else{va=ua;while(1){c[h+(c[va>>2]<<2)>>2]=Ka;ua=c[va+4>>2]|0;if((ua|0)==0){rb=0;sb=0;break}else{va=ua}}}while(1){va=c[A+(rb<<2)>>2]|0;Ma=(ca(va,f)|0)>(xa|0);ta=(Ma?va:0)+sb|0;c[C+(rb<<2)>>2]=ta;va=rb+1|0;if((va|0)<(f|0)){rb=va;sb=ta}else{Na=xa;break}}}else{Na=ra}}while(0);qa=sa+1|0;c[L>>2]=qa;if((qa|0)<(f|0)){sa=qa;ra=Na}else{Ia=Na;break}}}else{c[L>>2]=0;Ia=Ga}}while(0);mrc(t|0,0,s|0)|0;mrc(H|0,0,J|0)|0;if(F){ra=0;do{sa=h+(ra<<2)|0;qa=c[sa>>2]|0;pa=u+(qa<<2)|0;c[pa>>2]=(c[pa>>2]|0)+1;e:do{if(K){pa=ca(ra,b)|0;xa=0;ta=qa;while(1){va=e+((ca(ta,b)|0)+xa<<2)|0;c[va>>2]=(c[va>>2]|0)+(c[a+(xa+pa<<2)>>2]|0);va=xa+1|0;if((va|0)>=(b|0)){break e}xa=va;ta=c[sa>>2]|0}}}while(0);ra=ra+1|0;}while((ra|0)<(d|0))}if(G){ra=0;do{sa=ca(ra,b)|0;qa=c[u+(ra<<2)>>2]|0;if((qa|0)>1&K){ta=qa>>1;xa=-ta|0;pa=0;do{va=e+(pa+sa<<2)|0;Ma=c[va>>2]|0;c[va>>2]=(((Ma|0)>0?ta:xa)+Ma|0)/(qa|0)|0;pa=pa+1|0;}while((pa|0)<(b|0))}ra=ra+1|0;}while((ra|0)<(f|0))}if(+(na-Ia|0)>+(Ia|0)*.1&(oa|0)<(g|0)){la=Ha;ma=oa;na=Ia}else{break}}kJb(q);kJb(t);kJb(z);kJb(v);kJb(x);kJb(B);kJb(D);i=k;return}function Vca(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[a+140>>2]=46;c[b+4>>2]=ca((c[a+124>>2]|0)>>>3,(c[a+120>>2]|0)>>>3)|0;a=UHb()|0;c[b>>2]=a;return((a|0)==0?-12:0)|0}function Wca(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;k=i;i=i+128|0;l=k|0;m=c[j+28>>2]|0;n=c[f+60>>2]|0;o=n;p=g;q=(c[f+120>>2]|0)/8|0;r=c[j+24>>2]|0;j=m>>>0>268435455>>>0?-8:m<<3;s=j>>>0>2147483639>>>0|(r|0)==0;t=s?0:r;r=s?0:j;j=r+8|0;if(s){u=s?-1094995529:0;i=k;return u|0}if((r|0)<64){u=-1;i=k;return u|0}s=t;v=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j>>>0>16>>>0?16:j;w=t+(s>>>3)|0;x=s+16|0;s=j>>>0>x>>>0?x:j;x=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24)<<16;w=x|v&65535;y=t+(s>>>3)|0;z=s+16|0;A=j>>>0>z>>>0?z:j;z=t+(A>>>3)|0;B=A+16|0;C=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((A&7)>>>0)<<16|(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((s&7)>>>0)&65535;if((v&276|0)==0|(x&125829120|0)==0){v=n;if((c[c[v>>2]>>2]|0)==0){u=-1094995529;i=k;return u|0}KIb(f,48,2454384,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;c[h>>2]=1;s=YHb(p,c[v>>2]|0)|0;u=(s|0)<0?s:C;i=k;return u|0}s=n+8|0;v=n+4|0;y=j>>>0>B>>>0?B:j;B=0;a:while(1){do{if((1<<B+17&w|0)==0){E=y}else{A=t+(y>>>3)|0;z=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((y&7)>>>0);do{if((B|0)==2){A=z&1048575;F=y+20|0;G=A-1|0;H=G>>>0>65535>>>0;I=H?G>>>16:G;G=H?16:0;if((I&65280|0)==0){J=G;K=I}else{J=G|8;K=I>>>8}L=A;M=J+1+(d[1359664+K|0]|0)|0;N=j>>>0>F>>>0?F:j}else{F=z&15;A=y+4|0;I=j>>>0>A>>>0?A:j;if((B|0)==0){L=1<<F;M=F;N=I;break}else{L=c[v>>2]<<F;M=F;N=I;break}}}while(0);O=s+(B*12|0)+8|0;kJb(c[O>>2]|0);if(L>>>0>63161282>>>0){P=20;break a}if((r-N|0)>>>0<(L*34|0)>>>0){P=20;break a}z=(L|0)==0;I=hJb(z?1:L<<3)|0;F=I;A=(I|0)==0;if(A|z){c[s+(B*12|0)>>2]=A?0:M;c[s+(B*12|0)+4>>2]=0;c[O>>2]=F;if((I|0)==0){u=-1;P=88;break a}else{E=N;break}}else{Q=0;R=N}do{I=t+(R>>>3)|0;A=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((R&7)>>>0);I=R+4|0;z=j>>>0>I>>>0?I:j;I=t+(z>>>3)|0;G=z+15|0;H=j>>>0>G>>>0?G:j;G=t+(H>>>3)|0;S=H+15|0;R=j>>>0>S>>>0?S:j;S=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((z&7)>>>0)&32767;z=F+(Q<<3)|0;I=z;T=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((H&7)>>>0)&32767;b[z>>1]=(A&1|0)==0?S:T;b[I+2>>1]=(A&2|0)==0?S:T;b[F+(Q<<3)+4>>1]=(A&4|0)==0?S:T;b[I+6>>1]=(A&8|0)==0?S:T;Q=Q+1|0;}while(Q>>>0<L>>>0);c[s+(B*12|0)>>2]=M;c[s+(B*12|0)+4>>2]=L;c[O>>2]=F;E=R}}while(0);T=B+1|0;if(T>>>0<3>>>0){y=E;B=T}else{P=23;break}}if((P|0)==20){c[s+(B*12|0)>>2]=0;c[s+(B*12|0)+4>>2]=0;c[O>>2]=0;u=-1;i=k;return u|0}else if((P|0)==23){O=M4a(f,p,1)|0;if((O|0)<0){u=O;i=k;return u|0}O=(c[g+32>>2]|0)/2|0;B=n;s=c[B>>2]|0;y=(c[s+32>>2]|0)/2|0;if((c[v>>2]|0)==0){U=E}else{R=O<<1;L=O*3|0;M=O<<2;Q=O*5|0;N=O*6|0;K=O*7|0;J=y<<1;w=y*3|0;T=y<<2;S=y*5|0;A=y*6|0;I=y*7|0;z=q<<3;H=8-z+(O<<3)|0;G=(y<<3)-z|0;z=l;V=l+16|0;W=l+32|0;X=l+48|0;Y=l+64|0;Z=l+80|0;_=l+96|0;$=l+112|0;aa=n+20|0;n=(x&65536|0)==0;x=E;E=1;ba=-1;ca=c[s>>2]|0;s=c[g>>2]|0;g=0;da=0;while(1){do{if((ba|0)==-1){if((r-x|0)<1){ea=x;fa=-1;P=33;break}ga=((x|0)<(j|0))+x|0;ha=(d[t+(x>>>3)|0]|0)>>>((x&7)>>>0)&1;if((ha|0)==0){ia=ga;P=36;break}ja=t+(ga>>>3)|0;ka=ga+3|0;la=j>>>0>ka>>>0?ka:j;ka=((d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)>>>((ga&7)>>>0)&7)+ha|0;if((ka|0)!=8){ma=ka;na=la;P=32;break}ka=t+(la>>>3)|0;ha=la+7|0;ga=j>>>0>ha>>>0?ha:j;ha=((d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)>>>((la&7)>>>0)&127)+8|0;if((ha|0)!=135){ea=ga;fa=ha;P=33;break}ha=t+(ga>>>3)|0;la=ga+12|0;ea=j>>>0>la>>>0?la:j;fa=((d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)>>>((ga&7)>>>0)&4095)+135|0;P=33}else{ma=ba;na=x;P=32}}while(0);if((P|0)==32){P=0;if((ma|0)==0){ia=na;P=36}else{ea=na;fa=ma;P=33}}do{if((P|0)==33){P=0;ga=s;if((ca|0)==0){mrc(ga|0,0,16)|0;mrc(s+(O<<1)|0,0,16)|0;mrc(s+(R<<1)|0,0,16)|0;mrc(s+(L<<1)|0,0,16)|0;mrc(s+(M<<1)|0,0,16)|0;mrc(s+(Q<<1)|0,0,16)|0;mrc(s+(N<<1)|0,0,16)|0;mrc(s+(K<<1)|0,0,16)|0;oa=E;pa=ea;qa=fa;break}else{nrc(ga|0,ca|0,16)|0;nrc(s+(O<<1)|0,ca+(y<<1)|0,16)|0;nrc(s+(R<<1)|0,ca+(J<<1)|0,16)|0;nrc(s+(L<<1)|0,ca+(w<<1)|0,16)|0;nrc(s+(M<<1)|0,ca+(T<<1)|0,16)|0;nrc(s+(Q<<1)|0,ca+(S<<1)|0,16)|0;nrc(s+(N<<1)|0,ca+(A<<1)|0,16)|0;nrc(s+(K<<1)|0,ca+(I<<1)|0,16)|0;oa=E;pa=ea;qa=fa;break}}else if((P|0)==36){P=0;if((ca|0)==0){mrc(l|0,0,128)|0}else{nrc(z|0,ca|0,16)|0;nrc(V|0,ca+(y<<1)|0,16)|0;nrc(W|0,ca+(J<<1)|0,16)|0;nrc(X|0,ca+(w<<1)|0,16)|0;nrc(Y|0,ca+(T<<1)|0,16)|0;nrc(Z|0,ca+(S<<1)|0,16)|0;nrc(_|0,ca+(A<<1)|0,16)|0;nrc($|0,ca+(I<<1)|0,16)|0}b:do{if((r-ia|0)>0){ga=ia;ha=E;la=0;while(1){ka=((ga|0)<(j|0))+ga|0;if((d[t+(ga>>>3)|0]&1<<(ga&7)|0)!=0){ra=ka;sa=ha;ta=la;break b}ja=((ka|0)<(j|0))+ka|0;if((d[t+(ka>>>3)|0]&1<<(ka&7)|0)==0){ua=ha;va=ja}else{ua=a[((d[t+(ja>>>3)|0]|0)>>>((ja&7)>>>0)&1)+(1585152+(ha<<1))|0]|0;va=((ja|0)<(j|0))+ja|0}ja=c[o+8+(ua*12|0)>>2]|0;if((ja|0)==0){wa=0;xa=va}else{ka=t+(va>>>3)|0;ya=32-ja|0;za=ja+va|0;wa=(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)>>>((va&7)>>>0)<<ya>>>(ya>>>0);xa=j>>>0>za>>>0?za:j}if((ua|0)==1){Aa=(da<<c[aa>>2])+wa|0}else{Aa=wa}if(Aa>>>0<(c[o+8+(ua*12|0)+4>>2]|0)>>>0){za=(c[o+8+(ua*12|0)+8>>2]|0)+(Aa<<3)|0;Ba=c[za+4>>2]|0;Ca=c[za>>2]|0}else{Ba=0;Ca=0}za=t+(xa>>>3)|0;ya=(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)>>>((xa&7)>>>0);za=xa+16|0;ka=j>>>0>za>>>0?za:j;za=0;do{if((e[838232+(za<<1)>>1]&ya|0)!=0){ja=(za&-4)+za|0;c[l+(ja<<2)>>2]=Ca;c[l+(ja+4<<2)>>2]=Ba}za=za+1|0;}while(za>>>0<16>>>0);za=ya&65535|la;if((r-ka|0)>0){ga=ka;ha=ua;la=za}else{ra=ka;sa=ua;ta=za;break}}}else{ra=ia;sa=E;ta=0}}while(0);F=((ra|0)<(j|0))+ra|0;c:do{if((d[t+(ra>>>3)|0]&1<<(ra&7)|0)==0){la=t+(F>>>3)|0;ha=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((F&7)>>>0);la=F+4|0;ga=j>>>0>la>>>0?la:j;if((ha&1|0)==0){la=t+(ga>>>3)|0;za=ga+4|0;Da=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ga&7)>>>0)&15;Ea=j>>>0>za>>>0?za:j}else{Da=15;Ea=ga}if((ha&2|0)==0){ga=t+(Ea>>>3)|0;za=Ea+4|0;Fa=(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((Ea&7)>>>0)<<4&240;Ga=j>>>0>za>>>0?za:j}else{Fa=240;Ga=Ea}if((ha&4|0)==0){za=t+(Ga>>>3)|0;ga=Ga+4|0;Ha=(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)>>>((Ga&7)>>>0)<<8&3840;Ia=j>>>0>ga>>>0?ga:j}else{Ha=3840;Ia=Ga}if((ha&8|0)==0){ha=t+(Ia>>>3)|0;ga=Ia+4|0;Ja=(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)>>>((Ia&7)>>>0)<<12&61440;Ka=j>>>0>ga>>>0?ga:j}else{Ja=61440;Ka=Ia}ga=Ja^(Ha^(Fa^(Da^ta)));ha=Ka;za=sa;la=0;while(1){if((e[838232+(la<<1)>>1]&ga|0)==0){La=za;Ma=ha}else{ja=((ha|0)<(j|0))+ha|0;if((d[t+(ha>>>3)|0]&1<<(ha&7)|0)==0){Na=za;Oa=ja}else{Na=a[((d[t+(ja>>>3)|0]|0)>>>((ja&7)>>>0)&1)+(1585152+(za<<1))|0]|0;Oa=((ja|0)<(j|0))+ja|0}ja=c[o+8+(Na*12|0)>>2]|0;if((ja|0)==0){Pa=0;Qa=Oa}else{Ra=t+(Oa>>>3)|0;Sa=32-ja|0;Ta=ja+Oa|0;Pa=(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)>>>((Oa&7)>>>0)<<Sa>>>(Sa>>>0);Qa=j>>>0>Ta>>>0?Ta:j}if((Na|0)==1){Ua=(da<<c[aa>>2])+Pa|0}else{Ua=Pa}if(Ua>>>0<(c[o+8+(Na*12|0)+4>>2]|0)>>>0){Ta=(c[o+8+(Na*12|0)+8>>2]|0)+(Ua<<3)|0;Va=c[Ta+4>>2]|0;Wa=c[Ta>>2]|0}else{Va=0;Wa=0}Ta=(la&-4)+la|0;c[l+(Ta<<2)>>2]=Wa;c[l+(Ta+4<<2)>>2]=Va;La=Na;Ma=Qa}Ta=la+1|0;if(Ta>>>0<16>>>0){ha=Ma;za=La;la=Ta}else{Xa=La;Ya=Ma;break}}}else{if(n){Xa=sa;Ya=F;break}if((r-F|0)>0){Za=F;_a=sa}else{Xa=sa;Ya=F;break}while(1){la=((Za|0)<(j|0))+Za|0;if((d[t+(Za>>>3)|0]&1<<(Za&7)|0)!=0){Xa=_a;Ya=la;break c}za=((la|0)<(j|0))+la|0;if((d[t+(la>>>3)|0]&1<<(la&7)|0)==0){$a=_a;ab=za}else{$a=a[((d[t+(za>>>3)|0]|0)>>>((za&7)>>>0)&1)+(1585152+(_a<<1))|0]|0;ab=((za|0)<(j|0))+za|0}za=c[o+8+($a*12|0)>>2]|0;if((za|0)==0){bb=0;cb=ab}else{la=t+(ab>>>3)|0;ha=32-za|0;ga=za+ab|0;bb=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ab&7)>>>0)<<ha>>>(ha>>>0);cb=j>>>0>ga>>>0?ga:j}if(($a|0)==1){db=(da<<c[aa>>2])+bb|0}else{db=bb}if(db>>>0<(c[o+8+($a*12|0)+4>>2]|0)>>>0){ga=(c[o+8+($a*12|0)+8>>2]|0)+(db<<3)|0;eb=c[ga+4>>2]|0;fb=c[ga>>2]|0}else{eb=0;fb=0}ga=t+(cb>>>3)|0;ha=(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)>>>((cb&7)>>>0);ga=cb+4|0;la=j>>>0>ga>>>0?ga:j;ga=(ha&12)+(ha&15)|0;c[l+(ga<<2)>>2]=fb;c[l+(ga+4<<2)>>2]=eb;if((r-la|0)>0){Za=la;_a=$a}else{Xa=$a;Ya=la;break}}}}while(0);nrc(s|0,z|0,16)|0;nrc(s+(O<<1)|0,V|0,16)|0;nrc(s+(R<<1)|0,W|0,16)|0;nrc(s+(L<<1)|0,X|0,16)|0;nrc(s+(M<<1)|0,Y|0,16)|0;nrc(s+(Q<<1)|0,Z|0,16)|0;nrc(s+(N<<1)|0,_|0,16)|0;nrc(s+(K<<1)|0,$|0,16)|0;oa=Xa;pa=Ya;qa=0}}while(0);F=g+1|0;la=s+16|0;ga=(ca|0)==0?0:ca+16|0;do{if((F|0)==(q|0)){ha=s+(H<<1)|0;if((ga|0)==0){gb=0;hb=ha;ib=0;break}gb=0;hb=ha;ib=ga+(G<<1)|0}else{gb=F;hb=la;ib=ga}}while(0);ga=da+1|0;if(ga>>>0<(c[v>>2]|0)>>>0){x=pa;E=oa;ba=qa-1|0;ca=ib;s=hb;g=gb;da=ga}else{U=pa;break}}}KIb(f,48,2364960,(D=i,i=i+24|0,c[D>>2]=C,c[D+8>>2]=m,c[D+16>>2]=(U|0)/8|0,D)|0);i=D;WHb(c[B>>2]|0);D=YHb(c[B>>2]|0,p)|0;if((D|0)<0){u=D;i=k;return u|0}c[h>>2]=1;u=C;i=k;return u|0}else if((P|0)==88){i=k;return u|0}return 0}function Xca(a){a=a|0;var b=0;b=c[a+60>>2]|0;kJb(c[b+16>>2]|0);kJb(c[b+28>>2]|0);kJb(c[b+40>>2]|0);VHb(b);return 0}function Yca(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+60>>2]|0;c[a+140>>2]=0;e=a+120|0;f=c[e>>2]|0;do{if((f&1|0)==0){g=a+124|0;h=c[g>>2]|0;if((h&1|0)!=0){break}j=d;c[j>>2]=hJb((ca(h,f)|0)/4|0)|0;h=d+28|0;k=h;c[k>>2]=hJb((ca((c[e>>2]|0)*3|0,c[g>>2]|0)|0)/2|0)|0;l=hJb((ca((c[e>>2]|0)*3|0,c[g>>2]|0)|0)/2|0)|0;m=d+32|0;c[m>>2]=l;do{if((c[j>>2]|0)!=0){n=c[k>>2]|0;if((n|0)==0|(l|0)==0){break}c[d+36>>2]=c[e>>2];o=(c[e>>2]|0)/2|0;c[d+44>>2]=o;c[d+40>>2]=o;c[d+4>>2]=n;o=ca(c[g>>2]|0,c[e>>2]|0)|0;c[d+12>>2]=n+o;p=(o|0)/4|0;q=p+o|0;c[d+20>>2]=n+q;c[d+8>>2]=l;n=d+16|0;c[n>>2]=l+o;r=d+24|0;c[r>>2]=l+q;mrc(l|0,0,o|0)|0;mrc(c[n>>2]|0,16,p|0)|0;mrc(c[r>>2]|0,16,(ca(c[g>>2]|0,c[e>>2]|0)|0)/4|0|0)|0;s=0;i=b;return s|0}}while(0);mJb(d);mJb(h);mJb(m);KIb(a,16,2248688,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-12;i=b;return s|0}}while(0);KIb(a,16,2299656,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=b;return s|0}function Zca(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;h=i;i=i+16|0;j=h|0;k=g+28|0;l=c[k>>2]|0;m=c[b+60>>2]|0;n=b+120|0;o=b+124|0;p=ca(c[o>>2]|0,c[n>>2]|0)|0;q=(p|0)/4|0;mrc(j|0,0,16)|0;r=c[m>>2]|0;if((l|0)<17){KIb(b,16,2454352,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}u=M4a(b,e,0)|0;if((u|0)<0){t=u;i=h;return t|0}u=c[g+24>>2]|0;g=c[k>>2]|0;k=g>>>0>268435455>>>0?-8:g<<3;g=k>>>0>2147483639>>>0|(u|0)==0;v=g?0:u;u=g?0:k;k=u+8|0;if(g){t=g?-1094995529:0;i=h;return t|0}g=m+4|0;w=m+12|0;x=m+20|0;y=c[m+36>>2]|0;z=c[m+40>>2]|0;A=c[m+44>>2]|0;B=m+8|0;C=m+16|0;D=m+24|0;a:do{if((p+3|0)>>>0>6>>>0){m=j|0;E=j+4|0;F=j+8|0;G=y+1|0;H=j+12|0;I=y<<1;J=(k|0)<128?k:128;K=c[x>>2]|0;L=0;M=0;N=16;O=16;P=-1;Q=0;R=r;S=c[w>>2]|0;T=c[g>>2]|0;U=c[D>>2]|0;V=c[C>>2]|0;W=c[B>>2]|0;b:while(1){do{if((P|0)==-1){if((u-J|0)<4){break b}X=((J|0)<(k|0))+J|0;if((d[v+(J>>>3)|0]&1<<(J&7)|0)!=0){Y=X;Z=17;break}_=v+(X>>>3)|0;$=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((X&7)>>>0)&7;_=X+3|0;X=k>>>0>_>>>0?_:k;if(($|0)!=0){aa=$;ba=X;Z=14;break}$=v+(X>>>3)|0;_=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((X&7)>>>0)&255;$=X+8|0;X=k>>>0>$>>>0?$:k;if((_|0)==0){$=v+(X>>>3)|0;da=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((X&7)>>>0)&32767;$=X+15|0;aa=(da|0)==0?-1:da+262|0;ba=k>>>0>$>>>0?$:k;Z=14;break}else{aa=_+7|0;ba=X;Z=14;break}}else{aa=P;ba=J;Z=14}}while(0);do{if((Z|0)==14){Z=0;if((aa|0)==(-1|0)){break b}else if((aa|0)==0){Y=ba;Z=17;break}c[m>>2]=d[W]|0;c[E>>2]=d[W+1|0]|0;c[F>>2]=d[W+y|0]|0;c[H>>2]=d[W+G|0]|0;ea=d[R]|0;fa=d[U]|0;ga=d[V]|0;ha=ba;ia=aa}}while(0);do{if((Z|0)==17){Z=0;X=((Y|0)<(k|0))+Y|0;_=v+(X>>>3)|0;do{if((d[v+(Y>>>3)|0]&1<<(Y&7)|0)==0){$=((X|0)<(k|0))+X|0;if((d[_]&1<<(X&7)|0)==0){ja=Q;ka=$;break}da=(($|0)<(k|0))+$|0;la=v+(da>>>3)|0;ma=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((da&7)>>>0);if((d[v+($>>>3)|0]&1<<($&7)|0)==0){$=da+3|0;na=(d[841864+(ma&7)|0]|0)+Q|0;oa=k>>>0>$>>>0?$:k}else{$=da+6|0;na=ma;oa=k>>>0>$>>>0?$:k}$=na&63;c[m>>2]=$;c[E>>2]=$;c[F>>2]=$;c[H>>2]=$;ja=$;ka=oa}else{$=_;ma=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((X&7)>>>0)&63;$=X+6|0;da=k>>>0>$>>>0?$:k;$=v+(da>>>3)|0;la=da+2|0;pa=k>>>0>la>>>0?la:k;la=v+(pa>>>3)|0;qa=pa+5|0;ra=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((pa&7)>>>0)<<1&62;pa=d[774824+((d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((da&7)>>>0)&3)|0]|0;da=(ca(a[566408+(ma<<2)|0]|0,pa)|0)+ra|0;if((da|0)<0){sa=0}else{sa=(da|0)>63?63:da}c[m>>2]=sa;da=(ca(a[566409+(ma<<2)|0]|0,pa)|0)+ra|0;if((da|0)<0){ta=0}else{ta=(da|0)>63?63:da}c[E>>2]=ta;da=(ca(a[566410+(ma<<2)|0]|0,pa)|0)+ra|0;if((da|0)<0){ua=0}else{ua=(da|0)>63?63:da}c[F>>2]=ua;da=(ca(a[566411+(ma<<2)|0]|0,pa)|0)+ra|0;if((da|0)<0){va=0}else{va=(da|0)>63?63:da}c[H>>2]=va;ja=ra;ka=k>>>0>qa>>>0?qa:k}}while(0);X=((ka|0)<(k|0))+ka|0;if((d[v+(ka>>>3)|0]&1<<(ka&7)|0)==0){ea=ja;fa=O;ga=N;ha=X;ia=0;break}_=((X|0)<(k|0))+X|0;qa=v+(_>>>3)|0;ra=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((_&7)>>>0);if((d[v+(X>>>3)|0]&1<<(X&7)|0)==0){X=ra&7;qa=_+3|0;ea=ja;fa=(d[1706440+X|0]|0)+O&31;ga=(d[1706432+X|0]|0)+N&31;ha=k>>>0>qa>>>0?qa:k;ia=0;break}else{qa=_+5|0;_=k>>>0>qa>>>0?qa:k;qa=v+(_>>>3)|0;X=_+5|0;ea=ja;fa=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((_&7)>>>0)&31;ga=ra&31;ha=k>>>0>X>>>0?X:k;ia=0;break}}}while(0);a[R]=ea;a[T]=c[m>>2];a[T+1|0]=c[E>>2];a[T+y|0]=c[F>>2];a[T+G|0]=c[H>>2];a[S]=ga;a[K]=fa;X=M+1|0;ra=X<<1;if((ra|0)==(c[n>>2]|0)){_=I-ra+2|0;qa=(ra|0)/2|0;ra=z-qa+1|0;da=A-qa+1|0;wa=W+_|0;xa=V+ra|0;ya=U+da|0;za=T+_|0;Aa=S+ra|0;Ba=0;Ca=K+da|0}else{wa=W+2|0;xa=V+1|0;ya=U+1|0;za=T+2|0;Aa=S+1|0;Ba=X;Ca=K+1|0}X=L+1|0;if(X>>>0<q>>>0){J=ha;K=Ca;L=X;M=Ba;N=ga;O=fa;P=ia-1|0;Q=ea;R=R+1|0;S=Aa;T=za;U=ya;V=xa;W=wa}else{break a}}KIb(b,16,2364928,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}}while(0);s=c[w>>2]|0;b=c[x>>2]|0;wa=c[e+4>>2]|0;xa=c[e+8>>2]|0;ya=c[o>>2]|0;do{if((ya|0)>0){za=e+32|0;Aa=c[e>>2]|0;ea=0;ia=c[g>>2]|0;fa=c[n>>2]|0;ga=ya;while(1){if((fa|0)>0){Ba=0;do{a[Aa+Ba|0]=a[ia+Ba|0]<<2;Ba=Ba+1|0;Da=c[n>>2]|0;}while((Ba|0)<(Da|0));Ea=Da;Fa=c[o>>2]|0}else{Ea=fa;Fa=ga}Ba=ea+1|0;if((Ba|0)<(Fa|0)){Aa=Aa+(c[za>>2]|0)|0;ea=Ba;ia=ia+y|0;fa=Ea;ga=Fa}else{break}}if((Fa|0)<=1){break}ga=e+36|0;fa=e+40|0;ia=xa;ea=wa;za=b;Aa=0;Ba=s;Ca=c[n>>2]|0;ha=Fa;while(1){if((Ca|0)>1){q=0;do{a[ea+q|0]=a[1704984+(d[Ba+q|0]|0)|0]|0;a[ia+q|0]=a[1704984+(d[za+q|0]|0)|0]|0;q=q+1|0;Ga=c[n>>2]|0;}while((q|0)<((Ga|0)/2|0|0));Ha=Ga;Ia=c[o>>2]|0}else{Ha=Ca;Ia=ha}q=Aa+1|0;if((q|0)<((Ia|0)/2|0|0)){ia=ia+(c[fa>>2]|0)|0;ea=ea+(c[ga>>2]|0)|0;za=za+A|0;Aa=q;Ba=Ba+z|0;Ca=Ha;ha=Ia}else{break}}}}while(0);Ia=c[g>>2]|0;c[g>>2]=c[B>>2];c[B>>2]=Ia;Ia=c[w>>2]|0;c[w>>2]=c[C>>2];c[C>>2]=Ia;Ia=c[x>>2]|0;c[x>>2]=c[D>>2];c[D>>2]=Ia;c[f>>2]=1;t=l;i=h;return t|0}function _ca(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b);mJb(b+28|0);mJb(b+32|0);return 0}function $ca(b){b=b|0;var d=0,e=0,f=0,h=0.0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0;d=c[b+60>>2]|0;c[b+416>>2]=1;e=b+448|0;c[e>>2]=4;c[e+4>>2]=0;c[b+420>>2]=3;g[d+116>>2]=.04800000041723251;g[d+156>>2]=0.0;g[d+120>>2]=.09600000083446503;g[d+160>>2]=0.0;g[d+124>>2]=.14399999380111694;g[d+164>>2]=0.0;g[d+128>>2]=.19200000166893005;g[d+168>>2]=0.0;g[d+132>>2]=.23999999463558197;g[d+172>>2]=0.0;g[d+136>>2]=.2879999876022339;g[d+176>>2]=0.0;g[d+140>>2]=.335999995470047;g[d+180>>2]=0.0;g[d+144>>2]=.3840000033378601;g[d+184>>2]=0.0;g[d+148>>2]=.4320000112056732;g[d+188>>2]=0.0;g[d+152>>2]=.47999998927116394;g[d+192>>2]=0.0;b=d+1788|0;e=d+1020|0;f=0;do{g[b+(f<<2)>>2]=0.0;g[e+(f<<2)>>2]=0.0;f=f+1|0;}while((f|0)<128);c[d+24>>2]=1;g[d+1008>>2]=40.0;g[d+2856>>2]=1.0;a[d+2865|0]=0;g[d+1016>>2]=0.0;g[d+1012>>2]=0.0;f=d+2300|0;d=0;e=0;while(1){h=(+(e|0)+-4.0)*.125;b=d;i=-8;while(1){j=h- +(i|0);k=j*2.827433388230814;if(k!=0.0){l=k;m=+V(l)*(+U(j*3.141592653589793*.11764705926179886)*.46+.54)/l*.8999999761581421}else{m=.8999999761581421}g[f+(b<<2)>>2]=m;n=i+1|0;if((n|0)<9){b=b+1|0;i=n}else{break}}i=e+1|0;if((i|0)<8){d=d+17|0;e=i}else{break}}return 0}function ada(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,U=0,V=0,W=0,X=0,Y=0.0,Z=0.0,_=0.0,aa=0.0,ba=0.0,da=0.0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0,qa=0.0,ra=0.0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0.0,ya=0,za=0.0,Aa=0.0,Ba=0.0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0.0,Ua=0.0,Va=0.0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0.0,gb=0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0.0,nb=0.0,ob=0.0,pb=0.0,qb=0.0,rb=0,sb=0.0;l=i;i=i+640|0;m=l|0;n=l+40|0;o=l+80|0;p=l+320|0;q=l+360|0;r=l+400|0;s=c[k+24>>2]|0;t=f+60|0;u=c[t>>2]|0;v=u;w=k+28|0;k=c[w>>2]|0;c[h+76>>2]=160;x=M4a(f,h,0)|0;if((x|0)<0){y=x;i=l;return y|0}x=h;h=c[x>>2]|0;switch(k|0){case 23:{z=4;A=8;break};case 10:{B=3;A=19;break};case 5:{B=2;A=19;break};case 0:{B=0;A=19;break};case 1:{C=0;D=d[s]|0;A=12;break};case 3:{z=1;A=8;break};case 22:{B=4;A=19;break};case 2:{B=1;A=19;break};case 6:{z=2;A=8;break};case 11:{z=3;A=8;break};default:{E=f;A=20}}do{if((A|0)==8){F=a[s]|0;G=F&255;if(!(z>>>0>G>>>0)){C=z;D=G;A=12;break}G=(c[t>>2]|0)+2866|0;if((a[G]|0)==0){KIb(f,24,2248640,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;a[G]=1;I=a[s]|0}else{I=F}J=I&255;A=14}else if((A|0)==19){KIb(f,48,2174264,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=B;L=k;M=s;A=21}}while(0);do{if((A|0)==12){if((C|0)>=(D|0)){J=C;A=14;break}B=f;KIb(B,16,2206568,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;E=B;A=20}}while(0);if((A|0)==14){K=J;L=k-1|0;M=s+1|0;A=21}else if((A|0)==20){s=u+20|0;c[s>>2]=-1;KIb(E,24,2299640,(H=i,i=i+16|0,c[H>>2]=c[f+428>>2],c[H+8>>2]=2454320,H)|0);i=H;N=s;A=110}a:do{if((A|0)==21){s=u+20|0;c[s>>2]=K;if((K|0)<1|(K|0)==2){N=s;A=110;break}E=(K|0)==1;do{if(E){if((c[u+24>>2]|0)!=4){break}if((a[u+2865|0]|0)==0){N=s;A=110;break a}}}while(0);k=L<<3;J=k>>>0>2147483639>>>0|(M|0)==0;C=J?0:M;D=J?0:k;c[u>>2]=C;c[u+12>>2]=D;k=D+8|0;c[u+16>>2]=k;c[u+4>>2]=C+(D>>3);D=u+8|0;c[D>>2]=0;J=u+28|0;mrc(J|0,0,46)|0;if((K|0)==3){B=C;I=(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)>>>1;B=k>>>0>7>>>0?7:k;c[D>>2]=B;t=I&127;b[u+30>>1]=t;I=C+(B>>>3)|0;z=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(B&7)>>>25;I=B+7|0;B=k>>>0>I>>>0?I:k;c[D>>2]=B;I=z&65535;b[u+32>>1]=I;z=C+(B>>>3)|0;F=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7)>>>24;z=B+8|0;B=k>>>0>z>>>0?z:k;c[D>>2]=B;b[u+34>>1]=F;F=C+(B>>>3)|0;z=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(B&7)>>>25;F=B+7|0;B=k>>>0>F>>>0?F:k;c[D>>2]=B;a[u+38|0]=z;z=C+(B>>>3)|0;F=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7)>>>29;z=B+3|0;B=k>>>0>z>>>0?z:k;c[D>>2]=B;a[u+40|0]=F;F=C+(B>>>3)|0;z=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(B&7)>>>22;F=B+10|0;B=k>>>0>F>>>0?F:k;c[D>>2]=B;b[u+44>>1]=z;z=C+(B>>>3)|0;F=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7)>>>28;z=B+4|0;B=k>>>0>z>>>0?z:k;c[D>>2]=B;a[u+68|0]=F;F=C+(B>>>3)|0;z=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(B&7)>>>29;F=B+3|0;B=k>>>0>F>>>0?F:k;c[D>>2]=B;a[u+41|0]=z;z=C+(B>>>3)|0;F=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7)>>>22;z=B+10|0;B=k>>>0>z>>>0?z:k;c[D>>2]=B;b[u+52>>1]=F;F=C+(B>>>3)|0;z=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(B&7)>>>28;F=B+4|0;B=k>>>0>F>>>0?F:k;c[D>>2]=B;a[u+69|0]=z;z=C+(B>>>3)|0;F=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7)>>>29;z=B+3|0;B=k>>>0>z>>>0?z:k;c[D>>2]=B;a[u+42|0]=F;F=C+(B>>>3)|0;z=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(B&7)>>>22;F=B+10|0;B=k>>>0>F>>>0?F:k;c[D>>2]=B;b[u+60>>1]=z;z=C+(B>>>3)|0;F=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7)>>>28;z=B+4|0;c[D>>2]=k>>>0>z>>>0?z:k;a[u+70|0]=F;O=t;P=I;Q=0}else if((K|0)==4){I=(d[C]|0)>>>7;t=(k|0)>0|0;c[D>>2]=t;a[J]=I;I=C;F=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<t>>>26;I=t|6;t=k>>>0>I>>>0?I:k;c[D>>2]=t;I=F&65535;b[u+30>>1]=I;F=C+(t>>>3)|0;z=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(t&7)>>>26;F=t+6|0;t=k>>>0>F>>>0?F:k;c[D>>2]=t;F=z&65535;b[u+32>>1]=F;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>23;z=t+9|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;b[u+34>>1]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>25;B=t+7|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;b[u+36>>1]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>25;z=t+7|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;a[u+38|0]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>27;B=t+5|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;a[u+39|0]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>29;z=t+3|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;a[u+40|0]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>24;B=t+8|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;b[u+44>>1]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>24;z=t+8|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;b[u+46>>1]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>24;B=t+8|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;b[u+48>>1]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>21;z=t+11|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;b[u+50>>1]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>27;B=t+5|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;a[u+68|0]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>29;z=t+3|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;a[u+41|0]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>24;B=t+8|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;b[u+52>>1]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>24;z=t+8|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;b[u+54>>1]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>24;B=t+8|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;b[u+56>>1]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>21;z=t+11|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;b[u+58>>1]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>27;B=t+5|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;a[u+69|0]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>29;z=t+3|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;a[u+42|0]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>24;B=t+8|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;b[u+60>>1]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>24;z=t+8|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;b[u+62>>1]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>24;B=t+8|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;b[u+64>>1]=z;z=C+(t>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>21;z=t+11|0;t=k>>>0>z>>>0?z:k;c[D>>2]=t;b[u+66>>1]=B;B=C+(t>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>27;B=t+5|0;t=k>>>0>B>>>0?B:k;c[D>>2]=t;a[u+70|0]=z;z=d[C+(t>>>3)|0]<<(t&7)>>>7;c[D>>2]=((t|0)<(k|0))+t;a[u+72|0]=z&1;O=I;P=F;Q=0}else if((K|0)==1){F=C;I=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>4;F=k>>>0>4>>>0?4:k;c[D>>2]=F;z=I&15;b[u+30>>1]=z;I=C+(F>>>3)|0;t=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(F&4)>>>28;I=F+4|0;F=k>>>0>I>>>0?I:k;c[D>>2]=F;I=t&65535;b[u+32>>1]=I;t=C+(F>>>3)|0;C=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(F&7)>>>24;t=F+8|0;c[D>>2]=k>>>0>t>>>0?t:k;k=C&255;a[u+71|0]=k;O=z;P=I;Q=k}else{O=0;P=0;Q=0}if(E){if(O<<16>>16==15&P<<16>>16==15&Q<<24>>24==-1){N=s;A=110;break}A=36}else{k=0;while(1){if(!(k>>>0<46>>>0)){break}if((a[u+(k+28)|0]|0)==0){k=k+1|0}else{break}}if((k|0)==46){N=s;A=110;break}if((K|0)==2|(K|0)==0){S=K}else{A=36}}if((A|0)==36){E=c[1506576+(K<<2)>>2]|0;I=0;z=0;C=K;while(1){t=a[(c[1506552+(C<<2)>>2]|0)+z|0]|0;D=t&255;F=c[E+(z<<2)>>2]|0;if(t<<24>>24==0){U=I;V=C}else{t=v+30+(z<<1)|0;B=D>>>0>1>>>0;G=0;W=I;while(1){g[v+76+(W<<2)>>2]=+g[F+((ca(e[t>>1]|0,D)|0)+G<<2)>>2];X=G+1|0;if((X|0)<(D|0)){G=X;W=W+1|0}else{break}}U=(B?D:1)+I|0;V=c[s>>2]|0}W=z+1|0;if((W|0)<(d[1490624+V|0]|0)){I=U;z=W;C=V}else{S=V;break}}}C=1;while(1){if((C|0)>=10){break}if(+g[v+76+(C<<2)>>2]>+g[v+76+(C-1<<2)>>2]){C=C+1|0}else{N=s;A=110;break a}}C=(d[1490624+S|0]|0)-1|0;z=1506552+(S<<2)|0;I=0;E=0;while(1){if((I|0)>=(C|0)){break}k=(d[(c[z>>2]|0)+I|0]|0)+E|0;if(+g[v+76+(k<<2)>>2]- +g[v+76+(k-1<<2)>>2]>.007957747154594767){I=I+1|0;E=k}else{N=s;A=110;break a}}if((S-3|0)>>>0<2>>>0){E=a[u+38|0]|0;if((E&255)>>>0>100>>>0){N=s;A=110;break}Y=+((E&255)+20|0);E=u+1004|0;g[E>>2]=Y;I=a[u+39|0]|0;do{if(I<<24>>24==0){Z=0.0;_=0.0;aa=0.0;ba=Y}else{da=+(I&255|0);if((~~(Y-da+16.0)-20|0)>>>0>100>>>0){N=s;A=110;break a}if((S|0)!=4){Z=0.0;_=0.0;aa=0.0;ba=Y;break}if((a[u+2865|0]|0)==0){Z=0.0;_=0.0;aa=0.0;ba=Y;break}z=u+1020|0;nrc(z|0,u+1788|0,512)|0;C=u+1008|0;ea=+g[C>>2];fa=ea-da+16.0;g[C>>2]=fa;k=+R(+(Y-ea))>15.0;da=k?Y:ea;k=z;W=u+1532|0;G=u+1012|0;t=0;ea=fa;fa=0.0;ga=.3312999904155731;while(1){F=d[552792+t|0]|0;ha=ea;ia=da*fa+ha*(1.0-fa);X=t+1|0;ja=da*ga+ha*(1.0-ga);ka=+g[1066176+(t+2<<2)>>2];la=da*ka+ha*(1.0-ka);ha=+g[G>>2];ma=+(F|0);na=1.0/ma;oa=na*(ja-ia);if(ma>0.0){pa=0;qa=0.0;do{ra=ia+oa*qa;sa=W+(pa<<2)|0;ta=Lc(+ra)|0;ua=~~((+(ta|0)-ra+.5)*8.0+.5);va=ua<<16>>16==8;wa=va?0:(ua<<16>>16)*17|0;g[sa>>2]=0.0;ua=pa-8-ta-(va<<31>>31)|0;va=0;ra=0.0;do{ra=ra+ +g[v+2300+(va+wa<<2)>>2]*+g[W+(ua+va<<2)>>2];g[sa>>2]=ra;va=va+1|0;}while((va|0)<17);pa=pa+1|0;qa=+(pa|0);}while(qa<ma)}qa=na*(la-ja);pa=~~ma;oa=+(pa|0);ra=ma+10.0;if(oa<ra){va=pa;xa=oa;while(1){oa=ja+qa*(xa-ma);pa=W+(va<<2)|0;sa=Lc(+oa)|0;ua=~~((+(sa|0)-oa+.5)*8.0+.5);wa=ua<<16>>16==8;ta=wa?0:(ua<<16>>16)*17|0;g[pa>>2]=0.0;ua=va-8-sa-(wa<<31>>31)|0;wa=0;oa=0.0;do{oa=oa+ +g[v+2300+(wa+ta<<2)>>2]*+g[W+(ua+wa<<2)>>2];g[pa>>2]=oa;wa=wa+1|0;}while((wa|0)<17);wa=va+1|0;oa=+(wa|0);if(oa<ra){va=wa;xa=oa}else{ya=0;break}}}else{ya=0}do{va=W+(ya<<2)|0;g[va>>2]=ha*+g[va>>2];ya=ya+1|0;}while((ya|0)<(F|0));orc(z|0,k+(F<<2)|0,512)|0;if((X|0)>=3){break}t=X;ea=+g[C>>2];fa=ga;ga=ka}Z=ia;_=ja;aa=la;ba=+g[E>>2]}}while(0);I=u+1008|0;if(+R(+(ba- +g[I>>2]))>15.0){g[I>>2]=ba}C=u+1016|0;g[C>>2]=0.0;t=u+1012|0;g[t>>2]=0.0;za=Z;Aa=_;Ba=aa;Ca=t;Da=C;Ea=u+2844|0;Fa=E;Ga=I}else{I=a[u+71|0]|0;C=u+2844|0;t=I&255;g[C>>2]=+T(+10.0,+(+g[1506600+(t*12|0)>>2]));g[u+2848>>2]=+T(+10.0,+(+g[1506604+(t*12|0)>>2]));g[u+2852>>2]=+T(+10.0,+(+g[1506608+(t*12|0)>>2]));a[u+2864|0]=I;za=20.0;Aa=20.0;Ba=20.0;Ca=u+1012|0;Da=u+1016|0;Ea=C;Fa=u+1004|0;Ga=u+1008|0}C=Ea;I=r;t=p|0;k=u+76|0;z=u+116|0;W=q|0;G=u+1020|0;D=G;B=u+1532|0;va=u+156|0;wa=r|0;pa=G;ua=u+44|0;ta=u+2856|0;sa=u+2865|0;Ha=q+4|0;Ia=q+8|0;Ja=q+12|0;Ka=q+16|0;La=q+20|0;Ma=q+24|0;Na=q+28|0;Oa=q+32|0;Pa=q+36|0;Y=Ba;ga=Aa;fa=za;Qa=0;Ra=h;while(1){mrc(I|0,0,240)|0;Sa=d[552792+Qa|0]|0;ea=+g[1066160+(Qa<<2)>>2];zlb(t,z,k,1.0-ea,ea,10);if((c[s>>2]|0)==1){Ta=fa;Ua=ga;Va=Y}else{ea=+g[Fa>>2];da=+g[1066176+(Qa<<2)>>2];ha=+g[Ga>>2];xa=+g[1066176+(Qa+1<<2)>>2];ra=+g[1066176+(Qa+2<<2)>>2];Ta=ea*da+ha*(1.0-da);Ua=ea*xa+ha*(1.0-xa);Va=ea*ra+ha*(1.0-ra)}Wa=Lc(+((Ua+Ta)*.5))|0;bda(t,W);do{if((a[J]|0)!=0){if((a[sa]|0)==0){break}g[W>>2]=+g[W>>2]*.75;g[Ha>>2]=+g[Ha>>2]*.5625;g[Ia>>2]=+g[Ia>>2]*.421875;g[Ja>>2]=+g[Ja>>2]*.31640625;g[Ka>>2]=+g[Ka>>2]*.2373046875;g[La>>2]=+g[La>>2]*.177978515625;g[Ma>>2]=+g[Ma>>2]*.13348388671875;g[Na>>2]=+g[Na>>2]*.1001129150390625;g[Oa>>2]=+g[Oa>>2]*.07508468627929688;g[Pa>>2]=+g[Pa>>2]*.056313514709472656}}while(0);Xa=c[s>>2]|0;if((Xa|0)==1){Ya=C+(Qa<<2)|0;Za=0;do{g[pa+(Za+128<<2)>>2]=+g[Ya>>2];Za=Za+1|0;}while((Za|0)<(Sa|0))}else{ra=+$(((Xa|0)==3?.5:.25)*+((d[u+(Qa+68)|0]|0)+1|0));Za=a[u+(Qa+40)|0]|0;Ya=Za&255;ha=+g[729312+(Ya<<2)>>2];g[Ca>>2]=ha/3.0+ +g[Ca>>2];g[Da>>2]=ra/3.0+ +g[Da>>2];ea=+(Sa|0);xa=1.0/ea;da=(Ua-Ta)*xa;if(ea>0.0){_a=0;ma=0.0;do{qa=Ta+da*ma;$a=B+(_a<<2)|0;ab=Lc(+qa)|0;bb=~~((+(ab|0)-qa+.5)*8.0+.5);cb=bb<<16>>16==8;db=cb?0:(bb<<16>>16)*17|0;g[$a>>2]=0.0;bb=_a-8-ab-(cb<<31>>31)|0;cb=0;qa=0.0;do{qa=qa+ +g[v+2300+(cb+db<<2)>>2]*+g[B+(bb+cb<<2)>>2];g[$a>>2]=qa;cb=cb+1|0;}while((cb|0)<17);_a=_a+1|0;ma=+(_a|0);}while(ma<ea)}ma=(Va-Ua)*xa;_a=~~ea;da=+(_a|0);qa=ea+10.0;if(da<qa){Xa=_a;ka=da;while(1){da=Ua+ma*(ka-ea);_a=B+(Xa<<2)|0;cb=Lc(+da)|0;$a=~~((+(cb|0)-da+.5)*8.0+.5);bb=$a<<16>>16==8;db=bb?0:($a<<16>>16)*17|0;g[_a>>2]=0.0;$a=Xa-8-cb-(bb<<31>>31)|0;bb=0;da=0.0;do{da=da+ +g[v+2300+(bb+db<<2)>>2]*+g[B+($a+bb<<2)>>2];g[_a>>2]=da;bb=bb+1|0;}while((bb|0)<17);bb=Xa+1|0;da=+(bb|0);if(da<qa){Xa=bb;ka=da}else{eb=0;break}}}else{eb=0}do{Xa=B+(eb<<2)|0;g[Xa>>2]=ha*+g[Xa>>2];eb=eb+1|0;}while((eb|0)<(Sa|0));Xa=ua+(Qa<<3)|0;if((c[s>>2]|0)==4){bb=b[ua+(Qa<<3)+6>>1]|0;_a=bb&65535;$a=_a>>>9&3;db=e[Xa>>1]|0;cb=db&127;X=($a>>>0)%5|0;F=(((cb>>>0)/11|0)*5|0)+X|0;ab=(((cb>>>0)%11|0)*5|0)+X|0;ka=(db&128|0)!=0?-1.0:1.0;g[r+(F<<2)>>2]=ka;if((ab|0)<(F|0)){g[r+(ab<<2)>>2]=-0.0-ka}else{F=r+(ab<<2)|0;g[F>>2]=ka+ +g[F>>2]}F=e[ua+(Qa<<3)+2>>1]|0;ab=F&127;db=(($a+1|0)>>>0)%5|0;X=(((ab>>>0)/11|0)*5|0)+db|0;cb=(((ab>>>0)%11|0)*5|0)+db|0;ka=(F&128|0)!=0?-1.0:1.0;g[r+(X<<2)>>2]=ka;if((cb|0)<(X|0)){g[r+(cb<<2)>>2]=-0.0-ka}else{X=r+(cb<<2)|0;g[X>>2]=ka+ +g[X>>2]}X=e[ua+(Qa<<3)+4>>1]|0;cb=X&127;F=(($a+2|0)>>>0)%5|0;db=(((cb>>>0)/11|0)*5|0)+F|0;ab=(((cb>>>0)%11|0)*5|0)+F|0;ka=(X&128|0)!=0?-1.0:1.0;g[r+(db<<2)>>2]=ka;if((ab|0)<(db|0)){g[r+(ab<<2)>>2]=-0.0-ka}else{db=r+(ab<<2)|0;g[db>>2]=ka+ +g[db>>2]}db=_a&127;g[r+((((db>>>0)/11|0)*5|0)+((($a+3|0)>>>0)%5|0)<<2)>>2]=(_a&256|0)!=0?-1.0:1.0;g[r+((((db>>>0)%11|0)*5|0)+((($a|4)>>>0)%5|0)<<2)>>2]=(bb&128)!=0?-1.0:1.0}else{bb=e[Xa>>1]|0;ka=(bb&512|0)!=0?-1.0:1.0;Xa=r+(((bb&7)*7|0)+4<<2)|0;g[Xa>>2]=+g[Xa>>2]+ka;Xa=r+(((bb>>>3&7)*7|0)+2<<2)|0;g[Xa>>2]=+g[Xa>>2]-ka;Xa=r+(((bb>>>6&7)*7|0)<<2)|0;g[Xa>>2]=+g[Xa>>2]+ka}if(Za<<24>>24==0){fb=.20000000298023224}else{fb=(Ya-6|0)>>>0<2>>>0?.8999999761581421:ha}if((Wa|0)<(Sa|0)){Xa=Wa;while(1){bb=r+(Xa<<2)|0;g[bb>>2]=+g[bb>>2]+fb*+g[r+(Xa-Wa<<2)>>2];bb=Xa+1|0;if((bb|0)<(Sa|0)){Xa=bb}else{gb=0;break}}}else{gb=0}do{Xa=pa+(gb+128<<2)|0;g[Xa>>2]=+g[Xa>>2]+ra*+g[r+(gb<<2)>>2];gb=gb+1|0;}while((gb|0)<(Sa|0));ra=+g[ta>>2]+.2;if(ra>1.0){hb=1.0}else{hb=ra}g[ta>>2]=hb}orc(G|0,D+(Sa<<2)|0,512)|0;cda(B,W,va,Sa,wa);dda(v,wa,W,Ra,Wa,704040+(c[s>>2]<<4)|0,Sa);Xa=Qa+1|0;if((Xa|0)<3){Y=Va;ga=Ua;fa=Ta;Qa=Xa;Ra=Ra+(Sa<<2)|0}else{break}}ib=0;jb=s;kb=u+24|0}}while(0);if((A|0)==110){KIb(f,24,2364912,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;H=u+20|0;f=0;while(1){Ta=+g[v+116+(f<<2)>>2];if((c[H>>2]|0)==1){g[v+76+(f<<2)>>2]=Ta;lb=f+1|0}else{A=f+1|0;g[v+76+(f<<2)>>2]=+(A|0)*.125*.048+Ta*.875;lb=A}if((lb|0)<10){f=lb}else{break}}if((a[u+2865|0]|0)!=0){lb=u+1012|0;g[lb>>2]=+g[lb>>2]*.75}if((c[H>>2]|0)==4){nrc(u+1788|0,u+1020|0,512)|0}lb=u+24|0;f=(c[lb>>2]|0)==1;c[H>>2]=f?1:4;if(f){f=d[u+2864|0]|0;Ta=+T(+10.0,+((+g[1506600+(f*12|0)>>2]+0.0+ +g[1506604+(f*12|0)>>2]+ +g[1506608+(f*12|0)>>2])/3.0));g[u+2844>>2]=Ta;g[u+2848>>2]=Ta;g[u+2852>>2]=Ta;mb=+g[u+1004>>2];nb=+g[u+1008>>2]}else{Ta=+g[u+1008>>2];g[u+1004>>2]=Ta;mb=Ta;nb=Ta}f=u+1004|0;A=u+1008|0;if(+R(+(mb-nb))>15.0){g[A>>2]=mb}gb=m|0;m=u+76|0;r=u+116|0;eb=n|0;n=u+1020|0;Da=u+1532|0;Ca=u+156|0;Ga=o|0;o=u+1012|0;Fa=u+1016|0;q=u+2856|0;mb=20.0;nb=20.0;Ta=20.0;p=0;Ea=h;while(1){h=d[552792+p|0]|0;Ua=+g[1066160+(p<<2)>>2];zlb(gb,r,m,1.0-Ua,Ua,10);do{if((c[H>>2]|0)==1){ob=Ta;pb=nb;qb=mb}else{if(+g[o>>2]<.3){ob=+g[1509720+(p<<2)>>2];pb=+g[1509720+(p+1<<2)>>2];qb=+g[1509720+(p+2<<2)>>2];break}else{Ua=+g[f>>2];Va=+g[1066176+(p<<2)>>2];hb=+g[A>>2];fb=+g[1066176+(p+1<<2)>>2];za=+g[1066176+(p+2<<2)>>2];ob=Ua*Va+hb*(1.0-Va);pb=Ua*fb+hb*(1.0-fb);qb=Ua*za+hb*(1.0-za);break}}}while(0);s=Lc(+((pb+ob)*.5))|0;bda(gb,eb);if((c[H>>2]|0)==1){ya=v+2844+(p<<2)|0;S=0;do{g[v+1020+(S+128<<2)>>2]=+g[ya>>2];S=S+1|0;}while((S|0)<(h|0))}else{za=+g[o>>2];hb=+(h|0);Ua=1.0/hb;fb=(pb-ob)*Ua;if(hb>0.0){S=0;Va=0.0;do{Aa=ob+fb*Va;ya=S+128|0;V=v+1020+(ya<<2)|0;U=Lc(+Aa)|0;K=~~((+(U|0)-Aa+.5)*8.0+.5);Q=K<<16>>16==8;P=Q?0:(K<<16>>16)*17|0;g[V>>2]=0.0;K=-8-U+ya-(Q<<31>>31)|0;Q=0;Aa=0.0;do{Aa=Aa+ +g[v+2300+(Q+P<<2)>>2]*+g[v+1020+(K+Q<<2)>>2];g[V>>2]=Aa;Q=Q+1|0;}while((Q|0)<17);S=S+1|0;Va=+(S|0);}while(Va<hb)}Va=(qb-pb)*Ua;S=~~hb;fb=+(S|0);Aa=hb+10.0;if(fb<Aa){Q=S;Ba=fb;while(1){fb=pb+Va*(Ba-hb);S=Q+128|0;V=v+1020+(S<<2)|0;K=Lc(+fb)|0;P=~~((+(K|0)-fb+.5)*8.0+.5);Sa=P<<16>>16==8;Wa=Sa?0:(P<<16>>16)*17|0;g[V>>2]=0.0;P=-8-K+S-(Sa<<31>>31)|0;Sa=0;fb=0.0;do{fb=fb+ +g[v+2300+(Sa+Wa<<2)>>2]*+g[v+1020+(P+Sa<<2)>>2];g[V>>2]=fb;Sa=Sa+1|0;}while((Sa|0)<17);Sa=Q+1|0;fb=+(Sa|0);if(fb<Aa){Q=Sa;Ba=fb}else{rb=0;break}}}else{rb=0}do{Q=v+1020+(rb+128<<2)|0;g[Q>>2]=za*+g[Q>>2];rb=rb+1|0;}while((rb|0)<(h|0));Q=0;za=+g[q>>2];do{Sa=v+1020+(Q+128<<2)|0;g[Sa>>2]=za*+g[Sa>>2];Q=Q+1|0;za=+g[q>>2]}while((Q|0)<(h|0));Ba=za+-.05;if(Ba>0.0){sb=Ba}else{sb=0.0}g[q>>2]=sb}orc(n|0,v+1020+(h<<2)|0,512)|0;do{if((c[H>>2]|0)==1){Q=v+2844+(p<<2)|0;Sa=0;do{g[v+1020+(Sa+128<<2)>>2]=+g[Q>>2];Sa=Sa+1|0;}while((Sa|0)<(h|0))}else{if(!(+g[o>>2]<.4)){break}Ba=+g[Fa>>2]*.1;Sa=0;do{Q=v+1020+(Sa+128<<2)|0;g[Q>>2]=Ba+ +g[Q>>2];Sa=Sa+1|0;}while((Sa|0)<(h|0))}}while(0);cda(Da,eb,Ca,h,Ga);dda(v,Ga,eb,Ea,s,704040+(c[H>>2]<<4)|0,h);Sa=p+1|0;if((Sa|0)<3){mb=qb;nb=pb;Ta=ob;p=Sa;Ea=Ea+(h<<2)|0}else{ib=1;jb=N;kb=lb;break}}}nrc(u+116|0,u+76|0,40)|0;a[u+2865|0]=ib;c[kb>>2]=c[jb>>2];if((c[jb>>2]|0)!=1){g[u+1008>>2]=+g[u+1004>>2]}u=c[x>>2]|0;x=0;do{jb=u+(x<<2)|0;g[jb>>2]=+g[jb>>2]*30517578125.0e-15;x=x+1|0;}while((x|0)<160);c[j>>2]=1;y=c[w>>2]|0;i=l;return y|0}function bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0.0,y=0,z=0.0,A=0,B=0,C=0.0,D=0,E=0.0;c=i;i=i+152|0;d=c|0;e=c+80|0;f=c+104|0;j=c+128|0;k=i;i=i+20|0;i=i+7&-8;l=i;i=i+20|0;i=i+7&-8;m=i;i=i+20|0;i=i+7&-8;mrc(j|0,0,20)|0;mrc(k|0,0,20)|0;mrc(l|0,0,20)|0;mrc(m|0,0,20)|0;yPa(d|0,a,10);a=e|0;n=f|0;o=e+20|0;p=f+20|0;q=0;while(1){r=(q|0)<2;s=r?.25:0.0;g[a>>2]=s;if(r){t=(q|0)<1?.25:-.25}else{t=0.0}g[n>>2]=t;r=0;u=s;s=t;while(1){v=r<<1;w=j+(r<<2)|0;x=+g[w>>2];y=k+(r<<2)|0;z=+g[y>>2]+(u- +h[d+(v<<3)>>3]*2.0*x);A=r+1|0;g[e+(A<<2)>>2]=z;B=l+(r<<2)|0;C=+g[B>>2];D=m+(r<<2)|0;E=+g[D>>2]+(s- +h[d+((v|1)<<3)>>3]*2.0*C);g[f+(A<<2)>>2]=E;g[y>>2]=x;g[w>>2]=u;g[D>>2]=C;g[B>>2]=s;if((A|0)<5){r=A;u=z;s=E}else{break}}if((q|0)==0){q=q+1|0;continue}else{g[b+(q-1<<2)>>2]=(+g[o>>2]+ +g[p>>2])*2.0;r=q+1|0;if((r|0)<11){q=r;continue}else{break}}}i=c;return}function cda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0.0,j=0,k=0,l=0,m=0.0;if((d|0)<=0){return}f=b+36|0;h=0;do{i=+g[a+(h<<2)>>2];j=e+(h<<2)|0;g[j>>2]=i;k=c+36|0;g[j>>2]=i- +g[f>>2]*+g[k>>2];l=c+32|0;i=+g[l>>2];g[k>>2]=i;g[j>>2]=+g[j>>2]- +g[b+32>>2]*i;k=c+28|0;i=+g[k>>2];g[l>>2]=i;g[j>>2]=+g[j>>2]- +g[b+28>>2]*i;l=c+24|0;i=+g[l>>2];g[k>>2]=i;g[j>>2]=+g[j>>2]- +g[b+24>>2]*i;k=c+20|0;i=+g[k>>2];g[l>>2]=i;g[j>>2]=+g[j>>2]- +g[b+20>>2]*i;l=c+16|0;i=+g[l>>2];g[k>>2]=i;g[j>>2]=+g[j>>2]- +g[b+16>>2]*i;k=c+12|0;i=+g[k>>2];g[l>>2]=i;g[j>>2]=+g[j>>2]- +g[b+12>>2]*i;l=c+8|0;i=+g[l>>2];g[k>>2]=i;g[j>>2]=+g[j>>2]- +g[b+8>>2]*i;k=c+4|0;i=+g[k>>2];g[l>>2]=i;g[j>>2]=+g[j>>2]- +g[b+4>>2]*i;i=+g[c>>2];g[k>>2]=i;m=+g[j>>2]- +g[b>>2]*i;g[j>>2]=m;g[c>>2]=m;h=h+1|0;}while((h|0)<(d|0));return}function dda(a,b,d,e,f,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0.0,P=0.0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0.0,da=0.0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0,ja=0,ka=0.0,la=0,ma=0,na=0.0,oa=0,pa=0.0,qa=0.0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0.0,Aa=0.0,Ba=0,Ca=0.0,Da=0;k=i;i=i+472|0;l=k|0;m=k+40|0;n=k+256|0;o=+g[h>>2];p=+g[h+8>>2];q=p;r=+g[d>>2];s=p*r;p=q*q;t=+g[d+4>>2];u=p*t;v=q*p;p=+g[d+8>>2];w=v*p;x=q*v;v=+g[d+12>>2];y=x*v;z=q*x;x=+g[d+16>>2];A=z*x;B=q*z;z=+g[d+20>>2];C=B*z;D=q*B;B=+g[d+24>>2];E=D*B;F=q*D;D=+g[d+28>>2];G=F*D;H=q*F;F=+g[d+32>>2];I=H*F;J=+g[d+36>>2];K=q*H*J;d=l|0;H=+g[h+12>>2];q=H;L=r*H;g[d>>2]=L;H=q*q;r=H*t;g[l+4>>2]=r;t=q*H;H=t*p;g[l+8>>2]=H;p=q*t;t=p*v;g[l+12>>2]=t;v=q*p;p=v*x;g[l+16>>2]=p;x=q*v;v=x*z;g[l+20>>2]=v;z=q*x;x=z*B;g[l+24>>2]=x;B=q*z;z=B*D;g[l+28>>2]=z;D=q*B;B=D*F;g[l+32>>2]=B;F=q*D*J;g[l+36>>2]=F;l=j-1|0;if((l|0)>0){J=0.0;M=0;D=+g[b>>2];while(1){N=M+1|0;q=+g[b+(N<<2)>>2];O=J+D*q;if((N|0)<(l|0)){J=O;M=N;D=q}else{break}}P=O<0.0?0.0:o}else{P=o}M=(j|0)>0;do{if(M){l=a+2860|0;N=0;o=+g[l>>2];while(1){O=+g[b+(N<<2)>>2];g[m+(N<<2)>>2]=O-P*o;g[l>>2]=O;Q=N+1|0;if((Q|0)<(j|0)){N=Q;o=O}else{break}}N=a+276|0;l=a+788|0;Q=a+196|0;if(!M){R=N;T=l;break}U=a+232|0;V=a+228|0;W=a+224|0;X=a+220|0;Y=a+216|0;Z=a+212|0;_=a+208|0;$=a+204|0;aa=a+200|0;ba=0;while(1){o=+g[m+(ba<<2)>>2];O=o+K*+g[U>>2];D=+g[V>>2];g[U>>2]=D;J=+g[W>>2];g[V>>2]=J;q=+g[X>>2];g[W>>2]=q;ca=+g[Y>>2];g[X>>2]=ca;da=+g[Z>>2];g[Y>>2]=da;ea=+g[_>>2];g[Z>>2]=ea;fa=+g[$>>2];g[_>>2]=fa;ga=+g[aa>>2];g[$>>2]=ga;ha=+g[Q>>2];g[aa>>2]=ha;g[Q>>2]=o;g[a+276+(ba+128<<2)>>2]=O+I*D+G*J+E*q+C*ca+A*da+y*ea+w*fa+u*ga+s*ha;ia=ba+1|0;if((ia|0)<(j|0)){ba=ia}else{R=N;T=l;break}}}else{R=a+276|0;T=a+788|0}}while(0);l=f-3|0;N=(l|0)<20?l:20;l=f+3|0;ba=(l|0)<120?120:l;l=j+128|0;a:do{if((N|0)>(ba|0)){ja=f}else{if(M){ka=0.0;la=N;ma=f}else{Q=N;while(1){aa=Q+1|0;if((aa|0)>(ba|0)){ja=f;break a}else{Q=aa}}}while(1){s=0.0;Q=128;do{s=s+ +g[a+276+(Q<<2)>>2]*+g[a+276+(Q-la<<2)>>2];Q=Q+1|0;}while((Q|0)<(l|0));Q=s>ka;aa=Q?la:ma;$=la+1|0;if(($|0)>(ba|0)){ja=aa;break}else{ka=Q?s:ka;la=$;ma=aa}}}}while(0);do{if(M){ka=0.0;ma=128;do{u=+g[a+276+(ma-ja<<2)>>2];ka=ka+u*u;ma=ma+1|0;}while((ma|0)<(l|0));if(M){na=0.0;oa=128}else{pa=0.0;qa=ka;break}while(1){u=na+ +g[a+276+(oa<<2)>>2]*+g[a+276+(oa-ja<<2)>>2];ma=oa+1|0;if((ma|0)<(l|0)){na=u;oa=ma}else{pa=u;qa=ka;break}}}else{pa=0.0;qa=0.0}}while(0);do{if(qa*pa==0.0){ra=24}else{if((c[a+20>>2]|0)==1){ra=24;break}na=pa/qa;if(na<.5){oa=n;l=j<<2;nrc(oa|0,T|0,l)|0;sa=oa;ta=l;break}if(M){ka=(na>1.0?1.0:na)*+g[h+4>>2];l=0;do{oa=l+128|0;g[n+(l<<2)>>2]=+g[a+276+(oa<<2)>>2]+ka*+g[a+276+(oa-ja<<2)>>2];l=l+1|0;}while((l|0)<(j|0))}sa=n;ta=j<<2}}while(0);if((ra|0)==24){ra=n;ja=j<<2;nrc(ra|0,T|0,ja)|0;sa=ra;ta=ja}nrc(m|0,sa|0,ta)|0;if(!M){ua=n|0;va=a+236|0;cda(ua,d,va,j,e);wa=R;xa=a+276+(j<<2)|0;ya=xa;orc(wa|0,ya|0,512)|0;i=k;return}ta=0;qa=+g[a+236>>2];pa=+g[a+240>>2];ka=+g[a+244>>2];na=+g[a+248>>2];u=+g[a+252>>2];w=+g[a+256>>2];y=+g[a+260>>2];A=+g[a+264>>2];C=+g[a+268>>2];E=+g[a+272>>2];while(1){sa=m+(ta<<2)|0;G=+g[sa>>2]-E*F-C*B-A*z-y*x-w*v-u*p-na*t-ka*H-pa*r-qa*L;g[sa>>2]=G;sa=ta+1|0;if((sa|0)<(j|0)){ta=sa;E=C;C=A;A=y;y=w;w=u;u=na;na=ka;ka=pa;pa=qa;qa=G}else{break}}if(M){za=0.0;Aa=0.0;Ba=0}else{ua=n|0;va=a+236|0;cda(ua,d,va,j,e);wa=R;xa=a+276+(j<<2)|0;ya=xa;orc(wa|0,ya|0,512)|0;i=k;return}do{qa=+g[b+(Ba<<2)>>2];Aa=Aa+qa*qa;qa=+g[m+(Ba<<2)>>2];za=za+qa*qa;Ba=Ba+1|0;}while((Ba|0)<(j|0));if(za!=0.0){Ca=+S(Aa/za)}else{Ca=1.0}if(M){Da=0}else{ua=n|0;va=a+236|0;cda(ua,d,va,j,e);wa=R;xa=a+276+(j<<2)|0;ya=xa;orc(wa|0,ya|0,512)|0;i=k;return}do{M=n+(Da<<2)|0;g[M>>2]=Ca*+g[M>>2];Da=Da+1|0;}while((Da|0)<(j|0));ua=n|0;va=a+236|0;cda(ua,d,va,j,e);wa=R;xa=a+276+(j<<2)|0;ya=xa;orc(wa|0,ya|0,512)|0;i=k;return}function eda(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;j=i;i=i+40|0;l=j|0;m=j+8|0;n=j+24|0;o=j+32|0;p=o;q=c[h+24>>2]|0;c[l>>2]=q;r=c[h+28>>2]|0;h=q+r|0;s=c[b+60>>2]|0;t=e;c[m>>2]=t;c[m+4>>2]=0;c[m+8>>2]=0;u=s+40|0;v=s+36|0;w=v;x=s+48|0;y=s+44|0;z=s+52|0;A=s+56|0;B=s+16|0;C=B;D=B;B=s+20|0;E=s+24|0;F=s+28|0;G=s+12|0;H=G;I=s+92|0;mrc(G|0,-1|0,20)|0;mrc(v|0,-1|0,24)|0;c[I>>2]=0;v=s+8|0;c[v>>2]=-1;c[s+76>>2]=q;c[s+84>>2]=r;if(r>>>0<10>>>0){KIb(b,16,2454288,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}q=c[l>>2]|0;G=q+4|0;c[l>>2]=G;L=q;M=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;if((M|0)!=20000630){KIb(b,16,2364888,(J=i,i=i+8|0,c[J>>2]=M,J)|0);i=J;K=-1094995529;i=j;return K|0}M=q+5|0;c[l>>2]=M;L=a[G]|0;if(!(L<<24>>24==2)){RIb(b,2299624,(J=i,i=i+8|0,c[J>>2]=L&255,J)|0);i=J;K=-1163346256;i=j;return K|0}L=q+8|0;c[l>>2]=L;if(!((a[M]&2)==0)){RIb(b,2248624,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1163346256;i=j;return K|0}a:do{if(L>>>0<h>>>0){M=s+104|0;q=b;G=s+88|0;N=b+224|0;O=h;P=0;Q=0;R=0;S=L;b:while(1){if((a[S]|0)==0){T=P;U=Q;V=R;W=S;break a}do{if((gda(b,l,h,2206552,2174256,38,n)|0)>-1){X=c[n>>2]|0;if((X|0)==0){K=-1094995529;Y=112;break b}Z=c[l>>2]|0;_=Z+X|0;$=_;if((X|0)>18){X=P;aa=Z;while(1){Z=c[M>>2]|0;do{if((a[Z]|0)==0){ba=aa}else{da=lrc(Z|0)|0;if((krc(aa,Z,da)|0)!=0){ba=aa;break}ea=aa+da|0;if((a[ea]|0)==46){fa=aa+(da+1)|0}else{fa=ea}KIb(q,32,2122920,(J=i,i=i+16|0,c[J>>2]=Z,c[J+8>>2]=fa,J)|0);i=J;ba=fa}}while(0);do{if((irc(ba,2640632)|0)==0){ga=0}else{if((irc(ba,2617904)|0)==0){ga=0;break}if((irc(ba,2590440)|0)==0){ga=0;break}if((irc(ba,2568824)|0)==0){ga=1;break}if((irc(ba,2550824)|0)==0){ga=1;break}if((irc(ba,2532552)|0)==0){ga=1;break}if((irc(ba,2517264)|0)==0){ga=2;break}if((irc(ba,2503296)|0)==0){ga=2;break}if((irc(ba,2490120)|0)==0){ga=2;break}if((irc(ba,2479256)|0)==0){ga=3;break}KIb(q,24,2469424,(J=i,i=i+8|0,c[J>>2]=c[l>>2],J)|0);i=J;ga=-1}}while(0);Z=c[l>>2]|0;while(1){ha=Z+1|0;c[l>>2]=ha;if((a[Z]|0)!=0&ha>>>0<_>>>0){Z=ha}else{break}}if(($-ha|0)<4){Y=34;break b}c[l>>2]=Z+5;ea=ha;da=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0;if(da>>>0>2>>>0){Y=36;break b}ea=Z+13|0;c[l>>2]=ea;ia=Z+9|0;ja=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;c[l>>2]=Z+17;ia=ea;ka=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;if(!((ja|0)==1&(ka|0)==1)){Y=38;break b}if((ga|0)>-1){ia=c[H>>2]|0;if(!((ia|0)==-1|(ia|0)==(da|0))){Y=41;break b}c[H>>2]=da;c[C+(ga<<2)>>2]=X}ia=c[G>>2]|0;ea=(c[I>>2]|0)+1|0;c[I>>2]=ea;la=jJb(ia,ea,12)|0;ea=la;c[G>>2]=ea;if((la|0)==0){K=-12;Y=112;break b}la=(c[I>>2]|0)-1|0;c[ea+(la*12|0)+8>>2]=da;c[ea+(la*12|0)>>2]=1;c[ea+(la*12|0)+4>>2]=1;la=(1<<da)+X|0;da=c[l>>2]|0;if(($-da|0)>18){X=la;aa=da}else{ma=la;break}}}else{ma=P}na=c[D>>2]|0;oa=c[B>>2]|0;aa=(na|0)>(oa|0)?oa:na;X=c[E>>2]|0;if((((aa|0)>(X|0)?X:aa)|0)<0){Y=46;break b}c[l>>2]=_;pa=R;qa=Q;ra=ma;sa=_}else{if((gda(b,l,h,2389800,2382880,31,n)|0)>-1){aa=c[n>>2]|0;if((aa|0)==0){K=-1094995529;Y=112;break b}X=c[l>>2]|0;$=X;la=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;c[u>>2]=la;$=X+4|0;da=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;c[x>>2]=da;$=X+8|0;ea=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;c[w>>2]=ea;$=X+12|0;ia=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;c[y>>2]=ia;c[z>>2]=ea+1-la;c[A>>2]=ia+1-da;da=X+aa|0;c[l>>2]=da;pa=R;qa=Q;ra=P;sa=da;break}if((gda(b,l,h,2376216,2382880,34,n)|0)>-1){da=c[n>>2]|0;if((da|0)==0){K=-1094995529;Y=112;break b}aa=c[l>>2]|0;X=aa+8|0;ia=(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24)+1|0;X=aa+12|0;la=(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24)+1|0;X=aa+da|0;c[l>>2]=X;pa=ia;qa=la;ra=P;sa=X;break}if((gda(b,l,h,2369568,2369568,25,n)|0)>-1){X=c[n>>2]|0;if((X|0)==0){K=-1094995529;Y=112;break b}KIb(q,48,2354840,(J=i,i=i+8|0,c[J>>2]=d[c[l>>2]|0]|0,J)|0);i=J;la=c[l>>2]|0;if((d[la]|0)>>>0>2>>>0){Y=63;break b}ia=la+X|0;c[l>>2]=ia;pa=R;qa=Q;ra=P;sa=ia;break}if((gda(b,l,h,2339872,2334096,31,n)|0)>-1){ia=c[n>>2]|0;if((ia|0)==0){K=-1094995529;Y=112;break b}X=c[l>>2]|0;AKb(p,(c[k>>2]=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24,+g[k>>2]),255);X=c[o+4>>2]|0;c[N>>2]=c[o>>2];c[N+4>>2]=X;X=(c[l>>2]|0)+ia|0;c[l>>2]=X;pa=R;qa=Q;ra=P;sa=X;break}if((gda(b,l,h,2328840,2328840,29,n)|0)>-1){X=c[n>>2]|0;if((X|0)==0){K=-1094995529;Y=112;break b}if((c[v>>2]|0)==-1){ia=c[l>>2]|0;c[v>>2]=d[ia]|0;ta=ia}else{KIb(q,24,2322976,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;ta=c[l>>2]|0}ia=ta+X|0;c[l>>2]=ia;pa=R;qa=Q;ra=P;sa=ia;break}ia=c[l>>2]|0;if((O-ia|0)<10){Y=75;break b}else{ua=ia}while(1){ia=ua+1|0;c[l>>2]=ia;if(!(ia>>>0<h>>>0)){va=ia;break}if((a[ia]|0)==0){va=ia;break}else{ua=ia}}while(1){_=va+1|0;c[l>>2]=_;if(!(_>>>0<h>>>0)){break}if((a[_]|0)==0){break}else{va=_}}_=va+2|0;c[l>>2]=_;if((O-_|0)<=4){pa=R;qa=Q;ra=P;sa=_;break}ia=va+6|0;c[l>>2]=ia;X=_;_=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;X=_>>>0<(O-ia|0)>>>0?_:0;c[n>>2]=X;if((X|0)==0){Y=79;break b}_=va+(X+6)|0;c[l>>2]=_;pa=R;qa=Q;ra=P;sa=_}}while(0);if(sa>>>0<h>>>0){P=ra;Q=qa;R=pa;S=sa}else{T=ra;U=qa;V=pa;W=sa;break a}}if((Y|0)==34){KIb(q,16,2460232,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==36){KIb(q,16,2443576,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==38){RIb(q,2431096,(J=i,i=i+16|0,c[J>>2]=ja,c[J+8>>2]=ka,J)|0);i=J;K=-1163346256;i=j;return K|0}else if((Y|0)==41){KIb(q,16,2420800,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==46){if((na|0)<0){KIb(q,16,2411576,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;wa=c[B>>2]|0}else{wa=oa}if((wa|0)<0){KIb(q,16,2403960,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}if((c[E>>2]|0)>=0){K=-1094995529;i=j;return K|0}KIb(q,16,2396776,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==63){KIb(q,16,2345880,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==75){KIb(q,16,2460232,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==79){KIb(q,16,2460232,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((Y|0)==112){i=j;return K|0}}else{T=0;U=0;V=0;W=L}}while(0);if((c[v>>2]|0)==-1){KIb(b,16,2317952,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}if(!(W>>>0<h>>>0)){KIb(b,16,2313200,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}c[l>>2]=W+1;W=c[H>>2]|0;if((W|0)==2|(W|0)==1){H=b+140|0;c[H>>2]=(c[F>>2]>>31&-250)+292;F=c[v>>2]|0;switch(F|0){case 0:case 1:case 2:{c[s+72>>2]=1;break};case 5:case 3:{c[s+72>>2]=16;break};case 4:{c[s+72>>2]=32;break};default:{RIb(b,2292472,(J=i,i=i+8|0,c[J>>2]=F,J)|0);i=J;K=-1163346256;i=j;return K|0}}F=c[u>>2]|0;u=c[w>>2]|0;do{if(!(F>>>0>u>>>0)){w=c[y>>2]|0;if((c[x>>2]|0)>>>0>w>>>0){break}if(!((c[z>>2]|0)==(1-F+u|0)&u>>>0<V>>>0&w>>>0<U>>>0)){break}w=H4a(b,V,U)|0;if((w|0)<0){K=w;i=j;return K|0}w=qKb(c[H>>2]|0)|0;c[s+32>>2]=w;L=ca(d[w+4|0]|0,c[b+120>>2]<<1)|0;w=s+64|0;c[w>>2]=ca(c[z>>2]|0,T)|0;c[w+4>>2]=0;w=c[s+72>>2]|0;Y=(((c[A>>2]|0)-1+w|0)>>>0)/(w>>>0)|0;do{if((c[v>>2]|0)!=0){w=s+100|0;E=c[w>>2]|0;wa=c[b+808>>2]|0;oa=wa*24|0;do{if(wa>>>0>65535>>>0){if(((oa>>>0)/(wa>>>0)|0|0)==24){break}else{K=-22}i=j;return K|0}}while(0);wa=s+96|0;B=wJb(c[wa>>2]|0,w,oa)|0;na=B;if((B|0)==0){K=-12;i=j;return K|0}else{c[wa>>2]=na;mrc(na+(E*24|0)|0,0,(c[w>>2]|0)-E|0)|0;break}}}while(0);q=J5a(b,m,0)|0;if((q|0)<0){K=q;i=j;return K|0}q=c[l>>2]|0;if((h-q|0)<(Y<<3|0)){K=-1094995529;i=j;return K|0}c[s+80>>2]=q;q=c[e>>2]|0;if((c[x>>2]|0)==0){xa=q}else{na=e+32|0;wa=0;B=q;while(1){mrc(B|0,0,L|0)|0;q=B+(c[na>>2]|0)|0;ka=wa+1|0;if(ka>>>0<(c[x>>2]|0)>>>0){wa=ka;B=q}else{xa=q;break}}}c[s+4>>2]=t;Xe[c[b+828>>2]&511](b,130,c[s+96>>2]|0,0,Y)|0;B=(c[y>>2]|0)+1|0;wa=b+124|0;if((B|0)<(c[wa>>2]|0)){na=e+32|0;q=xa;ka=B;while(1){mrc(q|0,0,L|0)|0;B=ka+1|0;if((B|0)<(c[wa>>2]|0)){q=q+(c[na>>2]|0)|0;ka=B}else{break}}}c[e+88>>2]=1;c[f>>2]=1;K=r;i=j;return K|0}}while(0);KIb(b,16,2285456,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}else if((W|0)==0){QIb(b,2308544,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1163346256;i=j;return K|0}else{KIb(b,16,2303488,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1094995529;i=j;return K|0}return 0}function fda(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;a=b+100|0;d=b+96|0;if(!((c[a>>2]|0)>>>0>23>>>0)){mJb(d);c[a>>2]=0;e=b+88|0;mJb(e);return 0}f=d;g=0;do{h=c[f>>2]|0;mJb(h+(g*24|0)|0);mJb(h+(g*24|0)+8|0);mJb(h+(g*24|0)+16|0);mJb(h+(g*24|0)+20|0);g=g+1|0;}while(g>>>0<(((c[a>>2]|0)>>>0)/24|0)>>>0);mJb(d);c[a>>2]=0;e=b+88|0;mJb(e);return 0}function gda(a,b,e,f,g,h,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=c[b>>2]|0;m=e;if((m-l|0)>>>0<h>>>0){n=-1;i=k;return n|0}if((irc(l,f)|0)!=0){n=-1;i=k;return n|0}h=lrc(f|0)|0;e=h+1|0;o=l+e|0;c[b>>2]=o;if((irc(o,g)|0)!=0){c[b>>2]=l+(e+~(lrc(f|0)|0));KIb(a,24,2268088,(p=i,i=i+8|0,c[p>>2]=f,p)|0);i=p;n=-1;i=k;return n|0}f=h+2+(lrc(g|0)|0)|0;g=l+(f+4)|0;c[b>>2]=g;b=l+f|0;f=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=f>>>0<(m-g|0)>>>0?f:0;c[j>>2]=b;if((b|0)!=0){n=1;i=k;return n|0}KIb(a,16,2460232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=1;i=k;return n|0}function hda(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0;g=i;i=i+488|0;k=g|0;l=g+8|0;m=g+480|0;n=c[f+60>>2]|0;o=c[n+4>>2]|0;p=c[n+96>>2]|0;q=p+(j*24|0)|0;r=n+52|0;s=c[r>>2]|0;t=n+32|0;u=d[(c[t>>2]|0)+4|0]|0;v=ca((c[f+120>>2]|0)+2147483647-(c[n+36>>2]|0)<<1,u)|0;f=n+40|0;w=ca(c[f>>2]<<1,u)|0;u=c[n+84>>2]|0;x=(c[n+80>>2]|0)+(h<<3)|0;h=x|0;z=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=x+4|0;x=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=u-8|0;A=(h|0)<0|0?-1:0;if(x>>>0>A>>>0|x>>>0==A>>>0&z>>>0>h>>>0){B=-1094995529;i=g;return B|0}h=c[n+76>>2]|0;A=z;C=A+8|0;D=h+C|0;E=h+A|0;F=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;if(F>>>0<(c[n+48>>2]|0)>>>0){B=-1094995529;i=g;return B|0}E=n+44|0;H=c[E>>2]|0;if(F>>>0>H>>>0){B=-1094995529;i=g;return B|0}I=h+(A+4)|0;J=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;if((J|0)<1|(J|0)>(u|0)){B=-1094995529;i=g;return B|0}I=n+72|0;K=c[I>>2]|0;L=H-F+1|0;H=K>>>0>L>>>0?L:K;K=n+60|0;c[K>>2]=H;L=n+64|0;M=Erc(H,(H|0)<0|0?-1:0,c[L>>2]|0,c[L+4>>2]|0)|0;H=G;N=n+8|0;O=J;P=(J|0)<0|0?-1:0;do{if((c[N>>2]|0)==0){if(!((O|0)==(M|0)&(P|0)==(H|0))){B=-1094995529;i=g;return B|0}Q=xrc(u,(u|0)<0|0?-1:0,M,H)|0;R=G;if(x>>>0>R>>>0|x>>>0==R>>>0&z>>>0>Q>>>0){B=-1094995529}else{break}i=g;return B|0}else{if(P>>>0>H>>>0|P>>>0==H>>>0&O>>>0>M>>>0){B=-1094995529;i=g;return B|0}Q=u-J|0;R=(Q|0)<0|0?-1:0;if(x>>>0>R>>>0|x>>>0==R>>>0&z>>>0>Q>>>0){B=-1094995529}else{break}i=g;return B|0}}while(0);z=(J|0)<0|0?-1:0;if(z>>>0<H>>>0|z>>>0==H>>>0&J>>>0<M>>>0){H=q|0;z=M;A4a(q,p+(j*24|0)+4|0,z);q=p+(j*24|0)+8|0;A4a(q,p+(j*24|0)+12|0,z);if((c[H>>2]|0)==0){B=-12;i=g;return B|0}M=c[q>>2]|0;if((M|0)==0){B=-12;i=g;return B|0}a:do{switch(c[N>>2]|0){case 2:case 3:{c[m>>2]=z;if(!((Aqc(M,m,D,J)|0)==0&(c[m>>2]|0)==(z|0))){break a}x=c[q>>2]|0;u=x+z|0;if((z|0)>1){O=x+1|0;P=a[x]|0;do{P=(a[O]|0)+P&255^-128;a[O]=P;O=O+1|0;}while(O>>>0<u>>>0);S=c[q>>2]|0}else{S=x}u=c[H>>2]|0;O=u+z|0;if((z|0)<=0){break a}P=S+((z+1|0)/2|0)|0;Q=u;u=S;while(1){R=Q+1|0;a[Q]=a[u]|0;if(!(R>>>0<O>>>0)){break a}T=Q+2|0;a[R]=a[P]|0;if(T>>>0<O>>>0){P=P+1|0;Q=T;u=u+1|0}else{break}}break};case 5:{c[k>>2]=z;u=(Aqc(M,k,D,J)|0)==0;if(!(u&(c[k>>2]|0)==(z|0))){break a}u=c[K>>2]|0;if((u|0)<=0){break a}Q=n+92|0;P=n+88|0;O=c[H>>2]|0;x=0;T=M;R=c[Q>>2]|0;U=u;while(1){if((R|0)>0){u=O;V=0;W=T;while(1){X=c[(c[P>>2]|0)+(V*12|0)+8>>2]|0;do{if((X|0)==2){Y=c[r>>2]|0;Z=Y<<1;_=W+(Z+Y)|0;if((Y|0)==0){$=_;aa=u;break}ba=u;da=0;ea=W+Z|0;Z=W+Y|0;Y=W;fa=0;while(1){ga=(d[Z]<<16|d[Y]<<24|d[ea]<<8)+fa|0;ha=ba;y=ga;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;ha=ba+4|0;ia=da+1|0;if(ia>>>0<(c[r>>2]|0)>>>0){ba=ha;da=ia;ea=ea+1|0;Z=Z+1|0;Y=Y+1|0;fa=ga}else{$=_;aa=ha;break}}}else if((X|0)==1){_=c[r>>2]|0;fa=W+(_<<1)|0;if((_|0)==0){$=fa;aa=u;break}Y=u;Z=0;ea=W+_|0;_=W;da=0;while(1){ba=(d[_]<<8|d[ea])+da|0;ha=Y;y=ba&65535;a[ha]=y;y=y>>8;a[ha+1|0]=y;ha=Y+2|0;ga=Z+1|0;if(ga>>>0<(c[r>>2]|0)>>>0){Y=ha;Z=ga;ea=ea+1|0;_=_+1|0;da=ba}else{$=fa;aa=ha;break}}}else{$=W;aa=u}}while(0);X=V+1|0;ja=c[Q>>2]|0;if((X|0)<(ja|0)){u=aa;V=X;W=$}else{break}}ka=aa;la=$;ma=ja;na=c[K>>2]|0}else{ka=O;la=T;ma=R;na=U}W=x+1|0;if((W|0)<(na|0)){O=ka;x=W;T=la;R=ma;U=na}else{break}}break};case 4:{U=M;R=p+(j*24|0)+16|0;T=c[R>>2]|0;if((T|0)==0){x=hJb(8192)|0;c[R>>2]=x;oa=x}else{oa=T}T=p+(j*24|0)+20|0;x=c[T>>2]|0;if((x|0)==0){O=hJb(131072)|0;c[T>>2]=O;pa=c[R>>2]|0;qa=O}else{pa=oa;qa=x}if((pa|0)==0|(qa|0)==0){break a}if(!((J|0)>-1)){KIb(0,0,2281448,(x=i,i=i+24|0,c[x>>2]=2277376,c[x+8>>2]=2273016,c[x+16>>2]=135,x)|0);i=x;Hd();return 0}x=h+(J+C)|0;O=x;if((J|0)<2){ra=0;sa=D}else{Q=D;ra=(d[Q]|d[Q+1|0]<<8)<<16>>16&65535;sa=h+(A+10)|0}if((O-sa|0)<2){ta=sa;ua=0}else{Q=sa;P=(d[Q]|d[Q+1|0]<<8)<<16>>16;if((P&65535)>>>0>8191>>>0){break a}else{ta=sa+2|0;ua=P&65535}}mrc(pa|0,0,(ra>>>0>8192>>>0?8192:ra)|0)|0;if(ra>>>0>ua>>>0){va=ta}else{P=ua-ra+1|0;Q=O-ta|0;W=Q>>>0>P>>>0?P:Q;nrc((c[R>>2]|0)+ra|0,ta|0,W)|0;va=ta+W|0}mrc((c[R>>2]|0)+ua|0,0,8192-ua|0)|0;W=c[R>>2]|0;R=c[T>>2]|0;Q=0;P=0;while(1){if((Q|0)==0){wa=39}else{if((d[W+(Q>>3)|0]&1<<(Q&7)|0)==0){xa=P}else{wa=39}}if((wa|0)==39){wa=0;b[R+(P<<1)>>1]=Q;xa=P+1|0}V=Q+1|0;if((V|0)<65536){Q=V;P=xa}else{break}}mrc(R+(xa<<1)|0,0,65536-xa<<1|0)|0;P=xa+65535&65535;Q=z>>>1;if((O-va|0)<4){ya=0;za=va}else{W=va;ya=d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0;za=va+4|0}if((O-za|0)<4){Aa=0;Ba=za}else{W=za;Aa=d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0;Ba=za+4|0}if((O-Ba|0)<4){Ca=0;Da=Ba}else{W=Ba;Ca=d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0;Da=Ba+4|0}W=O-Da|0;V=W>>>0>4>>>0?4:W;W=Da+V|0;if((O-W|0)<4){Ea=0;Fa=W}else{u=W;Ea=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;Fa=Da+(V+4)|0}if(Aa>>>0>65536>>>0|Ca>>>0>65536>>>0|(ya|0)<0){break a}V=O-Fa|0;u=V>>>0>4>>>0?4:V;V=Fa+u|0;W=qJb(65537,8)|0;X=W;fa=qJb(16384,12)|0;da=fa;_=(fa|0)==0;b:do{if((W|0)==0|_){Ga=-12}else{ea=O-V|0;Z=ea>>>0>268435455>>>0?-8:ea<<3;Y=Z>>>0>2147483639>>>0|(V|0)==0;ha=Y?0:V;ba=Y?8:Z+8|0;Z=(Aa|0)>(Ca|0);if(Z){Ha=0}else{Y=Ca+1|0;ga=0;ia=Aa;while(1){Ia=ha+(ga>>>3)|0;Ja=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(ga&7);Ia=Ja>>>26;Ka=ga+6|0;La=ba>>>0>Ka>>>0?Ka:ba;Ka=X+(ia<<3)|0;c[Ka>>2]=Ia;c[Ka+4>>2]=0;do{if((Ia|0)==63){Ma=ha+(La>>>3)|0;Na=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(La&7)>>>24;Ma=La+8|0;if((ia+6+Na|0)>(Y|0)){Ga=-1094995529;break b}mrc(Ka|0,0,(Na<<3)+48|0)|0;Oa=ia+5+Na|0;Pa=ba>>>0>Ma>>>0?Ma:ba}else{if(!(Ja>>>0>3959422975>>>0)){Oa=ia;Pa=La;break}Ma=Ia-57|0;if((Ma+ia|0)>(Y|0)){Ga=-1094995529;break b}if((Ma|0)==0){Qa=ia}else{mrc(Ka|0,0,(Ia<<3)-456|0)|0;Qa=ia-57+Ia|0}Oa=Qa-1|0;Pa=La}}while(0);La=Oa+1|0;if((La|0)>(Ca|0)){Ha=Pa;break}else{ga=Pa;ia=La}}}ia=(Ha+7|0)/8|0;ga=ea>>>0>ia>>>0?ia:ea;mrc(l|0,0,472)|0;ia=0;do{Y=l+(c[X+(ia<<3)>>2]<<3)|0;ba=wrc(c[Y>>2]|0,c[Y+4>>2]|0,1,0)|0;c[Y>>2]=ba;c[Y+4>>2]=G;ia=ia+1|0;}while((ia|0)<65537);ia=ga+u|0;ea=58;Y=0;ba=0;while(1){ha=l+(ea<<3)|0;La=wrc(c[ha>>2]|0,c[ha+4>>2]|0,ba,Y)|0;Ia=G;c[ha>>2]=ba;c[ha+4>>2]=Y;ha=ea-1|0;if((ha|0)>0){ea=ha;Y=Ia>>>1|0<<31;ba=La>>>1|Ia<<31}else{break}}ba=Fa+ia|0;Y=0;do{ea=X+(Y<<3)|0;ga=c[ea>>2]|0;if((ga|0)>0){Ia=l+(ga<<3)|0;La=c[Ia>>2]|0;ha=c[Ia+4>>2]|0;Ka=wrc(La,ha,1,0)|0;c[Ia>>2]=Ka;c[Ia+4>>2]=G;c[ea>>2]=La<<6|0>>>26|ga;c[ea+4>>2]=ha<<6|La>>>26|((ga|0)<0|0?-1:0)}Y=Y+1|0;}while((Y|0)<65537);if(Ea>>>0>O-ba<<3>>>0){Ga=-1094995529;break}if(!Z){Y=Aa;do{ga=X+(Y<<3)|0;La=c[ga>>2]|0;ha=c[ga+4>>2]|0;ga=La>>>6|ha<<26;ea=ha>>>6|0<<26;ha=La&63;La=zrc(ga|0,ea|0,ha|0)|0;if(!((La|0)==0&(G|0)==0)){Ga=-1094995529;break b}do{if(ha>>>0>14>>>0){La=zrc(ga|0,ea|0,ha-14|0)|0;Ia=La;if((c[da+(Ia*12|0)>>2]|0)!=0){Ga=-1094995529;break b}La=da+(Ia*12|0)+4|0;Ka=(c[La>>2]|0)+1|0;c[La>>2]=Ka;Ja=da+(Ia*12|0)+8|0;Ia=jJb(c[Ja>>2]|0,Ka,4)|0;Ka=Ia;c[Ja>>2]=Ka;if((Ia|0)==0){Ga=-12;break b}c[Ka+((c[La>>2]|0)-1<<2)>>2]=Y}else{if((ha|0)==0){break}La=14-ha|0;Ka=1<<La;if((Ka|0)<=0){break}Ia=yrc(ga|0,ea|0,La|0)|0;La=Ka;Ka=da+(Ia*12|0)|0;while(1){Ia=Ka|0;if((c[Ia>>2]|0)!=0){Ga=-1094995529;break b}if((c[Ka+8>>2]|0)!=0){Ga=-1094995529;break b}c[Ia>>2]=ha;c[Ka+4>>2]=Y;Ia=La-1|0;if((Ia|0)>0){La=Ia;Ka=Ka+12|0}else{break}}}}while(0);Y=Y+1|0;}while((Y|0)<=(Ca|0))}Y=U+(Q<<1)|0;Z=Fa+(((Ea+7|0)/8|0)+ia)|0;if((Ea|0)>0){ha=0;ea=0;ga=0;Ka=U;La=ba;Ia=ba;while(1){if((O-La|0)<1){Ra=0;Sa=0;Ta=La;Ua=Ia}else{Ja=La+1|0;Ra=0;Sa=d[La]|0;Ta=Ja;Ua=Ja}Ja=Sa|(ga<<8|0>>>24);Ma=Ra|(ea<<8|ga>>>24);Na=ha+8|0;c:do{if((Na|0)>13){Va=Na;Wa=Ma;Xa=Ja;Ya=Ka;Za=Ta;_a=Ua;while(1){$a=Va;ab=Ya;while(1){bb=zrc(Xa|0,Wa|0,$a-14|0)|0;cb=bb&16383;bb=c[da+(cb*12|0)>>2]|0;db=c[da+(cb*12|0)+4>>2]|0;eb=c[da+(cb*12|0)+8>>2]|0;if((bb|0)==0){wa=103;break}fb=$a-bb|0;if((db|0)==(Ca|0)){wa=93;break}if(!(ab>>>0<Y>>>0)){Ga=-1094995529;break b}bb=ab+2|0;b[ab>>1]=db;if((fb|0)>13){$a=fb;ab=bb}else{gb=fb;hb=bb;ib=Wa;jb=Xa;kb=Za;lb=_a;break c}}do{if((wa|0)==93){wa=0;if((fb|0)<8){if((O-_a|0)<1){mb=0;nb=0;ob=_a}else{mb=0;nb=d[_a]|0;ob=_a+1|0}pb=mb|(Wa<<8|Xa>>>24);qb=nb|(Xa<<8|0>>>24);rb=fb+8|0;sb=ob;tb=ob}else{pb=Wa;qb=Xa;rb=fb;sb=Za;tb=_a}bb=rb-8|0;cb=zrc(qb|0,pb|0,bb|0)|0;if((ab+((cb&255)<<1)|0)>>>0>Y>>>0){Ga=-1094995529;break b}ub=cb&255;if(ub<<24>>24==0){vb=ab;wb=pb;xb=qb;yb=bb;zb=sb;Ab=tb;break}cb=b[ab-2>>1]&255;Bb=ub;Cb=ab;while(1){Db=Bb-1&255;b[Cb>>1]=cb;if(Db<<24>>24==0){break}else{Bb=Db;Cb=Cb+2|0}}vb=ab+((ub-1&255)+1<<1)|0;wb=pb;xb=qb;yb=bb;zb=sb;Ab=tb}else if((wa|0)==103){wa=0;if((eb|0)==0){Ga=-1094995529;break b}d:do{if((db|0)>0){Cb=$a;Bb=0;cb=Wa;Db=Xa;Eb=Za;Fb=_a;while(1){Gb=c[eb+(Bb<<2)>>2]|0;Hb=X+(Gb<<3)|0;Ib=c[Hb>>2]|0;Jb=c[Hb+4>>2]|0;Hb=Ib&63;e:do{if((Cb|0)<(Hb|0)){Kb=Cb;Lb=cb;Mb=Db;Nb=Eb;Ob=Fb;while(1){if((x|0)==(Nb|0)){Pb=Kb;Qb=Lb;Rb=Mb;Sb=x;Tb=Ob;break e}if((O-Ob|0)<1){Ub=0;Vb=0;Wb=Ob}else{Ub=0;Vb=d[Ob]|0;Wb=Ob+1|0}Xb=Vb|(Mb<<8|0>>>24);Yb=Ub|(Lb<<8|Mb>>>24);Zb=Kb+8|0;if((Zb|0)<(Hb|0)){Kb=Zb;Lb=Yb;Mb=Xb;Nb=Wb;Ob=Wb}else{_b=Zb;$b=Yb;ac=Xb;bc=Wb;cc=Wb;wa=110;break}}}else{_b=Cb;$b=cb;ac=Db;bc=Eb;cc=Fb;wa=110}}while(0);if((wa|0)==110){wa=0;dc=_b-Hb|0;Ob=zrc(ac|0,$b|0,dc|0)|0;Nb=G;Mb=yrc(1,0,Hb|0)|0;Lb=wrc(Mb,G,-1,-1)|0;if((Ib>>>6|Jb<<26|0)==(Ob&Lb|0)&(Jb>>>6|0<<26|0)==(Nb&G|0)){break}else{Pb=_b;Qb=$b;Rb=ac;Sb=bc;Tb=cc}}Nb=Bb+1|0;if((Nb|0)<(db|0)){Cb=Pb;Bb=Nb;cb=Qb;Db=Rb;Eb=Sb;Fb=Tb}else{ec=ab;fc=Qb;gc=Rb;hc=Pb;ic=Nb;jc=Sb;kc=Tb;break d}}if((Gb|0)!=(Ca|0)){if(!(ab>>>0<Y>>>0)){Ga=-1094995529;break b}b[ab>>1]=Gb;ec=ab+2|0;fc=$b;gc=ac;hc=dc;ic=Bb;jc=bc;kc=cc;break}if((dc|0)<8){if((O-bc|0)<1){lc=0;mc=0;nc=bc;oc=cc}else{Fb=bc+1|0;lc=0;mc=d[bc]|0;nc=Fb;oc=Fb}pc=lc|($b<<8|ac>>>24);qc=mc|(ac<<8|0>>>24);rc=dc+8|0;sc=nc;tc=oc}else{pc=$b;qc=ac;rc=dc;sc=bc;tc=cc}Fb=rc-8|0;Eb=zrc(qc|0,pc|0,Fb|0)|0;if((ab+((Eb&255)<<1)|0)>>>0>Y>>>0){Ga=-1094995529;break b}Db=Eb&255;if(Db<<24>>24==0){ec=ab;fc=pc;gc=qc;hc=Fb;ic=Bb;jc=sc;kc=tc;break}Eb=b[ab-2>>1]&255;cb=Db;Cb=ab;while(1){Nb=cb-1&255;b[Cb>>1]=Eb;if(Nb<<24>>24==0){break}else{cb=Nb;Cb=Cb+2|0}}ec=ab+((Db-1&255)+1<<1)|0;fc=pc;gc=qc;hc=Fb;ic=Bb;jc=sc;kc=tc}else{ec=ab;fc=Wa;gc=Xa;hc=$a;ic=0;jc=Za;kc=_a}}while(0);if((ic|0)==(db|0)){Ga=-1094995529;break b}else{vb=ec;wb=fc;xb=gc;yb=hc;zb=jc;Ab=kc}}}while(0);if((yb|0)>13){Va=yb;Wa=wb;Xa=xb;Ya=vb;Za=zb;_a=Ab}else{gb=yb;hb=vb;ib=wb;jb=xb;kb=zb;lb=Ab;break}}}else{gb=Na;hb=Ka;ib=Ma;jb=Ja;kb=Ta;lb=Ua}}while(0);if(kb>>>0<Z>>>0){ha=gb;ea=ib;ga=jb;Ka=hb;La=kb;Ia=lb}else{uc=gb;vc=ib;wc=jb;xc=hb;yc=kb;break}}}else{uc=0;vc=0;wc=0;xc=U;yc=ba}Ia=-Ea&7;La=uc-Ia|0;f:do{if((La|0)>0){Ka=zrc(wc|0,vc|0,Ia|0)|0;ga=La;ea=G;ha=Ka;Ka=xc;Z=yc;while(1){ia=ga;Ja=Ka;while(1){Ma=yrc(ha|0,ea|0,14-ia|0)|0;Na=Ma&16383;Ma=c[da+(Na*12|0)>>2]|0;_a=c[da+(Na*12|0)+4>>2]|0;if((Ma|0)==0){Ga=-1094995529;break b}zc=ia-Ma|0;if((_a|0)==(Ca|0)){break}if(!(Ja>>>0<Y>>>0)){Ga=-1094995529;break b}Ma=Ja+2|0;b[Ja>>1]=_a;if((zc|0)>0){ia=zc;Ja=Ma}else{Ac=Ma;break f}}if((zc|0)<8){if((O-Z|0)<1){Bc=0;Cc=0;Dc=Z}else{Bc=0;Cc=d[Z]|0;Dc=Z+1|0}Ec=Bc|(ea<<8|ha>>>24);Fc=Cc|(ha<<8|0>>>24);Gc=zc+8|0;Hc=Dc}else{Ec=ea;Fc=ha;Gc=zc;Hc=Z}ia=Gc-8|0;Ma=zrc(Fc|0,Ec|0,ia|0)|0;if((Ja+((Ma&255)<<1)|0)>>>0>Y>>>0){Ga=-1094995529;break b}_a=Ma&255;if(_a<<24>>24==0){Ic=Ja}else{Ma=b[Ja-2>>1]&255;Na=_a;Za=Ja;while(1){Ya=Na-1&255;b[Za>>1]=Ma;if(Ya<<24>>24==0){break}else{Na=Ya;Za=Za+2|0}}Ic=Ja+((_a-1&255)+1<<1)|0}if((ia|0)>0){ga=ia;ea=Ec;ha=Fc;Ka=Ic;Z=Hc}else{Ac=Ic;break}}}else{Ac=xc}}while(0);Ga=(Ac-M>>1|0)==(Q|0)?0:-1094995529}}while(0);if(!_){O=0;do{mJb(da+(O*12|0)+8|0);O=O+1|0;}while((O|0)<16384)}kJb(W);kJb(fa);if((Ga|0)!=0){break a}O=n+92|0;da=c[O>>2]|0;if((da|0)>0){_=c[n+88>>2]|0;x=c[r>>2]|0;X=c[K>>2]|0;u=(P&65535)>>>0<16384>>>0;V=(x|0)>(X|0)?X:x;R=0;Y=U;do{La=c[_+(R*12|0)+8>>2]|0;Ia=ca(La,x)|0;if((La|0)>0){ba=Ia+La|0;Z=0;do{Ka=1;while(1){if((Ka|0)>(V|0)){break}else{Ka=Ka<<1}}ha=Y+(Z<<1)|0;ea=Ka>>2;if((ea|0)>0){ga=Ka>>1;Za=ea;while(1){ea=ca(X-ga|0,Ia)|0;Na=Y+(ea+Z<<1)|0;Ma=ca(Za,Ia)|0;Ya=ca(ga,Ia)|0;Xa=ca(Za,La)|0;Wa=ca(ga,La)|0;if((ea|0)<0){Jc=ha}else{ea=ca(x-ga|0,La)|0;Va=(Za&x|0)==0;$a=ca(Za,ba)|0;ab=(ea|0)<0;bb=ha;while(1){ub=bb+(ea<<1)|0;if(ab){Kc=bb}else{if(u){Cb=bb;while(1){cb=Cb+(Xa<<1)|0;Eb=Cb+(Ma<<1)|0;Nb=Cb+($a<<1)|0;Lb=b[Eb>>1]|0;Ob=(Lb&1)+(b[Cb>>1]|0)+(Lb>>1)|0;Mb=b[Nb>>1]|0;Kb=(Mb&1)+(b[cb>>1]|0)+(Mb>>1)|0;Xb=Kb<<16;Yb=Xb>>16;Zb=(Xb>>17)+(Ob<<16>>16)+(Yb&1)|0;b[Cb>>1]=Zb;b[cb>>1]=Zb-Yb;Yb=Kb-Mb<<16;Mb=Yb>>16;Kb=(Yb>>17)+(Ob-Lb<<16>>16)+(Mb&1)|0;b[Eb>>1]=Kb;b[Nb>>1]=Kb-Mb;Mb=Cb+(Wa<<1)|0;if(Mb>>>0>ub>>>0){Kc=Mb;break}else{Cb=Mb}}}else{Cb=bb;while(1){Mb=Cb+(Xa<<1)|0;Kb=Cb+(Ma<<1)|0;Nb=Cb+($a<<1)|0;Eb=e[Kb>>1]|0;Lb=(e[Cb>>1]|0)-(Eb>>>1)|0;Ob=e[Nb>>1]|0;Yb=(e[Mb>>1]|0)-(Ob>>>1)|0;Zb=Ob+32768+Yb|0;Ob=(Eb+32768+Lb&65535)-(Zb>>>1&32767)|0;b[Mb>>1]=Ob;b[Cb>>1]=Zb+32768+Ob;Ob=(Lb&65535)-(Yb>>>1&32767)|0;b[Nb>>1]=Ob;b[Kb>>1]=Yb+32768+Ob;Ob=Cb+(Wa<<1)|0;if(Ob>>>0>ub>>>0){Kc=Ob;break}else{Cb=Ob}}}}if(!Va){Cb=Kc+(Ma<<1)|0;ub=b[Kc>>1]|0;Ob=b[Cb>>1]|0;if(u){Yb=Ob<<16>>16;Kb=(Yb&1)+(ub<<16>>16)+(Yb>>1)|0;b[Cb>>1]=Kb-Yb;Lc=Kb&65535}else{Kb=Ob&65535;Ob=(ub&65535)-(Kb>>>1)|0;b[Cb>>1]=Ob;Lc=Kb+32768+Ob&65535}b[Kc>>1]=Lc}Ob=bb+(Ya<<1)|0;if(Ob>>>0>Na>>>0){Jc=Ob;break}else{bb=Ob}}}do{if((Za&X|0)!=0){bb=ca(x-ga|0,La)|0;Na=Jc+(bb<<1)|0;if((bb|0)<0){break}if(u){bb=Jc;do{Ya=bb+(Xa<<1)|0;Ma=b[Ya>>1]|0;Va=(Ma&1)+(b[bb>>1]|0)+(Ma>>1)|0;b[Ya>>1]=Va-Ma;b[bb>>1]=Va;bb=bb+(Wa<<1)|0;}while(!(bb>>>0>Na>>>0))}else{bb=Jc;do{Va=bb+(Xa<<1)|0;Ma=e[Va>>1]|0;Ya=(e[bb>>1]|0)-(Ma>>>1)|0;b[Va>>1]=Ya;b[bb>>1]=Ma+32768+Ya;bb=bb+(Wa<<1)|0;}while(!(bb>>>0>Na>>>0))}}}while(0);Wa=Za>>1;if((Wa|0)>0){ga=Za;Za=Wa}else{break}}}Z=Z+1|0;}while((Z|0)<(La|0))}Y=Y+((ca(Ia,X)|0)<<1)|0;R=R+1|0;}while((R|0)<(da|0))}R=c[T>>2]|0;if((Q|0)!=0){X=0;do{Y=U+(X<<1)|0;b[Y>>1]=b[R+(e[Y>>1]<<1)>>1]|0;X=X+1|0;}while((X|0)<(Q|0))}Q=c[K>>2]|0;if((Q|0)<=0){break a}X=0;R=c[H>>2]|0;T=da;Y=Q;while(1){if((T|0)>0){Q=0;u=R;x=c[r>>2]|0;V=Y;while(1){nrc(u|0,U+((ca((ca(Q,V)|0)+X|0,x)|0)<<1)|0,x<<1)|0;_=c[r>>2]|0;P=u+(_<<1)|0;fa=Q+1|0;W=c[O>>2]|0;La=c[K>>2]|0;if((fa|0)<(W|0)){Q=fa;u=P;x=_;V=La}else{Mc=P;Nc=W;Oc=La;break}}}else{Mc=R;Nc=T;Oc=Y}V=X+1|0;if((V|0)<(Oc|0)){X=V;R=Mc;T=Nc;Y=Oc}else{break}}break};case 1:{Y=M+z|0;if((J|0)>0){T=M;R=D;X=J;O=z;while(1){U=R+1|0;da=a[R]|0;V=da<<24>>24;do{if(da<<24>>24<0){x=V+O|0;if((x|0)<0){break a}u=-V|0;Q=X-1+V|0;if((Q|0)<0){break a}if(da<<24>>24==0){Pc=x;Qc=Q;Rc=U;Sc=T;break}else{Tc=T;Uc=U;Vc=u}while(1){Ia=Vc-1|0;a[Tc]=a[Uc]|0;if((Ia|0)==0){break}else{Tc=Tc+1|0;Uc=Uc+1|0;Vc=Ia}}Pc=x;Qc=Q;Rc=R+(1-V)|0;Sc=T+u|0}else{Ia=V+1|0;La=O-Ia|0;if((La|0)<0){break a}W=X-2|0;if((W|0)<0){break a}if((Ia|0)==0){Wc=T}else{P=T;_=Ia;while(1){fa=_-1|0;a[P]=a[U]|0;if((fa|0)==0){break}else{P=P+1|0;_=fa}}Wc=T+Ia|0}Pc=La;Qc=W;Rc=R+2|0;Sc=Wc}}while(0);if((Qc|0)>0){T=Sc;R=Rc;X=Qc;O=Pc}else{Xc=Sc;break}}}else{Xc=M}if((Y|0)!=(Xc|0)){break a}O=c[q>>2]|0;X=O+z|0;if((z|0)>1){R=O+1|0;T=a[O]|0;do{T=(a[R]|0)+T&255^-128;a[R]=T;R=R+1|0;}while(R>>>0<X>>>0);Yc=c[q>>2]|0}else{Yc=O}X=c[H>>2]|0;R=X+z|0;if((z|0)<=0){break a}T=Yc+((z+1|0)/2|0)|0;Y=X;X=Yc;while(1){U=Y+1|0;a[Y]=a[X]|0;if(!(U>>>0<R>>>0)){break a}V=Y+2|0;a[U]=a[T]|0;if(V>>>0<R>>>0){T=T+1|0;Y=V;X=X+1|0}else{break}}break};default:{}}}while(0);Zc=c[H>>2]|0}else{Zc=D}D=Zc+(ca(c[n+16>>2]|0,s)|0)|0;H=Zc+(ca(c[n+20>>2]|0,s)|0)|0;Yc=Zc+(ca(c[n+24>>2]|0,s)|0)|0;z=c[n+28>>2]|0;if((z|0)>-1){_c=Zc+(ca(z,s)|0)|0}else{_c=0}z=o+32|0;if((c[I>>2]|0)<=0){B=0;i=g;return B|0}Zc=ca(c[z>>2]|0,F)|0;q=n+12|0;n=(s|0)==0;Xc=0;M=(c[o>>2]|0)+Zc|0;Zc=D;D=H;H=Yc;Yc=_c;_c=0;while(1){if((_c+F|0)>>>0>(c[E>>2]|0)>>>0){B=0;wa=271;break}o=(Yc|0)!=0;Sc=o?Yc:Xc;mrc(M|0,0,w|0)|0;Pc=M+((ca(d[(c[t>>2]|0)+4|0]|0,c[f>>2]|0)|0)<<1)|0;do{if((c[q>>2]|0)==2){if(n){$c=Pc;ad=Sc;break}else{bd=Zc;cd=D;dd=H;ed=Sc;fd=Pc;gd=0}while(1){Qc=bd+4|0;Rc=bd;Wc=d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0;Rc=Wc>>>23;do{if(Wc>>>0<931135488>>>0){hd=0}else{if(Wc>>>0>1065353215>>>0){hd=-1;break}hd=(Wc&8388607|8388608)>>>((134-Rc|0)>>>0)&65535}}while(0);Rc=fd+2|0;b[fd>>1]=hd;Wc=cd+4|0;W=cd;La=d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0;W=La>>>23;do{if(La>>>0<931135488>>>0){id=0}else{if(La>>>0>1065353215>>>0){id=-1;break}id=(La&8388607|8388608)>>>((134-W|0)>>>0)&65535}}while(0);W=fd+4|0;b[Rc>>1]=id;La=dd+4|0;Ia=dd;Vc=d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0;Ia=Vc>>>23;do{if(Vc>>>0<931135488>>>0){jd=0}else{if(Vc>>>0>1065353215>>>0){jd=-1;break}jd=(Vc&8388607|8388608)>>>((134-Ia|0)>>>0)&65535}}while(0);Ia=fd+6|0;b[W>>1]=jd;if(o){Vc=ed+4|0;Rc=ed;Uc=d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0;Rc=Uc>>>23;do{if(Uc>>>0<931135488>>>0){kd=0}else{if(Uc>>>0>1065353215>>>0){kd=-1;break}kd=(Uc&8388607|8388608)>>>((134-Rc|0)>>>0)&65535}}while(0);b[Ia>>1]=kd;ld=fd+8|0;md=Vc}else{ld=Ia;md=ed}Rc=gd+1|0;if(Rc>>>0<s>>>0){bd=Qc;cd=Wc;dd=La;ed=md;fd=ld;gd=Rc}else{$c=ld;ad=md;break}}}else{if(n){$c=Pc;ad=Sc;break}else{nd=Zc;od=D;pd=H;qd=Sc;rd=Pc;sd=0}while(1){Rc=nd+2|0;Uc=nd;W=(d[Uc]|d[Uc+1|0]<<8)<<16>>16;Uc=(W&65535)>>>10;Tc=14-Uc|0;do{if(Tc>>>0>13>>>0){if((Uc|0)==0){td=(W&65535)>>>9&1;break}else{td=((W&65535)>>>15)-1&65535;break}}else{td=(W<<6&65535|65536)>>>((Tc+1|0)>>>0)&65535}}while(0);Tc=rd+2|0;b[rd>>1]=td;W=od+2|0;Uc=od;La=(d[Uc]|d[Uc+1|0]<<8)<<16>>16;Uc=(La&65535)>>>10;Wc=14-Uc|0;do{if(Wc>>>0>13>>>0){if((Uc|0)==0){ud=(La&65535)>>>9&1;break}else{ud=((La&65535)>>>15)-1&65535;break}}else{ud=(La<<6&65535|65536)>>>((Wc+1|0)>>>0)&65535}}while(0);Wc=rd+4|0;b[Tc>>1]=ud;La=pd+2|0;Uc=pd;Qc=(d[Uc]|d[Uc+1|0]<<8)<<16>>16;Uc=(Qc&65535)>>>10;Ia=14-Uc|0;do{if(Ia>>>0>13>>>0){if((Uc|0)==0){vd=(Qc&65535)>>>9&1;break}else{vd=((Qc&65535)>>>15)-1&65535;break}}else{vd=(Qc<<6&65535|65536)>>>((Ia+1|0)>>>0)&65535}}while(0);Ia=rd+6|0;b[Wc>>1]=vd;if(o){Qc=qd+2|0;Uc=qd;Tc=(d[Uc]|d[Uc+1|0]<<8)<<16>>16;Uc=(Tc&65535)>>>10;Vc=14-Uc|0;do{if(Vc>>>0>13>>>0){if((Uc|0)==0){wd=(Tc&65535)>>>9&1;break}else{wd=((Tc&65535)>>>15)-1&65535;break}}else{wd=(Tc<<6&65535|65536)>>>((Vc+1|0)>>>0)&65535}}while(0);b[Ia>>1]=wd;xd=rd+8|0;yd=Qc}else{xd=Ia;yd=qd}Vc=sd+1|0;if(Vc>>>0<s>>>0){nd=Rc;od=W;pd=La;qd=yd;rd=xd;sd=Vc}else{$c=xd;ad=yd;break}}}}while(0);mrc($c|0,0,v|0)|0;Pc=c[L>>2]|0;if(o){zd=Yc+Pc|0}else{zd=0}Sc=_c+1|0;if((Sc|0)>=(c[I>>2]|0)){B=0;wa=271;break}Xc=ad;M=M+(c[z>>2]|0)|0;Zc=Zc+Pc|0;D=D+Pc|0;H=H+Pc|0;Yc=zd;_c=Sc}if((wa|0)==271){i=g;return B|0}return 0}function ida(a){a=a|0;var c=0,d=0,e=0,f=0,h=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0.0,E=0.0;c=i;i=i+256|0;d=c|0;e=0;while(1){f=b[a+(e<<1)>>1]|0;h=e|7;j=b[a+(h<<1)>>1]|0;k=+(j+f|0);l=f-j|0;m=+(l|0);j=e|1;f=b[a+(j<<1)>>1]|0;n=e|6;o=b[a+(n<<1)>>1]|0;p=+(o+f|0);q=f-o|0;o=e|2;f=b[a+(o<<1)>>1]|0;r=e|5;s=b[a+(r<<1)>>1]|0;t=+(s+f|0);u=f-s|0;s=e|3;f=b[a+(s<<1)>>1]|0;v=e|4;w=b[a+(v<<1)>>1]|0;x=+(w+f|0);y=k+x;z=k-x;x=p+t;g[d+(e<<2)>>2]=x+y;g[d+(v<<2)>>2]=y-x;x=(p-t+z)*.7071067811865476;g[d+(o<<2)>>2]=z+x;g[d+(n<<2)>>2]=z-x;x=+(u+f-w|0);z=+(q+l|0);t=x*.9238795325112867-z*.3826834323650898;p=z*.9238795325112867+x*.3826834323650898;x=+(u+q|0)*.7071067811865476;z=m+x;y=m-x;g[d+(r<<2)>>2]=y+t;g[d+(s<<2)>>2]=y-t;g[d+(j<<2)>>2]=z+p;g[d+(h<<2)>>2]=z-p;h=e+8|0;if((h|0)<64){e=h}else{A=0;break}}do{p=+g[d+(A<<2)>>2];e=A+56|0;z=+g[d+(e<<2)>>2];t=p+z;y=p-z;h=A+8|0;z=+g[d+(h<<2)>>2];j=A+48|0;p=+g[d+(j<<2)>>2];x=z+p;m=z-p;s=A+16|0;p=+g[d+(s<<2)>>2];r=A+40|0;z=+g[d+(r<<2)>>2];k=p+z;B=p-z;q=A+24|0;z=+g[d+(q<<2)>>2];u=A+32|0;p=+g[d+(u<<2)>>2];C=z+p;D=t+C;E=t-C;C=x+k;b[a+(A<<1)>>1]=Lc(+(+g[703744+(A<<2)>>2]*(C+D)))|0;b[a+(u<<1)>>1]=Lc(+(+g[703744+(u<<2)>>2]*(D-C)))|0;C=(x-k+E)*.7071067811865476;b[a+(s<<1)>>1]=Lc(+(+g[703744+(s<<2)>>2]*(E+C)))|0;b[a+(j<<1)>>1]=Lc(+(+g[703744+(j<<2)>>2]*(E-C)))|0;C=B+(z-p);p=y+m;z=C*.9238795325112867-p*.3826834323650898;E=p*.9238795325112867+C*.3826834323650898;C=(m+B)*.7071067811865476;B=y+C;m=y-C;b[a+(r<<1)>>1]=Lc(+((m+z)*+g[703744+(r<<2)>>2]))|0;b[a+(q<<1)>>1]=Lc(+((m-z)*+g[703744+(q<<2)>>2]))|0;b[a+(h<<1)>>1]=Lc(+((B+E)*+g[703744+(h<<2)>>2]))|0;b[a+(e<<1)>>1]=Lc(+((B-E)*+g[703744+(e<<2)>>2]))|0;A=A+1|0;}while((A|0)<8);i=c;return}function jda(a){a=a|0;var c=0,d=0,e=0,f=0,h=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0;c=i;i=i+256|0;d=c|0;e=0;while(1){f=b[a+(e<<1)>>1]|0;h=e|7;j=b[a+(h<<1)>>1]|0;k=+(j+f|0);l=f-j|0;m=+(l|0);j=e|1;f=b[a+(j<<1)>>1]|0;n=e|6;o=b[a+(n<<1)>>1]|0;p=+(o+f|0);q=f-o|0;o=e|2;f=b[a+(o<<1)>>1]|0;r=e|5;s=b[a+(r<<1)>>1]|0;t=+(s+f|0);u=f-s|0;s=e|3;f=b[a+(s<<1)>>1]|0;v=e|4;w=b[a+(v<<1)>>1]|0;x=+(w+f|0);y=k+x;z=k-x;x=p+t;g[d+(e<<2)>>2]=x+y;g[d+(v<<2)>>2]=y-x;x=(p-t+z)*.7071067811865476;g[d+(o<<2)>>2]=z+x;g[d+(n<<2)>>2]=z-x;x=+(u+f-w|0);z=+(q+l|0);t=x*.9238795325112867-z*.3826834323650898;p=z*.9238795325112867+x*.3826834323650898;x=+(u+q|0)*.7071067811865476;z=m+x;y=m-x;g[d+(r<<2)>>2]=y+t;g[d+(s<<2)>>2]=y-t;g[d+(j<<2)>>2]=z+p;g[d+(h<<2)>>2]=z-p;h=e+8|0;if((h|0)<64){e=h}else{A=0;break}}do{p=+g[d+(A<<2)>>2];e=A+8|0;z=+g[d+(e<<2)>>2];t=p+z;h=A+16|0;y=+g[d+(h<<2)>>2];j=A+24|0;x=+g[d+(j<<2)>>2];m=y+x;s=A+32|0;k=+g[d+(s<<2)>>2];r=A+40|0;B=+g[d+(r<<2)>>2];C=k+B;q=A+48|0;D=+g[d+(q<<2)>>2];u=A+56|0;E=+g[d+(u<<2)>>2];F=D+E;G=p-z;z=y-x;x=k-B;B=D-E;E=t+F;D=m+C;k=t-F;F=+g[703744+(A<<2)>>2];b[a+(A<<1)>>1]=Lc(+(F*(D+E)))|0;t=+g[703744+(s<<2)>>2];b[a+(s<<1)>>1]=Lc(+(t*(E-D)))|0;D=(m-C+k)*.7071067811865476;C=+g[703744+(h<<2)>>2];b[a+(h<<1)>>1]=Lc(+(C*(k+D)))|0;m=+g[703744+(q<<2)>>2];b[a+(q<<1)>>1]=Lc(+(m*(k-D)))|0;D=G+B;k=z+x;E=G-B;b[a+(e<<1)>>1]=Lc(+((k+D)*F))|0;b[a+(r<<1)>>1]=Lc(+((D-k)*t))|0;t=(z-x+E)*.7071067811865476;b[a+(j<<1)>>1]=Lc(+((E+t)*C))|0;b[a+(u<<1)>>1]=Lc(+((E-t)*m))|0;A=A+1|0;}while((A|0)<8);i=c;return}function kda(a){a=a|0;var c=0,d=0,e=0;c=i;i=i+256|0;d=c|0;e=0;do{g[d+(e<<2)>>2]=+(b[a+(e<<1)>>1]|0)*+g[699600+(e<<2)>>2];e=e+1|0;}while((e|0)<64);e=d|0;lda(a,e,0,0,1,8,0);lda(a,e,0,0,8,1,1);i=c;return}function lda(c,e,f,h,i,j,k){c=c|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0.0,F=0.0,G=0,H=0,I=0.0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;l=j<<3;if((l|0)<=0){return}m=i*7|0;n=i*5|0;o=i*3|0;p=i<<1;q=i*6|0;r=i<<2;s=h*7|0;t=h*6|0;u=h<<1;v=h*5|0;w=h*3|0;x=h<<2;y=0;do{z=y+i|0;A=e+(z<<2)|0;B=+g[A>>2];C=y+m|0;D=e+(C<<2)|0;E=+g[D>>2];F=B+E;G=y+n|0;H=e+(G<<2)|0;I=+g[H>>2];J=y+o|0;K=e+(J<<2)|0;L=+g[K>>2];M=I+L;N=F+M;O=B-E;E=I-L;L=O*1.8477590650225735+E*-.7653668647301797-N;I=(F-M)*1.4142135623730951-L;M=O*-.7653668647301795-E*1.8477590650225735+I;P=y+p|0;Q=e+(P<<2)|0;E=+g[Q>>2];R=y+q|0;S=e+(R<<2)|0;O=+g[S>>2];F=E+O;B=(E-O)*1.4142135623730951-F;T=e+(y<<2)|0;O=+g[T>>2];U=y+r|0;V=e+(U<<2)|0;E=+g[V>>2];W=O+E;X=O-E;E=F+W;O=W-F;F=X+B;W=X-B;if((k|0)==0){g[T>>2]=N+E;g[D>>2]=E-N;g[A>>2]=L+F;g[S>>2]=F-L;g[Q>>2]=I+W;g[H>>2]=W-I;g[K>>2]=O-M;g[V>>2]=O+M}else if((k|0)==2){V=f+y|0;K=d[V]|0;H=K+(Lc(+(N+E))|0)|0;if(H>>>0>255>>>0){Y=-H>>31&255}else{Y=H&255}a[V]=Y;V=f+(y+s)|0;H=d[V]|0;K=H+(Lc(+(E-N))|0)|0;if(K>>>0>255>>>0){Z=-K>>31&255}else{Z=K&255}a[V]=Z;V=f+(y+h)|0;K=d[V]|0;H=K+(Lc(+(L+F))|0)|0;if(H>>>0>255>>>0){_=-H>>31&255}else{_=H&255}a[V]=_;V=f+(y+t)|0;H=d[V]|0;K=H+(Lc(+(F-L))|0)|0;if(K>>>0>255>>>0){$=-K>>31&255}else{$=K&255}a[V]=$;V=f+(y+u)|0;K=d[V]|0;H=K+(Lc(+(I+W))|0)|0;if(H>>>0>255>>>0){aa=-H>>31&255}else{aa=H&255}a[V]=aa;V=f+(y+v)|0;H=d[V]|0;K=H+(Lc(+(W-I))|0)|0;if(K>>>0>255>>>0){ba=-K>>31&255}else{ba=K&255}a[V]=ba;V=f+(y+w)|0;K=d[V]|0;H=K+(Lc(+(O-M))|0)|0;if(H>>>0>255>>>0){ca=-H>>31&255}else{ca=H&255}a[V]=ca;V=f+(y+x)|0;H=d[V]|0;K=H+(Lc(+(O+M))|0)|0;if(K>>>0>255>>>0){da=-K>>31&255}else{da=K&255}a[V]=da}else if((k|0)==1){b[c+(y<<1)>>1]=Lc(+(N+E))|0;b[c+(C<<1)>>1]=Lc(+(E-N))|0;b[c+(z<<1)>>1]=Lc(+(L+F))|0;b[c+(R<<1)>>1]=Lc(+(F-L))|0;b[c+(P<<1)>>1]=Lc(+(I+W))|0;b[c+(G<<1)>>1]=Lc(+(W-I))|0;b[c+(J<<1)>>1]=Lc(+(O-M))|0;b[c+(U<<1)>>1]=Lc(+(O+M))|0}else{U=Lc(+(N+E))|0;if(U>>>0>255>>>0){ea=-U>>31&255}else{ea=U&255}a[f+y|0]=ea;U=Lc(+(E-N))|0;if(U>>>0>255>>>0){fa=-U>>31&255}else{fa=U&255}a[f+(y+s)|0]=fa;U=Lc(+(L+F))|0;if(U>>>0>255>>>0){ga=-U>>31&255}else{ga=U&255}a[f+(y+h)|0]=ga;U=Lc(+(F-L))|0;if(U>>>0>255>>>0){ha=-U>>31&255}else{ha=U&255}a[f+(y+t)|0]=ha;U=Lc(+(I+W))|0;if(U>>>0>255>>>0){ia=-U>>31&255}else{ia=U&255}a[f+(y+u)|0]=ia;U=Lc(+(W-I))|0;if(U>>>0>255>>>0){ja=-U>>31&255}else{ja=U&255}a[f+(y+v)|0]=ja;U=Lc(+(O-M))|0;if(U>>>0>255>>>0){ka=-U>>31&255}else{ka=U&255}a[f+(y+w)|0]=ka;U=Lc(+(O+M))|0;if(U>>>0>255>>>0){la=-U>>31&255}else{la=U&255}a[f+(y+x)|0]=la}y=y+j|0;}while((y|0)<(l|0));return}function mda(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,h=0;e=i;i=i+256|0;f=e|0;h=0;do{g[f+(h<<2)>>2]=+(b[d+(h<<1)>>1]|0)*+g[699600+(h<<2)>>2];h=h+1|0;}while((h|0)<64);h=f|0;lda(d,h,0,0,1,8,0);lda(0,h,a,c,8,1,2);i=e;return}function nda(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,h=0;e=i;i=i+256|0;f=e|0;h=0;do{g[f+(h<<2)>>2]=+(b[d+(h<<1)>>1]|0)*+g[699600+(h<<2)>>2];h=h+1|0;}while((h|0)<64);h=f|0;lda(d,h,0,0,1,8,0);lda(0,h,a,c,8,1,3);i=e;return}function oda(a){a=a|0;var b=0,d=0.0,e=0,f=0;b=1<<a;d=6.283185307179586/+(b|0);e=c[1405944+(a<<2)>>2]|0;a=(b|0)/4|0;if((b|0)<-3){return}else{f=0}do{g[e+(f<<2)>>2]=+U(d*+(f|0));f=f+1|0;}while((f|0)<=(a|0));if((b|0)<=7){return}f=(b|0)/2|0;b=1;do{g[e+(f-b<<2)>>2]=+g[e+(b<<2)>>2];b=b+1|0;}while((b|0)<(a|0));return}function pda(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0;do{if((d-2|0)>>>0>14>>>0){f=a+8|0}else{c[a>>2]=d;h=1<<d;i=hJb(h<<1)|0;j=a+8|0;c[j>>2]=i;if((i|0)==0){f=j;break}i=hJb(h<<3)|0;c[a+12>>2]=i;if((i|0)==0){f=j;break}c[a+4>>2]=e;c[a+56>>2]=0;c[a+32>>2]=446;c[a+36>>2]=508;c[a+40>>2]=976;c[a+44>>2]=450;c[a+48>>2]=890;c[a+52>>2]=890;if((d|0)>=4){i=4;do{k=1<<i;l=6.283185307179586/+(k|0);m=c[1405944+(i<<2)>>2]|0;n=(k|0)/4|0;do{if(!((k|0)<-3)){o=0;do{g[m+(o<<2)>>2]=+U(l*+(o|0));o=o+1|0;}while((o|0)<=(n|0));if((k|0)<=7){break}o=(k|0)/2|0;p=1;do{g[m+(o-p<<2)>>2]=+g[m+(p<<2)>>2];p=p+1|0;}while((p|0)<(n|0))}}while(0);i=i+1|0;}while((i|0)<=(d|0))}if((h|0)<=0){q=0;return q|0}i=h-1|0;n=c[j>>2]|0;m=0;while(1){b[n+((i&-(sda(m,h,e)|0))<<1)>>1]=m;k=m+1|0;if((k|0)<(h|0)){m=k}else{q=0;break}}return q|0}}while(0);mJb(f);mJb(a+12|0);q=-1;return q|0}function qda(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[a+8>>2]|0;f=1<<c[a>>2];g=a+12|0;if((f|0)>0){h=0}else{i=b;j=c[g>>2]|0;k=j;l=f<<3;nrc(i|0,k|0,l)|0;return}do{a=b+(h<<3)|0;m=(c[g>>2]|0)+((e[d+(h<<1)>>1]|0)<<3)|0;n=c[a+4>>2]|0;c[m>>2]=c[a>>2];c[m+4>>2]=n;h=h+1|0;}while((h|0)<(f|0));i=b;j=c[g>>2]|0;k=j;l=f<<3;nrc(i|0,k|0,l)|0;return}function rda(a,b){a=a|0;b=b|0;qe[c[1241184+((c[a>>2]|0)-2<<2)>>2]&1023](b);return}function sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if((b|0)<3){d=a&1;return d|0}e=b>>1;if((e&a|0)==0){return(sda(a,e,c)|0)<<1|0}e=b>>2;b=(sda(a,e,c)|0)<<2;if(((e&a|0)==0|0)==(c|0)){d=b|1;return d|0}else{d=b-1|0;return d|0}return 0}function tda(a){a=a|0;mJb(a+8|0);mJb(a+12|0);return}function uda(a){a=a|0;var b=0,c=0.0,d=0,e=0.0,f=0.0,h=0.0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0.0,p=0.0;b=a|0;c=+g[b>>2];d=a+8|0;e=+g[d>>2];f=c-e;h=c+e;i=a+24|0;e=+g[i>>2];j=a+16|0;c=+g[j>>2];k=e-c;l=e+c;g[j>>2]=h-l;g[b>>2]=h+l;b=a+4|0;l=+g[b>>2];j=a+12|0;h=+g[j>>2];c=l-h;e=l+h;m=a+20|0;h=+g[m>>2];n=a+28|0;l=+g[n>>2];o=h-l;p=h+l;g[n>>2]=c-k;g[j>>2]=k+c;g[i>>2]=f-o;g[d>>2]=f+o;g[m>>2]=e-p;g[b>>2]=e+p;return}function vda(a){a=a|0;var b=0,c=0.0,d=0,e=0.0,f=0.0,h=0.0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0.0,p=0.0,q=0,r=0,s=0.0,t=0.0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0.0,B=0.0,C=0,D=0,E=0.0,F=0,G=0.0,H=0,I=0.0,J=0.0,K=0.0,L=0.0;b=a|0;c=+g[b>>2];d=a+8|0;e=+g[d>>2];f=c-e;h=c+e;i=a+24|0;e=+g[i>>2];j=a+16|0;c=+g[j>>2];k=e-c;l=e+c;c=h-l;e=h+l;m=a+4|0;l=+g[m>>2];n=a+12|0;h=+g[n>>2];o=l-h;p=l+h;q=a+20|0;h=+g[q>>2];r=a+28|0;l=+g[r>>2];s=h-l;t=h+l;l=o-k;h=k+o;o=f-s;k=f+s;s=p-t;f=p+t;u=a+32|0;t=+g[u>>2];v=a+40|0;p=+g[v>>2];w=t+p;x=t-p;y=a+36|0;p=+g[y>>2];z=a+44|0;t=+g[z>>2];A=p+t;B=p-t;C=a+48|0;t=+g[C>>2];D=a+56|0;p=+g[D>>2];E=t+p;F=a+52|0;G=+g[F>>2];H=a+60|0;I=+g[H>>2];J=G+I;K=E-w;L=w+E;g[u>>2]=e-L;g[b>>2]=L+e;g[F>>2]=s-K;g[q>>2]=K+s;s=A-J;K=A+J;g[C>>2]=c-s;g[j>>2]=s+c;g[y>>2]=f-K;g[m>>2]=f+K;K=x*.7071067690849304-B*-.7071067690849304;f=x*-.7071067690849304+B*.7071067690849304;B=(t-p)*.7071067690849304;p=(G-I)*.7071067690849304;I=B-p;G=B+p;p=I-K;B=K+I;g[v>>2]=k-B;g[d>>2]=k+B;g[H>>2]=l-p;g[r>>2]=p+l;l=f-G;p=f+G;g[D>>2]=o-l;g[i>>2]=o+l;g[z>>2]=h-p;g[n>>2]=h+p;return}function wda(a){a=a|0;var b=0.0,c=0.0,d=0,e=0.0,f=0,h=0.0,i=0.0,j=0.0,k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0.0,r=0.0,s=0,t=0,u=0.0,v=0.0,w=0,x=0,y=0.0,z=0.0,A=0,B=0,C=0.0,D=0.0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0,K=0,L=0.0,M=0.0,N=0,O=0,P=0.0,Q=0,R=0.0,S=0,T=0.0,U=0.0,V=0.0;b=+g[2192349];c=+g[2192351];vda(a);d=a+64|0;e=+g[d>>2];f=a+72|0;h=+g[f>>2];i=e-h;j=e+h;k=a+88|0;h=+g[k>>2];l=a+80|0;e=+g[l>>2];m=h-e;n=h+e;e=j-n;h=j+n;o=a+68|0;n=+g[o>>2];p=a+76|0;j=+g[p>>2];q=n-j;r=n+j;s=a+84|0;j=+g[s>>2];t=a+92|0;n=+g[t>>2];u=j-n;v=j+n;n=q-m;j=m+q;q=i-u;m=i+u;u=r-v;i=r+v;w=a+96|0;v=+g[w>>2];x=a+104|0;r=+g[x>>2];y=v-r;z=v+r;A=a+120|0;r=+g[A>>2];B=a+112|0;v=+g[B>>2];C=r-v;D=r+v;v=z+D;E=a+100|0;r=+g[E>>2];F=a+108|0;G=+g[F>>2];H=r-G;I=r+G;J=a+116|0;G=+g[J>>2];K=a+124|0;r=+g[K>>2];L=G-r;M=G+r;r=H-C;G=C+H;H=y-L;C=y+L;L=I+M;N=a|0;y=+g[N>>2];O=a+4|0;P=+g[O>>2];Q=a+32|0;R=+g[Q>>2];S=a+36|0;T=+g[S>>2];U=v-h;V=h+v;g[d>>2]=y-V;g[N>>2]=y+V;g[E>>2]=T-U;g[S>>2]=U+T;T=i-L;U=i+L;g[w>>2]=R-T;g[Q>>2]=T+R;g[o>>2]=P-U;g[O>>2]=U+P;P=e*.7071067690849304-u*-.7071067690849304;U=e*-.7071067690849304+u*.7071067690849304;u=(z-D)*.7071067690849304;D=(I-M)*.7071067690849304;M=u-D;I=u+D;O=a+16|0;D=+g[O>>2];o=a+20|0;u=+g[o>>2];Q=a+48|0;z=+g[Q>>2];w=a+52|0;e=+g[w>>2];R=M-P;T=P+M;g[l>>2]=D-T;g[O>>2]=D+T;g[J>>2]=e-R;g[w>>2]=R+e;e=U-I;R=U+I;g[B>>2]=z-e;g[Q>>2]=z+e;g[s>>2]=u-R;g[o>>2]=u+R;R=-0.0-c;u=b*m-j*R;e=m*R+b*j;j=b*C-c*G;R=c*C+b*G;o=a+8|0;G=+g[o>>2];s=a+12|0;C=+g[s>>2];Q=a+40|0;m=+g[Q>>2];B=a+44|0;z=+g[B>>2];I=j-u;U=u+j;g[f>>2]=G-U;g[o>>2]=G+U;g[F>>2]=z-I;g[B>>2]=I+z;z=e-R;I=e+R;g[x>>2]=m-z;g[Q>>2]=m+z;g[p>>2]=C-I;g[s>>2]=C+I;I=-0.0-b;C=c*q-n*I;z=q*I+c*n;n=c*H-b*r;I=b*H+c*r;s=a+24|0;r=+g[s>>2];p=a+28|0;c=+g[p>>2];Q=a+56|0;H=+g[Q>>2];x=a+60|0;b=+g[x>>2];q=n-C;m=C+n;g[k>>2]=r-m;g[s>>2]=r+m;g[K>>2]=b-q;g[x>>2]=q+b;b=z-I;q=z+I;g[A>>2]=H-b;g[Q>>2]=H+b;g[t>>2]=c-q;g[p>>2]=c+q;return}function xda(a){a=a|0;wda(a);vda(a+128|0);vda(a+192|0);Kda(a,8713248,4);return}function yda(a){a=a|0;wda(a);vda(a+128|0);vda(a+192|0);Kda(a,8713248,4);wda(a+256|0);wda(a+384|0);Kda(a,8600960,8);return}function zda(a){a=a|0;var b=0;wda(a);vda(a+128|0);vda(a+192|0);Kda(a,8713248,4);wda(a+256|0);wda(a+384|0);Kda(a,8600960,8);b=a+512|0;wda(b);vda(a+640|0);vda(a+704|0);Kda(b,8713248,4);b=a+768|0;wda(b);vda(a+896|0);vda(a+960|0);Kda(b,8713248,4);Kda(a,8769552,16);return}function Ada(a){a=a|0;var b=0;zda(a);b=a+1024|0;wda(b);vda(a+1152|0);vda(a+1216|0);Kda(b,8713248,4);wda(a+1280|0);wda(a+1408|0);Kda(b,8600960,8);b=a+1536|0;wda(b);vda(a+1664|0);vda(a+1728|0);Kda(b,8713248,4);wda(a+1792|0);wda(a+1920|0);Kda(b,8600960,8);Kda(a,8713568,32);return}function Bda(a){a=a|0;Ada(a);zda(a+2048|0);zda(a+3072|0);Kda(a,8601600,64);return}function Cda(a){a=a|0;Ada(a);zda(a+2048|0);zda(a+3072|0);Kda(a,8601600,64);Ada(a+4096|0);Ada(a+6144|0);Jda(a,8770832,128);return}function Dda(a){a=a|0;var b=0;Ada(a);zda(a+2048|0);zda(a+3072|0);Kda(a,8601600,64);Ada(a+4096|0);Ada(a+6144|0);Jda(a,8770832,128);b=a+8192|0;Ada(b);zda(a+10240|0);zda(a+11264|0);Kda(b,8601600,64);b=a+12288|0;Ada(b);zda(a+14336|0);zda(a+15360|0);Kda(b,8601600,64);Jda(a,8716128,256);return}function Eda(a){a=a|0;var b=0;Dda(a);b=a+16384|0;Ada(b);zda(a+18432|0);zda(a+19456|0);Kda(b,8601600,64);Ada(a+20480|0);Ada(a+22528|0);Jda(b,8770832,128);b=a+24576|0;Ada(b);zda(a+26624|0);zda(a+27648|0);Kda(b,8601600,64);Ada(a+28672|0);Ada(a+30720|0);Jda(b,8770832,128);Jda(a,8606720,512);return}function Fda(a){a=a|0;Eda(a);Dda(a+32768|0);Dda(a+49152|0);Jda(a,8387904,1024);return}function Gda(a){a=a|0;Eda(a);Dda(a+32768|0);Dda(a+49152|0);Jda(a,8387904,1024);Eda(a+65536|0);Eda(a+98304|0);Jda(a,8736624,2048);return}function Hda(a){a=a|0;var b=0;Eda(a);Dda(a+32768|0);Dda(a+49152|0);Jda(a,8387904,1024);Eda(a+65536|0);Eda(a+98304|0);Jda(a,8736624,2048);b=a+131072|0;Eda(b);Dda(a+163840|0);Dda(a+180224|0);Jda(b,8387904,1024);b=a+196608|0;Eda(b);Dda(a+229376|0);Dda(a+245760|0);Jda(b,8387904,1024);Jda(a,8647712,4096);return}function Ida(a){a=a|0;var b=0;Hda(a);b=a+262144|0;Eda(b);Dda(a+294912|0);Dda(a+311296|0);Jda(b,8387904,1024);Eda(a+327680|0);Eda(a+360448|0);Jda(b,8736624,2048);b=a+393216|0;Eda(b);Dda(a+425984|0);Dda(a+442368|0);Jda(b,8387904,1024);Eda(a+458752|0);Eda(a+491520|0);Jda(b,8736624,2048);Jda(a,8469824,8192);return}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0.0,j=0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0,v=0,w=0.0,x=0.0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=c<<1;e=c<<2;f=c*6|0;h=a+(e<<3)|0;i=+g[h>>2];j=a+(e<<3)+4|0;k=+g[j>>2];l=a+(f<<3)|0;m=+g[l>>2];n=a+(f<<3)+4|0;o=+g[n>>2];p=a|0;q=+g[p>>2];r=a+4|0;s=+g[r>>2];t=a+(d<<3)|0;u=+g[t>>2];v=a+(d<<3)+4|0;w=+g[v>>2];x=m-i;y=i+m;g[h>>2]=q-y;g[p>>2]=y+q;g[n>>2]=w-x;g[v>>2]=x+w;w=k-o;x=k+o;g[l>>2]=u-w;g[t>>2]=w+u;g[j>>2]=s-x;g[r>>2]=x+s;r=e|1;j=a+(r<<3)|0;s=+g[j>>2];x=+g[b+4>>2];t=a+(r<<3)+4|0;u=+g[t>>2];w=+g[b+(d-1<<2)>>2];o=-0.0-w;k=s*x-u*o;q=x*u+s*o;r=f|1;l=a+(r<<3)|0;o=+g[l>>2];v=a+(r<<3)+4|0;s=+g[v>>2];u=x*o-w*s;y=w*o+x*s;n=a+8|0;s=+g[n>>2];p=a+12|0;x=+g[p>>2];h=d|1;z=a+(h<<3)|0;o=+g[z>>2];A=a+(h<<3)+4|0;w=+g[A>>2];m=u-k;i=k+u;g[j>>2]=s-i;g[n>>2]=s+i;g[v>>2]=w-m;g[A>>2]=m+w;w=q-y;m=q+y;g[l>>2]=o-w;g[z>>2]=o+w;g[t>>2]=x-m;g[p>>2]=x+m;p=e|2;t=f+2|0;f=d+2|0;z=e|3;e=r+2|0;r=h+2|0;h=a;a=b;l=c-1|0;c=b+(d<<2)|0;while(1){d=h+16|0;b=a+8|0;A=c-8|0;v=h+(p<<3)|0;m=+g[v>>2];x=+g[b>>2];n=h+(p<<3)+4|0;w=+g[n>>2];o=+g[A>>2];y=-0.0-o;q=m*x-w*y;i=x*w+m*y;j=h+(t<<3)|0;y=+g[j>>2];B=h+(t<<3)+4|0;m=+g[B>>2];w=x*y-o*m;s=o*y+x*m;C=d|0;m=+g[C>>2];D=h+20|0;x=+g[D>>2];E=h+(f<<3)|0;y=+g[E>>2];F=h+(f<<3)+4|0;o=+g[F>>2];u=w-q;k=q+w;g[v>>2]=m-k;g[C>>2]=m+k;g[B>>2]=o-u;g[F>>2]=u+o;o=i-s;u=i+s;g[j>>2]=y-o;g[E>>2]=y+o;g[n>>2]=x-u;g[D>>2]=x+u;D=h+(z<<3)|0;u=+g[D>>2];x=+g[a+12>>2];n=h+(z<<3)+4|0;o=+g[n>>2];y=+g[c-12>>2];s=-0.0-y;i=u*x-o*s;k=x*o+u*s;E=h+(e<<3)|0;s=+g[E>>2];j=h+(e<<3)+4|0;u=+g[j>>2];o=x*s-y*u;m=y*s+x*u;F=h+24|0;u=+g[F>>2];B=h+28|0;x=+g[B>>2];C=h+(r<<3)|0;s=+g[C>>2];v=h+(r<<3)+4|0;y=+g[v>>2];w=o-i;q=i+o;g[D>>2]=u-q;g[F>>2]=u+q;g[j>>2]=y-w;g[v>>2]=w+y;y=k-m;w=k+m;g[E>>2]=s-y;g[C>>2]=s+y;g[n>>2]=x-w;g[B>>2]=x+w;B=l-1|0;if((B|0)==0){break}else{h=d;a=b;l=B;c=A}}return}function Kda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0.0,j=0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0.0,q=0.0,r=0,s=0.0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c<<1;e=c<<2;f=c*6|0;h=a+(e<<3)|0;i=+g[h>>2];j=a+(e<<3)+4|0;k=+g[j>>2];l=a+(f<<3)|0;m=+g[l>>2];n=a+(f<<3)+4|0;o=+g[n>>2];p=m-i;q=i+m;r=a|0;g[h>>2]=+g[r>>2]-q;g[r>>2]=q+ +g[r>>2];r=a+(d<<3)+4|0;g[n>>2]=+g[r>>2]-p;g[r>>2]=p+ +g[r>>2];p=k-o;q=k+o;r=a+(d<<3)|0;g[l>>2]=+g[r>>2]-p;g[r>>2]=p+ +g[r>>2];r=a+4|0;g[j>>2]=+g[r>>2]-q;g[r>>2]=q+ +g[r>>2];r=e|1;j=a+(r<<3)|0;q=+g[j>>2];p=+g[b+4>>2];l=a+(r<<3)+4|0;o=+g[l>>2];k=+g[b+(d-1<<2)>>2];m=-0.0-k;i=q*p-o*m;s=p*o+q*m;r=f|1;n=a+(r<<3)|0;m=+g[n>>2];h=a+(r<<3)+4|0;q=+g[h>>2];o=p*m-k*q;t=k*m+p*q;q=o-i;p=i+o;u=a+8|0;g[j>>2]=+g[u>>2]-p;g[u>>2]=+g[u>>2]+p;u=d|1;j=a+(u<<3)+4|0;g[h>>2]=+g[j>>2]-q;g[j>>2]=q+ +g[j>>2];q=s-t;p=s+t;j=a+(u<<3)|0;g[n>>2]=+g[j>>2]-q;g[j>>2]=q+ +g[j>>2];j=a+12|0;g[l>>2]=+g[j>>2]-p;g[j>>2]=p+ +g[j>>2];j=e|2;l=f+2|0;f=d+2|0;n=e|3;e=r+2|0;r=u+2|0;u=b+(d<<2)|0;d=a;a=b;b=c-1|0;while(1){c=d+16|0;h=a+8|0;v=u-8|0;w=d+(j<<3)|0;p=+g[w>>2];q=+g[h>>2];x=d+(j<<3)+4|0;t=+g[x>>2];s=+g[v>>2];o=-0.0-s;i=p*q-t*o;m=q*t+p*o;y=d+(l<<3)|0;o=+g[y>>2];z=d+(l<<3)+4|0;p=+g[z>>2];t=q*o-s*p;k=s*o+q*p;p=t-i;q=i+t;A=c|0;g[w>>2]=+g[A>>2]-q;g[A>>2]=+g[A>>2]+q;A=d+(f<<3)+4|0;g[z>>2]=+g[A>>2]-p;g[A>>2]=p+ +g[A>>2];p=m-k;q=m+k;A=d+(f<<3)|0;g[y>>2]=+g[A>>2]-p;g[A>>2]=p+ +g[A>>2];A=d+20|0;g[x>>2]=+g[A>>2]-q;g[A>>2]=q+ +g[A>>2];A=d+(n<<3)|0;q=+g[A>>2];p=+g[a+12>>2];x=d+(n<<3)+4|0;k=+g[x>>2];m=+g[u-12>>2];t=-0.0-m;i=q*p-k*t;o=p*k+q*t;y=d+(e<<3)|0;t=+g[y>>2];z=d+(e<<3)+4|0;q=+g[z>>2];k=p*t-m*q;s=m*t+p*q;q=k-i;p=i+k;w=d+24|0;g[A>>2]=+g[w>>2]-p;g[w>>2]=+g[w>>2]+p;w=d+(r<<3)+4|0;g[z>>2]=+g[w>>2]-q;g[w>>2]=q+ +g[w>>2];q=o-s;p=o+s;w=d+(r<<3)|0;g[y>>2]=+g[w>>2]-q;g[w>>2]=q+ +g[w>>2];w=d+28|0;g[x>>2]=+g[w>>2]-p;g[w>>2]=p+ +g[w>>2];w=b-1|0;if((w|0)==0){break}else{u=v;d=c;a=h;b=w}}return}function Lda(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+1056|0;f=e+32|0;g=c[b+60>>2]|0;h=g;j=Ipb(b)|0;if((j|0)<0){k=j;i=e;return k|0}a:do{if((c[b+96>>2]|0)!=0){j=e|0;l=g+8|0;m=l;mrc(f|0,-128|0,1024)|0;mrc(j|0,-128|0,32)|0;n=g+4|0;o=c[n>>2]|0;TYa(m,c[o+96>>2]|0,c[o+100>>2]|0);UYa(m,214748364,248);o=Qda(m,j,0)|0;p=g+4720|0;c[p>>2]=o;if((o|0)<2){KIb(c[n>>2]|0,16,2431056,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;k=-1094995529;i=e;return k|0}if((o|0)>2){o=g+544|0;c[o>>2]=(c[o>>2]|0)-4;c[g+4724>>2]=Qda(m,j,0)|0}o=Qda(m,j,0)|0;c[(c[n>>2]|0)+568>>2]=o;r=g+4796|0;c[r>>2]=o;if((o|0)>1){o=1;do{s=Qda(m,j,1)|0;a[h+38196+o|0]=(d[h+280+o|0]|0)+s;o=o+1|0;}while((o|0)<256)}o=g+38488|0;c[o>>2]=Qda(m,j,0)|0;s=Qda(m,j,0)|0;c[(c[n>>2]|0)+796>>2]=s;s=g+12|0;t=c[s>>2]|0;u=d[j]|0;v=(ca(u,t)|0)>>8;w=t-v|0;c[s>>2]=w;t=l;x=c[t>>2]|0;do{if((x|0)<(w|0)){a[j]=a[h+24+u|0]|0;if((w|0)>=256){y=0;break}c[s>>2]=w<<8;z=x<<8;c[t>>2]=z;A=g+540|0;B=c[A>>2]|0;if(B>>>0<(c[g+544>>2]|0)>>>0){c[t>>2]=d[B]|0|z}c[A>>2]=B+1;y=0}else{B=x-w|0;c[t>>2]=B;a[j]=a[h+280+u|0]|0;c[s>>2]=v;if((v|0)>=256){y=1;break}c[s>>2]=v<<8;A=B<<8;c[t>>2]=A;B=g+540|0;z=c[B>>2]|0;if(z>>>0<(c[g+544>>2]|0)>>>0){c[t>>2]=d[z]|0|A}c[B>>2]=z+1;y=1}}while(0);v=g+4736|0;c[v>>2]=y;u=g+4740|0;c[u>>2]=Qda(m,j,0)|0;w=g+4744|0;c[w>>2]=Qda(m,j,0)|0;x=c[s>>2]|0;l=d[j]|0;z=(ca(l,x)|0)>>8;B=x-z|0;c[s>>2]=B;x=c[t>>2]|0;do{if((x|0)<(B|0)){a[j]=a[h+24+l|0]|0;if((B|0)>=256){C=0;break}c[s>>2]=B<<8;A=x<<8;c[t>>2]=A;D=g+540|0;E=c[D>>2]|0;if(E>>>0<(c[g+544>>2]|0)>>>0){c[t>>2]=d[E]|0|A}c[D>>2]=E+1;C=0}else{E=x-B|0;c[t>>2]=E;a[j]=a[h+280+l|0]|0;c[s>>2]=z;if((z|0)>=256){C=1;break}c[s>>2]=z<<8;D=E<<8;c[t>>2]=D;E=g+540|0;A=c[E>>2]|0;if(A>>>0<(c[g+544>>2]|0)>>>0){c[t>>2]=d[A]|0|D}c[E>>2]=A+1;C=1}}while(0);z=g+4748|0;c[z>>2]=C;if((c[v>>2]|0)==0){F=(c[p>>2]|0)<4?2:1}else{F=2}c[g+4792>>2]=F+C;l=g+40804|0;c[l>>2]=(Qda(m,j,0)|0)+1;B=(Qda(m,j,0)|0)+1|0;x=g+40800|0;c[x>>2]=B;A=c[l>>2]|0;do{if(!(A>>>0>(c[g+4728>>2]|0)>>>0|(A|0)==0)){if(B>>>0>(c[g+4732>>2]|0)>>>0|(B|0)==0){break}E=Qda(m,j,0)|0;D=g+38524|0;c[D>>2]=E;if(E>>>0>8>>>0){k=-1094995529;i=e;return k|0}b:do{if((E|0)>0){G=0;while(1){H=Rda(m,h+17684+(G*2560|0)|0)|0;c[h+38164+(G<<2)>>2]=H;if((H|0)<0){break}G=G+1|0;if((G|0)>=(c[D>>2]|0)){break b}}KIb(c[n>>2]|0,16,2469400,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;k=-1094995529;i=e;return k|0}}while(0);E=Mpb(h)|0;if((E|0)<0){k=E;i=e;return k|0}E=c[D>>2]|0;if((E|0)>0){G=g+540|0;H=g+544|0;I=0;J=a[j]|0;K=E;while(1){E=c[s>>2]|0;L=J&255;M=(ca(E,L)|0)>>8;N=E-M|0;c[s>>2]=N;E=c[t>>2]|0;do{if((E|0)<(N|0)){O=a[h+24+L|0]|0;a[j]=O;if((N|0)>=256){P=O;Q=K;break}c[s>>2]=N<<8;R=E<<8;c[t>>2]=R;S=c[G>>2]|0;if(S>>>0<(c[H>>2]|0)>>>0){c[t>>2]=d[S]|0|R}c[G>>2]=S+1;P=O;Q=K}else{O=E-N|0;c[t>>2]=O;S=a[h+280+L|0]|0;a[j]=S;c[s>>2]=M;if((M|0)<256){c[s>>2]=M<<8;R=O<<8;c[t>>2]=R;O=c[G>>2]|0;if(O>>>0<(c[H>>2]|0)>>>0){c[t>>2]=d[O]|0|R}c[G>>2]=O+1}O=h+38164+(I<<2)|0;if((c[O>>2]|0)<=0){P=S;Q=K;break}R=h+38452+(I<<2)|0;T=0;do{U=T-1|0;if((T|0)==0){V=0;do{W=(Qda(m,f+(V<<5)|0,1)|0)+128&255;a[(c[R>>2]|0)+V|0]=W;V=V+1|0;}while((V|0)<32)}else{V=0;do{W=d[(c[R>>2]|0)+(U<<5)+V|0]|0;X=(Qda(m,f+(V<<5)|0,1)|0)+W&255;a[(c[R>>2]|0)+(T<<5)+V|0]=X;V=V+1|0;}while((V|0)<32)}T=T+1|0;}while((T|0)<(c[O>>2]|0));P=S;Q=c[D>>2]|0}}while(0);M=I+1|0;if((M|0)<(Q|0)){I=M;J=P;K=Q}else{break}}}do{if((c[p>>2]|0)>2){c[g+38496>>2]=Qda(m,j,0)|0;if((c[g+4724>>2]|0)>2){c[g+38500>>2]=Qda(m,j,0)|0}if((c[p>>2]|0)<=2){break}K=DGb(3)|0;J=c[n>>2]|0;I=EGb(K,0,c[J+96>>2]|0,c[J+100>>2]|0)|0;if((I|0)==0){break}KIb(J,16,2411552,(q=i,i=i+8|0,c[q>>2]=I,q)|0);i=q;k=-1094995529;i=e;return k|0}}while(0);I=c[n>>2]|0;if((c[I+688>>2]&1|0)==0){break a}J=c[g+4724>>2]|0;K=c[r>>2]|0;G=c[o>>2]|0;H=c[I+796>>2]|0;M=c[v>>2]|0;L=c[u>>2]|0;N=c[w>>2]|0;E=c[z>>2]|0;O=c[l>>2]|0;T=c[x>>2]|0;R=c[D>>2]|0;V=c[g+38496>>2]|0;U=c[g+38500>>2]|0;KIb(I,48,2403840,(q=i,i=i+112|0,c[q>>2]=c[p>>2],c[q+8>>2]=J,c[q+16>>2]=K,c[q+24>>2]=G,c[q+32>>2]=H,c[q+40>>2]=M,c[q+48>>2]=L,c[q+56>>2]=N,c[q+64>>2]=E,c[q+72>>2]=O,c[q+80>>2]=T,c[q+88>>2]=R,c[q+96>>2]=V,c[q+104>>2]=U,q)|0);i=q;break a}}while(0);KIb(c[n>>2]|0,16,2420776,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;k=-1094995529;i=e;return k|0}}while(0);q=Lpb(h)|0;if((q|0)<0){k=q;i=e;return k|0}c[(c[b+64>>2]|0)+4>>2]=1;k=0;i=e;return k|0}function Mda(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;j=i;i=i+80|0;k=j|0;l=j+48|0;m=j+64|0;n=c[g+24>>2]|0;o=c[g+28>>2]|0;p=c[b+60>>2]|0;q=p;r=p+39772|0;s=r;t=r;u=c[t>>2]|0;v=u+8|0;w=p+4772|0;x=w;y=w;if((c[y>>2]|0)!=0){H5a(b,x)}z=j+32|0;c[z>>2]=c[w>>2];c[z+4>>2]=c[w+4>>2];c[z+8>>2]=c[w+8>>2];A=p+4760|0;B=A;c[w>>2]=c[A>>2];c[w+4>>2]=c[A+4>>2];c[w+8>>2]=c[A+8>>2];c[A>>2]=c[z>>2];c[A+4>>2]=c[z+4>>2];c[A+8>>2]=c[z+8>>2];z=A;A=c[z>>2]|0;w=p+4788|0;c[w>>2]=A;C=p+4720|0;do{if((c[C>>2]|0)<3){D=c[b+408>>2]|0;if(!(D>>>0>1>>>0)){break}c[A+296>>2]=1;if(!((D|0)==2|(D|0)==4)){break}c[A+300>>2]=1}}while(0);D=p+4|0;c[D>>2]=b;TYa(v,n,o);UYa(v,214748364,248);c[A+88>>2]=1;E=u+12|0;F=c[E>>2]|0;H=F>>1;I=F-H|0;c[E>>2]=I;F=v|0;v=c[F>>2]|0;do{if((v|0)<(I|0)){if((I|0)<256){c[E>>2]=I<<8;J=v<<8;c[F>>2]=J;K=u+540|0;L=c[K>>2]|0;if(L>>>0<(c[u+544>>2]|0)>>>0){c[F>>2]=d[L]|0|J}c[K>>2]=L+1}if((c[p+38508>>2]|0)!=0){c[A+84>>2]=0;break}KIb(b,16,2454144,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}else{L=v-I|0;c[F>>2]=L;c[E>>2]=H;if((H|0)<256){c[E>>2]=H<<8;K=L<<8;c[F>>2]=K;L=u+540|0;J=c[L>>2]|0;if(J>>>0<(c[u+544>>2]|0)>>>0){c[F>>2]=d[J]|0|K}c[L>>2]=J+1}c[A+84>>2]=1;J=p+38508|0;c[J>>2]=0;L=k|0;K=c[t>>2]|0;O=K+8|0;mrc(L|0,-128|0,32)|0;if((c[C>>2]|0)<2){P=Qda(O,L,0)|0;if(P>>>0>1>>>0){KIb(c[D>>2]|0,16,2532512,(M=i,i=i+8|0,c[M>>2]=P,M)|0);i=M;N=-1094995529;i=j;return N|0}c[C>>2]=P;P=Qda(O,L,0)|0;c[(c[D>>2]|0)+568>>2]=P;c[p+4796>>2]=P;if((P|0)>1){P=1;do{Q=Qda(O,L,1)|0;a[q+38196+P|0]=(d[K+280+P|0]|0)+Q;P=P+1|0;}while((P|0)<256)}P=Qda(O,L,0)|0;if((c[C>>2]|0)>0){R=Qda(O,L,0)|0}else{R=c[(c[D>>2]|0)+796>>2]|0}Q=K+12|0;S=c[Q>>2]|0;T=d[L]|0;U=(ca(T,S)|0)>>8;V=S-U|0;c[Q>>2]=V;S=O|0;W=c[S>>2]|0;do{if((W|0)<(V|0)){a[L]=a[K+24+T|0]|0;if((V|0)>=256){X=0;break}c[Q>>2]=V<<8;Y=W<<8;c[S>>2]=Y;Z=K+540|0;_=c[Z>>2]|0;if(_>>>0<(c[K+544>>2]|0)>>>0){c[S>>2]=d[_]|0|Y}c[Z>>2]=_+1;X=0}else{_=W-V|0;c[S>>2]=_;a[L]=a[K+280+T|0]|0;c[Q>>2]=U;if((U|0)>=256){X=1;break}c[Q>>2]=U<<8;Z=_<<8;c[S>>2]=Z;_=K+540|0;Y=c[_>>2]|0;if(Y>>>0<(c[K+544>>2]|0)>>>0){c[S>>2]=d[Y]|0|Z}c[_>>2]=Y+1;X=1}}while(0);U=Qda(O,L,0)|0;T=Qda(O,L,0)|0;V=c[Q>>2]|0;W=d[L]|0;Y=(ca(W,V)|0)>>8;_=V-Y|0;c[Q>>2]=_;V=c[S>>2]|0;do{if((V|0)<(_|0)){a[L]=a[K+24+W|0]|0;if((_|0)>=256){$=0;break}c[Q>>2]=_<<8;Z=V<<8;c[S>>2]=Z;aa=K+540|0;ba=c[aa>>2]|0;if(ba>>>0<(c[K+544>>2]|0)>>>0){c[S>>2]=d[ba]|0|Z}c[aa>>2]=ba+1;$=0}else{ba=V-_|0;c[S>>2]=ba;a[L]=a[K+280+W|0]|0;c[Q>>2]=Y;if((Y|0)>=256){$=1;break}c[Q>>2]=Y<<8;aa=ba<<8;c[S>>2]=aa;ba=K+540|0;Z=c[ba>>2]|0;if(Z>>>0<(c[K+544>>2]|0)>>>0){c[S>>2]=d[Z]|0|aa}c[ba>>2]=Z+1;$=1}}while(0);S=p+4792|0;a:do{if((c[S>>2]|0)==0){da=c[D>>2]|0;ea=p+38488|0;fa=p+4736|0;ga=p+4740|0;ha=p+4744|0;ia=p+4748|0}else{Y=p+38488|0;Q=c[D>>2]|0;do{if((P|0)==(c[Y>>2]|0)){if((R|0)!=(c[Q+796>>2]|0)){break}W=p+4736|0;if((X|0)!=(c[W>>2]|0)){break}_=p+4740|0;if((U|0)!=(c[_>>2]|0)){break}V=p+4744|0;if((T|0)!=(c[V>>2]|0)){break}Z=p+4748|0;if(($|0)==(c[Z>>2]|0)){da=Q;ea=Y;fa=W;ga=_;ha=V;ia=Z;break a}}}while(0);KIb(Q,16,2517224,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}}while(0);c[ea>>2]=P;c[da+796>>2]=R;c[fa>>2]=X;c[ga>>2]=U;c[ha>>2]=T;c[ia>>2]=$;c[S>>2]=$|2;ja=ea}else{ja=p+38488|0}Y=c[ja>>2]|0;b:do{if((Y|0)==0){Z=c[D>>2]|0;V=p+4748|0;if((c[Z+944>>2]|0)==0){if((c[V>>2]|0)==0){ka=57}else{la=0}}else{c[V>>2]=0;ka=57}do{if((ka|0)==57){if((c[p+4736>>2]|0)!=0){la=1;break}V=Z+140|0;if((c[Z+796>>2]|0)<9){c[V>>2]=8;ma=Z;break b}else{c[V>>2]=32;ma=Z;break b}}}while(0);Q=c[Z+796>>2]|0;if((Q|0)<9){V=(c[p+4740>>2]<<4)+(c[p+4744>>2]|0)|0;if(!la){if((V|0)==0){c[Z+140>>2]=299;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=300;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=35;ma=Z;break}else{ma=Z;break}}switch(V|0){case 1:{c[Z+140>>2]=33;ma=Z;break b;break};case 16:{c[Z+140>>2]=4;ma=Z;break b;break};case 17:{c[Z+140>>2]=0;ma=Z;break b;break};case 32:{c[Z+140>>2]=7;ma=Z;break b;break};case 34:{c[Z+140>>2]=6;ma=Z;break b;break};case 0:{c[Z+140>>2]=5;ma=Z;break b;break};default:{ma=Z;break b}}}if((Q|0)==9){c[p+38516>>2]=1;V=(c[p+4740>>2]<<4)+(c[p+4744>>2]|0)|0;if(la){if((V|0)==17){c[Z+140>>2]=70;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=80;ma=Z;break}else if((V|0)==0){c[Z+140>>2]=76;ma=Z;break}else{ma=Z;break}}else{if((V|0)==0){c[Z+140>>2]=96;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=92;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=94;ma=Z;break}else{ma=Z;break}}}else if((Q|0)==16){V=(c[p+4740>>2]<<4)+(c[p+4744>>2]|0)|0;if(la){if((V|0)==16){c[Z+140>>2]=56;ma=Z;break}else if((V|0)==0){c[Z+140>>2]=58;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=54;ma=Z;break}else{ma=Z;break}}else{if((V|0)==0){c[Z+140>>2]=108;ma=Z;break}else if((V|0)==16){c[Z+140>>2]=106;ma=Z;break}else if((V|0)==17){c[Z+140>>2]=104;ma=Z;break}else{ma=Z;break}}}else if((Q|0)==10){c[p+38516>>2]=1;Q=(c[p+4740>>2]<<4)+(c[p+4744>>2]|0)|0;if(la){if((Q|0)==16){c[Z+140>>2]=74;ma=Z;break}else if((Q|0)==17){c[Z+140>>2]=72;ma=Z;break}else if((Q|0)==0){c[Z+140>>2]=78;ma=Z;break}else{ma=Z;break}}else{if((Q|0)==17){c[Z+140>>2]=98;ma=Z;break}else if((Q|0)==16){c[Z+140>>2]=100;ma=Z;break}else if((Q|0)==0){c[Z+140>>2]=102;ma=Z;break}else{ma=Z;break}}}else{ma=Z;break}}else if((Y|0)==1){do{if((c[p+4740>>2]|0)==0){if((c[p+4744>>2]|0)!=0){break}Q=c[D>>2]|0;V=c[Q+796>>2]|0;if((V|0)==14){c[Q+140>>2]=316;ma=Q;break b}else if((V|0)==10){c[Q+140>>2]=86;ma=Q;break b}else if((V|0)==12){c[Q+140>>2]=314;ma=Q;break b}else if((V|0)==9){c[Q+140>>2]=84;ma=Q;break b}else{V=Q+140|0;if((c[p+4748>>2]|0)==0){c[V>>2]=298;ma=Q;break b}else{c[V>>2]=30;ma=Q;break b}}}}while(0);KIb(c[D>>2]|0,16,2503240,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-38;i=j;return N|0}else{KIb(c[D>>2]|0,16,2490088,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-38;i=j;return N|0}}while(0);if((c[ma+140>>2]|0)==-1){KIb(ma,16,2479232,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-38;i=j;return N|0}Y=c[C>>2]|0;c:do{if((Y|0)<2){S=Rda(O,p+15124|0)|0;if((S|0)>=0){na=S;oa=c[p+40796>>2]|0;break}KIb(c[D>>2]|0,16,2469400,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}else{if((Y|0)<3){S=Qda(O,L,0)|0;c[p+40796>>2]=S;na=-1;oa=S;break}S=c[K+544>>2]|0;T=p+40796|0;U=K+536|0;P=p+38496|0;c[T>>2]=0;Z=0;Q=S;while(1){S=Q-(c[U>>2]|0)|0;if((S|0)<=3){na=-1;oa=Z;break c}V=-((c[P>>2]|0)!=0|0)&5;_=-3-V|0;W=V+3+((d[Q+(_+1)|0]|0)<<8|(d[Q+_|0]|0)<<16|(d[Q+(_+2)|0]|0))|0;if((W|0)>(S|0)){na=-1;oa=Z;break c}S=Z+1|0;c[T>>2]=S;if((S|0)<256){Z=S;Q=Q+(-W|0)|0}else{na=-1;oa=S;break}}}}while(0);K=p+40796|0;if(oa>>>0>256>>>0|(oa|0)<1){KIb(c[D>>2]|0,16,2460200,(M=i,i=i+8|0,c[M>>2]=oa,M)|0);i=M;N=-1094995529;i=j;return N|0}d:do{if((oa|0)>0){Y=p+4796|0;Q=p+38516|0;Z=p+4728|0;T=p+4732|0;P=p+40804|0;U=p+40800|0;S=p+4792|0;W=p+38524|0;_=p+15124|0;V=na;ba=0;e:while(1){aa=c[q+39772+(ba<<2)>>2]|0;c[aa+4796>>2]=c[Y>>2];c[aa+38516>>2]=c[Q>>2];c[aa+38504>>2]=0;if((c[C>>2]|0)==2){pa=Qda(O,L,0)|0;qa=aa+40816|0;c[qa>>2]=ca(c[Z>>2]|0,pa)|0;pa=Qda(O,L,0)|0;ra=aa+40820|0;c[ra>>2]=ca(c[T>>2]|0,pa)|0;pa=(Qda(O,L,0)|0)+1|0;sa=ca(pa,c[Z>>2]|0)|0;pa=aa+40808|0;c[pa>>2]=sa+(c[qa>>2]|0);sa=(Qda(O,L,0)|0)+1|0;ta=ca(sa,c[T>>2]|0)|0;sa=c[ra>>2]|0;ua=ta+sa|0;ta=aa+40812|0;c[ta>>2]=ua;va=(c[qa>>2]|0)/(c[P>>2]|0)|0;c[qa>>2]=va;qa=(sa|0)/(c[U>>2]|0)|0;c[ra>>2]=qa;ra=((c[pa>>2]|0)/(c[P>>2]|0)|0)-va|0;c[pa>>2]=ra;pa=((ua|0)/(c[U>>2]|0)|0)-qa|0;c[ta>>2]=pa;ta=c[Z>>2]|0;if(ra>>>0>ta>>>0){N=-1094995529;ka=188;break}ua=c[T>>2]|0;if(pa>>>0>ua>>>0){N=-1094995529;ka=188;break}sa=wrc(ra,(ra|0)<0|0?-1:0,va,0)|0;va=G;ra=(ta|0)<0|0?-1:0;if(va>>>0>ra>>>0|va>>>0==ra>>>0&sa>>>0>ta>>>0){N=-1094995529;ka=188;break}ta=wrc(pa,(pa|0)<0|0?-1:0,qa,0)|0;qa=G;pa=(ua|0)<0|0?-1:0;if(qa>>>0>pa>>>0|qa>>>0==pa>>>0&ta>>>0>ua>>>0){N=-1094995529;ka=188;break}}if((c[S>>2]|0)>0){ua=V;ta=0;while(1){pa=aa+4804+(ta*2580|0)|0;if((c[C>>2]|0)==2){qa=Qda(O,L,0)|0;if(qa>>>0>(c[W>>2]|0)>>>0){ka=138;break e}c[aa+4804+(ta*2580|0)+2560>>2]=qa;nrc(pa|0,q+17684+(qa*2560|0)|0,2560)|0;wa=c[q+38164+(qa<<2)>>2]|0}else{nrc(pa|0,_|0,2560)|0;wa=ua}if((c[C>>2]|0)<3){if(!((wa|0)>-1)){ka=143;break e}pa=aa+4804+(ta*2580|0)+2564|0;if((c[pa>>2]|0)<(wa|0)){mJb(aa+4804+(ta*2580|0)+2568|0);mJb(aa+4804+(ta*2580|0)+2572|0)}c[pa>>2]=wa}pa=ta+1|0;if((pa|0)<(c[S>>2]|0)){ua=wa;ta=pa}else{xa=wa;break}}}else{xa=V}ta=ba+1|0;if((ta|0)<(c[K>>2]|0)){V=xa;ba=ta}else{break d}}if((ka|0)==138){KIb(c[D>>2]|0,16,2568792,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}else if((ka|0)==143){KIb(0,0,2640600,(M=i,i=i+24|0,c[M>>2]=2443552,c[M+8>>2]=2590416,c[M+16>>2]=814,M)|0);i=M;Hd();return 0}else if((ka|0)==188){i=j;return N|0}}}while(0);c[J>>2]=1}}while(0);xa=J5a(b,B,1)|0;if((xa|0)<0){N=xa;i=j;return N|0}if((c[b+688>>2]&1|0)==0){ya=p+40796|0}else{xa=c[A+84>>2]|0;wa=c[p+4796>>2]|0;q=c[p+38496>>2]|0;na=p+40796|0;oa=c[na>>2]|0;ma=c[(c[D>>2]|0)+796>>2]|0;KIb(b,48,2364832,(M=i,i=i+48|0,c[M>>2]=c[C>>2],c[M+8>>2]=xa,c[M+16>>2]=wa,c[M+24>>2]=q,c[M+32>>2]=oa,c[M+40>>2]=ma,M)|0);i=M;ya=na}K5a(b);na=c[ya>>2]|0;if((na|0)>0){ma=p+38496|0;oa=u+536|0;u=g+8|0;q=g+16|0;g=b+888|0;wa=b+892|0;xa=n+o|0;n=na;while(1){la=n-1|0;za=c[s+(la<<2)>>2]|0;ja=c[ma>>2]|0;ea=-((ja|0)!=0|0)&5;$=ea+3|0;ia=(la|0)!=0;do{if(ia){ka=161}else{if((c[C>>2]|0)>2){ka=161;break}ha=c[oa>>2]|0;ga=xa;Aa=ga-ha|0;Ba=ha;Ca=ga}}while(0);if((ka|0)==161){ka=0;J=-3-ea|0;Aa=$+((d[xa+(J+1)|0]|0)<<8|(d[xa+J|0]|0)<<16|(d[xa+(J+2)|0]|0))|0;Ba=c[oa>>2]|0;Ca=xa}if((Ca-Ba|0)<(Aa|0)){ka=164;break}J=xa+(-Aa|0)|0;do{if((ja|0)!=0){ga=EGb(DGb(3)|0,0,J,Aa)|0;if((ga|0)==0){break}ha=c[u>>2]|0;X=c[u+4>>2]|0;do{if((ha|0)==0&(X|0)==(-2147483648|0)){fa=c[q>>2]|0;R=c[q+4>>2]|0;KIb(c[D>>2]|0,16,2248600,(M=i,i=i+8|0,c[M>>2]=ga,M)|0);i=M;if(!((fa|0)==0&(R|0)==(-2147483648|0))){Da=R;Ea=fa;ka=171;break}KIb(c[D>>2]|0,16,2146664,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M}else{KIb(c[D>>2]|0,16,2248600,(M=i,i=i+8|0,c[M>>2]=ga,M)|0);i=M;Da=X;Ea=ha;ka=171}}while(0);do{if((ka|0)==171){ka=0;ha=c[g>>2]|0;X=c[D>>2]|0;if((ha|0)==0){KIb(X,16,2174240,(M=i,i=i+16|0,c[M>>2]=Ea,c[M+8>>2]=Da,M)|0);i=M;break}else{KIb(X,16,2206536,(M=i,i=i+8|0,h[M>>3]=(+(Ea>>>0)+ +(Da|0)*4294967296.0)*(+(ha|0)/+(c[wa>>2]|0)),M)|0);i=M;break}}}while(0);c[za+38504>>2]=1}}while(0);if(!ia){ka=176;break}TYa(za+8|0,J,Aa);c[za+4>>2]=b;c[za+4788>>2]=A;if((la|0)>0){xa=J;n=la}else{break}}if((ka|0)==164){KIb(b,16,2299592,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;N=-1094995529;i=j;return N|0}else if((ka|0)==176){c[za+544>>2]=xa;c[za+4>>2]=b;c[za+4788>>2]=A}Fa=c[ya>>2]|0}else{Fa=na}se[c[b+824>>2]&127](b,648,r,0,Fa,4)|0;Fa=c[ya>>2]|0;if((Fa|0)>0){ya=p+4740|0;r=p+4744|0;na=m|0;za=A+32|0;xa=l|0;ka=b+140|0;M=Fa;do{M=M-1|0;Fa=c[s+(M<<2)>>2]|0;do{if((c[Fa+38504>>2]|0)!=0){if((c[c[y>>2]>>2]|0)==0){break}M5a(x,2147483647,0);n=c[Fa+40820>>2]|0;Aa=c[Fa+40816>>2]|0;c[na>>2]=(c[A>>2]|0)+((ca(n,c[za>>2]|0)|0)+Aa);wa=c[y>>2]|0;c[xa>>2]=(c[wa>>2]|0)+((ca(n,c[wa+32>>2]|0)|0)+Aa);wa=n>>c[r>>2];Da=Aa>>c[ya>>2];c[m+4>>2]=(c[A+4>>2]|0)+((ca(wa,c[A+36>>2]|0)|0)+Da);Ea=c[y>>2]|0;c[l+4>>2]=(c[Ea+4>>2]|0)+((ca(wa,c[Ea+36>>2]|0)|0)+Da);Da=n>>c[r>>2];Ea=Aa>>c[ya>>2];c[m+8>>2]=(c[A+8>>2]|0)+((ca(Da,c[A+40>>2]|0)|0)+Ea);wa=c[y>>2]|0;c[l+8>>2]=(c[wa+8>>2]|0)+((ca(Da,c[wa+40>>2]|0)|0)+Ea);c[m+12>>2]=(c[A+12>>2]|0)+((ca(n,c[A+44>>2]|0)|0)+Aa);Ea=c[y>>2]|0;c[l+12>>2]=(c[Ea+12>>2]|0)+((ca(n,c[Ea+44>>2]|0)|0)+Aa);vIb(na,za,xa,(c[y>>2]|0)+32|0,c[ka>>2]|0,c[Fa+40808>>2]|0,c[Fa+40812>>2]|0)}}while(0);}while((M|0)>0)}L5a(B,2147483647,0);B=p+4756|0;c[B>>2]=(c[B>>2]|0)+1;if((c[y>>2]|0)!=0){H5a(b,x)}c[w>>2]=0;w=YHb(e,c[z>>2]|0)|0;if((w|0)<0){N=w;i=j;return N|0}c[f>>2]=1;N=o;i=j;return N|0}function Nda(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0;h=i;i=i+64|0;j=h|0;k=h+32|0;l=c[g>>2]|0;g=l;m=l+4|0;n=c[(c[m>>2]|0)+60>>2]|0;o=(e[(qKb(c[f+140>>2]|0)|0)+8>>1]|0)>>>2&7;f=n+4788|0;p=c[f>>2]|0;q=n+39772|0;r=0;while(1){s=q+(r<<2)|0;if((g|0)==(c[s>>2]|0)){break}else{r=r+1|0}}q=n;t=o+1|0;o=n+4784|0;do{if((c[o>>2]|0)!=0){u=p+84|0;if((c[u>>2]|0)!=0){break}M5a(n+4772|0,r,0);v=c[o>>2]|0;if((v|0)==0){break}if((c[u>>2]|0)!=0){break}u=c[v+39772+(r<<2)>>2]|0;v=c[s>>2]|0;w=v+38504|0;c[w>>2]=c[w>>2]|c[u+38504>>2];w=n+4792|0;if((c[w>>2]|0)<=0){break}x=u+4796|0;y=0;do{z=v+4804+(y*2580|0)+2568|0;kJb(c[z>>2]|0);A=v+4804+(y*2580|0)+2572|0;kJb(c[A>>2]|0);nrc(v+4804+(y*2580|0)|0,u+4804+(y*2580|0)|0,2580)|0;c[z>>2]=0;c[A>>2]=0;B=u+4804+(y*2580|0)+2564|0;C=c[B>>2]|0;if((c[x>>2]|0)==0){D=hJb(C*6|0)|0;c[A>>2]=D;nrc(D|0,c[u+4804+(y*2580|0)+2572>>2]|0,(c[B>>2]|0)*6|0)|0}else{D=hJb(C<<5)|0;c[z>>2]=D;nrc(D|0,c[u+4804+(y*2580|0)+2568>>2]|0,c[B>>2]<<5)|0}y=y+1|0;}while((y|0)<(c[w>>2]|0))}}while(0);s=l+40832|0;c[s>>2]=1;o=l+40836|0;c[o>>2]=1;w=n+4720|0;a:do{if((c[w>>2]|0)>2){if((Jpb(q,g)|0)<0){E=-12;i=h;return E|0}y=k|0;u=l+8|0;x=u;mrc(y|0,-128|0,32)|0;if((c[w>>2]|0)<=2){KIb(0,0,2640600,(F=i,i=i+24|0,c[F>>2]=2617888,c[F+8>>2]=2590416,c[F+16>>2]=286,F)|0);i=F;Hd();return 0}v=Qda(x,y,0)|0;B=n+4728|0;D=l+40816|0;c[D>>2]=ca(c[B>>2]|0,v)|0;v=Qda(x,y,0)|0;z=n+4732|0;C=l+40820|0;c[C>>2]=ca(c[z>>2]|0,v)|0;v=(Qda(x,y,0)|0)+1|0;A=ca(v,c[B>>2]|0)|0;v=l+40808|0;c[v>>2]=A+(c[D>>2]|0);A=(Qda(x,y,0)|0)+1|0;H=ca(A,c[z>>2]|0)|0;A=c[C>>2]|0;I=H+A|0;H=l+40812|0;c[H>>2]=I;J=n+40804|0;K=(c[D>>2]|0)/(c[J>>2]|0)|0;c[D>>2]=K;D=n+40800|0;L=(A|0)/(c[D>>2]|0)|0;c[C>>2]=L;C=((c[v>>2]|0)/(c[J>>2]|0)|0)-K|0;c[v>>2]=C;v=((I|0)/(c[D>>2]|0)|0)-L|0;c[H>>2]=v;H=c[B>>2]|0;b:do{if(!(C>>>0>H>>>0)){B=c[z>>2]|0;if(v>>>0>B>>>0){break}D=wrc(C,(C|0)<0|0?-1:0,K,0)|0;I=G;J=(H|0)<0|0?-1:0;if(I>>>0>J>>>0|I>>>0==J>>>0&D>>>0>H>>>0){break}D=wrc(v,(v|0)<0|0?-1:0,L,0)|0;J=G;I=(B|0)<0|0?-1:0;if(J>>>0>I>>>0|J>>>0==I>>>0&D>>>0>B>>>0){break}B=n+4792|0;D=(c[B>>2]|0)==0;I=Qda(x,y,0)|0;c:do{if(D){M=I}else{J=n+38524|0;A=0;N=I;while(1){if(N>>>0>(c[J>>2]|0)>>>0){break}c[g+4804+(A*2580|0)+2560>>2]=N;nrc(g+4804+(A*2580|0)|0,q+17684+(N*2560|0)|0,2560)|0;O=c[q+38164+(N<<2)>>2]|0;P=g+4804+(A*2580|0)+2564|0;if((c[P>>2]|0)>>>0<O>>>0){mJb(g+4804+(A*2580|0)+2568|0);mJb(g+4804+(A*2580|0)+2572|0)}c[P>>2]=O;O=A+1|0;P=O>>>0<(c[B>>2]|0)>>>0;Q=Qda(x,y,0)|0;if(P){A=O;N=Q}else{M=Q;break c}}KIb(c[n+4>>2]|0,16,2568792,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;break b}}while(0);if((M|0)==2){B=c[f>>2]|0;c[B+296>>2]=1;c[B+300>>2]=0}else if((M|0)==1){B=c[f>>2]|0;c[B+296>>2]=1;c[B+300>>2]=1}else if((M|0)==3){c[(c[f>>2]|0)+296>>2]=0}B=Qda(x,y,0)|0;c[(c[f>>2]|0)+124>>2]=B;B=Qda(x,y,0)|0;c[(c[f>>2]|0)+128>>2]=B;if((c[l+4720>>2]|0)<=3){break a}B=l+12|0;I=c[B>>2]|0;D=d[y]|0;N=(ca(D,I)|0)>>8;A=I-N|0;c[B>>2]=A;I=u;J=c[I>>2]|0;do{if((J|0)<(A|0)){a[y]=a[g+24+D|0]|0;if((A|0)>=256){R=0;break}c[B>>2]=A<<8;Q=J<<8;c[I>>2]=Q;O=l+540|0;P=c[O>>2]|0;if(P>>>0<(c[l+544>>2]|0)>>>0){c[I>>2]=d[P]|Q}c[O>>2]=P+1;R=0}else{P=J-A|0;c[I>>2]=P;a[y]=a[g+280+D|0]|0;c[B>>2]=N;if((N|0)>=256){R=1;break}c[B>>2]=N<<8;O=P<<8;c[I>>2]=O;P=l+540|0;Q=c[P>>2]|0;if(Q>>>0<(c[l+544>>2]|0)>>>0){c[I>>2]=d[Q]|O}c[P>>2]=Q+1;R=1}}while(0);c[l+40824>>2]=R;I=Qda(x,y,0)|0;c[l+40828>>2]=I;if((I|0)==1){break a}c[s>>2]=Qda(x,y,0)|0;I=Qda(x,y,0)|0;c[o>>2]=I;N=c[s>>2]|0;B=wrc(N,(N|0)<0|0?-1:0,I,(I|0)<0|0?-1:0)|0;I=G;N=0;if(!(I>>>0>N>>>0|I>>>0==N>>>0&B>>>0>4>>>0)){break a}KIb(c[n+4>>2]|0,16,2550784,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F}}while(0);c[l+38504>>2]=1;E=-1094995529;i=h;return E|0}}while(0);R=Jpb(q,g)|0;if((R|0)<0){E=R;i=h;return E|0}if((c[(c[f>>2]|0)+84>>2]|0)==0){if((c[l+40824>>2]|0)!=0){S=49}}else{S=49}if((S|0)==49){Npb(q,g)}q=c[l+40808>>2]|0;f=c[l+40812>>2]|0;R=c[l+40816>>2]|0;M=c[l+40820>>2]|0;k=l+4796|0;if((c[k>>2]|0)==0){y=c[w>>2]|0;if((y|0)==3){if((c[n+4724>>2]|0)>1){S=54}}else{if((y|0)>3){S=54}}do{if((S|0)==54){y=l+12|0;x=c[y>>2]|0;u=(x*129|0)>>8;L=x-u|0;c[y>>2]=L;x=l+8|0;v=c[x>>2]|0;if((v|0)<(L|0)){if((L|0)>=256){break}c[y>>2]=L<<8;H=v<<8;c[x>>2]=H;K=l+540|0;C=c[K>>2]|0;if(C>>>0<(c[l+544>>2]|0)>>>0){c[x>>2]=d[C]|H}c[K>>2]=C+1;break}else{C=v-L|0;c[x>>2]=C;c[y>>2]=u;if((u|0)>=256){break}c[y>>2]=u<<8;u=C<<8;c[x>>2]=u;C=l+540|0;y=c[C>>2]|0;if(y>>>0<(c[l+544>>2]|0)>>>0){c[x>>2]=d[y]|u}c[C>>2]=y+1;break}}}while(0);do{if((c[w>>2]|0)>2){S=66}else{if((M|R|0)==0){S=66;break}T=0;U=c[l+536>>2]|0}}while(0);if((S|0)==66){S=c[l+536>>2]|0;T=(c[l+540>>2]|0)-1-S|0;U=S}c[l+4800>>2]=T;S=U+T|0;y=(c[l+544>>2]|0)-(U+T)<<3;T=y>>>0>2147483639>>>0|(S|0)==0;U=T?0:S;S=T?0:y;c[l+548>>2]=U;c[l+560>>2]=S;c[l+564>>2]=S+8;c[l+552>>2]=U+(S>>3);c[l+556>>2]=0}do{if((c[n+38488>>2]|0)==0){S=c[n+4740>>2]|0;U=-(-q>>S)|0;y=c[n+4744>>2]|0;T=-(-f>>y)|0;C=M>>y;y=ca(R,t)|0;u=c[p+32>>2]|0;Oda(g,(c[p>>2]|0)+((ca(u,M)|0)+y)|0,q,f,u,0);if((c[n+4736>>2]|0)!=0){u=ca(R>>S,t)|0;S=c[p+36>>2]|0;Oda(g,(c[p+4>>2]|0)+((ca(S,C)|0)+u)|0,U,T,S,1);S=c[p+40>>2]|0;Oda(g,(c[p+8>>2]|0)+((ca(S,C)|0)+u)|0,U,T,S,1)}if((c[l+4748>>2]|0)==0){break}S=c[p+44>>2]|0;Oda(g,(c[p+12>>2]|0)+((ca(S,M)|0)+y)|0,q,f,S,2)}else{S=c[p>>2]|0;y=ca(R,t)|0;T=p+32|0;U=(ca(c[T>>2]|0,M)|0)+y|0;u=c[p+4>>2]|0;C=p+36|0;x=c[C>>2]|0;L=c[p+8>>2]|0;v=p+40|0;K=c[v>>2]|0;H=c[(c[m>>2]|0)+796>>2]|0;z=(H|0)>0?H:8;B=c[l+38492>>2]|0;N=q+6|0;c[j>>2]=B+6;I=j+4|0;c[I>>2]=B+(q+9<<1);c[j+8>>2]=B+((N<<1)+3<<1);D=j+12|0;c[D>>2]=B+((N*3|0)+3<<1);c[j+16>>2]=B+((N<<2|3)<<1);A=j+20|0;c[A>>2]=B+((N*5|0)+3<<1);c[j+24>>2]=B+((N*6|0)+3<<1);J=j+28|0;c[J>>2]=B+((N*7|0)+3<<1);N=(H|0)<9;H=1<<z;Q=l+38484|0;c[Q>>2]=0;mrc(B|0,0,(q<<4)+96|0)|0;if((f|0)<=0){break}B=l+4748|0;P=(q|0)>0;O=l+40828|0;V=q-1|0;W=l+548|0;X=W;Y=l+556|0;Z=W;W=l+564|0;_=l+12|0;$=l+8|0;aa=l+540|0;ba=l+544|0;da=q<<1;ea=(ca(x,M)|0)+y|0;x=(ca(K,M)|0)+y|0;y=0;do{if(((c[B>>2]|0)+3|0)>0){K=0;do{fa=j+(K<<3)|0;ga=c[fa>>2]|0;ha=j+(K<<3)+4|0;ia=c[ha>>2]|0;c[fa>>2]=ia;c[ha>>2]=ga;ha=ga-2|0;b[ha>>1]=b[ia>>1]|0;b[ia+(q<<1)>>1]=b[ia+(V<<1)>>1]|0;fa=c[O>>2]|0;K=K+1|0;ja=(K|0)/2|0;d:do{if(N&(fa|0)==0){ka=c[Q>>2]|0;if(P){la=g+4804+(ja*2580|0)+1790|0;ma=g+4804+(ja*2580|0)+2572|0;na=g+4804+(ja*2580|0)+2568|0;oa=0;pa=0;qa=0;ra=ka;sa=b[ha>>1]|0;while(1){ta=ia+(oa<<1)|0;ua=oa+1|0;va=oa-1|0;wa=ia+(va<<1)|0;xa=b[wa>>1]|0;ya=b[ta>>1]|0;za=b[ia+(ua<<1)>>1]|0;Aa=sa<<16>>16;if((b[la>>1]|0)==0){Ba=(b[g+4804+(ja*2580|0)+512+((xa-ya&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+((Aa-xa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1024+((ya-za&255)<<1)>>1]|0)|0}else{Ba=(b[g+4804+(ja*2580|0)+512+((xa-ya&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+((Aa-xa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1024+((ya-za&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1536+(((e[ga+(oa-2<<1)>>1]|0)-Aa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+2048+(((e[ga+(oa<<1)>>1]|0)-ya&255)<<1)>>1]|0)|0}ya=(Ba|0)<0?-Ba|0:Ba;do{if((c[k>>2]|0)==0){Aa=(ya|qa|0)==0?1:qa;if((Aa|0)==0){Ca=Pda(X,(c[ma>>2]|0)+(ya*6|0)|0,9)|0;Da=ra;Ea=0;Fa=pa;break}do{if((pa|0)==0&(Aa|0)==1){za=c[Y>>2]|0;xa=c[Z>>2]|0;Ga=d[xa+(za>>>3)|0]|0;Ha=c[W>>2]|0;Ia=((za|0)<(Ha|0))+za|0;c[Y>>2]=Ia;Ja=a[1359920+ra|0]|0;if((Ga&128>>>((za&7)>>>0)|0)!=0){za=1<<(Ja&255);Ka=((za+oa|0)<=(q|0))+ra|0;La=1;Ma=za;break}if(Ja<<24>>24==0){Na=0}else{za=Ja&255;Ja=xa+(Ia>>>3)|0;xa=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Ia&7)>>>((32-za|0)>>>0);Ja=Ia+za|0;c[Y>>2]=Ha>>>0>Ja>>>0?Ja:Ha;Na=xa}Ka=(ra|0)==0?0:ra-1|0;La=2;Ma=Na}else{Ka=ra;La=Aa;Ma=pa}}while(0);Aa=Ma-1|0;if((Aa|0)>=0){Ca=0;Da=Ka;Ea=La;Fa=Aa;break}Aa=Pda(X,(c[ma>>2]|0)+(ya*6|0)|0,9)|0;Ca=(Aa>>>31^1)+Aa|0;Da=Ka;Ea=0;Fa=0}else{Aa=c[na>>2]|0;xa=Aa+(ya<<5)|0;Ha=c[_>>2]|0;Ja=(ca(d[xa]|0,Ha)|0)>>8;za=Ha-Ja|0;c[_>>2]=za;Ha=c[$>>2]|0;if((Ha|0)>=(za|0)){c[$>>2]=Ha-za;a[xa]=a[(d[xa]|0)+(g+280)|0]|0;c[_>>2]=Ja;if((Ja|0)>=256){Ca=0;Da=ra;Ea=qa;Fa=pa;break}c[_>>2]=Ja<<8;Ja=c[$>>2]<<8;c[$>>2]=Ja;za=c[aa>>2]|0;if(za>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[za]|Ja}c[aa>>2]=za+1;Ca=0;Da=ra;Ea=qa;Fa=pa;break}a[xa]=a[(d[xa]|0)+(g+24)|0]|0;xa=c[_>>2]|0;if((xa|0)<256){za=xa<<8;c[_>>2]=za;Ja=c[$>>2]<<8;c[$>>2]=Ja;Ha=c[aa>>2]|0;if(Ha>>>0<(c[ba>>2]|0)>>>0){Ia=d[Ha]|Ja;c[$>>2]=Ia;Oa=Ia}else{Oa=Ja}c[aa>>2]=Ha+1;Pa=za;Qa=Oa}else{Pa=xa;Qa=c[$>>2]|0}xa=Aa+(ya<<5)+1|0;za=(ca(d[xa]|0,Pa)|0)>>8;Ha=Pa-za|0;c[_>>2]=Ha;if((Qa|0)<(Ha|0)){Ra=0;Sa=xa}else{Ja=1;Ia=xa;xa=za;za=Ha;Ha=Qa;while(1){c[$>>2]=Ha-za;a[Ia]=a[(d[Ia]|0)+(g+280)|0]|0;c[_>>2]=xa;if((xa|0)<256){Ga=xa<<8;c[_>>2]=Ga;Ta=c[$>>2]<<8;c[$>>2]=Ta;Ua=c[aa>>2]|0;if(Ua>>>0<(c[ba>>2]|0)>>>0){Va=d[Ua]|Ta;c[$>>2]=Va;Wa=Va}else{Wa=Ta}c[aa>>2]=Ua+1;Xa=Ga;Ya=Wa}else{Xa=xa;Ya=c[$>>2]|0}Ga=Ja+1|0;Ua=((Ja|0)>9?10:Ga)+(Aa+(ya<<5))|0;Ta=(ca(d[Ua]|0,Xa)|0)>>8;Va=Xa-Ta|0;c[_>>2]=Va;if((Ya|0)<(Va|0)){Ra=Ja;Sa=Ua;break}else{Ja=Ga;Ia=Ua;xa=Ta;za=Va;Ha=Ya}}}a[Sa]=a[(d[Sa]|0)+(g+24)|0]|0;Ha=c[_>>2]|0;if((Ha|0)<256){za=Ha<<8;c[_>>2]=za;xa=c[$>>2]<<8;c[$>>2]=xa;Ia=c[aa>>2]|0;if(Ia>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Ia]|xa}c[aa>>2]=Ia+1;Za=za}else{Za=Ha}e:do{if((Ra|0)>0){Ha=2;za=Ra;Ia=Za;while(1){xa=za-1|0;Ja=((xa|0)>9?31:za+21|0)+(Aa+(ya<<5))|0;Va=(ca(d[Ja]|0,Ia)|0)>>8;Ta=Ia-Va|0;c[_>>2]=Ta;Ua=c[$>>2]|0;do{if((Ua|0)<(Ta|0)){a[Ja]=a[(d[Ja]|0)+(g+24)|0]|0;Ga=c[_>>2]|0;if((Ga|0)>=256){_a=0;$a=Ga;break}ab=Ga<<8;c[_>>2]=ab;Ga=c[$>>2]<<8;c[$>>2]=Ga;bb=c[aa>>2]|0;if(bb>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[bb]|Ga}c[aa>>2]=bb+1;_a=0;$a=ab}else{c[$>>2]=Ua-Ta;a[Ja]=a[(d[Ja]|0)+(g+280)|0]|0;c[_>>2]=Va;if((Va|0)>=256){_a=1;$a=Va;break}ab=Va<<8;c[_>>2]=ab;bb=c[$>>2]<<8;c[$>>2]=bb;Ga=c[aa>>2]|0;if(Ga>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Ga]|bb}c[aa>>2]=Ga+1;_a=1;$a=ab}}while(0);Va=_a|Ha;if((xa|0)<=0){cb=Va;db=$a;break e}Ha=Va<<1;za=xa;Ia=$a}}else{cb=1;db=Za}}while(0);Ia=((Ra|0)>10?21:Ra+11|0)+(Aa+(ya<<5))|0;za=(ca(d[Ia]|0,db)|0)>>8;Ha=db-za|0;c[_>>2]=Ha;Va=c[$>>2]|0;do{if((Va|0)<(Ha|0)){a[Ia]=a[(d[Ia]|0)+(g+24)|0]|0;Ja=c[_>>2]|0;if((Ja|0)>=256){eb=0;break}c[_>>2]=Ja<<8;Ja=c[$>>2]<<8;c[$>>2]=Ja;Ta=c[aa>>2]|0;if(Ta>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Ta]|Ja}c[aa>>2]=Ta+1;eb=0}else{c[$>>2]=Va-Ha;a[Ia]=a[(d[Ia]|0)+(g+280)|0]|0;c[_>>2]=za;if((za|0)>=256){eb=1;break}c[_>>2]=za<<8;Ta=c[$>>2]<<8;c[$>>2]=Ta;Ja=c[aa>>2]|0;if(Ja>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Ja]|Ta}c[aa>>2]=Ja+1;eb=1}}while(0);Ca=(cb^-eb)+eb|0;Da=ra;Ea=qa;Fa=pa}}while(0);ya=(Ba|0)>-1?Ca:-Ca|0;za=b[ta>>1]|0;Ia=b[ga+(va<<1)>>1]|0;Ha=za+Ia-(b[wa>>1]|0)|0;do{if((Ia|0)>(Ha|0)){if((za|0)<=(Ha|0)){fb=Ha;break}fb=(za|0)>(Ia|0)?Ia:za}else{if((Ha|0)<=(za|0)){fb=Ha;break}fb=(za|0)>(Ia|0)?za:Ia}}while(0);Ia=fb+ya&511;b[ga+(oa<<1)>>1]=Ia;if((ua|0)<(q|0)){oa=ua;pa=Fa;qa=Ea;ra=Da;sa=Ia}else{gb=Da;break}}}else{gb=ka}c[Q>>2]=gb}else{sa=((fa|0)!=1)+z|0;ra=c[Q>>2]|0;if((fa|0)==1){if(!P){break}if((sa|0)<=0){mrc(ga|0,0,da|0)|0;break}qa=0;pa=c[_>>2]|0;oa=c[$>>2]|0;while(1){na=1;ma=0;la=pa;Ia=oa;while(1){za=la>>1;Ha=la-za|0;c[_>>2]=Ha;do{if((Ia|0)<(Ha|0)){if((Ha|0)>=256){hb=0;ib=Ha;jb=Ia;break}wa=Ha<<8;c[_>>2]=wa;va=Ia<<8;c[$>>2]=va;ta=c[aa>>2]|0;if(ta>>>0<(c[ba>>2]|0)>>>0){Va=d[ta]|va;c[$>>2]=Va;kb=Va}else{kb=va}c[aa>>2]=ta+1;hb=0;ib=wa;jb=kb}else{wa=Ia-Ha|0;c[$>>2]=wa;c[_>>2]=za;if((za|0)>=256){hb=1;ib=za;jb=wa;break}ta=za<<8;c[_>>2]=ta;va=wa<<8;c[$>>2]=va;wa=c[aa>>2]|0;if(wa>>>0<(c[ba>>2]|0)>>>0){Va=d[wa]|va;c[$>>2]=Va;lb=Va}else{lb=va}c[aa>>2]=wa+1;hb=1;ib=ta;jb=lb}}while(0);mb=hb|ma;if((na|0)>=(sa|0)){break}na=na+1|0;ma=mb<<1;la=ib;Ia=jb}b[ga+(qa<<1)>>1]=mb;Ia=qa+1|0;if((Ia|0)<(q|0)){qa=Ia;pa=ib;oa=jb}else{break d}}}if(P){oa=g+4804+(ja*2580|0)+1790|0;pa=g+4804+(ja*2580|0)+2572|0;qa=(1<<sa)+65535|0;ka=g+4804+(ja*2580|0)+2568|0;Ia=0;la=0;ma=0;na=ra;ua=b[ha>>1]|0;while(1){ya=ia+(Ia<<1)|0;za=Ia+1|0;Ha=Ia-1|0;ta=ia+(Ha<<1)|0;wa=b[ta>>1]|0;va=b[ya>>1]|0;Va=b[ia+(za<<1)>>1]|0;Aa=ua<<16>>16;if((b[oa>>1]|0)==0){nb=(b[g+4804+(ja*2580|0)+512+((wa-va&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+((Aa-wa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1024+((va-Va&255)<<1)>>1]|0)|0}else{nb=(b[g+4804+(ja*2580|0)+512+((wa-va&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+((Aa-wa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1024+((va-Va&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+1536+(((e[ga+(Ia-2<<1)>>1]|0)-Aa&255)<<1)>>1]|0)+(b[g+4804+(ja*2580|0)+2048+(((e[ga+(Ia<<1)>>1]|0)-va&255)<<1)>>1]|0)|0}va=(nb|0)<0?-nb|0:nb;do{if((c[k>>2]|0)==0){Aa=(va|ma|0)==0?1:ma;if((Aa|0)==0){ob=Pda(X,(c[pa>>2]|0)+(va*6|0)|0,sa)|0;pb=na;qb=0;rb=la;break}do{if((la|0)==0&(Aa|0)==1){Va=c[Y>>2]|0;wa=c[Z>>2]|0;Ja=d[wa+(Va>>>3)|0]|0;Ta=c[W>>2]|0;Ua=((Va|0)<(Ta|0))+Va|0;c[Y>>2]=Ua;ab=a[1359920+na|0]|0;if((Ja&128>>>((Va&7)>>>0)|0)!=0){Va=1<<(ab&255);sb=((Va+Ia|0)<=(q|0))+na|0;tb=1;ub=Va;break}if(ab<<24>>24==0){vb=0}else{Va=ab&255;ab=wa+(Ua>>>3)|0;wa=(je(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(Ua&7)>>>((32-Va|0)>>>0);ab=Ua+Va|0;c[Y>>2]=Ta>>>0>ab>>>0?ab:Ta;vb=wa}sb=(na|0)==0?0:na-1|0;tb=2;ub=vb}else{sb=na;tb=Aa;ub=la}}while(0);Aa=ub-1|0;if((Aa|0)>=0){ob=0;pb=sb;qb=tb;rb=Aa;break}Aa=Pda(X,(c[pa>>2]|0)+(va*6|0)|0,sa)|0;ob=(Aa>>>31^1)+Aa|0;pb=sb;qb=0;rb=0}else{Aa=c[ka>>2]|0;wa=Aa+(va<<5)|0;Ta=c[_>>2]|0;ab=(ca(d[wa]|0,Ta)|0)>>8;Va=Ta-ab|0;c[_>>2]=Va;Ta=c[$>>2]|0;if((Ta|0)>=(Va|0)){c[$>>2]=Ta-Va;a[wa]=a[(d[wa]|0)+(g+280)|0]|0;c[_>>2]=ab;if((ab|0)>=256){ob=0;pb=na;qb=ma;rb=la;break}c[_>>2]=ab<<8;ab=c[$>>2]<<8;c[$>>2]=ab;Va=c[aa>>2]|0;if(Va>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Va]|ab}c[aa>>2]=Va+1;ob=0;pb=na;qb=ma;rb=la;break}a[wa]=a[(d[wa]|0)+(g+24)|0]|0;wa=c[_>>2]|0;if((wa|0)<256){Va=wa<<8;c[_>>2]=Va;ab=c[$>>2]<<8;c[$>>2]=ab;Ta=c[aa>>2]|0;if(Ta>>>0<(c[ba>>2]|0)>>>0){Ua=d[Ta]|ab;c[$>>2]=Ua;wb=Ua}else{wb=ab}c[aa>>2]=Ta+1;xb=Va;yb=wb}else{xb=wa;yb=c[$>>2]|0}wa=Aa+(va<<5)+1|0;Va=(ca(d[wa]|0,xb)|0)>>8;Ta=xb-Va|0;c[_>>2]=Ta;if((yb|0)<(Ta|0)){zb=0;Ab=wa}else{ab=1;Ua=wa;wa=Va;Va=Ta;Ta=yb;while(1){c[$>>2]=Ta-Va;a[Ua]=a[(d[Ua]|0)+(g+280)|0]|0;c[_>>2]=wa;if((wa|0)<256){Ja=wa<<8;c[_>>2]=Ja;Ga=c[$>>2]<<8;c[$>>2]=Ga;bb=c[aa>>2]|0;if(bb>>>0<(c[ba>>2]|0)>>>0){Bb=d[bb]|Ga;c[$>>2]=Bb;Cb=Bb}else{Cb=Ga}c[aa>>2]=bb+1;Db=Ja;Eb=Cb}else{Db=wa;Eb=c[$>>2]|0}Ja=ab+1|0;bb=((ab|0)>9?10:Ja)+(Aa+(va<<5))|0;Ga=(ca(d[bb]|0,Db)|0)>>8;Bb=Db-Ga|0;c[_>>2]=Bb;if((Eb|0)<(Bb|0)){zb=ab;Ab=bb;break}else{ab=Ja;Ua=bb;wa=Ga;Va=Bb;Ta=Eb}}}a[Ab]=a[(d[Ab]|0)+(g+24)|0]|0;Ta=c[_>>2]|0;if((Ta|0)<256){Va=Ta<<8;c[_>>2]=Va;wa=c[$>>2]<<8;c[$>>2]=wa;Ua=c[aa>>2]|0;if(Ua>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Ua]|wa}c[aa>>2]=Ua+1;Fb=Va}else{Fb=Ta}f:do{if((zb|0)>0){Ta=2;Va=zb;Ua=Fb;while(1){wa=Va-1|0;ab=((wa|0)>9?31:Va+21|0)+(Aa+(va<<5))|0;Bb=(ca(d[ab]|0,Ua)|0)>>8;Ga=Ua-Bb|0;c[_>>2]=Ga;bb=c[$>>2]|0;do{if((bb|0)<(Ga|0)){a[ab]=a[(d[ab]|0)+(g+24)|0]|0;Ja=c[_>>2]|0;if((Ja|0)>=256){Gb=0;Hb=Ja;break}Ib=Ja<<8;c[_>>2]=Ib;Ja=c[$>>2]<<8;c[$>>2]=Ja;Jb=c[aa>>2]|0;if(Jb>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Jb]|Ja}c[aa>>2]=Jb+1;Gb=0;Hb=Ib}else{c[$>>2]=bb-Ga;a[ab]=a[(d[ab]|0)+(g+280)|0]|0;c[_>>2]=Bb;if((Bb|0)>=256){Gb=1;Hb=Bb;break}Ib=Bb<<8;c[_>>2]=Ib;Jb=c[$>>2]<<8;c[$>>2]=Jb;Ja=c[aa>>2]|0;if(Ja>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Ja]|Jb}c[aa>>2]=Ja+1;Gb=1;Hb=Ib}}while(0);Bb=Gb|Ta;if((wa|0)<=0){Kb=Bb;Lb=Hb;break f}Ta=Bb<<1;Va=wa;Ua=Hb}}else{Kb=1;Lb=Fb}}while(0);Ua=((zb|0)>10?21:zb+11|0)+(Aa+(va<<5))|0;Va=(ca(d[Ua]|0,Lb)|0)>>8;Ta=Lb-Va|0;c[_>>2]=Ta;Bb=c[$>>2]|0;do{if((Bb|0)<(Ta|0)){a[Ua]=a[(d[Ua]|0)+(g+24)|0]|0;ab=c[_>>2]|0;if((ab|0)>=256){Mb=0;break}c[_>>2]=ab<<8;ab=c[$>>2]<<8;c[$>>2]=ab;Ga=c[aa>>2]|0;if(Ga>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[Ga]|ab}c[aa>>2]=Ga+1;Mb=0}else{c[$>>2]=Bb-Ta;a[Ua]=a[(d[Ua]|0)+(g+280)|0]|0;c[_>>2]=Va;if((Va|0)>=256){Mb=1;break}c[_>>2]=Va<<8;Ga=c[$>>2]<<8;c[$>>2]=Ga;ab=c[aa>>2]|0;if(ab>>>0<(c[ba>>2]|0)>>>0){c[$>>2]=d[ab]|Ga}c[aa>>2]=ab+1;Mb=1}}while(0);ob=(Kb^-Mb)+Mb|0;pb=na;qb=ma;rb=la}}while(0);va=(nb|0)>-1?ob:-ob|0;Va=b[ya>>1]|0;Ua=b[ga+(Ha<<1)>>1]|0;Ta=Va+Ua-(b[ta>>1]|0)|0;do{if((Ua|0)>(Ta|0)){if((Va|0)<=(Ta|0)){Nb=Ta;break}Nb=(Va|0)>(Ua|0)?Ua:Va}else{if((Ta|0)<=(Va|0)){Nb=Ta;break}Nb=(Va|0)>(Ua|0)?Va:Ua}}while(0);Ua=Nb+va&qa&65535;b[ga+(Ia<<1)>>1]=Ua;if((za|0)<(q|0)){Ia=za;la=rb;ma=qb;na=pb;ua=Ua}else{Ob=pb;break}}}else{Ob=ra}c[Q>>2]=Ob}}while(0);}while((K|0)<((c[B>>2]|0)+3|0))}if(P){K=c[I>>2]|0;ga=c[D>>2]|0;ja=c[A>>2]|0;ia=c[J>>2]|0;ha=0;do{fa=b[K+(ha<<1)>>1]|0;ua=b[ga+(ha<<1)>>1]|0;na=b[ja+(ha<<1)>>1]|0;if((c[O>>2]|0)==1){Pb=na;Qb=ua;Rb=fa}else{ma=ua-H|0;ua=na-H|0;na=ca(c[s>>2]|0,ma)|0;la=fa-((ca(c[o>>2]|0,ua)|0)+na>>2)|0;Pb=la+ua|0;Qb=la+ma|0;Rb=la}if(N){c[S+((ha<<2)+U+(ca(c[T>>2]|0,y)|0))>>2]=(Rb<<8)+(e[ia+(ha<<1)>>1]<<24)+Qb+(Pb<<16)}else{la=ha<<1;b[S+(la+U+(ca(c[T>>2]|0,y)|0))>>1]=Qb;b[u+(ea+la+(ca(c[C>>2]|0,y)|0))>>1]=Rb;b[L+(x+la+(ca(c[v>>2]|0,y)|0))>>1]=Pb}ha=ha+1|0;}while((ha|0)<(q|0))}y=y+1|0;}while((y|0)<(f|0))}}while(0);do{if((c[k>>2]|0)!=0){if((c[w>>2]|0)<=2){break}f=l+12|0;q=c[f>>2]|0;Pb=(q*129|0)>>8;Rb=q-Pb|0;c[f>>2]=Rb;q=l+8|0;Qb=c[q>>2]|0;do{if((Qb|0)<(Rb|0)){if((Rb|0)>=256){break}c[f>>2]=Rb<<8;o=Qb<<8;c[q>>2]=o;s=l+540|0;Ob=c[s>>2]|0;if(Ob>>>0<(c[l+544>>2]|0)>>>0){c[q>>2]=d[Ob]|o}c[s>>2]=Ob+1}else{Ob=Qb-Rb|0;c[q>>2]=Ob;c[f>>2]=Pb;if((Pb|0)>=256){break}c[f>>2]=Pb<<8;s=Ob<<8;c[q>>2]=s;Ob=l+540|0;o=c[Ob>>2]|0;if(o>>>0<(c[l+544>>2]|0)>>>0){c[q>>2]=d[o]|s}c[Ob>>2]=o+1}}while(0);q=(c[l+544>>2]|0)-2-(c[l+540>>2]|0)+((c[n+38496>>2]|0)*-5|0)|0;if((q|0)==0){break}KIb(c[n+4>>2]|0,16,2122880,(F=i,i=i+8|0,c[F>>2]=q,F)|0);i=F;c[l+38504>>2]=1}}while(0);L5a(n+4760|0,r,0);E=0;i=h;return E|0}function Oda(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0;l=c[f+38492>>2]|0;m=f+38484|0;c[m>>2]=0;mrc(l|0,0,(h<<2)+24|0)|0;if((i|0)<=0){return}n=h-1|0;o=f+4|0;p=f+40828|0;q=(h|0)>0;r=f+12|0;s=f+8|0;t=f+540|0;u=f+544|0;v=f+4804+(k*2580|0)+1790|0;w=f+4796|0;x=f+548|0;y=f+4804+(k*2580|0)+2572|0;z=f+556|0;A=f+548|0;B=f+564|0;C=f+4804+(k*2580|0)+2568|0;D=f+38516|0;E=h<<1;F=l+(h+9<<1)|0;G=l+6|0;l=0;while(1){H=G;I=G-2|0;b[I>>1]=b[F>>1]|0;b[F+(h<<1)>>1]=b[F+(n<<1)>>1]|0;J=c[(c[o>>2]|0)+796>>2]|0;K=c[m>>2]|0;L=(c[p>>2]|0)==1;do{if((J|0)<9){if(L){if(!q){break}M=0;N=c[r>>2]|0;O=c[s>>2]|0;while(1){P=1;Q=0;R=N;S=O;while(1){T=R>>1;U=R-T|0;c[r>>2]=U;do{if((S|0)<(U|0)){if((U|0)>=256){V=0;W=U;X=S;break}Y=U<<8;c[r>>2]=Y;Z=S<<8;c[s>>2]=Z;_=c[t>>2]|0;if(_>>>0<(c[u>>2]|0)>>>0){$=d[_]|Z;c[s>>2]=$;aa=$}else{aa=Z}c[t>>2]=_+1;V=0;W=Y;X=aa}else{Y=S-U|0;c[s>>2]=Y;c[r>>2]=T;if((T|0)>=256){V=1;W=T;X=Y;break}_=T<<8;c[r>>2]=_;Z=Y<<8;c[s>>2]=Z;Y=c[t>>2]|0;if(Y>>>0<(c[u>>2]|0)>>>0){$=d[Y]|Z;c[s>>2]=$;ba=$}else{ba=Z}c[t>>2]=Y+1;V=1;W=_;X=ba}}while(0);da=V|Q;if((P|0)>=8){break}P=P+1|0;Q=da<<1;R=W;S=X}b[G+(M<<1)>>1]=da;S=M+1|0;if((S|0)<(h|0)){M=S;N=W;O=X}else{break}}}else{if(q){O=0;N=0;M=0;S=K;R=b[I>>1]|0;while(1){Q=F+(O<<1)|0;P=O+1|0;T=O-1|0;U=F+(T<<1)|0;_=b[U>>1]|0;Y=b[Q>>1]|0;Z=b[F+(P<<1)>>1]|0;$=R<<16>>16;if((b[v>>1]|0)==0){ea=(b[f+4804+(k*2580|0)+512+((_-Y&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+(($-_&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1024+((Y-Z&255)<<1)>>1]|0)|0}else{ea=(b[f+4804+(k*2580|0)+512+((_-Y&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+(($-_&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1024+((Y-Z&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1536+(((e[G+(O-2<<1)>>1]|0)-$&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+2048+(((e[G+(O<<1)>>1]|0)-Y&255)<<1)>>1]|0)|0}Y=(ea|0)<0?-ea|0:ea;do{if((c[w>>2]|0)==0){$=(Y|M|0)==0?1:M;if(($|0)==0){fa=Pda(x,(c[y>>2]|0)+(Y*6|0)|0,8)|0;ga=S;ha=0;ia=N;break}do{if((N|0)==0&($|0)==1){Z=c[z>>2]|0;_=c[A>>2]|0;ja=d[_+(Z>>>3)|0]|0;ka=c[B>>2]|0;la=((Z|0)<(ka|0))+Z|0;c[z>>2]=la;ma=a[1359920+S|0]|0;if((ja&128>>>((Z&7)>>>0)|0)!=0){Z=1<<(ma&255);na=((Z+O|0)<=(h|0))+S|0;oa=1;pa=Z;break}if(ma<<24>>24==0){qa=0}else{Z=ma&255;ma=_+(la>>>3)|0;_=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)>>>((32-Z|0)>>>0);ma=la+Z|0;c[z>>2]=ka>>>0>ma>>>0?ma:ka;qa=_}na=(S|0)==0?0:S-1|0;oa=2;pa=qa}else{na=S;oa=$;pa=N}}while(0);$=pa-1|0;if(($|0)>=0){fa=0;ga=na;ha=oa;ia=$;break}$=Pda(x,(c[y>>2]|0)+(Y*6|0)|0,8)|0;fa=($>>>31^1)+$|0;ga=na;ha=0;ia=0}else{$=c[C>>2]|0;_=$+(Y<<5)|0;ka=c[r>>2]|0;ma=(ca(d[_]|0,ka)|0)>>8;Z=ka-ma|0;c[r>>2]=Z;ka=c[s>>2]|0;if((ka|0)>=(Z|0)){c[s>>2]=ka-Z;a[_]=a[(d[_]|0)+(f+280)|0]|0;c[r>>2]=ma;if((ma|0)>=256){fa=0;ga=S;ha=M;ia=N;break}c[r>>2]=ma<<8;ma=c[s>>2]<<8;c[s>>2]=ma;Z=c[t>>2]|0;if(Z>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[Z]|ma}c[t>>2]=Z+1;fa=0;ga=S;ha=M;ia=N;break}a[_]=a[(d[_]|0)+(f+24)|0]|0;_=c[r>>2]|0;if((_|0)<256){Z=_<<8;c[r>>2]=Z;ma=c[s>>2]<<8;c[s>>2]=ma;ka=c[t>>2]|0;if(ka>>>0<(c[u>>2]|0)>>>0){la=d[ka]|ma;c[s>>2]=la;ra=la}else{ra=ma}c[t>>2]=ka+1;sa=Z;ta=ra}else{sa=_;ta=c[s>>2]|0}_=$+(Y<<5)+1|0;Z=(ca(d[_]|0,sa)|0)>>8;ka=sa-Z|0;c[r>>2]=ka;if((ta|0)<(ka|0)){ua=0;va=_}else{ma=1;la=_;_=Z;Z=ka;ka=ta;while(1){c[s>>2]=ka-Z;a[la]=a[(d[la]|0)+(f+280)|0]|0;c[r>>2]=_;if((_|0)<256){ja=_<<8;c[r>>2]=ja;wa=c[s>>2]<<8;c[s>>2]=wa;xa=c[t>>2]|0;if(xa>>>0<(c[u>>2]|0)>>>0){ya=d[xa]|wa;c[s>>2]=ya;za=ya}else{za=wa}c[t>>2]=xa+1;Aa=ja;Ba=za}else{Aa=_;Ba=c[s>>2]|0}ja=ma+1|0;xa=((ma|0)>9?10:ja)+($+(Y<<5))|0;wa=(ca(d[xa]|0,Aa)|0)>>8;ya=Aa-wa|0;c[r>>2]=ya;if((Ba|0)<(ya|0)){ua=ma;va=xa;break}else{ma=ja;la=xa;_=wa;Z=ya;ka=Ba}}}a[va]=a[(d[va]|0)+(f+24)|0]|0;ka=c[r>>2]|0;if((ka|0)<256){Z=ka<<8;c[r>>2]=Z;_=c[s>>2]<<8;c[s>>2]=_;la=c[t>>2]|0;if(la>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[la]|_}c[t>>2]=la+1;Ca=Z}else{Ca=ka}a:do{if((ua|0)>0){ka=2;Z=ua;la=Ca;while(1){_=Z-1|0;ma=((_|0)>9?31:Z+21|0)+($+(Y<<5))|0;ya=(ca(d[ma]|0,la)|0)>>8;wa=la-ya|0;c[r>>2]=wa;xa=c[s>>2]|0;do{if((xa|0)<(wa|0)){a[ma]=a[(d[ma]|0)+(f+24)|0]|0;ja=c[r>>2]|0;if((ja|0)>=256){Da=0;Ea=ja;break}Fa=ja<<8;c[r>>2]=Fa;ja=c[s>>2]<<8;c[s>>2]=ja;Ga=c[t>>2]|0;if(Ga>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[Ga]|ja}c[t>>2]=Ga+1;Da=0;Ea=Fa}else{c[s>>2]=xa-wa;a[ma]=a[(d[ma]|0)+(f+280)|0]|0;c[r>>2]=ya;if((ya|0)>=256){Da=1;Ea=ya;break}Fa=ya<<8;c[r>>2]=Fa;Ga=c[s>>2]<<8;c[s>>2]=Ga;ja=c[t>>2]|0;if(ja>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[ja]|Ga}c[t>>2]=ja+1;Da=1;Ea=Fa}}while(0);ya=Da|ka;if((_|0)<=0){Ha=ya;Ia=Ea;break a}ka=ya<<1;Z=_;la=Ea}}else{Ha=1;Ia=Ca}}while(0);la=((ua|0)>10?21:ua+11|0)+($+(Y<<5))|0;Z=(ca(d[la]|0,Ia)|0)>>8;ka=Ia-Z|0;c[r>>2]=ka;ya=c[s>>2]|0;do{if((ya|0)<(ka|0)){a[la]=a[(d[la]|0)+(f+24)|0]|0;ma=c[r>>2]|0;if((ma|0)>=256){Ja=0;break}c[r>>2]=ma<<8;ma=c[s>>2]<<8;c[s>>2]=ma;wa=c[t>>2]|0;if(wa>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[wa]|ma}c[t>>2]=wa+1;Ja=0}else{c[s>>2]=ya-ka;a[la]=a[(d[la]|0)+(f+280)|0]|0;c[r>>2]=Z;if((Z|0)>=256){Ja=1;break}c[r>>2]=Z<<8;wa=c[s>>2]<<8;c[s>>2]=wa;ma=c[t>>2]|0;if(ma>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[ma]|wa}c[t>>2]=ma+1;Ja=1}}while(0);fa=(Ha^-Ja)+Ja|0;ga=S;ha=M;ia=N}}while(0);Y=(ea|0)>-1?fa:-fa|0;Z=b[Q>>1]|0;la=b[G+(T<<1)>>1]|0;ka=Z+la-(b[U>>1]|0)|0;do{if((la|0)>(ka|0)){if((Z|0)<=(ka|0)){Ka=ka;break}Ka=(Z|0)>(la|0)?la:Z}else{if((ka|0)<=(Z|0)){Ka=ka;break}Ka=(Z|0)>(la|0)?Z:la}}while(0);la=Ka+Y&255;b[G+(O<<1)>>1]=la;if((P|0)<(h|0)){O=P;N=ia;M=ha;S=ga;R=la}else{La=ga;break}}}else{La=K}c[m>>2]=La}if(!q){break}R=ca(l,j)|0;S=0;do{a[g+(S+R)|0]=b[G+(S<<1)>>1];S=S+1|0;}while((S|0)<(h|0))}else{do{if(L){if(!q){break}if((J|0)<=0){mrc(H|0,0,E|0)|0;break}S=0;R=c[r>>2]|0;M=c[s>>2]|0;while(1){N=1;O=0;la=R;Z=M;while(1){ka=la>>1;U=la-ka|0;c[r>>2]=U;do{if((Z|0)<(U|0)){if((U|0)>=256){Ma=0;Na=U;Oa=Z;break}T=U<<8;c[r>>2]=T;Q=Z<<8;c[s>>2]=Q;ya=c[t>>2]|0;if(ya>>>0<(c[u>>2]|0)>>>0){$=d[ya]|Q;c[s>>2]=$;Pa=$}else{Pa=Q}c[t>>2]=ya+1;Ma=0;Na=T;Oa=Pa}else{T=Z-U|0;c[s>>2]=T;c[r>>2]=ka;if((ka|0)>=256){Ma=1;Na=ka;Oa=T;break}ya=ka<<8;c[r>>2]=ya;Q=T<<8;c[s>>2]=Q;T=c[t>>2]|0;if(T>>>0<(c[u>>2]|0)>>>0){$=d[T]|Q;c[s>>2]=$;Qa=$}else{Qa=Q}c[t>>2]=T+1;Ma=1;Na=ya;Oa=Qa}}while(0);Ra=Ma|O;if((N|0)>=(J|0)){break}N=N+1|0;O=Ra<<1;la=Na;Z=Oa}b[G+(S<<1)>>1]=Ra;Z=S+1|0;if((Z|0)<(h|0)){S=Z;R=Na;M=Oa}else{break}}}else{if(q){M=(1<<J)+65535|0;R=0;S=0;P=0;Y=K;Z=b[I>>1]|0;while(1){la=F+(R<<1)|0;O=R+1|0;N=R-1|0;ka=F+(N<<1)|0;U=b[ka>>1]|0;ya=b[la>>1]|0;T=b[F+(O<<1)>>1]|0;Q=Z<<16>>16;if((b[v>>1]|0)==0){Sa=(b[f+4804+(k*2580|0)+512+((U-ya&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+((Q-U&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1024+((ya-T&255)<<1)>>1]|0)|0}else{Sa=(b[f+4804+(k*2580|0)+512+((U-ya&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+((Q-U&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1024+((ya-T&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+1536+(((e[G+(R-2<<1)>>1]|0)-Q&255)<<1)>>1]|0)+(b[f+4804+(k*2580|0)+2048+(((e[G+(R<<1)>>1]|0)-ya&255)<<1)>>1]|0)|0}ya=(Sa|0)<0?-Sa|0:Sa;do{if((c[w>>2]|0)==0){Q=(ya|P|0)==0?1:P;if((Q|0)==0){Ta=Pda(x,(c[y>>2]|0)+(ya*6|0)|0,J)|0;Ua=Y;Va=0;Wa=S;break}do{if((S|0)==0&(Q|0)==1){T=c[z>>2]|0;U=c[A>>2]|0;$=d[U+(T>>>3)|0]|0;ma=c[B>>2]|0;wa=((T|0)<(ma|0))+T|0;c[z>>2]=wa;xa=a[1359920+Y|0]|0;if(($&128>>>((T&7)>>>0)|0)!=0){T=1<<(xa&255);Xa=((T+R|0)<=(h|0))+Y|0;Ya=1;Za=T;break}if(xa<<24>>24==0){_a=0}else{T=xa&255;xa=U+(wa>>>3)|0;U=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(wa&7)>>>((32-T|0)>>>0);xa=wa+T|0;c[z>>2]=ma>>>0>xa>>>0?xa:ma;_a=U}Xa=(Y|0)==0?0:Y-1|0;Ya=2;Za=_a}else{Xa=Y;Ya=Q;Za=S}}while(0);Q=Za-1|0;if((Q|0)>=0){Ta=0;Ua=Xa;Va=Ya;Wa=Q;break}Q=Pda(x,(c[y>>2]|0)+(ya*6|0)|0,J)|0;Ta=(Q>>>31^1)+Q|0;Ua=Xa;Va=0;Wa=0}else{Q=c[C>>2]|0;U=Q+(ya<<5)|0;ma=c[r>>2]|0;xa=(ca(d[U]|0,ma)|0)>>8;T=ma-xa|0;c[r>>2]=T;ma=c[s>>2]|0;if((ma|0)>=(T|0)){c[s>>2]=ma-T;a[U]=a[(d[U]|0)+(f+280)|0]|0;c[r>>2]=xa;if((xa|0)>=256){Ta=0;Ua=Y;Va=P;Wa=S;break}c[r>>2]=xa<<8;xa=c[s>>2]<<8;c[s>>2]=xa;T=c[t>>2]|0;if(T>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[T]|xa}c[t>>2]=T+1;Ta=0;Ua=Y;Va=P;Wa=S;break}a[U]=a[(d[U]|0)+(f+24)|0]|0;U=c[r>>2]|0;if((U|0)<256){T=U<<8;c[r>>2]=T;xa=c[s>>2]<<8;c[s>>2]=xa;ma=c[t>>2]|0;if(ma>>>0<(c[u>>2]|0)>>>0){wa=d[ma]|xa;c[s>>2]=wa;$a=wa}else{$a=xa}c[t>>2]=ma+1;ab=T;bb=$a}else{ab=U;bb=c[s>>2]|0}U=Q+(ya<<5)+1|0;T=(ca(d[U]|0,ab)|0)>>8;ma=ab-T|0;c[r>>2]=ma;if((bb|0)<(ma|0)){cb=0;db=U}else{xa=1;wa=U;U=T;T=ma;ma=bb;while(1){c[s>>2]=ma-T;a[wa]=a[(d[wa]|0)+(f+280)|0]|0;c[r>>2]=U;if((U|0)<256){$=U<<8;c[r>>2]=$;Fa=c[s>>2]<<8;c[s>>2]=Fa;ja=c[t>>2]|0;if(ja>>>0<(c[u>>2]|0)>>>0){Ga=d[ja]|Fa;c[s>>2]=Ga;eb=Ga}else{eb=Fa}c[t>>2]=ja+1;fb=$;gb=eb}else{fb=U;gb=c[s>>2]|0}$=xa+1|0;ja=((xa|0)>9?10:$)+(Q+(ya<<5))|0;Fa=(ca(d[ja]|0,fb)|0)>>8;Ga=fb-Fa|0;c[r>>2]=Ga;if((gb|0)<(Ga|0)){cb=xa;db=ja;break}else{xa=$;wa=ja;U=Fa;T=Ga;ma=gb}}}a[db]=a[(d[db]|0)+(f+24)|0]|0;ma=c[r>>2]|0;if((ma|0)<256){T=ma<<8;c[r>>2]=T;U=c[s>>2]<<8;c[s>>2]=U;wa=c[t>>2]|0;if(wa>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[wa]|U}c[t>>2]=wa+1;hb=T}else{hb=ma}b:do{if((cb|0)>0){ma=2;T=cb;wa=hb;while(1){U=T-1|0;xa=((U|0)>9?31:T+21|0)+(Q+(ya<<5))|0;Ga=(ca(d[xa]|0,wa)|0)>>8;Fa=wa-Ga|0;c[r>>2]=Fa;ja=c[s>>2]|0;do{if((ja|0)<(Fa|0)){a[xa]=a[(d[xa]|0)+(f+24)|0]|0;$=c[r>>2]|0;if(($|0)>=256){ib=0;jb=$;break}kb=$<<8;c[r>>2]=kb;$=c[s>>2]<<8;c[s>>2]=$;lb=c[t>>2]|0;if(lb>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[lb]|$}c[t>>2]=lb+1;ib=0;jb=kb}else{c[s>>2]=ja-Fa;a[xa]=a[(d[xa]|0)+(f+280)|0]|0;c[r>>2]=Ga;if((Ga|0)>=256){ib=1;jb=Ga;break}kb=Ga<<8;c[r>>2]=kb;lb=c[s>>2]<<8;c[s>>2]=lb;$=c[t>>2]|0;if($>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[$]|lb}c[t>>2]=$+1;ib=1;jb=kb}}while(0);Ga=ib|ma;if((U|0)<=0){mb=Ga;nb=jb;break b}ma=Ga<<1;T=U;wa=jb}}else{mb=1;nb=hb}}while(0);wa=((cb|0)>10?21:cb+11|0)+(Q+(ya<<5))|0;T=(ca(d[wa]|0,nb)|0)>>8;ma=nb-T|0;c[r>>2]=ma;_=c[s>>2]|0;do{if((_|0)<(ma|0)){a[wa]=a[(d[wa]|0)+(f+24)|0]|0;Ga=c[r>>2]|0;if((Ga|0)>=256){ob=0;break}c[r>>2]=Ga<<8;Ga=c[s>>2]<<8;c[s>>2]=Ga;xa=c[t>>2]|0;if(xa>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[xa]|Ga}c[t>>2]=xa+1;ob=0}else{c[s>>2]=_-ma;a[wa]=a[(d[wa]|0)+(f+280)|0]|0;c[r>>2]=T;if((T|0)>=256){ob=1;break}c[r>>2]=T<<8;xa=c[s>>2]<<8;c[s>>2]=xa;Ga=c[t>>2]|0;if(Ga>>>0<(c[u>>2]|0)>>>0){c[s>>2]=d[Ga]|xa}c[t>>2]=Ga+1;ob=1}}while(0);Ta=(mb^-ob)+ob|0;Ua=Y;Va=P;Wa=S}}while(0);ya=(Sa|0)>-1?Ta:-Ta|0;T=b[la>>1]|0;wa=b[G+(N<<1)>>1]|0;ma=T+wa-(b[ka>>1]|0)|0;do{if((wa|0)>(ma|0)){if((T|0)<=(ma|0)){pb=ma;break}pb=(T|0)>(wa|0)?wa:T}else{if((ma|0)<=(T|0)){pb=ma;break}pb=(T|0)>(wa|0)?T:wa}}while(0);wa=pb+ya&M&65535;b[G+(R<<1)>>1]=wa;if((O|0)<(h|0)){R=O;S=Wa;P=Va;Y=Ua;Z=wa}else{qb=Ua;break}}}else{qb=K}c[m>>2]=qb}}while(0);if((c[D>>2]|0)==0){if(!q){break}Z=16-(c[(c[o>>2]|0)+796>>2]|0)|0;Y=g+(ca(l,j)|0)|0;P=0;do{b[Y+(P<<1)>>1]=b[G+(P<<1)>>1]<<Z;P=P+1|0;}while((P|0)<(h|0))}else{if(!q){break}P=g+(ca(l,j)|0)|0;Z=0;do{b[P+(Z<<1)>>1]=b[G+(Z<<1)>>1]|0;Z=Z+1|0;}while((Z|0)<(h|0))}}}while(0);K=l+1|0;if((K|0)<(i|0)){J=F;F=G;l=K;G=J}else{break}}return}function Pda(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=g+5|0;j=d[i]|0;k=g+2|0;l=e[k>>1]|0;if(j>>>0<l>>>0){m=j;j=0;while(1){n=j+1|0;o=m<<1;if((o|0)<(l|0)){m=o;j=n}else{p=n;break}}}else{p=0}j=f+8|0;m=c[j>>2]|0;n=c[f+16>>2]|0;o=c[f>>2]|0;f=o+(m>>>3)|0;q=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(m&7);f=q>>>0>65535>>>0;r=f?q>>>16:q;s=f?16:0;if((r&65280|0)==0){t=s;u=r}else{t=s|8;u=r>>>8}r=(d[1359664+u|0]|0)+t|0;if((r|0)>19){t=p+32+m-r|0;c[j>>2]=n>>>0>t>>>0?t:n;v=(q>>>((r-p|0)>>>0))+(30-r<<p)|0}else{p=m+12|0;m=n>>>0>p>>>0?p:n;p=o+(m>>>3)|0;o=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>((32-h|0)>>>0);p=m+h|0;c[j>>2]=n>>>0>p>>>0?p:n;v=o+11|0}o=v+1|0;v=o>>1;n=g|0;p=b[n>>1]|0;j=a[i]|0;m=j&255;r=(p<<1)+m>>31^((o&1|0)==0?-v|0:v);v=g+4|0;g=a[v]|0;o=r+(g<<24>>24)|0;if((h|0)==8){w=o<<24>>24}else{q=1<<h-1;w=(o+q&(1<<h)-1)-q|0}q=l+((r|0)>-1?r:-r|0)|0;l=p+r|0;if(j<<24>>24==-128){x=m>>>1;y=l>>1;z=q>>>1&32767}else{x=m;y=l;z=q&65535}b[k>>1]=z;z=x+1|0;k=~x;if((y|0)>(k|0)){if((y|0)<=0){A=y&65535;b[n>>1]=A;B=z&255;a[i]=B;return w|0}if(!(g<<24>>24==127)){a[v]=g+1}q=y-z|0;A=(q|0)>0?0:q&65535;b[n>>1]=A;B=z&255;a[i]=B;return w|0}else{if(!(g<<24>>24==-128)){a[v]=g-1}g=z+y|0;if((g|0)>(k|0)){A=g&65535;b[n>>1]=A;B=z&255;a[i]=B;return w|0}A=-x&65535;b[n>>1]=A;B=z&255;a[i]=B;return w|0}return 0}function Qda(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=b+4|0;h=c[g>>2]|0;i=(ca(d[e]|0,h)|0)>>8;j=h-i|0;c[g>>2]=j;h=b|0;k=c[h>>2]|0;if((k|0)>=(j|0)){c[h>>2]=k-j;a[e]=a[(d[e]|0)+(b+272)|0]|0;c[g>>2]=i;if((i|0)>=256){l=0;return l|0}c[g>>2]=i<<8;i=c[h>>2]<<8;c[h>>2]=i;j=b+532|0;k=c[j>>2]|0;if(k>>>0<(c[b+536>>2]|0)>>>0){c[h>>2]=d[k]|0|i}c[j>>2]=k+1;l=0;return l|0}a[e]=a[(d[e]|0)+(b+16)|0]|0;k=c[g>>2]|0;if((k|0)<256){j=k<<8;c[g>>2]=j;i=c[h>>2]<<8;c[h>>2]=i;m=b+532|0;n=c[m>>2]|0;if(n>>>0<(c[b+536>>2]|0)>>>0){o=d[n]|0|i;c[h>>2]=o;p=o}else{p=i}c[m>>2]=n+1;q=j;r=p}else{q=k;r=c[h>>2]|0}k=e+1|0;p=(ca(d[k]|0,q)|0)>>8;j=q-p|0;c[g>>2]=j;if((r|0)<(j|0)){s=0;t=k}else{q=b+532|0;n=b+536|0;m=1;i=k;k=p;p=j;j=r;while(1){c[h>>2]=j-p;a[i]=a[(d[i]|0)+(b+272)|0]|0;c[g>>2]=k;if((k|0)<256){r=k<<8;c[g>>2]=r;o=c[h>>2]<<8;c[h>>2]=o;u=c[q>>2]|0;if(u>>>0<(c[n>>2]|0)>>>0){v=d[u]|0|o;c[h>>2]=v;w=v}else{w=o}c[q>>2]=u+1;x=r;y=w}else{x=k;y=c[h>>2]|0}r=m+1|0;u=e+((m|0)>9?10:r)|0;o=(ca(d[u]|0,x)|0)>>8;v=x-o|0;c[g>>2]=v;if((y|0)<(v|0)){s=m;t=u;break}else{m=r;i=u;k=o;p=v;j=y}}}a[t]=a[(d[t]|0)+(b+16)|0]|0;t=c[g>>2]|0;if((t|0)<256){y=t<<8;c[g>>2]=y;j=c[h>>2]<<8;c[h>>2]=j;p=b+532|0;k=c[p>>2]|0;if(k>>>0<(c[b+536>>2]|0)>>>0){c[h>>2]=d[k]|0|j}c[p>>2]=k+1;z=y}else{z=t}a:do{if((s|0)>0){t=b+532|0;y=b+536|0;k=2;p=s;j=z;while(1){i=p-1|0;m=e+((i|0)>9?31:p+21|0)|0;x=(ca(d[m]|0,j)|0)>>8;w=j-x|0;c[g>>2]=w;q=c[h>>2]|0;do{if((q|0)<(w|0)){a[m]=a[(d[m]|0)+(b+16)|0]|0;n=c[g>>2]|0;if((n|0)>=256){A=0;B=n;break}v=n<<8;c[g>>2]=v;n=c[h>>2]<<8;c[h>>2]=n;o=c[t>>2]|0;if(o>>>0<(c[y>>2]|0)>>>0){c[h>>2]=d[o]|0|n}c[t>>2]=o+1;A=0;B=v}else{c[h>>2]=q-w;a[m]=a[(d[m]|0)+(b+272)|0]|0;c[g>>2]=x;if((x|0)>=256){A=1;B=x;break}v=x<<8;c[g>>2]=v;o=c[h>>2]<<8;c[h>>2]=o;n=c[t>>2]|0;if(n>>>0<(c[y>>2]|0)>>>0){c[h>>2]=d[n]|0|o}c[t>>2]=n+1;A=1;B=v}}while(0);x=A|k;if((i|0)<=0){C=x;D=B;break a}k=x<<1;p=i;j=B}}else{C=1;D=z}}while(0);do{if((f|0)==0){E=0}else{z=e+((s|0)>10?21:s+11|0)|0;B=(ca(d[z]|0,D)|0)>>8;A=D-B|0;c[g>>2]=A;j=c[h>>2]|0;if((j|0)<(A|0)){a[z]=a[(d[z]|0)+(b+16)|0]|0;p=c[g>>2]|0;if((p|0)>=256){E=0;break}c[g>>2]=p<<8;p=c[h>>2]<<8;c[h>>2]=p;k=b+532|0;t=c[k>>2]|0;if(t>>>0<(c[b+536>>2]|0)>>>0){c[h>>2]=d[t]|0|p}c[k>>2]=t+1;E=0;break}else{c[h>>2]=j-A;a[z]=a[(d[z]|0)+(b+272)|0]|0;c[g>>2]=B;if((B|0)>=256){E=1;break}c[g>>2]=B<<8;B=c[h>>2]<<8;c[h>>2]=B;z=b+532|0;A=c[z>>2]|0;if(A>>>0<(c[b+536>>2]|0)>>>0){c[h>>2]=d[A]|0|B}c[z>>2]=A+1;E=1;break}}}while(0);l=(C^-E)+E|0;return l|0}function Rda(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+32|0;e=d|0;f=1;g=0;while(1){if((g|0)>=5){break}mrc(e|0,-128|0,32)|0;h=0;j=0;while(1){k=(Qda(a,e,0)|0)+1|0;if(k>>>0>(128-j|0)>>>0){l=-1094995529;break}if((k|0)==0){m=j}else{n=(ca(h,f)|0)&65535;o=j;p=k;while(1){q=p-1|0;b[c+(g<<9)+(o<<1)>>1]=n;if((q|0)==0){break}else{o=o+1|0;p=q}}m=k+j|0}r=h+1|0;if((m|0)<128){h=r;j=m}else{s=1;t=10;break}}if((t|0)==10){while(1){t=0;b[c+(g<<9)+(256-s<<1)>>1]=-(b[c+(g<<9)+(s<<1)>>1]|0);j=s+1|0;if((j|0)<128){s=j;t=10}else{break}}b[c+(g<<9)+256>>1]=-(b[c+(g<<9)+254>>1]|0);l=(r<<1)-1|0}j=ca(l,f)|0;if(j>>>0>32768>>>0){u=-1094995529;t=14;break}else{f=j;g=g+1|0}}if((t|0)==14){i=d;return u|0}u=(f+1|0)/2|0;i=d;return u|0}function Sda(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0,pa=0,qa=0.0,ra=0.0,sa=0.0,ta=0.0,ua=0,va=0.0,wa=0,xa=0.0,ya=0,za=0.0,Aa=0.0,Ba=0,Ca=0.0,Da=0,Ea=0.0,Fa=0.0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0.0,Oa=0,Pa=0.0,Qa=0,Ra=0,Sa=0,Ta=0.0,Ua=0,Va=0.0,Wa=0.0,Xa=0,Ya=0,Za=0,_a=0,$a=0.0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;f=i;i=i+74792|0;g=f|0;j=f+32|0;k=f+1056|0;l=f+3104|0;m=f+5152|0;n=f+7200|0;o=f+9248|0;p=f+74784|0;q=c[e+60>>2]|0;r=q;s=e+140|0;t=qKb(c[s>>2]|0)|0;u=Ipb(e)|0;if((u|0)<0){v=u;i=f;return v|0}u=q+4720|0;c[u>>2]=0;w=e+88|0;x=e+404|0;if((c[w>>2]&1536|0)==0){z=c[x>>2]|0;if((z|0)>1){A=4}else{B=z;C=0}}else{A=4}if((A|0)==4){c[u>>2]=2;B=c[x>>2]|0;C=2}x=e+404|0;z=e+844|0;do{if((B|0)==0){if((c[z>>2]|0)>=0){D=C;break}if((ca(c[e+124>>2]|0,c[e+120>>2]|0)|0)<=414720){D=C;break}c[u>>2]=2;D=2}else{D=C}}while(0);C=c[z>>2]|0;if((C|0)<1&(D|0)==2){c[u>>2]=3;E=c[z>>2]|0;F=3}else{E=C;F=D}if(E>>>0<5>>>0){D=(F|0)>(E|0)?F:E;c[u>>2]=D;H=D}else{H=F}F=q+38496|0;if((c[F>>2]|0)<0){c[F>>2]=(H|0)>2}do{if((H|0)==2|(H|0)>3){if(!((c[e+680>>2]|0)>-2)){break}KIb(e,16,2550696,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-1094995529;i=f;return v|0}}while(0);D=e+568|0;E=(c[D>>2]|0)>0;C=q+4796|0;c[C>>2]=E?2:0;z=q+4792|0;c[z>>2]=3;a:do{switch(c[s>>2]|0){case 86:{J=e+796|0;A=44;break};case 78:case 72:case 74:case 102:case 100:case 98:{A=24;break};case 298:{c[q+38488>>2]=1;c[q+4736>>2]=1;break};case 32:case 58:case 56:case 54:case 108:case 106:case 104:{A=27;break};case 8:case 5:case 33:case 4:case 0:case 7:case 6:case 299:case 300:case 35:{A=39;break};case 30:{c[q+38488>>2]=1;c[q+4748>>2]=1;c[q+4736>>2]=1;break};case 314:{K=e+796|0;A=47;break};case 84:{B=e+796|0;if((c[B>>2]|0)!=0){J=B;A=44;break a}c[q+38512>>2]=9;J=B;A=44;break};case 76:case 80:case 70:case 96:case 94:case 92:{if((c[e+796>>2]|0)!=0){A=24;break a}c[q+38512>>2]=9;A=24;break};case 316:{L=e+796|0;A=50;break};default:{KIb(e,16,2490064,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-38;i=f;return v|0}}}while(0);do{if((A|0)==24){c[q+38516>>2]=1;if((c[e+796>>2]|0)!=0){A=27;break}B=q+38512|0;if((c[B>>2]|0)!=0){A=27;break}c[B>>2]=10;A=27}else if((A|0)==44){if((c[J>>2]|0)!=0){K=J;A=47;break}B=q+38512|0;if((c[B>>2]|0)!=0){K=J;A=47;break}c[B>>2]=10;K=J;A=47}}while(0);do{if((A|0)==27){J=c[e+796>>2]|0;B=q+38512|0;M=c[B>>2]|0;N=(M|0)==0;do{if((J|0)==0){if(!N){O=M;A=32;break}c[B>>2]=16}else{if(!N){O=M;A=32;break}c[q+38512>>2]=J;O=J;A=32}}while(0);do{if((A|0)==32){if((O|0)>=9){break}KIb(e,16,2532480,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-1094995529;i=f;return v|0}}while(0);do{if(E){P=H}else{J=e;if((c[D>>2]|0)==-1){KIb(J,32,2517176,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;c[C>>2]=2;P=c[u>>2]|0;break}KIb(J,16,2503176,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-38;i=f;return v|0}}while(0);c[u>>2]=(P|0)>1?P:1;A=39}else if((A|0)==47){if((c[K>>2]|0)!=0){L=K;A=50;break}J=q+38512|0;if((c[J>>2]|0)!=0){L=K;A=50;break}c[J>>2]=12;L=K;A=50}}while(0);do{if((A|0)==39){K=t+4|0;c[q+4736>>2]=(d[K]|0)>>>0>2>>>0;c[q+38488>>2]=0;c[q+4748>>2]=(a[K]|0)==4}else if((A|0)==50){K=c[L>>2]|0;P=q+38512|0;D=(c[P>>2]|0)==0;do{if((K|0)==0){if(!D){break}c[P>>2]=14}else{if(!D){break}c[q+38512>>2]=K}}while(0);c[q+38488>>2]=1;c[q+4736>>2]=1;c[u>>2]=(H|0)>1?H:1;if(E){break}KIb(e,16,2503176,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-38;i=f;return v|0}}while(0);E=q+4748|0;if((c[E>>2]|0)!=0){KIb(e,24,2479152,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}H=e+572|0;L=c[H>>2]|0;if(L>>>0>1>>>0){KIb(e,16,2469344,(I=i,i=i+8|0,c[I>>2]=L,I)|0);i=I;v=-22;i=f;return v|0}if((c[C>>2]|0)>1){L=1;do{a[q+(L+38196)|0]=a[263024+L|0]|0;L=L+1|0;}while((L|0)<256)}L=q+38524|0;t=q+38512|0;K=q+17684|0;D=K;P=q+18196|0;O=q+18708|0;J=q+20244|0;M=q+20756|0;N=q+21268|0;B=q+21780|0;Q=q+22292|0;R=0;do{c[L>>2]=2;if((c[t>>2]|0)<9){S=a[689616+R|0]|0;b[D+(R<<1)>>1]=S;T=S*11&65535;b[P+(R<<1)>>1]=T;b[O+(R<<1)>>1]=S*121;b[J+(R<<1)>>1]=S;b[M+(R<<1)>>1]=T;T=a[689320+R|0]|0;b[N+(R<<1)>>1]=T*121;b[B+(R<<1)>>1]=T*605;b[Q+(R<<1)>>1]=T*3025}else{T=a[688720+R|0]|0;b[D+(R<<1)>>1]=T;S=T*11&65535;b[P+(R<<1)>>1]=S;b[O+(R<<1)>>1]=T*121;b[J+(R<<1)>>1]=T;b[M+(R<<1)>>1]=S;S=a[689064+R|0]|0;b[N+(R<<1)>>1]=S*121;b[B+(R<<1)>>1]=S*605;b[Q+(R<<1)>>1]=S*3025}R=R+1|0;}while((R|0)<256);R=q+38164|0;Q=R;c[R>>2]=666;c[q+38168>>2]=7563;R=q+15124|0;nrc(R|0,K+((c[H>>2]|0)*2560|0)|0,2560)|0;if((c[z>>2]|0)>0){K=q+4804|0;B=0;do{nrc(K+(B*2580|0)|0,R|0,2560)|0;N=c[H>>2]|0;c[K+(B*2580|0)+2560>>2]=N;c[K+(B*2580|0)+2564>>2]=c[Q+(N<<2)>>2];B=B+1|0;}while((B|0)<(c[z>>2]|0))}B=Mpb(r)|0;if((B|0)<0){v=B;i=f;return v|0}B=UHb()|0;c[e+804>>2]=B;if((B|0)==0){v=-12;i=f;return v|0}c[B+88>>2]=1;if((c[E>>2]|0)==0){c[z>>2]=2}B=q+4736|0;do{if((c[B>>2]|0)==0){if((c[u>>2]|0)<=3){break}c[z>>2]=(c[z>>2]|0)-1}}while(0);z=q+4740|0;K=q+4744|0;vLa(c[s>>2]|0,z,K);c[q+4756>>2]=0;b:do{if((c[w>>2]&1536|0)!=0){s=q+4688|0;H=0;while(1){if((H|0)>=(c[L>>2]|0)){break b}R=pJb(c[Q+(H<<2)>>2]<<9)|0;c[s+(H<<2)>>2]=R;if((R|0)==0){v=-12;break}else{H=H+1|0}}i=f;return v|0}}while(0);H=c[e+672>>2]|0;do{if((H|0)!=0){if((c[u>>2]|0)<=1){KIb(0,0,2248568,(I=i,i=i+24|0,c[I>>2]=2460184,c[I+8>>2]=2174216,c[I+16>>2]=869,I)|0);i=I;Hd();return 0}s=q+4688|0;R=q+592|0;N=H;M=0;c:while(1){if((M|0)<256){U=N;V=0;while(1){if((V|0)>=2){break}J=rb(U|0,p|0,0)|0;O=R+(M<<4)+(V<<3)|0;c[O>>2]=J;c[O+4>>2]=(J|0)<0|0?-1:0;J=c[p>>2]|0;if((J|0)==(U|0)){A=91;break c}else{U=J;V=V+1|0}}N=U;M=M+1|0;continue}J=c[L>>2]|0;if((J|0)>0){W=0;O=N;P=J;while(1){J=Q+(W<<2)|0;if((c[J>>2]|0)>0){D=s+(W<<2)|0;X=0;S=O;while(1){Y=0;T=S;while(1){Z=T;_=0;while(1){if((_|0)>=2){break}$=rb(Z|0,p|0,0)|0;aa=(c[D>>2]|0)+(X<<9)+(Y<<4)+(_<<3)|0;c[aa>>2]=$;c[aa+4>>2]=($|0)<0|0?-1:0;$=c[p>>2]|0;if(($|0)==(Z|0)){A=99;break c}else{Z=$;_=_+1|0}}$=Y+1|0;if(($|0)<32){Y=$;T=Z}else{break}}T=X+1|0;if((T|0)<(c[J>>2]|0)){X=T;S=Z}else{break}}ba=Z;da=c[L>>2]|0}else{ba=O;da=P}S=W+1|0;if((S|0)<(da|0)){W=S;O=ba;P=da}else{ea=ba;break}}}else{ea=N}fa=rb(ea|0,p|0,0)|0;P=c[p>>2]|0;if((P|0)==(ea|0)|(fa|0)<1){A=105;break}else{ga=P}while(1){P=a[ga]|0;if((P<<24>>24|0)==0){ha=12;ia=0;A=108;break c}else if(!((P<<24>>24|0)==32|(P<<24>>24|0)==10)){N=ga;M=0;continue c}ga=ga+1|0}}if((A|0)==91){KIb(e,16,2443512,(I=i,i=i+24|0,c[I>>2]=M,c[I+8>>2]=V,c[I+16>>2]=U,I)|0);i=I;v=-1094995529;i=f;return v|0}else if((A|0)==99){KIb(e,16,2431016,(I=i,i=i+40|0,c[I>>2]=W,c[I+8>>2]=X,c[I+16>>2]=Y,c[I+24>>2]=_,c[I+32>>2]=Z,I)|0);i=I;v=-1094995529;i=f;return v|0}else if((A|0)==105){KIb(e,16,2420752,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;v=-1094995529;i=f;return v|0}else if((A|0)==108){d:while(1){A=0;N=ha;while(1){if((N|0)>=244){A=131;break}ja=N+1|0;ka=N+4|0;if((ja|0)<245){break}else{N=ja}}if((A|0)==131){A=0;if((ia|0)==0){break}else{ha=12;ia=0;A=108;continue}}R=r+592+(N<<4)|0;P=256-N|0;la=-0.0- +lc(+(+(P|0)*.00390625));O=r+592+(N<<4)+8|0;ma=-0.0- +lc(+(+(N|0)*.00390625));S=r+592+(P<<4)|0;J=r+592+(P<<4)+8|0;D=(N|0)==128;T=q+(N+38196)|0;$=q+(P+38196)|0;aa=P&255;na=N&255;oa=ia;pa=ja;while(1){qa=+((c[R>>2]|0)>>>0)+ +((c[R+4>>2]|0)>>>0)*4294967296.0;ra=+((c[O>>2]|0)>>>0)+ +((c[O+4>>2]|0)>>>0)*4294967296.0;sa=+((c[S>>2]|0)>>>0)+ +((c[S+4>>2]|0)>>>0)*4294967296.0;ta=+((c[J>>2]|0)>>>0)+ +((c[J+4>>2]|0)>>>0)*4294967296.0;ua=r+592+(pa<<4)|0;va=+((c[ua>>2]|0)>>>0)+ +((c[ua+4>>2]|0)>>>0)*4294967296.0;wa=256-pa|0;xa=-0.0- +lc(+(+(wa|0)*.00390625));ya=r+592+(pa<<4)+8|0;za=+((c[ya>>2]|0)>>>0)+ +((c[ya+4>>2]|0)>>>0)*4294967296.0;Aa=-0.0- +lc(+(+(pa|0)*.00390625));Ba=r+592+(wa<<4)|0;Ca=+((c[Ba>>2]|0)>>>0)+ +((c[Ba+4>>2]|0)>>>0)*4294967296.0;Da=r+592+(wa<<4)+8|0;Ea=+((c[Da>>2]|0)>>>0)+ +((c[Da+4>>2]|0)>>>0)*4294967296.0;Fa=qa*la+ra*ma+sa*ma+ta*la+va*xa+za*Aa+Ca*Aa+Ea*xa;e:do{if(Fa-(Ea*la+(Ca*ma+(za*ma+(va*la+(ta*xa+(sa*Aa+(qa*xa+ra*Aa)))))))<=Fa*1.0e-14|D|(pa|0)==128){Ga=oa}else{Ha=q+(pa+38196)|0;Ia=a[Ha]|0;a[Ha]=a[T]|0;a[T]=Ia;Ia=c[ua>>2]|0;Ha=c[R+4>>2]|0;c[ua>>2]=c[R>>2];c[ua+4>>2]=Ha;Ha=Ia;c[R>>2]=Ha;c[R+4>>2]=(Ha|0)<0|0?-1:0;Ha=c[ya>>2]|0;Ia=c[O+4>>2]|0;c[ya>>2]=c[O>>2];c[ya+4>>2]=Ia;Ia=Ha;c[O>>2]=Ia;c[O+4>>2]=(Ia|0)<0|0?-1:0;if((N|0)==(wa|0)){Ia=pa&255;Ha=1;while(1){Ja=q+(Ha+38196)|0;Ka=d[Ja]|0;do{if((Ka|0)==(N|0)){a[Ja]=Ia}else{if((Ka|0)!=(pa|0)){break}a[Ja]=na}}while(0);Ja=Ha+1|0;if((Ja|0)<256){Ha=Ja}else{Ga=1;break e}}}Ha=q+(wa+38196)|0;Ia=a[Ha]|0;a[Ha]=a[$]|0;a[$]=Ia;Ia=c[Ba>>2]|0;Ha=c[S+4>>2]|0;c[Ba>>2]=c[S>>2];c[Ba+4>>2]=Ha;Ha=Ia;c[S>>2]=Ha;c[S+4>>2]=(Ha|0)<0|0?-1:0;Ha=c[Da>>2]|0;Ia=c[J+4>>2]|0;c[Da>>2]=c[J>>2];c[Da+4>>2]=Ia;Ia=Ha;c[J>>2]=Ia;c[J+4>>2]=(Ia|0)<0|0?-1:0;Ia=pa&255;Ha=wa&255;Ja=1;while(1){Ka=q+(Ja+38196)|0;La=d[Ka]|0;do{if((La|0)==(N|0)){a[Ka]=Ia}else{if((La|0)!=(pa|0)){break}a[Ka]=na}}while(0);Ka=q+(38452-Ja)|0;La=d[Ka]|0;do{if((La|0)==(P|0)){a[Ka]=Ha}else{if((La|0)!=(wa|0)){break}a[Ka]=aa}}while(0);Ka=Ja+1|0;if((Ka|0)<256){Ja=Ka}else{Ga=1;break}}}}while(0);wa=pa+1|0;if((wa|0)<245&(wa|0)<(ka|0)){oa=Ga;pa=wa}else{ha=ja;ia=Ga;A=108;continue d}}}M=m;pa=n;oa=1;while(1){h[k+(oa<<3)>>3]=+lc(+(+(oa|0)*.00390625));aa=oa+1|0;if((aa|0)<256){oa=aa}else{Ma=0;break}}do{oa=0;do{h[l+(oa<<3)>>3]=1073741824.0;oa=oa+1|0;}while((oa|0)<256);la=+(Ma|0)*.00390625;oa=Ma-10|0;aa=(oa|0)>1?oa:1;oa=Ma+11|0;P=(oa|0)>256?256:oa;if((aa|0)<(P|0)){ma=1.0-la;oa=aa;do{mrc(M|0,0,2048)|0;h[m+(oa<<3)>>3]=1.0;aa=oa&255;na=0;Fa=0.0;while(1){mrc(pa|0,0,2048)|0;N=1;Aa=Fa;while(1){ra=+h[m+(N<<3)>>3];if(ra!=0.0){Na=Aa-ra*(la*+h[k+(N<<3)>>3]+ma*+h[k+(256-N<<3)>>3])}else{Na=Aa}J=N+1|0;if((J|0)<256){N=J;Aa=Na}else{break}}N=l+(na<<3)|0;if(Na<+h[N>>3]){h[N>>3]=Na;a[o+(Ma<<8)+na|0]=aa;Oa=0}else{Oa=0}do{Aa=+h[m+(Oa<<3)>>3];if(Aa!=0.0){N=n+(d[q+(Oa+38196)|0]<<3)|0;h[N>>3]=la*Aa+ +h[N>>3];N=n+(256-(d[q+(38452-Oa)|0]|0)<<3)|0;h[N>>3]=ma*Aa+ +h[N>>3]}Oa=Oa+1|0;}while((Oa|0)<256);nrc(M|0,pa|0,2048)|0;N=na+1|0;if((N|0)<256){na=N;Fa=Na}else{break}}oa=oa+1|0;}while((oa|0)<(P|0))}Ma=Ma+1|0;}while((Ma|0)<256);if((c[L>>2]|0)<=0){break}ma=+(fa|0);pa=q+38452|0;M=0;do{P=Q+(M<<2)|0;oa=s+(M<<2)|0;na=pa+(M<<2)|0;aa=0;N=c[P>>2]|0;while(1){if((N|0)>0){la=0.0;Fa=0.0;J=0;S=0;while(1){$=c[oa>>2]|0;O=$+(S<<9)+(aa<<4)|0;R=c[O>>2]|0;T=c[O+4>>2]|0;O=$+(S<<9)+(aa<<4)+8|0;$=c[O>>2]|0;D=c[O+4>>2]|0;O=wrc($,D,R,T)|0;wa=G;Aa=la+Fa;Da=0;if((S|0)!=0&(wa>>>0>Da>>>0|wa>>>0==Da>>>0&O>>>0>200>>>0)|Aa>200.0){if(Aa!=0.0){Pa=Fa*256.0/Aa}else{Pa=128.0}O=~~(Aa/ma);if((O|0)<0){Qa=0}else{Qa=(O|0)>255?255:O}O=~~+Nb(+Pa);if((O|0)<1){Ra=1}else{Ra=(O|0)>255?255:O}a[(c[na>>2]|0)+(J<<5)+aa|0]=a[o+(Ra<<8)+Qa|0]|0;O=J+1|0;if((O|0)<(S|0)){Da=J;wa=O;while(1){Ba=c[na>>2]|0;a[Ba+(wa<<5)+aa|0]=a[Ba+(Da<<5)+aa|0]|0;Ba=wa+1|0;if((Ba|0)<(S|0)){Da=wa;wa=Ba}else{Sa=S;break}}}else{Sa=O}wa=c[oa>>2]|0;Da=wa+(S<<9)+(aa<<4)|0;Ba=wa+(S<<9)+(aa<<4)+8|0;Ta=Pa;Ua=Sa;Va=0.0;Wa=0.0;Xa=c[Da+4>>2]|0;Ya=c[Da>>2]|0;Za=c[Ba+4>>2]|0;_a=c[Ba>>2]|0}else{Ta=128.0;Ua=J;Va=Fa;Wa=la;Xa=T;Ya=R;Za=D;_a=$}Aa=Wa+(+(Ya>>>0)+ +(Xa>>>0)*4294967296.0);ra=Va+(+(_a>>>0)+ +(Za>>>0)*4294967296.0);xa=Aa+ra;if(xa!=0.0){$a=ra*256.0/xa}else{$a=Ta}Ba=~~(xa/ma);if((Ba|0)<0){ab=0}else{ab=(Ba|0)>255?255:Ba}Ba=~~+Nb(+$a);if((Ba|0)<1){bb=1}else{bb=(Ba|0)>255?255:Ba}a[(c[na>>2]|0)+(S<<5)+aa|0]=a[o+(bb<<8)+ab|0]|0;Ba=S+1|0;Da=c[P>>2]|0;if((Ba|0)<(Da|0)){la=Aa;Fa=ra;J=Ua;S=Ba}else{cb=Da;break}}}else{cb=N}S=aa+1|0;if((S|0)<32){aa=S;N=cb}else{break}}M=M+1|0;}while((M|0)<(c[L>>2]|0))}}}while(0);if((c[u>>2]|0)>1){do{if((c[e+120>>2]|0)>352){db=2}else{if((c[e+124>>2]|0)>288){db=2;break}db=(c[x>>2]|0)==0?2:1}}while(0);cb=q+40800|0;c[cb>>2]=db;Ua=q+40804|0;ab=db;f:while(1){db=ab;while(1){c[Ua>>2]=db;if((db|0)>=(ab<<1|0)){break}bb=c[x>>2]|0;if((bb|0)==(ca(ab,db)|0)&(bb|0)<65|(bb|0)==0){break f}else{db=db+1|0}}db=ab+1|0;c[cb>>2]=db;if((db|0)<9){ab=db}else{A=183;break}}if((A|0)==183){KIb(e,16,2411432,(I=i,i=i+8|0,c[I>>2]=c[x>>2],I)|0);i=I;v=-38;i=f;return v|0}x=g|0;g=q+8|0;mrc(j|0,-128|0,1024)|0;mrc(x|0,-128|0,32)|0;ab=q+4|0;c[(c[ab>>2]|0)+100>>2]=536596;db=hJb(536596)|0;c[(c[ab>>2]|0)+96>>2]=db;db=c[ab>>2]|0;bb=c[db+96>>2]|0;if((bb|0)==0){v=-12;i=f;return v|0}SYa(g,bb,c[db+100>>2]|0);UYa(g,214748364,248);Yda(g,x,c[u>>2]|0,0);db=c[u>>2]|0;if((db|0)>2){if((db|0)==3){c[q+4724>>2]=4;eb=4}else if((db|0)==4){c[q+4724>>2]=2;eb=2}else{eb=c[q+4724>>2]|0}Yda(g,x,eb,0)}Yda(g,x,c[C>>2]|0,0);if((c[C>>2]|0)>1){C=1;do{Yda(g,x,(d[r+38196+C|0]|0)-(d[r+280+C|0]|0)|0,1);C=C+1|0;}while((C|0)<256)}Yda(g,x,c[q+38488>>2]|0,0);Yda(g,x,c[t>>2]|0,0);Vda(g,x,c[B>>2]|0);Yda(g,x,c[z>>2]|0,0);Yda(g,x,c[K>>2]|0,0);Vda(g,x,c[E>>2]|0);Yda(g,x,(c[Ua>>2]|0)-1|0,0);Yda(g,x,(c[cb>>2]|0)-1|0,0);Yda(g,x,c[L>>2]|0,0);do{if((c[L>>2]|0)>0){cb=0;do{Zda(g,r+17684+(cb*2560|0)|0);cb=cb+1|0;fb=c[L>>2]|0;}while((cb|0)<(fb|0));if((fb|0)>0){gb=0}else{break}do{cb=r+38164+(gb<<2)|0;Ua=c[cb>>2]|0;E=Ua<<5;g:do{if((E|0)>0){K=c[r+38452+(gb<<2)>>2]|0;if((K|0)==0){hb=Ua<<5;break}else{ib=0}while(1){if(!((a[K+ib|0]|0)==-128)){hb=ib;break g}z=ib+1|0;if((z|0)<(E|0)){ib=z}else{hb=z;break}}}else{hb=0}}while(0);do{if((hb|0)<(E|0)){Vda(g,x,1);if((c[cb>>2]|0)<=0){break}Ua=r+38452+(gb<<2)|0;K=0;do{z=K-1|0;if((K|0)==0){B=0;do{Yda(g,j+(B<<5)|0,(a[(c[Ua>>2]|0)+B|0]^-128)<<24>>24,1);B=B+1|0;}while((B|0)<32)}else{B=0;do{$=c[Ua>>2]|0;Yda(g,j+(B<<5)|0,((a[$+(K<<5)+B|0]|0)-(a[$+(z<<5)+B|0]|0)&255)<<24>>24,1);B=B+1|0;}while((B|0)<32)}K=K+1|0;}while((K|0)<(c[cb>>2]|0))}else{Vda(g,x,0)}}while(0);gb=gb+1|0;}while((gb|0)<(c[L>>2]|0))}}while(0);if((c[u>>2]|0)>2){Yda(g,x,c[F>>2]|0,0);F=(c[(c[ab>>2]|0)+136>>2]|0)<2|0;c[q+38500>>2]=F;Yda(g,x,F,0)}F=VYa(g)|0;c[(c[ab>>2]|0)+100>>2]=F;F=DGb(3)|0;g=c[ab>>2]|0;x=c[g+96>>2]|0;u=c[g+100>>2]|0;g=x+u|0;y=EGb(F,0,x,u)|0;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;g=(c[ab>>2]|0)+100|0;c[g>>2]=(c[g>>2]|0)+4}g=Lpb(r)|0;if((g|0)<0){v=g;i=f;return v|0}g=Kpb(r)|0;if((g|0)<0){v=g;i=f;return v|0}if((c[w>>2]&512|0)==0){v=0;i=f;return v|0}w=pJb(6291456)|0;c[e+668>>2]=w;if((w|0)==0){v=-12;i=f;return v|0}if((c[L>>2]|0)<=0){v=0;i=f;return v|0}w=q+40796|0;e=q+39772|0;q=0;h:while(1){g=Q+(q<<2)|0;r=0;while(1){if((r|0)>=(c[w>>2]|0)){break}ab=(c[e+(r<<2)>>2]|0)+4688+(q<<2)|0;if((c[ab>>2]|0)!=0){A=222;break h}u=pJb(c[g>>2]<<9)|0;c[ab>>2]=u;if((u|0)==0){v=-12;A=226;break h}r=r+1|0}r=q+1|0;if((r|0)<(c[L>>2]|0)){q=r}else{v=0;A=226;break}}if((A|0)==222){KIb(0,0,2248568,(I=i,i=i+24|0,c[I>>2]=2403816,c[I+8>>2]=2174216,c[I+16>>2]=969,I)|0);i=I;Hd();return 0}else if((A|0)==226){i=f;return v|0}return 0}function Tda(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;h=i;i=i+48|0;j=h|0;k=h+32|0;l=h+40|0;m=c[b+60>>2]|0;n=m;o=m+39772|0;p=o;q=o;r=c[q>>2]|0;s=r+8|0;t=c[m+4760>>2]|0;a[k]=-128;u=ca(c[b+124>>2]|0,c[b+120>>2]|0)|0;v=u;w=(u|0)<0|0?-1:0;if((f|0)==0){if((c[b+88>>2]&512|0)==0){x=0;i=h;return x|0}u=c[b+668>>2]|0;z=u+6291456|0;A=m+592|0;B=A;mrc(A|0,0,4096)|0;A=m+38524|0;if((c[A>>2]|0)>0){C=m+4688|0;D=m+38164|0;E=0;do{mrc(c[C+(E<<2)>>2]|0,0,c[D+(E<<2)>>2]<<9|0)|0;E=E+1|0;}while((E|0)<(c[A>>2]|0))}E=m+40796|0;if((c[E>>2]|0)>0){D=m+38164|0;C=m+4688|0;F=0;do{H=c[p+(F<<2)>>2]|0;I=0;do{J=H+592+(I<<4)|0;K=B+(I<<4)|0;L=wrc(c[K>>2]|0,c[K+4>>2]|0,c[J>>2]|0,c[J+4>>2]|0)|0;c[K>>2]=L;c[K+4>>2]=G;K=H+592+(I<<4)+8|0;L=B+(I<<4)+8|0;J=wrc(c[L>>2]|0,c[L+4>>2]|0,c[K>>2]|0,c[K+4>>2]|0)|0;c[L>>2]=J;c[L+4>>2]=G;I=I+1|0;}while((I|0)<256);I=c[A>>2]|0;if((I|0)>0){L=0;do{J=c[D+(L<<2)>>2]|0;if((J|0)>0){K=c[H+4688+(L<<2)>>2]|0;M=c[C+(L<<2)>>2]|0;N=0;do{O=0;do{P=K+(N<<9)+(O<<4)|0;Q=M+(N<<9)+(O<<4)|0;R=wrc(c[Q>>2]|0,c[Q+4>>2]|0,c[P>>2]|0,c[P+4>>2]|0)|0;c[Q>>2]=R;c[Q+4>>2]=G;Q=K+(N<<9)+(O<<4)+8|0;R=M+(N<<9)+(O<<4)+8|0;P=wrc(c[R>>2]|0,c[R+4>>2]|0,c[Q>>2]|0,c[Q+4>>2]|0)|0;c[R>>2]=P;c[R+4>>2]=G;O=O+1|0;}while((O|0)<32);N=N+1|0;}while((N|0)<(J|0))}L=L+1|0;}while((L|0)<(I|0))}F=F+1|0;}while((F|0)<(c[E>>2]|0))}E=z;z=u;u=0;F=6291456;do{C=B+(u<<4)|0;D=c[C+4>>2]|0;I=B+(u<<4)+8|0;L=c[I>>2]|0;H=c[I+4>>2]|0;Rb(z|0,F|0,2454088,(S=i,i=i+32|0,c[S>>2]=c[C>>2],c[S+8>>2]=D,c[S+16>>2]=L,c[S+24>>2]=H,S)|0)|0;i=S;z=z+(lrc(z|0)|0)|0;u=u+1|0;F=E-z|0}while((u|0)<256);Rb(z|0,F|0,2364824,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0)|0;i=S;F=c[A>>2]|0;if((F|0)>0){u=m+38164|0;B=m+4688|0;H=z;L=0;D=F;while(1){F=u+(L<<2)|0;if((c[F>>2]|0)>0){C=B+(L<<2)|0;I=H;J=0;while(1){N=0;T=I;do{M=c[C>>2]|0;K=M+(J<<9)+(N<<4)|0;O=c[K+4>>2]|0;R=M+(J<<9)+(N<<4)+8|0;M=c[R>>2]|0;P=c[R+4>>2]|0;Rb(T|0,E-T|0,2454088,(S=i,i=i+32|0,c[S>>2]=c[K>>2],c[S+8>>2]=O,c[S+16>>2]=M,c[S+24>>2]=P,S)|0)|0;i=S;T=T+(lrc(T|0)|0)|0;N=N+1|0;}while((N|0)<32);N=J+1|0;if((N|0)<(c[F>>2]|0)){I=T;J=N}else{break}}U=T;V=c[A>>2]|0}else{U=H;V=D}J=L+1|0;if((J|0)<(V|0)){H=U;L=J;D=V}else{W=U;break}}}else{W=z}Rb(W|0,E-W|0,2299584,(S=i,i=i+8|0,c[S>>2]=c[m+38520>>2],S)|0)|0;i=S;x=0;i=h;return x|0}W=Erc(v,w,140,0)|0;E=G;z=m+4720|0;if((c[z>>2]|0)>3){U=Erc(v,w,12,0)|0;X=G;Y=U}else{X=E;Y=W}W=wrc(Y,X,16384,0)|0;X=d5a(b,e,W,G)|0;if((X|0)<0){x=X;i=h;return x|0}X=e+24|0;W=e+28|0;SYa(s,c[X>>2]|0,c[W>>2]|0);UYa(s,214748364,248);WHb(t);Y=YHb(t,f)|0;if((Y|0)<0){x=Y;i=h;return x|0}Y=b+804|0;c[(c[Y>>2]|0)+88>>2]=1;t=c[b+136>>2]|0;do{if((t|0)==0){Z=36}else{if(((c[m+4756>>2]|0)%(t|0)|0|0)==0){Z=36;break}Vda(s,k,0);c[(c[Y>>2]|0)+84>>2]=0}}while(0);a:do{if((Z|0)==36){Vda(s,k,1);c[(c[Y>>2]|0)+84>>2]=1;t=m+38520|0;c[t>>2]=(c[t>>2]|0)+1;t=j|0;E=c[q>>2]|0;U=E+8|0;mrc(t|0,-128|0,32)|0;w=c[z>>2]|0;if((w|0)<2){Yda(U,t,w,0);v=m+4796|0;Yda(U,t,c[v>>2]|0,0);if((c[v>>2]|0)>1){v=1;do{Yda(U,t,(d[n+38196+v|0]|0)-(d[E+280+v|0]|0)|0,1);v=v+1|0;}while((v|0)<256)}Yda(U,t,c[m+38488>>2]|0,0);if((c[z>>2]|0)>0){Yda(U,t,c[m+38512>>2]|0,0)}Vda(U,t,c[m+4736>>2]|0);Yda(U,t,c[m+4740>>2]|0,0);Yda(U,t,c[m+4744>>2]|0,0);Vda(U,t,c[m+4748>>2]|0);Zda(U,m+15124|0);break}if((w|0)>=3){break}v=m+40796|0;Yda(U,t,c[v>>2]|0,0);if((c[v>>2]|0)<=0){break}E=m+40804|0;V=m+4728|0;D=m+40800|0;L=m+4732|0;H=m+4792|0;A=m+4|0;T=0;b:while(1){B=c[n+39772+(T<<2)>>2]|0;u=ca((c[B+40816>>2]|0)+1|0,c[E>>2]|0)|0;Yda(U,t,(u|0)/(c[V>>2]|0)|0,0);u=ca((c[B+40820>>2]|0)+1|0,c[D>>2]|0)|0;Yda(U,t,(u|0)/(c[L>>2]|0)|0,0);u=ca((c[B+40808>>2]|0)+1|0,c[E>>2]|0)|0;Yda(U,t,((u|0)/(c[V>>2]|0)|0)-1|0,0);u=ca((c[B+40812>>2]|0)+1|0,c[D>>2]|0)|0;Yda(U,t,((u|0)/(c[L>>2]|0)|0)-1|0,0);u=0;while(1){if((u|0)>=(c[H>>2]|0)){break}B=n+4804+(u*2580|0)+2560|0;Yda(U,t,c[B>>2]|0,0);if((c[B>>2]|0)==(c[(c[A>>2]|0)+572>>2]|0)){u=u+1|0}else{break b}}T=T+1|0;if((T|0)>=(c[v>>2]|0)){break a}}KIb(0,0,2248568,(S=i,i=i+24|0,c[S>>2]=2568728,c[S+8>>2]=2174216,c[S+16>>2]=533,S)|0);i=S;Hd();return 0}}while(0);if((c[m+4796>>2]|0)>1){n=1;do{q=a[m+(n+38196)|0]|0;a[r+280+n|0]=q;a[256-n+(r+24)|0]=-q;n=n+1|0;}while((n|0)<256)}n=m+40796|0;r=c[n>>2]|0;if((r|0)>1){q=1;j=r;while(1){k=c[p+(q<<2)>>2]|0;s=c[X>>2]|0;v=c[W>>2]|0;T=Erc(v,(v|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;A=Crc(T,G,j,(j|0)<0|0?-1:0)|0;SYa(k+8|0,s+A|0,(v|0)/(j|0)|0);v=q+1|0;A=c[n>>2]|0;if((v|0)<(A|0)){q=v;j=A}else{_=A;break}}}else{_=r}se[c[b+824>>2]&127](b,854,o,0,_,4)|0;_=c[X>>2]|0;c:do{if((c[n>>2]|0)>0){o=m+38496|0;r=0;j=_;while(1){q=c[p+(r<<2)>>2]|0;if((c[q+4796>>2]|0)==0){A=q+572|0;v=c[A>>2]|0;s=q+568|0;if((v|0)<32){k=c[s>>2]<<v;c[s>>2]=k;v=q+580|0;T=k>>>24&255;while(1){k=c[v>>2]|0;c[v>>2]=k+1;a[k]=T;k=c[s>>2]|0;c[s>>2]=k<<8;t=(c[A>>2]|0)+8|0;c[A>>2]=t;if((t|0)<32){T=k>>>16&255}else{$=v;break}}}else{$=q+580|0}c[A>>2]=32;c[s>>2]=0;aa=(((c[$>>2]|0)-(c[q+576>>2]|0)<<3|7|0)/8|0)+(c[q+4800>>2]|0)|0}else{a[l]=-127;v=q+8|0;Vda(v,l,0);aa=VYa(v)|0}if((r|0)>0){Z=66}else{if((c[z>>2]|0)>2){Z=66}else{ba=aa}}if((Z|0)==66){Z=0;if((aa|0)>=((c[W>>2]|0)/(c[n>>2]|0)|0|0)){Z=67;break}orc(j|0,c[q+536>>2]|0,aa|0)|0;if((aa|0)>=16777216){Z=69;break}a[j+(aa+2)|0]=aa;a[j+(aa+1)|0]=aa>>>8;a[j+aa|0]=aa>>>16;ba=aa+3|0}if((c[o>>2]|0)==0){da=ba}else{v=ba+1|0;a[j+ba|0]=0;T=j+v|0;y=EGb(DGb(3)|0,0,j,v)|0;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;da=ba+5|0}T=j+da|0;v=r+1|0;if((v|0)<(c[n>>2]|0)){r=v;j=T}else{ea=T;break c}}if((Z|0)==67){KIb(0,0,2248568,(S=i,i=i+24|0,c[S>>2]=2206496,c[S+8>>2]=2174216,c[S+16>>2]=1281,S)|0);i=S;Hd();return 0}else if((Z|0)==69){KIb(0,0,2248568,(S=i,i=i+24|0,c[S>>2]=2146640,c[S+8>>2]=2174216,c[S+16>>2]=1283,S)|0);i=S;Hd();return 0}}else{ea=_}}while(0);if((c[b+88>>2]&512|0)!=0){a[c[b+668>>2]|0]=0}b=m+4756|0;c[b>>2]=(c[b>>2]|0)+1;c[W>>2]=ea-(c[X>>2]|0);X=f+136|0;f=c[X>>2]|0;ea=c[X+4>>2]|0;X=e+16|0;c[X>>2]=f;c[X+4>>2]=ea;X=e+8|0;c[X>>2]=f;c[X+4>>2]=ea;ea=e+36|0;c[ea>>2]=c[ea>>2]|c[(c[Y>>2]|0)+84>>2];c[g>>2]=1;x=0;i=h;return x|0}function Uda(a){a=a|0;VHb(a+804|0);Opb(a)|0;return 0}function Vda(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b+4|0;h=c[g>>2]|0;i=(ca(d[e]|0,h)|0)>>8;j=h-i|0;if((f|0)==0){c[g>>2]=j;k=(d[e]|0)+(b+16)|0}else{f=b|0;c[f>>2]=(c[f>>2]|0)+j;c[g>>2]=i;k=(d[e]|0)+(b+272)|0}a[e]=a[k]|0;if((c[g>>2]|0)>=256){return}k=b+12|0;e=b|0;i=b+532|0;j=b+8|0;b=c[k>>2]|0;f=c[e>>2]|0;while(1){do{if((b|0)<0){h=f>>8;c[k>>2]=h;l=h;m=f}else{if((f|0)<65281){h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=-1;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>8;c[k>>2]=n;l=n;m=h;break}if((f|0)<=65535){c[j>>2]=(c[j>>2]|0)+1;l=b;m=f;break}h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b+1;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=0;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>>8&255;c[k>>2]=n;l=n;m=h}}while(0);h=m<<8&65280;c[e>>2]=h;n=c[g>>2]<<8;c[g>>2]=n;if((n|0)<256){b=l;f=h}else{break}}return}function Wda(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0;h=i;i=i+704|0;j=h|0;k=h+32|0;l=h+40|0;m=h+88|0;n=h+696|0;o=c[g>>2]|0;g=o;p=o+4|0;q=c[(c[p>>2]|0)+60>>2]|0;r=q;s=o+40808|0;t=c[s>>2]|0;u=o+40812|0;v=c[u>>2]|0;w=o+40816|0;x=c[w>>2]|0;z=o+40820|0;A=c[z>>2]|0;B=q+4760|0;C=c[B>>2]|0;D=((e[(qKb(c[f+140>>2]|0)|0)+8>>1]|0)>>>2&7)+1|0;E=o+8|0;F=E;H=h+152|0;nrc(H|0,E|0,540)|0;I=C|0;J=c[I>>2]|0;K=ca(D,x)|0;L=C+32|0;M=K+(ca(c[L>>2]|0,A)|0)|0;N=C+4|0;O=c[N>>2]|0;P=C+36|0;Q=(ca(c[P>>2]|0,A)|0)+K|0;R=C+8|0;S=c[R>>2]|0;T=C+40|0;U=(ca(c[T>>2]|0,A)|0)+K|0;V=o+40828|0;c[V>>2]=0;W=q+4720|0;if((c[W>>2]|0)>3){mrc(m|0,0,60)|0;X=o+38512|0;Y=(c[X>>2]|0)<9;if((v|0)>0){Z=c[o+38492>>2]|0;_=(t|0)>0;$=t<<1;aa=0;do{if(_){ba=(aa|0)==0;da=0;ea=0;fa=0;ga=0;while(1){if(Y){ha=c[J+((ga<<2)+M+(ca(c[L>>2]|0,aa)|0))>>2]|0;ia=ha>>>16&255;ja=ha>>>8&255;ka=ha&255}else{ha=ga<<1;la=e[J+(ha+M+(ca(c[L>>2]|0,aa)|0))>>1]|0;ma=e[O+(ha+Q+(ca(c[P>>2]|0,aa)|0))>>1]|0;ia=e[S+(ha+U+(ca(c[T>>2]|0,aa)|0))>>1]|0;ja=ma;ka=la}la=ia-da|0;ma=ja-ea|0;ha=ka-fa|0;na=Z+(ga<<1)|0;if((ga|0)==0|ba){oa=Z+(ga+t<<1)|0;pa=Z+(ga+$<<1)|0}else{qa=ma-(b[na>>1]|0)|0;ra=Z+(ga+t<<1)|0;sa=Z+(ga+$<<1)|0;ta=la-qa-(b[sa>>1]|0)|0;ua=ha-qa-(b[ra>>1]|0)|0;va=0;while(1){wa=ca(c[1706816+(va<<3)>>2]|0,ta)|0;xa=((ca(c[1706820+(va<<3)>>2]|0,ua)|0)+wa>>2)+qa|0;wa=m+(va<<2)|0;c[wa>>2]=((xa|0)>-1?xa:-xa|0)+(c[wa>>2]|0);wa=va+1|0;if((wa|0)<15){va=wa}else{oa=ra;pa=sa;break}}}b[na>>1]=ma;b[oa>>1]=ha;b[pa>>1]=la;sa=ga+1|0;if((sa|0)<(t|0)){da=ia;ea=ja;fa=ka;ga=sa}else{break}}}aa=aa+1|0;}while((aa|0)<(v|0));ya=c[m+4>>2]|0;za=c[m>>2]|0;Aa=c[m+8>>2]|0;Ba=c[m+12>>2]|0;Ca=c[m+16>>2]|0;Da=c[m+20>>2]|0;Ea=c[m+24>>2]|0;Fa=c[m+28>>2]|0;Ga=c[m+32>>2]|0;Ha=c[m+36>>2]|0;Ia=c[m+40>>2]|0;Ja=c[m+44>>2]|0;Ka=c[m+48>>2]|0;La=c[m+52>>2]|0;Ma=c[m+56>>2]|0}else{ya=0;za=0;Aa=0;Ba=0;Ca=0;Da=0;Ea=0;Fa=0;Ga=0;Ha=0;Ia=0;Ja=0;Ka=0;La=0;Ma=0}aa=(ya|0)<(za|0)|0;za=(Aa|0)<(c[m+(aa<<2)>>2]|0)?2:aa;aa=(Ba|0)<(c[m+(za<<2)>>2]|0)?3:za;za=(Ca|0)<(c[m+(aa<<2)>>2]|0)?4:aa;aa=(Da|0)<(c[m+(za<<2)>>2]|0)?5:za;za=(Ea|0)<(c[m+(aa<<2)>>2]|0)?6:aa;aa=(Fa|0)<(c[m+(za<<2)>>2]|0)?7:za;za=(Ga|0)<(c[m+(aa<<2)>>2]|0)?8:aa;aa=(Ha|0)<(c[m+(za<<2)>>2]|0)?9:za;za=(Ia|0)<(c[m+(aa<<2)>>2]|0)?10:aa;aa=(Ja|0)<(c[m+(za<<2)>>2]|0)?11:za;za=(Ka|0)<(c[m+(aa<<2)>>2]|0)?12:aa;aa=(La|0)<(c[m+(za<<2)>>2]|0)?13:za;za=(Ma|0)<(c[m+(aa<<2)>>2]|0)?14:aa;c[o+40832>>2]=c[1706820+(za<<3)>>2];c[o+40836>>2]=c[1706816+(za<<3)>>2];Na=X}else{c[o+40832>>2]=1;c[o+40836>>2]=1;Na=o+38512|0}X=f+804|0;za=j|0;j=q+40804|0;aa=q+4728|0;m=q+40800|0;Ma=q+4732|0;La=q+4792|0;Ka=q+4|0;Ja=o+40832|0;Ia=o+40836|0;Ha=o+4796|0;Ga=n|0;n=o+4800|0;Fa=o+536|0;Ea=o+544|0;Da=o+588|0;Ca=o+576|0;Ba=o+584|0;Aa=o+580|0;ya=o+572|0;ka=o+568|0;ja=(A|x|0)==0;ia=q+38488|0;pa=-t|0;oa=q+4740|0;$=-v|0;Z=q+4744|0;Y=q+4736|0;q=o+4748|0;_=C+12|0;ga=C+44|0;C=o+4720|0;fa=f;f=o+38484|0;ea=o+38492|0;da=t+6|0;ba=da<<3;sa=(v|0)>0;ra=(t|0)>0;va=t-1|0;qa=t<<2;ua=o+4752|0;ta=o+592|0;wa=(ta|0)==0;xa=(ta|0)!=0;ta=o+540|0;o=t*35|0;Oa=l|0;Pa=l+12|0;Qa=l+24|0;Ra=l+36|0;a:while(1){if((c[(c[X>>2]|0)+84>>2]|0)!=0){Npb(r,g)}do{if((c[W>>2]|0)>2){mrc(za|0,-128|0,32)|0;Sa=ca((c[w>>2]|0)+1|0,c[j>>2]|0)|0;Yda(F,za,(Sa|0)/(c[aa>>2]|0)|0,0);Sa=ca((c[z>>2]|0)+1|0,c[m>>2]|0)|0;Yda(F,za,(Sa|0)/(c[Ma>>2]|0)|0,0);Sa=ca((c[s>>2]|0)+1|0,c[j>>2]|0)|0;Yda(F,za,((Sa|0)/(c[aa>>2]|0)|0)-1|0,0);Sa=ca((c[u>>2]|0)+1|0,c[m>>2]|0)|0;Yda(F,za,((Sa|0)/(c[Ma>>2]|0)|0)-1|0,0);Sa=0;while(1){if((Sa|0)>=(c[La>>2]|0)){break}Ta=r+4804+(Sa*2580|0)+2560|0;Yda(F,za,c[Ta>>2]|0,0);if((c[Ta>>2]|0)==(c[(c[Ka>>2]|0)+572>>2]|0)){Sa=Sa+1|0}else{Ua=25;break a}}Sa=c[B>>2]|0;if((c[Sa+296>>2]|0)==0){Yda(F,za,3,0)}else{Yda(F,za,(c[Sa+300>>2]|0)==0?2:1,0)}Yda(F,za,c[(c[B>>2]|0)+124>>2]|0,0);Yda(F,za,c[(c[B>>2]|0)+128>>2]|0,0);if((c[W>>2]|0)<=3){break}Vda(F,za,(c[V>>2]|0)==1|0);Sa=c[V>>2]|0;if((Sa|0)==1){Npb(r,g);Va=c[V>>2]|0}else{Va=Sa}Yda(F,za,Va,0);if((c[V>>2]|0)==1){break}Yda(F,za,c[Ja>>2]|0,0);Yda(F,za,c[Ia>>2]|0,0)}}while(0);if((c[Ha>>2]|0)==0){if((c[W>>2]|0)>2){a[Ga]=-127;Vda(F,Ga,0);if((c[W>>2]|0)>2|ja){Ua=38}else{Wa=0}}else{if(ja){Ua=38}else{Wa=0}}if((Ua|0)==38){Ua=0;Wa=VYa(F)|0}c[n>>2]=Wa;Sa=c[Fa>>2]|0;la=(c[Ea>>2]|0)-Sa-Wa|0;ha=(la|0)<0;ma=ha?0:Sa+Wa|0;Sa=ha?0:la;c[Da>>2]=Sa<<3;c[Ca>>2]=ma;c[Ba>>2]=ma+Sa;c[Aa>>2]=ma;c[ya>>2]=32;c[ka>>2]=0}do{if((c[ia>>2]|0)==0){ma=c[oa>>2]|0;Sa=-(pa>>ma)|0;la=c[Z>>2]|0;ha=-($>>la)|0;na=A>>la;la=c[L>>2]|0;Ta=Xda(g,(c[I>>2]|0)+((ca(la,A)|0)+K)|0,t,v,la,0)|0;if((c[Y>>2]|0)==0){Xa=Ta}else{la=ca(x>>ma,D)|0;ma=c[P>>2]|0;Ya=Xda(g,(c[N>>2]|0)+((ca(ma,na)|0)+la)|0,Sa,ha,ma,1)|0|Ta;Ta=c[T>>2]|0;Xa=Ya|(Xda(g,(c[R>>2]|0)+((ca(Ta,na)|0)+la)|0,Sa,ha,Ta,1)|0)}if((c[q>>2]|0)==0){Za=Xa}else{Ta=c[ga>>2]|0;Za=Xda(g,(c[_>>2]|0)+((ca(Ta,A)|0)+K)|0,t,v,Ta,2)|0|Xa}if((Za|0)<0){_a=Za}else{$a=0;Ua=314;break a}}else{Ta=(c[(c[p>>2]|0)+572>>2]|0)!=0?3:2;ha=c[Na>>2]|0;Sa=(ha|0)<9;la=(ha|0)>0?ha:8;ha=1<<la;c[f>>2]=0;mrc(c[ea>>2]|0,0,ca(ba,Ta)|0)|0;if(!sa){$a=0;Ua=314;break a}na=Ta<<1;Ya=Ta*3|0;ma=0;ab=0;b:while(1){bb=c[ea>>2]|0;cb=v-ma|0;db=0;do{eb=(cb+db|0)%(Ta|0)|0;c[l+(db<<2)>>2]=bb+((ca(eb,da)|0)+3<<1);c[l+12+(db<<2)>>2]=bb+((ca(eb+Ta|0,da)|0)+3<<1);c[l+24+(db<<2)>>2]=bb+((ca(eb+na|0,da)|0)+3<<1);c[l+36+(db<<2)>>2]=bb+((ca(eb+Ya|0,da)|0)+3<<1);db=db+1|0;}while((db|0)<(Ta|0));if(ra){db=c[Oa>>2]|0;bb=c[Pa>>2]|0;cb=c[Qa>>2]|0;eb=c[Ra>>2]|0;fb=0;gb=ab;while(1){if(Sa){hb=c[J+((fb<<2)+M+(ca(c[L>>2]|0,ma)|0))>>2]|0;ib=hb>>>24&65535;jb=hb>>>16&255;kb=hb>>>8&255;lb=hb&255}else{hb=fb<<1;mb=e[J+(hb+M+(ca(c[L>>2]|0,ma)|0))>>1]|0;nb=e[O+(hb+Q+(ca(c[P>>2]|0,ma)|0))>>1]|0;ib=gb;jb=e[S+(hb+U+(ca(c[T>>2]|0,ma)|0))>>1]|0;kb=nb;lb=mb}if((c[V>>2]|0)==1){ob=jb&65535;pb=kb&65535;qb=lb&65535}else{mb=lb-kb|0;nb=jb-kb|0;hb=ca(c[Ja>>2]|0,mb)|0;ob=nb+ha&65535;pb=(((ca(c[Ia>>2]|0,nb)|0)+hb|0)>>>2)+kb&65535;qb=mb+ha&65535}b[db+(fb<<1)>>1]=pb;b[bb+(fb<<1)>>1]=qb;b[cb+(fb<<1)>>1]=ob;b[eb+(fb<<1)>>1]=ib;mb=fb+1|0;if((mb|0)<(t|0)){fb=mb;gb=ib}else{rb=ib;break}}}else{rb=ab}if(((c[q>>2]|0)+3|0)>0){gb=0;while(1){fb=c[l+(gb*12|0)+4>>2]|0;eb=c[l+(gb*12|0)>>2]|0;b[eb-2>>1]=b[fb>>1]|0;b[fb+(t<<1)>>1]=b[fb+(va<<1)>>1]|0;cb=c[V>>2]|0;bb=gb+1|0;db=(bb|0)/2|0;c:do{if(Sa&(cb|0)==0){mb=c[f>>2]|0;if((c[Ha>>2]|0)==0){hb=c[Ca>>2]|0;if(((c[Ba>>2]|0)-hb-(32-(c[ya>>2]|0)+((c[Aa>>2]|0)-hb<<3)>>3)|0)<(qa|0)){Ua=63;break b}}else{if(((c[Ea>>2]|0)-(c[ta>>2]|0)|0)<(o|0)){Ua=61;break b}}do{if(ra){hb=g+4804+(db*2580|0)+1790|0;nb=g+4804+(db*2580|0)+2572|0;sb=g+4804+(db*2580|0)+2568|0;tb=g+4804+(db*2580|0)+2560|0;ub=l+(gb*12|0)+8|0;vb=0;wb=mb;xb=0;yb=0;while(1){zb=vb+1|0;Ab=vb-1|0;Bb=b[fb+(Ab<<1)>>1]|0;Cb=b[fb+(vb<<1)>>1]|0;Db=b[fb+(zb<<1)>>1]|0;Eb=b[eb+(Ab<<1)>>1]|0;if((b[hb>>1]|0)==0){Fb=(b[g+4804+(db*2580|0)+512+((Bb-Cb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+((Eb-Bb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1024+((Cb-Db&255)<<1)>>1]|0)|0}else{Fb=(b[g+4804+(db*2580|0)+512+((Bb-Cb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+((Eb-Bb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1024+((Cb-Db&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1536+(((e[eb+(vb-2<<1)>>1]|0)-Eb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+2048+(((e[(c[ub>>2]|0)+(vb<<1)>>1]|0)-Cb&255)<<1)>>1]|0)|0}Db=b[eb+(vb<<1)>>1]|0;Ab=Cb-Bb+Eb|0;do{if((Eb|0)>(Ab|0)){if((Cb|0)<=(Ab|0)){Gb=Ab;break}Gb=(Cb|0)>(Eb|0)?Eb:Cb}else{if((Ab|0)<=(Cb|0)){Gb=Ab;break}Gb=(Cb|0)>(Eb|0)?Cb:Eb}}while(0);Eb=Db-Gb|0;if((Fb|0)<0){Hb=-Fb|0;Ib=-Eb|0}else{Hb=Fb;Ib=Eb}Eb=Ib+256&511;Cb=Eb-256|0;do{if((c[Ha>>2]|0)==0){Ab=(Hb|0)==0?1:yb;if((Ab|0)==0){Jb=Cb;Kb=xb;Lb=wb}else{if((Cb|0)==0){Mb=Ab;Nb=xb+1|0;Ob=wb;break}Ab=d[1359920+wb|0]|0;Bb=1<<Ab;Pb=c[ka>>2]|0;Qb=c[ya>>2]|0;if((xb|0)<(Bb|0)){Rb=wb;Sb=xb;Tb=Ab;Ub=Pb;Vb=Qb}else{Ab=wb;Wb=xb;Xb=Bb;Bb=Pb;Pb=Qb;while(1){Qb=Wb-Xb|0;Yb=Ab+1|0;if((Pb|0)>1){Zb=Pb-1|0;_b=Bb<<1|1}else{$b=je(1>>>((1-Pb|0)>>>0)|Bb<<Pb|0)|0;ac=c[Aa>>2]|0;y=$b;a[ac]=y;y=y>>8;a[ac+1|0]=y;y=y>>8;a[ac+2|0]=y;y=y>>8;a[ac+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;Zb=Pb+31|0;_b=1}c[ka>>2]=_b;c[ya>>2]=Zb;ac=d[1359920+Yb|0]|0;$b=1<<ac;if((Qb|0)<($b|0)){Rb=Yb;Sb=Qb;Tb=ac;Ub=_b;Vb=Zb;break}else{Ab=Yb;Wb=Qb;Xb=$b;Bb=_b;Pb=Zb}}}Pb=Tb+1|0;if((Vb|0)>(Pb|0)){bc=Vb-Pb|0;cc=Ub<<Pb|Sb}else{Bb=je(Sb>>>((Pb-Vb|0)>>>0)|Ub<<Vb|0)|0;Pb=c[Aa>>2]|0;y=Bb;a[Pb]=y;y=y>>8;a[Pb+1|0]=y;y=y>>8;a[Pb+2|0]=y;y=y>>8;a[Pb+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;bc=Vb+31-Tb|0;cc=Sb}c[ka>>2]=cc;c[ya>>2]=bc;Jb=(((Cb|0)>0)<<31>>31)+Cb|0;Kb=0;Lb=(Rb|0)==0?0:Rb-1|0}Pb=c[nb>>2]|0;Bb=Pb+(Hb*6|0)+4|0;Xb=Jb+256-(a[Bb]|0)&511;Wb=Xb-256|0;Ab=Pb+(Hb*6|0)+5|0;$b=d[Ab]|0;Qb=Pb+(Hb*6|0)+2|0;Yb=e[Qb>>1]|0;if($b>>>0<Yb>>>0){ac=$b;dc=0;while(1){ec=dc+1|0;fc=ac<<1;if((fc|0)<(Yb|0)){ac=fc;dc=ec}else{gc=ec;break}}}else{gc=0}dc=Pb+(Hb*6|0)|0;ac=(((b[dc>>1]<<1)+$b>>31^Wb)*-2|0)-1|0;Yb=ac>>31^ac;ac=Yb>>gc;do{if((ac|0)<12){ec=ac+gc|0;fc=ec+1|0;hc=1<<gc;ic=(Yb&hc-1)+hc|0;hc=c[ka>>2]|0;jc=c[ya>>2]|0;if((jc|0)>(fc|0)){kc=jc-fc|0;lc=hc<<fc|ic;break}else{mc=je(ic>>>((fc-jc|0)>>>0)|hc<<jc|0)|0;hc=c[Aa>>2]|0;y=mc;a[hc]=y;y=y>>8;a[hc+1|0]=y;y=y>>8;a[hc+2|0]=y;y=y>>8;a[hc+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;kc=31-ec+jc|0;lc=ic;break}}else{ic=Yb-11|0;jc=c[ka>>2]|0;ec=c[ya>>2]|0;if((ec|0)>21){kc=ec-21|0;lc=jc<<21|ic;break}else{hc=je(ic>>>((21-ec|0)>>>0)|jc<<ec|0)|0;jc=c[Aa>>2]|0;y=hc;a[jc]=y;y=y>>8;a[jc+1|0]=y;y=y>>8;a[jc+2|0]=y;y=y>>8;a[jc+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;kc=ec+11|0;lc=ic;break}}}while(0);c[ka>>2]=lc;c[ya>>2]=kc;Yb=a[Ab]|0;ac=Yb&255;$b=(e[Qb>>1]|0)+((Wb|0)>-1?Wb:256-Xb|0)|0;Pb=(b[dc>>1]|0)+Wb|0;if(Yb<<24>>24==-128){nc=ac>>>1;oc=Pb>>1;pc=$b>>>1&32767}else{nc=ac;oc=Pb;pc=$b&65535}b[Qb>>1]=pc;$b=nc+1|0;Pb=~nc;do{if((oc|0)>(Pb|0)){if((oc|0)<=0){qc=oc&65535;break}ac=a[Bb]|0;if(!(ac<<24>>24==127)){a[Bb]=ac+1}ac=oc-$b|0;qc=(ac|0)>0?0:ac&65535}else{ac=a[Bb]|0;if(!(ac<<24>>24==-128)){a[Bb]=ac-1}ac=$b+oc|0;if((ac|0)>(Pb|0)){qc=ac&65535;break}qc=-nc&65535}}while(0);b[dc>>1]=qc;a[Ab]=$b;Mb=0;Nb=Kb;Ob=Lb}else{Pb=c[sb>>2]|0;Bb=Pb+(Hb<<5)|0;if((c[ua>>2]&512|0)==0){if((Cb|0)==0){Vda(F,Bb,1);Mb=yb;Nb=xb;Ob=wb;break}Qb=(Cb|0)>-1?Cb:256-Eb|0;Wb=Qb>>>0>65535>>>0;Xb=Wb?Qb>>>16:Qb;ac=Wb?16:0;if((Xb&65280|0)==0){rc=ac;sc=Xb}else{rc=ac|8;sc=Xb>>>8}Xb=(d[1359664+sc|0]|0)+rc|0;Vda(F,Bb,0);if((Xb|0)>=10){ac=0;while(1){Wb=ac+1|0;Vda(F,((ac|0)>9?10:Wb)+(Pb+(Hb<<5))|0,1);if((Wb|0)<(Xb|0)){ac=Wb}else{break}}Vda(F,Pb+(Hb<<5)+10|0,0);ac=Xb;while(1){$b=ac-1|0;Vda(F,(($b|0)>9?31:ac+21|0)+(Pb+(Hb<<5))|0,Qb>>>($b>>>0)&1);if(($b|0)>0){ac=$b}else{break}}Vda(F,Pb+(Hb<<5)+21|0,Cb>>>31);Mb=yb;Nb=xb;Ob=wb;break}if((Xb|0)>0){ac=0;do{ac=ac+1|0;Vda(F,Pb+(Hb<<5)+ac|0,1);}while((ac|0)<(Xb|0));Vda(F,Xb+1+(Pb+(Hb<<5))|0,0);ac=Xb;while(1){$b=ac-1|0;Vda(F,ac+21+(Pb+(Hb<<5))|0,Qb>>>($b>>>0)&1);if(($b|0)>0){ac=$b}else{break}}}else{Vda(F,Pb+(Hb<<5)+1|0,0)}Vda(F,Xb+11+(Pb+(Hb<<5))|0,Cb>>>31);Mb=yb;Nb=xb;Ob=wb;break}ac=c[g+4688+(c[tb>>2]<<2)>>2]|0;if((Cb|0)==0){if(!wa){Qb=g+592+(d[Bb]<<4)+8|0;$b=wrc(c[Qb>>2]|0,c[Qb+4>>2]|0,1,0)|0;c[Qb>>2]=$b;c[Qb+4>>2]=G;Qb=ac+(Hb<<9)+8|0;$b=wrc(c[Qb>>2]|0,c[Qb+4>>2]|0,1,0)|0;c[Qb>>2]=$b;c[Qb+4>>2]=G}Vda(F,Bb,1);Mb=yb;Nb=xb;Ob=wb;break}Qb=(Cb|0)>-1?Cb:256-Eb|0;$b=Qb>>>0>65535>>>0;Ab=$b?Qb>>>16:Qb;dc=$b?16:0;if((Ab&65280|0)==0){tc=dc;uc=Ab}else{tc=dc|8;uc=Ab>>>8}Ab=(d[1359664+uc|0]|0)+tc|0;if(xa){dc=g+592+(d[Bb]<<4)|0;$b=wrc(c[dc>>2]|0,c[dc+4>>2]|0,1,0)|0;c[dc>>2]=$b;c[dc+4>>2]=G;dc=ac+(Hb<<9)|0;$b=wrc(c[dc>>2]|0,c[dc+4>>2]|0,1,0)|0;c[dc>>2]=$b;c[dc+4>>2]=G}Vda(F,Bb,0);if((Ab|0)>=10){dc=0;while(1){if(xa){$b=dc+1|0;Wb=(dc|0)>9?10:$b;Yb=g+592+(d[Pb+(Hb<<5)+Wb|0]<<4)+8|0;ic=wrc(c[Yb>>2]|0,c[Yb+4>>2]|0,1,0)|0;c[Yb>>2]=ic;c[Yb+4>>2]=G;Yb=ac+(Hb<<9)+(Wb<<4)+8|0;Wb=wrc(c[Yb>>2]|0,c[Yb+4>>2]|0,1,0)|0;c[Yb>>2]=Wb;c[Yb+4>>2]=G;vc=$b}else{vc=dc+1|0}Vda(F,((dc|0)>9?10:vc)+(Pb+(Hb<<5))|0,1);if((vc|0)<(Ab|0)){dc=vc}else{break}}dc=Pb+(Hb<<5)+10|0;if(xa){Bb=g+592+(d[dc]<<4)|0;Xb=wrc(c[Bb>>2]|0,c[Bb+4>>2]|0,1,0)|0;c[Bb>>2]=Xb;c[Bb+4>>2]=G;Bb=ac+(Hb<<9)+160|0;Xb=wrc(c[Bb>>2]|0,c[Bb+4>>2]|0,1,0)|0;c[Bb>>2]=Xb;c[Bb+4>>2]=G;Vda(F,dc,0);Bb=Ab;while(1){Xb=Bb-1|0;$b=Qb>>>(Xb>>>0)&1;Yb=(Xb|0)>9?31:Bb+21|0;Wb=Pb+(Hb<<5)+Yb|0;ic=g+592+(d[Wb]<<4)+($b<<3)|0;ec=wrc(c[ic>>2]|0,c[ic+4>>2]|0,1,0)|0;c[ic>>2]=ec;c[ic+4>>2]=G;ic=ac+(Hb<<9)+(Yb<<4)+($b<<3)|0;Yb=wrc(c[ic>>2]|0,c[ic+4>>2]|0,1,0)|0;c[ic>>2]=Yb;c[ic+4>>2]=G;Vda(F,Wb,$b);if((Xb|0)>0){Bb=Xb}else{break}}}else{Vda(F,dc,0);Bb=Ab;while(1){Xb=Bb-1|0;Vda(F,((Xb|0)>9?31:Bb+21|0)+(Pb+(Hb<<5))|0,Qb>>>(Xb>>>0)&1);if((Xb|0)>0){Bb=Xb}else{break}}}if(xa){Bb=Cb>>>31;dc=Pb+(Hb<<5)+21|0;Xb=g+592+(d[dc]<<4)+(Bb<<3)|0;$b=wrc(c[Xb>>2]|0,c[Xb+4>>2]|0,1,0)|0;c[Xb>>2]=$b;c[Xb+4>>2]=G;Xb=ac+(Hb<<9)+336+(Bb<<3)|0;$b=wrc(c[Xb>>2]|0,c[Xb+4>>2]|0,1,0)|0;c[Xb>>2]=$b;c[Xb+4>>2]=G;wc=dc;xc=Bb}else{wc=Pb+(Hb<<5)+21|0;xc=Cb>>>31}Vda(F,wc,xc);Mb=yb;Nb=xb;Ob=wb;break}Bb=(Ab|0)>0;if(Bb){if(xa){dc=0;do{dc=dc+1|0;Xb=Pb+(Hb<<5)+dc|0;$b=g+592+(d[Xb]<<4)+8|0;Wb=wrc(c[$b>>2]|0,c[$b+4>>2]|0,1,0)|0;c[$b>>2]=Wb;c[$b+4>>2]=G;$b=ac+(Hb<<9)+(dc<<4)+8|0;Wb=wrc(c[$b>>2]|0,c[$b+4>>2]|0,1,0)|0;c[$b>>2]=Wb;c[$b+4>>2]=G;Vda(F,Xb,1);}while((dc|0)<(Ab|0))}else{dc=0;do{dc=dc+1|0;Vda(F,Pb+(Hb<<5)+dc|0,1);}while((dc|0)<(Ab|0))}yc=Ab+1|0}else{yc=1}dc=Pb+(Hb<<5)+yc|0;if(xa){Xb=g+592+(d[dc]<<4)|0;$b=wrc(c[Xb>>2]|0,c[Xb+4>>2]|0,1,0)|0;c[Xb>>2]=$b;c[Xb+4>>2]=G;Xb=ac+(Hb<<9)+(yc<<4)|0;$b=wrc(c[Xb>>2]|0,c[Xb+4>>2]|0,1,0)|0;c[Xb>>2]=$b;c[Xb+4>>2]=G}Vda(F,dc,0);dc=Ab-1|0;if(Bb){if(xa){Xb=Ab;$b=dc;while(1){Wb=Qb>>>($b>>>0)&1;ic=Xb+21|0;Yb=Pb+(Hb<<5)+ic|0;ec=g+592+(d[Yb]<<4)+(Wb<<3)|0;jc=wrc(c[ec>>2]|0,c[ec+4>>2]|0,1,0)|0;c[ec>>2]=jc;c[ec+4>>2]=G;ec=ac+(Hb<<9)+(ic<<4)+(Wb<<3)|0;ic=wrc(c[ec>>2]|0,c[ec+4>>2]|0,1,0)|0;c[ec>>2]=ic;c[ec+4>>2]=G;Vda(F,Yb,Wb);if(($b|0)>0){Xb=$b;$b=$b-1|0}else{break}}}else{$b=Ab;Xb=dc;while(1){Vda(F,$b+21+(Pb+(Hb<<5))|0,Qb>>>(Xb>>>0)&1);if((Xb|0)>0){$b=Xb;Xb=Xb-1|0}else{break}}}}if(xa){Xb=Cb>>>31;$b=Ab+11|0;Qb=Pb+(Hb<<5)+$b|0;dc=g+592+(d[Qb]<<4)+(Xb<<3)|0;Bb=wrc(c[dc>>2]|0,c[dc+4>>2]|0,1,0)|0;c[dc>>2]=Bb;c[dc+4>>2]=G;dc=ac+(Hb<<9)+($b<<4)+(Xb<<3)|0;$b=wrc(c[dc>>2]|0,c[dc+4>>2]|0,1,0)|0;c[dc>>2]=$b;c[dc+4>>2]=G;zc=Qb;Ac=Xb}else{zc=Ab+11+(Pb+(Hb<<5))|0;Ac=Cb>>>31}Vda(F,zc,Ac);Mb=yb;Nb=xb;Ob=wb}}while(0);if((zb|0)<(t|0)){vb=zb;wb=Ob;xb=Nb;yb=Mb}else{break}}if((Mb|0)==0){Bc=Ob;break}yb=1<<d[1359920+Ob|0];if((Nb|0)<(yb|0)){Cc=Ob;Dc=Nb}else{xb=Ob;wb=Nb;vb=yb;yb=c[ka>>2]|0;tb=c[ya>>2]|0;while(1){sb=wb-vb|0;nb=xb+1|0;if((tb|0)>1){Ec=tb-1|0;Fc=yb<<1|1}else{ub=je(1>>>((1-tb|0)>>>0)|yb<<tb|0)|0;hb=c[Aa>>2]|0;y=ub;a[hb]=y;y=y>>8;a[hb+1|0]=y;y=y>>8;a[hb+2|0]=y;y=y>>8;a[hb+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;Ec=tb+31|0;Fc=1}c[ka>>2]=Fc;c[ya>>2]=Ec;hb=1<<d[1359920+nb|0];if((sb|0)<(hb|0)){Cc=nb;Dc=sb;break}else{xb=nb;wb=sb;vb=hb;yb=Fc;tb=Ec}}}if((Dc|0)==0){Bc=Cc;break}tb=c[ka>>2]|0;yb=c[ya>>2]|0;if((yb|0)>1){Gc=yb-1|0;Hc=tb<<1|1}else{vb=je(1>>>((1-yb|0)>>>0)|tb<<yb|0)|0;tb=c[Aa>>2]|0;y=vb;a[tb]=y;y=y>>8;a[tb+1|0]=y;y=y>>8;a[tb+2|0]=y;y=y>>8;a[tb+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;Gc=yb+31|0;Hc=1}c[ka>>2]=Hc;c[ya>>2]=Gc;Bc=Cc}else{Bc=mb}}while(0);c[f>>2]=Bc}else{mb=((cb|0)!=1)+la|0;yb=c[f>>2]|0;if((c[Ha>>2]|0)==0){tb=c[Ca>>2]|0;if(((c[Ba>>2]|0)-tb-(32-(c[ya>>2]|0)+((c[Aa>>2]|0)-tb<<3)>>3)|0)<(qa|0)){Ua=181;break b}}else{if(((c[Ea>>2]|0)-(c[ta>>2]|0)|0)<(o|0)){Ua=179;break b}}if((cb|0)==1){if(!ra){break}tb=(mb|0)>0;vb=0;while(1){wb=b[eb+(vb<<1)>>1]|0;if(tb){xb=mb;do{xb=xb-1|0;a[k]=-128;Vda(F,k,wb>>>(xb>>>0)&1);}while((xb|0)>0)}vb=vb+1|0;if((vb|0)>=(t|0)){break c}}}do{if(ra){vb=g+4804+(db*2580|0)+1790|0;tb=(mb|0)==8;xb=g+4804+(db*2580|0)+2572|0;wb=mb+12|0;hb=20-mb|0;sb=1<<mb-1;nb=(1<<mb)-1|0;ub=g+4804+(db*2580|0)+2568|0;Cb=g+4804+(db*2580|0)+2560|0;Eb=l+(gb*12|0)+8|0;Db=0;Xb=yb;Qb=0;dc=0;while(1){$b=Db+1|0;Bb=Db-1|0;Wb=b[fb+(Bb<<1)>>1]|0;Yb=b[fb+(Db<<1)>>1]|0;ec=b[fb+($b<<1)>>1]|0;ic=b[eb+(Bb<<1)>>1]|0;if((b[vb>>1]|0)==0){Ic=(b[g+4804+(db*2580|0)+512+((Wb-Yb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+((ic-Wb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1024+((Yb-ec&255)<<1)>>1]|0)|0}else{Ic=(b[g+4804+(db*2580|0)+512+((Wb-Yb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+((ic-Wb&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1024+((Yb-ec&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+1536+(((e[eb+(Db-2<<1)>>1]|0)-ic&255)<<1)>>1]|0)+(b[g+4804+(db*2580|0)+2048+(((e[(c[Eb>>2]|0)+(Db<<1)>>1]|0)-Yb&255)<<1)>>1]|0)|0}ec=b[eb+(Db<<1)>>1]|0;Bb=Yb-Wb+ic|0;do{if((ic|0)>(Bb|0)){if((Yb|0)<=(Bb|0)){Jc=Bb;break}Jc=(Yb|0)>(ic|0)?ic:Yb}else{if((Bb|0)<=(Yb|0)){Jc=Bb;break}Jc=(Yb|0)>(ic|0)?Yb:ic}}while(0);ic=ec-Jc|0;if((Ic|0)<0){Kc=-Ic|0;Lc=-ic|0}else{Kc=Ic;Lc=ic}if(tb){Mc=Lc<<24>>24}else{Mc=(Lc+sb&nb)-sb|0}do{if((c[Ha>>2]|0)==0){ic=(Kc|0)==0?1:dc;if((ic|0)==0){Nc=Mc;Oc=Qb;Pc=Xb}else{if((Mc|0)==0){Qc=ic;Rc=Qb+1|0;Sc=Xb;break}ic=d[1359920+Xb|0]|0;Yb=1<<ic;Bb=c[ka>>2]|0;zb=c[ya>>2]|0;if((Qb|0)<(Yb|0)){Tc=Xb;Uc=Qb;Vc=ic;Wc=Bb;Xc=zb}else{ic=Xb;Wb=Qb;jc=Yb;Yb=Bb;Bb=zb;while(1){zb=Wb-jc|0;hc=ic+1|0;if((Bb|0)>1){Yc=Bb-1|0;Zc=Yb<<1|1}else{mc=je(1>>>((1-Bb|0)>>>0)|Yb<<Bb|0)|0;fc=c[Aa>>2]|0;y=mc;a[fc]=y;y=y>>8;a[fc+1|0]=y;y=y>>8;a[fc+2|0]=y;y=y>>8;a[fc+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;Yc=Bb+31|0;Zc=1}c[ka>>2]=Zc;c[ya>>2]=Yc;fc=d[1359920+hc|0]|0;mc=1<<fc;if((zb|0)<(mc|0)){Tc=hc;Uc=zb;Vc=fc;Wc=Zc;Xc=Yc;break}else{ic=hc;Wb=zb;jc=mc;Yb=Zc;Bb=Yc}}}Bb=Vc+1|0;if((Xc|0)>(Bb|0)){_c=Xc-Bb|0;$c=Wc<<Bb|Uc}else{Yb=je(Uc>>>((Bb-Xc|0)>>>0)|Wc<<Xc|0)|0;Bb=c[Aa>>2]|0;y=Yb;a[Bb]=y;y=y>>8;a[Bb+1|0]=y;y=y>>8;a[Bb+2|0]=y;y=y>>8;a[Bb+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;_c=Xc+31-Vc|0;$c=Uc}c[ka>>2]=$c;c[ya>>2]=_c;Nc=(((Mc|0)>0)<<31>>31)+Mc|0;Oc=0;Pc=(Tc|0)==0?0:Tc-1|0}Bb=c[xb>>2]|0;Yb=Bb+(Kc*6|0)+4|0;jc=Nc-(a[Yb]|0)|0;if(tb){ad=jc<<24>>24}else{ad=(jc+sb&nb)-sb|0}jc=Bb+(Kc*6|0)+5|0;Wb=d[jc]|0;ic=Bb+(Kc*6|0)+2|0;Pb=e[ic>>1]|0;if(Wb>>>0<Pb>>>0){Ab=Wb;ac=0;while(1){mc=ac+1|0;zb=Ab<<1;if((zb|0)<(Pb|0)){Ab=zb;ac=mc}else{bd=mc;break}}}else{bd=0}ac=Bb+(Kc*6|0)|0;Ab=(((b[ac>>1]<<1)+Wb>>31^ad)*-2|0)-1|0;Pb=Ab>>31^Ab;Ab=Pb>>bd;do{if((Ab|0)<12){mc=Ab+bd|0;zb=mc+1|0;hc=1<<bd;fc=(Pb&hc-1)+hc|0;hc=c[ka>>2]|0;cd=c[ya>>2]|0;if((cd|0)>(zb|0)){dd=cd-zb|0;ed=hc<<zb|fc;break}else{fd=je(fc>>>((zb-cd|0)>>>0)|hc<<cd|0)|0;hc=c[Aa>>2]|0;y=fd;a[hc]=y;y=y>>8;a[hc+1|0]=y;y=y>>8;a[hc+2|0]=y;y=y>>8;a[hc+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;dd=31-mc+cd|0;ed=fc;break}}else{fc=Pb-11|0;cd=c[ka>>2]|0;mc=c[ya>>2]|0;if((mc|0)>(wb|0)){dd=mc-wb|0;ed=cd<<wb|fc;break}else{hc=je(fc>>>((wb-mc|0)>>>0)|cd<<mc|0)|0;cd=c[Aa>>2]|0;y=hc;a[cd]=y;y=y>>8;a[cd+1|0]=y;y=y>>8;a[cd+2|0]=y;y=y>>8;a[cd+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;dd=hb+mc|0;ed=fc;break}}}while(0);c[ka>>2]=ed;c[ya>>2]=dd;Pb=a[jc]|0;Ab=Pb&255;Wb=(e[ic>>1]|0)+((ad|0)>-1?ad:-ad|0)|0;Bb=(b[ac>>1]|0)+ad|0;if(Pb<<24>>24==-128){gd=Ab>>>1;hd=Bb>>1;id=Wb>>>1&32767}else{gd=Ab;hd=Bb;id=Wb&65535}b[ic>>1]=id;Wb=gd+1|0;Bb=~gd;do{if((hd|0)>(Bb|0)){if((hd|0)<=0){jd=hd&65535;break}Ab=a[Yb]|0;if(!(Ab<<24>>24==127)){a[Yb]=Ab+1}Ab=hd-Wb|0;jd=(Ab|0)>0?0:Ab&65535}else{Ab=a[Yb]|0;if(!(Ab<<24>>24==-128)){a[Yb]=Ab-1}Ab=Wb+hd|0;if((Ab|0)>(Bb|0)){jd=Ab&65535;break}jd=-gd&65535}}while(0);b[ac>>1]=jd;a[jc]=Wb;Qc=0;Rc=Oc;Sc=Pc}else{Bb=c[ub>>2]|0;Yb=Bb+(Kc<<5)|0;if((c[ua>>2]&512|0)==0){if((Mc|0)==0){Vda(F,Yb,1);Qc=dc;Rc=Qb;Sc=Xb;break}ic=(Mc|0)>-1?Mc:-Mc|0;Ab=ic>>>0>65535>>>0;Pb=Ab?ic>>>16:ic;fc=Ab?16:0;if((Pb&65280|0)==0){kd=fc;ld=Pb}else{kd=fc|8;ld=Pb>>>8}Pb=(d[1359664+ld|0]|0)+kd|0;Vda(F,Yb,0);if((Pb|0)>=10){fc=0;while(1){Ab=fc+1|0;Vda(F,((fc|0)>9?10:Ab)+(Bb+(Kc<<5))|0,1);if((Ab|0)<(Pb|0)){fc=Ab}else{break}}Vda(F,Bb+(Kc<<5)+10|0,0);fc=Pb;while(1){Wb=fc-1|0;Vda(F,((Wb|0)>9?31:fc+21|0)+(Bb+(Kc<<5))|0,ic>>>(Wb>>>0)&1);if((Wb|0)>0){fc=Wb}else{break}}Vda(F,Bb+(Kc<<5)+21|0,Mc>>>31);Qc=dc;Rc=Qb;Sc=Xb;break}if((Pb|0)>0){fc=0;do{fc=fc+1|0;Vda(F,Bb+(Kc<<5)+fc|0,1);}while((fc|0)<(Pb|0));Vda(F,Pb+1+(Bb+(Kc<<5))|0,0);fc=Pb;while(1){Wb=fc-1|0;Vda(F,fc+21+(Bb+(Kc<<5))|0,ic>>>(Wb>>>0)&1);if((Wb|0)>0){fc=Wb}else{break}}}else{Vda(F,Bb+(Kc<<5)+1|0,0)}Vda(F,Pb+11+(Bb+(Kc<<5))|0,Mc>>>31);Qc=dc;Rc=Qb;Sc=Xb;break}fc=c[g+4688+(c[Cb>>2]<<2)>>2]|0;if((Mc|0)==0){ic=g+592+(d[Yb]<<4)+8|0;Wb=wrc(c[ic>>2]|0,c[ic+4>>2]|0,1,0)|0;c[ic>>2]=Wb;c[ic+4>>2]=G;ic=fc+(Kc<<9)+8|0;Wb=wrc(c[ic>>2]|0,c[ic+4>>2]|0,1,0)|0;c[ic>>2]=Wb;c[ic+4>>2]=G;Vda(F,Yb,1);Qc=dc;Rc=Qb;Sc=Xb;break}ic=(Mc|0)>-1?Mc:-Mc|0;Wb=ic>>>0>65535>>>0;jc=Wb?ic>>>16:ic;ac=Wb?16:0;if((jc&65280|0)==0){md=ac;nd=jc}else{md=ac|8;nd=jc>>>8}jc=(d[1359664+nd|0]|0)+md|0;if(xa){ac=g+592+(d[Yb]<<4)|0;Wb=wrc(c[ac>>2]|0,c[ac+4>>2]|0,1,0)|0;c[ac>>2]=Wb;c[ac+4>>2]=G;ac=fc+(Kc<<9)|0;Wb=wrc(c[ac>>2]|0,c[ac+4>>2]|0,1,0)|0;c[ac>>2]=Wb;c[ac+4>>2]=G}Vda(F,Yb,0);if((jc|0)>=10){ac=0;while(1){if(xa){Wb=ac+1|0;Ab=(ac|0)>9?10:Wb;mc=g+592+(d[Bb+(Kc<<5)+Ab|0]<<4)+8|0;cd=wrc(c[mc>>2]|0,c[mc+4>>2]|0,1,0)|0;c[mc>>2]=cd;c[mc+4>>2]=G;mc=fc+(Kc<<9)+(Ab<<4)+8|0;Ab=wrc(c[mc>>2]|0,c[mc+4>>2]|0,1,0)|0;c[mc>>2]=Ab;c[mc+4>>2]=G;od=Wb}else{od=ac+1|0}Vda(F,((ac|0)>9?10:od)+(Bb+(Kc<<5))|0,1);if((od|0)<(jc|0)){ac=od}else{break}}ac=Bb+(Kc<<5)+10|0;if(xa){Yb=g+592+(d[ac]<<4)|0;Pb=wrc(c[Yb>>2]|0,c[Yb+4>>2]|0,1,0)|0;c[Yb>>2]=Pb;c[Yb+4>>2]=G;Yb=fc+(Kc<<9)+160|0;Pb=wrc(c[Yb>>2]|0,c[Yb+4>>2]|0,1,0)|0;c[Yb>>2]=Pb;c[Yb+4>>2]=G;Vda(F,ac,0);Yb=jc;while(1){Pb=Yb-1|0;Wb=ic>>>(Pb>>>0)&1;mc=(Pb|0)>9?31:Yb+21|0;Ab=Bb+(Kc<<5)+mc|0;cd=g+592+(d[Ab]<<4)+(Wb<<3)|0;hc=wrc(c[cd>>2]|0,c[cd+4>>2]|0,1,0)|0;c[cd>>2]=hc;c[cd+4>>2]=G;cd=fc+(Kc<<9)+(mc<<4)+(Wb<<3)|0;mc=wrc(c[cd>>2]|0,c[cd+4>>2]|0,1,0)|0;c[cd>>2]=mc;c[cd+4>>2]=G;Vda(F,Ab,Wb);if((Pb|0)>0){Yb=Pb}else{break}}}else{Vda(F,ac,0);Yb=jc;while(1){Pb=Yb-1|0;Vda(F,((Pb|0)>9?31:Yb+21|0)+(Bb+(Kc<<5))|0,ic>>>(Pb>>>0)&1);if((Pb|0)>0){Yb=Pb}else{break}}}if(xa){Yb=Mc>>>31;ac=Bb+(Kc<<5)+21|0;Pb=g+592+(d[ac]<<4)+(Yb<<3)|0;Wb=wrc(c[Pb>>2]|0,c[Pb+4>>2]|0,1,0)|0;c[Pb>>2]=Wb;c[Pb+4>>2]=G;Pb=fc+(Kc<<9)+336+(Yb<<3)|0;Wb=wrc(c[Pb>>2]|0,c[Pb+4>>2]|0,1,0)|0;c[Pb>>2]=Wb;c[Pb+4>>2]=G;pd=ac;qd=Yb}else{pd=Bb+(Kc<<5)+21|0;qd=Mc>>>31}Vda(F,pd,qd);Qc=dc;Rc=Qb;Sc=Xb;break}Yb=(jc|0)>0;if(Yb){if(xa){ac=0;do{ac=ac+1|0;Pb=Bb+(Kc<<5)+ac|0;Wb=g+592+(d[Pb]<<4)+8|0;Ab=wrc(c[Wb>>2]|0,c[Wb+4>>2]|0,1,0)|0;c[Wb>>2]=Ab;c[Wb+4>>2]=G;Wb=fc+(Kc<<9)+(ac<<4)+8|0;Ab=wrc(c[Wb>>2]|0,c[Wb+4>>2]|0,1,0)|0;c[Wb>>2]=Ab;c[Wb+4>>2]=G;Vda(F,Pb,1);}while((ac|0)<(jc|0))}else{ac=0;do{ac=ac+1|0;Vda(F,Bb+(Kc<<5)+ac|0,1);}while((ac|0)<(jc|0))}rd=jc+1|0}else{rd=1}ac=Bb+(Kc<<5)+rd|0;if(xa){Pb=g+592+(d[ac]<<4)|0;Wb=wrc(c[Pb>>2]|0,c[Pb+4>>2]|0,1,0)|0;c[Pb>>2]=Wb;c[Pb+4>>2]=G;Pb=fc+(Kc<<9)+(rd<<4)|0;Wb=wrc(c[Pb>>2]|0,c[Pb+4>>2]|0,1,0)|0;c[Pb>>2]=Wb;c[Pb+4>>2]=G}Vda(F,ac,0);ac=jc-1|0;if(Yb){if(xa){Pb=jc;Wb=ac;while(1){Ab=ic>>>(Wb>>>0)&1;cd=Pb+21|0;mc=Bb+(Kc<<5)+cd|0;hc=g+592+(d[mc]<<4)+(Ab<<3)|0;fd=wrc(c[hc>>2]|0,c[hc+4>>2]|0,1,0)|0;c[hc>>2]=fd;c[hc+4>>2]=G;hc=fc+(Kc<<9)+(cd<<4)+(Ab<<3)|0;cd=wrc(c[hc>>2]|0,c[hc+4>>2]|0,1,0)|0;c[hc>>2]=cd;c[hc+4>>2]=G;Vda(F,mc,Ab);if((Wb|0)>0){Pb=Wb;Wb=Wb-1|0}else{break}}}else{Wb=jc;Pb=ac;while(1){Vda(F,Wb+21+(Bb+(Kc<<5))|0,ic>>>(Pb>>>0)&1);if((Pb|0)>0){Wb=Pb;Pb=Pb-1|0}else{break}}}}if(xa){Pb=Mc>>>31;Wb=jc+11|0;ic=Bb+(Kc<<5)+Wb|0;ac=g+592+(d[ic]<<4)+(Pb<<3)|0;Yb=wrc(c[ac>>2]|0,c[ac+4>>2]|0,1,0)|0;c[ac>>2]=Yb;c[ac+4>>2]=G;ac=fc+(Kc<<9)+(Wb<<4)+(Pb<<3)|0;Wb=wrc(c[ac>>2]|0,c[ac+4>>2]|0,1,0)|0;c[ac>>2]=Wb;c[ac+4>>2]=G;sd=ic;td=Pb}else{sd=jc+11+(Bb+(Kc<<5))|0;td=Mc>>>31}Vda(F,sd,td);Qc=dc;Rc=Qb;Sc=Xb}}while(0);if(($b|0)<(t|0)){Db=$b;Xb=Sc;Qb=Rc;dc=Qc}else{break}}if((Qc|0)==0){ud=Sc;break}dc=1<<d[1359920+Sc|0];if((Rc|0)<(dc|0)){vd=Sc;wd=Rc}else{Qb=Sc;Xb=Rc;Db=dc;dc=c[ka>>2]|0;Cb=c[ya>>2]|0;while(1){ub=Xb-Db|0;hb=Qb+1|0;if((Cb|0)>1){xd=Cb-1|0;yd=dc<<1|1}else{wb=je(1>>>((1-Cb|0)>>>0)|dc<<Cb|0)|0;sb=c[Aa>>2]|0;y=wb;a[sb]=y;y=y>>8;a[sb+1|0]=y;y=y>>8;a[sb+2|0]=y;y=y>>8;a[sb+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;xd=Cb+31|0;yd=1}c[ka>>2]=yd;c[ya>>2]=xd;sb=1<<d[1359920+hb|0];if((ub|0)<(sb|0)){vd=hb;wd=ub;break}else{Qb=hb;Xb=ub;Db=sb;dc=yd;Cb=xd}}}if((wd|0)==0){ud=vd;break}Cb=c[ka>>2]|0;dc=c[ya>>2]|0;if((dc|0)>1){zd=dc-1|0;Ad=Cb<<1|1}else{Db=je(1>>>((1-dc|0)>>>0)|Cb<<dc|0)|0;Cb=c[Aa>>2]|0;y=Db;a[Cb]=y;y=y>>8;a[Cb+1|0]=y;y=y>>8;a[Cb+2|0]=y;y=y>>8;a[Cb+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;zd=dc+31|0;Ad=1}c[ka>>2]=Ad;c[ya>>2]=zd;ud=vd}else{ud=yb}}while(0);c[f>>2]=ud}}while(0);if((bb|0)<((c[q>>2]|0)+3|0)){gb=bb}else{break}}}gb=ma+1|0;if((gb|0)<(v|0)){ma=gb;ab=rb}else{$a=0;Ua=314;break a}}if((Ua|0)==61){Ua=0;KIb(c[p>>2]|0,16,2590384,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;_a=-1094995529;break}else if((Ua|0)==63){Ua=0;KIb(c[p>>2]|0,16,2590384,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;_a=-1094995529;break}else if((Ua|0)==179){Ua=0;KIb(c[p>>2]|0,16,2590384,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;_a=-1094995529;break}else if((Ua|0)==181){Ua=0;KIb(c[p>>2]|0,16,2590384,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;_a=-1094995529;break}}}while(0);if((c[V>>2]|0)!=0){Ua=309;break}if((c[C>>2]|0)<4){Ua=312;break}if((c[Ha>>2]|0)==0){Ua=312;break}KIb(fa,48,2617864,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;c[V>>2]=1;nrc(E|0,H|0,540)|0}if((Ua|0)==25){KIb(0,0,2248568,(Bd=i,i=i+24|0,c[Bd>>2]=2568728,c[Bd+8>>2]=2174216,c[Bd+16>>2]=993,Bd)|0);i=Bd;Hd();return 0}else if((Ua|0)==309){KIb(0,0,2248568,(Bd=i,i=i+24|0,c[Bd>>2]=2122848,c[Bd+8>>2]=2174216,c[Bd+16>>2]=1154,Bd)|0);i=Bd;Hd();return 0}else if((Ua|0)==312){KIb(fa,16,2640576,(Bd=i,i=i+1|0,i=i+7&-8,c[Bd>>2]=0,Bd)|0);i=Bd;$a=_a;i=h;return $a|0}else if((Ua|0)==314){i=h;return $a|0}return 0}function Xda(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0;m=i;i=i+32|0;n=m|0;o=m+8|0;p=m+16|0;q=f+4|0;r=(c[(c[q>>2]|0)+572>>2]|0)!=0?3:2;s=f+38484|0;c[s>>2]=0;t=f+38492|0;u=h+6|0;mrc(c[t>>2]|0,0,ca(u<<1,r)|0)|0;if((j|0)<=0){v=0;i=m;return v|0}w=p+4|0;x=p|0;z=h-1|0;A=f+38512|0;B=f+38516|0;C=f+8|0;D=f+4796|0;E=f+584|0;F=f+576|0;H=f+572|0;I=f+580|0;J=h<<2;K=f+40828|0;L=(h|0)>0;M=f+4804+(l*2580|0)+1790|0;N=f+4804+(l*2580|0)+2572|0;O=f+568|0;P=f+4752|0;Q=f+4804+(l*2580|0)+2568|0;R=f+592|0;S=f+4804+(l*2580|0)+2560|0;T=(R|0)==0;U=(R|0)!=0;R=p+8|0;V=f+544|0;W=f+540|0;X=h*35|0;Y=0;a:while(1){Z=c[t>>2]|0;_=j-Y|0;$=0;do{c[p+($<<2)>>2]=Z+((ca((_+$|0)%(r|0)|0,u)|0)+3<<1);$=$+1|0;}while(($|0)<(r|0));$=c[w>>2]|0;_=c[x>>2]|0;b[_-2>>1]=b[$>>1]|0;b[$+(h<<1)>>1]=b[$+(z<<1)>>1]|0;Z=c[A>>2]|0;b:do{if((Z|0)<9){if(L){aa=ca(Y,k)|0;ba=0;do{b[_+(ba<<1)>>1]=d[g+(ba+aa)|0]|0;ba=ba+1|0;}while((ba|0)<(h|0))}ba=c[s>>2]|0;if((c[D>>2]|0)==0){aa=c[F>>2]|0;if(((c[E>>2]|0)-aa-(32-(c[H>>2]|0)+((c[I>>2]|0)-aa<<3)>>3)|0)<(J|0)){da=13;break a}}else{if(((c[V>>2]|0)-(c[W>>2]|0)|0)<(X|0)){da=11;break a}}if((c[K>>2]|0)==1){if(L){ea=0}else{break}while(1){aa=b[_+(ea<<1)>>1]|0;a[o]=-128;Vda(C,o,aa>>>7&1);a[o]=-128;Vda(C,o,aa>>>6&1);a[o]=-128;Vda(C,o,aa>>>5&1);a[o]=-128;Vda(C,o,aa>>>4&1);a[o]=-128;Vda(C,o,aa>>>3&1);a[o]=-128;Vda(C,o,aa>>>2&1);a[o]=-128;Vda(C,o,aa>>>1&1);a[o]=-128;Vda(C,o,aa&1);ea=ea+1|0;if((ea|0)>=(h|0)){break b}}}do{if(L){aa=c[R>>2]|0;fa=0;ga=ba;ha=0;ia=0;while(1){ja=fa+1|0;ka=fa-1|0;la=b[$+(ka<<1)>>1]|0;ma=b[$+(fa<<1)>>1]|0;na=b[$+(ja<<1)>>1]|0;oa=b[_+(ka<<1)>>1]|0;if((b[M>>1]|0)==0){pa=(b[f+4804+(l*2580|0)+512+((la-ma&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+((oa-la&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1024+((ma-na&255)<<1)>>1]|0)|0}else{pa=(b[f+4804+(l*2580|0)+512+((la-ma&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+((oa-la&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1024+((ma-na&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1536+(((e[_+(fa-2<<1)>>1]|0)-oa&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+2048+(((e[aa+(fa<<1)>>1]|0)-ma&255)<<1)>>1]|0)|0}na=b[_+(fa<<1)>>1]|0;ka=ma-la+oa|0;do{if((oa|0)>(ka|0)){if((ma|0)<=(ka|0)){qa=ka;break}qa=(ma|0)>(oa|0)?oa:ma}else{if((ka|0)<=(ma|0)){qa=ka;break}qa=(ma|0)>(oa|0)?ma:oa}}while(0);oa=na-qa|0;if((pa|0)<0){ra=-pa|0;sa=-oa|0}else{ra=pa;sa=oa}oa=sa<<24;ma=oa>>24;do{if((c[D>>2]|0)==0){ka=(ra|0)==0?1:ia;if((ka|0)==0){ta=ma;ua=ha;va=ga}else{if((ma|0)==0){wa=ka;xa=ha+1|0;ya=ga;break}ka=d[1359920+ga|0]|0;la=1<<ka;za=c[O>>2]|0;Aa=c[H>>2]|0;if((ha|0)<(la|0)){Ba=ga;Ca=ha;Da=ka;Ea=za;Fa=Aa}else{ka=ga;Ga=ha;Ha=la;la=za;za=Aa;while(1){Aa=Ga-Ha|0;Ia=ka+1|0;if((za|0)>1){Ja=za-1|0;Ka=la<<1|1}else{La=je(1>>>((1-za|0)>>>0)|la<<za|0)|0;Ma=c[I>>2]|0;y=La;a[Ma]=y;y=y>>8;a[Ma+1|0]=y;y=y>>8;a[Ma+2|0]=y;y=y>>8;a[Ma+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Ja=za+31|0;Ka=1}c[O>>2]=Ka;c[H>>2]=Ja;Ma=d[1359920+Ia|0]|0;La=1<<Ma;if((Aa|0)<(La|0)){Ba=Ia;Ca=Aa;Da=Ma;Ea=Ka;Fa=Ja;break}else{ka=Ia;Ga=Aa;Ha=La;la=Ka;za=Ja}}}za=Da+1|0;if((Fa|0)>(za|0)){Na=Fa-za|0;Oa=Ea<<za|Ca}else{la=je(Ca>>>((za-Fa|0)>>>0)|Ea<<Fa|0)|0;za=c[I>>2]|0;y=la;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Na=Fa+31-Da|0;Oa=Ca}c[O>>2]=Oa;c[H>>2]=Na;ta=(((oa|0)>0)<<31>>31)+ma|0;ua=0;va=(Ba|0)==0?0:Ba-1|0}za=c[N>>2]|0;la=za+(ra*6|0)+4|0;Ha=ta-(d[la]|0)<<24;Ga=Ha>>24;ka=za+(ra*6|0)+5|0;La=d[ka]|0;Aa=za+(ra*6|0)+2|0;Ia=e[Aa>>1]|0;if(La>>>0<Ia>>>0){Ma=La;Pa=0;while(1){Qa=Pa+1|0;Ra=Ma<<1;if((Ra|0)<(Ia|0)){Ma=Ra;Pa=Qa}else{Sa=Qa;break}}}else{Sa=0}Pa=za+(ra*6|0)|0;Ma=(((b[Pa>>1]<<1)+La>>31^Ga)*-2|0)-1|0;Ia=Ma>>31^Ma;Ma=Ia>>Sa;do{if((Ma|0)<12){Qa=Ma+Sa|0;Ra=Qa+1|0;Ta=1<<Sa;Ua=(Ia&Ta-1)+Ta|0;Ta=c[O>>2]|0;Va=c[H>>2]|0;if((Va|0)>(Ra|0)){Wa=Va-Ra|0;Xa=Ta<<Ra|Ua;break}else{Ya=je(Ua>>>((Ra-Va|0)>>>0)|Ta<<Va|0)|0;Ta=c[I>>2]|0;y=Ya;a[Ta]=y;y=y>>8;a[Ta+1|0]=y;y=y>>8;a[Ta+2|0]=y;y=y>>8;a[Ta+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Wa=31-Qa+Va|0;Xa=Ua;break}}else{Ua=Ia-11|0;Va=c[O>>2]|0;Qa=c[H>>2]|0;if((Qa|0)>20){Wa=Qa-20|0;Xa=Va<<20|Ua;break}else{Ta=je(Ua>>>((20-Qa|0)>>>0)|Va<<Qa|0)|0;Va=c[I>>2]|0;y=Ta;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Wa=Qa+12|0;Xa=Ua;break}}}while(0);c[O>>2]=Xa;c[H>>2]=Wa;Ia=a[ka]|0;Ma=Ia&255;La=(e[Aa>>1]|0)+((Ha|0)>-16777216?Ga:-Ga|0)|0;za=(b[Pa>>1]|0)+Ga|0;if(Ia<<24>>24==-128){Za=Ma>>>1;_a=za>>1;$a=La>>>1&32767}else{Za=Ma;_a=za;$a=La&65535}b[Aa>>1]=$a;La=Za+1|0;za=~Za;do{if((_a|0)>(za|0)){if((_a|0)<=0){ab=_a&65535;break}Ma=a[la]|0;if(!(Ma<<24>>24==127)){a[la]=Ma+1}Ma=_a-La|0;ab=(Ma|0)>0?0:Ma&65535}else{Ma=a[la]|0;if(!(Ma<<24>>24==-128)){a[la]=Ma-1}Ma=La+_a|0;if((Ma|0)>(za|0)){ab=Ma&65535;break}ab=-Za&65535}}while(0);b[Pa>>1]=ab;a[ka]=La;wa=0;xa=ua;ya=va}else{za=c[Q>>2]|0;la=za+(ra<<5)|0;if((c[P>>2]&512|0)==0){if((ma|0)==0){Vda(C,la,1);wa=ia;xa=ha;ya=ga;break}Aa=(oa|0)>-16777216?ma:-ma|0;Ga=Aa>>>0>65535>>>0;Ha=Ga?Aa>>>16:Aa;Ma=Ga?16:0;if((Ha&65280|0)==0){bb=Ma;cb=Ha}else{bb=Ma|8;cb=Ha>>>8}Ha=(d[1359664+cb|0]|0)+bb|0;Vda(C,la,0);if((Ha|0)>=10){Ma=0;while(1){Ga=Ma+1|0;Vda(C,((Ma|0)>9?10:Ga)+(za+(ra<<5))|0,1);if((Ga|0)<(Ha|0)){Ma=Ga}else{break}}Vda(C,za+(ra<<5)+10|0,0);Ma=Ha;while(1){La=Ma-1|0;Vda(C,((La|0)>9?31:Ma+21|0)+(za+(ra<<5))|0,Aa>>>(La>>>0)&1);if((La|0)>0){Ma=La}else{break}}Vda(C,za+(ra<<5)+21|0,ma>>>31);wa=ia;xa=ha;ya=ga;break}if((Ha|0)>0){Ma=0;do{Ma=Ma+1|0;Vda(C,za+(ra<<5)+Ma|0,1);}while((Ma|0)<(Ha|0));Vda(C,Ha+1+(za+(ra<<5))|0,0);Ma=Ha;while(1){La=Ma-1|0;Vda(C,Ma+21+(za+(ra<<5))|0,Aa>>>(La>>>0)&1);if((La|0)>0){Ma=La}else{break}}}else{Vda(C,za+(ra<<5)+1|0,0)}Vda(C,Ha+11+(za+(ra<<5))|0,ma>>>31);wa=ia;xa=ha;ya=ga;break}Ma=c[f+4688+(c[S>>2]<<2)>>2]|0;if((ma|0)==0){if(!T){Aa=f+592+(d[la]<<4)+8|0;La=wrc(c[Aa>>2]|0,c[Aa+4>>2]|0,1,0)|0;c[Aa>>2]=La;c[Aa+4>>2]=G;Aa=Ma+(ra<<9)+8|0;La=wrc(c[Aa>>2]|0,c[Aa+4>>2]|0,1,0)|0;c[Aa>>2]=La;c[Aa+4>>2]=G}Vda(C,la,1);wa=ia;xa=ha;ya=ga;break}Aa=(oa|0)>-16777216?ma:-ma|0;La=Aa>>>0>65535>>>0;ka=La?Aa>>>16:Aa;Pa=La?16:0;if((ka&65280|0)==0){db=Pa;eb=ka}else{db=Pa|8;eb=ka>>>8}ka=(d[1359664+eb|0]|0)+db|0;if(U){Pa=f+592+(d[la]<<4)|0;La=wrc(c[Pa>>2]|0,c[Pa+4>>2]|0,1,0)|0;c[Pa>>2]=La;c[Pa+4>>2]=G;Pa=Ma+(ra<<9)|0;La=wrc(c[Pa>>2]|0,c[Pa+4>>2]|0,1,0)|0;c[Pa>>2]=La;c[Pa+4>>2]=G}Vda(C,la,0);if((ka|0)>=10){Pa=0;while(1){if(U){La=Pa+1|0;Ga=(Pa|0)>9?10:La;Ia=f+592+(d[za+(ra<<5)+Ga|0]<<4)+8|0;Ua=wrc(c[Ia>>2]|0,c[Ia+4>>2]|0,1,0)|0;c[Ia>>2]=Ua;c[Ia+4>>2]=G;Ia=Ma+(ra<<9)+(Ga<<4)+8|0;Ga=wrc(c[Ia>>2]|0,c[Ia+4>>2]|0,1,0)|0;c[Ia>>2]=Ga;c[Ia+4>>2]=G;fb=La}else{fb=Pa+1|0}Vda(C,((Pa|0)>9?10:fb)+(za+(ra<<5))|0,1);if((fb|0)<(ka|0)){Pa=fb}else{break}}Pa=za+(ra<<5)+10|0;if(U){la=f+592+(d[Pa]<<4)|0;Ha=wrc(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=Ha;c[la+4>>2]=G;la=Ma+(ra<<9)+160|0;Ha=wrc(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=Ha;c[la+4>>2]=G;Vda(C,Pa,0);la=ka;while(1){Ha=la-1|0;La=Aa>>>(Ha>>>0)&1;Ia=(Ha|0)>9?31:la+21|0;Ga=za+(ra<<5)+Ia|0;Ua=f+592+(d[Ga]<<4)+(La<<3)|0;Qa=wrc(c[Ua>>2]|0,c[Ua+4>>2]|0,1,0)|0;c[Ua>>2]=Qa;c[Ua+4>>2]=G;Ua=Ma+(ra<<9)+(Ia<<4)+(La<<3)|0;Ia=wrc(c[Ua>>2]|0,c[Ua+4>>2]|0,1,0)|0;c[Ua>>2]=Ia;c[Ua+4>>2]=G;Vda(C,Ga,La);if((Ha|0)>0){la=Ha}else{break}}}else{Vda(C,Pa,0);la=ka;while(1){Ha=la-1|0;Vda(C,((Ha|0)>9?31:la+21|0)+(za+(ra<<5))|0,Aa>>>(Ha>>>0)&1);if((Ha|0)>0){la=Ha}else{break}}}if(U){la=ma>>>31;Pa=za+(ra<<5)+21|0;Ha=f+592+(d[Pa]<<4)+(la<<3)|0;La=wrc(c[Ha>>2]|0,c[Ha+4>>2]|0,1,0)|0;c[Ha>>2]=La;c[Ha+4>>2]=G;Ha=Ma+(ra<<9)+336+(la<<3)|0;La=wrc(c[Ha>>2]|0,c[Ha+4>>2]|0,1,0)|0;c[Ha>>2]=La;c[Ha+4>>2]=G;gb=Pa;hb=la}else{gb=za+(ra<<5)+21|0;hb=ma>>>31}Vda(C,gb,hb);wa=ia;xa=ha;ya=ga;break}la=(ka|0)>0;if(la){if(U){Pa=0;do{Pa=Pa+1|0;Ha=za+(ra<<5)+Pa|0;La=f+592+(d[Ha]<<4)+8|0;Ga=wrc(c[La>>2]|0,c[La+4>>2]|0,1,0)|0;c[La>>2]=Ga;c[La+4>>2]=G;La=Ma+(ra<<9)+(Pa<<4)+8|0;Ga=wrc(c[La>>2]|0,c[La+4>>2]|0,1,0)|0;c[La>>2]=Ga;c[La+4>>2]=G;Vda(C,Ha,1);}while((Pa|0)<(ka|0))}else{Pa=0;do{Pa=Pa+1|0;Vda(C,za+(ra<<5)+Pa|0,1);}while((Pa|0)<(ka|0))}ib=ka+1|0}else{ib=1}Pa=za+(ra<<5)+ib|0;if(U){Ha=f+592+(d[Pa]<<4)|0;La=wrc(c[Ha>>2]|0,c[Ha+4>>2]|0,1,0)|0;c[Ha>>2]=La;c[Ha+4>>2]=G;Ha=Ma+(ra<<9)+(ib<<4)|0;La=wrc(c[Ha>>2]|0,c[Ha+4>>2]|0,1,0)|0;c[Ha>>2]=La;c[Ha+4>>2]=G}Vda(C,Pa,0);Pa=ka-1|0;if(la){if(U){Ha=ka;La=Pa;while(1){Ga=Aa>>>(La>>>0)&1;Ua=Ha+21|0;Ia=za+(ra<<5)+Ua|0;Qa=f+592+(d[Ia]<<4)+(Ga<<3)|0;Va=wrc(c[Qa>>2]|0,c[Qa+4>>2]|0,1,0)|0;c[Qa>>2]=Va;c[Qa+4>>2]=G;Qa=Ma+(ra<<9)+(Ua<<4)+(Ga<<3)|0;Ua=wrc(c[Qa>>2]|0,c[Qa+4>>2]|0,1,0)|0;c[Qa>>2]=Ua;c[Qa+4>>2]=G;Vda(C,Ia,Ga);if((La|0)>0){Ha=La;La=La-1|0}else{break}}}else{La=ka;Ha=Pa;while(1){Vda(C,La+21+(za+(ra<<5))|0,Aa>>>(Ha>>>0)&1);if((Ha|0)>0){La=Ha;Ha=Ha-1|0}else{break}}}}if(U){Ha=ma>>>31;La=ka+11|0;Aa=za+(ra<<5)+La|0;Pa=f+592+(d[Aa]<<4)+(Ha<<3)|0;la=wrc(c[Pa>>2]|0,c[Pa+4>>2]|0,1,0)|0;c[Pa>>2]=la;c[Pa+4>>2]=G;Pa=Ma+(ra<<9)+(La<<4)+(Ha<<3)|0;La=wrc(c[Pa>>2]|0,c[Pa+4>>2]|0,1,0)|0;c[Pa>>2]=La;c[Pa+4>>2]=G;jb=Aa;kb=Ha}else{jb=ka+11+(za+(ra<<5))|0;kb=ma>>>31}Vda(C,jb,kb);wa=ia;xa=ha;ya=ga}}while(0);if((ja|0)<(h|0)){fa=ja;ga=ya;ha=xa;ia=wa}else{break}}if((wa|0)==0){lb=ya;break}ia=1<<d[1359920+ya|0];if((xa|0)<(ia|0)){mb=ya;nb=xa}else{ha=ya;ga=xa;fa=ia;ia=c[O>>2]|0;aa=c[H>>2]|0;while(1){ma=ga-fa|0;oa=ha+1|0;if((aa|0)>1){ob=aa-1|0;pb=ia<<1|1}else{na=je(1>>>((1-aa|0)>>>0)|ia<<aa|0)|0;Ha=c[I>>2]|0;y=na;a[Ha]=y;y=y>>8;a[Ha+1|0]=y;y=y>>8;a[Ha+2|0]=y;y=y>>8;a[Ha+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;ob=aa+31|0;pb=1}c[O>>2]=pb;c[H>>2]=ob;Ha=1<<d[1359920+oa|0];if((ma|0)<(Ha|0)){mb=oa;nb=ma;break}else{ha=oa;ga=ma;fa=Ha;ia=pb;aa=ob}}}if((nb|0)==0){lb=mb;break}aa=c[O>>2]|0;ia=c[H>>2]|0;if((ia|0)>1){qb=ia-1|0;rb=aa<<1|1}else{fa=je(1>>>((1-ia|0)>>>0)|aa<<ia|0)|0;aa=c[I>>2]|0;y=fa;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;qb=ia+31|0;rb=1}c[O>>2]=rb;c[H>>2]=qb;lb=mb}else{lb=ba}}while(0);c[s>>2]=lb}else{do{if((c[B>>2]|0)==0){if(!L){break}ba=g+(ca(Y,k)|0)|0;ia=16-Z|0;aa=0;do{b[_+(aa<<1)>>1]=(e[ba+(aa<<1)>>1]|0)>>>(ia>>>0);aa=aa+1|0;}while((aa|0)<(h|0))}else{if(!L){break}aa=g+(ca(Y,k)|0)|0;ia=0;do{b[_+(ia<<1)>>1]=b[aa+(ia<<1)>>1]|0;ia=ia+1|0;}while((ia|0)<(h|0))}}while(0);ia=c[s>>2]|0;if((c[D>>2]|0)==0){aa=c[F>>2]|0;if(((c[E>>2]|0)-aa-(32-(c[H>>2]|0)+((c[I>>2]|0)-aa<<3)>>3)|0)<(J|0)){da=141;break a}}else{if(((c[V>>2]|0)-(c[W>>2]|0)|0)<(X|0)){da=139;break a}}if((c[K>>2]|0)==1){if(!L){break}aa=(Z|0)>0;ba=0;while(1){fa=b[_+(ba<<1)>>1]|0;if(aa){ga=Z;do{ga=ga-1|0;a[n]=-128;Vda(C,n,fa>>>(ga>>>0)&1);}while((ga|0)>0)}ba=ba+1|0;if((ba|0)>=(h|0)){break b}}}do{if(L){ba=(Z|0)==8;aa=Z+12|0;ga=20-Z|0;fa=1<<Z-1;ha=(1<<Z)-1|0;Ha=c[R>>2]|0;ma=0;oa=ia;na=0;Aa=0;while(1){Pa=ma+1|0;La=ma-1|0;la=b[$+(La<<1)>>1]|0;Ga=b[$+(ma<<1)>>1]|0;Ia=b[$+(Pa<<1)>>1]|0;Qa=b[_+(La<<1)>>1]|0;if((b[M>>1]|0)==0){sb=(b[f+4804+(l*2580|0)+512+((la-Ga&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+((Qa-la&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1024+((Ga-Ia&255)<<1)>>1]|0)|0}else{sb=(b[f+4804+(l*2580|0)+512+((la-Ga&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+((Qa-la&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1024+((Ga-Ia&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+1536+(((e[_+(ma-2<<1)>>1]|0)-Qa&255)<<1)>>1]|0)+(b[f+4804+(l*2580|0)+2048+(((e[Ha+(ma<<1)>>1]|0)-Ga&255)<<1)>>1]|0)|0}Ia=b[_+(ma<<1)>>1]|0;La=Ga-la+Qa|0;do{if((Qa|0)>(La|0)){if((Ga|0)<=(La|0)){tb=La;break}tb=(Ga|0)>(Qa|0)?Qa:Ga}else{if((La|0)<=(Ga|0)){tb=La;break}tb=(Ga|0)>(Qa|0)?Ga:Qa}}while(0);Qa=Ia-tb|0;if((sb|0)<0){ub=-sb|0;vb=-Qa|0}else{ub=sb;vb=Qa}if(ba){wb=vb<<24>>24}else{wb=(vb+fa&ha)-fa|0}do{if((c[D>>2]|0)==0){Qa=(ub|0)==0?1:Aa;if((Qa|0)==0){xb=wb;yb=na;zb=oa}else{if((wb|0)==0){Ab=Qa;Bb=na+1|0;Cb=oa;break}Qa=d[1359920+oa|0]|0;Ga=1<<Qa;La=c[O>>2]|0;ja=c[H>>2]|0;if((na|0)<(Ga|0)){Db=oa;Eb=na;Fb=Qa;Gb=La;Hb=ja}else{Qa=oa;la=na;Ua=Ga;Ga=La;La=ja;while(1){ja=la-Ua|0;Va=Qa+1|0;if((La|0)>1){Ib=La-1|0;Jb=Ga<<1|1}else{Ta=je(1>>>((1-La|0)>>>0)|Ga<<La|0)|0;Ya=c[I>>2]|0;y=Ta;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Ib=La+31|0;Jb=1}c[O>>2]=Jb;c[H>>2]=Ib;Ya=d[1359920+Va|0]|0;Ta=1<<Ya;if((ja|0)<(Ta|0)){Db=Va;Eb=ja;Fb=Ya;Gb=Jb;Hb=Ib;break}else{Qa=Va;la=ja;Ua=Ta;Ga=Jb;La=Ib}}}La=Fb+1|0;if((Hb|0)>(La|0)){Kb=Hb-La|0;Lb=Gb<<La|Eb}else{Ga=je(Eb>>>((La-Hb|0)>>>0)|Gb<<Hb|0)|0;La=c[I>>2]|0;y=Ga;a[La]=y;y=y>>8;a[La+1|0]=y;y=y>>8;a[La+2|0]=y;y=y>>8;a[La+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Kb=Hb+31-Fb|0;Lb=Eb}c[O>>2]=Lb;c[H>>2]=Kb;xb=(((wb|0)>0)<<31>>31)+wb|0;yb=0;zb=(Db|0)==0?0:Db-1|0}La=c[N>>2]|0;Ga=La+(ub*6|0)+4|0;Ua=xb-(a[Ga]|0)|0;if(ba){Mb=Ua<<24>>24}else{Mb=(Ua+fa&ha)-fa|0}Ua=La+(ub*6|0)+5|0;la=d[Ua]|0;Qa=La+(ub*6|0)+2|0;za=e[Qa>>1]|0;if(la>>>0<za>>>0){ka=la;Ma=0;while(1){Ta=Ma+1|0;ja=ka<<1;if((ja|0)<(za|0)){ka=ja;Ma=Ta}else{Nb=Ta;break}}}else{Nb=0}Ma=La+(ub*6|0)|0;ka=(((b[Ma>>1]<<1)+la>>31^Mb)*-2|0)-1|0;za=ka>>31^ka;ka=za>>Nb;do{if((ka|0)<12){Ta=ka+Nb|0;ja=Ta+1|0;Va=1<<Nb;Ya=(za&Va-1)+Va|0;Va=c[O>>2]|0;Ra=c[H>>2]|0;if((Ra|0)>(ja|0)){Ob=Ra-ja|0;Pb=Va<<ja|Ya;break}else{Qb=je(Ya>>>((ja-Ra|0)>>>0)|Va<<Ra|0)|0;Va=c[I>>2]|0;y=Qb;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Ob=31-Ta+Ra|0;Pb=Ya;break}}else{Ya=za-11|0;Ra=c[O>>2]|0;Ta=c[H>>2]|0;if((Ta|0)>(aa|0)){Ob=Ta-aa|0;Pb=Ra<<aa|Ya;break}else{Va=je(Ya>>>((aa-Ta|0)>>>0)|Ra<<Ta|0)|0;Ra=c[I>>2]|0;y=Va;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Ob=ga+Ta|0;Pb=Ya;break}}}while(0);c[O>>2]=Pb;c[H>>2]=Ob;za=a[Ua]|0;ka=za&255;la=(e[Qa>>1]|0)+((Mb|0)>-1?Mb:-Mb|0)|0;La=(b[Ma>>1]|0)+Mb|0;if(za<<24>>24==-128){Rb=ka>>>1;Sb=La>>1;Tb=la>>>1&32767}else{Rb=ka;Sb=La;Tb=la&65535}b[Qa>>1]=Tb;la=Rb+1|0;La=~Rb;do{if((Sb|0)>(La|0)){if((Sb|0)<=0){Ub=Sb&65535;break}ka=a[Ga]|0;if(!(ka<<24>>24==127)){a[Ga]=ka+1}ka=Sb-la|0;Ub=(ka|0)>0?0:ka&65535}else{ka=a[Ga]|0;if(!(ka<<24>>24==-128)){a[Ga]=ka-1}ka=la+Sb|0;if((ka|0)>(La|0)){Ub=ka&65535;break}Ub=-Rb&65535}}while(0);b[Ma>>1]=Ub;a[Ua]=la;Ab=0;Bb=yb;Cb=zb}else{La=c[Q>>2]|0;Ga=La+(ub<<5)|0;if((c[P>>2]&512|0)==0){if((wb|0)==0){Vda(C,Ga,1);Ab=Aa;Bb=na;Cb=oa;break}Qa=(wb|0)>-1?wb:-wb|0;ka=Qa>>>0>65535>>>0;za=ka?Qa>>>16:Qa;Ya=ka?16:0;if((za&65280|0)==0){Vb=Ya;Wb=za}else{Vb=Ya|8;Wb=za>>>8}za=(d[1359664+Wb|0]|0)+Vb|0;Vda(C,Ga,0);if((za|0)>=10){Ya=0;while(1){ka=Ya+1|0;Vda(C,((Ya|0)>9?10:ka)+(La+(ub<<5))|0,1);if((ka|0)<(za|0)){Ya=ka}else{break}}Vda(C,La+(ub<<5)+10|0,0);Ya=za;while(1){la=Ya-1|0;Vda(C,((la|0)>9?31:Ya+21|0)+(La+(ub<<5))|0,Qa>>>(la>>>0)&1);if((la|0)>0){Ya=la}else{break}}Vda(C,La+(ub<<5)+21|0,wb>>>31);Ab=Aa;Bb=na;Cb=oa;break}if((za|0)>0){Ya=0;do{Ya=Ya+1|0;Vda(C,La+(ub<<5)+Ya|0,1);}while((Ya|0)<(za|0));Vda(C,za+1+(La+(ub<<5))|0,0);Ya=za;while(1){la=Ya-1|0;Vda(C,Ya+21+(La+(ub<<5))|0,Qa>>>(la>>>0)&1);if((la|0)>0){Ya=la}else{break}}}else{Vda(C,La+(ub<<5)+1|0,0)}Vda(C,za+11+(La+(ub<<5))|0,wb>>>31);Ab=Aa;Bb=na;Cb=oa;break}Ya=c[f+4688+(c[S>>2]<<2)>>2]|0;if((wb|0)==0){Qa=f+592+(d[Ga]<<4)+8|0;la=wrc(c[Qa>>2]|0,c[Qa+4>>2]|0,1,0)|0;c[Qa>>2]=la;c[Qa+4>>2]=G;Qa=Ya+(ub<<9)+8|0;la=wrc(c[Qa>>2]|0,c[Qa+4>>2]|0,1,0)|0;c[Qa>>2]=la;c[Qa+4>>2]=G;Vda(C,Ga,1);Ab=Aa;Bb=na;Cb=oa;break}Qa=(wb|0)>-1?wb:-wb|0;la=Qa>>>0>65535>>>0;Ua=la?Qa>>>16:Qa;Ma=la?16:0;if((Ua&65280|0)==0){Xb=Ma;Yb=Ua}else{Xb=Ma|8;Yb=Ua>>>8}Ua=(d[1359664+Yb|0]|0)+Xb|0;if(U){Ma=f+592+(d[Ga]<<4)|0;la=wrc(c[Ma>>2]|0,c[Ma+4>>2]|0,1,0)|0;c[Ma>>2]=la;c[Ma+4>>2]=G;Ma=Ya+(ub<<9)|0;la=wrc(c[Ma>>2]|0,c[Ma+4>>2]|0,1,0)|0;c[Ma>>2]=la;c[Ma+4>>2]=G}Vda(C,Ga,0);if((Ua|0)>=10){Ma=0;while(1){if(U){la=Ma+1|0;ka=(Ma|0)>9?10:la;Ta=f+592+(d[La+(ub<<5)+ka|0]<<4)+8|0;Ra=wrc(c[Ta>>2]|0,c[Ta+4>>2]|0,1,0)|0;c[Ta>>2]=Ra;c[Ta+4>>2]=G;Ta=Ya+(ub<<9)+(ka<<4)+8|0;ka=wrc(c[Ta>>2]|0,c[Ta+4>>2]|0,1,0)|0;c[Ta>>2]=ka;c[Ta+4>>2]=G;Zb=la}else{Zb=Ma+1|0}Vda(C,((Ma|0)>9?10:Zb)+(La+(ub<<5))|0,1);if((Zb|0)<(Ua|0)){Ma=Zb}else{break}}Ma=La+(ub<<5)+10|0;if(U){Ga=f+592+(d[Ma]<<4)|0;za=wrc(c[Ga>>2]|0,c[Ga+4>>2]|0,1,0)|0;c[Ga>>2]=za;c[Ga+4>>2]=G;Ga=Ya+(ub<<9)+160|0;za=wrc(c[Ga>>2]|0,c[Ga+4>>2]|0,1,0)|0;c[Ga>>2]=za;c[Ga+4>>2]=G;Vda(C,Ma,0);Ga=Ua;while(1){za=Ga-1|0;la=Qa>>>(za>>>0)&1;Ta=(za|0)>9?31:Ga+21|0;ka=La+(ub<<5)+Ta|0;Ra=f+592+(d[ka]<<4)+(la<<3)|0;Va=wrc(c[Ra>>2]|0,c[Ra+4>>2]|0,1,0)|0;c[Ra>>2]=Va;c[Ra+4>>2]=G;Ra=Ya+(ub<<9)+(Ta<<4)+(la<<3)|0;Ta=wrc(c[Ra>>2]|0,c[Ra+4>>2]|0,1,0)|0;c[Ra>>2]=Ta;c[Ra+4>>2]=G;Vda(C,ka,la);if((za|0)>0){Ga=za}else{break}}}else{Vda(C,Ma,0);Ga=Ua;while(1){za=Ga-1|0;Vda(C,((za|0)>9?31:Ga+21|0)+(La+(ub<<5))|0,Qa>>>(za>>>0)&1);if((za|0)>0){Ga=za}else{break}}}if(U){Ga=wb>>>31;Ma=La+(ub<<5)+21|0;za=f+592+(d[Ma]<<4)+(Ga<<3)|0;la=wrc(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=la;c[za+4>>2]=G;za=Ya+(ub<<9)+336+(Ga<<3)|0;la=wrc(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=la;c[za+4>>2]=G;_b=Ma;$b=Ga}else{_b=La+(ub<<5)+21|0;$b=wb>>>31}Vda(C,_b,$b);Ab=Aa;Bb=na;Cb=oa;break}Ga=(Ua|0)>0;if(Ga){if(U){Ma=0;do{Ma=Ma+1|0;za=La+(ub<<5)+Ma|0;la=f+592+(d[za]<<4)+8|0;ka=wrc(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=ka;c[la+4>>2]=G;la=Ya+(ub<<9)+(Ma<<4)+8|0;ka=wrc(c[la>>2]|0,c[la+4>>2]|0,1,0)|0;c[la>>2]=ka;c[la+4>>2]=G;Vda(C,za,1);}while((Ma|0)<(Ua|0))}else{Ma=0;do{Ma=Ma+1|0;Vda(C,La+(ub<<5)+Ma|0,1);}while((Ma|0)<(Ua|0))}ac=Ua+1|0}else{ac=1}Ma=La+(ub<<5)+ac|0;if(U){za=f+592+(d[Ma]<<4)|0;la=wrc(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=la;c[za+4>>2]=G;za=Ya+(ub<<9)+(ac<<4)|0;la=wrc(c[za>>2]|0,c[za+4>>2]|0,1,0)|0;c[za>>2]=la;c[za+4>>2]=G}Vda(C,Ma,0);Ma=Ua-1|0;if(Ga){if(U){za=Ua;la=Ma;while(1){ka=Qa>>>(la>>>0)&1;Ra=za+21|0;Ta=La+(ub<<5)+Ra|0;Va=f+592+(d[Ta]<<4)+(ka<<3)|0;Qb=wrc(c[Va>>2]|0,c[Va+4>>2]|0,1,0)|0;c[Va>>2]=Qb;c[Va+4>>2]=G;Va=Ya+(ub<<9)+(Ra<<4)+(ka<<3)|0;Ra=wrc(c[Va>>2]|0,c[Va+4>>2]|0,1,0)|0;c[Va>>2]=Ra;c[Va+4>>2]=G;Vda(C,Ta,ka);if((la|0)>0){za=la;la=la-1|0}else{break}}}else{la=Ua;za=Ma;while(1){Vda(C,la+21+(La+(ub<<5))|0,Qa>>>(za>>>0)&1);if((za|0)>0){la=za;za=za-1|0}else{break}}}}if(U){za=wb>>>31;la=Ua+11|0;Qa=La+(ub<<5)+la|0;Ma=f+592+(d[Qa]<<4)+(za<<3)|0;Ga=wrc(c[Ma>>2]|0,c[Ma+4>>2]|0,1,0)|0;c[Ma>>2]=Ga;c[Ma+4>>2]=G;Ma=Ya+(ub<<9)+(la<<4)+(za<<3)|0;la=wrc(c[Ma>>2]|0,c[Ma+4>>2]|0,1,0)|0;c[Ma>>2]=la;c[Ma+4>>2]=G;bc=Qa;cc=za}else{bc=Ua+11+(La+(ub<<5))|0;cc=wb>>>31}Vda(C,bc,cc);Ab=Aa;Bb=na;Cb=oa}}while(0);if((Pa|0)<(h|0)){ma=Pa;oa=Cb;na=Bb;Aa=Ab}else{break}}if((Ab|0)==0){dc=Cb;break}Aa=1<<d[1359920+Cb|0];if((Bb|0)<(Aa|0)){ec=Cb;fc=Bb}else{na=Cb;oa=Bb;ma=Aa;Aa=c[O>>2]|0;ga=c[H>>2]|0;while(1){aa=oa-ma|0;fa=na+1|0;if((ga|0)>1){gc=ga-1|0;hc=Aa<<1|1}else{ha=je(1>>>((1-ga|0)>>>0)|Aa<<ga|0)|0;ba=c[I>>2]|0;y=ha;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;gc=ga+31|0;hc=1}c[O>>2]=hc;c[H>>2]=gc;ba=1<<d[1359920+fa|0];if((aa|0)<(ba|0)){ec=fa;fc=aa;break}else{na=fa;oa=aa;ma=ba;Aa=hc;ga=gc}}}if((fc|0)==0){dc=ec;break}ga=c[O>>2]|0;Aa=c[H>>2]|0;if((Aa|0)>1){ic=Aa-1|0;jc=ga<<1|1}else{ma=je(1>>>((1-Aa|0)>>>0)|ga<<Aa|0)|0;ga=c[I>>2]|0;y=ma;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;ic=Aa+31|0;jc=1}c[O>>2]=jc;c[H>>2]=ic;dc=ec}else{dc=ia}}while(0);c[s>>2]=dc}}while(0);_=Y+1|0;if((_|0)<(j|0)){Y=_}else{v=0;da=266;break}}if((da|0)==11){KIb(c[q>>2]|0,16,2590384,(kc=i,i=i+1|0,i=i+7&-8,c[kc>>2]=0,kc)|0);i=kc;v=-1094995529;i=m;return v|0}else if((da|0)==13){KIb(c[q>>2]|0,16,2590384,(kc=i,i=i+1|0,i=i+7&-8,c[kc>>2]=0,kc)|0);i=kc;v=-1094995529;i=m;return v|0}else if((da|0)==139){KIb(c[q>>2]|0,16,2590384,(kc=i,i=i+1|0,i=i+7&-8,c[kc>>2]=0,kc)|0);i=kc;v=-1094995529;i=m;return v|0}else if((da|0)==141){KIb(c[q>>2]|0,16,2590384,(kc=i,i=i+1|0,i=i+7&-8,c[kc>>2]=0,kc)|0);i=kc;v=-1094995529;i=m;return v|0}else if((da|0)==266){i=m;return v|0}return 0}function Yda(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((c|0)==0){Vda(a,b,1);return}f=(c|0)>-1?c:-c|0;g=f>>>0>65535>>>0;h=g?f>>>16:f;i=g?16:0;if((h&65280|0)==0){j=i;k=h}else{j=i|8;k=h>>>8}h=(d[1359664+k|0]|0)+j|0;Vda(a,b,0);if((h|0)>=10){j=0;while(1){k=j+1|0;Vda(a,b+((j|0)>9?10:k)|0,1);if((k|0)<(h|0)){j=k}else{break}}Vda(a,b+10|0,0);j=h;while(1){k=j-1|0;Vda(a,b+((k|0)>9?31:j+21|0)|0,f>>>(k>>>0)&1);if((k|0)>0){j=k}else{break}}if((e|0)==0){return}Vda(a,b+21|0,c>>>31);return}if((h|0)>0){j=0;do{j=j+1|0;Vda(a,b+j|0,1);}while((j|0)<(h|0));Vda(a,b+(h+1)|0,0);j=h;while(1){k=j-1|0;Vda(a,b+(j+21)|0,f>>>(k>>>0)&1);if((k|0)>0){j=k}else{break}}}else{Vda(a,b+1|0,0)}if((e|0)==0){return}Vda(a,b+(h+11)|0,c>>>31);return}function Zda(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+32|0;e=d|0;mrc(e|0,-128|0,32)|0;f=0;g=1;h=-1;while(1){if((b[c+(g<<1)>>1]|0)==(b[c+(g-1<<1)>>1]|0)){j=f}else{Yda(a,e,g+h|0,0);j=g}k=g+1|0;if((k|0)>=128){break}f=j;g=k;h=~j}Yda(a,e,127-j|0,0);mrc(e|0,-128|0,32)|0;j=0;h=1;g=-1;while(1){if((b[c+512+(h<<1)>>1]|0)==(b[c+512+(h-1<<1)>>1]|0)){l=j}else{Yda(a,e,h+g|0,0);l=h}f=h+1|0;if((f|0)>=128){break}j=l;h=f;g=~l}Yda(a,e,127-l|0,0);mrc(e|0,-128|0,32)|0;l=0;g=1;h=-1;while(1){if((b[c+1024+(g<<1)>>1]|0)==(b[c+1024+(g-1<<1)>>1]|0)){m=l}else{Yda(a,e,g+h|0,0);m=g}j=g+1|0;if((j|0)>=128){break}l=m;g=j;h=~m}Yda(a,e,127-m|0,0);mrc(e|0,-128|0,32)|0;m=0;h=1;g=-1;while(1){if((b[c+1536+(h<<1)>>1]|0)==(b[c+1536+(h-1<<1)>>1]|0)){n=m}else{Yda(a,e,h+g|0,0);n=h}l=h+1|0;if((l|0)>=128){break}m=n;h=l;g=~n}Yda(a,e,127-n|0,0);mrc(e|0,-128|0,32)|0;n=0;g=1;h=-1;while(1){if((b[c+2048+(g<<1)>>1]|0)==(b[c+2048+(g-1<<1)>>1]|0)){o=n}else{Yda(a,e,g+h|0,0);o=g}m=g+1|0;if((m|0)>=128){break}n=o;g=m;h=~o}Yda(a,e,127-o|0,0);i=d;return}function _da(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;b=i;e=c[a+60>>2]|0;f=e;if((c[a+416>>2]|0)>32){KIb(a,16,2454040,(g=i,i=i+8|0,c[g>>2]=32,g)|0);i=g;h=-22;i=b;return h|0}j=c[a+100>>2]|0;a:do{if((j|0)<4){k=-22;l=34}else{m=c[a+96>>2]|0;n=m+j|0;o=m;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+552|0;c[o>>2]=p;if((p|0)<0){k=-22;l=34;break}q=m+4|0;m=qJb(p,96)|0;p=m;r=e+20|0;c[r>>2]=p;if((m|0)==0){k=-12;l=34;break}if((c[o>>2]|0)>0){m=n;s=a+412|0;t=q;u=-2147483648;v=0;w=0;while(1){if((m-t|0)<24){k=-22;l=34;break a}x=t;y=x|0;z=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=x+4|0;x=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=p+(w*96|0)|0;c[y>>2]=z;c[y+4>>2]=x;y=t+8|0;A=y|0;B=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;A=y+4|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;A=p+(w*96|0)+8|0;c[A>>2]=B;c[A+4>>2]=y;A=t+16|0;C=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;c[p+(w*96|0)+84>>2]=C;A=t+20|0;c[p+(w*96|0)+80>>2]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=t+24|0;if(!((x|0)>=(u|0)&((x|0)>(u|0)|z>>>0>=v>>>0)&((y|0)>(x|0)|(y|0)==(x|0)&B>>>0>z>>>0))){k=-22;l=34;break a}D=xrc(B,y,z,x)|0;y=G;do{if((C|0)==1397313358){if((m-A|0)<8){k=-22;l=34;break a}B=A;E=t+28|0;F=t+32|0;H=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;I=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0}else if((C|0)==1162758483){if((m-A|0)<20){k=-22;l=34;break a}E=A;B=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=t+28|0;J=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=t+32|0;K=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=t+36|0;L=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=t+40|0;M=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=t+44|0;N=B;O=(B|0)<0|0?-1:0;B=c[s>>2]|0;P=B;R=P<<16|0>>>16;S=((B|0)<0|0?-1:0)<<16|P>>>16;P=1;do{if(S>>>0<P>>>0|S>>>0==P>>>0&R>>>0<0>>>0){B=0;T=N;U=Frc(B,T,R,S)|0;W=Grc(B,T,R,S)|0;T=Frc(0,W,R,S)|0;W=T|0;T=G|U;U=J;(J|0)<0|0?-1:0;B=0;X=U;U=Frc(B,X,R,S)|0;Y=Grc(B,X,R,S)|0;X=Frc(0,Y,R,S)|0;Z=G|U;_=X|0;$=T;aa=W}else{W=65536;if(S>>>0<W>>>0|S>>>0==W>>>0&R>>>0<0>>>0){W=N<<16|0>>>16;T=O<<16|N>>>16;X=Frc(W,T,R,S)|0;U=G;Y=Grc(W,T,R,S)|0;T=Y<<16|0>>>16;W=G<<16|Y>>>16;Y=Frc(T,W,R,S)|0;B=Y|(X<<16|0>>>16);Y=G|(U<<16|X>>>16);X=Grc(T,W,R,S)|0;W=X<<16|0>>>16;T=G<<16|X>>>16;X=Frc(W,T,R,S)|0;U=X|(B<<16|0>>>16);X=G|(Y<<16|B>>>16);B=Grc(W,T,R,S)|0;T=Frc(B<<16|0>>>16,G<<16|B>>>16,R,S)|0;B=G|(X<<16|U>>>16);X=J;W=X<<16|0>>>16;Y=((J|0)<0|0?-1:0)<<16|X>>>16;X=Frc(W,Y,R,S)|0;ba=G;ca=Grc(W,Y,R,S)|0;Y=ca<<16|0>>>16;W=G<<16|ca>>>16;ca=Frc(Y,W,R,S)|0;da=ca|(X<<16|0>>>16);ca=G|(ba<<16|X>>>16);X=Grc(Y,W,R,S)|0;W=X<<16|0>>>16;Y=G<<16|X>>>16;X=Frc(W,Y,R,S)|0;ba=X|(da<<16|0>>>16);X=G|(ca<<16|da>>>16);da=Grc(W,Y,R,S)|0;Y=Frc(da<<16|0>>>16,G<<16|da>>>16,R,S)|0;Z=G|(X<<16|ba>>>16);_=Y|(ba<<16|0>>>16);$=B;aa=T|(U<<16|0>>>16);break}else{ea=O;fa=N;ga=0;ha=0;ia=63}while(1){U=-1;T=fa<<1|0>>>31;B=ea<<1|fa>>>31;if(((ea|0)>(U|0)|(ea|0)==(U|0)&fa>>>0>-1>>>0)&(B>>>0<S>>>0|B>>>0==S>>>0&T>>>0<R>>>0)){ja=ga;ka=ha;la=B;ma=T}else{U=yrc(1,0,ia|0)|0;ba=G|ga;Y=xrc(T,B,R,S)|0;ja=ba;ka=U|ha;la=G;ma=Y}if((ia|0)>0){ea=la;fa=ma;ga=ja;ha=ka;ia=ia-1|0}else{break}}Y=(J|0)<0|0?-1:0;U=J;ba=0;B=0;T=63;while(1){X=-1;da=U<<1|0>>>31;W=Y<<1|U>>>31;if(((Y|0)>(X|0)|(Y|0)==(X|0)&U>>>0>-1>>>0)&(W>>>0<S>>>0|W>>>0==S>>>0&da>>>0<R>>>0)){na=ba;oa=B;pa=W;qa=da}else{X=yrc(1,0,T|0)|0;ca=G|ba;ra=xrc(da,W,R,S)|0;na=ca;oa=X|B;pa=G;qa=ra}if((T|0)>0){Y=pa;U=qa;ba=na;B=oa;T=T-1|0}else{Z=na;_=oa;$=ja;aa=ka;break}}}}while(0);S=p+(w*96|0)+24|0;c[S>>2]=aa;c[S+4>>2]=$;S=xrc(_,Z,aa,$)|0;R=Crc(S,G,D,y)|0;S=p+(w*96|0)+32|0;c[S>>2]=R;c[S+4>>2]=G;if((M|0)>=0){S=p+(w*96|0)+16|0;c[S>>2]=0<<1|0>>>31;c[S+4>>2]=M<<1|0>>>31;F=E;H=K;I=L;break}S=M&2147483647;if(!(S>>>0<w>>>0)){k=-22;l=34;break a}R=p+(S*96|0)|0;J=xrc(z,x,c[R>>2]|0,c[R+4>>2]|0)|0;R=G;if((J&1|0)==0&(R&0|0)==0){N=wrc(J,R,-1,-1)|0;O=Erc(J>>>1|R<<31,R>>>1|0<<31,N,G)|0;sa=G;ta=O}else{O=wrc(J,R,-1,-1)|0;N=G;P=Erc(O>>>1|N<<31,N>>>1|0<<31,J,R)|0;sa=G;ta=P}P=p+(S*96|0)+16|0;N=c[P>>2]|0;O=c[P+4>>2]|0;P=p+(S*96|0)+24|0;T=Erc(c[P>>2]|0,c[P+4>>2]|0,J,R)|0;R=wrc(T,G,N,O)|0;O=G;N=p+(S*96|0)+32|0;S=Erc(c[N>>2]|0,c[N+4>>2]|0,ta,sa)|0;N=wrc(R,O,S,G)|0;S=p+(w*96|0)+16|0;c[S>>2]=N;c[S+4>>2]=G;F=E;H=K;I=L}else{k=-22;l=34;break a}}while(0);A=0;C=H;S=p+(w*96|0)+40|0;c[S>>2]=A;c[S+4>>2]=C;S=xrc(0,I,A,C)|0;C=Crc(S,G,D,y)|0;S=p+(w*96|0)+48|0;c[S>>2]=C;c[S+4>>2]=G;S=w+1|0;if((S|0)<(c[o>>2]|0)){t=F;u=x;v=z;w=S}else{ua=F;break}}}else{ua=q}w=(ua|0)==(n|0);if(!w){k=w?0:-22;l=34;break}w=hJb(65536)|0;v=w;u=e+16|0;c[u>>2]=v;if((w|0)==0){va=-12;wa=r;xa=u;break}else{ya=0}do{c[v+(ya<<2)>>2]=~~+Q(+V(+(ya|0)*6.283185307179586*6103515625.0e-14)*32767.0);ya=ya+1|0;}while((ya|0)<16384);c[e+24>>2]=1213483332;v=c[o>>2]|0;if((v|0)>0){n=c[r>>2]|0;q=e+544|0;u=0;w=c[q>>2]|0;do{w=((c[n+(u*96|0)+84>>2]|0)==1397313358)+w|0;u=u+1|0;}while((u|0)<(v|0));c[q>>2]=w}c[e+28>>2]=1263421776;c[e+548>>2]=128;bea(f,0,0);c[a+420>>2]=1;h=0;i=b;return h|0}}while(0);if((l|0)==34){KIb(a,16,2364736,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;va=k;wa=e+20|0;xa=e+16|0}kJb(c[wa>>2]|0);kJb(c[xa>>2]|0);h=va;i=b;return h|0}function $da(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;h=i;i=i+128|0;j=h|0;k=c[a+60>>2]|0;l=k;c[f>>2]=0;m=g+28|0;if((c[m>>2]|0)!=12){n=-1094995529;i=h;return n|0}o=g+24|0;g=c[o>>2]|0;p=g;q=p|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k;if((r|0)==(c[q>>2]|0)&(p|0)==(c[q+4>>2]|0)){s=g}else{bea(l,r,p);s=c[o>>2]|0}o=s+8|0;s=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;if((s|0)<1){n=-22;i=h;return n|0}c[e+76>>2]=s;o=M4a(a,e,0)|0;if((o|0)<0){n=o;i=h;return n|0}o=j;g=a+416|0;a=k+8|0;t=j|0;u=k+556|0;v=k+548|0;w=k+20|0;x=k+16|0;y=k+24|0;z=k+560|0;A=k+552|0;k=p;p=r;r=1;B=c[e>>2]|0;e=c[g>>2]|0;while(1){mrc(o|0,0,e<<2|0)|0;C=c[a+4>>2]|0;if(!((k|0)<(C|0)|(k|0)==(C|0)&p>>>0<(c[a>>2]|0)>>>0)){C=c[u>>2]|0;if((C|0)>-1){D=c[w>>2]|0;E=C;while(1){C=D+(E*96|0)+88|0;F=c[C>>2]|0;if((F|0)>-1){E=F}else{H=C;break}}}else{H=u}E=c[z>>2]|0;D=c[A>>2]|0;a:do{if((E|0)<(D|0)){C=c[w>>2]|0;F=E;I=H;J=D;while(1){K=C+(F*96|0)|0;L=c[K+4>>2]|0;if((L|0)>(k|0)|(L|0)==(k|0)&(c[K>>2]|0)>>>0>p>>>0){M=F;N=I;O=J;break a}K=C+(F*96|0)+8|0;L=c[K+4>>2]|0;if((L|0)>(k|0)|(L|0)==(k|0)&(c[K>>2]|0)>>>0>p>>>0){c[I>>2]=F;K=C+(F*96|0)+16|0;L=c[K+4>>2]|0;P=C+(F*96|0)+56|0;c[P>>2]=c[K>>2];c[P+4>>2]=L;L=C+(F*96|0)+24|0;P=c[L+4>>2]|0;K=C+(F*96|0)+64|0;c[K>>2]=c[L>>2];c[K+4>>2]=P;P=C+(F*96|0)+40|0;K=c[P+4>>2]|0;L=C+(F*96|0)+72|0;c[L>>2]=c[P>>2];c[L+4>>2]=K;Q=C+(F*96|0)+88|0;R=c[A>>2]|0}else{Q=I;R=J}K=F+1|0;if((K|0)<(R|0)){F=K;I=Q;J=R}else{M=K;N=Q;O=R;break}}}else{M=E;N=H;O=D}}while(0);c[z>>2]=M;if((M|0)<(O|0)){D=(c[w>>2]|0)+(M*96|0)|0;S=c[D+4>>2]|0;T=c[D>>2]|0}else{S=2147483647;T=-1}c[a>>2]=T;c[a+4>>2]=S;c[N>>2]=-1}D=c[u>>2]|0;E=c[v>>2]|0;if((E|0)==128){cea(l);U=c[v>>2]|0}else{U=E}c[v>>2]=U+1;E=c[l+32+(U<<2)>>2]>>16;do{if((D|0)>-1){J=c[w>>2]|0;I=D;F=u;C=0;b:while(1){K=I;while(1){V=J+(K*96|0)+88|0;W=c[V>>2]|0;L=J+(K*96|0)+8|0;P=c[L+4>>2]|0;if((P|0)>(k|0)|(P|0)==(k|0)&(c[L>>2]|0)>>>0>p>>>0){break}c[F>>2]=W;if((W|0)>-1){K=W}else{X=C;break b}}L=J+(K*96|0)+72|0;P=c[L+4>>2]|0;Y=P;Z=J+(K*96|0)+48|0;_=wrc(c[Z>>2]|0,c[Z+4>>2]|0,c[L>>2]|0,P)|0;c[L>>2]=_;c[L+4>>2]=G;L=c[J+(K*96|0)+84>>2]|0;if((L|0)==1397313358){$=ca(Y,E)|0}else if((L|0)==1162758483){L=J+(K*96|0)+56|0;_=c[L+4>>2]|0;P=ca(c[(c[x>>2]|0)+((_>>>18|0<<14)<<2)>>2]|0,Y)|0;Y=J+(K*96|0)+64|0;Z=c[Y>>2]|0;aa=c[Y+4>>2]|0;ba=wrc(Z,aa,c[L>>2]|0,_)|0;c[L>>2]=ba;c[L+4>>2]=G;L=J+(K*96|0)+32|0;ba=wrc(c[L>>2]|0,c[L+4>>2]|0,Z,aa)|0;c[Y>>2]=ba;c[Y+4>>2]=G;$=P}else{$=0}P=c[J+(K*96|0)+80>>2]|0;Y=P|C;if((P|0)!=0){ba=t;aa=P;while(1){if((aa&1|0)!=0){c[ba>>2]=(c[ba>>2]|0)+$}P=aa>>>1;if((P|0)==0){break}else{ba=ba+4|0;aa=P}}}if((W|0)>-1){I=W;F=V;C=Y}else{X=Y;break}}C=(ca(c[y>>2]|0,1284865837)|0)-144211633|0;c[y>>2]=C;F=C>>16;if((X|0)==0){break}else{da=t;ea=X}while(1){if((ea&1|0)!=0){c[da>>2]=(c[da>>2]|0)+F}C=ea>>>1;if((C|0)==0){break}else{da=da+4|0;ea=C}}}else{c[y>>2]=(ca(c[y>>2]|0,1284865837)|0)-144211633}}while(0);E=c[g>>2]|0;if((E|0)>0){D=(E|0)>1?E:1;F=0;C=B;while(1){b[C>>1]=(c[j+(F<<2)>>2]|0)>>>16;I=F+1|0;if((I|0)<(E|0)){F=I;C=C+2|0}else{break}}fa=B+(D<<1)|0}else{fa=B}if((r|0)>=(s|0)){break}C=wrc(p,k,1,0)|0;k=G;p=C;r=r+1|0;B=fa;e=E}e=wrc(c[q>>2]|0,c[q+4>>2]|0,s,(s|0)<0|0?-1:0)|0;c[q>>2]=e;c[q+4>>2]=G;c[f>>2]=1;n=c[m>>2]|0;i=h;return n|0}function aea(a){a=a|0;var b=0;b=c[a+60>>2]|0;kJb(c[b+16>>2]|0);kJb(c[b+20>>2]|0);return 0}function bea(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;e=a+556|0;f=a+552|0;g=c[f>>2]|0;a:do{if((g|0)>0){h=c[a+20>>2]|0;i=0;j=e;k=g;while(1){l=h+(i*96|0)|0;m=c[l>>2]|0;n=c[l+4>>2]|0;if((n|0)>(d|0)|(n|0)==(d|0)&m>>>0>b>>>0){o=i;p=j;q=k;break a}l=h+(i*96|0)+8|0;r=c[l+4>>2]|0;if((r|0)>(d|0)|(r|0)==(d|0)&(c[l>>2]|0)>>>0>b>>>0){c[j>>2]=i;l=xrc(b,d,m,n)|0;n=G;if((l&1|0)==0&(n&0|0)==0){m=wrc(l,n,-1,-1)|0;r=Erc(l>>>1|n<<31,n>>>1|0<<31,m,G)|0;s=G;t=r}else{r=wrc(l,n,-1,-1)|0;m=G;u=Erc(r>>>1|m<<31,m>>>1|0<<31,l,n)|0;s=G;t=u}u=h+(i*96|0)+16|0;m=c[u>>2]|0;r=c[u+4>>2]|0;u=h+(i*96|0)+24|0;v=c[u>>2]|0;w=c[u+4>>2]|0;u=Erc(v,w,l,n)|0;x=wrc(u,G,m,r)|0;r=G;m=h+(i*96|0)+32|0;u=c[m>>2]|0;y=c[m+4>>2]|0;m=Erc(u,y,t,s)|0;z=wrc(x,r,m,G)|0;m=h+(i*96|0)+56|0;c[m>>2]=z;c[m+4>>2]=G;m=Erc(l,n,u,y)|0;y=wrc(m,G,v,w)|0;w=h+(i*96|0)+64|0;c[w>>2]=y;c[w+4>>2]=G;w=h+(i*96|0)+40|0;y=c[w>>2]|0;v=c[w+4>>2]|0;w=h+(i*96|0)+48|0;m=Erc(l,n,c[w>>2]|0,c[w+4>>2]|0)|0;w=wrc(m,G,y,v)|0;v=h+(i*96|0)+72|0;c[v>>2]=w;c[v+4>>2]=G;A=h+(i*96|0)+88|0;B=c[f>>2]|0}else{A=j;B=k}v=i+1|0;if((v|0)<(B|0)){i=v;j=A;k=B}else{o=v;p=A;q=B;break}}}else{o=0;p=e;q=g}}while(0);c[a+560>>2]=o;if((o|0)<(q|0)){q=(c[a+20>>2]|0)+(o*96|0)|0;C=c[q+4>>2]|0;D=c[q>>2]|0}else{C=2147483647;D=-1}q=a+8|0;c[q>>2]=D;c[q+4>>2]=C;c[p>>2]=-1;p=a+24|0;C=a|0;q=c[C>>2]|0;D=c[C+4>>2]|0;o=xrc(b,d,q,D)|0;g=G;e=c[p>>2]|0;B=-1;A=(g|0)>(B|0)|(g|0)==(B|0)&o>>>0>-1>>>0;B=xrc(0,0,o,g)|0;f=A?o:B;B=A?g:G;if((f|0)==0&(B|0)==0){E=e}else{g=B;B=f;f=A?1284865837:849225893;o=A?-144211633:-559108117;A=e;while(1){if((B&1|0)==0&(g&0|0)==0){F=A}else{F=(ca(f,A)|0)+o|0}e=ca(f+1|0,o)|0;s=ca(f,f)|0;t=B>>>1|g<<31;k=g>>1|((g|0)<0|0?-1:0)<<31;if((t|0)==0&(k|0)==0){E=F;break}else{g=k;B=t;f=s;o=e;A=F}}}c[p>>2]=E;if((c[a+544>>2]|0)==0){H=C|0;c[H>>2]=b;I=C+4|0;c[I>>2]=d;return}E=wrc(q,D,127,0)|0;D=b&127;q=a+28|0;p=xrc(b&-128,d&2147483647,E&-128,G&2147483647)|0;E=p<<1|0>>>31;F=G<<1|p>>>31;p=c[q>>2]|0;A=-1;o=(F|0)>(A|0)|(F|0)==(A|0)&E>>>0>-1>>>0;A=xrc(0,0,E,F)|0;f=o?E:A;A=o?F:G;if((f|0)==0&(A|0)==0){J=p}else{F=A;A=f;f=o?1284865837:849225893;E=o?-144211633:-559108117;o=p;while(1){if((A&1|0)==0&(F&0|0)==0){K=o}else{K=(ca(f,o)|0)+E|0}p=ca(f+1|0,E)|0;B=ca(f,f)|0;g=A>>>1|F<<31;e=F>>1|((F|0)<0|0?-1:0)<<31;if((g|0)==0&(e|0)==0){J=K;break}else{F=e;A=g;f=B;E=p;o=K}}}c[q>>2]=J;if((D|0)==0){c[a+548>>2]=128;H=C|0;c[H>>2]=b;I=C+4|0;c[I>>2]=d;return}else{cea(a);c[a+548>>2]=D;H=C|0;c[H>>2]=b;I=C+4|0;c[I>>2]=d;return}}function cea(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;c[a+548>>2]=0;if((c[a+544>>2]|0)==0){return}b=a+28|0;d=0;e=0;f=0;g=0;h=0;i=0;j=0;k=0;l=0;while(1){do{if((e&1|0)==0){m=(ca(c[b>>2]|0,1284865837)|0)-144211633|0;c[b>>2]=m;n=m>>3;o=d-f+n|0;if((e&2|0)!=0){p=o;q=n;r=g;s=h;t=i;u=j;v=k;w=l;x=m;break}y=(ca(m,1284865837)|0)-144211633|0;c[b>>2]=y;m=y>>3;z=o-g+m|0;if((e&4|0)!=0){p=z;q=n;r=m;s=h;t=i;u=j;v=k;w=l;x=y;break}o=(ca(y,1284865837)|0)-144211633|0;c[b>>2]=o;y=o>>3;A=z-h+y|0;if((e&8|0)!=0){p=A;q=n;r=m;s=y;t=i;u=j;v=k;w=l;x=o;break}z=(ca(o,1284865837)|0)-144211633|0;c[b>>2]=z;o=z>>3;B=A-i+o|0;if((e&16|0)!=0){p=B;q=n;r=m;s=y;t=o;u=j;v=k;w=l;x=z;break}A=(ca(z,1284865837)|0)-144211633|0;c[b>>2]=A;z=A>>3;C=B-j+z|0;if((e&32|0)!=0){p=C;q=n;r=m;s=y;t=o;u=z;v=k;w=l;x=A;break}B=(ca(A,1284865837)|0)-144211633|0;c[b>>2]=B;A=B>>3;D=C-k+A|0;if((e&64|0)!=0){p=D;q=n;r=m;s=y;t=o;u=z;v=A;w=l;x=B;break}C=(ca(B,1284865837)|0)-144211633|0;c[b>>2]=C;B=C>>3;p=D-l+B|0;q=n;r=m;s=y;t=o;u=z;v=A;w=B;x=C}else{p=d;q=f;r=g;s=h;t=i;u=j;v=k;w=l;x=c[b>>2]|0}}while(0);C=(ca(x,1284865837)|0)-144211633|0;c[b>>2]=C;c[a+32+(e<<2)>>2]=(C>>3)+p;C=e+1|0;if((C|0)<128){d=p;e=C;f=q;g=r;h=s;i=t;j=u;k=v;l=w}else{break}}c[b>>2]=(ca(c[b>>2]|0,1284865837)|0)-144211633;return}function dea(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+1400>>2]=(c[a+120>>2]|0)+15&-16;c[b+1404>>2]=(c[a+124>>2]|0)+15&-16;c[a+140>>2]=0;c[a+796>>2]=8;d=UHb()|0;c[b+4>>2]=d;if((d|0)==0){e=-12;return e|0}l8(b+8|0,a);L6(b+1136|0,b+1252|0,1242080);e=0;return e|0}function eea(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;j=c[b+60>>2]|0;k=c[g+24>>2]|0;l=j+4|0;m=N4a(b,c[l>>2]|0)|0;if((m|0)<0){KIb(b,16,2454008,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=m;i=h;return o|0}m=g+28|0;if((c[m>>2]|0)<31){KIb(b,16,2364704,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}if((grc(k,1237984,7)|0)!=0){KIb(b,24,2299552,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}do{if((a[k+17|0]|0)==0){g=a[k+13|0]|0;p=g&255;if(g<<24>>24==0){KIb(b,16,2248544,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}c[j+1392>>2]=(a[k+23|0]|0)!=0?1237920:1237856;g=d[k+25|0]<<8|d[k+24|0]<<16|d[k+26|0];if((g|0)>((c[m>>2]|0)-27|0)){KIb(b,16,2206464,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}q=(c[j+1404>>2]>>4<<4|0)/(p|0)|0;r=j+1412|0;if((q&15|0)==0){s=q}else{s=q-1&-16}c[r>>2]=s;q=g+27|0;t=p<<2;u=q+t|0;v=-27-t-g+(c[m>>2]|0)|0;if((v|0)<1){KIb(b,16,2174176,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}g=c[l>>2]|0;c[g+84>>2]=1;c[g+88>>2]=1;g=j+1384|0;t=g;w=j+1388|0;x=p*144|0;xJb(g,w,x);if((c[w>>2]|0)==0){KIb(b,16,2146608,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=h;return o|0}mrc(c[t>>2]|0,0,x|0)|0;x=p-1|0;w=b+124|0;g=0;do{y=(g<<2)+q|0;z=k+y|0;A=je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0;z=c[r>>2]|0;B=ca(z,g)|0;if((g|0)==(x|0)){C=15-(ca(z,x)|0)+(c[w>>2]|0)&-16;D=v}else{E=k+(y+4)|0;C=z;D=je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0}if(!(D>>>0<A>>>0|D>>>0>v>>>0)){c[(c[t>>2]|0)+(g*144|0)+128>>2]=k+(u+A);E=c[t>>2]|0;c[E+(g*144|0)+136>>2]=D-A;c[E+(g*144|0)+132>>2]=C;c[E+(g*144|0)+140>>2]=B}g=g+1|0;}while((g|0)<(p|0));g=se[c[b+824>>2]&127](b,368,c[t>>2]|0,0,p,144)|0;if((g|0)>=0){break}o=g>>>31;i=h;return o|0}}while(0);c[f>>2]=1;f=YHb(e,c[l>>2]|0)|0;if((f|0)<0){o=f;i=h;return o|0}o=c[m>>2]|0;i=h;return o|0}function fea(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+1384|0);VHb(b+4|0);return 0}function gea(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=c[e+60>>2]|0;e=g;h=c[f+128>>2]|0;i=c[f+132>>2]|0;j=c[f+140>>2]|0;k=c[f+136>>2]<<3;l=k>>>0>2147483639>>>0|(h|0)==0;m=l?0:h;h=l?8:k+8|0;k=g+4|0;l=g+1400|0;n=f;f=g+44|0;o=g+1128|0;p=g+1392|0;g=0;q=0;a:while(1){r=c[k>>2]|0;s=c[r+32+(q<<2)>>2]|0;t=(q|0)!=0|0;u=i>>t;if((u|0)>0){v=ca(s,j>>t)|0;w=s<<3;x=g;y=0;z=(c[r+(q<<2)>>2]|0)+v|0;v=c[l>>2]|0;while(1){if((v>>t|0)>0){r=x;A=0;while(1){B=z+A|0;C=((r|0)<(h|0))+r|0;if((d[m+(r>>>3)|0]&128>>>((r&7)>>>0)|0)==0){qe[c[f>>2]&1023](n);D=m+(C>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7);D=E>>>25;F=C+7|0;G=h>>>0>F>>>0?F:h;if(E>>>0>2181038079>>>0){H=-1094995529;I=19;break a}if((D|0)==0){J=G}else{E=0;F=G;while(1){G=m+(F>>>3)|0;K=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(F&7);if(K>>>0>134217727>>>0){G=K>>>23;L=(d[1382088+G|0]|0)+F|0;M=a[1306768+G|0]|0;N=h>>>0>L>>>0?L:h}else{L=K>>>0>65535>>>0;G=L?K>>>16:K;K=L?16:0;if((G&65280|0)==0){O=K;P=G}else{O=K|8;P=G>>>8}G=(d[1359664+P|0]|0)+O|0;K=31-G+F|0;L=h>>>0>K>>>0?K:h;K=m+(L>>>3)|0;Q=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(L&7)>>>(G>>>0);K=L+(32-G)|0;G=Q>>>1;M=(Q&1|0)==0?G:-G|0;N=h>>>0>K>>>0?K:h}K=(ca(d[(c[p>>2]|0)+E|0]|0,M)|0)&65535;b[n+(d[e+1256+E|0]<<1)>>1]=K;K=E+1|0;if((K|0)<(D|0)){E=K;F=N}else{J=N;break}}}ef[c[o>>2]&4095](B,s,n);R=J}else{F=c[k>>2]|0;c[F+84>>2]=0;c[F+88>>2]=2;R=C}F=A+8|0;E=c[l>>2]|0;if((F|0)<(E>>t|0)){r=R;A=F}else{S=R;T=E;break}}}else{S=x;T=v}A=y+8|0;if((A|0)<(u|0)){x=S;y=A;z=z+w|0;v=T}else{U=S;break}}}else{U=g}v=q+1|0;if((v|0)<3){g=U;q=v}else{H=0;I=19;break}}if((I|0)==19){return H|0}return 0}function hea(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;h=i;j=e+8|0;k=c[j>>2]|0;l=e+16|0;m=c[l>>2]|0;n=e|0;e=c[n>>2]|0;o=e+(k>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(k&7);o=k+15|0;k=m>>>0>o>>>0?o:m;c[j>>2]=k;if(!((p&-131072|0)==-524288)){KIb(b,g+16|0,2555664,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}p=d[e+(k>>>3)|0]<<(k&7)>>>7;c[j>>2]=((k|0)<(m|0))+k;c[f+32>>2]=p&1;p=c[j>>2]|0;k=c[l>>2]|0;m=e+(p>>>3)|0;o=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>28;m=p+4|0;p=k>>>0>m>>>0?m:k;c[j>>2]=p;m=e+(p>>>3)|0;s=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7);m=s>>>28;t=p+4|0;p=k>>>0>t>>>0?t:k;c[j>>2]=p;t=e+(p>>>3)|0;e=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(p&7);t=e>>>28;u=p+4|0;c[j>>2]=k>>>0>u>>>0?u:k;k=f+16|0;c[k>>2]=t;do{if((e|0)>-1){c[f+4>>2]=t+1;v=0}else{if(e>>>0<2952790016>>>0){c[f+4>>2]=2;v=t-7|0;break}KIb(b,g+16|0,2607152,(q=i,i=i+8|0,c[q>>2]=t,q)|0);i=q;r=-1094995529;i=h;return r|0}}while(0);c[k>>2]=v;v=c[j>>2]|0;k=c[l>>2]|0;t=c[n>>2]|0;e=t+(v>>>3)|0;u=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(v&7)>>>29;e=v+3|0;c[j>>2]=k>>>0>e>>>0?e:k;if((u|0)==7|(u|0)==3){KIb(b,g+16|0,2453976,(q=i,i=i+8|0,c[q>>2]=u,q)|0);i=q;r=-1094995529;i=h;return r|0}c[f+8>>2]=a[612072+u|0]|0;u=c[j>>2]|0;k=d[t+(u>>>3)|0]|0;e=c[l>>2]|0;v=((u|0)<(e|0))+u|0;c[j>>2]=v;if((k&128>>>((u&7)>>>0)|0)!=0){KIb(b,g+16|0,2364672,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}u=t+(v>>>3)|0;k=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7);u=k>>>24;p=v+8|0;v=e>>>0>p>>>0?p:e;c[j>>2]=v;p=u;w=0;x=k>>>25&64;a:do{if(!((p&192|0)==128&(w&0|0)==0|k>>>0>4261412863>>>0)){if((x&u|0)==0){y=w;z=p;A=x;B=v}else{C=w;D=p;E=x;F=v;while(1){H=t+(F>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>24;H=F+8|0;J=e>>>0>H>>>0?H:e;c[j>>2]=J;H=I-128|0;if(H>>>0>63>>>0){break a}I=wrc(H,(H|0)<0|0?-1:0,D<<6|0>>>26,C<<6|D>>>26)|0;H=G;K=E<<5;if((I&K|0)==0&(H&0|0)==0){y=H;z=I;A=K;B=J;break}else{C=H;D=I;E=K;F=J}}}F=f+24|0;c[F>>2]=(A<<1)-1&z;c[F+4>>2]=0&y;if((o|0)==0){KIb(b,g+16|0,2248488,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}else if((o|0)==7){F=t+(B>>>3)|0;E=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(B&7)>>>16;F=B+16|0;c[j>>2]=e>>>0>F>>>0?F:e;c[f+12>>2]=E+1}else if((o|0)==6){E=t+(B>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(B&7)>>>24;E=B+8|0;c[j>>2]=e>>>0>E>>>0?E:e;c[f+12>>2]=F+1}else{c[f+12>>2]=c[1389064+(o<<2)>>2]}do{if(s>>>0<3221225472>>>0){c[f>>2]=c[1388536+(m<<2)>>2]}else{if((m|0)==12){F=c[j>>2]|0;E=c[l>>2]|0;D=t+(F>>>3)|0;C=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(F&7)>>>24;D=F+8|0;c[j>>2]=E>>>0>D>>>0?D:E;c[f>>2]=C*1e3|0;break}else if((m|0)==13){C=c[j>>2]|0;E=c[l>>2]|0;D=t+(C>>>3)|0;F=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>>16;D=C+16|0;c[j>>2]=E>>>0>D>>>0?D:E;c[f>>2]=F;break}else if((m|0)==14){F=c[j>>2]|0;E=c[l>>2]|0;D=t+(F>>>3)|0;C=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(F&7)>>>16;D=F+16|0;c[j>>2]=E>>>0>D>>>0?D:E;c[f>>2]=C*10|0;break}else{KIb(b,g+16|0,2206432,(q=i,i=i+8|0,c[q>>2]=m,q)|0);i=q;r=-1094995529;i=h;return r|0}}}while(0);C=c[l>>2]|0;E=(c[j>>2]|0)+8|0;c[j>>2]=C>>>0>E>>>0?E:C;C=DGb(0)|0;if((EGb(C,0,c[n>>2]|0,(c[j>>2]|0)/8|0)|0)==0){r=0;i=h;return r|0}KIb(b,g+16|0,2174152,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}}while(0);j=f+24|0;c[j>>2]=-1;c[j+4>>2]=-1;KIb(b,g+16|0,2299504,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ca((c+14|0)/8|0,b)|0;if((b|0)==2){e=c<<1|1}else{e=ca(c,b)|0}return d+18+(((ca(e,a)|0)+7|0)/8|0)|0}function jea(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=a+96|0;h=c[g>>2]|0;do{if((h|0)!=0){j=c[a+100>>2]|0;if((j|0)<34){break}k=h;do{if((d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)==1130450022){if((j|0)>=42){c[b>>2]=1;l=h+8|0;break}KIb(a,16,2640552,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=f;return n|0}else{if((j|0)==34){o=h}else{KIb(a,24,2122808,(m=i,i=i+8|0,c[m>>2]=34-j,m)|0);i=m;o=c[g>>2]|0}c[b>>2]=0;l=o}}while(0);c[e>>2]=l;n=1;i=f;return n|0}}while(0);KIb(a,16,2146576,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0;i=f;return n|0}function kea(a){a=a|0;var b=0,d=0,e=0;b=c[a+416>>2]|0;if(b>>>0<9>>>0){d=1212856+(b-1<<3)|0;b=c[d+4>>2]|0;e=a+448|0;c[e>>2]=c[d>>2];c[e+4>>2]=b;return}else{b=a+448|0;c[b>>2]=0;c[b+4>>2]=0;return}}function lea(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=(e|0)==0?8:280;h=g>>>0>16>>>0?16:g;j=e+(h>>>3)|0;k=je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;j=k>>>16;l=h+16|0;h=b+12|0;c[h>>2]=j;if(k>>>0<1048576>>>0){KIb(a,24,2617832,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;c[h>>2]=16}h=(g>>>0>l>>>0?l:g)+24|0;l=g>>>0>h>>>0?h:g;h=e+(l>>>3)|0;k=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(l&7)>>>8;h=l+24|0;l=g>>>0>h>>>0?h:g;c[b+16>>2]=k;k=e+(l>>>3)|0;h=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(l&7)>>>12;k=l+20|0;l=g>>>0>k>>>0?k:g;k=b|0;c[k>>2]=h;h=e+(l>>>3)|0;j=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(l&7)>>>29;h=l+3|0;l=g>>>0>h>>>0?h:g;h=j+1|0;c[b+4>>2]=h;m=e+(l>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(l&7)>>>27;m=l+5|0;l=g>>>0>m>>>0?m:g;m=b+8|0;c[m>>2]=n+1;c[a+416>>2]=h;c[a+412>>2]=c[k>>2];c[a+796>>2]=c[m>>2];if(h>>>0<9>>>0){h=1212856+(j<<3)|0;j=c[h+4>>2]|0;m=a+448|0;c[m>>2]=c[h>>2];c[m+4>>2]=j}else{j=a+448|0;c[j>>2]=0;c[j+4>>2]=0}j=e+(l>>>3)|0;a=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(l&7)>>>28;j=l+4|0;l=g>>>0>j>>>0?j:g;j=e+(l>>>3)|0;m=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(l&7)&-65536;j=l+16|0;l=g>>>0>j>>>0?j:g;g=e+(l>>>3)|0;e=b+24|0;c[e>>2]=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(l&7)>>>16|m;c[e+4>>2]=a;i=f;return}function mea(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;g=d[a]|0;if((b|0)!=0){c[b>>2]=g&128}if((e|0)!=0){c[e>>2]=g&127}if((f|0)==0){return}c[f>>2]=(d[a+2|0]|0)<<8|(d[a+1|0]|0)<<16|(d[a+3|0]|0);return}function nea(a){a=a|0;var b=0;b=c[a>>2]|0;c[b>>2]=a;a=dHb(106496)|0;c[b+28>>2]=a;return((a|0)==0?-12:0)|0}function oea(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;j=i;i=i+80|0;k=j|0;l=j+24|0;m=j+64|0;n=c[a>>2]|0;o=n;if((c[a+176>>2]&1|0)!=0){p=(g|0)==0?0:128;c[k>>2]=g;c[k+12>>2]=p;c[k+16>>2]=p|8;c[k+4>>2]=g+(p>>>3);c[k+8>>2]=0;do{if((hea(b,k,l,127)|0)==0){c[a+304>>2]=c[l+12>>2];p=b+412|0;if((c[p>>2]|0)!=0){break}c[p>>2]=c[l>>2]}}while(0);c[e>>2]=g;c[f>>2]=h;q=h;i=j;return q|0}c[n+4>>2]=b;l=n+24|0;if((c[l>>2]|0)!=0){q=qea(o,e,f)|0;i=j;return q|0}k=n+12|0;p=k;r=c[p>>2]|0;do{if((r|0)!=0){s=c[r+60>>2]|0;t=n+8|0;u=c[t>>2]|0;if((s|0)==0){if((u|0)==(r|0)){v=r}else{w=u;while(1){x=c[w+56>>2]|0;mJb(w+4|0);kJb(w);if((x|0)==(c[p>>2]|0)){v=x;break}else{w=x}}}c[t>>2]=c[v+56>>2];mJb(v+4|0);mJb(k);break}a:do{if((u|0)!=(s|0)){w=n+20|0;x=b;y=u;z=r;while(1){if((y|0)==(z|0)){A=y+56|0}else{B=c[y>>2]|0;C=y+56|0;D=c[c[C>>2]>>2]|0;KIb(x,48,2555552,(E=i,i=i+24|0,c[E>>2]=c[y+8>>2],c[E+8>>2]=B,c[E+16>>2]=D,E)|0);i=E;A=C}C=c[A>>2]|0;mJb(y+4|0);kJb(y);c[w>>2]=(c[w>>2]|0)-1;if((C|0)==(s|0)){break a}y=C;z=c[p>>2]|0}}}while(0);u=s|0;kHb(c[n+28>>2]|0,c[u>>2]|0);z=c[s+56>>2]|0;if((z|0)!=0){y=z;do{z=y|0;c[z>>2]=(c[z>>2]|0)-(c[u>>2]|0);y=c[y+56>>2]|0;}while((y|0)!=0)}y=n+20|0;c[y>>2]=(c[y>>2]|0)-1;c[u>>2]=0;c[t>>2]=s;if((c[y>>2]|0)<=9){c[p>>2]=0;break}c[p>>2]=s;q=qea(o,e,f)|0;i=j;return q|0}}while(0);A=(g|0)!=0;r=A^1;k=n+20|0;v=n+32|0;y=n+28|0;z=m|0;m=n+16|0;w=n+8|0;x=h;h=g;b:while(1){C=h+16|0;D=h;B=x;F=h;while(1){G=(B|0)==0;H=G|r;I=g+B|0;do{if(A&(G^1)&F>>>0<I>>>0){J=c[k>>2]|0;if((J|0)>=10){K=29;break}if(H){K=32;break}L=I-F|0;M=(10-J<<13)+8192|0;N=B;O=F+((L|0)>(M|0)?M:L)|0}else{K=29}}while(0);if((K|0)==29){K=0;if(!H){P=0;K=69;break b}if((c[v>>2]|0)==0){K=32}else{P=G;K=69;break b}}if((K|0)==32){K=0;c[v>>2]=1;N=16;O=C}Q=O-D|0;if((gHb(c[y>>2]|0)|0)<(Q|0)){I=c[y>>2]|0;if((hHb(I,((fHb(I)|0)<<1)+Q|0)|0)<0){K=36;break b}}if((N|0)==0|r){mrc(z|0,0,16)|0;jHb(c[y>>2]|0,z,16,0)|0}else{jHb(c[y>>2]|0,h,Q,0)|0}I=-15-Q+(fHb(c[y>>2]|0)|0)|0;L=(I|0)<0?0:I;c[m>>2]=0;I=(fHb(c[y>>2]|0)|0)-15|0;M=I-L+1|0;J=c[y>>2]|0;R=c[J+4>>2]|0;S=R+L|0;T=c[J+12>>2]|0;if(S>>>0<T>>>0){U=S;V=T}else{S=T;U=R+(L-S+(c[J>>2]|0))|0;V=S}S=V-U|0;J=(M|0)>(S|0)?S:M;M=vea(o,U,J,L)|0;S=J-1|0;R=S+L|0;if((R|0)==(I|0)){W=M}else{T=I-R+1|0;I=J+L|0;L=c[y>>2]|0;J=c[L+4>>2]|0;X=J+I|0;Y=c[L+12>>2]|0;if(X>>>0<Y>>>0){Z=X;_=Y}else{X=Y;Z=J+(I-X+(c[L>>2]|0))|0;_=X}X=_-Z|0;if(((he((d[Z]|0)<<8|(d[U+S|0]|0)|0)|0)&-2)<<16>>16==-8){S=wea(o,R)|0;$=(M|0)>(S|0)?M:S}else{$=M}M=vea(o,Z,(T|0)>(X|0)?X:T,I)|0;W=($|0)>(M|0)?$:M}do{if((W|0)==0){M=c[w>>2]|0;if((M|0)==0){aa=0;break}else{ba=0;ca=M}while(1){M=ba+1|0;I=c[ca+56>>2]|0;if((I|0)==0){da=M;K=53;break}else{ba=M;ca=I}}}else{da=W;K=53}}while(0);if((K|0)==53){K=0;if((da|0)<0){K=54;break b}else{aa=da}}c[k>>2]=aa;G=(c[v>>2]|0)==0;if(G&(aa|0)<10){K=56;break}if(G){if((c[m>>2]|0)!=0){K=60}}else{K=60}do{if((K|0)==60){K=0;G=c[w>>2]|0;if((G|0)==0){break}else{ea=G}do{c[ea+8>>2]=-1e5;ea=c[ea+56>>2]|0;}while((ea|0)!=0);G=c[w>>2]|0;if((G|0)==0){break}else{fa=0;ga=G}while(1){if((sea(o,ga)|0)>(fa|0)){c[p>>2]=ga;ha=c[ga+8>>2]|0}else{ha=fa}G=c[ga+56>>2]|0;if((G|0)==0){break}else{fa=ha;ga=G}}}}while(0);if((c[v>>2]|0)==0){B=N;F=O}else{K=67;break}}if((K|0)==56){K=0;if(!A){ia=O;break}if(O>>>0<(g+N|0)>>>0){x=N;h=O;continue}else{ia=O;break}}else if((K|0)==67){K=0;B=c[y>>2]|0;D=B+8|0;C=c[D>>2]|0;s=(C-(c[B>>2]|0)|0)<16;c[D>>2]=C-16;C=c[y>>2]|0;D=C+20|0;c[D>>2]=(c[D>>2]|0)-16;if(!s){x=0;h=0;continue}s=C+8|0;c[s>>2]=(c[s>>2]|0)+((c[C+12>>2]|0)-(c[C>>2]|0));x=0;h=0;continue}}do{if((K|0)==36){h=(fHb(c[y>>2]|0)|0)+Q|0;KIb(b,16,2607088,(E=i,i=i+8|0,c[E>>2]=h,E)|0);i=E;ia=O}else if((K|0)==54){KIb(b,16,2453920,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;ia=O}else if((K|0)==69){h=c[w>>2]|0;if((h|0)!=0){x=h;do{h=c[x+8>>2]|0;do{if((h|0)>0){N=c[p>>2]|0;if((N|0)!=0){if((h|0)<=(c[N+8>>2]|0)){break}}c[p>>2]=x}}while(0);x=c[x+56>>2]|0;}while((x|0)!=0)}x=c[p>>2]|0;if((x|0)==0){ia=F;break}c[l>>2]=1;h=c[x>>2]|0;if((h|0)<=0){if(!P){ia=F;break}q=qea(o,e,f)|0;i=j;return q|0}KIb(b,48,2364632,(E=i,i=i+8|0,c[E>>2]=h,E)|0);i=E;c[a+304>>2]=0;h=c[c[p>>2]>>2]|0;c[f>>2]=h;c[e>>2]=rea(o,0,h,n+36|0,n+40|0)|0;if(P){h=c[c[p>>2]>>2]|0;q=h-(fHb(c[y>>2]|0)|0)|0;i=j;return q|0}else{q=F-g|0;i=j;return q|0}}}while(0);c[e>>2]=0;c[f>>2]=0;q=ia-g|0;i=j;return q|0}function pea(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;a=c[b+8>>2]|0;if((a|0)!=0){d=a;while(1){a=c[d+56>>2]|0;mJb(d+4|0);kJb(d);if((a|0)==0){break}else{d=a}}}eHb(c[b+28>>2]|0);kJb(c[b+36>>2]|0);return}function qea(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[a+12>>2]|0;f=c[e+60>>2]|0;g=(f|0)!=0;if(g){c[d>>2]=(c[f>>2]|0)-(c[e>>2]|0);uea(a,e,f,0)|0}else{h=fHb(c[a+28>>2]|0)|0;c[d>>2]=h-(c[e>>2]|0)}h=e+16|0;i=c[e+20>>2]|0;j=a+4|0;k=c[j>>2]|0;l=k+416|0;if((i|0)==(c[l>>2]|0)){m=k+448|0;if((c[m>>2]|0)==0&(c[m+4>>2]|0)==0){n=6}else{o=k}}else{n=6}if((n|0)==6){c[l>>2]=i;kea(k);o=c[j>>2]|0}c[o+412>>2]=c[h>>2];c[(c[a>>2]|0)+304>>2]=c[e+28>>2];c[b>>2]=rea(a,c[e>>2]|0,c[d>>2]|0,a+36|0,a+40|0)|0;c[a+24>>2]=0;c[a+88>>2]=1;d=a+48|0;e=h;c[d>>2]=c[e>>2];c[d+4>>2]=c[e+4>>2];c[d+8>>2]=c[e+8>>2];c[d+12>>2]=c[e+12>>2];c[d+16>>2]=c[e+16>>2];c[d+20>>2]=c[e+20>>2];c[d+24>>2]=c[e+24>>2];c[d+28>>2]=c[e+28>>2];c[d+32>>2]=c[e+32>>2];c[d+36>>2]=c[e+36>>2];if(!g){p=0;return p|0}g=c[f>>2]|0;p=g-(fHb(c[a+28>>2]|0)|0)|0;return p|0}function rea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=c[a+28>>2]|0;j=c[h+4>>2]|0;k=j+b|0;l=h+12|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=k;o=m}else{k=m;n=j+(b-k+(c[h>>2]|0))|0;o=k}if((o-n|0)>=(d|0)){p=n;i=g;return p|0}o=wJb(c[e>>2]|0,f,d)|0;if((o|0)==0){KIb(c[a+4>>2]|0,16,2299456,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;p=0;i=g;return p|0}c[e>>2]=o;a=h|0;h=o;o=n;n=d;d=c[l>>2]|0;while(1){f=d-o|0;k=(f|0)>(n|0)?n:f;nrc(h|0,o|0,k)|0;f=c[l>>2]|0;b=n-k|0;if((b|0)>0){h=h+k|0;o=o+((c[a>>2]|0)-f+k)|0;n=b;d=f}else{break}}p=c[e>>2]|0;i=g;return p|0}function sea(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b+8|0;e=c[d>>2]|0;if(!((e|0)==-1e5)){f=e;return f|0}if((c[a+88>>2]|0)==0){g=10}else{g=10-(tea(a,a+48|0,b+16|0,48)|0)|0}c[d>>2]=g;e=c[b+56>>2]|0;if((e|0)==0){f=g;return f|0}h=b+4|0;i=b+60|0;j=0;k=e;e=c[h>>2]|0;while(1){if((c[e+(j<<2)>>2]|0)==1e5){l=uea(a,b,k,48)|0;c[(c[h>>2]|0)+(j<<2)>>2]=l}l=sea(a,k)|0;m=c[h>>2]|0;n=l-(c[m+(j<<2)>>2]|0)|0;l=c[d>>2]|0;if((n+10|0)>(l|0)){c[i>>2]=k;o=n+g|0;c[d>>2]=o;p=o}else{p=l}l=j+1|0;o=c[k+56>>2]|0;if((l|0)>2|(o|0)==0){f=p;break}else{j=l;k=o;e=m}}return f|0}function tea(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;if((c[d>>2]|0)==(c[b>>2]|0)){g=0}else{KIb(c[a+4>>2]|0,e+24|0,2174088,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=7}if((c[d+8>>2]|0)==(c[b+8>>2]|0)){j=g}else{KIb(c[a+4>>2]|0,e+24|0,2146520,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=g+7|0}if((c[d+32>>2]|0)==(c[b+32>>2]|0)){k=j}else{KIb(c[a+4>>2]|0,e+24|0,2122752,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;k=j+10|0}if((c[d+4>>2]|0)==(c[b+4>>2]|0)){l=k;i=f;return l|0}KIb(c[a+4>>2]|0,e+24|0,2640496,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;l=k+7|0;i=f;return l|0}function uea(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;g=tea(a,b+16|0,d+16|0,e)|0;h=d+40|0;j=c[h>>2]|0;k=c[h+4>>2]|0;l=b+40|0;m=c[l>>2]|0;n=c[l+4>>2]|0;o=xrc(j,k,m,n)|0;p=c[b+28>>2]|0;q=(o|0)==(p|0)&(G|0)==(((p|0)<0|0?-1:0)|0);p=wrc(m,n,1,0)|0;if(q|(j|0)==(p|0)&(k|0)==(G|0)){r=0;s=g}else{p=m;if((b|0)==(d|0)){t=p;u=p}else{m=b;q=p;n=p;while(1){p=m+4|0;o=0;while(1){if((o|0)>=3){v=n;w=q;break}if((c[(c[p>>2]|0)+(o<<2)>>2]|0)<50){x=6;break}else{o=o+1|0}}if((x|0)==6){x=0;v=(c[m+28>>2]|0)+n|0;w=q+1|0}o=c[m+56>>2]|0;if((o|0)==(d|0)){t=w;u=v;break}else{m=o;q=w;n=v}}}if((t|0)==(j|0)&(((t|0)<0|0?-1:0)|0)==(k|0)){x=10}else{if((u|0)==(j|0)&(((u|0)<0|0?-1:0)|0)==(k|0)){x=10}else{y=0}}if((x|0)==10){y=(g|0)==0|0}KIb(c[a+4>>2]|0,e+24|0,2248432,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;r=y;s=g+7|0}if(!((s|0)!=0&(r|0)==0)){A=s;i=f;return A|0}r=c[b+56>>2]|0;if((r|0)==(d|0)){B=0}else{g=0;y=r;while(1){x=g+1|0;k=c[y+56>>2]|0;if((x|0)>2|(k|0)==(d|0)){B=x;break}else{g=x;y=k}}}y=c[b+4>>2]|0;g=c[y+(B<<2)>>2]|0;do{if((g|0)<50|(g|0)==1e5){a:do{if((B|0)>0){k=B-1|0;if((c[y+(k<<2)>>2]|0)>49){C=b;D=r}else{x=(c[(c[r+4>>2]|0)+(k<<2)>>2]|0)>49;E=x?r:d;F=b;H=x&1;break}while(1){if((D|0)==(d|0)){E=d;F=C;H=1;break a}C=D;D=c[D+56>>2]|0}}else{E=d;F=b;H=0}}while(0);x=E|0;k=F|0;u=c[k>>2]|0;j=(c[x>>2]|0)-u|0;t=a+28|0;v=c[t>>2]|0;n=c[v+4>>2]|0;w=n+u|0;q=c[v+12>>2]|0;if(w>>>0<q>>>0){I=w;J=q}else{w=q;I=n+(u-w+(c[v>>2]|0))|0;J=w}w=J-I|0;v=(j|0)>(w|0)?w:j;j=EGb(DGb(1)|0,0,I,v)|0;w=c[x>>2]|0;x=w-(c[k>>2]|0)|0;k=x-v|0;if((x|0)==(v|0)){K=j}else{v=w-k|0;w=c[t>>2]|0;t=c[w+4>>2]|0;x=t+v|0;u=c[w+12>>2]|0;if(x>>>0<u>>>0){L=x;M=u}else{x=u;L=t+(v-x+(c[w>>2]|0))|0;M=x}x=M-L|0;K=EGb(DGb(1)|0,j,L,(k|0)>(x|0)?x:k)|0}if((K|0)==0^(H|0)==0){break}else{A=s}i=f;return A|0}}while(0);H=c[l>>2]|0;K=c[l+4>>2]|0;l=c[d>>2]|0;d=c[h>>2]|0;L=c[h+4>>2]|0;KIb(c[a+4>>2]|0,e+24|0,2206352,(z=i,i=i+48|0,c[z>>2]=c[b>>2],c[z+8>>2]=H,c[z+16>>2]=K,c[z+24>>2]=l,c[z+32>>2]=d,c[z+40>>2]=L,z)|0);i=z;A=s+50|0;i=f;return A|0}function vea(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c-1|0;c=(f|0)%4|0;if((c|0)>0){g=0;h=0;while(1){i=b+g|0;if(((he((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-8){j=wea(a,g+e|0)|0}else{j=h}i=g+1|0;if((i|0)<(c|0)){g=i;h=j}else{k=c;l=j;break}}}else{k=0;l=0}if((k|0)<(f|0)){m=k;n=l}else{o=l;return o|0}while(1){l=b+m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=je(k|0)|0;do{if((l&-2139062144&-16843010-l|0)==0){p=n}else{j=m+e|0;if(((he(k&65535|0)|0)&-2)<<16>>16==-8){q=wea(a,j)|0}else{q=n}c=b+(m+1)|0;if(((he((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-8){r=wea(a,j+1|0)|0}else{r=q}c=b+(m+2)|0;if(((he((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-8){s=wea(a,j+2|0)|0}else{s=r}c=b+(m+3)|0;if(!(((he((d[c]|d[c+1|0]<<8)<<16>>16|0)|0)&-2)<<16>>16==-8)){p=s;break}p=wea(a,j+3|0)|0}}while(0);k=m+4|0;if((k|0)<(f|0)){m=k;n=p}else{o=p;break}}return o|0}function wea(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+64|0;e=d|0;f=d+24|0;g=rea(a,b,16,a+36|0,a+40|0)|0;h=a+4|0;j=c[h>>2]|0;k=(g|0)==0?0:128;c[e>>2]=g;c[e+12>>2]=k;c[e+16>>2]=k|8;c[e+4>>2]=g+(k>>>3);c[e+8>>2]=0;if((hea(j,e,f,127)|0)!=0){l=0;i=d;return l|0}e=a+8|0;j=c[e>>2]|0;if((j|0)==0){m=1;n=e}else{e=1;k=j;while(1){j=k+56|0;g=e+1|0;o=c[j>>2]|0;if((o|0)==0){m=g;n=j;break}else{e=g;k=o}}}k=pJb(64)|0;c[n>>2]=k;if((k|0)==0){KIb(c[h>>2]|0,16,2617792,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;l=-12;i=d;return l|0}else{h=k+16|0;k=f;c[h>>2]=c[k>>2];c[h+4>>2]=c[k+4>>2];c[h+8>>2]=c[k+8>>2];c[h+12>>2]=c[k+12>>2];c[h+16>>2]=c[k+16>>2];c[h+20>>2]=c[k+20>>2];c[h+24>>2]=c[k+24>>2];c[h+28>>2]=c[k+28>>2];c[h+32>>2]=c[k+32>>2];c[h+36>>2]=c[k+36>>2];c[c[n>>2]>>2]=b;b=hJb(12)|0;c[(c[n>>2]|0)+4>>2]=b;b=c[(c[n>>2]|0)+4>>2]|0;c[b>>2]=1e5;c[b+4>>2]=1e5;c[b+8>>2]=1e5;b=a+16|0;c[b>>2]=(c[b>>2]|0)+1;l=m;i=d;return l|0}return 0}function xea(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+16|0;d=b+8|0;e=c[a+60>>2]|0;f=e+32|0;c[f>>2]=a;if((c[a+96>>2]|0)==0){g=0;i=b;return g|0}if((jea(a,b|0,d)|0)==0){g=-1094995529;i=b;return g|0}lea(a,e,c[d>>2]|0);d=Aea(e)|0;if((d|0)<0){g=d;i=b;return g|0}d=c[(c[f>>2]|0)+468>>2]|0;h=e+8|0;j=(c[h>>2]|0)>16;k=QKb(d)|0;l=(RKb(d)|0)==0;d=(c[f>>2]|0)+420|0;if(j|(k|0)>2){c[d>>2]=l?2:7;k=c[h>>2]|0;c[e+60>>2]=32-k;m=k}else{c[d>>2]=l?1:6;l=c[h>>2]|0;c[e+60>>2]=16-l;m=l}Cea(e+112|0,c[a+420>>2]|0,m);c[e+68>>2]=1;g=0;i=b;return g|0}function yea(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;h=i;i=i+216|0;j=h|0;k=h+128|0;l=h+168|0;m=h+176|0;n=h+184|0;o=h+192|0;p=h+200|0;c[p>>2]=e;c[p+4>>2]=0;c[p+8>>2]=0;q=c[g+24>>2]|0;r=c[g+28>>2]|0;s=c[b+60>>2]|0;t=s;c[f>>2]=0;u=s+16|0;if((c[u>>2]|0)==0){v=c[s+12>>2]|0;c[u>>2]=iea((v|0)==0?65535:v,8,32)|0}do{if((r|0)>5){if((grc(q,2453912,5)|0)!=0){break}KIb(c[s+32>>2]|0,48,2364592,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=r;i=h;return x|0}}while(0);if((r|0)<=0){x=r;i=h;return x|0}if((a[q]&127)==4){KIb(c[s+32>>2]|0,48,2299416,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=r;i=h;return x|0}if((r|0)<11){x=r;i=h;return x|0}v=q;if((d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)==1130450022){v=s+68|0;a:do{if((c[v>>2]|0)==0){if((r|0)<42){break}mea(q+4|0,0,n,o);do{if((c[n>>2]|0)==0){if((c[o>>2]|0)!=34){y=-1094995529;break}z=s+32|0;lea(c[z>>2]|0,s,q+8|0);A=Aea(t)|0;if((A|0)<0){y=A;break}A=c[(c[z>>2]|0)+468>>2]|0;B=s+8|0;C=(c[B>>2]|0)>16;D=QKb(A)|0;E=(RKb(A)|0)==0;A=(c[z>>2]|0)+420|0;if(C|(D|0)>2){c[A>>2]=E?2:7;D=c[B>>2]|0;c[s+60>>2]=32-D;F=D}else{c[A>>2]=E?1:6;E=c[B>>2]|0;c[s+60>>2]=16-E;F=E}Cea(s+112|0,c[(c[z>>2]|0)+420>>2]|0,F);c[v>>2]=1;break a}else{y=-1094995529}}while(0);KIb(c[s+32>>2]|0,16,2248416,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=y;i=h;return x|0}}while(0);y=q+r|0;v=q+4|0;while(1){if((y-v|0)<4){x=0;G=154;break}mea(v,l,0,m);F=c[m>>2]|0;if((y-(v+4)|0)<(F|0)){x=0;G=154;break}H=v+(F+4)|0;if((c[l>>2]|0)==0){v=H}else{G=25;break}}if((G|0)==25){x=r-y+H|0;i=h;return x|0}else if((G|0)==154){i=h;return x|0}}H=s+36|0;y=r>>>0>268435455>>>0?-8:r<<3;v=y>>>0>2147483639>>>0|(q|0)==0;l=v?0:q;m=v?0:y;y=H;c[y>>2]=l;F=s+48|0;c[F>>2]=m;o=s+52|0;c[o>>2]=m+8;c[s+40>>2]=l+(m>>3);m=s+44|0;c[m>>2]=0;if(v){x=v?-1094995529:0;i=h;return x|0}v=s+32|0;l=hea(c[v>>2]|0,H,k,0)|0;b:do{if((l|0)<0){KIb(c[v>>2]|0,16,2640472,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=l}else{H=s+4|0;n=c[H>>2]|0;z=k+4|0;do{if((n|0)!=0){E=c[z>>2]|0;if((E|0)==(n|0)){break}if((c[s+68>>2]|0)==0){break}B=c[v>>2]|0;c[B+416>>2]=E;c[H>>2]=E;kea(B);B=Aea(t)|0;if((B|0)<0){I=B;break b}}}while(0);n=c[z>>2]|0;B=c[v>>2]|0;c[B+416>>2]=n;c[H>>2]=n;n=B+448|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){kea(B)}B=s+64|0;c[B>>2]=c[k+16>>2];n=s+8|0;E=c[n>>2]|0;A=k+8|0;D=c[A>>2]|0;C=(D|0)==0;do{if((E|0)==0){J=c[v>>2]|0;if(C){KIb(J,16,2617744,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}c[J+796>>2]=D;c[n>>2]=D;K=c[J+468>>2]|0;J=QKb(K)|0;L=(RKb(K)|0)==0;K=(c[v>>2]|0)+420|0;if((D|0)>16|(J|0)>2){c[K>>2]=L?2:7;c[s+60>>2]=32-(c[n>>2]|0);break}else{c[K>>2]=L?1:6;c[s+60>>2]=16-(c[n>>2]|0);break}}else{if(C){c[A>>2]=E;break}if((D|0)==(E|0)){break}KIb(c[v>>2]|0,16,2590336,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}}while(0);E=s+12|0;D=c[E>>2]|0;if((D|0)==0){c[E>>2]=65535;M=65535}else{M=D}D=c[k+12>>2]|0;if((D|0)>(M|0)){KIb(c[v>>2]|0,16,2568704,(w=i,i=i+16|0,c[w>>2]=D,c[w+8>>2]=M,w)|0);i=w;I=-1094995529;break}A=s+56|0;c[A>>2]=D;D=s;C=c[D>>2]|0;z=k|0;L=c[z>>2]|0;K=(L|0)==0;do{if((C|0)==0){if(!K){N=L;break}KIb(c[v>>2]|0,16,2550640,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}else{if(!K){N=L;break}c[z>>2]=C;N=C}}while(0);c[(c[v>>2]|0)+412>>2]=N;c[D>>2]=N;C=s+68|0;if((c[C>>2]|0)==0){z=Aea(t)|0;if((z|0)<0){I=z;break}Cea(s+112|0,c[(c[v>>2]|0)+420>>2]|0,c[n>>2]|0);c[C>>2]=1;C=c[v>>2]|0;KIb(C,48,2411408,(w=i,i=i+8|0,c[w>>2]=c[E>>2],w)|0);i=w;KIb(C,48,2403792,(w=i,i=i+8|0,c[w>>2]=c[u>>2],w)|0);i=w;KIb(C,48,2396744,(w=i,i=i+8|0,c[w>>2]=c[D>>2],w)|0);i=w;KIb(C,48,2389776,(w=i,i=i+8|0,c[w>>2]=c[H>>2],w)|0);i=w;KIb(C,48,2382848,(w=i,i=i+8|0,c[w>>2]=c[n>>2],w)|0);i=w}c:do{if((c[H>>2]|0)>0){C=s+128|0;z=j|0;L=0;d:while(1){K=c[t+72+(L<<2)>>2]|0;J=c[n>>2]|0;O=c[B>>2]|0;do{if((L|0)==0){P=((O|0)==2)+J|0}else{if(!((O|0)==1|(O|0)==3)){P=J;break}P=J+1|0}}while(0);J=c[m>>2]|0;O=c[y>>2]|0;Q=d[O+(J>>>3)|0]|0;R=c[o>>2]|0;S=((J|0)<(R|0))+J|0;c[m>>2]=S;if((Q&128>>>((J&7)>>>0)|0)!=0){G=64;break}J=O+(S>>>3)|0;Q=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(S&7);J=Q>>>26;T=S+6|0;S=R>>>0>T>>>0?T:R;c[m>>2]=S;T=d[O+(S>>>3)|0]|0;U=((S|0)<(R|0))+S|0;c[m>>2]=U;if((T&128>>>((S&7)>>>0)|0)==0){V=0;W=P;X=U}else{Y=(c[F>>2]|0)-U|0;if((Y|0)<0){G=77;break}if((Y|0)<(P|0)){S=O+(U>>>3)|0;T=d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0;S=U&7;Z=(je(T|0)|0)<<S;if((Y|0)<26){_=Z>>>((32-Y|0)>>>0)}else{$=U+16|0;aa=R>>>0>$>>>0?$:R;$=O+(aa>>>3)|0;_=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(aa&7)>>>((48-Y|0)>>>0)|Z>>>16<<Y-16}if((_|0)==0){G=77;break}else{ba=S;ca=T}}else{T=O+(U>>>3)|0;ba=U&7;ca=d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0}T=(je(ca|0)|0)<<ba;if((P|0)<26){da=T>>>((32-P|0)>>>0)}else{S=U+16|0;Z=R>>>0>S>>>0?S:R;S=O+(Z>>>3)|0;da=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Z&7)>>>((48-P|0)>>>0)|T>>>16<<P-16}if((da|0)==0){G=77;break}else{ea=0;fa=U}while(1){if((ea|0)>=(Y|0)){G=79;break}U=d[O+(fa>>>3)|0]|0;T=((fa|0)<(R|0))+fa|0;c[m>>2]=T;Z=ea+1|0;if((U&128>>>((fa&7)>>>0)|0)==0){ea=Z;fa=T}else{ga=T;ha=Z;break}}if((G|0)==79){G=0;ga=fa;ha=ea+1|0}V=ha;W=P-ha|0;X=ga}if((W|0)>32){G=83;break}e:do{if((J|0)==0){do{if((W|0)==0){ia=0}else{Z=O+(X>>>3)|0;T=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(X&7);if((W|0)<26){Z=W+X|0;c[m>>2]=R>>>0>Z>>>0?Z:R;ia=T>>>((32-W|0)>>>0);break}else{Z=X+16|0;U=R>>>0>Z>>>0?Z:R;c[m>>2]=U;Z=W-16|0;S=O+(U>>>3)|0;aa=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(U&7)>>>((48-W|0)>>>0);S=U+Z|0;c[m>>2]=R>>>0>S>>>0?S:R;ia=aa|T>>>16<<Z;break}}}while(0);Z=32-W|0;T=ia<<Z>>Z;if((c[A>>2]|0)>0){ja=0}else{break}do{c[K+(ja<<2)>>2]=T;ja=ja+1|0;}while((ja|0)<(c[A>>2]|0))}else if((J|0)==1){if((c[A>>2]|0)<=0){break}T=(W|0)==0;Z=32-W|0;aa=(W|0)<26;S=W-16|0;U=48-W|0;$=0;do{do{if(T){ka=0}else{la=c[m>>2]|0;ma=c[o>>2]|0;na=O+(la>>>3)|0;oa=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(la&7);if(aa){na=la+W|0;c[m>>2]=ma>>>0>na>>>0?na:ma;ka=oa>>>(Z>>>0);break}else{na=la+16|0;la=ma>>>0>na>>>0?na:ma;c[m>>2]=la;na=O+(la>>>3)|0;pa=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(la&7)>>>(U>>>0);na=la+S|0;c[m>>2]=ma>>>0>na>>>0?na:ma;ka=pa|oa>>>16<<S;break}}}while(0);c[K+($<<2)>>2]=ka<<Z>>Z;$=$+1|0;}while(($|0)<(c[A>>2]|0))}else{if(!((J-8|0)>>>0<5>>>0)){if((Q|0)>=0){G=137;break d}$=J&31;Z=$+1|0;S=(W|0)==0;U=32-W|0;aa=(W|0)<26;T=W-16|0;oa=48-W|0;pa=0;do{do{if(S){qa=0}else{ma=c[m>>2]|0;na=c[o>>2]|0;la=O+(ma>>>3)|0;ra=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7);if(aa){la=ma+W|0;c[m>>2]=na>>>0>la>>>0?la:na;qa=ra>>>(U>>>0);break}else{la=ma+16|0;ma=na>>>0>la>>>0?la:na;c[m>>2]=ma;la=O+(ma>>>3)|0;sa=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>(oa>>>0);la=ma+T|0;c[m>>2]=na>>>0>la>>>0?la:na;qa=sa|ra>>>16<<T;break}}}while(0);c[K+(pa<<2)>>2]=qa<<U>>U;pa=pa+1|0;}while((pa|0)<(Z|0));pa=c[m>>2]|0;U=c[o>>2]|0;T=O+(pa>>>3)|0;oa=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(pa&7)>>>28;T=pa+4|0;pa=U>>>0>T>>>0?T:U;c[m>>2]=pa;T=oa+1|0;if((T|0)==16){G=130;break d}aa=O+(pa>>>3)|0;ta=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(pa&7)>>27;aa=pa+5|0;pa=U>>>0>aa>>>0?aa:U;c[m>>2]=pa;if((ta|0)<0){G=133;break d}aa=oa^31;oa=0;S=pa;do{pa=O+(S>>>3)|0;ra=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(S&7)>>aa;pa=S+T|0;S=U>>>0>pa>>>0?pa:U;c[m>>2]=S;c[j+($-oa<<2)>>2]=ra;oa=oa+1|0;}while((oa|0)<(Z|0));oa=Bea(t,K,Z)|0;if((oa|0)<0){I=oa;break b}pe[c[C>>2]&1023](K,z,Z,ta,c[A>>2]|0);break}ua=J&55;oa=c[A>>2]|0;$=(ua|0)!=0;if($){S=(W|0)==0;U=32-W|0;T=(W|0)<26;aa=W-16|0;ra=48-W|0;pa=0;do{do{if(S){va=0}else{sa=c[m>>2]|0;na=c[o>>2]|0;la=O+(sa>>>3)|0;ma=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(sa&7);if(T){la=sa+W|0;c[m>>2]=na>>>0>la>>>0?la:na;va=ma>>>(U>>>0);break}else{la=sa+16|0;sa=na>>>0>la>>>0?la:na;c[m>>2]=sa;la=O+(sa>>>3)|0;wa=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(sa&7)>>>(ra>>>0);la=sa+aa|0;c[m>>2]=na>>>0>la>>>0?la:na;va=wa|ma>>>16<<aa;break}}}while(0);c[K+(pa<<2)>>2]=va<<U>>U;pa=pa+1|0;}while((pa|0)<(ua|0))}pa=Bea(t,K,ua)|0;if((pa|0)<0){I=pa;break b}if(!$){break}pa=c[K+(ua-1<<2)>>2]|0;if(!(ua>>>0>1>>>0)){if((oa|0)>1){xa=pa;ya=1}else{break}while(1){U=K+(ya<<2)|0;xa=(c[U>>2]|0)+xa|0;c[U>>2]=xa;ya=ya+1|0;if((ya|0)>=(oa|0)){break e}}}$=c[K+(ua-2<<2)>>2]|0;U=pa-$|0;if(!(ua>>>0>2>>>0)){if((oa|0)>2){za=pa;Aa=U;Ba=2}else{break}while(1){aa=K+(Ba<<2)|0;Aa=(c[aa>>2]|0)+Aa|0;za=Aa+za|0;c[aa>>2]=za;Ba=Ba+1|0;if((Ba|0)>=(oa|0)){break e}}}aa=c[K+(ua-3<<2)>>2]|0;ra=aa+(U-$)|0;if(!(ua>>>0>3>>>0)){if((oa|0)>3){Ca=pa;Da=U;Ea=ra;Fa=3}else{break}while(1){T=K+(Fa<<2)|0;Ea=(c[T>>2]|0)+Ea|0;Da=Ea+Da|0;Ca=Da+Ca|0;c[T>>2]=Ca;Fa=Fa+1|0;if((Fa|0)>=(oa|0)){break e}}}if((ua|0)!=4){G=121;break d}if((oa|0)<=4){break}T=pa;S=U;Z=ra;ma=ra-$+(aa<<1)-(c[K>>2]|0)|0;wa=4;do{na=K+(wa<<2)|0;ma=(c[na>>2]|0)+ma|0;Z=ma+Z|0;S=Z+S|0;T=S+T|0;c[na>>2]=T;wa=wa+1|0;}while((wa|0)<(oa|0))}}while(0);do{if((V|0)!=0){if((c[A>>2]|0)>0){Ga=0}else{break}do{O=K+(Ga<<2)|0;c[O>>2]=c[O>>2]<<V;Ga=Ga+1|0;}while((Ga|0)<(c[A>>2]|0))}}while(0);L=L+1|0;if((L|0)>=(c[H>>2]|0)){break c}}if((G|0)==64){KIb(c[v>>2]|0,16,2532440,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}else if((G|0)==77){KIb(c[v>>2]|0,16,2517112,(w=i,i=i+16|0,c[w>>2]=P,c[w+8>>2]=Y,w)|0);i=w;I=-1094995529;break b}else if((G|0)==83){RIb(c[v>>2]|0,2503144,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1163346256;break b}else if((G|0)==121){KIb(c[v>>2]|0,16,2420728,(w=i,i=i+8|0,c[w>>2]=ua,w)|0);i=w;I=-1094995529;break b}else if((G|0)==130){KIb(c[v>>2]|0,16,2479120,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}else if((G|0)==133){KIb(c[v>>2]|0,16,2469296,(w=i,i=i+8|0,c[w>>2]=ta,w)|0);i=w;I=-1094995529;break b}else if((G|0)==137){KIb(c[v>>2]|0,16,2490040,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;I=-1094995529;break b}}}while(0);n=c[m>>2]|0;D=-n&7;E=c[o>>2]|0;if((D|0)==0){Ha=n}else{L=D+n|0;n=E>>>0>L>>>0?L:E;c[m>>2]=n;Ha=n}n=Ha+16|0;c[m>>2]=E>>>0>n>>>0?n:E;E=(c[m>>2]|0)/8|0;do{if((c[(c[v>>2]|0)+696>>2]&131073|0)!=0){if((EGb(DGb(1)|0,0,q,E)|0)==0){break}n=g+8|0;L=c[n+4>>2]|0;KIb(c[v>>2]|0,16,2174064,(w=i,i=i+16|0,c[w>>2]=c[n>>2],c[w+8>>2]=L,w)|0);i=w;if((c[(c[v>>2]|0)+696>>2]&8|0)==0){break}else{x=-1094995529}i=h;return x|0}}while(0);c[e+76>>2]=c[A>>2];L=J5a(b,p,0)|0;if((L|0)<0){x=L;i=h;return x|0}pe[c[s+112+(c[B>>2]<<2)>>2]&1023](e,s+72|0,c[H>>2]|0,c[A>>2]|0,c[s+60>>2]|0);if((E|0)>(r|0)){KIb(c[v>>2]|0,16,2146496,(w=i,i=i+8|0,c[w>>2]=E-r,w)|0);i=w;x=-1094995529;i=h;return x|0}if((E|0)<(r|0)){KIb(c[v>>2]|0,48,2122688,(w=i,i=i+16|0,c[w>>2]=r-E,c[w+8>>2]=r,w)|0);i=w}c[f>>2]=1;x=E;i=h;return x|0}}while(0);KIb(c[v>>2]|0,16,2206328,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=I;i=h;return x|0}function zea(a){a=a|0;mJb((c[a+60>>2]|0)+104|0);return 0}function Aea(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+12|0;e=c[d>>2]|0;if((e|0)==0){KIb(0,0,2376168,(f=i,i=i+24|0,c[f>>2]=2369512,c[f+8>>2]=2354816,c[f+16>>2]=134,f)|0);i=f;Hd();return 0}f=a+4|0;g=SKb(0,c[f>>2]|0,e,7,0)|0;if((g|0)<0){h=g;i=b;return h|0}e=a+104|0;xJb(e,a+108|0,g);g=c[e>>2]|0;if((g|0)==0){h=-12;i=b;return h|0}h=TKb(a+72|0,0,g,c[f>>2]|0,c[d>>2]|0,7,0)|0;i=b;return h|0}function Bea(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;g=a+44|0;h=c[g>>2]|0;j=a+52|0;k=c[j>>2]|0;l=c[a+36>>2]|0;m=l+(h>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7);m=n>>>30;o=h+2|0;h=k>>>0>o>>>0?o:k;c[g>>2]=h;if((n|0)<0){KIb(c[a+32>>2]|0,16,2460136,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;q=-1094995529;i=f;return q|0}n=l+(h>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>28;n=h+4|0;h=k>>>0>n>>>0?n:k;c[g>>2]=h;n=c[a+56>>2]|0;r=n>>o;if((r<<o|0)!=(n|0)){KIb(c[a+32>>2]|0,16,2443464,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=n,p)|0);i=p;q=-1094995529;i=f;return q|0}if((r|0)<(e|0)){KIb(c[a+32>>2]|0,16,2430976,(p=i,i=i+16|0,c[p>>2]=e,c[p+8>>2]=r,p)|0);i=p;q=-1094995529;i=f;return q|0}p=m|4;m=(1<<p)-1|0;n=1<<o;if((n|0)<=0){q=0;i=f;return q|0}o=32-p|0;s=a+48|0;a=1;t=e;u=b+(e<<2)|0;e=h;h=k;while(1){k=l+(e>>>3)|0;b=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(e&7)>>>(o>>>0);k=e+p|0;v=h>>>0>k>>>0?k:h;c[g>>2]=v;do{if((b|0)==(m|0)){k=l+(v>>>3)|0;w=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(v&7);k=w>>>27;x=v+5|0;c[g>>2]=h>>>0>x>>>0?x:h;if((t|0)>=(r|0)){y=u;break}x=(k|0)==0;z=32-k|0;A=w>>>0<3489660928>>>0;w=k-16|0;B=48-k|0;C=t;D=u;while(1){do{if(x){E=0}else{F=c[g>>2]|0;G=c[j>>2]|0;H=l+(F>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7);if(A){H=F+k|0;c[g>>2]=G>>>0>H>>>0?H:G;E=I>>>(z>>>0);break}else{H=F+16|0;F=G>>>0>H>>>0?H:G;c[g>>2]=F;H=l+(F>>>3)|0;J=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>(B>>>0);H=F+w|0;c[g>>2]=G>>>0>H>>>0?H:G;E=J|I>>>16<<w;break}}}while(0);c[D>>2]=E<<z>>z;I=C+1|0;if((I|0)<(r|0)){C=I;D=D+4|0}else{break}}y=u+(r-t<<2)|0}else{if((t|0)>=(r|0)){y=u;break}D=32-b|0;C=b+32|0;a:do{if((b|0)==0){z=t;w=u;B=v;k=h;while(1){A=l+(B>>>3)|0;x=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(B&7);A=x>>>0>65535>>>0;I=A?x>>>16:x;J=A?16:0;if((I&65280|0)==0){K=J;L=I}else{K=J|8;L=I>>>8}I=(d[1359664+L|0]|0)+K|0;b:do{if((I|0)<7){do{if((x|0)>-1){J=c[s>>2]|0;A=B;G=0;do{if(!(J>>>0>A>>>0)){M=-1;break b}H=A+1|0;A=k>>>0>H>>>0?H:k;H=l+(A>>>3)|0;G=G+1|0;}while((G|0)!=2147483647&((je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(A&7)|0)>-1);J=A+1|0;H=k>>>0>J>>>0?J:k;if((G|0)<2147483646){N=G;O=H;break}if((G|0)!=2147483646){M=-1;break b}c[g>>2]=H;M=0;break b}else{H=B+1|0;N=0;O=k>>>0>H>>>0?H:k}}while(0);c[g>>2]=O;M=N}else{H=C+B-I|0;c[g>>2]=k>>>0>H>>>0?H:k;M=(x>>>(I>>>0))+(30-I)|0}}while(0);c[w>>2]=M>>1^-(M&1);I=z+1|0;if((I|0)>=(r|0)){break a}z=I;w=w+4|0;B=c[g>>2]|0;k=c[j>>2]|0}}else{k=t;B=u;w=v;z=h;while(1){I=l+(w>>>3)|0;x=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(w&7);I=x>>>0>65535>>>0;H=I?x>>>16:x;J=I?16:0;if((H&65280|0)==0){P=J;Q=H}else{P=J|8;Q=H>>>8}H=(d[1359664+Q|0]|0)+P|0;J=H-b|0;c:do{if((J|0)<7|(H|0)==-2147483615){do{if((x|0)>-1){I=c[s>>2]|0;F=w;R=0;do{if(!(I>>>0>F>>>0)){S=-1;break c}T=F+1|0;F=z>>>0>T>>>0?T:z;T=l+(F>>>3)|0;U=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(F&7);R=R+1|0;}while((R|0)!=2147483647&(U|0)>-1);I=F+1|0;G=z>>>0>I>>>0?I:z;if((R|0)<2147483646){V=R;W=U;X=G;break}if((R|0)!=2147483646){S=-1;break c}c[g>>2]=G;S=0;break c}else{G=w+1|0;V=0;W=x;X=z>>>0>G>>>0?G:z}}while(0);G=X+b|0;c[g>>2]=z>>>0>G>>>0?G:z;S=(W<<1>>>(D>>>0))+(V<<b)|0}else{G=C+w-H|0;c[g>>2]=z>>>0>G>>>0?G:z;S=(x>>>(J>>>0))+(30-H<<b)|0}}while(0);c[B>>2]=S>>1^-(S&1);H=k+1|0;if((H|0)>=(r|0)){break a}k=H;B=B+4|0;w=c[g>>2]|0;z=c[j>>2]|0}}}while(0);y=u+(r-t<<2)|0}}while(0);if((a|0)>=(n|0)){q=0;break}a=a+1|0;t=0;u=y;e=c[g>>2]|0;h=c[j>>2]|0}i=f;return q|0}function Cea(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+16|0;if((d|0)>16){c[e>>2]=114;c[a+20>>2]=118}else{c[e>>2]=386;c[a+20>>2]=138}if((b|0)==7){c[a>>2]=170;c[a+4>>2]=88;c[a+8>>2]=596;c[a+12>>2]=638;return}else if((b|0)==6){c[a>>2]=270;c[a+4>>2]=418;c[a+8>>2]=360;c[a+12>>2]=474;return}else if((b|0)==1){c[a>>2]=554;c[a+4>>2]=540;c[a+8>>2]=20;c[a+12>>2]=306;return}else if((b|0)==2){c[a>>2]=520;c[a+4>>2]=512;c[a+8>>2]=48;c[a+12>>2]=340;return}else{return}}function Dea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d|0)>=(f|0)){return}g=e;if((d|0)>0){h=a;i=d}else{return}while(1){a=0;e=0;j=0;do{k=c[b+(a<<2)>>2]|0;l=c[h+(a<<2)>>2]|0;m=Erc(l,(l|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;j=wrc(m,G,j,e)|0;e=G;a=a+1|0;}while((a|0)<(d|0));a=Arc(j|0,e|0,g|0)|0;m=h+(d<<2)|0;k=wrc(c[m>>2]|0,0,a,G)|0;c[m>>2]=k;k=i+1|0;if((k|0)<(f|0)){h=h+4|0;i=k}else{break}}return}function Eea(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0;if((e|0)>0){h=0;do{c[a+(h<<2)>>2]=c[b+(h<<2)>>2];h=h+1|0;}while((h|0)<(e|0))}switch(e|0){case 1:{if((d|0)<=1){return}h=g;i=1;do{j=c[b+(i-1<<2)>>2]|0;k=c[f>>2]|0;l=k;m=(k|0)<0|0?-1:0;k=Erc(l,m,j,(j|0)<0|0?-1:0)|0;j=G;n=c[b+(i<<2)>>2]|0;o=Erc(n,(n|0)<0|0?-1:0,l,m)|0;m=G;l=Arc(k|0,j|0,h|0)|0;j=G;k=wrc(l,j,-2147483648,0)|0;p=G;q=0;if(p>>>0>q>>>0|p>>>0==q>>>0&k>>>0>-1>>>0){((j|0)<0|0?-1:0)>>31|((j|0)<0|0?-1:0)<<1;r=(j>>31|((j|0)<0|0?-1:0)<<1)^2147483647}else{r=l}c[a+(i<<2)>>2]=n-r;n=i+1|0;l=c[b+(n<<2)>>2]|0;j=Arc(o|0,m|0,h|0)|0;m=G;o=wrc(j,m,-2147483648,0)|0;k=G;q=0;if(k>>>0>q>>>0|k>>>0==q>>>0&o>>>0>-1>>>0){((m|0)<0|0?-1:0)>>31|((m|0)<0|0?-1:0)<<1;s=(m>>31|((m|0)<0|0?-1:0)<<1)^2147483647}else{s=j}c[a+(n<<2)>>2]=l-s;i=i+2|0;}while((i|0)<(d|0));return};case 8:{if((d|0)<=8){return}i=f+28|0;s=f+24|0;h=f+20|0;r=f+16|0;l=f+12|0;n=f+8|0;j=f+4|0;m=g;o=8;do{q=c[b+(o-8<<2)>>2]|0;k=c[i>>2]|0;p=k;t=(k|0)<0|0?-1:0;k=Erc(p,t,q,(q|0)<0|0?-1:0)|0;q=G;u=c[b+(o-7<<2)>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=Erc(v,w,p,t)|0;t=G;p=c[s>>2]|0;x=p;y=(p|0)<0|0?-1:0;p=Erc(x,y,v,w)|0;w=wrc(p,G,k,q)|0;q=G;k=c[b+(o-6<<2)>>2]|0;p=k;v=(k|0)<0|0?-1:0;k=Erc(p,v,x,y)|0;y=wrc(k,G,u,t)|0;t=G;u=c[h>>2]|0;k=u;x=(u|0)<0|0?-1:0;u=Erc(k,x,p,v)|0;v=wrc(w,q,u,G)|0;u=G;q=c[b+(o-5<<2)>>2]|0;w=q;p=(q|0)<0|0?-1:0;q=Erc(w,p,k,x)|0;x=wrc(y,t,q,G)|0;q=G;t=c[r>>2]|0;y=t;k=(t|0)<0|0?-1:0;t=Erc(y,k,w,p)|0;p=wrc(v,u,t,G)|0;t=G;u=c[b+(o-4<<2)>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=Erc(v,w,y,k)|0;k=wrc(x,q,u,G)|0;u=G;q=c[l>>2]|0;x=q;y=(q|0)<0|0?-1:0;q=Erc(x,y,v,w)|0;w=wrc(p,t,q,G)|0;q=G;t=c[b+(o-3<<2)>>2]|0;p=t;v=(t|0)<0|0?-1:0;t=Erc(p,v,x,y)|0;y=wrc(k,u,t,G)|0;t=G;u=c[n>>2]|0;k=u;x=(u|0)<0|0?-1:0;u=Erc(k,x,p,v)|0;v=wrc(w,q,u,G)|0;u=G;q=c[b+(o-2<<2)>>2]|0;w=q;p=(q|0)<0|0?-1:0;q=Erc(w,p,k,x)|0;x=wrc(y,t,q,G)|0;q=G;t=c[j>>2]|0;y=t;k=(t|0)<0|0?-1:0;t=Erc(y,k,w,p)|0;p=wrc(v,u,t,G)|0;t=G;u=c[b+(o-1<<2)>>2]|0;v=u;w=(u|0)<0|0?-1:0;u=Erc(v,w,y,k)|0;k=wrc(x,q,u,G)|0;u=G;q=c[f>>2]|0;x=q;y=(q|0)<0|0?-1:0;q=Erc(x,y,v,w)|0;w=wrc(p,t,q,G)|0;q=G;t=c[b+(o<<2)>>2]|0;p=Erc(t,(t|0)<0|0?-1:0,x,y)|0;y=wrc(k,u,p,G)|0;p=G;u=Arc(w|0,q|0,m|0)|0;q=G;w=wrc(u,q,-2147483648,0)|0;k=G;x=0;if(k>>>0>x>>>0|k>>>0==x>>>0&w>>>0>-1>>>0){((q|0)<0|0?-1:0)>>31|((q|0)<0|0?-1:0)<<1;z=(q>>31|((q|0)<0|0?-1:0)<<1)^2147483647}else{z=u}c[a+(o<<2)>>2]=t-z;t=o|1;u=c[b+(t<<2)>>2]|0;q=Arc(y|0,p|0,m|0)|0;p=G;y=wrc(q,p,-2147483648,0)|0;w=G;x=0;if(w>>>0>x>>>0|w>>>0==x>>>0&y>>>0>-1>>>0){((p|0)<0|0?-1:0)>>31|((p|0)<0|0?-1:0)<<1;A=(p>>31|((p|0)<0|0?-1:0)<<1)^2147483647}else{A=q}c[a+(t<<2)>>2]=u-A;o=o+2|0;}while((o|0)<(d|0));return};case 2:{if((d|0)<=2){return}o=f+4|0;A=g;m=2;do{z=c[b+(m-2<<2)>>2]|0;j=c[o>>2]|0;n=j;l=(j|0)<0|0?-1:0;j=Erc(n,l,z,(z|0)<0|0?-1:0)|0;z=G;r=c[b+(m-1<<2)>>2]|0;h=r;s=(r|0)<0|0?-1:0;r=Erc(h,s,n,l)|0;l=G;n=c[f>>2]|0;i=n;u=(n|0)<0|0?-1:0;n=Erc(i,u,h,s)|0;s=wrc(n,G,j,z)|0;z=G;j=c[b+(m<<2)>>2]|0;n=Erc(j,(j|0)<0|0?-1:0,i,u)|0;u=wrc(n,G,r,l)|0;l=G;r=Arc(s|0,z|0,A|0)|0;z=G;s=wrc(r,z,-2147483648,0)|0;n=G;i=0;if(n>>>0>i>>>0|n>>>0==i>>>0&s>>>0>-1>>>0){((z|0)<0|0?-1:0)>>31|((z|0)<0|0?-1:0)<<1;B=(z>>31|((z|0)<0|0?-1:0)<<1)^2147483647}else{B=r}c[a+(m<<2)>>2]=j-B;j=m|1;r=c[b+(j<<2)>>2]|0;z=Arc(u|0,l|0,A|0)|0;l=G;u=wrc(z,l,-2147483648,0)|0;s=G;i=0;if(s>>>0>i>>>0|s>>>0==i>>>0&u>>>0>-1>>>0){((l|0)<0|0?-1:0)>>31|((l|0)<0|0?-1:0)<<1;C=(l>>31|((l|0)<0|0?-1:0)<<1)^2147483647}else{C=z}c[a+(j<<2)>>2]=r-C;m=m+2|0;}while((m|0)<(d|0));return};case 5:{if((d|0)<=5){return}m=f+16|0;C=f+12|0;A=f+8|0;B=f+4|0;o=g;r=5;do{j=c[b+(r-5<<2)>>2]|0;z=c[m>>2]|0;l=z;u=(z|0)<0|0?-1:0;z=Erc(l,u,j,(j|0)<0|0?-1:0)|0;j=G;i=c[b+(r-4<<2)>>2]|0;s=i;n=(i|0)<0|0?-1:0;i=Erc(s,n,l,u)|0;u=G;l=c[C>>2]|0;h=l;t=(l|0)<0|0?-1:0;l=Erc(h,t,s,n)|0;n=wrc(l,G,z,j)|0;j=G;z=c[b+(r-3<<2)>>2]|0;l=z;s=(z|0)<0|0?-1:0;z=Erc(l,s,h,t)|0;t=wrc(z,G,i,u)|0;u=G;i=c[A>>2]|0;z=i;h=(i|0)<0|0?-1:0;i=Erc(z,h,l,s)|0;s=wrc(n,j,i,G)|0;i=G;j=c[b+(r-2<<2)>>2]|0;n=j;l=(j|0)<0|0?-1:0;j=Erc(n,l,z,h)|0;h=wrc(t,u,j,G)|0;j=G;u=c[B>>2]|0;t=u;z=(u|0)<0|0?-1:0;u=Erc(t,z,n,l)|0;l=wrc(s,i,u,G)|0;u=G;i=c[b+(r-1<<2)>>2]|0;s=i;n=(i|0)<0|0?-1:0;i=Erc(s,n,t,z)|0;z=wrc(h,j,i,G)|0;i=G;j=c[f>>2]|0;h=j;t=(j|0)<0|0?-1:0;j=Erc(h,t,s,n)|0;n=wrc(l,u,j,G)|0;j=G;u=c[b+(r<<2)>>2]|0;l=Erc(u,(u|0)<0|0?-1:0,h,t)|0;t=wrc(z,i,l,G)|0;l=G;i=Arc(n|0,j|0,o|0)|0;j=G;n=wrc(i,j,-2147483648,0)|0;z=G;h=0;if(z>>>0>h>>>0|z>>>0==h>>>0&n>>>0>-1>>>0){((j|0)<0|0?-1:0)>>31|((j|0)<0|0?-1:0)<<1;D=(j>>31|((j|0)<0|0?-1:0)<<1)^2147483647}else{D=i}c[a+(r<<2)>>2]=u-D;u=r+1|0;i=c[b+(u<<2)>>2]|0;j=Arc(t|0,l|0,o|0)|0;l=G;t=wrc(j,l,-2147483648,0)|0;n=G;h=0;if(n>>>0>h>>>0|n>>>0==h>>>0&t>>>0>-1>>>0){((l|0)<0|0?-1:0)>>31|((l|0)<0|0?-1:0)<<1;E=(l>>31|((l|0)<0|0?-1:0)<<1)^2147483647}else{E=j}c[a+(u<<2)>>2]=i-E;r=r+2|0;}while((r|0)<(d|0));return};case 7:{if((d|0)<=7){return}r=f+24|0;E=f+20|0;o=f+16|0;D=f+12|0;B=f+8|0;A=f+4|0;C=g;m=7;do{i=c[b+(m-7<<2)>>2]|0;u=c[r>>2]|0;j=u;l=(u|0)<0|0?-1:0;u=Erc(j,l,i,(i|0)<0|0?-1:0)|0;i=G;t=c[b+(m-6<<2)>>2]|0;h=t;n=(t|0)<0|0?-1:0;t=Erc(h,n,j,l)|0;l=G;j=c[E>>2]|0;z=j;s=(j|0)<0|0?-1:0;j=Erc(z,s,h,n)|0;n=wrc(j,G,u,i)|0;i=G;u=c[b+(m-5<<2)>>2]|0;j=u;h=(u|0)<0|0?-1:0;u=Erc(j,h,z,s)|0;s=wrc(u,G,t,l)|0;l=G;t=c[o>>2]|0;u=t;z=(t|0)<0|0?-1:0;t=Erc(u,z,j,h)|0;h=wrc(n,i,t,G)|0;t=G;i=c[b+(m-4<<2)>>2]|0;n=i;j=(i|0)<0|0?-1:0;i=Erc(n,j,u,z)|0;z=wrc(s,l,i,G)|0;i=G;l=c[D>>2]|0;s=l;u=(l|0)<0|0?-1:0;l=Erc(s,u,n,j)|0;j=wrc(h,t,l,G)|0;l=G;t=c[b+(m-3<<2)>>2]|0;h=t;n=(t|0)<0|0?-1:0;t=Erc(h,n,s,u)|0;u=wrc(z,i,t,G)|0;t=G;i=c[B>>2]|0;z=i;s=(i|0)<0|0?-1:0;i=Erc(z,s,h,n)|0;n=wrc(j,l,i,G)|0;i=G;l=c[b+(m-2<<2)>>2]|0;j=l;h=(l|0)<0|0?-1:0;l=Erc(j,h,z,s)|0;s=wrc(u,t,l,G)|0;l=G;t=c[A>>2]|0;u=t;z=(t|0)<0|0?-1:0;t=Erc(u,z,j,h)|0;h=wrc(n,i,t,G)|0;t=G;i=c[b+(m-1<<2)>>2]|0;n=i;j=(i|0)<0|0?-1:0;i=Erc(n,j,u,z)|0;z=wrc(s,l,i,G)|0;i=G;l=c[f>>2]|0;s=l;u=(l|0)<0|0?-1:0;l=Erc(s,u,n,j)|0;j=wrc(h,t,l,G)|0;l=G;t=c[b+(m<<2)>>2]|0;h=Erc(t,(t|0)<0|0?-1:0,s,u)|0;u=wrc(z,i,h,G)|0;h=G;i=Arc(j|0,l|0,C|0)|0;l=G;j=wrc(i,l,-2147483648,0)|0;z=G;s=0;if(z>>>0>s>>>0|z>>>0==s>>>0&j>>>0>-1>>>0){((l|0)<0|0?-1:0)>>31|((l|0)<0|0?-1:0)<<1;F=(l>>31|((l|0)<0|0?-1:0)<<1)^2147483647}else{F=i}c[a+(m<<2)>>2]=t-F;t=m+1|0;i=c[b+(t<<2)>>2]|0;l=Arc(u|0,h|0,C|0)|0;h=G;u=wrc(l,h,-2147483648,0)|0;j=G;s=0;if(j>>>0>s>>>0|j>>>0==s>>>0&u>>>0>-1>>>0){((h|0)<0|0?-1:0)>>31|((h|0)<0|0?-1:0)<<1;H=(h>>31|((h|0)<0|0?-1:0)<<1)^2147483647}else{H=l}c[a+(t<<2)>>2]=i-H;m=m+2|0;}while((m|0)<(d|0));return};case 3:{if((d|0)<=3){return}m=f+8|0;H=f+4|0;C=g;F=3;do{A=c[b+(F-3<<2)>>2]|0;B=c[m>>2]|0;D=B;o=(B|0)<0|0?-1:0;B=Erc(D,o,A,(A|0)<0|0?-1:0)|0;A=G;E=c[b+(F-2<<2)>>2]|0;r=E;i=(E|0)<0|0?-1:0;E=Erc(r,i,D,o)|0;o=G;D=c[H>>2]|0;t=D;l=(D|0)<0|0?-1:0;D=Erc(t,l,r,i)|0;i=wrc(D,G,B,A)|0;A=G;B=c[b+(F-1<<2)>>2]|0;D=B;r=(B|0)<0|0?-1:0;B=Erc(D,r,t,l)|0;l=wrc(B,G,E,o)|0;o=G;E=c[f>>2]|0;B=E;t=(E|0)<0|0?-1:0;E=Erc(B,t,D,r)|0;r=wrc(i,A,E,G)|0;E=G;A=c[b+(F<<2)>>2]|0;i=Erc(A,(A|0)<0|0?-1:0,B,t)|0;t=wrc(l,o,i,G)|0;i=G;o=Arc(r|0,E|0,C|0)|0;E=G;r=wrc(o,E,-2147483648,0)|0;l=G;B=0;if(l>>>0>B>>>0|l>>>0==B>>>0&r>>>0>-1>>>0){((E|0)<0|0?-1:0)>>31|((E|0)<0|0?-1:0)<<1;I=(E>>31|((E|0)<0|0?-1:0)<<1)^2147483647}else{I=o}c[a+(F<<2)>>2]=A-I;A=F+1|0;o=c[b+(A<<2)>>2]|0;E=Arc(t|0,i|0,C|0)|0;i=G;t=wrc(E,i,-2147483648,0)|0;r=G;B=0;if(r>>>0>B>>>0|r>>>0==B>>>0&t>>>0>-1>>>0){((i|0)<0|0?-1:0)>>31|((i|0)<0|0?-1:0)<<1;J=(i>>31|((i|0)<0|0?-1:0)<<1)^2147483647}else{J=E}c[a+(A<<2)>>2]=o-J;F=F+2|0;}while((F|0)<(d|0));return};case 6:{if((d|0)<=6){return}F=f+20|0;J=f+16|0;C=f+12|0;I=f+8|0;H=f+4|0;m=g;o=6;do{A=c[b+(o-6<<2)>>2]|0;E=c[F>>2]|0;i=E;t=(E|0)<0|0?-1:0;E=Erc(i,t,A,(A|0)<0|0?-1:0)|0;A=G;B=c[b+(o-5<<2)>>2]|0;r=B;l=(B|0)<0|0?-1:0;B=Erc(r,l,i,t)|0;t=G;i=c[J>>2]|0;D=i;h=(i|0)<0|0?-1:0;i=Erc(D,h,r,l)|0;l=wrc(i,G,E,A)|0;A=G;E=c[b+(o-4<<2)>>2]|0;i=E;r=(E|0)<0|0?-1:0;E=Erc(i,r,D,h)|0;h=wrc(E,G,B,t)|0;t=G;B=c[C>>2]|0;E=B;D=(B|0)<0|0?-1:0;B=Erc(E,D,i,r)|0;r=wrc(l,A,B,G)|0;B=G;A=c[b+(o-3<<2)>>2]|0;l=A;i=(A|0)<0|0?-1:0;A=Erc(l,i,E,D)|0;D=wrc(h,t,A,G)|0;A=G;t=c[I>>2]|0;h=t;E=(t|0)<0|0?-1:0;t=Erc(h,E,l,i)|0;i=wrc(r,B,t,G)|0;t=G;B=c[b+(o-2<<2)>>2]|0;r=B;l=(B|0)<0|0?-1:0;B=Erc(r,l,h,E)|0;E=wrc(D,A,B,G)|0;B=G;A=c[H>>2]|0;D=A;h=(A|0)<0|0?-1:0;A=Erc(D,h,r,l)|0;l=wrc(i,t,A,G)|0;A=G;t=c[b+(o-1<<2)>>2]|0;i=t;r=(t|0)<0|0?-1:0;t=Erc(i,r,D,h)|0;h=wrc(E,B,t,G)|0;t=G;B=c[f>>2]|0;E=B;D=(B|0)<0|0?-1:0;B=Erc(E,D,i,r)|0;r=wrc(l,A,B,G)|0;B=G;A=c[b+(o<<2)>>2]|0;l=Erc(A,(A|0)<0|0?-1:0,E,D)|0;D=wrc(h,t,l,G)|0;l=G;t=Arc(r|0,B|0,m|0)|0;B=G;r=wrc(t,B,-2147483648,0)|0;h=G;E=0;if(h>>>0>E>>>0|h>>>0==E>>>0&r>>>0>-1>>>0){((B|0)<0|0?-1:0)>>31|((B|0)<0|0?-1:0)<<1;K=(B>>31|((B|0)<0|0?-1:0)<<1)^2147483647}else{K=t}c[a+(o<<2)>>2]=A-K;A=o|1;t=c[b+(A<<2)>>2]|0;B=Arc(D|0,l|0,m|0)|0;l=G;D=wrc(B,l,-2147483648,0)|0;r=G;E=0;if(r>>>0>E>>>0|r>>>0==E>>>0&D>>>0>-1>>>0){((l|0)<0|0?-1:0)>>31|((l|0)<0|0?-1:0)<<1;L=(l>>31|((l|0)<0|0?-1:0)<<1)^2147483647}else{L=B}c[a+(A<<2)>>2]=t-L;o=o+2|0;}while((o|0)<(d|0));return};case 4:{if((d|0)<=4){return}o=f+12|0;L=f+8|0;m=f+4|0;K=g;H=4;do{I=c[b+(H-4<<2)>>2]|0;C=c[o>>2]|0;J=C;F=(C|0)<0|0?-1:0;C=Erc(J,F,I,(I|0)<0|0?-1:0)|0;I=G;t=c[b+(H-3<<2)>>2]|0;A=t;B=(t|0)<0|0?-1:0;t=Erc(A,B,J,F)|0;F=G;J=c[L>>2]|0;l=J;D=(J|0)<0|0?-1:0;J=Erc(l,D,A,B)|0;B=wrc(J,G,C,I)|0;I=G;C=c[b+(H-2<<2)>>2]|0;J=C;A=(C|0)<0|0?-1:0;C=Erc(J,A,l,D)|0;D=wrc(C,G,t,F)|0;F=G;t=c[m>>2]|0;C=t;l=(t|0)<0|0?-1:0;t=Erc(C,l,J,A)|0;A=wrc(B,I,t,G)|0;t=G;I=c[b+(H-1<<2)>>2]|0;B=I;J=(I|0)<0|0?-1:0;I=Erc(B,J,C,l)|0;l=wrc(D,F,I,G)|0;I=G;F=c[f>>2]|0;D=F;C=(F|0)<0|0?-1:0;F=Erc(D,C,B,J)|0;J=wrc(A,t,F,G)|0;F=G;t=c[b+(H<<2)>>2]|0;A=Erc(t,(t|0)<0|0?-1:0,D,C)|0;C=wrc(l,I,A,G)|0;A=G;I=Arc(J|0,F|0,K|0)|0;F=G;J=wrc(I,F,-2147483648,0)|0;l=G;D=0;if(l>>>0>D>>>0|l>>>0==D>>>0&J>>>0>-1>>>0){((F|0)<0|0?-1:0)>>31|((F|0)<0|0?-1:0)<<1;M=(F>>31|((F|0)<0|0?-1:0)<<1)^2147483647}else{M=I}c[a+(H<<2)>>2]=t-M;t=H|1;I=c[b+(t<<2)>>2]|0;F=Arc(C|0,A|0,K|0)|0;A=G;C=wrc(F,A,-2147483648,0)|0;J=G;D=0;if(J>>>0>D>>>0|J>>>0==D>>>0&C>>>0>-1>>>0){((A|0)<0|0?-1:0)>>31|((A|0)<0|0?-1:0)<<1;N=(A>>31|((A|0)<0|0?-1:0)<<1)^2147483647}else{N=F}c[a+(t<<2)>>2]=I-N;H=H+2|0;}while((H|0)<(d|0));return};default:{if((e|0)>=(d|0)){return}H=f+28|0;N=f+24|0;K=f+20|0;M=f+16|0;m=f+12|0;L=f+8|0;o=f+4|0;I=g;g=f+124|0;t=f+120|0;F=f+116|0;A=f+112|0;C=f+108|0;D=f+104|0;J=f+100|0;l=f+96|0;B=f+92|0;E=f+88|0;r=f+84|0;h=f+80|0;i=f+76|0;u=f+72|0;s=f+68|0;j=f+64|0;z=f+60|0;n=f+56|0;q=f+52|0;p=f+48|0;y=f+44|0;x=f+40|0;w=f+36|0;k=f+32|0;v=e;do{O=c[b+(v-e<<2)>>2]|0;switch(e|0){case 9:{P=O;Q=0;R=0;S=0;T=0;U=87;break};case 17:{V=O;W=0;X=0;Y=0;Z=0;U=79;break};case 16:{_=O;$=0;aa=0;ba=0;ca=0;U=80;break};case 32:{da=c[g>>2]|0;ea=da;fa=(da|0)<0|0?-1:0;da=Erc(ea,fa,O,(O|0)<0|0?-1:0)|0;ga=G;ha=c[b+(v-31<<2)>>2]|0;ia=Erc(ha,(ha|0)<0|0?-1:0,ea,fa)|0;ja=ha;ka=ga;la=da;ma=G;na=ia;U=65;break};case 22:{oa=O;pa=0;qa=0;ra=0;sa=0;U=74;break};case 30:{ta=O;ua=0;va=0;wa=0;xa=0;U=66;break};case 24:{ya=O;za=0;Aa=0;Ba=0;Ca=0;U=72;break};case 29:{Da=O;Ea=0;Fa=0;Ga=0;Ha=0;U=67;break};case 15:{Ia=O;Ja=0;Ka=0;La=0;Ma=0;U=81;break};case 14:{Na=O;Oa=0;Pa=0;Qa=0;Ra=0;U=82;break};case 31:{ja=O;ka=0;la=0;ma=0;na=0;U=65;break};case 11:{Sa=O;Ta=0;Ua=0;Va=0;Wa=0;U=85;break};case 10:{Xa=O;Ya=0;Za=0;_a=0;$a=0;U=86;break};case 13:{ab=O;bb=0;cb=0;db=0;eb=0;U=83;break};case 12:{fb=O;gb=0;hb=0;ib=0;jb=0;U=84;break};case 21:{kb=O;lb=0;mb=0;nb=0;ob=0;U=75;break};case 20:{pb=O;qb=0;rb=0;sb=0;tb=0;U=76;break};case 28:{ub=O;vb=0;wb=0;xb=0;yb=0;U=68;break};case 25:{zb=O;Ab=0;Bb=0;Cb=0;Db=0;U=71;break};case 27:{Eb=O;Fb=0;Gb=0;Hb=0;Ib=0;U=69;break};case 23:{Jb=O;Kb=0;Lb=0;Mb=0;Nb=0;U=73;break};case 26:{Ob=O;Pb=0;Qb=0;Rb=0;Sb=0;U=70;break};case 19:{Tb=O;Ub=0;Vb=0;Wb=0;Xb=0;U=77;break};case 18:{Yb=O;Zb=0;_b=0;$b=0;ac=0;U=78;break};default:{bc=0;cc=0;dc=0;ec=0;fc=c[b+(v<<2)>>2]|0}}if((U|0)==65){U=0;O=c[t>>2]|0;ia=O;da=(O|0)<0|0?-1:0;O=Erc(ia,da,ja,(ja|0)<0|0?-1:0)|0;ga=wrc(O,G,la,ka)|0;O=G;ha=c[b+(v-30<<2)>>2]|0;fa=Erc(ha,(ha|0)<0|0?-1:0,ia,da)|0;da=wrc(fa,G,na,ma)|0;ta=ha;ua=O;va=ga;wa=G;xa=da;U=66}if((U|0)==66){U=0;da=c[F>>2]|0;ga=da;O=(da|0)<0|0?-1:0;da=Erc(ga,O,ta,(ta|0)<0|0?-1:0)|0;ha=wrc(da,G,va,ua)|0;da=G;fa=c[b+(v-29<<2)>>2]|0;ia=Erc(fa,(fa|0)<0|0?-1:0,ga,O)|0;O=wrc(ia,G,xa,wa)|0;Da=fa;Ea=da;Fa=ha;Ga=G;Ha=O;U=67}if((U|0)==67){U=0;O=c[A>>2]|0;ha=O;da=(O|0)<0|0?-1:0;O=Erc(ha,da,Da,(Da|0)<0|0?-1:0)|0;fa=wrc(O,G,Fa,Ea)|0;O=G;ia=c[b+(v-28<<2)>>2]|0;ga=Erc(ia,(ia|0)<0|0?-1:0,ha,da)|0;da=wrc(ga,G,Ha,Ga)|0;ub=ia;vb=O;wb=fa;xb=G;yb=da;U=68}if((U|0)==68){U=0;da=c[C>>2]|0;fa=da;O=(da|0)<0|0?-1:0;da=Erc(fa,O,ub,(ub|0)<0|0?-1:0)|0;ia=wrc(da,G,wb,vb)|0;da=G;ga=c[b+(v-27<<2)>>2]|0;ha=Erc(ga,(ga|0)<0|0?-1:0,fa,O)|0;O=wrc(ha,G,yb,xb)|0;Eb=ga;Fb=da;Gb=ia;Hb=G;Ib=O;U=69}if((U|0)==69){U=0;O=c[D>>2]|0;ia=O;da=(O|0)<0|0?-1:0;O=Erc(ia,da,Eb,(Eb|0)<0|0?-1:0)|0;ga=wrc(O,G,Gb,Fb)|0;O=G;ha=c[b+(v-26<<2)>>2]|0;fa=Erc(ha,(ha|0)<0|0?-1:0,ia,da)|0;da=wrc(fa,G,Ib,Hb)|0;Ob=ha;Pb=O;Qb=ga;Rb=G;Sb=da;U=70}if((U|0)==70){U=0;da=c[J>>2]|0;ga=da;O=(da|0)<0|0?-1:0;da=Erc(ga,O,Ob,(Ob|0)<0|0?-1:0)|0;ha=wrc(da,G,Qb,Pb)|0;da=G;fa=c[b+(v-25<<2)>>2]|0;ia=Erc(fa,(fa|0)<0|0?-1:0,ga,O)|0;O=wrc(ia,G,Sb,Rb)|0;zb=fa;Ab=da;Bb=ha;Cb=G;Db=O;U=71}if((U|0)==71){U=0;O=c[l>>2]|0;ha=O;da=(O|0)<0|0?-1:0;O=Erc(ha,da,zb,(zb|0)<0|0?-1:0)|0;fa=wrc(O,G,Bb,Ab)|0;O=G;ia=c[b+(v-24<<2)>>2]|0;ga=Erc(ia,(ia|0)<0|0?-1:0,ha,da)|0;da=wrc(ga,G,Db,Cb)|0;ya=ia;za=O;Aa=fa;Ba=G;Ca=da;U=72}if((U|0)==72){U=0;da=c[B>>2]|0;fa=da;O=(da|0)<0|0?-1:0;da=Erc(fa,O,ya,(ya|0)<0|0?-1:0)|0;ia=wrc(da,G,Aa,za)|0;da=G;ga=c[b+(v-23<<2)>>2]|0;ha=Erc(ga,(ga|0)<0|0?-1:0,fa,O)|0;O=wrc(ha,G,Ca,Ba)|0;Jb=ga;Kb=da;Lb=ia;Mb=G;Nb=O;U=73}if((U|0)==73){U=0;O=c[E>>2]|0;ia=O;da=(O|0)<0|0?-1:0;O=Erc(ia,da,Jb,(Jb|0)<0|0?-1:0)|0;ga=wrc(O,G,Lb,Kb)|0;O=G;ha=c[b+(v-22<<2)>>2]|0;fa=Erc(ha,(ha|0)<0|0?-1:0,ia,da)|0;da=wrc(fa,G,Nb,Mb)|0;oa=ha;pa=O;qa=ga;ra=G;sa=da;U=74}if((U|0)==74){U=0;da=c[r>>2]|0;ga=da;O=(da|0)<0|0?-1:0;da=Erc(ga,O,oa,(oa|0)<0|0?-1:0)|0;ha=wrc(da,G,qa,pa)|0;da=G;fa=c[b+(v-21<<2)>>2]|0;ia=Erc(fa,(fa|0)<0|0?-1:0,ga,O)|0;O=wrc(ia,G,sa,ra)|0;kb=fa;lb=da;mb=ha;nb=G;ob=O;U=75}if((U|0)==75){U=0;O=c[h>>2]|0;ha=O;da=(O|0)<0|0?-1:0;O=Erc(ha,da,kb,(kb|0)<0|0?-1:0)|0;fa=wrc(O,G,mb,lb)|0;O=G;ia=c[b+(v-20<<2)>>2]|0;ga=Erc(ia,(ia|0)<0|0?-1:0,ha,da)|0;da=wrc(ga,G,ob,nb)|0;pb=ia;qb=O;rb=fa;sb=G;tb=da;U=76}if((U|0)==76){U=0;da=c[i>>2]|0;fa=da;O=(da|0)<0|0?-1:0;da=Erc(fa,O,pb,(pb|0)<0|0?-1:0)|0;ia=wrc(da,G,rb,qb)|0;da=G;ga=c[b+(v-19<<2)>>2]|0;ha=Erc(ga,(ga|0)<0|0?-1:0,fa,O)|0;O=wrc(ha,G,tb,sb)|0;Tb=ga;Ub=da;Vb=ia;Wb=G;Xb=O;U=77}if((U|0)==77){U=0;O=c[u>>2]|0;ia=O;da=(O|0)<0|0?-1:0;O=Erc(ia,da,Tb,(Tb|0)<0|0?-1:0)|0;ga=wrc(O,G,Vb,Ub)|0;O=G;ha=c[b+(v-18<<2)>>2]|0;fa=Erc(ha,(ha|0)<0|0?-1:0,ia,da)|0;da=wrc(fa,G,Xb,Wb)|0;Yb=ha;Zb=O;_b=ga;$b=G;ac=da;U=78}if((U|0)==78){U=0;da=c[s>>2]|0;ga=da;O=(da|0)<0|0?-1:0;da=Erc(ga,O,Yb,(Yb|0)<0|0?-1:0)|0;ha=wrc(da,G,_b,Zb)|0;da=G;fa=c[b+(v-17<<2)>>2]|0;ia=Erc(fa,(fa|0)<0|0?-1:0,ga,O)|0;O=wrc(ia,G,ac,$b)|0;V=fa;W=da;X=ha;Y=G;Z=O;U=79}if((U|0)==79){U=0;O=c[j>>2]|0;ha=O;da=(O|0)<0|0?-1:0;O=Erc(ha,da,V,(V|0)<0|0?-1:0)|0;fa=wrc(O,G,X,W)|0;O=G;ia=c[b+(v-16<<2)>>2]|0;ga=Erc(ia,(ia|0)<0|0?-1:0,ha,da)|0;da=wrc(ga,G,Z,Y)|0;_=ia;$=O;aa=fa;ba=G;ca=da;U=80}if((U|0)==80){U=0;da=c[z>>2]|0;fa=da;O=(da|0)<0|0?-1:0;da=Erc(fa,O,_,(_|0)<0|0?-1:0)|0;ia=wrc(da,G,aa,$)|0;da=G;ga=c[b+(v-15<<2)>>2]|0;ha=Erc(ga,(ga|0)<0|0?-1:0,fa,O)|0;O=wrc(ha,G,ca,ba)|0;Ia=ga;Ja=da;Ka=ia;La=G;Ma=O;U=81}if((U|0)==81){U=0;O=c[n>>2]|0;ia=O;da=(O|0)<0|0?-1:0;O=Erc(ia,da,Ia,(Ia|0)<0|0?-1:0)|0;ga=wrc(O,G,Ka,Ja)|0;O=G;ha=c[b+(v-14<<2)>>2]|0;fa=Erc(ha,(ha|0)<0|0?-1:0,ia,da)|0;da=wrc(fa,G,Ma,La)|0;Na=ha;Oa=O;Pa=ga;Qa=G;Ra=da;U=82}if((U|0)==82){U=0;da=c[q>>2]|0;ga=da;O=(da|0)<0|0?-1:0;da=Erc(ga,O,Na,(Na|0)<0|0?-1:0)|0;ha=wrc(da,G,Pa,Oa)|0;da=G;fa=c[b+(v-13<<2)>>2]|0;ia=Erc(fa,(fa|0)<0|0?-1:0,ga,O)|0;O=wrc(ia,G,Ra,Qa)|0;ab=fa;bb=da;cb=ha;db=G;eb=O;U=83}if((U|0)==83){U=0;O=c[p>>2]|0;ha=O;da=(O|0)<0|0?-1:0;O=Erc(ha,da,ab,(ab|0)<0|0?-1:0)|0;fa=wrc(O,G,cb,bb)|0;O=G;ia=c[b+(v-12<<2)>>2]|0;ga=Erc(ia,(ia|0)<0|0?-1:0,ha,da)|0;da=wrc(ga,G,eb,db)|0;fb=ia;gb=O;hb=fa;ib=G;jb=da;U=84}if((U|0)==84){U=0;da=c[y>>2]|0;fa=da;O=(da|0)<0|0?-1:0;da=Erc(fa,O,fb,(fb|0)<0|0?-1:0)|0;ia=wrc(da,G,hb,gb)|0;da=G;ga=c[b+(v-11<<2)>>2]|0;ha=Erc(ga,(ga|0)<0|0?-1:0,fa,O)|0;O=wrc(ha,G,jb,ib)|0;Sa=ga;Ta=da;Ua=ia;Va=G;Wa=O;U=85}if((U|0)==85){U=0;O=c[x>>2]|0;ia=O;da=(O|0)<0|0?-1:0;O=Erc(ia,da,Sa,(Sa|0)<0|0?-1:0)|0;ga=wrc(O,G,Ua,Ta)|0;O=G;ha=c[b+(v-10<<2)>>2]|0;fa=Erc(ha,(ha|0)<0|0?-1:0,ia,da)|0;da=wrc(fa,G,Wa,Va)|0;Xa=ha;Ya=O;Za=ga;_a=G;$a=da;U=86}if((U|0)==86){U=0;da=c[w>>2]|0;ga=da;O=(da|0)<0|0?-1:0;da=Erc(ga,O,Xa,(Xa|0)<0|0?-1:0)|0;ha=wrc(da,G,Za,Ya)|0;da=G;fa=c[b+(v-9<<2)>>2]|0;ia=Erc(fa,(fa|0)<0|0?-1:0,ga,O)|0;O=wrc(ia,G,$a,_a)|0;P=fa;Q=da;R=ha;S=G;T=O;U=87}if((U|0)==87){U=0;O=c[k>>2]|0;ha=O;da=(O|0)<0|0?-1:0;O=Erc(ha,da,P,(P|0)<0|0?-1:0)|0;fa=wrc(O,G,R,Q)|0;O=G;ia=c[b+(v-8<<2)>>2]|0;ga=ia;ea=(ia|0)<0|0?-1:0;ia=Erc(ga,ea,ha,da)|0;da=wrc(ia,G,T,S)|0;ia=G;ha=c[H>>2]|0;gc=ha;hc=(ha|0)<0|0?-1:0;ha=Erc(gc,hc,ga,ea)|0;ea=wrc(fa,O,ha,G)|0;ha=G;O=c[b+(v-7<<2)>>2]|0;fa=O;ga=(O|0)<0|0?-1:0;O=Erc(fa,ga,gc,hc)|0;hc=wrc(da,ia,O,G)|0;O=G;ia=c[N>>2]|0;da=ia;gc=(ia|0)<0|0?-1:0;ia=Erc(da,gc,fa,ga)|0;ga=wrc(ea,ha,ia,G)|0;ia=G;ha=c[b+(v-6<<2)>>2]|0;ea=ha;fa=(ha|0)<0|0?-1:0;ha=Erc(ea,fa,da,gc)|0;gc=wrc(hc,O,ha,G)|0;ha=G;O=c[K>>2]|0;hc=O;da=(O|0)<0|0?-1:0;O=Erc(hc,da,ea,fa)|0;fa=wrc(ga,ia,O,G)|0;O=G;ia=c[b+(v-5<<2)>>2]|0;ga=ia;ea=(ia|0)<0|0?-1:0;ia=Erc(ga,ea,hc,da)|0;da=wrc(gc,ha,ia,G)|0;ia=G;ha=c[M>>2]|0;gc=ha;hc=(ha|0)<0|0?-1:0;ha=Erc(gc,hc,ga,ea)|0;ea=wrc(fa,O,ha,G)|0;ha=G;O=c[b+(v-4<<2)>>2]|0;fa=O;ga=(O|0)<0|0?-1:0;O=Erc(fa,ga,gc,hc)|0;hc=wrc(da,ia,O,G)|0;O=G;ia=c[m>>2]|0;da=ia;gc=(ia|0)<0|0?-1:0;ia=Erc(da,gc,fa,ga)|0;ga=wrc(ea,ha,ia,G)|0;ia=G;ha=c[b+(v-3<<2)>>2]|0;ea=ha;fa=(ha|0)<0|0?-1:0;ha=Erc(ea,fa,da,gc)|0;gc=wrc(hc,O,ha,G)|0;ha=G;O=c[L>>2]|0;hc=O;da=(O|0)<0|0?-1:0;O=Erc(hc,da,ea,fa)|0;fa=wrc(ga,ia,O,G)|0;O=G;ia=c[b+(v-2<<2)>>2]|0;ga=ia;ea=(ia|0)<0|0?-1:0;ia=Erc(ga,ea,hc,da)|0;da=wrc(gc,ha,ia,G)|0;ia=G;ha=c[o>>2]|0;gc=ha;hc=(ha|0)<0|0?-1:0;ha=Erc(gc,hc,ga,ea)|0;ea=wrc(fa,O,ha,G)|0;ha=G;O=c[b+(v-1<<2)>>2]|0;fa=O;ga=(O|0)<0|0?-1:0;O=Erc(fa,ga,gc,hc)|0;hc=wrc(da,ia,O,G)|0;O=G;ia=c[f>>2]|0;da=ia;gc=(ia|0)<0|0?-1:0;ia=Erc(da,gc,fa,ga)|0;ga=wrc(ea,ha,ia,G)|0;ia=G;ha=c[b+(v<<2)>>2]|0;ea=Erc(ha,(ha|0)<0|0?-1:0,da,gc)|0;gc=wrc(hc,O,ea,G)|0;bc=ia;cc=ga;dc=G;ec=gc;fc=ha}ha=Arc(cc|0,bc|0,I|0)|0;gc=G;ga=wrc(ha,gc,-2147483648,0)|0;ia=G;ea=0;if(ia>>>0>ea>>>0|ia>>>0==ea>>>0&ga>>>0>-1>>>0){((gc|0)<0|0?-1:0)>>31|((gc|0)<0|0?-1:0)<<1;ic=(gc>>31|((gc|0)<0|0?-1:0)<<1)^2147483647}else{ic=ha}c[a+(v<<2)>>2]=fc-ic;ha=v+1|0;gc=c[b+(ha<<2)>>2]|0;ga=Arc(ec|0,dc|0,I|0)|0;ea=G;ia=wrc(ga,ea,-2147483648,0)|0;O=G;hc=0;if(O>>>0>hc>>>0|O>>>0==hc>>>0&ia>>>0>-1>>>0){((ea|0)<0|0?-1:0)>>31|((ea|0)<0|0?-1:0)<<1;jc=(ea>>31|((ea|0)<0|0?-1:0)<<1)^2147483647}else{jc=ga}c[a+(ha<<2)>>2]=gc-jc;v=v+2|0;}while((v|0)<(d|0));return}}}function Fea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=f-1|0;a:do{if((g|0)>(d|0)){if((d|0)>1){h=a;i=d}else{j=a;k=d;l=c[a>>2]|0;while(1){m=c[b>>2]|0;n=(ca(m,l)|0)>>e;o=j+4|0;p=(c[o>>2]|0)+n|0;c[o>>2]=p;o=(ca(p,m)|0)>>e;m=j+8|0;p=o+(c[m>>2]|0)|0;c[m>>2]=p;o=k+2|0;if((o|0)<(g|0)){j=m;k=o;l=p}else{q=m;r=o;break a}}}while(1){l=c[b>>2]|0;k=1;j=0;o=l;m=ca(l,c[h>>2]|0)|0;while(1){l=c[h+(k<<2)>>2]|0;s=(ca(l,o)|0)+j|0;p=k+1|0;t=c[b+(k<<2)>>2]|0;u=(ca(t,l)|0)+m|0;if((p|0)<(d|0)){k=p;j=s;o=t;m=u}else{break}}m=h+(d<<2)|0;o=(c[m>>2]|0)+(u>>e)|0;c[m>>2]=o;m=(ca(o,t)|0)+s>>e;o=h+(d+1<<2)|0;c[o>>2]=m+(c[o>>2]|0);o=i+2|0;m=h+8|0;if((o|0)<(g|0)){h=m;i=o}else{q=m;r=o;break}}}else{q=a;r=d}}while(0);if((r|0)>=(f|0)){return}if((d|0)>0){f=0;r=0;while(1){a=(ca(c[q+(f<<2)>>2]|0,c[b+(f<<2)>>2]|0)|0)+r|0;i=f+1|0;if((i|0)<(d|0)){f=i;r=a}else{v=d;w=a;break}}}else{v=0;w=0}d=q+(v<<2)|0;c[d>>2]=(c[d>>2]|0)+(w>>e);return}function Gea(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0;if((e|0)>0){h=0;do{c[a+(h<<2)>>2]=c[b+(h<<2)>>2];h=h+1|0;}while((h|0)<(e|0))}switch(e|0){case 1:{if((d|0)>1){i=1}else{return}do{h=c[f>>2]|0;j=ca(h,c[b+(i-1<<2)>>2]|0)|0;k=c[b+(i<<2)>>2]|0;l=ca(k,h)|0;c[a+(i<<2)>>2]=k-(j>>g);j=i+1|0;c[a+(j<<2)>>2]=(c[b+(j<<2)>>2]|0)-(l>>g);i=i+2|0;}while((i|0)<(d|0));return};case 3:{if((d|0)<=3){return}i=f+8|0;l=f+4|0;j=3;do{k=c[i>>2]|0;h=ca(k,c[b+(j-3<<2)>>2]|0)|0;m=c[b+(j-2<<2)>>2]|0;n=ca(m,k)|0;k=c[l>>2]|0;o=(ca(k,m)|0)+h|0;h=c[b+(j-1<<2)>>2]|0;m=(ca(h,k)|0)+n|0;n=c[f>>2]|0;k=o+(ca(n,h)|0)|0;h=c[b+(j<<2)>>2]|0;o=m+(ca(h,n)|0)|0;c[a+(j<<2)>>2]=h-(k>>g);k=j+1|0;c[a+(k<<2)>>2]=(c[b+(k<<2)>>2]|0)-(o>>g);j=j+2|0;}while((j|0)<(d|0));return};case 7:{if((d|0)<=7){return}j=f+24|0;l=f+20|0;i=f+16|0;o=f+12|0;k=f+8|0;h=f+4|0;n=7;do{m=c[j>>2]|0;p=ca(m,c[b+(n-7<<2)>>2]|0)|0;q=c[b+(n-6<<2)>>2]|0;r=ca(q,m)|0;m=c[l>>2]|0;s=(ca(m,q)|0)+p|0;p=c[b+(n-5<<2)>>2]|0;q=(ca(p,m)|0)+r|0;r=c[i>>2]|0;m=s+(ca(r,p)|0)|0;p=c[b+(n-4<<2)>>2]|0;s=q+(ca(p,r)|0)|0;r=c[o>>2]|0;q=m+(ca(r,p)|0)|0;p=c[b+(n-3<<2)>>2]|0;m=s+(ca(p,r)|0)|0;r=c[k>>2]|0;s=q+(ca(r,p)|0)|0;p=c[b+(n-2<<2)>>2]|0;q=m+(ca(p,r)|0)|0;r=c[h>>2]|0;m=s+(ca(r,p)|0)|0;p=c[b+(n-1<<2)>>2]|0;s=q+(ca(p,r)|0)|0;r=c[f>>2]|0;q=m+(ca(r,p)|0)|0;p=c[b+(n<<2)>>2]|0;m=s+(ca(p,r)|0)|0;c[a+(n<<2)>>2]=p-(q>>g);q=n+1|0;c[a+(q<<2)>>2]=(c[b+(q<<2)>>2]|0)-(m>>g);n=n+2|0;}while((n|0)<(d|0));return};case 2:{if((d|0)<=2){return}n=f+4|0;h=2;do{k=c[n>>2]|0;o=ca(k,c[b+(h-2<<2)>>2]|0)|0;i=c[b+(h-1<<2)>>2]|0;l=ca(i,k)|0;k=c[f>>2]|0;j=(ca(k,i)|0)+o|0;o=c[b+(h<<2)>>2]|0;i=(ca(o,k)|0)+l|0;c[a+(h<<2)>>2]=o-(j>>g);j=h|1;c[a+(j<<2)>>2]=(c[b+(j<<2)>>2]|0)-(i>>g);h=h+2|0;}while((h|0)<(d|0));return};case 8:{if((d|0)<=8){return}h=f+28|0;n=f+24|0;i=f+20|0;j=f+16|0;o=f+12|0;l=f+8|0;k=f+4|0;m=8;do{q=c[h>>2]|0;p=ca(q,c[b+(m-8<<2)>>2]|0)|0;r=c[b+(m-7<<2)>>2]|0;s=ca(r,q)|0;q=c[n>>2]|0;t=(ca(q,r)|0)+p|0;p=c[b+(m-6<<2)>>2]|0;r=(ca(p,q)|0)+s|0;s=c[i>>2]|0;q=t+(ca(s,p)|0)|0;p=c[b+(m-5<<2)>>2]|0;t=r+(ca(p,s)|0)|0;s=c[j>>2]|0;r=q+(ca(s,p)|0)|0;p=c[b+(m-4<<2)>>2]|0;q=t+(ca(p,s)|0)|0;s=c[o>>2]|0;t=r+(ca(s,p)|0)|0;p=c[b+(m-3<<2)>>2]|0;r=q+(ca(p,s)|0)|0;s=c[l>>2]|0;q=t+(ca(s,p)|0)|0;p=c[b+(m-2<<2)>>2]|0;t=r+(ca(p,s)|0)|0;s=c[k>>2]|0;r=q+(ca(s,p)|0)|0;p=c[b+(m-1<<2)>>2]|0;q=t+(ca(p,s)|0)|0;s=c[f>>2]|0;t=r+(ca(s,p)|0)|0;p=c[b+(m<<2)>>2]|0;r=q+(ca(p,s)|0)|0;c[a+(m<<2)>>2]=p-(t>>g);t=m|1;c[a+(t<<2)>>2]=(c[b+(t<<2)>>2]|0)-(r>>g);m=m+2|0;}while((m|0)<(d|0));return};case 4:{if((d|0)<=4){return}m=f+12|0;k=f+8|0;l=f+4|0;o=4;do{j=c[m>>2]|0;i=ca(j,c[b+(o-4<<2)>>2]|0)|0;n=c[b+(o-3<<2)>>2]|0;h=ca(n,j)|0;j=c[k>>2]|0;r=(ca(j,n)|0)+i|0;i=c[b+(o-2<<2)>>2]|0;n=(ca(i,j)|0)+h|0;h=c[l>>2]|0;j=r+(ca(h,i)|0)|0;i=c[b+(o-1<<2)>>2]|0;r=n+(ca(i,h)|0)|0;h=c[f>>2]|0;n=j+(ca(h,i)|0)|0;i=c[b+(o<<2)>>2]|0;j=r+(ca(i,h)|0)|0;c[a+(o<<2)>>2]=i-(n>>g);n=o|1;c[a+(n<<2)>>2]=(c[b+(n<<2)>>2]|0)-(j>>g);o=o+2|0;}while((o|0)<(d|0));return};case 6:{if((d|0)<=6){return}o=f+20|0;l=f+16|0;k=f+12|0;m=f+8|0;j=f+4|0;n=6;do{i=c[o>>2]|0;h=ca(i,c[b+(n-6<<2)>>2]|0)|0;r=c[b+(n-5<<2)>>2]|0;t=ca(r,i)|0;i=c[l>>2]|0;p=(ca(i,r)|0)+h|0;h=c[b+(n-4<<2)>>2]|0;r=(ca(h,i)|0)+t|0;t=c[k>>2]|0;i=p+(ca(t,h)|0)|0;h=c[b+(n-3<<2)>>2]|0;p=r+(ca(h,t)|0)|0;t=c[m>>2]|0;r=i+(ca(t,h)|0)|0;h=c[b+(n-2<<2)>>2]|0;i=p+(ca(h,t)|0)|0;t=c[j>>2]|0;p=r+(ca(t,h)|0)|0;h=c[b+(n-1<<2)>>2]|0;r=i+(ca(h,t)|0)|0;t=c[f>>2]|0;i=p+(ca(t,h)|0)|0;h=c[b+(n<<2)>>2]|0;p=r+(ca(h,t)|0)|0;c[a+(n<<2)>>2]=h-(i>>g);i=n|1;c[a+(i<<2)>>2]=(c[b+(i<<2)>>2]|0)-(p>>g);n=n+2|0;}while((n|0)<(d|0));return};case 5:{if((d|0)<=5){return}n=f+16|0;j=f+12|0;m=f+8|0;k=f+4|0;l=5;do{o=c[n>>2]|0;p=ca(o,c[b+(l-5<<2)>>2]|0)|0;i=c[b+(l-4<<2)>>2]|0;h=ca(i,o)|0;o=c[j>>2]|0;t=(ca(o,i)|0)+p|0;p=c[b+(l-3<<2)>>2]|0;i=(ca(p,o)|0)+h|0;h=c[m>>2]|0;o=t+(ca(h,p)|0)|0;p=c[b+(l-2<<2)>>2]|0;t=i+(ca(p,h)|0)|0;h=c[k>>2]|0;i=o+(ca(h,p)|0)|0;p=c[b+(l-1<<2)>>2]|0;o=t+(ca(p,h)|0)|0;h=c[f>>2]|0;t=i+(ca(h,p)|0)|0;p=c[b+(l<<2)>>2]|0;i=o+(ca(p,h)|0)|0;c[a+(l<<2)>>2]=p-(t>>g);t=l+1|0;c[a+(t<<2)>>2]=(c[b+(t<<2)>>2]|0)-(i>>g);l=l+2|0;}while((l|0)<(d|0));return};default:{if((e|0)>=(d|0)){return}l=f+28|0;k=f+24|0;m=f+20|0;j=f+16|0;n=f+12|0;i=f+8|0;t=f+4|0;p=f+124|0;h=f+120|0;o=f+116|0;r=f+112|0;s=f+108|0;q=f+104|0;u=f+100|0;v=f+96|0;w=f+92|0;x=f+88|0;y=f+84|0;z=f+80|0;A=f+76|0;B=f+72|0;C=f+68|0;D=f+64|0;E=f+60|0;F=f+56|0;G=f+52|0;H=f+48|0;I=f+44|0;J=f+40|0;K=f+36|0;L=f+32|0;M=e;do{N=c[b+(M-e<<2)>>2]|0;switch(e|0){case 28:{O=N;P=0;Q=0;R=35;break};case 13:{S=N;T=0;U=0;R=50;break};case 12:{V=N;W=0;X=0;R=51;break};case 30:{Y=N;Z=0;_=0;R=33;break};case 31:{$=N;aa=0;ba=0;R=32;break};case 10:{da=N;ea=0;fa=0;R=53;break};case 20:{ga=N;ha=0;ia=0;R=43;break};case 22:{ja=N;ka=0;la=0;R=41;break};case 17:{ma=N;na=0;oa=0;R=46;break};case 9:{pa=N;qa=0;ra=0;R=54;break};case 14:{sa=N;ta=0;ua=0;R=49;break};case 26:{va=N;wa=0;xa=0;R=37;break};case 24:{ya=N;za=0;Aa=0;R=39;break};case 32:{Ba=c[p>>2]|0;Ca=ca(Ba,N)|0;Da=c[b+(M-31<<2)>>2]|0;$=Da;aa=Ca;ba=ca(Da,Ba)|0;R=32;break};case 21:{Ea=N;Fa=0;Ga=0;R=42;break};case 19:{Ha=N;Ia=0;Ja=0;R=44;break};case 11:{Ka=N;La=0;Ma=0;R=52;break};case 16:{Na=N;Oa=0;Pa=0;R=47;break};case 29:{Qa=N;Ra=0;Sa=0;R=34;break};case 25:{Ta=N;Ua=0;Va=0;R=38;break};case 23:{Wa=N;Xa=0;Ya=0;R=40;break};case 18:{Za=N;_a=0;$a=0;R=45;break};case 15:{ab=N;bb=0;cb=0;R=48;break};case 27:{db=N;eb=0;fb=0;R=36;break};default:{gb=0;hb=0;ib=c[b+(M<<2)>>2]|0}}if((R|0)==32){R=0;N=c[h>>2]|0;Ba=(ca(N,$)|0)+aa|0;Da=c[b+(M-30<<2)>>2]|0;Y=Da;Z=Ba;_=(ca(Da,N)|0)+ba|0;R=33}if((R|0)==33){R=0;N=c[o>>2]|0;Da=(ca(N,Y)|0)+Z|0;Ba=c[b+(M-29<<2)>>2]|0;Qa=Ba;Ra=Da;Sa=(ca(Ba,N)|0)+_|0;R=34}if((R|0)==34){R=0;N=c[r>>2]|0;Ba=(ca(N,Qa)|0)+Ra|0;Da=c[b+(M-28<<2)>>2]|0;O=Da;P=Ba;Q=(ca(Da,N)|0)+Sa|0;R=35}if((R|0)==35){R=0;N=c[s>>2]|0;Da=(ca(N,O)|0)+P|0;Ba=c[b+(M-27<<2)>>2]|0;db=Ba;eb=Da;fb=(ca(Ba,N)|0)+Q|0;R=36}if((R|0)==36){R=0;N=c[q>>2]|0;Ba=(ca(N,db)|0)+eb|0;Da=c[b+(M-26<<2)>>2]|0;va=Da;wa=Ba;xa=(ca(Da,N)|0)+fb|0;R=37}if((R|0)==37){R=0;N=c[u>>2]|0;Da=(ca(N,va)|0)+wa|0;Ba=c[b+(M-25<<2)>>2]|0;Ta=Ba;Ua=Da;Va=(ca(Ba,N)|0)+xa|0;R=38}if((R|0)==38){R=0;N=c[v>>2]|0;Ba=(ca(N,Ta)|0)+Ua|0;Da=c[b+(M-24<<2)>>2]|0;ya=Da;za=Ba;Aa=(ca(Da,N)|0)+Va|0;R=39}if((R|0)==39){R=0;N=c[w>>2]|0;Da=(ca(N,ya)|0)+za|0;Ba=c[b+(M-23<<2)>>2]|0;Wa=Ba;Xa=Da;Ya=(ca(Ba,N)|0)+Aa|0;R=40}if((R|0)==40){R=0;N=c[x>>2]|0;Ba=(ca(N,Wa)|0)+Xa|0;Da=c[b+(M-22<<2)>>2]|0;ja=Da;ka=Ba;la=(ca(Da,N)|0)+Ya|0;R=41}if((R|0)==41){R=0;N=c[y>>2]|0;Da=(ca(N,ja)|0)+ka|0;Ba=c[b+(M-21<<2)>>2]|0;Ea=Ba;Fa=Da;Ga=(ca(Ba,N)|0)+la|0;R=42}if((R|0)==42){R=0;N=c[z>>2]|0;Ba=(ca(N,Ea)|0)+Fa|0;Da=c[b+(M-20<<2)>>2]|0;ga=Da;ha=Ba;ia=(ca(Da,N)|0)+Ga|0;R=43}if((R|0)==43){R=0;N=c[A>>2]|0;Da=(ca(N,ga)|0)+ha|0;Ba=c[b+(M-19<<2)>>2]|0;Ha=Ba;Ia=Da;Ja=(ca(Ba,N)|0)+ia|0;R=44}if((R|0)==44){R=0;N=c[B>>2]|0;Ba=(ca(N,Ha)|0)+Ia|0;Da=c[b+(M-18<<2)>>2]|0;Za=Da;_a=Ba;$a=(ca(Da,N)|0)+Ja|0;R=45}if((R|0)==45){R=0;N=c[C>>2]|0;Da=(ca(N,Za)|0)+_a|0;Ba=c[b+(M-17<<2)>>2]|0;ma=Ba;na=Da;oa=(ca(Ba,N)|0)+$a|0;R=46}if((R|0)==46){R=0;N=c[D>>2]|0;Ba=(ca(N,ma)|0)+na|0;Da=c[b+(M-16<<2)>>2]|0;Na=Da;Oa=Ba;Pa=(ca(Da,N)|0)+oa|0;R=47}if((R|0)==47){R=0;N=c[E>>2]|0;Da=(ca(N,Na)|0)+Oa|0;Ba=c[b+(M-15<<2)>>2]|0;ab=Ba;bb=Da;cb=(ca(Ba,N)|0)+Pa|0;R=48}if((R|0)==48){R=0;N=c[F>>2]|0;Ba=(ca(N,ab)|0)+bb|0;Da=c[b+(M-14<<2)>>2]|0;sa=Da;ta=Ba;ua=(ca(Da,N)|0)+cb|0;R=49}if((R|0)==49){R=0;N=c[G>>2]|0;Da=(ca(N,sa)|0)+ta|0;Ba=c[b+(M-13<<2)>>2]|0;S=Ba;T=Da;U=(ca(Ba,N)|0)+ua|0;R=50}if((R|0)==50){R=0;N=c[H>>2]|0;Ba=(ca(N,S)|0)+T|0;Da=c[b+(M-12<<2)>>2]|0;V=Da;W=Ba;X=(ca(Da,N)|0)+U|0;R=51}if((R|0)==51){R=0;N=c[I>>2]|0;Da=(ca(N,V)|0)+W|0;Ba=c[b+(M-11<<2)>>2]|0;Ka=Ba;La=Da;Ma=(ca(Ba,N)|0)+X|0;R=52}if((R|0)==52){R=0;N=c[J>>2]|0;Ba=(ca(N,Ka)|0)+La|0;Da=c[b+(M-10<<2)>>2]|0;da=Da;ea=Ba;fa=(ca(Da,N)|0)+Ma|0;R=53}if((R|0)==53){R=0;N=c[K>>2]|0;Da=(ca(N,da)|0)+ea|0;Ba=c[b+(M-9<<2)>>2]|0;pa=Ba;qa=Da;ra=(ca(Ba,N)|0)+fa|0;R=54}if((R|0)==54){R=0;N=c[L>>2]|0;Ba=(ca(N,pa)|0)+qa|0;Da=c[b+(M-8<<2)>>2]|0;Ca=(ca(Da,N)|0)+ra|0;N=c[l>>2]|0;jb=Ba+(ca(N,Da)|0)|0;Da=c[b+(M-7<<2)>>2]|0;Ba=Ca+(ca(Da,N)|0)|0;N=c[k>>2]|0;Ca=jb+(ca(N,Da)|0)|0;Da=c[b+(M-6<<2)>>2]|0;jb=Ba+(ca(Da,N)|0)|0;N=c[m>>2]|0;Ba=Ca+(ca(N,Da)|0)|0;Da=c[b+(M-5<<2)>>2]|0;Ca=jb+(ca(Da,N)|0)|0;N=c[j>>2]|0;jb=Ba+(ca(N,Da)|0)|0;Da=c[b+(M-4<<2)>>2]|0;Ba=Ca+(ca(Da,N)|0)|0;N=c[n>>2]|0;Ca=jb+(ca(N,Da)|0)|0;Da=c[b+(M-3<<2)>>2]|0;jb=Ba+(ca(Da,N)|0)|0;N=c[i>>2]|0;Ba=Ca+(ca(N,Da)|0)|0;Da=c[b+(M-2<<2)>>2]|0;Ca=jb+(ca(Da,N)|0)|0;N=c[t>>2]|0;jb=Ba+(ca(N,Da)|0)|0;Da=c[b+(M-1<<2)>>2]|0;Ba=Ca+(ca(Da,N)|0)|0;N=c[f>>2]|0;Ca=jb+(ca(N,Da)|0)|0;Da=c[b+(M<<2)>>2]|0;gb=Ca;hb=Ba+(ca(Da,N)|0)|0;ib=Da}c[a+(M<<2)>>2]=ib-(gb>>g);Da=M+1|0;c[a+(Da<<2)>>2]=(c[b+(Da<<2)>>2]|0)-(hb>>g);M=M+2|0;}while((M|0)<(d|0));return}}}function Hea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)>0&(d|0)>0){g=c[a>>2]|0;h=0}else{return}while(1){a=g;i=0;while(1){c[a>>2]=c[(c[b+(i<<2)>>2]|0)+(h<<2)>>2]<<f;j=i+1|0;if((j|0)<(d|0)){a=a+4|0;i=j}else{break}}i=h+1|0;if((i|0)<(e|0)){g=g+(d<<2)|0;h=i}else{break}}return}function Iea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)<=0){return}d=c[b>>2]|0;g=c[b+4>>2]|0;b=0;h=c[a>>2]|0;while(1){a=c[d+(b<<2)>>2]|0;i=c[g+(b<<2)>>2]|0;c[h>>2]=a<<f;c[h+4>>2]=a-i<<f;i=b+1|0;if((i|0)<(e|0)){b=i;h=h+8|0}else{break}}return}function Jea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)<=0){return}d=c[b>>2]|0;g=c[b+4>>2]|0;b=0;h=c[a>>2]|0;while(1){a=c[g+(b<<2)>>2]|0;c[h>>2]=a+(c[d+(b<<2)>>2]|0)<<f;c[h+4>>2]=a<<f;a=b+1|0;if((a|0)<(e|0)){b=a;h=h+8|0}else{break}}return}function Kea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)<=0){return}d=c[b>>2]|0;g=c[b+4>>2]|0;b=0;h=c[a>>2]|0;while(1){a=c[g+(b<<2)>>2]|0;i=(c[d+(b<<2)>>2]|0)-(a>>1)|0;c[h>>2]=i+a<<f;c[h+4>>2]=i<<f;i=b+1|0;if((i|0)<(e|0)){b=i;h=h+8|0}else{break}}return}function Lea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;if((e|0)>0&(d|0)>0){g=0}else{return}do{h=0;do{c[(c[a+(h<<2)>>2]|0)+(g<<2)>>2]=c[(c[b+(h<<2)>>2]|0)+(g<<2)>>2]<<f;h=h+1|0;}while((h|0)<(d|0));g=g+1|0;}while((g|0)<(e|0));return}function Mea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)<=0){return}d=a+4|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=0;do{i=c[g+(b<<2)>>2]|0;j=c[h+(b<<2)>>2]|0;c[(c[a>>2]|0)+(b<<2)>>2]=i<<f;c[(c[d>>2]|0)+(b<<2)>>2]=i-j<<f;b=b+1|0;}while((b|0)<(e|0));return}function Nea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)<=0){return}d=a+4|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=0;do{i=c[h+(b<<2)>>2]|0;c[(c[a>>2]|0)+(b<<2)>>2]=i+(c[g+(b<<2)>>2]|0)<<f;c[(c[d>>2]|0)+(b<<2)>>2]=i<<f;b=b+1|0;}while((b|0)<(e|0));return}function Oea(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)<=0){return}d=a+4|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=0;do{i=c[h+(b<<2)>>2]|0;j=(c[g+(b<<2)>>2]|0)-(i>>1)|0;c[(c[a>>2]|0)+(b<<2)>>2]=j+i<<f;c[(c[d>>2]|0)+(b<<2)>>2]=j<<f;b=b+1|0;}while((b|0)<(e|0));return}function Pea(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((f|0)>0&(e|0)>0){h=c[a>>2]|0;i=0}else{return}while(1){a=h;j=0;while(1){b[a>>1]=c[(c[d+(j<<2)>>2]|0)+(i<<2)>>2]<<g;k=j+1|0;if((k|0)<(e|0)){a=a+2|0;j=k}else{break}}j=i+1|0;if((j|0)<(f|0)){h=h+(e<<1)|0;i=j}else{break}}return}function Qea(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)<=0){return}e=c[d>>2]|0;h=c[d+4>>2]|0;d=0;i=c[a>>2]|0;while(1){a=c[e+(d<<2)>>2]|0;j=c[h+(d<<2)>>2]|0;b[i>>1]=a<<g;b[i+2>>1]=a-j<<g;j=d+1|0;if((j|0)<(f|0)){d=j;i=i+4|0}else{break}}return}function Rea(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;if((f|0)<=0){return}e=c[d>>2]|0;h=c[d+4>>2]|0;d=0;i=c[a>>2]|0;while(1){a=c[h+(d<<2)>>2]|0;b[i>>1]=a+(c[e+(d<<2)>>2]|0)<<g;b[i+2>>1]=a<<g;a=d+1|0;if((a|0)<(f|0)){d=a;i=i+4|0}else{break}}return}function Sea(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)<=0){return}e=c[d>>2]|0;h=c[d+4>>2]|0;d=0;i=c[a>>2]|0;while(1){a=c[h+(d<<2)>>2]|0;j=(c[e+(d<<2)>>2]|0)-(a>>1)|0;b[i>>1]=j+a<<g;b[i+2>>1]=j<<g;j=d+1|0;if((j|0)<(f|0)){d=j;i=i+4|0}else{break}}return}function Tea(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)<=0){return}h=(e|0)>0;i=0;do{if(h){j=0;do{b[(c[a+(j<<2)>>2]|0)+(i<<1)>>1]=c[(c[d+(j<<2)>>2]|0)+(i<<2)>>2]<<g;j=j+1|0;}while((j|0)<(e|0))}i=i+1|0;}while((i|0)<(f|0));return}function Uea(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((f|0)<=0){return}e=a+4|0;h=c[d>>2]|0;i=c[d+4>>2]|0;d=0;do{j=c[h+(d<<2)>>2]|0;k=c[i+(d<<2)>>2]|0;b[(c[a>>2]|0)+(d<<1)>>1]=j<<g;b[(c[e>>2]|0)+(d<<1)>>1]=j-k<<g;d=d+1|0;}while((d|0)<(f|0));return}function Vea(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((f|0)<=0){return}e=a+4|0;h=c[d>>2]|0;i=c[d+4>>2]|0;d=0;do{j=c[i+(d<<2)>>2]|0;b[(c[a>>2]|0)+(d<<1)>>1]=j+(c[h+(d<<2)>>2]|0)<<g;b[(c[e>>2]|0)+(d<<1)>>1]=j<<g;d=d+1|0;}while((d|0)<(f|0));return}function Wea(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((f|0)<=0){return}e=a+4|0;h=c[d>>2]|0;i=c[d+4>>2]|0;d=0;do{j=c[i+(d<<2)>>2]|0;k=(c[h+(d<<2)>>2]|0)-(j>>1)|0;b[(c[a>>2]|0)+(d<<1)>>1]=k+j<<g;b[(c[e>>2]|0)+(d<<1)>>1]=k<<g;d=d+1|0;}while((d|0)<(f|0));return}function Xea(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=i;i=i+392|0;d=b|0;e=b+56|0;f=b+112|0;g=b+168|0;h=b+224|0;j=b+280|0;k=b+336|0;l=c[a+412>>2]|0;m=c[a+416>>2]|0;n=c[a+60>>2]|0;o=n;p=n+4203908|0;c[p>>2]=a;q=a+420|0;r=c[q>>2]|0;if((r|0)==2){s=a+796|0;if((c[s>>2]|0)!=24){KIb(a,24,2299384,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}c[s>>2]=24;c[n+44>>2]=6}else if((r|0)==1){c[a+796>>2]=16;c[n+44>>2]=4}if((m-1|0)>>>0>7>>>0){KIb(a,16,2248360,(t=i,i=i+16|0,c[t>>2]=m,c[t+8>>2]=8,t)|0);i=t;u=-22;i=b;return u|0}r=n+28|0;c[r>>2]=m;if((l|0)<1){u=-1;i=b;return u|0}else{v=4}while(1){if((v|0)>=12){w=12;break}if((l|0)==(c[1388536+(v<<2)>>2]|0)){w=11;break}else{v=v+1|0}}do{if((w|0)==11){c[n+32>>2]=l;c[n+36>>2]=v;c[n+40>>2]=0}else if((w|0)==12){if((v|0)!=12){break}do{if(((l|0)%1e3|0|0)==0&(l|0)<255e3){c[n+36>>2]=12;c[n+40>>2]=(l|0)/1e3|0}else{if(((l|0)%10|0|0)==0&(l|0)<655350){c[n+36>>2]=14;c[n+40>>2]=(l|0)/10|0;break}if((l|0)<65535){c[n+36>>2]=13;c[n+40>>2]=l;break}KIb(a,16,2206288,(t=i,i=i+8|0,c[t>>2]=l,t)|0);i=t;u=-22;i=b;return u|0}}while(0);c[n+32>>2]=l}}while(0);l=c[a+84>>2]|0;v=n+4203864|0;do{if((l|0)<0){c[v>>2]=5;x=5}else{c[v>>2]=l;if((l|0)<=12){x=l;break}KIb(a,16,2174024,(t=i,i=i+8|0,c[t>>2]=l,t)|0);i=t;u=-22;i=b;return u|0}}while(0);c[d>>2]=27;c[d+4>>2]=27;c[d+8>>2]=27;c[d+12>>2]=105;c[d+16>>2]=105;c[d+20>>2]=105;c[d+24>>2]=105;c[d+28>>2]=105;c[d+32>>2]=105;c[d+36>>2]=105;c[d+40>>2]=105;c[d+44>>2]=105;c[d+48>>2]=105;l=c[d+(x<<2)>>2]|0;c[n+4203868>>2]=l;d=n+4203872|0;s=c[d>>2]|0;if((s|0)==-1){c[e>>2]=1;c[e+4>>2]=1;c[e+8>>2]=1;c[e+12>>2]=2;c[e+16>>2]=2;c[e+20>>2]=2;c[e+24>>2]=2;c[e+28>>2]=2;c[e+32>>2]=2;c[e+36>>2]=2;c[e+40>>2]=2;c[e+44>>2]=2;c[e+48>>2]=2;y=c[e+(x<<2)>>2]|0;c[d>>2]=y;z=y}else{z=s}c[f>>2]=2;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=1;c[f+16>>2]=1;c[f+20>>2]=1;c[f+24>>2]=1;c[f+28>>2]=1;c[f+32>>2]=1;c[f+36>>2]=1;c[f+40>>2]=1;c[f+44>>2]=1;c[f+48>>2]=1;s=c[f+(x<<2)>>2]|0;f=n+4203884|0;c[f>>2]=s;c[g>>2]=3;c[g+4>>2]=4;c[g+8>>2]=4;c[g+12>>2]=6;c[g+16>>2]=8;c[g+20>>2]=8;c[g+24>>2]=8;c[g+28>>2]=8;c[g+32>>2]=12;c[g+36>>2]=12;c[g+40>>2]=12;c[g+44>>2]=32;c[g+48>>2]=32;y=c[g+(x<<2)>>2]|0;g=n+4203888|0;c[g>>2]=y;e=n+4203892|0;if((c[e>>2]|0)<0){mrc(h|0,0,24)|0;c[h+24>>2]=2;c[h+28>>2]=5;c[h+32>>2]=2;c[h+36>>2]=5;c[h+40>>2]=4;c[h+44>>2]=5;c[h+48>>2]=4;c[e>>2]=c[h+(x<<2)>>2]}h=n+4203896|0;A=c[h>>2]|0;B=n+4203900|0;C=c[B>>2]|0;if((A|0)>(C|0)){KIb(a,16,2146440,(t=i,i=i+16|0,c[t>>2]=A,c[t+8>>2]=C,t)|0);i=t;u=-22;i=b;return u|0}if((A|0)<0){mrc(j|0,0,52)|0;c[j>>2]=2;c[j+4>>2]=2;c[h>>2]=c[j+(x<<2)>>2]}if((C|0)<0){c[k>>2]=2;c[k+4>>2]=2;c[k+8>>2]=3;c[k+12>>2]=3;c[k+16>>2]=3;c[k+20>>2]=8;c[k+24>>2]=8;c[k+28>>2]=8;c[k+32>>2]=8;c[k+36>>2]=8;c[k+40>>2]=8;c[k+44>>2]=8;c[k+48>>2]=8;c[B>>2]=c[k+(x<<2)>>2]}do{if((z|0)==0){c[f>>2]=0;c[g>>2]=0}else{x=c[a+604>>2]|0;do{if((x|0)>-1){if((z|0)==1){if((x|0)<=4){c[f>>2]=x;D=x;break}KIb(a,16,2122648,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;u=-22;i=b;return u|0}else{if(!((x-1|0)>>>0>31>>>0)){c[f>>2]=x;D=x;break}KIb(a,16,2122648,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;u=-22;i=b;return u|0}}else{D=s}}while(0);x=c[a+608>>2]|0;if((x|0)>-1){do{if((z|0)==1){if((x|0)<=4){break}KIb(a,16,2640424,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;u=-22;i=b;return u|0}else{if(!((x-1|0)>>>0>31>>>0)){break}KIb(a,16,2640424,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;u=-22;i=b;return u|0}}while(0);c[g>>2]=x;E=x}else{E=y}if((E|0)>=(D|0)){break}KIb(a,16,2617664,(t=i,i=i+16|0,c[t>>2]=D,c[t+8>>2]=E,t)|0);i=t;u=-22;i=b;return u|0}}while(0);E=a+424|0;D=c[E>>2]|0;do{if((D|0)>0){if(!((D-16|0)>>>0>65519>>>0)){y=c[p>>2]|0;F=m;G=y;H=c[y+424>>2]|0;break}KIb(a,16,2590304,(t=i,i=i+8|0,c[t>>2]=D,t)|0);i=t;u=-22;i=b;return u|0}else{y=c[n+32>>2]|0;if((y|0)>0){z=c[347267]|0;s=(ca(l,y)|0)/1e3|0;y=c[347266]|0;k=(s|0)>=(y|0)&(y|0)>(z|0)?y:z;y=(s|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[347268]|0;z=(s|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[347269]|0;k=(s|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[347270]|0;y=(s|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[347271]|0;z=(s|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[347272]|0;k=(s|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[347273]|0;y=(s|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[347274]|0;z=(s|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[347275]|0;k=(s|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[347276]|0;y=(s|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[347277]|0;z=(s|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[347278]|0;k=(s|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[347279]|0;y=(s|0)>=(z|0)&(z|0)>(k|0)?z:k;k=c[347280]|0;z=(s|0)>=(k|0)&(k|0)>(y|0)?k:y;y=c[347281]|0;k=(s|0)>=(y|0)&(y|0)>(z|0)?y:z;z=c[p>>2]|0;c[z+424>>2]=k;F=c[r>>2]|0;G=z;H=k;break}else{KIb(0,0,2345848,(t=i,i=i+24|0,c[t>>2]=2339856,c[t+8>>2]=2334072,c[t+16>>2]=157,t)|0);i=t;Hd();return 0}}}while(0);c[n+48>>2]=H;H=n+56|0;c[H>>2]=iea(c[G+424>>2]|0,F,c[G+796>>2]|0)|0;G=aJb()|0;c[n+4203940>>2]=G;if((G|0)==0){u=-12;i=b;return u|0}bJb(G);G=hJb(34)|0;if((G|0)==0){u=-12;i=b;return u|0}_ea(o,G);c[a+96>>2]=G;c[a+100>>2]=34;c[n+64>>2]=0;c[n+52>>2]=c[H>>2];if((m|0)==4){H=a+448|0;G=c[H>>2]|0;o=c[H+4>>2]|0;if(!((G|0)==1539&(o|0)==0|(G|0)==51&(o|0)==0)){I=o;J=G;w=68}}else if((m|0)==5){G=a+448|0;o=c[G>>2]|0;H=c[G+4>>2]|0;if(!((o|0)==1543&(H|0)==0|(o|0)==55&(H|0)==0)){I=H;J=o;w=68}}else if((m|0)==3){o=a+448|0;H=c[o>>2]|0;G=c[o+4>>2]|0;if(!((H|0)==7&(G|0)==0)){I=G;J=H;w=68}}else if((m|0)==6){H=a+448|0;G=c[H>>2]|0;o=c[H+4>>2]|0;if(!((G|0)==1551&(o|0)==0|(G|0)==63&(o|0)==0)){I=o;J=G;w=68}}do{if((w|0)==68){G=a;if((J|0)==0&(I|0)==0){KIb(G,24,2550552,(t=i,i=i+8|0,c[t>>2]=m,t)|0);i=t;break}else{KIb(G,16,2568584,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}}}while(0);m=rPa(n+4203912|0,c[E>>2]|0,c[g>>2]|0,2)|0;l8(n+4203952|0,a);Cea(n+4205196|0,c[q>>2]|0,c[a+796>>2]|0);a=c[p>>2]|0;p=a;KIb(p,48,2532416,(t=i,i=i+8|0,c[t>>2]=c[v>>2],t)|0);i=t;v=c[d>>2]|0;if((v|0)==1){KIb(p,48,2503096,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else if((v|0)==2){KIb(p,48,2489984,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else if((v|0)==0){KIb(p,48,2517088,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else if((v|0)==3){v=c[n+4203876>>2]|0;KIb(p,48,2479072,(t=i,i=i+16|0,c[t>>2]=v,c[t+8>>2]=(v|0)==1?10230512:2460128,t)|0);i=t}v=c[g>>2]|0;KIb(p,48,2443432,(t=i,i=i+16|0,c[t>>2]=c[f>>2],c[t+8>>2]=v,t)|0);i=t;switch(c[e>>2]|0){case 2:{KIb(p,48,2430952,(t=i,i=i+8|0,c[t>>2]=2403784,t)|0);i=t;break};case 3:{KIb(p,48,2430952,(t=i,i=i+8|0,c[t>>2]=2396736,t)|0);i=t;break};case 0:{KIb(p,48,2430952,(t=i,i=i+8|0,c[t>>2]=2420712,t)|0);i=t;break};case 1:{KIb(p,48,2430952,(t=i,i=i+8|0,c[t>>2]=2411400,t)|0);i=t;break};case 4:{KIb(p,48,2430952,(t=i,i=i+8|0,c[t>>2]=2389760,t)|0);i=t;break};case 5:{KIb(p,48,2430952,(t=i,i=i+8|0,c[t>>2]=2382832,t)|0);i=t;break};default:{}}e=c[B>>2]|0;KIb(p,48,2376136,(t=i,i=i+16|0,c[t>>2]=c[h>>2],c[t+8>>2]=e,t)|0);i=t;KIb(p,48,2369488,(t=i,i=i+8|0,c[t>>2]=c[a+424>>2],t)|0);i=t;KIb(p,48,2354792,(t=i,i=i+8|0,c[t>>2]=c[n+4203880>>2],t)|0);i=t;u=m;i=b;return u|0}function Yea(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0;j=i;i=i+72|0;k=j|0;l=j+32|0;m=j+64|0;n=c[e+60>>2]|0;o=n;if((g|0)==0){c[n+56>>2]=c[n+60>>2];eJb(c[n+4203940>>2]|0,n+80|0);_ea(o,c[e+96>>2]|0);p=0;i=j;return p|0}q=g+76|0;r=c[q>>2]|0;s=n+4203840|0;if((r|0)<(c[s>>2]|0)){c[n+56>>2]=iea(r,c[n+28>>2]|0,c[e+796>>2]|0)|0;t=c[q>>2]|0}else{t=r}r=0;while(1){if((r|0)>=16){u=9;break}if((c[1389064+(r<<2)>>2]|0)==(t|0)){u=8;break}else{r=r+1|0}}do{if((u|0)==8){c[s>>2]=t;c[n+4203844>>2]=r;c[n+4203848>>2]=0}else if((u|0)==9){if((r|0)!=16){break}c[s>>2]=t;v=n+4203844|0;if((t|0)<257){c[v>>2]=6;c[n+4203848>>2]=t-1;break}else{c[v>>2]=7;c[n+4203848>>2]=t-1;break}}}while(0);t=n+28|0;r=n+4203908|0;if((c[t>>2]|0)>0){v=0;do{c[o+96+(v*525468|0)+12>>2]=0;w=c[(c[r>>2]|0)+796>>2]|0;c[o+96+(v*525468|0)+8>>2]=w;c[o+96+(v*525468|0)+152>>2]=(w|0)>16?5:4;v=v+1|0;}while((v|0)<(c[t>>2]|0))}v=n+4203860|0;c[v>>2]=0;w=g|0;x=c[w>>2]|0;z=(QKb(c[(c[r>>2]|0)+420>>2]|0)|0)<<3;A=c[r>>2]|0;B=z-(c[A+796>>2]|0)|0;do{if((c[A+420>>2]|0)==1){z=x;C=c[s>>2]|0;if((C|0)<=0){D=C;break}E=0;F=0;H=c[t>>2]|0;I=C;while(1){if((H|0)>0){C=0;J=E;do{c[o+96+(C*525468|0)+1184+(F<<2)>>2]=b[z+(J<<1)>>1]>>B;C=C+1|0;J=J+1|0;K=c[t>>2]|0;}while((C|0)<(K|0));L=J;M=K;N=c[s>>2]|0}else{L=E;M=H;N=I}C=F+1|0;if((C|0)<(N|0)){E=L;F=C;H=M;I=N}else{D=N;break}}}else{I=x;H=c[s>>2]|0;if((H|0)<=0){D=H;break}F=0;E=0;z=c[t>>2]|0;C=H;while(1){if((z|0)>0){H=0;O=F;do{c[o+96+(H*525468|0)+1184+(E<<2)>>2]=c[I+(O<<2)>>2]>>B;H=H+1|0;O=O+1|0;P=c[t>>2]|0;}while((H|0)<(P|0));Q=O;R=P;S=c[s>>2]|0}else{Q=F;R=z;S=C}H=E+1|0;if((H|0)<(S|0)){F=Q;E=H;z=R;C=S}else{D=S;break}}}}while(0);do{if((c[t>>2]|0)==2){S=c[n+4203904>>2]|0;if((S|0)<0){R=(1<<c[n+248>>2])-2|0;Q=k+24|0;P=k+16|0;B=k+8|0;x=k|0;mrc(k|0,0,32)|0;if((D|0)>2){N=2;M=0;L=0;K=0;A=0;C=0;z=0;E=0;F=0;I=c[n+1284>>2]|0;H=c[n+526752>>2]|0;while(1){J=c[o+1280+(N<<2)>>2]|0;T=N-2|0;U=J-(I<<1)+(c[o+1280+(T<<2)>>2]|0)|0;V=c[o+526748+(N<<2)>>2]|0;W=V-(H<<1)+(c[o+526748+(T<<2)>>2]|0)|0;T=W+U>>1;X=(T|0)>-1?T:-T|0;Y=wrc(X,(X|0)<0|0?-1:0,L,M)|0;Z=G;X=U-W|0;T=(X|0)>-1?X:-X|0;_=wrc(T,(T|0)<0|0?-1:0,A,K)|0;$=G;T=(U|0)>-1?U:-U|0;aa=wrc(T,(T|0)<0|0?-1:0,z,C)|0;ba=G;T=(W|0)>-1?W:-W|0;da=wrc(T,(T|0)<0|0?-1:0,F,E)|0;ea=G;T=N+1|0;if((T|0)<(D|0)){N=T;M=Z;L=Y;K=$;A=_;C=ba;z=aa;E=ea;F=da;I=J;H=V}else{break}}c[P>>2]=Y;c[P+4>>2]=Z;c[Q>>2]=_;c[Q+4>>2]=$;c[x>>2]=aa;c[x+4>>2]=ba;c[B>>2]=da;c[B+4>>2]=ea;fa=ba;ga=aa}else{fa=0;ga=0}H=D>>1;I=H;F=(H|0)<0|0?-1:0;H=D;E=(D|0)<0|0?-1:0;z=0;C=fa;A=ga;while(1){K=k+(z<<3)|0;L=A<<1|0>>>31;M=C<<1|A>>>31;N=xrc(L,M,I,F)|0;V=G;if(F>>>0<M>>>0|F>>>0==M>>>0&I>>>0<L>>>0){L=Frc(N,V,H,E)|0;M=G;J=wrc(L,M,-2147483648,0)|0;T=G;W=0;if(T>>>0>W>>>0|T>>>0==W>>>0&J>>>0>-1>>>0){((M|0)<0|0?-1:0)>>31|((M|0)<0|0?-1:0)<<1;ha=(M>>31|((M|0)<0|0?-1:0)<<1)^2147483647}else{ha=L}L=ha>>>0>65535>>>0;M=L?ha>>>16:ha;J=L?16:0;if((M&65280|0)==0){ia=J;ja=M}else{ia=J|8;ja=M>>>8}M=(d[1359664+ja|0]|0)+ia|0;ka=(M|0)>(R|0)?R:M}else{ka=0}M=ca(ka+1|0,D)|0;J=zrc(N|0,V|0,ka|0)|0;V=wrc(M,(M|0)<0|0?-1:0,J,G)|0;c[K>>2]=V;c[K+4>>2]=G;K=z+1|0;if((K|0)>=4){break}V=k+(K<<3)|0;z=K;C=c[V+4>>2]|0;A=c[V>>2]|0}A=c[x>>2]|0;C=c[x+4>>2]|0;z=c[B>>2]|0;R=c[B+4>>2]|0;E=wrc(z,R,A,C)|0;H=G;I=l|0;c[I>>2]=E;c[I+4>>2]=H;I=c[Q>>2]|0;F=c[Q+4>>2]|0;V=wrc(I,F,A,C)|0;C=G;A=l+8|0;c[A>>2]=V;c[A+4>>2]=C;A=wrc(I,F,z,R)|0;R=G;z=l+16|0;c[z>>2]=A;c[z+4>>2]=R;z=wrc(c[P>>2]|0,c[P+4>>2]|0,I,F)|0;F=G;I=l+24|0;c[I>>2]=z;c[I+4>>2]=F;I=(C>>>0<H>>>0|C>>>0==H>>>0&V>>>0<E>>>0)&1;E=l+(I<<3)|0;V=c[E+4>>2]|0;H=R>>>0<V>>>0|R>>>0==V>>>0&A>>>0<(c[E>>2]|0)>>>0?2:I;I=l+(H<<3)|0;E=c[I+4>>2]|0;A=F>>>0<E>>>0|F>>>0==E>>>0&z>>>0<(c[I>>2]|0)>>>0?3:H;c[n+4203856>>2]=A;la=A}else{c[n+4203856>>2]=S;la=S}if((la|0)==0){break}else if((la|0)==1){if((D|0)>0){A=0;do{H=o+526748+(A<<2)|0;c[H>>2]=(c[o+1280+(A<<2)>>2]|0)-(c[H>>2]|0);A=A+1|0;}while((A|0)<(D|0))}A=n+525572|0;c[A>>2]=(c[A>>2]|0)+1;break}else if((la|0)==3){if((D|0)>0){A=0;do{S=o+1280+(A<<2)|0;P=c[S>>2]|0;Q=o+526748+(A<<2)|0;B=c[Q>>2]|0;c[S>>2]=B+P>>1;c[Q>>2]=P-B;A=A+1|0;}while((A|0)<(D|0))}A=n+525572|0;c[A>>2]=(c[A>>2]|0)+1;break}else{if((D|0)>0){A=0;do{B=o+1280+(A<<2)|0;c[B>>2]=(c[B>>2]|0)-(c[o+526748+(A<<2)>>2]|0);A=A+1|0;}while((A|0)<(D|0))}A=n+104|0;c[A>>2]=(c[A>>2]|0)+1;break}}else{c[n+4203856>>2]=0}}while(0);if((c[t>>2]|0)>0){D=0;do{la=c[s>>2]|0;l=0;k=0;while(1){if((k|0)>=(la|0)){ma=l;break}ka=c[o+96+(D*525468|0)+1184+(k<<2)>>2]|l;if((ka&1|0)==0){l=ka;k=k+1|0}else{ma=ka;break}}do{if((ma|0)!=0&(ma&1|0)==0){k=zIb(ma)|0;if((c[s>>2]|0)>0){l=0;do{la=o+96+(D*525468|0)+1184+(l<<2)|0;c[la>>2]=c[la>>2]>>k;l=l+1|0;}while((l|0)<(c[s>>2]|0))}c[o+96+(D*525468|0)+12>>2]=k;l=o+96+(D*525468|0)+8|0;O=(c[l>>2]|0)-k|0;c[l>>2]=O;if((O|0)>=18){break}c[o+96+(D*525468|0)+152>>2]=4}}while(0);D=D+1|0;}while((D|0)<(c[t>>2]|0))}D=$ea(o)|0;if((D|0)<0){u=68}else{if((D|0)>(c[n+56>>2]|0)){u=68}else{na=D}}do{if((u|0)==68){c[v>>2]=1;D=$ea(o)|0;if((D|0)>=0){na=D;break}KIb(e,16,2453888,(oa=i,i=i+1|0,i=i+7&-8,c[oa>>2]=0,oa)|0);i=oa;p=D;i=j;return p|0}}while(0);v=d5a(e,f,na,(na|0)<0|0?-1:0)|0;if((v|0)<0){p=v;i=j;return p|0}v=f+28|0;na=c[v>>2]|0;u=(na|0)<0;D=u?0:c[f+24>>2]|0;ma=u?0:na;c[n+24>>2]=ma<<3;na=n+12|0;c[na>>2]=D;c[n+20>>2]=D+ma;ma=n+16|0;c[ma>>2]=D;u=n+8|0;O=n+4|0;l=n+4203844|0;la=n+36|0;ka=c[l>>2]<<4|c[la>>2]|16775168;c[O>>2]=ka;c[u>>2]=8;ia=c[n+4203856>>2]|0;if((ia|0)==0){pa=(c[t>>2]|0)-1|ka<<4}else{pa=ka<<4|ia+7}ia=D;y=je((c[n+44>>2]|pa<<3)<<1|0)|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=(c[ma>>2]|0)+4|0;c[ma>>2]=ia;c[O>>2]=0;c[u>>2]=32;pa=n+64|0;D=c[pa>>2]|0;do{if(D>>>0<128>>>0){ka=D&255;c[O>>2]=ka;c[u>>2]=24;qa=ka;ra=24;sa=ia}else{ka=D>>>0>65535>>>0;ja=ka?D>>>16:D;ha=ka?16:0;if((ja&65280|0)==0){ta=ha;ua=ja}else{ta=ha|8;ua=ja>>>8}ja=(ta+4+(d[1359664+ua|0]|0)|0)/5|0;ha=(ja*6|0)-6|0;ka=(D>>>(ha>>>0)|256-(256>>>(ja>>>0)))&255;c[O>>2]=ka;c[u>>2]=24;if((ha|0)>5){va=ha;wa=ka;xa=24;ya=ia}else{qa=ka;ra=24;sa=ia;break}while(1){ka=va-6|0;ha=D>>>(ka>>>0)&63|128;if((xa|0)>8){za=xa-8|0;Aa=ha|wa<<8;Ba=ya}else{ja=ya;y=je(ha>>>((8-xa|0)>>>0)|wa<<xa|0)|0;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;ja=(c[ma>>2]|0)+4|0;c[ma>>2]=ja;za=xa+24|0;Aa=ha;Ba=ja}c[O>>2]=Aa;c[u>>2]=za;if((ka|0)>5){va=ka;wa=Aa;xa=za;ya=Ba}else{qa=Aa;ra=za;sa=Ba;break}}}}while(0);Ba=c[l>>2]|0;if((Ba|0)==7){l=c[n+4203848>>2]|0;if((ra|0)>16){Ca=ra-16|0;Da=l|qa<<16;Ea=sa}else{za=sa;y=je(l>>>((16-ra|0)>>>0)|qa<<ra|0)|0;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=(c[ma>>2]|0)+4|0;c[ma>>2]=za;Ca=ra+16|0;Da=l;Ea=za}c[O>>2]=Da;c[u>>2]=Ca;Fa=Da;Ga=Ca;Ha=Ea}else if((Ba|0)==6){Ba=c[n+4203848>>2]|0;if((ra|0)>8){Ia=ra-8|0;Ja=Ba|qa<<8;Ka=sa}else{Ea=sa;y=je(Ba>>>((8-ra|0)>>>0)|qa<<ra|0)|0;a[Ea]=y;y=y>>8;a[Ea+1|0]=y;y=y>>8;a[Ea+2|0]=y;y=y>>8;a[Ea+3|0]=y;Ea=(c[ma>>2]|0)+4|0;c[ma>>2]=Ea;Ia=ra+24|0;Ja=Ba;Ka=Ea}c[O>>2]=Ja;c[u>>2]=Ia;Fa=Ja;Ga=Ia;Ha=Ka}else{Fa=qa;Ga=ra;Ha=sa}sa=c[la>>2]|0;do{if((sa|0)==12){la=c[n+40>>2]|0;if((Ga|0)>8){La=Ga-8|0;Ma=la|Fa<<8;Na=Ha}else{ra=Ha;y=je(la>>>((8-Ga|0)>>>0)|Fa<<Ga|0)|0;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;ra=(c[ma>>2]|0)+4|0;c[ma>>2]=ra;La=Ga+24|0;Ma=la;Na=ra}c[O>>2]=Ma;c[u>>2]=La;Oa=La;Pa=Ma;Qa=Na}else{if((sa|0)<=12){Oa=Ga;Pa=Fa;Qa=Ha;break}ra=c[n+40>>2]|0;if((Ga|0)>16){Ra=Ga-16|0;Sa=ra|Fa<<16;Ta=Ha}else{la=Ha;y=je(ra>>>((16-Ga|0)>>>0)|Fa<<Ga|0)|0;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;la=(c[ma>>2]|0)+4|0;c[ma>>2]=la;Ra=Ga+16|0;Sa=ra;Ta=la}c[O>>2]=Sa;c[u>>2]=Ra;Oa=Ra;Pa=Sa;Qa=Ta}}while(0);do{if((Oa|0)<32){Ta=Pa<<Oa;c[O>>2]=Ta;c[ma>>2]=Qa+1;a[Qa]=Ta>>>24;Ta=c[O>>2]|0;c[O>>2]=Ta<<8;Sa=(c[u>>2]|0)+8|0;c[u>>2]=Sa;if((Sa|0)>=32){break}Sa=Ta>>>16&255;while(1){Ta=c[ma>>2]|0;c[ma>>2]=Ta+1;a[Ta]=Sa;Ta=c[O>>2]|0;c[O>>2]=Ta<<8;Ra=(c[u>>2]|0)+8|0;c[u>>2]=Ra;if((Ra|0)<32){Sa=Ta>>>16&255}else{break}}}}while(0);c[u>>2]=32;c[O>>2]=0;Qa=DGb(0)|0;Oa=c[na>>2]|0;Pa=c[u>>2]|0;Sa=c[ma>>2]|0;Ta=EGb(Qa,0,Oa,32-Pa+(Sa-Oa<<3)>>3)|0;Oa=c[O>>2]|0;if((Pa|0)>8){Ua=Pa-8|0;Va=Oa<<8|Ta;Wa=Sa}else{Qa=Sa;y=je(Oa<<Pa|Ta>>>((8-Pa|0)>>>0)|0)|0;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;Qa=(c[ma>>2]|0)+4|0;c[ma>>2]=Qa;Ua=Pa+24|0;Va=Ta;Wa=Qa}c[O>>2]=Va;c[u>>2]=Ua;if((c[t>>2]|0)>0){Qa=n+4203880|0;Ta=0;Pa=Va;Oa=Ua;Sa=Wa;while(1){Ra=o+96+(Ta*525468|0)+263324|0;Ga=c[s>>2]|0;Fa=o+96+(Ta*525468|0)+263324+(Ga<<2)|0;if((Oa|0)>1){Xa=Oa-1|0;Ya=Pa<<1;Za=Sa}else{Ha=Sa;y=je(Pa<<Oa|0)|0;a[Ha]=y;y=y>>8;a[Ha+1|0]=y;y=y>>8;a[Ha+2|0]=y;y=y>>8;a[Ha+3|0]=y;Ha=(c[ma>>2]|0)+4|0;c[ma>>2]=Ha;Xa=Oa+31|0;Ya=0;Za=Ha}c[O>>2]=Ya;c[u>>2]=Xa;Ha=c[o+96+(Ta*525468|0)+4>>2]|0;if((Xa|0)>6){_a=Xa-6|0;$a=Ha|Ya<<6;ab=Za}else{sa=Za;y=je(Ha>>>((6-Xa|0)>>>0)|Ya<<Xa|0)|0;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;sa=(c[ma>>2]|0)+4|0;c[ma>>2]=sa;_a=Xa+26|0;$a=Ha;ab=sa}c[O>>2]=$a;c[u>>2]=_a;sa=o+96+(Ta*525468|0)+12|0;Ha=(c[sa>>2]|0)!=0|0;if((_a|0)>1){bb=_a-1|0;cb=Ha|$a<<1;db=ab}else{Na=ab;y=je(Ha>>>((1-_a|0)>>>0)|$a<<_a|0)|0;a[Na]=y;y=y>>8;a[Na+1|0]=y;y=y>>8;a[Na+2|0]=y;y=y>>8;a[Na+3|0]=y;Na=(c[ma>>2]|0)+4|0;c[ma>>2]=Na;bb=_a+31|0;cb=Ha;db=Na}c[O>>2]=cb;c[u>>2]=bb;Na=c[sa>>2]|0;if((Na|0)==0){eb=cb;fb=bb;gb=db}else{if((bb|0)>(Na|0)){hb=bb;ib=cb<<Na|1;jb=db}else{sa=db;y=je(1>>>((Na-bb|0)>>>0)|cb<<bb|0)|0;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;sa=(c[ma>>2]|0)+4|0;c[ma>>2]=sa;hb=bb+32|0;ib=1;jb=sa}sa=hb-Na|0;c[O>>2]=ib;c[u>>2]=sa;eb=ib;fb=sa;gb=jb}sa=o+96+(Ta*525468|0)|0;Na=c[sa>>2]|0;do{if((Na|0)==1){if((Ga|0)<=0){kb=eb;lb=fb;mb=gb;break}Ha=o+96+(Ta*525468|0)+8|0;Ma=Ra;La=eb;la=fb;ra=gb;while(1){qa=c[Ha>>2]|0;Ka=Ma+4|0;Ia=(1<<qa)-1&c[Ma>>2];if((la|0)>(qa|0)){nb=la;ob=Ia|La<<qa;pb=ra}else{Ja=ra;y=je(Ia>>>((qa-la|0)>>>0)|La<<la|0)|0;a[Ja]=y;y=y>>8;a[Ja+1|0]=y;y=y>>8;a[Ja+2|0]=y;y=y>>8;a[Ja+3|0]=y;Ja=(c[ma>>2]|0)+4|0;c[ma>>2]=Ja;nb=la+32|0;ob=Ia;pb=Ja}Ja=nb-qa|0;c[O>>2]=ob;c[u>>2]=Ja;if(Ka>>>0<Fa>>>0){Ma=Ka;La=ob;la=Ja;ra=pb}else{kb=ob;lb=Ja;mb=pb;break}}}else if((Na|0)==0){ra=c[o+96+(Ta*525468|0)+8>>2]|0;la=(1<<ra)-1&c[Ra>>2];if((fb|0)>(ra|0)){qb=fb;rb=la|eb<<ra;sb=gb}else{La=gb;y=je(la>>>((ra-fb|0)>>>0)|eb<<fb|0)|0;a[La]=y;y=y>>8;a[La+1|0]=y;y=y>>8;a[La+2|0]=y;y=y>>8;a[La+3|0]=y;La=(c[ma>>2]|0)+4|0;c[ma>>2]=La;qb=fb+32|0;rb=la;sb=La}La=qb-ra|0;c[O>>2]=rb;c[u>>2]=La;kb=rb;lb=La;mb=sb}else{La=o+96+(Ta*525468|0)+16|0;if((c[La>>2]|0)>0){ra=o+96+(Ta*525468|0)+8|0;la=Ra;Ma=0;Ha=eb;k=fb;Ja=gb;while(1){Ka=c[ra>>2]|0;tb=la+4|0;qa=(1<<Ka)-1&c[la>>2];if((k|0)>(Ka|0)){ub=k;vb=qa|Ha<<Ka;wb=Ja}else{Ia=Ja;y=je(qa>>>((Ka-k|0)>>>0)|Ha<<k|0)|0;a[Ia]=y;y=y>>8;a[Ia+1|0]=y;y=y>>8;a[Ia+2|0]=y;y=y>>8;a[Ia+3|0]=y;Ia=(c[ma>>2]|0)+4|0;c[ma>>2]=Ia;ub=k+32|0;vb=qa;wb=Ia}xb=ub-Ka|0;c[O>>2]=vb;c[u>>2]=xb;Ka=Ma+1|0;if((Ka|0)<(c[La>>2]|0)){la=tb;Ma=Ka;Ha=vb;k=xb;Ja=wb}else{break}}yb=tb;zb=c[sa>>2]|0;Ab=vb;Bb=xb;Cb=wb}else{yb=Ra;zb=Na;Ab=eb;Bb=fb;Cb=gb}do{if((zb|0)==32){Ja=c[Qa>>2]|0;k=Ja-1|0;if((Bb|0)>4){Db=Bb-4|0;Eb=k|Ab<<4;Fb=Cb}else{Ha=Cb;y=je(k>>>((4-Bb|0)>>>0)|Ab<<Bb|0)|0;a[Ha]=y;y=y>>8;a[Ha+1|0]=y;y=y>>8;a[Ha+2|0]=y;y=y>>8;a[Ha+3|0]=y;Ha=(c[ma>>2]|0)+4|0;c[ma>>2]=Ha;Db=Bb+28|0;Eb=k;Fb=Ha}c[O>>2]=Eb;c[u>>2]=Db;Ha=c[o+96+(Ta*525468|0)+148>>2]&31;if((Db|0)>5){Gb=Db-5|0;Hb=Ha|Eb<<5;Ib=Fb}else{k=Fb;y=je(Ha>>>((5-Db|0)>>>0)|Eb<<Db|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=(c[ma>>2]|0)+4|0;c[ma>>2]=k;Gb=Db+27|0;Hb=Ha;Ib=k}c[O>>2]=Hb;c[u>>2]=Gb;if((c[La>>2]|0)<=0){Jb=Hb;Kb=Gb;Lb=Ib;break}k=(1<<Ja)-1|0;Ha=32-Ja|0;Ma=0;la=Hb;ra=Gb;Ka=Ib;while(1){Ia=c[o+96+(Ta*525468|0)+20+(Ma<<2)>>2]&k;if((ra|0)>(Ja|0)){Mb=ra-Ja|0;Nb=Ia|la<<Ja;Ob=Ka}else{qa=Ka;y=je(Ia>>>((Ja-ra|0)>>>0)|la<<ra|0)|0;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;qa=(c[ma>>2]|0)+4|0;c[ma>>2]=qa;Mb=Ha+ra|0;Nb=Ia;Ob=qa}c[O>>2]=Nb;c[u>>2]=Mb;qa=Ma+1|0;if((qa|0)<(c[La>>2]|0)){Ma=qa;la=Nb;ra=Mb;Ka=Ob}else{Jb=Nb;Kb=Mb;Lb=Ob;break}}}else{Jb=Ab;Kb=Bb;Lb=Cb}}while(0);La=o+96+(Ta*525468|0)+152|0;Ka=(c[La>>2]|0)-4|0;if((Kb|0)>2){Pb=Kb-2|0;Qb=Ka|Jb<<2;Rb=Lb}else{ra=Lb;y=je(Ka>>>((2-Kb|0)>>>0)|Jb<<Kb|0)|0;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;ra=(c[ma>>2]|0)+4|0;c[ma>>2]=ra;Pb=Kb+30|0;Qb=Ka;Rb=ra}c[O>>2]=Qb;c[u>>2]=Pb;ra=c[o+96+(Ta*525468|0)+156>>2]|0;Ka=c[s>>2]>>ra;if((Pb|0)>4){Sb=Pb-4|0;Tb=ra|Qb<<4;Ub=Rb}else{la=Rb;y=je(ra>>>((4-Pb|0)>>>0)|Qb<<Pb|0)|0;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;la=(c[ma>>2]|0)+4|0;c[ma>>2]=la;Sb=Pb+28|0;Tb=ra;Ub=la}c[O>>2]=Tb;c[u>>2]=Sb;la=1<<ra;if((la|0)<=0){kb=Tb;lb=Sb;mb=Ub;break}ra=o+96+(Ta*525468|0)+263324+(Ka<<2)|0;Ma=yb;Ha=0;Ja=Tb;k=Sb;qa=Ub;while(1){Ia=c[o+96+(Ta*525468|0)+160+(Ha<<2)>>2]|0;Ea=c[La>>2]|0;if((k|0)>(Ea|0)){Vb=k;Wb=Ja<<Ea|Ia;Xb=qa}else{Ba=qa;y=je(Ia>>>((Ea-k|0)>>>0)|Ja<<k|0)|0;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=(c[ma>>2]|0)+4|0;c[ma>>2]=Ba;Vb=k+32|0;Wb=Ia;Xb=Ba}Ba=Vb-Ea|0;c[O>>2]=Wb;c[u>>2]=Ba;if(Ma>>>0<ra>>>0){Ea=(Ia|0)==0;Ca=(1<<Ia)-1|0;Da=32-Ia|0;za=Ma;l=Wb;Aa=Ba;ya=Xb;while(1){xa=za+4|0;wa=((c[za>>2]|0)*-2|0)-1|0;va=wa>>31^wa;wa=va>>Ia;D=wa+1|0;do{if((D|0)==2147483647){ia=2147483647;ua=l;ta=Aa;ka=ya;while(1){if((ta|0)>31){Yb=ta-31|0;Zb=ua<<31;_b=ka}else{ja=ka;y=je(ua<<ta|0)|0;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;ja=(c[ma>>2]|0)+4|0;c[ma>>2]=ja;Yb=ta+1|0;Zb=0;_b=ja}c[O>>2]=Zb;c[u>>2]=Yb;ja=ia-31|0;if((ja|0)>31){ia=ja;ua=Zb;ta=Yb;ka=_b}else{break}}if((Yb|0)>1){$b=Yb-1|0;ac=_b}else{ka=_b;y=je(1>>>((1-Yb|0)>>>0)|Zb<<Yb|0)|0;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;ka=(c[ma>>2]|0)+4|0;c[ma>>2]=ka;$b=Yb+31|0;ac=ka}c[O>>2]=1;c[u>>2]=$b;ka=va-1|0;if(($b|0)>0){bc=$b;cc=ka|1;dc=ac}else{ta=ac;y=je(1<<$b|ka>>>((-$b|0)>>>0)|0)|0;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;ta=(c[ma>>2]|0)+4|0;c[ma>>2]=ta;bc=$b+32|0;cc=ka;dc=ta}c[O>>2]=cc;c[u>>2]=bc;ec=cc;fc=bc;gc=dc}else{if((D|0)>31){ta=D;ka=l;ua=Aa;ia=ya;while(1){if((ua|0)>31){hc=ua-31|0;ic=ka<<31;jc=ia}else{ja=ia;y=je(ka<<ua|0)|0;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;ja=(c[ma>>2]|0)+4|0;c[ma>>2]=ja;hc=ua+1|0;ic=0;jc=ja}c[O>>2]=ic;c[u>>2]=hc;ja=ta-31|0;if((ja|0)>31){ta=ja;ka=ic;ua=hc;ia=jc}else{break}}kc=(((wa-31|0)>>>0)%31|0)+1|0;lc=ic;mc=hc;nc=jc}else{kc=D;lc=l;mc=Aa;nc=ya}if((mc|0)>(kc|0)){oc=mc;pc=lc<<kc|1;qc=nc}else{ia=nc;y=je(1>>>((kc-mc|0)>>>0)|lc<<mc|0)|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=(c[ma>>2]|0)+4|0;c[ma>>2]=ia;oc=mc+32|0;pc=1;qc=ia}ia=oc-kc|0;c[O>>2]=pc;c[u>>2]=ia;if(Ea){ec=pc;fc=ia;gc=qc;break}ua=va&Ca;if((ia|0)>(Ia|0)){rc=ia-Ia|0;sc=pc<<Ia|ua;tc=qc}else{ka=qc;y=je(ua>>>((Ia-ia|0)>>>0)|pc<<ia|0)|0;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;ka=(c[ma>>2]|0)+4|0;c[ma>>2]=ka;rc=Da+ia|0;sc=ua;tc=ka}c[O>>2]=sc;c[u>>2]=rc;ec=sc;fc=rc;gc=tc}}while(0);if(xa>>>0<ra>>>0){za=xa;l=ec;Aa=fc;ya=gc}else{uc=xa;vc=ec;wc=fc;xc=gc;break}}}else{uc=Ma;vc=Wb;wc=Ba;xc=Xb}ya=ra+(Ka<<2)|0;Aa=Ha+1|0;if((Aa|0)<(la|0)){ra=Fa>>>0>ya>>>0?ya:Fa;Ma=uc;Ha=Aa;Ja=vc;k=wc;qa=xc}else{kb=vc;lb=wc;mb=xc;break}}}}while(0);Fa=Ta+1|0;if((Fa|0)<(c[t>>2]|0)){Ta=Fa;Pa=kb;Oa=lb;Sa=mb}else{yc=lb;zc=kb;Ac=mb;break}}}else{yc=Ua;zc=Va;Ac=Wa}do{if((yc|0)<32){Wa=zc<<yc;c[O>>2]=Wa;c[ma>>2]=Ac+1;a[Ac]=Wa>>>24;Wa=c[O>>2]|0;c[O>>2]=Wa<<8;Va=(c[u>>2]|0)+8|0;c[u>>2]=Va;if((Va|0)>=32){break}Va=Wa>>>16&255;while(1){Wa=c[ma>>2]|0;c[ma>>2]=Wa+1;a[Wa]=Va;Wa=c[O>>2]|0;c[O>>2]=Wa<<8;Ua=(c[u>>2]|0)+8|0;c[u>>2]=Ua;if((Ua|0)<32){Va=Wa>>>16&255}else{break}}}}while(0);c[u>>2]=32;c[O>>2]=0;Ac=DGb(1)|0;yc=c[na>>2]|0;zc=c[u>>2]|0;Va=c[ma>>2]|0;Wa=(he((EGb(Ac,0,yc,32-zc+(Va-yc<<3)>>3)|0)&65535|0)|0)&65535;yc=c[O>>2]|0;if((zc|0)>16){Bc=zc-16|0;Cc=yc<<16|Wa;Dc=Va}else{Ac=Va;y=je(Wa>>>((16-zc|0)>>>0)|yc<<zc|0)|0;a[Ac]=y;y=y>>8;a[Ac+1|0]=y;y=y>>8;a[Ac+2|0]=y;y=y>>8;a[Ac+3|0]=y;Ac=(c[ma>>2]|0)+4|0;c[ma>>2]=Ac;Bc=zc+16|0;Cc=Wa;Dc=Ac}c[O>>2]=Cc;c[u>>2]=Bc;if((Bc|0)<32){Ac=Cc<<Bc;c[O>>2]=Ac;c[ma>>2]=Dc+1;a[Dc]=Ac>>>24;Ac=c[O>>2]|0;c[O>>2]=Ac<<8;Bc=(c[u>>2]|0)+8|0;c[u>>2]=Bc;if((Bc|0)<32){Bc=Ac>>>16&255;while(1){Ac=c[ma>>2]|0;c[ma>>2]=Ac+1;a[Ac]=Bc;Ac=c[O>>2]|0;c[O>>2]=Ac<<8;Cc=(c[u>>2]|0)+8|0;c[u>>2]=Cc;if((Cc|0)<32){Bc=Ac>>>16&255}else{break}}}Ec=c[ma>>2]|0}else{Ec=Dc}c[u>>2]=32;c[O>>2]=0;O=Ec-(c[na>>2]|0)<<3>>3;c[pa>>2]=(c[pa>>2]|0)+1;pa=c[q>>2]|0;na=n+72|0;Ec=wrc(c[na>>2]|0,c[na+4>>2]|0,pa,(pa|0)<0|0?-1:0)|0;c[na>>2]=Ec;c[na+4>>2]=G;na=c[w>>2]|0;w=ca(c[t>>2]|0,c[s>>2]|0)|0;Ec=c[(c[r>>2]|0)+796>>2]|0;pa=ca(w,(Ec+7|0)/8|0)|0;do{if((Ec|0)>16){w=n+4203944|0;u=w;xJb(w,n+4203948|0,pa);w=c[u>>2]|0;if((w|0)==0){KIb(e,16,2364560,(oa=i,i=i+1|0,i=i+7&-8,c[oa>>2]=0,oa)|0);i=oa;p=-12;i=j;return p|0}if((c[(c[r>>2]|0)+796>>2]|0)<17){Fc=na;break}Dc=na;if((ca(c[t>>2]|0,c[s>>2]|0)|0)>0){Gc=0;Hc=w}else{Fc=w;break}while(1){w=c[Dc+(Gc<<2)>>2]|0;a[Hc]=w>>>8;a[Hc+1|0]=w>>>16;a[Hc+2|0]=w>>>24;w=Gc+1|0;if((w|0)<(ca(c[t>>2]|0,c[s>>2]|0)|0)){Gc=w;Hc=Hc+3|0}else{break}}Fc=c[u>>2]|0}else{Fc=na}}while(0);cJb(c[n+4203940>>2]|0,Fc,pa);pa=n+60|0;if((O|0)>(c[pa>>2]|0)){c[pa>>2]=O}pa=n+52|0;if((O|0)<(c[pa>>2]|0)){c[pa>>2]=O}pa=g+136|0;g=c[pa+4>>2]|0;n=f+8|0;c[n>>2]=c[pa>>2];c[n+4>>2]=g;g=c[q>>2]|0;c[m>>2]=1;c[m+4>>2]=c[e+412>>2];q=XIb(g,(g|0)<0|0?-1:0,m,e+104|0)|0;c[f+48>>2]=q;c[v>>2]=O;c[h>>2]=1;p=0;i=j;return p|0}function Zea(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((b|0)!=0){mJb(b+4203940|0);mJb(b+4203944|0);qPa(b+4203912|0)}mJb(a+96|0);c[a+100>>2]=0;return 0}function _ea(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;mrc(d|0,0,34)|0;f=c[b+48>>2]|0;g=d;y=je(f|f<<16|0)|0;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;g=c[b+56>>2]|0;f=d+4|0;y=je(g>>>16|c[b+52>>2]<<8|0)|0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=c[b+32>>2]|0;h=d+8|0;y=je(f>>>4|g<<16|0)|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=b+72|0;g=c[h>>2]|0;j=d+12|0;y=je((g>>>16|c[h+4>>2]<<16)&1048575|((c[(c[b+4203908>>2]|0)+796>>2]|0)+4095|((c[b+28>>2]|0)+127|f<<3)<<5)<<20|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=c[h>>2]&4095|g&-4096;g=j<<16;h=j>>>8&255;j=16;f=d+16|0;while(1){a[f]=h;k=g;g=k<<8;l=j+8|0;if((l|0)<32){h=k>>>16&255;j=l;f=f+1|0}else{break}}nrc(d+18|0,b+80|0,16)|0;i=e;return}function $ea(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;b=i;i=i+4840|0;e=b|0;f=b+4096|0;g=b+4224|0;h=b+4264|0;j=b+4328|0;k=b+4584|0;l=c[a+64>>2]|0;if(l>>>0<128>>>0){m=40}else{n=l>>>0>65535>>>0;o=n?l>>>16:l;l=n?16:0;if((o&65280|0)==0){p=l;q=o}else{p=l|8;q=o>>>8}o=((p+4+(d[1359664+q|0]|0)|0)/5|0)*6|0;q=40;while(1){p=o-6|0;if((p|0)>5){o=p;q=q+8|0}else{m=q;break}}}q=c[a+4203844>>2]|0;if((q|0)==7){r=m+16|0}else if((q|0)==6){r=m+8|0}else{r=m}m=c[a+36>>2]|0;q=r+8+(((m|0)==12)+((m|0)>12)<<3)|0;m=q;r=(q|0)<0|0?-1:0;q=a+28|0;if((c[q>>2]|0)>0){o=k;p=a+4203840|0;l=a+4203860|0;n=a+4203884|0;s=a+4203888|0;t=a+4203892|0;u=a+4203872|0;v=a+4203912|0;w=a+4203880|0;x=e|0;y=f|0;z=a+4203876|0;A=a+4205216|0;B=j|0;C=g|0;D=0;E=r;F=m;while(1){H=a+96+(D*525468|0)|0;I=a+96+(D*525468|0)+263324|0;J=a+96+(D*525468|0)+1184|0;K=c[p>>2]|0;L=1;while(1){if((L|0)>=(K|0)){break}if((c[a+96+(D*525468|0)+1184+(L<<2)>>2]|0)==(c[J>>2]|0)){L=L+1|0}else{break}}do{if((L|0)==(K|0)){c[a+96+(D*525468|0)+4>>2]=0;c[H>>2]=0;c[I>>2]=c[J>>2];M=afa(a,H,0)|0;N=M}else{if((c[l>>2]|0)!=0|(K|0)<5){c[a+96+(D*525468|0)+4>>2]=1;c[H>>2]=1;nrc(I|0,J|0,K<<2)|0;M=afa(a,H,0)|0;N=M;break}M=c[n>>2]|0;O=c[s>>2]|0;P=c[t>>2]|0;Q=H|0;c[Q>>2]=8;if(!((c[u>>2]|0)>>>0>1>>>0&(K|0)>(O|0))){R=(O|0)>4?4:O;c[C>>2]=-1;c[C+4>>2]=0;if((M|0)>(R|0)){S=0;T=8}else{U=0;V=M;do{bfa(I,J,K,V);W=cfa(a,H,V)|0;X=G;Y=g+(V<<3)|0;c[Y>>2]=W;c[Y+4>>2]=X;Y=g+(U<<3)|0;Z=c[Y+4>>2]|0;U=X>>>0<Z>>>0|X>>>0==Z>>>0&W>>>0<(c[Y>>2]|0)>>>0?V:U;V=V+1|0;}while((V|0)<=(R|0));S=U;T=c[Q>>2]|0}V=a+96+(D*525468|0)+16|0;c[V>>2]=S;c[a+96+(D*525468|0)+4>>2]=S|T;if((S|0)==(R|0)){_=R}else{bfa(I,J,K,S);cfa(a,H,c[V>>2]|0)|0;_=c[V>>2]|0}V=afa(a,H,_)|0;N=V;break}c[Q>>2]=32;V=pPa(v,J,K,M,O,c[w>>2]|0,x,y,c[u>>2]|0,c[z>>2]|0,P,15,0)|0;do{if((P-1|0)>>>0<3>>>0){Y=1<<P;W=Y-1|0;Z=O-1|0;X=h+(W<<3)|0;c[X>>2]=-1;c[X+4>>2]=0;if((Y|0)>0){X=1-M+O|0;$=M-1|0;aa=Z;ba=-1;da=W;ea=W;while(1){W=((ca(ea+1|0,X)|0)/(Y|0)|0)+$|0;if((W|0)<($|0)){fa=$}else{fa=(W|0)>(Z|0)?Z:W}if((fa|0)==(ba|0)){ga=da;ha=aa}else{W=fa+1|0;_e[c[A>>2]&511](I,J,K,W,e+(fa<<7)|0,c[f+(fa<<2)>>2]|0);ia=cfa(a,H,W)|0;W=G;ja=h+(ea<<3)|0;c[ja>>2]=ia;c[ja+4>>2]=W;ja=h+(da<<3)|0;ka=c[ja+4>>2]|0;la=W>>>0<ka>>>0|W>>>0==ka>>>0&ia>>>0<(c[ja>>2]|0)>>>0;ga=la?ea:da;ha=la?fa:aa}if((ea|0)>0){aa=ha;ba=fa;da=ga;ea=ea-1|0}else{ma=ha;break}}}else{ma=Z}na=ma+1|0}else{if((P|0)==4){c[B>>2]=-1;c[B+4>>2]=0;ea=M-1|0;if((ea|0)<(O|0)){oa=0;pa=ea}else{na=1;break}while(1){ea=pa+1|0;_e[c[A>>2]&511](I,J,K,ea,e+(pa<<7)|0,c[f+(pa<<2)>>2]|0);da=cfa(a,H,ea)|0;ba=G;aa=j+(pa<<3)|0;c[aa>>2]=da;c[aa+4>>2]=ba;aa=j+(oa<<3)|0;$=c[aa+4>>2]|0;qa=ba>>>0<$>>>0|ba>>>0==$>>>0&da>>>0<(c[aa>>2]|0)>>>0?pa:oa;if((ea|0)<(O|0)){oa=qa;pa=ea}else{break}}na=qa+1|0;break}else if((P|0)!=5){na=V;break}Z=M-1|0;mrc(o|0,-1|0,256)|0;ea=((O-M|0)/3|0)+Z|0;aa=16;while(1){da=ea-aa|0;$=ea+aa|0;if((da|0)>($|0)){ra=ea}else{ba=ea;Y=da;while(1){do{if((Y|0)>=(Z|0)&(Y|0)<(O|0)){da=k+(Y<<3)|0;X=c[da+4>>2]|0;la=0;if(X>>>0<la>>>0|X>>>0==la>>>0&(c[da>>2]|0)>>>0<-1>>>0){sa=ba;break}la=Y+1|0;_e[c[A>>2]&511](I,J,K,la,e+(Y<<7)|0,c[f+(Y<<2)>>2]|0);X=cfa(a,H,la)|0;la=G;c[da>>2]=X;c[da+4>>2]=la;da=k+(ba<<3)|0;ja=c[da+4>>2]|0;sa=la>>>0<ja>>>0|la>>>0==ja>>>0&X>>>0<(c[da>>2]|0)>>>0?Y:ba}else{sa=ba}}while(0);da=Y+aa|0;if((da|0)>($|0)){ra=sa;break}else{ba=sa;Y=da}}}Y=aa>>1;if((Y|0)==0){break}else{ea=ra;aa=Y}}na=ra+1|0}}while(0);O=a+96+(D*525468|0)+16|0;c[O>>2]=na;M=na-1|0;c[a+96+(D*525468|0)+4>>2]=c[Q>>2]|M;V=c[f+(M<<2)>>2]|0;M=a+96+(D*525468|0)+148|0;c[M>>2]=V;if((na|0)>0){P=0;R=na;do{c[a+96+(D*525468|0)+20+(P<<2)>>2]=c[e+(R-1<<7)+(P<<2)>>2];P=P+1|0;R=c[O>>2]|0;}while((P|0)<(R|0));ta=R;ua=c[M>>2]|0}else{ta=na;ua=V}_e[c[A>>2]&511](I,J,K,ta,a+96+(D*525468|0)+20|0,ua);cfa(a,H,c[O>>2]|0)|0;P=afa(a,H,c[O>>2]|0)|0;N=P}}while(0);H=wrc(N,(N|0)<0|0?-1:0,F,E)|0;K=G;J=D+1|0;if((J|0)<(c[q>>2]|0)){D=J;E=K;F=H}else{va=K;wa=H;break}}}else{va=r;wa=m}m=xrc(0,0,wa,va)|0;r=G&0;F=wrc(wa,va,16,0)|0;va=wrc(F,G,m&7,r)|0;r=G;m=3;if(r>>>0>m>>>0|r>>>0==m>>>0&va>>>0>-1>>>0){xa=-558323010;i=b;return xa|0}xa=va>>>3|r<<29;i=b;return xa|0}function afa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=c[b>>2]|0;if((e|0)==1){f=ca(c[b+8>>2]|0,c[a+4203840>>2]|0)|0;g=wrc(f,(f|0)<0|0?-1:0,8,0)|0;h=G;i=g;return(G=h,i)|0}else if((e|0)==0){g=c[b+8>>2]|0;f=wrc(g,(g|0)<0|0?-1:0,8,0)|0;h=G;i=f;return(G=h,i)|0}else{f=ca(c[b+8>>2]|0,d)|0;g=wrc(f,(f|0)<0|0?-1:0,8,0)|0;f=G;if((e|0)==32){e=(ca(c[a+4203880>>2]|0,d)|0)+9|0;j=wrc(e,(e|0)<0|0?-1:0,g,f)|0;k=G;l=j}else{k=f;l=g}g=c[b+156>>2]|0;f=c[a+4203840>>2]|0;a=f>>g;j=wrc(l,k,6,0)|0;k=G;l=1<<g;if((l|0)<=0){h=k;i=j;return(G=h,i)|0}g=c[b+152>>2]|0;e=0;m=d;d=a;n=k;k=j;j=0;while(1){o=c[b+160+(j<<2)>>2]|0;p=wrc(g,e,k,n)|0;q=G;r=d-m|0;if((r|0)>0){s=o+1|0;t=0;u=0;v=0;while(1){w=((c[b+263324+(v+m<<2)>>2]|0)*-2|0)-1|0;x=s+((w>>31^w)>>o)|0;w=wrc(x,(x|0)<0|0?-1:0,u,t)|0;x=G;y=v+1|0;if((y|0)<(r|0)){t=x;u=w;v=y}else{z=x;A=w;break}}}else{z=0;A=0}v=wrc(p,q,A,z)|0;u=G;t=d+a|0;r=j+1|0;if((r|0)<(l|0)){m=d;d=(f|0)>(t|0)?t:f;n=u;k=v;j=r}else{h=u;i=v;break}}return(G=h,i)|0}return 0}function bfa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((e|0)>0){f=0;do{c[a+(f<<2)>>2]=c[b+(f<<2)>>2];f=f+1|0;}while((f|0)<(e|0))}if((e|0)==1){if((d|0)>1){g=1}else{return}do{c[a+(g<<2)>>2]=(c[b+(g<<2)>>2]|0)-(c[b+(g-1<<2)>>2]|0);g=g+1|0;}while((g|0)<(d|0));return}else if((e|0)==2){if((d|0)<=2){return}g=(c[b+4>>2]|0)-(c[b>>2]|0)|0;f=2;do{h=b+(f<<2)|0;i=(c[h>>2]|0)-(c[b+(f-1<<2)>>2]|0)|0;c[a+(f<<2)>>2]=i-g;j=f|1;g=(c[b+(j<<2)>>2]|0)-(c[h>>2]|0)|0;c[a+(j<<2)>>2]=g-i;f=f+2|0;}while((f|0)<(d|0));return}else if((e|0)==0){if((d|0)>0){k=0}else{return}do{c[a+(k<<2)>>2]=c[b+(k<<2)>>2];k=k+1|0;}while((k|0)<(d|0));return}else{k=c[b+(e-1<<2)>>2]|0;f=c[b+(e-2<<2)>>2]|0;g=k-f|0;i=c[b+(e-3<<2)>>2]|0;j=k-(f<<1)+i|0;if((e|0)==3){if((d|0)>3){l=j;m=g;n=3}else{return}do{h=b+(n<<2)|0;o=(c[h>>2]|0)-(c[b+(n-1<<2)>>2]|0)|0;p=o-m|0;c[a+(n<<2)>>2]=p-l;q=n+1|0;m=(c[b+(q<<2)>>2]|0)-(c[h>>2]|0)|0;l=m-o|0;c[a+(q<<2)>>2]=l-p;n=n+2|0;}while((n|0)<(d|0));return}if((e|0)>=(d|0)){return}n=g;g=j;j=k-(c[b+(e-4<<2)>>2]|0)+((i-f|0)*3|0)|0;f=e;e=k;while(1){k=b+(f<<2)|0;i=(c[k>>2]|0)-e|0;l=i-n|0;m=l-g|0;c[a+(f<<2)>>2]=m-j;p=f+1|0;q=b+(p<<2)|0;o=(c[q>>2]|0)-(c[k>>2]|0)|0;k=o-i|0;i=k-l|0;c[a+(p<<2)>>2]=i-m;m=f+2|0;if((m|0)>=(d|0)){break}n=o;g=k;j=i;f=m;e=c[q>>2]|0}return}}function cfa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;i=i+19544|0;g=f|0;h=f+72|0;j=f+1104|0;k=f+1112|0;l=c[a+4203896>>2]|0;m=c[a+4203840>>2]|0;n=m-1^m;o=n>>>0>65535>>>0;p=o?n>>>16:n;n=o?16:0;o=(p&65280|0)==0;if(o){q=n;r=p}else{q=n|8;r=p>>>8}s=(d[1359664+r|0]|0)+q|0;q=(s|0)<(l|0)?s:l;l=(e|0)>0;if(l){s=(m|0)/(e|0)|0;r=s>>>0>65535>>>0;t=r?s>>>16:s;s=r?16:0;if((t&65280|0)==0){u=s;v=t}else{u=s|8;v=t>>>8}t=(d[1359664+v|0]|0)+u|0;w=(q|0)>(t|0)?t:q}else{w=q}q=c[a+4203900>>2]|0;if(o){x=n;y=p}else{x=n|8;y=p>>>8}p=(d[1359664+y|0]|0)+x|0;x=(p|0)<(q|0)?p:q;if(l){l=(m|0)/(e|0)|0;q=l>>>0>65535>>>0;p=q?l>>>16:l;l=q?16:0;if((p&65280|0)==0){z=l;A=p}else{z=l|8;A=p>>>8}p=(d[1359664+A|0]|0)+z|0;B=(x|0)>(p|0)?p:x}else{B=x}x=(ca(c[b+8>>2]|0,e)|0)+10|0;p=b+152|0;z=c[p>>2]|0;A=x+z|0;x=0;if((c[b>>2]|0)==32){l=(ca(c[a+4203880>>2]|0,e)|0)+9|0;a=wrc(l,(l|0)<0|0?-1:0,A,x)|0;C=G;D=a}else{C=x;D=A}A=h;x=j;a=h|0;c[a>>2]=z;l=hJb(m<<2)|0;c[j>>2]=l;if((m|0)>0){j=0;do{q=c[b+263324+(j<<2)>>2]|0;c[l+(j<<2)>>2]=q<<1^q>>31;j=j+1|0;}while((j|0)<(m|0))}j=1<<B;b=m>>B;if((j|0)>0){q=0;y=l+(e<<2)|0;n=l;while(1){l=n+(b<<2)|0;if(y>>>0<l>>>0){o=y;t=0;u=0;while(1){v=o+4|0;s=wrc(c[o>>2]|0,0,u,t)|0;r=G;if(v>>>0<l>>>0){o=v;t=r;u=s}else{E=v;F=r;H=s;break}}}else{E=y;F=0;H=0}u=k+(B<<11)+(q<<3)|0;c[u>>2]=H;c[u+4>>2]=F;u=q+1|0;if((u|0)<(j|0)){q=u;y=E;n=l}else{break}}}n=B-1|0;if((n|0)>=(w|0)){E=B;y=n;while(1){n=1<<y;if((n|0)>0){q=0;do{j=q<<1;F=k+(E<<11)+(j<<3)|0;H=k+(E<<11)+((j|1)<<3)|0;j=wrc(c[H>>2]|0,c[H+4>>2]|0,c[F>>2]|0,c[F+4>>2]|0)|0;F=k+(y<<11)+(q<<3)|0;c[F>>2]=j;c[F+4>>2]=G;q=q+1|0;}while((q|0)<(n|0))}n=y-1|0;if((n|0)<(w|0)){break}else{E=y;y=n}}}y=g+(w<<3)|0;c[y>>2]=-1;c[y+4>>2]=0;if((w|0)>(B|0)){I=0;J=-1;mJb(x);K=wrc(J,I,D,C)|0;L=G;i=f;return(G=L,K)|0}y=h+4|0;E=p;p=w;n=w;w=z;while(1){z=(1<<w)-2|0;q=1<<p;l=q<<2;F=l;j=(l|0)<0|0?-1:0;l=m>>p;if((q|0)>0){H=l-e|0;b=0;u=j;t=F;while(1){o=k+(p<<11)+(b<<3)|0;s=c[o>>2]|0;r=c[o+4>>2]|0;o=H>>1;v=o;M=(o|0)<0|0?-1:0;o=xrc(s,r,v,M)|0;N=G;if(M>>>0<r>>>0|M>>>0==r>>>0&v>>>0<s>>>0){s=Frc(o,N,H,(H|0)<0|0?-1:0)|0;v=G;r=wrc(s,v,-2147483648,0)|0;M=G;O=0;if(M>>>0>O>>>0|M>>>0==O>>>0&r>>>0>-1>>>0){((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1;P=(v>>31|((v|0)<0|0?-1:0)<<1)^2147483647}else{P=s}s=P>>>0>65535>>>0;v=s?P>>>16:P;r=s?16:0;if((v&65280|0)==0){Q=r;R=v}else{Q=r|8;R=v>>>8}v=(d[1359664+R|0]|0)+Q|0;S=(v|0)>(z|0)?z:v}else{S=0}c[h+8+(b<<2)>>2]=S;v=ca(S+1|0,H)|0;r=zrc(o|0,N|0,S|0)|0;N=wrc(r,G,t,u)|0;r=wrc(N,G,v,(v|0)<0|0?-1:0)|0;v=G;N=b+1|0;if((N|0)<(q|0)){H=l;b=N;u=v;t=r}else{T=v;U=r;break}}}else{T=j;U=F}c[y>>2]=p;t=g+(p<<3)|0;c[t>>2]=U;c[t+4>>2]=T;t=g+(n<<3)|0;u=c[t+4>>2]|0;if(T>>>0>u>>>0|T>>>0==u>>>0&U>>>0>(c[t>>2]|0)>>>0){V=n}else{nrc(E|0,A|0,1032)|0;V=p}t=p+1|0;if((t|0)>(B|0)){break}p=t;n=V;w=c[a>>2]|0}a=g+(V<<3)|0;I=c[a+4>>2]|0;J=c[a>>2]|0;mJb(x);K=wrc(J,I,D,C)|0;L=G;i=f;return(G=L,K)|0}function dfa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+60|0;e=c[d>>2]|0;c[e>>2]=a;c[e+64>>2]=0;c[e+68>>2]=0;c[e+72>>2]=0;f=_pc(e+32|0,2403776,56)|0;if((f|0)!=0){KIb(a,16,2396712,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=1;i=b;return h|0}c[a+140>>2]=3;a=UHb()|0;c[e+4>>2]=a;if((a|0)!=0){h=0;i=b;return h|0}a=c[d>>2]|0;cqc(a+32|0)|0;VHb(a+4|0);mJb(a+24|0);h=-12;i=b;return h|0}function efa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;h=i;i=i+112|0;j=h|0;k=h+56|0;l=g+28|0;m=c[l>>2]|0;n=b+60|0;o=c[n>>2]|0;p=o+16|0;q=c[p>>2]|0;r=o+20|0;s=c[r>>2]|0;if((m|0)==0){t=0;i=h;return t|0}if((m|0)<4){t=-1;i=h;return t|0}u=g+24|0;v=c[u>>2]|0;w=m>>>0>268435455>>>0?-8:m<<3;x=w>>>0>2147483639>>>0|(v|0)==0;y=x?0:v;v=x?0:w;w=v+8|0;if(x){t=x?-1094995529:0;i=h;return t|0}x=y;z=w>>>0>4>>>0?4:w;A=((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24)&240)+16|0;c[p>>2]=A;x=y+(z>>>3)|0;B=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&4)>>>20;x=z+12|0;z=w>>>0>x>>>0?x:w;x=o+8|0;c[x>>2]=B;B=y+(z>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7)>>>28;B=z+4|0;z=w>>>0>B>>>0?B:w;B=(C<<4)+16|0;c[r>>2]=B;C=y+(z>>>3)|0;D=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(z&7)>>>20;C=z+12|0;z=w>>>0>C>>>0?C:w;C=o+12|0;c[C>>2]=D;if(!((q|0)==(A|0)&(s|0)==(B|0))){mJb(o+108|0)}B=o+88|0;do{if((c[B>>2]|0)==2){s=z+6|0;A=w>>>0>s>>>0?s:w;s=((A|0)<(w|0))+A|0;if(((d[y+(A>>>3)|0]|0)&128>>>((A&7)>>>0)|0)!=0){QIb(b,2248352,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1163346256;i=h;return t|0}if(((d[y+(s>>>3)|0]|0)&128>>>((s&7)>>>0)|0)==0){F=((s|0)<(w|0))+s|0;break}QIb(b,2206272,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1163346256;i=h;return t|0}else{F=z}}while(0);z=c[x>>2]|0;s=c[p>>2]|0;A=(z|0)/(s|0)|0;q=(z|0)%(s|0)|0;z=c[C>>2]|0;D=c[r>>2]|0;G=(z|0)/(D|0)|0;H=(z|0)%(D|0)|0;z=o+28|0;a:do{if((c[z>>2]|0)<(ca(D,s)|0)){I=ca(s*3|0,D)|0;J=lJb(o+24|0,I)|0;if((J|0)<0){c[z>>2]=0;KIb(b,16,2173984,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=J;i=h;return t|0}if((c[B>>2]|0)!=2){break}c[j+32>>2]=0;c[j+36>>2]=0;c[j+40>>2]=0;do{if((Gpc(j,0,2403776,56)|0)==0){J=Mpc(j,I)|0;Ipc(j)|0;c[o+116>>2]=J;if((J|0)<1){break}K=lJb(o+112|0,J)|0;if((K|0)>=0){break a}c[z>>2]=0;KIb(b,16,2122608,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=K;i=h;return t|0}else{c[o+116>>2]=-1}}while(0);KIb(b,16,2146400,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1;i=h;return t|0}}while(0);c[z>>2]=ca(c[r>>2]|0,c[p>>2]|0)|0;z=b+120|0;j=c[z>>2]|0;do{if((j|0)==0){if((c[b+124>>2]|0)!=0){L=0;break}D=H4a(b,c[x>>2]|0,c[C>>2]|0)|0;if((D|0)<0){t=D;i=h;return t|0}else{L=c[z>>2]|0;break}}else{L=j}}while(0);j=b+124|0;do{if((L|0)==(c[x>>2]|0)){if((c[j>>2]|0)!=(c[C>>2]|0)){break}do{if((c[g+36>>2]&1|0)==0){D=o+96|0;c[D>>2]=0;M=D}else{D=(c[B>>2]|0)==2;s=o+96|0;c[s>>2]=D&1;if(!D){M=s;break}D=o+100|0;I=lJb(D,c[l>>2]|0)|0;if((I|0)<0){t=I;i=h;return t|0}else{nrc(c[D>>2]|0,c[u>>2]|0,c[l>>2]|0)|0;M=s;break}}}while(0);do{if((c[B>>2]|0)==2){s=o+108|0;if((c[s>>2]|0)!=0){break}c[s>>2]=pJb(ca(((q|0)!=0)+A<<3,((H|0)!=0)+G|0)|0)|0}}while(0);s=o+4|0;D=N4a(b,c[s>>2]|0)|0;if((D|0)<0){t=D;i=h;return t|0}D=((H|0)!=0)+G|0;b:do{if((D|0)>0){I=((q|0)!=0)+A|0;K=(I|0)>0;J=o+120|0;N=J;O=o+124|0;P=o+128|0;Q=o+132|0;R=o+136|0;S=b;T=k+32|0;U=k+36|0;V=k+40|0;W=k|0;X=k+4|0;Y=k+12|0;Z=k+16|0;_=o+108|0;$=o+104|0;aa=F;ba=0;c:while(1){da=c[r>>2]|0;ea=ca(da,ba)|0;fa=(ba|0)<(G|0)?da:H;if(K){da=ca(ba,I)|0;ga=~ea;ha=(fa|0)>0;ia=aa;ja=0;while(1){ka=c[p>>2]|0;la=ca(ka,ja)|0;ma=(ja|0)<(A|0)?ka:q;ka=y+(ia>>>3)|0;na=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ia&7)>>>16;ka=ia+16|0;oa=w>>>0>ka>>>0?ka:w;mrc(J|0,0,16)|0;c[R>>2]=fa;if((na<<3|0)>(v-oa|0)){pa=43;break c}d:do{if((c[B>>2]|0)!=2|(na|0)==0){qa=oa;ra=na}else{ka=oa+3|0;sa=w>>>0>ka>>>0?ka:w;ka=y+(sa>>>3)|0;ta=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(sa&7)>>>30;ka=sa+2|0;sa=w>>>0>ka>>>0?ka:w;c[N>>2]=ta;ka=d[y+(sa>>>3)|0]|0;ua=((sa|0)<(w|0))+sa|0;va=((ua|0)<(w|0))+ua|0;c[O>>2]=(d[y+(ua>>>3)|0]|0)<<(ua&7)>>>7&1;ua=((va|0)<(w|0))+va|0;wa=(d[y+(va>>>3)|0]|0)<<(va&7)>>>7&1;c[P>>2]=wa;if(!((ta|0)==0|(ta|0)==2)){pa=46;break c}va=(ka&128>>>((sa&7)>>>0)|0)==0;if(va){xa=na;ya=ua;za=wa}else{if((c[$>>2]|0)==0){pa=49;break c}wa=y+(ua>>>3)|0;Aa=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ua&7)>>>24;wa=ua+8|0;ua=w>>>0>wa>>>0?wa:w;c[Q>>2]=Aa;wa=y+(ua>>>3)|0;Ba=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ua&7)>>>24;wa=ua+8|0;c[R>>2]=Ba;if((Ba+Aa|0)>(fa|0)){pa=51;break c}KIb(S,48,2532352,(E=i,i=i+32|0,c[E>>2]=ja,c[E+8>>2]=ba,c[E+16>>2]=Aa,c[E+24>>2]=Ba,E)|0);i=E;xa=na-2|0;ya=w>>>0>wa>>>0?wa:w;za=c[P>>2]|0}if((za|0)!=0){KIb(S,48,2517056,(E=i,i=i+16|0,c[E>>2]=ja,c[E+8>>2]=ba,E)|0);i=E}if((c[O>>2]|0)!=0){pa=56;break c}if((c[_>>2]|0)==0){if((c[P>>2]|0)!=0){pa=59;break c}}wa=xa-1|0;if(va){qa=ya;ra=wa;break}va=c[s>>2]|0;ua=c[va+32>>2]|0;sa=ca(ua,(c[C>>2]|0)+ga|0)|0;if(!ha){qa=ya;ra=wa;break}ka=la*3|0;Ca=ma*3|0;Da=0;Ea=va;va=ua;while(1){ua=sa-(ca(va,Da)|0)+ka|0;nrc((c[Ea>>2]|0)+ua|0,(c[$>>2]|0)+ua|0,Ca)|0;ua=Da+1|0;if((ua|0)>=(fa|0)){qa=ya;ra=wa;break d}Fa=c[s>>2]|0;Da=ua;Ea=Fa;va=c[Fa+32>>2]|0}}}while(0);e:do{if((ra|0)==0){Ga=qa}else{na=ja+da|0;oa=c[n>>2]|0;va=oa+24|0;Ea=c[va>>2]|0;Da=oa+32|0;wa=Da;Ca=Xpc(wa)|0;f:do{if((Ca|0)==0){do{if((c[oa+124>>2]|0)==0){if((c[oa+128>>2]|0)!=0){pa=71;break}Ha=Da;Ia=oa+36|0;Ja=oa+44|0;Ka=oa+28|0;La=oa+48|0}else{pa=71}}while(0);do{if((pa|0)==71){pa=0;ka=c[oa+108>>2]|0;sa=c[ka+(na<<3)>>2]|0;Fa=c[ka+(na<<3)+4>>2]|0;if((sa|0)==0){break f}c[T>>2]=0;c[U>>2]=0;c[V>>2]=0;ka=Da;c[ka>>2]=sa;sa=oa+36|0;c[sa>>2]=Fa;Fa=oa+44|0;c[Fa>>2]=c[va>>2];ua=oa+28|0;Ma=oa+48|0;c[Ma>>2]=(c[ua>>2]|0)*3|0;$pc(wa,2)|0;if((Gpc(k,0,2403776,56)|0)!=0){break f}c[W>>2]=c[va>>2];c[X>>2]=((c[ua>>2]|0)*3|0)-(c[Ma>>2]|0);Na=oa+112|0;c[Y>>2]=c[Na>>2];Oa=oa+116|0;c[Z>>2]=c[Oa>>2];Lpc(k,2)|0;Ipc(k)|0;Pa=Xpc(wa)|0;if((Pa|0)==0){c[ka>>2]=c[Na>>2];c[sa>>2]=(c[Oa>>2]|0)-(c[Z>>2]|0);c[Fa>>2]=c[va>>2];c[Ma>>2]=(c[ua>>2]|0)*3|0;$pc(wa,2)|0;Ha=ka;Ia=sa;Ja=Fa;Ka=ua;La=Ma;break}else{KIb(c[oa>>2]|0,16,2430920,(E=i,i=i+8|0,c[E>>2]=Pa,E)|0);i=E;break f}}}while(0);Pa=(qa|0)/8|0;c[Ha>>2]=(c[u>>2]|0)+Pa;c[Ia>>2]=ra;c[Ja>>2]=c[va>>2];c[La>>2]=(c[Ka>>2]|0)*3|0;if(($pc(wa,4)|0)==-3){KIb(S,16,2420688,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;dqc(wa)|0;$pc(wa,4)|0}if((c[oa+96>>2]|0)!=0){Ma=oa+108|0;c[(c[Ma>>2]|0)+(na<<3)>>2]=(c[oa+100>>2]|0)+Pa;c[(c[Ma>>2]|0)+(na<<3)+4>>2]=ra}Ma=(c[oa+132>>2]|0)+ea|0;do{if((c[oa+120>>2]|0)==0){Pa=oa+136|0;if((c[Pa>>2]|0)<1){break}ua=oa+4|0;Fa=la*3|0;sa=oa+12|0;ka=ma*3|0;Oa=Ea;Na=1;while(1){Qa=c[ua>>2]|0;nrc((c[Qa>>2]|0)+((ca((c[sa>>2]|0)-(Na+Ma)|0,c[Qa+32>>2]|0)|0)+Fa)|0,Oa|0,ka)|0;Qa=Na+1|0;if((Qa|0)>(c[Pa>>2]|0)){break}else{Oa=Oa+ka|0;Na=Qa}}}else{Na=c[va>>2]|0;ka=c[Ja>>2]|0;Oa=c[oa+4>>2]|0;Pa=c[Oa>>2]|0;Fa=c[oa+136>>2]|0;sa=(c[oa+12>>2]|0)+~Ma|0;ua=sa-Fa|0;Qa=c[Oa+32>>2]|0;Oa=c[oa+92>>2]|0;g:do{if((Fa|0)>0){Ra=la*3|0;if((ma|0)>0){Sa=sa;Ta=Na}else{Ua=Na;pa=93;break}while(1){Va=Pa+((ca(Sa,Qa)|0)+Ra)|0;Wa=0;Xa=Ta;while(1){if(!(Xa>>>0<ka>>>0)){break g}Ya=d[Xa]|0;if((Ya&128|0)==0){Za=c[Oa+(Ya<<2)>>2]|0;a[Va]=Za;a[Va+1|0]=Za>>>8;a[Va+2|0]=Za>>>16;_a=Xa+1|0}else{Za=Xa;Ya=(he((d[Za]|d[Za+1|0]<<8)<<16>>16|0)|0)&65535;a[Va]=Ya>>>2&7|Ya<<3;a[Va+1|0]=Ya>>>5<<3|Ya>>>7&7;a[Va+2|0]=Ya>>>10<<3|Ya>>>12&7;_a=Xa+2|0}Ya=Wa+1|0;if((Ya|0)<(ma|0)){Va=Va+3|0;Wa=Ya;Xa=_a}else{break}}Xa=Sa-1|0;if((Xa|0)>(ua|0)){Sa=Xa;Ta=_a}else{Ua=_a;pa=93;break}}}else{Ua=Na;pa=93}}while(0);if((pa|0)==93){pa=0;if((Ua-Na|0)>=0){break}}KIb(S,16,2411376,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;break f}}while(0);Ma=ra<<3;ua=-qa|0;Oa=w-qa|0;if((Ma|0)<(ua|0)){$a=ua}else{$a=(Oa|0)<(Ma|0)?Oa:Ma}Ga=$a+qa|0;break e}else{KIb(S,16,2430920,(E=i,i=i+8|0,c[E>>2]=Ca,E)|0);i=E}}while(0);KIb(S,16,2469240,(E=i,i=i+16|0,c[E>>2]=ja,c[E+8>>2]=ba,E)|0);i=E;Ga=qa}}while(0);ma=ja+1|0;if((ma|0)<(I|0)){ia=Ga;ja=ma}else{ab=Ga;break}}}else{ab=aa}ia=ba+1|0;if((ia|0)<(D|0)){aa=ab;ba=ia}else{bb=ab;break b}}if((pa|0)==43){WHb(c[s>>2]|0);t=-1094995529;i=h;return t|0}else if((pa|0)==46){KIb(S,16,2590272,(E=i,i=i+24|0,c[E>>2]=ja,c[E+8>>2]=ba,c[E+16>>2]=ta,E)|0);i=E;t=-1094995529;i=h;return t|0}else if((pa|0)==49){KIb(S,16,2568552,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1094995529;i=h;return t|0}else if((pa|0)==51){KIb(S,16,2550504,(E=i,i=i+24|0,c[E>>2]=Aa,c[E+8>>2]=Ba,c[E+16>>2]=fa,E)|0);i=E;t=-1094995529;i=h;return t|0}else if((pa|0)==56){aa=y+(ya>>>3)|0;I=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ya&7)>>>24;aa=ya+8|0;Z=w>>>0>aa>>>0?aa:w;aa=y+(Z>>>3)|0;Y=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(Z&7)>>>24;KIb(S,48,2503024,(E=i,i=i+32|0,c[E>>2]=ja,c[E+8>>2]=ba,c[E+16>>2]=I,c[E+24>>2]=Y,E)|0);i=E;QIb(S,2489960,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1163346256;i=h;return t|0}else if((pa|0)==59){KIb(S,16,2479016,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-1094995529;i=h;return t|0}}else{bb=F}}while(0);do{if((c[M>>2]|0)!=0){if((c[B>>2]|0)!=2){break}D=o+104|0;Y=c[D>>2]|0;do{if((Y|0)==0){I=hJb(ca(c[j>>2]|0,c[(c[s>>2]|0)+32>>2]|0)|0)|0;c[D>>2]=I;if((I|0)!=0){cb=I;break}KIb(b,16,2460096,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;t=-12;i=h;return t|0}else{cb=Y}}while(0);Y=c[s>>2]|0;nrc(cb|0,c[Y>>2]|0,ca(c[j>>2]|0,c[Y+32>>2]|0)|0)|0}}while(0);Y=YHb(e,c[s>>2]|0)|0;if((Y|0)<0){t=Y;i=h;return t|0}c[f>>2]=1;Y=(bb|0)/8|0;if((Y|0)==(m|0)){t=m;i=h;return t|0}KIb(b,16,2443360,(E=i,i=i+16|0,c[E>>2]=m,c[E+8>>2]=Y,E)|0);i=E;t=m;i=h;return t|0}}while(0);m=b;KIb(m,16,2640368,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;b=c[z>>2]|0;z=c[C>>2]|0;C=c[x>>2]|0;KIb(m,16,2617592,(E=i,i=i+32|0,c[E>>2]=c[j>>2],c[E+8>>2]=b,c[E+16>>2]=z,c[E+24>>2]=C,E)|0);i=E;t=-1094995529;i=h;return t|0}function ffa(a){a=a|0;var b=0;b=c[a+60>>2]|0;cqc(b+32|0)|0;VHb(b+4|0);mJb(b+24|0);return 0}function gfa(a){a=a|0;var b=0;b=c[a+60>>2]|0;dfa(a)|0;c[b+92>>2]=1387920;c[b+88>>2]=2;return 0}function hfa(a){a=a|0;var b=0;b=a+60|0;a=c[b>>2]|0;mJb(a+100|0);mJb(a+108|0);mJb(a+104|0);mJb(a+112|0);a=c[b>>2]|0;cqc(a+32|0)|0;VHb(a+4|0);mJb(a+24|0);return 0}function ifa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;e=c[b+60>>2]|0;f=e;c[e>>2]=b;g=c[b+84>>2]|0;h=(g|0)==-1?9:g;c[e+56>>2]=h;if(h>>>0>9>>>0){KIb(b,16,2122560,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;k=-1;i=d;return k|0}h=b+120|0;g=c[h>>2]|0;do{if((g|0)<=4095){l=b+124|0;m=c[l>>2]|0;if((m|0)>4095){break}n=b;if((g|0)<16|(m|0)<16){KIb(n,16,2617528,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=d;return k|0}if((tIb(g,m,0,n)|0)<0){k=-1;i=d;return k|0}c[e+68>>2]=0;m=c[h>>2]|0;c[e+72>>2]=m;o=c[l>>2]|0;c[e+76>>2]=o;l=((m|0)/12|0)&-16;p=e+80|0;c[p>>2]=l;q=((o|0)/12|0)&-16;r=e+84|0;c[r>>2]=q;if((l|0)==0){c[p>>2]=1;s=1}else{s=l}if((q|0)==0){c[r>>2]=1;t=1}else{t=q}q=(o-1+t|0)/(t|0)|0;c[e+60>>2]=q;r=(m-1+s|0)/(s|0)|0;c[e+64>>2]=r;l=ca(m*3|0,o)|0;o=e+40|0;c[o>>2]=l;m=e+44|0;c[m>>2]=ca(q<<5,r)|0;r=e+12|0;q=r;c[q>>2]=pJb(l)|0;l=e+16|0;p=l;c[p>>2]=pJb(c[o>>2]|0)|0;u=e+20|0;v=u;c[v>>2]=pJb((c[o>>2]|0)*6|0)|0;w=e+4|0;x=w;c[x>>2]=pJb(c[o>>2]|0)|0;y=e+8|0;z=y;c[z>>2]=pJb(c[o>>2]|0)|0;o=e+32|0;A=o;c[A>>2]=pJb(c[m>>2]|0)|0;B=e+36|0;C=B;c[C>>2]=pJb(c[m>>2]|0)|0;m=e+24|0;c[m>>2]=0;c[e+28>>2]=0;mfa(f,c[A>>2]|0,c[q>>2]|0,c[v>>2]|0);mfa(f,c[C>>2]|0,c[p>>2]|0,0);a[e+89|0]=0;a[e+90|0]=-1;do{if((c[q>>2]|0)!=0){if((c[p>>2]|0)==0){break}if((c[v>>2]|0)==0){break}if((c[x>>2]|0)==0){break}if((c[z>>2]|0)==0){break}if((c[C>>2]|0)==0){break}if((c[A>>2]|0)==0){break}else{k=0}i=d;return k|0}}while(0);KIb(n,16,2248320,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;mJb(r);mJb(l);mJb(u);mJb(m);mJb(w);mJb(y);mJb(o);mJb(B);k=-1;i=d;return k|0}}while(0);KIb(b,16,2640304,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=d;return k|0}function jfa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;h=i;i=i+56|0;j=h|0;k=c[b+60>>2]|0;l=k;m=k+40|0;n=(c[m>>2]|0)+16384|0;o=d5a(b,e,n,(n|0)<0|0?-1:0)|0;if((o|0)<0){p=o;i=h;return p|0}o=b+428|0;n=c[o>>2]|0;q=(n|0)==0;r=c[b+136>>2]|0;if((r|0)>0){if((n|0)<((c[k+68>>2]|0)+r|0)&(q^1)){s=1}else{t=5}}else{if(q){t=5}else{s=1}}do{if((t|0)==5){q=((c[k+76>>2]|0)+63|0)/64|0;r=k+60|0;c[r>>2]=q;n=((c[k+72>>2]|0)+63|0)/64|0;u=k+64|0;c[u>>2]=n;v=k+80|0;w=k+84|0;if((c[v>>2]|0)==64){if((c[w>>2]|0)!=64){t=7}}else{t=7}do{if((t|0)==7){c[v>>2]=64;c[w>>2]=64;x=ca(n,q)|0;z=k+44|0;A=k+32|0;B=c[A>>2]|0;do{if(x>>>0>(c[z>>2]|0)>>>5>>>0){c[A>>2]=iJb(B,x<<5)|0;C=k+36|0;D=iJb(c[C>>2]|0,ca(c[u>>2]<<5,c[r>>2]|0)|0)|0;c[C>>2]=D;E=c[A>>2]|0;if(!((E|0)==0|(D|0)==0)){c[z>>2]=ca(c[r>>2]<<5,c[u>>2]|0)|0;F=E;G=C;break}KIb(c[k>>2]|0,16,2248320,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;p=-1;i=h;return p|0}else{F=B;G=k+36|0}}while(0);mfa(l,F,c[k+12>>2]|0,c[k+20>>2]|0);mfa(l,c[G>>2]|0,c[k+16>>2]|0,0);B=k+24|0;xJb(B,k+28|0,24576);if((c[B>>2]|0)!=0){break}KIb(c[k>>2]|0,16,2206232,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;p=-12;i=h;return p|0}}while(0);u=k;r=(c[(c[u>>2]|0)+80>>2]|0)==0;c[k+48>>2]=r&1;if(!r){s=0;break}r=k+90|0;q=a[r]|0;if((a[k+89|0]|0)!=0){n=q<<24>>24!=1;if(n){p=n<<31>>31}else{s=0;break}i=h;return p|0}if(q<<24>>24==0){s=0;break}nrc(k+92|0,1572720,512)|0;q=4;do{n=q<<16;w=q<<7&31744;v=4;do{B=v<<8;z=v<<2&992|w;A=4;do{x=A|B;C=x>>>8&255;E=(x|n)>>>16&255;x=C+A+E|0;D=-1;I=2147483647;J=0;while(1){K=c[l+92+(J<<2)>>2]|0;L=K&255;M=K>>>8&255;N=K>>>16&255;K=L-x+M+N|0;O=L-A|0;L=M-C|0;M=N-E|0;N=((L|0)>-1?L:-L|0)+((O|0)>-1?O:-O|0)+((M|0)>-1?M:-M|0)+((K|0)>-1?K:-K|0)|0;K=(N|0)<(I|0);P=K?J:D;M=J+1|0;if((M|0)<128){D=P;I=K?N:I;J=M}else{break}}a[(z|A>>3)+(l+604)|0]=P;A=A+8|0;}while((A|0)<256);v=v+8|0;}while((v|0)<256);q=q+8|0;}while((q|0)<256);a[r]=0;KIb(c[u>>2]|0,48,2146368,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;s=0}}while(0);P=k+48|0;if((c[P>>2]|0)!=0){c[k+52>>2]=15}l=c[f>>2]|0;G=c[f+32>>2]|0;f=c[e+24>>2]|0;F=e+28|0;q=c[F>>2]|0;v=k+76|0;n=c[v>>2]|0;if((n|0)>0){w=k+64|0;A=k+32|0;z=k+84|0;B=k+80|0;J=k+72|0;I=k+4|0;D=k+8|0;E=n;n=c[w>>2]|0;while(1){C=E-1|0;if((n|0)>0){x=ca(C,G)|0;M=0;N=n;while(1){K=(c[v>>2]|0)-C-1|0;O=c[A>>2]|0;L=c[z>>2]|0;Q=(ca((K|0)/(L|0)|0,N)|0)+M|0;R=ca(c[B>>2]|0,M)|0;S=((ca(c[J>>2]|0,K)|0)+R|0)*3|0;T=l+((R*3|0)+x)|0;R=(c[I>>2]|0)+S|0;U=(c[D>>2]|0)+S|0;S=(K|0)%(L|0)|0;L=O+(Q<<5)+29|0;K=a[L]|0;V=(K&255)*3|0;if((grc(T,R,V)|0)==0){W=K}else{a[O+(Q<<5)+26|0]=1;nrc(R|0,T|0,V)|0;W=a[L]|0}if((grc(T,U,(W&255)*3|0)|0)!=0){U=O+(Q<<5)+25|0;if((a[U]|0)==0){T=S&255;a[O+(Q<<5)+24|0]=T;X=T}else{X=a[O+(Q<<5)+24|0]|0}a[U]=S+1-(X&255)}S=M+1|0;U=c[w>>2]|0;if((S|0)<(U|0)){M=S;N=U}else{Y=U;break}}}else{Y=n}if((C|0)>0){E=C;n=Y}else{break}}}Y=k+60|0;n=c[Y>>2]|0;a:do{if((n|0)>0){E=k+64|0;w=k+32|0;X=k+36|0;W=k+4|0;D=k+72|0;I=k+84|0;l=k+80|0;J=k+92|0;B=k+56|0;z=k+52|0;A=k+24|0;G=j+32|0;N=j+36|0;M=j+40|0;x=j|0;u=j+4|0;r=j+12|0;U=j+16|0;S=0;Q=c[E>>2]|0;O=n;while(1){if((Q|0)>0){T=0;L=Q;do{V=c[w>>2]|0;R=(ca(L,S)|0)+T|0;K=c[X>>2]|0;Z=(c[P>>2]|0)!=0;_=Z?16:0;$=V+(R<<5)+31|0;a[$]=_;do{if(s){aa=V+(R<<5)+24|0;if((a[V+(R<<5)+26|0]|0)==0){a[aa]=0;a[V+(R<<5)+25|0]=0;c[V+(R<<5)+20>>2]=0;break}ba=(a[aa]|0)==0;if(ba){aa=a[V+(R<<5)+25|0]|0;da=V+(R<<5)+30|0;ea=a[da]|0;if(aa<<24>>24==ea<<24>>24){fa=aa;ga=1;ha=da;t=53;break}else{ia=ea}}else{ia=a[V+(R<<5)+30|0]|0}a[$]=_|4;fa=ia;ga=ba;ha=V+(R<<5)+30|0;t=53}else{a[V+(R<<5)+24|0]=0;ba=V+(R<<5)+30|0;ea=a[ba]|0;a[V+(R<<5)+25|0]=ea;fa=ea;ga=1;ha=ba;t=53}}while(0);do{if((t|0)==53){t=0;_=c[W>>2]|0;ba=(c[D>>2]|0)*3|0;ea=ca(ca(c[I>>2]|0,S)|0,ba)|0;da=ea+(ca(T*3|0,c[l>>2]|0)|0)|0;ea=c[B>>2]|0;aa=c[z>>2]|0;ja=c[A>>2]|0;ka=V+(R<<5)+29|0;la=a[ka]|0;ma=la&255;na=ca((fa&255)*6|0,ma)|0;oa=V+(R<<5)|0;pa=c[oa>>2]|0;qa=V+(R<<5)+24|0;if(Z){do{if(ga){ra=0;sa=pa;ta=0}else{ua=pa+(lfa(J,pa,_+da|0,ma,aa)|0)|0;va=a[qa]|0;if((va&255)>>>0>1>>>0){wa=ua;xa=1;while(1){ya=wa+(lfa(J,wa,_+((ca(xa,ba)|0)+da)|0,d[ka]|0,aa)|0)|0;za=xa+1|0;Aa=d[qa]|0;if((za|0)<(Aa|0)){wa=ya;xa=za}else{ra=za;sa=ya;ta=Aa;break}}}else{ra=1;sa=ua;ta=va&255;break}}}while(0);c[V+(R<<5)+4>>2]=sa;xa=V+(R<<5)+25|0;if((ra|0)<((d[xa]|0)+ta|0)){wa=ra;Aa=sa;while(1){ya=_+((ca(wa,ba)|0)+da)|0;za=Aa+(lfa(J,Aa,ya,d[ka]|0,aa)|0)|0;ya=wa+1|0;if((ya|0)<((d[xa]|0)+(d[qa]|0)|0)){wa=ya;Aa=za}else{Ba=ya;Ca=za;break}}}else{Ba=ra;Ca=sa}c[V+(R<<5)+8>>2]=Ca;if((Ba|0)<(d[ha]|0)){Aa=Ba;wa=Ca;while(1){xa=_+((ca(Aa,ba)|0)+da)|0;za=wa+(lfa(J,wa,xa,d[ka]|0,aa)|0)|0;xa=Aa+1|0;if((xa|0)<(d[ha]|0)){Aa=xa;wa=za}else{Da=za;break}}}else{Da=Ca}c[V+(R<<5)+12>>2]=Da-(c[oa>>2]|0)}else{if(ga){Ea=0;Fa=pa;Ga=0;Ha=la}else{wa=0;Aa=ma;aa=pa;while(1){nrc(aa|0,_+((ca(wa,ba)|0)+da)|0,Aa*3|0)|0;za=wa+1|0;xa=d[qa]|0;ya=a[ka]|0;Ia=ya&255;Ja=pa+(ca(za*3|0,Ia)|0)|0;if((za|0)<(xa|0)){wa=za;Aa=Ia;aa=Ja}else{Ea=za;Fa=Ja;Ga=xa;Ha=ya;break}}}c[V+(R<<5)+4>>2]=Fa;aa=V+(R<<5)+25|0;Aa=Ha&255;wa=pa+(ca(Aa*3|0,Ea)|0)|0;if((Ea|0)<((d[aa]|0)+Ga|0)){ma=Ea;la=Aa;Aa=wa;while(1){nrc(Aa|0,_+((ca(ma,ba)|0)+da)|0,la*3|0)|0;ya=ma+1|0;xa=a[ka]|0;Ja=xa&255;za=pa+(ca(ya*3|0,Ja)|0)|0;if((ya|0)<((d[aa]|0)+(d[qa]|0)|0)){ma=ya;la=Ja;Aa=za}else{Ka=ya;La=za;Ma=xa;break}}}else{Ka=Ea;La=wa;Ma=Ha}c[V+(R<<5)+8>>2]=La;Aa=Ma&255;la=pa+(ca(Aa*3|0,Ka)|0)|0;if((Ka|0)<(d[ha]|0)){ma=Ka;qa=Aa;Aa=la;while(1){nrc(Aa|0,_+((ca(ma,ba)|0)+da)|0,qa*3|0)|0;aa=ma+1|0;xa=d[ka]|0;za=pa+(ca(aa*3|0,xa)|0)|0;if((aa|0)<(d[ha]|0)){ma=aa;qa=xa;Aa=za}else{Na=za;break}}}else{Na=la}c[V+(R<<5)+12>>2]=Na-(c[oa>>2]|0)}Aa=V+(R<<5)+20|0;if((a[V+(R<<5)+25|0]|0)==0){c[Aa>>2]=0;break}c[Aa>>2]=na;qa=V+(R<<5)+16|0;ma=V+(R<<5)+4|0;pa=c[ma>>2]|0;ka=V+(R<<5)+8|0;if((Bpc(c[qa>>2]|0,Aa,pa,(c[ka>>2]|0)-pa|0,ea)|0)!=0){Oa=-1;t=101;break a}if(!s){break}c[G>>2]=0;c[N>>2]=0;c[M>>2]=0;if((Gpc(j,ea,2299376,56)|0)<0){Pa=-1;break a}c[x>>2]=c[K+(R<<5)>>2];pa=c[K+(R<<5)+12>>2]|0;c[u>>2]=pa;if((pa|0)!=0){do{c[r>>2]=ja;c[U>>2]=na;if((Lpc(j,2)|0)<0){Oa=-1;t=101;break a}}while((c[u>>2]|0)!=0)}ea=c[ma>>2]|0;c[x>>2]=ea;c[u>>2]=(c[ka>>2]|0)-ea;c[r>>2]=ja;c[U>>2]=na;ea=Lpc(j,4)|0;Ipc(j)|0;oa=na-(c[U>>2]|0)|0;if((ea|0)!=1){Oa=-1;t=101;break a}if(!(oa>>>0<(c[Aa>>2]|0)>>>0)){break}c[Aa>>2]=oa;nrc(c[qa>>2]|0,ja|0,oa)|0;a[$]=a[$]|1}}while(0);T=T+1|0;L=c[E>>2]|0;}while((T|0)<(L|0));Qa=L;Ra=c[Y>>2]|0}else{Qa=Q;Ra=O}T=S+1|0;if((T|0)<(Ra|0)){S=T;Q=Qa;O=Ra}else{t=84;break}}}else{t=84}}while(0);do{if((t|0)==84){if((q|0)<5){Oa=-1;t=101;break}Ra=je(((((c[k+80>>2]|0)>>>4<<12)+61440|c[k+72>>2])<<4|((c[k+84>>2]|0)>>>4)+1048575)<<12|c[v>>2]|0)|0;Qa=(q&268435456|0)!=0?0:f;y=Ra;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;Qa=k+88|0;a[f+4|0]=a[Qa]|0;Ra=(a[Qa]&1)==0;Qa=Ra?5:-1;if(!Ra){Oa=Qa;t=101;break}Ra=q-Qa|0;j=c[Y>>2]|0;b:do{if((j|0)>0){Na=k+64|0;ha=k+32|0;Ka=Qa+2|0;Ma=Qa+3|0;La=Qa+4|0;Ha=Qa+1|0;Ea=0;Ga=0;Fa=c[Na>>2]|0;ga=j;while(1){if((Fa|0)>0){Da=0;Ca=Ea;Ba=Fa;do{sa=c[ha>>2]|0;ra=Da+(ca(Ba,Ga)|0)|0;ta=sa+(ra<<5)+20|0;fa=c[ta>>2]|0;ia=sa+(ra<<5)+31|0;P=a[ia]|0;n=(P&4)==0?fa:fa+2|0;fa=(P&2)==0?n:n+2|0;n=(fa|0)==0?0:fa+1|0;do{if((n+2|0)>>>0>(Ra-Ca|0)>>>0){Sa=-1}else{fa=Ca+Qa|0;a[f+fa|0]=n>>>8;P=Ha+Ca|0;a[f+P|0]=n;if((n|0)==0){Sa=2;break}a[f+(Ka+Ca)|0]=a[ia]|0;O=a[ia]|0;if((O&4)==0){Ta=3;Ua=O}else{a[f+(Ma+Ca)|0]=a[sa+(ra<<5)+24|0]|0;a[f+(La+Ca)|0]=a[sa+(ra<<5)+25|0]|0;Ta=5;Ua=a[ia]|0}if((Ua&2)==0){Va=Ta}else{a[f+(Ta+fa)|0]=a[sa+(ra<<5)+27|0]|0;a[f+(Ta+P)|0]=a[sa+(ra<<5)+28|0]|0;Va=Ta+2|0}nrc(f+(Va+fa)|0,c[sa+(ra<<5)+16>>2]|0,c[ta>>2]|0)|0;Sa=(c[ta>>2]|0)+Va|0}}while(0);a[sa+(ra<<5)+26|0]=0;a[sa+(ra<<5)+25|0]=0;a[sa+(ra<<5)+24|0]=0;if((Sa|0)<0){Wa=Sa;break b}Ca=Sa+Ca|0;Da=Da+1|0;Ba=c[Na>>2]|0;}while((Da|0)<(Ba|0));Xa=Ca;Ya=Ba;Za=c[Y>>2]|0}else{Xa=Ea;Ya=Fa;Za=ga}Da=Ga+1|0;if((Da|0)<(Za|0)){Ea=Xa;Ga=Da;Fa=Ya;ga=Za}else{Wa=Xa;break}}}else{Wa=0}}while(0);Ra=((Wa|0)<0?0:Qa)+Wa|0;if(s){Pa=Ra}else{_a=Ra;t=102}}}while(0);if((t|0)==101){if(s){Pa=Oa}else{_a=Oa;t=102}}if((t|0)==102){t=k+36|0;nrc(c[t>>2]|0,c[k+32>>2]|0,c[k+44>>2]|0)|0;nrc(c[k+8>>2]|0,c[k+4>>2]|0,c[m>>2]|0)|0;Oa=ca(c[k+64>>2]|0,c[Y>>2]|0)|0;Y=k+16|0;s=c[Y>>2]|0;Wa=k+12|0;Xa=c[Wa>>2]|0;if((Oa|0)>0){Za=0;Ya=s;Sa=Xa;while(1){Va=(c[t>>2]|0)+(Za<<5)|0;c[Va>>2]=(c[Va>>2]|0)+(Ya-Sa);c[(c[t>>2]|0)+(Za<<5)+4>>2]=0;c[(c[t>>2]|0)+(Za<<5)+8>>2]=0;c[(c[t>>2]|0)+(Za<<5)+16>>2]=0;Va=Za+1|0;f=c[Y>>2]|0;Ta=c[Wa>>2]|0;if((Va|0)<(Oa|0)){Za=Va;Ya=f;Sa=Ta}else{$a=f;ab=Ta;break}}}else{$a=s;ab=Xa}nrc($a|0,ab|0,c[m>>2]|0)|0;c[k+68>>2]=c[o>>2];k=e+36|0;c[k>>2]=c[k>>2]|1;KIb(b,48,2364496,(H=i,i=i+8|0,c[H>>2]=c[o>>2],H)|0);i=H;Pa=_a}c[F>>2]=Pa;c[g>>2]=1;p=0;i=h;return p|0}function kfa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+12|0);mJb(b+16|0);mJb(b+20|0);mJb(b+24|0);mJb(b+4|0);mJb(b+8|0);mJb(b+32|0);mJb(b+36|0);return 0}function lfa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((g|0)>0){i=0;j=0}else{k=0;return k|0}while(1){l=e+i|0;m=j*3|0;n=d[f+m|0]|0;o=d[f+(m+1)|0]|0;p=o<<2&992|n>>>3;q=d[f+(m+2)|0]|0;m=p|q<<7&31744;r=n&248;s=o&248;t=q&248;u=o+n+q|0;v=u-(s+r)-t|0;w=n-r|0;r=o-s|0;s=q-t|0;t=a[b+512+m|0]|0;x=c[b+((t&255)<<2)>>2]|0;y=x&255;z=x>>>8&255;A=x>>>16&255;x=u-y-z-A|0;u=n-y|0;y=o-z|0;z=q-A|0;if((((w|0)>-1?w:-w|0)+h+((r|0)>-1?r:-r|0)+((s|0)>-1?s:-s|0)+((v|0)>-1?v:-v|0)|0)<(((y|0)>-1?y:-y|0)+((u|0)>-1?u:-u|0)+((z|0)>-1?z:-z|0)+((x|0)>-1?x:-x|0)|0)){a[l]=m>>>8|128;a[e+(i+1)|0]=p;B=2}else{a[l]=t;B=1}t=B+i|0;l=j+1|0;if((l|0)<(g|0)){i=t;j=l}else{k=t;break}}return k|0}function mfa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=b+64|0;h=c[g>>2]|0;if((h|0)<=0){return}i=b+60|0;j=b+80|0;k=b+84|0;l=b+76|0;m=b+72|0;b=f;f=0;n=e;e=c[i>>2]|0;o=h;while(1){if((e|0)>0){h=f&255;p=b;q=0;r=n;s=o;while(1){t=(ca(s,q)|0)+f|0;if((f|0)<(s-1|0)){u=c[j>>2]&255}else{u=(c[m>>2]|0)-(ca(c[j>>2]|0,f)|0)&255}a[d+(t<<5)+29|0]=u;if((q|0)<((c[i>>2]|0)-1|0)){v=c[k>>2]&255}else{v=(c[l>>2]|0)-(ca(c[k>>2]|0,q)|0)&255}a[d+(t<<5)+30|0]=v;a[d+(t<<5)+28|0]=q;a[d+(t<<5)+27|0]=h;c[d+(t<<5)>>2]=r;c[d+(t<<5)+16>>2]=p;t=ca(v&255,u&255)|0;w=r+(t*3|0)|0;if((p|0)==0){x=0}else{x=t*6|0}t=p+x|0;y=q+1|0;z=c[i>>2]|0;A=c[g>>2]|0;if((y|0)<(z|0)){p=t;q=y;r=w;s=A}else{B=t;C=w;D=z;E=A;break}}}else{B=b;C=n;D=e;E=o}s=f+1|0;if((s|0)<(E|0)){b=B;f=s;n=C;e=D;o=E}else{break}}return}function nfa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a+60|0;e=c[d>>2]|0;c[e>>2]=a;f=a+120|0;do{if((c[f>>2]|0)<=4095){g=a+124|0;if((c[g>>2]|0)>4095){break}mrc(e+36|0,0,60)|0;h=e+8|0;c[h>>2]=c[f>>2];j=e+12|0;c[j>>2]=c[g>>2];g=e+24|0;c[g>>2]=pJb(196608)|0;k=pJb(ca((c[h>>2]|0)*3|0,c[j>>2]|0)|0)|0;c[e+28>>2]=k;if((c[g>>2]|0)==0|(k|0)==0){KIb(a,16,2453832,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-12;i=b;return m|0}k=UHb()|0;g=a+804|0;c[g>>2]=k;if((k|0)!=0){m=0;i=b;return m|0}k=c[d>>2]|0;Ipc(k+36|0)|0;kJb(c[k+28>>2]|0);kJb(c[k+4>>2]|0);kJb(c[k+24>>2]|0);VHb(g);m=-12;i=b;return m|0}}while(0);KIb(a,16,2299312,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=b;return m|0}function ofa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;g=i;i=i+8|0;h=g|0;j=c[b+60>>2]|0;k=b+428|0;do{if((c[k>>2]|0)==0){l=e+32|0;m=c[l>>2]|0;n=pJb(ca((m|0)>-1?m:-m|0,c[j+12>>2]|0)|0)|0;c[j+4>>2]=n;if((n|0)!=0){o=1;p=n;q=l;break}KIb(b,16,2453832,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-12;i=g;return s|0}else{o=0;p=c[j+4>>2]|0;q=e+32|0}}while(0);l=c[q>>2]|0;n=j+4|0;if((l|0)<0){t=p+(ca((c[j+12>>2]|0)-1|0,-l|0)|0)|0}else{t=p}p=c[b+136>>2]|0;if((p|0)>0){u=(c[k>>2]|0)<((c[j+92>>2]|0)+p|0)?o:1}else{u=o}o=j+8|0;p=j+12|0;l=ca((c[o>>2]|0)*3|0,c[p>>2]|0)|0;m=d5a(b,d,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){s=m;i=g;return s|0}m=c[d+24>>2]|0;l=d+28|0;v=(c[l>>2]&268435456|0)!=0;w=je(c[p>>2]|c[o>>2]<<16|805318656|0)|0;x=v?0:m;y=w;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=c[o>>2]|0;o=(x|0)/64|0;w=(x|0)%64|0;x=c[p>>2]|0;v=(x|0)/64|0;z=(x|0)%64|0;x=((z|0)!=0)+v|0;if((x|0)>0){A=((w|0)!=0)+o|0;B=(A|0)>0;C=e|0;D=j+24|0;E=j;F=(u|0)==0;G=0;H=4;I=0;while(1){J=(I|0)<(v|0)?64:z;a:do{if(B){K=~(I<<6);L=K-J|0;M=J*3|0;if((J|0)>0){N=G;O=H;P=0}else{Q=G;R=H;S=0;while(1){T=m+R|0;if(F){U=T;y=0;a[U]=y;y=y>>8;a[U+1|0]=y;V=2;W=Q+1|0}else{c[h>>2]=12288;if((Bpc(m+(R+2)|0,h,c[D>>2]|0,ca((S|0)<(o|0)?64:w,M)|0,9)|0)!=0){KIb(c[E>>2]|0,16,2364456,(r=i,i=i+16|0,c[r>>2]=S,c[r+8>>2]=I,r)|0);i=r}U=c[h>>2]|0;X=T;y=he(U&65535|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;V=U+2|0;W=Q}U=V+R|0;X=S+1|0;if((X|0)<(A|0)){Q=W;R=U;S=X}else{Y=W;Z=U;break a}}}while(1){S=(P|0)<(o|0)?64:w;R=m+O|0;Q=c[C>>2]|0;U=c[p>>2]|0;X=L+U|0;T=c[q>>2]|0;_=P*192|0;$=S*3|0;if(($|0)>0){aa=U+K|0;U=c[D>>2]|0;ba=0;while(1){da=(ca(aa,T)|0)+_|0;ea=0;fa=ba;do{ga=da+ea|0;ha=a[Q+ga|0]|0;fa=(ha^a[t+ga|0])&255|fa;a[U+ea|0]=ha;ea=ea+1|0;}while((ea|0)<($|0));ea=aa-1|0;if((ea|0)>(X|0)){aa=ea;U=U+$|0;ba=fa}else{break}}if((fa|u|0)==0){ia=24}else{ia=21}}else{if(F){ia=24}else{ia=21}}if((ia|0)==21){ia=0;c[h>>2]=12288;if((Bpc(m+(O+2)|0,h,c[D>>2]|0,ca(S,M)|0,9)|0)!=0){KIb(c[E>>2]|0,16,2364456,(r=i,i=i+16|0,c[r>>2]=P,c[r+8>>2]=I,r)|0);i=r}ba=c[h>>2]|0;$=R;y=he(ba&65535|0)|0;a[$]=y;y=y>>8;a[$+1|0]=y;ja=ba+2|0;ka=N}else if((ia|0)==24){ia=0;ba=R;y=0;a[ba]=y;y=y>>8;a[ba+1|0]=y;ja=2;ka=N+1|0}ba=ja+O|0;$=P+1|0;if(($|0)<(A|0)){N=ka;O=ba;P=$}else{Y=ka;Z=ba;break}}}else{Y=G;Z=H}}while(0);J=I+1|0;if((J|0)<(x|0)){G=Y;H=Z;I=J}else{la=Y;ma=Z;na=C;break}}}else{la=0;ma=4;na=e|0}c[l>>2]=ma;ma=c[q>>2]|0;q=c[n>>2]|0;n=c[na>>2]|0;na=c[p>>2]|0;if((ma|0)>0){nrc(q|0,n|0,ca(na,ma)|0)|0}else{p=n+(ca(na-1|0,ma)|0)|0;nrc(q|0,p|0,ca(na,(ma|0)>-1?ma:-ma|0)|0)|0}ma=c[b+804>>2]|0;b=ma+88|0;do{if((la|0)==0){c[b>>2]=1;na=ma+84|0;c[na>>2]=1;c[j+92>>2]=c[k>>2];if((c[na>>2]|0)==0){break}na=d+36|0;c[na>>2]=c[na>>2]|1}else{c[b>>2]=2;c[ma+84>>2]=0}}while(0);c[f>>2]=1;s=0;i=g;return s|0}function pfa(a){a=a|0;var b=0;b=c[a+60>>2]|0;Ipc(b+36|0)|0;kJb(c[b+28>>2]|0);kJb(c[b+4>>2]|0);kJb(c[b+24>>2]|0);VHb(a+804|0);return 0}function qfa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=c[a+60>>2]|0;f=a+96|0;g=c[f>>2]|0;h=c[a+100>>2]|0;switch(h|0){case 0:case 12:case 128:case 256:case 904:case 1024:{break};default:{KIb(a,16,2478984,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;k=-1094995529;i=b;return k|0}}c[e>>2]=a;switch(h|0){case 0:case 256:case 904:{c[e+1036>>2]=44817;l=8;m=44817;break};case 1024:{h=e+8|0;n=c[f>>2]|0;f=0;while(1){o=n;c[h+(f<<2)>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=f+1|0;if((o|0)<256){n=n+4|0;f=o}else{break}}l=8;m=c[e+1036>>2]|0;break};case 12:{c[e+1036>>2]=44819;l=8;m=44819;break};default:{f=g+4|0;n=(d[f]|d[f+1|0]<<8)<<16>>16&65535;c[e+1036>>2]=n;f=g+12|0;l=(d[f]|d[f+1|0]<<8)<<16>>16&65535;m=n}}n=(l|0)==0?8:l;l=(m|0)==44818&(n|0)==16?15:n;if((l|0)==16){c[a+140>>2]=44}else if((l|0)==15){c[a+140>>2]=46}else if((l|0)==24){c[a+140>>2]=3;QIb(a,2469224,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1163346256;i=b;return k|0}else if((l|0)==8){c[a+140>>2]=11}else{KIb(a,16,2460040,(j=i,i=i+8|0,c[j>>2]=l,j)|0);i=j;k=-1094995529;i=b;return k|0}j=UHb()|0;c[e+4>>2]=j;if((j|0)==0){k=-12;i=b;return k|0}c[e+1032>>2]=0;k=0;i=b;return k|0}function rfa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=c[e+140>>2]|0;if((h|0)==46|(h|0)==44){m=c[e+60>>2]|0;if(!((l|0)>-1)){KIb(0,0,2568520,(n=i,i=i+24|0,c[n>>2]=2550488,c[n+8>>2]=2532328,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}o=m+4|0;p=N4a(e,c[o>>2]|0)|0;if((p|0)<0){q=p;i=j;return q|0}p=c[o>>2]|0;r=c[p>>2]|0;s=m;m=ca(c[p+32>>2]|0,c[(c[s>>2]|0)+124>>2]|0)|0;p=k+l|0;t=k;if((l|0)<4){u=0;v=k}else{w=k;u=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;v=k+4|0}w=p-v|0;x=w>>>0>2>>>0?2:w;w=v+x|0;if((p-w|0)<2){y=0;z=w}else{A=w;y=(d[A]|d[A+1|0]<<8)<<16>>16&65535;z=v+(x+2)|0}x=p-z|0;v=z+(x>>>0>8>>>0?8:x)|0;x=(u>>>0>l>>>0?l:u)-16|0;a:do{if((x|0)!=0&(y|0)!=0){u=-4-t|0;z=e;A=2-t|0;w=1-t|0;B=v;C=y;D=x;b:while(1){E=p-B|0;if(!(E>>>0>3>>>0)){F=B;break a}do{if((E|0)<4){G=0;H=B}else{I=B+4|0;J=B;K=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;if(!(K>>>0>D>>>0)){G=K;H=I;break}KIb(z,24,2299264,(n=i,i=i+16|0,c[n>>2]=K,c[n+8>>2]=D,n)|0);i=n;G=D;H=I}}while(0);E=H;I=u+E+G|0;c:do{if((p-E|0)<2){L=H;M=0;N=274}else{K=H+2|0;J=H;O=(d[J]|d[J+1|0]<<8)<<16>>16&65535;switch(O|0){case 12:{KIb(z,16,2206184,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;J=G-6|0;P=p-K|0;Q=H+((P>>>0>J>>>0?J:P)+2)|0;break c;break};case 13:{mrc(r|0,0,ca(c[(c[s>>2]|0)+124>>2]|0,c[(c[o>>2]|0)+32>>2]|0)|0)|0;Q=K;break c;break};case 25:{P=c[s>>2]|0;if((c[P+124>>2]|0)>0){R=K;S=0;T=0;U=P}else{Q=K;break c}while(1){P=p-R|0;J=R+(P>>>0>1>>>0?1:P)|0;P=c[U+120>>2]|0;if((P|0)>0){V=J;W=P;P=T;d:while(1){X=V;if((X+w|0)>(I|0)){Y=V;break}do{if((p-X|0)<1){Z=V;_=0;N=252}else{$=V+1|0;aa=a[V]|0;ba=aa<<24>>24;if(!(aa<<24>>24>0)){Z=$;_=ba;N=252;break}if((p-$|0)<2){da=0;ea=$}else{aa=$;da=(d[aa]|d[aa+1|0]<<8)<<16>>16;ea=V+3|0}fa=(ba<<1)+P|0;if(fa>>>0>m>>>0){N=248;break b}else{ga=0;ha=W;ia=P}while(1){b[r+ia>>1]=da;aa=ha-1|0;if((aa|0)<0){KIb(z,16,2122528,(n=i,i=i+8|0,c[n>>2]=aa,n)|0);i=n}$=ga+1|0;if(($|0)<(ba|0)){ga=$;ha=aa;ia=ia+2|0}else{break}}ja=fa;ka=W-ba|0;la=ea}}while(0);do{if((N|0)==252){N=0;X=-_|0;aa=X<<1;if((aa-t+Z|0)>(I|0)){Y=Z;break d}ma=aa+P|0;if(ma>>>0>m>>>0){N=256;break b}if((_|0)>=0){ja=P;ka=W;la=Z;break}aa=(X|0)>1?X:1;$=Z;na=0;oa=W;pa=P;while(1){if((p-$|0)<2){qa=0;ra=$}else{sa=$;qa=(d[sa]|d[sa+1|0]<<8)<<16>>16;ra=$+2|0}b[r+pa>>1]=qa;sa=oa-1|0;if((sa|0)<0){KIb(z,16,2122528,(n=i,i=i+8|0,c[n>>2]=sa,n)|0);i=n}ta=na+1|0;if((ta|0)<(X|0)){$=ra;na=ta;oa=sa;pa=pa+2|0}else{break}}ja=(aa<<1)+P|0;ka=W-aa|0;la=ra}}while(0);if((ka|0)>0){V=la;W=ka;P=ja}else{Y=la;break}}ua=Y;va=c[s>>2]|0}else{ua=J;va=U}P=S+1|0;if((P|0)<(c[va+124>>2]|0)){R=ua;S=P;T=(c[(c[o>>2]|0)+32>>2]|0)+T|0;U=va}else{Q=ua;break}}break};case 4:case 11:{P=G-6|0;W=p-K|0;Q=H+((W>>>0>P>>>0?P:W)+2)|0;break c;break};case 15:{W=c[s>>2]|0;if((c[W+124>>2]|0)>0){wa=K;xa=0;ya=0;za=W}else{Q=K;break c}while(1){W=p-wa|0;P=wa+(W>>>0>1>>>0?1:W)|0;W=c[za+120>>2]<<1;if((W|0)>0){V=P;pa=W;W=ya;e:while(1){oa=V;if((oa+w|0)>(I|0)){Aa=V;break}do{if((p-oa|0)<1){Ba=V;Ca=0;N=226}else{na=V+1|0;$=a[V]|0;X=$<<24>>24;if(!($<<24>>24>0)){Ba=na;Ca=X;N=226;break}if((p-na|0)<1){Da=0;Ea=na}else{Da=a[na]|0;Ea=V+2|0}Fa=X+W|0;if(Fa>>>0>m>>>0){N=222;break b}else{Ga=0;Ha=pa;Ia=W}while(1){a[r+Ia|0]=Da;na=Ha-1|0;if((na|0)<0){KIb(z,16,2173944,(n=i,i=i+16|0,c[n>>2]=na,c[n+8>>2]=xa,n)|0);i=n}$=Ga+1|0;if(($|0)<(X|0)){Ga=$;Ha=na;Ia=Ia+1|0}else{break}}Ja=Fa;Ka=pa-X|0;La=Ea}}while(0);do{if((N|0)==226){N=0;oa=-Ca|0;if((Ba-(Ca+t)|0)>(I|0)){Aa=Ba;break e}Ma=W-Ca|0;if(Ma>>>0>m>>>0){N=230;break b}if((Ca|0)>=0){Ja=W;Ka=pa;La=Ba;break}aa=(oa|0)>1?oa:1;na=Ba;$=0;ba=pa;sa=W;while(1){if((p-na|0)<1){Na=0;Oa=na}else{Na=a[na]|0;Oa=na+1|0}a[r+sa|0]=Na;ta=ba-1|0;if((ta|0)<0){KIb(z,16,2146328,(n=i,i=i+16|0,c[n>>2]=ta,c[n+8>>2]=xa,n)|0);i=n}Pa=$+1|0;if((Pa|0)<(oa|0)){na=Oa;$=Pa;ba=ta;sa=sa+1|0}else{break}}Ja=aa+W|0;Ka=pa-aa|0;La=Oa}}while(0);if((Ka|0)>0){V=La;pa=Ka;W=Ja}else{Aa=La;break}}Qa=Aa;Ra=c[s>>2]|0}else{Qa=P;Ra=za}W=xa+1|0;if((W|0)<(c[Ra+124>>2]|0)){wa=Qa;xa=W;ya=(c[(c[o>>2]|0)+32>>2]|0)+ya|0;za=Ra}else{Q=Qa;break}}break};case 7:case 27:{if((p-K|0)<2){Q=K;break c}W=H+4|0;pa=K;V=(d[pa]|d[pa+1|0]<<8)<<16>>16;if(V<<16>>16==0){Q=W;break c}pa=W;W=V&65535;V=0;while(1){J=pa;if((J+A|0)>(I|0)){Q=pa;break c}else{Sa=V;Ta=pa;Ua=J}while(1){if((p-Ua|0)<2){Va=Ta;Wa=0;break}J=Ta+2|0;sa=Ta;ba=(d[sa]|d[sa+1|0]<<8)<<16>>16;sa=ba<<16>>16;if(!(ba<<16>>16<0)){Va=J;Wa=sa;break}ba=(ca(c[(c[o>>2]|0)+32>>2]|0,-sa<<16>>16)|0)+Sa|0;sa=J;if((sa+A|0)>(I|0)){Q=J;break c}else{Sa=ba;Ta=J;Ua=sa}}P=W-1|0;Xa=c[s>>2]|0;if(Sa>>>0>m>>>0){N=187;break b}f:do{if((Wa|0)>0){sa=Va;J=0;ba=Sa;while(1){$=sa;if(($+A|0)>(I|0)){Ya=sa;break f}if((p-$|0)<1){Za=0;_a=sa}else{Za=(d[sa]|0)<<1;_a=sa+1|0}$=Za+ba|0;do{if((p-_a|0)<1){$a=_a;ab=0;N=200}else{na=_a+1|0;oa=a[_a]|0;X=oa<<24>>24;if(!(oa<<24>>24<0)){$a=na;ab=X;N=200;break}oa=-X|0;if((p-na|0)<2){bb=0;cb=na}else{X=na;bb=(d[X]|d[X+1|0]<<8)<<16>>16;cb=_a+3|0}X=oa<<1;db=X+$|0;if(db>>>0>m>>>0){N=198;break b}na=(oa|0)>1?X:2;X=0;ta=$;while(1){b[r+ta>>1]=bb;Pa=X+1|0;if((Pa|0)<(oa|0)){X=Pa;ta=ta+2|0}else{break}}eb=$+na|0;fb=cb}}while(0);do{if((N|0)==200){N=0;aa=ab<<1;if((aa-t+$a|0)>(I|0)){Ya=$a;break f}gb=aa+$|0;if(gb>>>0>m>>>0){N=203;break b}if((ab|0)>0){hb=$a;ib=0;jb=$}else{eb=$;fb=$a;break}while(1){if((p-hb|0)<2){kb=0;lb=hb}else{aa=hb;kb=(d[aa]|d[aa+1|0]<<8)<<16>>16;lb=hb+2|0}b[r+jb>>1]=kb;aa=ib+1|0;if((aa|0)<(ab|0)){hb=lb;ib=aa;jb=jb+2|0}else{eb=gb;fb=lb;break}}}}while(0);$=J+1|0;if(($|0)<(Wa|0)){sa=fb;J=$;ba=eb}else{Ya=fb;break}}}else{Ya=Va}}while(0);if((P|0)>0){pa=Ya;W=P;V=(c[(c[o>>2]|0)+32>>2]|0)+Sa|0}else{Q=Ya;break}}break};case 16:case 26:{V=G-6|0;W=c[s>>2]|0;pa=c[W+120>>2]|0;ba=c[W+124>>2]|0;if(V>>>0>(ca(pa<<1,ba)|0)>>>0){KIb(z,16,2640224,(n=i,i=i+8|0,c[n>>2]=V,n)|0);i=n;W=p-K|0;Q=H+((W>>>0>V>>>0?V:W)+2)|0;break c}W=c[(c[o>>2]|0)+32>>2]|0;V=ca(W,ba)|0;if((V|0)<=0){Q=K;break c}ba=(pa|0)>0;J=K;sa=0;while(1){if(ba){$=J;na=pa;aa=0;while(1){if((p-$|0)<2){mb=0;nb=$}else{ta=$;mb=(d[ta]|d[ta+1|0]<<8)<<16>>16;nb=$+2|0}b[r+(aa+sa)>>1]=mb;ta=na-1|0;if((ta|0)>0){$=nb;na=ta;aa=aa+2|0}else{ob=nb;break}}}else{ob=J}aa=sa+W|0;if((aa|0)<(V|0)){J=ob;sa=aa}else{Q=ob;break}}break};case 18:{sa=G-6|0;J=p-K|0;Q=H+((J>>>0>sa>>>0?sa:J)+2)|0;break c;break};default:{L=K;M=O;N=274;break c}}}}while(0);if((N|0)==274){N=0;KIb(z,16,2617496,(n=i,i=i+8|0,c[n>>2]=M,n)|0);i=n;Q=L}I=C-1|0;if((D|0)!=(G|0)&(I|0)>0){B=Q;C=I;D=D-G|0}else{F=Q;break a}}if((N|0)==187){KIb(Xa,16,2248272,(n=i,i=i+16|0,c[n>>2]=Sa,c[n+8>>2]=m,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==198){KIb(Xa,16,2248272,(n=i,i=i+16|0,c[n>>2]=db,c[n+8>>2]=m,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==203){KIb(Xa,16,2248272,(n=i,i=i+16|0,c[n>>2]=gb,c[n+8>>2]=m,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==222){KIb(c[s>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=Fa,c[n+8>>2]=m,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==230){KIb(c[s>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=Ma,c[n+8>>2]=m,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==248){KIb(c[s>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=fa,c[n+8>>2]=m,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==256){KIb(c[s>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=ma,c[n+8>>2]=m,n)|0);i=n;q=-1094995529;i=j;return q|0}}else{F=v}}while(0);v=F;if(!((p-v|0)>>>0<2>>>0)){KIb(e,16,2590200,(n=i,i=i+16|0,c[n>>2]=l,c[n+8>>2]=v-t,n)|0);i=n}t=YHb(f,c[o>>2]|0)|0;if((t|0)<0){q=t;i=j;return q|0}c[g>>2]=1;q=l;i=j;return q|0}else if((h|0)==3){KIb(e,16,2364400,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=-1163346256;i=j;return q|0}else if((h|0)==11){h=c[e+60>>2]|0;if(!((l|0)>-1)){KIb(0,0,2568520,(n=i,i=i+24|0,c[n>>2]=2550488,c[n+8>>2]=2532328,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}t=h+4|0;o=N4a(e,c[t>>2]|0)|0;if((o|0)<0){q=o;i=j;return q|0}o=c[t>>2]|0;v=c[o>>2]|0;p=h;F=ca(c[o+32>>2]|0,c[(c[p>>2]|0)+124>>2]|0)|0;if((l-16|0)>>>0>2147482847>>>0){q=-1094995529;i=j;return q|0}o=k+l|0;m=k;if((l|0)<4){pb=0;qb=k}else{ma=k;pb=d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0;qb=k+4|0}k=o-qb|0;ma=k>>>0>2>>>0?2:k;k=qb+ma|0;if((o-k|0)<2){rb=0;sb=k}else{s=k;rb=(d[s]|d[s+1|0]<<8)<<16>>16&65535;sb=qb+(ma+2)|0}ma=o-sb|0;qb=sb+(ma>>>0>8>>>0?8:ma)|0;ma=(pb>>>0>l>>>0?l:pb)-16|0;g:do{if(ma>>>0>5>>>0&(rb|0)!=0){pb=-4-m|0;sb=e;s=2-m|0;k=1-m|0;fa=h+1036|0;Ma=h+8|0;Fa=h+1032|0;gb=qb;Xa=rb;db=ma;h:while(1){Sa=o-gb|0;if(!(Sa>>>0>3>>>0)){tb=gb;break g}do{if((Sa|0)<4){ub=0;vb=gb}else{Q=gb+4|0;G=gb;L=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;if(!(L>>>0>db>>>0)){ub=L;vb=Q;break}KIb(sb,24,2299264,(n=i,i=i+16|0,c[n>>2]=L,c[n+8>>2]=db,n)|0);i=n;ub=db;vb=Q}}while(0);Sa=vb;Q=pb+Sa+ub|0;i:do{if((o-Sa|0)<2){wb=vb;xb=0;N=151}else{L=vb+2|0;G=vb;M=(d[G]|d[G+1|0]<<8)<<16>>16&65535;switch(M|0){case 11:{N=20;break};case 15:{G=c[p>>2]|0;if((c[G+124>>2]|0)>0){yb=L;zb=0;Ab=0;Bb=G}else{Cb=L;break i}while(1){G=o-yb|0;H=yb+(G>>>0>1>>>0?1:G)|0;G=c[Bb+120>>2]|0;if((G|0)>0){ob=H;nb=G;G=Ab;j:while(1){mb=ob;if((mb+k|0)>(Q|0)){Db=ob;break}if((o-mb|0)<1){N=125;break h}mb=ob+1|0;r=a[ob]|0;Ya=r<<24>>24;Va=-Ya|0;if(r<<24>>24==0){N=125;break h}do{if(r<<24>>24>0){if((o-mb|0)<1){Eb=0;Fb=mb}else{Eb=a[mb]|0;Fb=ob+2|0}Gb=Ya+G|0;if(Gb>>>0>F>>>0){N=130;break h}else{Hb=0;Ib=nb;Jb=G}while(1){a[v+Jb|0]=Eb;fb=Ib-1|0;if((fb|0)<0){KIb(sb,16,2146328,(n=i,i=i+16|0,c[n>>2]=fb,c[n+8>>2]=zb,n)|0);i=n}eb=Hb+1|0;if((eb|0)<(Ya|0)){Hb=eb;Ib=fb;Jb=Jb+1|0}else{break}}Kb=Gb;Lb=nb-Ya|0;Mb=Fb}else{Nb=G-Ya|0;if(Nb>>>0>F>>>0){N=135;break h}if((mb-m-Ya|0)>(Q|0)){Db=mb;break j}if(!(r<<24>>24<0)){Kb=G;Lb=nb;Mb=mb;break}fb=(Va|0)>1?Va:1;eb=mb;Wa=0;lb=nb;jb=G;while(1){if((o-eb|0)<1){Ob=0;Pb=eb}else{Ob=a[eb]|0;Pb=eb+1|0}a[v+jb|0]=Ob;ib=lb-1|0;if((ib|0)<0){KIb(sb,16,2146328,(n=i,i=i+16|0,c[n>>2]=ib,c[n+8>>2]=zb,n)|0);i=n}hb=Wa+1|0;if((hb|0)<(Va|0)){eb=Pb;Wa=hb;lb=ib;jb=jb+1|0}else{break}}Kb=fb+G|0;Lb=nb-fb|0;Mb=Pb}}while(0);if((Lb|0)>0){ob=Mb;nb=Lb;G=Kb}else{Db=Mb;break}}Qb=Db;Rb=c[p>>2]|0}else{Qb=H;Rb=Bb}G=zb+1|0;if((G|0)<(c[Rb+124>>2]|0)){yb=Qb;zb=G;Ab=(c[(c[t>>2]|0)+32>>2]|0)+Ab|0;Bb=Rb}else{Cb=Qb;break i}}break};case 4:{if((c[fa>>2]|0)==44819){N=20}else{Sb=0}break};case 16:{O=ub-6|0;K=c[p>>2]|0;G=c[K+120>>2]|0;nb=c[K+124>>2]|0;if((O|0)!=(ca(nb,G)|0)){KIb(sb,16,2489880,(n=i,i=i+8|0,c[n>>2]=O,n)|0);i=n;K=o-L|0;Cb=vb+((K>>>0>O>>>0?O:K)+2)|0;break i}if((ca(c[(c[t>>2]|0)+32>>2]|0,nb)|0)<=0){Cb=L;break i}nb=o-L|0;K=nb>>>0>G>>>0?G:nb;nrc(v|0,L|0,K)|0;nb=vb+(K+2)|0;K=c[(c[t>>2]|0)+32>>2]|0;G=c[p>>2]|0;if((K|0)<(ca(c[G+124>>2]|0,K)|0)){Tb=nb;Ub=K;Vb=G}else{Cb=nb;break i}while(1){nb=c[Vb+120>>2]|0;G=o-Tb|0;K=G>>>0>nb>>>0?nb:G;nrc(v+Ub|0,Tb|0,K)|0;G=Tb+K|0;K=c[(c[t>>2]|0)+32>>2]|0;nb=K+Ub|0;O=c[p>>2]|0;if((nb|0)<(ca(c[O+124>>2]|0,K)|0)){Tb=G;Ub=nb;Vb=O}else{Cb=G;break i}}break};case 12:{if((o-L|0)<2){Wb=0;Xb=L}else{G=L;Wb=(d[G]|d[G+1|0]<<8)<<16>>16&65535;Xb=vb+4|0}G=c[t>>2]|0;if((o-Xb|0)<2){Cb=Xb;break i}O=ca(c[G+32>>2]|0,Wb)|0;nb=Xb+2|0;K=Xb;ob=(d[K]|d[K+1|0]<<8)<<16>>16;if(ob<<16>>16==0){Cb=nb;break i}if(O>>>0>F>>>0){Yb=O;N=92;break h}else{Zb=G;_b=O;$b=ob&65535;ac=nb}while(1){nb=ac;if((nb+k|0)>(Q|0)){Cb=ac;break i}do{if((o-nb|0)<1){bc=ac;cc=Zb}else{ob=ac+1|0;O=a[ac]|0;G=O&255;if(O<<24>>24==0){bc=ob;cc=Zb;break}else{dc=ob;ec=0;fc=_b}k:while(1){ob=dc;if((ob+k|0)>(Q|0)){gc=dc;break}if((o-ob|0)<1){hc=0;ic=dc}else{hc=d[dc]|0;ic=dc+1|0}ob=hc+fc|0;do{if((o-ic|0)<1){jc=ob;kc=ic}else{O=ic+1|0;K=a[ic]|0;Va=K<<24>>24;if(K<<24>>24>0){lc=Va+ob|0;if(lc>>>0>F>>>0){N=102;break h}if((O-m+Va|0)>(Q|0)){gc=O;break k}else{mc=O;nc=0;oc=ob}while(1){if((o-mc|0)<1){pc=0;qc=mc}else{pc=a[mc]|0;qc=mc+1|0}a[v+oc|0]=pc;mb=nc+1|0;if((mb|0)<(Va|0)){mc=qc;nc=mb;oc=oc+1|0}else{jc=lc;kc=qc;break}}}else{if(!(K<<24>>24<0)){jc=ob;kc=O;break}if((o-O|0)<1){rc=0;sc=O}else{rc=a[O]|0;sc=ic+2|0}tc=ob-Va|0;if(tc>>>0>F>>>0){N=111;break h}mb=-Va|0;r=(mb|0)>1?mb:1;mrc(v+ob|0,rc|0,r|0)|0;jc=r+ob|0;kc=sc;break}}}while(0);ob=ec+1|0;if((ob|0)<(G|0)){dc=kc;ec=ob;fc=jc}else{gc=kc;break}}bc=gc;cc=c[t>>2]|0}}while(0);nb=$b-1|0;if((nb|0)<=0){Cb=bc;break i}H=(c[cc+32>>2]|0)+_b|0;if(H>>>0>F>>>0){Yb=H;N=92;break h}else{Zb=cc;_b=H;$b=nb;ac=bc}}break};case 18:{Cb=L;break i;break};case 7:{if((o-L|0)<2){Cb=L;break i}nb=vb+4|0;H=L;G=(d[H]|d[H+1|0]<<8)<<16>>16;if(G<<16>>16==0){Cb=nb;break i}H=nb;nb=G&65535;G=0;while(1){ob=H;if((ob+s|0)>(Q|0)){Cb=H;break i}else{uc=H;vc=G;wc=ob}l:while(1){ob=vc-1|0;fb=uc;r=wc;while(1){if((o-r|0)<2){xc=fb;yc=0;break l}zc=fb+2|0;mb=fb;Ya=(d[mb]|d[mb+1|0]<<8)<<16>>16;Ac=Ya<<16>>16;mb=Ac&49152;if((mb|0)==16384){KIb(sb,16,2517016,(n=i,i=i+8|0,c[n>>2]=Ac,n)|0);i=n}else if((mb|0)==32768){Bc=ob+(c[(c[t>>2]|0)+32>>2]|0)|0;if(Bc>>>0>F>>>0){N=61;break h}a[v+Bc|0]=Ya}else if((mb|0)==49152){break}else{xc=zc;yc=Ac;break l}mb=zc;if((mb+s|0)>(Q|0)){Cb=zc;break i}else{fb=zc;r=mb}}r=(ca(c[(c[t>>2]|0)+32>>2]|0,-Ac<<16>>16)|0)+vc|0;fb=zc;if((fb+s|0)>(Q|0)){Cb=zc;break i}else{uc=zc;vc=r;wc=fb}}fb=nb-1|0;if(vc>>>0>F>>>0){N=63;break h}m:do{if((yc|0)>0){r=xc;ob=0;mb=vc;while(1){Ya=r;if((Ya+s|0)>(Q|0)){Cc=r;break m}if((o-Ya|0)<1){Dc=0;Ec=r}else{Dc=d[r]|0;Ec=r+1|0}Ya=Dc+mb|0;do{if((o-Ec|0)<1){Fc=Ec;Gc=0;N=77}else{jb=Ec+1|0;lb=a[Ec]|0;Wa=lb<<24>>24;if(!(lb<<24>>24<0)){Fc=jb;Gc=Wa;N=77;break}lb=-Wa|0;if((o-jb|0)<1){Hc=0;Ic=jb}else{Hc=a[jb]|0;Ic=Ec+2|0}if((o-Ic|0)<1){Jc=0;Kc=Ic}else{Jc=a[Ic]|0;Kc=Ic+1|0}jb=lb<<1;Lc=jb+Ya|0;if(Lc>>>0>F>>>0){N=75;break h}else{Mc=0;Nc=Ya}while(1){a[v+Nc|0]=Hc;a[v+(Nc+1)|0]=Jc;Wa=Mc+1|0;if((Wa|0)<(lb|0)){Mc=Wa;Nc=Nc+2|0}else{break}}Oc=((lb|0)>1?jb:2)+Ya|0;Pc=Kc}}while(0);do{if((N|0)==77){N=0;Va=Gc<<1;Qc=Va+Ya|0;if(Qc>>>0>F>>>0){N=78;break h}if((Va-m+Fc|0)>(Q|0)){Cc=Fc;break m}if((Va|0)>0){Rc=Fc;Sc=0;Tc=Ya}else{Oc=Ya;Pc=Fc;break}while(1){if((o-Rc|0)<1){Uc=0;Vc=Rc}else{Uc=a[Rc]|0;Vc=Rc+1|0}a[v+Tc|0]=Uc;O=Sc+1|0;if((O|0)<(Va|0)){Rc=Vc;Sc=O;Tc=Tc+1|0}else{Oc=Qc;Pc=Vc;break}}}}while(0);Ya=ob+1|0;if((Ya|0)<(yc|0)){r=Pc;ob=Ya;mb=Oc}else{Cc=Pc;break}}}else{Cc=xc}}while(0);if((fb|0)>0){H=Cc;nb=fb;G=(c[(c[t>>2]|0)+32>>2]|0)+vc|0}else{Cb=Cc;break i}}break};case 13:{mrc(v|0,0,ca(c[(c[p>>2]|0)+124>>2]|0,c[(c[t>>2]|0)+32>>2]|0)|0)|0;Cb=L;break i;break};default:{wb=L;xb=M;N=151;break i}}if((N|0)==20){N=0;Sb=2}if((o-L|0)<2){Cb=L;break}G=vb+4|0;nb=L;H=(d[nb]|d[nb+1|0]<<8)<<16>>16;nb=H&65535;if(H<<16>>16==0){Cb=G;break}H=(Sb|0)==2;mb=G;G=0;ob=0;while(1){if((o-mb|0)<1){Wc=0;Xc=mb}else{Wc=d[mb]|0;Xc=mb+1|0}r=Wc+ob|0;if((o-Xc|0)<1){Yc=0;Zc=Xc}else{Yc=d[Xc]|0;Zc=Xc+1|0}Ya=(Yc|0)==0?256:Yc;if((Zc-m+(Ya*3|0)|0)>(Q|0)){Cb=Zc;break i}if(H){Va=Zc;jb=0;lb=r;while(1){O=lb>>>0>255>>>0?0:lb;if((o-Va|0)<1){_c=0;$c=Va}else{_c=(d[Va]|0)<<18;$c=Va+1|0}if((o-$c|0)<1){ad=0;bd=$c}else{ad=(d[$c]|0)<<10&64512;bd=$c+1|0}if((o-bd|0)<1){cd=0;dd=bd}else{cd=(d[bd]|0)<<2&252;dd=bd+1|0}K=ad|_c|cd;Wa=K|K>>>6&197379|-16777216;K=Ma+(O<<2)|0;if((c[K>>2]|0)!=(Wa|0)){c[Fa>>2]=1}eb=O+1|0;c[K>>2]=Wa;Wa=jb+1|0;if((Wa|0)<(Ya|0)){Va=dd;jb=Wa;lb=eb}else{ed=dd;fd=eb;break}}}else{lb=Zc;jb=0;Va=r;while(1){fb=Va>>>0>255>>>0?0:Va;if((o-lb|0)<1){gd=0;hd=lb}else{gd=d[lb]|0;hd=lb+1|0}if((o-hd|0)<1){id=0;jd=hd}else{id=d[hd]|0;jd=hd+1|0}if((o-jd|0)<1){kd=0;ld=jd}else{kd=d[jd]|0;ld=jd+1|0}eb=gd<<Sb<<16|id<<Sb<<8&65280|kd<<Sb&255|-16777216;Wa=Ma+(fb<<2)|0;if((c[Wa>>2]|0)!=(eb|0)){c[Fa>>2]=1}K=fb+1|0;c[Wa>>2]=eb;eb=jb+1|0;if((eb|0)<(Ya|0)){lb=ld;jb=eb;Va=K}else{ed=ld;fd=K;break}}}Va=G+1|0;if((Va|0)<(nb|0)){mb=ed;G=Va;ob=fd}else{Cb=ed;break}}}}while(0);if((N|0)==151){N=0;KIb(sb,16,2617496,(n=i,i=i+8|0,c[n>>2]=xb,n)|0);i=n;Cb=wb}Sa=Cb;ob=m-Sa+Q|0;if((ob|0)>0){G=o-Sa|0;md=Cb+(G>>>0>ob>>>0?ob:G)|0}else{md=Cb}G=db-ub|0;ob=Xa-1|0;if(G>>>0>5>>>0&(ob|0)>0){gb=md;Xa=ob;db=G}else{tb=md;break g}}if((N|0)==61){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=Bc,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==63){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=vc,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==75){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=Lc,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==78){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=Qc,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==92){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=Yb,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==102){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=lc,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==111){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=tc,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==125){KIb(sb,16,2502992,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==130){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=Gb,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}else if((N|0)==135){KIb(c[p>>2]|0,16,2248272,(n=i,i=i+16|0,c[n>>2]=Nb,c[n+8>>2]=F,n)|0);i=n;q=-1094995529;i=j;return q|0}}else{tb=qb}}while(0);qb=o-tb|0;if(qb>>>0>2>>>0){KIb(e,16,2590200,(n=i,i=i+16|0,c[n>>2]=l,c[n+8>>2]=l-qb,n)|0);i=n}nrc(c[(c[t>>2]|0)+4>>2]|0,h+8|0,1024)|0;qb=h+1032|0;h=c[t>>2]|0;if((c[qb>>2]|0)!=0){c[h+304>>2]=1;c[qb>>2]=0}qb=YHb(f,h)|0;if((qb|0)<0){q=qb;i=j;return q|0}c[g>>2]=1;q=l;i=j;return q|0}else{KIb(e,16,2453760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=-558323010;i=j;return q|0}return 0}function sfa(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function tfa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=a+8|0;h=c[g>>2]|0;i=c[a>>2]|0;j=d[i+(h>>>3)|0]|0;k=a+16|0;a=c[k>>2]|0;l=((h|0)<(a|0))+h|0;c[g>>2]=l;m=(d[i+(l>>>3)|0]|0)<<(l&7)>>>7;c[g>>2]=((l|0)<(a|0))+l;c[f>>2]=m&1;m=c[g>>2]|0;f=c[k>>2]|0;l=i+(m>>>3)|0;a=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>26;l=m+6|0;c[g>>2]=f>>>0>l>>>0?l:f;c[e>>2]=a;a=c[g>>2]|0;e=c[k>>2]|0;k=i+(a>>>3)|0;i=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(a&7);if((j&128>>>((h&7)>>>0)|0)==0){h=a+7|0;n=i>>25;o=e>>>0>h>>>0?h:e;c[g>>2]=o;c[b>>2]=n;return}else{h=a+11|0;n=i>>21;o=e>>>0>h>>>0?h:e;c[g>>2]=o;c[b>>2]=n;return}}function ufa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;e=a+14128|0;f=c[e>>2]|0;g=a+14136|0;h=c[g>>2]|0;j=a+14120|0;k=c[j>>2]|0;l=k+(f>>>3)|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(f&7);l=f+17|0;f=h>>>0>l>>>0?l:h;c[e>>2]=f;if((m&-32768|0)!=32768){KIb(c[a+4>>2]|0,16,2553288,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=b;return o|0}m=k+(f>>>3)|0;l=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(f&7);m=f+5|0;f=h>>>0>m>>>0?m:h;c[e>>2]=f;if(l>>>0>268435455>>>0){KIb(c[a+4>>2]|0,16,2606672,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=b;return o|0}m=a+44|0;c[m>>2]=(l>>>27)+1;l=k+(f>>>3)|0;p=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(f&7)>>>24;l=f+8|0;f=h>>>0>l>>>0?l:h;c[e>>2]=f;l=a+108|0;c[l>>2]=p;p=k+(f>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(f&7)>>>29;p=f+3|0;f=h>>>0>p>>>0?p:h;c[e>>2]=f;switch(q|0){case 2:{r=288;s=352;break};case 6:{r=120;s=160;break};case 5:{r=240;s=320;break};case 0:{q=k+(f>>>3)|0;p=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(f&7)>>>24;q=f+8|0;t=h>>>0>q>>>0?q:h;c[e>>2]=t;q=k+(t>>>3)|0;u=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(t&7)>>>24;q=t+8|0;c[e>>2]=h>>>0>q>>>0?q:h;r=u;s=p;break};case 4:{r=96;s=128;break};case 3:{r=144;s=176;break};case 1:{p=k+(f>>>3)|0;u=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(f&7)>>>16;p=f+16|0;f=h>>>0>p>>>0?p:h;c[e>>2]=f;p=k+(f>>>3)|0;k=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(f&7)>>>16;p=f+16|0;c[e>>2]=h>>>0>p>>>0?p:h;r=k;s=u;break};default:{r=0;s=0}}u=a+4|0;if((tIb(s,r,0,c[u>>2]|0)|0)!=0){o=-22;i=b;return o|0}c[a+8>>2]=s;c[a+12>>2]=r;r=c[e>>2]|0;s=c[g>>2]|0;g=c[j>>2]|0;j=g+(r>>>3)|0;k=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(r&7)>>>30;j=r+2|0;r=s>>>0>j>>>0?j:s;c[e>>2]=r;j=k+1|0;k=a+9992|0;c[k>>2]=j;h=j>>>0>2>>>0;j=a+10008|0;c[j>>2]=h&1;if(h){c[k>>2]=2}h=r+1|0;r=s>>>0>h>>>0?h:s;c[e>>2]=r;h=g+(r>>>3)|0;p=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(r&7)>>>27;h=r+5|0;r=s>>>0>h>>>0?h:s;c[e>>2]=r;h=a+9960|0;c[h>>2]=p;c[a+9964>>2]=p;c[a+40>>2]=0;c[a+10048>>2]=1;c[a+10052>>2]=0;p=c[a+14132>>2]|0;if((p-r|0)<1){o=-1094995529;i=b;return o|0}else{v=r}while(1){r=d[g+(v>>>3)|0]|0;f=((v|0)<(s|0))+v|0;c[e>>2]=f;if((r&128>>>((v&7)>>>0)|0)==0){break}r=f+8|0;f=s>>>0>r>>>0?r:s;c[e>>2]=f;if((p-f|0)<1){o=-1094995529;w=26;break}else{v=f}}if((w|0)==26){i=b;return o|0}c[a+11556>>2]=1;if((c[a+13812>>2]|0)!=0){w=c[u>>2]|0;c[w+224>>2]=1;c[w+228>>2]=2}w=c[u>>2]|0;if((c[w+688>>2]&1|0)!=0){if((c[j>>2]|0)==0){x=(BLb(c[k>>2]|0)|0)<<24>>24}else{x=68}k=(c[m>>2]|0)-1|0;m=c[h>>2]|0;h=c[l>>2]|0;KIb(w,48,2453664,(n=i,i=i+32|0,c[n>>2]=x,c[n+8>>2]=k,c[n+16>>2]=m,c[n+24>>2]=h,n)|0);i=n}c[a+9892>>2]=1347360;c[a+9888>>2]=1347360;o=0;i=b;return o|0}function vfa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;d=b+784|0;Y2(d);e=d|0;d=c[e>>2]|0;f=b+788|0;g=c[f>>2]|0;if((g|0)>17){h=g-17|0;i=d<<17|1}else{j=je(1>>>((17-g|0)>>>0)|d<<g|0)|0;d=b+796|0;k=c[d>>2]|0;y=j;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[d>>2]=(c[d>>2]|0)+4;h=g+15|0;i=1}c[e>>2]=i;c[f>>2]=h;g=(c[b+44>>2]|0)-1|0;if((h|0)>5){l=h-5|0;m=i<<5|g}else{d=je(g>>>((5-h|0)>>>0)|i<<h|0)|0;i=b+796|0;k=c[i>>2]|0;y=d;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=h+27|0;m=g}c[e>>2]=m;c[f>>2]=l;g=c[b+108>>2]|0;h=Erc(g,(g|0)<0|0?-1:0,30,0)|0;g=c[b+4>>2]|0;i=c[g+104>>2]|0;k=Erc(h,G,i,(i|0)<0|0?-1:0)|0;i=c[g+108>>2]|0;g=Crc(k,G,i,(i|0)<0|0?-1:0)|0;i=g&255;if((l|0)>8){n=l-8|0;o=m<<8|i}else{g=je(i>>>((8-l|0)>>>0)|m<<l|0)|0;m=b+796|0;k=c[m>>2]|0;y=g;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;n=l+24|0;o=i}c[e>>2]=o;c[f>>2]=n;i=b+8|0;l=c[i>>2]|0;switch(l|0){case 352:{if((c[b+12>>2]|0)==288){p=2}else{q=18}break};case 320:{if((c[b+12>>2]|0)==240){p=5}else{q=18}break};case 160:{if((c[b+12>>2]|0)==120){p=6}else{q=17}break};case 176:{if((c[b+12>>2]|0)==144){p=3}else{q=17}break};case 128:{if((c[b+12>>2]|0)==96){p=4}else{q=17}break};default:{if((l|0)<256){q=17}else{q=18}}}if((q|0)==17){if((c[b+12>>2]|0)<256){p=0}else{q=18}}if((q|0)==18){p=1}if((n|0)>3){r=n-3|0;s=o<<3|p}else{q=je(p>>>((3-n|0)>>>0)|o<<n|0)|0;o=b+796|0;l=c[o>>2]|0;y=q;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;r=n+29|0;s=p}c[e>>2]=s;c[f>>2]=r;if((p|0)==0){n=c[i>>2]|0;if((r|0)>8){t=r-8|0;u=s<<8|n}else{o=je(s<<r|n>>>((8-r|0)>>>0)|0)|0;l=b+796|0;q=c[l>>2]|0;y=o;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;t=r+24|0;u=n}c[e>>2]=u;c[f>>2]=t;n=c[b+12>>2]|0;if((t|0)>8){v=t-8|0;w=u<<8|n}else{l=je(u<<t|n>>>((8-t|0)>>>0)|0)|0;u=b+796|0;q=c[u>>2]|0;y=l;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+24|0;w=n}c[e>>2]=w;c[f>>2]=v;x=v;z=w}else if((p|0)==1){p=c[i>>2]|0;if((r|0)>16){A=r-16|0;B=s<<16|p}else{i=je(s<<r|p>>>((16-r|0)>>>0)|0)|0;w=b+796|0;v=c[w>>2]|0;y=i;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;A=r+16|0;B=p}c[e>>2]=B;c[f>>2]=A;p=c[b+12>>2]|0;if((A|0)>16){C=A-16|0;D=B<<16|p}else{w=je(B<<A|p>>>((16-A|0)>>>0)|0)|0;B=b+796|0;v=c[B>>2]|0;y=w;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;C=A+16|0;D=p}c[e>>2]=D;c[f>>2]=C;x=C;z=D}else{x=r;z=s}s=(c[b+9992>>2]|0)==2|0;if((x|0)>2){E=x-2|0;F=z<<2|s}else{r=je(s>>>((2-x|0)>>>0)|z<<x|0)|0;z=b+796|0;D=c[z>>2]|0;y=r;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;E=x+30|0;F=s}c[e>>2]=F;c[f>>2]=E;if((E|0)>1){H=E-1|0;I=F<<1|1}else{s=je(1>>>((1-E|0)>>>0)|F<<E|0)|0;F=b+796|0;x=c[F>>2]|0;y=s;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[F>>2]=(c[F>>2]|0)+4;H=E+31|0;I=1}c[e>>2]=I;c[f>>2]=H;E=c[b+9960>>2]|0;if((H|0)>5){J=H-5|0;K=I<<5|E}else{F=je(I<<H|E>>>((5-H|0)>>>0)|0)|0;I=b+796|0;x=c[I>>2]|0;y=F;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;J=H+27|0;K=E}c[e>>2]=K;c[f>>2]=J;if((J|0)>1){L=J-1|0;M=K<<1}else{E=je(K<<J|0)|0;K=b+796|0;H=c[K>>2]|0;y=E;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[K>>2]=(c[K>>2]|0)+4;L=J+31|0;M=0}c[e>>2]=M;c[f>>2]=L;L=b+9892|0;if((c[b+228>>2]|0)==0){c[L>>2]=1347360;c[b+9888>>2]=1347360;return}else{c[L>>2]=1434232;c[b+9888>>2]=1434232;return}}function wfa(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0;h=b|0;i=c[h>>2]|0;j=b+4|0;k=c[j>>2]|0;l=(k|0)>1;if((e|0)<64){if(l){m=k-1|0;n=i<<1}else{e=je(i<<k|0)|0;o=b+12|0;p=c[o>>2]|0;y=e;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;m=k+31|0;n=0}c[h>>2]=n;c[j>>2]=m;if((m|0)>1){q=m-1|0;r=n<<1|g}else{o=je(g>>>((1-m|0)>>>0)|n<<m|0)|0;n=b+12|0;p=c[n>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;q=m+31|0;r=g}c[h>>2]=r;c[j>>2]=q;if((q|0)>6){s=q-6|0;t=r<<6|f}else{m=je(f>>>((6-q|0)>>>0)|r<<q|0)|0;r=b+12|0;n=c[r>>2]|0;y=m;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;s=q+26|0;t=f}c[h>>2]=t;c[j>>2]=s;q=d&127;if((s|0)>7){u=s-7|0;v=t<<7|q;c[h>>2]=v;c[j>>2]=u;return}else{r=je(q>>>((7-s|0)>>>0)|t<<s|0)|0;t=b+12|0;n=c[t>>2]|0;y=r;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;u=s+25|0;v=q;c[h>>2]=v;c[j>>2]=u;return}}else{if(l){w=k-1|0;x=i<<1|1}else{l=je(1>>>((1-k|0)>>>0)|i<<k|0)|0;i=b+12|0;q=c[i>>2]|0;y=l;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;w=k+31|0;x=1}c[h>>2]=x;c[j>>2]=w;if((w|0)>1){z=w-1|0;A=x<<1|g}else{k=je(g>>>((1-w|0)>>>0)|x<<w|0)|0;x=b+12|0;i=c[x>>2]|0;y=k;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;z=w+31|0;A=g}c[h>>2]=A;c[j>>2]=z;if((z|0)>6){B=z-6|0;C=A<<6|f}else{g=je(f>>>((6-z|0)>>>0)|A<<z|0)|0;A=b+12|0;w=c[A>>2]|0;y=g;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;B=z+26|0;C=f}c[h>>2]=C;c[j>>2]=B;f=d&2047;if((B|0)>11){u=B-11|0;v=C<<11|f;c[h>>2]=v;c[j>>2]=u;return}else{d=je(f>>>((11-B|0)>>>0)|C<<B|0)|0;C=b+12|0;b=c[C>>2]|0;y=d;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;u=B+21|0;v=f;c[h>>2]=v;c[j>>2]=u;return}}}function xfa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0;do{if((e|0)==2){if((d|0)==0){return}f=c[b>>2]|0;h=c[b+4>>2]|0;i=0;do{j=i<<1;g[a+(j<<2)>>2]=+g[f+(i<<2)>>2];g[a+((j|1)<<2)>>2]=+g[h+(i<<2)>>2];i=i+1|0;}while(i>>>0<d>>>0);return}else if((e|0)==1){if(!(d>>>0<536870911>>>0)){k=0;break}nrc(a|0,c[b>>2]|0,d<<2)|0;return}else{if(!((e|0)<1|(d|0)==0)){k=0;break}return}}while(0);do{i=c[b+(k<<2)>>2]|0;h=k;f=0;while(1){g[a+(h<<2)>>2]=+g[i+(f<<2)>>2];j=f+1|0;if(j>>>0<d>>>0){h=h+e|0;f=j}else{break}}k=k+1|0;}while((k|0)<(e|0));return}function yfa(a,b){a=a|0;b=b|0;c[a>>2]=2;c[a+4>>2]=576;c[a+8>>2]=934;c[a+12>>2]=188;c[a+16>>2]=96;return}function zfa(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0;if((e|0)>0){f=0}else{return}do{g[a+(f<<2)>>2]=+(c[b+(f<<2)>>2]|0)*d;f=f+1|0;}while((f|0)<(e|0));return}function Afa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0;if((f|0)<=0){return}h=a|0;a=e;e=0;while(1){xe[c[h>>2]&7](b+(e<<2)|0,d+(e<<2)|0,+g[a>>2],8);i=e+8|0;if((i|0)<(f|0)){a=a+4|0;e=i}else{break}}return}function Bfa(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,h=0;if((d|0)>0){e=0}else{return}do{f=Lc(+(+g[c+(e<<2)>>2]))|0;if((f+32768|0)>>>0>65535>>>0){h=(f>>31^32767)&65535}else{h=f&65535}b[a+(e<<1)>>1]=h;e=e+1|0;}while((e|0)<(d|0));return}function Cfa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)!=2){if((f|0)>0&(e|0)>0){h=0}else{return}do{i=d+(h<<2)|0;j=0;k=h;while(1){l=Lc(+(+g[(c[i>>2]|0)+(j<<2)>>2]))|0;if((l+32768|0)>>>0>65535>>>0){m=(l>>31^32767)&65535}else{m=l&65535}b[a+(k<<1)>>1]=m;l=j+1|0;if((l|0)<(e|0)){j=l;k=k+f|0}else{break}}h=h+1|0;}while((h|0)<(f|0));return}if((e|0)<=0){return}f=d+4|0;h=0;do{m=Lc(+(+g[(c[d>>2]|0)+(h<<2)>>2]))|0;if((m+32768|0)>>>0>65535>>>0){n=(m>>31^32767)&65535}else{n=m&65535}m=h<<1;b[a+(m<<1)>>1]=n;k=Lc(+(+g[(c[f>>2]|0)+(h<<2)>>2]))|0;if((k+32768|0)>>>0>65535>>>0){o=(k>>31^32767)&65535}else{o=k&65535}b[a+((m|1)<<1)>>1]=o;h=h+1|0;}while((h|0)<(e|0));return}function Dfa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+4>>2]=0;l8(b+12|0,a);return 0}function Efa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=c[b+60>>2]|0;m=l;n=c[g+24>>2]|0;o=c[g+28>>2]|0;c[j>>2]=e;c[j+4>>2]=0;c[j+8>>2]=0;if((o|0)<4){KIb(b,16,2453624,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}g=n;r=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=r&255;s=r>>>28&4;t=s+4|0;if(g>>>0>5>>>0){KIb(b,16,2364264,(p=i,i=i+8|0,c[p>>2]=g,p)|0);i=p;q=-1163346256;i=h;return q|0}u=n+t|0;a:do{if(g>>>0<2>>>0){v=((ca((c[b+120>>2]|0)*3|0,c[b+124>>2]|0)|0)>>>(((g|0)==0|0)>>>0))+t|0;if((r|0)<0){c[f>>2]=0;q=o;i=h;return q|0}if((o|0)==(v|0)){w=0;break}KIb(b,16,2299096,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=v,p)|0);i=p;q=-1094995529;i=h;return q|0}else{if((o|0)==8){c[f>>2]=0;q=8;i=h;return q|0}v=u;if((d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)!=2018725958|(o|0)<3096){KIb(b,16,2248176,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}v=s|8;x=o-t|0;y=n+v|0;z=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;c[k>>2]=z;do{if(z>>>0<x>>>0){y=n+(v+4)|0;A=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;c[k+4>>2]=A;if(!(A>>>0<x>>>0)){B=1;break}if(!(A>>>0>(z+1024|0)>>>0)){B=1;break}y=n+(v+8)|0;C=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;c[k+8>>2]=C;if(!(C>>>0<x>>>0)){B=2;break}if(!(C>>>0>(A+1024|0)>>>0)){B=2;break}c[k+12>>2]=x;A=l+4|0;C=A;y=l+8|0;D=0;E=z;while(1){if((D|0)>=3){w=z;break a}F=D+1|0;G=c[k+(F<<2)>>2]|0;A4a(A,y,G-1024-E|0);if((c[C>>2]|0)==0){q=-12;break}else{D=F;E=G}}i=h;return q|0}else{B=0}}while(0);KIb(b,16,2206096,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;q=-1094995529;i=h;return q|0}}while(0);c[e+88>>2]=1;c[e+84>>2]=1;B=r&1;c[b+140>>2]=(B|0)!=0?3:12;c[b+396>>2]=B<<1^2;c[b+392>>2]=B+1;B=J5a(b,j,0)|0;if((B|0)<0){q=B;i=h;return q|0}b:do{switch(g|0){case 1:{B=b+124|0;j=c[B>>2]|0;if((j|0)==0){break b}r=e+32|0;l=e;s=b+120|0;z=0;x=j;do{j=ca(c[r>>2]|0,x+~z|0)|0;v=c[s>>2]|0;nrc((c[l>>2]|0)+j|0,n+((ca(z*3|0,v)|0)+t)|0,v*3|0)|0;z=z+1|0;x=c[B>>2]|0;}while(z>>>0<x>>>0);break};case 2:case 4:{x=e;z=e+32|0;B=b+120|0;l=b+124|0;s=0;r=w;while(1){if((s|0)>=3){break b}v=(s|0)!=0|0;j=s+1|0;E=c[k+(j<<2)>>2]|0;H=Gfa(m,c[x+(s<<2)>>2]|0,c[z+(s<<2)>>2]|0,c[B>>2]>>v,c[l>>2]>>v,n+(r+t)|0,E-r|0,v,1)|0;if((H|0)<0){break}else{s=j;r=E}}KIb(b,16,2146272,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;q=H;i=h;return q|0};case 5:case 3:{r=e;l=e+32|0;B=b+124|0;z=b+120|0;x=0;E=w;while(1){I=c[r>>2]|0;if((x|0)>=3){break}j=c[l>>2]|0;v=c[B>>2]|0;D=I+((ca(v-1|0,j)|0)+x)|0;C=x+1|0;y=c[k+(C<<2)>>2]|0;J=Gfa(m,D,-j|0,c[z>>2]|0,v,n+(E+t)|0,y-E|0,0,3)|0;if((J|0)<0){K=43;break}else{x=C;E=y}}if((K|0)==43){KIb(b,16,2146272,(p=i,i=i+8|0,c[p>>2]=x,p)|0);i=p;q=J;i=h;return q|0}E=c[B>>2]|0;if((E|0)<=0){break b}r=0;s=I;y=c[z>>2]|0;C=E;while(1){E=y*3|0;v=s+E|0;if((E|0)>0){E=s;do{j=a[E+1|0]|0;a[E]=(a[E]|0)+j;D=E+2|0;a[D]=(a[D]|0)+j;E=E+3|0;}while(E>>>0<v>>>0);L=E;M=c[z>>2]|0;N=c[B>>2]|0}else{L=s;M=y;N=C}v=r+1|0;if((v|0)<(N|0)){r=v;s=L+((M*-3|0)+(c[l>>2]|0))|0;y=M;C=N}else{break}}break};default:{C=b+120|0;y=c[C>>2]|0;l=b+124|0;s=c[l>>2]|0;do{if((y&7|0)==0){if((s&1|0)!=0){break}if(!((s+1|0)>>>0>2>>>0)){break b}r=e+32|0;B=c[e>>2]|0;z=e+36|0;x=c[e+4>>2]|0;v=e+40|0;j=c[e+8>>2]|0;D=0;A=u;G=y;F=s;while(1){O=D<<1;P=c[r>>2]|0;if((G|0)==0){Q=A;R=0;S=F}else{T=A;U=B+(ca(P,O)|0)|0;V=B+(ca(P,O|1)|0)|0;O=j+(ca(c[v>>2]|0,D)|0)|0;P=x+(ca(c[z>>2]|0,D)|0)|0;W=0;while(1){c[U>>2]=c[T>>2];c[U+4>>2]=c[T+4>>2];c[V>>2]=c[T+8>>2];c[V+4>>2]=c[T+12>>2];c[P>>2]=c[T+16>>2];X=T+24|0;c[O>>2]=c[T+20>>2];Y=W+8|0;Z=c[C>>2]|0;if(Y>>>0<Z>>>0){T=X;U=U+8|0;V=V+8|0;O=O+4|0;P=P+4|0;W=Y}else{break}}Q=X;R=Z;S=c[l>>2]|0}W=D+1|0;if(W>>>0<((S|0)/2|0)>>>0){D=W;A=Q;G=R;F=S}else{break b}}}}while(0);KIb(b,16,2173904,(p=i,i=i+16|0,c[p>>2]=y,c[p+8>>2]=s,p)|0);i=p;q=-1094995529;i=h;return q|0}}}while(0);c[f>>2]=1;q=o;i=h;return q|0}function Ffa(a){a=a|0;mJb((c[a+60>>2]|0)+4|0);return 0}function Gfa(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;o=i;i=i+4120|0;p=o|0;q=o+24|0;r=k;s=0;while(1){t=r;c[q+(s<<3)+4>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;t=s+1|0;if((t|0)<256){r=r+4|0;s=t}else{break}}s=l-1024|0;l=QKa(c[e>>2]|0,p,256,11,q|0,42,2)|0;if((l|0)<0){u=l;i=o;return u|0}l=e+4|0;ef[c[e+1108>>2]&4095](c[l>>2]|0,k+1024|0,s>>2);k=c[l>>2]|0;l=s<<3;s=l>>>0>2147483639>>>0|(k|0)==0;e=s?0:k;k=s?0:l;l=k+8|0;a:do{if((j|0)>0){s=ca(n,h)|0;q=p+4|0;r=(m|0)==0;t=0;v=f;w=0;b:while(1){c:do{if((w|0)==0){x=0;y=t;while(1){if((x|0)>=(s|0)){z=y;break c}A=c[q>>2]|0;B=e+(y>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)>>>21;B=b[A+(C<<2)>>1]|0;D=b[A+(C<<2)+2>>1]|0;C=D<<16>>16;do{if(D<<16>>16<0){E=y+11|0;F=l>>>0>E>>>0?E:l;E=e+(F>>>3)|0;G=((je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(F&7)>>>((C+32|0)>>>0))+B|0;E=b[A+(G<<2)>>1]|0;H=b[A+(G<<2)+2>>1]|0;G=H<<16>>16;if(!(H<<16>>16<0)){I=G;J=E;K=F;break}H=F-C|0;F=l>>>0>H>>>0?H:l;H=e+(F>>>3)|0;L=((je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>((G+32|0)>>>0))+E|0;I=b[A+(L<<2)+2>>1]|0;J=b[A+(L<<2)>>1]|0;K=F}else{I=C;J=B;K=y}}while(0);B=I+K|0;C=l>>>0>B>>>0?B:l;if(r){M=J&255}else{M=J+128&255}a[v+x|0]=M;if((k-C|0)<0){break b}else{x=x+n|0;y=C}}}else{if(r){y=0;x=t;while(1){if((y|0)>=(s|0)){z=x;break c}C=c[q>>2]|0;B=e+(x>>>3)|0;A=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>21;B=b[C+(A<<2)>>1]|0;D=b[C+(A<<2)+2>>1]|0;A=D<<16>>16;do{if(D<<16>>16<0){F=x+11|0;L=l>>>0>F>>>0?F:l;F=e+(L>>>3)|0;E=((je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(L&7)>>>((A+32|0)>>>0))+B|0;F=b[C+(E<<2)>>1]|0;G=b[C+(E<<2)+2>>1]|0;E=G<<16>>16;if(!(G<<16>>16<0)){N=E;O=F;P=L;break}G=L-A|0;L=l>>>0>G>>>0?G:l;G=e+(L>>>3)|0;H=((je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(L&7)>>>((E+32|0)>>>0))+F|0;N=b[C+(H<<2)+2>>1]|0;O=b[C+(H<<2)>>1]|0;P=L}else{N=A;O=B;P=x}}while(0);B=N+P|0;A=l>>>0>B>>>0?B:l;B=v+y|0;a[B]=O;a[B]=(d[v+(y-g)|0]|0)+O;if((k-A|0)<0){break b}else{y=y+n|0;x=A}}}else{x=0;y=t;while(1){if((x|0)>=(s|0)){z=y;break c}A=c[q>>2]|0;B=e+(y>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)>>>21;B=b[A+(C<<2)>>1]|0;D=b[A+(C<<2)+2>>1]|0;C=D<<16>>16;do{if(D<<16>>16<0){L=y+11|0;H=l>>>0>L>>>0?L:l;L=e+(H>>>3)|0;F=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(H&7)>>>((C+32|0)>>>0))+B|0;L=b[A+(F<<2)>>1]|0;E=b[A+(F<<2)+2>>1]|0;F=E<<16>>16;if(!(E<<16>>16<0)){Q=F;R=L;S=H;break}E=H-C|0;H=l>>>0>E>>>0?E:l;E=e+(H>>>3)|0;G=((je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(H&7)>>>((F+32|0)>>>0))+L|0;Q=b[A+(G<<2)+2>>1]|0;R=b[A+(G<<2)>>1]|0;S=H}else{Q=C;R=B;S=y}}while(0);B=Q+S|0;C=l>>>0>B>>>0?B:l;B=v+x|0;a[B]=R;a[B]=(d[v+(x-g)|0]|0)+R;if((k-C|0)<0){break b}else{x=x+n|0;y=C}}}}}while(0);y=w+1|0;if((y|0)<(j|0)){t=z;v=v+g|0;w=y}else{break a}}c3(p);u=-1094995529;i=o;return u|0}}while(0);c3(p);u=0;i=o;return u|0}function Hfa(a,d){a=a|0;d=d|0;return((c[a+4>>2]|0)-(c[d+4>>2]|0)<<8)+(b[a>>1]|0)-(b[d>>1]|0)|0}function Ifa(a){a=a|0;var b=0,d=0;b=i;if((c[a+120>>2]&1|0)==0){c[a+140>>2]=17;d=0;i=b;return d|0}else{KIb(a,16,2206056,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;d=-22;i=b;return d|0}return 0}function Jfa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;h=c[a+60>>2]|0;j=c[f+24>>2]|0;k=f+28|0;f=c[k>>2]|0;l=a+120|0;m=a+124|0;if((f|0)<((ca(c[l>>2]<<1,c[m>>2]|0)|0)+20|0)){KIb(a,16,2453600,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}p=j;if((d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)!=827806278){KIb(a,16,2364240,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}p=M4a(a,b,0)|0;if((p|0)<0){o=p;i=g;return o|0}c[b+88>>2]=1;c[b+84>>2]=1;p=b;q=j+f|0;f=h+4|0;h=b+32|0;b=j+4|0;j=0;r=c[l>>2]|0;while(1){s=(j|0)!=0;t=(c[m>>2]|0)+(s&1^1)>>1;u=ca(r<<1,t)|0;v=c[p>>2]|0;if((q-b|0)<8){o=-1094995529;w=26;break}x=b+8|0;y=b+4|0;z=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;if((z|0)<(u|0)){w=9;break}A=q-x|0;if((A|0)<(z|0)){w=11;break}y=c[f>>2]|0;do{if((j|0)==(y|0)){if((j|0)==0){B=v;break}B=v+(c[h>>2]<<1)|0}else{B=v+(c[h>>2]|0)|0}}while(0);a:do{if((t|0)>0){v=t-1|0;if(s){C=x;D=0;E=B;F=r;G=y}else{H=x;I=0;J=B;K=r;while(1){nrc(J|0,H|0,K<<1)|0;L=c[l>>2]|0;M=H+(L<<1)|0;N=I+1|0;if((N|0)<(t|0)){H=M;I=N;J=J+(c[h>>2]<<1)|0;K=L}else{O=M;P=L;break a}}}while(1){if((G|0)!=0&(D|0)==(v|0)){Q=c[p>>2]|0}else{Q=E}nrc(Q|0,C|0,F<<1)|0;K=c[l>>2]|0;J=C+(K<<1)|0;I=D+1|0;if((I|0)>=(t|0)){O=J;P=K;break a}C=J;D=I;E=Q+(c[h>>2]<<1)|0;F=K;G=c[f>>2]|0}}else{O=x;P=r}}while(0);x=j+1|0;if((x|0)>=2){w=25;break}b=O+(z-u)|0;j=x;r=P}if((w|0)==9){KIb(a,16,2299048,(n=i,i=i+16|0,c[n>>2]=z,c[n+8>>2]=u,n)|0);i=n;o=-1094995529;i=g;return o|0}else if((w|0)==11){KIb(a,16,2248136,(n=i,i=i+16|0,c[n>>2]=z,c[n+8>>2]=A,n)|0);i=n;o=-1094995529;i=g;return o|0}else if((w|0)==25){c[e>>2]=1;o=c[k>>2]|0;i=g;return o|0}else if((w|0)==26){i=g;return o|0}return 0}function Kfa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+1280|0;e=d+256|0;f=d+768|0;g=c[a+60>>2]|0;h=d|0;j=e;k=f;mrc(h|0,0,256)|0;l=e|0;eQa(h,l,1965720,1965368);e=0;do{b[f+(e<<1)>>1]=e;e=e+1|0;}while((e|0)<256);e=g+1376|0;do{if(($2(e,9,12,h,1,1,j,2,2,k,2,2,0)|0)==0){mrc(h|0,0,256)|0;eQa(h,l,1965744,1965368);m=0;do{b[f+(m<<1)>>1]=m;m=m+1|0;}while((m|0)<256);m=g+1396|0;if(($2(m,9,12,h,1,1,j,2,2,k,2,2,0)|0)!=0){n=m;break}mrc(h|0,0,256)|0;eQa(h,l,1965768,1965384);o=0;do{b[f+(o<<1)>>1]=o+16;o=o+1|0;}while((o|0)<256);o=f|0;b[o>>1]=4096;if(($2(g+1416|0,9,251,h,1,1,j,2,2,k,2,2,0)|0)!=0){n=m;break}mrc(h|0,0,256)|0;eQa(h,l,1965792,1965552);p=0;do{b[f+(p<<1)>>1]=p+16;p=p+1|0;}while((p|0)<256);b[o>>1]=4096;if(($2(g+1436|0,9,251,h,1,1,j,2,2,k,2,2,0)|0)!=0){n=m;break}l8(g,a);L6(g+1128|0,g+1244|0,1242080);c[a+140>>2]=2;q=0;i=d;return q|0}else{n=g+1396|0}}while(0);KIb(a,16,2382808,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c3(e);c3(g+1416|0);c3(n);c3(g+1436|0);mJb(g+2240|0);q=-12;i=d;return q|0}function Lfa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0;h=i;i=i+784|0;j=h|0;k=h+768|0;l=h+776|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;o=e;if((n|0)<12){KIb(b,16,2453536,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;q=-1094995529;i=h;return q|0}r=m+n|0;s=m;t=m+4|0;u=m;v=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;do{if((v&-16|0)==1194478896){u=v&15;if((u-2|0)>>>0>2>>>0){break}if((u|0)!=4){KIb(b,16,2299008,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-38;i=h;return q|0}u=n-4|0;do{if(u>>>0>5>>>0){w=b;x=g+2300|0;z=g+2264|0;A=g+2268|0;B=b+120|0;C=b+124|0;D=g+2260|0;E=g+2276|0;F=g+2280|0;G=g+2284|0;H=g+2288|0;I=g+2272|0;J=g+2304|0;K=g+2308|0;L=g+2320|0;M=g+2324|0;N=g+2328|0;O=g+2340|0;P=g+2344|0;Q=g+2332|0;R=g+2336|0;S=g+2312|0;T=g+2316|0;U=g+2292|0;V=g+2296|0;W=j|0;X=k|0;Y=g;Z=g+2368|0;_=g+2372|0;$=g+2360|0;aa=g+2364|0;ba=g+2348|0;da=ba;ea=g+2376|0;fa=g+2380|0;ga=g+2356|0;ha=g+2352|0;ia=t;ja=0;ka=u;a:while(1){if((ka|0)<4){la=0;ma=ia}else{na=ia;la=d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0;ma=ia+4|0}oa=la-1|0;if((r-ma|0)<1){pa=0;qa=ma}else{pa=d[ma]|0;qa=ma+1|0}na=qa;ra=na-s|0;sa=r-na|0;if(oa>>>0>sa>>>0){ta=15;break}b:do{switch(pa|0){case 203:{if(oa>>>0<8>>>0){KIb(w,16,2478952,(p=i,i=i+8|0,c[p>>2]=oa,p)|0);i=p;ua=ja;va=qa;break b}na=m+ra|0;wa=la-5|0;if(!((wa|0)>-1)){ta=139;break a}xa=m+(ra+wa)|0;if((wa|0)<4){ya=0;za=na}else{wa=na;ya=je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0;za=m+(ra+4)|0}if((xa-za|0)<1){Aa=0;Ba=za}else{Aa=d[za]|0;Ba=za+1|0}if((xa-Ba|0)<1){Ca=0;Da=Ba}else{Ca=d[Ba]|0;Da=Ba+1|0}if((xa-Da|0)<1){Ea=0;Fa=Da}else{Ea=d[Da]|0;Fa=Da+1|0}if((xa-Fa|0)<1){Ga=0;Ha=Fa}else{Ga=d[Fa]|0;Ha=Fa+1|0}if((xa-Ha|0)<1){Ia=0;Ja=Ha}else{Ia=d[Ha]|0;Ja=Ha+1|0}wa=(Ia|0)==1?32:1;na=(Aa+1073741823+wa&-wa)<<2;if((Aa|0)==0|(Ca|0)==0){KIb(w,16,246e4,(p=i,i=i+16|0,c[p>>2]=Aa,c[p+8>>2]=Ca,p)|0);i=p;ua=ja;va=qa;break b}if(Ea>>>0>Aa>>>0|Ga>>>0>Ca>>>0){KIb(w,24,2443320,(p=i,i=i+16|0,c[p>>2]=Ea,c[p+8>>2]=Ga,p)|0);i=p;wa=Aa-1|0;Ka=Ca-1|0;La=Ga>>>0>Ka>>>0?Ka:Ga;Ma=Ea>>>0>wa>>>0?wa:Ea}else{La=Ga;Ma=Ea}wa=xa-Ja|0;do{if(!((ya-9|0)>>>0>wa>>>0)){if(((ca(c[aa>>2]|0,c[$>>2]|0)|0)/4|0)>>>0>ya>>>0){break}if(!((Ia|0)==32|(Ia|0)==1)){RIb(w,2420632,(p=i,i=i+8|0,c[p>>2]=Ia,p)|0);i=p;ua=ja;va=qa;break b}if((lJb(ba,ca(na,Ca)|0)|0)<0){KIb(w,16,2411344,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;ua=ja;va=qa;break b}c[$>>2]=Aa;c[aa>>2]=Ca;c[ea>>2]=Ma;c[fa>>2]=La;c[ga>>2]=Ia;c[ha>>2]=na;Ka=c[da>>2]|0;if((Ia|0)==32){Na=ca(Ca,(Aa+31|0)>>>3&60)|0;Oa=Ka;Pa=0;Qa=Aa;Ra=Ca;Sa=Ja+(wa>>>0>Na>>>0?Na:wa)|0;while(1){if((Qa|0)>0){Na=Oa;Ta=1;Ua=Sa;while(1){if((xa-Ua|0)<4){Va=0;Wa=0;Xa=0;Ya=0;Za=Ua}else{_a=Ua;$a=je(d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0)|0;Va=$a>>>24&255;Wa=$a>>>16&255;Xa=$a>>>8&255;Ya=$a&255;Za=Ua+4|0}a[Na]=Ya;a[Na+1|0]=Xa;a[Na+2|0]=Wa;ab=Na+4|0;a[Na+3|0]=Va;bb=c[$>>2]|0;if((Ta|0)<(bb|0)){Na=ab;Ta=Ta+1|0;Ua=Za}else{break}}cb=ab;db=bb;eb=c[aa>>2]|0;fb=Za}else{cb=Oa;db=Qa;eb=Ra;fb=Sa}Ua=Pa+1|0;if((Ua|0)<(eb|0)){Oa=cb;Pa=Ua;Qa=db;Ra=eb;Sa=fb}else{ua=ja;va=qa;break b}}}else if((Ia|0)==1){gb=Ka;hb=0;ib=Aa;jb=Ca;kb=Ja}else{ua=ja;va=qa;break b}while(1){if((ib|0)>0){Sa=gb;Ra=0;Qa=kb;while(1){if((xa-Qa|0)<4){lb=0;mb=Qa}else{Pa=Qa;lb=je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0;mb=Qa+4|0}Pa=lb;Oa=Sa;Ua=0;while(1){a[Oa]=Pa>>>31;Ta=Ua+1|0;if((Ta|0)<32){Pa=Pa<<1;Oa=Oa+4|0;Ua=Ta}else{break}}nb=Sa+128|0;Ua=Ra+32|0;ob=c[$>>2]|0;if((Ua|0)<(ob|0)){Sa=nb;Ra=Ua;Qa=mb}else{break}}pb=nb;qb=ob;rb=c[aa>>2]|0;sb=mb}else{pb=gb;qb=ib;rb=jb;sb=kb}Qa=hb+1|0;if((Qa|0)<(rb|0)){gb=pb;hb=Qa;ib=qb;jb=rb;kb=sb}else{break}}if((rb|0)<=0){ua=ja;va=qa;break b}Ka=c[da>>2]|0;Qa=0;Ra=qb;Sa=rb;Ua=sb;while(1){if((Ra|0)>0){Oa=Ka;Pa=0;Ta=Ua;while(1){if((xa-Ta|0)<4){tb=0;ub=Ta}else{Na=Ta;tb=je(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0;ub=Ta+4|0}Na=tb;$a=Oa;_a=0;while(1){vb=(d[$a]|0)<<1|Na>>>31;if((vb|0)==0){a[$a]=-1;a[$a+1|0]=0;a[$a+2|0]=0;a[$a+3|0]=0}else if((vb|0)==1){vb=$a;y=-1;a[vb]=y;y=y>>8;a[vb+1|0]=y;y=y>>8;a[vb+2|0]=y;y=y>>8;a[vb+3|0]=y}else{vb=$a;y=0;a[vb]=y;y=y>>8;a[vb+1|0]=y;y=y>>8;a[vb+2|0]=y;y=y>>8;a[vb+3|0]=y}vb=_a+1|0;if((vb|0)<32){Na=Na<<1;$a=$a+4|0;_a=vb}else{break}}wb=Oa+128|0;_a=Pa+32|0;xb=c[$>>2]|0;if((_a|0)<(xb|0)){Oa=wb;Pa=_a;Ta=ub}else{break}}yb=wb;zb=xb;Ab=c[aa>>2]|0;Bb=ub}else{yb=Ka;zb=Ra;Ab=Sa;Bb=Ua}Ta=Qa+1|0;if((Ta|0)<(Ab|0)){Ka=yb;Qa=Ta;Ra=zb;Sa=Ab;Ua=Bb}else{ua=ja;va=qa;break b}}}}while(0);KIb(w,16,2430880,(p=i,i=i+16|0,c[p>>2]=ya,c[p+8>>2]=wa,p)|0);i=p;ua=ja;va=qa;break};case 200:{c[x>>2]=0;if(oa>>>0<21>>>0){KIb(w,16,2206024,(p=i,i=i+8|0,c[p>>2]=oa,p)|0);i=p;ua=0;va=qa;break b}if((sa|0)<4){Cb=0;Db=qa}else{xa=qa;Cb=je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0;Db=qa+4|0}c[z>>2]=Cb;if((r-Db|0)<4){Eb=0;Fb=Db}else{xa=Db;Eb=je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0;Fb=Db+4|0}c[A>>2]=Eb;if((Cb|0)<16){ta=26;break a}xa=c[B>>2]|0;if((Cb|0)>(xa|0)|(Eb|0)<16){ta=26;break a}na=c[C>>2]|0;if((Eb|0)>(na|0)){ta=26;break a}if(!((Cb|0)==(xa|0)&(Eb|0)==(na|0))){na=H4a(b,Cb,Eb)|0;if((na|0)<0){Gb=na;break a}}if((r-Fb|0)<4){ta=30;break a}na=Fb+4|0;xa=Fb;Ua=je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0;c[D>>2]=Ua;if(!((Ua-2|0)>>>0<2>>>0)){Hb=Ua;ta=32;break a}if((r-na|0)<4){Ib=0;Jb=na}else{Ua=na;Ib=je(d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0)|0;Jb=Fb+8|0}c[E>>2]=Ib;if((r-Jb|0)<4){ta=36;break a}Ua=Jb+4|0;na=Jb;xa=d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0;na=je(xa|0)|0;c[F>>2]=na;if((Ib|0)==0|(xa|0)==0){Kb=na;ta=39;break a}if(((Ib|na)&15|0)!=0){Kb=na;ta=39;break a}xa=c[z>>2]|0;c[G>>2]=(Ib-1+xa|0)/(Ib|0)|0;Sa=c[A>>2]|0;c[H>>2]=(Sa-1+na|0)/(na|0)|0;if((r-Ua|0)<1){ta=41;break a}na=Jb+5|0;Ra=a[Ua]|0;Ua=Ra&255;c[I>>2]=Ua;if(!(Ra<<24>>24==32)){Lb=Ua;ta=53;break a}Ua=r-na|0;if(Ua>>>0<16>>>0){ta=45;break a}if((la-22|0)>>>0<16>>>0){ta=45;break a}if((Ua|0)<4){Mb=0;Nb=na}else{Ua=na;Mb=je(d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0)|0;Nb=Jb+9|0}if((r-Nb|0)<4){Ob=0;Pb=Nb}else{Ua=Nb;Ob=je(d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0)|0;Pb=Nb+4|0}if((r-Pb|0)<4){Qb=0;ta=52;break a}Ua=Pb+4|0;na=Pb;Ra=d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0;na=je(Ra|0)|0;if(!((Mb|0)==16711680&(Ob|0)==65280&(Ra|0)==-16777216)){Qb=na;ta=52;break a}na=c[J>>2]|0;do{if((na|0)==0){ta=57}else{if((c[S>>2]|0)<(xa|0)){ta=57;break}if((c[T>>2]|0)<(Sa|0)){ta=57}}}while(0);if((ta|0)==57){ta=0;c[K>>2]=(xa+30&-16)*3|0;kJb(na);wa=pJb(ca(c[K>>2]|0,Sa+15|0)|0)|0;c[J>>2]=wa;if((wa|0)==0){Gb=-12;break a}}wa=c[L>>2]|0;do{if((wa|0)!=0){if((c[M>>2]|0)==0){break}if((c[Q>>2]|0)<(c[E>>2]|0)){break}if((c[R>>2]|0)>=(c[F>>2]|0)){ua=1;va=Ua;break b}}}while(0);c[N>>2]=((c[E>>2]|0)+15&-16)*3|0;Sa=(c[F>>2]|0)+15&-16;kJb(wa);kJb(c[M>>2]|0);kJb(c[O>>2]|0);kJb(c[P>>2]|0);c[L>>2]=pJb(ca(c[N>>2]|0,Sa)|0)|0;c[M>>2]=pJb(ca(c[N>>2]|0,Sa)|0)|0;c[O>>2]=pJb((ca((c[E>>2]|0)+1|0,Sa)|0)+16|0)|0;na=pJb(ca(c[E>>2]|0,Sa)|0)|0;c[P>>2]=na;if((c[L>>2]|0)==0){Gb=-12;break a}if((c[M>>2]|0)==0){Gb=-12;break a}if((c[O>>2]|0)==0|(na|0)==0){Gb=-12;break a}else{ua=1;va=Ua}break};case 202:{if(oa>>>0<5>>>0){KIb(w,16,2489800,(p=i,i=i+8|0,c[p>>2]=oa,p)|0);i=p;ua=ja;va=qa;break b}if((sa|0)<2){Rb=0;Sb=qa}else{na=qa;Rb=(he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535;Sb=qa+2|0}c[Z>>2]=Rb;if((r-Sb|0)<2){Tb=0;Ub=Sb}else{na=Sb;Tb=(he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535;Ub=Sb+2|0}c[_>>2]=Tb;ua=ja;va=Ub;break};case 201:{na=c[G>>2]|0;do{if((na|0)!=0){Sa=c[H>>2]|0;if((Sa|0)==0){break}if(oa>>>0<2>>>0){KIb(w,16,2550432,(p=i,i=i+8|0,c[p>>2]=oa,p)|0);i=p;ua=ja;va=qa;break b}if((sa|0)<1){Vb=0;Wb=qa}else{Vb=d[qa]|0;Wb=qa+1|0}c[U>>2]=Vb;if((r-Wb|0)<1){Xb=0;Yb=Wb}else{Xb=d[Wb]|0;Yb=Wb+1|0}c[V>>2]=Xb;if(!((Vb|0)<(na|0)&(Xb|0)<(Sa|0))){KIb(w,16,2532256,(p=i,i=i+32|0,c[p>>2]=Vb,c[p+8>>2]=Xb,c[p+16>>2]=na,c[p+24>>2]=Sa,p)|0);i=p;ua=ja;va=Yb;break b}Sa=c[D>>2]|0;if((Sa|0)==2){ta=77;break a}else if((Sa|0)!=3){ua=ja;va=Yb;break b}Sa=Yb-s|0;xa=la-3|0;Ra=m+(Sa+xa)|0;Qa=c[E>>2]|0;Ka=c[F>>2]|0;c[l>>2]=ca(Qa+1|0,Ka)|0;Ta=ca(Qa,Vb)|0;Pa=ca(Ka,Xb)|0;Oa=c[K>>2]|0;_a=(c[J>>2]|0)+((ca(Oa,Pa)|0)+(Ta*3|0))|0;c:do{if((xa|0)>=2){$a=(c[z>>2]|0)-Ta|0;Na=($a|0)>(Qa|0)?Qa:$a;$a=(c[A>>2]|0)-Pa|0;vb=($a|0)>(Ka|0)?Ka:$a;$a=m+(Sa+1)|0;Zb=(d[m+Sa|0]|0)>>>5;if((Zb|0)==1){if((Nfa(Y,Na,vb,$a,Ra-$a|0,_a,Oa,0,0,0)|0)==0){ua=ja;va=Yb;break b}else{break}}else if((Zb|0)==0){a[X]=a[$a]|0;a[X+1|0]=a[$a+1|0]|0;a[X+2|0]=a[$a+2|0]|0;if((vb|0)>0&(Na|0)>0){_b=_a;$b=0}else{ua=ja;va=Yb;break b}while(1){ac=0;do{bc=_b+(ac*3|0)|0;a[bc]=a[X]|0;a[bc+1|0]=a[X+1|0]|0;a[bc+2|0]=a[X+2|0]|0;ac=ac+1|0;}while((ac|0)<(Na|0));ac=$b+1|0;if((ac|0)<(vb|0)){_b=_b+(c[K>>2]|0)|0;$b=ac}else{ua=ja;va=Yb;break b}}}else{ac=(Zb|0)!=2;if(ac){a[X]=a[$a]|0;a[X+1|0]=a[$a+1|0]|0;a[X+2|0]=a[$a+2|0]|0;cc=m+(Sa+4)|0}else{cc=$a}bc=cc+1|0;dc=(d[cc]|0)+1|0;ec=Ra;fc=dc*3|0;if((ec-bc|0)<(fc|0)){break}nrc(W|0,bc|0,fc)|0;bc=cc+(fc+1)|0;d:do{if(ac){gc=0;while(1){if((gc|0)>=(dc|0)){hc=-1;break d}if((grc(j+(gc*3|0)|0,X,3)|0)==0){hc=gc;break}else{gc=gc+1|0}}}else{hc=-1}}while(0);if((ec-bc|0)<2){ua=ja;va=Yb;break b}$a=(d[bc]|0)<<8|(d[cc+(fc+2)|0]|0);gc=fc+3|0;ic=cc+gc|0;if((ec-ic|0)<($a+(ac&1)|0)){break}if((Aqc(c[O>>2]|0,l,ic,$a)|0)!=0){break}ic=$a+gc|0;if((Zb|0)==2){gc=c[O>>2]|0;$a=c[K>>2]|0;jc=c[l>>2]<<3;kc=jc>>>0>2147483639>>>0|(gc|0)==0;lc=kc?0:gc;gc=kc?8:jc+8|0;do{if(dc>>>0<3>>>0){mc=1}else{if(dc>>>0<5>>>0){mc=2;break}mc=dc>>>0<17>>>0?4:8}}while(0);if((vb|0)<=0){ua=ja;va=Yb;break b}Zb=(Na|0)<1;ac=32-mc|0;fc=0;bc=_a;jc=0;while(1){kc=lc+(jc>>>3)|0;nc=je(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0;kc=jc+8|0;oc=gc>>>0>kc>>>0?kc:gc;if((nc&-16777216>>>((jc&7)>>>0)|0)!=0|Zb){pc=oc}else{nc=0;kc=oc;while(1){oc=lc+(kc>>>3)|0;qc=(je(d[oc]|d[oc+1|0]<<8|d[oc+2|0]<<16|d[oc+3|0]<<24|0)|0)<<(kc&7)>>>(ac>>>0);oc=kc+mc|0;rc=gc>>>0>oc>>>0?oc:gc;oc=nc*3|0;sc=bc+oc|0;if((qc|0)==(hc|0)){tc=oc|0;a[sc]=a[tc]|0;a[sc+1|0]=a[tc+1|0]|0;a[sc+2|0]=a[tc+2|0]|0}else{tc=j+(qc*3|0)|0;a[sc]=a[tc]|0;a[sc+1|0]=a[tc+1|0]|0;a[sc+2|0]=a[tc+2|0]|0}tc=nc+1|0;if((tc|0)<(Na|0)){nc=tc;kc=rc}else{pc=rc;break}}}kc=fc+1|0;if((kc|0)<(vb|0)){fc=kc;bc=bc+$a|0;jc=pc}else{ua=ja;va=Yb;break b}}}jc=cc+(ic+1)|0;$a=(d[cc+ic|0]|0)+1|0;bc=Na+15|0;fc=bc>>3&-2;gc=vb+15>>4;if((gc|0)>0){ac=bc>>4;bc=(ac|0)>0;lc=0;Zb=0;kc=jc;nc=0;rc=0;while(1){if(bc){tc=lc<<1;sc=ca(tc|1,fc)|0;qc=ca(tc,fc)|0;tc=0;oc=Zb;uc=kc;vc=nc;wc=rc;while(1){if((vc|0)==0){if(!(uc>>>0<Ra>>>0)){break c}xc=d[uc]|0;yc=8;zc=uc+1|0}else{xc=wc;yc=vc;zc=uc}Ac=xc&1;Bc=Ac+oc|0;if((Bc|0)>($a|0)){break c}Cc=xc>>1;Dc=yc-1|0;Ec=Ac&255;Ac=tc<<1;Fc=Ac|1;a[(c[P>>2]|0)+(Fc+sc)|0]=Ec;a[(c[P>>2]|0)+(Ac+sc)|0]=Ec;a[(c[P>>2]|0)+(Fc+qc)|0]=Ec;a[(c[P>>2]|0)+(Ac+qc)|0]=Ec;Ec=tc+1|0;if((Ec|0)<(ac|0)){tc=Ec;oc=Bc;uc=zc;vc=Dc;wc=Cc}else{Gc=Bc;Hc=zc;Ic=Dc;Jc=Cc;break}}}else{Gc=Zb;Hc=kc;Ic=nc;Jc=rc}wc=lc+1|0;if((wc|0)<(gc|0)){lc=wc;Zb=Gc;kc=Hc;nc=Ic;rc=Jc}else{Kc=Hc;break}}}else{Kc=jc}mrc(c[M>>2]|0,0,ca(c[N>>2]|0,vb)|0)|0;Nfa(Y,Na,vb,Kc,ec-Kc|0,c[M>>2]|0,c[N>>2]|0,c[P>>2]|0,fc,$a<<2)|0;rc=c[O>>2]|0;nc=c[K>>2]|0;kc=c[M>>2]|0;Zb=c[N>>2]|0;lc=c[l>>2]<<3;gc=lc>>>0>2147483639>>>0|(rc|0)==0;ac=gc?0:rc;rc=gc?8:lc+8|0;do{if(dc>>>0<3>>>0){Lc=1}else{if(dc>>>0<5>>>0){Lc=2;break}Lc=dc>>>0<17>>>0?4:8}}while(0);if((vb|0)<=0){ua=ja;va=Yb;break b}dc=(Na|0)<1;$a=32-Lc|0;fc=kc;ec=0;jc=_a;lc=0;while(1){gc=ac+(lc>>>3)|0;bc=je(d[gc]|d[gc+1|0]<<8|d[gc+2|0]<<16|d[gc+3|0]<<24|0)|0;gc=lc+8|0;ic=rc>>>0>gc>>>0?gc:rc;if((bc&-16777216>>>((lc&7)>>>0)|0)!=0|dc){Mc=ic}else{bc=0;gc=ic;while(1){ic=ac+(gc>>>3)|0;wc=(je(d[ic]|d[ic+1|0]<<8|d[ic+2|0]<<16|d[ic+3|0]<<24|0)|0)<<(gc&7)>>>($a>>>0);ic=gc+Lc|0;vc=rc>>>0>ic>>>0?ic:rc;ic=bc*3|0;uc=jc+ic|0;if((wc|0)==(hc|0)){oc=fc+ic|0;a[uc]=a[oc]|0;a[uc+1|0]=a[oc+1|0]|0;a[uc+2|0]=a[oc+2|0]|0}else{oc=j+(wc*3|0)|0;a[uc]=a[oc]|0;a[uc+1|0]=a[oc+1|0]|0;a[uc+2|0]=a[oc+2|0]|0}oc=bc+1|0;if((oc|0)<(Na|0)){bc=oc;gc=vc}else{Mc=vc;break}}}gc=ec+1|0;if((gc|0)<(vb|0)){fc=fc+Zb|0;ec=gc;jc=jc+nc|0;lc=Mc}else{ua=ja;va=Yb;break b}}}}}while(0);if((c[J>>2]|0)==0){ua=ja;va=Yb;break b}_a=c[V>>2]|0;KIb(w,16,2502920,(p=i,i=i+16|0,c[p>>2]=c[U>>2],c[p+8>>2]=_a,p)|0);i=p;ua=ja;va=Yb;break b}}while(0);KIb(w,24,2568448,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;ua=ja;va=qa;break};case 204:case 205:{ua=ja;va=qa;break};default:{KIb(w,24,2469192,(p=i,i=i+8|0,c[p>>2]=pa,p)|0);i=p;ua=ja;va=qa}}}while(0);sa=va;na=ra+oa+(s-sa)|0;Ua=r-sa|0;sa=va+(Ua>>>0>na>>>0?na:Ua)|0;Ua=r-sa|0;if(Ua>>>0>5>>>0){ia=sa;ja=ua;ka=Ua}else{Nc=ua;ta=195;break}}if((ta|0)==15){KIb(w,16,2248096,(p=i,i=i+16|0,c[p>>2]=oa,c[p+8>>2]=pa,p)|0);i=p;Nc=ja;ta=195}else if((ta|0)==26){KIb(w,16,2173856,(p=i,i=i+16|0,c[p>>2]=Cb,c[p+8>>2]=Eb,p)|0);i=p;Gb=-1094995529}else if((ta|0)==30){c[D>>2]=0;Hb=0;ta=32}else if((ta|0)==36){c[F>>2]=0;Kb=0;ta=39}else if((ta|0)==41){c[I>>2]=0;Lb=0;ta=53}else if((ta|0)==45){KIb(w,16,2640152,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Gb=-1094995529}else if((ta|0)==52){KIb(w,16,2617416,(p=i,i=i+24|0,c[p>>2]=Mb,c[p+8>>2]=Ob,c[p+16>>2]=Qb,p)|0);i=p;Gb=-1163346256}else if((ta|0)==77){KIb(w,16,2516936,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-38;i=h;return q|0}else if((ta|0)==139){KIb(0,0,2403744,(p=i,i=i+24|0,c[p>>2]=2396696,c[p+8>>2]=2389736,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}if((ta|0)==32){KIb(w,16,2146216,(p=i,i=i+8|0,c[p>>2]=Hb,p)|0);i=p;Gb=-1163346256}else if((ta|0)==39){KIb(w,16,2122448,(p=i,i=i+16|0,c[p>>2]=Ib,c[p+8>>2]=Kb,p)|0);i=p;Gb=-1094995529}else if((ta|0)==53){QIb(w,2590160,(p=i,i=i+8|0,c[p>>2]=Lb,p)|0);i=p;Gb=-1163346256}else if((ta|0)==195){if((Nc|0)==0){Oc=0;Pc=2;break}c[g+2300>>2]=1;Oc=Nc;Pc=1;break}c[A>>2]=0;c[z>>2]=0;c[H>>2]=0;c[G>>2]=0;q=Gb;i=h;return q|0}else{Oc=0;Pc=2}}while(0);u=g+2264|0;if((c[u>>2]|0)==0){q=n;i=h;return q|0}ka=g+2268|0;if((c[ka>>2]|0)==0){q=n;i=h;return q|0}ia=g+2304|0;if((c[ia>>2]|0)==0){q=n;i=h;return q|0}U=M4a(b,o,0)|0;if((U|0)<0){q=U;i=h;return q|0}c[e+84>>2]=Oc;c[e+88>>2]=Pc;U=b+124|0;V=e;J=c[V>>2]|0;N=e+32|0;M=c[N>>2]|0;if((c[U>>2]|0)>0){K=g+2308|0;O=0;P=J;Y=M;while(1){X=P+(ca(Y,O)|0)|0;W=(c[ia>>2]|0)+(ca(c[K>>2]|0,O)|0)|0;nrc(X|0,W|0,(c[u>>2]|0)*3|0)|0;W=O+1|0;X=c[V>>2]|0;E=c[N>>2]|0;if((W|0)<(c[U>>2]|0)){O=W;P=X;Y=E}else{Qc=X;Rc=E;break}}}else{Qc=J;Rc=M}Y=c[g+2348>>2]|0;do{if((Y|0)!=0){P=(c[g+2368>>2]|0)-(c[g+2376>>2]|0)|0;O=(c[g+2372>>2]|0)-(c[g+2380>>2]|0)|0;U=c[g+2360>>2]|0;N=c[g+2364>>2]|0;V=c[u>>2]|0;K=(U+P|0)>(V|0)?V-P|0:U;U=c[ka>>2]|0;V=(N+O|0)>(U|0)?U-O|0:N;if((P|0)<0){Sc=Qc;Tc=Y+(-P<<2)|0;Uc=K+P|0}else{Sc=Qc+(P*3|0)|0;Tc=Y;Uc=K}if((O|0)<0){Vc=Sc;Wc=Tc+(ca(c[g+2352>>2]|0,-O|0)|0)|0;Xc=V+O|0}else{Vc=Sc+(ca(O,Rc)|0)|0;Wc=Tc;Xc=V}if(!((Xc|Uc|0)>-1&(Xc|0)>0)){break}V=(Uc|0)>0;O=g+2352|0;K=0;P=Wc;N=Vc;while(1){if(V){U=0;do{ia=U<<2;E=U*3|0;X=N+E|0;W=d[P+ia|0]|0;_=256-W|0;Z=ca(d[X]|0,_)|0;a[X]=((ca(d[P+(ia|1)|0]|0,W)|0)+Z|0)>>>8;Z=N+(E+1)|0;X=ca(d[Z]|0,_)|0;a[Z]=((ca(d[P+(ia|2)|0]|0,W)|0)+X|0)>>>8;X=N+(E+2)|0;E=ca(d[X]|0,_)|0;a[X]=((ca(d[P+(ia|3)|0]|0,W)|0)+E|0)>>>8;U=U+1|0;}while((U|0)<(Uc|0))}U=K+1|0;if((U|0)<(Xc|0)){K=U;P=P+(c[O>>2]|0)|0;N=N+Rc|0}else{break}}}}while(0);c[f>>2]=1;q=n;i=h;return q|0}}while(0);KIb(b,16,2364176,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;q=-1094995529;i=h;return q|0}function Mfa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c3(b+1376|0);c3(b+1416|0);c3(b+1396|0);c3(b+1436|0);mJb(b+2240|0);mJb(b+2340|0);mJb(b+2344|0);mJb(b+2320|0);mJb(b+2324|0);mJb(b+2348|0);mJb(b+2304|0);return 0}function Nfa(d,e,f,g,h,j,k,l,m,n){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;o=i;i=i+24|0;p=o|0;q=d+2240|0;r=lJb(q,h+16|0)|0;if((r|0)<0){s=r;i=o;return s|0}r=c[q>>2]|0;t=g+h|0;if((h|0)>0){h=r;u=g;while(1){g=u+1|0;v=a[u]|0;w=h+1|0;a[h]=v;if(v<<24>>24==-1){x=(a[g]|0)==0?u+2|0:g}else{x=g}if(x>>>0<t>>>0){h=w;u=x}else{break}}y=w;z=c[q>>2]|0}else{y=r;z=r}w=y-r|0;mrc(z+w|0,0,16)|0;z=c[q>>2]|0;q=w<<3;w=q>>>0>2147483639>>>0|(z|0)==0;r=w?0:z;z=w?0:q;c[p>>2]=r;c[p+12>>2]=z;c[p+16>>2]=z+8;c[p+4>>2]=r+(z>>3);c[p+8>>2]=0;z=e+15>>4;e=f+15>>4;if((n|0)==0){A=ca(z<<2,e)|0}else{A=n}c[d+1456>>2]=1024;c[d+1460>>2]=1024;c[d+1464>>2]=1024;n=d+1472|0;qe[c[d+40>>2]&1023](n);if((e|0)<=0){s=0;i=o;return s|0}f=(z|0)>0;r=m<<1;q=d+1116|0;w=0;y=0;x=A;A=l;a:while(1){if(f){l=(A|0)!=0;u=0;h=0;t=x;while(1){b:do{if(l){g=u<<1;if((a[A+g|0]|0)==0){v=g|1;do{if((a[A+v|0]|0)==0){if((a[A+(g+m)|0]|0)!=0){break}if((a[A+(v+m)|0]|0)==0){B=t;break b}}}while(0);if(!l){C=22;break}}if((a[A+g|0]|0)==0){D=t}else{v=Ofa(d,p,0,n)|0;if((v|0)!=0){s=v;C=39;break a}qe[c[q>>2]&1023](n);D=t-1|0}if((a[A+(g|1)|0]|0)==0){E=D}else{v=d+1600|0;F=Ofa(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}qe[c[q>>2]&1023](v);E=D-1|0}v=g+m|0;if((a[A+v|0]|0)==0){G=E}else{F=d+1728|0;H=Ofa(d,p,0,F)|0;if((H|0)!=0){s=H;C=39;break a}qe[c[q>>2]&1023](F);G=E-1|0}if((a[A+(v+1)|0]|0)==0){I=G;C=23;break}v=d+1856|0;F=Ofa(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}qe[c[q>>2]&1023](v);I=G-1|0;C=23}else{C=22}}while(0);if((C|0)==22){C=0;v=Ofa(d,p,0,n)|0;if((v|0)!=0){s=v;C=39;break a}qe[c[q>>2]&1023](n);v=d+1600|0;F=Ofa(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}qe[c[q>>2]&1023](v);v=d+1728|0;F=Ofa(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}qe[c[q>>2]&1023](v);v=d+1856|0;F=Ofa(d,p,0,v)|0;if((F|0)!=0){s=F;C=39;break a}qe[c[q>>2]&1023](v);I=t-4|0;C=23}if((C|0)==23){C=0;v=d+1984|0;F=Ofa(d,p,1,v)|0;if((F|0)!=0){s=F;C=39;break a}qe[c[q>>2]&1023](v);v=d+2112|0;F=Ofa(d,p,2,v)|0;if((F|0)!=0){s=F;C=39;break a}qe[c[q>>2]&1023](v);v=0;do{F=ca(v+y|0,k)|0;H=v<<3&56;J=v>>3<<1;K=v>>1<<3;L=0;do{M=b[d+1472+((L>>3)+J<<7)+((L&7|H)<<1)>>1]|0;N=(L>>1)+K|0;O=(b[d+1984+(N<<1)>>1]|0)-128|0;P=(b[d+2112+(N<<1)>>1]|0)-128|0;N=((L+h|0)*3|0)+F|0;Q=((P*91881|0)+32768>>16)+M|0;if(Q>>>0>255>>>0){R=-Q>>31&255}else{R=Q&255}a[j+N|0]=R;Q=((O*-22554|0)+32768+(P*-46802|0)>>16)+M|0;if(Q>>>0>255>>>0){S=-Q>>31&255}else{S=Q&255}a[j+(N+1)|0]=S;Q=((O*116130|0)+32768>>16)+M|0;if(Q>>>0>255>>>0){T=-Q>>31&255}else{T=Q&255}a[j+(N+2)|0]=T;L=L+1|0;}while((L|0)<16);v=v+1|0;}while((v|0)<16);if((I|0)==0){s=0;C=39;break a}else{B=I}}v=u+1|0;if((v|0)<(z|0)){u=v;h=h+16|0;t=B}else{U=B;break}}}else{U=x}if((A|0)==0){V=0}else{V=A+r|0}t=w+1|0;if((t|0)<(e|0)){w=t;y=y+16|0;x=U;A=V}else{s=0;C=39;break}}if((C|0)==39){i=o;return s|0}return 0}function Ofa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=(f|0)!=0;i=h&1;j=h?1705136:841784;qe[c[a+36>>2]&1023](g);h=c[a+1376+(i*20|0)+4>>2]|0;k=e+8|0;l=c[k>>2]|0;m=e+16|0;n=c[m>>2]|0;o=c[e>>2]|0;e=o+(l>>>3)|0;p=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(l&7)>>>23;e=b[h+(p<<2)>>1]|0;q=b[h+(p<<2)+2>>1]|0;p=q<<16>>16;do{if(q<<16>>16<0){r=l+9|0;s=n>>>0>r>>>0?r:n;r=o+(s>>>3)|0;t=((je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((p+32|0)>>>0))+e|0;r=b[h+(t<<2)>>1]|0;u=b[h+(t<<2)+2>>1]|0;t=u<<16>>16;if(!(u<<16>>16<0)){v=t;w=r;x=s;break}u=s-p|0;s=n>>>0>u>>>0?u:n;u=o+(s>>>3)|0;y=((je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(s&7)>>>((t+32|0)>>>0))+r|0;v=b[h+(y<<2)+2>>1]|0;w=b[h+(y<<2)>>1]|0;x=s}else{v=p;w=e;x=l}}while(0);l=v+x|0;x=n>>>0>l>>>0?l:n;c[k>>2]=x;if((w|0)<0){z=-1094995529;return z|0}if((w|0)==0){A=0}else{l=o+(x>>>3)|0;v=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(x&7);l=(v^-2147483648)>>31;e=x+w|0;c[k>>2]=n>>>0>e>>>0?e:n;A=((l^v)>>>((32-w|0)>>>0)^l)-l|0}l=ca(d[j]|0,A)|0;A=a+1456+(f<<2)|0;f=l+(c[A>>2]|0)|0;b[g>>1]=f;c[A>>2]=f;f=c[a+1416+(i*20|0)+4>>2]|0;i=c[m>>2]|0;m=0;A=c[k>>2]|0;while(1){l=o+(A>>>3)|0;w=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(A&7)>>>23;l=b[f+(w<<2)>>1]|0;v=b[f+(w<<2)+2>>1]|0;w=v<<16>>16;do{if(v<<16>>16<0){n=A+9|0;e=i>>>0>n>>>0?n:i;n=o+(e>>>3)|0;x=((je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(e&7)>>>((w+32|0)>>>0))+l|0;n=b[f+(x<<2)>>1]|0;p=b[f+(x<<2)+2>>1]|0;x=p<<16>>16;if(!(p<<16>>16<0)){B=x;C=n;D=e;break}p=e-w|0;e=i>>>0>p>>>0?p:i;p=o+(e>>>3)|0;h=((je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(e&7)>>>((x+32|0)>>>0))+n|0;B=b[f+(h<<2)+2>>1]|0;C=b[f+(h<<2)>>1]|0;D=e}else{B=w;C=l;D=A}}while(0);l=B+D|0;w=i>>>0>l>>>0?l:i;c[k>>2]=w;if((C|0)<0){z=-1094995529;E=17;break}l=(C>>4)+m|0;v=C&15;F=(v|0)!=0;if((l|0)>63){E=13;break}if(F){e=o+(w>>>3)|0;h=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(w&7);e=(h^-2147483648)>>31;n=w+v|0;x=i>>>0>n>>>0?n:i;c[k>>2]=x;n=(ca(((e^h)>>>((32-v|0)>>>0)^e)-e|0,d[j+(d[1242080+l|0]|0)|0]|0)|0)&65535;b[g+(d[a+1248+l|0]<<1)>>1]=n;G=x}else{G=w}if((l|0)<63){m=l;A=G}else{z=0;E=17;break}}if((E|0)==13){z=F?-1094995529:0;return z|0}else if((E|0)==17){return z|0}return 0}function Pfa(a){a=a|0;var d=0,e=0;d=c[a+60>>2]|0;c[a+416>>2]=1;e=a+448|0;c[e>>2]=4;c[e+4>>2]=0;c[a+420>>2]=1;b[d+2114>>1]=8;b[d+2170>>1]=2;c[d+2056>>2]=22;return 0}function Qfa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[a+60>>2]|0;m=8-(c[l+4>>2]|0)|0;n=c[920184+(m<<2)>>2]|0;o=g+28|0;c[e+76>>2]=c[o>>2]<<1;p=M4a(a,e,0)|0;if((p|0)<0){q=p;i=h;return q|0}p=c[g+24>>2]|0;g=c[o>>2]|0;a=g<<3;r=a>>>0>2147483639>>>0|(p|0)==0;s=r?0:p;p=r?8:a+8|0;if((g|0)>0){g=6-m|0;a=32-g|0;r=l+2060|0;t=r;u=l+2114|0;v=r;r=2-m|0;w=l+2116|0;x=w;y=l+2170|0;z=w;w=l+2056|0;A=l+8|0;l=A;B=A;C=0;D=0;E=c[e>>2]|0;while(1){e=s+(C>>>3)|0;F=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(C&7)>>>30;e=C+2|0;G=p>>>0>e>>>0?e:p;e=s+(G>>>3)|0;H=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(G&7)>>>(a>>>0);e=G+g|0;G=(p>>>0>e>>>0?e:p)+m|0;e=(ca(b[n+(H<<1)>>1]|0,b[u>>1]|0)|0)>>10;I=e+(b[v>>1]|0)|0;if((I|0)<-16384){J=-16384}else{J=(I|0)>16383?16383:I}Ppb(t,H>>r);H=(ca(b[1386128+(F<<1)>>1]|0,b[y>>1]|0)|0)>>10;I=H+(b[z>>1]|0)|0;if((I|0)<-16384){K=-16384}else{K=(I|0)>16383?16383:I}Rpb(x,H,F);F=c[w>>2]|0;c[w>>2]=F+1;b[l+(F<<1)>>1]=K+J;F=c[w>>2]|0;c[w>>2]=F+1;b[l+(F<<1)>>1]=J-K;Spb(B+((c[w>>2]|0)-24<<1)|0,j,k);F=c[j>>2]|0;H=F>>11;if((H+32768|0)>>>0>65535>>>0){L=(F>>31^32767)&65535}else{L=H&65535}b[E>>1]=L;H=c[k>>2]|0;F=H>>11;if((F+32768|0)>>>0>65535>>>0){M=(H>>31^32767)&65535}else{M=F&65535}b[E+2>>1]=M;F=c[w>>2]|0;if((F|0)>1023){orc(A|0,B+(F-22<<1)|0,44)|0;c[w>>2]=22}F=D+1|0;if((F|0)<(c[o>>2]|0)){C=p>>>0>G>>>0?G:p;D=F;E=E+4|0}else{break}}}c[f>>2]=1;q=c[o>>2]|0;i=h;return q|0}function Rfa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;e=a+60|0;f=c[e>>2]|0;if((c[a+416>>2]|0)!=1){KIb(a,16,2453488,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=d;return h|0}b[f+2114>>1]=8;b[f+2170>>1]=2;c[f+2056>>2]=22;j=a+600|0;k=c[j>>2]|0;a:do{if((k|0)!=0){l=1<<k;m=l<<10;n=f+2188|0;o=l<<7;p=f+2172|0;q=l<<3;l=f+2180|0;r=0;while(1){if((r|0)>=2){break a}s=n+(r<<2)|0;c[s>>2]=pJb(m)|0;t=p+(r<<2)|0;c[t>>2]=pJb(o)|0;u=pJb(q)|0;c[l+(r<<2)>>2]=u;if((c[s>>2]|0)==0){break}if((c[t>>2]|0)==0|(u|0)==0){break}else{r=r+1|0}}r=c[e>>2]|0;mJb(r+2188|0);mJb(r+2172|0);mJb(r+2180|0);mJb(r+2192|0);mJb(r+2176|0);mJb(r+2184|0);h=-12;i=d;return h|0}}while(0);e=a+424|0;f=c[e>>2]|0;do{if((f|0)==0){c[e>>2]=320}else{k=(f|0)>32768;if(!((f&1|0)!=0|k)){break}if((f|0)==1){v=2}else{v=k?32768:f-1|0}KIb(a,24,2364088,(g=i,i=i+16|0,c[g>>2]=v,c[g+8>>2]=f,g)|0);i=g;c[e>>2]=v}}while(0);c[a+116>>2]=22;v=c[j>>2]|0;if((v|0)==0){h=0;i=d;return h|0}if(!(v>>>0>16>>>0)){h=0;i=d;return h|0}if((v|0)<0){w=0}else{w=(v|0)>16?16:v}KIb(a,24,2298920,(g=i,i=i+16|0,c[g>>2]=w,c[g+8>>2]=v,g)|0);i=g;c[j>>2]=w;h=0;i=d;return h|0}



function vNa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0;k=i;i=i+33848|0;l=k|0;m=c[f+60>>2]|0;n=m;o=(ca((c[f+120>>2]|0)*9|0,c[f+124>>2]|0)|0)+16384|0;p=d5a(f,g,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=k;return q|0}p=g+24|0;o=c[p>>2]|0;f=m+52|0;c[f>>2]=o;r=m+56|0;c[r>>2]=o;s=g+28|0;t=(c[p>>2]|0)+(c[s>>2]|0)|0;p=m+60|0;c[p>>2]=t;c[m+4>>2]=h;u=c[h+168>>2]|0;v=Erc(u,(u|0)<0|0?-1:0,1e8,0)|0;u=m+72|0;c[u>>2]=v;c[u+4>>2]=G;v=m+44|0;w=c[v>>2]|0;x=m+48|0;z=c[x>>2]|0;if((ca(z,w)|0)>0){A=m+28|0;B=m+32|0;C=c[m+456>>2]|0;D=0;while(1){E=C+(D<<2)|0;a:do{if((a[A]|0)==0){F=c[E>>2]|0;H=b[F+220>>1]|0;I=H&65535;J=b[F+222>>1]|0;if(!((H&65535)>>>0<(J&65535)>>>0)){break}H=b[F+216>>1]|0;K=h+32|0;L=c[B>>2]|0;M=H&65535;N=c[K>>2]|0;O=(ca(N,I)|0)+(ca(M,L)|0)|0;P=b[F+218>>1]|0;Q=(H&65535)>>>0<(P&65535)>>>0;H=J&65535;J=P&65535;P=M+1|0;R=(P>>>0>J>>>0?P:J)-M|0;P=0;S=I;I=(c[h>>2]|0)+O|0;O=N;N=L;while(1){if(Q){L=P;T=M;U=I;V=N;while(1){if((V|0)>0){W=0;X=U;while(1){Y=X+1|0;c[(c[F+(W*232|0)+212>>2]|0)+(L<<2)>>2]=(d[X]|0)-128;Z=W+1|0;_=c[B>>2]|0;if((Z|0)<(_|0)){W=Z;X=Y}else{$=Y;aa=_;break}}}else{$=U;aa=V}X=T+1|0;if((X|0)<(J|0)){L=L+1|0;T=X;U=$;V=aa}else{break}}ba=R+P|0;da=c[K>>2]|0;ea=aa}else{ba=P;da=O;ea=N}V=S+1|0;if((V|0)>=(H|0)){break a}P=ba;S=V;I=I+da|0;O=da;N=ea}}else{N=c[B>>2]|0;if((N|0)<=0){break}O=c[E>>2]|0;I=0;S=N;while(1){N=b[O+(I*232|0)+220>>1]|0;P=N&65535;H=b[O+(I*232|0)+222>>1]|0;if((N&65535)>>>0<(H&65535)>>>0){N=h+32+(I<<2)|0;K=b[O+(I*232|0)+216>>1]|0;R=c[N>>2]|0;J=K&65535;F=(ca(R,P)|0)+J|0;M=b[O+(I*232|0)+218>>1]|0;Q=(K&65535)>>>0<(M&65535)>>>0;K=H&65535;H=M&65535;M=J+1|0;V=(M>>>0>H>>>0?M:H)-J|0;M=P;P=(c[h+(I<<2)>>2]|0)+F|0;F=c[O+(I*232|0)+212>>2]|0;U=R;while(1){if(Q){R=J;T=F;L=P;while(1){c[T>>2]=(d[L]|0)-128;X=R+1|0;if((X|0)<(H|0)){R=X;T=T+4|0;L=L+1|0}else{break}}fa=F+(V<<2)|0;ga=c[N>>2]|0}else{fa=F;ga=U}L=M+1|0;if((L|0)<(K|0)){M=L;P=P+ga|0;F=fa;U=ga}else{break}}ha=c[B>>2]|0}else{ha=S}U=I+1|0;if((U|0)<(ha|0)){I=U;S=ha}else{break}}}}while(0);E=D+1|0;S=c[v>>2]|0;I=c[x>>2]|0;if((E|0)<(ca(I,S)|0)){D=E}else{ia=S;ja=I;break}}}else{ia=w;ja=z}if((ca(ja,ia)|0)>0){z=m+456|0;w=m+32|0;D=m+80|0;ha=0;B=c[w>>2]|0;ga=ia;ia=ja;while(1){if((B|0)>0){ja=(c[z>>2]|0)+(ha<<2)|0;fa=0;do{NNa((c[ja>>2]|0)+(fa*232|0)|0,D);fa=fa+1|0;ka=c[w>>2]|0;}while((fa|0)<(ka|0));la=ka;ma=c[v>>2]|0;na=c[x>>2]|0}else{la=B;ma=ga;na=ia}fa=ha+1|0;if((fa|0)<(ca(ma,na)|0)){ha=fa;B=la;ga=ma;ia=na}else{break}}oa=c[p>>2]|0;pa=c[r>>2]|0}else{oa=t;pa=o}if((oa-pa|0)<2){q=-1;i=k;return q|0}oa=pa;y=20479;a[oa]=y;y=y>>8;a[oa+1|0]=y;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;pa=m+32|0;if(((c[p>>2]|0)-oa|0)<(((c[pa>>2]|0)*3|0)+40|0)){q=-1;i=k;return q|0}o=oa;y=20991;a[o]=y;y=y>>8;a[o+1|0]=y;o=(c[r>>2]|0)+2|0;c[r>>2]=o;oa=o;y=he(((c[pa>>2]|0)*3|0)+38&65535|0)|0;a[oa]=y;y=y>>8;a[oa+1|0]=y;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;o=oa;y=0;a[o]=y;y=y>>8;a[o+1|0]=y;o=(c[r>>2]|0)+2|0;c[r>>2]=o;oa=o;y=je(c[m+8>>2]|0)|0;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;oa=(c[r>>2]|0)+4|0;c[r>>2]=oa;o=oa;y=je(c[m+12>>2]|0)|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=(c[r>>2]|0)+4|0;c[r>>2]=o;oa=o;y=0;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;oa=(c[r>>2]|0)+4|0;c[r>>2]=oa;o=oa;y=0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=(c[r>>2]|0)+4|0;c[r>>2]=o;oa=o;y=je(c[m+36>>2]|0)|0;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;oa=(c[r>>2]|0)+4|0;c[r>>2]=oa;o=oa;y=je(c[m+40>>2]|0)|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=(c[r>>2]|0)+4|0;c[r>>2]=o;oa=o;y=0;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;oa=(c[r>>2]|0)+4|0;c[r>>2]=oa;o=oa;y=0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=(c[r>>2]|0)+4|0;c[r>>2]=o;oa=o;y=he(c[pa>>2]&65535|0)|0;a[oa]=y;y=y>>8;a[oa+1|0]=y;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;if((c[pa>>2]|0)>0){o=m+20|0;t=m+24|0;na=0;ia=oa;while(1){a[ia]=7;ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;if((na|0)==0){a[ma]=1;ga=(c[r>>2]|0)+1|0;c[r>>2]=ga;qa=1;ra=ga}else{a[ma]=1<<c[o>>2];ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;qa=1<<c[t>>2]&255;ra=ma}a[ra]=qa;ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;ga=na+1|0;if((ga|0)<(c[pa>>2]|0)){na=ga;ia=ma}else{sa=ma;break}}}else{sa=oa}if(((c[p>>2]|0)-sa|0)<14){q=-1;i=k;return q|0}oa=sa;y=21247;a[oa]=y;y=y>>8;a[oa+1|0]=y;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;sa=oa;y=3072;a[sa]=y;y=y>>8;a[sa+1|0]=y;sa=(c[r>>2]|0)+2|0;c[r>>2]=sa;a[sa]=0;sa=(c[r>>2]|0)+1|0;c[r>>2]=sa;a[sa]=0;sa=(c[r>>2]|0)+1|0;c[r>>2]=sa;oa=sa;y=256;a[oa]=y;y=y>>8;a[oa+1|0]=y;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;sa=m;a[oa]=(c[(c[sa>>2]|0)+140>>2]|0)==5?2:0;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;ia=m+80|0;a[oa]=(c[ia>>2]|0)+255;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;a[oa]=(a[m+88|0]|0)-2;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;a[oa]=(a[m+89|0]|0)-2;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;a[oa]=0;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;na=m+90|0;a[oa]=(a[na]|0)==1|0;oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;qa=m+452|0;ra=(c[ia>>2]|0)-1|0;if((a[qa]|0)==0){ta=(ra*3|0)+4|0}else{ta=(ra*6|0)+5|0}if(((c[p>>2]|0)-oa|0)<(ta+2|0)){q=-1;i=k;return q|0}ra=oa;y=23807;a[ra]=y;y=y>>8;a[ra+1|0]=y;ra=(c[r>>2]|0)+2|0;c[r>>2]=ra;oa=ra;y=he(ta&65535|0)|0;a[oa]=y;y=y>>8;a[oa+1|0]=y;oa=(c[r>>2]|0)+2|0;c[r>>2]=oa;ta=m+453|0;a[oa]=a[ta]<<5|a[qa];oa=(c[r>>2]|0)+1|0;c[r>>2]=oa;ra=(((c[ia>>2]|0)*3|0)-2|0)>0;do{if((a[qa]|0)==0){if(ra){ua=0;va=oa}else{wa=oa;break}while(1){a[va]=a[n+164+ua|0]<<3;t=(c[r>>2]|0)+1|0;c[r>>2]=t;o=ua+1|0;if((o|0)<(((c[ia>>2]|0)*3|0)-2|0)){ua=o;va=t}else{wa=t;break}}}else{if(ra){xa=0;ya=oa}else{wa=oa;break}while(1){t=ya;y=he(d[n+164+xa|0]<<11|b[n+260+(xa<<1)>>1]|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;t=(c[r>>2]|0)+2|0;c[r>>2]=t;o=xa+1|0;if((o|0)<(((c[ia>>2]|0)*3|0)-2|0)){xa=o;ya=t}else{wa=t;break}}}}while(0);b:do{if((ca(c[x>>2]|0,c[v>>2]|0)|0)>0){ya=m+456|0;xa=l+33808|0;oa=l+33846|0;ra=l+33845|0;va=m+64|0;ua=0;qa=wa;c:while(1){if(((c[p>>2]|0)-qa|0)<12){q=-1;za=299;break}t=qa;y=-28417;a[t]=y;y=y>>8;a[t+1|0]=y;t=(c[r>>2]|0)+2|0;c[r>>2]=t;o=t;y=2560;a[o]=y;y=y>>8;a[o+1|0]=y;o=(c[r>>2]|0)+2|0;c[r>>2]=o;t=o;y=he(ua&65535|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;t=(c[r>>2]|0)+2|0;c[r>>2]=t;o=t;y=0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;ma=(c[r>>2]|0)+4|0;c[r>>2]=ma;a[ma]=0;ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;a[ma]=1;ma=(c[r>>2]|0)+1|0;c[r>>2]=ma;if((t|0)==0){q=-1;za=299;break}if(((c[p>>2]|0)-ma|0)<2){q=-1;za=299;break}ga=ma;y=-27649;a[ga]=y;y=y>>8;a[ga+1|0]=y;c[r>>2]=(c[r>>2]|0)+2;ga=c[ya>>2]|0;d:do{if((c[pa>>2]|0)>0){ma=0;la=ga;while(1){B=c[la+(ua<<2)>>2]|0;KIb(c[sa>>2]|0,48,2362264,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;ha=B+(ma*232|0)+212|0;ka=YNa(B+(ma*232|0)+4|0,c[ha>>2]|0)|0;if((ka|0)!=0){q=ka;za=299;break c}KIb(c[sa>>2]|0,48,2297520,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;ka=c[ia>>2]|0;if((ka|0)>0){w=B+(ma*232|0)|0;D=B+(ma*232|0)+218|0;z=B+(ma*232|0)+216|0;B=0;fa=ka;while(1){ka=c[w>>2]|0;ja=ka+(B*20|0)|0;h=a[ja]|0;if(h<<24>>24==0){Ba=fa}else{ea=ka+(B*20|0)+16|0;ka=(B|0)>0|0;da=(B|0)==0;ba=B-1|0;aa=0;$=h;while(1){h=c[ea>>2]|0;A=c[h+(aa*24|0)+20>>2]|0;if((aa|0)==0){Ca=0}else{C=c[w>>2]|0;Ca=(e[C+(ba*20|0)+8>>1]|0)-(e[C+(ba*20|0)+6>>1]|0)|0}C=h+(aa*24|0)+4|0;I=b[C>>1]|0;S=I&65535;E=h+(aa*24|0)+10|0;O=b[E>>1]|0;U=O&65535;F=(1<<U)+S>>U<<U;U=h+(aa*24|0)+6|0;P=b[U>>1]|0;M=P&65535;K=Ca-S+((F|0)>(M|0)?M:F)|0;F=h+(aa*24|0)|0;M=b[F>>1]|0;S=h+(aa*24|0)+2|0;N=b[S>>1]|0;do{if(M<<16>>16==N<<16>>16|I<<16>>16==P<<16>>16){Da=$}else{V=aa+ka|0;H=A+2|0;J=b[H>>1]|0;if(J<<16>>16==0){Da=$;break}Q=da|(aa|0)==1;L=h+(aa*24|0)+8|0;T=A|0;R=A+12|0;X=h+(aa*24|0)+12|0;W=0;_=0;Y=Ca;Z=K;Ea=M;Fa=N;Ga=O;Ha=P;Ia=I;Ja=J;while(1){if(Q){Ka=0}else{J=c[w>>2]|0;Ka=(e[J+(ba*20|0)+4>>1]|0)-(e[J+(ba*20|0)+2>>1]|0)|0}J=Ea&65535;La=e[L>>1]|0;Ma=(1<<La)+J>>La<<La;La=Fa&65535;if((b[T>>1]|0)==0){Na=_;Oa=Ea;Pa=Fa;Qa=Ga;Ra=Ha;Sa=Ia;Ta=Ja}else{Ua=Z-Y|0;Va=Ua+2|0;Wa=(Va|0)>0;Xa=(Ua|0)>0;Ya=(Y|0)<(Z|0);Za=0;_a=_;$a=Ka;ab=Ka-J+((Ma|0)>(La|0)?La:Ma)|0;while(1){do{if((a[na]|0)==1){if(!Ya){break}Ma=($a|0)<(ab|0);La=Y;do{if(Ma){J=ca((e[D>>1]|0)-(e[z>>1]|0)|0,La)|0;bb=c[ha>>2]|0;cb=$a;db=l+(La-Y<<8)|0;while(1){c[db>>2]=c[bb+(cb+J<<2)>>2]<<6;eb=cb+1|0;if((eb|0)<(ab|0)){cb=eb;db=db+4|0}else{break}}}La=La+1|0;}while((La|0)<(Z|0))}else{if(!Ya){break}La=($a|0)<(ab|0);Ma=Y;do{if(La){db=ca((e[D>>1]|0)-(e[z>>1]|0)|0,Ma)|0;cb=c[ha>>2]|0;J=$a;bb=l+(Ma-Y<<8)|0;while(1){eb=c[cb+(J+db<<2)>>2]|0;c[bb>>2]=eb;fb=1073741824/(c[X>>2]|0)|0;gb=Erc(fb,(fb|0)<0|0?-1:0,eb,(eb|0)<0|0?-1:0)|0;c[bb>>2]=gb>>>9|G<<23;gb=J+1|0;if((gb|0)<(ab|0)){J=gb;bb=bb+4|0}else{break}}}Ma=Ma+1|0;}while((Ma|0)<(Z|0))}}while(0);Ma=c[R>>2]|0;La=ab-$a|0;if(Wa){bb=(La<<2)+8|0;J=0;do{mrc(l+16384+(J*264|0)|0,0,bb|0)|0;J=J+1|0;}while((J|0)<(Va|0))}J=(La|0)>0;do{if(Xa&J){bb=0;db=0;while(1){cb=bb+1|0;gb=0;hb=db;do{eb=l+(bb<<8)+(gb<<2)|0;fb=c[eb>>2]|0;gb=gb+1|0;if((fb|0)<0){ib=l+16384+(cb*264|0)+(gb<<2)|0;c[ib>>2]=c[ib>>2]|32768;ib=-fb|0;c[eb>>2]=ib;jb=ib}else{jb=fb}hb=(hb|0)>(jb|0)?hb:jb;}while((gb|0)<(La|0));if((cb|0)<(Ua|0)){bb=cb;db=hb}else{break}}if((hb|0)==0){za=94;break}db=hb>>>0>65535>>>0;bb=db?hb>>>16:hb;gb=db?16:0;if((bb&65280|0)==0){kb=gb;lb=bb}else{kb=gb|8;lb=bb>>>8}bb=kb+251+(d[1359664+lb|0]|0)|0;a[Ma+(_a*9816|0)+2|0]=bb;gb=bb&255;xUa(xa,Ma+(_a*9816|0)+10|0);if((gb|0)==0){mb=0}else{nb=2;ob=0;pb=gb-1|0;qb=0;rb=0;za=98}}else{za=94}}while(0);if((za|0)==94){za=0;a[Ma+(_a*9816|0)+2|0]=0;xUa(xa,Ma+(_a*9816|0)+10|0);nb=2;ob=0;pb=0;qb=0;rb=0;za=98}if((za|0)==98){while(1){za=0;do{if((nb|0)==0){gb=1<<pb+6;if(!Xa){sb=0;break}bb=(pb|0)>0;db=0;fb=0;while(1){ib=db+4|0;if(J){eb=0;tb=fb;while(1){ub=eb+1|0;if(bb){vb=db;wb=tb;while(1){xb=vb+1|0;yb=l+16384+(xb*264|0)+(ub<<2)|0;zb=c[yb>>2]|0;Ab=zb&255;if((zb&8192|0)!=0|(Ab|0)==0){Bb=wb}else{zb=l+(vb<<8)+(eb<<2)|0;Cb=(c[zb>>2]&gb|0)!=0;yUa(xa,(d[7696880+(Ab<<2)+V|0]|0)+(l+33828)|0,Cb&1);if(Cb){Cb=c[yb>>2]|0;Ab=Cb>>>8&15;Db=Cb&15;yUa(xa,(d[7697904+(Db<<4)+Ab|0]|0)+(l+33828)|0,d[7696624+(Db<<4)+Ab|0]^Cb>>15);Cb=(c[5790800+((c[zb>>2]>>pb&127)<<2)>>2]|0)+wb|0;KNa(l,eb,vb,c[yb>>2]>>15);Eb=Cb}else{Eb=wb}c[yb>>2]=c[yb>>2]|4096;Bb=Eb}if((xb|0)<(Ua|0)&(xb|0)<(ib|0)){vb=xb;wb=Bb}else{Fb=Bb;break}}}else{wb=db;vb=tb;while(1){xb=wb+1|0;yb=l+16384+(xb*264|0)+(ub<<2)|0;Cb=c[yb>>2]|0;zb=Cb&255;if((Cb&8192|0)!=0|(zb|0)==0){Gb=vb}else{Cb=l+(wb<<8)+(eb<<2)|0;Ab=(c[Cb>>2]&gb|0)!=0;yUa(xa,(d[7696880+(zb<<2)+V|0]|0)+(l+33828)|0,Ab&1);if(Ab){Ab=c[yb>>2]|0;zb=Ab>>>8&15;Db=Ab&15;yUa(xa,(d[7697904+(Db<<4)+zb|0]|0)+(l+33828)|0,d[7696624+(Db<<4)+zb|0]^Ab>>15);Ab=(c[5790288+((c[Cb>>2]&127)<<2)>>2]|0)+vb|0;KNa(l,eb,wb,c[yb>>2]>>15);Hb=Ab}else{Hb=vb}c[yb>>2]=c[yb>>2]|4096;Gb=Hb}if((xb|0)<(Ua|0)&(xb|0)<(ib|0)){wb=xb;vb=Gb}else{Fb=Gb;break}}}if((ub|0)<(La|0)){eb=ub;tb=Fb}else{Ib=Fb;break}}}else{Ib=fb}if((ib|0)<(Ua|0)){db=ib;fb=Ib}else{sb=Ib;break}}}else if((nb|0)==1){fb=1<<pb+6;if(!Xa){sb=0;break}db=(pb|0)>0;gb=0;bb=0;while(1){cb=gb+4|0;if(J){tb=0;eb=bb;while(1){vb=tb+1|0;if(db){wb=gb;xb=eb;while(1){yb=wb+1|0;Ab=l+16384+(yb*264|0)+(vb<<2)|0;Cb=c[Ab>>2]|0;if((Cb&12288|0)==8192){zb=c[l+(wb<<8)+(tb<<2)>>2]|0;Db=(c[5791824+((zb>>pb&127)<<2)>>2]|0)+xb|0;yUa(xa,(d[((Cb&255|0)!=0)+(682088+((Cb>>>14&1)<<1))|0]|0)+(l+33828)|0,(zb&fb|0)!=0|0);c[Ab>>2]=c[Ab>>2]|16384;Jb=Db}else{Jb=xb}if((yb|0)<(Ua|0)&(yb|0)<(cb|0)){wb=yb;xb=Jb}else{Kb=Jb;break}}}else{xb=gb;wb=eb;while(1){ub=xb+1|0;yb=l+16384+(ub*264|0)+(vb<<2)|0;Db=c[yb>>2]|0;if((Db&12288|0)==8192){Ab=c[l+(xb<<8)+(tb<<2)>>2]|0;zb=(c[5791312+((Ab&127)<<2)>>2]|0)+wb|0;yUa(xa,(d[((Db&255|0)!=0)+(682088+((Db>>>14&1)<<1))|0]|0)+(l+33828)|0,(Ab&fb|0)!=0|0);c[yb>>2]=c[yb>>2]|16384;Lb=zb}else{Lb=wb}if((ub|0)<(Ua|0)&(ub|0)<(cb|0)){xb=ub;wb=Lb}else{Kb=Lb;break}}}if((vb|0)<(La|0)){tb=vb;eb=Kb}else{Mb=Kb;break}}}else{Mb=bb}if((cb|0)<(Ua|0)){gb=cb;bb=Mb}else{sb=Mb;break}}}else if((nb|0)==2){bb=1<<pb+6;if(!Xa){sb=0;break}gb=(pb|0)>0;fb=0;db=0;while(1){if(J){eb=fb|3;tb=(eb|0)<(Ua|0);ib=fb|1;wb=fb|2;xb=fb+4|0;ub=0;zb=db;while(1){yb=ub+1|0;do{if(tb){if((c[l+16384+(ib*264|0)+(yb<<2)>>2]&12543|0)!=0){Nb=fb;Ob=zb;za=151;break}if((c[l+16384+(wb*264|0)+(yb<<2)>>2]&12543|0)!=0){Nb=fb;Ob=zb;za=151;break}if((c[l+16384+(eb*264|0)+(yb<<2)>>2]&12543|0)!=0){Nb=fb;Ob=zb;za=151;break}if((c[l+16384+(xb*264|0)+(yb<<2)>>2]&12543|0)==0){Pb=0}else{Nb=fb;Ob=zb;za=151;break}while(1){if((Pb|0)>=4){break}if((c[l+(Pb+fb<<8)+(ub<<2)>>2]&bb|0)==0){Pb=Pb+1|0}else{break}}yUa(xa,oa,(Pb|0)!=4|0);if((Pb|0)==4){Qb=zb;break}yUa(xa,ra,Pb>>1);yUa(xa,ra,Pb&1);Ab=Pb+fb|0;if((Ab|0)<(xb|0)){Rb=Ab;Sb=zb}else{Qb=zb;break}while(1){Db=Rb+1|0;Cb=l+16384+(Db*264|0)+(yb<<2)|0;Tb=c[Cb>>2]|0;do{if((Tb&12288|0)==0){if((Rb|0)>(Ab|0)){Ub=l+(Rb<<8)+(ub<<2)|0;yUa(xa,(d[7696880+((Tb&255)<<2)+V|0]|0)+(l+33828)|0,(c[Ub>>2]&bb|0)!=0|0);Vb=Ub}else{Vb=l+(Rb<<8)+(ub<<2)|0}Ub=c[Vb>>2]|0;if((Ub&bb|0)==0){Wb=Sb;break}Xb=c[Cb>>2]|0;Yb=Xb>>>8&15;Zb=Xb&15;if(gb){_b=5790800+((Ub>>pb&127)<<2)|0}else{_b=5790288+((Ub&127)<<2)|0}Ub=(c[_b>>2]|0)+Sb|0;yUa(xa,(d[7697904+(Zb<<4)+Yb|0]|0)+(l+33828)|0,d[7696624+(Zb<<4)+Yb|0]^Xb>>15);KNa(l,ub,Rb,c[Cb>>2]>>15);Wb=Ub}else{Wb=Sb}}while(0);c[Cb>>2]=c[Cb>>2]&-4097;if((Db|0)<(xb|0)){Rb=Db;Sb=Wb}else{Qb=Wb;break}}}else{Nb=fb;Ob=zb;za=151}}while(0);if((za|0)==151){while(1){za=0;vb=Nb+1|0;Ab=l+16384+(vb*264|0)+(yb<<2)|0;Tb=c[Ab>>2]|0;do{if((Tb&12288|0)==0){Ub=l+(Nb<<8)+(ub<<2)|0;yUa(xa,(d[7696880+((Tb&255)<<2)+V|0]|0)+(l+33828)|0,(c[Ub>>2]&bb|0)!=0|0);Xb=c[Ub>>2]|0;if((Xb&bb|0)==0){$b=Ob;break}Ub=c[Ab>>2]|0;Yb=Ub>>>8&15;Zb=Ub&15;if(gb){ac=5790800+((Xb>>pb&127)<<2)|0}else{ac=5790288+((Xb&127)<<2)|0}Xb=(c[ac>>2]|0)+Ob|0;yUa(xa,(d[7697904+(Zb<<4)+Yb|0]|0)+(l+33828)|0,d[7696624+(Zb<<4)+Yb|0]^Ub>>15);KNa(l,ub,Nb,c[Ab>>2]>>15);$b=Xb}else{$b=Ob}}while(0);c[Ab>>2]=c[Ab>>2]&-4097;if((vb|0)<(xb|0)&(vb|0)<(Ua|0)){Nb=vb;Ob=$b;za=151}else{Qb=$b;break}}}if((yb|0)<(La|0)){ub=yb;zb=Qb}else{bc=xb;cc=Qb;break}}}else{bc=fb+4|0;cc=db}if((bc|0)<(Ua|0)){fb=bc;db=cc}else{sb=cc;break}}}else{sb=0}}while(0);b[Ma+(_a*9816|0)+8208+(ob<<4)>>1]=(zUa(xa)|0)+3;db=yrc(sb|0,((sb|0)<0|0?-1:0)|0,pb<<1|0)|0;fb=wrc(db,G,rb,qb)|0;db=G;gb=Ma+(_a*9816|0)+8208+(ob<<4)+8|0;c[gb>>2]=fb;c[gb+4>>2]=db;gb=nb+1|0;bb=(gb|0)==3;xb=(bb<<31>>31)+pb|0;zb=ob+1|0;if((xb|0)>-1){nb=bb?0:gb;ob=zb;pb=xb;qb=db;rb=fb;za=98}else{mb=zb;break}}}La=mb&255;a[Ma+(_a*9816|0)|0]=La;a[Ma+(_a*9816|0)+1|0]=La;b[Ma+(_a*9816|0)+8208+(mb-1<<4)>>1]=AUa(xa)|0;La=(1<<e[L>>1])+ab|0;dc=b[S>>1]|0;ec=b[F>>1]|0;J=(dc&65535)-(ec&65535)+Ka|0;zb=Za+1|0;fc=_a+1|0;if((zb|0)<(e[T>>1]|0)){Za=zb;_a=fc;$a=ab;ab=(La|0)>(J|0)?J:La}else{break}}Na=fc;Oa=ec;Pa=dc;Qa=b[E>>1]|0;Ra=b[U>>1]|0;Sa=b[C>>1]|0;Ta=b[H>>1]|0}ab=(1<<(Qa&65535))+Z|0;$a=(Ra&65535)-(Sa&65535)+Ca|0;_a=W+1|0;if((_a|0)<(Ta&65535|0)){W=_a;_=Na;Y=Z;Z=(ab|0)>($a|0)?$a:ab;Ea=Oa;Fa=Pa;Ga=Qa;Ha=Ra;Ia=Sa;Ja=Ta}else{break}}Da=a[ja]|0}}while(0);C=aa+1|0;if((C|0)<(Da&255|0)){aa=C;$=Da}else{break}}Ba=c[ia>>2]|0}$=B+1|0;if(($|0)<(Ba|0)){B=$;fa=Ba}else{break}}}KIb(c[sa>>2]|0,48,2246680,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;fa=ma+1|0;if((fa|0)>=(c[pa>>2]|0)){break d}ma=fa;la=c[ya>>2]|0}}}while(0);KIb(c[sa>>2]|0,48,2204960,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;la=c[pa>>2]|0;if((la|0)>0){ma=ga+(ua<<2)|0;fa=0;B=c[ia>>2]|0;ha=la;while(1){if((B|0)>0){la=(c[ma>>2]|0)+(fa*232|0)|0;z=0;D=B;w=B;while(1){$=D-1|0;aa=c[la>>2]|0;ja=aa+(z*20|0)+10|0;ba=b[ja>>1]|0;da=aa+(z*20|0)+12|0;ka=b[da>>1]|0;if((ca(ka&65535,ba&65535)|0)==0){gc=w}else{ea=aa+(z*20|0)|0;C=(z|0)>0|0;U=aa+(z*20|0)+16|0;aa=a[ea]|0;E=0;F=aa;S=ba;ba=ka;ka=aa;while(1){if(F<<24>>24==0){hc=0;ic=S;jc=ba;kc=ka}else{aa=0;I=ka;while(1){P=aa+C|0;O=c[U>>2]|0;N=c[O+(aa*24|0)+20>>2]|0;M=N+(E*24|0)+2|0;K=N+(E*24|0)|0;if((ca(e[K>>1]|0,e[M>>1]|0)|0)==0){lc=I}else{h=N+(E*24|0)+12|0;N=O+(aa*24|0)+12|0;O=0;do{A=c[h>>2]|0;Ja=c[u>>2]|0;Ia=c[u+4>>2]|0;Ha=a[A+(O*9816|0)|0]|0;if(Ha<<24>>24==0){mc=0}else{Ga=c[N>>2]|0;Fa=c[1515408+(((a[na]|0)==1|0)*160|0)+(P*40|0)+($<<2)>>2]|0;Ea=Erc(Fa,(Fa|0)<0|0?-1:0,Ga,(Ga|0)<0|0?-1:0)|0;Ga=Ea>>>15|G<<17;Ea=Ga;Fa=(Ga|0)<0|0?-1:0;Ga=Ha&255;Ha=0;Z=0;do{Y=e[A+(O*9816|0)+8208+(Z<<4)>>1]|0;if((Ha|0)==0){nc=0;oc=0;pc=Y}else{_=Ha-1|0;W=A+(O*9816|0)+8208+(_<<4)+8|0;nc=c[W+4>>2]|0;oc=c[W>>2]|0;pc=Y-(e[A+(O*9816|0)+8208+(_<<4)>>1]|0)|0}_=A+(O*9816|0)+8208+(Z<<4)+8|0;Y=xrc(c[_>>2]|0,c[_+4>>2]|0,oc,nc)|0;_=Erc(Y,G,Ea,Fa)|0;Y=G;W=Erc(_>>>13|Y<<19,Y>>13|((Y|0)<0|0?-1:0)<<19,Ea,Fa)|0;Y=G;_=Erc(pc,(pc|0)<0|0?-1:0,Ja,Ia)|0;H=G;Z=Z+1|0;Ha=(Y|0)<(H|0)|(Y|0)==(H|0)&W>>>0<_>>>0?Ha:Z;}while((Z|0)<(Ga|0));mc=Ha&255}a[A+(O*9816|0)+1|0]=mc;O=O+1|0;}while((O|0)<(ca(e[K>>1]|0,e[M>>1]|0)|0));lc=a[ea]|0}M=aa+1|0;if((M|0)<(lc&255|0)){aa=M;I=lc}else{break}}hc=lc;ic=b[ja>>1]|0;jc=b[da>>1]|0;kc=lc}I=E+1|0;if((I|0)<(ca(ic&65535,jc&65535)|0)){E=I;F=hc;S=ic;ba=jc;ka=kc}else{break}}gc=c[ia>>2]|0}ka=z+1|0;if((ka|0)<(gc|0)){z=ka;D=$;w=gc}else{break}}qc=gc;rc=c[pa>>2]|0}else{qc=B;rc=ha}w=fa+1|0;if((w|0)<(rc|0)){fa=w;B=qc;ha=rc}else{break}}}KIb(c[sa>>2]|0,48,2145424,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;ha=c[ia>>2]|0;if((ha|0)>0){B=0;fa=c[pa>>2]|0;ma=ha;while(1){if((fa|0)>0){ha=(B|0)==0?0:(B*3|0)-2|0;ga=0;w=fa;while(1){D=c[(c[(c[ya>>2]|0)+(ua<<2)>>2]|0)+(ga*232|0)>>2]|0;z=D+(B*20|0)+10|0;la=D+(B*20|0)+12|0;if((ca(e[la>>1]|0,e[z>>1]|0)|0)==0){sc=w}else{ka=D+(B*20|0)|0;ba=D+(B*20|0)+16|0;D=0;do{S=a[ta]|0;a[c[r>>2]|0]=0;c[va>>2]=0;F=a[ka]|0;e:do{if(F<<24>>24==0){tc=1}else{E=c[ba>>2]|0;da=F&255;ja=0;while(1){if((e[E+(ja*24|0)>>1]|0)>>>0<(e[E+(ja*24|0)+2>>1]|0)>>>0){if((e[E+(ja*24|0)+4>>1]|0)>>>0<(e[E+(ja*24|0)+6>>1]|0)>>>0){tc=0;break e}}ea=ja+1|0;if((ea|0)<(da|0)){ja=ea}else{tc=1;break}}}}while(0);c[va>>2]=1;F=c[r>>2]|0;a[F]=(tc&1)<<7^-128|a[F];do{if(tc){if((c[va>>2]|0)==0){break}c[va>>2]=0;c[r>>2]=(c[r>>2]|0)+1}else{F=a[ka]|0;if(F<<24>>24==0){uc=0}else{ja=S-1&255;da=0;E=F;while(1){F=c[ba>>2]|0;ea=c[F+(da*24|0)+20>>2]|0;U=b[ea+(D*24|0)>>1]|0;C=U&65535;do{if((b[F+(da*24|0)>>1]|0)==(b[F+(da*24|0)+2>>1]|0)){vc=E}else{if((b[F+(da*24|0)+4>>1]|0)==(b[F+(da*24|0)+6>>1]|0)){vc=E;break}I=ea+(D*24|0)+2|0;aa=b[I>>1]|0;do{if(!(aa<<16>>16==0)){M=U<<16>>16==0;K=ea+(D*24|0)+12|0;O=ea+(D*24|0)+8|0;P=da+ha+(n+164)|0;N=ea+(D*24|0)+4|0;h=C>>>0>1>>>0?C:1;Ga=0;Z=0;Ia=aa;while(1){if(M){wc=Ga;xc=Ia}else{Ja=ca(Z,C)|0;Fa=Ga;Ea=0;while(1){_=Ea+Ja|0;a[(c[O>>2]|0)+(Fa<<3)|0]=(a[(c[K>>2]|0)+(_*9816|0)+1|0]|0)==0|0;W=c[O>>2]|0;H=W+(Fa<<3)+4|0;Y=c[H>>2]|0;f:do{if((Y|0)!=0){T=W+(Fa<<3)|0;L=H;V=Y;do{R=V|0;X=a[T|0]|0;if(!((d[R]|0)>>>0>(X&255)>>>0)){break f}a[R]=X;T=c[L>>2]|0;L=T+4|0;V=c[L>>2]|0;}while((V|0)!=0)}}while(0);a[(c[N>>2]|0)+(Fa<<3)|0]=(ja+(a[P]|0)&255)-(a[(c[K>>2]|0)+(_*9816|0)+2|0]|0);Y=c[N>>2]|0;H=Y+(Fa<<3)+4|0;W=c[H>>2]|0;g:do{if((W|0)!=0){V=Y+(Fa<<3)|0;L=H;T=W;do{X=T|0;R=a[V|0]|0;if(!((d[X]|0)>>>0>(R&255)>>>0)){break g}a[X]=R;V=c[L>>2]|0;L=V+4|0;T=c[L>>2]|0;}while((T|0)!=0)}}while(0);W=Ea+1|0;if((W|0)<(C|0)){Fa=Fa+1|0;Ea=W}else{break}}wc=Ga+h|0;xc=b[I>>1]|0}Ea=Z+1|0;if((Ea|0)<(xc&65535|0)){Ga=wc;Z=Ea;Ia=xc}else{break}}if(xc<<16>>16==0){break}else{yc=0;zc=0;Ac=xc}while(1){if(M){Bc=yc;Cc=Ac}else{Ia=ca(zc,C)|0;Z=yc;Ga=0;do{h=c[K>>2]|0;P=Ga+Ia|0;if(((c[p>>2]|0)-(c[r>>2]|0)|0)<20){q=-1;za=299;break c}xNa(n,(c[O>>2]|0)+(Z<<3)|0,1);Ma=h+(P*9816|0)+1|0;h:do{if((a[Ma]|0)!=0){xNa(n,(c[N>>2]|0)+(Z<<3)|0,100);Ea=a[Ma]|0;Fa=Ea&255;do{if((Fa|0)==1){Ja=c[va>>2]|0;if((Ja|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;H=W+1|0;c[r>>2]=H;a[H]=0;Dc=c[va>>2]|0}else{Dc=Ja}c[va>>2]=Dc+1}else if((Fa|0)==2){Ja=c[va>>2]|0;if((Ja|0)==8){H=c[r>>2]|0;c[va>>2]=(a[H]|0)==-1;W=H+1|0;c[r>>2]=W;a[W]=0;Ec=c[va>>2]|0}else{Ec=Ja}c[va>>2]=Ec+1;Ja=c[r>>2]|0;a[Ja]=d[Ja]|1<<7-Ec;Ja=c[va>>2]|0;if((Ja|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;H=W+1|0;c[r>>2]=H;a[H]=0;Fc=c[va>>2]|0}else{Fc=Ja}c[va>>2]=Fc+1}else{if((Ea&255)>>>0<6>>>0){Ja=Fa-3|0;H=c[va>>2]|0;if((H|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;Y=W+1|0;c[r>>2]=Y;a[Y]=0;Gc=c[va>>2]|0}else{Gc=H}c[va>>2]=Gc+1;H=c[r>>2]|0;a[H]=d[H]|1<<7-Gc;H=c[va>>2]|0;if((H|0)==8){Y=c[r>>2]|0;c[va>>2]=(a[Y]|0)==-1;W=Y+1|0;c[r>>2]=W;a[W]=0;Hc=c[va>>2]|0}else{Hc=H}c[va>>2]=Hc+1;H=c[r>>2]|0;a[H]=d[H]|1<<7-Hc;H=c[va>>2]|0;if((H|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;Y=W+1|0;c[r>>2]=Y;a[Y]=0;Ic=c[va>>2]|0}else{Ic=H}c[va>>2]=Ic+1;H=c[r>>2]|0;a[H]=d[H]|(Ja>>>1&1)<<7-Ic;H=c[va>>2]|0;if((H|0)==8){Y=c[r>>2]|0;c[va>>2]=(a[Y]|0)==-1;W=Y+1|0;c[r>>2]=W;a[W]=0;Jc=c[va>>2]|0}else{Jc=H}c[va>>2]=Jc+1;H=c[r>>2]|0;a[H]=d[H]|(Ja&1)<<7-Jc;break}else{if((Ea&255)>>>0<37>>>0){Ja=Fa-6|480;H=9;do{H=H-1|0;W=c[va>>2]|0;if((W|0)==8){Y=c[r>>2]|0;c[va>>2]=(a[Y]|0)==-1;_=Y+1|0;c[r>>2]=_;a[_]=0;Kc=c[va>>2]|0}else{Kc=W}c[va>>2]=Kc+1;W=c[r>>2]|0;a[W]=d[W]|(Ja>>>(H>>>0)&1)<<7-Kc;}while((H|0)>0)}else{H=Fa-37|65408;Ja=16;do{Ja=Ja-1|0;yb=c[va>>2]|0;if((yb|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;_=W+1|0;c[r>>2]=_;a[_]=0;Lc=c[va>>2]|0}else{Lc=yb}c[va>>2]=Lc+1;yb=c[r>>2]|0;a[yb]=d[yb]|(H>>>(Ja>>>0)&1)<<7-Lc;}while((Ja|0)>0)}}}}while(0);Fa=d[Ma]|0;Ea=e[h+(P*9816|0)+8208+(Fa-1<<4)>>1]|0;Ja=(Ea&65280|0)==0;H=(Ja?0:8)+(d[1359664+(Ja?Ea:Ea>>>8)|0]|0)|0;Ja=H-(d[1359664+Fa|0]|0)|0;Fa=Ja-2|0;yb=(Fa|0)<0;_=yb?2-Ja|0:0;Ja=yb?0:Fa;if((Ja|0)>0){Fa=Ja;do{Fa=Fa-1|0;Ja=c[va>>2]|0;if((Ja|0)==8){yb=c[r>>2]|0;c[va>>2]=(a[yb]|0)==-1;W=yb+1|0;c[r>>2]=W;a[W]=0;Mc=c[va>>2]|0}else{Mc=Ja}c[va>>2]=Mc+1;Ja=c[r>>2]|0;a[Ja]=d[Ja]|1<<7-Mc;}while((Fa|0)>0)}Fa=c[va>>2]|0;if((Fa|0)==8){Ja=c[r>>2]|0;c[va>>2]=(a[Ja]|0)==-1;W=Ja+1|0;c[r>>2]=W;a[W]=0;Nc=c[va>>2]|0}else{Nc=Fa}Fa=Nc+1|0;c[va>>2]=Fa;W=H+1+_|0;if((W|0)>0){Oc=W;Pc=Fa}else{break}while(1){Fa=Oc-1|0;if((Pc|0)==8){W=c[r>>2]|0;c[va>>2]=(a[W]|0)==-1;Ja=W+1|0;c[r>>2]=Ja;a[Ja]=0;Qc=c[va>>2]|0}else{Qc=Pc}c[va>>2]=Qc+1;Ja=c[r>>2]|0;a[Ja]=d[Ja]|(Ea>>>(Fa>>>0)&1)<<7-Qc;if((Fa|0)<=0){break h}Oc=Fa;Pc=c[va>>2]|0}}}while(0);Ga=Ga+1|0;Z=Z+1|0;}while((Ga|0)<(C|0));Bc=Z;Cc=b[I>>1]|0}Ga=zc+1|0;if((Ga|0)<(Cc&65535|0)){yc=Bc;zc=Ga;Ac=Cc}else{break}}}}while(0);vc=a[ka]|0}}while(0);C=da+1|0;if((C|0)<(vc&255|0)){da=C;E=vc}else{uc=vc;break}}}if((c[va>>2]|0)==0){Rc=uc}else{c[va>>2]=0;c[r>>2]=(c[r>>2]|0)+1;Rc=a[ka]|0}if(Rc<<24>>24==0){break}else{Sc=0;Tc=Rc}while(1){E=c[(c[ba>>2]|0)+(Sc*24|0)+20>>2]|0;da=b[E+(D*24|0)>>1]|0;ja=da&65535;C=E+(D*24|0)+2|0;ea=b[C>>1]|0;if(ea<<16>>16==0){Uc=Tc}else{U=da<<16>>16==0;da=E+(D*24|0)+12|0;E=0;F=ea;while(1){if(U){Vc=F}else{ea=ca(E,ja)|0;A=0;do{Ha=c[da>>2]|0;I=A+ea|0;aa=a[Ha+(I*9816|0)+1|0]|0;if(!(aa<<24>>24==0)){N=c[r>>2]|0;O=e[Ha+(I*9816|0)+8208+((aa&255)-1<<4)>>1]|0;if(((c[p>>2]|0)-N|0)<(O|0)){q=-1;za=299;break c}nrc(N|0,Ha+(I*9816|0)+10|0,O)|0;c[r>>2]=(c[r>>2]|0)+O}A=A+1|0;}while((A|0)<(ja|0));Vc=b[C>>1]|0}A=E+1|0;if((A|0)<(Vc&65535|0)){E=A;F=Vc}else{break}}Uc=a[ka]|0}F=Sc+1|0;if((F|0)<(Uc&255|0)){Sc=F;Tc=Uc}else{break}}}}while(0);D=D+1|0;}while((D|0)<(ca(e[la>>1]|0,e[z>>1]|0)|0));sc=c[pa>>2]|0}z=ga+1|0;if((z|0)<(sc|0)){ga=z;w=sc}else{break}}Wc=sc;Xc=c[ia>>2]|0}else{Wc=fa;Xc=ma}w=B+1|0;if((w|0)<(Xc|0)){B=w;fa=Wc;ma=Xc}else{break}}}KIb(c[sa>>2]|0,48,2121632,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;KIb(c[sa>>2]|0,48,2172816,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=je(6-t+(c[r>>2]|0)|0)|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;ma=ua+1|0;fa=(ma|0)<(ca(c[x>>2]|0,c[v>>2]|0)|0);B=c[r>>2]|0;if(fa){ua=ma;qa=B}else{Yc=B;break b}}if((za|0)==299){i=k;return q|0}}else{Yc=wa}}while(0);if(((c[p>>2]|0)-Yc|0)<2){q=-1;i=k;return q|0}p=Yc;y=-9729;a[p]=y;y=y>>8;a[p+1|0]=y;c[r>>2]=(c[r>>2]|0)+2;KIb(c[sa>>2]|0,48,2451504,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;c[s>>2]=(c[r>>2]|0)-(c[f>>2]|0);f=g+36|0;c[f>>2]=c[f>>2]|1;c[j>>2]=1;q=0;i=k;return q|0}function wNa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a+60>>2]|0;a=b+80|0;d=b+44|0;e=b+48|0;if((ca(c[e>>2]|0,c[d>>2]|0)|0)<=0){f=b+456|0;g=f;mJb(g);return 0}h=b+32|0;i=b+456|0;b=0;while(1){j=(c[i>>2]|0)+(b<<2)|0;if((c[h>>2]|0)>0){k=0;l=j;while(1){ONa((c[l>>2]|0)+(k*232|0)|0,a);m=k+1|0;n=(c[i>>2]|0)+(b<<2)|0;if((m|0)<(c[h>>2]|0)){k=m;l=n}else{o=n;break}}}else{o=j}mJb(o);l=b+1|0;if((l|0)<(ca(c[e>>2]|0,c[d>>2]|0)|0)){b=l}else{f=i;break}}g=f;mJb(g);return 0}function xNa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+120|0;h=g|0;c[h>>2]=e;j=c[e+4>>2]|0;do{if((j|0)==0){k=1;l=0}else{e=1;m=j;while(1){n=m+1|0;if((a[n]|0)!=0){o=5;break}a[n]=1;n=e+1|0;c[h+(e<<2)>>2]=m;p=c[m+4>>2]|0;if((p|0)==0){q=0;r=n;break}else{e=n;m=p}}if((o|0)==5){q=d[m|0]|0;r=e}if((r|0)>0){k=r;l=q;break}i=g;return}}while(0);q=b+64|0;r=b+56|0;b=l;l=k;while(1){k=l-1|0;j=c[h+(k<<2)>>2]|0;p=d[j]|0;if((p|0)>=(f|0)){break}n=p-b|0;p=c[q>>2]|0;if((n|0)>0){s=n;n=p;while(1){t=s-1|0;if((n|0)==8){u=c[r>>2]|0;c[q>>2]=(a[u]|0)==-1;v=u+1|0;c[r>>2]=v;a[v]=0;w=c[q>>2]|0}else{w=n}v=w+1|0;c[q>>2]=v;if((t|0)>0){s=t;n=v}else{x=v;break}}}else{x=p}if((x|0)==8){n=c[r>>2]|0;c[q>>2]=(a[n]|0)==-1;s=n+1|0;c[r>>2]=s;a[s]=0;y=c[q>>2]|0}else{y=x}c[q>>2]=y+1;s=c[r>>2]|0;a[s]=d[s]|1<<7-y;if((k|0)>0){b=d[j]|0;l=k}else{o=20;break}}if((o|0)==20){i=g;return}o=f-b|0;if((o|0)<=0){i=g;return}b=o;o=c[q>>2]|0;do{b=b-1|0;if((o|0)==8){f=c[r>>2]|0;c[q>>2]=(a[f]|0)==-1;l=f+1|0;c[r>>2]=l;a[l]=0;z=c[q>>2]|0}else{z=o}o=z+1|0;c[q>>2]=o;}while((b|0)>0);i=g;return}function yNa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=i;i=i+1160|0;g=b|0;h=b+128|0;j=b+1152|0;k=d;l=c[f+24>>2]|0;m=f+28|0;if((c[m>>2]|0)<1){n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}t=a[l]|0;if(t<<24>>24==0){n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}else{u=l;v=t}while(1){t=u+1|0;if(!(v<<24>>24==32|(v-9&255)>>>0<5>>>0)){break}u=t;v=a[t]|0}v=_b(u|0,32)|0;if((v|0)==0){n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}u=_b(v+1|0,32)|0;if((u|0)==0){n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}v=u+1|0;SFb(h,512,512);u=g|0;t=a[v]|0;l=t<<24>>24;mrc(u|0,0,128)|0;do{if(((((l-97|0)>>>0<26>>>0?l^32:l)<<24)-1073741825|0)>>>0<452984832>>>0){w=g+127|0;x=v;y=u;z=t;while(1){A=x+1|0;B=y+1|0;a[y]=((z<<24>>24)-97|0)>>>0<26>>>0?z^32:z;C=a[A]|0;if((C<<24>>24|0)==0|(C<<24>>24|0)==32){break}if((C-9&255)>>>0>4>>>0&B>>>0<w>>>0){x=A;y=B;z=C}else{break}}a[B]=0;if(!(C<<24>>24==32|(C-9&255)>>>0<5>>>0)){D=A;break}z=x+2|0;while(1){y=a[z]|0;if(y<<24>>24==32|(y-9&255)>>>0<5>>>0){z=z+1|0}else{D=z;break}}}else{D=v}}while(0);do{if((Db(u|0,2451496)|0)==0){if((Db(u|0,2362248)|0)!=0){E=2;break}v=(Db(u|0,2297512)|0)==0;E=v?0:4}else{E=1}}while(0);do{if((Db(u|0,2246672)|0)==0){if((Db(u|0,2204952)|0)!=0){F=16;G=19;break}v=(Db(u|0,2172808)|0)==0;A=(E|0)!=0;if(!(v&(A^1))){H=v?0:32;I=A;J=v;G=21}}else{F=8;G=19}}while(0);if((G|0)==19){H=F;I=(E|0)!=0;J=0;G=21}a:do{if((G|0)==21){switch((J?8:H)|(I?E:1)|0){case 34:{UFb(h,2567720,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 17:{UFb(h,2145416,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 18:{UFb(h,2616504,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 12:{UFb(h,2531520,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 36:{UFb(h,2516352,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 33:{UFb(h,2639128,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 20:{UFb(h,2549568,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 9:{UFb(h,2121624,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};case 10:{UFb(h,2589248,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;break a;break};default:{break a}}}}while(0);E=a[D]|0;b:do{if(!(E<<24>>24==0)){I=E;H=D;while(1){J=H+1|0;c:do{if((I<<24>>24|0)==92){while(1){if((a[J]|0)==10){break}else{L=0}while(1){if(!(L>>>0<14>>>0)){break}F=c[2013352+(L*12|0)>>2]|0;u=lrc(F|0)|0;if((krc(H,F,u)|0)==0){M=L;N=u;G=42;break c}else{L=L+1|0}}if((L|0)==14){G=44;break c}}u=H+2|0;while(1){F=a[u]|0;if(F<<24>>24==32|(F-9&255)>>>0<5>>>0){u=u+1|0}else{O=u;break}}}else if((I<<24>>24|0)==10|(I<<24>>24|0)==0){break b}else{u=0;while(1){if(u>>>0<14>>>0){F=c[2013352+(u*12|0)>>2]|0;v=lrc(F|0)|0;if((krc(H,F,v)|0)==0){M=u;N=v;G=42;break}else{u=u+1|0;continue}}if((u|0)==14){G=44;break c}if((I<<24>>24|0)==0|(I<<24>>24|0)==10){break b}else{u=0}}}}while(0);if((G|0)==42){G=0;O=H+((Ee[c[2013360+(M*12|0)>>2]&511](h,H+N|0,c[2013356+(M*12|0)>>2]|0)|0)+N)|0}else if((G|0)==44){G=0;UFb(h,2502384,(K=i,i=i+8|0,c[K>>2]=I<<24>>24,K)|0);i=K;O=H+1|0}J=a[O]|0;if(J<<24>>24==0){break}else{I=J;H=O}}}}while(0);UFb(h,2489304,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;_Fb(h,j)|0;fmb(k,c[j>>2]|0,c[f+8>>2]|0,c[f+48>>2]|0,0)|0;kJb(c[j>>2]|0);n=d+12|0;o=n;p=c[o>>2]|0;q=(p|0)!=0;r=q&1;c[e>>2]=r;s=c[m>>2]|0;i=b;return s|0}function zNa(a,b,d){a=a|0;b=b|0;d=d|0;b=i;UFb(a,2281272,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;i=b;return 0}function ANa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+72|0;e=b+16|0;f=b+24|0;g=b|0;mrc(g|0,0,16)|0;c[e>>2]=ie(0)|0;sc(e|0,f|0)|0;Fc(g|0,16,d|0,f|0)|0;UFb(a,2281272,(a=i,i=i+8|0,c[a>>2]=g,a)|0);i=a;i=b;return 0}function BNa(a,b,c){a=a|0;b=b|0;c=c|0;return 1}function CNa(a,b,c){a=a|0;b=b|0;c=c|0;return 1}function DNa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=t+h|0;v=h-t|0;t=p+l|0;b[c>>1]=u+t;b[r>>1]=u-t;t=((l-p+v|0)*181|0)>>>8<<16>>16;b[k>>1]=t+v;b[j>>1]=v-t;t=e-s+q|0;s=m+i|0;e=((t-s|0)*98|0)>>>8<<16>>16;v=e+((t*139|0)>>>8<<16>>16)|0;t=e+((s*334|0)>>>8<<16>>16)|0;s=((q+m|0)*181|0)>>>8<<16>>16;m=s+i|0;q=i-s|0;b[n>>1]=v+q;b[o>>1]=q-v;b[g>>1]=t+m;b[f>>1]=m-t;if((d|0)>0){c=c+16|0;d=d-1|0}else{w=a;x=7;break}}while(1){a=b[w>>1]|0;d=w+112|0;c=b[d>>1]|0;t=c+a|0;m=a-c|0;c=w+16|0;a=b[c>>1]|0;f=w+96|0;g=b[f>>1]|0;v=g+a|0;q=a-g|0;g=w+32|0;a=b[g>>1]|0;o=w+80|0;n=b[o>>1]|0;s=n+a|0;i=a-n|0;n=w+48|0;a=b[n>>1]|0;e=w+64|0;j=b[e>>1]|0;k=j+a|0;p=k+t|0;l=t-k|0;k=s+v|0;b[w>>1]=p+k;b[e>>1]=p-k;k=((v-s+l|0)*181|0)>>>8<<16>>16;b[g>>1]=k+l;b[f>>1]=l-k;k=a-j+i|0;j=q+m|0;a=((k-j|0)*98|0)>>>8<<16>>16;l=a+((k*139|0)>>>8<<16>>16)|0;k=a+((j*334|0)>>>8<<16>>16)|0;j=((i+q|0)*181|0)>>>8<<16>>16;q=j+m|0;i=m-j|0;b[o>>1]=l+i;b[n>>1]=i-l;b[c>>1]=k+q;b[d>>1]=q-k;if((x|0)>0){w=w+2|0;x=x-1|0}else{break}}return}function ENa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=t+h|0;v=h-t|0;t=p+l|0;b[c>>1]=u+t;b[r>>1]=u-t;t=((l-p+v|0)*181|0)>>>8<<16>>16;b[k>>1]=t+v;b[j>>1]=v-t;t=e-s+q|0;s=m+i|0;e=((t-s|0)*98|0)>>>8<<16>>16;v=e+((t*139|0)>>>8<<16>>16)|0;t=e+((s*334|0)>>>8<<16>>16)|0;s=((q+m|0)*181|0)>>>8<<16>>16;m=s+i|0;q=i-s|0;b[n>>1]=v+q;b[o>>1]=q-v;b[g>>1]=t+m;b[f>>1]=m-t;if((d|0)>0){c=c+16|0;d=d-1|0}else{w=a;x=7;break}}while(1){a=b[w>>1]|0;d=w+16|0;c=b[d>>1]|0;t=c+a|0;m=w+32|0;f=b[m>>1]|0;g=w+48|0;v=b[g>>1]|0;q=v+f|0;o=w+64|0;n=b[o>>1]|0;s=w+80|0;i=b[s>>1]|0;e=i+n|0;j=w+96|0;k=b[j>>1]|0;p=w+112|0;l=b[p>>1]|0;u=l+k|0;r=a-c|0;c=f-v|0;v=n-i|0;i=k-l|0;l=u+t|0;k=e+q|0;n=t-u|0;b[w>>1]=l+k;b[o>>1]=l-k;k=((q-e+n|0)*181|0)>>>8<<16>>16;b[m>>1]=k+n;b[j>>1]=n-k;k=i+r|0;n=v+c|0;j=r-i|0;b[d>>1]=k+n;b[s>>1]=k-n;n=((c-v+j|0)*181|0)>>>8<<16>>16;b[g>>1]=n+j;b[p>>1]=j-n;if((x|0)>0){w=w+2|0;x=x-1|0}else{break}}return}function FNa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=e-s|0;s=t+h|0;e=h-t|0;t=p+l|0;h=l-p|0;b[c>>1]=s+t<<4;b[r>>1]=s-t<<4;t=(e+h|0)*4433|0;b[k>>1]=((e*6270|0)+256+t|0)>>>9;b[j>>1]=((h*-15137|0)+256+t|0)>>>9;t=u+m|0;h=q+i|0;j=(t+h|0)*9633|0;e=(u+i|0)*-7373|0;k=(q+m|0)*-20995|0;s=j+(t*-16069|0)|0;t=j+(h*-3196|0)|0;b[f>>1]=((u*2446|0)+256+e+s|0)>>>9;b[n>>1]=((q*16819|0)+256+k+t|0)>>>9;b[o>>1]=((m*25172|0)+256+k+s|0)>>>9;b[g>>1]=((i*12299|0)+256+e+t|0)>>>9;if((d|0)>0){c=c+16|0;d=d-1|0}else{v=a;w=7;break}}while(1){a=b[v>>1]|0;d=v+112|0;c=b[d>>1]|0;t=c+a|0;e=a-c|0;c=v+16|0;a=b[c>>1]|0;i=v+96|0;g=b[i>>1]|0;s=g+a|0;k=a-g|0;g=v+32|0;a=b[g>>1]|0;m=v+80|0;o=b[m>>1]|0;q=o+a|0;n=a-o|0;o=v+48|0;a=b[o>>1]|0;u=v+64|0;f=b[u>>1]|0;h=f+a|0;j=a-f|0;f=h+t|0;a=t-h|0;h=q+s|0;t=s-q|0;b[v>>1]=(h+8+f|0)>>>4;b[u>>1]=(8-h+f|0)>>>4;f=(a+t|0)*4433|0;b[g>>1]=(a*6270|0)+65536+f>>17;b[i>>1]=(t*-15137|0)+65536+f>>17;f=j+k|0;t=n+e|0;i=(f+t|0)*9633|0;a=(j+e|0)*-7373|0;g=(n+k|0)*-20995|0;h=i+(f*-16069|0)|0;f=i+(t*-3196|0)|0;b[d>>1]=(j*2446|0)+65536+a+h>>17;b[m>>1]=(n*16819|0)+65536+g+f>>17;b[o>>1]=(k*25172|0)+65536+g+h>>17;b[c>>1]=(e*12299|0)+65536+a+f>>17;if((w|0)>0){v=v+2|0;w=w-1|0}else{break}}return}function GNa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=e-s|0;s=t+h|0;e=h-t|0;t=p+l|0;h=l-p|0;b[c>>1]=s+t<<4;b[r>>1]=s-t<<4;t=(e+h|0)*4433|0;b[k>>1]=((e*6270|0)+256+t|0)>>>9;b[j>>1]=((h*-15137|0)+256+t|0)>>>9;t=u+m|0;h=q+i|0;j=(t+h|0)*9633|0;e=(u+i|0)*-7373|0;k=(q+m|0)*-20995|0;s=j+(t*-16069|0)|0;t=j+(h*-3196|0)|0;b[f>>1]=((u*2446|0)+256+e+s|0)>>>9;b[n>>1]=((q*16819|0)+256+k+t|0)>>>9;b[o>>1]=((m*25172|0)+256+k+s|0)>>>9;b[g>>1]=((i*12299|0)+256+e+t|0)>>>9;if((d|0)>0){c=c+16|0;d=d-1|0}else{v=a;w=7;break}}while(1){a=b[v>>1]|0;d=v+16|0;c=b[d>>1]|0;t=c+a|0;e=v+32|0;i=b[e>>1]|0;g=v+48|0;s=b[g>>1]|0;k=s+i|0;m=v+64|0;o=b[m>>1]|0;q=v+80|0;n=b[q>>1]|0;u=n+o|0;f=v+96|0;h=b[f>>1]|0;j=v+112|0;r=b[j>>1]|0;p=r+h|0;l=a-c|0;c=i-s|0;s=o-n|0;n=h-r|0;r=p+t|0;h=u+k|0;o=k-u|0;u=t-p|0;b[v>>1]=(h+8+r|0)>>>4;b[m>>1]=(8-h+r|0)>>>4;r=(u+o|0)*4433|0;b[e>>1]=(u*6270|0)+65536+r>>17;b[f>>1]=(o*-15137|0)+65536+r>>17;r=n+l|0;o=s+c|0;f=c-s|0;s=l-n|0;b[d>>1]=(o+8+r|0)>>>4;b[q>>1]=(8-o+r|0)>>>4;r=(s+f|0)*4433|0;b[g>>1]=(s*6270|0)+65536+r>>17;b[j>>1]=(f*-15137|0)+65536+r>>17;if((w|0)>0){v=v+2|0;w=w-1|0}else{break}}return}function HNa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=e-s|0;s=t+h|0;e=h-t|0;t=p+l|0;h=l-p|0;b[c>>1]=s+t<<1;b[r>>1]=s-t<<1;t=(e+h|0)*4433|0;b[k>>1]=((e*6270|0)+2048+t|0)>>>12;b[j>>1]=((h*-15137|0)+2048+t|0)>>>12;t=u+m|0;h=q+i|0;j=(t+h|0)*9633|0;e=(u+i|0)*-7373|0;k=(q+m|0)*-20995|0;s=j+(t*-16069|0)|0;t=j+(h*-3196|0)|0;b[f>>1]=((u*2446|0)+2048+e+s|0)>>>12;b[n>>1]=((q*16819|0)+2048+k+t|0)>>>12;b[o>>1]=((m*25172|0)+2048+k+s|0)>>>12;b[g>>1]=((i*12299|0)+2048+e+t|0)>>>12;if((d|0)>0){c=c+16|0;d=d-1|0}else{v=a;w=7;break}}while(1){a=b[v>>1]|0;d=v+112|0;c=b[d>>1]|0;t=c+a|0;e=a-c|0;c=v+16|0;a=b[c>>1]|0;i=v+96|0;g=b[i>>1]|0;s=g+a|0;k=a-g|0;g=v+32|0;a=b[g>>1]|0;m=v+80|0;o=b[m>>1]|0;q=o+a|0;n=a-o|0;o=v+48|0;a=b[o>>1]|0;u=v+64|0;f=b[u>>1]|0;h=f+a|0;j=a-f|0;f=h+t|0;a=t-h|0;h=q+s|0;t=s-q|0;b[v>>1]=(h+2+f|0)>>>2;b[u>>1]=(2-h+f|0)>>>2;f=(a+t|0)*4433|0;b[g>>1]=((a*6270|0)+16384+f|0)>>>15;b[i>>1]=((t*-15137|0)+16384+f|0)>>>15;f=j+k|0;t=n+e|0;i=(f+t|0)*9633|0;a=(j+e|0)*-7373|0;g=(n+k|0)*-20995|0;h=i+(f*-16069|0)|0;f=i+(t*-3196|0)|0;b[d>>1]=((j*2446|0)+16384+a+h|0)>>>15;b[m>>1]=((n*16819|0)+16384+g+f|0)>>>15;b[o>>1]=((k*25172|0)+16384+g+h|0)>>>15;b[c>>1]=((e*12299|0)+16384+a+f|0)>>>15;if((w|0)>0){v=v+2|0;w=w-1|0}else{break}}return}function INa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=a;d=7;while(1){e=b[c>>1]|0;f=c+14|0;g=b[f>>1]|0;h=g+e|0;i=e-g|0;g=c+2|0;e=b[g>>1]|0;j=c+12|0;k=b[j>>1]|0;l=k+e|0;m=e-k|0;k=c+4|0;e=b[k>>1]|0;n=c+10|0;o=b[n>>1]|0;p=o+e|0;q=e-o|0;o=c+6|0;e=b[o>>1]|0;r=c+8|0;s=b[r>>1]|0;t=s+e|0;u=e-s|0;s=t+h|0;e=h-t|0;t=p+l|0;h=l-p|0;b[c>>1]=s+t<<1;b[r>>1]=s-t<<1;t=(e+h|0)*4433|0;b[k>>1]=((e*6270|0)+2048+t|0)>>>12;b[j>>1]=((h*-15137|0)+2048+t|0)>>>12;t=u+m|0;h=q+i|0;j=(t+h|0)*9633|0;e=(u+i|0)*-7373|0;k=(q+m|0)*-20995|0;s=j+(t*-16069|0)|0;t=j+(h*-3196|0)|0;b[f>>1]=((u*2446|0)+2048+e+s|0)>>>12;b[n>>1]=((q*16819|0)+2048+k+t|0)>>>12;b[o>>1]=((m*25172|0)+2048+k+s|0)>>>12;b[g>>1]=((i*12299|0)+2048+e+t|0)>>>12;if((d|0)>0){c=c+16|0;d=d-1|0}else{v=a;w=7;break}}while(1){a=b[v>>1]|0;d=v+16|0;c=b[d>>1]|0;t=c+a|0;e=v+32|0;i=b[e>>1]|0;g=v+48|0;s=b[g>>1]|0;k=s+i|0;m=v+64|0;o=b[m>>1]|0;q=v+80|0;n=b[q>>1]|0;u=n+o|0;f=v+96|0;h=b[f>>1]|0;j=v+112|0;r=b[j>>1]|0;p=r+h|0;l=a-c|0;c=i-s|0;s=o-n|0;n=h-r|0;r=p+t|0;h=u+k|0;o=k-u|0;u=t-p|0;b[v>>1]=(h+2+r|0)>>>2;b[m>>1]=(2-h+r|0)>>>2;r=(u+o|0)*4433|0;b[e>>1]=((u*6270|0)+16384+r|0)>>>15;b[f>>1]=((o*-15137|0)+16384+r|0)>>>15;r=n+l|0;o=s+c|0;f=c-s|0;s=l-n|0;b[d>>1]=(o+2+r|0)>>>2;b[q>>1]=(2-o+r|0)>>>2;r=(s+f|0)*4433|0;b[g>>1]=((s*6270|0)+16384+r|0)>>>15;b[j>>1]=((f*-15137|0)+16384+r|0)>>>15;if((w|0)>0){v=v+2|0;w=w-1|0}else{break}}return}function JNa(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=0;while(1){d=(b>>>1&1)+(b>>>2&1)|0;e=(b>>>3&1)+(b&1)|0;f=(b>>>4&1)+(b>>>5&1)+(b>>>6&1)+(b>>>7&1)|0;g=(f|0)>1;h=(f|0)==1;i=(f|0)>0?6:5;j=d+e|0;k=(j|0)>0?7:6;l=(j|0)>1;m=(j|0)==1;j=m?4:3;do{if((f|0)>2){do{if((d|0)==2){n=8;o=62}else if((d|0)==1){if((e|0)!=0){n=7;o=62;break}a[7696880+(b<<2)|0]=i;o=65}else{if((e|0)==1){a[7696880+(b<<2)|0]=3;o=63;break}else if((e|0)==2){a[7696880+(b<<2)|0]=4;p=8;o=70;break}else{if(g){n=2;o=62;break}n=h&1;o=62;break}}}while(0);if((o|0)==62){o=0;a[7696880+(b<<2)|0]=n;if((e|0)==1){o=63}else if((e|0)==2){p=8;o=70}else{o=65}}do{if((o|0)==63){o=0;if((d|0)!=0){p=7;o=70;break}a[7696881+(b<<2)|0]=i;o=72}else if((o|0)==65){o=0;if((d|0)==2){a[7696881+(b<<2)|0]=4;q=8;break}else if((d|0)==1){a[7696881+(b<<2)|0]=3;o=71;break}else{if(g){p=2;o=70;break}p=h&1;o=70;break}}}while(0);if((o|0)==70){o=0;a[7696881+(b<<2)|0]=p;if((d|0)==1){o=71}else if((d|0)==2){q=8}else{o=72}}do{if((o|0)==71){o=0;q=(e|0)==0?i:7}else if((o|0)==72){o=0;if((e|0)==1){q=3;break}else if((e|0)==2){q=4;break}if(g){q=2;break}q=h&1}}while(0);a[7696882+(b<<2)|0]=q;a[7696883+(b<<2)|0]=8}else{if((f|0)==2){do{if((d|0)==2){r=8;o=77}else if((d|0)==1){if((e|0)!=0){r=7;o=77;break}a[7696880+(b<<2)|0]=i;o=80}else{if((e|0)==2){a[7696880+(b<<2)|0]=4;s=8;o=85;break}else if((e|0)==1){a[7696880+(b<<2)|0]=3;o=78;break}else{if(g){r=2;o=77;break}r=h&1;o=77;break}}}while(0);if((o|0)==77){o=0;a[7696880+(b<<2)|0]=r;if((e|0)==1){o=78}else if((e|0)==2){s=8;o=85}else{o=80}}do{if((o|0)==78){o=0;if((d|0)!=0){s=7;o=85;break}a[7696881+(b<<2)|0]=i;o=87}else if((o|0)==80){o=0;if((d|0)==2){a[7696881+(b<<2)|0]=4;t=8;break}else if((d|0)==1){a[7696881+(b<<2)|0]=3;o=86;break}else{if(g){s=2;o=85;break}s=h&1;o=85;break}}}while(0);if((o|0)==85){o=0;a[7696881+(b<<2)|0]=s;if((d|0)==1){o=86}else if((d|0)==2){t=8}else{o=87}}do{if((o|0)==86){o=0;t=(e|0)==0?i:7}else if((o|0)==87){o=0;if((e|0)==1){t=3;break}else if((e|0)==2){t=4;break}if(g){t=2;break}t=h&1}}while(0);a[7696882+(b<<2)|0]=t;a[7696883+(b<<2)|0]=k;break}do{if((d|0)==1){if((e|0)!=0){u=7;o=41;break}a[7696880+(b<<2)|0]=i;o=44}else if((d|0)==2){u=8;o=41}else{if((e|0)==2){a[7696880+(b<<2)|0]=4;v=8;o=49;break}else if((e|0)==1){a[7696880+(b<<2)|0]=3;o=42;break}else{if(g){u=2;o=41;break}u=h&1;o=41;break}}}while(0);if((o|0)==41){o=0;a[7696880+(b<<2)|0]=u;if((e|0)==1){o=42}else if((e|0)==2){v=8;o=49}else{o=44}}do{if((o|0)==42){o=0;if((d|0)!=0){v=7;o=49;break}a[7696881+(b<<2)|0]=i;o=51}else if((o|0)==44){o=0;if((d|0)==2){a[7696881+(b<<2)|0]=4;w=8;o=57;break}else if((d|0)==1){a[7696881+(b<<2)|0]=3;o=50;break}else{if(g){v=2;o=49;break}v=h&1;o=49;break}}}while(0);if((o|0)==49){o=0;a[7696881+(b<<2)|0]=v;if((d|0)==1){o=50}else if((d|0)==2){w=8;o=57}else{o=51}}do{if((o|0)==50){o=0;w=(e|0)==0?i:7;o=57}else if((o|0)==51){o=0;if((e|0)==1){w=3;o=57;break}else if((e|0)==2){w=4;o=57;break}if(g){w=2;o=57;break}x=7696882+(b<<2)|0;if(h){a[x]=1;o=60;break}else{a[x]=0;o=58;break}}}while(0);if((o|0)==57){o=0;a[7696882+(b<<2)|0]=w;if(h){o=60}else{o=58}}do{if((o|0)==58){o=0;if(l){y=2;break}y=m&1}else if((o|0)==60){o=0;y=l?5:j}}while(0);a[7696883+(b<<2)|0]=y}}while(0);j=b+1|0;if((j|0)<256){b=j}else{z=0;break}}do{b=0;do{y=(b<<8)+z|0;if((y&4|0)==0){A=0}else{A=2-(y>>>10&1)|0}if((y&2|0)==0){B=0}else{B=2-(y>>>11&1)|0}o=(c[1637808+(B*12|0)+(A<<2)>>2]|0)+1|0;if((y&1|0)==0){C=0}else{C=2-(y>>>8&1)|0}if((y&8|0)==0){D=0}else{D=2-(y>>>9&1)|0}y=(c[1637808+(D*12|0)+(C<<2)>>2]|0)+1|0;a[7696624+(z<<4)+b|0]=c[2e3+(o*12|0)+(y<<2)>>2];a[7697904+(z<<4)+b|0]=c[1624944+(o*12|0)+(y<<2)>>2];b=b+1|0;}while((b|0)<16);z=z+1|0;}while((z|0)<16);return}function KNa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b+1|0;g=d+1|0;h=a+16384+(g*264|0)+(f<<2)|0;c[h>>2]=c[h>>2]|8192;h=b+2|0;i=a+16384+(g*264|0)+(h<<2)|0;j=c[i>>2]|0;if((e|0)==0){c[i>>2]=j|4;e=a+16384+(g*264|0)+(b<<2)|0;c[e>>2]=c[e>>2]|2;e=a+16384+((d+2|0)*264|0)+(f<<2)|0;c[e>>2]=c[e>>2]|1;e=a+16384+(d*264|0)+(f<<2)|0;c[e>>2]=c[e>>2]|8}else{c[i>>2]=j|1028;j=a+16384+(g*264|0)+(b<<2)|0;c[j>>2]=c[j>>2]|2050;j=a+16384+((d+2|0)*264|0)+(f<<2)|0;c[j>>2]=c[j>>2]|257;j=a+16384+(d*264|0)+(f<<2)|0;c[j>>2]=c[j>>2]|520}j=d+2|0;f=a+16384+(j*264|0)+(h<<2)|0;c[f>>2]=c[f>>2]|32;f=a+16384+(j*264|0)+(b<<2)|0;c[f>>2]=c[f>>2]|16;f=a+16384+(d*264|0)+(h<<2)|0;c[f>>2]=c[f>>2]|128;f=a+16384+(d*264|0)+(b<<2)|0;c[f>>2]=c[f>>2]|64;return}function LNa(f,h,j,k,l,m,n){f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0.0,ha=0.0,ia=0.0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;o=i;p=c[h+4>>2]|0;if((p|0)<1){KIb(n,16,2525104,(q=i,i=i+8|0,c[q>>2]=p,q)|0);i=q;r=-1094995529;i=o;return r|0}s=f+216|0;t=h+10|0;u=XNa(f+4|0,s|0,p-1|0,d[t]|0)|0;if((u|0)!=0){r=u;i=o;return r|0}u=ca((e[f+222>>1]|0)-(e[f+220>>1]|0)|0,(e[f+218>>1]|0)-(e[s>>1]|0)|0)|0;do{if((a[t]|0)==0){c[f+212>>2]=0;if(u>>>0<536870911>>>0){s=pJb(u<<2)|0;c[f+208>>2]=s;if((s|0)==0){r=-12}else{break}i=o;return r|0}else{c[f+208>>2]=0;r=-12;i=o;return r|0}}else{c[f+208>>2]=0;if(u>>>0<536870911>>>0){s=pJb(u<<2)|0;c[f+212>>2]=s;if((s|0)==0){r=-12}else{break}i=o;return r|0}else{c[f+212>>2]=0;r=-12;i=o;return r|0}}}while(0);u=h|0;s=qJb(c[u>>2]|0,20)|0;p=s;v=f|0;c[v>>2]=p;if((s|0)==0){r=-12;i=o;return r|0}s=c[u>>2]|0;if((s|0)<=0){r=0;i=o;return r|0}w=j+288|0;x=n;y=n+12|0;n=l-1|0;z=m-1|0;A=h+8|0;B=h+9|0;C=k+2|0;D=k&255;k=0;E=0;F=s;s=p;a:while(1){p=F-E|0;G=p-1|0;H=(1<<G)-1|0;I=f+224|0;J=H+(e[I>>1]|0)>>G;K=J&65535;b[s+(E*20|0)+2>>1]=K;L=f+226|0;M=H+(e[L>>1]|0)>>G;N=M&65535;b[s+(E*20|0)+4>>1]=N;O=f+228|0;P=H+(e[O>>1]|0)>>G;Q=P&65535;b[s+(E*20|0)+6>>1]=Q;R=f+230|0;S=H+(e[R>>1]|0)>>G;T=S&65535;b[s+(E*20|0)+8>>1]=T;U=a[h+16+E|0]|0;V=s+(E*20|0)+14|0;a[V]=U;W=a[h+49+E|0]|0;X=s+(E*20|0)+15|0;a[X]=W;Y=(E|0)==0;Z=s+(E*20|0)|0;_=Y?1:3;a[Z]=_;if(N<<16>>16==K<<16>>16){b[s+(E*20|0)+10>>1]=0}else{K=U&255;b[s+(E*20|0)+10>>1]=((M&65535)-1+(1<<K)>>K)-((J&65535)>>>(K>>>0))}if(T<<16>>16==Q<<16>>16){b[s+(E*20|0)+12>>1]=0}else{Q=W&255;b[s+(E*20|0)+12>>1]=((S&65535)-1+(1<<Q)>>Q)-((P&65535)>>>(Q>>>0))}Q=qJb(_&255,24)|0;_=Q;P=s+(E*20|0)+16|0;c[P>>2]=_;if((Q|0)==0){r=-12;$=57;break}b:do{if((a[Z]|0)==0){aa=k}else{Q=s+(E*20|0)+10|0;S=s+(E*20|0)+12|0;W=(E|0)!=0|0;T=E-1|0;K=(1<<p)-1|0;J=(E|0)>0|0;M=k;U=0;N=_;while(1){ba=d[w]|0;if((ba|0)==0){g[N+(U*24|0)+16>>2]=1.0}else if((ba|0)==1){da=C+(d[U+J+(841088+(((a[t]|0)==1)<<2))|0]|0)-(d[j+M|0]|0)|0;ea=(e[j+96+(M<<1)>>1]|0)+2048|0;if((da|0)>-1){fa=ea<<da}else{fa=ea>>>((-da|0)>>>0)}g[N+(U*24|0)+16>>2]=+(fa|0)}else if((ba|0)==2){ga=+Jqc(1.0,D-(d[j+M|0]|0)|0);g[N+(U*24|0)+16>>2]=ga*(+(e[j+96+(M<<1)>>1]|0)*.00048828125+1.0)}else{g[N+(U*24|0)+16>>2]=0.0;KIb(x,16,2603136,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}ba=(D4a(c[y>>2]|0)|0)==0;da=N+(U*24|0)+16|0;ga=+g[da>>2];if(ba){ha=ga*.5;g[da>>2]=ha;ia=ha}else{ia=ga}c[N+(U*24|0)+12>>2]=~~(ia*32768.0);if(Y){da=H>>G&65535;b[N+(U*24|0)>>1]=da;ba=H+(e[L>>1]|0)-(e[I>>1]|0)>>G&65535;b[N+(U*24|0)+2>>1]=ba;b[N+(U*24|0)+4>>1]=da;ea=H+(e[R>>1]|0)-(e[O>>1]|0)>>G&65535;b[N+(U*24|0)+6>>1]=ea;ja=a[V]|0;ka=a[X]|0;la=a[A]|0;b[N+(U*24|0)+8>>1]=((la&255)>>>0>(ja&255)>>>0?ja:la)&255;la=a[B]|0;ma=a[X]|0;b[N+(U*24|0)+10>>1]=((la&255)>>>0>(ma&255)>>>0?ma:la)&255;na=ja;oa=ka;pa=da;qa=ba;ra=da;sa=ea}else{ea=U+1|0;da=K-((ea&1)<<G)|0;ba=da>>p&65535;b[N+(U*24|0)>>1]=ba;ka=da+(e[L>>1]|0)-(e[I>>1]|0)>>p&65535;b[N+(U*24|0)+2>>1]=ka;da=K-((ea>>>1&1)<<G)|0;ea=da>>p&65535;b[N+(U*24|0)+4>>1]=ea;ja=da+(e[R>>1]|0)-(e[O>>1]|0)>>p&65535;b[N+(U*24|0)+6>>1]=ja;da=a[A]|0;la=(d[V]|0)-1|0;b[N+(U*24|0)+8>>1]=(da&255|0)>(la|0)?la&65535:da&255;da=a[B]|0;la=(d[X]|0)-1|0;b[N+(U*24|0)+10>>1]=(da&255|0)>(la|0)?la&65535:da&255;na=(a[V]|0)-1&255;oa=(a[X]|0)-1&255;pa=ba;qa=ka;ra=ea;sa=ja}ja=N+(U*24|0)|0;b[ja>>1]=(n+(pa&65535)|0)/(l|0)|0;ea=N+(U*24|0)+2|0;b[ea>>1]=(n+(qa&65535)|0)/(l|0)|0;ka=N+(U*24|0)+4|0;b[ka>>1]=(z+(ra&65535)|0)/(m|0)|0;ba=N+(U*24|0)+6|0;b[ba>>1]=(z+(sa&65535)|0)/(m|0)|0;da=qJb(ca(e[S>>1]|0,e[Q>>1]|0)|0,24)|0;la=da;ma=N+(U*24|0)+20|0;c[ma>>2]=la;if((da|0)==0){r=-12;$=57;break a}da=b[Q>>1]|0;ta=ca(e[S>>1]|0,da&65535)|0;c:do{if((ta|0)!=0){ua=na&255;va=1<<ua;wa=oa&255;xa=1<<wa;ya=N+(U*24|0)+8|0;za=N+(U*24|0)+10|0;Aa=U+W|0;Ba=(Aa&1|0)==0;Ca=(Aa&2|0)==0;Da=0;Ea=la;Aa=da;while(1){Fa=((Da|0)%(Aa&65535|0)|0)<<ua;Ga=Fa&65535;Ha=Ea+(Da*24|0)+16|0;b[Ha>>1]=Ga;Ia=b[ja>>1]|0;Ja=(Fa&65535)>>>0>(Ia&65535)>>>0?Ga:Ia;b[Ha>>1]=Ja;Ia=((Da|0)/(e[Q>>1]|0)|0)<<wa;Ga=Ia&65535;Fa=Ea+(Da*24|0)+20|0;b[Fa>>1]=Ga;Ka=b[ka>>1]|0;La=(Ia&65535)>>>0>(Ka&65535)>>>0?Ga:Ka;b[Fa>>1]=La;Ka=Ja&65535;Ja=Ka+va|0;Ga=Ja&65535;Ia=Ea+(Da*24|0)+18|0;b[Ia>>1]=Ga;Ma=b[ea>>1]|0;Na=(Ja&65535)>>>0>(Ma&65535)>>>0?Ma:Ga;b[Ia>>1]=Na;Ga=La&65535;La=Ga+xa|0;Ma=La&65535;Ja=Ea+(Da*24|0)+22|0;b[Ja>>1]=Ma;Oa=b[ba>>1]|0;Pa=(La&65535)>>>0>(Oa&65535)>>>0?Oa:Ma;b[Ja>>1]=Pa;Ma=e[ya>>1]|0;Oa=(Na&65535)-1-Ka+(1<<Ma)>>Ma;Ma=Ea+(Da*24|0)|0;b[Ma>>1]=Oa;Ka=e[za>>1]|0;Na=(Pa&65535)-1-Ga+(1<<Ka)>>Ka;Ka=Ea+(Da*24|0)+2|0;b[Ka>>1]=Na;Ga=MNa(Oa&65535,Na&65535)|0;c[Ea+(Da*24|0)+8>>2]=Ga;if((Ga|0)==0){r=-12;$=57;break a}Ga=MNa(e[Ma>>1]|0,e[Ka>>1]|0)|0;c[Ea+(Da*24|0)+4>>2]=Ga;if((Ga|0)==0){r=-12;$=57;break a}Ga=ca(e[Ka>>1]|0,e[Ma>>1]|0)|0;if(!(Ga>>>0<218773>>>0)){$=42;break a}Na=pJb(Ga*9816|0)|0;Ga=Na;Oa=Ea+(Da*24|0)+12|0;c[Oa>>2]=Ga;if((Na|0)==0){r=-12;$=57;break a}Na=e[Ma>>1]|0;d:do{if((ca(e[Ka>>1]|0,Na)|0)!=0){Pa=0;La=Na;Qa=Ga;while(1){Ra=b[Ha>>1]|0;Sa=Ra&65535;Ta=e[ya>>1]|0;Ua=(Sa>>>(Ta>>>0)<<Ta)+(((Pa|0)%(La|0)|0)<<Ta)|0;Ta=Ua&65535;Va=Ta>>>0>Sa>>>0?Ua&65535:Ra;Ra=Qa+(Pa*9816|0)+9808|0;b[Ra>>1]=Va;Ua=b[Fa>>1]|0;Sa=Ua&65535;Wa=e[za>>1]|0;Xa=(Sa>>>(Wa>>>0)<<Wa)+(((Pa|0)/(e[Ma>>1]|0)|0)<<Wa)|0;Wa=Xa&65535;Ya=Wa>>>0>Sa>>>0?Xa&65535:Ua;Ua=Qa+(Pa*9816|0)+9812|0;b[Ua>>1]=Ya;Xa=(1<<e[ya>>1])+Ta|0;Ta=b[Ia>>1]|0;Sa=(Xa|0)>(Ta&65535|0)?Ta:Xa&65535;Xa=Qa+(Pa*9816|0)+9810|0;b[Xa>>1]=Sa;Ta=(1<<e[za>>1])+Wa|0;Wa=b[Ja>>1]|0;Za=(Ta|0)>(Wa&65535|0)?Wa:Ta&65535;Ta=Qa+(Pa*9816|0)+9814|0;b[Ta>>1]=Za;if(!Ba){Wa=c[v>>2]|0;_a=Wa+(T*20|0)+4|0;$a=Wa+(T*20|0)+2|0;b[Ra>>1]=((b[_a>>1]|0)-(b[$a>>1]|0)&65535)+Va;b[Xa>>1]=((b[_a>>1]|0)-(b[$a>>1]|0)&65535)+Sa}if(!Ca){Sa=c[v>>2]|0;$a=Sa+(T*20|0)+8|0;_a=Sa+(T*20|0)+6|0;b[Ua>>1]=((b[$a>>1]|0)-(b[_a>>1]|0)&65535)+Ya;b[Ta>>1]=((b[$a>>1]|0)-(b[_a>>1]|0)&65535)+Za}a[Qa+(Pa*9816|0)+9|0]=0;a[Qa+(Pa*9816|0)+8|0]=3;b[Qa+(Pa*9816|0)+4>>1]=0;b[Qa+(Pa*9816|0)+6>>1]=0;a[Qa+(Pa*9816|0)|0]=0;Za=Pa+1|0;_a=e[Ma>>1]|0;if((Za|0)>=(ca(e[Ka>>1]|0,_a)|0)){break d}Pa=Za;La=_a;Qa=c[Oa>>2]|0}}}while(0);Oa=Da+1|0;if((Oa|0)>=(ta|0)){break c}Da=Oa;Ea=c[ma>>2]|0;Aa=b[Q>>1]|0}}}while(0);ma=U+1|0;ta=M+1|0;if((ma|0)>=(d[Z]|0)){aa=ta;break b}M=ta;U=ma;N=c[P>>2]|0}}}while(0);P=E+1|0;Z=c[u>>2]|0;if((P|0)>=(Z|0)){r=0;$=57;break}k=aa;E=P;F=Z;s=c[v>>2]|0}if(($|0)==42){c[Ea+(Da*24|0)+12>>2]=0;r=-12;i=o;return r|0}else if(($|0)==57){i=o;return r|0}return 0}function MNa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=PNa(a&65535,b&65535)|0;if(!(d>>>0<268435455>>>0)){e=0;return e|0}f=pJb(d<<3)|0;d=f;if((f|0)==0){e=0;return e|0}if((a|0)>1|(b|0)>1){f=b;b=d;g=a;while(1){a=g+1>>1;h=f+1>>1;i=ca(g,f)|0;j=b+(i<<3)|0;if((f|0)>0&(g|0)>0){k=0;do{l=(ca(k>>1,a)|0)+i|0;m=ca(k,g)|0;n=0;do{c[b+(n+m<<3)+4>>2]=b+(l+(n>>1)<<3);n=n+1|0;}while((n|0)<(g|0));k=k+1|0;}while((k|0)<(f|0))}if((a|0)>1|(h|0)>1){f=h;b=j;g=a}else{o=j;break}}}else{o=d}c[o+4>>2]=0;e=d;return e|0}function NNa(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=i;h=f|0;f=c[h>>2]|0;if((f|0)<=0){i=g;return}j=d|0;d=0;k=f;a:while(1){f=c[j>>2]|0;l=f+(d*20|0)|0;m=a[l]|0;if(m<<24>>24==0){n=k}else{o=f+(d*20|0)+16|0;p=f+(d*20|0)+10|0;q=f+(d*20|0)+12|0;f=0;r=b[p>>1]|0;s=b[q>>1]|0;t=m;while(1){if((ca(s&65535,r&65535)|0)==0){u=r;v=s;w=t}else{m=(c[o>>2]|0)+(f*24|0)+20|0;x=0;do{y=c[m>>2]|0;z=c[y+(x*24|0)+4>>2]|0;A=y+(x*24|0)|0;B=b[A>>1]|0;C=y+(x*24|0)+2|0;D=b[C>>1]|0;if((B&65535)>>>0>1>>>0|(D&65535)>>>0>1>>>0){E=D;F=0;G=B;do{H=G&65535;I=E&65535;F=(ca(I,H)|0)+F|0;J=F+1|0;if(!(J>>>0<2147483647>>>0)){K=9;break a}G=(H+1|0)>>>1&65535;E=(I+1|0)>>>1&65535;}while((G&65535)>>>0>1>>>0|(E&65535)>>>0>1>>>0);if((J|0)>0){L=J;K=12}else{M=B;N=D}}else{L=1;K=12}if((K|0)==12){K=0;E=0;do{a[z+(E<<3)|0]=0;a[z+(E<<3)+1|0]=0;E=E+1|0;}while((E|0)<(L|0));M=b[A>>1]|0;N=b[C>>1]|0}E=c[y+(x*24|0)+8>>2]|0;if((M&65535)>>>0>1>>>0|(N&65535)>>>0>1>>>0){z=N;D=0;B=M;do{G=B&65535;F=z&65535;D=(ca(F,G)|0)+D|0;O=D+1|0;if(!(O>>>0<2147483647>>>0)){K=17;break a}B=(G+1|0)>>>1&65535;z=(F+1|0)>>>1&65535;}while((B&65535)>>>0>1>>>0|(z&65535)>>>0>1>>>0);if((O|0)>0){P=O;K=20}else{Q=M;R=N}}else{P=1;K=20}if((K|0)==20){K=0;z=0;do{a[E+(z<<3)|0]=0;a[E+(z<<3)+1|0]=0;z=z+1|0;}while((z|0)<(P|0));Q=b[A>>1]|0;R=b[C>>1]|0}if((ca(R&65535,Q&65535)|0)!=0){z=y+(x*24|0)+12|0;E=0;do{B=c[z>>2]|0;b[B+(E*9816|0)+4>>1]=0;a[B+(E*9816|0)+8|0]=3;E=E+1|0;}while((E|0)<(ca(e[C>>1]|0,e[A>>1]|0)|0))}x=x+1|0;S=b[p>>1]|0;T=b[q>>1]|0;}while((x|0)<(ca(T&65535,S&65535)|0));u=S;v=T;w=a[l]|0}x=f+1|0;if((x|0)<(w&255|0)){f=x;r=u;s=v;t=w}else{break}}n=c[h>>2]|0}t=d+1|0;if((t|0)<(n|0)){d=t;k=n}else{K=31;break}}if((K|0)==9){KIb(0,0,2451448,(U=i,i=i+24|0,c[U>>2]=2362160,c[U+8>>2]=2297480,c[U+16>>2]=44,U)|0);i=U;Hd()}else if((K|0)==17){KIb(0,0,2451448,(U=i,i=i+24|0,c[U>>2]=2362160,c[U+8>>2]=2297480,c[U+16>>2]=44,U)|0);i=U;Hd()}else if((K|0)==31){i=g;return}}function ONa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=e|0;e=d|0;g=c[e>>2]|0;a:do{if((g|0)!=0){h=0;i=g;while(1){if((h|0)>=(c[f>>2]|0)){break a}j=i+(h*20|0)|0;k=a[j]|0;l=i+(h*20|0)+16|0;if(!(k<<24>>24==0)){m=i+(h*20|0)+10|0;n=i+(h*20|0)+12|0;o=0;p=k;while(1){k=c[l>>2]|0;if((k|0)==0){q=p}else{r=b[m>>1]|0;s=b[n>>1]|0;t=k+(o*24|0)+20|0;if((ca(s&65535,r&65535)|0)!=0){k=0;u=r;r=s;while(1){s=c[t>>2]|0;if((s|0)==0){v=u;w=r}else{mJb(s+(k*24|0)+4|0);mJb(s+(k*24|0)+8|0);mJb(s+(k*24|0)+12|0);v=b[m>>1]|0;w=b[n>>1]|0}s=k+1|0;if((s|0)<(ca(w&65535,v&65535)|0)){k=s;u=v;r=w}else{break}}}mJb(t);q=a[j]|0}r=o+1|0;if((r|0)<(q&255|0)){o=r;p=q}else{break}}}mJb(l);p=c[e>>2]|0;if((p|0)==0){break}else{h=h+1|0;i=p}}}}while(0);_Na(d+4|0);mJb(d);mJb(d+212|0);mJb(d+208|0);return}function PNa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a&65535)>>>0>1>>>0|(b&65535)>>>0>1>>>0){e=b;f=0;g=a}else{h=1;i=d;return h|0}while(1){a=g&65535;b=e&65535;j=(ca(b,a)|0)+f|0;k=j+1|0;if(!(k>>>0<2147483647>>>0)){l=3;break}m=(a+1|0)>>>1&65535;a=(b+1|0)>>>1&65535;if((m&65535)>>>0>1>>>0|(a&65535)>>>0>1>>>0){e=a;f=j;g=m}else{h=k;l=5;break}}if((l|0)==3){KIb(0,0,2451448,(g=i,i=i+24|0,c[g>>2]=2362160,c[g+8>>2]=2297480,c[g+16>>2]=44,g)|0);i=g;Hd();return 0}else if((l|0)==5){i=d;return h|0}return 0}function QNa(a){a=a|0;JNa();sUa();return}function RNa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0.0,Dd=0.0,Ed=0.0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0;l=i;i=i+34248|0;m=l|0;n=l+88|0;o=l+384|0;p=l+34232|0;q=c[f+60>>2]|0;r=q;s=h;c[p>>2]=s;c[p+4>>2]=0;c[p+8>>2]=0;t=q+4|0;c[t>>2]=f;u=q+8|0;v=c[k+24>>2]|0;w=c[k+28>>2]|0;if(!((w|0)>-1)){KIb(0,0,2246608,(x=i,i=i+24|0,c[x>>2]=2317640,c[x+8>>2]=2312968,c[x+16>>2]=135,x)|0);i=x;Hd();return 0}k=u;c[k>>2]=v;y=q+16|0;c[y>>2]=v;z=v+w|0;A=q+12|0;c[A>>2]=z;B=q+2664|0;c[B>>2]=-1;C=q+1128|0;mrc(C|0,-1|0,16)|0;a:do{if(w>>>0<2>>>0){D=-1094995529}else{b:do{if(w>>>0>11>>>0){E=v+4|0;c[k>>2]=E;F=v;if((d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)!=201326592){H=65;break}F=v+8|0;c[k>>2]=F;I=E;if((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)!=538988650){H=65;break}I=v+12|0;c[k>>2]=I;E=F;if((d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)!=176622093){H=65;break}E=q+96|0;F=q+1124|0;J=10;K=I;I=z;L=v;while(1){M=I;if(!((M-K|0)>>>0>7>>>0)){break}N=K+4|0;c[k>>2]=N;O=K;P=je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;O=K+8|0;c[k>>2]=O;Q=N;N=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=O;R=Q-8+P-L|0;if((N|0)==1664249962){S=O;T=I;U=L;break b}if((M-Q|0)>>>0<P>>>0|R>>>0<P>>>0){break}c:do{if((N|0)==1748136042&P>>>0>15>>>0){Q=I;M=O;V=L;while(1){W=M+4|0;c[k>>2]=W;X=M;Y=je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0;X=M+8|0;c[k>>2]=X;Z=qc(-8-V+X|0,Y|0)|0;_=Z;if(Y>>>0<8>>>0|_>>>0>R>>>0|G){$=J;aa=Q;ba=V;break c}Z=W;W=je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0;d:do{if((W|0)==1785737827){S=X;T=Q;U=V;break b}else if((W|0)==1885564018){if(!(Y>>>0>5>>>0)){H=56;break}Z=M+10|0;c[k>>2]=Z;da=X;ea=(d[da]|d[da+1|0]<<8)<<16>>16;da=he(ea|0)|0;fa=da&65535;ga=M+11|0;c[k>>2]=ga;ha=a[Z]|0;Z=M+12|0;c[k>>2]=Z;ia=a[ga]&127;ga=ia+1|0;ja=M+13|0;c[k>>2]=ja;ka=a[Z]&127;Z=ka+1|0;la=M+14|0;c[k>>2]=la;ma=a[ja]&127;ja=ma+1|0;if(ha<<24>>24!=3|(da&65535)>>>0>256>>>0|ga>>>0>16>>>0|Z>>>0>16>>>0|ja>>>0>16>>>0|Y>>>0<(ca(((ka+8|0)>>>3)+((ia+8|0)>>>3)+((ma+8|0)>>>3)|0,fa)|0)>>>0){QIb(c[t>>2]|0,2322672,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;da=c[A>>2]|0;ha=c[y>>2]|0;na=da-ha|0;if((_|0)<0){oa=0}else{oa=(na|0)<(_|0)?na:_}pa=ha+oa|0;qa=da;ra=ha;break}a[F]=1;if(ea<<16>>16==0){H=56;break}ea=7-ia|0;ha=Z>>>0<9>>>0;da=7-ka|0;na=ja>>>0<9>>>0;sa=7-ma|0;ta=ma-7|0;ma=ka-7|0;ka=ia-7|0;if(ga>>>0<9>>>0){ia=0;ua=la;while(1){va=ua+1|0;c[k>>2]=va;wa=d[ua]<<ea;xa=wa>>>(ga>>>0)|wa;if(ha){wa=ua+2|0;c[k>>2]=wa;ya=d[va]<<da;za=xa>>>(Z>>>0)|xa;Aa=wa}else{wa=ua+3|0;c[k>>2]=wa;Ba=va;ya=((he((d[Ba]|d[Ba+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ma>>>0);za=xa;Aa=wa}if(na){c[k>>2]=Aa+1;Ca=d[Aa]<<sa;Da=za>>>(ja>>>0)|za}else{c[k>>2]=Aa+2;wa=Aa;Ca=((he((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ta>>>0);Da=za}c[r+100+(ia<<2)>>2]=ya<<8|Da<<16|Ca|-16777216;wa=ia+1|0;if((wa|0)>=(fa|0)){H=56;break d}ia=wa;ua=c[k>>2]|0}}if(ha){ua=0;ia=la;while(1){ga=ia+2|0;c[k>>2]=ga;ea=ia;wa=((he((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ka>>>0);ea=ia+3|0;c[k>>2]=ea;xa=wa>>>(Z>>>0)|wa;wa=d[ga]<<da<<8;if(na){c[k>>2]=ia+4;Ea=d[ea]<<sa;Fa=xa>>>(ja>>>0)|xa}else{c[k>>2]=ia+5;ga=ea;Ea=((he((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ta>>>0);Fa=xa}c[r+100+(ua<<2)>>2]=wa|Fa<<16|Ea|-16777216;wa=ua+1|0;if((wa|0)>=(fa|0)){H=56;break d}ua=wa;ia=c[k>>2]|0}}else{ia=0;ua=la;while(1){da=ua+2|0;c[k>>2]=da;Z=ua;ha=((he((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ka>>>0);Z=ua+4|0;c[k>>2]=Z;wa=da;da=((he((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ma>>>0)<<8;if(na){c[k>>2]=ua+5;Ga=d[Z]<<sa;Ha=ha>>>(ja>>>0)|ha}else{c[k>>2]=ua+6;wa=Z;Ga=((he((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)>>>(ta>>>0);Ha=ha}c[r+100+(ia<<2)>>2]=da|Ha<<16|Ga|-16777216;da=ia+1|0;if((da|0)>=(fa|0)){H=56;break d}ia=da;ua=c[k>>2]|0}}}else if((W|0)==1667523942){if(!(Y>>>0>1>>>0)){H=56;break}ua=M+10|0;c[k>>2]=ua;ia=X;fa=(d[ia]|d[ia+1|0]<<8)<<16>>16;if(fa<<16>>16==0){H=56;break}ia=(he(fa|0)|0)&65535;fa=Q;ta=ua;while(1){ua=fa;if((ua-ta|0)<2){Ia=0;Ja=ta}else{ja=ta+2|0;c[k>>2]=ja;sa=ta;Ia=(he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535;Ja=ja}if((ua-Ja|0)<2){Ka=Ja}else{ja=Ja+2|0;c[k>>2]=ja;Ka=ja}if((ua-Ka|0)<2){La=0;H=53}else{c[k>>2]=Ka+2;ua=Ka;ja=he((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0;if(Ia>>>0<4>>>0|(ja&65535)>>>0<4>>>0){La=ja&65535;H=53}}if((H|0)==53){H=0;c[r+1128+(Ia<<2)>>2]=La}ja=ia-1|0;if((ja|0)<=0){H=56;break d}ia=ja;fa=c[A>>2]|0;ta=c[k>>2]|0}}else if((W|0)==1668246642){if(!(Y>>>0>6>>>0)){H=56;break}c[k>>2]=M+9;ta=a[X]|0;fa=M+11|0;c[k>>2]=fa;if(!(ta<<24>>24==1)){H=56;break}c[k>>2]=M+15;ta=fa;c[E>>2]=je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0;H=56}else{H=56}}while(0);if((H|0)==56){H=0;X=c[A>>2]|0;Y=c[y>>2]|0;W=X-Y|0;if((_|0)<0){Ma=0}else{Ma=(W|0)<(_|0)?W:_}pa=Y+Ma|0;qa=X;ra=Y}c[k>>2]=pa;if((R-_|0)>>>0>7>>>0){Q=qa;M=pa;V=ra}else{$=J;aa=qa;ba=ra;break}}}else{$=J-1|0;aa=I;ba=L}}while(0);O=aa-ba|0;if((R|0)<0){Na=0}else{Na=(O|0)<(R|0)?O:R}O=ba+Na|0;c[k>>2]=O;if(($|0)==0){break}else{J=$;K=O;I=aa;L=ba}}KIb(f,16,2451400,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break a}else{H=65}}while(0);if((H|0)==65){L=v+((w|0)<0?w:0)|0;c[k>>2]=L;S=L;T=z;U=v}L=T;I=L-S|0;e:do{if(I>>>0>2>>>0){K=S;J=I;while(1){if((J|0)>=2){E=K;if((d[E]|d[E+1|0]<<8)<<16>>16<<16>>16==20479){Oa=K;break e}}E=L-K|0;F=K+(E>>>0>1>>>0?1:E)|0;c[k>>2]=F;E=L-F|0;if(E>>>0>2>>>0){K=F;J=E}else{Oa=F;break}}}else{Oa=S}}while(0);L=Oa+2|0;c[k>>2]=L;I=Oa;if(!((d[I]|d[I+1|0]<<8)<<16>>16<<16>>16==20479)){KIb(f,16,2362136,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break}I=q+1164|0;J=q+1500|0;K=q+2668|0;F=q+1156|0;E=q+1152|0;O=q+20|0;P=q+24|0;N=q+28|0;V=q+32|0;M=q+1144|0;Q=q+1148|0;Y=q+36|0;X=q+40|0;W=q+92|0;ta=q+2672|0;fa=q+88|0;ia=q+1124|0;ja=q+96|0;ua=q+60|0;sa=q+76|0;na=q+64|0;ma=q+80|0;ka=m;la=m+11|0;da=m+15|0;ha=m+12|0;wa=m+13|0;Z=n|0;xa=I;ga=J;ea=q+52|0;Ba=L;L=T;va=U;f:while(1){if((L-Ba|0)>>>0<2>>>0){H=74;break}else{Pa=Ba;Qa=L;Ra=va}while(1){Sa=Pa+2|0;c[k>>2]=Sa;Ta=Pa;Ua=(he((d[Ta]|d[Ta+1|0]<<8)<<16>>16|0)|0)&65535;Va=Sa;Wa=Ra;if((Ua|0)==65497){break f}else if((Ua|0)!=65427){break}Ta=c[K>>2]|0;if((Ta|0)==0){H=77;break f}Xa=c[B>>2]|0;if((Xa|0)<0){H=79;break f}Ya=e[Ta+(Xa*1588|0)+1584>>1]|0;Za=c[Ta+(Xa*1588|0)+1504+(Ya*20|0)+4>>2]|0;if(Za>>>0<Sa>>>0){H=81;break f}_a=Za;Za=_a-Va|0;if(!((Za|0)>-1)){H=83;break f}c[Ta+(Xa*1588|0)+1504+(Ya*20|0)+8>>2]=Sa;c[Ta+(Xa*1588|0)+1504+(Ya*20|0)+16>>2]=Sa;c[Ta+(Xa*1588|0)+1504+(Ya*20|0)+12>>2]=Pa+(Za+2);Za=c[k>>2]|0;Ya=Za;Xa=_a-Ya|0;_a=c[A>>2]|0;Ta=_a;$a=Ta-Ya|0;Ya=Za+($a>>>0>Xa>>>0?Xa:$a)|0;c[k>>2]=Ya;if((Ta-Ya|0)>>>0<2>>>0){H=74;break f}Pa=Ya;Qa=_a;Ra=c[y>>2]|0}_a=Qa;if((_a-Va|0)<2){D=-1094995529;break a}Ya=Pa+4|0;c[k>>2]=Ya;Ta=Sa;$a=he((d[Ta]|d[Ta+1|0]<<8)<<16>>16|0)|0;Ta=$a&65535;if(($a&65535)>>>0<2>>>0){D=-1094995529;break a}$a=Ya;Xa=_a-$a|0;Za=Ta-2|0;if(Xa>>>0<Za>>>0){D=-1094995529;break a}g:do{switch(Ua|0){case 65363:{if(Xa>>>0<2>>>0){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}eb=Pa+5|0;c[k>>2]=eb;fb=d[Ya]|0;gb=c[W>>2]|0;if((fb|0)>=(gb|0)){KIb(c[t>>2]|0,16,2410928,(x=i,i=i+16|0,c[x>>2]=fb,c[x+8>>2]=gb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1094995529;break g}c[k>>2]=Pa+6;a[xa+(fb*84|0)+11|0]=a[eb]|0;eb=WNa(r,xa+(fb*84|0)|0)|0;if((eb|0)<0){ab=xa;bb=ga;cb=ea;db=eb;break g}eb=ea+fb|0;a[eb]=a[eb]|1;ab=xa;bb=ga;cb=ea;db=0;break};case 65372:{mrc(Z|0,0,290)|0;eb=VNa(r,Ta,n)|0;if((eb|0)<0){ab=xa;bb=ga;cb=ea;db=eb;break g}eb=c[W>>2]|0;if((eb|0)>0){hb=0;ib=eb}else{ab=xa;bb=ga;cb=ea;db=0;break g}while(1){if((a[ea+hb|0]&2)==0){nrc(ga+(hb*290|0)|0,Z|0,290)|0;jb=c[W>>2]|0}else{jb=ib}eb=hb+1|0;if((eb|0)<(jb|0)){hb=eb;ib=jb}else{ab=xa;bb=ga;cb=ea;db=0;break}}break};case 65373:{if((Qa|0)==(Ya|0)){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}c[k>>2]=Pa+5;R=d[Ya]|0;eb=c[W>>2]|0;if((R|0)<(eb|0)){fb=ea+R|0;a[fb]=a[fb]|2;ab=xa;bb=ga;cb=ea;db=VNa(r,Ta-1|0,ga+(R*290|0)|0)|0;break g}else{KIb(c[t>>2]|0,16,2410928,(x=i,i=i+16|0,c[x>>2]=R,c[x+8>>2]=eb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1094995529;break g}break};case 65362:{if(Xa>>>0<5>>>0){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}eb=Pa+5|0;c[k>>2]=eb;a[la]=a[Ya]|0;R=Pa+6|0;c[k>>2]=R;a[da]=a[eb]|0;eb=Pa+8|0;c[k>>2]=eb;fb=R;a[ha]=((d[fb]|d[fb+1|0]<<8)<<16>>16&65535)>>>8;c[k>>2]=Pa+9;fb=a[eb]|0;eb=fb&255;a[wa]=fb;do{if(!(fb<<24>>24==0)){R=c[W>>2]|0;if((R|0)>=3){break}KIb(c[t>>2]|0,16,2403256,(x=i,i=i+16|0,c[x>>2]=eb,c[x+8>>2]=R,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1094995529;break g}}while(0);eb=WNa(r,m)|0;if((eb|0)<0){ab=xa;bb=ga;cb=ea;db=eb;break g}eb=c[W>>2]|0;if((eb|0)>0){kb=0;lb=eb}else{ab=xa;bb=ga;cb=ea;db=0;break g}while(1){if((a[ea+kb|0]&1)==0){nrc(xa+(kb*84|0)|0,ka|0,84)|0;mb=c[W>>2]|0}else{mb=lb}eb=kb+1|0;if((eb|0)<(mb|0)){kb=eb;lb=mb}else{ab=xa;bb=ga;cb=ea;db=0;break}}break};case 65361:{h:do{if(Xa>>>0<36>>>0){nb=-1094995529}else{eb=Pa+6|0;c[k>>2]=eb;fb=Ya;R=(he((d[fb]|d[fb+1|0]<<8)<<16>>16|0)|0)&65535;fb=c[t>>2]|0;c[fb+840>>2]=R;R=Pa+10|0;c[k>>2]=R;gb=eb;c[O>>2]=je(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0;gb=Pa+14|0;c[k>>2]=gb;eb=R;c[P>>2]=je(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0;eb=Pa+18|0;c[k>>2]=eb;R=gb;gb=d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0;c[N>>2]=je(gb|0)|0;R=Pa+22|0;c[k>>2]=R;ob=eb;eb=d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0;c[V>>2]=je(eb|0)|0;ob=Pa+26|0;c[k>>2]=ob;pb=R;R=je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0;c[M>>2]=R;pb=Pa+30|0;c[k>>2]=pb;qb=ob;ob=je(d[qb]|d[qb+1|0]<<8|d[qb+2|0]<<16|d[qb+3|0]<<24|0)|0;c[Q>>2]=ob;qb=Pa+34|0;c[k>>2]=qb;rb=pb;c[Y>>2]=je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0;rb=Pa+38|0;c[k>>2]=rb;pb=qb;c[X>>2]=je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0;pb=Pa+40|0;c[k>>2]=pb;qb=rb;rb=(d[qb]|d[qb+1|0]<<8)<<16>>16;qb=he(rb|0)|0;sb=qb&65535;if((eb|gb|0)!=0){QIb(fb,2354424,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;nb=-1163346256;break}if(rb<<16>>16==0){KIb(fb,16,2345592,(x=i,i=i+8|0,c[x>>2]=c[W>>2],x)|0);i=x;nb=-1094995529;break}if((qb&65535)>>>0>4>>>0){QIb(fb,2420288,(x=i,i=i+8|0,c[x>>2]=c[W>>2],x)|0);i=x;nb=-1163346256;break}c[W>>2]=sb;if((R|0)<1|(ob|0)<1){KIb(fb,16,2339560,(x=i,i=i+16|0,c[x>>2]=R,c[x+8>>2]=ob,x)|0);i=x;nb=-1094995529;break}if((_a-pb|0)>>>0<(sb*3|0)>>>0){nb=-1094995529;break}else{tb=0;ub=0;vb=pb}while(1){c[k>>2]=vb+1;pb=a[vb]|0;ob=(pb&127)+1|0;a[r+44+ub|0]=ob;R=ob&255;ob=c[fa>>2]|0;c[fa>>2]=(R|0)>(ob|0)?R:ob;a[r+48+ub|0]=(pb&255)>>>7;pb=c[k>>2]|0;c[k>>2]=pb+1;ob=r+56+(ub<<2)|0;c[ob>>2]=d[pb]|0;pb=c[k>>2]|0;c[k>>2]=pb+1;R=a[pb]|0;wb=R&255;c[r+72+(ub<<2)>>2]=wb;xb=c[ob>>2]|0;if((xb|0)==0|(xb|0)==3){H=102;break}if((xb|0)>4|R<<24>>24==0|R<<24>>24==3|(R&255)>>>0>4>>>0){H=102;break}R=ub<<2;yb=xb>>1<<(R|2)|tb|wb>>>1<<R;R=ub+1|0;if((R|0)>=(c[W>>2]|0)){break}tb=yb;ub=R;vb=c[k>>2]|0}if((H|0)==102){H=0;KIb(c[t>>2]|0,16,2333824,(x=i,i=i+16|0,c[x>>2]=xb,c[x+8>>2]=wb,x)|0);i=x;nb=-1094995529;break}R=c[M>>2]|0;ob=c[P>>2]|0;pb=c[X>>2]|0;fb=c[Q>>2]|0;rb=((c[O>>2]|0)-1-(c[Y>>2]|0)+R|0)/(R|0)|0;c[E>>2]=rb;R=(ob-1-pb+fb|0)/(fb|0)|0;c[F>>2]=R;fb=Erc(R,0,rb,0)|0;pb=G;ob=0;if(pb>>>0>ob>>>0|pb>>>0==ob>>>0&fb>>>0>1352319>>>0){c[F>>2]=0;c[E>>2]=0;nb=-22;break}fb=ca(R,rb)|0;do{if(fb>>>0>1352318>>>0){c[K>>2]=0}else{rb=pJb(fb*1588|0)|0;c[K>>2]=rb;if((rb|0)==0){break}else{zb=0}while(1){if(!(zb>>>0<(ca(c[F>>2]|0,c[E>>2]|0)|0)>>>0)){break}rb=c[K>>2]|0;R=pJb((c[W>>2]|0)*232|0)|0;c[rb+(zb*1588|0)>>2]=R;if((R|0)==0){nb=-12;break h}else{zb=zb+1|0}}_=c[ta>>2]|0;R=c[t>>2]|0;c[R+120>>2]=(c[O>>2]|0)-1-(c[N>>2]|0)+(1<<_)>>_;_=c[ta>>2]|0;c[R+124>>2]=(c[P>>2]|0)-1-(c[V>>2]|0)+(1<<_)>>_;do{if(((c[R+840>>2]|0)-3|0)>>>0<2>>>0){Ab=1;Bb=1992}else{_=c[ja>>2]|0;if((_|0)==16){Ab=5;Bb=679560;break}else if((_|0)==17){Ab=3;Bb=1146920;break}else if((_|0)==18){Ab=33;Bb=744;break}else{Ab=42;Bb=2022344;break}}}while(0);R=yb>>>10&3;_=yb>>>8&3;rb=yb>>>6&3;ob=yb>>>4&3;pb=(yb&61440|0)!=0;gb=(yb&15|0)!=0;eb=0;i:while(1){Cb=c[Bb+(eb<<2)>>2]|0;Db=c[fa>>2]|0;Eb=a[ia]|0;Fb=qKb(Cb)|0;do{if((d[Fb+4|0]|0)==(sb|0)){if((sb|0)==4){if((((e[Fb+14>>1]|0)>>>11&15)+1|0)<(Db|0)|pb){break}else{H=122}}else if((sb|0)==3){H=122}else if((sb|0)==2){H=125}else if((sb|0)!=1){H=130;break i}if((H|0)==122){H=0;if((((e[Fb+12>>1]|0)>>>11&15)+1|0)<(Db|0)){break}if((R|0)!=(d[Fb+5|0]|0)){break}if((_|0)==(d[Fb+6|0]|0)){H=125}else{break}}if((H|0)==125){H=0;if((((e[Fb+10>>1]|0)>>>11&15)+1|0)<(Db|0)){break}if((rb|0)!=(d[Fb+5|0]|0)){break}if((ob|0)!=(d[Fb+6|0]|0)){break}}if((((e[Fb+8>>1]|0)>>>11&15)+1|0)<(Db|0)|gb){break}if((a[Fb+7|0]&2|0)==(Eb<<1|0)){H=130;break i}}}while(0);Eb=eb+1|0;if((Eb|0)<(Ab|0)){eb=Eb}else{Gb=Eb;break}}if((H|0)==130){H=0;c[(c[t>>2]|0)+140>>2]=Cb;Gb=eb}if((Gb|0)!=(Ab|0)){c[(c[t>>2]|0)+796>>2]=c[fa>>2];nb=0;break h}gb=c[t>>2]|0;ob=c[ja>>2]|0;rb=c[fa>>2]|0;if((qb&65535)>>>0>2>>>0){Hb=c[ma>>2]|0;Ib=c[sa>>2]|0;Jb=c[ua>>2]|0;Kb=c[na>>2]|0}else{Hb=0;Ib=0;Jb=0;Kb=0}KIb(gb,16,2328400,(x=i,i=i+64|0,c[x>>2]=c[gb+840>>2],c[x+8>>2]=ob,c[x+16>>2]=sb,c[x+24>>2]=rb,c[x+32>>2]=Jb,c[x+40>>2]=Ib,c[x+48>>2]=Kb,c[x+56>>2]=Hb,x)|0);i=x;nb=-1163346256;break h}}while(0);c[F>>2]=0;c[E>>2]=0;nb=-12}}while(0);if((c[K>>2]|0)!=0){ab=xa;bb=ga;cb=ea;db=nb;break g}c[F>>2]=0;c[E>>2]=0;ab=xa;bb=ga;cb=ea;db=nb;break};case 65424:{if(Xa>>>0<8>>>0){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}c[B>>2]=0;sb=Pa+6|0;c[k>>2]=sb;qb=Ya;fb=he((d[qb]|d[qb+1|0]<<8)<<16>>16|0)|0;qb=fb&65535;if(!(qb>>>0<(ca(c[F>>2]|0,c[E>>2]|0)|0)>>>0)){ab=xa;bb=ga;cb=ea;db=-1094995529;break g}c[B>>2]=qb;rb=Pa+10|0;c[k>>2]=rb;ob=sb;sb=je(d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0)|0;c[k>>2]=Pa+11;ob=a[rb]|0;rb=ob&255;gb=Pa+12|0;c[k>>2]=gb;if(sb>>>0>(_a+2-gb+Ta|0)>>>0){KIb(c[t>>2]|0,16,2430544,(x=i,i=i+8|0,c[x>>2]=sb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1094995529;break g}if((ob&255)>>>0>3>>>0){QIb(c[t>>2]|0,2420288,(x=i,i=i+8|0,c[x>>2]=rb,x)|0);i=x;ab=xa;bb=ga;cb=ea;db=-1163346256;break g}gb=c[K>>2]|0;b[gb+(qb*1588|0)+1584>>1]=ob&255;a[gb+(qb*1588|0)+1504+(rb*20|0)|0]=fb;c[gb+(qb*1588|0)+1504+(rb*20|0)+4>>2]=(c[k>>2]|0)+(-2-Ta+sb);if(ob<<24>>24==0){ob=c[K>>2]|0;sb=c[B>>2]|0;nrc(ob+(sb*1588|0)+8|0,I|0,(c[W>>2]|0)*84|0)|0;nrc(ob+(sb*1588|0)+344|0,J|0,(c[W>>2]|0)*290|0)|0}sb=c[B>>2]|0;ob=c[K>>2]|0;ab=ob+(sb*1588|0)+8|0;bb=ob+(sb*1588|0)+344|0;cb=ob+(sb*1588|0)+4|0;db=0;break};case 65380:{c[k>>2]=Pa+((Xa>>>0>Za>>>0?Za:Xa)+4);ab=xa;bb=ga;cb=ea;db=0;break};case 65365:{if((Xa|0)<1){Lb=Ya}else{sb=Pa+5|0;c[k>>2]=sb;Lb=sb}if((_a-Lb|0)<1){Mb=0;Nb=Lb}else{sb=Lb+1|0;c[k>>2]=sb;Mb=d[Lb]|0;Nb=sb}sb=Mb>>>6&1;ob=Mb>>>4&3;rb=((Ta-4|0)/(ob+2+(sb<<1)|0)|0)&255;if((rb|0)==0){ab=xa;bb=ga;cb=ea;db=0;break g}qb=(sb|0)==0;sb=0;gb=Nb;while(1){do{if((ob|0)==1){if((_a-gb|0)<1){Ob=gb;break}fb=gb+1|0;c[k>>2]=fb;Ob=fb}else if((ob|0)==2){if((_a-gb|0)<2){Ob=gb;break}fb=gb+2|0;c[k>>2]=fb;Ob=fb}else if((ob|0)==3){if((_a-gb|0)<4){Ob=gb;break}fb=gb+4|0;c[k>>2]=fb;Ob=fb}else{Ob=gb}}while(0);fb=_a-Ob|0;do{if(qb){if((fb|0)<2){Pb=Ob;break}_=Ob+2|0;c[k>>2]=_;Pb=_}else{if((fb|0)<4){Pb=Ob;break}_=Ob+4|0;c[k>>2]=_;Pb=_}}while(0);fb=sb+1&255;if((fb&255)>>>0<rb>>>0){sb=fb;gb=Pb}else{ab=xa;bb=ga;cb=ea;db=0;break}}break};default:{KIb(c[t>>2]|0,16,2459440,(x=i,i=i+16|0,c[x>>2]=Ua,c[x+8>>2]=$a-4-Wa,x)|0);i=x;gb=c[k>>2]|0;sb=(c[A>>2]|0)-gb|0;c[k>>2]=gb+(sb>>>0>Za>>>0?Za:sb);ab=xa;bb=ga;cb=ea;db=0}}}while(0);Za=c[k>>2]|0;$a=c[y>>2]|0;if(!((Wa-Va+Za-$a|0)==(Ta|0)&(db|0)==0)){H=194;break}xa=ab;ga=bb;ea=cb;Ba=Za;L=c[A>>2]|0;va=$a}if((H|0)==74){KIb(c[t>>2]|0,16,2502368,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}else if((H|0)==77){KIb(c[t>>2]|0,16,2489288,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break}else if((H|0)==79){KIb(c[t>>2]|0,16,2478288,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break}else if((H|0)==81){KIb(c[t>>2]|0,16,2468688,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;D=-1094995529;break}else if((H|0)==83){KIb(0,0,2246608,(x=i,i=i+24|0,c[x>>2]=2317640,c[x+8>>2]=2312968,c[x+16>>2]=135,x)|0);i=x;Hd();return 0}else if((H|0)==194){KIb(c[t>>2]|0,16,2442696,(x=i,i=i+8|0,c[x>>2]=Ua,x)|0);i=x;va=(db|0)!=0?db:-1;if((va|0)!=0){D=va;break}}va=J5a(f,p,0)|0;if((va|0)<0){D=va;break}c[h+88>>2]=1;c[h+84>>2]=1;va=q+2660|0;L=0;while(1){Ba=c[E>>2]|0;Qb=ca(c[F>>2]|0,Ba)|0;if(!(L>>>0<Qb>>>0)){break}ea=c[K>>2]|0;ga=(L>>>0)%(Ba>>>0)|0;xa=(L>>>0)/(Ba>>>0)|0;Ba=ea+(L*1588|0)|0;if((c[Ba>>2]|0)==0){D=-12;break a}J=ga+1|0;I=xa+1|0;na=0;while(1){Rb=c[W>>2]|0;if((na|0)>=(Rb|0)){break}ua=c[Ba>>2]|0;sa=c[M>>2]|0;ma=ca(sa,ga)|0;ja=c[Y>>2]|0;ia=ma+ja|0;ma=c[N>>2]|0;ka=(ia|0)>(ma|0)?ia:ma;b[ua+(na*232|0)+224>>1]=ka;ma=(ca(sa,J)|0)+ja|0;ja=c[O>>2]|0;sa=(ma|0)>(ja|0)?ja:ma;b[ua+(na*232|0)+226>>1]=sa;ma=c[Q>>2]|0;ja=ca(ma,xa)|0;ia=c[X>>2]|0;wa=ja+ia|0;ja=c[V>>2]|0;ha=(wa|0)>(ja|0)?wa:ja;b[ua+(na*232|0)+228>>1]=ha;ja=(ca(ma,I)|0)+ia|0;ia=c[P>>2]|0;ma=(ja|0)>(ia|0)?ia:ja;b[ua+(na*232|0)+230>>1]=ma;ja=c[ta>>2]|0;ia=1<<ja;b[ua+(na*232|0)+216>>1]=(ka&65535)-1+ia>>ja;b[ua+(na*232|0)+218>>1]=(sa&65535)-1+ia>>ja;b[ua+(na*232|0)+220>>1]=(ha&65535)-1+ia>>ja;b[ua+(na*232|0)+222>>1]=ia-1+(ma&65535)>>ja;ja=LNa(ua+(na*232|0)|0,ea+(L*1588|0)+8+(na*84|0)|0,ea+(L*1588|0)+344+(na*290|0)|0,d[r+44+na|0]|0,c[r+56+(na<<2)>>2]|0,c[r+72+(na<<2)>>2]|0,c[t>>2]|0)|0;if((ja|0)!=0){D=ja;break a}na=na+1|0}na=ea+(L*1588|0)|0;I=ea+(L*1588|0)+1512|0;c[u>>2]=c[I>>2];c[u+4>>2]=c[I+4>>2];c[u+8>>2]=c[I+8>>2];c[va>>2]=8;j:do{switch(d[ea+(L*1588|0)+23|0]|0){case 2:{QIb(c[t>>2]|0,2616480,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Sb=-1163346256;break};case 3:{QIb(c[t>>2]|0,2589184,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Sb=-1163346256;break};case 0:{H=209;break};case 4:{if((Rb|0)<=0){Sb=0;break j}I=na|0;xa=ea+(L*1588|0)+20|0;J=0;ga=0;Ba=c[P>>2]|0;Ta=Rb;while(1){ja=ea+(L*1588|0)+8+(J*84|0)|0;ua=ea+(L*1588|0)+1504+(J*20|0)+8|0;c[u>>2]=c[ua>>2];c[u+4>>2]=c[ua+4>>2];c[u+8>>2]=c[ua+8>>2];if((Ba|0)>0){ua=ja|0;ma=ea+(L*1588|0)+344+(J*290|0)+289|0;ia=0;ha=ga;sa=c[O>>2]|0;ka=Ba;while(1){if((sa|0)>0){wa=(ia|0)==0;da=ia-1|0;la=0;Z=ha;$a=c[ua>>2]|0;Za=sa;while(1){if(($a|0)>0){_a=(la|0)==0;Ya=la-1|0;Xa=0;sb=Z;gb=$a;while(1){rb=c[(c[I>>2]|0)+(J*232|0)>>2]|0;qb=rb+(Xa*20|0)|0;ob=d[rb+(Xa*20|0)+15|0]|0;fb=gb+255-Xa&255;do{if(((ia|0)%(1<<ob+fb|0)|0|0)==0|wa){_=d[rb+(Xa*20|0)+14|0]|0;if(!(((la|0)%(1<<_+fb|0)|0|0)==0|_a)){Tb=sb;Ub=gb;break}R=1<<fb;pb=Ya+R>>fb>>_&65535;_=e[rb+(Xa*20|0)+10>>1]|0;Eb=da+R>>fb>>ob&65535;R=(ca(_,Eb)|0)+pb|0;if(!(pb>>>0<_>>>0)){D=-1163346256;break a}if(!(Eb>>>0<(e[rb+(Xa*20|0)+12>>1]|0)>>>0)){D=-1163346256;break a}Eb=((Xa|0)==0?0:(Xa*3|0)-2|0)+(ea+(L*1588|0)+344+(J*290|0))|0;_=sb;pb=0;while(1){if((pb|0)>=(d[xa]|0)){break}Fb=TNa(r,ja,qb,R,pb,Eb,d[ma]|0)|0;if((Fb|0)<0){D=Fb;break a}_=Fb;pb=pb+1|0}Tb=_;Ub=c[ua>>2]|0}else{Tb=sb;Ub=gb}}while(0);qb=Xa+1|0;if((qb|0)<(Ub|0)){Xa=qb;sb=Tb;gb=Ub}else{break}}Vb=Tb;Wb=Ub;Xb=c[O>>2]|0}else{Vb=Z;Wb=$a;Xb=Za}gb=la+256|0;if((gb|0)<(Xb|0)){la=gb;Z=Vb;$a=Wb;Za=Xb}else{break}}Yb=Vb;Zb=Xb;_b=c[P>>2]|0}else{Yb=ha;Zb=sa;_b=ka}Za=ia+256|0;if((Za|0)<(_b|0)){ia=Za;ha=Yb;sa=Zb;ka=_b}else{break}}$b=Yb;ac=_b;bc=c[W>>2]|0}else{$b=ga;ac=Ba;bc=Ta}ka=J+1|0;if((ka|0)<(bc|0)){J=ka;ga=$b;Ba=ac;Ta=bc}else{Sb=$b;break}}break};case 1:{QIb(c[t>>2]|0,2639104,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;H=209;break};default:{Sb=0}}}while(0);do{if((H|0)==209){H=0;Ta=ea+(L*1588|0)+20|0;if((a[Ta]|0)==0){Sb=0;break}Ba=na|0;ga=0;J=0;xa=c[W>>2]|0;while(1){I=0;ka=J;sa=xa;while(1){if((sa|0)<=0){cc=sa;dc=ka;break}ha=(I|0)==0?0:(I*3|0)-2|0;ia=0;ua=0;ma=ka;ja=sa;while(1){Za=ea+(L*1588|0)+8+(ua*84|0)|0;if((I|0)<(c[Za>>2]|0)){$a=c[(c[Ba>>2]|0)+(ua*232|0)>>2]|0;Z=$a+(I*20|0)|0;la=$a+(I*20|0)+10|0;da=$a+(I*20|0)+12|0;$a=ea+(L*1588|0)+344+(ua*290|0)+289|0;wa=ea+(L*1588|0)+344+(ua*290|0)+ha|0;eb=ma;gb=0;while(1){if((gb|0)>=(ca(e[da>>1]|0,e[la>>1]|0)|0)){break}sb=TNa(r,Za,Z,gb,ga,wa,d[$a]|0)|0;if((sb|0)<0){D=sb;break a}else{eb=sb;gb=gb+1|0}}ec=eb;fc=1;gc=c[W>>2]|0}else{ec=ma;fc=ia;gc=ja}gb=ua+1|0;if((gb|0)<(gc|0)){ia=fc;ua=gb;ma=ec;ja=gc}else{break}}if((fc|0)==0){cc=gc;dc=ec;break}else{I=I+1|0;ka=ec;sa=gc}}sa=ga+1|0;if((sa|0)<(d[Ta]|0)){ga=sa;J=dc;xa=cc}else{Sb=dc;break}}}}while(0);ea=c[k>>2]|0;na=(c[A>>2]|0)-ea|0;c[k>>2]=ea+(na>>>0>2>>>0?2:na);if((Sb|0)!=0){D=Sb;break a}L=L+1|0}k:do{if((Qb|0)!=0){L=o+33808|0;P=o+33846|0;O=o+33845|0;va=C;ta=0;l:while(1){X=c[K>>2]|0;Q=X+(ta*1588|0)|0;Y=qKb(c[(c[t>>2]|0)+140>>2]|0)|0;M=(a[Y+7|0]&16)!=0;na=M^1;if(M){hc=1}else{hc=d[Y+4|0]|0}if((c[W>>2]|0)>0){Y=Q|0;ea=0;do{xa=c[Y>>2]|0;J=X+(ta*1588|0)+8+(ea*84|0)+4|0;ga=c[J>>2]|0;if((ga|0)>0){Ta=xa+(ea*232|0)|0;Ba=X+(ta*1588|0)+8+(ea*84|0)+14|0;sa=X+(ta*1588|0)+8+(ea*84|0)+10|0;ka=xa+(ea*232|0)+218|0;I=xa+(ea*232|0)+216|0;ja=xa+(ea*232|0)+208|0;ma=xa+(ea*232|0)+212|0;ua=0;ia=ga;while(1){ga=c[Ta>>2]|0;ha=ga+(ua*20|0)|0;gb=a[ha]|0;if(gb<<24>>24==0){ic=ia}else{$a=ga+(ua*20|0)+16|0;wa=(ua|0)>0|0;Z=ga+(ua*20|0)+10|0;Za=ga+(ua*20|0)+12|0;ga=0;la=gb;while(1){gb=c[$a>>2]|0;da=ga+wa|0;do{if((b[gb+(ga*24|0)>>1]|0)==(b[gb+(ga*24|0)+2>>1]|0)){jc=la}else{if((b[gb+(ga*24|0)+4>>1]|0)==(b[gb+(ga*24|0)+6>>1]|0)){jc=la;break}sb=ca(e[Za>>1]|0,e[Z>>1]|0)|0;if((sb|0)==0){jc=la;break}Xa=gb+(ga*24|0)+20|0;Ya=gb+(ga*24|0)+16|0;_a=gb+(ga*24|0)+12|0;qb=0;do{rb=c[Xa>>2]|0;ob=rb+(qb*24|0)|0;fb=rb+(qb*24|0)+2|0;if((ca(e[fb>>1]|0,e[ob>>1]|0)|0)!=0){pb=rb+(qb*24|0)+12|0;rb=0;do{Eb=c[pb>>2]|0;R=Eb+(rb*9816|0)+9810|0;Fb=Eb+(rb*9816|0)+9808|0;Db=(e[R>>1]|0)-(e[Fb>>1]|0)|0;kc=Eb+(rb*9816|0)+9814|0;lc=Eb+(rb*9816|0)+9812|0;mc=(e[kc>>1]|0)-(e[lc>>1]|0)|0;nc=a[Eb+(rb*9816|0)|0]|0;oc=nc&255;pc=(d[Eb+(rb*9816|0)+2|0]|0)-1|0;rc=d[Ba]|0;sc=rc&1;tc=rc&8;if((Db|0)>=65){H=264;break l}if((mc|0)>=65){H=268;break l}rc=(mc|0)>0;if(rc){uc=Db<<2;vc=0;do{mrc(o+(vc<<8)|0,0,uc|0)|0;vc=vc+1|0;}while((vc|0)<(mc|0))}vc=Eb+(rb*9816|0)+4|0;uc=b[vc>>1]|0;do{if(!(uc<<16>>16==0)){wc=mc+2|0;if((wc|0)>0){xc=(Db<<2)+8|0;yc=0;do{mrc(o+16384+(yc*264|0)|0,0,xc|0)|0;yc=yc+1|0;}while((yc|0)<(wc|0));zc=b[vc>>1]|0}else{zc=uc}a[(zc&65535)+(Eb+(rb*9816|0)+10)|0]=-1;a[(e[vc>>1]|0)+1+(Eb+(rb*9816|0)+10)|0]=-1;wc=Eb+(rb*9816|0)+10|0;uUa(L,wc);if(nc<<24>>24==0){break}yc=(sc|0)==0;xc=(Db|0)>0;Ac=(tc|0)==0;Bc=(sc|0)!=0;Cc=(tc|0)!=0;Dc=2;Ec=pc;Fc=0;Gc=oc;while(1){Hc=Gc-1|0;do{if((Dc|0)==1){Ic=1<<Ec;Jc=-Ic|0;if(rc){Kc=0;while(1){Mc=Kc+4|0;if(xc){Nc=0;while(1){Oc=Nc+1|0;Pc=Kc;while(1){Qc=Pc+1|0;Rc=o+16384+(Qc*264|0)+(Oc<<2)|0;Sc=c[Rc>>2]|0;if((Sc&12288|0)==8192){Tc=(vUa(L,(d[((Sc&255|0)!=0)+(682080+((Sc>>>14&1)<<1))|0]|0)+(o+33828)|0)|0)!=0;Sc=Tc?Ic:Jc;Tc=o+(Pc<<8)+(Nc<<2)|0;Uc=c[Tc>>2]|0;c[Tc>>2]=((Uc|0)<0?-Sc|0:Sc)+Uc;c[Rc>>2]=c[Rc>>2]|16384}if((Qc|0)<(mc|0)&(Qc|0)<(Mc|0)){Pc=Qc}else{break}}if((Oc|0)<(Db|0)){Nc=Oc}else{break}}}if((Mc|0)<(mc|0)){Kc=Mc}else{break}}}if(!(Bc&(Fc|0)>3)){Vc=Fc;break}uUa(L,wc);Vc=Fc}else if((Dc|0)==0){if(yc){Wc=0}else{Wc=(Fc|0)>3|0}Kc=3<<Ec;if(!rc){Vc=Fc;break}Jc=(Wc|0)==0;Ic=-Kc|0;Nc=0;while(1){Pc=Nc+4|0;if(xc){Qc=Nc|3;Rc=0;while(1){Uc=Rc+1|0;Sc=Nc;while(1){Tc=Sc+1|0;Xc=o+16384+(Tc*264|0)+(Uc<<2)|0;Yc=c[Xc>>2]|0;if((Yc&255|0)!=0&(Yc&12288|0)==0){if(Ac){Zc=255}else{Zc=(Sc|0)==(Qc|0)?55:255}if((vUa(L,(d[7696880+((Zc&Yc)<<2)+da|0]|0)+(o+33828)|0)|0)!=0){Yc=c[Xc>>2]|0;_c=Yc>>>8&15;$c=Yc&15;Yc=a[7696624+($c<<4)+_c|0]|0;ad=vUa(L,(d[7697904+($c<<4)+_c|0]|0)+(o+33828)|0)|0;if(Jc){_c=(ad|0)!=(Yc&255|0)?Ic:Kc;c[o+(Sc<<8)+(Rc<<2)>>2]=_c;bd=_c}else{_c=(ad|0)!=0?Ic:Kc;c[o+(Sc<<8)+(Rc<<2)>>2]=_c;bd=_c}KNa(o,Rc,Sc,bd>>>31)}c[Xc>>2]=c[Xc>>2]|4096}if((Tc|0)<(mc|0)&(Tc|0)<(Pc|0)){Sc=Tc}else{break}}if((Uc|0)<(Db|0)){Rc=Uc}else{break}}}if((Pc|0)<(mc|0)){Nc=Pc}else{Vc=Fc;break}}}else if((Dc|0)==2){Nc=a[Ba]|0;Kc=3<<Ec;if(rc){Ic=-Kc|0;Jc=0;while(1){if(xc){Rc=Jc|3;Qc=(Rc|0)<(mc|0);Mc=Jc|1;Sc=Jc|2;Oc=Jc+4|0;Tc=0;while(1){Xc=Tc+1|0;do{if(Qc){if((c[o+16384+(Mc*264|0)+(Xc<<2)>>2]&12543|0)!=0){cd=0;dd=0;H=319;break}if((c[o+16384+(Sc*264|0)+(Xc<<2)>>2]&12543|0)!=0){cd=0;dd=0;H=319;break}if((c[o+16384+(Rc*264|0)+(Xc<<2)>>2]&12543|0)!=0){cd=0;dd=0;H=319;break}if((c[o+16384+(Oc*264|0)+(Xc<<2)>>2]&12543|0)!=0){cd=0;dd=0;H=319;break}if((vUa(L,P)|0)==0){break}_c=(vUa(L,O)|0)<<1;cd=1;dd=_c|(vUa(L,O)|0);H=319}else{cd=0;dd=0;H=319}}while(0);do{if((H|0)==319){H=0;Uc=dd+Jc|0;if((Uc|0)<(Oc|0)&(Uc|0)<(mc|0)){ed=Uc;fd=cd}else{break}while(1){Uc=ed+1|0;_c=o+16384+(Uc*264|0)+(Xc<<2)|0;do{if((fd|0)==0){ad=c[_c>>2]|0;if((ad&12288|0)!=0){break}if((vUa(L,(d[7696880+((ad&(Cc&(ed|0)==(Rc|0)?55:255))<<2)+da|0]|0)+(o+33828)|0)|0)!=0){H=323}}else{H=323}}while(0);if((H|0)==323){H=0;ad=c[_c>>2]|0;Yc=ad>>>8&15;$c=ad&15;ad=d[7696624+($c<<4)+Yc|0]|0;gd=(vUa(L,(d[7697904+($c<<4)+Yc|0]|0)+(o+33828)|0)|0)!=(ad|0);ad=gd?Ic:Kc;c[o+(ed<<8)+(Tc<<2)>>2]=ad;KNa(o,Tc,ed,ad>>>31)}c[_c>>2]=c[_c>>2]&-4097;if((Uc|0)<(Oc|0)&(Uc|0)<(mc|0)){ed=Uc;fd=0}else{break}}}}while(0);if((Xc|0)<(Db|0)){Tc=Xc}else{hd=Oc;break}}}else{hd=Jc+4|0}if((hd|0)<(mc|0)){Jc=hd}else{break}}}do{if(!((Nc&32)==0)){Jc=(vUa(L,O)|0)<<1;Kc=Jc+(vUa(L,O)|0)<<1;Jc=Kc+(vUa(L,O)|0)<<1;if((Jc+(vUa(L,O)|0)|0)==10){break}KIb(c[t>>2]|0,16,2121584,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}}while(0);Nc=Fc+1|0;if(!(Bc&(Nc|0)>3)){Vc=Nc;break}uUa(L,wc);Vc=Nc}else{Vc=Fc}}while(0);Nc=Dc+1|0;Jc=(Nc|0)==3;if((Hc|0)==0){break}else{Dc=Jc?0:Nc;Ec=(Jc<<31>>31)+Ec|0;Fc=Vc;Gc=Hc}}}}while(0);mc=e[Fb>>1]|0;Db=e[lc>>1]|0;rc=(e[R>>1]|0)-mc|0;oc=(e[kc>>1]|0)-Db|0;pc=(oc|0)>0;do{if((a[sa]|0)==0){if(!pc){break}tc=(e[ka>>1]|0)-(e[I>>1]|0)|0;sc=c[ja>>2]|0;nc=(rc|0)>0;Eb=0;do{vc=(ca(Eb+Db|0,tc)|0)+mc|0;if(nc){uc=0;do{g[sc+(vc+uc<<2)>>2]=+(c[o+(Eb<<8)+(uc<<2)>>2]|0)*+g[Ya>>2];uc=uc+1|0;}while((uc|0)<(rc|0))}Eb=Eb+1|0;}while((Eb|0)<(oc|0))}else{if(!pc){break}Eb=(e[ka>>1]|0)-(e[I>>1]|0)|0;sc=c[ma>>2]|0;nc=(rc|0)>0;tc=0;do{uc=(ca(tc+Db|0,Eb)|0)+mc|0;if(nc){vc=0;do{c[sc+(uc+vc<<2)>>2]=(ca(c[_a>>2]|0,c[o+(tc<<8)+(vc<<2)>>2]|0)|0)+16384>>15;vc=vc+1|0;}while((vc|0)<(rc|0))}tc=tc+1|0;}while((tc|0)<(oc|0))}}while(0);rb=rb+1|0;}while((rb|0)<(ca(e[fb>>1]|0,e[ob>>1]|0)|0))}qb=qb+1|0;}while((qb|0)<(sb|0));jc=a[ha]|0}}while(0);da=ga+1|0;if((da|0)<(jc&255|0)){ga=da;la=jc}else{break}}ic=c[J>>2]|0}la=ua+1|0;if((la|0)<(ic|0)){ua=la;ia=ic}else{id=sa;break}}}else{id=X+(ta*1588|0)+8+(ea*84|0)+10|0}if((a[id]|0)==0){jd=c[xa+(ea*232|0)+208>>2]|0}else{jd=c[xa+(ea*232|0)+212>>2]|0}ZNa(xa+(ea*232|0)+4|0,jd)|0;ea=ea+1|0;}while((ea|0)<(c[W>>2]|0))}do{if((a[X+(ta*1588|0)+21|0]|0)!=0){ea=a[X+(ta*1588|0)+18|0]|0;Y=1;while(1){if((Y|0)>=3){break}if(ea<<24>>24==(a[X+(ta*1588|0)+8+(Y*84|0)+10|0]|0)){Y=Y+1|0}else{H=359;break}}if((H|0)==359){H=0;KIb(c[t>>2]|0,16,2297440,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;break}Y=c[Q>>2]|0;if(ea<<24>>24==0){kd=c[Y+672>>2]|0;ld=0;md=c[Y+208>>2]|0;nd=0;od=0;pd=c[Y+440>>2]|0}else{kd=0;ld=c[Y+676>>2]|0;md=0;nd=c[Y+212>>2]|0;od=c[Y+444>>2]|0;pd=0}xa=ca((e[Y+222>>1]|0)-(e[Y+220>>1]|0)|0,(e[Y+218>>1]|0)-(e[Y+216>>1]|0)|0)|0;Y=ea&255;if((Y|0)==1){if((xa|0)>0){qd=0;rd=nd;sd=ld;td=od}else{break}while(1){sa=c[sd>>2]|0;ia=c[td>>2]|0;ua=(c[rd>>2]|0)-(ia+sa>>2)|0;c[rd>>2]=ua+sa;c[td>>2]=ua;c[sd>>2]=ua+ia;ia=qd+1|0;if((ia|0)<(xa|0)){qd=ia;rd=rd+4|0;sd=sd+4|0;td=td+4|0}else{break}}}else if((Y|0)==2){if((xa|0)>0){ud=0;vd=nd;wd=ld;xd=od}else{break}while(1){ea=c[vd>>2]|0;ia=c[wd>>2]|0;ua=c[xd>>2]|0;c[vd>>2]=((ia*91881|0)+32768>>16)+ea;c[xd>>2]=ea-((ia*46802|0)+32768>>16)-((ua*22553|0)+32768>>16);c[wd>>2]=((ua*116130|0)+32768>>16)+ea;ea=ud+1|0;if((ea|0)<(xa|0)){ud=ea;vd=vd+4|0;wd=wd+4|0;xd=xd+4|0}else{break}}}else if((Y|0)==0){if((xa|0)>0){yd=0;zd=md;Ad=kd;Bd=pd}else{break}while(1){Cd=+g[zd>>2];Dd=+g[Ad>>2];Ed=+g[Bd>>2];g[zd>>2]=Cd+Dd*1.4019999504089355;g[Bd>>2]=Cd-Ed*.3441300094127655-Dd*.714139997959137;g[Ad>>2]=Cd+Ed*1.7719999551773071;ea=yd+1|0;if((ea|0)<(xa|0)){yd=ea;zd=zd+4|0;Ad=Ad+4|0;Bd=Bd+4|0}else{break}}}else{break}}}while(0);do{if((c[va>>2]|0)<0){xa=c[W>>2]|0;if((xa|0)>0){Y=0;while(1){ea=Y+1|0;c[r+1128+(Y<<2)>>2]=ea;ua=c[W>>2]|0;if((ea|0)<(ua|0)){Y=ea}else{Fd=ua;break}}}else{Fd=xa}if((Fd&1|0)!=0){break}c[r+1128+(Fd-1<<2)>>2]=0}}while(0);Y=c[W>>2]|0;ua=(Y|0)>0;do{if((c[fa>>2]|0)<9){if(!ua){break}ea=Q|0;ia=-(na&1)|0;sa=0;J=Y;ma=c[ea>>2]|0;while(1){I=d[r+44+sa|0]|0;ka=c[N>>2]|0;ja=(e[ma+(sa*232|0)+218>>1]|0)-ka|0;if(M){Ba=c[r+1128+(sa<<2)>>2]|0;Gd=((Ba|0)==0?J:Ba)-1|0}else{Gd=0}Ba=c[V>>2]|0;Ta=(e[ma+(sa*232|0)+220>>1]|0)-Ba|0;la=r+72+(sa<<2)|0;ga=s+32+(Gd<<2)|0;if((Ta|0)<((e[ma+(sa*232|0)+222>>1]|0)-Ba|0)){Ba=ca((Ta|0)/(c[la>>2]|0)|0,c[ga>>2]|0)|0;ha=r+56+(sa<<2)|0;Z=sa&ia;Za=X+(ta*1588|0)+8+(sa*84|0)+10|0;wa=1<<I-1;$a=(1<<I)-1|0;da=8-I|0;I=c[ma+(sa*232|0)+212>>2]|0;gb=c[ma+(sa*232|0)+208>>2]|0;eb=(c[s+(Gd<<2)>>2]|0)+Ba|0;Ba=Ta;Ta=ma;sb=c[ha>>2]|0;qb=ka;while(1){ka=(e[Ta+(sa*232|0)+216>>1]|0)-qb|0;_a=eb+((ca((ka|0)/(sb|0)|0,hc)|0)+Z)|0;Ya=(ka|0)<(ja|0);do{if((a[Za]|0)==0){if(Ya){Id=gb;Jd=_a;Kd=ka}else{Ld=gb;Md=I;Nd=sb;break}while(1){Xa=(Lc(+(+g[Id>>2]))|0)+wa|0;if((Xa|0)<0){Od=0}else{Od=(Xa|0)>($a|0)?$a:Xa}a[Jd]=Od<<da;Xa=Id+4|0;ob=c[ha>>2]|0;fb=ob+Kd|0;if((fb|0)<(ja|0)){Id=Xa;Jd=Jd+hc|0;Kd=fb}else{Ld=Xa;Md=I;Nd=ob;break}}}else{if(Ya){Pd=I;Qd=_a;Rd=ka}else{Ld=gb;Md=I;Nd=sb;break}while(1){ob=(c[Pd>>2]|0)+wa|0;if((ob|0)<0){Sd=0}else{Sd=(ob|0)>($a|0)?$a:ob}a[Qd]=Sd<<da;ob=Pd+4|0;Xa=c[ha>>2]|0;fb=Xa+Rd|0;if((fb|0)<(ja|0)){Pd=ob;Qd=Qd+hc|0;Rd=fb}else{Ld=gb;Md=ob;Nd=Xa;break}}}}while(0);ka=(c[la>>2]|0)+Ba|0;Td=c[ea>>2]|0;if((ka|0)>=((e[Td+(sa*232|0)+222>>1]|0)-(c[V>>2]|0)|0)){break}I=Md;gb=Ld;eb=eb+(c[ga>>2]|0)|0;Ba=ka;Ta=Td;sb=Nd;qb=c[N>>2]|0}Ud=Td;Vd=c[W>>2]|0}else{Ud=ma;Vd=J}qb=sa+1|0;if((qb|0)<(Vd|0)){sa=qb;J=Vd;ma=Ud}else{break}}}else{if(!ua){break}ma=Q|0;J=-(na&1)|0;sa=0;ea=Y;ia=c[ma>>2]|0;while(1){xa=d[r+44+sa|0]|0;qb=c[N>>2]|0;sb=(e[ia+(sa*232|0)+218>>1]|0)-qb|0;if(M){Ta=c[r+1128+(sa<<2)>>2]|0;Wd=((Ta|0)==0?ea:Ta)-1|0}else{Wd=0}Ta=c[V>>2]|0;Ba=(e[ia+(sa*232|0)+220>>1]|0)-Ta|0;ga=r+72+(sa<<2)|0;eb=s+32+(Wd<<2)|0;if((Ba|0)<((e[ia+(sa*232|0)+222>>1]|0)-Ta|0)){gb=c[eb>>2]|0;I=c[ga>>2]|0;la=(c[s+(Wd<<2)>>2]|0)+((ca((Ba|0)/(I|0)|0,gb>>1)|0)<<1)|0;ja=r+56+(sa<<2)|0;ha=sa&J;da=X+(ta*1588|0)+8+(sa*84|0)+10|0;$a=1<<xa-1;wa=(1<<xa)-1|0;Za=16-xa|0;xa=Ba;Ba=c[ia+(sa*232|0)+208>>2]|0;Z=c[ia+(sa*232|0)+212>>2]|0;ka=la;la=ia;_a=c[ja>>2]|0;Ya=gb;gb=I;I=Ta;Ta=qb;while(1){qb=(e[la+(sa*232|0)+216>>1]|0)-Ta|0;Xa=ka+((ca((qb|0)/(_a|0)|0,hc)|0)+ha<<1)|0;ob=(qb|0)<(sb|0);do{if((a[da]|0)==0){if(ob){Xd=Ba;Yd=qb;Zd=Xa}else{_d=Z;$d=Ba;ae=_a;be=Ya;ce=gb;de=la;ee=I;break}while(1){fb=(Lc(+(+g[Xd>>2]))|0)+$a|0;if((fb|0)<0){fe=0}else{fe=(fb|0)>(wa|0)?wa:fb}b[Zd>>1]=fe<<Za;ge=Xd+4|0;ie=c[ja>>2]|0;fb=ie+Yd|0;if((fb|0)<(sb|0)){Xd=ge;Yd=fb;Zd=Zd+(hc<<1)|0}else{break}}_d=Z;$d=ge;ae=ie;be=c[eb>>2]|0;ce=c[ga>>2]|0;de=c[ma>>2]|0;ee=c[V>>2]|0}else{if(ob){ke=Z;le=qb;me=Xa}else{_d=Z;$d=Ba;ae=_a;be=Ya;ce=gb;de=la;ee=I;break}while(1){fb=(c[ke>>2]|0)+$a|0;if((fb|0)<0){ne=0}else{ne=(fb|0)>(wa|0)?wa:fb}b[me>>1]=ne<<Za;fb=ke+4|0;rb=le+_a|0;if((rb|0)<(sb|0)){ke=fb;le=rb;me=me+(hc<<1)|0}else{_d=fb;$d=Ba;ae=_a;be=Ya;ce=gb;de=la;ee=I;break}}}}while(0);Xa=ce+xa|0;if((Xa|0)>=((e[de+(sa*232|0)+222>>1]|0)-ee|0)){break}xa=Xa;Ba=$d;Z=_d;ka=ka+(be>>1<<1)|0;la=de;_a=ae;Ya=be;gb=ce;I=ee;Ta=c[N>>2]|0}oe=de;pe=c[W>>2]|0}else{oe=ia;pe=ea}Ta=sa+1|0;if((Ta|0)<(pe|0)){sa=Ta;ea=pe;ia=oe}else{break}}}}while(0);ta=ta+1|0;if(!(ta>>>0<(ca(c[F>>2]|0,c[E>>2]|0)|0)>>>0)){break k}}if((H|0)==264){KIb(0,0,2246608,(x=i,i=i+24|0,c[x>>2]=2204920,c[x+8>>2]=2172776,c[x+16>>2]=1057,x)|0);i=x;Hd();return 0}else if((H|0)==268){KIb(0,0,2246608,(x=i,i=i+24|0,c[x>>2]=2145400,c[x+8>>2]=2172776,c[x+16>>2]=1058,x)|0);i=x;Hd();return 0}}}while(0);SNa(r);c[j>>2]=1;if((c[(c[t>>2]|0)+140>>2]|0)==11){nrc(c[h+4>>2]|0,q+100|0,1024)|0}qe=(c[k>>2]|0)-(c[y>>2]|0)|0;i=l;return qe|0}}while(0);SNa(r);qe=D;i=l;return qe|0}function SNa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=a+1152|0;d=c[b>>2]|0;e=a+1156|0;f=c[e>>2]|0;g=a+2668|0;if((ca(f,d)|0)==0){h=g;mJb(h);i=a+1164|0;c[e>>2]=0;c[b>>2]=0;j=i;mrc(j|0,0,1496)|0;return}k=a+92|0;l=0;m=d;d=f;while(1){f=c[g>>2]|0;if((c[f+(l*1588|0)>>2]|0)==0){n=m;o=d}else{p=f+(l*1588|0)|0;if((c[k>>2]|0)>0){q=0;r=f;f=p;while(1){ONa((c[f>>2]|0)+(q*232|0)|0,r+(l*1588|0)+8+(q*84|0)|0);s=q+1|0;t=c[g>>2]|0;u=t+(l*1588|0)|0;if((s|0)<(c[k>>2]|0)){q=s;r=t;f=u}else{v=u;break}}}else{v=p}mJb(v);n=c[b>>2]|0;o=c[e>>2]|0}f=l+1|0;if(f>>>0<(ca(o,n)|0)>>>0){l=f;m=n;d=o}else{break}}h=g;mJb(h);i=a+1164|0;c[e>>2]=0;c[b>>2]=0;j=i;mrc(j|0,0,1496)|0;return}function TNa(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0;n=i;o=f+2660|0;p=f+12|0;q=f+8|0;r=c[o>>2]|0;if((r|0)==0){s=c[p>>2]|0;t=c[q>>2]|0;if((s-t|0)<1){u=8;v=t}else{w=t+1|0;c[q>>2]=w;u=(a[t]|0)!=-1?8:7;v=w}c[o>>2]=u;x=u;y=v;z=s}else{x=r;y=c[q>>2]|0;z=c[p>>2]|0}r=x-1|0;c[o>>2]=r;x=z;s=(x-y|0)<1;if(s){A=0}else{A=d[y]|0}if((A&1<<r|0)==0){do{if(!s){r=y+1|0;c[q>>2]=r;if(!((a[y]|0)==-1)){break}A=x-r|0;c[q>>2]=y+(A>>>0>1>>>0?2:A+1|0)}}while(0);c[o>>2]=8;B=0;i=n;return B|0}x=h|0;s=a[x]|0;do{if(s<<24>>24==0){C=z;D=y}else{A=h+16|0;r=k+1|0;v=m-1|0;u=0;w=s;a:while(1){t=c[A>>2]|0;E=c[t+(u*24|0)+20>>2]|0;do{if((b[t+(u*24|0)>>1]|0)==(b[t+(u*24|0)+2>>1]|0)){F=w}else{if((b[t+(u*24|0)+4>>1]|0)==(b[t+(u*24|0)+6>>1]|0)){F=w;break}G=ca(e[E+(j*24|0)>>1]|0,e[E+(j*24|0)+2>>1]|0)|0;if((G|0)==0){F=w;break}H=E+(j*24|0)+12|0;I=E+(j*24|0)+8|0;J=l+u|0;K=E+(j*24|0)+4|0;L=0;do{M=c[H>>2]|0;N=M+(L*9816|0)|0;if((a[N]|0)==0){O=(UNa(f,(c[I>>2]|0)+(L<<3)|0,r)|0)==(k|0)|0}else{P=c[o>>2]|0;if((P|0)==0){Q=c[p>>2]|0;R=c[q>>2]|0;if((Q-R|0)<1){S=8;T=R}else{U=R+1|0;c[q>>2]=U;S=(a[R]|0)!=-1?8:7;T=U}c[o>>2]=S;V=S;W=T;X=Q}else{V=P;W=c[q>>2]|0;X=c[p>>2]|0}P=V-1|0;c[o>>2]=P;if((X-W|0)<1){Y=0}else{Y=d[W]|0}O=Y>>>(P>>>0)&1}if((O|0)!=0){if((a[N]|0)==0){P=d[J]|0;Z=v+P-(UNa(f,(c[K>>2]|0)+(L<<3)|0,100)|0)|0;if((Z|0)<0){_=32;break a}a[M+(L*9816|0)+2|0]=Z}P=c[o>>2]|0;if((P|0)==0){Q=c[p>>2]|0;U=c[q>>2]|0;if((Q-U|0)<1){$=8;aa=U}else{R=U+1|0;c[q>>2]=R;$=(a[U]|0)!=-1?8:7;aa=R}c[o>>2]=$;ba=$;da=aa;ea=Q}else{ba=P;da=c[q>>2]|0;ea=c[p>>2]|0}P=ba-1|0;c[o>>2]=P;Q=ea;R=(Q-da|0)<1;if(R){fa=0}else{fa=d[da]|0}do{if((fa&1<<P|0)==0){ga=1;ha=P;ia=da}else{if((P|0)==0){if(R){ja=8;ka=da}else{U=da+1|0;c[q>>2]=U;ja=(a[da]|0)!=-1?8:7;ka=U}c[o>>2]=ja;la=ja;ma=ka}else{la=P;ma=da}U=la-1|0;c[o>>2]=U;na=(Q-ma|0)<1;if(na){oa=0}else{oa=d[ma]|0}if((oa&1<<U|0)==0){ga=2;ha=U;ia=ma;break}if((U|0)==0){if(na){pa=8;qa=ma}else{na=ma+1|0;c[q>>2]=na;pa=(a[ma]|0)!=-1?8:7;qa=na}c[o>>2]=pa;ra=pa;sa=qa}else{ra=U;sa=ma}U=ra-1|0;c[o>>2]=U;na=(Q-sa|0)<1;if(na){ta=0}else{ta=d[sa]|0}ua=ta>>>(U>>>0)<<1&2;if((U|0)==0){if(na){va=8;wa=sa}else{na=sa+1|0;c[q>>2]=na;va=(a[sa]|0)!=-1?8:7;wa=na}c[o>>2]=va;xa=va;ya=wa}else{xa=U;ya=sa}U=xa-1|0;c[o>>2]=U;na=(Q-ya|0)<1;if(na){za=0}else{za=d[ya]|0}Aa=za>>>(U>>>0)&1|ua;if((Aa|0)!=3){ga=Aa+3|0;ha=U;ia=ya;break}if((U|0)==0){if(na){Ba=8;Ca=ya}else{na=ya+1|0;c[q>>2]=na;Ba=(a[ya]|0)!=-1?8:7;Ca=na}c[o>>2]=Ba;Da=Ba;Ea=Ca}else{Da=U;Ea=ya}U=Da-1|0;c[o>>2]=U;na=(Q-Ea|0)<1;if(na){Fa=0}else{Fa=d[Ea]|0}Aa=Fa>>>(U>>>0)<<1&2;if((U|0)==0){if(na){Ga=8;Ha=Ea}else{na=Ea+1|0;c[q>>2]=na;Ga=(a[Ea]|0)!=-1?8:7;Ha=na}c[o>>2]=Ga;Ia=Ga;Ja=Ha}else{Ia=U;Ja=Ea}U=Ia-1|0;c[o>>2]=U;na=(Q-Ja|0)<1;if(na){Ka=0}else{Ka=d[Ja]|0}ua=(Ka>>>(U>>>0)&1|Aa)<<1;if((U|0)==0){if(na){La=8;Ma=Ja}else{na=Ja+1|0;c[q>>2]=na;La=(a[Ja]|0)!=-1?8:7;Ma=na}c[o>>2]=La;Na=La;Oa=Ma}else{Na=U;Oa=Ja}U=Na-1|0;c[o>>2]=U;na=(Q-Oa|0)<1;if(na){Pa=0}else{Pa=d[Oa]|0}Aa=(Pa>>>(U>>>0)&1|ua)<<1;if((U|0)==0){if(na){Qa=8;Ra=Oa}else{na=Oa+1|0;c[q>>2]=na;Qa=(a[Oa]|0)!=-1?8:7;Ra=na}c[o>>2]=Qa;Sa=Qa;Ta=Ra}else{Sa=U;Ta=Oa}U=Sa-1|0;c[o>>2]=U;na=(Q-Ta|0)<1;if(na){Ua=0}else{Ua=d[Ta]|0}ua=(Ua>>>(U>>>0)&1|Aa)<<1;if((U|0)==0){if(na){Va=8;Wa=Ta}else{na=Ta+1|0;c[q>>2]=na;Va=(a[Ta]|0)!=-1?8:7;Wa=na}c[o>>2]=Va;Xa=Va;Ya=Wa}else{Xa=U;Ya=Ta}U=Xa-1|0;c[o>>2]=U;if((Q-Ya|0)<1){Za=0}else{Za=d[Ya]|0}na=Za>>>(U>>>0)&1|ua;if((na|0)==31){ua=0;Aa=7;_a=U;$a=Ya;while(1){ab=Aa-1|0;bb=ua<<1;if((_a|0)==0){if((Q-$a|0)<1){cb=8;db=$a}else{eb=$a+1|0;c[q>>2]=eb;cb=(a[$a]|0)!=-1?8:7;db=eb}c[o>>2]=cb;fb=cb;gb=db}else{fb=_a;gb=$a}hb=fb-1|0;c[o>>2]=hb;if((Q-gb|0)<1){ib=0}else{ib=d[gb]|0}jb=ib>>>(hb>>>0)&1|bb;if((ab|0)>0){ua=jb;Aa=ab;_a=hb;$a=gb}else{break}}kb=(jb|0)<0?jb:jb+37|0;lb=hb;mb=gb}else{kb=(na|0)<0?na:na+6|0;lb=U;mb=Ya}if((kb|0)<0){B=kb;_=127;break a}else{ga=kb;ha=lb;ia=mb}}}while(0);P=0;R=ha;$a=ia;while(1){if((R|0)==0){if((Q-$a|0)<1){nb=8;ob=$a}else{_a=$a+1|0;c[q>>2]=_a;nb=(a[$a]|0)!=-1?8:7;ob=_a}c[o>>2]=nb;pb=nb;qb=ob}else{pb=R;qb=$a}_a=pb-1|0;c[o>>2]=_a;if((Q-qb|0)<1){rb=0}else{rb=d[qb]|0}if((rb&1<<_a|0)==0){break}else{P=P+1|0;R=_a;$a=qb}}if((P|0)<0){B=P;_=127;break a}$a=M+(L*9816|0)+8|0;R=(d[$a]|0)+P|0;a[$a]=R;$a=ga>>>0>65535>>>0;Q=$a?ga>>>16:ga;_a=$a?16:0;if((Q&65280|0)==0){sb=_a;tb=Q}else{sb=_a|8;tb=Q>>>8}Q=sb+(R&255)+(d[1359664+tb|0]|0)|0;if((Q|0)>0){R=0;_a=Q;Q=c[o>>2]|0;do{_a=_a-1|0;$a=R<<1;if((Q|0)==0){Aa=c[p>>2]|0;ua=c[q>>2]|0;if((Aa-ua|0)<1){ub=8;vb=ua}else{ab=ua+1|0;c[q>>2]=ab;ub=(a[ua]|0)!=-1?8:7;vb=ab}c[o>>2]=ub;wb=ub;xb=vb;yb=Aa}else{wb=Q;xb=c[q>>2]|0;yb=c[p>>2]|0}Q=wb-1|0;c[o>>2]=Q;if((yb-xb|0)<1){zb=0}else{zb=d[xb]|0}R=zb>>>(Q>>>0)&1|$a;}while((_a|0)>0);if((R|0)<0){B=R;_=127;break a}if(R>>>0>8192>>>0){_=103;break a}else{Ab=R&65535}}else{Ab=0}b[M+(L*9816|0)+6>>1]=Ab;a[N]=(d[N]|0)+ga}L=L+1|0;}while((L|0)<(G|0));F=a[x]|0}}while(0);E=u+1|0;if((E|0)<(F&255|0)){u=E;w=F}else{_=108;break}}if((_|0)==32){KIb(c[f+4>>2]|0,16,2567696,(Bb=i,i=i+8|0,c[Bb>>2]=Z,Bb)|0);i=Bb;B=-1094995529;i=n;return B|0}else if((_|0)==103){QIb(c[f+4>>2]|0,2549528,(Bb=i,i=i+8|0,c[Bb>>2]=8192,Bb)|0);i=Bb;B=-1163346256;i=n;return B|0}else if((_|0)==108){C=c[p>>2]|0;D=c[q>>2]|0;break}else if((_|0)==127){i=n;return B|0}}}while(0);Z=C;do{if((Z-D|0)<1){Cb=D}else{C=D+1|0;c[q>>2]=C;if(!((a[D]|0)==-1)){Cb=C;break}F=Z-C|0;C=D+(F>>>0>1>>>0?2:F+1|0)|0;c[q>>2]=C;Cb=C}}while(0);c[o>>2]=8;b:do{if(!((a[g+11|0]&4)==0)){o=f+8|0;q=Z-Cb|0;do{if((q|0)>=2){D=Cb;if(!((d[D]|d[D+1|0]<<8)<<16>>16<<16>>16==-27905)){break}c[o>>2]=Cb+(q>>>0>2>>>0?2:q);break b}}while(0);KIb(c[f+4>>2]|0,16,2531496,(Bb=i,i=i+1|0,i=i+7&-8,c[Bb>>2]=0,Bb)|0);i=Bb}}while(0);Cb=a[x]|0;if(Cb<<24>>24==0){B=0;i=n;return B|0}Z=h+16|0;h=f+8|0;g=0;q=Cb;c:while(1){Cb=c[(c[Z>>2]|0)+(g*24|0)+20>>2]|0;o=ca(e[Cb+(j*24|0)>>1]|0,e[Cb+(j*24|0)+2>>1]|0)|0;if((o|0)==0){Db=q}else{D=Cb+(j*24|0)+12|0;Cb=0;C=c[h>>2]|0;do{F=c[D>>2]|0;ga=F+(Cb*9816|0)+6|0;Eb=e[ga>>1]|0;Ab=F+(Cb*9816|0)+4|0;Fb=b[Ab>>1]|0;if(((c[p>>2]|0)-C|0)>>>0<Eb>>>0){break c}zb=Fb&65535;if((Eb+2+zb|0)>>>0>8192>>>0){break c}nrc(F+(Cb*9816|0)+10+zb|0,C|0,Eb)|0;C=(c[h>>2]|0)+Eb|0;c[h>>2]=C;b[Ab>>1]=(b[Ab>>1]|0)+(b[ga>>1]|0);b[ga>>1]=0;Cb=Cb+1|0;}while((Cb|0)<(o|0));Db=a[x]|0}o=g+1|0;if((o|0)<(Db&255|0)){g=o;q=Db}else{B=0;_=127;break}}if((_|0)==127){i=n;return B|0}KIb(c[f+4>>2]|0,16,2516304,(Bb=i,i=i+16|0,c[Bb>>2]=Fb&65535,c[Bb+8>>2]=Eb,Bb)|0);i=Bb;B=-1094995529;i=n;return B|0}function UNa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+120|0;h=g|0;if((e|0)==0){j=-1094995529;i=g;return j|0}else{k=e;l=-1}while(1){if((a[k+1|0]|0)!=0){m=l;break}e=l+1|0;c[h+(e<<2)>>2]=k;n=c[k+4>>2]|0;if((n|0)==0){m=e;break}else{k=n;l=e}}l=d[k|0]|0;if(!((l|0)<(f|0)&(m|0)>-1)){j=l;i=g;return j|0}k=b+2660|0;e=b+12|0;n=b+8|0;b=m;m=l;a:while(1){l=c[h+(b<<2)>>2]|0;o=l|0;p=d[o]|0;q=(m|0)<(p|0)?p:m;while(1){r=(q|0)<(f|0);if(!r){break a}p=c[k>>2]|0;if((p|0)==0){s=c[e>>2]|0;t=c[n>>2]|0;if((s-t|0)<1){u=8;v=t}else{w=t+1|0;c[n>>2]=w;u=(a[t]|0)!=-1?8:7;v=w}c[k>>2]=u;x=u;y=v;z=s}else{x=p;y=c[n>>2]|0;z=c[e>>2]|0}p=x-1|0;c[k>>2]=p;if((z-y|0)<1){A=0}else{A=d[y]|0}if((A&1<<p|0)!=0){break}q=q+1|0}p=l+1|0;a[p]=(a[p]|0)+1;a[o]=q;if(r&(b|0)>0){b=b-1|0;m=q}else{j=q;B=19;break}}if((B|0)==19){i=g;return j|0}a[o]=q;j=q;i=g;return j|0}function VNa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=e+8|0;i=c[h>>2]|0;j=e+12|0;if((c[j>>2]|0)==(i|0)){k=-1094995529;return k|0}c[h>>2]=i+1;e=a[i]|0;a[g+289|0]=(e&255)>>>5;i=e&31;a[g+288|0]=i;if((i<<24>>24|0)==1){e=c[h>>2]|0;if(((c[j>>2]|0)-e|0)>>>0<2>>>0){k=-1094995529;return k|0}c[h>>2]=e+2;l=e;e=he((d[l]|d[l+1|0]<<8)<<16>>16|0)|0;l=(e&65535)>>>11&255;m=g|0;a[m]=l;n=g+96|0;b[n>>1]=e&2047;e=1;o=l;while(1){l=(o&255)-((e-1|0)/3|0)|0;a[g+e|0]=(l|0)<0?0:l&255;b[g+96+(e<<1)>>1]=b[n>>1]|0;l=e+1|0;if((l|0)>=96){k=0;break}e=l;o=a[m]|0}return k|0}else if((i<<24>>24|0)==0){i=f-3|0;m=c[h>>2]|0;if(((c[j>>2]|0)-m|0)>>>0<i>>>0|(i|0)>96){k=-1094995529;return k|0}if((i|0)>0){p=0;q=m}else{k=0;return k|0}while(1){c[h>>2]=q+1;a[g+p|0]=(d[q]|0)>>>3;m=p+1|0;if((m|0)>=(i|0)){k=0;break}p=m;q=c[h>>2]|0}return k|0}else{q=f-3>>1;f=c[h>>2]|0;if(((c[j>>2]|0)-f|0)>>>0<q<<1>>>0|(q|0)>96){k=-1094995529;return k|0}if((q|0)>0){r=0;s=f}else{k=0;return k|0}while(1){c[h>>2]=s+2;f=s;j=he((d[f]|d[f+1|0]<<8)<<16>>16|0)|0;a[g+r|0]=(j&65535)>>>11;b[g+96+(r<<1)>>1]=j&2047;j=r+1|0;if((j|0)>=(q|0)){k=0;break}r=j;s=c[h>>2]|0}return k|0}return 0}function WNa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;g=b+8|0;h=c[g>>2]|0;j=b+12|0;if(((c[j>>2]|0)-h|0)>>>0<5>>>0){k=-1094995529;i=f;return k|0}l=h+1|0;c[g>>2]=l;m=d[h]|0;n=m+1|0;o=e|0;c[o>>2]=n;if(n>>>0>32>>>0){KIb(c[b+4>>2]|0,16,2396344,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;k=-1094995529;i=f;return k|0}q=b+2672|0;r=c[q>>2]|0;if((n|0)<=(r|0)){KIb(c[b+4>>2]|0,16,2389408,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;c[q>>2]=(c[o>>2]|0)-1;k=-22;i=f;return k|0}c[e+4>>2]=n-r;c[g>>2]=h+2;h=e+8|0;a[h]=(a[l]&15)+2;l=c[g>>2]|0;c[g>>2]=l+1;r=(a[l]&15)+2|0;a[e+9|0]=r;l=a[h]|0;h=l&255;do{if(!((l&255)>>>0>10>>>0)){n=r&255;if(n>>>0>10>>>0){break}if((n+h|0)>12){break}if((l&255)>>>0>6>>>0|n>>>0>6>>>0){QIb(c[b+4>>2]|0,2375848,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=-1163346256;i=f;return k|0}n=c[g>>2]|0;c[g>>2]=n+1;q=a[n]|0;a[e+14|0]=q;if(q<<24>>24==0){s=b+4|0}else{n=b+4|0;KIb(c[n>>2]|0,24,2369184,(p=i,i=i+8|0,c[p>>2]=q&255,p)|0);i=p;s=n}n=c[g>>2]|0;c[g>>2]=n+1;q=a[n]|0;n=e+10|0;a[n]=q;if((c[(c[s>>2]|0)+88>>2]&8388608|0)!=0&q<<24>>24==0){a[n]=2}if((a[e+11|0]&1)==0){mrc(e+16|0,15,66)|0;k=0;i=f;return k|0}if((c[o>>2]|0)>0){t=0}else{k=0;i=f;return k|0}while(1){n=c[g>>2]|0;if(((c[j>>2]|0)-n|0)<1){u=0;v=0}else{c[g>>2]=n+1;q=a[n]|0;u=(q&255)>>>4;v=q&15}a[e+16+t|0]=v;a[e+49+t|0]=u;q=t+1|0;if((q|0)<(c[o>>2]|0)){t=q}else{k=0;break}}i=f;return k|0}}while(0);KIb(c[b+4>>2]|0,16,2382488,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=-1094995529;i=f;return k|0}function XNa(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;a[d+192|0]=g;a[d+193|0]=h;i=e[f>>1]|0;j=e[f+2>>1]|0;k=e[f+4>>1]|0;l=e[f+6>>1]|0;f=j-i|0;m=l-k|0;n=(f|0)>(m|0)?f:m;if((g|0)>0){m=g;g=j;j=i;i=l;l=k;while(1){k=m-1|0;b[d+(k<<2)>>1]=g-j;a[d+128+(k<<1)|0]=j&1;b[d+(k<<2)+2>>1]=i-l;a[d+128+(k<<1)+1|0]=l&1;if((k|0)>0){m=k;g=g+1>>1;j=j+1>>1;i=i+1>>1;l=l+1>>1}else{break}}}do{if((h|0)==0){l=hJb((n<<2)+48|0)|0;c[d+200>>2]=l;if((l|0)==0){o=-12}else{break}return o|0}else if((h|0)==2){l=hJb((n<<2)+48|0)|0;c[d+196>>2]=l;if((l|0)==0){o=-12}else{break}return o|0}else if((h|0)==1){l=hJb((n<<2)+24|0)|0;c[d+196>>2]=l;if((l|0)==0){o=-12}else{break}return o|0}else{o=-1;return o|0}}while(0);o=0;return o|0}function YNa(e,f){e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;h=d[e+193|0]|0;if((h|0)==1){i=f;j=a[e+192|0]|0;k=(j&255)-1|0;l=b[e+(k<<2)>>1]|0;m=l&65535;n=c[e+196>>2]|0;if(j<<24>>24==0){o=0;return o|0}else{p=k;q=l}while(1){l=q&65535;k=b[e+(p<<2)+2>>1]|0;j=k&65535;r=d[e+128+(p<<1)|0]|0;s=d[e+128+(p<<1)+1|0]|0;t=r+3|0;u=k<<16>>16==0;if(!u){k=q<<16>>16==0;v=r+l|0;w=r+1|0;x=(w|0)==(v|0);y=n+(r+4<<2)|0;z=r+2|0;A=n+(z<<2)|0;B=v+1|0;C=n+(B<<2)|0;D=n+(v+3<<2)|0;E=n+(r+5<<2)|0;F=n+(w<<2)|0;G=n+(v<<2)|0;H=n+(v+4<<2)|0;v=w>>>1;w=v-1|0;I=B>>>1;B=(w|0)<(I|0);J=v>>>0<I>>>0;K=r>>>0<l>>>0;L=1-r|0;M=(L|0)<(l|0);N=(((z>>>0>l>>>0?z:l)+~r|0)>>>1)+1|0;z=0;do{if(!k){O=ca(z,m)|0;P=0;do{c[n+(P+t<<2)>>2]=c[i+(P+O<<2)>>2];P=P+1|0;}while((P|0)<(l|0))}do{if(!x){c[A>>2]=c[y>>2];c[D>>2]=c[C>>2];c[F>>2]=c[E>>2];c[H>>2]=c[G>>2];if(B){P=w;do{O=P<<1;Q=n+((O|1)+3<<2)|0;c[Q>>2]=(c[Q>>2]|0)-((c[n+(O+5<<2)>>2]|0)+(c[n+(O+3<<2)>>2]|0)>>1);P=P+1|0;}while((P|0)<(I|0))}if(J){R=v}else{break}do{P=R<<1;O=n+(P+3<<2)|0;c[O>>2]=((c[n+(P+2<<2)>>2]|0)+2+(c[n+((P|1)+3<<2)>>2]|0)>>2)+(c[O>>2]|0);R=R+1|0;}while((R|0)<(I|0))}}while(0);if(K){O=ca(z,m)|0;P=r;Q=0;while(1){c[i+(Q+O<<2)>>2]=c[n+(P+t<<2)>>2];S=P+2|0;if((S|0)<(l|0)){P=S;Q=Q+1|0}else{T=N;break}}}else{T=0}if(M){Q=ca(z,m)|0;P=L;O=T;while(1){c[i+(O+Q<<2)>>2]=c[n+(P+t<<2)>>2];S=P+2|0;if((S|0)<(l|0)){P=S;O=O+1|0}else{break}}}z=z+1|0;}while((z|0)<(j|0))}z=s+3|0;if(!(q<<16>>16==0)){t=s+j|0;L=s+1|0;M=(L|0)==(t|0);N=n+(s+4<<2)|0;r=s+2|0;K=n+(r<<2)|0;I=t+1|0;v=n+(I<<2)|0;J=n+(t+3<<2)|0;w=n+(s+5<<2)|0;B=n+(L<<2)|0;G=n+(t<<2)|0;H=n+(t+4<<2)|0;t=L>>>1;L=t-1|0;E=I>>>1;I=(L|0)<(E|0);F=t>>>0<E>>>0;C=s>>>0<j>>>0;D=1-s|0;y=(D|0)<(j|0);A=(((r>>>0>j>>>0?r:j)+~s|0)>>>1)+1|0;r=0;do{if(!u){x=0;do{c[n+(x+z<<2)>>2]=c[i+((ca(x,m)|0)+r<<2)>>2];x=x+1|0;}while((x|0)<(j|0))}do{if(!M){c[K>>2]=c[N>>2];c[J>>2]=c[v>>2];c[B>>2]=c[w>>2];c[H>>2]=c[G>>2];if(I){x=L;do{k=x<<1;O=n+((k|1)+3<<2)|0;c[O>>2]=(c[O>>2]|0)-((c[n+(k+5<<2)>>2]|0)+(c[n+(k+3<<2)>>2]|0)>>1);x=x+1|0;}while((x|0)<(E|0))}if(F){U=t}else{break}do{x=U<<1;k=n+(x+3<<2)|0;c[k>>2]=((c[n+(x+2<<2)>>2]|0)+2+(c[n+((x|1)+3<<2)>>2]|0)>>2)+(c[k>>2]|0);U=U+1|0;}while((U|0)<(E|0))}}while(0);if(C){k=s;x=0;while(1){c[i+((ca(x,m)|0)+r<<2)>>2]=c[n+(k+z<<2)>>2];O=k+2|0;if((O|0)<(j|0)){k=O;x=x+1|0}else{V=A;break}}}else{V=0}if(y){x=D;k=V;while(1){c[i+((ca(k,m)|0)+r<<2)>>2]=c[n+(x+z<<2)>>2];O=x+2|0;if((O|0)<(j|0)){x=O;k=k+1|0}else{break}}}r=r+1|0;}while((r|0)<(l|0))}l=p-1|0;if((p|0)<=0){o=0;break}p=l;q=b[e+(l<<2)>>1]|0}return o|0}else if((h|0)==0){q=f;p=a[e+192|0]|0;n=(p&255)-1|0;m=b[e+(n<<2)>>1]|0;i=m&65535;V=c[e+200>>2]|0;U=V+20|0;if(p<<24>>24==0){o=0;return o|0}else{W=n;X=m}while(1){m=X&65535;n=b[e+(W<<2)+2>>1]|0;p=n&65535;T=d[e+128+(W<<1)|0]|0;R=d[e+128+(W<<1)+1|0]|0;l=T+5|0;r=n<<16>>16==0;a:do{if(!r){n=T+m|0;j=T>>>0<m>>>0;z=1-T|0;D=(z|0)<(m|0);if(X<<16>>16==0){y=0;while(1){dOa(U,T,n);if(j){A=ca(y,i)|0;s=T;C=0;while(1){g[q+(C+A<<2)>>2]=+g[V+(s+l<<2)>>2]*1.625732421875*.5;E=s+2|0;if((E|0)<(m|0)){s=E;C=C+1|0}else{Y=1;break}}}else{Y=0}if(D){C=ca(y,i)|0;s=z;A=Y;while(1){g[q+(A+C<<2)>>2]=+g[V+(s+l<<2)>>2]*1.2301740646362305*.5;E=s+2|0;if((E|0)<(m|0)){s=E;A=A+1|0}else{break}}}y=y+1|0;if((y|0)>=(p|0)){break a}}}y=T+2|0;A=((y>>>0>m>>>0?y:m)+~T|0)>>>1;if(j){Z=0}else{y=0;while(1){s=ca(y,i)|0;C=0;do{g[V+(C+l<<2)>>2]=+g[q+(C+s<<2)>>2];C=C+1|0;}while((C|0)<(m|0));dOa(U,T,n);if(D){C=z;E=0;while(1){g[q+(E+s<<2)>>2]=+g[V+(C+l<<2)>>2]*1.2301740646362305*.5;t=C+2|0;if((t|0)<(m|0)){C=t;E=E+1|0}else{break}}}y=y+1|0;if((y|0)>=(p|0)){break a}}}do{y=ca(Z,i)|0;j=0;do{g[V+(j+l<<2)>>2]=+g[q+(j+y<<2)>>2];j=j+1|0;}while((j|0)<(m|0));dOa(U,T,n);j=T;E=0;while(1){g[q+(E+y<<2)>>2]=+g[V+(j+l<<2)>>2]*1.625732421875*.5;C=j+2|0;if((C|0)<(m|0)){j=C;E=E+1|0}else{break}}if(D){E=z;j=A;do{j=j+1|0;g[q+(j+y<<2)>>2]=+g[V+(E+l<<2)>>2]*1.2301740646362305*.5;E=E+2|0;}while((E|0)<(m|0))}Z=Z+1|0;}while((Z|0)<(p|0))}}while(0);l=R+5|0;if(!(X<<16>>16==0)){T=R+p|0;A=R>>>0<p>>>0;z=1-R|0;D=(z|0)<(p|0);n=R+2|0;E=(((n>>>0>p>>>0?n:p)+~R|0)>>>1)+1|0;n=0;do{if(!r){y=0;do{g[V+(y+l<<2)>>2]=+g[q+((ca(y,i)|0)+n<<2)>>2];y=y+1|0;}while((y|0)<(p|0))}dOa(U,R,T);if(A){y=R;j=0;while(1){g[q+((ca(j,i)|0)+n<<2)>>2]=+g[V+(y+l<<2)>>2]*1.625732421875*.5;C=y+2|0;if((C|0)<(p|0)){y=C;j=j+1|0}else{_=E;break}}}else{_=0}if(D){j=z;y=_;while(1){g[q+((ca(y,i)|0)+n<<2)>>2]=+g[V+(j+l<<2)>>2]*1.2301740646362305*.5;C=j+2|0;if((C|0)<(p|0)){j=C;y=y+1|0}else{break}}}n=n+1|0;}while((n|0)<(m|0))}m=W-1|0;if((W|0)<=0){o=0;break}W=m;X=b[e+(m<<2)>>1]|0}return o|0}else if((h|0)==2){h=f;f=a[e+192|0]|0;X=(f&255)-1|0;W=b[e+(X<<2)>>1]|0;V=W&65535;i=c[e+196>>2]|0;q=i+20|0;if(f<<24>>24==0){o=0;return o|0}else{$=X;aa=W}while(1){W=aa&65535;X=b[e+($<<2)+2>>1]|0;f=X&65535;_=d[e+128+($<<1)|0]|0;U=d[e+128+($<<1)+1|0]|0;Z=_+5|0;Y=X<<16>>16==0;if(!Y){X=aa<<16>>16==0;m=_+W|0;n=_>>>0<W>>>0;p=1-_|0;l=(p|0)<(W|0);z=_+2|0;D=(((z>>>0>W>>>0?z:W)+~_|0)>>>1)+1|0;z=0;do{if(!X){E=ca(z,V)|0;R=0;do{c[i+(R+Z<<2)>>2]=c[h+(R+E<<2)>>2];R=R+1|0;}while((R|0)<(W|0))}cOa(q,_,m);if(n){R=ca(z,V)|0;E=_;A=0;while(1){c[h+(A+R<<2)>>2]=((c[i+(E+Z<<2)>>2]|0)*106544|0)+65536>>17;T=E+2|0;if((T|0)<(W|0)){E=T;A=A+1|0}else{ba=D;break}}}else{ba=0}if(l){A=ca(z,V)|0;E=p;R=ba;while(1){c[h+(R+A<<2)>>2]=((c[i+(E+Z<<2)>>2]|0)*80621|0)+65536>>17;T=E+2|0;if((T|0)<(W|0)){E=T;R=R+1|0}else{break}}}z=z+1|0;}while((z|0)<(f|0))}z=U+5|0;if(!(aa<<16>>16==0)){Z=U+f|0;p=U>>>0<f>>>0;l=1-U|0;D=(l|0)<(f|0);_=U+2|0;n=(((_>>>0>f>>>0?_:f)+~U|0)>>>1)+1|0;_=0;do{if(!Y){m=0;do{c[i+(m+z<<2)>>2]=c[h+((ca(m,V)|0)+_<<2)>>2];m=m+1|0;}while((m|0)<(f|0))}cOa(q,U,Z);if(p){m=U;X=0;while(1){c[h+((ca(X,V)|0)+_<<2)>>2]=((c[i+(m+z<<2)>>2]|0)*106544|0)+65536>>17;R=m+2|0;if((R|0)<(f|0)){m=R;X=X+1|0}else{da=n;break}}}else{da=0}if(D){X=l;m=da;while(1){c[h+((ca(m,V)|0)+_<<2)>>2]=((c[i+(X+z<<2)>>2]|0)*80621|0)+65536>>17;R=X+2|0;if((R|0)<(f|0)){X=R;m=m+1|0}else{break}}}_=_+1|0;}while((_|0)<(W|0))}W=$-1|0;if(($|0)<=0){o=0;break}$=W;aa=b[e+(W<<2)>>1]|0}return o|0}else{o=-1;return o|0}return 0}function ZNa(f,h){f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;i=d[f+193|0]|0;if((i|0)==1){j=h;k=f+192|0;l=a[k]|0;m=e[f+((l&255)-1<<2)>>1]|0;n=c[f+196>>2]|0;o=n+12|0;if(l<<24>>24==0){p=0;return p|0}else{q=0}while(1){l=b[f+(q<<2)>>1]|0;r=l&65535;s=b[f+(q<<2)+2>>1]|0;t=s&65535;u=d[f+128+(q<<1)|0]|0;v=d[f+128+(q<<1)+1|0]|0;w=u+3|0;x=s<<16>>16==0;if(!x){s=u>>>0<r>>>0;y=1-u|0;z=(y|0)<(r|0);A=u+r|0;B=l<<16>>16==0;C=u+2|0;D=(((C>>>0>r>>>0?C:r)+~u|0)>>>1)+1|0;C=0;do{if(s){E=ca(C,m)|0;F=u;G=0;while(1){c[n+(F+w<<2)>>2]=c[j+(G+E<<2)>>2];H=F+2|0;if((H|0)<(r|0)){F=H;G=G+1|0}else{I=D;break}}}else{I=0}if(z){G=ca(C,m)|0;F=y;E=I;while(1){c[n+(F+w<<2)>>2]=c[j+(E+G<<2)>>2];H=F+2|0;if((H|0)<(r|0)){F=H;E=E+1|0}else{break}}}$Na(o,u,A);if(!B){E=ca(C,m)|0;F=0;do{c[j+(F+E<<2)>>2]=c[n+(F+w<<2)>>2];F=F+1|0;}while((F|0)<(r|0))}C=C+1|0;}while((C|0)<(t|0))}C=v+3|0;if(!(l<<16>>16==0)){w=v>>>0<t>>>0;B=1-v|0;A=(B|0)<(t|0);u=v+t|0;y=v+2|0;z=(((y>>>0>t>>>0?y:t)+~v|0)>>>1)+1|0;y=0;do{if(w){D=v;s=0;while(1){c[n+(D+C<<2)>>2]=c[j+((ca(s,m)|0)+y<<2)>>2];F=D+2|0;if((F|0)<(t|0)){D=F;s=s+1|0}else{J=z;break}}}else{J=0}if(A){s=B;D=J;while(1){c[n+(s+C<<2)>>2]=c[j+((ca(D,m)|0)+y<<2)>>2];F=s+2|0;if((F|0)<(t|0)){s=F;D=D+1|0}else{break}}}$Na(o,v,u);if(!x){D=0;do{c[j+((ca(D,m)|0)+y<<2)>>2]=c[n+(D+C<<2)>>2];D=D+1|0;}while((D|0)<(t|0))}y=y+1|0;}while((y|0)<(r|0))}r=q+1|0;if((r|0)<(d[k]|0|0)){q=r}else{p=0;break}}return p|0}else if((i|0)==2){q=h;k=f+192|0;n=a[k]|0;m=e[f+((n&255)-1<<2)>>1]|0;j=c[f+196>>2]|0;o=j+20|0;if(n<<24>>24==0){p=0;return p|0}else{K=0}while(1){n=b[f+(K<<2)>>1]|0;J=n&65535;I=b[f+(K<<2)+2>>1]|0;r=I&65535;y=d[f+128+(K<<1)|0]|0;t=d[f+128+(K<<1)+1|0]|0;C=y+5|0;x=I<<16>>16==0;if(!x){I=y>>>0<J>>>0;u=1-y|0;v=(u|0)<(J|0);B=y+J|0;A=n<<16>>16==0;z=y+2|0;w=(((z>>>0>J>>>0?z:J)+~y|0)>>>1)+1|0;z=0;do{if(I){l=ca(z,m)|0;D=y;s=0;while(1){c[j+(D+C<<2)>>2]=((c[q+(s+l<<2)>>2]|0)*80621|0)+32768>>16;F=D+2|0;if((F|0)<(J|0)){D=F;s=s+1|0}else{L=w;break}}}else{L=0}if(v){s=ca(z,m)|0;D=u;l=L;while(1){c[j+(D+C<<2)>>2]=((c[q+(l+s<<2)>>2]|0)*106544|0)+32768>>16;F=D+2|0;if((F|0)<(J|0)){D=F;l=l+1|0}else{break}}}aOa(o,y,B);if(!A){l=ca(z,m)|0;D=0;do{c[q+(D+l<<2)>>2]=c[j+(D+C<<2)>>2];D=D+1|0;}while((D|0)<(J|0))}z=z+1|0;}while((z|0)<(r|0))}z=t+5|0;if(!(n<<16>>16==0)){C=t>>>0<r>>>0;A=1-t|0;B=(A|0)<(r|0);y=t+r|0;u=t+2|0;v=(((u>>>0>r>>>0?u:r)+~t|0)>>>1)+1|0;u=0;do{if(C){w=t;I=0;while(1){c[j+(w+z<<2)>>2]=((c[q+((ca(I,m)|0)+u<<2)>>2]|0)*80621|0)+32768>>16;D=w+2|0;if((D|0)<(r|0)){w=D;I=I+1|0}else{M=v;break}}}else{M=0}if(B){I=A;w=M;while(1){c[j+(I+z<<2)>>2]=((c[q+((ca(w,m)|0)+u<<2)>>2]|0)*106544|0)+32768>>16;D=I+2|0;if((D|0)<(r|0)){I=D;w=w+1|0}else{break}}}aOa(o,t,y);if(!x){w=0;do{c[q+((ca(w,m)|0)+u<<2)>>2]=c[j+(w+z<<2)>>2];w=w+1|0;}while((w|0)<(r|0))}u=u+1|0;}while((u|0)<(J|0))}J=K+1|0;if((J|0)<(d[k]|0|0)){K=J}else{p=0;break}}return p|0}else if((i|0)==0){i=h;h=f+192|0;K=a[h]|0;k=e[f+((K&255)-1<<2)>>1]|0;j=c[f+200>>2]|0;m=j+20|0;if(K<<24>>24==0){p=0;return p|0}else{N=0}while(1){K=b[f+(N<<2)>>1]|0;q=K&65535;o=b[f+(N<<2)+2>>1]|0;M=o&65535;L=d[f+128+(N<<1)|0]|0;J=d[f+128+(N<<1)+1|0]|0;u=L+5|0;r=o<<16>>16==0;if(!r){o=L>>>0<q>>>0;z=1-L|0;x=(z|0)<(q|0);y=L+q|0;t=K<<16>>16==0;A=L+2|0;B=(((A>>>0>q>>>0?A:q)+~L|0)>>>1)+1|0;A=0;do{if(o){v=ca(A,k)|0;C=L;n=0;while(1){g[j+(C+u<<2)>>2]=+g[i+(n+v<<2)>>2]*1.2301740646362305;w=C+2|0;if((w|0)<(q|0)){C=w;n=n+1|0}else{O=B;break}}}else{O=0}if(x){n=ca(A,k)|0;C=z;v=O;while(1){g[j+(C+u<<2)>>2]=+g[i+(v+n<<2)>>2]*1.625732421875;w=C+2|0;if((w|0)<(q|0)){C=w;v=v+1|0}else{break}}}bOa(m,L,y);if(!t){v=ca(A,k)|0;C=0;do{g[i+(C+v<<2)>>2]=+g[j+(C+u<<2)>>2];C=C+1|0;}while((C|0)<(q|0))}A=A+1|0;}while((A|0)<(M|0))}A=J+5|0;if(!(K<<16>>16==0)){u=J>>>0<M>>>0;t=1-J|0;y=(t|0)<(M|0);L=J+M|0;z=J+2|0;x=(((z>>>0>M>>>0?z:M)+~J|0)>>>1)+1|0;z=0;do{if(u){B=J;o=0;while(1){g[j+(B+A<<2)>>2]=+g[i+((ca(o,k)|0)+z<<2)>>2]*1.2301740646362305;C=B+2|0;if((C|0)<(M|0)){B=C;o=o+1|0}else{P=x;break}}}else{P=0}if(y){o=t;B=P;while(1){g[j+(o+A<<2)>>2]=+g[i+((ca(B,k)|0)+z<<2)>>2]*1.625732421875;C=o+2|0;if((C|0)<(M|0)){o=C;B=B+1|0}else{break}}}bOa(m,J,L);if(!r){B=0;do{g[i+((ca(B,k)|0)+z<<2)>>2]=+g[j+(B+A<<2)>>2];B=B+1|0;}while((B|0)<(M|0))}z=z+1|0;}while((z|0)<(q|0))}q=N+1|0;if((q|0)<(d[h]|0|0)){N=q}else{p=0;break}}return p|0}else{p=-1;return p|0}return 0}function _Na(a){a=a|0;mJb(a+200|0);mJb(a+196|0);return}function $Na(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+1|0;if((e|0)==(d|0)){return}c[a+(b-1<<2)>>2]=c[a+(e<<2)>>2];c[a+(d<<2)>>2]=c[a+(d-2<<2)>>2];c[a+(b-2<<2)>>2]=c[a+(b+2<<2)>>2];c[a+(d+1<<2)>>2]=c[a+(d-3<<2)>>2];e=(b|0)/2|0;b=(d|0)/2|0;d=b+1|0;if((e|0)<(d|0)){f=e;do{g=f<<1;h=a+(g<<2)|0;c[h>>2]=(c[h>>2]|0)-((c[a+(g-1<<2)>>2]|0)+2+(c[a+((g|1)<<2)>>2]|0)>>2);f=f+1|0;}while((f|0)<(d|0))}if((e|0)<(b|0)){i=e}else{return}do{e=i<<1;d=a+((e|1)<<2)|0;c[d>>2]=((c[a+(e+2<<2)>>2]|0)+(c[a+(e<<2)>>2]|0)>>1)+(c[d>>2]|0);i=i+1|0;}while((i|0)<(b|0));return}function aOa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+1|0;if((e|0)==(d|0)){return}c[a+(b-1<<2)>>2]=c[a+(e<<2)>>2];c[a+(d<<2)>>2]=c[a+(d-2<<2)>>2];c[a+(b-2<<2)>>2]=c[a+(b+2<<2)>>2];c[a+(d+1<<2)>>2]=c[a+(d-3<<2)>>2];c[a+(b-3<<2)>>2]=c[a+(b+3<<2)>>2];c[a+(d+2<<2)>>2]=c[a+(d-4<<2)>>2];c[a+(b-4<<2)>>2]=c[a+(b+4<<2)>>2];c[a+(d+3<<2)>>2]=c[a+(d-5<<2)>>2];e=(b|0)/2|0;b=e-1|0;f=(d|0)/2|0;d=f+2|0;if((b|0)<(d|0)){g=b;do{h=g<<1;i=a+(h<<2)|0;c[i>>2]=(c[i>>2]|0)-((((c[a+((h|1)<<2)>>2]|0)+(c[a+(h-1<<2)>>2]|0)|0)*29066|0)+32768>>16);g=g+1|0;}while((g|0)<(d|0))}d=f+1|0;if((b|0)<(d|0)){g=b;do{b=g<<1;h=a+((b|1)<<2)|0;c[h>>2]=(c[h>>2]|0)-((((c[a+(b+2<<2)>>2]|0)+(c[a+(b<<2)>>2]|0)|0)*57862|0)+32768>>16);g=g+1|0;}while((g|0)<(d|0))}if((e|0)<(d|0)){g=e;do{b=g<<1;h=a+(b<<2)|0;c[h>>2]=((((c[a+((b|1)<<2)>>2]|0)+(c[a+(b-1<<2)>>2]|0)|0)*3472|0)+32768>>16)+(c[h>>2]|0);g=g+1|0;}while((g|0)<(d|0))}if((e|0)<(f|0)){j=e}else{return}do{e=j<<1;d=a+((e|1)<<2)|0;c[d>>2]=((((c[a+(e+2<<2)>>2]|0)+(c[a+(e<<2)>>2]|0)|0)*103949|0)+32768>>16)+(c[d>>2]|0);j=j+1|0;}while((j|0)<(f|0));return}function bOa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0,j=0;d=b+1|0;if((d|0)==(c|0)){return}g[a+(b-1<<2)>>2]=+g[a+(d<<2)>>2];g[a+(c<<2)>>2]=+g[a+(c-2<<2)>>2];g[a+(b-2<<2)>>2]=+g[a+(b+2<<2)>>2];g[a+(c+1<<2)>>2]=+g[a+(c-3<<2)>>2];g[a+(b-3<<2)>>2]=+g[a+(b+3<<2)>>2];g[a+(c+2<<2)>>2]=+g[a+(c-4<<2)>>2];g[a+(b-4<<2)>>2]=+g[a+(b+4<<2)>>2];g[a+(c+3<<2)>>2]=+g[a+(c-5<<2)>>2];d=(b|0)/2|0;b=d-1|0;e=(c|0)/2|0;c=e+2|0;if((b|0)<(c|0)){f=b;do{h=f<<1;i=a+(h<<2)|0;g[i>>2]=+g[i>>2]-(+g[a+(h-1<<2)>>2]+ +g[a+((h|1)<<2)>>2])*.4435068666934967;f=f+1|0;}while((f|0)<(c|0))}c=e+1|0;if((b|0)<(c|0)){f=b;do{b=f<<1;h=a+((b|1)<<2)|0;g[h>>2]=+g[h>>2]-(+g[a+(b<<2)>>2]+ +g[a+(b+2<<2)>>2])*.8829110860824585;f=f+1|0;}while((f|0)<(c|0))}if((d|0)<(c|0)){f=d;do{b=f<<1;h=a+(b<<2)|0;g[h>>2]=+g[h>>2]+(+g[a+(b-1<<2)>>2]+ +g[a+((b|1)<<2)>>2])*.05298011749982834;f=f+1|0;}while((f|0)<(c|0))}if((d|0)<(e|0)){j=d}else{return}do{d=j<<1;c=a+((d|1)<<2)|0;g[c>>2]=+g[c>>2]+(+g[a+(d<<2)>>2]+ +g[a+(d+2<<2)>>2])*1.5861343145370483;j=j+1|0;}while((j|0)<(e|0));return}function cOa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+1|0;if((e|0)==(d|0)){return}c[a+(b-1<<2)>>2]=c[a+(e<<2)>>2];c[a+(d<<2)>>2]=c[a+(d-2<<2)>>2];c[a+(b-2<<2)>>2]=c[a+(b+2<<2)>>2];f=d+1|0;c[a+(f<<2)>>2]=c[a+(d-3<<2)>>2];c[a+(b-3<<2)>>2]=c[a+(b+3<<2)>>2];c[a+(d+2<<2)>>2]=c[a+(d-4<<2)>>2];c[a+(b-4<<2)>>2]=c[a+(b+4<<2)>>2];c[a+(d+3<<2)>>2]=c[a+(d-5<<2)>>2];d=(e|0)/2|0;e=d-2|0;b=(f|0)/2|0;f=b+1|0;if((e|0)<(f|0)){g=e;do{e=g<<1;h=a+((e|1)<<2)|0;c[h>>2]=(c[h>>2]|0)-((((c[a+(e+2<<2)>>2]|0)+(c[a+(e<<2)>>2]|0)|0)*103949|0)+32768>>16);g=g+1|0;}while((g|0)<(f|0))}g=d-1|0;if((g|0)<(f|0)){e=g;do{h=e<<1;i=a+(h<<2)|0;c[i>>2]=(c[i>>2]|0)-((((c[a+((h|1)<<2)>>2]|0)+(c[a+(h-1<<2)>>2]|0)|0)*3472|0)+32768>>16);e=e+1|0;}while((e|0)<(f|0))}if((g|0)<(b|0)){f=g;do{g=f<<1;e=a+((g|1)<<2)|0;c[e>>2]=((((c[a+(g+2<<2)>>2]|0)+(c[a+(g<<2)>>2]|0)|0)*57862|0)+32768>>16)+(c[e>>2]|0);f=f+1|0;}while((f|0)<(b|0))}if((d|0)<(b|0)){j=d}else{return}do{d=j<<1;f=a+(d<<2)|0;c[f>>2]=((((c[a+((d|1)<<2)>>2]|0)+(c[a+(d-1<<2)>>2]|0)|0)*29066|0)+32768>>16)+(c[f>>2]|0);j=j+1|0;}while((j|0)<(b|0));return}function dOa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0,j=0;d=b+1|0;if((d|0)==(c|0)){return}g[a+(b-1<<2)>>2]=+g[a+(d<<2)>>2];g[a+(c<<2)>>2]=+g[a+(c-2<<2)>>2];g[a+(b-2<<2)>>2]=+g[a+(b+2<<2)>>2];e=c+1|0;g[a+(e<<2)>>2]=+g[a+(c-3<<2)>>2];g[a+(b-3<<2)>>2]=+g[a+(b+3<<2)>>2];g[a+(c+2<<2)>>2]=+g[a+(c-4<<2)>>2];g[a+(b-4<<2)>>2]=+g[a+(b+4<<2)>>2];g[a+(c+3<<2)>>2]=+g[a+(c-5<<2)>>2];c=(d|0)/2|0;d=c-2|0;b=(e|0)/2|0;e=b+1|0;if((d|0)<(e|0)){f=d;do{d=f<<1;h=a+((d|1)<<2)|0;g[h>>2]=+g[h>>2]-(+g[a+(d<<2)>>2]+ +g[a+(d+2<<2)>>2])*1.586134;f=f+1|0;}while((f|0)<(e|0))}f=c-1|0;if((f|0)<(e|0)){d=f;do{h=d<<1;i=a+(h<<2)|0;g[i>>2]=+g[i>>2]-(+g[a+(h-1<<2)>>2]+ +g[a+((h|1)<<2)>>2])*.05298;d=d+1|0;}while((d|0)<(e|0))}if((f|0)<(b|0)){e=f;do{f=e<<1;d=a+((f|1)<<2)|0;g[d>>2]=+g[d>>2]+(+g[a+(f<<2)>>2]+ +g[a+(f+2<<2)>>2])*.882911;e=e+1|0;}while((e|0)<(b|0))}if((c|0)<(b|0)){j=c}else{return}do{c=j<<1;e=a+(c<<2)|0;g[e>>2]=+g[e>>2]+(+g[a+(c-1<<2)>>2]+ +g[a+((c|1)<<2)>>2])*.443506;j=j+1|0;}while((j|0)<(b|0));return}function eOa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;e=a+16|0;f=c[a+24>>2]|0;g=(c[e>>2]|0)+16|0;h=f>>>0>g>>>0?g:f;c[e>>2]=h;g=c[a+8>>2]|0;j=g+(h>>>3)|0;k=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>24;j=h+8|0;h=f>>>0>j>>>0?j:f;c[e>>2]=h;if((k|0)==1){j=g+(h>>>3)|0;l=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>16;j=h+16|0;h=f>>>0>j>>>0?j:f;c[e>>2]=h;c[a+876>>2]=l;l=g+(h>>>3)|0;j=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>16;l=h+16|0;h=f>>>0>l>>>0?l:f;c[e>>2]=h;c[a+884>>2]=j;j=g+(h>>>3)|0;l=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>16;j=h+16|0;h=f>>>0>j>>>0?j:f;c[e>>2]=h;c[a+888>>2]=l;l=g+(h>>>3)|0;j=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>16;l=h+16|0;h=f>>>0>l>>>0?l:f;c[e>>2]=h;c[a+892>>2]=j;j=g+(h>>>3)|0;g=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>16;j=h+16|0;c[e>>2]=f>>>0>j>>>0?j:f;c[a+896>>2]=g;m=0;i=b;return m|0}else if((k|0)==2|(k|0)==3){KIb(c[a+4>>2]|0,16,2524120,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-38;i=b;return m|0}else if((k|0)==4){KIb(c[a+4>>2]|0,16,2603064,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-38;i=b;return m|0}else{KIb(c[a+4>>2]|0,16,2451384,(n=i,i=i+8|0,c[n>>2]=k,n)|0);i=n;m=-1094995529;i=b;return m|0}return 0}function fOa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;k=i;i=i+16|0;l=k|0;m=f+1140|0;n=pJb(c[(c[m>>2]|0)+32>>2]|0)|0;o=c[c[m>>2]>>2]|0;p=pJb(5924)|0;q=p;r=p+5900|0;c[r>>2]=g;g=f+860|0;s=c[g>>2]|0;c[p+5884>>2]=(s|0)<2?2:s;s=p+5892|0;c[s>>2]=c[f+876>>2];t=p;c[t>>2]=c[f+884>>2];u=p+4|0;c[u>>2]=c[f+888>>2];v=p+8|0;c[v>>2]=c[f+892>>2];w=p+5880|0;c[w>>2]=c[f+896>>2];Eqb(q,0);Dqb(q);x=c[g>>2]|0;y=((x|0)<9?8:16)-x+h|0;x=f+4|0;z=c[x>>2]|0;if((c[z+688>>2]&1|0)!=0){A=c[f+904>>2]|0;B=c[r>>2]|0;r=c[s>>2]|0;s=c[t>>2]|0;t=c[u>>2]|0;u=c[v>>2]|0;v=c[w>>2]|0;w=c[p+5876>>2]|0;C=c[p+5888>>2]|0;D=c[p+5896>>2]|0;KIb(z,48,2362048,(E=i,i=i+88|0,c[E>>2]=c[f+900>>2],c[E+8>>2]=A,c[E+16>>2]=B,c[E+24>>2]=r,c[E+32>>2]=s,c[E+40>>2]=t,c[E+48>>2]=u,c[E+56>>2]=v,c[E+64>>2]=w,c[E+72>>2]=C,c[E+80>>2]=D,E)|0);i=E;D=c[g>>2]|0;C=c[f+2968>>2]|0;KIb(c[x>>2]|0,48,2297392,(E=i,i=i+32|0,c[E>>2]=j,c[E+8>>2]=h,c[E+16>>2]=D,c[E+24>>2]=C,E)|0);i=E}a:do{if((j|0)==2){RIb(c[x>>2]|0,2246576,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1163346256;kJb(p);kJb(n);i=k;return F|0}else if((j|0)==0){C=c[f+2968>>2]|0;D=c[f+916>>2]|0;if((C|0)>(D|0)){F=-1094995529;kJb(p);kJb(n);i=k;return F|0}h=(D|0)>1?3:1;D=C-1|0;C=h-1|0;if((D|0)<0){G=0}else{G=(D|0)>(C|0)?C:D}D=ca(c[f+900>>2]|0,h)|0;C=f+904|0;if((c[C>>2]|0)<=0){H=G;I=h;break}w=f+2944|0;v=f+2948|0;u=f+16|0;t=f+24|0;s=o+G|0;r=n;B=0;A=1;while(1){if((c[g>>2]|0)<9){gOa(q,f,r,s,B,D,h,G,8);J=d[r]|0}else{gOa(q,f,r,s,B,D,h,G,16);J=e[r>>1]|0}z=s+(c[(c[m>>2]|0)+32>>2]|0)|0;do{if((c[w>>2]|0)!=0){K=(c[v>>2]|0)-1|0;c[v>>2]=K;if((K|0)!=0){break}K=c[u>>2]|0;L=-K&7;M=c[t>>2]|0;if((L|0)==0){N=K}else{O=L+K|0;K=M>>>0>O>>>0?O:M;c[u>>2]=K;N=K}K=N+16|0;c[u>>2]=M>>>0>K>>>0?K:M}}while(0);if((A|0)>=(c[C>>2]|0)){H=G;I=h;break a}r=s;s=z;B=J;A=A+1|0}}else if((j|0)==1){mrc(l|0,0,12)|0;A=(c[f+916>>2]|0)>1?3:1;mrc(o|0,0,c[(c[m>>2]|0)+32>>2]|0)|0;B=ca(c[f+900>>2]|0,A)|0;s=f+904|0;if((c[s>>2]|0)<=0){H=0;I=A;break}r=f+2944|0;h=f+2948|0;C=f+16|0;u=f+24|0;t=o;v=n;w=0;while(1){D=0;do{M=v+D|0;K=l+(D<<2)|0;gOa(q,f,M,t+D|0,c[K>>2]|0,B,A,D,8);c[K>>2]=d[M]|0;do{if((c[r>>2]|0)!=0){M=(c[h>>2]|0)-1|0;c[h>>2]=M;if((M|0)!=0){break}M=c[C>>2]|0;K=-M&7;O=c[u>>2]|0;if((K|0)==0){P=M}else{L=K+M|0;M=O>>>0>L>>>0?L:O;c[C>>2]=M;P=M}M=P+16|0;c[C>>2]=O>>>0>M>>>0?M:O}}while(0);D=D+1|0;}while((D|0)<(A|0));D=w+1|0;if((D|0)<(c[s>>2]|0)){v=t;t=t+(c[(c[m>>2]|0)+32>>2]|0)|0;w=D}else{H=0;I=A;break}}}else{H=0;I=1}}while(0);P=f+868|0;q=c[P>>2]|0;b:do{if((q|0)!=0){if((c[f+916>>2]|0)!=3){break}l=(c[f+900>>2]|0)*3|0;if((c[g>>2]|0)>=9){RIb(c[x>>2]|0,2204904,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;break}o=f+904|0;if((c[o>>2]|0)<=0){break}j=(H|0)<(l|0);J=c[c[m>>2]>>2]|0;G=1;N=q;while(1){do{if((N|0)==1){if(j){Q=H}else{break}do{A=a[J+(Q+1)|0]^-128;w=J+Q|0;a[w]=(a[w]|0)+A;w=J+(Q+2)|0;a[w]=(a[w]|0)+A;Q=Q+3|0;}while((Q|0)<(l|0))}else if((N|0)==3){if(j){R=H}else{break}do{A=J+R|0;w=J+(R+2)|0;t=d[w]|0;v=J+(R+1)|0;s=d[v]|0;C=(d[A]|0)-((s+t|0)>>>2)+64|0;a[A]=t+128+C;a[w]=s+128+C;a[v]=C;R=R+3|0;}while((R|0)<(l|0))}else if((N|0)==4){if(j){S=H}else{break}do{C=J+S|0;v=d[C]|0;s=J+(S+2)|0;w=(d[s]|0)-128|0;t=v-((w*359|0)+490>>8)|0;A=J+(S+1)|0;u=(d[A]|0)-128|0;h=v-((w*-183|0)+30+(u*88|0)>>8)|0;w=((u*454|0)+574>>8)+v|0;if(t>>>0>255>>>0){T=-t>>31&255}else{T=t&255}a[C]=T;if(h>>>0>255>>>0){U=-h>>31&255}else{U=h&255}a[A]=U;if(w>>>0>255>>>0){V=-w>>31&255}else{V=w&255}a[s]=V;S=S+3|0;}while((S|0)<(l|0))}else if((N|0)==2){if(j){W=H}else{break}do{s=a[J+(W+1)|0]|0;w=J+W|0;A=(a[w]|0)+(s^-128)&255;a[w]=A;w=J+(W+2)|0;a[w]=(d[w]|0)+128+(((A&255)+(s&255)|0)>>>1);W=W+3|0;}while((W|0)<(l|0))}}while(0);if((G|0)>=(c[o>>2]|0)){break b}J=J+(c[(c[m>>2]|0)+32>>2]|0)|0;G=G+1|0;N=c[P>>2]|0}}}while(0);if((y|0)==0){F=0;kJb(p);kJb(n);i=k;return F|0}P=ca(c[f+916>>2]|0,c[f+900>>2]|0)|0;W=c[m>>2]|0;S=c[W>>2]|0;V=f+904|0;f=c[V>>2]|0;U=(f|0)>0;if((c[g>>2]|0)>=9){if(!U){F=0;kJb(p);kJb(n);i=k;return F|0}g=(P|0)>0;T=(c[W+32>>2]|0)/2|0;R=0;Q=S;while(1){if(g){q=0;do{E=Q+(q<<1)|0;b[E>>1]=(e[E>>1]|0)<<y;q=q+1|0;}while((q|0)<(P|0))}q=R+1|0;if((q|0)<(f|0)){R=q;Q=Q+(T<<1)|0}else{F=0;break}}kJb(p);kJb(n);i=k;return F|0}if(!U){F=0;kJb(p);kJb(n);i=k;return F|0}U=(H|0)<(P|0);T=0;Q=S;S=W;W=f;while(1){if(U){f=H;do{R=Q+f|0;a[R]=(d[R]|0)<<y;f=f+I|0;}while((f|0)<(P|0));X=c[m>>2]|0;Y=c[V>>2]|0}else{X=S;Y=W}f=T+1|0;if((f|0)<(Y|0)){T=f;Q=Q+(c[X+32>>2]|0)|0;S=X;W=Y}else{F=0;break}}kJb(p);kJb(n);i=k;return F|0}function gOa(f,g,h,i,j,k,l,m,n){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;if((k|0)<=0){return}o=(n|0)==8;n=i;p=h;q=k-l|0;r=f+5900|0;s=f+5892|0;t=g+8|0;u=f+8|0;v=f+4|0;w=f|0;x=f+5896|0;y=f+5904|0;z=g+16|0;A=t|0;B=g+24|0;g=f+5908+(m<<2)|0;m=f+5876|0;C=f+5888|0;D=f+5880|0;E=0;a:while(1){F=(E|0)!=0;do{if(F){G=E-l|0;if(o){H=i+G|0;I=8;break}else{J=n+(G<<1)|0;I=9;break}}else{if(o){H=h;I=8}else{J=p;I=9}}}while(0);if((I|0)==8){I=0;K=d[h+E|0]|0;L=d[H]|0}else if((I|0)==9){I=0;K=e[p+(E<<1)>>1]|0;L=e[J>>1]|0}do{if(F){G=E-l|0;if(o){M=d[h+G|0]|0;break}else{M=e[p+(G<<1)>>1]|0;break}}else{M=j}}while(0);do{if((E|0)<(q|0)){F=E+l|0;if(o){N=d[h+F|0]|0;break}else{N=e[p+(F<<1)>>1]|0;break}}else{if(o){N=d[h+E|0]|0;break}else{N=e[p+(E<<1)>>1]|0;break}}}while(0);F=N-K|0;G=K-M|0;O=M-L|0;P=c[r>>2]|0;do{if((((F|0)>-1?F:-F|0)|0)>(P|0)){I=83}else{if((((G|0)>-1?G:-G|0)|0)>(P|0)){I=83;break}if((((O|0)>-1?O:-O|0)|0)>(P|0)){I=83;break}Q=L&255;R=L&65535;b:do{if(o){S=E;while(1){T=c[z>>2]|0;U=c[A>>2]|0;V=d[U+(T>>>3)|0]|0;W=c[B>>2]|0;X=((T|0)<(W|0))+T|0;c[z>>2]=X;Y=c[g>>2]|0;Z=a[1359920+Y|0]|0;_=Z&255;if((V&128>>>((T&7)>>>0)|0)==0){$=S;aa=X;ba=Z;da=_;ea=W;fa=U;break b}if(((l<<_)+S|0)>(k|0)){ga=(k-S|0)/(l|0)|0}else{ga=1<<_}if((ga|0)>0){_=ca(ga,l)|0;U=S;W=0;while(1){a[i+U|0]=Q;X=W+1|0;if((X|0)<(ga|0)){U=U+l|0;W=X}else{break}}W=c[g>>2]|0;ha=S+_|0;ia=W;ja=a[1359920+W|0]|0}else{ha=S;ia=Y;ja=Z}if((ga|0)!=(1<<(ja&255)|0)){I=138;break a}if((ia|0)<31){c[g>>2]=ia+1}if((ha+l|0)>(k|0)){I=138;break a}else{S=ha}}}else{S=c[A>>2]|0;W=E;while(1){U=c[z>>2]|0;X=d[S+(U>>>3)|0]|0;T=c[B>>2]|0;V=((U|0)<(T|0))+U|0;c[z>>2]=V;ka=c[g>>2]|0;la=a[1359920+ka|0]|0;ma=la&255;if((X&128>>>((U&7)>>>0)|0)==0){$=W;aa=V;ba=la;da=ma;ea=T;fa=S;break b}T=1<<ma;if(((l<<ma)+W|0)>(k|0)){na=(k-W|0)/(l|0)|0}else{na=T}if((na|0)>0){ma=ca(na,l)|0;la=W;V=0;while(1){b[n+(la<<1)>>1]=R;U=V+1|0;if((U|0)<(na|0)){la=la+l|0;V=U}else{break}}oa=W+ma|0}else{oa=W}if((na|0)!=(T|0)){I=138;break a}if((ka|0)<31){c[g>>2]=ka+1}if((oa+l|0)>(k|0)){I=138;break a}else{W=oa}}}}while(0);do{if(ba<<24>>24==0){pa=da}else{W=fa+(aa>>>3)|0;S=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(aa&7);if((ba&255)>>>0<26>>>0){W=aa+da|0;c[z>>2]=ea>>>0>W>>>0?W:ea;pa=S>>>((32-da|0)>>>0);break}else{W=aa+16|0;V=ea>>>0>W>>>0?W:ea;c[z>>2]=V;W=da-16|0;la=fa+(V>>>3)|0;Z=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(V&7)>>>((48-da|0)>>>0);la=V+W|0;c[z>>2]=ea>>>0>la>>>0?la:ea;pa=Z|S>>>16<<W;break}}}while(0);if(((ca(pa,l)|0)+$|0)>(k|0)){qa=(k-$|0)/(l|0)|0}else{qa=pa}if((qa|0)>0){if(o){W=$;S=0;while(1){a[i+W|0]=Q;Z=S+1|0;if((Z|0)<(qa|0)){W=W+l|0;S=Z}else{break}}}else{S=$;W=0;while(1){b[n+(S<<1)>>1]=R;Q=W+1|0;if((Q|0)<(qa|0)){S=S+l|0;W=Q}else{break}}}ra=$+(ca(qa,l)|0)|0}else{ra=$}if(o){sa=d[h+ra|0]|0}else{sa=e[p+(ra<<1)>>1]|0}W=L-sa|0;S=(((W|0)>-1?W:-W|0)|0)<=(c[r>>2]|0);W=S&1;R=d[1359920+(c[g>>2]|0)|0]|0;Q=S?366:365;Z=f+12+(Q<<2)|0;la=c[Z>>2]|0;V=f+4408+(Q<<2)|0;Y=c[V>>2]|0;if(S){ta=(Y>>1)+la|0}else{ta=la}la=0;while(1){if((Y<<la|0)<(ta|0)){la=la+1|0}else{break}}Y=iOa(t,la,(c[m>>2]|0)+~R|0,c[C>>2]|0)|0;do{if((la|0)==0){if((Y|0)==0&(S^1)){ua=0;break}ua=(c[f+1480+(Q<<2)>>2]<<1|0)<(c[V>>2]|0)|0}else{ua=0}}while(0);la=Y+W+ua|0;if((la&1|0)==0){va=la>>1}else{R=f+1480+(Q<<2)|0;c[R>>2]=(c[R>>2]|0)+1;va=ua-(la+1>>1)|0}la=(va|0)>-1?va:-va|0;if((la|0)>65535){wa=-65536}else{R=(c[Z>>2]|0)+(la-W)|0;c[Z>>2]=R;la=ca(c[y>>2]|0,va)|0;_=c[V>>2]|0;if((_|0)==(c[D>>2]|0)){c[Z>>2]=R>>1;R=f+1480+(Q<<2)|0;c[R>>2]=c[R>>2]>>1;R=_>>1;c[V>>2]=R;xa=R}else{xa=_}c[V>>2]=xa+1;wa=la}la=c[g>>2]|0;if((la|0)!=0){c[g>>2]=la-1}la=c[r>>2]|0;if(!((la|0)==0|S^1)){ya=wa+L|0;za=ra;Aa=la;break}if(sa>>>0<L>>>0){ya=sa-wa|0;za=ra;Aa=la;break}else{ya=wa+sa|0;za=ra;Aa=la;break}}}while(0);if((I|0)==83){I=0;do{if((N|0)==(K|0)){Ba=0}else{if((F|0)<0){if((F|0)<=(-(c[u>>2]|0)|0)){Ba=-4;break}if((F|0)<=(-(c[v>>2]|0)|0)){Ba=-3;break}if((F|0)<=(-(c[w>>2]|0)|0)){Ba=-2;break}Ba=((F|0)<(-P|0))<<31>>31;break}else{if((P|0)>=(F|0)){Ba=0;break}if((c[w>>2]|0)>(F|0)){Ba=1;break}if((c[v>>2]|0)>(F|0)){Ba=2;break}Ba=(c[u>>2]|0)>(F|0)?3:4;break}}}while(0);F=Ba*81|0;do{if((K|0)==(M|0)){Ca=0}else{if((G|0)<0){if((G|0)<=(-(c[u>>2]|0)|0)){Ca=-4;break}if((G|0)<=(-(c[v>>2]|0)|0)){Ca=-3;break}if((G|0)<=(-(c[w>>2]|0)|0)){Ca=-2;break}Ca=((G|0)<(-P|0))<<31>>31;break}else{if((P|0)>=(G|0)){Ca=0;break}if((c[w>>2]|0)>(G|0)){Ca=1;break}if((c[v>>2]|0)>(G|0)){Ca=2;break}Ca=(c[u>>2]|0)>(G|0)?3:4;break}}}while(0);G=(Ca*9|0)+F|0;do{if((M|0)==(L|0)){Da=0}else{if((O|0)<0){if((O|0)<=(-(c[u>>2]|0)|0)){Da=-4;break}if((O|0)<=(-(c[v>>2]|0)|0)){Da=-3;break}if((O|0)<=(-(c[w>>2]|0)|0)){Da=-2;break}Da=((O|0)<(-P|0))<<31>>31;break}else{if((P|0)>=(O|0)){Da=0;break}if((c[w>>2]|0)>(O|0)){Da=1;break}if((c[v>>2]|0)>(O|0)){Da=2;break}Da=(c[u>>2]|0)>(O|0)?3:4;break}}}while(0);O=G+Da|0;P=K+L-M|0;do{if((L|0)>(P|0)){if((K|0)<=(P|0)){Ea=P;break}Ea=K>>>0>L>>>0?L:K}else{if((P|0)<=(K|0)){Ea=P;break}Ea=K>>>0>L>>>0?K:L}}while(0);P=(O|0)<0;G=P?-O|0:O;F=c[f+2948+(G<<2)>>2]|0;if(P){P=Ea-F|0;la=c[s>>2]|0;if((P|0)<0){Fa=0}else{Fa=(P|0)>(la|0)?la:P}Ga=Fa;Ha=-(hOa(t,f,G)|0)|0}else{P=F+Ea|0;F=c[s>>2]|0;if((P|0)<0){Ia=0}else{Ia=(P|0)>(F|0)?F:P}Ga=Ia;Ha=hOa(t,f,G)|0}ya=Ga+Ha|0;za=E;Aa=c[r>>2]|0}do{if((Aa|0)==0){Ja=ya;Ka=c[s>>2]|0}else{do{if((ya|0)<(-Aa|0)){G=(ca(c[y>>2]|0,c[x>>2]|0)|0)+ya|0;La=G;Ma=c[s>>2]|0}else{G=c[s>>2]|0;if((ya|0)<=(G+Aa|0)){La=ya;Ma=G;break}La=ya-(ca(c[y>>2]|0,c[x>>2]|0)|0)|0;Ma=G}}while(0);if((La|0)<0){Ja=0;Ka=Ma;break}Ja=(La|0)>(Ma|0)?Ma:La;Ka=Ma}}while(0);O=Ka&Ja;if(o){a[i+za|0]=O}else{b[n+(za<<1)>>1]=O}O=za+l|0;if((O|0)<(k|0)){E=O}else{I=138;break}}if((I|0)==138){return}}function hOa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b+4408+(d<<2)|0;f=c[e>>2]|0;g=b+12+(d<<2)|0;h=c[g>>2]|0;i=0;while(1){if((f<<i|0)<(h|0)){i=i+1|0}else{break}}h=iOa(a,i,c[b+5876>>2]|0,c[b+5888>>2]|0)|0;if((h&1|0)==0){j=h>>1}else{j=-(h+1>>1)|0}if((c[b+5900>>2]|i|0)==0){k=((c[b+1480+(d<<2)>>2]<<1|0)<=(-(c[e>>2]|0)|0))<<31>>31^j}else{k=j}j=(k|0)>-1?k:-k|0;if((j|0)>65535){l=-65536;return l|0}i=(c[g>>2]|0)+j|0;c[g>>2]=i;j=ca(c[b+5904>>2]|0,k)|0;k=b+1480+(d<<2)|0;h=(c[k>>2]|0)+j|0;c[k>>2]=h;a=c[e>>2]|0;if((a|0)==(c[b+5880>>2]|0)){c[g>>2]=i>>1;i=h>>1;c[k>>2]=i;g=a>>1;c[e>>2]=g;m=g;n=i}else{m=a;n=h}h=m+1|0;c[e>>2]=h;if((n|0)<=(~m|0)){e=h+n|0;a=-m|0;c[k>>2]=(e|0)>(a|0)?e:a;a=b+2948+(d<<2)|0;e=c[a>>2]|0;if(!((e|0)>-128)){l=j;return l|0}c[a>>2]=e-1;l=j;return l|0}if((n|0)<=0){l=j;return l|0}e=n-h|0;c[k>>2]=(e|0)>0?0:e;e=b+2948+(d<<2)|0;d=c[e>>2]|0;if((d|0)>=127){l=j;return l|0}c[e>>2]=d+1;l=j;return l|0}function iOa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=a+8|0;h=c[g>>2]|0;i=c[a+16>>2]|0;j=c[a>>2]|0;k=j+(h>>>3)|0;l=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(h&7);k=l>>>0>65535>>>0;m=k?l>>>16:l;n=k?16:0;if((m&65280|0)==0){o=n;p=m}else{o=n|8;p=m>>>8}m=(d[1359664+p|0]|0)+o|0;o=m-b|0;if((o|0)>6&(32-m|0)<(e|0)){p=b+32+h-m|0;c[g>>2]=i>>>0>p>>>0?p:i;q=(l>>>(o>>>0))+(30-m<<b)|0;return q|0}a:do{if((e|0)>0&(l|0)>-1){m=c[a+12>>2]|0;o=h;p=0;while(1){if(!(m>>>0>o>>>0)){q=-1;break}n=o+1|0;k=i>>>0>n>>>0?n:i;n=j+(k>>>3)|0;r=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7);n=p+1|0;if((n|0)<(e|0)&(r|0)>-1){o=k;p=n}else{s=k;t=r;u=n;break a}}return q|0}else{s=h;t=l;u=0}}while(0);l=t<<1;t=s+1|0;s=i>>>0>t>>>0?t:i;t=e-1|0;if((u|0)<(t|0)){if((b|0)==0){v=s;w=0}else{e=s+b|0;v=i>>>0>e>>>0?e:i;w=l>>>((32-b|0)>>>0)}c[g>>2]=v;q=w+(u<<b)|0;return q|0}else{if((u|0)!=(t|0)){q=-1;return q|0}t=s+f|0;c[g>>2]=i>>>0>t>>>0?t:i;q=(l>>>((32-f|0)>>>0))+1|0;return q|0}return 0}function jOa(a){a=a|0;var b=0,d=0,e=0;b=i;d=UHb()|0;c[a+804>>2]=d;if((d|0)==0){e=-12;i=b;return e|0}c[d+88>>2]=1;c[d+84>>2]=1;d=c[a+140>>2]|0;if((d|0)==8|(d|0)==32|(d|0)==2|(d|0)==3){e=0;i=b;return e|0}KIb(a,16,2451328,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1;i=b;return e|0}function kOa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0;j=i;i=i+6024|0;k=j|0;l=j+5928|0;m=j+5952|0;n=j+5976|0;o=j+5984|0;p=j+5992|0;q=j+6008|0;r=c[b+216>>2]|0;s=b+140|0;t=c[s>>2]|0;if((t|0)==8|(t|0)==32){u=1}else{u=3}t=b+120|0;v=b+124|0;w=(ca(ca(u<<2,c[t>>2]|0)|0,c[v>>2]|0)|0)+16384|0;x=d5a(b,f,w,(w|0)<0|0?-1:0)|0;if((x|0)<0){z=x;i=j;return z|0}x=f+28|0;w=hJb(c[x>>2]|0)|0;b=c[x>>2]|0;A=(b|0)<0;B=A?0:c[f+24>>2]|0;C=A?0:b;b=C<<3;c[l+20>>2]=b;D=l+8|0;c[D>>2]=B;c[l+16>>2]=B+C;E=l+12|0;c[E>>2]=B;F=l+4|0;G=l|0;H=A?0:w;c[m+20>>2]=b;b=m+8|0;c[b>>2]=H;c[m+16>>2]=H+C;C=m+12|0;c[C>>2]=H;H=m+4|0;c[H>>2]=32;A=m|0;c[A>>2]=0;I=B;y=-134227713;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;I=(c[E>>2]|0)+4|0;c[E>>2]=I;B=c[v>>2]|0;J=I;y=je(((u*768|0)+2048|((c[s>>2]|0)==32?16:8))<<8|B>>>8|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;J=(c[E>>2]|0)+4|0;c[E>>2]=J;I=J;y=je(u|(B<<16|c[t>>2])<<8|0)|0;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;I=(c[E>>2]|0)+4|0;c[E>>2]=I;c[G>>2]=u;c[F>>2]=32;B=1;J=u;K=32;L=1;M=I;while(1){if(L){N=K-8|0;O=J<<8|B;P=M}else{I=M;y=je(B>>>((8-K|0)>>>0)|J<<K|0)|0;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;I=(c[E>>2]|0)+4|0;c[E>>2]=I;N=K+24|0;O=B;P=I}c[G>>2]=O;c[F>>2]=N;if((N|0)>8){Q=N-8|0;R=O<<8|17;S=P}else{I=P;y=je(17>>>((8-N|0)>>>0)|O<<N|0)|0;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;I=(c[E>>2]|0)+4|0;c[E>>2]=I;Q=N+24|0;R=17;S=I}c[G>>2]=R;c[F>>2]=Q;if((Q|0)>8){T=Q-8|0;U=R<<8;V=S}else{I=S;y=je(R<<Q|0)|0;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;I=(c[E>>2]|0)+4|0;c[E>>2]=I;T=Q+24|0;U=0;V=I}c[G>>2]=U;c[F>>2]=T;I=B+1|0;W=(T|0)>8;if((I|0)>(u|0)){break}else{B=I;J=U;K=T;L=W;M=V}}if(W){X=T-8|0;Y=U<<8|255;Z=V}else{W=V;y=je(255>>>((8-T|0)>>>0)|U<<T|0)|0;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;W=(c[E>>2]|0)+4|0;c[E>>2]=W;X=T+24|0;Y=255;Z=W}c[G>>2]=Y;c[F>>2]=X;if((X|0)>8){_=X-8|0;$=Y<<8|218;aa=Z}else{W=Z;y=je(218>>>((8-X|0)>>>0)|Y<<X|0)|0;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;W=(c[E>>2]|0)+4|0;c[E>>2]=W;_=X+24|0;$=218;aa=W}c[G>>2]=$;c[F>>2]=_;W=(u<<1)+6|0;if((_|0)>16){ba=_-16|0;da=$<<16|W;ea=aa}else{X=aa;y=je(W>>>((16-_|0)>>>0)|$<<_|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=(c[E>>2]|0)+4|0;c[E>>2]=X;ba=_+16|0;da=W;ea=X}c[G>>2]=da;c[F>>2]=ba;if((ba|0)>8){fa=ba-8|0;ga=da<<8|u;ha=ea}else{X=ea;y=je(u>>>((8-ba|0)>>>0)|da<<ba|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=(c[E>>2]|0)+4|0;c[E>>2]=X;fa=ba+24|0;ga=u;ha=X}c[G>>2]=ga;c[F>>2]=fa;X=1;ba=ga;ga=fa;da=(fa|0)>8;fa=ha;while(1){if(da){ia=ga-8|0;ja=ba<<8|X;ka=fa}else{ha=fa;y=je(X>>>((8-ga|0)>>>0)|ba<<ga|0)|0;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;ha=(c[E>>2]|0)+4|0;c[E>>2]=ha;ia=ga+24|0;ja=X;ka=ha}c[G>>2]=ja;c[F>>2]=ia;if((ia|0)>8){la=ia-8|0;ma=ja<<8;na=ka}else{ha=ka;y=je(ja<<ia|0)|0;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;ha=(c[E>>2]|0)+4|0;c[E>>2]=ha;la=ia+24|0;ma=0;na=ha}c[G>>2]=ma;c[F>>2]=la;ha=X+1|0;oa=(la|0)>8;if((ha|0)>(u|0)){break}else{X=ha;ba=ma;ga=la;da=oa;fa=na}}if(oa){pa=la-8|0;qa=ma<<8|r;ra=na}else{oa=na;y=je(r>>>((8-la|0)>>>0)|ma<<la|0)|0;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;oa=(c[E>>2]|0)+4|0;c[E>>2]=oa;pa=la+24|0;qa=r;ra=oa}c[G>>2]=qa;c[F>>2]=pa;oa=(u|0)!=1|0;if((pa|0)>8){sa=pa-8|0;ta=qa<<8|oa;ua=ra}else{u=ra;y=je(oa>>>((8-pa|0)>>>0)|qa<<pa|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=(c[E>>2]|0)+4|0;c[E>>2]=u;sa=pa+24|0;ta=oa;ua=u}c[G>>2]=ta;c[F>>2]=sa;if((sa|0)>8){va=sa-8|0;wa=ta<<8;xa=ua}else{u=ua;y=je(ta<<sa|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=(c[E>>2]|0)+4|0;c[E>>2]=u;va=sa+24|0;wa=0;xa=u}c[G>>2]=wa;c[F>>2]=va;u=pJb(5924)|0;sa=u;c[o>>2]=sa;c[u+5900>>2]=r;r=u+5884|0;c[r>>2]=(c[s>>2]|0)==32?16:8;Eqb(sa,0);Dqb(sa);mrc(k|0,0,5924)|0;c[k+5884>>2]=c[r>>2];c[k+5900>>2]=c[u+5900>>2];Eqb(k,1);r=u;do{if((c[r>>2]|0)==(c[k>>2]|0)){if((c[u+4>>2]|0)!=(c[k+4>>2]|0)){ya=48;break}if((c[u+8>>2]|0)!=(c[k+8>>2]|0)){ya=48;break}if((c[u+5880>>2]|0)!=(c[k+5880>>2]|0)){ya=48}}else{ya=48}}while(0);if((ya|0)==48){if((va|0)>8){za=va-8|0;Aa=wa<<8|255;Ba=xa}else{ya=xa;y=je(255>>>((8-va|0)>>>0)|wa<<va|0)|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=(c[E>>2]|0)+4|0;c[E>>2]=ya;za=va+24|0;Aa=255;Ba=ya}c[G>>2]=Aa;c[F>>2]=za;if((za|0)>8){Ca=za-8|0;Da=Aa<<8|248;Ea=Ba}else{ya=Ba;y=je(248>>>((8-za|0)>>>0)|Aa<<za|0)|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=(c[E>>2]|0)+4|0;c[E>>2]=ya;Ca=za+24|0;Da=248;Ea=ya}c[G>>2]=Da;c[F>>2]=Ca;if((Ca|0)>16){Fa=Ca-16|0;Ga=Da<<16|13;Ha=Ea}else{ya=Ea;y=je(13>>>((16-Ca|0)>>>0)|Da<<Ca|0)|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=(c[E>>2]|0)+4|0;c[E>>2]=ya;Fa=Ca+16|0;Ga=13;Ha=ya}c[G>>2]=Ga;c[F>>2]=Fa;if((Fa|0)>8){Ia=Fa-8|0;Ja=Ga<<8|1;Ka=Ha}else{ya=Ha;y=je(1>>>((8-Fa|0)>>>0)|Ga<<Fa|0)|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=(c[E>>2]|0)+4|0;c[E>>2]=ya;Ia=Fa+24|0;Ja=1;Ka=ya}c[G>>2]=Ja;c[F>>2]=Ia;ya=c[u+5892>>2]|0;if((Ia|0)>16){La=Ia-16|0;Ma=ya|Ja<<16;Na=Ka}else{Fa=Ka;y=je(ya>>>((16-Ia|0)>>>0)|Ja<<Ia|0)|0;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;Fa=(c[E>>2]|0)+4|0;c[E>>2]=Fa;La=Ia+16|0;Ma=ya;Na=Fa}c[G>>2]=Ma;c[F>>2]=La;Fa=c[r>>2]|0;if((La|0)>16){Oa=La-16|0;Pa=Fa|Ma<<16;Qa=Na}else{r=Na;y=je(Fa>>>((16-La|0)>>>0)|Ma<<La|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[E>>2]|0)+4|0;c[E>>2]=r;Oa=La+16|0;Pa=Fa;Qa=r}c[G>>2]=Pa;c[F>>2]=Oa;r=c[u+4>>2]|0;if((Oa|0)>16){Ra=Oa-16|0;Sa=r|Pa<<16;Ta=Qa}else{Fa=Qa;y=je(r>>>((16-Oa|0)>>>0)|Pa<<Oa|0)|0;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;Fa=(c[E>>2]|0)+4|0;c[E>>2]=Fa;Ra=Oa+16|0;Sa=r;Ta=Fa}c[G>>2]=Sa;c[F>>2]=Ra;Fa=c[u+8>>2]|0;if((Ra|0)>16){Ua=Ra-16|0;Va=Fa|Sa<<16;Wa=Ta}else{r=Ta;y=je(Fa>>>((16-Ra|0)>>>0)|Sa<<Ra|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[E>>2]|0)+4|0;c[E>>2]=r;Ua=Ra+16|0;Va=Fa;Wa=r}c[G>>2]=Va;c[F>>2]=Ua;r=c[u+5880>>2]|0;if((Ua|0)>16){Xa=Ua-16|0;Ya=r|Va<<16}else{u=Wa;y=je(r>>>((16-Ua|0)>>>0)|Va<<Ua|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;Xa=Ua+16|0;Ya=r}c[G>>2]=Ya;c[F>>2]=Xa}Xa=g+32|0;Ya=c[Xa>>2]|0;r=pJb((Ya|0)>-1?Ya:-Ya|0)|0;c[n>>2]=r;if((r|0)==0){kJb(c[o>>2]|0);z=-12;i=j;return z|0}Ya=c[g>>2]|0;g=c[s>>2]|0;a:do{if((g|0)==2){mrc(p|0,0,12)|0;s=(c[t>>2]|0)*3|0;if((c[v>>2]|0)>0){Za=1;_a=r;$a=Ya;ab=0}else{break}while(1){Ua=p|0;mOa(c[o>>2]|0,m,_a,$a,ab,s,3,0,8);c[Ua>>2]=d[_a]|0;u=_a+1|0;Va=p+4|0;mOa(c[o>>2]|0,m,u,$a+1|0,c[Va>>2]|0,s,3,1,8);c[Va>>2]=d[u]|0;u=_a+2|0;Va=p+8|0;mOa(c[o>>2]|0,m,u,$a+2|0,c[Va>>2]|0,s,3,2,8);c[Va>>2]=d[u]|0;if((Za|0)>=(c[v>>2]|0)){break a}Za=Za+1|0;_a=$a;$a=$a+(c[Xa>>2]|0)|0;ab=c[Ua>>2]|0}}else if((g|0)==8){if((c[v>>2]|0)>0){bb=1;cb=r;db=0;eb=Ya}else{break}while(1){mOa(c[o>>2]|0,m,cb,eb,db,c[t>>2]|0,1,0,8);if((bb|0)>=(c[v>>2]|0)){break a}s=d[cb]|0;bb=bb+1|0;cb=eb;db=s;eb=eb+(c[Xa>>2]|0)|0}}else if((g|0)==32){if((c[v>>2]|0)>0){fb=1;gb=r;hb=0;ib=Ya}else{break}while(1){mOa(c[o>>2]|0,m,gb,ib,hb,c[t>>2]|0,1,0,16);if((fb|0)>=(c[v>>2]|0)){break a}s=e[gb>>1]|0;fb=fb+1|0;gb=ib;hb=s;ib=ib+(c[Xa>>2]|0)|0}}else if((g|0)==3){mrc(q|0,0,12)|0;s=(c[t>>2]|0)*3|0;if((c[v>>2]|0)>0){jb=1;kb=r;lb=Ya;mb=0}else{break}while(1){Ua=kb+2|0;u=q+8|0;mOa(c[o>>2]|0,m,Ua,lb+2|0,mb,s,3,2,8);c[u>>2]=d[Ua]|0;Ua=kb+1|0;Va=q+4|0;mOa(c[o>>2]|0,m,Ua,lb+1|0,c[Va>>2]|0,s,3,1,8);c[Va>>2]=d[Ua]|0;Ua=q|0;mOa(c[o>>2]|0,m,kb,lb,c[Ua>>2]|0,s,3,0,8);c[Ua>>2]=d[kb]|0;if((jb|0)>=(c[v>>2]|0)){break a}jb=jb+1|0;kb=lb;lb=lb+(c[Xa>>2]|0)|0;mb=c[u>>2]|0}}}while(0);mJb(n);mJb(o);o=c[A>>2]|0;n=c[H>>2]|0;if((n|0)>7){nb=n-7|0;ob=o<<7;pb=c[C>>2]|0}else{mb=je(o<<n|0)|0;o=c[C>>2]|0;Xa=o;y=mb;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;Xa=o+4|0;c[C>>2]=Xa;nb=n+25|0;ob=0;pb=Xa}c[A>>2]=ob;c[H>>2]=nb;Xa=(pb-(c[b>>2]|0)<<3)+(32-nb)|0;if((nb|0)<32){b=ob<<nb;c[A>>2]=b;ob=(((nb+8|0)>32?nb+7|0:31)-nb|0)>>>3;n=nb+(ob<<3)|0;o=ob+1|0;ob=b>>>24&255;mb=pb;lb=b;b=nb;while(1){a[mb]=ob;qb=lb<<8;nb=b+8|0;if((nb|0)<32){ob=lb>>>16&255;mb=mb+1|0;lb=qb;b=nb}else{break}}c[C>>2]=pb+o;c[A>>2]=qb;c[H>>2]=n+8}c[H>>2]=32;c[A>>2]=0;A=Xa>>>0>2147483639>>>0|(w|0)==0;H=A?0:w;n=A?8:Xa+8|0;A=Xa-7|0;if((A|0)>0){Xa=0;qb=c[G>>2]|0;o=c[F>>2]|0;while(1){pb=H+(Xa>>>3)|0;C=(je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(Xa&7)>>>24;pb=Xa+8|0;b=n>>>0>pb>>>0?pb:n;if((o|0)>8){rb=o-8|0;sb=qb<<8|C}else{pb=je(C>>>((8-o|0)>>>0)|qb<<o|0)|0;lb=c[E>>2]|0;y=pb;a[lb]=y;y=y>>8;a[lb+1|0]=y;y=y>>8;a[lb+2|0]=y;y=y>>8;a[lb+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;rb=o+24|0;sb=C}c[G>>2]=sb;c[F>>2]=rb;if((C|0)==255){C=H+(b>>>3)|0;lb=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(b&7)>>>25;C=b+7|0;if((rb|0)>8){tb=rb-8|0;ub=sb<<8|lb}else{pb=je(lb>>>((8-rb|0)>>>0)|sb<<rb|0)|0;mb=c[E>>2]|0;y=pb;a[mb]=y;y=y>>8;a[mb+1|0]=y;y=y>>8;a[mb+2|0]=y;y=y>>8;a[mb+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;tb=rb+24|0;ub=lb}c[G>>2]=ub;c[F>>2]=tb;vb=n>>>0>C>>>0?C:n;wb=ub;xb=tb}else{vb=b;wb=sb;xb=rb}if((vb|0)<(A|0)){Xa=vb;qb=wb;o=xb}else{break}}}Y2(l);kJb(w);w=c[G>>2]|0;l=c[F>>2]|0;if((l|0)>8){yb=l-8|0;zb=w<<8|255}else{xb=je(255>>>((8-l|0)>>>0)|w<<l|0)|0;w=c[E>>2]|0;y=xb;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;yb=l+24|0;zb=255}c[G>>2]=zb;c[F>>2]=yb;if((yb|0)>8){Ab=yb-8|0;Bb=zb<<8|217}else{l=je(217>>>((8-yb|0)>>>0)|zb<<yb|0)|0;zb=c[E>>2]|0;y=l;a[zb]=y;y=y>>8;a[zb+1|0]=y;y=y>>8;a[zb+2|0]=y;y=y>>8;a[zb+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;Ab=yb+24|0;Bb=217}c[G>>2]=Bb;c[F>>2]=Ab;b:do{if((Ab|0)<32){yb=Bb<<Ab;c[G>>2]=yb;zb=yb>>>24&255;while(1){yb=c[E>>2]|0;c[E>>2]=yb+1;a[yb]=zb;yb=c[G>>2]|0;c[G>>2]=yb<<8;l=(c[F>>2]|0)+8|0;c[F>>2]=l;if((l|0)>=32){break b}zb=yb>>>16&255}}}while(0);c[F>>2]=32;c[G>>2]=0;c[x>>2]=(c[E>>2]|0)-(c[D>>2]|0)<<3>>3;D=f+36|0;c[D>>2]=c[D>>2]|1;c[h>>2]=1;z=0;i=j;return z|0}function lOa(a){a=a|0;VHb(a+804|0);return 0}function mOa(f,g,h,i,j,k,l,m,n){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0;if((k|0)<=0){return}o=(n|0)==8;n=i;p=h;q=k-l|0;r=f+5900|0;s=f+5892|0;t=f+5896|0;u=f+5876|0;v=f+5888|0;w=f+5904|0;x=f+5880|0;z=f+8|0;A=f+4|0;B=f|0;C=f+5908+(m<<2)|0;m=g|0;D=g+4|0;E=g+12|0;F=0;a:while(1){G=(F|0)!=0;do{if(G){H=F-l|0;if(o){I=i+H|0;J=8;break}else{K=n+(H<<1)|0;J=9;break}}else{if(o){I=h;J=8}else{K=p;J=9}}}while(0);if((J|0)==8){J=0;L=d[h+F|0]|0;M=d[I]|0}else if((J|0)==9){J=0;L=e[p+(F<<1)>>1]|0;M=e[K>>1]|0}do{if(G){H=F-l|0;if(o){N=d[h+H|0]|0;break}else{N=e[p+(H<<1)>>1]|0;break}}else{N=j}}while(0);do{if((F|0)<(q|0)){G=F+l|0;if(o){O=d[h+G|0]|0;break}else{O=e[p+(G<<1)>>1]|0;break}}else{if(o){O=d[h+F|0]|0;break}else{O=e[p+(F<<1)>>1]|0;break}}}while(0);G=O-L|0;H=L-N|0;P=N-M|0;Q=c[r>>2]|0;do{if((((G|0)>-1?G:-G|0)|0)>(Q|0)){J=85}else{if((((H|0)>-1?H:-H|0)|0)>(Q|0)){J=85;break}if((((P|0)>-1?P:-P|0)|0)>(Q|0)){J=85;break}b:do{if((F|0)<(k|0)){R=M&255;S=M&65535;if(o){T=F;U=0;while(1){V=a[i+T|0]|0;W=V&255;if(((((V&255)-M|0)>-1?W-M|0:M-W|0)|0)>(c[r>>2]|0)){X=T;Y=U;Z=1;break b}W=U+1|0;a[i+T|0]=R;V=T+l|0;if((V|0)<(k|0)){T=V;U=W}else{X=V;Y=W;Z=0;break}}}else{U=F;T=0;while(1){R=b[n+(U<<1)>>1]|0;W=R&65535;if(((((R&65535)-M|0)>-1?W-M|0:M-W|0)|0)>(Q|0)){X=U;Y=T;Z=1;break b}W=T+1|0;b[n+(U<<1)>>1]=S;R=U+l|0;if((R|0)<(k|0)){U=R;T=W}else{X=R;Y=W;Z=0;break}}}}else{X=F;Y=0;Z=0}}while(0);if((1<<(d[1359920+(c[C>>2]|0)|0]|0)|0)>(Y|0)){_=Y}else{T=Y;while(1){U=c[m>>2]|0;S=c[D>>2]|0;if((S|0)>1){$=S-1|0;aa=U<<1|1}else{W=je(1>>>((1-S|0)>>>0)|U<<S|0)|0;U=c[E>>2]|0;y=W;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;$=S+31|0;aa=1}c[m>>2]=aa;c[D>>2]=$;S=c[C>>2]|0;U=a[1359920+S|0]|0;W=T-(1<<(U&255))|0;if((S|0)<31){R=S+1|0;c[C>>2]=R;ba=a[1359920+R|0]|0}else{ba=U}if((W|0)<(1<<(ba&255)|0)){_=W;break}else{T=W}}}do{if(Z|(_|0)==0){if(!Z){J=164;break a}T=c[m>>2]|0;W=c[D>>2]|0;if((W|0)>1){da=W-1|0;ea=T<<1}else{U=je(T<<W|0)|0;T=c[E>>2]|0;y=U;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;da=W+31|0;ea=0}c[m>>2]=ea;c[D>>2]=da;W=a[1359920+(c[C>>2]|0)|0]|0;if(W<<24>>24==0){break}T=W&255;if((da|0)>(T|0)){fa=da;ga=ea<<T|_}else{W=je(_>>>((T-da|0)>>>0)|ea<<da|0)|0;U=c[E>>2]|0;y=W;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;fa=da+32|0;ga=_}c[m>>2]=ga;c[D>>2]=fa-T}else{T=c[m>>2]|0;U=c[D>>2]|0;if((U|0)>1){ha=U-1|0;ia=T<<1|1}else{W=je(1>>>((1-U|0)>>>0)|T<<U|0)|0;T=c[E>>2]|0;y=W;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;ha=U+31|0;ia=1}c[m>>2]=ia;c[D>>2]=ha}}while(0);if(!Z){J=164;break a}if(o){ja=d[h+X|0]|0}else{ja=e[p+(X<<1)>>1]|0}U=M-ja|0;T=c[r>>2]|0;W=(((U|0)>-1?U:-U|0)|0)<=(T|0);U=W&1;R=W?M:ja;if(o){ka=d[i+X|0]|0}else{ka=e[n+(X<<1)>>1]|0}S=ka-R|0;V=M>>>0>ja>>>0&(W^1);la=V?-S|0:S;do{if((T|0)==0){ma=la}else{if((la|0)>0){S=c[w>>2]|0;na=(la+T|0)/(S|0)|0;oa=S}else{S=c[w>>2]|0;na=(la-T|0)/(S|0)|0;oa=S}S=ca(oa,na)|0;do{if(V){pa=R-S|0;qa=c[s>>2]|0;if((pa|0)<0){ra=0;sa=0;break}ta=(pa|0)>(qa|0)?qa:pa;ra=ta&255;sa=ta&65535}else{ta=S+R|0;pa=c[s>>2]|0;if((ta|0)<0){ra=0;sa=0;break}qa=(ta|0)>(pa|0)?pa:ta;ra=qa&255;sa=qa&65535}}while(0);if(o){a[i+X|0]=ra;ma=na;break}else{b[n+(X<<1)>>1]=sa;ma=na;break}}}while(0);R=c[t>>2]|0;V=ma+((ma|0)<0?R:0)|0;T=(V|0)<(R+1>>1|0)?0:R;R=V-T|0;la=d[1359920+(c[C>>2]|0)|0]|0;S=W?366:365;qa=f+12+(S<<2)|0;ta=c[qa>>2]|0;pa=f+4408+(S<<2)|0;ua=c[pa>>2]|0;if(W){va=(ua>>1)+ta|0}else{va=ta}ta=0;while(1){if((ua<<ta|0)<(va|0)){ta=ta+1|0}else{break}}if((ta|0)!=0|(V|0)==(T|0)){wa=0}else{wa=(c[f+1480+(S<<2)>>2]<<1|0)<(ua|0)|0}W=(R|0)<0;xa=R<<1;if(W){ya=~xa-U+wa|0}else{ya=xa-U-wa|0}nOa(g,ya,ta,(c[u>>2]|0)+~la|0,c[v>>2]|0);if(W){W=f+1480+(S<<2)|0;c[W>>2]=(c[W>>2]|0)+1}W=(c[qa>>2]|0)+(ya+(U^1)>>1)|0;c[qa>>2]=W;xa=c[pa>>2]|0;if((xa|0)==(c[x>>2]|0)){c[qa>>2]=W>>1;W=f+1480+(S<<2)|0;c[W>>2]=c[W>>2]>>1;W=xa>>1;c[pa>>2]=W;za=W}else{za=xa}c[pa>>2]=za+1;xa=c[C>>2]|0;if((xa|0)<=0){Aa=X;break}c[C>>2]=xa-1;Aa=X}}while(0);do{if((J|0)==85){J=0;do{if((O|0)==(L|0)){Ba=0}else{if((G|0)<0){if((G|0)<=(-(c[z>>2]|0)|0)){Ba=-4;break}if((G|0)<=(-(c[A>>2]|0)|0)){Ba=-3;break}if((G|0)<=(-(c[B>>2]|0)|0)){Ba=-2;break}Ba=((G|0)<(-Q|0))<<31>>31;break}else{if((Q|0)>=(G|0)){Ba=0;break}if((c[B>>2]|0)>(G|0)){Ba=1;break}if((c[A>>2]|0)>(G|0)){Ba=2;break}Ba=(c[z>>2]|0)>(G|0)?3:4;break}}}while(0);pa=Ba*81|0;do{if((L|0)==(N|0)){Ca=0}else{if((H|0)<0){if((H|0)<=(-(c[z>>2]|0)|0)){Ca=-4;break}if((H|0)<=(-(c[A>>2]|0)|0)){Ca=-3;break}if((H|0)<=(-(c[B>>2]|0)|0)){Ca=-2;break}Ca=((H|0)<(-Q|0))<<31>>31;break}else{if((Q|0)>=(H|0)){Ca=0;break}if((c[B>>2]|0)>(H|0)){Ca=1;break}if((c[A>>2]|0)>(H|0)){Ca=2;break}Ca=(c[z>>2]|0)>(H|0)?3:4;break}}}while(0);S=(Ca*9|0)+pa|0;do{if((N|0)==(M|0)){Da=0}else{if((P|0)<0){if((P|0)<=(-(c[z>>2]|0)|0)){Da=-4;break}if((P|0)<=(-(c[A>>2]|0)|0)){Da=-3;break}if((P|0)<=(-(c[B>>2]|0)|0)){Da=-2;break}Da=((P|0)<(-Q|0))<<31>>31;break}else{if((Q|0)>=(P|0)){Da=0;break}if((c[B>>2]|0)>(P|0)){Da=1;break}if((c[A>>2]|0)>(P|0)){Da=2;break}Da=(c[z>>2]|0)>(P|0)?3:4;break}}}while(0);pa=S+Da|0;qa=L+M-N|0;do{if((M|0)>(qa|0)){if((L|0)<=(qa|0)){Ea=qa;break}Ea=L>>>0>M>>>0?M:L}else{if((qa|0)<=(L|0)){Ea=qa;break}Ea=L>>>0>M>>>0?L:M}}while(0);if((pa|0)<0){qa=-pa|0;S=Ea-(c[f+2948+(qa<<2)>>2]|0)|0;U=c[s>>2]|0;if((S|0)<0){Fa=0}else{Fa=(S|0)>(U|0)?U:S}if(o){Ga=d[i+F|0]|0}else{Ga=e[n+(F<<1)>>1]|0}Ha=qa;Ia=1;Ja=Fa;Ka=Fa-Ga|0;La=U}else{U=(c[f+2948+(pa<<2)>>2]|0)+Ea|0;qa=c[s>>2]|0;if((U|0)<0){Ma=0}else{Ma=(U|0)>(qa|0)?qa:U}if(o){Na=d[i+F|0]|0}else{Na=e[n+(F<<1)>>1]|0}Ha=pa;Ia=0;Ja=Ma;Ka=Na-Ma|0;La=qa}do{if((Q|0)==0){Oa=Ka}else{if((Ka|0)>0){qa=c[w>>2]|0;Pa=(Q+Ka|0)/(qa|0)|0;Qa=qa}else{qa=c[w>>2]|0;Pa=(Ka-Q|0)/(qa|0)|0;Qa=qa}qa=ca(Qa,Pa)|0;do{if((Ia|0)==0){U=qa+Ja|0;if((U|0)<0){Ra=0;Sa=0;break}S=(U|0)>(La|0)?La:U;Ra=S&255;Sa=S&65535}else{S=Ja-qa|0;if((S|0)<0){Ra=0;Sa=0;break}U=(S|0)>(La|0)?La:S;Ra=U&255;Sa=U&65535}}while(0);if(o){a[i+F|0]=Ra;Oa=Pa;break}else{b[n+(F<<1)>>1]=Sa;Oa=Pa;break}}}while(0);pa=f+4408+(Ha<<2)|0;qa=c[pa>>2]|0;U=f+12+(Ha<<2)|0;S=c[U>>2]|0;la=0;while(1){if((qa<<la|0)<(S|0)){la=la+1|0}else{break}}if((c[r>>2]|la|0)==0){Ta=(c[f+1480+(Ha<<2)>>2]<<1|0)<=(-qa|0)|0}else{Ta=0}if((Oa|0)<0){Ua=(c[t>>2]|0)+Oa|0}else{Ua=Oa}S=c[t>>2]|0;if((Ua|0)<(S+1>>1|0)){Va=Ua;Wa=Ua<<1|Ta}else{ta=Ua-S|0;Va=ta;Wa=(((ta|0)>-1?ta:-ta|0)<<1)+~Ta|0}nOa(g,Wa,la,c[u>>2]|0,c[v>>2]|0);ta=(Va|0)>-1?Va:-Va|0;if((ta|0)>65535){Aa=F;break}S=(c[U>>2]|0)+ta|0;c[U>>2]=S;ta=ca(c[w>>2]|0,Va)|0;R=f+1480+(Ha<<2)|0;ua=(c[R>>2]|0)+ta|0;c[R>>2]=ua;ta=c[pa>>2]|0;if((ta|0)==(c[x>>2]|0)){c[U>>2]=S>>1;S=ua>>1;c[R>>2]=S;T=ta>>1;c[pa>>2]=T;Xa=T;Ya=S}else{Xa=ta;Ya=ua}ua=Xa+1|0;c[pa>>2]=ua;if((Ya|0)<=(~Xa|0)){ta=ua+Ya|0;S=-Xa|0;c[R>>2]=(ta|0)>(S|0)?ta:S;S=f+2948+(Ha<<2)|0;ta=c[S>>2]|0;if(!((ta|0)>-128)){Aa=F;break}c[S>>2]=ta-1;Aa=F;break}if((Ya|0)<=0){Aa=F;break}ta=Ya-ua|0;c[R>>2]=(ta|0)>0?0:ta;ta=f+2948+(Ha<<2)|0;R=c[ta>>2]|0;if((R|0)>=127){Aa=F;break}c[ta>>2]=R+1;Aa=F}}while(0);Q=Aa+l|0;if((Q|0)<(k|0)){F=Q}else{J=164;break}}if((J|0)==164){return}}function nOa(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=d>>e;i=h+1|0;if((i|0)>=(f|0)){j=b|0;k=c[j>>2]|0;l=b+4|0;m=c[l>>2]|0;if((f|0)>31){n=b+12|0;o=f-32|0;p=(o>>>0)%31|0;q=f;r=k;s=m;while(1){if((s|0)>31){t=s-31|0;u=r<<31}else{v=je(r<<s|0)|0;w=c[n>>2]|0;y=v;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;t=s+1|0;u=0}c[j>>2]=u;c[l>>2]=t;w=q-31|0;if((w|0)>31){q=w;r=u;s=t}else{break}}x=f-31+(p-o)|0;z=u;A=t}else{x=f;z=k;A=m}if((A|0)>(x|0)){B=A-x|0;C=z<<x|1}else{m=je(1>>>((x-A|0)>>>0)|z<<A|0)|0;z=b+12|0;k=c[z>>2]|0;y=m;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;B=32-x+A|0;C=1}c[j>>2]=C;c[l>>2]=B;A=d-1|0;if((B|0)>(g|0)){D=B-g|0;E=C<<g|A}else{x=je(A>>>((g-B|0)>>>0)|C<<B|0)|0;C=b+12|0;z=c[C>>2]|0;y=x;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;D=32-g+B|0;E=A}c[j>>2]=E;c[l>>2]=D;return}D=b|0;l=c[D>>2]|0;E=b+4|0;j=c[E>>2]|0;if((i|0)>31){A=b+12|0;B=h-31|0;g=(B>>>0)%31|0;C=i;z=l;x=j;while(1){if((x|0)>31){F=x-31|0;G=z<<31}else{k=je(z<<x|0)|0;m=c[A>>2]|0;y=k;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;F=x+1|0;G=0}c[D>>2]=G;c[E>>2]=F;m=C-31|0;if((m|0)>31){C=m;z=G;x=F}else{break}}H=h-30+(g-B)|0;I=G;J=F}else{H=i;I=l;J=j}if((J|0)>(H|0)){K=J-H|0;L=I<<H|1}else{j=je(1>>>((H-J|0)>>>0)|I<<J|0)|0;I=b+12|0;l=c[I>>2]|0;y=j;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;K=32-H+J|0;L=1}c[D>>2]=L;c[E>>2]=K;if((e|0)==0){return}J=(1<<e)-1&d;if((K|0)>(e|0)){M=K-e|0;N=L<<e|J}else{d=je(L<<K|J>>>((e-K|0)>>>0)|0)|0;L=b+12|0;b=c[L>>2]|0;y=d;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[L>>2]=(c[L>>2]|0)+4;M=32-e+K|0;N=J}c[D>>2]=N;c[E>>2]=M;return}function oOa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=a;e=7;while(1){f=d;g=b[d>>1]|0;h=g<<16>>16;i=d+2|0;j=b[i>>1]|0;k=j<<16>>16;l=d+4|0;m=b[l>>1]|0;n=m<<16>>16;o=d+6|0;p=b[o>>1]|0;q=p<<16>>16;r=d+8|0;s=b[r>>1]|0;t=s<<16>>16;u=d+10|0;v=b[u>>1]|0;w=v<<16>>16;x=d+12|0;y=b[x>>1]|0;z=y<<16>>16;A=d+14|0;B=b[A>>1]|0;C=B<<16>>16;do{if((m|j|p|s|v|y|B)<<16>>16==0){if(g<<16>>16==0){break}D=g<<2<<16>>16;E=D&65532|D<<16;c[f>>2]=E;c[l>>2]=E;c[r>>2]=E;c[x>>2]=E}else{E=j<<16>>16!=0;do{if(p<<16>>16==0){if(E){D=k*4433|0;F=k*10703|0;G=n+h<<13;H=h-n<<13;I=G-F|0;J=H-D|0;K=H+D|0;L=G+F|0;break}else{F=n+h<<13;G=h-n<<13;I=F;J=G;K=G;L=F;break}}else{if(E){F=(q+k|0)*4433|0;G=F+(q*-15137|0)|0;D=F+(k*6270|0)|0;F=n+h<<13;H=h-n<<13;I=F-D|0;J=H-G|0;K=G+H|0;L=D+F|0;break}else{F=q*-10703|0;D=q*4433|0;H=n+h<<13;G=h-n<<13;I=H-D|0;J=G-F|0;K=G+F|0;L=H+D|0;break}}}while(0);E=y<<16>>16!=0;D=v<<16>>16!=0;H=s<<16>>16!=0;do{if(B<<16>>16==0){if(!E){if(!D){if(!H){M=0;N=0;O=0;P=0;break}M=t*2260|0;N=t*6436|0;O=t*9633|0;P=t*11363|0;break}if(H){F=w+t|0;G=F*6436|0;Q=F*9633|0;M=(t*8697|0)-G|0;N=G+(w*-17799|0)|0;O=Q+(w*-11893|0)|0;P=Q+(t*1730|0)|0;break}else{M=w*-6436|0;N=w*-11363|0;O=w*-2260|0;P=w*9633|0;break}}if(D){Q=z+w|0;if(H){G=z+t|0;F=(G+w|0)*9633|0;R=Q*-20995|0;S=F+(w*-16069|0)|0;T=F+(G*-3196|0)|0;M=S+(t*-7373|0)|0;N=R+(z*16819|0)+T|0;O=R+(w*25172|0)+S|0;P=(t*4926|0)+T|0;break}else{T=Q*9633|0;S=Q*-11363|0;M=T+(w*-16069|0)|0;N=S+(z*13623|0)|0;O=S+(w*9102|0)|0;P=T+(z*-3196|0)|0;break}}else{if(H){T=z+t|0;S=T*9633|0;Q=T*6436|0;M=S+(t*-7373|0)|0;N=Q+(z*-4176|0)|0;O=S+(z*-20995|0)|0;P=Q+(t*4926|0)|0;break}else{M=z*9633|0;N=z*2260|0;O=z*-11363|0;P=z*6436|0;break}}}else{if(E){if(D){if(H){Q=C+w|0;S=z+t|0;T=(Q+S|0)*9633|0;R=(C+t|0)*-7373|0;G=(z+w|0)*-20995|0;F=T+(Q*-16069|0)|0;Q=T+(S*-3196|0)|0;M=R+(C*2446|0)+F|0;N=G+(z*16819|0)+Q|0;O=G+(w*25172|0)+F|0;P=R+(t*12299|0)+Q|0;break}else{Q=C+w|0;R=(Q+z|0)*9633|0;F=(z+w|0)*-20995|0;G=R+(Q*-16069|0)|0;Q=R+(z*-3196|0)|0;M=(C*-4927|0)+G|0;N=F+(z*16819|0)+Q|0;O=F+(w*25172|0)+G|0;P=Q+(C*-7373|0)|0;break}}else{if(H){Q=z+t|0;G=(C+Q|0)*9633|0;F=(C+t|0)*-7373|0;R=G+(C*-16069|0)|0;S=G+(Q*-3196|0)|0;M=F+(C*2446|0)+R|0;N=(z*-4176|0)+S|0;O=R+(z*-20995|0)|0;P=F+(t*12299|0)+S|0;break}else{S=(C+z|0)*9633|0;F=S+(C*-16069|0)|0;R=S+(z*-3196|0)|0;M=F+(C*-4926|0)|0;N=R+(z*-4176|0)|0;O=F+(z*-20995|0)|0;P=R+(C*-7373|0)|0;break}}}else{if(D){if(H){R=C+w|0;F=(R+t|0)*9633|0;S=(C+t|0)*-7373|0;Q=F+(R*-16069|0)|0;R=F+(t*-3196|0)|0;M=S+(C*2446|0)+Q|0;N=R+(w*-20995|0)|0;O=(w*4177|0)+Q|0;P=S+(t*12299|0)+R|0;break}else{R=C+w|0;S=R*9633|0;Q=R*-6436|0;M=Q+(C*-4926|0)|0;N=S+(w*-20995|0)|0;O=Q+(w*4176|0)|0;P=S+(C*-7373|0)|0;break}}else{if(H){S=C+t|0;Q=S*9633|0;R=S*2260|0;M=R+(C*-13623|0)|0;N=Q+(t*-3196|0)|0;O=Q+(C*-16069|0)|0;P=R+(t*9102|0)|0;break}else{M=C*-11363|0;N=C*9633|0;O=C*-6436|0;P=C*2260|0;break}}}}}while(0);H=L+1024|0;b[d>>1]=(H+P|0)>>>11;b[A>>1]=(H-P|0)>>>11;H=K+1024|0;b[i>>1]=(H+O|0)>>>11;b[x>>1]=(H-O|0)>>>11;H=J+1024|0;b[l>>1]=(H+N|0)>>>11;b[u>>1]=(H-N|0)>>>11;H=I+1024|0;b[o>>1]=(H+M|0)>>>11;b[r>>1]=(H-M|0)>>>11}}while(0);if((e|0)>0){d=d+16|0;e=e-1|0}else{U=a;V=7;break}}while(1){a=b[U>>1]|0;e=U+16|0;d=b[e>>1]|0;M=d<<16>>16;I=U+32|0;N=b[I>>1]|0;J=N<<16>>16;O=U+48|0;K=b[O>>1]|0;P=K<<16>>16;L=U+64|0;r=b[L>>1]|0;o=U+80|0;u=b[o>>1]|0;l=u<<16>>16;x=U+96|0;i=b[x>>1]|0;A=i<<16>>16;C=U+112|0;t=b[C>>1]|0;w=t<<16>>16;z=N<<16>>16!=0;do{if(i<<16>>16==0){if(z){N=J*4433|0;B=J*10703|0;s=r+a<<13;v=a-r<<13;W=s-B|0;X=v-N|0;Y=v+N|0;Z=s+B|0;break}else{B=r+a<<13;s=a-r<<13;W=B;X=s;Y=s;Z=B;break}}else{if(z){B=(A+J|0)*4433|0;s=B+(A*-15137|0)|0;N=B+(J*6270|0)|0;B=r+a<<13;v=a-r<<13;W=B-N|0;X=v-s|0;Y=s+v|0;Z=N+B|0;break}else{B=A*-10703|0;N=A*4433|0;v=r+a<<13;s=a-r<<13;W=v-N|0;X=s-B|0;Y=B+s|0;Z=N+v|0;break}}}while(0);r=u<<16>>16!=0;a=K<<16>>16!=0;A=d<<16>>16!=0;do{if(t<<16>>16==0){if(!r){if(!a){if(!A){_=0;$=0;aa=0;ba=0;break}_=M*2260|0;$=M*6436|0;aa=M*9633|0;ba=M*11363|0;break}if(A){J=P+M|0;z=J*6436|0;i=J*9633|0;_=(M*8697|0)-z|0;$=z+(P*-17799|0)|0;aa=i+(P*-11893|0)|0;ba=i+(M*1730|0)|0;break}else{_=P*-6436|0;$=P*-11363|0;aa=P*-2260|0;ba=P*9633|0;break}}if(a){i=l+P|0;if(A){z=l+M|0;J=(z+P|0)*9633|0;v=i*-20995|0;N=J+(P*-16069|0)|0;s=J+(z*-3196|0)|0;_=N+(M*-7373|0)|0;$=v+(l*16819|0)+s|0;aa=v+(P*25172|0)+N|0;ba=(M*4926|0)+s|0;break}else{s=i*9633|0;N=i*-11363|0;_=s+(P*-16069|0)|0;$=N+(l*13623|0)|0;aa=N+(P*9102|0)|0;ba=s+(l*-3196|0)|0;break}}else{if(A){s=l+M|0;N=s*9633|0;i=s*6436|0;_=N+(M*-7373|0)|0;$=i+(l*-4176|0)|0;aa=N+(l*-20995|0)|0;ba=i+(M*4926|0)|0;break}else{_=l*9633|0;$=l*2260|0;aa=l*-11363|0;ba=l*6436|0;break}}}else{if(r){if(a){if(A){i=w+P|0;N=l+M|0;s=(i+N|0)*9633|0;v=(w+M|0)*-7373|0;z=(l+P|0)*-20995|0;J=s+(i*-16069|0)|0;i=s+(N*-3196|0)|0;_=v+(w*2446|0)+J|0;$=z+(l*16819|0)+i|0;aa=z+(P*25172|0)+J|0;ba=v+(M*12299|0)+i|0;break}else{i=w+P|0;v=(i+l|0)*9633|0;J=(l+P|0)*-20995|0;z=v+(i*-16069|0)|0;i=v+(l*-3196|0)|0;_=(w*-4927|0)+z|0;$=J+(l*16819|0)+i|0;aa=J+(P*25172|0)+z|0;ba=i+(w*-7373|0)|0;break}}else{if(A){i=l+M|0;z=(w+i|0)*9633|0;J=(w+M|0)*-7373|0;v=z+(w*-16069|0)|0;N=z+(i*-3196|0)|0;_=J+(w*2446|0)+v|0;$=(l*-4176|0)+N|0;aa=v+(l*-20995|0)|0;ba=J+(M*12299|0)+N|0;break}else{N=(w+l|0)*9633|0;J=N+(w*-16069|0)|0;v=N+(l*-3196|0)|0;_=J+(w*-4926|0)|0;$=v+(l*-4176|0)|0;aa=J+(l*-20995|0)|0;ba=v+(w*-7373|0)|0;break}}}else{if(a){if(A){v=w+P|0;J=(v+M|0)*9633|0;N=(w+M|0)*-7373|0;i=J+(v*-16069|0)|0;v=J+(M*-3196|0)|0;_=N+(w*2446|0)+i|0;$=v+(P*-20995|0)|0;aa=(P*4177|0)+i|0;ba=N+(M*12299|0)+v|0;break}else{v=w+P|0;N=v*9633|0;i=v*-6436|0;_=i+(w*-4926|0)|0;$=N+(P*-20995|0)|0;aa=i+(P*4176|0)|0;ba=N+(w*-7373|0)|0;break}}else{if(A){N=w+M|0;i=N*9633|0;v=N*2260|0;_=v+(w*-13623|0)|0;$=i+(M*-3196|0)|0;aa=i+(w*-16069|0)|0;ba=v+(M*9102|0)|0;break}else{_=w*-11363|0;$=w*9633|0;aa=w*-6436|0;ba=w*2260|0;break}}}}}while(0);w=Z+131072|0;b[U>>1]=w+ba>>18;b[C>>1]=w-ba>>18;w=Y+131072|0;b[e>>1]=w+aa>>18;b[x>>1]=w-aa>>18;w=X+131072|0;b[I>>1]=w+$>>18;b[o>>1]=w-$>>18;w=W+131072|0;b[O>>1]=w+_>>18;b[L>>1]=w-_>>18;if((V|0)>0){U=U+2|0;V=V-1|0}else{break}}return}function pOa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=(b[a>>1]|0)+4&65535;b[a>>1]=d;e=a;f=3;g=d;while(1){d=e;h=g<<16>>16;i=e+2|0;j=b[i>>1]|0;k=j<<16>>16;l=e+4|0;m=b[l>>1]|0;n=m<<16>>16;o=e+6|0;p=b[o>>1]|0;q=p<<16>>16;do{if((m|j|p)<<16>>16==0){if(g<<16>>16==0){break}r=g<<2<<16>>16;s=r&65532|r<<16;c[d>>2]=s;c[l>>2]=s}else{s=j<<16>>16!=0;do{if(p<<16>>16==0){if(s){r=k*4433|0;t=k*10703|0;u=n+h<<13;v=h-n<<13;w=u-t|0;x=v-r|0;y=v+r|0;z=u+t|0;break}else{t=n+h<<13;u=h-n<<13;w=t;x=u;y=u;z=t;break}}else{if(s){t=(q+k|0)*4433|0;u=t+(q*-15137|0)|0;r=t+(k*6270|0)|0;t=n+h<<13;v=h-n<<13;w=t-r|0;x=v-u|0;y=u+v|0;z=r+t|0;break}else{t=q*-10703|0;r=q*4433|0;v=n+h<<13;u=h-n<<13;w=v-r|0;x=u-t|0;y=u+t|0;z=v+r|0;break}}}while(0);b[e>>1]=(z+1024|0)>>>11;b[i>>1]=(y+1024|0)>>>11;b[l>>1]=(x+1024|0)>>>11;b[o>>1]=(w+1024|0)>>>11}}while(0);o=e+16|0;if((f|0)<=0){A=a;B=3;break}e=o;f=f-1|0;g=b[o>>1]|0}while(1){g=b[A>>1]|0;f=A+16|0;e=b[f>>1]|0;a=e<<16>>16;w=A+32|0;x=b[w>>1]|0;y=A+48|0;z=b[y>>1]|0;o=z<<16>>16;l=e<<16>>16!=0;do{if(z<<16>>16==0){if(l){e=a*4433|0;i=a*10703|0;n=x+g<<13;h=g-x<<13;C=n-i|0;D=h-e|0;E=h+e|0;F=n+i|0;break}else{i=x+g<<13;n=g-x<<13;C=i;D=n;E=n;F=i;break}}else{if(l){i=(o+a|0)*4433|0;n=i+(o*-15137|0)|0;e=i+(a*6270|0)|0;i=x+g<<13;h=g-x<<13;C=i-e|0;D=h-n|0;E=n+h|0;F=e+i|0;break}else{i=o*-10703|0;e=o*4433|0;h=x+g<<13;n=g-x<<13;C=h-e|0;D=n-i|0;E=n+i|0;F=h+e|0;break}}}while(0);b[A>>1]=F>>18;b[f>>1]=E>>18;b[w>>1]=D>>18;b[y>>1]=C>>18;if((B|0)<=0){break}A=A+2|0;B=B-1|0}return}function qOa(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=((b[a>>1]|0)+4&65535)<<16>>16;d=a+2|0;e=b[d>>1]|0;f=c+e|0;g=c-e|0;e=a+16|0;c=b[e>>1]|0;h=a+18|0;i=b[h>>1]|0;j=i+c|0;k=c-i|0;b[a>>1]=(j+f|0)>>>3;b[d>>1]=(k+g|0)>>>3;b[e>>1]=(f-j|0)>>>3;b[h>>1]=(g-k|0)>>>3;return}function rOa(a){a=a|0;b[a>>1]=((b[a>>1]|0)+4|0)>>>3;return}function sOa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=UHb()|0;c[b+1244>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+140>>2]=11;l8(b,a);e=0;return e|0}function tOa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=c[b+60>>2]|0;n=c[g+24>>2]|0;o=g+28|0;g=c[o>>2]|0;p=n+g|0;if((g|0)<6){q=-1094995529;i=h;return q|0}r=n;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=a[n+4|0]|0;t=r&255;u=n+5|0;v=(s|0)!=0;a:do{if(v){do{if((s|0)>=0){if((s|0)>(g-5|0)){break}w=m+1244|0;x=N4a(b,c[w>>2]|0)|0;if((x|0)<0){q=x;i=h;return q|0}if(!((r&255)>>>0<2>>>0)){if(!(r<<24>>24==2)){KIb(b,24,2362016,(y=i,i=i+8|0,c[y>>2]=t,y)|0);i=y;q=-1094995529;i=h;return q|0}x=n+6|0;z=a[u]|0;A=b+124|0;if((c[A>>2]|0)<=0){B=x;break a}C=b+120|0;D=0;while(1){E=c[w>>2]|0;F=(c[E>>2]|0)+(ca(c[E+32>>2]|0,D)|0)|0;mrc(F|0,z|0,c[C>>2]|0)|0;F=D+1|0;if((F|0)<(c[A>>2]|0)){D=F}else{B=x;break a}}}x=s<<3;D=x>>>0>2147483639>>>0|(u|0)==0;A=D?0:u;C=D?8:x+8|0;x=b+124|0;D=c[x>>2]|0;if((D|0)>0){z=b+120|0;F=l|0;E=m+1240|0;G=l+4|0;H=k|0;I=k+4|0;J=j|0;K=j+4|0;L=0;M=0;N=c[z>>2]|0;O=D;while(1){if((N|0)>0){D=L;P=0;while(1){Q=c[w>>2]|0;R=c[Q>>2]|0;S=c[Q+32>>2]|0;Q=(ca(S,M)|0)+P|0;T=A+(D>>>3)|0;U=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(D&7)>>>30;T=D+2|0;V=C>>>0>T>>>0?T:C;if((U|0)==3){T=S+1|0;W=Q+S|0;X=Q+(S<<1)|0;Y=Q+(S*3|0)|0;Z=0;_=V;while(1){$=ca(Z,S)|0;aa=0;ba=_;while(1){da=aa+$|0;ea=A+(ba>>>3)|0;fa=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ba&7)>>>30;ea=ba+2|0;ga=C>>>0>ea>>>0?ea:C;if((fa|0)==2){ea=A+(ga>>>3)|0;ha=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ga&7)>>>24;ea=ga+8|0;ia=C>>>0>ea>>>0?ea:C;c[H>>2]=ha;ha=A+(ia>>>3)|0;ea=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ia&7)>>>24;ha=ia+8|0;c[I>>2]=ea;ea=da+Q|0;ia=(da|2)+Q|0;ja=(da|3)+Q|0;ka=(da|1)+Q|0;la=2;ma=C>>>0>ha>>>0?ha:C;while(1){ha=ca(la,S)|0;na=((ma|0)<(C|0))+ma|0;a[R+(ea+ha)|0]=c[k+(((d[A+(ma>>>3)|0]|0)<<(ma&7)>>>7&1)<<2)>>2];oa=((na|0)<(C|0))+na|0;a[R+(ea+(ha|1))|0]=c[k+(((d[A+(na>>>3)|0]|0)<<(na&7)>>>7&1)<<2)>>2];na=((oa|0)<(C|0))+oa|0;a[R+(ia+ha)|0]=c[k+(((d[A+(oa>>>3)|0]|0)<<(oa&7)>>>7&1)<<2)>>2];oa=((na|0)<(C|0))+na|0;a[R+(ja+ha)|0]=c[k+(((d[A+(na>>>3)|0]|0)<<(na&7)>>>7&1)<<2)>>2];na=ca(la|1,S)|0;ha=((oa|0)<(C|0))+oa|0;a[R+(ea+na)|0]=c[k+(((d[A+(oa>>>3)|0]|0)<<(oa&7)>>>7&1)<<2)>>2];oa=((ha|0)<(C|0))+ha|0;a[R+(ka+na)|0]=c[k+(((d[A+(ha>>>3)|0]|0)<<(ha&7)>>>7&1)<<2)>>2];ha=((oa|0)<(C|0))+oa|0;a[R+(ia+na)|0]=c[k+(((d[A+(oa>>>3)|0]|0)<<(oa&7)>>>7&1)<<2)>>2];oa=((ha|0)<(C|0))+ha|0;a[R+(ja+na)|0]=c[k+(((d[A+(ha>>>3)|0]|0)<<(ha&7)>>>7&1)<<2)>>2];ha=la-2|0;if((ha|0)>-1){la=ha;ma=oa}else{pa=oa;break}}}else if((fa|0)==1){ma=A+(ga>>>3)|0;la=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ga&7)>>>24;ma=ga+8|0;c[H>>2]=la;ja=la&255;mrc(R+(da+Q)|0,ja|0,4)|0;mrc(R+(W+da)|0,ja|0,4)|0;mrc(R+(X+da)|0,ja|0,4)|0;mrc(R+(Y+da)|0,ja|0,4)|0;pa=C>>>0>ma>>>0?ma:C}else if((fa|0)==3){ma=da+Q|0;ja=da+S+Q|0;la=T+da+Q|0;ia=0;ka=ga;while(1){ea=ca(ia,S)|0;oa=0;ha=ka;while(1){na=oa+ea|0;qa=R+(ma+na)|0;ra=A+(ha>>>3)|0;sa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ha&7)>>>30;ra=ha+2|0;ta=C>>>0>ra>>>0?ra:C;if((sa|0)==1){ra=A+(ta>>>3)|0;ua=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ta&7)>>>24;ra=ta+8|0;c[J>>2]=ua;va=ua&255;mrc(qa|0,va|0,2)|0;mrc(R+(ja+na)|0,va|0,2)|0;wa=C>>>0>ra>>>0?ra:C}else if((sa|0)==2){ra=A+(ta>>>3)|0;va=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ta&7)>>>24;ra=ta+8|0;ua=C>>>0>ra>>>0?ra:C;c[J>>2]=va;va=A+(ua>>>3)|0;ra=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(ua&7)>>>24;va=ua+8|0;ua=C>>>0>va>>>0?va:C;c[K>>2]=ra;ra=((ua|0)<(C|0))+ua|0;a[qa]=c[j+(((d[A+(ua>>>3)|0]|0)<<(ua&7)>>>7&1)<<2)>>2];ua=((ra|0)<(C|0))+ra|0;a[R+(ma+(na|1))|0]=c[j+(((d[A+(ra>>>3)|0]|0)<<(ra&7)>>>7&1)<<2)>>2];ra=((ua|0)<(C|0))+ua|0;a[R+(ja+na)|0]=c[j+(((d[A+(ua>>>3)|0]|0)<<(ua&7)>>>7&1)<<2)>>2];a[R+(la+na)|0]=c[j+(((d[A+(ra>>>3)|0]|0)<<(ra&7)>>>7&1)<<2)>>2];wa=((ra|0)<(C|0))+ra|0}else if((sa|0)==3){sa=A+(ta>>>3)|0;ra=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ta&7)>>>24;sa=ta+8|0;ua=C>>>0>sa>>>0?sa:C;a[qa]=ra;ra=A+(ua>>>3)|0;qa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ua&7)>>>24;ra=ua+8|0;ua=C>>>0>ra>>>0?ra:C;a[R+(ma+(na|1))|0]=qa;qa=A+(ua>>>3)|0;ra=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ua&7)>>>24;qa=ua+8|0;ua=C>>>0>qa>>>0?qa:C;a[R+(ja+na)|0]=ra;ra=A+(ua>>>3)|0;qa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ua&7)>>>24;ra=ua+8|0;a[R+(la+na)|0]=qa;wa=C>>>0>ra>>>0?ra:C}else{wa=ta}ta=oa+2|0;if((ta|0)<4){oa=ta;ha=wa}else{break}}ha=ia+2|0;if((ha|0)<4){ia=ha;ka=wa}else{pa=wa;break}}}else{pa=ga}ka=aa+4|0;if((ka|0)<8){aa=ka;ba=pa}else{break}}ba=Z+4|0;if((ba|0)<8){Z=ba;_=pa}else{xa=pa;break}}}else if((U|0)==2){_=A+(V>>>3)|0;Z=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(V&7)>>>24;_=V+8|0;T=C>>>0>_>>>0?_:C;c[F>>2]=Z;Z=A+(T>>>3)|0;_=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(T&7)>>>24;Z=T+8|0;c[G>>2]=_;_=7;T=C>>>0>Z>>>0?Z:C;while(1){Z=(ca(_,S)|0)+Q|0;Y=0;X=T;while(1){ya=((X|0)<(C|0))+X|0;a[R+(Z+Y)|0]=c[l+(((d[A+(X>>>3)|0]|0)<<(X&7)>>>7&1)<<2)>>2];W=Y+1|0;if((W|0)<8){Y=W;X=ya}else{break}}if((_|0)>0){_=_-1|0;T=ya}else{xa=ya;break}}}else if((U|0)==1){T=A+(V>>>3)|0;_=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(V&7)>>>24;T=V+8|0;c[F>>2]=_;mf[c[E>>2]&2047](R+Q|0,_&255,S,8);xa=C>>>0>T>>>0?T:C}else{xa=V}T=P+8|0;za=c[z>>2]|0;if((T|0)<(za|0)){D=xa;P=T}else{break}}Aa=xa;Ba=za;Ca=c[x>>2]|0}else{Aa=L;Ba=N;Ca=O}P=M+8|0;if((P|0)<(Ca|0)){L=Aa;M=P;N=Ba;O=Ca}else{break}}}B=n+(s+5)|0;break a}}while(0);KIb(b,16,2451304,(y=i,i=i+8|0,c[y>>2]=s,y)|0);i=y;q=-1094995529;i=h;return q|0}else{B=u}}while(0);if((p-B|0)>767){p=m+1248|0;u=0;y=B;while(1){B=(d[y+1|0]|0)<<8|(d[y]|0)<<16|(d[y+2|0]|0);c[p+(u<<2)>>2]=B<<2|B>>>4&197379|-16777216;B=u+1|0;if((B|0)<256){u=B;y=y+3|0}else{break}}c[m+2272>>2]=1}do{if(v){y=m+1244|0;u=c[y>>2]|0;c[u+84>>2]=1;c[u+88>>2]=1;p=m+2272|0;c[u+304>>2]=c[p>>2];c[p>>2]=0;nrc(c[u+4>>2]|0,m+1248|0,1024)|0;u=YHb(e,c[y>>2]|0)|0;if((u|0)<0){q=u;i=h;return q|0}else{c[f>>2]=1;break}}}while(0);q=c[o>>2]|0;i=h;return q|0}function uOa(a){a=a|0;VHb((c[a+60>>2]|0)+1244|0);return 0}function vOa(a){a=a|0;c[a+140>>2]=46;return 0}function wOa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+32|0;j=h|0;k=j;l=e;m=c[g+24>>2]|0;n=g+28|0;g=c[n>>2]|0;o=a+60|0;p=c[o>>2]|0;if((g|0)<2){q=-1094995529;i=h;return q|0}r=((d[m]|0)<<3)+8|0;s=((d[m+1|0]|0)<<3)+8|0;t=m+2|0;u=a+120|0;if((r|0)==(c[u>>2]|0)){if((s|0)!=(c[a+124>>2]|0)){v=4}}else{v=4}do{if((v|0)==4){mJb(p);mJb(p+4|0);w=H4a(a,r,s)|0;if((w|0)<0){q=w}else{break}i=h;return q|0}}while(0);w=p;do{if((c[w>>2]|0)==0){x=a+124|0;c[w>>2]=pJb(ca(c[u>>2]<<1,c[x>>2]|0)|0)|0;y=pJb(ca(c[u>>2]<<1,c[x>>2]|0)|0)|0;c[p+4>>2]=y;if(!((c[w>>2]|0)==0|(y|0)==0)){break}y=c[o>>2]|0;mJb(y);mJb(y+4|0);q=-12;i=h;return q|0}}while(0);o=ca(s,r)|0;r=M4a(a,l,0)|0;if((r|0)<0){q=r;i=h;return q|0}r=c[w>>2]|0;l=p+4|0;p=c[l>>2]|0;mrc(k|0,-1|0,32)|0;if((o|0)>0){k=m+(g-2)|0;s=m+(g-3)|0;y=m+(g-1)|0;a:do{if((p|0)==0){g=0;m=t;while(1){if(k>>>0<m>>>0){z=g;break a}x=m;A=(d[x]|d[x+1|0]<<8)<<16>>16;B=A&65535;C=m+2|0;if((B&32768|0)==0){b[r+(g<<1)>>1]=A;D=C;E=g+1|0}else{A=B&24576;if((A|0)==24576){break}x=(B&8191)+1|0;if((A|0)==0){F=C;G=2}else if((A|0)==8192){F=C;G=3}else{if(y>>>0<C>>>0){z=g;break a}F=m+3|0;G=(d[C]|0)+4|0}if((g|0)<(x|0)){z=g;break a}if((o-g|0)<(G|0)){z=g;break a}vJb(r+(g<<1)|0,x<<1,G<<1);D=F;E=G+g|0}if((E|0)<(o|0)){g=E;m=D}else{z=E;break a}}x=(B&1023)+3|0;A=j+((B>>>10&7)<<2)|0;H=c[A>>2]|0;if((H|0)<0){if(s>>>0<C>>>0){z=g;break}I=(d[m+3|0]|0)<<8|(d[m+4|0]|0)<<16|(d[C]|0);c[A>>2]=I;J=I}else{J=H}if((o-((J+g|0)%(o|0)|0)|0)<(x|0)){z=g;break}if((o-g|0)<(x|0)){z=g;break}KIb(a,16,2451272,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;z=g}else{x=0;H=t;while(1){if(k>>>0<H>>>0){z=x;break a}I=H;A=(d[I]|d[I+1|0]<<8)<<16>>16;I=A&65535;L=H+2|0;if((I&32768|0)==0){b[r+(x<<1)>>1]=A;M=L;N=x+1|0}else{A=I&24576;if((A|0)==24576){O=(I&1023)+3|0;P=j+((I>>>10&7)<<2)|0;Q=c[P>>2]|0;if((Q|0)<0){if(s>>>0<L>>>0){z=x;break a}R=(d[H+3|0]|0)<<8|(d[H+4|0]|0)<<16|(d[L]|0);c[P>>2]=R;S=H+5|0;T=R}else{S=L;T=Q}Q=(T+x|0)%(o|0)|0;if((o-Q|0)<(O|0)){z=x;break a}if((o-x|0)<(O|0)){z=x;break a}nrc(r+(x<<1)|0,p+(Q<<1)|0,O<<1)|0;U=S;V=O}else{O=(I&8191)+1|0;if((A|0)==0){W=L;X=2}else if((A|0)==8192){W=L;X=3}else{if(y>>>0<L>>>0){z=x;break a}W=H+3|0;X=(d[L]|0)+4|0}if((x|0)<(O|0)){z=x;break a}if((o-x|0)<(X|0)){z=x;break a}vJb(r+(x<<1)|0,O<<1,X<<1);U=W;V=X}M=U;N=V+x|0}if((N|0)<(o|0)){x=N;H=M}else{z=N;break}}}}while(0);if((z|0)!=(o|0)){Y=z;v=49}}else{Y=0;v=49}if((v|0)==49){KIb(a,48,2361984,(K=i,i=i+8|0,c[K>>2]=Y-o,K)|0);i=K}K=c[u>>2]<<1;uIb(c[e>>2]|0,c[e+32>>2]|0,c[w>>2]|0,K,K,c[a+124>>2]|0);a=c[l>>2]|0;c[l>>2]=c[w>>2];c[w>>2]=a;c[f>>2]=1;q=c[n>>2]|0;i=h;return q|0}function xOa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b);mJb(b+4|0);return 0}function yOa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b);mJb(b+4|0);return}function zOa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;do{if((c[a+120>>2]|0)<=320){if((c[a+124>>2]|0)>200){break}c[e+1036>>2]=e+1044;c[e+1040>>2]=e+65044;f=e+12|0;g=0;do{c[f+(g<<2)>>2]=g*65793|0|-16777216;g=g+1|0;}while((g|0)<256);g=a+100|0;do{if((c[g>>2]|0)<12){KIb(a,24,2639016,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;c[e+8>>2]=127}else{j=(c[a+96>>2]|0)+10|0;k=(d[j]|d[j+1|0]<<8)<<16>>16;j=e+8|0;c[j>>2]=k&65535;if(!((k&65535)>>>0>255>>>0)){break}c[j>>2]=127;KIb(a,16,2616456,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;l=-1094995529;i=b;return l|0}}while(0);if((c[g>>2]|0)==1036){j=0;k=(c[a+96>>2]|0)+12|0;while(1){m=k;c[f+(j<<2)>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=j+1|0;if((m|0)<256){j=m;k=k+4|0}else{break}}c[e+4>>2]=1}c[a+140>>2]=11;l=0;i=b;return l|0}}while(0);KIb(a,16,2121528,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;l=-22;i=b;return l|0}function AOa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0;h=i;j=c[b+60>>2]|0;k=V1(g,0,0)|0;l=c[g+24>>2]|0;m=g+28|0;g=c[m>>2]|0;if(!((g|0)>-1)){KIb(0,0,2204872,(n=i,i=i+24|0,c[n>>2]=2172720,c[n+8>>2]=2145304,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}o=j+129044|0;c[o>>2]=l;p=j+129052|0;c[p>>2]=l;q=j+129048|0;c[q>>2]=l+g;g=M4a(b,e,0)|0;if((g|0)<0){r=g;i=h;return r|0}g=c[q>>2]|0;l=c[o>>2]|0;s=g;if((s-l|0)<1){t=0;u=l}else{v=l+1|0;c[o>>2]=v;t=d[l]|0;u=v}v=s-u|0;do{if((v|0)<1){w=g;x=u}else{if((a[u]|0)!=127){w=g;x=u;break}s=u+(v>>>0>3>>>0?3:v)|0;c[o>>2]=s;l=t&129;y=j+12|0;z=0;A=g;B=s;do{if((A-B|0)<3){C=-16777216}else{c[o>>2]=B+3;C=d[B]<<16|d[B+1|0]<<8|d[B+2|0]|-16777216}c[y+(z+l<<2)>>2]=C;A=c[q>>2]|0;D=c[o>>2]|0;E=A;s=E-D|0;F=s>>>0>1>>>0?1:s;B=D+F|0;c[o>>2]=B;z=z+1|0;}while((z|0)<127);z=B;l=(c[p>>2]|0)-z|0;y=E-z|0;if((l|0)>-511){G=l}else{G=(y|0)<-511?y:-511}y=D+(F+G)|0;c[o>>2]=y;w=A;x=y}}while(0);G=e+84|0;if((t&128|0)==0){c[G>>2]=0;c[e+88>>2]=2}else{c[G>>2]=1;c[e+88>>2]=1}a:do{if((t&64|0)!=0){c[e+304>>2]=1;G=j+8|0;if((c[G>>2]|0)<1){break}F=j+12|0;D=1;E=w;p=x;while(1){if((E-p|0)<3){H=-16777216}else{c[o>>2]=p+3;H=d[p]<<16|d[p+1|0]<<8|d[p+2|0]|-16777216}c[F+(D<<2)>>2]=H;C=D+1|0;if((C|0)>(c[G>>2]|0)){break a}D=C;E=c[q>>2]|0;p=c[o>>2]|0}}}while(0);if((k|0)!=0){c[e+304>>2]=1;nrc(j+12|0,k|0,1024)|0}k=j+4|0;if((c[k>>2]|0)!=0){c[k>>2]=0;c[e+304>>2]=1}nrc(c[e+4>>2]|0,j+12|0,1024)|0;k=c[o>>2]|0;do{if(((c[q>>2]|0)-k|0)<1){I=0}else{c[o>>2]=k+1;H=d[k]|0;if(!((H|0)==127|(H|0)==8)){I=H;break}H=j+1036|0;mrc(c[H>>2]|0,0,64e3)|0;x=t&15;b:do{if((x|0)==4){w=c[b+120>>2]|0;p=b+124|0;E=c[p>>2]|0;D=c[o>>2]|0;if(((c[q>>2]|0)-D|0)<1){J=0}else{c[o>>2]=D+1;J=d[D]|0}if((E|0)<=0){K=p;break}D=(w|0)>0;G=j+1040|0;F=0;A=7;B=J;c:while(1){if(D){C=0;g=A;v=B;while(1){u=(1<<g&v|0)==0;y=g-1|0;do{if((g|0)==0){l=c[o>>2]|0;if(((c[q>>2]|0)-l|0)<1){L=0;M=7;break}c[o>>2]=l+1;L=d[l]|0;M=7}else{L=v;M=y}}while(0);d:do{if(u){y=(L&1<<M|0)==0;l=M-1|0;do{if((M|0)==0){z=c[o>>2]|0;if(((c[q>>2]|0)-z|0)<1){N=0;O=7;break}c[o>>2]=z+1;N=d[z]|0;O=7}else{N=L;O=l}}while(0);if(!y){l=0;while(1){z=(((l>>3)+F|0)*320|0)+(l&7|C)|0;if((z|0)<0){P=0}else{P=(z|0)>63999?63999:z}a[(c[H>>2]|0)+P|0]=a[(c[G>>2]|0)+P|0]|0;z=l+1|0;if((z|0)<64){l=z}else{Q=N;R=O;break d}}}l=c[o>>2]|0;y=c[q>>2]|0;if((y|0)==(l|0)){S=145;break c}if((y-l|0)<1){T=0}else{c[o>>2]=l+1;T=a[l]|0}l=0;while(1){y=(((l>>3)+F|0)*320|0)+(l&7|C)|0;if((y|0)<0){U=0}else{U=(y|0)>63999?63999:y}a[(c[H>>2]|0)+U|0]=T;y=l+1|0;if((y|0)<64){l=y}else{Q=N;R=O;break}}}else{if((c[q>>2]|0)==(c[o>>2]|0)){S=156;break c}else{V=0;W=M;X=L}while(1){l=V<<2&4|C;y=V<<1&4|F;z=(1<<W&X|0)==0;s=W-1|0;do{if((W|0)==0){Y=c[o>>2]|0;if(((c[q>>2]|0)-Y|0)<1){Z=0;_=7;break}c[o>>2]=Y+1;Z=d[Y]|0;_=7}else{Z=X;_=s}}while(0);e:do{if(z){s=(Z&1<<_|0)==0;do{if((_|0)==0){Y=c[q>>2]|0;$=c[o>>2]|0;if((Y-$|0)<1){aa=0;ba=7;ca=Y;da=$;break}ea=$+1|0;c[o>>2]=ea;aa=d[$]|0;ba=7;ca=Y;da=ea}else{aa=Z;ba=_-1|0;ca=c[q>>2]|0;da=c[o>>2]|0}}while(0);if((ca-da|0)<1){fa=0}else{c[o>>2]=da+1;fa=d[da]|0}if(s){ea=fa&255;Y=0;while(1){$=(((Y>>2)+y|0)*320|0)+(Y&3|l)|0;if(($|0)<0){ga=0}else{ga=($|0)>63999?63999:$}a[(c[H>>2]|0)+ga|0]=ea;$=Y+1|0;if(($|0)<16){Y=$}else{ha=aa;ia=ba;break e}}}Y=(fa&15)-8|0;ea=(fa>>>4)-8|0;if((Y+l+((ea+y|0)*320|0)|0)>>>0>63036>>>0){S=173;break c}else{ja=0}while(1){s=ja&3|l;$=(ja>>2)+y|0;ka=s+Y+(($+ea|0)*320|0)|0;if((ka|0)<0){la=0}else{la=(ka|0)>63999?63999:ka}ka=($*320|0)+s|0;if((ka|0)<0){ma=0}else{ma=(ka|0)>63999?63999:ka}a[(c[H>>2]|0)+ma|0]=a[(c[G>>2]|0)+la|0]|0;ka=ja+1|0;if((ka|0)<16){ja=ka}else{ha=aa;ia=ba;break}}}else{ea=0;Y=_;ka=Z;while(1){s=ea<<1&2|l;$=ea&2|y;na=(1<<Y&ka|0)==0;oa=Y-1|0;do{if((Y|0)==0){pa=c[o>>2]|0;if(((c[q>>2]|0)-pa|0)<1){qa=0;ra=7;break}c[o>>2]=pa+1;qa=d[pa]|0;ra=7}else{qa=ka;ra=oa}}while(0);do{if(na){oa=(qa&1<<ra|0)==0;do{if((ra|0)==0){pa=c[q>>2]|0;sa=c[o>>2]|0;if((pa-sa|0)<1){ta=0;ua=7;va=pa;wa=sa;break}xa=sa+1|0;c[o>>2]=xa;ta=d[sa]|0;ua=7;va=pa;wa=xa}else{ta=qa;ua=ra-1|0;va=c[q>>2]|0;wa=c[o>>2]|0}}while(0);if((va-wa|0)<1){ya=0}else{c[o>>2]=wa+1;ya=d[wa]|0}if(oa){xa=ya&255;pa=$*320|0;sa=s+pa|0;if((sa|0)<0){za=0}else{za=(sa|0)>63999?63999:sa}a[(c[H>>2]|0)+za|0]=xa;sa=s|1;Aa=sa+pa|0;if((Aa|0)<0){Ba=0}else{Ba=(Aa|0)>63999?63999:Aa}a[(c[H>>2]|0)+Ba|0]=xa;Aa=($|1)*320|0;pa=Aa+s|0;if((pa|0)<0){Ca=0}else{Ca=(pa|0)>63999?63999:pa}a[(c[H>>2]|0)+Ca|0]=xa;pa=sa+Aa|0;if((pa|0)<0){Da=0}else{Da=(pa|0)>63999?63999:pa}a[(c[H>>2]|0)+Da|0]=xa;Ea=ta;Fa=ua;break}xa=(ya&15)-8|0;pa=(ya>>>4)-8|0;Aa=xa+s|0;sa=(pa+$|0)*320|0;Ga=sa+Aa|0;if(Ga>>>0>63678>>>0){S=200;break c}Ha=$*320|0;Ia=s+Ha|0;if((Ia|0)<0){Ja=0}else{Ja=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Ja|0]=a[(c[G>>2]|0)+Ga|0]|0;Ga=s|1;Ia=xa+Ga|0;xa=sa+Ia|0;if((xa|0)<0){Ka=0}else{Ka=(xa|0)>63999?63999:xa}xa=Ga+Ha|0;if((xa|0)<0){La=0}else{La=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+La|0]=a[(c[G>>2]|0)+Ka|0]|0;xa=$|1;Ha=(pa+xa|0)*320|0;pa=Ha+Aa|0;if((pa|0)<0){Ma=0}else{Ma=(pa|0)>63999?63999:pa}pa=xa*320|0;xa=pa+s|0;if((xa|0)<0){Na=0}else{Na=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+Na|0]=a[(c[G>>2]|0)+Ma|0]|0;xa=Ha+Ia|0;if((xa|0)<0){Oa=0}else{Oa=(xa|0)>63999?63999:xa}xa=Ga+pa|0;if((xa|0)<0){Pa=0}else{Pa=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+Pa|0]=a[(c[G>>2]|0)+Oa|0]|0;Ea=ta;Fa=ua}else{xa=c[o>>2]|0;if(((c[q>>2]|0)-xa|0)<1){Qa=0}else{c[o>>2]=xa+1;Qa=a[xa]|0}xa=$*320|0;pa=s+xa|0;if((pa|0)<0){Ra=0}else{Ra=(pa|0)>63999?63999:pa}a[(c[H>>2]|0)+Ra|0]=Qa;pa=c[o>>2]|0;if(((c[q>>2]|0)-pa|0)<1){Sa=0}else{c[o>>2]=pa+1;Sa=a[pa]|0}pa=s|1;Ga=pa+xa|0;if((Ga|0)<0){Ta=0}else{Ta=(Ga|0)>63999?63999:Ga}a[(c[H>>2]|0)+Ta|0]=Sa;Ga=c[o>>2]|0;if(((c[q>>2]|0)-Ga|0)<1){Ua=0}else{c[o>>2]=Ga+1;Ua=a[Ga]|0}Ga=($|1)*320|0;xa=Ga+s|0;if((xa|0)<0){Va=0}else{Va=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+Va|0]=Ua;xa=c[o>>2]|0;if(((c[q>>2]|0)-xa|0)<1){Wa=0}else{c[o>>2]=xa+1;Wa=a[xa]|0}xa=pa+Ga|0;if((xa|0)<0){Xa=0}else{Xa=(xa|0)>63999?63999:xa}a[(c[H>>2]|0)+Xa|0]=Wa;Ea=qa;Fa=ra}}while(0);s=ea+1|0;if((s|0)<4){ea=s;Y=Fa;ka=Ea}else{ha=Ea;ia=Fa;break}}}}while(0);y=V+1|0;if((y|0)<4){V=y;W=ia;X=ha}else{Q=ha;R=ia;break}}}}while(0);u=C+8|0;if((u|0)<(w|0)){C=u;g=R;v=Q}else{Ya=R;Za=Q;break}}}else{Ya=A;Za=B}v=F+8|0;if((v|0)<(E|0)){F=v;A=Ya;B=Za}else{K=p;break b}}if((S|0)==145){KIb(c[j>>2]|0,16,2297376,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=p;break}else if((S|0)==156){KIb(c[j>>2]|0,16,2297376,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=p;break}else if((S|0)==173){KIb(c[j>>2]|0,16,2246560,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=p;break}else if((S|0)==200){KIb(c[j>>2]|0,16,2246560,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=p;break}}else if((x|0)==0|(x|0)==1){nrc(c[H>>2]|0,c[j+1040>>2]|0,64e3)|0;K=b+124|0}else if((x|0)==3){B=c[b+120>>2]|0;A=b+124|0;F=c[A>>2]|0;E=c[o>>2]|0;if(((c[q>>2]|0)-E|0)<1){_a=0}else{c[o>>2]=E+1;_a=d[E]|0}if((F|0)<=0){K=A;break}E=(B|0)>0;w=0;G=7;D=_a;f:while(1){if(E){v=0;g=G;C=D;while(1){u=c[o>>2]|0;y=c[q>>2]|0;if((y|0)==(u|0)){S=40;break f}l=(1<<g&C|0)==0;z=g-1|0;do{if((g|0)==0){if((y-u|0)<1){$a=0;ab=7;bb=u;break}ka=u+1|0;c[o>>2]=ka;$a=d[u]|0;ab=7;bb=ka}else{$a=C;ab=z;bb=u}}while(0);if(l){if((y-bb|0)<1){cb=0}else{c[o>>2]=bb+1;cb=a[bb]|0}u=0;while(1){z=(((u>>3)+w|0)*320|0)+(u&7|v)|0;if((z|0)<0){db=0}else{db=(z|0)>63999?63999:z}a[(c[H>>2]|0)+db|0]=cb;z=u+1|0;if((z|0)<64){u=z}else{eb=$a;fb=ab;break}}}else{u=0;y=ab;l=$a;while(1){z=u<<2&4|v;ka=u<<1&4|w;Y=(1<<y&l|0)==0;ea=y-1|0;do{if((y|0)==0){s=c[o>>2]|0;if(((c[q>>2]|0)-s|0)<1){gb=0;hb=7;break}c[o>>2]=s+1;gb=d[s]|0;hb=7}else{gb=l;hb=ea}}while(0);g:do{if(Y){ea=(gb&1<<hb|0)==0;do{if((hb|0)==0){s=c[q>>2]|0;$=c[o>>2]|0;if((s-$|0)<1){ib=0;jb=7;kb=s;lb=$;break}na=$+1|0;c[o>>2]=na;ib=d[$]|0;jb=7;kb=s;lb=na}else{ib=gb;jb=hb-1|0;kb=c[q>>2]|0;lb=c[o>>2]|0}}while(0);if((kb-lb|0)<1){mb=0}else{c[o>>2]=lb+1;mb=d[lb]|0}if(ea){na=mb&255;s=0;while(1){$=(((s>>2)+ka|0)*320|0)+(s&3|z)|0;if(($|0)<0){nb=0}else{nb=($|0)>63999?63999:$}a[(c[H>>2]|0)+nb|0]=na;$=s+1|0;if(($|0)<16){s=$}else{ob=ib;pb=jb;break g}}}s=mb&15;na=mb>>>4;if((z-s+((ka-na|0)*320|0)|0)>>>0>63036>>>0){S=67;break f}else{qb=0}while(1){ea=qb&3|z;$=(qb>>2)+ka|0;xa=(($-na|0)*320|0)+(ea-s)|0;if((xa|0)<0){rb=0}else{rb=(xa|0)>63999?63999:xa}xa=c[H>>2]|0;Ga=($*320|0)+ea|0;if((Ga|0)<0){sb=0}else{sb=(Ga|0)>63999?63999:Ga}a[xa+sb|0]=a[xa+rb|0]|0;xa=qb+1|0;if((xa|0)<16){qb=xa}else{ob=ib;pb=jb;break}}}else{s=0;na=hb;xa=gb;while(1){Ga=s<<1&2|z;ea=s&2|ka;$=(1<<na&xa|0)==0;pa=na-1|0;do{if((na|0)==0){Ia=c[o>>2]|0;if(((c[q>>2]|0)-Ia|0)<1){tb=0;ub=7;break}c[o>>2]=Ia+1;tb=d[Ia]|0;ub=7}else{tb=xa;ub=pa}}while(0);do{if($){pa=(tb&1<<ub|0)==0;do{if((ub|0)==0){Ia=c[q>>2]|0;Ha=c[o>>2]|0;if((Ia-Ha|0)<1){vb=0;wb=7;xb=Ia;yb=Ha;break}Aa=Ha+1|0;c[o>>2]=Aa;vb=d[Ha]|0;wb=7;xb=Ia;yb=Aa}else{vb=tb;wb=ub-1|0;xb=c[q>>2]|0;yb=c[o>>2]|0}}while(0);if((xb-yb|0)<1){zb=0}else{c[o>>2]=yb+1;zb=d[yb]|0}if(pa){Aa=zb&255;Ia=ea*320|0;Ha=Ga+Ia|0;if((Ha|0)<0){Ab=0}else{Ab=(Ha|0)>63999?63999:Ha}a[(c[H>>2]|0)+Ab|0]=Aa;Ha=Ga|1;sa=Ha+Ia|0;if((sa|0)<0){Bb=0}else{Bb=(sa|0)>63999?63999:sa}a[(c[H>>2]|0)+Bb|0]=Aa;sa=(ea|1)*320|0;Ia=sa+Ga|0;if((Ia|0)<0){Cb=0}else{Cb=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Cb|0]=Aa;Ia=Ha+sa|0;if((Ia|0)<0){Db=0}else{Db=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Db|0]=Aa;Eb=vb;Fb=wb;break}Aa=zb&15;Ia=zb>>>4;sa=Ga-Aa|0;Ha=(ea-Ia|0)*320|0;Gb=Ha+sa|0;if(Gb>>>0>63678>>>0){S=94;break f}Hb=c[H>>2]|0;Ib=ea*320|0;Jb=Ga+Ib|0;if((Jb|0)<0){Kb=0}else{Kb=(Jb|0)>63999?63999:Jb}a[Hb+Kb|0]=a[Hb+Gb|0]|0;Gb=Ga|1;Hb=Gb-Aa|0;Aa=Ha+Hb|0;if((Aa|0)<0){Lb=0}else{Lb=(Aa|0)>63999?63999:Aa}Aa=c[H>>2]|0;Ha=Gb+Ib|0;if((Ha|0)<0){Mb=0}else{Mb=(Ha|0)>63999?63999:Ha}a[Aa+Mb|0]=a[Aa+Lb|0]|0;Aa=ea|1;Ha=(Aa-Ia|0)*320|0;Ia=Ha+sa|0;if((Ia|0)<0){Nb=0}else{Nb=(Ia|0)>63999?63999:Ia}Ia=c[H>>2]|0;sa=Aa*320|0;Aa=sa+Ga|0;if((Aa|0)<0){Ob=0}else{Ob=(Aa|0)>63999?63999:Aa}a[Ia+Ob|0]=a[Ia+Nb|0]|0;Ia=Ha+Hb|0;if((Ia|0)<0){Pb=0}else{Pb=(Ia|0)>63999?63999:Ia}Ia=c[H>>2]|0;Hb=Gb+sa|0;if((Hb|0)<0){Qb=0}else{Qb=(Hb|0)>63999?63999:Hb}a[Ia+Qb|0]=a[Ia+Pb|0]|0;Eb=vb;Fb=wb}else{Ia=c[o>>2]|0;if(((c[q>>2]|0)-Ia|0)<1){Rb=0}else{c[o>>2]=Ia+1;Rb=a[Ia]|0}Ia=ea*320|0;Hb=Ga+Ia|0;if((Hb|0)<0){Sb=0}else{Sb=(Hb|0)>63999?63999:Hb}a[(c[H>>2]|0)+Sb|0]=Rb;Hb=c[o>>2]|0;if(((c[q>>2]|0)-Hb|0)<1){Tb=0}else{c[o>>2]=Hb+1;Tb=a[Hb]|0}Hb=Ga|1;sa=Hb+Ia|0;if((sa|0)<0){Ub=0}else{Ub=(sa|0)>63999?63999:sa}a[(c[H>>2]|0)+Ub|0]=Tb;sa=c[o>>2]|0;if(((c[q>>2]|0)-sa|0)<1){Vb=0}else{c[o>>2]=sa+1;Vb=a[sa]|0}sa=(ea|1)*320|0;Ia=sa+Ga|0;if((Ia|0)<0){Wb=0}else{Wb=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Wb|0]=Vb;Ia=c[o>>2]|0;if(((c[q>>2]|0)-Ia|0)<1){Xb=0}else{c[o>>2]=Ia+1;Xb=a[Ia]|0}Ia=Hb+sa|0;if((Ia|0)<0){Yb=0}else{Yb=(Ia|0)>63999?63999:Ia}a[(c[H>>2]|0)+Yb|0]=Xb;Eb=tb;Fb=ub}}while(0);Ga=s+1|0;if((Ga|0)<4){s=Ga;na=Fb;xa=Eb}else{ob=Eb;pb=Fb;break}}}}while(0);ka=u+1|0;if((ka|0)<4){u=ka;y=pb;l=ob}else{eb=ob;fb=pb;break}}}l=v+8|0;if((l|0)<(B|0)){v=l;g=fb;C=eb}else{Zb=fb;_b=eb;break}}}else{Zb=G;_b=D}C=w+8|0;if((C|0)<(F|0)){w=C;G=Zb;D=_b}else{K=A;break b}}if((S|0)==40){KIb(c[j>>2]|0,16,2297376,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=A;break}else if((S|0)==67){KIb(c[j>>2]|0,16,2246560,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=A;break}else if((S|0)==94){KIb(c[j>>2]|0,16,2246560,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;K=A;break}}else{KIb(b,16,2361952,(n=i,i=i+8|0,c[n>>2]=x,n)|0);i=n;r=-1094995529;i=h;return r|0}}while(0);h:do{if((c[K>>2]|0)>0){x=b+120|0;D=e+32|0;G=1;w=c[H>>2]|0;F=c[e>>2]|0;while(1){nrc(F|0,w|0,c[x>>2]|0)|0;if((G|0)>=(c[K>>2]|0)){break h}G=G+1|0;w=w+320|0;F=F+(c[D>>2]|0)|0}}}while(0);D=c[H>>2]|0;F=j+1044|0;if((D|0)==(F|0)){c[H>>2]=j+65044;c[j+1040>>2]=D}else{c[H>>2]=F;c[j+1040>>2]=j+65044}c[f>>2]=1;r=c[m>>2]|0;i=h;return r|0}}while(0);KIb(b,16,2451216,(n=i,i=i+8|0,c[n>>2]=I,n)|0);i=n;r=-1094995529;i=h;return r|0}function BOa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;l8(b+4|0,a);return 0}function COa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;h=i;i=i+48|0;j=h|0;k=h+16|0;l=h+32|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;o=g;c[j>>2]=e;c[j+4>>2]=0;c[j+8>>2]=0;c[e+84>>2]=1;p=a[m]|0;q=m+1|0;r=q;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=m+5|0;t=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=p&255;a:do{switch(r|0){case 6:{u=b+792|0;v=b+140|0;if((c[u>>2]|0)==24){c[v>>2]=2;w=s}else{c[v>>2]=30;w=s|-16777216}v=J5a(b,j,0)|0;if((v|0)<0){x=v;i=h;return x|0}v=b+124|0;z=c[v>>2]|0;if((z|0)<=0){break a}A=b+120|0;B=e+32|0;C=w&255;D=w>>>8&255;E=w>>>16&255;F=c[e>>2]|0;G=0;H=c[A>>2]|0;I=z;while(1){if((H|0)>0){z=0;do{if((c[u>>2]|0)==24){J=z*3|0;a[F+(J+2)|0]=C;a[F+(J+1)|0]=D;a[F+J|0]=E}else{J=F+(z<<2)|0;y=w;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y}z=z+1|0;K=c[A>>2]|0;}while((z|0)<(K|0));L=K;M=c[v>>2]|0}else{L=H;M=I}z=G+1|0;if((z|0)<(M|0)){F=F+(c[B>>2]|0)|0;G=z;H=L;I=M}else{break}}break};case 8:{c[b+140>>2]=30;I=m+9|0;c[k+12>>2]=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24;N=4;O=13;P=32;break};case 4:case 2:{N=3;O=9;P=32;break};case 9:{c[b+140>>2]=30;P=3;break};case 3:{c[b+140>>2]=4;I=J5a(b,j,0)|0;if((I|0)<0){x=I;i=h;return x|0}if(n>>>0>9>>>0&s>>>0<n>>>0&t>>>0<n>>>0){I=b+120|0;H=b+124|0;EOa(o,c[e>>2]|0,c[I>>2]|0,c[H>>2]|0,c[e+32>>2]|0,m+9|0,n-9|0);EOa(o,c[e+4>>2]|0,(c[I>>2]|0)/2|0,c[H>>2]|0,c[e+36>>2]|0,m+s|0,n-s|0);EOa(o,c[e+8>>2]|0,(c[I>>2]|0)/2|0,c[H>>2]|0,c[e+40>>2]|0,m+t|0,n-t|0);break a}KIb(b,16,2361928,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;x=-1094995529;i=h;return x|0};case 10:{c[b+140>>2]=0;H=J5a(b,j,0)|0;if((H|0)<0){x=H;i=h;return x|0}if(n>>>0>9>>>0&n>>>0>s>>>0&n>>>0>t>>>0){H=b+120|0;I=b+124|0;EOa(o,c[e>>2]|0,c[H>>2]|0,c[I>>2]|0,c[e+32>>2]|0,m+9|0,n-9|0);EOa(o,c[e+8>>2]|0,(c[H>>2]|0)/2|0,(c[I>>2]|0)/2|0,c[e+40>>2]|0,m+s|0,n-s|0);EOa(o,c[e+4>>2]|0,(c[H>>2]|0)/2|0,(c[I>>2]|0)/2|0,c[e+36>>2]|0,m+t|0,n-t|0);break a}else{x=-1094995529;i=h;return x|0}break};case 5:{P=3;break};default:{KIb(b,16,2297304,(Q=i,i=i+8|0,c[Q>>2]=r,Q)|0);i=Q;x=-1163346256;i=h;return x|0}}}while(0);b:do{if((P|0)==3){do{if(p<<24>>24==5){r=b+140|0;if((c[b+792>>2]|0)==24){c[r>>2]=2;R=3;break}else{c[r>>2]=298;R=4;break}}else{R=3}}while(0);r=J5a(b,j,0)|0;if((r|0)<0){x=r;i=h;return x|0}r=c[e>>2]|0;M=b+124|0;L=c[M>>2]|0;K=(L|0)>0;if(!(p<<24>>24==9)){if(!K){break}w=b+120|0;I=e+32|0;H=r;G=0;while(1){mrc(H|0,a[q]|0,ca(c[w>>2]|0,R)|0)|0;B=G+1|0;if((B|0)<(c[M>>2]|0)){H=H+(c[I>>2]|0)|0;G=B}else{break b}}}if(!K){break}G=b+120|0;I=e+32|0;H=r;w=0;B=c[G>>2]|0;F=L;while(1){if((B|0)>0){v=0;do{A=H+(v<<2)|0;y=s;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;v=v+1|0;S=c[G>>2]|0;}while((v|0)<(S|0));T=S;U=c[M>>2]|0}else{T=B;U=F}v=w+1|0;if((v|0)<(U|0)){H=H+(c[I>>2]|0)|0;w=v;B=T;F=U}else{break}}}else if((P|0)==32){if((p<<24>>24|0)==4|(p<<24>>24|0)==2){c[b+140>>2]=2}F=J5a(b,j,0)|0;if((F|0)<0){x=F;i=h;return x|0}c[k>>2]=t;c[k+4>>2]=s;c[k+8>>2]=O;F=b+120|0;B=(c[F>>2]|0)+15&-16;w=g+1264|0;c[w>>2]=B;I=g+1256|0;H=I;M=b+124|0;xJb(I,g+1260|0,ca(ca(c[M>>2]|0,N)|0,B)|0|1);B=c[H>>2]|0;if((B|0)==0){KIb(b,16,2451176,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;x=-12;i=h;return x|0}I=c[w>>2]|0;G=c[M>>2]|0;L=0;while(1){r=L+1|0;c[l+(L<<2)>>2]=B+((ca(ca(I,r)|0,G)|0)-I);if((r|0)<(N|0)){L=r}else{V=0;break}}while(1){if((V|0)>=(N|0)){W=0;X=G;Y=I;Z=t;break}if(n>>>0>(c[k+(V<<2)>>2]|0)>>>0){V=V+1|0}else{P=41;break}}if((P|0)==41){KIb(b,16,2361928,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;x=-1094995529;i=h;return x|0}while(1){EOa(o,c[l+(W<<2)>>2]|0,c[F>>2]|0,X,-Y|0,m+Z|0,n-Z|0);I=W+1|0;if((I|0)>=(N|0)){break}W=I;X=c[M>>2]|0;Y=c[w>>2]|0;Z=c[k+(I<<2)>>2]|0}I=c[e>>2]|0;G=c[H>>2]|0;L=c[w>>2]|0;B=c[M>>2]|0;r=0;do{c[l+(r<<2)>>2]=G+(ca(ca(L,r)|0,B)|0);r=r+1|0;}while((r|0)<(N|0));if((B|0)<=0){break}r=l|0;G=l+4|0;H=l+8|0;K=p<<24>>24==8;v=l+12|0;A=e+32|0;E=I;D=0;C=c[F>>2]|0;u=L;while(1){if((C|0)>0){if(K){z=0;while(1){J=a[(c[G>>2]|0)+z|0]|0;_=E+(z<<2)|0;y=(J+(a[(c[r>>2]|0)+z|0]|0)&255)<<16|(J&255)<<8|(a[(c[H>>2]|0)+z|0]|0)+J&255|(d[(c[v>>2]|0)+z|0]|0)<<24;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;_=c[F>>2]|0;J=z+1|0;if((J|0)<(_|0)){z=J}else{$=_;break}}}else{z=0;while(1){_=a[(c[G>>2]|0)+z|0]|0;J=(a[(c[H>>2]|0)+z|0]|0)+_&255;aa=z*3|0;a[E+aa|0]=_+(a[(c[r>>2]|0)+z|0]|0);a[E+(aa+1)|0]=_;a[E+(aa+2)|0]=J;J=c[F>>2]|0;aa=z+1|0;if((aa|0)<(J|0)){z=aa}else{$=J;break}}}ba=$;da=c[w>>2]|0}else{ba=C;da=u}z=c[A>>2]|0;J=0;do{aa=l+(J<<2)|0;c[aa>>2]=(c[aa>>2]|0)+da;J=J+1|0;}while((J|0)<(N|0));J=D+1|0;if((J|0)<(c[M>>2]|0)){E=E+z|0;D=J;C=ba;u=da}else{break}}}}while(0);c[f>>2]=1;x=n;i=h;return x|0}function DOa(a){a=a|0;mJb((c[a+60>>2]|0)+1256|0);return 0}function EOa(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;l=i;m=-h|0;n=i;i=i+4|0;i=i+7&-8;o=i;i=i+4|0;i=i+7&-8;p=i;i=i+4|0;i=i+7&-8;q=i;i=i+20|0;i=i+7&-8;r=i;i=i+1320|0;s=j+k|0;t=b|0;u=c[t>>2]|0;v=r|0;c[v>>2]=u;w=b+1248|0;c[w>>2]=0;if((k|0)<2){i=l;return}x=a[j]|0;y=x&255;a:do{if((x&255)>>>0<4>>>0){z=ca(g,f)|0;if((k|0)<5){i=l;return}A=x<<24>>24==0;if(A){B=1;C=z}else{D=j+1|0;E=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=E>>>0<z>>>0;B=D?5:1;C=D?E:z}z=j+B|0;E=k-B|0;D=E>>>0>268435455>>>0?-8:E<<3;E=D>>>0>2147483639>>>0|(z|0)==0;F=E?0:z;z=E?0:D;c[q>>2]=F;c[q+12>>2]=z;c[q+16>>2]=z+8;c[q+4>>2]=F+(z>>3);c[q+8>>2]=0;if(E){i=l;return}E=r+32|0;c[E>>2]=0;c[r+1060>>2]=-1;z=1;F=0;b:while(1){D=r+32+(z<<2)|0;if((GOa(q,D)|0)<0){H=9;break}I=c[D>>2]|0;D=wrc(I,0,F,0)|0;J=G;K=0;if(J>>>0>K>>>0|J>>>0==K>>>0&D>>>0>-1>>>0){H=11;break}L=I+F|0;do{if((I|0)==0){if((GOa(q,n)|0)!=0){H=14;break b}D=c[n>>2]|0;K=256-z|0;if(D>>>0>K>>>0){c[n>>2]=K;M=K}else{M=D}if((M|0)==0){N=z;break}D=M>>>0>1>>>0?M:1;mrc(r+32+(z+1<<2)|0,0,D<<2|0)|0;N=D+z|0}else{N=z}}while(0);I=N+1|0;if((I|0)<257){z=I;F=L}else{H=20;break}}if((H|0)==9){KIb(c[v>>2]|0,16,2121488,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else if((H|0)==11){KIb(c[v>>2]|0,16,2638944,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else if((H|0)==14){KIb(c[v>>2]|0,16,2616416,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else if((H|0)==20){if((L|0)==0){KIb(c[v>>2]|0,16,2589152,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}F=L>>>0>65535>>>0;z=F?L>>>16:L;I=F?16:0;if((z&65280|0)==0){P=I;Q=z}else{P=I|8;Q=z>>>8}z=(d[1359664+Q|0]|0)+P|0;I=L-1|0;do{if((I&L|0)==0){R=z}else{F=I>>>0>65535>>>0;D=F?I>>>16:I;K=F?16:0;if((D&65280|0)==0){S=K;T=D}else{S=K|8;T=D>>>8}D=S+1+(d[1359664+T|0]|0)|0;K=L;F=0;J=Frc(0,1048576,K,F)|0;U=G;V=Erc(J,U,K,F)|0;W=xrc(0,1048576,V,G)|0;V=G;X=D;D=yrc(J|0,U|0,X|0)|0;U=G;J=yrc(W|0,V|0,X|0)|0;X=wrc(J,G,L>>>1,0)|0;J=Frc(X,G,K,F)|0;F=wrc(D,U,J,G)|0;J=G;U=F|0;F=J&0;D=J;J=0;K=1;X=0;do{V=r+32+(K<<2)|0;W=c[V>>2]|0;Y=0;Z=Erc(W,Y,U,F)|0;_=G;$=Erc(W,Y,D,J)|0;Y=wrc(_,0,$,G)|0;$=G;W=Y>>>21|$<<11;aa=W>>>0>65535>>>0;ba=aa?($>>>5|0<<27)&65535:W;W=aa?16:0;if((ba&65280|0)==0){da=W;ea=ba}else{da=W|8;ea=ba>>>8}ba=1<<(d[1359664+ea|0]|0)+da;wrc(ba,(ba|0)<0|0?-1:0,Z|0,_&0)|0;_=wrc(G,0,Y,$)|0;$=_>>>20|G<<12;c[V>>2]=$;X=$+X|0;K=K+1|0;}while((K|0)<129);if((X|0)==0){KIb(c[v>>2]|0,16,2567664,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else{fa=129;ga=X}do{K=r+32+(fa<<2)|0;$=c[K>>2]|0;V=0;_=Erc($,V,U,F)|0;Y=G;Z=Erc($,V,D,J)|0;V=wrc(Y,0,Z,G)|0;Z=G;$=V>>>21|Z<<11;ba=$>>>0>65535>>>0;W=ba?(Z>>>5|0<<27)&65535:$;$=ba?16:0;if((W&65280|0)==0){ha=$;ia=W}else{ha=$|8;ia=W>>>8}W=1<<(d[1359664+ia|0]|0)+ha;wrc(W,(W|0)<0|0?-1:0,_|0,Y&0)|0;Y=wrc(G,0,V,Z)|0;Z=Y>>>20|G<<12;c[K>>2]=Z;ga=Z+ga|0;fa=fa+1|0;}while((fa|0)<257);J=z+1|0;D=1<<J;if(ga>>>0>D>>>0){KIb(c[v>>2]|0,16,2549480,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}if((D|0)==(ga|0)){R=J;break}F=1;U=D-ga|0;while(1){D=r+32+(F<<2)|0;X=c[D>>2]|0;if((X|0)==0){ja=U}else{c[D>>2]=X+1;ja=U-1|0}if((ja|0)==0){R=J;break}else{F=(F&127)+1|0;U=ja}}}}while(0);c[r+12>>2]=R;z=1;I=c[E>>2]|0;do{U=r+32+(z<<2)|0;I=(c[U>>2]|0)+I|0;c[U>>2]=I;z=z+1|0;}while((z|0)<257);HOa(r,q,C-h|0);if((g|0)<=0){break}z=A?-1:y;I=b+1252|0;E=0;U=0;do{F=ca(E,h)|0;J=0;X=0;D=c[I>>2]|0;c:while(1){if((D|0)==0){ka=J}else{Z=f-J|0;K=(D|0)>(Z|0)?Z:D;mrc(e+(J+F)|0,0,K|0)|0;c[I>>2]=(c[I>>2]|0)-K;ka=K+J|0}if((ka|0)<(f|0)){la=X;ma=ka}else{na=X;break}while(1){K=FOa(r)|0;a[e+(ma+F)|0]=K;Z=la+1|0;if(K<<24>>24==0){K=(c[w>>2]|0)+1|0;c[w>>2]=K;oa=ma+1|0;if((K|0)==(z|0)){break}else{pa=oa}}else{c[w>>2]=0;pa=ma+1|0}if((pa|0)<(f|0)){la=Z;ma=pa}else{na=Z;break c}}Z=FOa(r)|0;c[w>>2]=0;K=Z<<24>>24;Z=(K<<1^K>>>7)&255;c[I>>2]=Z;J=oa;X=la+2|0;D=Z}U=na+U|0;E=E+1|0;}while((E|0)<(g|0));if(!(U>>>0>C>>>0)){break}KIb(c[t>>2]|0,24,2246512,(O=i,i=i+16|0,c[O>>2]=U,c[O+8>>2]=C,O)|0);i=O;break}}else{if(!((x&255)>>>0<8>>>0)){if(!(x<<24>>24==-1)){KIb(u,16,2204832,(O=i,i=i+8|0,c[O>>2]=y,O)|0);i=O;i=l;return}if((g|0)<=0){i=l;return}E=j+1|0;I=0;do{z=e+(ca(I,h)|0)|0;mrc(z|0,a[E]|0,f|0)|0;I=I+1|0;}while((I|0)<(g|0));i=l;return}I=y-4|0;E=j+1|0;if((I|0)<=0){if((k-1|0)<(ca(g,f)|0)){i=l;return}if((g|0)>0){qa=0;ra=E}else{break}while(1){nrc(e+(ca(qa,h)|0)|0,ra|0,f)|0;U=qa+1|0;if((U|0)<(g|0)){qa=U;ra=ra+f|0}else{break a}}}if((g|0)<=0){break}U=-((I|0)<2|0)&255;z=-((I|0)<3|0)&255;A=f-2|0;D=b+1252|0;X=s;J=0;F=E;Z=u;d:while(1){K=ca(J,h)|0;Y=e+K|0;V=e+(A+K)|0;QIb(Z,2172704,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;mrc(Y|0,0,f|0)|0;K=V;_=Y;Y=F;W=0;$=c[D>>2]|0;e:while(1){if(($|0)==0){sa=_}else{ba=f-W|0;aa=($|0)>(ba|0)?ba:$;if((K-_|0)<(aa|0)){H=66;break d}mrc(_|0,0,aa|0)|0;c[D>>2]=(c[D>>2]|0)-aa;sa=_+aa|0}if(!(sa>>>0<V>>>0)){ta=Y;break}aa=X-Y|0;ua=0;while(1){if(!((sa+ua|0)>>>0<V>>>0)){H=74;break e}va=ua+1|0;ba=ua+3|0;if((ba|0)>=(aa|0)){H=124;break d}if((a[Y+(ua+2)|0]&U|a[Y+va|0]|a[Y+ba|0]&z)<<24>>24==0){break}else{ua=va}}aa=va+I|0;nrc(sa|0,Y|0,aa)|0;ba=a[Y+aa|0]|0;wa=(ba<<1^ba>>>7)&255;c[D>>2]=wa;_=sa+aa|0;Y=Y+(aa+1)|0;W=aa;$=wa}if((H|0)==74){H=0;nrc(sa|0,Y|0,ua)|0;ta=Y+ua|0}$=ta-F|0;if(($|0)<0){H=124;break}W=J+1|0;if((W|0)>=(g|0)){break a}J=W;F=F+$|0;Z=c[t>>2]|0}if((H|0)==66){KIb(c[t>>2]|0,16,2145272,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;i=l;return}else if((H|0)==124){i=l;return}}}while(0);H=c[t>>2]|0;O=(g|0)>0;if((c[H+140>>2]|0)==4){if(!O){i=l;return}ta=f-1|0;ua=ta-(h<<1)|0;sa=ta-h|0;ta=b+1088|0;va=b+1092|0;u=~h;s=0;ra=e;qa=H;while(1){H=(c[qa+120>>2]|0)==(f|0);do{if((s|0)==1){k=H?4:2;j=d[ra+sa|0]|0;c[o>>2]=j;y=d[ra+(k+u)|0]|0;c[p>>2]=y;x=0;C=j;do{j=ra+x|0;C=(d[j]|0)+C|0;a[j]=C;x=x+1|0;}while((x|0)<(k|0));c[o>>2]=C;if((k|0)<(f|0)){xa=k;ya=C;za=y}else{break}while(1){x=ya&255;Aa=d[ra+(xa-h)|0]|0;Y=ya-za+Aa&255;do{if(x>>>0>Aa>>>0){if(!(Y>>>0>Aa>>>0)){Ba=Aa;break}Ba=Y>>>0>x>>>0?x:Y}else{if(!(Aa>>>0>Y>>>0)){Ba=Aa;break}Ba=Y>>>0>x>>>0?Y:x}}while(0);x=ra+xa|0;Ca=(d[x]|0)+Ba|0;a[x]=Ca;x=xa+1|0;if((x|0)<(f|0)){xa=x;ya=Ca;za=Aa}else{break}}c[o>>2]=Ca;c[p>>2]=Aa}else if((s|0)==0){c[o>>2]=d[ra]|0;if(H){a[ra]=0;hf[c[va>>2]&1023](ra,ra,f,0)|0;a[ra]=c[o>>2];break}else{hf[c[va>>2]&1023](ra,ra,f,0)|0;break}}else{c[p>>2]=d[ra+ua|0]|0;c[o>>2]=d[ra+sa|0]|0;_e[c[ta>>2]&511](ra,ra+m|0,ra,f,o,p)}}while(0);H=s+1|0;if((H|0)>=(g|0)){break}s=H;ra=ra+h|0;qa=c[t>>2]|0}i=l;return}else{if(!O){i=l;return}O=b+1092|0;b=f-1|0;qa=b-h|0;ra=b-(h<<1)|0;if((f|0)>0){Da=0;Ea=e}else{b=0;s=e;while(1){if((b|0)==0){hf[c[O>>2]&1023](s,s,f,0)|0}e=b+1|0;if((e|0)<(g|0)){b=e;s=s+h|0}else{break}}i=l;return}while(1){if((Da|0)==0){hf[c[O>>2]&1023](Ea,Ea,f,0)|0}else{s=a[Ea+qa|0]|0;b=s&255;do{if((Da|0)==1){if((c[(c[t>>2]|0)+140>>2]|0)!=0){Fa=0;Ga=s;Ha=s;Ia=b;break}Fa=0;Ga=s;Ha=a[Ea+m|0]|0;Ia=b}else{Fa=0;Ga=s;Ha=a[Ea+ra|0]|0;Ia=b}}while(0);while(1){b=a[Ea+(Fa-h)|0]|0;s=b&255;e=s+(Ia-(Ha&255))|0;do{if((Ga&255)>>>0>(b&255)>>>0){if((e|0)<=(s|0)){Ja=s;break}Ja=(e|0)>(Ia|0)?Ia:e}else{if((s|0)<=(e|0)){Ja=s;break}Ja=(e|0)>(Ia|0)?e:Ia}}while(0);e=Ea+Fa|0;s=(d[e]|0)+Ja|0;p=s&255;a[e]=p;e=Fa+1|0;if((e|0)<(f|0)){Fa=e;Ga=p;Ha=b;Ia=s&255}else{break}}}s=Da+1|0;if((s|0)<(g|0)){Da=s;Ea=Ea+h|0}else{break}}i=l;return}}function FOa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=a+8|0;e=c[b>>2]|0;f=a+4|0;if(e>>>0<8388609>>>0){g=a+24|0;h=c[a+28>>2]|0;i=c[f>>2]|0;j=e;k=c[g>>2]|0;while(1){l=i<<8;c[f>>2]=l;m=j<<8;c[b>>2]=m;n=k;o=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)>>>1&255|l;c[f>>2]=o;if(k>>>0<h>>>0){l=k+1|0;c[g>>2]=l;p=l}else{p=k}if(m>>>0<8388609>>>0){i=o;j=m;k=p}else{q=m;r=o;break}}}else{q=e;r=c[f>>2]|0}f=q>>>((c[a+12>>2]|0)>>>0);e=a+4|0;p=ca(c[a+1052>>2]|0,f)|0;if(!(r>>>0<p>>>0)){s=255;t=q-p|0;u=(t|0)==0;v=u?128:t;c[b>>2]=v;w=a+32+(s<<2)|0;x=c[w>>2]|0;y=ca(x,f)|0;z=r-y|0;c[e>>2]=z;A=s&255;return A|0}p=c[a+36>>2]|0;if(r>>>0<(ca(p,f)|0)>>>0){B=0;C=p}else{p=f>>>0>65535>>>0;q=p?f>>>16:f;k=p?16:0;if((q&65280|0)==0){D=k;E=q}else{D=k|8;E=q>>>8}q=30-D-(d[1359664+E|0]|0)|0;E=xrc(r,0,r>>>24,0)|0;Erc(c[1367848+(((f<<(q&255))+8388607|0)>>>23<<2)>>2]|0,0,E,G)|0;E=G;D=q-(c[a+16>>2]|0)&31;q=d[((E<<D|E>>>((32-D|0)>>>0))&255)+(a+1064)|0]|0;while(1){D=q+1|0;E=c[a+32+(D<<2)>>2]|0;if(r>>>0<(ca(E,f)|0)>>>0){B=q;C=E;break}else{q=D}}}s=B;t=ca(C-(c[a+32+(B<<2)>>2]|0)|0,f)|0;u=(t|0)==0;v=u?128:t;c[b>>2]=v;w=a+32+(s<<2)|0;x=c[w>>2]|0;y=ca(x,f)|0;z=r-y|0;c[e>>2]=z;A=s&255;return A|0}function GOa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+8|0;f=a|0;g=a+16|0;a=0;h=0;i=0;j=0;while(1){k=(h|0)==0;if(!((j|0)==0|k)){l=i;break}m=c[e>>2]|0;n=(d[(c[f>>2]|0)+(m>>>3)|0]|0)<<(m&7)>>>7;c[e>>2]=((m|0)<(c[g>>2]|0))+m;m=n&1;if((m|0)!=0&k){o=(d[1017152+a|0]|0)+i|0}else{o=i}k=a+1|0;if((k|0)<7){a=k;j=h;h=m;i=o}else{l=o;break}}o=l-1|0;if(o>>>0>31>>>0){c[b>>2]=0;p=-1;return p|0}if((o|0)==0){c[b>>2]=0;p=0;return p|0}i=c[e>>2]|0;h=c[g>>2]|0;g=c[f>>2]|0;f=g+(i>>>3)|0;j=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(i&7);if((o|0)<26){f=i+o|0;c[e>>2]=h>>>0>f>>>0?f:h;q=j>>>((33-l|0)>>>0)}else{f=i+16|0;i=h>>>0>f>>>0?f:h;c[e>>2]=i;f=l-17|0;a=g+(i>>>3)|0;g=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>((49-l|0)>>>0);l=i+f|0;c[e>>2]=h>>>0>l>>>0?l:h;q=g|j>>>16<<f}c[b>>2]=(q|1<<o)-1;p=0;return p|0}function HOa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;f=e+8|0;g=c[f>>2]|0;h=-g&7;if((h|0)==0){i=g}else{j=c[e+16>>2]|0;k=h+g|0;g=j>>>0>k>>>0?k:j;c[f>>2]=g;i=g}g=(c[e+12>>2]|0)-i>>3;f=c[e>>2]|0;e=(i|0)/8|0;i=f+e|0;c[b+24>>2]=i;c[b+20>>2]=i;c[b+28>>2]=f+(e+g);c[b+8>>2]=128;c[b+4>>2]=(d[i]|0)>>>1;i=(c[b+12>>2]|0)-8|0;g=(i|0)>0?i:0;i=b+16|0;c[i>>2]=g;e=0;f=0;j=g;while(1){g=f<<j;k=e;while(1){h=k+1|0;if((c[b+32+(h<<2)>>2]|0)>>>0>g>>>0){break}else{k=h}}a[b+1064+f|0]=k;g=f+1|0;l=c[i>>2]|0;if((g|0)<256){e=k;f=g;j=l}else{break}}c[i>>2]=l+23;return}function IOa(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+16|0;j=b|0;k=b+8|0;c[j>>2]=g;c[k>>2]=h;do{if((c[a+176>>2]&1|0)==0){l=c[a>>2]|0;m=l;n=l+20|0;o=c[n>>2]|0;p=l+16|0;q=c[p>>2]|0;do{if((o|0)==0){r=q;s=0;while(1){if((s|0)>=(h|0)){t=6;break}u=r<<8;v=d[g+s|0]|0|u;if((u&16769024|0)==5693440){t=5;break}else{r=v;s=s+1|0}}if((t|0)==5){c[l+40>>2]=~s;w=1;x=v;t=7;break}else if((t|0)==6){y=0;z=r;A=c[l+40>>2]|0;t=10;break}}else{w=o;x=q;t=7}}while(0);do{if((t|0)==7){if((h|0)==0){B=0;break}q=c[l+40>>2]|0;o=(x&8191)-q|0;if(o>>>0>h>>>0){y=w;z=x;A=q;t=10;break}c[n>>2]=0;c[p>>2]=-1;B=o}}while(0);if((t|0)==10){c[l+40>>2]=A+h;c[n>>2]=y;c[p>>2]=z;B=-100}if((IWa(m,B,j,k)|0)>=0){C=B;D=c[j>>2]|0;E=c[k>>2]|0;break}c[e>>2]=0;c[f>>2]=0;F=c[k>>2]|0;i=b;return F|0}else{C=h;D=g;E=h}}while(0);c[e>>2]=D;c[f>>2]=E;F=C;i=b;return F|0}function JOa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=c[b+60>>2]|0;j=b+120|0;k=c[j>>2]|0;l=b+124|0;m=c[l>>2]|0;n=ca(m,k)|0;o=ca(m+3&-4,k+3&-4)|0;if((c[b+100>>2]|0)<8){KIb(b,16,2531464,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}k=b+48|0;m=c[k>>2]|0;if((m|0)==55){if((a[(c[b+96>>2]|0)+7|0]|0)!=3){r=6}}else if((m|0)==54){if((a[(c[b+96>>2]|0)+7|0]|0)!=1){r=6}}if((r|0)==6){KIb(b,16,2516240,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}r=b+96|0;m=d[(c[r>>2]|0)+4|0]|0;c[h>>2]=m;a:do{switch(m|0){case 3:{c[h+12>>2]=(n>>>1)*3|0;c[b+140>>2]=7;KIb(b,48,2459408,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=(o>>>1)*3|0;break};case 0:{c[h+12>>2]=n*3|0;c[b+140>>2]=5;KIb(b,48,2502320,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=o*3|0;break};case 1:{c[h+12>>2]=n<<1;c[b+140>>2]=4;t=b;KIb(t,48,2489256,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;if((c[j>>2]&3|0)==0){s=o<<1;break a}QIb(t,2478256,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0};case 5:{c[h+12>>2]=(n>>>1)*3|0;c[b+140>>2]=0;KIb(b,48,2430512,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=(o>>>1)*3|0;break};case 4:{c[h+12>>2]=n<<1;c[b+140>>2]=4;KIb(b,48,2442664,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=o<<1;break};case 2:{c[h+12>>2]=n*3|0;c[b+140>>2]=3;KIb(b,48,2468664,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;s=o*3|0;break};default:{KIb(b,16,2420256,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;q=-1094995529;i=e;return q|0}}}while(0);tKb(c[b+140>>2]|0,f,g)|0;do{if(((c[j>>2]|0)%(1<<c[f>>2]|0)|0|0)==0){if(((c[l>>2]|0)%(1<<c[g>>2]|0)|0|0)!=0){break}m=a[(c[r>>2]|0)+5|0]|0;o=m<<24>>24;c[h+4>>2]=o;n=c[k>>2]|0;do{if((n|0)==55){if((o|0)==1){KIb(b,48,2389376,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else if((o|0)==(-1|0)){KIb(b,48,2375824,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else if((o|0)==9){KIb(b,48,2382464,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else{t=b;if(!((m&255)>>>0>9>>>0)){KIb(t,48,2354384,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;break}KIb(t,16,2369136,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=-1094995529;i=e;return q|0}}else if((n|0)==54){if((o|0)==1){c[h+12>>2]=0;KIb(b,48,2403232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else if((o|0)==0){KIb(b,48,2410904,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else{KIb(b,16,2396296,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=-1094995529;i=e;return q|0}}else{KIb(b,16,2345544,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}}while(0);do{if((c[h+12>>2]|0)!=0){o=hJb(s)|0;c[h+16>>2]=o;if((o|0)!=0){break}KIb(b,16,2339520,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-12;i=e;return q|0}}while(0);o=d[(c[r>>2]|0)+6|0]|0;n=h+8|0;c[n>>2]=o;if((o&1|0)==0){u=o}else{KIb(b,48,2333792,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=c[n>>2]|0}if((u&2|0)!=0){KIb(b,48,2328368,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}do{if((c[k>>2]|0)==55){if((c[n>>2]&4|0)==0){break}KIb(b,48,2322648,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);o=c[n>>2]|0;if((o&248|0)!=0){KIb(b,16,2317616,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p}if((c[k>>2]|0)!=55){q=0;i=e;return q|0}c[h+52>>2]=0;c[h+56>>2]=0;c[h+60>>2]=0;o=_pc(h+20|0,2312960,56)|0;if((o|0)==0){q=0;i=e;return q|0}KIb(b,16,2308328,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;mJb(h+16|0);q=-1313558101;i=e;return q|0}}while(0);QIb(b,2478256,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}function KOa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=c[b+120>>2]|0;m=c[b+124>>2]|0;n=M4a(b,e,0)|0;if((n|0)<0){o=n;i=h;return o|0}n=e;p=c[n>>2]|0;q=b+48|0;r=c[q>>2]|0;a:do{if((r|0)==54){s=c[g+4>>2]|0;if((s|0)==0){if((c[g>>2]|0)==2){if((k|0)==(ca(l*3|0,m)|0)){t=j;break}}if((c[g+8>>2]&1|0)==0){u=g+16|0;v=g+12|0;w=MOa(j,k,c[u>>2]|0,c[v>>2]|0)|0;x=c[v>>2]|0;if((x|0)==(w|0)){t=c[u>>2]|0;break}KIb(b,16,2172664,(z=i,i=i+16|0,c[z>>2]=x,c[z+8>>2]=w,z)|0);i=z;o=-1094995529;i=h;return o|0}w=j;x=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;if(k>>>0<8>>>0){KIb(b,16,2297280,(z=i,i=i+8|0,c[z>>2]=k,z)|0);i=z;o=-1094995529;i=h;return o|0}w=k-8|0;u=x>>>0>w>>>0?w:x;x=j+4|0;v=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=g+12|0;A=c[x>>2]|0;B=v>>>0>A>>>0?A:v;v=g+16|0;C=MOa(j+8|0,u,c[v>>2]|0,A)|0;if((B|0)!=(C|0)){KIb(b,16,2246432,(z=i,i=i+16|0,c[z>>2]=B,c[z+8>>2]=C,z)|0);i=z;o=-1094995529;i=h;return o|0}C=MOa(j+(u+8)|0,w-u|0,(c[v>>2]|0)+B|0,(c[x>>2]|0)-B|0)|0;if((B|0)==(C|0)){t=c[v>>2]|0;break}KIb(b,16,2204784,(z=i,i=i+16|0,c[z>>2]=B,c[z+8>>2]=C,z)|0);i=z;o=-1094995529;i=h;return o|0}else if((s|0)==1){switch(c[g>>2]|0){case 3:case 5:{D=3;break};case 0:case 2:{D=6;break};case 1:case 4:{D=4;break};default:{D=0}}if(k>>>0<(ca(ca(m,l)|0,D)|0)>>>1>>>0){o=-1094995529}else{t=j;break}i=h;return o|0}else{KIb(b,16,2145216,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=h;return o|0}}else if((r|0)==55){do{if((c[g+4>>2]|0)==-1){if((c[g>>2]|0)!=2){E=28;break}if((k|0)!=(ca(l*3|0,m)|0)){E=28;break}if((c[g+8>>2]&4|0)==0){t=j;break a}nrc(c[g+16>>2]|0,j|0,k)|0}else{E=28}}while(0);do{if((E|0)==28){if((c[g+8>>2]&1|0)==0){s=NOa(b,j,k,0,c[g+12>>2]|0)|0;if((s|0)<0){o=s}else{break}i=h;return o|0}s=j;C=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k-8|0;B=C>>>0>s>>>0?s:C;C=j+4|0;v=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=c[g+12>>2]|0;x=v>>>0>C>>>0?C:v;v=NOa(b,j+8|0,B,0,x)|0;if((v|0)<0){o=v;i=h;return o|0}v=NOa(b,j+(B+8)|0,s-B|0,x,x)|0;if((v|0)<0){o=v}else{break}i=h;return o|0}}while(0);t=c[g+16>>2]|0}else{KIb(b,16,2121424,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=h;return o|0}}while(0);b:do{if((c[q>>2]|0)==55){if((c[g+8>>2]&4|0)==0){break}switch(c[g>>2]|0){case 3:{if((m|0)==0){break b}j=l>>>2;E=(j|0)==0;r=0;do{if(!E){D=0;v=((ca(r,l)|0)>>>1)*3|0;x=0;B=0;s=0;while(1){C=t+v|0;u=x-(a[C]|0)&255;a[C]=u;C=t+(v+1)|0;w=u-(a[C]|0)&255;a[C]=w;C=t+(v+2)|0;u=w-(a[C]|0)&255;a[C]=u;C=t+(v+3)|0;w=u-(a[C]|0)&255;a[C]=w;C=t+(v+4)|0;u=B-(a[C]|0)&255;a[C]=u;C=t+(v+5)|0;A=s-(a[C]|0)&255;a[C]=A;C=D+1|0;if(C>>>0<j>>>0){D=C;v=v+6|0;x=w;B=u;s=A}else{break}}}r=r+1|0;}while(r>>>0<m>>>0);break};case 1:{if((m|0)==0){break b}r=l<<1;j=l>>>2;E=(j|0)==0;s=0;do{if(!E){B=0;x=ca(r,s)|0;v=0;D=0;A=0;while(1){u=t+x|0;w=v-(a[u]|0)&255;a[u]=w;u=t+(x|1)|0;C=w-(a[u]|0)&255;a[u]=C;u=t+(x+2)|0;w=C-(a[u]|0)&255;a[u]=w;u=t+(x+3)|0;C=w-(a[u]|0)&255;a[u]=C;u=t+(x+4)|0;w=D-(a[u]|0)&255;a[u]=w;u=t+(x+5)|0;F=w-(a[u]|0)&255;a[u]=F;u=t+(x+6)|0;w=A-(a[u]|0)&255;a[u]=w;u=t+(x+7)|0;G=w-(a[u]|0)&255;a[u]=G;u=B+1|0;if(u>>>0<j>>>0){B=u;x=x+8|0;v=C;D=F;A=G}else{break}}}s=s+1|0;}while(s>>>0<m>>>0);break};case 5:{s=m>>>1;if((s|0)==0){break b}j=l*3|0;r=l>>>1;E=(r|0)==0;A=0;do{if(!E){D=0;v=ca(j,A)|0;x=0;B=0;G=0;F=0;while(1){C=t+v|0;u=x-(a[C]|0)&255;a[C]=u;C=t+(v+1)|0;w=u-(a[C]|0)&255;a[C]=w;C=t+(v+2)|0;u=B-(a[C]|0)&255;a[C]=u;C=t+(v+3)|0;H=u-(a[C]|0)&255;a[C]=H;C=t+(v+4)|0;u=G-(a[C]|0)&255;a[C]=u;C=t+(v+5)|0;I=F-(a[C]|0)&255;a[C]=I;C=D+1|0;if(C>>>0<r>>>0){D=C;v=v+6|0;x=w;B=H;G=u;F=I}else{break}}}A=A+1|0;}while(A>>>0<s>>>0);break};case 0:case 2:{if((m|0)==0){break b}s=l*3|0;A=l>>>0>1>>>0;r=0;do{j=ca(s,r)|0;if(A){E=t+(j+1)|0;F=1;G=a[t+j|0]|0;B=(d[E]|d[E+1|0]<<8)<<16>>16&65535;E=j;while(1){j=E+3|0;x=t+j|0;v=G-(a[x]|0)&255;a[x]=v;x=t+(E+4)|0;D=B-((d[x]|d[x+1|0]<<8)<<16>>16&65535)|0;y=D&65535;a[x]=y;y=y>>8;a[x+1|0]=y;x=F+1|0;if(x>>>0<l>>>0){F=x;G=v;B=D;E=j}else{break}}}r=r+1|0;}while(r>>>0<m>>>0);break};case 4:{if((m|0)==0){break b}r=l<<1;A=l>>>1;s=(A|0)==0;E=0;do{if(!s){B=0;G=ca(r,E)|0;F=0;j=0;D=0;while(1){v=t+G|0;x=F-(a[v]|0)&255;a[v]=x;v=t+(G|1)|0;I=x-(a[v]|0)&255;a[v]=I;v=t+(G+2)|0;x=j-(a[v]|0)&255;a[v]=x;v=t+(G+3)|0;u=D-(a[v]|0)&255;a[v]=u;v=B+1|0;if(v>>>0<A>>>0){B=v;G=G+4|0;F=I;j=x;D=u}else{break}}}E=E+1|0;}while(E>>>0<m>>>0);break};default:{KIb(b,16,2638896,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=h;return o|0}}}}while(0);q=m-1|0;E=e+32|0;A=c[E>>2]|0;r=(c[n>>2]|0)+(ca(A,q)|0)|0;n=c[e+4>>2]|0;s=e+36|0;D=c[s>>2]|0;j=n+(ca(D,q)|0)|0;F=c[e+8>>2]|0;G=e+40|0;e=c[G>>2]|0;B=F+(ca(e,q)|0)|0;c:do{switch(c[g>>2]|0){case 0:{if((m|0)==0|(l|0)==0){break c}u=l*3|0;x=0;I=r;v=j;H=B;w=t;while(1){C=0;J=w;while(1){a[I+C|0]=a[J]|0;a[v+C|0]=a[J+1|0]^-128;a[H+C|0]=a[J+2|0]^-128;K=C+1|0;if(K>>>0<l>>>0){C=K;J=J+3|0}else{break}}J=x+1|0;if(J>>>0<m>>>0){x=J;I=I+(-(c[E>>2]|0)|0)|0;v=v+(-(c[s>>2]|0)|0)|0;H=H+(-(c[G>>2]|0)|0)|0;w=w+u|0}else{break}}break};case 5:{u=(m>>>1)-1|0;if((q|0)==0){break c}w=l-1|0;H=(w|0)==0;v=0;I=r;x=n+(ca(D,u)|0)|0;J=F+(ca(e,u)|0)|0;u=t;C=A;K=D;L=e;while(1){if(H){M=u;N=C;O=K;P=L}else{Q=0;R=u;while(1){S=R;T=I+Q|0;y=(d[S]|d[S+1|0]<<8)<<16>>16;a[T]=y;y=y>>8;a[T+1|0]=y;T=R+2|0;S=I+(Q-(c[E>>2]|0))|0;y=(d[T]|d[T+1|0]<<8)<<16>>16;a[S]=y;y=y>>8;a[S+1|0]=y;S=Q>>1;a[x+S|0]=a[R+4|0]^-128;U=R+6|0;a[J+S|0]=a[R+5|0]^-128;S=Q+2|0;if(S>>>0<w>>>0){Q=S;R=U}else{break}}M=U;N=c[E>>2]|0;O=c[s>>2]|0;P=c[G>>2]|0}R=v+2|0;if(R>>>0<q>>>0){v=R;I=I+(-(N<<1)|0)|0;x=x+(-O|0)|0;J=J+(-P|0)|0;u=M;C=N;K=O;L=P}else{break}}break};case 2:{if(!((q|0)>-1)){break c}L=l*3|0;K=q;C=t;u=A;while(1){nrc(p+(ca(u,K)|0)|0,C|0,L)|0;if((K|0)<=0){break c}K=K-1|0;C=C+L|0;u=c[E>>2]|0}break};case 3:{if((m|0)==0){break c}u=l-3|0;if((u|0)==0){break c}else{V=0;W=r;X=j;Y=B;Z=t}while(1){L=0;C=Z;while(1){K=C;J=W+L|0;y=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;J=L>>2;a[X+J|0]=a[C+4|0]^-128;_=C+6|0;a[Y+J|0]=a[C+5|0]^-128;J=L+4|0;if(J>>>0<u>>>0){L=J;C=_}else{break}}C=V+1|0;if(C>>>0<m>>>0){V=C;W=W+(-(c[E>>2]|0)|0)|0;X=X+(-(c[s>>2]|0)|0)|0;Y=Y+(-(c[G>>2]|0)|0)|0;Z=_}else{break}}break};case 1:{if((m|0)==0){break c}u=l-3|0;if((u|0)==0){break c}else{$=0;aa=r;ba=j;da=B;ea=t}while(1){C=0;L=ea;while(1){J=L;K=aa+C|0;y=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;K=C>>1;a[ba+K|0]=a[L+4|0]^-128;J=K|1;a[ba+J|0]=a[L+5|0]^-128;a[da+K|0]=a[L+6|0]^-128;fa=L+8|0;a[da+J|0]=a[L+7|0]^-128;J=C+4|0;if(J>>>0<u>>>0){C=J;L=fa}else{break}}L=$+1|0;if(L>>>0<m>>>0){$=L;aa=aa+(-(c[E>>2]|0)|0)|0;ba=ba+(-(c[s>>2]|0)|0)|0;da=da+(-(c[G>>2]|0)|0)|0;ea=fa}else{break}}break};case 4:{if((m|0)==0){break c}u=l-1|0;L=(u|0)==0;C=0;J=r;K=j;x=B;I=t;v=A;w=D;H=e;while(1){if(L){ga=I;ha=v;ia=w;ja=H}else{R=0;Q=I;while(1){S=Q;T=J+R|0;y=(d[S]|d[S+1|0]<<8)<<16>>16;a[T]=y;y=y>>8;a[T+1|0]=y;T=R>>1;a[K+T|0]=a[Q+2|0]^-128;ka=Q+4|0;a[x+T|0]=a[Q+3|0]^-128;T=R+2|0;if(T>>>0<u>>>0){R=T;Q=ka}else{break}}ga=ka;ha=c[E>>2]|0;ia=c[s>>2]|0;ja=c[G>>2]|0}Q=C+1|0;if(Q>>>0<m>>>0){C=Q;J=J+(-ha|0)|0;K=K+(-ia|0)|0;x=x+(-ja|0)|0;I=ga;v=ha;w=ia;H=ja}else{break}}break};default:{KIb(b,16,2616368,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=h;return o|0}}}while(0);c[f>>2]=1;o=k;i=h;return o|0}function LOa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+16|0);if((c[a+48>>2]|0)!=55){return 0}cqc(b+20|0)|0;return 0}function MOa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=e+f|0;f=b+c|0;c=e;h=g;i=f;j=d[b]|0;k=e;e=b+1|0;a:while(1){b=128;l=k;m=e;while(1){if(!(m>>>0<f>>>0&l>>>0<g>>>0)){break a}if((b&j|0)==0){n=m;o=l;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;p=l+4|0;q=m+4|0}else{o=m;n=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=n&2047;r=l;s=r-c|0;t=o>>>0>s>>>0?s:o;o=(n>>>11<<2)+4|0;n=h-r|0;r=o>>>0>n>>>0?n:o;if((t|0)==0){mrc(l|0,0,r|0)|0}else{vJb(l,t,r)}p=l+r|0;q=m+2|0}r=b>>>1;if((r|0)==0){break}else{b=r;l=p;m=q}}m=q+1|0;b=a[q]|0;r=b&255;if(b<<24>>24==0){u=m;v=p;w=r}else{j=r;k=p;e=m;continue}while(1){if((h-v|0)<32){j=w;k=v;e=u;continue a}if((i-u|0)<32){j=w;k=v;e=u;continue a}nrc(v|0,u|0,32)|0;m=v+32|0;r=u+33|0;b=a[u+32|0]|0;t=b&255;if(b<<24>>24==0){u=r;v=m;w=t}else{j=t;k=m;e=r;continue a}}}return l-c|0}function NOa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=c[a+60>>2]|0;j=h+20|0;k=j;l=Xpc(k)|0;if((l|0)!=0){KIb(a,16,2589120,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1313558101;i=g;return n|0}c[j>>2]=b;c[h+24>>2]=d;c[h+32>>2]=(c[h+16>>2]|0)+e;c[h+36>>2]=(c[h+12>>2]|0)-e;e=$pc(k,4)|0;if(e>>>0>1>>>0){KIb(a,16,2567640,(m=i,i=i+8|0,c[m>>2]=e,m)|0);i=m;n=-1313558101;i=g;return n|0}e=c[h+40>>2]|0;if((e|0)==(f|0)){n=f;i=g;return n|0}KIb(a,16,2549440,(m=i,i=i+16|0,c[m>>2]=f,c[m+8>>2]=e,m)|0);i=m;n=-1313558101;i=g;return n|0}function OOa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=c[b+60>>2]|0;f=e;c[f>>2]=b;if((c[b+120>>2]|0)==0){KIb(0,0,2246400,(g=i,i=i+24|0,c[g>>2]=2204752,c[g+8>>2]=2172640,c[g+16>>2]=132,g)|0);i=g;Hd();return 0}if((c[b+124>>2]|0)==0){KIb(0,0,2246400,(g=i,i=i+24|0,c[g>>2]=2204752,c[g+8>>2]=2172640,c[g+16>>2]=132,g)|0);i=g;Hd();return 0}h=pJb(24)|0;j=b+96|0;c[j>>2]=h;if((h|0)==0){k=-12;i=d;return k|0}h=UHb()|0;c[b+804>>2]=h;if((h|0)==0){k=-12;i=d;return k|0}c[h+88>>2]=1;c[h+84>>2]=1;h=c[b+84>>2]|0;do{if((h|0)==-1){l=-1}else{if((h|0)<0){l=0;break}l=(h|0)>9?9:h}}while(0);h=e+8|0;c[h>>2]=l;l=e+12|0;c[l>>2]=0;m=e+4|0;c[m>>2]=2;c[b+792>>2]=24;a[c[j>>2]|0]=4;a[(c[j>>2]|0)+1|0]=0;a[(c[j>>2]|0)+2|0]=0;a[(c[j>>2]|0)+3|0]=0;a[(c[j>>2]|0)+4|0]=c[m>>2];a[(c[j>>2]|0)+5|0]=c[h>>2];a[(c[j>>2]|0)+6|0]=c[l>>2];a[(c[j>>2]|0)+7|0]=3;c[(c[f>>2]|0)+100>>2]=8;c[e+48>>2]=0;c[e+52>>2]=0;c[e+56>>2]=0;f=Gpc(e+16|0,c[h>>2]|0,2145208,56)|0;if((f|0)==0){k=0;i=d;return k|0}KIb(b,16,2121400,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;k=1;i=d;return k|0}function POa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=c[a+60>>2]|0;h=g+16|0;j=h;k=a+120|0;l=a+124|0;m=Mpc(j,ca((c[k>>2]|0)*3|0,c[l>>2]|0)|0)|0;n=d5a(a,b,m,(m|0)<0|0?-1:0)|0;if((n|0)<0){o=n;i=f;return o|0}if((c[a+140>>2]|0)!=3){KIb(a,16,2451120,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1;i=f;return o|0}n=Jpc(j)|0;if((n|0)!=0){KIb(a,16,2361856,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;o=-1;i=f;return o|0}c[g+28>>2]=c[b+24>>2];n=b+28|0;c[g+32>>2]=c[n>>2];m=d|0;q=d+32|0;d=h;h=g+20|0;r=c[l>>2]|0;while(1){l=r-1|0;if((r|0)<=0){break}c[d>>2]=(c[m>>2]|0)+(ca(c[q>>2]|0,l)|0);c[h>>2]=(c[k>>2]|0)*3|0;s=Lpc(j,0)|0;if((s|0)==0){r=l}else{t=9;break}}if((t|0)==9){KIb(a,16,2297256,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;o=-1;i=f;return o|0}s=Lpc(j,4)|0;if((s|0)==1){c[n>>2]=c[g+36>>2];g=b+36|0;c[g>>2]=c[g>>2]|1;c[e>>2]=1;o=0;i=f;return o|0}else{KIb(a,16,2297256,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;o=-1;i=f;return o|0}return 0}function QOa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(a+96|0);Ipc(b+16|0)|0;VHb(a+804|0);return 0}function ROa(a){a=a|0;return VOa(a,202440)|0}function SOa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+8|0;g=f|0;h=c[a+60>>2]|0;j=b;c[g>>2]=0;k=h;h=e+28|0;if((kYb(k,c[e+24>>2]|0,c[h>>2]|0,0,0)|0)!=0){e=fYb(k)|0;l=gYb(k)|0;m=a;KIb(m,16,2204720,(n=i,i=i+8|0,c[n>>2]=e,n)|0);i=n;if((l|0)==0){o=-1094995529;i=f;return o|0}KIb(m,16,2172608,(n=i,i=i+8|0,c[n>>2]=l,n)|0);i=n;o=-1094995529;i=f;return o|0}l=lYb(k,g)|0;do{if((l|0)!=0){g=c[l>>2]|0;if((g|0)!=258){KIb(a,16,2145168,(n=i,i=i+8|0,c[n>>2]=g,n)|0);i=n;o=-1094995529;i=f;return o|0}g=l+12|0;k=c[g>>2]|0;m=c[a+120>>2]|0;if((k|0)==(m|0)){e=c[l+16>>2]|0;p=c[a+124>>2]|0;if((e|0)!=(p|0)){q=p;r=e;s=10}}else{q=c[a+124>>2]|0;r=c[l+16>>2]|0;s=10}do{if((s|0)==10){KIb(a,32,2121360,(n=i,i=i+32|0,c[n>>2]=m,c[n+8>>2]=q,c[n+16>>2]=k,c[n+24>>2]=r,n)|0);i=n;e=H4a(a,c[g>>2]|0,c[l+16>>2]|0)|0;if((e|0)<0){o=e}else{break}i=f;return o|0}}while(0);k=M4a(a,j,0)|0;if((k|0)<0){o=k;i=f;return o|0}else{vIb(b,b+32|0,l+28|0,l+44|0,c[a+140>>2]|0,c[g>>2]|0,c[l+16>>2]|0);c[d>>2]=1;break}}}while(0);o=c[h>>2]|0;i=f;return o|0}function TOa(a){a=a|0;hYb(c[a+60>>2]|0)|0;return 0}function UOa(a){a=a|0;return VOa(a,202280)|0}function VOa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;e=d|0;f=c[a+60>>2]|0;g=c[a+808>>2]|0;c[e>>2]=(g|0)>16?16:g;c[e+4>>2]=0;c[e+8>>2]=0;g=a;h=dYb()|0;KIb(g,32,2297248,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;h=AYb()|0;KIb(g,40,2297248,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;h=f;if((jYb(h,b,e,0,7)|0)==0){c[a+140>>2]=0;k=0;i=d;return k|0}else{a=fYb(h)|0;KIb(g,16,2246360,(j=i,i=i+8|0,c[j>>2]=a,j)|0);i=j;k=-22;i=d;return k|0}return 0}function WOa(a){a=a|0;return _Oa(a,202520)|0}function XOa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;g=i;i=i+112|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=b+60|0;n=c[m>>2]|0;o=(e|0)!=0;if(o){c[n+60>>2]=c[e>>2];c[n+64>>2]=c[e+4>>2];c[n+68>>2]=c[e+8>>2];p=e+32|0;c[n+76>>2]=c[p>>2];q=e+36|0;c[n+80>>2]=c[q>>2];r=e+40|0;c[n+84>>2]=c[r>>2];if((a[n+228|0]|0)==0){s=0}else{c[n+172>>2]=c[e+12>>2];t=e+72|0;u=hJb(ca(c[t>>2]|0,c[q>>2]|0)|0)|0;v=c[t>>2]|0;mrc(u|0,-128|0,ca(v,c[q>>2]|0)|0)|0;c[n+176>>2]=u;u=hJb(ca(v,c[r>>2]|0)|0)|0;mrc(u|0,-128|0,ca(c[t>>2]|0,c[r>>2]|0)|0)|0;c[n+180>>2]=u;c[n+188>>2]=c[p>>2];c[n+192>>2]=c[q>>2];c[n+196>>2]=c[r>>2];s=n+144|0}r=e+136|0;w=n+32|0;x=s;y=(c[e+88>>2]|0)==1|0;z=c[r+4>>2]|0;A=c[r>>2]|0}else{w=0;x=0;y=0;z=0;A=0}r=b+112|0;e=n+240|0;if((oYb(n+4|0,w,A,z,c[r>>2]|0,y,c[e>>2]|0)|0)!=0){w=(c[m>>2]|0)+4|0;s=fYb(w)|0;q=gYb(w)|0;w=b;KIb(w,16,2285256,(B=i,i=i+16|0,c[B>>2]=2557728,c[B+8>>2]=s,B)|0);i=B;if((q|0)==0){C=-1094995529;i=g;return C|0}KIb(w,16,2281208,(B=i,i=i+8|0,c[B>>2]=q,B)|0);i=B;C=-1094995529;i=g;return C|0}do{if((a[n+228|0]|0)!=0){if((oYb(n+116|0,x,A,z,c[r>>2]|0,y,c[e>>2]|0)|0)==0){break}q=(c[m>>2]|0)+4|0;w=fYb(q)|0;s=gYb(q)|0;q=b;KIb(q,16,2285256,(B=i,i=i+16|0,c[B>>2]=2556424,c[B+8>>2]=w,B)|0);i=B;if((s|0)==0){C=-1094995529;i=g;return C|0}KIb(q,16,2281208,(B=i,i=i+8|0,c[B>>2]=s,B)|0);i=B;C=-1094995529;i=g;return C|0}}while(0);e=c[b+804>>2]|0;y=c[m>>2]|0;c[j>>2]=0;c[k>>2]=0;m=y+296|0;r=c[m>>2]|0;do{if((r|0)==0){D=0;E=17}else{z=aPa(b,r,d,e)|0;if((z|0)<0){F=z;break}c[m>>2]=c[r+80>>2];c[h>>2]=r;mJb(r);A=r+8|0;if((c[A>>2]|0)!=0){mJb(A)}mJb(h);D=z;E=17}}while(0);a:do{if((E|0)==17){h=y+4|0;r=y+228|0;z=y+288|0;A=y+280|0;s=y+248|0;q=y+232|0;w=y+236|0;p=q;u=s;t=y+256|0;v=y+264|0;H=y+272|0;I=y+116|0;J=l+16|0;K=l+24|0;L=l+28|0;M=l+4|0;N=l|0;O=l+64|0;P=l+72|0;Q=l+32|0;R=l+8|0;S=l+12|0;T=0;U=D;b:while(1){V=pYb(h,j)|0;if((V|0)==0){F=U;break a}W=(U|0)==0;X=T;Y=V;while(1){if((a[r]|0)==0){Z=X}else{V=pYb(I,k)|0;if((V|0)==0){F=U;break a}else{Z=V}}V=c[Y>>2]|0;if((V|0)==0){if(W){break}_=hJb(88)|0;$=_;if((_|0)==0){E=35;break b}aa=Y+8|0;ba=Y+16|0;da=c[ba+4>>2]|0;ea=_+16|0;c[ea>>2]=c[ba>>2];c[ea+4>>2]=da;c[_+24>>2]=c[Y+24>>2];da=c[aa+20>>2]|0;c[_+28>>2]=da;ea=Y+12|0;ba=_+4|0;c[ba>>2]=c[ea>>2];fa=aa;aa=_;c[aa>>2]=c[fa>>2];ga=_+64|0;c[ga>>2]=0;do{if((da&4|0)==0){ha=wrc(c[z>>2]|0,c[z+4>>2]|0,1,0)|0;ia=G;c[z>>2]=ha;c[z+4>>2]=ia;ja=_+72|0;c[ja>>2]=ha;c[ja+4>>2]=ia;c[ga>>2]=c[A>>2];if((c[A>>2]|0)==0){break}ia=_+32|0;c[ia>>2]=c[s>>2];c[ia+4>>2]=c[s+4>>2];c[ia+8>>2]=c[s+8>>2];c[ia+12>>2]=c[s+12>>2];c[ia+16>>2]=c[s+16>>2];c[ia+20>>2]=c[s+20>>2];c[ia+24>>2]=c[s+24>>2];c[ia+28>>2]=c[s+28>>2];c[A>>2]=0}else{ia=_+72|0;c[ia>>2]=-1;c[ia+4>>2]=-1}}while(0);if((Z|0)==0){c[_+8>>2]=0;c[_+12>>2]=0;ka=0}else{c[_+8>>2]=c[Z+8>>2];ga=c[Z+12>>2]|0;c[_+12>>2]=ga;ka=ga}la=c[ba>>2]|0;ga=hJb(la)|0;c[aa>>2]=ga;if((ga|0)==0){E=44;break b}nrc(ga|0,c[fa>>2]|0,c[ea>>2]|0)|0;if((a[r]|0)==0){ma=m}else{ga=hJb(ka)|0;c[_+8>>2]=ga;if((ga|0)==0){E=47;break b}nrc(ga|0,c[Z+8>>2]|0,c[Z+12>>2]|0)|0;ma=m}while(1){ga=c[ma>>2]|0;if((ga|0)==0){break}else{ma=ga+80|0}}c[ma>>2]=$;c[_+80>>2]=0}else if((V|0)==1){ea=Y+12|0;na=lJb(q,(c[ea>>2]|0)+(c[w>>2]|0)|0)|0;if((na|0)<0){E=53;break b}nrc((c[p>>2]|0)+(c[w>>2]|0)|0,c[Y+8>>2]|0,c[ea>>2]|0)|0;c[w>>2]=(c[w>>2]|0)+(c[ea>>2]|0)}else if((V|0)==2){if((c[A>>2]|0)!=0){E=56;break b}ea=Y+24|0;fa=c[ea+4>>2]|0;c[u>>2]=c[ea>>2];c[u+4>>2]=fa;fa=Y+32|0;ea=c[fa+4>>2]|0;c[t>>2]=c[fa>>2];c[t+4>>2]=ea;ea=Y+40|0;fa=c[ea+4>>2]|0;c[v>>2]=c[ea>>2];c[v+4>>2]=fa;fa=Y+48|0;ea=c[fa+4>>2]|0;c[H>>2]=c[fa>>2];c[H+4>>2]=ea;c[A>>2]=1}ea=pYb(h,j)|0;if((ea|0)==0){F=U;break a}else{X=Z;Y=ea}}if((c[m>>2]|0)!=0){E=25;break}X=Y+8|0;W=Y+16|0;ea=c[W+4>>2]|0;c[J>>2]=c[W>>2];c[J+4>>2]=ea;c[K>>2]=c[Y+24>>2];ea=c[X+20>>2]|0;c[L>>2]=ea;c[M>>2]=c[Y+12>>2];c[N>>2]=c[X>>2];c[O>>2]=0;do{if((ea&4|0)==0){X=wrc(c[z>>2]|0,c[z+4>>2]|0,1,0)|0;W=G;c[z>>2]=X;c[z+4>>2]=W;c[P>>2]=X;c[P+4>>2]=W;W=c[A>>2]|0;c[O>>2]=W;if((W|0)==0){break}c[Q>>2]=c[s>>2];c[Q+4>>2]=c[s+4>>2];c[Q+8>>2]=c[s+8>>2];c[Q+12>>2]=c[s+12>>2];c[Q+16>>2]=c[s+16>>2];c[Q+20>>2]=c[s+20>>2];c[Q+24>>2]=c[s+24>>2];c[Q+28>>2]=c[s+28>>2];c[A>>2]=0}else{c[P>>2]=-1;c[P+4>>2]=-1}}while(0);if((Z|0)==0){c[R>>2]=0;oa=0}else{c[R>>2]=c[Z+8>>2];oa=c[Z+12>>2]|0}c[S>>2]=oa;ea=aPa(b,l,d,e)|0;if((ea|0)<0){F=ea;break a}else{T=Z;U=ea}}if((E|0)==25){KIb(0,0,2554040,(B=i,i=i+24|0,c[B>>2]=2553144,c[B+8>>2]=2551584,c[B+16>>2]=600,B)|0);i=B;Hd();return 0}else if((E|0)==35){KIb(b,16,2547064,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;F=-12;break}else if((E|0)==44){KIb(b,16,2544552,(B=i,i=i+8|0,c[B>>2]=la,B)|0);i=B;kJb(_);F=-12;break}else if((E|0)==47){KIb(b,16,2544552,(B=i,i=i+8|0,c[B>>2]=c[_+12>>2],B)|0);i=B;kJb(_);F=-12;break}else if((E|0)==53){c[w>>2]=0;KIb(b,16,2543120,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;F=na;break}else if((E|0)==56){KIb(0,0,2554040,(B=i,i=i+24|0,c[B>>2]=2541480,c[B+8>>2]=2551584,c[B+16>>2]=655,B)|0);i=B;Hd();return 0}}}while(0);do{if(!o){if((c[b+88>>2]&512|0)==0){break}E=n+236|0;na=((((c[E>>2]|0)+2|0)>>>0)/3|0)<<2|1;_=hJb(na)|0;c[b+668>>2]=_;if((_|0)!=0){RFb(_,na,c[n+232>>2]|0,c[E>>2]|0)|0;break}KIb(b,16,2555336,(B=i,i=i+8|0,c[B>>2]=na,B)|0);i=B;C=-12;i=g;return C|0}}while(0);if((x|0)!=0){kJb(c[x+32>>2]|0);kJb(c[x+36>>2]|0)}c[f>>2]=(F|0)!=0;C=0;i=g;return C|0}function YOa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=c[b+60>>2]|0;hYb(f+4|0)|0;if((a[f+228|0]|0)!=0){hYb(f+116|0)|0}mJb(f+232|0);mJb(b+804|0);mJb(b+668|0);b=c[f+296>>2]|0;if((b|0)==0){i=d;return 0}f=e;g=b;while(1){b=c[g+80>>2]|0;c[e>>2]=g;mJb(g);h=g+8|0;if((c[h>>2]|0)!=0){mJb(h)}mJb(f);if((b|0)==0){break}else{g=b}}i=d;return 0}function ZOa(a){a=a|0;return _Oa(a,202360)|0}function _Oa(b,e){b=b|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+624|0;h=f|0;j=f+80|0;k=f+352|0;l=b+60|0;m=c[l>>2]|0;n=b+88|0;o=c[n>>2]<<1&65536;p=b;q=dYb()|0;KIb(p,32,2246352,(r=i,i=i+8|0,c[r>>2]=q,r)|0);i=r;q=AYb()|0;KIb(p,40,2246352,(r=i,i=i+8|0,c[r>>2]=q,r)|0);i=r;if((c[b+140>>2]|0)==35){a[m+228|0]=1}q=nYb(e,j,0)|0;if((q|0)!=0){s=eYb(q)|0;KIb(p,16,2204688,(r=i,i=i+8|0,c[r>>2]=s,r)|0);i=r;t=-22;i=f;return t|0}s=b+72|0;a:do{if((c[s>>2]|0)==0){do{if((c[b+540>>2]|0)==0){if((c[b+524>>2]|0)!=0){break}if((c[b+564>>2]|0)==0){break a}}}while(0);KIb(p,16,2172560,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;t=-22;i=f;return t|0}}while(0);$Oa(b,j);q=b+120|0;c[j+12>>2]=c[q>>2];u=b+124|0;c[j+16>>2]=c[u>>2];c[j+20>>2]=c[b+104>>2];c[j+24>>2]=c[b+108>>2];c[j+4>>2]=c[b+808>>2];v=j+36|0;c[v>>2]=c[m+324>>2];w=c[n>>2]|0;do{if((w&512|0)==0){n=j+32|0;if((w&1024|0)==0){c[n>>2]=0;break}else{c[n>>2]=2;break}}else{c[j+32>>2]=1}}while(0);w=b+544|0;n=c[w>>2]|0;x=b+540|0;do{if((n|0)==(c[x>>2]|0)){y=c[s>>2]|0;if((n|0)!=(y|0)|(y|0)==0){z=18;break}c[j+64>>2]=1}else{z=18}}while(0);do{if((z|0)==18){if((c[m+332>>2]|0)==0){break}c[j+64>>2]=2}}while(0);n=c[s>>2]|0;do{if((n|0)==0){y=j+76|0;if((c[j+64>>2]|0)==2){c[y>>2]=1e6;break}else{A=c[y>>2]|0;c[s>>2]=A*1e3|0;KIb(p,24,2145080,(r=i,i=i+8|0,c[r>>2]=A,r)|0);i=r;break}}else{A=UIb(n,(n|0)<0|0?-1:0,1,0,1e3,0,5)|0;c[j+76>>2]=A}}while(0);n=c[b+500>>2]|0;if((n|0)>-1){c[j+80>>2]=n}n=c[b+504>>2]|0;if((n|0)>-1){c[j+84>>2]=n}do{if((c[j+64>>2]|0)==2){n=c[m+332>>2]|0;A=c[j+80>>2]|0;y=c[j+84>>2]|0;if(!(n>>>0<A>>>0|n>>>0>y>>>0)){break}KIb(p,16,2121288,(r=i,i=i+16|0,c[r>>2]=A,c[r+8>>2]=y,r)|0);i=r;t=-22;i=f;return t|0}}while(0);c[j+40>>2]=c[b+584>>2];c[j+108>>2]=~~+Nb(+(+g[b+492>>2]*100.0));y=c[s>>2]|0;if((y|0)!=0){s=c[w>>2]|0;w=Erc(s,(s|0)<0|0?-1:0,100,0)|0;s=Crc(w,G,y,(y|0)<0|0?-1:0)|0;c[j+112>>2]=s}s=c[x>>2]|0;if((s|0)!=0){x=Erc(s,(s|0)<0|0?-1:0,100,0)|0;s=Crc(x,G,y,(y|0)<0|0?-1:0)|0;c[j+116>>2]=s}s=c[b+524>>2]|0;if((s|0)!=0){x=Erc(s,(s|0)<0|0?-1:0,1e3,0)|0;s=Crc(x,G,y,(y|0)<0|0?-1:0)|0;c[j+96>>2]=s}s=c[b+564>>2]|0;if((s|0)!=0){x=Erc(s,(s|0)<0|0?-1:0,1e3,0)|0;s=Crc(x,G,y,(y|0)<0|0?-1:0)|0;c[j+100>>2]=s}c[j+104>>2]=(((c[j+96>>2]|0)*5|0)>>>0)/6|0;c[j+88>>2]=~~+Nb(+(+g[b+548>>2]*100.0));s=c[b+360>>2]|0;y=c[b+136>>2]|0;if((s|0)>-1&(s|0)==(y|0)){c[j+124>>2]=s;B=s}else{B=y}if((B|0)>-1){c[j+128>>2]=B}B=c[j+32>>2]|0;do{if((B|0)==2){y=b+672|0;s=c[y>>2]|0;if((s|0)==0){KIb(p,16,2638856,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;t=-1094995529;i=f;return t|0}x=((lrc(s|0)|0)*3|0)>>>2;s=m+232|0;w=m+236|0;c[w>>2]=x;A=hJb(x)|0;c[s>>2]=A;if((A|0)==0){KIb(p,16,2616328,(r=i,i=i+8|0,c[r>>2]=c[w>>2],r)|0);i=r;t=-12;i=f;return t|0}x=QFb(A,c[y>>2]|0,c[w>>2]|0)|0;if((x|0)>=0){c[w>>2]=x;x=s;s=j+68|0;w=c[x+4>>2]|0;c[s>>2]=c[x>>2];c[s+4>>2]=w;break}KIb(p,16,2589056,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;t=-1094995529;i=f;return t|0}else if((B|0)==1){c[v>>2]=0}}while(0);v=c[b+840>>2]|0;if(!((v|0)==-99)){c[j+8>>2]=v}if((c[m+328>>2]|0)==0){C=c[m+304>>2]&1}else{C=1}c[j+28>>2]=C;$Oa(b,j);if((mYb(m+4|0,e,j,o,7)|0)!=0){C=(c[l>>2]|0)+4|0;v=fYb(C)|0;B=gYb(C)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=2567608,c[r+8>>2]=v,r)|0);i=r;if((B|0)==0){t=-22;i=f;return t|0}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=B,r)|0);i=r;t=-22;i=f;return t|0}B=m+228|0;do{if((a[B]|0)!=0){nrc(k|0,j|0,268)|0;if((mYb(m+116|0,e,k,o,7)|0)==0){break}v=(c[l>>2]|0)+4|0;C=fYb(v)|0;w=gYb(v)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=2549400,c[r+8>>2]=C,r)|0);i=r;if((w|0)==0){t=-22;i=f;return t|0}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=w,r)|0);i=r;t=-22;i=f;return t|0}}while(0);KIb(p,48,2531440,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;o=c[m+300>>2]|0;do{if(!((o|0)==-2147483648)){k=h|0;e=c[l>>2]|0;Rb(k|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2396272,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=k,c[r+16>>2]=o,r)|0);i=r;j=iYb(e+4|0,13,(r=i,i=i+8|0,c[r>>2]=o,r)|0)|0;i=r;if((j|0)==0){break}Rb(k|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2396272,r)|0)|0;i=r;j=(c[l>>2]|0)+4|0;e=fYb(j)|0;w=gYb(j)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=k,c[r+8>>2]=e,r)|0);i=r;if((w|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=w,r)|0);i=r}}while(0);o=m+308|0;if((c[m+304>>2]&2|0)==0){w=c[o>>2]|0;if((w|0)>-1){D=w;z=71}}else{c[o>>2]=1;D=1;z=71}do{if((z|0)==71){o=h|0;w=c[l>>2]|0;Rb(o|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2389344,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=o,c[r+16>>2]=D,r)|0);i=r;e=iYb(w+4|0,14,(r=i,i=i+8|0,c[r>>2]=D,r)|0)|0;i=r;if((e|0)==0){break}Rb(o|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2389344,r)|0)|0;i=r;e=(c[l>>2]|0)+4|0;w=fYb(e)|0;k=gYb(e)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=o,c[r+8>>2]=w,r)|0);i=r;if((k|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=k,r)|0);i=r}}while(0);D=c[m+312>>2]|0;do{if((D|0)>-1){z=h|0;k=c[l>>2]|0;Rb(z|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2339496,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=z,c[r+16>>2]=D,r)|0);i=r;w=iYb(k+4|0,21,(r=i,i=i+8|0,c[r>>2]=D,r)|0)|0;i=r;if((w|0)==0){break}Rb(z|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2339496,r)|0)|0;i=r;w=(c[l>>2]|0)+4|0;k=fYb(w)|0;o=gYb(w)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=z,c[r+8>>2]=k,r)|0);i=r;if((o|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r}}while(0);D=c[m+316>>2]|0;do{if((D|0)>-1){o=h|0;k=c[l>>2]|0;Rb(o|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2333768,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=o,c[r+16>>2]=D,r)|0);i=r;z=iYb(k+4|0,22,(r=i,i=i+8|0,c[r>>2]=D,r)|0)|0;i=r;if((z|0)==0){break}Rb(o|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2333768,r)|0)|0;i=r;z=(c[l>>2]|0)+4|0;k=fYb(z)|0;w=gYb(z)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=o,c[r+8>>2]=k,r)|0);i=r;if((w|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=w,r)|0);i=r}}while(0);D=c[m+320>>2]|0;w=h|0;do{if((D|0)>-1){h=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2328344,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=D,r)|0);i=r;k=iYb(h+4|0,23,(r=i,i=i+8|0,c[r>>2]=D,r)|0)|0;i=r;if((k|0)==0){break}Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2328344,r)|0)|0;i=r;k=(c[l>>2]|0)+4|0;h=fYb(k)|0;o=gYb(k)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=h,r)|0);i=r;if((o|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r}}while(0);D=c[b+312>>2]|0;o=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2382432,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=D,r)|0);i=r;h=iYb(o+4|0,15,(r=i,i=i+8|0,c[r>>2]=D,r)|0)|0;i=r;do{if((h|0)!=0){Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2382432,r)|0)|0;i=r;D=(c[l>>2]|0)+4|0;o=fYb(D)|0;k=gYb(D)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=o,r)|0);i=r;if((k|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=k,r)|0);i=r}}while(0);h=b+48|0;do{if((c[h>>2]|0)==141){k=c[b+404>>2]|0;o=k>>>0>65535>>>0;D=o?k>>>16:k;k=o?16:0;if((D&65280|0)==0){E=k;F=D}else{E=k|8;F=D>>>8}D=(d[1359664+F|0]|0)+E|0;k=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2354320,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=D,r)|0);i=r;o=iYb(k+4|0,18,(r=i,i=i+8|0,c[r>>2]=D,r)|0)|0;i=r;if((o|0)==0){break}Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2354320,r)|0)|0;i=r;o=(c[l>>2]|0)+4|0;D=fYb(o)|0;k=gYb(o)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=D,r)|0);i=r;if((k|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=k,r)|0);i=r}}while(0);E=c[b+320>>2]|0;F=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2369104,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=E,r)|0);i=r;k=iYb(F+4|0,17,(r=i,i=i+8|0,c[r>>2]=E,r)|0)|0;i=r;do{if((k|0)!=0){Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2369104,r)|0)|0;i=r;E=(c[l>>2]|0)+4|0;F=fYb(E)|0;D=gYb(E)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=F,r)|0);i=r;if((D|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=D,r)|0);i=r}}while(0);k=c[m+332>>2]|0;D=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2322624,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=k,r)|0);i=r;F=iYb(D+4|0,25,(r=i,i=i+8|0,c[r>>2]=k,r)|0)|0;i=r;do{if((F|0)!=0){Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2322624,r)|0)|0;i=r;k=(c[l>>2]|0)+4|0;D=fYb(k)|0;E=gYb(k)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=D,r)|0);i=r;if((E|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=E,r)|0);i=r}}while(0);F=c[m+336>>2]|0;do{if((F|0)>-1){E=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2317584,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=F,r)|0);i=r;D=iYb(E+4|0,26,(r=i,i=i+8|0,c[r>>2]=F,r)|0)|0;i=r;if((D|0)==0){break}Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2317584,r)|0)|0;i=r;D=(c[l>>2]|0)+4|0;E=fYb(D)|0;k=gYb(D)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=E,r)|0);i=r;if((k|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=k,r)|0);i=r}}while(0);do{if((c[h>>2]|0)==169){F=c[m+340>>2]|0;do{if((F|0)>-1){k=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2312936,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=F,r)|0);i=r;E=iYb(k+4|0,27,(r=i,i=i+8|0,c[r>>2]=F,r)|0)|0;i=r;if((E|0)==0){break}Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2312936,r)|0)|0;i=r;E=(c[l>>2]|0)+4|0;k=fYb(E)|0;D=gYb(E)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=k,r)|0);i=r;if((D|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=D,r)|0);i=r}}while(0);F=c[m+344>>2]|0;do{if((F|0)>-1){D=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2308304,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=F,r)|0);i=r;k=iYb(D+4|0,28,(r=i,i=i+8|0,c[r>>2]=F,r)|0)|0;i=r;if((k|0)==0){break}Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2308304,r)|0)|0;i=r;k=(c[l>>2]|0)+4|0;D=fYb(k)|0;E=gYb(k)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=D,r)|0);i=r;if((E|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=E,r)|0);i=r}}while(0);F=c[m+348>>2]|0;do{if((F|0)>-1){E=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2303280,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=F,r)|0);i=r;D=iYb(E+4|0,29,(r=i,i=i+8|0,c[r>>2]=F,r)|0)|0;i=r;if((D|0)==0){break}Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2303280,r)|0)|0;i=r;D=(c[l>>2]|0)+4|0;E=fYb(D)|0;k=gYb(D)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=E,r)|0);i=r;if((k|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=k,r)|0);i=r}}while(0);F=c[m+352>>2]|0;if(!((F|0)>-1)){break}k=c[l>>2]|0;Rb(w|0,80,2489248,(r=i,i=i+8|0,c[r>>2]=2292104,r)|0)|0;i=r;KIb(p,48,2478240,(r=i,i=i+24|0,c[r>>2]=-30,c[r+8>>2]=w,c[r+16>>2]=F,r)|0);i=r;E=iYb(k+4|0,30,(r=i,i=i+8|0,c[r>>2]=F,r)|0)|0;i=r;if((E|0)==0){break}Rb(w|0,80,2468632,(r=i,i=i+8|0,c[r>>2]=2292104,r)|0)|0;i=r;E=(c[l>>2]|0)+4|0;F=fYb(E)|0;k=gYb(E)|0;KIb(p,16,2285256,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=F,r)|0);i=r;if((k|0)==0){break}KIb(p,16,2281208,(r=i,i=i+8|0,c[r>>2]=k,r)|0);i=r}}while(0);KIb(p,48,2516216,(r=i,i=i+8|0,c[r>>2]=c[m+240>>2],r)|0);i=r;vYb(m+32|0,258,c[q>>2]|0,c[u>>2]|0,1,1)|0;if((a[B]|0)!=0){vYb(m+144|0,258,c[q>>2]|0,c[u>>2]|0,1,1)|0}u=UHb()|0;c[b+804>>2]=u;if((u|0)!=0){t=0;i=f;return t|0}KIb(p,16,2502288,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;YOa(b)|0;t=-12;i=f;return t|0}function $Oa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=a;KIb(e,48,2277176,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;f=c[b>>2]|0;g=c[b+4>>2]|0;h=c[b+8>>2]|0;j=c[b+12>>2]|0;k=c[b+16>>2]|0;l=c[b+20>>2]|0;m=c[b+24>>2]|0;n=c[b+28>>2]|0;o=c[b+32>>2]|0;p=c[b+36>>2]|0;KIb(e,48,2272624,(a=i,i=i+224|0,c[a>>2]=-30,c[a+8>>2]=2267904,c[a+16>>2]=f,c[a+24>>2]=-30,c[a+32>>2]=2264176,c[a+40>>2]=g,c[a+48>>2]=-30,c[a+56>>2]=2260368,c[a+64>>2]=h,c[a+72>>2]=-30,c[a+80>>2]=2255952,c[a+88>>2]=j,c[a+96>>2]=-30,c[a+104>>2]=2251760,c[a+112>>2]=k,c[a+120>>2]=-30,c[a+128>>2]=2241304,c[a+136>>2]=l,c[a+144>>2]=m,c[a+152>>2]=-30,c[a+160>>2]=2235456,c[a+168>>2]=n,c[a+176>>2]=-30,c[a+184>>2]=2231888,c[a+192>>2]=o,c[a+200>>2]=-30,c[a+208>>2]=2228040,c[a+216>>2]=p,a)|0);i=a;p=c[b+40>>2]|0;o=c[b+44>>2]|0;n=c[b+56>>2]|0;m=c[b+60>>2]|0;l=c[b+64>>2]|0;k=c[b+68>>2]|0;j=c[b+72>>2]|0;h=c[b+76>>2]|0;KIb(e,48,2223184,(a=i,i=i+176|0,c[a>>2]=-30,c[a+8>>2]=2219704,c[a+16>>2]=p,c[a+24>>2]=-30,c[a+32>>2]=2216768,c[a+40>>2]=o,c[a+48>>2]=-30,c[a+56>>2]=2213952,c[a+64>>2]=n,c[a+72>>2]=-30,c[a+80>>2]=2211568,c[a+88>>2]=m,c[a+96>>2]=-30,c[a+104>>2]=2208872,c[a+112>>2]=l,c[a+120>>2]=-30,c[a+128>>2]=2200248,c[a+136>>2]=k,c[a+144>>2]=j,c[a+152>>2]=-30,c[a+160>>2]=2195720,c[a+168>>2]=h,a)|0);i=a;h=c[b+80>>2]|0;j=c[b+84>>2]|0;KIb(e,48,2193096,(a=i,i=i+48|0,c[a>>2]=-30,c[a+8>>2]=2190656,c[a+16>>2]=h,c[a+24>>2]=-30,c[a+32>>2]=2188016,c[a+40>>2]=j,a)|0);i=a;j=c[b+88>>2]|0;h=c[b+92>>2]|0;KIb(e,48,2185456,(a=i,i=i+48|0,c[a>>2]=-30,c[a+8>>2]=2183184,c[a+16>>2]=j,c[a+24>>2]=-30,c[a+32>>2]=2181080,c[a+40>>2]=h,a)|0);i=a;h=c[b+96>>2]|0;j=c[b+100>>2]|0;k=c[b+104>>2]|0;KIb(e,48,2178752,(a=i,i=i+72|0,c[a>>2]=-30,c[a+8>>2]=2176296,c[a+16>>2]=h,c[a+24>>2]=-30,c[a+32>>2]=2168488,c[a+40>>2]=j,c[a+48>>2]=-30,c[a+56>>2]=2164096,c[a+64>>2]=k,a)|0);i=a;k=c[b+108>>2]|0;j=c[b+112>>2]|0;h=c[b+116>>2]|0;KIb(e,48,2162024,(a=i,i=i+72|0,c[a>>2]=-30,c[a+8>>2]=2160032,c[a+16>>2]=k,c[a+24>>2]=-30,c[a+32>>2]=2158168,c[a+40>>2]=j,c[a+48>>2]=-30,c[a+56>>2]=2156312,c[a+64>>2]=h,a)|0);i=a;h=c[b+120>>2]|0;j=c[b+124>>2]|0;k=c[b+128>>2]|0;KIb(e,48,2154768,(a=i,i=i+72|0,c[a>>2]=-30,c[a+8>>2]=2152832,c[a+16>>2]=h,c[a+24>>2]=-30,c[a+32>>2]=2150512,c[a+40>>2]=j,c[a+48>>2]=-30,c[a+56>>2]=2148352,c[a+64>>2]=k,a)|0);i=a;KIb(e,48,2141728,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=d;return}function aPa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=d5a(b,e,c[d+4>>2]|0,0)|0;if(!((g|0)>-1)){h=g;return h|0}g=e+28|0;nrc(c[e+24>>2]|0,c[d>>2]|0,c[g>>2]|0)|0;i=d+16|0;j=c[i>>2]|0;k=c[i+4>>2]|0;l=e+16|0;c[l>>2]=j;c[l+4>>2]=k;l=e+8|0;c[l>>2]=j;c[l+4>>2]=k;k=c[i+4>>2]|0;l=f+136|0;c[l>>2]=c[i>>2];c[l+4>>2]=k;k=c[d+28>>2]&1;c[f+84>>2]=k;l=f+88|0;if((k|0)==0){c[l>>2]=2}else{c[l>>2]=1;l=e+36|0;c[l>>2]=c[l>>2]|1}l=d+64|0;if((c[l>>2]|0)!=0){k=d+40|0;i=c[k>>2]|0;j=c[k+4>>2]|0;k=f+224|0;c[k>>2]=i;c[k+4>>2]=j;k=d+48|0;m=c[k+4>>2]|0;n=f+232|0;c[n>>2]=c[k>>2];c[n+4>>2]=m;m=d+56|0;k=c[m+4>>2]|0;o=f+240|0;c[o>>2]=c[m>>2];c[o+4>>2]=k;k=f+248|0;c[k>>2]=0;c[k+4>>2]=0;f=b+720|0;m=wrc(c[f>>2]|0,c[f+4>>2]|0,i,j)|0;c[f>>2]=m;c[f+4>>2]=G;f=b+728|0;m=wrc(c[f>>2]|0,c[f+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0)|0;c[f>>2]=m;c[f+4>>2]=G;f=b+736|0;m=wrc(c[f>>2]|0,c[f+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[f>>2]=m;c[f+4>>2]=G;f=b+744|0;b=wrc(c[f>>2]|0,c[f+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;c[f>>2]=b;c[f+4>>2]=G;c[l>>2]=0}l=d+12|0;f=c[l>>2]|0;do{if((f|0)!=0){b=U1(e,74,f+8|0)|0;if((b|0)!=0){k=b;m=k|0;y=0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+4|0;y=16777216;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;nrc(b+8|0,c[d+8>>2]|0,c[l>>2]|0)|0;break}P1(e);kJb(e);h=-12;return h|0}}while(0);h=c[g>>2]|0;return h|0}function bPa(a){a=a|0;var b=0;b=c[27428]|0;if((b|0)==8){c[a+24>>2]=729096;return}else if((b|0)==9){c[a+24>>2]=729064;return}else if((b|0)==10){c[a+24>>2]=729136;return}else{return}}function cPa(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=i;i=i+552|0;d=b|0;e=b+8|0;f=b+16|0;h=b+272|0;j=b+528|0;k=b+536|0;l=b+544|0;m=c[a+60>>2]|0;n=m+4|0;DLb(n);o=a+88|0;c[m+144>>2]=c[o>>2]&2048;p=m+628|0;g[m+680>>2]=+g[a+160>>2];c[m+544>>2]=c[a+368>>2];q=m+1072|0;r=c[q>>2]|0;s=c[m+1076>>2]|0;do{if(!((r|0)==0&(s|0)==0)){if((FLb(n,r,s)|0)>=0){break}t=a;u=c[m+1076>>2]|0;KIb(t,16,2113080,(v=i,i=i+16|0,c[v>>2]=c[q>>2],c[v+8>>2]=u,v)|0);i=v;KIb(t,32,2111208,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2580328,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2578152,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2576712,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2575304,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2574032,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2204608,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2572496,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2571088,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2569632,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2565160,v)|0);i=v;KIb(t,32,2107984,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;KIb(t,32,2106624,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2600104,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2598504,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2596040,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2594096,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2591968,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2260360,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2586048,v)|0);i=v;KIb(t,32,2109528,(v=i,i=i+8|0,c[v>>2]=2582320,v)|0);i=v;KIb(t,32,2107984,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=b;return w|0}}while(0);q=c[a+844>>2]|0;if((q|0)>0){c[m+44>>2]=q}c[m+500>>2]=456;q=a;c[m+504>>2]=q;c[m+508>>2]=3;s=a+140|0;switch(c[s>>2]|0){case 5:case 14:case 76:case 78:{x=8;break};case 112:case 113:{x=6;break};case 3:{x=10;break};case 25:{x=3;break};case 0:case 12:case 70:case 72:{x=1;break};case 2:{x=12;break};case 4:case 13:case 74:{x=4;break};default:{x=0}}c[m+40>>2]=x;x=m+1092|0;r=c[x>>2]|0;do{if((r|0)!=0){t=JLb(n,2277168,r)|0;if((t|0)>=0){break}u=c[x>>2]|0;if((t|0)==-1){KIb(q,16,2105280,(v=i,i=i+16|0,c[v>>2]=2277168,c[v+8>>2]=u,v)|0);i=v;w=-1;i=b;return w|0}else{KIb(q,16,2644336,(v=i,i=i+16|0,c[v>>2]=2277168,c[v+8>>2]=u,v)|0);i=v;w=-1;i=b;return w|0}}}while(0);x=a+72|0;r=c[x>>2]|0;if((r|0)!=0){c[m+648>>2]=(r|0)/1e3|0;c[p>>2]=2}r=a+524|0;c[m+668>>2]=(c[r>>2]|0)/1e3|0;c[m+664>>2]=(c[a+540>>2]|0)/1e3|0;c[m+704>>2]=c[o>>2]&512;do{if((c[o>>2]&1024|0)==0){y=+g[m+1100>>2];do{if(y<0.0){u=c[m+1108>>2]|0;if(!((u|0)>-1)){break}c[p>>2]=0;c[m+632>>2]=u}else{c[p>>2]=1;g[m+652>>2]=y}}while(0);y=+g[m+1104>>2];if(y<0.0){break}g[m+656>>2]=y}else{c[m+712>>2]=1}}while(0);p=c[r>>2]|0;do{if((p|0)!=0){r=c[a+564>>2]|0;if((r|0)<1|(r|0)>(p|0)){break}g[m+672>>2]=+(r|0)/+(p|0)}}while(0);p=m+1084|0;r=c[p>>2]|0;do{if((r|0)!=0){u=JLb(n,2567600,r)|0;if((u|0)>=0){break}t=c[p>>2]|0;if((u|0)==-1){KIb(q,16,2105280,(v=i,i=i+16|0,c[v>>2]=2567600,c[v+8>>2]=t,v)|0);i=v;w=-1;i=b;return w|0}else{KIb(q,16,2644336,(v=i,i=i+16|0,c[v>>2]=2567600,c[v+8>>2]=t,v)|0);i=v;w=-1;i=b;return w|0}}}while(0);y=+g[a+184>>2];if(y>0.0){g[m+676>>2]=1.0/+R(+y)}switch(c[a+144>>2]|0){case 2:{c[m+548>>2]=3;break};case 9:{c[m+548>>2]=4;break};case 8:{c[m+548>>2]=2;break};case 7:{c[m+548>>2]=1;break};case 5:{c[m+548>>2]=0;break};default:{}}p=c[a+136>>2]|0;if((p|0)>-1){c[m+100>>2]=p}p=a+156|0;r=c[p>>2]|0;if((r|0)>-1){c[m+116>>2]=r}r=c[a+308>>2]|0;if((r|0)>-1){c[m+108>>2]=r}r=c[a+500>>2]|0;if((r|0)>-1){c[m+636>>2]=r}r=c[a+504>>2]|0;if((r|0)>-1){c[m+640>>2]=r}r=c[a+508>>2]|0;if((r|0)>-1){c[m+644>>2]=r}y=+g[a+496>>2];if(!(y<0.0)){g[m+724>>2]=y}y=+g[a+492>>2];if(!(y<0.0)){g[m+720>>2]=y}r=c[a+364>>2]|0;if((r|0)>-1){c[m+92>>2]=r}r=c[a+600>>2]|0;if((r|0)>-1){c[m+576>>2]=r}r=c[a+276>>2]|0;if((r|0)>-1){c[m+552>>2]=r}r=c[a+312>>2]|0;if((r|0)>-1){c[m+588>>2]=r}r=c[a+268>>2]|0;if((r|0)>-1){c[m+564>>2]=r}r=c[a+168>>2]|0;if((r|0)>-1){c[m+120>>2]=r}r=c[a+360>>2]|0;if((r|0)>-1){c[m+104>>2]=r}r=c[a+568>>2]|0;if((r|0)>-1){c[m+156>>2]=(r|0)==1}r=c[a+232>>2]|0;if((r|0)>-1){c[m+568>>2]=r&256}r=c[m+1112>>2]|0;if((r|0)>-1){c[m+688>>2]=r}y=+g[m+1116>>2];if(!(y<0.0)){g[m+692>>2]=y}r=m+1120|0;t=c[r>>2]|0;do{if((t|0)!=0){if((JLb(n,2312928,t)|0)>=0){break}u=c[r>>2]|0;KIb(q,16,2642528,(v=i,i=i+16|0,c[v>>2]=2312928,c[v+8>>2]=u,v)|0);i=v;w=-22;i=b;return w|0}}while(0);r=m+1180|0;t=c[r>>2]|0;do{if((t|0)!=0){if((JLb(n,2164088,t)|0)>=0){break}u=c[r>>2]|0;KIb(q,16,2642528,(v=i,i=i+16|0,c[v>>2]=2164088,c[v+8>>2]=u,v)|0);i=v;w=-22;i=b;return w|0}}while(0);r=m+1188|0;t=c[r>>2]|0;do{if((t|0)!=0){if((JLb(n,2156296,t)|0)>=0){break}u=c[r>>2]|0;KIb(q,16,2642528,(v=i,i=i+16|0,c[v>>2]=2156296,c[v+8>>2]=u,v)|0);i=v;w=-22;i=b;return w|0}}while(0);r=m+1200|0;t=c[r>>2]|0;do{if((t|0)!=0){if((JLb(n,2132640,t)|0)>=0){break}u=c[r>>2]|0;KIb(q,16,2642528,(v=i,i=i+16|0,c[v>>2]=2132640,c[v+8>>2]=u,v)|0);i=v;w=-22;i=b;return w|0}}while(0);r=c[m+1124>>2]|0;if((r|0)>-1){c[m+600>>2]=r}r=c[m+1128>>2]|0;if((r|0)>-1){c[m+700>>2]=r}r=c[m+1132>>2]|0;if((r|0)>-1){c[m+532>>2]=r}r=c[m+1136>>2]|0;if((r|0)>-1){c[m+536>>2]=r}y=+g[m+1184>>2];if(!(y<0.0)){g[m+728>>2]=y}r=c[m+1140>>2]|0;if((r|0)>-1){c[m+624>>2]=r}r=c[m+1144>>2]|0;if((r|0)>-1){c[m+112>>2]=r}r=c[m+1148>>2]|0;if((r|0)>-1){c[m+136>>2]=r;c[m+780>>2]=0}r=c[m+1152>>2]|0;if(!((r|0)==-2147483648)){c[m+124>>2]=r}r=c[m+1156>>2]|0;if((r|0)>-1){c[m+128>>2]=r}r=c[m+1160>>2]|0;if((r|0)>-1){c[m+572>>2]=r}r=c[m+1164>>2]|0;if((r|0)>-1){c[m+528>>2]=r}r=c[m+1168>>2]|0;if((r|0)>-1){c[m+580>>2]=r}r=c[m+1172>>2]|0;if((r|0)>-1){c[m+764>>2]=r}r=c[m+1176>>2]|0;if((r|0)>-1){c[m+696>>2]=r}r=c[m+1192>>2]|0;if((r|0)>-1){c[m+540>>2]=r}r=c[m+1196>>2]|0;do{if((r|0)>-1){c[m+836>>2]=r}else{t=c[a+628>>2]|0;if((t|0)==0){break}c[m+836>>2]=t}}while(0);if((c[m+1088>>2]|0)!=0){GLb(n)}r=m+1080|0;t=c[r>>2]|0;a:do{if((t|0)==0){switch(c[a+840>>2]|0){case 144:{u=rJb(2627352)|0;c[r>>2]=u;z=u;break a;break};case 77:{u=rJb(2626e3)|0;c[r>>2]=u;z=u;break a;break};case 100:{u=rJb(2632880)|0;c[r>>2]=u;z=u;break a;break};case 110:{u=rJb(2630712)|0;c[r>>2]=u;z=u;break a;break};case 122:{u=rJb(2628888)|0;c[r>>2]=u;z=u;break a;break};case 66:{u=rJb(2636176)|0;c[r>>2]=u;z=u;break a;break};default:{z=0;break a}}}else{z=t}}while(0);t=c[m+1204>>2]|0;if((t|0)>-1){c[m+52>>2]=t}do{if((z|0)!=0){if((HLb(n,z)|0)>=0){break}KIb(q,16,2624752,(v=i,i=i+8|0,c[v>>2]=c[r>>2],v)|0);i=v;KIb(q,32,2623264,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;KIb(q,32,2109528,(v=i,i=i+8|0,c[v>>2]=2636176,v)|0);i=v;KIb(q,32,2109528,(v=i,i=i+8|0,c[v>>2]=2626e3,v)|0);i=v;KIb(q,32,2109528,(v=i,i=i+8|0,c[v>>2]=2632880,v)|0);i=v;KIb(q,32,2109528,(v=i,i=i+8|0,c[v>>2]=2630712,v)|0);i=v;KIb(q,32,2109528,(v=i,i=i+8|0,c[v>>2]=2628888,v)|0);i=v;KIb(q,32,2109528,(v=i,i=i+8|0,c[v>>2]=2627352,v)|0);i=v;KIb(q,32,2107984,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-22;i=b;return w|0}}while(0);c[m+32>>2]=c[a+120>>2];c[m+36>>2]=c[a+124>>2];r=c[a+224>>2]|0;z=c[a+228>>2]|0;xKb(d,e,r,(r|0)<0|0?-1:0,z,(z|0)<0|0?-1:0,4096,0)|0;c[m+60>>2]=c[d>>2];c[m+56>>2]=c[e>>2];e=a+108|0;c[m+800>>2]=c[e>>2];d=a+104|0;c[m+796>>2]=c[d>>2];c[m+788>>2]=c[e>>2];c[m+792>>2]=ca(c[a+112>>2]|0,c[d>>2]|0)|0;c[m+620>>2]=c[o>>2]&32768;c[m+8>>2]=c[a+808>>2];d=c[a+812>>2]|0;if((d|0)!=0){c[m+16>>2]=(d|0)==2}c[m+164>>2]=c[o>>2]&262144;c[m+132>>2]=(c[o>>2]|0)>>>31^1;c[m+848>>2]=c[a+404>>2];if(((c[s>>2]|0)-12|0)>>>0<3>>>0){A=1}else{A=(c[a+396>>2]|0)==2|0}c[m+72>>2]=A;A=c[a+392>>2]|0;if((A|0)!=2){c[m+84>>2]=A}A=c[a+384>>2]|0;if((A|0)!=2){c[m+76>>2]=A}A=c[a+388>>2]|0;if((A|0)!=2){c[m+80>>2]=A}if((c[o>>2]&4194304|0)!=0){c[m+768>>2]=0}A=c[m+1096>>2]|0;b:do{if((A|0)!=0){s=f|0;d=h|0;e=A;while(1){mrc(s|0,0,256)|0;mrc(d|0,0,256)|0;z=Bd(e|0,2621768,(v=i,i=i+16|0,c[v>>2]=s,c[v+8>>2]=d,v)|0)|0;i=v;if((z|0)==1){B=JLb(n,s,2619232)|0;if((B|0)<0){C=162;break}}else{D=JLb(n,s,d)|0;if((D|0)<0){C=166;break}}z=_b(e|0,58)|0;e=z+((z|0)!=0)|0;if((e|0)==0){break b}}if((C|0)==162){if((B|0)==-1){KIb(q,16,2105280,(v=i,i=i+16|0,c[v>>2]=s,c[v+8>>2]=2619232,v)|0);i=v;w=-1;i=b;return w|0}else{KIb(q,16,2644336,(v=i,i=i+16|0,c[v>>2]=s,c[v+8>>2]=2619232,v)|0);i=v;w=-1;i=b;return w|0}}else if((C|0)==166){if((D|0)==-1){KIb(q,16,2105280,(v=i,i=i+16|0,c[v>>2]=s,c[v+8>>2]=d,v)|0);i=v;w=-1;i=b;return w|0}else{KIb(q,16,2644336,(v=i,i=i+16|0,c[v>>2]=s,c[v+8>>2]=d,v)|0);i=v;w=-1;i=b;return w|0}}}}while(0);D=m+1208|0;do{if((c[D>>2]|0)!=0){c[j>>2]=0;if((NGb(j,c[D>>2]|0,2612752,2609048,0)|0)!=0){break}C=LGb(c[j>>2]|0,10230736,0,2)|0;if((C|0)!=0){B=C;do{C=B|0;A=B+4|0;if((JLb(n,c[C>>2]|0,c[A>>2]|0)|0)<0){h=c[A>>2]|0;KIb(q,24,2603896,(v=i,i=i+16|0,c[v>>2]=c[C>>2],c[v+8>>2]=h,v)|0);i=v}B=LGb(c[j>>2]|0,10230736,B,2)|0;}while((B|0)!=0)}OGb(j)}}while(0);if((c[m+116>>2]|0)==0){E=0}else{E=(c[m+128>>2]|0)!=0?2:1}c[a+176>>2]=E;if((c[p>>2]|0)<0){c[p>>2]=0}c[x>>2]=(c[m+648>>2]|0)*1e3|0;x=ULb(n)|0;n=m+864|0;c[n>>2]=x;if((x|0)==0){w=-1;i=b;return w|0}x=UHb()|0;c[a+804>>2]=x;if((x|0)==0){w=-12;i=b;return w|0}if((c[o>>2]&4194304|0)==0){w=0;i=b;return w|0}o=hJb(_Lb(c[n>>2]|0,k,l)|0)|0;n=a+96|0;c[n>>2]=o;if((c[l>>2]|0)>0){x=m+1068|0;p=m+1064|0;m=o;E=0;j=c[k>>2]|0;while(1){D=c[j+(E<<5)+24>>2]|0;if((c[j+(E<<5)+4>>2]|0)==6){KIb(q,32,2601880,(v=i,i=i+8|0,c[v>>2]=D+25,v)|0);i=v;B=c[(c[k>>2]|0)+(E<<5)+20>>2]|0;c[x>>2]=B;d=hJb(B)|0;c[p>>2]=d;B=c[k>>2]|0;nrc(d|0,c[B+(E<<5)+24>>2]|0,c[B+(E<<5)+20>>2]|0)|0;F=m;G=B}else{nrc(m|0,D|0,c[j+(E<<5)+20>>2]|0)|0;D=c[k>>2]|0;F=m+(c[D+(E<<5)+20>>2]|0)|0;G=D}D=E+1|0;if((D|0)<(c[l>>2]|0)){m=F;E=D;j=G}else{break}}H=F;I=c[n>>2]|0}else{H=o;I=o}c[a+100>>2]=H-I;w=0;i=b;return w|0}function dPa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+208|0;g=f|0;h=f+8|0;j=f+16|0;k=a+60|0;l=c[k>>2]|0;mrc(j|0,0,192)|0;m=l+872|0;n=m;LLb(n);o=l+4|0;p=c[l+40>>2]|0;q=l+908|0;c[q>>2]=p;if((c[27428]|0)>8){c[q>>2]=p|8192}p=l+912|0;c[p>>2]=((c[a+140>>2]|0)-2|0)>>>0<2>>>0?1:3;q=(d|0)!=0;do{if(q){r=l+932|0;s=l+916|0;t=0;do{c[r+(t<<2)>>2]=c[d+(t<<2)>>2];c[s+(t<<2)>>2]=c[d+32+(t<<2)>>2];t=t+1|0;}while((t|0)<(c[p>>2]|0));t=d+136|0;s=c[t+4>>2]|0;r=l+888|0;c[r>>2]=c[t>>2];c[r+4>>2]=s;s=c[d+88>>2]|0;do{if((s|0)==1){u=6}else{if((s|0)==2){u=3;break}u=(s|0)==3?5:0}}while(0);c[m>>2]=u;do{if((c[l+164>>2]|0)!=0){s=l+804|0;r=c[d+300>>2]|0;if((c[s>>2]|0)==(r|0)){break}c[s>>2]=r;ZLb(c[l+864>>2]|0,o)|0}}while(0);r=l+56|0;s=a+224|0;t=c[a+228>>2]|0;if((c[r>>2]|0)==(t|0)){v=l+60|0;w=s|0;if((c[v>>2]|0)!=(c[w>>2]|0)){x=w;y=v;z=16}}else{x=s|0;y=l+60|0;z=16}if((z|0)==16){c[r>>2]=t;c[y>>2]=c[x>>2];ZLb(c[l+864>>2]|0,o)|0}t=fIb(d,2)|0;do{if((t|0)!=0){switch(c[c[t+4>>2]>>2]|0){case 3:{A=5;break};case 4:{A=0;break};case 1:{A=3;break};case 2:{A=4;break};case 6:{A=1;break};case 7:{A=2;break};default:{A=-1}}r=l+760|0;if((A|0)==(c[r>>2]|0)){break}c[r>>2]=A;ZLb(c[l+864>>2]|0,o)|0}}while(0);t=l+864|0;r=q?n:0;if(!q){B=t;C=r;z=28;break}if((aMb(c[t>>2]|0,g,h,r,j)|0)<0){D=-1;i=f;return D|0}else{r=c[h>>2]|0;if((r|0)==0){E=0;F=0;break}else{G=r;z=33;break}}}else{B=l+864|0;C=0;z=28}}while(0);a:do{if((z|0)==28){while(1){if((aMb(c[B>>2]|0,g,h,C,j)|0)<0){D=-1;break}l=c[h>>2]|0;if((l|0)!=0){G=l;z=33;break a}if((fMb(c[B>>2]|0)|0)==0){E=0;F=0;break a}}i=f;return D|0}}while(0);do{if((z|0)==33){B=c[k>>2]|0;h=c[g>>2]|0;C=B+1068|0;l=c[C>>2]|0;q=(G|0)>0;if(q){n=0;o=l;while(1){A=(c[h+(n<<5)+20>>2]|0)+o|0;d=n+1|0;if((d|0)<(G|0)){n=d;o=A}else{H=A;break}}}else{H=l}if((d5a(a,b,H,(H|0)<0|0?-1:0)|0)<0){D=-1;i=f;return D|0}o=c[b+24>>2]|0;n=c[C>>2]|0;do{if((n|0)>0&q){if((n|0)<=(H|0)){A=B+1064|0;nrc(o|0,c[A>>2]|0,n)|0;d=o+(c[C>>2]|0)|0;c[C>>2]=0;mJb(A);I=d;break}KIb(a,16,2114712,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;D=-1;i=f;return D|0}else{I=o}}while(0);if(q){J=I;K=0}else{E=1;F=1;break}while(1){o=h+(K<<5)+20|0;nrc(J|0,c[h+(K<<5)+24>>2]|0,c[o>>2]|0)|0;C=K+1|0;if((C|0)<(G|0)){J=J+(c[o>>2]|0)|0;K=C}else{E=1;F=1;break}}}}while(0);K=j+16|0;J=c[K+4>>2]|0;G=b+8|0;c[G>>2]=c[K>>2];c[G+4>>2]=J;J=j+24|0;G=c[J+4>>2]|0;K=b+16|0;c[K>>2]=c[J>>2];c[K+4>>2]=G;switch(c[j>>2]|0){case 5:case 4:{c[(c[a+804>>2]|0)+88>>2]=3;break};case 3:{c[(c[a+804>>2]|0)+88>>2]=2;break};case 1:case 2:{c[(c[a+804>>2]|0)+88>>2]=1;break};default:{}}G=b+36|0;c[G>>2]=c[G>>2]|c[j+12>>2];if(F){c[(c[a+804>>2]|0)+168>>2]=((c[j+4>>2]|0)*118|0)-118}c[e>>2]=E;D=0;i=f;return D|0}function ePa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;mJb(a+96|0);kJb(c[b+1064>>2]|0);d=c[b+864>>2]|0;if((d|0)==0){e=a+804|0;VHb(e);return 0}eMb(d);e=a+804|0;VHb(e);return 0}function fPa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>3>>>0){return}LIb(a,c[2653728+(b<<2)>>2]|0,d,e);return}function gPa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;e=c[a+140>>2]|0;do{if((e|0)==0|(e|0)==4|(e|0)==5){if(!((c[a+680>>2]|0)>-1)){break}KIb(a,16,2361552,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=b;return g|0}}while(0);e=UHb()|0;c[a+804>>2]=e;if((e|0)==0){g=-12;i=b;return g|0}c[e+88>>2]=1;c[e+84>>2]=1;e=(c[a+120>>2]|0)+1|0;if(e>>>0>268435454>>>0){h=0}else{h=hJb(e<<3)|0}c[d+1600>>2]=h;l8(d,a);L6(d+1128|0,d+1244|0,1242080);uQa(a,d+1516|0,d+1504|0);eQa(d+1576|0,d+1528|0,1965720,1965368);eQa(d+1588|0,d+1552|0,1965744,1965368);g=0;i=b;return g|0}function hPa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;k=i;i=i+72|0;l=k|0;m=k+16|0;n=k+32|0;o=k+48|0;p=f+60|0;q=c[p>>2]|0;r=f+120|0;s=c[r>>2]|0;t=f+124|0;u=c[t>>2]|0;v=c[q+1516>>2]|0;w=c[q+1504>>2]|0;x=f+140|0;y=c[x>>2]|0;if((y|0)==298|(y|0)==30|(y|0)==3){z=ca(s*12|0,u)|0}else{z=ca(ca(ca(v*12|0,w)|0,(u-1+w|0)/(w|0)|0)|0,(s-1+v|0)/(v|0)|0)|0}v=z+16384|0;z=d5a(f,g,v,(v|0)<0|0?-1:0)|0;if((z|0)<0){A=z;i=k;return A|0}z=g+28|0;v=c[z>>2]|0;s=(v|0)<0;w=s?0:c[g+24>>2]|0;u=s?0:v;c[o+20>>2]=u<<3;v=o+8|0;c[v>>2]=w;s=o+16|0;c[s>>2]=w+u;u=o+12|0;c[u>>2]=w;w=o+4|0;c[w>>2]=32;y=o|0;c[y>>2]=0;B=q+1376|0;vQa(f,o,q+1244|0,B,B);B=c[w>>2]|0;q=c[v>>2]|0;C=c[u>>2]|0;D=(C-q<<3)+(32-B)|0;E=c[x>>2]|0;a:do{if((E|0)==298|(E|0)==30|(E|0)==3){F=c[p>>2]|0;G=c[h+68>>2]|0;H=c[h+72>>2]|0;I=c[h+32>>2]|0;J=c[F+1600>>2]|0;K=c[f+216>>2]|0;L=J|0;b[L>>1]=256;M=J+2|0;b[M>>1]=256;N=J+4|0;b[N>>1]=256;O=K+1|0;if((H|0)<=0){break}K=h|0;P=G*12|0;Q=(G|0)>0;R=F+1576|0;S=F+1528|0;T=F+1588|0;U=F+1552|0;F=n|0;V=l|0;W=m|0;X=n+4|0;Y=l+4|0;Z=m+4|0;_=n+8|0;$=l+8|0;aa=m+8|0;ba=0;da=q;ea=B;fa=C;while(1){ga=(ba|0)!=0?O:1;ha=c[K>>2]|0;ia=ca(ba,I)|0;ja=da;if(((c[s>>2]|0)-ja-(32-ea+(fa-ja<<3)>>3)|0)<(P|0)){break}ja=e[L>>1]|0;c[F>>2]=ja;c[V>>2]=ja;c[W>>2]=ja;ja=e[M>>1]|0;c[X>>2]=ja;c[Y>>2]=ja;c[Z>>2]=ja;ja=e[N>>1]|0;c[_>>2]=ja;c[$>>2]=ja;c[aa>>2]=ja;if(Q){ja=ia+1|0;ka=ia+2|0;la=(ga|0)==0;ma=0;while(1){if((c[x>>2]|0)==3){na=ma*3|0;oa=ha+(na+ia)|0;pa=ha+(ja+na)|0;b[J+(ma<<3)+2>>1]=(d[oa]|0|256)-(d[pa]|0);qa=ha+(ka+na)|0;b[J+(ma<<3)+4>>1]=(d[qa]|0|256)-(d[pa]|0);na=(((d[pa]|0)<<1)+(d[oa]|0)+(d[qa]|0)|0)>>>2&65535;b[J+(ma<<3)>>1]=na;ra=na}else{na=ma<<2;qa=ha+(na+ia)|0;oa=ha+((na|1)+ia)|0;b[J+(ma<<3)+2>>1]=(d[qa]|0|256)-(d[oa]|0);pa=ha+((na|2)+ia)|0;b[J+(ma<<3)+4>>1]=(d[pa]|0|256)-(d[oa]|0);na=(((d[oa]|0)<<1)+(d[qa]|0)+(d[pa]|0)|0)>>>2&65535;b[J+(ma<<3)>>1]=na;ra=na}na=ma+1|0;b:do{if(la){c[F>>2]=c[W>>2];c[W>>2]=e[J+(na<<3)>>1]|0;pa=ra&65535;c[V>>2]=pa;zQa(o,(pa+256&511)-256|0,R,S);c[X>>2]=c[Z>>2];c[Z>>2]=e[J+(na<<3)+2>>1]|0;pa=e[J+(ma<<3)+2>>1]|0;c[Y>>2]=pa;zQa(o,(pa+256&511)-256|0,T,U);c[_>>2]=c[aa>>2];c[aa>>2]=e[J+(na<<3)+4>>1]|0;pa=e[J+(ma<<3)+4>>1]|0;c[$>>2]=pa;zQa(o,(pa+256&511)-256|0,T,U)}else{pa=0;while(1){switch(ga|0){case 2:{sa=c[m+(pa<<2)>>2]|0;break};case 4:{sa=(c[m+(pa<<2)>>2]|0)+(c[l+(pa<<2)>>2]|0)-(c[n+(pa<<2)>>2]|0)|0;break};case 3:{sa=c[n+(pa<<2)>>2]|0;break};case 6:{sa=((c[l+(pa<<2)>>2]|0)-(c[n+(pa<<2)>>2]|0)>>1)+(c[m+(pa<<2)>>2]|0)|0;break};case 1:{sa=c[l+(pa<<2)>>2]|0;break};case 0:{sa=0;break};case 5:{sa=((c[m+(pa<<2)>>2]|0)-(c[n+(pa<<2)>>2]|0)>>1)+(c[l+(pa<<2)>>2]|0)|0;break};default:{sa=(c[m+(pa<<2)>>2]|0)+(c[l+(pa<<2)>>2]|0)>>1}}qa=m+(pa<<2)|0;c[n+(pa<<2)>>2]=c[qa>>2];c[qa>>2]=e[J+(na<<3)+(pa<<1)>>1]|0;qa=e[J+(ma<<3)+(pa<<1)>>1]|0;c[l+(pa<<2)>>2]=qa;oa=(256-sa+qa&511)-256|0;if((pa|0)==0){zQa(o,oa,R,S);pa=1;continue}else{zQa(o,oa,T,U);oa=pa+1|0;if((oa|0)<3){pa=oa;continue}else{break b}}}}}while(0);if((na|0)<(G|0)){ma=na}else{break}}}ma=ba+1|0;if((ma|0)>=(H|0)){break a}ba=ma;da=c[v>>2]|0;ea=c[w>>2]|0;fa=c[u>>2]|0}KIb(f,16,2450872,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;A=-1;i=k;return A|0}else{fa=c[f+216>>2]|0;ea=c[p>>2]|0;da=ea;ba=ea+1516|0;H=c[ba>>2]|0;G=((c[r>>2]|0)-1+H|0)/(H|0)|0;U=ea+1504|0;T=c[U>>2]|0;S=((c[t>>2]|0)-1+T|0)/(T|0)|0;if((S|0)<=0){break}R=G*12|0;J=(G|0)>0;$=ea+1576|0;aa=ea+1528|0;_=ea+1588|0;Y=ea+1552|0;ea=0;Z=H;H=T;T=q;X=B;V=C;while(1){W=T;if(((c[s>>2]|0)-W-(32-X+(V-W<<3)>>3)|0)<(ca(ca(R,H)|0,Z)|0)){break}if(J){W=(ea|0)==0;F=0;do{Q=(F|0)==0;if(Q|W){N=Q^1;Q=0;do{M=c[da+1516+(Q<<2)>>2]|0;L=c[da+1504+(Q<<2)>>2]|0;P=c[h+32+(Q<<2)>>2]|0;if((L|0)>0){I=(M|0)>0;K=h+(Q<<2)|0;O=ca(L,ea)|0;ma=ca(M,F)|0;ga=(Q|0)==0;la=~P;ia=0;do{if(I){ha=(ca(ia+O|0,P)|0)+ma|0;ka=(ia|ea|0)==0;ja=0;do{pa=c[K>>2]|0;oa=ha+ja|0;qa=pa+oa|0;ua=(ja|0)!=0|N;c:do{if(ka){if(!ua){va=128;break}va=d[pa+(oa-1)|0]|0}else{if(!ua){va=d[pa+(oa-P)|0]|0;break}switch(fa|0){case 0:{va=d[pa+(oa-1)|0]|0;break c;break};case 4:{va=((d[pa+(oa-P)|0]|0)-(d[pa+(oa+la)|0]|0)>>1)+(d[pa+(oa-1)|0]|0)|0;break c;break};case 2:{va=d[pa+(oa+la)|0]|0;break c;break};case 1:{va=d[pa+(oa-P)|0]|0;break c;break};case 3:{va=(d[pa+(oa-P)|0]|0)+(d[pa+(oa-1)|0]|0)-(d[pa+(oa+la)|0]|0)|0;break c;break};case 5:{va=((d[pa+(oa-1)|0]|0)-(d[pa+(oa+la)|0]|0)>>1)+(d[pa+(oa-P)|0]|0)|0;break c;break};case-1:{va=0;break c;break};default:{va=((d[pa+(oa-P)|0]|0)+(d[pa+(oa-1)|0]|0)|0)>>>1;break c}}}}while(0);oa=(d[qa]|0)-va|0;if(ga){zQa(o,oa,$,aa)}else{zQa(o,oa,_,Y)}ja=ja+1|0;}while((ja|0)<(M|0))}ia=ia+1|0;}while((ia|0)<(L|0))}Q=Q+1|0;}while((Q|0)<3)}else{Q=0;do{N=c[da+1516+(Q<<2)>>2]|0;na=c[da+1504+(Q<<2)>>2]|0;L=c[h+32+(Q<<2)>>2]|0;if((na|0)>0){ia=(N|0)>0;M=h+(Q<<2)|0;ga=ca(na,ea)|0;P=ca(N,F)|0;la=(Q|0)==0;K=~L;ma=0;do{d:do{if(ia){O=(ca(ma+ga|0,L)|0)+P|0;I=0;while(1){ja=c[M>>2]|0;ka=O+I|0;switch(fa|0){case 3:{wa=(d[ja+(ka-L)|0]|0)+(d[ja+(ka-1)|0]|0)-(d[ja+(ka+K)|0]|0)|0;break};case 4:{wa=((d[ja+(ka-L)|0]|0)-(d[ja+(ka+K)|0]|0)>>1)+(d[ja+(ka-1)|0]|0)|0;break};case 1:{wa=d[ja+(ka-L)|0]|0;break};case 2:{wa=d[ja+(ka+K)|0]|0;break};case 0:{wa=d[ja+(ka-1)|0]|0;break};case-1:{wa=0;break};case 5:{wa=((d[ja+(ka-1)|0]|0)-(d[ja+(ka+K)|0]|0)>>1)+(d[ja+(ka-L)|0]|0)|0;break};default:{wa=((d[ja+(ka-L)|0]|0)+(d[ja+(ka-1)|0]|0)|0)>>>1}}ha=(d[ja+ka|0]|0)-wa|0;if(la){zQa(o,ha,$,aa)}else{zQa(o,ha,_,Y)}I=I+1|0;if((I|0)>=(N|0)){break d}}}}while(0);ma=ma+1|0;}while((ma|0)<(na|0))}Q=Q+1|0;}while((Q|0)<3)}F=F+1|0;}while((F|0)<(G|0))}F=ea+1|0;if((F|0)>=(S|0)){break a}ea=F;Z=c[ba>>2]|0;H=c[U>>2]|0;T=c[v>>2]|0;X=c[w>>2]|0;V=c[u>>2]|0}KIb(f,16,2450872,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;A=-1;i=k;return A|0}}while(0);wQa(o,D>>3);yQa(o,D);D=c[w>>2]|0;if((D|0)<32){o=c[y>>2]<<D;c[y>>2]=o;D=o>>>24&255;while(1){o=c[u>>2]|0;c[u>>2]=o+1;a[o]=D;o=c[y>>2]|0;c[y>>2]=o<<8;ta=(c[w>>2]|0)+8|0;c[w>>2]=ta;if((ta|0)<32){D=o>>>16&255}else{break}}}c[w>>2]=32;c[y>>2]=0;c[z>>2]=(c[u>>2]|0)-(c[v>>2]|0);v=g+36|0;c[v>>2]=c[v>>2]|1;c[j>>2]=1;A=0;i=k;return A|0}function iPa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(a+804|0);mJb(b+1600|0);return 0}function jPa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=c[a+100>>2]|0;if((f|0)<12){KIb(a,16,2204528,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-1094995529;i=b;return h|0}f=a+96|0;j=c[f>>2]|0;k=j;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;if((l|0)==2){k=j+8|0;c[e+4>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;m=j}else if((l|0)==1){c[e+4>>2]=0;m=j}else{k=j+8|0;c[e+4>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;QIb(a,2172512,(g=i,i=i+8|0,c[g>>2]=l,g)|0);i=g;m=c[f>>2]|0}f=m+4|0;m=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[e+8>>2]=m;switch(m|0){case-1:case 1:case 2:{c[a+140>>2]=4;break};case-3:case 4:{c[a+140>>2]=30;break};case-2:case 3:{c[a+140>>2]=3;break};case-4:case 5:{c[a+140>>2]=0;break};default:{KIb(a,32,2144960,(g=i,i=i+8|0,c[g>>2]=m,g)|0);i=g;h=-1094995529;i=b;return h|0}}if((c[a+688>>2]&1|0)==0){h=0;i=b;return h|0}KIb(a,32,2121224,(g=i,i=i+24|0,c[g>>2]=c[e+4>>2],c[g+8>>2]=l,c[g+16>>2]=m,g)|0);i=g;h=0;i=b;return h|0}function kPa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;g=c[a+60>>2]|0;h=g;j=c[e+24>>2]|0;k=e+28|0;e=c[k>>2]|0;l=M4a(a,b,0)|0;if((l|0)<0){m=l;i=f;return m|0}c[b+84>>2]=1;a:do{switch(c[g+8>>2]|0){case-1:case 1:case 2:{l=a+120|0;n=a+124|0;o=lPa(h,c[b>>2]|0,c[l>>2]|0,c[n>>2]|0,c[b+32>>2]|0,j,e,1)|0;if(!((o|0)>-1&(o|0)<(e|0))){break a}p=e-o|0;q=lPa(h,c[b+4>>2]|0,(c[l>>2]|0)/2|0,c[n>>2]|0,c[b+36>>2]|0,j+o|0,p,1)|0;if(!((q|0)>-1&(q|0)<(p|0))){break a}r=p-q|0;s=lPa(h,c[b+8>>2]|0,(c[l>>2]|0)/2|0,c[n>>2]|0,c[b+40>>2]|0,j+(q+o)|0,r,1)|0;t=r;u=17;break};case-3:case 4:{r=b;o=b+32|0;q=c[o>>2]|0;n=a+124|0;l=c[n>>2]|0;p=a+120|0;v=lPa(h,(c[r>>2]|0)+(ca(l-1|0,q)|0)|0,c[p>>2]|0,l,-q|0,j,e,4)|0;if(!((v|0)>-1&(v|0)<(e|0))){break a}q=e-v|0;l=c[o>>2]|0;w=c[n>>2]|0;x=lPa(h,(c[r>>2]|0)+((ca(w-1|0,l)|0)+1)|0,c[p>>2]|0,w,-l|0,j+v|0,q,4)|0;if(!((x|0)>-1&(x|0)<(q|0))){break a}l=x+v|0;v=q-x|0;x=c[o>>2]|0;q=c[n>>2]|0;w=lPa(h,(c[r>>2]|0)+((ca(q-1|0,x)|0)+2)|0,c[p>>2]|0,q,-x|0,j+l|0,v,4)|0;if(!((w|0)>-1&(w|0)<(v|0))){break a}x=v-w|0;v=c[o>>2]|0;o=c[n>>2]|0;s=lPa(h,(c[r>>2]|0)+((ca(o-1|0,v)|0)+3)|0,c[p>>2]|0,o,-v|0,j+(w+l)|0,x,4)|0;t=x;u=17;break};case-2:case 3:{x=b;l=b+32|0;w=c[l>>2]|0;v=a+124|0;o=c[v>>2]|0;p=a+120|0;r=lPa(h,(c[x>>2]|0)+(ca(o-1|0,w)|0)|0,c[p>>2]|0,o,-w|0,j,e,3)|0;if(!((r|0)>-1&(r|0)<(e|0))){break a}w=e-r|0;o=c[l>>2]|0;n=c[v>>2]|0;q=lPa(h,(c[x>>2]|0)+((ca(n-1|0,o)|0)+1)|0,c[p>>2]|0,n,-o|0,j+r|0,w,3)|0;if(!((q|0)>-1&(q|0)<(w|0))){break a}o=w-q|0;w=c[l>>2]|0;l=c[v>>2]|0;s=lPa(h,(c[x>>2]|0)+((ca(l-1|0,w)|0)+2)|0,c[p>>2]|0,l,-w|0,j+(q+r)|0,o,3)|0;t=o;u=17;break};case-4:case 5:{o=a+120|0;r=a+124|0;q=lPa(h,c[b>>2]|0,c[o>>2]|0,c[r>>2]|0,c[b+32>>2]|0,j,e,1)|0;if(!((q|0)>-1&(q|0)<(e|0))){break a}w=e-q|0;l=lPa(h,c[b+8>>2]|0,(c[o>>2]|0)/2|0,(c[r>>2]|0)/2|0,c[b+40>>2]|0,j+q|0,w,1)|0;if(!((l|0)>-1&(l|0)<(w|0))){break a}p=w-l|0;s=lPa(h,c[b+4>>2]|0,(c[o>>2]|0)/2|0,(c[r>>2]|0)/2|0,c[b+36>>2]|0,j+(l+q)|0,p,1)|0;t=p;u=17;break};default:{KIb(0,0,2450840,(y=i,i=i+24|0,c[y>>2]=2361544,c[y+8>>2]=2297112,c[y+16>>2]=235,y)|0);i=y;Hd();return 0}}}while(0);do{if((u|0)==17){if((s|0)<0|(s|0)>(t|0)){break}c[d>>2]=1;m=s-t+(c[k>>2]|0)|0;i=f;return m|0}}while(0);KIb(a,16,2246240,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;m=-22;i=f;return m|0}function lPa(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=i;i=i+48|0;n=m|0;if((k|0)<1){o=-1;i=m;return o|0}p=k>>>0>268435455>>>0?-8:k<<3;k=p>>>0>2147483639>>>0|(j|0)==0;q=k?0:j;j=k?0:p;c[n>>2]=q;c[n+12>>2]=j;c[n+16>>2]=j+8;c[n+4>>2]=q+(j>>3);j=n+8|0;c[j>>2]=0;c[n+20>>2]=0;c[n+24>>2]=0;c[n+28>>2]=0;c[n+40>>2]=c[b+4>>2];c[n+32>>2]=8;c[n+36>>2]=1;a[e]=(mPa(n)|0)+128;b=(f|0)>1;if(b){q=1;do{p=mPa(n)|0;k=ca(q,l)|0;a[e+k|0]=(d[e+(k-l)|0]|0)+p;q=q+1|0;}while((q|0)<(f|0))}q=e+h|0;a:do{if((g|0)>1){p=l+h|0;if(b){r=e;s=1;t=q}else{k=e;u=1;v=q;while(1){w=mPa(n)|0;a[v]=(d[k]|0)+w;w=u+1|0;if((w|0)<(g|0)){k=v;u=w;v=v+h|0}else{break a}}}while(1){v=mPa(n)|0;a[t]=(d[r]|0)+v;v=1;do{u=mPa(n)|0;k=ca(v,l)|0;w=k+h|0;x=r+w|0;y=d[r+k|0]|0;k=d[r+(w-l)|0]|0;z=k+y-(d[r+(w-p)|0]|0)|0;do{if((y|0)>(z|0)){if((k|0)<=(z|0)){A=z;break}A=k>>>0>y>>>0?y:k}else{if((z|0)<=(k|0)){A=z;break}A=k>>>0>y>>>0?k:y}}while(0);a[x]=A+u;v=v+1|0;}while((v|0)<(f|0));v=s+1|0;if((v|0)<(g|0)){r=t;s=v;t=t+h|0}else{break}}}}while(0);o=(c[j>>2]|0)+7>>3;i=m;return o|0}function mPa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a+24|0;d=c[b>>2]|0;if((d|0)>0){c[b>>2]=d-1;d=a+32|0;e=c[d>>2]|0;f=a+36|0;g=(c[f>>2]|0)+1|0;c[f>>2]=g;if((g|0)!=16){h=0;return h|0}c[d>>2]=e>>1;c[f>>2]=8;h=0;return h|0}f=a|0;e=a+36|0;d=c[e>>2]|0;g=a+32|0;i=c[g>>2]|0;if((i|0)>(d|0)){j=0;k=d;while(1){d=k<<1;l=j+1|0;if((i|0)>(d|0)&(l|0)<9){j=l;k=d}else{m=l;break}}}else{m=0}k=nPa(f,m)|0;m=(k+1>>1)+(c[g>>2]|0)|0;c[g>>2]=m;j=(c[e>>2]|0)+1|0;c[e>>2]=j;if((j|0)==16){c[g>>2]=m>>1;c[e>>2]=8}if((k|0)!=0){e=(c[a+40>>2]|0)+(k>>1)^-(k&1);k=a+28|0;m=c[k>>2]|0;if((m|0)<=0){h=e;return h|0}g=a+20|0;c[g>>2]=(c[g>>2]|0)+((m|0)>2?m:-3);c[k>>2]=0;h=e;return h|0}e=a+20|0;if(!((c[e>>2]|0)>-1)){k=a+28|0;c[k>>2]=(c[k>>2]|0)+1;h=0;return h|0}k=nPa(f,2)|0;c[b>>2]=k;if((k|0)>1){c[e>>2]=k+1+(c[e>>2]|0);h=0;return h|0}else{c[e>>2]=(c[e>>2]|0)-3;h=0;return h|0}return 0}function nPa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=c[a>>2]|0;i=h+(f>>>3)|0;j=(je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(f&7);i=j>>>0>65535>>>0;k=i?j>>>16:j;l=i?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=(d[1359664+n|0]|0)+m|0;m=k-b|0;if(!((m|0)<7|(k|0)==-2147483615)){n=b+32+f-k|0;c[e>>2]=g>>>0>n>>>0?n:g;o=(j>>>(m>>>0))+(30-k<<b)|0;return o|0}do{if((j|0)>-1){k=c[a+12>>2]|0;m=f;n=0;do{if(!(k>>>0>m>>>0)){o=-1;p=16;break}l=m+1|0;m=g>>>0>l>>>0?l:g;l=h+(m>>>3)|0;q=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7);n=n+1|0;}while((n|0)!=2147483647&(q|0)>-1);if((p|0)==16){return o|0}k=m+1|0;l=g>>>0>k>>>0?k:g;if((n|0)<2147483646){r=n;s=q;t=l;break}if((n|0)!=2147483646){o=-1;return o|0}c[e>>2]=l;o=0;return o|0}else{l=f+1|0;r=0;s=j;t=g>>>0>l>>>0?l:g}}while(0);if((b|0)==0){u=t;v=0}else{j=t+b|0;u=g>>>0>j>>>0?j:g;v=s<<1>>>((32-b|0)>>>0)}c[e>>2]=u;o=v+(r<<b)|0;return o|0}function oPa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0,s=0.0,t=0.0;f=i;i=i+776|0;g=f|0;j=f+256|0;k=f+512|0;l=a|0;m=a+16|0;ef[c[a+20>>2]&4095](b,c[l>>2]|0,c[m>>2]|0);b=k|0;mf[c[a+24>>2]&2047](c[m>>2]|0,c[l>>2]|0,d,b);if((d|0)<=0){h[e>>3]=(-0.0-0.0)/+h[b>>3];i=f;return d|0}l=k+8|0;k=d<<3;nrc(j|0,l|0,k)|0;nrc(g|0,l|0,k)|0;k=j|0;n=+h[k>>3];o=+h[b>>3];p=(-0.0-n)/o;h[e>>3]=p;if((d|0)<=1){i=f;return d|0}b=1;q=o+n*p;o=n;n=p;while(1){l=d-b|0;if((l|0)>0){m=0;while(1){a=m+1|0;p=+h[j+(a<<3)>>3];r=g+(m<<3)|0;s=+h[r>>3];h[j+(m<<3)>>3]=p+n*s;h[r>>3]=n*p+s;if((a|0)<(l|0)){m=a}else{break}}t=+h[k>>3]}else{t=o}s=(-0.0-t)/q;h[e+(b<<3)>>3]=s;m=b+1|0;if((m|0)<(d|0)){b=m;q=q+t*s;o=t;n=s}else{break}}i=f;return d|0}function pPa(a,b,d,e,f,g,j,k,l,m,n,o,p){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0,P=0,Q=0,T=0.0,U=0,V=0.0,W=0.0,X=0,Y=0.0,Z=0,_=0.0,$=0,aa=0,ba=0,ca=0,da=0;q=i;i=i+46728|0;r=q|0;s=q+264|0;t=q+520|0;u=q+8712|0;v=q+46408|0;w=(l|0)==3;x=(l|0)==2;if(!((l-2|0)>>>0<2>>>0)){KIb(0,0,2519128,(y=i,i=i+24|0,c[y>>2]=2602280,c[y+8>>2]=2450816,c[y+16>>2]=185,y)|0);i=y;Hd();return 0}y=a|0;z=a+4|0;do{if((c[y>>2]|0)==(d|0)){if((c[z>>2]|0)!=(f|0)){A=6;break}if((c[a+8>>2]|0)!=(l|0)){A=6}}else{A=6}}while(0);do{if((A|0)==6){B=a+12|0;mJb(B);c[y>>2]=d;c[z>>2]=f;c[a+8>>2]=l;C=f+3&-4;D=pJb(d+2+C<<3)|0;E=D;c[B>>2]=E;if((D|0)==0){break}c[a+16>>2]=E+(C<<3);c[a+20>>2]=284;c[a+24>>2]=322}}while(0);l=(m|0)<1?2:m;if(x){A=10}else{if(w&(l|0)>1){A=10}else{F=0}}do{if((A|0)==10){x=a+16|0;ef[c[a+20>>2]&4095](b,d,c[x>>2]|0);m=r|0;mf[c[a+24>>2]&2047](c[x>>2]|0,d,f,m);x=t|0;z=(f|0)>0;if(!z){F=1;break}y=x;C=0;G=+h[m>>3];m=x;while(1){x=C+1|0;H=-0.0- +h[r+(x<<3)>>3];if((C|0)>0){E=0;I=H;while(1){J=I- +h[m+(E<<3)>>3]*+h[r+(C-E<<3)>>3];D=E+1|0;if((D|0)<(C|0)){E=D;I=J}else{K=J;break}}}else{K=H}I=K/G;J=G*(1.0-I*I);h[y+(C<<3)>>3]=I;E=x>>1;if((E|0)>0){D=C-1|0;B=0;do{L=+h[m+(B<<3)>>3];M=D-B|0;N=+h[m+(M<<3)>>3];h[y+(B<<3)>>3]=L+I*N;h[y+(M<<3)>>3]=N+I*L;B=B+1|0;}while((B|0)<(E|0))}if((x|0)<(f|0)){m=y;y=y+256|0;C=x;G=J}else{break}}if(z){O=0}else{F=1;break}while(1){h[s+(O<<3)>>3]=+R(+(+h[t+(O<<8)+(O<<3)>>3]));C=O+1|0;if((C|0)<(f|0)){O=C}else{F=1;break}}}}while(0);do{if(w){O=v+31&-32;r=O;mrc(O|0,0,288)|0;O=(f|0)>0;if(O){a=f-1|0;A=0;do{h[u+10368+(a<<8)+(A<<3)>>3]=-0.0- +h[t+(a<<8)+(A<<3)>>3];A=A+1|0;}while((A|0)<(f|0))}if((F|0)<(l|0)){A=(f|0)<(d|0);a=(f|0)<0;z=r+8|0;C=f-1|0;y=F;while(1){m=y&1;E=u+(m*18848|0)|0;CIb(E,f);a:do{if(A){B=(y|0)==0;D=u+(m*18848|0)+18820|0;M=u+(m*18848|0)+18824|0;P=u+((m^1)*18848|0)|0;K=+(512>>>(y>>>0)|0);if(a){G=0.0;Q=f;while(1){if(B){T=1.0}else{I=+Ye[c[M>>2]&3](P,z,C);T=1.0/(K+ +R(+(I- +h[r>>3])))}I=G+T;re[c[D>>2]&1023](E,r);U=Q+1|0;if((U|0)<(d|0)){G=I;Q=U}else{V=I;break a}}}else{W=0.0;X=f}while(1){Q=0;do{h[r+(Q<<3)>>3]=+(c[b+(X-Q<<2)>>2]|0);Q=Q+1|0;}while((Q|0)<=(f|0));b:do{if(B){Y=1.0}else{G=+Ye[c[M>>2]&3](P,z,C);I=+h[r>>3];H=1.0/(K+ +R(+(G-I)));G=+S(H);Q=0;L=I;while(1){h[r+(Q<<3)>>3]=G*L;U=Q+1|0;if((U|0)>(f|0)){Y=H;break b}Q=U;L=+h[r+(U<<3)>>3]}}}while(0);L=W+Y;re[c[D>>2]&1023](E,r);Q=X+1|0;if((Q|0)<(d|0)){W=L;X=Q}else{V=L;break}}}else{V=0.0}}while(0);BIb(E,.001,0);m=y+1|0;if((m|0)<(l|0)){y=m}else{Z=l;_=V;break}}}else{Z=F;_=0.0}if(O){y=Z&1^1;J=+(d-f|0);r=0;do{C=0;do{h[t+(r<<8)+(C<<3)>>3]=-0.0- +h[u+(y*18848|0)+10368+(r<<8)+(C<<3)>>3];C=C+1|0;}while((C|0)<(f|0));h[s+(r<<3)>>3]=J*+S(+h[u+(y*18848|0)+18560+(r<<3)>>3]/_)/4.0e3;r=r+1|0;}while((r|0)<(f|0))}r=f-1|0;if((r|0)>0){$=f;aa=r}else{break}while(1){r=s+(aa<<3)|0;h[r>>3]=+h[s+($-2<<3)>>3]- +h[r>>3];r=aa-1|0;if((r|0)>0){$=aa;aa=r}else{break}}}}while(0);aa=e-1|0;if((n|0)==0){n=f;while(1){$=n-1|0;if(($|0)<(aa|0)){ba=e;break}if(+h[s+($<<3)>>3]>.1){ba=n;break}else{n=$}}n=ba-1|0;sPa(t+(n<<8)|0,ba,g,j+(n<<7)|0,k+(n<<2)|0,o,p);ca=ba;i=q;return ca|0}else{if((aa|0)<(f|0)){da=aa}else{ca=f;i=q;return ca|0}while(1){aa=da+1|0;sPa(t+(da<<8)|0,aa,g,j+(da<<7)|0,k+(da<<2)|0,o,p);if((aa|0)<(f|0)){da=aa}else{ca=f;break}}i=q;return ca|0}return 0}function qPa(a){a=a|0;mJb(a+12|0);return}function rPa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[a>>2]=b;c[a+4>>2]=d;c[a+8>>2]=e;e=d+3&-4;d=pJb(b+2+e<<3)|0;b=d;c[a+12>>2]=b;if((d|0)==0){f=-12;return f|0}c[a+16>>2]=b+(e<<3);c[a+20>>2]=284;c[a+24>>2]=322;f=0;return f|0}function sPa(a,b,d,e,f,g,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var j=0,k=0,l=0.0,m=0,n=0.0,o=0.0,p=0,q=0.0,r=0.0,s=0,t=0,u=0;j=1<<d-1;d=j-1|0;k=(b|0)>0;if(k){l=0.0;m=0;while(1){n=+R(+(+h[a+(m<<3)>>3]));o=l>n?l:n;p=m+1|0;if((p|0)<(b|0)){l=o;m=p}else{q=o;break}}}else{q=0.0}if(+(1<<g|0)*q<1.0){c[f>>2]=i;mrc(e|0,0,b<<2|0)|0;return}l=+(d|0);i=g;while(1){r=+(1<<i|0);if(q*r>l&(i|0)>0){i=i-1|0}else{break}}do{if((i|0)==0&q>l){o=l/q;if(k){s=0}else{break}while(1){g=a+(s<<3)|0;h[g>>3]=o*+h[g>>3];g=s+1|0;if((g|0)<(b|0)){s=g}else{t=8;break}}}else{t=8}}while(0);do{if((t|0)==8){if(!k){break}s=1-j|0;q=0.0;g=0;while(1){l=q-r*+h[a+(g<<3)>>3];m=Lc(+l)|0;if((m|0)<(s|0)){u=s}else{u=(m|0)>(d|0)?d:m}c[e+(g<<2)>>2]=u;m=g+1|0;if((m|0)<(b|0)){q=l- +(u|0);g=m}else{break}}}}while(0);c[f>>2]=i;return}function tPa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0.0,g=0.0,i=0.0,j=0;e=b>>1;if((e|0)<=0){return}f=2.0/(+(b|0)+-1.0)- +(e|0);b=0;do{g=f+ +(b|0);i=1.0-g*g;j=e+~b|0;h[d+(j<<3)>>3]=i*+(c[a+(j<<2)>>2]|0);j=b+e|0;h[d+(j<<3)>>3]=i*+(c[a+(j<<2)>>2]|0);b=b+1|0;}while((b|0)<(e|0));return}function uPa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0.0;if((c|0)>0){e=0;while(1){if((e|0)<(b|0)){f=e;g=1.0;i=1.0;while(1){j=+h[a+(f<<3)>>3];k=f-e|0;l=g+j*+h[a+(k<<3)>>3];m=i+j*+h[a+(k-1<<3)>>3];k=f+1|0;if((k|0)<(b|0)){f=k;g=l;i=m}else{n=l;o=m;break}}}else{n=1.0;o=1.0}h[d+(e<<3)>>3]=n;h[d+((e|1)<<3)>>3]=o;f=e+2|0;if((f|0)<(c|0)){e=f}else{p=f;break}}}else{p=0}if((p|0)!=(c|0)){return}p=c-1|0;if((p|0)<(b|0)){e=p;o=1.0;while(1){p=e-c|0;n=o+(+h[a+(e<<3)>>3]*+h[a+(p<<3)>>3]+ +h[a+(e+1<<3)>>3]*+h[a+(p+1<<3)>>3]);p=e+2|0;if((p|0)<(b|0)){e=p;o=n}else{q=n;break}}}else{q=1.0}h[d+(c<<3)>>3]=q;return}function vPa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f-1|0;if((g|0)>0){h=0;do{i=h;while(1){j=a+(i<<1)|0;k=b[j>>1]|0;l=a+(i+1<<1)|0;m=b[l>>1]|0;if(!(k<<16>>16>m<<16>>16)){break}b[l>>1]=k;b[j>>1]=m;if((i|0)>0){i=i-1|0}else{break}}h=h+1|0;}while((h|0)<(g|0))}if((f|0)>0){h=0;i=d;while(1){d=a+(h<<1)|0;m=b[d>>1]|0;j=(m<<16>>16|0)>(i|0)?m:i&65535;b[d>>1]=j;d=h+1|0;if((d|0)<(f|0)){h=d;i=(j<<16>>16)+c|0}else{break}}}c=a+(g<<1)|0;g=b[c>>1]|0;b[c>>1]=(g<<16>>16|0)>(e|0)?e&65535:g;return}function wPa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0.0,f=0,h=0.0,i=0.0;if((c|0)>0){d=0;e=0.0}else{return}do{f=a+(d<<2)|0;h=+g[f>>2];i=e+b;e=h>i?h:i;g[f>>2]=e;d=d+1|0;}while((d|0)<(c|0));return}function xPa(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)>0){e=0}else{return}do{f=(b[c+(e<<1)>>1]|0)*20861|0;g=f>>>23&255;h=b[335912+(g<<1)>>1]|0;b[a+(e<<1)>>1]=((ca((b[335912+(g+1<<1)>>1]|0)-h|0,f>>>15&255)|0)>>>8)+h;e=e+1|0;}while((e|0)<(d|0));return}function yPa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((c|0)>0){d=0}else{return}do{h[a+(d<<3)>>3]=+U(+g[b+(d<<2)>>2]*6.283185307179586);d=d+1|0;}while((d|0)<(c|0));return}function zPa(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+96|0;g=f|0;h=f+48|0;c[g>>2]=4194304;j=-(b[d>>1]|0)<<8;k=g+4|0;c[k>>2]=j;l=(e|0)<2;if(l){m=j}else{j=2;while(1){n=c[g+(j-2<<2)>>2]|0;c[g+(j<<2)>>2]=n;o=b[d+((j<<1)-2<<1)>>1]|0;if((j|0)>1){p=o<<16>>16;q=o<<16>>16<0|0?-1:0;r=j;s=n;while(1){n=r-1|0;t=c[g+(n<<2)>>2]|0;u=Erc(t,(t|0)<0|0?-1:0,p,q)|0;v=G;w=wrc(c[g+(r-2<<2)>>2]|0,0,s,0)|0;x=xrc(w,G,u>>>14|v<<18,v>>>14|0<<18)|0;c[g+(r<<2)>>2]=x;if((n|0)>1){r=n;s=t}else{break}}}s=(c[k>>2]|0)-(o<<16>>16<<8)|0;c[k>>2]=s;r=j+1|0;if((r|0)>(e|0)){m=s;break}else{j=r}}}j=h|0;c[j>>2]=4194304;k=-(b[d+2>>1]|0)<<8;r=h+4|0;c[r>>2]=k;if(l){y=k}else{k=2;while(1){l=c[h+(k-2<<2)>>2]|0;c[h+(k<<2)>>2]=l;s=b[d+((k<<1)-1<<1)>>1]|0;if((k|0)>1){q=s<<16>>16;p=s<<16>>16<0|0?-1:0;t=k;n=l;while(1){l=t-1|0;x=c[h+(l<<2)>>2]|0;v=Erc(x,(x|0)<0|0?-1:0,q,p)|0;u=G;w=wrc(c[h+(t-2<<2)>>2]|0,0,n,0)|0;z=xrc(w,G,v>>>14|u<<18,u>>>14|0<<18)|0;c[h+(t<<2)>>2]=z;if((l|0)>1){t=l;n=x}else{break}}}n=(c[r>>2]|0)-(s<<16>>16<<8)|0;c[r>>2]=n;t=k+1|0;if((t|0)>(e|0)){y=n;break}else{k=t}}}b[a>>1]=4096;k=e+1|0;if((e|0)<=0){i=f;return}r=e<<1|1;e=1;d=c[j>>2]|0;j=m;m=y;while(1){y=m-d|0;t=j+1024+(c[g+(e-1<<2)>>2]|0)|0;b[a+(e<<1)>>1]=(y+t|0)>>>11;b[a+(r-e<<1)>>1]=(t-y|0)>>>11;y=e+1|0;if((y|0)>=(k|0)){break}e=y;d=m;j=c[g+(y<<2)>>2]|0;m=c[h+(y<<2)>>2]|0}i=f;return}function APa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,j=0,k=0,l=0.0,m=0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,F=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0,L=0.0,M=0;d=i;i=i+176|0;e=d|0;f=d+88|0;j=c>>1;k=e+8|0;h[e>>3]=0.0;h[f>>3]=1.0;l=+h[a>>3]*-2.0;m=f+8|0;h[m>>3]=l;a:do{if((j|0)<2){n=l}else{o=2;p=l;q=1.0;while(1){r=+h[a+((o<<1)-2<<3)>>3]*-2.0;s=o-1|0;t=f+(s<<3)|0;u=f+(o<<3)|0;h[u>>3]=q*2.0+p*r;do{if((s|0)>1){v=o-2|0;w=+h[f+(o-3<<3)>>3];h[t>>3]=p+(r*q+w);if((v|0)>1){x=v;y=w}else{break}while(1){v=f+(x<<3)|0;z=x-1|0;w=+h[f+(x-2<<3)>>3];h[v>>3]=+h[v>>3]+(r*y+w);if((z|0)>1){x=z;y=w}else{break}}}}while(0);w=r+ +h[m>>3];h[m>>3]=w;s=o+1|0;if((s|0)>(j|0)){n=w;break a}o=s;p=+h[u>>3];q=+h[t>>3]}}}while(0);m=j-1|0;h[k>>3]=1.0;y=+h[a+8>>3]*-2.0;k=e+16|0;h[k>>3]=y;b:do{if((m|0)>=2){x=2;l=y;q=1.0;while(1){p=+h[a+((x<<1)-1<<3)>>3]*-2.0;o=x-1|0;s=e+(x<<3)|0;z=x+1|0;v=e+(z<<3)|0;h[v>>3]=q*2.0+l*p;do{if((o|0)>1){A=x-2|0;w=+h[e+(A<<3)>>3];h[s>>3]=l+(p*q+w);if((A|0)>1){B=o;C=A;D=w}else{break}while(1){A=C-1|0;w=+h[e+(A<<3)>>3];h[e+(C+1<<3)>>3]=+h[e+(B<<3)>>3]+(p*D+w);if((A|0)>1){B=C;C=A;D=w}else{break}}}}while(0);h[k>>3]=p+ +h[k>>3];if((z|0)>(m|0)){break b}x=z;l=+h[v>>3];q=+h[s>>3]}}}while(0);k=c-1|0;D=+h[a+(k<<3)>>3];if((j|0)<=1){E=D+1.0;F=f+(j<<3)|0;G=+h[F>>3];H=E*G;I=H*.5;J=I;K=b+(m<<2)|0;g[K>>2]=J;L=D;M=b+(k<<2)|0;g[M>>2]=L;i=d;return}y=D+1.0;q=1.0-D;a=k;c=1;l=n;while(1){n=l*y;C=c+1|0;B=c-1|0;r=q*(+h[e+(C<<3)>>3]- +h[e+(B<<3)>>3]);g[b+(B<<2)>>2]=(n+r)*.5;B=a-1|0;g[b+(B<<2)>>2]=(n-r)*.5;if((C|0)>=(j|0)){break}a=B;c=C;l=+h[f+(C<<3)>>3]}E=D+1.0;F=f+(j<<3)|0;G=+h[F>>3];H=E*G;I=H*.5;J=I;K=b+(m<<2)|0;g[K>>2]=J;L=D;M=b+(k<<2)|0;g[M>>2]=L;i=d;return}function BPa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+40|0;h=g|0;if((f|0)>0){j=0;do{b[h+(j<<1)>>1]=((b[e+(j<<1)>>1]|0)+(b[d+(j<<1)>>1]|0)|0)>>>1;j=j+1|0;}while((j|0)<(f|0))}j=f>>1;zPa(a,h|0,j);zPa(c,d,j);i=g;return}function CPa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,j=0,k=0.0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0.0,y=0,z=0,A=0.0,B=0;d=i;i=i+176|0;e=d|0;f=d+88|0;j=c<<1;h[e>>3]=1.0;k=+h[a>>3]*-2.0;l=e+8|0;h[l>>3]=k;m=(c|0)<2;a:do{if(!m){n=2;o=k;p=1.0;while(1){q=+h[a+((n<<1)-2<<3)>>3]*-2.0;r=n-1|0;s=e+(r<<3)|0;t=e+(n<<3)|0;h[t>>3]=p*2.0+o*q;do{if((r|0)>1){u=n-2|0;v=+h[e+(n-3<<3)>>3];h[s>>3]=o+(q*p+v);if((u|0)>1){w=u;x=v}else{break}while(1){u=e+(w<<3)|0;y=w-1|0;v=+h[e+(w-2<<3)>>3];h[u>>3]=+h[u>>3]+(q*x+v);if((y|0)>1){w=y;x=v}else{break}}}}while(0);h[l>>3]=q+ +h[l>>3];r=n+1|0;if((r|0)>(c|0)){break a}n=r;o=+h[t>>3];p=+h[s>>3]}}}while(0);h[f>>3]=1.0;x=+h[a+8>>3]*-2.0;l=f+8|0;h[l>>3]=x;b:do{if(!m){w=2;k=x;p=1.0;while(1){o=+h[a+((w<<1)-1<<3)>>3]*-2.0;n=w-1|0;r=f+(n<<3)|0;y=f+(w<<3)|0;h[y>>3]=p*2.0+k*o;do{if((n|0)>1){u=w-2|0;v=+h[f+(w-3<<3)>>3];h[r>>3]=k+(o*p+v);if((u|0)>1){z=u;A=v}else{break}while(1){u=f+(z<<3)|0;B=z-1|0;v=+h[f+(z-2<<3)>>3];h[u>>3]=+h[u>>3]+(o*A+v);if((B|0)>1){z=B;A=v}else{break}}}}while(0);h[l>>3]=o+ +h[l>>3];n=w+1|0;if((n|0)>(c|0)){break b}w=n;k=+h[y>>3];p=+h[r>>3]}}}while(0);if((c|0)==0){i=d;return}l=c;A=+h[e+(c<<3)>>3];x=+h[f+(c<<3)>>3];while(1){c=l-1|0;p=+h[e+(c<<3)>>3];k=A+p;q=+h[f+(c<<3)>>3];v=x-q;g[b+(c<<2)>>2]=(k+v)*.5;g[b+(j-l<<2)>>2]=(k-v)*.5;if((c|0)==0){break}else{l=c;A=p;x=q}}i=d;return}function DPa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0.0,h=0,i=0.0;c=b-1|0;if((c|0)>0){d=0}else{return}do{b=d;while(1){e=a+(b<<2)|0;f=+g[e>>2];h=a+(b+1<<2)|0;i=+g[h>>2];if(!(f>i)){break}g[h>>2]=f;g[e>>2]=i;if((b|0)>0){b=b-1|0}else{break}}d=d+1|0;}while((d|0)<(c|0));return}function EPa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b;if((c[b+20>>2]|0)!=0){e=c[d>>2]|0;c[d>>2]=e+((c[b+4>>2]|0)-e);return}e=b+16456|0;f=c[e>>2]|0;if((f|0)<=0){return}g=c[b+4>>2]|0;b=f;f=c[d>>2]|0;while(1){if((g|0)==(f|0)){h=9;break}i=g;j=i-f|0;k=j>>>0>b>>>0?b:j;j=f+k|0;c[d>>2]=j;if((i-j|0)<1){h=6;break}i=f+(k+1)|0;c[d>>2]=i;k=a[j]|0;j=k&255;c[e>>2]=j;if(k<<24>>24==0){h=9;break}else{b=j;f=i}}if((h|0)==6){c[e>>2]=0;return}else if((h|0)==9){return}}function FPa(a){a=a|0;c[a>>2]=pJb(16460)|0;return}function GPa(a){a=a|0;mJb(a);return}function HPa(a,b,d,f,g){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;if((b-1|0)>>>0>10>>>0){j=-1;i=h;return j|0}if(!((f|0)>-1)){KIb(0,0,2519016,(k=i,i=i+24|0,c[k>>2]=2602264,c[k+8>>2]=2450792,c[k+16>>2]=135,k)|0);i=k;Hd();return 0}c[a>>2]=d;c[a+8>>2]=d;c[a+4>>2]=d+f;c[a+16>>2]=0;c[a+12>>2]=0;c[a+16456>>2]=0;c[a+32>>2]=b;f=b+1|0;c[a+24>>2]=f;c[a+28>>2]=e[838280+(f<<1)>>1]|0;c[a+48>>2]=1<<f;f=1<<b;c[a+36>>2]=f;c[a+40>>2]=f+1;b=f+2|0;c[a+44>>2]=b;c[a+56>>2]=b;c[a+60>>2]=-1;c[a+64>>2]=-1;c[a+68>>2]=a+72;c[a+20>>2]=g;c[a+52>>2]=(g|0)==1;j=0;i=h;return j|0}function IPa(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;i=f+40|0;if((c[i>>2]|0)<0){j=0;return j|0}k=f+68|0;l=f+64|0;m=f+60|0;n=f+72|0;o=f+20|0;p=f+12|0;q=f+24|0;r=f+16456|0;s=f+4|0;t=f;u=f+16|0;v=f+28|0;w=f+36|0;x=f+32|0;y=f+44|0;z=f+56|0;A=f+48|0;B=f+8264|0;C=f+52|0;D=c[k>>2]|0;E=c[m>>2]|0;F=c[l>>2]|0;G=g;g=h;a:while(1){if(D>>>0>n>>>0){H=F;I=E;J=D}else{K=F;L=E;M=D;while(1){N=c[o>>2]|0;O=K;P=L;Q=c[p>>2]|0;R=c[q>>2]|0;while(1){S=(Q|0)<(R|0);if((N|0)==0){if(S){T=c[s>>2]|0;U=c[r>>2]|0;V=Q;W=c[t>>2]|0;while(1){X=T;if((U|0)==0){if((X-W|0)<1){Y=0;Z=W}else{_=W+1|0;c[t>>2]=_;Y=d[W]|0;Z=_}c[r>>2]=Y;$=Y;aa=Z}else{$=U;aa=W}if((X-aa|0)<1){ba=0;ca=aa}else{X=aa+1|0;c[t>>2]=X;ba=d[aa]|0;ca=X}X=c[u>>2]|ba<<V;c[u>>2]=X;_=V+8|0;c[p>>2]=_;da=$-1|0;c[r>>2]=da;if((_|0)<(R|0)){U=da;V=_;W=ca}else{ea=_;fa=X;break}}}else{ea=Q;fa=c[u>>2]|0}c[u>>2]=fa>>>(R>>>0);ga=fa;ha=ea}else{W=c[u>>2]|0;if(S){V=c[s>>2]|0;U=W;T=c[t>>2]|0;X=Q;while(1){if((V-T|0)<1){ia=0;ja=T}else{_=T+1|0;c[t>>2]=_;ia=d[T]|0;ja=_}_=ia|U<<8;c[u>>2]=_;da=X+8|0;c[p>>2]=da;if((da|0)<(R|0)){U=_;T=ja;X=da}else{ka=_;la=da;break}}}else{ka=W;la=Q}ga=ka>>>((la-R|0)>>>0);ha=la}X=ha-R|0;c[p>>2]=X;ma=c[v>>2]&ga;if((ma|0)==(c[i>>2]|0)){na=38;break a}if((ma|0)!=(c[w>>2]|0)){break}T=(c[x>>2]|0)+1|0;c[q>>2]=T;c[v>>2]=e[838280+(T<<1)>>1]|0;c[z>>2]=c[y>>2];c[A>>2]=1<<T;O=-1;P=-1;Q=X;R=T}R=c[z>>2]|0;if((ma|0)==(R|0)&(P|0)>-1){a[M]=P;oa=M+1|0;pa=O}else{if((ma|0)<(R|0)){oa=M;pa=ma}else{na=38;break a}}if((pa|0)<(c[y>>2]|0)){qa=pa;ra=oa}else{R=pa;Q=oa;while(1){N=Q+1|0;a[Q]=a[f+(R+4168)|0]|0;T=e[B+(R<<1)>>1]|0;if((T|0)<(c[y>>2]|0)){qa=T;ra=N;break}else{R=T;Q=N}}}Q=qa&255;R=ra+1|0;a[ra]=Q;N=c[z>>2]|0;T=c[A>>2]|0;if((N|0)<(T|0)&(O|0)>-1){a[f+(N+4168)|0]=Q;Q=c[z>>2]|0;c[z>>2]=Q+1;b[B+(Q<<1)>>1]=O;sa=c[z>>2]|0;ta=c[A>>2]|0}else{sa=N;ta=T}do{if((sa|0)>=(ta-(c[C>>2]|0)|0)){T=c[q>>2]|0;if((T|0)>=12){break}c[A>>2]=ta<<1;N=T+1|0;c[q>>2]=N;c[v>>2]=e[838280+(N<<1)>>1]|0}}while(0);if(R>>>0>n>>>0){H=ma;I=qa;J=R;break}else{K=ma;L=qa;M=R}}}L=J-1|0;a[G]=a[L]|0;K=g-1|0;if((K|0)==0){ua=L;va=0;wa=H;xa=I;break}else{D=L;E=I;F=H;G=G+1|0;g=K}}if((na|0)==38){c[i>>2]=-1;ua=M;va=g;wa=O;xa=P}c[k>>2]=ua;c[l>>2]=wa;c[m>>2]=xa;j=h-va|0;return j|0}function JPa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;c[a>>2]=256;c[a+4>>2]=257;c[a+196976>>2]=e;h=(d|0)<0;j=h?0:b;b=h?0:d;c[a+196972>>2]=b<<3;c[a+196960>>2]=j;c[a+196968>>2]=j+b;c[a+196964>>2]=j;c[a+196956>>2]=32;c[a+196952>>2]=0;c[a+196948>>2]=d;if((e-9|0)>>>0<4>>>0){c[a+196980>>2]=1<<e;c[a+196984>>2]=0;c[a+196988>>2]=-1;c[a+196944>>2]=9;c[a+196992>>2]=f;c[a+196996>>2]=g;i=i;return}else{KIb(0,0,2518832,(g=i,i=i+24|0,c[g>>2]=2602224,c[g+8>>2]=2450768,c[g+16>>2]=210,g)|0);i=g;Hd()}}function KPa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=b+196984|0;if((e*3|0|0)>((c[b+196948>>2]|0)-(c[f>>2]|0)<<1|0)){g=-1;return g|0}h=b+196988|0;if((c[h>>2]|0)==-1){i=b+196944|0;ef[c[b+196996>>2]&4095](b+196952|0,c[i>>2]|0,c[b>>2]|0);c[i>>2]=9;i=0;while(1){c[b+8+(i*12|0)>>2]=-2;j=i+1|0;if((j|0)<16411){i=j}else{k=0;break}}do{i=k<<6;c[b+8+(i*12|0)+4>>2]=k;a[b+8+(i*12|0)+8|0]=k;c[b+8+(i*12|0)>>2]=-1;k=k+1|0;}while((k|0)<256);c[b+196940>>2]=258}a:do{if((e|0)>0){k=b+196996|0;i=b+196952|0;j=b+196944|0;l=b+196940|0;m=b+196992|0;n=b+196980|0;o=b|0;p=d;q=1;while(1){r=p+1|0;s=a[p]|0;t=c[h>>2]|0;u=(s&255)<<6;v=((t|0)>0?t:0)^u;w=(v|0)>16410?v-16411|0:v;v=(w|0)==0?1:16411-w|0;x=c[b+8+(w*12|0)>>2]|0;b:do{if((x|0)==-2){y=w;z=14}else{A=w;B=x;while(1){if((a[b+8+(A*12|0)+8|0]|0)==s<<24>>24&(B|0)==(t|0)){break}C=A-v|0;D=(C|0)<0?C+16411|0:C;C=c[b+8+(D*12|0)>>2]|0;if((C|0)==-2){y=D;z=14;break b}else{A=D;B=C}}if((t|0)==-2){y=A;z=14;break}E=A;F=c[l>>2]|0}}while(0);do{if((z|0)==14){z=0;ef[c[k>>2]&4095](i,c[j>>2]|0,t);v=c[h>>2]|0;c[b+8+(y*12|0)+4>>2]=c[l>>2];a[b+8+(y*12|0)+8|0]=s;c[b+8+(y*12|0)>>2]=v;v=(c[l>>2]|0)+1|0;c[l>>2]=v;x=c[j>>2]|0;if((v|0)<(((c[m>>2]|0)==0)+(1<<x)|0)){E=u;F=v;break}c[j>>2]=x+1;E=u;F=v}}while(0);c[h>>2]=c[b+8+(E*12|0)+4>>2];if((F|0)>=((c[n>>2]|0)-1|0)){ef[c[k>>2]&4095](i,c[j>>2]|0,c[o>>2]|0);c[j>>2]=9;u=0;while(1){c[b+8+(u*12|0)>>2]=-2;s=u+1|0;if((s|0)<16411){u=s}else{G=0;break}}do{u=G<<6;c[b+8+(u*12|0)+4>>2]=G;a[b+8+(u*12|0)+8|0]=G;c[b+8+(u*12|0)>>2]=-1;G=G+1|0;}while((G|0)<256);c[l>>2]=258}if((q|0)>=(e|0)){break a}p=r;q=q+1|0}}}while(0);e=32-(c[b+196956>>2]|0)+((c[b+196964>>2]|0)-(c[b+196960>>2]|0)<<3)>>3;b=e-(c[f>>2]|0)|0;c[f>>2]=e;g=b;return g|0}function LPa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a+196988|0;e=c[d>>2]|0;f=a+196996|0;if((e|0)==-1){g=a+196952|0;h=a+196944|0}else{i=a+196952|0;j=a+196944|0;ef[c[f>>2]&4095](i,c[j>>2]|0,e);g=i;h=j}ef[c[f>>2]&4095](g,c[h>>2]|0,c[a+4>>2]|0);if((c[a+196992>>2]|0)==0){ef[c[f>>2]&4095](g,1,0)}qe[b&1023](g);c[d>>2]=-1;d=32-(c[a+196956>>2]|0)+((c[a+196964>>2]|0)-(c[a+196960>>2]|0)<<3)>>3;g=a+196984|0;a=d-(c[g>>2]|0)|0;c[g>>2]=d;return a|0}function MPa(a){a=a|0;var b=0;if(((c[a+416>>2]|0)-1|0)>>>0>1>>>0){b=-22;return b|0}c[a+420>>2]=6;b=0;return b|0}function NPa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;k=i;i=i+8|0;l=k|0;m=g;n=c[j+24>>2]|0;o=c[j+28>>2]|0;j=c[f+60>>2]|0;p=(c[f+48>>2]|0)==86025;q=p&1;r=f+416|0;s=c[r>>2]|0;do{if(((o|0)%(s<<q|0)|0|0)==0){t=o;u=s}else{KIb(f,16,2246216,(v=i,i=i+8|0,c[v>>2]=o,v)|0);i=v;v=c[r>>2]|0;w=(o|0)%(v<<q|0)|0;if((o|0)==(w|0)){x=-1094995529}else{t=o-w|0;u=v;break}i=k;return x|0}}while(0);o=q^1;c[g+76>>2]=((t<<o)*3|0|0)/(u|0)|0;u=M4a(f,m,0)|0;if((u|0)<0){x=u;i=k;return x|0}u=c[g+64>>2]|0;g=c[r>>2]|0;if((g|0)>0){m=1<<q;f=(m|0)>0;s=l|0;v=l+1|0;w=l+2|0;y=l+3|0;z=l+4|0;A=l+5|0;B=j;j=1<<o;C=3<<o;o=0;D=g;while(1){if(((t|0)/(D<<q|0)|0|0)>0){g=o<<q;E=B+(o*10|0)|0;F=B+(o*10|0)+8|0;G=B+(o*10|0)+6|0;H=B+(o*10|0)+2|0;I=B+(o*10|0)+4|0;J=0;K=c[u+(o<<2)>>2]|0;L=D;while(1){if(f){M=0;N=K;O=L;while(1){P=a[n+(M+g+((ca(O,J)|0)<<q))|0]|0;Q=(P&255)>>>5;a[s]=Q;R=(P&255)>>>3&3;a[v]=R;S=P&7;a[w]=S;a[y]=S;a[z]=R;a[A]=Q;if(p){Q=0;R=N;while(1){S=d[l+3+Q|0]|0;P=c[316864+(Q*12|0)>>2]|0;T=b[E>>1]|0;U=ca((T&65535)>>>4&127,P)|0;if((S|0)<(P|0)){V=b[(c[316860+(Q*12|0)>>2]|0)+(U+S<<1)>>1]|0}else{V=~b[(c[316860+(Q*12|0)>>2]|0)+((P<<1)+~S+U<<1)>>1]}U=T<<16>>16;T=U-(U>>>5)+(e[(c[316856+(Q*12|0)>>2]|0)+(S<<1)>>1]|0)&65535;b[E>>1]=T<<16>>16<0?0:T;T=(b[F>>1]|0)+(V<<16>>16)|0;if((T|0)>32767){W=32767}else{W=(T|0)<-32768?-32767:T<<16>>16}b[F>>1]=W-(W>>>3);b[R>>1]=W>>>8&255|W&65280;T=Q+1|0;if((T|0)<3){Q=T;R=R+(j<<1)|0}else{break}}}else{R=0;Q=N;while(1){T=d[l+R|0]|0;S=c[316864+(R*12|0)>>2]|0;U=b[E>>1]|0;P=ca((U&65535)>>>4&127,S)|0;if((T|0)<(S|0)){X=b[(c[316860+(R*12|0)>>2]|0)+(P+T<<1)>>1]|0}else{X=~b[(c[316860+(R*12|0)>>2]|0)+((S<<1)+~T+P<<1)>>1]}P=U<<16>>16;U=P-(P>>>5)+(e[(c[316856+(R*12|0)>>2]|0)+(T<<1)>>1]|0)&65535;b[E>>1]=U<<16>>16<0?0:U;U=b[G>>1]|0;T=X<<16>>16;P=b[H>>1]|0;do{if((U^X)<<16>>16>-1){S=P+506|0;Y=(S|0)>32767?32767:S&65535;b[H>>1]=Y;Z=Y}else{Y=P-314|0;if((Y|0)<-32768){b[H>>1]=-32767;Z=-32767;break}else{S=Y&65535;b[H>>1]=S;Z=S;break}}}while(0);P=(b[F>>1]|0)+T|0;if((P|0)>32767){_=32767}else{_=(P|0)<-32768?-32767:P<<16>>16}b[F>>1]=(ca(_,Z<<16>>16)|0)>>>15;P=_>>>1&65535;S=b[I>>1]|0;Y=P<<16>>16;$=S+(U<<16>>16)-(S-Y>>2)|0;b[Q>>1]=$>>>8&255|$&65280;$=(b[G>>1]|0)+Y+((b[I>>1]|0)-Y>>2)|0;b[Q+2>>1]=$>>>8&255|$&65280;b[I>>1]=b[G>>1]|0;b[G>>1]=P;P=R+1|0;if((P|0)<3){R=P;Q=Q+(j<<1)|0}else{break}}}Q=N+(C<<1)|0;R=M+1|0;P=c[r>>2]|0;if((R|0)<(m|0)){M=R;N=Q;O=P}else{aa=Q;ba=P;break}}}else{aa=K;ba=L}O=J+1|0;if((O|0)<((t|0)/(ba<<q|0)|0|0)){J=O;K=aa;L=ba}else{da=ba;break}}}else{da=D}L=o+1|0;if((L|0)<(da|0)){o=L;D=da}else{break}}}c[h>>2]=1;x=t;i=k;return x|0}function OPa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=+e;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0.0,v=0.0;mrc(a|0,0,60)|0;f=1<<b;c[a+20>>2]=b;c[a+16>>2]=f;h=f>>2;i=a+60|0;c[i>>2]=0;do{if((pda(a,b-2|0,d)|0)<0){j=a+24|0}else{k=hJb(((f|0)/2|0)<<2)|0;l=k;m=a+24|0;c[m>>2]=l;if((k|0)==0){j=m;break}n=c[i>>2]|0;if((n|0)==0){o=l+(h<<2)|0;c[a+28>>2]=o;p=1;q=o}else if((n|0)==1){n=k+4|0;c[a+28>>2]=n;p=2;q=n}else{j=m;break}r=(e<0.0?+(h|0):0.0)+.125;s=+S(+R(+e));if((h|0)<=0){t=0;return t|0}u=+(f|0);m=0;while(1){v=(r+ +(m|0))*6.283185307179586/u;n=ca(m,p)|0;g[l+(n<<2)>>2]=s*(-0.0- +U(v));g[q+(n<<2)>>2]=s*(-0.0- +V(v));n=m+1|0;if((n|0)<(h|0)){m=n}else{t=0;break}}return t|0}}while(0);mJb(j);tda(a);t=-1;return t|0}function PPa(a){a=a|0;mJb(a+24|0);tda(a);return}function QPa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0;f=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=b;b=1<<c[a+20>>2];k=b>>2;l=b>>3;if((k|0)>0){m=d+((b>>1)-1<<2)|0;b=d;d=0;while(1){n=e[f+(d<<1)>>1]|0;o=h+(d<<2)|0;p=i+(d<<2)|0;g[j+(n<<3)>>2]=+g[m>>2]*+g[o>>2]- +g[b>>2]*+g[p>>2];g[j+(n<<3)+4>>2]=+g[m>>2]*+g[p>>2]+ +g[b>>2]*+g[o>>2];o=d+1|0;if((o|0)<(k|0)){m=m-8|0;b=b+8|0;d=o}else{break}}}re[c[a+36>>2]&1023](a,j);if((l|0)>0){q=0}else{return}do{a=l-q-1|0;d=j+(a<<3)+4|0;r=+g[d>>2];s=+g[i+(a<<2)>>2];b=j+(a<<3)|0;t=+g[b>>2];u=+g[h+(a<<2)>>2];a=q+l|0;m=j+(a<<3)+4|0;v=+g[m>>2];w=+g[i+(a<<2)>>2];k=j+(a<<3)|0;x=+g[k>>2];y=+g[h+(a<<2)>>2];g[b>>2]=r*s-t*u;g[d>>2]=w*x+v*y;g[k>>2]=v*w-x*y;g[m>>2]=s*t+r*u;q=q+1|0;}while((q|0)<(l|0));return}function RPa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0;e=1<<c[a+20>>2];f=e>>1;h=e>>2;QPa(a,b+(h<<2)|0,d);if((h|0)<=0){return}d=f-1|0;a=e-1|0;e=0;i=0;while(1){g[b+(e<<2)>>2]=-0.0- +g[b+(d+i<<2)>>2];g[b+(a+i<<2)>>2]=+g[b+(e+f<<2)>>2];j=e+1|0;k=~e;if((j|0)<(h|0)){e=j;i=k}else{break}}return}function SPa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0;f=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=b;b=1<<c[a+20>>2];k=b>>1;l=b>>2;m=b>>3;n=l*3|0;o=(m|0)>0;if(!o){re[c[a+36>>2]&1023](a,j);return}p=n-1|0;q=l-1|0;r=k-1|0;s=b-1|0;b=0;do{t=b<<1;u=-0.0- +g[d+(t+n<<2)>>2]- +g[d+(p-t<<2)>>2];v=+g[d+(q-t<<2)>>2]- +g[d+(t+l<<2)>>2];w=e[f+(b<<1)>>1]|0;x=h+(b<<2)|0;y=i+(b<<2)|0;g[j+(w<<3)>>2]=u*(-0.0- +g[x>>2])-v*+g[y>>2];g[j+(w<<3)+4>>2]=u*+g[y>>2]+v*(-0.0- +g[x>>2]);v=+g[d+(t<<2)>>2]- +g[d+(r-t<<2)>>2];u=-0.0- +g[d+(t+k<<2)>>2]- +g[d+(s-t<<2)>>2];t=b+m|0;x=e[f+(t<<1)>>1]|0;y=h+(t<<2)|0;w=i+(t<<2)|0;g[j+(x<<3)>>2]=v*(-0.0- +g[y>>2])-u*+g[w>>2];g[j+(x<<3)+4>>2]=v*+g[w>>2]+u*(-0.0- +g[y>>2]);b=b+1|0;}while((b|0)<(m|0));re[c[a+36>>2]&1023](a,j);if(o){z=0}else{return}do{o=m-z-1|0;a=j+(o<<3)|0;u=+g[a>>2];v=-0.0- +g[i+(o<<2)>>2];b=j+(o<<3)+4|0;A=+g[b>>2];B=-0.0- +g[h+(o<<2)>>2];o=z+m|0;f=j+(o<<3)|0;C=+g[f>>2];D=-0.0- +g[i+(o<<2)>>2];s=j+(o<<3)+4|0;E=+g[s>>2];F=-0.0- +g[h+(o<<2)>>2];g[a>>2]=A*v+u*B;g[b>>2]=C*D-E*F;g[f>>2]=E*D+C*F;g[s>>2]=u*v-A*B;z=z+1|0;}while((z|0)<(m|0));return}function TPa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b+1432>>2]=((c[a+128>>2]|0)+15|0)/16|0;c[b+1436>>2]=((c[a+132>>2]|0)+15|0)/16|0;c[b>>2]=a;l8(b+4|0,a);jRa();L6(b+1132|0,b+1280|0,1242080);b=a+788|0;if((c[b>>2]|0)!=0){d=a+140|0;c[d>>2]=12;return 0}c[b>>2]=2;d=a+140|0;c[d>>2]=12;return 0}function UPa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;k=i;i=i+16|0;l=k|0;m=c[f+60>>2]|0;n=m;o=c[j+24>>2]|0;p=c[j+28>>2]|0;j=l|0;c[j>>2]=g;c[l+4>>2]=0;c[l+8>>2]=0;g=J5a(f,l,0)|0;if((g|0)<0){q=g;i=k;return q|0}g=c[j>>2]|0;c[g+88>>2]=1;c[g+84>>2]=1;g=m+2224|0;l=g;A4a(g,m+2228|0,p);g=c[l>>2]|0;if((g|0)==0){q=-12;i=k;return q|0}ef[c[m+1104>>2]&4095](g,o,(p+1|0)/2|0);o=c[l>>2]|0;l=p>>>0>268435455>>>0?-8:p<<3;p=l>>>0>2147483639>>>0|(o|0)==0;g=p?0:o;o=p?0:l;l=m+1260|0;c[l>>2]=g;f=m+1272|0;c[f>>2]=o;r=o+8|0;s=m+1276|0;c[s>>2]=r;c[m+1264>>2]=g+(o>>3);o=m+1268|0;c[o>>2]=0;if(p){q=p?-1094995529:0;i=k;return q|0}p=r>>>0>32>>>0?32:r;c[o>>2]=p;t=g+(p>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)>>>16;t=p+16|0;p=r>>>0>t>>>0?t:r;c[o>>2]=p;t=m+1416|0;c[t>>2]=u;u=g+(p>>>3)|0;g=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(p&7)>>>16;u=p+16|0;c[o>>2]=r>>>0>u>>>0?u:r;r=m+1412|0;c[r>>2]=g;c[m+1428>>2]=128;c[m+1424>>2]=128;c[m+1420>>2]=128;g=m+1440|0;c[g>>2]=0;u=m+1432|0;p=c[u>>2]|0;a:do{if((p|0)>0){v=m+1444|0;w=m+1436|0;x=m+1456|0;y=x;z=m+44|0;A=x;x=m+1124|0;B=m+1584|0;C=m+1712|0;D=m+1840|0;E=m;F=m+1968|0;G=m+2096|0;H=c[w>>2]|0;I=0;J=p;b:while(1){c[v>>2]=0;if((H|0)>0){do{qe[c[z>>2]&1023](A);K=0;while(1){if((K|0)>=6){break}L=c[1585128+(K<<2)>>2]|0;M=y+(L<<7)|0;N=c[t>>2]|0;if((c[r>>2]|0)==2){O=c[o>>2]|0;P=c[s>>2]|0;Q=c[l>>2]|0;R=Q+(O>>>3)|0;S=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>22;R=O+10|0;O=P>>>0>R>>>0?R:P;c[o>>2]=O;T=(S<<1)+1024&65535;U=O;V=P;W=Q}else{Q=K>>>0>1>>>0?0:L-3|0;if((Q|0)==0){P=c[2094917]|0;O=c[o>>2]|0;S=c[s>>2]|0;R=c[l>>2]|0;X=R+(O>>>3)|0;Y=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(O&7)>>>23;X=b[P+(Y<<2)>>1]|0;Z=b[P+(Y<<2)+2>>1]|0;Y=Z<<16>>16;if(Z<<16>>16<0){Z=O+9|0;_=S>>>0>Z>>>0?Z:S;Z=R+(_>>>3)|0;$=((je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(_&7)>>>((Y+32|0)>>>0))+X|0;aa=b[P+($<<2)+2>>1]|0;ba=b[P+($<<2)>>1]|0;da=_}else{aa=Y;ba=X;da=O}O=aa+da|0;ea=ba;fa=S;ga=R;ha=S>>>0>O>>>0?O:S}else{S=c[2094923]|0;O=c[o>>2]|0;R=c[s>>2]|0;X=c[l>>2]|0;Y=X+(O>>>3)|0;_=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(O&7)>>>23;Y=b[S+(_<<2)>>1]|0;$=b[S+(_<<2)+2>>1]|0;_=$<<16>>16;if($<<16>>16<0){$=O+9|0;P=R>>>0>$>>>0?$:R;$=X+(P>>>3)|0;Z=((je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(P&7)>>>((_+32|0)>>>0))+Y|0;ia=b[S+(Z<<2)+2>>1]|0;ja=b[S+(Z<<2)>>1]|0;ka=P}else{ia=_;ja=Y;ka=O}O=ia+ka|0;ea=ja;fa=R;ga=X;ha=R>>>0>O>>>0?O:R}c[o>>2]=ha;if((ea|0)<0){la=19;break b}if((ea|0)==0){ma=0}else{R=ga+(ha>>>3)|0;O=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(ha&7);R=(O^-2147483648)>>31;X=ea+ha|0;c[o>>2]=fa>>>0>X>>>0?X:fa;X=((R^O)>>>((32-ea|0)>>>0)^R)-R|0;if((X|0)>65534){q=-1094995529;la=41;break b}else{ma=X}}X=n+1420+(Q<<2)|0;Q=(c[X>>2]|0)+ma|0;c[X>>2]=Q;T=Q<<3&65535;U=c[o>>2]|0;V=c[s>>2]|0;W=c[l>>2]|0}b[M>>1]=T;M=-N|0;Q=c[328980]|0;X=U;R=0;c:while(1){O=W+(X>>>3)|0;Y=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(X&7);O=Y>>>23;_=b[Q+(O<<2)>>1]|0;P=a[Q+(O<<2)+2|0]|0;Z=P<<24>>24;if(P<<24>>24<0){P=Y<<9;S=X+9|0;$=(P>>>((Z+32|0)>>>0))+_|0;na=$;oa=a[Q+($<<2)+2|0]|0;pa=b[Q+($<<2)>>1]|0;qa=P;ra=V>>>0>S>>>0?S:V}else{na=O;oa=Z;pa=_;qa=Y;ra=X}Y=qa<<oa;_=oa+ra|0;sa=V>>>0>_>>>0?_:V;do{if((pa|0)==127){break c}else if((pa|0)==0){_=sa+6|0;Z=V>>>0>_>>>0?_:V;_=W+(Z>>>3)|0;O=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Z&7)>>22;_=Z+10|0;Z=V>>>0>_>>>0?_:V;_=R+1+(Y>>>26)|0;S=d[n+1284+_|0]|0;if((O|0)<0){ta=-(((ca(ca(O,M)|0,e[1346848+(S<<1)>>1]|0)|0)>>>3)+65535|1)&65535;ua=Z;va=_;wa=S;break}else{P=ca(O,N)|0;ta=(((ca(P,e[1346848+(S<<1)>>1]|0)|0)>>>3)+65535|1)&65535;ua=Z;va=_;wa=S;break}}else{S=(d[Q+(na<<2)+3|0]|0)+R|0;_=d[n+1284+S|0]|0;Z=ca(pa,N)|0;P=Y>>31;O=((ca(Z,e[1346848+(_<<1)>>1]|0)|0)>>>3^P)-P|0;P=sa+1|0;ta=O&65535;ua=V>>>0>P>>>0?P:V;va=S;wa=_}}while(0);if((va|0)>63){la=32;break b}b[y+(L<<7)+(wa<<1)>>1]=ta;X=ua;R=va}c[o>>2]=sa;c[n+2232+(L<<2)>>2]=R;if(((c[f>>2]|0)-(c[o>>2]|0)|0)<0){q=-1094995529;la=41;break b}else{K=K+1|0}}K=c[j>>2]|0;X=c[g>>2]|0;N=c[v>>2]|0;Q=c[K+32>>2]|0;M=c[K>>2]|0;Y=(ca(N<<4,Q)|0)+(X<<4)|0;_=c[K+4>>2]|0;S=N<<3;N=K+36|0;P=c[N>>2]|0;O=X<<3;X=c[K+8>>2]|0;Z=K+40|0;K=c[Z>>2]|0;ef[c[x>>2]&4095](M+Y|0,Q,A);ef[c[x>>2]&4095](M+(Y|8)|0,Q,B);$=Y+(Q<<3)|0;ef[c[x>>2]&4095](M+$|0,Q,C);ef[c[x>>2]&4095](M+($+8)|0,Q,D);if((c[(c[E>>2]|0)+88>>2]&8192|0)==0){Q=X+((ca(K,S)|0)+O)|0;K=_+((ca(P,S)|0)+O)|0;ef[c[x>>2]&4095](K,c[N>>2]|0,F);ef[c[x>>2]&4095](Q,c[Z>>2]|0,G)}Z=(c[v>>2]|0)+1|0;c[v>>2]=Z;xa=c[w>>2]|0;}while((Z|0)<(xa|0));ya=xa;za=c[g>>2]|0;Aa=c[u>>2]|0}else{ya=H;za=I;Aa=J}Z=za+1|0;c[g>>2]=Z;if((Z|0)<(Aa|0)){H=ya;I=Z;J=Aa}else{break a}}if((la|0)==19){KIb(0,16,2361464,(Ba=i,i=i+1|0,i=i+7&-8,c[Ba>>2]=0,Ba)|0);i=Ba;q=-1094995529;i=k;return q|0}else if((la|0)==32){J=c[v>>2]|0;KIb(c[E>>2]|0,16,2450728,(Ba=i,i=i+16|0,c[Ba>>2]=c[g>>2],c[Ba+8>>2]=J,Ba)|0);i=Ba;q=-1094995529;i=k;return q|0}else if((la|0)==41){i=k;return q|0}}}while(0);c[h>>2]=1;q=(((c[o>>2]|0)+31|0)/32|0)<<2;i=k;return q|0}function VPa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+2224|0);c[b+2228>>2]=0;return 0}function WPa(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;f=c[a+60>>2]|0;g=c[a+96>>2]|0;do{if((g|0)!=0){if((c[a+100>>2]|0)<16){break}h=g+12|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=1681536;while(1){k=c[h>>2]|0;if((k|0)==0){l=6;break}if((k|0)==(j|0)){break}else{h=h+16|0}}if((l|0)==6){KIb(a,16,2361416,(m=i,i=i+8|0,c[m>>2]=j,m)|0);i=m;n=-1094995529;i=b;return n|0}k=c[h+12>>2]|0;c[a+412>>2]=k;o=c[h+8>>2]|0;c[a+416>>2]=o;p=(c[h+4>>2]|0)*1e3|0;c[a+72>>2]=p;q=(k|0)/1e3|0;if((o-1|0)>>>0>1>>>0){KIb(a,16,2297056,(m=i,i=i+8|0,c[m>>2]=o,m)|0);i=m;n=-1094995529;i=b;return n|0}r=(o|0)==1;s=a+448|0;c[s>>2]=r?4:3;c[s+4>>2]=r?0:0;r=(p|0)/(o*1e3|0|0)|0;s=(o<<16)+(q<<8)+r|0;if((s|0)==71192){c[f+232>>2]=1357272;t=1357272}else if((s|0)==142384){c[f+232>>2]=1356432;t=1356432}else if((s|0)==67590){c[f+232>>2]=1358232;t=1358232}else if((s|0)==69648){c[f+232>>2]=1357512;t=1357512}else if((s|0)==76840){c[f+232>>2]=1356792;t=1356792}else if((s|0)==67592){c[f+232>>2]=1357992;t=1357992}else if((s|0)==68362){c[f+232>>2]=1357752;t=1357752}else if((s|0)==133128){c[f+232>>2]=1357872;t=1357872}else if((s|0)==76848){c[f+232>>2]=1356552;t=1356552}else if((s|0)==133126){c[f+232>>2]=1358112;t=1358112}else if((s|0)==136728){c[f+232>>2]=1357152;t=1357152}else if((s|0)==76832){c[f+232>>2]=1357032;t=1357032}else if((s|0)==135184){c[f+232>>2]=1357392;t=1357392}else if((s|0)==142368){c[f+232>>2]=1356912;t=1356912}else if((s|0)==142376){c[f+232>>2]=1356672;t=1356672}else if((s|0)==133898){c[f+232>>2]=1357632;t=1357632}else{KIb(a,16,2246048,(m=i,i=i+16|0,c[m>>2]=q,c[m+8>>2]=r,m)|0);i=m;n=-38;i=b;return n|0}c[f+36872>>2]=1;c[f+36876>>2]=316;c[f+36880>>2]=4;c[f+36884>>2]=216;c[f+34228>>2]=(ca(e[t+96>>1]|0,p)|0)/(k|0)|0;c[f+236>>2]=(r|0)==6;n=o4a(a)|0;i=b;return n|0}}while(0);KIb(a,16,2450680,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=b;return n|0}function XPa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;h=i;j=c[e+232>>2]|0;k=c[(c[e>>2]|0)+416>>2]|0;l=g<<3;g=l>>>0>2147483639>>>0|(f|0)==0;m=g?0:f;f=g?8:l+8|0;l=e+34236|0;c[l>>2]=0;g=e+34232|0;a:do{if((c[g>>2]|0)>0){n=(k|0)>0;o=e+34184|0;p=e+34168|0;q=j+112|0;r=j+115|0;s=j+104|0;t=j+105|0;u=j+107|0;v=j+106|0;w=e+236|0;x=0;y=0;while(1){z=m+(x>>>3)|0;A=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((x&7)>>>0)&15;z=x+4|0;B=f>>>0>z>>>0?z:f;c[e+34240+(y*1316|0)>>2]=A;if(A>>>0>8>>>0){break}A=c[1276760+(c[e+34240+((c[l>>2]|0)*1316|0)>>2]<<2)>>2]|0;z=e+34240+(y*1316|0)+4|0;c[z>>2]=A;C=a[j+(A<<5)|0]|0;D=C&255;do{if((A|0)==0){E=B}else{if((c[w>>2]|0)!=0){E=B;break}F=B+2|0;E=f>>>0>F>>>0?F:f}}while(0);B=e+34172+(A<<2)|0;if((c[B>>2]|0)>0){F=e+34156+(A<<2)|0;G=0;H=e+34240+(y*1316|0)+8|0;I=E;while(1){J=(G|0)>=(c[F>>2]|0)|0;K=d[e+34140+(A<<1)+J|0]|0;L=m+(I>>>3)|0;M=32-K|0;N=K+I|0;K=f>>>0>N>>>0?N:f;a[H]=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((I&7)>>>0)<<M>>>(M>>>0);M=d[e+34148+(A<<1)+J|0]|0;J=m+(K>>>3)|0;L=32-M|0;N=K+M|0;M=f>>>0>N>>>0?N:f;a[H+1|0]=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((K&7)>>>0)<<L>>>(L>>>0);L=G+1|0;if((L|0)<(c[B>>2]|0)){G=L;H=H+2|0;I=M}else{O=M;break}}}else{O=E}do{if(C<<24>>24==0|n^1){P=O}else{I=O;H=0;while(1){G=I;B=0;A=c[z>>2]|0;while(1){if((a[j+(A<<5)+16|0]|0)==0){Q=G;R=A}else{F=G;M=0;L=A;while(1){K=d[j+(L<<5)+17|0]|0;J=m+(F>>>3)|0;N=32-K|0;S=K+F|0;K=f>>>0>S>>>0?S:f;a[e+34240+(y*1316|0)+1126+(H<<6)+(B<<2)+M|0]=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((F&7)>>>0)<<N>>>(N>>>0);N=M+1|0;J=c[z>>2]|0;if((N|0)<(d[j+(J<<5)+16|0]|0)){F=K;M=N;L=J}else{Q=K;R=J;break}}}L=B+1|0;if((L|0)<(D|0)){G=Q;B=L;A=R}else{break}}A=H+1|0;if((A|0)<(k|0)){I=Q;H=A}else{break}}if(C<<24>>24==0|n^1){P=Q;break}else{T=Q;U=0}while(1){H=T;I=0;while(1){V=((H|0)<(f|0))+H|0;a[e+34240+(y*1316|0)+1254+(U<<4)+I|0]=(d[m+(H>>>3)|0]|0)>>>((H&7)>>>0)&1;A=I+1|0;if((A|0)<(D|0)){H=V;I=A}else{break}}I=U+1|0;if((I|0)<(k|0)){T=V;U=I}else{P=V;break}}}}while(0);b:do{if((c[z>>2]|0)==2){if(n){W=P;X=0}else{Y=P;break}while(1){I=m+(W>>>3)|0;H=W+8|0;A=f>>>0>H>>>0?H:f;a[e+34240+(y*1316|0)+1092+X|0]=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((W&7)>>>0);I=X+1|0;if((I|0)<(k|0)){W=A;X=I}else{Z=A;_=30;break}}}else{if(!n){Y=P;break}if(C<<24>>24==0){A=P;I=0;while(1){H=m+(A>>>3)|0;B=A+8|0;G=f>>>0>B>>>0?B:f;a[e+34240+(y*1316|0)+1092+I|0]=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((A&7)>>>0);H=I+1|0;if((H|0)<(k|0)){A=G;I=H}else{Z=G;_=30;break b}}}else{$=P;aa=0}while(1){I=m+($>>>3)|0;A=$+8|0;a[e+34240+(y*1316|0)+1092+aa|0]=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>(($&7)>>>0);I=ca(aa,D)|0;G=f>>>0>A>>>0?A:f;A=0;while(1){H=m+(G>>>3)|0;B=G+5|0;ba=f>>>0>B>>>0?B:f;a[A+I+(e+34240+(y*1316|0)+1094)|0]=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((G&7)>>>0)&31;H=A+1|0;if((H|0)<(D|0)){G=ba;A=H}else{break}}A=aa+1|0;if((A|0)<(k|0)){$=ba;aa=A}else{Z=ba;_=30;break}}}}while(0);do{if((_|0)==30){_=0;if(n){da=Z;ea=0}else{Y=Z;break}while(1){D=d[s]|0;C=m+(da>>>3)|0;A=32-D|0;G=D+da|0;D=f>>>0>G>>>0?G:f;a[e+34240+(y*1316|0)+1296+ea|0]=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((da&7)>>>0)<<A>>>(A>>>0);A=d[t]|0;C=m+(D>>>3)|0;G=32-A|0;I=D+A|0;A=f>>>0>I>>>0?I:f;a[e+34240+(y*1316|0)+1286+ea|0]=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((D&7)>>>0)<<G>>>(G>>>0);if((a[u]|0)==0){fa=A}else{G=A;A=0;while(1){D=d[v]|0;C=m+(G>>>3)|0;I=32-D|0;H=D+G|0;D=f>>>0>H>>>0?H:f;a[e+34240+(y*1316|0)+1288+(ea<<2)+A|0]=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((G&7)>>>0)<<I>>>(I>>>0);I=A+1|0;if((I|0)<(d[u]|0)){G=D;A=I}else{fa=D;break}}}A=ea+1|0;if((A|0)<(k|0)){da=fa;ea=A}else{Y=fa;break}}}}while(0);do{if((c[z>>2]|0)==2){if((c[o>>2]|0)>0){A=0;G=e+34240+(y*1316|0)+1032|0;D=Y;while(1){I=(A|0)>=(c[p>>2]|0)|0;C=d[e+34146+I|0]|0;H=m+(D>>>3)|0;B=32-C|0;L=C+D|0;C=f>>>0>L>>>0?L:f;a[G]=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((D&7)>>>0)<<B>>>(B>>>0);B=d[e+34154+I|0]|0;I=m+(C>>>3)|0;H=32-B|0;L=C+B|0;B=f>>>0>L>>>0?L:f;a[G+1|0]=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((C&7)>>>0)<<H>>>(H>>>0);H=A+1|0;if((H|0)<(c[o>>2]|0)){A=H;G=G+2|0;D=B}else{ga=B;break}}}else{ga=Y}if(n){ha=ga;ia=0}else{ja=ga;break}while(1){D=d[q]|0;G=m+(ha>>>3)|0;A=32-D|0;B=D+ha|0;D=f>>>0>B>>>0?B:f;c[e+34240+(y*1316|0)+1300+(ia<<2)>>2]=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((ha&7)>>>0)<<A>>>(A>>>0);A=d[r]|0;G=m+(D>>>3)|0;B=32-A|0;H=D+A|0;A=f>>>0>H>>>0?H:f;c[e+34240+(y*1316|0)+1308+(ia<<2)>>2]=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((D&7)>>>0)<<B>>>(B>>>0);B=ia+1|0;if((B|0)<(k|0)){ha=A;ia=B}else{ja=A;break}}}else{ja=Y}}while(0);z=ja&3;if((z|0)==0){ka=ja}else{A=4-z+ja|0;ka=f>>>0>A>>>0?A:f}A=(c[l>>2]|0)+1|0;c[l>>2]=A;if((A|0)<(c[g>>2]|0)){x=ka;y=A}else{la=ka;break a}}KIb(b,16,2204448,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;ma=-1094995529;i=h;return ma|0}else{la=0}}while(0);ma=(la+7|0)/8|0;i=h;return ma|0}function YPa(e,f,h,j,k,l,m){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=+l;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0,L=0,M=0,N=0,O=0;n=i;i=i+16|0;o=n|0;p=c[e+232>>2]|0;g[o>>2]=.4000000059604645;g[o+4>>2]=.3499999940395355;g[o+8>>2]=.2800000011920929;q=a[p+(m<<5)+16|0]|0;r=q&255;s=(d[p+(m<<5)+8|0]|0)/(q&255)|0;t=s&255;u=e|0;v=(c[(c[u>>2]|0)+416>>2]|0)==1?.5:+g[o+(m<<2)>>2];if(s<<24>>24==0){i=n;return}s=q<<24>>24==0;q=p+(m<<5)+12|0;o=(h|0)!=0;h=p+(m<<5)+4|0;w=1.0-v;p=r>>>0>1>>>0?r:1;x=0;y=0;z=k;while(1){if(s){A=y;B=z}else{k=c[q>>2]|0;C=0;D=y;E=z;while(1){F=+(b[k+((ca(d[f+C|0]|0,t)|0)+x<<1)>>1]|0)*.00048828125;do{if((c[(c[u>>2]|0)+416>>2]|0)==1){if(o){G=F+v*+g[e+400+(m*320|0)+(j*160|0)+(D<<2)>>2]}else{G=F}H=G}else{I=F;if(!o){H=I;break}H=w*I+v*+g[e+400+(m*320|0)+(j*160|0)+(D<<2)>>2]}}while(0);I=H+1.0;g[e+400+(m*320|0)+(j*160|0)+(D<<2)>>2]=F;J=(I<.1?.10000000149011612:I)*l;K=b[(c[h>>2]|0)+(D<<1)>>1]|0;L=K&65535;if(!(K<<16>>16==0)){K=E;M=L;while(1){N=M-1|0;g[K>>2]=J;if((N|0)==0){break}else{K=K+4|0;M=N}}}O=E+(L<<2)|0;M=C+1|0;if((M|0)>=(r|0)){break}C=M;D=D+1|0;E=O}A=p+y|0;B=O}E=x+1|0;if((E|0)<(t|0)){x=E;y=A;z=B}else{break}}i=n;return}function ZPa(e,f,h,i,j){e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;k=c[e+232>>2]|0;l=c[e>>2]|0;e=c[l+412>>2]|0;m=(e|0)/1e3|0;n=c[l+416>>2]|0;o=(c[l+72>>2]|0)/(n*1e3|0|0)|0;l=b[k+96>>1]|0;p=(n|0)==1;q=+((l&65535)>>>0)/+(m|0)*.2;if(p){r=+lc(+q);s=r;t=+lc(+6.0)+r}else{r=q*400.0;s=+(~~(r+.5)|0)/400.0;t=+(~~(r*6.0+.5)|0)/400.0}r=s+ +(f|0)*(t-s)/+((1<<(d[k+112|0]|0))-1|0);if(p){u=+ad(+r)}else{u=+(~~(r*400.0+.5)|0)/400.0}switch(m|0){case 44:{v=8.0;break};case 8:{v=2.0;break};case 22:{v=(o|0)==32?2.0:4.0;break};case 16:{v=3.0;break};case 11:{v=3.0;break};default:{v=4.0}}m=a[k+114|0]|0;p=m&255;f=~~(v/(+(l&65535|0)/u)*+(p|0));if((e-22e3|0)>>>0<1e3>>>0&(o|0)==32){w=~~(+(f|0)*(2.0/u+1.0)+.5)}else{w=f}v=(n|0)==2?25.0e3:2.0e4;r=v/+((1<<(d[k+115|0]|0))-1|0);s=(+(h|0)*r+r*.5)/v;if(s<-1.0){x=-1.0}else{x=s>1.0?1.0:s}s=(+$(+R(+x)*5.303304908059076)+-1.0)*v*(x>0.0?1.0:-1.0)/200.0*.0001220703125;h=i+(p<<2)|0;k=(w|0)/2|0;if((w|0)>1){n=(k|0)>1;f=0;o=i;while(1){e=j+(f<<2)|0;g[e>>2]=+g[e>>2]+s*+g[o>>2];e=f+1|0;if((e|0)<(k|0)){f=e;o=o+4|0}else{break}}y=i+((n?k:1)<<2)|0}else{y=i}i=w>>1;k=((m<<24>>24!=0?i:-i|0)+p|0)/(w|0)|0;p=~~(u+.5);i=(w|0)/-2|0;m=(w+1|0)/2|0;if((k|0)>1){w=(i|0)<(m|0);n=m-i|0;o=1;f=y;e=p;while(1){if(w){l=i;z=f;while(1){A=j+(l+e<<2)|0;g[A>>2]=+g[A>>2]+s*+g[z>>2];A=l+1|0;if((A|0)<(m|0)){l=A;z=z+4|0}else{break}}B=f+(n<<2)|0}else{B=f}z=o+1|0;l=~~(u*+(z|0)+.5);if((z|0)<(k|0)){o=z;f=B;e=l}else{C=B;D=l;break}}}else{C=y;D=p}if((i|0)<(m|0)&C>>>0<h>>>0){E=i;F=C}else{return}while(1){C=F+4|0;i=j+(E+D<<2)|0;g[i>>2]=+g[i>>2]+s*+g[F>>2];i=E+1|0;if((i|0)<(m|0)&C>>>0<h>>>0){E=i;F=C}else{break}}return}function _Pa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+1216|0;e=d|0;f=d+1024|0;mrc(f|0,0,192)|0;SFb(e,0,1);UFb(e,2489160,(g=i,i=i+8|0,c[g>>2]=2478208,g)|0);i=g;h=c[b+96>>2]|0;if((h|0)==0){j=2;k=0;l=0;m=0;n=16777215;o=16;p=e|0;q=c[p>>2]|0;r=cmb(b,q,o,n,0,m,l,k,j)|0;i=d;return r|0}aQa(f|0,h)|0;h=0;s=16;t=16777215;u=0;v=0;w=0;x=2;while(1){y=a[f+(h*24|0)|0]|0;switch(((y-65|0)>>>0<26>>>0?y^32:y)|0){case 102:{ZFb(e);y=c[f+(h*24|0)+16>>2]|0;UFb(e,2468608,(g=i,i=i+16|0,c[g>>2]=c[f+(h*24|0)+20>>2],c[g+8>>2]=y,g)|0);i=g;z=x;A=w;B=v;C=u;D=t;E=s;break};case 112:{z=8;A=w;B=v;C=u;D=t;E=s;break};case 121:{y=c[f+(h*24|0)+8>>2]|0;z=x;A=(y&4|0)==0?w:1;B=(y&1|0)==0?v:1;C=(y&2|0)==0?u:1;D=t;E=s;break};case 99:{z=x;A=w;B=v;C=u;D=c[f+(h*24|0)+8>>2]|0;E=s;break};case 115:{z=x;A=w;B=v;C=u;D=t;E=c[f+(h*24|0)+8>>2]|0;break};default:{z=x;A=w;B=v;C=u;D=t;E=s}}y=h+1|0;if(y>>>0<8>>>0){h=y;s=E;t=D;u=C;v=B;w=A;x=z}else{j=z;k=A;l=B;m=C;n=D;o=E;break}}p=e|0;q=c[p>>2]|0;r=cmb(b,q,o,n,0,m,l,k,j)|0;i=d;return r|0}function $Pa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+1248|0;h=g|0;j=g+1032|0;k=g+1040|0;l=g+1232|0;m=g+1240|0;n=d;o=c[f+24>>2]|0;p=f+28|0;q=c[p>>2]|0;r=o+q|0;mrc(k|0,0,192)|0;if((q|0)<1){s=q;i=g;return s|0}t=Bd(o|0,2450640,(u=i,i=i+8|0,c[u>>2]=g+1024,u)|0)|0;i=u;do{if((t|0)==1){if((a[o+((c[p>>2]|0)-1)|0]|0)!=10){SFb(h,0,2048);if((q|0)>0){v=7;break}else{break}}KIb(b,16,2361272,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;s=-1094995529;i=g;return s|0}else{SFb(h,0,2048);v=7}}while(0);a:do{if((v|0)==7){q=k|0;t=o;while(1){if((a[t]|0)==0){break a}w=aQa(q,t)|0;x=0;do{y=k+(x*24|0)+4|0;z=c[y>>2]|0;do{if((z|0)!=2){b:do{switch(a[k+(x*24|0)|0]|0){case 99:{UFb(h,2588952,(u=i,i=i+8|0,c[u>>2]=c[k+(x*24|0)+8>>2],u)|0);i=u;break};case 102:{A=c[k+(x*24|0)+16>>2]|0;UFb(h,2567560,(u=i,i=i+16|0,c[u>>2]=c[k+(x*24|0)+20>>2],c[u+8>>2]=A,u)|0);i=u;break};case 89:case 121:{A=c[k+(x*24|0)+8>>2]|0;if((A&1|0)!=0){UFb(h,2616192,(u=i,i=i+8|0,c[u>>2]=105,u)|0);i=u}if((A&2|0)!=0){UFb(h,2616192,(u=i,i=i+8|0,c[u>>2]=98,u)|0);i=u}if((A&4|0)!=0){UFb(h,2616192,(u=i,i=i+8|0,c[u>>2]=117,u)|0);i=u}if((A&8|0)==0){break b}UFb(h,2616192,(u=i,i=i+8|0,c[u>>2]=115,u)|0);i=u;break};case 115:{UFb(h,2549328,(u=i,i=i+8|0,c[u>>2]=c[k+(x*24|0)+8>>2],u)|0);i=u;break};case 111:{A=c[k+(x*24|0)+12>>2]|0;UFb(h,2516136,(u=i,i=i+16|0,c[u>>2]=c[k+(x*24|0)+8>>2],c[u+8>>2]=A,u)|0);i=u;break};case 112:{if((c[k+(x*24|0)+8>>2]|0)!=0){break b}UFb(h,2531384,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break};default:{}}}while(0);if((z|0)!=1){break}c[y>>2]=2}}while(0);x=x+1|0;}while(x>>>0<8>>>0);c:do{if(w>>>0<r>>>0){x=w;while(1){y=a[x]|0;if((y<<24>>24|0)==0){B=x;break c}else if((y<<24>>24|0)==124){C=7;break}WFb(h,y,1);y=x+1|0;if(y>>>0<r>>>0){x=y}else{B=y;break c}}while(1){if((c[k+(C*24|0)+4>>2]|0)==0){y=k+(C*24|0)|0;z=a[y]|0;do{if((z|0)==102){UFb(h,2121168,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u}else if((z|0)==121){A=c[k+(C*24|0)+8>>2]|0;if((A&8|0)!=0){UFb(h,2204400,(u=i,i=i+8|0,c[u>>2]=115,u)|0);i=u}if((A&4|0)!=0){UFb(h,2204400,(u=i,i=i+8|0,c[u>>2]=117,u)|0);i=u}if((A&2|0)!=0){UFb(h,2204400,(u=i,i=i+8|0,c[u>>2]=98,u)|0);i=u}if((A&1|0)==0){break}UFb(h,2204400,(u=i,i=i+8|0,c[u>>2]=105,u)|0);i=u}else if((z|0)==99){UFb(h,2144896,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u}else if((z|0)==115){UFb(h,2638720,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u}}while(0);a[y]=0}if((C|0)>0){C=C-1|0}else{break}}UFb(h,2297048,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;B=x+1|0}else{B=w}}while(0);if(B>>>0<r>>>0){t=B}else{break}}}}while(0);if((c[h+4>>2]|0)!=0){UFb(h,2246040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;_Fb(h,j)|0;h=c[j>>2]|0;if((a[h]|0)==0){D=h}else{h=f+8|0;u=c[h>>2]|0;B=c[h+4>>2]|0;h=c[f+48>>2]|0;f=b+104|0;c[l>>2]=1;c[l+4>>2]=100;b=XIb(u,B,f,l)|0;if((h|0)==-1){E=-1}else{c[m>>2]=1;c[m+4>>2]=100;l=XIb(h,(h|0)<0|0?-1:0,f,m)|0;E=l}fmb(n,c[j>>2]|0,b,E,0)|0;D=c[j>>2]|0}kJb(D)}c[e>>2]=(c[d+12>>2]|0)!=0;s=c[p>>2]|0;i=g;return s|0}function aQa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=i;i=i+24|0;f=e+8|0;c[f>>2]=d;if((a[d]|0)!=123){g=d;i=e;return g|0}h=e+16|0;j=e|0;k=d;a:while(1){d=a[k+1|0]|0;mrc(h|0,0,3)|0;if(d<<24>>24==0){g=k;l=33;break}if((a[k+2|0]|0)!=58){g=k;l=33;break}m=k+3|0;c[f>>2]=m;switch(d<<24>>24|0){case 67:{n=1;l=14;break};case 89:{o=1;l=7;break};case 72:{p=_b(m|0,125)|0;if((p|0)==0){g=k;l=33;break a}q=p-m|0;if((q|0)<0){g=k;l=33;break a}p=k+(q+3)|0;c[f>>2]=p;r=q;s=m;t=0;u=0;v=0;w=104;x=p;break};case 115:{y=0;l=22;break};case 80:{p=k+4|0;c[f>>2]=p;if((a[p]|0)==125){r=0;s=0;t=0;u=(a[m]|0)==49|0;v=1;w=112;x=p}else{g=k;l=33;break a}break};case 111:{p=rb(m|0,f|0,10)|0;q=c[f>>2]|0;if((a[q]|0)!=44){g=k;l=33;break a}z=q+1|0;c[f>>2]=z;q=rb(z|0,f|0,10)|0;z=c[f>>2]|0;if((a[z]|0)==125){r=0;s=0;t=q;u=p;v=1;w=111;x=z}else{g=k;l=33;break a}break};case 70:{A=1;l=18;break};case 83:{y=1;l=22;break};case 102:{A=0;l=18;break};case 121:{o=0;l=7;break};case 99:{n=0;l=14;break};default:{g=k;l=33;break a}}b:do{if((l|0)==7){l=0;z=0;p=m;while(1){q=a[p]|0;if((q<<24>>24|0)==0){g=k;l=33;break a}else if((q<<24>>24|0)==125){r=0;s=0;t=0;u=z;v=o;w=d;x=p;break b}B=Ob(2172496,q<<24>>24|0,5)|0;do{if((B|0)==0){C=z}else{q=B-2172496|0;if(!((q|0)>-1)){C=z;break}C=1<<q|z}}while(0);B=p+1|0;c[f>>2]=B;z=C;p=B}}else if((l|0)==14){l=0;if((a[m]|0)==36){p=k+4|0;c[f>>2]=p;D=p}else{D=m}p=(rb(D|0,f|0,16)|0)&16777215;z=c[f>>2]|0;if((a[z]|0)==125){r=0;s=0;t=0;u=p;v=n;w=99;x=z}else{g=k;l=33;break a}}else if((l|0)==18){l=0;z=_b(m|0,125)|0;if((z|0)==0){g=k;l=33;break a}p=z-m|0;if((p|0)<0){g=k;l=33;break a}z=k+(p+3)|0;c[f>>2]=z;r=p;s=m;t=0;u=0;v=A;w=102;x=z}else if((l|0)==22){l=0;z=rb(m|0,f|0,10)|0;p=c[f>>2]|0;if((a[p]|0)==125){r=0;s=0;t=0;u=z;v=y;w=115;x=p}else{g=k;l=33;break a}}}while(0);a[j]=a[h]|0;a[j+1|0]=a[h+1|0]|0;a[j+2|0]=a[h+2|0]|0;m=Ob(2502224,w<<24>>24|0,9)|0;do{if((m|0)!=0){d=m-2502224|0;if((d|0)<0){break}p=b+(d*24|0)|0;a[p]=w;d=p+1|0;a[d]=a[j]|0;a[d+1|0]=a[j+1|0]|0;a[d+2|0]=a[j+2|0]|0;c[p+4>>2]=v;c[p+8>>2]=u;c[p+12>>2]=t;c[p+16>>2]=s;c[p+20>>2]=r}}while(0);m=x+1|0;c[f>>2]=m;if((a[m]|0)==123){k=m}else{g=m;l=33;break}}if((l|0)==33){i=e;return g|0}return 0}function bQa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+60|0;e=c[d>>2]|0;f=a+64|0;c[(c[f>>2]|0)+4>>2]=1;c[e+40>>2]=0;c[e+36>>2]=15;g=$2(e+2996|0,11,127,1079576,1,1,1078744,4,4,0,0,0,0)|0;if((g|0)<0){KIb(a,16,2616152,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=g;i=b;return j|0}l8(e+1544|0,a);YJa(e+2788|0,c[a+88>>2]|0);L6(e+2672|0,e+1412|0,1644480);g=e+44|0;e=0;while(1){if(!(e>>>0<16>>>0)){j=0;k=12;break}h=UHb()|0;c[g+(e*12|0)>>2]=h;if((h|0)==0){break}else{e=e+1|0}}if((k|0)==12){i=b;return j|0}k=c[d>>2]|0;mJb(k+28|0);c[k+32>>2]=0;d=k+44|0;e=0;do{g=d+(e*12|0)|0;h=g|0;if((c[h>>2]|0)!=0){H5a(a,g)}VHb(h);e=e+1|0;}while(e>>>0<16>>>0);if((c[c[f>>2]>>2]|0)!=0){j=-12;i=b;return j|0}c3(k+2996|0);j=-12;i=b;return j|0}function cQa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=l-20|0;m=c[e+60>>2]|0;n=m;if((l|0)<21){KIb(e,16,2450528,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}q=k+20|0;r=k+2|0;s=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=k+4|0;t=(d[r]|d[r+1|0]<<8)<<16>>16;r=t&65535;u=k+6|0;v=(d[u]|d[u+1|0]<<8)<<16>>16;u=v&65535;w=k+12|0;x=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=a[k+16|0]|0;k=w&255;y=m;z=c[y>>2]|0;do{if((z|0)==0){do{if(!(t<<16>>16==160&v<<16>>16==120)){if(t<<16>>16==320&v<<16>>16==240){break}KIb(e,16,2361232,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}}while(0);c[y>>2]=e;c[e+120>>2]=r;c[e+124>>2]=u;c[e+140>>2]=0;A=-u|0;c[m+4>>2]=-(A>>3);c[m+16>>2]=r>>>3;B=-(A>>4)|0;c[m+8>>2]=B;A=r>>>4;c[m+20>>2]=A;c[m+12>>2]=B;c[m+24>>2]=A}else{if((r|0)==(c[z+120>>2]|0)){if((u|0)==(c[z+124>>2]|0)){break}}QIb(e,2297008,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1163346256;i=j;return p|0}}while(0);z=(x|0)!=0;do{if(z){x=m+44|0;if((c[c[x+((c[m+40>>2]|0)*12|0)>>2]>>2]|0)!=0){C=x;break}KIb(e,16,2245968,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=j;return p|0}else{C=m+44|0}}while(0);x=m+36|0;H5a(e,C+((c[x>>2]|0)*12|0)|0);u=c[x>>2]|0;c[(c[C+(u*12|0)>>2]|0)+88>>2]=z?2:1;r=J5a(e,C+(u*12|0)|0,1)|0;if((r|0)<0){p=r;i=j;return p|0}r=c[x>>2]|0;u=m+3020|0;c[u>>2]=r;v=m+3016|0;c[v>>2]=r+15&15;t=m+236|0;A=c[C+(r*12|0)>>2]|0;B=c[(c[y>>2]|0)+124>>2]|0;D=c[A+32>>2]|0;c[t+(r<<6)>>2]=(c[A>>2]|0)+(ca(B-1|0,D)|0);E=(B>>1)-1|0;B=A+40|0;c[t+(r<<6)+4>>2]=(c[A+8>>2]|0)+(ca(E,c[B>>2]|0)|0);F=A+36|0;c[t+(r<<6)+8>>2]=(c[A+4>>2]|0)+(ca(E,c[F>>2]|0)|0);c[t+(r<<6)+32>>2]=-D;c[t+(r<<6)+36>>2]=-(c[F>>2]|0);c[t+(r<<6)+40>>2]=-(c[B>>2]|0);K5a(e);B=m+28|0;r=B;A4a(B,m+32|0,h);B=c[r>>2]|0;if((B|0)==0){p=-12;i=j;return p|0}ef[c[m+2640>>2]&4095](B,q,h>>2);q=c[r>>2]|0;r=h<<3;h=r>>>0>2147483639>>>0|(q|0)==0;B=h?0:q;q=h?0:r;r=m+1392|0;c[r>>2]=B;c[m+1404>>2]=q;h=m+1408|0;c[h>>2]=q+8;c[m+1396>>2]=B+(q>>3);q=m+1400|0;c[q>>2]=0;B=z&1^1;t=1e4-s|0;s=m+40|0;F=m+2804|0;D=m+1264|0;E=m+1580|0;A=(w&255)>>>0>1>>>0;w=m+3e3|0;G=m+2996|0;H=m+2664|0;m=(t|0)>1e4?1e4:t;I=0;J=0;a:while(1){K=(J|0)!=0;L=K?1e3:2e3;M=((t|0)<(L|0)?L:m)<<2;L=c[x>>2]|0;N=c[n+236+(L<<6)+32+(J<<2)>>2]|0;O=n+4+(J<<2)|0;if((c[O>>2]|0)>0){P=n+16+(J<<2)|0;Q=(J|B|0)==0;R=I;S=c[n+236+(c[s>>2]<<6)+(J<<2)>>2]|0;T=c[n+236+(L<<6)+(J<<2)>>2]|0;L=0;while(1){U=c[P>>2]|0;if((U|0)>0){V=0;W=S;X=T;while(1){do{if(z){Y=c[q>>2]|0;Z=c[r>>2]|0;_=d[Z+(Y>>>3)|0]|0;$=c[h>>2]|0;aa=((Y|0)<($|0))+Y|0;c[q>>2]=aa;if(K^(_&128>>>((Y&7)>>>0)|0)!=0){M5a(n+44+((c[s>>2]|0)*12|0)|0,R,0);mf[c[F>>2]&2047](X,W,N,8);break}if(!Q){ba=25;break}Y=d[Z+(aa>>>3)|0]|0;_=((aa|0)<($|0))+aa|0;c[q>>2]=_;if((Y&128>>>((aa&7)>>>0)|0)==0){ba=25;break}aa=Z+(_>>>3)|0;Z=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7)>>>28;aa=_+4|0;c[q>>2]=$>>>0>aa>>>0?aa:$;$=c[x>>2]|0;aa=Z+$&15;Z=c[n+236+(aa<<6)>>2]|0;if((aa|0)==($|0)|(Z|0)==0){KIb(c[y>>2]|0,16,2172456,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else{M5a(n+44+(aa*12|0)|0,R,0);mf[c[F>>2]&2047](X,Z+(W-(c[n+236+(c[s>>2]<<6)+(J<<2)>>2]|0))|0,N,8);break}}else{ba=25}}while(0);if((ba|0)==25){ba=0;qe[c[E>>2]&1023](D);Z=c[q>>2]|0;aa=c[h>>2]|0;$=c[r>>2]|0;_=$+(Z>>>3)|0;Y=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(Z&7)>>>24;_=Z+8|0;Z=aa>>>0>_>>>0?_:aa;c[q>>2]=Z;b[D>>1]=Y<<3;b:do{if(A){Y=1;_=Z;da=aa;ea=$;while(1){fa=c[w>>2]|0;ga=c[G>>2]|0;ha=ea+(_>>>3)|0;ia=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(_&7)>>>((32-ga|0)>>>0);ha=b[fa+(ia<<2)>>1]|0;ja=b[fa+(ia<<2)+2>>1]|0;ia=ja<<16>>16;do{if(ja<<16>>16<0){ka=ga+_|0;la=da>>>0>ka>>>0?ka:da;ka=ea+(la>>>3)|0;ma=((je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(la&7)>>>((ia+32|0)>>>0))+ha|0;ka=b[fa+(ma<<2)>>1]|0;na=b[fa+(ma<<2)+2>>1]|0;ma=na<<16>>16;if(!(na<<16>>16<0)){oa=ma;pa=ka;qa=la;break}na=la-ia|0;la=da>>>0>na>>>0?na:da;na=ea+(la>>>3)|0;ra=((je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(la&7)>>>((ma+32|0)>>>0))+ka|0;oa=b[fa+(ra<<2)+2>>1]|0;pa=b[fa+(ra<<2)>>1]|0;qa=la}else{oa=ia;pa=ha;qa=_}}while(0);ha=oa+qa|0;ia=da>>>0>ha>>>0?ha:da;c[q>>2]=ia;if((pa|0)==0){break b}else if((pa|0)==(-1|0)){ba=36;break a}ha=(pa&15)+Y|0;fa=pa>>>4;if(ha>>>0>63>>>0){ba=36;break a}ga=ea+(ia>>>3)|0;ja=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ia&7)>>>((32-fa|0)>>>0);ga=ia+fa|0;c[q>>2]=da>>>0>ga>>>0?ga:da;ga=a[254440+(fa<<6)+ja|0]|0;if(ha>>>0<3>>>0){sa=ga<<4&65535}else{sa=((ca(M,ga)|0)/1001|0)&65535}b[n+1264+(d[n+1416+ha|0]<<1)>>1]=sa;ga=ha+1|0;if(!(ga>>>0<k>>>0)){break b}Y=ga;_=c[q>>2]|0;da=c[h>>2]|0;ea=c[r>>2]|0}}}while(0);ef[c[H>>2]&4095](X,N,D)}$=W+8|0;aa=X+8|0;Z=V+1|0;ea=c[P>>2]|0;if((Z|0)<(ea|0)){V=Z;W=$;X=aa}else{ta=$;ua=aa;va=ea;break}}}else{ta=S;ua=T;va=U}X=N-va<<3;W=R+1|0;L5a(n+44+((c[x>>2]|0)*12|0)|0,R,0);V=L+1|0;if((V|0)<(c[O>>2]|0)){R=W;S=ta+X|0;T=ua+X|0;L=V}else{wa=W;break}}}else{wa=I}L=J+1|0;if((L|0)<3){I=wa;J=L}else{xa=0;break}}if((ba|0)==36){KIb(c[y>>2]|0,16,2204376,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;xa=-1094995529}L5a(C+((c[x>>2]|0)*12|0)|0,2147483647,0);do{if((xa|0)<0){if((c[e+816>>2]&1|0)!=0){break}H5a(e,C+((c[x>>2]|0)*12|0)|0);p=xa;i=j;return p|0}}while(0);xa=YHb(f,c[C+((c[x>>2]|0)*12|0)>>2]|0)|0;if((xa|0)<0){p=xa;i=j;return p|0}c[g>>2]=1;c[s>>2]=c[u>>2];u=c[v>>2]|0;c[x>>2]=u;H5a(e,C+(u*12|0)|0);p=l;i=j;return p|0}function dQa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+60>>2]|0;mJb(b+28|0);c[b+32>>2]=0;d=b+44|0;e=0;do{f=d+(e*12|0)|0;g=f|0;if((c[g>>2]|0)!=0){H5a(a,f)}VHb(g);e=e+1|0;}while(e>>>0<16>>>0);if((c[c[a+64>>2]>>2]|0)!=0){return 0}c3(b+2996|0);return 0}function eQa(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=0;i=0;j=1;while(1){k=a[f+j|0]|0;l=k&255;if(k<<24>>24==0){m=h;n=i}else{k=j&255;o=l>>>0>1>>>0?l:1;p=i+o|0;q=h;r=0;s=i;while(1){t=d[g+q|0]|0;a[c+t|0]=k;b[e+(t<<1)>>1]=s;t=r+1|0;if((t|0)<(l|0)){q=q+1|0;r=t;s=s+1|0}else{break}}m=h+o|0;n=p}s=j+1|0;if((s|0)<17){h=m;i=n<<1;j=s}else{break}}return}function fQa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;f=c[a+60>>2]|0;k=f;l=f+1144|0;c[l>>2]=0;m=f+2944|0;c[m>>2]=0;n=f+2948|0;c[n>>2]=0;o=f+2964|0;c[o>>2]=0;p=h+j|0;if((j|0)>268435455){q=-1094995529;i=g;return q|0}r=a;s=f+8|0;t=f+20|0;u=f+24|0;v=f+12|0;w=f+16|0;x=f+28|0;y=a+696|0;z=f+816|0;A=f+820|0;B=f+2960|0;C=h;D=j;a:while(1){E=D<<3;F=E>>>0>2147483639>>>0|(C|0)==0;G=F?0:C;H=F?8:E+8|0;E=H>>>0>32>>>0?32:H;F=G+(E>>>3)|0;I=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)&-65536;F=E+16|0;E=H>>>0>F>>>0?F:H;F=G+(E>>>3)|0;J=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>16;F=E+16|0;E=H>>>0>F>>>0?F:H;if((J|I|0)!=1835692135){K=4;break}I=G+(E>>>3)|0;J=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(E&7)&-65536;I=E+16|0;E=H>>>0>I>>>0?I:H;I=G+(E>>>3)|0;F=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(E&7)>>>16;I=E+16|0;E=F|J;KIb(r,48,2361168,(L=i,i=i+8|0,c[L>>2]=E,L)|0);i=L;J=(H>>>0>I>>>0?I:H)+32|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;F=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)&-65536;J=I+16|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;M=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)>>>16;J=I+16|0;I=H>>>0>J>>>0?J:H;J=M|F;if(J>>>0<D>>>0){N=J}else{KIb(r,24,2296928,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;N=0}KIb(r,48,2245912,(L=i,i=i+8|0,c[L>>2]=N,L)|0);i=L;J=G+(I>>>3)|0;F=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)&-65536;J=I+16|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;M=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)>>>16;J=I+16|0;I=H>>>0>J>>>0?J:H;J=M|F;do{if(J>>>0<D>>>0){KIb(r,48,2172408,(L=i,i=i+8|0,c[L>>2]=J,L)|0);i=L;if((J|0)==0){break}F=C+J|0;M=p-F<<3;O=M>>>0>2147483639>>>0|(F|0)==0;P=O?0:F;F=O?0:M;c[s>>2]=P;c[t>>2]=F;c[u>>2]=F+8;c[v>>2]=P+(F>>3);c[w>>2]=0;c[x>>2]=219;if((iQa(k)|0)>=0){break}if((c[y>>2]&8|0)!=0){q=-1094995529;K=36;break a}}else{KIb(r,24,2204320,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;KIb(r,48,2172408,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L}}while(0);J=G+(I>>>3)|0;F=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)&-65536;J=I+16|0;P=H>>>0>J>>>0?J:H;J=G+(P>>>3)|0;M=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(P&7)>>>16;J=P+16|0;P=H>>>0>J>>>0?J:H;J=M|F;do{if(J>>>0<D>>>0){KIb(r,48,2121152,(L=i,i=i+8|0,c[L>>2]=J,L)|0);i=L;if((J|0)==0){break}F=C+J|0;M=p-F<<3;O=M>>>0>2147483639>>>0|(F|0)==0;Q=O?0:F;F=O?0:M;c[s>>2]=Q;c[t>>2]=F;c[u>>2]=F+8;c[v>>2]=Q+(F>>3);c[w>>2]=0;c[x>>2]=196;hQa(k)|0}else{KIb(r,24,2144864,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;KIb(r,48,2121152,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L}}while(0);J=G+(P>>>3)|0;I=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(P&7)&-65536;J=P+16|0;F=H>>>0>J>>>0?J:H;J=G+(F>>>3)|0;Q=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(F&7)>>>16;J=F+16|0;F=H>>>0>J>>>0?J:H;J=Q|I;do{if(J>>>0<D>>>0){KIb(r,48,2616136,(L=i,i=i+8|0,c[L>>2]=J,L)|0);i=L;if((J|0)==0){break}I=C+J|0;Q=p-I<<3;M=Q>>>0>2147483639>>>0|(I|0)==0;O=M?0:I;I=M?0:Q;c[s>>2]=O;c[t>>2]=I;c[u>>2]=I+8;c[v>>2]=O+(I>>3);c[w>>2]=0;c[x>>2]=192;if((kQa(k)|0)<0){q=-1;K=36;break a}}else{KIb(r,24,2638688,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;KIb(r,48,2616136,(L=i,i=i+8|0,c[L>>2]=0,L)|0);i=L}}while(0);J=G+(F>>>3)|0;P=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(F&7)&-65536;J=F+16|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;O=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)>>>16;J=I+16|0;I=H>>>0>J>>>0?J:H;J=O|P;if(J>>>0<D>>>0){R=J}else{KIb(r,24,2588912,(L=i,i=i+16|0,c[L>>2]=J,c[L+8>>2]=D,L)|0);i=L;R=0}KIb(r,48,2567528,(L=i,i=i+8|0,c[L>>2]=R,L)|0);i=L;J=G+(I>>>3)|0;P=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)&-65536;J=I+16|0;I=H>>>0>J>>>0?J:H;J=G+(I>>>3)|0;O=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(I&7)>>>16|P;if(O>>>0<D>>>0){S=O}else{KIb(r,24,2638688,(L=i,i=i+16|0,c[L>>2]=O,c[L+8>>2]=D,L)|0);i=L;S=0}KIb(r,48,2549288,(L=i,i=i+8|0,c[L>>2]=S,L)|0);i=L;do{if((R|0)!=0){O=C+R|0;P=D-R|0;I=(E>>>0>P>>>0?P:E)<<3;P=I>>>0>2147483639>>>0|(O|0)==0;J=P?0:O;O=P?0:I;c[s>>2]=J;c[t>>2]=O;c[u>>2]=O+8;c[v>>2]=J+(O>>3);c[w>>2]=0;O=J;c[o>>2]=S-R-((je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)>>>16);c[x>>2]=218;if((lQa(k,0,0,0)|0)>=0){break}if((c[y>>2]&8|0)!=0){q=-1094995529;K=36;break a}}}while(0);if((c[z>>2]|0)==0){K=30;break}E=c[A>>2]^1;c[A>>2]=E;if((E|0)==(c[B>>2]|0)|(N|0)==0){K=30;break}c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;E=j-N|0;if((E|0)>268435455){q=-1094995529;K=36;break}else{C=h+N|0;D=E}}if((K|0)==4){KIb(r,24,2450456,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=-1094995529;i=g;return q|0}else if((K|0)==30){if((c[l>>2]|0)==0){KIb(r,24,2531336,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;q=j;i=g;return q|0}l=YHb(b,c[f+1140>>2]|0)|0;if((l|0)<0){q=l;i=g;return q|0}c[e>>2]=1;if((c[f+824>>2]|0)!=0){q=j;i=g;return q|0}if((c[a+688>>2]&16|0)==0){q=j;i=g;return q|0}a=c[f+792>>2]|0;e=c[f+796>>2]|0;l=(a|0)>(e|0)?a:e;e=c[f+800>>2]|0;KIb(r,48,2516128,(L=i,i=i+8|0,c[L>>2]=(l|0)>(e|0)?l:e,L)|0);i=L;q=j;i=g;return q|0}else if((K|0)==36){i=g;return q|0}return 0}function gQa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;f=i;i=i+15360|0;g=f|0;h=f+256|0;j=f+768|0;k=f+1280|0;l=f+1536|0;m=f+2048|0;n=f+2560|0;o=f+2816|0;p=f+3328|0;q=f+3840|0;r=f+4096|0;s=f+4608|0;t=f+5120|0;u=f+5376|0;v=f+5888|0;w=f+6400|0;x=f+6656|0;y=f+7168|0;z=f+7680|0;A=f+7936|0;B=f+8448|0;C=f+8960|0;D=f+9216|0;E=f+9728|0;F=f+10240|0;G=f+10496|0;H=f+11008|0;I=f+11520|0;J=f+11776|0;K=f+12288|0;L=f+12800|0;M=f+13056|0;N=f+13568|0;O=f+14080|0;P=f+14336|0;Q=f+14848|0;R=c[e+60>>2]|0;S=R;T=R+1140|0;do{if((c[T>>2]|0)==0){U=UHb()|0;c[R+1136>>2]=U;if((U|0)==0){V=-12;i=f;return V|0}else{c[T>>2]=U;break}}}while(0);T=R+4|0;c[T>>2]=e;YJa(R+2736|0,c[e+88>>2]|0);l8(R+1492|0,e);L6(R+2620|0,R+1360|0,1242080);c[R+32>>2]=0;c[R+36>>2]=0;c[R+28>>2]=-1;c[R+812>>2]=1;c[R+1144>>2]=0;c[R+808>>2]=c[e+132>>2];c[e+400>>2]=2;U=R+552|0;W=I|0;I=J;X=K;mrc(W|0,0,256)|0;eQa(W,J|0,1965720,1965368);J=0;do{b[K+(J<<1)>>1]=J;J=J+1|0;}while((J|0)<256);J=U;$2(J,9,12,W,1,1,I,2,2,X,2,2,0)|0;X=R+572|0;I=F|0;F=G;W=H;mrc(I|0,0,256)|0;eQa(I,G|0,1965744,1965368);G=0;do{b[H+(G<<1)>>1]=G;G=G+1|0;}while((G|0)<256);G=X;$2(G,9,12,I,1,1,F,2,2,W,2,2,0)|0;W=R+632|0;F=C|0;C=D;I=E;mrc(F|0,0,256)|0;eQa(F,D|0,1965768,1965384);D=0;do{b[E+(D<<1)>>1]=D+16;D=D+1|0;}while((D|0)<256);D=W;b[E>>1]=4096;$2(D,9,251,F,1,1,C,2,2,I,2,2,0)|0;I=R+652|0;C=z|0;z=A;F=B;mrc(C|0,0,256)|0;eQa(C,A|0,1965792,1965552);A=0;do{b[B+(A<<1)>>1]=A+16;A=A+1|0;}while((A|0)<256);A=I;b[B>>1]=4096;$2(A,9,251,C,1,1,z,2,2,F,2,2,0)|0;F=R+712|0;z=w|0;w=x;C=y;mrc(z|0,0,256)|0;eQa(z,x|0,1965768,1965384);x=0;do{b[y+(x<<1)>>1]=x;x=x+1|0;}while((x|0)<256);x=F;$2(x,9,251,z,1,1,w,2,2,C,2,2,0)|0;C=R+732|0;w=O|0;O=P;z=Q;mrc(w|0,0,256)|0;eQa(w,P|0,1965792,1965552);P=0;do{b[Q+(P<<1)>>1]=P;P=P+1|0;}while((P|0)<256);P=C;$2(P,9,251,w,1,1,O,2,2,z,2,2,0)|0;do{if((c[R+2984>>2]|0)!=0){z=e;KIb(z,32,2513184,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;O=c[e+96>>2]|0;w=c[e+100>>2]<<3;C=w>>>0>2147483639>>>0|(O|0)==0;Q=C?0:O;O=C?0:w;c[R+8>>2]=Q;c[R+20>>2]=O;c[R+24>>2]=O+8;c[R+12>>2]=Q+(O>>3);c[R+16>>2]=0;if((hQa(S)|0)==0){break}KIb(z,16,2601608,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;z=t|0;O=u;Q=v;mrc(z|0,0,256)|0;eQa(z,u|0,1965720,1965368);w=0;do{b[v+(w<<1)>>1]=w;w=w+1|0;}while((w|0)<256);$2(J,9,12,z,1,1,O,2,2,Q,2,2,0)|0;w=q|0;C=r;F=s;mrc(w|0,0,256)|0;eQa(w,r|0,1965744,1965368);y=0;do{b[s+(y<<1)>>1]=y;y=y+1|0;}while((y|0)<256);$2(G,9,12,w,1,1,C,2,2,F,2,2,0)|0;y=n|0;Q=o;O=p;mrc(y|0,0,256)|0;eQa(y,o|0,1965768,1965384);z=0;do{b[p+(z<<1)>>1]=z+16;z=z+1|0;}while((z|0)<256);b[p>>1]=4096;$2(D,9,251,y,1,1,Q,2,2,O,2,2,0)|0;z=k|0;F=l;C=m;mrc(z|0,0,256)|0;eQa(z,l|0,1965792,1965552);w=0;do{b[m+(w<<1)>>1]=w+16;w=w+1|0;}while((w|0)<256);b[m>>1]=4096;$2(A,9,251,z,1,1,F,2,2,C,2,2,0)|0;w=g|0;O=h;Q=j;mrc(w|0,0,256)|0;eQa(w,h|0,1965768,1965384);y=0;do{b[j+(y<<1)>>1]=y;y=y+1|0;}while((y|0)<256);$2(x,9,251,w,1,1,O,2,2,Q,2,2,0)|0;y=L|0;C=M;F=N;mrc(y|0,0,256)|0;eQa(y,M|0,1965792,1965552);z=0;do{b[N+(z<<1)>>1]=z;z=z+1|0;}while((z|0)<256);$2(P,9,251,y,1,1,C,2,2,F,2,2,0)|0}}while(0);P=c[e+408>>2]|0;do{if((P|0)==3){c[R+2960>>2]=1;KIb(e,48,2450432,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y}else if((P|0)==0){if((c[e+52>>2]|0)!=1196444237){break}c[R+2960>>2]=1}}while(0);P=c[e+100>>2]|0;do{if((P|0)>8){N=c[e+96>>2]|0;M=N;if((d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)!=44){break}M=N+4|0;if((d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)!=24){break}c[R+2952>>2]=1;M=(P|0)>14;do{if(M){L=N+12|0;x=a[L]|0;if(x<<24>>24==1){c[R+2960>>2]=1;Z=a[L]|0}else{Z=x}if(!(Z<<24>>24==2)){break}c[R+2960>>2]=0}}while(0);F=c[T>>2]|0;if((c[F+688>>2]&1|0)==0){break}if(M){_=d[N+12|0]|0}else{_=-1}KIb(F,32,2623240,(Y=i,i=i+16|0,c[Y>>2]=P,c[Y+8>>2]=_,Y)|0);i=Y}}while(0);if((c[(c[e+12>>2]|0)+12>>2]|0)!=108){V=0;i=f;return V|0}c[R+2972>>2]=1;V=0;i=f;return V|0}function hQa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+280|0;f=e|0;g=e+24|0;h=b+16|0;j=c[h>>2]|0;k=b+24|0;l=c[k>>2]|0;m=b+8|0;n=(c[m>>2]|0)+(j>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(j&7)>>>16;n=j+16|0;c[h>>2]=l>>>0>n>>>0?n:l;l=o-2|0;if((l|0)<=0){p=0;i=e;return p|0}o=b+4|0;n=f|0;j=g|0;q=l;while(1){if((q|0)<17){p=-1094995529;r=15;break}l=c[h>>2]|0;s=c[k>>2]|0;t=c[m>>2]|0;u=t+(l>>>3)|0;v=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(l&7);u=v>>>28;w=l+4|0;l=s>>>0>w>>>0?w:s;c[h>>2]=l;if(v>>>0>536870911>>>0){p=-1094995529;r=15;break}v=t+(l>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(l&7);v=w>>>28;x=l+4|0;l=s>>>0>x>>>0?x:s;c[h>>2]=l;if(w>>>0>1073741823>>>0){p=-1094995529;r=15;break}else{y=1;z=0;A=l}do{l=t+(A>>>3)|0;w=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(A&7)>>>24;l=A+8|0;A=s>>>0>l>>>0?l:s;c[h>>2]=A;a[f+y|0]=w;z=w+z|0;y=y+1|0;}while((y|0)<17);w=q-17|0;if((w|0)<(z|0)|(z|0)>256){p=-1094995529;r=15;break}if((z|0)>0){l=0;x=0;B=A;do{C=t+(B>>>3)|0;D=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7)>>>24;C=B+8|0;B=s>>>0>C>>>0?C:s;c[h>>2]=B;x=(D|0)>(x|0)?D:x;a[g+l|0]=D;l=l+1|0;}while((l|0)<(z|0));E=x+1|0}else{E=1}l=w-z|0;B=b+552+(u*80|0)+(v*20|0)|0;c3(B);KIb(c[o>>2]|0,48,2172376,(s=i,i=i+24|0,c[s>>2]=u,c[s+8>>2]=v,c[s+16>>2]=E,s)|0);i=s;s=(u|0)!=0;t=jQa(B,n,j,E,s&1)|0;if((t|0)<0){p=t;r=15;break}if(s){s=b+712+(v*20|0)|0;c3(s);t=jQa(s,n,j,E,0)|0;if((t|0)<0){p=t;r=15;break}}if((l|0)>0){q=l}else{p=0;r=15;break}}if((r|0)==15){i=e;return p|0}return 0}function iQa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;f=a+16|0;g=c[f>>2]|0;h=a+24|0;j=c[h>>2]|0;k=a+8|0;l=c[k>>2]|0;m=l+(g>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(g&7)>>>16;m=g+16|0;g=j>>>0>m>>>0?m:j;c[f>>2]=g;m=n-2|0;if((m|0)<=64){o=0;i=e;return o|0}n=a+4|0;p=a+1365|0;q=a+1372|0;r=m;m=g;g=j;j=l;while(1){l=j+(m>>>3)|0;s=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7);l=m+4|0;t=g>>>0>l>>>0?l:g;c[f>>2]=t;if(s>>>0>536870911>>>0){u=4;break}l=j+(t>>>3)|0;v=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(t&7);l=v>>>28;w=t+4|0;c[f>>2]=g>>>0>w>>>0?w:g;if(v>>>0>1073741823>>>0){o=-1;u=10;break}KIb(c[n>>2]|0,48,2245896,(x=i,i=i+8|0,c[x>>2]=l,x)|0);i=x;v=s>>>0>268435455>>>0?16:8;s=32-v|0;w=0;do{t=d[a+1364+w|0]|0;y=c[f>>2]|0;z=c[h>>2]|0;A=(c[k>>2]|0)+(y>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7)>>>(s>>>0);A=y+v|0;c[f>>2]=z>>>0>A>>>0?A:z;b[a+40+(l<<7)+(t<<1)>>1]=B;w=w+1|0;}while((w|0)<64);w=b[a+40+(l<<7)+((d[p]|0)<<1)>>1]|0;v=b[a+40+(l<<7)+((d[q]|0)<<1)>>1]|0;s=(w<<16>>16>v<<16>>16?w:v)<<16>>16>>1;c[a+792+(l<<2)>>2]=s;KIb(c[n>>2]|0,48,2204304,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=s,x)|0);i=x;s=r-65|0;if((s|0)<=64){o=0;u=10;break}r=s;m=c[f>>2]|0;g=c[h>>2]|0;j=c[k>>2]|0}if((u|0)==4){KIb(c[n>>2]|0,16,2296904,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;o=-1094995529;i=e;return o|0}else if((u|0)==10){i=e;return o|0}return 0}function jQa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+1280|0;j=h+256|0;k=h+768|0;l=h|0;mrc(l|0,0,256)|0;if((f|0)>=257){KIb(0,0,2489128,(m=i,i=i+24|0,c[m>>2]=2624736,c[m+8>>2]=2468584,c[m+16>>2]=56,m)|0);i=m;Hd();return 0}eQa(l,j|0,d,e);e=g<<4;d=0;do{b[k+(d<<1)>>1]=d+e;d=d+1|0;}while((d|0)<256);if((g|0)==0){n=j;o=k;p=$2(a,9,f,l,1,1,n,2,2,o,2,2,0)|0;i=h;return p|0}b[k>>1]=4096;n=j;o=k;p=$2(a,9,f,l,1,1,n,2,2,o,2,2,0)|0;i=h;return p|0}function kQa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;b=i;i=i+32|0;e=b|0;f=b+16|0;c[a+2968>>2]=0;g=a+848|0;c[g>>2]=0;h=a+840|0;c[h>>2]=0;j=a+16|0;k=c[j>>2]|0;l=a+24|0;m=c[l>>2]|0;n=a+8|0;o=c[n>>2]|0;p=o+(k>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(k&7)>>>16;p=k+16|0;k=m>>>0>p>>>0?p:m;c[j>>2]=k;p=o+(k>>>3)|0;r=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(k&7)>>>24;p=k+8|0;c[j>>2]=m>>>0>p>>>0?p:m;m=a+860|0;c[m>>2]=r;p=a+4|0;k=c[p>>2]|0;c[k+796>>2]=r;do{if((c[a+856>>2]|0)==0){if((c[m>>2]|0)!=9){break}c[a+852>>2]=1}else{c[m>>2]=9}}while(0);r=a+824|0;do{if((c[r>>2]|0)!=0){if((c[k+800>>2]|0)==0){break}KIb(k,16,2144816,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1;i=b;return t|0}}while(0);u=c[j>>2]|0;v=c[l>>2]|0;w=o+(u>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>16;w=u+16|0;u=v>>>0>w>>>0?w:v;c[j>>2]=u;w=o+(u>>>3)|0;o=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>16;w=u+16|0;c[j>>2]=v>>>0>w>>>0?w:v;v=a+816|0;do{if((c[v>>2]|0)==0){y=x}else{if((c[a+900>>2]|0)!=(o|0)){y=x;break}w=c[a+904>>2]|0;y=(w|0)==(x+1|0)?w:x}}while(0);KIb(k,48,2121128,(s=i,i=i+16|0,c[s>>2]=o,c[s+8>>2]=y,s)|0);i=s;if((tIb(o,y,0,c[p>>2]|0)|0)!=0){t=-1094995529;i=b;return t|0}k=c[j>>2]|0;x=c[l>>2]|0;w=c[n>>2]|0;u=w+(k>>>3)|0;z=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(k&7)>>>24;u=k+8|0;k=x>>>0>u>>>0?u:x;c[j>>2]=k;if((z-1|0)>>>0>3>>>0){t=-1;i=b;return t|0}do{if((c[v>>2]|0)!=0){if((c[a+820>>2]|0)!=((c[a+2960>>2]|0)==0|0)){break}if((z|0)==(c[a+916>>2]|0)){break}KIb(c[p>>2]|0,16,2638640,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=b;return t|0}}while(0);u=a+828|0;A=c[u>>2]|0;do{if((A|0)!=0){if((c[m>>2]|0)<9|(z|0)==1){break}RIb(c[p>>2]|0,2616080,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1163346256;i=b;return t|0}}while(0);B=a+916|0;c[B>>2]=z;C=a+1096|0;c[C>>2]=1;D=a+1100|0;c[D>>2]=1;E=e;mrc(E|0,0,16)|0;F=f;mrc(F|0,0,16)|0;do{if((z|0)==0){G=A}else{H=0;I=k;J=x;K=w;while(1){L=K+(I>>>3)|0;M=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(I&7)>>>24;L=I+8|0;c[j>>2]=J>>>0>L>>>0?L:J;L=a+936+(H<<2)|0;c[L>>2]=M-1;M=c[j>>2]|0;N=c[l>>2]|0;O=c[n>>2]|0;P=O+(M>>>3)|0;Q=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7)>>>28;P=M+4|0;M=N>>>0>P>>>0?P:N;c[j>>2]=M;c[e+(H<<2)>>2]=Q;P=O+(M>>>3)|0;R=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7)>>>28;P=M+4|0;M=N>>>0>P>>>0?P:N;c[j>>2]=M;c[f+(H<<2)>>2]=R;if((Q|0)>(c[C>>2]|0)){c[C>>2]=Q}if((R|0)>(c[D>>2]|0)){c[D>>2]=R}P=O+(M>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7);P=O>>>24;S=M+8|0;c[j>>2]=N>>>0>S>>>0?S:N;c[a+1104+(H<<2)>>2]=P;if(O>>>0>67108863>>>0){T=26;break}if((Q|0)==0){U=R;T=29;break}if((R|0)==0){U=0;T=29;break}O=c[L>>2]|0;KIb(c[p>>2]|0,48,2549248,(s=i,i=i+40|0,c[s>>2]=H,c[s+8>>2]=Q,c[s+16>>2]=R,c[s+24>>2]=O,c[s+32>>2]=P,s)|0);i=s;P=H+1|0;if((P|0)>=(z|0)){T=32;break}H=P;I=c[j>>2]|0;J=c[l>>2]|0;K=c[n>>2]|0}if((T|0)==26){KIb(c[p>>2]|0,16,2588888,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=b;return t|0}else if((T|0)==29){KIb(c[p>>2]|0,16,2567480,(s=i,i=i+24|0,c[s>>2]=H,c[s+8>>2]=Q,c[s+16>>2]=U,s)|0);i=s;t=-1094995529;i=b;return t|0}else if((T|0)==32){G=c[u>>2]|0;break}}}while(0);do{if((G|0)!=0){if((c[C>>2]|0)<=1){if((c[D>>2]|0)<=1){break}}RIb(c[p>>2]|0,2531312,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1163346256;i=b;return t|0}}while(0);G=a+900|0;U=a+904|0;do{if((o|0)==(c[G>>2]|0)){if((y|0)!=(c[U>>2]|0)){T=42;break}if((grc(a+952|0,E,16)|0)!=0){T=42;break}if((grc(a+968|0,F,16)|0)!=0){T=42;break}V=y;W=a+1144|0}else{T=42}}while(0);do{if((T|0)==42){c[G>>2]=o;c[U>>2]=y;Q=a+952|0;c[Q>>2]=c[E>>2];c[Q+4>>2]=c[E+4>>2];c[Q+8>>2]=c[E+8>>2];c[Q+12>>2]=c[E+12>>2];Q=a+968|0;c[Q>>2]=c[F>>2];c[Q+4>>2]=c[F+4>>2];c[Q+8>>2]=c[F+8>>2];c[Q+12>>2]=c[F+12>>2];c[v>>2]=0;Q=a+1144|0;c[Q>>2]=0;n=a+812|0;do{if((c[n>>2]|0)==0){X=y}else{l=c[a+808>>2]|0;if((l|0)==0){X=y;break}if((y|0)>=((l*3|0|0)/4|0|0)){X=y;break}c[v>>2]=1;l=a+2960|0;c[a+820>>2]=c[l>>2];j=c[a+1140>>2]|0;c[j+296>>2]=1;c[j+300>>2]=(c[l>>2]|0)==0;X=y<<1}}while(0);H=H4a(c[p>>2]|0,o,X)|0;if((H|0)<0){t=H;i=b;return t|0}else{c[n>>2]=0;V=X;W=Q;break}}}while(0);do{if((c[W>>2]|0)==0){T=53}else{if((c[v>>2]|0)==0){T=53;break}if((c[a+820>>2]|0)!=((c[a+2960>>2]|0)==0|0)){T=53;break}if((c[a+832>>2]|0)==0){break}QIb(c[p>>2]|0,2516080,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=b;return t|0}}while(0);do{if((T|0)==53){do{if((c[D>>2]|0)==1){if((c[C>>2]|0)!=1){T=58;break}X=c[r>>2]|0;if((X|0)!=1){Y=X;T=59;break}if(!((z-3|0)>>>0<2>>>0)){T=58;break}c[a+836>>2]=1}else{T=58}}while(0);if((T|0)==58){Y=c[r>>2]|0;T=59}do{if((T|0)==59){if((Y|0)!=0){break}c[a+836>>2]=0}}while(0);Q=c[a+968>>2]<<24|c[a+952>>2]<<28|c[a+956>>2]<<20|c[a+972>>2]<<16|c[a+960>>2]<<12|c[a+976>>2]<<8|c[a+964>>2]<<4|c[a+980>>2];KIb(c[p>>2]|0,48,2502200,(s=i,i=i+8|0,c[s>>2]=Q,s)|0);i=s;if((Q&-791621424|0)==0){Z=Q-(Q>>>1&2021161080)|0}else{Z=Q}if((Z&218959117|0)==0){_=Z-(Z>>>1&126322567)|0}else{_=Z}do{if((_|0)==303173888|(_|0)==571613440){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}n=(c[a+2956>>2]|0)!=0;X=c[p>>2]|0;c[X+140>>2]=n?5:14;c[X+396>>2]=n?1:2;c[g>>2]=2;c[h>>2]=(_|0)==571613440;c[a+844>>2]=c[a+904>>2];$=X;aa=Q}else if((_|0)==555815168|(_|0)==572592640){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}X=(c[a+2956>>2]|0)!=0;n=c[p>>2]|0;c[n+140>>2]=X?5:14;c[n+396>>2]=X?1:2;c[g>>2]=(_|0)==572592640;c[h>>2]=2;c[a+844>>2]=c[a+904>>2];$=n;aa=Q}else if((_|0)==571609344|(_|0)==571544064){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}n=(c[a+2956>>2]|0)!=0;X=c[p>>2]|0;c[X+140>>2]=n?4:13;c[X+396>>2]=n?1:2;c[g>>2]=(_|0)==571609344?2:1;$=X;aa=Q}else if((_|0)==571543808){Q=c[m>>2]|0;if((Q|0)<9){X=c[a+2956>>2]|0;n=c[p>>2]|0;c[n+140>>2]=(X|0)!=0?0:12;ba=X;da=n}else{n=c[p>>2]|0;c[n+140>>2]=54;ba=c[a+2956>>2]|0;da=n}c[da+396>>2]=(ba|0)!=0?1:2;$=da;aa=Q}else if((_|0)==572657920){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}n=(c[a+2956>>2]|0)!=0;X=c[p>>2]|0;c[X+140>>2]=n?5:14;c[X+396>>2]=n?1:2;c[g>>2]=2;c[h>>2]=2;c[a+844>>2]=(c[a+904>>2]|0)/2|0;$=X;aa=Q}else if((_|0)==285212672|(_|0)==318767104|(_|0)==335544320|(_|0)==822083584|(_|0)==855638016|(_|0)==872415232|(_|0)==1090519040|(_|0)==1124073472|(_|0)==1140850688){Q=c[m>>2]|0;X=c[p>>2]|0;n=X+140|0;if((Q|0)<9){c[n>>2]=8;$=X;aa=Q;break}else{c[n>>2]=32;$=X;aa=Q;break}}else if((_|0)==286331153){do{if((c[a+836>>2]|0)==0){Q=c[m>>2]|0;if((c[a+872>>2]|0)==0&(Q|0)<9){X=c[p>>2]|0;c[X+140>>2]=317;ea=X;fa=Q;break}else{X=c[p>>2]|0;c[X+140>>2]=(Q|0)<9?299:108;c[X+396>>2]=(c[a+2956>>2]|0)!=0?1:2;ea=X;fa=Q;break}}else{Q=c[m>>2]|0;X=c[p>>2]|0;c[X+140>>2]=(Q|0)<10?29:292;ea=X;fa=Q}}while(0);if((c[B>>2]|0)==4){$=ea;aa=fa;break}KIb(0,0,2489128,(s=i,i=i+24|0,c[s>>2]=2459288,c[s+8>>2]=2468584,c[s+16>>2]=409,s)|0);i=s;Hd();return 0}else if((_|0)==286331136){a:do{if((c[a+836>>2]|0)==0){do{if((c[a+936>>2]|0)==81){if((c[a+940>>2]|0)!=70){break}if((c[a+944>>2]|0)!=65){break}Q=c[m>>2]|0;X=c[p>>2]|0;c[X+140>>2]=(Q|0)<9?82:88;ga=X;ha=Q;break a}}while(0);Q=c[m>>2]|0;if((Q|0)<9){X=c[a+2956>>2]|0;n=c[p>>2]|0;c[n+140>>2]=(X|0)!=0?5:14;ia=X;ja=n}else{n=c[p>>2]|0;c[n+140>>2]=58;ia=c[a+2956>>2]|0;ja=n}c[ja+396>>2]=(ia|0)!=0?1:2;ga=ja;ha=Q}else{Q=c[m>>2]|0;n=c[p>>2]|0;c[n+140>>2]=(Q|0)<10?3:68;ga=n;ha=Q}}while(0);if((c[B>>2]|0)==3){$=ga;aa=ha;break}KIb(0,0,2489128,(s=i,i=i+24|0,c[s>>2]=2478184,c[s+8>>2]=2468584,c[s+16>>2]=396,s)|0);i=s;Hd();return 0}else if((_|0)==1091637504){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}n=(c[a+2956>>2]|0)!=0;X=c[p>>2]|0;c[X+140>>2]=n?7:320;c[X+396>>2]=n?1:2;$=X;aa=Q}else if((_|0)==303108352|(_|0)==572592384|(_|0)==571547904){Q=c[m>>2]|0;if((Q|0)>=9){T=108;break}X=(c[a+2956>>2]|0)!=0;n=c[p>>2]|0;c[n+140>>2]=X?33:34;c[n+396>>2]=X?1:2;c[h>>2]=((_|0)==572592384)<<1|(_|0)==571547904;c[a+844>>2]=(c[a+904>>2]|0)/2|0;$=n;aa=Q}else if((_|0)==554766592){Q=c[m>>2]|0;if((Q|0)<9){n=c[a+2956>>2]|0;X=c[p>>2]|0;c[X+140>>2]=(n|0)!=0?4:13;ka=n;la=X}else{X=c[p>>2]|0;c[X+140>>2]=56;ka=c[a+2956>>2]|0;la=X}c[la+396>>2]=(ka|0)!=0?1:2;$=la;aa=Q}else{T=108}}while(0);if((T|0)==108){KIb(c[p>>2]|0,16,2442536,(s=i,i=i+8|0,c[s>>2]=_,s)|0);i=s;t=-1163346256;i=b;return t|0}if((c[h>>2]|0)==0){if((c[g>>2]|0)!=0){T=111}}else{T=111}do{if((T|0)==111){if((c[$+800>>2]|0)==0){break}KIb($,16,2430456,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1163346256;i=b;return t|0}}while(0);do{if((c[u>>2]|0)==0){ma=c[$+140>>2]|0}else{c[g>>2]=0;c[h>>2]=0;if((c[B>>2]|0)>1){c[$+140>>2]=2;ma=2;break}Q=$+140|0;if((aa|0)<9){c[Q>>2]=8;ma=8;break}else{c[Q>>2]=32;ma=32;break}}}while(0);Q=qKb(ma)|0;c[a+2996>>2]=Q;if((Q|0)==0){KIb(c[p>>2]|0,16,2420136,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-558323010;i=b;return t|0}Q=a+1140|0;WHb(c[Q>>2]|0);if((M4a(c[p>>2]|0,c[Q>>2]|0,1)|0)<0){t=-1;i=b;return t|0}X=c[Q>>2]|0;c[X+88>>2]=1;c[X+84>>2]=1;c[W>>2]=1;Q=c[v>>2]|0;c[a+1148>>2]=c[X+32>>2]<<Q;c[a+1152>>2]=c[X+36>>2]<<Q;c[a+1156>>2]=c[X+40>>2]<<Q;c[a+1160>>2]=c[X+44>>2]<<Q;if((q|0)==((z*3|0)+8|0)){break}KIb(c[p>>2]|0,48,2410856,(s=i,i=i+8|0,c[s>>2]=q,s)|0);i=s}}while(0);do{if((c[a+836>>2]|0)!=0){if((c[r>>2]|0)!=0){break}if((c[u>>2]|0)!=0){break}KIb(c[p>>2]|0,16,2403120,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1163346256;i=b;return t|0}}while(0);if((c[a+832>>2]|0)==0){t=0;i=b;return t|0}s=c[C>>2]<<3;C=(o-1+s|0)/(s|0)|0;s=c[D>>2]<<3;b:do{if((c[B>>2]|0)>0){D=ca((V-1+s|0)/(s|0)|0,C)|0;o=0;while(1){p=a+952+(o<<2)|0;u=ca(D,c[p>>2]|0)|0;r=ca(u,c[a+968+(o<<2)>>2]|0)|0;u=a+1296+(o<<2)|0;mJb(u);q=a+1312+(o<<2)|0;mJb(q);c[u>>2]=pJb(r<<7)|0;z=pJb(r)|0;c[q>>2]=z;if((c[u>>2]|0)==0|(z|0)==0){t=-12;break}c[a+920+(o<<2)>>2]=ca(c[p>>2]|0,C)|0;o=o+1|0;if((o|0)>=(c[B>>2]|0)){break b}}i=b;return t|0}}while(0);mrc(a+1328|0,0,32)|0;t=0;i=b;return t|0}function lQa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0;k=i;i=i+64|0;l=k|0;m=k+16|0;n=k+32|0;o=k+48|0;p=f+824|0;q=(c[p>>2]|0)!=0?1:8;if((c[f+1144>>2]|0)==0){KIb(c[f+4>>2]|0,24,2396200,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1;i=k;return s|0}t=f+1140|0;if((c[c[t>>2]>>2]|0)==0){KIb(0,0,2489128,(r=i,i=i+24|0,c[r>>2]=2389288,c[r+8>>2]=2468584,c[r+16>>2]=1312,r)|0);i=r;Hd();return 0}u=f+16|0;v=c[u>>2]|0;w=f+24|0;x=c[w>>2]|0;z=f+8|0;A=c[z>>2]|0;B=A+(v>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7)>>>16;B=v+16|0;v=x>>>0>B>>>0?B:x;c[u>>2]=v;B=A+(v>>>3)|0;D=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7);B=D>>>24;E=v+8|0;v=x>>>0>E>>>0?E:x;c[u>>2]=v;if((B|0)==0|D>>>0>83886079>>>0){KIb(c[f+4>>2]|0,16,2382376,(r=i,i=i+8|0,c[r>>2]=B,r)|0);i=r;s=-1163346256;i=k;return s|0}if((C|0)!=((B<<1)+6|0)){KIb(c[f+4>>2]|0,16,2375784,(r=i,i=i+8|0,c[r>>2]=C,r)|0);i=r;s=-1094995529;i=k;return s|0}C=A+(v>>>3)|0;A=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(v&7)>>>24;C=v+8|0;c[u>>2]=x>>>0>C>>>0?C:x;x=f+4|0;C=f+916|0;v=(B|0)==3;E=f+832|0;F=f+1016|0;H=(B|0)==1;I=0;J=A;while(1){A=J-1|0;KIb(c[x>>2]|0,48,2369056,(r=i,i=i+8|0,c[r>>2]=A,r)|0);i=r;K=c[C>>2]|0;L=0;while(1){if((L|0)>=(K|0)){break}if((A|0)==(c[f+936+(L<<2)>>2]|0)){break}else{L=L+1|0}}M=c[x>>2]|0;if((L|0)==(K|0)){N=14;break}A=(I|0)==0|(c[M+52>>2]|0)==1246975053&v&(K|0)==3^1?L:3-I|0;c[f+1080+(I<<2)>>2]=c[f+1104+(A<<2)>>2];O=f+952+(A<<2)|0;P=f+968+(A<<2)|0;c[f+1032+(I<<2)>>2]=ca(c[P>>2]|0,c[O>>2]|0)|0;c[f+1048+(I<<2)>>2]=c[O>>2];c[f+1064+(I<<2)>>2]=c[P>>2];do{if(v){if((c[C>>2]|0)!=3){Q=A;break}if((c[(c[x>>2]|0)+140>>2]|0)!=82){Q=A;break}Q=(I+2|0)%3|0}else{if(!H){Q=A;break}if((c[C>>2]|0)!=3){Q=A;break}if((c[(c[x>>2]|0)+140>>2]|0)!=82){Q=A;break}Q=(A+2|0)%3|0}}while(0);c[f+984+(I<<2)>>2]=Q;A=c[u>>2]|0;L=c[w>>2]|0;P=(c[z>>2]|0)+(A>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(A&7)>>>28;P=A+4|0;c[u>>2]=L>>>0>P>>>0?P:L;L=f+1e3+(I<<2)|0;c[L>>2]=O;O=c[u>>2]|0;P=c[w>>2]|0;A=(c[z>>2]|0)+(O>>>3)|0;R=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(O&7);A=R>>>28;S=O+4|0;c[u>>2]=P>>>0>S>>>0?S:P;c[f+1016+(I<<2)>>2]=A;P=c[L>>2]|0;if(P>>>0>3>>>0|R>>>0>1073741823>>>0){N=374;break}if((c[f+552+(P*20|0)+4>>2]|0)==0){N=374;break}if((c[E>>2]|0)==0){if((c[f+632+(A*20|0)+4>>2]|0)==0){N=374;break}}else{if((c[f+712+((c[F>>2]|0)*20|0)+4>>2]|0)==0){N=374;break}}A=I+1|0;P=c[u>>2]|0;T=c[w>>2]|0;U=c[z>>2]|0;R=U+(P>>>3)|0;V=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(P&7)>>>24;R=P+8|0;W=T>>>0>R>>>0?R:T;c[u>>2]=W;if((A|0)<(B|0)){I=A;J=V}else{N=29;break}}if((N|0)==14){KIb(M,16,2354208,(r=i,i=i+8|0,c[r>>2]=K,r)|0);i=r;s=-1094995529;i=k;return s|0}else if((N|0)==29){K=U+(W>>>3)|0;M=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(W&7);K=M>>>24;J=W+8|0;W=T>>>0>J>>>0?J:T;c[u>>2]=W;J=c[x>>2]|0;if((c[J+52>>2]|0)==1196444227){X=0;Y=0}else{I=U+(W>>>3)|0;F=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(W&7)>>>28;I=W+4|0;W=T>>>0>I>>>0?I:T;c[u>>2]=W;I=U+(W>>>3)|0;U=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(W&7)>>>28;I=W+4|0;c[u>>2]=T>>>0>I>>>0?I:T;X=F;Y=U}do{if(D>>>0>33554431>>>0){U=ca(c[f+1096>>2]|0,q)|0;c[f+908>>2]=((c[f+900>>2]|0)-1+U|0)/(U|0)|0;U=ca(c[f+1100>>2]|0,q)|0;c[f+912>>2]=((c[f+904>>2]|0)-1+U|0)/(U|0)|0}else{if((c[f+828>>2]|0)!=0){break}U=f+1048|0;F=f+1064|0;T=(c[f+1100>>2]|0)/(c[F>>2]|0)|0;I=ca((c[f+1096>>2]|0)/(c[U>>2]|0)|0,q)|0;c[f+908>>2]=(I-1+(c[f+900>>2]|0)|0)/(I|0)|0;I=ca(T,q)|0;c[f+912>>2]=(I-1+(c[f+904>>2]|0)|0)/(I|0)|0;c[f+1032>>2]=1;c[U>>2]=1;c[F>>2]=1}}while(0);if((c[J+688>>2]&1|0)==0){Z=f+2964|0}else{q=(c[f+836>>2]|0)!=0?2322584:10230288;D=c[f+860>>2]|0;F=f+2964|0;U=c[F>>2]|0;if((c[f+856>>2]|0)==0){_=(c[f+852>>2]|0)!=0?2308216:10230288}else{_=2312920}KIb(J,48,2339408,(r=i,i=i+72|0,c[r>>2]=(c[p>>2]|0)!=0?2333736:2328256,c[r+8>>2]=q,c[r+16>>2]=V,c[r+24>>2]=Y,c[r+32>>2]=K,c[r+40>>2]=D,c[r+48>>2]=U,c[r+56>>2]=_,c[r+64>>2]=B,r)|0);i=r;Z=F}F=c[Z>>2]|0;if((F|0)>0){Z=c[w>>2]|0;_=F;F=c[u>>2]|0;do{U=F+8|0;F=Z>>>0>U>>>0?U:Z;_=_-1|0;}while((_|0)>0);c[u>>2]=F}F=f+860|0;_=f+832|0;Z=(V|0)==0;U=(g|0)!=0;D=f+908|0;q=f+912|0;J=f+2948|0;I=(j|0)==0;T=f+2944|0;W=f+20|0;E=f+816|0;Q=f+2752|0;C=f+1528|0;H=f+1168|0;v=f+8|0;A=f+2612|0;R=(X|0)==0;X=f+820|0;P=f+1136|0;L=f+984|0;S=f+1080|0;O=K>>>0<V>>>0|M>>>0>1073741823>>>0;M=(Y|0)==0;$=yrc(1,0,K+1|0)|0;aa=G;ba=yrc(1,0,V|0)|0;da=xrc($,aa,ba,G)|0;ba=G;aa=f+1016|0;$=f+1364+K|0;ea=K&255;fa=f+12|0;ga=f+828|0;ha=f+836|0;ia=(B-1|0)>>>0<4>>>0;ja=f+1148|0;ka=f+916|0;la=f+1100|0;ma=f+1096|0;na=f+2976|0;oa=na;pa=f+2980|0;qa=f+852|0;ra=f+856|0;sa=o|0;ta=l|0;ua=o+4|0;va=l+4|0;wa=o+8|0;xa=l+8|0;ya=o+12|0;za=l+12|0;Aa=0;a:while(1){if((Aa|0)<(B|0)){c[f+1120+(Aa<<2)>>2]=4<<c[F>>2];Aa=Aa+1|0;continue}b:do{if((c[p>>2]|0)==0){if((c[_>>2]|0)==0|Z){Ba=(c[F>>2]|0)>8?2:1;do{if(U){Ca=ca(c[q>>2]|0,c[D>>2]|0)|0;if((Ca+7>>3|0)==(h|0)){Da=Ca>>>0>2147483639>>>0;Ea=Da?0:g;Fa=Da?8:Ca+8|0;N=306;break}else{KIb(c[x>>2]|0,16,2106592,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;Ga=-1094995529;break}}else{Ea=0;Fa=0;N=306}}while(0);c:do{if((N|0)==306){N=0;c[J>>2]=0;Ca=0;do{Da=c[f+984+(Ca<<2)>>2]|0;c[m+(Da<<2)>>2]=c[(c[t>>2]|0)+(Da<<2)>>2];if(I){Ha=0}else{Ha=c[j+(Da<<2)>>2]|0}c[n+(Da<<2)>>2]=Ha;c[o+(Da<<2)>>2]=c[f+1148+(Da<<2)>>2];Ia=f+1328+(Da<<3)|0;Da=c[Ia+4>>2]|0;c[Ia>>2]=c[Ia>>2]|1;c[Ia+4>>2]=Da;Ca=Ca+1|0;}while((Ca|0)<(B|0));Ca=c[q>>2]|0;if((Ca|0)<=0){Ga=0;break}Da=0;Ia=0;Ja=c[D>>2]|0;Ka=Ca;d:while(1){if((Ja|0)>0){Ca=Da;La=0;while(1){if(U){Ma=(d[Ea+(Ca>>>3)|0]&128>>>((Ca&7)>>>0)|0)==0;Na=((Ca|0)<(Fa|0))+Ca|0}else{Ma=0;Na=Ca}Oa=c[T>>2]|0;do{if((Oa|0)!=0){if((c[J>>2]|0)!=0){break}c[J>>2]=Oa}}while(0);Pa=(c[W>>2]|0)-(c[u>>2]|0)|0;if((Pa|0)<0){N=319;break d}else{Qa=0}do{Oa=c[f+1032+(Qa<<2)>>2]|0;Ra=c[f+984+(Qa<<2)>>2]|0;Sa=c[f+1048+(Qa<<2)>>2]|0;e:do{if((Oa|0)>0){Ta=c[o+(Ra<<2)>>2]|0;Ua=ca(c[f+1064+(Qa<<2)>>2]|0,Ia)|0;Va=ca(Sa,La)|0;Wa=c[m+(Ra<<2)>>2]|0;Xa=n+(Ra<<2)|0;Ya=f+1e3+(Qa<<2)|0;Za=f+1016+(Qa<<2)|0;_a=f+1080+(Qa<<2)|0;$a=f+1120+(Qa<<2)|0;ab=f+920+(Ra<<2)|0;bb=f+1296+(Ra<<2)|0;cb=Ta>>1;db=Ta<<1;eb=db+Ta|0;fb=0;gb=0;hb=1;while(1){ib=gb+Ua|0;jb=fb+Va|0;kb=(ca(jb,Ba)|0)+(ca(ib,Ta)|0)<<3;lb=c[(c[x>>2]|0)+800>>2]|0;mb=kb>>lb;if((c[E>>2]|0)==0){nb=mb}else{nb=((c[X>>2]|0)==0?0:cb)+mb|0}mb=Wa+nb|0;f:do{if((c[_>>2]|0)==0){if(Ma){kb=c[Xa>>2]|0;ob=kb+nb|0;if((lb|0)==0){mf[c[Q>>2]&2047](mb,ob,Ta,8);break}else if((lb|0)==1){pb=ob;qb=mb;y=d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0;a[qb]=y;y=y>>8;a[qb+1|0]=y;y=y>>8;a[qb+2|0]=y;y=y>>8;a[qb+3|0]=y;qb=nb+Ta|0;pb=kb+qb|0;rb=Wa+qb|0;y=d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0;a[rb]=y;y=y>>8;a[rb+1|0]=y;y=y>>8;a[rb+2|0]=y;y=y>>8;a[rb+3|0]=y;rb=nb+db|0;pb=kb+rb|0;qb=Wa+rb|0;y=d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0;a[qb]=y;y=y>>8;a[qb+1|0]=y;y=y>>8;a[qb+2|0]=y;y=y>>8;a[qb+3|0]=y;qb=eb+nb|0;pb=kb+qb|0;rb=Wa+qb|0;y=d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0;a[rb]=y;y=y>>8;a[rb+1|0]=y;y=y>>8;a[rb+2|0]=y;y=y>>8;a[rb+3|0]=y;break}else if((lb|0)==2){rb=ob;pb=mb;y=(d[rb]|d[rb+1|0]<<8)<<16>>16;a[pb]=y;y=y>>8;a[pb+1|0]=y;pb=nb+Ta|0;rb=kb+pb|0;kb=Wa+pb|0;y=(d[rb]|d[rb+1|0]<<8)<<16>>16;a[kb]=y;y=y>>8;a[kb+1|0]=y;break}else if((lb|0)==3){a[mb]=a[ob]|0;break}else{break}}qe[c[C>>2]&1023](H);ob=c[Za>>2]|0;kb=c[_a>>2]|0;rb=rQa(f,c[Ya>>2]|0)|0;if((rb|0)==1048575){N=332;break d}pb=ca(b[f+40+(kb<<7)>>1]|0,rb)|0;rb=pb+(c[$a>>2]|0)|0;c[$a>>2]=rb;b[H>>1]=rb;rb=c[w>>2]|0;pb=c[v>>2]|0;qb=c[f+632+(ob*20|0)+4>>2]|0;ob=0;sb=c[u>>2]|0;while(1){tb=pb+(sb>>>3)|0;ub=(je(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(sb&7);tb=ub>>>23;vb=b[qb+(tb<<2)>>1]|0;wb=b[qb+(tb<<2)+2>>1]|0;tb=wb<<16>>16;if(wb<<16>>16<0){wb=sb+9|0;xb=rb>>>0>wb>>>0?wb:rb;wb=pb+(xb>>>3)|0;yb=(je(d[wb]|d[wb+1|0]<<8|d[wb+2|0]<<16|d[wb+3|0]<<24|0)|0)<<(xb&7);wb=(yb>>>((tb+32|0)>>>0))+vb|0;zb=b[qb+(wb<<2)>>1]|0;Ab=b[qb+(wb<<2)+2>>1]|0;Bb=yb;Cb=xb}else{zb=vb;Ab=tb;Bb=ub;Cb=sb}ub=Ab+Cb|0;tb=rb>>>0>ub>>>0?ub:rb;Db=(zb>>>4)+ob|0;ub=zb&15;if((ub|0)==0){Eb=tb}else{if(ub>>>0>9>>>0){vb=pb+(tb>>>3)|0;Fb=(je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(tb&7)}else{Fb=Bb<<Ab}vb=(Fb^-2147483648)>>31;xb=tb+ub|0;if((Db|0)>63){N=340;break d}tb=d[f+1364+Db|0]|0;b[f+1168+(tb<<1)>>1]=ca(b[f+40+(kb<<7)+(tb<<1)>>1]|0,((vb^Fb)>>>((32-ub|0)>>>0)^vb)-vb|0)|0;Eb=rb>>>0>xb>>>0?xb:rb}if((Db|0)<63){ob=Db;sb=Eb}else{break}}c[u>>2]=Eb;ef[c[A>>2]&4095](mb,Ta,H);sb=c[F>>2]|0;if((sb&7|0)==0){break}ob=8>>>((c[(c[x>>2]|0)+800>>2]|0)>>>0);rb=(ob|0)>0;if((sb|0)<=8){if(rb){Gb=0}else{break}while(1){kb=(ca(Gb,Ta)|0)+nb|0;pb=0;do{qb=Wa+(kb+pb)|0;a[qb]=d[qb]<<8-(c[F>>2]|0);pb=pb+1|0;}while((pb|0)<(ob|0));Gb=Gb+1|0;if((Gb|0)>=(ob|0)){break f}}}if(!rb){break}pb=16-sb|0;kb=0;do{qb=(ca(kb,Ta)|0)+nb|0;xb=0;do{vb=Wa+(qb+(xb<<1))|0;b[vb>>1]=e[vb>>1]<<pb;xb=xb+1|0;}while((xb|0)<(ob|0));kb=kb+1|0;}while((kb|0)<(ob|0))}else{ob=(ca(c[ab>>2]|0,ib)|0)+jb|0;kb=(c[bb>>2]|0)+(ob<<7)|0;if(!R){ob=c[u>>2]|0;pb=d[(c[v>>2]|0)+(ob>>>3)|0]<<(ob&7)>>>7;c[u>>2]=((ob|0)<(c[w>>2]|0))+ob;b[kb>>1]=((b[f+40+(c[_a>>2]<<7)>>1]&-(pb&1))<<Y)+(e[kb>>1]|0);break}pb=c[Ya>>2]|0;ob=c[_a>>2]|0;qe[c[C>>2]&1023](kb);sb=rQa(f,pb)|0;if((sb|0)==1048575){N=359;break d}pb=(ca(b[f+40+(ob<<7)>>1]|0,sb)|0)<<Y;sb=pb+(c[$a>>2]|0)|0;c[$a>>2]=sb;b[kb>>1]=sb}}while(0);jb=fb+1|0;ib=(jb|0)==(Sa|0);if((hb|0)>=(Oa|0)){break e}fb=ib?0:jb;gb=(ib&1)+gb|0;hb=hb+1|0}}}while(0);Qa=Qa+1|0;}while((Qa|0)<(B|0));qQa(f,B)|0;Oa=La+1|0;Hb=c[D>>2]|0;if((Oa|0)<(Hb|0)){Ca=Na;La=Oa}else{break}}Ib=Na;Jb=Hb;Kb=c[q>>2]|0}else{Ib=Da;Jb=Ja;Kb=Ka}Ca=Ia+1|0;if((Ca|0)<(Kb|0)){Da=Ib;Ia=Ca;Ja=Jb;Ka=Kb}else{Ga=0;break c}}if((N|0)==319){N=0;KIb(c[x>>2]|0,16,2105264,(r=i,i=i+8|0,c[r>>2]=-Pa,r)|0);i=r;Ga=-1094995529;break}else if((N|0)==332){N=0;KIb(c[x>>2]|0,16,2642488,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}else if((N|0)==340){N=0;KIb(c[x>>2]|0,16,2632856,(r=i,i=i+8|0,c[r>>2]=Db,r)|0);i=r}else if((N|0)==359){N=0;KIb(c[x>>2]|0,16,2642488,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;KIb(c[x>>2]|0,16,2644312,(r=i,i=i+16|0,c[r>>2]=Ia,c[r+8>>2]=La,r)|0);i=r;Ga=-1094995529;break}KIb(c[x>>2]|0,16,2644312,(r=i,i=i+16|0,c[r>>2]=Ia,c[r+8>>2]=La,r)|0);i=r;Ga=-1094995529}}while(0);if((Ga|0)<0){s=Ga;N=375;break a}else{break}}Ba=c[t>>2]|0;if((Ba|0)!=(c[P>>2]|0)){N=211;break a}Ka=c[L>>2]|0;Ja=c[Ba+(Ka<<2)>>2]|0;Ba=c[f+1148+(Ka<<2)>>2]|0;Da=c[S>>2]|0;Ca=(c[F>>2]|0)>8?16:8;if(O){N=213;break a}if(M){Oa=f+1328+(Ka<<3)|0;Sa=c[Oa>>2]|da;Ra=c[Oa+4>>2]|ba;c[Oa>>2]=Sa;c[Oa+4>>2]=Ra;Lb=(Sa|0)==(-1|0)&(Ra|0)==(-1|0)&1}else{Lb=0}do{if((c[E>>2]|0)==0){Mb=Ja}else{if((c[X>>2]|0)==0){Mb=Ja;break}Mb=Ja+(Ba>>1)|0}}while(0);c[J>>2]=0;Ja=c[q>>2]|0;if((Ja|0)<=0){break}Ra=Ba<<3;Sa=f+920+(Ka<<2)|0;Oa=f+1296+(Ka<<2)|0;hb=f+1312+(Ka<<2)|0;gb=(Lb|0)==0;fb=0;Nb=0;$a=c[D>>2]|0;_a=Ja;while(1){Ja=ca(c[Sa>>2]|0,Nb)|0;if(($a|0)>0){Ya=ca(Ra,Nb)|0;bb=fb;Ob=0;ab=Mb+(Ya>>c[(c[x>>2]|0)+800>>2])|0;Ya=(c[Oa>>2]|0)+(Ja<<7)|0;Wa=(c[hb>>2]|0)+Ja|0;while(1){Ja=c[T>>2]|0;do{if((Ja|0)!=0){if((c[J>>2]|0)!=0){break}c[J>>2]=Ja}}while(0);Ja=Ya|0;Ta=c[aa>>2]|0;g:do{if(R){if((bb|0)!=0){Pb=bb-1|0;break}Za=c[w>>2]|0;eb=c[v>>2]|0;db=c[f+712+(Ta*20|0)+4>>2]|0;Xa=V;cb=c[u>>2]|0;while(1){Va=eb+(cb>>>3)|0;Ua=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(cb&7);Va=Ua>>>23;ib=b[db+(Va<<2)>>1]|0;jb=b[db+(Va<<2)+2>>1]|0;Va=jb<<16>>16;if(jb<<16>>16<0){jb=cb+9|0;mb=Za>>>0>jb>>>0?jb:Za;jb=eb+(mb>>>3)|0;lb=(je(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(mb&7);jb=(lb>>>((Va+32|0)>>>0))+ib|0;Qb=b[db+(jb<<2)>>1]|0;Rb=b[db+(jb<<2)+2>>1]|0;Sb=lb;Tb=mb}else{Qb=ib;Rb=Va;Sb=Ua;Tb=cb}Ua=Rb+Tb|0;Ub=Za>>>0>Ua>>>0?Ua:Za;Vb=Qb>>>4;Ua=Qb&15;if((Ua|0)==0){if((Vb|0)!=15){N=279;break}Wb=Xa+15|0;if((Wb|0)<(K|0)){Xb=Wb;Yb=Ub}else{N=278;break a}}else{Zb=Vb+Xa|0;if(Ua>>>0>9>>>0){Va=eb+(Ub>>>3)|0;_b=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ub&7)}else{_b=Sb<<Rb}Va=(_b^-2147483648)>>31;$b=((Va^_b)>>>((32-Ua|0)>>>0)^Va)-Va|0;Va=Ub+Ua|0;ac=Za>>>0>Va>>>0?Va:Za;if((Zb|0)>=(K|0)){N=272;break}Va=d[f+1364+Zb|0]|0;b[Ya+(Va<<1)>>1]=(ca(b[f+40+(Da<<7)+(Va<<1)>>1]|0,$b)|0)<<Y;Xb=Zb;Yb=ac}Xa=Xb+1|0;cb=Yb}if((N|0)==272){N=0;if((Zb|0)!=(K|0)){N=274;break a}cb=d[$]|0;b[Ya+(cb<<1)>>1]=(ca(b[f+40+(Da<<7)+(cb<<1)>>1]|0,$b)|0)<<Y;bc=K;cc=ac;dc=0}else if((N|0)==279){N=0;cb=1<<Vb;if((Vb|0)==0){ec=Ub;fc=cb}else{db=eb+(Ub>>>3)|0;Va=((je(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(Ub&7)>>>((32-Vb|0)>>>0))+cb|0;cb=Ub+Vb|0;ec=Za>>>0>cb>>>0?cb:Za;fc=Va}bc=Xa;cc=ec;dc=fc-1|0}c[u>>2]=cc;if((bc|0)<=(d[Wa]|0)){Pb=dc;break}a[Wa]=bc;Pb=dc}else{Va=d[Wa]|0;cb=Va>>>0<K>>>0?Va:K;Va=c[u>>2]|0;db=c[w>>2]|0;do{if((bb|0)==0){Ua=c[v>>2]|0;ib=c[f+712+(Ta*20|0)+4>>2]|0;mb=Va;lb=V;h:while(1){jb=Ua+(mb>>>3)|0;sb=(je(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(mb&7)>>>23;jb=b[ib+(sb<<2)>>1]|0;kb=b[ib+(sb<<2)+2>>1]|0;sb=kb<<16>>16;if(kb<<16>>16<0){kb=mb+9|0;pb=db>>>0>kb>>>0?kb:db;kb=Ua+(pb>>>3)|0;ob=((je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(pb&7)>>>((sb+32|0)>>>0))+jb|0;gc=b[ib+(ob<<2)+2>>1]|0;hc=b[ib+(ob<<2)>>1]|0;ic=pb}else{gc=sb;hc=jb;ic=mb}jb=gc+ic|0;jc=db>>>0>jb>>>0?jb:db;kc=hc>>>4;i:do{if((hc&15|0)==0){if((kc|0)!=15){break h}if((lb|0)>(cb|0)){lc=15;mc=lb;nc=jc}else{jb=15;sb=lb;pb=jc;while(1){ob=d[f+1364+sb|0]|0;kb=Ya+(ob<<1)|0;rb=b[kb>>1]|0;if(rb<<16>>16==0){if((jb|0)==0){oc=pb;pc=sb;break i}else{qc=pb;rc=jb-1|0}}else{xb=Ua+(pb>>>3)|0;qb=(je(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(pb&7);xb=rb<<16>>16;rb=xb>>15;b[kb>>1]=(((b[f+40+(Da<<7)+(ob<<1)>>1]^rb)-rb&qb>>31)<<Y)+xb;xb=pb+1|0;qc=db>>>0>xb>>>0?xb:db;rc=jb}xb=sb+1|0;if((xb|0)>(cb|0)){lc=rc;mc=xb;nc=qc;break}else{jb=rc;sb=xb;pb=qc}}}sc=lc+mc|0;if((sc|0)>(K|0)){N=248;break a}else{oc=nc;pc=sc}}else{pb=Ua+(jc>>>3)|0;sb=(je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(jc&7)>>>31;pb=jc+1|0;jb=db>>>0>pb>>>0?pb:db;j:do{if((lb|0)>(cb|0)){tc=kc;uc=lb;vc=jb;N=234}else{pb=kc;xb=lb;qb=jb;while(1){rb=a[f+1364+xb|0]|0;ob=rb&255;kb=Ya+(ob<<1)|0;vb=b[kb>>1]|0;if(vb<<16>>16==0){if((pb|0)==0){wc=xb;xc=qb;yc=rb;break j}else{zc=qb;Ac=pb-1|0}}else{rb=Ua+(qb>>>3)|0;ub=(je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(qb&7);rb=vb<<16>>16;vb=rb>>15;b[kb>>1]=(((b[f+40+(Da<<7)+(ob<<1)>>1]^vb)-vb&ub>>31)<<Y)+rb;rb=qb+1|0;zc=db>>>0>rb>>>0?rb:db;Ac=pb}rb=xb+1|0;if((rb|0)>(cb|0)){tc=Ac;uc=rb;vc=zc;N=234;break}else{pb=Ac;xb=rb;qb=zc}}}}while(0);if((N|0)==234){N=0;Bc=tc+uc|0;if((Bc|0)>(K|0)){N=236;break a}wc=Bc;xc=vc;yc=a[f+1364+Bc|0]|0}jb=yc&255;qb=sb-1|0;b[Ya+(jb<<1)>>1]=(b[f+40+(Da<<7)+(jb<<1)>>1]^qb)-qb<<Y;if((wc|0)==(K|0)){N=242;break h}else{oc=xc;pc=wc}}}while(0);mb=oc;lb=pc+1|0}if((N|0)==242){N=0;if((d[Wa]|0)>>>0<K>>>0){a[Wa]=ea}c[u>>2]=xc;Pb=0;break g}mb=1<<kc;if((kc|0)==0){Cc=jc;Dc=mb}else{ib=Ua+(jc>>>3)|0;qb=((je(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(jc&7)>>>((32-kc|0)>>>0))+mb|0;mb=jc+kc|0;Cc=db>>>0>mb>>>0?mb:db;Dc=qb}qb=Dc-1|0;if((lb|0)<=(d[Wa]|0)){Ec=Cc;Fc=lb;Gc=qb;break}a[Wa]=lb;Ec=Cc;Fc=lb;Gc=qb}else{Ec=Va;Fc=V;Gc=bb-1|0}}while(0);if((Fc|0)>(cb|0)){Hc=Ec}else{Va=Fc;Xa=Ec;while(1){Za=d[f+1364+Va|0]|0;eb=Ya+(Za<<1)|0;qb=b[eb>>1]|0;if(qb<<16>>16==0){Ic=Xa}else{mb=(c[v>>2]|0)+(Xa>>>3)|0;ib=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(Xa&7);mb=qb<<16>>16;qb=mb>>15;b[eb>>1]=(((b[f+40+(Da<<7)+(Za<<1)>>1]^qb)-qb&ib>>31)<<Y)+mb;mb=Xa+1|0;Ic=db>>>0>mb>>>0?mb:db}mb=Va+1|0;if((mb|0)>(cb|0)){Hc=Ic;break}else{Va=mb;Xa=Ic}}}c[u>>2]=Hc;Pb=Gc}}while(0);if(gb){Jc=ab}else{ef[c[A>>2]&4095](ab,Ba,Ja);Ta=c[F>>2]|0;k:do{if((Ta&7|0)!=0){Xa=8>>>((c[(c[x>>2]|0)+800>>2]|0)>>>0);Va=(Xa|0)>0;if((Ta|0)<=8){if(Va){Kc=0}else{break}while(1){cb=ca(Kc,Ba)|0;db=0;do{mb=ab+(db+cb)|0;a[mb]=d[mb]<<8-(c[F>>2]|0);db=db+1|0;}while((db|0)<(Xa|0));Kc=Kc+1|0;if((Kc|0)>=(Xa|0)){break k}}}if(!Va){break}db=16-Ta|0;cb=0;do{lb=ca(cb,Ba)|0;Ua=0;do{mb=ab+((Ua<<1)+lb)|0;b[mb>>1]=e[mb>>1]<<db;Ua=Ua+1|0;}while((Ua|0)<(Xa|0));cb=cb+1|0;}while((cb|0)<(Xa|0))}}while(0);Jc=ab+(Ca>>>((c[(c[x>>2]|0)+800>>2]|0)>>>0))|0}Ta=(qQa(f,0)|0)==0;Lc=Ta?Pb:0;Ta=Ob+1|0;Mc=c[D>>2]|0;if((Ta|0)<(Mc|0)){bb=Lc;Ob=Ta;ab=Jc;Ya=Ya+128|0;Wa=Wa+1|0}else{break}}Nc=Lc;Oc=Mc;Pc=c[q>>2]|0}else{Nc=fb;Oc=$a;Pc=_a}Wa=Nb+1|0;if((Wa|0)<(Pc|0)){fb=Nc;Nb=Wa;$a=Oc;_a=Pc}else{break}}}else{if((c[t>>2]|0)!=(c[P>>2]|0)){N=49;break a}if((c[ga>>2]|0)!=0){_a=fOa(f,V,Y,K)|0;if((_a|0)<0){s=_a;N=375;break a}else{break}}if((c[ha>>2]|0)!=0){_a=c[ja>>2]|0;$a=(1<<c[F>>2])-1|0;fb=$a<<Y;if(!(((c[ka>>2]|0)-3|0)>>>0<2>>>0)){s=-1094995529;N=375;break a}if((c[la>>2]|0)!=1){s=-1094995529;N=375;break a}if((c[ma>>2]|0)!=1){s=-1094995529;N=375;break a}c[J>>2]=c[T>>2];xJb(oa,pa,c[D>>2]<<3);Ca=c[na>>2]|0;Ba=1<<(c[F>>2]|0)-1&65535;gb=Ca|0;b[gb>>1]=Ba;Da=Ca+2|0;b[Da>>1]=Ba;hb=Ca+4|0;b[hb>>1]=Ba;Oa=Ca+6|0;b[Oa>>1]=Ba;if((c[q>>2]|0)<=0){break}Ba=_a>>1;Ra=0;Sa=0;Ka=0;while(1){Wa=c[c[t>>2]>>2]|0;Ya=ca(Ra,_a)|0;ab=Wa+Ya|0;do{if((c[E>>2]|0)==0){Qc=ab}else{if((c[X>>2]|0)==0){Qc=ab;break}Qc=Wa+(Ya+Ba)|0}}while(0);Ya=e[gb>>1]|0;c[sa>>2]=Ya;c[ta>>2]=Ya;Ya=e[Da>>1]|0;c[ua>>2]=Ya;c[va>>2]=Ya;Ya=e[hb>>1]|0;c[wa>>2]=Ya;c[xa>>2]=Ya;Ya=e[Oa>>1]|0;c[ya>>2]=Ya;c[za>>2]=Ya;Ya=c[D>>2]|0;if((Ya|0)>0){Wa=Sa;ab=Ka;bb=0;Ia=c[T>>2]|0;while(1){do{if((Ia|0)==0){Rc=ab;Sc=Wa}else{if((c[J>>2]|0)!=0){Rc=ab;Sc=Wa;break}c[J>>2]=Ia;Ta=1<<(c[F>>2]|0)-1;c[sa>>2]=Ta;c[ta>>2]=Ta;c[ua>>2]=Ta;c[va>>2]=Ta;c[wa>>2]=Ta;c[xa>>2]=Ta;c[ya>>2]=Ta;c[za>>2]=Ta;Rc=bb;Sc=Ra}}while(0);l:do{if((Ra|0)==(Sc|0)){Tc=0;N=73}else{if((Ra|0)==(Sc+1|0)){if(!((bb|0)>=(Rc|0)&(bb|0)!=0)){Tc=0;N=73;break}}else{if((bb|0)==0){Tc=0;N=73;break}}if((V|0)==0){Ta=0;while(1){Ja=Ca+(bb<<3)+(Ta<<1)|0;c[l+(Ta<<2)>>2]=e[Ja>>1]|0;Xa=rQa(f,c[f+1e3+(Ta<<2)>>2]|0)|0;if((Xa|0)==1048575){s=-1;N=375;break a}cb=(Xa&$a)<<Y;b[Ja>>1]=cb;c[o+(Ta<<2)>>2]=cb&65535;Ta=Ta+1|0;if((Ta|0)>=(B|0)){break l}}}else if((V|0)==1){Tc=0;N=73;break}else{Uc=0}while(1){Ta=l+(Uc<<2)|0;cb=c[Ta>>2]|0;Ja=Ca+(bb<<3)+(Uc<<1)|0;Xa=e[Ja>>1]|0;c[Ta>>2]=Xa;switch(V|0){case 3:{Vc=cb;break};case 4:{Vc=Xa-cb+(c[o+(Uc<<2)>>2]|0)|0;break};case 0:{Vc=0;break};case 5:{Vc=(c[o+(Uc<<2)>>2]|0)+(Xa-cb>>1)|0;break};case 6:{Vc=((c[o+(Uc<<2)>>2]|0)-cb>>1)+Xa|0;break};case 2:{Vc=Xa;break};default:{Vc=(c[o+(Uc<<2)>>2]|0)+Xa>>1}}Xa=rQa(f,c[f+1e3+(Uc<<2)>>2]|0)|0;if((Xa|0)==1048575){s=-1;N=375;break a}cb=(Xa<<Y)+Vc&fb;b[Ja>>1]=cb;c[o+(Uc<<2)>>2]=cb&65535;Uc=Uc+1|0;if((Uc|0)>=(B|0)){break l}}}}while(0);if((N|0)==73){while(1){N=0;cb=Ca+(bb<<3)+(Tc<<1)|0;c[l+(Tc<<2)>>2]=e[cb>>1]|0;Ja=o+(Tc<<2)|0;Xa=c[Ja>>2]|0;Ta=rQa(f,c[f+1e3+(Tc<<2)>>2]|0)|0;if((Ta|0)==1048575){s=-1;N=375;break a}db=(Ta<<Y)+Xa&fb;b[cb>>1]=db;c[Ja>>2]=db&65535;db=Tc+1|0;if((db|0)<(B|0)){Tc=db;N=73}else{break}}}db=c[T>>2]|0;do{if((db|0)!=0){Ja=(c[J>>2]|0)-1|0;c[J>>2]=Ja;if((Ja|0)!=0){break}Ja=c[u>>2]|0;cb=-Ja&7;Xa=c[w>>2]|0;if((cb|0)==0){Wc=Ja}else{Ta=cb+Ja|0;Ja=Xa>>>0>Ta>>>0?Ta:Xa;c[u>>2]=Ja;Wc=Ja}Ja=Wc+16|0;c[u>>2]=Xa>>>0>Ja>>>0?Ja:Xa}}while(0);Xa=bb+1|0;Ja=c[D>>2]|0;if((Xa|0)<(Ja|0)){Wa=Sc;ab=Rc;bb=Xa;Ia=db}else{Xc=Sc;Yc=Rc;Zc=Ja;break}}}else{Xc=Sa;Yc=Ka;Zc=Ya}m:do{if((c[ka>>2]|0)==4){Ia=Qc;bb=0;ab=Zc;while(1){Wa=c[f+984+(bb<<2)>>2]|0;Ja=c[F>>2]|0;do{if((Ja|0)<9){if((ab|0)>0){_c=0}else{$c=ab;break}while(1){a[Qc+((_c<<2|3)-Wa)|0]=b[Ca+(_c<<3)+(bb<<1)>>1];Xa=_c+1|0;Ta=c[D>>2]|0;if((Xa|0)<(Ta|0)){_c=Xa}else{$c=Ta;break}}}else{if((Ja|0)==9){s=-1163346256;N=375;break a}if((ab|0)>0){ad=0}else{$c=ab;break}while(1){b[Ia+((ad<<2)+Wa<<1)>>1]=b[Ca+(ad<<3)+(bb<<1)>>1]|0;Ta=ad+1|0;if((Ta|0)<(ab|0)){ad=Ta}else{$c=ab;break}}}}while(0);Wa=bb+1|0;if((Wa|0)<(B|0)){bb=Wa;ab=$c}else{break}}}else{if((c[qa>>2]|0)!=0){if((Zc|0)>0){bd=0}else{break}while(1){ab=Ca+(bd<<3)+2|0;bb=Ca+(bd<<3)+4|0;Ia=(e[Ca+(bd<<3)>>1]|0)-(((e[ab>>1]|0)+512+(e[bb>>1]|0)|0)>>>2)|0;db=Ia&255;Wa=bd*3|0;a[Qc+(Wa+1)|0]=db;a[Qc+Wa|0]=Ia+(e[ab>>1]|0);a[Qc+(Wa+2)|0]=db+(b[bb>>1]&255);bd=bd+1|0;if((bd|0)>=(c[D>>2]|0)){break m}}}if((c[ra>>2]|0)!=0){if((Zc|0)>0){cd=0}else{break}while(1){bb=Ca+(cd<<3)+2|0;db=Ca+(cd<<3)+4|0;Wa=(e[Ca+(cd<<3)>>1]|0)-(((e[db>>1]|0)+(e[bb>>1]|0)|0)>>>2)|0;ab=Wa&255;Ia=cd*3|0;a[Qc+(Ia+1)|0]=ab;a[Qc+Ia|0]=Wa+(e[bb>>1]|0);a[Qc+(Ia+2)|0]=ab+(b[db>>1]&255);cd=cd+1|0;if((cd|0)>=(c[D>>2]|0)){break m}}}db=Qc;ab=0;Ia=Zc;while(1){bb=c[f+984+(ab<<2)>>2]|0;Wa=c[F>>2]|0;do{if((Wa|0)<9){if((Ia|0)<=0){dd=Ia;break}Ja=2-bb|0;Ta=0;while(1){a[Qc+(Ja+(Ta*3|0))|0]=b[Ca+(Ta<<3)+(ab<<1)>>1];Xa=Ta+1|0;cb=c[D>>2]|0;if((Xa|0)<(cb|0)){Ta=Xa}else{dd=cb;break}}}else{if((Wa|0)==9){s=-1163346256;N=375;break a}if((Ia|0)<=0){dd=Ia;break}Ta=2-bb|0;Ja=0;while(1){b[db+(Ta+(Ja*3|0)<<1)>>1]=b[Ca+(Ja<<3)+(ab<<1)>>1]|0;cb=Ja+1|0;if((cb|0)<(Ia|0)){Ja=cb}else{dd=Ia;break}}}}while(0);bb=ab+1|0;if((bb|0)<(B|0)){ab=bb;Ia=dd}else{break}}}}while(0);Ya=Ra+1|0;if((Ya|0)<(c[q>>2]|0)){Ra=Ya;Sa=Xc;Ka=Yc}else{break b}}}Ka=c[F>>2]|0;Sa=Ka+7&-8;Ra=Sa-Ka+Y|0;Ca=(1<<Ka)-1<<Ra;if(!ia){N=119;break a}Ka=c[q>>2]|0;if((Ka|0)<=0){break}fb=(Sa|0)>8;$a=(Sa|0)<9;Oa=1<<Sa-1;Sa=0;hb=0;Da=0;gb=c[D>>2]|0;Ba=Ka;while(1){if((gb|0)>0){Ka=Sa;_a=hb;Ya=0;Ia=c[T>>2]|0;while(1){do{if((Ia|0)==0){ed=_a;fd=Ka}else{if((c[J>>2]|0)!=0){ed=_a;fd=Ka;break}c[J>>2]=Ia;ed=Da;fd=Ya}}while(0);ab=(Ya|0)!=0;db=(Da|0)==(ed|0);do{if(db|ab^1){N=128}else{if((Da|0)==(ed+1|0)&(Ya|0)<(fd|0)){N=128;break}if((c[E>>2]|0)==0){gd=0}else{N=128;break}do{bb=c[f+1032+(gd<<2)>>2]|0;Wa=c[f+984+(gd<<2)>>2]|0;Ja=c[f+1048+(gd<<2)>>2]|0;Ta=c[f+1148+(Wa<<2)>>2]|0;if(fb){hd=(Ta|0)/2|0}else{hd=Ta}if((bb|0)>0){Ta=f+1e3+(gd<<2)|0;cb=ca(c[f+1064+(gd<<2)>>2]|0,Da)|0;Xa=ca(Ja,Ya)|0;Va=~hd;Ua=-hd|0;lb=0;mb=0;ib=0;while(1){qb=rQa(f,c[Ta>>2]|0)|0;if((qb|0)==1048575){s=-1;N=375;break a}Za=c[(c[t>>2]|0)+(Wa<<2)>>2]|0;eb=ca(mb+cb|0,hd)|0;if($a){jb=lb+Xa+eb|0;switch(V|0){case 0:{id=0;break};case 1:{id=d[Za+(jb-1)|0]|0;break};case 2:{id=d[Za+(jb-hd)|0]|0;break};case 3:{id=d[Za+(jb+Va)|0]|0;break};case 4:{id=(d[Za+(jb-hd)|0]|0)+(d[Za+(jb-1)|0]|0)-(d[Za+(jb+Va)|0]|0)|0;break};case 5:{id=((d[Za+(jb-hd)|0]|0)-(d[Za+(jb+Va)|0]|0)>>1)+(d[Za+(jb-1)|0]|0)|0;break};case 6:{id=((d[Za+(jb-1)|0]|0)-(d[Za+(jb+Va)|0]|0)>>1)+(d[Za+(jb-hd)|0]|0)|0;break};default:{id=((d[Za+(jb-hd)|0]|0)+(d[Za+(jb-1)|0]|0)|0)>>>1}}a[Za+jb|0]=(id&Ca)+(qb<<Ra)}else{jb=(eb<<1)+(lb+Xa<<1)|0;eb=Za+jb|0;switch(V|0){case 5:{jd=((e[eb+(Ua<<1)>>1]|0)-(e[eb+(Va<<1)>>1]|0)>>1)+(e[Za+(jb-2)>>1]|0)|0;break};case 0:{jd=0;break};case 1:{jd=e[Za+(jb-2)>>1]|0;break};case 2:{jd=e[eb+(Ua<<1)>>1]|0;break};case 3:{jd=e[eb+(Va<<1)>>1]|0;break};case 4:{jd=(e[eb+(Ua<<1)>>1]|0)+(e[Za+(jb-2)>>1]|0)-(e[eb+(Va<<1)>>1]|0)|0;break};case 6:{jd=((e[Za+(jb-2)>>1]|0)-(e[eb+(Va<<1)>>1]|0)>>1)+(e[eb+(Ua<<1)>>1]|0)|0;break};default:{jd=((e[eb+(Ua<<1)>>1]|0)+(e[Za+(jb-2)>>1]|0)|0)>>>1}}b[eb>>1]=(jd&Ca)+(qb<<Ra)}qb=lb+1|0;eb=(qb|0)==(Ja|0);jb=ib+1|0;if((jb|0)<(bb|0)){lb=eb?0:qb;mb=(eb&1)+mb|0;ib=jb}else{break}}}gd=gd+1|0;}while((gd|0)<(B|0))}}while(0);if((N|0)==128){N=0;if(db){kd=0}else{kd=(Ya|0)>=(fd|0)|(Da|0)!=(ed+1|0)}if(ab){ld=db&(Ya|0)==(fd|0)^1}else{ld=0}ib=0;do{mb=c[f+1032+(ib<<2)>>2]|0;lb=c[f+984+(ib<<2)>>2]|0;bb=c[f+1048+(ib<<2)>>2]|0;Ja=c[f+1148+(lb<<2)>>2]|0;if(fb){md=(Ja|0)/2|0}else{md=Ja}if((mb|0)>0){Ja=f+1e3+(ib<<2)|0;Ua=ca(c[f+1064+(ib<<2)>>2]|0,Da)|0;Va=ca(bb,Ya)|0;Xa=~md;cb=md>>1;Wa=-md|0;Ta=0;jb=0;eb=0;while(1){qb=rQa(f,c[Ja>>2]|0)|0;if((qb|0)==1048575){s=-1;N=375;break a}Za=c[(c[t>>2]|0)+(lb<<2)>>2]|0;xb=ca(jb+Ua|0,md)|0;if($a){pb=Ta+Va+xb|0;rb=Za+pb|0;ub=(Ta|0)!=0|ld;n:do{if((jb|0)!=0|kd){if(!ub){nd=d[Za+(pb-md)|0]|0;break}switch(V|0){case 1:{nd=d[Za+(pb-1)|0]|0;break n;break};case 2:{nd=d[Za+(pb-md)|0]|0;break n;break};case 0:{nd=0;break n;break};case 3:{nd=d[Za+(pb+Xa)|0]|0;break n;break};case 4:{nd=(d[Za+(pb-md)|0]|0)+(d[Za+(pb-1)|0]|0)-(d[Za+(pb+Xa)|0]|0)|0;break n;break};case 5:{nd=((d[Za+(pb-md)|0]|0)-(d[Za+(pb+Xa)|0]|0)>>1)+(d[Za+(pb-1)|0]|0)|0;break n;break};case 6:{nd=((d[Za+(pb-1)|0]|0)-(d[Za+(pb+Xa)|0]|0)>>1)+(d[Za+(pb-md)|0]|0)|0;break n;break};default:{nd=((d[Za+(pb-md)|0]|0)+(d[Za+(pb-1)|0]|0)|0)>>>1;break n}}}else{if(!ub){nd=Oa;break}nd=d[Za+(pb-1)|0]|0}}while(0);do{if((c[E>>2]|0)==0){od=rb}else{if((c[X>>2]|0)==0){od=rb;break}od=Za+(pb+cb)|0}}while(0);a[od]=(nd&Ca)+(qb<<Ra)}else{pb=(xb<<1)+(Ta+Va<<1)|0;rb=Za+pb|0;ub=(Ta|0)!=0|ld;o:do{if((jb|0)!=0|kd){if(!ub){pd=e[rb+(Wa<<1)>>1]|0;break}switch(V|0){case 1:{pd=e[Za+(pb-2)>>1]|0;break o;break};case 5:{pd=((e[rb+(Wa<<1)>>1]|0)-(e[rb+(Xa<<1)>>1]|0)>>1)+(e[Za+(pb-2)>>1]|0)|0;break o;break};case 6:{pd=((e[Za+(pb-2)>>1]|0)-(e[rb+(Xa<<1)>>1]|0)>>1)+(e[rb+(Wa<<1)>>1]|0)|0;break o;break};case 0:{pd=0;break o;break};case 2:{pd=e[rb+(Wa<<1)>>1]|0;break o;break};case 3:{pd=e[rb+(Xa<<1)>>1]|0;break o;break};case 4:{pd=(e[rb+(Wa<<1)>>1]|0)+(e[Za+(pb-2)>>1]|0)-(e[rb+(Xa<<1)>>1]|0)|0;break o;break};default:{pd=((e[rb+(Wa<<1)>>1]|0)+(e[Za+(pb-2)>>1]|0)|0)>>>1;break o}}}else{if(!ub){pd=Oa;break}pd=e[Za+(pb-2)>>1]|0}}while(0);do{if((c[E>>2]|0)==0){qd=rb}else{if((c[X>>2]|0)==0){qd=rb;break}qd=rb+(cb<<1)|0}}while(0);b[qd>>1]=(pd&Ca)+(qb<<Ra)}rb=Ta+1|0;pb=(rb|0)==(bb|0);Za=eb+1|0;if((Za|0)<(mb|0)){Ta=pb?0:rb;jb=(pb&1)+jb|0;eb=Za}else{break}}}ib=ib+1|0;}while((ib|0)<(B|0))}ib=c[T>>2]|0;do{if((ib|0)!=0){db=(c[J>>2]|0)-1|0;c[J>>2]=db;if((db|0)!=0){break}db=c[u>>2]|0;ab=-db&7;eb=c[w>>2]|0;if((ab|0)==0){rd=db}else{jb=ab+db|0;db=eb>>>0>jb>>>0?jb:eb;c[u>>2]=db;rd=db}db=rd+16|0;c[u>>2]=eb>>>0>db>>>0?db:eb}}while(0);eb=Ya+1|0;sd=c[D>>2]|0;if((eb|0)<(sd|0)){Ka=fd;_a=ed;Ya=eb;Ia=ib}else{break}}td=fd;ud=ed;vd=sd;wd=c[q>>2]|0}else{td=Sa;ud=hb;vd=gb;wd=Ba}Ia=Da+1|0;if((Ia|0)<(wd|0)){Sa=td;hb=ud;Da=Ia;gb=vd;Ba=wd}else{break}}}}while(0);if((c[E>>2]|0)==0){s=0;N=375;break}Ba=c[u>>2]|0;gb=c[W>>2]|0;if((gb-Ba|0)<=32){s=0;N=375;break}Da=c[z>>2]|0;hb=Da+(Ba>>>3)|0;if(!(((je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(Ba&7)&-16777216|0)==-16777216)){s=0;N=375;break}hb=c[fa>>2]|0;Sa=c[w>>2]|0;Ra=-Ba&7;if((Ra|0)==0){xd=Ba}else{Ca=Ra+Ba|0;xd=Sa>>>0>Ca>>>0?Ca:Sa}Ca=Da+(xd>>>3)|0;if(!(((je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(xd&7)&-65536|0)==-3080192)){s=0;N=375;break}KIb(c[x>>2]|0,48,2291976,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;c[v>>2]=Da;c[fa>>2]=hb;c[W>>2]=gb;c[w>>2]=Sa;gb=xd+16|0;c[u>>2]=Sa>>>0>gb>>>0?gb:Sa;c[X>>2]=c[X>>2]^1;Aa=0}if((N|0)==49){KIb(0,0,2489128,(r=i,i=i+24|0,c[r>>2]=2303216,c[r+8>>2]=2468584,c[r+16>>2]=1402,r)|0);i=r;Hd();return 0}else if((N|0)==119){KIb(0,0,2489128,(r=i,i=i+24|0,c[r>>2]=2625960,c[r+8>>2]=2468584,c[r+16>>2]=962,r)|0);i=r;Hd();return 0}else if((N|0)==211){KIb(0,0,2489128,(r=i,i=i+24|0,c[r>>2]=2303216,c[r+8>>2]=2468584,c[r+16>>2]=1423,r)|0);i=r;Hd();return 0}else if((N|0)==213){KIb(c[x>>2]|0,16,2628864,(r=i,i=i+16|0,c[r>>2]=V,c[r+8>>2]=K,r)|0);i=r;s=-1094995529;i=k;return s|0}else if((N|0)==236){KIb(c[x>>2]|0,16,2632856,(r=i,i=i+8|0,c[r>>2]=Bc,r)|0);i=r}else if((N|0)==248){KIb(c[x>>2]|0,16,2632856,(r=i,i=i+8|0,c[r>>2]=sc,r)|0);i=r}else if((N|0)==274){KIb(c[x>>2]|0,16,2632856,(r=i,i=i+8|0,c[r>>2]=Zb,r)|0);i=r}else if((N|0)==278){KIb(c[x>>2]|0,16,2627328,(r=i,i=i+8|0,c[r>>2]=Wb,r)|0);i=r}else if((N|0)==375){i=k;return s|0}KIb(c[x>>2]|0,16,2644312,(r=i,i=i+16|0,c[r>>2]=Nb,c[r+8>>2]=Ob,r)|0);i=r;s=-1094995529;i=k;return s|0}else if((N|0)==374){KIb(c[x>>2]|0,16,2285208,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=k;return s|0}return 0}function mQa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;k=c[e>>2]|0;l=f;a:do{if((l-k|0)>1){m=k;n=a[k]|0;while(1){o=m+1|0;p=a[o]|0;if(n<<24>>24==-1){if((p&255)>>>0>191>>>0&p<<24>>24!=-1&o>>>0<f>>>0){break}}if((l-o|0)>1){m=o;n=p}else{q=-1;r=f;break a}}q=p&255;r=m+2|0}else{q=-1;r=f}}while(0);c[e>>2]=r;p=b+36|0;A4a(p,b+32|0,l-r|0);r=c[p>>2]|0;if((r|0)==0){s=-12;i=j;return s|0}if((q|0)!=218){c[g>>2]=c[e>>2];c[h>>2]=l-(c[e>>2]|0);s=q;i=j;return s|0}q=c[e>>2]|0;k=q>>>0<f>>>0;if((c[b+828>>2]|0)==0){n=b+4|0;b:do{if(k){b=r;o=q;while(1){t=o+1|0;u=a[o]|0;v=b+1|0;a[b]=u;do{if((c[(c[n>>2]|0)+48>>2]|0)!=101&u<<24>>24==-1){if(t>>>0<f>>>0){w=t}else{x=v;break b}while(1){z=w+1|0;A=a[w]|0;if(z>>>0<f>>>0&A<<24>>24==-1){w=z}else{break}}if((A+48&255)>>>0<8>>>0){a[v]=A;B=z;C=b+2|0;break}else{if(A<<24>>24==0){B=z;C=v;break}else{x=v;break b}}}else{B=t;C=v}}while(0);if(B>>>0<f>>>0){b=C;o=B}else{x=C;break}}}else{x=r}}while(0);c[g>>2]=c[p>>2];C=c[p>>2]|0;B=x;x=B-C|0;c[h>>2]=x;mrc(C+x|0,0,16)|0;KIb(c[n>>2]|0,48,2281136,(n=i,i=i+8|0,c[n>>2]=l-B-(c[e>>2]|0)+(c[p>>2]|0),n)|0);i=n;s=218;i=j;return s|0}c:do{if(k){n=0;e=q;while(1){B=n+1|0;if((a[e]|0)==-1){l=q+B|0;if(l>>>0<f>>>0){D=B;E=l}else{F=B;break}do{D=D+1|0;G=a[E]|0;E=q+D|0;}while(E>>>0<f>>>0&G<<24>>24==-1);if(G<<24>>24<0){F=D;break}else{H=D}}else{H=B}l=q+H|0;if(l>>>0<f>>>0){n=H;e=l}else{I=H;break c}}I=F-((F|0)<2?F:2)|0}else{I=0}}while(0);F=0;H=0;f=I<<3;D=32;G=(I|0)<0?0:r;E=0;d:while(1){k=H;J=D;K=G;L=E;while(1){if((k|0)>=(I|0)){break d}M=k+1|0;e=a[q+k|0]|0;n=e&255;if((J|0)>8){N=J-8|0;O=L<<8|n;P=K}else{l=K;y=je(n>>>((8-J|0)>>>0)|L<<J|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;N=J+24|0;O=n;P=K+4|0}F=O;if(e<<24>>24==-1){break}else{k=M;J=N;K=P;L=O}}e=d[q+M|0]|0;if((N|0)>7){Q=N-7|0;R=e|O<<7;S=P}else{n=P;y=je(e>>>((7-N|0)>>>0)|O<<N|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;Q=N+25|0;R=e;S=P+4|0}F=R;H=k+2|0;f=f-1|0;D=Q;G=S;E=R}if((J|0)<32){R=L<<J;F=R;L=R>>>24&255;R=J;J=K;while(1){a[J]=L;K=F;F=K<<8;E=R+8|0;if((E|0)<32){L=K>>>16&255;R=E;J=J+1|0}else{break}}}F=0;c[g>>2]=r;r=f+7>>3;c[h>>2]=r;mrc((c[p>>2]|0)+r|0,0,16)|0;s=218;i=j;return s|0}function nQa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0;h=i;i=i+104|0;j=h+32|0;k=h+48|0;l=h+56|0;m=h+64|0;n=h+72|0;o=h+80|0;p=h+88|0;q=h+96|0;r=e;e=c[g+24>>2]|0;s=c[g+28>>2]|0;g=c[b+60>>2]|0;t=g;u=g+2988|0;OGb(u);v=g+2992|0;w=v;mJb(v);x=g+872|0;c[x>>2]=-1;c[m>>2]=e;y=e+s|0;z=b;A=y;B=g+8|0;C=g+20|0;D=g+24|0;E=g+12|0;F=g+16|0;G=g+28|0;H=g+4|0;I=g+2944|0;J=g+2948|0;K=g+824|0;L=g+828|0;M=g+832|0;N=g+2968|0;O=b+696|0;P=h|0;Q=g+864|0;R=g+868|0;S=j|0;T=j+8|0;U=j+4|0;V=g+2952|0;W=g+836|0;X=g+856|0;Y=g+2960|0;Z=g+2956|0;_=g+2972|0;$=g+1144|0;aa=g+816|0;ba=g+820|0;da=e;a:while(1){b:do{if(da>>>0<y>>>0){ea=mQa(t,m,y,n,q)|0;if((ea|0)<0){fa=131;break}ga=c[q>>2]|0;if((ga|0)>268435455){fa=5;break a}ha=A-(c[m>>2]|0)|0;KIb(z,48,2272544,(ia=i,i=i+16|0,c[ia>>2]=ea,c[ia+8>>2]=ha,ia)|0);i=ia;ha=c[n>>2]|0;ja=ga>>>0>268435455>>>0?-8:ga<<3;ka=ja>>>0>2147483639>>>0|(ha|0)==0;la=ka?0:ha;ha=ka?0:ja;c[B>>2]=la;c[C>>2]=ha;c[D>>2]=ha+8;c[E>>2]=la+(ha>>3);c[F>>2]=0;if(ka){fa=7;break a}c[G>>2]=ea;if((c[(c[H>>2]|0)+688>>2]&256|0)!=0){KIb(z,48,2264152,(ia=i,i=i+8|0,c[ia>>2]=ea,ia)|0);i=ia}c:do{if((ea-208|0)>>>0<8>>>0){KIb(z,48,2260336,(ia=i,i=i+8|0,c[ia>>2]=ea&15,ia)|0);i=ia;fa=105}else{if(!((ea-224|0)>>>0<16>>>0)){switch(ea|0){case 194:{fa=111;break c;break};case 247:{fa=113;break c;break};case 196:{fa=108;break c;break};case 192:case 193:{fa=110;break c;break};case 218:{fa=125;break c;break};case 221:{fa=127;break c;break};case 197:case 198:case 199:case 201:case 202:case 203:case 205:case 206:case 207:case 200:{fa=129;break c;break};case 195:{fa=112;break c;break};case 217:{fa=115;break b;break};case 216:{fa=106;break c;break};case 219:{fa=107;break c;break};case 254:{break};case 248:{fa=114;break c;break};default:{break b}}ka=c[F>>2]|0;ha=c[D>>2]|0;la=(c[B>>2]|0)+(ka>>>3)|0;ja=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ka&7);la=ja>>>16;ma=ka+16|0;ka=ha>>>0>ma>>>0?ma:ha;c[F>>2]=ka;if(!(ja>>>0>131071>>>0)){break b}if(((la<<3)-16|0)>((c[C>>2]|0)-ka|0)){fa=105;break}ka=hJb(la-1|0)|0;if((ka|0)==0){fa=105;break}ha=la-2|0;do{if((ha|0)>0){ma=c[D>>2]|0;na=c[B>>2]|0;oa=0;pa=c[F>>2]|0;do{qa=na+(pa>>>3)|0;ra=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(pa&7)>>>24;qa=pa+8|0;pa=ma>>>0>qa>>>0?qa:ma;c[F>>2]=pa;a[ka+oa|0]=ra;oa=oa+1|0;}while((oa|0)<(ha|0));oa=ka+(la-3)|0;if((a[oa]|0)!=10){sa=ha;fa=87;break}a[oa]=0}else{sa=0;fa=87}}while(0);if((fa|0)==87){fa=0;a[ka+sa|0]=0}ha=c[H>>2]|0;if((c[ha+688>>2]&1|0)!=0){KIb(ha,32,2181040,(ia=i,i=i+8|0,c[ia>>2]=ka,ia)|0);i=ia}do{if((krc(ka,2178712,4)|0)==0){c[V>>2]=1;ha=ja>>>0>983039>>>0;do{if(ha){oa=a[ka+12|0]|0;if((oa<<24>>24|0)==2){c[Y>>2]=0;break}else if((oa<<24>>24|0)==1){c[Y>>2]=1;break}else{break}}}while(0);oa=c[H>>2]|0;if((c[oa+688>>2]&1|0)==0){break}if(ha){ta=d[ka+12|0]|0}else{ta=-1}KIb(oa,32,2623240,(ia=i,i=i+16|0,c[ia>>2]=la,c[ia+8>>2]=ta,ia)|0);i=ia}else{if((irc(ka,2176240)|0)==0){c[Z>>2]=1;break}if((krc(ka,2168392,32)|0)!=0){if((krc(ka,2164064,20)|0)!=0){break}}c[_>>2]=1}}while(0);kJb(ka);fa=105;break}la=c[F>>2]|0;ja=c[D>>2]|0;oa=c[B>>2]|0;pa=oa+(la>>>3)|0;ma=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(la&7);pa=ma>>>16;na=la+16|0;la=ja>>>0>na>>>0?na:ja;c[F>>2]=la;if(ma>>>0<393216>>>0){fa=105;break}if((pa<<3|0)>((c[C>>2]|0)-la|0)){fa=105;break}ma=oa+(la>>>3)|0;na=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)&-65536;ma=la+16|0;la=ja>>>0>ma>>>0?ma:ja;c[F>>2]=la;ma=oa+(la>>>3)|0;oa=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7)>>>16;ma=la+16|0;c[F>>2]=ja>>>0>ma>>>0?ma:ja;ja=oa|na;na=pa-6|0;if((c[(c[H>>2]|0)+688>>2]&256|0)!=0){v5a(P,32,je(ja|0)|0)|0;KIb(c[H>>2]|0,48,2161952,(ia=i,i=i+24|0,c[ia>>2]=P,c[ia+8>>2]=ja,c[ia+16>>2]=na,ia)|0);i=ia}do{if((ja|0)==1279936838){oa=c[H>>2]|0;if((c[oa+688>>2]&1|0)!=0){KIb(oa,32,2141648,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia}oa=c[D>>2]|0;ma=(c[F>>2]|0)+16|0;la=(oa>>>0>ma>>>0?ma:oa)+16|0;ma=(oa>>>0>la>>>0?la:oa)+16|0;la=(oa>>>0>ma>>>0?ma:oa)+16|0;ma=oa>>>0>la>>>0?la:oa;c[F>>2]=ma;la=(c[B>>2]|0)+(ma>>>3)|0;ra=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>24;la=ma+8|0;c[F>>2]=oa>>>0>la>>>0?la:oa;if((ra|0)==1){c[W>>2]=1;c[X>>2]=0}else if((ra|0)==2){c[W>>2]=1;c[X>>2]=1}else{KIb(c[H>>2]|0,16,2138120,(ia=i,i=i+8|0,c[ia>>2]=ra,ia)|0);i=ia}ua=pa-15|0}else if((ja|0)==1097101154){ra=c[F>>2]|0;oa=c[D>>2]|0;la=c[B>>2]|0;ma=la+(ra>>>3)|0;qa=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ra&7);ma=ra+8|0;ra=oa>>>0>ma>>>0?ma:oa;c[F>>2]=ra;if((qa&-16777216|0)!=1694498816){fa=43;break}qa=ra+16|0;ra=(oa>>>0>qa>>>0?qa:oa)+16|0;qa=(oa>>>0>ra>>>0?ra:oa)+16|0;ra=oa>>>0>qa>>>0?qa:oa;c[F>>2]=ra;qa=la+(ra>>>3)|0;la=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ra&7)>>>24;qa=ra+8|0;c[F>>2]=oa>>>0>qa>>>0?qa:oa;c[x>>2]=la;oa=c[H>>2]|0;if((c[oa+688>>2]&1|0)!=0){KIb(oa,32,2150432,(ia=i,i=i+8|0,c[ia>>2]=la,ia)|0);i=ia}ua=pa-13|0}else if((ja|0)==1096173873){c[V>>2]=1;la=c[F>>2]|0;oa=c[D>>2]|0;qa=(c[B>>2]|0)+(la>>>3)|0;ra=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(la&7)>>>24;qa=la+8|0;c[F>>2]=oa>>>0>qa>>>0?qa:oa;KIb(c[H>>2]|0,48,2158096,(ia=i,i=i+8|0,c[ia>>2]=ra,ia)|0);i=ia;ua=pa-7|0}else if((ja|0)==1246120262){ra=c[D>>2]|0;oa=(c[F>>2]|0)+8|0;qa=ra>>>0>oa>>>0?oa:ra;c[F>>2]=qa;oa=c[B>>2]|0;la=oa+(qa>>>3)|0;ma=d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0;la=qa+8|0;va=ra>>>0>la>>>0?la:ra;c[F>>2]=va;la=oa+(va>>>3)|0;wa=d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0;la=va+8|0;xa=(ra>>>0>la>>>0?la:ra)+8|0;la=ra>>>0>xa>>>0?xa:ra;c[F>>2]=la;xa=oa+(la>>>3)|0;ya=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(la&7)>>>16;xa=la+16|0;c[F>>2]=ra>>>0>xa>>>0?xa:ra;ra=c[H>>2]|0;xa=ra+224|0;c[xa>>2]=ya;ya=c[F>>2]|0;la=c[D>>2]|0;za=oa+(ya>>>3)|0;Aa=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(ya&7)>>>16;za=ya+16|0;c[F>>2]=la>>>0>za>>>0?za:la;c[ra+228>>2]=Aa;if((c[ra+688>>2]&1|0)==0){Ba=oa}else{oa=je(wa|0)|0;wa=(je(ma|0)|0)<<(qa&7)>>>24;qa=c[xa>>2]|0;KIb(ra,32,2154600,(ia=i,i=i+32|0,c[ia>>2]=wa,c[ia+8>>2]=oa<<(va&7)>>>24,c[ia+16>>2]=qa,c[ia+24>>2]=Aa,ia)|0);i=ia;Ba=c[B>>2]|0}Aa=c[F>>2]|0;qa=c[D>>2]|0;va=Ba+(Aa>>>3)|0;oa=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(Aa&7)>>>24;va=Aa+8|0;Aa=qa>>>0>va>>>0?va:qa;c[F>>2]=Aa;va=Ba+(Aa>>>3)|0;wa=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(Aa&7)>>>24;va=Aa+8|0;c[F>>2]=qa>>>0>va>>>0?va:qa;if((oa|0)==0|(wa|0)==0){Ca=na}else{qa=ca(oa*3|0,wa)|0;Ca=na-((pa-16-qa|0)>0?qa:0)|0}ua=Ca-10|0}else{qa=(na|0)>0;if((ja|0)==1919709027&qa){wa=c[F>>2]|0;oa=c[D>>2]|0;va=(c[B>>2]|0)+(wa>>>3)|0;Aa=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7)>>>24;va=wa+8|0;c[F>>2]=oa>>>0>va>>>0?va:oa;c[Q>>2]=Aa;oa=c[H>>2]|0;if((c[oa+688>>2]&1|0)!=0){KIb(oa,32,2134496,(ia=i,i=i+8|0,c[ia>>2]=Aa,ia)|0);i=ia}ua=pa-7|0;break}if(!((ja|0)==1836213880&qa)){fa=43;break}qa=c[F>>2]|0;Aa=c[D>>2]|0;oa=(c[B>>2]|0)+(qa>>>3)|0;va=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(qa&7)>>>24;oa=qa+8|0;c[F>>2]=Aa>>>0>oa>>>0?oa:Aa;c[R>>2]=va;Aa=c[H>>2]|0;if((c[Aa+688>>2]&1|0)!=0){KIb(Aa,32,2131120,(ia=i,i=i+8|0,c[ia>>2]=va,ia)|0);i=ia}ua=pa-7|0}}while(0);do{if((fa|0)==43){fa=0;ka=c[G>>2]|0;if((ka|0)==227){if(!((ja|0)==1598705747&(na|0)>9)){ua=na;break}va=c[H>>2]|0;if((c[va+688>>2]&1|0)!=0){KIb(va,32,2128120,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia}va=c[D>>2]|0;Aa=(c[F>>2]|0)+32|0;oa=(va>>>0>Aa>>>0?Aa:va)+16|0;Aa=(va>>>0>oa>>>0?oa:va)+8|0;oa=va>>>0>Aa>>>0?Aa:va;c[F>>2]=oa;Aa=c[B>>2]|0;qa=Aa+(oa>>>3)|0;wa=je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0;qa=oa&7;ra=oa+8|0;oa=va>>>0>ra>>>0?ra:va;c[F>>2]=oa;ra=Aa+(oa>>>3)|0;xa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(oa&7)>>>24;ra=oa+8|0;oa=va>>>0>ra>>>0?ra:va;c[F>>2]=oa;ra=Aa+(oa>>>3)|0;Aa=d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0;ra=oa+8|0;c[F>>2]=va>>>0>ra>>>0?ra:va;va=pa-16|0;ra=hLb()|0;c[w>>2]=ra;if((ra|0)==0){ua=va;break}ma=(je(Aa|0)|0)<<(oa&7)>>>24;if((ma|0)==0){c[ra>>2]=0;ua=va;break}else if((ma|0)!=1){ua=va;break}if((xa|0)==3){c[ra>>2]=2}else if((xa|0)==2){c[ra>>2]=1}else if((xa|0)==1){c[ra>>2]=6}if((67108864>>>(qa>>>0)&wa|0)!=0){ua=va;break}c[ra+4>>2]=1;ua=va;break}else if((ka|0)!=225){ua=na;break}if(!((ja|0)==1165519206&(na|0)>1)){if((na|0)<=32){ua=na;break}ka=c[F>>2]|0;va=c[D>>2]|0;ra=c[B>>2]|0;wa=ra+(ka>>>3)|0;qa=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ka&7)&-65536;wa=ka+16|0;ka=va>>>0>wa>>>0?wa:va;c[F>>2]=ka;wa=ra+(ka>>>3)|0;ra=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ka&7)>>>16;wa=ka+16|0;c[F>>2]=va>>>0>wa>>>0?wa:va;va=pa-10|0;if((ra|qa|0)!=1835692135){ua=va;break}qa=c[H>>2]|0;if((c[qa+688>>2]&1|0)==0){ua=va;break}KIb(qa,32,2113040,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;ua=va;break}va=c[D>>2]|0;qa=(c[F>>2]|0)+16|0;ra=va>>>0>qa>>>0?qa:va;qa=pa-8|0;wa=-ra&7;if((wa|0)==0){Da=ra}else{ka=wa+ra|0;Da=va>>>0>ka>>>0?ka:va}c[F>>2]=Da;va=c[B>>2]|0;ka=Da>>3;ra=va+ka|0;if(!((qa|0)>-1)){fa=60;break a}c[S>>2]=ra;c[T>>2]=ra;c[U>>2]=va+(ka+qa);if((B3a(j,k,l)|0)!=0){KIb(c[H>>2]|0,16,2124368,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;fa=105;break c}ka=c[l>>2]|0;va=c[T>>2]|0;ra=(c[U>>2]|0)-va|0;if((ka|0)<0){Ea=0}else{Ea=(ra|0)<(ka|0)?ra:ka}c[S>>2]=va+Ea;if((Dpb(c[H>>2]|0,j,c[k>>2]|0,0,u)|0)<0){KIb(c[H>>2]|0,16,2118064,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;fa=105;break c}else{va=(c[S>>2]|0)-(c[T>>2]|0)|0;ka=c[D>>2]|0;ra=(va<<3)+(c[F>>2]|0)|0;c[F>>2]=ka>>>0>ra>>>0?ra:ka;ua=qa-va|0;break}}}while(0);if((ua|0)<0){KIb(c[H>>2]|0,16,2111152,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia}pa=ua-1|0;if((pa|0)<=0){fa=105;break}na=c[D>>2]|0;ja=pa;pa=c[F>>2]|0;do{va=pa+8|0;pa=na>>>0>va>>>0?va:na;ja=ja-1|0;}while((ja|0)>0);c[F>>2]=pa;fa=105}}while(0);if((fa|0)==105){fa=0;switch(ea|0){case 194:{fa=111;break};case 247:{fa=113;break};case 196:{fa=108;break};case 192:case 193:{fa=110;break};case 218:{fa=125;break};case 221:{fa=127;break};case 197:case 198:case 199:case 201:case 202:case 203:case 205:case 206:case 207:case 200:{fa=129;break};case 195:{fa=112;break};case 217:{fa=115;break b;break};case 216:{fa=106;break};case 219:{fa=107;break};case 248:{fa=114;break};default:{break b}}}if((fa|0)==106){fa=0;c[I>>2]=0;c[J>>2]=0;break}else if((fa|0)==107){fa=0;iQa(t)|0;break}else if((fa|0)==108){fa=0;Fa=hQa(t)|0;if((Fa|0)<0){fa=109;break a}else{break}}else if((fa|0)==110){fa=0;c[K>>2]=0;c[L>>2]=0;c[M>>2]=0;ja=kQa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==111){fa=0;c[K>>2]=0;c[L>>2]=0;c[M>>2]=1;ja=kQa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==112){fa=0;c[K>>2]=1;c[L>>2]=0;c[M>>2]=0;ja=kQa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==113){fa=0;c[K>>2]=1;c[L>>2]=1;c[M>>2]=0;ja=kQa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==114){fa=0;ja=eOa(t)|0;if((ja|0)<0){Ga=ja;break a}else{break}}else if((fa|0)==125){fa=0;c[N>>2]=(c[N>>2]|0)+1;ja=lQa(t,0,0,0)|0;if((ja|0)>=0){break}if((c[O>>2]&8|0)==0){break}else{Ga=ja;break a}}else if((fa|0)==127){fa=0;ja=c[F>>2]|0;na=c[D>>2]|0;va=c[B>>2]|0;qa=va+(ja>>>3)|0;ka=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ja&7);qa=ja+16|0;ja=na>>>0>qa>>>0?qa:na;c[F>>2]=ja;if((ka&-65536|0)!=262144){break}ka=va+(ja>>>3)|0;va=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ja&7)>>>16;ka=ja+16|0;c[F>>2]=na>>>0>ka>>>0?ka:na;c[I>>2]=va;c[J>>2]=0;KIb(c[H>>2]|0,48,2183144,(ia=i,i=i+8|0,c[ia>>2]=va,ia)|0);i=ia;break}else if((fa|0)==129){fa=0;KIb(z,16,2235400,(ia=i,i=i+8|0,c[ia>>2]=ea,ia)|0);i=ia;break}}else{fa=131}}while(0);if((fa|0)==131){fa=0;if((c[$>>2]|0)==0){fa=134;break}if((c[N>>2]|0)==0){fa=134;break}KIb(z,24,2228008,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;fa=115}do{if((fa|0)==115){fa=0;c[N>>2]=0;if((c[$>>2]|0)==0){KIb(z,24,2251680,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;break}if((c[aa>>2]|0)==0){fa=119;break a}va=c[ba>>2]^1;c[ba>>2]=va;if((va|0)!=((c[Y>>2]|0)==0|0)){fa=119;break a}}}while(0);va=c[F>>2]|0;na=(va+7|0)/8|0;ka=(c[m>>2]|0)+na|0;c[m>>2]=ka;KIb(z,48,2231808,(ia=i,i=i+16|0,c[ia>>2]=na,c[ia+8>>2]=va,ia)|0);i=ia;da=ka}if((fa|0)==5){KIb(z,16,2277112,(ia=i,i=i+24|0,c[ia>>2]=ea,c[ia+8>>2]=ga,c[ia+16>>2]=s,ia)|0);i=ia;Ha=-1094995529;i=h;return Ha|0}else if((fa|0)==7){KIb(z,16,2267880,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Ga=-1094995529}else if((fa|0)==60){KIb(0,0,2489128,(ia=i,i=i+24|0,c[ia>>2]=2109512,c[ia+8>>2]=2107960,c[ia+16>>2]=135,ia)|0);i=ia;Hd();return 0}else if((fa|0)==109){KIb(z,16,2255872,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Ga=Fa}else if((fa|0)==119){Fa=g+1140|0;s=YHb(r,c[Fa>>2]|0)|0;if((s|0)<0){Ha=s;i=h;return Ha|0}c[f>>2]=1;c[$>>2]=0;do{if((c[K>>2]|0)==0){f=c[g+792>>2]|0;s=c[g+796>>2]|0;ga=(f|0)>(s|0)?f:s;s=c[g+800>>2]|0;f=(ga|0)>(s|0)?ga:s;s=((c[g+900>>2]|0)+15|0)/16|0;ga=cGb(s)|0;if((ga|0)!=0){mrc(c[ga+4>>2]|0,f&255|0,s|0)|0;RHb(r,ga,0,0)|0}if((c[b+688>>2]&16|0)==0){break}KIb(z,48,2241200,(ia=i,i=i+8|0,c[ia>>2]=f,ia)|0);i=ia}}while(0);K=g+840|0;f=c[K>>2]|0;d:do{if((f|0)!=0){ga=c[(c[Fa>>2]|0)+(f<<2)>>2]|0;s=c[b+140>>2]|0;if(!((s|0)==14|(s|0)==5|(s|0)==34|(s|0)==33)){KIb(0,0,2489128,(ia=i,i=i+24|0,c[ia>>2]=2219528,c[ia+8>>2]=2468584,c[ia+16>>2]=2042,ia)|0);i=ia;Hd();return 0}s=g+844|0;ea=c[s>>2]|0;if((ea|0)<=0){break}da=g+900|0;F=g+1148|0;Y=ga;ga=1;ba=f;aa=ea;while(1){ea=c[da>>2]|0;N=ea-1|0;if((N|0)==0){Ia=ba;Ja=aa}else{J=ea;ea=N;while(1){a[Y+ea|0]=((d[Y+((J|0)/2|0)|0]|0)+(d[Y+((ea|0)/2|0)|0]|0)|0)>>>1;N=ea-1|0;if((N|0)==0){break}else{J=ea;ea=N}}Ia=c[K>>2]|0;Ja=c[s>>2]|0}if((ga|0)>=(Ja|0)){break d}Y=Y+(c[F+(Ia<<2)>>2]|0)|0;ga=ga+1|0;ba=Ia;aa=Ja}}}while(0);Ja=g+848|0;Ia=c[Ja>>2]|0;e:do{if((Ia|0)!=0){K=g+904|0;f=g+1148|0;aa=ca((c[K>>2]|0)-1|0,c[f+(Ia<<2)>>2]|0)|0;ba=(c[(c[Fa>>2]|0)+(Ia<<2)>>2]|0)+aa|0;vLa(c[(c[H>>2]|0)+140>>2]|0,o,p);aa=c[g+900>>2]>>c[o>>2];ga=c[b+140>>2]|0;if(!((ga|0)==14|(ga|0)==5|(ga|0)==13|(ga|0)==4)){KIb(0,0,2489128,(ia=i,i=i+24|0,c[ia>>2]=2216568,c[ia+8>>2]=2468584,c[ia+16>>2]=2057,ia)|0);i=ia;Hd();return 0}ga=c[K>>2]|0;K=ga-1|0;if((K|0)==0){break}F=(aa|0)>0;Y=c[Ja>>2]|0;s=ba;ba=ga;ga=K;K=Y;da=c[f+(Y<<2)>>2]|0;while(1){Y=ca(da,(ga|0)/2|0)|0;ea=c[(c[Fa>>2]|0)+(K<<2)>>2]|0;J=ca((ba|0)/2|0,da)|0;do{if((Y|0)==(J|0)){nrc(s|0,ea+Y|0,aa)|0}else{if(F){Ka=0}else{break}do{a[s+Ka|0]=((d[ea+(Ka+J)|0]|0)+(d[ea+(Ka+Y)|0]|0)|0)>>>1;Ka=Ka+1|0;}while((Ka|0)<(aa|0))}}while(0);Y=c[Ja>>2]|0;ea=c[f+(Y<<2)>>2]|0;J=ga-1|0;if((J|0)==0){break e}s=s+(-ea|0)|0;ba=ga;ga=J;K=Y;da=ea}}}while(0);if((c[_>>2]|0)!=0){vLa(c[(c[H>>2]|0)+140>>2]|0,o,p);_=0;Ja=c[Fa>>2]|0;while(1){Ka=c[Ja+(_<<2)>>2]|0;b=c[Ja+68>>2]|0;g=c[Ja+72>>2]|0;if((_|0)!=0&(_|0)<3){La=-(-g>>c[p>>2])|0;Ma=-(-b>>c[o>>2])|0}else{La=g;Ma=b}do{if((Ka|0)==0){Na=Ja}else{b=(La|0)/2|0;if((La|0)<=1){Na=Ja;break}g=(Ma|0)>0;Ia=Ka+(ca(c[Ja+32+(_<<2)>>2]|0,La-1|0)|0)|0;da=Ka;K=0;ga=Ja;while(1){if(g){ba=0;do{s=Ia+ba|0;f=a[s]|0;aa=da+ba|0;a[s]=a[aa]|0;a[aa]=f;ba=ba+1|0;}while((ba|0)<(Ma|0));Oa=c[Fa>>2]|0}else{Oa=ga}ba=c[Oa+32+(_<<2)>>2]|0;f=K+1|0;if((f|0)<(b|0)){Ia=Ia+(-ba|0)|0;da=da+ba|0;K=f;ga=Oa}else{Na=Oa;break}}}}while(0);Ka=_+1|0;if((Ka|0)<4){_=Ka;Ja=Na}else{break}}}f:do{if((c[x>>2]|0)==0){if((c[(c[H>>2]|0)+140>>2]|0)!=317){break}Na=c[Fa>>2]|0;Ja=c[Na+68>>2]|0;_=c[Na+72>>2]|0;if((_|0)<=0){break}Oa=(Ja|0)>0;Ma=0;La=Na;while(1){Na=c[La>>2]|0;o=ca(c[La+32>>2]|0,Ma)|0;p=c[La+4>>2]|0;Ka=ca(c[La+36>>2]|0,Ma)|0;ga=c[La+8>>2]|0;K=ca(c[La+40>>2]|0,Ma)|0;da=c[La+12>>2]|0;Ia=ca(c[La+44>>2]|0,Ma)|0;if(Oa){b=0;do{g=da+(Ia+b)|0;f=Na+(o+b)|0;ba=d[f]|0;aa=p+(Ka+b)|0;s=ga+(K+b)|0;F=d[s]|0;ea=(d[g]|0)*257|0;a[f]=(ca(ea,d[aa]|0)|0)>>>16;a[aa]=(ca(ea,F)|0)>>>16;a[s]=(ca(ea,ba)|0)>>>16;a[g]=-1;b=b+1|0;}while((b|0)<(Ja|0))}b=Ma+1|0;if((b|0)>=(_|0)){break f}Ma=b;La=c[Fa>>2]|0}}}while(0);if((c[w>>2]|0)!=0){Fa=iLb(r)|0;if((Fa|0)!=0){H=c[w>>2]|0;c[Fa>>2]=c[H>>2];c[Fa+4>>2]=c[H+4>>2]}mJb(v)}v=QHb(r)|0;PGb(v,c[u>>2]|0,0);OGb(u);u=c[m>>2]|0;KIb(z,48,2213904,(ia=i,i=i+8|0,c[ia>>2]=A-u,ia)|0);i=ia;Ha=u-e|0;i=h;return Ha|0}else if((fa|0)==134){KIb(z,8,2223112,(ia=i,i=i+1|0,i=i+7&-8,c[ia>>2]=0,ia)|0);i=ia;Ha=-1094995529;i=h;return Ha|0}c[$>>2]=0;Ha=Ga;i=h;return Ha|0}function oQa(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a+60>>2]|0;do{if((c[d+816>>2]|0)!=0){if((c[d+820>>2]|0)!=((c[d+2960>>2]|0)==0|0)){break}if((c[d+1144>>2]|0)==0){break}if((c[a+428>>2]|0)!=0){break}KIb(a,32,2211544,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}}while(0);a=d+1136|0;do{if((c[a>>2]|0)==0){e=c[d+1140>>2]|0;if((e|0)==0){break}WHb(e)}else{VHb(a);c[d+1140>>2]=0}}while(0);mJb(d+36|0);mJb(d+2992|0);mJb(d+2976|0);c[d+2980>>2]=0;c3(d+552|0);c3(d+572|0);c3(d+592|0);c3(d+612|0);c3(d+632|0);c3(d+652|0);c3(d+672|0);c3(d+692|0);c3(d+712|0);c3(d+732|0);c3(d+752|0);c3(d+772|0);mJb(d+1296|0);mJb(d+1312|0);mJb(d+1300|0);mJb(d+1316|0);mJb(d+1304|0);mJb(d+1320|0);mJb(d+1308|0);mJb(d+1324|0);OGb(d+2988|0);i=b;return 0}function pQa(a){a=a|0;c[(c[a+60>>2]|0)+1144>>2]=0;return}function qQa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[a+2944>>2]|0)==0){e=0;return e|0}f=a+2948|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;if((g|0)!=0){e=0;return e|0}do{if((c[(c[a+4>>2]|0)+48>>2]|0)==101){g=a+16|0;h=c[g>>2]|0;i=-h&7;if((i|0)!=0){j=c[a+24>>2]|0;k=i+h|0;c[g>>2]=j>>>0>k>>>0?k:j}if((b|0)<=0){l=9;break}j=a+860|0;k=0;do{c[a+1120+(k<<2)>>2]=4<<c[j>>2];k=k+1|0;}while((k|0)<(b|0));k=a+16|0;j=c[k>>2]|0;g=-j&7;if((c[f>>2]|0)==0){m=k;n=j;o=g;p=g;break}else{e=0}return e|0}else{l=9}}while(0);if((l|0)==9){l=a+16|0;f=c[l>>2]|0;g=-f&7;m=l;n=f;o=g;p=g}g=p|8;p=c[a+8>>2]|0;f=p+(n>>>3)|0;l=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(n&7)>>>((32-g|0)>>>0);if(!((l|0)==((1<<g)-1|0)|(l|0)==255)){e=0;return e|0}if((o|0)==0){q=n}else{l=c[a+24>>2]|0;g=o+n|0;o=l>>>0>g>>>0?g:l;c[m>>2]=o;q=o}o=c[a+20>>2]|0;a:do{if((o-q|0)>7){l=a+24|0;g=q;while(1){f=p+(g>>>3)|0;if(!(((je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(g&7)&-16777216|0)==-16777216)){r=g;break a}f=c[l>>2]|0;j=g+8|0;k=f>>>0>j>>>0?j:f;c[m>>2]=k;if((o-k|0)>7){g=k}else{r=k;break}}}else{r=q}}while(0);q=c[a+24>>2]|0;do{if((o-r|0)>7){g=p+(r>>>3)|0;l=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(r&7);g=r+8|0;k=q>>>0>g>>>0?g:q;c[m>>2]=k;if(!((l&-134217728|0)==-805306368)){s=k;break}if((b|0)<=0){e=1;return e|0}k=a+860|0;l=0;while(1){c[a+1120+(l<<2)>>2]=4<<c[k>>2];g=l+1|0;if((g|0)<(b|0)){l=g}else{e=1;break}}return e|0}else{s=r}}while(0);r=n-s|0;n=-s|0;b=q-s|0;if((r|0)<(n|0)){t=n}else{t=(b|0)<(r|0)?b:r}c[m>>2]=t+s;e=0;return e|0}function rQa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=c[a+552+(e*20|0)+4>>2]|0;h=a+16|0;j=c[h>>2]|0;k=c[a+24>>2]|0;l=c[a+8>>2]|0;m=l+(j>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>23;m=b[g+(n<<2)>>1]|0;o=b[g+(n<<2)+2>>1]|0;n=o<<16>>16;if(o<<16>>16<0){o=j+9|0;p=k>>>0>o>>>0?o:k;o=l+(p>>>3)|0;q=((je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(p&7)>>>((n+32|0)>>>0))+m|0;r=b[g+(q<<2)+2>>1]|0;s=b[g+(q<<2)>>1]|0;t=p}else{r=n;s=m;t=j}j=r+t|0;t=k>>>0>j>>>0?j:k;c[h>>2]=t;if(s>>>0>16>>>0){KIb(c[a+4>>2]|0,24,2636088,(j=i,i=i+24|0,c[j>>2]=0,c[j+8>>2]=e,c[j+16>>2]=a+552+(e*20|0),j)|0);i=j;u=1048575;i=f;return u|0}if((s|0)==0){u=0;i=f;return u|0}j=l+(t>>>3)|0;l=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(t&7);j=(l^-2147483648)>>31;e=t+s|0;c[h>>2]=k>>>0>e>>>0?e:k;u=((j^l)>>>((32-s|0)>>>0)^j)-j|0;i=f;return u|0}function sQa(a){a=a|0;var b=0,d=0,e=0;b=i;do{if((c[a+8>>2]|0)<=65500){if((c[a+12>>2]|0)>65500){break}d=hJb(1608)|0;if((d|0)==0){e=-12;i=b;return e|0}c[a+13080>>2]=-1023;c[a+13084>>2]=1023;eQa(d,d+12|0,1965720,1965368);eQa(d+36|0,d+48|0,1965744,1965368);eQa(d+72|0,d+328|0,1965768,1965384);eQa(d+840|0,d+1096|0,1965792,1965552);c[a+14052>>2]=d;e=0;i=b;return e|0}}while(0);KIb(a,16,2511144,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-22;i=b;return e|0}function tQa(a){a=a|0;kJb(c[a+14052>>2]|0);return}function uQa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a+140|0;tKb(c[h>>2]|0,f,g)|0;j=c[h>>2]|0;a:do{if((c[(c[a+12>>2]|0)+12>>2]|0)==10){switch(j|0){case 5:case 14:{k=5;break a;break};case 298:case 30:case 3:{break};default:{k=6;break a}}c[b+8>>2]=1;c[d+8>>2]=1;c[b+4>>2]=1;c[d+4>>2]=1;c[b>>2]=1;c[d>>2]=1;i=e;return}else{if((j|0)==5|(j|0)==14){k=5}else{k=6}}}while(0);if((k|0)==5){c[d+8>>2]=2;c[d+4>>2]=2;c[d>>2]=2;c[b+8>>2]=1;c[b+4>>2]=1;c[b>>2]=1;i=e;return}else if((k|0)==6){c[d>>2]=2;k=2>>>((c[g>>2]|0)>>>0);c[d+4>>2]=k;c[d+8>>2]=k;c[b>>2]=2;k=2>>>((c[f>>2]|0)>>>0);c[b+4>>2]=k;c[b+8>>2]=k;i=e;return}}function vQa(b,f,g,h,j){b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=b+48|0;o=c[n>>2]|0;p=(o|0)!=108&(o|0)!=8;q=h;r=j;s=(grc(q,r,128)|0)!=0|0;t=b+140|0;tKb(c[t>>2]|0,l,m)|0;u=b+12|0;v=c[t>>2]|0;if((c[(c[u>>2]|0)+12>>2]|0)==10){switch(v|0){case 5:case 14:{w=4;break};case 298:case 30:case 3:{x=1;z=1;A=1;B=1;break};default:{w=5}}}else{if((v|0)==5|(v|0)==14){w=4}else{w=5}}if((w|0)==4){x=2;z=2;A=1;B=1}else if((w|0)==5){x=2;z=2>>>((c[m>>2]|0)>>>0);A=2;B=2>>>((c[l>>2]|0)>>>0)}l=f|0;m=c[l>>2]|0;v=f+4|0;C=c[v>>2]|0;if((C|0)>8){D=C-8|0;E=m<<8|255}else{F=je(255>>>((8-C|0)>>>0)|m<<C|0)|0;m=f+12|0;G=c[m>>2]|0;y=F;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;D=C+24|0;E=255}c[l>>2]=E;c[v>>2]=D;if((D|0)>8){H=D-8|0;I=E<<8|216}else{C=je(216>>>((8-D|0)>>>0)|E<<D|0)|0;E=f+12|0;m=c[E>>2]|0;y=C;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;H=D+24|0;I=216}c[l>>2]=I;c[v>>2]=H;if((c[n>>2]|0)==108){J=H}else{D=b+224|0;do{if((c[D>>2]|0)>0){E=b+228|0;if((c[E>>2]|0)<=0){K=I;L=H;break}if((H|0)>8){M=H-8|0;N=I<<8|255}else{m=je(I<<H|255>>>((8-H|0)>>>0)|0)|0;C=f+12|0;G=c[C>>2]|0;y=m;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;M=H+24|0;N=255}c[l>>2]=N;c[v>>2]=M;if((M|0)>8){O=M-8|0;P=N<<8|224}else{C=je(224>>>((8-M|0)>>>0)|N<<M|0)|0;G=f+12|0;m=c[G>>2]|0;y=C;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;O=M+24|0;P=224}c[l>>2]=P;c[v>>2]=O;if((O|0)>16){Q=O-16|0;R=P<<16|16}else{G=je(16>>>((16-O|0)>>>0)|P<<O|0)|0;m=f+12|0;C=c[m>>2]|0;y=G;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;Q=O+16|0;R=16}c[l>>2]=R;c[v>>2]=Q;Z2(f,2638632,1);m=c[l>>2]|0;C=c[v>>2]|0;if((C|0)>16){S=C-16|0;T=m<<16|258}else{G=je(258>>>((16-C|0)>>>0)|m<<C|0)|0;m=f+12|0;F=c[m>>2]|0;y=G;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;S=C+16|0;T=258}c[l>>2]=T;c[v>>2]=S;if((S|0)>8){U=S-8|0;V=T<<8}else{C=je(T<<S|0)|0;m=f+12|0;F=c[m>>2]|0;y=C;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;U=S+24|0;V=0}c[l>>2]=V;c[v>>2]=U;m=c[D>>2]|0;if((U|0)>16){W=U-16|0;X=m|V<<16}else{F=je(m>>>((16-U|0)>>>0)|V<<U|0)|0;C=f+12|0;G=c[C>>2]|0;y=F;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;W=U+16|0;X=m}c[l>>2]=X;c[v>>2]=W;m=c[E>>2]|0;if((W|0)>16){Y=W-16|0;Z=m|X<<16}else{E=je(m>>>((16-W|0)>>>0)|X<<W|0)|0;C=f+12|0;G=c[C>>2]|0;y=E;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;Y=W+16|0;Z=m}c[l>>2]=Z;c[v>>2]=Y;if((Y|0)>8){_=Y-8|0;$=Z<<8}else{m=je(Z<<Y|0)|0;C=f+12|0;G=c[C>>2]|0;y=m;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;_=Y+24|0;$=0}c[l>>2]=$;c[v>>2]=_;if((_|0)>8){aa=_-8|0;ba=$<<8}else{C=je($<<_|0)|0;G=f+12|0;m=c[G>>2]|0;y=C;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;aa=_+24|0;ba=0}c[l>>2]=ba;c[v>>2]=aa;K=ba;L=aa}else{K=I;L=H}}while(0);if((c[b+88>>2]&8388608|0)==0){if((L|0)>8){ca=L-8|0;da=K<<8|255}else{H=je(255>>>((8-L|0)>>>0)|K<<L|0)|0;K=f+12|0;I=c[K>>2]|0;y=H;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[K>>2]=(c[K>>2]|0)+4;ca=L+24|0;da=255}c[l>>2]=da;c[v>>2]=ca;if((ca|0)>8){ea=ca-8|0;fa=da<<8|254}else{L=je(254>>>((8-ca|0)>>>0)|da<<ca|0)|0;da=f+12|0;K=c[da>>2]|0;y=L;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[da>>2]=(c[da>>2]|0)+4;ea=ca+24|0;fa=254}c[l>>2]=fa;c[v>>2]=ea;a:do{if((ea|0)<32){ca=fa<<ea;c[l>>2]=ca;da=f+12|0;K=ca>>>24&255;while(1){ca=c[da>>2]|0;c[da>>2]=ca+1;a[ca]=K;ca=c[l>>2]|0;c[l>>2]=ca<<8;L=(c[v>>2]|0)+8|0;c[v>>2]=L;if((L|0)>=32){ga=da;break a}K=ca>>>16&255}}else{ga=f+12|0}}while(0);c[v>>2]=32;ea=c[ga>>2]|0;c[l>>2]=0;c[v>>2]=16;Z2(f,2616064,1);ga=ea;y=4096;a[ga]=y;y=y>>8;a[ga+1|0]=y}ga=c[t>>2]|0;if((ga|0)==0|(ga|0)==4|(ga|0)==5){ga=c[l>>2]|0;ea=c[v>>2]|0;if((ea|0)>8){ha=ea-8|0;ia=ga<<8|255}else{fa=je(255>>>((8-ea|0)>>>0)|ga<<ea|0)|0;ga=f+12|0;K=c[ga>>2]|0;y=fa;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[ga>>2]=(c[ga>>2]|0)+4;ha=ea+24|0;ia=255}c[l>>2]=ia;c[v>>2]=ha;if((ha|0)>8){ja=ha-8|0;ka=ia<<8|254}else{ea=je(254>>>((8-ha|0)>>>0)|ia<<ha|0)|0;ia=f+12|0;ga=c[ia>>2]|0;y=ea;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[ia>>2]=(c[ia>>2]|0)+4;ja=ha+24|0;ka=254}c[l>>2]=ka;c[v>>2]=ja;b:do{if((ja|0)<32){ha=ka<<ja;c[l>>2]=ha;ia=f+12|0;ga=ha>>>24&255;while(1){ha=c[ia>>2]|0;c[ia>>2]=ha+1;a[ha]=ga;ha=c[l>>2]|0;c[l>>2]=ha<<8;ea=(c[v>>2]|0)+8|0;c[v>>2]=ea;if((ea|0)>=32){la=ia;break b}ga=ha>>>16&255}}else{la=f+12|0}}while(0);c[v>>2]=32;ja=c[la>>2]|0;c[l>>2]=0;c[v>>2]=16;Z2(f,2588872,1);la=ja;y=3072;a[la]=y;y=y>>8;a[la+1|0]=y}do{if((c[n>>2]|0)==10){ma=c[v>>2]|0;na=c[l>>2]|0}else{la=(grc(q,r,128)|0)!=0;ja=c[l>>2]|0;ka=c[v>>2]|0;if((ka|0)>8){oa=ka-8|0;pa=ja<<8|255}else{ga=je(255>>>((8-ka|0)>>>0)|ja<<ka|0)|0;ja=f+12|0;ia=c[ja>>2]|0;y=ga;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;oa=ka+24|0;pa=255}c[l>>2]=pa;c[v>>2]=oa;if((oa|0)>8){qa=oa-8|0;ra=pa<<8|219}else{ka=je(219>>>((8-oa|0)>>>0)|pa<<oa|0)|0;ja=f+12|0;ia=c[ja>>2]|0;y=ka;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;qa=oa+24|0;ra=219}c[l>>2]=ra;c[v>>2]=qa;ja=la?132:67;if((qa|0)>16){sa=qa-16|0;ta=ra<<16|ja}else{ia=je(ja>>>((16-qa|0)>>>0)|ra<<qa|0)|0;ka=f+12|0;ga=c[ka>>2]|0;y=ia;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[ka>>2]=(c[ka>>2]|0)+4;sa=qa+16|0;ta=ja}c[l>>2]=ta;c[v>>2]=sa;if((sa|0)>4){ua=sa-4|0;va=ta<<4}else{ja=je(ta<<sa|0)|0;ka=f+12|0;ga=c[ka>>2]|0;y=ja;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[ka>>2]=(c[ka>>2]|0)+4;ua=sa+28|0;va=0}c[l>>2]=va;c[v>>2]=ua;if((ua|0)>4){wa=ua-4|0;xa=va<<4;ya=f+12|0}else{ka=je(va<<ua|0)|0;ga=f+12|0;ja=c[ga>>2]|0;y=ka;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;c[ga>>2]=(c[ga>>2]|0)+4;wa=ua+28|0;xa=0;ya=ga}c[l>>2]=xa;c[v>>2]=wa;ga=0;ja=xa;ka=wa;while(1){ia=e[h+((d[g+4+ga|0]|0)<<1)>>1]|0;if((ka|0)>8){za=ka-8|0;Aa=ia|ja<<8}else{ha=je(ia>>>((8-ka|0)>>>0)|ja<<ka|0)|0;ea=c[ya>>2]|0;y=ha;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;c[ya>>2]=(c[ya>>2]|0)+4;za=ka+24|0;Aa=ia}c[l>>2]=Aa;c[v>>2]=za;ia=ga+1|0;if((ia|0)<64){ga=ia;ja=Aa;ka=za}else{break}}if(!la){ma=za;na=Aa;break}if((za|0)>4){Ba=za-4|0;Ca=Aa<<4}else{ka=je(Aa<<za|0)|0;ja=c[ya>>2]|0;y=ka;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;c[ya>>2]=(c[ya>>2]|0)+4;Ba=za+28|0;Ca=0}c[l>>2]=Ca;c[v>>2]=Ba;if((Ba|0)>4){Da=Ba-4|0;Ea=Ca<<4|1}else{ja=je(1>>>((4-Ba|0)>>>0)|Ca<<Ba|0)|0;ka=c[ya>>2]|0;y=ja;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;c[ya>>2]=(c[ya>>2]|0)+4;Da=Ba+28|0;Ea=1}c[l>>2]=Ea;c[v>>2]=Da;ka=0;ja=Ea;ga=Da;while(1){ia=e[j+((d[g+4+ka|0]|0)<<1)>>1]|0;if((ga|0)>8){Fa=ga-8|0;Ga=ia|ja<<8}else{ea=je(ia>>>((8-ga|0)>>>0)|ja<<ga|0)|0;ha=c[ya>>2]|0;y=ea;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;c[ya>>2]=(c[ya>>2]|0)+4;Fa=ga+24|0;Ga=ia}c[l>>2]=Ga;c[v>>2]=Fa;ia=ka+1|0;if((ia|0)<64){ka=ia;ja=Ga;ga=Fa}else{ma=Fa;na=Ga;break}}}}while(0);if((c[b+816>>2]&2|0)==0){Ha=na;Ia=ma}else{if((ma|0)>8){Ja=ma-8|0;Ka=na<<8|255}else{Ga=je(na<<ma|255>>>((8-ma|0)>>>0)|0)|0;na=f+12|0;Fa=c[na>>2]|0;y=Ga;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;c[na>>2]=(c[na>>2]|0)+4;Ja=ma+24|0;Ka=255}c[l>>2]=Ka;c[v>>2]=Ja;if((Ja|0)>8){La=Ja-8|0;Ma=Ka<<8|221}else{ma=je(221>>>((8-Ja|0)>>>0)|Ka<<Ja|0)|0;Ka=f+12|0;na=c[Ka>>2]|0;y=ma;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[Ka>>2]=(c[Ka>>2]|0)+4;La=Ja+24|0;Ma=221}c[l>>2]=Ma;c[v>>2]=La;if((La|0)>16){Na=La-16|0;Oa=Ma<<16|4}else{Ja=je(4>>>((16-La|0)>>>0)|Ma<<La|0)|0;Ma=f+12|0;Ka=c[Ma>>2]|0;y=Ja;a[Ka]=y;y=y>>8;a[Ka+1|0]=y;y=y>>8;a[Ka+2|0]=y;y=y>>8;a[Ka+3|0]=y;c[Ma>>2]=(c[Ma>>2]|0)+4;Na=La+16|0;Oa=4}c[l>>2]=Oa;c[v>>2]=Na;La=(((c[b+120>>2]|0)-1|0)/(A<<3|0)|0)+1|0;if((Na|0)>16){Pa=Na-16|0;Qa=La|Oa<<16}else{Ma=je(La>>>((16-Na|0)>>>0)|Oa<<Na|0)|0;Oa=f+12|0;Ka=c[Oa>>2]|0;y=Ma;a[Ka]=y;y=y>>8;a[Ka+1|0]=y;y=y>>8;a[Ka+2|0]=y;y=y>>8;a[Ka+3|0]=y;c[Oa>>2]=(c[Oa>>2]|0)+4;Pa=Na+16|0;Qa=La}c[l>>2]=Qa;c[v>>2]=Pa;Ha=Qa;Ia=Pa}if((Ia|0)>8){Ra=Ia-8|0;Sa=Ha<<8|255}else{Pa=je(255>>>((8-Ia|0)>>>0)|Ha<<Ia|0)|0;Ha=f+12|0;Qa=c[Ha>>2]|0;y=Pa;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;c[Ha>>2]=(c[Ha>>2]|0)+4;Ra=Ia+24|0;Sa=255}c[l>>2]=Sa;c[v>>2]=Ra;if((Ra|0)>8){Ta=Ra-8|0;Ua=Sa<<8|196}else{Ia=je(196>>>((8-Ra|0)>>>0)|Sa<<Ra|0)|0;Sa=f+12|0;Ha=c[Sa>>2]|0;y=Ia;a[Ha]=y;y=y>>8;a[Ha+1|0]=y;y=y>>8;a[Ha+2|0]=y;y=y>>8;a[Ha+3|0]=y;c[Sa>>2]=(c[Sa>>2]|0)+4;Ta=Ra+24|0;Ua=196}c[l>>2]=Ua;c[v>>2]=Ta;c:do{if((Ta|0)<32){Ra=Ua<<Ta;c[l>>2]=Ra;Sa=f+12|0;Ha=Ra>>>24&255;while(1){Ra=c[Sa>>2]|0;c[Sa>>2]=Ra+1;a[Ra]=Ha;Ra=c[l>>2]|0;c[l>>2]=Ra<<8;Ia=(c[v>>2]|0)+8|0;c[v>>2]=Ia;if((Ia|0)>=32){Va=Sa;break c}Ha=Ra>>>16&255}}else{Va=f+12|0}}while(0);c[v>>2]=32;Ta=c[Va>>2]|0;c[l>>2]=0;c[v>>2]=8;Ua=0;Ha=1;Sa=0;Ra=8;Ia=Ta;while(1){Qa=d[1965720+Ha|0]|0;Wa=Qa+Ua|0;if((Ra|0)>8){Xa=Ra-8|0;Ya=Qa|Sa<<8;Za=Ia}else{Pa=Ia;y=je(Qa>>>((8-Ra|0)>>>0)|Sa<<Ra|0)|0;a[Pa]=y;y=y>>8;a[Pa+1|0]=y;y=y>>8;a[Pa+2|0]=y;y=y>>8;a[Pa+3|0]=y;Pa=(c[Va>>2]|0)+4|0;c[Va>>2]=Pa;Xa=Ra+24|0;Ya=Qa;Za=Pa}c[l>>2]=Ya;c[v>>2]=Xa;Pa=Ha+1|0;if((Pa|0)<17){Ua=Wa;Ha=Pa;Sa=Ya;Ra=Xa;Ia=Za}else{break}}if((Wa|0)>0){Ia=0;Ra=Xa;Sa=Za;Ha=Ya;while(1){Ua=d[1965368+Ia|0]|0;if((Ra|0)>8){_a=Ra-8|0;$a=Ua|Ha<<8;ab=Sa}else{Pa=Sa;y=je(Ua>>>((8-Ra|0)>>>0)|Ha<<Ra|0)|0;a[Pa]=y;y=y>>8;a[Pa+1|0]=y;y=y>>8;a[Pa+2|0]=y;y=y>>8;a[Pa+3|0]=y;Pa=(c[Va>>2]|0)+4|0;c[Va>>2]=Pa;_a=Ra+24|0;$a=Ua;ab=Pa}c[l>>2]=$a;c[v>>2]=_a;Pa=Ia+1|0;if((Pa|0)<(Wa|0)){Ia=Pa;Ra=_a;Sa=ab;Ha=$a}else{bb=_a;cb=$a;db=ab;break}}}else{bb=Xa;cb=Ya;db=Za}if((bb|0)>4){eb=bb-4|0;fb=cb<<4;gb=db}else{Za=db;y=je(cb<<bb|0)|0;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;Za=(c[Va>>2]|0)+4|0;c[Va>>2]=Za;eb=bb+28|0;fb=0;gb=Za}c[l>>2]=fb;c[v>>2]=eb;if((eb|0)>4){hb=eb-4|0;ib=fb<<4|1;jb=gb}else{Za=gb;y=je(1>>>((4-eb|0)>>>0)|fb<<eb|0)|0;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;Za=(c[Va>>2]|0)+4|0;c[Va>>2]=Za;hb=eb+28|0;ib=1;jb=Za}c[l>>2]=ib;c[v>>2]=hb;Za=0;eb=1;fb=ib;ib=hb;hb=jb;while(1){jb=d[1965744+eb|0]|0;kb=jb+Za|0;if((ib|0)>8){lb=ib-8|0;mb=jb|fb<<8;nb=hb}else{gb=hb;y=je(jb>>>((8-ib|0)>>>0)|fb<<ib|0)|0;a[gb]=y;y=y>>8;a[gb+1|0]=y;y=y>>8;a[gb+2|0]=y;y=y>>8;a[gb+3|0]=y;gb=(c[Va>>2]|0)+4|0;c[Va>>2]=gb;lb=ib+24|0;mb=jb;nb=gb}c[l>>2]=mb;c[v>>2]=lb;gb=eb+1|0;if((gb|0)<17){Za=kb;eb=gb;fb=mb;ib=lb;hb=nb}else{break}}if((kb|0)>0){hb=0;ib=lb;fb=nb;eb=mb;while(1){Za=d[1965368+hb|0]|0;if((ib|0)>8){ob=ib-8|0;pb=Za|eb<<8;qb=fb}else{gb=fb;y=je(Za>>>((8-ib|0)>>>0)|eb<<ib|0)|0;a[gb]=y;y=y>>8;a[gb+1|0]=y;y=y>>8;a[gb+2|0]=y;y=y>>8;a[gb+3|0]=y;gb=(c[Va>>2]|0)+4|0;c[Va>>2]=gb;ob=ib+24|0;pb=Za;qb=gb}c[l>>2]=pb;c[v>>2]=ob;gb=hb+1|0;if((gb|0)<(kb|0)){hb=gb;ib=ob;fb=qb;eb=pb}else{rb=ob;sb=pb;tb=qb;break}}}else{rb=lb;sb=mb;tb=nb}if((rb|0)>4){ub=rb-4|0;vb=sb<<4|1;wb=tb}else{nb=tb;y=je(1>>>((4-rb|0)>>>0)|sb<<rb|0)|0;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=(c[Va>>2]|0)+4|0;c[Va>>2]=nb;ub=rb+28|0;vb=1;wb=nb}c[l>>2]=vb;c[v>>2]=ub;if((ub|0)>4){xb=ub-4|0;yb=vb<<4;zb=wb}else{nb=wb;y=je(vb<<ub|0)|0;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=(c[Va>>2]|0)+4|0;c[Va>>2]=nb;xb=ub+28|0;yb=0;zb=nb}c[l>>2]=yb;c[v>>2]=xb;nb=0;ub=1;vb=yb;yb=xb;xb=zb;while(1){zb=d[1965768+ub|0]|0;Ab=zb+nb|0;if((yb|0)>8){Bb=yb-8|0;Cb=zb|vb<<8;Db=xb}else{wb=xb;y=je(zb>>>((8-yb|0)>>>0)|vb<<yb|0)|0;a[wb]=y;y=y>>8;a[wb+1|0]=y;y=y>>8;a[wb+2|0]=y;y=y>>8;a[wb+3|0]=y;wb=(c[Va>>2]|0)+4|0;c[Va>>2]=wb;Bb=yb+24|0;Cb=zb;Db=wb}c[l>>2]=Cb;c[v>>2]=Bb;wb=ub+1|0;if((wb|0)<17){nb=Ab;ub=wb;vb=Cb;yb=Bb;xb=Db}else{break}}if((Ab|0)>0){xb=0;yb=Bb;vb=Db;ub=Cb;while(1){nb=d[1965384+xb|0]|0;if((yb|0)>8){Eb=yb-8|0;Fb=nb|ub<<8;Gb=vb}else{wb=vb;y=je(nb>>>((8-yb|0)>>>0)|ub<<yb|0)|0;a[wb]=y;y=y>>8;a[wb+1|0]=y;y=y>>8;a[wb+2|0]=y;y=y>>8;a[wb+3|0]=y;wb=(c[Va>>2]|0)+4|0;c[Va>>2]=wb;Eb=yb+24|0;Fb=nb;Gb=wb}c[l>>2]=Fb;c[v>>2]=Eb;wb=xb+1|0;if((wb|0)<(Ab|0)){xb=wb;yb=Eb;vb=Gb;ub=Fb}else{Hb=Eb;Ib=Fb;Jb=Gb;break}}}else{Hb=Bb;Ib=Cb;Jb=Db}if((Hb|0)>4){Kb=Hb-4|0;Lb=Ib<<4|1;Mb=Jb}else{Db=Jb;y=je(1>>>((4-Hb|0)>>>0)|Ib<<Hb|0)|0;a[Db]=y;y=y>>8;a[Db+1|0]=y;y=y>>8;a[Db+2|0]=y;y=y>>8;a[Db+3|0]=y;Db=(c[Va>>2]|0)+4|0;c[Va>>2]=Db;Kb=Hb+28|0;Lb=1;Mb=Db}c[l>>2]=Lb;c[v>>2]=Kb;if((Kb|0)>4){Nb=Kb-4|0;Ob=Lb<<4|1;Pb=Mb}else{Db=Mb;y=je(1>>>((4-Kb|0)>>>0)|Lb<<Kb|0)|0;a[Db]=y;y=y>>8;a[Db+1|0]=y;y=y>>8;a[Db+2|0]=y;y=y>>8;a[Db+3|0]=y;Db=(c[Va>>2]|0)+4|0;c[Va>>2]=Db;Nb=Kb+28|0;Ob=1;Pb=Db}c[l>>2]=Ob;c[v>>2]=Nb;Db=0;Kb=1;Lb=Ob;Ob=Nb;Nb=Pb;while(1){Pb=d[1965792+Kb|0]|0;Qb=Pb+Db|0;if((Ob|0)>8){Rb=Ob-8|0;Sb=Pb|Lb<<8;Tb=Nb}else{Mb=Nb;y=je(Pb>>>((8-Ob|0)>>>0)|Lb<<Ob|0)|0;a[Mb]=y;y=y>>8;a[Mb+1|0]=y;y=y>>8;a[Mb+2|0]=y;y=y>>8;a[Mb+3|0]=y;Mb=(c[Va>>2]|0)+4|0;c[Va>>2]=Mb;Rb=Ob+24|0;Sb=Pb;Tb=Mb}c[l>>2]=Sb;c[v>>2]=Rb;Mb=Kb+1|0;if((Mb|0)<17){Db=Qb;Kb=Mb;Lb=Sb;Ob=Rb;Nb=Tb}else{break}}if((Qb|0)>0){Nb=0;Ob=Rb;Rb=Sb;Sb=Tb;while(1){Tb=d[1965552+Nb|0]|0;if((Ob|0)>8){Ub=Ob-8|0;Vb=Tb|Rb<<8;Wb=Sb}else{Lb=Sb;y=je(Tb>>>((8-Ob|0)>>>0)|Rb<<Ob|0)|0;a[Lb]=y;y=y>>8;a[Lb+1|0]=y;y=y>>8;a[Lb+2|0]=y;y=y>>8;a[Lb+3|0]=y;Lb=(c[Va>>2]|0)+4|0;c[Va>>2]=Lb;Ub=Ob+24|0;Vb=Tb;Wb=Lb}c[l>>2]=Vb;c[v>>2]=Ub;Lb=Nb+1|0;if((Lb|0)<(Qb|0)){Nb=Lb;Ob=Ub;Rb=Vb;Sb=Wb}else{break}}}Wb=Ta;y=he(Wa+70+kb+Ab+Qb&65535|0)|0;a[Wb]=y;y=y>>8;a[Wb+1|0]=y;Wb=c[n>>2]|0;do{if((Wb|0)==10){Qb=c[l>>2]|0;Ab=c[v>>2]|0;if((Ab|0)>8){Xb=Ab-8|0;Yb=Qb<<8|255}else{kb=je(255>>>((8-Ab|0)>>>0)|Qb<<Ab|0)|0;Qb=f+12|0;Wa=c[Qb>>2]|0;y=kb;a[Wa]=y;y=y>>8;a[Wa+1|0]=y;y=y>>8;a[Wa+2|0]=y;y=y>>8;a[Wa+3|0]=y;c[Qb>>2]=(c[Qb>>2]|0)+4;Xb=Ab+24|0;Yb=255}c[l>>2]=Yb;c[v>>2]=Xb;if((Xb|0)>8){Zb=Xb-8|0;_b=Yb<<8|195;break}else{Ab=je(195>>>((8-Xb|0)>>>0)|Yb<<Xb|0)|0;Qb=f+12|0;Wa=c[Qb>>2]|0;y=Ab;a[Wa]=y;y=y>>8;a[Wa+1|0]=y;y=y>>8;a[Wa+2|0]=y;y=y>>8;a[Wa+3|0]=y;c[Qb>>2]=(c[Qb>>2]|0)+4;Zb=Xb+24|0;_b=195;break}}else if((Wb|0)==8){Qb=c[l>>2]|0;Wa=c[v>>2]|0;if((Wa|0)>8){$b=Wa-8|0;ac=Qb<<8|255}else{Ab=je(255>>>((8-Wa|0)>>>0)|Qb<<Wa|0)|0;Qb=f+12|0;kb=c[Qb>>2]|0;y=Ab;a[kb]=y;y=y>>8;a[kb+1|0]=y;y=y>>8;a[kb+2|0]=y;y=y>>8;a[kb+3|0]=y;c[Qb>>2]=(c[Qb>>2]|0)+4;$b=Wa+24|0;ac=255}c[l>>2]=ac;c[v>>2]=$b;if(($b|0)>8){Zb=$b-8|0;_b=ac<<8|192;break}else{Wa=je(192>>>((8-$b|0)>>>0)|ac<<$b|0)|0;Qb=f+12|0;kb=c[Qb>>2]|0;y=Wa;a[kb]=y;y=y>>8;a[kb+1|0]=y;y=y>>8;a[kb+2|0]=y;y=y>>8;a[kb+3|0]=y;c[Qb>>2]=(c[Qb>>2]|0)+4;Zb=$b+24|0;_b=192;break}}else{KIb(0,0,2601480,(bc=i,i=i+24|0,c[bc>>2]=2450416,c[bc+8>>2]=2361128,c[bc+16>>2]=255,bc)|0);i=bc;Hd()}}while(0);c[l>>2]=_b;c[v>>2]=Zb;if((Zb|0)>16){cc=Zb-16|0;dc=_b<<16|17}else{$b=je(17>>>((16-Zb|0)>>>0)|_b<<Zb|0)|0;_b=f+12|0;ac=c[_b>>2]|0;y=$b;a[ac]=y;y=y>>8;a[ac+1|0]=y;y=y>>8;a[ac+2|0]=y;y=y>>8;a[ac+3|0]=y;c[_b>>2]=(c[_b>>2]|0)+4;cc=Zb+16|0;dc=17}c[l>>2]=dc;c[v>>2]=cc;do{if((o|0)==108|(o|0)==8){w=208}else{Zb=c[t>>2]|0;if(!((Zb|0)==298|(Zb|0)==30|(Zb|0)==3)){w=208;break}if((cc|0)>8){ec=cc-8|0;fc=dc<<8|9;break}else{Zb=je(9>>>((8-cc|0)>>>0)|dc<<cc|0)|0;_b=f+12|0;ac=c[_b>>2]|0;y=Zb;a[ac]=y;y=y>>8;a[ac+1|0]=y;y=y>>8;a[ac+2|0]=y;y=y>>8;a[ac+3|0]=y;c[_b>>2]=(c[_b>>2]|0)+4;ec=cc+24|0;fc=9;break}}}while(0);do{if((w|0)==208){if((cc|0)>8){ec=cc-8|0;fc=dc<<8|8;break}else{t=je(8>>>((8-cc|0)>>>0)|dc<<cc|0)|0;_b=f+12|0;ac=c[_b>>2]|0;y=t;a[ac]=y;y=y>>8;a[ac+1|0]=y;y=y>>8;a[ac+2|0]=y;y=y>>8;a[ac+3|0]=y;c[_b>>2]=(c[_b>>2]|0)+4;ec=cc+24|0;fc=8;break}}}while(0);c[l>>2]=fc;c[v>>2]=ec;cc=c[b+124>>2]|0;if((ec|0)>16){gc=ec-16|0;hc=fc<<16|cc}else{dc=je(fc<<ec|cc>>>((16-ec|0)>>>0)|0)|0;fc=f+12|0;w=c[fc>>2]|0;y=dc;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[fc>>2]=(c[fc>>2]|0)+4;gc=ec+16|0;hc=cc}c[l>>2]=hc;c[v>>2]=gc;cc=c[b+120>>2]|0;if((gc|0)>16){ic=gc-16|0;jc=hc<<16|cc}else{ec=je(hc<<gc|cc>>>((16-gc|0)>>>0)|0)|0;hc=f+12|0;fc=c[hc>>2]|0;y=ec;a[fc]=y;y=y>>8;a[fc+1|0]=y;y=y>>8;a[fc+2|0]=y;y=y>>8;a[fc+3|0]=y;c[hc>>2]=(c[hc>>2]|0)+4;ic=gc+16|0;jc=cc}c[l>>2]=jc;c[v>>2]=ic;if((ic|0)>8){kc=ic-8|0;lc=jc<<8|3}else{cc=je(3>>>((8-ic|0)>>>0)|jc<<ic|0)|0;jc=f+12|0;gc=c[jc>>2]|0;y=cc;a[gc]=y;y=y>>8;a[gc+1|0]=y;y=y>>8;a[gc+2|0]=y;y=y>>8;a[gc+3|0]=y;c[jc>>2]=(c[jc>>2]|0)+4;kc=ic+24|0;lc=3}c[l>>2]=lc;c[v>>2]=kc;if((kc|0)>8){mc=kc-8|0;nc=lc<<8|1}else{ic=je(1>>>((8-kc|0)>>>0)|lc<<kc|0)|0;lc=f+12|0;jc=c[lc>>2]|0;y=ic;a[jc]=y;y=y>>8;a[jc+1|0]=y;y=y>>8;a[jc+2|0]=y;y=y>>8;a[jc+3|0]=y;c[lc>>2]=(c[lc>>2]|0)+4;mc=kc+24|0;nc=1}c[l>>2]=nc;c[v>>2]=mc;if((mc|0)>4){oc=mc-4|0;pc=nc<<4|A}else{kc=je(A>>>((4-mc|0)>>>0)|nc<<mc|0)|0;nc=f+12|0;lc=c[nc>>2]|0;y=kc;a[lc]=y;y=y>>8;a[lc+1|0]=y;y=y>>8;a[lc+2|0]=y;y=y>>8;a[lc+3|0]=y;c[nc>>2]=(c[nc>>2]|0)+4;oc=mc+28|0;pc=A}c[l>>2]=pc;c[v>>2]=oc;if((oc|0)>4){qc=oc-4|0;rc=pc<<4|x}else{A=je(x>>>((4-oc|0)>>>0)|pc<<oc|0)|0;pc=f+12|0;mc=c[pc>>2]|0;y=A;a[mc]=y;y=y>>8;a[mc+1|0]=y;y=y>>8;a[mc+2|0]=y;y=y>>8;a[mc+3|0]=y;c[pc>>2]=(c[pc>>2]|0)+4;qc=oc+28|0;rc=x}c[l>>2]=rc;c[v>>2]=qc;if((qc|0)>8){sc=qc-8|0;tc=rc<<8}else{x=je(rc<<qc|0)|0;rc=f+12|0;oc=c[rc>>2]|0;y=x;a[oc]=y;y=y>>8;a[oc+1|0]=y;y=y>>8;a[oc+2|0]=y;y=y>>8;a[oc+3|0]=y;c[rc>>2]=(c[rc>>2]|0)+4;sc=qc+24|0;tc=0}c[l>>2]=tc;c[v>>2]=sc;if((sc|0)>8){uc=sc-8|0;vc=tc<<8|2}else{qc=je(2>>>((8-sc|0)>>>0)|tc<<sc|0)|0;tc=f+12|0;rc=c[tc>>2]|0;y=qc;a[rc]=y;y=y>>8;a[rc+1|0]=y;y=y>>8;a[rc+2|0]=y;y=y>>8;a[rc+3|0]=y;c[tc>>2]=(c[tc>>2]|0)+4;uc=sc+24|0;vc=2}c[l>>2]=vc;c[v>>2]=uc;if((uc|0)>4){wc=uc-4|0;xc=vc<<4|B}else{sc=je(B>>>((4-uc|0)>>>0)|vc<<uc|0)|0;vc=f+12|0;tc=c[vc>>2]|0;y=sc;a[tc]=y;y=y>>8;a[tc+1|0]=y;y=y>>8;a[tc+2|0]=y;y=y>>8;a[tc+3|0]=y;c[vc>>2]=(c[vc>>2]|0)+4;wc=uc+28|0;xc=B}c[l>>2]=xc;c[v>>2]=wc;if((wc|0)>4){yc=wc-4|0;zc=xc<<4|z}else{uc=je(z>>>((4-wc|0)>>>0)|xc<<wc|0)|0;xc=f+12|0;vc=c[xc>>2]|0;y=uc;a[vc]=y;y=y>>8;a[vc+1|0]=y;y=y>>8;a[vc+2|0]=y;y=y>>8;a[vc+3|0]=y;c[xc>>2]=(c[xc>>2]|0)+4;yc=wc+28|0;zc=z}c[l>>2]=zc;c[v>>2]=yc;wc=p?0:s;if((yc|0)>8){Ac=yc-8|0;Bc=zc<<8|wc}else{s=je(wc>>>((8-yc|0)>>>0)|zc<<yc|0)|0;zc=f+12|0;xc=c[zc>>2]|0;y=s;a[xc]=y;y=y>>8;a[xc+1|0]=y;y=y>>8;a[xc+2|0]=y;y=y>>8;a[xc+3|0]=y;c[zc>>2]=(c[zc>>2]|0)+4;Ac=yc+24|0;Bc=wc}c[l>>2]=Bc;c[v>>2]=Ac;if((Ac|0)>8){Cc=Ac-8|0;Dc=Bc<<8|3}else{yc=je(3>>>((8-Ac|0)>>>0)|Bc<<Ac|0)|0;Bc=f+12|0;zc=c[Bc>>2]|0;y=yc;a[zc]=y;y=y>>8;a[zc+1|0]=y;y=y>>8;a[zc+2|0]=y;y=y>>8;a[zc+3|0]=y;c[Bc>>2]=(c[Bc>>2]|0)+4;Cc=Ac+24|0;Dc=3}c[l>>2]=Dc;c[v>>2]=Cc;if((Cc|0)>4){Ec=Cc-4|0;Fc=Dc<<4|B}else{Ac=je(B>>>((4-Cc|0)>>>0)|Dc<<Cc|0)|0;Dc=f+12|0;Bc=c[Dc>>2]|0;y=Ac;a[Bc]=y;y=y>>8;a[Bc+1|0]=y;y=y>>8;a[Bc+2|0]=y;y=y>>8;a[Bc+3|0]=y;c[Dc>>2]=(c[Dc>>2]|0)+4;Ec=Cc+28|0;Fc=B}c[l>>2]=Fc;c[v>>2]=Ec;if((Ec|0)>4){Gc=Ec-4|0;Hc=Fc<<4|z}else{B=je(z>>>((4-Ec|0)>>>0)|Fc<<Ec|0)|0;Fc=f+12|0;Cc=c[Fc>>2]|0;y=B;a[Cc]=y;y=y>>8;a[Cc+1|0]=y;y=y>>8;a[Cc+2|0]=y;y=y>>8;a[Cc+3|0]=y;c[Fc>>2]=(c[Fc>>2]|0)+4;Gc=Ec+28|0;Hc=z}c[l>>2]=Hc;c[v>>2]=Gc;if((Gc|0)>8){Ic=Gc-8|0;Jc=Hc<<8|wc}else{z=je(wc>>>((8-Gc|0)>>>0)|Hc<<Gc|0)|0;Hc=f+12|0;Ec=c[Hc>>2]|0;y=z;a[Ec]=y;y=y>>8;a[Ec+1|0]=y;y=y>>8;a[Ec+2|0]=y;y=y>>8;a[Ec+3|0]=y;c[Hc>>2]=(c[Hc>>2]|0)+4;Ic=Gc+24|0;Jc=wc}c[l>>2]=Jc;c[v>>2]=Ic;if((Ic|0)>8){Kc=Ic-8|0;Lc=Jc<<8|255}else{wc=je(255>>>((8-Ic|0)>>>0)|Jc<<Ic|0)|0;Jc=f+12|0;Gc=c[Jc>>2]|0;y=wc;a[Gc]=y;y=y>>8;a[Gc+1|0]=y;y=y>>8;a[Gc+2|0]=y;y=y>>8;a[Gc+3|0]=y;c[Jc>>2]=(c[Jc>>2]|0)+4;Kc=Ic+24|0;Lc=255}c[l>>2]=Lc;c[v>>2]=Kc;if((Kc|0)>8){Mc=Kc-8|0;Nc=Lc<<8|218}else{Ic=je(218>>>((8-Kc|0)>>>0)|Lc<<Kc|0)|0;Lc=f+12|0;Jc=c[Lc>>2]|0;y=Ic;a[Jc]=y;y=y>>8;a[Jc+1|0]=y;y=y>>8;a[Jc+2|0]=y;y=y>>8;a[Jc+3|0]=y;c[Lc>>2]=(c[Lc>>2]|0)+4;Mc=Kc+24|0;Nc=218}c[l>>2]=Nc;c[v>>2]=Mc;if((Mc|0)>16){Oc=Mc-16|0;Pc=Nc<<16|12}else{Kc=je(12>>>((16-Mc|0)>>>0)|Nc<<Mc|0)|0;Nc=f+12|0;Lc=c[Nc>>2]|0;y=Kc;a[Lc]=y;y=y>>8;a[Lc+1|0]=y;y=y>>8;a[Lc+2|0]=y;y=y>>8;a[Lc+3|0]=y;c[Nc>>2]=(c[Nc>>2]|0)+4;Oc=Mc+16|0;Pc=12}c[l>>2]=Pc;c[v>>2]=Oc;if((Oc|0)>8){Qc=Oc-8|0;Rc=Pc<<8|3}else{Mc=je(3>>>((8-Oc|0)>>>0)|Pc<<Oc|0)|0;Pc=f+12|0;Nc=c[Pc>>2]|0;y=Mc;a[Nc]=y;y=y>>8;a[Nc+1|0]=y;y=y>>8;a[Nc+2|0]=y;y=y>>8;a[Nc+3|0]=y;c[Pc>>2]=(c[Pc>>2]|0)+4;Qc=Oc+24|0;Rc=3}c[l>>2]=Rc;c[v>>2]=Qc;if((Qc|0)>8){Sc=Qc-8|0;Tc=Rc<<8|1}else{Oc=je(1>>>((8-Qc|0)>>>0)|Rc<<Qc|0)|0;Rc=f+12|0;Pc=c[Rc>>2]|0;y=Oc;a[Pc]=y;y=y>>8;a[Pc+1|0]=y;y=y>>8;a[Pc+2|0]=y;y=y>>8;a[Pc+3|0]=y;c[Rc>>2]=(c[Rc>>2]|0)+4;Sc=Qc+24|0;Tc=1}c[l>>2]=Tc;c[v>>2]=Sc;if((Sc|0)>4){Uc=Sc-4|0;Vc=Tc<<4}else{Qc=je(Tc<<Sc|0)|0;Tc=f+12|0;Rc=c[Tc>>2]|0;y=Qc;a[Rc]=y;y=y>>8;a[Rc+1|0]=y;y=y>>8;a[Rc+2|0]=y;y=y>>8;a[Rc+3|0]=y;c[Tc>>2]=(c[Tc>>2]|0)+4;Uc=Sc+28|0;Vc=0}c[l>>2]=Vc;c[v>>2]=Uc;if((Uc|0)>4){Wc=Uc-4|0;Xc=Vc<<4}else{Sc=je(Vc<<Uc|0)|0;Vc=f+12|0;Tc=c[Vc>>2]|0;y=Sc;a[Tc]=y;y=y>>8;a[Tc+1|0]=y;y=y>>8;a[Tc+2|0]=y;y=y>>8;a[Tc+3|0]=y;c[Vc>>2]=(c[Vc>>2]|0)+4;Wc=Uc+28|0;Xc=0}c[l>>2]=Xc;c[v>>2]=Wc;if((Wc|0)>8){Yc=Wc-8|0;Zc=Xc<<8|2}else{Uc=je(2>>>((8-Wc|0)>>>0)|Xc<<Wc|0)|0;Xc=f+12|0;Vc=c[Xc>>2]|0;y=Uc;a[Vc]=y;y=y>>8;a[Vc+1|0]=y;y=y>>8;a[Vc+2|0]=y;y=y>>8;a[Vc+3|0]=y;c[Xc>>2]=(c[Xc>>2]|0)+4;Yc=Wc+24|0;Zc=2}c[l>>2]=Zc;c[v>>2]=Yc;if((Yc|0)>4){_c=Yc-4|0;$c=Zc<<4|1}else{Wc=je(1>>>((4-Yc|0)>>>0)|Zc<<Yc|0)|0;Zc=f+12|0;Xc=c[Zc>>2]|0;y=Wc;a[Xc]=y;y=y>>8;a[Xc+1|0]=y;y=y>>8;a[Xc+2|0]=y;y=y>>8;a[Xc+3|0]=y;c[Zc>>2]=(c[Zc>>2]|0)+4;_c=Yc+28|0;$c=1}c[l>>2]=$c;c[v>>2]=_c;Yc=p&1^1;if((_c|0)>4){ad=_c-4|0;bd=$c<<4|Yc}else{p=je(Yc>>>((4-_c|0)>>>0)|$c<<_c|0)|0;$c=f+12|0;Zc=c[$c>>2]|0;y=p;a[Zc]=y;y=y>>8;a[Zc+1|0]=y;y=y>>8;a[Zc+2|0]=y;y=y>>8;a[Zc+3|0]=y;c[$c>>2]=(c[$c>>2]|0)+4;ad=_c+28|0;bd=Yc}c[l>>2]=bd;c[v>>2]=ad;if((ad|0)>8){cd=ad-8|0;dd=bd<<8|3}else{_c=je(3>>>((8-ad|0)>>>0)|bd<<ad|0)|0;bd=f+12|0;$c=c[bd>>2]|0;y=_c;a[$c]=y;y=y>>8;a[$c+1|0]=y;y=y>>8;a[$c+2|0]=y;y=y>>8;a[$c+3|0]=y;c[bd>>2]=(c[bd>>2]|0)+4;cd=ad+24|0;dd=3}c[l>>2]=dd;c[v>>2]=cd;if((cd|0)>4){ed=cd-4|0;fd=dd<<4|1}else{ad=je(1>>>((4-cd|0)>>>0)|dd<<cd|0)|0;dd=f+12|0;bd=c[dd>>2]|0;y=ad;a[bd]=y;y=y>>8;a[bd+1|0]=y;y=y>>8;a[bd+2|0]=y;y=y>>8;a[bd+3|0]=y;c[dd>>2]=(c[dd>>2]|0)+4;ed=cd+28|0;fd=1}c[l>>2]=fd;c[v>>2]=ed;if((ed|0)>4){gd=ed-4|0;hd=fd<<4|Yc}else{cd=je(Yc>>>((4-ed|0)>>>0)|fd<<ed|0)|0;fd=f+12|0;dd=c[fd>>2]|0;y=cd;a[dd]=y;y=y>>8;a[dd+1|0]=y;y=y>>8;a[dd+2|0]=y;y=y>>8;a[dd+3|0]=y;c[fd>>2]=(c[fd>>2]|0)+4;gd=ed+28|0;hd=Yc}c[l>>2]=hd;c[v>>2]=gd;if((o|0)==108|(o|0)==8){id=0}else{id=(c[b+216>>2]|0)+1|0}if((gd|0)>8){jd=gd-8|0;kd=hd<<8|id}else{Yc=je(hd<<gd|id>>>((8-gd|0)>>>0)|0)|0;hd=f+12|0;ed=c[hd>>2]|0;y=Yc;a[ed]=y;y=y>>8;a[ed+1|0]=y;y=y>>8;a[ed+2|0]=y;y=y>>8;a[ed+3|0]=y;c[hd>>2]=(c[hd>>2]|0)+4;jd=gd+24|0;kd=id}c[l>>2]=kd;c[v>>2]=jd;id=c[n>>2]|0;do{if((id|0)==8){if((jd|0)>8){ld=jd-8|0;md=kd<<8|63;break}else{n=je(kd<<jd|63>>>((8-jd|0)>>>0)|0)|0;gd=f+12|0;hd=c[gd>>2]|0;y=n;a[hd]=y;y=y>>8;a[hd+1|0]=y;y=y>>8;a[hd+2|0]=y;y=y>>8;a[hd+3|0]=y;c[gd>>2]=(c[gd>>2]|0)+4;ld=jd+24|0;md=63;break}}else if((id|0)==10){if((jd|0)>8){ld=jd-8|0;md=kd<<8;break}else{gd=je(kd<<jd|0)|0;hd=f+12|0;n=c[hd>>2]|0;y=gd;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[hd>>2]=(c[hd>>2]|0)+4;ld=jd+24|0;md=0;break}}else{KIb(0,0,2601480,(bc=i,i=i+24|0,c[bc>>2]=2450416,c[bc+8>>2]=2361128,c[bc+16>>2]=312,bc)|0);i=bc;Hd()}}while(0);c[l>>2]=md;c[v>>2]=ld;if((ld|0)>8){nd=ld-8|0;od=md<<8}else{jd=je(md<<ld|0)|0;md=f+12|0;kd=c[md>>2]|0;y=jd;a[kd]=y;y=y>>8;a[kd+1|0]=y;y=y>>8;a[kd+2|0]=y;y=y>>8;a[kd+3|0]=y;c[md>>2]=(c[md>>2]|0)+4;nd=ld+24|0;od=0}c[l>>2]=od;c[v>>2]=nd;J=nd}if(!((o|0)==108|(o|0)==8)){i=k;return}o=c[b+60>>2]|0;if((c[(c[u>>2]|0)+52>>2]|0)!=14672){KIb(0,0,2601480,(bc=i,i=i+24|0,c[bc>>2]=2296848,c[bc+8>>2]=2361128,c[bc+16>>2]=320,bc)|0);i=bc;Hd()}c[o+14056>>2]=32-J+((c[f+12>>2]|0)-(c[f+8>>2]|0)<<3)>>3;f=o+944|0;if((c[f>>2]|0)<=1){i=k;return}J=o+816|0;o=1;do{c[(c[J+(o<<2)>>2]|0)+14056>>2]=0;o=o+1|0;}while((o|0)<(c[f>>2]|0));i=k;return}function wQa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0;e=b+8|0;f=c[e>>2]|0;g=-(f+d|0)|0;h=g&3;i=b+4|0;j=c[i>>2]|0;k=b+12|0;l=j&7;if((l|0)==0){m=j;n=b|0}else{o=(1<<l)-1|0;p=b|0;b=c[p>>2]|0;if((j|0)>(l|0)){q=j-l|0;r=b<<l|o}else{s=je(o>>>((l-j|0)>>>0)|b<<j|0)|0;b=c[k>>2]|0;y=s;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;q=32-l+j|0;r=o}c[p>>2]=r;c[i>>2]=q;m=q;n=p}a:do{if((m|0)<32){p=c[n>>2]<<m;c[n>>2]=p;q=p>>>24&255;while(1){p=c[k>>2]|0;c[k>>2]=p+1;a[p]=q;p=c[n>>2]|0;c[n>>2]=p<<8;r=(c[i>>2]|0)+8|0;c[i>>2]=r;if((r|0)>=32){break a}q=p>>>16&255}}}while(0);c[i>>2]=32;c[n>>2]=0;m=c[k>>2]|0;q=32-(d<<3)-32+(m-(c[e>>2]|0)<<3)|0;e=q>>3;if((q|0)>0&(h|0)!=0){q=-e|0;p=g&3;g=p>>>0>1>>>0?-p|0:-1;p=g>>>0<q>>>0?q:g;g=0;q=0;do{g=((a[f+(q+d)|0]|0)==-1)+g|0;q=q+1|0;}while((q|0)<(e|0)&(q|0)<(h|0));t=g;u=-p|0}else{t=0;u=0}p=e-15|0;if((u|0)<(p|0)){g=d+4|0;h=d+8|0;q=d+12|0;r=u+(e-16-u&-16)|0;o=t;j=u;do{l=c[f+(j+d)>>2]|0;b=c[f+(g+j)>>2]|0;s=c[f+(h+j)>>2]|0;v=c[f+(q+j)>>2]|0;w=((b&252645135&b>>>4)+16843009&269488144)+((l&252645135&l>>>4)+16843009&269488144)+((s&252645135&s>>>4)+16843009&269488144)+((v&252645135&v>>>4)+16843009&269488144)|0;v=(w>>>4)+(w>>>20)|0;o=((v>>>8)+v&255)+o|0;j=j+16|0;}while((j|0)<(p|0));x=o;z=r+16|0}else{x=t;z=u}if((z|0)<(e|0)){u=x;t=z;while(1){z=((a[f+(t+d)|0]|0)==-1)+u|0;r=t+1|0;if((r|0)<(e|0)){u=z;t=r}else{A=z;break}}}else{A=x}if((A|0)==0){return}c[i>>2]=32;c[n>>2]=0;c[k>>2]=m+A;m=A;A=e;while(1){e=A-1|0;k=e+d|0;n=a[f+k|0]|0;if(n<<24>>24==-1){a[f+(m+d+e)|0]=0;B=m-1|0}else{B=m}a[f+(k+B)|0]=n;if((B|0)==0){break}else{m=B;A=e}}return}function xQa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b+784|0;e=(c[b+12480>>2]|0)-((c[b+12476>>2]|0)==0)|0;f=b+14056|0;wQa(d,c[f>>2]|0);do{if((c[(c[b+4>>2]|0)+816>>2]&2|0)!=0){if((e|0)>=(c[b+120>>2]|0)){break}g=e&7|208;h=d|0;i=c[h>>2]|0;j=b+788|0;k=c[j>>2]|0;if((k|0)>8){l=k-8|0;m=i<<8|255}else{n=je(255>>>((8-k|0)>>>0)|i<<k|0)|0;i=b+796|0;o=c[i>>2]|0;y=n;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=k+24|0;m=255}c[h>>2]=m;c[j>>2]=l;if((l|0)>8){p=l-8|0;q=m<<8|g}else{k=je(g>>>((8-l|0)>>>0)|m<<l|0)|0;i=b+796|0;o=c[i>>2]|0;y=k;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;p=l+24|0;q=g}c[h>>2]=q;c[j>>2]=p}}while(0);c[f>>2]=32-(c[b+788>>2]|0)+((c[b+796>>2]|0)-(c[b+792>>2]|0)<<3)>>3;f=128<<c[b+14176>>2];c[b+9860>>2]=f;c[b+9864>>2]=f;c[b+9868>>2]=f;return}function yQa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b|0;e=c[d>>2]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)>8){h=g-8|0;i=e<<8|255}else{j=je(255>>>((8-g|0)>>>0)|e<<g|0)|0;e=b+12|0;k=c[e>>2]|0;y=j;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[e>>2]=(c[e>>2]|0)+4;h=g+24|0;i=255}c[d>>2]=i;c[f>>2]=h;if((h|0)>8){l=h-8|0;m=i<<8|217;c[d>>2]=m;c[f>>2]=l;return}else{g=je(217>>>((8-h|0)>>>0)|i<<h|0)|0;i=b+12|0;b=c[i>>2]|0;y=g;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=h+24|0;m=217;c[d>>2]=m;c[f>>2]=l;return}}function zQa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((f|0)==0){i=d[g]|0;j=e[h>>1]|0;k=b|0;l=c[k>>2]|0;m=b+4|0;n=c[m>>2]|0;if((n|0)>(i|0)){o=n-i|0;p=l<<i|j}else{q=je(j>>>((i-n|0)>>>0)|l<<n|0)|0;l=b+12|0;r=c[l>>2]|0;y=q;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;o=32-i+n|0;p=j}c[k>>2]=p;c[m>>2]=o;return}if((f|0)<0){s=-f|0;t=f-1|0}else{s=f;t=f}f=(s&65280|0)==0;o=(f?0:8)+(d[1359664+(f?s:s>>>8)|0]|0)|0;s=o+1|0;f=d[g+s|0]|0;g=e[h+(s<<1)>>1]|0;h=b|0;m=c[h>>2]|0;p=b+4|0;k=c[p>>2]|0;if((k|0)>(f|0)){u=k-f|0;v=m<<f|g}else{j=je(g>>>((f-k|0)>>>0)|m<<k|0)|0;m=b+12|0;n=c[m>>2]|0;y=j;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;u=32-f+k|0;v=g}c[h>>2]=v;c[p>>2]=u;g=(1<<s)-1&t;if((u|0)>(s|0)){w=u-s|0;x=v<<s|g}else{t=je(g>>>((s-u|0)>>>0)|v<<u|0)|0;v=b+12|0;b=c[v>>2]|0;y=t;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;w=31-o+u|0;x=g}c[h>>2]=x;c[p>>2]=w;return}function AQa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+14212|0;e=(c[d>>2]|0)==3;BQa(a,b|0,0);do{if(e){BQa(a,b+256|0,2);BQa(a,b+512|0,4);BQa(a,b+1024|0,8);BQa(a,b+640|0,5);BQa(a,b+1152|0,9);if((c[a+12476>>2]<<4|8|0)>=(c[a+8>>2]|0)){break}BQa(a,b+128|0,1);BQa(a,b+384|0,3);BQa(a,b+768|0,6);BQa(a,b+1280|0,10);BQa(a,b+896|0,7);BQa(a,b+1408|0,11)}else{BQa(a,b+128|0,1);BQa(a,b+256|0,2);BQa(a,b+384|0,3);BQa(a,b+512|0,4);if((c[d>>2]|0)==1){BQa(a,b+640|0,5);break}else{BQa(a,b+768|0,6);BQa(a,b+640|0,5);BQa(a,b+896|0,7);break}}}while(0);b=((c[a+796>>2]|0)-(c[a+792>>2]|0)<<3)+(32-(c[a+788>>2]|0))|0;d=a+13700|0;e=c[d>>2]|0;c[d>>2]=b;d=a+13672|0;c[d>>2]=(c[d>>2]|0)-e+b;return}function BQa(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=c[f+14052>>2]|0;if((h|0)<4){j=b[g>>1]|0;k=f+9860|0;l=f+784|0;zQa(l,j-(c[k>>2]|0)|0,i|0,i+12|0);m=i+328|0;n=i+72|0;o=j;p=k;q=l}else{l=b[g>>1]|0;k=f+9860+((h&1)+1<<2)|0;j=f+784|0;zQa(j,l-(c[k>>2]|0)|0,i+36|0,i+48|0);m=i+1096|0;n=i+840|0;o=l;p=k;q=j}c[p>>2]=o;o=c[f+180+(h<<2)>>2]|0;do{if((o|0)>=1){h=q|0;p=q+4|0;j=q+12|0;k=n+240|0;l=m+480|0;i=0;r=1;while(1){s=b[g+(d[f+368+r|0]<<1)>>1]|0;t=s<<16>>16;if(s<<16>>16==0){u=i+1|0}else{if((i|0)>15){v=i;w=c[h>>2]|0;x=c[p>>2]|0;while(1){z=d[k]|0;A=e[l>>1]|0;if((x|0)>(z|0)){B=x-z|0;C=w<<z|A}else{D=je(A>>>((z-x|0)>>>0)|w<<x|0)|0;E=c[j>>2]|0;y=D;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;B=32-z+x|0;C=A}c[h>>2]=C;c[p>>2]=B;A=v-16|0;if((A|0)>15){v=A;w=C;x=B}else{break}}F=i&15}else{F=i}if(s<<16>>16<0){G=t-1|0;H=-t|0}else{G=t;H=t}x=(H&65280|0)==0;w=(d[1359664+(x?H:H>>>8)|0]|0)+(x?0:8)|0;x=w+1|0;v=x|F<<4;A=d[n+v|0]|0;z=e[m+(v<<1)>>1]|0;v=c[h>>2]|0;E=c[p>>2]|0;if((E|0)>(A|0)){I=E-A|0;J=v<<A|z}else{D=je(z>>>((A-E|0)>>>0)|v<<E|0)|0;v=c[j>>2]|0;y=D;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;I=32-A+E|0;J=z}c[h>>2]=J;c[p>>2]=I;z=(1<<x)-1&G;if((I|0)>(x|0)){K=I-x|0;L=J<<x|z}else{E=je(z>>>((x-I|0)>>>0)|J<<I|0)|0;x=c[j>>2]|0;y=E;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;K=31-w+I|0;L=z}c[h>>2]=L;c[p>>2]=K;u=0}z=r+1|0;if((z|0)>(o|0)){break}else{i=u;r=z}}if(!((o|0)>62&(u|0)==0)){break}return}}while(0);u=d[n]|0;n=e[m>>1]|0;m=q|0;o=c[m>>2]|0;K=q+4|0;L=c[K>>2]|0;if((L|0)>(u|0)){M=L-u|0;N=o<<u|n}else{I=je(n>>>((u-L|0)>>>0)|o<<L|0)|0;o=q+12|0;q=c[o>>2]|0;y=I;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;M=32-u+L|0;N=n}c[m>>2]=N;c[K>>2]=M;return}function CQa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+24|0;g=f|0;h=f+16|0;j=c[a+60>>2]|0;tKb(c[a+140>>2]|0,f+8|0,h)|0;if((c[(c[j+4>>2]|0)+88>>2]&16384|0)!=0){k=-22;i=f;return k|0}l=$Hb(d)|0;c[g>>2]=l;if((l|0)==0){k=-12;i=f;return k|0}d=j+120|0;m=j+12|0;j=ca(((c[d>>2]<<3)-(((c[m>>2]|0)/2|0)&7)<<1)-1|0,c[l+32>>2]|0)|0;n=l|0;c[n>>2]=(c[n>>2]|0)+j;j=c[g>>2]|0;n=j+32|0;c[n>>2]=-(c[n>>2]|0);n=ca((ca((c[d>>2]<<3)-(((c[m>>2]|0)/2|0)&7)|0,2>>>((c[h>>2]|0)>>>0))|0)-1|0,c[j+36>>2]|0)|0;l=j+4|0;c[l>>2]=(c[l>>2]|0)+n;n=c[g>>2]|0;l=n+36|0;c[l>>2]=-(c[l>>2]|0);l=ca((ca((c[d>>2]<<3)-(((c[m>>2]|0)/2|0)&7)|0,2>>>((c[h>>2]|0)>>>0))|0)-1|0,c[n+40>>2]|0)|0;h=n+8|0;c[h>>2]=(c[h>>2]|0)+l;l=c[g>>2]|0;h=l+40|0;c[h>>2]=-(c[h>>2]|0);h=dUa(a,b,l,e)|0;VHb(g);k=h;i=f;return k|0}function DQa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;if((c[e+12>>2]|0)<224){KIb(a,16,2510816,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1;i=f;return h|0}j=e|0;k=Uqb(c[j>>2]|0,26)|0;l=c[j>>2]|0;j=l+26|0;if(!(k<<16>>16==(d[j]|d[j+1|0]<<8)<<16>>16<<16>>16)){KIb(a,16,2601440,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=f;return h|0}g=e+8|0;a=c[g>>2]|0;j=e+16|0;e=c[j>>2]|0;k=l+(a>>>3)|0;m=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(a&7);k=a+24|0;a=e>>>0>k>>>0?k:e;c[g>>2]=a;if(!((m&-256|0)==-126718208)){h=-1094995529;i=f;return h|0}m=l+(a>>>3)|0;k=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(a&7)>>>24;m=a+8|0;c[g>>2]=e>>>0>m>>>0?m:e;c[b>>2]=k;if((k|0)==187){e=c[g>>2]|0;m=c[j>>2]|0;a=l+(e>>>3)|0;n=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(e&7)>>>28;a=e+4|0;c[g>>2]=m>>>0>a>>>0?a:m;c[b+4>>2]=d[830648+n|0]|0;n=c[g>>2]|0;m=c[j>>2]|0;a=l+(n>>>3)|0;e=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(n&7)>>>28;a=n+4|0;c[g>>2]=m>>>0>a>>>0?a:m;c[b+8>>2]=d[830648+e|0]|0;e=c[g>>2]|0;m=c[j>>2]|0;a=l+(e>>>3)|0;n=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(e&7)>>>28;a=e+4|0;c[g>>2]=m>>>0>a>>>0?a:m;if((n|0)==15){o=0}else{o=((n&8|0)!=0?44100:48e3)<<(n&7)}c[b+12>>2]=o;o=c[g>>2]|0;m=c[j>>2]|0;a=l+(o>>>3)|0;e=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(o&7)>>>28;a=o+4|0;c[g>>2]=m>>>0>a>>>0?a:m;if((e|0)==15){p=0}else{p=((e&8|0)!=0?44100:48e3)<<(e&7)}c[b+16>>2]=p;p=c[j>>2]|0;e=(c[g>>2]|0)+11|0;m=p>>>0>e>>>0?e:p;c[g>>2]=m;e=l+(m>>>3)|0;a=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(m&7)>>>27;e=m+5|0;c[g>>2]=p>>>0>e>>>0?e:p;c[b+20>>2]=a;c[b+36>>2]=d[830664+a|0]|0;p=1352512+(a<<3)|0;a=c[p+4>>2]|0;e=b+48|0;c[e>>2]=c[p>>2];c[e+4>>2]=a;q=n}else if((k|0)==186){c[b+4>>2]=24;c[b+8>>2]=0;k=c[g>>2]|0;n=c[j>>2]|0;a=l+(k>>>3)|0;e=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(k&7)>>>28;a=k+4|0;c[g>>2]=n>>>0>a>>>0?a:n;if((e|0)==15){r=0}else{r=((e&8|0)!=0?44100:48e3)<<(e&7)}c[b+12>>2]=r;c[b+16>>2]=0;r=c[j>>2]|0;n=(c[g>>2]|0)+4|0;a=r>>>0>n>>>0?n:r;c[g>>2]=a;n=l+(a>>>3)|0;k=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(a&7)>>>30;n=a+2|0;c[g>>2]=r>>>0>n>>>0?n:r;c[b+24>>2]=k;k=c[g>>2]|0;r=c[j>>2]|0;n=l+(k>>>3)|0;a=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7)>>>30;n=k+2|0;c[g>>2]=r>>>0>n>>>0?n:r;c[b+28>>2]=a;a=c[g>>2]|0;r=c[j>>2]|0;n=l+(a>>>3)|0;k=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(a&7);n=k>>>27;p=a+5|0;c[g>>2]=r>>>0>p>>>0?p:r;c[b+20>>2]=n;r=n&1;n=k>>>28;p=k>>>29;a=k>>>30&1;c[b+40>>2]=(k>>31&2|-p&1)+(-a&2)+(-r&2|-n&1);m=xrc(0,0,r,0)|0;r=G&0;o=xrc(0,0,n&1,0)|0;n=G&0;s=xrc(0,0,p&1,0)|0;p=G&0;t=xrc(0,0,a,0)|0;a=G&0;u=xrc(0,0,k>>>31,0)|0;k=b+56|0;c[k>>2]=m&3|u&20480|o&4|s&8|t&1536;c[k+4>>2]=r|G&0|n|p|a;a=c[g>>2]|0;p=c[j>>2]|0;n=l+(a>>>3)|0;r=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(a&7)>>>30;n=a+2|0;c[g>>2]=p>>>0>n>>>0?n:p;c[b+32>>2]=r;r=c[g>>2]|0;p=c[j>>2]|0;n=l+(r>>>3)|0;a=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(r&7);n=r+13|0;c[g>>2]=p>>>0>n>>>0?n:p;p=a>>>19&1;n=a>>>20;r=a>>>21;k=a>>>22&1;t=a>>>23&1;s=a>>>24&1;o=a>>>25&1;u=a>>>26;m=a>>>27;v=a>>>28&1;w=a>>>29&1;x=a>>>30;y=a>>>31;c[b+44>>2]=(-r&1)+y+(-u&1)+(-m&1)+(-x&1)+(-k&2)+(-t&2)+(-s&2)+(-o&2)+(-v&2)+(-w&2)+(-p&2|-n&1);a=xrc(0,0,p,0)|0;p=G&0;z=xrc(0,0,n&1,0)|0;n=G&0;A=xrc(0,0,r&1,0)|0;r=G&0;B=xrc(0,0,k,0)|0;k=G&0;C=xrc(0,0,t,0)|0;t=G&0;D=xrc(0,0,s,0)|0;s=G&0;E=xrc(0,0,o,0)|0;o=G&0;F=xrc(0,0,u&1,0)|0;u=G&0;H=xrc(0,0,m&1,0)|0;m=G&0;I=xrc(0,0,v,0)|0;v=G&6;J=xrc(0,0,w,0)|0;w=G&1;K=xrc(0,0,x&1,0)|0;x=G&0;L=xrc(0,0,y,0)|0;y=b+64|0;c[y>>2]=a&3|L&0|z&4|A&8|B&1536|C&20480|D&192|E&48|F&256|H&2048|I&0|J&-2147483648|K&8192;c[y+4>>2]=p|G&8|n|r|k|t|s|o|u|m|v|w|x;q=e}else{h=-1094995529;i=f;return h|0}e=q&7;c[b+72>>2]=40<<e;c[b+76>>2]=64<<e;e=c[g>>2]|0;q=-e|0;x=c[j>>2]|0;w=x-e|0;if((q|0)>48){M=q}else{M=(w|0)<48?w:48}w=M+e|0;c[g>>2]=w;e=(d[l+(w>>>3)|0]|0)<<(w&7)>>>7;c[g>>2]=((w|0)<(x|0))+w;c[b+80>>2]=e&1;e=c[g>>2]|0;w=c[j>>2]|0;x=l+(e>>>3)|0;M=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(e&7)>>>17;x=e+15|0;c[g>>2]=w>>>0>x>>>0?x:w;c[b+84>>2]=((ca(M,c[b+12>>2]|0)|0)+8|0)>>>4;M=c[g>>2]|0;w=c[j>>2]|0;x=l+(M>>>3)|0;l=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(M&7)>>>28;x=M+4|0;c[g>>2]=w>>>0>x>>>0?x:w;c[b+88>>2]=l;l=c[g>>2]|0;b=-l|0;w=(c[j>>2]|0)-l|0;if((b|0)>92){N=b}else{N=(w|0)<92?w:92}c[g>>2]=N+l;h=0;i=f;return h|0}function EQa(a){a=a|0;Tqb();return 0}function FQa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=i;i=i+136|0;l=k|0;m=k+8|0;n=k+16|0;o=k+40|0;c[l>>2]=h;c[m>>2]=j;p=c[b>>2]|0;c[g>>2]=0;if((j|0)==0){q=0;i=k;return q|0}r=p+44|0;if((c[r>>2]|0)==0){a:do{if((j|0)>0){s=p+16|0;t=p+4|0;u=0;v=c[s>>2]|0;while(1){w=d[h+u|0]|0|v<<8;c[s>>2]=w;if((w&-2|0)==-126718022){if(((c[t>>2]|0)+u|0)>6){break}}x=u+1|0;if((x|0)<(c[m>>2]|0)){u=x;v=w}else{break a}}c[r>>2]=1;c[p+40>>2]=0;v=u-7|0;IWa(p,v,l,m)|0;q=v;i=k;return q|0}}while(0);if(!((IWa(p,-100,l,m)|0)==-1)){KIb(e,24,2450384,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}q=c[m>>2]|0;i=k;return q|0}h=p+40|0;v=c[h>>2]|0;t=p;do{if((v|0)==0){s=p+24|0;if((c[s>>2]|0)>0){w=p+28|0;x=p;z=p+4|0;do{A=c[w>>2]|0;c[w>>2]=A+1;B=c[x>>2]|0;C=a[B+A|0]|0;A=c[z>>2]|0;c[z>>2]=A+1;a[B+A|0]=C;C=(c[s>>2]|0)-1|0;c[s>>2]=C;}while((C|0)>0);D=c[m>>2]|0;E=z}else{D=j;E=p+4|0}s=c[E>>2]|0;if((D+s|0)<2){if(!((IWa(t,-100,l,m)|0)==-1)){KIb(e,24,2450384,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}q=c[m>>2]|0;i=k;return q|0}do{if((s|0)>0){x=(d[c[p>>2]|0]|0)<<8;if((s|0)<=1){F=x;G=26;break}H=(c[p>>2]|0)+1|0;I=x}else{F=(d[c[l>>2]|0]|0)<<8;G=26}}while(0);if((G|0)==26){H=(c[l>>2]|0)+(1-s)|0;I=F}z=d[H]|0|I&3840;x=z<<1;c[h>>2]=x;if((z|0)==0){break}z=x-s|0;c[h>>2]=z;J=z;K=c[m>>2]|0;G=29}else{J=v;K=j;G=29}}while(0);b:do{if((G|0)==29){j=(J|0)>(K|0)?-100:J;if((IWa(t,j,l,m)|0)<0){c[h>>2]=(c[h>>2]|0)-(c[m>>2]|0);q=c[m>>2]|0;i=k;return q|0}c[h>>2]=0;v=c[l>>2]|0;I=v+4|0;H=I;do{if(((je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)&-2|0)==-126718022){F=(c[m>>2]<<3)-32|0;D=F>>>0>2147483639>>>0|(I|0)==0;E=D?0:I;z=D?0:F;c[n>>2]=E;c[n+12>>2]=z;c[n+16>>2]=z+8;c[n+4>>2]=E+(z>>3);c[n+8>>2]=0;if((DQa(e,o,n)|0)<0){break b}z=c[o+4>>2]|0;c[e+796>>2]=z;c[e+420>>2]=(z|0)>16?2:1;c[e+412>>2]=c[o+12>>2];c[b+304>>2]=c[o+72>>2];z=e+416|0;if((c[z>>2]|0)==0){G=41}else{E=e+448|0;if((c[E>>2]|0)==0&(c[E+4>>2]|0)==0){G=41}}c:do{if((G|0)==41){E=c[e+440>>2]|0;F=(E-1|0)>>>0<2>>>0;if((c[o>>2]|0)==187){do{if(F){if((c[o+88>>2]|0)<=1){break}c[z>>2]=2;D=e+448|0;c[D>>2]=3;c[D+4>>2]=0;break c}}while(0);D=e+456|0;x=c[D>>2]|0;w=c[D+4>>2]|0;do{if(((x|0)!=0|(w|0)!=0)&((x&3|0)==(x|0)&(w&0|0)==(w|0))){if((c[o+88>>2]|0)<=1){break}c[z>>2]=2;D=e+448|0;c[D>>2]=3;c[D+4>>2]=0;break c}}while(0);c[z>>2]=c[o+36>>2];w=o+48|0;x=c[w+4>>2]|0;D=e+448|0;c[D>>2]=c[w>>2];c[D+4>>2]=x;break}do{if(F){if((c[o+88>>2]|0)<=1){break}c[z>>2]=2;x=e+448|0;c[x>>2]=3;c[x+4>>2]=0;break c}}while(0);do{if((E|0)>0){F=c[o+40>>2]|0;if((E|0)>(F|0)){break}c[z>>2]=F;F=o+56|0;x=c[F+4>>2]|0;D=e+448|0;c[D>>2]=c[F>>2];c[D+4>>2]=x;break c}}while(0);E=e+456|0;x=c[E>>2]|0;D=c[E+4>>2]|0;do{if(((x|0)!=0|(D|0)!=0)&((x&3|0)==(x|0)&(D&0|0)==(D|0))){if((c[o+88>>2]|0)<=1){break}c[z>>2]=2;E=e+448|0;c[E>>2]=3;c[E+4>>2]=0;break c}}while(0);E=c[o+44>>2]|0;do{if((E|0)==0){F=o+56|0;L=c[F+4>>2]|0;M=c[F>>2]|0}else{if(!((x|0)==0&(D|0)==0)){F=o+56|0;w=c[F>>2]|0;u=c[F+4>>2]|0;if((w&x|0)==(x|0)&(u&D|0)==(D|0)){L=u;M=w;break}}c[z>>2]=E;w=o+64|0;u=c[w+4>>2]|0;F=e+448|0;c[F>>2]=c[w>>2];c[F+4>>2]=u;break c}}while(0);c[z>>2]=c[o+40>>2];E=e+448|0;c[E>>2]=M;c[E+4>>2]=L}}while(0);if((c[o+80>>2]|0)==0){c[e+72>>2]=c[o+84>>2]}c[p+48>>2]=c[o+88>>2];N=c[l>>2]|0}else{z=c[p+48>>2]|0;if((z|0)>-1){E=0;D=-1;x=0;while(1){u=a[v+x|0]|0;F=x+2|0;w=u^E^a[v+(x+1)|0];if((D|0)<0|u<<24>>24<0){O=x+4|0;P=a[v+F|0]^w^a[v+(x+3)|0]}else{O=F;P=w}w=D+1|0;if((w|0)<(z|0)){E=P;D=w;x=O}else{Q=P;break}}}else{Q=0}x=Q&255;if((x>>>4^x&15|0)==15){N=v;break}KIb(e,32,2361096,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;break b}}while(0);c[f>>2]=N;c[g>>2]=c[m>>2];q=j;i=k;return q|0}}while(0);c[r>>2]=0;q=1;i=k;return q|0}function GQa(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((c[1486560]|0)==0){c[1486561]=5913248;c[1486563]=512;$2(5946240,9,18,1352769,2,1,1352768,2,1,0,0,0,4)|0;c[1486566]=5911200;c[1486568]=512;$2(5946260,9,16,1352805,2,1,1352804,2,1,0,0,0,4)|0;c[1486571]=5909152;c[1486573]=512;$2(5946280,9,15,1352841,2,1,1352840,2,1,0,0,0,4)|0}Tqb();c[b>>2]=a;c[b+1548>>2]=-1;c[b+3076>>2]=-1;c[b+4604>>2]=-1;JQa(b+11332|0);return 0}function HQa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0;k=i;i=i+1480|0;l=k|0;m=k+1344|0;n=k+1440|0;o=k+1464|0;p=k+1472|0;q=c[j+24>>2]|0;r=c[j+28>>2]|0;j=c[f+60>>2]|0;s=j;if((r|0)<4){t=-1094995529;i=k;return t|0}u=q;v=((he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)<<1&8190;if(v>>>0<4>>>0|v>>>0>r>>>0){t=-1094995529;i=k;return t|0}r=q+4|0;u=(v<<3)-32|0;w=u>>>0>2147483639>>>0|(r|0)==0;x=w?0:r;r=w?0:u;u=n|0;c[u>>2]=x;w=n+12|0;c[w>>2]=r;z=n+16|0;c[z>>2]=r|8;A=n+4|0;c[A>>2]=x+(r>>3);r=n+8|0;c[r>>2]=0;x=j+4|0;c[x>>2]=0;B=c[u>>2]|0;C=c[r>>2]|0;D=c[z>>2]|0;E=B+(C>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(C&7)>>>16;E=C+16|0;C=D>>>0>E>>>0?E:D;D=B+(C>>>3)|0;a:do{if(((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>>17|F<<15|0)==2084124637){B=j;E=DQa(c[B>>2]|0,m,n)|0;do{if((E|0)==0){H=m+4|0;I=c[H>>2]|0;if((I|0)==0){KIb(c[B>>2]|0,16,2267816,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}if((c[m+8>>2]|0)>(I|0)){KIb(c[B>>2]|0,16,2264088,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}I=c[m+16>>2]|0;K=c[m+12>>2]|0;do{if((I|0)==0){if((K|0)!=0){L=K;break}KIb(c[B>>2]|0,16,2255840,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}else{if((I|0)==(K|0)){L=I;break}KIb(c[B>>2]|0,16,2260256,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}}while(0);if((L|0)>192e3){KIb(c[B>>2]|0,16,2251616,(J=i,i=i+16|0,c[J>>2]=L,c[J+8>>2]=192e3,J)|0);i=J;break a}I=m+72|0;K=c[I>>2]|0;if((K|0)>160){KIb(c[B>>2]|0,16,2241136,(J=i,i=i+16|0,c[J>>2]=K,c[J+8>>2]=160,J)|0);i=J;break a}M=c[m+76>>2]|0;if((M|0)>256){KIb(c[B>>2]|0,16,2235336,(J=i,i=i+16|0,c[J>>2]=M,c[J+8>>2]=256,J)|0);i=J;break a}N=m+88|0;O=c[N>>2]|0;if((O|0)==0){break a}P=c[B>>2]|0;if((c[P+48>>2]|0)==86045&(O|0)>2){KIb(P,16,2231768,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break a}if((O|0)>3){QIb(P,2227944,(J=i,i=i+8|0,c[J>>2]=O,J)|0);i=J;break a}c[j+12>>2]=K;c[j+16>>2]=M;a[j+9|0]=O;M=j+10|0;a[M]=O+255;c[P+412>>2]=L;c[P+424>>2]=c[I>>2];c[P+796>>2]=c[H>>2];c[P+420>>2]=(c[H>>2]|0)>16?2:1;a[j+8|0]=1;a[j+24|0]=0;a[j+1552|0]=0;a[j+3080|0]=0;P=c[B>>2]|0;I=c[m>>2]|0;do{if((c[P+48>>2]|0)==86045){if((I|0)!=187){QIb(P,2223072,(J=i,i=i+8|0,c[J>>2]=I,J)|0);i=J;break a}O=(c[N>>2]|0)>1;if(O){K=j+40|0;c[K>>2]=3;c[K+4>>2]=0}K=m+48|0;Q=c[K+4>>2]|0;R=s+24+((O&1)*1528|0)+16|0;c[R>>2]=c[K>>2];c[R+4>>2]=Q}else{if((I|0)!=186){QIb(P,2219472,(J=i,i=i+8|0,c[J>>2]=I,J)|0);i=J;break a}Q=c[N>>2]|0;R=(Q|0)>1;K=R&1;do{if(R){O=j+40|0;c[O>>2]=3;c[O+4>>2]=0;if((Q|0)<=2){break}O=m+64|0;S=c[O>>2]|0;T=c[O+4>>2]|0;if((S|0)==0&(T|0)==0){O=m+56|0;U=c[O+4>>2]|0;V=j+3096|0;c[V>>2]=c[O>>2];c[V+4>>2]=U;break}else{U=j+3096|0;c[U>>2]=S;c[U+4>>2]=T;break}}}while(0);Q=m+56|0;R=c[Q>>2]|0;T=c[Q+4>>2]|0;Q=s+24+(K*1528|0)+16|0;c[Q>>2]=R;c[Q+4>>2]=T;Q=c[B>>2]|0;if(!((c[Q+416>>2]|0)<3&((R|0)==4&(T|0)==0))){break}if((a[M]|0)!=1){break}KIb(Q,48,2216520,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;a[M]=0;Q=c[B>>2]|0;if((c[Q+416>>2]|0)!=2){break}T=Q+448|0;c[T>>2]=3;c[T+4>>2]=0}}while(0);M=c[m+20>>2]|0;if((M|0)>17){W=(M|0)<21|0}else{W=0}a[j+11|0]=W;M=j+48|0;c[M>>2]=0;I=j+1576|0;c[I>>2]=0;P=j+3104|0;c[P>>2]=0;if((c[(c[B>>2]|0)+48>>2]|0)!=86061){break}H=c[N>>2]|0;do{if((H|0)>2){T=m+64|0;if(!((c[T>>2]&1536|0)==1536&(c[T+4>>2]&0|0)==0)){X=50;break}if((c[m+32>>2]|0)!=2){X=49;break}c[P>>2]=5;X=49}else{X=49}}while(0);if((X|0)==49){if((H|0)>1){X=50}}do{if((X|0)==50){P=m+56|0;if(!((c[P>>2]&1536|0)==1536&(c[P+4>>2]&0|0)==0)){break}if((c[m+28>>2]|0)!=2){break}c[I>>2]=5}}while(0);if((H|0)<=0){break}I=c[m+24>>2]|0;if((I|0)==1){c[M>>2]=1;break}else if((I|0)==2){c[M>>2]=6;break}else{break}}else{if((E|0)<0){break a}}}while(0);c[x>>2]=1;Y=32;X=59}else{Y=4;X=59}}while(0);b:do{if((X|0)==59){if((a[j+8|0]|0)==0){KIb(c[j>>2]|0,24,2296800,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;c[h>>2]=0;t=v;i=k;return t|0}m=j+9|0;c:do{if((a[m]|0)==0){Z=0}else{W=j;L=v-Y|0;F=j+10|0;C=0;D=0;E=0;while(1){B=c[r>>2]|0;I=c[u>>2]|0;P=d[I+(B>>>3)|0]|0;N=c[z>>2]|0;T=((B|0)<(N|0))+B|0;c[r>>2]=T;Q=d[I+(T>>>3)|0]<<(T&7)>>>7;R=((T|0)<(N|0))+T|0;c[r>>2]=R;T=Q&1;Q=d[I+(R>>>3)|0]<<(R&7)>>>7;U=((R|0)<(N|0))+R+1|0;R=N>>>0>U>>>0?U:N;c[r>>2]=R;U=I+(R>>>3)|0;I=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(R&7)>>>20;U=R+12|0;R=N>>>0>U>>>0?U:N;c[r>>2]=R;U=I<<1;if((P&128>>>((B&7)>>>0)|0)==0){_=C+2|0}else{$=c[W>>2]|0;if((c[$+48>>2]|0)==86045){X=65;break}B=R+16|0;c[r>>2]=N>>>0>B>>>0?B:N;_=C+4|0}if((T|0)==(c[x>>2]|0)){X=68;break}if((U+Y+_|0)>>>0>v>>>0){KIb(c[W>>2]|0,16,2172304,(J=i,i=i+8|0,c[J>>2]=E,J)|0);i=J;aa=L-_|0}else{aa=U}if(aa>>>0<D>>>0){X=72;break}if(E>>>0>(d[F]|0)>>>0){ba=D}else{a[o+E|0]=Q&1;b[p+(E<<1)>>1]=aa-D;ba=aa}Q=E+1|0;if(Q>>>0<(d[m]|0)>>>0){C=_;D=ba;E=Q}else{Z=_;break c}}if((X|0)==65){KIb($,16,2245832,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break b}else if((X|0)==68){KIb(c[W>>2]|0,16,2204248,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break b}else if((X|0)==72){KIb(f,16,2144712,(J=i,i=i+8|0,c[J>>2]=E,J)|0);i=J;break b}}}while(0);m=Xqb(q,4)|0;D=((Xqb(q+Y|0,Z)|0)^m)&255;if((D>>>4^D&15|0)!=15){KIb(f,16,2121104,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break}D=j+10|0;m=j+24|0;C=j+4608|0;F=C;L=j+12|0;M=j;H=l+640|0;Q=H;U=l+1312|0;T=j+11332|0;N=j+11|0;B=0;R=q+(Z+Y)|0;d:while(1){P=e[p+(B<<1)>>1]|0;I=P<<3;S=(R|0)==0?0:I;c[u>>2]=R;c[w>>2]=S;c[z>>2]=S+8;c[A>>2]=R+(S>>>3);c[r>>2]=0;S=m+(B*1528|0)+1514|0;mrc(C|0,0,68)|0;b[S>>1]=0;V=m+(B*1528|0)|0;O=s+24+(B*1528|0)+1220|0;ca=s+24+(B*1528|0)+1514|0;da=s+24+(B*1528|0)+1512|0;ea=s+24+(B*1528|0)+5|0;fa=s+24+(B*1528|0)+4|0;ga=s+24+(B*1528|0)+1222|0;ha=s+24+(B*1528|0)+1221|0;ia=s+24+(B*1528|0)+6|0;ja=s+24+(B*1528|0)+2|0;ka=B&255;la=s+24+(B*1528|0)+16|0;ma=s+24+(B*1528|0)+1212|0;na=s+24+(B*1528|0)+1216|0;oa=s+24+(B*1528|0)+1524|0;pa=s+24+(B*1528|0)+7|0;qa=s+24+(B*1528|0)+1516|0;ra=s+24+(B*1528|0)+1504|0;sa=s+24+(B*1528|0)+11|0;ta=s+24+(B*1528|0)+10|0;ua=s+24+(B*1528|0)+9|0;va=s+24+(B*1528|0)+12|0;wa=c[r>>2]|0;xa=R;ya=c[z>>2]|0;e:while(1){za=d[xa+(wa>>>3)|0]|0;Aa=((wa|0)<(ya|0))+wa|0;c[r>>2]=Aa;do{if((za&128>>>((wa&7)>>>0)|0)!=0){Ba=d[xa+(Aa>>>3)|0]|0;Ca=((Aa|0)<(ya|0))+Aa|0;c[r>>2]=Ca;if((Ba&128>>>((Aa&7)>>>0)|0)==0){if((a[V]|0)==0){X=243;break e}}else{Da=c[M>>2]|0;Ea=(c[Da+48>>2]|0)==86045?5:7;Ba=xa+(Ca>>>3)|0;Fa=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ca&7)>>>19;Ba=Ca+13|0;Ga=ya>>>0>Ba>>>0?Ba:ya;c[r>>2]=Ga;if((Fa|0)!=6389){X=83;break e}Ba=d[xa+(Ga>>>3)|0]<<(Ga&7)>>>7;Ha=((Ga|0)<(ya|0))+Ga|0;c[r>>2]=Ha;Ga=Ba&1;Ba=Ga&65535;b[ja>>1]=Ba;Ia=c[M>>2]|0;if(!((c[Ia+48>>2]|0)!=86045|(Ga|0)==0)){X=85;break e}Ga=Ha+16|0;Ha=ya>>>0>Ga>>>0?Ga:ya;c[r>>2]=Ha;Ga=xa+(Ha>>>3)|0;Ja=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7)>>>28;Ga=Ha+4|0;Ha=ya>>>0>Ga>>>0?Ga:ya;c[r>>2]=Ha;Ga=xa+(Ha>>>3)|0;Ka=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7);La=Ka>>>28;Ga=Ha+4|0;Ha=ya>>>0>Ga>>>0?Ga:ya;c[r>>2]=Ha;Ga=xa+(Ha>>>3)|0;Ma=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7)>>>28;Ga=Ha+4|0;c[r>>2]=ya>>>0>Ga>>>0?Ga:ya;if(Ma>>>0>Ea>>>0){X=87;break e}if((La|0)!=(Ma|0)){X=89;break e}if(Ka>>>0>1610612735>>>0&Ba<<16>>16==0){X=91;break e}if(Ja>>>0>La>>>0){X=93;break e}a[fa]=Ja;Ja=La&255;a[ea]=Ja;a[ia]=Ja;Ja=c[Ia+440>>2]|0;do{if((Ja|0)>0){Ba=La+1|0;if((Ja|0)>(Ba|0)){X=98;break}if(!((d[D]|0)>>>0>B>>>0)){X=98;break}KIb(Ia,48,2291888,(J=i,i=i+16|0,c[J>>2]=Ba,c[J+8>>2]=B,J)|0);i=J;a[D]=ka}else{X=98}}while(0);do{if((X|0)==98){X=0;Ja=Ia+456|0;Ba=c[Ja>>2]|0;Ka=c[Ja+4>>2]|0;if((Ba|0)==0&(Ka|0)==0){break}Ja=c[la>>2]|0;Ma=c[la+4>>2]|0;if(!((Ja&Ba|0)==(Ba|0)&(Ma&Ka|0)==(Ka|0))){break}if(!((d[D]|0)>>>0>B>>>0)){break}KIb(Ia,48,2285112,(J=i,i=i+32|0,c[J>>2]=La+1,c[J+8>>2]=Ja,c[J+16>>2]=Ma,c[J+24>>2]=B,J)|0);i=J;a[D]=ka}}while(0);Ma=c[r>>2]|0;Ja=c[z>>2]|0;Ka=(c[u>>2]|0)+(Ma>>>3)|0;Ba=(je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ma&7)>>>28;Ka=Ma+4|0;c[r>>2]=Ja>>>0>Ka>>>0?Ka:Ja;a[ma]=Ba;Ba=c[r>>2]|0;Ja=c[z>>2]|0;Ka=c[u>>2]|0;Ma=Ka+(Ba>>>3)|0;Ga=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ba&7)>>>9;Ma=Ba+23|0;c[r>>2]=Ja>>>0>Ma>>>0?Ma:Ja;c[na>>2]=Ga;Ga=c[z>>2]|0;Ja=(c[r>>2]|0)+19|0;Ma=Ga>>>0>Ja>>>0?Ja:Ga;c[r>>2]=Ma;Ja=d[Ka+(Ma>>>3)|0]<<(Ma&7)>>>7;c[r>>2]=((Ma|0)<(Ga|0))+Ma;a[O]=Ja&1;Ja=c[r>>2]|0;Ma=c[z>>2]|0;Ga=(c[u>>2]|0)+(Ja>>>3)|0;Ka=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ja&7)>>>24;Ga=Ja+8|0;Ja=Ma>>>0>Ga>>>0?Ga:Ma;c[r>>2]=Ja;do{if((d[D]|0)==(B|0)){Ga=c[oa>>2]|0;if((Ga|0)==-1){Na=Ja;Oa=Ma;break}Ba=Ga>>>16^Ga;Ga=(Ba>>>8^Ba)&255;if((Ga|0)==(Ka|0)){Na=Ja;Oa=Ma;break}KIb(c[M>>2]|0,24,2281072,(J=i,i=i+16|0,c[J>>2]=Ka,c[J+8>>2]=Ga,J)|0);i=J;Na=c[r>>2]|0;Oa=c[z>>2]|0}else{Na=Ja;Oa=Ma}}while(0);Ma=Na+16|0;c[r>>2]=Oa>>>0>Ma>>>0?Ma:Oa;Ma=pa|0;y=0;a[Ma]=y;y=y>>8;a[Ma+1|0]=y;y=y>>8;a[Ma+2|0]=y;y=y>>8;a[Ma+3|0]=y;Ma=pa+4|0;y=0;a[Ma]=y;y=y>>8;a[Ma+1|0]=y;y=y>>8;a[Ma+2|0]=y;y=y>>8;a[Ma+3|0]=y;Pa=0;while(1){Ma=c[r>>2]|0;Ja=c[z>>2]|0;Ka=(c[u>>2]|0)+(Ma>>>3)|0;Ga=(je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ma&7)>>>26;Ka=Ma+6|0;c[r>>2]=Ja>>>0>Ka>>>0?Ka:Ja;if((c[(c[M>>2]|0)+48>>2]|0)==86061){Ja=c[la>>2]|0;Ka=c[la+4>>2]|0;f:do{if((rGb(Ja,Ka)|0)>(Ga|0)){Ma=Ga;Ba=0;while(1){Ha=310072+(Ba<<3)|0;Qa=c[Ha>>2]|0;Ra=c[Ha+4>>2]|0;if((Qa&Ja|0)==0&(Ra&Ka|0)==0){Sa=Ma}else{if((Ma|0)==0){Ta=Ra;Ua=Qa;break f}else{Sa=Ma-1|0}}Qa=Ba+1|0;if(Qa>>>0<20>>>0){Ma=Sa;Ba=Qa}else{Ta=0;Ua=0;break}}}else{Ta=0;Ua=0}}while(0);Va=uGb(c[la>>2]|0,c[la+4>>2]|0,Ua,Ta)|0}else{Va=Ga}if(Va>>>0>(d[ia]|0)>>>0){X=114;break e}a[s+24+(B*1528|0)+7+Va|0]=Pa;Ka=Pa+1|0;if(Ka>>>0>(d[ia]|0)>>>0){break}else{Pa=Ka}}Ka=(Wqb(R,(c[r>>2]|0)-Ca|0)|0)&255;Ja=c[r>>2]|0;Ba=c[z>>2]|0;Ma=(c[u>>2]|0)+(Ja>>>3)|0;Qa=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ja&7)>>>24;Ma=Ja+8|0;c[r>>2]=Ba>>>0>Ma>>>0?Ma:Ba;if((Ka|0)!=(Qa|0)){KIb(c[M>>2]|0,16,2272512,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}a[ha]=-1;a[ga]=0;b[da>>1]=8;c[oa>>2]=0;Qa=qa|0;y=0;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;Qa=qa+4|0;y=0;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;Qa=ra|0;y=0;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;Qa=ra+4|0;y=0;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;Qa=a[fa]|0;if(!((Qa&255)>>>0>(d[ea]|0)>>>0)){Ka=Qa&255;do{a[s+24+(B*1528|0)+28+(Ka*148|0)|0]=0;a[s+24+(B*1528|0)+28+(Ka*148|0)+36|0]=0;a[s+24+(B*1528|0)+28+(Ka*148|0)+1|0]=0;a[s+24+(B*1528|0)+28+(Ka*148|0)+37|0]=0;b[s+24+(B*1528|0)+28+(Ka*148|0)+136>>1]=0;c[s+24+(B*1528|0)+28+(Ka*148|0)+140>>2]=-8388608;a[s+24+(B*1528|0)+28+(Ka*148|0)+144|0]=0;a[s+24+(B*1528|0)+28+(Ka*148|0)+145|0]=24;Ka=Ka+1|0;}while(!(Ka>>>0>(d[ea]|0)>>>0))}do{if((d[D]|0)==(B|0)){Ka=c[M>>2]|0;c[Ka+416>>2]=(d[ia]|0)+1;Ca=c[la>>2]|0;Qa=c[la+4>>2]|0;Ba=Ka+448|0;c[Ba>>2]=Ca;c[Ba+4>>2]=Qa;if((c[Ka+48>>2]|0)!=86045){break}if((a[N]|0)==0){break}Ka=55;Ba=0;Ma=59;Ja=0;if((Ca|0)==63&(Qa|0)==0){Ra=a[sa]|0;a[sa]=a[ua]|0;a[ua]=Ra;Ra=a[va]|0;a[va]=a[ta]|0;a[ta]=Ra;break}else if((Ca|0)==(Ma|0)&(Qa|0)==(Ja|0)|(Ca|0)==(Ka|0)&(Qa|0)==(Ba|0)){Ba=a[sa]|0;a[sa]=a[ta]|0;a[ta]=a[ua]|0;a[ua]=Ba;break}else{break}}}while(0);a[V]=1}Ba=a[ha]|0;do{if((Ba&1)==0){Wa=Ba}else{Qa=c[r>>2]|0;Ka=c[u>>2]|0;Ca=d[Ka+(Qa>>>3)|0]|0;Ja=c[z>>2]|0;Ma=((Qa|0)<(Ja|0))+Qa|0;c[r>>2]=Ma;if((Ca&128>>>((Qa&7)>>>0)|0)==0){Wa=a[ha]|0;break}else{Qa=Ka+(Ma>>>3)|0;Ka=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Ma&7)>>>24;Qa=Ma+8|0;c[r>>2]=Ja>>>0>Qa>>>0?Qa:Ja;Ja=Ka&255;a[ha]=Ja;Wa=Ja;break}}}while(0);do{if(Wa<<24>>24<0){Ba=c[r>>2]|0;Ja=c[u>>2]|0;Ka=d[Ja+(Ba>>>3)|0]|0;Qa=c[z>>2]|0;Ma=((Ba|0)<(Qa|0))+Ba|0;c[r>>2]=Ma;if((Ka&128>>>((Ba&7)>>>0)|0)==0){break}Ba=Ja+(Ma>>>3)|0;Ja=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ma&7);Ba=Ja>>>23;Ka=Ma+9|0;c[r>>2]=Qa>>>0>Ka>>>0?Ka:Qa;b[da>>1]=Ba;if(Ja>>>0<67108864>>>0){X=137;break e}if((Ba|0)>(c[L>>2]|0)){X=137;break e}}}while(0);do{if(!((a[ha]&64)==0)){Ba=c[r>>2]|0;Ja=c[u>>2]|0;Qa=d[Ja+(Ba>>>3)|0]|0;c[r>>2]=((Ba|0)<(c[z>>2]|0))+Ba;if((Qa&128>>>((Ba&7)>>>0)|0)==0){break}Xa=c[M>>2]|0;Ya=(c[Xa+48>>2]|0)==86045?6:8;Ba=c[F>>2]|0;c[F>>2]=Ba+1;if((Ba|0)>1){X=141;break e}Ba=c[r>>2]|0;Qa=c[z>>2]|0;Ka=Ja+(Ba>>>3)|0;Ja=(je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ba&7)>>>28;Ka=Ba+4|0;c[r>>2]=Qa>>>0>Ka>>>0?Ka:Qa;Qa=Ja&255;a[ga]=Qa;if(Ja>>>0>Ya>>>0){X=144;break e}if(Qa<<24>>24==0){break}else{Za=0}do{Qa=c[r>>2]|0;Ja=c[z>>2]|0;Ka=(c[u>>2]|0)+(Qa>>>3)|0;Ba=(je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Qa&7)>>>28;Ka=Qa+4|0;c[r>>2]=Ja>>>0>Ka>>>0?Ka:Ja;Ja=s+24+(B*1528|0)+1223+Za|0;a[Ja]=Ba;Ba=c[r>>2]|0;Ka=c[z>>2]|0;Qa=c[u>>2]|0;Ma=Qa+(Ba>>>3)|0;Ca=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ba&7)>>>28;Ma=Ba+4|0;Ba=Ka>>>0>Ma>>>0?Ma:Ka;c[r>>2]=Ba;Ma=d[Qa+(Ba>>>3)|0]<<(Ba&7)>>>7;c[r>>2]=((Ba|0)<(Ka|0))+Ba;a[s+24+(B*1528|0)+1231+Za|0]=Ma&1;_a=a[Ja]|0;Ja=a[ia]|0;Ma=Ja&255;if((_a&255)>>>0>(Ja&255)>>>0){X=146;break e}if((Ca|0)==15){X=148;break e}Ja=(b[ja>>1]|0)==0?Ma+2|0:Ma;Ma=14-Ca|0;Ba=Ca+2|0;Ka=30-Ca|0;Ca=c[u>>2]|0;Qa=0;do{Ra=c[r>>2]|0;Ha=d[Ca+(Ra>>>3)|0]|0;$a=c[z>>2]|0;ab=((Ra|0)<($a|0))+Ra|0;c[r>>2]=ab;if((Ha&128>>>((Ra&7)>>>0)|0)==0){bb=0}else{Ra=Ca+(ab>>>3)|0;Ha=(je(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(ab&7)>>Ka;Ra=Ba+ab|0;c[r>>2]=$a>>>0>Ra>>>0?Ra:$a;bb=Ha}c[s+24+(B*1528|0)+1240+(Za<<5)+(Qa<<2)>>2]=bb<<Ma;Qa=Qa+1|0;}while(!(Qa>>>0>Ja>>>0));if((b[ja>>1]|0)==0){a[s+24+(B*1528|0)+1496+Za|0]=0}else{Ja=c[r>>2]|0;Qa=c[z>>2]|0;Ma=Ca+(Ja>>>3)|0;Ba=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ja&7)>>>28;Ma=Ja+4|0;c[r>>2]=Qa>>>0>Ma>>>0?Ma:Qa;a[s+24+(B*1528|0)+1496+Za|0]=Ba}Za=Za+1|0;}while(Za>>>0<(d[ga]|0)>>>0)}}while(0);g:do{if(!((a[ha]&32)==0)){Ga=c[r>>2]|0;Ba=c[u>>2]|0;Qa=d[Ba+(Ga>>>3)|0]|0;Ma=c[z>>2]|0;Ja=((Ga|0)<(Ma|0))+Ga|0;c[r>>2]=Ja;if((Qa&128>>>((Ga&7)>>>0)|0)==0){break}else{cb=0;db=Ja;eb=Ma;fb=Ba}while(1){Ba=fb+(db>>>3)|0;Ma=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(db&7)>>28;Ba=db+4|0;c[r>>2]=eb>>>0>Ba>>>0?Ba:eb;a[s+24+(B*1528|0)+1516+cb|0]=Ma;Ma=cb+1|0;if(Ma>>>0>(d[ia]|0)>>>0){break g}cb=Ma;db=c[r>>2]|0;eb=c[z>>2]|0;fb=c[u>>2]|0}}}while(0);h:do{if(!((a[ha]&16)==0)){Ma=c[r>>2]|0;Ba=c[u>>2]|0;Ja=d[Ba+(Ma>>>3)|0]|0;Ga=c[z>>2]|0;Qa=((Ma|0)<(Ga|0))+Ma|0;c[r>>2]=Qa;if((Ja&128>>>((Ma&7)>>>0)|0)==0){break}else{gb=0;hb=Qa;ib=Ga;jb=Ba}while(1){Ba=jb+(hb>>>3)|0;Ga=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(hb&7)>>>28;Ba=hb+4|0;c[r>>2]=ib>>>0>Ba>>>0?Ba:ib;a[s+24+(B*1528|0)+1504+gb|0]=Ga;Ba=(d[s+24+(B*1528|0)+28+(gb*148|0)+145|0]|0)-Ga|0;Ga=a[s+24+(B*1528|0)+28+(gb*148|0)+144|0]|0;if(Ga<<24>>24==0){kb=b[s+24+(B*1528|0)+28+(gb*148|0)+136>>1]|0;lb=Ba-1|0}else{kb=(b[s+24+(B*1528|0)+28+(gb*148|0)+136>>1]|0)-(7<<Ba)|0;lb=2-(Ga&255)+Ba|0}if((lb|0)>-1){mb=kb-(1<<lb)|0}else{mb=kb}c[s+24+(B*1528|0)+28+(gb*148|0)+140>>2]=mb;Ba=gb+1|0;if(Ba>>>0>(d[ea]|0)>>>0){break h}gb=Ba;hb=c[r>>2]|0;ib=c[z>>2]|0;jb=c[u>>2]|0}}}while(0);Ba=a[fa]|0;if((Ba&255)>>>0>(d[ea]|0)>>>0){break}Ga=Ba&255;do{Ba=c[r>>2]|0;Qa=c[u>>2]|0;Ma=d[Qa+(Ba>>>3)|0]|0;Ja=c[z>>2]|0;Ka=((Ba|0)<(Ja|0))+Ba|0;c[r>>2]=Ka;if((Ma&128>>>((Ba&7)>>>0)|0)!=0){do{if(!((a[ha]&8)==0)){Ba=d[Qa+(Ka>>>3)|0]|0;c[r>>2]=((Ka|0)<(Ja|0))+Ka;if((Ba&128>>>((Ka&7)>>>0)|0)==0){break}if((IQa(s,n,B,Ga,0)|0)<0){X=242;break e}}}while(0);do{if(!((a[ha]&4)==0)){Ka=c[r>>2]|0;Ja=d[(c[u>>2]|0)+(Ka>>>3)|0]|0;c[r>>2]=((Ka|0)<(c[z>>2]|0))+Ka;if((Ja&128>>>((Ka&7)>>>0)|0)==0){break}if((IQa(s,n,B,Ga,1)|0)<0){X=242;break e}}}while(0);Ka=a[s+24+(B*1528|0)+28+(Ga*148|0)|0]|0;Ja=a[s+24+(B*1528|0)+28+(Ga*148|0)+36|0]|0;if(((Ja&255)+(Ka&255)|0)>8){X=180;break e}Qa=Ka<<24>>24==0;Ka=Ja<<24>>24==0;if(!(Qa|Ka)){if((a[s+24+(B*1528|0)+28+(Ga*148|0)+1|0]|0)!=(a[s+24+(B*1528|0)+28+(Ga*148|0)+37|0]|0)){X=183;break e}}if(!(Ka|Qa^1)){a[s+24+(B*1528|0)+28+(Ga*148|0)+1|0]=a[s+24+(B*1528|0)+28+(Ga*148|0)+37|0]|0}Qa=c[r>>2]|0;do{if((a[ha]&2)==0){nb=Qa;ob=c[z>>2]|0;pb=c[u>>2]|0}else{Ka=c[u>>2]|0;Ja=d[Ka+(Qa>>>3)|0]|0;Ba=c[z>>2]|0;Ma=((Qa|0)<(Ba|0))+Qa|0;c[r>>2]=Ma;if((Ja&128>>>((Qa&7)>>>0)|0)==0){nb=Ma;ob=Ba;pb=Ka;break}Ja=Ka+(Ma>>>3)|0;Ha=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Ma&7)>>17;Ja=Ma+15|0;Ma=Ba>>>0>Ja>>>0?Ja:Ba;c[r>>2]=Ma;b[s+24+(B*1528|0)+28+(Ga*148|0)+136>>1]=Ha;nb=Ma;ob=Ba;pb=Ka}}while(0);Qa=pb+(nb>>>3)|0;Ka=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(nb&7)>>>30;Qa=nb+2|0;c[r>>2]=ob>>>0>Qa>>>0?Qa:ob;Qa=s+24+(B*1528|0)+28+(Ga*148|0)+144|0;a[Qa]=Ka;Ka=c[r>>2]|0;Ba=c[z>>2]|0;Ma=(c[u>>2]|0)+(Ka>>>3)|0;Ha=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ka&7);Ma=Ha>>>27;Ja=Ka+5|0;c[r>>2]=Ba>>>0>Ja>>>0?Ja:Ba;qb=s+24+(B*1528|0)+28+(Ga*148|0)+145|0;a[qb]=Ma;if(Ha>>>0>3355443199>>>0){X=191;break e}Ha=Ma-(d[s+24+(B*1528|0)+1504+Ga|0]|0)|0;Ma=a[Qa]|0;if(Ma<<24>>24==0){rb=b[s+24+(B*1528|0)+28+(Ga*148|0)+136>>1]|0;sb=Ha-1|0}else{rb=(b[s+24+(B*1528|0)+28+(Ga*148|0)+136>>1]|0)-(7<<Ha)|0;sb=2-(Ma&255)+Ha|0}if((sb|0)>-1){tb=rb-(1<<sb)|0}else{tb=rb}c[s+24+(B*1528|0)+28+(Ga*148|0)+140>>2]=tb}Ga=Ga+1|0;}while(!(Ga>>>0>(d[ea]|0)>>>0))}}while(0);if((a[V]|0)==0){X=243;break}if((a[O]|0)==0){ub=0}else{Aa=c[r>>2]|0;za=c[z>>2]|0;K=(c[u>>2]|0)+(Aa>>>3)|0;Ga=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Aa&7)>>>16;K=Aa+16|0;c[r>>2]=za>>>0>K>>>0?K:za;QIb(c[M>>2]|0,2502152,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;ub=Ga+Aa|0}Aa=e[ca>>1]|0;Ga=e[da>>1]|0;if((Ga+Aa|0)>(c[L>>2]|0)){X=203;break d}mrc(s+4932+(Aa<<3)|0,0,Ga<<3|0)|0;if((b[da>>1]|0)==0){vb=a[ea]|0;wb=0}else{Ga=0;while(1){Aa=a[ga]|0;if(!(Aa<<24>>24==0)){za=0;K=Aa;while(1){if((a[s+24+(B*1528|0)+1231+za|0]|0)==0){xb=K}else{Aa=c[r>>2]|0;Ha=d[(c[u>>2]|0)+(Aa>>>3)|0]<<(Aa&7)>>>7;c[r>>2]=((Aa|0)<(c[z>>2]|0))+Aa;a[s+4932+((e[ca>>1]|0)+Ga<<3)+za|0]=Ha&1;xb=a[ga]|0}Ha=za+1|0;if(Ha>>>0<(xb&255)>>>0){za=Ha;K=xb}else{break}}}K=a[fa]|0;za=a[ea]|0;if((K&255)>>>0>(za&255)>>>0){yb=za}else{za=K&255;while(1){K=a[s+24+(B*1528|0)+28+(za*148|0)+144|0]|0;Ha=d[s+24+(B*1528|0)+1504+za|0]|0;Aa=(d[s+24+(B*1528|0)+28+(za*148|0)+145|0]|0)-Ha|0;if(K<<24>>24==0){zb=0}else{Ma=c[5946244+(((K&255)-1|0)*20|0)>>2]|0;K=c[r>>2]|0;Qa=c[z>>2]|0;Ba=(c[u>>2]|0)+(K>>>3)|0;Ja=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(K&7)>>>23;Ba=b[Ma+(Ja<<2)>>1]|0;Ka=(b[Ma+(Ja<<2)+2>>1]|0)+K|0;c[r>>2]=Qa>>>0>Ka>>>0?Ka:Qa;if(Ba<<16>>16<0){t=-1094995529;X=284;break d}else{zb=Ba<<16>>16}}if((Aa|0)>0){Ba=c[r>>2]|0;Qa=c[z>>2]|0;Ka=(c[u>>2]|0)+(Ba>>>3)|0;K=(je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ba&7)>>>((32-Aa|0)>>>0);Ka=Ba+Aa|0;c[r>>2]=Qa>>>0>Ka>>>0?Ka:Qa;Ab=K+(zb<<Aa)|0}else{Ab=zb}c[s+6212+((e[ca>>1]|0)+Ga<<5)+(za<<2)>>2]=(c[s+24+(B*1528|0)+28+(za*148|0)+140>>2]|0)+Ab<<Ha;Ha=za+1|0;Aa=a[ea]|0;if(Ha>>>0>(Aa&255)>>>0){yb=Aa;break}else{za=Ha}}}za=Ga+1|0;Ha=b[da>>1]|0;if(za>>>0<(Ha&65535)>>>0){Ga=za}else{vb=yb;wb=Ha;break}}}Ga=a[fa]|0;if((Ga&255)>>>0>(vb&255)>>>0){Bb=wb}else{Ha=Ga&255;Ga=wb;while(1){za=d[s+24+(B*1528|0)+28+(Ha*148|0)+1|0]|0;Aa=-1<<d[s+24+(B*1528|0)+1504+Ha|0];K=s+24+(B*1528|0)+28+(Ha*148|0)+4|0;nrc(Q|0,K|0,32)|0;Qa=s+24+(B*1528|0)+28+(Ha*148|0)+40|0;c[U>>2]=c[Qa>>2];c[U+4>>2]=c[Qa+4>>2];c[U+8>>2]=c[Qa+8>>2];c[U+12>>2]=c[Qa+12>>2];Ge[c[T>>2]&255](H,s+24+(B*1528|0)+28+(Ha*148|0)+72|0,d[s+24+(B*1528|0)+28+(Ha*148|0)|0]|0,d[s+24+(B*1528|0)+28+(Ha*148|0)+36|0]|0,za,Aa,Ga&65535,s+6212+(e[ca>>1]<<5)+(Ha<<2)|0);nrc(K|0,l+(160-(e[da>>1]|0)<<2)|0,32)|0;K=l+672+(160-(e[da>>1]|0)<<2)|0;c[Qa>>2]=c[K>>2];c[Qa+4>>2]=c[K+4>>2];c[Qa+8>>2]=c[K+8>>2];c[Qa+12>>2]=c[K+12>>2];K=Ha+1|0;Qa=b[da>>1]|0;if(K>>>0>(d[ea]|0)>>>0){Bb=Qa;break}else{Ha=K;Ga=Qa}}}b[ca>>1]=(b[ca>>1]|0)+Bb;Ga=c[r>>2]|0;if((a[O]|0)==0){Cb=Ga}else{if((Ga|0)==(ub|0)){Db=ub}else{KIb(c[M>>2]|0,16,2478120,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Db=c[r>>2]|0}Ga=c[z>>2]|0;Ha=Db+8|0;Qa=Ga>>>0>Ha>>>0?Ha:Ga;c[r>>2]=Qa;Cb=Qa}if((Cb|0)>=(I|0)){X=282;break d}Eb=c[u>>2]|0;Qa=d[Eb+(Cb>>>3)|0]|0;Fb=c[z>>2]|0;Gb=((Cb|0)<(Fb|0))+Cb|0;c[r>>2]=Gb;if((Qa&128>>>((Cb&7)>>>0)|0)==0){wa=Gb;xa=Eb;ya=Fb}else{X=227;break}}if((X|0)==83){X=0;KIb(Da,16,2328208,(J=i,i=i+8|0,c[J>>2]=Fa,J)|0);i=J;X=242}else if((X|0)==85){X=0;KIb(Ia,16,2322544,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==87){X=0;KIb(Ia,16,2317488,(J=i,i=i+8|0,c[J>>2]=Ea,J)|0);i=J;X=242}else if((X|0)==89){X=0;KIb(Ia,16,2312872,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==91){X=0;QIb(Ia,2308152,(J=i,i=i+8|0,c[J>>2]=La+2,J)|0);i=J;X=242}else if((X|0)==93){X=0;KIb(Ia,16,2303152,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==114){X=0;QIb(c[M>>2]|0,2277048,(J=i,i=i+16|0,c[J>>2]=Pa,c[J+8>>2]=Va,J)|0);i=J;X=242}else if((X|0)==137){X=0;KIb(c[M>>2]|0,16,2468544,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;b[da>>1]=0;X=242}else if((X|0)==141){X=0;KIb(Xa,16,2354160,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==144){X=0;KIb(Xa,16,2345464,(J=i,i=i+8|0,c[J>>2]=Ya,J)|0);i=J;X=242}else if((X|0)==146){X=0;KIb(c[M>>2]|0,16,2339352,(J=i,i=i+8|0,c[J>>2]=_a&255,J)|0);i=J;X=242}else if((X|0)==148){X=0;KIb(c[M>>2]|0,16,2333696,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==180){X=0;KIb(c[M>>2]|0,16,2459240,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==183){X=0;KIb(c[M>>2]|0,16,2442432,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;X=242}else if((X|0)==191){X=0;KIb(c[M>>2]|0,16,2430392,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;a[qb]=0;X=242}else if((X|0)==227){X=0;ya=(-Gb&15)+Gb|0;xa=Fb>>>0>ya>>>0?ya:Fb;c[r>>2]=xa;do{if((I-xa|0)>31){ya=Eb+(xa>>>3)|0;wa=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(xa&7);ya=xa+16|0;O=Fb>>>0>ya>>>0?ya:Fb;c[r>>2]=O;if(!((wa&-65536|0)==-768344064)){t=-1094995529;X=284;break d}wa=Eb+(O>>>3)|0;ya=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(O&7)>>>16;wa=O+16|0;c[r>>2]=Fb>>>0>wa>>>0?wa:Fb;wa=c[(c[M>>2]|0)+48>>2]|0;do{if((wa|0)==86061){if((ya&8192|0)==0){break}O=ya&8191;ca=e[S>>1]|0;b[S>>1]=ca-(O>>>0>ca>>>0?ca:O)}else{if(!((wa|0)!=86045|(ya|0)==53812)){t=-1094995529;X=284;break d}}}while(0);if((B|0)!=(d[D]|0)){break}KIb(c[M>>2]|0,32,2638600,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}}while(0);do{if((a[o+B|0]|0)!=0){if((I-(c[r>>2]|0)|0)!=16){X=282;break d}S=P-2|0;xa=Xqb(R,S)|0;da=Vqb(R,S)|0;S=c[r>>2]|0;ya=c[z>>2]|0;wa=c[u>>2]|0;O=wa+(S>>>3)|0;ca=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(S&7)>>>24;O=S+8|0;S=ya>>>0>O>>>0?O:ya;c[r>>2]=S;if((ca^xa&255|0)==169){Hb=S;Ib=ya;Jb=wa}else{KIb(c[M>>2]|0,16,2616024,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J;Hb=c[r>>2]|0;Ib=c[z>>2]|0;Jb=c[u>>2]|0}wa=Jb+(Hb>>>3)|0;ya=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Hb&7)>>>24;wa=Hb+8|0;c[r>>2]=Ib>>>0>wa>>>0?wa:Ib;if((ya|0)==(da&255|0)){break}KIb(c[M>>2]|0,16,2588840,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J}}while(0);if((I|0)==(c[r>>2]|0)){X=242}else{X=282;break}}if((X|0)==242){X=0;if((a[V]|0)==0){X=243}}if((X|0)==243){X=0;KIb(c[M>>2]|0,16,2567432,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J}da=B+1|0;Kb=d[D]|0;if(da>>>0>Kb>>>0){X=245;break}else{B=da;R=R+P|0}}if((X|0)==203){KIb(c[M>>2]|0,16,2489080,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;t=-1094995529;i=k;return t|0}else if((X|0)==245){R=d[s+24+(Kb*1528|0)+6|0]|0;H=s+24+(Kb*1528|0)+1216|0;T=c[H>>2]|0;do{if((b[s+24+(Kb*1528|0)+2>>1]|0)==0){U=s+24+(Kb*1528|0)+1514|0;if((b[U>>1]|0)==0){Lb=R+2|0;Mb=T;break}Q=s+24+(Kb*1528|0)+1212|0;L=R+1|0;F=R+2|0;N=T;m=0;while(1){C=N>>>7;c[s+6212+(m<<5)+(L<<2)>>2]=N>>>15<<24>>24<<d[Q];c[s+6212+(m<<5)+(F<<2)>>2]=C<<24>>24<<d[Q];da=C&65535;C=(da|N<<16)^da<<5;da=m+1|0;if(da>>>0<(e[U>>1]|0)>>>0){N=C;m=da}else{Lb=F;Mb=C;break}}}else{F=j+16|0;if((c[F>>2]|0)==0){Lb=R;Mb=T;break}else{Nb=T;Ob=0}while(1){m=Nb>>>15&255;a[s+4676+Ob|0]=a[778312+m|0]|0;N=(m|Nb<<8)^m<<5;m=Ob+1|0;if(m>>>0<(c[F>>2]|0)>>>0){Nb=N;Ob=m}else{Lb=R;Mb=N;break}}}}while(0);c[H>>2]=Mb;R=s+24+(Kb*1528|0)+1222|0;T=a[R]|0;if(!(T<<24>>24==0)){F=s+24+(Kb*1528|0)+1514|0;N=j+16|0;m=0;U=T&255;Q=b[F>>1]|0;L=T;while(1){T=a[s+24+(Kb*1528|0)+1496+m|0]|0;P=d[s+24+(Kb*1528|0)+1223+m|0]|0;V=U-m|0;I=V<<1|1;if(Q<<16>>16==0){Pb=0;Qb=L}else{C=-1<<d[s+24+(Kb*1528|0)+1504+P|0];da=0;ya=(T&255)+7|0;if(T<<24>>24==0){T=0;while(1){wa=a[s+4932+(T<<3)+m|0]|0;S=0;xa=0;ca=0;do{O=c[s+6212+(T<<5)+(S<<2)>>2]|0;ea=c[s+24+(Kb*1528|0)+1240+(m<<5)+(S<<2)>>2]|0;fa=Erc(ea,(ea|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;ca=wrc(fa,G,ca,xa)|0;xa=G;S=S+1|0;}while(!(S>>>0>Lb>>>0));S=wrc((ca>>>14|xa<<18)&C,(xa>>>14|0<<18)&da,wa<<24>>24,wa<<24>>24<0|0?-1:0)|0;c[s+6212+(T<<5)+(P<<2)>>2]=S;S=T+1|0;fa=b[F>>1]|0;if(S>>>0<(fa&65535)>>>0){T=S}else{Rb=fa;break}}}else{T=V;fa=0;while(1){S=a[s+4932+(fa<<3)+m|0]|0;O=0;ea=0;ga=0;do{ha=c[s+6212+(fa<<5)+(O<<2)>>2]|0;ia=c[s+24+(Kb*1528|0)+1240+(m<<5)+(O<<2)>>2]|0;ja=Erc(ia,(ia|0)<0|0?-1:0,ha,(ha|0)<0|0?-1:0)|0;ga=wrc(ja,G,ga,ea)|0;ea=G;O=O+1|0;}while(!(O>>>0>Lb>>>0));O=(c[N>>2]|0)-1&T;wa=a[s+4676+O|0]<<ya;xa=wrc(wa,(wa|0)<0|0?-1:0,ga,ea)|0;wa=G;ca=wrc((xa>>>14|wa<<18)&C,(wa>>>14|0<<18)&da,S<<24>>24,S<<24>>24<0|0?-1:0)|0;c[s+6212+(fa<<5)+(P<<2)>>2]=ca;ca=fa+1|0;wa=b[F>>1]|0;if(ca>>>0<(wa&65535)>>>0){T=O+I|0;fa=ca}else{Rb=wa;break}}}Pb=Rb;Qb=a[R]|0}fa=m+1|0;I=Qb&255;if(fa>>>0<I>>>0){m=fa;U=I;Q=Pb;L=Qb}else{break}}}L=d[D]|0;Q=g;U=c[M>>2]|0;m=(c[U+420>>2]|0)==2;R=s+24+(L*1528|0)+6|0;do{if((c[U+416>>2]|0)==((d[R]|0)+1|0)){F=s+24+(L*1528|0)+1514|0;N=b[F>>1]|0;if(N<<16>>16==0){KIb(U,16,2516056,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Sb=-1094995529;break}c[g+76>>2]=N&65535;N=M4a(U,Q,0)|0;if((N|0)<0){Sb=N;break}N=c[g>>2]|0;H=b[F>>1]|0;if(!(H<<16>>16==0)){I=s+24+(L*1528|0)+1524|0;if(m){fa=N;T=0;while(1){P=fa;da=0;while(1){C=d[s+24+(L*1528|0)+7+da|0]|0;ya=c[s+6212+(T<<5)+(C<<2)>>2]<<a[s+24+(L*1528|0)+1516+C|0];c[I>>2]=(ya&16777215)<<C^c[I>>2];Tb=P+4|0;c[P>>2]=ya<<8;ya=da+1|0;if(ya>>>0>(d[R]|0)>>>0){break}else{P=Tb;da=ya}}da=T+1|0;if(da>>>0<(H&65535)>>>0){fa=Tb;T=da}else{break}}}else{T=N;fa=0;while(1){H=T;da=0;P=c[I>>2]|0;while(1){S=d[s+24+(L*1528|0)+7+da|0]|0;ea=c[s+6212+(fa<<5)+(S<<2)>>2]<<a[s+24+(L*1528|0)+1516+S|0];ga=(ea&16777215)<<S^P;c[I>>2]=ga;Ub=H+2|0;b[H>>1]=ea>>>8;ea=da+1|0;if(ea>>>0>(d[R]|0)>>>0){break}else{H=Ub;da=ea;P=ga}}P=fa+1|0;if(P>>>0<(e[F>>1]|0)>>>0){T=Ub;fa=P}else{break}}}}fa=I4a(Q,c[s+24+(L*1528|0)+24>>2]|0)|0;if((fa|0)<0){Sb=fa;break}c[h>>2]=1;Sb=0}else{KIb(U,16,2531264,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Sb=-1094995529}}while(0);t=(Sb|0)<0?Sb:v;i=k;return t|0}else if((X|0)==282){KIb(c[M>>2]|0,16,2549216,(J=i,i=i+8|0,c[J>>2]=B,J)|0);i=J;t=-1094995529;i=k;return t|0}else if((X|0)==284){i=k;return t|0}}}while(0);a[j+8|0]=0;t=-1094995529;i=k;return t|0}function IQa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;k=b;l=(h|0)!=0;m=l?4:8;n=l?73:70;if(!(h>>>0<2>>>0)){KIb(0,0,2420104,(o=i,i=i+24|0,c[o>>2]=2410840,c[o+8>>2]=2403096,c[o+16>>2]=640,o)|0);i=o;Hd();return 0}l=b+4612+(g<<3)+(h<<2)|0;p=c[l>>2]|0;c[l>>2]=p+1;if((p|0)>1){KIb(c[b>>2]|0,16,2396152,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;q=-1094995529;i=j;return q|0}p=e+8|0;l=c[p>>2]|0;r=e+16|0;s=c[r>>2]|0;t=e|0;e=(c[t>>2]|0)+(l>>>3)|0;u=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(l&7);e=u>>>28;v=l+4|0;c[p>>2]=s>>>0>v>>>0?v:s;if(e>>>0>m>>>0){KIb(c[b>>2]|0,16,2389232,(o=i,i=i+24|0,c[o>>2]=n&255,c[o+8>>2]=e,c[o+16>>2]=m,o)|0);i=o;q=-1094995529;i=j;return q|0}a[b+24+(f*1528|0)+28+(g*148|0)+(h*36|0)|0]=e;if((e|0)==0){q=0;i=j;return q|0}m=c[p>>2]|0;s=c[r>>2]|0;v=(c[t>>2]|0)+(m>>>3)|0;l=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(m&7)>>>28;v=m+4|0;c[p>>2]=s>>>0>v>>>0?v:s;a[b+24+(f*1528|0)+28+(g*148|0)+(h*36|0)+1|0]=l;l=c[p>>2]|0;s=c[r>>2]|0;v=c[t>>2]|0;t=v+(l>>>3)|0;m=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(l&7)>>>27;t=l+5|0;l=s>>>0>t>>>0?t:s;c[p>>2]=l;t=v+(l>>>3)|0;w=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(l&7)>>>29;t=l+3|0;l=s>>>0>t>>>0?t:s;c[p>>2]=l;if((m-1|0)>>>0>15>>>0){KIb(c[b>>2]|0,16,2382320,(o=i,i=i+8|0,c[o>>2]=n&255,o)|0);i=o;q=-1094995529;i=j;return q|0}if((w+m|0)>16){KIb(c[b>>2]|0,16,2375712,(o=i,i=i+8|0,c[o>>2]=n&255,o)|0);i=o;q=-1094995529;i=j;return q|0}n=32-m|0;t=0;x=l;l=s;do{s=v+(x>>>3)|0;y=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(x&7)>>n;s=x+m|0;c[p>>2]=l>>>0>s>>>0?s:l;c[b+24+(f*1528|0)+28+(g*148|0)+72+(h<<5)+(t<<2)>>2]=y<<w;t=t+1|0;x=c[p>>2]|0;l=c[r>>2]|0}while((t|0)<(e|0));t=d[v+(x>>>3)|0]|0;w=((x|0)<(l|0))+x|0;c[p>>2]=w;if((t&128>>>((x&7)>>>0)|0)==0){q=0;i=j;return q|0}if((h|0)==0){KIb(c[b>>2]|0,16,2369016,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;q=-1094995529;i=j;return q|0}o=v+(w>>>3)|0;x=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(w&7)>>>28;o=w+4|0;w=l>>>0>o>>>0?o:l;c[p>>2]=w;o=v+(w>>>3)|0;t=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(w&7)>>>28;o=w+4|0;c[p>>2]=l>>>0>o>>>0?o:l;l=32-x|0;if((x|0)==0){mrc(k+((f*1528|0)+(g*148|0)+(h*36|0)+56)|0,0,(u>>>0>536870911>>>0?e<<2:4)|0)|0;q=0;i=j;return q|0}else{u=0;while(1){k=c[p>>2]|0;o=c[r>>2]|0;w=v+(k>>>3)|0;m=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(k&7)>>l;w=k+x|0;c[p>>2]=o>>>0>w>>>0?w:o;c[b+24+(f*1528|0)+28+(g*148|0)+(h*36|0)+4+(u<<2)>>2]=m<<t;m=u+1|0;if((m|0)<(e|0)){u=m}else{q=0;break}}i=j;return q|0}return 0}function JQa(a){a=a|0;c[a>>2]=8;return}function KQa(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=a+672|0;if((h|0)<=0){return}k=(e|0)!=0;l=f;f=g;m=0;if((d|0)!=0){n=j;o=0;p=a;q=i;while(1){r=c[q>>2]|0;s=0;t=0;u=0;do{v=c[p+(s<<2)>>2]|0;w=c[b+(s<<2)>>2]|0;x=Erc(w,(w|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;u=wrc(x,G,u,t)|0;t=G;s=s+1|0;}while(s>>>0<d>>>0);if(k){s=0;x=t;v=u;while(1){w=c[n+(s<<2)>>2]|0;y=c[b+(s+8<<2)>>2]|0;z=Erc(y,(y|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=wrc(z,G,v,x)|0;z=G;y=s+1|0;if(y>>>0<e>>>0){s=y;x=z;v=w}else{A=z;B=w;break}}}else{A=t;B=u}v=Arc(B|0,A|0,l|0)|0;x=G;s=wrc(v,x,r,0)|0;w=s&f;s=w;z=p-4|0;c[z>>2]=s;y=xrc(w,G&m,v,x)|0;x=n-4|0;c[x>>2]=y;c[q>>2]=s;s=o+1|0;if((s|0)<(h|0)){n=x;o=s;p=z;q=q+32|0}else{break}}return}if(k){C=j;D=0;E=a;F=i}else{k=j;j=0;q=a;a=i;while(1){i=c[a>>2]&g;p=q-4|0;c[p>>2]=i;o=k-4|0;c[o>>2]=i;c[a>>2]=i;i=j+1|0;if((i|0)<(h|0)){k=o;j=i;q=p;a=a+32|0}else{break}}return}while(1){a=c[F>>2]|0;q=0;j=0;k=0;do{g=c[C+(q<<2)>>2]|0;p=c[b+(q+8<<2)>>2]|0;i=Erc(p,(p|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;k=wrc(i,G,k,j)|0;j=G;q=q+1|0;}while(q>>>0<e>>>0);q=Arc(k|0,j|0,l|0)|0;r=G;u=wrc(q,r,a,0)|0;t=u&f;u=t;i=E-4|0;c[i>>2]=u;g=xrc(t,G&m,q,r)|0;r=C-4|0;c[r>>2]=g;c[F>>2]=u;u=D+1|0;if((u|0)<(h|0)){C=r;D=u;E=i;F=F+32|0}else{break}}return}function LQa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;a=UHb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function MQa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=c[j>>2]|0;k=c[a+60>>2]|0;l=k;if((f|0)<6){m=-1094995529;i=g;return m|0}n=h;o=(d[n]|d[n+1|0]<<8)<<16>>16;n=h+6|0;if(!((f-6|0)>-1)){KIb(0,0,2450280,(p=i,i=i+24|0,c[p>>2]=2361032,c[p+8>>2]=2296712,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}p=k+1032|0;c[p>>2]=n;c[k+1040>>2]=n;n=k+1036|0;c[n>>2]=h+f;f=k+4|0;h=N4a(a,c[f>>2]|0)|0;if((h|0)<0){m=h;i=g;return m|0}a:do{switch(o&65535|0){case 12:{h=k;a=0;b:while(1){q=0;do{r=c[p>>2]|0;s=c[n>>2]|0;if((s|0)==(r|0)){break a}t=c[h>>2]|0;if((a|0)>=(c[t+124>>2]|0)){break a}u=s;if((u-r|0)<1){v=0;w=r;x=31}else{s=r+1|0;c[p>>2]=s;y=d[r]|0;if((y&128|0)==0){v=y;w=s;x=31}else{z=y;A=1}}do{if((x|0)==31){x=0;y=(v&127)+2|0;if((u-w|0)<1){z=0;A=y;break}c[p>>2]=w+1;z=d[w]|0;A=y}}while(0);u=A<<1;y=c[t+120>>2]|0;if((u|0)>(y-q|0)){m=-1094995529;break b}if((z|0)==0){B=y}else{y=c[f>>2]|0;mrc((c[y>>2]|0)+((ca(c[y+32>>2]|0,a)|0)+q)|0,z&255|0,u|0)|0;B=c[(c[h>>2]|0)+120>>2]|0}q=u+q|0;}while((q|0)<(B|0));a=a+1|0}i=g;return m|0};case 15:{C=OQa(l,1,1)|0;x=54;break};case 8:{a=k;h=0;c:while(1){q=0;do{u=c[p>>2]|0;y=c[n>>2]|0;if((y|0)==(u|0)){break a}s=c[a>>2]|0;if((h|0)>=(c[s+124>>2]|0)){break a}r=y;if((r-u|0)<1){D=0;E=u;x=18}else{y=u+1|0;c[p>>2]=y;F=d[u]|0;if((F&128|0)==0){D=F;E=y;x=18}else{G=F;H=1}}do{if((x|0)==18){x=0;F=(D&127)+2|0;if((r-E|0)<1){G=0;H=F;break}c[p>>2]=E+1;G=d[E]|0;H=F}}while(0);r=c[s+120>>2]|0;if((H|0)>(r-q|0)){m=-1094995529;break c}if((G|0)==0){I=r}else{r=c[f>>2]|0;mrc((c[r>>2]|0)+((ca(c[r+32>>2]|0,h)|0)+q)|0,G&255|0,H|0)|0;I=c[(c[a>>2]|0)+120>>2]|0}q=H+q|0;}while((q|0)<(I|0));h=h+1|0}i=g;return m|0};case 14:{h=k;a=0;d:while(1){q=a|1;r=0;do{t=c[p>>2]|0;F=c[n>>2]|0;if((F|0)==(t|0)){break a}y=c[h>>2]|0;if((a|0)>=(c[y+124>>2]|0)){break a}u=F;if((u-t|0)<1){J=0;K=t;x=44}else{F=t+1|0;c[p>>2]=F;L=d[t]|0;if((L&128|0)==0){J=L;K=F;x=44}else{M=L;N=1}}do{if((x|0)==44){x=0;L=(J&127)+2|0;if((u-K|0)<1){M=0;N=L;break}c[p>>2]=K+1;M=d[K]|0;N=L}}while(0);u=N<<1;s=c[y+120>>2]|0;if((u|0)>(s-r|0)){m=-1094995529;break d}if((M|0)==0){O=s}else{s=c[f>>2]|0;L=M&255;mrc((c[s>>2]|0)+((ca(c[s+32>>2]|0,a)|0)+r)|0,L|0,u|0)|0;s=c[f>>2]|0;mrc((c[s>>2]|0)+((ca(c[s+32>>2]|0,q)|0)+r)|0,L|0,u|0)|0;O=c[(c[h>>2]|0)+120>>2]|0}r=u+r|0;}while((r|0)<(O|0));a=a+2|0}i=g;return m|0};case 5:{C=OQa(l,0,0)|0;x=54;break};case 13:{C=OQa(l,1,0)|0;x=54;break};case 49:{a=c[n>>2]|0;h=c[p>>2]|0;r=a-h|0;q=h+(r>>>0>4>>>0?4:r)|0;c[p>>2]=q;r=0;h=a;a=q;while(1){if((h-a|0)<3){P=-16777216}else{c[p>>2]=a+3;P=(d[a]|0)<<16|(d[a+1|0]|0)<<8|(d[a+2|0]|0)|-16777216}c[l+8+(r<<2)>>2]=P;c[l+8+(r+128<<2)>>2]=P<<2;q=r+1|0;if((q|0)>=128){break}r=q;h=c[n>>2]|0;a=c[p>>2]|0}m=c[j>>2]|0;i=g;return m|0};default:{m=-1094995529;i=g;return m|0}}}while(0);do{if((x|0)==54){if((C|0)<0){m=C}else{break}i=g;return m|0}}while(0);nrc(c[(c[f>>2]|0)+4>>2]|0,k+8|0,1024)|0;k=YHb(b,c[f>>2]|0)|0;if((k|0)<0){m=k;i=g;return m|0}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function NQa(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function OQa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;h=b+1036|0;j=b+1032|0;k=c[j>>2]|0;l=c[h>>2]|0;if((l-k|0)<2){m=0;n=k}else{o=k+2|0;c[j>>2]=o;p=k;m=(d[p]|d[p+1|0]<<8)<<16>>16&65535;n=o}o=l-n|0;if(o>>>0<m>>>0){q=-1094995529;i=g;return q|0}l=n+m|0;if(!((o-m|0)>-1)){KIb(0,0,2450280,(m=i,i=i+24|0,c[m>>2]=2361032,c[m+8>>2]=2296712,c[m+16>>2]=135,m)|0);i=m;Hd();return 0}m=b|0;p=f+1|0;k=e+1|0;r=n+o|0;o=b+4|0;b=(e|0)!=0;s=(f|0)==0;t=0;u=l;v=n;a:while(1){n=t;w=v;while(1){if(!(w>>>0<l>>>0)){q=0;x=32;break a}y=c[h>>2]|0;z=y;if((z-w|0)<1){A=0;B=w}else{C=w+1|0;c[j>>2]=C;A=d[w]|0;B=C}if((z-B|0)<1){D=0;E=B}else{z=B+1|0;c[j>>2]=z;D=d[B]|0;E=z}F=D|A<<1&256;G=A&127;if((G|0)==0){n=F+n|0;w=E}else{break}}if((n+f|0)>=(c[(c[m>>2]|0)+124>>2]|0)){q=0;x=32;break}w=n+1|0;z=u;C=F;H=1;I=y;J=E;while(1){if((I-J|0)<1){K=0}else{c[j>>2]=J+1;K=d[J]|0}L=z;M=0;N=C;while(1){if((N+e|0)>=(c[(c[m>>2]|0)+120>>2]|0)){q=-1094995529;x=32;break a}do{if((1<<7-M&K|0)==0){O=L}else{if((r-L|0)<1){P=0;Q=L}else{P=a[L]|0;Q=L+1|0}R=c[o>>2]|0;S=(ca(c[R+32>>2]|0,n)|0)+N|0;a[(c[R>>2]|0)+S|0]=P;if(b){S=c[o>>2]|0;R=N+1+(ca(c[S+32>>2]|0,n)|0)|0;a[(c[S>>2]|0)+R|0]=P}if(s){O=Q;break}R=c[o>>2]|0;S=(ca(c[R+32>>2]|0,w)|0)+N|0;a[(c[R>>2]|0)+S|0]=P;if(!b){O=Q;break}S=c[o>>2]|0;R=N+1+(ca(c[S+32>>2]|0,w)|0)|0;a[(c[S>>2]|0)+R|0]=P;O=Q}}while(0);T=k+N|0;R=M+1|0;if((R|0)<8){L=O;M=R;N=T}else{break}}if((H|0)>=(G|0)){break}z=O;C=T;H=H+1|0;I=c[h>>2]|0;J=c[j>>2]|0}t=p+n|0;u=O;v=c[j>>2]|0}if((x|0)==32){i=g;return q|0}return 0}function PQa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;f=b+60|0;g=c[f>>2]|0;h=b+120|0;j=b+124|0;k=(c[j>>2]|0)+3&-4;if((c[b+100>>2]|0)<2){KIb(b,16,2245760,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=e;return m|0}l=(c[h>>2]|0)+3&-4;if((a[5689906]|0)==0){n=0;while(1){o=n*1e3|0;p=n&255;q=-31;do{r=((q*701|0)+o|0)/1e3|0;s=(q*-357|0)+o|0;t=r<<10;u=q&255;v=-31;do{w=(s+(v*-172|0)|0)/1e3|0;x=((v*886|0)+o|0)/1e3|0;do{if((w|r|x)>>>0<32>>>0){y=w<<5|t|x;if((y|0)>=32768){break}z=5689906+(y*3|0)|0;A=5689905+(y*3|0)|0;B=5689904+(y*3|0)|0;if(!((a[A]|a[z]|a[B])<<24>>24==0)){break}a[B]=p;a[A]=u;a[z]=v}}while(0);v=v+1|0;}while((v|0)<32);q=q+1|0;}while((q|0)<32);q=n+1|0;if((q|0)<32){n=q}else{C=0;break}}do{n=C<<5;q=0;do{p=31;do{o=p+n|0;v=5689904+(o*3|0)|0;p=p-1|0;if((a[5689905+(o*3|0)|0]|a[5689906+(o*3|0)|0]|a[v])<<24>>24==0){o=5689904+((p+n|0)*3|0)|0;a[v]=a[o]|0;a[v+1|0]=a[o+1|0]|0;a[v+2|0]=a[o+2|0]|0}}while((p|0)>(q|0));p=31-q|0;o=0;do{v=o+n|0;u=5689904+(v*3|0)|0;o=o+1|0;if((a[5689905+(v*3|0)|0]|a[5689906+(v*3|0)|0]|a[u])<<24>>24==0){v=5689904+((o+n|0)*3|0)|0;a[u]=a[v]|0;a[u+1|0]=a[v+1|0]|0;a[u+2|0]=a[v+2|0]|0}}while((o|0)<(p|0));q=q+1|0;}while((q|0)<31);C=C+1|0;}while((C|0)<1024)}c[g>>2]=b;l8(g+8|0,b);C=g+1252|0;q=C;c[q>>2]=pJb(ca(c[h>>2]|0,k)|0)|0;n=ca(c[j>>2]|0,c[h>>2]|0)|0;h=n>>>0>65535>>>0;p=h?n>>>16:n;n=h?16:0;if((p&65280|0)==0){D=n;E=p}else{D=n|8;E=p>>>8}c[g+1256>>2]=D+1+(d[1359664+E|0]|0);E=g+1420|0;D=E;c[D>>2]=pJb((c[j>>2]|0)*3|0)|0;j=pJb(((ca(l,k)|0)/16|0)*3|0)|0;k=g+1424|0;c[k>>2]=j;do{if((c[q>>2]|0)!=0){if((c[D>>2]|0)==0|(j|0)==0){break}c[b+140>>2]=46;l=UHb()|0;c[g+4>>2]=l;if((l|0)!=0){m=0;i=e;return m|0}l=c[f>>2]|0;mJb(l+1252|0);mJb(l+1420|0);mJb(l+1424|0);mJb(l+1432|0);VHb(l+4|0);m=-12;i=e;return m|0}}while(0);mJb(C);mJb(E);mJb(k);m=-12;i=e;return m|0}function QQa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0;k=i;i=i+24|0;l=k|0;m=c[j+24>>2]|0;n=c[j+28>>2]|0;j=c[f+60>>2]|0;o=j;p=j+4|0;q=N4a(f,c[p>>2]|0)|0;if((q|0)<0){r=q;i=k;return r|0}q=j+1432|0;s=q;A4a(q,j+1436|0,n);q=c[s>>2]|0;if((q|0)==0){r=-12;i=k;return r|0}ef[c[j+1104>>2]&4095](q,m,(n|0)/4|0);q=n&3;if((q|0)!=0){t=n&-4;nrc((c[s>>2]|0)+t|0,m+t|0,q)|0}q=c[s>>2]|0;s=n<<3;t=s>>>0>2147483639>>>0|(q|0)==0;m=t?0:q;q=t?0:s;s=l|0;c[s>>2]=m;c[l+12>>2]=q;t=q+8|0;u=l+16|0;c[u>>2]=t;c[l+4>>2]=m+(q>>3);q=l+8|0;c[q>>2]=0;v=j+1252|0;mrc(c[v>>2]|0,0,ca(c[f+124>>2]|0,c[f+120>>2]|0)|0)|0;w=f+96|0;f=m;x=je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;f=((d[(c[w>>2]|0)+1|0]|0)>>>1&1^1)&255;y=0;z=t;t=x;x=m;do{m=y+12|0;A=z>>>0>m>>>0?m:z;m=x+(A>>>3)|0;B=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(A&7)>>>20;m=A+12|0;c[q>>2]=z>>>0>m>>>0?m:z;SQa(o,l,t>>>20,8,f);SQa(o,l,B,4,f);f=f+1|0;y=c[q>>2]|0;z=c[u>>2]|0;x=c[s>>2]|0;B=x+(y>>>3)|0;t=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)}while((f|0)<2);f=y+4|0;y=t>>>28;t=z>>>0>f>>>0?f:z;c[q>>2]=t;f=j+1260|0;c[f>>2]=y;a:do{if((y|0)!=0){B=c[v>>2]|0;if((a[B]|0)==0){m=x+(t>>>3)|0;A=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(t&7)>>>17;m=t+15|0;C=z>>>0>m>>>0?m:z;c[q>>2]=C;b[c[c[p>>2]>>2]>>1]=A;a[B]=1;D=c[f>>2]|0;E=C}else{D=y;E=t}C=x+(E>>>3)|0;B=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>28;C=E+4|0;A=z>>>0>C>>>0?C:z;c[q>>2]=A;do{if((D|0)==1){a[j+1277|0]=B;F=1;G=A;H=z;I=x}else{c[j+1268>>2]=B;if((D|0)>0){C=0;m=A;do{J=x+(m>>>3)|0;K=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(m&7)>>>28;J=m+4|0;m=z>>>0>J>>>0?J:z;a[o+1272+(C<<3)+5|0]=K;C=C+1|0;}while((C|0)<(c[f>>2]|0));c[q>>2]=m}C=j+1264|0;c[C>>2]=0;if((TQa(o,l,0,0)|0)<0){break a}K=c[f>>2]|0;if((c[C>>2]|0)<(K|0)){KIb(c[j>>2]|0,16,2450264,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;break a}else{F=K;G=c[q>>2]|0;H=c[u>>2]|0;I=c[s>>2]|0;break}}}while(0);A=I+(G>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(G&7)>>>14;A=G+18|0;K=H>>>0>A>>>0?A:H;c[q>>2]=K;if((a[c[w>>2]|0]|0)==5){L=B;M=K}else{A=I+(K>>>3)|0;C=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(K&7)>>>14;A=K+18|0;K=H>>>0>A>>>0?A:H;c[q>>2]=K;L=C+B|0;M=K}if((L|0)==0){break}K=j+1268|0;B=c[K>>2]|0;if((B|0)<1){break}C=j+1400|0;if(($2(C,B,F,j+1276|0,8,1,j+1272|0,8,4,0,0,0,0)|0)!=0){break}B=j;A=c[B>>2]|0;if((c[A+124>>2]|0)>0){J=j+1428|0;N=j+1429|0;O=j+1430|0;P=j+1404|0;Q=j+1420|0;R=0;S=0;T=0;U=0;V=A;W=M;X=H;Y=H;while(1){Z=ca(c[V+120>>2]|0,U)|0;if((a[(c[v>>2]|0)+Z|0]|0)==0){Z=(c[f>>2]|0)==1;if(Z){_=0;$=W;aa=X;ba=Y}else{da=c[P>>2]|0;ea=c[K>>2]|0;fa=I+(W>>>3)|0;ga=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(W&7)>>>((32-ea|0)>>>0);ea=b[da+(ga<<2)>>1]|0;fa=(b[da+(ga<<2)+2>>1]|0)+W|0;ga=H>>>0>fa>>>0?fa:H;c[q>>2]=ga;_=ea;$=ga;aa=H;ba=H}ga=a[o+1272+(_<<3)+5|0]|0;ea=ca(d[J]|0,(ga&255)-7|0)|0;if(ga<<24>>24==0){ha=2}else{ha=ga<<24>>24==14?2:1}a[J]=ha;ga=ea+(T&255)|0;ea=ga<<24;if((ea|0)<0){ia=0}else{ia=(ea|0)>520093696?31:ga&255}do{if((U&3|0)==0){if(Z){ja=0;ka=$;la=aa}else{ga=c[P>>2]|0;ea=c[K>>2]|0;fa=I+($>>>3)|0;da=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<($&7)>>>((32-ea|0)>>>0);ea=b[ga+(da<<2)>>1]|0;fa=(b[ga+(da<<2)+2>>1]|0)+$|0;da=ba>>>0>fa>>>0?fa:ba;c[q>>2]=da;ja=ea;ka=da;la=ba}da=a[o+1272+(ja<<3)+5|0]|0;ea=ca(d[N]|0,(da&255)-7|0)|0;if(da<<24>>24==0){ma=2}else{ma=da<<24>>24==14?2:1}a[N]=ma;da=ea+(S&255)|0;ea=da<<24;if((ea|0)<-536870912){na=-32}else{na=(ea|0)>520093696?31:da&255}if(Z){oa=0;pa=ka}else{da=c[P>>2]|0;ea=c[K>>2]|0;fa=I+(ka>>>3)|0;ga=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ka&7)>>>((32-ea|0)>>>0);ea=b[da+(ga<<2)>>1]|0;fa=(b[da+(ga<<2)+2>>1]|0)+ka|0;ga=la>>>0>fa>>>0?fa:la;c[q>>2]=ga;oa=ea;pa=ga}ga=a[o+1272+(oa<<3)+5|0]|0;ea=ca(d[O]|0,(ga&255)-7|0)|0;if(ga<<24>>24==0){qa=2}else{qa=ga<<24>>24==14?2:1}a[O]=qa;ga=ea+(R&255)|0;ea=ga<<24;if((ea|0)<-536870912){ra=na;sa=-32;ta=pa;ua=la;break}ra=na;sa=(ea|0)>520093696?31:ga&255;ta=pa;ua=la}else{ra=S;sa=R;ta=$;ua=aa}}while(0);Z=(c[Q>>2]|0)+(U*3|0)|0;a[Z]=ia;a[Z+1|0]=ra;a[Z+2|0]=sa;Z=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;m=ra<<24>>24;ga=sa<<24>>24;ea=(ia<<24>>24)*1e3|0;b[(c[Z>>2]|0)+(ca(c[Z+32>>2]|0,U)|0)>>1]=d[((((ga*-172|0)+ea+(m*-357|0)|0)/1e3|0)<<3)+1404400|0]<<2&992|d[((((m*701|0)+ea|0)/1e3|0)<<3)+1404400|0]<<7&31744|(a[((((ga*886|0)+ea|0)/1e3|0)<<3)+1404400|0]&255)>>>3;va=ia;wa=ra;xa=sa;ya=c[B>>2]|0;za=ta;Aa=ua;Ba=ba}else{mrc(J|0,1,3)|0;ea=c[p>>2]|0;ga=5689904+((e[(c[ea>>2]|0)+(ca(c[ea+32>>2]|0,U)|0)>>1]|0)*3|0)|0;va=a[ga]|0;wa=a[ga+1|0]|0;xa=a[ga+2|0]|0;ya=V;za=W;Aa=X;Ba=Y}ga=U+1|0;if((ga|0)<(c[ya+124>>2]|0)){R=xa;S=wa;T=va;U=ga;V=ya;W=za;X=Aa;Y=Ba}else{Ca=ya;Da=Q;Ea=J;Fa=N;Ga=O;Ha=P;Ia=za;break}}}else{Ca=A;Da=j+1420|0;Ea=j+1428|0;Fa=j+1429|0;Ga=j+1430|0;Ha=j+1404|0;Ia=M}P=j+1424|0;O=0;N=Ca;J=Ia;Q=H;Y=H;while(1){if((O|0)<(c[N+124>>2]|0)){X=O;W=N;V=J;U=Q;T=Y;while(1){S=W+120|0;R=c[S>>2]|0;ga=ca(R,X)|0;ea=(c[Da>>2]|0)+(X*3|0)|0;m=a[ea]|0;Z=a[ea+1|0]|0;fa=a[ea+2|0]|0;ea=c[v>>2]|0;if((a[ea+ga|0]|0)==0){mrc(Ea|0,1,3)|0;Ja=1;Ka=c[S>>2]|0}else{Ja=0;Ka=R}b:do{if((Ja|0)<(Ka|0)){R=(X&3|0)==0;S=(X|0)/4|0;da=fa;La=Z;Ma=m;Na=Ja;Oa=Ka;Pa=W;Qa=ea;Ra=V;Sa=U;Ta=T;while(1){Ua=Na+ga|0;Va=a[Qa+Ua|0]|0;Wa=Va&255;if(Va<<24>>24==0){if((c[f>>2]|0)==1){Xa=0;Ya=Ra;Za=Sa;_a=Ta}else{$a=c[Ha>>2]|0;ab=c[K>>2]|0;bb=I+(Ra>>>3)|0;cb=(je(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(Ra&7)>>>((32-ab|0)>>>0);ab=b[$a+(cb<<2)>>1]|0;bb=(b[$a+(cb<<2)+2>>1]|0)+Ra|0;cb=H>>>0>bb>>>0?bb:H;c[q>>2]=cb;Xa=ab;Ya=cb;Za=H;_a=H}cb=a[o+1272+(Xa<<3)+5|0]|0;ab=ca(d[Ea]|0,(cb&255)-7|0)|0;if(cb<<24>>24==0){db=2}else{db=cb<<24>>24==14?2:1}a[Ea]=db;cb=ab+(Ma&255)|0;ab=cb<<24;if((ab|0)<0){eb=0}else{eb=(ab|0)>520093696?31:cb&255}do{if((Na&3|0)==0){if(!R){cb=((ca(c[Pa+120>>2]|0,S)|0)+Na|0)/4|0;ab=c[P>>2]|0;fb=a[ab+(cb*3|0)+1|0]|0;gb=a[ab+(cb*3|0)+2|0]|0;hb=Ya;ib=Za;break}if((c[f>>2]|0)==1){jb=0;kb=Ya;lb=Za}else{cb=c[Ha>>2]|0;ab=c[K>>2]|0;bb=I+(Ya>>>3)|0;$a=(je(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(Ya&7)>>>((32-ab|0)>>>0);ab=b[cb+($a<<2)>>1]|0;bb=(b[cb+($a<<2)+2>>1]|0)+Ya|0;$a=_a>>>0>bb>>>0?bb:_a;c[q>>2]=$a;jb=ab;kb=$a;lb=_a}$a=a[o+1272+(jb<<3)+5|0]|0;ab=ca(d[Fa]|0,($a&255)-7|0)|0;if($a<<24>>24==0){mb=2}else{mb=$a<<24>>24==14?2:1}a[Fa]=mb;$a=ab+(La&255)|0;ab=$a<<24;if((ab|0)<-536870912){nb=-32}else{nb=(ab|0)>520093696?31:$a&255}if((c[f>>2]|0)==1){ob=0;pb=kb}else{$a=c[Ha>>2]|0;ab=c[K>>2]|0;bb=I+(kb>>>3)|0;cb=(je(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(kb&7)>>>((32-ab|0)>>>0);ab=b[$a+(cb<<2)>>1]|0;bb=(b[$a+(cb<<2)+2>>1]|0)+kb|0;cb=lb>>>0>bb>>>0?bb:lb;c[q>>2]=cb;ob=ab;pb=cb}cb=a[o+1272+(ob<<3)+5|0]|0;ab=ca(d[Ga]|0,(cb&255)-7|0)|0;if(cb<<24>>24==0){qb=2}else{qb=cb<<24>>24==14?2:1}a[Ga]=qb;cb=ab+(da&255)|0;ab=cb<<24;if((ab|0)<-536870912){rb=-32}else{rb=(ab|0)>520093696?31:cb&255}cb=((ca(c[Pa+120>>2]|0,S)|0)+Na|0)/4|0;ab=(c[P>>2]|0)+(cb*3|0)|0;a[ab]=eb;a[ab+1|0]=nb;a[ab+2|0]=rb;fb=nb;gb=rb;hb=pb;ib=lb}else{fb=La;gb=da;hb=Ya;ib=Za}}while(0);ab=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;cb=fb<<24>>24;bb=gb<<24>>24;$a=(eb<<24>>24)*1e3|0;b[(c[ab>>2]|0)+((ca(c[ab+32>>2]|0,X)|0)+(Na<<1))>>1]=d[((((bb*-172|0)+$a+(cb*-357|0)|0)/1e3|0)<<3)+1404400|0]<<2&992|d[((((cb*701|0)+$a|0)/1e3|0)<<3)+1404400|0]<<7&31744|(a[((((bb*886|0)+$a|0)/1e3|0)<<3)+1404400|0]&255)>>>3;sb=Na+1|0;tb=eb;ub=fb;vb=gb;wb=hb;xb=ib;yb=_a}else{c:do{if(R){do{if(!((d[Qa+(Ua+Oa)|0]|0)>>>0<(Va&255)>>>0)){if((d[Qa+(Ua+(Oa<<1))|0]|0)>>>0<(Va&255)>>>0){break}if(!((d[Qa+(Ua+(Oa*3|0))|0]|0)>>>0<(Va&255)>>>0)){break c}}}while(0);$a=Na+3&-4;bb=Wa+Na|0;if(($a|0)<(bb|0)){zb=$a;Ab=Oa}else{break}while(1){$a=((ca(Ab,S)|0)+zb|0)/4|0;cb=c[p>>2]|0;orc((c[P>>2]|0)+($a*3|0)|0,5689904+((e[(c[cb>>2]|0)+((ca(c[cb+32>>2]|0,X)|0)+(zb<<1))>>1]|0)*3|0)|0,3)|0;cb=zb+4|0;if((cb|0)>=(bb|0)){break c}zb=cb;Ab=c[(c[B>>2]|0)+120>>2]|0}}}while(0);Va=Wa+Na|0;mrc(Ea|0,1,3)|0;Ua=c[p>>2]|0;bb=5689904+((e[(c[Ua>>2]|0)+((Va<<1)-2+(ca(c[Ua+32>>2]|0,X)|0))>>1]|0)*3|0)|0;sb=Va;tb=a[bb]|0;ub=a[bb+1|0]|0;vb=a[bb+2|0]|0;wb=Ra;xb=Sa;yb=Ta}bb=c[B>>2]|0;Va=c[bb+120>>2]|0;if((sb|0)>=(Va|0)){Bb=bb;Cb=wb;Db=xb;Eb=yb;break b}da=vb;La=ub;Ma=tb;Na=sb;Oa=Va;Pa=bb;Qa=c[v>>2]|0;Ra=wb;Sa=xb;Ta=yb}}else{Bb=W;Cb=V;Db=U;Eb=T}}while(0);ga=X+2|0;if((ga|0)<(c[Bb+124>>2]|0)){X=ga;W=Bb;V=Cb;U=Db;T=Eb}else{Fb=Bb;Gb=Cb;Hb=Db;Ib=Eb;break}}}else{Fb=N;Gb=J;Hb=Q;Ib=Y}T=O+1|0;if((T|0)<2){O=T;N=Fb;J=Gb;Q=Hb;Y=Ib}else{break}}c3(C)}}while(0);Ib=YHb(g,c[p>>2]|0)|0;if((Ib|0)<0){r=Ib;i=k;return r|0}c[h>>2]=1;r=n;i=k;return r|0}function RQa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+1252|0);mJb(b+1420|0);mJb(b+1424|0);mJb(b+1432|0);VHb(b+4|0);return 0}function SQa(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((g|0)==0){return}j=e+1256|0;k=f+8|0;l=f+16|0;m=f|0;f=32-h|0;n=(i|0)!=0;i=e|0;o=e+4|0;p=e+1252|0;e=0;q=g;while(1){g=q-1|0;r=c[j>>2]|0;do{if((r|0)==0){s=0;t=c[k>>2]|0;u=c[l>>2]|0;v=c[m>>2]|0}else{w=c[k>>2]|0;x=c[l>>2]|0;y=c[m>>2]|0;z=y+(w>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7);if((r|0)<26){z=w+r|0;B=x>>>0>z>>>0?z:x;c[k>>2]=B;s=A>>>((32-r|0)>>>0);t=B;u=x;v=y;break}else{B=w+16|0;w=x>>>0>B>>>0?B:x;c[k>>2]=w;B=r-16|0;z=y+(w>>>3)|0;C=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7)>>>((48-r|0)>>>0);z=w+B|0;w=x>>>0>z>>>0?z:x;c[k>>2]=w;s=C|A>>>16<<B;t=w;u=x;v=y;break}}}while(0);r=v+(t>>>3)|0;y=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7)>>>(f>>>0);r=t+h|0;x=u>>>0>r>>>0?r:u;c[k>>2]=x;r=y+1|0;y=v+(x>>>3)|0;w=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>(f>>>0);y=x+h|0;x=u>>>0>y>>>0?y:u;c[k>>2]=x;y=w+1|0;if(n){w=v+(x>>>3)|0;B=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(x&7)>>>17;w=x+15|0;c[k>>2]=u>>>0>w>>>0?w:u;D=B&65535}else{D=e}B=c[i>>2]|0;w=c[B+120>>2]|0;x=(s|0)%(w|0)|0;A=(s|0)/(w|0)|0;C=c[B+124>>2]|0;a:do{if((A|0)<(C|0)){B=w-x|0;z=(r|0)>(B|0)?B:r;B=C-A|0;E=(y|0)>(B|0)?B:y;B=c[o>>2]|0;F=(ca(c[B+32>>2]|0,A)|0)+(x<<1)|0;G=(c[B>>2]|0)+F|0;F=E-1|0;if((E|0)==0){break}E=z&255;B=(z|0)>0;if(!n){if(B){H=s;I=F;while(1){a[(c[p>>2]|0)+H|0]=E;if((I|0)==0){break a}else{H=(c[(c[i>>2]|0)+120>>2]|0)+H|0;I=I-1|0}}}else{I=s;H=F;while(1){a[(c[p>>2]|0)+I|0]=E;if((H|0)==0){break a}else{I=(c[(c[i>>2]|0)+120>>2]|0)+I|0;H=H-1|0}}}}if(B){J=s;K=G;L=F}else{H=s;I=F;while(1){a[(c[p>>2]|0)+H|0]=E;if((I|0)==0){break a}else{H=(c[(c[i>>2]|0)+120>>2]|0)+H|0;I=I-1|0}}}while(1){a[(c[p>>2]|0)+J|0]=E;I=0;do{b[K+(I<<1)>>1]=D;I=I+1|0;}while((I|0)<(z|0));if((L|0)==0){break}else{J=(c[(c[i>>2]|0)+120>>2]|0)+J|0;K=K+(((c[(c[o>>2]|0)+32>>2]|0)/2|0)<<1)|0;L=L-1|0}}}}while(0);if((g|0)==0){break}else{e=D;q=g}}return}function TQa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=e+8|0;k=e|0;l=e+16|0;m=b+1268|0;n=g;g=f;while(1){f=c[j>>2]|0;o=d[(c[k>>2]|0)+(f>>>3)|0]|0;c[j>>2]=((f|0)<(c[l>>2]|0))+f;if((o&128>>>((f&7)>>>0)|0)==0){p=6;break}q=g+1|0;r=c[m>>2]|0;if((q|0)>(r|0)){p=4;break}f=n<<1;if((TQa(b,e,q,f|1)|0)<0){s=-1094995529;p=9;break}else{n=f;g=q}}if((p|0)==4){KIb(c[b>>2]|0,16,2361e3,(t=i,i=i+16|0,c[t>>2]=q,c[t+8>>2]=r,t)|0);i=t;s=-1094995529;i=h;return s|0}else if((p|0)==6){r=b+1264|0;q=c[r>>2]|0;if((q|0)>15){KIb(c[b>>2]|0,16,2296696,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;s=-1094995529;i=h;return s|0}else{c[b+1272+(q<<3)>>2]=n;n=c[r>>2]|0;c[r>>2]=n+1;a[b+1272+(n<<3)+4|0]=g;s=0;i=h;return s|0}}else if((p|0)==9){i=h;return s|0}return 0}function UQa(a){a=a|0;return dmb(a)|0}function VQa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;i=i+1040|0;j=h|0;k=h+1024|0;l=h+1032|0;m=e;n=c[g+24>>2]|0;if((n|0)==0){o=-1094995529;i=h;return o|0}p=g+28|0;q=c[p>>2]|0;if((q|0)<2){o=-1094995529;i=h;return o|0}r=n;s=(d[r]|d[r+1|0]<<8)<<16>>16;if((q|0)==2){o=s<<16>>16==0?0:-1094995529;i=h;return o|0}r=((he(s|0)|0)&65535)+2|0;s=(r|0)>(q|0)?q:r;r=n+s|0;q=g+8|0;t=c[q>>2]|0;u=c[q+4>>2]|0;v=b+104|0;c[k>>2]=1;c[k+4>>2]=100;b=XIb(t,u,v,k)|0;k=b;b=c[g+48>>2]|0;g=wrc(b,(b|0)<0|0?-1:0,c[q>>2]|0,c[q+4>>2]|0)|0;c[l>>2]=1;c[l+4>>2]=100;q=XIb(g,G,v,l)|0;SFb(j,0,-1);if((s|0)>2){s=n+2|0;do{n=a[s]|0;l=n<<24>>24;if((l|0)==10){UFb(j,2450256,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}else if((l|0)!=13){WFb(j,n,1)}s=s+1|0;}while(s>>>0<r>>>0)}UFb(j,2360992,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if(!((c[j+4>>2]|0)>>>0<(c[j+8>>2]|0)>>>0)){o=-12;i=h;return o|0}fmb(m,c[j>>2]|0,k,q-k|0,0)|0;c[f>>2]=(c[e+12>>2]|0)!=0;_Fb(j,0)|0;o=c[p>>2]|0;i=h;return o|0}function WQa(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;d=a+100|0;c[d>>2]=48;e=pJb(48)|0;c[a+96>>2]=e;if((e|0)==0){f=-12;return f|0}nrc(e|0,822504,c[d>>2]|0)|0;d=hmb(c[a+860>>2]|0)|0;c[b>>2]=d;f=(d|0)!=0?0:-1094995529;return f|0}function XQa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+8|0;h=g|0;j=c[b+60>>2]|0;k=j+4|0;l=j+2052|0;m=l;c[m>>2]=k;c[j+2056>>2]=l;l=f+12|0;if((c[l>>2]|0)==0){n=0;i=g;return n|0}o=f+16|0;f=j;p=0;do{q=c[(c[o>>2]|0)+(p<<2)>>2]|0;if((c[q+84>>2]|0)!=3){r=4;break}s=kmb(c[f>>2]|0,c[q+92>>2]|0,0,h)|0;a:do{if((s|0)!=0){q=s;do{t=c[h>>2]|0;c[h>>2]=t-1;if((t|0)==0){break a}mmb(822552,j,c[q+16>>2]|0)|0;q=q+20|0;}while((q|0)!=0)}}while(0);p=p+1|0;}while(p>>>0<(c[l>>2]|0)>>>0);if((r|0)==4){KIb(b,16,2450216,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;n=-38;i=g;return n|0}if((c[m>>2]|0)==(k|0)){n=0;i=g;return n|0}m=d;y=he((lrc(k|0)|0)&65535|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;m=CFb(d+2|0,k,e-2|0)|0;if((m|0)>(e-3|0)){KIb(b,16,2360952,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;n=-22;i=g;return n|0}else{n=m+2|0;i=g;return n|0}return 0}function YQa(a){a=a|0;jmb(c[c[a+60>>2]>>2]|0);return 0}function ZQa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a+2056|0;g=c[f>>2]|0;h=a+2052|0;a=c[h>>2]|0;if(g>>>0<a>>>0){KIb(0,0,2296664,(j=i,i=i+24|0,c[j>>2]=2245736,c[j+8>>2]=2204216,c[j+16>>2]=91,j)|0);i=j;Hd()}else{j=g-a|0;g=d+1|0;CFb(a,b,(j|0)>(g|0)?g:j)|0;j=c[h>>2]|0;g=(c[f>>2]|0)-j|0;c[h>>2]=j+((g|0)>(d|0)?d:g);i=e;return}}function _Qa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;b=i;d=a+2056|0;e=c[d>>2]|0;f=a+2052|0;a=c[f>>2]|0;if(e>>>0<a>>>0){KIb(0,0,2296664,(g=i,i=i+24|0,c[g>>2]=2245736,c[g+8>>2]=2204216,c[g+16>>2]=99,g)|0);i=g;Hd()}g=e-a|0;CFb(a,2172296,(g|0)>2?2:g)|0;g=c[f>>2]|0;if(!((c[d>>2]|0)>>>0>g>>>0)){i=b;return}c[f>>2]=g+1;i=b;return}function $Qa(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;h=g|0;j=c[b+60>>2]|0;k=g;l=c[b+416>>2]|0;if((l|0)!=2){QIb(b,2204200,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1163346256;i=f;return n|0}l=c[b+100>>2]|0;if((l|0)<16){KIb(b,16,2172264,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1;i=f;return n|0}mrc(j+1316|0,0,256)|0;AIb(j+12468|0,-559038737);l8(j,b);PSa(j+1244|0);ef[c[j+1096>>2]&4095](h,c[b+96>>2]|0,4);zrb();l=(d[k]|0)>>>7;c[j+1288>>2]=l;o=(d[k]|0)>>>6&1;c[j+1292>>2]=o;k=c[h>>2]&63;c[j+1304>>2]=k;if(k>>>0>31>>>0){KIb(b,16,2144688,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;n=-1;i=f;return n|0}h=g+12|0;g=(d[h]|0)>>>7;c[j+1296>>2]=g;p=(je(c[h>>2]|0)|0)>>>20&2047;c[j+1300>>2]=p;h=b;KIb(h,48,2121056,(m=i,i=i+40|0,c[m>>2]=l,c[m+8>>2]=o,c[m+16>>2]=g,c[m+24>>2]=p,c[m+32>>2]=k,m)|0);i=m;c[j+12728>>2]=0;c[b+420>>2]=6;j=b+448|0;c[j>>2]=3;c[j+4>>2]=0;if(a[812160]|0){n=0;i=f;return n|0}KIb(h,48,2638584,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;c[1280449]=5658648;c[1280451]=8;if(($2(5121792,3,4,808329,2,1,808328,2,1,0,0,0,4)|0)!=0){KIb(h,16,2616e3,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=f;return n|0}c[2333741]=5689624;c[2333743]=64;if(($2(9334960,6,16,812129,2,1,812128,2,1,0,0,0,4)|0)!=0){KIb(h,16,2588808,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=f;return n|0}c[1487399]=5687576;c[1487401]=512;if(($2(5949592,9,10,812105,2,1,812104,2,1,0,0,0,4)|0)==0){q=0}else{KIb(h,16,2567408,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=f;return n|0}a:while(1){j=q<<1;b=808336+q|0;r=0;while(1){if((r|0)>=2){break}k=r+j|0;p=e[687856+(k<<1)>>1]|0;c[5413776+(q*40|0)+(r*20|0)+4>>2]=5658680+(p<<2);c[5413776+(q*40|0)+(r*20|0)+12>>2]=(e[687856+(k+1<<1)>>1]|0)-p;if(($2(5413776+(q*40|0)+(r*20|0)|0,9,d[b]|0,808360+(q<<9)+(r<<8)+2|0,4,2,808360+(q<<9)+(r<<8)|0,4,2,0,0,0,4)|0)==0){r=r+1|0}else{s=17;break a}}b=q+1|0;if((b|0)<7){q=b}else{s=19;break}}if((s|0)==17){KIb(h,16,2549184,(m=i,i=i+16|0,c[m>>2]=q,c[m+8>>2]=r,m)|0);i=m;n=-1;i=f;return n|0}else if((s|0)==19){a[812160]=1;n=0;i=f;return n|0}return 0}function aRa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;j=i;k=c[h+24>>2]|0;l=c[e+60>>2]|0;m=l;n=l+1572|0;o=n;p=l+1304|0;mrc(n|0,0,((c[p>>2]|0)*52|0)+52|0)|0;n=h+28|0;h=c[n>>2]|0;q=h&-4;if((q|0)<1){KIb(e,16,2450168,(r=i,i=i+8|0,c[r>>2]=h,r)|0);i=r;s=-1094995529;i=j;return s|0}if((q|0)!=(h|0)){KIb(e,24,2360872,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}h=d[k]|0;t=a[k+1|0]|0;u=q-4|0;q=f+76|0;c[q>>2]=1152;v=M4a(e,f,0)|0;if((v|0)<0){s=v;i=j;return s|0}v=l+12460|0;w=v;A4a(v,l+12464|0,u);v=c[w>>2]|0;if((v|0)==0){s=-12;i=j;return s|0}ef[c[l+1096>>2]&4095](v,k+4|0,u>>2);k=c[w>>2]|0;w=u<<3;u=w>>>0>2147483639>>>0|(k|0)==0;v=u?0:k;k=u?8:w|8;u=(k|0)<(h|0)?k:h;do{if((c[p>>2]|0)<0){x=u;y=-1}else{h=l+1292|0;z=u;A=-1;B=0;a:while(1){C=B-1|0;b:do{if((B|0)==0){D=0;E=z;while(1){if((D|0)>=2){F=E;break b}G=v+(E>>>3)|0;H=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7)>>>28;G=E+4|0;c[o+4+(D<<2)>>2]=H;if((H+1|0)>>>0>18>>>0){I=18;break a}else{D=D+1|0;E=k>>>0>G>>>0?G:k}}}else{E=0;D=z;while(1){if((E|0)>=2){F=D;break b}G=c[1487399]|0;H=v+(D>>>3)|0;J=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(D&7)>>>23;H=(b[G+(J<<2)+2>>1]|0)+D|0;K=k>>>0>H>>>0?H:k;H=(b[G+(J<<2)>>1]|0)-5|0;if((H|0)==4){J=v+(K>>>3)|0;G=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(K&7)>>>28;J=K+4|0;c[o+(B*52|0)+4+(E<<2)>>2]=G;L=k>>>0>J>>>0?J:k;M=G}else{G=(c[o+(C*52|0)+4+(E<<2)>>2]|0)+H|0;c[o+(B*52|0)+4+(E<<2)>>2]=G;L=K;M=G}if((M+1|0)>>>0>18>>>0){I=18;break a}else{E=E+1|0;D=L}}}}while(0);if((c[o+(B*52|0)+4>>2]|0)==0){if((c[o+(B*52|0)+8>>2]|0)==0){N=A;O=F}else{I=21}}else{I=21}do{if((I|0)==21){I=0;if((c[h>>2]|0)==0){N=B;O=F;break}c[o+(B*52|0)>>2]=d[v+(F>>>3)|0]<<(F&7)>>>7&1;N=B;O=((F|0)<(k|0))+F|0}}while(0);C=B+1|0;if((C|0)>(c[p>>2]|0)){break}else{z=O;A=N;B=C}}if((I|0)==18){KIb(e,16,2296640,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}B=(N|0)<0;if(B){x=O;y=N;break}else{P=O;Q=0}while(1){if((c[o+(Q*52|0)+4>>2]|0)==0){R=P}else{A=c[1280449]|0;z=v+(P>>>3)|0;h=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(P&7)>>>29;z=(b[A+(h<<2)+2>>1]|0)+P|0;c[o+(Q*52|0)+12>>2]=b[A+(h<<2)>>1]|0;R=k>>>0>z>>>0?z:k}if((c[o+(Q*52|0)+8>>2]|0)==0){S=R}else{z=c[1280449]|0;h=v+(R>>>3)|0;A=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(R&7)>>>29;h=(b[z+(A<<2)+2>>1]|0)+R|0;c[o+(Q*52|0)+16>>2]=b[z+(A<<2)>>1]|0;S=k>>>0>h>>>0?h:k}h=Q+1|0;if((h|0)>(N|0)){break}else{P=S;Q=h}}if(B){x=S;y=N;break}h=l+1316|0;A=S;z=0;while(1){C=A;D=0;while(1){if((c[o+(z*52|0)+4+(D<<2)>>2]|0)==0){T=C}else{E=h+(D<<7)+(z<<2)|0;G=c[E>>2]|0;K=o+(z*52|0)+20+(D*12|0)+8|0;c[K>>2]=G;H=c[2333741]|0;J=v+(C>>>3)|0;U=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(C&7)>>>26;J=(b[H+(U<<2)+2>>1]|0)+C|0;V=k>>>0>J>>>0?J:k;J=(b[H+(U<<2)>>1]|0)-7|0;if((J|0)==8){U=v+(V>>>3)|0;W=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(V&7)>>>26;U=V+6|0;X=W;Y=k>>>0>U>>>0?U:k}else{X=J+G|0;Y=V}c[o+(z*52|0)+20+(D*12|0)>>2]=X;V=c[o+(z*52|0)+12+(D<<2)>>2]|0;if((V|0)==2){c[o+(z*52|0)+20+(D*12|0)+4>>2]=X;J=v+(Y>>>3)|0;U=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(Y&7)>>>26;J=(b[H+(U<<2)+2>>1]|0)+Y|0;W=k>>>0>J>>>0?J:k;J=(b[H+(U<<2)>>1]|0)-7|0;if((J|0)==8){U=v+(W>>>3)|0;Z=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(W&7)>>>26;U=W+6|0;_=Z;$=k>>>0>U>>>0?U:k}else{_=J+X|0;$=W}c[K>>2]=_;aa=$;ba=_}else if((V|0)==3){c[o+(z*52|0)+20+(D*12|0)+4>>2]=X;c[K>>2]=X;aa=Y;ba=X}else if((V|0)==0){W=v+(Y>>>3)|0;J=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Y&7)>>>26;W=(b[H+(J<<2)+2>>1]|0)+Y|0;U=k>>>0>W>>>0?W:k;W=(b[H+(J<<2)>>1]|0)-7|0;if((W|0)==8){J=v+(U>>>3)|0;Z=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(U&7)>>>26;J=U+6|0;ca=Z;da=k>>>0>J>>>0?J:k}else{ca=W+X|0;da=U}c[o+(z*52|0)+20+(D*12|0)+4>>2]=ca;U=v+(da>>>3)|0;W=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(da&7)>>>26;U=(b[H+(W<<2)+2>>1]|0)+da|0;J=k>>>0>U>>>0?U:k;U=(b[H+(W<<2)>>1]|0)-7|0;if((U|0)==8){W=v+(J>>>3)|0;Z=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(J&7)>>>26;W=J+6|0;ea=Z;fa=k>>>0>W>>>0?W:k}else{ea=U+ca|0;fa=J}c[K>>2]=ea;aa=fa;ba=ea}else if((V|0)==1){V=v+(Y>>>3)|0;J=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Y&7)>>>26;V=(b[H+(J<<2)+2>>1]|0)+Y|0;U=k>>>0>V>>>0?V:k;V=(b[H+(J<<2)>>1]|0)-7|0;if((V|0)==8){J=v+(U>>>3)|0;H=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(U&7)>>>26;J=U+6|0;ga=H;ha=k>>>0>J>>>0?J:k}else{ga=V+X|0;ha=U}c[o+(z*52|0)+20+(D*12|0)+4>>2]=ga;c[K>>2]=ga;aa=ha;ba=ga}else{aa=Y;ba=G}c[E>>2]=ba;T=aa}E=D+1|0;if((E|0)<2){C=T;D=E}else{break}}D=z+1|0;if((D|0)>(N|0)){x=T;y=N;break}else{A=T;z=D}}}}while(0);T=l+3236|0;N=T;mrc(T|0,0,9216)|0;T=l+12724|0;aa=x;x=0;ba=0;while(1){Y=aa;ga=0;while(1){ha=c[o+(ba*52|0)+4+(ga<<2)>>2]|0;X=N+(ga*4608|0)+(x<<2)|0;c:do{switch(ha|0){case 3:case 4:case 5:case 6:case 7:{ea=ha-1|0;fa=d[808352+ea|0]|0;ca=c[5413776+(ea*40|0)+((d[v+(Y>>>3)|0]<<(Y&7)>>>7&1)*20|0)+4>>2]|0;ea=X;da=1;_=((Y|0)<(k|0))+Y|0;while(1){$=v+(_>>>3)|0;S=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(_&7)>>>23;$=b[ca+(S<<2)>>1]|0;Q=b[ca+(S<<2)+2>>1]|0;S=Q<<16>>16;if(Q<<16>>16<0){Q=_+9|0;P=k>>>0>Q>>>0?Q:k;Q=v+(P>>>3)|0;R=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(P&7)>>>((S+32|0)>>>0))+$|0;ia=b[ca+(R<<2)+2>>1]|0;ja=b[ca+(R<<2)>>1]|0;ka=P}else{ia=S;ja=$;ka=_}$=ia+ka|0;S=k>>>0>$>>>0?$:k;c[ea>>2]=ja-fa;if((da|0)>=36){la=S;break c}ea=ea+4|0;da=da+1|0;_=S}break};case-1:{_=X;da=0;while(1){ea=c[T>>2]|0;c[m+12468+((ea&63)<<2)>>2]=(c[m+12468+((ea+9&63)<<2)>>2]|0)+(c[m+12468+((ea+40&63)<<2)>>2]|0);ea=c[T>>2]|0;c[T>>2]=ea+1;c[_>>2]=(c[m+12468+((ea&63)<<2)>>2]&1020)-510;ea=da+1|0;if((ea|0)<36){_=_+4|0;da=ea}else{la=Y;break}}break};case 8:case 9:case 10:case 11:case 12:case 13:case 14:case 15:case 16:case 17:{da=ha-1|0;_=33-ha|0;ea=(-1<<ha-2)+1|0;fa=X;ca=0;S=Y;while(1){$=v+(S>>>3)|0;P=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(S&7)>>>(_>>>0);$=da+S|0;R=k>>>0>$>>>0?$:k;c[fa>>2]=ea+P;P=ca+1|0;if((P|0)<36){fa=fa+4|0;ca=P;S=R}else{la=R;break}}break};case 2:{S=c[5413820+((d[v+(Y>>>3)|0]<<(Y&7)>>>7&1)*20|0)>>2]|0;ca=X;fa=1;ea=((Y|0)<(k|0))+Y|0;while(1){da=v+(ea>>>3)|0;_=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ea&7)>>>23;da=b[S+(_<<2)>>1]|0;R=b[S+(_<<2)+2>>1]|0;_=R<<16>>16;if(R<<16>>16<0){R=ea+9|0;P=k>>>0>R>>>0?R:k;R=v+(P>>>3)|0;$=((je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(P&7)>>>((_+32|0)>>>0))+da|0;ma=b[S+($<<2)+2>>1]|0;na=b[S+($<<2)>>1]|0;oa=P}else{ma=_;na=da;oa=ea}da=ma+oa|0;_=k>>>0>da>>>0?da:k;c[ca>>2]=a[811976+na|0]|0;c[ca+4>>2]=a[811944+na|0]|0;if((fa|0)>=18){la=_;break c}ca=ca+8|0;fa=fa+1|0;ea=_}break};case 1:{ea=c[5413780+((d[v+(Y>>>3)|0]<<(Y&7)>>>7&1)*20|0)>>2]|0;fa=X;ca=1;S=((Y|0)<(k|0))+Y|0;while(1){_=v+(S>>>3)|0;da=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(S&7)>>>23;_=b[ea+(da<<2)>>1]|0;P=b[ea+(da<<2)+2>>1]|0;da=P<<16>>16;if(P<<16>>16<0){P=S+9|0;$=k>>>0>P>>>0?P:k;P=v+($>>>3)|0;R=((je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<($&7)>>>((da+32|0)>>>0))+_|0;pa=b[ea+(R<<2)+2>>1]|0;qa=b[ea+(R<<2)>>1]|0;ra=$}else{pa=da;qa=_;ra=S}_=pa+ra|0;da=k>>>0>_>>>0?_:k;c[fa>>2]=a[812072+qa|0]|0;c[fa+4>>2]=a[812040+qa|0]|0;c[fa+8>>2]=a[812008+qa|0]|0;if((ca|0)>=12){la=da;break c}fa=fa+12|0;ca=ca+1|0;S=da}break};default:{la=Y}}}while(0);X=ga+1|0;if((X|0)<2){Y=la;ga=X}else{break}}ga=ba+1|0;if((ga|0)<32){aa=la;x=x+36|0;ba=ga}else{break}}Arb(m,y,c[f+64>>2]|0,2);do{if(t<<24>>24==0){if((w|0)>=(la|0)&(la+32|0)>(w|0)){break}KIb(e,16,2245688,(r=i,i=i+16|0,c[r>>2]=la,c[r+8>>2]=w,r)|0);i=r;s=-1;i=j;return s|0}else{c[q>>2]=c[l+1300>>2]}}while(0);q=l+12728|0;l=c[q>>2]|0;if((l|0)==0){c[g>>2]=1;s=c[n>>2]|0;i=j;return s|0}else{c[q>>2]=l-1;c[g>>2]=0;s=c[n>>2]|0;i=j;return s|0}return 0}function bRa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+12460|0);c[b+12464>>2]=0;return 0}function cRa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mrc(b+1316|0,0,256)|0;c[b+12728>>2]=32;return}function dRa(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[f+60>>2]|0;j=c[f+100>>2]|0;if((j|0)<2){KIb(f,16,2360840,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;l=-1;i=g;return l|0}mrc(h+1316|0,0,256)|0;AIb(h+12468|0,-559038737);l8(h,f);PSa(h+1244|0);zrb();j=c[f+96>>2]|0;m=(j|0)==0;n=j;o=((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)&31)+1|0;c[h+1304>>2]=o;if(o>>>0>31>>>0){KIb(f,16,2296616,(k=i,i=i+8|0,c[k>>2]=o,k)|0);i=k;l=-1094995529;i=g;return l|0}o=j+1|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;n=(j>>>4&15)+1|0;if(n>>>0>2>>>0){QIb(f,2245664,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=g;return l|0}p=m?0:4;c[h+1292>>2]=(j&255)<<p>>>7&1;c[h+12456>>2]=1<<((je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<((p|m&1)^1)>>>29<<1);c[f+420>>2]=6;m=(n|0)==2;p=f+448|0;c[p>>2]=m?3:4;c[p+4>>2]=m?0:0;c[f+416>>2]=n;if(a[803552]|0){l=0;i=g;return l|0}KIb(f,48,2204184,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;c[2474743]=5656480;c[2474745]=542;$2(9898968,9,33,808288,1,1,808248,1,1,0,0,0,4)|0;c[1357525]=5626936;c[1357527]=520;$2(5430096,9,19,802744,1,1,802720,1,1,0,0,0,4)|0;c[1357499]=5620728;c[1357501]=524;$2(5429992,9,256,800560,1,1,800304,1,1,0,0,0,4)|0;c[1280439]=5620696;c[1280441]=8;$2(5121752,3,4,800184,1,1,800176,1,1,0,0,0,4)|0;c[1280444]=5620184;c[1280446]=128;$2(5121772,7,16,800160,1,1,800144,1,1,0,0,0,4)|0;c[2333731]=5631408;c[2333733]=560;$2(9334920,9,64,803488,1,1,803424,1,1,0,0,0,4)|0;c[2333736]=5629016;c[2333738]=598;$2(9334940,9,65,803352,1,1,803280,1,1,0,0,0,4)|0;c[1357505]=5624888;c[1357507]=512;$2(5430016,9,49,802152,1,1,802096,1,1,802040,1,1,4)|0;c[1357510]=5622824;c[1357512]=516;$2(5430036,9,81,801952,1,1,801864,1,1,801776,1,1,4)|0;k=0;f=0;n=640;m=1184;p=1748;o=2298;h=2426;j=2554;q=3066;r=3578;s=4106;t=4618;while(1){c[5410100+(k*20|0)>>2]=5633648+((f&65535)<<2);u=k+1|0;c[5410108+(k*20|0)>>2]=(n&65535)-(e[256224+(k<<1)>>1]|0);$2(5410096+(k*20|0)|0,9,17,800232+(k*17|0)|0,1,1,800192+(k*17|0)|0,1,1,0,0,0,4)|0;c[5430060+(k*20|0)>>2]=5633648+((m&65535)<<2);v=b[256224+(k+2<<1)>>1]|0;c[5430068+(k*20|0)>>2]=(p&65535)-(v&65535);$2(5430056+(k*20|0)|0,9,125,802464+(k*125|0)|0,1,1,802208+(k*125|0)|0,1,1,0,0,0,4)|0;c[5413620+(k*20|0)>>2]=5633648+((o&65535)<<2);w=b[256224+(k+4<<1)>>1]|0;c[5413628+(k*20|0)>>2]=(h&65535)-(w&65535);$2(5413616+(k*20|0)|0,7,15,801744+(k*15|0)|0,1,1,801712+(k*15|0)|0,1,1,0,0,0,4)|0;c[5413660+(k*20|0)>>2]=5633648+((j&65535)<<2);x=b[256224+(k+6<<1)>>1]|0;c[5413668+(k*20|0)>>2]=(q&65535)-(x&65535);$2(5413656+(k*20|0)|0,9,31,801648+(k*31|0)|0,1,1,801584+(k*31|0)|0,1,1,0,0,0,4)|0;c[5413700+(k*20|0)>>2]=5633648+((r&65535)<<2);y=b[256224+(k+8<<1)>>1]|0;c[5413708+(k*20|0)>>2]=(s&65535)-(y&65535);$2(5413696+(k*20|0)|0,9,63,801456+(k*63|0)|0,1,1,801328+(k*63|0)|0,1,1,0,0,0,4)|0;z=t&65535;c[5413740+(k*20|0)>>2]=5633648+(z<<2);A=b[256224+(k+11<<1)>>1]|0;c[5413748+(k*20|0)>>2]=(A&65535)-z;$2(5413736+(k*20|0)|0,9,127,801072+(k*127|0)|0,1,1,800816+(k*127|0)|0,1,1,0,0,0,4)|0;if((u|0)<2){k=u;f=n;n=v;m=p;p=w;o=h;h=x;j=q;q=y;r=s;s=t;t=A}else{break}}a[803552]=1;l=0;i=g;return l|0}function eRa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0;j=i;i=i+24|0;k=j|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;h=c[e+60>>2]|0;n=h;o=h+1572|0;c[f+76>>2]=1152;p=M4a(e,f,0)|0;if((p|0)<0){q=p;i=j;return q|0}p=h+12452|0;r=(c[p>>2]|0)==0;if(r){mrc(h+3236|0,0,9216)|0;c[h+1312>>2]=0;s=0}else{s=c[h+1312>>2]&7}t=m<<3;u=t>>>0>2147483639>>>0|(l|0)==0;v=u?0:l;l=u?0:t;u=k|0;c[u>>2]=v;w=k+12|0;c[w>>2]=l;x=l+8|0;y=k+16|0;c[y>>2]=x;c[k+4>>2]=v+(l>>3);l=k+8|0;z=h+1312|0;A=x>>>0>s>>>0?s:x;c[l>>2]=A;do{if(r){s=(c[h+1304>>2]|0)+1|0;B=a[805672+s|0]|0;if(B<<24>>24==0){C=0;D=A;break}E=B&255;B=E-1|0;do{if((B|0)==0){F=0;G=A}else{H=v+(A>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(A&7);if((B|0)<26){H=B+A|0;J=x>>>0>H>>>0?H:x;c[l>>2]=J;F=I>>>((33-E|0)>>>0);G=J;break}else{J=A+16|0;H=x>>>0>J>>>0?J:x;J=E-17|0;K=v+(H>>>3)|0;L=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(H&7)>>>((49-E|0)>>>0);K=H+J|0;H=x>>>0>K>>>0?K:x;c[l>>2]=H;F=L|I>>>16<<J;G=H;break}}}while(0);E=c[803560+(s<<2)>>2]|0;if(F>>>0<E>>>0){C=F;D=G;break}B=d[v+(G>>>3)|0]<<(G&7)>>>7;H=((G|0)<(x|0))+G|0;c[l>>2]=H;C=(B&1|F<<1)-E|0;D=H}else{H=c[h+1308>>2]|0;E=c[2474743]|0;B=v+(A>>>3)|0;J=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>23;B=b[E+(J<<2)>>1]|0;I=b[E+(J<<2)+2>>1]|0;J=I<<16>>16;if(I<<16>>16<0){I=A+9|0;L=x>>>0>I>>>0?I:x;I=v+(L>>>3)|0;K=((je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>((J+32|0)>>>0))+B|0;M=b[E+(K<<2)+2>>1]|0;N=b[E+(K<<2)>>1]|0;O=L}else{M=J;N=B;O=A}B=M+O|0;J=x>>>0>B>>>0?B:x;c[l>>2]=J;B=N+H|0;if((B|0)<=32){C=B;D=J;break}C=B-33|0;D=J}}while(0);N=h+1304|0;if((C|0)>((c[N>>2]|0)+1|0)){KIb(e,16,2450144,(O=i,i=i+8|0,c[O>>2]=C,O)|0);i=O;q=-1094995529;i=j;return q|0}c[h+1308>>2]=C;do{if((C|0)==0){P=0}else{O=C-1|0;M=(C|0)>0;if(M){A=O;F=D;G=0;J=0;while(1){B=c[5410100+(((G|0)>2|0)*20|0)>>2]|0;H=v+(F>>>3)|0;L=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>23;H=b[B+(L<<2)>>1]|0;K=b[B+(L<<2)+2>>1]|0;L=K<<16>>16;if(K<<16>>16<0){K=F+9|0;E=x>>>0>K>>>0?K:x;K=v+(E>>>3)|0;I=((je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(E&7)>>>((L+32|0)>>>0))+H|0;Q=b[B+(I<<2)+2>>1]|0;R=b[B+(I<<2)>>1]|0;S=E}else{Q=L;R=H;S=F}H=Q+S|0;L=x>>>0>H>>>0?H:x;H=G+R|0;E=(H|0)>15?H-17|0:H;c[o+(A*52|0)+4>>2]=E;H=c[5410100+(((J|0)>2|0)*20|0)>>2]|0;I=v+(L>>>3)|0;B=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>23;I=b[H+(B<<2)>>1]|0;K=b[H+(B<<2)+2>>1]|0;B=K<<16>>16;if(K<<16>>16<0){K=L+9|0;T=x>>>0>K>>>0?K:x;K=v+(T>>>3)|0;U=((je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(T&7)>>>((B+32|0)>>>0))+I|0;V=b[H+(U<<2)+2>>1]|0;W=b[H+(U<<2)>>1]|0;X=T}else{V=B;W=I;X=L}L=V+X|0;Y=x>>>0>L>>>0?L:x;L=J+W|0;I=(L|0)>15?L-17|0:L;c[o+(A*52|0)+8>>2]=I;if((A|0)>0){A=A-1|0;F=Y;G=E;J=I}else{break}}c[l>>2]=Y;Z=Y}else{Z=D}if((c[h+1292>>2]|0)==0){P=C;break}if(M){J=0;G=0;while(1){if((c[o+(G*52|0)+4>>2]|0)==0){if((c[o+(G*52|0)+8>>2]|0)==0){_=J}else{$=29}}else{$=29}if(($|0)==29){$=0;_=J+1|0}F=G+1|0;if((F|0)<(C|0)){J=_;G=F}else{aa=_;break}}}else{aa=0}G=a[805672+aa|0]|0;do{if(G<<24>>24==0){ba=0}else{J=G&255;F=J-1|0;do{if((F|0)==0){ca=0;da=Z}else{A=v+(Z>>>3)|0;s=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(Z&7);if((F|0)<26){A=Z+F|0;I=x>>>0>A>>>0?A:x;c[l>>2]=I;ca=s>>>((33-J|0)>>>0);da=I;break}else{I=Z+16|0;A=x>>>0>I>>>0?I:x;I=J-17|0;E=v+(A>>>3)|0;L=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(A&7)>>>((49-J|0)>>>0);E=A+I|0;A=x>>>0>E>>>0?E:x;c[l>>2]=A;ca=L|s>>>16<<I;da=A;break}}}while(0);J=c[803560+(aa<<2)>>2]|0;if(ca>>>0<J>>>0){ba=ca;break}F=d[v+(da>>>3)|0]<<(da&7)>>>7;c[l>>2]=((da|0)<(x|0))+da;ba=(F&1|ca<<1)-J|0}}while(0);G=gRa(k,aa,ba)|0;if(M){ea=O;fa=G}else{P=C;break}while(1){if((c[o+(ea*52|0)+4>>2]|0)==0){if((c[o+(ea*52|0)+8>>2]|0)==0){ga=fa}else{$=42}}else{$=42}if(($|0)==42){$=0;c[o+(ea*52|0)>>2]=fa&1;ga=fa>>1}if((ea|0)>0){ea=ea-1|0;fa=ga}else{P=C;break}}}}while(0);if((P|0)<(c[N>>2]|0)){ga=P;do{c[o+(ga*52|0)+8>>2]=0;c[o+(ga*52|0)+4>>2]=0;ga=ga+1|0;}while((ga|0)<(c[N>>2]|0))}if(r){r=h+1444|0;N=h+1316|0;ga=0;do{c[r+(ga<<2)>>2]=1;c[N+(ga<<2)>>2]=1;ga=ga+1|0;}while((ga|0)<32)}ga=(C|0)>0;do{if(ga){N=c[y>>2]|0;r=c[u>>2]|0;P=0;do{fa=c[o+(P*52|0)+4>>2]|0;ea=(fa|0)==0;$=c[o+(P*52|0)+8>>2]|0;do{if((fa|$|0)!=0){ba=(($|0)!=0)+((fa|0)!=0)|0;aa=ba-1|0;if((ba|0)<=0){break}ba=c[5121756+(aa*20|0)>>2]|0;ca=c[5121752+(aa*20|0)>>2]|0;da=c[l>>2]|0;x=r+(da>>>3)|0;v=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(da&7)>>>((32-ca|0)>>>0);ca=b[ba+(v<<2)>>1]|0;x=(b[ba+(v<<2)+2>>1]|0)+da|0;c[l>>2]=N>>>0>x>>>0?x:N;if(!ea){c[o+(P*52|0)+12>>2]=ca>>(aa<<1)}if(($|0)==0){break}c[o+(P*52|0)+16>>2]=ca&3}}while(0);P=P+1|0;}while((P|0)<(C|0));if(!ga){break}P=h+1316|0;N=c[y>>2]|0;r=c[u>>2]|0;$=0;do{ea=0;do{if((c[o+($*52|0)+4+(ea<<2)>>2]|0)!=0){fa=P+(ea<<7)+($<<2)|0;if((c[fa>>2]|0)==0){ca=c[2333736]|0;aa=c[l>>2]|0;x=r+(aa>>>3)|0;da=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(aa&7)>>>23;x=b[ca+(da<<2)>>1]|0;v=b[ca+(da<<2)+2>>1]|0;da=v<<16>>16;if(v<<16>>16<0){v=aa+9|0;ba=N>>>0>v>>>0?v:N;v=r+(ba>>>3)|0;Z=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(ba&7)>>>((da+32|0)>>>0))+x|0;ha=b[ca+(Z<<2)+2>>1]|0;ia=b[ca+(Z<<2)>>1]|0;ja=ba}else{ha=da;ia=x;ja=aa}aa=ha+ja|0;x=N>>>0>aa>>>0?aa:N;c[l>>2]=x;if((ia|0)==64){aa=r+(x>>>3)|0;da=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(x&7)>>>26;aa=x+6|0;ba=N>>>0>aa>>>0?aa:N;c[l>>2]=ba;ka=da|64;la=ba}else{ka=ia;la=x}c[o+($*52|0)+20+(ea*12|0)>>2]=(ka+103+(c[o+($*52|0)+20+(ea*12|0)+8>>2]|0)&127)-6;ma=la}else{x=c[l>>2]|0;ba=r+(x>>>3)|0;da=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(x&7)>>>25;ba=x+7|0;x=N>>>0>ba>>>0?ba:N;c[l>>2]=x;c[o+($*52|0)+20+(ea*12|0)>>2]=da-6;c[fa>>2]=0;ma=x}x=o+($*52|0)+12+(ea<<2)|0;fa=0;da=ma;while(1){if((c[x>>2]&2>>>(fa>>>0)|0)==0){ba=c[2333731]|0;aa=r+(da>>>3)|0;Z=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(da&7)>>>23;aa=b[ba+(Z<<2)>>1]|0;ca=b[ba+(Z<<2)+2>>1]|0;Z=ca<<16>>16;if(ca<<16>>16<0){ca=da+9|0;v=N>>>0>ca>>>0?ca:N;ca=r+(v>>>3)|0;_=((je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(v&7)>>>((Z+32|0)>>>0))+aa|0;na=b[ba+(_<<2)+2>>1]|0;oa=b[ba+(_<<2)>>1]|0;pa=v}else{na=Z;oa=aa;pa=da}aa=na+pa|0;Z=N>>>0>aa>>>0?aa:N;c[l>>2]=Z;if((oa|0)==31){aa=r+(Z>>>3)|0;v=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(Z&7)>>>26;aa=Z+6|0;_=N>>>0>aa>>>0?aa:N;c[l>>2]=_;qa=v|64;ra=_}else{qa=oa;ra=Z}c[o+($*52|0)+20+(ea*12|0)+(fa+1<<2)>>2]=(qa+103+(c[o+($*52|0)+20+(ea*12|0)+(fa<<2)>>2]|0)&127)-6;sa=ra}else{c[o+($*52|0)+20+(ea*12|0)+(fa+1<<2)>>2]=c[o+($*52|0)+20+(ea*12|0)+(fa<<2)>>2];sa=da}Z=fa+1|0;if((Z|0)<2){fa=Z;da=sa}else{break}}}ea=ea+1|0;}while((ea|0)<2);$=$+1|0;}while(($|0)<(C|0));if(!ga){break}$=h+3236|0;N=h+12468|0;r=h+12724|0;P=0;ea=0;while(1){da=0;do{fa=c[o+(P*52|0)+4+(da<<2)>>2]|0;switch(fa|0){case-1:{x=0;do{Z=c[r>>2]|0;c[N+((Z&63)<<2)>>2]=(c[N+((Z+9&63)<<2)>>2]|0)+(c[N+((Z+40&63)<<2)>>2]|0);Z=c[r>>2]|0;c[r>>2]=Z+1;c[$+(da*4608|0)+(x+ea<<2)>>2]=(c[N+((Z&63)<<2)>>2]&1020)-510;x=x+1|0;}while((x|0)<36);break};case 1:{x=0;Z=c[y>>2]|0;_=c[u>>2]|0;do{v=c[1357525]|0;aa=c[l>>2]|0;ba=_+(aa>>>3)|0;ca=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(aa&7)>>>23;ba=b[v+(ca<<2)>>1]|0;D=b[v+(ca<<2)+2>>1]|0;ca=D<<16>>16;if(D<<16>>16<0){D=aa+9|0;Y=Z>>>0>D>>>0?D:Z;D=_+(Y>>>3)|0;W=((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(Y&7)>>>((ca+32|0)>>>0))+ba|0;ta=b[v+(W<<2)+2>>1]|0;ua=b[v+(W<<2)>>1]|0;va=Y}else{ta=ca;ua=ba;va=aa}aa=ta+va|0;c[l>>2]=Z>>>0>aa>>>0?aa:Z;aa=gRa(k,18,ua)|0;ba=x+ea|0;_=c[u>>2]|0;Z=c[y>>2]|0;ca=0;Y=aa;while(1){if((Y&131072|0)==0){wa=0}else{aa=c[l>>2]|0;W=d[_+(aa>>>3)|0]<<(aa&7)>>>7;c[l>>2]=((aa|0)<(Z|0))+aa;wa=(W<<1&2)-1|0}c[$+(da*4608|0)+(ba+ca<<2)>>2]=wa;W=ca+1|0;if((W|0)<18){ca=W;Y=Y<<1}else{break}}x=x+18|0;}while((x|0)<36);break};case 2:{x=c[y>>2]|0;Z=c[u>>2]|0;_=0;Y=6;ca=c[l>>2]|0;while(1){ba=c[5430060+(((Y|0)>3|0)*20|0)>>2]|0;W=Z+(ca>>>3)|0;aa=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ca&7)>>>23;W=b[ba+(aa<<2)>>1]|0;v=b[ba+(aa<<2)+2>>1]|0;aa=v<<16>>16;if(v<<16>>16<0){v=ca+9|0;D=x>>>0>v>>>0?v:x;v=Z+(D>>>3)|0;X=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(D&7)>>>((aa+32|0)>>>0))+W|0;xa=b[ba+(X<<2)+2>>1]|0;ya=b[ba+(X<<2)>>1]|0;za=D}else{xa=aa;ya=W;za=ca}W=xa+za|0;Aa=x>>>0>W>>>0?W:x;W=_+ea|0;c[$+(da*4608|0)+(W<<2)>>2]=a[803024+ya|0]|0;c[$+(da*4608|0)+(W+1<<2)>>2]=a[802896+ya|0]|0;c[$+(da*4608|0)+(W+2<<2)>>2]=a[802768+ya|0]|0;W=_+3|0;if((W|0)<36){_=W;Y=(a[803152+ya|0]|0)+(Y>>1)|0;ca=Aa}else{break}}c[l>>2]=Aa;break};case 3:case 4:{ca=fa-3|0;Y=c[y>>2]|0;_=c[u>>2]|0;x=c[696312+(ca<<2)>>2]|0;Z=c[5430020+(ca*20|0)>>2]|0;ca=0;W=c[l>>2]|0;do{aa=_+(W>>>3)|0;D=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(W&7)>>>23;aa=b[Z+(D<<2)>>1]|0;X=b[Z+(D<<2)+2>>1]|0;D=X<<16>>16;if(X<<16>>16<0){X=W+9|0;ba=Y>>>0>X>>>0?X:Y;X=_+(ba>>>3)|0;v=((je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(ba&7)>>>((D+32|0)>>>0))+aa|0;Ba=b[Z+(v<<2)+2>>1]|0;Ca=b[Z+(v<<2)>>1]|0;Da=ba}else{Ba=D;Ca=aa;Da=W}aa=Ba+Da|0;W=Y>>>0>aa>>>0?aa:Y;aa=x+Ca|0;D=ca+ea|0;c[$+(da*4608|0)+((D|1)<<2)>>2]=aa>>4;c[$+(da*4608|0)+(D<<2)>>2]=(aa&8|0)!=0?aa|-16:aa&15;ca=ca+2|0;}while((ca|0)<36);c[l>>2]=W;break};case 0:{break};case 5:case 6:case 7:case 8:{ca=c[800104+(fa<<2)>>2]|0;x=fa-5|0;Y=c[y>>2]|0;Z=c[u>>2]|0;_=c[687832+(x<<2)>>2]|0;aa=0;D=ca<<1;ba=c[l>>2]|0;while(1){v=D>>>0>ca>>>0|0;X=c[5413616+(x*40|0)+(v*20|0)+4>>2]|0;V=c[5413616+(x*40|0)+(v*20|0)>>2]|0;v=Z+(ba>>>3)|0;R=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(ba&7)>>>((32-V|0)>>>0);v=b[X+(R<<2)>>1]|0;S=b[X+(R<<2)+2>>1]|0;R=S<<16>>16;if(S<<16>>16<0){S=ba+V|0;V=Y>>>0>S>>>0?S:Y;S=Z+(V>>>3)|0;Q=((je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(V&7)>>>((R+32|0)>>>0))+v|0;Ea=b[X+(Q<<2)+2>>1]|0;Fa=b[X+(Q<<2)>>1]|0;Ga=V}else{Ea=R;Fa=v;Ga=ba}v=Ea+Ga|0;Ha=Y>>>0>v>>>0?v:Y;v=_+Fa|0;c[$+(da*4608|0)+(aa+ea<<2)>>2]=v;R=aa+1|0;if((R|0)<36){aa=R;D=((v|0)>-1?v:-v|0)+(D>>1)|0;ba=Ha}else{break}}c[l>>2]=Ha;break};default:{ba=c[y>>2]|0;D=c[u>>2]|0;aa=(-1<<fa-2)+1|0;_=fa-9|0;Y=41-fa|0;Z=c[l>>2]|0;x=c[1357499]|0;if((fa|0)==9){ca=0;W=Z;while(1){v=D+(W>>>3)|0;R=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(W&7)>>>23;v=b[x+(R<<2)>>1]|0;V=b[x+(R<<2)+2>>1]|0;R=V<<16>>16;if(V<<16>>16<0){V=W+9|0;Q=ba>>>0>V>>>0?V:ba;V=D+(Q>>>3)|0;X=((je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Q&7)>>>((R+32|0)>>>0))+v|0;Ia=b[x+(X<<2)+2>>1]|0;Ja=b[x+(X<<2)>>1]|0;Ka=Q}else{Ia=R;Ja=v;Ka=W}v=Ia+Ka|0;R=ba>>>0>v>>>0?v:ba;c[$+(da*4608|0)+(ca+ea<<2)>>2]=aa+Ja;v=ca+1|0;if((v|0)<36){ca=v;W=R}else{La=R;break}}}else{W=0;ca=Z;while(1){fa=D+(ca>>>3)|0;R=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ca&7)>>>23;fa=b[x+(R<<2)>>1]|0;v=b[x+(R<<2)+2>>1]|0;R=v<<16>>16;if(v<<16>>16<0){v=ca+9|0;Q=ba>>>0>v>>>0?v:ba;v=D+(Q>>>3)|0;X=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(Q&7)>>>((R+32|0)>>>0))+fa|0;Ma=b[x+(X<<2)+2>>1]|0;Na=b[x+(X<<2)>>1]|0;Oa=Q}else{Ma=R;Na=fa;Oa=ca}fa=Ma+Oa|0;R=ba>>>0>fa>>>0?fa:ba;fa=$+(da*4608|0)+(W+ea<<2)|0;Q=Na<<_;c[fa>>2]=Q;X=D+(R>>>3)|0;v=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(R&7)>>>(Y>>>0);X=R+_|0;R=ba>>>0>X>>>0?X:ba;c[fa>>2]=aa+(v|Q);Q=W+1|0;if((Q|0)<36){W=Q;ca=R}else{La=R;break}}}c[l>>2]=La}}da=da+1|0;}while((da|0)<2);da=P+1|0;if((da|0)<(C|0)){P=da;ea=ea+36|0}else{break}}}}while(0);Arb(n,C-1|0,c[f+64>>2]|0,c[e+416>>2]|0);e=(c[p>>2]|0)+1|0;c[p>>2]=e;f=c[l>>2]|0;c[z>>2]=f;if(((c[w>>2]|0)-f|0)<8){c[z>>2]=t}if((e|0)>=(c[h+12456>>2]|0)){c[p>>2]=0}c[g>>2]=1;if((c[p>>2]|0)==0){q=m;i=j;return q|0}q=c[z>>2]>>3;i=j;return q|0}function fRa(a){a=a|0;c[(c[a+60>>2]|0)+12452>>2]=0;return}function gRa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((e|0)==0|(e|0)==(b|0)){f=0;g=e<<1;h=(g|0)>(b|0);i=h<<31>>31;j=f^i;return j|0}k=b-e|0;l=(k|0)<(e|0)?k:e;k=l-1|0;m=806200+(k<<7)|0;n=b-1|0;o=d[805672+(k*33|0)+n|0]|0;p=o-1|0;do{if((p|0)==0){q=0}else{r=a+8|0;s=c[r>>2]|0;t=c[a+16>>2]|0;u=c[a>>2]|0;v=u+(s>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(s&7);if((p|0)<26){v=s+p|0;c[r>>2]=t>>>0>v>>>0?v:t;q=w>>>((33-o|0)>>>0);break}else{v=s+16|0;s=t>>>0>v>>>0?v:t;c[r>>2]=s;v=o-17|0;x=u+(s>>>3)|0;u=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(s&7)>>>((49-o|0)>>>0);x=s+v|0;c[r>>2]=t>>>0>x>>>0?x:t;q=u|w>>>16<<v;break}}}while(0);o=c[803560+(k*132|0)+(n<<2)>>2]|0;if(q>>>0<o>>>0){y=q;z=m;A=0;B=b;C=l}else{n=a+8|0;k=c[n>>2]|0;p=(d[(c[a>>2]|0)+(k>>>3)|0]|0)<<(k&7)>>>7;c[n>>2]=((k|0)<(c[a+16>>2]|0))+k;y=(p&1|q<<1)-o|0;z=m;A=0;B=b;C=l}while(1){l=B-1|0;m=c[z+(l<<2)>>2]|0;if(y>>>0<m>>>0){D=y;E=z;F=A;G=C}else{D=y-m|0;E=z-128|0;F=1<<l|A;G=C-1|0}if((G|0)>0){y=D;z=E;A=F;B=l;C=G}else{f=F;break}}g=e<<1;h=(g|0)>(b|0);i=h<<31>>31;j=f^i;return j|0}function hRa(a){a=a|0;var b=0;b=c[1346096+(c[a+14176>>2]<<2)>>2]|0;c[a+9892>>2]=b;c[a+9888>>2]=b;return}function iRa(a){a=a|0;var b=0;b=1<<(c[a+14176>>2]|0)+7;c[a+9860>>2]=b;c[a+9864>>2]=b;c[a+9868>>2]=b;mrc(a+11824|0,0,32)|0;return}function jRa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(a[1347872]|0){return}a[1347872]=1;c[2094917]=7680280;c[2094919]=512;$2(8379664,9,12,1347576,1,1,1347552,2,2,0,0,0,4)|0;c[2094923]=7678224;c[2094925]=514;$2(8379688,9,12,1347616,1,1,1347592,2,2,0,0,0,4)|0;c[1644861]=7676152;c[1644863]=518;$2(6579440,9,17,1347761,2,1,1347760,2,1,0,0,0,4)|0;c[1924113]=7674e3;c[1924115]=538;$2(7696448,9,36,1347801,2,1,1347800,2,1,0,0,0,4)|0;c[1924125]=7671952;c[1924127]=512;$2(7696496,9,64,1347633,2,1,1347632,2,1,0,0,0,4)|0;c[1924119]=7671696;c[1924121]=64;$2(7696472,6,7,317633,2,1,317632,2,1,0,0,0,4)|0;c[1924151]=7671440;c[1924153]=64;$2(7696600,6,11,320721,2,1,320720,2,1,0,0,0,4)|0;ATa(1315856,7665240);ATa(1315664,7665630);c[328976]=7668720;c[328978]=680;d=c[328966]|0;$2(1315900,9,(c[328964]|0)+2|0,d+2|0,4,2,d,4,2,0,0,0,4)|0;c[328980]=7685024;if((c[328977]|0)>0){d=0;do{e=c[328976]|0;f=b[e+(d<<2)>>1]|0;g=f<<16>>16;h=b[e+(d<<2)+2>>1]|0;do{if(h<<16>>16==0){i=65;j=64}else{if(h<<16>>16<0){i=0;j=f;break}e=c[328964]|0;if((g|0)==(e|0)){i=65;j=0;break}if((g|0)==(e+1|0)){i=0;j=127;break}i=(a[(c[328967]|0)+g|0]|0)+1&255;j=a[(c[328968]|0)+g|0]|0}}while(0);a[(c[328980]|0)+(d<<2)+2|0]=h;g=c[328980]|0;b[g+(d<<2)>>1]=j;a[g+(d<<2)+3|0]=i;d=d+1|0;}while((d|0)<(c[328977]|0))}c[328928]=7666024;c[328930]=674;d=c[328918]|0;$2(1315708,9,(c[328916]|0)+2|0,d+2|0,4,2,d,4,2,0,0,0,4)|0;c[328932]=7682328;if((c[328929]|0)>0){k=0}else{return}do{d=c[328928]|0;i=b[d+(k<<2)>>1]|0;j=i<<16>>16;g=b[d+(k<<2)+2>>1]|0;do{if(g<<16>>16==0){l=65;m=64}else{if(g<<16>>16<0){l=0;m=i;break}d=c[328916]|0;if((j|0)==(d|0)){l=65;m=0;break}if((j|0)==(d+1|0)){l=0;m=127;break}l=(a[(c[328919]|0)+j|0]|0)+1&255;m=a[(c[328920]|0)+j|0]|0}}while(0);a[(c[328932]|0)+(k<<2)+2|0]=g;j=c[328932]|0;b[j+(k<<2)>>1]=m;a[j+(k<<2)+3|0]=l;k=k+1|0;}while((k|0)<(c[328929]|0));return}function kRa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;i=i+8|0;h=g|0;j=b+16|0;k=c[j>>2]|0;c[h>>2]=k;if((e|0)==0){l=0;i=g;return l|0}a:do{if((e|0)>0){m=b+20|0;n=d+e|0;o=d;b:do{if((f|0)==0){p=0;q=c[m>>2]|0;r=k;while(1){do{if((q&1|0)==0){s=(U5a(d+p|0,n,h)|0)-o|0;t=s-1|0;u=c[m>>2]|0;v=c[h>>2]|0;do{if((u|0)==0){if(!((v-257|0)>>>0<175>>>0)){w=0;x=16;break}c[m>>2]=4;y=s;z=v}else{w=u;x=16}}while(0);if((x|0)==16){x=0;if((v|0)==439){A=t;x=37;break b}if((w|0)==2&(v|0)==435){c[m>>2]=0;B=0;x=20}else{if((w|0)<4){B=w;x=20}else{C=w;D=v}}do{if((x|0)==20){x=0;if((v|0)!=437){C=B;D=v;break}u=B+1|0;c[m>>2]=u;C=u;D=437}}while(0);if((C|0)==4){y=t;z=D}else{E=t;F=C;G=D;break}}if((z&-256|0)==256&(z-257|0)>>>0>174>>>0){H=y;x=45;break b}else{E=y;F=4;G=z}}else{do{if((r|0)==439){if((a[d+p|0]&3)==3){c[m>>2]=0;I=0;break}else{v=q+1&3;c[m>>2]=v;I=v;break}}else if((r|0)==437){if((a[d+p|0]&-16)<<24>>24==-128){I=q;break}v=q-1|0;c[m>>2]=v;I=v}else{I=q}}while(0);t=r+1|0;c[h>>2]=t;E=p;F=I;G=t}}while(0);t=E+1|0;if((t|0)<(e|0)){p=t;q=F;r=G}else{J=G;break a}}}else{r=0;do{q=c[m>>2]|0;c:do{if((q&1|0)==0){p=(U5a(d+r|0,n,h)|0)-o|0;t=p-1|0;v=c[m>>2]|0;u=c[h>>2]|0;do{if((v|0)==0){if(!((u-257|0)>>>0<175>>>0)){K=0;x=36;break}c[m>>2]=4;L=p;M=u}else{K=v;x=36}}while(0);do{if((x|0)==36){x=0;if((u|0)==439){A=t;x=37;break b}if((K|0)==2&(u|0)==435){c[m>>2]=0;N=0;x=41}else{if((K|0)<4){N=K;x=41}else{O=K;P=u}}do{if((x|0)==41){x=0;if((u|0)!=437){O=N;P=u;break}v=N+1|0;c[m>>2]=v;O=v;P=437}}while(0);if((O|0)==4){L=t;M=P;break}else if((O|0)!=0){Q=t;break c}if((P|0)!=256){Q=t;break c}EWa(f,p-4|0,1);Q=t;break c}}while(0);if((M&-256|0)==256&(M-257|0)>>>0>174>>>0){H=L;x=45;break b}else{Q=L}}else{t=c[h>>2]|0;do{if((t|0)==439){if((a[d+r|0]&3)==3){c[m>>2]=0;break}else{c[m>>2]=q+1&3;break}}else if((t|0)==437){if((a[d+r|0]&-16)<<24>>24==-128){break}c[m>>2]=q-1}}while(0);c[h>>2]=t+1;Q=r}}while(0);r=Q+1|0;}while((r|0)<(e|0));J=c[h>>2]|0;break a}}while(0);if((x|0)==37){c[m>>2]=0;c[j>>2]=-1;l=A+1|0;i=g;return l|0}else if((x|0)==45){c[m>>2]=0;c[j>>2]=-1;l=H-3|0;i=g;return l|0}}else{J=k}}while(0);c[j>>2]=J;l=-100;i=g;return l|0}function lRa(a,b,c){a=a|0;b=b|0;c=c|0;return mRa(a,b,c)|0}function mRa(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;k=c[f+9960>>2]|0;l=(h|0)<4?0:h-3|0;m=f+14120|0;n=tRa(m,l)|0;if((n|0)>65534){o=-1;i=j;return o|0}p=f+9860+(l<<2)|0;l=(c[p>>2]|0)+n|0;c[p>>2]=l;b[g>>1]=ca(e[f+12560>>1]|0,l)|0;l=f+14128|0;p=c[l>>2]|0;n=c[m>>2]|0;m=n+(p>>>3)|0;q=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7);a:do{if((q|0)<-1073741824){r=p;s=0}else{m=-k|0;t=c[328980]|0;u=q;v=p;w=0;b:while(1){x=u>>>23;y=b[t+(x<<2)>>1]|0;z=a[t+(x<<2)+2|0]|0;A=z<<24>>24;if(z<<24>>24<0){z=u<<9;B=(z>>>((A+32|0)>>>0))+y|0;C=B;D=a[t+(B<<2)+2|0]|0;E=z;F=v+9|0;G=b[t+(B<<2)>>1]|0}else{C=x;D=A;E=u;F=v;G=y}y=E<<D;A=D+F|0;do{if((G|0)==0){x=y>>>26;B=A+6|0;z=n+(B>>>3)|0;H=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7);B=H>>24;do{if((B|0)==-128){I=H<<16;J=A+22|0;K=H>>>16|-256}else{if((B|0)!=0){I=H<<8;J=A+14|0;K=B;break}I=H<<16;J=A+22|0;K=H>>>16&255}}while(0);H=w+1+x|0;if((H|0)>63){L=15;break b}B=d[f+368+H|0]|0;if((K|0)<0){M=I;N=J;O=-(((ca(ca(K,m)|0,e[f+12560+(B<<1)>>1]|0)|0)>>>4)+65535|1)&65535;P=H;Q=B;break}else{z=ca(K,k)|0;M=I;N=J;O=(((ca(z,e[f+12560+(B<<1)>>1]|0)|0)>>>4)+65535|1)&65535;P=H;Q=B;break}}else{B=(d[t+(C<<2)+3|0]|0)+w|0;if((B|0)>63){L=8;break b}H=d[f+368+B|0]|0;z=ca(G,k)|0;R=y>>31;M=y<<1;N=A+1|0;O=((((ca(z,e[f+12560+(H<<1)>>1]|0)|0)>>>4)+65535|1)^R)-R&65535;P=B;Q=H}}while(0);b[g+(Q<<1)>>1]=O;if((M|0)<-1073741824){r=N;s=P;break a}A=n+(N>>>3)|0;u=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(N&7);v=N;w=P}if((L|0)==8){w=c[f+12480>>2]|0;KIb(c[f+4>>2]|0,16,2200136,(S=i,i=i+16|0,c[S>>2]=c[f+12476>>2],c[S+8>>2]=w,S)|0);i=S;o=-1094995529;i=j;return o|0}else if((L|0)==15){w=c[f+12480>>2]|0;KIb(c[f+4>>2]|0,16,2200136,(S=i,i=i+16|0,c[S>>2]=c[f+12476>>2],c[S+8>>2]=w,S)|0);i=S;o=-1094995529;i=j;return o|0}}}while(0);c[l>>2]=r+2;c[f+180+(h<<2)>>2]=s;o=0;i=j;return o|0}function nRa(b){b=b|0;var d=0,e=0;d=c[b+60>>2]|0;e=0;do{a[d+(e+11184)|0]=e;e=e+1|0;}while((e|0)<64);e=d;uTa(e);c[d+4>>2]=b;c[d+60>>2]=c[b+88>>2];c[d+64>>2]=c[b+92>>2];hRa(e);jRa();c[d+14672>>2]=0;c[d+108>>2]=0;c[d+14676>>2]=0;e=(c[b+12>>2]|0)+12|0;c[d+48>>2]=c[e>>2];c[b+396>>2]=1;c[b+400>>2]=(c[e>>2]|0)==1?2:1;return 0}function oRa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[g+24>>2]|0;c[j>>2]=l;m=c[g+28>>2]|0;c[k>>2]=m;g=a+60|0;n=c[g>>2]|0;o=e;if((m|0)==0){p=3}else if((m|0)==4){e=l;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)==-1224671232){p=3}}if((p|0)==3){if((c[n+13944>>2]|0)!=0){q=m;i=h;return q|0}e=n+9852|0;r=c[e>>2]|0;if((r|0)==0){q=m;i=h;return q|0}s=YHb(o,r|0)|0;if((s|0)<0){q=s;i=h;return q|0}c[e>>2]=0;c[f>>2]=1;q=c[k>>2]|0;i=h;return q|0}do{if((c[n+60>>2]&65536|0)!=0){e=n+13744|0;if((IWa(e,kRa(e,l,m,0)|0,j,k)|0)>=0){break}q=c[k>>2]|0;i=h;return q|0}}while(0);m=F5a(c[a+52>>2]|0)|0;c[n+88>>2]=m;do{if((c[n+14672>>2]|0)==0){if(!((m|0)==844251990|(m|0)==808539970)){break}l=c[g>>2]|0;e=l;c[l+28>>2]=0;s=l+14672|0;if((c[s>>2]|0)==0){t=l}else{xTa(e);c[s>>2]=0;t=c[g>>2]|0}r=l+8|0;c[r>>2]=c[a+128>>2];u=l+12|0;c[u>>2]=c[a+132>>2];c[a+176>>2]=0;c[l+13944>>2]=1;v=c[t+14212>>2]|0;if((v|0)<2){w=I5a(a,(c[a+48>>2]|0)==1?798400:796608)|0}else{w=(v|0)==2?4:5}v=a+140|0;c[v>>2]=w;x=E5a(a)|0;c[a+712>>2]=x;y=(x|0)==0;if(y){if(((c[v>>2]|0)-37|0)>>>0<2>>>0){p=19}}else{p=19}do{if((p|0)==19){x=a+788|0;if((c[x>>2]|0)==0){c[x>>2]=2}if(y){break}if((c[v>>2]|0)!=16){break}c[(c[g>>2]|0)+14288>>2]=1;c[a+292>>2]=2}}while(0);if((rTa(e)|0)<0){break}c[s>>2]=1;v=l+12560|0;y=l+12688|0;x=l+12816|0;z=l+12944|0;A=0;do{B=d[l+(A+11184)|0]|0;C=b[1346848+(A<<1)>>1]|0;b[v+(B<<1)>>1]=C;b[y+(B<<1)>>1]=C;C=b[1346720+(A<<1)>>1]|0;b[x+(B<<1)>>1]=C;b[z+(B<<1)>>1]=C;A=A+1|0;}while((A|0)<64);c[l+14152>>2]=1;c[l+14224>>2]=1;c[l+14172>>2]=3;c[l+14240>>2]=0;c[l+14180>>2]=1;c[l+14212>>2]=1;if((c[l+88>>2]|0)==808539970){c[(c[l+4>>2]|0)+48>>2]=1;c[l+48>>2]=1}else{c[l+14284>>2]=1;c[(c[l+4>>2]|0)+48>>2]=2;c[l+48>>2]=2}c[l+14732>>2]=c[r>>2];c[l+14736>>2]=c[u>>2];c[l+14740>>2]=1}}while(0);c[n+14724>>2]=0;g=c[a+96>>2]|0;do{if((g|0)!=0){p=n+14764|0;if((c[p>>2]|0)!=0){break}w=rRa(a,o,f,g,c[a+100>>2]|0)|0;if((c[f>>2]|0)!=0){KIb(a,16,2549160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;c[f>>2]=0}c[p>>2]=1;if((w|0)>=0){break}if((c[a+696>>2]&8|0)==0){break}c[n+9856>>2]=0;q=w;i=h;return q|0}}while(0);g=rRa(a,o,f,c[j>>2]|0,c[k>>2]|0)|0;do{if((g|0)>=0){if((c[f>>2]|0)==0){q=g}else{break}i=h;return q|0}}while(0);c[n+9856>>2]=0;q=g;i=h;return q|0}function pRa(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((c[b+14672>>2]|0)!=0){xTa(b)}mJb(b+14716|0);return 0}function qRa(a){a=a|0;c[(c[a+60>>2]|0)+14752>>2]=0;PTa(a);return}function rRa(f,h,j,k,l){f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,re=0,se=0,te=0,ue=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0;m=i;i=i+336|0;n=m|0;o=m+24|0;p=m+152|0;q=m+256|0;r=m+264|0;s=m+272|0;t=m+280|0;u=m+288|0;v=m+296|0;w=m+304|0;x=m+312|0;y=m+320|0;z=m+328|0;A=f+60|0;B=c[A>>2]|0;C=B;D=B;E=k+l|0;c[z>>2]=-1;F=U5a(k,E,z)|0;H=c[z>>2]|0;do{if(H>>>0>511>>>0){I=F;J=4}else{K=E;L=f+688|0;M=B+14152|0;N=B+14172|0;O=B+4|0;P=B+14240|0;Q=B+120|0;R=B+140|0;S=B+9928|0;T=B+124|0;U=B+14180|0;V=B+14224|0;W=B+48|0;X=B+9848|0;Y=B+9992|0;Z=B+9988|0;_=B+14752|0;$=B+9852|0;aa=f+856|0;ba=B+14672|0;da=f+328|0;ea=f+332|0;fa=f;ga=f+696|0;ha=B+14760|0;ia=B+9856|0;ja=f+140|0;ka=B+14724|0;la=B+13708|0;ma=B+13704|0;na=B+14120|0;oa=na;pa=na;na=B+14132|0;qa=B+14136|0;ra=B+14124|0;sa=B+14128|0;ta=B+14236|0;ua=B+14192|0;va=B+9960|0;wa=B+14424|0;xa=B+12476|0;ya=B+12480|0;za=B+88|0;Aa=B+116|0;Ba=B+12484|0;Ca=B+14156|0;Da=B+14160|0;Ea=B+14164|0;Fa=B+14168|0;Ga=B+14200|0;Ha=B+14184|0;Ia=B+14176|0;Ja=B+14188|0;Ka=B+14196|0;La=B+14204|0;Ma=B+14208|0;Na=B+14340|0;Oa=B+14212|0;Pa=B+10096|0;Qa=B+14220|0;Ra=B+11824|0;Sa=B+12488|0;Ta=B+64|0;Ua=B+12560|0;Va=B+12688|0;Wa=Ra;Xa=B+11832|0;Ya=B+11744|0;Za=B+11828|0;_a=B+11836|0;$a=B+11748|0;ab=B+9160|0;bb=B+11736|0;cb=B+11740|0;db=B+11840|0;eb=B+11848|0;fb=B+11776|0;gb=B+11844|0;hb=B+11852|0;ib=B+11780|0;jb=B+14232|0;kb=B+14228|0;lb=B+11816|0;mb=B+11808|0;nb=B+180|0;ob=B+12816|0;pb=B+12944|0;qb=B+9148|0;rb=B+12544|0;sb=B+14216|0;tb=B+12548|0;ub=B+12552|0;vb=B+56|0;wb=B+128|0;xb=B+9924|0;yb=B+9180|0;zb=B+9152|0;Ab=B+9184|0;Bb=B+7624|0;Cb=B+7628|0;Db=B+7632|0;Eb=B+7636|0;Fb=B+14680|0;Gb=B+14716|0;Hb=Gb;Ib=B+14712|0;Jb=B+14704|0;Kb=B+14720|0;Lb=f+96|0;Mb=B+8|0;Nb=B+12|0;Ob=B+14756|0;Pb=p|0;Qb=m+216|0;Rb=q;Sb=w;Tb=y;Ub=f+48|0;Vb=f+176|0;Wb=f+108|0;Xb=f+104|0;Yb=f+224|0;Zb=f+112|0;_b=f+712|0;$b=f+788|0;ac=f+292|0;bc=o;cc=t|0;dc=t+4|0;ec=u|0;fc=u+4|0;gc=v|0;hc=v+4|0;ic=r|0;jc=r+4|0;kc=x|0;lc=x+4|0;mc=f+540|0;nc=f+72|0;oc=f+128|0;pc=f+132|0;qc=B+24|0;rc=B+13944|0;sc=B+60|0;tc=B+14744|0;uc=B+14748|0;vc=B+14684|0;wc=B+14688|0;xc=B+14692|0;yc=B+14694|0;zc=B+14696|0;Ac=B+14698|0;Bc=B+14700|0;Cc=B+14702|0;Dc=B+7712|0;Ec=B+7708|0;Fc=B+11184|0;Gc=B+232|0;Hc=B+364|0;Ic=f+272|0;Jc=m+8|0;Kc=f+616|0;Lc=k;Mc=0;Nc=0;Oc=0;Pc=F;Qc=H;a:while(1){Rc=Pc;Sc=K-Rc|0;if((c[L>>2]&256|0)==0){Tc=Qc}else{KIb(fa,48,2531240,(Uc=i,i=i+24|0,c[Uc>>2]=Qc,c[Uc+8>>2]=Rc-Lc,c[Uc+16>>2]=Sc,Uc)|0);i=Uc;Tc=c[z>>2]|0}b:do{switch(Tc|0){case 434:{Rc=Pc+Sc|0;if((Sc|0)>29){Vc=(c[A>>2]|0)+14756|0;Wc=0;do{if((grc(Pc+Wc|0,2185352,9)|0)==0){c[Vc>>2]=1}Wc=Wc+1|0;}while((Wc|0)<20)}Wc=Rc;if((Sc|0)<=4){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Vc=a[Pc]|0;do{if(Vc<<24>>24==68){if((a[Pc+1|0]|0)!=84){break}if((a[Pc+2|0]|0)!=71){break}if((a[Pc+3|0]|0)!=49){break}$c=d[Pc+4|0]|0;ad=($c&128|0)==0?Pc+5|0:Pc+7|0;if(($c&64|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((Wc-ad|0)<1){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}c[Ic>>2]=a[ad]&15;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}while(0);if((Sc|0)<=5){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}do{if(Vc<<24>>24==74){if((a[Pc+1|0]|0)!=80){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+2|0]|0)!=51){break}if((a[Pc+3|0]|0)!=68){break}if((a[Pc+4|0]|0)!=3){break}Wc=a[Pc+5|0]&127;Rc=Wc&255;if(!((Wc<<24>>24|0)==3|(Wc<<24>>24|0)==4|(Wc<<24>>24|0)==8|(Wc<<24>>24|0)==35)){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Wc=c[A>>2]|0;c[Wc+14712>>2]=1;if((Rc|0)==3){c[Wc+14704>>2]=1;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else if((Rc|0)==4){c[Wc+14704>>2]=2;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else if((Rc|0)==8){c[Wc+14704>>2]=0;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else if((Rc|0)==35){c[Wc+14704>>2]=5;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}}while(0);Wc=c[A>>2]|0;do{if(Vc<<24>>24==71){if((a[Pc+1|0]|0)!=65){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+2|0]|0)!=57){break}if((a[Pc+3|0]|0)!=52){break}if((a[Pc+4|0]|0)!=3){break}Rc=d[Pc+5|0]|0;if((Rc&64|0)==0){break}ad=Rc&31;if((ad|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Rc=ad*3|0;if((Rc+7|0)>(Sc|0)){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}ad=Wc+14716|0;mJb(ad);$c=Wc+14720|0;c[$c>>2]=Rc;bd=hJb(Rc)|0;c[ad>>2]=bd;if((bd|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}nrc(bd|0,Pc+7|0,c[$c>>2]|0)|0;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}while(0);if(!((Sc|0)>10&Vc<<24>>24==67)){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+1|0]|0)!=67){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+2|0]|0)!=1){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}if((a[Pc+3|0]|0)==-8){cd=5;dd=0}else{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}while(1){$c=cd+6|0;if(($c|0)>(Sc|0)){break}if((a[Pc+cd|0]&-2)<<24>>24==-2){cd=$c;dd=dd+1|0}else{break}}if((dd|0)<=0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Vc=Wc+14716|0;mJb(Vc);$c=dd*6|0;c[Wc+14720>>2]=$c;bd=hJb($c)|0;c[Vc>>2]=bd;if((bd|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}Vc=a[Pc+4|0]|0;$c=(Vc<<24>>24>>7)-3&255;ad=(Vc&255)>>>7|-4;Vc=Pc+5|0;Rc=0;ed=bd;while(1){a[ed]=(a[Vc]|0)==-1?$c:-3;a[ed+1|0]=a[Vc+1|0]|0;a[ed+2|0]=a[Vc+2|0]|0;a[ed+3|0]=(a[Vc+3|0]|0)==-1?ad:-3;a[ed+4|0]=a[Vc+4|0]|0;a[ed+5|0]=a[Vc+5|0]|0;bd=Rc+1|0;if((bd|0)<(dd|0)){Vc=Vc+6|0;Rc=bd;ed=ed+6|0}else{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break}}break};case 435:{if((Mc|0)!=0){KIb(fa,16,2516016,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}ed=c[A>>2]|0;Rc=ed;Vc=Sc<<3;ad=Vc>>>0>2147483639>>>0|(Pc|0)==0;$c=ad?0:Pc;Wc=ad?0:Vc;Vc=ed+14120|0;c[Vc>>2]=$c;c[ed+14132>>2]=Wc;c[ed+14136>>2]=Wc+8;c[ed+14124>>2]=$c+(Wc>>3);Wc=ed+14128|0;c[Wc>>2]=0;ad=$c;bd=(je(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)>>>20;c[Wc>>2]=12;ad=$c+1|0;gd=(je(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)>>>16&4095;c[Wc>>2]=24;do{if((bd|0)==0|(gd|0)==0){KIb(fa,24,2159968,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;if((c[ga>>2]&131074|0)!=0){break}hd=c[Wc>>2]|0;id=c[Vc>>2]|0;J=33}else{hd=24;id=$c;J=33}}while(0);do{if((J|0)==33){J=0;$c=id+(hd>>>3)|0;ad=(je(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(hd&7)>>>28;$c=hd+4|0;c[Wc>>2]=$c;c[ed+13928>>2]=ad;if((ad|0)==0){KIb(fa,16,2158056,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;if((c[ga>>2]&131074|0)!=0){break}jd=c[Wc>>2]|0;kd=c[Vc>>2]|0}else{jd=$c;kd=id}$c=kd+(jd>>>3)|0;ad=(je(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(jd&7);$c=ad>>>28;ld=jd+4|0;c[Wc>>2]=ld;c[ed+10012>>2]=$c;if(($c|0)==0|ad>>>0>3758096383>>>0){break}ad=kd+(ld>>>3)|0;$c=(je(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)<<(ld&7)>>>14;ld=jd+22|0;c[Wc>>2]=ld;ad=ed+24|0;c[ad>>2]=$c*400|0;$c=d[kd+(ld>>>3)|0]|0;md=jd+23|0;c[Wc>>2]=md;if(($c&128>>>((ld&7)>>>0)|0)==0){break}c[ed+8>>2]=bd;c[ed+12>>2]=gd;ld=kd+(md>>>3)|0;$c=(je(d[ld]|d[ld+1|0]<<8|d[ld+2|0]<<16|d[ld+3|0]<<24|0)|0)<<(md&7)>>>22;c[Wc>>2]=jd+33;md=ed+4|0;c[(c[md>>2]|0)+524>>2]=$c<<14;$c=c[Wc>>2]|0;ld=$c+1|0;c[Wc>>2]=ld;nd=d[kd+(ld>>>3)|0]|0;c[Wc>>2]=$c+2;if((128>>>((ld&7)>>>0)&nd|0)==0){nd=ed+12560|0;ld=ed+12688|0;$c=0;do{od=d[ed+($c+11184)|0]|0;pd=b[1346848+($c<<1)>>1]|0;b[nd+(od<<1)>>1]=pd;b[ld+(od<<1)>>1]=pd;$c=$c+1|0;}while(($c|0)<64)}else{uRa(Rc,ed+12688|0,ed+12560|0,1)}$c=c[Wc>>2]|0;ld=d[(c[Vc>>2]|0)+($c>>>3)|0]|0;c[Wc>>2]=$c+1;if((ld&128>>>(($c&7)>>>0)|0)==0){$c=ed+12816|0;ld=ed+12944|0;nd=0;do{pd=d[ed+(nd+11184)|0]|0;od=b[1346720+(nd<<1)>>1]|0;b[$c+(pd<<1)>>1]=od;b[ld+(pd<<1)>>1]=od;nd=nd+1|0;}while((nd|0)<64)}else{uRa(Rc,ed+12944|0,ed+12816|0,0)}nd=c[Wc>>2]|0;ld=(c[Vc>>2]|0)+(nd>>>3)|0;if(((je(d[ld]|d[ld+1|0]<<8|d[ld+2|0]<<16|d[ld+3|0]<<24|0)|0)&-512>>>((nd&7)>>>0)|0)!=0){KIb(c[md>>2]|0,16,2156256,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;break}c[ed+14152>>2]=1;c[ed+14224>>2]=1;c[ed+14172>>2]=3;c[ed+14240>>2]=0;c[ed+14180>>2]=1;c[ed+14212>>2]=1;nd=c[md>>2]|0;c[nd+48>>2]=1;c[ed+48>>2]=1;c[ed+28>>2]=0;c[ed+14284>>2]=0;if((c[ed+60>>2]&524288|0)!=0){c[ed+13944>>2]=1}if((c[nd+688>>2]&1|0)==0){break}ld=c[ad>>2]|0;KIb(nd,48,2154568,(Uc=i,i=i+16|0,c[Uc>>2]=c[nd+524>>2],c[Uc+8>>2]=ld,Uc)|0);i=Uc}}while(0);if((c[Lb>>2]|0)==(k|0)){Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break b}c[_>>2]=1;Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break};case 440:{if((Mc|0)!=0){KIb(fa,16,2430352,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}c[P>>2]=0;ed=c[A>>2]|0;Vc=Sc<<3;Wc=Vc>>>0>2147483639>>>0|(Pc|0)==0;Rc=Wc?0:Pc;gd=Wc?0:Vc;c[ed+14120>>2]=Rc;c[ed+14132>>2]=gd;c[ed+14136>>2]=gd+8;c[ed+14124>>2]=Rc+(gd>>3);gd=ed+14128|0;c[gd>>2]=0;Vc=Rc;Wc=(je(d[Vc]|d[Vc+1|0]<<8|d[Vc+2|0]<<16|d[Vc+3|0]<<24|0)|0)>>>7;c[gd>>2]=25;c[Kc>>2]=Wc;c[Kc+4>>2]=0;Vc=Rc+3|0;Rc=(d[Vc]|0)>>>6;c[gd>>2]=26;bd=ed+9988|0;c[bd>>2]=Rc&1;Rc=a[Vc]|0;c[gd>>2]=27;gd=ed+4|0;if((c[(c[gd>>2]|0)+688>>2]&1|0)!=0){pLb(Jc,Wc)|0;Wc=c[bd>>2]|0;KIb(c[gd>>2]|0,48,2187952,(Uc=i,i=i+24|0,c[Uc>>2]=Jc,c[Uc+8>>2]=Wc,c[Uc+16>>2]=(Rc&255)>>>5&1,Uc)|0);i=Uc}c[_>>2]=1;Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break};case 437:{Rc=Sc<<3;Wc=Rc>>>0>2147483639>>>0|(Pc|0)==0;gd=Wc?0:Pc;bd=Wc?0:Rc;c[pa>>2]=gd;c[na>>2]=bd;c[qa>>2]=bd+8;c[ra>>2]=gd+(bd>>3);c[sa>>2]=0;bd=gd;Rc=(d[bd]|d[bd+1|0]<<8|d[bd+2|0]<<16|d[bd+3|0]<<24|0)>>>4&15;c[sa>>2]=4;switch(Rc|0){case 3:{Rc=a[gd]|0;c[sa>>2]=5;if((Rc&8)==0){qd=5;rd=gd}else{uRa(D,Va,Ua,1);qd=c[sa>>2]|0;rd=c[pa>>2]|0}Rc=d[rd+(qd>>>3)|0]|0;Wc=qd+1|0;c[sa>>2]=Wc;if((Rc&128>>>((qd&7)>>>0)|0)==0){sd=Wc;td=rd}else{uRa(D,pb,ob,0);sd=c[sa>>2]|0;td=c[pa>>2]|0}Wc=d[td+(sd>>>3)|0]|0;Rc=sd+1|0;c[sa>>2]=Rc;c:do{if((Wc&128>>>((sd&7)>>>0)|0)!=0){ed=0;Vc=Rc;ld=td;while(1){nd=d[(d[1242080+ed|0]|0)+(D+11184)|0]|0;$c=ld+(Vc>>>3)|0;od=(je(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(Vc&7)>>>24;c[sa>>2]=Vc+8;if((od|0)==0){break}if((ed|0)!=0|(od|0)==8){ud=od&65535}else{KIb(c[O>>2]|0,48,2176176,(Uc=i,i=i+8|0,c[Uc>>2]=od,Uc)|0);i=Uc;ud=8}b[D+12688+(nd<<1)>>1]=ud;nd=ed+1|0;if((nd|0)>=64){break c}ed=nd;Vc=c[sa>>2]|0;ld=c[pa>>2]|0}KIb(c[O>>2]|0,16,2178696,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc}}while(0);Rc=c[sa>>2]|0;Wc=c[pa>>2]|0;ld=d[Wc+(Rc>>>3)|0]|0;Vc=Rc+1|0;c[sa>>2]=Vc;if((ld&128>>>((Rc&7)>>>0)|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{vd=0;wd=Vc}while(1){Vc=a[(d[1242080+vd|0]|0)+(D+11184)|0]|0;Rc=Wc+(wd>>>3)|0;ld=(je(d[Rc]|d[Rc+1|0]<<8|d[Rc+2|0]<<16|d[Rc+3|0]<<24|0)|0)<<(wd&7)>>>24;Rc=wd+8|0;c[sa>>2]=Rc;if((ld|0)==0){break}b[D+12944+((Vc&255)<<1)>>1]=ld;ld=vd+1|0;if((ld|0)<64){vd=ld;wd=Rc}else{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}KIb(c[O>>2]|0,16,2178696,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b;break};case 1:{if((Mc|0)!=0){KIb(fa,16,2459208,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}c[sa>>2]=5;Wc=(d[bd]|d[bd+1|0]<<8|d[bd+2|0]<<16|d[bd+3|0]<<24)&7;c[sa>>2]=8;Rc=c[O>>2]|0;ld=Rc+840|0;c[ld>>2]=Wc;Wc=c[sa>>2]|0;Vc=gd+(Wc>>>3)|0;ed=(je(d[Vc]|d[Vc+1|0]<<8|d[Vc+2|0]<<16|d[Vc+3|0]<<24|0)|0)<<(Wc&7)>>>28;c[sa>>2]=Wc+4;Wc=Rc+844|0;c[Wc>>2]=ed;ed=c[sa>>2]|0;Vc=d[gd+(ed>>>3)|0]<<(ed&7)>>>7;ad=ed+1|0;c[sa>>2]=ad;c[M>>2]=Vc&1;Vc=gd+(ad>>>3)|0;md=(je(d[Vc]|d[Vc+1|0]<<8|d[Vc+2|0]<<16|d[Vc+3|0]<<24|0)|0)<<(ad&7)>>>30;ad=ed+3|0;c[sa>>2]=ad;c[Oa>>2]=md;md=gd+(ad>>>3)|0;Vc=(je(d[md]|d[md+1|0]<<8|d[md+2|0]<<16|d[md+3|0]<<24|0)|0)<<(ad&7)>>>30;ad=ed+5|0;c[sa>>2]=ad;md=gd+(ad>>>3)|0;nd=(je(d[md]|d[md+1|0]<<8|d[md+2|0]<<16|d[md+3|0]<<24|0)|0)<<(ad&7)>>>30;ad=ed+7|0;c[sa>>2]=ad;c[Mb>>2]=c[Mb>>2]|Vc<<12;c[Nb>>2]=nd<<12|c[Nb>>2];nd=gd+(ad>>>3)|0;Vc=ca((je(d[nd]|d[nd+1|0]<<8|d[nd+2|0]<<16|d[nd+3|0]<<24|0)|0)<<(ad&7)>>>20,104857600)|0;c[qc>>2]=Vc+(c[qc>>2]|0);Vc=ed+20|0;c[sa>>2]=Vc;ad=gd+(Vc>>>3)|0;nd=(je(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)<<(Vc&7)&-16777216;c[sa>>2]=ed+28;ed=Rc+524|0;c[ed>>2]=nd+(c[ed>>2]|0);nd=c[sa>>2]|0;Vc=d[gd+(nd>>>3)|0]<<(nd&7)>>>7;ad=nd+1|0;c[sa>>2]=ad;c[rc>>2]=Vc&1;if((c[sc>>2]&524288|0)!=0){c[rc>>2]=1}Vc=gd+(ad>>>3)|0;md=(je(d[Vc]|d[Vc+1|0]<<8|d[Vc+2|0]<<16|d[Vc+3|0]<<24|0)|0)<<(ad&7)>>>30;ad=nd+3|0;c[sa>>2]=ad;c[tc>>2]=md+1;md=gd+(ad>>>3)|0;Vc=(je(d[md]|d[md+1|0]<<8|d[md+2|0]<<16|d[md+3|0]<<24|0)|0)<<(ad&7)>>>27;c[sa>>2]=nd+8;c[uc>>2]=Vc+1;c[Rc+48>>2]=2;c[W>>2]=2;if((c[Rc+688>>2]&1|0)==0){Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break b}Vc=c[Wc>>2]|0;Wc=c[M>>2]|0;nd=c[Oa>>2]|0;ad=c[ed>>2]|0;ed=c[qc>>2]|0;KIb(Rc,48,2164e3,(Uc=i,i=i+48|0,c[Uc>>2]=c[ld>>2],c[Uc+8>>2]=Vc,c[Uc+16>>2]=Wc,c[Uc+24>>2]=nd,c[Uc+32>>2]=ad,c[Uc+40>>2]=ed,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=0;_c=Pc;break b;break};case 2:{c[sa>>2]=7;ed=a[gd]|0;c[sa>>2]=8;if((ed&1)==0){xd=8;yd=c[O>>2]|0}else{ed=gd+1|0;ad=(d[ed]|d[ed+1|0]<<8|d[ed+2|0]<<16|d[ed+3|0]<<24)&255;c[sa>>2]=16;ed=c[O>>2]|0;c[ed+384>>2]=ad;ad=gd+2|0;nd=(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24)&255;c[sa>>2]=24;c[ed+388>>2]=nd;nd=gd+3|0;ad=(d[nd]|d[nd+1|0]<<8|d[nd+2|0]<<16|d[nd+3|0]<<24)&255;c[sa>>2]=32;c[ed+392>>2]=ad;xd=32;yd=ed}ed=gd+(xd>>>3)|0;ad=(je(d[ed]|d[ed+1|0]<<8|d[ed+2|0]<<16|d[ed+3|0]<<24|0)|0)>>>18;ed=xd+15|0;c[sa>>2]=ed;nd=gd+(ed>>>3)|0;ed=(je(d[nd]|d[nd+1|0]<<8|d[nd+2|0]<<16|d[nd+3|0]<<24|0)|0)>>>11&16383;c[sa>>2]=xd+29;c[vc>>2]=ad<<4;c[wc>>2]=ed<<4;if((c[yd+688>>2]&1|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}KIb(yd,48,2168344,(Uc=i,i=i+16|0,c[Uc>>2]=ad,c[Uc+8>>2]=ed,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b;break};case 7:{do{if((c[M>>2]|0)==0){if((c[N>>2]|0)!=3){zd=1;break}zd=(c[La>>2]|0)==0?2:3}else{if((c[La>>2]|0)==0){zd=1;break}zd=(c[Ha>>2]|0)==0?2:3}}while(0);ed=0;ad=4;nd=gd;while(1){Wc=nd+(ad>>>3)|0;Vc=(je(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)<<(ad&7)>>>16;c[sa>>2]=ad+16;b[C+14692+(ed<<2)>>1]=Vc;Vc=c[sa>>2]|0;Wc=Vc+1|0;c[sa>>2]=Wc;ld=(c[pa>>2]|0)+(Wc>>>3)|0;Rc=(je(d[ld]|d[ld+1|0]<<8|d[ld+2|0]<<16|d[ld+3|0]<<24|0)|0)<<(Wc&7)>>>16;c[sa>>2]=Vc+17;b[C+14692+(ed<<2)+2>>1]=Rc;Rc=(c[sa>>2]|0)+1|0;c[sa>>2]=Rc;Vc=ed+1|0;if((Vc|0)>=(zd|0)){break}ed=Vc;ad=Rc;nd=c[pa>>2]|0}nd=c[O>>2]|0;if((c[nd+688>>2]&1|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}ad=b[yc>>1]|0;ed=b[zc>>1]|0;Rc=b[Ac>>1]|0;Vc=b[Bc>>1]|0;Wc=b[Cc>>1]|0;KIb(nd,48,2181008,(Uc=i,i=i+48|0,c[Uc>>2]=b[xc>>1]|0,c[Uc+8>>2]=ad,c[Uc+16>>2]=ed,c[Uc+24>>2]=Rc,c[Uc+32>>2]=Vc,c[Uc+40>>2]=Wc,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b;break};case 8:{if((Mc|0)!=256){KIb(fa,16,2442368,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}c[jb>>2]=0;c[kb>>2]=0;Wc=(d[bd]|d[bd+1|0]<<8|d[bd+2|0]<<16|d[bd+3|0]<<24)&15;c[sa>>2]=8;c[Ca>>2]=Wc;Vc=gd+1|0;Rc=(d[Vc]|d[Vc+1|0]<<8|d[Vc+2|0]<<16|d[Vc+3|0]<<24|0)>>>4&15;c[sa>>2]=12;c[Da>>2]=Rc;ed=(d[Vc]|d[Vc+1|0]<<8|d[Vc+2|0]<<16|d[Vc+3|0]<<24)&15;c[sa>>2]=16;c[Ea>>2]=ed;Vc=gd+2|0;ad=(d[Vc]|d[Vc+1|0]<<8|d[Vc+2|0]<<16|d[Vc+3|0]<<24|0)>>>4&15;c[sa>>2]=20;c[Fa>>2]=ad;do{if((c[Y>>2]|0)==0){if((c[ba>>2]|0)==0){Ad=Wc;Bd=Rc;Cd=ed;Dd=ad;Ed=20;Fd=gd;break}KIb(c[O>>2]|0,16,2183088,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;Vc=c[Ea>>2]|0;nd=c[Fa>>2]|0;d:do{if((Vc|0)==15&(nd|0)==15){ld=c[Ca>>2]|0;do{if((ld|0)==15){if((c[Da>>2]|0)!=15){break}c[Y>>2]=1;Gd=1;Id=15;Jd=15;break d}}while(0);c[Y>>2]=2;Gd=2;Id=ld;Jd=15}else{c[Y>>2]=3;Gd=3;Id=c[Ca>>2]|0;Jd=nd}}while(0);c[Dc>>2]=Gd;c[Ec>>2]=(Gd|0)==1;Ad=Id;Bd=c[Da>>2]|0;Cd=Vc;Dd=Jd;Ed=c[sa>>2]|0;Fd=c[pa>>2]|0}else{Ad=Wc;Bd=Rc;Cd=ed;Dd=ad;Ed=20;Fd=gd}}while(0);c[Ca>>2]=((Ad|0)==0)+Ad;c[Da>>2]=((Bd|0)==0)+Bd;c[Ea>>2]=((Cd|0)==0)+Cd;c[Fa>>2]=((Dd|0)==0)+Dd;gd=Fd+(Ed>>>3)|0;ad=(je(d[gd]|d[gd+1|0]<<8|d[gd+2|0]<<16|d[gd+3|0]<<24|0)|0)<<(Ed&7)>>>30;gd=Ed+2|0;c[sa>>2]=gd;c[Ia>>2]=ad;ad=Fd+(gd>>>3)|0;ed=(je(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)<<(gd&7)>>>30;gd=Ed+4|0;c[sa>>2]=gd;c[N>>2]=ed;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;gd=Ed+5|0;c[sa>>2]=gd;c[Ha>>2]=ed&1;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;gd=Ed+6|0;c[sa>>2]=gd;c[U>>2]=ed&1;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;gd=Ed+7|0;c[sa>>2]=gd;c[Ja>>2]=ed&1;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;gd=Ed+8|0;c[sa>>2]=gd;c[ua>>2]=ed&1;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;gd=Ed+9|0;c[sa>>2]=gd;c[Ka>>2]=ed&1;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;gd=Ed+10|0;c[sa>>2]=gd;ad=ed&1;c[Ga>>2]=ad;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;gd=Ed+11|0;c[sa>>2]=gd;c[La>>2]=ed&1;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;gd=Ed+12|0;c[sa>>2]=gd;c[Ma>>2]=ed&1;ed=d[Fd+(gd>>>3)|0]<<(gd&7)>>>7;c[sa>>2]=Ed+13;c[V>>2]=ed&1;if((ad|0)==0){L6(Fc,Gc,1242080);L6(Fc,Hc,1242080);Xc=Oc;Yc=Nc;Zc=256;_c=Pc;break b}else{L6(Fc,Gc,1433224);L6(Fc,Hc,1433224);Xc=Oc;Yc=Nc;Zc=256;_c=Pc;break b}break};default:{Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}break};case 256:{do{if((Oc|0)!=0){if((c[N>>2]|0)!=3){break}KIb(fa,24,2502064,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}}while(0);Kd=c[Mb>>2]|0;Ld=c[Nb>>2]|0;if((Kd|0)<1|(Ld|0)<1){J=59;break a}if((c[Ob>>2]|0)!=0){c[Ia>>2]=3;b[Ua>>1]=1}if(!((Mc|0)==257|(Mc|0)==0)){KIb(fa,16,2468520,(Uc=i,i=i+8|0,c[Uc>>2]=Mc,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=1;Yc=Nc;Zc=Mc;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}ad=c[A>>2]|0;ed=ad;gd=ad+14672|0;e:do{if((c[gd>>2]|0)==0){Md=ad+8|0;J=73}else{Rc=c[oc>>2]|0;Wc=ad+8|0;do{if((Rc|0)==(c[Wc>>2]|0)){bd=c[pc>>2]|0;if((bd|0)!=(c[ad+12>>2]|0)){break}if((c[ad+14732>>2]|0)!=(Rc|0)){break}if((c[ad+14736>>2]|0)!=(bd|0)){break}if((c[ad+14728>>2]|0)!=(c[ad+13928>>2]|0)){break}if((c[ad+14740>>2]|0)==(c[ad+14152>>2]|0)){Nd=0;break e}if((bd&31|0)==0){Nd=0;break e}}}while(0);Rc=ad+13744|0;c[Qb>>2]=c[Rc>>2];c[Qb+4>>2]=c[Rc+4>>2];c[Qb+8>>2]=c[Rc+8>>2];c[Qb+12>>2]=c[Rc+12>>2];c[Qb+16>>2]=c[Rc+16>>2];c[Qb+20>>2]=c[Rc+20>>2];c[Qb+24>>2]=c[Rc+24>>2];c[Qb+28>>2]=c[Rc+28>>2];c[Qb+32>>2]=c[Rc+32>>2];c[Qb+36>>2]=c[Rc+36>>2];c[Rc>>2]=0;xTa(ed);c[Rc>>2]=c[Qb>>2];c[Rc+4>>2]=c[Qb+4>>2];c[Rc+8>>2]=c[Qb+8>>2];c[Rc+12>>2]=c[Qb+12>>2];c[Rc+16>>2]=c[Qb+16>>2];c[Rc+20>>2]=c[Qb+20>>2];c[Rc+24>>2]=c[Qb+24>>2];c[Rc+28>>2]=c[Qb+28>>2];c[Rc+32>>2]=c[Qb+32>>2];c[Rc+36>>2]=c[Qb+36>>2];c[gd>>2]=0;Md=Wc;J=73}}while(0);do{if((J|0)==73){J=0;Rc=c[Md>>2]|0;if((Rc|0)==0){Nd=-2;break}Vc=ad+12|0;bd=c[Vc>>2]|0;if((bd|0)==0){Nd=-2;break}nd=H4a(f,Rc,bd)|0;if((nd|0)<0){Nd=nd;break}nd=c[Ub>>2]|0;do{if((nd|0)==1){bd=c[ad+24>>2]|0;if((bd|0)==0){break}else if((bd|0)==104857200){if((c[ad+9996>>2]|0)==65535){break}}c[nc>>2]=bd}else if((nd|0)==2){bd=c[ad+24>>2]|0;if((bd|0)==0){break}c[mc>>2]=bd}}while(0);Wc=ad+13928|0;c[ad+14728>>2]=c[Wc>>2];c[ad+14732>>2]=c[Md>>2];c[ad+14736>>2]=c[Vc>>2];c[ad+14740>>2]=c[ad+14152>>2];c[Vb>>2]=(c[ad+13944>>2]|0)==0;f:do{if((nd|0)==1){bd=ad+10012|0;c[Wb>>2]=c[1347880+(c[bd>>2]<<3)>>2];c[Xb>>2]=c[1347884+(c[bd>>2]<<3)>>2];AKb(Rb,1.0/+g[1347488+(c[Wc>>2]<<2)>>2],255);bd=c[q+4>>2]|0;c[Yb>>2]=c[q>>2];c[Yb+4>>2]=bd;c[Zb>>2]=1}else{bd=ad+4|0;Rc=c[bd>>2]|0;md=c[ad+10012>>2]|0;od=ca(c[1347880+(md<<3)>>2]<<1,c[ad+14744>>2]|0)|0;$c=ca(c[ad+14748>>2]|0,c[1347884+(md<<3)>>2]|0)|0;xKb(Rc+108|0,Rc+104|0,od,(od|0)<0|0?-1:0,$c,($c|0)<0|0?-1:0,1073741824,0)|0;c[Zb>>2]=2;$c=c[Wc>>2]|0;if(($c|0)<=1){od=1346112+($c<<3)|0;Rc=(c[bd>>2]|0)+224|0;md=c[od+4>>2]|0;c[Rc>>2]=c[od>>2];c[Rc+4>>2]=md;break}md=ad+14684|0;c[cc>>2]=c[md>>2];Rc=ad+14688|0;c[dc>>2]=c[Rc>>2];zKb(s,1346112+($c<<3)|0,t);c[ec>>2]=c[Md>>2];c[fc>>2]=c[Vc>>2];yKb(r,s,u);$c=c[md>>2]|0;do{if(($c|0)!=0){if((c[Rc>>2]|0)==0){break}md=c[ic>>2]|0;od=c[jc>>2]|0;pd=md;Od=(md|0)<0|0?-1:0;Pd=Erc(pd,Od,3,0)|0;Qd=od;Rd=(od|0)<0|0?-1:0;if((Pd|0)==(Qd<<2|0>>>30|0)&(G|0)==(Rd<<2|Qd>>>30|0)){if(!((od|0)!=0|(md|0)>0)){J=89}}else{J=89}if((J|0)==89){J=0;Pd=Erc(pd,Od,9,0)|0;if(!((Pd|0)==(Qd<<4|0>>>28|0)&(G|0)==(Rd<<4|Qd>>>28|0))){break}if(!((od|0)!=0|(md|0)>0)){break}}md=(c[bd>>2]|0)+224|0;od=1346112+(c[Wc>>2]<<3)|0;c[kc>>2]=$c;c[lc>>2]=c[Rc>>2];zKb(Tb,od,x);od=md;md=c[y+4>>2]|0;c[od>>2]=c[y>>2];c[od+4>>2]=md;break f}}while(0);Rc=(c[bd>>2]|0)+224|0;$c=1346112+(c[Wc>>2]<<3)|0;c[gc>>2]=c[Md>>2];c[hc>>2]=c[Vc>>2];zKb(Sb,$c,v);$c=Rc;Rc=c[w+4>>2]|0;c[$c>>2]=c[w>>2];c[$c+4>>2]=Rc}}while(0);Vc=c[(c[A>>2]|0)+14212>>2]|0;if((Vc|0)<2){Sd=I5a(f,(c[Ub>>2]|0)==1?798400:796608)|0}else{Sd=(Vc|0)==2?4:5}c[ja>>2]=Sd;Vc=E5a(f)|0;c[_b>>2]=Vc;Wc=(Vc|0)==0;if(Wc){if(((c[ja>>2]|0)-37|0)>>>0<2>>>0){J=99}}else{J=99}do{if((J|0)==99){J=0;if((c[$b>>2]|0)==0){c[$b>>2]=2}if(Wc){break}if((c[ja>>2]|0)!=16){break}c[(c[A>>2]|0)+14288>>2]=1;c[ac>>2]=2}}while(0);nrc(Pb|0,ad+11184|0,64)|0;if((rTa(ed)|0)<0){Nd=-2;break}Wc=ad+12560|0;Vc=Wc;nrc(bc|0,Wc|0,128)|0;Wc=0;do{b[Vc+(d[ad+(Wc+11184)|0]<<1)>>1]=b[o+(d[p+Wc|0]<<1)>>1]|0;Wc=Wc+1|0;}while((Wc|0)<64);Wc=ad+12816|0;Vc=Wc;nrc(bc|0,Wc|0,128)|0;Wc=0;do{b[Vc+(d[ad+(Wc+11184)|0]<<1)>>1]=b[o+(d[p+Wc|0]<<1)>>1]|0;Wc=Wc+1|0;}while((Wc|0)<64);Wc=ad+12688|0;Vc=Wc;nrc(bc|0,Wc|0,128)|0;Wc=0;do{b[Vc+(d[ad+(Wc+11184)|0]<<1)>>1]=b[o+(d[p+Wc|0]<<1)>>1]|0;Wc=Wc+1|0;}while((Wc|0)<64);Wc=ad+12944|0;Vc=Wc;nrc(bc|0,Wc|0,128)|0;Wc=0;do{b[Vc+(d[ad+(Wc+11184)|0]<<1)>>1]=b[o+(d[p+Wc|0]<<1)>>1]|0;Wc=Wc+1|0;}while((Wc|0)<64);c[gd>>2]=1;Nd=0}}while(0);if((Nd|0)<0){J=115;break a}gd=c[A>>2]|0;ad=Sc<<3;ed=ad>>>0>2147483639>>>0|(Pc|0)==0;Wc=ed?0:Pc;Vc=ed?0:ad;c[gd+14120>>2]=Wc;c[gd+14132>>2]=Vc;c[gd+14136>>2]=Vc+8;c[gd+14124>>2]=Wc+(Vc>>3);Vc=gd+14128|0;c[Vc>>2]=0;ad=Wc;ed=(je(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)>>>22;c[Vc>>2]=10;ad=Wc+1|0;nd=(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)>>>3&7;c[Vc>>2]=13;c[gd+9992>>2]=nd;g:do{if((nd|0)==0|nd>>>0>3>>>0){J=127}else{Rc=(je(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)>>>11&65535;c[Vc>>2]=29;c[gd+9996>>2]=Rc;do{if((nd-2|0)>>>0<2>>>0){$c=Wc+3|0;ld=(d[$c]|0)>>>2;c[Vc>>2]=30;c[gd+14228>>2]=ld&1;ld=$c;$c=(je(d[ld]|d[ld+1|0]<<8|d[ld+2|0]<<16|d[ld+3|0]<<24|0)|0)>>>23&7;c[Vc>>2]=33;ld=($c|0)==0;if(ld){if((c[ga>>2]&131074|0)!=0){J=127;break g}}md=(ld&1)+$c|0;c[gd+14156>>2]=md;c[gd+14160>>2]=md;if((nd|0)!=3){break}md=Wc+4|0;$c=(d[md]|0)>>>6;c[Vc>>2]=34;c[gd+14232>>2]=$c&1;$c=md;md=(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)>>>3&7;c[Vc>>2]=37;$c=(md|0)==0;if($c){if((c[ga>>2]&131074|0)!=0){J=127;break g}}ld=($c&1)+md|0;c[gd+14164>>2]=ld;c[gd+14168>>2]=ld}}while(0);c[gd+7712>>2]=nd;c[gd+7708>>2]=(nd|0)==1;if((c[L>>2]&1|0)!=0){KIb(fa,48,2161920,(Uc=i,i=i+24|0,c[Uc>>2]=Rc,c[Uc+8>>2]=ed,c[Uc+16>>2]=nd,Uc)|0);i=Uc}c[gd+168>>2]=8;c[gd+172>>2]=8}}while(0);if((J|0)==127){J=0;c[Y>>2]=0}c[ha>>2]=1;Xc=1;Yc=Nc;Zc=256;_c=Pc;break};default:{do{if((Tc-257|0)>>>0<175>>>0&(Mc|0)==256){do{if((c[M>>2]|0)!=0){if((c[V>>2]|0)!=0){break}c[V>>2]=1;KIb(c[O>>2]|0,16,2420048,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc}}while(0);Rc=c[N>>2]|0;if((Rc|0)==0){J=237}else{if((c[V>>2]|0)==0|(Rc|0)==3){Td=Rc}else{J=237}}if((J|0)==237){J=0;KIb(c[O>>2]|0,16,2410800,(Uc=i,i=i+8|0,c[Uc>>2]=Rc,Uc)|0);i=Uc;c[N>>2]=3;Td=3}do{if((c[M>>2]|0)==0){Ud=Td}else{if((c[U>>2]|0)!=0){Ud=Td;break}KIb(c[O>>2]|0,24,2403064,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;Ud=c[N>>2]|0}}while(0);if((Ud|0)==3){c[P>>2]=0;c[R>>2]=c[Q>>2]<<4;break}else{c[P>>2]=c[P>>2]^1;Rc=c[Q>>2]|0;c[R>>2]=Rc<<3;mrc(c[S>>2]|0,0,ca(Rc,c[T>>2]|0)|0)|0;break}}}while(0);Rc=(c[z>>2]|0)-257|0;if(Rc>>>0>174>>>0|(Mc|0)==0){Xc=Oc;Yc=Nc;Zc=Mc;_c=Pc;break b}gd=c[N>>2]|0;nd=(gd|0)!=3|0;ed=c[W>>2]|0;do{if((ed|0)==1){Vd=Rc}else{if((c[Q>>2]|0)<=175){Vd=Rc;break}Vd=(d[Pc]<<2&896)+Rc|0}}while(0);Wd=((gd|0)==2)+(Vd<<nd)|0;if((Sc|0)<2){J=249;break a}Xd=c[Q>>2]|0;if((Wd|0)>=(Xd|0)){J=251;break a}Rc=c[Y>>2]|0;if((c[X>>2]|0)==0&(Rc|0)==3){if((c[Z>>2]|0)==0){Xc=Oc;Yc=1;Zc=257;_c=Pc;break b}else{Yd=3;J=255}}else{if((Rc|0)==1){Zd=1;_d=1;J=256}else{Yd=Rc;J=255}}if((J|0)==255){J=0;if((c[Ta>>2]&4194304|0)==0){$d=Yd;ae=0}else{Zd=Yd;_d=0;J=256}}if((J|0)==256){J=0;c[_>>2]=1;$d=Zd;ae=_d}if((c[$>>2]|0)==0&($d|0)==2){if((c[_>>2]|0)==0){Xc=Oc;Yc=1;Zc=257;_c=Pc;break b}}Rc=c[aa>>2]|0;do{if((Rc|0)>7){if(($d|0)==3){Xc=Oc;Yc=1;Zc=257;_c=Pc;break b}if((Rc|0)<=31){break}if((Rc|0)>47|ae^1){Xc=Oc;Yc=1;Zc=257;_c=Pc;break b}}}while(0);if((c[ba>>2]|0)==0){Xc=Oc;Yc=Nc;Zc=257;_c=Pc;break b}if((ed|0)==2){if((Wd|0)<(c[da>>2]|0)){Xc=Oc;Yc=Nc;Zc=257;_c=Pc;break b}if((Wd|0)>=(Xd-(c[ea>>2]|0)|0)){Xc=Oc;Yc=Nc;Zc=257;_c=Pc;break b}}if(($d|0)==0){KIb(fa,16,2382288,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;if((c[ga>>2]&8|0)==0){Xc=Oc;Yc=Nc;Zc=257;_c=Pc;break b}else{fd=-1094995529;J=641;break a}}do{if((c[ha>>2]|0)==0){be=Nc}else{c[ha>>2]=0;ce=c[O>>2]|0;do{if((c[P>>2]|0)!=0|(gd|0)==3){if((DTa(D,ce)|0)<0){fd=-1;J=641;break a}STa(D);Rc=c[ia>>2]|0;nd=Rc+292|0;c[nd>>2]=0;do{if((c[La>>2]|0)!=0){if((c[M>>2]|0)==0){if((c[V>>2]|0)==0){break}c[nd>>2]=1;break}if((c[Ha>>2]|0)==0){c[nd>>2]=2;break}else{c[nd>>2]=4;break}}}while(0);nd=dIb(Rc|0,0,24)|0;if((nd|0)==0){fd=-1;J=641;break a}nrc(c[nd+4>>2]|0,Fb|0,24)|0;if((c[Hb>>2]|0)!=0){nd=dIb(c[ia>>2]|0,1,c[Kb>>2]|0)|0;if((nd|0)!=0){nrc(c[nd+4>>2]|0,c[Hb>>2]|0,c[Kb>>2]|0)|0}mJb(Gb)}if((c[Ib>>2]|0)==0){break}nd=iLb(c[ia>>2]|0)|0;if((nd|0)==0){fd=-1;J=641;break a}bd=nd;nd=c[Jb+4>>2]|0;c[bd>>2]=c[Jb>>2];c[bd+4>>2]=nd;c[Ib>>2]=0}else{if((c[ia>>2]|0)==0){J=288;break a}nd=c[ce+712>>2]|0;do{if((nd|0)!=0){if((c[ce+288>>2]&2|0)==0){break}if((ve[c[nd+32>>2]&4095](ce)|0)>=0){break}KIb(ce,16,2190512,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc}}while(0);nd=c[ia>>2]|0;Rc=c[nd>>2]|0;c[Bb>>2]=Rc;if((c[N>>2]|0)==2){c[Bb>>2]=Rc+(c[nd+32>>2]|0);c[Cb>>2]=(c[nd+4>>2]|0)+(c[nd+36>>2]|0);c[Db>>2]=(c[nd+8>>2]|0)+(c[nd+40>>2]|0);c[Eb>>2]=(c[nd+12>>2]|0)+(c[nd+44>>2]|0);break}else{c[Cb>>2]=c[nd+4>>2];c[Db>>2]=c[nd+8>>2];c[Eb>>2]=c[nd+12>>2];break}}}while(0);nd=c[ce+712>>2]|0;if((nd|0)==0){be=0;break}if((Ee[c[nd+24>>2]&511](ce,k,l)|0)<0){fd=-1;J=641;break a}else{be=0}}}while(0);if((c[ia>>2]|0)==0){J=299;break a}if(((c[ja>>2]|0)-37|0)>>>0<2>>>0){c[ka>>2]=(c[ka>>2]|0)+1;Xc=Oc;Yc=be;Zc=257;_c=Pc;break b}gd=c[O>>2]|0;ed=c[gd+800>>2]|0;nd=(c[N>>2]|0)!=3;Rc=nd&1;c[la>>2]=-1;c[ma>>2]=-1;bd=c[Q>>2]|0;if((bd|0)<=(Wd|0)){J=303;break a}Vc=Sc<<3;Wc=Vc>>>0>2147483639>>>0|(Pc|0)==0;ad=Wc?0:Pc;ld=Wc?0:Vc;c[pa>>2]=ad;c[na>>2]=ld;c[qa>>2]=ld+8;c[ra>>2]=ad+(ld>>3);c[sa>>2]=0;if((c[W>>2]|0)!=1&(bd|0)>175){c[sa>>2]=3}iRa(D);c[ta>>2]=0;bd=c[sa>>2]|0;ld=c[pa>>2]|0;ad=ld+(bd>>>3)|0;Vc=(je(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)|0)<<(bd&7)>>>27;ad=bd+5|0;c[sa>>2]=ad;if((c[ua>>2]|0)==0){de=Vc<<1}else{de=d[778280+Vc|0]|0}c[va>>2]=de;h:do{if((de|0)==0){KIb(c[O>>2]|0,16,2339336,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1}else{Vc=c[na>>2]|0;if((Vc-ad|0)<1){ee=-1094995529;break}else{fe=ad}while(1){bd=d[ld+(fe>>>3)|0]|0;ge=fe+1|0;c[sa>>2]=ge;if((bd&128>>>((fe&7)>>>0)|0)==0){break}bd=fe+9|0;c[sa>>2]=bd;if((Vc-bd|0)<1){ee=-1094995529;break h}else{fe=bd}}c[xa>>2]=0;do{if((Wd|0)==0){if((c[za>>2]|0)!=1179208787){J=315;break}c[sa>>2]=fe+2;he=0}else{J=315}}while(0);i:do{if((J|0)==315){J=0;if((Vc-ge|0)<=0){he=0;break}bd=c[1924113]|0;Wc=0;md=ge;while(1){$c=ld+(md>>>3)|0;od=(je(d[$c]|d[$c+1|0]<<8|d[$c+2|0]<<16|d[$c+3|0]<<24|0)|0)<<(md&7)>>>23;$c=b[bd+(od<<2)>>1]|0;Qd=b[bd+(od<<2)+2>>1]|0;od=Qd<<16>>16;if(Qd<<16>>16<0){Qd=md+9|0;Rd=ld+(Qd>>>3)|0;Pd=((je(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(Qd&7)>>>((od+32|0)>>>0))+$c|0;ie=b[bd+(Pd<<2)+2>>1]|0;ke=Qd;le=b[bd+(Pd<<2)>>1]|0}else{ie=od;ke=md;le=$c}$c=ie+ke|0;c[sa>>2]=$c;if((le|0)<0){J=322;break}if((le|0)<=32){J=327;break}if((le|0)==33){od=Wc+33|0;c[xa>>2]=od;me=od}else{me=Wc}if((Vc-$c|0)>0){Wc=me;md=$c}else{he=me;break i}}if((J|0)==322){J=0;KIb(c[O>>2]|0,16,2328184,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==327){J=0;md=le+Wc|0;c[xa>>2]=md;he=md;break}}}while(0);if(!(he>>>0<(c[Aa>>2]|0)>>>0)){KIb(c[O>>2]|0,16,2322520,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break}Vc=gd+712|0;md=c[Vc>>2]|0;do{if((md|0)==0){J=333}else{if((c[md+28>>2]|0)==0){J=333;break}bd=Pc-4|0;c[n>>2]=-1;$c=Pc+Sc|0;od=U5a(Pc-2|0,$c,n)|0;Pd=od>>>0<$c>>>0?od-4|0:od;c[ya>>2]=Wd;if((Ee[c[(c[Vc>>2]|0)+28>>2]&511](gd,bd,Pd-bd|0)|0)<0){ee=-1;break h}else{ne=Pd}}}while(0);if((J|0)==333){J=0;c[ma>>2]=he;c[ya>>2]=Wd;c[la>>2]=Wd;c[Ba>>2]=0;NTa(D);do{if((c[ya>>2]|0)==0){if((c[xa>>2]|0)!=0){break}if((c[P>>2]|0)==0){if((c[N>>2]|0)!=3){break}}Vc=c[O>>2]|0;if((c[Vc+688>>2]&1|0)==0){break}md=Vc;Vc=c[va>>2]|0;Pd=c[Ca>>2]|0;bd=c[Da>>2]|0;od=c[Ea>>2]|0;$c=c[Fa>>2]|0;Qd=c[Y>>2]|0;do{if((Qd|0)==1){oe=2312864}else{if((Qd|0)==2){oe=2308144;break}oe=(Qd|0)==3?2303144:2291864}}while(0);Qd=(c[M>>2]|0)!=0?2285104:10230248;Wc=(c[V>>2]|0)!=0?2277040:10230248;Rd=(c[Ga>>2]|0)!=0?2272504:10230248;Od=(c[Ha>>2]|0)!=0?2267808:10230248;pd=c[Ia>>2]|0;pe=c[N>>2]|0;re=c[U>>2]|0;se=c[Ja>>2]|0;te=c[ua>>2]|0;ue=c[Ka>>2]|0;we=c[La>>2]|0;xe=(c[Ma>>2]|0)!=0?2264072:10230248;KIb(md,48,2317384,(Uc=i,i=i+144|0,c[Uc>>2]=Vc,c[Uc+8>>2]=Pd,c[Uc+16>>2]=bd,c[Uc+24>>2]=od,c[Uc+32>>2]=$c,c[Uc+40>>2]=oe,c[Uc+48>>2]=Qd,c[Uc+56>>2]=Wc,c[Uc+64>>2]=Rd,c[Uc+72>>2]=Od,c[Uc+80>>2]=pd,c[Uc+88>>2]=pe,c[Uc+96>>2]=re,c[Uc+104>>2]=se,c[Uc+112>>2]=te,c[Uc+120>>2]=ue,c[Uc+128>>2]=we,c[Uc+136>>2]=xe,Uc)|0);i=Uc}}while(0);xe=16>>>(ed>>>0);we=1<<Rc;ue=c[Ba>>2]|0;j:while(1){te=1<<c[Oa>>2];se=te+4|0;c[Ba>>2]=ue-1;re=c[Y>>2]|0;do{if((ue|0)==0){do{if((re|0)==2){pe=c[1924119]|0;pd=c[sa>>2]|0;Od=c[pa>>2]|0;Rd=Od+(pd>>>3)|0;Wc=(je(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(pd&7)>>>26;Rd=b[pe+(Wc<<2)>>1]|0;Qd=(b[pe+(Wc<<2)+2>>1]|0)+pd|0;c[sa>>2]=Qd;if(Rd<<16>>16<0){J=358;break j}ye=697440+(Rd<<16>>16<<2)|0;ze=Qd;Ae=Od;J=363}else if((re|0)==3){Od=c[1924151]|0;Qd=c[sa>>2]|0;Rd=c[pa>>2]|0;pd=Rd+(Qd>>>3)|0;Wc=(je(d[pd]|d[pd+1|0]<<8|d[pd+2|0]<<16|d[pd+3|0]<<24|0)|0)<<(Qd&7)>>>26;pd=b[Od+(Wc<<2)>>1]|0;pe=(b[Od+(Wc<<2)+2>>1]|0)+Qd|0;c[sa>>2]=pe;if(pd<<16>>16<0){J=361;break j}ye=1899824+(pd<<16>>16<<2)|0;ze=pe;Ae=Rd;J=363}else{Rd=c[sa>>2]|0;pe=c[pa>>2]|0;pd=d[pe+(Rd>>>3)|0]|0;Qd=Rd+1|0;c[sa>>2]=Qd;if((pd&128>>>((Rd&7)>>>0)|0)!=0){Be=1;J=364;break}pd=d[pe+(Qd>>>3)|0]|0;c[sa>>2]=Rd+2;if((pd&128>>>((Qd&7)>>>0)|0)==0){J=356;break j}else{Be=65537;J=364}}}while(0);k:do{if((J|0)==363){J=0;Qd=c[ye>>2]|0;if((Qd&7|0)!=0){Be=Qd;J=364;break}l:do{if((Qd&536870912|0)==0){pd=(c[N>>2]|0)==3;if(pd){if((c[U>>2]|0)==0){J=430}else{Ce=2;De=ze}}else{J=430}do{if((J|0)==430){J=0;Rd=Ae+(ze>>>3)|0;pe=(je(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(ze&7)>>>30;Rd=ze+2|0;c[sa>>2]=Rd;if(!pd){Ce=pe;De=Rd;break}if((Qd&131072|0)==0){Ce=pe;De=Rd;break}Wc=d[Ae+(Rd>>>3)|0]<<(Rd&7)>>>7;Rd=ze+3|0;c[sa>>2]=Rd;c[ta>>2]=Wc&1;Ce=pe;De=Rd}}while(0);if((Qd&65536|0)==0){Fe=De}else{Rd=Ae+(De>>>3)|0;pe=(je(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(De&7)>>>27;Rd=De+5|0;c[sa>>2]=Rd;if((c[ua>>2]|0)==0){Ge=pe<<1}else{Ge=d[778280+pe|0]|0}c[va>>2]=Ge;Fe=Rd}c[bb>>2]=Qd>>>13&3;if((Ce|0)==3){if((c[M>>2]|0)!=0){J=459;break j}c[cb>>2]=4;Rd=Qd;pe=0;while(1){do{if((12288<<(pe<<1)&Rd|0)==0){He=Rd}else{Wc=(c[N>>2]|0)==3|0;Od=D+11824+(pe<<4)|0;Ie=sRa(D,c[D+14156+(pe<<3)>>2]|0,c[Od>>2]|0)|0;c[Od>>2]=Ie;c[D+11824+(pe<<4)+8>>2]=Ie;Od=c[sa>>2]|0;Je=c[pa>>2]|0;Ke=d[Je+(Od>>>3)|0]|0;Le=Od+1|0;c[sa>>2]=Le;if((Ke&128>>>((Od&7)>>>0)|0)==0){Me=0}else{Ke=d[Je+(Le>>>3)|0]<<(Le&7)>>>7;c[sa>>2]=Od+2;Me=1-(Ke<<1&2)|0}Ke=D+11824+(pe<<4)+4|0;Od=sRa(D,c[D+14156+(pe<<3)+4>>2]|0,c[Ke>>2]>>Wc)|0;Le=c[sa>>2]|0;Je=c[pa>>2]|0;Ne=d[Je+(Le>>>3)|0]|0;Oe=Le+1|0;c[sa>>2]=Oe;if((Ne&128>>>((Le&7)>>>0)|0)==0){Pe=0}else{Ne=d[Je+(Oe>>>3)|0]<<(Oe&7)>>>7;c[sa>>2]=Le+2;Pe=1-(Ne<<1&2)|0}Ne=Od<<Wc;c[Ke>>2]=Ne;c[D+11824+(pe<<4)+12>>2]=Ne;c[D+11744+(pe<<5)>>2]=Ie;c[D+11744+(pe<<5)+4>>2]=Od;c[D+11744+(pe<<5)+8>>2]=Ie;c[D+11744+(pe<<5)+12>>2]=Od;Ne=c[N>>2]|0;if((Ne|0)==3){Ke=(c[Ha>>2]|0)!=0?1:3;Wc=(Ie|0)>0|0;c[D+11744+(pe<<5)+16>>2]=((ca(Ke,Ie)|0)+Wc>>1)+Me;Le=(Od|0)>0|0;c[D+11744+(pe<<5)+20>>2]=Pe-1+((ca(Ke,Od)|0)+Le>>1);Oe=4-Ke|0;c[D+11744+(pe<<5)+24>>2]=((ca(Oe,Ie)|0)+Wc>>1)+Me;c[D+11744+(pe<<5)+28>>2]=Pe+1+((ca(Oe,Od)|0)+Le>>1);He=Rd|136;break}Le=Rd|8;c[D+11744+(pe<<5)+16>>2]=Me+(((Ie|0)>0)+Ie>>1);Ie=Pe+(((Od|0)>0)+Od>>1)|0;Od=D+11744+(pe<<5)+20|0;c[Od>>2]=Ie;if((Ne|0)==1){c[Od>>2]=Ie-1;He=Le;break}else{c[Od>>2]=Ie+1;He=Le;break}}}while(0);Le=pe+1|0;if((Le|0)<2){Rd=He;pe=Le}else{Qe=He;break}}}else if((Ce|0)==2){if(!pd){pe=Qd|144;c[cb>>2]=2;Rd=0;while(1){if((12288<<(Rd<<1)&pe|0)!=0){Le=D+14156+(Rd<<3)|0;Ie=c[sa>>2]|0;Od=d[(c[pa>>2]|0)+(Ie>>>3)|0]<<(Ie&7)>>>7;c[sa>>2]=Ie+1;c[D+11808+(Rd<<3)>>2]=Od&1;Od=D+11824+(Rd<<4)|0;Ie=sRa(D,c[Le>>2]|0,c[Od>>2]|0)|0;c[Od>>2]=Ie;c[D+11744+(Rd<<5)>>2]=Ie;Ie=D+14156+(Rd<<3)+4|0;Od=D+11824+(Rd<<4)+4|0;Ne=sRa(D,c[Ie>>2]|0,c[Od>>2]|0)|0;c[Od>>2]=Ne;c[D+11744+(Rd<<5)+4>>2]=Ne;Ne=c[sa>>2]|0;Od=d[(c[pa>>2]|0)+(Ne>>>3)|0]<<(Ne&7)>>>7;c[sa>>2]=Ne+1;c[D+11808+(Rd<<3)+4>>2]=Od&1;Od=D+11824+(Rd<<4)+8|0;Ne=sRa(D,c[Le>>2]|0,c[Od>>2]|0)|0;c[Od>>2]=Ne;c[D+11744+(Rd<<5)+8>>2]=Ne;Ne=D+11824+(Rd<<4)+12|0;Od=sRa(D,c[Ie>>2]|0,c[Ne>>2]|0)|0;c[Ne>>2]=Od;c[D+11744+(Rd<<5)+12>>2]=Od}Od=Rd+1|0;if((Od|0)<2){Rd=Od}else{Qe=pe;break l}}}pe=Qd|8;c[cb>>2]=0;do{if((Qd&12288|0)!=0){Rd=sRa(D,c[Ca>>2]|0,c[Wa>>2]|0)|0;c[Xa>>2]=Rd;c[Wa>>2]=Rd;c[Ya>>2]=Rd;Rd=sRa(D,c[Da>>2]|0,c[Za>>2]|0)|0;c[_a>>2]=Rd;c[Za>>2]=Rd;c[$a>>2]=Rd;if((c[kb>>2]|0)==0){break}c[Ya>>2]=c[Ya>>2]<<1;c[$a>>2]=Rd<<1}}while(0);if((Qd&49152|0)==0){Qe=pe;break}Rd=sRa(D,c[Ea>>2]|0,c[db>>2]|0)|0;c[eb>>2]=Rd;c[db>>2]=Rd;c[fb>>2]=Rd;Rd=sRa(D,c[Fa>>2]|0,c[gb>>2]|0)|0;c[hb>>2]=Rd;c[gb>>2]=Rd;c[ib>>2]=Rd;if((c[jb>>2]|0)==0){Qe=pe;break}c[fb>>2]=c[fb>>2]<<1;c[ib>>2]=Rd<<1;Qe=pe;break}else if((Ce|0)==1){c[cb>>2]=3;if(pd){Rd=Qd|144;Od=0;while(1){if((12288<<(Od<<1)&Rd|0)!=0){Ne=D+14156+(Od<<3)|0;Ie=D+14156+(Od<<3)+4|0;Le=c[sa>>2]|0;Oe=d[(c[pa>>2]|0)+(Le>>>3)|0]<<(Le&7)>>>7;c[sa>>2]=Le+1;c[D+11808+(Od<<3)>>2]=Oe&1;Oe=D+11824+(Od<<4)|0;Le=sRa(D,c[Ne>>2]|0,c[Oe>>2]|0)|0;c[Oe>>2]=Le;c[D+11744+(Od<<5)>>2]=Le;Le=D+11824+(Od<<4)+4|0;Oe=sRa(D,c[Ie>>2]|0,c[Le>>2]>>1)|0;c[Le>>2]=Oe<<1;c[D+11744+(Od<<5)+4>>2]=Oe;Oe=c[sa>>2]|0;Le=d[(c[pa>>2]|0)+(Oe>>>3)|0]<<(Oe&7)>>>7;c[sa>>2]=Oe+1;c[D+11808+(Od<<3)+4>>2]=Le&1;Le=D+11824+(Od<<4)+8|0;Oe=sRa(D,c[Ne>>2]|0,c[Le>>2]|0)|0;c[Le>>2]=Oe;c[D+11744+(Od<<5)+8>>2]=Oe;Oe=D+11824+(Od<<4)+12|0;Le=sRa(D,c[Ie>>2]|0,c[Oe>>2]>>1)|0;c[Oe>>2]=Le<<1;c[D+11744+(Od<<5)+12>>2]=Le}Le=Od+1|0;if((Le|0)<2){Od=Le}else{Qe=Rd;break l}}}if((c[M>>2]|0)!=0){J=454;break a}Rd=Qd|136;if((Qd&12288|0)!=0){Od=d[Ae+(Fe>>>3)|0]<<(Fe&7)>>>7;c[sa>>2]=Fe+1;c[mb>>2]=Od&1;Od=sRa(D,c[Ca>>2]|0,c[Wa>>2]|0)|0;c[Wa>>2]=Od;c[Xa>>2]=Od;c[Ya>>2]=Od;Od=sRa(D,c[Da>>2]|0,c[Za>>2]|0)|0;c[Za>>2]=Od;c[_a>>2]=Od;c[$a>>2]=Od}if((Qd&49152|0)==0){Qe=Rd;break}Od=c[sa>>2]|0;pd=d[(c[pa>>2]|0)+(Od>>>3)|0]<<(Od&7)>>>7;c[sa>>2]=Od+1;c[lb>>2]=pd&1;pd=sRa(D,c[Ea>>2]|0,c[db>>2]|0)|0;c[db>>2]=pd;c[eb>>2]=pd;c[fb>>2]=pd;pd=sRa(D,c[Fa>>2]|0,c[gb>>2]|0)|0;c[gb>>2]=pd;c[hb>>2]=pd;c[ib>>2]=pd;Qe=Rd;break}else{J=472;break j}}else{c[bb>>2]=1;Rd=c[N>>2]|0;if((Rd|0)==3){if((c[U>>2]|0)==0){pd=d[Ae+(ze>>>3)|0]<<(ze&7)>>>7;Od=ze+1|0;c[sa>>2]=Od;c[ta>>2]=pd&1;Re=Od}else{Re=ze}c[cb>>2]=0;Se=Qd;Te=Re}else{c[cb>>2]=3;c[mb>>2]=Rd-1;Se=Qd|128;Te=ze}if((Se&65536|0)!=0){Rd=Ae+(Te>>>3)|0;Od=(je(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(Te&7)>>>27;c[sa>>2]=Te+5;if((c[ua>>2]|0)==0){Ue=Od<<1}else{Ue=d[778280+Od|0]|0}c[va>>2]=Ue}c[Ya>>2]=0;c[$a>>2]=0;mrc(Ra|0,0,16)|0;Qe=Se}}while(0);c[Sa>>2]=0;if((Qe&131072|0)==0){mrc(nb|0,-1|0,48)|0;Ve=Qe;break}qe[c[Pa>>2]&1023](c[Na>>2]|0);Qd=c[1924125]|0;Od=c[sa>>2]|0;Rd=c[pa>>2]|0;pd=Rd+(Od>>>3)|0;pe=(je(d[pd]|d[pd+1|0]<<8|d[pd+2|0]<<16|d[pd+3|0]<<24|0)|0)<<(Od&7)>>>23;pd=b[Qd+(pe<<2)>>1]|0;Le=(b[Qd+(pe<<2)+2>>1]|0)+Od|0;c[sa>>2]=Le;if((se|0)>6){Od=te-2|0;pe=Rd+(Le>>>3)|0;Rd=(je(d[pe]|d[pe+1|0]<<8|d[pe+2|0]<<16|d[pe+3|0]<<24|0)|0)<<(Le&7)>>>((34-te|0)>>>0);c[sa>>2]=Le+Od;qe[c[Pa>>2]&1023]((c[Na>>2]|0)+768|0);We=Rd|pd<<Od}else{We=pd}if((We|0)<1){J=478;break j}pd=(c[Ta>>2]&1|0)!=0;if((c[W>>2]|0)==2){if(pd){Od=We;Rd=0;while(1){if((Od&32|0)==0){c[D+180+(Rd<<2)>>2]=-1}else{Le=c[D+14292+(Rd<<2)>>2]|0;pe=Le|0;Qd=c[va>>2]|0;Oe=c[sa>>2]|0;Ie=c[pa>>2]|0;Ne=Ie+(Oe>>>3)|0;Wc=(je(d[Ne]|d[Ne+1|0]<<8|d[Ne+2|0]<<16|d[Ne+3|0]<<24|0)|0)<<(Oe&7);if((Wc|0)<0){Ne=(Qd*3|0)>>1;if((Wc&1073741824|0)==0){Xe=Ne&65535}else{Xe=-Ne&65535}b[pe>>1]=Xe;pe=Wc<<2;Ne=Oe+2|0;if((pe|0)<-1073741824){Ye=Ne;Ze=0}else{_e=pe;$e=Ne;af=0;J=486}}else{_e=Wc;$e=Oe;af=-1;J=486}m:do{if((J|0)==486){J=0;Oe=c[328980]|0;Wc=_e;Ne=$e;pe=af;while(1){Ke=Wc>>>23;Je=b[Oe+(Ke<<2)>>1]|0;bf=a[Oe+(Ke<<2)+2|0]|0;cf=bf<<24>>24;if(bf<<24>>24<0){bf=Wc<<9;df=(bf>>>((cf+32|0)>>>0))+Je|0;ef=df;ff=b[Oe+(df<<2)>>1]|0;gf=a[Oe+(df<<2)+2|0]|0;hf=bf;jf=Ne+9|0}else{ef=Ke;ff=Je;gf=cf;hf=Wc;jf=Ne}cf=hf<<gf;Je=gf+jf|0;do{if((ff|0)==0){Ke=Je+6|0;bf=Ie+(Ke>>>3)|0;df=(je(d[bf]|d[bf+1|0]<<8|d[bf+2|0]<<16|d[bf+3|0]<<24|0)|0)<<(Ke&7);Ke=df>>20;bf=df<<12;df=Je+18|0;kf=pe+1+(cf>>>26)|0;lf=d[D+368+kf|0]|0;if((Ke|0)<0){mf=-((ca(-Ke<<1|1,Qd)|0)>>>1)&65535;nf=bf;of=df;pf=kf;qf=lf;break}else{mf=(ca(Ke<<1|1,Qd)|0)>>>1&65535;nf=bf;of=df;pf=kf;qf=lf;break}}else{lf=(d[Oe+(ef<<2)+3|0]|0)+pe|0;kf=cf>>31;mf=((ca(ff<<1|1,Qd)|0)>>>1^kf)-kf&65535;nf=cf<<1;of=Je+1|0;pf=lf;qf=d[D+368+lf|0]|0}}while(0);b[Le+(qf<<1)>>1]=mf;if((nf|0)<-1073741824|(pf|0)>63){Ye=of;Ze=pf;break m}Je=Ie+(of>>>3)|0;Wc=(je(d[Je]|d[Je+1|0]<<8|d[Je+2|0]<<16|d[Je+3|0]<<24|0)|0)<<(of&7);Ne=of;pe=pf}}}while(0);c[sa>>2]=Ye+2;c[D+180+(Rd<<2)>>2]=Ze}Ie=Rd+1|0;if((Ie|0)<6){Od=Od<<1;Rd=Ie}else{Ve=Qe;break k}}}if((se|0)<=0){Ve=Qe;break}Rd=We<<8-te;Od=0;while(1){if((Rd&2048|0)==0){c[D+180+(Od<<2)>>2]=-1}else{Ie=c[D+14292+(Od<<2)>>2]|0;Le=c[va>>2]|0;Qd=c[sa>>2]|0;pe=(Od|0)<4?ob:pb;Ne=c[pa>>2]|0;Wc=Ne+(Qd>>>3)|0;Oe=(je(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)<<(Qd&7);if((Oe|0)<0){Wc=(ca(Le*3|0,e[pe>>1]|0)|0)>>5;Je=(Oe&1073741824|0)==0?Wc:-Wc|0;b[Ie>>1]=Je;Wc=Je^1;Je=Oe<<2;cf=Qd+2|0;if((Je|0)<-1073741824){rf=cf;sf=Wc;tf=0}else{uf=Je;vf=cf;wf=Wc;xf=0;J=504}}else{uf=Oe;vf=Qd;wf=1;xf=-1;J=504}n:do{if((J|0)==504){J=0;Qd=c[328980]|0;Oe=uf;Wc=vf;cf=wf;Je=xf;while(1){lf=Oe>>>23;kf=b[Qd+(lf<<2)>>1]|0;df=a[Qd+(lf<<2)+2|0]|0;bf=df<<24>>24;if(df<<24>>24<0){df=Oe<<9;Ke=(df>>>((bf+32|0)>>>0))+kf|0;yf=Ke;zf=a[Qd+(Ke<<2)+2|0]|0;Af=df;Bf=Wc+9|0;Cf=b[Qd+(Ke<<2)>>1]|0}else{yf=lf;zf=bf;Af=Oe;Bf=Wc;Cf=kf}kf=Af<<zf;bf=zf+Bf|0;do{if((Cf|0)==0){lf=bf+6|0;Ke=Ne+(lf>>>3)|0;df=(je(d[Ke]|d[Ke+1|0]<<8|d[Ke+2|0]<<16|d[Ke+3|0]<<24|0)|0)<<(lf&7);lf=df>>20;Ke=df<<12;df=bf+18|0;Df=Je+1+(kf>>>26)|0;if((Df|0)>63){J=512;break j}Ef=d[D+368+Df|0]|0;if((lf|0)<0){Ff=ca(-lf<<1|1,Le)|0;Gf=Ke;Hf=df;If=-((ca(Ff,e[pe+(Ef<<1)>>1]|0)|0)>>5)|0;Jf=Df;Kf=Ef;break}else{Ff=ca(lf<<1|1,Le)|0;Gf=Ke;Hf=df;If=(ca(Ff,e[pe+(Ef<<1)>>1]|0)|0)>>5;Jf=Df;Kf=Ef;break}}else{Ef=(d[Qd+(yf<<2)+3|0]|0)+Je|0;if((Ef|0)>63){J=509;break j}Df=d[D+368+Ef|0]|0;Ff=ca(Cf<<1|1,Le)|0;df=kf>>31;Gf=kf<<1;Hf=bf+1|0;If=((ca(Ff,e[pe+(Df<<1)>>1]|0)|0)>>5^df)-df|0;Jf=Ef;Kf=Df}}while(0);bf=If^cf;b[Ie+(Kf<<1)>>1]=If;if((Gf|0)<-1073741824){rf=Hf;sf=bf;tf=Jf;break n}kf=Ne+(Hf>>>3)|0;Oe=(je(d[kf]|d[kf+1|0]<<8|d[kf+2|0]<<16|d[kf+3|0]<<24|0)|0)<<(Hf&7);Wc=Hf;cf=bf;Je=Jf}}}while(0);c[sa>>2]=rf+2;Ne=Ie+126|0;b[Ne>>1]=e[Ne>>1]^sf&1;c[D+180+(Od<<2)>>2]=tf}Ne=Od+1|0;if((Ne|0)<(se|0)){Rd=Rd<<1;Od=Ne}else{Ve=Qe;break k}}}if(pd){Lf=We;Mf=0}else{Od=We;Rd=0;while(1){if((Od&32|0)==0){c[D+180+(Rd<<2)>>2]=-1}else{Ne=c[D+14292+(Rd<<2)>>2]|0;pe=Ne|0;Le=c[va>>2]|0;Je=c[sa>>2]|0;cf=c[pa>>2]|0;Wc=cf+(Je>>>3)|0;Oe=(je(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)<<(Je&7);if((Oe|0)<0){Wc=((ca(Le*3|0,e[ob>>1]|0)|0)>>5)-1|1;if((Oe&1073741824|0)==0){Nf=Wc&65535}else{Nf=-Wc&65535}b[pe>>1]=Nf;pe=Oe<<2;Wc=Je+2|0;if((pe|0)<-1073741824){Of=Wc;Pf=0}else{Qf=pe;Rf=Wc;Sf=0;J=553}}else{Qf=Oe;Rf=Je;Sf=-1;J=553}o:do{if((J|0)==553){J=0;Je=c[328980]|0;Oe=Qf;Wc=Rf;pe=Sf;while(1){Qd=Oe>>>23;bf=b[Je+(Qd<<2)>>1]|0;kf=a[Je+(Qd<<2)+2|0]|0;Df=kf<<24>>24;if(kf<<24>>24<0){kf=Oe<<9;Ef=(kf>>>((Df+32|0)>>>0))+bf|0;Tf=Ef;Uf=a[Je+(Ef<<2)+2|0]|0;Vf=kf;Wf=Wc+9|0;Xf=b[Je+(Ef<<2)>>1]|0}else{Tf=Qd;Uf=Df;Vf=Oe;Wf=Wc;Xf=bf}bf=Vf<<Uf;Df=Uf+Wf|0;do{if((Xf|0)==0){Qd=bf>>>26;Ef=Df+6|0;kf=cf+(Ef>>>3)|0;df=(je(d[kf]|d[kf+1|0]<<8|d[kf+2|0]<<16|d[kf+3|0]<<24|0)|0)<<(Ef&7);Ef=df>>24;do{if((Ef|0)==-128){Yf=df<<16;Zf=Df+22|0;_f=df>>>16|-256}else{if((Ef|0)!=0){Yf=df<<8;Zf=Df+14|0;_f=Ef;break}Yf=df<<16;Zf=Df+22|0;_f=df>>>16&255}}while(0);df=pe+1+Qd|0;if((df|0)>63){J=565;break j}Ef=d[D+368+df|0]|0;if((_f|0)<0){kf=ca(-_f<<1|1,Le)|0;$f=Yf;ag=Zf;bg=-(((ca(kf,e[D+12816+(Ef<<1)>>1]|0)|0)>>>5)+65535|1)&65535;cg=df;dg=Ef;break}else{kf=ca(_f<<1|1,Le)|0;$f=Yf;ag=Zf;bg=(((ca(kf,e[D+12816+(Ef<<1)>>1]|0)|0)>>>5)+65535|1)&65535;cg=df;dg=Ef;break}}else{Ef=(d[Je+(Tf<<2)+3|0]|0)+pe|0;if((Ef|0)>63){J=558;break j}df=d[D+368+Ef|0]|0;kf=ca(Xf<<1|1,Le)|0;Ff=bf>>31;$f=bf<<1;ag=Df+1|0;bg=((((ca(kf,e[D+12816+(df<<1)>>1]|0)|0)>>>5)+65535|1)^Ff)-Ff&65535;cg=Ef;dg=df}}while(0);b[Ne+(dg<<1)>>1]=bg;if(($f|0)<-1073741824){Of=ag;Pf=cg;break o}Df=cf+(ag>>>3)|0;Oe=(je(d[Df]|d[Df+1|0]<<8|d[Df+2|0]<<16|d[Df+3|0]<<24|0)|0)<<(ag&7);Wc=ag;pe=cg}}}while(0);c[sa>>2]=Of+2;c[D+180+(Rd<<2)>>2]=Pf}cf=Rd+1|0;if((cf|0)<6){Od=Od<<1;Rd=cf}else{Ve=Qe;break k}}}while(1){p:do{if((Lf&32|0)==0){c[D+180+(Mf<<2)>>2]=-1}else{Rd=c[D+14292+(Mf<<2)>>2]|0;Od=Rd|0;pd=c[va>>2]|0;cf=c[sa>>2]|0;Ne=c[pa>>2]|0;Le=Ne+(cf>>>3)|0;Ie=(je(d[Le]|d[Le+1|0]<<8|d[Le+2|0]<<16|d[Le+3|0]<<24|0)|0)<<(cf&7);if((Ie|0)<0){Le=((pd*3|0)>>1)-1|1;if((Ie&1073741824|0)==0){eg=Le&65535}else{eg=-Le&65535}b[Od>>1]=eg;Od=Ie<<2;Le=cf+2|0;if((Od|0)<-1073741824){fg=Le;gg=0}else{hg=Od;ig=Le;jg=0;J=527}}else{hg=Ie;ig=cf;jg=-1;J=527}q:do{if((J|0)==527){J=0;cf=c[328980]|0;Ie=hg;Le=ig;Od=jg;r:while(1){pe=Ie>>>23;Wc=b[cf+(pe<<2)>>1]|0;Oe=a[cf+(pe<<2)+2|0]|0;Je=Oe<<24>>24;if(Oe<<24>>24<0){Oe=Ie<<9;Df=(Oe>>>((Je+32|0)>>>0))+Wc|0;kg=Df;lg=a[cf+(Df<<2)+2|0]|0;mg=Oe;ng=Le+9|0;og=b[cf+(Df<<2)>>1]|0}else{kg=pe;lg=Je;mg=Ie;ng=Le;og=Wc}Wc=mg<<lg;Je=lg+ng|0;do{if((og|0)==0){pe=Wc>>>26;Df=Je+6|0;Oe=Ne+(Df>>>3)|0;bf=(je(d[Oe]|d[Oe+1|0]<<8|d[Oe+2|0]<<16|d[Oe+3|0]<<24|0)|0)<<(Df&7);Df=bf>>24;do{if((Df|0)==-128){pg=bf<<16;qg=Je+22|0;rg=bf>>>16|-256}else{if((Df|0)!=0){pg=bf<<8;qg=Je+14|0;rg=Df;break}pg=bf<<16;qg=Je+22|0;rg=bf>>>16&255}}while(0);bf=Od+1+pe|0;if((bf|0)>63){J=539;break r}Df=d[D+368+bf|0]|0;if((rg|0)<0){sg=pg;tg=qg;ug=-(((ca(-rg<<1|1,pd)|0)>>>1)+65535|1)&65535;vg=bf;wg=Df;break}else{sg=pg;tg=qg;ug=(((ca(rg<<1|1,pd)|0)>>>1)+65535|1)&65535;vg=bf;wg=Df;break}}else{Df=(d[cf+(kg<<2)+3|0]|0)+Od|0;if((Df|0)>63){J=532;break r}bf=Wc>>31;sg=Wc<<1;tg=Je+1|0;ug=((((ca(og<<1|1,pd)|0)>>>1)+65535|1)^bf)-bf&65535;vg=Df;wg=d[D+368+Df|0]|0}}while(0);b[Rd+(wg<<1)>>1]=ug;if((sg|0)<-1073741824){fg=tg;gg=vg;break q}Je=Ne+(tg>>>3)|0;Ie=(je(d[Je]|d[Je+1|0]<<8|d[Je+2|0]<<16|d[Je+3|0]<<24|0)|0)<<(tg&7);Le=tg;Od=vg}if((J|0)==532){J=0;Od=c[ya>>2]|0;KIb(c[O>>2]|0,16,2200136,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=Od,Uc)|0);i=Uc;break p}else if((J|0)==539){J=0;Od=c[ya>>2]|0;KIb(c[O>>2]|0,16,2200136,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=Od,Uc)|0);i=Uc;break p}}}while(0);c[sa>>2]=fg+2;c[D+180+(Mf<<2)>>2]=gg}}while(0);Ne=Mf+1|0;if((Ne|0)<6){Lf=Lf<<1;Mf=Ne}else{Ve=Qe;break}}}}while(0);s:do{if((J|0)==364){J=0;qe[c[Pa>>2]&1023](c[Na>>2]|0);if((c[Qa>>2]|0)==0){qe[c[Pa>>2]&1023]((c[Na>>2]|0)+768|0)}Ne=(c[N>>2]|0)==3;do{if(Ne){if((c[U>>2]|0)!=0){break}Rd=c[sa>>2]|0;pd=d[(c[pa>>2]|0)+(Rd>>>3)|0]<<(Rd&7)>>>7;c[sa>>2]=Rd+1;c[ta>>2]=pd&1}}while(0);if((Be&65536|0)!=0){pd=c[sa>>2]|0;Rd=(c[pa>>2]|0)+(pd>>>3)|0;Od=(je(d[Rd]|d[Rd+1|0]<<8|d[Rd+2|0]<<16|d[Rd+3|0]<<24|0)|0)<<(pd&7)>>>27;c[sa>>2]=pd+5;if((c[ua>>2]|0)==0){xg=Od<<1}else{xg=d[778280+Od|0]|0}c[va>>2]=xg}if((c[Ja>>2]|0)==0){mrc(Ra|0,0,32)|0}else{if(!Ne){c[sa>>2]=(c[sa>>2]|0)+1}Od=sRa(D,c[Ca>>2]|0,c[Wa>>2]|0)|0;c[Xa>>2]=Od;c[Wa>>2]=Od;c[Ya>>2]=Od;Od=sRa(D,c[Da>>2]|0,c[Za>>2]|0)|0;c[_a>>2]=Od;c[Za>>2]=Od;c[$a>>2]=Od;c[sa>>2]=(c[sa>>2]|0)+1}c[Sa>>2]=1;if((c[W>>2]|0)!=2){Od=0;while(1){if((Od|0)>=6){Ve=Be;break s}if((mRa(D,c[D+14292+(Od<<2)>>2]|0,Od)|0)<0){ee=-1;break h}else{Od=Od+1|0}}}if((c[Ta>>2]&1|0)!=0){Od=0;while(1){Ne=c[D+14292+(Od<<2)>>2]|0;pd=c[va>>2]|0;if((Od|0)<4){yg=Ua;zg=0}else{yg=Va;zg=(Od&1)+1|0}Rd=tRa(oa,zg)|0;if((Rd|0)<=65534){Le=D+9860+(zg<<2)|0;Ie=(c[Le>>2]|0)+Rd|0;c[Le>>2]=Ie;b[Ne>>1]=Ie<<3-(c[Ia>>2]|0);Ie=-pd|0;Le=c[pa>>2]|0;Rd=c[((c[Ka>>2]|0)==0?1315856:1315664)+64>>2]|0;cf=c[sa>>2]|0;Je=0;while(1){Wc=Le+(cf>>>3)|0;Qd=(je(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)<<(cf&7);Wc=Qd>>>23;Df=b[Rd+(Wc<<2)>>1]|0;bf=a[Rd+(Wc<<2)+2|0]|0;Oe=bf<<24>>24;if(bf<<24>>24<0){bf=Qd<<9;df=(bf>>>((Oe+32|0)>>>0))+Df|0;Ag=df;Bg=a[Rd+(df<<2)+2|0]|0;Cg=bf;Dg=cf+9|0;Eg=b[Rd+(df<<2)>>1]|0}else{Ag=Wc;Bg=Oe;Cg=Qd;Dg=cf;Eg=Df}Df=d[Rd+(Ag<<2)+3|0]|0;Qd=Cg<<Bg;Fg=Bg+Dg|0;if((Eg|0)>63|(Je|0)>63){break}do{if((Eg|0)==0){Oe=Fg+6|0;Wc=Le+(Oe>>>3)|0;df=(je(d[Wc]|d[Wc+1|0]<<8|d[Wc+2|0]<<16|d[Wc+3|0]<<24|0)|0)<<(Oe&7)>>20;Oe=Fg+18|0;Wc=Je+1+(Qd>>>26)|0;bf=d[D+368+Wc|0]|0;if((df|0)<0){Gg=Oe;Hg=-((ca(ca(df,Ie)|0,e[yg+(bf<<1)>>1]|0)|0)>>>4)&65535;Ig=Wc;Jg=bf;break}else{Ef=ca(df,pd)|0;Gg=Oe;Hg=(ca(Ef,e[yg+(bf<<1)>>1]|0)|0)>>>4&65535;Ig=Wc;Jg=bf;break}}else{bf=Df+Je|0;Wc=d[D+368+bf|0]|0;Ef=ca(Eg,pd)|0;Oe=Qd>>31;Gg=Fg+1|0;Hg=((ca(Ef,e[yg+(Wc<<1)>>1]|0)|0)>>>4^Oe)-Oe&65535;Ig=bf;Jg=Wc}}while(0);b[Ne+(Jg<<1)>>1]=Hg;cf=Gg;Je=Ig}c[sa>>2]=Fg;c[D+180+(Od<<2)>>2]=Je}cf=Od+1|0;if((cf|0)<6){Od=cf}else{Ve=Be;break s}}}if((se|0)>0){Kg=0}else{Ve=Be;break}while(1){Od=c[D+14292+(Kg<<2)>>2]|0;cf=c[va>>2]|0;if((Kg|0)<4){Lg=Ua;Mg=0}else{Lg=Va;Mg=(Kg&1)+1|0}Ne=tRa(oa,Mg)|0;if((Ne|0)>65534){ee=-1;break h}pd=D+9860+(Mg<<2)|0;Ie=(c[pd>>2]|0)+Ne|0;c[pd>>2]=Ie;pd=Ie<<3-(c[Ia>>2]|0)&65535;b[Od>>1]=pd;Ie=-cf|0;Ne=c[pa>>2]|0;Le=c[((c[Ka>>2]|0)==0?1315856:1315664)+64>>2]|0;Rd=c[sa>>2]|0;Qd=pd<<16>>16^1;pd=0;t:while(1){Df=Ne+(Rd>>>3)|0;Wc=(je(d[Df]|d[Df+1|0]<<8|d[Df+2|0]<<16|d[Df+3|0]<<24|0)|0)<<(Rd&7);Df=Wc>>>23;bf=b[Le+(Df<<2)>>1]|0;Oe=a[Le+(Df<<2)+2|0]|0;Ef=Oe<<24>>24;if(Oe<<24>>24<0){Oe=Wc<<9;df=(Oe>>>((Ef+32|0)>>>0))+bf|0;Ng=df;Og=a[Le+(df<<2)+2|0]|0;Pg=Oe;Qg=Rd+9|0;Rg=b[Le+(df<<2)>>1]|0}else{Ng=Df;Og=Ef;Pg=Wc;Qg=Rd;Rg=bf}bf=Pg<<Og;Sg=Og+Qg|0;do{if((Rg|0)==127){break t}else if((Rg|0)==0){Wc=Sg+6|0;Ef=Ne+(Wc>>>3)|0;Df=(je(d[Ef]|d[Ef+1|0]<<8|d[Ef+2|0]<<16|d[Ef+3|0]<<24|0)|0)<<(Wc&7)>>20;Wc=Sg+18|0;Ef=pd+1+(bf>>>26)|0;if((Ef|0)>63){J=408;break j}df=d[D+368+Ef|0]|0;if((Df|0)<0){Tg=Wc;Ug=-((ca(ca(Df,Ie)|0,e[Lg+(df<<1)>>1]|0)|0)>>4)|0;Vg=Ef;Wg=df;break}else{Oe=ca(Df,cf)|0;Tg=Wc;Ug=(ca(Oe,e[Lg+(df<<1)>>1]|0)|0)>>4;Vg=Ef;Wg=df;break}}else{df=(d[Le+(Ng<<2)+3|0]|0)+pd|0;if((df|0)>63){J=405;break j}Ef=d[D+368+df|0]|0;Oe=ca(Rg,cf)|0;Wc=bf>>31;Tg=Sg+1|0;Ug=((ca(Oe,e[Lg+(Ef<<1)>>1]|0)|0)>>4^Wc)-Wc|0;Vg=df;Wg=Ef}}while(0);b[Od+(Wg<<1)>>1]=Ug;Rd=Tg;Qd=Ug^Qd;pd=Vg}c[sa>>2]=Sg;Rd=Od+126|0;b[Rd>>1]=e[Rd>>1]^Qd&1;c[D+180+(Kg<<2)>>2]=pd;Rd=Kg+1|0;if((Rd|0)<(se|0)){Kg=Rd}else{Ve=Be;break}}}}while(0);Rd=(ca(c[T>>2]|0,c[ya>>2]|0)|0)+(c[xa>>2]|0)|0;c[(c[ab>>2]|0)+(Rd<<2)>>2]=Ve}else{if((re|0)==2){c[xb>>2]=1;Rd=(ca(c[T>>2]|0,c[ya>>2]|0)|0)+(c[xa>>2]|0)|0;c[(c[ab>>2]|0)+(Rd<<2)>>2]=14344;break}Rd=c[xa>>2]|0;if((Rd|0)==0){cf=c[ya>>2]|0;Le=c[T>>2]|0;Ie=(c[Aa>>2]|0)-1+(ca(cf-1|0,Le)|0)|0;Ne=c[ab>>2]|0;Xg=Ne+(Ie<<2)|0;Yg=cf;Zg=Le;_g=Ne}else{Ne=c[ya>>2]|0;Le=c[T>>2]|0;cf=Rd-1+(ca(Le,Ne)|0)|0;Ie=c[ab>>2]|0;Xg=Ie+(cf<<2)|0;Yg=Ne;Zg=Le;_g=Ie}Ie=c[Xg>>2]|0;if((Ie&7|0)!=0){J=350;break j}c[_g+((ca(Yg,Zg)|0)+Rd<<2)>>2]=Ie|2048;if((c[$a>>2]|c[Ya>>2]|c[fb>>2]|c[ib>>2]|0)!=0){break}c[xb>>2]=1}}while(0);do{if((c[qb>>2]|0)!=0){if((c[vb>>2]|0)!=0){break}re=c[wb>>2]|0;se=c[xa>>2]|0;te=c[ya>>2]|0;$c=(ca(te,re)|0)+se<<1;od=(ca(c[T>>2]|0,te)|0)+se<<2;se=0;te=$c;while(1){$c=te+1|0;bd=od|1;do{if((c[Sa>>2]|0)==0){Pd=c[cb>>2]|0;if((Pd|0)==3){if(nd){J=584}else{J=585}}else if((Pd|0)==0){J=584}else{J=585}if((J|0)==584){J=0;$g=c[$a>>2]&65535;ah=c[Ya>>2]&65535;break}else if((J|0)==585){J=0;$g=c[D+11744+(se<<3)+4>>2]&65535;ah=c[D+11744+(se<<3)>>2]&65535;break}}else{$g=0;ah=0}}while(0);Pd=c[qb>>2]|0;b[Pd+(te<<2)>>1]=ah;b[Pd+(te<<2)+2>>1]=$g;b[Pd+($c<<2)>>1]=ah;b[Pd+($c<<2)+2>>1]=$g;Pd=c[D+11808+(se<<2)>>2]&255;a[(c[yb>>2]|0)+bd|0]=Pd;a[(c[yb>>2]|0)+od|0]=Pd;do{if((c[Sa>>2]|0)==0){if((c[Y>>2]|0)!=3){bh=0;ch=0;break}Pd=c[cb>>2]|0;if((Pd|0)==3){if(nd){J=632}else{J=633}}else if((Pd|0)==0){J=632}else{J=633}if((J|0)==632){J=0;bh=c[ib>>2]&65535;ch=c[fb>>2]&65535;break}else if((J|0)==633){J=0;bh=c[D+11776+(se<<3)+4>>2]&65535;ch=c[D+11776+(se<<3)>>2]&65535;break}}else{bh=0;ch=0}}while(0);Pd=c[zb>>2]|0;b[Pd+(te<<2)>>1]=ch;b[Pd+(te<<2)+2>>1]=bh;b[Pd+($c<<2)>>1]=ch;b[Pd+($c<<2)+2>>1]=bh;Pd=c[D+11816+(se<<2)>>2]&255;a[(c[Ab>>2]|0)+bd|0]=Pd;a[(c[Ab>>2]|0)+od|0]=Pd;Pd=se+1|0;if((Pd|0)<2){od=od+2|0;se=Pd;te=te+re|0}else{break}}}}while(0);c[rb>>2]=(c[rb>>2]|0)+xe;re=xe>>c[sb>>2];c[tb>>2]=(c[tb>>2]|0)+re;c[ub>>2]=(c[ub>>2]|0)+re;KTa(D,c[Na>>2]|0);re=(c[xa>>2]|0)+1|0;c[xa>>2]=re;if((re|0)>=(c[Aa>>2]|0)){re=16>>>((c[(c[O>>2]|0)+800>>2]|0)>>>0);MTa(D,ca(c[ya>>2]>>Rc,re)|0,re);RTa(D);c[xa>>2]=0;re=(c[ya>>2]|0)+we|0;c[ya>>2]=re;if((re|0)>=(c[Q>>2]|0)){J=589;break}NTa(D)}re=c[Ba>>2]|0;if(!((re|0)==-1)){ue=re;continue}c[Ba>>2]=0;re=c[1924113]|0;dh=c[pa>>2]|0;te=c[sa>>2]|0;eh=0;u:while(1){se=te;while(1){od=dh+(se>>>3)|0;Pd=(je(d[od]|d[od+1|0]<<8|d[od+2|0]<<16|d[od+3|0]<<24|0)|0)<<(se&7)>>>23;od=b[re+(Pd<<2)>>1]|0;Vc=b[re+(Pd<<2)+2>>1]|0;Pd=Vc<<16>>16;if(Vc<<16>>16<0){Vc=se+9|0;md=dh+(Vc>>>3)|0;Ie=((je(d[md]|d[md+1|0]<<8|d[md+2|0]<<16|d[md+3|0]<<24|0)|0)<<(Vc&7)>>>((Pd+32|0)>>>0))+od|0;fh=b[re+(Ie<<2)+2>>1]|0;gh=Vc;hh=b[re+(Ie<<2)>>1]|0}else{fh=Pd;gh=se;hh=od}ih=fh+gh|0;c[sa>>2]=ih;if((hh|0)<0){J=614;break j}if((hh|0)<=32){break u}if((hh|0)==33){break}else if((hh|0)==35){J=618;break j}else{se=ih}}se=eh+33|0;c[Ba>>2]=se;te=ih;eh=se}te=hh+eh|0;c[Ba>>2]=te;if((te|0)==0){ue=0;continue}re=c[Y>>2]|0;if((re|0)==1){J=623;break}c[Sa>>2]=0;mrc(nb|0,-1|0,48)|0;se=c[N>>2]|0;c[cb>>2]=(se|0)==3?0:3;if((re|0)==2){c[bb>>2]=1;c[$a>>2]=0;c[Ya>>2]=0;mrc(Ra|0,0,16)|0;c[mb>>2]=se&1^1;ue=te;continue}else{c[Ya>>2]=c[Wa>>2];c[$a>>2]=c[Za>>2];c[fb>>2]=c[db>>2];c[ib>>2]=c[gb>>2];ue=te;continue}}v:do{if((J|0)==350){J=0;KIb(c[O>>2]|0,16,2231744,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==356){J=0;ue=c[ya>>2]|0;KIb(c[O>>2]|0,16,2227904,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ue,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==358){J=0;ue=c[ya>>2]|0;KIb(c[O>>2]|0,16,2223032,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ue,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==361){J=0;ue=c[ya>>2]|0;KIb(c[O>>2]|0,16,2219432,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ue,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==405){J=0;ue=c[ya>>2]|0;KIb(c[O>>2]|0,16,2200136,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ue,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==408){J=0;ue=c[ya>>2]|0;KIb(c[O>>2]|0,16,2200136,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ue,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==459){J=0;KIb(c[O>>2]|0,16,2213872,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==472){J=0;ue=c[ya>>2]|0;KIb(c[O>>2]|0,16,2211512,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ue,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==478){J=0;ue=c[xa>>2]|0;we=c[ya>>2]|0;KIb(c[O>>2]|0,16,2208776,(Uc=i,i=i+24|0,c[Uc>>2]=We,c[Uc+8>>2]=ue,c[Uc+16>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==509){J=0;we=c[ya>>2]|0;KIb(c[O>>2]|0,16,2200136,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==512){J=0;we=c[ya>>2]|0;KIb(c[O>>2]|0,16,2200136,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==558){J=0;we=c[ya>>2]|0;KIb(c[O>>2]|0,16,2200136,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==565){J=0;we=c[ya>>2]|0;KIb(c[O>>2]|0,16,2200136,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=we,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==589){J=0;we=c[sa>>2]|0;ue=c[na>>2]|0;xe=ue-we|0;do{if((c[Oa>>2]|0)==2){if((c[Y>>2]|0)!=1){jh=0;break}if((c[gd+840>>2]|0)!=0){jh=0;break}if((c[gd+844>>2]|0)!=5){jh=0;break}if((c[Ia>>2]|0)!=2){jh=0;break}if((c[ua>>2]|0)!=1){jh=0;break}if((c[Ga>>2]|0)!=0){jh=0;break}jh=(c[V>>2]|0)==0}else{jh=0}}while(0);te=jh&1;do{if((xe|0)<32|jh){kh=te}else{se=(c[pa>>2]|0)+(((-we&7)+we|0)>>>3)|0;if(((je(d[se]|d[se+1|0]<<8|d[se+2|0]<<16|d[se+3|0]<<24|0)|0)&-256|0)!=101591808){kh=te;break}KIb(gd,48,2260216,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;kh=1}}while(0);do{if((xe|0)<0){lh=c[pa>>2]|0;mh=c[sa>>2]|0;nh=32-xe|0}else{if((ue|0)==(we|0)){oh=c[sa>>2]|0;break v}te=c[pa>>2]|0;se=c[sa>>2]|0;re=te+(se>>>3)|0;od=(je(d[re]|d[re+1|0]<<8|d[re+2|0]<<16|d[re+3|0]<<24|0)|0)<<(se&7);re=32-xe|0;if((od>>>(((xe|0)>23?9:re)>>>0)|0)!=0&(kh|0)==0){lh=te;mh=se;nh=re;break}if((c[gd+696>>2]&262146|0)!=0&(xe|0)>8){lh=te;mh=se;nh=re}else{oh=se;break v}}}while(0);we=lh+(mh>>>3)|0;ue=(je(d[we]|d[we+1|0]<<8|d[we+2|0]<<16|d[we+3|0]<<24|0)|0)<<(mh&7);KIb(gd,16,2255808,(Uc=i,i=i+16|0,c[Uc>>2]=xe,c[Uc+8>>2]=ue>>>(((xe|0)>23?9:nh)>>>0),Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==614){J=0;KIb(c[O>>2]|0,16,2251592,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==618){J=0;if((eh|0)==0){ue=dh+(ih>>>3)|0;if(((je(d[ue]|d[ue+1|0]<<8|d[ue+2|0]<<16|d[ue+3|0]<<24|0)|0)&-131072>>>((ih&7)>>>0)|0)==0){oh=ih;break}}KIb(c[O>>2]|0,16,2241096,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;ee=-1;break h}else if((J|0)==623){J=0;ue=c[ya>>2]|0;KIb(c[O>>2]|0,16,2235304,(Uc=i,i=i+16|0,c[Uc>>2]=c[xa>>2],c[Uc+8>>2]=ue,Uc)|0);i=Uc;ee=-1;break h}}while(0);if(((c[na>>2]|0)-oh|0)<0){ee=-1094995529;break}ne=Pc+((oh-1|0)/8|0)|0}ypb(wa,c[ma>>2]|0,c[la>>2]|0,(c[xa>>2]|0)-1|0,c[ya>>2]|0,112);Xc=Oc;Yc=be;Zc=257;_c=ne;break b}}while(0);if((c[ga>>2]&8|0)!=0){fd=ee;J=641;break a}gd=c[ma>>2]|0;if(!((gd|0)>-1)){Xc=Oc;Yc=be;Zc=257;_c=Pc;break b}Rc=c[la>>2]|0;if(!((Rc|0)>-1)){Xc=Oc;Yc=be;Zc=257;_c=Pc;break b}ypb(wa,gd,Rc,c[xa>>2]|0,c[ya>>2]|0,14);Xc=Oc;Yc=be;Zc=257;_c=Pc}}}while(0);c[z>>2]=-1;ph=U5a(_c,E,z)|0;Sc=c[z>>2]|0;if(Sc>>>0>511>>>0){J=3;break}else{Mc=Zc;Nc=Yc;Oc=Xc;Pc=ph;Qc=Sc}}if((J|0)==3){if((Yc|0)==0){I=ph;J=4;break}else{qh=ph;break}}else if((J|0)==59){KIb(fa,16,2489040,(Uc=i,i=i+16|0,c[Uc>>2]=Kd,c[Uc+8>>2]=Ld,Uc)|0);i=Uc;fd=-1094995529;i=m;return fd|0}else if((J|0)==115){KIb(fa,16,2478088,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;fd=Nd;i=m;return fd|0}else if((J|0)==249){KIb(c[O>>2]|0,16,2396128,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;fd=-1094995529;i=m;return fd|0}else if((J|0)==251){KIb(c[O>>2]|0,16,2389200,(Uc=i,i=i+16|0,c[Uc>>2]=Wd,c[Uc+8>>2]=Xd,Uc)|0);i=Uc;fd=-1;i=m;return fd|0}else if((J|0)==288){KIb(ce,16,2193024,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;fd=-1;i=m;return fd|0}else if((J|0)==299){KIb(fa,16,2375672,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc;fd=-1094995529;i=m;return fd|0}else if((J|0)==303){KIb(0,0,2368984,(Uc=i,i=i+24|0,c[Uc>>2]=2354104,c[Uc+8>>2]=2345440,c[Uc+16>>2]=1708,Uc)|0);i=Uc;Hd();return 0}else if((J|0)==454){KIb(0,0,2368984,(Uc=i,i=i+24|0,c[Uc>>2]=2216440,c[Uc+8>>2]=2345440,c[Uc+16>>2]=960,Uc)|0);i=Uc;Hd();return 0}else if((J|0)==641){i=m;return fd|0}}}while(0);do{if((J|0)==4){ce=c[A>>2]|0;Xd=ce;if((c[ce+14672>>2]|0)==0){qh=I;break}Wd=ce+9856|0;if((c[Wd>>2]|0)==0){qh=I;break}Nd=c[ce+4>>2]|0;Ld=c[Nd+712>>2]|0;do{if((Ld|0)!=0){if((ve[c[Ld+32>>2]&4095](Nd)|0)>=0){break}KIb(f,16,2152728,(Uc=i,i=i+1|0,i=i+7&-8,c[Uc>>2]=0,Uc)|0);i=Uc}}while(0);if((c[ce+14240>>2]|0)!=0){qh=I;break}if((c[ce+14760>>2]|0)!=0){qh=I;break}zpb(ce+14424|0);ETa(Xd);do{if((c[ce+9992>>2]|0)==3){J=13}else{if((c[ce+13944>>2]|0)!=0){J=13;break}if((c[f+816>>2]&1|0)!=0){Nd=ce+108|0;c[Nd>>2]=(c[Nd>>2]|0)+1}Nd=ce+9848|0;Ld=c[Nd>>2]|0;if((Ld|0)==0){break}fa=YHb(h,Ld|0)|0;if((fa|0)<0){fd=fa;i=m;return fd|0}else{HTa(Xd,c[Nd>>2]|0,h);ITa(Xd,h,c[Nd>>2]|0,1)|0;break}}}while(0);do{if((J|0)==13){ce=YHb(h,c[Wd>>2]|0)|0;if((ce|0)<0){fd=ce;i=m;return fd|0}else{HTa(Xd,c[Wd>>2]|0,h);ITa(Xd,h,c[Wd>>2]|0,1)|0;break}}}while(0);if((c[B+9848>>2]|0)==0){if((c[B+13944>>2]|0)==0){qh=I;break}}c[j>>2]=1;qh=I}}while(0);c[B+9992>>2]=0;do{if((c[f+696>>2]&8|0)!=0){if((c[B+14456>>2]|0)==0){break}else{fd=-1094995529}i=m;return fd|0}}while(0);f=qh-k-(c[B+13752>>2]|0)|0;fd=(f|0)<0?0:f;i=m;return fd|0}function sRa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=c[1644861]|0;h=a+14128|0;i=c[h>>2]|0;j=c[a+14120>>2]|0;a=j+(i>>>3)|0;k=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>23;a=b[g+(k<<2)>>1]|0;l=b[g+(k<<2)+2>>1]|0;k=l<<16>>16;if(l<<16>>16<0){l=i+9|0;m=j+(l>>>3)|0;n=((je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(l&7)>>>((k+32|0)>>>0))+a|0;o=b[g+(n<<2)+2>>1]|0;p=l;q=b[g+(n<<2)>>1]|0}else{o=k;p=i;q=a}a=o+p|0;c[h>>2]=a;if((q|0)==0){r=f;return r|0}if((q|0)<0){r=65535;return r|0}p=d[j+(a>>>3)|0]|0;o=a+1|0;c[h>>2]=o;i=e-1|0;if((i|0)==0){s=q}else{k=j+(o>>>3)|0;j=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(o&7)>>>((33-e|0)>>>0);c[h>>2]=a+e;s=(j|q-1<<i)+1|0}i=28-e|0;r=((p&128>>>((a&7)>>>0)|0)==0?s:-s|0)+f<<i>>i;return r|0}function tRa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;if((e|0)==0){e=c[2094917]|0;g=a+8|0;h=c[g>>2]|0;j=c[a>>2]|0;k=j+(h>>>3)|0;l=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(h&7)>>>23;k=b[e+(l<<2)>>1]|0;m=b[e+(l<<2)+2>>1]|0;l=m<<16>>16;if(m<<16>>16<0){m=h+9|0;n=j+(m>>>3)|0;o=((je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(m&7)>>>((l+32|0)>>>0))+k|0;p=b[e+(o<<2)+2>>1]|0;q=m;r=b[e+(o<<2)>>1]|0}else{p=l;q=h;r=k}k=p+q|0;c[g>>2]=k;s=r;t=k;u=j}else{j=c[2094923]|0;k=a+8|0;r=c[k>>2]|0;g=c[a>>2]|0;q=g+(r>>>3)|0;p=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>23;q=b[j+(p<<2)>>1]|0;h=b[j+(p<<2)+2>>1]|0;p=h<<16>>16;if(h<<16>>16<0){h=r+9|0;l=g+(h>>>3)|0;o=((je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>((p+32|0)>>>0))+q|0;v=b[j+(o<<2)+2>>1]|0;w=h;x=b[j+(o<<2)>>1]|0}else{v=p;w=r;x=q}q=v+w|0;c[k>>2]=q;s=x;t=q;u=g}if((s|0)<0){KIb(0,16,2195648,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;y=65535;i=f;return y|0}if((s|0)==0){y=0;i=f;return y|0}g=u+(t>>>3)|0;u=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(t&7);g=(u^-2147483648)>>31;c[a+8>>2]=t+s;y=((g^u)>>>((32-s|0)>>>0)^g)-g|0;i=f;return y|0}function uRa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;k=e+14128|0;l=e+14120|0;m=(g|0)==0;n=e+4|0;a:do{if((h|0)==0){o=c[k>>2]|0;p=c[l>>2]|0;if(m){q=0;r=o;do{s=a[(d[1242080+q|0]|0)+(e+11184)|0]|0;t=p+(r>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(r&7)>>>24;r=r+8|0;c[k>>2]=r;if((u|0)==0){break a}b[f+((s&255)<<1)>>1]=u;q=q+1|0;}while((q|0)<64);i=j;return}else{q=0;r=o;do{u=d[(d[1242080+q|0]|0)+(e+11184)|0]|0;s=p+(r>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>24;r=r+8|0;c[k>>2]=r;if((t|0)==0){break a}s=t&65535;b[f+(u<<1)>>1]=s;b[g+(u<<1)>>1]=s;q=q+1|0;}while((q|0)<64);i=j;return}}else{if(m){q=0;do{r=d[(d[1242080+q|0]|0)+(e+11184)|0]|0;p=c[k>>2]|0;o=(c[l>>2]|0)+(p>>>3)|0;s=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(p&7)>>>24;c[k>>2]=p+8;if((s|0)==0){break a}if((q|0)!=0|(s|0)==8){v=s&65535}else{KIb(c[n>>2]|0,48,2176176,(w=i,i=i+8|0,c[w>>2]=s,w)|0);i=w;v=8}b[f+(r<<1)>>1]=v;q=q+1|0;}while((q|0)<64);i=j;return}else{q=0;do{r=d[(d[1242080+q|0]|0)+(e+11184)|0]|0;s=c[k>>2]|0;p=(c[l>>2]|0)+(s>>>3)|0;o=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(s&7)>>>24;c[k>>2]=s+8;if((o|0)==0){break a}if((q|0)!=0|(o|0)==8){x=o&65535}else{KIb(c[n>>2]|0,48,2176176,(w=i,i=i+8|0,c[w>>2]=o,w)|0);i=w;x=8}b[f+(r<<1)>>1]=x;b[g+(r<<1)>>1]=x;q=q+1|0;}while((q|0)<64);i=j;return}}}while(0);KIb(c[n>>2]|0,16,2178696,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;i=j;return}function vRa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;do{if((c[b+48>>2]|0)==2){if((c[b+12>>2]|0)<=2800){e=13;break}f=b+12480|0;g=(c[f>>2]&127)+257|0;h=b+784|0;Y2(h);i=g>>>16;j=h|0;h=c[j>>2]|0;k=b+788|0;l=c[k>>2]|0;if((l|0)>16){m=l-16|0;n=h<<16|i}else{o=je(i>>>((16-l|0)>>>0)|h<<l|0)|0;h=b+796|0;p=c[h>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;m=l+16|0;n=i}c[j>>2]=n;c[k>>2]=m;i=g&65535;if((m|0)>16){q=m-16|0;r=n<<16|i}else{g=je(i>>>((16-m|0)>>>0)|n<<m|0)|0;l=b+796|0;h=c[l>>2]|0;y=g;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;q=m+16|0;r=i}c[j>>2]=r;c[k>>2]=q;i=c[f>>2]>>7;if((q|0)>3){s=q-3|0;t=r<<3|i}else{f=je(i>>>((3-q|0)>>>0)|r<<q|0)|0;l=b+796|0;h=c[l>>2]|0;y=f;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;s=q+29|0;t=i}c[j>>2]=t;c[k>>2]=s;u=t;v=s}else{e=13}}while(0);if((e|0)==13){e=(c[b+12480>>2]|0)+257|0;s=b+784|0;Y2(s);t=e>>16;q=s|0;s=c[q>>2]|0;r=b+788|0;m=c[r>>2]|0;if((m|0)>16){w=m-16|0;x=s<<16|t}else{n=je(t>>>((16-m|0)>>>0)|s<<m|0)|0;s=b+796|0;k=c[s>>2]|0;y=n;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;w=m+16|0;x=t}c[q>>2]=x;c[r>>2]=w;t=e&65535;if((w|0)>16){z=w-16|0;A=x<<16|t}else{e=je(t>>>((16-w|0)>>>0)|x<<w|0)|0;x=b+796|0;m=c[x>>2]|0;y=e;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;z=w+16|0;A=t}c[q>>2]=A;c[r>>2]=z;u=A;v=z}z=b+784|0;A=c[b+9960>>2]|0;if((c[b+14192>>2]|0)==0){if((v|0)>5){B=v-5|0;C=u<<5|A}else{r=je(A>>>((5-v|0)>>>0)|u<<v|0)|0;q=b+796|0;t=c[q>>2]|0;y=r;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;B=v+27|0;C=A}c[z>>2]=C;c[b+788>>2]=B;D=C;E=B}else{B=d[1062808+A|0]|0;if((v|0)>5){F=v-5|0;G=u<<5|B}else{A=je(B>>>((5-v|0)>>>0)|u<<v|0)|0;u=b+796|0;C=c[u>>2]|0;y=A;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;F=v+27|0;G=B}c[z>>2]=G;c[b+788>>2]=F;D=G;E=F}F=z|0;z=b+788|0;if((E|0)>1){H=E-1|0;I=D<<1;c[F>>2]=I;c[z>>2]=H;return}else{G=je(D<<E|0)|0;D=b+796|0;b=c[D>>2]|0;y=G;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;H=E+31|0;I=0;c[F>>2]=I;c[z>>2]=H;return}}function wRa(b,e){b=b|0;e=e|0;var f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0;e=i;f=b+4|0;h=c[f>>2]|0;j=+(c[h+224>>2]|0)/+(c[h+228>>2]|0);h=j==0.0;if((c[b+7708>>2]|0)==0){k=b+784|0;l=k;m=k|0;n=b+788|0}else{k=b+10012|0;o=c[k>>2]|0;p=c[1347880+(o<<3)>>2]|0;q=c[1347884+(o<<3)>>2]|0;o=b+784|0;Y2(o);r=o|0;s=c[r>>2]|0;t=b+788|0;u=c[t>>2]|0;if((u|0)>16){v=u-16|0;w=s<<16}else{x=je(s<<u|0)|0;s=b+796|0;z=c[s>>2]|0;y=x;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;v=u+16|0;w=0}c[r>>2]=w;c[t>>2]=v;if((v|0)>16){A=v-16|0}else{u=je(435>>>((16-v|0)>>>0)|w<<v|0)|0;w=b+796|0;s=c[w>>2]|0;y=u;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;A=v+16|0}c[r>>2]=435;c[t>>2]=A;v=b+8|0;w=c[v>>2]&4095;if((A|0)>12){B=A-12|0;C=w|1781760}else{s=je(w>>>((12-A|0)>>>0)|435<<A|0)|0;u=b+796|0;z=c[u>>2]|0;y=s;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;B=A+20|0;C=w}c[r>>2]=C;c[t>>2]=B;w=b+12|0;A=c[w>>2]&4095;if((B|0)>12){D=B-12|0;E=A|C<<12}else{u=je(A>>>((12-B|0)>>>0)|C<<B|0)|0;C=b+796|0;z=c[C>>2]|0;y=u;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;D=B+20|0;E=A}c[r>>2]=E;c[t>>2]=D;A=b+48|0;F=h?1.0:j;h=b+13928|0;if((c[A>>2]|0)==1){B=1;j=1.0e10;while(1){H=F-1.0/+g[1347488+(B<<2)>>2];if(H<0.0){I=-0.0-H}else{I=H}if(I<j){c[h>>2]=B;J=I}else{J=j}C=B+1|0;if((C|0)<15){B=C;j=J}else{break}}}else{B=1;J=1.0e10;while(1){if((B|0)<2){K=1.0/+g[1347488+(B<<2)>>2]}else{K=+(c[1346112+(B<<3)>>2]|0)/+(c[1346116+(B<<3)>>2]|0)*+(c[w>>2]|0)/+(c[v>>2]|0)}j=F-K;if(j<0.0){L=-0.0-j}else{L=j}if(L<J){c[h>>2]=B;M=L}else{M=J}C=B+1|0;if((C|0)<15){B=C;J=M}else{break}}}B=c[h>>2]|0;if((D|0)>4){N=D-4|0;O=B|E<<4}else{h=je(B>>>((4-D|0)>>>0)|E<<D|0)|0;E=b+796|0;C=c[E>>2]|0;y=h;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;N=D+28|0;O=B}c[r>>2]=O;c[t>>2]=N;B=c[k>>2]|0;if((N|0)>4){P=N-4|0;Q=B|O<<4}else{k=je(B>>>((4-N|0)>>>0)|O<<N|0)|0;O=b+796|0;D=c[O>>2]|0;y=k;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[O>>2]=(c[O>>2]|0)+4;P=N+28|0;Q=B}c[r>>2]=Q;c[t>>2]=P;B=c[f>>2]|0;N=c[B+540>>2]|0;do{if((N|0)==0){R=262143}else{O=(N+399|0)/400|0;if(!(O>>>0>262143>>>0)){R=O;break}R=(c[A>>2]|0)==1?262143:O}}while(0);N=c[B+524>>2]|0;if((N|0)==0){S=(((c[b+24>>2]|0)*20|0|0)/575964|0)<<13}else{S=N}N=S+16383|0;S=R&262143;if((P|0)>18){T=P-18|0;U=S|Q<<18}else{B=je(S>>>((18-P|0)>>>0)|Q<<P|0)|0;Q=b+796|0;O=c[Q>>2]|0;y=B;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;T=P+14|0;U=S}c[r>>2]=U;c[t>>2]=T;if((T|0)>1){V=T-1|0;W=U<<1|1}else{S=je(1>>>((1-T|0)>>>0)|U<<T|0)|0;U=b+796|0;P=c[U>>2]|0;y=S;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[U>>2]=(c[U>>2]|0)+4;V=T+31|0;W=1}c[r>>2]=W;c[t>>2]=V;T=N>>>14&1023;if((V|0)>10){X=V-10|0;Y=W<<10|T}else{U=je(T>>>((10-V|0)>>>0)|W<<V|0)|0;W=b+796|0;P=c[W>>2]|0;y=U;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;X=V+22|0;Y=T}c[r>>2]=Y;c[t>>2]=X;do{if((c[v>>2]|0)<769){if((c[w>>2]|0)>=577){Z=0;break}T=ca(c[b+120>>2]|0,c[b+116>>2]|0)|0;if((T|0)>=397){Z=0;break}if((ca(T,p)|0)>(q*9900|0|0)|(p|0)>(q*30|0|0)){Z=0;break}T=c[(c[f>>2]|0)+276>>2]|0;if(!((T|0)!=0&(T|0)<128&N>>>0<344064>>>0&R>>>0<4641>>>0)){Z=0;break}Z=(c[A>>2]|0)==1|0}else{Z=0}}while(0);if((X|0)>1){_=X-1|0;$=Z|Y<<1}else{T=je(Z>>>((1-X|0)>>>0)|Y<<X|0)|0;Y=b+796|0;V=c[Y>>2]|0;y=T;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[Y>>2]=(c[Y>>2]|0)+4;_=X+31|0;$=Z}c[r>>2]=$;c[t>>2]=_;XTa(o,c[(c[f>>2]|0)+300>>2]|0);XTa(o,c[(c[f>>2]|0)+304>>2]|0);if((c[A>>2]|0)==2){Y2(o);A=c[r>>2]|0;_=c[t>>2]|0;if((_|0)>16){aa=_-16|0;ba=A<<16}else{$=je(A<<_|0)|0;A=b+796|0;Z=c[A>>2]|0;y=$;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;aa=_+16|0;ba=0}c[r>>2]=ba;c[t>>2]=aa;if((aa|0)>16){da=aa-16|0}else{_=je(437>>>((16-aa|0)>>>0)|ba<<aa|0)|0;ba=b+796|0;A=c[ba>>2]|0;y=_;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[ba>>2]=(c[ba>>2]|0)+4;da=aa+16|0}c[r>>2]=437;c[t>>2]=da;if((da|0)>4){ea=da-4|0;fa=6993}else{aa=je(1>>>((4-da|0)>>>0)|437<<da|0)|0;ba=b+796|0;A=c[ba>>2]|0;y=aa;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[ba>>2]=(c[ba>>2]|0)+4;ea=da+28|0;fa=1}c[r>>2]=fa;c[t>>2]=ea;da=c[f>>2]|0;ba=(c[da+840>>2]|0)==0|0;if((ea|0)>1){ga=ea-1|0;ha=ba|fa<<1;ia=da}else{da=je(ba>>>((1-ea|0)>>>0)|fa<<ea|0)|0;fa=b+796|0;A=c[fa>>2]|0;y=da;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[fa>>2]=(c[fa>>2]|0)+4;ga=ea+31|0;ha=ba;ia=c[f>>2]|0}c[r>>2]=ha;c[t>>2]=ga;ba=c[ia+840>>2]|0;if((ga|0)>3){ja=ga-3|0;ka=ba|ha<<3;la=ia}else{ia=je(ba>>>((3-ga|0)>>>0)|ha<<ga|0)|0;ha=b+796|0;ea=c[ha>>2]|0;y=ia;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;ja=ga+29|0;ka=ba;la=c[f>>2]|0}c[r>>2]=ka;c[t>>2]=ja;ba=c[la+844>>2]|0;if((ja|0)>4){ma=ja-4|0;na=ba|ka<<4}else{la=je(ba>>>((4-ja|0)>>>0)|ka<<ja|0)|0;ka=b+796|0;ga=c[ka>>2]|0;y=la;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[ka>>2]=(c[ka>>2]|0)+4;ma=ja+28|0;na=ba}c[r>>2]=na;c[t>>2]=ma;ba=c[b+14152>>2]|0;if((ma|0)>1){oa=ma-1|0;pa=ba|na<<1}else{ja=je(ba>>>((1-ma|0)>>>0)|na<<ma|0)|0;na=b+796|0;ka=c[na>>2]|0;y=ja;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;c[na>>2]=(c[na>>2]|0)+4;oa=ma+31|0;pa=ba}c[r>>2]=pa;c[t>>2]=oa;ba=c[b+14212>>2]|0;if((oa|0)>2){qa=oa-2|0;ra=ba|pa<<2}else{ma=je(ba>>>((2-oa|0)>>>0)|pa<<oa|0)|0;pa=b+796|0;na=c[pa>>2]|0;y=ma;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[pa>>2]=(c[pa>>2]|0)+4;qa=oa+30|0;ra=ba}c[r>>2]=ra;c[t>>2]=qa;ba=c[v>>2]>>12;if((qa|0)>2){sa=qa-2|0;ta=ba|ra<<2}else{v=je(ba>>>((2-qa|0)>>>0)|ra<<qa|0)|0;ra=b+796|0;oa=c[ra>>2]|0;y=v;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;c[ra>>2]=(c[ra>>2]|0)+4;sa=qa+30|0;ta=ba}c[r>>2]=ta;c[t>>2]=sa;ba=c[w>>2]>>12;if((sa|0)>2){ua=sa-2|0;va=ba|ta<<2}else{w=je(ba>>>((2-sa|0)>>>0)|ta<<sa|0)|0;ta=b+796|0;qa=c[ta>>2]|0;y=w;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;c[ta>>2]=(c[ta>>2]|0)+4;ua=sa+30|0;va=ba}c[r>>2]=va;c[t>>2]=ua;ba=R>>>18;if((ua|0)>12){wa=ua-12|0;xa=va<<12|ba}else{R=je(ba>>>((12-ua|0)>>>0)|va<<ua|0)|0;va=b+796|0;sa=c[va>>2]|0;y=R;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;c[va>>2]=(c[va>>2]|0)+4;wa=ua+20|0;xa=ba}c[r>>2]=xa;c[t>>2]=wa;if((wa|0)>1){ya=wa-1|0;za=xa<<1|1}else{ba=je(1>>>((1-wa|0)>>>0)|xa<<wa|0)|0;xa=b+796|0;ua=c[xa>>2]|0;y=ba;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y;c[xa>>2]=(c[xa>>2]|0)+4;ya=wa+31|0;za=1}c[r>>2]=za;c[t>>2]=ya;wa=N>>>24;if((ya|0)>8){Aa=ya-8|0;Ba=za<<8|wa}else{N=je(wa>>>((8-ya|0)>>>0)|za<<ya|0)|0;za=b+796|0;xa=c[za>>2]|0;y=N;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[za>>2]=(c[za>>2]|0)+4;Aa=ya+24|0;Ba=wa}c[r>>2]=Ba;c[t>>2]=Aa;wa=c[b+13944>>2]|0;if((Aa|0)>1){Ca=Aa-1|0;Da=wa|Ba<<1}else{ya=je(wa>>>((1-Aa|0)>>>0)|Ba<<Aa|0)|0;Ba=b+796|0;za=c[Ba>>2]|0;y=ya;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;c[Ba>>2]=(c[Ba>>2]|0)+4;Ca=Aa+31|0;Da=wa}c[r>>2]=Da;c[t>>2]=Ca;wa=(c[b+10016>>2]|0)-1|0;if((Ca|0)>2){Ea=Ca-2|0;Fa=wa|Da<<2}else{Aa=je(wa>>>((2-Ca|0)>>>0)|Da<<Ca|0)|0;Da=b+796|0;Ba=c[Da>>2]|0;y=Aa;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;c[Da>>2]=(c[Da>>2]|0)+4;Ea=Ca+30|0;Fa=wa}c[r>>2]=Fa;c[t>>2]=Ea;wa=(c[b+10020>>2]|0)-1|0;if((Ea|0)>5){Ga=Ea-5|0;Ha=wa|Fa<<5}else{Ca=je(wa>>>((5-Ea|0)>>>0)|Fa<<Ea|0)|0;Fa=b+796|0;Da=c[Fa>>2]|0;y=Ca;a[Da]=y;y=y>>8;a[Da+1|0]=y;y=y>>8;a[Da+2|0]=y;y=y>>8;a[Da+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;Ga=Ea+27|0;Ha=wa}c[r>>2]=Ha;c[t>>2]=Ga}Y2(o);Ga=c[r>>2]|0;Ha=c[t>>2]|0;if((Ha|0)>16){Ia=Ha-16|0;Ja=Ga<<16}else{wa=je(Ga<<Ha|0)|0;Ga=b+796|0;Ea=c[Ga>>2]|0;y=wa;a[Ea]=y;y=y>>8;a[Ea+1|0]=y;y=y>>8;a[Ea+2|0]=y;y=y>>8;a[Ea+3|0]=y;c[Ga>>2]=(c[Ga>>2]|0)+4;Ia=Ha+16|0;Ja=0}c[r>>2]=Ja;c[t>>2]=Ia;if((Ia|0)>16){Ka=Ia-16|0}else{Ha=je(440>>>((16-Ia|0)>>>0)|Ja<<Ia|0)|0;Ja=b+796|0;Ga=c[Ja>>2]|0;y=Ha;a[Ga]=y;y=y>>8;a[Ga+1|0]=y;y=y>>8;a[Ga+2|0]=y;y=y>>8;a[Ga+3|0]=y;c[Ja>>2]=(c[Ja>>2]|0)+4;Ka=Ia+16|0}c[r>>2]=440;c[t>>2]=Ka;Ia=b+14244|0;Ja=c[Ia>>2]|0;if((Ka|0)>1){La=Ka-1|0;Ma=Ja|880;Na=Ja}else{Ga=je(Ja>>>((1-Ka|0)>>>0)|440<<Ka|0)|0;Ha=b+796|0;Ea=c[Ha>>2]|0;y=Ga;a[Ea]=y;y=y>>8;a[Ea+1|0]=y;y=y>>8;a[Ea+2|0]=y;y=y>>8;a[Ea+3|0]=y;c[Ha>>2]=(c[Ha>>2]|0)+4;La=Ka+31|0;Ma=Ja;Na=c[Ia>>2]|0}c[r>>2]=Ma;c[t>>2]=La;Ia=(((q|0)/2|0)+p|0)/(q|0)|0;q=c[(c[b+9856>>2]|0)+160>>2]|0;p=(c[f>>2]|0)+616|0;f=wrc(c[p>>2]|0,c[p+4>>2]|0,q,(q|0)<0|0?-1:0)|0;p=G;c[b+14140>>2]=q;if((Na|0)!=(c[b+14264>>2]&1|0)){KIb(0,0,2508440,(Oa=i,i=i+24|0,c[Oa>>2]=2267736,c[Oa+8>>2]=2450048,c[Oa+16>>2]=343,Oa)|0);i=Oa;Hd()}if((Na|0)==0){Pa=p;Qa=f;Ra=Ma;Sa=La}else{La=lLb(f,Ia)|0;Pa=(La|0)<0|0?-1:0;Qa=La;Ra=c[r>>2]|0;Sa=c[t>>2]|0}La=Frc(Qa,Pa,Ia*3600|0,0)|0;f=Grc(La,G,24,0)|0;La=f;if((Sa|0)>5){Ta=Sa-5|0;Ua=La|Ra<<5}else{f=je(La>>>((5-Sa|0)>>>0)|Ra<<Sa|0)|0;Ra=b+796|0;Ma=c[Ra>>2]|0;y=f;a[Ma]=y;y=y>>8;a[Ma+1|0]=y;y=y>>8;a[Ma+2|0]=y;y=y>>8;a[Ma+3|0]=y;c[Ra>>2]=(c[Ra>>2]|0)+4;Ta=Sa+27|0;Ua=La}c[r>>2]=Ua;c[t>>2]=Ta;La=Frc(Qa,Pa,Ia*60|0,0)|0;Sa=Grc(La,G,60,0)|0;La=Sa;if((Ta|0)>6){Va=Ta-6|0;Wa=La|Ua<<6}else{Sa=je(La>>>((6-Ta|0)>>>0)|Ua<<Ta|0)|0;Ua=b+796|0;Ra=c[Ua>>2]|0;y=Sa;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;c[Ua>>2]=(c[Ua>>2]|0)+4;Va=Ta+26|0;Wa=La}c[r>>2]=Wa;c[t>>2]=Va;if((Va|0)>1){Xa=Va-1|0;Ya=Wa<<1|1}else{La=je(1>>>((1-Va|0)>>>0)|Wa<<Va|0)|0;Wa=b+796|0;Ta=c[Wa>>2]|0;y=La;a[Ta]=y;y=y>>8;a[Ta+1|0]=y;y=y>>8;a[Ta+2|0]=y;y=y>>8;a[Ta+3|0]=y;c[Wa>>2]=(c[Wa>>2]|0)+4;Xa=Va+31|0;Ya=1}c[r>>2]=Ya;c[t>>2]=Xa;Va=Ia;Ia=0;Wa=Frc(Qa,Pa,Va,Ia)|0;Ta=Grc(Wa,G,60,0)|0;Wa=Ta;if((Xa|0)>6){Za=Xa-6|0;_a=Wa|Ya<<6}else{Ta=je(Wa>>>((6-Xa|0)>>>0)|Ya<<Xa|0)|0;Ya=b+796|0;La=c[Ya>>2]|0;y=Ta;a[La]=y;y=y>>8;a[La+1|0]=y;y=y>>8;a[La+2|0]=y;y=y>>8;a[La+3|0]=y;c[Ya>>2]=(c[Ya>>2]|0)+4;Za=Xa+26|0;_a=Wa}c[r>>2]=_a;c[t>>2]=Za;Wa=Grc(Qa,Pa,Va,Ia)|0;Ia=Wa;if((Za|0)>6){$a=Za-6|0;ab=Ia|_a<<6}else{Wa=je(Ia>>>((6-Za|0)>>>0)|_a<<Za|0)|0;_a=b+796|0;Va=c[_a>>2]|0;y=Wa;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;c[_a>>2]=(c[_a>>2]|0)+4;$a=Za+26|0;ab=Ia}c[r>>2]=ab;c[t>>2]=$a;Ia=(c[b+60>>2]|0)>>>31;if(($a|0)>1){bb=$a-1|0;cb=Ia|ab<<1}else{Za=je(Ia>>>((1-$a|0)>>>0)|ab<<$a|0)|0;ab=b+796|0;_a=c[ab>>2]|0;y=Za;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;c[ab>>2]=(c[ab>>2]|0)+4;bb=$a+31|0;cb=Ia}c[r>>2]=cb;c[t>>2]=bb;if((bb|0)>1){db=bb-1|0;eb=cb<<1}else{Ia=je(cb<<bb|0)|0;cb=b+796|0;$a=c[cb>>2]|0;y=Ia;a[$a]=y;y=y>>8;a[$a+1|0]=y;y=y>>8;a[$a+2|0]=y;y=y>>8;a[$a+3|0]=y;c[cb>>2]=(c[cb>>2]|0)+4;db=bb+31|0;eb=0}c[r>>2]=eb;c[t>>2]=db;l=o;m=r;n=t}Y2(l);t=c[m>>2]|0;r=c[n>>2]|0;if((r|0)>16){fb=r-16|0;gb=t<<16}else{o=je(t<<r|0)|0;t=b+796|0;db=c[t>>2]|0;y=o;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;fb=r+16|0;gb=0}c[m>>2]=gb;c[n>>2]=fb;if((fb|0)>16){hb=fb-16|0}else{r=je(256>>>((16-fb|0)>>>0)|gb<<fb|0)|0;gb=b+796|0;t=c[gb>>2]|0;y=r;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[gb>>2]=(c[gb>>2]|0)+4;hb=fb+16|0}c[m>>2]=256;c[n>>2]=hb;fb=(c[b+108>>2]|0)-(c[b+14140>>2]|0)&1023;if((hb|0)>10){ib=hb-10|0;jb=fb|262144}else{gb=je(fb>>>((10-hb|0)>>>0)|256<<hb|0)|0;t=b+796|0;r=c[t>>2]|0;y=gb;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;ib=hb+22|0;jb=fb}c[m>>2]=jb;c[n>>2]=ib;fb=b+9992|0;hb=c[fb>>2]|0;if((ib|0)>3){kb=ib-3|0;lb=jb<<3|hb;mb=c[b+796>>2]|0}else{t=je(jb<<ib|hb>>>((3-ib|0)>>>0)|0)|0;jb=b+796|0;r=c[jb>>2]|0;y=t;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[jb>>2]|0)+4|0;c[jb>>2]=r;kb=ib+29|0;lb=hb;mb=r}c[m>>2]=lb;c[n>>2]=kb;r=c[b+792>>2]|0;hb=b+796|0;c[b+14148>>2]=r+((32-kb+(mb-r<<3)|0)/8|0);if((kb|0)>16){nb=kb-16|0;ob=lb<<16|65535;pb=mb}else{r=mb;y=je(65535>>>((16-kb|0)>>>0)|lb<<kb|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[hb>>2]|0)+4|0;c[hb>>2]=r;nb=kb+16|0;ob=65535;pb=r}c[m>>2]=ob;c[n>>2]=nb;do{if(((c[fb>>2]|0)-2|0)>>>0<2>>>0){if((nb|0)>1){qb=nb-1|0;rb=ob<<1;sb=pb}else{r=pb;y=je(ob<<nb|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[hb>>2]|0)+4|0;c[hb>>2]=r;qb=nb+31|0;rb=0;sb=r}c[m>>2]=rb;c[n>>2]=qb;r=b+48|0;do{if((c[r>>2]|0)==1){kb=c[b+11556>>2]|0;if((qb|0)>3){tb=qb-3|0;ub=rb<<3|kb;vb=sb;break}else{lb=sb;y=je(rb<<qb|kb>>>((3-qb|0)>>>0)|0)|0;a[lb]=y;y=y>>8;a[lb+1|0]=y;y=y>>8;a[lb+2|0]=y;y=y>>8;a[lb+3|0]=y;lb=(c[hb>>2]|0)+4|0;c[hb>>2]=lb;tb=qb+29|0;ub=kb;vb=lb;break}}else{if((qb|0)>3){tb=qb-3|0;ub=rb<<3|7;vb=sb;break}else{lb=sb;y=je(rb<<qb|7>>>((3-qb|0)>>>0)|0)|0;a[lb]=y;y=y>>8;a[lb+1|0]=y;y=y>>8;a[lb+2|0]=y;y=y>>8;a[lb+3|0]=y;lb=(c[hb>>2]|0)+4|0;c[hb>>2]=lb;tb=qb+29|0;ub=7;vb=lb;break}}}while(0);c[m>>2]=ub;c[n>>2]=tb;if((c[fb>>2]|0)!=3){wb=tb;xb=ub;yb=vb;break}if((tb|0)>1){zb=tb-1|0;Ab=ub<<1;Bb=vb}else{lb=vb;y=je(ub<<tb|0)|0;a[lb]=y;y=y>>8;a[lb+1|0]=y;y=y>>8;a[lb+2|0]=y;y=y>>8;a[lb+3|0]=y;lb=(c[hb>>2]|0)+4|0;c[hb>>2]=lb;zb=tb+31|0;Ab=0;Bb=lb}c[m>>2]=Ab;c[n>>2]=zb;if((c[r>>2]|0)==1){lb=c[b+11560>>2]|0;if((zb|0)>3){Cb=zb-3|0;Db=Ab<<3|lb;Eb=Bb}else{kb=Bb;y=je(Ab<<zb|lb>>>((3-zb|0)>>>0)|0)|0;a[kb]=y;y=y>>8;a[kb+1|0]=y;y=y>>8;a[kb+2|0]=y;y=y>>8;a[kb+3|0]=y;kb=(c[hb>>2]|0)+4|0;c[hb>>2]=kb;Cb=zb+29|0;Db=lb;Eb=kb}c[m>>2]=Db;c[n>>2]=Cb;wb=Cb;xb=Db;yb=Eb;break}else{if((zb|0)>3){Fb=zb-3|0;Gb=Ab<<3|7;Hb=Bb}else{kb=Bb;y=je(Ab<<zb|7>>>((3-zb|0)>>>0)|0)|0;a[kb]=y;y=y>>8;a[kb+1|0]=y;y=y>>8;a[kb+2|0]=y;y=y>>8;a[kb+3|0]=y;kb=(c[hb>>2]|0)+4|0;c[hb>>2]=kb;Fb=zb+29|0;Gb=7;Hb=kb}c[m>>2]=Gb;c[n>>2]=Fb;wb=Fb;xb=Gb;yb=Hb;break}}else{wb=nb;xb=ob;yb=pb}}while(0);if((wb|0)>1){Ib=wb-1|0;Jb=xb<<1}else{pb=yb;y=je(xb<<wb|0)|0;a[pb]=y;y=y>>8;a[pb+1|0]=y;y=y>>8;a[pb+2|0]=y;y=y>>8;a[pb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Ib=wb+31|0;Jb=0}c[m>>2]=Jb;c[n>>2]=Ib;Ib=b+14180|0;c[Ib>>2]=1;if((c[b+48>>2]|0)==2){Y2(l);Jb=c[m>>2]|0;wb=c[n>>2]|0;if((wb|0)>16){Kb=wb-16|0;Lb=Jb<<16}else{pb=je(Jb<<wb|0)|0;Jb=c[hb>>2]|0;y=pb;a[Jb]=y;y=y>>8;a[Jb+1|0]=y;y=y>>8;a[Jb+2|0]=y;y=y>>8;a[Jb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Kb=wb+16|0;Lb=0}c[m>>2]=Lb;c[n>>2]=Kb;if((Kb|0)>16){Mb=Kb-16|0}else{wb=je(437>>>((16-Kb|0)>>>0)|Lb<<Kb|0)|0;Lb=c[hb>>2]|0;y=wb;a[Lb]=y;y=y>>8;a[Lb+1|0]=y;y=y>>8;a[Lb+2|0]=y;y=y>>8;a[Lb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Mb=Kb+16|0}c[m>>2]=437;c[n>>2]=Mb;if((Mb|0)>4){Nb=Mb-4|0;Ob=7e3}else{Kb=je(8>>>((4-Mb|0)>>>0)|437<<Mb|0)|0;Lb=c[hb>>2]|0;y=Kb;a[Lb]=y;y=y>>8;a[Lb+1|0]=y;y=y>>8;a[Lb+2|0]=y;y=y>>8;a[Lb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Nb=Mb+28|0;Ob=8}c[m>>2]=Ob;c[n>>2]=Nb;do{if(((c[fb>>2]|0)-2|0)>>>0<2>>>0){Mb=b+11556|0;Lb=c[Mb>>2]|0;if((Nb|0)>4){Pb=Nb-4|0;Qb=Ob<<4|Lb;Rb=Lb}else{Kb=je(Ob<<Nb|Lb>>>((4-Nb|0)>>>0)|0)|0;wb=c[hb>>2]|0;y=Kb;a[wb]=y;y=y>>8;a[wb+1|0]=y;y=y>>8;a[wb+2|0]=y;y=y>>8;a[wb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Pb=Nb+28|0;Qb=Lb;Rb=c[Mb>>2]|0}c[m>>2]=Qb;c[n>>2]=Pb;if((Pb|0)>4){Sb=Pb-4|0;Tb=Qb<<4|Rb;break}else{Mb=je(Qb<<Pb|Rb>>>((4-Pb|0)>>>0)|0)|0;Lb=c[hb>>2]|0;y=Mb;a[Lb]=y;y=y>>8;a[Lb+1|0]=y;y=y>>8;a[Lb+2|0]=y;y=y>>8;a[Lb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Sb=Pb+28|0;Tb=Rb;break}}else{if((Nb|0)>8){Sb=Nb-8|0;Tb=Ob<<8|255;break}else{Lb=je(Ob<<Nb|255>>>((8-Nb|0)>>>0)|0)|0;Mb=c[hb>>2]|0;y=Lb;a[Mb]=y;y=y>>8;a[Mb+1|0]=y;y=y>>8;a[Mb+2|0]=y;y=y>>8;a[Mb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Sb=Nb+24|0;Tb=255;break}}}while(0);c[m>>2]=Tb;c[n>>2]=Sb;do{if((c[fb>>2]|0)==3){Nb=b+11560|0;Ob=c[Nb>>2]|0;if((Sb|0)>4){Ub=Sb-4|0;Vb=Tb<<4|Ob;Wb=Ob}else{Rb=je(Ob>>>((4-Sb|0)>>>0)|Tb<<Sb|0)|0;Pb=c[hb>>2]|0;y=Rb;a[Pb]=y;y=y>>8;a[Pb+1|0]=y;y=y>>8;a[Pb+2|0]=y;y=y>>8;a[Pb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Ub=Sb+28|0;Vb=Ob;Wb=c[Nb>>2]|0}c[m>>2]=Vb;c[n>>2]=Ub;if((Ub|0)>4){Xb=Ub-4|0;Yb=Vb<<4|Wb;break}else{Nb=je(Vb<<Ub|Wb>>>((4-Ub|0)>>>0)|0)|0;Ob=c[hb>>2]|0;y=Nb;a[Ob]=y;y=y>>8;a[Ob+1|0]=y;y=y>>8;a[Ob+2|0]=y;y=y>>8;a[Ob+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Xb=Ub+28|0;Yb=Wb;break}}else{if((Sb|0)>8){Xb=Sb-8|0;Yb=Tb<<8|255;break}else{Ob=je(255>>>((8-Sb|0)>>>0)|Tb<<Sb|0)|0;Nb=c[hb>>2]|0;y=Ob;a[Nb]=y;y=y>>8;a[Nb+1|0]=y;y=y>>8;a[Nb+2|0]=y;y=y>>8;a[Nb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Xb=Sb+24|0;Yb=255;break}}}while(0);c[m>>2]=Yb;c[n>>2]=Xb;Sb=c[b+14176>>2]|0;if((Xb|0)>2){Zb=Xb-2|0;_b=Yb<<2|Sb}else{Tb=je(Yb<<Xb|Sb>>>((2-Xb|0)>>>0)|0)|0;Yb=c[hb>>2]|0;y=Tb;a[Yb]=y;y=y>>8;a[Yb+1|0]=y;y=y>>8;a[Yb+2|0]=y;y=y>>8;a[Yb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Zb=Xb+30|0;_b=Sb}c[m>>2]=_b;c[n>>2]=Zb;if((c[b+14172>>2]|0)!=3){KIb(0,0,2508440,(Oa=i,i=i+24|0,c[Oa>>2]=2600896,c[Oa+8>>2]=2450048,c[Oa+16>>2]=448,Oa)|0);i=Oa;Hd()}if((Zb|0)>2){$b=Zb-2|0;ac=_b<<2|3}else{Oa=je(_b<<Zb|3>>>((2-Zb|0)>>>0)|0)|0;_b=c[hb>>2]|0;y=Oa;a[_b]=y;y=y>>8;a[_b+1|0]=y;y=y>>8;a[_b+2|0]=y;y=y>>8;a[_b+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;$b=Zb+30|0;ac=3}c[m>>2]=ac;c[n>>2]=$b;Zb=b+14152|0;do{if((c[Zb>>2]|0)==0){_b=c[(c[b+9856>>2]|0)+300>>2]|0;if(($b|0)>1){bc=$b-1|0;cc=ac<<1|_b;break}else{Oa=je(ac<<$b|_b>>>((1-$b|0)>>>0)|0)|0;Sb=c[hb>>2]|0;y=Oa;a[Sb]=y;y=y>>8;a[Sb+1|0]=y;y=y>>8;a[Sb+2|0]=y;y=y>>8;a[Sb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;bc=$b+31|0;cc=_b;break}}else{if(($b|0)>1){bc=$b-1|0;cc=ac<<1;break}else{_b=je(ac<<$b|0)|0;Sb=c[hb>>2]|0;y=_b;a[Sb]=y;y=y>>8;a[Sb+1|0]=y;y=y>>8;a[Sb+2|0]=y;y=y>>8;a[Sb+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;bc=$b+31|0;cc=0;break}}}while(0);c[m>>2]=cc;c[n>>2]=bc;$b=c[Zb>>2]|0;c[Ib>>2]=$b;if((bc|0)>1){dc=bc-1|0;ec=cc<<1|$b}else{Ib=je($b>>>((1-bc|0)>>>0)|cc<<bc|0)|0;cc=c[hb>>2]|0;y=Ib;a[cc]=y;y=y>>8;a[cc+1|0]=y;y=y>>8;a[cc+2|0]=y;y=y>>8;a[cc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;dc=bc+31|0;ec=$b}c[m>>2]=ec;c[n>>2]=dc;$b=c[b+14188>>2]|0;if((dc|0)>1){fc=dc-1|0;gc=ec<<1|$b}else{bc=je(ec<<dc|$b>>>((1-dc|0)>>>0)|0)|0;ec=c[hb>>2]|0;y=bc;a[ec]=y;y=y>>8;a[ec+1|0]=y;y=y>>8;a[ec+2|0]=y;y=y>>8;a[ec+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;fc=dc+31|0;gc=$b}c[m>>2]=gc;c[n>>2]=fc;$b=c[b+14192>>2]|0;if((fc|0)>1){hc=fc-1|0;ic=gc<<1|$b}else{dc=je(gc<<fc|$b>>>((1-fc|0)>>>0)|0)|0;gc=c[hb>>2]|0;y=dc;a[gc]=y;y=y>>8;a[gc+1|0]=y;y=y>>8;a[gc+2|0]=y;y=y>>8;a[gc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;hc=fc+31|0;ic=$b}c[m>>2]=ic;c[n>>2]=hc;$b=c[b+14196>>2]|0;if((hc|0)>1){jc=hc-1|0;kc=ic<<1|$b}else{fc=je(ic<<hc|$b>>>((1-hc|0)>>>0)|0)|0;ic=c[hb>>2]|0;y=fc;a[ic]=y;y=y>>8;a[ic+1|0]=y;y=y>>8;a[ic+2|0]=y;y=y>>8;a[ic+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;jc=hc+31|0;kc=$b}c[m>>2]=kc;c[n>>2]=jc;$b=c[b+14200>>2]|0;if((jc|0)>1){lc=jc-1|0;mc=kc<<1|$b}else{hc=je(kc<<jc|$b>>>((1-jc|0)>>>0)|0)|0;kc=c[hb>>2]|0;y=hc;a[kc]=y;y=y>>8;a[kc+1|0]=y;y=y>>8;a[kc+2|0]=y;y=y>>8;a[kc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;lc=jc+31|0;mc=$b}c[m>>2]=mc;c[n>>2]=lc;$b=c[b+14204>>2]|0;if((lc|0)>1){nc=lc-1|0;oc=mc<<1|$b}else{jc=je(mc<<lc|$b>>>((1-lc|0)>>>0)|0)|0;mc=c[hb>>2]|0;y=jc;a[mc]=y;y=y>>8;a[mc+1|0]=y;y=y>>8;a[mc+2|0]=y;y=y>>8;a[mc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;nc=lc+31|0;oc=$b}c[m>>2]=oc;c[n>>2]=nc;$b=c[Zb>>2]|0;Zb=b+14224|0;c[Zb>>2]=$b;lc=(c[b+14212>>2]|0)==1?$b:0;if((nc|0)>1){pc=nc-1|0;qc=oc<<1|lc;rc=$b}else{$b=je(lc>>>((1-nc|0)>>>0)|oc<<nc|0)|0;oc=c[hb>>2]|0;y=$b;a[oc]=y;y=y>>8;a[oc+1|0]=y;y=y>>8;a[oc+2|0]=y;y=y>>8;a[oc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;pc=nc+31|0;qc=lc;rc=c[Zb>>2]|0}c[m>>2]=qc;c[n>>2]=pc;if((pc|0)>1){sc=pc-1|0;tc=qc<<1|rc}else{Zb=je(qc<<pc|rc>>>((1-pc|0)>>>0)|0)|0;qc=c[hb>>2]|0;y=Zb;a[qc]=y;y=y>>8;a[qc+1|0]=y;y=y>>8;a[qc+2|0]=y;y=y>>8;a[qc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;sc=pc+31|0;tc=rc}c[m>>2]=tc;c[n>>2]=sc;if((sc|0)>1){uc=sc-1|0;vc=tc<<1}else{rc=je(tc<<sc|0)|0;tc=c[hb>>2]|0;y=rc;a[tc]=y;y=y>>8;a[tc+1|0]=y;y=y>>8;a[tc+2|0]=y;y=y>>8;a[tc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;uc=sc+31|0;vc=0}c[m>>2]=vc;c[n>>2]=uc}if((c[b+14248>>2]|0)!=0){Y2(l);uc=c[m>>2]|0;vc=c[n>>2]|0;if((vc|0)>16){wc=vc-16|0;xc=uc<<16}else{sc=je(uc<<vc|0)|0;uc=c[hb>>2]|0;y=sc;a[uc]=y;y=y>>8;a[uc+1|0]=y;y=y>>8;a[uc+2|0]=y;y=y>>8;a[uc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;wc=vc+16|0;xc=0}c[m>>2]=xc;c[n>>2]=wc;if((wc|0)>16){yc=wc-16|0}else{vc=je(434>>>((16-wc|0)>>>0)|xc<<wc|0)|0;xc=c[hb>>2]|0;y=vc;a[xc]=y;y=y>>8;a[xc+1|0]=y;y=y>>8;a[xc+2|0]=y;y=y>>8;a[xc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;yc=wc+16|0}c[m>>2]=434;c[n>>2]=yc;wc=0;xc=434;vc=yc;while(1){yc=d[551888+wc|0]|0;if((vc|0)>8){zc=vc-8|0;Ac=xc<<8|yc}else{uc=je(yc>>>((8-vc|0)>>>0)|xc<<vc|0)|0;sc=c[hb>>2]|0;y=uc;a[sc]=y;y=y>>8;a[sc+1|0]=y;y=y>>8;a[sc+2|0]=y;y=y>>8;a[sc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;zc=vc+24|0;Ac=yc}c[m>>2]=Ac;c[n>>2]=zc;yc=wc+1|0;if(yc>>>0<14>>>0){wc=yc;xc=Ac;vc=zc}else{break}}}zc=fIb(c[b+9856>>2]|0,2)|0;if((zc|0)==0){Bc=b+12480|0;c[Bc>>2]=0;vRa(b);i=e;return}vc=c[c[zc+4>>2]>>2]|0;if((vc|0)==2){Cc=4}else if((vc|0)==0){Cc=8}else if((vc|0)==5){Cc=35}else if((vc|0)==1){Cc=3}else{Bc=b+12480|0;c[Bc>>2]=0;vRa(b);i=e;return}Y2(l);l=c[m>>2]|0;vc=c[n>>2]|0;if((vc|0)>16){Dc=vc-16|0;Ec=l<<16}else{zc=je(l<<vc|0)|0;l=c[hb>>2]|0;y=zc;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Dc=vc+16|0;Ec=0}c[m>>2]=Ec;c[n>>2]=Dc;if((Dc|0)>16){Fc=Dc-16|0}else{vc=je(434>>>((16-Dc|0)>>>0)|Ec<<Dc|0)|0;Ec=c[hb>>2]|0;y=vc;a[Ec]=y;y=y>>8;a[Ec+1|0]=y;y=y>>8;a[Ec+2|0]=y;y=y>>8;a[Ec+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Fc=Dc+16|0}c[m>>2]=434;c[n>>2]=Fc;if((Fc|0)>8){Gc=Fc-8|0;Hc=111178}else{Dc=je(74>>>((8-Fc|0)>>>0)|434<<Fc|0)|0;Ec=c[hb>>2]|0;y=Dc;a[Ec]=y;y=y>>8;a[Ec+1|0]=y;y=y>>8;a[Ec+2|0]=y;y=y>>8;a[Ec+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Gc=Fc+24|0;Hc=74}c[m>>2]=Hc;c[n>>2]=Gc;if((Gc|0)>8){Ic=Gc-8|0;Jc=Hc<<8|80}else{Fc=je(80>>>((8-Gc|0)>>>0)|Hc<<Gc|0)|0;Hc=c[hb>>2]|0;y=Fc;a[Hc]=y;y=y>>8;a[Hc+1|0]=y;y=y>>8;a[Hc+2|0]=y;y=y>>8;a[Hc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Ic=Gc+24|0;Jc=80}c[m>>2]=Jc;c[n>>2]=Ic;if((Ic|0)>8){Kc=Ic-8|0;Lc=Jc<<8|51}else{Gc=je(51>>>((8-Ic|0)>>>0)|Jc<<Ic|0)|0;Jc=c[hb>>2]|0;y=Gc;a[Jc]=y;y=y>>8;a[Jc+1|0]=y;y=y>>8;a[Jc+2|0]=y;y=y>>8;a[Jc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Kc=Ic+24|0;Lc=51}c[m>>2]=Lc;c[n>>2]=Kc;if((Kc|0)>8){Mc=Kc-8|0;Nc=Lc<<8|68}else{Ic=je(68>>>((8-Kc|0)>>>0)|Lc<<Kc|0)|0;Lc=c[hb>>2]|0;y=Ic;a[Lc]=y;y=y>>8;a[Lc+1|0]=y;y=y>>8;a[Lc+2|0]=y;y=y>>8;a[Lc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Mc=Kc+24|0;Nc=68}c[m>>2]=Nc;c[n>>2]=Mc;if((Mc|0)>8){Oc=Mc-8|0;Pc=Nc<<8|3}else{Kc=je(3>>>((8-Mc|0)>>>0)|Nc<<Mc|0)|0;Nc=c[hb>>2]|0;y=Kc;a[Nc]=y;y=y>>8;a[Nc+1|0]=y;y=y>>8;a[Nc+2|0]=y;y=y>>8;a[Nc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Oc=Mc+24|0;Pc=3}c[m>>2]=Pc;c[n>>2]=Oc;if((Oc|0)>1){Qc=Oc-1|0;Rc=Pc<<1|1}else{Mc=je(1>>>((1-Oc|0)>>>0)|Pc<<Oc|0)|0;Pc=c[hb>>2]|0;y=Mc;a[Pc]=y;y=y>>8;a[Pc+1|0]=y;y=y>>8;a[Pc+2|0]=y;y=y>>8;a[Pc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Qc=Oc+31|0;Rc=1}c[m>>2]=Rc;c[n>>2]=Qc;if((Qc|0)>7){Sc=Qc-7|0;Tc=Rc<<7|Cc}else{Oc=je(Cc>>>((7-Qc|0)>>>0)|Rc<<Qc|0)|0;Rc=c[hb>>2]|0;y=Oc;a[Rc]=y;y=y>>8;a[Rc+1|0]=y;y=y>>8;a[Rc+2|0]=y;y=y>>8;a[Rc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Sc=Qc+25|0;Tc=Cc}c[m>>2]=Tc;c[n>>2]=Sc;if((Sc|0)>8){Uc=Sc-8|0;Vc=Tc<<8|4}else{Cc=je(4>>>((8-Sc|0)>>>0)|Tc<<Sc|0)|0;Tc=c[hb>>2]|0;y=Cc;a[Tc]=y;y=y>>8;a[Tc+1|0]=y;y=y>>8;a[Tc+2|0]=y;y=y>>8;a[Tc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Uc=Sc+24|0;Vc=4}c[m>>2]=Vc;c[n>>2]=Uc;if((Uc|0)>8){Wc=Uc-8|0;Xc=Vc<<8|255}else{Sc=je(255>>>((8-Uc|0)>>>0)|Vc<<Uc|0)|0;Vc=c[hb>>2]|0;y=Sc;a[Vc]=y;y=y>>8;a[Vc+1|0]=y;y=y>>8;a[Vc+2|0]=y;y=y>>8;a[Vc+3|0]=y;c[hb>>2]=(c[hb>>2]|0)+4;Wc=Uc+24|0;Xc=255}c[m>>2]=Xc;c[n>>2]=Wc;Bc=b+12480|0;c[Bc>>2]=0;vRa(b);i=e;return}function xRa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0;k=i;l=c[f+12476>>2]|0;m=c[f+12480>>2]|0;n=(l|0)==(c[f+13704>>2]|0);if((c[f+14212>>2]|0)==1){if(n){o=(m|0)==(c[f+13708>>2]|0)}else{o=0}p=(c[f+180>>2]>>31)+32&-32;q=(c[f+184>>2]|0)>-1?p|16:p;p=(c[f+188>>2]|0)>-1?q|8:q;q=(c[f+192>>2]|0)>-1?p|4:p;p=(c[f+196>>2]|0)>-1?q|2:q;do{if((c[f+200>>2]|0)>-1){r=p|1;s=0}else{q=(p|0)==0;if(o|q^1){r=p;s=q;break}if((c[f+11740>>2]|0)!=0){r=p;s=q;break}if((l|0)==((c[f+116>>2]|0)-1|0)){if((m|0)==((c[f+812>>2]|0)-1|0)){r=p;s=q;break}if((c[f+48>>2]|0)!=1){r=p;s=q;break}}t=c[f+9992>>2]|0;u=(t|0)==2;if(u){if((j|h|0)!=0){r=p;s=q;break}}else{if((t|0)!=3){r=p;s=q;break}t=c[f+11736>>2]|0;if((t|0)!=(c[f+14144>>2]|0)){r=p;s=q;break}if((t&1|0)==0){v=0}else{v=(c[f+11748>>2]|0)-(c[f+11828>>2]|0)|(c[f+11744>>2]|0)-(c[f+11824>>2]|0)}if((t&2|0)==0){w=0}else{w=(c[f+11780>>2]|0)-(c[f+11844>>2]|0)|(c[f+11776>>2]|0)-(c[f+11840>>2]|0)}if((w|v|0)!=0){r=p;s=q;break}}q=f+12484|0;c[q>>2]=(c[q>>2]|0)+1;q=f+9960|0;c[q>>2]=(c[q>>2]|0)-(c[f+9984>>2]|0);q=f+13692|0;c[q>>2]=(c[q>>2]|0)+1;q=f+13696|0;c[q>>2]=(c[q>>2]|0)+1;q=f+13700|0;c[q>>2]=(c[q>>2]|0)+1;if(!u){i=k;return}mrc(f+11824|0,0,16)|0;i=k;return}}while(0);p=f+12484|0;v=c[p>>2]|0;if(o){if((v|0)!=0){KIb(0,0,2508440,(x=i,i=i+24|0,c[x>>2]=2272480,c[x+8>>2]=2450048,c[x+16>>2]=724,x)|0);i=x;Hd()}o=f+784|0;if((l|0)>32){w=f+788|0;u=f+796|0;q=l;t=c[o>>2]|0;z=c[w>>2]|0;while(1){if((z|0)>11){A=z-11|0;B=t<<11|8}else{C=je(8>>>((11-z|0)>>>0)|t<<z|0)|0;D=c[u>>2]|0;y=C;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;A=z+21|0;B=8}c[o>>2]=B;c[w>>2]=A;D=q-33|0;if((D|0)>32){q=D;t=B;z=A}else{break}}E=((l-33|0)>>>0)%33|0;F=B;G=A}else{E=l;F=c[o>>2]|0;G=c[f+788>>2]|0}A=d[1347801+(E<<1)|0]|0;B=d[1347800+(E<<1)|0]|0;if((G|0)>(A|0)){H=G;I=F<<A|B}else{E=je(B>>>((A-G|0)>>>0)|F<<G|0)|0;F=f+796|0;z=c[F>>2]|0;y=E;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[F>>2]=(c[F>>2]|0)+4;H=G+32|0;I=B}B=H-A|0;c[o>>2]=I;c[f+788>>2]=B;J=I;K=B}else{B=f+784|0;if((v|0)>32){I=f+788|0;o=f+796|0;A=v;H=c[B>>2]|0;G=c[I>>2]|0;while(1){if((G|0)>11){L=G-11|0;M=H<<11|8}else{F=je(8>>>((11-G|0)>>>0)|H<<G|0)|0;z=c[o>>2]|0;y=F;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;L=G+21|0;M=8}c[B>>2]=M;c[I>>2]=L;z=A-33|0;if((z|0)>32){A=z;H=M;G=L}else{break}}N=((v-33|0)>>>0)%33|0;O=M;P=L}else{N=v;O=c[B>>2]|0;P=c[f+788>>2]|0}v=d[1347801+(N<<1)|0]|0;L=d[1347800+(N<<1)|0]|0;if((P|0)>(v|0)){Q=P;R=O<<v|L}else{N=je(L>>>((v-P|0)>>>0)|O<<P|0)|0;O=f+796|0;M=c[O>>2]|0;y=N;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[O>>2]=(c[O>>2]|0)+4;Q=P+32|0;R=L}L=Q-v|0;c[B>>2]=R;c[f+788>>2]=L;J=R;K=L}L=c[f+9992>>2]|0;do{if((L|0)==1){R=f+9984|0;B=f+784|0;v=f+788|0;do{if((c[R>>2]|0)==0|s){if((K|0)>1){S=K-1|0;T=J<<1|1}else{Q=je(1>>>((1-K|0)>>>0)|J<<K|0)|0;P=f+796|0;O=c[P>>2]|0;y=Q;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[P>>2]=(c[P>>2]|0)+4;S=K+31|0;T=1}c[B>>2]=T;c[v>>2]=S;if((c[f+14180>>2]|0)==0){P=c[f+14236>>2]|0;if((S|0)>1){U=S-1|0;V=P|T<<1}else{O=je(P>>>((1-S|0)>>>0)|T<<S|0)|0;Q=f+796|0;M=c[Q>>2]|0;y=O;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;U=S+31|0;V=P}c[B>>2]=V;c[v>>2]=U;W=U}else{W=S}P=f+9960|0;c[P>>2]=(c[P>>2]|0)-(c[R>>2]|0);X=W}else{if((K|0)>2){Y=K-2|0;Z=J<<2|1}else{P=je(1>>>((2-K|0)>>>0)|J<<K|0)|0;Q=f+796|0;M=c[Q>>2]|0;y=P;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;Y=K+30|0;Z=1}c[B>>2]=Z;c[v>>2]=Y;if((c[f+14180>>2]|0)==0){Q=c[f+14236>>2]|0;if((Y|0)>1){_=Y-1|0;$=Q|Z<<1}else{M=je(Q>>>((1-Y|0)>>>0)|Z<<Y|0)|0;P=f+796|0;O=c[P>>2]|0;y=M;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[P>>2]=(c[P>>2]|0)+4;_=Y+31|0;$=Q}c[B>>2]=$;c[v>>2]=_;aa=$;ba=_}else{aa=Z;ba=Y}Q=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((ba|0)>5){ca=ba-5|0;da=Q|aa<<5}else{P=je(Q>>>((5-ba|0)>>>0)|aa<<ba|0)|0;O=f+796|0;M=c[O>>2]|0;y=P;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[O>>2]=(c[O>>2]|0)+4;ca=ba+27|0;da=Q}c[B>>2]=da;c[v>>2]=ca;X=ca;break}else{O=d[1062808+Q|0]|0;if((ba|0)>5){ea=ba-5|0;fa=O|aa<<5}else{Q=je(O>>>((5-ba|0)>>>0)|aa<<ba|0)|0;M=f+796|0;P=c[M>>2]|0;y=Q;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[M>>2]=(c[M>>2]|0)+4;ea=ba+27|0;fa=O}c[B>>2]=fa;c[v>>2]=ea;X=ea;break}}}while(0);B=f+796|0;R=((c[B>>2]|0)-(c[f+792>>2]|0)<<3)+(32-X)|0;O=f+13700|0;M=c[O>>2]|0;c[O>>2]=R;O=f+13696|0;c[O>>2]=(c[O>>2]|0)-M+R;R=f+13680|0;c[R>>2]=(c[R>>2]|0)+1;ga=X;ha=f+12488|0;ia=v;ja=B;ka=r}else{B=f+12488|0;if((c[B>>2]|0)!=0){R=f+9984|0;M=f+784|0;O=f+788|0;do{if((c[R>>2]|0)==0|s){if((K|0)>5){la=K-5|0;ma=J<<5|3}else{P=je(3>>>((5-K|0)>>>0)|J<<K|0)|0;Q=f+796|0;N=c[Q>>2]|0;y=P;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;la=K+27|0;ma=3}c[M>>2]=ma;c[O>>2]=la;if((c[f+14180>>2]|0)==0){Q=c[f+14236>>2]|0;if((la|0)>1){na=la-1|0;oa=Q|ma<<1}else{N=je(Q>>>((1-la|0)>>>0)|ma<<la|0)|0;P=f+796|0;G=c[P>>2]|0;y=N;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[P>>2]=(c[P>>2]|0)+4;na=la+31|0;oa=Q}c[M>>2]=oa;c[O>>2]=na;pa=na}else{pa=la}Q=f+9960|0;c[Q>>2]=(c[Q>>2]|0)-(c[R>>2]|0);qa=pa}else{if((K|0)>6){ra=K-6|0;sa=J<<6|1}else{Q=je(1>>>((6-K|0)>>>0)|J<<K|0)|0;P=f+796|0;G=c[P>>2]|0;y=Q;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[P>>2]=(c[P>>2]|0)+4;ra=K+26|0;sa=1}c[M>>2]=sa;c[O>>2]=ra;if((c[f+14180>>2]|0)==0){P=c[f+14236>>2]|0;if((ra|0)>1){ta=ra-1|0;ua=P|sa<<1}else{G=je(P>>>((1-ra|0)>>>0)|sa<<ra|0)|0;Q=f+796|0;N=c[Q>>2]|0;y=G;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;ta=ra+31|0;ua=P}c[M>>2]=ua;c[O>>2]=ta;va=ua;wa=ta}else{va=sa;wa=ra}P=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((wa|0)>5){xa=wa-5|0;ya=P|va<<5}else{Q=je(P>>>((5-wa|0)>>>0)|va<<wa|0)|0;N=f+796|0;G=c[N>>2]|0;y=Q;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;xa=wa+27|0;ya=P}c[M>>2]=ya;c[O>>2]=xa;qa=xa;break}else{N=d[1062808+P|0]|0;if((wa|0)>5){za=wa-5|0;Aa=N|va<<5}else{P=je(N>>>((5-wa|0)>>>0)|va<<wa|0)|0;G=f+796|0;Q=c[G>>2]|0;y=P;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;za=wa+27|0;Aa=N}c[M>>2]=Aa;c[O>>2]=za;qa=za;break}}}while(0);M=f+796|0;R=((c[M>>2]|0)-(c[f+792>>2]|0)<<3)+(32-qa)|0;v=f+13700|0;N=c[v>>2]|0;c[v>>2]=R;v=f+13696|0;c[v>>2]=(c[v>>2]|0)-N+R;R=f+13680|0;c[R>>2]=(c[R>>2]|0)+1;mrc(f+11824|0,0,32)|0;ga=qa;ha=B;ia=O;ja=M;ka=r;break}M=(c[f+11740>>2]|0)==0;R=(r|0)!=0;if((L|0)==2){if(M){do{if(R){N=(c[f+9984>>2]|0)!=0;v=f+784|0;G=f+788|0;if((j|h|0)==0){do{if(N){if((K|0)>5){Ba=K-5|0;Ca=J<<5|1}else{Q=je(1>>>((5-K|0)>>>0)|J<<K|0)|0;P=f+796|0;H=c[P>>2]|0;y=Q;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[P>>2]=(c[P>>2]|0)+4;Ba=K+27|0;Ca=1}c[v>>2]=Ca;c[G>>2]=Ba;if((c[f+14180>>2]|0)==0){P=c[f+14236>>2]|0;if((Ba|0)>1){Da=Ba-1|0;Ea=P|Ca<<1}else{H=je(P>>>((1-Ba|0)>>>0)|Ca<<Ba|0)|0;Q=f+796|0;A=c[Q>>2]|0;y=H;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;Da=Ba+31|0;Ea=P}c[v>>2]=Ea;c[G>>2]=Da;Fa=Ea;Ga=Da}else{Fa=Ca;Ga=Ba}P=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Ga|0)>5){Ha=Ga-5|0;Ia=P|Fa<<5}else{Q=je(P>>>((5-Ga|0)>>>0)|Fa<<Ga|0)|0;A=f+796|0;H=c[A>>2]|0;y=Q;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Ha=Ga+27|0;Ia=P}c[v>>2]=Ia;c[G>>2]=Ha;Ja=Ha;break}else{A=d[1062808+P|0]|0;if((Ga|0)>5){Ka=Ga-5|0;La=A|Fa<<5}else{P=je(A>>>((5-Ga|0)>>>0)|Fa<<Ga|0)|0;H=f+796|0;Q=c[H>>2]|0;y=P;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;Ka=Ga+27|0;La=A}c[v>>2]=La;c[G>>2]=Ka;Ja=Ka;break}}else{if((K|0)>2){Ma=K-2|0;Na=J<<2|1}else{A=je(1>>>((2-K|0)>>>0)|J<<K|0)|0;H=f+796|0;Q=c[H>>2]|0;y=A;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;Ma=K+30|0;Na=1}c[v>>2]=Na;c[G>>2]=Ma;if((c[f+14180>>2]|0)!=0){Ja=Ma;break}H=c[f+14236>>2]|0;if((Ma|0)>1){Oa=Ma-1|0;Pa=H|Na<<1}else{Q=je(H>>>((1-Ma|0)>>>0)|Na<<Ma|0)|0;A=f+796|0;P=c[A>>2]|0;y=Q;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Oa=Ma+31|0;Pa=H}c[v>>2]=Pa;c[G>>2]=Oa;Ja=Oa}}while(0);H=c[f+796>>2]|0;A=(H-(c[f+792>>2]|0)<<3)+(32-Ja)|0;P=f+13700|0;Q=c[P>>2]|0;c[P>>2]=A;P=f+13696|0;c[P>>2]=(c[P>>2]|0)-Q+A;Qa=Ja;Ra=H;Sa=f+11824|0;Ta=f+11828|0;break}do{if(N){if((K|0)>5){Ua=K-5|0;Va=J<<5|2}else{H=je(2>>>((5-K|0)>>>0)|J<<K|0)|0;A=f+796|0;Q=c[A>>2]|0;y=H;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Ua=K+27|0;Va=2}c[v>>2]=Va;c[G>>2]=Ua;if((c[f+14180>>2]|0)==0){if((Ua|0)>2){Wa=Ua-2|0;Xa=Va<<2|2}else{A=je(2>>>((2-Ua|0)>>>0)|Va<<Ua|0)|0;Q=f+796|0;H=c[Q>>2]|0;y=A;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;Wa=Ua+30|0;Xa=2}c[v>>2]=Xa;c[G>>2]=Wa;Q=c[f+14236>>2]|0;if((Wa|0)>1){Ya=Wa-1|0;Za=Q|Xa<<1}else{H=je(Q>>>((1-Wa|0)>>>0)|Xa<<Wa|0)|0;A=f+796|0;P=c[A>>2]|0;y=H;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Ya=Wa+31|0;Za=Q}c[v>>2]=Za;c[G>>2]=Ya;_a=Za;$a=Ya}else{_a=Va;$a=Ua}Q=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if(($a|0)>5){ab=$a-5|0;bb=Q|_a<<5}else{A=je(Q>>>((5-$a|0)>>>0)|_a<<$a|0)|0;P=f+796|0;H=c[P>>2]|0;y=A;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[P>>2]=(c[P>>2]|0)+4;ab=$a+27|0;bb=Q}c[v>>2]=bb;c[G>>2]=ab;cb=ab;break}else{P=d[1062808+Q|0]|0;if(($a|0)>5){db=$a-5|0;eb=P|_a<<5}else{Q=je(P>>>((5-$a|0)>>>0)|_a<<$a|0)|0;H=f+796|0;A=c[H>>2]|0;y=Q;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;db=$a+27|0;eb=P}c[v>>2]=eb;c[G>>2]=db;cb=db;break}}else{if((K|0)>1){fb=K-1|0;gb=J<<1|1}else{P=je(1>>>((1-K|0)>>>0)|J<<K|0)|0;H=f+796|0;A=c[H>>2]|0;y=P;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;fb=K+31|0;gb=1}c[v>>2]=gb;c[G>>2]=fb;if((c[f+14180>>2]|0)!=0){cb=fb;break}if((fb|0)>2){hb=fb-2|0;ib=gb<<2|2}else{H=je(2>>>((2-fb|0)>>>0)|gb<<fb|0)|0;A=f+796|0;P=c[A>>2]|0;y=H;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;hb=fb+30|0;ib=2}c[v>>2]=ib;c[G>>2]=hb;A=c[f+14236>>2]|0;if((hb|0)>1){jb=hb-1|0;kb=A|ib<<1}else{P=je(A>>>((1-hb|0)>>>0)|ib<<hb|0)|0;H=f+796|0;Q=c[H>>2]|0;y=P;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;jb=hb+31|0;kb=A}c[v>>2]=kb;c[G>>2]=jb;cb=jb}}while(0);v=f+792|0;N=f+796|0;A=((c[N>>2]|0)-(c[v>>2]|0)<<3)+(32-cb)|0;H=f+13700|0;Q=c[H>>2]|0;c[H>>2]=A;P=f+13696|0;c[P>>2]=(c[P>>2]|0)-Q+A;A=f+11824|0;Q=f+11556|0;BRa(f,h-(c[A>>2]|0)|0,c[Q>>2]|0);P=f+11828|0;BRa(f,j-(c[P>>2]|0)|0,c[Q>>2]|0);Q=c[G>>2]|0;I=c[N>>2]|0;N=(I-(c[v>>2]|0)<<3)+(32-Q)|0;v=c[H>>2]|0;c[H>>2]=N;H=f+13664|0;c[H>>2]=(c[H>>2]|0)-v+N;Qa=Q;Ra=I;Sa=A;Ta=P}else{P=f+784|0;A=f+788|0;if((K|0)>3){lb=K-3|0;mb=J<<3|1}else{I=je(1>>>((3-K|0)>>>0)|J<<K|0)|0;Q=f+796|0;N=c[Q>>2]|0;y=I;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;lb=K+29|0;mb=1}c[P>>2]=mb;c[A>>2]=lb;if((c[f+14180>>2]|0)==0){if((lb|0)>2){nb=lb-2|0;ob=mb<<2|2}else{Q=je(2>>>((2-lb|0)>>>0)|mb<<lb|0)|0;N=f+796|0;I=c[N>>2]|0;y=Q;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;nb=lb+30|0;ob=2}c[P>>2]=ob;c[A>>2]=nb;pb=nb}else{pb=lb}P=f+792|0;N=f+796|0;I=((c[N>>2]|0)-(c[P>>2]|0)<<3)+(32-pb)|0;Q=f+13700|0;v=c[Q>>2]|0;c[Q>>2]=I;H=f+13696|0;c[H>>2]=(c[H>>2]|0)-v+I;I=f+11824|0;v=f+11556|0;BRa(f,h-(c[I>>2]|0)|0,c[v>>2]|0);H=f+11828|0;BRa(f,j-(c[H>>2]|0)|0,c[v>>2]|0);v=f+9960|0;c[v>>2]=(c[v>>2]|0)-(c[f+9984>>2]|0);v=c[A>>2]|0;A=c[N>>2]|0;N=(A-(c[P>>2]|0)<<3)+(32-v)|0;P=c[Q>>2]|0;c[Q>>2]=N;Q=f+13664|0;c[Q>>2]=(c[Q>>2]|0)-P+N;Qa=v;Ra=A;Sa=I;Ta=H}}while(0);c[Sa>>2]=h;c[f+11832>>2]=h;c[Ta>>2]=j;c[f+11836>>2]=j;qb=Qa;rb=Ra}else{do{if(R){O=f+784|0;H=f+788|0;if((c[f+9984>>2]|0)==0){if((K|0)>1){sb=K-1|0;tb=J<<1|1}else{I=je(1>>>((1-K|0)>>>0)|J<<K|0)|0;A=f+796|0;v=c[A>>2]|0;y=I;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;sb=K+31|0;tb=1}c[O>>2]=tb;c[H>>2]=sb;if((c[f+14180>>2]|0)!=0){ub=sb;vb=tb;break}if((sb|0)>2){wb=sb-2|0;xb=tb<<2|1}else{A=je(1>>>((2-sb|0)>>>0)|tb<<sb|0)|0;v=f+796|0;I=c[v>>2]|0;y=A;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;wb=sb+30|0;xb=1}c[O>>2]=xb;c[H>>2]=wb;v=c[f+14236>>2]|0;if((wb|0)>1){yb=wb-1|0;zb=v|xb<<1}else{I=je(v>>>((1-wb|0)>>>0)|xb<<wb|0)|0;A=f+796|0;N=c[A>>2]|0;y=I;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;yb=wb+31|0;zb=v}c[O>>2]=zb;c[H>>2]=yb;ub=yb;vb=zb;break}if((K|0)>5){Ab=K-5|0;Bb=J<<5|2}else{v=je(2>>>((5-K|0)>>>0)|J<<K|0)|0;A=f+796|0;N=c[A>>2]|0;y=v;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Ab=K+27|0;Bb=2}c[O>>2]=Bb;c[H>>2]=Ab;if((c[f+14180>>2]|0)==0){if((Ab|0)>2){Cb=Ab-2|0;Db=Bb<<2|1}else{A=je(1>>>((2-Ab|0)>>>0)|Bb<<Ab|0)|0;N=f+796|0;v=c[N>>2]|0;y=A;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;Cb=Ab+30|0;Db=1}c[O>>2]=Db;c[H>>2]=Cb;N=c[f+14236>>2]|0;if((Cb|0)>1){Eb=Cb-1|0;Fb=N|Db<<1}else{v=je(N>>>((1-Cb|0)>>>0)|Db<<Cb|0)|0;A=f+796|0;I=c[A>>2]|0;y=v;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Eb=Cb+31|0;Fb=N}c[O>>2]=Fb;c[H>>2]=Eb;Gb=Fb;Hb=Eb}else{Gb=Bb;Hb=Ab}N=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Hb|0)>5){Ib=Hb-5|0;Jb=N|Gb<<5}else{A=je(N>>>((5-Hb|0)>>>0)|Gb<<Hb|0)|0;I=f+796|0;v=c[I>>2]|0;y=A;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Ib=Hb+27|0;Jb=N}c[O>>2]=Jb;c[H>>2]=Ib;ub=Ib;vb=Jb;break}else{I=d[1062808+N|0]|0;if((Hb|0)>5){Kb=Hb-5|0;Lb=I|Gb<<5}else{N=je(I>>>((5-Hb|0)>>>0)|Gb<<Hb|0)|0;v=f+796|0;A=c[v>>2]|0;y=N;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;Kb=Hb+27|0;Lb=I}c[O>>2]=Lb;c[H>>2]=Kb;ub=Kb;vb=Lb;break}}else{H=f+784|0;O=f+788|0;if((K|0)>3){Mb=K-3|0;Nb=J<<3|1}else{I=je(1>>>((3-K|0)>>>0)|J<<K|0)|0;v=f+796|0;A=c[v>>2]|0;y=I;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;Mb=K+29|0;Nb=1}c[H>>2]=Nb;c[O>>2]=Mb;if((Mb|0)>2){Ob=Mb-2|0;Pb=Nb<<2|1}else{v=je(1>>>((2-Mb|0)>>>0)|Nb<<Mb|0)|0;A=f+796|0;I=c[A>>2]|0;y=v;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Ob=Mb+30|0;Pb=1}c[H>>2]=Pb;c[O>>2]=Ob;O=f+9960|0;c[O>>2]=(c[O>>2]|0)-(c[f+9984>>2]|0);ub=Ob;vb=Pb}}while(0);O=f+788|0;H=f+792|0;A=f+796|0;I=c[A>>2]|0;v=(I-(c[H>>2]|0)<<3)+(32-ub)|0;N=f+13700|0;P=c[N>>2]|0;c[N>>2]=v;Q=f+13696|0;c[Q>>2]=(c[Q>>2]|0)-P+v;v=f+784|0;P=f+11556|0;Q=c[f+11808>>2]|0;if((ub|0)>1){Qb=ub-1|0;Rb=Q|vb<<1}else{o=I;y=je(Q>>>((1-ub|0)>>>0)|vb<<ub|0)|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Qb=ub+31|0;Rb=Q}c[v>>2]=Rb;c[O>>2]=Qb;Q=f+11744|0;o=f+11824|0;BRa(f,(c[Q>>2]|0)-(c[o>>2]|0)|0,c[P>>2]|0);I=f+11748|0;z=f+11828|0;BRa(f,(c[I>>2]|0)-(c[z>>2]>>1)|0,c[P>>2]|0);c[o>>2]=c[Q>>2];c[z>>2]=c[I>>2]<<1;I=c[f+11812>>2]|0;z=c[v>>2]|0;Q=c[O>>2]|0;if((Q|0)>1){Sb=Q-1|0;Tb=z<<1|I}else{o=je(I>>>((1-Q|0)>>>0)|z<<Q|0)|0;z=c[A>>2]|0;y=o;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Sb=Q+31|0;Tb=I}c[v>>2]=Tb;c[O>>2]=Sb;v=f+11752|0;I=f+11832|0;BRa(f,(c[v>>2]|0)-(c[I>>2]|0)|0,c[P>>2]|0);Q=f+11756|0;z=f+11836|0;BRa(f,(c[Q>>2]|0)-(c[z>>2]>>1)|0,c[P>>2]|0);c[I>>2]=c[v>>2];c[z>>2]=c[Q>>2]<<1;Q=c[O>>2]|0;O=c[A>>2]|0;A=(O-(c[H>>2]|0)<<3)+(32-Q)|0;H=c[N>>2]|0;c[N>>2]=A;N=f+13664|0;c[N>>2]=(c[N>>2]|0)-H+A;qb=Q;rb=O}do{if(R){O=f+784|0;if((c[f+14220>>2]|0)!=0){Q=d[1347633+(r<<1)|0]|0;A=d[1347632+(r<<1)|0]|0;H=O|0;N=c[H>>2]|0;z=f+788|0;if((qb|0)>(Q|0)){Ub=qb;Vb=N<<Q|A}else{v=f+796|0;I=rb;y=je(A>>>((Q-qb|0)>>>0)|N<<qb|0)|0;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;Ub=qb+32|0;Vb=A}A=Ub-Q|0;c[H>>2]=Vb;c[z>>2]=A;Wb=A;Xb=z;Yb=r;break}z=r>>2;A=d[1347633+(z<<1)|0]|0;H=d[1347632+(z<<1)|0]|0;z=O|0;O=c[z>>2]|0;Q=f+788|0;if((qb|0)>(A|0)){Zb=qb;_b=O<<A|H;$b=rb}else{v=f+796|0;I=rb;y=je(H>>>((A-qb|0)>>>0)|O<<qb|0)|0;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;I=(c[v>>2]|0)+4|0;c[v>>2]=I;Zb=qb+32|0;_b=H;$b=I}I=Zb-A|0;c[z>>2]=_b;c[Q>>2]=I;A=r&3;if((I|0)>2){ac=I-2|0;bc=_b<<2|A}else{H=f+796|0;v=$b;y=je(A>>>((2-I|0)>>>0)|_b<<I|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;ac=I+30|0;bc=A}c[z>>2]=bc;c[Q>>2]=ac;Wb=ac;Xb=Q;Yb=r}else{Wb=qb;Xb=f+788|0;Yb=0}}while(0);Q=f+13684|0;c[Q>>2]=(c[Q>>2]|0)+1;ga=Wb;ha=B;ia=Xb;ja=f+796|0;ka=Yb;break}do{if(M){do{if(R){Q=c[f+11736>>2]|0;if((c[f+9984>>2]|0)==0){z=5-Q|0;A=f+784|0;I=f+788|0;if((K|0)>(z|0)){cc=K;dc=J<<z|3}else{H=je(3>>>((z-K|0)>>>0)|J<<K|0)|0;v=f+796|0;O=c[v>>2]|0;y=H;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;cc=K+32|0;dc=3}v=cc-z|0;c[A>>2]=dc;c[I>>2]=v;if((c[f+14180>>2]|0)!=0){ec=v;break}if((v|0)>2){fc=v-2|0;gc=dc<<2|2}else{z=je(2>>>((2-v|0)>>>0)|dc<<v|0)|0;O=f+796|0;H=c[O>>2]|0;y=z;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[O>>2]=(c[O>>2]|0)+4;fc=v+30|0;gc=2}c[A>>2]=gc;c[I>>2]=fc;v=c[f+14236>>2]|0;if((fc|0)>1){hc=fc-1|0;ic=v|gc<<1}else{O=je(v>>>((1-fc|0)>>>0)|gc<<fc|0)|0;H=f+796|0;z=c[H>>2]|0;y=O;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;hc=fc+31|0;ic=v}c[A>>2]=ic;c[I>>2]=hc;ec=hc;break}do{if((Q|0)==1){I=f+784|0;A=f+788|0;if((K|0)>6){jc=K-6|0;kc=J<<6|3}else{v=je(3>>>((6-K|0)>>>0)|J<<K|0)|0;H=f+796|0;z=c[H>>2]|0;y=v;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;jc=K+26|0;kc=3}c[I>>2]=kc;c[A>>2]=jc;if((c[f+14180>>2]|0)!=0){lc=kc;mc=jc;break}if((jc|0)>2){nc=jc-2|0;oc=kc<<2|2}else{H=je(2>>>((2-jc|0)>>>0)|kc<<jc|0)|0;z=f+796|0;v=c[z>>2]|0;y=H;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;nc=jc+30|0;oc=2}c[I>>2]=oc;c[A>>2]=nc;z=c[f+14236>>2]|0;if((nc|0)>1){pc=nc-1|0;qc=z|oc<<1}else{v=je(z>>>((1-nc|0)>>>0)|oc<<nc|0)|0;H=f+796|0;O=c[H>>2]|0;y=v;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;pc=nc+31|0;qc=z}c[I>>2]=qc;c[A>>2]=pc;lc=qc;mc=pc}else{A=8-Q|0;I=f+784|0;z=f+788|0;if((K|0)>(A|0)){rc=K;sc=J<<A|2}else{H=je(2>>>((A-K|0)>>>0)|J<<K|0)|0;O=f+796|0;v=c[O>>2]|0;y=H;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[O>>2]=(c[O>>2]|0)+4;rc=K+32|0;sc=2}O=rc-A|0;c[I>>2]=sc;c[z>>2]=O;if((c[f+14180>>2]|0)!=0){lc=sc;mc=O;break}if((O|0)>2){tc=O-2|0;uc=sc<<2|2}else{A=je(2>>>((2-O|0)>>>0)|sc<<O|0)|0;v=f+796|0;H=c[v>>2]|0;y=A;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;tc=O+30|0;uc=2}c[I>>2]=uc;c[z>>2]=tc;O=c[f+14236>>2]|0;if((tc|0)>1){vc=tc-1|0;wc=O|uc<<1}else{v=je(O>>>((1-tc|0)>>>0)|uc<<tc|0)|0;H=f+796|0;A=c[H>>2]|0;y=v;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;vc=tc+31|0;wc=O}c[I>>2]=wc;c[z>>2]=vc;lc=wc;mc=vc}}while(0);Q=f+784|0;z=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((mc|0)>5){xc=mc-5|0;yc=z|lc<<5}else{I=je(z>>>((5-mc|0)>>>0)|lc<<mc|0)|0;O=f+796|0;H=c[O>>2]|0;y=I;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[O>>2]=(c[O>>2]|0)+4;xc=mc+27|0;yc=z}c[Q>>2]=yc;c[f+788>>2]=xc;ec=xc;break}else{O=d[1062808+z|0]|0;if((mc|0)>5){zc=mc-5|0;Ac=O|lc<<5}else{z=je(O>>>((5-mc|0)>>>0)|lc<<mc|0)|0;H=f+796|0;I=c[H>>2]|0;y=z;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;zc=mc+27|0;Ac=O}c[Q>>2]=Ac;c[f+788>>2]=zc;ec=zc;break}}else{Q=5-(c[f+11736>>2]|0)|0;O=f+784|0;H=f+788|0;if((K|0)>(Q|0)){Bc=K;Cc=J<<Q|2}else{I=je(2>>>((Q-K|0)>>>0)|J<<K|0)|0;z=f+796|0;A=c[z>>2]|0;y=I;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;Bc=K+32|0;Cc=2}z=Bc-Q|0;c[O>>2]=Cc;c[H>>2]=z;if((c[f+14180>>2]|0)==0){if((z|0)>2){Dc=z-2|0;Ec=Cc<<2|2}else{Q=je(2>>>((2-z|0)>>>0)|Cc<<z|0)|0;A=f+796|0;I=c[A>>2]|0;y=Q;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Dc=z+30|0;Ec=2}c[O>>2]=Ec;c[H>>2]=Dc;Fc=Dc}else{Fc=z}z=f+9960|0;c[z>>2]=(c[z>>2]|0)-(c[f+9984>>2]|0);ec=Fc}}while(0);G=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-ec)|0;z=f+13700|0;H=c[z>>2]|0;c[z>>2]=G;z=f+13696|0;c[z>>2]=(c[z>>2]|0)-H+G;G=f+11736|0;H=c[G>>2]|0;if((H&1|0)==0){Gc=H}else{H=f+11744|0;z=f+11824|0;O=f+11556|0;BRa(f,(c[H>>2]|0)-(c[z>>2]|0)|0,c[O>>2]|0);A=f+11748|0;I=f+11828|0;BRa(f,(c[A>>2]|0)-(c[I>>2]|0)|0,c[O>>2]|0);O=c[H>>2]|0;c[f+11832>>2]=O;c[z>>2]=O;O=c[A>>2]|0;c[f+11836>>2]=O;c[I>>2]=O;O=f+13684|0;c[O>>2]=(c[O>>2]|0)+1;Gc=c[G>>2]|0}if((Gc&2|0)==0){break}G=f+11776|0;O=f+11840|0;I=f+11560|0;BRa(f,(c[G>>2]|0)-(c[O>>2]|0)|0,c[I>>2]|0);A=f+11780|0;z=f+11844|0;BRa(f,(c[A>>2]|0)-(c[z>>2]|0)|0,c[I>>2]|0);I=c[G>>2]|0;c[f+11848>>2]=I;c[O>>2]=I;I=c[A>>2]|0;c[f+11852>>2]=I;c[z>>2]=I;I=f+13688|0;c[I>>2]=(c[I>>2]|0)+1}else{do{if(R){I=c[f+11736>>2]|0;if((c[f+9984>>2]|0)==0){z=5-I|0;A=f+784|0;O=f+788|0;if((K|0)>(z|0)){Hc=K;Ic=J<<z|3}else{G=je(3>>>((z-K|0)>>>0)|J<<K|0)|0;H=f+796|0;Q=c[H>>2]|0;y=G;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;Hc=K+32|0;Ic=3}H=Hc-z|0;c[A>>2]=Ic;c[O>>2]=H;if((c[f+14180>>2]|0)!=0){Jc=H;Kc=Ic;break}if((H|0)>2){Lc=H-2|0;Mc=Ic<<2|1}else{z=je(1>>>((2-H|0)>>>0)|Ic<<H|0)|0;Q=f+796|0;G=c[Q>>2]|0;y=z;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;Lc=H+30|0;Mc=1}c[A>>2]=Mc;c[O>>2]=Lc;H=c[f+14236>>2]|0;if((Lc|0)>1){Nc=Lc-1|0;Oc=H|Mc<<1}else{Q=je(H>>>((1-Lc|0)>>>0)|Mc<<Lc|0)|0;G=f+796|0;z=c[G>>2]|0;y=Q;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;Nc=Lc+31|0;Oc=H}c[A>>2]=Oc;c[O>>2]=Nc;Jc=Nc;Kc=Oc;break}do{if((I|0)==1){O=f+784|0;A=f+788|0;if((K|0)>6){Pc=K-6|0;Qc=J<<6|3}else{H=je(3>>>((6-K|0)>>>0)|J<<K|0)|0;G=f+796|0;z=c[G>>2]|0;y=H;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;Pc=K+26|0;Qc=3}c[O>>2]=Qc;c[A>>2]=Pc;if((c[f+14180>>2]|0)!=0){Rc=Qc;Sc=Pc;break}if((Pc|0)>2){Tc=Pc-2|0;Uc=Qc<<2|1}else{G=je(1>>>((2-Pc|0)>>>0)|Qc<<Pc|0)|0;z=f+796|0;H=c[z>>2]|0;y=G;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;Tc=Pc+30|0;Uc=1}c[O>>2]=Uc;c[A>>2]=Tc;z=c[f+14236>>2]|0;if((Tc|0)>1){Vc=Tc-1|0;Wc=z|Uc<<1}else{H=je(z>>>((1-Tc|0)>>>0)|Uc<<Tc|0)|0;G=f+796|0;Q=c[G>>2]|0;y=H;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;Vc=Tc+31|0;Wc=z}c[O>>2]=Wc;c[A>>2]=Vc;Rc=Wc;Sc=Vc}else{A=8-I|0;O=f+784|0;z=f+788|0;if((K|0)>(A|0)){Xc=K;Yc=J<<A|2}else{G=je(2>>>((A-K|0)>>>0)|J<<K|0)|0;Q=f+796|0;H=c[Q>>2]|0;y=G;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;Xc=K+32|0;Yc=2}Q=Xc-A|0;c[O>>2]=Yc;c[z>>2]=Q;if((c[f+14180>>2]|0)!=0){Rc=Yc;Sc=Q;break}if((Q|0)>2){Zc=Q-2|0;_c=Yc<<2|1}else{A=je(1>>>((2-Q|0)>>>0)|Yc<<Q|0)|0;H=f+796|0;G=c[H>>2]|0;y=A;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;Zc=Q+30|0;_c=1}c[O>>2]=_c;c[z>>2]=Zc;Q=c[f+14236>>2]|0;if((Zc|0)>1){$c=Zc-1|0;ad=Q|_c<<1}else{H=je(Q>>>((1-Zc|0)>>>0)|_c<<Zc|0)|0;G=f+796|0;A=c[G>>2]|0;y=H;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;$c=Zc+31|0;ad=Q}c[O>>2]=ad;c[z>>2]=$c;Rc=ad;Sc=$c}}while(0);I=f+784|0;z=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Sc|0)>5){bd=Sc-5|0;cd=z|Rc<<5}else{O=je(z>>>((5-Sc|0)>>>0)|Rc<<Sc|0)|0;Q=f+796|0;G=c[Q>>2]|0;y=O;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;bd=Sc+27|0;cd=z}c[I>>2]=cd;c[f+788>>2]=bd;Jc=bd;Kc=cd;break}else{Q=d[1062808+z|0]|0;if((Sc|0)>5){dd=Sc-5|0;ed=Q|Rc<<5}else{z=je(Q>>>((5-Sc|0)>>>0)|Rc<<Sc|0)|0;G=f+796|0;O=c[G>>2]|0;y=z;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;dd=Sc+27|0;ed=Q}c[I>>2]=ed;c[f+788>>2]=dd;Jc=dd;Kc=ed;break}}else{I=5-(c[f+11736>>2]|0)|0;Q=f+784|0;G=f+788|0;if((K|0)>(I|0)){fd=K;gd=J<<I|2}else{O=je(2>>>((I-K|0)>>>0)|J<<K|0)|0;z=f+796|0;A=c[z>>2]|0;y=O;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;fd=K+32|0;gd=2}z=fd-I|0;c[Q>>2]=gd;c[G>>2]=z;if((z|0)>2){hd=z-2|0;id=gd<<2|1}else{I=je(1>>>((2-z|0)>>>0)|gd<<z|0)|0;A=f+796|0;O=c[A>>2]|0;y=I;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;hd=z+30|0;id=1}c[Q>>2]=id;c[G>>2]=hd;G=f+9960|0;c[G>>2]=(c[G>>2]|0)-(c[f+9984>>2]|0);Jc=hd;Kc=id}}while(0);G=f+788|0;Q=f+796|0;z=c[Q>>2]|0;A=(z-(c[f+792>>2]|0)<<3)+(32-Jc)|0;O=f+13700|0;I=c[O>>2]|0;c[O>>2]=A;O=f+13696|0;c[O>>2]=(c[O>>2]|0)-I+A;A=f+11736|0;I=c[A>>2]|0;if((I&1|0)==0){jd=I}else{I=f+784|0;O=f+11556|0;H=c[f+11808>>2]|0;if((Jc|0)>1){kd=Jc-1|0;ld=H|Kc<<1}else{v=z;y=je(H>>>((1-Jc|0)>>>0)|Kc<<Jc|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;kd=Jc+31|0;ld=H}c[I>>2]=ld;c[G>>2]=kd;H=f+11744|0;v=f+11824|0;BRa(f,(c[H>>2]|0)-(c[v>>2]|0)|0,c[O>>2]|0);z=f+11748|0;N=f+11828|0;BRa(f,(c[z>>2]|0)-(c[N>>2]>>1)|0,c[O>>2]|0);c[v>>2]=c[H>>2];c[N>>2]=c[z>>2]<<1;z=c[f+11812>>2]|0;N=c[I>>2]|0;H=c[G>>2]|0;if((H|0)>1){md=H-1|0;nd=N<<1|z}else{v=je(z>>>((1-H|0)>>>0)|N<<H|0)|0;N=c[Q>>2]|0;y=v;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;md=H+31|0;nd=z}c[I>>2]=nd;c[G>>2]=md;I=f+11752|0;z=f+11832|0;BRa(f,(c[I>>2]|0)-(c[z>>2]|0)|0,c[O>>2]|0);H=f+11756|0;N=f+11836|0;BRa(f,(c[H>>2]|0)-(c[N>>2]>>1)|0,c[O>>2]|0);c[z>>2]=c[I>>2];c[N>>2]=c[H>>2]<<1;H=f+13684|0;c[H>>2]=(c[H>>2]|0)+1;jd=c[A>>2]|0}if((jd&2|0)==0){break}A=f+784|0;H=f+11560|0;N=c[f+11816>>2]|0;I=c[A>>2]|0;z=c[G>>2]|0;if((z|0)>1){od=z-1|0;pd=I<<1|N}else{O=je(N>>>((1-z|0)>>>0)|I<<z|0)|0;I=c[Q>>2]|0;y=O;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;od=z+31|0;pd=N}c[A>>2]=pd;c[G>>2]=od;N=f+11776|0;z=f+11840|0;BRa(f,(c[N>>2]|0)-(c[z>>2]|0)|0,c[H>>2]|0);I=f+11780|0;O=f+11844|0;BRa(f,(c[I>>2]|0)-(c[O>>2]>>1)|0,c[H>>2]|0);c[z>>2]=c[N>>2];c[O>>2]=c[I>>2]<<1;I=c[f+11820>>2]|0;O=c[A>>2]|0;N=c[G>>2]|0;if((N|0)>1){qd=N-1|0;rd=O<<1|I}else{z=je(I>>>((1-N|0)>>>0)|O<<N|0)|0;O=c[Q>>2]|0;y=z;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;qd=N+31|0;rd=I}c[A>>2]=rd;c[G>>2]=qd;G=f+11784|0;A=f+11848|0;BRa(f,(c[G>>2]|0)-(c[A>>2]|0)|0,c[H>>2]|0);I=f+11788|0;N=f+11852|0;BRa(f,(c[I>>2]|0)-(c[N>>2]>>1)|0,c[H>>2]|0);c[A>>2]=c[G>>2];c[N>>2]=c[I>>2]<<1;I=f+13688|0;c[I>>2]=(c[I>>2]|0)+1}}while(0);M=f+788|0;I=c[M>>2]|0;N=f+796|0;G=c[N>>2]|0;A=(G-(c[f+792>>2]|0)<<3)+(32-I)|0;H=f+13700|0;Q=c[H>>2]|0;c[H>>2]=A;H=f+13664|0;c[H>>2]=(c[H>>2]|0)-Q+A;if(!R){ga=I;ha=B;ia=M;ja=N;ka=0;break}A=f+784|0;if((c[f+14220>>2]|0)!=0){Q=d[1347633+(r<<1)|0]|0;H=d[1347632+(r<<1)|0]|0;O=A|0;z=c[O>>2]|0;if((I|0)>(Q|0)){sd=I;td=z<<Q|H}else{v=G;y=je(H>>>((Q-I|0)>>>0)|z<<I|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;sd=I+32|0;td=H}H=sd-Q|0;c[O>>2]=td;c[M>>2]=H;ga=H;ha=B;ia=M;ja=N;ka=r;break}H=r>>2;O=d[1347633+(H<<1)|0]|0;Q=d[1347632+(H<<1)|0]|0;H=A|0;A=c[H>>2]|0;if((I|0)>(O|0)){ud=I;vd=A<<O|Q;wd=G}else{v=G;y=je(Q>>>((O-I|0)>>>0)|A<<I|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;v=(c[N>>2]|0)+4|0;c[N>>2]=v;ud=I+32|0;vd=Q;wd=v}v=ud-O|0;c[H>>2]=vd;c[M>>2]=v;O=r&3;if((v|0)>2){xd=v-2|0;yd=vd<<2|O}else{Q=wd;y=je(O>>>((2-v|0)>>>0)|vd<<v|0)|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;xd=v+30|0;yd=O}c[H>>2]=yd;c[M>>2]=xd;ga=xd;ha=B;ia=M;ja=N;ka=r}}while(0);r=f+784|0;xd=f+48|0;yd=f+14196|0;vd=0;wd=ga;while(1){if((1<<5-vd&ka|0)==0){zd=wd}else{ga=g+(vd<<7)|0;ud=c[328966]|0;td=c[f+180+(vd<<2)>>2]|0;do{if((c[ha>>2]|0)==0){sd=b[ga>>1]|0;qd=sd<<16>>16;if(((sd<<16>>16>-1?qd:-qd|0)|0)!=1){Ad=ud;Bd=qd;Cd=-1;Dd=0;break}sd=qd>>>31|2;qd=c[r>>2]|0;if((wd|0)>2){Ed=wd-2|0;Fd=qd<<2|sd}else{rd=je(qd<<wd|sd>>>((2-wd|0)>>>0)|0)|0;qd=c[ja>>2]|0;y=rd;a[qd]=y;y=y>>8;a[qd+1|0]=y;y=y>>8;a[qd+2|0]=y;y=y>>8;a[qd+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;Ed=wd+30|0;Fd=sd}c[r>>2]=Fd;c[ia>>2]=Ed;Gd=ud;Id=0;Jd=1;Kd=405}else{if((vd|0)<4){Ld=0}else{Ld=(vd&1)+1|0}sd=b[ga>>1]|0;qd=f+9860+(Ld<<2)|0;rd=sd-(c[qd>>2]|0)|0;od=rd+255|0;do{if(od>>>0>510>>>0){if((rd|0)<0){pd=rd*-2|0;jd=(pd&65280|0)==0;Md=(d[1359664+(jd?pd:pd>>>8)|0]|0)+(jd?0:8)|0;Nd=rd-1|0}else{jd=rd<<1;pd=(jd&65280|0)==0;Md=(d[1359664+(pd?jd:rd>>>7&16777215)|0]|0)+(pd?0:8)|0;Nd=rd}if((Ld|0)==0){pd=(d[1347576+Md|0]|0)+Md|0;jd=(e[1347552+(Md<<1)>>1]<<Md)+((1<<Md)-1&Nd)|0;md=c[r>>2]|0;if((wd|0)>(pd|0)){Od=wd;Pd=jd|md<<pd}else{nd=je(jd>>>((pd-wd|0)>>>0)|md<<wd|0)|0;md=c[ja>>2]|0;y=nd;a[md]=y;y=y>>8;a[md+1|0]=y;y=y>>8;a[md+2|0]=y;y=y>>8;a[md+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;Od=wd+32|0;Pd=jd}c[r>>2]=Pd;c[ia>>2]=Od-pd;break}else{pd=(d[1347616+Md|0]|0)+Md|0;jd=(e[1347592+(Md<<1)>>1]<<Md)+((1<<Md)-1&Nd)|0;md=c[r>>2]|0;if((wd|0)>(pd|0)){Qd=wd;Rd=jd|md<<pd}else{nd=je(jd>>>((pd-wd|0)>>>0)|md<<wd|0)|0;md=c[ja>>2]|0;y=nd;a[md]=y;y=y>>8;a[md+1|0]=y;y=y>>8;a[md+2|0]=y;y=y>>8;a[md+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;Qd=wd+32|0;Rd=jd}c[r>>2]=Rd;c[ia>>2]=Qd-pd;break}}else{if((Ld|0)==0){pd=c[5616024+(od<<2)>>2]|0;jd=pd&255;md=pd>>>8;pd=c[r>>2]|0;if((wd|0)>(jd|0)){Sd=wd;Td=pd<<jd|md}else{nd=je(md>>>((jd-wd|0)>>>0)|pd<<wd|0)|0;pd=c[ja>>2]|0;y=nd;a[pd]=y;y=y>>8;a[pd+1|0]=y;y=y>>8;a[pd+2|0]=y;y=y>>8;a[pd+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;Sd=wd+32|0;Td=md}c[r>>2]=Td;c[ia>>2]=Sd-jd;break}else{jd=c[5618136+(od<<2)>>2]|0;md=jd&255;pd=jd>>>8;jd=c[r>>2]|0;if((wd|0)>(md|0)){Ud=wd;Vd=jd<<md|pd}else{nd=je(pd>>>((md-wd|0)>>>0)|jd<<wd|0)|0;jd=c[ja>>2]|0;y=nd;a[jd]=y;y=y>>8;a[jd+1|0]=y;y=y>>8;a[jd+2|0]=y;y=y>>8;a[jd+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;Ud=wd+32|0;Vd=pd}c[r>>2]=Vd;c[ia>>2]=Ud-md;break}}}while(0);c[qd>>2]=sd;Gd=(c[yd>>2]|0)==0?ud:c[328918]|0;Id=0;Jd=1;Kd=405}}while(0);while(1){if((Kd|0)==405){Kd=0;if((Jd|0)>(td|0)){break}Ad=Gd;Bd=b[g+(vd<<7)+(d[f+368+Jd|0]<<1)>>1]|0;Cd=Id;Dd=Jd}do{if((Bd|0)==0){Wd=Cd}else{ud=Dd-Cd-1|0;ga=Bd>>31;B=(ga^Bd)-ga|0;if((B|0)<=(a[5615960+ud|0]|0)){R=B-1+(d[5618072+ud|0]|0)|0;od=e[Ad+(R<<2)+2>>1]|0;rd=od+1|0;md=e[Ad+(R<<2)>>1]<<1|ga&1;ga=c[r>>2]|0;R=c[ia>>2]|0;if((R|0)>(rd|0)){Xd=R-rd|0;Yd=md|ga<<rd}else{pd=je(md>>>((rd-R|0)>>>0)|ga<<R|0)|0;ga=c[ja>>2]|0;y=pd;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;Xd=31-od+R|0;Yd=md}c[r>>2]=Yd;c[ia>>2]=Xd;Wd=Dd;break}md=e[Ad+446>>1]|0;R=e[Ad+444>>1]|0;od=c[r>>2]|0;ga=c[ia>>2]|0;if((ga|0)>(md|0)){Zd=ga-md|0;_d=od<<md|R}else{pd=je(R>>>((md-ga|0)>>>0)|od<<ga|0)|0;od=c[ja>>2]|0;y=pd;a[od]=y;y=y>>8;a[od+1|0]=y;y=y>>8;a[od+2|0]=y;y=y>>8;a[od+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;Zd=32-md+ga|0;_d=R}c[r>>2]=_d;c[ia>>2]=Zd;if((Zd|0)>6){$d=Zd-6|0;ae=_d<<6|ud}else{R=je(ud>>>((6-Zd|0)>>>0)|_d<<Zd|0)|0;ga=c[ja>>2]|0;y=R;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;$d=Zd+26|0;ae=ud}c[r>>2]=ae;c[ia>>2]=$d;if((c[xd>>2]|0)!=1){ud=Bd&4095;if(($d|0)>12){be=$d-12|0;ce=ae<<12|ud}else{ga=je(ud>>>((12-$d|0)>>>0)|ae<<$d|0)|0;R=c[ja>>2]|0;y=ga;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;be=$d+20|0;ce=ud}c[r>>2]=ce;c[ia>>2]=be;Wd=Dd;break}if((B|0)<128){B=Bd&255;if(($d|0)>8){de=$d-8|0;ee=ae<<8|B}else{ud=je(B>>>((8-$d|0)>>>0)|ae<<$d|0)|0;R=c[ja>>2]|0;y=ud;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;de=$d+24|0;ee=B}c[r>>2]=ee;c[ia>>2]=de;Wd=Dd;break}if((Bd|0)<0){B=Bd+33024|0;if(($d|0)>16){fe=$d-16|0;ge=ae<<16|B}else{R=je(B>>>((16-$d|0)>>>0)|ae<<$d|0)|0;ud=c[ja>>2]|0;y=R;a[ud]=y;y=y>>8;a[ud+1|0]=y;y=y>>8;a[ud+2|0]=y;y=y>>8;a[ud+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;fe=$d+16|0;ge=B}c[r>>2]=ge;c[ia>>2]=fe;Wd=Dd;break}else{B=Bd&65535;if(($d|0)>16){he=$d-16|0;ie=ae<<16|B}else{ud=je(B>>>((16-$d|0)>>>0)|ae<<$d|0)|0;R=c[ja>>2]|0;y=ud;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;he=$d+16|0;ie=B}c[r>>2]=ie;c[ia>>2]=he;Wd=Dd;break}}}while(0);Gd=Ad;Id=Wd;Jd=Dd+1|0;Kd=405}td=e[Gd+450>>1]|0;sd=e[Gd+448>>1]|0;qd=c[r>>2]|0;B=c[ia>>2]|0;if((B|0)>(td|0)){ke=B-td|0;le=qd<<td|sd}else{R=je(sd>>>((td-B|0)>>>0)|qd<<B|0)|0;qd=c[ja>>2]|0;y=R;a[qd]=y;y=y>>8;a[qd+1|0]=y;y=y>>8;a[qd+2|0]=y;y=y>>8;a[qd+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;ke=32-td+B|0;le=sd}c[r>>2]=le;c[ia>>2]=ke;zd=ke}sd=vd+1|0;if((sd|0)<6){vd=sd;wd=zd}else{break}}wd=c[ja>>2]|0;c[p>>2]=0;p=(c[ha>>2]|0)==0;ha=(wd-(c[f+792>>2]|0)<<3)+(32-zd)|0;zd=f+13700|0;wd=c[zd>>2]|0;c[zd>>2]=ha;zd=ha-wd|0;if(p){p=f+13676|0;c[p>>2]=(c[p>>2]|0)+zd;i=k;return}else{p=f+13672|0;c[p>>2]=(c[p>>2]|0)+zd;i=k;return}}else{if(n){me=(m|0)==(c[f+13708>>2]|0)}else{me=0}n=(c[f+180>>2]>>31)+128&-128;zd=(c[f+184>>2]|0)>-1?n|64:n;n=(c[f+188>>2]|0)>-1?zd|32:zd;zd=(c[f+192>>2]|0)>-1?n|16:n;n=(c[f+196>>2]|0)>-1?zd|8:zd;zd=(c[f+200>>2]|0)>-1?n|4:n;n=(c[f+204>>2]|0)>-1?zd|2:zd;do{if((c[f+208>>2]|0)>-1){ne=n|1;oe=0}else{zd=(n|0)==0;if(me|zd^1){ne=n;oe=zd;break}if((c[f+11740>>2]|0)!=0){ne=n;oe=zd;break}if((l|0)==((c[f+116>>2]|0)-1|0)){if((m|0)==((c[f+812>>2]|0)-1|0)){ne=n;oe=zd;break}if((c[f+48>>2]|0)!=1){ne=n;oe=zd;break}}p=c[f+9992>>2]|0;wd=(p|0)==2;if(wd){if((j|h|0)!=0){ne=n;oe=zd;break}}else{if((p|0)!=3){ne=n;oe=zd;break}p=c[f+11736>>2]|0;if((p|0)!=(c[f+14144>>2]|0)){ne=n;oe=zd;break}if((p&1|0)==0){pe=0}else{pe=(c[f+11748>>2]|0)-(c[f+11828>>2]|0)|(c[f+11744>>2]|0)-(c[f+11824>>2]|0)}if((p&2|0)==0){qe=0}else{qe=(c[f+11780>>2]|0)-(c[f+11844>>2]|0)|(c[f+11776>>2]|0)-(c[f+11840>>2]|0)}if((qe|pe|0)!=0){ne=n;oe=zd;break}}zd=f+12484|0;c[zd>>2]=(c[zd>>2]|0)+1;zd=f+9960|0;c[zd>>2]=(c[zd>>2]|0)-(c[f+9984>>2]|0);zd=f+13692|0;c[zd>>2]=(c[zd>>2]|0)+1;zd=f+13696|0;c[zd>>2]=(c[zd>>2]|0)+1;zd=f+13700|0;c[zd>>2]=(c[zd>>2]|0)+1;if(!wd){i=k;return}mrc(f+11824|0,0,16)|0;i=k;return}}while(0);n=f+12484|0;pe=c[n>>2]|0;if(me){if((pe|0)!=0){KIb(0,0,2508440,(x=i,i=i+24|0,c[x>>2]=2272480,c[x+8>>2]=2450048,c[x+16>>2]=724,x)|0);i=x;Hd()}x=f+784|0;if((l|0)>32){me=f+788|0;qe=f+796|0;m=l;wd=c[x>>2]|0;zd=c[me>>2]|0;while(1){if((zd|0)>11){re=zd-11|0;se=wd<<11|8}else{p=je(8>>>((11-zd|0)>>>0)|wd<<zd|0)|0;ha=c[qe>>2]|0;y=p;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;c[qe>>2]=(c[qe>>2]|0)+4;re=zd+21|0;se=8}c[x>>2]=se;c[me>>2]=re;ha=m-33|0;if((ha|0)>32){m=ha;wd=se;zd=re}else{break}}te=((l-33|0)>>>0)%33|0;ue=se;ve=re}else{te=l;ue=c[x>>2]|0;ve=c[f+788>>2]|0}l=d[1347801+(te<<1)|0]|0;re=d[1347800+(te<<1)|0]|0;if((ve|0)>(l|0)){we=ve;xe=ue<<l|re}else{te=je(re>>>((l-ve|0)>>>0)|ue<<ve|0)|0;ue=f+796|0;se=c[ue>>2]|0;y=te;a[se]=y;y=y>>8;a[se+1|0]=y;y=y>>8;a[se+2|0]=y;y=y>>8;a[se+3|0]=y;c[ue>>2]=(c[ue>>2]|0)+4;we=ve+32|0;xe=re}re=we-l|0;c[x>>2]=xe;c[f+788>>2]=re;ye=xe;ze=re}else{re=f+784|0;if((pe|0)>32){xe=f+788|0;x=f+796|0;l=pe;we=c[re>>2]|0;ve=c[xe>>2]|0;while(1){if((ve|0)>11){Ae=ve-11|0;Be=we<<11|8}else{ue=je(8>>>((11-ve|0)>>>0)|we<<ve|0)|0;se=c[x>>2]|0;y=ue;a[se]=y;y=y>>8;a[se+1|0]=y;y=y>>8;a[se+2|0]=y;y=y>>8;a[se+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;Ae=ve+21|0;Be=8}c[re>>2]=Be;c[xe>>2]=Ae;se=l-33|0;if((se|0)>32){l=se;we=Be;ve=Ae}else{break}}Ce=((pe-33|0)>>>0)%33|0;De=Be;Ee=Ae}else{Ce=pe;De=c[re>>2]|0;Ee=c[f+788>>2]|0}pe=d[1347801+(Ce<<1)|0]|0;Ae=d[1347800+(Ce<<1)|0]|0;if((Ee|0)>(pe|0)){Fe=Ee;Ge=De<<pe|Ae}else{Ce=je(Ae>>>((pe-Ee|0)>>>0)|De<<Ee|0)|0;De=f+796|0;Be=c[De>>2]|0;y=Ce;a[Be]=y;y=y>>8;a[Be+1|0]=y;y=y>>8;a[Be+2|0]=y;y=y>>8;a[Be+3|0]=y;c[De>>2]=(c[De>>2]|0)+4;Fe=Ee+32|0;Ge=Ae}Ae=Fe-pe|0;c[re>>2]=Ge;c[f+788>>2]=Ae;ye=Ge;ze=Ae}Ae=c[f+9992>>2]|0;do{if((Ae|0)==1){Ge=f+9984|0;re=f+784|0;pe=f+788|0;do{if((c[Ge>>2]|0)==0|oe){if((ze|0)>1){He=ze-1|0;Ie=ye<<1|1}else{Fe=je(1>>>((1-ze|0)>>>0)|ye<<ze|0)|0;Ee=f+796|0;De=c[Ee>>2]|0;y=Fe;a[De]=y;y=y>>8;a[De+1|0]=y;y=y>>8;a[De+2|0]=y;y=y>>8;a[De+3|0]=y;c[Ee>>2]=(c[Ee>>2]|0)+4;He=ze+31|0;Ie=1}c[re>>2]=Ie;c[pe>>2]=He;if((c[f+14180>>2]|0)==0){Ee=c[f+14236>>2]|0;if((He|0)>1){Je=He-1|0;Ke=Ee|Ie<<1}else{De=je(Ee>>>((1-He|0)>>>0)|Ie<<He|0)|0;Fe=f+796|0;Be=c[Fe>>2]|0;y=De;a[Be]=y;y=y>>8;a[Be+1|0]=y;y=y>>8;a[Be+2|0]=y;y=y>>8;a[Be+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;Je=He+31|0;Ke=Ee}c[re>>2]=Ke;c[pe>>2]=Je;Le=Je}else{Le=He}Ee=f+9960|0;c[Ee>>2]=(c[Ee>>2]|0)-(c[Ge>>2]|0);Me=Le}else{if((ze|0)>2){Ne=ze-2|0;Oe=ye<<2|1}else{Ee=je(1>>>((2-ze|0)>>>0)|ye<<ze|0)|0;Fe=f+796|0;Be=c[Fe>>2]|0;y=Ee;a[Be]=y;y=y>>8;a[Be+1|0]=y;y=y>>8;a[Be+2|0]=y;y=y>>8;a[Be+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;Ne=ze+30|0;Oe=1}c[re>>2]=Oe;c[pe>>2]=Ne;if((c[f+14180>>2]|0)==0){Fe=c[f+14236>>2]|0;if((Ne|0)>1){Pe=Ne-1|0;Qe=Fe|Oe<<1}else{Be=je(Fe>>>((1-Ne|0)>>>0)|Oe<<Ne|0)|0;Ee=f+796|0;De=c[Ee>>2]|0;y=Be;a[De]=y;y=y>>8;a[De+1|0]=y;y=y>>8;a[De+2|0]=y;y=y>>8;a[De+3|0]=y;c[Ee>>2]=(c[Ee>>2]|0)+4;Pe=Ne+31|0;Qe=Fe}c[re>>2]=Qe;c[pe>>2]=Pe;Re=Qe;Se=Pe}else{Re=Oe;Se=Ne}Fe=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Se|0)>5){Te=Se-5|0;Ue=Fe|Re<<5}else{Ee=je(Fe>>>((5-Se|0)>>>0)|Re<<Se|0)|0;De=f+796|0;Be=c[De>>2]|0;y=Ee;a[Be]=y;y=y>>8;a[Be+1|0]=y;y=y>>8;a[Be+2|0]=y;y=y>>8;a[Be+3|0]=y;c[De>>2]=(c[De>>2]|0)+4;Te=Se+27|0;Ue=Fe}c[re>>2]=Ue;c[pe>>2]=Te;Me=Te;break}else{De=d[1062808+Fe|0]|0;if((Se|0)>5){Ve=Se-5|0;We=De|Re<<5}else{Fe=je(De>>>((5-Se|0)>>>0)|Re<<Se|0)|0;Be=f+796|0;Ee=c[Be>>2]|0;y=Fe;a[Ee]=y;y=y>>8;a[Ee+1|0]=y;y=y>>8;a[Ee+2|0]=y;y=y>>8;a[Ee+3|0]=y;c[Be>>2]=(c[Be>>2]|0)+4;Ve=Se+27|0;We=De}c[re>>2]=We;c[pe>>2]=Ve;Me=Ve;break}}}while(0);re=f+796|0;Ge=((c[re>>2]|0)-(c[f+792>>2]|0)<<3)+(32-Me)|0;De=f+13700|0;Be=c[De>>2]|0;c[De>>2]=Ge;De=f+13696|0;c[De>>2]=(c[De>>2]|0)-Be+Ge;Ge=f+13680|0;c[Ge>>2]=(c[Ge>>2]|0)+1;Xe=Me;Ye=f+12488|0;Ze=pe;_e=re;$e=ne}else{re=f+12488|0;if((c[re>>2]|0)!=0){Ge=f+9984|0;Be=f+784|0;De=f+788|0;do{if((c[Ge>>2]|0)==0|oe){if((ze|0)>5){af=ze-5|0;bf=ye<<5|3}else{Ee=je(3>>>((5-ze|0)>>>0)|ye<<ze|0)|0;Fe=f+796|0;Ce=c[Fe>>2]|0;y=Ee;a[Ce]=y;y=y>>8;a[Ce+1|0]=y;y=y>>8;a[Ce+2|0]=y;y=y>>8;a[Ce+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;af=ze+27|0;bf=3}c[Be>>2]=bf;c[De>>2]=af;if((c[f+14180>>2]|0)==0){Fe=c[f+14236>>2]|0;if((af|0)>1){cf=af-1|0;df=Fe|bf<<1}else{Ce=je(Fe>>>((1-af|0)>>>0)|bf<<af|0)|0;Ee=f+796|0;ve=c[Ee>>2]|0;y=Ce;a[ve]=y;y=y>>8;a[ve+1|0]=y;y=y>>8;a[ve+2|0]=y;y=y>>8;a[ve+3|0]=y;c[Ee>>2]=(c[Ee>>2]|0)+4;cf=af+31|0;df=Fe}c[Be>>2]=df;c[De>>2]=cf;ef=cf}else{ef=af}Fe=f+9960|0;c[Fe>>2]=(c[Fe>>2]|0)-(c[Ge>>2]|0);ff=ef}else{if((ze|0)>6){gf=ze-6|0;hf=ye<<6|1}else{Fe=je(1>>>((6-ze|0)>>>0)|ye<<ze|0)|0;Ee=f+796|0;ve=c[Ee>>2]|0;y=Fe;a[ve]=y;y=y>>8;a[ve+1|0]=y;y=y>>8;a[ve+2|0]=y;y=y>>8;a[ve+3|0]=y;c[Ee>>2]=(c[Ee>>2]|0)+4;gf=ze+26|0;hf=1}c[Be>>2]=hf;c[De>>2]=gf;if((c[f+14180>>2]|0)==0){Ee=c[f+14236>>2]|0;if((gf|0)>1){jf=gf-1|0;kf=Ee|hf<<1}else{ve=je(Ee>>>((1-gf|0)>>>0)|hf<<gf|0)|0;Fe=f+796|0;Ce=c[Fe>>2]|0;y=ve;a[Ce]=y;y=y>>8;a[Ce+1|0]=y;y=y>>8;a[Ce+2|0]=y;y=y>>8;a[Ce+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;jf=gf+31|0;kf=Ee}c[Be>>2]=kf;c[De>>2]=jf;lf=kf;mf=jf}else{lf=hf;mf=gf}Ee=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((mf|0)>5){nf=mf-5|0;of=Ee|lf<<5}else{Fe=je(Ee>>>((5-mf|0)>>>0)|lf<<mf|0)|0;Ce=f+796|0;ve=c[Ce>>2]|0;y=Fe;a[ve]=y;y=y>>8;a[ve+1|0]=y;y=y>>8;a[ve+2|0]=y;y=y>>8;a[ve+3|0]=y;c[Ce>>2]=(c[Ce>>2]|0)+4;nf=mf+27|0;of=Ee}c[Be>>2]=of;c[De>>2]=nf;ff=nf;break}else{Ce=d[1062808+Ee|0]|0;if((mf|0)>5){pf=mf-5|0;qf=Ce|lf<<5}else{Ee=je(Ce>>>((5-mf|0)>>>0)|lf<<mf|0)|0;ve=f+796|0;Fe=c[ve>>2]|0;y=Ee;a[Fe]=y;y=y>>8;a[Fe+1|0]=y;y=y>>8;a[Fe+2|0]=y;y=y>>8;a[Fe+3|0]=y;c[ve>>2]=(c[ve>>2]|0)+4;pf=mf+27|0;qf=Ce}c[Be>>2]=qf;c[De>>2]=pf;ff=pf;break}}}while(0);Be=f+796|0;Ge=((c[Be>>2]|0)-(c[f+792>>2]|0)<<3)+(32-ff)|0;pe=f+13700|0;Ce=c[pe>>2]|0;c[pe>>2]=Ge;pe=f+13696|0;c[pe>>2]=(c[pe>>2]|0)-Ce+Ge;Ge=f+13680|0;c[Ge>>2]=(c[Ge>>2]|0)+1;mrc(f+11824|0,0,32)|0;Xe=ff;Ye=re;Ze=De;_e=Be;$e=ne;break}Be=(c[f+11740>>2]|0)==0;Ge=(ne|0)!=0;if((Ae|0)==2){if(Be){do{if(Ge){Ce=(c[f+9984>>2]|0)!=0;pe=f+784|0;ve=f+788|0;if((j|h|0)==0){do{if(Ce){if((ze|0)>5){rf=ze-5|0;sf=ye<<5|1}else{Fe=je(1>>>((5-ze|0)>>>0)|ye<<ze|0)|0;Ee=f+796|0;we=c[Ee>>2]|0;y=Fe;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[Ee>>2]=(c[Ee>>2]|0)+4;rf=ze+27|0;sf=1}c[pe>>2]=sf;c[ve>>2]=rf;if((c[f+14180>>2]|0)==0){Ee=c[f+14236>>2]|0;if((rf|0)>1){tf=rf-1|0;uf=Ee|sf<<1}else{we=je(Ee>>>((1-rf|0)>>>0)|sf<<rf|0)|0;Fe=f+796|0;l=c[Fe>>2]|0;y=we;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;tf=rf+31|0;uf=Ee}c[pe>>2]=uf;c[ve>>2]=tf;vf=uf;wf=tf}else{vf=sf;wf=rf}Ee=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((wf|0)>5){xf=wf-5|0;yf=Ee|vf<<5}else{Fe=je(Ee>>>((5-wf|0)>>>0)|vf<<wf|0)|0;l=f+796|0;we=c[l>>2]|0;y=Fe;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;xf=wf+27|0;yf=Ee}c[pe>>2]=yf;c[ve>>2]=xf;zf=xf;break}else{l=d[1062808+Ee|0]|0;if((wf|0)>5){Af=wf-5|0;Bf=l|vf<<5}else{Ee=je(l>>>((5-wf|0)>>>0)|vf<<wf|0)|0;we=f+796|0;Fe=c[we>>2]|0;y=Ee;a[Fe]=y;y=y>>8;a[Fe+1|0]=y;y=y>>8;a[Fe+2|0]=y;y=y>>8;a[Fe+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;Af=wf+27|0;Bf=l}c[pe>>2]=Bf;c[ve>>2]=Af;zf=Af;break}}else{if((ze|0)>2){Cf=ze-2|0;Df=ye<<2|1}else{l=je(1>>>((2-ze|0)>>>0)|ye<<ze|0)|0;we=f+796|0;Fe=c[we>>2]|0;y=l;a[Fe]=y;y=y>>8;a[Fe+1|0]=y;y=y>>8;a[Fe+2|0]=y;y=y>>8;a[Fe+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;Cf=ze+30|0;Df=1}c[pe>>2]=Df;c[ve>>2]=Cf;if((c[f+14180>>2]|0)!=0){zf=Cf;break}we=c[f+14236>>2]|0;if((Cf|0)>1){Ef=Cf-1|0;Ff=we|Df<<1}else{Fe=je(we>>>((1-Cf|0)>>>0)|Df<<Cf|0)|0;l=f+796|0;Ee=c[l>>2]|0;y=Fe;a[Ee]=y;y=y>>8;a[Ee+1|0]=y;y=y>>8;a[Ee+2|0]=y;y=y>>8;a[Ee+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;Ef=Cf+31|0;Ff=we}c[pe>>2]=Ff;c[ve>>2]=Ef;zf=Ef}}while(0);we=c[f+796>>2]|0;l=(we-(c[f+792>>2]|0)<<3)+(32-zf)|0;Ee=f+13700|0;Fe=c[Ee>>2]|0;c[Ee>>2]=l;Ee=f+13696|0;c[Ee>>2]=(c[Ee>>2]|0)-Fe+l;Gf=zf;Hf=we;If=f+11824|0;Jf=f+11828|0;break}do{if(Ce){if((ze|0)>5){Kf=ze-5|0;Lf=ye<<5|2}else{we=je(2>>>((5-ze|0)>>>0)|ye<<ze|0)|0;l=f+796|0;Fe=c[l>>2]|0;y=we;a[Fe]=y;y=y>>8;a[Fe+1|0]=y;y=y>>8;a[Fe+2|0]=y;y=y>>8;a[Fe+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;Kf=ze+27|0;Lf=2}c[pe>>2]=Lf;c[ve>>2]=Kf;if((c[f+14180>>2]|0)==0){if((Kf|0)>2){Mf=Kf-2|0;Nf=Lf<<2|2}else{l=je(2>>>((2-Kf|0)>>>0)|Lf<<Kf|0)|0;Fe=f+796|0;we=c[Fe>>2]|0;y=l;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;Mf=Kf+30|0;Nf=2}c[pe>>2]=Nf;c[ve>>2]=Mf;Fe=c[f+14236>>2]|0;if((Mf|0)>1){Of=Mf-1|0;Pf=Fe|Nf<<1}else{we=je(Fe>>>((1-Mf|0)>>>0)|Nf<<Mf|0)|0;l=f+796|0;Ee=c[l>>2]|0;y=we;a[Ee]=y;y=y>>8;a[Ee+1|0]=y;y=y>>8;a[Ee+2|0]=y;y=y>>8;a[Ee+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;Of=Mf+31|0;Pf=Fe}c[pe>>2]=Pf;c[ve>>2]=Of;Qf=Pf;Rf=Of}else{Qf=Lf;Rf=Kf}Fe=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Rf|0)>5){Sf=Rf-5|0;Tf=Fe|Qf<<5}else{l=je(Fe>>>((5-Rf|0)>>>0)|Qf<<Rf|0)|0;Ee=f+796|0;we=c[Ee>>2]|0;y=l;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[Ee>>2]=(c[Ee>>2]|0)+4;Sf=Rf+27|0;Tf=Fe}c[pe>>2]=Tf;c[ve>>2]=Sf;Uf=Sf;break}else{Ee=d[1062808+Fe|0]|0;if((Rf|0)>5){Vf=Rf-5|0;Wf=Ee|Qf<<5}else{Fe=je(Ee>>>((5-Rf|0)>>>0)|Qf<<Rf|0)|0;we=f+796|0;l=c[we>>2]|0;y=Fe;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;Vf=Rf+27|0;Wf=Ee}c[pe>>2]=Wf;c[ve>>2]=Vf;Uf=Vf;break}}else{if((ze|0)>1){Xf=ze-1|0;Yf=ye<<1|1}else{Ee=je(1>>>((1-ze|0)>>>0)|ye<<ze|0)|0;we=f+796|0;l=c[we>>2]|0;y=Ee;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;Xf=ze+31|0;Yf=1}c[pe>>2]=Yf;c[ve>>2]=Xf;if((c[f+14180>>2]|0)!=0){Uf=Xf;break}if((Xf|0)>2){Zf=Xf-2|0;_f=Yf<<2|2}else{we=je(2>>>((2-Xf|0)>>>0)|Yf<<Xf|0)|0;l=f+796|0;Ee=c[l>>2]|0;y=we;a[Ee]=y;y=y>>8;a[Ee+1|0]=y;y=y>>8;a[Ee+2|0]=y;y=y>>8;a[Ee+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;Zf=Xf+30|0;_f=2}c[pe>>2]=_f;c[ve>>2]=Zf;l=c[f+14236>>2]|0;if((Zf|0)>1){$f=Zf-1|0;ag=l|_f<<1}else{Ee=je(l>>>((1-Zf|0)>>>0)|_f<<Zf|0)|0;we=f+796|0;Fe=c[we>>2]|0;y=Ee;a[Fe]=y;y=y>>8;a[Fe+1|0]=y;y=y>>8;a[Fe+2|0]=y;y=y>>8;a[Fe+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;$f=Zf+31|0;ag=l}c[pe>>2]=ag;c[ve>>2]=$f;Uf=$f}}while(0);pe=f+792|0;Ce=f+796|0;l=((c[Ce>>2]|0)-(c[pe>>2]|0)<<3)+(32-Uf)|0;we=f+13700|0;Fe=c[we>>2]|0;c[we>>2]=l;Ee=f+13696|0;c[Ee>>2]=(c[Ee>>2]|0)-Fe+l;l=f+11824|0;Fe=f+11556|0;BRa(f,h-(c[l>>2]|0)|0,c[Fe>>2]|0);Ee=f+11828|0;BRa(f,j-(c[Ee>>2]|0)|0,c[Fe>>2]|0);Fe=c[ve>>2]|0;xe=c[Ce>>2]|0;Ce=(xe-(c[pe>>2]|0)<<3)+(32-Fe)|0;pe=c[we>>2]|0;c[we>>2]=Ce;we=f+13664|0;c[we>>2]=(c[we>>2]|0)-pe+Ce;Gf=Fe;Hf=xe;If=l;Jf=Ee}else{Ee=f+784|0;l=f+788|0;if((ze|0)>3){bg=ze-3|0;cg=ye<<3|1}else{xe=je(1>>>((3-ze|0)>>>0)|ye<<ze|0)|0;Fe=f+796|0;Ce=c[Fe>>2]|0;y=xe;a[Ce]=y;y=y>>8;a[Ce+1|0]=y;y=y>>8;a[Ce+2|0]=y;y=y>>8;a[Ce+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;bg=ze+29|0;cg=1}c[Ee>>2]=cg;c[l>>2]=bg;if((c[f+14180>>2]|0)==0){if((bg|0)>2){dg=bg-2|0;eg=cg<<2|2}else{Fe=je(2>>>((2-bg|0)>>>0)|cg<<bg|0)|0;Ce=f+796|0;xe=c[Ce>>2]|0;y=Fe;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;c[Ce>>2]=(c[Ce>>2]|0)+4;dg=bg+30|0;eg=2}c[Ee>>2]=eg;c[l>>2]=dg;fg=dg}else{fg=bg}Ee=f+792|0;Ce=f+796|0;xe=((c[Ce>>2]|0)-(c[Ee>>2]|0)<<3)+(32-fg)|0;Fe=f+13700|0;pe=c[Fe>>2]|0;c[Fe>>2]=xe;we=f+13696|0;c[we>>2]=(c[we>>2]|0)-pe+xe;xe=f+11824|0;pe=f+11556|0;BRa(f,h-(c[xe>>2]|0)|0,c[pe>>2]|0);we=f+11828|0;BRa(f,j-(c[we>>2]|0)|0,c[pe>>2]|0);pe=f+9960|0;c[pe>>2]=(c[pe>>2]|0)-(c[f+9984>>2]|0);pe=c[l>>2]|0;l=c[Ce>>2]|0;Ce=(l-(c[Ee>>2]|0)<<3)+(32-pe)|0;Ee=c[Fe>>2]|0;c[Fe>>2]=Ce;Fe=f+13664|0;c[Fe>>2]=(c[Fe>>2]|0)-Ee+Ce;Gf=pe;Hf=l;If=xe;Jf=we}}while(0);c[If>>2]=h;c[f+11832>>2]=h;c[Jf>>2]=j;c[f+11836>>2]=j;gg=Gf;hg=Hf}else{do{if(Ge){De=f+784|0;we=f+788|0;if((c[f+9984>>2]|0)==0){if((ze|0)>1){ig=ze-1|0;jg=ye<<1|1}else{xe=je(1>>>((1-ze|0)>>>0)|ye<<ze|0)|0;l=f+796|0;pe=c[l>>2]|0;y=xe;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;ig=ze+31|0;jg=1}c[De>>2]=jg;c[we>>2]=ig;if((c[f+14180>>2]|0)!=0){kg=ig;lg=jg;break}if((ig|0)>2){mg=ig-2|0;ng=jg<<2|1}else{l=je(1>>>((2-ig|0)>>>0)|jg<<ig|0)|0;pe=f+796|0;xe=c[pe>>2]|0;y=l;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;c[pe>>2]=(c[pe>>2]|0)+4;mg=ig+30|0;ng=1}c[De>>2]=ng;c[we>>2]=mg;pe=c[f+14236>>2]|0;if((mg|0)>1){og=mg-1|0;pg=pe|ng<<1}else{xe=je(pe>>>((1-mg|0)>>>0)|ng<<mg|0)|0;l=f+796|0;Ce=c[l>>2]|0;y=xe;a[Ce]=y;y=y>>8;a[Ce+1|0]=y;y=y>>8;a[Ce+2|0]=y;y=y>>8;a[Ce+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;og=mg+31|0;pg=pe}c[De>>2]=pg;c[we>>2]=og;kg=og;lg=pg;break}if((ze|0)>5){qg=ze-5|0;rg=ye<<5|2}else{pe=je(2>>>((5-ze|0)>>>0)|ye<<ze|0)|0;l=f+796|0;Ce=c[l>>2]|0;y=pe;a[Ce]=y;y=y>>8;a[Ce+1|0]=y;y=y>>8;a[Ce+2|0]=y;y=y>>8;a[Ce+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;qg=ze+27|0;rg=2}c[De>>2]=rg;c[we>>2]=qg;if((c[f+14180>>2]|0)==0){if((qg|0)>2){sg=qg-2|0;tg=rg<<2|1}else{l=je(1>>>((2-qg|0)>>>0)|rg<<qg|0)|0;Ce=f+796|0;pe=c[Ce>>2]|0;y=l;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;c[Ce>>2]=(c[Ce>>2]|0)+4;sg=qg+30|0;tg=1}c[De>>2]=tg;c[we>>2]=sg;Ce=c[f+14236>>2]|0;if((sg|0)>1){ug=sg-1|0;vg=Ce|tg<<1}else{pe=je(Ce>>>((1-sg|0)>>>0)|tg<<sg|0)|0;l=f+796|0;xe=c[l>>2]|0;y=pe;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;ug=sg+31|0;vg=Ce}c[De>>2]=vg;c[we>>2]=ug;wg=vg;xg=ug}else{wg=rg;xg=qg}Ce=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((xg|0)>5){yg=xg-5|0;zg=Ce|wg<<5}else{l=je(Ce>>>((5-xg|0)>>>0)|wg<<xg|0)|0;xe=f+796|0;pe=c[xe>>2]|0;y=l;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;c[xe>>2]=(c[xe>>2]|0)+4;yg=xg+27|0;zg=Ce}c[De>>2]=zg;c[we>>2]=yg;kg=yg;lg=zg;break}else{xe=d[1062808+Ce|0]|0;if((xg|0)>5){Ag=xg-5|0;Bg=xe|wg<<5}else{Ce=je(xe>>>((5-xg|0)>>>0)|wg<<xg|0)|0;pe=f+796|0;l=c[pe>>2]|0;y=Ce;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[pe>>2]=(c[pe>>2]|0)+4;Ag=xg+27|0;Bg=xe}c[De>>2]=Bg;c[we>>2]=Ag;kg=Ag;lg=Bg;break}}else{we=f+784|0;De=f+788|0;if((ze|0)>3){Cg=ze-3|0;Dg=ye<<3|1}else{xe=je(1>>>((3-ze|0)>>>0)|ye<<ze|0)|0;pe=f+796|0;l=c[pe>>2]|0;y=xe;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[pe>>2]=(c[pe>>2]|0)+4;Cg=ze+29|0;Dg=1}c[we>>2]=Dg;c[De>>2]=Cg;if((Cg|0)>2){Eg=Cg-2|0;Fg=Dg<<2|1}else{pe=je(1>>>((2-Cg|0)>>>0)|Dg<<Cg|0)|0;l=f+796|0;xe=c[l>>2]|0;y=pe;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;Eg=Cg+30|0;Fg=1}c[we>>2]=Fg;c[De>>2]=Eg;De=f+9960|0;c[De>>2]=(c[De>>2]|0)-(c[f+9984>>2]|0);kg=Eg;lg=Fg}}while(0);De=f+788|0;we=f+792|0;l=f+796|0;xe=c[l>>2]|0;pe=(xe-(c[we>>2]|0)<<3)+(32-kg)|0;Ce=f+13700|0;Ee=c[Ce>>2]|0;c[Ce>>2]=pe;Fe=f+13696|0;c[Fe>>2]=(c[Fe>>2]|0)-Ee+pe;pe=f+784|0;Ee=f+11556|0;Fe=c[f+11808>>2]|0;if((kg|0)>1){Gg=kg-1|0;Hg=Fe|lg<<1}else{x=xe;y=je(Fe>>>((1-kg|0)>>>0)|lg<<kg|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;Gg=kg+31|0;Hg=Fe}c[pe>>2]=Hg;c[De>>2]=Gg;Fe=f+11744|0;x=f+11824|0;BRa(f,(c[Fe>>2]|0)-(c[x>>2]|0)|0,c[Ee>>2]|0);xe=f+11748|0;se=f+11828|0;BRa(f,(c[xe>>2]|0)-(c[se>>2]>>1)|0,c[Ee>>2]|0);c[x>>2]=c[Fe>>2];c[se>>2]=c[xe>>2]<<1;xe=c[f+11812>>2]|0;se=c[pe>>2]|0;Fe=c[De>>2]|0;if((Fe|0)>1){Ig=Fe-1|0;Jg=se<<1|xe}else{x=je(xe>>>((1-Fe|0)>>>0)|se<<Fe|0)|0;se=c[l>>2]|0;y=x;a[se]=y;y=y>>8;a[se+1|0]=y;y=y>>8;a[se+2|0]=y;y=y>>8;a[se+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;Ig=Fe+31|0;Jg=xe}c[pe>>2]=Jg;c[De>>2]=Ig;pe=f+11752|0;xe=f+11832|0;BRa(f,(c[pe>>2]|0)-(c[xe>>2]|0)|0,c[Ee>>2]|0);Fe=f+11756|0;se=f+11836|0;BRa(f,(c[Fe>>2]|0)-(c[se>>2]>>1)|0,c[Ee>>2]|0);c[xe>>2]=c[pe>>2];c[se>>2]=c[Fe>>2]<<1;Fe=c[De>>2]|0;De=c[l>>2]|0;l=(De-(c[we>>2]|0)<<3)+(32-Fe)|0;we=c[Ce>>2]|0;c[Ce>>2]=l;Ce=f+13664|0;c[Ce>>2]=(c[Ce>>2]|0)-we+l;gg=Fe;hg=De}do{if(Ge){De=f+784|0;if((c[f+14220>>2]|0)!=0){Fe=d[1347633+(ne<<1)|0]|0;l=d[1347632+(ne<<1)|0]|0;we=De|0;Ce=c[we>>2]|0;se=f+788|0;if((gg|0)>(Fe|0)){Kg=gg;Lg=Ce<<Fe|l}else{pe=f+796|0;xe=hg;y=je(l>>>((Fe-gg|0)>>>0)|Ce<<gg|0)|0;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;c[pe>>2]=(c[pe>>2]|0)+4;Kg=gg+32|0;Lg=l}l=Kg-Fe|0;c[we>>2]=Lg;c[se>>2]=l;Mg=l;Ng=se;Og=ne;break}se=ne>>2;l=d[1347633+(se<<1)|0]|0;we=d[1347632+(se<<1)|0]|0;se=De|0;De=c[se>>2]|0;Fe=f+788|0;if((gg|0)>(l|0)){Pg=gg;Qg=De<<l|we;Rg=hg}else{pe=f+796|0;xe=hg;y=je(we>>>((l-gg|0)>>>0)|De<<gg|0)|0;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;xe=(c[pe>>2]|0)+4|0;c[pe>>2]=xe;Pg=gg+32|0;Qg=we;Rg=xe}xe=Pg-l|0;c[se>>2]=Qg;c[Fe>>2]=xe;l=ne&3;if((xe|0)>2){Sg=xe-2|0;Tg=Qg<<2|l}else{we=f+796|0;pe=Rg;y=je(l>>>((2-xe|0)>>>0)|Qg<<xe|0)|0;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;Sg=xe+30|0;Tg=l}c[se>>2]=Tg;c[Fe>>2]=Sg;Mg=Sg;Ng=Fe;Og=ne}else{Mg=gg;Ng=f+788|0;Og=0}}while(0);Fe=f+13684|0;c[Fe>>2]=(c[Fe>>2]|0)+1;Xe=Mg;Ye=re;Ze=Ng;_e=f+796|0;$e=Og;break}do{if(Be){do{if(Ge){Fe=c[f+11736>>2]|0;if((c[f+9984>>2]|0)==0){se=5-Fe|0;l=f+784|0;xe=f+788|0;if((ze|0)>(se|0)){Ug=ze;Vg=ye<<se|3}else{we=je(3>>>((se-ze|0)>>>0)|ye<<ze|0)|0;pe=f+796|0;De=c[pe>>2]|0;y=we;a[De]=y;y=y>>8;a[De+1|0]=y;y=y>>8;a[De+2|0]=y;y=y>>8;a[De+3|0]=y;c[pe>>2]=(c[pe>>2]|0)+4;Ug=ze+32|0;Vg=3}pe=Ug-se|0;c[l>>2]=Vg;c[xe>>2]=pe;if((c[f+14180>>2]|0)!=0){Wg=pe;break}if((pe|0)>2){Xg=pe-2|0;Yg=Vg<<2|2}else{se=je(2>>>((2-pe|0)>>>0)|Vg<<pe|0)|0;De=f+796|0;we=c[De>>2]|0;y=se;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[De>>2]=(c[De>>2]|0)+4;Xg=pe+30|0;Yg=2}c[l>>2]=Yg;c[xe>>2]=Xg;pe=c[f+14236>>2]|0;if((Xg|0)>1){Zg=Xg-1|0;_g=pe|Yg<<1}else{De=je(pe>>>((1-Xg|0)>>>0)|Yg<<Xg|0)|0;we=f+796|0;se=c[we>>2]|0;y=De;a[se]=y;y=y>>8;a[se+1|0]=y;y=y>>8;a[se+2|0]=y;y=y>>8;a[se+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;Zg=Xg+31|0;_g=pe}c[l>>2]=_g;c[xe>>2]=Zg;Wg=Zg;break}do{if((Fe|0)==1){xe=f+784|0;l=f+788|0;if((ze|0)>6){$g=ze-6|0;ah=ye<<6|3}else{pe=je(3>>>((6-ze|0)>>>0)|ye<<ze|0)|0;we=f+796|0;se=c[we>>2]|0;y=pe;a[se]=y;y=y>>8;a[se+1|0]=y;y=y>>8;a[se+2|0]=y;y=y>>8;a[se+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;$g=ze+26|0;ah=3}c[xe>>2]=ah;c[l>>2]=$g;if((c[f+14180>>2]|0)!=0){bh=ah;ch=$g;break}if(($g|0)>2){dh=$g-2|0;eh=ah<<2|2}else{we=je(2>>>((2-$g|0)>>>0)|ah<<$g|0)|0;se=f+796|0;pe=c[se>>2]|0;y=we;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;c[se>>2]=(c[se>>2]|0)+4;dh=$g+30|0;eh=2}c[xe>>2]=eh;c[l>>2]=dh;se=c[f+14236>>2]|0;if((dh|0)>1){fh=dh-1|0;gh=se|eh<<1}else{pe=je(se>>>((1-dh|0)>>>0)|eh<<dh|0)|0;we=f+796|0;De=c[we>>2]|0;y=pe;a[De]=y;y=y>>8;a[De+1|0]=y;y=y>>8;a[De+2|0]=y;y=y>>8;a[De+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;fh=dh+31|0;gh=se}c[xe>>2]=gh;c[l>>2]=fh;bh=gh;ch=fh}else{l=8-Fe|0;xe=f+784|0;se=f+788|0;if((ze|0)>(l|0)){hh=ze;ih=ye<<l|2}else{we=je(2>>>((l-ze|0)>>>0)|ye<<ze|0)|0;De=f+796|0;pe=c[De>>2]|0;y=we;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;c[De>>2]=(c[De>>2]|0)+4;hh=ze+32|0;ih=2}De=hh-l|0;c[xe>>2]=ih;c[se>>2]=De;if((c[f+14180>>2]|0)!=0){bh=ih;ch=De;break}if((De|0)>2){jh=De-2|0;kh=ih<<2|2}else{l=je(2>>>((2-De|0)>>>0)|ih<<De|0)|0;pe=f+796|0;we=c[pe>>2]|0;y=l;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[pe>>2]=(c[pe>>2]|0)+4;jh=De+30|0;kh=2}c[xe>>2]=kh;c[se>>2]=jh;De=c[f+14236>>2]|0;if((jh|0)>1){lh=jh-1|0;mh=De|kh<<1}else{pe=je(De>>>((1-jh|0)>>>0)|kh<<jh|0)|0;we=f+796|0;l=c[we>>2]|0;y=pe;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;lh=jh+31|0;mh=De}c[xe>>2]=mh;c[se>>2]=lh;bh=mh;ch=lh}}while(0);Fe=f+784|0;se=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((ch|0)>5){nh=ch-5|0;oh=se|bh<<5}else{xe=je(se>>>((5-ch|0)>>>0)|bh<<ch|0)|0;De=f+796|0;we=c[De>>2]|0;y=xe;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[De>>2]=(c[De>>2]|0)+4;nh=ch+27|0;oh=se}c[Fe>>2]=oh;c[f+788>>2]=nh;Wg=nh;break}else{De=d[1062808+se|0]|0;if((ch|0)>5){ph=ch-5|0;qh=De|bh<<5}else{se=je(De>>>((5-ch|0)>>>0)|bh<<ch|0)|0;we=f+796|0;xe=c[we>>2]|0;y=se;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;ph=ch+27|0;qh=De}c[Fe>>2]=qh;c[f+788>>2]=ph;Wg=ph;break}}else{Fe=5-(c[f+11736>>2]|0)|0;De=f+784|0;we=f+788|0;if((ze|0)>(Fe|0)){rh=ze;sh=ye<<Fe|2}else{xe=je(2>>>((Fe-ze|0)>>>0)|ye<<ze|0)|0;se=f+796|0;l=c[se>>2]|0;y=xe;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[se>>2]=(c[se>>2]|0)+4;rh=ze+32|0;sh=2}se=rh-Fe|0;c[De>>2]=sh;c[we>>2]=se;if((c[f+14180>>2]|0)==0){if((se|0)>2){th=se-2|0;uh=sh<<2|2}else{Fe=je(2>>>((2-se|0)>>>0)|sh<<se|0)|0;l=f+796|0;xe=c[l>>2]|0;y=Fe;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;th=se+30|0;uh=2}c[De>>2]=uh;c[we>>2]=th;vh=th}else{vh=se}se=f+9960|0;c[se>>2]=(c[se>>2]|0)-(c[f+9984>>2]|0);Wg=vh}}while(0);ve=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-Wg)|0;se=f+13700|0;we=c[se>>2]|0;c[se>>2]=ve;se=f+13696|0;c[se>>2]=(c[se>>2]|0)-we+ve;ve=f+11736|0;we=c[ve>>2]|0;if((we&1|0)==0){wh=we}else{we=f+11744|0;se=f+11824|0;De=f+11556|0;BRa(f,(c[we>>2]|0)-(c[se>>2]|0)|0,c[De>>2]|0);l=f+11748|0;xe=f+11828|0;BRa(f,(c[l>>2]|0)-(c[xe>>2]|0)|0,c[De>>2]|0);De=c[we>>2]|0;c[f+11832>>2]=De;c[se>>2]=De;De=c[l>>2]|0;c[f+11836>>2]=De;c[xe>>2]=De;De=f+13684|0;c[De>>2]=(c[De>>2]|0)+1;wh=c[ve>>2]|0}if((wh&2|0)==0){break}ve=f+11776|0;De=f+11840|0;xe=f+11560|0;BRa(f,(c[ve>>2]|0)-(c[De>>2]|0)|0,c[xe>>2]|0);l=f+11780|0;se=f+11844|0;BRa(f,(c[l>>2]|0)-(c[se>>2]|0)|0,c[xe>>2]|0);xe=c[ve>>2]|0;c[f+11848>>2]=xe;c[De>>2]=xe;xe=c[l>>2]|0;c[f+11852>>2]=xe;c[se>>2]=xe;xe=f+13688|0;c[xe>>2]=(c[xe>>2]|0)+1}else{do{if(Ge){xe=c[f+11736>>2]|0;if((c[f+9984>>2]|0)==0){se=5-xe|0;l=f+784|0;De=f+788|0;if((ze|0)>(se|0)){xh=ze;yh=ye<<se|3}else{ve=je(3>>>((se-ze|0)>>>0)|ye<<ze|0)|0;we=f+796|0;Fe=c[we>>2]|0;y=ve;a[Fe]=y;y=y>>8;a[Fe+1|0]=y;y=y>>8;a[Fe+2|0]=y;y=y>>8;a[Fe+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;xh=ze+32|0;yh=3}we=xh-se|0;c[l>>2]=yh;c[De>>2]=we;if((c[f+14180>>2]|0)!=0){zh=we;Ah=yh;break}if((we|0)>2){Bh=we-2|0;Ch=yh<<2|1}else{se=je(1>>>((2-we|0)>>>0)|yh<<we|0)|0;Fe=f+796|0;ve=c[Fe>>2]|0;y=se;a[ve]=y;y=y>>8;a[ve+1|0]=y;y=y>>8;a[ve+2|0]=y;y=y>>8;a[ve+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;Bh=we+30|0;Ch=1}c[l>>2]=Ch;c[De>>2]=Bh;we=c[f+14236>>2]|0;if((Bh|0)>1){Dh=Bh-1|0;Eh=we|Ch<<1}else{Fe=je(we>>>((1-Bh|0)>>>0)|Ch<<Bh|0)|0;ve=f+796|0;se=c[ve>>2]|0;y=Fe;a[se]=y;y=y>>8;a[se+1|0]=y;y=y>>8;a[se+2|0]=y;y=y>>8;a[se+3|0]=y;c[ve>>2]=(c[ve>>2]|0)+4;Dh=Bh+31|0;Eh=we}c[l>>2]=Eh;c[De>>2]=Dh;zh=Dh;Ah=Eh;break}do{if((xe|0)==1){De=f+784|0;l=f+788|0;if((ze|0)>6){Fh=ze-6|0;Gh=ye<<6|3}else{we=je(3>>>((6-ze|0)>>>0)|ye<<ze|0)|0;ve=f+796|0;se=c[ve>>2]|0;y=we;a[se]=y;y=y>>8;a[se+1|0]=y;y=y>>8;a[se+2|0]=y;y=y>>8;a[se+3|0]=y;c[ve>>2]=(c[ve>>2]|0)+4;Fh=ze+26|0;Gh=3}c[De>>2]=Gh;c[l>>2]=Fh;if((c[f+14180>>2]|0)!=0){Hh=Gh;Ih=Fh;break}if((Fh|0)>2){Jh=Fh-2|0;Kh=Gh<<2|1}else{ve=je(1>>>((2-Fh|0)>>>0)|Gh<<Fh|0)|0;se=f+796|0;we=c[se>>2]|0;y=ve;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[se>>2]=(c[se>>2]|0)+4;Jh=Fh+30|0;Kh=1}c[De>>2]=Kh;c[l>>2]=Jh;se=c[f+14236>>2]|0;if((Jh|0)>1){Lh=Jh-1|0;Mh=se|Kh<<1}else{we=je(se>>>((1-Jh|0)>>>0)|Kh<<Jh|0)|0;ve=f+796|0;Fe=c[ve>>2]|0;y=we;a[Fe]=y;y=y>>8;a[Fe+1|0]=y;y=y>>8;a[Fe+2|0]=y;y=y>>8;a[Fe+3|0]=y;c[ve>>2]=(c[ve>>2]|0)+4;Lh=Jh+31|0;Mh=se}c[De>>2]=Mh;c[l>>2]=Lh;Hh=Mh;Ih=Lh}else{l=8-xe|0;De=f+784|0;se=f+788|0;if((ze|0)>(l|0)){Nh=ze;Oh=ye<<l|2}else{ve=je(2>>>((l-ze|0)>>>0)|ye<<ze|0)|0;Fe=f+796|0;we=c[Fe>>2]|0;y=ve;a[we]=y;y=y>>8;a[we+1|0]=y;y=y>>8;a[we+2|0]=y;y=y>>8;a[we+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;Nh=ze+32|0;Oh=2}Fe=Nh-l|0;c[De>>2]=Oh;c[se>>2]=Fe;if((c[f+14180>>2]|0)!=0){Hh=Oh;Ih=Fe;break}if((Fe|0)>2){Ph=Fe-2|0;Qh=Oh<<2|1}else{l=je(1>>>((2-Fe|0)>>>0)|Oh<<Fe|0)|0;we=f+796|0;ve=c[we>>2]|0;y=l;a[ve]=y;y=y>>8;a[ve+1|0]=y;y=y>>8;a[ve+2|0]=y;y=y>>8;a[ve+3|0]=y;c[we>>2]=(c[we>>2]|0)+4;Ph=Fe+30|0;Qh=1}c[De>>2]=Qh;c[se>>2]=Ph;Fe=c[f+14236>>2]|0;if((Ph|0)>1){Rh=Ph-1|0;Sh=Fe|Qh<<1}else{we=je(Fe>>>((1-Ph|0)>>>0)|Qh<<Ph|0)|0;ve=f+796|0;l=c[ve>>2]|0;y=we;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[ve>>2]=(c[ve>>2]|0)+4;Rh=Ph+31|0;Sh=Fe}c[De>>2]=Sh;c[se>>2]=Rh;Hh=Sh;Ih=Rh}}while(0);xe=f+784|0;se=c[f+9960>>2]|0;if((c[f+14192>>2]|0)==0){if((Ih|0)>5){Th=Ih-5|0;Uh=se|Hh<<5}else{De=je(se>>>((5-Ih|0)>>>0)|Hh<<Ih|0)|0;Fe=f+796|0;ve=c[Fe>>2]|0;y=De;a[ve]=y;y=y>>8;a[ve+1|0]=y;y=y>>8;a[ve+2|0]=y;y=y>>8;a[ve+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;Th=Ih+27|0;Uh=se}c[xe>>2]=Uh;c[f+788>>2]=Th;zh=Th;Ah=Uh;break}else{Fe=d[1062808+se|0]|0;if((Ih|0)>5){Vh=Ih-5|0;Wh=Fe|Hh<<5}else{se=je(Fe>>>((5-Ih|0)>>>0)|Hh<<Ih|0)|0;ve=f+796|0;De=c[ve>>2]|0;y=se;a[De]=y;y=y>>8;a[De+1|0]=y;y=y>>8;a[De+2|0]=y;y=y>>8;a[De+3|0]=y;c[ve>>2]=(c[ve>>2]|0)+4;Vh=Ih+27|0;Wh=Fe}c[xe>>2]=Wh;c[f+788>>2]=Vh;zh=Vh;Ah=Wh;break}}else{xe=5-(c[f+11736>>2]|0)|0;Fe=f+784|0;ve=f+788|0;if((ze|0)>(xe|0)){Xh=ze;Yh=ye<<xe|2}else{De=je(2>>>((xe-ze|0)>>>0)|ye<<ze|0)|0;se=f+796|0;l=c[se>>2]|0;y=De;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[se>>2]=(c[se>>2]|0)+4;Xh=ze+32|0;Yh=2}se=Xh-xe|0;c[Fe>>2]=Yh;c[ve>>2]=se;if((se|0)>2){Zh=se-2|0;_h=Yh<<2|1}else{xe=je(1>>>((2-se|0)>>>0)|Yh<<se|0)|0;l=f+796|0;De=c[l>>2]|0;y=xe;a[De]=y;y=y>>8;a[De+1|0]=y;y=y>>8;a[De+2|0]=y;y=y>>8;a[De+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;Zh=se+30|0;_h=1}c[Fe>>2]=_h;c[ve>>2]=Zh;ve=f+9960|0;c[ve>>2]=(c[ve>>2]|0)-(c[f+9984>>2]|0);zh=Zh;Ah=_h}}while(0);ve=f+788|0;Fe=f+796|0;se=c[Fe>>2]|0;l=(se-(c[f+792>>2]|0)<<3)+(32-zh)|0;De=f+13700|0;xe=c[De>>2]|0;c[De>>2]=l;De=f+13696|0;c[De>>2]=(c[De>>2]|0)-xe+l;l=f+11736|0;xe=c[l>>2]|0;if((xe&1|0)==0){$h=xe}else{xe=f+784|0;De=f+11556|0;we=c[f+11808>>2]|0;if((zh|0)>1){ai=zh-1|0;bi=we|Ah<<1}else{pe=se;y=je(we>>>((1-zh|0)>>>0)|Ah<<zh|0)|0;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;ai=zh+31|0;bi=we}c[xe>>2]=bi;c[ve>>2]=ai;we=f+11744|0;pe=f+11824|0;BRa(f,(c[we>>2]|0)-(c[pe>>2]|0)|0,c[De>>2]|0);se=f+11748|0;Ce=f+11828|0;BRa(f,(c[se>>2]|0)-(c[Ce>>2]>>1)|0,c[De>>2]|0);c[pe>>2]=c[we>>2];c[Ce>>2]=c[se>>2]<<1;se=c[f+11812>>2]|0;Ce=c[xe>>2]|0;we=c[ve>>2]|0;if((we|0)>1){ci=we-1|0;di=Ce<<1|se}else{pe=je(se>>>((1-we|0)>>>0)|Ce<<we|0)|0;Ce=c[Fe>>2]|0;y=pe;a[Ce]=y;y=y>>8;a[Ce+1|0]=y;y=y>>8;a[Ce+2|0]=y;y=y>>8;a[Ce+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;ci=we+31|0;di=se}c[xe>>2]=di;c[ve>>2]=ci;xe=f+11752|0;se=f+11832|0;BRa(f,(c[xe>>2]|0)-(c[se>>2]|0)|0,c[De>>2]|0);we=f+11756|0;Ce=f+11836|0;BRa(f,(c[we>>2]|0)-(c[Ce>>2]>>1)|0,c[De>>2]|0);c[se>>2]=c[xe>>2];c[Ce>>2]=c[we>>2]<<1;we=f+13684|0;c[we>>2]=(c[we>>2]|0)+1;$h=c[l>>2]|0}if(($h&2|0)==0){break}l=f+784|0;we=f+11560|0;Ce=c[f+11816>>2]|0;xe=c[l>>2]|0;se=c[ve>>2]|0;if((se|0)>1){ei=se-1|0;fi=xe<<1|Ce}else{De=je(Ce>>>((1-se|0)>>>0)|xe<<se|0)|0;xe=c[Fe>>2]|0;y=De;a[xe]=y;y=y>>8;a[xe+1|0]=y;y=y>>8;a[xe+2|0]=y;y=y>>8;a[xe+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;ei=se+31|0;fi=Ce}c[l>>2]=fi;c[ve>>2]=ei;Ce=f+11776|0;se=f+11840|0;BRa(f,(c[Ce>>2]|0)-(c[se>>2]|0)|0,c[we>>2]|0);xe=f+11780|0;De=f+11844|0;BRa(f,(c[xe>>2]|0)-(c[De>>2]>>1)|0,c[we>>2]|0);c[se>>2]=c[Ce>>2];c[De>>2]=c[xe>>2]<<1;xe=c[f+11820>>2]|0;De=c[l>>2]|0;Ce=c[ve>>2]|0;if((Ce|0)>1){gi=Ce-1|0;hi=De<<1|xe}else{se=je(xe>>>((1-Ce|0)>>>0)|De<<Ce|0)|0;De=c[Fe>>2]|0;y=se;a[De]=y;y=y>>8;a[De+1|0]=y;y=y>>8;a[De+2|0]=y;y=y>>8;a[De+3|0]=y;c[Fe>>2]=(c[Fe>>2]|0)+4;gi=Ce+31|0;hi=xe}c[l>>2]=hi;c[ve>>2]=gi;ve=f+11784|0;l=f+11848|0;BRa(f,(c[ve>>2]|0)-(c[l>>2]|0)|0,c[we>>2]|0);xe=f+11788|0;Ce=f+11852|0;BRa(f,(c[xe>>2]|0)-(c[Ce>>2]>>1)|0,c[we>>2]|0);c[l>>2]=c[ve>>2];c[Ce>>2]=c[xe>>2]<<1;xe=f+13688|0;c[xe>>2]=(c[xe>>2]|0)+1}}while(0);Be=f+788|0;xe=c[Be>>2]|0;Ce=f+796|0;ve=c[Ce>>2]|0;l=(ve-(c[f+792>>2]|0)<<3)+(32-xe)|0;we=f+13700|0;Fe=c[we>>2]|0;c[we>>2]=l;we=f+13664|0;c[we>>2]=(c[we>>2]|0)-Fe+l;if(!Ge){Xe=xe;Ye=re;Ze=Be;_e=Ce;$e=0;break}l=f+784|0;if((c[f+14220>>2]|0)!=0){Fe=d[1347633+(ne<<1)|0]|0;we=d[1347632+(ne<<1)|0]|0;De=l|0;se=c[De>>2]|0;if((xe|0)>(Fe|0)){ii=xe;ji=se<<Fe|we}else{pe=ve;y=je(we>>>((Fe-xe|0)>>>0)|se<<xe|0)|0;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;c[Ce>>2]=(c[Ce>>2]|0)+4;ii=xe+32|0;ji=we}we=ii-Fe|0;c[De>>2]=ji;c[Be>>2]=we;Xe=we;Ye=re;Ze=Be;_e=Ce;$e=ne;break}we=ne>>2;De=d[1347633+(we<<1)|0]|0;Fe=d[1347632+(we<<1)|0]|0;we=l|0;l=c[we>>2]|0;if((xe|0)>(De|0)){ki=xe;li=l<<De|Fe;mi=ve}else{pe=ve;y=je(Fe>>>((De-xe|0)>>>0)|l<<xe|0)|0;a[pe]=y;y=y>>8;a[pe+1|0]=y;y=y>>8;a[pe+2|0]=y;y=y>>8;a[pe+3|0]=y;pe=(c[Ce>>2]|0)+4|0;c[Ce>>2]=pe;ki=xe+32|0;li=Fe;mi=pe}pe=ki-De|0;c[we>>2]=li;c[Be>>2]=pe;De=ne&3;if((pe|0)>2){ni=pe-2|0;oi=li<<2|De}else{Fe=mi;y=je(De>>>((2-pe|0)>>>0)|li<<pe|0)|0;a[Fe]=y;y=y>>8;a[Fe+1|0]=y;y=y>>8;a[Fe+2|0]=y;y=y>>8;a[Fe+3|0]=y;c[Ce>>2]=(c[Ce>>2]|0)+4;ni=pe+30|0;oi=De}c[we>>2]=oi;c[Be>>2]=ni;Xe=ni;Ye=re;Ze=Be;_e=Ce;$e=ne}}while(0);ne=f+784|0;ni=f+48|0;oi=f+14196|0;li=0;mi=Xe;while(1){if((1<<7-li&$e|0)==0){pi=mi}else{Xe=g+(li<<7)|0;ki=c[328966]|0;ji=c[f+180+(li<<2)>>2]|0;do{if((c[Ye>>2]|0)==0){ii=b[Xe>>1]|0;gi=ii<<16>>16;if(((ii<<16>>16>-1?gi:-gi|0)|0)!=1){qi=ki;ri=gi;si=-1;ti=0;break}ii=gi>>>31|2;gi=c[ne>>2]|0;if((mi|0)>2){ui=mi-2|0;vi=gi<<2|ii}else{hi=je(gi<<mi|ii>>>((2-mi|0)>>>0)|0)|0;gi=c[_e>>2]|0;y=hi;a[gi]=y;y=y>>8;a[gi+1|0]=y;y=y>>8;a[gi+2|0]=y;y=y>>8;a[gi+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;ui=mi+30|0;vi=ii}c[ne>>2]=vi;c[Ze>>2]=ui;wi=ki;xi=0;yi=1;Kd=859}else{if((li|0)<4){zi=0}else{zi=(li&1)+1|0}ii=b[Xe>>1]|0;gi=f+9860+(zi<<2)|0;hi=ii-(c[gi>>2]|0)|0;ei=hi+255|0;do{if(ei>>>0>510>>>0){if((hi|0)<0){fi=hi*-2|0;$h=(fi&65280|0)==0;Ai=(d[1359664+($h?fi:fi>>>8)|0]|0)+($h?0:8)|0;Bi=hi-1|0}else{$h=hi<<1;fi=($h&65280|0)==0;Ai=(d[1359664+(fi?$h:hi>>>7&16777215)|0]|0)+(fi?0:8)|0;Bi=hi}if((zi|0)==0){fi=(d[1347576+Ai|0]|0)+Ai|0;$h=(e[1347552+(Ai<<1)>>1]<<Ai)+((1<<Ai)-1&Bi)|0;ci=c[ne>>2]|0;if((mi|0)>(fi|0)){Ci=mi;Di=$h|ci<<fi}else{di=je($h>>>((fi-mi|0)>>>0)|ci<<mi|0)|0;ci=c[_e>>2]|0;y=di;a[ci]=y;y=y>>8;a[ci+1|0]=y;y=y>>8;a[ci+2|0]=y;y=y>>8;a[ci+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Ci=mi+32|0;Di=$h}c[ne>>2]=Di;c[Ze>>2]=Ci-fi;break}else{fi=(d[1347616+Ai|0]|0)+Ai|0;$h=(e[1347592+(Ai<<1)>>1]<<Ai)+((1<<Ai)-1&Bi)|0;ci=c[ne>>2]|0;if((mi|0)>(fi|0)){Ei=mi;Fi=$h|ci<<fi}else{di=je($h>>>((fi-mi|0)>>>0)|ci<<mi|0)|0;ci=c[_e>>2]|0;y=di;a[ci]=y;y=y>>8;a[ci+1|0]=y;y=y>>8;a[ci+2|0]=y;y=y>>8;a[ci+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Ei=mi+32|0;Fi=$h}c[ne>>2]=Fi;c[Ze>>2]=Ei-fi;break}}else{if((zi|0)==0){fi=c[5616024+(ei<<2)>>2]|0;$h=fi&255;ci=fi>>>8;fi=c[ne>>2]|0;if((mi|0)>($h|0)){Gi=mi;Hi=fi<<$h|ci}else{di=je(ci>>>(($h-mi|0)>>>0)|fi<<mi|0)|0;fi=c[_e>>2]|0;y=di;a[fi]=y;y=y>>8;a[fi+1|0]=y;y=y>>8;a[fi+2|0]=y;y=y>>8;a[fi+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Gi=mi+32|0;Hi=ci}c[ne>>2]=Hi;c[Ze>>2]=Gi-$h;break}else{$h=c[5618136+(ei<<2)>>2]|0;ci=$h&255;fi=$h>>>8;$h=c[ne>>2]|0;if((mi|0)>(ci|0)){Ii=mi;Ji=$h<<ci|fi}else{di=je(fi>>>((ci-mi|0)>>>0)|$h<<mi|0)|0;$h=c[_e>>2]|0;y=di;a[$h]=y;y=y>>8;a[$h+1|0]=y;y=y>>8;a[$h+2|0]=y;y=y>>8;a[$h+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Ii=mi+32|0;Ji=fi}c[ne>>2]=Ji;c[Ze>>2]=Ii-ci;break}}}while(0);c[gi>>2]=ii;wi=(c[oi>>2]|0)==0?ki:c[328918]|0;xi=0;yi=1;Kd=859}}while(0);while(1){if((Kd|0)==859){Kd=0;if((yi|0)>(ji|0)){break}qi=wi;ri=b[g+(li<<7)+(d[f+368+yi|0]<<1)>>1]|0;si=xi;ti=yi}do{if((ri|0)==0){Ki=si}else{ki=ti-si-1|0;Xe=ri>>31;re=(Xe^ri)-Xe|0;if((re|0)<=(a[5615960+ki|0]|0)){Ge=re-1+(d[5618072+ki|0]|0)|0;ei=e[qi+(Ge<<2)+2>>1]|0;hi=ei+1|0;ci=e[qi+(Ge<<2)>>1]<<1|Xe&1;Xe=c[ne>>2]|0;Ge=c[Ze>>2]|0;if((Ge|0)>(hi|0)){Li=Ge-hi|0;Mi=ci|Xe<<hi}else{fi=je(ci>>>((hi-Ge|0)>>>0)|Xe<<Ge|0)|0;Xe=c[_e>>2]|0;y=fi;a[Xe]=y;y=y>>8;a[Xe+1|0]=y;y=y>>8;a[Xe+2|0]=y;y=y>>8;a[Xe+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Li=31-ei+Ge|0;Mi=ci}c[ne>>2]=Mi;c[Ze>>2]=Li;Ki=ti;break}ci=e[qi+446>>1]|0;Ge=e[qi+444>>1]|0;ei=c[ne>>2]|0;Xe=c[Ze>>2]|0;if((Xe|0)>(ci|0)){Ni=Xe-ci|0;Oi=ei<<ci|Ge}else{fi=je(Ge>>>((ci-Xe|0)>>>0)|ei<<Xe|0)|0;ei=c[_e>>2]|0;y=fi;a[ei]=y;y=y>>8;a[ei+1|0]=y;y=y>>8;a[ei+2|0]=y;y=y>>8;a[ei+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Ni=32-ci+Xe|0;Oi=Ge}c[ne>>2]=Oi;c[Ze>>2]=Ni;if((Ni|0)>6){Pi=Ni-6|0;Qi=Oi<<6|ki}else{Ge=je(ki>>>((6-Ni|0)>>>0)|Oi<<Ni|0)|0;Xe=c[_e>>2]|0;y=Ge;a[Xe]=y;y=y>>8;a[Xe+1|0]=y;y=y>>8;a[Xe+2|0]=y;y=y>>8;a[Xe+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Pi=Ni+26|0;Qi=ki}c[ne>>2]=Qi;c[Ze>>2]=Pi;if((c[ni>>2]|0)!=1){ki=ri&4095;if((Pi|0)>12){Ri=Pi-12|0;Si=Qi<<12|ki}else{Xe=je(ki>>>((12-Pi|0)>>>0)|Qi<<Pi|0)|0;Ge=c[_e>>2]|0;y=Xe;a[Ge]=y;y=y>>8;a[Ge+1|0]=y;y=y>>8;a[Ge+2|0]=y;y=y>>8;a[Ge+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Ri=Pi+20|0;Si=ki}c[ne>>2]=Si;c[Ze>>2]=Ri;Ki=ti;break}if((re|0)<128){re=ri&255;if((Pi|0)>8){Ti=Pi-8|0;Ui=Qi<<8|re}else{ki=je(re>>>((8-Pi|0)>>>0)|Qi<<Pi|0)|0;Ge=c[_e>>2]|0;y=ki;a[Ge]=y;y=y>>8;a[Ge+1|0]=y;y=y>>8;a[Ge+2|0]=y;y=y>>8;a[Ge+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Ti=Pi+24|0;Ui=re}c[ne>>2]=Ui;c[Ze>>2]=Ti;Ki=ti;break}if((ri|0)<0){re=ri+33024|0;if((Pi|0)>16){Vi=Pi-16|0;Wi=Qi<<16|re}else{Ge=je(re>>>((16-Pi|0)>>>0)|Qi<<Pi|0)|0;ki=c[_e>>2]|0;y=Ge;a[ki]=y;y=y>>8;a[ki+1|0]=y;y=y>>8;a[ki+2|0]=y;y=y>>8;a[ki+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Vi=Pi+16|0;Wi=re}c[ne>>2]=Wi;c[Ze>>2]=Vi;Ki=ti;break}else{re=ri&65535;if((Pi|0)>16){Xi=Pi-16|0;Yi=Qi<<16|re}else{ki=je(re>>>((16-Pi|0)>>>0)|Qi<<Pi|0)|0;Ge=c[_e>>2]|0;y=ki;a[Ge]=y;y=y>>8;a[Ge+1|0]=y;y=y>>8;a[Ge+2|0]=y;y=y>>8;a[Ge+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Xi=Pi+16|0;Yi=re}c[ne>>2]=Yi;c[Ze>>2]=Xi;Ki=ti;break}}}while(0);wi=qi;xi=Ki;yi=ti+1|0;Kd=859}ji=e[wi+450>>1]|0;ii=e[wi+448>>1]|0;gi=c[ne>>2]|0;re=c[Ze>>2]|0;if((re|0)>(ji|0)){Zi=re-ji|0;_i=gi<<ji|ii}else{Ge=je(ii>>>((ji-re|0)>>>0)|gi<<re|0)|0;gi=c[_e>>2]|0;y=Ge;a[gi]=y;y=y>>8;a[gi+1|0]=y;y=y>>8;a[gi+2|0]=y;y=y>>8;a[gi+3|0]=y;c[_e>>2]=(c[_e>>2]|0)+4;Zi=32-ji+re|0;_i=ii}c[ne>>2]=_i;c[Ze>>2]=Zi;pi=Zi}ii=li+1|0;if((ii|0)<8){li=ii;mi=pi}else{break}}mi=c[_e>>2]|0;c[n>>2]=0;n=(c[Ye>>2]|0)==0;Ye=(mi-(c[f+792>>2]|0)<<3)+(32-pi)|0;pi=f+13700|0;mi=c[pi>>2]|0;c[pi>>2]=Ye;pi=Ye-mi|0;if(n){n=f+13676|0;c[n>>2]=(c[n>>2]|0)+pi;i=k;return}else{n=f+13672|0;c[n>>2]=(c[n>>2]|0)+pi;i=k;return}}}function yRa(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;hRa(b);if(!(a[1346712]|0)){a[1346712]=1;ATa(1315856,7665240);ATa(1315664,7665630);f=c[328971]|0;g=c[328969]|0;h=0;do{a[5615960+h|0]=a[f+h|0]|0;a[5618072+h|0]=a[g+h|0]|0;h=h+1|0;}while((h|0)<64);zRa(1315856,3561200);if((c[b+14196>>2]|0)==0){i=-255}else{zRa(1315664,3553008);i=-255}do{h=(i|0)>-1?i:-i|0;g=h<<1;f=g>>>0>65535>>>0;j=f?h>>>15&65535:g;g=f?16:0;if((j&65280|0)==0){k=g;l=j}else{k=g|8;l=j>>>8}j=(d[1359664+l|0]|0)+k|0;g=(1<<j)-1&(i>>31)+i;f=i+255|0;c[5616024+(f<<2)>>2]=(d[1347576+j|0]|0)+j+(g+((e[1347552+(j<<1)>>1]|0)<<j)<<8);c[5618136+(f<<2)>>2]=(d[1347616+j|0]|0)+j+(((e[1347592+(j<<1)>>1]|0)<<j)+g<<8);i=i+1|0;}while((i|0)<256);i=a[1347761]|0;k=d[1347793]|0;l=1;while(1){g=l-1|0;j=l+1|0;f=j+k&255;h=-4096;while(1){if((h|0)==0){a[h+4096+(5550248+(l*8193|0))|0]=i;h=h+1|0;continue}m=(((h|0)<0?-h|0:h)-1>>g)+1|0;if((m|0)<17){n=(d[1347761+(m<<1)|0]|0)+l&255}else{n=f}a[h+4096+(5550248+(l*8193|0))|0]=n;h=h+1|0;if((h|0)>=4097){break}}if((j|0)<8){l=j}else{break}}mrc(8832616,7,2048)|0;mrc(8833128,6,1024)|0;mrc(8833384,5,512)|0;mrc(8833512,4,256)|0;mrc(8833576,3,128)|0;mrc(8833608,2,64)|0;mrc(8833624,1,32)|0}c[b+12460>>2]=5550248;c[b+11856>>2]=8829544;l=b+13080|0;if((c[b+48>>2]|0)==1){c[l>>2]=-255;c[b+13084>>2]=255}else{c[l>>2]=-2047;c[b+13084>>2]=2047}l=b+13096|0;if((c[b+14196>>2]|0)==0){c[l>>2]=3561200;c[b+13092>>2]=3561200;o=b+13104|0;c[o>>2]=3561200;p=b+13100|0;c[p>>2]=3561200;return}else{c[l>>2]=3553008;c[b+13092>>2]=3553008;o=b+13104|0;c[o>>2]=3561200;p=b+13100|0;c[p>>2]=3561200;return}}function zRa(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=e+28|0;h=e+8|0;i=e+20|0;e=0;do{j=e-64|0;if((j|0)!=0){k=(j|0)>-1?j:64-e|0;j=k-1|0;if((k|0)<128){l=0;do{do{if((k|0)>(a[(c[g>>2]|0)+l|0]|0)){m=c[h>>2]|0;n=8}else{o=j+(d[(c[i>>2]|0)+l|0]|0)|0;p=c[h>>2]|0;if((o|0)>=111){m=p;n=8;break}q=(b[p+(o<<2)+2>>1]&255)+1&255}}while(0);if((n|0)==8){n=0;q=(b[m+446>>1]&255)+14&255}a[f+((l<<7)+e)|0]=q;l=l+1|0;}while((l|0)<64)}else{l=0;do{do{if((k|0)>(a[(c[g>>2]|0)+l|0]|0)){r=c[h>>2]|0;n=14}else{o=j+(d[(c[i>>2]|0)+l|0]|0)|0;p=c[h>>2]|0;if((o|0)>=111){r=p;n=14;break}s=(b[p+(o<<2)+2>>1]&255)+1&255}}while(0);if((n|0)==14){n=0;s=(b[r+446>>1]&255)+22&255}a[f+((l<<7)+e)|0]=s;l=l+1|0;}while((l|0)<64)}}e=e+1|0;}while((e|0)<128);return}function ARa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;b=i;i=i+40|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=b+32|0;j=h;k=c[a+60>>2]|0;do{if((c[a+48>>2]|0)==1){if((c[a+124>>2]|0)<=2800){break}c[a+808>>2]=1}}while(0);if((bUa(a)|0)<0){l=-1;i=b;return l|0}m=d;n=g;c[d>>2]=0;c[d+4>>2]=0;o=k+4|0;p=c[o>>2]|0;q=c[p+104>>2]|0;r=f|0;c[r>>2]=c[p+108>>2];p=f+4|0;c[p>>2]=q;q=e|0;s=e+4|0;t=k+48|0;u=d;v=k+10012|0;w=k+10016|0;x=k+10020|0;y=1;do{c[q>>2]=1;z=1347880+(y<<3)|0;do{c[s>>2]=1;do{yKb(n,e,z);A=c[s>>2]|0;do{if((c[t>>2]|0)==2){B=c[q>>2]|0;C=(A|0)<0|0?-1:0;D=A;E=(B|0)<0|0?-1:0;F=B;H=12}else{if((A|0)!=1){break}if((c[q>>2]|0)==1){C=0;D=1;E=0;F=1;H=12}}}while(0);a:do{if((H|0)==12){H=0;A=TIb(D,C,F,E)|0;if(!((A|0)==1&(G|0)==0)){break}do{if((c[u>>2]|0)!=0){if((BKb(f,m,n)|0)<0){break}if((c[q>>2]|0)!=1){break a}if((c[s>>2]|0)!=1){break a}if((BKb(f,m,n)|0)!=0){break a}}}while(0);A=c[g+4>>2]|0;c[d>>2]=c[g>>2];c[d+4>>2]=A;c[v>>2]=y;c[w>>2]=c[q>>2];c[x>>2]=c[s>>2]}}while(0);A=(c[s>>2]|0)+1|0;c[s>>2]=A;}while((A|0)<33);A=(c[q>>2]|0)+1|0;c[q>>2]=A;}while((A|0)<5);y=y+1|0;if((y|0)>=14){break}}while(!((c[(c[o>>2]|0)+680>>2]|0)>-1&(y|0)>8));y=c[r>>2]|0;r=c[p>>2]|0;p=c[u>>2]|0;u=c[m+4>>2]|0;m=Erc(u,(u|0)<0|0?-1:0,y,(y|0)<0|0?-1:0)|0;q=G;s=Erc(p,(p|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;x=G;do{if((m|0)==(s|0)&(q|0)==(x|0)){if(!((u|0)==0|(r|0)==0)){I=0;break}if((y|0)==0|(p|0)==0){I=-2147483648;break}I=(y>>31)-(p>>31)|0}else{xrc(m,q,s,x)|0;w=G^((u^r|0)<0|0?-1:0);((w|0)<0|0?-1:0)>>31|((w|0)<0|0?-1:0)<<1;I=w>>31|((w|0)<0|0?-1:0)<<1|1}}while(0);do{if((I|0)!=0){r=a;u=c[a+108>>2]|0;x=c[a+104>>2]|0;if(!((c[k+80>>2]|0)>-2)){KIb(r,32,2312792,(J=i,i=i+16|0,c[J>>2]=u,c[J+8>>2]=x,J)|0);i=J;break}KIb(r,16,2317344,(J=i,i=i+16|0,c[J>>2]=u,c[J+8>>2]=x,J)|0);i=J;l=-1;i=b;return l|0}}while(0);I=a+840|0;x=c[I>>2]|0;u=(c[a+844>>2]|0)==-99;do{if((x|0)==-99){if(u){r=(c[k+14212>>2]|0)==1?4:0;c[I>>2]=r;K=r;H=38;break}KIb(a,16,2308120,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;l=-1;i=b;return l|0}else{if(u){K=x;H=38;break}L=c[a+120>>2]|0}}while(0);b:do{if((H|0)==38){x=a+844|0;do{if((K|0)==0){u=c[a+120>>2]|0;do{if((u|0)<721){if((c[a+124>>2]|0)>=609){break}c[x>>2]=5;L=u;break b}}while(0);c[x>>2]=2;L=u;break b}else if((K|0)!=1){if((c[k+14212>>2]|0)==1){break}KIb(a,16,2303072,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;l=-1;i=b;return l|0}}while(0);I=c[a+120>>2]|0;do{if((I|0)<721){if((c[a+124>>2]|0)>=577){break}c[x>>2]=8;L=I;break b}else{if((I|0)<1441){break}c[x>>2]=4;L=I;break b}}while(0);c[x>>2]=6;L=I}}while(0);K=(L&4095|0)==0;do{if(K){if((c[a+124>>2]&4095|0)!=1){break}KIb(a,16,2291824,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;l=-22;i=b;return l|0}}while(0);do{if((c[k+80>>2]|0)>-1){if(!K){if((c[a+124>>2]&4095|0)!=0){break}}KIb(a,16,2284992,(J=i,i=i+8|0,c[J>>2]=-1,J)|0);i=J;l=-22;i=b;return l|0}}while(0);K=k+14244|0;if((c[K>>2]|0)==0){L=c[a+92>>2]&8192;r=L>>>13;c[K>>2]=r;if((L|0)==0){M=r}else{N=r;H=61}}else{c[K>>2]=1;N=1;H=61}if((H|0)==61){H=k+14264|0;c[H>>2]=c[H>>2]|1;M=N}do{if((M|0)!=0){if((c[v>>2]|0)==4){break}KIb(a,16,2281016,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;l=-1;i=b;return l|0}}while(0);J=k+14256|0;if((c[J>>2]|0)==0){a=(c[o>>2]|0)+616|0;c[a>>2]=0;c[a+4>>2]=0;l=0;i=b;return l|0}a=1347880+(c[v>>2]<<3)|0;v=c[a+4>>2]|0;c[h>>2]=c[a>>2];c[h+4>>2]=v;v=k+14260|0;h=sLb(v,j,c[J>>2]|0,k)|0;if((h|0)<0){l=h;i=b;return l|0}c[K>>2]=c[k+14264>>2]&1;k=c[v>>2]|0;v=(c[o>>2]|0)+616|0;c[v>>2]=k;c[v+4>>2]=(k|0)<0|0?-1:0;l=0;i=b;return l|0}function BRa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;if((e|0)==0){g=d[1347761]|0;h=d[1347760]|0;i=b+784|0;j=c[i>>2]|0;k=b+788|0;l=c[k>>2]|0;if((l|0)>(g|0)){m=l-g|0;n=j<<g|h}else{o=je(h>>>((g-l|0)>>>0)|j<<l|0)|0;j=b+796|0;p=c[j>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;m=32-g+l|0;n=h}c[i>>2]=n;c[k>>2]=m;return}m=f-1|0;k=1<<m;n=28-f|0;i=e<<n>>n;if((i|0)>-1){n=i-1|0;q=n;r=n&k-1;s=0}else{n=~i;q=n;r=k-1&n;s=1}n=(q>>m)+1|0;q=d[1347761+(n<<1)|0]|0;k=d[1347760+(n<<1)|0]|0;n=b+784|0;i=c[n>>2]|0;e=b+788|0;h=c[e>>2]|0;if((h|0)>(q|0)){t=h-q|0;u=i<<q|k}else{l=je(k>>>((q-h|0)>>>0)|i<<h|0)|0;i=b+796|0;g=c[i>>2]|0;y=l;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;t=32-q+h|0;u=k}c[n>>2]=u;c[e>>2]=t;if((t|0)>1){v=t-1|0;w=u<<1|s}else{k=je(s>>>((1-t|0)>>>0)|u<<t|0)|0;u=b+796|0;h=c[u>>2]|0;y=k;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+31|0;w=s}c[n>>2]=w;c[e>>2]=v;if((m|0)<=0){return}if((v|0)>(m|0)){x=v-m|0;z=w<<m|r}else{s=je(w<<v|r>>>((m-v|0)>>>0)|0)|0;m=b+796|0;b=c[m>>2]|0;y=s;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;x=33-f+v|0;z=r}c[n>>2]=z;c[e>>2]=x;return}function CRa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;if((e|0)<1){g=-1094995529;return g|0}h=e>>>0>2147483639>>>0|(b|0)==0;i=h?0:b;b=h?0:e;e=b+8|0;if(h){g=-1094995529;return g|0}h=i;j=(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>3&31;h=e>>>0>5>>>0?5:e;if((j|0)==31){k=i+(h>>>3)|0;l=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(h&7)>>>26;k=h+6|0;m=l+32|0;n=e>>>0>k>>>0?k:e}else{m=j;n=h}h=a|0;c[h>>2]=m;j=i+(n>>>3)|0;k=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(n&7)>>>28;j=n+4|0;n=e>>>0>j>>>0?j:e;c[a+4>>2]=k;if((k|0)==15){j=i+(n>>>3)|0;l=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(n&7)>>>8;j=n+24|0;o=l;p=e>>>0>j>>>0?j:e}else{o=c[1965112+(k<<2)>>2]|0;p=n}n=a+8|0;c[n>>2]=o;k=i+(p>>>3)|0;j=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(p&7);k=j>>>28;l=p+4|0;p=e>>>0>l>>>0?l:e;l=a+12|0;c[l>>2]=k;if((j|0)>-1){c[a+36>>2]=d[1343560+k|0]|0}k=a+16|0;c[k>>2]=-1;j=a+40|0;c[j>>2]=-1;do{if((m|0)==5){q=-1;r=i+(p>>>3)|0;s=p&7;t=14}else if((m|0)==29){u=i+(p>>>3)|0;v=p&7;w=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<v;if((w&1610612736|0)!=0&(w&528482304|0)==0){t=21;break}c[j>>2]=1;q=1;r=u;s=v;t=14}else{t=21}}while(0);do{if((t|0)==14){c[a+20>>2]=5;c[k>>2]=1;v=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<s>>>28;u=p+4|0;w=e>>>0>u>>>0?u:e;c[a+24>>2]=v;if((v|0)==15){u=i+(w>>>3)|0;x=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(w&7)>>>8;u=w+24|0;y=x;z=e>>>0>u>>>0?u:e}else{y=c[1965112+(v<<2)>>2]|0;z=w}c[a+28>>2]=y;w=i+(z>>>3)|0;v=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(z&7)>>>27;w=z+5|0;u=e>>>0>w>>>0?w:e;if((v|0)==31){w=i+(u>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>26;w=u+6|0;A=x+32|0;B=e>>>0>w>>>0?w:e}else{A=v;B=u}c[h>>2]=A;if((A|0)!=22){C=B;D=A;E=5;F=1;G=q;t=22;break}u=i+(B>>>3)|0;v=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(B&7)>>>28;u=B+4|0;c[a+32>>2]=v;H=e>>>0>u>>>0?u:e;I=22;J=q;t=50}else if((t|0)==21){c[a+20>>2]=0;c[a+28>>2]=0;C=p;D=m;E=0;F=-1;G=-1;t=22}}while(0);a:do{if((t|0)==22){if((D|0)==36){m=C+5|0;p=e>>>0>m>>>0?m:e;m=i+(p>>>3)|0;if(((je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)&-256|0)==1095521024){K=p}else{m=-p|0;q=e-p|0;if((m|0)>24){L=m}else{L=(q|0)<24?q:24}K=L+p|0}if((b-K|0)<112){g=-1;return g|0}p=i+(K>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(K&7)&-65536;p=K+16|0;m=e>>>0>p>>>0?p:e;p=i+(m>>>3)|0;B=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>16;p=m+16|0;m=e>>>0>p>>>0?p:e;if((B|q|0)!=1095521024){g=-1;return g|0}q=i+(m>>>3)|0;B=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(m&7)&-65536;q=m+16|0;m=e>>>0>q>>>0?q:e;q=i+(m>>>3)|0;p=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(m&7)>>>16;q=m+16|0;m=e>>>0>q>>>0?q:e;q=p|B;c[n>>2]=q;B=-m|0;p=e-m|0;if((B|0)>32){M=B}else{M=(p|0)<32?p:32}p=M+m|0;c[l>>2]=0;m=i+(p>>>3)|0;B=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>16;m=p+16|0;c[a+36>>2]=B+1;N=K;O=e>>>0>m>>>0?m:e;P=q}else{N=C;O=C;P=o}q=a+20|0;if((E|0)==5|(f|0)==0){H=N;I=D;J=G;t=50;break}if((b-O|0)>15){Q=O}else{H=N;I=D;J=G;t=50;break}while(1){m=i+(Q>>>3)|0;if(((je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(Q&7)&-2097152|0)==1457520640){break}m=((Q|0)<(e|0))+Q|0;if((b-m|0)>15){Q=m}else{H=N;I=D;J=G;t=50;break a}}m=Q+11|0;B=e>>>0>m>>>0?m:e;m=i+(B>>>3)|0;p=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>27;m=B+5|0;B=e>>>0>m>>>0?m:e;if((p|0)==31){m=i+(B>>>3)|0;A=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>26;m=B+6|0;R=A+32|0;S=e>>>0>m>>>0?m:e}else{R=p;S=B}c[q>>2]=R;do{if((R|0)==5){B=((S|0)<(e|0))+S|0;p=(d[i+(S>>>3)|0]|0)<<(S&7)>>>7&1;c[k>>2]=p;if((p|0)==0){T=B;U=0;break}m=i+(B>>>3)|0;A=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>28;m=B+4|0;B=e>>>0>m>>>0?m:e;c[a+24>>2]=A;if((A|0)==15){m=i+(B>>>3)|0;h=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>8;m=B+24|0;V=h;W=e>>>0>m>>>0?m:e}else{V=c[1965112+(A<<2)>>2]|0;W=B}c[a+28>>2]=V;if((V|0)!=(P|0)){T=W;U=p;break}c[k>>2]=-1;T=W;U=-1}else{T=S;U=F}}while(0);do{if((b-T|0)>11){q=i+(T>>>3)|0;p=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(T&7);q=T+11|0;B=e>>>0>q>>>0?q:e;if(!((p&-2097152|0)==-1459617792)){X=G;break}p=(d[i+(B>>>3)|0]|0)<<(B&7)>>>7&1;c[j>>2]=p;X=p}else{X=G}}while(0);if((U|0)!=0){H=N;I=D;J=X;t=50;break}c[j>>2]=0;Y=N;t=51}}while(0);if((t|0)==50){if((J|0)!=-1|(I|0)==2){Y=H;t=51}else{Z=H}}do{if((t|0)==51){if((c[a+36>>2]|0)>>>0>1>>>0){Z=Y;break}else{g=Y}return g|0}}while(0);c[j>>2]=0;g=Z;return g|0}function DRa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;f=b+4|0;g=c[f>>2]|0;h=b+8|0;i=b+12|0;j=c[i>>2]|0;k=j;l=c[h>>2]|0;m=e+8|0;n=c[m>>2]|0;o=e+16|0;p=c[o>>2]|0;q=e|0;e=c[q>>2]|0;r=e+(n>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(n&7)>>>22;r=n+10|0;c[m>>2]=p>>>0>r>>>0?r:p;p=b|0;r=c[p>>2]|0;n=c[f>>2]|0;if((n|0)>10){t=n-10|0;u=r<<10|s;v=e;w=j}else{e=j;y=je(s>>>((10-n|0)>>>0)|r<<n|0)|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=(c[i>>2]|0)+4|0;c[i>>2]=e;t=n+22|0;u=s;v=c[q>>2]|0;w=e}c[p>>2]=u;c[f>>2]=t;t=c[m>>2]|0;u=c[o>>2]|0;e=v+(t>>>3)|0;s=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(t&7)>>>28;e=t+4|0;c[m>>2]=u>>>0>e>>>0?e:u;u=c[p>>2]|0;e=c[f>>2]|0;if((e|0)>4){x=e-4|0;z=u<<4|s;A=v;B=w}else{v=w;y=je(s>>>((4-e|0)>>>0)|u<<e|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;v=(c[i>>2]|0)+4|0;c[i>>2]=v;x=e+28|0;z=s;A=c[q>>2]|0;B=v}c[p>>2]=z;c[f>>2]=x;x=c[m>>2]|0;z=c[o>>2]|0;v=A+(x>>>3)|0;e=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(x&7)>>>28;v=x+4|0;c[m>>2]=z>>>0>v>>>0?v:z;z=c[p>>2]|0;v=c[f>>2]|0;if((v|0)>4){C=v-4|0;D=z<<4|e;E=A;F=B}else{A=B;y=je(e>>>((4-v|0)>>>0)|z<<v|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;A=(c[i>>2]|0)+4|0;c[i>>2]=A;C=v+28|0;D=e;E=c[q>>2]|0;F=A}c[p>>2]=D;c[f>>2]=C;C=c[m>>2]|0;D=c[o>>2]|0;A=E+(C>>>3)|0;v=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(C&7)>>>28;A=C+4|0;c[m>>2]=D>>>0>A>>>0?A:D;D=c[p>>2]|0;A=c[f>>2]|0;if((A|0)>4){G=A-4|0;H=D<<4|v;I=E;J=F}else{E=F;y=je(v>>>((4-A|0)>>>0)|D<<A|0)|0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;E=(c[i>>2]|0)+4|0;c[i>>2]=E;G=A+28|0;H=v;I=c[q>>2]|0;J=E}c[p>>2]=H;c[f>>2]=G;G=c[m>>2]|0;H=c[o>>2]|0;E=I+(G>>>3)|0;A=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(G&7)>>>30;E=G+2|0;c[m>>2]=H>>>0>E>>>0?E:H;H=c[p>>2]|0;E=c[f>>2]|0;if((E|0)>2){K=E-2|0;L=H<<2|A;M=I;N=J}else{I=J;y=je(A>>>((2-E|0)>>>0)|H<<E|0)|0;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;I=(c[i>>2]|0)+4|0;c[i>>2]=I;K=E+30|0;L=A;M=c[q>>2]|0;N=I}c[p>>2]=L;c[f>>2]=K;K=c[m>>2]|0;L=c[o>>2]|0;I=M+(K>>>3)|0;E=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(K&7)>>>29;I=K+3|0;c[m>>2]=L>>>0>I>>>0?I:L;L=c[p>>2]|0;I=c[f>>2]|0;if((I|0)>3){O=I-3|0;P=L<<3|E;Q=M;R=N}else{M=N;y=je(E>>>((3-I|0)>>>0)|L<<I|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;M=(c[i>>2]|0)+4|0;c[i>>2]=M;O=I+29|0;P=E;Q=c[q>>2]|0;R=M}c[p>>2]=P;c[f>>2]=O;O=E+A|0;A=c[m>>2]|0;E=c[o>>2]|0;P=Q+(A>>>3)|0;M=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(A&7)>>>28;P=A+4|0;c[m>>2]=E>>>0>P>>>0?P:E;E=c[p>>2]|0;P=c[f>>2]|0;if((P|0)>4){S=P-4|0;T=E<<4|M;U=Q;V=R}else{Q=R;y=je(M>>>((4-P|0)>>>0)|E<<P|0)|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=(c[i>>2]|0)+4|0;c[i>>2]=Q;S=P+28|0;T=M;U=c[q>>2]|0;V=Q}c[p>>2]=T;c[f>>2]=S;S=e+s+v+M|0;M=c[m>>2]|0;v=c[o>>2]|0;s=U+(M>>>3)|0;U=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(M&7)>>>31;s=M+1|0;c[m>>2]=v>>>0>s>>>0?s:v;v=c[p>>2]|0;s=c[f>>2]|0;if((s|0)>1){W=s-1|0;X=v<<1|U;Y=V}else{M=V;y=je(U>>>((1-s|0)>>>0)|v<<s|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;M=(c[i>>2]|0)+4|0;c[i>>2]=M;W=s+31|0;X=U;Y=M}c[p>>2]=X;c[f>>2]=W;if((U|0)==0){Z=Y}else{U=c[m>>2]|0;W=c[o>>2]|0;X=(c[q>>2]|0)+(U>>>3)|0;M=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(U&7)>>>28;X=U+4|0;c[m>>2]=W>>>0>X>>>0?X:W;W=c[p>>2]|0;X=c[f>>2]|0;if((X|0)>4){_=X-4|0;$=W<<4|M;aa=Y}else{U=Y;y=je(M>>>((4-X|0)>>>0)|W<<X|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=(c[i>>2]|0)+4|0;c[i>>2]=U;_=X+28|0;$=M;aa=U}c[p>>2]=$;c[f>>2]=_;Z=aa}aa=c[m>>2]|0;_=c[o>>2]|0;$=(c[q>>2]|0)+(aa>>>3)|0;U=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(aa&7)>>>31;$=aa+1|0;c[m>>2]=_>>>0>$>>>0?$:_;_=c[p>>2]|0;$=c[f>>2]|0;if(($|0)>1){ba=$-1|0;ca=_<<1|U;da=Z}else{aa=Z;y=je(U>>>((1-$|0)>>>0)|_<<$|0)|0;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;aa=(c[i>>2]|0)+4|0;c[i>>2]=aa;ba=$+31|0;ca=U;da=aa}c[p>>2]=ca;c[f>>2]=ba;if((U|0)==0){ea=da}else{U=c[m>>2]|0;ba=c[o>>2]|0;ca=(c[q>>2]|0)+(U>>>3)|0;aa=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(U&7)>>>28;ca=U+4|0;c[m>>2]=ba>>>0>ca>>>0?ca:ba;ba=c[p>>2]|0;ca=c[f>>2]|0;if((ca|0)>4){fa=ca-4|0;ga=ba<<4|aa;ha=da}else{U=da;y=je(aa>>>((4-ca|0)>>>0)|ba<<ca|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=(c[i>>2]|0)+4|0;c[i>>2]=U;fa=ca+28|0;ga=aa;ha=U}c[p>>2]=ga;c[f>>2]=fa;ea=ha}ha=c[m>>2]|0;fa=c[o>>2]|0;ga=(c[q>>2]|0)+(ha>>>3)|0;U=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ha&7)>>>31;ga=ha+1|0;c[m>>2]=fa>>>0>ga>>>0?ga:fa;fa=c[p>>2]|0;ga=c[f>>2]|0;if((ga|0)>1){ia=ga-1|0;ja=fa<<1|U;ka=ea}else{ha=ea;y=je(U>>>((1-ga|0)>>>0)|fa<<ga|0)|0;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;ha=(c[i>>2]|0)+4|0;c[i>>2]=ha;ia=ga+31|0;ja=U;ka=ha}c[p>>2]=ja;c[f>>2]=ia;if((U|0)==0){la=ka}else{U=c[m>>2]|0;ia=c[o>>2]|0;ja=(c[q>>2]|0)+(U>>>3)|0;ha=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(U&7)>>>29;ja=U+3|0;c[m>>2]=ia>>>0>ja>>>0?ja:ia;ia=c[p>>2]|0;ja=c[f>>2]|0;if((ja|0)>3){ma=ja-3|0;na=ia<<3|ha;oa=ka}else{U=ka;y=je(ha>>>((3-ja|0)>>>0)|ia<<ja|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=(c[i>>2]|0)+4|0;c[i>>2]=U;ma=ja+29|0;na=ha;oa=U}c[p>>2]=na;c[f>>2]=ma;la=oa}oa=S*5|0;S=oa+(O<<2)|0;if((S|0)>16){ma=O<<2;O=oa+ma|0;na=15-ma-oa|0;U=((na|0)>-17?na:-17)+oa+ma&-16;ma=S;oa=la;while(1){na=c[m>>2]|0;ha=c[o>>2]|0;ja=(c[q>>2]|0)+(na>>>3)|0;ia=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(na&7)>>>16;ja=na+16|0;c[m>>2]=ha>>>0>ja>>>0?ja:ha;ha=c[p>>2]|0;ja=c[f>>2]|0;if((ja|0)>16){pa=ja-16|0;qa=ha<<16|ia;ra=oa}else{na=oa;y=je(ia>>>((16-ja|0)>>>0)|ha<<ja|0)|0;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;na=(c[i>>2]|0)+4|0;c[i>>2]=na;pa=ja+16|0;qa=ia;ra=na}c[p>>2]=qa;c[f>>2]=pa;na=ma-16|0;if((na|0)>16){ma=na;oa=ra}else{break}}sa=O-16-U|0;ta=ra}else{sa=S;ta=la}if((sa|0)!=0){la=c[m>>2]|0;S=c[o>>2]|0;ra=(c[q>>2]|0)+(la>>>3)|0;U=32-sa|0;O=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(la&7)>>>(U>>>0);ra=la+sa|0;c[m>>2]=S>>>0>ra>>>0?ra:S;S=c[p>>2]|0;ra=c[f>>2]|0;if((ra|0)>(sa|0)){ua=ra-sa|0;va=S<<sa|O}else{la=ta;y=je(O>>>((sa-ra|0)>>>0)|S<<ra|0)|0;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;ua=ra+U|0;va=O}c[p>>2]=va;c[f>>2]=ua}Y2(b);b=c[m>>2]|0;ua=-b&7;va=c[o>>2]|0;if((ua|0)==0){wa=b}else{O=ua+b|0;b=va>>>0>O>>>0?O:va;c[m>>2]=b;wa=b}b=(c[q>>2]|0)+(wa>>>3)|0;O=(je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(wa&7)>>>24;b=wa+8|0;c[m>>2]=va>>>0>b>>>0?b:va;va=c[p>>2]|0;b=c[f>>2]|0;if((b|0)>8){xa=b-8|0;ya=va<<8|O}else{wa=je(O>>>((8-b|0)>>>0)|va<<b|0)|0;va=c[i>>2]|0;y=wa;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;xa=b+24|0;ya=O}c[p>>2]=ya;c[f>>2]=xa;if((O|0)==0){za=xa;Aa=c[h>>2]|0;Ba=c[i>>2]|0;Ca=Ba;Da=Aa;Ea=Ca-Da|0;Fa=Ea<<3;Ga=l-k|0;Ha=Ga<<3;Ia=Ha+g|0;Ja=Ia-za|0;Ka=Ja+Fa|0;return Ka|0}else{La=O}while(1){O=c[m>>2]|0;xa=c[o>>2]|0;ya=(c[q>>2]|0)+(O>>>3)|0;b=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(O&7)>>>24;ya=O+8|0;c[m>>2]=xa>>>0>ya>>>0?ya:xa;xa=c[p>>2]|0;ya=c[f>>2]|0;if((ya|0)>8){Ma=ya-8|0;Na=xa<<8|b}else{O=je(b>>>((8-ya|0)>>>0)|xa<<ya|0)|0;xa=c[i>>2]|0;y=O;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;Ma=ya+24|0;Na=b}c[p>>2]=Na;c[f>>2]=Ma;b=La-1|0;if((b|0)>0){La=b}else{za=Ma;break}}Aa=c[h>>2]|0;Ba=c[i>>2]|0;Ca=Ba;Da=Aa;Ea=Ca-Da|0;Fa=Ea<<3;Ga=l-k|0;Ha=Ga<<3;Ia=Ha+g|0;Ja=Ia-za|0;Ka=Ja+Fa|0;return Ka|0}function ERa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+9992>>2]|0;if((b|0)==3){d=c[a+11556>>2]|0;e=c[a+11560>>2]|0;f=(d|0)>(e|0)?d:e;g=(f|0)>2?f+15|0:17;return g|0}else if((b|0)==2|(b|0)==4){g=(c[a+11556>>2]|0)+15|0;return g|0}else if((b|0)==1){g=16;return g|0}else{g=-1;return g|0}return 0}function FRa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+128>>2]|0;d=c[a+12480>>2]|0;e=ca((d<<1)-1|0,b)|0;f=c[a+12476>>2]|0;g=c[a+124>>2]|0;h=f-1+(ca(g,d-1|0)|0)|0;mrc((c[a+9912>>2]|0)+((f<<1)-1+e<<5)|0,0,b<<6|32|0)|0;b=(g<<5)+32|0;mrc((c[a+9916>>2]|0)+(h<<5)|0,0,b|0)|0;mrc((c[a+9920>>2]|0)+(h<<5)|0,0,b|0)|0;c[a+11844>>2]=0;c[a+11840>>2]=0;c[a+11828>>2]=0;c[a+11824>>2]=0;return}function GRa(a){a=a|0;var c=0,d=0,f=0,g=0,h=0;c=a+13874|0;d=a+13872|0;f=0;do{g=f-32|0;h=ca(e[c>>1]|0,g)|0;b[a+11860+(f<<1)>>1]=(h|0)/(e[d>>1]|0|0)|0;h=e[d>>1]|0;b[a+11988+(f<<1)>>1]=(ca((e[c>>1]|0)-h|0,g)|0)/(h|0)|0;f=f+1|0;}while((f|0)<64);return}function HRa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=(ca(c[d+124>>2]|0,c[d+12480>>2]|0)|0)+(c[d+12476>>2]|0)|0;i=c[(c[d+4712>>2]|0)+(h<<2)>>2]|0;if((i&64|0)!=0){c[d+11740>>2]=1;IRa(d,f,g,0);IRa(d,f,g,1);IRa(d,f,g,2);IRa(d,f,g,3);j=61760;return j|0}if((i&128|0)==0){IRa(d,f,g,0);i=c[d+11744>>2]|0;c[d+11768>>2]=i;c[d+11760>>2]=i;c[d+11752>>2]=i;i=c[d+11748>>2]|0;c[d+11772>>2]=i;c[d+11764>>2]=i;c[d+11756>>2]=i;i=c[d+11776>>2]|0;c[d+11800>>2]=i;c[d+11792>>2]=i;c[d+11784>>2]=i;i=c[d+11780>>2]|0;c[d+11804>>2]=i;c[d+11796>>2]=i;c[d+11788>>2]=i;do{if((c[(c[d+4>>2]|0)+676>>2]&512|0)==0){if((c[d+13924>>2]|0)==0){break}c[d+11740>>2]=1;j=61704;return j|0}}while(0);c[d+11740>>2]=0;j=61704;return j|0}c[d+11740>>2]=3;i=h<<2;k=d+4732|0;l=d+14184|0;m=d+13876|0;n=d+13878|0;o=(g|0)==0;if((f|0)==0){p=0;q=0;while(1){r=a[(c[k>>2]|0)+((p<<1)+i)|0]|0;c[d+11808+(p<<2)>>2]=r;c[d+11816+(p<<2)>>2]=p;s=e[m>>1]|0;if((c[l>>2]|0)==0){t=r+q|0;u=t+s&65535;v=t+(e[n>>1]|0)&65535}else{t=p-r|0;u=t+s&65535;v=t+(e[n>>1]|0)&65535}t=c[d+11660+(p<<3)>>2]|0;s=b[t+(h<<2)>>1]|0;r=v&65535;w=u&65535;c[d+11744+(p<<3)>>2]=(ca(s,r)|0)/(w|0)|0;x=b[t+(h<<2)+2>>1]|0;t=((ca(x,r)|0)/(w|0)|0)+g|0;c[d+11744+(p<<3)+4>>2]=t;c[d+11776+(p<<3)>>2]=(ca(s,r-w|0)|0)/(w|0)|0;if(o){y=(ca(x,r-w|0)|0)/(w|0)|0}else{y=t-x|0}c[d+11776+(p<<3)+4>>2]=y;x=p+1|0;t=~p;if((x|0)<2){p=x;q=t}else{j=61840;break}}return j|0}if(o){o=0;q=0;while(1){p=a[(c[k>>2]|0)+((o<<1)+i)|0]|0;c[d+11808+(o<<2)>>2]=p;c[d+11816+(o<<2)>>2]=o;y=e[m>>1]|0;if((c[l>>2]|0)==0){u=p+q|0;z=u+y&65535;A=u+(e[n>>1]|0)&65535}else{u=o-p|0;z=u+y&65535;A=u+(e[n>>1]|0)&65535}u=c[d+11660+(o<<3)>>2]|0;y=b[u+(h<<2)>>1]|0;p=A&65535;v=z&65535;t=((ca(y,p)|0)/(v|0)|0)+f|0;c[d+11744+(o<<3)>>2]=t;x=b[u+(h<<2)+2>>1]|0;c[d+11744+(o<<3)+4>>2]=(ca(x,p)|0)/(v|0)|0;c[d+11776+(o<<3)>>2]=t-y;c[d+11776+(o<<3)+4>>2]=(ca(x,p-v|0)|0)/(v|0)|0;v=o+1|0;p=~o;if((v|0)<2){o=v;q=p}else{j=61840;break}}return j|0}else{q=0;o=0;while(1){z=a[(c[k>>2]|0)+((q<<1)+i)|0]|0;c[d+11808+(q<<2)>>2]=z;c[d+11816+(q<<2)>>2]=q;A=e[m>>1]|0;if((c[l>>2]|0)==0){p=z+o|0;B=p+A&65535;C=p+(e[n>>1]|0)&65535}else{p=q-z|0;B=p+A&65535;C=p+(e[n>>1]|0)&65535}p=c[d+11660+(q<<3)>>2]|0;A=b[p+(h<<2)>>1]|0;z=C&65535;v=B&65535;x=((ca(A,z)|0)/(v|0)|0)+f|0;c[d+11744+(q<<3)>>2]=x;y=b[p+(h<<2)+2>>1]|0;p=((ca(y,z)|0)/(v|0)|0)+g|0;c[d+11744+(q<<3)+4>>2]=p;c[d+11776+(q<<3)>>2]=x-A;c[d+11776+(q<<3)+4>>2]=p-y;y=q+1|0;p=~q;if((y|0)<2){q=y;o=p}else{j=61840;break}}return j|0}return 0}function IRa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=c[a+12496+(f<<2)>>2]|0;h=b[a+13872>>1]|0;i=b[a+13874>>1]|0;j=c[a+4700>>2]|0;k=b[j+(g<<2)>>1]|0;l=k+32|0;if(l>>>0<64>>>0){m=(b[a+11860+(l<<1)>>1]|0)+d|0;c[a+11744+(f<<3)>>2]=m;if((d|0)==0){n=b[a+11988+(l<<1)>>1]|0}else{n=m-k|0}c[a+11776+(f<<3)>>2]=n}else{n=i&65535;m=h&65535;l=((ca(k,n)|0)/(m|0)|0)+d|0;c[a+11744+(f<<3)>>2]=l;if((d|0)==0){o=(ca(k,n-m|0)|0)/(m|0)|0}else{o=l-k|0}c[a+11776+(f<<3)>>2]=o}o=b[j+(g<<2)+2>>1]|0;g=o+32|0;if(g>>>0<64>>>0){j=(b[a+11860+(g<<1)>>1]|0)+e|0;c[a+11744+(f<<3)+4>>2]=j;if((e|0)==0){p=b[a+11988+(g<<1)>>1]|0}else{p=j-o|0}c[a+11776+(f<<3)+4>>2]=p;return}else{p=i&65535;i=h&65535;h=((ca(o,p)|0)/(i|0)|0)+e|0;c[a+11744+(f<<3)+4>>2]=h;if((e|0)==0){q=(ca(o,p-i|0)|0)/(i|0)|0}else{q=h-o|0}c[a+11776+(f<<3)+4>>2]=q;return}}function JRa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=a+20|0;g=c[f>>2]|0;h=a+16|0;a=c[h>>2]|0;a:do{if((g|0)==0){i=a;j=0;while(1){if((j|0)>=(e|0)){k=i;l=0;break a}m=d[b+j|0]|0|i<<8;n=j+1|0;if((m|0)==438){o=1;p=n;q=438;r=4;break}else{i=m;j=n}}}else{o=g;p=0;q=a;r=4}}while(0);b:do{if((r|0)==4){if((e|0)==0){s=0;return s|0}if((p|0)<(e|0)){t=p;u=q}else{k=q;l=o;break}while(1){a=u<<8;if((a|0)==256){break}g=d[b+t|0]|0|a;a=t+1|0;if((a|0)<(e|0)){t=a;u=g}else{k=g;l=o;break b}}c[f>>2]=0;c[h>>2]=-1;s=t-3|0;return s|0}}while(0);c[f>>2]=l;c[h>>2]=k;s=-100;return s|0}function KRa(a){a=a|0;var b=0;b=c[a>>2]|0;SRa();c[b+14824>>2]=1;c[b+13960>>2]=5;c[b+984>>2]=1;c[b+14804>>2]=1;return 0}function LRa(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=i;i=i+56|0;k=j|0;l=j+24|0;m=j+32|0;n=j+40|0;o=j+48|0;c[n>>2]=g;c[o>>2]=h;p=a|0;q=c[p>>2]|0;r=q;s=a+176|0;do{if((c[s>>2]&1|0)==0){t=q+20|0;u=c[t>>2]|0;v=q+16|0;w=c[v>>2]|0;a:do{if((u|0)==0){x=w;y=0;while(1){if((y|0)>=(h|0)){z=x;A=0;B=10;break a}C=d[g+y|0]|0|x<<8;D=y+1|0;if((C|0)==438){E=1;F=D;H=438;B=5;break}else{x=C;y=D}}}else{E=u;F=0;H=w;B=5}}while(0);b:do{if((B|0)==5){if((h|0)==0){I=0;break}if((F|0)<(h|0)){J=F;K=H}else{z=H;A=E;B=10;break}while(1){w=K<<8;if((w|0)==256){break}u=d[g+J|0]|0|w;w=J+1|0;if((w|0)<(h|0)){J=w;K=u}else{z=u;A=E;B=10;break b}}c[t>>2]=0;c[v>>2]=-1;I=J-3|0}}while(0);if((B|0)==10){c[t>>2]=A;c[v>>2]=z;I=-100}if((IWa(r,I,n,o)|0)>=0){L=I;M=c[n>>2]|0;N=c[o>>2]|0;O=c[p>>2]|0;break}c[e>>2]=0;c[f>>2]=0;P=c[o>>2]|0;i=j;return P|0}else{L=h;M=g;N=h;O=q}}while(0);q=O+40|0;h=O+44|0;c[h>>2]=b;c[O+9896>>2]=O+7664;g=c[b+100>>2]|0;do{if((g|0)!=0){if((c[O+14824>>2]|0)==0){break}p=c[b+96>>2]|0;I=g<<3;r=I>>>0>2147483639>>>0|(p|0)==0;z=r?0:p;p=r?0:I;c[k>>2]=z;c[k+12>>2]=p;c[k+16>>2]=p+8;c[k+4>>2]=z+(p>>3);c[k+8>>2]=0;RRa(q,k)|0}}while(0);g=N<<3;N=g>>>0>2147483639>>>0|(M|0)==0;p=N?0:M;M=N?0:g;c[k>>2]=p;c[k+12>>2]=M;c[k+16>>2]=M+8;c[k+4>>2]=p+(M>>3);c[k+8>>2]=0;M=RRa(q,k)|0;k=c[O+48>>2]|0;c:do{if((k|0)==0){Q=M;B=23}else{do{if((c[b+120>>2]|0)!=0){if((c[b+124>>2]|0)==0){break}if((c[b+128>>2]|0)==0){break}if((c[b+132>>2]|0)!=0){Q=M;B=23;break c}}}while(0);v=H4a(b,k,c[O+52>>2]|0)|0;if((v|0)>=0){Q=v;B=23}}}while(0);if((B|0)==23){do{if((c[s>>2]&4096|0)!=0){B=(c[h>>2]|0)+108|0;if(!((c[B>>2]|0)>0&(Q|0)>-1)){break}k=O+13896|0;b=c[k>>2]|0;M=c[k+4>>2]|0;c[l>>2]=1;c[l+4>>2]=c[B>>2];c[m>>2]=1;c[m+4>>2]=12e5;B=XIb(b,M,l,m)|0;M=a+40|0;c[M>>2]=B;c[M+4>>2]=G}}while(0);c[a+32>>2]=c[O+10032>>2];c[O+14824>>2]=0}c[e>>2]=c[n>>2];c[f>>2]=c[o>>2];P=L;i=j;return P|0}function MRa(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=c[f+9136>>2]|0;k=c[f+9912>>2]|0;l=c[f+12496+(h<<2)>>2]<<4;a:do{if((c[f+176>>2]|0)!=0){m=c[f+12476>>2]|0;if((i|0)==0){n=l-16|0;do{if((m|0)!=0){o=m-1+(ca(c[f+12480>>2]|0,c[f+124>>2]|0)|0)|0;p=c[f+9960>>2]|0;q=j+o|0;o=a[q]|0;if((p|0)==(o<<24>>24|0)){break}if((h|0)==3|(h|0)==1){break}else{r=1;s=o}while(1){o=ca(s<<24>>24,b[k+(r+n<<1)>>1]|0)|0;t=p>>1;u=g+(d[(r<<3)+(f+11184)|0]<<1)|0;b[u>>1]=(e[u>>1]|0)+((((o|0)>0?t:-t|0)+o|0)/(p|0)|0);o=r+1|0;if((o|0)>=8){break a}r=o;s=a[q]|0}}}while(0);n=g+(d[f+11192|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-15<<1)>>1]|0);n=g+(d[f+11200|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-14<<1)>>1]|0);n=g+(d[f+11208|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-13<<1)>>1]|0);n=g+(d[f+11216|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-12<<1)>>1]|0);n=g+(d[f+11224|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-11<<1)>>1]|0);n=g+(d[f+11232|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-10<<1)>>1]|0);n=g+(d[f+11240|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+(l-9<<1)>>1]|0);break}n=c[f+12480>>2]|0;q=c[f+124>>2]|0;p=l-(c[f+12520+(h<<2)>>2]<<4)|0;do{if((n|0)!=0){o=m-q+(ca(q,n)|0)|0;t=c[f+9960>>2]|0;u=j+o|0;o=a[u]|0;if((t|0)==(o<<24>>24|0)){break}if((h-2|0)>>>0<2>>>0){break}v=p|8;w=1;x=o;while(1){o=ca(x<<24>>24,b[k+(v+w<<1)>>1]|0)|0;y=t>>1;z=g+(d[f+11184+w|0]<<1)|0;b[z>>1]=(e[z>>1]|0)+((((o|0)>0?y:-y|0)+o|0)/(t|0)|0);o=w+1|0;if((o|0)>=8){break a}w=o;x=a[u]|0}}}while(0);n=g+(d[f+11185|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|9)<<1)>>1]|0);n=g+(d[f+11186|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|10)<<1)>>1]|0);n=g+(d[f+11187|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|11)<<1)>>1]|0);n=g+(d[f+11188|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|12)<<1)>>1]|0);n=g+(d[f+11189|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|13)<<1)>>1]|0);n=g+(d[f+11190|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|14)<<1)>>1]|0);n=g+(d[f+11191|0]<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[k+((p|15)<<1)>>1]|0)}}while(0);b[k+((l|1)<<1)>>1]=b[g+(d[f+11192|0]<<1)>>1]|0;b[k+((l|2)<<1)>>1]=b[g+(d[f+11200|0]<<1)>>1]|0;b[k+((l|3)<<1)>>1]=b[g+(d[f+11208|0]<<1)>>1]|0;b[k+((l|4)<<1)>>1]=b[g+(d[f+11216|0]<<1)>>1]|0;b[k+((l|5)<<1)>>1]=b[g+(d[f+11224|0]<<1)>>1]|0;b[k+((l|6)<<1)>>1]=b[g+(d[f+11232|0]<<1)>>1]|0;b[k+((l|7)<<1)>>1]=b[g+(d[f+11240|0]<<1)>>1]|0;b[k+((l|9)<<1)>>1]=b[g+(d[f+11185|0]<<1)>>1]|0;b[k+((l|10)<<1)>>1]=b[g+(d[f+11186|0]<<1)>>1]|0;b[k+((l|11)<<1)>>1]=b[g+(d[f+11187|0]<<1)>>1]|0;b[k+((l|12)<<1)>>1]=b[g+(d[f+11188|0]<<1)>>1]|0;b[k+((l|13)<<1)>>1]=b[g+(d[f+11189|0]<<1)>>1]|0;b[k+((l|14)<<1)>>1]=b[g+(d[f+11190|0]<<1)>>1]|0;b[k+((l|15)<<1)>>1]=b[g+(d[f+11191|0]<<1)>>1]|0;return}function NRa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;e=a|0;f=a+144|0;g=(c[f>>2]|0)-1|0;h=g>>>0>65535>>>0;j=h?g>>>16:g;g=h?16:0;if((j&65280|0)==0){k=g;l=j}else{k=g|8;l=j>>>8}j=(d[1359664+l|0]|0)+k|0;k=j+1|0;l=a+14120|0;g=a+14128|0;h=c[g>>2]|0;if((h|0)>((c[a+14132>>2]|0)-20|0)){m=-1;i=b;return m|0}n=l|0;o=0;p=h;while(1){if((o|0)>=32){break}h=d[(c[n>>2]|0)+(p>>>3)|0]|0;q=p+1|0;c[g>>2]=q;if((h&128>>>((p&7)>>>0)|0)==0){o=o+1|0;p=q}else{break}}if((o|0)!=(ERa(e)|0)){KIb(c[a+4>>2]|0,16,2507792,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=-1;i=b;return m|0}e=a+14676|0;o=c[e>>2]|0;p=(o|0)==0;q=c[g>>2]|0;if(p){s=0;t=q;u=c[n>>2]|0}else{h=c[n>>2]|0;v=(d[h+(q>>>3)|0]|0)<<(q&7)>>>7;w=q+1|0;c[g>>2]=w;s=v&1;t=w;u=h}h=u+(t>>>3)|0;w=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(t&7)>>>((31-j|0)>>>0);j=k+t|0;c[g>>2]=j;t=c[f>>2]|0;if((w|0)>=(t|0)){KIb(c[a+4>>2]|0,16,2600800,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=t,r)|0);i=r;m=-1;i=b;return m|0}t=c[a+116>>2]|0;c[a+12476>>2]=(w|0)%(t|0)|0;c[a+12480>>2]=(w|0)/(t|0)|0;do{if((o|0)==2){x=s;y=j}else{t=c[a+13920>>2]|0;w=u+(j>>>3)|0;f=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(j&7)>>>((32-t|0)>>>0);w=j+t|0;c[g>>2]=w;if((f|0)!=0){c[a+9960>>2]=f;c[a+9964>>2]=f}if(!p){x=s;y=w;break}f=(d[u+(w>>>3)|0]|0)<<(w&7)>>>7;t=w+1|0;c[g>>2]=t;x=f&1;y=t}}while(0);do{if((x|0)!=0){s=y;while(1){p=d[u+(s>>>3)|0]|0;z=s+1|0;c[g>>2]=z;if((p&128>>>((s&7)>>>0)|0)==0){break}else{s=z}}p=d[u+(z>>>3)|0]|0;j=s+2|0;c[g>>2]=j;if((p&128>>>((z&7)>>>0)|0)==0){KIb(0,32,2510544,(r=i,i=i+8|0,c[r>>2]=245e4,r)|0);i=r;A=c[g>>2]|0;B=c[n>>2]|0}else{A=j;B=u}j=A+(c[a+14672>>2]|0)|0;c[g>>2]=j;p=d[B+(j>>>3)|0]|0;o=j+1|0;c[g>>2]=o;if((p&128>>>((j&7)>>>0)|0)==0){KIb(0,32,2510544,(r=i,i=i+8|0,c[r>>2]=2360736,r)|0);i=r;C=c[g>>2]|0}else{C=o}c[g>>2]=C+2;if((c[e>>2]|0)==2){break}c[g>>2]=C+5;o=a+9992|0;j=c[o>>2]|0;do{if((j|0)==4){if((c[a+14680>>2]|0)!=2){D=4;break}if((ORa(a,l)|0)<0){m=-1094995529;i=b;return m|0}else{KIb(c[a+4>>2]|0,16,2296552,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;E=c[o>>2]|0;F=30;break}}else{E=j;F=30}}while(0);if((F|0)==30){if((E|0)==1){break}else{D=E}}j=c[g>>2]|0;s=(c[n>>2]|0)+(j>>>3)|0;p=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;c[g>>2]=j+3;if((p&-536870912>>>((j&7)>>>0)|0)==0){KIb(c[a+4>>2]|0,16,2245568,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;G=c[o>>2]|0}else{G=D}if((G|0)!=3){break}j=c[g>>2]|0;p=(c[n>>2]|0)+(j>>>3)|0;s=je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;c[g>>2]=j+3;if((s&-536870912>>>((j&7)>>>0)|0)!=0){break}KIb(c[a+4>>2]|0,16,2204096,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}}while(0);if((c[a+14728>>2]|0)==0){m=0;i=b;return m|0}G=(c[a+14672>>2]|0)+3|0;a=(G|0)>15?15:G;G=a+(c[g>>2]|0)|0;c[g>>2]=G;D=c[n>>2]|0;n=G+1+((128>>>((G&7)>>>0)&(d[D+(G>>>3)|0]|0)|0)==0?0:a)|0;c[g>>2]=n;a=d[D+(n>>>3)|0]|0;c[g>>2]=n+1;if((128>>>((n&7)>>>0)&a|0)!=0){m=0;i=b;return m|0}KIb(0,32,2510544,(r=i,i=i+8|0,c[r>>2]=2511776,r)|0);i=r;m=0;i=b;return m|0}function ORa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+32|0;g=f|0;h=c[a+13932>>2]|0;j=2<<h;k=3-h|0;l=16>>>((h+1|0)>>>0);h=c[a+8>>2]|0;m=c[a+12>>2]|0;mrc(g|0,0,32)|0;if((h|0)<1|(m|0)<1){n=-1094995529;i=f;return n|0}o=a+14688|0;if((c[o>>2]|0)>0){p=e+8|0;q=a+14748|0;r=a+14752|0;s=c[1273385]|0;t=c[e>>2]|0;e=0;u=c[p>>2]|0;do{v=t+(u>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(u&7)>>>26;v=b[s+(w<<2)>>1]|0;x=b[s+(w<<2)+2>>1]|0;w=x<<16>>16;do{if(x<<16>>16<0){y=u+6|0;z=t+(y>>>3)|0;A=((je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(y&7)>>>((w+32|0)>>>0))+v|0;z=b[s+(A<<2)>>1]|0;B=b[s+(A<<2)+2>>1]|0;A=B<<16>>16;if(!(B<<16>>16<0)){C=A;D=y;E=z;break}B=y-w|0;y=t+(B>>>3)|0;F=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(B&7)>>>((A+32|0)>>>0))+z|0;C=b[s+(F<<2)+2>>1]|0;D=B;E=b[s+(F<<2)>>1]|0}else{C=w;D=u;E=v}}while(0);v=C+D|0;c[p>>2]=v;if((E|0)==0){G=0;H=v}else{w=t+(v>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7);w=(x^-2147483648)>>31;F=v+E|0;c[p>>2]=F;G=((w^x)>>>((32-E|0)>>>0)^w)-w|0;H=F}if((c[q>>2]|0)==500){if((c[r>>2]|0)==413){I=H}else{J=12}}else{J=12}if((J|0)==12){J=0;F=H+1|0;c[p>>2]=F;I=F}F=t+(I>>>3)|0;w=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>26;F=b[s+(w<<2)>>1]|0;x=b[s+(w<<2)+2>>1]|0;w=x<<16>>16;do{if(x<<16>>16<0){v=I+6|0;B=t+(v>>>3)|0;z=((je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7)>>>((w+32|0)>>>0))+F|0;B=b[s+(z<<2)>>1]|0;A=b[s+(z<<2)+2>>1]|0;z=A<<16>>16;if(!(A<<16>>16<0)){K=z;L=v;M=B;break}A=v-w|0;v=t+(A>>>3)|0;y=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(A&7)>>>((z+32|0)>>>0))+B|0;K=b[s+(y<<2)+2>>1]|0;L=A;M=b[s+(y<<2)>>1]|0}else{K=w;L=I;M=F}}while(0);F=K+L|0;c[p>>2]=F;if((M|0)==0){N=0;O=F}else{w=t+(F>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(F&7);w=(x^-2147483648)>>31;y=F+M|0;c[p>>2]=y;N=((w^x)>>>((32-M|0)>>>0)^w)-w|0;O=y}u=O+1|0;c[p>>2]=u;c[g+(e<<3)>>2]=G;b[a+14692+(e<<2)>>1]=G;c[g+(e<<3)+4>>2]=N;b[a+14692+(e<<2)+2>>1]=N;e=e+1|0;}while((e|0)<(c[o>>2]|0));if((e|0)<4){P=e;J=19}else{Q=0}}else{P=0;J=19}if((J|0)==19){while(1){J=0;b[a+14692+(P<<2)+2>>1]=0;b[a+14692+(P<<2)>>1]=0;e=P+1|0;if((e|0)<4){P=e;J=19}else{Q=0;break}}}while(1){R=1<<Q;if((R|0)<(h|0)){Q=Q+1|0}else{S=0;break}}while(1){T=1<<S;if((T|0)<(m|0)){S=S+1|0}else{break}}do{if((c[a+14748>>2]|0)==500){if((c[a+14752>>2]|0)!=413){J=25;break}P=c[g>>2]|0;e=c[g+4>>2]|0;N=P+(ca(j,h)|0)|0;G=e+(ca(m,j)|0)|0;U=G+(c[g+20>>2]|0)|0;V=(c[g+16>>2]|0)+P|0;W=(c[g+12>>2]|0)+e|0;X=N+(c[g+8>>2]|0)|0;Y=e;Z=P}else{J=25}}while(0);if((J|0)==25){J=j>>1;P=c[g>>2]|0;e=ca(P,J)|0;N=c[g+4>>2]|0;G=ca(N,J)|0;u=ca(P+(h<<1)+(c[g+8>>2]|0)|0,J)|0;p=ca((c[g+12>>2]|0)+N|0,J)|0;O=ca((c[g+16>>2]|0)+P|0,J)|0;U=ca(N+(m<<1)+(c[g+20>>2]|0)|0,J)|0;V=O;W=p;X=u;Y=G;Z=e}e=R<<4;G=h-R|0;u=ca(Z,l)|0;p=((ca(X,l)|0)-(h<<4)<<Q)+(ca(u,G)|0)|0;X=h>>1;O=-X|0;J=((((p|0)>0?X:O)+p|0)/(h|0)|0)+e|0;p=ca(Y,l)|0;g=((ca(W,l)|0)<<Q)+(ca(p,G)|0)|0;G=(((g|0)>0?X:O)+g|0)/(h|0)|0;h=m-T|0;g=((ca(V,l)|0)<<S)+(ca(u,h)|0)|0;u=m>>1;V=((ca(U,l)|0)-(m<<4)<<S)+(ca(p,h)|0)|0;h=c[o>>2]|0;if((h|0)==1){c[a+13884>>2]=Z;c[a+13888>>2]=Y;c[a+13892>>2]=Z>>1|Z&1;c[a+13896>>2]=Y>>1|Y&1;o=a+13900|0;c[o>>2]=j;c[a+13908>>2]=0;c[a+13904>>2]=0;c[a+13912>>2]=j;c[a+14712>>2]=0;U=a+14708|0;c[U>>2]=0;_=o;$=U}else if((h|0)==2){U=Q+k|0;o=-l|0;O=J+(ca(Z,o)|0)|0;X=p-G|0;p=1<<U-1;c[a+13884>>2]=(Z<<U)+p;W=G+(ca(Y,o)|0)|0;c[a+13888>>2]=(Y<<U)+p;p=ca(R<<1,l)|0;o=(1<<U+1)-e|0;c[a+13892>>2]=o+(ca(Z,p)|0)+X+O;c[a+13896>>2]=o+(ca(Y,p)|0)+O+W;p=a+13900|0;c[p>>2]=O;c[a+13904>>2]=X;c[a+13908>>2]=W;c[a+13912>>2]=O;O=a+14708|0;c[O>>2]=U;c[a+14712>>2]=U+2;_=p;$=O}else if((h|0)==3){O=-u|0;p=(Q|0)>(S|0)?S:Q;U=R>>p;R=T>>p;W=Q+k+S-p|0;p=-l|0;S=ca(Z,p)|0;k=ca(J+S|0,R)|0;J=ca(((((g|0)>0?u:O)+g|0)/(m|0)|0)+S|0,U)|0;S=1<<W-1;c[a+13884>>2]=(Z<<W)+S;g=ca(Y,p)|0;p=ca(G+g|0,R)|0;G=ca(g+(T<<4)+((((V|0)>0?u:O)+V|0)/(m|0)|0)|0,U)|0;c[a+13888>>2]=(Y<<W)+S;S=ca(l<<1<<Q,R)|0;Q=(1<<W+1)-(ca(R,e)|0)|0;c[a+13892>>2]=Q+(ca(Z,S)|0)+k+J;c[a+13896>>2]=Q+(ca(Y,S)|0)+p+G;S=a+13900|0;c[S>>2]=k;c[a+13904>>2]=J;c[a+13908>>2]=p;c[a+13912>>2]=G;G=a+14708|0;c[G>>2]=W;c[a+14712>>2]=W+2;_=S;$=G}else if((h|0)==0){G=a+13900|0;mrc(a+13884|0,0,16)|0;c[G>>2]=j;c[a+13908>>2]=0;c[a+13904>>2]=0;c[a+13912>>2]=j;c[a+14712>>2]=0;S=a+14708|0;c[S>>2]=0;_=G;$=S}else{_=a+13900|0;$=a+14708|0}S=c[_>>2]|0;G=c[$>>2]|0;W=a+13904|0;p=c[W>>2]|0;do{if((S|0)==(j<<G|0)&(p|0)==0){J=a+13908|0;if((c[J>>2]|0)!=0){aa=0;break}k=a+13912|0;if((c[k>>2]|0)!=(S|0)){aa=0;break}Y=a+13884|0;c[Y>>2]=c[Y>>2]>>G;Y=a+13888|0;c[Y>>2]=c[Y>>2]>>G;Y=a+14712|0;Q=c[Y>>2]|0;Z=a+13892|0;c[Z>>2]=c[Z>>2]>>Q;Z=a+13896|0;c[Z>>2]=c[Z>>2]>>Q;c[_>>2]=j;c[W>>2]=0;c[J>>2]=0;c[k>>2]=j;c[$>>2]=0;c[Y>>2]=0;c[a+13880>>2]=1;n=0;i=f;return n|0}else{aa=p}}while(0);p=16-G|0;G=a+14712|0;j=16-(c[G>>2]|0)|0;W=a+13884|0;c[W>>2]=c[W>>2]<<p;W=a+13892|0;c[W>>2]=c[W>>2]<<j;c[_>>2]=S<<p;S=a+13908|0;c[S>>2]=c[S>>2]<<p;c[$>>2]=16;$=a+13888|0;c[$>>2]=c[$>>2]<<p;$=a+13896|0;c[$>>2]=c[$>>2]<<j;c[a+13904>>2]=aa<<p;aa=a+13912|0;c[aa>>2]=c[aa>>2]<<p;c[G>>2]=16;c[a+13880>>2]=h;n=0;i=f;return n|0}function PRa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=e|0;m=e+9992|0;n=(c[m>>2]|0)==1;o=n?12:8;p=n?96:64;n=e+14084|0;c[n>>2]=1;q=e+12480|0;r=e+120|0;a:do{if((c[q>>2]|0)<(c[r>>2]|0)){s=e+12476|0;t=e+116|0;u=e+124|0;v=e+4|0;w=e+12496|0;x=e+12500|0;y=e+12504|0;z=e+12508|0;A=e+12512|0;B=e+12516|0;C=e+12544|0;D=e+12548|0;E=e+12552|0;F=e+13704|0;G=e+13708|0;H=e+9148|0;I=e+128|0;J=e+14120|0;K=e+14128|0;L=e+9936|0;M=e+12488|0;N=e+9932|0;O=e+14680|0;P=e+13916|0;Q=e+11556|0;R=e+9160|0;S=e+9960|0;T=e+9136|0;U=e+9940|0;V=0;b:while(1){NTa(l);W=c[s>>2]|0;if((W|0)<(c[t>>2]|0)){X=V;Y=W;while(1){Z=c[q>>2]|0;W=(ca(c[u>>2]|0,Z)|0)+Y|0;_=X+1|0;$=c[v>>2]|0;aa=8>>>((c[$+800>>2]|0)>>>0);ba=(c[w>>2]|0)+2|0;c[w>>2]=ba;c[x>>2]=(c[x>>2]|0)+2;c[y>>2]=(c[y>>2]|0)+2;c[z>>2]=(c[z>>2]|0)+2;c[A>>2]=(c[A>>2]|0)+1;c[B>>2]=(c[B>>2]|0)+1;c[C>>2]=(c[C>>2]|0)+(aa<<1);c[D>>2]=(c[D>>2]|0)+aa;c[E>>2]=(c[E>>2]|0)+aa;do{if((Y|0)==(c[F>>2]|0)){if((Z|0)!=((c[G>>2]|0)+1|0)){break}c[n>>2]=0}}while(0);aa=c[m>>2]|0;c:do{if((aa|0)==1){da=c[J>>2]|0;ea=c[K>>2]|0;do{fa=da+(ea>>>3)|0;ga=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ea&7);if((ga&-8192|0)==-704634880){ha=X;break a}fa=c[2055815]|0;ia=ga>>>26;ga=b[fa+(ia<<2)>>1]|0;ja=b[fa+(ia<<2)+2>>1]|0;ia=ja<<16>>16;if(ja<<16>>16<0){ja=ea+6|0;ka=da+(ja>>>3)|0;la=((je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ja&7)>>>((ia+32|0)>>>0))+ga|0;ma=b[fa+(la<<2)+2>>1]|0;na=ja;oa=b[fa+(la<<2)>>1]|0}else{ma=ia;na=ea;oa=ga}ea=ma+na|0;c[K>>2]=ea;if((oa|0)<0){pa=13;break b}}while((oa|0)==8);a[(c[L>>2]|0)+W|0]=oa&3;c[(c[R>>2]|0)+(W<<2)>>2]=1;c[M>>2]=1;if((oa&4|0)!=0){ea=c[S>>2]|0;da=c[K>>2]|0;ga=(c[J>>2]|0)+(da>>>3)|0;ia=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(da&7)>>>30;c[K>>2]=da+2;QTa(l,(a[795256+ia|0]|0)+ea|0)}a[(c[T>>2]|0)+W|0]=c[S>>2];a[(c[N>>2]|0)+W|0]=1;if((ZRa(l,0,h)|0)<0){pa=18;break b}ea=c[h>>2]|0;if((ZRa(l,1,h)|0)<0){pa=18;break b}ia=(c[h>>2]|0)!=0|0;if((ZRa(l,2,h)|0)<0){pa=18;break b}da=c[h>>2]|0;if((ZRa(l,3,h)|0)<0){pa=18;break b}ga=(c[h>>2]|0)!=0|0;if((ZRa(l,4,h)|0)<0){pa=18;break b}la=c[h>>2]|0;if((ZRa(l,5,h)|0)<0){pa=18;break b}a[(c[U>>2]|0)+W|0]=(c[h>>2]|0)!=0|((la|0)!=0|(ga|((da|0)!=0|(ia|((ea|0)!=0)<<1)<<1)<<1)<<1)<<1}else{ea=c[H>>2]|0;ia=ea+(ba<<2)|0;da=c[I>>2]<<1;ga=c[J>>2]|0;la=c[K>>2]|0;do{fa=ga+(la>>>3)|0;ja=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(la&7)>>>15;if((ja|0)==126977){ha=X;break a}fa=la+1|0;c[K>>2]=fa;if((ja&65536|0)!=0){pa=23;break}ja=c[2055821]|0;ka=ga+(fa>>>3)|0;qa=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(fa&7)>>>25;ka=b[ja+(qa<<2)>>1]|0;ra=b[ja+(qa<<2)+2>>1]|0;qa=ra<<16>>16;if(ra<<16>>16<0){ra=la+8|0;sa=ga+(ra>>>3)|0;ta=((je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ra&7)>>>((qa+32|0)>>>0))+ka|0;ua=b[ja+(ta<<2)+2>>1]|0;va=ra;wa=b[ja+(ta<<2)>>1]|0}else{ua=qa;va=fa;wa=ka}la=ua+va|0;c[K>>2]=la;if((wa|0)<0){pa=32;break b}}while((wa|0)==20);if((pa|0)==23){pa=0;do{if((aa|0)==4){if((c[O>>2]|0)!=2){pa=26;break}c[(c[R>>2]|0)+(W<<2)>>2]=15368;la=WRa(e,0)|0;xa=(WRa(e,1)|0)&65535;ya=la&65535}else{pa=26}}while(0);if((pa|0)==26){pa=0;c[(c[R>>2]|0)+(W<<2)>>2]=14344;xa=0;ya=0}b[ea+(ba<<2)+(da+2<<1)>>1]=ya;b[ea+(ba<<2)+(da<<1)>>1]=ya;b[ea+(ba<<2)+4>>1]=ya;b[ia>>1]=ya;b[ea+(ba<<2)+(da+3<<1)>>1]=xa;b[ea+(ba<<2)+((da|1)<<1)>>1]=xa;b[ea+(ba<<2)+6>>1]=xa;b[ea+(ba<<2)+2>>1]=xa;if((a[(c[N>>2]|0)+W|0]|0)==0){break}JTa(l);break}a[(c[L>>2]|0)+W|0]=wa&11;la=wa&4;c[M>>2]=la>>>2;if((la|0)!=0){c[(c[R>>2]|0)+(W<<2)>>2]=1;a[(c[N>>2]|0)+W|0]=1;b[ea+(ba<<2)+(da+2<<1)>>1]=0;b[ea+(ba<<2)+(da<<1)>>1]=0;b[ea+(ba<<2)+4>>1]=0;b[ia>>1]=0;b[ea+(ba<<2)+(da+3<<1)>>1]=0;b[ea+(ba<<2)+((da|1)<<1)>>1]=0;b[ea+(ba<<2)+6>>1]=0;b[ea+(ba<<2)+2>>1]=0;break}if((a[(c[N>>2]|0)+W|0]|0)!=0){JTa(l)}do{if((c[m>>2]|0)==4){if((c[O>>2]|0)!=2){pa=42;break}if((wa&16|0)!=0){pa=42;break}la=c[K>>2]|0;ga=d[(c[J>>2]|0)+(la>>>3)|0]<<(la&7)>>>7;c[K>>2]=la+1;c[P>>2]=ga&1}else{pa=42}}while(0);do{if((pa|0)==42){pa=0;c[P>>2]=0;if((wa&16|0)==0){break}c[(c[R>>2]|0)+(W<<2)>>2]=12352;ga=Rga(l,0,0,j,k)|0;la=HMa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((la|0)>65534){ha=-1;break a}ka=HMa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((ka|0)>65534){ha=-1;break a}b[ga>>1]=la;b[ga+2>>1]=ka;ka=Rga(l,1,0,j,k)|0;ga=HMa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((ga|0)>65534){ha=-1;break a}la=HMa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((la|0)>65534){ha=-1;break a}b[ka>>1]=ga;b[ka+2>>1]=la;la=Rga(l,2,0,j,k)|0;ka=HMa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((ka|0)>65534){ha=-1;break a}ga=HMa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((ga|0)>65534){ha=-1;break a}b[la>>1]=ka;b[la+2>>1]=ga;ga=Rga(l,3,0,j,k)|0;la=HMa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((la|0)>65534){ha=-1;break a}ka=HMa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((ka|0)>65534){ha=-1;break a}b[ga>>1]=la;b[ga+2>>1]=ka;break c}}while(0);Rga(l,0,0,j,k)|0;if((c[P>>2]|0)==0){ka=HMa(l,c[j>>2]|0,c[Q>>2]|0)|0;if((ka|0)>65534){ha=-1;break a}ga=HMa(l,c[k>>2]|0,c[Q>>2]|0)|0;if((ga|0)>65534){ha=-1;break a}c[(c[R>>2]|0)+(W<<2)>>2]=12296;za=ga&65535;Aa=ka&65535}else{ka=WRa(e,0)|0;ga=WRa(e,1)|0;c[(c[R>>2]|0)+(W<<2)>>2]=13320;za=ga&65535;Aa=ka&65535}b[ea+(ba<<2)+(da+2<<1)>>1]=Aa;b[ea+(ba<<2)+(da<<1)>>1]=Aa;b[ea+(ba<<2)+4>>1]=Aa;b[ia>>1]=Aa;b[ea+(ba<<2)+(da+3<<1)>>1]=za;b[ea+(ba<<2)+((da|1)<<1)>>1]=za;b[ea+(ba<<2)+6>>1]=za;b[ea+(ba<<2)+2>>1]=za}}while(0);ba=(c[s>>2]|0)+1|0;c[s>>2]=ba;if((ba|0)<(c[t>>2]|0)){X=_;Y=ba}else{Ba=_;break}}}else{Ba=V}c[s>>2]=0;X=(c[q>>2]|0)+1|0;c[q>>2]=X;if((X|0)<(c[r>>2]|0)){V=Ba}else{ha=Ba;break a}}if((pa|0)==13){KIb($,16,2514088,(Ca=i,i=i+16|0,c[Ca>>2]=Y,c[Ca+8>>2]=Z,Ca)|0);i=Ca;ha=-1;break}else if((pa|0)==18){V=c[q>>2]|0;KIb(c[v>>2]|0,16,2519328,(Ca=i,i=i+16|0,c[Ca>>2]=c[s>>2],c[Ca+8>>2]=V,Ca)|0);i=Ca;ha=-1;break}else if((pa|0)==32){KIb($,16,2514088,(Ca=i,i=i+16|0,c[Ca>>2]=Y,c[Ca+8>>2]=Z,Ca)|0);i=Ca;ha=-1;break}}else{ha=0}}while(0);if((ha|0)<0){ypb(e+14424|0,c[e+13704>>2]|0,c[e+13708>>2]|0,c[e+12476>>2]|0,c[q>>2]|0,o);Da=-1;i=f;return Da|0}Z=e+13704|0;Y=c[Z>>2]|0;$=e+13708|0;Ba=c[$>>2]|0;r=e+116|0;za=Y+ha+(ca(c[r>>2]|0,Ba)|0)|0;if((za|0)>(c[e+144>>2]|0)){KIb(c[e+4>>2]|0,16,2172200,(Ca=i,i=i+1|0,i=i+7&-8,c[Ca>>2]=0,Ca)|0);i=Ca;ypb(e+14424|0,c[Z>>2]|0,c[$>>2]|0,c[e+12476>>2]|0,c[q>>2]|0,o);Da=-1;i=f;return Da|0}c[e+13732>>2]=ha;o=(c[m>>2]|0)==1;za=c[e+14120>>2]|0;Aa=e+14128|0;k=c[Aa>>2]|0;j=za+(k>>>3)|0;wa=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(k&7);do{if(o){if((wa&-8388608|0)==8388608){j=k;while(1){xa=j+9|0;c[Aa>>2]=xa;ya=za+(xa>>>3)|0;if(((je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(xa&7)&-8388608|0)==8388608){j=xa}else{Ea=xa;break}}}else{Ea=k}j=za+(Ea>>>3)|0;s=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(Ea&7);c[Aa>>2]=Ea+19;if((s&-8192|0)==-704634880){break}s=c[q>>2]|0;KIb(c[e+4>>2]|0,16,2144552,(Ca=i,i=i+16|0,c[Ca>>2]=c[e+12476>>2],c[Ca+8>>2]=s,Ca)|0);i=Ca;Da=-1;i=f;return Da|0}else{if((wa&-4194304|0)==4194304){s=k;while(1){j=s+10|0;c[Aa>>2]=j;v=za+(j>>>3)|0;if(((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(j&7)&-4194304|0)==4194304){s=j}else{Fa=j;break}}}else{Fa=k}s=za+(Fa>>>3)|0;j=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(Fa&7);c[Aa>>2]=Fa+17;if((j&-32768|0)==-134184960){break}j=c[q>>2]|0;KIb(c[e+4>>2]|0,16,2120944,(Ca=i,i=i+16|0,c[Ca>>2]=c[e+12476>>2],c[Ca+8>>2]=j,Ca)|0);i=Ca;Da=-1;i=f;return Da|0}}while(0);Fa=e+14424|0;Aa=e+12476|0;ypb(Fa,Y,Ba,(c[Aa>>2]|0)-1|0,c[q>>2]|0,p);c[Aa>>2]=c[Z>>2];c[n>>2]=1;c[q>>2]=c[$>>2];d:do{if((ha|0)>0){p=e+124|0;Ba=e+4|0;Y=e+12496|0;za=e+12500|0;k=e+12504|0;wa=e+12508|0;Ea=e+12512|0;o=e+12516|0;j=e+12544|0;s=e+12548|0;v=e+12552|0;xa=e+14128|0;ya=e+14120|0;va=e+9936|0;ua=e+9160|0;h=e+9960|0;oa=e+9136|0;na=e+9940|0;ma=0;e:while(1){NTa(l);if((ma|0)>=(ha|0)){break d}V=ma;Ga=c[Aa>>2]|0;while(1){if((Ga|0)>=(c[r>>2]|0)){break}Ha=c[q>>2]|0;t=(ca(c[p>>2]|0,Ha)|0)+Ga|0;R=V+1|0;Ia=c[Ba>>2]|0;Q=8>>>((c[Ia+800>>2]|0)>>>0);c[Y>>2]=(c[Y>>2]|0)+2;c[za>>2]=(c[za>>2]|0)+2;c[k>>2]=(c[k>>2]|0)+2;c[wa>>2]=(c[wa>>2]|0)+2;c[Ea>>2]=(c[Ea>>2]|0)+1;c[o>>2]=(c[o>>2]|0)+1;c[j>>2]=(c[j>>2]|0)+(Q<<1);c[s>>2]=(c[s>>2]|0)+Q;c[v>>2]=(c[v>>2]|0)+Q;do{if((Ga|0)==(c[Z>>2]|0)){if((Ha|0)!=((c[$>>2]|0)+1|0)){break}c[n>>2]=0}}while(0);do{if((c[m>>2]|0)==1){_=c[xa>>2]|0;Q=c[ya>>2]|0;P=a[Q+(_>>>3)|0]|0;K=_+1|0;c[xa>>2]=K;J=c[2093353]|0;O=Q+(K>>>3)|0;Q=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(K&7)>>>26;O=b[J+(Q<<2)>>1]|0;c[xa>>2]=(b[J+(Q<<2)+2>>1]|0)+K;if(O<<16>>16<0){pa=88;break e}K=(c[va>>2]|0)+t|0;a[K]=a[K]|(O&255)<<2;O=(c[ua>>2]|0)+(t<<2)|0;c[O>>2]=c[O>>2]|(P&255)<<(_&7)>>>7<<9&512}else{_=c[(c[ua>>2]|0)+(t<<2)>>2]|0;if((_&7|0)==0){if((_&2048|0)!=0){a[(c[oa>>2]|0)+t|0]=c[h>>2];a[(c[va>>2]|0)+t|0]=0;break}_=c[2093353]|0;P=c[xa>>2]|0;O=c[ya>>2]|0;K=O+(P>>>3)|0;Q=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(P&7)>>>26;K=b[_+(Q<<2)>>1]|0;J=(b[_+(Q<<2)+2>>1]|0)+P|0;c[xa>>2]=J;if(K<<16>>16<0){pa=101;break e}if(!((a[(c[va>>2]|0)+t|0]&8)==0)){P=c[h>>2]|0;Q=O+(J>>>3)|0;O=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(J&7)>>>30;c[xa>>2]=J+2;QTa(l,(a[795256+O|0]|0)+P|0)}a[(c[oa>>2]|0)+t|0]=c[h>>2];P=(c[va>>2]|0)+t|0;a[P]=a[P]&3;P=(c[va>>2]|0)+t|0;a[P]=a[P]|(K&255)<<2^60;break}K=c[xa>>2]|0;P=c[ya>>2]|0;O=d[P+(K>>>3)|0]<<(K&7)>>>7;J=K+1|0;c[xa>>2]=J;K=c[2093353]|0;Q=P+(J>>>3)|0;_=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(J&7)>>>26;Q=b[K+(_<<2)>>1]|0;N=(b[K+(_<<2)+2>>1]|0)+J|0;c[xa>>2]=N;if(Q<<16>>16<0){pa=92;break e}if(!((a[(c[va>>2]|0)+t|0]&8)==0)){J=c[h>>2]|0;_=P+(N>>>3)|0;P=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(N&7)>>>30;c[xa>>2]=N+2;QTa(l,(a[795256+P|0]|0)+J|0)}a[(c[oa>>2]|0)+t|0]=c[h>>2];if((ZRa(l,0,g)|0)<0){pa=96;break e}J=c[g>>2]|0;if((ZRa(l,1,g)|0)<0){pa=96;break e}P=(c[g>>2]|0)!=0|0;if((ZRa(l,2,g)|0)<0){pa=96;break e}N=c[g>>2]|0;if((ZRa(l,3,g)|0)<0){pa=96;break e}_=(c[g>>2]|0)!=0|0;if((ZRa(l,4,g)|0)<0){pa=96;break e}K=c[g>>2]|0;if((ZRa(l,5,g)|0)<0){pa=96;break e}M=(c[g>>2]|0)!=0|((K|0)!=0|(_|((N|0)!=0|(P|((J|0)!=0)<<1)<<1)<<1)<<1)<<1;J=(c[va>>2]|0)+t|0;a[J]=a[J]&3;J=(c[va>>2]|0)+t|0;a[J]=a[J]|(Q&255)<<2;Q=(c[ua>>2]|0)+(t<<2)|0;c[Q>>2]=c[Q>>2]|O<<9&512;a[(c[na>>2]|0)+t|0]=M}}while(0);t=(c[Aa>>2]|0)+1|0;c[Aa>>2]=t;if((R|0)<(ha|0)){V=R;Ga=t}else{break d}}c[Aa>>2]=0;c[q>>2]=(c[q>>2]|0)+1;if((V|0)<(ha|0)){ma=V}else{break d}}if((pa|0)==88){KIb(Ia,16,2521456,(Ca=i,i=i+16|0,c[Ca>>2]=Ga,c[Ca+8>>2]=Ha,Ca)|0);i=Ca}else if((pa|0)==92){KIb(Ia,16,2520248,(Ca=i,i=i+16|0,c[Ca>>2]=Ga,c[Ca+8>>2]=Ha,Ca)|0);i=Ca}else if((pa|0)==96){ma=c[q>>2]|0;KIb(c[Ba>>2]|0,16,2519328,(Ca=i,i=i+16|0,c[Ca>>2]=c[Aa>>2],c[Ca+8>>2]=ma,Ca)|0);i=Ca}else if((pa|0)==101){KIb(Ia,16,2517912,(Ca=i,i=i+16|0,c[Ca>>2]=Ga,c[Ca+8>>2]=Ha,Ca)|0);i=Ca}if((c[m>>2]|0)!=2){Da=-1;i=f;return Da|0}ypb(Fa,c[Z>>2]|0,c[$>>2]|0,c[Aa>>2]|0,c[q>>2]|0,4);Da=-1;i=f;return Da|0}}while(0);if((c[m>>2]|0)!=2){Da=0;i=f;return Da|0}ypb(Fa,c[Z>>2]|0,c[$>>2]|0,(c[Aa>>2]|0)-1|0,c[q>>2]|0,32);Da=0;i=f;return Da|0}function QRa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;d=c[a+60>>2]|0;e=d+14756|0;f=c[e>>2]|0;a:do{if((f|0)==-1){g=d+14748|0;h=(c[g>>2]|0)==-1;if(!h){j=-1;break}b:do{if((c[d+14760>>2]|0)==-1){do{if((c[d+92>>2]|0)!=1145656920){k=c[d+88>>2]|0;if((k|0)==1145656920|(k|0)==1481201240|(k|0)==877677906|(k|0)==877677914|(k|0)==1347438931){break}if(h){break b}else{j=-1;break a}}}while(0);c[e>>2]=0;l=0;m=14;break a}}while(0);if(!((c[d+14760>>2]|0)==-1)){j=-1;break}if((c[d+88>>2]|0)!=1482049860){j=-1;break}if((c[d+13948>>2]|0)!=0){j=-1;break}if((c[d+13952>>2]|0)!=0){j=-1;break}c[g>>2]=400;j=-1}else{if((f|0)>-1){l=f;m=14}else{j=f}}}while(0);do{if((m|0)==14){f=d+14748|0;if(!((c[f>>2]|0)>-1)){j=l;break}c[d+14752>>2]=-1;c[f>>2]=-1;j=l}}while(0);l=d+84|0;f=c[l>>2]|0;do{if((f&1|0)==0){n=f}else{e=c[d+88>>2]|0;if((e|0)==877677909){h=f|8;c[l>>2]=h;o=h}else if((e|0)==1481201240){e=f|4;c[l>>2]=e;o=e}else{o=f}e=c[d+14748>>2]|0;do{if((e|0)>499){h=(c[d+14752>>2]|0)<1814;if(h){k=o|64;c[l>>2]=k;p=k}else{p=o}if((e|0)<503|h^1){q=p;break}h=p|256;c[l>>2]=h;q=h}else{q=o}}while(0);do{if(j>>>0<4>>>0){c[d+14008>>2]=1073741824;if(!(j>>>0<2>>>0)){r=q;m=29;break}g=q|64;c[l>>2]=g;s=g;m=28}else{s=q;m=28}}while(0);if((m|0)==28){if(j>>>0<13>>>0){r=s;m=29}else{t=s}}if((m|0)==29){g=r|1024;c[l>>2]=g;t=g}if(j>>>0<33>>>0){g=t|4096;c[l>>2]=g;u=g}else{u=t}g=c[d+14760>>2]|0;if(g>>>0<4653>>>0){h=u|128;c[l>>2]=h;v=h;m=35}else{if(g>>>0<4655>>>0){v=u;m=35}else{w=u}}if((m|0)==35){h=v|512;c[l>>2]=h;w=h}if(g>>>0<4670>>>0){h=w|1024;c[l>>2]=h;x=h}else{x=w}if(g>>>0<4713>>>0){g=x|4096;c[l>>2]=g;y=g}else{y=x}g=(e|0)>-1;if(!g){n=y;break}h=y|512;c[l>>2]=h;do{if((e|0)==501){if((c[d+14752>>2]|0)!=20020416){z=h;break}c[d+14008>>2]=1073741824;m=44}else{m=44}}while(0);do{if((m|0)==44){if(!(e>>>0<500>>>0)){z=h;break}k=y|1536;c[l>>2]=k;z=k}}while(0);if(!g){n=z;break}h=z|2048;c[l>>2]=h;n=h}}while(0);if((n&128|0)!=0){c[d+10700>>2]=2288;c[d+10956>>2]=1482;c[d+10828>>2]=2048;c[d+10708>>2]=1268;c[d+10964>>2]=1430;c[d+10836>>2]=926;c[d+10716>>2]=1022;c[d+10972>>2]=846;c[d+10844>>2]=1036;c[d+10724>>2]=724;c[d+10980>>2]=262;c[d+10852>>2]=466;c[d+10732>>2]=12;c[d+10988>>2]=1842;c[d+10860>>2]=290;c[d+10740>>2]=2246;c[d+10996>>2]=840;c[d+10868>>2]=452;c[d+10764>>2]=1676;c[d+11020>>2]=1730;c[d+10892>>2]=2186;c[d+10772>>2]=1148;c[d+11028>>2]=490;c[d+10900>>2]=948;c[d+10780>>2]=964;c[d+11036>>2]=1948;c[d+10908>>2]=386;c[d+10788>>2]=1560;c[d+11044>>2]=234;c[d+10916>>2]=1888;c[d+10796>>2]=492;c[d+11052>>2]=2248;c[d+10924>>2]=854;c[d+10804>>2]=148;c[d+11060>>2]=2016;c[d+10932>>2]=1152}if((c[a+688>>2]&4096|0)==0){i=b;return 0}a=c[d+14760>>2]|0;l=c[d+14748>>2]|0;z=c[d+14752>>2]|0;y=(c[d+14012>>2]|0)!=0?2488992:10230536;KIb(c[d+4>>2]|0,48,2501952,(d=i,i=i+48|0,c[d>>2]=n,c[d+8>>2]=a,c[d+16>>2]=j,c[d+24>>2]=l,c[d+32>>2]=z,c[d+40>>2]=y,d)|0);i=d;i=b;return 0}function RRa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0;h=i;i=i+320|0;j=h|0;k=h+256|0;l=h+264|0;m=h+272|0;n=h+280|0;o=h+288|0;p=h+296|0;q=f|0;r=g+8|0;s=c[r>>2]|0;t=-s&7;if((t|0)==0){u=s}else{v=t+s|0;c[r>>2]=v;u=v}v=f+88|0;do{if((c[v>>2]|0)==1177638487){s=c[g>>2]|0;t=s+(u>>>3)|0;if(((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(u&7)&-256|0)!=1465266176){w=u;x=6;break}t=u+24|0;c[r>>2]=t;y=s+(t>>>3)|0;s=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(t&7);t=u+32|0;c[r>>2]=t;if(!((s&-16777216|0)==-268435456)){w=t;x=6}}else{w=u;x=6}}while(0);a:do{if((x|0)==6){u=g+12|0;t=c[u>>2]|0;b:do{if((w|0)<(t|0)){s=g|0;y=f+4|0;z=p;A=f+13948|0;B=f+13928|0;C=f+13952|0;D=f+108|0;E=f+13944|0;F=f+14676|0;H=f+14672|0;I=f+14724|0;J=f+14224|0;K=f+14152|0;L=f+14236|0;M=f+14680|0;N=f+14688|0;O=f+13932|0;P=f+14684|0;Q=f+13920|0;R=f+14004|0;S=f+13924|0;T=f+14768|0;U=f+14772|0;V=f+14776|0;W=f+14720|0;X=f+13936|0;Y=f+14728|0;Z=f+14736|0;_=g;$=f+14732|0;aa=f+14716|0;ba=f+8|0;da=f+12|0;ea=f+14420|0;fa=j|0;ga=f+14748|0;ha=f+14752|0;ia=f+14012|0;ja=f+14764|0;ka=f+14760|0;la=f+14756|0;ma=f+13852|0;na=255;oa=w;c:while(1){pa=(c[s>>2]|0)+(oa>>>3)|0;qa=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(oa&7)>>>24;pa=oa+8|0;c[r>>2]=pa;ra=na<<8;sa=qa|ra;do{if((ra|0)==256){qa=c[y>>2]|0;if((c[qa+688>>2]&256|0)!=0){KIb(qa,48,2430312,(ta=i,i=i+8|0,c[ta>>2]=sa,ta)|0);i=ta;d:do{if(sa>>>0<288>>>0){KIb(c[y>>2]|0,48,2419968,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}else{if(sa>>>0<304>>>0){KIb(c[y>>2]|0,48,2410672,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}if(sa>>>0<320>>>0){KIb(c[y>>2]|0,48,2403e3,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}if(sa>>>0<352>>>0){KIb(c[y>>2]|0,48,2396088,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}if(sa>>>0<432>>>0){KIb(c[y>>2]|0,48,2403e3,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}switch(sa|0){case 435:{KIb(c[y>>2]|0,48,2368928,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 445:{KIb(c[y>>2]|0,48,2303032,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 441:{KIb(c[y>>2]|0,48,2322440,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 448:{KIb(c[y>>2]|0,48,2280992,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 449:{KIb(c[y>>2]|0,48,2276992,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 432:{KIb(c[y>>2]|0,48,2389112,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 433:{KIb(c[y>>2]|0,48,2382256,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 446:{KIb(c[y>>2]|0,48,2291792,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 443:{KIb(c[y>>2]|0,48,2312768,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 440:{KIb(c[y>>2]|0,48,2328152,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 444:{KIb(c[y>>2]|0,48,2308096,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 438:{KIb(c[y>>2]|0,48,2339200,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 439:{KIb(c[y>>2]|0,48,2333656,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 451:{KIb(c[y>>2]|0,48,2267720,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 437:{KIb(c[y>>2]|0,48,2345392,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 436:{KIb(c[y>>2]|0,48,2353976,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 447:{KIb(c[y>>2]|0,48,2284960,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 434:{KIb(c[y>>2]|0,48,2375608,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 442:{KIb(c[y>>2]|0,48,2317320,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};case 450:{KIb(c[y>>2]|0,48,2272448,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d;break};default:{if(sa>>>0<454>>>0){KIb(c[y>>2]|0,48,2264056,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d}if(!(sa>>>0<512>>>0)){break d}KIb(c[y>>2]|0,48,2260200,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break d}}}}while(0);KIb(c[y>>2]|0,48,2255800,(ta=i,i=i+8|0,c[ta>>2]=c[r>>2],ta)|0);i=ta}do{if((sa-288|0)>>>0<16>>>0){qa=c[r>>2]|0;ua=qa+1|0;c[r>>2]=ua;va=c[s>>2]|0;wa=va+(ua>>>3)|0;xa=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(ua&7)>>>24;c[r>>2]=qa+9;c[A>>2]=xa;xa=c[r>>2]|0;qa=d[va+(xa>>>3)|0]|0;ua=xa+1|0;c[r>>2]=ua;if((qa&128>>>((xa&7)>>>0)|0)==0){ya=1;za=ua}else{qa=va+(ua>>>3)|0;wa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ua&7)>>>28;ua=xa+8|0;c[r>>2]=ua;ya=wa;za=ua}ua=va+(za>>>3)|0;wa=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(za&7)>>>28;c[r>>2]=za+4;c[B>>2]=wa;if((wa|0)==15){ua=c[r>>2]|0;xa=va+(ua>>>3)|0;qa=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(ua&7)>>>24;c[r>>2]=ua+8;ua=c[y>>2]|0;c[ua+224>>2]=qa;qa=c[r>>2]|0;xa=va+(qa>>>3)|0;Aa=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(qa&7)>>>24;c[r>>2]=qa+8;c[ua+228>>2]=Aa;Ba=va}else{va=1378736+(wa<<3)|0;wa=(c[y>>2]|0)+224|0;Aa=c[va+4>>2]|0;c[wa>>2]=c[va>>2];c[wa+4>>2]=Aa;Ba=c[s>>2]|0}Aa=c[r>>2]|0;wa=d[Ba+(Aa>>>3)|0]<<(Aa&7)>>>7;c[r>>2]=Aa+1;Aa=wa&1;c[C>>2]=Aa;do{if((Aa|0)==0){if((c[D>>2]|0)!=0){Ca=Ba;break}c[E>>2]=0;Ca=Ba}else{wa=c[r>>2]|0;va=Ba+(wa>>>3)|0;ua=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7);va=wa+2|0;c[r>>2]=va;if((ua&-1073741824|0)==1073741824){Da=va;Ea=Ba}else{KIb(c[y>>2]|0,16,2569568,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Da=c[r>>2]|0;Ea=c[s>>2]|0}va=d[Ea+(Da>>>3)|0]<<(Da&7)>>>7;c[r>>2]=Da+1;c[E>>2]=va&1;va=c[r>>2]|0;ua=d[Ea+(va>>>3)|0]|0;c[r>>2]=va+1;if((ua&128>>>((va&7)>>>0)|0)==0){Ca=Ea;break}c[r>>2]=va+80;Ca=Ea}}while(0);Aa=c[r>>2]|0;va=Ca+(Aa>>>3)|0;ua=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(Aa&7)>>>30;c[r>>2]=Aa+2;c[F>>2]=ua;do{if((ua|0)==0){Fa=(ya|0)==1;x=68}else{KIb(c[y>>2]|0,16,2565096,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Aa=(ya|0)==1;if((c[F>>2]|0)!=3|Aa){Fa=Aa;x=68;break}KIb(c[y>>2]|0,16,2562008,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Aa=(c[r>>2]|0)+4|0;c[r>>2]=Aa;Ga=Aa;Ha=0}}while(0);if((x|0)==68){x=0;Ga=c[r>>2]|0;Ha=Fa}ua=c[s>>2]|0;Aa=d[ua+(Ga>>>3)|0]|0;va=Ga+1|0;c[r>>2]=va;if((Aa&128>>>((Ga&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2560536,ta)|0);i=ta;Ia=c[r>>2]|0;Ja=c[s>>2]|0}else{Ia=va;Ja=ua}ua=Ja+(Ia>>>3)|0;va=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(Ia&7)>>>16;c[r>>2]=Ia+16;Ka=c[y>>2]|0;c[Ka+108>>2]=va;if((va|0)==0){x=73;break c}ua=va-1|0;va=ua>>>0>65535>>>0;Aa=va?ua>>>16:ua;ua=va?16:0;if((Aa&65280|0)==0){La=ua;Ma=Aa}else{La=ua|8;Ma=Aa>>>8}Aa=(d[1359664+Ma|0]|0)+La|0;c[H>>2]=(Aa|0)<0?1:Aa+1|0;Aa=c[r>>2]|0;ua=c[s>>2]|0;va=d[ua+(Aa>>>3)|0]|0;wa=Aa+1|0;c[r>>2]=wa;if((va&128>>>((Aa&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2557696,ta)|0);i=ta;Na=c[r>>2]|0;Oa=c[s>>2]|0}else{Na=wa;Oa=ua}ua=d[Oa+(Na>>>3)|0]|0;wa=Na+1|0;c[r>>2]=wa;if((ua&128>>>((Na&7)>>>0)|0)==0){c[(c[y>>2]|0)+104>>2]=1}else{ua=c[H>>2]|0;Aa=Oa+(wa>>>3)|0;va=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(wa&7)>>>((32-ua|0)>>>0);c[r>>2]=ua+wa;c[(c[y>>2]|0)+104>>2]=va}c[I>>2]=0;va=c[F>>2]|0;e:do{if((va|0)==0){wa=c[r>>2]|0;ua=d[Oa+(wa>>>3)|0]|0;Aa=wa+1|0;c[r>>2]=Aa;if((ua&128>>>((wa&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2556400,ta)|0);i=ta;Pa=c[r>>2]|0;Qa=c[s>>2]|0}else{Pa=Aa;Qa=Oa}Aa=Qa+(Pa>>>3)|0;wa=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Pa&7)>>>19;Aa=Pa+13|0;c[r>>2]=Aa;ua=d[Qa+(Aa>>>3)|0]|0;qa=Pa+14|0;c[r>>2]=qa;if((ua&128>>>((Aa&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2555312,ta)|0);i=ta;Ra=c[r>>2]|0;Sa=c[s>>2]|0}else{Ra=qa;Sa=Qa}qa=Sa+(Ra>>>3)|0;Aa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Ra&7)>>>19;qa=Ra+13|0;c[r>>2]=qa;ua=d[Sa+(qa>>>3)|0]|0;c[r>>2]=Ra+14;if((ua&128>>>((qa&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2554008,ta)|0);i=ta}if((wa|0)==0|(Aa|0)==0){x=95;break}qa=c[ba>>2]|0;do{if((qa|0)!=0){if((c[v>>2]|0)==1395937357){x=95;break e}ua=c[da>>2]|0;if((ua|0)==0){break}if((qa|0)==(wa|0)&(ua|0)==(Aa|0)){break}c[ea>>2]=1}}while(0);c[ba>>2]=wa;c[da>>2]=Aa;x=95}else if((va|0)!=2){x=95}}while(0);do{if((x|0)==95){x=0;va=c[r>>2]|0;qa=c[s>>2]|0;ua=d[qa+(va>>>3)|0]<<(va&7)>>>7;c[r>>2]=va+1;va=ua&1^1;c[J>>2]=va;c[K>>2]=va;c[L>>2]=0;va=c[r>>2]|0;ua=d[qa+(va>>>3)|0]|0;qa=va+1|0;c[r>>2]=qa;do{if((ua&128>>>((va&7)>>>0)|0)==0){xa=c[y>>2]|0;if((c[xa+688>>2]&1|0)==0){Ta=qa;break}KIb(xa,32,2551488,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Ta=c[r>>2]|0}else{Ta=qa}}while(0);if(Ha){qa=d[(c[s>>2]|0)+(Ta>>>3)|0]<<(Ta&7)>>>7;c[r>>2]=Ta+1;Ua=qa&1}else{qa=(c[s>>2]|0)+(Ta>>>3)|0;va=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Ta&7)>>>30;c[r>>2]=Ta+2;Ua=va}c[M>>2]=Ua;if((Ua|0)==1){KIb(c[y>>2]|0,16,2546976,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Va=c[M>>2]|0}else{Va=Ua}do{if((Va-1|0)>>>0<2>>>0){va=c[r>>2]|0;if((Va|0)==1){qa=va+56|0;c[r>>2]=qa;Wa=qa}else{Wa=va}va=c[s>>2]|0;qa=va+(Wa>>>3)|0;ua=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Wa&7);Xa=ua>>>26;c[r>>2]=Wa+6;c[N>>2]=Xa;if(ua>>>0>268435455>>>0){x=108;break c}ua=c[r>>2]|0;qa=va+(ua>>>3)|0;Aa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ua&7)>>>30;c[r>>2]=ua+2;c[O>>2]=Aa;Aa=c[r>>2]|0;ua=d[va+(Aa>>>3)|0]<<(Aa&7)>>>7;c[r>>2]=Aa+1;c[P>>2]=ua&1;if((c[M>>2]|0)!=1){Ya=va;break}c[r>>2]=(c[r>>2]|0)+1;Ya=va}else{Ya=c[s>>2]|0}}while(0);va=c[r>>2]|0;ua=d[Ya+(va>>>3)|0]|0;Aa=va+1|0;c[r>>2]=Aa;do{if((ua&128>>>((va&7)>>>0)|0)==0){c[Q>>2]=5}else{qa=Ya+(Aa>>>3)|0;wa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Aa&7)>>>28;c[r>>2]=va+5;c[Q>>2]=wa;wa=c[r>>2]|0;qa=Ya+(wa>>>3)|0;xa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(wa&7);c[r>>2]=wa+4;if(!((xa&-268435456|0)==-2147483648)){KIb(c[y>>2]|0,16,2543088,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}xa=c[Q>>2]|0;if((xa|0)==5){break}KIb(c[y>>2]|0,16,2541448,(ta=i,i=i+8|0,c[ta>>2]=xa,ta)|0);i=ta;if(!(((c[Q>>2]|0)-3|0)>>>0>6>>>0)){break}c[Q>>2]=5}}while(0);va=c[r>>2]|0;Aa=c[s>>2]|0;ua=d[Aa+(va>>>3)|0]<<(va&7)>>>7;c[r>>2]=va+1;va=ua&1;c[R>>2]=va;f:do{if((va|0)!=0){ua=0;do{xa=d[f+11184+ua|0]|0;wa=b[1344696+(ua<<1)>>1]|0;b[f+12560+(xa<<1)>>1]=wa;b[f+12688+(xa<<1)>>1]=wa;wa=b[1344568+(ua<<1)>>1]|0;b[f+12816+(xa<<1)>>1]=wa;b[f+12944+(xa<<1)>>1]=wa;ua=ua+1|0;}while((ua|0)<64);ua=c[r>>2]|0;wa=d[Aa+(ua>>>3)|0]|0;xa=ua+1|0;c[r>>2]=xa;g:do{if((wa&128>>>((ua&7)>>>0)|0)==0){Za=xa}else{qa=0;_a=0;$a=xa;while(1){ab=Aa+($a>>>3)|0;bb=(je(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<($a&7)>>>24;cb=$a+8|0;c[r>>2]=cb;if((bb|0)==0){break}ab=d[(d[1242080+_a|0]|0)+(f+11184)|0]|0;db=bb&65535;b[f+12560+(ab<<1)>>1]=db;b[f+12688+(ab<<1)>>1]=db;ab=_a+1|0;if((ab|0)<64){qa=db;_a=ab;$a=cb}else{Za=cb;break g}}if((_a|0)<64){eb=_a}else{Za=cb;break}while(1){$a=d[(d[1242080+eb|0]|0)+(f+11184)|0]|0;b[f+12560+($a<<1)>>1]=qa;b[f+12688+($a<<1)>>1]=qa;$a=eb+1|0;if(($a|0)<64){eb=$a}else{Za=cb;break}}}}while(0);xa=d[Aa+(Za>>>3)|0]|0;ua=Za+1|0;c[r>>2]=ua;if((xa&128>>>((Za&7)>>>0)|0)==0){break}else{fb=0;gb=0;hb=ua}while(1){ua=Aa+(hb>>>3)|0;xa=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(hb&7)>>>24;ua=hb+8|0;c[r>>2]=ua;if((xa|0)==0){break}wa=d[(d[1242080+gb|0]|0)+(f+11184)|0]|0;qa=xa&65535;b[f+12816+(wa<<1)>>1]=qa;b[f+12944+(wa<<1)>>1]=qa;wa=gb+1|0;if((wa|0)<64){fb=qa;gb=wa;hb=ua}else{break f}}if((gb|0)<64){ib=gb}else{break}do{ua=d[(d[1242080+ib|0]|0)+(f+11184)|0]|0;b[f+12816+(ua<<1)>>1]=fb;b[f+12944+(ua<<1)>>1]=fb;ib=ib+1|0;}while((ib|0)<64)}}while(0);va=(ya|0)!=1;if(va){ua=c[r>>2]|0;wa=d[Aa+(ua>>>3)|0]<<(ua&7)>>>7;c[r>>2]=ua+1;jb=wa&1}else{jb=0}c[S>>2]=jb;wa=c[r>>2]|0;if(((c[u>>2]|0)-wa|0)<4){x=133;break c}ua=d[Aa+(wa>>>3)|0]|0;qa=wa+1|0;c[r>>2]=qa;do{if((ua&128>>>((wa&7)>>>0)|0)==0){xa=Aa+(qa>>>3)|0;_a=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(qa&7);xa=_a>>>30;$a=wa+3|0;c[r>>2]=$a;if(!((_a|0)>-1)){KIb(c[y>>2]|0,16,2536168,(ta=i,i=i+8|0,c[ta>>2]=xa,ta)|0);i=ta;break}_a=d[Aa+($a>>>3)|0]|0;ab=wa+4|0;c[r>>2]=ab;if((_a&128>>>(($a&7)>>>0)|0)==0){$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=wa+5;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<3&8)+(c[T>>2]|0);_a=c[r>>2]|0;$a=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=_a+1;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<3&8)+(c[T>>2]|0);_a=c[r>>2]|0;$a=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=_a+1;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<3&8)+(c[T>>2]|0);kb=c[r>>2]|0}else{kb=ab}ab=d[Aa+(kb>>>3)|0]|0;_a=kb+1|0;c[r>>2]=_a;if((ab&128>>>((kb&7)>>>0)|0)==0){ab=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=kb+2;c[T>>2]=(ab<<3&8)+(c[T>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0);$a=c[r>>2]|0;ab=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[U>>2]=(ab<<3&8)+(c[U>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[T>>2]=($a<<3&8)+(c[T>>2]|0);lb=c[r>>2]|0}else{lb=_a}_a=d[Aa+(lb>>>3)|0]|0;$a=lb+1|0;c[r>>2]=$a;if((_a&128>>>((lb&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2538904,ta)|0);i=ta;c[r>>2]=qa;x=151;break}_a=d[Aa+($a>>>3)|0]|0;ab=lb+2|0;c[r>>2]=ab;if((_a&128>>>(($a&7)>>>0)|0)==0){$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=lb+3;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<3&8)+(c[T>>2]|0);_a=c[r>>2]|0;$a=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=_a+1;c[T>>2]=($a<<3&8)+(c[T>>2]|0);$a=c[r>>2]|0;_a=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[T>>2]=(_a<<2&4)+(c[T>>2]|0);mb=c[r>>2]|0}else{mb=ab}ab=d[Aa+(mb>>>3)|0]|0;_a=mb+1|0;c[r>>2]=_a;if((ab&128>>>((mb&7)>>>0)|0)==0){ab=d[Aa+(_a>>>3)|0]<<(_a&7)>>>7;c[r>>2]=mb+2;c[U>>2]=(ab<<3&8)+(c[U>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0);$a=c[r>>2]|0;ab=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[V>>2]=(ab<<3&8)+(c[V>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0);$a=c[r>>2]|0;ab=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=$a+1;c[U>>2]=(ab<<3&8)+(c[U>>2]|0);ab=c[r>>2]|0;$a=d[Aa+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=ab+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0);nb=c[r>>2]|0}else{nb=_a}_a=d[Aa+(nb>>>3)|0]|0;$a=nb+1|0;c[r>>2]=$a;if((_a&128>>>((nb&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2537520,ta)|0);i=ta;c[r>>2]=qa;x=151;break}if((xa|0)!=1){break}xa=d[Aa+($a>>>3)|0]<<($a&7)>>>7;c[r>>2]=nb+2;c[T>>2]=(xa<<3&8)+(c[T>>2]|0);xa=c[r>>2]|0;$a=d[Aa+(xa>>>3)|0]<<(xa&7)>>>7;c[r>>2]=xa+1;c[U>>2]=($a<<3&8)+(c[U>>2]|0)}else{x=151}}while(0);if((x|0)==151){x=0;c[V>>2]=0;c[U>>2]=0;c[T>>2]=0}Aa=c[r>>2]|0;qa=c[s>>2]|0;wa=d[qa+(Aa>>>3)|0]<<(Aa&7);c[r>>2]=Aa+1;c[W>>2]=wa>>>7&1^1;wa=c[r>>2]|0;Aa=d[qa+(wa>>>3)|0]<<(wa&7)>>>7;c[r>>2]=wa+1;wa=Aa&1;c[X>>2]=wa;if((wa|0)!=0){wa=c[r>>2]|0;Aa=d[qa+(wa>>>3)|0]<<(wa&7)>>>7;c[r>>2]=wa+1;c[aa>>2]=Aa&1}do{if(va){Aa=c[r>>2]|0;wa=d[qa+(Aa>>>3)|0]<<(Aa&7)>>>7;c[r>>2]=Aa+1;Aa=wa&1;c[Y>>2]=Aa;if((Aa|0)==0){ob=qa;pb=c[r>>2]|0}else{KIb(c[y>>2]|0,16,2534944,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;Aa=(c[r>>2]|0)+3|0;c[r>>2]=Aa;ob=c[s>>2]|0;pb=Aa}Aa=d[ob+(pb>>>3)|0]|0;c[r>>2]=pb+1;if((Aa&128>>>((pb&7)>>>0)|0)==0){qb=ob;break}KIb(c[y>>2]|0,16,2533328,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;qb=c[s>>2]|0}else{c[Y>>2]=0;qb=qa}}while(0);qa=c[r>>2]|0;va=d[qb+(qa>>>3)|0]<<(qa&7)>>>7;c[r>>2]=qa+1;qa=va&1;c[Z>>2]=qa;if((qa|0)==0){break}c[z>>2]=c[_>>2];c[z+4>>2]=c[_+4>>2];c[z+8>>2]=c[_+8>>2];c[z+12>>2]=c[_+12>>2];c[z+16>>2]=c[_+16>>2];qa=c[r>>2]|0;va=qa+6|0;c[r>>2]=va;Aa=qb+(va>>>3)|0;wa=je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0;Aa=qa+11|0;c[r>>2]=Aa;ua=qb+(Aa>>>3)|0;$a=je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0;ua=qa+16|0;c[r>>2]=ua;xa=qb+(ua>>>3)|0;_a=je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0;xa=qa+21|0;c[r>>2]=xa;ab=qb+(xa>>>3)|0;db=je(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0;ab=qa+26|0;c[r>>2]=ab;bb=d[qb+(ab>>>3)|0]<<(ab&7)>>>7;c[r>>2]=qa+27;c[$>>2]=bb&1;if((-134217728>>>((va&7)>>>0)&wa|0)==0|($a&-134217728>>>((Aa&7)>>>0)|0)==0|(_a&-134217728>>>((ua&7)>>>0)|0)==0|(db&-134217728>>>((xa&7)>>>0)|0)==0){c[Z>>2]=0;c[_>>2]=c[z>>2];c[_+4>>2]=c[z+4>>2];c[_+8>>2]=c[z+8>>2];c[_+12>>2]=c[z+12>>2];c[_+16>>2]=c[z+16>>2];break}else{KIb(c[y>>2]|0,16,2529320,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}}}while(0);xa=c[y>>2]|0;if((c[xa+688>>2]&1|0)==0){break}db=c[xa+108>>2]|0;ua=c[H>>2]|0;_a=c[Q>>2]|0;Aa=c[K>>2]|0;$a=(c[Z>>2]|0)!=0?2525728:10230536;wa=(c[S>>2]|0)!=0?2524408:10230536;va=(c[X>>2]|0)!=0?2523440:10230536;bb=(c[aa>>2]|0)!=0?2522488:10230536;KIb(xa,48,2526856,(ta=i,i=i+72|0,c[ta>>2]=c[xa+104>>2],c[ta+8>>2]=db,c[ta+16>>2]=ua,c[ta+24>>2]=_a,c[ta+32>>2]=Aa,c[ta+40>>2]=$a,c[ta+48>>2]=wa,c[ta+56>>2]=va,c[ta+64>>2]=bb,ta)|0);i=ta}else{if((sa|0)==434){c[k>>2]=0;c[l>>2]=0;c[m>>2]=0;c[n>>2]=0;bb=c[u>>2]|0;va=0;wa=c[r>>2]|0;while(1){if((wa|0)>=(bb|0)){rb=va;break}$a=(c[s>>2]|0)+(wa>>>3)|0;Aa=je(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0;$a=wa&7;if((Aa&-512>>>($a>>>0)|0)==0){rb=va;break}_a=wa+8|0;c[r>>2]=_a;a[j+va|0]=Aa<<$a>>>24;$a=va+1|0;if(($a|0)<255){va=$a;wa=_a}else{rb=$a;break}}a[j+rb|0]=0;wa=Bd(fa|0,2582304,(ta=i,i=i+24|0,c[ta>>2]=k,c[ta+8>>2]=l,c[ta+16>>2]=o,ta)|0)|0;i=ta;if((wa|0)<2){va=Bd(fa|0,2580312,(ta=i,i=i+24|0,c[ta>>2]=k,c[ta+8>>2]=l,c[ta+16>>2]=o,ta)|0)|0;i=ta;if((va|0)>1){sb=va;x=174}}else{sb=wa;x=174}do{if((x|0)==174){x=0;c[ga>>2]=c[k>>2];c[ha>>2]=c[l>>2];if((sb|0)!=3){c[ia>>2]=0;break}wa=(a[o]|0)==112;c[ia>>2]=wa&1;if(!wa){break}if((c[ja>>2]|0)!=0){break}KIb(c[y>>2]|0,32,2578008,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[ja>>2]=1}}while(0);wa=Bd(fa|0,2576696,(ta=i,i=i+8|0,c[ta>>2]=l,ta)|0)|0;i=ta;do{if((wa|0)==1){x=185}else{va=Bd(fa|0,2575264,(ta=i,i=i+32|0,c[ta>>2]=k,c[ta+8>>2]=m,c[ta+16>>2]=n,c[ta+24>>2]=l,ta)|0)|0;i=ta;if((va|0)==4){x=185;break}va=Bd(fa|0,2574016,(ta=i,i=i+24|0,c[ta>>2]=k,c[ta+8>>2]=m,c[ta+16>>2]=n,ta)|0)|0;i=ta;if((va|0)>0){c[l>>2]=(c[m>>2]<<8)+(c[k>>2]<<16)+(c[n>>2]|0);if((va|0)==3){x=185;break}}if((irc(fa,2572488)|0)!=0){break}c[ka>>2]=4600}}while(0);if((x|0)==185){x=0;c[ka>>2]=c[l>>2]}wa=Bd(fa|0,2571080,(ta=i,i=i+8|0,c[ta>>2]=l,ta)|0)|0;i=ta;if((wa|0)!=1){break}c[la>>2]=c[l>>2];break}else if((sa|0)==432){wa=c[y>>2]|0;va=c[r>>2]|0;bb=c[s>>2]|0;$a=bb+(va>>>3)|0;_a=(je(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(va&7)>>>28;c[r>>2]=va+4;va=wa+840|0;c[va>>2]=_a;_a=c[r>>2]|0;$a=bb+(_a>>>3)|0;bb=(je(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(_a&7)>>>28;c[r>>2]=_a+4;_a=wa+844|0;c[_a>>2]=bb;if(!((c[va>>2]|0)==0&(bb|0)==8)){break}c[_a>>2]=0;break}else if((sa|0)==438){break a}else if((sa|0)==435){_a=c[s>>2]|0;bb=c[r>>2]|0;va=_a+(bb>>>3)|0;wa=je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0;va=bb&7;if((wa&-512>>>(va>>>0)|0)==0){KIb(c[y>>2]|0,24,2585968,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;break}else{$a=bb+5|0;c[r>>2]=$a;Aa=_a+($a>>>3)|0;ua=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<($a&7)>>>26;$a=bb+12|0;c[r>>2]=$a;Aa=_a+($a>>>3)|0;_a=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<($a&7)>>>26;c[r>>2]=bb+18;c[ma>>2]=_a+((ua+((wa<<va>>>27)*60|0)|0)*60|0);c[r>>2]=(c[r>>2]|0)+2;break}}else{break}}}while(0);va=c[r>>2]|0;wa=-va&7;if((wa|0)==0){tb=255;ub=va;break}ua=wa+va|0;c[r>>2]=ua;tb=255;ub=ua}else{tb=sa;ub=pa}}while(0);pa=c[u>>2]|0;if((ub|0)<(pa|0)){na=tb;oa=ub}else{vb=pa;break b}}if((x|0)==73){KIb(Ka,16,2558776,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[(c[y>>2]|0)+104>>2]=0;wb=-1;i=h;return wb|0}else if((x|0)==108){KIb(c[y>>2]|0,16,2544456,(ta=i,i=i+8|0,c[ta>>2]=Xa,ta)|0);i=ta;c[N>>2]=0;wb=-1;i=h;return wb|0}else if((x|0)==133){KIb(c[y>>2]|0,16,2540256,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;wb=-1;i=h;return wb|0}}else{vb=t}}while(0);do{if((vb|0)==8){if((c[f+14748>>2]|0)>-1){break}if(!((c[f+14756>>2]|0)>-1)){x=11}}else{x=11}}while(0);do{if((x|0)==11){if((c[v>>2]|0)==877677905){break}else{wb=-1}i=h;return wb|0}}while(0);KIb(c[f+4>>2]|0,40,2442288,(ta=i,i=i+8|0,c[ta>>2]=vb,ta)|0);i=ta;wb=100;i=h;return wb|0}}while(0);vb=f+60|0;v=f+13944|0;if((c[vb>>2]&524288|0)==0){xb=(c[v>>2]|0)==0|0}else{c[v>>2]=1;xb=0}v=f+13944|0;Xa=f+4|0;Ka=c[Xa>>2]|0;c[Ka+176>>2]=xb;xb=c[r>>2]|0;ub=g|0;tb=(c[ub>>2]|0)+(xb>>>3)|0;l=(je(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(xb&7)>>>30;c[r>>2]=xb+2;xb=l+1|0;l=f+9992|0;c[l>>2]=xb;do{if((xb|0)==3){if((c[v>>2]|0)==0){break}if((c[f+13952>>2]|0)!=0){break}if((c[vb>>2]&524288|0)!=0){break}KIb(Ka,16,2107912,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[v>>2]=0}}while(0);Ka=f+13936|0;if((c[Ka>>2]|0)==0){yb=0}else{yb=(c[l>>2]|0)!=3}c[f+13940>>2]=yb&1;c[f+14348>>2]=yb?534:1042;yb=c[ub>>2]|0;vb=0;xb=c[r>>2]|0;while(1){tb=d[yb+(xb>>>3)|0]|0;zb=xb+1|0;c[r>>2]=zb;if((tb&128>>>((xb&7)>>>0)|0)==0){break}else{vb=vb+1|0;xb=zb}}tb=d[yb+(zb>>>3)|0]|0;c[r>>2]=xb+2;if((tb&128>>>((zb&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2106568,ta)|0);i=ta}zb=f+14672|0;tb=c[zb>>2]|0;if((tb|0)==0){x=211}else{xb=c[r>>2]|0;yb=(c[ub>>2]|0)+(xb>>>3)|0;if(((je(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(xb&7)&1<<31-tb|0)==0){x=211}}do{if((x|0)==211){KIb(c[Xa>>2]|0,16,2105152,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[zb>>2]=1;tb=f+14680|0;xb=c[l>>2]|0;h:do{if((xb|0)==2){yb=1;while(1){n=c[r>>2]|0;k=(c[ub>>2]|0)+(n>>>3)|0;if(((je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(n&7)>>>((26-yb|0)>>>0)&55|0)==48){Ab=yb;break h}n=yb+1|0;c[zb>>2]=n;if((n|0)<16){yb=n}else{Ab=n;break}}}else if((xb|0)==4){yb=1;while(1){y=(c[tb>>2]|0)==2;N=c[r>>2]|0;n=(c[ub>>2]|0)+(N>>>3)|0;k=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(N&7);if(y){if((k>>>((26-yb|0)>>>0)&55|0)==48){Ab=yb;break h}}else{if((k>>>((27-yb|0)>>>0)&31|0)==24){Ab=yb;break h}}k=yb+1|0;c[zb>>2]=k;if((k|0)<16){yb=k}else{Ab=k;break}}}else{yb=1;while(1){k=c[r>>2]|0;y=(c[ub>>2]|0)+(k>>>3)|0;if(((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(k&7)>>>((27-yb|0)>>>0)&31|0)==24){Ab=yb;break h}k=yb+1|0;c[zb>>2]=k;if((k|0)<16){yb=k}else{Ab=k;break}}}}while(0);KIb(c[Xa>>2]|0,16,2644288,(ta=i,i=i+8|0,c[ta>>2]=Ab,ta)|0);i=ta;tb=(c[Xa>>2]|0)+108|0;xb=c[tb>>2]|0;if((xb|0)==0){break}yb=1<<c[zb>>2];if((xb<<2|0)>=(yb|0)){break}c[tb>>2]=yb}}while(0);Ab=c[zb>>2]|0;yb=c[r>>2]|0;tb=(c[ub>>2]|0)+(yb>>>3)|0;xb=(je(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(yb&7)>>>((32-Ab|0)>>>0);c[r>>2]=yb+Ab;do{if((c[l>>2]|0)==3){Ab=(ca(c[(c[Xa>>2]|0)+108>>2]|0,(c[f+13848>>2]|0)+vb|0)|0)+xb|0;yb=Ab;tb=(Ab|0)<0|0?-1:0;Ab=f+13856|0;c[Ab>>2]=yb;c[Ab+4>>2]=tb;k=f+13872|0;y=b[k>>1]|0;N=f+13864|0;n=xrc(yb,tb,c[N>>2]|0,c[N+4>>2]|0)|0;tb=wrc(n,G,y&65535,0)|0;n=f+13874|0;b[n>>1]=tb;yb=tb&65535;if((y&65535)>>>0<=yb>>>0|(yb|0)==0|y<<16>>16==0){wb=100;i=h;return wb|0}GRa(q);y=f+14724|0;yb=c[y>>2]|0;do{if((yb|0)==0){tb=b[n>>1]|0;m=tb&65535;c[y>>2]=m;if(!(tb<<16>>16==0)){Bb=m;break}c[y>>2]=1;Bb=1}else{Bb=yb}}while(0);yb=c[N>>2]|0;y=c[N+4>>2]|0;n=0;m=(y|0)>(n|0)|(y|0)==(n|0)&yb>>>0>0>>>0;n=Bb>>1;tb=n;o=(n|0)<0|0?-1:0;n=xrc(0,0,tb,o)|0;sb=G;rb=wrc(m?tb:n,m?o:sb,yb,y)|0;m=Bb;j=(Bb|0)<0|0?-1:0;qb=Crc(rb,G,m,j)|0;rb=G;ob=xrc(yb,y,e[k>>1]|0,0)|0;y=G;yb=0;pb=(y|0)>(yb|0)|(y|0)==(yb|0)&ob>>>0>0>>>0;yb=wrc(pb?tb:n,pb?o:sb,ob,y)|0;y=Crc(yb,G,m,j)|0;yb=G;ob=xrc(qb,rb,y,yb)|0;rb=ob<<1|0>>>31;ob=f+13876|0;b[ob>>1]=rb;qb=c[Ab>>2]|0;pb=c[Ab+4>>2]|0;nb=0;mb=(pb|0)>(nb|0)|(pb|0)==(nb|0)&qb>>>0>0>>>0;nb=wrc(mb?tb:n,mb?o:sb,qb,pb)|0;sb=Crc(nb,G,m,j)|0;j=xrc(sb,G,y,yb)|0;yb=j<<1|0>>>31;j=f+13878|0;b[j>>1]=yb;y=yb&65534;if(!((rb&65534)>>>0<=y>>>0|y>>>0<2>>>0)){Cb=pb;Db=qb;break}b[j>>1]=2;b[ob>>1]=4;if((c[f+14152>>2]|0)==0){wb=100}else{Cb=pb;Db=qb;break}i=h;return wb|0}else{qb=f+13852|0;pb=c[qb>>2]|0;c[f+13848>>2]=pb;ob=pb+vb|0;c[qb>>2]=ob;pb=(c[Xa>>2]|0)+108|0;j=(ca(c[pb>>2]|0,ob)|0)+xb|0;y=j;rb=(j|0)<0|0?-1:0;j=f+13856|0;c[j>>2]=y;c[j+4>>2]=rb;yb=f+13864|0;sb=c[yb>>2]|0;m=c[yb+4>>2]|0;if((c[f+84>>2]&8|0)!=0&((rb|0)<(m|0)|(rb|0)==(m|0)&y>>>0<sb>>>0)){c[qb>>2]=ob+1;ob=c[pb>>2]|0;pb=wrc(ob,(ob|0)<0|0?-1:0,y,rb)|0;ob=G;c[j>>2]=pb;c[j+4>>2]=ob;Eb=ob;Fb=pb}else{Eb=rb;Fb=y}y=xrc(Fb,Eb,sb,m)|0;b[f+13872>>1]=y;c[yb>>2]=Fb;c[yb+4>>2]=Eb;Cb=Eb;Db=Fb}}while(0);Fb=c[Xa>>2]|0;Eb=c[Fb+104>>2]|0;if((Eb|0)==0){Gb=-2147483648;Hb=0}else{vb=0;Bb=(Cb|0)>(vb|0)|(Cb|0)==(vb|0)&Db>>>0>0>>>0;vb=Eb>>1;q=vb;yb=(vb|0)<0|0?-1:0;vb=xrc(0,0,q,yb)|0;y=wrc(Bb?q:vb,Bb?yb:G,Db,Cb)|0;Cb=Crc(y,G,Eb,(Eb|0)<0|0?-1:0)|0;Gb=G;Hb=Cb}if((c[Fb+688>>2]&512|0)!=0){KIb(Fb,48,2642448,(ta=i,i=i+16|0,c[ta>>2]=Hb,c[ta+8>>2]=Gb,ta)|0);i=ta}Gb=c[r>>2]|0;Hb=c[ub>>2]|0;Fb=d[Hb+(Gb>>>3)|0]|0;Cb=Gb+1|0;c[r>>2]=Cb;if((Fb&128>>>((Gb&7)>>>0)|0)==0){KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2636048,ta)|0);i=ta;Ib=c[r>>2]|0;Jb=c[ub>>2]|0}else{Ib=Cb;Jb=Hb}Hb=d[Jb+(Ib>>>3)|0]|0;Cb=Ib+1|0;c[r>>2]=Cb;if((Hb&128>>>((Ib&7)>>>0)|0)==0){Ib=c[Xa>>2]|0;if((c[Ib+688>>2]&1|0)==0){wb=100;i=h;return wb|0}KIb(Ib,16,2632840,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;wb=100;i=h;return wb|0}do{if((c[f+14728>>2]|0)!=0){Ib=(c[zb>>2]|0)+3|0;Hb=(Ib|0)>15?15:Ib;Ib=Hb+Cb|0;c[r>>2]=Ib;Gb=Ib+1+((128>>>((Ib&7)>>>0)&d[Jb+(Ib>>>3)|0]|0)==0?0:Hb)|0;c[r>>2]=Gb;Hb=d[Jb+(Gb>>>3)|0]|0;c[r>>2]=Gb+1;if((128>>>((Gb&7)>>>0)&Hb|0)!=0){break}KIb(0,32,2510544,(ta=i,i=i+8|0,c[ta>>2]=2511776,ta)|0);i=ta}}while(0);Jb=f+14676|0;Cb=c[Jb>>2]|0;do{if((Cb|0)==2){x=249}else{zb=c[l>>2]|0;if((zb|0)==4){if((c[f+14680>>2]|0)!=2){x=249;break}}else if((zb|0)!=2){x=249;break}zb=c[r>>2]|0;Hb=d[(c[ub>>2]|0)+(zb>>>3)|0]<<(zb&7)>>>7;c[r>>2]=zb+1;c[f+12472>>2]=Hb&1;Kb=c[Jb>>2]|0}}while(0);if((x|0)==249){c[f+12472>>2]=0;Kb=Cb}do{if((Kb|0)==0){Lb=c[r>>2]|0;x=258}else{do{if((c[f+14680>>2]|0)==1){if((c[l>>2]|0)!=1){x=255;break}Mb=c[r>>2]|0}else{x=255}}while(0);if((x|0)==255){Ab=(c[r>>2]|0)+55|0;c[r>>2]=Ab;Mb=Ab}Ab=Mb+1|0;c[r>>2]=Ab;k=((d[(c[ub>>2]|0)+(Ab>>>3)|0]&128>>>((Ab&7)>>>0)|0)==0?2:10)+Mb|0;c[r>>2]=k;if((c[Jb>>2]|0)!=2){Lb=k;x=258;break}Nb=c[f+14200>>2]|0;x=266}}while(0);do{if((x|0)==258){Mb=(c[f+14768>>2]|0)+Lb|0;c[r>>2]=Mb;do{if((c[l>>2]|0)==1){Ob=Mb}else{Kb=(c[f+14772>>2]|0)+Mb|0;c[r>>2]=Kb;if((c[l>>2]|0)!=3){Ob=Kb;break}k=(c[f+14776>>2]|0)+Kb|0;c[r>>2]=k;Ob=k}}while(0);if(((c[g+12>>2]|0)-Ob|0)<3){KIb(c[Xa>>2]|0,16,2630688,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;wb=-1;i=h;return wb|0}Mb=c[ub>>2]|0;k=Mb+(Ob>>>3)|0;Kb=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Ob&7)>>>29;c[r>>2]=Ob+3;c[f+14744>>2]=d[1344928+Kb|0]|0;if((c[f+14152>>2]|0)==0){Kb=c[r>>2]|0;k=d[Mb+(Kb>>>3)|0]<<(Kb&7)>>>7;c[r>>2]=Kb+1;c[f+14184>>2]=k&1;k=c[r>>2]|0;Kb=d[Mb+(k>>>3)|0]<<(k&7)>>>7;c[r>>2]=k+1;k=Kb&1;c[f+14200>>2]=k;Nb=k;x=266;break}else{k=f+14200|0;c[k>>2]=0;Pb=k;Qb=f+11184|0;Rb=f+232|0;x=268;break}}}while(0);do{if((x|0)==266){Ob=f+14200|0;Lb=f+11184|0;k=f+232|0;if((Nb|0)==0){Pb=Ob;Qb=Lb;Rb=k;x=268;break}L6(Lb,k,1433224);L6(Lb,f+364|0,1433224);L6(Lb,f+496|0,1433224);L6(Lb,f+628|0,1433224);Sb=Ob}}while(0);if((x|0)==268){L6(Qb,Rb,1242080);L6(Qb,f+364|0,1242080);L6(Qb,f+496|0,1433288);L6(Qb,f+628|0,1433224);Sb=Pb}do{if((c[l>>2]|0)==4){Pb=f+14680|0;if(!(((c[Pb>>2]|0)-1|0)>>>0<2>>>0)){break}if((ORa(f,g)|0)<0){wb=-1094995529;i=h;return wb|0}if((c[f+14684>>2]|0)!=0){KIb(c[Xa>>2]|0,16,2628824,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}if((c[Pb>>2]|0)!=1){break}KIb(c[Xa>>2]|0,16,2627296,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}}while(0);do{if((c[Jb>>2]|0)!=2){Pb=c[f+13920>>2]|0;Qb=c[r>>2]|0;Rb=c[ub>>2]|0;Nb=Rb+(Qb>>>3)|0;Ob=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Qb&7)>>>((32-Pb|0)>>>0);c[r>>2]=Qb+Pb;Pb=f+9960|0;c[Pb>>2]=Ob;c[f+9964>>2]=Ob;if((Ob|0)==0){KIb(c[Xa>>2]|0,16,2625904,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;wb=-1;i=h;return wb|0}do{if((c[l>>2]|0)==1){c[f+11556>>2]=1;x=286}else{Ob=c[r>>2]|0;Qb=Rb+(Ob>>>3)|0;Nb=(je(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(Ob&7)>>>29;c[r>>2]=Ob+3;Ob=f+11556|0;c[Ob>>2]=Nb;if((Nb|0)==0){KIb(c[Xa>>2]|0,16,2624680,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[Ob>>2]=1;wb=-1;i=h;return wb|0}if((c[l>>2]|0)!=3){x=286;break}Ob=c[r>>2]|0;Nb=Rb+(Ob>>>3)|0;Qb=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Ob&7)>>>29;c[r>>2]=Ob+3;Ob=f+11560|0;c[Ob>>2]=Qb;if((Qb|0)!=0){Tb=Qb;break}KIb(c[Xa>>2]|0,16,2623184,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[Ob>>2]=1;wb=-1;i=h;return wb|0}}while(0);if((x|0)==286){c[f+11560>>2]=1;Tb=1}Rb=c[Xa>>2]|0;if((c[Rb+688>>2]&1|0)!=0){Ob=Rb;Rb=c[Pb>>2]|0;Qb=c[f+11556>>2]|0;Nb=c[l>>2]|0;do{if((Nb|0)==1){Ub=2619184}else{if((Nb|0)==2){Ub=2612632;break}Ub=(Nb|0)==3?2609040:2606056}}while(0);Nb=c[g+12>>2]|0;Pb=c[f+14152>>2]|0;Lb=c[Sb>>2]|0;k=c[f+14184>>2]|0;Kb=(c[f+13924>>2]|0)!=0?2603888:2601856;Mb=c[Ka>>2]|0;Ab=c[f+14720>>2]|0;N=c[f+14688>>2]|0;Cb=c[f+13932>>2]|0;Hb=1-(c[f+12472>>2]|0)|0;zb=c[f+13948>>2]|0;Gb=(c[f+13952>>2]|0)!=0?2600080:2598488;Ib=c[f+14744>>2]|0;Fb=c[f+14768>>2]|0;Eb=c[f+14772>>2]|0;y=c[f+14776>>2]|0;Db=f+13856|0;yb=c[Db>>2]|0;Bb=c[Db+4>>2]|0;KIb(Ob,48,2621632,(ta=i,i=i+184|0,c[ta>>2]=Rb,c[ta+8>>2]=Qb,c[ta+16>>2]=Tb,c[ta+24>>2]=Ub,c[ta+32>>2]=Nb,c[ta+40>>2]=Pb,c[ta+48>>2]=Lb,c[ta+56>>2]=k,c[ta+64>>2]=Kb,c[ta+72>>2]=Mb,c[ta+80>>2]=Ab,c[ta+88>>2]=N,c[ta+96>>2]=Cb,c[ta+104>>2]=Hb,c[ta+112>>2]=zb,c[ta+120>>2]=Gb,c[ta+128>>2]=Ib,c[ta+136>>2]=Fb,c[ta+144>>2]=Eb,c[ta+152>>2]=y,c[ta+160>>2]=yb,c[ta+168>>2]=Bb,c[ta+176>>2]=xb,ta)|0);i=ta}if((c[f+14736>>2]|0)==0){if((c[Jb>>2]|0)==0){break}if((c[l>>2]|0)==1){break}c[r>>2]=(c[r>>2]|0)+1;break}do{if((c[f+14732>>2]|0)!=0){Bb=c[r>>2]|0;yb=d[(c[ub>>2]|0)+(Bb>>>3)|0]|0;c[r>>2]=Bb+1;if((yb&128>>>((Bb&7)>>>0)|0)==0){break}KIb(c[Xa>>2]|0,16,2595984,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta}}while(0);c[r>>2]=(c[r>>2]|0)+2}}while(0);do{if((c[f+13948>>2]|0)==0){if((c[f+13952>>2]|0)!=0){break}if(!((c[f+14748>>2]|0)==-1)){break}if((c[f+108>>2]|0)!=0){break}KIb(c[Xa>>2]|0,24,2594e3,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;c[v>>2]=1}}while(0);v=f+108|0;c[v>>2]=(c[v>>2]|0)+1;c[f+9888>>2]=1343568;c[f+9892>>2]=1344936;if((c[f+84>>2]&1024|0)==0){wb=0;i=h;return wb|0}c[f+136>>2]=c[f+8>>2];c[f+140>>2]=c[f+12>>2];wb=0;i=h;return wb|0}function SRa(){var b=0;if(a[1343504]|0){return}ATa(1343600,7664064);ATa(1312288,7664454);ATa(1312096,7664844);c[335912]=7316504;c[335914]=554;b=c[335902]|0;$2(1343644,9,(c[335900]|0)+1|0,b+2|0,4,2,b,4,2,0,0,0,4)|0;if((c[335916]|0)==0){b=0;do{c[1343664+(b<<2)>>2]=7593152+(b*2216|0);b=b+1|0;}while((b|0)<32);BTa(1343600)}c[328084]=7312216;c[328086]=1072;b=c[328074]|0;$2(1312332,9,(c[328072]|0)+1|0,b+2|0,4,2,b,4,2,0,0,0,4)|0;if((c[328088]|0)==0){b=0;do{c[1312352+(b<<2)>>2]=7455936+(b*4288|0);b=b+1|0;}while((b|0)<32);BTa(1312288)}c[328036]=7307928;c[328038]=1072;b=c[328026]|0;$2(1312140,9,(c[328024]|0)+1|0,b+2|0,4,2,b,4,2,0,0,0,4)|0;if((c[328040]|0)==0){b=0;do{c[1312160+(b<<2)>>2]=7318720+(b*4288|0);b=b+1|0;}while((b|0)<32);BTa(1312096)}c[2443063]=7305880;c[2443065]=512;$2(9772248,9,10,1344969,2,1,1344968,2,1,0,0,0,4)|0;c[2443069]=7303832;c[2443071]=512;$2(9772272,9,10,1345001,2,1,1345e3,2,1,0,0,0,4)|0;c[1273385]=7303320;c[1273387]=128;$2(5093536,6,15,1303578,4,2,1303576,4,2,0,0,0,4)|0;c[1447567]=7303256;c[1447569]=16;$2(5790264,4,4,1358737,2,1,1358736,2,1,0,0,0,4)|0;a[1343504]=1;return}function TRa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=c[b+60>>2]|0;if((c[f+14012>>2]|0)==0){g=0;return g|0}b=f+14016|0;h=b;if((c[f+14120>>2]|0)==(c[h>>2]|0)){i=0}else{i=c[f+14128>>2]>>3}j=e-i|0;if((j|0)<=7){g=0;return g|0}k=e-4|0;if((i|0)<(k|0)){l=i}else{g=0;return g|0}a:while(1){e=l+1|0;do{if((a[d+l|0]|0)==0){if((a[d+e|0]|0)!=0){break}if((a[d+(l+2)|0]|0)!=1){break}if((a[d+(l+3)|0]|0)==-74){break a}}}while(0);if((e|0)<(k|0)){l=e}else{g=0;m=14;break}}if((m|0)==14){return g|0}if(!((a[d+(l+4)|0]&64)==0)){g=0;return g|0}A4a(b,f+14024|0,j);b=c[h>>2]|0;if((b|0)==0){g=-12;return g|0}nrc(b|0,d+i|0,j)|0;c[f+14020>>2]=j;g=0;return g|0}function URa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;mrc(b+14748|0,-1|0,16)|0;d=Vga(a)|0;if((d|0)<0){e=d;return e|0}SRa();c[b+32>>2]=1;c[b+13944>>2]=0;c[b+14348>>2]=1042;c[b+14672>>2]=4;c[a+400>>2]=1;c[(c[a+64>>2]|0)+4>>2]=1;e=0;return e|0}function VRa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=e;l=e+12476|0;m=c[l>>2]|0;n=e+12480|0;o=c[n>>2]|0;p=e+124|0;q=c[p>>2]|0;r=(ca(q,o)|0)+m|0;s=e+9992|0;t=c[s>>2]|0;a:do{if((t|0)==2|(t|0)==4){u=e+14128|0;v=e+14120|0;w=c[v>>2]|0;x=c[u>>2]|0;while(1){y=d[w+(x>>>3)|0]|0;z=x+1|0;c[u>>2]=z;if((y&128>>>((x&7)>>>0)|0)!=0){A=5;break}y=c[2055821]|0;B=w+(z>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7)>>>25;B=b[y+(C<<2)>>1]|0;D=b[y+(C<<2)+2>>1]|0;C=D<<16>>16;if(D<<16>>16<0){D=x+8|0;E=w+(D>>>3)|0;F=((je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>((C+32|0)>>>0))+B|0;G=b[y+(F<<2)+2>>1]|0;H=D;I=b[y+(F<<2)>>1]|0}else{G=C;H=z;I=B}B=G+H|0;c[u>>2]=B;if((I|0)<0){A=12;break}if((I|0)==20){x=B}else{A=14;break}}if((A|0)==5){c[e+12488>>2]=0;mrc(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;do{if((t|0)==4){if((c[e+14680>>2]|0)!=2){break}c[(c[e+9160>>2]|0)+(r<<2)>>2]=15368;c[e+13916>>2]=1;c[e+11744>>2]=WRa(k,0)|0;c[e+11748>>2]=WRa(k,1)|0;c[e+9924>>2]=0;break a}}while(0);c[(c[e+9160>>2]|0)+(r<<2)>>2]=14344;c[e+13916>>2]=0;c[e+11744>>2]=0;c[e+11748>>2]=0;c[e+9924>>2]=1;break}else if((A|0)==12){KIb(c[e+4>>2]|0,16,2208736,(J=i,i=i+16|0,c[J>>2]=m,c[J+8>>2]=o,J)|0);i=J;K=-1;i=g;return K|0}else if((A|0)==14){qe[c[e+10096>>2]&1023](c[e+14340>>2]|0);x=I&8;w=I&4;c[e+12488>>2]=w>>>2;if((w|0)!=0){L=I;M=x;N=c[u>>2]|0;O=c[v>>2]|0;A=84;break}do{if((c[s>>2]|0)==4){if((c[e+14680>>2]|0)!=2){A=20;break}if((I&16|0)!=0){A=20;break}w=c[u>>2]|0;B=c[v>>2]|0;z=d[B+(w>>>3)|0]<<(w&7)>>>7;C=w+1|0;c[u>>2]=C;c[e+13916>>2]=z&1;P=C;Q=B}else{A=20}}while(0);if((A|0)==20){c[e+13916>>2]=0;P=c[u>>2]|0;Q=c[v>>2]|0}B=c[2093353]|0;C=Q+(P>>>3)|0;z=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(P&7)>>>26;C=b[B+(z<<2)>>1]|0;w=(b[B+(z<<2)+2>>1]|0)+P|0;c[u>>2]=w;z=C<<2|I&3;C=z^60;if((x|0)!=0){B=c[e+9960>>2]|0;F=Q+(w>>>3)|0;y=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(w&7)>>>30;c[u>>2]=w+2;QTa(e,(a[795256+y|0]|0)+B|0)}B=(c[e+14152>>2]|0)==0;do{if(B){if((z|0)==60){if((c[e+84>>2]&4|0)==0){break}}y=c[u>>2]|0;w=d[(c[v>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[u>>2]=y+1;c[e+14236>>2]=w&1}}while(0);c[e+11736>>2]=1;if((I&16|0)!=0){c[(c[e+9160>>2]|0)+(r<<2)>>2]=12352;c[e+11740>>2]=1;z=e+11556|0;x=Rga(e,0,0,h,j)|0;w=HMa(e,c[h>>2]|0,c[z>>2]|0)|0;if((w|0)>65534){K=-1;i=g;return K|0}y=HMa(e,c[j>>2]|0,c[z>>2]|0)|0;if((y|0)>65534){K=-1;i=g;return K|0}c[e+11744>>2]=w;c[e+11748>>2]=y;b[x>>1]=w;b[x+2>>1]=y;y=Rga(e,1,0,h,j)|0;x=HMa(e,c[h>>2]|0,c[z>>2]|0)|0;if((x|0)>65534){K=-1;i=g;return K|0}w=HMa(e,c[j>>2]|0,c[z>>2]|0)|0;if((w|0)>65534){K=-1;i=g;return K|0}c[e+11752>>2]=x;c[e+11756>>2]=w;b[y>>1]=x;b[y+2>>1]=w;w=Rga(e,2,0,h,j)|0;y=HMa(e,c[h>>2]|0,c[z>>2]|0)|0;if((y|0)>65534){K=-1;i=g;return K|0}x=HMa(e,c[j>>2]|0,c[z>>2]|0)|0;if((x|0)>65534){K=-1;i=g;return K|0}c[e+11760>>2]=y;c[e+11764>>2]=x;b[w>>1]=y;b[w+2>>1]=x;x=Rga(e,3,0,h,j)|0;w=HMa(e,c[h>>2]|0,c[z>>2]|0)|0;if((w|0)>65534){K=-1;i=g;return K|0}y=HMa(e,c[j>>2]|0,c[z>>2]|0)|0;if((y|0)>65534){K=-1;i=g;return K|0}else{c[e+11768>>2]=w;c[e+11772>>2]=y;b[x>>1]=w;b[x+2>>1]=y;R=C;A=77;break}}if((c[e+13916>>2]|0)!=0){c[(c[e+9160>>2]|0)+(r<<2)>>2]=13320;c[e+11740>>2]=0;y=WRa(k,0)|0;x=WRa(k,1)|0;c[e+11744>>2]=y;c[e+11748>>2]=x;R=C;A=77;break}do{if(B){x=c[u>>2]|0;y=c[v>>2]|0;w=d[y+(x>>>3)|0]|0;c[u>>2]=x+1;if((w&128>>>((x&7)>>>0)|0)==0){break}c[(c[e+9160>>2]|0)+(r<<2)>>2]=12432;c[e+11740>>2]=3;x=c[u>>2]|0;w=d[y+(x>>>3)|0]<<(x&7)>>>7;z=x+1|0;c[u>>2]=z;c[e+11808>>2]=w&1;w=d[y+(z>>>3)|0]<<(z&7)>>>7;c[u>>2]=x+2;c[e+11812>>2]=w&1;Rga(e,0,0,h,j)|0;w=e+11556|0;x=HMa(e,c[h>>2]|0,c[w>>2]|0)|0;if((x|0)>65534){K=-1;i=g;return K|0}z=HMa(e,(c[j>>2]|0)/2|0,c[w>>2]|0)|0;if((z|0)>65534){K=-1;i=g;return K|0}c[e+11744>>2]=x;c[e+11748>>2]=z;z=HMa(e,c[h>>2]|0,c[w>>2]|0)|0;if((z|0)>65534){K=-1;i=g;return K|0}x=HMa(e,(c[j>>2]|0)/2|0,c[w>>2]|0)|0;if((x|0)>65534){K=-1;i=g;return K|0}else{c[e+11752>>2]=z;c[e+11756>>2]=x;R=C;A=77;break a}}}while(0);c[(c[e+9160>>2]|0)+(r<<2)>>2]=12296;c[e+11740>>2]=0;Rga(e,0,0,h,j)|0;u=e+11556|0;v=HMa(e,c[h>>2]|0,c[u>>2]|0)|0;if((v|0)>65534){K=-1;i=g;return K|0}B=HMa(e,c[j>>2]|0,c[u>>2]|0)|0;if((B|0)>65534){K=-1;i=g;return K|0}else{c[e+11744>>2]=v;c[e+11748>>2]=B;R=C;A=77;break}}}else if((t|0)==3){c[e+12488>>2]=0;c[e+13916>>2]=0;if((m|0)==0){mrc(e+11824|0,0,32)|0;M5a((c[e+9852>>2]|0)+1496|0,o,0);S=c[n>>2]|0;T=c[p>>2]|0;U=c[l>>2]|0}else{S=o;T=q;U=m}B=(ca(T,S)|0)+U|0;v=a[(c[e+4720>>2]|0)+B|0]|0;c[e+9924>>2]=v&255;if(!(v<<24>>24==0)){mrc(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11780>>2]=0;c[e+11776>>2]=0;c[e+11748>>2]=0;c[e+11744>>2]=0;c[(c[e+9160>>2]|0)+(r<<2)>>2]=14344;break}v=e+14128|0;B=c[v>>2]|0;u=e+14120|0;x=c[u>>2]|0;z=d[x+(B>>>3)|0]|0;w=B+1|0;c[v>>2]=w;do{if((z&128>>>((B&7)>>>0)|0)==0){y=a[x+(w>>>3)|0]|0;F=B+2|0;c[v>>2]=F;D=c[1447567]|0;E=x+(F>>>3)|0;V=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(F&7)>>>28;E=b[D+(V<<2)>>1]|0;c[v>>2]=(b[D+(V<<2)+2>>1]|0)+F;if(E<<16>>16<0){KIb(c[e+4>>2]|0,16,2200112,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1;i=g;return K|0}F=c[832984+(E<<16>>16<<2)>>2]|0;do{if((y&255&128>>>((w&7)>>>0)|0)==0){qe[c[e+10096>>2]&1023](c[e+14340>>2]|0);V=c[v>>2]|0;D=c[u>>2]|0;W=D+(V>>>3)|0;X=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(V&7)>>>26;W=V+6|0;c[v>>2]=W;Y=E<<16>>16==0;Z=(X|0)==0;if(Y|Z){_=X;$=Y;aa=Z;break}Z=d[D+(W>>>3)|0]|0;Y=V+7|0;c[v>>2]=Y;if((Z&128>>>((W&7)>>>0)|0)==0){_=X;$=0;aa=0;break}W=c[e+9960>>2]|0;Z=d[D+(Y>>>3)|0]<<(Y&7)>>>7;c[v>>2]=V+8;QTa(e,W-2+(Z<<2&4)|0);_=X;$=0;aa=0}else{_=0;$=E<<16>>16==0;aa=1}}while(0);do{if((c[e+14152>>2]|0)==0){if(!aa){y=c[v>>2]|0;X=d[(c[u>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[v>>2]=y+1;c[e+14236>>2]=X&1}if($){ba=F;break}X=c[v>>2]|0;y=c[u>>2]|0;Z=d[y+(X>>>3)|0]|0;W=X+1|0;c[v>>2]=W;if((Z&128>>>((X&7)>>>0)|0)==0){ba=F;break}Z=F&-153|144;if(E<<16>>16==2){da=W}else{V=d[y+(W>>>3)|0]<<(W&7)>>>7;W=X+2|0;c[v>>2]=W;c[e+11808>>2]=V&1;V=d[y+(W>>>3)|0]<<(W&7)>>>7;W=X+3|0;c[v>>2]=W;c[e+11812>>2]=V&1;if(E<<16>>16==3){ba=Z;break}else{da=W}}W=d[y+(da>>>3)|0]<<(da&7)>>>7;V=da+1|0;c[v>>2]=V;c[e+11816>>2]=W&1;W=d[y+(V>>>3)|0]<<(V&7)>>>7;c[v>>2]=da+2;c[e+11820>>2]=W&1;ba=Z}else{ba=F}}while(0);F=e+11736|0;c[F>>2]=0;do{if((ba&384|0)==0){c[e+11740>>2]=0;if((ba&12288|0)!=0){c[F>>2]=1;E=e+11824|0;Z=e+11556|0;W=HMa(e,c[E>>2]|0,c[Z>>2]|0)|0;V=e+11828|0;y=HMa(e,c[V>>2]|0,c[Z>>2]|0)|0;c[e+11744>>2]=W;c[E>>2]=W;c[e+11832>>2]=W;c[e+11748>>2]=y;c[V>>2]=y;c[e+11836>>2]=y}if((ba&49152|0)==0){break}c[F>>2]=c[F>>2]|2;y=e+11840|0;V=e+11560|0;W=HMa(e,c[y>>2]|0,c[V>>2]|0)|0;E=e+11844|0;Z=HMa(e,c[E>>2]|0,c[V>>2]|0)|0;c[e+11776>>2]=W;c[y>>2]=W;c[e+11848>>2]=W;c[e+11780>>2]=Z;c[E>>2]=Z;c[e+11852>>2]=Z}else{if((ba&256|0)!=0){break}c[e+11740>>2]=3;if((ba&12288|0)!=0){c[F>>2]=1;Z=e+11556|0;E=e+11824|0;W=HMa(e,c[E>>2]|0,c[Z>>2]|0)|0;y=e+11828|0;V=HMa(e,(c[y>>2]|0)/2|0,c[Z>>2]|0)|0;c[e+11744>>2]=W;c[E>>2]=W;c[e+11748>>2]=V;c[y>>2]=V<<1;V=e+11832|0;y=HMa(e,c[V>>2]|0,c[Z>>2]|0)|0;W=e+11836|0;E=HMa(e,(c[W>>2]|0)/2|0,c[Z>>2]|0)|0;c[e+11752>>2]=y;c[V>>2]=y;c[e+11756>>2]=E;c[W>>2]=E<<1}if((ba&49152|0)==0){break}c[F>>2]=c[F>>2]|2;E=e+11560|0;W=e+11840|0;y=HMa(e,c[W>>2]|0,c[E>>2]|0)|0;V=e+11844|0;Z=HMa(e,(c[V>>2]|0)/2|0,c[E>>2]|0)|0;c[e+11776>>2]=y;c[W>>2]=y;c[e+11780>>2]=Z;c[V>>2]=Z<<1;Z=e+11848|0;V=HMa(e,c[Z>>2]|0,c[E>>2]|0)|0;y=e+11852|0;W=HMa(e,(c[y>>2]|0)/2|0,c[E>>2]|0)|0;c[e+11784>>2]=V;c[Z>>2]=V;c[e+11788>>2]=W;c[y>>2]=W<<1}}while(0);if((ba&256|0)==0){ea=ba;fa=_;break}if((ba&2048|0)!=0){ga=0;ha=0;ia=ba;ja=_;ka=F;A=75;break}W=HMa(e,0,1)|0;ga=W;ha=HMa(e,0,1)|0;ia=ba;ja=_;ka=F;A=75}else{ga=0;ha=0;ia=63744;ja=0;ka=e+11736|0;A=75}}while(0);if((A|0)==75){c[ka>>2]=7;ea=HRa(e,ga,ha)|0|ia;fa=ja}c[(c[e+9160>>2]|0)+(r<<2)>>2]=ea;R=fa;A=77}else{v=e+14128|0;u=c[2055815]|0;w=c[e+14120>>2]|0;x=c[v>>2]|0;while(1){B=w+(x>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>26;B=b[u+(z<<2)>>1]|0;C=b[u+(z<<2)+2>>1]|0;z=C<<16>>16;if(C<<16>>16<0){C=x+6|0;W=w+(C>>>3)|0;y=((je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(C&7)>>>((z+32|0)>>>0))+B|0;la=b[u+(y<<2)+2>>1]|0;ma=C;na=b[u+(y<<2)>>1]|0}else{la=z;ma=x;na=B}oa=la+ma|0;c[v>>2]=oa;if((na|0)<0){break}if((na|0)==8){x=oa}else{A=83;break}}if((A|0)==83){c[e+12488>>2]=1;L=na;M=na&4;N=oa;O=w;A=84;break}KIb(c[e+4>>2]|0,16,2195616,(J=i,i=i+16|0,c[J>>2]=m,c[J+8>>2]=o,J)|0);i=J;K=-1;i=g;return K|0}}while(0);do{if((A|0)==77){if((XRa(k,f|0,0,R&32,0,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+128|0,1,R<<1&32,0,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+256|0,2,R<<2&32,0,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+384|0,3,R<<3&32,0,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+512|0,4,R<<4&32,0,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+640|0,5,R<<5&32,0,0)|0)<0){K=-1}else{break}i=g;return K|0}else if((A|0)==84){o=e+14128|0;m=e+14120|0;oa=d[O+(N>>>3)|0]<<(N&7)>>>7;c[o>>2]=N+1;na=oa&1;c[e+176>>2]=na;c[(c[e+9160>>2]|0)+(r<<2)>>2]=na<<9|1;na=c[2093353]|0;oa=c[o>>2]|0;ma=c[m>>2]|0;la=ma+(oa>>>3)|0;fa=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(oa&7)>>>26;la=b[na+(fa<<2)>>1]|0;ea=(b[na+(fa<<2)+2>>1]|0)+oa|0;c[o>>2]=ea;if(la<<16>>16<0){oa=c[n>>2]|0;KIb(c[e+4>>2]|0,16,2192992,(J=i,i=i+16|0,c[J>>2]=c[l>>2],c[J+8>>2]=oa,J)|0);i=J;K=-1;i=g;return K|0}oa=la<<16>>16;la=oa<<2;fa=la|L&3;na=c[e+9960>>2]|0;c[e+14740>>2]=(na|0)<(c[e+14744>>2]|0);if((M|0)!=0){ja=ma+(ea>>>3)|0;ma=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ea&7)>>>30;c[o>>2]=ea+2;QTa(e,(a[795256+ma|0]|0)+na|0)}if((c[e+14152>>2]|0)==0){na=c[o>>2]|0;ma=d[(c[m>>2]|0)+(na>>>3)|0]<<(na&7)>>>7;c[o>>2]=na+1;c[e+14236>>2]=ma&1}qe[c[e+10096>>2]&1023](c[e+14340>>2]|0);if((XRa(k,f|0,0,la&32,1,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+128|0,1,oa<<3&32,1,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+256|0,2,oa<<4&32,1,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+384|0,3,oa<<5&32,1,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+512|0,4,fa<<4&32,1,0)|0)<0){K=-1;i=g;return K|0}if((XRa(k,f+640|0,5,fa<<5&32,1,0)|0)<0){K=-1}else{break}i=g;return K|0}}while(0);if((c[e+48>>2]|0)!=13){K=0;i=g;return K|0}f=YRa(k)|0;if((f|0)==0){K=0;i=g;return K|0}k=c[l>>2]|0;l=c[n>>2]|0;n=c[e+116>>2]|0;M=k+1|0;L=M+(ca(n,l)|0)|0;do{if((L|0)>(f|0)){if((c[(c[e+4>>2]|0)+696>>2]&262144|0)==0){break}else{K=-1}i=g;return K|0}}while(0);if((L|0)>=(f|0)){K=-2;i=g;return K|0}do{if((c[s>>2]|0)==3){f=(M|0)==(n|0)?2:1;if((f+k|0)<(n|0)){pa=l}else{L=l+1|0;J=(c[e+120>>2]|0)-1|0;pa=(L|0)>(J|0)?J:L}M5a((c[e+9852>>2]|0)+1496|0,pa,0);if((a[(c[e+4720>>2]|0)+(f+r)|0]|0)==0){break}else{K=0}i=g;return K|0}}while(0);K=-2;i=g;return K|0}function WRa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=1<<(c[a+11556>>2]|0)+4;e=c[a+13932>>2]|0;if((c[a+84>>2]&32|0)==0){f=d}else{f=d>>c[a+13924>>2]}a:do{if((c[a+13880>>2]|0)==1){do{if((c[a+14748>>2]|0)==500){if((c[a+14752>>2]|0)!=413){break}g=(c[a+13884+(b<<2)>>2]|0)/(1<<e-(c[a+13924>>2]|0)|0)|0;break a}}while(0);d=c[a+13884+(b<<2)>>2]<<c[a+13924>>2];g=d+(1<<e>>1)+(((d|0)<1)<<31>>31)>>e}else{d=c[a+14708>>2]|0;h=(b|0)==0;i=1<<e+1+d;j=(c[a+13900+(b<<3)>>2]|0)-(h?i:0)|0;k=(c[a+13900+(b<<3)+4>>2]|0)-(h?0:i)|0;i=ca(c[a+12476>>2]<<4,j)|0;h=c[a+12480>>2]<<4;l=i+(c[a+13884+(b<<2)>>2]|0)|0;i=0;m=0;do{n=l+(ca(m+h|0,k)|0)|0;o=n+j|0;p=o+j|0;q=p+j|0;r=q+j|0;s=r+j|0;t=s+j|0;u=t+j|0;v=u+j|0;w=v+j|0;x=w+j|0;y=x+j|0;z=y+j|0;A=z+j|0;B=A+j|0;i=(B+j>>d)+((B>>d)+((A>>d)+((z>>d)+((y>>d)+((x>>d)+((w>>d)+((v>>d)+((u>>d)+((t>>d)+((s>>d)+((r>>d)+((q>>d)+((p>>d)+((o>>d)+((n>>d)+i)))))))))))))))|0;m=m+1|0;}while((m|0)<16);m=e+8-(c[a+13924>>2]|0)|0;g=(((i|0)<1)<<31>>31)+i+(1<<m>>1)>>m}}while(0);a=-f|0;if((g|0)<(a|0)){return a|0}else{return((g|0)<(f|0)?g:f-1|0)|0}return 0}function XRa(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;l=i;i=i+8|0;m=l|0;n=e|0;o=(j|0)!=0;do{if(o){if((c[e+14740>>2]|0)==0){_Ra(n,g,0,m)|0;p=-1}else{do{if((c[e+13940>>2]|0)==0){j=ZRa(n,g,m)|0;if((j|0)<0){q=-1}else{r=j&65535;break}i=l;return q|0}else{j=b[(c[e+9876>>2]|0)+(c[e+12496+(g<<2)>>2]<<1)>>1]|0;if((g|0)<4){s=c[e+168>>2]|0;t=(s>>1)+j|0;Erc(t,(t|0)<0|0?-1:0,c[1367848+(s<<2)>>2]|0,0)|0;u=G&65535}else{s=c[e+172>>2]|0;t=(s>>1)+j|0;Erc(t,(t|0)<0|0?-1:0,c[1367848+(s<<2)>>2]|0,0)|0;u=G&65535}s=(ca(c[e+124>>2]|0,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;c[m>>2]=d[(c[e+9940>>2]|0)+s|0]<<g&32;r=u}}while(0);b[f>>1]=r;p=0}if((h|0)==0){v=p;break}s=(k|0)==0;t=s?1343600:1312096;j=s?c[335916]|0:c[328040]|0;if((c[e+176>>2]|0)==0){w=p;x=e+368|0;y=j;z=t;A=0;B=1;C=26;break}if((c[m>>2]|0)==0){w=p;x=e+632|0;y=j;z=t;A=0;B=1;C=26;break}else{w=p;x=e+500|0;y=j;z=t;A=0;B=1;C=26;break}}else{if((h|0)==0){c[e+180+(g<<2)>>2]=-1;q=0;i=l;return q|0}t=(k|0)!=0;j=t?1312288:1378528;s=e+368|0;if((c[e+14004>>2]|0)==0){D=c[e+9960>>2]|0;E=D<<1;F=D-1|1;if(t){w=-1;x=s;y=c[1312352+(D<<2)>>2]|0;z=j;A=F;B=E;C=26;break}else{w=-1;x=s;y=c[1378592+(D<<2)>>2]|0;z=j;A=F;B=E;C=26;break}}else{if(t){w=-1;x=s;y=c[328088]|0;z=j;A=0;B=1;C=26;break}else{w=-1;x=s;y=c[344648]|0;z=j;A=0;B=1;C=26;break}}}}while(0);do{if((C|0)==26){h=e+14128|0;p=(k|0)==0;r=-A|0;u=e+13740|0;j=c[e+14120>>2]|0;s=w;t=c[h>>2]|0;a:while(1){E=j+(t>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(t&7);E=F>>>23;D=b[y+(E<<2)>>1]|0;H=a[y+(E<<2)+2|0]|0;I=H<<24>>24;if(H<<24>>24<0){H=F<<9;J=(H>>>((I+32|0)>>>0))+D|0;K=b[y+(J<<2)>>1]|0;L=J;M=a[y+(J<<2)+2|0]|0;N=H;O=t+9|0}else{K=D;L=E;M=I;N=F;O=t}F=N<<M;I=M+O|0;do{if((K|0)==0){if(!p){if((F|0)>-1){C=32;break a}E=I+8|0;D=j+(E>>>3)|0;H=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7);if((H|0)>-1){C=34;break a}if((H&1015808|0)!=524288){C=36;break a}E=H<<17>>31;D=I+26|0;J=s+1+(F>>>24&63)|0;P=((ca(H>>>20&2047,B)|0)+A^E)-E&65535;if((F&1073741824|0)==0){Q=P;R=J;S=D;break}Q=P;R=J+192|0;S=D;break}if((F|0)>=0){D=F>>>22&511;J=b[y+(D<<2)>>1]|0;P=a[y+(D<<2)+2|0]|0;E=P<<24>>24;if(P<<24>>24<0){P=I+10|0;H=j+(P>>>3)|0;T=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(P&7);H=(T>>>((E+32|0)>>>0))+J|0;U=H;V=a[y+(H<<2)+2|0]|0;W=b[y+(H<<2)>>1]|0;X=T;Y=P}else{U=D;V=E;W=J;X=F<<1;Y=I+1|0}J=d[y+(U<<2)+3|0]|0;E=X<<V>>31;Q=((ca(a[(c[z+28+(J>>>7<<2)>>2]|0)+(J+63&63)|0]|0,B)|0)+W^E)-E&65535;R=J+s|0;S=Y+1+V|0;break}if((F&1073741824|0)==0){J=F>>>21&511;E=b[y+(J<<2)>>1]|0;D=a[y+(J<<2)+2|0]|0;P=D<<24>>24;if(D<<24>>24<0){D=I+11|0;T=j+(D>>>3)|0;H=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(D&7);T=(H>>>((P+32|0)>>>0))+E|0;Z=T;_=b[y+(T<<2)>>1]|0;$=a[y+(T<<2)+2|0]|0;aa=H;ba=D}else{Z=J;_=E;$=P;aa=F<<2;ba=I+2|0}P=d[y+(Z<<2)+3|0]|0;E=aa<<$>>31;Q=(E^_)-E&65535;R=s+1+P+(a[(c[z+36+(P>>>7<<2)>>2]|0)+((_|0)/(B|0)|0)|0]|0)|0;S=ba+1+$|0;break}P=F&536870912;E=F>>>23&63;J=I+9|0;D=j+(J>>>3)|0;H=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(J&7);if((H|0)>-1){C=42;break a}J=H<<1>>20;if((H&262144|0)==0){C=44;break a}H=I+23|0;D=ca(J,B)|0;T=((J|0)>0?A:r)+D|0;D=T&65535;if((T+2048|0)>>>0>4095>>>0){if((c[u>>2]&262146|0)!=0){if((T+2560|0)>>>0>5120>>>0){C=48;break a}}da=(T|0)<0?-2048:2047}else{da=D}D=s+1+E|0;if((P|0)==0){Q=da;R=D;S=H;break}Q=da;R=D+192|0;S=H}else{H=F>>31;Q=(K^H)-H&65535;R=(d[y+(L<<2)+3|0]|0)+s|0;S=I+1|0}}while(0);if((R|0)>62){C=60;break}b[f+(d[x+R|0]<<1)>>1]=Q;s=R;t=S}if((C|0)==32){KIb(c[e+4>>2]|0,16,2190472,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==34){KIb(c[e+4>>2]|0,16,2187912,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==36){KIb(c[e+4>>2]|0,16,2185328,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==42){KIb(c[e+4>>2]|0,16,2183048,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==44){KIb(c[e+4>>2]|0,16,2180968,(ea=i,i=i+1|0,i=i+7&-8,c[ea>>2]=0,ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==48){KIb(c[e+4>>2]|0,16,2178656,(ea=i,i=i+8|0,c[ea>>2]=c[e+9960>>2],ea)|0);i=ea;q=-1;i=l;return q|0}else if((C|0)==60){t=R-192|0;if(!(t>>>0>63>>>0)){b[f+(d[x+t|0]<<1)>>1]=Q;c[h>>2]=S;v=t;break}t=c[e+12480>>2]|0;KIb(c[e+4>>2]|0,16,2176128,(ea=i,i=i+16|0,c[ea>>2]=c[e+12476>>2],c[ea+8>>2]=t,ea)|0);i=ea;q=-1;i=l;return q|0}}}while(0);if(o){if((c[e+14740>>2]|0)==0){b[f>>1]=_Ra(n,g,b[f>>1]|0,m)|0;fa=v-(v>>31)|0}else{fa=v}MRa(n,f,g,c[m>>2]|0);ga=(c[e+176>>2]|0)==0?fa:63}else{ga=v}c[e+180+(g<<2)>>2]=ga;q=0;i=l;return q|0}function YRa(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;i=i+24|0;f=b|0;g=a|0;h=a+14120|0;j=a+14128|0;k=c[j>>2]|0;l=c[h>>2]|0;m=l+(k>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(k&7);m=n>>>16;do{if((c[a+84>>2]&16|0)!=0){if((c[a+14720>>2]|0)==0){o=0}else{break}i=b;return o|0}}while(0);p=a+13940|0;a:do{if(n>>>0<16777216>>>0){q=c[a+9992>>2]|0;r=k;s=m;t=k;while(1){if((q|0)==3){u=r;v=s;w=t;break a}if((s>>>((8-q|0)>>>0)|0)!=1){u=r;v=s;w=t;break a}if((c[p>>2]|0)!=0){u=r;v=s;w=t;break a}x=q+8+t|0;c[j>>2]=x;y=r+8+q|0;z=l+(x>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7);z=A>>>16;if(A>>>0<16777216>>>0){r=y;s=z;t=x}else{u=y;v=z;w=x;break}}}else{u=k;v=m;w=k}}while(0);k=c[a+14132>>2]|0;do{if((u+8|0)<(k|0)){if((v|0)!=(e[1343792+((u&7)<<1)>>1]|0|0)){break}m=c[a+144>>2]|0;p=m-1|0;n=p>>>0>65535>>>0;t=n?p>>>16:p;p=n?16:0;if((t&65280|0)==0){B=p;C=t}else{B=p|8;C=t>>>8}t=(d[1359664+C|0]|0)+B|0;p=t+1|0;n=f;s=h;c[n>>2]=c[s>>2];c[n+4>>2]=c[s+4>>2];c[n+8>>2]=c[s+8>>2];c[n+12>>2]=c[s+12>>2];c[n+16>>2]=c[s+16>>2];r=w+1|0;q=w&7;if((q|0)==7){D=r}else{D=(q^7)+r|0}c[j>>2]=D;r=0;q=D;while(1){if((r|0)>=32){E=q;break}x=d[l+(q>>>3)|0]|0;z=q+1|0;c[j>>2]=z;if((x&128>>>((q&7)>>>0)|0)==0){r=r+1|0;q=z}else{E=z;break}}q=l+(E>>>3)|0;z=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(E&7)>>>((31-t|0)>>>0);q=p+E|0;c[j>>2]=q;if((z|0)==0|(z|0)>(m|0)){F=22}else{if((q+6|0)>(k|0)){F=22}else{G=z}}if((F|0)==22){G=-1}c[s>>2]=c[n>>2];c[s+4>>2]=c[n+4>>2];c[s+8>>2]=c[n+8>>2];c[s+12>>2]=c[n+12>>2];c[s+16>>2]=c[n+16>>2];if((r|0)<(ERa(g)|0)){break}else{o=G}i=b;return o|0}else{if((127>>>((u&7^7)>>>0)|v>>>8|0)!=127){break}o=c[a+144>>2]|0;i=b;return o|0}}while(0);o=0;i=b;return o|0}function ZRa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=a+14120|0;if((e|0)<4){j=c[2443063]|0;k=a+14128|0;l=c[k>>2]|0;m=c[h>>2]|0;n=m+(l>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(l&7)>>>23;n=b[j+(o<<2)>>1]|0;p=(b[j+(o<<2)+2>>1]|0)+l|0;c[k>>2]=p;q=n;r=p;s=m}else{m=c[2443069]|0;p=a+14128|0;n=c[p>>2]|0;k=c[h>>2]|0;h=k+(n>>>3)|0;l=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(n&7)>>>23;h=b[m+(l<<2)>>1]|0;o=(b[m+(l<<2)+2>>1]|0)+n|0;c[p>>2]=o;q=h;r=o;s=k}k=q<<16>>16;if((q&65535)>>>0>9>>>0){KIb(c[a+4>>2]|0,16,2161904,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1;i=g;return u|0}do{if(q<<16>>16==0){v=0}else{o=a+14128|0;h=s+(r>>>3)|0;p=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(r&7);h=(p^-2147483648)>>31;n=r+k|0;c[o>>2]=n;l=((h^p)>>>((32-k|0)>>>0)^h)-h|0;if(!(q<<16>>16>8)){v=l;break}h=d[s+(n>>>3)|0]|0;c[o>>2]=n+1;if((h&128>>>((n&7)>>>0)|0)!=0){v=l;break}if((c[a+13740>>2]&131074|0)==0){v=l;break}KIb(c[a+4>>2]|0,16,2159944,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1;i=g;return u|0}}while(0);u=_Ra(a,e,v,f)|0;i=g;return u|0}function _Ra(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;h=c[((d|0)<4?a+168|0:a+172|0)>>2]|0;j=c[a+12520+(d<<2)>>2]|0;k=c[a+9876>>2]|0;l=c[a+12496+(d<<2)>>2]|0;m=k+(l<<1)|0;n=b[k+(l-1<<1)>>1]|0;o=b[k+(l+~j<<1)>>1]|0;p=b[k+(l-j<<1)>>1]|0;do{if((c[a+14084>>2]|0)==0|(d|0)==3){q=p;r=o;s=n}else{j=(d|0)==2;l=j?o:1024;k=j?p:1024;if((d|0)==1){q=k;r=l;s=n;break}j=(c[a+12476>>2]|0)==(c[a+13704>>2]|0);q=k;r=j?1024:l;s=j?1024:n}}while(0);n=a+12476|0;do{if((c[n>>2]|0)==(c[a+13704>>2]|0)){if((c[a+12480>>2]|0)!=((c[a+13708>>2]|0)+1|0)){t=r;break}if(!((d|0)==5|(d|0)==4|(d|0)==0)){t=r;break}t=1024}else{t=r}}while(0);r=s-t|0;d=t-q|0;t=(((r|0)>-1?r:-r|0)|0)<(((d|0)>-1?d:-d|0)|0);c[f>>2]=t&1;f=(t?q:s)+(h>>1)|0;Erc(f,(f|0)<0|0?-1:0,c[1367848+(h<<2)>>2]|0,0)|0;f=G+e|0;do{if((c[a+13740>>2]&262146|0)==0){u=ca(f,h)|0}else{if((f|0)<0){e=c[a+12480>>2]|0;KIb(c[a+4>>2]|0,16,2168328,(v=i,i=i+16|0,c[v>>2]=c[n>>2],c[v+8>>2]=e,v)|0);i=v;w=-1;i=g;return w|0}e=ca(f,h)|0;if((e|0)<=(h+2048|0)){u=e;break}e=c[a+12480>>2]|0;KIb(c[a+4>>2]|0,16,2163976,(v=i,i=i+16|0,c[v>>2]=c[n>>2],c[v+8>>2]=e,v)|0);i=v;w=-1;i=g;return w|0}}while(0);v=u&65535;do{if(u>>>0>2047>>>0){if((u|0)<0){x=0;break}x=(c[a+84>>2]&4096|0)==0?2047:v}else{x=v}}while(0);b[m>>1]=x;w=f;i=g;return w|0}function $Ra(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;h=e;j=e+12476|0;k=e+12480|0;l=(ca(c[e+124>>2]|0,c[k>>2]|0)|0)+(c[j>>2]|0)|0;m=e+9160|0;n=c[(c[m>>2]|0)+(l<<2)>>2]|0;o=e+9936|0;p=d[(c[o>>2]|0)+l|0]|0;q=c[e+9960>>2]|0;c[e+14740>>2]=(q|0)<(c[e+14744>>2]|0);r=a[(c[e+9136>>2]|0)+l|0]|0;if((r|0)!=(q|0)){QTa(e,r)}r=c[e+9992>>2]|0;a:do{if((r|0)==2|(r|0)==4){q=c[e+12496>>2]|0;s=c[e+9148>>2]|0;c[e+11744>>2]=b[s+(q<<2)>>1]|0;c[e+11748>>2]=b[s+(q<<2)+2>>1]|0;q=c[e+12500>>2]|0;c[e+11752>>2]=b[s+(q<<2)>>1]|0;c[e+11756>>2]=b[s+(q<<2)+2>>1]|0;q=c[e+12504>>2]|0;c[e+11760>>2]=b[s+(q<<2)>>1]|0;c[e+11764>>2]=b[s+(q<<2)+2>>1]|0;q=c[e+12508>>2]|0;c[e+11768>>2]=b[s+(q<<2)>>1]|0;c[e+11772>>2]=b[s+(q<<2)+2>>1]|0;q=n&7;c[e+12488>>2]=q;s=n&2048;if((s|0)!=0){mrc(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;do{if((r|0)==4){if((c[e+14680>>2]|0)!=2){break}c[e+13916>>2]=1;c[e+9924>>2]=0;t=s;u=15;break a}}while(0);c[e+13916>>2]=0;c[e+9924>>2]=1;t=s;u=15;break}if((q|0)!=0){c[e+176>>2]=c[(c[m>>2]|0)+(l<<2)>>2]&512;u=16;break}c[e+11736>>2]=1;v=e+11740|0;if((n&64|0)==0){c[v>>2]=0;u=16;break}else{c[v>>2]=1;u=16;break}}else{c[e+12488>>2]=1;c[e+176>>2]=c[(c[m>>2]|0)+(l<<2)>>2]&512;t=n&2048;u=15}}while(0);if((u|0)==15){if((t|0)==0){u=16}}b:do{if((u|0)==16){qe[c[e+10096>>2]&1023](c[e+14340>>2]|0);t=e+12488|0;n=e+14716|0;do{if((XRa(h,f|0,0,p&32,c[t>>2]|0,c[n>>2]|0)|0)>=0){if((XRa(h,f+128|0,1,p<<1&32,c[t>>2]|0,c[n>>2]|0)|0)<0){break}if((XRa(h,f+256|0,2,p<<2&32,c[t>>2]|0,c[n>>2]|0)|0)<0){break}if((XRa(h,f+384|0,3,p<<3&32,c[t>>2]|0,c[n>>2]|0)|0)<0){break}if((XRa(h,f+512|0,4,p<<4&32,c[t>>2]|0,c[n>>2]|0)|0)<0){break}if((XRa(h,f+640|0,5,p<<5&32,c[t>>2]|0,c[n>>2]|0)|0)>=0){break b}}}while(0);n=c[k>>2]|0;q=c[t>>2]|0;KIb(c[e+4>>2]|0,16,2591864,(s=i,i=i+24|0,c[s>>2]=c[j>>2],c[s+8>>2]=n,c[s+16>>2]=q,s)|0);i=s;w=-1;i=g;return w|0}}while(0);k=e+13732|0;p=(c[k>>2]|0)-1|0;c[k>>2]=p;k=(YRa(h)|0)!=0;if((p|0)<1){w=k?-2:-3;i=g;return w|0}do{if(k){if((a[(c[o>>2]|0)+((((c[j>>2]|0)+1|0)==(c[e+116>>2]|0)?2:1)+l)|0]|0)==0){break}else{w=-2}i=g;return w|0}}while(0);w=0;i=g;return w|0}function aSa(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[d+9136>>2]|0;xqb(d);if((c[d+9992>>2]|0)!=3){return}f=d+144|0;g=c[f>>2]|0;h=(g|0)>0;if(!h){return}i=c[d+12556>>2]|0;j=0;k=0;do{j=(a[e+(c[i+(k<<2)>>2]|0)|0]&1)+j|0;k=k+1|0;}while((k|0)<(g|0));k=(j<<1|0)>(g|0);if(!h){return}h=d+12556|0;g=0;do{j=e+(c[(c[h>>2]|0)+(g<<2)>>2]|0)|0;i=a[j]|0;if(k^(i&1)!=0){l=i+1&255;a[j]=l;m=l}else{m=i}if(m<<24>>24>31){a[j]=31}g=g+1|0;n=c[f>>2]|0;}while((g|0)<(n|0));if((n|0)<=1){return}g=d+12492|0;f=c[d+12556>>2]|0;d=1;m=c[f>>2]|0;while(1){k=c[f+(d<<2)>>2]|0;do{if((a[e+k|0]|0)!=(a[e+m|0]|0)){h=(c[g>>2]|0)+(k<<1)|0;j=b[h>>1]|0;if((j&16)==0){break}b[h>>1]=j|128}}while(0);j=d+1|0;if((j|0)<(n|0)){d=j;m=k}else{break}}return}function bSa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0;j=i;i=i+112|0;k=j|0;l=j+8|0;m=j+16|0;n=j+40|0;o=j+64|0;p=j+88|0;q=c[e+13936>>2]|0;r=(q|0)!=0;s=e+13980|0;t=e+784|0;u=r?s:t;if(r){r=c[e+9992>>2]|0;v=(r|0)==3?t:e+13956|0;if((r|0)==1){w=v;x=3}else{z=s;A=v}}else{w=t;x=3}if((x|0)==3){z=t;A=w}w=c[e+60>>2]|0;v=(q|0)==0&(w&512|0)!=0;if((c[e+12488>>2]|0)!=0){q=e+168|0;s=e+172|0;r=e+12476|0;B=e+13704|0;C=e+12480|0;D=e+13708|0;E=e+84|0;F=c[e+9876>>2]|0;H=c[e+14084>>2]|0;I=0;do{J=b[f+(I<<7)>>1]|0;K=n+(I<<2)|0;L=c[((I|0)<4?q:s)>>2]|0;M=c[e+12520+(I<<2)>>2]|0;N=c[e+12496+(I<<2)>>2]|0;O=F+(N<<1)|0;P=b[F+(N-1<<1)>>1]|0;Q=b[F+(N+~M<<1)>>1]|0;R=b[F+(N-M<<1)>>1]|0;do{if((H|0)==0|(I|0)==3){S=R;T=Q;U=P}else{M=(I|0)==2;N=M?Q:1024;V=M?R:1024;if((I|0)==1){S=V;T=N;U=P;break}M=(c[r>>2]|0)==(c[B>>2]|0);S=V;T=M?1024:N;U=M?1024:P}}while(0);do{if((c[r>>2]|0)==(c[B>>2]|0)){if((c[C>>2]|0)!=((c[D>>2]|0)+1|0)){W=T;break}if(!((I|0)==5|(I|0)==4|(I|0)==0)){W=T;break}W=1024}else{W=T}}while(0);P=U-W|0;R=W-S|0;Q=(((P|0)>-1?P:-P|0)|0)<(((R|0)>-1?R:-R|0)|0);c[K>>2]=Q&1;R=(Q?S:U)+(L>>1)|0;Erc(R,(R|0)<0|0?-1:0,c[1367848+(L<<2)>>2]|0,0)|0;R=J-G|0;Q=ca(L,J)|0;P=Q&65535;do{if(Q>>>0>2047>>>0){if((Q|0)<0){X=0;break}X=(c[E>>2]&4096|0)==0?2047:P}else{X=P}}while(0);b[O>>1]=X;c[m+(I<<2)>>2]=R;I=I+1|0;}while((I|0)<6);if((w&16777216|0)==0){w=e+368|0;c[p>>2]=w;c[p+4>>2]=w;c[p+8>>2]=w;c[p+12>>2]=w;c[p+16>>2]=w;c[p+20>>2]=w}else{w=p|0;I=c[e+9136>>2]|0;X=o;E=e+180|0;c[X>>2]=c[E>>2];c[X+4>>2]=c[E+4>>2];c[X+8>>2]=c[E+8>>2];c[X+12>>2]=c[E+12>>2];c[X+16>>2]=c[E+16>>2];c[X+20>>2]=c[E+20>>2];E=e+9912|0;X=e+632|0;U=e+124|0;S=e+9960|0;W=e+500|0;T=e+13092|0;D=e+13096|0;B=e+13088|0;H=0;F=0;do{s=e+180+(H<<2)|0;q=c[s>>2]|0;if((q|0)<1){Y=0}else{P=1;Q=0;J=0;while(1){L=b[f+(H<<7)+(d[e+368+P|0]<<1)>>1]|0;if(L<<16>>16==0){Z=J;_=Q}else{K=(L<<16>>16)+64|0;do{if(K>>>0<128>>>0){L=(P-J<<7)-128+K|0;if((P|0)<(q|0)){$=d[(c[T>>2]|0)+L|0]|0;break}else{$=d[(c[D>>2]|0)+L|0]|0;break}}else{$=c[B>>2]|0}}while(0);Z=P;_=$+Q|0}K=P+1|0;if((K|0)>(q|0)){Y=_;break}else{P=K;Q=_;J=Z}}}J=F-Y|0;Q=c[E>>2]|0;P=c[e+12496+(H<<2)>>2]<<4;q=c[r>>2]|0;if((c[n+(H<<2)>>2]|0)==0){R=P-16|0;a:do{if((q|0)==0){x=291}else{O=q-1+(ca(c[C>>2]|0,c[U>>2]|0)|0)|0;K=c[S>>2]|0;L=I+O|0;O=a[L]|0;if((K|0)==(O<<24>>24|0)){x=291;break}if((H|0)==3|(H|0)==1){x=291;break}M=P|8;N=K>>1;V=-N|0;aa=1;ba=O;while(1){O=f+(H<<7)+(d[(aa<<3)+(e+11184)|0]<<1)|0;da=b[O>>1]|0;ea=ca(b[Q+(aa+R<<1)>>1]|0,ba<<24>>24)|0;b[O>>1]=(da&65535)-((((ea|0)>0?N:V)+ea|0)/(K|0)|0);b[Q+(aa+P<<1)>>1]=da;b[Q+(aa+M<<1)>>1]=b[f+(H<<7)+(d[e+11184+aa|0]<<1)>>1]|0;da=aa+1|0;if((da|0)>=8){break a}aa=da;ba=a[L]|0}}}while(0);if((x|0)==291){x=0;L=P|8;ba=1;do{aa=f+(H<<7)+(d[(ba<<3)+(e+11184)|0]<<1)|0;M=b[aa>>1]|0;b[aa>>1]=M-(b[Q+(ba+R<<1)>>1]|0);b[Q+(ba+P<<1)>>1]=M;b[Q+(ba+L<<1)>>1]=b[f+(H<<7)+(d[e+11184+ba|0]<<1)>>1]|0;ba=ba+1|0;}while((ba|0)<8)}c[p+(H<<2)>>2]=X;fa=X}else{ba=c[C>>2]|0;L=c[U>>2]|0;R=P-(c[e+12520+(H<<2)>>2]<<4)|0;b:do{if((ba|0)==0){ga=1;x=286}else{M=q-L+(ca(L,ba)|0)|0;aa=c[S>>2]|0;K=I+M|0;M=a[K]|0;if((aa|0)==(M<<24>>24|0)){ga=1;x=286;break}if((H-2|0)>>>0<2>>>0){ga=1;x=286;break}V=aa>>1;N=-V|0;da=1;ea=M;while(1){M=f+(H<<7)+(d[e+11184+da|0]<<1)|0;O=b[M>>1]|0;ha=da+8|0;ia=ca(b[Q+(ha+R<<1)>>1]|0,ea<<24>>24)|0;b[M>>1]=(O&65535)-((((ia|0)>0?V:N)+ia|0)/(aa|0)|0);b[Q+(da+P<<1)>>1]=b[f+(H<<7)+(d[(da<<3)+(e+11184)|0]<<1)>>1]|0;b[Q+(ha+P<<1)>>1]=O;O=da+1|0;if((O|0)>=8){break b}da=O;ea=a[K]|0}}}while(0);if((x|0)==286){while(1){x=0;ba=f+(H<<7)+(d[e+11184+ga|0]<<1)|0;L=b[ba>>1]|0;q=ga+8|0;b[ba>>1]=L-(b[Q+(q+R<<1)>>1]|0);b[Q+(ga+P<<1)>>1]=b[f+(H<<7)+(d[(ga<<3)+(e+11184)|0]<<1)>>1]|0;b[Q+(q+P<<1)>>1]=L;L=ga+1|0;if((L|0)<8){ga=L;x=286}else{break}}}c[p+(H<<2)>>2]=W;fa=W}P=63;while(1){if((P|0)<=0){x=301;break}if((b[f+(H<<7)+(d[fa+P|0]<<1)>>1]|0)==0){P=P-1|0}else{x=303;break}}do{if((x|0)==301){x=0;c[s>>2]=P;ja=0}else if((x|0)==303){x=0;c[s>>2]=P;if((P|0)<1){ja=0;break}else{ka=1;la=0;ma=0}while(1){Q=b[f+(H<<7)+(d[fa+ka|0]<<1)>>1]|0;if(Q<<16>>16==0){na=ma;oa=la}else{R=(Q<<16>>16)+64|0;do{if(R>>>0<128>>>0){Q=(ka-ma<<7)-128+R|0;if((ka|0)<(P|0)){pa=d[(c[T>>2]|0)+Q|0]|0;break}else{pa=d[(c[D>>2]|0)+Q|0]|0;break}}else{pa=c[B>>2]|0}}while(0);na=ka;oa=pa+la|0}R=ka+1|0;if((R|0)>(P|0)){ja=oa;break}else{ka=R;la=oa;ma=na}}}}while(0);F=ja+J|0;H=H+1|0;}while((H|0)<6);if((F|0)<0){qa=1}else{eSa(e,f,n|0,w,o|0);qa=0}c[e+176>>2]=qa}qa=(c[e+180>>2]|0)>0?32:0;w=(c[e+184>>2]|0)>0?qa|16:qa;qa=(c[e+188>>2]|0)>0?w|8:w;w=(c[e+192>>2]|0)>0?qa|4:qa;qa=(c[e+196>>2]|0)>0?w|2:w;w=qa&3|(c[e+200>>2]|0)>0;F=e+9984|0;H=(c[F>>2]|0)!=0;if((c[e+9992>>2]|0)==1){ja=H?w|4:w;na=d[1379080+ja|0]|0;ma=d[1379064+ja|0]|0;ja=t|0;oa=c[ja>>2]|0;la=e+788|0;ka=c[la>>2]|0;if((ka|0)>(na|0)){ra=ka-na|0;sa=oa<<na|ma}else{pa=je(ma>>>((na-ka|0)>>>0)|oa<<ka|0)|0;oa=e+796|0;B=c[oa>>2]|0;y=pa;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[oa>>2]=(c[oa>>2]|0)+4;ra=32-na+ka|0;sa=ma}c[ja>>2]=sa;c[la>>2]=ra}else{ra=t|0;la=c[ra>>2]|0;sa=e+788|0;ja=c[sa>>2]|0;if((ja|0)>1){ta=ja-1|0;ua=la<<1}else{ma=je(la<<ja|0)|0;la=e+796|0;ka=c[la>>2]|0;y=ma;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;c[la>>2]=(c[la>>2]|0)+4;ta=ja+31|0;ua=0}c[ra>>2]=ua;c[sa>>2]=ta;ja=(H?w|8:w)|4;w=d[1379128+ja|0]|0;H=d[1379096+ja|0]|0;if((ta|0)>(w|0)){va=ta;wa=ua<<w|H}else{ja=je(H>>>((w-ta|0)>>>0)|ua<<ta|0)|0;ua=e+796|0;la=c[ua>>2]|0;y=ja;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;c[ua>>2]=(c[ua>>2]|0)+4;va=ta+32|0;wa=H}c[ra>>2]=wa;c[sa>>2]=va-w}w=e+176|0;va=c[w>>2]|0;sa=u|0;wa=c[sa>>2]|0;ra=u+4|0;H=c[ra>>2]|0;if((H|0)>1){xa=H-1|0;ya=wa<<1|va}else{ta=je(va>>>((1-H|0)>>>0)|wa<<H|0)|0;wa=u+12|0;ua=c[wa>>2]|0;y=ta;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y;c[wa>>2]=(c[wa>>2]|0)+4;xa=H+31|0;ya=va}c[sa>>2]=ya;c[ra>>2]=xa;va=qa>>2;qa=d[1379529+(va<<1)|0]|0;H=d[1379528+(va<<1)|0]|0;if((xa|0)>(qa|0)){za=xa;Aa=ya<<qa|H}else{va=je(H>>>((qa-xa|0)>>>0)|ya<<xa|0)|0;ya=u+12|0;wa=c[ya>>2]|0;y=va;a[wa]=y;y=y>>8;a[wa+1|0]=y;y=y>>8;a[wa+2|0]=y;y=y>>8;a[wa+3|0]=y;c[ya>>2]=(c[ya>>2]|0)+4;za=xa+32|0;Aa=H}c[sa>>2]=Aa;c[ra>>2]=za-qa;qa=c[F>>2]|0;if((qa|0)!=0){F=c[1520336+(qa+2<<2)>>2]|0;qa=z|0;za=c[qa>>2]|0;ra=z+4|0;Aa=c[ra>>2]|0;if((Aa|0)>2){Ba=Aa-2|0;Ca=za<<2|F}else{sa=je(F>>>((2-Aa|0)>>>0)|za<<Aa|0)|0;za=z+12|0;H=c[za>>2]|0;y=sa;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[za>>2]=(c[za>>2]|0)+4;Ba=Aa+30|0;Ca=F}c[qa>>2]=Ca;c[ra>>2]=Ba}if((c[e+14152>>2]|0)==0){Ba=c[e+14236>>2]|0;ra=z|0;Ca=c[ra>>2]|0;qa=z+4|0;F=c[qa>>2]|0;if((F|0)>1){Da=F-1|0;Ea=Ca<<1|Ba}else{Aa=je(Ba>>>((1-F|0)>>>0)|Ca<<F|0)|0;Ca=z+12|0;za=c[Ca>>2]|0;y=Aa;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;c[Ca>>2]=(c[Ca>>2]|0)+4;Da=F+31|0;Ea=Ba}c[ra>>2]=Ea;c[qa>>2]=Da}if(v){Da=e+788|0;qa=e+792|0;Ea=e+796|0;ra=((c[Ea>>2]|0)-(c[qa>>2]|0)<<3)+(32-(c[Da>>2]|0))|0;Ba=e+13700|0;F=c[Ba>>2]|0;c[Ba>>2]=ra;Ca=e+13696|0;c[Ca>>2]=(c[Ca>>2]|0)-F+ra;ra=p|0;dSa(e,f,m|0,ra,z,A);F=((c[Ea>>2]|0)-(c[qa>>2]|0)<<3)+(32-(c[Da>>2]|0))|0;Da=c[Ba>>2]|0;c[Ba>>2]=F;Ba=e+13672|0;c[Ba>>2]=(c[Ba>>2]|0)-Da+F;Fa=ra}else{ra=p|0;dSa(e,f,m|0,ra,z,A);Fa=ra}ra=e+13680|0;c[ra>>2]=(c[ra>>2]|0)+1;if((c[w>>2]|0)==0){i=j;return}eSa(e,f,n|0,Fa,o|0);i=j;return}if((c[e+9992>>2]|0)==3){o=e+11736|0;Fa=c[o>>2]|0;n=c[1344536+(Fa<<2)>>2]|0;w=c[e+12476>>2]|0;if((w|0)==0){mrc(e+11824|0,0,32)|0}ra=(ca(c[e+124>>2]|0,c[e+12480>>2]|0)|0)+w|0;if((a[(c[e+4720>>2]|0)+ra|0]|0)!=0){ra=e+13692|0;c[ra>>2]=(c[ra>>2]|0)+1;c[e+11780>>2]=0;c[e+11776>>2]=0;c[e+11748>>2]=0;c[e+11744>>2]=0;c[o>>2]=1;ra=e+9960|0;c[ra>>2]=(c[ra>>2]|0)-(c[e+9984>>2]|0);i=j;return}do{if((c[e+14404>>2]&8|0)==0){ra=(c[e+180>>2]>>31)+32&-32;w=(c[e+184>>2]|0)>-1?ra|16:ra;ra=(c[e+188>>2]|0)>-1?w|8:w;w=(c[e+192>>2]|0)>-1?ra|4:ra;ra=(c[e+196>>2]|0)>-1?w|2:w;if(!((c[e+200>>2]|0)>-1)){Ga=ra;break}Ga=ra|1}else{ra=c[e+9972>>2]|0;w=c[e+13112>>2]|0;z=(w|0)<0?w:0;m=w>>31&32;w=c[e+13116>>2]|0;if((w|0)<0){Ha=m|16;Ia=z+w|0}else{Ha=m;Ia=z}z=c[e+13120>>2]|0;if((z|0)<0){Ja=Ha|8;Ka=z+Ia|0}else{Ja=Ha;Ka=Ia}z=c[e+13124>>2]|0;if((z|0)<0){La=Ja|4;Ma=z+Ka|0}else{La=Ja;Ma=Ka}z=c[e+13128>>2]|0;if((z|0)<0){Na=La|2;Oa=z+Ma|0}else{Na=La;Oa=Ma}z=c[e+13132>>2]|0;if((z|0)<0){Pa=z+Oa|0;Qa=Na|1;x=14}else{if((Na|0)==0){Ra=0}else{Pa=Oa;Qa=Na;x=14}}if((x|0)==14){z=(ca((h|g|n|c[e+9984>>2]|0)==0?-10:-6,ra>>>1)|0)>(Pa|0);Ra=z?Qa:0}z=e+10092|0;ra=e+14340|0;m=e+180|0;do{if((c[m>>2]|0)>-1){if((Ra&32|0)!=0){break}c[m>>2]=-1;qe[c[z>>2]&1023](c[ra>>2]|0)}}while(0);m=e+184|0;do{if((c[m>>2]|0)>-1){if((Ra&16|0)!=0){break}c[m>>2]=-1;qe[c[z>>2]&1023]((c[ra>>2]|0)+128|0)}}while(0);m=e+188|0;do{if((c[m>>2]|0)>-1){if((Ra&8|0)!=0){break}c[m>>2]=-1;qe[c[z>>2]&1023]((c[ra>>2]|0)+256|0)}}while(0);m=e+192|0;do{if((c[m>>2]|0)>-1){if((Ra&4|0)!=0){break}c[m>>2]=-1;qe[c[z>>2]&1023]((c[ra>>2]|0)+384|0)}}while(0);m=e+196|0;do{if((c[m>>2]|0)>-1){if((Ra&2|0)!=0){break}c[m>>2]=-1;qe[c[z>>2]&1023]((c[ra>>2]|0)+512|0)}}while(0);m=e+200|0;if(!((c[m>>2]|0)>-1)){Ga=Ra;break}if((Ra&1|0)!=0){Ga=Ra;break}c[m>>2]=-1;qe[c[z>>2]&1023]((c[ra>>2]|0)+640|0);Ga=Ra}}while(0);Ra=t|0;Qa=c[Ra>>2]|0;Pa=e+788|0;Na=c[Pa>>2]|0;Oa=(Na|0)>1;if((h|g|n|Ga|0)==0){if(Oa){Sa=Na-1|0;Ta=Qa<<1|1}else{Ma=je(1>>>((1-Na|0)>>>0)|Qa<<Na|0)|0;La=e+796|0;Ka=c[La>>2]|0;y=Ma;a[Ka]=y;y=y>>8;a[Ka+1|0]=y;y=y>>8;a[Ka+2|0]=y;y=y>>8;a[Ka+3|0]=y;c[La>>2]=(c[La>>2]|0)+4;Sa=Na+31|0;Ta=1}c[Ra>>2]=Ta;c[Pa>>2]=Sa;if(v){Sa=e+13696|0;c[Sa>>2]=(c[Sa>>2]|0)+1;Sa=e+13700|0;c[Sa>>2]=(c[Sa>>2]|0)+1}Sa=e+13692|0;c[Sa>>2]=(c[Sa>>2]|0)+1;i=j;return}if(Oa){Ua=Na-1|0;Va=Qa<<1}else{Oa=je(Qa<<Na|0)|0;Qa=e+796|0;Sa=c[Qa>>2]|0;y=Oa;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;c[Qa>>2]=(c[Qa>>2]|0)+4;Ua=Na+31|0;Va=0}c[Ra>>2]=Va;c[Pa>>2]=Ua;Na=(Ga|0)!=0;Qa=Na&1^1;if((Ua|0)>1){Wa=Ua-1|0;Xa=Va<<1|Qa}else{Sa=je(Qa>>>((1-Ua|0)>>>0)|Va<<Ua|0)|0;Va=e+796|0;Oa=c[Va>>2]|0;y=Sa;a[Oa]=y;y=y>>8;a[Oa+1|0]=y;y=y>>8;a[Oa+2|0]=y;y=y>>8;a[Oa+3|0]=y;c[Va>>2]=(c[Va>>2]|0)+4;Wa=Ua+31|0;Xa=Qa}c[Ra>>2]=Xa;c[Pa>>2]=Wa;Qa=n+1|0;if((Wa|0)>(Qa|0)){Ya=Wa-Qa|0;Za=Xa<<Qa|1}else{Ua=je(1>>>((Qa-Wa|0)>>>0)|Xa<<Wa|0)|0;Xa=e+796|0;Qa=c[Xa>>2]|0;y=Ua;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;c[Xa>>2]=(c[Xa>>2]|0)+4;Ya=31-n+Wa|0;Za=1}c[Ra>>2]=Za;c[Pa>>2]=Ya;do{if(Na){if((Ya|0)>6){_a=Ya-6|0;$a=Za<<6|Ga}else{Wa=je(Za<<Ya|Ga>>>((6-Ya|0)>>>0)|0)|0;n=e+796|0;Xa=c[n>>2]|0;y=Wa;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;_a=Ya+26|0;$a=Ga}c[Ra>>2]=$a;c[Pa>>2]=_a;if((Fa|0)==7){ab=$a;bb=_a;x=74;break}n=c[e+9984>>2]|0;if((n|0)==0){if((_a|0)>1){cb=_a-1|0;db=$a<<1}else{Xa=je($a<<_a|0)|0;Wa=e+796|0;Qa=c[Wa>>2]|0;y=Xa;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;c[Wa>>2]=(c[Wa>>2]|0)+4;cb=_a+31|0;db=0}c[Ra>>2]=db;c[Pa>>2]=cb;eb=db;fb=cb;break}else{Wa=(n>>2)+3|0;if((_a|0)>2){gb=_a-2|0;hb=$a<<2|Wa}else{n=je($a<<_a|Wa>>>((2-_a|0)>>>0)|0)|0;Qa=e+796|0;Xa=c[Qa>>2]|0;y=n;a[Xa]=y;y=y>>8;a[Xa+1|0]=y;y=y>>8;a[Xa+2|0]=y;y=y>>8;a[Xa+3|0]=y;c[Qa>>2]=(c[Qa>>2]|0)+4;gb=_a+30|0;hb=Wa}c[Ra>>2]=hb;c[Pa>>2]=gb;eb=hb;fb=gb;break}}else{ab=Za;bb=Ya;x=74}}while(0);if((x|0)==74){Ya=e+9960|0;c[Ya>>2]=(c[Ya>>2]|0)-(c[e+9984>>2]|0);eb=ab;fb=bb}do{if((c[e+14152>>2]|0)==0){if(Na){bb=c[e+14236>>2]|0;if((fb|0)>1){ib=fb-1|0;jb=eb<<1|bb}else{ab=je(bb>>>((1-fb|0)>>>0)|eb<<fb|0)|0;Ya=e+796|0;Za=c[Ya>>2]|0;y=ab;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;c[Ya>>2]=(c[Ya>>2]|0)+4;ib=fb+31|0;jb=bb}c[Ra>>2]=jb;c[Pa>>2]=ib;kb=jb;lb=ib}else{kb=eb;lb=fb}if((Fa|0)==7){mb=lb;nb=kb;break}bb=(c[e+11740>>2]|0)==3|0;if((lb|0)>1){ob=lb-1|0;pb=kb<<1|bb}else{Ya=je(bb>>>((1-lb|0)>>>0)|kb<<lb|0)|0;Za=e+796|0;ab=c[Za>>2]|0;y=Ya;a[ab]=y;y=y>>8;a[ab+1|0]=y;y=y>>8;a[ab+2|0]=y;y=y>>8;a[ab+3|0]=y;c[Za>>2]=(c[Za>>2]|0)+4;ob=lb+31|0;pb=bb}c[Ra>>2]=pb;c[Pa>>2]=ob;mb=ob;nb=pb}else{mb=fb;nb=eb}}while(0);if(v){eb=((c[e+796>>2]|0)-(c[e+792>>2]|0)<<3)+(32-mb)|0;fb=e+13700|0;pb=c[fb>>2]|0;c[fb>>2]=eb;fb=e+13696|0;c[fb>>2]=(c[fb>>2]|0)-pb+eb}do{if((Fa|0)==7){if((c[e+64>>2]&4|0)==0){Aqb(e,g,1);Aqb(e,h,1)}else{if((g|0)==0){qb=d[1339809]|0}else{qb=(d[1339809+(g<<26>>26<<1)|0]|0)+1|0}if((h|0)==0){rb=d[1339809]|0}else{rb=(d[1339809+(h<<26>>26<<1)|0]|0)+1|0}eb=mb-(rb+qb)|0;pb=e+796|0;c[pb>>2]=(c[pb>>2]|0)+(-(eb>>5<<2)|0);c[Pa>>2]=eb&31}eb=e+13688|0;c[eb>>2]=(c[eb>>2]|0)+1;eb=e+13684|0;c[eb>>2]=(c[eb>>2]|0)+1}else{eb=c[o>>2]|0;pb=(eb&1|0)!=0;if((c[e+11740>>2]|0)!=3){if(pb){fb=e+11744|0;ob=e+11824|0;lb=e+11748|0;kb=e+11828|0;cSa(e,(c[fb>>2]|0)-(c[ob>>2]|0)|0,(c[lb>>2]|0)-(c[kb>>2]|0)|0,c[e+11556>>2]|0);ib=c[fb>>2]|0;c[e+11832>>2]=ib;c[ob>>2]=ib;ib=c[lb>>2]|0;c[e+11836>>2]=ib;c[kb>>2]=ib;ib=e+13684|0;c[ib>>2]=(c[ib>>2]|0)+1;sb=c[o>>2]|0}else{sb=eb}if((sb&2|0)==0){break}ib=e+11776|0;kb=e+11840|0;lb=e+11780|0;ob=e+11844|0;cSa(e,(c[ib>>2]|0)-(c[kb>>2]|0)|0,(c[lb>>2]|0)-(c[ob>>2]|0)|0,c[e+11560>>2]|0);fb=c[ib>>2]|0;c[e+11848>>2]=fb;c[kb>>2]=fb;fb=c[lb>>2]|0;c[e+11852>>2]=fb;c[ob>>2]=fb;fb=e+13688|0;c[fb>>2]=(c[fb>>2]|0)+1;break}if(pb){pb=c[e+11808>>2]|0;if((mb|0)>1){tb=mb-1|0;ub=nb<<1|pb}else{fb=je(pb>>>((1-mb|0)>>>0)|nb<<mb|0)|0;ob=e+796|0;lb=c[ob>>2]|0;y=fb;a[lb]=y;y=y>>8;a[lb+1|0]=y;y=y>>8;a[lb+2|0]=y;y=y>>8;a[lb+3|0]=y;c[ob>>2]=(c[ob>>2]|0)+4;tb=mb+31|0;ub=pb}c[Ra>>2]=ub;c[Pa>>2]=tb;pb=c[e+11812>>2]|0;if((tb|0)>1){vb=tb-1|0;wb=ub<<1|pb}else{ob=je(ub<<tb|pb>>>((1-tb|0)>>>0)|0)|0;lb=e+796|0;fb=c[lb>>2]|0;y=ob;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;c[lb>>2]=(c[lb>>2]|0)+4;vb=tb+31|0;wb=pb}c[Ra>>2]=wb;c[Pa>>2]=vb;xb=c[o>>2]|0;yb=wb;zb=vb}else{xb=eb;yb=nb;zb=mb}if((xb&2|0)==0){Ab=xb}else{eb=c[e+11816>>2]|0;if((zb|0)>1){Bb=zb-1|0;Cb=yb<<1|eb}else{pb=je(eb>>>((1-zb|0)>>>0)|yb<<zb|0)|0;lb=e+796|0;fb=c[lb>>2]|0;y=pb;a[fb]=y;y=y>>8;a[fb+1|0]=y;y=y>>8;a[fb+2|0]=y;y=y>>8;a[fb+3|0]=y;c[lb>>2]=(c[lb>>2]|0)+4;Bb=zb+31|0;Cb=eb}c[Ra>>2]=Cb;c[Pa>>2]=Bb;eb=c[e+11820>>2]|0;if((Bb|0)>1){Db=Bb-1|0;Eb=Cb<<1|eb}else{lb=je(Cb<<Bb|eb>>>((1-Bb|0)>>>0)|0)|0;fb=e+796|0;pb=c[fb>>2]|0;y=lb;a[pb]=y;y=y>>8;a[pb+1|0]=y;y=y>>8;a[pb+2|0]=y;y=y>>8;a[pb+3|0]=y;c[fb>>2]=(c[fb>>2]|0)+4;Db=Bb+31|0;Eb=eb}c[Ra>>2]=Eb;c[Pa>>2]=Db;Ab=c[o>>2]|0}if((Ab&1|0)==0){Fb=Ab}else{eb=e+11556|0;fb=e+11744|0;pb=e+11824|0;lb=e+11748|0;ob=e+11828|0;cSa(e,(c[fb>>2]|0)-(c[pb>>2]|0)|0,(c[lb>>2]|0)-((c[ob>>2]|0)/2|0)|0,c[eb>>2]|0);c[pb>>2]=c[fb>>2];c[ob>>2]=c[lb>>2]<<1;lb=e+11752|0;ob=e+11832|0;fb=e+11756|0;pb=e+11836|0;cSa(e,(c[lb>>2]|0)-(c[ob>>2]|0)|0,(c[fb>>2]|0)-((c[pb>>2]|0)/2|0)|0,c[eb>>2]|0);c[ob>>2]=c[lb>>2];c[pb>>2]=c[fb>>2]<<1;fb=e+13684|0;c[fb>>2]=(c[fb>>2]|0)+1;Fb=c[o>>2]|0}if((Fb&2|0)==0){break}fb=e+11560|0;pb=e+11776|0;lb=e+11840|0;ob=e+11780|0;eb=e+11844|0;cSa(e,(c[pb>>2]|0)-(c[lb>>2]|0)|0,(c[ob>>2]|0)-((c[eb>>2]|0)/2|0)|0,c[fb>>2]|0);c[lb>>2]=c[pb>>2];c[eb>>2]=c[ob>>2]<<1;ob=e+11784|0;eb=e+11848|0;pb=e+11788|0;lb=e+11852|0;cSa(e,(c[ob>>2]|0)-(c[eb>>2]|0)|0,(c[pb>>2]|0)-((c[lb>>2]|0)/2|0)|0,c[fb>>2]|0);c[eb>>2]=c[ob>>2];c[lb>>2]=c[pb>>2]<<1;pb=e+13688|0;c[pb>>2]=(c[pb>>2]|0)+1}}while(0);if(v){Fb=e+792|0;o=e+796|0;Ab=((c[o>>2]|0)-(c[Fb>>2]|0)<<3)+(32-(c[Pa>>2]|0))|0;Db=e+13700|0;Eb=c[Db>>2]|0;c[Db>>2]=Ab;Ra=e+13664|0;c[Ra>>2]=(c[Ra>>2]|0)-Eb+Ab;dSa(e,f,0,0,0,t);Ab=((c[o>>2]|0)-(c[Fb>>2]|0)<<3)+(32-(c[Pa>>2]|0))|0;Pa=c[Db>>2]|0;c[Db>>2]=Ab;Db=e+13676|0;c[Db>>2]=(c[Db>>2]|0)-Pa+Ab;i=j;return}else{dSa(e,f,0,0,0,t);i=j;return}}do{if((c[e+14404>>2]&8|0)==0){Ab=(c[e+180>>2]>>31)+32&-32;Pa=(c[e+184>>2]|0)>-1?Ab|16:Ab;Ab=(c[e+188>>2]|0)>-1?Pa|8:Pa;Pa=(c[e+192>>2]|0)>-1?Ab|4:Ab;Ab=(c[e+196>>2]|0)>-1?Pa|2:Pa;if(!((c[e+200>>2]|0)>-1)){Gb=Ab;break}Gb=Ab|1}else{Ab=(c[e+11740>>2]|0)==0;Pa=c[e+9984>>2]|0;Db=((Pa|0)!=0?8:0)|(Ab?0:16);Fb=(c[e+9972>>2]|0)>>>1;o=ca(d[1379128+Db|0]|0,Fb)|0;Eb=(o|0)==2147483647;Ra=ca(d[1379128+(Db|1)|0]|0,Fb)|0;Bb=c[e+13132>>2]|0;Cb=Ra+Bb|0;Ra=(Cb|0)<(o|0);zb=Ra?Cb:o;o=ca(d[1379128+(Db|2)|0]|0,Fb)|0;Cb=c[e+13128>>2]|0;yb=o+Cb|0;o=(yb|0)<(zb|0);xb=o?yb:zb;zb=Cb+Bb+(ca(d[1379128+(Db|3)|0]|0,Fb)|0)|0;Db=(zb|0)<(xb|0);Bb=Db?zb:xb;xb=e+13112|0;zb=e+13116|0;Cb=e+13120|0;yb=e+13124|0;mb=2147483647;nb=-1;vb=0;do{wb=ca(d[1379529+((vb^15)<<1)|0]|0,Fb)|0;if((vb&1|0)==0){Hb=wb}else{Hb=(c[yb>>2]|0)+wb|0}if((vb&2|0)==0){Ib=Hb}else{Ib=(c[Cb>>2]|0)+Hb|0}if((vb&4|0)==0){Jb=Ib}else{Jb=(c[zb>>2]|0)+Ib|0}if((vb&8|0)==0){Kb=Jb}else{Kb=(c[xb>>2]|0)+Jb|0}wb=(Kb|0)<(mb|0);mb=wb?Kb:mb;nb=wb?vb:nb;vb=vb+1|0;}while((vb|0)<16);vb=(nb<<2)+(Db?3:o?2:Ra?1:Eb<<31>>31)|0;if((h|g|Pa|0)!=0|Ab^1){Lb=vb}else{Lb=(Bb+(Fb<<1)+mb|0)>-1?0:vb}vb=e+10092|0;xb=e+14340|0;zb=e+180|0;do{if((c[zb>>2]|0)>-1){if((Lb&32|0)!=0){break}c[zb>>2]=-1;qe[c[vb>>2]&1023](c[xb>>2]|0)}}while(0);zb=e+184|0;do{if((c[zb>>2]|0)>-1){if((Lb&16|0)!=0){break}c[zb>>2]=-1;qe[c[vb>>2]&1023]((c[xb>>2]|0)+128|0)}}while(0);zb=e+188|0;do{if((c[zb>>2]|0)>-1){if((Lb&8|0)!=0){break}c[zb>>2]=-1;qe[c[vb>>2]&1023]((c[xb>>2]|0)+256|0)}}while(0);zb=e+192|0;do{if((c[zb>>2]|0)>-1){if((Lb&4|0)!=0){break}c[zb>>2]=-1;qe[c[vb>>2]&1023]((c[xb>>2]|0)+384|0)}}while(0);zb=e+196|0;do{if((c[zb>>2]|0)>-1){if((Lb&2|0)!=0){break}c[zb>>2]=-1;qe[c[vb>>2]&1023]((c[xb>>2]|0)+512|0)}}while(0);zb=e+200|0;if(!((c[zb>>2]|0)>-1)){Gb=Lb;break}if((Lb&1|0)!=0){Gb=Lb;break}c[zb>>2]=-1;qe[c[vb>>2]&1023]((c[xb>>2]|0)+640|0);Gb=Lb}}while(0);Lb=e+9984|0;c:do{if((h|g|Gb|c[Lb>>2]|0)==0){if((c[e+11740>>2]|0)!=0){break}Kb=e+68|0;Jb=c[Kb>>2]|0;do{if((Jb|0)>0){Ib=c[e+12476>>2]<<4;Hb=c[e+12480>>2]<<4;zb=e+148|0;mb=(ca(Hb,c[zb>>2]|0)|0)+Ib|0;Fb=c[e+5400>>2]|0;Bb=Fb+mb|0;Ab=e+9924|0;c[Ab>>2]=1;Pa=e+164|0;Eb=mb+16|0;Ra=Ib+16|0;o=e+8|0;Db=e+12|0;nb=e+9960|0;Cb=Hb+16|0;yb=e+10108|0;ra=0;z=Jb;while(1){if((ra|0)>=(z|0)){x=177;break}wb=ra+1|0;tb=c[(c[Pa>>2]|0)+(wb<<2)>>2]|0;if((tb|0)==0){x=177;break}if((c[tb+88>>2]|0)!=3){x=177;break}ub=c[tb>>2]|0;sb=(c[tb+2196>>2]|0)==0?Eb:mb;tb=c[o>>2]|0;qb=c[Db>>2]|0;if((Ra|0)>(tb|0)|(Cb|0)>(qb|0)){rb=tb-Ib|0;tb=(rb|0)<16?rb:16;rb=qb-Hb|0;qb=(rb|0)<16?rb:16;if((qb|0)>0&(tb|0)>0){rb=0;Fa=0;while(1){pb=ca(c[zb>>2]|0,Fa)|0;lb=rb;ob=0;do{eb=pb+ob|0;fb=(d[Fb+(eb+mb)|0]|0)-(d[ub+(eb+sb)|0]|0)|0;lb=((fb|0)>-1?fb:-fb|0)+lb|0;ob=ob+1|0;}while((ob|0)<(tb|0));ob=Fa+1|0;if((ob|0)<(qb|0)){rb=lb;Fa=ob}else{Mb=lb;break}}}else{Mb=0}Nb=(Mb<<8|0)/(ca(qb,tb)|0)|0}else{Nb=Xe[c[yb>>2]&511](0,Bb,ub+sb|0,c[zb>>2]|0,16)|0}if((Nb|0)>((c[nb>>2]|0)*70|0|0)){x=175;break}ra=wb;z=c[Kb>>2]|0}if((x|0)==175){c[Ab>>2]=0;break c}else if((x|0)==177){if((c[Ab>>2]|0)==1){break}else{break c}}}else{c[e+9924>>2]=1}}while(0);Kb=t|0;Jb=c[Kb>>2]|0;xb=e+788|0;vb=c[xb>>2]|0;if((vb|0)>1){Ob=vb-1|0;Pb=Jb<<1|1}else{z=je(1>>>((1-vb|0)>>>0)|Jb<<vb|0)|0;Jb=e+796|0;ra=c[Jb>>2]|0;y=z;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;c[Jb>>2]=(c[Jb>>2]|0)+4;Ob=vb+31|0;Pb=1}c[Kb>>2]=Pb;c[xb>>2]=Ob;if(v){xb=e+13696|0;c[xb>>2]=(c[xb>>2]|0)+1;xb=e+13700|0;c[xb>>2]=(c[xb>>2]|0)+1}xb=e+13692|0;c[xb>>2]=(c[xb>>2]|0)+1;i=j;return}}while(0);Ob=t|0;t=c[Ob>>2]|0;Pb=e+788|0;x=c[Pb>>2]|0;if((x|0)>1){Qb=x-1|0;Rb=t<<1}else{Nb=je(t<<x|0)|0;t=e+796|0;Mb=c[t>>2]|0;y=Nb;a[Mb]=y;y=y>>8;a[Mb+1|0]=y;y=y>>8;a[Mb+2|0]=y;y=y>>8;a[Mb+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;Qb=x+31|0;Rb=0}c[Ob>>2]=Rb;c[Pb>>2]=Qb;x=Gb&3;t=Gb>>2^15;Mb=c[e+11740>>2]|0;if((Mb|0)==0){Nb=(c[Lb>>2]|0)==0?x:x|8;xb=d[1379128+Nb|0]|0;Kb=d[1379096+Nb|0]|0;if((Qb|0)>(xb|0)){Sb=Qb;Tb=Rb<<xb|Kb}else{Nb=je(Kb>>>((xb-Qb|0)>>>0)|Rb<<Qb|0)|0;vb=e+796|0;Jb=c[vb>>2]|0;y=Nb;a[Jb]=y;y=y>>8;a[Jb+1|0]=y;y=y>>8;a[Jb+2|0]=y;y=y>>8;a[Jb+3|0]=y;c[vb>>2]=(c[vb>>2]|0)+4;Sb=Qb+32|0;Tb=Kb}c[Ob>>2]=Tb;c[Pb>>2]=Sb-xb;xb=d[1379529+(t<<1)|0]|0;Sb=d[1379528+(t<<1)|0]|0;Tb=u|0;Kb=c[Tb>>2]|0;vb=u+4|0;Jb=c[vb>>2]|0;if((Jb|0)>(xb|0)){Ub=Jb-xb|0;Vb=Kb<<xb|Sb}else{Nb=je(Sb>>>((xb-Jb|0)>>>0)|Kb<<Jb|0)|0;Kb=u+12|0;ra=c[Kb>>2]|0;y=Nb;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;c[Kb>>2]=(c[Kb>>2]|0)+4;Ub=32-xb+Jb|0;Vb=Sb}c[Tb>>2]=Vb;c[vb>>2]=Ub;Sb=c[Lb>>2]|0;if((Sb|0)==0){Wb=Ub;Xb=Vb}else{Jb=c[1520336+(Sb+2<<2)>>2]|0;if((Ub|0)>2){Yb=Ub-2|0;Zb=Vb<<2|Jb}else{Sb=je(Vb<<Ub|Jb>>>((2-Ub|0)>>>0)|0)|0;Vb=u+12|0;xb=c[Vb>>2]|0;y=Sb;a[xb]=y;y=y>>8;a[xb+1|0]=y;y=y>>8;a[xb+2|0]=y;y=y>>8;a[xb+3|0]=y;c[Vb>>2]=(c[Vb>>2]|0)+4;Yb=Ub+30|0;Zb=Jb}c[Tb>>2]=Zb;c[vb>>2]=Yb;Wb=Yb;Xb=Zb}if((c[e+14152>>2]|0)==0){if((Gb|0)==0){_b=Wb;$b=Xb}else{Zb=c[e+14236>>2]|0;if((Wb|0)>1){ac=Wb-1|0;bc=Xb<<1|Zb}else{Yb=je(Zb>>>((1-Wb|0)>>>0)|Xb<<Wb|0)|0;Xb=u+12|0;Jb=c[Xb>>2]|0;y=Yb;a[Jb]=y;y=y>>8;a[Jb+1|0]=y;y=y>>8;a[Jb+2|0]=y;y=y>>8;a[Jb+3|0]=y;c[Xb>>2]=(c[Xb>>2]|0)+4;ac=Wb+31|0;bc=Zb}c[Tb>>2]=bc;c[vb>>2]=ac;_b=ac;$b=bc}if((_b|0)>1){cc=_b-1|0;dc=$b<<1}else{bc=je($b<<_b|0)|0;$b=u+12|0;ac=c[$b>>2]|0;y=bc;a[ac]=y;y=y>>8;a[ac+1|0]=y;y=y>>8;a[ac+2|0]=y;y=y>>8;a[ac+3|0]=y;c[$b>>2]=(c[$b>>2]|0)+4;cc=_b+31|0;dc=0}c[Tb>>2]=dc;c[vb>>2]=cc}if(v){cc=((c[e+796>>2]|0)-(c[e+792>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;vb=e+13700|0;dc=c[vb>>2]|0;c[vb>>2]=cc;vb=e+13696|0;c[vb>>2]=(c[vb>>2]|0)-dc+cc}Rga(e,0,0,k,l)|0;cSa(e,g-(c[k>>2]|0)|0,h-(c[l>>2]|0)|0,c[e+11556>>2]|0)}else if((Mb|0)==3){Mb=(c[Lb>>2]|0)==0?x:x|8;h=d[1379128+Mb|0]|0;g=d[1379096+Mb|0]|0;if((Qb|0)>(h|0)){ec=Qb;fc=Rb<<h|g}else{Mb=je(g>>>((h-Qb|0)>>>0)|Rb<<Qb|0)|0;cc=e+796|0;dc=c[cc>>2]|0;y=Mb;a[dc]=y;y=y>>8;a[dc+1|0]=y;y=y>>8;a[dc+2|0]=y;y=y>>8;a[dc+3|0]=y;c[cc>>2]=(c[cc>>2]|0)+4;ec=Qb+32|0;fc=g}c[Ob>>2]=fc;c[Pb>>2]=ec-h;h=d[1379529+(t<<1)|0]|0;ec=d[1379528+(t<<1)|0]|0;fc=u|0;g=c[fc>>2]|0;cc=u+4|0;dc=c[cc>>2]|0;if((dc|0)>(h|0)){gc=dc-h|0;hc=g<<h|ec}else{Mb=je(ec>>>((h-dc|0)>>>0)|g<<dc|0)|0;g=u+12|0;vb=c[g>>2]|0;y=Mb;a[vb]=y;y=y>>8;a[vb+1|0]=y;y=y>>8;a[vb+2|0]=y;y=y>>8;a[vb+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;gc=32-h+dc|0;hc=ec}c[fc>>2]=hc;c[cc>>2]=gc;ec=c[Lb>>2]|0;if((ec|0)==0){ic=gc;jc=hc}else{Lb=c[1520336+(ec+2<<2)>>2]|0;if((gc|0)>2){kc=gc-2|0;lc=hc<<2|Lb}else{ec=je(hc<<gc|Lb>>>((2-gc|0)>>>0)|0)|0;hc=u+12|0;dc=c[hc>>2]|0;y=ec;a[dc]=y;y=y>>8;a[dc+1|0]=y;y=y>>8;a[dc+2|0]=y;y=y>>8;a[dc+3|0]=y;c[hc>>2]=(c[hc>>2]|0)+4;kc=gc+30|0;lc=Lb}c[fc>>2]=lc;c[cc>>2]=kc;ic=kc;jc=lc}if((Gb|0)==0){mc=ic;nc=jc}else{lc=c[e+14236>>2]|0;if((ic|0)>1){oc=ic-1|0;pc=jc<<1|lc}else{kc=je(lc>>>((1-ic|0)>>>0)|jc<<ic|0)|0;jc=u+12|0;Lb=c[jc>>2]|0;y=kc;a[Lb]=y;y=y>>8;a[Lb+1|0]=y;y=y>>8;a[Lb+2|0]=y;y=y>>8;a[Lb+3|0]=y;c[jc>>2]=(c[jc>>2]|0)+4;oc=ic+31|0;pc=lc}c[fc>>2]=pc;c[cc>>2]=oc;mc=oc;nc=pc}if((mc|0)>1){qc=mc-1|0;rc=nc<<1|1}else{pc=je(1>>>((1-mc|0)>>>0)|nc<<mc|0)|0;nc=u+12|0;oc=c[nc>>2]|0;y=pc;a[oc]=y;y=y>>8;a[oc+1|0]=y;y=y>>8;a[oc+2|0]=y;y=y>>8;a[oc+3|0]=y;c[nc>>2]=(c[nc>>2]|0)+4;qc=mc+31|0;rc=1}c[fc>>2]=rc;c[cc>>2]=qc;if(v){qc=((c[e+796>>2]|0)-(c[e+792>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;cc=e+13700|0;rc=c[cc>>2]|0;c[cc>>2]=qc;cc=e+13696|0;c[cc>>2]=(c[cc>>2]|0)-rc+qc}Rga(e,0,0,k,l)|0;c[l>>2]=(c[l>>2]|0)/2|0;qc=c[e+11808>>2]|0;rc=c[Ob>>2]|0;cc=c[Pb>>2]|0;if((cc|0)>1){sc=cc-1|0;tc=rc<<1|qc}else{fc=je(qc>>>((1-cc|0)>>>0)|rc<<cc|0)|0;rc=e+796|0;mc=c[rc>>2]|0;y=fc;a[mc]=y;y=y>>8;a[mc+1|0]=y;y=y>>8;a[mc+2|0]=y;y=y>>8;a[mc+3|0]=y;c[rc>>2]=(c[rc>>2]|0)+4;sc=cc+31|0;tc=qc}c[Ob>>2]=tc;c[Pb>>2]=sc;qc=c[e+11812>>2]|0;if((sc|0)>1){uc=sc-1|0;vc=tc<<1|qc}else{cc=je(tc<<sc|qc>>>((1-sc|0)>>>0)|0)|0;tc=e+796|0;rc=c[tc>>2]|0;y=cc;a[rc]=y;y=y>>8;a[rc+1|0]=y;y=y>>8;a[rc+2|0]=y;y=y>>8;a[rc+3|0]=y;c[tc>>2]=(c[tc>>2]|0)+4;uc=sc+31|0;vc=qc}c[Ob>>2]=vc;c[Pb>>2]=uc;uc=e+11556|0;cSa(e,(c[e+11744>>2]|0)-(c[k>>2]|0)|0,(c[e+11748>>2]|0)-(c[l>>2]|0)|0,c[uc>>2]|0);cSa(e,(c[e+11752>>2]|0)-(c[k>>2]|0)|0,(c[e+11756>>2]|0)-(c[l>>2]|0)|0,c[uc>>2]|0)}else{uc=x|16;x=d[1379128+uc|0]|0;vc=d[1379096+uc|0]|0;if((Qb|0)>(x|0)){wc=Qb;xc=Rb<<x|vc}else{uc=je(vc>>>((x-Qb|0)>>>0)|Rb<<Qb|0)|0;Rb=e+796|0;qc=c[Rb>>2]|0;y=uc;a[qc]=y;y=y>>8;a[qc+1|0]=y;y=y>>8;a[qc+2|0]=y;y=y>>8;a[qc+3|0]=y;c[Rb>>2]=(c[Rb>>2]|0)+4;wc=Qb+32|0;xc=vc}c[Ob>>2]=xc;c[Pb>>2]=wc-x;x=d[1379529+(t<<1)|0]|0;wc=d[1379528+(t<<1)|0]|0;t=u|0;xc=c[t>>2]|0;Ob=u+4|0;vc=c[Ob>>2]|0;if((vc|0)>(x|0)){yc=vc-x|0;zc=xc<<x|wc}else{Qb=je(wc>>>((x-vc|0)>>>0)|xc<<vc|0)|0;xc=u+12|0;Rb=c[xc>>2]|0;y=Qb;a[Rb]=y;y=y>>8;a[Rb+1|0]=y;y=y>>8;a[Rb+2|0]=y;y=y>>8;a[Rb+3|0]=y;c[xc>>2]=(c[xc>>2]|0)+4;yc=32-x+vc|0;zc=wc}c[t>>2]=zc;c[Ob>>2]=yc;if(!((c[e+14152>>2]|0)!=0|(Gb|0)==0)){Gb=c[e+14236>>2]|0;if((yc|0)>1){Ac=yc-1|0;Bc=zc<<1|Gb}else{wc=je(zc<<yc|Gb>>>((1-yc|0)>>>0)|0)|0;zc=u+12|0;u=c[zc>>2]|0;y=wc;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[zc>>2]=(c[zc>>2]|0)+4;Ac=yc+31|0;Bc=Gb}c[t>>2]=Bc;c[Ob>>2]=Ac}if(v){Ac=((c[e+796>>2]|0)-(c[e+792>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;Ob=e+13700|0;Bc=c[Ob>>2]|0;c[Ob>>2]=Ac;Ob=e+13696|0;c[Ob>>2]=(c[Ob>>2]|0)-Bc+Ac}Ac=e+9148|0;Bc=e+11556|0;Rga(e,0,0,k,l)|0;Ob=c[e+12496>>2]|0;t=c[Ac>>2]|0;cSa(e,(b[t+(Ob<<2)>>1]|0)-(c[k>>2]|0)|0,(b[t+(Ob<<2)+2>>1]|0)-(c[l>>2]|0)|0,c[Bc>>2]|0);Rga(e,1,0,k,l)|0;Ob=c[e+12500>>2]|0;t=c[Ac>>2]|0;cSa(e,(b[t+(Ob<<2)>>1]|0)-(c[k>>2]|0)|0,(b[t+(Ob<<2)+2>>1]|0)-(c[l>>2]|0)|0,c[Bc>>2]|0);Rga(e,2,0,k,l)|0;Ob=c[e+12504>>2]|0;t=c[Ac>>2]|0;cSa(e,(b[t+(Ob<<2)>>1]|0)-(c[k>>2]|0)|0,(b[t+(Ob<<2)+2>>1]|0)-(c[l>>2]|0)|0,c[Bc>>2]|0);Rga(e,3,0,k,l)|0;Ob=c[e+12508>>2]|0;t=c[Ac>>2]|0;cSa(e,(b[t+(Ob<<2)>>1]|0)-(c[k>>2]|0)|0,(b[t+(Ob<<2)+2>>1]|0)-(c[l>>2]|0)|0,c[Bc>>2]|0)}if(v){v=e+792|0;Bc=e+796|0;l=((c[Bc>>2]|0)-(c[v>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;Ob=e+13700|0;t=c[Ob>>2]|0;c[Ob>>2]=l;k=e+13664|0;c[k>>2]=(c[k>>2]|0)-t+l;dSa(e,f,0,0,0,A);l=((c[Bc>>2]|0)-(c[v>>2]|0)<<3)+(32-(c[Pb>>2]|0))|0;Pb=c[Ob>>2]|0;c[Ob>>2]=l;Ob=e+13676|0;c[Ob>>2]=(c[Ob>>2]|0)-Pb+l}else{dSa(e,f,0,0,0,A)}A=e+13684|0;c[A>>2]=(c[A>>2]|0)+1;i=j;return}function cSa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((c[a+64>>2]&4|0)==0){Aqb(a,b,f);Aqb(a,e,f);return}if((b|0)==0){g=d[1339809]|0}else{h=27-f|0;g=(d[1339809+(((b<<h>>h)-1>>f-1)+1<<1)|0]|0)+f|0}if((e|0)==0){i=d[1339809]|0}else{h=27-f|0;i=(d[1339809+(((e<<h>>h)-1>>f-1)+1<<1)|0]|0)+f|0}f=a+788|0;h=(c[f>>2]|0)-(i+g)|0;g=a+796|0;c[g>>2]=(c[g>>2]|0)+(-(h>>5<<2)|0);c[f>>2]=h&31;return}function dSa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=(c[a+64>>2]&4|0)!=0;if((e|0)==0){i=a+368|0;if(h){j=a+788|0;k=a+796|0;l=pSa(a,b|0,0,0,i)|0;m=(c[j>>2]|0)-l|0;l=m>>5<<2;n=c[k>>2]|0;c[k>>2]=n+(-l|0);o=m&31;c[j>>2]=o;p=pSa(a,b+128|0,1,0,i)|0;q=l+(o-p>>5<<2)|0;c[k>>2]=n+(-q|0);o=m-p|0;p=o&31;c[j>>2]=p;m=pSa(a,b+256|0,2,0,i)|0;l=q+(p-m>>5<<2)|0;c[k>>2]=n+(-l|0);p=o-m|0;m=p&31;c[j>>2]=m;o=pSa(a,b+384|0,3,0,i)|0;q=l+(m-o>>5<<2)|0;c[k>>2]=n+(-q|0);m=p-o|0;o=m&31;c[j>>2]=o;p=pSa(a,b+512|0,4,0,i)|0;l=q+(o-p>>5<<2)|0;c[k>>2]=n+(-l|0);o=m-p|0;p=o&31;c[j>>2]=p;m=pSa(a,b+640|0,5,0,i)|0;c[k>>2]=n+(-(l+(p-m>>5<<2)|0)|0);c[j>>2]=o-m&31;return}else{qSa(a,b|0,0,0,i,f,g);qSa(a,b+128|0,1,0,i,f,g);qSa(a,b+256|0,2,0,i,f,g);qSa(a,b+384|0,3,0,i,f,g);qSa(a,b+512|0,4,0,i,f,g);qSa(a,b+640|0,5,0,i,f,g);return}}else{if(h){h=a+788|0;i=a+796|0;m=pSa(a,b|0,0,c[d>>2]|0,c[e>>2]|0)|0;o=(c[h>>2]|0)-m|0;m=o>>5<<2;j=c[i>>2]|0;c[i>>2]=j+(-m|0);p=o&31;c[h>>2]=p;l=pSa(a,b+128|0,1,c[d+4>>2]|0,c[e+4>>2]|0)|0;n=m+(p-l>>5<<2)|0;c[i>>2]=j+(-n|0);p=o-l|0;l=p&31;c[h>>2]=l;o=pSa(a,b+256|0,2,c[d+8>>2]|0,c[e+8>>2]|0)|0;m=n+(l-o>>5<<2)|0;c[i>>2]=j+(-m|0);l=p-o|0;o=l&31;c[h>>2]=o;p=pSa(a,b+384|0,3,c[d+12>>2]|0,c[e+12>>2]|0)|0;n=m+(o-p>>5<<2)|0;c[i>>2]=j+(-n|0);o=l-p|0;p=o&31;c[h>>2]=p;l=pSa(a,b+512|0,4,c[d+16>>2]|0,c[e+16>>2]|0)|0;m=n+(p-l>>5<<2)|0;c[i>>2]=j+(-m|0);p=o-l|0;l=p&31;c[h>>2]=l;o=pSa(a,b+640|0,5,c[d+20>>2]|0,c[e+20>>2]|0)|0;c[i>>2]=j+(-(m+(l-o>>5<<2)|0)|0);c[h>>2]=p-o&31;return}else{qSa(a,b|0,0,c[d>>2]|0,c[e>>2]|0,f,g);qSa(a,b+128|0,1,c[d+4>>2]|0,c[e+4>>2]|0,f,g);qSa(a,b+256|0,2,c[d+8>>2]|0,c[e+8>>2]|0,f,g);qSa(a,b+384|0,3,c[d+12>>2]|0,c[e+12>>2]|0,f,g);qSa(a,b+512|0,4,c[d+16>>2]|0,c[e+16>>2]|0,f,g);qSa(a,b+640|0,5,c[d+20>>2]|0,c[e+20>>2]|0,f,g);return}}}function eSa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=a+180|0;j=h;c[i>>2]=c[j>>2];c[i+4>>2]=c[j+4>>2];c[i+8>>2]=c[j+8>>2];c[i+12>>2]=c[j+12>>2];c[i+16>>2]=c[j+16>>2];c[i+20>>2]=c[j+20>>2];j=a+9912|0;i=a+368|0;h=0;do{k=c[j>>2]|0;l=c[a+12496+(h<<2)>>2]<<4;c[g+(h<<2)>>2]=i;if((c[f+(h<<2)>>2]|0)==0){b[e+(h<<7)+((d[a+11192|0]|0)<<1)>>1]=b[k+((l|1)<<1)>>1]|0;b[e+(h<<7)+((d[a+11200|0]|0)<<1)>>1]=b[k+((l|2)<<1)>>1]|0;b[e+(h<<7)+((d[a+11208|0]|0)<<1)>>1]=b[k+((l|3)<<1)>>1]|0;b[e+(h<<7)+((d[a+11216|0]|0)<<1)>>1]=b[k+((l|4)<<1)>>1]|0;b[e+(h<<7)+((d[a+11224|0]|0)<<1)>>1]=b[k+((l|5)<<1)>>1]|0;b[e+(h<<7)+((d[a+11232|0]|0)<<1)>>1]=b[k+((l|6)<<1)>>1]|0;b[e+(h<<7)+((d[a+11240|0]|0)<<1)>>1]=b[k+((l|7)<<1)>>1]|0}else{b[e+(h<<7)+((d[a+11185|0]|0)<<1)>>1]=b[k+((l|9)<<1)>>1]|0;b[e+(h<<7)+((d[a+11186|0]|0)<<1)>>1]=b[k+((l|10)<<1)>>1]|0;b[e+(h<<7)+((d[a+11187|0]|0)<<1)>>1]=b[k+((l|11)<<1)>>1]|0;b[e+(h<<7)+((d[a+11188|0]|0)<<1)>>1]=b[k+((l|12)<<1)>>1]|0;b[e+(h<<7)+((d[a+11189|0]|0)<<1)>>1]=b[k+((l|13)<<1)>>1]|0;b[e+(h<<7)+((d[a+11190|0]|0)<<1)>>1]=b[k+((l|14)<<1)>>1]|0;b[e+(h<<7)+((d[a+11191|0]|0)<<1)>>1]=b[k+((l|15)<<1)>>1]|0}h=h+1|0;}while((h|0)<6);return}function fSa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b|0;e=c[d>>2]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)>1){h=g-1|0;i=e<<1}else{j=je(e<<g|0)|0;e=b+12|0;k=c[e>>2]|0;y=j;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[e>>2]=(c[e>>2]|0)+4;h=g+31|0;i=0}c[d>>2]=i;c[f>>2]=h;g=h&7;if((g|0)==0){return}e=(1<<g)-1|0;if((h|0)>(g|0)){l=h;m=i<<g|e}else{k=je(i<<h|e>>>((g-h|0)>>>0)|0)|0;i=b+12|0;b=c[i>>2]|0;y=k;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=h+32|0;m=e}c[d>>2]=m;c[f>>2]=l-g;return}function gSa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((c[a+9992>>2]|0)==3){GRa(a);return}b=a+13852|0;c[a+13848>>2]=c[b>>2];d=a+13856|0;e=c[d>>2]|0;f=c[d+4>>2]|0;d=0;g=c[(c[a+4>>2]|0)+108>>2]|0;if((f|0)>(d|0)|(f|0)==(d|0)&e>>>0>0>>>0){h=f;i=e}else{d=wrc(e,f,1,0)|0;f=xrc(d,G,g,(g|0)<0|0?-1:0)|0;h=G;i=f}f=Crc(i,h,g,(g|0)<0|0?-1:0)|0;c[b>>2]=f;return}function hSa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;e=i;f=b+9992|0;do{if((c[f>>2]|0)==1){g=b+60|0;do{if((c[g>>2]&4194304|0)==0){h=b+80|0;j=c[h>>2]|0;if((j|0)<2){iSa(b);k=c[h>>2]|0}else{k=j}if(!((k|0)<2|(d|0)==0)){break}jSa(b)}}while(0);if((c[b+84>>2]&8192|0)!=0){break}j=b+784|0;h=c[j>>2]|0;l=b+788|0;m=c[l>>2]|0;if((m|0)>16){n=m-16|0;o=h<<16}else{p=je(h<<m|0)|0;h=b+796|0;q=c[h>>2]|0;y=p;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;n=m+16|0;o=0}c[j>>2]=o;c[l>>2]=n;if((n|0)>16){r=n-16|0}else{m=je(435>>>((16-n|0)>>>0)|o<<n|0)|0;h=b+796|0;q=c[h>>2]|0;y=m;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;r=n+16|0}c[j>>2]=435;c[l>>2]=r;h=(c[b+9856>>2]|0)+136|0;q=c[h>>2]|0;m=c[h+4>>2]|0;h=c[(c[b+164>>2]|0)+4>>2]|0;if((h|0)==0){s=m;t=q}else{p=h+136|0;h=c[p>>2]|0;u=c[p+4>>2]|0;p=(m|0)>(u|0)|(m|0)==(u|0)&q>>>0>h>>>0;s=p?u:m;t=p?h:q}q=c[b+4>>2]|0;h=c[q+104>>2]|0;p=Erc(h,(h|0)<0|0?-1:0,t,s)|0;h=G;m=0;u=q+108|0;q=c[u>>2]|0;v=q;w=(q|0)<0|0?-1:0;if((h|0)>(m|0)|(h|0)==(m|0)&p>>>0>0>>>0){m=Crc(p,h,v,w)|0;c[b+13848>>2]=m;x=h;z=p;A=c[u>>2]|0}else{m=xrc(1,0,v,w)|0;q=wrc(m,G,p,h)|0;m=Crc(q,G,v,w)|0;c[b+13848>>2]=m;m=c[u>>2]|0;u=wrc(p,h,1,0)|0;h=xrc(u,G,m,(m|0)<0|0?-1:0)|0;x=G;z=h;A=m}m=Crc(z,x,A,(A|0)<0|0?-1:0)|0;h=m;m=(h|0)>0?h:h-59|0;u=(m|0)/60|0;p=((m|0)%60|0)-m+h|0;h=(m|0)>59?u:u-59|0;m=(h|0)/60|0;w=((h|0)%60|0)-h+u|0;u=(h|0)>59?m:m-23|0;h=((u|0)%24|0)-u+m|0;if((r|0)>5){B=r-5|0;C=h|13920}else{m=je(h>>>((5-r|0)>>>0)|435<<r|0)|0;u=b+796|0;v=c[u>>2]|0;y=m;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;B=r+27|0;C=h}c[j>>2]=C;c[l>>2]=B;if((B|0)>6){D=B-6|0;E=C<<6|w}else{h=je(w>>>((6-B|0)>>>0)|C<<B|0)|0;u=b+796|0;v=c[u>>2]|0;y=h;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;D=B+26|0;E=w}c[j>>2]=E;c[l>>2]=D;if((D|0)>1){F=D-1|0;H=E<<1|1}else{w=je(1>>>((1-D|0)>>>0)|E<<D|0)|0;u=b+796|0;v=c[u>>2]|0;y=w;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;F=D+31|0;H=1}c[j>>2]=H;c[l>>2]=F;if((F|0)>6){I=F-6|0;J=H<<6|p}else{u=je(p>>>((6-F|0)>>>0)|H<<F|0)|0;v=b+796|0;w=c[v>>2]|0;y=u;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;I=F+26|0;J=p}c[j>>2]=J;c[l>>2]=I;p=(c[g>>2]|0)>>>31;if((I|0)>1){K=I-1|0;L=p|J<<1}else{v=je(p>>>((1-I|0)>>>0)|J<<I|0)|0;w=b+796|0;u=c[w>>2]|0;y=v;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;K=I+31|0;L=p}c[j>>2]=L;c[l>>2]=K;if((K|0)>1){M=K-1|0;N=L<<1}else{p=je(L<<K|0)|0;w=b+796|0;u=c[w>>2]|0;y=p;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;M=K+31|0;N=0}c[j>>2]=N;c[l>>2]=M;if((M|0)>1){O=M-1|0;P=N<<1}else{w=je(N<<M|0)|0;u=b+796|0;p=c[u>>2]|0;y=w;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;O=M+31|0;P=0}c[j>>2]=P;c[l>>2]=O;u=O&7;if((u|0)==0){break}p=(1<<u)-1|0;if((O|0)>(u|0)){Q=O;R=p|P<<u}else{w=je(p>>>((u-O|0)>>>0)|P<<O|0)|0;v=b+796|0;h=c[v>>2]|0;y=w;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;Q=O+32|0;R=p}c[j>>2]=R;c[l>>2]=Q-u}}while(0);if((c[b+13936>>2]|0)==0){S=0}else{S=(c[f>>2]|0)!=3|0}c[b+13940>>2]=S;S=b+784|0;Q=c[S>>2]|0;R=b+788|0;O=c[R>>2]|0;if((O|0)>16){T=O-16|0;U=Q<<16}else{P=je(Q<<O|0)|0;Q=b+796|0;M=c[Q>>2]|0;y=P;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;T=O+16|0;U=0}c[S>>2]=U;c[R>>2]=T;if((T|0)>16){V=T-16|0}else{O=je(438>>>((16-T|0)>>>0)|U<<T|0)|0;U=b+796|0;Q=c[U>>2]|0;y=O;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[U>>2]=(c[U>>2]|0)+4;V=T+16|0}c[S>>2]=438;c[R>>2]=V;T=(c[f>>2]|0)-1|0;if((V|0)>2){W=V-2|0;X=T|1752}else{U=je(T>>>((2-V|0)>>>0)|438<<V|0)|0;Q=b+796|0;O=c[Q>>2]|0;y=U;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;W=V+30|0;X=T}c[S>>2]=X;c[R>>2]=W;T=b+13856|0;V=c[T>>2]|0;Q=c[T+4>>2]|0;T=0;O=c[(c[b+4>>2]|0)+108>>2]|0;U=O;M=(O|0)<0|0?-1:0;if((Q|0)>(T|0)|(Q|0)==(T|0)&V>>>0>0>>>0){T=Crc(V,Q,U,M)|0;Y=Q;Z=V;_=M;$=U;aa=T}else{T=wrc(V,Q,1,0)|0;P=xrc(T,G,U,M)|0;M=O;U=(O|0)<0|0?-1:0;O=Crc(P,G,M,U)|0;P=xrc(1,0,M,U)|0;T=wrc(P,G,V,Q)|0;Y=G;Z=T;_=U;$=M;aa=O}O=Drc(Z,Y,$,_)|0;_=xrc(O,G,Z,Y)|0;Y=wrc(V,Q,_,G)|0;_=Y;Y=c[b+13848>>2]|0;Q=aa-Y|0;if(!((Q|0)>-1)){KIb(0,0,2506392,(V=i,i=i+24|0,c[V>>2]=2600512,c[V+8>>2]=2449896,c[V+16>>2]=1113,V)|0);i=V;Hd()}if((aa|0)==(Y|0)){ba=X;ca=W}else{Y=b+796|0;aa=Q;Q=X;X=W;while(1){W=aa-1|0;if((X|0)>1){da=X-1|0;ea=Q<<1|1}else{V=je(1>>>((1-X|0)>>>0)|Q<<X|0)|0;Z=c[Y>>2]|0;y=V;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;c[Y>>2]=(c[Y>>2]|0)+4;da=X+31|0;ea=1}c[S>>2]=ea;c[R>>2]=da;if((W|0)==0){ba=ea;ca=da;break}else{aa=W;Q=ea;X=da}}}if((ca|0)>1){fa=ca-1|0;ga=ba<<1}else{da=je(ba<<ca|0)|0;ba=b+796|0;X=c[ba>>2]|0;y=da;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;c[ba>>2]=(c[ba>>2]|0)+4;fa=ca+31|0;ga=0}c[S>>2]=ga;c[R>>2]=fa;if((fa|0)>1){ha=fa-1|0;ia=ga<<1|1}else{ca=je(1>>>((1-fa|0)>>>0)|ga<<fa|0)|0;ga=b+796|0;ba=c[ga>>2]|0;y=ca;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;c[ga>>2]=(c[ga>>2]|0)+4;ha=fa+31|0;ia=1}c[S>>2]=ia;c[R>>2]=ha;fa=c[b+13844>>2]|0;if((ha|0)>(fa|0)){ja=ha;ka=ia<<fa|_}else{ga=je(_>>>((fa-ha|0)>>>0)|ia<<ha|0)|0;ia=b+796|0;ba=c[ia>>2]|0;y=ga;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;c[ia>>2]=(c[ia>>2]|0)+4;ja=ha+32|0;ka=_}_=ja-fa|0;c[S>>2]=ka;c[R>>2]=_;if((_|0)>1){la=_-1|0;ma=ka<<1|1}else{fa=je(1>>>((1-_|0)>>>0)|ka<<_|0)|0;ka=b+796|0;ja=c[ka>>2]|0;y=fa;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;c[ka>>2]=(c[ka>>2]|0)+4;la=_+31|0;ma=1}c[S>>2]=ma;c[R>>2]=la;if((la|0)>1){na=la-1|0;oa=ma<<1|1}else{_=je(1>>>((1-la|0)>>>0)|ma<<la|0)|0;ma=b+796|0;ka=c[ma>>2]|0;y=_;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;c[ma>>2]=(c[ma>>2]|0)+4;na=la+31|0;oa=1}c[S>>2]=oa;c[R>>2]=na;if((c[f>>2]|0)==2){la=c[b+12472>>2]|0;if((na|0)>1){pa=na-1|0;qa=oa<<1|la}else{ma=je(oa<<na|la>>>((1-na|0)>>>0)|0)|0;ka=b+796|0;_=c[ka>>2]|0;y=ma;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;c[ka>>2]=(c[ka>>2]|0)+4;pa=na+31|0;qa=la}c[S>>2]=qa;c[R>>2]=pa;ra=pa;sa=qa}else{ra=na;sa=oa}if((ra|0)>3){ta=ra-3|0;ua=sa<<3}else{oa=je(sa<<ra|0)|0;sa=b+796|0;na=c[sa>>2]|0;y=oa;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[sa>>2]=(c[sa>>2]|0)+4;ta=ra+29|0;ua=0}c[S>>2]=ua;c[R>>2]=ta;if((c[b+14152>>2]|0)==0){ra=c[(c[b+9856>>2]|0)+300>>2]|0;if((ta|0)>1){va=ta-1|0;wa=ua<<1|ra}else{sa=je(ua<<ta|ra>>>((1-ta|0)>>>0)|0)|0;na=b+796|0;oa=c[na>>2]|0;y=sa;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;c[na>>2]=(c[na>>2]|0)+4;va=ta+31|0;wa=ra}c[S>>2]=wa;c[R>>2]=va;ra=c[b+14200>>2]|0;if((va|0)>1){xa=va-1|0;ya=wa<<1|ra}else{na=je(wa<<va|ra>>>((1-va|0)>>>0)|0)|0;wa=b+796|0;oa=c[wa>>2]|0;y=na;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;c[wa>>2]=(c[wa>>2]|0)+4;xa=va+31|0;ya=ra}c[S>>2]=ya;c[R>>2]=xa;za=xa;Aa=ya}else{za=ta;Aa=ua}ua=c[b+9960>>2]|0;if((za|0)>5){Ba=za-5|0;Ca=Aa<<5|ua}else{ta=je(Aa<<za|ua>>>((5-za|0)>>>0)|0)|0;Aa=b+796|0;ya=c[Aa>>2]|0;y=ta;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;Ba=za+27|0;Ca=ua}c[S>>2]=Ca;c[R>>2]=Ba;ua=c[f>>2]|0;if((ua|0)==1){i=e;return}za=c[b+11556>>2]|0;if((Ba|0)>3){Da=Ba-3|0;Ea=Ca<<3|za;Fa=ua}else{ua=je(Ca<<Ba|za>>>((3-Ba|0)>>>0)|0)|0;Ca=b+796|0;Aa=c[Ca>>2]|0;y=ua;a[Aa]=y;y=y>>8;a[Aa+1|0]=y;y=y>>8;a[Aa+2|0]=y;y=y>>8;a[Aa+3|0]=y;c[Ca>>2]=(c[Ca>>2]|0)+4;Da=Ba+29|0;Ea=za;Fa=c[f>>2]|0}c[S>>2]=Ea;c[R>>2]=Da;if((Fa|0)!=3){i=e;return}Fa=c[b+11560>>2]|0;if((Da|0)>3){Ga=Da-3|0;Ha=Ea<<3|Fa}else{f=je(Fa>>>((3-Da|0)>>>0)|Ea<<Da|0)|0;Ea=b+796|0;b=c[Ea>>2]|0;y=f;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[Ea>>2]=(c[Ea>>2]|0)+4;Ga=Da+29|0;Ha=Fa}c[S>>2]=Ha;c[R>>2]=Ga;i=e;return}function iSa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=c[b+4>>2]|0;e=c[d+840>>2]|0;do{if((e|0)==-99){if((c[b+68>>2]|0)!=0){f=240;break}f=(c[b+13924>>2]|0)==0?0:240}else{f=e<<4}}while(0);e=c[d+844>>2]|0;d=((e|0)==-99?1:e)|f;f=(d&-16|0)==240?5:1;e=b+784|0;g=c[e>>2]|0;h=b+788|0;i=c[h>>2]|0;if((i|0)>16){j=i-16|0;k=g<<16}else{l=je(g<<i|0)|0;g=b+796|0;m=c[g>>2]|0;y=l;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;j=i+16|0;k=0}c[e>>2]=k;c[h>>2]=j;if((j|0)>16){n=j-16|0}else{i=je(432>>>((16-j|0)>>>0)|k<<j|0)|0;k=b+796|0;g=c[k>>2]|0;y=i;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;n=j+16|0}c[e>>2]=432;c[h>>2]=n;if((n|0)>8){o=n-8|0;p=d|110592}else{j=je(d>>>((8-n|0)>>>0)|432<<n|0)|0;k=b+796|0;g=c[k>>2]|0;y=j;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;o=n+24|0;p=d}c[e>>2]=p;c[h>>2]=o;if((o|0)>16){q=o-16|0;r=p<<16}else{d=je(p<<o|0)|0;p=b+796|0;n=c[p>>2]|0;y=d;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;q=o+16|0;r=0}c[e>>2]=r;c[h>>2]=q;if((q|0)>16){s=q-16|0}else{o=je(437>>>((16-q|0)>>>0)|r<<q|0)|0;r=b+796|0;p=c[r>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;s=q+16|0}c[e>>2]=437;c[h>>2]=s;if((s|0)>1){t=s-1|0;u=875}else{q=je(1>>>((1-s|0)>>>0)|437<<s|0)|0;r=b+796|0;p=c[r>>2]|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;t=s+31|0;u=1}c[e>>2]=u;c[h>>2]=t;if((t|0)>4){v=t-4|0;w=u<<4|f}else{s=je(f>>>((4-t|0)>>>0)|u<<t|0)|0;u=b+796|0;r=c[u>>2]|0;y=s;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+28|0;w=f}c[e>>2]=w;c[h>>2]=v;if((v|0)>3){x=v-3|0;z=w<<3|1}else{f=je(1>>>((3-v|0)>>>0)|w<<v|0)|0;w=b+796|0;t=c[w>>2]|0;y=f;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;x=v+29|0;z=1}c[e>>2]=z;c[h>>2]=x;if((x|0)>4){A=x-4|0;B=z<<4|1}else{v=je(1>>>((4-x|0)>>>0)|z<<x|0)|0;z=b+796|0;w=c[z>>2]|0;y=v;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;A=x+28|0;B=1}c[e>>2]=B;c[h>>2]=A;if((A|0)>1){C=A-1|0;D=B<<1}else{x=je(B<<A|0)|0;B=b+796|0;z=c[B>>2]|0;y=x;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;C=A+31|0;D=0}c[e>>2]=D;c[h>>2]=C;if((C|0)>1){E=C-1|0;F=D<<1}else{A=je(D<<C|0)|0;D=b+796|0;B=c[D>>2]|0;y=A;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;E=C+31|0;F=0}c[e>>2]=F;c[h>>2]=E;C=E&7;if((C|0)==0){return}D=(1<<C)-1|0;if((E|0)>(C|0)){G=E;H=D|F<<C}else{B=je(D>>>((C-E|0)>>>0)|F<<E|0)|0;F=b+796|0;b=c[F>>2]|0;y=B;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[F>>2]=(c[F>>2]|0)+4;G=E+32|0;H=D}c[e>>2]=H;c[h>>2]=G-C;return}function jSa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;do{if((c[b+68>>2]|0)==0){if((c[b+13924>>2]|0)!=0){d=3;break}c[b+13948>>2]=1;e=1}else{d=3}}while(0);if((d|0)==3){c[b+13948>>2]=17;e=5}d=b+784|0;f=d|0;g=c[f>>2]|0;h=b+788|0;i=c[h>>2]|0;if((i|0)>16){j=i-16|0;k=g<<16}else{l=je(g<<i|0)|0;g=b+796|0;m=c[g>>2]|0;y=l;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;j=i+16|0;k=0}c[f>>2]=k;c[h>>2]=j;if((j|0)>16){n=j-16|0}else{i=je(256>>>((16-j|0)>>>0)|k<<j|0)|0;k=b+796|0;g=c[k>>2]|0;y=i;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;n=j+16|0}c[f>>2]=256;c[h>>2]=n;if((n|0)>16){o=n-16|0;p=16777216}else{j=je(256<<n|0)|0;k=b+796|0;g=c[k>>2]|0;y=j;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;o=n+16|0;p=0}c[f>>2]=p;c[h>>2]=o;if((o|0)>16){q=o-16|0}else{n=je(288>>>((16-o|0)>>>0)|p<<o|0)|0;p=b+796|0;k=c[p>>2]|0;y=n;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;q=o+16|0}c[f>>2]=288;c[h>>2]=q;if((q|0)>1){r=q-1|0;s=576}else{o=je(288<<q|0)|0;p=b+796|0;k=c[p>>2]|0;y=o;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;r=q+31|0;s=0}c[f>>2]=s;c[h>>2]=r;q=c[b+13948>>2]|0;if((r|0)>8){t=r-8|0;u=s<<8|q}else{p=je(s<<r|q>>>((8-r|0)>>>0)|0)|0;s=b+796|0;k=c[s>>2]|0;y=p;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;t=r+24|0;u=q}c[f>>2]=u;c[h>>2]=t;q=b+84|0;r=(t|0)>1;do{if((c[q>>2]&8192|0)==0){if(r){v=t-1|0;w=u<<1|1}else{s=je(u<<t|1>>>((1-t|0)>>>0)|0)|0;k=b+796|0;p=c[k>>2]|0;y=s;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;v=t+31|0;w=1}c[f>>2]=w;c[h>>2]=v;if((v|0)>4){x=v-4|0;z=w<<4|e}else{k=je(e>>>((4-v|0)>>>0)|w<<v|0)|0;p=b+796|0;s=c[p>>2]|0;y=k;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;x=v+28|0;z=e}c[f>>2]=z;c[h>>2]=x;if((x|0)>3){A=x-3|0;B=z<<3|1;break}else{p=je(1>>>((3-x|0)>>>0)|z<<x|0)|0;s=b+796|0;k=c[s>>2]|0;y=p;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;A=x+29|0;B=1;break}}else{if(r){A=t-1|0;B=u<<1;break}else{s=je(u<<t|0)|0;k=b+796|0;p=c[k>>2]|0;y=s;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;A=t+31|0;B=0;break}}}while(0);c[f>>2]=B;c[h>>2]=A;A=b+4|0;B=tqb((c[A>>2]|0)+224|0)|0;t=b+13928|0;c[t>>2]=B;u=c[f>>2]|0;r=c[h>>2]|0;if((r|0)>4){C=r-4|0;D=u<<4|B;E=B}else{x=je(B>>>((4-r|0)>>>0)|u<<r|0)|0;u=b+796|0;z=c[u>>2]|0;y=x;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;C=r+28|0;D=B;E=c[t>>2]|0}c[f>>2]=D;c[h>>2]=C;if((E|0)==15){E=c[A>>2]|0;t=E+224|0;B=E+228|0;E=c[t>>2]|0;r=c[B>>2]|0;xKb(t,B,E,(E|0)<0|0?-1:0,r,(r|0)<0|0?-1:0,255,0)|0;r=c[A>>2]|0;E=c[r+224>>2]|0;B=c[f>>2]|0;t=c[h>>2]|0;if((t|0)>8){F=t-8|0;G=B<<8|E;H=r}else{r=je(E>>>((8-t|0)>>>0)|B<<t|0)|0;B=b+796|0;u=c[B>>2]|0;y=r;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;F=t+24|0;G=E;H=c[A>>2]|0}c[f>>2]=G;c[h>>2]=F;E=c[H+228>>2]|0;if((F|0)>8){I=F-8|0;J=G<<8|E}else{H=je(G<<F|E>>>((8-F|0)>>>0)|0)|0;G=b+796|0;t=c[G>>2]|0;y=H;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;I=F+24|0;J=E}c[f>>2]=J;c[h>>2]=I;K=J;L=I}else{K=D;L=C}C=(L|0)>1;do{if((c[q>>2]&8192|0)==0){if(C){M=L-1|0;N=K<<1|1}else{D=je(1>>>((1-L|0)>>>0)|K<<L|0)|0;I=b+796|0;J=c[I>>2]|0;y=D;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;M=L+31|0;N=1}c[f>>2]=N;c[h>>2]=M;if((M|0)>2){O=M-2|0;P=N<<2|1}else{I=je(1>>>((2-M|0)>>>0)|N<<M|0)|0;J=b+796|0;D=c[J>>2]|0;y=I;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[J>>2]=(c[J>>2]|0)+4;O=M+30|0;P=1}c[f>>2]=P;c[h>>2]=O;J=c[b+13944>>2]|0;if((O|0)>1){Q=O-1|0;R=P<<1|J}else{D=je(P<<O|J>>>((1-O|0)>>>0)|0)|0;I=b+796|0;E=c[I>>2]|0;y=D;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;Q=O+31|0;R=J}c[f>>2]=R;c[h>>2]=Q;if((Q|0)>1){S=Q-1|0;T=R<<1;break}else{J=je(R<<Q|0)|0;I=b+796|0;E=c[I>>2]|0;y=J;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;S=Q+31|0;T=0;break}}else{if(C){S=L-1|0;T=K<<1;break}else{I=je(K<<L|0)|0;E=b+796|0;J=c[E>>2]|0;y=I;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;S=L+31|0;T=0;break}}}while(0);c[f>>2]=T;c[h>>2]=S;if((S|0)>2){U=S-2|0;V=T<<2}else{L=je(T<<S|0)|0;T=b+796|0;K=c[T>>2]|0;y=L;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[T>>2]=(c[T>>2]|0)+4;U=S+30|0;V=0}c[f>>2]=V;c[h>>2]=U;if((U|0)>1){W=U-1|0;X=V<<1|1}else{S=je(1>>>((1-U|0)>>>0)|V<<U|0)|0;V=b+796|0;T=c[V>>2]|0;y=S;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[V>>2]=(c[V>>2]|0)+4;W=U+31|0;X=1}c[f>>2]=X;c[h>>2]=W;U=c[(c[A>>2]|0)+108>>2]|0;if((W|0)>16){Y=W-16|0;Z=X<<16|U}else{V=je(X<<W|U>>>((16-W|0)>>>0)|0)|0;X=b+796|0;T=c[X>>2]|0;y=V;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[X>>2]=(c[X>>2]|0)+4;Y=W+16|0;Z=U}c[f>>2]=Z;c[h>>2]=Y;U=b+13844|0;if((c[U>>2]|0)<1){c[U>>2]=1}if((Y|0)>1){_=Y-1|0;$=Z<<1|1}else{U=je(1>>>((1-Y|0)>>>0)|Z<<Y|0)|0;Z=b+796|0;W=c[Z>>2]|0;y=U;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;c[Z>>2]=(c[Z>>2]|0)+4;_=Y+31|0;$=1}c[f>>2]=$;c[h>>2]=_;if((_|0)>1){aa=_-1|0;ba=$<<1}else{Y=je($<<_|0)|0;$=b+796|0;Z=c[$>>2]|0;y=Y;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;aa=_+31|0;ba=0}c[f>>2]=ba;c[h>>2]=aa;if((aa|0)>1){ca=aa-1|0;da=ba<<1|1}else{_=je(1>>>((1-aa|0)>>>0)|ba<<aa|0)|0;ba=b+796|0;$=c[ba>>2]|0;y=_;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;c[ba>>2]=(c[ba>>2]|0)+4;ca=aa+31|0;da=1}c[f>>2]=da;c[h>>2]=ca;aa=c[b+8>>2]|0;if((ca|0)>13){ea=ca-13|0;fa=da<<13|aa}else{ba=je(da<<ca|aa>>>((13-ca|0)>>>0)|0)|0;da=b+796|0;$=c[da>>2]|0;y=ba;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;c[da>>2]=(c[da>>2]|0)+4;ea=ca+19|0;fa=aa}c[f>>2]=fa;c[h>>2]=ea;if((ea|0)>1){ga=ea-1|0;ha=fa<<1|1}else{aa=je(1>>>((1-ea|0)>>>0)|fa<<ea|0)|0;fa=b+796|0;ca=c[fa>>2]|0;y=aa;a[ca]=y;y=y>>8;a[ca+1|0]=y;y=y>>8;a[ca+2|0]=y;y=y>>8;a[ca+3|0]=y;c[fa>>2]=(c[fa>>2]|0)+4;ga=ea+31|0;ha=1}c[f>>2]=ha;c[h>>2]=ga;ea=c[b+12>>2]|0;if((ga|0)>13){ia=ga-13|0;ja=ha<<13|ea}else{fa=je(ha<<ga|ea>>>((13-ga|0)>>>0)|0)|0;ha=b+796|0;ca=c[ha>>2]|0;y=fa;a[ca]=y;y=y>>8;a[ca+1|0]=y;y=y>>8;a[ca+2|0]=y;y=y>>8;a[ca+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;ia=ga+19|0;ja=ea}c[f>>2]=ja;c[h>>2]=ia;if((ia|0)>1){ka=ia-1|0;la=ja<<1|1}else{ea=je(1>>>((1-ia|0)>>>0)|ja<<ia|0)|0;ja=b+796|0;ga=c[ja>>2]|0;y=ea;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[ja>>2]=(c[ja>>2]|0)+4;ka=ia+31|0;la=1}c[f>>2]=la;c[h>>2]=ka;ia=(c[b+14152>>2]|0)==0|0;if((ka|0)>1){ma=ka-1|0;na=la<<1|ia}else{ja=je(ia>>>((1-ka|0)>>>0)|la<<ka|0)|0;la=b+796|0;ga=c[la>>2]|0;y=ja;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[la>>2]=(c[la>>2]|0)+4;ma=ka+31|0;na=ia}c[f>>2]=na;c[h>>2]=ma;if((ma|0)>1){oa=ma-1|0;pa=na<<1|1}else{ia=je(1>>>((1-ma|0)>>>0)|na<<ma|0)|0;na=b+796|0;ka=c[na>>2]|0;y=ia;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;c[na>>2]=(c[na>>2]|0)+4;oa=ma+31|0;pa=1}c[f>>2]=pa;c[h>>2]=oa;do{if((e|0)==1){if((oa|0)>1){qa=oa-1|0;ra=pa<<1;break}else{ma=je(pa<<oa|0)|0;na=b+796|0;ka=c[na>>2]|0;y=ma;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;c[na>>2]=(c[na>>2]|0)+4;qa=oa+31|0;ra=0;break}}else{if((oa|0)>2){qa=oa-2|0;ra=pa<<2;break}else{na=je(pa<<oa|0)|0;ka=b+796|0;ma=c[ka>>2]|0;y=na;a[ma]=y;y=y>>8;a[ma+1|0]=y;y=y>>8;a[ma+2|0]=y;y=y>>8;a[ma+3|0]=y;c[ka>>2]=(c[ka>>2]|0)+4;qa=oa+30|0;ra=0;break}}}while(0);c[f>>2]=ra;c[h>>2]=qa;if((qa|0)>1){sa=qa-1|0;ta=ra<<1}else{oa=je(ra<<qa|0)|0;ra=b+796|0;pa=c[ra>>2]|0;y=oa;a[pa]=y;y=y>>8;a[pa+1|0]=y;y=y>>8;a[pa+2|0]=y;y=y>>8;a[pa+3|0]=y;c[ra>>2]=(c[ra>>2]|0)+4;sa=qa+31|0;ta=0}c[f>>2]=ta;c[h>>2]=sa;qa=b+14004|0;ra=c[qa>>2]|0;if((sa|0)>1){ua=sa-1|0;va=ta<<1|ra;wa=ra}else{pa=je(ta<<sa|ra>>>((1-sa|0)>>>0)|0)|0;ta=b+796|0;oa=c[ta>>2]|0;y=pa;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;c[ta>>2]=(c[ta>>2]|0)+4;ua=sa+31|0;va=ra;wa=c[qa>>2]|0}c[f>>2]=va;c[h>>2]=ua;if((wa|0)!=0){XTa(d,c[(c[A>>2]|0)+300>>2]|0);XTa(d,c[(c[A>>2]|0)+304>>2]|0)}A=(e|0)!=1;if(A){e=c[b+13924>>2]|0;wa=c[f>>2]|0;ua=c[h>>2]|0;if((ua|0)>1){xa=ua-1|0;ya=wa<<1|e}else{va=je(e>>>((1-ua|0)>>>0)|wa<<ua|0)|0;wa=b+796|0;qa=c[wa>>2]|0;y=va;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;c[wa>>2]=(c[wa>>2]|0)+4;xa=ua+31|0;ya=e}c[f>>2]=ya;c[h>>2]=xa;za=xa;Aa=ya}else{za=c[h>>2]|0;Aa=c[f>>2]|0}if((za|0)>1){Ba=za-1|0;Ca=Aa<<1|1}else{ya=je(1>>>((1-za|0)>>>0)|Aa<<za|0)|0;Aa=b+796|0;xa=c[Aa>>2]|0;y=ya;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[Aa>>2]=(c[Aa>>2]|0)+4;Ba=za+31|0;Ca=1}c[f>>2]=Ca;c[h>>2]=Ba;za=(c[b+14252>>2]|0)==0|0;if((Ba|0)>1){Da=Ba-1|0;Ea=Ca<<1|za}else{Aa=je(za>>>((1-Ba|0)>>>0)|Ca<<Ba|0)|0;Ca=b+796|0;xa=c[Ca>>2]|0;y=Aa;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[Ca>>2]=(c[Ca>>2]|0)+4;Da=Ba+31|0;Ea=za}c[f>>2]=Ea;c[h>>2]=Da;za=b+13936|0;Ba=c[za>>2]|0;Ca=(Ba|0)!=0|0;if((Da|0)>1){Fa=Da-1|0;Ga=Ea<<1|Ca;Ha=Ba}else{Ba=je(Ca>>>((1-Da|0)>>>0)|Ea<<Da|0)|0;Ea=b+796|0;xa=c[Ea>>2]|0;y=Ba;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[Ea>>2]=(c[Ea>>2]|0)+4;Fa=Da+31|0;Ga=Ca;Ha=c[za>>2]|0}c[f>>2]=Ga;c[h>>2]=Fa;if((Ha|0)==0){Ia=Ga;Ja=Fa}else{if((Fa|0)>1){Ka=Fa-1|0;La=Ga<<1}else{Ha=je(Ga<<Fa|0)|0;Ga=b+796|0;za=c[Ga>>2]|0;y=Ha;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;c[Ga>>2]=(c[Ga>>2]|0)+4;Ka=Fa+31|0;La=0}c[f>>2]=La;c[h>>2]=Ka;Ia=La;Ja=Ka}if(A){if((Ja|0)>1){Ma=Ja-1|0;Na=Ia<<1}else{A=je(Ia<<Ja|0)|0;Ka=b+796|0;La=c[Ka>>2]|0;y=A;a[La]=y;y=y>>8;a[La+1|0]=y;y=y>>8;a[La+2|0]=y;y=y>>8;a[La+3|0]=y;c[Ka>>2]=(c[Ka>>2]|0)+4;Ma=Ja+31|0;Na=0}c[f>>2]=Na;c[h>>2]=Ma;if((Ma|0)>1){Oa=Ma-1|0;Pa=Na<<1}else{Ka=je(Na<<Ma|0)|0;Na=b+796|0;La=c[Na>>2]|0;y=Ka;a[La]=y;y=y>>8;a[La+1|0]=y;y=y>>8;a[La+2|0]=y;y=y>>8;a[La+3|0]=y;c[Na>>2]=(c[Na>>2]|0)+4;Oa=Ma+31|0;Pa=0}c[f>>2]=Pa;c[h>>2]=Oa;Qa=Oa;Ra=Pa}else{Qa=Ja;Ra=Ia}if((Qa|0)>1){Sa=Qa-1|0;Ta=Ra<<1}else{Ia=je(Ra<<Qa|0)|0;Ra=b+796|0;Ja=c[Ra>>2]|0;y=Ia;a[Ja]=y;y=y>>8;a[Ja+1|0]=y;y=y>>8;a[Ja+2|0]=y;y=y>>8;a[Ja+3|0]=y;c[Ra>>2]=(c[Ra>>2]|0)+4;Sa=Qa+31|0;Ta=0}c[f>>2]=Ta;c[h>>2]=Sa;if((Sa|0)>1){Ua=Sa-1|0;Va=Ta<<1}else{Qa=je(Ta<<Sa|0)|0;Ta=b+796|0;Ra=c[Ta>>2]|0;y=Qa;a[Ra]=y;y=y>>8;a[Ra+1|0]=y;y=y>>8;a[Ra+2|0]=y;y=y>>8;a[Ra+3|0]=y;c[Ta>>2]=(c[Ta>>2]|0)+4;Ua=Sa+31|0;Va=0}c[f>>2]=Va;c[h>>2]=Ua;Sa=Ua&7;if((Sa|0)==0){Wa=Va;Xa=Ua}else{Ta=(1<<Sa)-1|0;if((Ua|0)>(Sa|0)){Ya=Ua;Za=Ta|Va<<Sa}else{Ra=je(Ta>>>((Sa-Ua|0)>>>0)|Va<<Ua|0)|0;Va=b+796|0;Qa=c[Va>>2]|0;y=Ra;a[Qa]=y;y=y>>8;a[Qa+1|0]=y;y=y>>8;a[Qa+2|0]=y;y=y>>8;a[Qa+3|0]=y;c[Va>>2]=(c[Va>>2]|0)+4;Ya=Ua+32|0;Za=Ta}Ta=Ya-Sa|0;c[f>>2]=Za;c[h>>2]=Ta;Wa=Za;Xa=Ta}if((c[b+60>>2]&8388608|0)!=0){return}if((Xa|0)>16){_a=Xa-16|0;$a=Wa<<16}else{Ta=je(Wa<<Xa|0)|0;Wa=b+796|0;Za=c[Wa>>2]|0;y=Ta;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;c[Wa>>2]=(c[Wa>>2]|0)+4;_a=Xa+16|0;$a=0}c[f>>2]=$a;c[h>>2]=_a;if((_a|0)>16){ab=_a-16|0}else{Xa=je(434>>>((16-_a|0)>>>0)|$a<<_a|0)|0;$a=b+796|0;b=c[$a>>2]|0;y=Xa;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[$a>>2]=(c[$a>>2]|0)+4;ab=_a+16|0}c[f>>2]=434;c[h>>2]=ab;Z2(d,2389096,0);return}function kSa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+796>>2]|0;d=a+800|0;e=b;f=(c[d>>2]|0)-e|0;g=(((f|0)/3|0)+e&-4)-e|0;e=f-(g<<1)&-4;c[d>>2]=(c[a+792>>2]|0)+g;d=(e|0)<0;f=d?0:b+g|0;h=d?0:e;c[a+13976>>2]=h<<3;c[a+13964>>2]=f;c[a+13972>>2]=f+h;c[a+13968>>2]=f;c[a+13960>>2]=32;c[a+13956>>2]=0;f=(g|0)<0;h=f?0:b+(e+g)|0;e=f?0:g;c[a+14e3>>2]=e<<3;c[a+13988>>2]=h;c[a+13996>>2]=h+e;c[a+13992>>2]=h;c[a+13984>>2]=32;c[a+13980>>2]=0;return}function lSa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;d=b+13984|0;e=b+13988|0;f=b+13992|0;g=((c[f>>2]|0)-(c[e>>2]|0)<<3)+(32-(c[d>>2]|0))|0;h=b+13960|0;i=b+13964|0;j=b+13968|0;k=((c[j>>2]|0)-(c[i>>2]|0)<<3)+(32-(c[h>>2]|0))|0;l=b+784|0;m=b+788|0;n=c[m>>2]|0;o=b+792|0;p=b+796|0;q=c[p>>2]|0;r=(q-(c[o>>2]|0)<<3)+(32-n)|0;s=l|0;t=c[s>>2]|0;if((c[b+9992>>2]|0)==1){if((n|0)>19){u=n-19|0;v=t<<19|438273}else{w=q;y=je(438273>>>((19-n|0)>>>0)|t<<n|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;u=n+13|0;v=438273}c[s>>2]=v;c[m>>2]=u;u=b+13696|0;c[u>>2]=g+19+r-(c[b+13700>>2]|0)+(c[u>>2]|0);u=b+13672|0;c[u>>2]=(c[u>>2]|0)+k}else{if((n|0)>17){x=n-17|0;z=t<<17|126977}else{u=q;y=je(126977>>>((17-n|0)>>>0)|t<<n|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;x=n+15|0;z=126977}c[s>>2]=z;c[m>>2]=x;x=b+13696|0;c[x>>2]=g+17+(c[x>>2]|0);x=b+13664|0;c[x>>2]=r-(c[b+13700>>2]|0)+(c[x>>2]|0);x=b+13676|0;c[x>>2]=(c[x>>2]|0)+k}x=c[d>>2]|0;r=b+13980|0;a:do{if((x|0)<32){z=c[r>>2]<<x;c[r>>2]=z;s=z>>>24&255;while(1){z=c[f>>2]|0;c[f>>2]=z+1;a[z]=s;z=c[r>>2]|0;c[r>>2]=z<<8;n=(c[d>>2]|0)+8|0;c[d>>2]=n;if((n|0)>=32){break a}s=z>>>16&255}}}while(0);c[d>>2]=32;c[r>>2]=0;r=c[h>>2]|0;d=b+13956|0;if((r|0)>=32){c[h>>2]=32;c[d>>2]=0;A=b+13996|0;B=c[A>>2]|0;C=c[o>>2]|0;D=B;E=C;F=D-E|0;G=C+F|0;H=b+800|0;c[H>>2]=G;I=c[e>>2]|0;_2(l,I,g);J=c[i>>2]|0;_2(l,J,k);K=c[m>>2]|0;L=c[o>>2]|0;M=c[p>>2]|0;N=M;O=L;P=N-O|0;Q=P<<3;R=32-K|0;S=R+Q|0;T=b+13700|0;c[T>>2]=S;return}f=c[d>>2]<<r;c[d>>2]=f;r=f>>>24&255;while(1){f=c[j>>2]|0;c[j>>2]=f+1;a[f]=r;f=c[d>>2]|0;c[d>>2]=f<<8;x=(c[h>>2]|0)+8|0;c[h>>2]=x;if((x|0)>=32){break}r=f>>>16&255}c[h>>2]=32;c[d>>2]=0;A=b+13996|0;B=c[A>>2]|0;C=c[o>>2]|0;D=B;E=C;F=D-E|0;G=C+F|0;H=b+800|0;c[H>>2]=G;I=c[e>>2]|0;_2(l,I,g);J=c[i>>2]|0;_2(l,J,k);K=c[m>>2]|0;L=c[o>>2]|0;M=c[p>>2]|0;N=M;O=L;P=N-O|0;Q=P<<3;R=32-K|0;S=R+Q|0;T=b+13700|0;c[T>>2]=S;return}function mSa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=(c[b+144>>2]|0)-1|0;f=e>>>0>65535>>>0;g=f?e>>>16:e;e=f?16:0;if((g&65280|0)==0){h=e;i=g}else{h=e|8;i=g>>>8}g=(d[1359664+i|0]|0)+h|0;h=g+1|0;i=ERa(b)|0;e=b+784|0;f=c[e>>2]|0;j=b+788|0;k=c[j>>2]|0;if((k|0)>(i|0)){l=k-i|0;m=f<<i}else{n=je(f<<k|0)|0;f=b+796|0;o=c[f>>2]|0;y=n;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;l=32-i+k|0;m=0}c[e>>2]=m;c[j>>2]=l;if((l|0)>1){p=l-1|0;q=m<<1|1}else{k=je(1>>>((1-l|0)>>>0)|m<<l|0)|0;m=b+796|0;i=c[m>>2]|0;y=k;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;p=l+31|0;q=1}c[e>>2]=q;c[j>>2]=p;l=(ca(c[b+116>>2]|0,c[b+12480>>2]|0)|0)+(c[b+12476>>2]|0)|0;if((p|0)>(h|0)){r=p-h|0;s=q<<h|l}else{m=je(l>>>((h-p|0)>>>0)|q<<p|0)|0;q=b+796|0;h=c[q>>2]|0;y=m;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;r=31-g+p|0;s=l}c[e>>2]=s;c[j>>2]=r;l=c[b+13920>>2]|0;p=c[b+9960>>2]|0;if((r|0)>(l|0)){t=r;u=s<<l|p}else{g=je(s<<r|p>>>((l-r|0)>>>0)|0)|0;s=b+796|0;q=c[s>>2]|0;y=g;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;t=r+32|0;u=p}p=t-l|0;c[e>>2]=u;c[j>>2]=p;if((p|0)>1){v=p-1|0;w=u<<1;c[e>>2]=w;c[j>>2]=v;return}else{l=je(u<<p|0)|0;u=b+796|0;b=c[u>>2]|0;y=l;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=p+31|0;w=0;c[e>>2]=w;c[j>>2]=v;return}}function nSa(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=c[d+60>>2]|0;g=f;do{if((c[d+120>>2]|0)<=8191){if((c[d+124>>2]|0)>8191){break}h=bUa(d)|0;if((h|0)<0){j=h;i=e;return j|0}if(!(a[1512688]|0)){a[1512688]=1;h=-256;do{k=-h|0;l=(h|0)>-1?h:k;if((l|0)==0){m=0}else{n=0;o=l;while(1){l=o>>1;p=n+1|0;if((l|0)==0){m=p;break}else{n=p;o=l}}}if((h|0)<0){q=(1<<m)-1^k}else{q=h}o=a[1344968+(m<<1)|0]|0;n=a[1344969+(m<<1)|0]|0;l=(m|0)>0;p=o&255;do{if(l){r=(o&255)<<m|q;s=(n&255)+m|0;if((m|0)<=8){t=s&255;u=r&65535;break}t=s+1&255;u=(r<<1|1)&65535}else{t=n;u=p}}while(0);p=h+256|0;b[3619056+(p<<1)>>1]=u;a[3618544+p|0]=t;n=a[1345e3+(m<<1)|0]|0;o=a[1345001+(m<<1)|0]|0;k=n&255;do{if(l){r=(n&255)<<m|q;s=(o&255)+m|0;if((m|0)<=8){v=s&255;w=r&65535;break}v=s+1&255;w=(r<<1|1)&65535}else{v=o;w=k}}while(0);b[3620592+(p<<1)>>1]=w;a[3620080+p|0]=v;h=h+1|0;}while((h|0)<256);ATa(1343600,7664064);oSa(1343600,3405552,3389168);oSa(1378528,3487472,3471088)}c[f+13080>>2]=-2048;c[f+13084>>2]=2047;c[f+13092>>2]=3389168;c[f+13096>>2]=3397360;c[f+13100>>2]=3471088;c[f+13104>>2]=3479280;c[f+13108>>2]=3618544;c[f+13088>>2]=30;c[f+9888>>2]=1343568;c[f+9892>>2]=1344936;if((c[f+60>>2]&4194304|0)==0){j=0;i=e;return j|0}h=hJb(1024)|0;k=f+4|0;c[(c[k>>2]|0)+96>>2]=h;h=c[(c[k>>2]|0)+96>>2]|0;c[f+804>>2]=8192;o=f+792|0;c[o>>2]=h;c[f+800>>2]=h+1024;n=f+796|0;c[n>>2]=h;h=f+788|0;c[h>>2]=32;l=f+784|0;c[l>>2]=0;if((c[f+84>>2]&8192|0)==0){iSa(g)}jSa(g);r=c[h>>2]|0;if((r|0)<32){s=c[l>>2]<<r;c[l>>2]=s;r=s>>>24&255;while(1){s=c[n>>2]|0;c[n>>2]=s+1;a[s]=r;s=c[l>>2]|0;c[l>>2]=s<<8;x=(c[h>>2]|0)+8|0;c[h>>2]=x;if((x|0)<32){r=s>>>16&255}else{break}}}c[h>>2]=32;c[l>>2]=0;c[(c[k>>2]|0)+100>>2]=(c[n>>2]|0)-(c[o>>2]|0)<<3>>3;j=0;i=e;return j|0}}while(0);KIb(d,16,2245528,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;j=-22;i=e;return j|0}function oSa(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;i=f|0;j=f+8|0;k=-64;while(1){if((k|0)==0){k=k+1|0;continue}l=k+64|0;m=(k|0)<0?-k|0:k;n=k>>>31;o=m-1|0;p=k&4095;q=0;do{r=l+(q<<7)|0;s=0;do{t=r+(s<<13)|0;u=h+t|0;a[u]=100;v=f+20+(s<<2)|0;w=d[(c[v>>2]|0)+q|0]|0;x=c[i>>2]|0;if((w|0)<(x|0)){y=(a[(c[f+28+(s<<2)>>2]|0)+q|0]|0)<(m|0)?x:o+w|0}else{y=x}w=c[j>>2]|0;z=(e[w+(y<<2)+2>>1]|0)+1|0;if((y|0)!=(x|0)&z>>>0<100>>>0){c[g+(t<<2)>>2]=e[w+(y<<2)>>1]<<1|n;A=z&255;a[u]=A;B=c[i>>2]|0;C=c[j>>2]|0;D=A}else{B=x;C=w;D=100}w=f+28+(s<<2)|0;x=a[(c[w>>2]|0)+q|0]|0;A=m-x|0;do{if((A|0)>0){z=b[C+(B<<2)+2>>1]|0;E=b[C+(B<<2)>>1]|0;F=d[(c[v>>2]|0)+q|0]|0;if((F|0)>=(B|0)|(x|0)<(A|0)){G=B;H=z;I=E}else{J=A-1+F|0;G=J;H=b[C+(J<<2)+2>>1]|0;I=b[C+(J<<2)>>1]|0}J=H&65535;F=(z&65535)+2+J|0;if((G|0)==(B|0)){K=B;L=C;M=D;break}if((F|0)>=(D&255|0)){K=B;L=C;M=D;break}c[g+(t<<2)>>2]=((E&65535)<<1<<J)+(I&65535)<<1|n;J=F&255;a[u]=J;K=c[i>>2]|0;L=c[j>>2]|0;M=J}else{K=B;L=C;M=D}}while(0);A=q-(a[(c[f+36+(s<<2)>>2]|0)+m|0]|0)|0;do{if((A|0)>0){x=b[L+(K<<2)+2>>1]|0;J=b[L+(K<<2)>>1]|0;F=x&65535;E=A-1|0;z=(J&65535)<<2|2;N=d[(c[v>>2]|0)+E|0]|0;do{if((N|0)<(K|0)){if((a[(c[w>>2]|0)+E|0]|0)<(m|0)){O=K;P=x;Q=J;break}R=o+N|0;O=R;P=b[L+(R<<2)+2>>1]|0;Q=b[L+(R<<2)>>1]|0}else{O=K;P=x;Q=J}}while(0);J=P&65535;x=F+3+J|0;if((O|0)==(K|0)){S=K;T=L;U=M;break}if((x|0)>=(M&255|0)){S=K;T=L;U=M;break}c[g+(t<<2)>>2]=(z<<J)+(Q&65535)<<1|n;J=x&255;a[u]=J;S=c[i>>2]|0;T=c[j>>2]|0;U=J}else{S=K;T=L;U=M}}while(0);w=(e[T+(S<<2)+2>>1]|0)+23|0;if(w>>>0<(U&255)>>>0){c[g+(t<<2)>>2]=(((e[T+(S<<2)>>1]<<3|6)+s<<6)+q<<13|p)<<1|8193;a[u]=w}s=s+1|0;}while((s|0)<2);q=q+1|0;}while((q|0)<64);k=k+1|0;if((k|0)>=64){break}}return}function pSa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c[a+180+(f<<2)>>2]|0;do{if((c[a+12488>>2]|0)==0){if((i|0)<0){j=0}else{k=0;l=3471088;m=0;break}return j|0}else{n=d[((f|0)<4?3618544:3620080)+(g+256)|0]|0;if((i|0)<1){j=n}else{k=1;l=3389168;m=n;break}return j|0}}while(0);g=k-1|0;f=b[e+((d[h+k|0]|0)<<1)>>1]|0;a=f<<16>>16;if((k|0)<(i|0)){n=m;o=g;p=k;q=f;f=a;while(1){if(q<<16>>16==0){r=o;s=n}else{t=f+64|0;if(t>>>0<128>>>0){u=d[l+((p-o<<7)-128+t)|0]|0}else{u=30}r=p;s=u+n|0}t=p+1|0;v=b[e+((d[h+t|0]|0)<<1)>>1]|0;w=v<<16>>16;if((t|0)<(i|0)){n=s;o=r;p=t;q=v;f=w}else{x=s;y=r;z=i;A=w;break}}}else{x=m;y=g;z=k;A=a}a=A+64|0;if(a>>>0<128>>>0){B=d[l+((z-y<<7)+8064+a)|0]|0}else{B=30}j=B+x|0;return j|0}function qSa(f,g,h,i,j,k,l){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=c[f+180+(h<<2)>>2]|0;do{if((c[f+12488>>2]|0)==0){if((m|0)>=0){n=0;o=3487472;p=3471088;break}return}else{q=i+256|0;if((h|0)<4){r=d[3618544+q|0]|0;s=e[3619056+(q<<1)>>1]|0;t=k|0;u=c[t>>2]|0;v=k+4|0;w=c[v>>2]|0;if((w|0)>(r|0)){x=w-r|0;z=u<<r|s}else{A=je(s>>>((r-w|0)>>>0)|u<<w|0)|0;u=k+12|0;B=c[u>>2]|0;y=A;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;x=32-r+w|0;z=s}c[t>>2]=z;c[v>>2]=x}else{v=d[3620080+q|0]|0;t=e[3620592+(q<<1)>>1]|0;q=k|0;s=c[q>>2]|0;w=k+4|0;r=c[w>>2]|0;if((r|0)>(v|0)){C=r-v|0;D=s<<v|t}else{u=je(t>>>((v-r|0)>>>0)|s<<r|0)|0;s=k+12|0;B=c[s>>2]|0;y=u;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;C=32-v+r|0;D=t}c[q>>2]=D;c[w>>2]=C}if((m|0)>=1){n=1;o=3405552;p=3389168;break}return}}while(0);C=n-1|0;D=b[g+((d[j+n|0]|0)<<1)>>1]|0;k=D<<16>>16;if((n|0)<(m|0)){x=l|0;z=l+4|0;h=l+12|0;i=C;f=n;w=D;D=k;while(1){do{if(w<<16>>16==0){E=i}else{q=f-i-1|0;t=D+64|0;if(t>>>0<128>>>0){r=t+(q<<7)|0;t=d[p+r|0]|0;v=c[o+(r<<2)>>2]|0;r=c[x>>2]|0;s=c[z>>2]|0;if((s|0)>(t|0)){F=s-t|0;G=r<<t|v}else{B=je(v>>>((t-s|0)>>>0)|r<<s|0)|0;r=c[h>>2]|0;y=B;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;F=32-t+s|0;G=v}c[x>>2]=G;c[z>>2]=F;E=f;break}else{v=(q<<14)+31465472|D<<1&8190|1;q=c[x>>2]|0;s=c[z>>2]|0;if((s|0)>30){H=s-30|0;I=q<<30|v}else{t=je(v>>>((30-s|0)>>>0)|q<<s|0)|0;q=c[h>>2]|0;y=t;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;H=s+2|0;I=v}c[x>>2]=I;c[z>>2]=H;E=f;break}}}while(0);v=f+1|0;s=b[g+((d[j+v|0]|0)<<1)>>1]|0;q=s<<16>>16;if((v|0)<(m|0)){i=E;f=v;w=s;D=q}else{J=E;K=m;L=q;break}}}else{J=C;K=n;L=k}k=K-J-1|0;J=L+64|0;if(J>>>0<128>>>0){K=(k<<7)+8192+J|0;J=d[p+K|0]|0;p=c[o+(K<<2)>>2]|0;K=l|0;o=c[K>>2]|0;n=l+4|0;C=c[n>>2]|0;if((C|0)>(J|0)){M=C-J|0;N=o<<J|p}else{m=je(p>>>((J-C|0)>>>0)|o<<C|0)|0;o=l+12|0;E=c[o>>2]|0;y=m;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;M=32-J+C|0;N=p}c[K>>2]=N;c[n>>2]=M;return}else{M=(k<<14)+32514048|L<<1&8190|1;L=l|0;k=c[L>>2]|0;n=l+4|0;N=c[n>>2]|0;if((N|0)>30){O=N-30|0;P=k<<30|M}else{K=je(M>>>((30-N|0)>>>0)|k<<N|0)|0;k=l+12|0;l=c[k>>2]|0;y=K;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;O=N+2|0;P=M}c[L>>2]=P;c[n>>2]=O;return}}function rSa(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;j=i;i=i+56|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;c[k>>2]=g;c[l>>2]=h;g=c[a>>2]|0;r=g;s=g+16|0;t=c[s>>2]|0;a:do{if((h|0)>0){u=g+40|0;v=g+48|0;w=g+44|0;x=b+48|0;y=b+412|0;z=b+416|0;A=a+304|0;B=g+52|0;C=b+72|0;D=0;E=t;F=h;while(1){G=c[u>>2]|0;b:do{if((G|0)==0){if((D|0)<(F|0)){H=D;I=E}else{J=E;K=D;break}while(1){L=I<<8;M=H+1|0;N=d[(c[k>>2]|0)+H|0]|0|L;O=NSa(N,m,n,p,o,q)|0;if((O|0)>=4){break}if((M|0)>4){c[v>>2]=-2}if((M|0)<(c[l>>2]|0)){H=M;I=N}else{J=N;K=M;break b}}P=c[w>>2]|0;if(((P^L)&-128e3|0)==0|(P|0)==0){Q=(c[v>>2]|0)+1|0}else{c[v>>2]=-3;Q=-2}c[w>>2]=N;c[v>>2]=Q;c[u>>2]=O-4;P=c[x>>2]|0;if((P|0)==0){R=0}else{R=(P|0)!=(c[q>>2]|0)|0}if((Q|0)<=(R|0)){J=N;K=M;break}c[y>>2]=c[m>>2];c[z>>2]=c[n>>2];c[A>>2]=c[p>>2];c[x>>2]=c[q>>2];if((c[B>>2]|0)==0){if((c[C>>2]|0)!=0){J=N;K=M;break}}c[B>>2]=1;P=c[C>>2]|0;c[C>>2]=(((c[o>>2]|0)-P|0)/(c[v>>2]|0)|0)+P;J=N;K=M}else{P=F-D|0;S=(P|0)>(G|0)?G:P;P=S+D|0;c[u>>2]=G-S;if((G|0)==(S|0)){T=0;U=P;break a}else{J=0;K=P}}}while(0);G=c[l>>2]|0;if((K|0)<(G|0)){D=K;E=J;F=G}else{T=J;U=-100;break}}}else{T=t;U=-100}}while(0);c[s>>2]=T;if((IWa(r,U,k,l)|0)<0){c[e>>2]=0;c[f>>2]=0;V=c[l>>2]|0;i=j;return V|0}else{c[e>>2]=c[k>>2];c[f>>2]=c[l>>2];V=U;i=j;return V|0}return 0}function sSa(e){e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0,D=0.0,E=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;i=i+1544|0;h=f|0;j=f+8|0;k=f+520|0;l=c[e+60>>2]|0;if(!(a[1585168]|0)){m=j|0;n=k;o=0;while(1){b[5122320+(o<<1)>>1]=(o|0)%3|0|((o|0)/3|0)<<2;p=o+1|0;if((p|0)<64){o=p}else{q=0;break}}do{o=q+2|0;p=yrc(8388608,0,o|0)|0;r=(1<<o)-1|0;o=Crc(p,G,r,(r|0)<0|0?-1:0)|0;r=o;p=r;s=(r|0)<0|0?-1:0;c[5122008+(q*12|0)>>2]=o<<1|0>>>31;o=Erc(p,s,13316085,0)|0;c[5122012+(q*12|0)>>2]=o>>>23|G<<9;o=Erc(p,s,10568984,0)|0;c[5122016+(q*12|0)>>2]=o>>>23|G<<9;q=q+1|0;}while((q|0)<15);SSa(7690816);q=0;o=1;while(1){mrc(m|0,0,512)|0;mrc(n|0,0,1024)|0;s=c[820936+(o*12|0)>>2]|0;p=(s|0)>1?s:1;r=c[820940+(o*12|0)>>2]|0;t=c[820944+(o*12|0)>>2]|0;u=0;v=0;while(1){w=u<<5;if((u|0)==0){x=0;y=v;while(1){z=x|w;a[j+z|0]=a[r+y|0]|0;b[k+(z<<1)>>1]=b[t+(y<<1)>>1]|0;z=x+1|0;if((z|0)<(s|0)){x=z;y=y+1|0}else{break}}}else{y=0;x=v;while(1){z=y|w|((y|0)!=0)<<4;a[j+z|0]=a[r+x|0]|0;b[k+(z<<1)>>1]=b[t+(x<<1)>>1]|0;z=y+1|0;if((z|0)<(s|0)){y=z;x=x+1|0}else{break}}}x=u+1|0;if((x|0)<(s|0)){u=x;v=v+p|0}else{break}}c[5945924+(o*20|0)>>2]=5930616+(q<<2);p=c[1079768+(o<<2)>>2]|0;c[5945932+(o*20|0)>>2]=p;$2(5945920+(o*20|0)|0,7,512,m,1,1,n,2,2,0,0,0,4)|0;v=o+1|0;if((v|0)<16){q=p+q|0;o=v}else{break}}c[1486875]=5946880;c[1486877]=128;$2(5947496,7,16,812264,1,1,812200,1,1,0,0,0,4)|0;c[1486880]=5947392;c[1486882]=16;$2(5947516,4,16,812280,1,1,812216,1,1,0,0,0,4)|0;o=0;q=0;n=0;while(1){b[9903568+(q<<1)>>1]=n;m=(d[1960072+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951806]=576;n=0;q=0;o=0;while(1){b[9903614+(q<<1)>>1]=o;m=(d[1960094+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4951829]=576;o=0;q=0;n=0;while(1){b[9903660+(q<<1)>>1]=n;m=(d[1960116+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951852]=576;n=0;q=0;o=0;while(1){b[9903706+(q<<1)>>1]=o;m=(d[1960138+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4951875]=576;o=0;q=0;n=0;while(1){b[9903752+(q<<1)>>1]=n;m=(d[1960160+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951898]=576;n=0;q=0;o=0;while(1){b[9903798+(q<<1)>>1]=o;m=(d[1960182+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4951921]=576;o=0;q=0;n=0;while(1){b[9903844+(q<<1)>>1]=n;m=(d[1960204+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951944]=576;n=0;q=0;o=0;while(1){b[9903890+(q<<1)>>1]=o;m=(d[1960226+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4951967]=576;o=0;q=0;n=0;while(1){b[9903936+(q<<1)>>1]=n;m=(d[1960248+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951990]=576;n=1;while(1){A=+((n|0)/4|0|0);B=A/1.759*+T(+A,+.3333333333333333);q=~~(+Wc(+(B*+ad(+(+(n&3|0)*.25))),h|0)*2147483648.0+.5);o=c[h>>2]|0;c[h>>2]=o-103;c[4886488+(n<<2)>>2]=q;a[5050632+n|0]=103-o;o=n+1|0;if((o|0)<32828){n=o}else{C=0;break}}do{B=+ad(+(+(C-400|0)*.25+23.0+5.0));n=0;do{A=+(n|0);D=B*A*+T(+A,+.3333333333333333)/1.759;if(D<4294967295.0){A=+Q(D+.5);h=~~+A>>>0;F=+A,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0;E=h}else{E=-1}c[8938104+(C<<6)+(n<<2)>>2]=E;g[8872568+(C<<6)+(n<<2)>>2]=D;n=n+1|0;}while((n|0)<16);c[8974456+(C<<2)>>2]=c[8938108+(C<<6)>>2];C=C+1|0;}while((C|0)<512);C=c[337118]|0;do{if((C|0)<0){E=1<<1-C;if((E|0)<=0){break}n=c[337100]|0;h=0;do{o=(h|0)/(n|0)|0;b[9344376+(h<<1)>>1]=(((o|0)%(n|0)|0)<<4)+((h|0)%(n|0)|0)+(((o|0)/(n|0)|0)<<8);h=h+1|0;}while((h|0)<(E|0))}}while(0);C=c[337119]|0;do{if((C|0)<0){E=1<<1-C;if((E|0)<=0){break}h=c[337101]|0;n=0;do{o=(n|0)/(h|0)|0;b[9343736+(n<<1)>>1]=(((o|0)%(h|0)|0)<<4)+((n|0)%(h|0)|0)+(((o|0)/(h|0)|0)<<8);n=n+1|0;}while((n|0)<(E|0))}}while(0);C=c[337120]|0;do{if((C|0)<0){E=1<<1-C;if((E|0)<=0){break}n=c[337102]|0;h=0;do{o=(h|0)/(n|0)|0;b[h<<1>>1]=(((o|0)%(n|0)|0)<<4)+((h|0)%(n|0)|0)+(((o|0)/(n|0)|0)<<8);h=h+1|0;}while((h|0)<(E|0))}}while(0);C=c[337121]|0;do{if((C|0)<0){E=1<<1-C;if((E|0)<=0){H=0;break}h=c[337103]|0;n=0;while(1){o=(n|0)/(h|0)|0;b[9339128+(n<<1)>>1]=(((o|0)%(h|0)|0)<<4)+((n|0)%(h|0)|0)+(((o|0)/(h|0)|0)<<8);o=n+1|0;if((o|0)<(E|0)){n=o}else{H=0;break}}}else{H=0}}while(0);do{if((H|0)==6){I=8388608}else{B=+W(+(H|0)*3.141592653589793/12.0);I=~~(B/(B+1.0)*8388608.0+.5)}c[5831320+(H<<2)>>2]=I;c[5831384+(6-H<<2)>>2]=I;H=H+1|0;}while((H|0)<7);mrc(5831348,0,36)|0;mrc(5831412,0,36)|0;H=0;while(1){I=H+1|0;C=I>>1;n=H&1;E=n^1;c[5830936+(E<<6)+(H<<2)>>2]=~~(+ad(+(+(-C|0)*.25))*8388608.0+.5);c[5830936+(n<<6)+(H<<2)>>2]=8388608;c[5831064+(E<<6)+(H<<2)>>2]=~~(+ad(+(+(C*-2|0|0)*.25))*8388608.0+.5);c[5831064+(n<<6)+(H<<2)>>2]=8388608;if((I|0)<16){H=I}else{J=0;break}}do{B=+g[1704920+(J<<2)>>2];D=1.0/+S(B*B+1.0);H=~~(D*.25*4294967296.0+.5);c[9772544+(J<<4)>>2]=H;I=~~(B*D*.25*4294967296.0+.5);c[9772548+(J<<4)>>2]=I;c[9772552+(J<<4)>>2]=I+H;c[9772556+(J<<4)>>2]=I-H;J=J+1|0;}while((J|0)<8);a[1585168]=1}c[l+32940>>2]=e;qHb(l+32968|0,c[e+88>>2]&8388608);PSa(l+32944|0);J=c[e+48>>2]|0;do{if((c[e+468>>2]|0)==1){if((J|0)==86030){K=86030;L=63;break}c[e+420>>2]=1;M=J}else{K=J;L=63}}while(0);if((L|0)==63){c[e+420>>2]=6;M=K}c[l+32936>>2]=c[e+696>>2];if((M|0)!=86029){i=f;return 0}c[l+32928>>2]=1;i=f;return 0}function tSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=g+28|0;k=c[j>>2]|0;l=c[b+60>>2]|0;m=l;if((k|0)==0){n=-1094995529;i=h;return n|0}o=k;k=c[g+24>>2]|0;while(1){if((a[k]|0)!=0){break}g=o-1|0;if((g|0)==0){n=-1094995529;p=22;break}else{o=g;k=k+1|0}}if((p|0)==22){i=h;return n|0}if((o|0)<4){n=-1094995529;i=h;return n|0}p=k;g=je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if((g&-256|0)==1413564160){KIb(b,48,2333592,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=o;i=h;return n|0}if((g&-2097152|0)!=-2097152|(g&393216|0)==0|(g&61440|0)==61440|(g&3072|0)==3072){KIb(b,16,2328136,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}if((MSa(l,g)|0)==1){c[l>>2]=-1;n=-1094995529;i=h;return n|0}g=l+24|0;c[b+416>>2]=c[g>>2];p=(c[g>>2]|0)==1;g=b+448|0;c[g>>2]=p?4:3;c[g+4>>2]=p?0:0;p=b+72|0;if((c[p>>2]|0)==0){c[p>>2]=c[l+20>>2]}p=l;g=c[p>>2]|0;if((g|0)<1|(g|0)>(o|0)){KIb(b,16,2322416,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}if((g|0)<(o|0)){KIb(b,48,2317264,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=c[p>>2]|0}else{r=o}o=l+33004|0;c[o>>2]=e;e=ASa(m,0,k,r)|0;do{if((e|0)>-1){c[(c[o>>2]|0)+76>>2]=c[b+424>>2];c[f>>2]=1;c[b+412>>2]=c[l+12>>2]}else{KIb(b,16,2345344,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[f>>2]=0;if((r|0)!=(c[j>>2]|0)&(e|0)==-1094995529){break}else{n=e}i=h;return n|0}}while(0);c[p>>2]=0;n=r;i=h;return n|0}function uSa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mrc(b+1152|0,0,8192)|0;c[b+1088>>2]=0;return}function vSa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;f=c[a+60>>2]|0;if((j|0)<4){KIb(a,16,2368896,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}m=h;n=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;if((n&393216|0)==0|(n&61440|0)==61440|(n&3072|0)==3072){KIb(a,16,2353928,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}MSa(f,n|-2097152)|0;c[a+412>>2]=c[f+12>>2];n=f+24|0;c[a+416>>2]=c[n>>2];m=(c[n>>2]|0)==1;n=a+448|0;c[n>>2]=m?4:3;c[n+4>>2]=m?0:0;m=a+72|0;if((c[m>>2]|0)==0){c[m>>2]=c[f+20>>2]}c[f>>2]=(j|0)>1792?1792:j;c[f+33004>>2]=b;b=ASa(f,0,h,j)|0;if((b|0)<0){KIb(a,16,2345344,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=b;i=g;return l|0}else{c[e>>2]=1;l=j;i=g;return l|0}return 0}function wSa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+48|0;f=e|0;g=a+60|0;h=c[g>>2]|0;j=c[a+100>>2]|0;do{if((j|0)>=2){k=c[a+96>>2]|0;if((k|0)==0){break}CRa(f,k,j<<3,1)|0;k=f+12|0;l=c[k>>2]|0;if((l|0)==0|(l|0)>7){KIb(a,16,2375568,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}o=h;c[o>>2]=d[821824+l|0]|0;l=c[k>>2]|0;c[h+8>>2]=1712672+(l*5|0);c[a+416>>2]=d[1343560+l|0]|0;k=b[1712728+(l<<1)>>1]|0;l=a+448|0;c[l>>2]=k<<16>>16;c[l+4>>2]=k<<16>>16<0|0?-1:0;c[h+4>>2]=(c[f+8>>2]|0)<16e3?-2097152:-1048576;k=pJb(33024)|0;l=h+12|0;p=l;q=l;c[q>>2]=k;a:do{if((k|0)!=0){c[g>>2]=k;sSa(a)|0;c[g>>2]=h;c[(c[q>>2]|0)+32928>>2]=1;if((c[o>>2]|0)>1){r=1}else{n=0;i=e;return n|0}while(1){l=pJb(33024)|0;s=p+(r<<2)|0;c[s>>2]=l;if((l|0)==0){break a}c[l+32928>>2]=1;c[l+32940>>2]=a;l=(c[s>>2]|0)+32944|0;s=(c[q>>2]|0)+32944|0;c[l>>2]=c[s>>2];c[l+4>>2]=c[s+4>>2];c[l+8>>2]=c[s+8>>2];c[l+12>>2]=c[s+12>>2];c[l+16>>2]=c[s+16>>2];c[l+20>>2]=c[s+20>>2];s=r+1|0;if((s|0)<(c[o>>2]|0)){r=s}else{n=0;break}}i=e;return n|0}}while(0);o=c[g>>2]|0;q=o;if((c[q>>2]|0)<=0){n=-12;i=e;return n|0}p=o+12|0;o=0;while(1){kJb(c[p+(o<<2)>>2]|0);k=o+1|0;if((k|0)<(c[q>>2]|0)){o=k}else{n=-12;break}}i=e;return n|0}}while(0);KIb(a,16,2382208,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}function xSa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+8|0;h=g|0;j=c[f+24>>2]|0;k=c[f+28>>2]|0;f=c[a+60>>2]|0;l=b+76|0;c[l>>2]=1152;m=M4a(a,b,0)|0;if((m|0)<0){n=m;i=g;return n|0}m=c[b+64>>2]|0;if((k|0)<4){n=-1094995529;i=g;return n|0}b=a+72|0;c[b>>2]=0;o=f;a:do{if((c[o>>2]|0)>0){p=f+12|0;q=f+4|0;r=a+416|0;s=f+8|0;t=h|0;u=h+4|0;v=a;w=k;x=0;y=j;z=0;A=0;while(1){B=y;C=((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;B=(C|0)>(w|0)?w:C;C=(B|0)>1792?1792:B;B=c[p+(z<<2)>>2]|0;if((C|0)<4){D=7;break}E=y;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)&1048575;E=c[q>>2]|0;G=F|E;if((E&-2097152|0)!=-2097152|(G&393216|0)==0|(G&61440|0)==61440|(G&3072|0)==3072){D=9;break}MSa(B,G)|0;G=B+24|0;E=c[G>>2]|0;F=E+A|0;H=c[r>>2]|0;if((F|0)>(H|0)){D=12;break}I=d[(c[s>>2]|0)+z|0]|0;if((I+E|0)>(H|0)){D=12;break}c[t>>2]=c[m+(I<<2)>>2];if((E|0)>1){c[u>>2]=c[m+((d[(c[s>>2]|0)+z|0]|0)+1<<2)>>2]}E=ASa(B,t,y,C)|0;if((E|0)<0){KIb(v,16,2501912,(J=i,i=i+8|0,c[J>>2]=F,J)|0);i=J;mrc(c[t>>2]|0,0,2304)|0;I=c[G>>2]|0;if((I|0)>1){mrc(c[u>>2]|0,0,2304)|0;K=c[G>>2]|0}else{K=I}L=K*2304|0}else{L=E}E=L+x|0;c[b>>2]=(c[b>>2]|0)+(c[B+20>>2]|0);B=z+1|0;if((B|0)<(c[o>>2]|0)){w=w-C|0;x=E;y=y+C|0;z=B;A=F}else{M=E;N=F;O=r;break a}}if((D|0)==7){KIb(v,16,2549032,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}else if((D|0)==9){KIb(v,16,2531136,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}else if((D|0)==12){KIb(v,16,2515848,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}}else{M=0;N=0;O=a+416|0}}while(0);if((N|0)==(c[O>>2]|0)){c[a+412>>2]=c[(c[f+12>>2]|0)+12>>2];c[l>>2]=(M>>>0)/(N<<1>>>0)|0;c[e>>2]=1;n=k;i=g;return n|0}else{KIb(a,16,2488904,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}return 0}function ySa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;a=b;if((c[a>>2]|0)<=0){return 0}d=b+12|0;b=0;do{kJb(c[d+(b<<2)>>2]|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function zSa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b;if((c[a>>2]|0)<=0){return}d=b+12|0;b=0;do{e=c[d+(b<<2)>>2]|0;mrc(e+1152|0,0,8192)|0;c[e+1088>>2]=0;b=b+1|0;}while((b|0)<(c[a>>2]|0));return}function ASa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0;k=i;i=i+3808|0;l=k|0;m=k+192|0;n=k+256|0;o=k+320|0;p=k+336|0;q=k+2640|0;r=k+3792|0;s=f+1096|0;t=h+4|0;h=j-4|0;j=h<<3;u=j>>>0>2147483639>>>0|(t|0)==0;v=u?0:t;t=u?0:j;j=s|0;c[j>>2]=v;u=f+1108|0;c[u>>2]=t;w=t+8|0;x=f+1112|0;c[x>>2]=w;y=f+1100|0;c[y>>2]=v+(t>>3);t=f+1104|0;c[t>>2]=0;if((c[f+4>>2]|0)==0){z=0}else{A=w>>>0>16>>>0?16:w;c[t>>2]=A;z=A}A=c[f+8>>2]|0;if((A|0)==2){c[(c[f+32940>>2]|0)+424>>2]=1152;B=f+24|0;C=Brb((c[f+20>>2]|0)/1e3|0,c[B>>2]|0,c[f+12>>2]|0,c[f+36>>2]|0)|0;D=c[1348376+(C<<2)>>2]|0;E=c[1349576+(C<<2)>>2]|0;if((c[f+28>>2]|0)==1){F=(c[f+32>>2]<<2)+4|0}else{F=D}C=(F|0)>(D|0)?D:F;F=(C|0)>0;if(F){H=f+1096|0;I=c[B>>2]|0;J=(I|0)>0;K=0;L=0;while(1){M=d[E+K|0]|0;if(J){N=32-M|0;O=c[x>>2]|0;P=c[H>>2]|0;Q=0;R=c[t>>2]|0;do{S=P+(R>>>3)|0;T=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(R&7)>>>(N>>>0);S=R+M|0;R=O>>>0>S>>>0?S:O;c[t>>2]=R;a[m+(Q<<5)+L|0]=T;Q=Q+1|0;}while((Q|0)<(I|0))}Q=(1<<M)+K|0;R=L+1|0;if((R|0)<(C|0)){K=Q;L=R}else{U=Q;break}}}else{U=0}L=(C|0)<(D|0);if(L){K=c[x>>2]|0;I=c[f+1096>>2]|0;H=U;U=C;J=c[t>>2]|0;while(1){Q=d[E+H|0]|0;R=I+(J>>>3)|0;O=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(J&7)>>>((32-Q|0)>>>0);R=Q+J|0;N=K>>>0>R>>>0?R:K;c[t>>2]=N;R=O&255;a[m+U|0]=R;a[m+32+U|0]=R;R=U+1|0;if((R|0)<(D|0)){H=(1<<Q)+H|0;U=R;J=N}else{break}}}J=f+1096|0;if((D|0)>0){U=c[B>>2]|0;H=(U|0)>0;K=0;while(1){if(H){I=0;do{if((a[m+(I<<5)+K|0]|0)!=0){N=c[t>>2]|0;R=c[x>>2]|0;Q=(c[J>>2]|0)+(N>>>3)|0;O=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(N&7)>>>30;Q=N+2|0;c[t>>2]=R>>>0>Q>>>0?Q:R;a[n+(I<<5)+K|0]=O}I=I+1|0;}while((I|0)<(U|0))}I=K+1|0;if((I|0)<(D|0)){K=I}else{V=0;break}}do{if(H){K=0;do{do{if((a[m+(K<<5)+V|0]|0)!=0){I=l+(K*96|0)+(V*3|0)|0;M=d[n+(K<<5)+V|0]|0;if((M|0)==1){O=c[t>>2]|0;R=c[x>>2]|0;Q=c[J>>2]|0;N=Q+(O>>>3)|0;P=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(O&7)>>>26;N=O+6|0;O=R>>>0>N>>>0?N:R;c[t>>2]=O;N=P&255;a[I]=N;P=Q+(O>>>3)|0;Q=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(O&7)>>>26;P=O+6|0;c[t>>2]=R>>>0>P>>>0?P:R;a[l+(K*96|0)+(V*3|0)+2|0]=Q;a[l+(K*96|0)+(V*3|0)+1|0]=N;break}else if((M|0)==3){N=c[t>>2]|0;Q=c[x>>2]|0;R=c[J>>2]|0;P=R+(N>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(N&7)>>>26;P=N+6|0;N=Q>>>0>P>>>0?P:Q;c[t>>2]=N;a[I]=O;O=R+(N>>>3)|0;R=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(N&7)>>>26;O=N+6|0;c[t>>2]=Q>>>0>O>>>0?O:Q;Q=R&255;a[l+(K*96|0)+(V*3|0)+2|0]=Q;a[l+(K*96|0)+(V*3|0)+1|0]=Q;break}else if((M|0)==2){M=c[t>>2]|0;Q=c[x>>2]|0;R=(c[J>>2]|0)+(M>>>3)|0;O=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(M&7)>>>26;R=M+6|0;c[t>>2]=Q>>>0>R>>>0?R:Q;Q=O&255;a[I]=Q;a[l+(K*96|0)+(V*3|0)+1|0]=Q;a[l+(K*96|0)+(V*3|0)+2|0]=Q;break}else{Q=c[t>>2]|0;O=c[x>>2]|0;R=c[J>>2]|0;M=R+(Q>>>3)|0;N=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Q&7)>>>26;M=Q+6|0;Q=O>>>0>M>>>0?M:O;c[t>>2]=Q;a[I]=N;N=R+(Q>>>3)|0;I=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Q&7)>>>26;N=Q+6|0;Q=O>>>0>N>>>0?N:O;c[t>>2]=Q;a[l+(K*96|0)+(V*3|0)+1|0]=I;I=R+(Q>>>3)|0;R=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(Q&7)>>>26;I=Q+6|0;c[t>>2]=O>>>0>I>>>0?I:O;a[l+(K*96|0)+(V*3|0)+2|0]=R;break}}}while(0);K=K+1|0;}while((K|0)<(U|0))}V=V+1|0;}while((V|0)<(D|0))}V=(D|0)<32;U=0;while(1){H=U*12|0;K=0;do{if(F){R=K+H|0;O=R+1|0;I=R+2|0;Q=0;N=0;M=c[B>>2]|0;while(1){P=d[E+Q|0]|0;if((M|0)>0){T=0;while(1){S=a[m+(T<<5)+N|0]|0;do{if(S<<24>>24==0){c[f+9376+(T*4608|0)+(R<<7)+(N<<2)>>2]=0;c[f+9376+(T*4608|0)+(O<<7)+(N<<2)>>2]=0;c[f+9376+(T*4608|0)+(I<<7)+(N<<2)>>2]=0}else{W=d[l+(T*96|0)+(N*3|0)+U|0]|0;X=d[E+((S&255)+Q)|0]|0;Y=c[1348472+(X<<2)>>2]|0;if((Y|0)>=0){Z=32-Y|0;_=Y-1|0;$=(-1<<_)+1|0;aa=c[t>>2]|0;ba=c[x>>2]|0;da=(c[J>>2]|0)+(aa>>>3)|0;ea=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(aa&7)>>>(Z>>>0);da=aa+Y|0;c[t>>2]=ba>>>0>da>>>0?da:ba;ba=e[5122320+(W<<1)>>1]|0;da=ea+$|0;ea=5122008+((Y-2|0)*12|0)+((ba&3)<<2)|0;aa=c[ea>>2]|0;fa=Erc(da,(da|0)<0|0?-1:0,aa,(aa|0)<0|0?-1:0)|0;aa=G;da=(ba>>>2)+_|0;_=yrc(1,0,da-1|0)|0;ba=G;ga=wrc(_,ba,fa,aa)|0;aa=da;da=Arc(ga|0,G|0,aa|0)|0;c[f+9376+(T*4608|0)+(R<<7)+(N<<2)>>2]=da;da=c[t>>2]|0;ga=c[x>>2]|0;fa=(c[J>>2]|0)+(da>>>3)|0;ha=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(da&7)>>>(Z>>>0);fa=da+Y|0;c[t>>2]=ga>>>0>fa>>>0?fa:ga;ga=ha+$|0;ha=c[ea>>2]|0;fa=Erc(ga,(ga|0)<0|0?-1:0,ha,(ha|0)<0|0?-1:0)|0;ha=wrc(fa,G,_,ba)|0;fa=Arc(ha|0,G|0,aa|0)|0;c[f+9376+(T*4608|0)+(O<<7)+(N<<2)>>2]=fa;fa=c[t>>2]|0;ha=c[x>>2]|0;ga=(c[J>>2]|0)+(fa>>>3)|0;da=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(fa&7)>>>(Z>>>0);Z=fa+Y|0;c[t>>2]=ha>>>0>Z>>>0?Z:ha;ha=da+$|0;$=c[ea>>2]|0;ea=Erc(ha,(ha|0)<0|0?-1:0,$,($|0)<0|0?-1:0)|0;$=wrc(ea,G,_,ba)|0;ba=Arc($|0,G|0,aa|0)|0;c[f+9376+(T*4608|0)+(I<<7)+(N<<2)>>2]=ba;break}ba=c[t>>2]|0;aa=c[x>>2]|0;$=(c[J>>2]|0)+(ba>>>3)|0;_=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ba&7)>>>((Y+32|0)>>>0);$=ba-Y|0;c[t>>2]=aa>>>0>$>>>0?$:aa;aa=b[(c[1530912+(X<<2)>>2]|0)+(_<<1)>>1]|0;_=c[1348400+(X<<2)>>2]|0;X=e[5122320+(W<<1)>>1]|0;W=X>>>2;$=_>>1;Y=c[608680+((_>>2)*12|0)+((X&3)<<2)>>2]|0;X=ca(Y,(aa&15)-$|0)|0;if((W|0)==0){c[f+9376+(T*4608|0)+(R<<7)+(N<<2)>>2]=X;c[f+9376+(T*4608|0)+(O<<7)+(N<<2)>>2]=ca((aa>>>4&15)-$|0,Y)|0;ia=ca(Y,(aa>>8)-$|0)|0}else{_=1<<W-1;c[f+9376+(T*4608|0)+(R<<7)+(N<<2)>>2]=_+X>>W;c[f+9376+(T*4608|0)+(O<<7)+(N<<2)>>2]=_+(ca((aa>>>4&15)-$|0,Y)|0)>>W;ia=_+(ca(Y,(aa>>8)-$|0)|0)>>W}c[f+9376+(T*4608|0)+(I<<7)+(N<<2)>>2]=ia}}while(0);S=T+1|0;W=c[B>>2]|0;if((S|0)<(W|0)){T=S}else{ja=W;break}}}else{ja=M}T=(1<<P)+Q|0;W=N+1|0;if((W|0)<(C|0)){Q=T;N=W;M=ja}else{ka=T;break}}}else{ka=0}if(L){M=K+H|0;N=M+1|0;Q=M+2|0;I=ka;O=C;while(1){R=d[E+I|0]|0;T=a[m+O|0]|0;do{if(T<<24>>24==0){c[f+9376+(M<<7)+(O<<2)>>2]=0;c[f+9376+(N<<7)+(O<<2)>>2]=0;c[f+9376+(Q<<7)+(O<<2)>>2]=0;c[f+13984+(M<<7)+(O<<2)>>2]=0;c[f+13984+(N<<7)+(O<<2)>>2]=0;c[f+13984+(Q<<7)+(O<<2)>>2]=0}else{W=d[l+(O*3|0)+U|0]|0;S=d[l+96+(O*3|0)+U|0]|0;$=d[E+((T&255)+I)|0]|0;aa=c[1348472+($<<2)>>2]|0;if((aa|0)>=0){Y=32-aa|0;_=aa-1|0;X=(-1<<_)+1|0;ba=aa-2|0;ea=b[5122320+(S<<1)>>1]|0;ha=e[5122320+(W<<1)>>1]|0;da=5122008+(ba*12|0)+((ha&3)<<2)|0;Z=(ha>>>2)+_|0;ha=yrc(1,0,Z-1|0)|0;fa=G;ga=Z;Z=ea&65535;ea=5122008+(ba*12|0)+((Z&3)<<2)|0;ba=(Z>>>2)+_|0;_=yrc(1,0,ba-1|0)|0;Z=G;la=ba;ba=c[t>>2]|0;ma=c[x>>2]|0;na=(c[J>>2]|0)+(ba>>>3)|0;oa=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ba&7)>>>(Y>>>0);na=ba+aa|0;c[t>>2]=ma>>>0>na>>>0?na:ma;ma=X+oa|0;oa=ma;na=(ma|0)<0|0?-1:0;ma=c[da>>2]|0;ba=Erc(oa,na,ma,(ma|0)<0|0?-1:0)|0;ma=wrc(ba,G,ha,fa)|0;ba=Arc(ma|0,G|0,ga|0)|0;c[f+9376+(M<<7)+(O<<2)>>2]=ba;ba=c[ea>>2]|0;ma=Erc(oa,na,ba,(ba|0)<0|0?-1:0)|0;ba=wrc(ma,G,_,Z)|0;ma=Arc(ba|0,G|0,la|0)|0;c[f+13984+(M<<7)+(O<<2)>>2]=ma;ma=c[t>>2]|0;ba=c[x>>2]|0;na=(c[J>>2]|0)+(ma>>>3)|0;oa=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ma&7)>>>(Y>>>0);na=ma+aa|0;c[t>>2]=ba>>>0>na>>>0?na:ba;ba=X+oa|0;oa=ba;na=(ba|0)<0|0?-1:0;ba=c[da>>2]|0;ma=Erc(oa,na,ba,(ba|0)<0|0?-1:0)|0;ba=wrc(ma,G,ha,fa)|0;ma=Arc(ba|0,G|0,ga|0)|0;c[f+9376+(N<<7)+(O<<2)>>2]=ma;ma=c[ea>>2]|0;ba=Erc(oa,na,ma,(ma|0)<0|0?-1:0)|0;ma=wrc(ba,G,_,Z)|0;ba=Arc(ma|0,G|0,la|0)|0;c[f+13984+(N<<7)+(O<<2)>>2]=ba;ba=c[t>>2]|0;ma=c[x>>2]|0;na=(c[J>>2]|0)+(ba>>>3)|0;oa=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ba&7)>>>(Y>>>0);Y=ba+aa|0;c[t>>2]=ma>>>0>Y>>>0?Y:ma;ma=X+oa|0;oa=ma;X=(ma|0)<0|0?-1:0;ma=c[da>>2]|0;da=Erc(oa,X,ma,(ma|0)<0|0?-1:0)|0;ma=wrc(da,G,ha,fa)|0;fa=Arc(ma|0,G|0,ga|0)|0;c[f+9376+(Q<<7)+(O<<2)>>2]=fa;fa=c[ea>>2]|0;ea=Erc(oa,X,fa,(fa|0)<0|0?-1:0)|0;fa=wrc(ea,G,_,Z)|0;Z=Arc(fa|0,G|0,la|0)|0;c[f+13984+(Q<<7)+(O<<2)>>2]=Z;break}Z=c[t>>2]|0;la=c[x>>2]|0;fa=(c[J>>2]|0)+(Z>>>3)|0;_=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Z&7)>>>((aa+32|0)>>>0);fa=Z-aa|0;c[t>>2]=la>>>0>fa>>>0?fa:la;la=c[1348400+($<<2)>>2]|0;$=(_|0)/(la|0)|0;fa=e[5122320+(W<<1)>>1]|0;W=fa>>>2;aa=la>>1;Z=((_|0)%(la|0)|0)-aa|0;_=la>>2;ea=c[608680+(_*12|0)+((fa&3)<<2)>>2]|0;fa=ca(ea,Z)|0;X=(W|0)==0;if(X){pa=fa}else{pa=(1<<W-1)+fa>>W}c[f+9376+(M<<7)+(O<<2)>>2]=pa;fa=e[5122320+(S<<1)>>1]|0;S=fa>>>2;oa=c[608680+(_*12|0)+((fa&3)<<2)>>2]|0;fa=ca(oa,Z)|0;Z=(S|0)==0;if(Z){qa=fa}else{qa=(1<<S-1)+fa>>S}c[f+13984+(M<<7)+(O<<2)>>2]=qa;fa=(($|0)%(la|0)|0)-aa|0;_=ca(fa,ea)|0;if(X){ra=_}else{ra=_+(1<<W-1)>>W}c[f+9376+(N<<7)+(O<<2)>>2]=ra;_=ca(fa,oa)|0;if(Z){sa=_}else{sa=_+(1<<S-1)>>S}c[f+13984+(N<<7)+(O<<2)>>2]=sa;_=(($|0)/(la|0)|0)-aa|0;aa=ca(_,ea)|0;if(X){ta=aa}else{ta=aa+(1<<W-1)>>W}c[f+9376+(Q<<7)+(O<<2)>>2]=ta;W=ca(_,oa)|0;if(Z){ua=W}else{ua=W+(1<<S-1)>>S}c[f+13984+(Q<<7)+(O<<2)>>2]=ua}}while(0);T=O+1|0;if((T|0)<(D|0)){I=(1<<R)+I|0;O=T}else{break}}}if(V){O=K+H|0;I=O+1|0;Q=O+2|0;N=D;M=c[B>>2]|0;while(1){if((M|0)>0){T=0;while(1){c[f+9376+(T*4608|0)+(O<<7)+(N<<2)>>2]=0;c[f+9376+(T*4608|0)+(I<<7)+(N<<2)>>2]=0;c[f+9376+(T*4608|0)+(Q<<7)+(N<<2)>>2]=0;P=T+1|0;S=c[B>>2]|0;if((P|0)<(S|0)){T=P}else{va=S;break}}}else{va=M}T=N+1|0;if((T|0)<32){N=T;M=va}else{break}}}K=K+3|0;}while((K|0)<12);K=U+1|0;if((K|0)<3){U=K}else{wa=36;break}}}else if((A|0)==3){U=f+36|0;c[(c[f+32940>>2]|0)+424>>2]=(c[U>>2]|0)!=0?576:1152;xa=c[t>>2]|0;ya=c[x>>2]|0;za=U;Aa=112}else if((A|0)==1){c[(c[f+32940>>2]|0)+424>>2]=384;if((c[f+28>>2]|0)==1){A=(c[f+32>>2]<<2)+4|0;if((A|0)>0){Ba=A;Aa=7}else{Ca=0;Da=A;Aa=11}}else{Ba=32;Aa=7}if((Aa|0)==7){A=c[f+24>>2]|0;U=(A|0)>0;va=0;do{if(U){B=c[x>>2]|0;D=0;V=c[t>>2]|0;do{ua=v+(V>>>3)|0;ta=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(V&7)>>>28;ua=V+4|0;V=B>>>0>ua>>>0?ua:B;c[t>>2]=V;a[m+(D<<5)+va|0]=ta;D=D+1|0;}while((D|0)<(A|0))}va=va+1|0;}while((va|0)<(Ba|0));if((Ba|0)<32){Ca=1;Da=Ba;Aa=11}else{Ea=0;Fa=Ba;Ga=A;Aa=17}}do{if((Aa|0)==11){A=f+1096|0;Ba=c[x>>2]|0;va=Da;U=c[t>>2]|0;do{D=v+(U>>>3)|0;V=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(U&7)>>>28;D=U+4|0;U=Ba>>>0>D>>>0?D:Ba;c[t>>2]=U;a[m+va|0]=V;va=va+1|0;}while((va|0)<32);if(!Ca){Ha=0;Ia=Da;Ja=A;Aa=16;break}Ea=1;Fa=Da;Ga=c[f+24>>2]|0;Aa=17}}while(0);if((Aa|0)==17){Da=f+1096|0;Ca=(Ga|0)>0;va=0;do{if(Ca){U=0;do{if((a[m+(U<<5)+va|0]|0)!=0){Ba=c[t>>2]|0;V=c[x>>2]|0;D=v+(Ba>>>3)|0;B=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(Ba&7)>>>26;D=Ba+6|0;c[t>>2]=V>>>0>D>>>0?D:V;a[n+(U<<5)+va|0]=B}U=U+1|0;}while((U|0)<(Ga|0))}va=va+1|0;}while((va|0)<(Fa|0));if(Ea){Ha=1;Ia=Fa;Ja=Da;Aa=16}else{Ka=1;La=Fa;Ma=0;Na=Da}}if((Aa|0)==16){Da=Ia;while(1){if((a[m+Da|0]|0)!=0){Fa=c[t>>2]|0;Ea=c[x>>2]|0;va=c[Ja>>2]|0;Ga=va+(Fa>>>3)|0;Ca=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Fa&7)>>>26;Ga=Fa+6|0;Fa=Ea>>>0>Ga>>>0?Ga:Ea;c[t>>2]=Fa;a[n+Da|0]=Ca;Ca=va+(Fa>>>3)|0;va=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(Fa&7)>>>26;Ca=Fa+6|0;c[t>>2]=Ea>>>0>Ca>>>0?Ca:Ea;a[n+32+Da|0]=va}va=Da+1|0;if((va|0)<32){Da=va}else{Ka=Ha;La=Ia;Ma=1;Na=Ja;break}}}Ja=f+24|0;Ia=0;while(1){if(Ka){Ha=0;Da=c[Ja>>2]|0;while(1){if((Da|0)>0){va=0;while(1){Ea=a[m+(va<<5)+Ha|0]|0;Ca=Ea&255;if(Ea<<24>>24==0){Oa=0}else{Ea=c[t>>2]|0;Fa=c[x>>2]|0;Ga=(c[Na>>2]|0)+(Ea>>>3)|0;U=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ea&7)>>>((31-Ca|0)>>>0);Ga=Ca+1+Ea|0;c[t>>2]=Fa>>>0>Ga>>>0?Ga:Fa;Fa=e[5122320+(d[n+(va<<5)+Ha|0]<<1)>>1]|0;Ga=(-1<<Ca)+1+U|0;U=c[5122008+((Ca-1|0)*12|0)+((Fa&3)<<2)>>2]|0;Ea=Erc(U,(U|0)<0|0?-1:0,Ga,(Ga|0)<0|0?-1:0)|0;Ga=G;U=(Fa>>>2)+Ca|0;Ca=yrc(1,0,U-1|0)|0;Fa=wrc(Ca,G,Ea,Ga)|0;Ga=Arc(Fa|0,G|0,U|0)|0;Oa=Ga}c[f+9376+(va*4608|0)+(Ia<<7)+(Ha<<2)>>2]=Oa;Ga=va+1|0;U=c[Ja>>2]|0;if((Ga|0)<(U|0)){va=Ga}else{Pa=U;break}}}else{Pa=Da}va=Ha+1|0;if((va|0)<(La|0)){Ha=va;Da=Pa}else{break}}}if(Ma){Da=La;do{Ha=a[m+Da|0]|0;va=Ha&255;if(Ha<<24>>24==0){c[f+9376+(Ia<<7)+(Da<<2)>>2]=0;c[f+13984+(Ia<<7)+(Da<<2)>>2]=0}else{Ha=c[t>>2]|0;U=c[x>>2]|0;Ga=(c[Na>>2]|0)+(Ha>>>3)|0;Fa=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7)>>>((31-va|0)>>>0);Ga=va+1+Ha|0;c[t>>2]=U>>>0>Ga>>>0?Ga:U;U=e[5122320+(d[n+Da|0]<<1)>>1]|0;Ga=(-1<<va)+1+Fa|0;Fa=Ga;Ha=(Ga|0)<0|0?-1:0;Ga=va-1|0;Ea=c[5122008+(Ga*12|0)+((U&3)<<2)>>2]|0;Ca=Erc(Ea,(Ea|0)<0|0?-1:0,Fa,Ha)|0;Ea=G;A=(U>>>2)+va|0;U=yrc(1,0,A-1|0)|0;B=wrc(U,G,Ca,Ea)|0;Ea=Arc(B|0,G|0,A|0)|0;c[f+9376+(Ia<<7)+(Da<<2)>>2]=Ea;Ea=e[5122320+(d[n+32+Da|0]<<1)>>1]|0;A=c[5122008+(Ga*12|0)+((Ea&3)<<2)>>2]|0;Ga=Erc(A,(A|0)<0|0?-1:0,Fa,Ha)|0;Ha=G;Fa=(Ea>>>2)+va|0;va=yrc(1,0,Fa-1|0)|0;Ea=wrc(va,G,Ga,Ha)|0;Ha=Arc(Ea|0,G|0,Fa|0)|0;c[f+13984+(Ia<<7)+(Da<<2)>>2]=Ha}Da=Da+1|0;}while((Da|0)<32)}Da=Ia+1|0;if((Da|0)<12){Ia=Da}else{wa=12;break}}}else{xa=z;ya=w;za=f+36|0;Aa=112}do{if((Aa|0)==112){w=(c[za>>2]|0)==0;z=v+(xa>>>3)|0;Ia=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(xa&7);do{if(w){z=Ia>>>23;n=xa+9|0;Na=ya>>>0>n>>>0?n:ya;c[t>>2]=Na;n=c[f+24>>2]|0;if((n|0)==2){m=Na+3|0;La=ya>>>0>m>>>0?m:ya;c[t>>2]=La;Qa=0;Ra=La}else{La=Na+5|0;Na=ya>>>0>La>>>0?La:ya;c[t>>2]=Na;if((n|0)>0){Qa=0;Ra=Na}else{Sa=2;Ta=z;Ua=n;break}}while(1){a[f+23200+(Qa*4864|0)|0]=0;Na=v+(Ra>>>3)|0;La=(je(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(Ra&7)>>>28;Na=Ra+4|0;m=ya>>>0>Na>>>0?Na:ya;c[t>>2]=m;a[f+23200+(Qa*4864|0)+2432|0]=La;La=Qa+1|0;if((La|0)<(n|0)){Qa=La;Ra=m}else{Sa=2;Ta=z;Ua=n;break}}}else{n=xa+8|0;z=c[f+24>>2]|0;m=z+(ya>>>0>n>>>0?n:ya)|0;c[t>>2]=ya>>>0>m>>>0?m:ya;Sa=1;Ta=Ia>>>24;Ua=z}}while(0);Ia=f+24|0;w=f+32|0;z=f+16|0;m=f+32940|0;n=0;La=Ua;Na=ya;Ma=v;a:while(1){if((La|0)>0){Pa=0;Ja=Na;Oa=Ma;while(1){Ka=c[t>>2]|0;Da=Oa+(Ka>>>3)|0;Ha=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Ka&7)>>>20;Da=Ka+12|0;Ka=Ja>>>0>Da>>>0?Da:Ja;c[t>>2]=Ka;c[f+23200+(Pa*4864|0)+(n*2432|0)+4>>2]=Ha;Ha=Oa+(Ka>>>3)|0;Da=(je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ka&7);Ha=Da>>>23;Fa=Ka+9|0;Ka=Ja>>>0>Fa>>>0?Fa:Ja;c[t>>2]=Ka;c[f+23200+(Pa*4864|0)+(n*2432|0)+8>>2]=Ha;if(Da>>>0>2424307711>>>0){Aa=121;break a}Da=Oa+(Ka>>>3)|0;Fa=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Ka&7)>>>24;Da=Ka+8|0;Ka=Ja>>>0>Da>>>0?Da:Ja;c[t>>2]=Ka;Da=f+23200+(Pa*4864|0)+(n*2432|0)+12|0;c[Da>>2]=Fa;if((c[w>>2]&3|0)==2){c[Da>>2]=Fa-2}Fa=c[za>>2]|0;Da=Oa+(Ka>>>3)|0;Ea=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Ka&7);if((Fa|0)==0){Da=Ka+4|0;Ga=Ja>>>0>Da>>>0?Da:Ja;c[t>>2]=Ga;c[f+23200+(Pa*4864|0)+(n*2432|0)+16>>2]=Ea>>>28;Va=Ga}else{Ga=Ka+9|0;Ka=Ja>>>0>Ga>>>0?Ga:Ja;c[t>>2]=Ka;c[f+23200+(Pa*4864|0)+(n*2432|0)+16>>2]=Ea>>>23;Va=Ka}Ka=d[Oa+(Va>>>3)|0]|0;Ea=((Va|0)<(Ja|0))+Va|0;c[t>>2]=Ea;if((Ka&128>>>((Va&7)>>>0)|0)==0){a[f+23200+(Pa*4864|0)+(n*2432|0)+20|0]=0;a[f+23200+(Pa*4864|0)+(n*2432|0)+21|0]=0;Ka=Oa+(Ea>>>3)|0;Ga=(je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ea&7)>>>27;Ka=Ea+5|0;Da=Ja>>>0>Ka>>>0?Ka:Ja;c[t>>2]=Da;c[f+23200+(Pa*4864|0)+(n*2432|0)+24>>2]=Ga;Ga=Oa+(Da>>>3)|0;Ka=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Da&7)>>>27;Ga=Da+5|0;Da=Ja>>>0>Ga>>>0?Ga:Ja;c[t>>2]=Da;c[f+23200+(Pa*4864|0)+(n*2432|0)+28>>2]=Ka;Ka=Oa+(Da>>>3)|0;Ga=(je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Da&7)>>>27;Ka=Da+5|0;Da=Ja>>>0>Ka>>>0?Ka:Ja;c[t>>2]=Da;c[f+23200+(Pa*4864|0)+(n*2432|0)+32>>2]=Ga;Ga=Oa+(Da>>>3)|0;Ka=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Da&7)>>>28;Ga=Da+4|0;Da=Ja>>>0>Ga>>>0?Ga:Ja;c[t>>2]=Da;Ga=Oa+(Da>>>3)|0;va=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Da&7)>>>29;Ga=Da+3|0;c[t>>2]=Ja>>>0>Ga>>>0?Ga:Ja;Ga=c[z>>2]|0;Da=(e[9903568+(Ga*46|0)+(Ka+1<<1)>>1]|0)>>>1;A=f+23200+(Pa*4864|0)+(n*2432|0)+52|0;c[A>>2]=Da;B=Ka+2+va|0;va=(e[9903568+(Ga*46|0)+(((B|0)>22?22:B)<<1)>>1]|0)>>>1;c[f+23200+(Pa*4864|0)+(n*2432|0)+56>>2]=va;Wa=Da;Xa=va;Ya=0;Za=0;_a=Ga;$a=A}else{A=Oa+(Ea>>>3)|0;Ga=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(Ea&7)>>>30;A=Ea+2|0;Ea=Ja>>>0>A>>>0?A:Ja;c[t>>2]=Ea;A=Ga&255;a[f+23200+(Pa*4864|0)+(n*2432|0)+20|0]=A;if((Ga|0)==0){Aa=129;break a}Ga=d[Oa+(Ea>>>3)|0]<<(Ea&7)>>>7;va=((Ea|0)<(Ja|0))+Ea|0;c[t>>2]=va;Ea=Ga&1;a[f+23200+(Pa*4864|0)+(n*2432|0)+21|0]=Ea;Ga=Oa+(va>>>3)|0;Da=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(va&7)>>>27;Ga=va+5|0;va=Ja>>>0>Ga>>>0?Ga:Ja;c[t>>2]=va;c[f+23200+(Pa*4864|0)+(n*2432|0)+24>>2]=Da;Da=Oa+(va>>>3)|0;Ga=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(va&7)>>>27;Da=va+5|0;va=Ja>>>0>Da>>>0?Da:Ja;c[t>>2]=va;c[f+23200+(Pa*4864|0)+(n*2432|0)+28>>2]=Ga;Ga=Oa+(va>>>3)|0;Da=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(va&7)>>>29;Ga=va+3|0;va=Ja>>>0>Ga>>>0?Ga:Ja;c[t>>2]=va;c[f+23200+(Pa*4864|0)+(n*2432|0)+36>>2]=Da;Da=Oa+(va>>>3)|0;Ga=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(va&7)>>>29;Da=va+3|0;va=Ja>>>0>Da>>>0?Da:Ja;c[t>>2]=va;c[f+23200+(Pa*4864|0)+(n*2432|0)+40>>2]=Ga;Ga=(c[j>>2]|0)+(va>>>3)|0;Da=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(va&7)>>>29;Ga=va+3|0;c[t>>2]=Ja>>>0>Ga>>>0?Ga:Ja;c[f+23200+(Pa*4864|0)+(n*2432|0)+44>>2]=Da;Da=c[z>>2]|0;Ga=A<<24>>24==2;do{if(Ga){A=f+23200+(Pa*4864|0)+(n*2432|0)+52|0;if((Da|0)==8){c[A>>2]=36;ab=36;break}else{c[A>>2]=18;ab=18;break}}else{if((Da|0)<3){c[f+23200+(Pa*4864|0)+(n*2432|0)+52>>2]=18;ab=18;break}A=f+23200+(Pa*4864|0)+(n*2432|0)+52|0;if((Da|0)==8){c[A>>2]=54;ab=54;break}else{c[A>>2]=27;ab=27;break}}}while(0);c[f+23200+(Pa*4864|0)+(n*2432|0)+56>>2]=288;Wa=ab;Xa=288;Ya=Ga;Za=Ea;_a=Da;$a=f+23200+(Pa*4864|0)+(n*2432|0)+52|0}A=(Wa|0)>(Ha|0)?Ha:Wa;c[$a>>2]=A;va=Xa>>>0>Ha>>>0?Ha:Xa;c[f+23200+(Pa*4864|0)+(n*2432|0)+56>>2]=va-A;c[f+23200+(Pa*4864|0)+(n*2432|0)+60>>2]=(Ha>>>0<288>>>0?Ha:288)-va;do{if(Ya){if(Za<<24>>24==0){c[f+23200+(Pa*4864|0)+(n*2432|0)+72>>2]=0;c[f+23200+(Pa*4864|0)+(n*2432|0)+68>>2]=0;bb=Fa;break}if((_a|0)==8){QIb(c[m>>2]|0,2389072,(cb=i,i=i+1|0,i=i+7&-8,c[cb>>2]=0,cb)|0);i=cb;db=c[z>>2]|0;eb=c[za>>2]|0}else{db=_a;eb=Fa}c[f+23200+(Pa*4864|0)+(n*2432|0)+72>>2]=(db|0)<3?8:6;c[f+23200+(Pa*4864|0)+(n*2432|0)+68>>2]=3;bb=eb}else{c[f+23200+(Pa*4864|0)+(n*2432|0)+68>>2]=13;c[f+23200+(Pa*4864|0)+(n*2432|0)+72>>2]=22;bb=Fa}}while(0);Fa=f+23200+(Pa*4864|0)+(n*2432|0)+64|0;c[Fa>>2]=0;Ha=c[t>>2]|0;if((bb|0)==0){Da=c[j>>2]|0;Ea=d[Da+(Ha>>>3)|0]<<(Ha&7)>>>7;Ga=c[x>>2]|0;va=((Ha|0)<(Ga|0))+Ha|0;c[t>>2]=va;c[Fa>>2]=Ea&1;fb=va;gb=Da;hb=Ga}else{fb=Ha;gb=c[j>>2]|0;hb=c[x>>2]|0}Ha=d[gb+(fb>>>3)|0]<<(fb&7)>>>7;c[t>>2]=((fb|0)<(hb|0))+fb;a[f+23200+(Pa*4864|0)+(n*2432|0)+48|0]=Ha&1;Ha=c[t>>2]|0;Ga=d[gb+(Ha>>>3)|0]<<(Ha&7)>>>7;c[t>>2]=((Ha|0)<(hb|0))+Ha;a[f+23200+(Pa*4864|0)+(n*2432|0)+49|0]=Ga&1;Ga=Pa+1|0;Ha=c[Ia>>2]|0;if((Ga|0)<(Ha|0)){Pa=Ga;Ja=hb;Oa=gb}else{ib=Ha;jb=hb;kb=gb;break}}}else{ib=La;jb=Na;kb=Ma}Oa=n+1|0;if((Oa|0)<(Sa|0)){n=Oa;La=ib;Na=jb;Ma=kb}else{Aa=153;break}}if((Aa|0)==121){KIb(c[m>>2]|0,16,2419840,(cb=i,i=i+1|0,i=i+7&-8,c[cb>>2]=0,cb)|0);i=cb;lb=-1094995529}else if((Aa|0)==129){KIb(c[m>>2]|0,16,2410624,(cb=i,i=i+1|0,i=i+7&-8,c[cb>>2]=0,cb)|0);i=cb;lb=-1094995529}else if((Aa|0)==153){do{if((c[f+32928>>2]|0)==0){Ma=c[t>>2]|0;Na=(c[u>>2]|0)-Ma>>3;if((Na|0)<0){mb=0}else{mb=(Na|0)>24?24:Na}Na=f+40|0;La=f+1088|0;nrc((c[La>>2]|0)+(f+40)|0,kb+(Ma>>3)|0,mb)|0;Ma=f+1116|0;n=Ma;Oa=s;c[n>>2]=c[Oa>>2];c[n+4>>2]=c[Oa+4>>2];c[n+8>>2]=c[Oa+8>>2];c[n+12>>2]=c[Oa+12>>2];c[n+16>>2]=c[Oa+16>>2];Ja=c[La>>2]|0;Pa=Ja<<3;Ha=Pa>>>0>2147483639>>>0|(Na|0)==0;Ga=Ha?0:Na;Na=Ha?0:Pa;c[j>>2]=Ga;c[u>>2]=Na;c[y>>2]=Ga+(Na>>3);c[t>>2]=0;Ga=1048-Ja|0;c[x>>2]=Na+8+(((mb|0)>(Ga|0)?mb:Ga)<<3);c[La>>2]=Pa;Ga=0;Na=Pa;while(1){if((Na>>3|0)>=(Ta|0)){nb=Ga;ob=Na;break}if((c[Ia>>2]|0)>0){Pa=Ga*18|0;Ja=0;Ha=Na;while(1){c[La>>2]=(c[f+23200+(Ja*4864|0)+(Ga*2432|0)+4>>2]|0)+Ha;mrc(f+23200+(Ja*4864|0)+(Ga*2432|0)+128|0,0,2304)|0;BSa(f,f+23200+(Ja*4864|0)+(Ga*2432|0)|0,f+9376+(Ja*4608|0)+(Pa<<7)|0,f+18592+(Ja*2304|0)|0);Da=Ja+1|0;va=c[La>>2]|0;if((Da|0)<(c[Ia>>2]|0)){Ja=Da;Ha=va}else{pb=va;break}}}else{pb=Na}Ha=Ga+1|0;if((Ha|0)<(Sa|0)){Ga=Ha;Na=pb}else{nb=Ha;ob=pb;break}}Na=ob-(Ta<<3)|0;Ga=c[u>>2]|0;do{if((Na|0)<(Ga|0)){Aa=168}else{La=Ma|0;if((c[La>>2]|0)==0){Aa=168;break}Ha=Na-Ga|0;Ja=f+1124|0;Pa=c[Ja>>2]|0;va=-Pa|0;Da=(c[f+1132>>2]|0)-Pa|0;if((Ha|0)<(va|0)){qb=va}else{qb=(Da|0)<(Ha|0)?Da:Ha}c[Ja>>2]=qb+Pa;c[Oa>>2]=c[n>>2];c[Oa+4>>2]=c[n+4>>2];c[Oa+8>>2]=c[n+8>>2];c[Oa+12>>2]=c[n+12>>2];c[Oa+16>>2]=c[n+16>>2];c[La>>2]=0}}while(0);if((Aa|0)==168){Ga=c[t>>2]|0;La=-Ga|0;Pa=(c[x>>2]|0)-Ga|0;if((Na|0)<(La|0)){rb=La}else{rb=(Pa|0)<(Na|0)?Pa:Na}c[t>>2]=rb+Ga}if((nb|0)>=(Sa|0)){break}sb=nb;tb=c[Ia>>2]|0;ub=Ma;vb=Oa;wb=n;Aa=173}else{Ga=f+1116|0;sb=0;tb=ib;ub=Ga;vb=s;wb=Ga;Aa=173}}while(0);if((Aa|0)==173){Ga=f+28|0;Pa=o|0;La=o+4|0;Ja=o+8|0;Ha=p;Da=p|0;va=q|0;Ea=ub|0;Fa=f+32936|0;A=r|0;B=r+12|0;Ka=r+8|0;Ca=r+4|0;U=sb;V=0;D=tb;while(1){Ba=V+sb|0;if((D|0)>0){ta=0;ua=c[t>>2]|0;while(1){sa=f+23200+(ta*4864|0)+(Ba*2432|0)+76|0;do{if((c[za>>2]|0)==0){ra=c[f+23200+(ta*4864|0)+(U*2432|0)+16>>2]|0;qa=a[564456+ra|0]|0;pa=qa&255;J=a[564472+ra|0]|0;ra=J&255;if((a[f+23200+(ta*4864|0)+(U*2432|0)+20|0]|0)==2){E=(a[f+23200+(ta*4864|0)+(U*2432|0)+21|0]|0)!=0?17:18;b:do{if(qa<<24>>24==0){mrc(sa|0,0,E|0)|0}else{l=32-pa|0;C=0;ka=ua;while(1){L=c[x>>2]|0;ja=(c[j>>2]|0)+(ka>>>3)|0;ia=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ka&7)>>>(l>>>0);ja=ka+pa|0;c[t>>2]=L>>>0>ja>>>0?ja:L;L=C+1|0;a[f+23200+(ta*4864|0)+(U*2432|0)+76+C|0]=ia;if((L|0)>=(E|0)){break b}C=L;ka=c[t>>2]|0}}}while(0);if(J<<24>>24==0){mrc(f+23200+(ta*4864|0)+(Ba*2432|0)+76+E|0,0,21)|0;break}qa=32-ra|0;ka=E;C=0;while(1){l=c[t>>2]|0;L=c[x>>2]|0;ia=(c[j>>2]|0)+(l>>>3)|0;ja=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(l&7)>>>(qa>>>0);ia=l+ra|0;c[t>>2]=L>>>0>ia>>>0?ia:L;a[f+23200+(ta*4864|0)+(U*2432|0)+76+ka|0]=ja;ja=C+1|0;if((ja|0)<18){ka=ka+1|0;C=ja}else{break}}mrc(E+18+(f+23200+(ta*4864|0)+(Ba*2432|0)+76)|0,0,3)|0;break}else{C=f+23200+(ta*4864|0)+(U*2432|0)|0;ka=0;qa=0;while(1){J=(ka|0)==0?6:5;c:do{if((d[C]&8>>>(ka>>>0)|0)==0){ja=(ka|0)<2?pa:ra;if((ja|0)==0){mrc(f+23200+(ta*4864|0)+(Ba*2432|0)+76+qa|0,0,J|0)|0;break}L=32-ja|0;ia=qa;l=1;while(1){F=c[t>>2]|0;K=c[x>>2]|0;H=(c[j>>2]|0)+(F>>>3)|0;M=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>(L>>>0);H=F+ja|0;c[t>>2]=K>>>0>H>>>0?H:K;a[f+23200+(ta*4864|0)+(U*2432|0)+76+ia|0]=M;if((l|0)>=(J|0)){break c}ia=ia+1|0;l=l+1|0}}else{l=qa;ia=0;while(1){a[f+23200+(ta*4864|0)+(U*2432|0)+76+l|0]=a[f+23200+(ta*4864|0)+76+l|0]|0;ja=ia+1|0;if((ja|0)<(J|0)){l=l+1|0;ia=ja}else{break}}}}while(0);ia=ka+1|0;if((ia|0)<4){ka=ia;qa=J+qa|0}else{break}}a[f+23200+(ta*4864|0)+(U*2432|0)+97|0]=0;break}}else{if((a[f+23200+(ta*4864|0)+(U*2432|0)+20|0]|0)==2){xb=(a[f+23200+(ta*4864|0)+(U*2432|0)+21|0]|0)!=0?2:1}else{xb=0}qa=c[f+23200+(ta*4864|0)+(U*2432|0)+16>>2]|0;do{if((c[w>>2]&1|0)!=0&(ta|0)==1){ka=qa>>1;if((ka|0)<180){c[B>>2]=0;ra=(ka*171|0)>>10;c[Ka>>2]=(ra*-6|0)+ka;pa=(ra*171|0)>>10;c[Ca>>2]=(pa*-6|0)+ra;c[A>>2]=pa;yb=3;zb=pa;break}if((ka|0)<244){pa=ka-180|0;c[B>>2]=0;c[Ka>>2]=pa&3;c[Ca>>2]=pa>>>2&3;ra=pa>>4;c[A>>2]=ra;yb=4;zb=ra;break}else{ra=ka-244|0;c[B>>2]=0;c[Ka>>2]=0;ka=(ra*171|0)>>9;c[Ca>>2]=(ka*-3|0)+ra;c[A>>2]=ka;yb=5;zb=ka;break}}else{if((qa|0)<400){c[B>>2]=qa&3;c[Ka>>2]=qa>>>2&3;ka=qa>>4;ra=(ka*205|0)>>10;c[Ca>>2]=(ra*-5|0)+ka;c[A>>2]=ra;yb=0;zb=ra;break}if((qa|0)<500){ra=qa-400|0;c[B>>2]=0;c[Ka>>2]=ra&3;ka=ra>>2;ra=(ka*205|0)>>10;c[Ca>>2]=(ra*-5|0)+ka;c[A>>2]=ra;yb=1;zb=ra;break}else{ra=qa-500|0;c[B>>2]=0;c[Ka>>2]=0;ka=(ra*171|0)>>9;c[Ca>>2]=(ka*-3|0)+ra;c[A>>2]=ka;c[f+23200+(ta*4864|0)+(U*2432|0)+64>>2]=1;yb=2;zb=ka;break}}}while(0);qa=0;ka=0;ra=zb;while(1){pa=a[884392+(yb*12|0)+(xb<<2)+qa|0]|0;C=pa&255;E=pa<<24>>24==0;do{if((ra|0)==0){if(E){Ab=ka;break}pa=C>>>0>1>>>0?C:1;mrc(f+23200+(ta*4864|0)+(Ba*2432|0)+76+ka|0,0,pa|0)|0;Ab=pa+ka|0}else{if(E){Ab=ka;break}pa=32-ra|0;ia=C>>>0>1>>>0;l=ka;ja=1;while(1){L=c[t>>2]|0;M=c[x>>2]|0;K=(c[j>>2]|0)+(L>>>3)|0;H=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(L&7)>>>(pa>>>0);K=L+ra|0;c[t>>2]=M>>>0>K>>>0?K:M;a[f+23200+(ta*4864|0)+(U*2432|0)+76+l|0]=H;if((ja|0)>=(C|0)){break}l=l+1|0;ja=ja+1|0}Ab=(ia?C:1)+ka|0}}while(0);C=qa+1|0;if((C|0)>=4){break}qa=C;ka=Ab;ra=c[r+(C<<2)>>2]|0}if((Ab|0)>=40){break}mrc(f+23200+(ta*4864|0)+(Ba*2432|0)+76+Ab|0,0,40-Ab|0)|0}}while(0);sa=c[z>>2]|0;ra=c[f+23200+(ta*4864|0)+(U*2432|0)+12>>2]|0;ka=(d[f+23200+(ta*4864|0)+(U*2432|0)+48|0]|0)+1|0;qa=c[f+23200+(ta*4864|0)+(U*2432|0)+64>>2]|0;C=c[f+23200+(ta*4864|0)+(U*2432|0)+72>>2]|0;if((C|0)>0){E=ra+190|0;J=0;ja=va;while(1){l=a[1960072+(sa*22|0)+J|0]|0;if(l<<24>>24==0){Bb=ja}else{pa=l&255;l=E-((d[f+23200+(ta*4864|0)+(U*2432|0)+76+J|0]|0)+(d[812344+(qa*22|0)+J|0]|0)<<ka)&65535;H=-pa|0;M=pa;K=ja;while(1){b[K>>1]=l;L=M-1|0;if((L|0)>0){M=L;K=K+2|0}else{break}}Bb=ja+(pa+1+((H|0)>-1?H:-1)<<1)|0}K=J+1|0;if((K|0)<(C|0)){J=K;ja=Bb}else{Cb=Bb;break}}}else{Cb=va}ja=c[f+23200+(ta*4864|0)+(U*2432|0)+68>>2]|0;if((ja|0)<13){J=ra+190|0;qa=J-(c[f+23200+(ta*4864|0)+(U*2432|0)+36>>2]<<3)|0;E=J-(c[f+23200+(ta*4864|0)+(U*2432|0)+40>>2]<<3)|0;K=J-(c[f+23200+(ta*4864|0)+(U*2432|0)+44>>2]<<3)|0;J=ja;ja=C;M=Cb;while(1){l=a[1959752+(sa*13|0)+J|0]|0;L=l&255;F=-L|0;N=(F|0)>-1?F:-1;F=ja+1|0;if(l<<24>>24==0){Db=M}else{l=qa-(d[f+23200+(ta*4864|0)+(U*2432|0)+76+ja|0]<<ka)&65535;Q=L;I=M;while(1){b[I>>1]=l;O=Q-1|0;if((O|0)>0){Q=O;I=I+2|0}else{break}}I=L+1+N|0;Q=E-(d[f+23200+(ta*4864|0)+(U*2432|0)+76+F|0]<<ka)&65535;l=L;H=M+(I<<1)|0;while(1){b[H>>1]=Q;pa=l-1|0;if((pa|0)>0){l=pa;H=H+2|0}else{break}}H=I<<1;l=K-(d[ja+2+(f+23200+(ta*4864|0)+(U*2432|0)+76)|0]<<ka)&65535;Q=L;F=M+(H<<1)|0;while(1){b[F>>1]=l;N=Q-1|0;if((N|0)>0){Q=N;F=F+2|0}else{break}}Db=M+(H+I<<1)|0}F=J+1|0;if((F|0)<13){J=F;ja=ja+3|0;M=Db}else{break}}}M=(c[f+23200+(ta*4864|0)+(U*2432|0)+4>>2]|0)+ua|0;ja=c[u>>2]|0;J=M;ka=(ja|0)<(M|0)?ja:M;M=0;ja=0;while(1){K=c[f+23200+(ta*4864|0)+(U*2432|0)+52+(M<<2)>>2]|0;d:do{if((K|0)==0){Eb=ja;Fb=ka;Gb=J}else{E=c[f+23200+(ta*4864|0)+(U*2432|0)+24+(M<<2)>>2]|0;qa=d[821192+(E<<1)|0]|0;sa=d[821193+(E<<1)|0]|0;if((16401>>>(E>>>0)&1|0)!=0){mrc(f+23200+(ta*4864|0)+(U*2432|0)+128+(ja<<2)|0,0,K<<3|0)|0;Eb=(K<<1)+ja|0;Fb=ka;Gb=J;break}if((K|0)<=0){Eb=ja;Fb=ka;Gb=J;break}C=5945924+(qa*20|0)|0;qa=E>>>0<16>>>0;E=32-sa|0;ra=J;F=ka;Q=K;l=ja;while(1){L=c[t>>2]|0;if((L|0)<(F|0)){Hb=F;Ib=ra;Jb=L}else{do{if((c[Ea>>2]|0)==0){Kb=L;Lb=F;Mb=ra}else{if((L|0)<(c[u>>2]|0)){Kb=L;Lb=F;Mb=ra;break}c[vb>>2]=c[wb>>2];c[vb+4>>2]=c[wb+4>>2];c[vb+8>>2]=c[wb+8>>2];c[vb+12>>2]=c[wb+12>>2];c[vb+16>>2]=c[wb+16>>2];c[Ea>>2]=0;N=L-F|0;pa=c[t>>2]|0;O=-pa|0;T=(c[x>>2]|0)-pa|0;if((N|0)<(O|0)){Nb=O}else{Nb=(T|0)<(N|0)?T:N}N=Nb+pa|0;c[t>>2]=N;pa=N+(ra-L)|0;Kb=N;Lb=pa;Mb=pa}}while(0);if((Kb|0)<(Lb|0)){Hb=Lb;Ib=Mb;Jb=Kb}else{Eb=l;Fb=Lb;Gb=Mb;break d}}L=c[C>>2]|0;ia=c[x>>2]|0;pa=c[j>>2]|0;N=pa+(Jb>>>3)|0;T=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Jb&7)>>>25;N=b[L+(T<<2)>>1]|0;O=b[L+(T<<2)+2>>1]|0;T=O<<16>>16;do{if(O<<16>>16<0){R=Jb+7|0;S=ia>>>0>R>>>0?R:ia;R=pa+(S>>>3)|0;P=((je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(S&7)>>>((T+32|0)>>>0))+N|0;R=b[L+(P<<2)>>1]|0;W=b[L+(P<<2)+2>>1]|0;P=W<<16>>16;if(!(W<<16>>16<0)){Ob=P;Pb=R;Qb=S;break}W=S-T|0;S=ia>>>0>W>>>0?W:ia;W=pa+(S>>>3)|0;Z=((je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(S&7)>>>((P+32|0)>>>0))+R|0;Ob=b[L+(Z<<2)+2>>1]|0;Pb=b[L+(Z<<2)>>1]|0;Qb=S}else{Ob=T;Pb=N;Qb=Jb}}while(0);N=Ob+Qb|0;T=ia>>>0>N>>>0?N:ia;c[t>>2]=T;do{if((Pb|0)==0){c[f+23200+(ta*4864|0)+(U*2432|0)+128+(l+1<<2)>>2]=0;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(l<<2)>>2]=0}else{N=b[q+(l<<1)>>1]|0;L=Pb>>5;O=Pb&15;if((Pb&16|0)==0){S=L+O|0;if((S|0)<15){Z=d[pa+(T>>>3)|0]<<(T&7)>>>7;c[t>>2]=((T|0)<(ia|0))+T;R=Z&1;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(((O|0)!=0)+l<<2)>>2]=(c[8938104+(N<<6)+(S<<2)>>2]^-R)+R}else{if(qa){Rb=0;Sb=T}else{R=pa+(T>>>3)|0;Z=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(T&7)>>>(E>>>0);R=T+sa|0;P=ia>>>0>R>>>0?R:ia;c[t>>2]=P;Rb=Z;Sb=P}P=Rb+S<<2|N&3;S=(a[5050632+P|0]|0)-(N>>2)|0;if((S|0)>31){Tb=0}else{Tb=((c[4886488+(P<<2)>>2]|0)+(1<<S-1)|0)>>>(S>>>0)}S=d[pa+(Sb>>>3)|0]|0;c[t>>2]=((Sb|0)<(ia|0))+Sb;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(((O|0)!=0)+l<<2)>>2]=(S&128>>>((Sb&7)>>>0)|0)==0?Tb:-Tb|0}c[f+23200+(ta*4864|0)+(U*2432|0)+128+(((O|0)==0)+l<<2)>>2]=0;break}if((L|0)<15){S=d[pa+(T>>>3)|0]<<(T&7)>>>7;c[t>>2]=((T|0)<(ia|0))+T;P=S&1;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(l<<2)>>2]=(c[8938104+(N<<6)+(L<<2)>>2]^-P)+P}else{if(qa){Ub=0;Vb=T}else{P=pa+(T>>>3)|0;S=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(T&7)>>>(E>>>0);P=T+sa|0;Z=ia>>>0>P>>>0?P:ia;c[t>>2]=Z;Ub=S;Vb=Z}Z=Ub+L<<2|N&3;L=(a[5050632+Z|0]|0)-(N>>2)|0;if((L|0)>31){Wb=0}else{Wb=((c[4886488+(Z<<2)>>2]|0)+(1<<L-1)|0)>>>(L>>>0)}L=d[pa+(Vb>>>3)|0]|0;c[t>>2]=((Vb|0)<(ia|0))+Vb;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(l<<2)>>2]=(L&128>>>((Vb&7)>>>0)|0)==0?Wb:-Wb|0}if((O|0)!=15){L=c[t>>2]|0;Z=d[pa+(L>>>3)|0]<<(L&7)>>>7;c[t>>2]=((L|0)<(c[x>>2]|0))+L;L=Z&1;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(l+1<<2)>>2]=(c[8938104+(N<<6)+(O<<2)>>2]^-L)+L;break}if(qa){Xb=60}else{L=c[t>>2]|0;O=c[x>>2]|0;Z=pa+(L>>>3)|0;S=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(L&7)>>>(E>>>0);Z=L+sa|0;c[t>>2]=O>>>0>Z>>>0?Z:O;Xb=(S<<2)+60|0}S=Xb|N&3;O=(a[5050632+S|0]|0)-(N>>2)|0;if((O|0)>31){Yb=0}else{Yb=((c[4886488+(S<<2)>>2]|0)+(1<<O-1)|0)>>>(O>>>0)}O=c[t>>2]|0;S=d[pa+(O>>>3)|0]|0;c[t>>2]=((O|0)<(c[x>>2]|0))+O;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(l+1<<2)>>2]=(S&128>>>((O&7)>>>0)|0)==0?Yb:-Yb|0}}while(0);pa=l+2|0;ia=Q-1|0;if((ia|0)>0){ra=Ib;F=Hb;Q=ia;l=pa}else{Eb=pa;Fb=Hb;Gb=Ib;break}}}}while(0);K=M+1|0;if((K|0)<3){J=Gb;ka=Fb;M=K;ja=Eb}else{break}}ja=d[f+23200+(ta*4864|0)+(U*2432|0)+49|0]|0;e:do{if((Eb|0)<573){M=5947500+(ja*20|0)|0;ka=5947496+(ja*20|0)|0;J=Gb;K=Fb;I=0;H=Eb;while(1){Zb=c[t>>2]|0;if((Zb|0)<(K|0)){_b=Zb;$b=K;ac=J}else{if(!((Zb|0)<=(J|0)|(I|0)==0)){break}do{if((c[Ea>>2]|0)==0){bc=Zb;cc=K;dc=J}else{if((Zb|0)<(c[u>>2]|0)){bc=Zb;cc=K;dc=J;break}c[vb>>2]=c[wb>>2];c[vb+4>>2]=c[wb+4>>2];c[vb+8>>2]=c[wb+8>>2];c[vb+12>>2]=c[wb+12>>2];c[vb+16>>2]=c[wb+16>>2];c[Ea>>2]=0;l=Zb-K|0;Q=c[t>>2]|0;F=-Q|0;ra=(c[x>>2]|0)-Q|0;if((l|0)<(F|0)){ec=F}else{ec=(ra|0)<(l|0)?ra:l}l=ec+Q|0;c[t>>2]=l;Q=l+(J-Zb)|0;bc=l;cc=Q;dc=Q}}while(0);if((bc|0)<(cc|0)){_b=bc;$b=cc;ac=dc}else{fc=H;gc=cc;hc=dc;break e}}Q=c[M>>2]|0;l=c[ka>>2]|0;ra=c[x>>2]|0;F=c[j>>2]|0;sa=F+(_b>>>3)|0;E=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(_b&7)>>>((32-l|0)>>>0);l=b[Q+(E<<2)>>1]|0;sa=(b[Q+(E<<2)+2>>1]|0)+_b|0;c[t>>2]=ra>>>0>sa>>>0?sa:ra;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(H+3<<2)>>2]=0;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(H+2<<2)>>2]=0;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(H+1<<2)>>2]=0;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(H<<2)>>2]=0;if(!(l<<16>>16==0)){ra=l<<16>>16;while(1){l=c[1078680+(ra<<2)>>2]|0;sa=l+H|0;E=8>>>(l>>>0);l=c[t>>2]|0;Q=d[F+(l>>>3)|0]<<(l&7)>>>7;c[t>>2]=((l|0)<(c[x>>2]|0))+l;l=Q&1;c[f+23200+(ta*4864|0)+(U*2432|0)+128+(sa<<2)>>2]=(c[8974456+(b[q+(sa<<1)>>1]<<2)>>2]^-l)+l;if((E|0)==(ra|0)){break}else{ra=E^ra}}}ra=H+4|0;if((ra|0)<573){J=ac;K=$b;I=_b;H=ra}else{fc=ra;gc=$b;hc=ac;break e}}ka=I-Zb|0;M=-Zb|0;ra=(c[x>>2]|0)-Zb|0;if((ka|0)<(M|0)){ic=M}else{ic=(ra|0)<(ka|0)?ra:ka}c[t>>2]=ic+Zb;KIb(c[m>>2]|0,32,2402944,(cb=i,i=i+24|0,c[cb>>2]=ka,c[cb+8>>2]=K-Zb,c[cb+16>>2]=J-Zb,cb)|0);i=cb;fc=(c[Fa>>2]&131074|0)==0?H-4|0:0;gc=K;hc=J}else{fc=Eb;gc=Fb;hc=Gb}}while(0);ja=hc-(c[t>>2]|0)|0;do{if((ja|0)<0){if((c[Fa>>2]&131076|0)==0){Aa=305;break}KIb(c[m>>2]|0,16,2396008,(cb=i,i=i+8|0,c[cb>>2]=ja,cb)|0);i=cb;jc=0}else{Aa=305}}while(0);do{if((Aa|0)==305){Aa=0;if((ja|0)<=0){jc=fc;break}if((c[Fa>>2]&262148|0)==0){jc=fc;break}KIb(c[m>>2]|0,16,2396008,(cb=i,i=i+8|0,c[cb>>2]=ja,cb)|0);i=cb;jc=0}}while(0);mrc(f+23200+(ta*4864|0)+(U*2432|0)+128+(jc<<2)|0,0,576-jc<<2|0)|0;ka=c[t>>2]|0;ra=-ka|0;M=(c[x>>2]|0)-ka|0;if((ja|0)<(ra|0)){kc=ra}else{kc=(M|0)<(ja|0)?M:ja}M=kc+ka|0;c[t>>2]=M;do{if((c[Ea>>2]|0)==0){lc=M}else{if((M|0)<(c[u>>2]|0)){lc=M;break}c[vb>>2]=c[wb>>2];c[vb+4>>2]=c[wb+4>>2];c[vb+8>>2]=c[wb+8>>2];c[vb+12>>2]=c[wb+12>>2];c[vb+16>>2]=c[wb+16>>2];c[Ea>>2]=0;ka=M-gc|0;ra=c[t>>2]|0;F=-ra|0;E=(c[x>>2]|0)-ra|0;if((ka|0)<(F|0)){mc=F}else{mc=(E|0)<(ka|0)?E:ka}ka=mc+ra|0;c[t>>2]=ka;lc=ka}}while(0);M=ta+1|0;if((M|0)<(c[Ia>>2]|0)){ta=M;ua=lc}else{break}}}f:do{if((c[Ga>>2]|0)==1){ua=c[w>>2]|0;if((ua&1|0)==0){if((ua&2|0)==0){break}else{nc=0}while(1){ua=f+23200+(U*2432|0)+128+(nc<<2)|0;ta=c[ua>>2]|0;Ba=f+28064+(U*2432|0)+128+(nc<<2)|0;n=c[Ba>>2]|0;c[ua>>2]=n+ta;c[Ba>>2]=ta-n;nc=nc+1|0;if((nc|0)>=576){break f}}}if((c[za>>2]|0)==0){oc=5831320;pc=7}else{oc=5830936+((c[f+28064+(U*2432|0)+16>>2]&1)<<7)|0;pc=16}n=f+23200+(U*2432|0)+2432|0;ta=f+28064+(U*2432|0)+2432|0;c[Pa>>2]=0;c[La>>2]=0;c[Ja>>2]=0;Ba=f+28064+(U*2432|0)+68|0;ua=c[Ba>>2]|0;Oa=f+28064+(U*2432|0)+72|0;if((ua|0)>12){qc=n;rc=ta}else{Ma=12;Na=((13-ua|0)*3|0)-3+(c[Oa>>2]|0)|0;ua=n;n=ta;while(1){ta=(Ma|0)==11?Na:Na-3|0;M=a[1959752+((c[z>>2]|0)*13|0)+Ma|0]|0;ja=M&255;ka=-ja|0;ra=M<<24>>24==0;M=2;E=ua;F=n;while(1){l=E+(ka<<2)|0;sa=F+(ka<<2)|0;Q=o+(M<<2)|0;do{if((c[Q>>2]|0)==0){qa=0;while(1){if((qa|0)>=(ja|0)){break}if((c[F+(qa-ja<<2)>>2]|0)==0){qa=qa+1|0}else{Aa=326;break}}if((Aa|0)==326){Aa=0;c[Q>>2]=1;Aa=331;break}qa=d[M+ta+(f+28064+(U*2432|0)+76)|0]|0;if(!(qa>>>0<pc>>>0)){Aa=331;break}if(ra){break}C=c[oc+64+(qa<<2)>>2]|0;pa=c[oc+(qa<<2)>>2]|0;qa=pa;ia=(pa|0)<0|0?-1:0;pa=C;T=(C|0)<0|0?-1:0;C=0;do{O=C-ja|0;S=E+(O<<2)|0;N=c[S>>2]|0;Z=N;L=(N|0)<0|0?-1:0;N=Erc(Z,L,qa,ia)|0;c[S>>2]=N>>>23|G<<9;N=Erc(Z,L,pa,T)|0;c[F+(O<<2)>>2]=N>>>23|G<<9;C=C+1|0;}while((C|0)<(ja|0))}else{Aa=331}}while(0);do{if((Aa|0)==331){Aa=0;if((c[w>>2]&2|0)==0|ra){break}else{sc=0}do{Q=sc-ja|0;C=E+(Q<<2)|0;T=c[C>>2]|0;pa=F+(Q<<2)|0;Q=c[pa>>2]|0;ia=Q+T|0;qa=Erc(ia,(ia|0)<0|0?-1:0,5931642,0)|0;c[C>>2]=qa>>>23|G<<9;qa=T-Q|0;Q=Erc(qa,(qa|0)<0|0?-1:0,5931642,0)|0;c[pa>>2]=Q>>>23|G<<9;sc=sc+1|0;}while((sc|0)<(ja|0))}}while(0);if((M|0)<=0){break}M=M-1|0;E=l;F=sa}F=ja*-3|0;E=n+(F<<2)|0;M=ua+(F<<2)|0;F=Ma-1|0;if((F|0)<(c[Ba>>2]|0)){qc=M;rc=E;break}else{Ma=F;Na=ta;ua=M;n=E}}}n=c[Oa>>2]|0;if((n|0)<=0){break}ua=c[Pa>>2]|c[La>>2]|c[Ja>>2];Na=qc;Ma=rc;Ba=n;while(1){n=(ua|0)==0;E=Na;M=Ma;F=Ba;g:while(1){tc=F-1|0;uc=a[1960072+((c[z>>2]|0)*22|0)+tc|0]|0;vc=uc&255;ra=-vc|0;wc=E+(ra<<2)|0;xc=M+(ra<<2)|0;if(n){yc=0}else{zc=ua;break}while(1){if((yc|0)>=(vc|0)){break}if((c[M+(yc-vc<<2)>>2]|0)==0){yc=yc+1|0}else{zc=1;break g}}sa=d[((tc|0)==21?20:tc)+(f+28064+(U*2432|0)+76)|0]|0;if(!(sa>>>0<pc>>>0)){zc=ua;break}if(!(uc<<24>>24==0)){l=c[oc+64+(sa<<2)>>2]|0;ra=c[oc+(sa<<2)>>2]|0;sa=ra;ka=(ra|0)<0|0?-1:0;ra=l;J=(l|0)<0|0?-1:0;l=0;do{K=l-vc|0;H=E+(K<<2)|0;I=c[H>>2]|0;Q=I;pa=(I|0)<0|0?-1:0;I=Erc(Q,pa,sa,ka)|0;c[H>>2]=I>>>23|G<<9;I=Erc(Q,pa,ra,J)|0;c[M+(K<<2)>>2]=I>>>23|G<<9;l=l+1|0;}while((l|0)<(vc|0))}if((tc|0)>0){E=wc;M=xc;F=tc}else{break f}}if(!((c[w>>2]&2|0)==0|uc<<24>>24==0)){F=0;do{n=F-vc|0;ta=E+(n<<2)|0;ja=c[ta>>2]|0;l=M+(n<<2)|0;n=c[l>>2]|0;J=n+ja|0;ra=Erc(J,(J|0)<0|0?-1:0,5931642,0)|0;c[ta>>2]=ra>>>23|G<<9;ra=ja-n|0;n=Erc(ra,(ra|0)<0|0?-1:0,5931642,0)|0;c[l>>2]=n>>>23|G<<9;F=F+1|0;}while((F|0)<(vc|0))}if((tc|0)>0){ua=zc;Na=wc;Ma=xc;Ba=tc}else{break}}}}while(0);Ba=c[Ia>>2]|0;if((Ba|0)>0){Ma=U*18|0;Na=0;while(1){ua=f+23200+(Na*4864|0)+(U*2432|0)|0;Oa=f+23200+(Na*4864|0)+(U*2432|0)+20|0;do{if((a[Oa]|0)==2){F=f+23200+(Na*4864|0)+(U*2432|0)+21|0;M=a[F]|0;do{if(M<<24>>24==0){Ac=f+23200+(Na*4864|0)+(U*2432|0)+128|0}else{if((c[z>>2]|0)==8){Ac=f+23200+(Na*4864|0)+(U*2432|0)+416|0;break}else{Ac=f+23200+(Na*4864|0)+(U*2432|0)+272|0;break}}}while(0);E=c[f+23200+(Na*4864|0)+(U*2432|0)+68>>2]|0;if((E|0)<13){n=Ac;l=E;while(1){E=a[1959752+((c[z>>2]|0)*13|0)+l|0]|0;ra=E&255;ja=ra<<1;if(E<<24>>24==0){Bc=n}else{E=-ra|0;ta=ra;J=n;ka=Da;while(1){c[ka>>2]=c[J>>2];c[ka+4>>2]=c[J+(ra<<2)>>2];c[ka+8>>2]=c[J+(ja<<2)>>2];sa=ta-1|0;if((sa|0)>0){ta=sa;J=J+4|0;ka=ka+12|0}else{break}}Bc=n+(ra+1+((E|0)>-1?E:-1)<<2)|0}nrc(n|0,Ha|0,ra*12|0)|0;ka=l+1|0;if((ka|0)>=13){break}n=Bc+(ja<<2)|0;l=ka}if((a[Oa]|0)!=2){Cc=31;Aa=370;break}Dc=a[F]|0}else{Dc=M}if(!(Dc<<24>>24==0)){Cc=1;Aa=370}}else{Cc=31;Aa=370}}while(0);if((Aa|0)==370){Aa=0;Oa=Cc;l=f+23200+(Na*4864|0)+(U*2432|0)+200|0;while(1){n=l-4|0;ka=c[n>>2]|0;J=c[l>>2]|0;ta=J+ka|0;sa=c[2443136]|0;Erc(sa,(sa|0)<0|0?-1:0,ta,(ta|0)<0|0?-1:0)|0;ta=G;sa=c[2443138]|0;Erc(sa,(sa|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[n>>2]=ta-G<<2;n=c[2443139]|0;Erc(n,(n|0)<0|0?-1:0,ka,(ka|0)<0|0?-1:0)|0;c[l>>2]=G+ta<<2;ta=l-8|0;ka=c[ta>>2]|0;n=l+4|0;J=c[n>>2]|0;sa=J+ka|0;I=c[2443140]|0;Erc(I,(I|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0)|0;sa=G;I=c[2443142]|0;Erc(I,(I|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[ta>>2]=sa-G<<2;ta=c[2443143]|0;Erc(ta,(ta|0)<0|0?-1:0,ka,(ka|0)<0|0?-1:0)|0;c[n>>2]=G+sa<<2;sa=l-12|0;n=c[sa>>2]|0;ka=l+8|0;ta=c[ka>>2]|0;J=ta+n|0;I=c[2443144]|0;Erc(I,(I|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;J=G;I=c[2443146]|0;Erc(I,(I|0)<0|0?-1:0,ta,(ta|0)<0|0?-1:0)|0;c[sa>>2]=J-G<<2;sa=c[2443147]|0;Erc(sa,(sa|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;c[ka>>2]=G+J<<2;J=l-16|0;ka=c[J>>2]|0;n=l+12|0;sa=c[n>>2]|0;ta=sa+ka|0;I=c[2443148]|0;Erc(I,(I|0)<0|0?-1:0,ta,(ta|0)<0|0?-1:0)|0;ta=G;I=c[2443150]|0;Erc(I,(I|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0)|0;c[J>>2]=ta-G<<2;J=c[2443151]|0;Erc(J,(J|0)<0|0?-1:0,ka,(ka|0)<0|0?-1:0)|0;c[n>>2]=G+ta<<2;ta=l-20|0;n=c[ta>>2]|0;ka=l+16|0;J=c[ka>>2]|0;sa=J+n|0;I=c[2443152]|0;Erc(I,(I|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0)|0;sa=G;I=c[2443154]|0;Erc(I,(I|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[ta>>2]=sa-G<<2;ta=c[2443155]|0;Erc(ta,(ta|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;c[ka>>2]=G+sa<<2;sa=l-24|0;ka=c[sa>>2]|0;n=l+20|0;ta=c[n>>2]|0;J=ta+ka|0;I=c[2443156]|0;Erc(I,(I|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;J=G;I=c[2443158]|0;Erc(I,(I|0)<0|0?-1:0,ta,(ta|0)<0|0?-1:0)|0;c[sa>>2]=J-G<<2;sa=c[2443159]|0;Erc(sa,(sa|0)<0|0?-1:0,ka,(ka|0)<0|0?-1:0)|0;c[n>>2]=G+J<<2;J=l-28|0;n=c[J>>2]|0;ka=l+24|0;sa=c[ka>>2]|0;ta=sa+n|0;I=c[2443160]|0;Erc(I,(I|0)<0|0?-1:0,ta,(ta|0)<0|0?-1:0)|0;ta=G;I=c[2443162]|0;Erc(I,(I|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0)|0;c[J>>2]=ta-G<<2;J=c[2443163]|0;Erc(J,(J|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;c[ka>>2]=G+ta<<2;ta=l-32|0;ka=c[ta>>2]|0;n=l+28|0;J=c[n>>2]|0;sa=J+ka|0;I=c[2443164]|0;Erc(I,(I|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0)|0;sa=G;I=c[2443166]|0;Erc(I,(I|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[ta>>2]=sa-G<<2;ta=c[2443167]|0;Erc(ta,(ta|0)<0|0?-1:0,ka,(ka|0)<0|0?-1:0)|0;c[n>>2]=G+sa<<2;sa=Oa-1|0;if((sa|0)>0){Oa=sa;l=l+72|0}else{break}}}BSa(f,ua,f+9376+(Na*4608|0)+(Ma<<7)|0,f+18592+(Na*2304|0)|0);l=Na+1|0;Oa=c[Ia>>2]|0;if((l|0)<(Oa|0)){Na=l}else{Ec=Oa;break}}}else{Ec=Ba}Na=U+1|0;if((Na|0)<(Sa|0)){U=Na;V=V+1|0;D=Ec}else{break}}}D=c[t>>2]|0;if((D|0)<0){V=-D|0;U=(c[x>>2]|0)-D|0;c[t>>2]=((U|0)<(V|0)?U:V)+D}lb=Sa*18|0}D=f+1088|0;c[D>>2]=0;V=f+1116|0;U=V|0;if((c[U>>2]|0)!=0){Ia=c[t>>2]|0;Ha=-Ia&7;if((Ha|0)==0){Fc=Ia}else{Da=c[x>>2]|0;z=Ha+Ia|0;Ia=Da>>>0>z>>>0?z:Da;c[t>>2]=Ia;Fc=Ia}Ia=(c[u>>2]|0)-Fc>>3;if(Ia>>>0<513>>>0){orc(f+40|0,(c[j>>2]|0)+(Fc>>3)|0,Ia|0)|0;c[D>>2]=Ia}else{KIb(c[m>>2]|0,16,2478e3,(cb=i,i=i+8|0,c[cb>>2]=Ia,cb)|0);i=cb}Ia=s;Da=V;c[Ia>>2]=c[Da>>2];c[Ia+4>>2]=c[Da+4>>2];c[Ia+8>>2]=c[Da+8>>2];c[Ia+12>>2]=c[Da+12>>2];c[Ia+16>>2]=c[Da+16>>2];c[U>>2]=0}U=c[t>>2]|0;Da=-U&7;if((Da|0)==0){Gc=U}else{Ia=c[x>>2]|0;V=Da+U|0;U=Ia>>>0>V>>>0?V:Ia;c[t>>2]=U;Gc=U}U=(c[u>>2]|0)-Gc>>3;Ia=(lb|0)<0;if(U>>>0>512>>>0|Ia){if((U|0)<0){KIb(c[m>>2]|0,16,2468392,(cb=i,i=i+8|0,c[cb>>2]=U,cb)|0);i=cb}Hc=(h|0)<512?h:512}else{Hc=U}nrc((c[D>>2]|0)+(f+40)|0,(c[j>>2]|0)+(h-Hc)|0,Hc)|0;c[D>>2]=(c[D>>2]|0)+Hc;if(Ia){Ic=lb}else{wa=lb;break}i=k;return Ic|0}}while(0);do{if((g|0)==0){lb=f+33004|0;Hc=c[lb>>2]|0;if((Hc|0)==0){KIb(0,0,2459088,(cb=i,i=i+24|0,c[cb>>2]=2442160,c[cb+8>>2]=2430248,c[cb+16>>2]=1606,cb)|0);i=cb;Hd();return 0}h=c[f+32940>>2]|0;c[Hc+76>>2]=c[h+424>>2];j=M4a(h,Hc,0)|0;if((j|0)<0){Ic=j;i=k;return Ic|0}else{Jc=c[(c[lb>>2]|0)+64>>2]|0;break}}else{Jc=g}}while(0);g=f+24|0;cb=c[g>>2]|0;if((cb|0)>0){lb=f+32940|0;j=(wa|0)>0;Hc=f+32944|0;h=f+32932|0;Gc=0;u=cb;while(1){if((c[(c[lb>>2]|0)+420>>2]|0)==6){Kc=1;Lc=c[Jc+(Gc<<2)>>2]|0}else{Kc=u;Lc=(c[Jc>>2]|0)+(Gc<<1)|0}if(j){t=f+1152+(Gc<<12)|0;x=f+9344+(Gc<<2)|0;s=Kc<<5;Fc=0;Sa=Lc;while(1){RSa(Hc,t,x,7690816,h,Sa,Kc,f+9376+(Gc*4608|0)+(Fc<<7)|0);Ec=Fc+1|0;if((Ec|0)<(wa|0)){Fc=Ec;Sa=Sa+(s<<1)|0}else{break}}Mc=c[g>>2]|0}else{Mc=u}s=Gc+1|0;if((s|0)<(Mc|0)){Gc=s;u=Mc}else{Nc=Mc;break}}}else{Nc=cb}Ic=ca(wa<<6,Nc)|0;i=k;return Ic|0}function BSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+48|0;j=h|0;k=e+128|0;l=e+272|0;m=e+2432|0;while(1){if(m>>>0<l>>>0){n=m;break}o=m-24|0;if((c[m-20>>2]|c[o>>2]|c[m-16>>2]|c[m-12>>2]|c[m-8>>2]|c[m-4>>2]|0)==0){m=o}else{n=o;break}}m=((n-k>>2|0)/18|0)+1|0;n=a[e+20|0]|0;l=e+21|0;if(n<<24>>24==2){p=(a[l]|0)==0?0:2}else{p=m}_e[c[b+32964>>2]&511](f,g,k,p,d[l]|0,n&255);n=g+(((p>>2)*72|0|p&3)<<2)|0;if((p|0)<(m|0)){g=j|0;l=j+40|0;k=j+28|0;b=j+16|0;o=j+4|0;q=j+36|0;r=j+32|0;s=j+12|0;t=j+8|0;u=j+20|0;v=j+44|0;w=j+24|0;x=n;y=p;z=e+128+((p*18|0)<<2)|0;e=f+(p+192<<2)|0;A=f+(p+384<<2)|0;while(1){c[f+(y<<2)>>2]=c[x>>2];c[f+(y+32<<2)>>2]=c[x+16>>2];c[f+(y+64<<2)>>2]=c[x+32>>2];c[f+(y+96<<2)>>2]=c[x+48>>2];c[f+(y+128<<2)>>2]=c[x+64>>2];c[f+(y+160<<2)>>2]=c[x+80>>2];p=-(y&1)&4|2;B=c[z>>2]|0;C=c[z+12>>2]|0;D=C+B|0;E=c[z+24>>2]|0;F=c[z+36>>2]|0;H=F+E|0;I=c[z+48>>2]|0;J=I+F|0;F=H+I+(c[z+60>>2]|0)|0;I=E+C<<1;Erc(I,(I|0)<0|0?-1:0,1859775393,0)|0;I=G;C=H+D<<2;Erc(C,(C|0)<0|0?-1:0,1859775393,0)|0;C=G;H=B-J|0;E=D-F<<1;Erc(E,(E|0)<0|0?-1:0,1518500250,0)|0;E=G;K=E+H|0;c[l>>2]=K;c[k>>2]=K;K=H-E|0;c[b>>2]=K;c[o>>2]=K;K=(J>>1)+B|0;B=I+K|0;J=F+(D<<1)|0;D=C+J|0;Erc(D,(D|0)<0|0?-1:0,1111619334,0)|0;D=G;F=D+B|0;c[q>>2]=F;c[r>>2]=F;F=B-D|0;c[s>>2]=F;c[t>>2]=F;F=K-I|0;I=J-C<<1;Erc(I,(I|0)<0|0?-1:0,2074309917,0)|0;I=G;C=F-I|0;c[u>>2]=C;c[g>>2]=C;J=I+F|0;c[v>>2]=J;c[w>>2]=J;J=0;F=e;I=C;while(1){C=c[7695168+(p*160|0)+(J<<2)>>2]|0;Erc(C,(C|0)<0|0?-1:0,I,(I|0)<0|0?-1:0)|0;C=J+6|0;c[F>>2]=G+(c[x+(C<<2<<2)>>2]|0);K=c[j+(C<<2)>>2]|0;D=c[7695168+(p*160|0)+(C<<2)>>2]|0;Erc(D,(D|0)<0|0?-1:0,K,(K|0)<0|0?-1:0)|0;c[x+((J<<2)+48<<2)>>2]=G;K=J+1|0;if((K|0)>=6){break}J=K;F=F+128|0;I=c[j+(K<<2)>>2]|0}I=c[z+4>>2]|0;F=c[z+16>>2]|0;J=F+I|0;K=c[z+28>>2]|0;D=c[z+40>>2]|0;C=D+K|0;B=c[z+52>>2]|0;E=B+D|0;D=C+B+(c[z+64>>2]|0)|0;B=K+F<<1;Erc(B,(B|0)<0|0?-1:0,1859775393,0)|0;B=G;F=C+J<<2;Erc(F,(F|0)<0|0?-1:0,1859775393,0)|0;F=G;C=I-E|0;K=J-D<<1;Erc(K,(K|0)<0|0?-1:0,1518500250,0)|0;K=G;H=K+C|0;c[l>>2]=H;c[k>>2]=H;H=C-K|0;c[b>>2]=H;c[o>>2]=H;H=(E>>1)+I|0;I=B+H|0;E=D+(J<<1)|0;J=F+E|0;Erc(J,(J|0)<0|0?-1:0,1111619334,0)|0;J=G;D=J+I|0;c[q>>2]=D;c[r>>2]=D;D=I-J|0;c[s>>2]=D;c[t>>2]=D;D=H-B|0;B=E-F<<1;Erc(B,(B|0)<0|0?-1:0,2074309917,0)|0;B=G;F=D-B|0;c[u>>2]=F;c[g>>2]=F;E=B+D|0;c[v>>2]=E;c[w>>2]=E;E=0;D=A;B=F;while(1){F=c[7695168+(p*160|0)+(E<<2)>>2]|0;Erc(F,(F|0)<0|0?-1:0,B,(B|0)<0|0?-1:0)|0;F=E<<2;c[D>>2]=G+(c[x+(F+48<<2)>>2]|0);H=E+6|0;J=c[j+(H<<2)>>2]|0;I=c[7695168+(p*160|0)+(H<<2)>>2]|0;Erc(I,(I|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;c[x+(F<<2)>>2]=G;F=E+1|0;if((F|0)>=6){break}E=F;D=D+128|0;B=c[j+(F<<2)>>2]|0}B=c[z+8>>2]|0;D=c[z+20>>2]|0;E=D+B|0;F=c[z+32>>2]|0;J=c[z+44>>2]|0;I=J+F|0;H=c[z+56>>2]|0;K=H+J|0;J=I+H+(c[z+68>>2]|0)|0;H=F+D<<1;Erc(H,(H|0)<0|0?-1:0,1859775393,0)|0;H=G;D=I+E<<2;Erc(D,(D|0)<0|0?-1:0,1859775393,0)|0;D=G;I=B-K|0;F=E-J<<1;Erc(F,(F|0)<0|0?-1:0,1518500250,0)|0;F=G;C=F+I|0;c[l>>2]=C;c[k>>2]=C;C=I-F|0;c[b>>2]=C;c[o>>2]=C;C=(K>>1)+B|0;B=H+C|0;K=J+(E<<1)|0;E=D+K|0;Erc(E,(E|0)<0|0?-1:0,1111619334,0)|0;E=G;J=E+B|0;c[q>>2]=J;c[r>>2]=J;J=B-E|0;c[s>>2]=J;c[t>>2]=J;J=C-H|0;H=K-D<<1;Erc(H,(H|0)<0|0?-1:0,2074309917,0)|0;H=G;D=J-H|0;c[u>>2]=D;c[g>>2]=D;K=H+J|0;c[v>>2]=K;c[w>>2]=K;K=0;J=D;while(1){D=c[7695168+(p*160|0)+(K<<2)>>2]|0;Erc(D,(D|0)<0|0?-1:0,J,(J|0)<0|0?-1:0)|0;D=K<<2;H=x+(D<<2)|0;c[H>>2]=G+(c[H>>2]|0);H=K+6|0;C=c[j+(H<<2)>>2]|0;E=c[7695168+(p*160|0)+(H<<2)>>2]|0;Erc(E,(E|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;c[x+(H<<2<<2)>>2]=G;c[x+(D+48<<2)>>2]=0;D=K+1|0;if((D|0)>=6){break}K=D;J=c[j+(D<<2)>>2]|0}J=x+(((y&3|0)!=3?1:69)<<2)|0;K=y+1|0;if((K|0)<(m|0)){x=J;y=K;z=z+72|0;e=e+4|0;A=A+4|0}else{L=J;break}}}else{L=n}if((m|0)<32){M=L;N=m}else{i=h;return}while(1){c[f+(N<<2)>>2]=c[M>>2];c[M>>2]=0;m=M+16|0;c[f+(N+32<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+32|0;c[f+(N+64<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+48|0;c[f+(N+96<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+64|0;c[f+(N+128<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+80|0;c[f+(N+160<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+96|0;c[f+(N+192<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+112|0;c[f+(N+224<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+128|0;c[f+(N+256<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+144|0;c[f+(N+288<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+160|0;c[f+(N+320<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+176|0;c[f+(N+352<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+192|0;c[f+(N+384<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+208|0;c[f+(N+416<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+224|0;c[f+(N+448<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+240|0;c[f+(N+480<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+256|0;c[f+(N+512<<2)>>2]=c[m>>2];c[m>>2]=0;m=M+272|0;c[f+(N+544<<2)>>2]=c[m>>2];c[m>>2]=0;m=N+1|0;if((m|0)<32){M=M+(((N&3|0)!=3?1:69)<<2)|0;N=m}else{break}}i=h;return}function CSa(e){e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0.0,E=0,H=0,I=0,J=0,K=0;f=i;i=i+1544|0;h=f|0;j=f+8|0;k=f+520|0;l=c[e+60>>2]|0;if(!(a[1585160]|0)){m=j|0;n=k;o=0;while(1){b[5122192+(o<<1)>>1]=(o|0)%3|0|((o|0)/3|0)<<2;p=o+1|0;if((p|0)<64){o=p}else{q=0;break}}do{o=q+2|0;p=yrc(8388608,0,o|0)|0;r=(1<<o)-1|0;o=Crc(p,G,r,(r|0)<0|0?-1:0)|0;s=+(o|0);c[5121824+(q*12|0)>>2]=~~(s*2.0);c[5121828+(q*12|0)>>2]=~~(s*1.587401032447815);c[5121832+(q*12|0)>>2]=~~(s*1.2599210739135742);q=q+1|0;}while((q|0)<15);XSa(7687744);q=0;o=1;while(1){mrc(m|0,0,512)|0;mrc(n|0,0,1024)|0;r=c[820744+(o*12|0)>>2]|0;p=(r|0)>1?r:1;t=c[820748+(o*12|0)>>2]|0;u=c[820752+(o*12|0)>>2]|0;v=0;w=0;while(1){x=v<<5;if((v|0)==0){y=0;z=w;while(1){A=y|x;a[j+A|0]=a[t+z|0]|0;b[k+(A<<1)>>1]=b[u+(z<<1)>>1]|0;A=y+1|0;if((A|0)<(r|0)){y=A;z=z+1|0}else{break}}}else{z=0;y=w;while(1){A=z|x|((z|0)!=0)<<4;a[j+A|0]=a[t+y|0]|0;b[k+(A<<1)>>1]=b[u+(y<<1)>>1]|0;A=z+1|0;if((A|0)<(r|0)){z=A;y=y+1|0}else{break}}}y=v+1|0;if((y|0)<(r|0)){v=y;w=w+p|0}else{break}}c[5945604+(o*20|0)>>2]=5915632+(q<<2);p=c[1079704+(o<<2)>>2]|0;c[5945612+(o*20|0)>>2]=p;$2(5945600+(o*20|0)|0,7,512,m,1,1,n,2,2,0,0,0,4)|0;w=o+1|0;if((w|0)<16){q=p+q|0;o=w}else{break}}c[1486865]=5946304;c[1486867]=128;$2(5947456,7,16,812232,1,1,812168,1,1,0,0,0,4)|0;c[1486870]=5946816;c[1486872]=16;$2(5947476,4,16,812248,1,1,812184,1,1,0,0,0,4)|0;o=0;q=0;n=0;while(1){b[9903152+(q<<1)>>1]=n;m=(d[1959872+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951598]=576;n=0;q=0;o=0;while(1){b[9903198+(q<<1)>>1]=o;m=(d[1959894+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4951621]=576;o=0;q=0;n=0;while(1){b[9903244+(q<<1)>>1]=n;m=(d[1959916+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951644]=576;n=0;q=0;o=0;while(1){b[9903290+(q<<1)>>1]=o;m=(d[1959938+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4951667]=576;o=0;q=0;n=0;while(1){b[9903336+(q<<1)>>1]=n;m=(d[1959960+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951690]=576;n=0;q=0;o=0;while(1){b[9903382+(q<<1)>>1]=o;m=(d[1959982+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4951713]=576;o=0;q=0;n=0;while(1){b[9903428+(q<<1)>>1]=n;m=(d[1960004+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951736]=576;n=0;q=0;o=0;while(1){b[9903474+(q<<1)>>1]=o;m=(d[1960026+q|0]|0)+n|0;k=q+1|0;if((k|0)<22){n=m;q=k;o=m&65535}else{break}}b[4951759]=576;o=0;q=0;n=0;while(1){b[9903520+(q<<1)>>1]=n;m=(d[1960048+q|0]|0)+o|0;k=q+1|0;if((k|0)<22){o=m;q=k;n=m&65535}else{break}}b[4951782]=576;n=1;while(1){s=+((n|0)/4|0|0);B=s/1.759*+T(+s,+.3333333333333333);q=~~(+Wc(+(B*+ad(+(+(n&3|0)*.25))),h|0)*2147483648.0+.5);o=c[h>>2]|0;c[h>>2]=o-103;c[4755176+(n<<2)>>2]=q;a[5017800+n|0]=103-o;o=n+1|0;if((o|0)<32828){n=o}else{C=0;break}}do{B=+ad(+(+(C-400|0)*.25+23.0+5.0));n=0;do{s=+(n|0);D=B*s*+T(+s,+.3333333333333333)/1.759;if(D<4294967295.0){s=+Q(D+.5);h=~~+s>>>0;F=+s,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0;E=h}else{E=-1}c[8905336+(C<<6)+(n<<2)>>2]=E;g[8839800+(C<<6)+(n<<2)>>2]=D;n=n+1|0;}while((n|0)<16);g[8972408+(C<<2)>>2]=+g[8839804+(C<<6)>>2];C=C+1|0;}while((C|0)<512);C=c[337118]|0;do{if((C|0)<0){E=1<<1-C;if((E|0)<=0){break}n=c[337100]|0;h=0;do{o=(h|0)/(n|0)|0;b[9344248+(h<<1)>>1]=(((o|0)%(n|0)|0)<<4)+((h|0)%(n|0)|0)+(((o|0)/(n|0)|0)<<8);h=h+1|0;}while((h|0)<(E|0))}}while(0);C=c[337119]|0;do{if((C|0)<0){E=1<<1-C;if((E|0)<=0){break}h=c[337101]|0;n=0;do{o=(n|0)/(h|0)|0;b[9343224+(n<<1)>>1]=(((o|0)%(h|0)|0)<<4)+((n|0)%(h|0)|0)+(((o|0)/(h|0)|0)<<8);n=n+1|0;}while((n|0)<(E|0))}}while(0);C=c[337120]|0;do{if((C|0)<0){E=1<<1-C;if((E|0)<=0){break}n=c[337102]|0;h=0;do{o=(h|0)/(n|0)|0;b[h<<1>>1]=(((o|0)%(n|0)|0)<<4)+((h|0)%(n|0)|0)+(((o|0)/(n|0)|0)<<8);h=h+1|0;}while((h|0)<(E|0))}}while(0);C=c[337121]|0;do{if((C|0)<0){E=1<<1-C;if((E|0)<=0){break}h=c[337103]|0;n=0;do{o=(n|0)/(h|0)|0;b[9335032+(n<<1)>>1]=(((o|0)%(h|0)|0)<<4)+((n|0)%(h|0)|0)+(((o|0)/(h|0)|0)<<8);n=n+1|0;}while((n|0)<(E|0))}}while(0);g[1457798]=0.0;g[1457820]=0.0;g[1457799]=.21132487058639526;g[1457819]=.21132487058639526;g[1457800]=.3660253882408142;g[1457818]=.3660253882408142;g[1457801]=.5;g[1457817]=.5;g[1457802]=.6339746117591858;g[1457816]=.6339746117591858;g[1457803]=.7886751294136047;g[1457815]=.7886751294136047;g[1457804]=1.0;g[1457814]=1.0;mrc(5831220,0,36)|0;mrc(5831284,0,36)|0;C=0;while(1){E=C+1|0;n=E>>1;h=C&1;o=h^1;g[5830680+(o<<6)+(C<<2)>>2]=+ad(+(+(-n|0)*.25));g[5830680+(h<<6)+(C<<2)>>2]=1.0;g[5830808+(o<<6)+(C<<2)>>2]=+ad(+(+(n*-2|0|0)*.25));g[5830808+(h<<6)+(C<<2)>>2]=1.0;if((E|0)<16){C=E}else{H=0;break}}do{B=+g[1704888+(H<<2)>>2];D=1.0/+S(B*B+1.0);s=B*D;g[9772416+(H<<4)>>2]=D;g[9772420+(H<<4)>>2]=s;g[9772424+(H<<4)>>2]=D+s;g[9772428+(H<<4)>>2]=s-D;H=H+1|0;}while((H|0)<8);a[1585160]=1}c[l+32940>>2]=e;qHb(l+32968|0,c[e+88>>2]&8388608);PSa(l+32944|0);H=c[e+48>>2]|0;do{if((c[e+468>>2]|0)==3){if((H|0)==86030){I=86030;J=60;break}c[e+420>>2]=3;K=H}else{I=H;J=60}}while(0);if((J|0)==60){c[e+420>>2]=8;K=I}c[l+32936>>2]=c[e+696>>2];if((K|0)!=86029){i=f;return 0}c[l+32928>>2]=1;i=f;return 0}function DSa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=g+28|0;k=c[j>>2]|0;l=c[b+60>>2]|0;m=l;if((k|0)==0){n=-1094995529;i=h;return n|0}o=k;k=c[g+24>>2]|0;while(1){if((a[k]|0)!=0){break}g=o-1|0;if((g|0)==0){n=-1094995529;p=22;break}else{o=g;k=k+1|0}}if((p|0)==22){i=h;return n|0}if((o|0)<4){n=-1094995529;i=h;return n|0}p=k;g=je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if((g&-256|0)==1413564160){KIb(b,48,2333568,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=o;i=h;return n|0}if((g&-2097152|0)!=-2097152|(g&393216|0)==0|(g&61440|0)==61440|(g&3072|0)==3072){KIb(b,16,2328120,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}if((MSa(l,g)|0)==1){c[l>>2]=-1;n=-1094995529;i=h;return n|0}g=l+24|0;c[b+416>>2]=c[g>>2];p=(c[g>>2]|0)==1;g=b+448|0;c[g>>2]=p?4:3;c[g+4>>2]=p?0:0;p=b+72|0;if((c[p>>2]|0)==0){c[p>>2]=c[l+20>>2]}p=l;g=c[p>>2]|0;if((g|0)<1|(g|0)>(o|0)){KIb(b,16,2322328,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}if((g|0)<(o|0)){KIb(b,48,2317208,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=c[p>>2]|0}else{r=o}o=l+33004|0;c[o>>2]=e;e=KSa(m,0,k,r)|0;do{if((e|0)>-1){c[(c[o>>2]|0)+76>>2]=c[b+424>>2];c[f>>2]=1;c[b+412>>2]=c[l+12>>2]}else{KIb(b,16,2345288,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[f>>2]=0;if((r|0)!=(c[j>>2]|0)&(e|0)==-1094995529){break}else{n=e}i=h;return n|0}}while(0);c[p>>2]=0;n=r;i=h;return n|0}function ESa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mrc(b+1152|0,0,8192)|0;c[b+1088>>2]=0;return}function FSa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;f=c[a+60>>2]|0;if((j|0)<4){KIb(a,16,2368872,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}m=h;n=je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0;if((n&393216|0)==0|(n&61440|0)==61440|(n&3072|0)==3072){KIb(a,16,2353904,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}MSa(f,n|-2097152)|0;c[a+412>>2]=c[f+12>>2];n=f+24|0;c[a+416>>2]=c[n>>2];m=(c[n>>2]|0)==1;n=a+448|0;c[n>>2]=m?4:3;c[n+4>>2]=m?0:0;m=a+72|0;if((c[m>>2]|0)==0){c[m>>2]=c[f+20>>2]}c[f>>2]=(j|0)>1792?1792:j;c[f+33004>>2]=b;b=KSa(f,0,h,j)|0;if((b|0)<0){KIb(a,16,2345288,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=b;i=g;return l|0}else{c[e>>2]=1;l=j;i=g;return l|0}return 0}function GSa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+48|0;f=e|0;g=a+60|0;h=c[g>>2]|0;j=c[a+100>>2]|0;do{if((j|0)>=2){k=c[a+96>>2]|0;if((k|0)==0){break}CRa(f,k,j<<3,1)|0;k=f+12|0;l=c[k>>2]|0;if((l|0)==0|(l|0)>7){KIb(a,16,2375536,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}o=h;c[o>>2]=d[821816+l|0]|0;l=c[k>>2]|0;c[h+8>>2]=1712632+(l*5|0);c[a+416>>2]=d[1343560+l|0]|0;k=b[1712712+(l<<1)>>1]|0;l=a+448|0;c[l>>2]=k<<16>>16;c[l+4>>2]=k<<16>>16<0|0?-1:0;c[h+4>>2]=(c[f+8>>2]|0)<16e3?-2097152:-1048576;k=pJb(33024)|0;l=h+12|0;p=l;q=l;c[q>>2]=k;a:do{if((k|0)!=0){c[g>>2]=k;CSa(a)|0;c[g>>2]=h;c[(c[q>>2]|0)+32928>>2]=1;if((c[o>>2]|0)>1){r=1}else{n=0;i=e;return n|0}while(1){l=pJb(33024)|0;s=p+(r<<2)|0;c[s>>2]=l;if((l|0)==0){break a}c[l+32928>>2]=1;c[l+32940>>2]=a;l=(c[s>>2]|0)+32944|0;s=(c[q>>2]|0)+32944|0;c[l>>2]=c[s>>2];c[l+4>>2]=c[s+4>>2];c[l+8>>2]=c[s+8>>2];c[l+12>>2]=c[s+12>>2];c[l+16>>2]=c[s+16>>2];c[l+20>>2]=c[s+20>>2];s=r+1|0;if((s|0)<(c[o>>2]|0)){r=s}else{n=0;break}}i=e;return n|0}}while(0);o=c[g>>2]|0;q=o;if((c[q>>2]|0)<=0){n=-12;i=e;return n|0}p=o+12|0;o=0;while(1){kJb(c[p+(o<<2)>>2]|0);k=o+1|0;if((k|0)<(c[q>>2]|0)){o=k}else{n=-12;break}}i=e;return n|0}}while(0);KIb(a,16,2382136,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}function HSa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+8|0;h=g|0;j=c[f+24>>2]|0;k=c[f+28>>2]|0;f=c[a+60>>2]|0;l=b+76|0;c[l>>2]=1152;m=M4a(a,b,0)|0;if((m|0)<0){n=m;i=g;return n|0}m=c[b+64>>2]|0;if((k|0)<4){n=-1094995529;i=g;return n|0}b=a+72|0;c[b>>2]=0;o=f;a:do{if((c[o>>2]|0)>0){p=f+12|0;q=f+4|0;r=a+416|0;s=f+8|0;t=h|0;u=h+4|0;v=a;w=k;x=0;y=j;z=0;A=0;while(1){B=y;C=((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)>>>4;B=(C|0)>(w|0)?w:C;C=(B|0)>1792?1792:B;B=c[p+(z<<2)>>2]|0;if((C|0)<4){D=7;break}E=y;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)&1048575;E=c[q>>2]|0;G=F|E;if((E&-2097152|0)!=-2097152|(G&393216|0)==0|(G&61440|0)==61440|(G&3072|0)==3072){D=9;break}MSa(B,G)|0;G=B+24|0;E=c[G>>2]|0;F=E+A|0;H=c[r>>2]|0;if((F|0)>(H|0)){D=12;break}I=d[(c[s>>2]|0)+z|0]|0;if((I+E|0)>(H|0)){D=12;break}c[t>>2]=c[m+(I<<2)>>2];if((E|0)>1){c[u>>2]=c[m+((d[(c[s>>2]|0)+z|0]|0)+1<<2)>>2]}E=KSa(B,t,y,C)|0;if((E|0)<0){KIb(v,16,2501880,(J=i,i=i+8|0,c[J>>2]=F,J)|0);i=J;mrc(c[t>>2]|0,0,4608)|0;I=c[G>>2]|0;if((I|0)>1){mrc(c[u>>2]|0,0,4608)|0;K=c[G>>2]|0}else{K=I}L=K*4608|0}else{L=E}E=L+x|0;c[b>>2]=(c[b>>2]|0)+(c[B+20>>2]|0);B=z+1|0;if((B|0)<(c[o>>2]|0)){w=w-C|0;x=E;y=y+C|0;z=B;A=F}else{M=E;N=F;O=r;break a}}if((D|0)==7){KIb(v,16,2548992,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}else if((D|0)==9){KIb(v,16,2531104,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}else if((D|0)==12){KIb(v,16,2515792,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}}else{M=0;N=0;O=a+416|0}}while(0);if((N|0)==(c[O>>2]|0)){c[a+412>>2]=c[(c[f+12>>2]|0)+12>>2];c[l>>2]=(M>>>0)/(N<<2>>>0)|0;c[e>>2]=1;n=k;i=g;return n|0}else{KIb(a,16,2488872,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;n=-1094995529;i=g;return n|0}return 0}function ISa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;a=b;if((c[a>>2]|0)<=0){return 0}d=b+12|0;b=0;do{kJb(c[d+(b<<2)>>2]|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function JSa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b;if((c[a>>2]|0)<=0){return}d=b+12|0;b=0;do{e=c[d+(b<<2)>>2]|0;mrc(e+1152|0,0,8192)|0;c[e+1088>>2]=0;b=b+1|0;}while((b|0)<(c[a>>2]|0));return}function KSa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0.0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0.0,wc=0,xc=0.0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0;l=i;i=i+3808|0;m=l|0;n=l+192|0;o=l+256|0;p=l+320|0;q=l+336|0;r=l+2640|0;s=l+3792|0;t=f+1096|0;u=j+4|0;j=k-4|0;k=j<<3;v=k>>>0>2147483639>>>0|(u|0)==0;w=v?0:u;u=v?0:k;k=t|0;c[k>>2]=w;v=f+1108|0;c[v>>2]=u;x=u+8|0;y=f+1112|0;c[y>>2]=x;z=f+1100|0;c[z>>2]=w+(u>>3);u=f+1104|0;c[u>>2]=0;if((c[f+4>>2]|0)==0){A=0}else{B=x>>>0>16>>>0?16:x;c[u>>2]=B;A=B}B=c[f+8>>2]|0;if((B|0)==2){c[(c[f+32940>>2]|0)+424>>2]=1152;C=f+24|0;D=Brb((c[f+20>>2]|0)/1e3|0,c[C>>2]|0,c[f+12>>2]|0,c[f+36>>2]|0)|0;E=c[1348376+(D<<2)>>2]|0;F=c[1349576+(D<<2)>>2]|0;if((c[f+28>>2]|0)==1){H=(c[f+32>>2]<<2)+4|0}else{H=E}D=(H|0)>(E|0)?E:H;H=(D|0)>0;if(H){I=f+1096|0;J=c[C>>2]|0;K=(J|0)>0;L=0;M=0;while(1){N=d[F+L|0]|0;if(K){O=32-N|0;P=c[y>>2]|0;Q=c[I>>2]|0;R=0;S=c[u>>2]|0;do{T=Q+(S>>>3)|0;U=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(S&7)>>>(O>>>0);T=S+N|0;S=P>>>0>T>>>0?T:P;c[u>>2]=S;a[n+(R<<5)+M|0]=U;R=R+1|0;}while((R|0)<(J|0))}R=(1<<N)+L|0;S=M+1|0;if((S|0)<(D|0)){L=R;M=S}else{V=R;break}}}else{V=0}M=(D|0)<(E|0);if(M){L=c[y>>2]|0;J=c[f+1096>>2]|0;I=V;V=D;K=c[u>>2]|0;while(1){R=d[F+I|0]|0;S=J+(K>>>3)|0;P=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(K&7)>>>((32-R|0)>>>0);S=R+K|0;O=L>>>0>S>>>0?S:L;c[u>>2]=O;S=P&255;a[n+V|0]=S;a[n+32+V|0]=S;S=V+1|0;if((S|0)<(E|0)){I=(1<<R)+I|0;V=S;K=O}else{break}}}K=f+1096|0;if((E|0)>0){V=c[C>>2]|0;I=(V|0)>0;L=0;while(1){if(I){J=0;do{if((a[n+(J<<5)+L|0]|0)!=0){O=c[u>>2]|0;S=c[y>>2]|0;R=(c[K>>2]|0)+(O>>>3)|0;P=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>30;R=O+2|0;c[u>>2]=S>>>0>R>>>0?R:S;a[o+(J<<5)+L|0]=P}J=J+1|0;}while((J|0)<(V|0))}J=L+1|0;if((J|0)<(E|0)){L=J}else{W=0;break}}do{if(I){L=0;do{do{if((a[n+(L<<5)+W|0]|0)!=0){J=m+(L*96|0)+(W*3|0)|0;N=d[o+(L<<5)+W|0]|0;if((N|0)==2){P=c[u>>2]|0;S=c[y>>2]|0;R=(c[K>>2]|0)+(P>>>3)|0;O=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(P&7)>>>26;R=P+6|0;c[u>>2]=S>>>0>R>>>0?R:S;S=O&255;a[J]=S;a[m+(L*96|0)+(W*3|0)+1|0]=S;a[m+(L*96|0)+(W*3|0)+2|0]=S;break}else if((N|0)==1){S=c[u>>2]|0;O=c[y>>2]|0;R=c[K>>2]|0;P=R+(S>>>3)|0;Q=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(S&7)>>>26;P=S+6|0;S=O>>>0>P>>>0?P:O;c[u>>2]=S;P=Q&255;a[J]=P;Q=R+(S>>>3)|0;R=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(S&7)>>>26;Q=S+6|0;c[u>>2]=O>>>0>Q>>>0?Q:O;a[m+(L*96|0)+(W*3|0)+2|0]=R;a[m+(L*96|0)+(W*3|0)+1|0]=P;break}else if((N|0)==3){N=c[u>>2]|0;P=c[y>>2]|0;R=c[K>>2]|0;O=R+(N>>>3)|0;Q=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(N&7)>>>26;O=N+6|0;N=P>>>0>O>>>0?O:P;c[u>>2]=N;a[J]=Q;Q=R+(N>>>3)|0;R=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(N&7)>>>26;Q=N+6|0;c[u>>2]=P>>>0>Q>>>0?Q:P;P=R&255;a[m+(L*96|0)+(W*3|0)+2|0]=P;a[m+(L*96|0)+(W*3|0)+1|0]=P;break}else{P=c[u>>2]|0;R=c[y>>2]|0;Q=c[K>>2]|0;N=Q+(P>>>3)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(P&7)>>>26;N=P+6|0;P=R>>>0>N>>>0?N:R;c[u>>2]=P;a[J]=O;O=Q+(P>>>3)|0;J=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(P&7)>>>26;O=P+6|0;P=R>>>0>O>>>0?O:R;c[u>>2]=P;a[m+(L*96|0)+(W*3|0)+1|0]=J;J=Q+(P>>>3)|0;Q=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(P&7)>>>26;J=P+6|0;c[u>>2]=R>>>0>J>>>0?J:R;a[m+(L*96|0)+(W*3|0)+2|0]=Q;break}}}while(0);L=L+1|0;}while((L|0)<(V|0))}W=W+1|0;}while((W|0)<(E|0))}W=(E|0)<32;V=0;while(1){I=V*12|0;L=0;do{if(H){Q=L+I|0;R=Q+1|0;J=Q+2|0;P=0;O=0;N=c[C>>2]|0;while(1){S=d[F+P|0]|0;if((N|0)>0){U=0;while(1){T=a[n+(U<<5)+O|0]|0;do{if(T<<24>>24==0){g[f+9376+(U*4608|0)+(Q<<7)+(O<<2)>>2]=0.0;g[f+9376+(U*4608|0)+(R<<7)+(O<<2)>>2]=0.0;g[f+9376+(U*4608|0)+(J<<7)+(O<<2)>>2]=0.0}else{X=d[m+(U*96|0)+(O*3|0)+V|0]|0;Y=d[F+((T&255)+P)|0]|0;Z=c[1348472+(Y<<2)>>2]|0;if((Z|0)>=0){_=32-Z|0;$=Z-1|0;aa=(-1<<$)+1|0;ba=c[u>>2]|0;da=c[y>>2]|0;ea=(c[K>>2]|0)+(ba>>>3)|0;fa=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ba&7)>>>(_>>>0);ea=ba+Z|0;c[u>>2]=da>>>0>ea>>>0?ea:da;da=e[5122192+(X<<1)>>1]|0;ea=fa+aa|0;fa=5121824+((Z-2|0)*12|0)+((da&3)<<2)|0;ba=c[fa>>2]|0;ga=Erc(ea,(ea|0)<0|0?-1:0,ba,(ba|0)<0|0?-1:0)|0;ba=G;ea=(da>>>2)+$|0;$=yrc(1,0,ea-1|0)|0;da=G;ha=wrc($,da,ga,ba)|0;ba=ea;ea=Arc(ha|0,G|0,ba|0)|0;g[f+9376+(U*4608|0)+(Q<<7)+(O<<2)>>2]=+(ea|0);ea=c[u>>2]|0;ha=c[y>>2]|0;ga=(c[K>>2]|0)+(ea>>>3)|0;ia=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ea&7)>>>(_>>>0);ga=ea+Z|0;c[u>>2]=ha>>>0>ga>>>0?ga:ha;ha=ia+aa|0;ia=c[fa>>2]|0;ga=Erc(ha,(ha|0)<0|0?-1:0,ia,(ia|0)<0|0?-1:0)|0;ia=wrc(ga,G,$,da)|0;ga=Arc(ia|0,G|0,ba|0)|0;g[f+9376+(U*4608|0)+(R<<7)+(O<<2)>>2]=+(ga|0);ga=c[u>>2]|0;ia=c[y>>2]|0;ha=(c[K>>2]|0)+(ga>>>3)|0;ea=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ga&7)>>>(_>>>0);_=ga+Z|0;c[u>>2]=ia>>>0>_>>>0?_:ia;ia=ea+aa|0;aa=c[fa>>2]|0;fa=Erc(ia,(ia|0)<0|0?-1:0,aa,(aa|0)<0|0?-1:0)|0;aa=wrc(fa,G,$,da)|0;da=Arc(aa|0,G|0,ba|0)|0;g[f+9376+(U*4608|0)+(J<<7)+(O<<2)>>2]=+(da|0);break}da=c[u>>2]|0;ba=c[y>>2]|0;aa=(c[K>>2]|0)+(da>>>3)|0;$=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(da&7)>>>((Z+32|0)>>>0);aa=da-Z|0;c[u>>2]=ba>>>0>aa>>>0?aa:ba;ba=b[(c[1530896+(Y<<2)>>2]|0)+($<<1)>>1]|0;$=c[1348400+(Y<<2)>>2]|0;Y=e[5122192+(X<<1)>>1]|0;X=Y>>>2;aa=$>>1;Z=c[608640+(($>>2)*12|0)+((Y&3)<<2)>>2]|0;Y=ca(Z,(ba&15)-aa|0)|0;$=(X|0)==0;if($){ja=Y}else{ja=(1<<X-1)+Y>>X}g[f+9376+(U*4608|0)+(Q<<7)+(O<<2)>>2]=+(ja|0);Y=ca((ba>>>4&15)-aa|0,Z)|0;if($){g[f+9376+(U*4608|0)+(R<<7)+(O<<2)>>2]=+(Y|0);ka=ca(Z,(ba>>8)-aa|0)|0}else{$=1<<X-1;g[f+9376+(U*4608|0)+(R<<7)+(O<<2)>>2]=+($+Y>>X|0);ka=$+(ca(Z,(ba>>8)-aa|0)|0)>>X}g[f+9376+(U*4608|0)+(J<<7)+(O<<2)>>2]=+(ka|0)}}while(0);T=U+1|0;X=c[C>>2]|0;if((T|0)<(X|0)){U=T}else{la=X;break}}}else{la=N}U=(1<<S)+P|0;X=O+1|0;if((X|0)<(D|0)){P=U;O=X;N=la}else{ma=U;break}}}else{ma=0}if(M){N=L+I|0;O=N+1|0;P=N+2|0;J=ma;R=D;while(1){Q=d[F+J|0]|0;U=a[n+R|0]|0;do{if(U<<24>>24==0){g[f+9376+(N<<7)+(R<<2)>>2]=0.0;g[f+9376+(O<<7)+(R<<2)>>2]=0.0;g[f+9376+(P<<7)+(R<<2)>>2]=0.0;g[f+13984+(N<<7)+(R<<2)>>2]=0.0;g[f+13984+(O<<7)+(R<<2)>>2]=0.0;g[f+13984+(P<<7)+(R<<2)>>2]=0.0}else{X=d[m+(R*3|0)+V|0]|0;T=d[m+96+(R*3|0)+V|0]|0;aa=d[F+((U&255)+J)|0]|0;ba=c[1348472+(aa<<2)>>2]|0;if((ba|0)>=0){Z=32-ba|0;$=ba-1|0;Y=(-1<<$)+1|0;da=ba-2|0;fa=b[5122192+(T<<1)>>1]|0;ia=e[5122192+(X<<1)>>1]|0;ea=5121824+(da*12|0)+((ia&3)<<2)|0;_=(ia>>>2)+$|0;ia=yrc(1,0,_-1|0)|0;ga=G;ha=_;_=fa&65535;fa=5121824+(da*12|0)+((_&3)<<2)|0;da=(_>>>2)+$|0;$=yrc(1,0,da-1|0)|0;_=G;na=da;da=c[u>>2]|0;oa=c[y>>2]|0;pa=(c[K>>2]|0)+(da>>>3)|0;qa=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(da&7)>>>(Z>>>0);pa=da+ba|0;c[u>>2]=oa>>>0>pa>>>0?pa:oa;oa=Y+qa|0;qa=oa;pa=(oa|0)<0|0?-1:0;oa=c[ea>>2]|0;da=Erc(qa,pa,oa,(oa|0)<0|0?-1:0)|0;oa=wrc(da,G,ia,ga)|0;da=Arc(oa|0,G|0,ha|0)|0;g[f+9376+(N<<7)+(R<<2)>>2]=+(da|0);da=c[fa>>2]|0;oa=Erc(qa,pa,da,(da|0)<0|0?-1:0)|0;da=wrc(oa,G,$,_)|0;oa=Arc(da|0,G|0,na|0)|0;g[f+13984+(N<<7)+(R<<2)>>2]=+(oa|0);oa=c[u>>2]|0;da=c[y>>2]|0;pa=(c[K>>2]|0)+(oa>>>3)|0;qa=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(oa&7)>>>(Z>>>0);pa=oa+ba|0;c[u>>2]=da>>>0>pa>>>0?pa:da;da=Y+qa|0;qa=da;pa=(da|0)<0|0?-1:0;da=c[ea>>2]|0;oa=Erc(qa,pa,da,(da|0)<0|0?-1:0)|0;da=wrc(oa,G,ia,ga)|0;oa=Arc(da|0,G|0,ha|0)|0;g[f+9376+(O<<7)+(R<<2)>>2]=+(oa|0);oa=c[fa>>2]|0;da=Erc(qa,pa,oa,(oa|0)<0|0?-1:0)|0;oa=wrc(da,G,$,_)|0;da=Arc(oa|0,G|0,na|0)|0;g[f+13984+(O<<7)+(R<<2)>>2]=+(da|0);da=c[u>>2]|0;oa=c[y>>2]|0;pa=(c[K>>2]|0)+(da>>>3)|0;qa=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(da&7)>>>(Z>>>0);Z=da+ba|0;c[u>>2]=oa>>>0>Z>>>0?Z:oa;oa=Y+qa|0;qa=oa;Y=(oa|0)<0|0?-1:0;oa=c[ea>>2]|0;ea=Erc(qa,Y,oa,(oa|0)<0|0?-1:0)|0;oa=wrc(ea,G,ia,ga)|0;ga=Arc(oa|0,G|0,ha|0)|0;g[f+9376+(P<<7)+(R<<2)>>2]=+(ga|0);ga=c[fa>>2]|0;fa=Erc(qa,Y,ga,(ga|0)<0|0?-1:0)|0;ga=wrc(fa,G,$,_)|0;_=Arc(ga|0,G|0,na|0)|0;g[f+13984+(P<<7)+(R<<2)>>2]=+(_|0);break}_=c[u>>2]|0;na=c[y>>2]|0;ga=(c[K>>2]|0)+(_>>>3)|0;$=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(_&7)>>>((ba+32|0)>>>0);ga=_-ba|0;c[u>>2]=na>>>0>ga>>>0?ga:na;na=c[1348400+(aa<<2)>>2]|0;aa=($|0)/(na|0)|0;ga=e[5122192+(X<<1)>>1]|0;X=ga>>>2;ba=na>>1;_=(($|0)%(na|0)|0)-ba|0;$=na>>2;fa=c[608640+($*12|0)+((ga&3)<<2)>>2]|0;ga=ca(fa,_)|0;Y=(X|0)==0;if(Y){ra=ga}else{ra=(1<<X-1)+ga>>X}g[f+9376+(N<<7)+(R<<2)>>2]=+(ra|0);ga=e[5122192+(T<<1)>>1]|0;T=ga>>>2;qa=c[608640+($*12|0)+((ga&3)<<2)>>2]|0;ga=ca(qa,_)|0;_=(T|0)==0;if(_){sa=ga}else{sa=(1<<T-1)+ga>>T}g[f+13984+(N<<7)+(R<<2)>>2]=+(sa|0);ga=((aa|0)%(na|0)|0)-ba|0;$=ca(ga,fa)|0;if(Y){ta=$}else{ta=$+(1<<X-1)>>X}g[f+9376+(O<<7)+(R<<2)>>2]=+(ta|0);$=ca(ga,qa)|0;if(_){ua=$}else{ua=$+(1<<T-1)>>T}g[f+13984+(O<<7)+(R<<2)>>2]=+(ua|0);$=((aa|0)/(na|0)|0)-ba|0;ba=ca($,fa)|0;if(Y){va=ba}else{va=ba+(1<<X-1)>>X}g[f+9376+(P<<7)+(R<<2)>>2]=+(va|0);X=ca($,qa)|0;if(_){wa=X}else{wa=X+(1<<T-1)>>T}g[f+13984+(P<<7)+(R<<2)>>2]=+(wa|0)}}while(0);U=R+1|0;if((U|0)<(E|0)){J=(1<<Q)+J|0;R=U}else{break}}}if(W){R=L+I|0;J=R+1|0;P=R+2|0;O=E;N=c[C>>2]|0;while(1){if((N|0)>0){U=0;while(1){g[f+9376+(U*4608|0)+(R<<7)+(O<<2)>>2]=0.0;g[f+9376+(U*4608|0)+(J<<7)+(O<<2)>>2]=0.0;g[f+9376+(U*4608|0)+(P<<7)+(O<<2)>>2]=0.0;S=U+1|0;T=c[C>>2]|0;if((S|0)<(T|0)){U=S}else{xa=T;break}}}else{xa=N}U=O+1|0;if((U|0)<32){O=U;N=xa}else{break}}}L=L+3|0;}while((L|0)<12);L=V+1|0;if((L|0)<3){V=L}else{ya=36;break}}}else if((B|0)==3){V=f+36|0;c[(c[f+32940>>2]|0)+424>>2]=(c[V>>2]|0)!=0?576:1152;za=c[u>>2]|0;Aa=c[y>>2]|0;Ba=V;Ca=114}else if((B|0)==1){c[(c[f+32940>>2]|0)+424>>2]=384;if((c[f+28>>2]|0)==1){B=(c[f+32>>2]<<2)+4|0;if((B|0)>0){Da=B;Ca=7}else{Ea=0;Fa=B;Ca=11}}else{Da=32;Ca=7}if((Ca|0)==7){B=c[f+24>>2]|0;V=(B|0)>0;xa=0;do{if(V){C=c[y>>2]|0;E=0;W=c[u>>2]|0;do{wa=w+(W>>>3)|0;va=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(W&7)>>>28;wa=W+4|0;W=C>>>0>wa>>>0?wa:C;c[u>>2]=W;a[n+(E<<5)+xa|0]=va;E=E+1|0;}while((E|0)<(B|0))}xa=xa+1|0;}while((xa|0)<(Da|0));if((Da|0)<32){Ea=1;Fa=Da;Ca=11}else{Ga=0;Ha=Da;Ia=B;Ca=17}}do{if((Ca|0)==11){B=f+1096|0;Da=c[y>>2]|0;xa=Fa;V=c[u>>2]|0;do{E=w+(V>>>3)|0;W=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(V&7)>>>28;E=V+4|0;V=Da>>>0>E>>>0?E:Da;c[u>>2]=V;a[n+xa|0]=W;xa=xa+1|0;}while((xa|0)<32);if(!Ea){Ja=0;Ka=Fa;La=B;Ca=16;break}Ga=1;Ha=Fa;Ia=c[f+24>>2]|0;Ca=17}}while(0);if((Ca|0)==17){Fa=f+1096|0;Ea=(Ia|0)>0;xa=0;do{if(Ea){V=0;do{if((a[n+(V<<5)+xa|0]|0)!=0){Da=c[u>>2]|0;W=c[y>>2]|0;E=w+(Da>>>3)|0;C=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(Da&7)>>>26;E=Da+6|0;c[u>>2]=W>>>0>E>>>0?E:W;a[o+(V<<5)+xa|0]=C}V=V+1|0;}while((V|0)<(Ia|0))}xa=xa+1|0;}while((xa|0)<(Ha|0));if(Ga){Ja=1;Ka=Ha;La=Fa;Ca=16}else{Ma=1;Na=Ha;Oa=0;Pa=Fa}}if((Ca|0)==16){Fa=Ka;while(1){if((a[n+Fa|0]|0)!=0){Ha=c[u>>2]|0;Ga=c[y>>2]|0;xa=c[La>>2]|0;Ia=xa+(Ha>>>3)|0;Ea=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ha&7)>>>26;Ia=Ha+6|0;Ha=Ga>>>0>Ia>>>0?Ia:Ga;c[u>>2]=Ha;a[o+Fa|0]=Ea;Ea=xa+(Ha>>>3)|0;xa=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ha&7)>>>26;Ea=Ha+6|0;c[u>>2]=Ga>>>0>Ea>>>0?Ea:Ga;a[o+32+Fa|0]=xa}xa=Fa+1|0;if((xa|0)<32){Fa=xa}else{Ma=Ja;Na=Ka;Oa=1;Pa=La;break}}}La=f+24|0;Ka=0;while(1){if(Ma){Ja=0;Fa=c[La>>2]|0;while(1){if((Fa|0)>0){xa=0;while(1){Ga=a[n+(xa<<5)+Ja|0]|0;Ea=Ga&255;if(Ga<<24>>24==0){Qa=0.0}else{Ga=c[u>>2]|0;Ha=c[y>>2]|0;Ia=(c[Pa>>2]|0)+(Ga>>>3)|0;V=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ga&7)>>>((31-Ea|0)>>>0);Ia=Ea+1+Ga|0;c[u>>2]=Ha>>>0>Ia>>>0?Ia:Ha;Ha=e[5122192+(d[o+(xa<<5)+Ja|0]<<1)>>1]|0;Ia=(-1<<Ea)+1+V|0;V=c[5121824+((Ea-1|0)*12|0)+((Ha&3)<<2)>>2]|0;Ga=Erc(V,(V|0)<0|0?-1:0,Ia,(Ia|0)<0|0?-1:0)|0;Ia=G;V=(Ha>>>2)+Ea|0;Ea=yrc(1,0,V-1|0)|0;Ha=wrc(Ea,G,Ga,Ia)|0;Ia=Arc(Ha|0,G|0,V|0)|0;Qa=+(Ia|0)}g[f+9376+(xa*4608|0)+(Ka<<7)+(Ja<<2)>>2]=Qa;Ia=xa+1|0;V=c[La>>2]|0;if((Ia|0)<(V|0)){xa=Ia}else{Ra=V;break}}}else{Ra=Fa}xa=Ja+1|0;if((xa|0)<(Na|0)){Ja=xa;Fa=Ra}else{break}}}if(Oa){Fa=Na;do{Ja=a[n+Fa|0]|0;xa=Ja&255;if(Ja<<24>>24==0){g[f+9376+(Ka<<7)+(Fa<<2)>>2]=0.0;g[f+13984+(Ka<<7)+(Fa<<2)>>2]=0.0}else{Ja=c[u>>2]|0;V=c[y>>2]|0;Ia=(c[Pa>>2]|0)+(Ja>>>3)|0;Ha=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ja&7)>>>((31-xa|0)>>>0);Ia=xa+1+Ja|0;c[u>>2]=V>>>0>Ia>>>0?Ia:V;V=e[5122192+(d[o+Fa|0]<<1)>>1]|0;Ia=(-1<<xa)+1+Ha|0;Ha=Ia;Ja=(Ia|0)<0|0?-1:0;Ia=xa-1|0;Ga=c[5121824+(Ia*12|0)+((V&3)<<2)>>2]|0;Ea=Erc(Ga,(Ga|0)<0|0?-1:0,Ha,Ja)|0;Ga=G;B=(V>>>2)+xa|0;V=yrc(1,0,B-1|0)|0;C=wrc(V,G,Ea,Ga)|0;Ga=Arc(C|0,G|0,B|0)|0;g[f+9376+(Ka<<7)+(Fa<<2)>>2]=+(Ga|0);Ga=e[5122192+(d[o+32+Fa|0]<<1)>>1]|0;B=c[5121824+(Ia*12|0)+((Ga&3)<<2)>>2]|0;Ia=Erc(B,(B|0)<0|0?-1:0,Ha,Ja)|0;Ja=G;Ha=(Ga>>>2)+xa|0;xa=yrc(1,0,Ha-1|0)|0;Ga=wrc(xa,G,Ia,Ja)|0;Ja=Arc(Ga|0,G|0,Ha|0)|0;g[f+13984+(Ka<<7)+(Fa<<2)>>2]=+(Ja|0)}Fa=Fa+1|0;}while((Fa|0)<32)}Fa=Ka+1|0;if((Fa|0)<12){Ka=Fa}else{ya=12;break}}}else{za=A;Aa=x;Ba=f+36|0;Ca=114}do{if((Ca|0)==114){x=(c[Ba>>2]|0)==0;A=w+(za>>>3)|0;Ka=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(za&7);do{if(x){A=Ka>>>23;o=za+9|0;Pa=Aa>>>0>o>>>0?o:Aa;c[u>>2]=Pa;o=c[f+24>>2]|0;if((o|0)==2){n=Pa+3|0;Na=Aa>>>0>n>>>0?n:Aa;c[u>>2]=Na;Sa=0;Ta=Na}else{Na=Pa+5|0;Pa=Aa>>>0>Na>>>0?Na:Aa;c[u>>2]=Pa;if((o|0)>0){Sa=0;Ta=Pa}else{Ua=2;Va=A;Wa=o;break}}while(1){a[f+23200+(Sa*4864|0)|0]=0;Pa=w+(Ta>>>3)|0;Na=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Ta&7)>>>28;Pa=Ta+4|0;n=Aa>>>0>Pa>>>0?Pa:Aa;c[u>>2]=n;a[f+23200+(Sa*4864|0)+2432|0]=Na;Na=Sa+1|0;if((Na|0)<(o|0)){Sa=Na;Ta=n}else{Ua=2;Va=A;Wa=o;break}}}else{o=za+8|0;A=c[f+24>>2]|0;n=A+(Aa>>>0>o>>>0?o:Aa)|0;c[u>>2]=Aa>>>0>n>>>0?n:Aa;Ua=1;Va=Ka>>>24;Wa=A}}while(0);Ka=f+24|0;x=f+32|0;A=f+16|0;n=f+32940|0;o=0;Na=Wa;Pa=Aa;Oa=w;a:while(1){if((Na|0)>0){Ra=0;La=Pa;Ma=Oa;while(1){Fa=c[u>>2]|0;Ja=Ma+(Fa>>>3)|0;Ha=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Fa&7)>>>20;Ja=Fa+12|0;Fa=La>>>0>Ja>>>0?Ja:La;c[u>>2]=Fa;c[f+23200+(Ra*4864|0)+(o*2432|0)+4>>2]=Ha;Ha=Ma+(Fa>>>3)|0;Ja=(je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Fa&7);Ha=Ja>>>23;Ga=Fa+9|0;Fa=La>>>0>Ga>>>0?Ga:La;c[u>>2]=Fa;c[f+23200+(Ra*4864|0)+(o*2432|0)+8>>2]=Ha;if(Ja>>>0>2424307711>>>0){Ca=123;break a}Ja=Ma+(Fa>>>3)|0;Ga=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Fa&7)>>>24;Ja=Fa+8|0;Fa=La>>>0>Ja>>>0?Ja:La;c[u>>2]=Fa;Ja=f+23200+(Ra*4864|0)+(o*2432|0)+12|0;c[Ja>>2]=Ga;if((c[x>>2]&3|0)==2){c[Ja>>2]=Ga-2}Ga=c[Ba>>2]|0;Ja=Ma+(Fa>>>3)|0;Ia=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Fa&7);if((Ga|0)==0){Ja=Fa+4|0;xa=La>>>0>Ja>>>0?Ja:La;c[u>>2]=xa;c[f+23200+(Ra*4864|0)+(o*2432|0)+16>>2]=Ia>>>28;Xa=xa}else{xa=Fa+9|0;Fa=La>>>0>xa>>>0?xa:La;c[u>>2]=Fa;c[f+23200+(Ra*4864|0)+(o*2432|0)+16>>2]=Ia>>>23;Xa=Fa}Fa=d[Ma+(Xa>>>3)|0]|0;Ia=((Xa|0)<(La|0))+Xa|0;c[u>>2]=Ia;if((Fa&128>>>((Xa&7)>>>0)|0)==0){a[f+23200+(Ra*4864|0)+(o*2432|0)+20|0]=0;a[f+23200+(Ra*4864|0)+(o*2432|0)+21|0]=0;Fa=Ma+(Ia>>>3)|0;xa=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ia&7)>>>27;Fa=Ia+5|0;Ja=La>>>0>Fa>>>0?Fa:La;c[u>>2]=Ja;c[f+23200+(Ra*4864|0)+(o*2432|0)+24>>2]=xa;xa=Ma+(Ja>>>3)|0;Fa=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ja&7)>>>27;xa=Ja+5|0;Ja=La>>>0>xa>>>0?xa:La;c[u>>2]=Ja;c[f+23200+(Ra*4864|0)+(o*2432|0)+28>>2]=Fa;Fa=Ma+(Ja>>>3)|0;xa=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ja&7)>>>27;Fa=Ja+5|0;Ja=La>>>0>Fa>>>0?Fa:La;c[u>>2]=Ja;c[f+23200+(Ra*4864|0)+(o*2432|0)+32>>2]=xa;xa=Ma+(Ja>>>3)|0;Fa=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ja&7)>>>28;xa=Ja+4|0;Ja=La>>>0>xa>>>0?xa:La;c[u>>2]=Ja;xa=Ma+(Ja>>>3)|0;B=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ja&7)>>>29;xa=Ja+3|0;c[u>>2]=La>>>0>xa>>>0?xa:La;xa=c[A>>2]|0;Ja=(e[9903152+(xa*46|0)+(Fa+1<<1)>>1]|0)>>>1;C=f+23200+(Ra*4864|0)+(o*2432|0)+52|0;c[C>>2]=Ja;Ea=Fa+2+B|0;B=(e[9903152+(xa*46|0)+(((Ea|0)>22?22:Ea)<<1)>>1]|0)>>>1;c[f+23200+(Ra*4864|0)+(o*2432|0)+56>>2]=B;Ya=Ja;Za=B;_a=0;$a=0;ab=xa;bb=C}else{C=Ma+(Ia>>>3)|0;xa=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(Ia&7)>>>30;C=Ia+2|0;Ia=La>>>0>C>>>0?C:La;c[u>>2]=Ia;C=xa&255;a[f+23200+(Ra*4864|0)+(o*2432|0)+20|0]=C;if((xa|0)==0){Ca=131;break a}xa=d[Ma+(Ia>>>3)|0]<<(Ia&7)>>>7;B=((Ia|0)<(La|0))+Ia|0;c[u>>2]=B;Ia=xa&1;a[f+23200+(Ra*4864|0)+(o*2432|0)+21|0]=Ia;xa=Ma+(B>>>3)|0;Ja=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(B&7)>>>27;xa=B+5|0;B=La>>>0>xa>>>0?xa:La;c[u>>2]=B;c[f+23200+(Ra*4864|0)+(o*2432|0)+24>>2]=Ja;Ja=Ma+(B>>>3)|0;xa=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(B&7)>>>27;Ja=B+5|0;B=La>>>0>Ja>>>0?Ja:La;c[u>>2]=B;c[f+23200+(Ra*4864|0)+(o*2432|0)+28>>2]=xa;xa=Ma+(B>>>3)|0;Ja=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(B&7)>>>29;xa=B+3|0;B=La>>>0>xa>>>0?xa:La;c[u>>2]=B;c[f+23200+(Ra*4864|0)+(o*2432|0)+36>>2]=Ja;Ja=Ma+(B>>>3)|0;xa=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(B&7)>>>29;Ja=B+3|0;B=La>>>0>Ja>>>0?Ja:La;c[u>>2]=B;c[f+23200+(Ra*4864|0)+(o*2432|0)+40>>2]=xa;xa=(c[k>>2]|0)+(B>>>3)|0;Ja=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(B&7)>>>29;xa=B+3|0;c[u>>2]=La>>>0>xa>>>0?xa:La;c[f+23200+(Ra*4864|0)+(o*2432|0)+44>>2]=Ja;Ja=c[A>>2]|0;xa=C<<24>>24==2;do{if(xa){C=f+23200+(Ra*4864|0)+(o*2432|0)+52|0;if((Ja|0)==8){c[C>>2]=36;cb=36;break}else{c[C>>2]=18;cb=18;break}}else{if((Ja|0)<3){c[f+23200+(Ra*4864|0)+(o*2432|0)+52>>2]=18;cb=18;break}C=f+23200+(Ra*4864|0)+(o*2432|0)+52|0;if((Ja|0)==8){c[C>>2]=54;cb=54;break}else{c[C>>2]=27;cb=27;break}}}while(0);c[f+23200+(Ra*4864|0)+(o*2432|0)+56>>2]=288;Ya=cb;Za=288;_a=xa;$a=Ia;ab=Ja;bb=f+23200+(Ra*4864|0)+(o*2432|0)+52|0}C=(Ya|0)>(Ha|0)?Ha:Ya;c[bb>>2]=C;B=Za>>>0>Ha>>>0?Ha:Za;c[f+23200+(Ra*4864|0)+(o*2432|0)+56>>2]=B-C;c[f+23200+(Ra*4864|0)+(o*2432|0)+60>>2]=(Ha>>>0<288>>>0?Ha:288)-B;do{if(_a){if($a<<24>>24==0){c[f+23200+(Ra*4864|0)+(o*2432|0)+72>>2]=0;c[f+23200+(Ra*4864|0)+(o*2432|0)+68>>2]=0;db=Ga;break}if((ab|0)==8){QIb(c[n>>2]|0,2389040,(eb=i,i=i+1|0,i=i+7&-8,c[eb>>2]=0,eb)|0);i=eb;fb=c[A>>2]|0;gb=c[Ba>>2]|0}else{fb=ab;gb=Ga}c[f+23200+(Ra*4864|0)+(o*2432|0)+72>>2]=(fb|0)<3?8:6;c[f+23200+(Ra*4864|0)+(o*2432|0)+68>>2]=3;db=gb}else{c[f+23200+(Ra*4864|0)+(o*2432|0)+68>>2]=13;c[f+23200+(Ra*4864|0)+(o*2432|0)+72>>2]=22;db=Ga}}while(0);Ga=f+23200+(Ra*4864|0)+(o*2432|0)+64|0;c[Ga>>2]=0;Ha=c[u>>2]|0;if((db|0)==0){Ja=c[k>>2]|0;Ia=d[Ja+(Ha>>>3)|0]<<(Ha&7)>>>7;xa=c[y>>2]|0;B=((Ha|0)<(xa|0))+Ha|0;c[u>>2]=B;c[Ga>>2]=Ia&1;hb=B;ib=Ja;jb=xa}else{hb=Ha;ib=c[k>>2]|0;jb=c[y>>2]|0}Ha=d[ib+(hb>>>3)|0]<<(hb&7)>>>7;c[u>>2]=((hb|0)<(jb|0))+hb;a[f+23200+(Ra*4864|0)+(o*2432|0)+48|0]=Ha&1;Ha=c[u>>2]|0;xa=d[ib+(Ha>>>3)|0]<<(Ha&7)>>>7;c[u>>2]=((Ha|0)<(jb|0))+Ha;a[f+23200+(Ra*4864|0)+(o*2432|0)+49|0]=xa&1;xa=Ra+1|0;Ha=c[Ka>>2]|0;if((xa|0)<(Ha|0)){Ra=xa;La=jb;Ma=ib}else{kb=Ha;lb=jb;mb=ib;break}}}else{kb=Na;lb=Pa;mb=Oa}Ma=o+1|0;if((Ma|0)<(Ua|0)){o=Ma;Na=kb;Pa=lb;Oa=mb}else{Ca=155;break}}if((Ca|0)==123){KIb(c[n>>2]|0,16,2419816,(eb=i,i=i+1|0,i=i+7&-8,c[eb>>2]=0,eb)|0);i=eb;nb=-1094995529}else if((Ca|0)==131){KIb(c[n>>2]|0,16,2410600,(eb=i,i=i+1|0,i=i+7&-8,c[eb>>2]=0,eb)|0);i=eb;nb=-1094995529}else if((Ca|0)==155){do{if((c[f+32928>>2]|0)==0){Oa=c[u>>2]|0;Pa=(c[v>>2]|0)-Oa>>3;if((Pa|0)<0){ob=0}else{ob=(Pa|0)>24?24:Pa}Pa=f+40|0;Na=f+1088|0;nrc((c[Na>>2]|0)+(f+40)|0,mb+(Oa>>3)|0,ob)|0;Oa=f+1116|0;o=Oa;Ma=t;c[o>>2]=c[Ma>>2];c[o+4>>2]=c[Ma+4>>2];c[o+8>>2]=c[Ma+8>>2];c[o+12>>2]=c[Ma+12>>2];c[o+16>>2]=c[Ma+16>>2];La=c[Na>>2]|0;Ra=La<<3;Ha=Ra>>>0>2147483639>>>0|(Pa|0)==0;xa=Ha?0:Pa;Pa=Ha?0:Ra;c[k>>2]=xa;c[v>>2]=Pa;c[z>>2]=xa+(Pa>>3);c[u>>2]=0;xa=1048-La|0;c[y>>2]=Pa+8+(((ob|0)>(xa|0)?ob:xa)<<3);c[Na>>2]=Ra;xa=0;Pa=Ra;while(1){if((Pa>>3|0)>=(Va|0)){pb=xa;qb=Pa;break}if((c[Ka>>2]|0)>0){Ra=xa*18|0;La=0;Ha=Pa;while(1){c[Na>>2]=(c[f+23200+(La*4864|0)+(xa*2432|0)+4>>2]|0)+Ha;mrc(f+23200+(La*4864|0)+(xa*2432|0)+128|0,0,2304)|0;LSa(f,f+23200+(La*4864|0)+(xa*2432|0)|0,f+9376+(La*4608|0)+(Ra<<7)|0,f+18592+(La*2304|0)|0);Ja=La+1|0;B=c[Na>>2]|0;if((Ja|0)<(c[Ka>>2]|0)){La=Ja;Ha=B}else{rb=B;break}}}else{rb=Pa}Ha=xa+1|0;if((Ha|0)<(Ua|0)){xa=Ha;Pa=rb}else{pb=Ha;qb=rb;break}}Pa=qb-(Va<<3)|0;xa=c[v>>2]|0;do{if((Pa|0)<(xa|0)){Ca=170}else{Na=Oa|0;if((c[Na>>2]|0)==0){Ca=170;break}Ha=Pa-xa|0;La=f+1124|0;Ra=c[La>>2]|0;B=-Ra|0;Ja=(c[f+1132>>2]|0)-Ra|0;if((Ha|0)<(B|0)){sb=B}else{sb=(Ja|0)<(Ha|0)?Ja:Ha}c[La>>2]=sb+Ra;c[Ma>>2]=c[o>>2];c[Ma+4>>2]=c[o+4>>2];c[Ma+8>>2]=c[o+8>>2];c[Ma+12>>2]=c[o+12>>2];c[Ma+16>>2]=c[o+16>>2];c[Na>>2]=0}}while(0);if((Ca|0)==170){xa=c[u>>2]|0;Na=-xa|0;Ra=(c[y>>2]|0)-xa|0;if((Pa|0)<(Na|0)){tb=Na}else{tb=(Ra|0)<(Pa|0)?Ra:Pa}c[u>>2]=tb+xa}if((pb|0)>=(Ua|0)){break}ub=pb;vb=c[Ka>>2]|0;wb=Oa;xb=Ma;yb=o;Ca=175}else{xa=f+1116|0;ub=0;vb=kb;wb=xa;xb=t;yb=xa;Ca=175}}while(0);if((Ca|0)==175){xa=f+28|0;Ra=f+32996|0;Na=p|0;La=p+4|0;Ha=p+8|0;Ja=q;B=q|0;Ia=r|0;Ga=wb|0;C=f+32936|0;Ea=s|0;Fa=s+12|0;V=s+8|0;W=s+4|0;E=ub;Da=0;va=vb;while(1){wa=Da+ub|0;if((va|0)>0){ua=0;ta=c[u>>2]|0;while(1){sa=f+23200+(ua*4864|0)+(wa*2432|0)+76|0;do{if((c[Ba>>2]|0)==0){ra=c[f+23200+(ua*4864|0)+(E*2432|0)+16>>2]|0;K=a[564424+ra|0]|0;F=K&255;m=a[564440+ra|0]|0;ra=m&255;if((a[f+23200+(ua*4864|0)+(E*2432|0)+20|0]|0)==2){D=(a[f+23200+(ua*4864|0)+(E*2432|0)+21|0]|0)!=0?17:18;b:do{if(K<<24>>24==0){mrc(sa|0,0,D|0)|0}else{ma=32-F|0;M=0;la=ta;while(1){ka=c[y>>2]|0;ja=(c[k>>2]|0)+(la>>>3)|0;H=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(la&7)>>>(ma>>>0);ja=la+F|0;c[u>>2]=ka>>>0>ja>>>0?ja:ka;ka=M+1|0;a[f+23200+(ua*4864|0)+(E*2432|0)+76+M|0]=H;if((ka|0)>=(D|0)){break b}M=ka;la=c[u>>2]|0}}}while(0);if(m<<24>>24==0){mrc(f+23200+(ua*4864|0)+(wa*2432|0)+76+D|0,0,21)|0;break}K=32-ra|0;la=D;M=0;while(1){ma=c[u>>2]|0;ka=c[y>>2]|0;H=(c[k>>2]|0)+(ma>>>3)|0;ja=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(ma&7)>>>(K>>>0);H=ma+ra|0;c[u>>2]=ka>>>0>H>>>0?H:ka;a[f+23200+(ua*4864|0)+(E*2432|0)+76+la|0]=ja;ja=M+1|0;if((ja|0)<18){la=la+1|0;M=ja}else{break}}mrc(D+18+(f+23200+(ua*4864|0)+(wa*2432|0)+76)|0,0,3)|0;break}else{M=f+23200+(ua*4864|0)+(E*2432|0)|0;la=0;K=0;while(1){m=(la|0)==0?6:5;c:do{if((d[M]&8>>>(la>>>0)|0)==0){ja=(la|0)<2?F:ra;if((ja|0)==0){mrc(f+23200+(ua*4864|0)+(wa*2432|0)+76+K|0,0,m|0)|0;break}ka=32-ja|0;H=K;ma=1;while(1){L=c[u>>2]|0;I=c[y>>2]|0;N=(c[k>>2]|0)+(L>>>3)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(L&7)>>>(ka>>>0);N=L+ja|0;c[u>>2]=I>>>0>N>>>0?N:I;a[f+23200+(ua*4864|0)+(E*2432|0)+76+H|0]=O;if((ma|0)>=(m|0)){break c}H=H+1|0;ma=ma+1|0}}else{ma=K;H=0;while(1){a[f+23200+(ua*4864|0)+(E*2432|0)+76+ma|0]=a[f+23200+(ua*4864|0)+76+ma|0]|0;ja=H+1|0;if((ja|0)<(m|0)){ma=ma+1|0;H=ja}else{break}}}}while(0);H=la+1|0;if((H|0)<4){la=H;K=m+K|0}else{break}}a[f+23200+(ua*4864|0)+(E*2432|0)+97|0]=0;break}}else{if((a[f+23200+(ua*4864|0)+(E*2432|0)+20|0]|0)==2){zb=(a[f+23200+(ua*4864|0)+(E*2432|0)+21|0]|0)!=0?2:1}else{zb=0}K=c[f+23200+(ua*4864|0)+(E*2432|0)+16>>2]|0;do{if((c[x>>2]&1|0)!=0&(ua|0)==1){la=K>>1;if((la|0)<180){c[Fa>>2]=0;ra=(la*171|0)>>10;c[V>>2]=(ra*-6|0)+la;F=(ra*171|0)>>10;c[W>>2]=(F*-6|0)+ra;c[Ea>>2]=F;Ab=3;Bb=F;break}if((la|0)<244){F=la-180|0;c[Fa>>2]=0;c[V>>2]=F&3;c[W>>2]=F>>>2&3;ra=F>>4;c[Ea>>2]=ra;Ab=4;Bb=ra;break}else{ra=la-244|0;c[Fa>>2]=0;c[V>>2]=0;la=(ra*171|0)>>9;c[W>>2]=(la*-3|0)+ra;c[Ea>>2]=la;Ab=5;Bb=la;break}}else{if((K|0)<400){c[Fa>>2]=K&3;c[V>>2]=K>>>2&3;la=K>>4;ra=(la*205|0)>>10;c[W>>2]=(ra*-5|0)+la;c[Ea>>2]=ra;Ab=0;Bb=ra;break}if((K|0)<500){ra=K-400|0;c[Fa>>2]=0;c[V>>2]=ra&3;la=ra>>2;ra=(la*205|0)>>10;c[W>>2]=(ra*-5|0)+la;c[Ea>>2]=ra;Ab=1;Bb=ra;break}else{ra=K-500|0;c[Fa>>2]=0;c[V>>2]=0;la=(ra*171|0)>>9;c[W>>2]=(la*-3|0)+ra;c[Ea>>2]=la;c[f+23200+(ua*4864|0)+(E*2432|0)+64>>2]=1;Ab=2;Bb=la;break}}}while(0);K=0;la=0;ra=Bb;while(1){F=a[884320+(Ab*12|0)+(zb<<2)+K|0]|0;M=F&255;D=F<<24>>24==0;do{if((ra|0)==0){if(D){Cb=la;break}F=M>>>0>1>>>0?M:1;mrc(f+23200+(ua*4864|0)+(wa*2432|0)+76+la|0,0,F|0)|0;Cb=F+la|0}else{if(D){Cb=la;break}F=32-ra|0;H=M>>>0>1>>>0;ma=la;ja=1;while(1){ka=c[u>>2]|0;O=c[y>>2]|0;I=(c[k>>2]|0)+(ka>>>3)|0;N=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(ka&7)>>>(F>>>0);I=ka+ra|0;c[u>>2]=O>>>0>I>>>0?I:O;a[f+23200+(ua*4864|0)+(E*2432|0)+76+ma|0]=N;if((ja|0)>=(M|0)){break}ma=ma+1|0;ja=ja+1|0}Cb=(H?M:1)+la|0}}while(0);M=K+1|0;if((M|0)>=4){break}K=M;la=Cb;ra=c[s+(M<<2)>>2]|0}if((Cb|0)>=40){break}mrc(f+23200+(ua*4864|0)+(wa*2432|0)+76+Cb|0,0,40-Cb|0)|0}}while(0);sa=c[A>>2]|0;ra=c[f+23200+(ua*4864|0)+(E*2432|0)+12>>2]|0;la=(d[f+23200+(ua*4864|0)+(E*2432|0)+48|0]|0)+1|0;K=c[f+23200+(ua*4864|0)+(E*2432|0)+64>>2]|0;M=c[f+23200+(ua*4864|0)+(E*2432|0)+72>>2]|0;if((M|0)>0){D=ra+190|0;m=0;ja=Ia;while(1){ma=a[1959872+(sa*22|0)+m|0]|0;if(ma<<24>>24==0){Db=ja}else{F=ma&255;ma=D-((d[f+23200+(ua*4864|0)+(E*2432|0)+76+m|0]|0)+(d[812296+(K*22|0)+m|0]|0)<<la)&65535;N=-F|0;O=F;I=ja;while(1){b[I>>1]=ma;ka=O-1|0;if((ka|0)>0){O=ka;I=I+2|0}else{break}}Db=ja+(F+1+((N|0)>-1?N:-1)<<1)|0}I=m+1|0;if((I|0)<(M|0)){m=I;ja=Db}else{Eb=Db;break}}}else{Eb=Ia}ja=c[f+23200+(ua*4864|0)+(E*2432|0)+68>>2]|0;if((ja|0)<13){m=ra+190|0;K=m-(c[f+23200+(ua*4864|0)+(E*2432|0)+36>>2]<<3)|0;D=m-(c[f+23200+(ua*4864|0)+(E*2432|0)+40>>2]<<3)|0;I=m-(c[f+23200+(ua*4864|0)+(E*2432|0)+44>>2]<<3)|0;m=ja;ja=M;O=Eb;while(1){ma=a[1959632+(sa*13|0)+m|0]|0;ka=ma&255;L=-ka|0;P=(L|0)>-1?L:-1;L=ja+1|0;if(ma<<24>>24==0){Fb=O}else{ma=K-(d[f+23200+(ua*4864|0)+(E*2432|0)+76+ja|0]<<la)&65535;J=ka;R=O;while(1){b[R>>1]=ma;U=J-1|0;if((U|0)>0){J=U;R=R+2|0}else{break}}R=ka+1+P|0;J=D-(d[f+23200+(ua*4864|0)+(E*2432|0)+76+L|0]<<la)&65535;ma=ka;N=O+(R<<1)|0;while(1){b[N>>1]=J;F=ma-1|0;if((F|0)>0){ma=F;N=N+2|0}else{break}}N=R<<1;ma=I-(d[ja+2+(f+23200+(ua*4864|0)+(E*2432|0)+76)|0]<<la)&65535;J=ka;L=O+(N<<1)|0;while(1){b[L>>1]=ma;P=J-1|0;if((P|0)>0){J=P;L=L+2|0}else{break}}Fb=O+(N+R<<1)|0}L=m+1|0;if((L|0)<13){m=L;ja=ja+3|0;O=Fb}else{break}}}O=(c[f+23200+(ua*4864|0)+(E*2432|0)+4>>2]|0)+ta|0;ja=c[v>>2]|0;m=O;la=(ja|0)<(O|0)?ja:O;O=0;ja=0;while(1){I=c[f+23200+(ua*4864|0)+(E*2432|0)+52+(O<<2)>>2]|0;d:do{if((I|0)==0){Gb=ja;Hb=la;Ib=m}else{D=c[f+23200+(ua*4864|0)+(E*2432|0)+24+(O<<2)>>2]|0;K=d[821128+(D<<1)|0]|0;sa=d[821129+(D<<1)|0]|0;if((16401>>>(D>>>0)&1|0)!=0){mrc(f+23200+(ua*4864|0)+(E*2432|0)+128+(ja<<2)|0,0,I<<3|0)|0;Gb=(I<<1)+ja|0;Hb=la;Ib=m;break}if((I|0)<=0){Gb=ja;Hb=la;Ib=m;break}M=5945604+(K*20|0)|0;K=D>>>0<16>>>0;D=32-sa|0;ra=m;L=la;J=I;ma=ja;while(1){ka=c[u>>2]|0;if((ka|0)<(L|0)){Jb=L;Kb=ra;Lb=ka}else{do{if((c[Ga>>2]|0)==0){Mb=ka;Nb=L;Ob=ra}else{if((ka|0)<(c[v>>2]|0)){Mb=ka;Nb=L;Ob=ra;break}c[xb>>2]=c[yb>>2];c[xb+4>>2]=c[yb+4>>2];c[xb+8>>2]=c[yb+8>>2];c[xb+12>>2]=c[yb+12>>2];c[xb+16>>2]=c[yb+16>>2];c[Ga>>2]=0;P=ka-L|0;F=c[u>>2]|0;U=-F|0;Q=(c[y>>2]|0)-F|0;if((P|0)<(U|0)){Pb=U}else{Pb=(Q|0)<(P|0)?Q:P}P=Pb+F|0;c[u>>2]=P;F=P+(ra-ka)|0;Mb=P;Nb=F;Ob=F}}while(0);if((Mb|0)<(Nb|0)){Jb=Nb;Kb=Ob;Lb=Mb}else{Gb=ma;Hb=Nb;Ib=Ob;break d}}ka=c[M>>2]|0;H=c[y>>2]|0;F=c[k>>2]|0;P=F+(Lb>>>3)|0;Q=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Lb&7)>>>25;P=b[ka+(Q<<2)>>1]|0;U=b[ka+(Q<<2)+2>>1]|0;Q=U<<16>>16;do{if(U<<16>>16<0){T=Lb+7|0;S=H>>>0>T>>>0?T:H;T=F+(S>>>3)|0;X=((je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(S&7)>>>((Q+32|0)>>>0))+P|0;T=b[ka+(X<<2)>>1]|0;_=b[ka+(X<<2)+2>>1]|0;X=_<<16>>16;if(!(_<<16>>16<0)){Qb=X;Rb=T;Sb=S;break}_=S-Q|0;S=H>>>0>_>>>0?_:H;_=F+(S>>>3)|0;qa=((je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(S&7)>>>((X+32|0)>>>0))+T|0;Qb=b[ka+(qa<<2)+2>>1]|0;Rb=b[ka+(qa<<2)>>1]|0;Sb=S}else{Qb=Q;Rb=P;Sb=Lb}}while(0);P=Qb+Sb|0;Q=H>>>0>P>>>0?P:H;c[u>>2]=Q;do{if((Rb|0)==0){g[f+23200+(ua*4864|0)+(E*2432|0)+128+(ma+1<<2)>>2]=0.0;g[f+23200+(ua*4864|0)+(E*2432|0)+128+(ma<<2)>>2]=0.0}else{P=b[r+(ma<<1)>>1]|0;ka=Rb>>5;U=Rb&15;if((Rb&16|0)==0){S=ka+U|0;if((S|0)<15){qa=c[8839800+(P<<6)+(S<<2)>>2]|0;T=d[F+(Q>>>3)|0]<<(Q&7)>>>7;c[u>>2]=((Q|0)<(H|0))+Q;c[f+23200+(ua*4864|0)+(E*2432|0)+128+(((U|0)!=0)+ma<<2)>>2]=T<<31^qa}else{if(K){Tb=0;Ub=Q}else{qa=F+(Q>>>3)|0;T=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Q&7)>>>(D>>>0);qa=Q+sa|0;X=H>>>0>qa>>>0?qa:H;c[u>>2]=X;Tb=T;Ub=X}X=Tb+S<<2|P&3;S=(a[5017800+X|0]|0)-(P>>2)|0;if((S|0)>31){Vb=0}else{Vb=((c[4755176+(X<<2)>>2]|0)+(1<<S-1)|0)>>>(S>>>0)}S=d[F+(Ub>>>3)|0]|0;c[u>>2]=((Ub|0)<(H|0))+Ub;g[f+23200+(ua*4864|0)+(E*2432|0)+128+(((U|0)!=0)+ma<<2)>>2]=+(((S&128>>>((Ub&7)>>>0)|0)==0?Vb:-Vb|0)|0)}g[f+23200+(ua*4864|0)+(E*2432|0)+128+(((U|0)==0)+ma<<2)>>2]=0.0;break}if((ka|0)<15){S=c[8839800+(P<<6)+(ka<<2)>>2]|0;X=d[F+(Q>>>3)|0]<<(Q&7)>>>7;c[u>>2]=((Q|0)<(H|0))+Q;c[f+23200+(ua*4864|0)+(E*2432|0)+128+(ma<<2)>>2]=X<<31^S}else{if(K){Wb=0;Xb=Q}else{S=F+(Q>>>3)|0;X=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Q&7)>>>(D>>>0);S=Q+sa|0;T=H>>>0>S>>>0?S:H;c[u>>2]=T;Wb=X;Xb=T}T=Wb+ka<<2|P&3;ka=(a[5017800+T|0]|0)-(P>>2)|0;if((ka|0)>31){Yb=0}else{Yb=((c[4755176+(T<<2)>>2]|0)+(1<<ka-1)|0)>>>(ka>>>0)}ka=d[F+(Xb>>>3)|0]|0;c[u>>2]=((Xb|0)<(H|0))+Xb;g[f+23200+(ua*4864|0)+(E*2432|0)+128+(ma<<2)>>2]=+(((ka&128>>>((Xb&7)>>>0)|0)==0?Yb:-Yb|0)|0)}if((U|0)!=15){ka=c[8839800+(P<<6)+(U<<2)>>2]|0;U=c[u>>2]|0;T=d[(c[k>>2]|0)+(U>>>3)|0]<<(U&7)>>>7;c[u>>2]=((U|0)<(c[y>>2]|0))+U;c[f+23200+(ua*4864|0)+(E*2432|0)+128+(ma+1<<2)>>2]=T<<31^ka;break}if(K){Zb=60}else{ka=c[u>>2]|0;T=c[y>>2]|0;U=(c[k>>2]|0)+(ka>>>3)|0;X=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(ka&7)>>>(D>>>0);U=ka+sa|0;c[u>>2]=T>>>0>U>>>0?U:T;Zb=(X<<2)+60|0}X=Zb|P&3;T=(a[5017800+X|0]|0)-(P>>2)|0;if((T|0)>31){_b=0}else{_b=((c[4755176+(X<<2)>>2]|0)+(1<<T-1)|0)>>>(T>>>0)}T=c[u>>2]|0;X=d[(c[k>>2]|0)+(T>>>3)|0]|0;c[u>>2]=((T|0)<(c[y>>2]|0))+T;g[f+23200+(ua*4864|0)+(E*2432|0)+128+(ma+1<<2)>>2]=+(((X&128>>>((T&7)>>>0)|0)==0?_b:-_b|0)|0)}}while(0);H=ma+2|0;F=J-1|0;if((F|0)>0){ra=Kb;L=Jb;J=F;ma=H}else{Gb=H;Hb=Jb;Ib=Kb;break}}}}while(0);I=O+1|0;if((I|0)<3){m=Ib;la=Hb;O=I;ja=Gb}else{break}}ja=d[f+23200+(ua*4864|0)+(E*2432|0)+49|0]|0;e:do{if((Gb|0)<573){O=5947460+(ja*20|0)|0;la=5947456+(ja*20|0)|0;m=Ib;I=Hb;R=0;N=Gb;while(1){$b=c[u>>2]|0;if(($b|0)<(I|0)){ac=$b;bc=I;cc=m}else{if(!(($b|0)<=(m|0)|(R|0)==0)){break}do{if((c[Ga>>2]|0)==0){dc=$b;ec=I;fc=m}else{if(($b|0)<(c[v>>2]|0)){dc=$b;ec=I;fc=m;break}c[xb>>2]=c[yb>>2];c[xb+4>>2]=c[yb+4>>2];c[xb+8>>2]=c[yb+8>>2];c[xb+12>>2]=c[yb+12>>2];c[xb+16>>2]=c[yb+16>>2];c[Ga>>2]=0;ma=$b-I|0;J=c[u>>2]|0;L=-J|0;ra=(c[y>>2]|0)-J|0;if((ma|0)<(L|0)){gc=L}else{gc=(ra|0)<(ma|0)?ra:ma}ma=gc+J|0;c[u>>2]=ma;J=ma+(m-$b)|0;dc=ma;ec=J;fc=J}}while(0);if((dc|0)<(ec|0)){ac=dc;bc=ec;cc=fc}else{hc=N;ic=ec;jc=fc;break e}}J=c[O>>2]|0;ma=c[la>>2]|0;ra=c[y>>2]|0;L=c[k>>2]|0;sa=L+(ac>>>3)|0;D=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ac&7)>>>((32-ma|0)>>>0);ma=b[J+(D<<2)>>1]|0;sa=(b[J+(D<<2)+2>>1]|0)+ac|0;D=ra>>>0>sa>>>0?sa:ra;c[u>>2]=D;g[f+23200+(ua*4864|0)+(E*2432|0)+128+(N+3<<2)>>2]=0.0;g[f+23200+(ua*4864|0)+(E*2432|0)+128+(N+2<<2)>>2]=0.0;g[f+23200+(ua*4864|0)+(E*2432|0)+128+(N+1<<2)>>2]=0.0;g[f+23200+(ua*4864|0)+(E*2432|0)+128+(N<<2)>>2]=0.0;f:do{if(!(ma<<16>>16==0)){sa=ma<<16>>16;J=D;K=L;M=ra;while(1){H=c[1078616+(sa<<2)>>2]|0;F=H+N|0;Q=8>>>(H>>>0);H=c[8972408+(b[r+(F<<1)>>1]<<2)>>2]|0;T=d[K+(J>>>3)|0]<<(J&7)>>>7;c[u>>2]=((J|0)<(M|0))+J;c[f+23200+(ua*4864|0)+(E*2432|0)+128+(F<<2)>>2]=T<<31^H;if((Q|0)==(sa|0)){break f}sa=Q^sa;J=c[u>>2]|0;K=c[k>>2]|0;M=c[y>>2]|0}}}while(0);ra=N+4|0;if((ra|0)<573){m=cc;I=bc;R=ac;N=ra}else{hc=ra;ic=bc;jc=cc;break e}}la=R-$b|0;O=-$b|0;ra=(c[y>>2]|0)-$b|0;if((la|0)<(O|0)){kc=O}else{kc=(ra|0)<(la|0)?ra:la}c[u>>2]=kc+$b;KIb(c[n>>2]|0,32,2402904,(eb=i,i=i+24|0,c[eb>>2]=la,c[eb+8>>2]=I-$b,c[eb+16>>2]=m-$b,eb)|0);i=eb;hc=(c[C>>2]&131074|0)==0?N-4|0:0;ic=I;jc=m}else{hc=Gb;ic=Hb;jc=Ib}}while(0);ja=jc-(c[u>>2]|0)|0;do{if((ja|0)<0){if((c[C>>2]&131076|0)==0){Ca=308;break}KIb(c[n>>2]|0,16,2395992,(eb=i,i=i+8|0,c[eb>>2]=ja,eb)|0);i=eb;lc=0}else{Ca=308}}while(0);do{if((Ca|0)==308){Ca=0;if((ja|0)<=0){lc=hc;break}if((c[C>>2]&262148|0)==0){lc=hc;break}KIb(c[n>>2]|0,16,2395992,(eb=i,i=i+8|0,c[eb>>2]=ja,eb)|0);i=eb;lc=0}}while(0);mrc(f+23200+(ua*4864|0)+(E*2432|0)+128+(lc<<2)|0,0,576-lc<<2|0)|0;la=c[u>>2]|0;ra=-la|0;O=(c[y>>2]|0)-la|0;if((ja|0)<(ra|0)){mc=ra}else{mc=(O|0)<(ja|0)?O:ja}O=mc+la|0;c[u>>2]=O;do{if((c[Ga>>2]|0)==0){nc=O}else{if((O|0)<(c[v>>2]|0)){nc=O;break}c[xb>>2]=c[yb>>2];c[xb+4>>2]=c[yb+4>>2];c[xb+8>>2]=c[yb+8>>2];c[xb+12>>2]=c[yb+12>>2];c[xb+16>>2]=c[yb+16>>2];c[Ga>>2]=0;la=O-ic|0;ra=c[u>>2]|0;L=-ra|0;D=(c[y>>2]|0)-ra|0;if((la|0)<(L|0)){oc=L}else{oc=(D|0)<(la|0)?D:la}la=oc+ra|0;c[u>>2]=la;nc=la}}while(0);O=ua+1|0;ja=c[Ka>>2]|0;if((O|0)<(ja|0)){ua=O;ta=nc}else{pc=ja;break}}}else{pc=va}g:do{if((c[xa>>2]|0)==1){ta=c[x>>2]|0;if((ta&1|0)==0){if((ta&2|0)==0){qc=pc;break}ef[c[Ra>>2]&4095](f+23200+(E*2432|0)+128|0,f+28064+(E*2432|0)+128|0,576);qc=c[Ka>>2]|0;break}if((c[Ba>>2]|0)==0){rc=5831192;sc=7}else{rc=5830680+((c[f+28064+(E*2432|0)+16>>2]&1)<<7)|0;sc=16}ua=f+23200+(E*2432|0)+2432|0;wa=f+28064+(E*2432|0)+2432|0;c[Na>>2]=0;c[La>>2]=0;c[Ha>>2]=0;o=c[f+28064+(E*2432|0)+68>>2]|0;Ma=c[f+28064+(E*2432|0)+72>>2]|0;if((o|0)>12){tc=ua;uc=wa}else{Oa=c[A>>2]|0;Pa=(ta&2|0)==0;ja=12;O=Ma-3+((13-o|0)*3|0)|0;la=ua;ua=wa;while(1){wa=(ja|0)==11?O:O-3|0;ra=a[1959632+(Oa*13|0)+ja|0]|0;D=ra&255;L=-D|0;ma=ra<<24>>24==0;ra=Pa|ma;M=2;K=la;J=ua;while(1){sa=K+(L<<2)|0;Q=J+(L<<2)|0;H=p+(M<<2)|0;do{if((c[H>>2]|0)==0){T=0;while(1){if((T|0)>=(D|0)){break}if(+g[J+(T-D<<2)>>2]!=0.0){Ca=329;break}else{T=T+1|0}}if((Ca|0)==329){Ca=0;c[H>>2]=1;Ca=333;break}T=d[M+wa+(f+28064+(E*2432|0)+76)|0]|0;if(!(T>>>0<sc>>>0)){Ca=333;break}Qa=+g[rc+(T<<2)>>2];vc=+g[rc+64+(T<<2)>>2];if(ma){break}else{wc=0}do{T=wc-D|0;F=K+(T<<2)|0;xc=+g[F>>2];g[F>>2]=Qa*xc;g[J+(T<<2)>>2]=vc*xc;wc=wc+1|0;}while((wc|0)<(D|0))}else{Ca=333}}while(0);do{if((Ca|0)==333){Ca=0;if(ra){break}else{yc=0}do{H=yc-D|0;T=K+(H<<2)|0;vc=+g[T>>2];F=J+(H<<2)|0;Qa=+g[F>>2];g[T>>2]=(vc+Qa)*.7071067690849304;g[F>>2]=(vc-Qa)*.7071067690849304;yc=yc+1|0;}while((yc|0)<(D|0))}}while(0);if((M|0)<=0){break}M=M-1|0;K=sa;J=Q}J=D*-3|0;K=ua+(J<<2)|0;M=la+(J<<2)|0;J=ja-1|0;if((J|0)<(o|0)){tc=M;uc=K;break}else{ja=J;O=wa;la=M;ua=K}}}if((Ma|0)<=0){qc=pc;break}ua=c[A>>2]|0;la=(ta&2|0)==0;O=c[Na>>2]|c[La>>2]|c[Ha>>2];ja=tc;o=uc;Pa=Ma;while(1){Oa=(O|0)==0;K=ja;M=o;J=Pa;h:while(1){zc=J-1|0;Ac=a[1959872+(ua*22|0)+zc|0]|0;Bc=Ac&255;ra=-Bc|0;Cc=K+(ra<<2)|0;Dc=M+(ra<<2)|0;if(Oa){Ec=0}else{Fc=O;break}while(1){if((Ec|0)>=(Bc|0)){break}if(+g[M+(Ec-Bc<<2)>>2]!=0.0){Fc=1;break h}else{Ec=Ec+1|0}}Q=d[((zc|0)==21?20:zc)+(f+28064+(E*2432|0)+76)|0]|0;if(!(Q>>>0<sc>>>0)){Fc=O;break}Qa=+g[rc+(Q<<2)>>2];vc=+g[rc+64+(Q<<2)>>2];if(!(Ac<<24>>24==0)){Q=0;do{sa=Q-Bc|0;ra=K+(sa<<2)|0;xc=+g[ra>>2];g[ra>>2]=Qa*xc;g[M+(sa<<2)>>2]=vc*xc;Q=Q+1|0;}while((Q|0)<(Bc|0))}if((zc|0)>0){K=Cc;M=Dc;J=zc}else{qc=pc;break g}}if(!(la|Ac<<24>>24==0)){J=0;do{Oa=J-Bc|0;wa=K+(Oa<<2)|0;vc=+g[wa>>2];D=M+(Oa<<2)|0;Qa=+g[D>>2];g[wa>>2]=(vc+Qa)*.7071067690849304;g[D>>2]=(vc-Qa)*.7071067690849304;J=J+1|0;}while((J|0)<(Bc|0))}if((zc|0)>0){O=Fc;ja=Cc;o=Dc;Pa=zc}else{qc=pc;break}}}else{qc=pc}}while(0);if((qc|0)>0){Pa=E*18|0;o=0;while(1){ja=f+23200+(o*4864|0)+(E*2432|0)|0;O=f+23200+(o*4864|0)+(E*2432|0)+20|0;do{if((a[O]|0)==2){la=f+23200+(o*4864|0)+(E*2432|0)+21|0;ua=a[la]|0;do{if(ua<<24>>24==0){Gc=f+23200+(o*4864|0)+(E*2432|0)+128|0}else{if((c[A>>2]|0)==8){Gc=f+23200+(o*4864|0)+(E*2432|0)+416|0;break}else{Gc=f+23200+(o*4864|0)+(E*2432|0)+272|0;break}}}while(0);Ma=c[f+23200+(o*4864|0)+(E*2432|0)+68>>2]|0;if((Ma|0)<13){ta=Gc;J=Ma;while(1){Ma=a[1959632+((c[A>>2]|0)*13|0)+J|0]|0;M=Ma&255;K=M<<1;if(Ma<<24>>24==0){Hc=ta}else{Ma=-M|0;D=M;wa=ta;Oa=B;while(1){g[Oa>>2]=+g[wa>>2];g[Oa+4>>2]=+g[wa+(M<<2)>>2];g[Oa+8>>2]=+g[wa+(K<<2)>>2];Q=D-1|0;if((Q|0)>0){D=Q;wa=wa+4|0;Oa=Oa+12|0}else{break}}Hc=ta+(M+1+((Ma|0)>-1?Ma:-1)<<2)|0}nrc(ta|0,Ja|0,M*12|0)|0;Oa=J+1|0;if((Oa|0)>=13){break}ta=Hc+(K<<2)|0;J=Oa}if((a[O]|0)!=2){Ic=31;Ca=371;break}Jc=a[la]|0}else{Jc=ua}if(!(Jc<<24>>24==0)){Ic=1;Ca=371}}else{Ic=31;Ca=371}}while(0);if((Ca|0)==371){Ca=0;O=Ic;J=f+23200+(o*4864|0)+(E*2432|0)+200|0;while(1){ta=J-4|0;Qa=+g[ta>>2];vc=+g[J>>2];g[ta>>2]=Qa*+g[2443104]-vc*+g[2443105];g[J>>2]=Qa*+g[2443105]+vc*+g[2443104];ta=J-8|0;vc=+g[ta>>2];Oa=J+4|0;Qa=+g[Oa>>2];g[ta>>2]=vc*+g[2443108]-Qa*+g[2443109];g[Oa>>2]=vc*+g[2443109]+Qa*+g[2443108];Oa=J-12|0;Qa=+g[Oa>>2];ta=J+8|0;vc=+g[ta>>2];g[Oa>>2]=Qa*+g[2443112]-vc*+g[2443113];g[ta>>2]=Qa*+g[2443113]+vc*+g[2443112];ta=J-16|0;vc=+g[ta>>2];Oa=J+12|0;Qa=+g[Oa>>2];g[ta>>2]=vc*+g[2443116]-Qa*+g[2443117];g[Oa>>2]=vc*+g[2443117]+Qa*+g[2443116];Oa=J-20|0;Qa=+g[Oa>>2];ta=J+16|0;vc=+g[ta>>2];g[Oa>>2]=Qa*+g[2443120]-vc*+g[2443121];g[ta>>2]=Qa*+g[2443121]+vc*+g[2443120];ta=J-24|0;vc=+g[ta>>2];Oa=J+20|0;Qa=+g[Oa>>2];g[ta>>2]=vc*+g[2443124]-Qa*+g[2443125];g[Oa>>2]=vc*+g[2443125]+Qa*+g[2443124];Oa=J-28|0;Qa=+g[Oa>>2];ta=J+24|0;vc=+g[ta>>2];g[Oa>>2]=Qa*+g[2443128]-vc*+g[2443129];g[ta>>2]=Qa*+g[2443129]+vc*+g[2443128];ta=J-32|0;vc=+g[ta>>2];Oa=J+28|0;Qa=+g[Oa>>2];g[ta>>2]=vc*+g[2443132]-Qa*+g[2443133];g[Oa>>2]=vc*+g[2443133]+Qa*+g[2443132];Oa=O-1|0;if((Oa|0)>0){O=Oa;J=J+72|0}else{break}}}LSa(f,ja,f+9376+(o*4608|0)+(Pa<<7)|0,f+18592+(o*2304|0)|0);J=o+1|0;O=c[Ka>>2]|0;if((J|0)<(O|0)){o=J}else{Kc=O;break}}}else{Kc=qc}o=E+1|0;if((o|0)<(Ua|0)){E=o;Da=Da+1|0;va=Kc}else{break}}}va=c[u>>2]|0;if((va|0)<0){Da=-va|0;E=(c[y>>2]|0)-va|0;c[u>>2]=((E|0)<(Da|0)?E:Da)+va}nb=Ua*18|0}va=f+1088|0;c[va>>2]=0;Da=f+1116|0;E=Da|0;if((c[E>>2]|0)!=0){Ka=c[u>>2]|0;Ja=-Ka&7;if((Ja|0)==0){Lc=Ka}else{B=c[y>>2]|0;A=Ja+Ka|0;Ka=B>>>0>A>>>0?A:B;c[u>>2]=Ka;Lc=Ka}Ka=(c[v>>2]|0)-Lc>>3;if(Ka>>>0<513>>>0){orc(f+40|0,(c[k>>2]|0)+(Lc>>3)|0,Ka|0)|0;c[va>>2]=Ka}else{KIb(c[n>>2]|0,16,2477968,(eb=i,i=i+8|0,c[eb>>2]=Ka,eb)|0);i=eb}Ka=t;B=Da;c[Ka>>2]=c[B>>2];c[Ka+4>>2]=c[B+4>>2];c[Ka+8>>2]=c[B+8>>2];c[Ka+12>>2]=c[B+12>>2];c[Ka+16>>2]=c[B+16>>2];c[E>>2]=0}E=c[u>>2]|0;B=-E&7;if((B|0)==0){Mc=E}else{Ka=c[y>>2]|0;Da=B+E|0;E=Ka>>>0>Da>>>0?Da:Ka;c[u>>2]=E;Mc=E}E=(c[v>>2]|0)-Mc>>3;Ka=(nb|0)<0;if(E>>>0>512>>>0|Ka){if((E|0)<0){KIb(c[n>>2]|0,16,2468360,(eb=i,i=i+8|0,c[eb>>2]=E,eb)|0);i=eb}Nc=(j|0)<512?j:512}else{Nc=E}nrc((c[va>>2]|0)+(f+40)|0,(c[k>>2]|0)+(j-Nc)|0,Nc)|0;c[va>>2]=(c[va>>2]|0)+Nc;if(Ka){Oc=nb}else{ya=nb;break}i=l;return Oc|0}}while(0);do{if((h|0)==0){nb=f+33004|0;Nc=c[nb>>2]|0;if((Nc|0)==0){KIb(0,0,2459056,(eb=i,i=i+24|0,c[eb>>2]=2442144,c[eb+8>>2]=2430208,c[eb+16>>2]=1606,eb)|0);i=eb;Hd();return 0}j=c[f+32940>>2]|0;c[Nc+76>>2]=c[j+424>>2];k=M4a(j,Nc,0)|0;if((k|0)<0){Oc=k;i=l;return Oc|0}else{Pc=c[(c[nb>>2]|0)+64>>2]|0;break}}else{Pc=h}}while(0);h=f+24|0;eb=c[h>>2]|0;if((eb|0)>0){nb=f+32940|0;k=(ya|0)>0;Nc=f+32944|0;j=f+32932|0;Mc=0;v=eb;while(1){if((c[(c[nb>>2]|0)+420>>2]|0)==8){Qc=1;Rc=c[Pc+(Mc<<2)>>2]|0}else{Qc=v;Rc=(c[Pc>>2]|0)+(Mc<<2)|0}if(k){u=f+1152+(Mc<<12)|0;y=f+9344+(Mc<<2)|0;t=Qc<<5;Lc=0;Ua=Rc;while(1){WSa(Nc,u,y,7687744,j,Ua,Qc,f+9376+(Mc*4608|0)+(Lc<<7)|0);Kc=Lc+1|0;if((Kc|0)<(ya|0)){Lc=Kc;Ua=Ua+(t<<2)|0}else{break}}Sc=c[h>>2]|0}else{Sc=v}t=Mc+1|0;if((t|0)<(Sc|0)){Mc=t;v=Sc}else{Tc=Sc;break}}}else{Tc=eb}Oc=ca(ya<<7,Tc)|0;i=l;return Oc|0}function LSa(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;j=i;i=i+48|0;k=j|0;l=e+128|0;m=e+272|0;n=e+2432|0;while(1){if(n>>>0<m>>>0){o=n;break}p=n-24|0;if((c[n-20>>2]|c[p>>2]|c[n-16>>2]|c[n-12>>2]|c[n-8>>2]|c[n-4>>2]|0)==0){n=p}else{o=p;break}}n=((o-l>>2|0)/18|0)+1|0;o=a[e+20|0]|0;m=e+21|0;if(o<<24>>24==2){q=(a[m]|0)==0?0:2}else{q=n}_e[c[b+32960>>2]&511](f,h,l,q,d[m]|0,o&255);o=h+(((q>>2)*72|0|q&3)<<2)|0;if((q|0)<(n|0)){h=k|0;m=k+40|0;l=k+28|0;b=k+16|0;p=k+4|0;r=k+36|0;s=k+32|0;t=k+12|0;u=k+8|0;v=k+20|0;w=k+44|0;x=k+24|0;y=o;z=q;A=e+128+((q*18|0)<<2)|0;e=f+(q+192<<2)|0;B=f+(q+384<<2)|0;while(1){g[f+(z<<2)>>2]=+g[y>>2];q=y+16|0;g[f+(z+32<<2)>>2]=+g[q>>2];C=y+32|0;g[f+(z+64<<2)>>2]=+g[C>>2];D=y+48|0;g[f+(z+96<<2)>>2]=+g[D>>2];E=y+64|0;g[f+(z+128<<2)>>2]=+g[E>>2];F=y+80|0;g[f+(z+160<<2)>>2]=+g[F>>2];G=-(z&1)&4|2;H=+g[A>>2];I=+g[A+12>>2];J=H+I;K=+g[A+24>>2];L=+g[A+36>>2];M=K+L;N=+g[A+48>>2];O=L+N;L=M+(N+ +g[A+60>>2]);N=(I+K)*.8660253882408142;K=(J+M)*1.7320507764816284;M=H-O;I=(J-L)*.7071067690849304;P=M+I;g[m>>2]=P;g[l>>2]=P;P=M-I;g[b>>2]=P;g[p>>2]=P;P=H+O*.5;O=N+P;H=J*2.0+L;L=(K+H)*.258819043636322;J=O+L;g[r>>2]=J;g[s>>2]=J;J=O-L;g[t>>2]=J;g[u>>2]=J;J=P-N;N=(H-K)*.9659258127212524;K=J-N;g[v>>2]=K;g[h>>2]=K;H=J+N;g[w>>2]=H;g[x>>2]=H;Q=7693888+(G*160|0)|0;g[e>>2]=+g[Q>>2]*K+ +g[y+96>>2];R=7693912+(G*160|0)|0;S=y+192|0;g[S>>2]=+g[R>>2]*+g[x>>2];T=7693892+(G*160|0)|0;g[e+128>>2]=+g[T>>2]*+g[p>>2]+ +g[y+112>>2];U=7693916+(G*160|0)|0;V=y+208|0;g[V>>2]=+g[U>>2]*+g[l>>2];W=7693896+(G*160|0)|0;g[e+256>>2]=+g[W>>2]*+g[u>>2]+ +g[y+128>>2];X=7693920+(G*160|0)|0;Y=y+224|0;g[Y>>2]=+g[X>>2]*+g[s>>2];Z=7693900+(G*160|0)|0;g[e+384>>2]=+g[Z>>2]*+g[t>>2]+ +g[y+144>>2];_=7693924+(G*160|0)|0;$=y+240|0;g[$>>2]=+g[_>>2]*+g[r>>2];aa=7693904+(G*160|0)|0;g[e+512>>2]=+g[aa>>2]*+g[b>>2]+ +g[y+160>>2];ba=7693928+(G*160|0)|0;ca=y+256|0;g[ca>>2]=+g[ba>>2]*+g[m>>2];da=7693908+(G*160|0)|0;g[e+640>>2]=+g[da>>2]*+g[v>>2]+ +g[y+176>>2];ea=7693932+(G*160|0)|0;fa=y+272|0;g[fa>>2]=+g[ea>>2]*+g[w>>2];K=+g[A+4>>2];H=+g[A+16>>2];N=K+H;J=+g[A+28>>2];P=+g[A+40>>2];L=J+P;O=+g[A+52>>2];I=P+O;P=L+(O+ +g[A+64>>2]);O=(H+J)*.8660253882408142;J=(N+L)*1.7320507764816284;L=K-I;H=(N-P)*.7071067690849304;M=L+H;g[m>>2]=M;g[l>>2]=M;M=L-H;g[b>>2]=M;g[p>>2]=M;M=K+I*.5;I=O+M;K=N*2.0+P;P=(J+K)*.258819043636322;N=I+P;g[r>>2]=N;g[s>>2]=N;N=I-P;g[t>>2]=N;g[u>>2]=N;N=M-O;O=(K-J)*.9659258127212524;J=N-O;g[v>>2]=J;g[h>>2]=J;K=N+O;g[w>>2]=K;g[x>>2]=K;g[B>>2]=+g[Q>>2]*J+ +g[S>>2];g[y>>2]=+g[R>>2]*+g[x>>2];g[B+128>>2]=+g[T>>2]*+g[p>>2]+ +g[V>>2];g[q>>2]=+g[U>>2]*+g[l>>2];g[B+256>>2]=+g[W>>2]*+g[u>>2]+ +g[Y>>2];g[C>>2]=+g[X>>2]*+g[s>>2];g[B+384>>2]=+g[Z>>2]*+g[t>>2]+ +g[$>>2];g[D>>2]=+g[_>>2]*+g[r>>2];g[B+512>>2]=+g[aa>>2]*+g[b>>2]+ +g[ca>>2];g[E>>2]=+g[ba>>2]*+g[m>>2];g[B+640>>2]=+g[da>>2]*+g[v>>2]+ +g[fa>>2];g[F>>2]=+g[ea>>2]*+g[w>>2];J=+g[A+8>>2];K=+g[A+20>>2];O=J+K;N=+g[A+32>>2];M=+g[A+44>>2];P=N+M;I=+g[A+56>>2];H=M+I;M=P+(I+ +g[A+68>>2]);I=(K+N)*.8660253882408142;N=(O+P)*1.7320507764816284;P=J-H;K=(O-M)*.7071067690849304;L=P+K;g[m>>2]=L;g[l>>2]=L;L=P-K;g[b>>2]=L;g[p>>2]=L;L=J+H*.5;H=I+L;J=O*2.0+M;M=(N+J)*.258819043636322;O=H+M;g[r>>2]=O;g[s>>2]=O;O=H-M;g[t>>2]=O;g[u>>2]=O;O=L-I;I=(J-N)*.9659258127212524;N=O-I;g[v>>2]=N;g[h>>2]=N;J=O+I;g[w>>2]=J;g[x>>2]=J;ea=0;J=N;while(1){F=ea<<2;fa=y+(F<<2)|0;g[fa>>2]=+g[7693888+(G*160|0)+(ea<<2)>>2]*J+ +g[fa>>2];fa=ea+6|0;g[y+(fa<<2<<2)>>2]=+g[7693888+(G*160|0)+(fa<<2)>>2]*+g[k+(fa<<2)>>2];g[y+(F+48<<2)>>2]=0.0;F=ea+1|0;if((F|0)>=6){break}ea=F;J=+g[k+(F<<2)>>2]}ea=y+(((z&3|0)!=3?1:69)<<2)|0;G=z+1|0;if((G|0)<(n|0)){y=ea;z=G;A=A+72|0;e=e+4|0;B=B+4|0}else{ga=ea;break}}}else{ga=o}if((n|0)<32){ha=ga;ia=n}else{i=j;return}while(1){g[f+(ia<<2)>>2]=+g[ha>>2];g[ha>>2]=0.0;n=ha+16|0;g[f+(ia+32<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+32|0;g[f+(ia+64<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+48|0;g[f+(ia+96<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+64|0;g[f+(ia+128<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+80|0;g[f+(ia+160<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+96|0;g[f+(ia+192<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+112|0;g[f+(ia+224<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+128|0;g[f+(ia+256<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+144|0;g[f+(ia+288<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+160|0;g[f+(ia+320<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+176|0;g[f+(ia+352<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+192|0;g[f+(ia+384<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+208|0;g[f+(ia+416<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+224|0;g[f+(ia+448<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+240|0;g[f+(ia+480<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+256|0;g[f+(ia+512<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ha+272|0;g[f+(ia+544<<2)>>2]=+g[n>>2];g[n>>2]=0.0;n=ia+1|0;if((n|0)<32){ha=ha+(((ia&3|0)!=3?1:69)<<2)|0;ia=n}else{break}}i=j;return}function MSa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((b&1048576|0)==0){c[a+36>>2]=1;d=1;f=1}else{g=b>>>19&1^1;c[a+36>>2]=g;d=0;f=g}g=4-(b>>>17&3)|0;c[a+8>>2]=g;h=b>>>10&3;i=f+d|0;d=(e[1965176+(h<<1)>>1]|0)>>>(i>>>0);c[a+16>>2]=(i*3|0)+h;c[a+4>>2]=b>>>16&1^1;c[a+12>>2]=d;h=b>>>12&15;i=b>>>9&1;j=b>>>6&3;c[a+28>>2]=j;c[a+32>>2]=b>>>4&3;c[a+24>>2]=(j|0)==3?1:2;if((h|0)==0){k=1;return k|0}j=e[1965184+(f*90|0)+((g-1|0)*30|0)+(h<<1)>>1]|0;c[a+20>>2]=j*1e3|0;if((g|0)==2){l=((j*144e3|0|0)/(d|0)|0)+i|0}else if((g|0)==1){l=((j*12e3|0|0)/(d|0)|0)+i<<2}else{l=((j*144e3|0|0)/(d<<f|0)|0)+i|0}c[a>>2]=l;k=0;return k|0}function NSa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+40|0;j=h|0;if((a&-2097152|0)!=-2097152|(a&393216|0)==0|(a&61440|0)==61440|(a&3072|0)==3072){k=-1;i=h;return k|0}if((MSa(j,a)|0)!=0){k=-1;i=h;return k|0}a=c[j+8>>2]|0;do{if((a|0)==2){c[g>>2]=86016;c[e>>2]=1152}else if((a|0)==1){c[g>>2]=86059;c[e>>2]=384}else{c[g>>2]=86017;if((c[j+36>>2]|0)==0){c[e>>2]=1152;break}else{c[e>>2]=576;break}}}while(0);c[b>>2]=c[j+12>>2];c[d>>2]=c[j+24>>2];c[f>>2]=c[j+20>>2];k=c[j>>2]|0;i=h;return k|0}function OSa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+40|0;j=h|0;k=a+48|0;if((b&-2097152|0)!=-2097152|(b&393216|0)==0|(b&61440|0)==61440|(b&3072|0)==3072){l=-1;i=h;return l|0}if((MSa(j,b)|0)!=0){l=-1;i=h;return l|0}b=c[j+8>>2]|0;do{if((b|0)==2){c[k>>2]=86016;c[f>>2]=1152}else if((b|0)==1){c[k>>2]=86059;c[f>>2]=384}else{c[k>>2]=86017;if((c[j+36>>2]|0)==0){c[f>>2]=1152;break}else{c[f>>2]=576;break}}}while(0);c[d>>2]=c[j+12>>2];c[e>>2]=c[j+24>>2];c[g>>2]=c[j+20>>2];l=c[j>>2]|0;i=h;return l|0}function PSa(a){a=a|0;var b=0,d=0;b=i;i=i+112|0;d=b|0;g5(d,5,0)|0;YSa();TSa();c[a>>2]=44;c[a+4>>2]=174;c[a+8>>2]=c[d+108>>2];c[a+12>>2]=264;c[a+16>>2]=10;c[a+20>>2]=200;i=b;return}function QSa(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;nrc(a+2048|0,a|0,128)|0;h=c[e>>2]|0;i=c[d>>2]|0;j=c[a+64>>2]|0;k=Erc(j,(j|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=wrc(k,G,h,(h|0)<0|0?-1:0)|0;h=G;k=c[d+256>>2]|0;j=c[a+320>>2]|0;l=Erc(j,(j|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=wrc(i,h,l,G)|0;l=G;h=c[d+512>>2]|0;i=c[a+576>>2]|0;j=Erc(i,(i|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=wrc(k,l,j,G)|0;j=G;l=c[d+768>>2]|0;k=c[a+832>>2]|0;i=Erc(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=wrc(h,j,i,G)|0;i=G;j=c[d+1024>>2]|0;h=c[a+1088>>2]|0;k=Erc(h,(h|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=wrc(l,i,k,G)|0;k=G;i=c[d+1280>>2]|0;l=c[a+1344>>2]|0;h=Erc(l,(l|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=wrc(j,k,h,G)|0;h=G;k=c[d+1536>>2]|0;j=c[a+1600>>2]|0;l=Erc(j,(j|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=wrc(i,h,l,G)|0;l=G;h=c[d+1792>>2]|0;i=c[a+1856>>2]|0;j=Erc(i,(i|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=wrc(k,l,j,G)|0;j=G;l=c[d+128>>2]|0;k=c[a+192>>2]|0;i=Erc(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=xrc(h,j,i,G)|0;i=G;j=c[d+384>>2]|0;h=c[a+448>>2]|0;k=Erc(h,(h|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=xrc(l,i,k,G)|0;k=G;i=c[d+640>>2]|0;l=c[a+704>>2]|0;h=Erc(l,(l|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=xrc(j,k,h,G)|0;h=G;k=c[d+896>>2]|0;j=c[a+960>>2]|0;l=Erc(j,(j|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=xrc(i,h,l,G)|0;l=G;h=c[d+1152>>2]|0;i=c[a+1216>>2]|0;j=Erc(i,(i|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=xrc(k,l,j,G)|0;j=G;l=c[d+1408>>2]|0;k=c[a+1472>>2]|0;i=Erc(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=xrc(h,j,i,G)|0;i=G;j=c[d+1664>>2]|0;h=c[a+1728>>2]|0;k=Erc(h,(h|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=xrc(l,i,k,G)|0;k=G;i=c[d+1920>>2]|0;l=c[a+1984>>2]|0;h=Erc(l,(l|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=xrc(j,k,h,G)|0;h=G;k=i>>>24|h<<8;j=k;if((j+32768|0)>>>0>65535>>>0){m=(j>>31^32767)&65535}else{m=k&65535}b[f>>1]=m;m=-g|0;k=f+(g<<4<<1)|0;j=1;l=f+((g*31|0)<<1)|0;n=d+124|0;o=h&0;h=i&16777215;i=f;f=d;while(1){p=i+(g<<1)|0;q=f+4|0;r=c[a+(j+16<<2)>>2]|0;s=c[q>>2]|0;t=r;u=(r|0)<0|0?-1:0;r=Erc(s,(s|0)<0|0?-1:0,t,u)|0;s=wrc(r,G,h,o)|0;r=G;v=c[n>>2]|0;w=xrc(0,0,t,u)|0;u=Erc(v,(v|0)<0|0?-1:0,w,G)|0;w=G;v=c[a+(j+80<<2)>>2]|0;t=c[f+260>>2]|0;x=v;y=(v|0)<0|0?-1:0;v=Erc(t,(t|0)<0|0?-1:0,x,y)|0;t=wrc(s,r,v,G)|0;v=G;r=c[n+256>>2]|0;s=Erc(r,(r|0)<0|0?-1:0,x,y)|0;y=xrc(u,w,s,G)|0;s=G;w=c[a+(j+144<<2)>>2]|0;u=c[f+516>>2]|0;x=w;r=(w|0)<0|0?-1:0;w=Erc(u,(u|0)<0|0?-1:0,x,r)|0;u=wrc(t,v,w,G)|0;w=G;v=c[n+512>>2]|0;t=Erc(v,(v|0)<0|0?-1:0,x,r)|0;r=xrc(y,s,t,G)|0;t=G;s=c[a+(j+208<<2)>>2]|0;y=c[f+772>>2]|0;x=s;v=(s|0)<0|0?-1:0;s=Erc(y,(y|0)<0|0?-1:0,x,v)|0;y=wrc(u,w,s,G)|0;s=G;w=c[n+768>>2]|0;u=Erc(w,(w|0)<0|0?-1:0,x,v)|0;v=xrc(r,t,u,G)|0;u=G;t=c[a+(j+272<<2)>>2]|0;r=c[f+1028>>2]|0;x=t;w=(t|0)<0|0?-1:0;t=Erc(r,(r|0)<0|0?-1:0,x,w)|0;r=wrc(y,s,t,G)|0;t=G;s=c[n+1024>>2]|0;y=Erc(s,(s|0)<0|0?-1:0,x,w)|0;w=xrc(v,u,y,G)|0;y=G;u=c[a+(j+336<<2)>>2]|0;v=c[f+1284>>2]|0;x=u;s=(u|0)<0|0?-1:0;u=Erc(v,(v|0)<0|0?-1:0,x,s)|0;v=wrc(r,t,u,G)|0;u=G;t=c[n+1280>>2]|0;r=Erc(t,(t|0)<0|0?-1:0,x,s)|0;s=xrc(w,y,r,G)|0;r=G;y=c[a+(j+400<<2)>>2]|0;w=c[f+1540>>2]|0;x=y;t=(y|0)<0|0?-1:0;y=Erc(w,(w|0)<0|0?-1:0,x,t)|0;w=wrc(v,u,y,G)|0;y=G;u=c[n+1536>>2]|0;v=Erc(u,(u|0)<0|0?-1:0,x,t)|0;t=xrc(s,r,v,G)|0;v=G;r=c[a+(j+464<<2)>>2]|0;s=c[f+1796>>2]|0;x=r;u=(r|0)<0|0?-1:0;r=Erc(s,(s|0)<0|0?-1:0,x,u)|0;s=wrc(w,y,r,G)|0;r=G;y=c[n+1792>>2]|0;w=Erc(y,(y|0)<0|0?-1:0,x,u)|0;u=xrc(t,v,w,G)|0;w=G;v=48-j|0;t=c[a+(v<<2)>>2]|0;x=c[f+132>>2]|0;y=t;z=(t|0)<0|0?-1:0;t=Erc(x,(x|0)<0|0?-1:0,y,z)|0;x=xrc(s,r,t,G)|0;t=G;r=c[n+128>>2]|0;s=Erc(r,(r|0)<0|0?-1:0,y,z)|0;z=xrc(u,w,s,G)|0;s=G;w=c[a+(v+64<<2)>>2]|0;u=c[f+388>>2]|0;y=w;r=(w|0)<0|0?-1:0;w=Erc(u,(u|0)<0|0?-1:0,y,r)|0;u=xrc(x,t,w,G)|0;w=G;t=c[n+384>>2]|0;x=Erc(t,(t|0)<0|0?-1:0,y,r)|0;r=xrc(z,s,x,G)|0;x=G;s=c[a+(v+128<<2)>>2]|0;z=c[f+644>>2]|0;y=s;t=(s|0)<0|0?-1:0;s=Erc(z,(z|0)<0|0?-1:0,y,t)|0;z=xrc(u,w,s,G)|0;s=G;w=c[n+640>>2]|0;u=Erc(w,(w|0)<0|0?-1:0,y,t)|0;t=xrc(r,x,u,G)|0;u=G;x=c[a+(v+192<<2)>>2]|0;r=c[f+900>>2]|0;y=x;w=(x|0)<0|0?-1:0;x=Erc(r,(r|0)<0|0?-1:0,y,w)|0;r=xrc(z,s,x,G)|0;x=G;s=c[n+896>>2]|0;z=Erc(s,(s|0)<0|0?-1:0,y,w)|0;w=xrc(t,u,z,G)|0;z=G;u=c[a+(v+256<<2)>>2]|0;t=c[f+1156>>2]|0;y=u;s=(u|0)<0|0?-1:0;u=Erc(t,(t|0)<0|0?-1:0,y,s)|0;t=xrc(r,x,u,G)|0;u=G;x=c[n+1152>>2]|0;r=Erc(x,(x|0)<0|0?-1:0,y,s)|0;s=xrc(w,z,r,G)|0;r=G;z=c[a+(v+320<<2)>>2]|0;w=c[f+1412>>2]|0;y=z;x=(z|0)<0|0?-1:0;z=Erc(w,(w|0)<0|0?-1:0,y,x)|0;w=xrc(t,u,z,G)|0;z=G;u=c[n+1408>>2]|0;t=Erc(u,(u|0)<0|0?-1:0,y,x)|0;x=xrc(s,r,t,G)|0;t=G;r=c[a+(v+384<<2)>>2]|0;s=c[f+1668>>2]|0;y=r;u=(r|0)<0|0?-1:0;r=Erc(s,(s|0)<0|0?-1:0,y,u)|0;s=xrc(w,z,r,G)|0;r=G;z=c[n+1664>>2]|0;w=Erc(z,(z|0)<0|0?-1:0,y,u)|0;u=xrc(x,t,w,G)|0;w=G;t=c[a+(v+448<<2)>>2]|0;v=c[f+1924>>2]|0;x=t;y=(t|0)<0|0?-1:0;t=Erc(v,(v|0)<0|0?-1:0,x,y)|0;v=xrc(s,r,t,G)|0;t=G;r=c[n+1920>>2]|0;s=Erc(r,(r|0)<0|0?-1:0,x,y)|0;y=xrc(u,w,s,G)|0;s=G;w=v>>>24|t<<8;u=w;if((u+32768|0)>>>0>65535>>>0){A=(u>>31^32767)&65535}else{A=w&65535}b[p>>1]=A;w=wrc(y,s,v&16777215,t&0)|0;u=w>>>24|G<<8;w=u;if((w+32768|0)>>>0>65535>>>0){B=(w>>31^32767)&65535}else{B=u&65535}b[l>>1]=B;u=j+1|0;w=wrc(v,t,y,s)|0;C=w&16777215;D=G&0;if((u|0)<16){j=u;l=l+(m<<1)|0;n=n-4|0;o=D;h=C;i=p;f=q}else{break}}f=c[d+192>>2]|0;i=c[a+128>>2]|0;h=Erc(i,(i|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=xrc(C,D,h,G)|0;h=G;D=c[d+448>>2]|0;C=c[a+384>>2]|0;i=Erc(C,(C|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;D=xrc(f,h,i,G)|0;i=G;h=c[d+704>>2]|0;f=c[a+640>>2]|0;C=Erc(f,(f|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=xrc(D,i,C,G)|0;C=G;i=c[d+960>>2]|0;D=c[a+896>>2]|0;f=Erc(D,(D|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=xrc(h,C,f,G)|0;f=G;C=c[d+1216>>2]|0;h=c[a+1152>>2]|0;D=Erc(h,(h|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;C=xrc(i,f,D,G)|0;D=G;f=c[d+1472>>2]|0;i=c[a+1408>>2]|0;h=Erc(i,(i|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=xrc(C,D,h,G)|0;h=G;D=c[d+1728>>2]|0;C=c[a+1664>>2]|0;i=Erc(C,(C|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;D=xrc(f,h,i,G)|0;i=G;h=c[d+1984>>2]|0;d=c[a+1920>>2]|0;a=Erc(d,(d|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=xrc(D,i,a,G)|0;a=h>>>24|G<<8;i=a;if(!((i+32768|0)>>>0>65535>>>0)){E=a&65535;b[k>>1]=E;F=h;H=F;I=H&16777215;c[e>>2]=I;return}E=(i>>31^32767)&65535;b[k>>1]=E;F=h;H=F;I=H&16777215;c[e>>2]=I;return}function RSa(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=c[d>>2]|0;k=b+(j<<2)|0;re[c[a+12>>2]&1023](k,i);pe[c[a+4>>2]&1023](k,e,f,g,h);c[d>>2]=j+480&511;return}function SSa(a){a=a|0;var b=0,d=0,e=0,f=0;b=0;while(1){d=c[1348544+(b<<2)>>2]|0;c[a+(b<<2)>>2]=d;if((b|0)==0){b=b+1|0;continue}else{c[a+(512-b<<2)>>2]=(b&63|0)==0?d:-d|0;d=b+1|0;if((d|0)<257){b=d;continue}else{e=0;break}}}while(1){b=e<<6|32;d=e<<4;c[a+(d+512<<2)>>2]=c[a+(b<<2)>>2];c[a+(d+513<<2)>>2]=c[a+(b-1<<2)>>2];c[a+(d+514<<2)>>2]=c[a+(b-2<<2)>>2];c[a+(d+515<<2)>>2]=c[a+(b-3<<2)>>2];c[a+(d+516<<2)>>2]=c[a+(b-4<<2)>>2];c[a+(d+517<<2)>>2]=c[a+(b-5<<2)>>2];c[a+(d+518<<2)>>2]=c[a+(b-6<<2)>>2];c[a+(d+519<<2)>>2]=c[a+(b-7<<2)>>2];c[a+(d+520<<2)>>2]=c[a+(b-8<<2)>>2];c[a+(d+521<<2)>>2]=c[a+(b-9<<2)>>2];c[a+(d+522<<2)>>2]=c[a+(b-10<<2)>>2];c[a+(d+523<<2)>>2]=c[a+(b-11<<2)>>2];c[a+(d+524<<2)>>2]=c[a+(b-12<<2)>>2];c[a+(d+525<<2)>>2]=c[a+(b-13<<2)>>2];c[a+(d+526<<2)>>2]=c[a+(b-14<<2)>>2];c[a+(d+527<<2)>>2]=c[a+(b-15<<2)>>2];b=e+1|0;if((b|0)<8){e=b}else{f=0;break}}do{e=f<<6|48;b=f<<4;c[a+(b+640<<2)>>2]=c[a+(e<<2)>>2];c[a+(b+641<<2)>>2]=c[a+(e-1<<2)>>2];c[a+(b+642<<2)>>2]=c[a+(e-2<<2)>>2];c[a+(b+643<<2)>>2]=c[a+(e-3<<2)>>2];c[a+(b+644<<2)>>2]=c[a+(e-4<<2)>>2];c[a+(b+645<<2)>>2]=c[a+(e-5<<2)>>2];c[a+(b+646<<2)>>2]=c[a+(e-6<<2)>>2];c[a+(b+647<<2)>>2]=c[a+(e-7<<2)>>2];c[a+(b+648<<2)>>2]=c[a+(e-8<<2)>>2];c[a+(b+649<<2)>>2]=c[a+(e-9<<2)>>2];c[a+(b+650<<2)>>2]=c[a+(e-10<<2)>>2];c[a+(b+651<<2)>>2]=c[a+(e-11<<2)>>2];c[a+(b+652<<2)>>2]=c[a+(e-12<<2)>>2];c[a+(b+653<<2)>>2]=c[a+(e-13<<2)>>2];c[a+(b+654<<2)>>2]=c[a+(e-14<<2)>>2];c[a+(b+655<<2)>>2]=c[a+(e-15<<2)>>2];f=f+1|0;}while((f|0)<8);return}function TSa(){var a=0,b=0,d=0.0,e=0.0,f=0,g=0,h=0,i=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0,C=0,D=0;a=0;while(1){b=((a|0)%3|0|0)==1;d=(+(a|0)+.5)*3.141592653589793/36.0;e=+((a<<1)+19|0)*3.141592653589793/72.0;f=(a|0)/3|0;g=(a|0)<18;h=g?a:a+2|0;i=(a|0)>29;j=(a|0)>23;k=(+(a-18|0)+.5)*3.141592653589793/12.0;l=(a|0)>17;m=(+(a-6|0)+.5)*3.141592653589793/12.0;if((a|0)<6){n=0;while(1){o=(n|0)==2;a:do{if(o){if(!b){p=16;break}q=+V(d);p=14}else{r=+V(d);if((n|0)==3){s=.8795/+U(e)*0.0;p=17;break}else if((n|0)==1){p=7}else{t=r}do{if((p|0)==7){p=0;if(i){t=0.0;break}if(j){q=+V(k);p=14;break a}else{q=l?1.0:r;p=14;break a}}}while(0);s=t*(.8795/+U(e));p=17}}while(0);do{if((p|0)==14){p=0;r=q*(.8795/+U(e));if(!o){s=r;p=17;break}c[7695488+(f<<2)>>2]=~~(r*.03125*4294967296.0+.5);p=16}}while(0);if((p|0)==16){p=0;n=n+1|0;continue}else if((p|0)==17){p=0;c[7695168+(n*160|0)+(h<<2)>>2]=~~(s*.03125*4294967296.0+.5);o=n+1|0;if((o|0)<4){n=o;continue}else{break}}}}else{if((a|0)<12){n=0;while(1){o=(n|0)==2;do{if(o){if(!b){p=30;break}u=+V(d);p=28}else{r=+V(d);if((n|0)==3){v=+V(m)}else if((n|0)==1){if(i){u=0.0;p=28;break}if(j){u=+V(k);p=28;break}else{u=l?1.0:r;p=28;break}}else{v=r}w=v*(.8795/+U(e));p=31}}while(0);do{if((p|0)==28){p=0;r=u*(.8795/+U(e));if(!o){w=r;p=31;break}c[7695488+(f<<2)>>2]=~~(r*.03125*4294967296.0+.5);p=30}}while(0);if((p|0)==30){p=0;n=n+1|0;continue}else if((p|0)==31){p=0;c[7695168+(n*160|0)+(h<<2)>>2]=~~(w*.03125*4294967296.0+.5);o=n+1|0;if((o|0)<4){n=o;continue}else{break}}}}else{n=0;while(1){o=(n|0)==2;b:do{if(o){if(!b){p=44;break}x=+V(d);p=42}else{m=+V(d);if((n|0)==1){p=36}else if((n|0)==3){x=g?1.0:m;p=42;break}else{y=m}do{if((p|0)==36){p=0;if(i){y=0.0;break}if(j){x=+V(k);p=42;break b}else{x=l?1.0:m;p=42;break b}}}while(0);z=y*(.8795/+U(e));p=45}}while(0);do{if((p|0)==42){p=0;m=x*(.8795/+U(e));if(!o){z=m;p=45;break}c[7695488+(f<<2)>>2]=~~(m*.03125*4294967296.0+.5);p=44}}while(0);if((p|0)==44){p=0;n=n+1|0;continue}else if((p|0)==45){p=0;c[7695168+(n*160|0)+(h<<2)>>2]=~~(z*.03125*4294967296.0+.5);o=n+1|0;if((o|0)<4){n=o;continue}else{break}}}}}n=a+1|0;if((n|0)<36){a=n}else{A=0;break}}while(1){c[7695808+(A<<2)>>2]=c[7695168+(A<<2)>>2];a=A|1;c[7695808+(a<<2)>>2]=-(c[7695168+(a<<2)>>2]|0);a=A+2|0;if((a|0)<40){A=a}else{B=0;break}}while(1){c[7695968+(B<<2)>>2]=c[7695328+(B<<2)>>2];A=B|1;c[7695968+(A<<2)>>2]=-(c[7695328+(A<<2)>>2]|0);A=B+2|0;if((A|0)<40){B=A}else{C=0;break}}while(1){c[7696128+(C<<2)>>2]=c[7695488+(C<<2)>>2];B=C|1;c[7696128+(B<<2)>>2]=-(c[7695488+(B<<2)>>2]|0);B=C+2|0;if((B|0)<40){C=B}else{D=0;break}}do{c[7696288+(D<<2)>>2]=c[7695648+(D<<2)>>2];C=D|1;c[7696288+(C<<2)>>2]=-(c[7695648+(C<<2)>>2]|0);D=D+2|0;}while((D|0)<40);return}function USa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;h=i;i=i+72|0;j=h|0;if((e|0)<=0){i=h;return}k=(f|0)!=0;f=j+64|0;l=j+68|0;m=d;d=0;n=b;b=a;while(1){a=-(d&1)&4;o=m+68|0;p=m+64|0;q=c[p>>2]|0;r=q+(c[o>>2]|0)|0;s=m+60|0;t=c[s>>2]|0;c[p>>2]=t+q;q=m+56|0;p=c[q>>2]|0;u=p+t|0;t=m+52|0;v=c[t>>2]|0;c[q>>2]=v+p;p=m+48|0;q=c[p>>2]|0;w=q+v|0;v=m+44|0;x=c[v>>2]|0;c[p>>2]=x+q;q=m+40|0;p=c[q>>2]|0;y=p+x|0;x=m+36|0;z=c[x>>2]|0;c[q>>2]=z+p;p=m+32|0;q=c[p>>2]|0;A=q+z|0;z=m+28|0;B=c[z>>2]|0;c[p>>2]=B+q;q=m+24|0;p=c[q>>2]|0;C=p+B|0;B=m+20|0;D=c[B>>2]|0;c[q>>2]=D+p;p=m+16|0;q=c[p>>2]|0;E=q+D|0;D=m+12|0;F=c[D>>2]|0;c[p>>2]=F+q;q=m+8|0;p=c[q>>2]|0;H=p+F|0;F=m+4|0;I=c[F>>2]|0;c[q>>2]=I+p;p=c[m>>2]|0;q=p+I|0;c[F>>2]=q;F=k&(d|0)<2?0:g;c[o>>2]=r+u;c[s>>2]=w+u;c[t>>2]=y+w;c[v>>2]=A+y;c[x>>2]=C+A;c[z>>2]=E+C;c[B>>2]=H+E;c[D>>2]=q+H;H=0;q=p;while(1){p=H+8|0;D=c[m+(p<<2)>>2]|0;E=H+16|0;B=c[m+(E<<2)>>2]|0;C=H+4|0;z=c[m+(C<<2)>>2]|0;A=B+D-z|0;x=H+12|0;y=c[m+(x<<2)>>2]|0;v=(y>>1)+q|0;w=q-y|0;y=H+6|0;c[j+(y<<2)>>2]=w-(A>>1);c[j+(E<<2)>>2]=w+A;A=z+D<<1;Erc(A,(A|0)<0|0?-1:0,2017974537,0)|0;A=G;w=D-B|0;Erc(w,(w|0)<0|0?-1:0,-745813244,-1)|0;w=G;D=z+B<<1;Erc(D,(D|0)<0|0?-1:0,-1645067915,-1)|0;D=G;B=H+10|0;c[j+(B<<2)>>2]=v-A-D;z=H+2|0;c[j+(z<<2)>>2]=w+v+A;A=H+14|0;c[j+(A<<2)>>2]=v-w+D;D=c[m+(B<<2)>>2]|0;B=c[m+(A<<2)>>2]|0;A=c[m+(z<<2)>>2]|0;z=B+D-A<<1;Erc(z,(z|0)<0|0?-1:0,-1859775393,-1)|0;c[j+(C<<2)>>2]=G;C=A+D<<1;Erc(C,(C|0)<0|0?-1:0,2114858546,0)|0;C=G;z=D-B|0;Erc(z,(z|0)<0|0?-1:0,-1468965330,-1)|0;z=G;D=c[m+(y<<2)>>2]<<1;Erc(D,(D|0)<0|0?-1:0,1859775393,0)|0;D=G;y=A+B<<1;Erc(y,(y|0)<0|0?-1:0,-1380375881,-1)|0;y=G;c[j+(H<<2)>>2]=C+z+D;c[j+(x<<2)>>2]=y+C-D;c[j+(p<<2)>>2]=z-y-D;D=H+1|0;if((D|0)>=2){break}H=D;q=c[m+(D<<2)>>2]|0}q=F+a|0;H=0;D=0;while(1){y=c[j+(D<<2)>>2]|0;z=c[j+((D|2)<<2)>>2]|0;p=z+y|0;C=z-y|0;y=c[j+((D|1)<<2)>>2]|0;z=c[j+((D|3)<<2)>>2]|0;x=z+y<<1;B=c[1077208+(H<<2)>>2]|0;Erc(x,(x|0)<0|0?-1:0,B,(B|0)<0|0?-1:0)|0;B=G;x=z-y|0;y=8-H|0;z=c[1077288+(y<<2)>>2]|0;A=Erc(z,(z|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=A>>>23|G<<9;A=B+p|0;z=p-B|0;B=H+9|0;p=c[7695168+(q*160|0)+(B<<2)>>2]|0;w=z;v=(z|0)<0|0?-1:0;Erc(w,v,p,(p|0)<0|0?-1:0)|0;p=n+(B<<2<<2)|0;c[b+(B<<5<<2)>>2]=G+(c[p>>2]|0);B=c[7695168+(q*160|0)+(y<<2)>>2]|0;Erc(w,v,B,(B|0)<0|0?-1:0)|0;B=n+(y<<2<<2)|0;c[b+(y<<5<<2)>>2]=G+(c[B>>2]|0);y=c[7695168+(q*160|0)+(H+29<<2)>>2]|0;v=A;w=(A|0)<0|0?-1:0;Erc(y,(y|0)<0|0?-1:0,v,w)|0;c[p>>2]=G;p=c[7695168+(q*160|0)+(28-H<<2)>>2]|0;Erc(p,(p|0)<0|0?-1:0,v,w)|0;c[B>>2]=G;B=x+C|0;w=C-x|0;x=17-H|0;C=c[7695168+(q*160|0)+(x<<2)>>2]|0;v=w;p=(w|0)<0|0?-1:0;Erc(C,(C|0)<0|0?-1:0,v,p)|0;C=n+(x<<2<<2)|0;c[b+(x<<5<<2)>>2]=G+(c[C>>2]|0);x=c[7695168+(q*160|0)+(H<<2)>>2]|0;Erc(x,(x|0)<0|0?-1:0,v,p)|0;p=n+(H<<2<<2)|0;c[b+(H<<5<<2)>>2]=G+(c[p>>2]|0);v=c[7695168+(q*160|0)+(37-H<<2)>>2]|0;x=B;w=(B|0)<0|0?-1:0;Erc(v,(v|0)<0|0?-1:0,x,w)|0;c[C>>2]=G;C=c[7695168+(q*160|0)+(H+20<<2)>>2]|0;Erc(C,(C|0)<0|0?-1:0,x,w)|0;c[p>>2]=G;p=H+1|0;if((p|0)<4){H=p;D=D+4|0}else{break}}D=c[f>>2]|0;H=c[l>>2]<<1;Erc(H,(H|0)<0|0?-1:0,1518500250,0)|0;H=G;a=H+D|0;F=D-H|0;H=c[7695220+(q*160|0)>>2]|0;D=F;p=(F|0)<0|0?-1:0;Erc(D,p,H,(H|0)<0|0?-1:0)|0;H=n+208|0;c[b+1664>>2]=G+(c[H>>2]|0);F=c[7695184+(q*160|0)>>2]|0;Erc(D,p,F,(F|0)<0|0?-1:0)|0;F=n+64|0;c[b+512>>2]=G+(c[F>>2]|0);p=c[7695300+(q*160|0)>>2]|0;D=a;w=(a|0)<0|0?-1:0;Erc(D,w,p,(p|0)<0|0?-1:0)|0;c[H>>2]=G;H=c[7695264+(q*160|0)>>2]|0;Erc(H,(H|0)<0|0?-1:0,D,w)|0;c[F>>2]=G;F=n+(((d&3|0)!=3?1:69)<<2)|0;w=d+1|0;if((w|0)<(e|0)){m=m+72|0;d=w;n=F;b=b+4|0}else{break}}i=h;return}function VSa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0;nrc(a+2048|0,a|0,128)|0;g[e>>2]=+(c[d>>2]|0)+ +g[b>>2]*+g[a+64>>2]+ +g[b+256>>2]*+g[a+320>>2]+ +g[b+512>>2]*+g[a+576>>2]+ +g[b+768>>2]*+g[a+832>>2]+ +g[b+1024>>2]*+g[a+1088>>2]+ +g[b+1280>>2]*+g[a+1344>>2]+ +g[b+1536>>2]*+g[a+1600>>2]+ +g[b+1792>>2]*+g[a+1856>>2]- +g[b+128>>2]*+g[a+192>>2]- +g[b+384>>2]*+g[a+448>>2]- +g[b+640>>2]*+g[a+704>>2]- +g[b+896>>2]*+g[a+960>>2]- +g[b+1152>>2]*+g[a+1216>>2]- +g[b+1408>>2]*+g[a+1472>>2]- +g[b+1664>>2]*+g[a+1728>>2]- +g[b+1920>>2]*+g[a+1984>>2];h=-f|0;i=e+(f<<4<<2)|0;j=1;k=e+((f*31|0)<<2)|0;l=b+124|0;m=e;e=b;while(1){n=m+(f<<2)|0;o=e+4|0;p=+g[a+(j+16<<2)>>2];q=+g[a+(j+80<<2)>>2];r=+g[a+(j+144<<2)>>2];s=+g[a+(j+208<<2)>>2];t=+g[a+(j+272<<2)>>2];u=+g[a+(j+336<<2)>>2];v=+g[a+(j+400<<2)>>2];w=+g[a+(j+464<<2)>>2];x=48-j|0;y=+g[a+(x<<2)>>2];z=+g[a+(x+64<<2)>>2];A=+g[a+(x+128<<2)>>2];B=+g[a+(x+192<<2)>>2];C=+g[a+(x+256<<2)>>2];D=+g[a+(x+320<<2)>>2];E=+g[a+(x+384<<2)>>2];F=+g[a+(x+448<<2)>>2];G=0.0-p*+g[l>>2]-q*+g[l+256>>2]-r*+g[l+512>>2]-s*+g[l+768>>2]-t*+g[l+1024>>2]-u*+g[l+1280>>2]-v*+g[l+1536>>2]-w*+g[l+1792>>2]-y*+g[l+128>>2]-z*+g[l+384>>2]-A*+g[l+640>>2]-B*+g[l+896>>2]-C*+g[l+1152>>2]-D*+g[l+1408>>2]-E*+g[l+1664>>2]-F*+g[l+1920>>2];g[n>>2]=p*+g[o>>2]+0.0+q*+g[e+260>>2]+r*+g[e+516>>2]+s*+g[e+772>>2]+t*+g[e+1028>>2]+u*+g[e+1284>>2]+v*+g[e+1540>>2]+w*+g[e+1796>>2]-y*+g[e+132>>2]-z*+g[e+388>>2]-A*+g[e+644>>2]-B*+g[e+900>>2]-C*+g[e+1156>>2]-D*+g[e+1412>>2]-E*+g[e+1668>>2]-F*+g[e+1924>>2];g[k>>2]=G+0.0;x=j+1|0;if((x|0)<16){j=x;k=k+(h<<2)|0;l=l-4|0;m=n;e=o}else{break}}g[i>>2]=0.0- +g[b+192>>2]*+g[a+128>>2]- +g[b+448>>2]*+g[a+384>>2]- +g[b+704>>2]*+g[a+640>>2]- +g[b+960>>2]*+g[a+896>>2]- +g[b+1216>>2]*+g[a+1152>>2]- +g[b+1472>>2]*+g[a+1408>>2]- +g[b+1728>>2]*+g[a+1664>>2]- +g[b+1984>>2]*+g[a+1920>>2];c[d>>2]=0;return}function WSa(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=c[d>>2]|0;k=b+(j<<2)|0;re[c[a+8>>2]&1023](k,i);pe[c[a>>2]&1023](k,e,f,g,h);c[d>>2]=j+480&511;return}function XSa(a){a=a|0;var b=0,d=0.0,e=0.0,f=0,h=0,i=0;b=0;while(1){d=+(c[1348544+(b<<2)>>2]|0)*1.8189894035458565e-12;g[a+(b<<2)>>2]=d;if((b&63|0)==0){e=d}else{e=-0.0-d}if((b|0)==0){b=b+1|0;continue}else{g[a+(512-b<<2)>>2]=e;f=b+1|0;if((f|0)<257){b=f;continue}else{h=0;break}}}while(1){b=h<<6|32;f=h<<4;g[a+(f+512<<2)>>2]=+g[a+(b<<2)>>2];g[a+(f+513<<2)>>2]=+g[a+(b-1<<2)>>2];g[a+(f+514<<2)>>2]=+g[a+(b-2<<2)>>2];g[a+(f+515<<2)>>2]=+g[a+(b-3<<2)>>2];g[a+(f+516<<2)>>2]=+g[a+(b-4<<2)>>2];g[a+(f+517<<2)>>2]=+g[a+(b-5<<2)>>2];g[a+(f+518<<2)>>2]=+g[a+(b-6<<2)>>2];g[a+(f+519<<2)>>2]=+g[a+(b-7<<2)>>2];g[a+(f+520<<2)>>2]=+g[a+(b-8<<2)>>2];g[a+(f+521<<2)>>2]=+g[a+(b-9<<2)>>2];g[a+(f+522<<2)>>2]=+g[a+(b-10<<2)>>2];g[a+(f+523<<2)>>2]=+g[a+(b-11<<2)>>2];g[a+(f+524<<2)>>2]=+g[a+(b-12<<2)>>2];g[a+(f+525<<2)>>2]=+g[a+(b-13<<2)>>2];g[a+(f+526<<2)>>2]=+g[a+(b-14<<2)>>2];g[a+(f+527<<2)>>2]=+g[a+(b-15<<2)>>2];b=h+1|0;if((b|0)<8){h=b}else{i=0;break}}do{h=i<<6|48;b=i<<4;g[a+(b+640<<2)>>2]=+g[a+(h<<2)>>2];g[a+(b+641<<2)>>2]=+g[a+(h-1<<2)>>2];g[a+(b+642<<2)>>2]=+g[a+(h-2<<2)>>2];g[a+(b+643<<2)>>2]=+g[a+(h-3<<2)>>2];g[a+(b+644<<2)>>2]=+g[a+(h-4<<2)>>2];g[a+(b+645<<2)>>2]=+g[a+(h-5<<2)>>2];g[a+(b+646<<2)>>2]=+g[a+(h-6<<2)>>2];g[a+(b+647<<2)>>2]=+g[a+(h-7<<2)>>2];g[a+(b+648<<2)>>2]=+g[a+(h-8<<2)>>2];g[a+(b+649<<2)>>2]=+g[a+(h-9<<2)>>2];g[a+(b+650<<2)>>2]=+g[a+(h-10<<2)>>2];g[a+(b+651<<2)>>2]=+g[a+(h-11<<2)>>2];g[a+(b+652<<2)>>2]=+g[a+(h-12<<2)>>2];g[a+(b+653<<2)>>2]=+g[a+(h-13<<2)>>2];g[a+(b+654<<2)>>2]=+g[a+(h-14<<2)>>2];g[a+(b+655<<2)>>2]=+g[a+(h-15<<2)>>2];i=i+1|0;}while((i|0)<8);return}function YSa(){var a=0,b=0,c=0.0,d=0.0,e=0,f=0,h=0,i=0,j=0,k=0.0,l=0,m=0.0,n=0.0,o=0.0,p=0.0,q=0,r=0,s=0,t=0;a=0;while(1){b=((a|0)%3|0|0)==1;c=(+(a|0)+.5)*3.141592653589793/36.0;d=+((a<<1)+19|0)*3.141592653589793/72.0;e=(a|0)/3|0;f=(a|0)<18;h=f?a:a+2|0;i=(a|0)>29;j=(a|0)>23;k=(+(a-18|0)+.5)*3.141592653589793/12.0;l=(a|0)>17;m=(+(a-6|0)+.5)*3.141592653589793/12.0;g[7693888+(h<<2)>>2]=+V(c)*(.8795/+U(d))*.03125;n=+V(c);do{if((a|0)<6){g[7694048+(h<<2)>>2]=(l?1.0:n)*(.8795/+U(d))*.03125;if(b){g[7694208+(e<<2)>>2]=+V(c)*(.8795/+U(d))*.03125}g[7694368+(h<<2)>>2]=.8795/+U(d)*0.0*.03125}else{if((a|0)<12){g[7694048+(h<<2)>>2]=(l?1.0:n)*(.8795/+U(d))*.03125;if(b){g[7694208+(e<<2)>>2]=+V(c)*(.8795/+U(d))*.03125}g[7694368+(h<<2)>>2]=+V(m)*(.8795/+U(d))*.03125;break}do{if(i){o=0.0}else{if(j){o=+V(k);break}else{o=l?1.0:n;break}}}while(0);g[7694048+(h<<2)>>2]=o*(.8795/+U(d))*.03125;if(b){g[7694208+(e<<2)>>2]=+V(c)*(.8795/+U(d))*.03125}p=+V(c);g[7694368+(h<<2)>>2]=(f?1.0:p)*(.8795/+U(d))*.03125}}while(0);f=a+1|0;if((f|0)<36){a=f}else{q=0;break}}while(1){g[7694528+(q<<2)>>2]=+g[7693888+(q<<2)>>2];a=q|1;g[7694528+(a<<2)>>2]=-0.0- +g[7693888+(a<<2)>>2];a=q+2|0;if((a|0)<40){q=a}else{r=0;break}}while(1){g[7694688+(r<<2)>>2]=+g[7694048+(r<<2)>>2];q=r|1;g[7694688+(q<<2)>>2]=-0.0- +g[7694048+(q<<2)>>2];q=r+2|0;if((q|0)<40){r=q}else{s=0;break}}while(1){g[7694848+(s<<2)>>2]=+g[7694208+(s<<2)>>2];r=s|1;g[7694848+(r<<2)>>2]=-0.0- +g[7694208+(r<<2)>>2];r=s+2|0;if((r|0)<40){s=r}else{t=0;break}}do{g[7695008+(t<<2)>>2]=+g[7694368+(t<<2)>>2];s=t|1;g[7695008+(s<<2)>>2]=-0.0- +g[7694368+(s<<2)>>2];t=t+2|0;}while((t|0)<40);return}function ZSa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0.0,v=0,w=0.0,x=0,y=0.0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0,G=0.0,H=0,I=0.0;h=i;i=i+72|0;j=h|0;if((d|0)<=0){i=h;return}k=(e|0)!=0;e=j+64|0;l=j+68|0;m=c;c=0;n=b;b=a;while(1){a=-(c&1)&4;o=m+68|0;p=m+64|0;q=+g[p>>2];r=+g[o>>2]+q;s=m+60|0;t=+g[s>>2];g[p>>2]=q+t;p=m+56|0;q=+g[p>>2];u=t+q;v=m+52|0;t=+g[v>>2];g[p>>2]=q+t;p=m+48|0;q=+g[p>>2];w=t+q;x=m+44|0;t=+g[x>>2];g[p>>2]=q+t;p=m+40|0;q=+g[p>>2];y=t+q;z=m+36|0;t=+g[z>>2];g[p>>2]=q+t;p=m+32|0;q=+g[p>>2];A=t+q;B=m+28|0;t=+g[B>>2];g[p>>2]=q+t;p=m+24|0;q=+g[p>>2];C=t+q;D=m+20|0;t=+g[D>>2];g[p>>2]=q+t;p=m+16|0;q=+g[p>>2];E=t+q;F=m+12|0;t=+g[F>>2];g[p>>2]=q+t;p=m+8|0;q=+g[p>>2];G=t+q;H=m+4|0;t=+g[H>>2];g[p>>2]=q+t;q=+g[m>>2];I=t+q;g[H>>2]=I;H=k&(c|0)<2?0:f;g[o>>2]=u+r;g[s>>2]=u+w;g[v>>2]=w+y;g[x>>2]=y+A;g[z>>2]=A+C;g[B>>2]=C+E;g[D>>2]=E+G;g[F>>2]=G+I;F=0;I=q;while(1){D=F+8|0;q=+g[m+(D<<2)>>2];B=F+16|0;G=+g[m+(B<<2)>>2];z=F+4|0;E=+g[m+(z<<2)>>2];C=q+G-E;x=F+12|0;A=+g[m+(x<<2)>>2];y=I+A*.5;w=I-A;v=F+6|0;g[j+(v<<2)>>2]=w-C*.5;g[j+(B<<2)>>2]=C+w;w=(q+E)*.9396926164627075;C=(q-G)*-.1736481785774231;q=(G+E)*-.7660444378852844;B=F+10|0;g[j+(B<<2)>>2]=y-w-q;s=F+2|0;g[j+(s<<2)>>2]=C+(w+y);o=F+14|0;g[j+(o<<2)>>2]=q+y-C;C=+g[m+(B<<2)>>2];y=+g[m+(o<<2)>>2];q=+g[m+(s<<2)>>2];g[j+(z<<2)>>2]=(C+y-q)*-.8660253882408142;w=(C+q)*.9848077297210693;E=(C-y)*-.3420201539993286;C=+g[m+(v<<2)>>2]*.8660253882408142;G=(y+q)*-.6427876353263855;g[j+(F<<2)>>2]=C+(E+w);g[j+(x<<2)>>2]=w+G-C;g[j+(D<<2)>>2]=E-G-C;D=F+1|0;if((D|0)>=2){break}F=D;I=+g[m+(D<<2)>>2]}F=H+a|0;D=0;x=0;while(1){I=+g[j+(x<<2)>>2];C=+g[j+((x|2)<<2)>>2];G=I+C;E=C-I;I=+g[j+((x|1)<<2)>>2];C=+g[j+((x|3)<<2)>>2];w=(I+C)*+g[1077168+(D<<2)>>2]*2.0;v=8-D|0;q=(C-I)*+g[1077248+(v<<2)>>2];I=G+w;C=G-w;z=D+9|0;s=n+(z<<2<<2)|0;g[b+(z<<5<<2)>>2]=+g[s>>2]+ +g[7693888+(F*160|0)+(z<<2)>>2]*C;z=n+(v<<2<<2)|0;g[b+(v<<5<<2)>>2]=C*+g[7693888+(F*160|0)+(v<<2)>>2]+ +g[z>>2];g[s>>2]=I*+g[7693888+(F*160|0)+(D+29<<2)>>2];g[z>>2]=I*+g[7693888+(F*160|0)+(28-D<<2)>>2];I=E+q;C=E-q;z=17-D|0;s=n+(z<<2<<2)|0;g[b+(z<<5<<2)>>2]=C*+g[7693888+(F*160|0)+(z<<2)>>2]+ +g[s>>2];z=n+(D<<2<<2)|0;g[b+(D<<5<<2)>>2]=C*+g[7693888+(F*160|0)+(D<<2)>>2]+ +g[z>>2];g[s>>2]=I*+g[7693888+(F*160|0)+(37-D<<2)>>2];g[z>>2]=I*+g[7693888+(F*160|0)+(D+20<<2)>>2];z=D+1|0;if((z|0)<4){D=z;x=x+4|0}else{break}}I=+g[e>>2];C=+g[l>>2]*.7071067690849304;q=I+C;E=I-C;x=n+208|0;g[b+1664>>2]=+g[x>>2]+ +g[7693940+(F*160|0)>>2]*E;D=n+64|0;g[b+512>>2]=E*+g[7693904+(F*160|0)>>2]+ +g[D>>2];g[x>>2]=q*+g[7694020+(F*160|0)>>2];g[D>>2]=q*+g[7693984+(F*160|0)>>2];D=n+(((c&3|0)!=3?1:69)<<2)|0;x=c+1|0;if((x|0)<(d|0)){m=m+72|0;c=x;n=D;b=b+4|0}else{break}}i=h;return}function _Sa(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0;f=i;g=c[d+60>>2]|0;h=c[d+412>>2]|0;j=c[d+416>>2]|0;if((j-1|0)>>>0>1>>>0){KIb(d,16,2171984,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;l=-22;i=f;return l|0}m=(c[d+72>>2]|0)/1e3|0;n=g+24|0;c[n>>2]=j;c[d+424>>2]=1152;c[d+116>>2]=481;j=g+28|0;c[j>>2]=0;o=0;while(1){if((o|0)>=3){p=0;break}q=e[1965176+(o<<1)>>1]|0;if((q|0)==(h|0)){p=0;break}if((q>>>1|0)==(h|0)){r=7;break}else{o=o+1|0}}if((r|0)==7){c[j>>2]=1;p=1}if((o|0)==3){KIb(d,16,2144376,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;l=-22;i=f;return l|0}c[g+36>>2]=o;o=0;while(1){if((o|0)>=15){break}if((e[1965214+(p*90|0)+(o<<1)>>1]|0|0)==(m|0)){break}else{o=o+1|0}}if((o|0)==15){KIb(d,16,2120696,(k=i,i=i+8|0,c[k>>2]=m,k)|0);i=k;l=-22;i=f;return l|0}c[g+32>>2]=o;s=+(ca(m,1152e3)|0)/(+(h|0)*8.0);c[g+40>>2]=~~s<<3;c[g+44>>2]=0;c[g+48>>2]=~~((s- +Q(s))*65536.0);o=Brb(m,c[n>>2]|0,h,p)|0;c[g+25920>>2]=c[1348376+(o<<2)>>2];c[g+25924>>2]=c[1349576+(o<<2)>>2];if((c[n>>2]|0)>0){o=g+16440|0;p=0;do{c[o+(p<<2)>>2]=0;p=p+1|0;}while((p|0)<(c[n>>2]|0))}n=g+25928|0;p=0;while(1){o=(c[1348544+(p<<2)>>2]|0)+2>>2;h=o&65535;b[n+(p<<1)>>1]=h;if((p&63|0)==0){t=h}else{t=-o&65535}if((p|0)==0){p=p+1|0;continue}else{b[n+(512-p<<1)>>1]=t;o=p+1|0;if((o|0)<257){p=o;continue}else{break}}}p=g+26952|0;t=g+27400|0;n=0;while(1){o=~~(+ad(+(+(3-n|0)/3.0))*1048576.0);c[p+(n<<2)>>2]=(o|0)<1?1:o;a[g+(n+27336)|0]=6-((n|0)/3|0);b[t+(n<<1)>>1]=~~(+ad(+(+((n|0)%3|0|0)/3.0))*32768.0);o=n+1|0;if((o|0)<64){n=o}else{u=0;break}}do{n=u-64|0;do{if((n|0)<-2){v=0}else{if((n|0)<0){v=1;break}if((n|0)==0){v=2;break}v=(n|0)<3?3:4}}while(0);a[g+(u+27208)|0]=v;u=u+1|0;}while((u|0)<128);u=g+27528|0;g=0;while(1){v=c[1348472+(g<<2)>>2]|0;if((v|0)<0){w=-v|0}else{w=v*3|0}b[u+(g<<1)>>1]=w*12|0;v=g+1|0;if((v|0)<17){g=v}else{l=0;break}}i=f;return l|0}function $Sa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0;l=i;i=i+776|0;m=l|0;n=l+128|0;o=l+192|0;p=l+200|0;q=l+456|0;r=l+584|0;s=l+712|0;t=c[f+60>>2]|0;u=t;v=c[j>>2]|0;w=t+24|0;x=c[w>>2]|0;do{if((x|0)>0){z=t+25928|0;A=p+64|0;B=q|0;C=q+116|0;D=q+124|0;E=q+108|0;F=q+100|0;H=q+92|0;I=q+84|0;J=q+76|0;K=q+68|0;L=q+60|0;M=q+52|0;N=q+44|0;O=q+36|0;P=q+28|0;Q=q+20|0;R=q+12|0;S=q+4|0;T=q+120|0;U=q+104|0;V=q+88|0;W=q+72|0;X=q+56|0;Y=q+40|0;Z=q+24|0;_=q+8|0;$=q+112|0;aa=q+16|0;ba=q+80|0;da=q+48|0;ea=q+32|0;fa=0;ga=x;do{ha=u+16440+(fa<<2)|0;ia=u+56+(fa<<13)+7232|0;ja=u+56+(fa<<13)|0;ka=ga<<5;la=v+(fa<<1)|0;ma=c[ha>>2]|0;na=0;oa=u+16448+(fa*4608|0)|0;while(1){pa=ma+31|0;qa=la;ra=0;while(1){b[u+56+(fa<<13)+(pa-ra<<1)>>1]=b[qa>>1]|0;sa=ra+1|0;if((sa|0)<32){qa=qa+(ga<<1)|0;ra=sa}else{break}}ra=u+56+(fa<<13)+(ma<<1)|0;qa=z;pa=0;while(1){sa=ca(b[qa>>1]|0,b[ra>>1]|0)|0;ta=(ca(b[qa+128>>1]|0,b[ra+128>>1]|0)|0)+sa|0;sa=ta+(ca(b[qa+256>>1]|0,b[ra+256>>1]|0)|0)|0;ta=sa+(ca(b[qa+384>>1]|0,b[ra+384>>1]|0)|0)|0;sa=ta+(ca(b[qa+512>>1]|0,b[ra+512>>1]|0)|0)|0;ta=sa+(ca(b[qa+640>>1]|0,b[ra+640>>1]|0)|0)|0;sa=ta+(ca(b[qa+768>>1]|0,b[ra+768>>1]|0)|0)|0;c[p+(pa<<2)>>2]=sa+(ca(b[qa+896>>1]|0,b[ra+896>>1]|0)|0);sa=pa+1|0;if((sa|0)<64){ra=ra+2|0;qa=qa+2|0;pa=sa}else{break}}c[B>>2]=c[A>>2]>>14;pa=1;while(1){c[q+(pa<<2)>>2]=(c[p+(16-pa<<2)>>2]|0)+(c[p+(pa+16<<2)>>2]|0)>>14;qa=pa+1|0;if((qa|0)<17){pa=qa}else{ua=17;break}}do{c[q+(ua<<2)>>2]=(c[p+(ua+16<<2)>>2]|0)-(c[p+(80-ua<<2)>>2]|0)>>14;ua=ua+1|0;}while((ua|0)<32);pa=c[C>>2]|0;qa=(c[D>>2]|0)+pa|0;ra=c[E>>2]|0;sa=c[F>>2]|0;ta=sa+ra|0;va=c[H>>2]|0;c[F>>2]=va+sa;sa=c[I>>2]|0;wa=sa+va|0;va=c[J>>2]|0;xa=va+sa|0;sa=c[K>>2]|0;ya=sa+va|0;va=c[L>>2]|0;c[K>>2]=va+sa;sa=c[M>>2]|0;za=sa+va|0;va=c[N>>2]|0;Aa=va+sa|0;sa=c[O>>2]|0;Ba=sa+va|0;va=c[P>>2]|0;c[O>>2]=va+sa;sa=c[Q>>2]|0;Ca=sa+va|0;va=c[R>>2]|0;Da=va+sa|0;c[Q>>2]=Da;sa=(c[S>>2]|0)+va|0;va=c[U>>2]|0;Ea=(c[T>>2]|0)+va|0;Fa=c[V>>2]|0;c[U>>2]=Fa+va;va=c[W>>2]|0;Ga=va+Fa|0;Fa=ya+wa|0;Ha=c[X>>2]|0;c[W>>2]=Ha+va;va=c[Y>>2]|0;Ia=va+Ha|0;Ha=Ba+za|0;Ja=c[Z>>2]|0;c[Y>>2]=Ja+va;va=(c[_>>2]|0)+Ja|0;Ja=sa+Ca|0;c[P>>2]=Ja;Ka=c[ba>>2]|0;La=(c[$>>2]|0)+Ka|0;c[T>>2]=Ea+Ga;Ea=c[da>>2]|0;c[ba>>2]=Ea+Ka;c[I>>2]=Aa+xa;c[H>>2]=Ha+Fa;Ka=Ea+(c[aa>>2]|0)|0;c[X>>2]=va+Ia;c[R>>2]=-sa;c[Z>>2]=-va;c[N>>2]=-(Ba+Ca|0);c[da>>2]=-Ka;c[M>>2]=-(Aa+Da|0);c[L>>2]=-(Ha+Ja|0);c[J>>2]=-(za+ya|0);c[V>>2]=-(Ga+Ia|0);c[E>>2]=-(wa+ta|0);c[$>>2]=-La;c[C>>2]=-(ra+pa+xa|0);c[D>>2]=-(qa+ta+Fa|0);Fa=B;while(1){ta=Fa+64|0;qa=c[ta>>2]|0;xa=Erc(qa,(qa|0)<0|0?-1:0,23170,0)|0;qa=xa>>>15|G<<17;xa=c[Fa>>2]|0;pa=xa-qa|0;ra=qa+xa|0;xa=Fa+96|0;qa=Fa+32|0;La=c[qa>>2]|0;wa=-((c[xa>>2]|0)+La|0)|0;Ia=Erc(wa,(wa|0)<0|0?-1:0,23170,0)|0;wa=Ia>>>15|G<<17;Ia=La-wa|0;Ga=Erc(Ia,(Ia|0)<0|0?-1:0,17733,0)|0;Ia=Ga>>>15|G<<17;Ga=wa+La|0;La=Erc(Ga,(Ga|0)<0|0?-1:0,42813,0)|0;Ga=La>>>15|G<<17;c[Fa>>2]=Ia+ra;c[qa>>2]=pa-Ga;c[ta>>2]=Ga+pa;c[xa>>2]=ra-Ia;Ia=Fa+4|0;if((Ia|0)==(ea|0)){Ma=B;break}else{Fa=Ia}}while(1){Fa=Ma+112|0;Ia=c[Fa>>2]|0;ra=Erc(Ia,(Ia|0)<0|0?-1:0,16704,0)|0;Ia=ra>>>15|G<<17;ra=c[Ma>>2]|0;c[Fa>>2]=ra-Ia;c[Ma>>2]=Ia+ra;ra=Ma+16|0;Ia=c[ra>>2]|0;Fa=Erc(Ia,(Ia|0)<0|0?-1:0,83981,0)|0;Ia=Fa>>>15|G<<17;Fa=Ma+96|0;xa=c[Fa>>2]|0;c[ra>>2]=xa-Ia;c[Fa>>2]=Ia+xa;xa=Ma+80|0;Ia=c[xa>>2]|0;Fa=Erc(Ia,(Ia|0)<0|0?-1:0,29490,0)|0;Ia=Fa>>>15|G<<17;Fa=Ma+32|0;ra=c[Fa>>2]|0;c[xa>>2]=ra-Ia;c[Fa>>2]=Ia+ra;ra=Ma+48|0;Ia=c[ra>>2]|0;Fa=Erc(Ia,(Ia|0)<0|0?-1:0,19704,0)|0;Ia=Fa>>>15|G<<17;Fa=Ma+64|0;xa=c[Fa>>2]|0;c[ra>>2]=xa-Ia;c[Fa>>2]=Ia+xa;xa=Ma+4|0;if((xa|0)==(aa|0)){Na=1636008;Oa=0;break}else{Ma=xa}}while(1){xa=Oa<<2;Ia=q+(30-xa<<2)|0;Fa=c[Ia>>2]|0;ra=c[Na>>2]|0;pa=Erc(ra,(ra|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=pa>>>15|G<<17;pa=q+(xa<<2)|0;c[Ia>>2]=(c[pa>>2]|0)-Fa;c[pa>>2]=Fa+(c[pa>>2]|0);pa=q+((xa|2)<<2)|0;Fa=c[pa>>2]|0;Ia=Na+4|0;ra=c[Ia>>2]|0;Ga=Erc(ra,(ra|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=Ga>>>15|G<<17;Ga=q+(28-xa<<2)|0;c[pa>>2]=(c[Ga>>2]|0)-Fa;c[Ga>>2]=Fa+(c[Ga>>2]|0);Ga=q+(31-xa<<2)|0;Fa=c[Ga>>2]|0;pa=c[Na>>2]|0;ra=Erc(pa,(pa|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=ra>>>15|G<<17;ra=q+((xa|1)<<2)|0;c[Ga>>2]=(c[ra>>2]|0)-Fa;c[ra>>2]=Fa+(c[ra>>2]|0);ra=q+((xa|3)<<2)|0;Fa=c[ra>>2]|0;Ga=c[Ia>>2]|0;Ia=Erc(Ga,(Ga|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=Ia>>>15|G<<17;Ia=q+(29-xa<<2)|0;c[ra>>2]=(c[Ia>>2]|0)-Fa;c[Ia>>2]=Fa+(c[Ia>>2]|0);Ia=Oa+1|0;if((Ia|0)<4){Na=Na+8|0;Oa=Ia}else{Pa=T;Qa=S;Ra=1636040;break}}while(1){Ia=c[Qa>>2]|0;Fa=c[Ra>>2]|0;ra=Erc(Fa,(Fa|0)<0|0?-1:0,Ia,(Ia|0)<0|0?-1:0)|0;Ia=ra>>>15|G<<17;c[Qa>>2]=(c[Pa>>2]|0)-Ia;c[Pa>>2]=Ia+(c[Pa>>2]|0);Ia=Pa-8|0;if(Ia>>>0<B>>>0){Sa=0;break}else{Pa=Ia;Qa=Qa+8|0;Ra=Ra+4|0}}do{c[oa+(Sa<<2)>>2]=c[q+(c[1906416+(Sa<<2)>>2]<<2)>>2];Sa=Sa+1|0;}while((Sa|0)<32);Ia=ma-32|0;if((Ia|0)<0){nrc(ia|0,ja|0,960)|0;Ta=3584}else{Ta=Ia}Ia=na+1|0;if((Ia|0)<36){la=la+(ka<<1)|0;ma=Ta;na=Ia;oa=oa+128|0}else{break}}c[ha>>2]=Ta;fa=fa+1|0;ga=c[w>>2]|0;}while((fa|0)<(ga|0));if((ga|0)<=0){Ua=ga;Va=23;break}fa=t+25856|0;B=t+16448|0;S=t+25920|0;T=t+25664|0;aa=0;ea=ga;while(1){D=c[S>>2]|0;if((D|0)>0){C=0;$=T+(aa*96|0)|0;while(1){E=C+32|0;V=C+64|0;J=C+96|0;L=C+128|0;M=C+160|0;da=C+192|0;N=C+224|0;Z=C+256|0;R=C+288|0;X=C+320|0;H=C+352|0;I=0;do{ba=c[B+(aa*4608|0)+(I*1536|0)+(C<<2)>>2]|0;P=(ba|0)>-1?ba:-ba|0;ba=c[B+(aa*4608|0)+(I*1536|0)+(E<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(V<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(J<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(L<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(M<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(da<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(N<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(Z<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(R<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(X<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(H<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;do{if((ba|0)>1){P=ba>>>0>65535>>>0;_=P?ba>>>16:ba;Y=P?16:0;if((_&65280|0)==0){Wa=Y;Xa=_}else{Wa=Y|8;Xa=_>>>8}_=((21-Wa-(d[1359664+Xa|0]|0)|0)*3|0)-3|0;if((_|0)>-1){Ya=_}else{Za=0;break}while(1){_=Ya+1|0;if((ba|0)>(c[u+26952+(_<<2)>>2]|0)){break}else{Ya=_}}Za=Ya&255}else{Za=62}}while(0);a[$+I|0]=Za;I=I+1|0;}while((I|0)<3);I=a[$]|0;H=$+1|0;X=a[H]|0;R=X&255;Z=$+2|0;N=a[Z]|0;switch((d[R+64-(N&255)+(u+27208)|0]|0)+((d[(I&255)+64-R+(u+27208)|0]|0)*5|0)|0){case 18:case 13:{a[H]=N;a[$]=N;_a=2;break};case 6:case 7:case 10:case 11:case 12:{a[Z]=I;a[H]=I;_a=2;break};case 1:case 2:case 21:case 22:{a[Z]=X;_a=3;break};case 5:case 9:case 14:{a[H]=I;_a=1;break};case 8:{if((I&255)>>>0>(N&255)>>>0){a[$]=N;$a=N}else{$a=I}a[Z]=$a;a[H]=$a;_a=2;break};case 3:case 23:{a[H]=N;_a=3;break};case 17:case 16:case 15:{a[Z]=X;a[$]=X;_a=2;break};default:{_a=0}}a[fa+(aa<<5)+C|0]=_a;X=C+1|0;if((X|0)<(D|0)){C=X;$=$+3|0}else{break}}ab=c[w>>2]|0}else{ab=ea}$=aa+1|0;if(($|0)<(ab|0)){aa=$;ea=ab}else{break}}ea=(ab|0)>0;if(!ea){bb=ab;cb=0;break}aa=c[t+25920>>2]|0;if((aa|0)>0){db=0}else{bb=ab;cb=1;break}while(1){fa=0;do{b[r+(db<<6)+(fa<<1)>>1]=~~(+g[1215224+(fa<<2)>>2]*10.0);fa=fa+1|0;}while((fa|0)<(aa|0));fa=db+1|0;if((fa|0)<(ab|0)){db=fa}else{bb=ab;cb=ea;break}}}else{Ua=x;Va=23}}while(0);if((Va|0)==23){bb=Ua;cb=(Ua|0)>0}nrc(m|0,r|0,bb<<6)|0;Ua=bb<<5;mrc(n|0,0,Ua|0)|0;mrc(s|0,0,Ua|0)|0;Ua=c[t+40>>2]|0;Va=t+44|0;x=(c[Va>>2]|0)+(c[t+48>>2]|0)|0;c[Va>>2]=x;if((x|0)>65535){c[Va>>2]=x-65536;c[t+52>>2]=1;eb=Ua+8|0}else{c[t+52>>2]=0;eb=Ua}Ua=t+25924|0;x=t+25920|0;Va=c[x>>2]|0;ab=(Va|0)>0;if(ab){db=0;_a=32;$a=c[Ua>>2]|0;while(1){Za=d[$a]|0;Ya=(ca(Za,bb)|0)+_a|0;Xa=db+1|0;if((Xa|0)<(Va|0)){db=Xa;_a=Ya;$a=$a+(1<<Za)|0}else{fb=Ya;break}}}else{fb=32}a:do{if(cb){$a=fb;while(1){while(1){if(ab){gb=0;hb=-2147483648;ib=-1;jb=-1}else{kb=$a;break a}while(1){_a=0;db=hb;Ya=ib;Za=jb;while(1){Xa=b[m+(gb<<6)+(_a<<1)>>1]|0;if((Xa|0)>(db|0)){Wa=(a[n+(gb<<5)+_a|0]|0)==2;lb=Wa?Za:_a;mb=Wa?Ya:gb;nb=Wa?db:Xa}else{lb=Za;mb=Ya;nb=db}Xa=_a+1|0;if((Xa|0)<(Va|0)){_a=Xa;db=nb;Ya=mb;Za=lb}else{break}}Za=gb+1|0;if((Za|0)<(bb|0)){gb=Za;hb=nb;ib=mb;jb=lb}else{break}}if((lb|0)<0){kb=$a;break a}Za=c[Ua>>2]|0;if((lb|0)>0){Ya=0;db=Za;while(1){_a=db+(1<<d[db])|0;Xa=Ya+1|0;if((Xa|0)<(lb|0)){Ya=Xa;db=_a}else{ob=_a;break}}}else{ob=Za}pb=n+(mb<<5)+lb|0;if((a[pb]|0)==0){qb=((d[785872+(d[u+25856+(mb<<5)+lb|0]|0)|0]|0)*6|0)+2+(e[u+27528+(d[ob+1|0]<<1)>>1]|0)|0}else{db=d[s+(mb<<5)+lb|0]|0;qb=(e[u+27528+(d[ob+(db+1)|0]<<1)>>1]|0)-(e[u+27528+(d[ob+db|0]<<1)>>1]|0)|0}rb=qb+$a|0;if((rb|0)<=(eb|0)){break}a[pb]=2}db=s+(mb<<5)+lb|0;Ya=(a[db]|0)+1&255;a[db]=Ya;db=Ya&255;b[m+(mb<<6)+(lb<<1)>>1]=(b[r+(mb<<6)+(lb<<1)>>1]|0)-(b[687792+(d[ob+db|0]<<1)>>1]|0);a[pb]=(db|0)==((1<<d[ob])-1|0)?2:1;$a=rb}}else{kb=fb}}while(0);fb=eb-kb|0;if(!((fb|0)>-1)){KIb(0,0,2296456,(kb=i,i=i+24|0,c[kb>>2]=2245384,c[kb+8>>2]=2203920,c[kb+16>>2]=593,kb)|0);i=kb;Hd();return 0}kb=d5a(f,h,1792,0)|0;if((kb|0)<0){sb=kb;i=l;return sb|0}kb=h+28|0;eb=c[kb>>2]|0;rb=(eb|0)<0;ob=rb?0:c[h+24>>2]|0;pb=rb?0:eb;c[t+20>>2]=pb<<3;eb=t+8|0;c[eb>>2]=ob;c[t+16>>2]=ob+pb;pb=t+12|0;c[pb>>2]=ob;rb=t+4|0;lb=t;mb=ob;y=je(((c[w>>2]|0)==2?0:192)|(c[t+52>>2]|(c[t+36>>2]|(c[t+32>>2]|(1-(c[t+28>>2]|0)<<7|1048400))<<2)<<1)<<9|4|0)|0;a[mb]=y;y=y>>8;a[mb+1|0]=y;y=y>>8;a[mb+2|0]=y;y=y>>8;a[mb+3|0]=y;mb=(c[pb>>2]|0)+4|0;c[pb>>2]=mb;c[lb>>2]=0;c[rb>>2]=32;t=c[x>>2]|0;do{if((t|0)>0){ob=0;r=0;m=c[w>>2]|0;qb=0;n=32;jb=t;ib=mb;while(1){nb=d[(c[Ua>>2]|0)+ob|0]|0;if((m|0)>0){hb=32-nb|0;gb=0;bb=qb;Va=n;ab=m;cb=ib;while(1){$a=d[s+(gb<<5)+r|0]|0;if((Va|0)>(nb|0)){tb=Va-nb|0;ub=$a|bb<<nb;vb=ab;wb=cb}else{db=cb;y=je($a>>>((nb-Va|0)>>>0)|bb<<Va|0)|0;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;db=(c[pb>>2]|0)+4|0;c[pb>>2]=db;tb=hb+Va|0;ub=$a;vb=c[w>>2]|0;wb=db}c[lb>>2]=ub;c[rb>>2]=tb;db=gb+1|0;if((db|0)<(vb|0)){gb=db;bb=ub;Va=tb;ab=vb;cb=wb}else{break}}xb=vb;yb=ub;zb=tb;Ab=c[x>>2]|0;Bb=wb}else{xb=m;yb=qb;zb=n;Ab=jb;Bb=ib}cb=r+1|0;if((cb|0)>=(Ab|0)){break}ob=(1<<nb)+ob|0;r=cb;m=xb;qb=yb;n=zb;jb=Ab;ib=Bb}if((Ab|0)>0){Cb=0;Db=xb;Eb=yb;Fb=zb;Gb=Ab;Hb=Bb}else{Ib=0;Jb=Ab;Kb=yb;Lb=zb;Mb=Bb;break}while(1){if((Db|0)>0){ib=0;jb=Db;n=Eb;qb=Fb;m=Hb;while(1){if((a[s+(ib<<5)+Cb|0]|0)==0){Nb=jb;Ob=n;Pb=qb;Qb=m}else{r=d[u+25856+(ib<<5)+Cb|0]|0;if((qb|0)>2){Rb=qb-2|0;Sb=r|n<<2;Tb=jb;Ub=m}else{ob=m;y=je(r>>>((2-qb|0)>>>0)|n<<qb|0)|0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;Rb=qb+30|0;Sb=r;Tb=c[w>>2]|0;Ub=ob}c[lb>>2]=Sb;c[rb>>2]=Rb;Nb=Tb;Ob=Sb;Pb=Rb;Qb=Ub}ob=ib+1|0;if((ob|0)<(Nb|0)){ib=ob;jb=Nb;n=Ob;qb=Pb;m=Qb}else{break}}Vb=Nb;Wb=Ob;Xb=Pb;Yb=c[x>>2]|0;Zb=Qb}else{Vb=Db;Wb=Eb;Xb=Fb;Yb=Gb;Zb=Hb}m=Cb+1|0;if((m|0)<(Yb|0)){Cb=m;Db=Vb;Eb=Wb;Fb=Xb;Gb=Yb;Hb=Zb}else{break}}if((Yb|0)>0){_b=0;$b=Vb;ac=Wb;bc=Xb;cc=Yb;dc=Zb}else{Ib=0;Jb=Yb;Kb=Wb;Lb=Xb;Mb=Zb;break}while(1){if(($b|0)>0){m=0;qb=ac;n=bc;jb=dc;while(1){do{if((a[s+(m<<5)+_b|0]|0)==0){ec=qb;fc=n;gc=jb}else{ib=u+25664+(m*96|0)+(_b*3|0)|0;nb=d[u+25856+(m<<5)+_b|0]|0;if((nb|0)==3|(nb|0)==1){ob=d[ib]|0;if((n|0)>6){hc=n-6|0;ic=ob|qb<<6;jc=jb}else{r=jb;y=je(ob>>>((6-n|0)>>>0)|qb<<n|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;hc=n+26|0;ic=ob;jc=r}c[lb>>2]=ic;c[rb>>2]=hc;r=d[u+25664+(m*96|0)+(_b*3|0)+2|0]|0;if((hc|0)>6){kc=hc-6|0;lc=r|ic<<6;mc=jc}else{ob=jc;y=je(r>>>((6-hc|0)>>>0)|ic<<hc|0)|0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;kc=hc+26|0;lc=r;mc=ob}c[lb>>2]=lc;c[rb>>2]=kc;ec=lc;fc=kc;gc=mc;break}else if((nb|0)==0){ob=d[ib]|0;if((n|0)>6){nc=n-6|0;oc=ob|qb<<6;pc=jb}else{r=jb;y=je(ob>>>((6-n|0)>>>0)|qb<<n|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;nc=n+26|0;oc=ob;pc=r}c[lb>>2]=oc;c[rb>>2]=nc;r=d[u+25664+(m*96|0)+(_b*3|0)+1|0]|0;if((nc|0)>6){qc=nc-6|0;rc=r|oc<<6;sc=pc}else{ob=pc;y=je(r>>>((6-nc|0)>>>0)|oc<<nc|0)|0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;qc=nc+26|0;rc=r;sc=ob}c[lb>>2]=rc;c[rb>>2]=qc;ob=d[u+25664+(m*96|0)+(_b*3|0)+2|0]|0;if((qc|0)>6){tc=qc-6|0;uc=ob|rc<<6;vc=sc}else{r=sc;y=je(ob>>>((6-qc|0)>>>0)|rc<<qc|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;tc=qc+26|0;uc=ob;vc=r}c[lb>>2]=uc;c[rb>>2]=tc;ec=uc;fc=tc;gc=vc;break}else if((nb|0)==2){nb=d[ib]|0;if((n|0)>6){wc=n-6|0;xc=nb|qb<<6;yc=jb}else{ib=jb;y=je(nb>>>((6-n|0)>>>0)|qb<<n|0)|0;a[ib]=y;y=y>>8;a[ib+1|0]=y;y=y>>8;a[ib+2|0]=y;y=y>>8;a[ib+3|0]=y;ib=(c[pb>>2]|0)+4|0;c[pb>>2]=ib;wc=n+26|0;xc=nb;yc=ib}c[lb>>2]=xc;c[rb>>2]=wc;ec=xc;fc=wc;gc=yc;break}else{ec=qb;fc=n;gc=jb;break}}}while(0);Za=m+1|0;zc=c[w>>2]|0;if((Za|0)<(zc|0)){m=Za;qb=ec;n=fc;jb=gc}else{break}}Ac=zc;Bc=ec;Cc=fc;Dc=c[x>>2]|0;Ec=gc}else{Ac=$b;Bc=ac;Cc=bc;Dc=cc;Ec=dc}jb=_b+1|0;if((jb|0)<(Dc|0)){_b=jb;$b=Ac;ac=Bc;bc=Cc;cc=Dc;dc=Ec}else{Ib=0;Jb=Dc;Kb=Bc;Lb=Cc;Mb=Ec;break}}}else{Ib=0;Jb=t;Kb=0;Lb=32;Mb=mb}}while(0);while(1){mb=0;t=Jb;Ec=Kb;Cc=Lb;Bc=Mb;while(1){b:do{if((t|0)>0){Dc=mb+1|0;dc=mb+2|0;cc=0;bc=0;ac=c[w>>2]|0;Ac=Ec;$b=Cc;_b=t;gc=Bc;while(1){fc=d[(c[Ua>>2]|0)+cc|0]|0;if((ac|0)>0){ec=0;zc=Ac;yc=$b;wc=gc;while(1){xc=a[s+(ec<<5)+bc|0]|0;do{if(xc<<24>>24==0){Fc=zc;Gc=yc;Hc=wc}else{vc=d[(c[Ua>>2]|0)+((xc&255)+cc)|0]|0;tc=c[1348400+(vc<<2)>>2]|0;uc=d[u+25664+(ec*96|0)+(bc*3|0)+Ib|0]|0;qc=a[u+27336+uc|0]|0;rc=qc<<24>>24;sc=e[u+27400+(uc<<1)>>1]|0;uc=-rc|0;nc=tc-1|0;oc=c[u+16448+(ec*4608|0)+(Ib*1536|0)+(mb<<7)+(bc<<2)>>2]|0;if(qc<<24>>24<0){qc=(ca(((ca(oc<<uc,sc)|0)>>15)+32768|0,tc)|0)>>16;pc=(qc|0)<0?0:qc;qc=(ca(((ca(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(Dc<<7)+(bc<<2)>>2]<<uc,sc)|0)>>15)+32768|0,tc)|0)>>16;mc=(qc|0)<0?0:qc;qc=(ca(((ca(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(dc<<7)+(bc<<2)>>2]<<uc,sc)|0)>>15)+32768|0,tc)|0)>>16;uc=(qc|0)<0?0:qc;Ic=(pc|0)<(tc|0)?pc:nc;Jc=(mc|0)<(tc|0)?mc:nc;Kc=(uc|0)<(tc|0)?uc:nc}else{uc=(ca(((ca(oc>>rc,sc)|0)>>15)+32768|0,tc)|0)>>16;oc=(uc|0)<0?0:uc;uc=(ca(((ca(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(Dc<<7)+(bc<<2)>>2]>>rc,sc)|0)>>15)+32768|0,tc)|0)>>16;mc=(uc|0)<0?0:uc;uc=(ca(((ca(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(dc<<7)+(bc<<2)>>2]>>rc,sc)|0)>>15)+32768|0,tc)|0)>>16;sc=(uc|0)<0?0:uc;Ic=(oc|0)<(tc|0)?oc:nc;Jc=(mc|0)<(tc|0)?mc:nc;Kc=(sc|0)<(tc|0)?sc:nc}nc=c[1348472+(vc<<2)>>2]|0;vc=-nc|0;if((nc|0)<0){sc=(ca((ca(Kc,tc)|0)+Jc|0,tc)|0)+Ic|0;if((yc|0)>(vc|0)){Lc=nc+yc|0;Mc=sc|zc<<vc;Nc=wc}else{tc=wc;y=je(sc>>>((vc-yc|0)>>>0)|zc<<yc|0)|0;a[tc]=y;y=y>>8;a[tc+1|0]=y;y=y>>8;a[tc+2|0]=y;y=y>>8;a[tc+3|0]=y;tc=(c[pb>>2]|0)+4|0;c[pb>>2]=tc;Lc=yc+32+nc|0;Mc=sc;Nc=tc}c[lb>>2]=Mc;c[rb>>2]=Lc;Fc=Mc;Gc=Lc;Hc=Nc;break}if((yc|0)>(nc|0)){Oc=yc;Pc=zc<<nc|Ic;Qc=wc}else{tc=wc;y=je(Ic>>>((nc-yc|0)>>>0)|zc<<yc|0)|0;a[tc]=y;y=y>>8;a[tc+1|0]=y;y=y>>8;a[tc+2|0]=y;y=y>>8;a[tc+3|0]=y;tc=(c[pb>>2]|0)+4|0;c[pb>>2]=tc;Oc=yc+32|0;Pc=Ic;Qc=tc}tc=Oc-nc|0;c[lb>>2]=Pc;c[rb>>2]=tc;if((tc|0)>(nc|0)){Rc=tc-nc|0;Sc=Pc<<nc|Jc;Tc=Qc}else{sc=Qc;y=je(Jc>>>((nc-tc|0)>>>0)|Pc<<tc|0)|0;a[sc]=y;y=y>>8;a[sc+1|0]=y;y=y>>8;a[sc+2|0]=y;y=y>>8;a[sc+3|0]=y;sc=(c[pb>>2]|0)+4|0;c[pb>>2]=sc;Rc=32-nc+tc|0;Sc=Jc;Tc=sc}c[lb>>2]=Sc;c[rb>>2]=Rc;if((Rc|0)>(nc|0)){Uc=Rc-nc|0;Vc=Sc<<nc|Kc;Wc=Tc}else{sc=Tc;y=je(Kc>>>((nc-Rc|0)>>>0)|Sc<<Rc|0)|0;a[sc]=y;y=y>>8;a[sc+1|0]=y;y=y>>8;a[sc+2|0]=y;y=y>>8;a[sc+3|0]=y;sc=(c[pb>>2]|0)+4|0;c[pb>>2]=sc;Uc=32-nc+Rc|0;Vc=Kc;Wc=sc}c[lb>>2]=Vc;c[rb>>2]=Uc;Fc=Vc;Gc=Uc;Hc=Wc}}while(0);xc=ec+1|0;Xc=c[w>>2]|0;if((xc|0)<(Xc|0)){ec=xc;zc=Fc;yc=Gc;wc=Hc}else{break}}Yc=Xc;Zc=Fc;_c=Gc;$c=c[x>>2]|0;ad=Hc}else{Yc=ac;Zc=Ac;_c=$b;$c=_b;ad=gc}wc=bc+1|0;if((wc|0)>=($c|0)){bd=$c;cd=Zc;dd=_c;ed=ad;break b}cc=(1<<fc)+cc|0;bc=wc;ac=Yc;Ac=Zc;$b=_c;_b=$c;gc=ad}}else{bd=t;cd=Ec;dd=Cc;ed=Bc}}while(0);gc=mb+3|0;if((gc|0)<12){mb=gc;t=bd;Ec=cd;Cc=dd;Bc=ed}else{break}}Bc=Ib+1|0;if((Bc|0)<3){Ib=Bc;Jb=bd;Kb=cd;Lb=dd;Mb=ed}else{break}}if((fb|0)>0){Mb=0;Lb=cd;Kb=dd;bd=ed;while(1){if((Kb|0)>1){fd=Kb-1|0;gd=Lb<<1;hd=bd}else{Jb=bd;y=je(Lb<<Kb|0)|0;a[Jb]=y;y=y>>8;a[Jb+1|0]=y;y=y>>8;a[Jb+2|0]=y;y=y>>8;a[Jb+3|0]=y;Jb=(c[pb>>2]|0)+4|0;c[pb>>2]=Jb;fd=Kb+31|0;gd=0;hd=Jb}c[lb>>2]=gd;c[rb>>2]=fd;Jb=Mb+1|0;if((Jb|0)<(fb|0)){Mb=Jb;Lb=gd;Kb=fd;bd=hd}else{id=fd;jd=gd;kd=hd;break}}}else{id=dd;jd=cd;kd=ed}c:do{if((id|0)<32){ed=jd<<id;c[lb>>2]=ed;cd=ed>>>24&255;ed=kd;while(1){c[pb>>2]=ed+1;a[ed]=cd;dd=c[lb>>2]|0;c[lb>>2]=dd<<8;hd=(c[rb>>2]|0)+8|0;c[rb>>2]=hd;if((hd|0)>=32){break c}cd=dd>>>16&255;ed=c[pb>>2]|0}}}while(0);c[rb>>2]=32;c[lb>>2]=0;lb=j+136|0;j=c[lb>>2]|0;kd=c[lb+4>>2]|0;if((j|0)==0&(kd|0)==(-2147483648|0)){ld=32}else{lb=c[f+116>>2]|0;c[o>>2]=1;c[o+4>>2]=c[f+412>>2];id=XIb(lb,(lb|0)<0|0?-1:0,o,f+104|0)|0;f=xrc(j,kd,id,G)|0;id=h+8|0;c[id>>2]=f;c[id+4>>2]=G;ld=c[rb>>2]|0}c[kb>>2]=(32-ld+((c[pb>>2]|0)-(c[eb>>2]|0)<<3)|0)/8|0;c[k>>2]=1;sb=0;i=l;return sb|0}function aTa(d){d=d|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0;f=i;h=c[d+60>>2]|0;j=c[d+412>>2]|0;k=c[d+416>>2]|0;if((k-1|0)>>>0>1>>>0){KIb(d,16,2171936,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;m=-22;i=f;return m|0}n=(c[d+72>>2]|0)/1e3|0;o=h+24|0;c[o>>2]=k;c[d+424>>2]=1152;c[d+116>>2]=481;k=h+28|0;c[k>>2]=0;p=0;while(1){if((p|0)>=3){q=0;break}r=e[1965176+(p<<1)>>1]|0;if((r|0)==(j|0)){q=0;break}if((r>>>1|0)==(j|0)){s=7;break}else{p=p+1|0}}if((s|0)==7){c[k>>2]=1;q=1}if((p|0)==3){KIb(d,16,2144336,(l=i,i=i+8|0,c[l>>2]=j,l)|0);i=l;m=-22;i=f;return m|0}c[h+36>>2]=p;p=0;while(1){if((p|0)>=15){break}if((e[1965214+(q*90|0)+(p<<1)>>1]|0|0)==(n|0)){break}else{p=p+1|0}}if((p|0)==15){KIb(d,16,2120656,(l=i,i=i+8|0,c[l>>2]=n,l)|0);i=l;m=-22;i=f;return m|0}c[h+32>>2]=p;t=+(ca(n,1152e3)|0)/(+(j|0)*8.0);c[h+40>>2]=~~t<<3;c[h+44>>2]=0;c[h+48>>2]=~~((t- +Q(t))*65536.0);p=Brb(n,c[o>>2]|0,j,q)|0;c[h+25920>>2]=c[1348376+(p<<2)>>2];c[h+25924>>2]=c[1349576+(p<<2)>>2];if((c[o>>2]|0)>0){p=h+16440|0;q=0;do{c[p+(q<<2)>>2]=0;q=q+1|0;}while((q|0)<(c[o>>2]|0))}o=h+25928|0;q=0;while(1){p=(c[1348544+(q<<2)>>2]|0)+2>>2;j=p&65535;b[o+(q<<1)>>1]=j;if((q&63|0)==0){u=j}else{u=-p&65535}if((q|0)==0){q=q+1|0;continue}else{b[o+(512-q<<1)>>1]=u;p=q+1|0;if((p|0)<257){q=p;continue}else{break}}}q=h+26952|0;u=h+27336|0;o=0;while(1){p=3-o|0;j=~~(+ad(+(+(p|0)/3.0))*1048576.0);c[q+(o<<2)>>2]=(j|0)<1?1:j;g[u+(o<<2)>>2]=+ad(+(+(-p|0)/3.0))*9.5367431640625e-7;p=o+1|0;if((p|0)<64){o=p}else{v=0;break}}do{o=v-64|0;do{if((o|0)<-2){w=0}else{if((o|0)<0){w=1;break}if((o|0)==0){w=2;break}w=(o|0)<3?3:4}}while(0);a[h+(v+27208)|0]=w;v=v+1|0;}while((v|0)<128);v=h+27592|0;h=0;while(1){w=c[1348472+(h<<2)>>2]|0;if((w|0)<0){x=-w|0}else{x=w*3|0}b[v+(h<<1)>>1]=x*12|0;w=h+1|0;if((w|0)<17){h=w}else{m=0;break}}i=f;return m|0}function bTa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0.0,Jc=0.0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0;l=i;i=i+776|0;m=l|0;n=l+128|0;o=l+192|0;p=l+200|0;q=l+456|0;r=l+584|0;s=l+712|0;t=c[f+60>>2]|0;u=t;v=c[j>>2]|0;w=t+24|0;x=c[w>>2]|0;do{if((x|0)>0){z=t+25928|0;A=p+64|0;B=q|0;C=q+116|0;D=q+124|0;E=q+108|0;F=q+100|0;H=q+92|0;I=q+84|0;J=q+76|0;K=q+68|0;L=q+60|0;M=q+52|0;N=q+44|0;O=q+36|0;P=q+28|0;Q=q+20|0;R=q+12|0;S=q+4|0;T=q+120|0;U=q+104|0;V=q+88|0;W=q+72|0;X=q+56|0;Y=q+40|0;Z=q+24|0;_=q+8|0;$=q+112|0;aa=q+16|0;ba=q+80|0;da=q+48|0;ea=q+32|0;fa=0;ga=x;do{ha=u+16440+(fa<<2)|0;ia=u+56+(fa<<13)+7232|0;ja=u+56+(fa<<13)|0;ka=ga<<5;la=v+(fa<<1)|0;ma=c[ha>>2]|0;na=0;oa=u+16448+(fa*4608|0)|0;while(1){pa=ma+31|0;qa=la;ra=0;while(1){b[u+56+(fa<<13)+(pa-ra<<1)>>1]=b[qa>>1]|0;sa=ra+1|0;if((sa|0)<32){qa=qa+(ga<<1)|0;ra=sa}else{break}}ra=u+56+(fa<<13)+(ma<<1)|0;qa=z;pa=0;while(1){sa=ca(b[qa>>1]|0,b[ra>>1]|0)|0;ta=(ca(b[qa+128>>1]|0,b[ra+128>>1]|0)|0)+sa|0;sa=ta+(ca(b[qa+256>>1]|0,b[ra+256>>1]|0)|0)|0;ta=sa+(ca(b[qa+384>>1]|0,b[ra+384>>1]|0)|0)|0;sa=ta+(ca(b[qa+512>>1]|0,b[ra+512>>1]|0)|0)|0;ta=sa+(ca(b[qa+640>>1]|0,b[ra+640>>1]|0)|0)|0;sa=ta+(ca(b[qa+768>>1]|0,b[ra+768>>1]|0)|0)|0;c[p+(pa<<2)>>2]=sa+(ca(b[qa+896>>1]|0,b[ra+896>>1]|0)|0);sa=pa+1|0;if((sa|0)<64){ra=ra+2|0;qa=qa+2|0;pa=sa}else{break}}c[B>>2]=c[A>>2]>>14;pa=1;while(1){c[q+(pa<<2)>>2]=(c[p+(16-pa<<2)>>2]|0)+(c[p+(pa+16<<2)>>2]|0)>>14;qa=pa+1|0;if((qa|0)<17){pa=qa}else{ua=17;break}}do{c[q+(ua<<2)>>2]=(c[p+(ua+16<<2)>>2]|0)-(c[p+(80-ua<<2)>>2]|0)>>14;ua=ua+1|0;}while((ua|0)<32);pa=c[C>>2]|0;qa=(c[D>>2]|0)+pa|0;ra=c[E>>2]|0;sa=c[F>>2]|0;ta=sa+ra|0;va=c[H>>2]|0;c[F>>2]=va+sa;sa=c[I>>2]|0;wa=sa+va|0;va=c[J>>2]|0;xa=va+sa|0;sa=c[K>>2]|0;ya=sa+va|0;va=c[L>>2]|0;c[K>>2]=va+sa;sa=c[M>>2]|0;za=sa+va|0;va=c[N>>2]|0;Aa=va+sa|0;sa=c[O>>2]|0;Ba=sa+va|0;va=c[P>>2]|0;c[O>>2]=va+sa;sa=c[Q>>2]|0;Ca=sa+va|0;va=c[R>>2]|0;Da=va+sa|0;c[Q>>2]=Da;sa=(c[S>>2]|0)+va|0;va=c[U>>2]|0;Ea=(c[T>>2]|0)+va|0;Fa=c[V>>2]|0;c[U>>2]=Fa+va;va=c[W>>2]|0;Ga=va+Fa|0;Fa=ya+wa|0;Ha=c[X>>2]|0;c[W>>2]=Ha+va;va=c[Y>>2]|0;Ia=va+Ha|0;Ha=Ba+za|0;Ja=c[Z>>2]|0;c[Y>>2]=Ja+va;va=(c[_>>2]|0)+Ja|0;Ja=sa+Ca|0;c[P>>2]=Ja;Ka=c[ba>>2]|0;La=(c[$>>2]|0)+Ka|0;c[T>>2]=Ea+Ga;Ea=c[da>>2]|0;c[ba>>2]=Ea+Ka;c[I>>2]=Aa+xa;c[H>>2]=Ha+Fa;Ka=Ea+(c[aa>>2]|0)|0;c[X>>2]=va+Ia;c[R>>2]=-sa;c[Z>>2]=-va;c[N>>2]=-(Ba+Ca|0);c[da>>2]=-Ka;c[M>>2]=-(Aa+Da|0);c[L>>2]=-(Ha+Ja|0);c[J>>2]=-(za+ya|0);c[V>>2]=-(Ga+Ia|0);c[E>>2]=-(wa+ta|0);c[$>>2]=-La;c[C>>2]=-(ra+pa+xa|0);c[D>>2]=-(qa+ta+Fa|0);Fa=B;while(1){ta=Fa+64|0;qa=c[ta>>2]|0;xa=Erc(qa,(qa|0)<0|0?-1:0,23170,0)|0;qa=xa>>>15|G<<17;xa=c[Fa>>2]|0;pa=xa-qa|0;ra=qa+xa|0;xa=Fa+96|0;qa=Fa+32|0;La=c[qa>>2]|0;wa=-((c[xa>>2]|0)+La|0)|0;Ia=Erc(wa,(wa|0)<0|0?-1:0,23170,0)|0;wa=Ia>>>15|G<<17;Ia=La-wa|0;Ga=Erc(Ia,(Ia|0)<0|0?-1:0,17733,0)|0;Ia=Ga>>>15|G<<17;Ga=wa+La|0;La=Erc(Ga,(Ga|0)<0|0?-1:0,42813,0)|0;Ga=La>>>15|G<<17;c[Fa>>2]=Ia+ra;c[qa>>2]=pa-Ga;c[ta>>2]=Ga+pa;c[xa>>2]=ra-Ia;Ia=Fa+4|0;if((Ia|0)==(ea|0)){Ma=B;break}else{Fa=Ia}}while(1){Fa=Ma+112|0;Ia=c[Fa>>2]|0;ra=Erc(Ia,(Ia|0)<0|0?-1:0,16704,0)|0;Ia=ra>>>15|G<<17;ra=c[Ma>>2]|0;c[Fa>>2]=ra-Ia;c[Ma>>2]=Ia+ra;ra=Ma+16|0;Ia=c[ra>>2]|0;Fa=Erc(Ia,(Ia|0)<0|0?-1:0,83981,0)|0;Ia=Fa>>>15|G<<17;Fa=Ma+96|0;xa=c[Fa>>2]|0;c[ra>>2]=xa-Ia;c[Fa>>2]=Ia+xa;xa=Ma+80|0;Ia=c[xa>>2]|0;Fa=Erc(Ia,(Ia|0)<0|0?-1:0,29490,0)|0;Ia=Fa>>>15|G<<17;Fa=Ma+32|0;ra=c[Fa>>2]|0;c[xa>>2]=ra-Ia;c[Fa>>2]=Ia+ra;ra=Ma+48|0;Ia=c[ra>>2]|0;Fa=Erc(Ia,(Ia|0)<0|0?-1:0,19704,0)|0;Ia=Fa>>>15|G<<17;Fa=Ma+64|0;xa=c[Fa>>2]|0;c[ra>>2]=xa-Ia;c[Fa>>2]=Ia+xa;xa=Ma+4|0;if((xa|0)==(aa|0)){Na=1635888;Oa=0;break}else{Ma=xa}}while(1){xa=Oa<<2;Ia=q+(30-xa<<2)|0;Fa=c[Ia>>2]|0;ra=c[Na>>2]|0;pa=Erc(ra,(ra|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=pa>>>15|G<<17;pa=q+(xa<<2)|0;c[Ia>>2]=(c[pa>>2]|0)-Fa;c[pa>>2]=Fa+(c[pa>>2]|0);pa=q+((xa|2)<<2)|0;Fa=c[pa>>2]|0;Ia=Na+4|0;ra=c[Ia>>2]|0;Ga=Erc(ra,(ra|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=Ga>>>15|G<<17;Ga=q+(28-xa<<2)|0;c[pa>>2]=(c[Ga>>2]|0)-Fa;c[Ga>>2]=Fa+(c[Ga>>2]|0);Ga=q+(31-xa<<2)|0;Fa=c[Ga>>2]|0;pa=c[Na>>2]|0;ra=Erc(pa,(pa|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=ra>>>15|G<<17;ra=q+((xa|1)<<2)|0;c[Ga>>2]=(c[ra>>2]|0)-Fa;c[ra>>2]=Fa+(c[ra>>2]|0);ra=q+((xa|3)<<2)|0;Fa=c[ra>>2]|0;Ga=c[Ia>>2]|0;Ia=Erc(Ga,(Ga|0)<0|0?-1:0,Fa,(Fa|0)<0|0?-1:0)|0;Fa=Ia>>>15|G<<17;Ia=q+(29-xa<<2)|0;c[ra>>2]=(c[Ia>>2]|0)-Fa;c[Ia>>2]=Fa+(c[Ia>>2]|0);Ia=Oa+1|0;if((Ia|0)<4){Na=Na+8|0;Oa=Ia}else{Pa=T;Qa=S;Ra=1635920;break}}while(1){Ia=c[Qa>>2]|0;Fa=c[Ra>>2]|0;ra=Erc(Fa,(Fa|0)<0|0?-1:0,Ia,(Ia|0)<0|0?-1:0)|0;Ia=ra>>>15|G<<17;c[Qa>>2]=(c[Pa>>2]|0)-Ia;c[Pa>>2]=Ia+(c[Pa>>2]|0);Ia=Pa-8|0;if(Ia>>>0<B>>>0){Sa=0;break}else{Pa=Ia;Qa=Qa+8|0;Ra=Ra+4|0}}do{c[oa+(Sa<<2)>>2]=c[q+(c[1906288+(Sa<<2)>>2]<<2)>>2];Sa=Sa+1|0;}while((Sa|0)<32);Ia=ma-32|0;if((Ia|0)<0){nrc(ia|0,ja|0,960)|0;Ta=3584}else{Ta=Ia}Ia=na+1|0;if((Ia|0)<36){la=la+(ka<<1)|0;ma=Ta;na=Ia;oa=oa+128|0}else{break}}c[ha>>2]=Ta;fa=fa+1|0;ga=c[w>>2]|0;}while((fa|0)<(ga|0));if((ga|0)<=0){Ua=ga;Va=23;break}fa=t+25856|0;B=t+16448|0;S=t+25920|0;T=t+25664|0;aa=0;ea=ga;while(1){D=c[S>>2]|0;if((D|0)>0){C=0;$=T+(aa*96|0)|0;while(1){E=C+32|0;V=C+64|0;J=C+96|0;L=C+128|0;M=C+160|0;da=C+192|0;N=C+224|0;Z=C+256|0;R=C+288|0;X=C+320|0;H=C+352|0;I=0;do{ba=c[B+(aa*4608|0)+(I*1536|0)+(C<<2)>>2]|0;P=(ba|0)>-1?ba:-ba|0;ba=c[B+(aa*4608|0)+(I*1536|0)+(E<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(V<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(J<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(L<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(M<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(da<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(N<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(Z<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(R<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;P=c[B+(aa*4608|0)+(I*1536|0)+(X<<2)>>2]|0;_=(P|0)>-1?P:-P|0;P=(_|0)>(ba|0)?_:ba;ba=c[B+(aa*4608|0)+(I*1536|0)+(H<<2)>>2]|0;_=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(P|0)?_:P;do{if((ba|0)>1){P=ba>>>0>65535>>>0;_=P?ba>>>16:ba;Y=P?16:0;if((_&65280|0)==0){Wa=Y;Xa=_}else{Wa=Y|8;Xa=_>>>8}_=((21-Wa-(d[1359664+Xa|0]|0)|0)*3|0)-3|0;if((_|0)>-1){Ya=_}else{Za=0;break}while(1){_=Ya+1|0;if((ba|0)>(c[u+26952+(_<<2)>>2]|0)){break}else{Ya=_}}Za=Ya&255}else{Za=62}}while(0);a[$+I|0]=Za;I=I+1|0;}while((I|0)<3);I=a[$]|0;H=$+1|0;X=a[H]|0;R=X&255;Z=$+2|0;N=a[Z]|0;switch((d[R+64-(N&255)+(u+27208)|0]|0)+((d[(I&255)+64-R+(u+27208)|0]|0)*5|0)|0){case 17:case 16:case 15:{a[Z]=X;a[$]=X;_a=2;break};case 3:case 23:{a[H]=N;_a=3;break};case 5:case 9:case 14:{a[H]=I;_a=1;break};case 18:case 13:{a[H]=N;a[$]=N;_a=2;break};case 6:case 7:case 10:case 11:case 12:{a[Z]=I;a[H]=I;_a=2;break};case 8:{if((I&255)>>>0>(N&255)>>>0){a[$]=N;$a=N}else{$a=I}a[Z]=$a;a[H]=$a;_a=2;break};case 1:case 2:case 21:case 22:{a[Z]=X;_a=3;break};default:{_a=0}}a[fa+(aa<<5)+C|0]=_a;X=C+1|0;if((X|0)<(D|0)){C=X;$=$+3|0}else{break}}ab=c[w>>2]|0}else{ab=ea}$=aa+1|0;if(($|0)<(ab|0)){aa=$;ea=ab}else{break}}ea=(ab|0)>0;if(!ea){bb=ab;cb=0;break}aa=c[t+25920>>2]|0;if((aa|0)>0){db=0}else{bb=ab;cb=1;break}while(1){fa=0;do{b[r+(db<<6)+(fa<<1)>>1]=~~(+g[1215096+(fa<<2)>>2]*10.0);fa=fa+1|0;}while((fa|0)<(aa|0));fa=db+1|0;if((fa|0)<(ab|0)){db=fa}else{bb=ab;cb=ea;break}}}else{Ua=x;Va=23}}while(0);if((Va|0)==23){bb=Ua;cb=(Ua|0)>0}nrc(m|0,r|0,bb<<6)|0;Ua=bb<<5;mrc(n|0,0,Ua|0)|0;mrc(s|0,0,Ua|0)|0;Ua=c[t+40>>2]|0;Va=t+44|0;x=(c[Va>>2]|0)+(c[t+48>>2]|0)|0;c[Va>>2]=x;if((x|0)>65535){c[Va>>2]=x-65536;c[t+52>>2]=1;eb=Ua+8|0}else{c[t+52>>2]=0;eb=Ua}Ua=t+25924|0;x=t+25920|0;Va=c[x>>2]|0;ab=(Va|0)>0;if(ab){db=0;_a=32;$a=c[Ua>>2]|0;while(1){Za=d[$a]|0;Ya=(ca(Za,bb)|0)+_a|0;Xa=db+1|0;if((Xa|0)<(Va|0)){db=Xa;_a=Ya;$a=$a+(1<<Za)|0}else{fb=Ya;break}}}else{fb=32}a:do{if(cb){$a=fb;while(1){while(1){if(ab){gb=0;hb=-2147483648;ib=-1;jb=-1}else{kb=$a;break a}while(1){_a=0;db=hb;Ya=ib;Za=jb;while(1){Xa=b[m+(gb<<6)+(_a<<1)>>1]|0;if((Xa|0)>(db|0)){Wa=(a[n+(gb<<5)+_a|0]|0)==2;lb=Wa?Za:_a;mb=Wa?Ya:gb;nb=Wa?db:Xa}else{lb=Za;mb=Ya;nb=db}Xa=_a+1|0;if((Xa|0)<(Va|0)){_a=Xa;db=nb;Ya=mb;Za=lb}else{break}}Za=gb+1|0;if((Za|0)<(bb|0)){gb=Za;hb=nb;ib=mb;jb=lb}else{break}}if((lb|0)<0){kb=$a;break a}Za=c[Ua>>2]|0;if((lb|0)>0){Ya=0;db=Za;while(1){_a=db+(1<<d[db])|0;Xa=Ya+1|0;if((Xa|0)<(lb|0)){Ya=Xa;db=_a}else{ob=_a;break}}}else{ob=Za}pb=n+(mb<<5)+lb|0;if((a[pb]|0)==0){qb=((d[785864+(d[u+25856+(mb<<5)+lb|0]|0)|0]|0)*6|0)+2+(e[u+27592+(d[ob+1|0]<<1)>>1]|0)|0}else{db=d[s+(mb<<5)+lb|0]|0;qb=(e[u+27592+(d[ob+(db+1)|0]<<1)>>1]|0)-(e[u+27592+(d[ob+db|0]<<1)>>1]|0)|0}rb=qb+$a|0;if((rb|0)<=(eb|0)){break}a[pb]=2}db=s+(mb<<5)+lb|0;Ya=(a[db]|0)+1&255;a[db]=Ya;db=Ya&255;b[m+(mb<<6)+(lb<<1)>>1]=(b[r+(mb<<6)+(lb<<1)>>1]|0)-(b[687752+(d[ob+db|0]<<1)>>1]|0);a[pb]=(db|0)==((1<<d[ob])-1|0)?2:1;$a=rb}}else{kb=fb}}while(0);fb=eb-kb|0;if(!((fb|0)>-1)){KIb(0,0,2296384,(kb=i,i=i+24|0,c[kb>>2]=2245344,c[kb+8>>2]=2203880,c[kb+16>>2]=593,kb)|0);i=kb;Hd();return 0}kb=d5a(f,h,1792,0)|0;if((kb|0)<0){sb=kb;i=l;return sb|0}kb=h+28|0;eb=c[kb>>2]|0;rb=(eb|0)<0;ob=rb?0:c[h+24>>2]|0;pb=rb?0:eb;c[t+20>>2]=pb<<3;eb=t+8|0;c[eb>>2]=ob;c[t+16>>2]=ob+pb;pb=t+12|0;c[pb>>2]=ob;rb=t+4|0;lb=t;mb=ob;y=je(((c[w>>2]|0)==2?0:192)|(c[t+52>>2]|(c[t+36>>2]|(c[t+32>>2]|(1-(c[t+28>>2]|0)<<7|1048400))<<2)<<1)<<9|4|0)|0;a[mb]=y;y=y>>8;a[mb+1|0]=y;y=y>>8;a[mb+2|0]=y;y=y>>8;a[mb+3|0]=y;mb=(c[pb>>2]|0)+4|0;c[pb>>2]=mb;c[lb>>2]=0;c[rb>>2]=32;t=c[x>>2]|0;do{if((t|0)>0){ob=0;r=0;m=c[w>>2]|0;qb=0;n=32;jb=t;ib=mb;while(1){nb=d[(c[Ua>>2]|0)+ob|0]|0;if((m|0)>0){hb=32-nb|0;gb=0;bb=qb;Va=n;ab=m;cb=ib;while(1){$a=d[s+(gb<<5)+r|0]|0;if((Va|0)>(nb|0)){tb=Va-nb|0;ub=$a|bb<<nb;vb=ab;wb=cb}else{db=cb;y=je($a>>>((nb-Va|0)>>>0)|bb<<Va|0)|0;a[db]=y;y=y>>8;a[db+1|0]=y;y=y>>8;a[db+2|0]=y;y=y>>8;a[db+3|0]=y;db=(c[pb>>2]|0)+4|0;c[pb>>2]=db;tb=hb+Va|0;ub=$a;vb=c[w>>2]|0;wb=db}c[lb>>2]=ub;c[rb>>2]=tb;db=gb+1|0;if((db|0)<(vb|0)){gb=db;bb=ub;Va=tb;ab=vb;cb=wb}else{break}}xb=vb;yb=ub;zb=tb;Ab=c[x>>2]|0;Bb=wb}else{xb=m;yb=qb;zb=n;Ab=jb;Bb=ib}cb=r+1|0;if((cb|0)>=(Ab|0)){break}ob=(1<<nb)+ob|0;r=cb;m=xb;qb=yb;n=zb;jb=Ab;ib=Bb}if((Ab|0)>0){Cb=0;Db=xb;Eb=yb;Fb=zb;Gb=Ab;Hb=Bb}else{Ib=0;Jb=Ab;Kb=yb;Lb=zb;Mb=Bb;break}while(1){if((Db|0)>0){ib=0;jb=Db;n=Eb;qb=Fb;m=Hb;while(1){if((a[s+(ib<<5)+Cb|0]|0)==0){Nb=jb;Ob=n;Pb=qb;Qb=m}else{r=d[u+25856+(ib<<5)+Cb|0]|0;if((qb|0)>2){Rb=qb-2|0;Sb=r|n<<2;Tb=jb;Ub=m}else{ob=m;y=je(r>>>((2-qb|0)>>>0)|n<<qb|0)|0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;Rb=qb+30|0;Sb=r;Tb=c[w>>2]|0;Ub=ob}c[lb>>2]=Sb;c[rb>>2]=Rb;Nb=Tb;Ob=Sb;Pb=Rb;Qb=Ub}ob=ib+1|0;if((ob|0)<(Nb|0)){ib=ob;jb=Nb;n=Ob;qb=Pb;m=Qb}else{break}}Vb=Nb;Wb=Ob;Xb=Pb;Yb=c[x>>2]|0;Zb=Qb}else{Vb=Db;Wb=Eb;Xb=Fb;Yb=Gb;Zb=Hb}m=Cb+1|0;if((m|0)<(Yb|0)){Cb=m;Db=Vb;Eb=Wb;Fb=Xb;Gb=Yb;Hb=Zb}else{break}}if((Yb|0)>0){_b=0;$b=Vb;ac=Wb;bc=Xb;cc=Yb;dc=Zb}else{Ib=0;Jb=Yb;Kb=Wb;Lb=Xb;Mb=Zb;break}while(1){if(($b|0)>0){m=0;qb=ac;n=bc;jb=dc;while(1){do{if((a[s+(m<<5)+_b|0]|0)==0){ec=qb;fc=n;gc=jb}else{ib=u+25664+(m*96|0)+(_b*3|0)|0;nb=d[u+25856+(m<<5)+_b|0]|0;if((nb|0)==3|(nb|0)==1){ob=d[ib]|0;if((n|0)>6){hc=n-6|0;ic=ob|qb<<6;jc=jb}else{r=jb;y=je(ob>>>((6-n|0)>>>0)|qb<<n|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;hc=n+26|0;ic=ob;jc=r}c[lb>>2]=ic;c[rb>>2]=hc;r=d[u+25664+(m*96|0)+(_b*3|0)+2|0]|0;if((hc|0)>6){kc=hc-6|0;lc=r|ic<<6;mc=jc}else{ob=jc;y=je(r>>>((6-hc|0)>>>0)|ic<<hc|0)|0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;kc=hc+26|0;lc=r;mc=ob}c[lb>>2]=lc;c[rb>>2]=kc;ec=lc;fc=kc;gc=mc;break}else if((nb|0)==0){ob=d[ib]|0;if((n|0)>6){nc=n-6|0;oc=ob|qb<<6;pc=jb}else{r=jb;y=je(ob>>>((6-n|0)>>>0)|qb<<n|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;nc=n+26|0;oc=ob;pc=r}c[lb>>2]=oc;c[rb>>2]=nc;r=d[u+25664+(m*96|0)+(_b*3|0)+1|0]|0;if((nc|0)>6){qc=nc-6|0;rc=r|oc<<6;sc=pc}else{ob=pc;y=je(r>>>((6-nc|0)>>>0)|oc<<nc|0)|0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=(c[pb>>2]|0)+4|0;c[pb>>2]=ob;qc=nc+26|0;rc=r;sc=ob}c[lb>>2]=rc;c[rb>>2]=qc;ob=d[u+25664+(m*96|0)+(_b*3|0)+2|0]|0;if((qc|0)>6){tc=qc-6|0;uc=ob|rc<<6;vc=sc}else{r=sc;y=je(ob>>>((6-qc|0)>>>0)|rc<<qc|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[pb>>2]|0)+4|0;c[pb>>2]=r;tc=qc+26|0;uc=ob;vc=r}c[lb>>2]=uc;c[rb>>2]=tc;ec=uc;fc=tc;gc=vc;break}else if((nb|0)==2){nb=d[ib]|0;if((n|0)>6){wc=n-6|0;xc=nb|qb<<6;yc=jb}else{ib=jb;y=je(nb>>>((6-n|0)>>>0)|qb<<n|0)|0;a[ib]=y;y=y>>8;a[ib+1|0]=y;y=y>>8;a[ib+2|0]=y;y=y>>8;a[ib+3|0]=y;ib=(c[pb>>2]|0)+4|0;c[pb>>2]=ib;wc=n+26|0;xc=nb;yc=ib}c[lb>>2]=xc;c[rb>>2]=wc;ec=xc;fc=wc;gc=yc;break}else{ec=qb;fc=n;gc=jb;break}}}while(0);Za=m+1|0;zc=c[w>>2]|0;if((Za|0)<(zc|0)){m=Za;qb=ec;n=fc;jb=gc}else{break}}Ac=zc;Bc=ec;Cc=fc;Dc=c[x>>2]|0;Ec=gc}else{Ac=$b;Bc=ac;Cc=bc;Dc=cc;Ec=dc}jb=_b+1|0;if((jb|0)<(Dc|0)){_b=jb;$b=Ac;ac=Bc;bc=Cc;cc=Dc;dc=Ec}else{Ib=0;Jb=Dc;Kb=Bc;Lb=Cc;Mb=Ec;break}}}else{Ib=0;Jb=t;Kb=0;Lb=32;Mb=mb}}while(0);while(1){mb=0;t=Jb;Ec=Kb;Cc=Lb;Bc=Mb;while(1){b:do{if((t|0)>0){Dc=mb+1|0;dc=mb+2|0;cc=0;bc=0;ac=c[w>>2]|0;Ac=Ec;$b=Cc;_b=t;gc=Bc;while(1){fc=d[(c[Ua>>2]|0)+cc|0]|0;if((ac|0)>0){ec=0;zc=Ac;yc=$b;wc=gc;while(1){xc=a[s+(ec<<5)+bc|0]|0;do{if(xc<<24>>24==0){Fc=zc;Gc=yc;Hc=wc}else{vc=d[(c[Ua>>2]|0)+((xc&255)+cc)|0]|0;tc=c[1348400+(vc<<2)>>2]|0;Ic=+g[u+27336+(d[u+25664+(ec*96|0)+(bc*3|0)+Ib|0]<<2)>>2];Jc=+(tc|0);uc=tc-1|0;qc=~~(Jc*(Ic*+(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(mb<<7)+(bc<<2)>>2]|0)+1.0)*.5);rc=(qc|0)<(tc|0)?qc:uc;qc=~~(Jc*(Ic*+(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(Dc<<7)+(bc<<2)>>2]|0)+1.0)*.5);sc=(qc|0)<(tc|0)?qc:uc;qc=~~(Jc*(Ic*+(c[u+16448+(ec*4608|0)+(Ib*1536|0)+(dc<<7)+(bc<<2)>>2]|0)+1.0)*.5);nc=(qc|0)<(tc|0)?qc:uc;uc=c[1348472+(vc<<2)>>2]|0;vc=-uc|0;if((uc|0)<0){qc=(ca((ca(nc,tc)|0)+sc|0,tc)|0)+rc|0;if((yc|0)>(vc|0)){Kc=uc+yc|0;Lc=qc|zc<<vc;Mc=wc}else{tc=wc;y=je(qc>>>((vc-yc|0)>>>0)|zc<<yc|0)|0;a[tc]=y;y=y>>8;a[tc+1|0]=y;y=y>>8;a[tc+2|0]=y;y=y>>8;a[tc+3|0]=y;tc=(c[pb>>2]|0)+4|0;c[pb>>2]=tc;Kc=yc+32+uc|0;Lc=qc;Mc=tc}c[lb>>2]=Lc;c[rb>>2]=Kc;Fc=Lc;Gc=Kc;Hc=Mc;break}if((yc|0)>(uc|0)){Nc=yc;Oc=rc|zc<<uc;Pc=wc}else{tc=wc;y=je(rc>>>((uc-yc|0)>>>0)|zc<<yc|0)|0;a[tc]=y;y=y>>8;a[tc+1|0]=y;y=y>>8;a[tc+2|0]=y;y=y>>8;a[tc+3|0]=y;tc=(c[pb>>2]|0)+4|0;c[pb>>2]=tc;Nc=yc+32|0;Oc=rc;Pc=tc}tc=Nc-uc|0;c[lb>>2]=Oc;c[rb>>2]=tc;if((tc|0)>(uc|0)){Qc=tc-uc|0;Rc=Oc<<uc|sc;Sc=Pc}else{rc=Pc;y=je(sc>>>((uc-tc|0)>>>0)|Oc<<tc|0)|0;a[rc]=y;y=y>>8;a[rc+1|0]=y;y=y>>8;a[rc+2|0]=y;y=y>>8;a[rc+3|0]=y;rc=(c[pb>>2]|0)+4|0;c[pb>>2]=rc;Qc=32-uc+tc|0;Rc=sc;Sc=rc}c[lb>>2]=Rc;c[rb>>2]=Qc;if((Qc|0)>(uc|0)){Tc=Qc-uc|0;Uc=Rc<<uc|nc;Vc=Sc}else{rc=Sc;y=je(nc>>>((uc-Qc|0)>>>0)|Rc<<Qc|0)|0;a[rc]=y;y=y>>8;a[rc+1|0]=y;y=y>>8;a[rc+2|0]=y;y=y>>8;a[rc+3|0]=y;rc=(c[pb>>2]|0)+4|0;c[pb>>2]=rc;Tc=32-uc+Qc|0;Uc=nc;Vc=rc}c[lb>>2]=Uc;c[rb>>2]=Tc;Fc=Uc;Gc=Tc;Hc=Vc}}while(0);xc=ec+1|0;Wc=c[w>>2]|0;if((xc|0)<(Wc|0)){ec=xc;zc=Fc;yc=Gc;wc=Hc}else{break}}Xc=Wc;Yc=Fc;Zc=Gc;_c=c[x>>2]|0;$c=Hc}else{Xc=ac;Yc=Ac;Zc=$b;_c=_b;$c=gc}wc=bc+1|0;if((wc|0)>=(_c|0)){ad=_c;bd=Yc;cd=Zc;dd=$c;break b}cc=(1<<fc)+cc|0;bc=wc;ac=Xc;Ac=Yc;$b=Zc;_b=_c;gc=$c}}else{ad=t;bd=Ec;cd=Cc;dd=Bc}}while(0);gc=mb+3|0;if((gc|0)<12){mb=gc;t=ad;Ec=bd;Cc=cd;Bc=dd}else{break}}Bc=Ib+1|0;if((Bc|0)<3){Ib=Bc;Jb=ad;Kb=bd;Lb=cd;Mb=dd}else{break}}if((fb|0)>0){Mb=0;Lb=bd;Kb=cd;ad=dd;while(1){if((Kb|0)>1){ed=Kb-1|0;fd=Lb<<1;gd=ad}else{Jb=ad;y=je(Lb<<Kb|0)|0;a[Jb]=y;y=y>>8;a[Jb+1|0]=y;y=y>>8;a[Jb+2|0]=y;y=y>>8;a[Jb+3|0]=y;Jb=(c[pb>>2]|0)+4|0;c[pb>>2]=Jb;ed=Kb+31|0;fd=0;gd=Jb}c[lb>>2]=fd;c[rb>>2]=ed;Jb=Mb+1|0;if((Jb|0)<(fb|0)){Mb=Jb;Lb=fd;Kb=ed;ad=gd}else{hd=ed;id=fd;jd=gd;break}}}else{hd=cd;id=bd;jd=dd}c:do{if((hd|0)<32){dd=id<<hd;c[lb>>2]=dd;bd=dd>>>24&255;dd=jd;while(1){c[pb>>2]=dd+1;a[dd]=bd;cd=c[lb>>2]|0;c[lb>>2]=cd<<8;gd=(c[rb>>2]|0)+8|0;c[rb>>2]=gd;if((gd|0)>=32){break c}bd=cd>>>16&255;dd=c[pb>>2]|0}}}while(0);c[rb>>2]=32;c[lb>>2]=0;lb=j+136|0;j=c[lb>>2]|0;jd=c[lb+4>>2]|0;if((j|0)==0&(jd|0)==(-2147483648|0)){kd=32}else{lb=c[f+116>>2]|0;c[o>>2]=1;c[o+4>>2]=c[f+412>>2];hd=XIb(lb,(lb|0)<0|0?-1:0,o,f+104|0)|0;f=xrc(j,jd,hd,G)|0;hd=h+8|0;c[hd>>2]=f;c[hd+4>>2]=G;kd=c[rb>>2]|0}c[kb>>2]=(32-kd+((c[pb>>2]|0)-(c[eb>>2]|0)<<3)|0)/8|0;c[k>>2]=1;sb=0;i=l;return sb|0}function cTa(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+4|0;l8(a+10056|0,c[b>>2]|0);Mia(a+11300|0,8);YJa(a+11332|0,c[(c[b>>2]|0)+88>>2]|0);G8a(a+11540|0,c[(c[b>>2]|0)+796>>2]|0);c[a+14368>>2]=758;c[a+14372>>2]=148;c[a+14352>>2]=184;c[a+14356>>2]=596;b=a+14360|0;c[b>>2]=74;if((c[a+60>>2]&8388608|0)!=0){c[b>>2]=860}c[a+14364>>2]=812;b=a+11184|0;d=a+232|0;if((c[a+14200>>2]|0)==0){L6(b,d,1242080);L6(b,a+364|0,1242080);e=a+496|0;L6(b,e,1433288);f=a+628|0;L6(b,f,1433224);return 0}else{L6(b,d,1433224);L6(b,a+364|0,1433224);e=a+496|0;L6(b,e,1433288);f=a+628|0;L6(b,f,1433224);return 0}return 0}function dTa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=g<<1;if((c[d+228>>2]|0)==0){b[e>>1]=ca(b[e>>1]|0,c[((f|0)<4?d+168|0:d+172|0)>>2]|0)|0;i=g-1|1}else{i=0}do{if((c[d+176>>2]|0)==0){g=a[(c[d+180+(f<<2)>>2]|0)+(d+300)|0]|0;if(!(g<<24>>24==0)){j=g&255;break}return}else{j=63}}while(0);d=-i|0;f=1;do{g=e+(f<<1)|0;k=b[g>>1]|0;if(!(k<<16>>16==0)){l=ca(h,k<<16>>16)|0;b[g>>1]=l+(k<<16>>16<0?d:i)}f=f+1|0;}while((f|0)<=(j|0));return}function eTa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=g-1|1;i=g<<1;g=d[(c[a+180+(f<<2)>>2]|0)+(a+300)|0]|0;a=-h|0;f=0;do{j=e+(f<<1)|0;k=b[j>>1]|0;if(!(k<<16>>16==0)){l=ca(i,k<<16>>16)|0;b[j>>1]=l+(k<<16>>16<0?a:h)}f=f+1|0;}while((f|0)<=(g|0));return}function fTa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=c[a+180+(g<<2)>>2]|0;b[f>>1]=ca(b[f>>1]|0,c[((g|0)<4?a+168|0:a+172|0)>>2]|0)|0;if((i|0)<1){return}g=-h|0;j=1;do{k=d[a+368+j|0]|0;l=f+(k<<1)|0;m=b[l>>1]|0;n=m<<16>>16;if(!(m<<16>>16==0)){if(m<<16>>16<0){o=-(((ca(ca(n,g)|0,e[a+12560+(k<<1)>>1]|0)|0)>>>3)+65535|1)&65535}else{m=ca(n,h)|0;o=(((ca(m,e[a+12560+(k<<1)>>1]|0)|0)>>>3)+65535|1)&65535}b[l>>1]=o}j=j+1|0;}while((j|0)<=(i|0));return}function gTa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c[a+180+(g<<2)>>2]|0;if((i|0)<0){return}else{j=0}do{g=d[a+368+j|0]|0;k=f+(g<<1)|0;l=b[k>>1]|0;m=l<<16>>16;if(!(l<<16>>16==0)){if(l<<16>>16<0){l=ca(-m<<1|1,h)|0;n=-(((ca(l,e[a+12816+(g<<1)>>1]|0)|0)>>>4)+65535|1)&65535}else{l=ca(m<<1|1,h)|0;n=(((ca(l,e[a+12816+(g<<1)>>1]|0)|0)>>>4)+65535|1)&65535}b[k>>1]=n}j=j+1|0;}while((j|0)<=(i|0));return}function hTa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[a+14200>>2]|0)==0){i=c[a+180+(g<<2)>>2]|0}else{i=63}b[f>>1]=ca(b[f>>1]|0,c[((g|0)<4?a+168|0:a+172|0)>>2]|0)|0;if((i|0)<1){return}g=-h|0;j=1;do{k=d[a+368+j|0]|0;l=f+(k<<1)|0;m=b[l>>1]|0;n=m<<16>>16;if(!(m<<16>>16==0)){if(m<<16>>16<0){o=-((ca(ca(n,g)|0,e[a+12560+(k<<1)>>1]|0)|0)>>>3)&65535}else{m=ca(n,h)|0;o=(ca(m,e[a+12560+(k<<1)>>1]|0)|0)>>>3&65535}b[l>>1]=o}j=j+1|0;}while((j|0)<=(i|0));return}function iTa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((c[a+14200>>2]|0)==0){i=c[a+180+(g<<2)>>2]|0}else{i=63}j=(ca(b[f>>1]|0,c[((g|0)<4?a+168|0:a+172|0)>>2]|0)|0)&65535;b[f>>1]=j;g=(j<<16>>16)-1|0;if((i|0)<1){k=g;l=k&1;m=f+126|0;n=b[m>>1]|0;o=n&65535;p=o^l;q=p&65535;b[m>>1]=q;return}j=-h|0;r=g;g=1;while(1){s=d[a+368+g|0]|0;t=f+(s<<1)|0;u=b[t>>1]|0;v=u<<16>>16;if(u<<16>>16==0){w=r}else{if(u<<16>>16<0){x=-((ca(ca(v,j)|0,e[a+12560+(s<<1)>>1]|0)|0)>>3)|0}else{u=ca(v,h)|0;x=(ca(u,e[a+12560+(s<<1)>>1]|0)|0)>>3}b[t>>1]=x;w=x+r|0}t=g+1|0;if((t|0)>(i|0)){k=w;break}else{r=w;g=t}}l=k&1;m=f+126|0;n=b[m>>1]|0;o=n&65535;p=o^l;q=p&65535;b[m>>1]=q;return}function jTa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;do{if((c[a+14200>>2]|0)==0){i=c[a+180+(g<<2)>>2]|0;if((i|0)<0){j=-1}else{k=i;break}l=j&1;m=f+126|0;n=b[m>>1]|0;o=n&65535;p=o^l;q=p&65535;b[m>>1]=q;return}else{k=63}}while(0);g=-1;i=0;while(1){r=d[a+368+i|0]|0;s=f+(r<<1)|0;t=b[s>>1]|0;u=t<<16>>16;if(t<<16>>16==0){v=g}else{if(t<<16>>16<0){t=ca(-u<<1|1,h)|0;w=-((ca(t,e[a+12816+(r<<1)>>1]|0)|0)>>4)|0}else{t=ca(u<<1|1,h)|0;w=(ca(t,e[a+12816+(r<<1)>>1]|0)|0)>>4}b[s>>1]=w;v=w+g|0}s=i+1|0;if((s|0)>(k|0)){j=v;break}else{g=v;i=s}}l=j&1;m=f+126|0;n=b[m>>1]|0;o=n&65535;p=o^l;q=p&65535;b[m>>1]=q;return}function kTa(a){a=a|0;c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(a+1564|0);fGb(a+1572|0);fGb(a+1588|0);fGb(a+1540|0);fGb(a+1508|0);fGb(a+1532|0);fGb(a+1516|0);fGb(a+1548|0);fGb(a+1520|0);fGb(a+1552|0);return}function lTa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=b+1508|0;do{if((c[f>>2]|0)!=0){g=b+1580|0;h=b+1584|0;if((c[g>>2]|0)==(c[a+116>>2]|0)){if((c[h>>2]|0)==(c[a+120>>2]|0)){break}}c[h>>2]=0;c[g>>2]=0;fGb(b+1564|0);fGb(b+1572|0);fGb(b+1588|0);fGb(b+1540|0);fGb(f);fGb(b+1532|0);fGb(b+1516|0);fGb(b+1548|0);fGb(b+1520|0);fGb(b+1552|0)}}while(0);a:do{if((d|0)==0){g=b+360|0;if((c[g>>2]|0)!=0){KIb(0,0,2502120,(j=i,i=i+24|0,c[j>>2]=2360384,c[j+8>>2]=2449704,c[j+16>>2]=599,j)|0);i=j;Hd();return 0}h=a+4|0;k=D4a(c[(c[h>>2]|0)+12>>2]|0)|0;l=b|0;m=b+1496|0;c[m>>2]=l;n=c[a+48>>2]|0;if((n|0)==152|(n|0)==153|(n|0)==168){n=c[h>>2]|0;c[b+68>>2]=c[n+120>>2];c[b+72>>2]=c[n+124>>2];c[b+80>>2]=c[n+140>>2];o=K4a(n,l,0)|0}else{l=c[h>>2]|0;if((k|0)!=0){c[b+68>>2]=(c[l+120>>2]|0)+32;c[b+72>>2]=(c[l+124>>2]|0)+32}o=J5a(l,m,(c[b+2192>>2]|0)!=0|0)|0}do{if((o|0)>=0){if((c[g>>2]|0)==0){break}if((k|0)==0){p=c[h>>2]|0}else{m=b|0;l=c[m>>2]|0;if((l|0)!=0){n=a+14220|0;q=a+14216|0;r=b+32|0;s=0;t=m;m=l;do{if((s|0)==0){u=0;v=c[r>>2]<<4}else{l=ca(16>>>((c[n>>2]|0)>>>0),c[b+32+(s<<2)>>2]|0)|0;u=c[q>>2]|0;v=l}c[t>>2]=m+((16>>>(u>>>0))+v);s=s+1|0;t=b+(s<<2)|0;m=c[t>>2]|0;}while((m|0)!=0)}m=c[h>>2]|0;c[b+68>>2]=c[m+120>>2];c[b+72>>2]=c[m+124>>2];p=m}m=c[p+712>>2]|0;do{if((m|0)!=0){t=c[m+36>>2]|0;if((t|0)==0){break}s=dGb(t)|0;c[b+1596>>2]=s;if((s|0)!=0){c[b+1600>>2]=c[s+4>>2];break}KIb(c[h>>2]|0,16,2251512,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;w=-1;i=e;return w|0}}while(0);m=a+148|0;s=c[m>>2]|0;do{if((s|0)==0){x=c[b+36>>2]|0}else{if((s|0)==(c[b+32>>2]|0)){t=c[a+152>>2]|0;if((t|0)==(c[b+36>>2]|0)){x=t;break}}KIb(c[h>>2]|0,16,2240976,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;mTa(a,b);w=-1;i=e;return w|0}}while(0);if((x|0)!=(c[b+40>>2]|0)){KIb(c[h>>2]|0,16,2235256,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;mTa(a,b);w=-1;i=e;return w|0}s=b+32|0;do{if((c[a+9944>>2]|0)==0){if((qTa(a,c[s>>2]|0)|0)>=0){break}KIb(c[h>>2]|0,16,2231680,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;mTa(a,b);w=-1;i=e;return w|0}}while(0);c[m>>2]=c[s>>2];c[a+152>>2]=c[b+36>>2];break a}}while(0);k=c[b>>2]|0;KIb(c[h>>2]|0,16,2255768,(j=i,i=i+16|0,c[j>>2]=o,c[j+8>>2]=k,j)|0);i=j;w=-1;i=e;return w|0}else{if((c[b>>2]|0)==0){KIb(0,0,2502120,(j=i,i=i+24|0,c[j>>2]=2600088,c[j+8>>2]=2449704,c[j+16>>2]=596,j)|0);i=j;Hd();return 0}else{c[b+2196>>2]=1;break}}}while(0);b:do{if((c[f>>2]|0)==0){o=a+124|0;x=c[o>>2]|0;p=a+120|0;v=c[p>>2]|0;u=(ca(v+1|0,x)|0)+1|0;d=ca(v,x)|0;x=ca(v<<3,c[a+128>>2]|0)|0;v=b+1540|0;c[v>>2]=dGb(d+2|0)|0;c[f>>2]=dGb(u+(c[o>>2]|0)|0)|0;k=dGb((c[o>>2]|0)+u<<2)|0;c[b+1532>>2]=k;if((c[v>>2]|0)==0){y=81;break}if((c[f>>2]|0)==0|(k|0)==0){y=81;break}k=a+56|0;if((c[k>>2]|0)!=0){v=d<<1;u=b+1564|0;c[u>>2]=dGb(v)|0;o=b+1572|0;c[o>>2]=dGb(v)|0;v=dGb(d)|0;c[b+1588>>2]=v;if((c[u>>2]|0)==0){y=81;break}if((c[o>>2]|0)==0|(v|0)==0){y=81;break}}do{if((c[a+28>>2]|0)==2){y=53}else{if((c[k>>2]|0)!=0){y=53;break}if((c[(c[a+4>>2]|0)+692>>2]|0)!=0){y=53}}}while(0);c:do{if((y|0)==53){k=x+16|0;h=d<<2;if((k|0)==0){break}else{z=0}while(1){if((z|0)>=2){break c}v=b+1516+(z<<2)|0;c[v>>2]=dGb(k)|0;o=dGb(h)|0;c[b+1548+(z<<2)>>2]=o;if((c[v>>2]|0)==0|(o|0)==0){y=81;break b}else{z=z+1|0}}}}while(0);c[b+1580>>2]=c[a+116>>2];c[b+1584>>2]=c[p>>2]}else{d=b+1564|0;if((c[d>>2]|0)!=0){if((iGb(d)|0)<0){y=81;break}}d=b+1572|0;if((c[d>>2]|0)!=0){if((iGb(d)|0)<0){y=81;break}}d=b+1588|0;if((c[d>>2]|0)!=0){if((iGb(d)|0)<0){y=81;break}}d=b+1540|0;if((c[d>>2]|0)!=0){if((iGb(d)|0)<0){y=81;break}}if((c[f>>2]|0)!=0){if((iGb(f)|0)<0){y=81;break}}d=b+1532|0;if((c[d>>2]|0)!=0){if((iGb(d)|0)<0){y=81;break}}d=b+1516|0;if((c[d>>2]|0)!=0){if((iGb(d)|0)<0){y=81;break}}d=b+1548|0;if((c[d>>2]|0)!=0){if((iGb(d)|0)<0){y=81;break}}d=b+1520|0;if((c[d>>2]|0)!=0){if((iGb(d)|0)<0){y=81;break}}d=b+1552|0;if((c[d>>2]|0)==0){break}if((iGb(d)|0)<0){y=81}}}while(0);if((y|0)==81){KIb(c[a+4>>2]|0,16,2296352,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;mTa(a,b);c[b+1584>>2]=0;c[b+1580>>2]=0;fGb(b+1564|0);fGb(b+1572|0);fGb(b+1588|0);fGb(b+1540|0);fGb(f);fGb(b+1532|0);fGb(b+1516|0);fGb(b+1548|0);fGb(b+1520|0);fGb(b+1552|0);w=-12;i=e;return w|0}if((c[a+56>>2]|0)!=0){c[b+1568>>2]=c[(c[b+1564>>2]|0)+4>>2];c[b+1576>>2]=c[(c[b+1572>>2]|0)+4>>2];c[b+1592>>2]=c[(c[b+1588>>2]|0)+4>>2]}c[b+1544>>2]=c[(c[b+1540>>2]|0)+4>>2];j=c[a+124>>2]<<1|1;c[b+1512>>2]=(c[(c[f>>2]|0)+4>>2]|0)+j;c[b+1536>>2]=(c[(c[b+1532>>2]|0)+4>>2]|0)+(j<<2);j=c[b+1516>>2]|0;if((j|0)==0){w=0;i=e;return w|0}c[b+1524>>2]=(c[j+4>>2]|0)+16;c[b+1556>>2]=c[(c[b+1548>>2]|0)+4>>2];c[b+1528>>2]=(c[(c[b+1520>>2]|0)+4>>2]|0)+16;c[b+1560>>2]=c[(c[b+1552>>2]|0)+4>>2];w=0;i=e;return w|0}function mTa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=b|0;e=b+1496|0;c[e>>2]=d;f=c[a+48>>2]|0;if((f|0)==152|(f|0)==153|(f|0)==168){WHb(d)}else{H5a(c[a+4>>2]|0,e)}e=b+1596|0;fGb(e);if((c[b+2188>>2]|0)==0){g=e;mrc(g|0,0,628)|0;return}c[b+1584>>2]=0;c[b+1580>>2]=0;fGb(b+1564|0);fGb(b+1572|0);fGb(b+1588|0);fGb(b+1540|0);fGb(b+1508|0);fGb(b+1532|0);fGb(b+1516|0);fGb(b+1548|0);fGb(b+1520|0);fGb(b+1552|0);g=e;mrc(g|0,0,628)|0;return}function nTa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;if((c[b+360>>2]|0)!=0){KIb(0,0,2502120,(f=i,i=i+24|0,c[f>>2]=2245328,c[f+8>>2]=2449704,c[f+16>>2]=714,f)|0);i=f;Hd();return 0}if((c[d+360>>2]|0)==0){KIb(0,0,2502120,(f=i,i=i+24|0,c[f>>2]=2203864,c[f+8>>2]=2449704,c[f+16>>2]=715,f)|0);i=f;Hd();return 0}f=d+1496|0;c[f>>2]=d;g=b+1496|0;c[g>>2]=b;h=G5a(g,f)|0;do{if((h|0)<0){j=h}else{f=oTa(b,d)|0;if((f|0)<0){j=f;break}if((c[d+1600>>2]|0)!=0){g=eGb(c[d+1596>>2]|0)|0;c[b+1596>>2]=g;if((g|0)==0){j=f;break}c[b+1600>>2]=c[g+4>>2]}c[b+2164>>2]=c[d+2164>>2];g=d+2168|0;f=c[g+4>>2]|0;k=b+2168|0;c[k>>2]=c[g>>2];c[k+4>>2]=f;f=d+2176|0;k=c[f+4>>2]|0;g=b+2176|0;c[g>>2]=c[f>>2];c[g+4>>2]=k;c[b+2184>>2]=c[d+2184>>2];c[b+2188>>2]=c[d+2188>>2];c[b+2192>>2]=c[d+2192>>2];c[b+2196>>2]=c[d+2196>>2];l=0;i=e;return l|0}}while(0);mTa(a,b);l=j;i=e;return l|0}function oTa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b+1564|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1564|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(f);fGb(a+1572|0);fGb(a+1588|0);fGb(a+1540|0);fGb(a+1508|0);fGb(a+1532|0);fGb(a+1516|0);fGb(a+1548|0);fGb(a+1520|0);fGb(a+1552|0);h=-12;return h|0}}while(0);d=b+1572|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1572|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(a+1564|0);fGb(f);fGb(a+1588|0);fGb(a+1540|0);fGb(a+1508|0);fGb(a+1532|0);fGb(a+1516|0);fGb(a+1548|0);fGb(a+1520|0);fGb(a+1552|0);h=-12;return h|0}}while(0);d=b+1588|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1588|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(a+1564|0);fGb(a+1572|0);fGb(f);fGb(a+1540|0);fGb(a+1508|0);fGb(a+1532|0);fGb(a+1516|0);fGb(a+1548|0);fGb(a+1520|0);fGb(a+1552|0);h=-12;return h|0}}while(0);d=b+1540|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1540|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(a+1564|0);fGb(a+1572|0);fGb(a+1588|0);fGb(f);fGb(a+1508|0);fGb(a+1532|0);fGb(a+1516|0);fGb(a+1548|0);fGb(a+1520|0);fGb(a+1552|0);h=-12;return h|0}}while(0);d=b+1508|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1508|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(a+1564|0);fGb(a+1572|0);fGb(a+1588|0);fGb(a+1540|0);fGb(f);fGb(a+1532|0);fGb(a+1516|0);fGb(a+1548|0);fGb(a+1520|0);fGb(a+1552|0);h=-12;return h|0}}while(0);d=b+1532|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1532|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(a+1564|0);fGb(a+1572|0);fGb(a+1588|0);fGb(a+1540|0);fGb(a+1508|0);fGb(f);fGb(a+1516|0);fGb(a+1548|0);fGb(a+1520|0);fGb(a+1552|0);h=-12;return h|0}}while(0);d=b+1516|0;e=c[d>>2]|0;do{if((e|0)==0){i=37}else{f=a+1516|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){i=37;break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){i=37;break}j=f;k=a+1520|0}}while(0);a:do{if((i|0)==37){d=b+1548|0;e=c[d>>2]|0;do{if((e|0)==0){i=43}else{f=a+1548|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){i=43;break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){i=43;break}l=f;m=a+1552|0}}while(0);b:do{if((i|0)==43){d=b+1520|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1520|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}j=a+1516|0;k=f;break a}}while(0);d=b+1552|0;e=c[d>>2]|0;do{if((e|0)!=0){f=a+1552|0;g=c[f>>2]|0;if((g|0)!=0){if((c[g>>2]|0)==(c[e>>2]|0)){break}}fGb(f);g=eGb(c[d>>2]|0)|0;c[f>>2]=g;if((g|0)!=0){break}l=a+1548|0;m=f;break b}}while(0);c[a+1568>>2]=c[b+1568>>2];c[a+1576>>2]=c[b+1576>>2];c[a+1592>>2]=c[b+1592>>2];c[a+1544>>2]=c[b+1544>>2];c[a+1512>>2]=c[b+1512>>2];c[a+1536>>2]=c[b+1536>>2];c[a+1524>>2]=c[b+1524>>2];c[a+1556>>2]=c[b+1556>>2];c[a+1528>>2]=c[b+1528>>2];c[a+1560>>2]=c[b+1560>>2];c[a+1580>>2]=c[b+1580>>2];c[a+1584>>2]=c[b+1584>>2];h=0;return h|0}}while(0);c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(a+1564|0);fGb(a+1572|0);fGb(a+1588|0);fGb(a+1540|0);fGb(a+1508|0);fGb(a+1532|0);fGb(a+1516|0);fGb(l);fGb(a+1520|0);fGb(m);h=-12;return h|0}}while(0);c[a+1584>>2]=0;c[a+1580>>2]=0;fGb(a+1564|0);fGb(a+1572|0);fGb(a+1588|0);fGb(a+1540|0);fGb(a+1508|0);fGb(a+1532|0);fGb(j);fGb(a+1548|0);fGb(k);fGb(a+1552|0);h=-12;return h|0}function pTa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=i;i=i+24|0;e=a+9944|0;f=c[e>>2]|0;g=a+12192|0;h=c[g>>2]|0;j=a+12208|0;k=c[j>>2]|0;l=a+9948|0;m=c[l>>2]|0;n=a+9956|0;o=c[n>>2]|0;p=a+9952|0;q=c[p>>2]|0;r=a+12216|0;s=c[r>>2]|0;t=a+12220|0;u=c[t>>2]|0;v=a+14344|0;w=c[v>>2]|0;x=a+14340|0;y=c[x>>2]|0;z=a+808|0;A=c[z>>2]|0;B=a+812|0;C=c[B>>2]|0;D=a+12224|0;E=c[D>>2]|0;F=a+784|0;G=d|0;c[G>>2]=c[F>>2];c[G+4>>2]=c[F+4>>2];c[G+8>>2]=c[F+8>>2];c[G+12>>2]=c[F+12>>2];c[G+16>>2]=c[F+16>>2];c[G+20>>2]=c[F+20>>2];H=a+13184|0;I=c[H>>2]|0;J=a+13188|0;K=c[J>>2]|0;L=a+13192|0;M=c[L>>2]|0;N=a+9908|0;O=c[N>>2]|0;P=a+9912|0;Q=c[P>>2]|0;R=a+9916|0;S=c[R>>2]|0;T=a+9920|0;U=c[T>>2]|0;nrc(a|0,b|0,14672)|0;c[e>>2]=f;c[g>>2]=h;c[j>>2]=k;c[l>>2]=m;c[n>>2]=o;c[p>>2]=q;c[r>>2]=s;c[t>>2]=u;c[v>>2]=w;c[x>>2]=y;c[z>>2]=A;c[B>>2]=C;c[D>>2]=E;c[F>>2]=c[G>>2];c[F+4>>2]=c[G+4>>2];c[F+8>>2]=c[G+8>>2];c[F+12>>2]=c[G+12>>2];c[F+16>>2]=c[G+16>>2];c[F+20>>2]=c[G+20>>2];c[H>>2]=I;c[J>>2]=K;c[L>>2]=M;c[N>>2]=O;c[P>>2]=Q;c[R>>2]=S;c[T>>2]=U;c[a+14292>>2]=y;c[a+14296>>2]=y+128;c[a+14300>>2]=y+256;c[a+14304>>2]=y+384;U=y+512|0;T=a+14308|0;c[T>>2]=U;S=y+640|0;R=a+14312|0;c[R>>2]=S;c[a+14316>>2]=y+768;c[a+14320>>2]=y+896;c[a+14324>>2]=y+1024;c[a+14328>>2]=y+1152;c[a+14332>>2]=y+1280;c[a+14336>>2]=y+1408;y=a+4|0;if((c[(c[y>>2]|0)+52>>2]|0)==844251990){c[T>>2]=S;c[R>>2]=U}if((f|0)!=0){V=0;i=d;return V|0}f=qTa(a,c[a+148>>2]|0)|0;if((f|0)>=0){V=0;i=d;return V|0}KIb(c[y>>2]|0,16,2144288,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;V=f;i=d;return V|0}function qTa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=(((b|0)>-1?b:-b|0)<<2)+380&-128;b=e*24|0;f=pJb(b)|0;g=a+9944|0;c[g>>2]=f;do{if((f|0)!=0|(b|0)==0){h=e<<5;j=pJb(h)|0;c[a+12192>>2]=j;if(!((j|0)!=0|(h|0)==0)){KIb(c[a+4>>2]|0,16,2531040,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;break}c[a+12208>>2]=j;c[a+9948>>2]=j;c[a+9956>>2]=j;c[a+9952>>2]=j+16;l=0;i=d;return l|0}else{KIb(c[a+4>>2]|0,16,2531040,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k}}while(0);mJb(g);l=-12;i=d;return l|0}function rTa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;if((c[a+56>>2]|0)==0){d=1}else{e=c[(c[a+4>>2]|0)+404>>2]|0;d=(e|0)==0?1:e}do{if((c[a+48>>2]|0)==2){if((c[a+14152>>2]|0)!=0){f=6;break}e=(((c[a+12>>2]|0)+31|0)/32|0)<<1;c[a+120>>2]=e;g=e}else{f=6}}while(0);if((f|0)==6){e=((c[a+12>>2]|0)+15|0)/16|0;c[a+120>>2]=e;g=e}e=a+4|0;h=c[e>>2]|0;if((c[h+140>>2]|0)==-1){KIb(h,16,2567248,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=b;return k|0}if((d|0)>32){f=11}else{if((d|0)<=(g|0)|(g|0)==0){l=d}else{f=11}}if((f|0)==11){if((g|0)==0){m=32}else{m=(g|0)<32?g:32}KIb(h,24,2548896,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=m,j)|0);i=j;l=m}m=c[a+8>>2]|0;d=c[a+12>>2]|0;do{if((m|d|0)!=0){if((tIb(m,d,0,c[e>>2]|0)|0)==0){break}else{k=-1}i=b;return k|0}}while(0);cTa(a)|0;d=c[e>>2]|0;c[a+60>>2]=c[d+88>>2];c[a+64>>2]=c[d+92>>2];vLa(c[d+140>>2]|0,a+14216|0,a+14220|0);c[a+88>>2]=F5a(c[(c[e>>2]|0)+52>>2]|0)|0;c[a+92>>2]=F5a(c[(c[e>>2]|0)+56>>2]|0)|0;d=pJb(80064)|0;m=d;h=a+156|0;c[h>>2]=m;a:do{if((d|0)==0){KIb(c[e>>2]|0,16,2531040,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}else{g=0;f=m;while(1){WHb(f+(g*2224|0)|0);n=g+1|0;if((n|0)>=36){break}g=n;f=c[h>>2]|0}f=a+952|0;g=a+7624|0;mrc(g|0,0,2224)|0;mrc(f|0,0,4448)|0;WHb(a+3176|0);WHb(f|0);WHb(g|0);if((vTa(a)|0)!=0){break}c[a+13760>>2]=-1;c[a+96>>2]=1;c[a+816>>2]=a;do{if((l|0)>1){g=a;f=1;do{n=hJb(14672)|0;c[a+816+(f<<2)>>2]=n;nrc(n|0,g|0,14672)|0;f=f+1|0;}while((f|0)<(l|0));if((l|0)<=0){break}f=a+120|0;g=(l|0)/2|0;n=0;do{o=a+816+(n<<2)|0;if((wTa(c[o>>2]|0)|0)<0){break a}p=((ca(c[f>>2]|0,n)|0)+g|0)/(l|0)|0;q=c[o>>2]|0;c[q+808>>2]=p;n=n+1|0;c[q+812>>2]=((ca(c[f>>2]|0,n)|0)+g|0)/(l|0)|0;}while((n|0)<(l|0))}else{if((wTa(a)|0)<0){break a}c[a+808>>2]=0;c[a+812>>2]=c[a+120>>2]}}while(0);c[a+944>>2]=l;k=0;i=b;return k|0}}while(0);xTa(a);k=-1;i=b;return k|0}function sTa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+944|0;do{if((c[b>>2]|0)>1){d=0;do{yTa(c[a+816+(d<<2)>>2]|0);d=d+1|0;e=c[b>>2]|0;}while((d|0)<(e|0));if((e|0)>1){f=1}else{break}do{mJb(a+816+(f<<2)|0);f=f+1|0;}while((f|0)<(c[b>>2]|0))}else{yTa(a)}}while(0);zTa(a);f=c[a+156>>2]|0;if((f|0)!=0){e=0;do{c[f+(e*2224|0)+2188>>2]=1;e=e+1|0;}while((e|0)<36)}c[a+9856>>2]=0;c[a+9852>>2]=0;c[a+9848>>2]=0;do{if((c[a+48>>2]|0)==2){if((c[a+14152>>2]|0)!=0){g=11;break}e=c[a+12>>2]|0;c[a+120>>2]=((e+31|0)/32|0)<<1;h=e}else{g=11}}while(0);if((g|0)==11){g=c[a+12>>2]|0;c[a+120>>2]=(g+15|0)/16|0;h=g}g=a+8|0;e=c[g>>2]|0;do{if((e|h|0)!=0){if((tIb(e,h,0,c[a+4>>2]|0)|0)==0){break}else{i=-1094995529}return i|0}}while(0);h=vTa(a)|0;a:do{if((h|0)==0){c[a+816>>2]=a;if((c[g>>2]|0)==0){i=0;return i|0}if((c[a+12>>2]|0)==0){i=0;return i|0}e=c[b>>2]|0;do{if((e|0)>1){f=a;d=1;do{j=hJb(14672)|0;c[a+816+(d<<2)>>2]=j;nrc(j|0,f|0,14672)|0;d=d+1|0;}while((d|0)<(e|0));if((e|0)<=0){break}d=a+120|0;f=(e|0)/2|0;j=0;do{k=a+816+(j<<2)|0;if((wTa(c[k>>2]|0)|0)<0){l=0;break a}m=((ca(c[d>>2]|0,j)|0)+f|0)/(e|0)|0;n=c[k>>2]|0;c[n+808>>2]=m;j=j+1|0;c[n+812>>2]=((ca(c[d>>2]|0,j)|0)+f|0)/(e|0)|0;}while((j|0)<(e|0))}else{j=wTa(a)|0;if((j|0)<0){l=j;break a}c[a+808>>2]=0;c[a+812>>2]=c[a+120>>2]}}while(0);c[b>>2]=e;i=0;return i|0}else{l=h}}while(0);xTa(a);i=l;return i|0}function tTa(a){a=a|0;c[a+9892>>2]=1347360;c[a+9888>>2]=1347360;c[a+9896>>2]=1402496;c[a+14224>>2]=1;c[a+14152>>2]=1;c[a+14172>>2]=3;c[a+104>>2]=0;c[a+108>>2]=0;c[a+11556>>2]=1;c[a+11560>>2]=1;c[a+944>>2]=1;return}function uTa(a){a=a|0;c[a+9892>>2]=1347360;c[a+9888>>2]=1347360;c[a+9896>>2]=1402496;c[a+14224>>2]=1;c[a+14152>>2]=1;c[a+14172>>2]=3;c[a+104>>2]=0;c[a+108>>2]=0;c[a+11556>>2]=1;c[a+11560>>2]=1;c[a+944>>2]=1;return}function vTa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;e=((c[a+8>>2]|0)+15|0)/16|0;f=a+116|0;c[f>>2]=e;g=e+1|0;h=a+124|0;c[h>>2]=g;j=e<<1|1;k=a+128|0;c[k>>2]=j;c[a+132>>2]=e<<2|1;l=a+120|0;m=c[l>>2]|0;n=ca(g,m)|0;o=(ca(m+2|0,g)|0)+1|0;c[a+136>>2]=e<<4;c[a+140>>2]=m<<4;p=ca(m,e)|0;e=a+144|0;c[e>>2]=p;c[a+12532>>2]=j;c[a+12528>>2]=j;c[a+12524>>2]=j;c[a+12520>>2]=j;c[a+12540>>2]=g;c[a+12536>>2]=g;q=ca(m<<1|1,j)|0;r=ca(g,m+1|0)|0;s=q+(r<<1)|0;if((m&1|0)==0){t=s}else{t=(g+j<<1)+s|0}s=pJb((p<<2)+4|0)|0;p=s;j=a+12556|0;c[j>>2]=p;do{if((s|0)==0){if((c[e>>2]&1073741823|0)==1073741823){break}KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}while(0);s=c[l>>2]|0;g=c[f>>2]|0;if((s|0)>0){m=0;w=g;while(1){if((w|0)>0){x=0;y=w;while(1){c[p+((ca(y,m)|0)+x<<2)>>2]=(ca(c[h>>2]|0,m)|0)+x;z=x+1|0;A=c[f>>2]|0;if((z|0)<(A|0)){x=z;y=A}else{B=A;break}}}else{B=w}y=m+1|0;if((y|0)<(s|0)){m=y;w=B}else{C=B;break}}}else{C=g}c[p+((ca(C,s)|0)<<2)>>2]=(ca(c[h>>2]|0,s-1|0)|0)+C;C=a+56|0;do{if((c[C>>2]|0)!=0){s=o<<2;p=pJb(s)|0;g=a+11564|0;c[g>>2]=p;B=(s|0)==0;if(!((p|0)!=0|B)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=pJb(s)|0;w=a+11568|0;c[w>>2]=p;if(!((p|0)!=0|B)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=pJb(s)|0;m=a+11572|0;c[m>>2]=p;if(!((p|0)!=0|B)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=pJb(s)|0;y=a+11576|0;c[y>>2]=p;if(!((p|0)!=0|B)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=pJb(s)|0;x=a+11580|0;c[x>>2]=p;if(!((p|0)!=0|B)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}p=pJb(s)|0;s=p;c[a+11584>>2]=s;if(!((p|0)!=0|B)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}B=(c[h>>2]|0)+1|0;c[a+11636>>2]=(c[g>>2]|0)+(B<<2);c[a+11640>>2]=(c[w>>2]|0)+(B<<2);c[a+11644>>2]=(c[m>>2]|0)+(B<<2);c[a+11648>>2]=(c[y>>2]|0)+(B<<2);c[a+11652>>2]=(c[x>>2]|0)+(B<<2);c[a+11656>>2]=s+(B<<2);B=n<<1;s=pJb(B)|0;c[a+12492>>2]=s;if(!((s|0)!=0|(B|0)==0)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}B=n<<2;s=pJb(B)|0;c[a+9976>>2]=s;x=(B|0)==0;if(!((s|0)!=0|x)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}s=hJb(B)|0;c[a+14412>>2]=s;if(!((s|0)!=0|x)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}s=hJb(B)|0;c[a+14416>>2]=s;if((s|0)!=0|x){break}KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}while(0);if((c[a+48>>2]|0)==13){D=33}else{if((c[a+60>>2]&536870912|0)!=0){D=33}}a:do{if((D|0)==33){x=o<<2;s=(x|0)==0;B=n<<1;y=(B|0)==0;m=0;while(1){if((m|0)>=2){break a}if(s){w=pJb(0)|0;c[a+11604+(m<<4)>>2]=w;c[a+11676+(m<<4)>>2]=w+((c[h>>2]|0)+1<<2);w=pJb(0)|0;c[a+11604+(m<<4)+4>>2]=w;c[a+11676+(m<<4)+4>>2]=w+((c[h>>2]|0)+1<<2);w=pJb(B)|0;c[a+11716+(m<<3)>>2]=w;if(!((w|0)!=0|y)){D=41;break}w=pJb(0)|0;c[a+11588+(m<<3)>>2]=w;c[a+11660+(m<<3)>>2]=w+((c[h>>2]|0)+1<<2);w=pJb(0)|0;c[a+11604+(m<<4)+8>>2]=w;c[a+11676+(m<<4)+8>>2]=w+((c[h>>2]|0)+1<<2);w=pJb(0)|0;c[a+11604+(m<<4)+12>>2]=w;c[a+11676+(m<<4)+12>>2]=w+((c[h>>2]|0)+1<<2);w=pJb(B)|0;c[a+11716+(m<<3)+4>>2]=w;if(!((w|0)!=0|y)){D=41;break}w=pJb(0)|0;c[a+11588+(m<<3)+4>>2]=w;c[a+11660+(m<<3)+4>>2]=w+((c[h>>2]|0)+1<<2)}else{w=pJb(x)|0;g=w;c[a+11604+(m<<4)>>2]=g;if((w|0)==0){D=38;break}c[a+11676+(m<<4)>>2]=g+((c[h>>2]|0)+1<<2);g=pJb(x)|0;w=g;c[a+11604+(m<<4)+4>>2]=w;if((g|0)==0){D=38;break}c[a+11676+(m<<4)+4>>2]=w+((c[h>>2]|0)+1<<2);w=pJb(B)|0;c[a+11716+(m<<3)>>2]=w;if(!((w|0)!=0|y)){D=41;break}w=pJb(x)|0;g=w;c[a+11588+(m<<3)>>2]=g;if((w|0)==0){D=43;break}c[a+11660+(m<<3)>>2]=g+((c[h>>2]|0)+1<<2);g=pJb(x)|0;w=g;c[a+11604+(m<<4)+8>>2]=w;if((g|0)==0){D=38;break}c[a+11676+(m<<4)+8>>2]=w+((c[h>>2]|0)+1<<2);w=pJb(x)|0;g=w;c[a+11604+(m<<4)+12>>2]=g;if((w|0)==0){D=38;break}c[a+11676+(m<<4)+12>>2]=g+((c[h>>2]|0)+1<<2);g=pJb(B)|0;c[a+11716+(m<<3)+4>>2]=g;if(!((g|0)!=0|y)){D=41;break}g=pJb(x)|0;w=g;c[a+11588+(m<<3)+4>>2]=w;if((g|0)==0){D=43;break}c[a+11660+(m<<3)+4>>2]=w+((c[h>>2]|0)+1<<2)}w=pJb(B)|0;c[a+11708+(m<<2)>>2]=w;if((w|0)!=0|y){m=m+1|0}else{D=45;break}}if((D|0)==38){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}else if((D|0)==41){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}else if((D|0)==43){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}else if((D|0)==45){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}}while(0);do{if((c[a+28>>2]|0)==2){o=pJb((ca(c[l>>2]<<1&2,c[k>>2]|0)|0)+q|0)|0;c[a+9900>>2]=o;do{if((o|0)==0){m=c[k>>2]|0;if((q|0)==(ca(c[l>>2]<<1&2,-m|0)|0)){E=m;break}KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}else{E=c[k>>2]|0}}while(0);c[a+9904>>2]=o+(E+1);m=pJb(n)|0;c[a+9936>>2]=m;y=(n|0)==0;if(!((m|0)!=0|y)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}m=pJb(n)|0;c[a+9940>>2]=m;if((m|0)!=0|y){break}KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}while(0);do{if((c[a+32>>2]|0)==0){if((c[a+40>>2]|0)!=0){D=58;break}if((c[C>>2]|0)==0){D=58}}else{D=58}}while(0);do{if((D|0)==58){C=t<<1;E=pJb(C)|0;y=E;c[a+9872>>2]=y;if((E|0)!=0|(C|0)==0){c[a+9876>>2]=y+((c[k>>2]|0)+1<<1);C=q+1+(c[h>>2]|0)|0;c[a+9880>>2]=y+(C<<1);c[a+9884>>2]=y+(C+r<<1);if((t|0)>0){F=0}else{break}do{b[y+(F<<1)>>1]=1024;F=F+1|0;}while((F|0)<(t|0))}else{KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}}}while(0);t=pJb(n)|0;F=a+9932|0;c[F>>2]=t;if(!((t|0)!=0|(n|0)==0)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}mrc(t|0,1,n|0)|0;t=n+2|0;n=pJb(t)|0;r=a+9928|0;c[r>>2]=n;if(!((n|0)!=0|(t|0)==0)){KIb(c[a+4>>2]|0,16,2531040,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-12;i=d;return v|0}u=c[l>>2]|0;l=c[h>>2]|0;h=ca(l,u)|0;c[a+14424>>2]=c[a+4>>2];c[a+14428>>2]=a+10056;c[a+14432>>2]=c[j>>2];c[a+14436>>2]=c[e>>2];c[a+14440>>2]=c[f>>2];c[a+14444>>2]=u;c[a+14448>>2]=l;c[a+14452>>2]=c[k>>2];k=a+14468|0;c[k>>2]=hJb(h)|0;l=pJb(h)|0;h=a+14464|0;c[h>>2]=l;if((c[k>>2]|0)==0|(l|0)==0){mJb(k);mJb(h);v=-12;i=d;return v|0}else{c[a+14484>>2]=c[r>>2];c[a+14488>>2]=c[F>>2];c[a+14472>>2]=c[a+9876>>2];c[a+14476>>2]=c[a+9880>>2];c[a+14480>>2]=c[a+9884>>2];c[a+14584>>2]=122;c[a+14588>>2]=a;v=0;i=d;return v|0}return 0}function wTa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=a+128|0;e=c[d>>2]|0;f=c[a+120>>2]|0;g=ca(f<<1|1,e)|0;h=a+124|0;j=c[h>>2]|0;k=ca(j,f+1|0)|0;l=g+(k<<1)|0;if((f&1|0)==0){m=l}else{m=(j+e<<1)+l|0}c[a+12208>>2]=0;c[a+12192>>2]=0;mrc(a+9944|0,0,16)|0;do{if((c[a+56>>2]|0)!=0){l=pJb(256)|0;c[a+12216>>2]=l;if((l|0)==0){KIb(c[a+4>>2]|0,16,2531040,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}l=pJb(256)|0;c[a+12220>>2]=l;e=a+4|0;j=c[e>>2]|0;if((l|0)==0){KIb(j,16,2531040,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}if((c[j+312>>2]|0)==0){break}j=pJb(512)|0;c[a+13184>>2]=j;if((j|0)!=0){break}KIb(c[e>>2]|0,16,2531040,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}}while(0);e=pJb(3072)|0;c[a+14344>>2]=e;if((e|0)==0){KIb(c[a+4>>2]|0,16,2531040,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}j=e;c[a+14340>>2]=j;c[a+14292>>2]=j;c[a+14296>>2]=e+128;c[a+14300>>2]=e+256;c[a+14304>>2]=e+384;j=e+512|0;l=a+14308|0;c[l>>2]=j;f=e+640|0;p=a+14312|0;c[p>>2]=f;c[a+14316>>2]=e+768;c[a+14320>>2]=e+896;c[a+14324>>2]=e+1024;c[a+14328>>2]=e+1152;c[a+14332>>2]=e+1280;c[a+14336>>2]=e+1408;e=a+4|0;if((c[(c[e>>2]|0)+52>>2]|0)==844251990){c[l>>2]=f;c[p>>2]=j}if((c[a+28>>2]|0)!=2){o=0;i=b;return o|0}j=m<<5;m=pJb(j)|0;p=m;c[a+9908>>2]=p;if((m|0)!=0|(j|0)==0){c[a+9912>>2]=p+((c[d>>2]|0)+1<<5);d=g+1+(c[h>>2]|0)|0;c[a+9916>>2]=p+(d<<5);c[a+9920>>2]=p+(d+k<<5);o=0;i=b;return o|0}else{KIb(c[e>>2]|0,16,2531040,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=b;return o|0}return 0}function xTa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+944|0;if((c[b>>2]|0)>1){d=0;do{yTa(c[a+816+(d<<2)>>2]|0);d=d+1|0;e=c[b>>2]|0;}while((d|0)<(e|0));if((e|0)>1){e=1;do{mJb(a+816+(e<<2)|0);e=e+1|0;}while((e|0)<(c[b>>2]|0))}c[b>>2]=1}else{yTa(a)}mJb(a+13744|0);c[a+13756>>2]=0;mJb(a+14016|0);c[a+14024>>2]=0;b=a+156|0;e=c[b>>2]|0;a:do{if((e|0)!=0){d=0;f=e;while(1){c[f+(d*2224|0)+1584>>2]=0;c[f+(d*2224|0)+1580>>2]=0;fGb(f+(d*2224|0)+1564|0);fGb(f+(d*2224|0)+1572|0);fGb(f+(d*2224|0)+1588|0);fGb(f+(d*2224|0)+1540|0);fGb(f+(d*2224|0)+1508|0);fGb(f+(d*2224|0)+1532|0);fGb(f+(d*2224|0)+1516|0);fGb(f+(d*2224|0)+1548|0);fGb(f+(d*2224|0)+1520|0);fGb(f+(d*2224|0)+1552|0);mTa(a,(c[b>>2]|0)+(d*2224|0)|0);g=d+1|0;if((g|0)>=36){break a}d=g;f=c[b>>2]|0}}}while(0);mJb(b);c[a+2536>>2]=0;c[a+2532>>2]=0;fGb(a+2516|0);fGb(a+2524|0);fGb(a+2540|0);fGb(a+2492|0);fGb(a+2460|0);fGb(a+2484|0);fGb(a+2468|0);fGb(a+2500|0);fGb(a+2472|0);fGb(a+2504|0);mTa(a,a+952|0);c[a+9208>>2]=0;c[a+9204>>2]=0;fGb(a+9188|0);fGb(a+9196|0);fGb(a+9212|0);fGb(a+9164|0);fGb(a+9132|0);fGb(a+9156|0);fGb(a+9140|0);fGb(a+9172|0);fGb(a+9144|0);fGb(a+9176|0);mTa(a,a+7624|0);c[a+4760>>2]=0;c[a+4756>>2]=0;fGb(a+4740|0);fGb(a+4748|0);fGb(a+4764|0);fGb(a+4716|0);fGb(a+4684|0);fGb(a+4708|0);fGb(a+4692|0);fGb(a+4724|0);fGb(a+4696|0);fGb(a+4728|0);mTa(a,a+3176|0);zTa(a);c[a+96>>2]=0;c[a+9856>>2]=0;c[a+9852>>2]=0;c[a+9848>>2]=0;c[a+152>>2]=0;c[a+148>>2]=0;return}function yTa(a){a=a|0;if((a|0)==0){return}mJb(a+9944|0);mJb(a+12192|0);c[a+9952>>2]=0;c[a+9956>>2]=0;c[a+9948>>2]=0;c[a+12208>>2]=0;mJb(a+13184|0);mJb(a+12216|0);mJb(a+12220|0);mJb(a+14344|0);mJb(a+9908|0);c[a+14340>>2]=0;return}function zTa(a){a=a|0;mJb(a+12492|0);mJb(a+11564|0);mJb(a+11568|0);mJb(a+11572|0);mJb(a+11576|0);mJb(a+11580|0);mJb(a+11584|0);mrc(a+11636|0,0,24)|0;mJb(a+11604|0);c[a+11676>>2]=0;mJb(a+11608|0);c[a+11680>>2]=0;mJb(a+11716|0);mJb(a+11588|0);c[a+11660>>2]=0;mJb(a+11612|0);c[a+11684>>2]=0;mJb(a+11616|0);c[a+11688>>2]=0;mJb(a+11720|0);mJb(a+11592|0);c[a+11664>>2]=0;mJb(a+11708|0);mJb(a+11620|0);c[a+11692>>2]=0;mJb(a+11624|0);c[a+11696>>2]=0;mJb(a+11724|0);mJb(a+11596|0);c[a+11668>>2]=0;mJb(a+11628|0);c[a+11700>>2]=0;mJb(a+11632|0);c[a+11704>>2]=0;mJb(a+11728|0);mJb(a+11600|0);c[a+11672>>2]=0;mJb(a+11712|0);mJb(a+9872|0);mJb(a+9900|0);mJb(a+9932|0);mJb(a+9936|0);mJb(a+9940|0);mJb(a+9928|0);mJb(a+14464|0);mJb(a+14468|0);mJb(a+12556|0);mJb(a+9976|0);mJb(a+14412|0);mJb(a+14416|0);c[a+152>>2]=0;c[a+148>>2]=0;return}function ATa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+216|0;g=f|0;h=f+72|0;j=f+144|0;k=(e|0)!=0;do{if(k){if((c[b+28>>2]|0)==0){break}i=f;return}}while(0);l=b+4|0;m=g|0;n=h|0;o=j|0;p=b|0;q=b+12|0;r=b+16|0;s=0;do{if((s|0)==0){t=l;u=0}else{t=p;u=c[l>>2]|0}v=c[t>>2]|0;mrc(m|0,0,65)|0;mrc(n|0,0,65)|0;w=c[p>>2]|0;mrc(o|0,w&255|0,65)|0;if((u|0)<(v|0)){x=c[q>>2]|0;y=c[r>>2]|0;z=u;do{A=a[x+z|0]|0;B=A<<24>>24;C=a[y+z|0]|0;D=j+B|0;if((d[D]|0)==(w|0)){a[D]=z}D=g+B|0;if(C<<24>>24>(a[D]|0)){a[D]=C}D=h+(C<<24>>24)|0;if(A<<24>>24>(a[D]|0)){a[D]=A}z=z+1|0;}while((z|0)<(v|0))}if(k){v=e+(s*195|0)|0;c[b+28+(s<<2)>>2]=v;nrc(v|0,m|0,65)|0;v=e+(s*195|0)+65|0;c[b+36+(s<<2)>>2]=v;nrc(v|0,n|0,65)|0;v=e+(s*195|0)+130|0;c[b+20+(s<<2)>>2]=v;E=v}else{v=hJb(65)|0;c[b+28+(s<<2)>>2]=v;nrc(v|0,m|0,65)|0;v=hJb(65)|0;c[b+36+(s<<2)>>2]=v;nrc(v|0,n|0,65)|0;v=hJb(65)|0;c[b+20+(s<<2)>>2]=v;E=v}nrc(E|0,o|0,65)|0;s=s+1|0;}while((s|0)<2);i=f;return}function BTa(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=d+52|0;f=d+48|0;g=d|0;h=d+12|0;i=d+16|0;j=d+4|0;k=0;l=c[e>>2]|0;while(1){m=(k|0)==0;n=m?1:k<<1;o=m?0:k+65535|1;if((l|0)>0){m=d+64+(k<<2)|0;p=0;while(1){q=c[f>>2]|0;r=b[q+(p<<2)>>1]|0;s=r<<16>>16;t=b[q+(p<<2)+2>>1]|0;do{if(t<<16>>16==0){u=66;v=64}else{if(t<<16>>16<0){u=0;v=r;break}if((s|0)==(c[g>>2]|0)){u=66;v=0;break}q=(ca(a[(c[i>>2]|0)+s|0]|0,n)|0)+o|0;u=(a[(c[h>>2]|0)+s|0]|0)+((s|0)<(c[j>>2]|0)?1:-63)&255;v=q&65535}}while(0);a[(c[m>>2]|0)+(p<<2)+2|0]=t;s=c[m>>2]|0;b[s+(p<<2)>>1]=v;a[s+(p<<2)+3|0]=u;s=p+1|0;r=c[e>>2]|0;if((s|0)<(r|0)){p=s}else{w=r;break}}}else{w=l}p=k+1|0;if((p|0)<32){k=p;l=w}else{break}}return}function CTa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=a+156|0;f=c[e>>2]|0;g=a+9848|0;a:do{if((b|0)==0){h=c[g>>2]|0;j=0;do{do{if((h|0)!=(f+(j*2224|0)|0)){if((c[f+(j*2224|0)+360>>2]|0)==0){k=j;break a}if((c[f+(j*2224|0)+2188>>2]|0)==0){break}if((c[f+(j*2224|0)+2192>>2]&4|0)==0){k=j;break a}}}while(0);j=j+1|0;}while((j|0)<36);l=a+4|0;m=c[l>>2]|0;n=m;KIb(n,8,2264008,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;Hd();return 0}else{j=0;do{if((c[f+(j*2224|0)+360>>2]|0)==0){if((f+(j*2224|0)|0)!=(c[g>>2]|0)){k=j;break a}}j=j+1|0;}while((j|0)<36);l=a+4|0;m=c[l>>2]|0;n=m;KIb(n,8,2264008,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;Hd();return 0}}while(0);if(!(k>>>0<36>>>0)){i=d;return k|0}o=f+(k*2224|0)+2188|0;if((c[o>>2]|0)==0){i=d;return k|0}c[o>>2]=0;c[f+(k*2224|0)+1584>>2]=0;c[f+(k*2224|0)+1580>>2]=0;fGb(f+(k*2224|0)+1564|0);fGb(f+(k*2224|0)+1572|0);fGb(f+(k*2224|0)+1588|0);fGb(f+(k*2224|0)+1540|0);fGb(f+(k*2224|0)+1508|0);fGb(f+(k*2224|0)+1532|0);fGb(f+(k*2224|0)+1516|0);fGb(f+(k*2224|0)+1548|0);fGb(f+(k*2224|0)+1520|0);fGb(f+(k*2224|0)+1552|0);mTa(a,(c[e>>2]|0)+(k*2224|0)|0);i=d;return k|0}function DTa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[a+9924>>2]=0;if((N5a(b)|0)==0){KIb(b,16,2515704,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1;i=d;return h|0}j=a+9992|0;k=a+9848|0;do{if((c[j>>2]|0)!=3){l=c[k>>2]|0;if((l|0)==0){break}if((l|0)==(c[a+9852>>2]|0)){break}if((c[l+360>>2]|0)==0){break}mTa(a,l)}}while(0);l=a+156|0;m=a+9852|0;n=b+816|0;o=b;p=0;do{q=c[l>>2]|0;r=q+(p*2224|0)|0;do{if((r|0)!=(c[k>>2]|0)){if((r|0)==(c[m>>2]|0)){break}if((c[q+(p*2224|0)+2192>>2]|0)==0){break}if((c[q+(p*2224|0)+2188>>2]|0)!=0){break}if((c[n>>2]&1|0)==0){KIb(o,16,2501824,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;s=c[l>>2]|0}else{s=q}mTa(a,s+(p*2224|0)|0)}}while(0);p=p+1|0;}while((p|0)<36);p=a+7624|0;mTa(a,p);s=0;do{n=c[l>>2]|0;if((c[n+(s*2224|0)+2192>>2]|0)==0){mTa(a,n+(s*2224|0)|0)}s=s+1|0;}while((s|0)<36);s=a+9856|0;n=c[s>>2]|0;if((n|0)==0){t=23}else{if((c[n+360>>2]|0)==0){u=n}else{t=23}}do{if((t|0)==23){n=CTa(a,0)|0;if((n|0)>=0){u=(c[l>>2]|0)+(n*2224|0)|0;break}KIb(c[a+4>>2]|0,16,2488840,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=n;i=d;return h|0}}while(0);n=u+2192|0;c[n>>2]=0;q=a+10008|0;do{if((c[q>>2]|0)==0){if((c[j>>2]|0)==3){break}c[n>>2]=3}}while(0);n=a+104|0;r=c[n>>2]|0;c[n>>2]=r+1;c[u+160>>2]=r;if((lTa(a,u,0)|0)<0){h=-1;i=d;return h|0}c[s>>2]=u;r=u+300|0;c[r>>2]=c[a+14184>>2];n=a+48|0;do{if(((c[n>>2]|0)-1|0)>>>0<2>>>0){v=c[a+14172>>2]|0;if((v|0)==3){break}c[r>>2]=((v|0)==1|0)==(c[a+14240>>2]|0)}}while(0);if((c[a+14224>>2]|0)==0){w=(c[a+14152>>2]|0)==0|0}else{w=0}c[u+296>>2]=w;w=a+14172|0;c[u+2164>>2]=(c[w>>2]|0)!=3;r=c[j>>2]|0;c[u+88>>2]=r;c[u+84>>2]=(r|0)==1;r=nTa(a,p,u)|0;if((r|0)<0){h=r;i=d;return h|0}r=c[j>>2]|0;do{if((r|0)==3){x=c[k>>2]|0}else{u=c[m>>2]|0;c[k>>2]=u;if((c[q>>2]|0)!=0){x=u;break}c[m>>2]=c[s>>2];x=u}}while(0);if((x|0)==0){t=42}else{if((c[x+360>>2]|0)==0){t=42}}do{if((t|0)==42){if((r|0)==1){if((c[w>>2]|0)==3){break}}x=a+4|0;tKb(c[(c[x>>2]|0)+140>>2]|0,e,f)|0;s=c[j>>2]|0;do{if((s|0)==3){q=c[m>>2]|0;if((q|0)==0){t=49;break}if((c[q+360>>2]|0)==0){if((s|0)==1){t=50;break}else{t=49;break}}else{KIb(o,48,2477920,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;break}}else if((s|0)==1){t=50}else{t=49}}while(0);do{if((t|0)==49){KIb(o,16,2468320,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}else if((t|0)==50){if((c[w>>2]|0)==3){break}KIb(o,48,2458976,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}}while(0);s=CTa(a,0)|0;if((s|0)<0){KIb(c[x>>2]|0,16,2488840,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=s;i=d;return h|0}q=c[l>>2]|0;u=q+(s*2224|0)|0;c[k>>2]=u;c[q+(s*2224|0)+2192>>2]=3;c[q+(s*2224|0)+84>>2]=0;c[q+(s*2224|0)+88>>2]=2;if((lTa(a,u,0)|0)<0){c[k>>2]=0;h=-1;i=d;return h|0}do{if((c[b+712>>2]|0)==0){u=b+124|0;s=c[u>>2]|0;do{if((s|0)>0){q=b+120|0;p=0;do{v=c[k>>2]|0;y=(c[v>>2]|0)+(ca(c[v+32>>2]|0,p)|0)|0;mrc(y|0,-128|0,c[q>>2]|0)|0;p=p+1|0;z=c[u>>2]|0;}while((p|0)<(z|0));if((z|0)<=0){A=z;break}p=b+120|0;q=0;while(1){y=c[k>>2]|0;v=(c[y+4>>2]|0)+(ca(c[y+36>>2]|0,q)|0)|0;mrc(v|0,-128|0,-(-(c[p>>2]|0)>>c[e>>2])|0)|0;v=c[k>>2]|0;y=(c[v+8>>2]|0)+(ca(c[v+40>>2]|0,q)|0)|0;mrc(y|0,-128|0,-(-(c[p>>2]|0)>>c[e>>2])|0)|0;y=q+1|0;v=c[u>>2]|0;if((y|0)<(-(-v>>c[f>>2])|0)){q=y}else{A=v;break}}}else{A=s}}while(0);s=c[n>>2]|0;if(!((s|0)==22|(s|0)==5)){break}if((A|0)<=0){break}s=b+120|0;q=0;do{p=c[k>>2]|0;v=(c[p>>2]|0)+(ca(c[p+32>>2]|0,q)|0)|0;mrc(v|0,16,c[s>>2]|0)|0;q=q+1|0;}while((q|0)<(c[u>>2]|0))}}while(0);L5a((c[k>>2]|0)+1496|0,2147483647,0);L5a((c[k>>2]|0)+1496|0,2147483647,1)}}while(0);A=c[m>>2]|0;if((A|0)==0){t=70}else{if((c[A+360>>2]|0)==0){t=70}}do{if((t|0)==70){if((c[j>>2]|0)!=3){break}A=CTa(a,0)|0;if((A|0)<0){KIb(c[a+4>>2]|0,16,2488840,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=A;i=d;return h|0}f=c[l>>2]|0;e=f+(A*2224|0)|0;c[m>>2]=e;c[f+(A*2224|0)+2192>>2]=3;c[f+(A*2224|0)+84>>2]=0;c[f+(A*2224|0)+88>>2]=2;if((lTa(a,e,0)|0)>=0){L5a((c[m>>2]|0)+1496|0,2147483647,0);L5a((c[m>>2]|0)+1496|0,2147483647,1);break}c[m>>2]=0;h=-1;i=d;return h|0}}while(0);do{if((c[k>>2]|0)!=0){l=a+952|0;mTa(a,l);t=c[k>>2]|0;if((c[t+360>>2]|0)==0){break}e=nTa(a,l,t)|0;if((e|0)<0){h=e}else{break}i=d;return h|0}}while(0);do{if((c[m>>2]|0)!=0){e=a+3176|0;mTa(a,e);t=c[m>>2]|0;if((c[t+360>>2]|0)==0){break}l=nTa(a,e,t)|0;if((l|0)<0){h=l}else{break}i=d;return h|0}}while(0);do{if((c[j>>2]|0)!=1){m=c[k>>2]|0;if((m|0)==0){KIb(0,0,2502120,(g=i,i=i+24|0,c[g>>2]=2442048,c[g+8>>2]=2449704,c[g+16>>2]=1840,g)|0);i=g;Hd();return 0}if((c[m+360>>2]|0)!=0){break}KIb(0,0,2502120,(g=i,i=i+24|0,c[g>>2]=2442048,c[g+8>>2]=2449704,c[g+16>>2]=1840,g)|0);i=g;Hd();return 0}}while(0);g=c[w>>2]|0;if((g|0)!=3){w=(g|0)==2;g=c[a+7656>>2]|0;if(w){k=a+7624|0;c[k>>2]=(c[k>>2]|0)+g}c[a+7656>>2]=g<<1;g=a+984|0;c[g>>2]=c[g>>2]<<1;g=a+3208|0;c[g>>2]=c[g>>2]<<1;g=c[a+7660>>2]|0;if(w){k=a+7628|0;c[k>>2]=(c[k>>2]|0)+g}c[a+7660>>2]=g<<1;g=a+988|0;c[g>>2]=c[g>>2]<<1;g=a+3212|0;c[g>>2]=c[g>>2]<<1;g=c[a+7664>>2]|0;if(w){k=a+7632|0;c[k>>2]=(c[k>>2]|0)+g}c[a+7664>>2]=g<<1;g=a+992|0;c[g>>2]=c[g>>2]<<1;g=a+3216|0;c[g>>2]=c[g>>2]<<1;g=c[a+7668>>2]|0;if(w){w=a+7636|0;c[w>>2]=(c[w>>2]|0)+g}c[a+7668>>2]=g<<1;g=a+996|0;c[g>>2]=c[g>>2]<<1;g=a+3220|0;c[g>>2]=c[g>>2]<<1}c[a+13740>>2]=c[b+696>>2];do{if((c[a+14004>>2]|0)==0){if((c[n>>2]|0)==2){break}if(((c[a+28>>2]|0)-1|0)>>>0<2>>>0){c[a+14384>>2]=c[a+14368>>2];c[a+14388>>2]=c[a+14372>>2];h=0;i=d;return h|0}else{c[a+14384>>2]=c[a+14352>>2];c[a+14388>>2]=c[a+14356>>2];h=0;i=d;return h|0}}}while(0);c[a+14384>>2]=c[a+14360>>2];c[a+14388>>2]=c[a+14364>>2];h=0;i=d;return h|0}function ETa(a){a=a|0;if((c[a+9816>>2]|0)==0){return}L5a((c[a+9856>>2]|0)+1496|0,2147483647,0);return}function FTa(d,e,f,g,h,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;n=i;i=i+16|0;o=n|0;p=n+8|0;if((c[d+712>>2]|0)!=0|(e|0)==0){i=n;return}q=e+1536|0;if((c[q>>2]|0)==0){i=n;return}r=d+12|0;if((c[(c[r>>2]|0)+16>>2]&128|0)!=0){i=n;return}s=d+688|0;t=c[s>>2]|0;if((t&152|0)==0){u=t}else{t=d;v=(BLb(c[f+88>>2]|0)|0)<<24>>24;KIb(t,48,2430184,(w=i,i=i+8|0,c[w>>2]=v,w)|0);i=w;if((k|0)>0){v=(j|0)>0;x=e+1512|0;y=0;do{if(v){z=ca(y,l)|0;A=0;do{B=c[s>>2]|0;if((B&128|0)==0){C=B}else{B=a[g+(A+z)|0]|0;KIb(t,48,2419808,(w=i,i=i+8|0,c[w>>2]=(B&255)>>>0>9>>>0?9:B&255,w)|0);i=w;C=c[s>>2]|0}if((C&16|0)==0){D=C}else{KIb(t,48,2410592,(w=i,i=i+8|0,c[w>>2]=a[(c[x>>2]|0)+(A+z)|0]|0,w)|0);i=w;D=c[s>>2]|0}do{if((D&8|0)!=0){B=c[(c[q>>2]|0)+(A+z<<2)>>2]|0;do{if((B&4|0)==0){if(!((B&7|0)==0|(B&512|0)==0)){KIb(t,48,2395984,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&1|0)!=0){KIb(t,48,2389032,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&2|0)!=0){KIb(t,48,2382128,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}E=(B&256|0)!=0;F=(B&2048|0)==0;if(!(F|E^1)){KIb(t,48,2375528,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if(E){KIb(t,48,2368856,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}E=(B&1024|0)!=0;if(!(F|E^1)){KIb(t,48,2353896,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if(E){KIb(t,48,2345280,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if(!F){KIb(t,48,2339184,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&49152|0)==0){KIb(t,48,2333560,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&12288|0)==0){KIb(t,48,2328112,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}else{KIb(t,48,2322320,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}}else{KIb(t,48,2402896,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}}while(0);do{if((B&64|0)==0){if((B&16|0)!=0){KIb(t,48,2312760,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&32|0)!=0){KIb(t,48,2308088,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}if((B&15|0)==0){KIb(t,48,2291760,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}else{KIb(t,48,2303024,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}}else{KIb(t,48,2317200,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}}while(0);if((B&128|0)==0){KIb(t,48,2303024,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}else{KIb(t,48,2284952,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break}}}while(0);A=A+1|0;}while((A|0)<(j|0))}KIb(t,48,2280984,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=y+1|0;}while((y|0)<(k|0))}u=c[s>>2]|0}do{if((u&24576|0)==0){if((c[d+692>>2]|0)!=0){break}i=n;return}}while(0);u=m+1|0;m=c[d+120>>2]|0;y=c[d+124>>2]|0;w=c[d+48>>2]|0;t=(w|0)==28;D=(w|0)==24;w=t|D?2:1;x=(j<<w)+((c[(c[r>>2]|0)+12>>2]|0)!=28)|0;c[h>>2]=0;vLa(c[d+140>>2]|0,o,p);cIb(f)|0;c[f+216>>2]=0;o=f|0;h=c[o>>2]|0;r=16>>>((c[p>>2]|0)>>>0);if((k|0)<=0){i=n;return}p=(j|0)>0;C=d+692|0;d=e+1524|0;v=(r|0)>0;A=(t|D)^1;D=w-2|0;t=1<<D;z=w-1|0;F=x<<D;E=x+1<<D;D=f+32|0;H=f+4|0;I=f+36|0;J=f+8|0;K=f+40|0;L=e+1512|0;M=f+88|0;f=0;do{if(p){N=ca(f,l)|0;O=f<<4;P=f<<1;Q=O|8;R=ca(f,r)|0;S=ca(f,x)|0;T=O|4;U=0;do{V=U+N|0;a:do{if((c[C>>2]|0)!=0){if((c[d>>2]|0)==0){break}W=U<<4;X=W|8;Y=U+S|0;Z=Y<<w;_=W|4;$=Y<<1;Y=U<<1;aa=0;while(1){do{if((aa|0)==1){if((c[C>>2]&2|0)==0){ba=76;break}if((c[M>>2]|0)==3){da=0;ba=68}}else if((aa|0)==0){if((c[C>>2]&1|0)==0){ba=76;break}if((c[M>>2]|0)==2){da=0;ba=68}}else if((aa|0)==2){if((c[C>>2]&4|0)==0){break a}if((c[M>>2]|0)==3){da=1;ba=68}}else{da=0;ba=68}}while(0);if((ba|0)==76){ba=0;aa=aa+1|0;continue}do{if((ba|0)==68){ba=0;ea=c[(c[q>>2]|0)+(V<<2)>>2]|0;if((ea&12288<<(da<<1)|0)==0){break}if((ea&64|0)!=0){fa=e+1524+(da<<2)|0;ga=ca(P,x)|0;ha=ga+Y<<z;ia=c[fa>>2]|0;GTa(h,_,T,(b[ia+(ha<<2)>>1]>>u)+_|0,(b[ia+(ha<<2)+2>>1]>>u)+T|0,m,y,c[D>>2]|0);ha=W|12;ia=Y|1;ja=ga+ia<<z;ga=c[fa>>2]|0;GTa(h,ha,T,(b[ga+(ja<<2)>>1]>>u)+ha|0,(b[ga+(ja<<2)+2>>1]>>u)+T|0,m,y,c[D>>2]|0);ja=O|12;ga=ca(P|1,x)|0;ka=ga+Y<<z;la=c[fa>>2]|0;GTa(h,_,ja,(b[la+(ka<<2)>>1]>>u)+_|0,(b[la+(ka<<2)+2>>1]>>u)+ja|0,m,y,c[D>>2]|0);ka=ga+ia<<z;ia=c[fa>>2]|0;GTa(h,ha,ja,(b[ia+(ka<<2)>>1]>>u)+ha|0,(b[ia+(ka<<2)+2>>1]>>u)+ja|0,m,y,c[D>>2]|0);break}if((ea&16|0)!=0){ja=e+1524+(da<<2)|0;ka=(ca(P,x)|0)+Y<<z;ia=c[ja>>2]|0;GTa(h,X,T,(b[ia+(ka<<2)>>1]>>u)+X|0,(b[ia+(ka<<2)+2>>1]>>u<<(ea>>>7&1))+T|0,m,y,c[D>>2]|0);ka=O|12;ia=(ca(P|1,x)|0)+Y<<z;ha=c[ja>>2]|0;GTa(h,X,ka,(b[ha+(ia<<2)>>1]>>u)+X|0,(b[ha+(ia<<2)+2>>1]>>u<<((c[(c[q>>2]|0)+(V<<2)>>2]|0)>>>7&1))+ka|0,m,y,c[D>>2]|0);break}ka=e+1524+(da<<2)|0;if((ea&32|0)==0){ia=c[ka>>2]|0;GTa(h,X,Q,(b[ia+(Z<<2)>>1]>>u)+X|0,(b[ia+(Z<<2)+2>>1]>>u)+Q|0,m,y,c[D>>2]|0);break}else{ia=$<<z;ha=c[ka>>2]|0;GTa(h,_,Q,(b[ha+(ia<<2)>>1]>>u)+_|0,(b[ha+(ia<<2)+2>>1]>>u<<(ea>>>7&1))+Q|0,m,y,c[D>>2]|0);ea=W|12;ia=($|1)<<z;ha=c[ka>>2]|0;GTa(h,ea,Q,(b[ha+(ia<<2)>>1]>>u)+ea|0,(b[ha+(ia<<2)+2>>1]>>u<<((c[(c[q>>2]|0)+(V<<2)>>2]|0)>>>7&1))+Q|0,m,y,c[D>>2]|0);break}}}while(0);aa=aa+1|0;if((aa|0)>=3){break}}}}while(0);aa=c[s>>2]|0;do{if((aa&8192|0)!=0){$=(a[(c[L>>2]|0)+V|0]<<7|0)/31|0;W=Erc($,($|0)<0|0?-1:0,16843009,16843009)|0;$=G;if(!v){break}_=c[H>>2]|0;Z=U<<3;X=c[I>>2]|0;Y=c[J>>2]|0;B=c[K>>2]|0;ia=0;do{ha=ia+R|0;ea=_+((ca(X,ha)|0)+Z)|0;c[ea>>2]=W;c[ea+4>>2]=$;ea=Y+((ca(B,ha)|0)+Z)|0;c[ea>>2]=W;c[ea+4>>2]=$;ia=ia+1|0;}while((ia|0)<(r|0))}}while(0);do{if((aa&16384|0)!=0){if((c[d>>2]|0)==0){break}ia=c[(c[q>>2]|0)+(V<<2)>>2]|0;do{if((ia&4|0)==0){if(!(((ia&7|0)==0|(ia&512|0)==0)&(ia&2|0)==0)){ma=-1751672937;na=-1751672937;oa=-1448498775;pa=-1448498775;break}if((ia&1|0)!=0){ma=-1347440721;na=-1347440721;oa=-2139062144;pa=-2139062144;break}$=(ia&2304|0)==2304;if((ia&256|0)!=0){ma=$?-2139062144:-1734829928;na=$?-2139062144:-1734829928;oa=$?-2139062144:1448498774;pa=$?-2139062144:1448498774;break}$=(ia&1024|0)!=0;W=(ia&3072|0)==3072;if((ia&3072|0)!=0){ma=$?W?-2004318072:2004318071:-2139062144;na=$?W?-2004318072:2004318071:-2139062144;oa=$?1347440720:-2139062144;pa=$?1347440720:-2139062144;break}if((ia&49152|0)==0){ma=1448498774;na=1448498774;oa=1734829927;pa=1734829927;break}$=(ia&12288|0)==0;ma=$?-2139062144:1448498774;na=$?-2139062144:1448498774;oa=$?-1330597712:-1751672937;pa=$?-1330597712:-1751672937}else{ma=-1448498775;na=-1448498775;oa=1751672936;pa=1751672936}}while(0);if(v){$=c[H>>2]|0;W=U<<3;Z=c[I>>2]|0;B=c[J>>2]|0;Y=c[K>>2]|0;X=0;do{_=X+R|0;ea=$+((ca(Z,_)|0)+W)|0;c[ea>>2]=pa;c[ea+4>>2]=oa;ea=B+((ca(Y,_)|0)+W)|0;c[ea>>2]=na;c[ea+4>>2]=ma;X=X+1|0;}while((X|0)<(r|0))}X=(ia&64|0)==0;if((ia&80|0)!=0){W=c[o>>2]|0;Y=U<<4;B=ca(c[D>>2]|0,Q)|0;Z=W+(B+Y)|0;$=c[Z+4>>2]^-2139062144;c[Z>>2]=c[Z>>2]^-2139062144;c[Z+4>>2]=$;$=W+(B+(Y|8))|0;Y=c[$+4>>2]^-2139062144;c[$>>2]=c[$>>2]^-2139062144;c[$+4>>2]=Y}if((ia&96|0)!=0){Y=U<<4|8;$=0;do{B=(ca(c[D>>2]|0,$+O|0)|0)+Y|0;W=(c[o>>2]|0)+B|0;a[W]=a[W]^-128;$=$+1|0;}while(($|0)<16)}if(X|A){break}$=U<<4;Y=U<<1;ia=0;do{W=ia&1;B=W<<3|$;Z=ia>>1;ea=(Z<<3)+O|0;_=(ca(Z+P|0,x)|0)+(W|Y)<<z;W=c[d>>2]|0;Z=W+(_<<2)|0;ha=c[Z>>2]|0;ka=W+(_+t<<2)|0;ja=W+(_+F<<2)|0;if((ha|0)==(c[ka>>2]|0)){if((c[ja>>2]|0)==(c[W+(_+E<<2)>>2]|0)){qa=ha}else{ba=103}}else{ba=103}if((ba|0)==103){ba=0;ha=B|4;fa=(ca(c[D>>2]|0,ea)|0)+ha|0;ga=(c[o>>2]|0)+fa|0;a[ga]=a[ga]^-128;ga=(ca(c[D>>2]|0,ea|1)|0)+ha|0;fa=(c[o>>2]|0)+ga|0;a[fa]=a[fa]^-128;fa=(ca(c[D>>2]|0,ea|2)|0)+ha|0;ga=(c[o>>2]|0)+fa|0;a[ga]=a[ga]^-128;ga=(ca(c[D>>2]|0,ea|3)|0)+ha|0;fa=(c[o>>2]|0)+ga|0;a[fa]=a[fa]^-128;fa=(ca(c[D>>2]|0,ea|4)|0)+ha|0;ga=(c[o>>2]|0)+fa|0;a[ga]=a[ga]^-128;ga=(ca(c[D>>2]|0,ea|5)|0)+ha|0;fa=(c[o>>2]|0)+ga|0;a[fa]=a[fa]^-128;fa=(ca(c[D>>2]|0,ea|6)|0)+ha|0;ga=(c[o>>2]|0)+fa|0;a[ga]=a[ga]^-128;ga=(ca(c[D>>2]|0,ea|7)|0)+ha|0;ha=(c[o>>2]|0)+ga|0;a[ha]=a[ha]^-128;qa=c[Z>>2]|0}if((qa|0)==(c[ja>>2]|0)){if((c[ka>>2]|0)!=(c[W+(_+E<<2)>>2]|0)){ba=106}}else{ba=106}if((ba|0)==106){ba=0;_=(c[o>>2]|0)+((ca(c[D>>2]|0,ea|4)|0)+B)|0;B=c[_+4>>2]^-2139062144;c[_>>2]=c[_>>2]^-2139062144;c[_+4>>2]=B}ia=ia+1|0;}while((ia|0)<4)}}while(0);a[g+V|0]=0;U=U+1|0;}while((U|0)<(j|0))}f=f+1|0;}while((f|0)<(k|0));i=n;return}function GTa(a,b,e,f,g,h,i,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=h+100|0;if((b|0)<-100){l=-100}else{l=(k|0)<(b|0)?k:b}b=i+100|0;if((e|0)<-100){m=-100}else{m=(b|0)<(e|0)?b:e}if((f|0)<-100){n=-100}else{n=(k|0)<(f|0)?k:f}if((g|0)<-100){o=-100}else{o=(b|0)<(g|0)?b:g}g=n-l|0;b=o-m|0;if(((ca(b,b)|0)+(ca(g,g)|0)|0)<=9){UTa(a,l,m,n,o,h,i,j);return}f=b+g|0;k=b-g|0;g=(ca(f,f)|0)+(ca(k,k)|0)|0;b=g<<8;if(b>>>0<255>>>0){p=(d[1303320+(b|1)|0]|0)-1>>4}else{do{if(b>>>0<4096>>>0){q=(d[1303320+(g<<4&268435440)|0]|0)>>>2}else{if(b>>>0<16384>>>0){q=(d[1303320+(g<<2&67108860)|0]|0)>>>1;break}if(b>>>0<65536>>>0){q=d[1303320+(g&16777215)|0]|0;break}else{e=g>>>8;r=(e&65280|0)==0;s=((d[1359664+(r?e&65535:g>>>16&255)|0]|0)+(r?0:8)|0)>>>1;r=b>>>((s+2|0)>>>0);e=d[1303320+(r>>>((s+8|0)>>>0))|0]|0;Erc(r,0,c[1367848+(e<<2)>>2]|0,0)|0;q=G+(e<<s)|0;break}}}while(0);p=q-((ca(q,q)|0)>>>0>b>>>0)|0}b=f*48|0;f=p>>1;q=-f|0;g=(((b|0)>0?f:q)+b|0)/(p|0)|0;b=k*48|0;k=(((b|0)>0?f:q)+b|0)/(p|0)|0;UTa(a,l,m,g+l|0,k+m|0,h,i,j);UTa(a,l,m,l-k|0,g+m|0,h,i,j);UTa(a,l,m,n,o,h,i,j);return}function HTa(a,b,d){a=a|0;b=b|0;d=d|0;FTa(c[a+4>>2]|0,b,d,c[a+9928>>2]|0,a+13944|0,c[a+116>>2]|0,c[a+120>>2]|0,c[a+124>>2]|0,c[a+13924>>2]|0);return}function ITa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=eGb(c[d+1508>>2]|0)|0;d=a+124|0;a=c[d>>2]|0;h=a<<1|1;if((g|0)==0){j=-12;i=f;return j|0}k=g+8|0;l=c[k>>2]|0;if((l|0)<((ca(((c[b+72>>2]|0)+15|0)/16|0,a)|0)+h|0)){KIb(0,0,2502120,(a=i,i=i+24|0,c[a>>2]=2276888,c[a+8>>2]=2449704,c[a+16>>2]=2272,a)|0);i=a;Hd();return 0}c[k>>2]=l-h;l=g+4|0;c[l>>2]=(c[l>>2]|0)+h;j=RHb(b,g,c[d>>2]|0,e)|0;i=f;return j|0}function JTa(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[d+128>>2]|0;f=c[d+12496>>2]|0;g=f+1|0;h=g+e|0;i=c[d+9876>>2]|0;b[i+(h<<1)>>1]=1024;j=f+e|0;b[i+(j<<1)>>1]=1024;b[i+(g<<1)>>1]=1024;b[i+(f<<1)>>1]=1024;i=d+9912|0;mrc((c[i>>2]|0)+(f<<5)|0,0,64)|0;mrc((c[i>>2]|0)+(j<<5)|0,0,64)|0;if((c[d+14092>>2]|0)>2){i=d+9904|0;a[(c[i>>2]|0)+h|0]=0;a[(c[i>>2]|0)+j|0]=0;a[(c[i>>2]|0)+g|0]=0;a[(c[i>>2]|0)+f|0]=0}f=(ca(c[d+12480>>2]|0,c[d+124>>2]|0)|0)+(c[d+12476>>2]|0)|0;b[(c[d+9884>>2]|0)+(f<<1)>>1]=1024;b[(c[d+9880>>2]|0)+(f<<1)>>1]=1024;mrc((c[d+9916>>2]|0)+(f<<5)|0,0,32)|0;mrc((c[d+9920>>2]|0)+(f<<5)|0,0,32)|0;a[(c[d+9932>>2]|0)+f|0]=0;return}function KTa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;g=i;h=e+4|0;j=c[h>>2]|0;k=(c[j+800>>2]|0)!=0;l=c[e+12480>>2]|0;m=ca(c[e+124>>2]|0,l)|0;n=c[e+12476>>2]|0;o=m+n|0;m=(c[j+688>>2]&64|0)==0;if((c[e+28>>2]|0)==0){if(!k){if(!m){KIb(j,48,2272416,(p=i,i=i+16|0,c[p>>2]=n,c[p+8>>2]=l,p)|0);i=p;q=0;r=c[h>>2]|0;do{KIb(r,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+(d[e+11184+q|0]<<1)>>1]|0,p)|0);i=p;q=q+1|0;r=c[h>>2]|0}while((q|0)<64);KIb(r,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;r=0;q=c[h>>2]|0;do{KIb(q,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+128+(d[e+11184+r|0]<<1)>>1]|0,p)|0);i=p;r=r+1|0;q=c[h>>2]|0}while((r|0)<64);KIb(q,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=0;r=c[h>>2]|0;do{KIb(r,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+256+(d[e+11184+q|0]<<1)>>1]|0,p)|0);i=p;q=q+1|0;r=c[h>>2]|0}while((q|0)<64);KIb(r,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;r=0;q=c[h>>2]|0;do{KIb(q,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+384+(d[e+11184+r|0]<<1)>>1]|0,p)|0);i=p;r=r+1|0;q=c[h>>2]|0}while((r|0)<64);KIb(q,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=0;r=c[h>>2]|0;do{KIb(r,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+512+(d[e+11184+q|0]<<1)>>1]|0,p)|0);i=p;q=q+1|0;r=c[h>>2]|0}while((q|0)<64);KIb(r,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;r=0;q=c[h>>2]|0;do{KIb(q,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+640+(d[e+11184+r|0]<<1)>>1]|0,p)|0);i=p;r=r+1|0;q=c[h>>2]|0}while((r|0)<64);KIb(q,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}q=e+9960|0;a[(c[e+9136>>2]|0)+o|0]=c[q>>2];r=e+12488|0;if((c[r>>2]|0)==0){s=128<<c[e+14176>>2];c[e+9868>>2]=s;c[e+9864>>2]=s;c[e+9860>>2]=s}do{if((c[e+60>>2]&32768|0)==0){s=c[h>>2]|0;if((c[s+584>>2]|0)!=0){break}if((c[s+588>>2]|0)!=0){break}if((c[e+56>>2]|0)==0){break}if((c[e+20>>2]|0)==0){if((c[e+9992>>2]|0)!=3){break}}if((c[s+296>>2]|0)==2){break}i=g;return}}while(0);s=c[e+7656>>2]|0;t=c[e+7660>>2]|0;u=e+9992|0;v=c[e+56>>2]|0;do{if((c[u>>2]|0)==3){if((v|0)==0){w=(c[(c[h>>2]|0)+148>>2]|0)!=0;x=e+56|0;y=130;break}else{z=e+56|0;y=134;break}}else{A=e+56|0;if((v|0)==0){w=1;x=A;y=130}else{z=A;y=134}}}while(0);a:do{if((y|0)==130){v=(c[e+9928>>2]|0)+o|0;A=e+9924|0;do{if((c[A>>2]|0)==0){if((c[e+9816>>2]|0)==0){a[v]=1;B=e+14236|0;C=c[B>>2]|0;D=s<<C;E=(C|0)==0?s<<3:s;if(w){F=x;G=B;H=D;I=E;y=136;break a}else{J=B;K=D;L=E;break}}else{a[v]=0;E=e+14236|0;D=c[E>>2]|0;B=s<<D;C=(D|0)==0?s<<3:s;if(w){F=x;G=E;H=B;I=C;y=136;break a}else{J=E;K=B;L=C;break}}}else{c[A>>2]=0;a[v]=1;C=e+14236|0;B=c[C>>2]|0;E=s<<B;D=(B|0)==0?s<<3:s;if(w){F=x;G=C;H=E;I=D;y=136;break a}else{J=C;K=E;L=D}}}while(0);v=c[e+9956>>2]|0;M=v;N=v+(s<<4)|0;O=v+(s<<5)|0;P=x;Q=0;R=J;S=K;T=L}else if((y|0)==134){v=e+14236|0;A=c[v>>2]|0;F=z;G=v;H=s<<A;I=(A|0)==0?s<<3:s;y=136}}while(0);if((y|0)==136){M=c[e+12544>>2]|0;N=c[e+12548>>2]|0;O=c[e+12552>>2]|0;P=F;Q=1;R=G;S=H;T=I}I=(c[P>>2]|0)!=0;b:do{if((c[r>>2]|0)==0){do{if(!I){H=c[e+12452>>2]|0;do{if((c[e+12472>>2]|0)==0){y=142}else{if((c[u>>2]|0)==3){y=142;break}U=e+11460|0}}while(0);if((y|0)==142){U=e+11332|0}G=e+11736|0;F=c[G>>2]|0;if((F&1|0)==0){V=H;W=U;X=F}else{mUa(e,M,N,O,0,e+952|0,U,H);V=c[e+12456>>2]|0;W=e+11396|0;X=c[G>>2]|0}if((X&2|0)==0){break}mUa(e,M,N,O,1,e+3176|0,W,V)}}while(0);G=c[(c[h>>2]|0)+852>>2]|0;do{if((G|0)>7){F=c[u>>2]|0;if((F|0)==3){break b}if((G|0)<=31){break}if((F|0)!=1|(G|0)>47){break b}}}while(0);c:do{if((c[P>>2]|0)==0){do{if((c[e+14092>>2]|0)==0){G=c[e+48>>2]|0;if((G|0)==1|(G|0)==2){break}else if((G|0)!=13){break c}if((c[e+14004>>2]|0)!=0){break c}}}while(0);if((c[e+180>>2]|0)>-1){ef[c[e+11180>>2]&4095](M,S,f|0)}if((c[e+184>>2]|0)>-1){ef[c[e+11180>>2]&4095](M+8|0,S,f+128|0)}if((c[e+188>>2]|0)>-1){ef[c[e+11180>>2]&4095](M+T|0,S,f+256|0)}if((c[e+192>>2]|0)>-1){ef[c[e+11180>>2]&4095](M+(T+8)|0,S,f+384|0)}if((c[e+14220>>2]|0)!=0){if((c[e+196>>2]|0)>-1){ef[c[e+11180>>2]&4095](N,t,f+512|0)}if(!((c[e+200>>2]|0)>-1)){break b}ef[c[e+11180>>2]&4095](O,t,f+640|0);break b}H=c[R>>2]|0;G=t<<H;F=(H|0)==0?t<<3:t;if((c[e+196>>2]|0)>-1){ef[c[e+11180>>2]&4095](N,G,f+512|0)}if((c[e+200>>2]|0)>-1){ef[c[e+11180>>2]&4095](O,G,f+640|0)}if((c[e+204>>2]|0)>-1){ef[c[e+11180>>2]&4095](N+F|0,G,f+768|0)}if((c[e+208>>2]|0)>-1){ef[c[e+11180>>2]&4095](O+F|0,G,f+896|0)}if((c[e+14216>>2]|0)!=0){break b}if((c[e+212>>2]|0)>-1){ef[c[e+11180>>2]&4095](N+8|0,G,f+1024|0)}if((c[e+216>>2]|0)>-1){ef[c[e+11180>>2]&4095](O+8|0,G,f+1152|0)}H=F+8|0;if((c[e+220>>2]|0)>-1){ef[c[e+11180>>2]&4095](N+H|0,G,f+1280|0)}if(!((c[e+224>>2]|0)>-1)){break b}ef[c[e+11180>>2]&4095](O+H|0,G,f+1408|0);break b}}while(0);G=f|0;if((c[e+180>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,G,0,c[q>>2]|0);ef[c[e+11180>>2]&4095](M,S,G)}G=f+128|0;if((c[e+184>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,G,1,c[q>>2]|0);ef[c[e+11180>>2]&4095](M+8|0,S,G)}G=f+256|0;if((c[e+188>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,G,2,c[q>>2]|0);ef[c[e+11180>>2]&4095](M+T|0,S,G)}G=f+384|0;if((c[e+192>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,G,3,c[q>>2]|0);ef[c[e+11180>>2]&4095](M+(T+8)|0,S,G)}if((c[e+14220>>2]|0)!=0){G=f+512|0;H=e+9964|0;if((c[e+196>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,G,4,c[H>>2]|0);ef[c[e+11180>>2]&4095](N,t,G)}G=f+640|0;if(!((c[e+200>>2]|0)>-1)){break}mf[c[e+14388>>2]&2047](e,G,5,c[H>>2]|0);ef[c[e+11180>>2]&4095](O,t,G);break}G=S>>1;H=T>>1;F=f+512|0;z=e+9964|0;if((c[e+196>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,F,4,c[z>>2]|0);ef[c[e+11180>>2]&4095](N,G,F)}F=f+640|0;if((c[e+200>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,F,5,c[z>>2]|0);ef[c[e+11180>>2]&4095](O,G,F)}F=f+768|0;if((c[e+204>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,F,6,c[z>>2]|0);ef[c[e+11180>>2]&4095](N+H|0,G,F)}F=f+896|0;if(!((c[e+208>>2]|0)>-1)){break}mf[c[e+14388>>2]&2047](e,F,7,c[z>>2]|0);ef[c[e+11180>>2]&4095](O+H|0,G,F)}else{do{if(!I){if(!(((c[e+48>>2]|0)-1|0)>>>0<2>>>0)){break}F=e+11176|0;ef[c[F>>2]&4095](M,S,f|0);ef[c[F>>2]&4095](M+8|0,S,f+128|0);ef[c[F>>2]&4095](M+T|0,S,f+256|0);ef[c[F>>2]&4095](M+(T+8)|0,S,f+384|0);if((c[e+14220>>2]|0)!=0){ef[c[F>>2]&4095](N,t,f+512|0);ef[c[F>>2]&4095](O,t,f+640|0);break b}G=c[R>>2]|0;H=t<<G;z=(G|0)==0?t<<3:t;ef[c[F>>2]&4095](N,H,f+512|0);ef[c[F>>2]&4095](O,H,f+640|0);ef[c[F>>2]&4095](N+z|0,H,f+768|0);ef[c[F>>2]&4095](O+z|0,H,f+896|0);if((c[e+14216>>2]|0)!=0){break b}ef[c[F>>2]&4095](N+8|0,H,f+1024|0);ef[c[F>>2]&4095](O+8|0,H,f+1152|0);G=z+8|0;ef[c[F>>2]&4095](N+G|0,H,f+1280|0);ef[c[F>>2]&4095](O+G|0,H,f+1408|0);break b}}while(0);H=f|0;G=e+14384|0;mf[c[G>>2]&2047](e,H,0,c[q>>2]|0);F=e+11176|0;ef[c[F>>2]&4095](M,S,H);H=f+128|0;mf[c[G>>2]&2047](e,H,1,c[q>>2]|0);ef[c[F>>2]&4095](M+8|0,S,H);H=f+256|0;mf[c[G>>2]&2047](e,H,2,c[q>>2]|0);ef[c[F>>2]&4095](M+T|0,S,H);H=f+384|0;mf[c[G>>2]&2047](e,H,3,c[q>>2]|0);ef[c[F>>2]&4095](M+(T+8)|0,S,H);if((c[e+14220>>2]|0)==0){H=T>>1;z=S>>1;L=f+512|0;K=e+9964|0;mf[c[G>>2]&2047](e,L,4,c[K>>2]|0);ef[c[F>>2]&4095](N,z,L);L=f+640|0;mf[c[G>>2]&2047](e,L,5,c[K>>2]|0);ef[c[F>>2]&4095](O,z,L);L=f+768|0;mf[c[G>>2]&2047](e,L,6,c[K>>2]|0);ef[c[F>>2]&4095](N+H|0,z,L);L=f+896|0;mf[c[G>>2]&2047](e,L,7,c[K>>2]|0);ef[c[F>>2]&4095](O+H|0,z,L);break}else{L=f+512|0;z=e+9964|0;mf[c[G>>2]&2047](e,L,4,c[z>>2]|0);ef[c[F>>2]&4095](N,t,L);L=f+640|0;mf[c[G>>2]&2047](e,L,5,c[z>>2]|0);ef[c[F>>2]&4095](O,t,L);break}}}while(0);if(Q){i=g;return}mf[c[e+11332>>2]&2047](c[e+12544>>2]|0,M,s,16);s=e+14216|0;M=e+14220|0;mf[c[e+11332+(c[s>>2]<<4)>>2]&2047](c[e+12548>>2]|0,N,t,16>>>((c[M>>2]|0)>>>0));mf[c[e+11332+(c[s>>2]<<4)>>2]&2047](c[e+12552>>2]|0,O,t,16>>>((c[M>>2]|0)>>>0));i=g;return}if(!m){KIb(j,48,2272416,(p=i,i=i+16|0,c[p>>2]=n,c[p+8>>2]=l,p)|0);i=p;M=0;t=c[h>>2]|0;do{KIb(t,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+(d[e+11184+M|0]<<1)>>1]|0,p)|0);i=p;M=M+1|0;t=c[h>>2]|0}while((M|0)<64);KIb(t,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=0;M=c[h>>2]|0;do{KIb(M,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+128+(d[e+11184+t|0]<<1)>>1]|0,p)|0);i=p;t=t+1|0;M=c[h>>2]|0}while((t|0)<64);KIb(M,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;M=0;t=c[h>>2]|0;do{KIb(t,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+256+(d[e+11184+M|0]<<1)>>1]|0,p)|0);i=p;M=M+1|0;t=c[h>>2]|0}while((M|0)<64);KIb(t,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=0;M=c[h>>2]|0;do{KIb(M,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+384+(d[e+11184+t|0]<<1)>>1]|0,p)|0);i=p;t=t+1|0;M=c[h>>2]|0}while((t|0)<64);KIb(M,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;M=0;t=c[h>>2]|0;do{KIb(t,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+512+(d[e+11184+M|0]<<1)>>1]|0,p)|0);i=p;M=M+1|0;t=c[h>>2]|0}while((M|0)<64);KIb(t,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;t=0;M=c[h>>2]|0;do{KIb(M,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+640+(d[e+11184+t|0]<<1)>>1]|0,p)|0);i=p;t=t+1|0;M=c[h>>2]|0}while((t|0)<64);KIb(M,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}M=e+9960|0;a[(c[e+9136>>2]|0)+o|0]=c[M>>2];t=e+12488|0;if((c[t>>2]|0)==0){O=128<<c[e+14176>>2];c[e+9868>>2]=O;c[e+9864>>2]=O;c[e+9860>>2]=O}O=c[h>>2]|0;do{if((c[e+60>>2]&32768|0)==0){if((c[O+584>>2]|0)!=0){break}if((c[O+588>>2]|0)!=0){break}if((c[e+56>>2]|0)==0){break}if((c[e+20>>2]|0)==0){if((c[e+9992>>2]|0)!=3){break}}if((c[O+296>>2]|0)==2){break}i=g;return}}while(0);s=c[e+7656>>2]|0;N=c[e+7660>>2]|0;Q=e+9992|0;S=8>>>((c[O+800>>2]|0)>>>0);O=e+56|0;do{if((c[O>>2]|0)==0){T=(c[e+9928>>2]|0)+o|0;q=e+9924|0;if((c[q>>2]|0)!=0){c[q>>2]=0;a[T]=1;break}if((c[e+9816>>2]|0)==0){a[T]=1;break}else{a[T]=0;break}}}while(0);T=e+14236|0;q=c[T>>2]|0;R=s<<q;if((q|0)==0){Y=ca(S,s)|0}else{Y=s}s=c[e+12544>>2]|0;q=c[e+12548>>2]|0;I=c[e+12552>>2]|0;P=(c[O>>2]|0)!=0;if((c[t>>2]|0)!=0){do{if(!P){if(!(((c[e+48>>2]|0)-1|0)>>>0<2>>>0)){break}t=e+11176|0;ef[c[t>>2]&4095](s,R,f|0);ef[c[t>>2]&4095](s+S|0,R,f+128|0);ef[c[t>>2]&4095](s+Y|0,R,f+256|0);ef[c[t>>2]&4095](s+(Y+S)|0,R,f+384|0);if((c[e+14220>>2]|0)!=0){ef[c[t>>2]&4095](q,N,f+512|0);ef[c[t>>2]&4095](I,N,f+640|0);i=g;return}u=c[T>>2]|0;V=N<<u;if((u|0)==0){Z=ca(S,N)|0}else{Z=N}ef[c[t>>2]&4095](q,V,f+512|0);ef[c[t>>2]&4095](I,V,f+640|0);ef[c[t>>2]&4095](q+Z|0,V,f+768|0);ef[c[t>>2]&4095](I+Z|0,V,f+896|0);if((c[e+14216>>2]|0)!=0){i=g;return}ef[c[t>>2]&4095](q+S|0,V,f+1024|0);ef[c[t>>2]&4095](I+S|0,V,f+1152|0);u=Z+S|0;ef[c[t>>2]&4095](q+u|0,V,f+1280|0);ef[c[t>>2]&4095](I+u|0,V,f+1408|0);i=g;return}}while(0);Z=f|0;V=e+14384|0;mf[c[V>>2]&2047](e,Z,0,c[M>>2]|0);u=e+11176|0;ef[c[u>>2]&4095](s,R,Z);Z=f+128|0;mf[c[V>>2]&2047](e,Z,1,c[M>>2]|0);ef[c[u>>2]&4095](s+S|0,R,Z);Z=f+256|0;mf[c[V>>2]&2047](e,Z,2,c[M>>2]|0);ef[c[u>>2]&4095](s+Y|0,R,Z);Z=f+384|0;mf[c[V>>2]&2047](e,Z,3,c[M>>2]|0);ef[c[u>>2]&4095](s+(Y+S)|0,R,Z);if((c[e+14220>>2]|0)==0){Z=Y>>1;t=R>>1;W=f+512|0;X=e+9964|0;mf[c[V>>2]&2047](e,W,4,c[X>>2]|0);ef[c[u>>2]&4095](q,t,W);W=f+640|0;mf[c[V>>2]&2047](e,W,5,c[X>>2]|0);ef[c[u>>2]&4095](I,t,W);W=f+768|0;mf[c[V>>2]&2047](e,W,6,c[X>>2]|0);ef[c[u>>2]&4095](q+Z|0,t,W);W=f+896|0;mf[c[V>>2]&2047](e,W,7,c[X>>2]|0);ef[c[u>>2]&4095](I+Z|0,t,W);i=g;return}else{W=f+512|0;t=e+9964|0;mf[c[V>>2]&2047](e,W,4,c[t>>2]|0);ef[c[u>>2]&4095](q,N,W);W=f+640|0;mf[c[V>>2]&2047](e,W,5,c[t>>2]|0);ef[c[u>>2]&4095](I,N,W);i=g;return}}do{if(!P){W=e+11300|0;u=e+11736|0;t=c[u>>2]|0;if((t&1|0)==0){_=W;$=t}else{TTa(e,s,q,I,0,e+952|0,W);_=e+11316|0;$=c[u>>2]|0}if(($&2|0)==0){break}TTa(e,s,q,I,1,e+3176|0,_)}}while(0);_=c[(c[h>>2]|0)+852>>2]|0;do{if((_|0)>7){$=c[Q>>2]|0;if(($|0)==3){i=g;return}if((_|0)<=31){break}if(!(($|0)!=1|(_|0)>47)){break}i=g;return}}while(0);d:do{if((c[O>>2]|0)==0){do{if((c[e+14092>>2]|0)==0){_=c[e+48>>2]|0;if((_|0)==1|(_|0)==2){break}else if((_|0)!=13){break d}if((c[e+14004>>2]|0)!=0){break d}}}while(0);if((c[e+180>>2]|0)>-1){ef[c[e+11180>>2]&4095](s,R,f|0)}if((c[e+184>>2]|0)>-1){ef[c[e+11180>>2]&4095](s+S|0,R,f+128|0)}if((c[e+188>>2]|0)>-1){ef[c[e+11180>>2]&4095](s+Y|0,R,f+256|0)}if((c[e+192>>2]|0)>-1){ef[c[e+11180>>2]&4095](s+(Y+S)|0,R,f+384|0)}if((c[e+14220>>2]|0)!=0){if((c[e+196>>2]|0)>-1){ef[c[e+11180>>2]&4095](q,N,f+512|0)}if(!((c[e+200>>2]|0)>-1)){i=g;return}ef[c[e+11180>>2]&4095](I,N,f+640|0);i=g;return}_=c[T>>2]|0;Q=N<<_;if((_|0)==0){aa=ca(S,N)|0}else{aa=N}if((c[e+196>>2]|0)>-1){ef[c[e+11180>>2]&4095](q,Q,f+512|0)}if((c[e+200>>2]|0)>-1){ef[c[e+11180>>2]&4095](I,Q,f+640|0)}if((c[e+204>>2]|0)>-1){ef[c[e+11180>>2]&4095](q+aa|0,Q,f+768|0)}if((c[e+208>>2]|0)>-1){ef[c[e+11180>>2]&4095](I+aa|0,Q,f+896|0)}if((c[e+14216>>2]|0)!=0){i=g;return}if((c[e+212>>2]|0)>-1){ef[c[e+11180>>2]&4095](q+S|0,Q,f+1024|0)}if((c[e+216>>2]|0)>-1){ef[c[e+11180>>2]&4095](I+S|0,Q,f+1152|0)}_=aa+S|0;if((c[e+220>>2]|0)>-1){ef[c[e+11180>>2]&4095](q+_|0,Q,f+1280|0)}if(!((c[e+224>>2]|0)>-1)){i=g;return}ef[c[e+11180>>2]&4095](I+_|0,Q,f+1408|0);i=g;return}}while(0);aa=f|0;if((c[e+180>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,aa,0,c[M>>2]|0);ef[c[e+11180>>2]&4095](s,R,aa)}aa=f+128|0;if((c[e+184>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,aa,1,c[M>>2]|0);ef[c[e+11180>>2]&4095](s+S|0,R,aa)}aa=f+256|0;if((c[e+188>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,aa,2,c[M>>2]|0);ef[c[e+11180>>2]&4095](s+Y|0,R,aa)}aa=f+384|0;if((c[e+192>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,aa,3,c[M>>2]|0);ef[c[e+11180>>2]&4095](s+(Y+S)|0,R,aa)}if((c[e+14220>>2]|0)!=0){aa=f+512|0;S=e+9964|0;if((c[e+196>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,aa,4,c[S>>2]|0);ef[c[e+11180>>2]&4095](q,N,aa)}aa=f+640|0;if(!((c[e+200>>2]|0)>-1)){i=g;return}mf[c[e+14388>>2]&2047](e,aa,5,c[S>>2]|0);ef[c[e+11180>>2]&4095](I,N,aa);i=g;return}aa=R>>1;R=Y>>1;Y=f+512|0;N=e+9964|0;if((c[e+196>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,Y,4,c[N>>2]|0);ef[c[e+11180>>2]&4095](q,aa,Y)}Y=f+640|0;if((c[e+200>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,Y,5,c[N>>2]|0);ef[c[e+11180>>2]&4095](I,aa,Y)}Y=f+768|0;if((c[e+204>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,Y,6,c[N>>2]|0);ef[c[e+11180>>2]&4095](q+R|0,aa,Y)}Y=f+896|0;if(!((c[e+208>>2]|0)>-1)){i=g;return}mf[c[e+14388>>2]&2047](e,Y,7,c[N>>2]|0);ef[c[e+11180>>2]&4095](I+R|0,aa,Y);i=g;return}if(!k){if(!m){KIb(j,48,2272416,(p=i,i=i+16|0,c[p>>2]=n,c[p+8>>2]=l,p)|0);i=p;k=0;Y=c[h>>2]|0;do{KIb(Y,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+(d[e+11184+k|0]<<1)>>1]|0,p)|0);i=p;k=k+1|0;Y=c[h>>2]|0}while((k|0)<64);KIb(Y,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Y=0;k=c[h>>2]|0;do{KIb(k,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+128+(d[e+11184+Y|0]<<1)>>1]|0,p)|0);i=p;Y=Y+1|0;k=c[h>>2]|0}while((Y|0)<64);KIb(k,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=0;Y=c[h>>2]|0;do{KIb(Y,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+256+(d[e+11184+k|0]<<1)>>1]|0,p)|0);i=p;k=k+1|0;Y=c[h>>2]|0}while((k|0)<64);KIb(Y,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Y=0;k=c[h>>2]|0;do{KIb(k,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+384+(d[e+11184+Y|0]<<1)>>1]|0,p)|0);i=p;Y=Y+1|0;k=c[h>>2]|0}while((Y|0)<64);KIb(k,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;k=0;Y=c[h>>2]|0;do{KIb(Y,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+512+(d[e+11184+k|0]<<1)>>1]|0,p)|0);i=p;k=k+1|0;Y=c[h>>2]|0}while((k|0)<64);KIb(Y,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Y=0;k=c[h>>2]|0;do{KIb(k,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+640+(d[e+11184+Y|0]<<1)>>1]|0,p)|0);i=p;Y=Y+1|0;k=c[h>>2]|0}while((Y|0)<64);KIb(k,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}k=e+9960|0;a[(c[e+9136>>2]|0)+o|0]=c[k>>2];Y=e+12488|0;aa=(c[e+32>>2]|0)==0;e:do{if((c[Y>>2]|0)==0){do{if(aa){if((c[e+228>>2]|0)!=0){break}R=128<<c[e+14176>>2];c[e+9868>>2]=R;c[e+9864>>2]=R;c[e+9860>>2]=R;break e}}while(0);if((a[(c[e+9932>>2]|0)+o|0]|0)==0){break}JTa(e)}else{if(aa){if((c[e+228>>2]|0)==0){break}}a[(c[e+9932>>2]|0)+o|0]=1}}while(0);do{if((c[e+60>>2]&32768|0)==0){aa=c[h>>2]|0;if((c[aa+584>>2]|0)!=0){break}if((c[aa+588>>2]|0)!=0){break}if((c[e+56>>2]|0)==0){break}if((c[e+20>>2]|0)==0){if((c[e+9992>>2]|0)!=3){break}}if((c[aa+296>>2]|0)==2){break}i=g;return}}while(0);aa=c[e+7656>>2]|0;R=c[e+7660>>2]|0;I=e+9992|0;N=c[e+56>>2]|0;do{if((c[I>>2]|0)==3){if((N|0)==0){ba=(c[(c[h>>2]|0)+148>>2]|0)!=0;da=e+56|0;y=372;break}else{ea=e+56|0;y=376;break}}else{q=e+56|0;if((N|0)==0){ba=1;da=q;y=372}else{ea=q;y=376}}}while(0);f:do{if((y|0)==372){N=(c[e+9928>>2]|0)+o|0;q=e+9924|0;do{if((c[q>>2]|0)==0){if((c[e+9816>>2]|0)==0){a[N]=1;S=e+14236|0;s=c[S>>2]|0;M=aa<<s;T=(s|0)==0?aa<<3:aa;if(ba){fa=da;ga=S;ha=M;ia=T;y=378;break f}else{ja=S;ka=M;la=T;break}}else{a[N]=0;T=e+14236|0;M=c[T>>2]|0;S=aa<<M;s=(M|0)==0?aa<<3:aa;if(ba){fa=da;ga=T;ha=S;ia=s;y=378;break f}else{ja=T;ka=S;la=s;break}}}else{c[q>>2]=0;a[N]=1;s=e+14236|0;S=c[s>>2]|0;T=aa<<S;M=(S|0)==0?aa<<3:aa;if(ba){fa=da;ga=s;ha=T;ia=M;y=378;break f}else{ja=s;ka=T;la=M}}}while(0);N=c[e+9956>>2]|0;ma=N;na=N+(aa<<4)|0;oa=N+(aa<<5)|0;pa=da;qa=0;ra=ja;sa=ka;ta=la}else if((y|0)==376){N=e+14236|0;q=c[N>>2]|0;fa=ea;ga=N;ha=aa<<q;ia=(q|0)==0?aa<<3:aa;y=378}}while(0);if((y|0)==378){ma=c[e+12544>>2]|0;na=c[e+12548>>2]|0;oa=c[e+12552>>2]|0;pa=fa;qa=1;ra=ga;sa=ha;ta=ia}ia=(c[pa>>2]|0)!=0;g:do{if((c[Y>>2]|0)==0){do{if(!ia){ha=c[e+12452>>2]|0;do{if((c[e+12472>>2]|0)==0){y=384}else{if((c[I>>2]|0)==3){y=384;break}ua=e+11460|0}}while(0);if((y|0)==384){ua=e+11332|0}ga=e+11736|0;fa=c[ga>>2]|0;if((fa&1|0)==0){va=ha;wa=ua;xa=fa}else{mUa(e,ma,na,oa,0,e+952|0,ua,ha);va=c[e+12456>>2]|0;wa=e+11396|0;xa=c[ga>>2]|0}if((xa&2|0)==0){break}mUa(e,ma,na,oa,1,e+3176|0,wa,va)}}while(0);ga=c[(c[h>>2]|0)+852>>2]|0;do{if((ga|0)>7){fa=c[I>>2]|0;if((fa|0)==3){break g}if((ga|0)<=31){break}if((fa|0)!=1|(ga|0)>47){break g}}}while(0);h:do{if((c[pa>>2]|0)==0){ga=c[e+48>>2]|0;do{if((c[e+14092>>2]|0)==0){if((ga|0)==1|(ga|0)==2){break}else if((ga|0)!=13){break h}if((c[e+14004>>2]|0)!=0){break h}}else{if((ga|0)!=19){break}Fhb(e,f,ma,na,oa);break g}}while(0);if((c[e+180>>2]|0)>-1){ef[c[e+11180>>2]&4095](ma,sa,f|0)}if((c[e+184>>2]|0)>-1){ef[c[e+11180>>2]&4095](ma+8|0,sa,f+128|0)}if((c[e+188>>2]|0)>-1){ef[c[e+11180>>2]&4095](ma+ta|0,sa,f+256|0)}if((c[e+192>>2]|0)>-1){ef[c[e+11180>>2]&4095](ma+(ta+8)|0,sa,f+384|0)}if((c[e+14220>>2]|0)!=0){if((c[e+196>>2]|0)>-1){ef[c[e+11180>>2]&4095](na,R,f+512|0)}if(!((c[e+200>>2]|0)>-1)){break g}ef[c[e+11180>>2]&4095](oa,R,f+640|0);break g}ga=c[ra>>2]|0;ha=R<<ga;fa=(ga|0)==0?R<<3:R;if((c[e+196>>2]|0)>-1){ef[c[e+11180>>2]&4095](na,ha,f+512|0)}if((c[e+200>>2]|0)>-1){ef[c[e+11180>>2]&4095](oa,ha,f+640|0)}if((c[e+204>>2]|0)>-1){ef[c[e+11180>>2]&4095](na+fa|0,ha,f+768|0)}if((c[e+208>>2]|0)>-1){ef[c[e+11180>>2]&4095](oa+fa|0,ha,f+896|0)}if((c[e+14216>>2]|0)!=0){break g}if((c[e+212>>2]|0)>-1){ef[c[e+11180>>2]&4095](na+8|0,ha,f+1024|0)}if((c[e+216>>2]|0)>-1){ef[c[e+11180>>2]&4095](oa+8|0,ha,f+1152|0)}ga=fa+8|0;if((c[e+220>>2]|0)>-1){ef[c[e+11180>>2]&4095](na+ga|0,ha,f+1280|0)}if(!((c[e+224>>2]|0)>-1)){break g}ef[c[e+11180>>2]&4095](oa+ga|0,ha,f+1408|0);break g}}while(0);ha=f|0;if((c[e+180>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,ha,0,c[k>>2]|0);ef[c[e+11180>>2]&4095](ma,sa,ha)}ha=f+128|0;if((c[e+184>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,ha,1,c[k>>2]|0);ef[c[e+11180>>2]&4095](ma+8|0,sa,ha)}ha=f+256|0;if((c[e+188>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,ha,2,c[k>>2]|0);ef[c[e+11180>>2]&4095](ma+ta|0,sa,ha)}ha=f+384|0;if((c[e+192>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,ha,3,c[k>>2]|0);ef[c[e+11180>>2]&4095](ma+(ta+8)|0,sa,ha)}if((c[e+14220>>2]|0)!=0){ha=f+512|0;ga=e+9964|0;if((c[e+196>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,ha,4,c[ga>>2]|0);ef[c[e+11180>>2]&4095](na,R,ha)}ha=f+640|0;if(!((c[e+200>>2]|0)>-1)){break}mf[c[e+14388>>2]&2047](e,ha,5,c[ga>>2]|0);ef[c[e+11180>>2]&4095](oa,R,ha);break}ha=sa>>1;ga=ta>>1;fa=f+512|0;ea=e+9964|0;if((c[e+196>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,fa,4,c[ea>>2]|0);ef[c[e+11180>>2]&4095](na,ha,fa)}fa=f+640|0;if((c[e+200>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,fa,5,c[ea>>2]|0);ef[c[e+11180>>2]&4095](oa,ha,fa)}fa=f+768|0;if((c[e+204>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,fa,6,c[ea>>2]|0);ef[c[e+11180>>2]&4095](na+ga|0,ha,fa)}fa=f+896|0;if(!((c[e+208>>2]|0)>-1)){break}mf[c[e+14388>>2]&2047](e,fa,7,c[ea>>2]|0);ef[c[e+11180>>2]&4095](oa+ga|0,ha,fa)}else{do{if(!ia){if(!(((c[e+48>>2]|0)-1|0)>>>0<2>>>0)){break}fa=e+11176|0;ef[c[fa>>2]&4095](ma,sa,f|0);ef[c[fa>>2]&4095](ma+8|0,sa,f+128|0);ef[c[fa>>2]&4095](ma+ta|0,sa,f+256|0);ef[c[fa>>2]&4095](ma+(ta+8)|0,sa,f+384|0);if((c[e+14220>>2]|0)!=0){ef[c[fa>>2]&4095](na,R,f+512|0);ef[c[fa>>2]&4095](oa,R,f+640|0);break g}ha=c[ra>>2]|0;ga=R<<ha;ea=(ha|0)==0?R<<3:R;ef[c[fa>>2]&4095](na,ga,f+512|0);ef[c[fa>>2]&4095](oa,ga,f+640|0);ef[c[fa>>2]&4095](na+ea|0,ga,f+768|0);ef[c[fa>>2]&4095](oa+ea|0,ga,f+896|0);if((c[e+14216>>2]|0)!=0){break g}ef[c[fa>>2]&4095](na+8|0,ga,f+1024|0);ef[c[fa>>2]&4095](oa+8|0,ga,f+1152|0);ha=ea+8|0;ef[c[fa>>2]&4095](na+ha|0,ga,f+1280|0);ef[c[fa>>2]&4095](oa+ha|0,ga,f+1408|0);break g}}while(0);ga=f|0;ha=e+14384|0;mf[c[ha>>2]&2047](e,ga,0,c[k>>2]|0);fa=e+11176|0;ef[c[fa>>2]&4095](ma,sa,ga);ga=f+128|0;mf[c[ha>>2]&2047](e,ga,1,c[k>>2]|0);ef[c[fa>>2]&4095](ma+8|0,sa,ga);ga=f+256|0;mf[c[ha>>2]&2047](e,ga,2,c[k>>2]|0);ef[c[fa>>2]&4095](ma+ta|0,sa,ga);ga=f+384|0;mf[c[ha>>2]&2047](e,ga,3,c[k>>2]|0);ef[c[fa>>2]&4095](ma+(ta+8)|0,sa,ga);if((c[e+14220>>2]|0)==0){ga=ta>>1;ea=sa>>1;la=f+512|0;ka=e+9964|0;mf[c[ha>>2]&2047](e,la,4,c[ka>>2]|0);ef[c[fa>>2]&4095](na,ea,la);la=f+640|0;mf[c[ha>>2]&2047](e,la,5,c[ka>>2]|0);ef[c[fa>>2]&4095](oa,ea,la);la=f+768|0;mf[c[ha>>2]&2047](e,la,6,c[ka>>2]|0);ef[c[fa>>2]&4095](na+ga|0,ea,la);la=f+896|0;mf[c[ha>>2]&2047](e,la,7,c[ka>>2]|0);ef[c[fa>>2]&4095](oa+ga|0,ea,la);break}else{la=f+512|0;ea=e+9964|0;mf[c[ha>>2]&2047](e,la,4,c[ea>>2]|0);ef[c[fa>>2]&4095](na,R,la);la=f+640|0;mf[c[ha>>2]&2047](e,la,5,c[ea>>2]|0);ef[c[fa>>2]&4095](oa,R,la);break}}}while(0);if(qa){i=g;return}mf[c[e+11332>>2]&2047](c[e+12544>>2]|0,ma,aa,16);aa=e+14216|0;ma=e+14220|0;mf[c[e+11332+(c[aa>>2]<<4)>>2]&2047](c[e+12548>>2]|0,na,R,16>>>((c[ma>>2]|0)>>>0));mf[c[e+11332+(c[aa>>2]<<4)>>2]&2047](c[e+12552>>2]|0,oa,R,16>>>((c[ma>>2]|0)>>>0));i=g;return}if(!m){KIb(j,48,2272416,(p=i,i=i+16|0,c[p>>2]=n,c[p+8>>2]=l,p)|0);i=p;l=0;n=c[h>>2]|0;do{KIb(n,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+(d[e+11184+l|0]<<1)>>1]|0,p)|0);i=p;l=l+1|0;n=c[h>>2]|0}while((l|0)<64);KIb(n,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=0;l=c[h>>2]|0;do{KIb(l,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+128+(d[e+11184+n|0]<<1)>>1]|0,p)|0);i=p;n=n+1|0;l=c[h>>2]|0}while((n|0)<64);KIb(l,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;l=0;n=c[h>>2]|0;do{KIb(n,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+256+(d[e+11184+l|0]<<1)>>1]|0,p)|0);i=p;l=l+1|0;n=c[h>>2]|0}while((l|0)<64);KIb(n,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=0;l=c[h>>2]|0;do{KIb(l,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+384+(d[e+11184+n|0]<<1)>>1]|0,p)|0);i=p;n=n+1|0;l=c[h>>2]|0}while((n|0)<64);KIb(l,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;l=0;n=c[h>>2]|0;do{KIb(n,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+512+(d[e+11184+l|0]<<1)>>1]|0,p)|0);i=p;l=l+1|0;n=c[h>>2]|0}while((l|0)<64);KIb(n,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=0;l=c[h>>2]|0;do{KIb(l,48,2267712,(p=i,i=i+8|0,c[p>>2]=b[f+640+(d[e+11184+n|0]<<1)>>1]|0,p)|0);i=p;n=n+1|0;l=c[h>>2]|0}while((n|0)<64);KIb(l,48,2280984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}p=e+9960|0;a[(c[e+9136>>2]|0)+o|0]=c[p>>2];l=e+12488|0;n=(c[e+32>>2]|0)==0;i:do{if((c[l>>2]|0)==0){do{if(n){if((c[e+228>>2]|0)!=0){break}j=128<<c[e+14176>>2];c[e+9868>>2]=j;c[e+9864>>2]=j;c[e+9860>>2]=j;break i}}while(0);if((a[(c[e+9932>>2]|0)+o|0]|0)==0){break}JTa(e)}else{if(n){if((c[e+228>>2]|0)==0){break}}a[(c[e+9932>>2]|0)+o|0]=1}}while(0);n=c[h>>2]|0;do{if((c[e+60>>2]&32768|0)==0){if((c[n+584>>2]|0)!=0){break}if((c[n+588>>2]|0)!=0){break}if((c[e+56>>2]|0)==0){break}if((c[e+20>>2]|0)==0){if((c[e+9992>>2]|0)!=3){break}}if((c[n+296>>2]|0)==2){break}i=g;return}}while(0);j=c[e+7656>>2]|0;m=c[e+7660>>2]|0;ma=e+9992|0;R=8>>>((c[n+800>>2]|0)>>>0);n=e+56|0;do{if((c[n>>2]|0)==0){oa=(c[e+9928>>2]|0)+o|0;aa=e+9924|0;if((c[aa>>2]|0)!=0){c[aa>>2]=0;a[oa]=1;break}if((c[e+9816>>2]|0)==0){a[oa]=1;break}else{a[oa]=0;break}}}while(0);o=e+14236|0;oa=c[o>>2]|0;aa=j<<oa;if((oa|0)==0){ya=ca(R,j)|0}else{ya=j}j=c[e+12544>>2]|0;oa=c[e+12548>>2]|0;na=c[e+12552>>2]|0;qa=(c[n>>2]|0)!=0;if((c[l>>2]|0)!=0){do{if(!qa){if(!(((c[e+48>>2]|0)-1|0)>>>0<2>>>0)){break}l=e+11176|0;ef[c[l>>2]&4095](j,aa,f|0);ef[c[l>>2]&4095](j+R|0,aa,f+128|0);ef[c[l>>2]&4095](j+ya|0,aa,f+256|0);ef[c[l>>2]&4095](j+(ya+R)|0,aa,f+384|0);if((c[e+14220>>2]|0)!=0){ef[c[l>>2]&4095](oa,m,f+512|0);ef[c[l>>2]&4095](na,m,f+640|0);i=g;return}sa=c[o>>2]|0;ta=m<<sa;if((sa|0)==0){za=ca(R,m)|0}else{za=m}ef[c[l>>2]&4095](oa,ta,f+512|0);ef[c[l>>2]&4095](na,ta,f+640|0);ef[c[l>>2]&4095](oa+za|0,ta,f+768|0);ef[c[l>>2]&4095](na+za|0,ta,f+896|0);if((c[e+14216>>2]|0)!=0){i=g;return}ef[c[l>>2]&4095](oa+R|0,ta,f+1024|0);ef[c[l>>2]&4095](na+R|0,ta,f+1152|0);sa=za+R|0;ef[c[l>>2]&4095](oa+sa|0,ta,f+1280|0);ef[c[l>>2]&4095](na+sa|0,ta,f+1408|0);i=g;return}}while(0);za=f|0;ta=e+14384|0;mf[c[ta>>2]&2047](e,za,0,c[p>>2]|0);sa=e+11176|0;ef[c[sa>>2]&4095](j,aa,za);za=f+128|0;mf[c[ta>>2]&2047](e,za,1,c[p>>2]|0);ef[c[sa>>2]&4095](j+R|0,aa,za);za=f+256|0;mf[c[ta>>2]&2047](e,za,2,c[p>>2]|0);ef[c[sa>>2]&4095](j+ya|0,aa,za);za=f+384|0;mf[c[ta>>2]&2047](e,za,3,c[p>>2]|0);ef[c[sa>>2]&4095](j+(ya+R)|0,aa,za);if((c[e+14220>>2]|0)==0){za=ya>>1;l=aa>>1;k=f+512|0;ra=e+9964|0;mf[c[ta>>2]&2047](e,k,4,c[ra>>2]|0);ef[c[sa>>2]&4095](oa,l,k);k=f+640|0;mf[c[ta>>2]&2047](e,k,5,c[ra>>2]|0);ef[c[sa>>2]&4095](na,l,k);k=f+768|0;mf[c[ta>>2]&2047](e,k,6,c[ra>>2]|0);ef[c[sa>>2]&4095](oa+za|0,l,k);k=f+896|0;mf[c[ta>>2]&2047](e,k,7,c[ra>>2]|0);ef[c[sa>>2]&4095](na+za|0,l,k);i=g;return}else{k=f+512|0;l=e+9964|0;mf[c[ta>>2]&2047](e,k,4,c[l>>2]|0);ef[c[sa>>2]&4095](oa,m,k);k=f+640|0;mf[c[ta>>2]&2047](e,k,5,c[l>>2]|0);ef[c[sa>>2]&4095](na,m,k);i=g;return}}do{if(!qa){k=e+11300|0;sa=e+11736|0;l=c[sa>>2]|0;if((l&1|0)==0){Aa=k;Ba=l}else{TTa(e,j,oa,na,0,e+952|0,k);Aa=e+11316|0;Ba=c[sa>>2]|0}if((Ba&2|0)==0){break}TTa(e,j,oa,na,1,e+3176|0,Aa)}}while(0);Aa=c[(c[h>>2]|0)+852>>2]|0;do{if((Aa|0)>7){h=c[ma>>2]|0;if((h|0)==3){i=g;return}if((Aa|0)<=31){break}if(!((h|0)!=1|(Aa|0)>47)){break}i=g;return}}while(0);j:do{if((c[n>>2]|0)==0){Aa=c[e+48>>2]|0;do{if((c[e+14092>>2]|0)==0){if((Aa|0)==1|(Aa|0)==2){break}else if((Aa|0)!=13){break j}if((c[e+14004>>2]|0)!=0){break j}}else{if((Aa|0)!=19){break}Fhb(e,f,j,oa,na);i=g;return}}while(0);if((c[e+180>>2]|0)>-1){ef[c[e+11180>>2]&4095](j,aa,f|0)}if((c[e+184>>2]|0)>-1){ef[c[e+11180>>2]&4095](j+R|0,aa,f+128|0)}if((c[e+188>>2]|0)>-1){ef[c[e+11180>>2]&4095](j+ya|0,aa,f+256|0)}if((c[e+192>>2]|0)>-1){ef[c[e+11180>>2]&4095](j+(ya+R)|0,aa,f+384|0)}if((c[e+14220>>2]|0)!=0){if((c[e+196>>2]|0)>-1){ef[c[e+11180>>2]&4095](oa,m,f+512|0)}if(!((c[e+200>>2]|0)>-1)){i=g;return}ef[c[e+11180>>2]&4095](na,m,f+640|0);i=g;return}Aa=c[o>>2]|0;ma=m<<Aa;if((Aa|0)==0){Ca=ca(R,m)|0}else{Ca=m}if((c[e+196>>2]|0)>-1){ef[c[e+11180>>2]&4095](oa,ma,f+512|0)}if((c[e+200>>2]|0)>-1){ef[c[e+11180>>2]&4095](na,ma,f+640|0)}if((c[e+204>>2]|0)>-1){ef[c[e+11180>>2]&4095](oa+Ca|0,ma,f+768|0)}if((c[e+208>>2]|0)>-1){ef[c[e+11180>>2]&4095](na+Ca|0,ma,f+896|0)}if((c[e+14216>>2]|0)!=0){i=g;return}if((c[e+212>>2]|0)>-1){ef[c[e+11180>>2]&4095](oa+R|0,ma,f+1024|0)}if((c[e+216>>2]|0)>-1){ef[c[e+11180>>2]&4095](na+R|0,ma,f+1152|0)}Aa=Ca+R|0;if((c[e+220>>2]|0)>-1){ef[c[e+11180>>2]&4095](oa+Aa|0,ma,f+1280|0)}if(!((c[e+224>>2]|0)>-1)){i=g;return}ef[c[e+11180>>2]&4095](na+Aa|0,ma,f+1408|0);i=g;return}}while(0);Ca=f|0;if((c[e+180>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,Ca,0,c[p>>2]|0);ef[c[e+11180>>2]&4095](j,aa,Ca)}Ca=f+128|0;if((c[e+184>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,Ca,1,c[p>>2]|0);ef[c[e+11180>>2]&4095](j+R|0,aa,Ca)}Ca=f+256|0;if((c[e+188>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,Ca,2,c[p>>2]|0);ef[c[e+11180>>2]&4095](j+ya|0,aa,Ca)}Ca=f+384|0;if((c[e+192>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,Ca,3,c[p>>2]|0);ef[c[e+11180>>2]&4095](j+(ya+R)|0,aa,Ca)}if((c[e+14220>>2]|0)!=0){Ca=f+512|0;R=e+9964|0;if((c[e+196>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,Ca,4,c[R>>2]|0);ef[c[e+11180>>2]&4095](oa,m,Ca)}Ca=f+640|0;if(!((c[e+200>>2]|0)>-1)){i=g;return}mf[c[e+14388>>2]&2047](e,Ca,5,c[R>>2]|0);ef[c[e+11180>>2]&4095](na,m,Ca);i=g;return}Ca=aa>>1;aa=ya>>1;ya=f+512|0;m=e+9964|0;if((c[e+196>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,ya,4,c[m>>2]|0);ef[c[e+11180>>2]&4095](oa,Ca,ya)}ya=f+640|0;if((c[e+200>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,ya,5,c[m>>2]|0);ef[c[e+11180>>2]&4095](na,Ca,ya)}ya=f+768|0;if((c[e+204>>2]|0)>-1){mf[c[e+14388>>2]&2047](e,ya,6,c[m>>2]|0);ef[c[e+11180>>2]&4095](oa+aa|0,Ca,ya)}ya=f+896|0;if(!((c[e+208>>2]|0)>-1)){i=g;return}mf[c[e+14388>>2]&2047](e,ya,7,c[m>>2]|0);ef[c[e+11180>>2]&4095](na+aa|0,Ca,ya);i=g;return}function LTa(a,b,e,f,g,h,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=i;i=i+32|0;m=l|0;n=m;o=d[(qKb(c[a+140>>2]|0)|0)+6|0]|0;p=(h|0)!=3;if(p){q=f<<1;r=g<<1}else{q=f;r=g}g=(c[a+124>>2]|0)-q|0;f=(r|0)>(g|0)?g:r;do{if(!((j|0)==0|p^1)){if((c[a+288>>2]&2|0)!=0){break}i=l;return}}while(0);p=c[a+148>>2]|0;if((p|0)==0){i=l;return}j=c[b+88>>2]|0;do{if((j|0)!=3&(k|0)==0){if((c[a+288>>2]&1|0)!=0){s=b;break}if((e|0)!=0){s=e;break}i=l;return}else{s=b}}while(0);b=s|0;do{if((j|0)==3&(h|0)==3){if((c[a+48>>2]|0)==24){t=12;break}mrc(n|0,0,32)|0;u=m|0}else{t=12}}while(0);if((t|0)==12){t=m|0;c[t>>2]=ca(c[s+32>>2]|0,q)|0;n=ca(c[s+36>>2]|0,q>>o)|0;c[m+8>>2]=n;c[m+4>>2]=n;mrc(m+12|0,0,20)|0;u=t}_e[p&511](a,b,u,q,h,f);i=l;return}function MTa(a,b,d){a=a|0;b=b|0;d=d|0;LTa(c[a+4>>2]|0,c[a+9856>>2]|0,c[a+9848>>2]|0,b,d,c[a+14172>>2]|0,c[a+14240>>2]|0,c[a+13944>>2]|0);return}function NTa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[a+7656>>2]|0;d=c[a+7660>>2]|0;e=c[a+4>>2]|0;f=4-(c[e+800>>2]|0)|0;g=c[a+128>>2]|0;h=c[a+12480>>2]|0;i=ca(h,g)|0;j=c[a+12476>>2]|0;k=j+i<<1;c[a+12496>>2]=k-2;c[a+12500>>2]=k-1;k=ca(h<<1|1,g)|0;i=j<<1;c[a+12504>>2]=i-2+k;c[a+12508>>2]=i-1+k;k=c[a+124>>2]|0;i=ca(h+1|0,k)|0;l=c[a+120>>2]|0;c[a+12512>>2]=i-1+(ca(g<<1,l)|0)+j;c[a+12516>>2]=(ca(l<<1,g)|0)-1+(ca(h+2+l|0,k)|0)+j;k=c[a+7624>>2]|0;l=j-1|0;j=l<<f;g=a+12544|0;c[g>>2]=k+j;i=c[a+7628>>2]|0;m=l<<f-(c[a+14216>>2]|0);l=a+12548|0;c[l>>2]=i+m;n=c[a+7632>>2]|0;o=a+12552|0;c[o>>2]=n+m;do{if((c[a+9992>>2]|0)==3){if((c[e+148>>2]|0)==0){break}if((c[a+14172>>2]|0)!=3){break}return}}while(0);if((c[a+14172>>2]|0)==3){c[g>>2]=k+(j+((ca(h,b)|0)<<f));e=ca(h,d)|0;p=e<<f-(c[a+14220>>2]|0);c[l>>2]=i+(m+p);c[o>>2]=n+(m+p);return}else{p=h>>1;c[g>>2]=k+(j+((ca(p,b)|0)<<f));b=ca(p,d)|0;d=b<<f-(c[a+14220>>2]|0);c[l>>2]=i+(m+d);c[o>>2]=n+(m+d);return}}function OTa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+128|0;h=g|0;if((f|0)<1){i=g;return}else{j=0}while(1){k=d[e+j|0]|0;l=a+(k<<1)|0;b[h+(k<<1)>>1]=b[l>>1]|0;b[l>>1]=0;l=j+1|0;if((l|0)>(f|0)){m=0;break}else{j=l}}do{j=d[e+m|0]|0;b[a+((d[c+j|0]|0)<<1)>>1]=b[h+(j<<1)>>1]|0;m=m+1|0;}while((m|0)<=(f|0));i=g;return}function PTa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;d=c[a+60>>2]|0;a=d;if((d|0)==0){return}e=d+156|0;f=c[e>>2]|0;if((f|0)==0){return}else{g=0;h=f}while(1){mTa(a,h+(g*2224|0)|0);f=g+1|0;if((f|0)>=36){break}g=f;h=c[e>>2]|0}c[d+9852>>2]=0;c[d+9848>>2]=0;c[d+9856>>2]=0;mTa(a,d+7624|0);mTa(a,d+952|0);mTa(a,d+3176|0);c[d+12480>>2]=0;c[d+12476>>2]=0;c[d+9988>>2]=0;c[d+13760>>2]=-1;c[d+13764>>2]=0;c[d+13768>>2]=0;c[d+13772>>2]=0;c[d+13748>>2]=0;c[d+13752>>2]=0;c[d+14020>>2]=0;b[d+13872>>1]=0;return}function QTa(a,b){a=a|0;b=b|0;var e=0;if((b|0)<1){e=1}else{e=(b|0)>31?31:b}c[a+9960>>2]=e;b=d[(c[a+9896>>2]|0)+e|0]|0;c[a+9964>>2]=b;c[a+168>>2]=d[(c[a+9888>>2]|0)+e|0]|0;c[a+172>>2]=d[(c[a+9892>>2]|0)+b|0]|0;return}function RTa(a){a=a|0;if((c[a+9992>>2]|0)==3){return}if((c[a+13940>>2]|0)!=0){return}if((c[a+14460>>2]|0)!=0){return}L5a((c[a+9856>>2]|0)+1496|0,c[a+12480>>2]|0,0);return}function STa(a){a=a|0;c[a+14556>>2]=c[a+9856>>2];c[a+14560>>2]=c[a+9848>>2];c[a+14564>>2]=c[a+9852>>2];b[a+14568>>1]=b[a+13872>>1]|0;b[a+14570>>1]=b[a+13874>>1]|0;c[a+14572>>2]=c[a+13924>>2];c[a+14576>>2]=c[a+13940>>2];xpb(a+14424|0);return}function TTa(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0;j=a+4|0;k=c[(c[j>>2]|0)+800>>2]|0;l=8>>>(k>>>0);m=a+12476|0;n=a+12480|0;o=c[n>>2]|0;switch(c[a+11740>>2]|0){case 2:{p=a+14172|0;q=l<<1;r=o>>1;s=a+14216|0;t=a+136|0;u=a+140|0;v=a+7656|0;w=a+7660|0;x=a+13924|0;y=r<<1;z=a+28|0;A=a+14220|0;B=a+11540|0;C=a+9944|0;D=a+148|0;E=a+152|0;F=l+1>>1;G=a+9992|0;H=a+14240|0;I=a+9856|0;J=f;K=0;L=e;M=b;while(1){N=c[a+11808+(g<<3)+(K<<2)>>2]|0;do{if((c[p>>2]|0)==(N+1|0)){O=h}else{if((c[G>>2]|0)==3){O=h;break}if((c[H>>2]|0)!=0){O=h;break}O=c[I>>2]|0}}while(0);P=c[a+11744+(g<<5)+(K<<3)>>2]|0;Q=(c[a+11744+(g<<5)+(K<<3)+4>>2]|0)+(ca(K,q)|0)|0;R=c[(c[j>>2]|0)+800>>2]|0;S=R-1|0;T=c[s>>2]|0;U=S+T|0;V=(U|0)>3?3:U;U=8>>>(R>>>0);W=(2<<R)-1|0;X=c[t>>2]>>R;Y=c[u>>2]>>R;Z=c[v>>2]|0;_=c[w>>2]|0;if((c[x>>2]|0)==0){$=P;aa=Q}else{$=(P|0)/2|0;aa=(Q|0)/2|0}Q=$&W;P=aa&W;ba=c[m>>2]|0;da=U<<1;ea=R+1|0;fa=(ca(ba,da)|0)+($>>ea)|0;ga=(aa>>ea)+(ca(y,U)|0)|0;ha=c[z>>2]|0;do{if((ha|0)==2){ia=aa>>1&W|P&1;ja=$>>1&W|Q&1;ka=ga>>1;la=fa>>1}else if((ha|0)==1){ma=($|0)/4|0;na=(aa|0)/4|0;ia=na<<1&W;ja=ma<<1&W;ka=(na>>R)+(ca(U,r)|0)|0;la=(ma>>R)+(ca(ba,U)|0)|0}else{if((c[A>>2]|0)!=0){ma=($|0)/2|0;na=(aa|0)/2|0;ia=na&W;ja=ma&W;ka=(na>>ea)+(ca(U,r)|0)|0;la=(ma>>ea)+(ca(ba,U)|0)|0;break}if((T|0)==0){ia=P;ja=Q;ka=ga;la=fa;break}ma=($|0)/2|0;ia=P;ja=ma&W;ka=ga;la=(ma>>ea)+(ca(ba,U)|0)|0}}while(0);U=(c[O>>2]|0)+(fa+(ca(ga,Z)|0))|0;ba=(ca(ka,_)|0)+la|0;ea=(c[O+4>>2]|0)+ba|0;W=(c[O+8>>2]|0)+ba|0;ba=X-((Q|0)!=0)-da|0;if(fa>>>0>((ba|0)>0?ba:0)>>>0|(ka|0)<0){oa=103}else{ba=Y-((P|0)!=0)-l|0;if(ga>>>0>((ba|0)>0?ba:0)>>>0){oa=103}else{pa=U;qa=ea;ra=W}}if((oa|0)==103){oa=0;Ve[c[B>>2]&127](c[C>>2]|0,U,Z,Z,17,17,fa,ga,X,Y);U=c[C>>2]|0;ba=(c[D>>2]|0)*18|0;T=U+ba|0;ha=X>>1;ma=Y>>1;Ve[c[B>>2]&127](T,ea,_,_,9,9,la,ka,ha,ma);ea=U+(ba+16)|0;Ve[c[B>>2]&127](ea,W,_,_,9,9,la,ka,ha,ma);pa=U;qa=T;ra=ea}if((N|0)==0){sa=pa;ta=qa;ua=ra}else{ea=c[E>>2]|0;sa=pa+(c[D>>2]|0)|0;ta=qa+ea|0;ua=ra+ea|0}_e[c[i+(S<<2)>>2]&511](M,sa,Z,l,Q<<2>>R,P<<2>>R);ea=c[A>>2]|0;T=(ea|0)==0?l:F;U=ja<<2>>R;ma=ia<<2>>R;if((T|0)==0){va=ea}else{ea=i+(V<<2)|0;_e[c[ea>>2]&511](L,ta,_,T,U,ma);_e[c[ea>>2]&511](J,ua,_,T,U,ma);va=c[A>>2]|0}ma=M+(ca(c[D>>2]|0,q)|0)|0;U=ca(q>>va,c[E>>2]|0)|0;T=K+1|0;if((T|0)<2){J=J+U|0;K=T;L=L+U|0;M=ma}else{break}}return};case 3:{M=c[a+14172>>2]|0;L=c[a+11808+(g<<3)>>2]|0;if((M|0)!=3){do{if((M|0)==(L+1|0)){wa=h}else{if((c[a+9992>>2]|0)==3){wa=h;break}if((c[a+14240>>2]|0)!=0){wa=h;break}wa=c[a+9856>>2]|0}}while(0);M=c[a+11744+(g<<5)>>2]|0;K=c[a+11744+(g<<5)+4>>2]|0;J=l<<1;E=o>>1;va=k-1|0;q=c[a+14216>>2]|0;D=va+q|0;A=(D|0)>3?3:D;D=(2<<k)-1|0;ua=c[a+136>>2]>>k;ta=c[a+140>>2]>>k;ia=c[a+7656>>2]|0;ja=c[a+7660>>2]|0;if((c[a+13924>>2]|0)==0){xa=M;ya=K}else{xa=(M|0)/2|0;ya=(K|0)/2|0}K=xa&D;M=ya&D;F=c[m>>2]|0;sa=k+1|0;ra=(ca(F,J)|0)+(xa>>sa)|0;qa=(ya>>sa)+(ca(E<<1,l)|0)|0;pa=c[a+28>>2]|0;do{if((pa|0)==2){za=ya>>1&D|M&1;Aa=xa>>1&D|K&1;Ba=qa>>1;Ca=ra>>1}else if((pa|0)==1){ka=(xa|0)/4|0;la=(ya|0)/4|0;za=la<<1&D;Aa=ka<<1&D;Ba=(la>>k)+(ca(l,E)|0)|0;Ca=(ka>>k)+(ca(F,l)|0)|0}else{if((c[a+14220>>2]|0)!=0){ka=(xa|0)/2|0;la=(ya|0)/2|0;za=la&D;Aa=ka&D;Ba=(la>>sa)+(ca(l,E)|0)|0;Ca=(ka>>sa)+(ca(F,l)|0)|0;break}if((q|0)==0){za=M;Aa=K;Ba=qa;Ca=ra;break}ka=(xa|0)/2|0;za=M;Aa=ka&D;Ba=qa;Ca=(ka>>sa)+(ca(F,l)|0)|0}}while(0);F=(c[wa>>2]|0)+(ra+(ca(qa,ia)|0))|0;sa=(ca(Ba,ja)|0)+Ca|0;D=(c[wa+4>>2]|0)+sa|0;xa=(c[wa+8>>2]|0)+sa|0;sa=ua-((K|0)!=0)-J|0;if(ra>>>0>((sa|0)>0?sa:0)>>>0|(Ba|0)<0){oa=83}else{sa=ta-((M|0)!=0)-J|0;if(qa>>>0>((sa|0)>0?sa:0)>>>0){oa=83}else{Da=F;Ea=D;Fa=xa}}if((oa|0)==83){sa=a+11540|0;wa=a+9944|0;Ve[c[sa>>2]&127](c[wa>>2]|0,F,ia,ia,17,17,ra,qa,ua,ta);qa=c[wa>>2]|0;wa=(c[a+148>>2]|0)*18|0;ra=qa+wa|0;F=ua>>1;ua=ta>>1;Ve[c[sa>>2]&127](ra,D,ja,ja,9,9,Ca,Ba,F,ua);D=qa+(wa+16)|0;Ve[c[sa>>2]&127](D,xa,ja,ja,9,9,Ca,Ba,F,ua);Da=qa;Ea=ra;Fa=D}if((L|0)==0){Ga=Da;Ha=Ea;Ia=Fa}else{D=c[a+152>>2]|0;Ga=Da+(c[a+148>>2]|0)|0;Ha=Ea+D|0;Ia=Fa+D|0}_e[c[i+(va<<2)>>2]&511](b,Ga,ia,J,K<<2>>k,M<<2>>k);M=(c[a+14220>>2]|0)==0?J:l;J=Aa<<2>>k;Aa=za<<2>>k;if((M|0)==0){return}za=i+(A<<2)|0;_e[c[za>>2]&511](e,Ha,ja,M,J,Aa);_e[c[za>>2]&511](f,Ia,ja,M,J,Aa);return}Aa=c[a+11744+(g<<5)>>2]|0;J=c[a+11744+(g<<5)+4>>2]|0;M=k-1|0;ja=a+14216|0;Ia=c[ja>>2]|0;za=Ia+M|0;Ha=(za|0)>3?3:za;za=(2<<k)-1|0;A=a+136|0;K=c[A>>2]>>k;ia=a+140|0;Ga=c[ia>>2]>>k;va=a+7656|0;D=c[va>>2]<<1;Fa=a+7660|0;Ea=c[Fa>>2]<<1;Da=a+13924|0;if((c[Da>>2]|0)==0){Ja=Aa;Ka=J}else{Ja=(Aa|0)/2|0;Ka=(J|0)/2|0}J=Ka-(ca(L,(1<<k)-1|0)|0)|0;Ka=Ja&za;Aa=J&za;ra=c[m>>2]|0;qa=l<<1;ua=k+1|0;F=(ca(ra,qa)|0)+(Ja>>ua)|0;Ba=o<<1;Ca=(J>>ua)+((ca(Ba,l)|0)>>1)|0;xa=a+28|0;sa=c[xa>>2]|0;do{if((sa|0)==2){La=J>>1&za|Aa&1;Ma=Ja>>1&za|Ka&1;Na=Ca>>1;Oa=F>>1}else if((sa|0)==1){wa=(Ja|0)/4|0;ta=(J|0)/4|0;La=ta<<1&za;Ma=wa<<1&za;Na=(ta>>k)+(ca(o,l)|0)|0;Oa=(wa>>k)+(ca(ra,l)|0)|0}else{if((c[a+14220>>2]|0)!=0){wa=(Ja|0)/2|0;ta=(J|0)/2|0;La=ta&za;Ma=wa&za;Na=(ta>>ua)+((ca(o,l)|0)>>1)|0;Oa=(wa>>ua)+(ca(ra,l)|0)|0;break}if((Ia|0)==0){La=Aa;Ma=Ka;Na=Ca;Oa=F;break}wa=(Ja|0)/2|0;La=Aa;Ma=wa&za;Na=Ca;Oa=(wa>>ua)+(ca(ra,l)|0)|0}}while(0);ra=(c[h>>2]|0)+((ca(Ca,D)|0)+F)|0;ua=h+4|0;za=(ca(Na,Ea)|0)+Oa|0;Ja=(c[ua>>2]|0)+za|0;Ia=h+8|0;J=(c[Ia>>2]|0)+za|0;za=K-((Ka|0)!=0)-qa|0;qa=Ga>>1;if(F>>>0>((za|0)>0?za:0)>>>0|(Na|0)<0){oa=44}else{za=qa-((Aa|0)!=0)-l|0;if(Ca>>>0>((za|0)>0?za:0)>>>0){oa=44}else{Pa=ra;Qa=Ja;Ra=J}}if((oa|0)==44){za=a+11540|0;sa=a+9944|0;wa=D>>1;Ve[c[za>>2]&127](c[sa>>2]|0,ra,wa,wa,17,18,F,Ca<<1,K,Ga);Ga=c[sa>>2]|0;sa=(c[a+148>>2]|0)*18|0;Ca=Ga+sa|0;F=Ea>>1;wa=Na<<1;Na=K>>1;Ve[c[za>>2]&127](Ca,Ja,F,F,9,10,Oa,wa,Na,qa);Ja=Ga+(sa+16)|0;Ve[c[za>>2]&127](Ja,J,F,F,9,10,Oa,wa,Na,qa);Pa=Ga;Qa=Ca;Ra=Ja}if((L|0)==0){Sa=Pa;Ta=Qa;Ua=Ra}else{L=c[a+152>>2]|0;Sa=Pa+(c[a+148>>2]|0)|0;Ta=Qa+L|0;Ua=Ra+L|0}_e[c[i+(M<<2)>>2]&511](b,Sa,D,l,Ka<<2>>k,Aa<<2>>k);Aa=a+14220|0;if((c[Aa>>2]|0)==0){Va=l}else{Va=l+1>>1}Ka=Ma<<2>>k;Ma=La<<2>>k;if((Va|0)!=0){La=i+(Ha<<2)|0;_e[c[La>>2]&511](e,Ta,Ea,Va,Ka,Ma);_e[c[La>>2]&511](f,Ua,Ea,Va,Ka,Ma)}Ma=c[a+11808+(g<<3)+4>>2]|0;Ka=c[a+11744+(g<<5)+8>>2]|0;Va=c[a+11744+(g<<5)+12>>2]|0;Ea=c[(c[j>>2]|0)+800>>2]|0;Ua=Ea-1|0;La=c[ja>>2]|0;ja=Ua+La|0;Ta=(ja|0)>3?3:ja;ja=8>>>(Ea>>>0);Ha=(2<<Ea)-1|0;D=c[A>>2]>>Ea;A=c[ia>>2]>>Ea;ia=c[va>>2]<<1;va=c[Fa>>2]<<1;if((c[Da>>2]|0)==0){Wa=Ka;Xa=Va}else{Wa=(Ka|0)/2|0;Xa=(Va|0)/2|0}Va=Xa+(ca((1<<Ea)-1|0,1-Ma|0)|0)|0;Xa=Wa&Ha;Ka=Va&Ha;Da=c[m>>2]|0;Fa=ja<<1;Sa=Ea+1|0;M=(ca(Da,Fa)|0)+(Wa>>Sa)|0;L=(Va>>Sa)+((ca(ja,Ba)|0)>>1)|0;Ba=c[xa>>2]|0;do{if((Ba|0)==2){Ya=Va>>1&Ha|Ka&1;Za=Wa>>1&Ha|Xa&1;_a=L>>1;$a=M>>1}else if((Ba|0)==1){xa=(Wa|0)/4|0;Ra=(Va|0)/4|0;Ya=Ra<<1&Ha;Za=xa<<1&Ha;_a=(Ra>>Ea)+(ca(ja,o)|0)|0;$a=(xa>>Ea)+(ca(Da,ja)|0)|0}else{if((c[Aa>>2]|0)!=0){xa=(Wa|0)/2|0;Ra=(Va|0)/2|0;Ya=Ra&Ha;Za=xa&Ha;_a=(Ra>>Sa)+((ca(ja,o)|0)>>1)|0;$a=(xa>>Sa)+(ca(Da,ja)|0)|0;break}if((La|0)==0){Ya=Ka;Za=Xa;_a=L;$a=M;break}xa=(Wa|0)/2|0;Ya=Ka;Za=xa&Ha;_a=L;$a=(xa>>Sa)+(ca(Da,ja)|0)|0}}while(0);ja=(c[h>>2]|0)+((ca(L,ia)|0)+M)|0;Da=(ca(_a,va)|0)+$a|0;Sa=(c[ua>>2]|0)+Da|0;ua=(c[Ia>>2]|0)+Da|0;Da=D-((Xa|0)!=0)-Fa|0;Fa=A>>1;do{if(M>>>0>((Da|0)>0?Da:0)>>>0|(_a|0)<0){oa=63}else{Ia=Fa-((Ka|0)!=0)-l|0;if(L>>>0>((Ia|0)>0?Ia:0)>>>0){oa=63;break}ab=ja;bb=Sa;cb=ua;db=a+148|0}}while(0);if((oa|0)==63){Da=a+11540|0;Ia=a+9944|0;Ha=ia>>1;Ve[c[Da>>2]&127](c[Ia>>2]|0,ja,Ha,Ha,17,18,M,L<<1,D,A);A=c[Ia>>2]|0;Ia=a+148|0;L=(c[Ia>>2]|0)*18|0;M=A+L|0;Ha=va>>1;ja=_a<<1;_a=D>>1;Ve[c[Da>>2]&127](M,Sa,Ha,Ha,9,10,$a,ja,_a,Fa);Sa=A+(L+16)|0;Ve[c[Da>>2]&127](Sa,ua,Ha,Ha,9,10,$a,ja,_a,Fa);ab=A;bb=M;cb=Sa;db=Ia}Ia=c[db>>2]|0;db=c[a+152>>2]|0;if((Ma|0)==0){eb=ab;fb=bb;gb=cb}else{eb=ab+Ia|0;fb=bb+db|0;gb=cb+db|0}_e[c[i+(Ua<<2)>>2]&511](b+Ia|0,eb,ia,l,Xa<<2>>Ea,Ka<<2>>Ea);Ka=l>>((c[Aa>>2]|0)!=0);Aa=Za<<2>>Ea;Za=Ya<<2>>Ea;if((Ka|0)==0){return}Ea=i+(Ta<<2)|0;_e[c[Ea>>2]&511](e+db|0,fb,va,Ka,Aa,Za);_e[c[Ea>>2]&511](f+db|0,gb,va,Ka,Aa,Za);return};case 1:{Za=a+148|0;Aa=c[m>>2]<<1;Ka=o<<1;va=a+136|0;gb=a+140|0;db=a+13924|0;Ea=a+11540|0;fb=a+9944|0;Ta=l+1|0;Ya=0;Xa=0;ia=0;eb=k;do{Ia=ia&1;Ua=ia>>1;cb=c[Za>>2]|0;bb=b+(ca((ca(cb,Ua)|0)+Ia|0,l)|0)|0;ab=ca(Ia|Aa,l)|0;Ia=ca(Ua+Ka|0,l)|0;Ua=c[va>>2]>>k;Ma=c[gb>>2]>>k;Sa=a+11744+(g<<5)+(ia<<3)|0;M=c[Sa>>2]|0;A=a+11744+(g<<5)+(ia<<3)+4|0;Fa=c[A>>2]|0;_a=(eb|0)>3?3:eb;ja=(2<<eb)-1|0;if((c[db>>2]|0)==0){hb=Fa;ib=M}else{hb=(Fa|0)/2|0;ib=(M|0)/2|0}M=ib&ja;Fa=hb&ja;ja=eb+1|0;$a=(ib>>ja)+ab|0;ab=(hb>>ja)+Ia|0;Ia=(c[h>>2]|0)+((ca(ab,cb)|0)+$a)|0;ja=Ua-((M|0)!=0)-l|0;if($a>>>0>((ja|0)>0?ja:0)>>>0){oa=22}else{ja=Ma-((Fa|0)!=0)-l|0;if(ab>>>0>((ja|0)>0?ja:0)>>>0){oa=22}else{jb=Ia}}if((oa|0)==22){oa=0;Ve[c[Ea>>2]&127](c[fb>>2]|0,Ia,cb,cb,Ta,Ta,$a,ab,Ua,Ma);jb=c[fb>>2]|0}_e[c[i+(_a<<2)>>2]&511](bb,jb,cb,l,M<<2>>eb,Fa<<2>>eb);Ya=(c[Sa>>2]|0)+Ya|0;Xa=(c[A>>2]|0)+Xa|0;ia=ia+1|0;eb=c[(c[j>>2]|0)+800>>2]|0}while((ia|0)<4);ia=(eb|0)>3?3:eb;jb=8>>>(eb>>>0);Ta=(2<<eb)-1|0;hb=eb+1|0;ib=c[va>>2]>>hb;va=c[gb>>2]>>hb;if((c[db>>2]|0)==0){kb=Ya;lb=Xa}else{kb=(Ya|0)/2|0;lb=(Xa|0)/2|0}Xa=(d[1378512+(kb&15)|0]|0)+(kb>>3)|0;kb=(d[1378512+(lb&15)|0]|0)+(lb>>3)|0;lb=Xa&Ta;Ya=kb&Ta;Ta=(ca(c[m>>2]|0,jb)|0)+(Xa>>hb)|0;Xa=(ca(c[n>>2]|0,jb)|0)+(kb>>hb)|0;hb=a+152|0;kb=c[hb>>2]|0;n=(ca(Xa,kb)|0)+Ta|0;db=(c[h+4>>2]|0)+n|0;gb=ib-((lb|0)!=0)-jb|0;if(Ta>>>0>((gb|0)>0?gb:0)>>>0){oa=28}else{gb=va-((Ya|0)!=0)-jb|0;if(Xa>>>0>((gb|0)>0?gb:0)>>>0){oa=28}else{mb=db;nb=0;ob=kb}}if((oa|0)==28){Ve[c[Ea>>2]&127](c[fb>>2]|0,db,kb,kb,9,9,Ta,Xa,ib,va);mb=c[fb>>2]|0;nb=1;ob=c[hb>>2]|0}kb=lb<<2>>eb;lb=Ya<<2>>eb;eb=i+(ia<<2)|0;_e[c[eb>>2]&511](e,mb,ob,jb,kb,lb);ob=(c[h+8>>2]|0)+n|0;if(nb){nb=c[hb>>2]|0;Ve[c[Ea>>2]&127](c[fb>>2]|0,ob,nb,nb,9,9,Ta,Xa,ib,va);pb=c[fb>>2]|0}else{pb=ob}_e[c[eb>>2]&511](f,pb,c[hb>>2]|0,jb,kb,lb);return};case 0:{lb=c[a+11744+(g<<5)>>2]|0;kb=c[a+11744+(g<<5)+4>>2]|0;jb=l<<1;hb=k-1|0;pb=c[a+14216>>2]|0;eb=pb+hb|0;ob=(eb|0)>3?3:eb;eb=(2<<k)-1|0;fb=c[a+136>>2]>>k;va=c[a+140>>2]>>k;ib=c[a+7656>>2]|0;Xa=c[a+7660>>2]|0;if((c[a+13924>>2]|0)==0){qb=lb;rb=kb}else{qb=(lb|0)/2|0;rb=(kb|0)/2|0}kb=qb&eb;lb=rb&eb;Ta=c[m>>2]|0;nb=k+1|0;Ea=(ca(Ta,jb)|0)+(qb>>nb)|0;n=(rb>>nb)+(ca(jb,o)|0)|0;mb=c[a+28>>2]|0;do{if((mb|0)==2){sb=rb>>1&eb|lb&1;tb=qb>>1&eb|kb&1;ub=n>>1;vb=Ea>>1}else if((mb|0)==1){ia=(qb|0)/4|0;Ya=(rb|0)/4|0;sb=Ya<<1&eb;tb=ia<<1&eb;ub=(Ya>>k)+(ca(o,l)|0)|0;vb=(ia>>k)+(ca(Ta,l)|0)|0}else{if((c[a+14220>>2]|0)!=0){ia=(qb|0)/2|0;Ya=(rb|0)/2|0;sb=Ya&eb;tb=ia&eb;ub=(Ya>>nb)+(ca(o,l)|0)|0;vb=(ia>>nb)+(ca(Ta,l)|0)|0;break}if((pb|0)==0){sb=lb;tb=kb;ub=n;vb=Ea;break}ia=(qb|0)/2|0;sb=lb;tb=ia&eb;ub=n;vb=(ia>>nb)+(ca(Ta,l)|0)|0}}while(0);Ta=(c[h>>2]|0)+(Ea+(ca(n,ib)|0))|0;nb=(ca(ub,Xa)|0)+vb|0;eb=(c[h+4>>2]|0)+nb|0;qb=(c[h+8>>2]|0)+nb|0;nb=fb-((kb|0)!=0)-jb|0;if(Ea>>>0>((nb|0)>0?nb:0)>>>0|(ub|0)<0){oa=15}else{nb=va-((lb|0)!=0)-jb|0;if(n>>>0>((nb|0)>0?nb:0)>>>0){oa=15}else{wb=Ta;xb=eb;yb=qb}}if((oa|0)==15){nb=a+11540|0;pb=a+9944|0;Ve[c[nb>>2]&127](c[pb>>2]|0,Ta,ib,ib,17,17,Ea,n,fb,va);n=c[pb>>2]|0;pb=(c[a+148>>2]|0)*18|0;Ea=n+pb|0;Ta=fb>>1;fb=va>>1;Ve[c[nb>>2]&127](Ea,eb,Xa,Xa,9,9,vb,ub,Ta,fb);eb=n+(pb+16)|0;Ve[c[nb>>2]&127](eb,qb,Xa,Xa,9,9,vb,ub,Ta,fb);wb=n;xb=Ea;yb=eb}_e[c[i+(hb<<2)>>2]&511](b,wb,ib,jb,kb<<2>>k,lb<<2>>k);lb=(c[a+14220>>2]|0)==0?jb:l;jb=tb<<2>>k;tb=sb<<2>>k;if((lb|0)==0){return}k=i+(ob<<2)|0;_e[c[k>>2]&511](e,xb,Xa,lb,jb,tb);_e[c[k>>2]&511](f,yb,Xa,lb,jb,tb);return};case 4:{tb=a+14172|0;if((c[tb>>2]|0)!=3){jb=l<<1;lb=o>>1;Xa=a+14216|0;yb=a+136|0;k=a+140|0;xb=a+7656|0;ob=a+7660|0;sb=a+13924|0;kb=lb<<1;ib=a+28|0;wb=a+14220|0;hb=a+11540|0;eb=a+9944|0;Ea=a+148|0;n=a+11316|0;fb=a+14240|0;Ta=a+152|0;ub=a+9856|0;vb=0;qb=h;nb=i;a:while(1){pb=qb+4|0;va=qb+8|0;rb=vb;mb=nb;while(1){if((rb|0)>=2){break a}zb=rb+1|0;ia=(c[tb>>2]|0)==(zb|0);Ya=rb<<1;db=c[a+11744+(g<<5)+(Ya<<3)>>2]|0;gb=c[a+11744+(g<<5)+(Ya<<3)+4>>2]|0;Ya=c[(c[j>>2]|0)+800>>2]|0;Ka=Ya-1|0;Aa=c[Xa>>2]|0;Za=Ka+Aa|0;A=(Za|0)>3?3:Za;Za=8>>>(Ya>>>0);Sa=(2<<Ya)-1|0;Fa=c[yb>>2]>>Ya;M=c[k>>2]>>Ya;cb=c[xb>>2]|0;bb=c[ob>>2]|0;if((c[sb>>2]|0)==0){Ab=db;Bb=gb}else{Ab=(db|0)/2|0;Bb=(gb|0)/2|0}gb=Ab&Sa;db=Bb&Sa;_a=c[m>>2]|0;Ma=Za<<1;Ua=Ya+1|0;ab=(ca(_a,Ma)|0)+(Ab>>Ua)|0;$a=(Bb>>Ua)+(ca(kb,Za)|0)|0;Ia=c[ib>>2]|0;do{if((Ia|0)==2){Cb=Bb>>1&Sa|db&1;Db=Ab>>1&Sa|gb&1;Eb=$a>>1;Fb=ab>>1}else if((Ia|0)==1){ja=(Ab|0)/4|0;Ha=(Bb|0)/4|0;Cb=Ha<<1&Sa;Db=ja<<1&Sa;Eb=(Ha>>Ya)+(ca(Za,lb)|0)|0;Fb=(ja>>Ya)+(ca(_a,Za)|0)|0}else{if((c[wb>>2]|0)!=0){ja=(Ab|0)/2|0;Ha=(Bb|0)/2|0;Cb=Ha&Sa;Db=ja&Sa;Eb=(Ha>>Ua)+(ca(Za,lb)|0)|0;Fb=(ja>>Ua)+(ca(_a,Za)|0)|0;break}if((Aa|0)==0){Cb=db;Db=gb;Eb=$a;Fb=ab;break}ja=(Ab|0)/2|0;Cb=db;Db=ja&Sa;Eb=$a;Fb=(ja>>Ua)+(ca(_a,Za)|0)|0}}while(0);Za=(c[qb>>2]|0)+(ab+(ca($a,cb)|0))|0;_a=(ca(Eb,bb)|0)+Fb|0;Ua=(c[pb>>2]|0)+_a|0;Sa=(c[va>>2]|0)+_a|0;_a=Fa-((gb|0)!=0)-Ma|0;if(ab>>>0>((_a|0)>0?_a:0)>>>0|(Eb|0)<0){oa=147}else{_a=M-((db|0)!=0)-jb|0;if($a>>>0>((_a|0)>0?_a:0)>>>0){oa=147}else{Gb=Za;Hb=Ua;Ib=Sa}}if((oa|0)==147){oa=0;Ve[c[hb>>2]&127](c[eb>>2]|0,Za,cb,cb,17,17,ab,$a,Fa,M);Za=c[eb>>2]|0;_a=(c[Ea>>2]|0)*18|0;Aa=Za+_a|0;Ia=Fa>>1;ja=M>>1;Ve[c[hb>>2]&127](Aa,Ua,bb,bb,9,9,Fb,Eb,Ia,ja);Ua=Za+(_a+16)|0;Ve[c[hb>>2]&127](Ua,Sa,bb,bb,9,9,Fb,Eb,Ia,ja);Gb=Za;Hb=Aa;Ib=Ua}if(ia){Jb=Gb;Kb=Hb;Lb=Ib}else{Ua=c[Ta>>2]|0;Jb=Gb+(c[Ea>>2]|0)|0;Kb=Hb+Ua|0;Lb=Ib+Ua|0}_e[c[mb+(Ka<<2)>>2]&511](b,Jb,cb,jb,gb<<2>>Ya,db<<2>>Ya);Ua=(c[wb>>2]|0)==0?jb:l;Aa=Db<<2>>Ya;Za=Cb<<2>>Ya;if((Ua|0)!=0){ja=mb+(A<<2)|0;_e[c[ja>>2]&511](e,Kb,bb,Ua,Aa,Za);_e[c[ja>>2]&511](f,Lb,bb,Ua,Aa,Za)}if((c[fb>>2]|0)==0){break}else{rb=zb;mb=n}}vb=zb;qb=c[ub>>2]|0;nb=n}return}n=a+14216|0;nb=a+136|0;ub=a+140|0;qb=a+7656|0;zb=a+7660|0;vb=a+13924|0;fb=o<<1;Lb=a+28|0;Kb=a+14220|0;Cb=h+4|0;Db=h+8|0;jb=a+11540|0;wb=a+9944|0;Jb=a+148|0;Ib=l+1|0;Hb=a+152|0;Ea=a+11316|0;Gb=i;i=0;while(1){Ta=i<<1;Eb=0;do{Fb=Eb+Ta|0;hb=c[a+11744+(g<<5)+(Fb<<3)>>2]|0;eb=c[a+11744+(g<<5)+(Fb<<3)+4>>2]|0;Fb=c[(c[j>>2]|0)+800>>2]|0;Ab=Fb-1|0;lb=c[n>>2]|0;Bb=Ab+lb|0;ib=(Bb|0)>3?3:Bb;Bb=8>>>(Fb>>>0);kb=(2<<Fb)-1|0;sb=c[nb>>2]>>Fb;ob=c[ub>>2]>>Fb;xb=c[qb>>2]<<1;k=c[zb>>2]<<1;if((c[vb>>2]|0)==0){Mb=hb;Nb=eb}else{Mb=(hb|0)/2|0;Nb=(eb|0)/2|0}eb=Nb+(ca((1<<Fb)-1|0,Eb-(Eb^i)|0)|0)|0;hb=Mb&kb;yb=eb&kb;Xa=c[m>>2]|0;tb=Bb<<1;mb=Fb+1|0;rb=(ca(Xa,tb)|0)+(Mb>>mb)|0;va=(eb>>mb)+((ca(fb,Bb)|0)>>1)|0;pb=c[Lb>>2]|0;do{if((pb|0)==2){Ob=eb>>1&kb|yb&1;Pb=Mb>>1&kb|hb&1;Qb=va>>1;Rb=rb>>1}else if((pb|0)==1){_=(Mb|0)/4|0;V=(eb|0)/4|0;Ob=V<<1&kb;Pb=_<<1&kb;Qb=(V>>Fb)+(ca(Bb,o)|0)|0;Rb=(_>>Fb)+(ca(Xa,Bb)|0)|0}else{if((c[Kb>>2]|0)!=0){_=(Mb|0)/2|0;V=(eb|0)/2|0;Ob=V&kb;Pb=_&kb;Qb=(V>>mb)+((ca(Bb,o)|0)>>1)|0;Rb=(_>>mb)+(ca(Xa,Bb)|0)|0;break}if((lb|0)==0){Ob=yb;Pb=hb;Qb=va;Rb=rb;break}_=(Mb|0)/2|0;Ob=yb;Pb=_&kb;Qb=va;Rb=(_>>mb)+(ca(Xa,Bb)|0)|0}}while(0);Bb=(c[h>>2]|0)+((ca(va,xb)|0)+rb)|0;Xa=(ca(Qb,k)|0)+Rb|0;mb=(c[Cb>>2]|0)+Xa|0;kb=(c[Db>>2]|0)+Xa|0;Xa=sb-((hb|0)!=0)-tb|0;lb=ob>>1;if(rb>>>0>((Xa|0)>0?Xa:0)>>>0|(Qb|0)<0){oa=124}else{Xa=lb-((yb|0)!=0)-l|0;if(va>>>0>((Xa|0)>0?Xa:0)>>>0){oa=124}else{Sb=Bb;Tb=mb;Ub=kb}}if((oa|0)==124){oa=0;Xa=xb>>1;Ve[c[jb>>2]&127](c[wb>>2]|0,Bb,Xa,Xa,17,18,rb,va<<1,sb,ob);Xa=c[wb>>2]|0;Bb=(c[Jb>>2]|0)*18|0;eb=Xa+Bb|0;pb=k>>1;bb=Qb<<1;A=sb>>1;Ve[c[jb>>2]&127](eb,mb,pb,pb,9,10,Rb,bb,A,lb);mb=Xa+(Bb+16)|0;Ve[c[jb>>2]&127](mb,kb,pb,pb,9,10,Rb,bb,A,lb);Sb=Xa;Tb=eb;Ub=mb}if((Eb|0)==0){Vb=b;Wb=e;Xb=f}else{mb=c[Hb>>2]|0;Vb=b+(c[Jb>>2]|0)|0;Wb=e+mb|0;Xb=f+mb|0}if((Eb|0)==(i|0)){Yb=Sb;Zb=Tb;_b=Ub}else{mb=c[Hb>>2]|0;Yb=Sb+(c[Jb>>2]|0)|0;Zb=Tb+mb|0;_b=Ub+mb|0}_e[c[Gb+(Ab<<2)>>2]&511](Vb,Yb,xb,l,hb<<2>>Fb,yb<<2>>Fb);if((c[Kb>>2]|0)==0){$b=l}else{$b=Ib-Eb>>1}mb=Pb<<2>>Fb;eb=Ob<<2>>Fb;if(($b|0)!=0){Xa=Gb+(ib<<2)|0;_e[c[Xa>>2]&511](Wb,Zb,k,$b,mb,eb);_e[c[Xa>>2]&511](Xb,_b,k,$b,mb,eb)}Eb=Eb+1|0;}while((Eb|0)<2);Eb=i+1|0;if((Eb|0)<2){Gb=Ea;i=Eb}else{break}}return};default:{return}}}function UTa(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=h-1|0;if((c|0)<0){l=0}else{l=(k|0)<(c|0)?k:c}c=i-1|0;if((e|0)<0){m=0}else{m=(c|0)<(e|0)?c:e}if((f|0)<0){n=0}else{n=(k|0)<(f|0)?k:f}if((g|0)<0){o=0}else{o=(c|0)<(g|0)?c:g}g=b+((ca(m,j)|0)+l)|0;a[g]=(a[g]|0)+100;g=n-l|0;c=o-m|0;if((((g|0)>-1?g:-g|0)|0)>(((c|0)>-1?c:-c|0)|0)){c=(l|0)>(n|0);g=c?o:m;f=c?n:l;k=(ca(g,j)|0)+f|0;e=(c?l:n)-f|0;f=((c?m:o)-g<<16|0)/(e|0)|0;if((e|0)<0){return}else{p=0}do{g=ca(p,f)|0;c=g>>16;i=g&65535;g=p+k|0;h=b+(g+(ca(c,j)|0))|0;a[h]=(d[h]|0)+(((65536-i|0)*100|0)>>>16);if((i|0)!=0){h=b+(g+(ca(c+1|0,j)|0))|0;a[h]=(d[h]|0)+((i*100|0)>>>16)}p=p+1|0;}while((p|0)<=(e|0));return}e=(m|0)>(o|0);p=e?m:o;k=e?o:m;m=e?n:l;o=(ca(k,j)|0)+m|0;f=p-k|0;if((p|0)==(k|0)){q=0}else{q=((e?l:n)-m<<16|0)/(f|0)|0}if((f|0)<0){return}m=o+1|0;n=0;do{l=ca(n,q)|0;e=l&65535;k=(l>>16)+(ca(n,j)|0)|0;l=b+(k+o)|0;a[l]=(d[l]|0)+(((65536-e|0)*100|0)>>>16);if((e|0)!=0){l=b+(m+k)|0;a[l]=(d[l]|0)+((e*100|0)>>>16)}n=n+1|0;}while((n|0)<=(f|0));return}function VTa(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0;l=i;m=a;c[a+11736>>2]=d;c[a+11740>>2]=e;c[a+12488>>2]=j;c[a+9924>>2]=k;k=a+12476|0;c[k>>2]=g;g=a+12480|0;c[g>>2]=h;nrc(a+11744|0,f|0,64)|0;NTa(m);f=a+4|0;h=8>>>((c[(c[f>>2]|0)+800>>2]|0)>>>0);j=a+12496|0;c[j>>2]=(c[j>>2]|0)+2;j=a+12500|0;c[j>>2]=(c[j>>2]|0)+2;j=a+12504|0;c[j>>2]=(c[j>>2]|0)+2;j=a+12508|0;c[j>>2]=(c[j>>2]|0)+2;j=a+12512|0;c[j>>2]=(c[j>>2]|0)+1;j=a+12516|0;c[j>>2]=(c[j>>2]|0)+1;j=a+12544|0;c[j>>2]=(c[j>>2]|0)+(h<<1);e=a+12548|0;c[e>>2]=(c[e>>2]|0)+h;d=a+12552|0;c[d>>2]=(c[d>>2]|0)+h;h=a+14340|0;qe[c[a+10096>>2]&1023](c[h>>2]|0);n=c[g>>2]|0;g=ca(c[a+148>>2]|0,n)|0;o=c[k>>2]|0;c[j>>2]=(c[a+7624>>2]|0)+(o+g<<4);g=ca(16>>>((c[a+14220>>2]|0)>>>0),n)|0;n=ca(g,c[a+152>>2]|0)|0;g=(ca(16>>>((c[a+14216>>2]|0)>>>0),o)|0)+n|0;c[e>>2]=(c[a+7628>>2]|0)+g;c[d>>2]=(c[a+7632>>2]|0)+g;if((b|0)==0){p=c[h>>2]|0;KTa(m,p);i=l;return}KIb(c[f>>2]|0,48,2260144,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;p=c[h>>2]|0;KTa(m,p);i=l;return}function WTa(a,f,g,h,j,k,l,m){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;n=i;if((k|0)>(l|0)){i=n;return}o=(m|0)<64;p=j<<8;j=(p|0)>0;q=c[a+1108>>2]|0;r=0;s=k;while(1){a:do{if((q|0)==128|(q|0)==102|(q|0)==350){k=0;do{t=ca(e[h+((d[a+1128+k|0]|0)<<1)>>1]|0,s)|0;u=Frc(2097152,0,t,(t|0)<0|0?-1:0)|0;c[f+(s<<8)+(k<<2)>>2]=u;k=k+1|0;}while((k|0)<64)}else{if((q|0)==8){k=s;u=(s|0)<0|0?-1:0;t=0;while(1){v=d[a+1128+t|0]|0;w=Erc(e[1445288+(t<<1)>>1]|0,0,k,u)|0;x=Erc(w,G,e[h+(v<<1)>>1]|0,0)|0;v=Frc(0,8,x,G)|0;c[f+(s<<8)+(t<<2)>>2]=v;t=t+1|0;if((t|0)>=64){break a}}}if(j){t=0;do{u=ca(e[h+((d[a+1128+t|0]|0)<<1)>>1]|0,s)|0;k=Frc(2097152,0,u,(u|0)<0|0?-1:0)|0;c[f+(s<<8)+(t<<2)>>2]=k;k=65536/(u|0)|0;u=k&65535;v=g+(s<<8)+(t<<1)|0;b[v>>1]=u;x=k&65535;if((x|0)==0|(x|0)==32768){b[v>>1]=32767;y=32767}else{y=u}u=y&65535;b[g+(s<<8)+128+(t<<1)>>1]=((u>>>1)+p|0)/(u|0)|0;t=t+1|0;}while((t|0)<64)}else{t=0;do{u=ca(e[h+((d[a+1128+t|0]|0)<<1)>>1]|0,s)|0;v=Frc(2097152,0,u,(u|0)<0|0?-1:0)|0;c[f+(s<<8)+(t<<2)>>2]=v;v=65536/(u|0)|0;u=v&65535;x=g+(s<<8)+(t<<1)|0;b[x>>1]=u;k=v&65535;if((k|0)==0|(k|0)==32768){b[x>>1]=32767;z=32767}else{z=u}u=z&65535;b[g+(s<<8)+128+(t<<1)>>1]=(p-(u>>>1)|0)/(u|0)|0;t=t+1|0;}while((t|0)<64)}}}while(0);if(o){if((q|0)==8){t=m;u=r;while(1){x=Erc(e[1445288+(t<<1)>>1]|0,0,8191,0)|0;k=G;v=c[f+(s<<8)+(t<<2)>>2]|0;w=Erc(v,(v|0)<0|0?-1:0,x>>>14|k<<18,k>>>14|0<<18)|0;k=G;x=u;while(1){v=Arc(w|0,k|0,x|0)|0;A=G;B=0;if((A|0)>(B|0)|(A|0)==(B|0)&v>>>0>2147483647>>>0){x=x+1|0}else{break}}k=t+1|0;if((k|0)<64){t=k;u=x}else{C=x;break}}}else{u=m;t=r;while(1){k=c[f+(s<<8)+(u<<2)>>2]|0;w=Erc(k,(k|0)<0|0?-1:0,8191,0)|0;k=G;v=t;while(1){B=Arc(w|0,k|0,v|0)|0;A=G;D=0;if((A|0)>(D|0)|(A|0)==(D|0)&B>>>0>2147483647>>>0){v=v+1|0}else{break}}k=u+1|0;if((k|0)<64){u=k;t=v}else{C=v;break}}}}else{C=r}t=s+1|0;if((t|0)>(l|0)){break}else{r=C;s=t}}if((C|0)==0){i=n;return}KIb(0,32,2501760,(s=i,i=i+8|0,c[s>>2]=21-C,s)|0);i=s;i=n;return}function XTa(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b|0;h=c[g>>2]|0;i=b+4|0;j=c[i>>2]|0;k=(j|0)>1;if((f|0)==0){if(k){l=j-1|0;m=h<<1}else{n=je(h<<j|0)|0;o=b+12|0;p=c[o>>2]|0;y=n;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;l=j+31|0;m=0}c[g>>2]=m;c[i>>2]=l;return}if(k){q=j-1|0;r=h<<1|1;s=b+12|0}else{k=je(1>>>((1-j|0)>>>0)|h<<j|0)|0;h=b+12|0;b=c[h>>2]|0;y=k;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;q=j+31|0;r=1;s=h}c[g>>2]=r;c[i>>2]=q;h=0;j=r;r=q;while(1){q=e[f+((d[1242080+h|0]|0)<<1)>>1]|0;if((r|0)>8){t=r-8|0;u=j<<8|q}else{b=je(q>>>((8-r|0)>>>0)|j<<r|0)|0;k=c[s>>2]|0;y=b;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;t=r+24|0;u=q}c[g>>2]=u;c[i>>2]=t;q=h+1|0;if((q|0)<64){h=q;j=u;r=t}else{break}}return}function YTa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[b+9136>>2]|0;e=b+144|0;if((c[e>>2]|0)<=0){return}f=b+12556|0;g=b+9976|0;h=b+4|0;b=0;do{i=c[(c[f>>2]|0)+(b<<2)>>2]|0;j=(((c[(c[g>>2]|0)+(i<<2)>>2]|0)*139|0)+8192|0)>>>14;k=c[h>>2]|0;l=c[k+500>>2]|0;m=c[k+504>>2]|0;if((j|0)<(l|0)){n=l&255}else{n=((j|0)>(m|0)?m:j)&255}a[d+i|0]=n;b=b+1|0;}while((b|0)<(c[e>>2]|0));return}function ZTa(a){a=a|0;var b=0,d=0,e=0;Zga(a+11548|0);b=a+14392|0;d=c[b>>2]|0;if((d|0)==0){c[b>>2]=4;e=4}else{e=d}d=a+14400|0;if((c[d>>2]|0)==0){c[d>>2]=662}c[a+14396>>2]=e;if((c[(c[a+4>>2]|0)+600>>2]|0)==0){return 0}c[b>>2]=78;return 0}function _Ta(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=c[a+364>>2]|0;qe[c[a+11164>>2]&1023](e);if((c[a+13184>>2]|0)!=0){re[c[a+14400>>2]&1023](a,e)}if((c[a+12488>>2]|0)==0){j=a+13076|0;k=a+13168|0;l=0;m=-1}else{if((c[a+228>>2]|0)==0){n=c[((f|0)<4?a+168|0:a+172|0)>>2]<<3}else{n=8}b[e>>1]=((b[e>>1]|0)+(n>>1)|0)/(n|0)|0;j=a+13072|0;k=(f|0)<4?a+13160|0:a+13164|0;l=1;m=0}f=c[k>>2]|0;k=c[j>>2]<<13;j=2097152-k-1|0;n=j<<1;o=63;while(1){p=d[i+o|0]|0;q=e+(p<<1)|0;if(((ca(b[q>>1]|0,c[f+(g<<8)+(p<<2)>>2]|0)|0)+j|0)>>>0>n>>>0){r=o;break}b[q>>1]=0;q=o-1|0;if((q|0)<(l|0)){r=m;break}else{o=q}}if((l|0)>(r|0)){s=0}else{o=0;m=l;while(1){l=d[i+m|0]|0;q=e+(l<<1)|0;p=ca(b[q>>1]|0,c[f+(g<<8)+(l<<2)>>2]|0)|0;if((p+j|0)>>>0>n>>>0){if((p|0)>0){l=p+k>>21;t=l;u=l&65535}else{l=k-p>>21;t=l;u=-l&65535}b[q>>1]=u;v=t|o}else{b[q>>1]=0;v=o}q=m+1|0;if((q|0)>(r|0)){s=v;break}else{o=v;m=q}}}c[h>>2]=(c[a+13084>>2]|0)<(s|0);if((c[a+11248>>2]|0)==1){return r|0}OTa(e,a+11184|0,i,r);return r|0}function $Ta(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[a+12488>>2]|0;g=a+13188+(f<<2)|0;c[g>>2]=(c[g>>2]|0)+1;g=a+13184|0;h=a+13196|0;a=0;do{i=d+(a<<1)|0;j=b[i>>1]|0;k=j<<16>>16;if(!(j<<16>>16==0)){l=(c[g>>2]|0)+(f<<8)+(a<<2)|0;m=c[l>>2]|0;if(j<<16>>16>0){c[l>>2]=m+k;j=k-(e[(c[h>>2]|0)+(f<<7)+(a<<1)>>1]|0)|0;n=(j|0)<0?0:j&65535}else{c[l>>2]=m-k;m=(e[(c[h>>2]|0)+(f<<7)+(a<<1)>>1]|0)+k|0;n=(m|0)>0?0:m&65535}b[i>>1]=n}a=a+1|0;}while((a|0)<64);return}function aUa(a,f,g,h,j){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0;k=i;i=i+1824|0;l=k|0;m=k+264|0;n=k+528|0;o=k+792|0;p=k+1056|0;q=k+1568|0;r=c[a+364>>2]|0;s=c[a+13088>>2]|0;t=(c[a+9972>>2]|0)>>>1;u=a+11164|0;qe[c[u>>2]&1023](f);if((c[a+13184>>2]|0)!=0){re[c[a+14400>>2]&1023](a,f)}v=h<<4;w=(h<<3)-8|8;x=a+12488|0;if((c[x>>2]|0)==0){y=c[a+13168>>2]|0;z=0;A=w;B=0;C=-1;D=a+13100|0;E=a+13104|0}else{if((c[a+228>>2]|0)==0){F=w;G=c[((g|0)<4?a+168|0:a+172|0)>>2]<<3}else{F=0;G=8}b[f>>1]=((b[f>>1]|0)+(G>>1)|0)/(G|0)|0;G=c[((g|0)<4?a+13160|0:a+13164|0)>>2]|0;if((c[a+14004>>2]|0)==0){if((c[a+28>>2]|0)==0){H=8}else{I=0}}else{H=8}if((H|0)==8){I=1048576}y=G;z=I;A=F;B=1;C=0;D=a+13092|0;E=a+13096|0}F=c[D>>2]|0;D=c[E>>2]|0;E=2097152-z-1|0;I=E<<1;G=63;while(1){if((G|0)<(B|0)){J=C;break}H=d[r+G|0]|0;if(((ca(b[f+(H<<1)>>1]|0,c[y+(h<<8)+(H<<2)>>2]|0)|0)+E|0)>>>0>I>>>0){J=G;break}else{G=G-1|0}}G=(B|0)>(J|0);do{if(G){c[j>>2]=(c[a+13084>>2]|0)>>>31}else{C=B;H=0;while(1){w=d[r+C|0]|0;K=ca(b[f+(w<<1)>>1]|0,c[y+(h<<8)+(w<<2)>>2]|0)|0;if((K+E|0)>>>0>I>>>0){if((K|0)>0){w=K+z>>21;c[p+(C<<2)>>2]=w;c[p+256+(C<<2)>>2]=w-1;L=w}else{w=z-K>>21;c[p+(C<<2)>>2]=-w;c[p+256+(C<<2)>>2]=1-w;L=w}c[q+(C<<2)>>2]=(L|0)>2?2:L;M=L|H}else{c[p+(C<<2)>>2]=K>>31|1;c[q+(C<<2)>>2]=1;M=H}K=C+1|0;if((K|0)>(J|0)){break}else{C=K;H=M}}c[j>>2]=(c[a+13084>>2]|0)<(M|0);if(G){break}c[n+(B<<2)>>2]=0;H=o|0;c[H>>2]=B;C=(c[u>>2]|0)==8;K=(J|0)<28;w=a+28|0;N=ca(t,s)|0;O=B;P=B;Q=0;R=0;S=0;T=1;while(1){U=d[r+O|0]|0;V=b[f+(U<<1)>>1]|0;W=V<<16>>16;X=V<<16>>16>-1?W:-W|0;if(C){Y=(ca(e[1368880+(U<<1)>>1]|0,X)|0)>>12}else{Y=X}X=ca(Y,Y)|0;W=c[q+(O<<2)>>2]|0;if((W|0)>0){V=((c[w>>2]|0)-1|0)>>>0<2>>>0;Z=T-1|0;_=(T|0)>0;$=O+1|0;aa=l+($<<2)|0;ba=m+($<<2)|0;da=0;ea=2013265920;fa=P;ga=Q;ha=R;ia=S;while(1){ja=c[p+(da<<8)+(O<<2)>>2]|0;ka=(ja|0)>-1?ja:-ja|0;if(V){la=(ca(ka,v)|0)+A|0}else{ma=d[a+11184+U|0]|0;if((c[x>>2]|0)==0){na=ca(ka<<1|1,h)|0;oa=(ca(na,e[a+12816+(ma<<1)>>1]|0)|0)>>4}else{na=ca(ka,h)|0;oa=(ca(na,e[a+12560+(ma<<1)>>1]|0)|0)>>3}la=(oa<<3)-8|8}ma=la-Y|0;na=(ca(ma,ma)|0)-X|0;ma=ja+64|0;do{if(ma>>>0<128>>>0){if(_){ka=Z;pa=ea;while(1){qa=c[o+(ka<<2)>>2]|0;ra=O-qa|0;sa=ca(d[F+((ra<<7)+ma)|0]|0,t)|0;ta=(c[n+(qa<<2)>>2]|0)+na+sa|0;if((ta|0)<(pa|0)){c[aa>>2]=ra;c[ba>>2]=ja;ua=ta}else{ua=pa}if((ka|0)>0){ka=ka-1|0;pa=ua}else{va=ua;break}}}else{va=ea}if(!V){wa=ia;xa=ha;ya=ga;za=fa;Aa=va;break}if(!_){wa=ia;xa=ha;ya=ga;za=fa;Aa=va;break}pa=ja&65535;ka=Z;ta=fa;ra=ga;sa=ha;qa=ia;while(1){Ba=c[o+(ka<<2)>>2]|0;Ca=O-Ba|0;Da=ca(d[D+((Ca<<7)+ma)|0]|0,t)|0;Ea=(c[n+(Ba<<2)>>2]|0)+na+Da|0;Da=(Ea|0)<(ra|0);Ba=Da?$:ta;Fa=Da?Ea:ra;Ea=Da?pa:sa;Ga=Da?Ca:qa;if((ka|0)>0){ka=ka-1|0;ta=Ba;ra=Fa;sa=Ea;qa=Ga}else{wa=Ga;xa=Ea;ya=Fa;za=Ba;Aa=va;break}}}else{qa=na+N|0;if(_){sa=Z;ra=ea;while(1){ta=c[o+(sa<<2)>>2]|0;ka=(c[n+(ta<<2)>>2]|0)+qa|0;if((ka|0)<(ra|0)){c[aa>>2]=O-ta;c[ba>>2]=ja;Ha=ka}else{Ha=ra}if((sa|0)>0){sa=sa-1|0;ra=Ha}else{Ia=Ha;break}}}else{Ia=ea}if(!V){wa=ia;xa=ha;ya=ga;za=fa;Aa=Ia;break}if(!_){wa=ia;xa=ha;ya=ga;za=fa;Aa=Ia;break}ra=ja&65535;sa=Z;ka=fa;ta=ga;pa=ha;Ba=ia;while(1){Fa=c[o+(sa<<2)>>2]|0;Ea=(c[n+(Fa<<2)>>2]|0)+qa|0;if((Ea|0)<(ta|0)){Ja=O-Fa|0;Ka=ra;La=Ea;Ma=$}else{Ja=Ba;Ka=pa;La=ta;Ma=ka}if((sa|0)>0){sa=sa-1|0;ka=Ma;ta=La;pa=Ka;Ba=Ja}else{wa=Ja;xa=Ka;ya=La;za=Ma;Aa=Ia;break}}}}while(0);ja=da+1|0;if((ja|0)<(W|0)){da=ja;ea=Aa;fa=za;ga=ya;ha=xa;ia=wa}else{Na=Aa;Oa=za;Pa=ya;Qa=xa;Ra=wa;Sa=$;break}}}else{Na=2013265920;Oa=P;Pa=Q;Qa=R;Ra=S;Sa=O+1|0}c[n+(Sa<<2)>>2]=Na;a:do{if(K){$=T;while(1){if(($|0)==0){Ta=0;break a}ia=$-1|0;if((c[n+(c[o+(ia<<2)>>2]<<2)>>2]|0)>(Na|0)){$=ia}else{Ta=$;break}}}else{$=Na+t|0;ia=T;while(1){if((ia|0)==0){Ta=0;break a}ha=ia-1|0;if((c[n+(c[o+(ha<<2)>>2]<<2)>>2]|0)>($|0)){ia=ha}else{Ta=ia;break}}}}while(0);c[o+(Ta<<2)>>2]=Sa;if((Sa|0)>(J|0)){break}else{O=Sa;P=Oa;Q=Pa;R=Qa;S=Ra;T=Ta+1|0}}do{if(((c[w>>2]|0)-1|0)>>>0<2>>>0){Ua=Ra;Va=Qa;Wa=Pa;Xa=Oa}else{T=c[H>>2]|0;S=J+1|0;if((T|0)>(S|0)){Ua=Ra;Va=Qa;Wa=2013265920;Xa=Oa;break}R=t<<1;Q=T;T=Oa;P=2013265920;O=Qa;K=Ra;while(1){N=(c[n+(Q<<2)>>2]|0)+((Q|0)==0?0:R)|0;if((N|0)<(P|0)){Ya=c[l+(Q<<2)>>2]|0;Za=c[m+(Q<<2)>>2]&65535;_a=N;$a=Q}else{Ya=K;Za=O;_a=P;$a=T}N=Q+1|0;if((N|0)>(S|0)){Ua=Ya;Va=Za;Wa=_a;Xa=$a;break}else{Q=N;T=$a;P=_a;O=Za;K=Ya}}}}while(0);H=a+13112+(g<<2)|0;c[H>>2]=Wa;K=b[f>>1]|0;O=K<<16>>16;P=K<<16>>16>-1?O:-O|0;O=Xa-1|0;mrc(f+(B<<1)|0,0,64-B<<1|0)|0;if((O|0)<(B|0)){ab=O;i=k;return ab|0}if((O|B|0)!=0){b[f+(d[a+368+O|0]<<1)>>1]=Va;K=O-Ua|0;if((K|0)>(B|0)){bb=K}else{ab=O;i=k;return ab|0}while(1){K=bb-1|0;b[f+(d[a+368+K|0]<<1)>>1]=c[m+(bb<<2)>>2];T=K-(c[l+(bb<<2)>>2]|0)|0;if((T|0)>(B|0)){bb=T}else{ab=O;break}}i=k;return ab|0}T=ca(P,P)|0;K=c[q>>2]|0;if((K|0)>0){Q=a+12816|0;if(((c[w>>2]|0)-1|0)>>>0<2>>>0){S=0;R=0;N=T;while(1){C=c[p+(S<<8)>>2]|0;ia=(((((ca((C|0)>-1?C:-C|0,v)|0)+A|0)>>>3)+4|0)>>>3<<6)-P|0;$=ca(ia,ia)|0;ia=C+64|0;if(ia>>>0<128>>>0){cb=d[D+ia|0]|0}else{cb=s}ia=(ca(cb,t)|0)+$|0;$=(ia|0)<(N|0);ha=$?C:R;C=$?ia:N;ia=S+1|0;if((ia|0)<(K|0)){S=ia;R=ha;N=C}else{db=ha;eb=C;break}}}else{N=0;R=0;S=T;while(1){w=c[p+(N<<8)>>2]|0;C=ca(((w|0)>-1?w:-w|0)<<1|1,h)|0;ha=(((((ca(C,e[Q>>1]|0)|0)>>4)+536870911|1)+4|0)>>>3<<6)-P|0;C=ca(ha,ha)|0;ha=w+64|0;if(ha>>>0<128>>>0){fb=d[D+ha|0]|0}else{fb=s}ha=(ca(fb,t)|0)+C|0;C=(ha|0)<(S|0);ia=C?w:R;w=C?ha:S;ha=N+1|0;if((ha|0)<(K|0)){N=ha;R=ia;S=w}else{db=ia;eb=w;break}}}}else{db=0;eb=T}b[f>>1]=db;c[H>>2]=eb-T;ab=(db|0)==0?-1:O;i=k;return ab|0}}while(0);mrc(f+(B<<1)|0,0,64-B<<1|0)|0;ab=J;i=k;return ab|0}function bUa(a){a=a|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;e=i;f=c[a+60>>2]|0;h=f;tTa(h);mrc(9419608,1,32)|0;c[f+12460>>2]=9349984;c[f+11856>>2]=9415528;c[f+100>>2]=0;c[f+112>>2]=0;j=a+48|0;k=c[j>>2]|0;a:do{if((k|0)==2){l=c[a+140>>2]|0;if((l|0)==0|(l|0)==4){m=l;n=9;break}KIb(a,16,2488784,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else if((k|0)==8|(k|0)==108){l=c[a+140>>2]|0;switch(l|0){case 12:case 13:case 14:{m=l;n=9;break a;break};case 0:case 4:case 5:{if(!((c[a+680>>2]|0)>-1)){m=l;n=9;break a}break};default:{}}KIb(a,16,2477856,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else{if((c[a+140>>2]|0)==0){n=12;break}KIb(a,16,2468280,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((n|0)==9){if((m|0)==14|(m|0)==5){c[f+14212>>2]=3;break}else if((m|0)==13|(m|0)==4){c[f+14212>>2]=2;break}else{n=12;break}}}while(0);if((n|0)==12){c[f+14212>>2]=1}m=a+72|0;c[f+24>>2]=c[m>>2];k=a+120|0;l=f+8|0;c[l>>2]=c[k>>2];q=a+124|0;r=f+12|0;c[r>>2]=c[q>>2];s=a+136|0;t=c[s>>2]|0;do{if((t|0)>600){if(!((c[a+680>>2]|0)>-2)){u=t;break}KIb(a,24,2458832,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=600,o)|0);i=o;c[s>>2]=600;u=600}else{u=t}}while(0);t=f+16|0;c[t>>2]=u;s=f+4|0;c[s>>2]=a;v=a+88|0;w=f+60|0;c[w>>2]=c[v>>2];c[f+64>>2]=c[a+92>>2];x=a+156|0;y=c[x>>2]|0;if((y|0)>16){KIb(a,16,2441928,(o=i,i=i+8|0,c[o>>2]=16,o)|0);i=o;c[x>>2]=16;z=16;A=c[t>>2]|0}else{z=y;A=u}u=f+68|0;c[u>>2]=z;z=a+12|0;y=f+48|0;c[y>>2]=c[(c[z>>2]|0)+12>>2];c[f+80>>2]=c[a+680>>2];x=f+13924|0;c[x>>2]=(c[v>>2]|0)>>>4&1;B=f+14004|0;c[B>>2]=c[a+180>>2];C=f+14252|0;c[C>>2]=(c[a+628>>2]|0)!=0;c[f+14176>>2]=c[a+324>>2];D=f+760|0;c[D>>2]=0;c[D+4>>2]=-2147483648;D=f+20|0;if((A|0)<2){c[D>>2]=1;c[t>>2]=12}else{c[D>>2]=0}c[f+11732>>2]=c[a+144>>2];t=(c[v>>2]|0)>>>1&1;A=f+52|0;c[A>>2]=t;E=c[s>>2]|0;do{if(+g[E+192>>2]!=0.0){n=28}else{if(+g[E+208>>2]!=0.0){n=28;break}if(+g[E+196>>2]!=0.0){n=28;break}if(+g[E+200>>2]!=0.0){n=28;break}if(+g[E+204>>2]!=0.0){n=28;break}if(+g[E+336>>2]!=0.0){n=28;break}if((c[f+14404>>2]&4|0)==0){F=0}else{n=28}}}while(0);if((n|0)==28){F=t^1}c[f+9980>>2]=F;F=f+13836|0;c[F>>2]=(c[w>>2]|0)>>>11&1;t=a+540|0;E=c[t>>2]|0;H=a+524|0;I=(c[H>>2]|0)==0;do{if((E|0)==0){if(I){J=0}else{n=48}}else{if(!I){if((c[H>>2]|0)==0){n=48;break}else{J=E;break}}switch(c[j>>2]|0){case 1:case 2:{if((E|0)>15e6){K=((E*112|0|0)/15e6|0)<<14}else{K=1835008}L=K;M=K;n=45;break};case 13:case 15:case 16:case 17:{do{if((E|0)>14999999){N=(((E*440|0)+1989934592|0)/234e5|0)+320|0;c[H>>2]=N;O=N}else{if((E|0)>1999999){N=(((E*240|0)-48e7|0)/13e6|0)+80|0;c[H>>2]=N;O=N;break}if((E|0)>383999){N=(((E*40|0)-1536e4|0)/1616e3|0)+40|0;c[H>>2]=N;O=N;break}else{c[H>>2]=40;O=40;break}}}while(0);N=O<<14;L=N;M=N;n=45;break};default:{P=E}}do{if((n|0)==45){c[H>>2]=M;if((L|0)==0){P=E;break}KIb(a,32,2430072,(o=i,i=i+8|0,c[o>>2]=(L|0)/8192|0,o)|0);i=o;P=c[t>>2]|0}}while(0);if((P|0)==0^(c[H>>2]|0)==0){n=48}else{J=P}}}while(0);do{if((n|0)==48){KIb(a,16,2419672,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;P=c[t>>2]|0;if((P|0)==0){J=0;break}if((c[H>>2]|0)==0){p=-1}else{J=P;break}i=e;return p|0}}while(0);P=a+544|0;L=c[P>>2]|0;do{if((L|0)==0){Q=0}else{if((J|0)==(L|0)){R=J}else{KIb(a,32,2410480,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;R=c[P>>2]|0}if((R|0)==0){Q=0;break}if((R|0)<=(c[m>>2]|0)){Q=R;break}KIb(a,16,2402856,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);R=c[t>>2]|0;do{if((R|0)!=0){t=c[m>>2]|0;if((R|0)<(t|0)){KIb(a,16,2395944,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else{if((R|0)!=(t|0)|(R|0)==(Q|0)){break}KIb(a,32,2388920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);Q=c[H>>2]|0;do{if((Q|0)!=0){H=c[m>>2]|0;R=c[a+104>>2]|0;t=Erc(R,(R|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;H=G;R=c[a+108>>2]|0;P=Erc(R,(R|0)<0|0?-1:0,Q,(Q|0)<0|0?-1:0)|0;R=G;if(!((H|0)>(R|0)|(H|0)==(R|0)&t>>>0>P>>>0)){break}KIb(a,16,2382088,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((c[A>>2]|0)==0){P=c[m>>2]|0;t=c[a+76>>2]|0;if(!(+(P|0)*(+(c[a+104>>2]|0)/+(c[a+108>>2]|0))>+(t|0))){break}KIb(a,16,2375480,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=P,o)|0);i=o;p=-1;i=e;return p|0}}while(0);m=c[s>>2]|0;A=c[m+540>>2]|0;do{if((A|0)!=0){if((c[m+544>>2]|0)!=(A|0)){break}if(!(((c[y>>2]|0)-1|0)>>>0<2>>>0)){break}P=Q-1|0;t=Erc(P,(P|0)<0|0?-1:0,9e4,0)|0;P=G;R=Erc(A,(A|0)<0|0?-1:0,65535,0)|0;H=G;if(!((P|0)>(H|0)|(P|0)==(H|0)&t>>>0>R>>>0)){break}KIb(a,32,2368744,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);do{if((c[w>>2]&4|0)!=0){A=c[y>>2]|0;if((A|0)==13|(A|0)==5|(A|0)==20|(A|0)==22){break}KIb(a,16,2353840,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);A=f+13788|0;do{if((c[A>>2]|0)!=0){if((c[(c[s>>2]|0)+296>>2]|0)==0){break}KIb(a,16,2345232,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((c[x>>2]|0)!=0){if((c[y>>2]|0)==13){break}KIb(a,16,2339152,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);x=c[u>>2]|0;Q=c[y>>2]|0;do{if((x|0)!=0){if(!((Q|0)==13|(Q|0)==1|(Q|0)==2)){KIb(a,16,2333520,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}if((x|0)>=0){break}KIb(a,16,2328040,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((Q|0)==13|(Q|0)==5|(Q|0)==20){x=a+224|0;m=c[x>>2]|0;R=c[a+228>>2]|0;if(!((m|0)>255|(R|0)>255)){S=Q;break}t=a+228|0;KIb(a,24,2322256,(o=i,i=i+16|0,c[o>>2]=m,c[o+8>>2]=R,o)|0);i=o;R=c[x>>2]|0;m=c[t>>2]|0;xKb(x,t,R,(R|0)<0|0?-1:0,m,(m|0)<0|0?-1:0,255,0)|0;S=c[y>>2]|0}else{S=Q}}while(0);b:do{if((S|0)==1){n=98}else if((S|0)==5|(S|0)==20){do{if((c[k>>2]|0)<=2048){if((c[q>>2]|0)>1152){break}if((S|0)==1){n=98;break b}else if(!((S|0)==5|(S|0)==20)){break b}do{if((c[k>>2]&3|0)==0){if((c[q>>2]&3|0)!=0){break}if((S|0)==1){n=98;break b}else{break b}}}while(0);KIb(a,16,2312728,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);KIb(a,16,2317144,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((n|0)==98){if((c[k>>2]|0)<=4095){if((c[q>>2]|0)<=4095){break}}KIb(a,16,2308032,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);Q=(S|0)==2;do{if(Q){if((c[k>>2]|0)<=16383){if((c[q>>2]|0)<=16383){break}}KIb(a,16,2302968,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);c:do{if((S|0)==6){do{if((c[k>>2]&15|0)==0){if((c[q>>2]&15|0)!=0){break}if((S|0)==7){n=110;break c}else{break c}}}while(0);KIb(a,16,2291712,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=e;return p|0}else if((S|0)==7){n=110}}while(0);do{if((n|0)==110){if((c[k>>2]&3|0)==0){if((c[q>>2]&3|0)==0){break}}KIb(a,16,2284904,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=e;return p|0}}while(0);do{if((S-18|0)>>>0<2>>>0){if((c[k>>2]&1|0)==0){break}KIb(a,16,2280952,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);k=c[w>>2]|0;do{if((k&537133056|0)!=0){if((S|0)==13|(S|0)==2){break}KIb(a,16,2276848,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((c[B>>2]|0)!=0){if((S|0)==13|(S|0)==2){break}KIb(a,16,2272360,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);q=c[f+14404>>2]|0;do{if((q&8|0)!=0){if((c[a+600>>2]|0)!=0){break}KIb(a,16,2267680,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);m=c[s>>2]|0;do{if((q&4|0)!=0){if((c[m+296>>2]|0)==2){break}KIb(a,16,2263984,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);if((c[m+308>>2]|0)<1e9&(k|0)<0){KIb(a,16,2260048,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}do{if((k&524288|0)==0){T=S}else{if(!Q){KIb(a,16,2255720,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}if((c[u>>2]|0)==0){T=2;break}KIb(a,16,2251472,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);do{if((c[f+14192>>2]|0)==1){if((c[a+504>>2]|0)<=12){break}KIb(a,16,2240920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);Q=m+808|0;S=c[Q>>2]|0;k=(S|0)>1;d:do{if(k){switch(T|0){case 13:case 1:case 2:case 8:case 20:{n=144;break d;break};default:{}}KIb(a,16,2235208,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}else{if((S|0)>=1){if((c[m+404>>2]|0)>1|k){n=144;break}else{U=S;break}}KIb(a,16,2231600,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}}while(0);if((n|0)==144){c[C>>2]=1;U=c[Q>>2]|0}if((U|0)>1&(T|0)==20){c[f+13824>>2]=1}T=a+108|0;U=c[T>>2]|0;do{if((U|0)!=0){Q=a+104|0;S=c[Q>>2]|0;if((S|0)==0){break}if((c[a+320>>2]|0)>4194303){KIb(a,16,2222992,(o=i,i=i+8|0,c[o>>2]=4194303,o)|0);i=o;p=-1;i=e;return p|0}k=a+168|0;do{if((c[k>>2]|0)==0){V=U;W=S}else{if((c[v>>2]&1024|0)==0){V=U;W=S;break}KIb(a,32,2219376,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[k>>2]=0;V=c[T>>2]|0;W=c[Q>>2]|0}}while(0);S=TIb(V,(V|0)<0|0?-1:0,W,(W|0)<0|0?-1:0)|0;m=S;if((m|0)>1){KIb(a,32,2216400,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;c[T>>2]=(c[T>>2]|0)/(m|0)|0;c[Q>>2]=(c[Q>>2]|0)/(m|0)|0}do{if((c[B>>2]|0)==0){m=c[y>>2]|0;if((m|0)==1|(m|0)==2|(m|0)==8|(m|0)==108){n=159;break}c[f+13072>>2]=0;c[f+13076>>2]=-64;X=0;Y=-64}else{n=159}}while(0);if((n|0)==159){c[f+13072>>2]=96;c[f+13076>>2]=0;X=96;Y=0}Q=a+500|0;m=c[Q>>2]|0;if((m|0)>(c[a+504>>2]|0)|(m|0)<1){KIb(a,16,2213800,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=e;return p|0}m=c[a+280>>2]|0;if((m|0)==999999){Z=X}else{c[f+13072>>2]=m;Z=m}m=c[a+284>>2]|0;S=f+13076|0;if((m|0)==999999){_=Y}else{c[S>>2]=m;_=m}m=a;q=f+13072|0;KIb(m,48,2211448,(o=i,i=i+16|0,c[o>>2]=Z,c[o+8>>2]=_,o)|0);i=o;R=c[s>>2]|0;t=c[R+108>>2]|0;if((c[j>>2]|0)==13&(t|0)>65535){KIb(m,16,2208624,(o=i,i=i+24|0,c[o>>2]=c[R+104>>2],c[o+8>>2]=t,c[o+16>>2]=65535,o)|0);i=o;p=-1;i=e;return p|0}R=t-1|0;t=R>>>0>65535>>>0;x=t?R>>>16:R;R=t?16:0;if((x&65280|0)==0){$=R;aa=x}else{$=R|8;aa=x>>>8}c[f+13844>>2]=$+1+(d[1359664+aa|0]|0);e:do{switch(c[(c[z>>2]|0)+12>>2]|0){case 7:{c[f+28>>2]=2;c[a+116>>2]=0;c[f+13944>>2]=1;c[f+13832>>2]=1;c[f+228>>2]=1;c[f+40>>2]=1;c[F>>2]=1;c[f+10048>>2]=0;break};case 22:{c[f+28>>2]=2;c[f+44>>2]=2;c[f+10048>>2]=1;c[C>>2]=0;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 6:{c[f+28>>2]=2;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 13:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;x=c[u>>2]|0;R=(x|0)==0;c[f+13944>>2]=R&1;c[a+116>>2]=R?0:x+1|0;break};case 17:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;c[f+14092>>2]=3;c[f+14088>>2]=1;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 18:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;c[f+14092>>2]=4;c[f+14088>>2]=1;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 8:case 108:{c[f+28>>2]=3;c[D>>2]=1;if((sQa(h)|0)<0){p=-1;i=e;return p|0}else{c[a+116>>2]=0;c[f+13944>>2]=1;break e}break};case 5:{if((D5a(1379168,8,c[l>>2]|0,c[r>>2]|0)|0)!=8){c[f+28>>2]=2;c[a+116>>2]=0;c[f+13944>>2]=1;break e}x=c[r>>2]|0;KIb(m,16,2195464,(o=i,i=i+16|0,c[o>>2]=c[l>>2],c[o+8>>2]=x,o)|0);i=o;p=-1;i=e;return p|0};case 4:{if((Iga(c[l>>2]|0,c[r>>2]|0)|0)>=0){c[f+28>>2]=1;c[a+116>>2]=0;c[f+13944>>2]=1;break e}x=c[r>>2]|0;KIb(m,16,2199952,(o=i,i=i+16|0,c[o>>2]=c[l>>2],c[o+8>>2]=x,o)|0);i=o;p=-1;i=e;return p|0};case 19:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;c[f+14092>>2]=5;c[f+14088>>2]=1;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 20:{c[f+28>>2]=2;c[f+40>>2]=1;x=(c[v>>2]|0)>>>24&1;c[f+228>>2]=x;c[f+13832>>2]=x;x=c[v>>2]&2048;c[F>>2]=x>>>11;if((c[A>>2]|x|0)==0){ba=(c[f+13816>>2]|0)!=0|0}else{ba=1}c[f+10048>>2]=ba;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 16:{c[f+28>>2]=2;c[f+32>>2]=1;c[f+10048>>2]=1;c[f+14092>>2]=2;c[a+116>>2]=0;c[f+13944>>2]=1;break};case 2:{c[f+28>>2]=0;x=c[w>>2]&524288;c[f+13944>>2]=x>>>19;if((x|0)==0){ca=(c[u>>2]|0)+1|0}else{ca=0}c[a+116>>2]=ca;c[C>>2]=1;break};case 1:{c[f+28>>2]=0;x=c[w>>2]&524288;c[f+13944>>2]=x>>>19;if((x|0)==0){da=(c[u>>2]|0)+1|0}else{da=0}c[a+116>>2]=da;break};default:{p=-1;i=e;return p|0}}}while(0);c[a+176>>2]=(c[f+13944>>2]|0)==0;c[f+56>>2]=1;if((c[v>>2]&537133056|0)==0){ea=(c[f+14200>>2]|0)==0|0}else{ea=0}c[f+14152>>2]=ea;c[f+14224>>2]=ea;if((rTa(h)|0)<0){p=-1;i=e;return p|0}c[(c[s>>2]|0)+804>>2]=f+7624;m=f+14092|0;do{if((c[m>>2]|0)==0){n=203}else{x=pJb(135200)|0;c[f+14108>>2]=x;if((x|0)!=0){n=203;break}KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);f:do{if((n|0)==203){x=pJb(256)|0;c[(c[s>>2]|0)+668>>2]=x;x=c[s>>2]|0;if((c[x+668>>2]|0)==0){KIb(x,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=pJb(8192)|0;R=f+13160|0;c[R>>2]=x;if((x|0)==0){KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=pJb(8192)|0;c[f+13164>>2]=x;if((x|0)==0){KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=pJb(8192)|0;t=f+13168|0;c[t>>2]=x;if((x|0)==0){KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=pJb(8192)|0;H=f+13172|0;c[H>>2]=x;if((x|0)==0){KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=pJb(8192)|0;c[f+13176>>2]=x;if((x|0)==0){KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=pJb(8192)|0;P=f+13180|0;c[P>>2]=x;if((x|0)==0){KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=pJb(144)|0;c[f+160>>2]=x;if((x|0)==0){KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}x=pJb(144)|0;c[f+164>>2]=x;J=c[s>>2]|0;if((x|0)==0){KIb(J,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}do{if((c[J+312>>2]|0)!=0){x=pJb(256)|0;c[f+13196>>2]=x;if((x|0)!=0){break}KIb(c[s>>2]|0,16,2192960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break f}}while(0);Zga(f+11548|0);J=f+14392|0;x=c[J>>2]|0;if((x|0)==0){c[J>>2]=4;fa=4}else{fa=x}x=f+14400|0;if((c[x>>2]|0)==0){c[x>>2]=662}c[f+14396>>2]=fa;x=c[s>>2]|0;if((c[x+600>>2]|0)!=0){c[J>>2]=78}if((c[f+13832>>2]|0)!=0){c[f+9896>>2]=1379496}c[f+13920>>2]=5;J=f+10056|0;h8(J,f+10540|0,c[x+244>>2]|0);h8(J,f+10564|0,c[(c[s>>2]|0)+596>>2]|0);x=f+28|0;L=c[x>>2]|0;if((L|0)==1){Mga(h);ga=c[x>>2]|0}else{ga=L}if((ga|0)==2){Bqb(h)}if((c[m>>2]|0)!=0){NUa(h)}if((c[x>>2]|0)==0){yRa(h)}L=f+12560|0;E=L;M=f+12816|0;O=M;K=0;do{I=d[f+(K+11184)|0]|0;do{if((c[y>>2]|0)==13){if((c[B>>2]|0)==0){n=244;break}b[E+(I<<1)>>1]=b[1344696+(K<<1)>>1]|0;b[O+(I<<1)>>1]=b[1344568+(K<<1)>>1]|0}else{n=244}}while(0);do{if((n|0)==244){n=0;if(((c[x>>2]|0)-1|0)>>>0<2>>>0){N=b[1346720+(K<<1)>>1]|0;b[O+(I<<1)>>1]=N;b[E+(I<<1)>>1]=N;break}else{b[E+(I<<1)>>1]=b[1346848+(K<<1)>>1]|0;b[O+(I<<1)>>1]=b[1346720+(K<<1)>>1]|0;break}}}while(0);N=c[s>>2]|0;ha=c[N+300>>2]|0;if((ha|0)==0){ia=N}else{b[E+(I<<1)>>1]=b[ha+(K<<1)>>1]|0;ia=c[s>>2]|0}ha=c[ia+304>>2]|0;if((ha|0)!=0){b[O+(I<<1)>>1]=b[ha+(K<<1)>>1]|0}K=K+1|0;}while((K|0)<64);if((c[x>>2]|0)!=3){WTa(J,c[R>>2]|0,c[H>>2]|0,L,c[q>>2]|0,c[Q>>2]|0,31,1);WTa(J,c[t>>2]|0,c[P>>2]|0,M,c[S>>2]|0,c[Q>>2]|0,31,0)}if((YYa(h)|0)<0){p=-1;i=e;return p|0}K=c[a+868>>2]|0;if((K|0)!=0){c[f+14592>>2]=K}if((c[k>>2]|0)!=2){p=0;i=e;return p|0}K=f+14596|0;O=a+356|0;E=0;while(1){if((E|0)>=((c[u>>2]|0)+2|0)){p=0;n=263;break}ha=UHb()|0;c[K+(E<<2)>>2]=ha;if((ha|0)==0){p=-12;n=263;break}c[ha+80>>2]=0;c[ha+68>>2]=c[l>>2]>>c[O>>2];c[ha+72>>2]=c[r>>2]>>c[O>>2];N=XHb(ha,32)|0;if((N|0)<0){p=N;n=263;break}else{E=E+1|0}}if((n|0)==263){i=e;return p|0}}}while(0);cUa(a)|0;p=-1313558101;i=e;return p|0}}while(0);KIb(a,16,2227776,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=e;return p|0}function cUa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+60>>2]|0;d=b;aZa(d);xTa(d);if((c[b+28>>2]|0)==3){tQa(d)}mJb(a+96|0);VHb(b+14596|0);VHb(b+14600|0);VHb(b+14604|0);VHb(b+14608|0);VHb(b+14612|0);VHb(b+14616|0);VHb(b+14620|0);VHb(b+14624|0);VHb(b+14628|0);VHb(b+14632|0);VHb(b+14636|0);VHb(b+14640|0);VHb(b+14644|0);VHb(b+14648|0);VHb(b+14652|0);VHb(b+14656|0);VHb(b+14660|0);VHb(b+14664|0);a=b+5400|0;kTa(a);mTa(d,a);mJb((c[b+4>>2]|0)+668|0);mJb(b+14108|0);a=b+13164|0;d=a;e=b+13160|0;if((c[d>>2]|0)!=(c[e>>2]|0)){mJb(a)}a=b+13176|0;f=a;g=b+13172|0;if((c[f>>2]|0)==(c[g>>2]|0)){c[d>>2]=0;c[f>>2]=0;mJb(e);h=b+13168|0;mJb(h);mJb(g);i=b+13180|0;mJb(i);j=b+160|0;mJb(j);k=b+164|0;mJb(k);l=b+13196|0;mJb(l);return 0}mJb(a);c[d>>2]=0;c[f>>2]=0;mJb(e);h=b+13168|0;mJb(h);mJb(g);i=b+13180|0;mJb(i);j=b+160|0;mJb(j);k=b+164|0;mJb(k);l=b+13196|0;mJb(l);return 0}function dUa(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0.0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0;m=i;i=i+288|0;n=m|0;o=m+80|0;p=m+88|0;q=m+168|0;r=m+176|0;s=m+256|0;t=m+264|0;u=m+272|0;v=m+280|0;w=c[f+60>>2]|0;x=w;z=w+944|0;A=c[z>>2]|0;B=w+112|0;c[B>>2]=(c[B>>2]|0)+1;C=w+68|0;D=c[C>>2]|0;if((D|0)==0){E=(c[w+13944>>2]|0)==0|0}else{E=D}do{if((k|0)==0){H=0}else{D=k+136|0;I=c[D>>2]|0;J=c[D+4>>2]|0;D=w+100|0;K=c[D>>2]|0;c[D>>2]=K+1;D=w+760|0;L=c[D>>2]|0;M=c[D+4>>2]|0;N=(L|0)!=0|(M|0)!=(-2147483648|0);do{if((I|0)==0&(J|0)==(-2147483648|0)){if(N){O=wrc(L,M,1,0)|0;P=G;c[D>>2]=O;c[D+4>>2]=P;KIb(c[w+4>>2]|0,32,2623128,(S=i,i=i+16|0,c[S>>2]=O,c[S+8>>2]=P,S)|0);i=S;U=P;V=O;break}else{U=(K|0)<0|0?-1:0;V=K;break}}else{do{if(N){if((J|0)>(M|0)|(J|0)==(M|0)&I>>>0>L>>>0){if(!((c[w+13944>>2]|0)==0&(K|0)==1)){break}O=xrc(I,J,L,M)|0;P=w+768|0;c[P>>2]=O;c[P+4>>2]=G;break}else{KIb(c[w+4>>2]|0,16,2624640,(S=i,i=i+32|0,c[S>>2]=I,c[S+8>>2]=J,c[S+16>>2]=L,c[S+24>>2]=M,S)|0);i=S;W=-1;i=m;return W|0}}}while(0);c[D>>2]=I;c[D+4>>2]=J;U=J;V=I}}while(0);I=w+148|0;J=w+152|0;D=c[J>>2]|0;M=w+8|0;if((c[M>>2]&15|0)==0){L=c[I>>2]|0;if((c[w+12>>2]&15|0)==0){X=(c[k+40>>2]|0)==(D|0)?(c[k+36>>2]|0)==(D|0)?(c[k+32>>2]|0)==(L|0)?(c[k+360>>2]|0)!=0|0:0:0:0;Y=L}else{Z=L;_=17}}else{Z=c[I>>2]|0;_=17}if((_|0)==17){X=0;Y=Z}L=k|0;a:do{if((X|0)==0|(c[L>>2]&7|0)!=0|(Y&7|0)!=0){D=CTa(x,0)|0;if((D|0)<0){W=-1;i=m;return W|0}N=c[w+156>>2]|0;P=N+(D*2224|0)|0;c[N+(D*2224|0)+2192>>2]=3;if((lTa(x,P,0)|0)<0){W=-1;i=m;return W|0}do{if(((c[P>>2]|0)+16|0)==(c[L>>2]|0)){if(((c[N+(D*2224|0)+4>>2]|0)+16|0)!=(c[k+4>>2]|0)){break}if(((c[N+(D*2224|0)+8>>2]|0)+16|0)==(c[k+8>>2]|0)){$=P;break a}}}while(0);O=w+4|0;tKb(c[(c[O>>2]|0)+140>>2]|0,u,v)|0;aa=w+12|0;da=w+48|0;ea=w+11260|0;fa=0;while(1){ga=c[k+32+(fa<<2)>>2]|0;ia=(fa|0)!=0;ja=c[(ia?J:I)>>2]|0;ka=ia?c[u>>2]|0:0;la=ia?c[v>>2]|0:0;ia=c[M>>2]>>ka;ma=c[aa>>2]|0;na=ma>>la;oa=c[k+(fa<<2)>>2]|0;pa=c[N+(D*2224|0)+(fa<<2)>>2]|0;qa=c[O>>2]|0;do{if((c[da>>2]|0)==108){if((c[qa+88>>2]&16384|0)!=0){ra=na;break}ra=((ma+15|0)/16|0)<<4>>la}else{ra=na}}while(0);na=(c[qa+524>>2]|0)==0?pa+16|0:pa;do{if((ga|0)==(ja|0)){nrc(na|0,oa|0,ca(ra,ga)|0)|0}else{if((ra|0)==0){break}else{sa=oa;ta=ra;ua=na}while(1){ma=ta-1|0;nrc(ua|0,sa|0,ia)|0;if((ma|0)==0){break}else{sa=sa+ga|0;ta=ma;ua=ua+ja|0}}}}while(0);if((c[M>>2]&15|0)==0){if((c[aa>>2]&15|0)!=0){_=37}}else{_=37}if((_|0)==37){_=0;Se[c[ea>>2]&1023](na,ja,ia,ra,16>>>(ka>>>0),16>>>(la>>>0),2)}ga=fa+1|0;if((ga|0)<3){fa=ga}else{$=P;break}}}else{P=CTa(x,1)|0;if((P|0)<0){W=-1;i=m;return W|0}fa=c[w+156>>2]|0;ea=fa+(P*2224|0)|0;c[fa+(P*2224|0)+2192>>2]=3;if((YHb(ea|0,k)|0)<0){W=-1;i=m;return W|0}if((lTa(x,ea,1)|0)<0){W=-1}else{$=ea;break}i=m;return W|0}}while(0);if((ZHb($|0,k)|0)<0){W=-1;i=m;return W|0}else{c[$+164>>2]=K;M=$+136|0;c[M>>2]=V;c[M+4>>2]=U;H=$;break}}}while(0);$=w+160|0;U=1;V=c[$>>2]|0;do{c[V+(U-1<<2)>>2]=c[V+(U<<2)>>2];U=U+1|0;V=c[$>>2]|0}while((U|0)<36);c[V+(E<<2)>>2]=H;H=w+164|0;E=1;V=c[H>>2]|0;do{c[V+(E-1<<2)>>2]=c[V+(E<<2)>>2];E=E+1|0;V=c[H>>2]|0}while((E|0)<36);c[V+140>>2]=0;V=c[H>>2]|0;b:do{if((c[V>>2]|0)==0){E=c[c[$>>2]>>2]|0;if((E|0)==0){va=V;break}U=w+4|0;k=c[U>>2]|0;if((c[k+584>>2]|0)==0){if((c[k+588>>2]|0)==0){wa=k}else{_=49}}else{_=49}do{if((_|0)==49){if((c[B>>2]|0)>=(c[w+16>>2]|0)){wa=k;break}ra=c[w+9852>>2]|0;if((ra|0)==0){wa=k;break}ua=w+120|0;ta=w+116|0;sa=E+2196|0;v=w+10568|0;u=0;Y=0;X=0;Z=0;M=c[ua>>2]|0;I=k;while(1){J=c[E+32+(Z<<2)>>2]|0;L=(Z|0)!=0?1:2;if((ca(L,M)|0)>0){ea=E+(Z<<2)|0;P=ra+(Z<<2)|0;fa=u;aa=Y;da=X;O=0;D=c[ta>>2]|0;N=M;ga=I;while(1){if((ca(D,L)|0)>0){oa=ca(O,J)|0;pa=fa;qa=aa;ma=da;xa=0;while(1){ya=xa+oa<<3;za=Xe[c[v>>2]&511](w,(c[ea>>2]|0)+(((c[sa>>2]|0)!=0?0:16)+ya)|0,(c[P>>2]|0)+ya|0,J,8)|0;Aa=c[U>>2]|0;ya=c[Aa+592>>2]|0;switch(((ya|0)>-1?ya:-ya|0)|0){case 2:{ya=za;Ba=(za|0)<0|0?-1:0;Ca=wrc(Erc(ya,Ba,ya,Ba)|0,G,qa,pa)|0;Da=ma;Ea=G;Fa=Ca;break};case 1:{Da=((za|0)>-1?za:-za|0)+ma|0;Ea=pa;Fa=qa;break};case 3:{Ca=za;Ba=(za|0)<0|0?-1:0;ya=Erc(Erc(Ca,Ba,Ca,Ba)|0,G,Ca,Ba)|0;Ba=G;Ca=-1;Ga=(Ba|0)>(Ca|0)|(Ba|0)==(Ca|0)&ya>>>0>-1>>>0;Ca=xrc(0,0,ya,Ba)|0;Ha=wrc(Ga?ya:Ca,Ga?Ba:G,qa,pa)|0;Da=ma;Ea=G;Fa=Ha;break};case 0:{Da=(ma|0)>(za|0)?ma:za;Ea=pa;Fa=qa;break};case 4:{Ha=za;Ba=(za|0)<0|0?-1:0;za=Erc(Ha,Ba,Ha,Ba)|0;Ba=G;Ha=wrc(Erc(za,Ba,za,Ba)|0,G,qa,pa)|0;Da=ma;Ea=G;Fa=Ha;break};default:{Da=ma;Ea=pa;Fa=qa}}Ha=xa+1|0;Ia=c[ta>>2]|0;if((Ha|0)<(ca(Ia,L)|0)){pa=Ea;qa=Fa;ma=Da;xa=Ha}else{break}}Ja=Ea;Ka=Fa;La=Da;Ma=Ia;Na=c[ua>>2]|0;Oa=Aa}else{Ja=fa;Ka=aa;La=da;Ma=D;Na=N;Oa=ga}xa=O+1|0;if((xa|0)<(ca(Na,L)|0)){fa=Ja;aa=Ka;da=La;O=xa;D=Ma;N=Na;ga=Oa}else{Pa=Ja;Qa=Ka;Ra=La;Sa=Na;Ta=Oa;break}}}else{Pa=u;Qa=Y;Ra=X;Sa=M;Ta=I}ga=Z+1|0;if((ga|0)<3){u=Pa;Y=Qa;X=Ra;Z=ga;M=Sa;I=Ta}else{break}}I=(Ra|0)==0;M=I?Qa:Ra;Z=I?Pa:(Ra|0)<0|0?-1:0;I=c[Ta+592>>2]|0;if((I|0)<0){Ua=+T(+((+(M>>>0)+ +(Z|0)*4294967296.0)/+(ca(c[ta>>2]|0,Sa)|0)),+(-1.0/+(I|0)));Va=(F=+Ua,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Wa=~~+Ua>>>0}else{Va=Z;Wa=M}M=c[Ta+584>>2]|0;Z=(M|0)<0|0?-1:0;if(!((Va|0)<(Z|0)|(Va|0)==(Z|0)&Wa>>>0<M>>>0)){M=c[Ta+588>>2]|0;Z=Erc(c[w+9968>>2]|0,0,M,(M|0)<0|0?-1:0)|0;M=G;I=M>>8|((M|0)<0|0?-1:0)<<24;if(!((Va|0)<(I|0)|(Va|0)==(I|0)&Wa>>>0<(Z>>>8|M<<24)>>>0)){wa=Ta;break}}WHb(c[c[$>>2]>>2]|0);bZa(x,0)|0;va=c[H>>2]|0;break b}}while(0);E=w+9852|0;do{if((c[E>>2]|0)!=0){if((c[w+20>>2]|0)!=0){break}k=w+60|0;c:do{if((c[k>>2]&1024|0)!=0){K=(c[C>>2]|0)+1|0;if((K|0)<=0){break}M=c[$>>2]|0;Z=c[(c[M>>2]|0)+164>>2]|0;I=c[w+13232>>2]|0;X=w+13236|0;Y=0;while(1){Xa=Y+Z|0;if((Xa|0)>=(I|0)){break c}u=c[M+(Y<<2)>>2]|0;if((u|0)==0){break}c[u+88>>2]=c[(c[X>>2]|0)+(Xa*80|0)+40>>2];Y=Y+1|0;if((Y|0)>=(K|0)){break c}}c[(c[X>>2]|0)+((Xa-1|0)*80|0)+40>>2]=2}}while(0);ta=c[wa+168>>2]|0;d:do{if((ta|0)==0){K=c[C>>2]|0;while(1){if((K|0)==0){Ya=0;_=142;break d}if((c[(c[$>>2]|0)+(K<<2)>>2]|0)==0){K=K-1|0}else{Za=K;_=143;break}}}else if((ta|0)==1){K=c[C>>2]|0;if((K|0)>0){X=w+148|0;Y=w+8|0;M=w+12|0;I=w+10108|0;Z=w+10100|0;u=1;ua=c[$>>2]|0;sa=K;while(1){v=c[ua+(u<<2)>>2]|0;do{if((v|0)==0){_a=ua;$a=sa}else{if((c[v+2184>>2]|0)!=0){_a=ua;$a=sa;break}ra=c[v>>2]|0;ga=c[c[ua+(u-1<<2)>>2]>>2]|0;N=c[X>>2]|0;D=c[Y>>2]&-16;O=c[M>>2]&-16;if((O|0)>0){da=(D|0)>0;aa=0;fa=0;while(1){if(da){L=ca(fa,N)|0;J=aa;P=0;while(1){ea=P+L|0;la=ra+ea|0;ka=Xe[c[I>>2]&511](0,la,ga+ea|0,N,16)|0;ia=(We[c[Z>>2]&2047](la,N)|0)+128>>8;la=0;ja=0;while(1){na=(ca(la,N)|0)+ea|0;xa=0;ab=ja;do{ma=(d[ra+(na+xa)|0]|0)-ia|0;ab=((ma|0)>-1?ma:-ma|0)+ab|0;xa=xa+1|0;}while((xa|0)<16);xa=la+1|0;if((xa|0)<16){la=xa;ja=ab}else{break}}ja=((ab+500|0)<(ka|0))+J|0;la=P+16|0;if((la|0)<(D|0)){J=ja;P=la}else{bb=ja;break}}}else{bb=aa}P=fa+16|0;if((P|0)<(O|0)){aa=bb;fa=P}else{break}}fa=c[$>>2]|0;cb=bb;db=fa;eb=c[fa+(u<<2)>>2]|0}else{cb=0;db=ua;eb=v}c[eb+2184>>2]=cb+1;_a=db;$a=c[C>>2]|0}}while(0);v=u+1|0;if((v|0)<($a+1|0)){u=v;ua=_a;sa=$a}else{fb=$a;break}}}else{fb=K}sa=fb+1|0;ua=w+144|0;u=0;while(1){if((u|0)>=(sa|0)){break}Z=c[(c[$>>2]|0)+(u<<2)>>2]|0;if((Z|0)==0){break}if(((c[Z+2184>>2]|0)-1|0)>((c[ua>>2]|0)/(c[(c[U>>2]|0)+380>>2]|0)|0|0)){break}else{u=u+1|0}}ua=u-1|0;sa=(ua|0)<0?0:ua;ua=sa+1|0;if((ua|0)<=0){Za=sa;_=143;break}K=c[$>>2]|0;Z=0;while(1){c[(c[K+(Z<<2)>>2]|0)+2184>>2]=0;I=Z+1|0;if((I|0)<(ua|0)){Z=I}else{Za=sa;_=143;break}}}else if((ta|0)==2){sa=t;Z=b5a(c[wa+48>>2]|0)|0;ua=mWa(0)|0;c[t>>2]=ua;K=c[U>>2]|0;u=c[K+356>>2]|0;if(!(u>>>0<4>>>0)){KIb(0,0,2183008,(S=i,i=i+24|0,c[S>>2]=2625856,c[S+8>>2]=2178624,c[S+16>>2]=1205,S)|0);i=S;Hd();return 0}I=c[w+10032>>2]|0;M=c[w+10036>>2]|0;Y=(M|0)==0?I:M;M=((ca(Y,Y)|0)+64|0)>>>7;c[ua+120>>2]=c[w+8>>2]>>u;c[ua+124>>2]=c[w+12>>2]>>u;X=ua+88|0;c[X>>2]=33026;c[X>>2]=c[K+88>>2]&16|33026;c[ua+296>>2]=c[K+296>>2];c[ua+232>>2]=c[K+232>>2];c[ua+240>>2]=c[K+240>>2];c[ua+236>>2]=c[K+236>>2];c[ua+140>>2]=0;X=K+104|0;K=ua+104|0;v=c[X+4>>2]|0;c[K>>2]=c[X>>2];c[K+4>>2]=v;c[ua+156>>2]=c[C>>2];if((_4a(ua,Z,0)|0)<0){Ya=-1;_=142;break}Z=c[C>>2]|0;if((Z+2|0)>0){ua=x+11264+(u<<2)|0;u=0;v=Z;while(1){K=(u|0)!=0;if(K){gb=(c[$>>2]|0)+(u-1<<2)|0}else{gb=E}X=c[gb>>2]|0;do{if((X|0)==0){hb=v}else{if(K){if((c[(c[$>>2]|0)+(u-1<<2)>>2]|0)==0){hb=v;break}}fa=c[X>>2]|0;aa=c[X+4>>2]|0;O=c[X+8>>2]|0;D=c[X+36>>2]|0;ra=c[X+40>>2]|0;if((c[X+2196>>2]|0)!=0|K^1){ib=fa;jb=aa;kb=O}else{ib=fa+16|0;jb=aa+16|0;kb=O+16|0}O=x+14596+(u<<2)|0;aa=c[O>>2]|0;fa=c[t>>2]|0;_e[c[ua>>2]&511](c[aa>>2]|0,c[aa+32>>2]|0,ib,c[X+32>>2]|0,c[fa+120>>2]|0,c[fa+124>>2]|0);fa=c[O>>2]|0;aa=c[t>>2]|0;_e[c[ua>>2]&511](c[fa+4>>2]|0,c[fa+36>>2]|0,jb,D,c[aa+120>>2]>>1,c[aa+124>>2]>>1);aa=c[O>>2]|0;O=c[t>>2]|0;_e[c[ua>>2]&511](c[aa+8>>2]|0,c[aa+40>>2]|0,kb,ra,c[O+120>>2]>>1,c[O+124>>2]>>1);hb=c[C>>2]|0}}while(0);X=u+1|0;if((X|0)<(hb+2|0)){u=X;v=hb}else{lb=hb;break}}}else{lb=Z}e:do{if((lb+1|0)>0){v=w+14596|0;u=r;ua=r+28|0;X=n;K=n+28|0;O=p;ra=p+28|0;if((c[c[$>>2]>>2]|0)==0){mb=-1;break}aa=0;D=2147483647;fa=-1;N=-1;ga=c[t>>2]|0;while(1){mrc(ga+720|0,0,24)|0;da=c[v>>2]|0;c[da+88>>2]=1;c[da+168>>2]=118;mrc(u|0,0,80)|0;J1(r);P=i5a(ga,r,da,s)|0;if((P|0)<0){nb=P}else{P=c[ua>>2]|0;P1(r);nb=P}P=c[C>>2]|0;if((P+1|0)>0){da=aa+1|0;J=0;L=0;ja=0;la=P;while(1){ia=((J|0)%(da|0)|0|0)==(aa|0)|(J|0)==(la|0);ea=J+1|0;xa=c[x+14596+(ea<<2)>>2]|0;c[xa+88>>2]=ia?2:3;c[xa+168>>2]=ia?I:Y;ia=c[t>>2]|0;mrc(O|0,0,80)|0;J1(p);na=i5a(ia,p,xa,q)|0;if((na|0)<0){ob=na}else{na=c[ra>>2]|0;P1(p);ob=na}na=(ca(ob,M)|0)>>4;xa=wrc(na,(na|0)<0|0?-1:0,ja,L)|0;na=G;ia=c[C>>2]|0;if((ea|0)<(ia+1|0)){J=ea;L=na;ja=xa;la=ia}else{pb=ob;qb=na;rb=xa;sb=ia;break}}}else{pb=nb;qb=0;rb=0;sb=P}la=c[t>>2]|0;if((pb|0)==0){tb=qb;ub=rb;vb=sb;wb=la}else{ja=qb;L=rb;J=la;do{mrc(X|0,0,80)|0;J1(n);la=i5a(J,n,0,o)|0;if((la|0)<0){xb=la}else{la=c[K>>2]|0;P1(n);xb=la}la=(ca(xb,M)|0)>>4;L=wrc(la,(la|0)<0|0?-1:0,L,ja)|0;ja=G;J=c[t>>2]|0}while((xb|0)!=0);tb=ja;ub=L;vb=c[C>>2]|0;wb=J}P=wb+720|0;la=wb+728|0;da=c[la>>2]|0;ia=c[la+4>>2]|0;la=wb+736|0;xa=c[la>>2]|0;na=c[la+4>>2]|0;la=wrc(c[P>>2]|0,c[P+4>>2]|0,ub,tb)|0;P=wrc(la,G,da,ia)|0;ia=wrc(P,G,xa,na)|0;na=G;xa=(na|0)<(D|0)|(na|0)==(D|0)&ia>>>0<fa>>>0;P=xa?aa:N;da=aa+1|0;if((da|0)>=(vb+1|0)){mb=P;break e}if((c[(c[$>>2]|0)+(da<<2)>>2]|0)==0){mb=P;break}else{aa=da;D=xa?na:D;fa=xa?ia:fa;N=P;ga=wb}}}else{mb=-1}}while(0);r5a(c[t>>2]|0)|0;mJb(sa);Za=mb;_=143}else{KIb(wa,16,2628792,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;Ya=0;_=142}}while(0);f:do{if((_|0)==142){yb=Ya;zb=c[$>>2]|0}else if((_|0)==143){ta=c[$>>2]|0;if((Za|0)>0){Ab=Za}else{yb=Za;zb=ta;break}while(1){M=Ab;while(1){Bb=M-1|0;Y=c[(c[ta+(Bb<<2)>>2]|0)+88>>2]|0;if(!((Y|0)==3|(Y|0)==0)){break}if((Bb|0)>0){M=Bb}else{yb=Ab;zb=ta;break f}}if((Bb|0)>0){Ab=Bb}else{yb=Bb;zb=ta;break}}}}while(0);do{if((c[(c[zb+(yb<<2)>>2]|0)+88>>2]|0)==3){if((yb|0)!=(c[C>>2]|0)){break}KIb(c[U>>2]|0,16,2627256,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}}while(0);ta=c[B>>2]|0;sa=c[w+16>>2]|0;do{if((ta+yb|0)<(sa|0)){Cb=yb}else{if((c[w+14404>>2]&2|0)!=0&(sa|0)>(ta|0)){Cb=sa+~ta|0;break}else{M=(c[k>>2]|0)<0?0:yb;c[(c[(c[$>>2]|0)+(M<<2)>>2]|0)+88>>2]=1;Cb=M;break}}}while(0);ta=c[$>>2]|0;if((c[k>>2]|0)>-1|(Cb|0)==0){Db=Cb}else{Db=(((c[(c[ta+(Cb<<2)>>2]|0)+88>>2]|0)==1)<<31>>31)+Cb|0}c[c[H>>2]>>2]=c[ta+(Db<<2)>>2];ta=c[H>>2]|0;sa=c[ta>>2]|0;M=sa+88|0;if((c[M>>2]|0)!=1){c[M>>2]=2}M=w+104|0;Y=c[M>>2]|0;c[M>>2]=Y+1;c[sa+160>>2]=Y;if((Db|0)>0){Eb=0;Fb=ta}else{va=ta;break b}while(1){ta=Eb+1|0;c[Fb+(ta<<2)>>2]=c[(c[$>>2]|0)+(Eb<<2)>>2];Y=c[H>>2]|0;sa=c[Y+(ta<<2)>>2]|0;c[sa+88>>2]=3;I=c[M>>2]|0;c[M>>2]=I+1;c[sa+160>>2]=I;if((ta|0)<(Db|0)){Eb=ta;Fb=Y}else{va=Y;break b}}}}while(0);c[c[H>>2]>>2]=c[c[$>>2]>>2];U=c[H>>2]|0;E=c[U>>2]|0;c[E+88>>2]=1;M=w+104|0;k=c[M>>2]|0;c[M>>2]=k+1;c[E+160>>2]=k;va=U}else{va=V}}while(0);V=c[va>>2]|0;do{if((V|0)==0){mTa(x,w+5400|0)}else{c[V+2192>>2]=(c[V+88>>2]|0)!=3?3:0;va=w+5400|0;$=va;mTa(x,$);Fb=nTa(x,$,c[c[H>>2]>>2]|0)|0;if((Fb|0)!=0){if((Fb|0)<0){W=-1}else{break}i=m;return W|0}Fb=c[c[H>>2]>>2]|0;do{if((c[Fb+2196>>2]|0)==0){if((c[(c[w+4>>2]|0)+524>>2]|0)!=0){_=165;break}c[w+9856>>2]=Fb;$=va;c[$>>2]=(c[$>>2]|0)+16;$=w+5404|0;c[$>>2]=(c[$>>2]|0)+16;$=w+5408|0;c[$>>2]=(c[$>>2]|0)+16;$=w+5412|0;c[$>>2]=(c[$>>2]|0)+16}else{_=165}}while(0);do{if((_|0)==165){va=CTa(x,0)|0;if((va|0)<0){W=-1;i=m;return W|0}Fb=c[w+156>>2]|0;$=Fb+(va*2224|0)|0;c[Fb+(va*2224|0)+2192>>2]=c[(c[c[H>>2]>>2]|0)+2192>>2];if((lTa(x,$,0)|0)<0){W=-1;i=m;return W|0}if((ZHb($|0,c[c[H>>2]>>2]|0)|0)<0){W=-1;i=m;return W|0}else{WHb(c[c[H>>2]>>2]|0);c[(c[c[H>>2]>>2]|0)+2196>>2]=0;c[w+9856>>2]=$;break}}}while(0);$=w+7624|0;mTa(x,$);if((nTa(x,$,c[w+9856>>2]|0)|0)<0){W=-1;i=m;return W|0}else{c[w+108>>2]=c[w+5564>>2];break}}}while(0);do{if((c[w+5400>>2]|0)==0){c[w+13216>>2]=0}else{H=w+116|0;V=w+120|0;$=(ca((c[H>>2]|0)*3100|0,c[V>>2]|0)|0)+1e4|0;va=d5a(f,j,$,($|0)<0|0?-1:0)|0;if((va|0)<0){W=va;i=m;return W|0}va=w+13792|0;if((c[va>>2]|0)!=0){c[w+13804>>2]=U1(j,3,ca((c[H>>2]|0)*12|0,c[V>>2]|0)|0)|0;c[w+13808>>2]=0;c[w+13800>>2]=0;c[w+13796>>2]=0}H=(A|0)>0;if(H){$=w+816|0;Fb=j+24|0;Eb=j+28|0;Db=0;do{Cb=c[$+(Db<<2)>>2]|0;yb=c[Cb+808>>2]|0;C=c[Cb+812>>2]|0;zb=c[V>>2]|0;Bb=c[Fb>>2]|0;Ab=c[Eb>>2]|0;Za=Ab;Ya=(Ab|0)<0|0?-1:0;Ab=Erc(Za,Ya,yb,(yb|0)<0|0?-1:0)|0;yb=zb;wa=(zb|0)<0|0?-1:0;zb=Crc(Ab,G,yb,wa)|0;Ab=zb;zb=Erc(Za,Ya,C,(C|0)<0|0?-1:0)|0;C=Crc(zb,G,yb,wa)|0;wa=C-Ab|0;C=(wa|0)<0;yb=C?0:Bb+Ab|0;Ab=C?0:wa;c[Cb+804>>2]=Ab<<3;c[Cb+792>>2]=yb;c[Cb+800>>2]=yb+Ab;c[Cb+796>>2]=yb;c[Cb+788>>2]=32;c[Cb+784>>2]=0;Db=Db+1|0;}while((Db|0)<(A|0))}Db=c[w+5488>>2]|0;Eb=w+9992|0;c[Eb>>2]=Db;do{if((Db|0)==3){Gb=3}else{Fb=c[w+9848>>2]|0;if((Fb|0)==0){Gb=Db;break}if((Fb|0)==(c[w+9852>>2]|0)){Gb=Db;break}if((c[Fb+360>>2]|0)==0){Gb=Db;break}mTa(x,Fb);Gb=c[Eb>>2]|0}}while(0);Db=w+9856|0;Fb=c[Db>>2]|0;c[Fb+88>>2]=Gb;c[Fb+84>>2]=(Gb|0)==1;Fb=w+7624|0;$=Fb;mTa(x,$);Cb=nTa(x,$,c[Db>>2]|0)|0;if((Cb|0)<0){W=Cb;i=m;return W|0}do{if((c[Eb>>2]|0)==3){Hb=c[w+9848>>2]|0}else{Cb=w+9852|0;$=c[Cb>>2]|0;c[w+9848>>2]=$;if((c[w+10008>>2]|0)!=0){Hb=$;break}c[Cb>>2]=c[Db>>2];Hb=$}}while(0);do{if((Hb|0)!=0){$=w+952|0;mTa(x,$);Cb=c[w+9848>>2]|0;if((c[Cb+360>>2]|0)==0){break}yb=nTa(x,$,Cb)|0;if((yb|0)<0){W=yb}else{break}i=m;return W|0}}while(0);yb=w+9852|0;do{if((c[yb>>2]|0)!=0){Cb=w+3176|0;mTa(x,Cb);$=c[yb>>2]|0;if((c[$+360>>2]|0)==0){break}Ab=nTa(x,Cb,$)|0;if((Ab|0)<0){W=Ab}else{break}i=m;return W|0}}while(0);yb=c[w+14172>>2]|0;if((yb|0)!=3){Ab=(yb|0)==2;yb=w+7656|0;$=c[yb>>2]|0;if(Ab){Cb=Fb;c[Cb>>2]=(c[Cb>>2]|0)+$}c[yb>>2]=$<<1;$=w+984|0;c[$>>2]=c[$>>2]<<1;$=w+3208|0;c[$>>2]=c[$>>2]<<1;$=w+7660|0;yb=c[$>>2]|0;if(Ab){Cb=w+7628|0;c[Cb>>2]=(c[Cb>>2]|0)+yb}c[$>>2]=yb<<1;yb=w+988|0;c[yb>>2]=c[yb>>2]<<1;yb=w+3212|0;c[yb>>2]=c[yb>>2]<<1;yb=w+7664|0;$=c[yb>>2]|0;if(Ab){Cb=w+7632|0;c[Cb>>2]=(c[Cb>>2]|0)+$}c[yb>>2]=$<<1;$=w+992|0;c[$>>2]=c[$>>2]<<1;$=w+3216|0;c[$>>2]=c[$>>2]<<1;$=w+7668|0;yb=c[$>>2]|0;if(Ab){Ab=w+7636|0;c[Ab>>2]=(c[Ab>>2]|0)+yb}c[$>>2]=yb<<1;yb=w+996|0;c[yb>>2]=c[yb>>2]<<1;yb=w+3220|0;c[yb>>2]=c[yb>>2]<<1}do{if((c[w+14004>>2]|0)==0){if((c[w+48>>2]|0)==2){_=203;break}if(((c[w+28>>2]|0)-1|0)>>>0<2>>>0){c[w+14384>>2]=c[w+14368>>2];c[w+14388>>2]=c[w+14372>>2];break}else{c[w+14384>>2]=c[w+14352>>2];c[w+14388>>2]=c[w+14356>>2];break}}else{_=203}}while(0);if((_|0)==203){c[w+14384>>2]=c[w+14360>>2];c[w+14388>>2]=c[w+14364>>2]}yb=w+13184|0;$=c[yb>>2]|0;Ab=w+4|0;if(($|0)==0){Ib=w+13188|0;Jb=w+13192|0}else{Cb=w+13196|0;wa=w+13188|0;C=c[wa>>2]|0;if((C|0)>65536){Bb=0;do{zb=$+(Bb<<2)|0;c[zb>>2]=c[zb>>2]>>1;Bb=Bb+1|0;}while((Bb|0)<64);Bb=c[wa>>2]>>1;c[wa>>2]=Bb;Kb=Bb}else{Kb=C}Bb=(c[Ab>>2]|0)+312|0;zb=c[Bb>>2]|0;Ya=ca(zb,Kb)|0;Za=c[Cb>>2]|0;mb=0;do{t=c[$+(mb<<2)>>2]|0;b[Za+(mb<<1)>>1]=(((t|0)/2|0)+Ya|0)/(t+1|0)|0;mb=mb+1|0;}while((mb|0)<64);mb=w+13192|0;Ya=c[mb>>2]|0;if((Ya|0)>65536){Cb=0;do{C=$+256+(Cb<<2)|0;c[C>>2]=c[C>>2]>>1;Cb=Cb+1|0;}while((Cb|0)<64);Cb=c[mb>>2]>>1;c[mb>>2]=Cb;Lb=c[Bb>>2]|0;Mb=Cb}else{Lb=zb;Mb=Ya}Cb=ca(Lb,Mb)|0;C=0;while(1){t=c[$+256+(C<<2)>>2]|0;b[Za+128+(C<<1)>>1]=(((t|0)/2|0)+Cb|0)/(t+1|0)|0;t=C+1|0;if((t|0)<64){C=t}else{Ib=wa;Jb=mb;break}}}mb=w+108|0;wa=w+12424|0;C=wa;Cb=w+12432|0;Za=w+48|0;$=w+13856|0;Ya=w+13872|0;zb=w+13864|0;Bb=w+13874|0;t=w+12440|0;wb=w+14088|0;vb=w+12472|0;tb=w+60|0;ub=w+10036|0;xb=w+9968|0;n=w+9960|0;o=w+9972|0;rb=w+10004|0;qb=w+13164|0;sb=qb;pb=w+13160|0;nb=w+13176|0;ob=nb;p=w+13172|0;q=w+12488|0;r=w+124|0;s=w+12492|0;lb=w+52|0;hb=w+816|0;kb=w+9800|0;jb=w+9792|0;ib=w+14092|0;gb=w+13816|0;fb=w+11640|0;$a=w+11648|0;_a=w+11556|0;db=w+11644|0;cb=w+11652|0;eb=w+11560|0;bb=w+11716|0;ab=w+11676|0;Xa=w+11680|0;Ta=w+11720|0;Wa=w+11684|0;Va=w+11688|0;Sa=w+11724|0;Ra=w+11692|0;Pa=w+11696|0;Qa=w+11728|0;Oa=w+11700|0;Na=w+11704|0;La=w+11636|0;Ka=w+11708|0;Ja=w+11660|0;Ma=w+11664|0;Aa=w+11712|0;Ia=w+11668|0;Da=w+11672|0;Fa=w+13084|0;Ea=w+28|0;U=w+14176|0;k=w+9892|0;E=w+9888|0;M=w+12560|0;Y=w+12688|0;ta=w+10056|0;I=w+13072|0;sa=w+7708|0;Z=w+7712|0;ga=w+12480|0;N=w+12476|0;fa=w+784|0;D=fa;aa=w+788|0;K=w+792|0;X=w+796|0;ra=w+13700|0;O=w+364|0;ua=w+13668|0;u=w+14140|0;v=w+14180|0;P=w+14224|0;ia=w+13940|0;xa=w+13664|0;na=w+13672|0;da=w+13676|0;la=w+13680|0;ea=w+13684|0;ma=w+13688|0;qa=w+13692|0;pa=w+13696|0;oa=w+14456|0;Ha=w+14008|0;Ba=w+7848|0;za=Ba;Ga=w+7856|0;Ca=w+7864|0;ya=fa;fa=f+636|0;Nb=f+632|0;Ob=f+660|0;Pb=f+640|0;Qb=f+644|0;Rb=f+648|0;Sb=w+144|0;Tb=f+652|0;Ub=f+656|0;Vb=w+10048|0;Wb=w+1e4|0;Xb=f+524|0;Yb=w+13240|0;Zb=f+556|0;_b=w+13224|0;$b=w+9980|0;ac=w+9924|0;bc=w+13848|0;cc=w+13852|0;dc=hb;ec=w+9976|0;fc=w+9816|0;gc=w+20|0;hc=w+11260|0;ic=Fb;jc=w+7656|0;kc=w+136|0;lc=w+140|0;mc=w+7628|0;nc=w+7660|0;oc=w+7632|0;pc=w+7664|0;qc=w+32|0;g:while(1){rc=c[mb>>2]|0;sc=c[z>>2]|0;mrc(wa|0,0,16)|0;tc=c[Za>>2]|0;do{if((tc-1|0)>>>0<2>>>0){_=229}else{if((c[qc>>2]|0)==0){break}if((c[ib>>2]|0)==0){_=229}}}while(0);do{if((_|0)==229){_=0;uc=(c[Db>>2]|0)+136|0;vc=c[(c[Ab>>2]|0)+104>>2]|0;wc=Erc(vc,(vc|0)<0|0?-1:0,c[uc>>2]|0,c[uc+4>>2]|0)|0;uc=G;c[$>>2]=wc;c[$+4>>2]=uc;if((c[Eb>>2]|0)==3){vc=e[Ya>>1]|0;xc=xrc(wc,uc,c[zb>>2]|0,c[zb+4>>2]|0)|0;yc=wrc(xc,G,vc,0)|0;b[Bb>>1]=yc;break}else{yc=xrc(wc,uc,c[zb>>2]|0,c[zb+4>>2]|0)|0;b[Ya>>1]=yc;c[zb>>2]=wc;c[zb+4>>2]=uc;break}}}while(0);if((tc|0)==13){gSa(x)}c[t>>2]=0;uc=c[Eb>>2]|0;do{if((uc|0)==1){if((c[ib>>2]|0)>2){c[vb>>2]=1;break}else{c[vb>>2]=0;break}}else if((uc|0)!=3){if((c[wb>>2]|0)==0){wc=c[Za>>2]|0;if(!((wc|0)==20|(wc|0)==13)){break}}c[vb>>2]=c[vb>>2]^1}}while(0);tc=c[tb>>2]|0;do{if((tc&1024|0)==0){if((tc&2|0)!=0){break}if((uc|0)==3){zc=ub}else{zc=x+10024+(c[rb>>2]<<2)|0}wc=c[zc>>2]|0;c[xb>>2]=wc;yc=((wc*139|0)+8192|0)>>>14;c[n>>2]=yc;vc=c[Ab>>2]|0;xc=c[vc+500>>2]|0;Ac=c[vc+504>>2]|0;if((yc|0)<(xc|0)){Bc=xc}else{Bc=(yc|0)>(Ac|0)?Ac:yc}c[n>>2]=Bc;c[o>>2]=((ca(wc,wc)|0)+64|0)>>>7}else{if((eUa(x,1)|0)<0){W=-1;_=420;break g}cZa(x)}}while(0);uc=c[Za>>2]|0;if(!((uc|0)==108|(uc|0)==8)){if((c[sb>>2]|0)!=(c[pb>>2]|0)){mJb(qb)}uc=c[ob>>2]|0;if((uc|0)==(c[p>>2]|0)){Cc=uc}else{mJb(nb);Cc=c[p>>2]|0}c[sb>>2]=c[pb>>2];c[ob>>2]=Cc}c[q>>2]=0;uc=1;while(1){if((uc|0)>=(sc|0)){break}if((pTa(c[x+816+(uc<<2)>>2]|0,x)|0)<0){W=-1;_=420;break g}else{uc=uc+1|0}}if(($qb(x)|0)<0){W=-1;_=420;break}uc=c[Eb>>2]|0;do{if((uc|0)==1){tc=ca(c[V>>2]|0,c[r>>2]|0)|0;if((tc|0)>0){wc=c[s>>2]|0;yc=0;do{b[wc+(yc<<1)>>1]=1;yc=yc+1|0;}while((yc|0)<(tc|0))}if((c[lb>>2]|0)!=0){break}tc=c[Ab>>2]|0;se[c[tc+824>>2]&127](tc,896,hb,0,sc,4)|0}else{tc=c[Ab>>2]|0;yc=tc+348|0;c[xb>>2]=((ca(c[yc>>2]|0,c[xb>>2]|0)|0)+128|0)>>>8;wc=c[yc>>2]|0;yc=Erc(wc,(wc|0)<0|0?-1:0,c[o>>2]|0,0)|0;wc=wrc(yc,G,128,0)|0;c[o>>2]=wc>>>8|G<<24;do{if((uc|0)==3){Dc=tc}else{wc=c[tc+256>>2]|0;if((wc|0)==0){Dc=tc;break}if(!((c[rb>>2]|0)==1|(wc|0)==2)){Dc=tc;break}se[c[tc+824>>2]&127](tc,306,hb,0,sc,4)|0;Dc=c[Ab>>2]|0}}while(0);se[c[Dc+824>>2]&127](Dc,826,hb,0,sc,4)|0}}while(0);uc=(sc|0)>1;if(uc){tc=1;do{wc=c[x+816+(tc<<2)>>2]|0;yc=wc+12440|0;c[t>>2]=(c[t>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=wc+12424|0;Ac=wrc(c[C>>2]|0,c[C+4>>2]|0,c[yc>>2]|0,c[yc+4>>2]|0)|0;c[C>>2]=Ac;c[C+4>>2]=G;c[yc>>2]=0;c[yc+4>>2]=0;yc=wc+12432|0;wc=wrc(c[Cb>>2]|0,c[Cb+4>>2]|0,c[yc>>2]|0,c[yc+4>>2]|0)|0;c[Cb>>2]=wc;c[Cb+4>>2]=G;c[yc>>2]=0;c[yc+4>>2]=0;tc=tc+1|0;}while((tc|0)<(sc|0))}tc=c[C>>2]|0;yc=c[C+4>>2]|0;wc=c[Db>>2]|0;Ac=wc+2176|0;c[Ac>>2]=tc;c[Ac+4>>2]=yc;c[kb>>2]=tc;c[kb+4>>2]=yc;yc=c[Cb>>2]|0;tc=c[Cb+4>>2]|0;Ac=wc+2168|0;c[Ac>>2]=yc;c[Ac+4>>2]=tc;c[jb>>2]=yc;c[jb+4>>2]=tc;do{if((c[t>>2]|0)>(c[(c[Ab>>2]|0)+308>>2]|0)){if((c[Eb>>2]|0)!=2){break}c[Eb>>2]=1;tc=ca(c[V>>2]|0,c[r>>2]|0)|0;if((tc|0)>0){yc=c[s>>2]|0;Ac=0;do{b[yc+(Ac<<1)>>1]=1;Ac=Ac+1|0;}while((Ac|0)<(tc|0))}if((c[ib>>2]|0)<=2){break}c[vb>>2]=1}}while(0);do{if((c[gb>>2]|0)==0){tc=c[Eb>>2]|0;if((tc|0)==2|(tc|0)==4){c[_a>>2]=orb(x,c[La>>2]|0,2)|0;if((c[tb>>2]&536870912|0)!=0){Ac=orb(x,c[Ja>>2]|0,256)|0;yc=orb(x,c[Da>>2]|0,256)|0;wc=c[_a>>2]|0;xc=(wc|0)>(Ac|0)?wc:Ac;c[_a>>2]=(xc|0)>(yc|0)?xc:yc}prb(x);qrb(x,0,0,c[La>>2]|0,c[_a>>2]|0,2,0);if((c[tb>>2]&536870912|0)!=0){qrb(x,c[Ka>>2]|0,0,c[Ja>>2]|0,c[_a>>2]|0,256,0);qrb(x,c[Ka>>2]|0,1,c[Ma>>2]|0,c[_a>>2]|0,256,0);qrb(x,c[Aa>>2]|0,0,c[Ia>>2]|0,c[_a>>2]|0,256,0);qrb(x,c[Aa>>2]|0,1,c[Da>>2]|0,c[_a>>2]|0,256,0)}Ec=c[Eb>>2]|0}else{Ec=tc}if((Ec|0)!=3){break}tc=orb(x,c[fb>>2]|0,32)|0;yc=orb(x,c[$a>>2]|0,128)|0;c[_a>>2]=(tc|0)>(yc|0)?tc:yc;yc=orb(x,c[db>>2]|0,64)|0;tc=orb(x,c[cb>>2]|0,128)|0;c[eb>>2]=(yc|0)>(tc|0)?yc:tc;qrb(x,0,0,c[fb>>2]|0,c[_a>>2]|0,32,1);qrb(x,0,0,c[db>>2]|0,c[eb>>2]|0,64,1);qrb(x,0,0,c[$a>>2]|0,c[_a>>2]|0,128,1);qrb(x,0,0,c[cb>>2]|0,c[eb>>2]|0,128,1);if((c[tb>>2]&536870912|0)==0){break}qrb(x,c[bb>>2]|0,0,c[ab>>2]|0,c[_a>>2]|0,2560,1);qrb(x,c[bb>>2]|0,1,c[Xa>>2]|0,c[_a>>2]|0,2560,1);qrb(x,c[Ta>>2]|0,0,c[Wa>>2]|0,c[_a>>2]|0,2560,1);qrb(x,c[Ta>>2]|0,1,c[Va>>2]|0,c[_a>>2]|0,2560,1);qrb(x,c[Sa>>2]|0,0,c[Ra>>2]|0,c[eb>>2]|0,3072,1);qrb(x,c[Sa>>2]|0,1,c[Pa>>2]|0,c[eb>>2]|0,3072,1);qrb(x,c[Qa>>2]|0,0,c[Oa>>2]|0,c[eb>>2]|0,3072,1);qrb(x,c[Qa>>2]|0,1,c[Na>>2]|0,c[eb>>2]|0,3072,1)}}while(0);if((eUa(x,0)|0)<0){W=-1;_=420;break}tc=c[n>>2]|0;do{if((tc|0)<3){if((c[Fa>>2]|0)>=129){Fc=tc;break}if((c[Eb>>2]|0)!=1){Fc=tc;break}if((c[tb>>2]&2|0)!=0){Fc=tc;break}c[n>>2]=3;Fc=3}else{Fc=tc}}while(0);if((c[Ea>>2]|0)==3){tc=c[Ab>>2]|0;yc=c[tc+300>>2]|0;xc=(yc|0)==0?1346848:yc;yc=c[tc+952>>2]|0;tc=(yc|0)==0?xc:yc;yc=1;Ac=Fc;while(1){wc=d[x+11184+yc|0]|0;vc=(ca(e[tc+(yc<<1)>>1]|0,Ac)|0)>>3;if(vc>>>0>255>>>0){Gc=-vc>>31&255}else{Gc=vc&255}b[x+12688+(wc<<1)>>1]=Gc&255;vc=(ca(e[xc+(yc<<1)>>1]|0,c[n>>2]|0)|0)>>3;if(vc>>>0>255>>>0){Hc=-vc>>31&255}else{Hc=vc&255}b[x+12560+(wc<<1)>>1]=Hc&255;wc=yc+1|0;if((wc|0)>=64){break}yc=wc;Ac=c[n>>2]|0}Ac=c[1346096+(c[U>>2]<<2)>>2]|0;c[k>>2]=Ac;c[E>>2]=Ac;yc=d[Ac+8|0]|0;b[M>>1]=yc;b[Y>>1]=yc;WTa(ta,c[pb>>2]|0,c[p>>2]|0,M,c[I>>2]|0,8,8,1);WTa(ta,c[sb>>2]|0,c[ob>>2]|0,Y,c[I>>2]|0,8,8,1);c[n>>2]=8}if((c[Za>>2]|0)==108){yc=1;do{Ac=d[(d[1242080+yc|0]|0)+(x+11184)|0]|0;b[x+12560+(Ac<<1)>>1]=d[561544+yc|0]|0;b[x+12688+(Ac<<1)>>1]=d[561608+yc|0]|0;yc=yc+1|0;}while((yc|0)<64);c[E>>2]=1512624;c[k>>2]=1512656;b[M>>1]=13;b[Y>>1]=14;WTa(ta,c[pb>>2]|0,c[p>>2]|0,M,c[I>>2]|0,8,8,1);WTa(ta,c[sb>>2]|0,c[ob>>2]|0,Y,c[I>>2]|0,8,8,1);c[n>>2]=8}yc=(c[Eb>>2]|0)==1|0;c[sa>>2]=yc;Ac=c[Db>>2]|0;c[Ac+84>>2]=yc;yc=c[Eb>>2]|0;c[Z>>2]=yc;c[Ac+88>>2]=yc;if((c[sa>>2]|0)!=0){c[B>>2]=0}c[ga>>2]=0;c[N>>2]=0;c[ra>>2]=32-(c[aa>>2]|0)+((c[X>>2]|0)-(c[K>>2]|0)<<3);yc=c[Ea>>2]|0;do{if((yc|0)==0){wRa(x,rc)}else if((yc|0)==2){Ac=c[Za>>2]|0;if((Ac|0)==19){Shb(x,rc)|0;break}if((c[ib>>2]|0)!=0){OUa(x,rc);break}if((c[qc>>2]|0)!=0){hSa(x,rc);break}if((Ac|0)==6){SZa(x,rc);break}else if((Ac|0)==7){TZa(x,rc);break}else if((Ac|0)==22){vfa(x,rc);break}else{uqb(x,rc);break}}else if((yc|0)==3){vQa(c[Ab>>2]|0,D,O,M,Y)}else if((yc|0)==1){Jga(x,rc)}else{_=326;break g}}while(0);c[ua>>2]=32-(c[aa>>2]|0)-(c[ra>>2]|0)+((c[X>>2]|0)-(c[K>>2]|0)<<3);if(uc){rc=1;do{yc=c[x+816+(rc<<2)>>2]|0;c[yc+9992>>2]=c[Eb>>2];nrc(yc+7624|0,Fb|0,2224)|0;c[yc+11556>>2]=c[_a>>2];c[yc+11560>>2]=c[eb>>2];c[yc+9960>>2]=c[n>>2];c[yc+9968>>2]=c[xb>>2];c[yc+9972>>2]=c[o>>2];c[yc+112>>2]=c[B>>2];c[yc+14140>>2]=c[u>>2];c[yc+14180>>2]=c[v>>2];c[yc+14224>>2]=c[P>>2];c[yc+13940>>2]=c[ia>>2];rc=rc+1|0;}while((rc|0)<(sc|0));rc=c[Ab>>2]|0;se[c[rc+824>>2]&127](rc,668,hb,0,sc,4)|0;rc=1;do{uc=c[x+816+(rc<<2)>>2]|0;yc=uc+13188|0;c[Ib>>2]=(c[Ib>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13192|0;c[Jb>>2]=(c[Jb>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13664|0;c[xa>>2]=(c[xa>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13672|0;c[na>>2]=(c[na>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13676|0;c[da>>2]=(c[da>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13680|0;c[la>>2]=(c[la>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13684|0;c[ea>>2]=(c[ea>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13688|0;c[ma>>2]=(c[ma>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13692|0;c[qa>>2]=(c[qa>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+13696|0;c[pa>>2]=(c[pa>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+14456|0;c[oa>>2]=(c[oa>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+14008|0;c[Ha>>2]=(c[Ha>>2]|0)+(c[yc>>2]|0);c[yc>>2]=0;yc=uc+7848|0;Ac=wrc(c[za>>2]|0,c[za+4>>2]|0,c[yc>>2]|0,c[yc+4>>2]|0)|0;c[za>>2]=Ac;c[za+4>>2]=G;c[yc>>2]=0;c[yc+4>>2]=0;yc=uc+7856|0;Ac=wrc(c[Ga>>2]|0,c[Ga+4>>2]|0,c[yc>>2]|0,c[yc+4>>2]|0)|0;c[Ga>>2]=Ac;c[Ga+4>>2]=G;c[yc>>2]=0;c[yc+4>>2]=0;yc=uc+7864|0;Ac=wrc(c[Ca>>2]|0,c[Ca+4>>2]|0,c[yc>>2]|0,c[yc+4>>2]|0)|0;c[Ca>>2]=Ac;c[Ca+4>>2]=G;c[yc>>2]=0;c[yc+4>>2]=0;if((c[(c[Ab>>2]|0)+312>>2]|0)!=0){yc=c[uc+13184>>2]|0;Ac=c[yb>>2]|0;xc=0;do{tc=yc+(xc<<2)|0;wc=Ac+(xc<<2)|0;c[wc>>2]=(c[wc>>2]|0)+(c[tc>>2]|0);c[tc>>2]=0;tc=yc+256+(xc<<2)|0;wc=Ac+256+(xc<<2)|0;c[wc>>2]=(c[wc>>2]|0)+(c[tc>>2]|0);c[tc>>2]=0;xc=xc+1|0;}while((xc|0)<64)}xc=c[uc+792>>2]|0;_2(D,xc,32-(c[uc+788>>2]|0)+((c[uc+796>>2]|0)-xc<<3)|0);xc=c[aa>>2]|0;if((xc|0)<32){Ac=c[ya>>2]<<xc;c[ya>>2]=Ac;xc=Ac>>>24&255;while(1){Ac=c[X>>2]|0;c[X>>2]=Ac+1;a[Ac]=xc;Ac=c[ya>>2]|0;c[ya>>2]=Ac<<8;yc=(c[aa>>2]|0)+8|0;c[aa>>2]=yc;if((yc|0)<32){xc=Ac>>>16&255}else{break}}}c[aa>>2]=32;c[ya>>2]=0;rc=rc+1|0;}while((rc|0)<(sc|0))}else{rc=c[Ab>>2]|0;se[c[rc+824>>2]&127](rc,668,hb,0,sc,4)|0}c[fa>>2]=c[ua>>2];c[Nb>>2]=c[xa>>2];c[Ob>>2]=c[pa>>2];c[Pb>>2]=c[na>>2];c[Qb>>2]=c[da>>2];c[Rb>>2]=c[la>>2];c[Tb>>2]=(c[Sb>>2]|0)-(c[la>>2]|0)-(c[qa>>2]|0);c[Ub>>2]=c[qa>>2];do{if((c[Vb>>2]|0)!=0){if((c[fc>>2]|0)==0){break}if((c[gc>>2]|0)!=0){break}rc=qKb(c[(c[Ab>>2]|0)+140>>2]|0)|0;xc=d[rc+5|0]|0;uc=d[rc+6|0]|0;Se[c[hc>>2]&1023](c[ic>>2]|0,c[jc>>2]|0,c[kc>>2]|0,c[lc>>2]|0,16,16,3);rc=16>>>(xc>>>0);Ac=16>>>(uc>>>0);Se[c[hc>>2]&1023](c[mc>>2]|0,c[nc>>2]|0,c[kc>>2]>>xc,c[lc>>2]>>uc,rc,Ac,3);Se[c[hc>>2]&1023](c[oc>>2]|0,c[pc>>2]|0,c[kc>>2]>>xc,c[lc>>2]>>uc,rc,Ac,3)}}while(0);sc=c[Eb>>2]|0;c[Wb>>2]=sc;c[x+10024+(sc<<2)>>2]=c[(c[Db>>2]|0)+168>>2];sc=c[Eb>>2]|0;if((sc|0)!=3){c[rb>>2]=sc}c[(c[Ab>>2]|0)+804>>2]=c[Db>>2];if((c[Ea>>2]|0)==3){yQa(D,c[ua>>2]|0)}if((c[Xb>>2]|0)==0){_=362;break}if((32-(c[aa>>2]|0)+((c[X>>2]|0)-(c[K>>2]|0)<<3)|0)<=(~~(+h[Yb>>3]*+g[Zb>>2])|0)){_=362;break}sc=c[xb>>2]|0;if(!(sc>>>0<(c[(c[Ab>>2]|0)+580>>2]|0)>>>0)){_=362;break}Ac=sc+1|0;rc=c[n>>2]|0;uc=((ca(rc+1|0,sc)|0)>>>0)/(rc>>>0)|0;c[_b>>2]=Ac>>>0>uc>>>0?Ac:uc;h:do{if((c[$b>>2]|0)!=0){if((ca(c[r>>2]|0,c[V>>2]|0)|0)<=0){break}uc=c[ec>>2]|0;Ac=0;sc=rc;while(1){xc=uc+(Ac<<2)|0;yc=c[xc>>2]|0;tc=yc+1|0;wc=(ca(sc+1|0,yc)|0)/(sc|0)|0;c[xc>>2]=(tc|0)>(wc|0)?tc:wc;wc=Ac+1|0;if((wc|0)>=(ca(c[r>>2]|0,c[V>>2]|0)|0)){break h}Ac=wc;sc=c[n>>2]|0}}}while(0);c[ac>>2]=0;rc=c[Eb>>2]|0;if((rc|0)==2){if((c[wb>>2]|0)==0){sc=c[Za>>2]|0;if((sc|0)==20|(sc|0)==13){_=357}}else{_=357}if((_|0)==357){_=0;c[vb>>2]=c[vb>>2]^1}if((rc|0)!=3){_=359}}else if((rc|0)!=3){_=359}if((_|0)==359){_=0;c[cc>>2]=c[bc>>2];rc=xrc(c[$>>2]|0,c[$+4>>2]|0,e[Ya>>1]|0,0)|0;c[zb>>2]=rc;c[zb+4>>2]=G}if(H){Ic=0}else{continue}while(1){rc=c[dc+(Ic<<2)>>2]|0;sc=rc+792|0;Ac=c[sc>>2]|0;uc=rc+800|0;wc=(c[uc>>2]|0)-Ac|0;tc=(wc|0)<0;xc=tc?0:Ac;Ac=tc?0:wc;c[rc+804>>2]=Ac<<3;c[sc>>2]=xc;c[uc>>2]=xc+Ac;c[rc+796>>2]=xc;c[rc+788>>2]=32;c[rc+784>>2]=0;rc=Ic+1|0;if((rc|0)<(A|0)){Ic=rc}else{continue g}}}if((_|0)==326){KIb(0,0,2183008,(S=i,i=i+24|0,c[S>>2]=2644280,c[S+8>>2]=2178624,c[S+16>>2]=3600,S)|0);i=S;Hd();return 0}else if((_|0)==362){if((c[tb>>2]&512|0)!=0){XYa(x)}dc=Ba;H=c[dc>>2]|0;zb=c[dc+4>>2]|0;dc=c[Db>>2]|0;Ya=dc+224|0;c[Ya>>2]=H;c[Ya+4>>2]=zb;Ya=f+720|0;$=wrc(c[Ya>>2]|0,c[Ya+4>>2]|0,H,zb)|0;c[Ya>>2]=$;c[Ya+4>>2]=G;Ya=w+7856|0;$=c[Ya>>2]|0;zb=c[Ya+4>>2]|0;Ya=dc+232|0;c[Ya>>2]=$;c[Ya+4>>2]=zb;Ya=f+728|0;H=wrc(c[Ya>>2]|0,c[Ya+4>>2]|0,$,zb)|0;c[Ya>>2]=H;c[Ya+4>>2]=G;Ya=w+7864|0;H=c[Ya>>2]|0;zb=c[Ya+4>>2]|0;Ya=dc+240|0;c[Ya>>2]=H;c[Ya+4>>2]=zb;Ya=f+736|0;$=wrc(c[Ya>>2]|0,c[Ya+4>>2]|0,H,zb)|0;c[Ya>>2]=$;c[Ya+4>>2]=G;Ya=w+7872|0;$=c[Ya>>2]|0;zb=c[Ya+4>>2]|0;Ya=dc+248|0;c[Ya>>2]=$;c[Ya+4>>2]=zb;Ya=f+744|0;dc=wrc(c[Ya>>2]|0,c[Ya+4>>2]|0,$,zb)|0;c[Ya>>2]=dc;c[Ya+4>>2]=G;Ya=c[aa>>2]|0;i:do{if((Ya|0)<32){dc=c[ya>>2]<<Ya;c[ya>>2]=dc;zb=dc>>>24&255;while(1){dc=c[X>>2]|0;c[X>>2]=dc+1;a[dc]=zb;dc=c[ya>>2]|0;c[ya>>2]=dc<<8;$=(c[aa>>2]|0)+8|0;c[aa>>2]=$;if(($|0)>=32){break i}zb=dc>>>16&255}}}while(0);c[aa>>2]=32;c[ya>>2]=0;Ya=(c[X>>2]|0)-(c[K>>2]|0)<<3;Db=w+13216|0;c[Db>>2]=Ya;Ba=bZa(x,Ya)|0;c[w+13220>>2]=Ba<<3;if((Ba|0)!=0){Ya=c[K>>2]|0;tb=c[aa>>2]|0;zb=c[X>>2]|0;if(((c[w+800>>2]|0)-Ya-(32-tb+(zb-Ya<<3)>>3)|0)<(Ba+50|0)){KIb(c[Ab>>2]|0,16,2190368,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;W=-1;i=m;return W|0}Ya=c[Za>>2]|0;do{if((Ya|0)==1|(Ya|0)==2){dc=Ba;$=c[ya>>2]|0;H=tb;bc=zb;while(1){cc=dc-1|0;if((H|0)>8){Jc=H-8|0;Kc=$<<8;Lc=bc}else{vb=bc;y=je($<<H|0)|0;a[vb]=y;y=y>>8;a[vb+1|0]=y;y=y>>8;a[vb+2|0]=y;y=y>>8;a[vb+3|0]=y;vb=(c[X>>2]|0)+4|0;c[X>>2]=vb;Jc=H+24|0;Kc=0;Lc=vb}c[ya>>2]=Kc;c[aa>>2]=Jc;if((cc|0)==0){Mc=Jc;break}else{dc=cc;$=Kc;H=Jc;bc=Lc}}}else if((Ya|0)==13){bc=c[ya>>2]|0;if((tb|0)>16){Nc=tb-16|0;Oc=bc<<16;Pc=zb}else{H=zb;y=je(bc<<tb|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=(c[X>>2]|0)+4|0;c[X>>2]=H;Nc=tb+16|0;Oc=0;Pc=H}c[ya>>2]=Oc;c[aa>>2]=Nc;if((Nc|0)>16){Qc=Nc-16|0;Rc=Pc}else{H=Pc;y=je(451>>>((16-Nc|0)>>>0)|Oc<<Nc|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=(c[X>>2]|0)+4|0;c[X>>2]=H;Qc=Nc+16|0;Rc=H}c[ya>>2]=451;c[aa>>2]=Qc;H=Ba-4|0;if((H|0)==0){Mc=Qc;break}else{Sc=H;Tc=451;Uc=Qc;Vc=Rc}while(1){H=Sc-1|0;if((Uc|0)>8){Wc=Uc-8|0;Xc=Tc<<8|255;Yc=Vc}else{bc=Vc;y=je(255>>>((8-Uc|0)>>>0)|Tc<<Uc|0)|0;a[bc]=y;y=y>>8;a[bc+1|0]=y;y=y>>8;a[bc+2|0]=y;y=y>>8;a[bc+3|0]=y;bc=(c[X>>2]|0)+4|0;c[X>>2]=bc;Wc=Uc+24|0;Xc=255;Yc=bc}c[ya>>2]=Xc;c[aa>>2]=Wc;if((H|0)==0){Mc=Wc;break}else{Sc=H;Tc=Xc;Uc=Wc;Vc=Yc}}}else{KIb(c[Ab>>2]|0,16,2187888,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;Mc=c[aa>>2]|0}}while(0);j:do{if((Mc|0)<32){Ba=c[ya>>2]<<Mc;c[ya>>2]=Ba;tb=Ba>>>24&255;while(1){Ba=c[X>>2]|0;c[X>>2]=Ba+1;a[Ba]=tb;Ba=c[ya>>2]|0;c[ya>>2]=Ba<<8;zb=(c[aa>>2]|0)+8|0;c[aa>>2]=zb;if((zb|0)>=32){break j}tb=Ba>>>16&255}}}while(0);c[aa>>2]=32;c[ya>>2]=0;c[Db>>2]=(c[X>>2]|0)-(c[K>>2]|0)<<3}tb=c[Ab>>2]|0;Ba=c[tb+540>>2]|0;do{if((Ba|0)!=0){if((c[tb+544>>2]|0)!=(Ba|0)){break}if((c[Ea>>2]|0)!=0){break}zb=(c[Xb>>2]|0)-1|0;Ya=Erc(zb,(zb|0)<0|0?-1:0,9e4,0)|0;zb=G;Za=Erc(Ba,(Ba|0)<0|0?-1:0,65535,0)|0;H=G;if((zb|0)>(H|0)|(zb|0)==(H|0)&Ya>>>0>Za>>>0){break}Za=w+14148|0;Ya=(c[Db>>2]|0)+8-((c[Za>>2]|0)-(c[K>>2]|0)<<3)|0;Ua=+h[Yb>>3]+ +(Ya|0)- +(Ba|0)*(+(c[tb+104>>2]|0)/+(c[tb+108>>2]|0));if(Ua<0.0){KIb(tb,16,2185296,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;Zc=c[(c[Ab>>2]|0)+540>>2]|0}else{Zc=Ba}H=~~(Ua*9.0e4/+(Zc|0));zb=Erc(Ya,(Ya|0)<0|0?-1:0,9e4,0)|0;Ya=Zc;bc=(Zc|0)<0|0?-1:0;$=wrc(zb,G,-1,-1)|0;zb=wrc($,G,Ya,bc)|0;$=Crc(zb,G,Ya,bc)|0;bc=$;$=(H|0)>(bc|0)?H:bc;if(($|0)<65535){bc=c[Za>>2]|0;a[bc]=a[bc]&-8;bc=c[Za>>2]|0;a[bc]=d[bc]|0|$>>>13;a[(c[Za>>2]|0)+1|0]=$>>>5;bc=(c[Za>>2]|0)+2|0;a[bc]=a[bc]&7;bc=(c[Za>>2]|0)+2|0;a[bc]=d[bc]|0|$<<3;bc=$*300|0;$=f+880|0;c[$>>2]=bc;c[$+4>>2]=(bc|0)<0|0?-1:0;break}else{KIb(0,0,2183008,(S=i,i=i+24|0,c[S>>2]=2180944,c[S+8>>2]=2178624,c[S+16>>2]=1779,S)|0);i=S;Hd();return 0}}}while(0);Ba=c[Db>>2]|0;Ab=w+13208|0;tb=wrc(c[Ab>>2]|0,c[Ab+4>>2]|0,Ba,(Ba|0)<0|0?-1:0)|0;c[Ab>>2]=tb;c[Ab+4>>2]=G;c[f+664>>2]=Ba;Ba=w+7760|0;Ab=c[Ba>>2]|0;tb=c[Ba+4>>2]|0;Ba=j+8|0;c[Ba>>2]=Ab;c[Ba+4>>2]=tb;do{if((c[w+13944>>2]|0)==0){if((c[Eb>>2]|0)==3){_=409;break}if((c[w+7784>>2]|0)==0){Ba=w+768|0;Yb=xrc(Ab,tb,c[Ba>>2]|0,c[Ba+4>>2]|0)|0;Ba=j+16|0;c[Ba>>2]=Yb;c[Ba+4>>2]=G;_c=w+776|0}else{Ba=w+776|0;Yb=c[Ba+4>>2]|0;K=j+16|0;c[K>>2]=c[Ba>>2];c[K+4>>2]=Yb;_c=Ba}c[_c>>2]=Ab;c[_c+4>>2]=tb}else{_=409}}while(0);if((_|0)==409){Eb=j+16|0;c[Eb>>2]=Ab;c[Eb+4>>2]=tb}if((c[sa>>2]|0)!=0){Eb=j+36|0;c[Eb>>2]=c[Eb>>2]|1}if((c[va>>2]|0)==0){break}_1(j,3,c[w+13808>>2]|0)|0;break}else if((_|0)==420){i=m;return W|0}}}while(0);_=w+156|0;_c=0;do{f=c[_>>2]|0;if((c[f+(_c*2224|0)+2192>>2]|0)==0){mTa(x,f+(_c*2224|0)|0)}_c=_c+1|0;}while((_c|0)<36);_c=c[w+13216>>2]|0;c[j+28>>2]=(_c|0)/8|0;c[l>>2]=(_c+7|0)>>>0>14>>>0;W=0;i=m;return W|0}function eUa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+13224|0;f=c[e>>2]|0;do{if((f|0)==0){if((c[b+52>>2]|0)!=0){break}g=~~+dZa(b,d);h=b+7792|0;c[h>>2]=g;c[(c[b+9856>>2]|0)+168>>2]=g;if((c[h>>2]|0)<0){i=-1}else{break}return i|0}else{c[b+7792>>2]=f;c[(c[b+9856>>2]|0)+168>>2]=f;if((d|0)!=0){break}c[e>>2]=0}}while(0);if((c[b+9980>>2]|0)==0){e=c[b+7792>>2]|0;c[b+9968>>2]=e;j=e}else{e=c[b+48>>2]|0;do{if((e|0)==5|(e|0)==20|(e|0)==22){xqb(b)}else if((e|0)==13){aSa(b)}else{d=c[b+9136>>2]|0;f=b+144|0;if((c[f>>2]|0)<=0){break}h=b+12556|0;g=b+9976|0;k=b+4|0;l=0;do{m=c[(c[h>>2]|0)+(l<<2)>>2]|0;n=(((c[(c[g>>2]|0)+(m<<2)>>2]|0)*139|0)+8192|0)>>>14;o=c[k>>2]|0;p=c[o+500>>2]|0;q=c[o+504>>2]|0;if((n|0)<(p|0)){r=p&255}else{r=((n|0)>(q|0)?q:n)&255}a[d+m|0]=r;l=l+1|0;}while((l|0)<(c[f>>2]|0))}}while(0);r=c[c[b+9976>>2]>>2]|0;c[b+9968>>2]=r;j=r}r=((j*139|0)+8192|0)>>>14;e=b+9960|0;c[e>>2]=r;f=c[b+4>>2]|0;l=c[f+500>>2]|0;d=c[f+504>>2]|0;if((r|0)<(l|0)){s=l}else{s=(r|0)>(d|0)?d:r}c[e>>2]=s;c[b+9972>>2]=((ca(j,j)|0)+64|0)>>>7;i=0;return i|0}function fUa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[b>>2]|0;b=a;d=a+12256|0;c[d>>2]=1;c[a+12260>>2]=c[(c[a+4>>2]|0)+264>>2];e=a+14084|0;c[e>>2]=1;f=a+12480|0;g=(c[a+812>>2]|0)-1|0;c[f>>2]=g;h=a+808|0;i=c[h>>2]|0;if((g|0)<(i|0)){c[d>>2]=0;return 0}j=a+116|0;k=a+12476|0;a=g;g=i;while(1){i=c[j>>2]|0;l=i-1|0;c[k>>2]=l;if((i|0)>0){i=l;l=a;do{krb(b,i,l)|0;m=c[k>>2]|0;i=m-1|0;c[k>>2]=i;l=c[f>>2]|0}while((m|0)>0);n=l;o=c[h>>2]|0}else{n=a;o=g}c[e>>2]=0;i=n-1|0;c[f>>2]=i;if((i|0)<(o|0)){break}else{a=i;g=o}}c[d>>2]=0;return 0}function gUa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[b>>2]|0;b=a;k8()|0;c[a+12260>>2]=c[(c[a+4>>2]|0)+248>>2];d=a+14084|0;c[d>>2]=1;e=c[a+808>>2]|0;f=a+12480|0;c[f>>2]=e;g=a+812|0;if((e|0)>=(c[g>>2]|0)){return 0}e=a+12476|0;h=a+116|0;i=a+12496|0;j=a+12500|0;k=a+12504|0;l=a+12508|0;m=a+9992|0;do{c[e>>2]=0;NTa(b);c[e>>2]=0;if((c[h>>2]|0)>0){a=0;do{c[i>>2]=(c[i>>2]|0)+2;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=(c[k>>2]|0)+2;c[l>>2]=(c[l>>2]|0)+2;n=c[f>>2]|0;if((c[m>>2]|0)==3){lrb(b,a,n)}else{grb(b,a,n)}a=(c[e>>2]|0)+1|0;c[e>>2]=a;}while((a|0)<(c[h>>2]|0))}c[d>>2]=0;a=(c[f>>2]|0)+1|0;c[f>>2]=a;}while((a|0)<(c[g>>2]|0));return 0}function hUa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[e>>2]|0;k8()|0;e=c[d+808>>2]|0;f=d+812|0;g=c[f>>2]|0;if((e|0)>=(g|0)){return 0}h=d+116|0;i=d+5400|0;j=d+148|0;k=d+10100|0;l=d+10104|0;m=d+124|0;n=d+9192|0;o=d+9216|0;p=d+12432|0;d=e;e=c[h>>2]|0;q=g;while(1){if((e|0)>0){g=0;do{r=c[j>>2]|0;s=(c[i>>2]|0)+((ca(r,d)|0)+g<<4)|0;t=We[c[k>>2]&2047](s,r)|0;r=(628-((ca(t,t)|0)>>>8)+(We[c[l>>2]&2047](s,c[j>>2]|0)|0)|0)>>>8;s=(ca(c[m>>2]|0,d)|0)+g|0;b[(c[n>>2]|0)+(s<<1)>>1]=r;a[(c[o>>2]|0)+s|0]=(t+128|0)>>>8;t=wrc(c[p>>2]|0,c[p+4>>2]|0,r,0)|0;c[p>>2]=t;c[p+4>>2]=G;g=g+1|0;u=c[h>>2]|0;}while((g|0)<(u|0));v=u;w=c[f>>2]|0}else{v=e;w=q}g=d+1|0;if((g|0)<(w|0)){d=g;e=v;q=w}else{break}}return 0}



function EBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=e+8|0;h=b+f|0;g=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=h;h=e<<1;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;j=b+g|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+g|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=b+16|0;h=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+16|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=j;j=b+24|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+24|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=e+16|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=e+24|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;e=b+h|0;f=e|0;g=e+4|0;e=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+h|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=e;e=h+8|0;h=b+e|0;b=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[g+4>>2]=h;return}function FBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;LDa(g|0,b,32,e);LDa(g+16|0,b+16|0,32,e);h=e<<3;LDa(g+256|0,b+h|0,32,e);LDa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=xrc(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ca(r,e)|0;l=h+16|0;k=b+l|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r<<5;p=g+(o|16)|0;j=p|0;q=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p+4|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p^k;n=xrc(q|m,p|k,((q^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+l|0;c[j>>2]=n;c[j+4>>2]=G;j=h+24|0;h=b+j|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+(o|24)|0;o=n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^h;q=xrc(m|l,n|h,((m^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;r=r+1|0;}while((r|0)<16);i=f;return}function GBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;LDa(a,b,c,c);LDa(a+16|0,b+16|0,c,c);d=c<<3;LDa(a+d|0,b+d|0,c,c);e=d+16|0;LDa(a+e|0,b+e|0,c,c);return}function HBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;LDa(g|0,b,32,e);LDa(g+16|0,b+16|0,32,e);h=e<<3;LDa(g+256|0,b+h|0,32,e);LDa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=xrc(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ca(r,e)|0;l=b+(h+18)|0;k=l|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=r<<5;m=g+(k|16)|0;p=m|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^l;q=xrc(o|j,m|l,((o^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(h+16)|0;c[p>>2]=q;c[p+4>>2]=G;p=b+(h+26)|0;q=p|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(k|24)|0;k=q|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q^p;l=xrc(o|j,q|p,((o^j)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(h+24)|0;c[k>>2]=l;c[k+4>>2]=G;r=r+1|0;}while((r|0)<16);i=f;return}function IBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}MDa(j|0,h+64|0,32,32);MDa(j+16|0,h+80|0,32,32);MDa(j+256|0,h+320|0,32,32);MDa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=xrc(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=G;m=e|8;e=h+(m+64)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=xrc(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+64)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=xrc(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=G;n=l|24;l=h+(n+64)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=xrc(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function JBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;LDa(j|0,e,32,f);LDa(j+16|0,e+16|0,32,f);l=f<<3;LDa(j+256|0,e+l|0,32,f);LDa(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=xrc(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=xrc(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=xrc(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=G;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=xrc(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function KBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;LDa(h|0,b,32,e);k=b+16|0;LDa(h+16|0,k,32,e);l=e<<3;m=b+l|0;LDa(h+256|0,m,32,e);n=b+(l+16)|0;LDa(h+272|0,n,32,e);l=g|0;NDa(j|0,l,b,32,32,e);b=g+32|0;NDa(j+16|0,b,k,32,32,e);NDa(j+256|0,l,m,32,32,e);NDa(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l^m;p=xrc(o|k,l|m,((o^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ca(n,e)|0;k=a+g|0;c[k>>2]=p;c[k+4>>2]=G;k=b|8;b=h+k|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+k|0;k=p|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p+4|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p^b;l=xrc(m|o,p|b,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(g+8)|0;c[k>>2]=l;c[k+4>>2]=G;k=n+1|0;if((k|0)<16){n=k}else{q=0;break}}do{n=q<<5;k=n|16;l=h+k|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+k|0;k=g|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^l;b=xrc(m|o,g|l,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=ca(q,e)|0;o=a+(k+16)|0;c[o>>2]=b;c[o+4>>2]=G;o=n|24;n=h+o|0;b=n|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=n+4|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^n;g=xrc(l|m,b|n,((l^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(k+24)|0;c[o>>2]=g;c[o+4>>2]=G;q=q+1|0;}while((q|0)<16);i=f;return}function LBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;LDa(j|0,e,32,f);LDa(j+16|0,e+16|0,32,f);l=f<<3;LDa(j+256|0,e+l|0,32,f);LDa(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=xrc(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=xrc(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=xrc(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=G;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=xrc(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function MBa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m+4|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}MDa(b,g+64|0,e,32);MDa(b+16|0,g+80|0,e,32);j=e<<3;MDa(b+j|0,g+320|0,e,32);MDa(b+(j+16)|0,g+336|0,e,32);i=f;return}function NBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=j|0;NDa(l|0,h,e,32,32,f);o=j+32|0;NDa(l+16|0,o,e+16|0,32,32,f);j=f<<3;NDa(l+256|0,h,e+j|0,32,32,f);NDa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=xrc(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=G;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=xrc(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=G;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=xrc(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=G;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=xrc(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=G;t=t+1|0;}while((t|0)<16);i=g;return}function OBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+2688|0;e=d|0;f=e|0;NDa(a,f,b,c,32,c);g=e+32|0;NDa(a+16|0,g,b+16|0,c,32,c);e=c<<3;NDa(a+e|0,f,b+e|0,c,32,c);f=e+16|0;NDa(a+f|0,g,b+f|0,c,32,c);i=d;return}function PBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=j|0;NDa(l|0,h,e,32,32,f);o=j+32|0;NDa(l+16|0,o,e+16|0,32,32,f);j=f<<3;NDa(l+256|0,h,e+j|0,32,32,f);NDa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=xrc(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=G;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=xrc(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=G;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=xrc(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=G;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=xrc(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=G;t=t+1|0;}while((t|0)<16);i=g;return}function QBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}MDa(j|0,h+64|0,32,32);MDa(j+16|0,h+80|0,32,32);MDa(j+256|0,h+320|0,32,32);MDa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=xrc(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=G;m=e|8;e=h+(m+96)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=xrc(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+96)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=xrc(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=G;n=l|24;l=h+(n+96)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=xrc(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function RBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;LDa(j|0,e+f|0,32,f);l=f+16|0;LDa(j+16|0,e+l|0,32,f);m=f<<3;LDa(j+256|0,e+(m+f)|0,32,f);LDa(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=xrc(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=xrc(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=xrc(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=G;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=xrc(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function SBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;LDa(h|0,b+e|0,32,e);LDa(h+16|0,b+(e+16)|0,32,e);k=e<<3;LDa(h+256|0,b+(k+e)|0,32,e);l=k+16|0;LDa(h+272|0,b+(l+e)|0,32,e);m=g|0;NDa(j|0,m,b,32,32,e);n=g+32|0;NDa(j+16|0,n,b+16|0,32,32,e);NDa(j+256|0,m,b+k|0,32,32,e);NDa(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k^n;p=xrc(o|m,k|n,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ca(l,e)|0;m=a+g|0;c[m>>2]=p;c[m+4>>2]=G;m=b|8;b=h+m|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+m|0;m=p|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^b;k=xrc(n|o,p|b,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(g+8)|0;c[m>>2]=k;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{q=0;break}}do{l=q<<5;m=l|16;k=h+m|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=g|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+4|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g^k;b=xrc(n|o,g|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(q,e)|0;o=a+(m+16)|0;c[o>>2]=b;c[o+4>>2]=G;o=l|24;l=h+o|0;b=l|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=l+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^l;g=xrc(k|n,b|l,((k^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(m+24)|0;c[o>>2]=g;c[o+4>>2]=G;q=q+1|0;}while((q|0)<16);i=f;return}function TBa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;LDa(j|0,e+f|0,32,f);l=f+16|0;LDa(j+16|0,e+l|0,32,f);m=f<<3;LDa(j+256|0,e+(m+f)|0,32,f);LDa(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=xrc(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=xrc(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=xrc(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=G;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=xrc(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function UBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+(e+8)|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+(e+8)|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=e<<1;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=b+(g+8)|0;j=f|0;i=f+4|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(h+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=f;f=g+e|0;g=h+e|0;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;e=b+g|0;f=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=e;e=b+(g+8)|0;g=e|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(h+8)|0;c[b>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[b+4>>2]=e;return}function VBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;LDa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=xrc(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function WBa(a,b,c){a=a|0;b=b|0;c=c|0;LDa(a,b,c,c);return}function XBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;LDa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=xrc(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function YBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;MDa(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k^b;h=xrc(m|g,k|b,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(p,e)|0;g=a+o|0;c[g>>2]=h;c[g+4>>2]=G;g=n|8;n=l+g|0;h=c[n>>2]|0;m=c[n+4>>2]|0;n=j+g|0;g=n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^m;k=xrc(b|h,n|m,((b^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(o+8)|0;c[g>>2]=k;c[g+4>>2]=G;p=p+1|0;}while((p|0)<8);i=f;return}function ZBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;LDa(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;MDa(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o^n;m=xrc(h|g,o|n,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=m;c[g+4>>2]=G;g=p|8;p=j+g|0;m=p|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+g|0;g=m|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m+4|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m^p;o=xrc(n|h,m|p,((n^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=o;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function _Ba(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;LDa(g|0,b,16,e);NDa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=xrc(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=G;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=xrc(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function $Ba(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;LDa(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;MDa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=xrc(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=xrc(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function aCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;MDa(a,j,e,16);i=f;return}function bCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;MDa(k|0,m,16,16);NDa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q^m;h=xrc(g|o,q|m,((g^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=ca(b,e)|0;o=a+p|0;c[o>>2]=h;c[o+4>>2]=G;o=j|8;j=k+o|0;h=j|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+o|0;o=h|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h^j;q=xrc(m|g,h|j,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(p+8)|0;c[o>>2]=q;c[o+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function cCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+832|0;NDa(a,d|0,b,c,16,c);i=d;return}function dCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;MDa(k|0,m,16,16);NDa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h^m;n=xrc(g|p,h|m,((g^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(b,e)|0;p=a+q|0;c[p>>2]=n;c[p+4>>2]=G;p=j|8;j=k+p|0;n=j|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^j;h=xrc(m|g,n|j,((m^g)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(q+8)|0;c[p>>2]=h;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function eCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;MDa(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^g;l=xrc(h|p,m|g,((h^p)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(o,e)|0;p=a+b|0;c[p>>2]=l;c[p+4>>2]=G;p=n|8;n=k+p|0;l=c[n>>2]|0;h=c[n+4>>2]|0;n=j+p|0;p=n|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^h;m=xrc(g|l,n|h,((g^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(b+8)|0;c[p>>2]=m;c[p+4>>2]=G;o=o+1|0;}while((o|0)<8);i=f;return}function fCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;LDa(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;MDa(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^o;n=xrc(h|g,m|o,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=q|8;q=j+g|0;n=q|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^q;m=xrc(o|h,n|q,((o^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=m;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function gCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;LDa(g|0,b+e|0,16,e);NDa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=xrc(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=G;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=xrc(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function hCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;LDa(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;MDa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=xrc(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=xrc(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function iCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+e|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=b+f|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=f+e|0;e=b+g|0;b=e|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[f+4>>2]=e;return}function jCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;IDa(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=xrc(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=G;h=b+e|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=xrc(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=G;n=e<<1;m=b+n|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=xrc(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=G;l=e*3|0;e=b+l|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=xrc(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=G;i=f;return}function kCa(a,b,c){a=a|0;b=b|0;c=c|0;IDa(a,b,c,c);return}function lCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;IDa(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=xrc(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=G;h=b+(e+2)|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=xrc(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=G;n=e<<1;m=b+(n+2)|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=xrc(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=G;l=e*3|0;e=b+(l+2)|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=xrc(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=G;i=f;return}function mCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;JDa(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=p^s;h=xrc(l|g,p|s,((l^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=h;c[k+4>>2]=G;k=c[o>>2]|0;h=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;l=c[o+4>>2]|0;o=l^h;s=xrc(g|k,l|h,((g^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+e|0;c[o>>2]=s;c[o+4>>2]=G;o=c[n>>2]|0;s=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;g=c[n+4>>2]|0;n=g^s;h=xrc(k|o,g|s,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+m|0;c[n>>2]=h;c[n+4>>2]=G;n=c[q>>2]|0;h=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;m=c[q+4>>2]|0;q=m^h;o=xrc(j|n,m|h,((j^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+(e*3|0)|0;c[q>>2]=o;c[q+4>>2]=G;i=f;return}function nCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;IDa(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;JDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=r^g;q=xrc(k|n,r|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=q;c[m+4>>2]=G;m=j+8|0;q=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;r=xrc(k|q,g|n,((k^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^q;g=xrc(k|r,n|q,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=r;c[m+4>>2]=G;i=f;return}function oCa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;IDa(f,b,8,d);KDa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=xrc(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=G;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=xrc(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=G;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=xrc(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=xrc(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=G;i=e;return}function pCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;IDa(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;JDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=xrc(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=G;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=G;i=f;return}function qCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+72|0;g=f|0;h=g|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=g+8|0;h=e-k|0;m=b+h|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=m;m=b;l=m|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=m;m=g+24|0;l=b+e|0;n=l|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=l;l=g+32|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=n;n=g+40|0;l=m+e|0;m=b+(l-k)|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;m=g+48|0;n=l+e|0;l=b+(n-k)|0;o=l|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=l;l=g+56|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[l+4>>2]=n;n=g+64|0;g=b+(h+m)|0;m=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=g;JDa(a,j,e);i=f;return}function rCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;JDa(k,o,8);KDa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=xrc(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=G;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=xrc(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=G;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=xrc(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=xrc(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=G;i=f;return}function sCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+288|0;KDa(a,d|0,b,c,c);i=d;return}function tCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;JDa(k,o,8);KDa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=xrc(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=G;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=xrc(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=G;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=xrc(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=xrc(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=G;i=f;return}function uCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;JDa(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=s^g;t=xrc(o|l,s|g,((o^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=t;c[k+4>>2]=G;k=c[n>>2]|0;t=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^t;g=xrc(l|k,o|t,((l^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=g;c[n+4>>2]=G;n=c[q>>2]|0;g=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;l=c[q+4>>2]|0;q=l^g;t=xrc(k|n,l|g,((k^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+m|0;c[q>>2]=t;c[q+4>>2]=G;q=c[p>>2]|0;t=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;m=c[p+4>>2]|0;p=m^t;n=xrc(j|q,m|t,((j^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(e*3|0)|0;c[p>>2]=n;c[p+4>>2]=G;i=f;return}function vCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;IDa(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;JDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=xrc(k|n,o|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;o=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=o;c[m+4>>2]=G;m=j+16|0;o=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|o,n|r,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+p|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;p=c[m+4>>2]|0;m=p^g;o=xrc(l|j,p|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=o;c[m+4>>2]=G;i=f;return}function wCa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;IDa(f,b+d|0,8,d);KDa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=xrc(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=G;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=xrc(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=G;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=xrc(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=xrc(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=G;i=e;return}function xCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;IDa(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;JDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=xrc(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=G;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=G;i=f;return}function yCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;return}function zCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;RDa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+e|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function ACa(a,b,c){a=a|0;b=b|0;c=c|0;RDa(a,b,c,c);return}function BCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;RDa(g,b,4,e);h=b+2|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+(e+2)|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function CCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;SDa(h,j,4);n=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|n)-((j^n)>>>1&2147450879);n=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|n)-((m^n)>>>1&2147450879);i=f;return}function DCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;RDa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;SDa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function ECa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+120|0;f=e+112|0;g=i;i=i+8|0;RDa(f,b,4,d);TDa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function FCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;RDa(h,b,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;SDa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function GCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+32|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;SDa(a,h,e);i=f;return}function HCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+112|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;SDa(j,l,4);TDa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function ICa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+112|0;TDa(a,d|0,b,c,c);i=d;return}function JCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+112|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=2-m|0;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+2|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+2)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e+e|0;m=b+(p+n)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;SDa(j,l,4);TDa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function KCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-k)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;SDa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2147450879);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2147450879);i=f;return}function LCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;l=b+e|0;RDa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;SDa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function MCa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+120|0;f=e+112|0;g=i;i=i+8|0;RDa(f,b+d|0,4,d);TDa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function NCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;RDa(h,b+e|0,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;SDa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function OCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=c[i+4>>2]|0;l=f;m=l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l^k;o=xrc(n|j,l|k,((n^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[i>>2]=o;c[i+4>>2]=G;i=g+8|0;o=c[i>>2]|0;m=c[i+4>>2]|0;j=f+8|0;n=j|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j^m;l=xrc(k|o,j|m,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[i>>2]=l;c[i+4>>2]=G;i=h+1|0;if((i|0)<16){f=f+e|0;g=g+e|0;h=i}else{break}}h=b+16|0;b=a+16|0;a=0;while(1){g=b;f=c[g>>2]|0;i=c[g+4>>2]|0;l=h;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^i;k=xrc(o|f,l|i,((o^f)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[g>>2]=k;c[g+4>>2]=G;g=b+8|0;k=c[g>>2]|0;n=c[g+4>>2]|0;f=h+8|0;o=f|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f+4|0;f=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f^n;l=xrc(i|k,f|n,((i^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[g>>2]=l;c[g+4>>2]=G;g=a+1|0;if((g|0)<16){h=h+e|0;b=b+e|0;a=g}else{break}}return}function PCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;LDa(g|0,b,32,e);LDa(g+16|0,b+16|0,32,e);h=e<<3;LDa(g+256|0,b+h|0,32,e);LDa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=xrc(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ca(u,e)|0;l=h+16|0;q=b+l|0;m=q|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=u<<5;s=g+(m|16)|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+l|0;l=c[t>>2]|0;j=c[t+4>>2]|0;p=s^q;k=xrc(r|o,s|q,((r^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;o=p^j;r=xrc(k|l,p|j,((k^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;t=h+24|0;h=b+t|0;r=h|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+(m|24)|0;m=r|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r+4|0;r=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+t|0;t=c[m>>2]|0;k=c[m+4>>2]|0;j=r^h;p=xrc(l|o,r|h,((l^o)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;o=j^k;l=xrc(p|t,j|k,((p^t)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function QCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;QDa(a,b,c,c);QDa(a+16|0,b+16|0,c,c);d=c<<3;QDa(a+d|0,b+d|0,c,c);e=d+16|0;QDa(a+e|0,b+e|0,c,c);return}function RCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;LDa(g|0,b,32,e);LDa(g+16|0,b+16|0,32,e);h=e<<3;LDa(g+256|0,b+h|0,32,e);LDa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=xrc(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ca(u,e)|0;l=b+(h+18)|0;q=l|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=u<<5;j=g+(q|16)|0;s=j|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=a+(h+16)|0;r=c[s>>2]|0;o=c[s+4>>2]|0;p=j^l;k=xrc(t|m,j|l,((t^m)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;m=p^o;t=xrc(k|r,p|o,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[s>>2]=t;c[s+4>>2]=G;s=b+(h+26)|0;t=s|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=g+(q|24)|0;q=t|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=t+4|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=a+(h+24)|0;h=c[q>>2]|0;k=c[q+4>>2]|0;o=t^s;p=xrc(r|m,t|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;m=o^k;r=xrc(p|h,o|k,((p^h)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function SCa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}MDa(j|0,h+64|0,32,32);MDa(j+16|0,h+80|0,32,32);MDa(j+256|0,h+320|0,32,32);MDa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=xrc(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;m=t^s;n=xrc(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=G;q=e|8;e=h+(q+64)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=xrc(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^u;r=xrc(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+80)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=xrc(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=G;m=n^e;t=xrc(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h+((l|8)+80)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=xrc(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^k;s=xrc(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function TCa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;LDa(j|0,e,32,f);LDa(j+16|0,e+16|0,32,f);l=f<<3;LDa(j+256|0,e+l|0,32,f);LDa(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=xrc(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=xrc(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^m;t=xrc(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=xrc(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^e;s=xrc(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function UCa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;LDa(h|0,b,32,e);k=b+16|0;LDa(h+16|0,k,32,e);l=e<<3;m=b+l|0;LDa(h+256|0,m,32,e);n=b+(l+16)|0;LDa(h+272|0,n,32,e);l=g|0;NDa(j|0,l,b,32,32,e);b=g+32|0;NDa(j+16|0,b,k,32,32,e);NDa(j+256|0,l,m,32,32,e);NDa(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(n,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^m;t=xrc(o|k,l|m,((o^k)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;k=s^r;o=xrc(t|q,s|r,((t^q)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=b|8;b=h+p|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=xrc(q|k,o|b,((q^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;k=r^t;q=xrc(s|g,r|t,((s^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;p=n+1|0;if((p|0)<16){n=p}else{u=0;break}}do{n=u<<5;p=n|16;q=h+p|0;k=q|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+p|0;p=k|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=k^q;m=xrc(s|g,k|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;g=o^b;s=xrc(m|r,o|b,((m^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=G;t=n|24;n=h+t|0;s=n|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;m=c[t+4>>2]|0;b=s^n;o=xrc(r|g,s|n,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;g=b^m;r=xrc(o|p,b|m,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function VCa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;LDa(j|0,e,32,f);LDa(j+16|0,e+16|0,32,f);l=f<<3;LDa(j+256|0,e+l|0,32,f);LDa(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=xrc(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=xrc(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^m;t=xrc(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=xrc(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^e;s=xrc(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function WCa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m+4|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}PDa(b,g+64|0,e,32);PDa(b+16|0,g+80|0,e,32);j=e<<3;PDa(b+j|0,g+320|0,e,32);PDa(b+(j+16)|0,g+336|0,e,32);i=f;return}function XCa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=j|0;NDa(l|0,h,e,32,32,f);o=j+32|0;NDa(l+16|0,o,e+16|0,32,32,f);j=f<<3;NDa(l+256|0,h,e+j|0,32,32,f);NDa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=xrc(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;n=t^q;s=xrc(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=G;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=xrc(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=G;n=q^u;r=xrc(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=G;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=xrc(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^e;t=xrc(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=xrc(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^o;q=xrc(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function YCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+2688|0;e=d|0;f=e|0;ODa(a,f,b,c,32,c);g=e+32|0;ODa(a+16|0,g,b+16|0,c,32,c);e=c<<3;ODa(a+e|0,f,b+e|0,c,32,c);f=e+16|0;ODa(a+f|0,g,b+f|0,c,32,c);i=d;return}function ZCa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=j|0;NDa(l|0,h,e,32,32,f);o=j+32|0;NDa(l+16|0,o,e+16|0,32,32,f);j=f<<3;NDa(l+256|0,h,e+j|0,32,32,f);NDa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=xrc(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;n=t^q;s=xrc(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=G;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=xrc(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=G;n=q^u;r=xrc(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=G;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=xrc(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^e;t=xrc(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=xrc(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^o;q=xrc(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function _Ca(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}MDa(j|0,h+64|0,32,32);MDa(j+16|0,h+80|0,32,32);MDa(j+256|0,h+320|0,32,32);MDa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=xrc(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;m=t^s;n=xrc(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=G;q=e|8;e=h+(q+96)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=xrc(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^u;r=xrc(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+112)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=xrc(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=G;m=n^e;t=xrc(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h+((l|8)+112)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=xrc(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^k;s=xrc(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function $Ca(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;LDa(j|0,e+f|0,32,f);l=f+16|0;LDa(j+16|0,e+l|0,32,f);m=f<<3;LDa(j+256|0,e+(m+f)|0,32,f);LDa(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=xrc(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=xrc(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^l;t=xrc(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=xrc(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=G;n=l^e;s=xrc(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function aDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;LDa(h|0,b+e|0,32,e);LDa(h+16|0,b+(e+16)|0,32,e);k=e<<3;LDa(h+256|0,b+(k+e)|0,32,e);l=k+16|0;LDa(h+272|0,b+(l+e)|0,32,e);m=g|0;NDa(j|0,m,b,32,32,e);n=g+32|0;NDa(j+16|0,n,b+16|0,32,32,e);NDa(j+256|0,m,b+k|0,32,32,e);NDa(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(l,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=k^n;t=xrc(o|m,k|n,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=b|8;b=h+p|0;o=b|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=xrc(q|m,o|b,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|g,r|t,((s^g)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;p=l+1|0;if((p|0)<16){l=p}else{u=0;break}}do{l=u<<5;p=l|16;q=h+p|0;m=q|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+p|0;p=m|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=m^q;n=xrc(s|g,m|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;g=o^b;s=xrc(n|r,o|b,((n^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=G;t=l|24;l=h+t|0;s=l|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+4|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;n=c[t+4>>2]|0;b=s^l;o=xrc(r|g,s|l,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;g=b^n;r=xrc(o|p,b|n,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function bDa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;LDa(j|0,e+f|0,32,f);l=f+16|0;LDa(j+16|0,e+l|0,32,f);m=f<<3;LDa(j+256|0,e+(m+f)|0,32,f);LDa(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}MDa(k|0,h+64|0,32,32);MDa(k+16|0,h+80|0,32,32);MDa(k+256|0,h+320|0,32,32);MDa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=xrc(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=xrc(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^l;t=xrc(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=xrc(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=G;n=l^e;s=xrc(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function cDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;j=f;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j^i;m=xrc(l|h,j|i,((l^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[g>>2]=m;c[g+4>>2]=G;g=b+8|0;m=c[g>>2]|0;k=c[g+4>>2]|0;h=f+8|0;l=h|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h^k;j=xrc(i|m,h|k,((i^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[g>>2]=j;c[g+4>>2]=G;g=a+1|0;if((g|0)<8){f=f+e|0;b=b+e|0;a=g}else{break}}return}function dDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;LDa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=xrc(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function eDa(a,b,c){a=a|0;b=b|0;c=c|0;QDa(a,b,c,c);return}function fDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;LDa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=xrc(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function gDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;MDa(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(p,e)|0;h=a+o|0;q=c[h>>2]|0;r=c[h+4>>2]|0;s=k^b;t=xrc(m|g,k|b,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[h>>2]=m;c[h+4>>2]=G;h=n|8;n=l+h|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=j+h|0;h=n|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(o+8)|0;o=c[h>>2]|0;t=c[h+4>>2]|0;r=n^g;s=xrc(q|m,n|g,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[h>>2]=q;c[h+4>>2]=G;p=p+1|0;}while((p|0)<8);i=f;return}function hDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;LDa(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;MDa(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;m=a+b|0;q=c[m>>2]|0;r=c[m+4>>2]|0;s=o^n;t=xrc(h|g,o|n,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;h=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=p|8;p=j+m|0;h=p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+m|0;m=h|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+(b+8)|0;b=c[m>>2]|0;t=c[m+4>>2]|0;r=h^p;s=xrc(q|g,h|p,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function iDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;LDa(g|0,b,16,e);NDa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=xrc(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=xrc(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function jDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;LDa(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;MDa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=xrc(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=xrc(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function kDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;PDa(a,j,e,16);i=f;return}function lDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;MDa(k|0,m,16,16);NDa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(b,e)|0;h=a+p|0;n=c[h>>2]|0;r=c[h+4>>2]|0;s=q^m;t=xrc(g|o,q|m,((g^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;o=s^r;g=xrc(t|n,s|r,((t^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=g;c[h+4>>2]=G;h=j|8;j=k+h|0;g=j|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+h|0;h=g|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(p+8)|0;p=c[h>>2]|0;t=c[h+4>>2]|0;r=g^j;s=xrc(n|o,g|j,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;o=r^t;n=xrc(s|p,r|t,((s^p)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=n;c[h+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function mDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+832|0;ODa(a,d|0,b,c,16,c);i=d;return}function nDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;MDa(k|0,m,16,16);NDa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=ca(b,e)|0;n=a+q|0;o=c[n>>2]|0;r=c[n+4>>2]|0;s=h^m;t=xrc(g|p,h|m,((g^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;p=s^r;g=xrc(t|o,s|r,((t^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=j|8;j=k+n|0;g=j|0;p=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+n|0;n=g|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+4|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(q+8)|0;q=c[n>>2]|0;t=c[n+4>>2]|0;r=g^j;s=xrc(o|p,g|j,((o^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;p=r^t;o=xrc(s|q,r|t,((s^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=o;c[n+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function oDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;MDa(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(o,e)|0;l=a+b|0;q=c[l>>2]|0;r=c[l+4>>2]|0;s=m^g;t=xrc(h|p,m|g,((h^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;p=s^r;h=xrc(t|q,s|r,((t^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[l>>2]=h;c[l+4>>2]=G;l=n|8;n=k+l|0;h=c[n>>2]|0;p=c[n+4>>2]|0;n=j+l|0;l=n|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(b+8)|0;b=c[l>>2]|0;t=c[l+4>>2]|0;r=n^p;s=xrc(q|h,n|p,((q^h)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;h=r^t;q=xrc(s|b,r|t,((s^b)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;o=o+1|0;}while((o|0)<8);i=f;return}function pDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;LDa(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;MDa(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;p=c[n>>2]|0;r=c[n+4>>2]|0;s=m^o;t=xrc(h|g,m|o,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;h=xrc(t|p,s|r,((t^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=h;c[n+4>>2]=G;n=q|8;q=j+n|0;h=q|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=h^q;s=xrc(p|g,h|q,((p^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;p=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=p;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function qDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;LDa(g|0,b+e|0,16,e);NDa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=xrc(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=xrc(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function rDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;LDa(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;MDa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=xrc(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=xrc(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function sDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=c[f>>2]|0;h=c[f+4>>2]|0;i=b;j=i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i^h;l=xrc(k|g,i|h,((k^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[f>>2]=l;c[f+4>>2]=G;f=a+e|0;l=c[f>>2]|0;j=c[f+4>>2]|0;g=b+e|0;k=g|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^j;i=xrc(h|l,g|j,((h^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[f>>2]=i;c[f+4>>2]=G;f=e<<1;i=a+f|0;k=c[i>>2]|0;l=c[i+4>>2]|0;h=b+f|0;j=h|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h^l;m=xrc(g|k,h|l,((g^k)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[i>>2]=m;c[i+4>>2]=G;i=f+e|0;e=a+i|0;a=c[e>>2]|0;f=c[e+4>>2]|0;m=b+i|0;i=m|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m^f;j=xrc(b|a,m|f,((b^a)>>>1|i<<31)&2147450879,(i>>>1|0<<31)&2147450879)|0;c[e>>2]=j;c[e+4>>2]=G;return}function tDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;IDa(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=xrc(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;l=p^o;k=xrc(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=G;h=b+e|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=xrc(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^p;n=xrc(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=G;k=e<<1;n=b+k|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=xrc(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;o=h^j;m=xrc(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=G;l=e*3|0;e=b+l|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=xrc(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;m=k^a;g=xrc(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=G;i=f;return}function uDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d>>1;d=0;g=a;a=c;while(1){c=a+2|0;h=a-2|0;i=a+4|0;j=a+6|0;k=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[i>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<16384>>>0){l=k}else{l=-k>>31&16383}b[g>>1]=((e[g>>1]|0)+1+l|0)>>>1;k=g+2|0;m=a+8|0;n=(((e[i>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[h>>1]|0)+(((e[j>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[m>>1]|0)>>5;if(n>>>0<16384>>>0){o=n}else{o=-n>>31&16383}b[k>>1]=((e[k>>1]|0)+1+o|0)>>>1;k=g+4|0;n=a+10|0;h=(((e[j>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[m>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(h>>>0<16384>>>0){p=h}else{p=-h>>31&16383}b[k>>1]=((e[k>>1]|0)+1+p|0)>>>1;k=g+6|0;h=(((e[m>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(h>>>0<16384>>>0){q=h}else{q=-h>>31&16383}b[k>>1]=((e[k>>1]|0)+1+q|0)>>>1;k=d+1|0;if((k|0)<4){d=k;g=g+(f<<1)|0;a=a+(f<<1)|0}else{break}}return}function vDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;IDa(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=xrc(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;l=p^o;k=xrc(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=G;h=b+(e+2)|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=xrc(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^p;n=xrc(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=G;k=e<<1;n=b+(k+2)|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=xrc(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;o=h^j;m=xrc(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=G;l=e*3|0;e=b+(l+2)|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=xrc(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;m=k^a;g=xrc(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=G;i=f;return}function wDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;JDa(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=a;h=c[k>>2]|0;b=c[k+4>>2]|0;r=p^s;t=xrc(l|g,p|s,((l^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^b;l=xrc(t|h,r|b,((t^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[k>>2]=l;c[k+4>>2]=G;k=c[o>>2]|0;l=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;h=c[o+4>>2]|0;o=a+e|0;t=c[o>>2]|0;b=c[o+4>>2]|0;r=h^l;s=xrc(g|k,h|l,((g^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;k=r^b;g=xrc(s|t,r|b,((s^t)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[o>>2]=g;c[o+4>>2]=G;o=c[n>>2]|0;g=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=a+m|0;m=c[n>>2]|0;s=c[n+4>>2]|0;b=t^g;r=xrc(k|o,t|g,((k^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;o=b^s;k=xrc(r|m,b|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[n>>2]=k;c[n+4>>2]=G;n=c[q>>2]|0;k=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;o=c[q+4>>2]|0;q=a+(e*3|0)|0;e=c[q>>2]|0;a=c[q+4>>2]|0;m=o^k;r=xrc(j|n,o|k,((j^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^a;j=xrc(r|e,m|a,((r^e)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=j;c[q+4>>2]=G;i=f;return}function xDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;IDa(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;JDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=a;q=c[m>>2]|0;h=c[m+4>>2]|0;b=r^g;p=xrc(k|n,r|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(p|q,b|h,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;q=c[m>>2]|0;p=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=p^n;r=xrc(q|k,p|n,((q^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;q=xrc(r|h,g|b,((r^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=G;m=j+16|0;q=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;r=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=r^k;n=xrc(h|q,r|k,((h^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;q=g^b;h=xrc(n|o,g|b,((n^o)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;q=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=q^h;n=xrc(l|j,q|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function yDa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;IDa(f,b,8,d);KDa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=xrc(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;b=o^n;g=xrc(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=G;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=xrc(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;g=k^o;m=xrc(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=G;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=xrc(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;m=b^k;n=xrc(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=xrc(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;f=o^a;h=xrc(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=G;i=e;return}function zDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;IDa(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;JDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=xrc(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=xrc(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=xrc(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function ADa(a,f,g){a=a|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=j|0;l=j+16|0;m=g<<1;n=f+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=n;n=j+8|0;k=g-m|0;o=f+k|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=f;n=o|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=p;c[l+4>>2]=o;o=j+24|0;n=f+g|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=n;n=j+32|0;o=m+g+g|0;q=f+(o-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=j+40|0;n=o+g|0;o=f+(n-m)|0;r=o|0;s=o+4|0;o=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=o;o=j+48|0;q=n+g|0;n=f+(q-m)|0;r=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=n;n=j+56|0;o=q+g|0;q=f+(o-m)|0;m=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=q;q=j+64|0;j=f+(k+o)|0;o=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=j;j=g>>1;g=j<<1;q=j*3|0;o=l;l=a;a=1;k=p&65535;while(1){p=e[o-8>>1]|0;f=k&65535;n=e[o+8>>1]|0;m=e[o+16>>1]|0;r=e[o+24>>1]|0;s=e[o+32>>1]|0;t=e[o+40>>1]|0;u=e[o+48>>1]|0;v=(e[o-16>>1]|0)+16+((n+f|0)*20|0)+r+((m+p|0)*-5|0)>>5;if(v>>>0<16384>>>0){w=v}else{w=-v>>31&16383}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;v=l+(j<<1)|0;x=p+16+((m+n|0)*20|0)+s+((r+f|0)*-5|0)>>5;if(x>>>0<16384>>>0){y=x}else{y=-x>>31&16383}b[v>>1]=((e[v>>1]|0)+1+y|0)>>>1;v=l+(g<<1)|0;x=f+16+((r+m|0)*20|0)+t+((s+n|0)*-5|0)>>5;if(x>>>0<16384>>>0){z=x}else{z=-x>>31&16383}b[v>>1]=((e[v>>1]|0)+1+z|0)>>>1;v=l+(q<<1)|0;x=n+16+((s+r|0)*20|0)+u+((t+m|0)*-5|0)>>5;if(x>>>0<16384>>>0){A=x}else{A=-x>>31&16383}b[v>>1]=((e[v>>1]|0)+1+A|0)>>>1;v=o+2|0;if((a|0)>=4){break}o=v;l=l+2|0;a=a+1|0;k=b[v>>1]|0}i=h;return}function BDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;JDa(k,o,8);KDa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;s=c[n+4>>2]|0;r=o^j;h=xrc(l|b,o|j,((l^b)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;b=r^s;l=xrc(h|g,r|s,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;s=c[n>>2]|0;r=c[n+4>>2]|0;j=h^b;o=xrc(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^r;g=xrc(o|s,j|r,((o^s)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;s=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;r=c[n+4>>2]|0;j=o^l;b=xrc(s|g,o|l,((s^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;g=j^r;s=xrc(b|p,j|r,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=s;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;s=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^s;b=xrc(m|k,g|s,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;k=p^a;m=xrc(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;i=f;return}function CDa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+288|0;h=g|0;j=f>>1;f=j<<1;k=d+(-f<<1)|0;d=0;l=h|0;while(1){m=e[k>>1]|0;n=e[k+2>>1]|0;o=e[k-2>>1]|0;p=e[k+4>>1]|0;q=e[k+6>>1]|0;c[l>>2]=(e[k-4>>1]|0)+((n+m|0)*20|0)+((p+o|0)*-5|0)+q;r=e[k+8>>1]|0;c[l+4>>2]=((p+n|0)*20|0)+o+r+((q+m|0)*-5|0);o=e[k+10>>1]|0;c[l+8>>2]=((q+p|0)*20|0)+m+o+((r+n|0)*-5|0);c[l+12>>2]=((r+q|0)*20|0)+n+(e[k+12>>1]|0)+((o+p|0)*-5|0);p=d+1|0;if((p|0)<9){k=k+(j<<1)|0;d=p;l=l+32|0}else{break}}l=j*3|0;d=a;a=0;k=h+64|0;while(1){h=c[k-32>>2]|0;p=c[k>>2]|0;o=c[k+32>>2]|0;n=c[k+64>>2]|0;q=c[k+96>>2]|0;r=c[k+128>>2]|0;m=c[k+160>>2]|0;s=c[k+192>>2]|0;t=(c[k-64>>2]|0)+512+((o+p|0)*20|0)+q+((n+h|0)*-5|0)>>10;if(t>>>0<16384>>>0){u=t}else{u=-t>>31&16383}b[d>>1]=((e[d>>1]|0)+1+u|0)>>>1;t=d+(j<<1)|0;v=h+512+((n+o|0)*20|0)+r+((q+p|0)*-5|0)>>10;if(v>>>0<16384>>>0){w=v}else{w=-v>>31&16383}b[t>>1]=((e[t>>1]|0)+1+w|0)>>>1;t=d+(f<<1)|0;v=p+512+((q+n|0)*20|0)+m+((r+o|0)*-5|0)>>10;if(v>>>0<16384>>>0){x=v}else{x=-v>>31&16383}b[t>>1]=((e[t>>1]|0)+1+x|0)>>>1;t=d+(l<<1)|0;v=o+512+((r+q|0)*20|0)+s+((m+n|0)*-5|0)>>10;if(v>>>0<16384>>>0){y=v}else{y=-v>>31&16383}b[t>>1]=((e[t>>1]|0)+1+y|0)>>>1;t=a+1|0;if((t|0)<4){d=d+2|0;a=t;k=k+4|0}else{break}}i=g;return}function DDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;JDa(k,o,8);KDa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;t=c[n+4>>2]|0;s=o^j;h=xrc(l|b,o|j,((l^b)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;b=s^t;l=xrc(h|g,s|t,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;t=c[n>>2]|0;s=c[n+4>>2]|0;j=h^b;o=xrc(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^s;g=xrc(o|t,j|s,((o^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;t=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;s=c[n+4>>2]|0;j=o^l;b=xrc(t|g,o|l,((t^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;g=j^s;t=xrc(b|p,j|s,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=t;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^t;b=xrc(m|k,g|t,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;k=p^a;m=xrc(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;i=f;return}function EDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;JDa(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=a;t=c[k>>2]|0;h=c[k+4>>2]|0;b=s^g;r=xrc(o|l,s|g,((o^l)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;l=b^h;o=xrc(r|t,b|h,((r^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=o;c[k+4>>2]=G;k=c[n>>2]|0;o=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;t=c[n+4>>2]|0;n=a+e|0;r=c[n>>2]|0;h=c[n+4>>2]|0;b=t^o;g=xrc(l|k,t|o,((l^k)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;k=b^h;l=xrc(g|r,b|h,((g^r)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=c[q>>2]|0;l=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;r=c[q+4>>2]|0;q=a+m|0;m=c[q>>2]|0;g=c[q+4>>2]|0;h=r^l;b=xrc(k|n,r|l,((k^n)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;n=h^g;k=xrc(b|m,h|g,((b^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=k;c[q+4>>2]=G;q=c[p>>2]|0;k=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;n=c[p+4>>2]|0;p=a+(e*3|0)|0;e=c[p>>2]|0;a=c[p+4>>2]|0;m=n^k;b=xrc(j|q,n|k,((j^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;q=m^a;j=xrc(b|e,m|a,((b^e)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[p>>2]=j;c[p+4>>2]=G;i=f;return}function FDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;IDa(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;JDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=o^g;q=xrc(k|n,o|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;o=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(o|h,g|b,((o^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;o=c[m+4>>2]|0;m=a+p|0;p=c[m>>2]|0;b=c[m+4>>2]|0;g=o^k;n=xrc(h|r,o|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|p,g|b,((n^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;p=r^h;n=xrc(l|j,r|h,((l^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;j=p^a;l=xrc(n|e,p|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function GDa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;IDa(f,b+d|0,8,d);KDa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=xrc(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;b=o^n;g=xrc(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=G;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=xrc(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;g=k^o;m=xrc(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=G;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=xrc(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;m=b^k;n=xrc(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=xrc(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;f=o^a;h=xrc(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=G;i=e;return}function HDa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;IDa(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;JDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=xrc(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=xrc(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=xrc(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function IDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<16384>>>0){m=l&65535}else{m=-l>>31&16383}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<16384>>>0){o=n&65535}else{o=-n>>31&16383}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<16384>>>0){p=i&65535}else{p=-i>>31&16383}b[h+4>>1]=p;i=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(i>>>0<16384>>>0){q=i&65535}else{q=-i>>31&16383}b[h+6>>1]=q;i=f+1|0;if((i|0)<4){f=i;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function JDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d>>1;d=f<<1;g=f*3|0;h=c;c=a;a=0;while(1){i=e[h-8>>1]|0;j=e[h>>1]|0;k=e[h+8>>1]|0;l=e[h+16>>1]|0;m=e[h+24>>1]|0;n=e[h+32>>1]|0;o=e[h+40>>1]|0;p=e[h+48>>1]|0;q=(e[h-16>>1]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0<16384>>>0){r=q&65535}else{r=-q>>31&16383}b[c>>1]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0<16384>>>0){s=q&65535}else{s=-q>>31&16383}b[c+(f<<1)>>1]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0<16384>>>0){t=q&65535}else{t=-q>>31&16383}b[c+(d<<1)>>1]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0<16384>>>0){u=q&65535}else{u=-q>>31&16383}b[c+(g<<1)>>1]=u;q=a+1|0;if((q|0)<4){h=h+2|0;c=c+2|0;a=q}else{break}}return}function KDa(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=h>>1;h=f+(-(i<<1)<<1)|0;f=0;j=d;while(1){k=e[h>>1]|0;l=e[h+2>>1]|0;m=e[h-2>>1]|0;n=e[h+4>>1]|0;o=e[h+6>>1]|0;c[j>>2]=(e[h-4>>1]|0)+((l+k|0)*20|0)+((n+m|0)*-5|0)+o;p=e[h+8>>1]|0;c[j+4>>2]=m+((n+l|0)*20|0)+((o+k|0)*-5|0)+p;m=e[h+10>>1]|0;c[j+8>>2]=k+((o+n|0)*20|0)+((p+l|0)*-5|0)+m;c[j+12>>2]=l+((p+o|0)*20|0)+((m+n|0)*-5|0)+(e[h+12>>1]|0);n=f+1|0;if((n|0)<9){h=h+(i<<1)|0;f=n;j=j+32|0}else{break}}j=g>>1;g=j<<1;f=j*3|0;i=a;a=0;h=d+64|0;while(1){d=c[h-32>>2]|0;n=c[h>>2]|0;m=c[h+32>>2]|0;o=c[h+64>>2]|0;p=c[h+96>>2]|0;l=c[h+128>>2]|0;k=c[h+160>>2]|0;q=c[h+192>>2]|0;r=(c[h-64>>2]|0)+512+((m+n|0)*20|0)+p+((o+d|0)*-5|0)>>10;if(r>>>0<16384>>>0){s=r&65535}else{s=-r>>31&16383}b[i>>1]=s;r=d+512+((o+m|0)*20|0)+l+((p+n|0)*-5|0)>>10;if(r>>>0<16384>>>0){t=r&65535}else{t=-r>>31&16383}b[i+(j<<1)>>1]=t;r=n+512+((p+o|0)*20|0)+k+((l+m|0)*-5|0)>>10;if(r>>>0<16384>>>0){u=r&65535}else{u=-r>>31&16383}b[i+(g<<1)>>1]=u;r=m+512+((l+p|0)*20|0)+q+((k+o|0)*-5|0)>>10;if(r>>>0<16384>>>0){v=r&65535}else{v=-r>>31&16383}b[i+(f<<1)>>1]=v;r=a+1|0;if((r|0)<4){i=i+2|0;a=r;h=h+4|0}else{break}}return}function LDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<16384>>>0){m=l&65535}else{m=-l>>31&16383}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<16384>>>0){o=n&65535}else{o=-n>>31&16383}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<16384>>>0){p=i&65535}else{p=-i>>31&16383}b[h+4>>1]=p;i=a+12|0;q=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(q>>>0<16384>>>0){r=q&65535}else{r=-q>>31&16383}b[h+6>>1]=r;q=a+14|0;c=(((e[n>>1]|0)+(e[l>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[q>>1]|0)>>5;if(c>>>0<16384>>>0){s=c&65535}else{s=-c>>31&16383}b[h+8>>1]=s;c=a+16|0;j=(((e[i>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[q>>1]|0)+(e[l>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<16384>>>0){t=j&65535}else{t=-j>>31&16383}b[h+10>>1]=t;j=a+18|0;k=(((e[q>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[l>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<16384>>>0){u=k&65535}else{u=-k>>31&16383}b[h+12>>1]=u;k=(((e[c>>1]|0)+(e[q>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<16384>>>0){v=k&65535}else{v=-k>>31&16383}b[h+14>>1]=v;k=f+1|0;if((k|0)<8){f=k;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function MDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<16384>>>0){L=K&65535}else{L=-K>>31&16383}b[c>>1]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0<16384>>>0){M=K&65535}else{M=-K>>31&16383}b[c+(g<<1)>>1]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0<16384>>>0){N=K&65535}else{N=-K>>31&16383}b[c+(r<<1)>>1]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0<16384>>>0){O=K&65535}else{O=-K>>31&16383}b[c+(s<<1)>>1]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0<16384>>>0){P=K&65535}else{P=-K>>31&16383}b[c+(t<<1)>>1]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0<16384>>>0){Q=K&65535}else{Q=-K>>31&16383}b[c+(u<<1)>>1]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0<16384>>>0){R=K&65535}else{R=-K>>31&16383}b[c+(v<<1)>>1]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0<16384>>>0){S=K&65535}else{S=-K>>31&16383}b[c+(w<<1)>>1]=S;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function NDa(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=i>>1;i=f+(-(j<<1)<<1)|0;f=0;k=d;while(1){l=e[i>>1]|0;m=e[i+2>>1]|0;n=e[i-2>>1]|0;o=e[i+4>>1]|0;p=e[i+6>>1]|0;c[k>>2]=(e[i-4>>1]|0)+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;q=e[i+8>>1]|0;c[k+4>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+q;n=e[i+10>>1]|0;c[k+8>>2]=l+((p+o|0)*20|0)+((q+m|0)*-5|0)+n;l=e[i+12>>1]|0;c[k+12>>2]=m+((q+p|0)*20|0)+((n+o|0)*-5|0)+l;m=e[i+14>>1]|0;c[k+16>>2]=o+((n+q|0)*20|0)+((l+p|0)*-5|0)+m;o=e[i+16>>1]|0;c[k+20>>2]=p+((l+n|0)*20|0)+((m+q|0)*-5|0)+o;p=e[i+18>>1]|0;c[k+24>>2]=q+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;c[k+28>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+(e[i+20>>1]|0);l=f+1|0;if((l|0)<13){i=i+(j<<1)|0;f=l;k=k+(h<<2)|0}else{break}}k=g>>1;g=h*-2|0;f=-h|0;j=h<<1;i=h*3|0;l=h<<2;p=h*5|0;m=h*6|0;o=h*7|0;n=h<<3;q=h*9|0;r=h*10|0;s=k<<1;t=k*3|0;u=k<<2;v=k*5|0;w=k*6|0;x=k*7|0;y=a;a=0;z=d+(h<<1<<2)|0;while(1){d=c[z+(f<<2)>>2]|0;A=c[z>>2]|0;B=c[z+(h<<2)>>2]|0;C=c[z+(j<<2)>>2]|0;D=c[z+(i<<2)>>2]|0;E=c[z+(l<<2)>>2]|0;F=c[z+(p<<2)>>2]|0;G=c[z+(m<<2)>>2]|0;H=c[z+(o<<2)>>2]|0;I=c[z+(n<<2)>>2]|0;J=c[z+(q<<2)>>2]|0;K=c[z+(r<<2)>>2]|0;L=(c[z+(g<<2)>>2]|0)+512+((B+A|0)*20|0)+D+((C+d|0)*-5|0)>>10;if(L>>>0<16384>>>0){M=L&65535}else{M=-L>>31&16383}b[y>>1]=M;L=d+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(L>>>0<16384>>>0){N=L&65535}else{N=-L>>31&16383}b[y+(k<<1)>>1]=N;L=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(L>>>0<16384>>>0){O=L&65535}else{O=-L>>31&16383}b[y+(s<<1)>>1]=O;L=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(L>>>0<16384>>>0){P=L&65535}else{P=-L>>31&16383}b[y+(t<<1)>>1]=P;L=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(L>>>0<16384>>>0){Q=L&65535}else{Q=-L>>31&16383}b[y+(u<<1)>>1]=Q;L=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(L>>>0<16384>>>0){R=L&65535}else{R=-L>>31&16383}b[y+(v<<1)>>1]=R;L=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(L>>>0<16384>>>0){S=L&65535}else{S=-L>>31&16383}b[y+(w<<1)>>1]=S;L=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(L>>>0<16384>>>0){T=L&65535}else{T=-L>>31&16383}b[y+(x<<1)>>1]=T;L=a+1|0;if((L|0)<8){y=y+2|0;a=L;z=z+4|0}else{break}}return}function ODa(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=i>>1;i=f+(-(j<<1)<<1)|0;f=0;k=d;while(1){l=e[i>>1]|0;m=e[i+2>>1]|0;n=e[i-2>>1]|0;o=e[i+4>>1]|0;p=e[i+6>>1]|0;c[k>>2]=(e[i-4>>1]|0)+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;q=e[i+8>>1]|0;c[k+4>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+q;n=e[i+10>>1]|0;c[k+8>>2]=l+((p+o|0)*20|0)+((q+m|0)*-5|0)+n;l=e[i+12>>1]|0;c[k+12>>2]=m+((q+p|0)*20|0)+((n+o|0)*-5|0)+l;m=e[i+14>>1]|0;c[k+16>>2]=o+((n+q|0)*20|0)+((l+p|0)*-5|0)+m;o=e[i+16>>1]|0;c[k+20>>2]=p+((l+n|0)*20|0)+((m+q|0)*-5|0)+o;p=e[i+18>>1]|0;c[k+24>>2]=q+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;c[k+28>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+(e[i+20>>1]|0);l=f+1|0;if((l|0)<13){i=i+(j<<1)|0;f=l;k=k+(h<<2)|0}else{break}}k=g>>1;g=h*-2|0;f=-h|0;j=h<<1;i=h*3|0;l=h<<2;p=h*5|0;m=h*6|0;o=h*7|0;n=h<<3;q=h*9|0;r=h*10|0;s=k<<1;t=k*3|0;u=k<<2;v=k*5|0;w=k*6|0;x=k*7|0;y=a;a=0;z=d+(h<<1<<2)|0;while(1){d=c[z+(f<<2)>>2]|0;A=c[z>>2]|0;B=c[z+(h<<2)>>2]|0;C=c[z+(j<<2)>>2]|0;D=c[z+(i<<2)>>2]|0;E=c[z+(l<<2)>>2]|0;F=c[z+(p<<2)>>2]|0;G=c[z+(m<<2)>>2]|0;H=c[z+(o<<2)>>2]|0;I=c[z+(n<<2)>>2]|0;J=c[z+(q<<2)>>2]|0;K=c[z+(r<<2)>>2]|0;L=(c[z+(g<<2)>>2]|0)+512+((B+A|0)*20|0)+D+((C+d|0)*-5|0)>>10;if(L>>>0<16384>>>0){M=L}else{M=-L>>31&16383}b[y>>1]=((e[y>>1]|0)+1+M|0)>>>1;L=y+(k<<1)|0;N=d+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(N>>>0<16384>>>0){O=N}else{O=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+O|0)>>>1;L=y+(s<<1)|0;N=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(N>>>0<16384>>>0){P=N}else{P=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+P|0)>>>1;L=y+(t<<1)|0;N=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(N>>>0<16384>>>0){Q=N}else{Q=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+Q|0)>>>1;L=y+(u<<1)|0;N=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(N>>>0<16384>>>0){R=N}else{R=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+R|0)>>>1;L=y+(v<<1)|0;N=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(N>>>0<16384>>>0){S=N}else{S=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+S|0)>>>1;L=y+(w<<1)|0;N=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(N>>>0<16384>>>0){T=N}else{T=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+T|0)>>>1;L=y+(x<<1)|0;N=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(N>>>0<16384>>>0){U=N}else{U=-N>>31&16383}b[L>>1]=((e[L>>1]|0)+1+U|0)>>>1;L=a+1|0;if((L|0)<8){y=y+2|0;a=L;z=z+4|0}else{break}}return}function PDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<16384>>>0){L=K}else{L=-K>>31&16383}b[c>>1]=((e[c>>1]|0)+1+L|0)>>>1;K=c+(g<<1)|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0<16384>>>0){N=M}else{N=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=c+(r<<1)|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0<16384>>>0){O=M}else{O=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=c+(s<<1)|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0<16384>>>0){P=M}else{P=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=c+(t<<1)|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0<16384>>>0){Q=M}else{Q=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=c+(u<<1)|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0<16384>>>0){R=M}else{R=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=c+(v<<1)|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0<16384>>>0){S=M}else{S=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=c+(w<<1)|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0<16384>>>0){T=M}else{T=-M>>31&16383}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function QDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<16384>>>0){m=l}else{m=-l>>31&16383}b[h>>1]=((e[h>>1]|0)+1+m|0)>>>1;l=h+2|0;n=a+8|0;o=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(o>>>0<16384>>>0){p=o}else{p=-o>>31&16383}b[l>>1]=((e[l>>1]|0)+1+p|0)>>>1;l=h+4|0;o=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[n>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[o>>1]|0)>>5;if(i>>>0<16384>>>0){q=i}else{q=-i>>31&16383}b[l>>1]=((e[l>>1]|0)+1+q|0)>>>1;l=h+6|0;i=a+12|0;r=(((e[n>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[o>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(r>>>0<16384>>>0){s=r}else{s=-r>>31&16383}b[l>>1]=((e[l>>1]|0)+1+s|0)>>>1;l=h+8|0;r=a+14|0;c=(((e[o>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[r>>1]|0)>>5;if(c>>>0<16384>>>0){t=c}else{t=-c>>31&16383}b[l>>1]=((e[l>>1]|0)+1+t|0)>>>1;l=h+10|0;c=a+16|0;j=(((e[i>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[r>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<16384>>>0){u=j}else{u=-j>>31&16383}b[l>>1]=((e[l>>1]|0)+1+u|0)>>>1;l=h+12|0;j=a+18|0;k=(((e[r>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[c>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<16384>>>0){v=k}else{v=-k>>31&16383}b[l>>1]=((e[l>>1]|0)+1+v|0)>>>1;l=h+14|0;k=(((e[c>>1]|0)+(e[r>>1]|0)|0)*20|0)+16+(e[o>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<16384>>>0){w=k}else{w=-k>>31&16383}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;l=f+1|0;if((l|0)<8){f=l;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function RDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a;h=c;i=d>>1;d=f>>1;f=c+2|0;j=c-2|0;k=c+4|0;l=c+6|0;m=(((e[f>>1]|0)+(e[h>>1]|0)|0)*20|0)+16+(e[c-4>>1]|0)+(((e[k>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[g>>1]=n;n=(((e[k>>1]|0)+(e[f>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[l>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[c+8>>1]|0)>>5;if(n>>>0<16384>>>0){o=n&65535}else{o=-n>>31&16383}b[a+2>>1]=o;o=h+(d<<1)|0;a=h+(d+1<<1)|0;n=h+(d-1<<1)|0;c=h+(d+2<<1)|0;l=h+(d+3<<1)|0;j=(((e[a>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[h+(d-2<<1)>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(j>>>0<16384>>>0){p=j&65535}else{p=-j>>31&16383}b[g+(i<<1)>>1]=p;p=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[l>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[h+(d+4<<1)>>1]|0)>>5;if(p>>>0<16384>>>0){q=p&65535;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}q=-p>>31&16383;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}function SDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a;g=d>>1;d=e[c-4>>1]|0;h=e[c>>1]|0;i=e[c+4>>1]|0;j=e[c+8>>1]|0;k=e[c+12>>1]|0;l=e[c+16>>1]|0;m=(e[c-8>>1]|0)+16+((i+h|0)*20|0)+k+((j+d|0)*-5|0)>>5;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[f>>1]=n;n=d+16+((j+i|0)*20|0)+l+((k+h|0)*-5|0)>>5;if(n>>>0<16384>>>0){o=n&65535}else{o=-n>>31&16383}b[f+(g<<1)>>1]=o;o=a+2|0;a=e[c-2>>1]|0;f=e[c+2>>1]|0;n=e[c+6>>1]|0;h=e[c+10>>1]|0;k=e[c+14>>1]|0;l=e[c+18>>1]|0;i=(e[c-6>>1]|0)+16+((n+f|0)*20|0)+k+((h+a|0)*-5|0)>>5;if(i>>>0<16384>>>0){p=i&65535}else{p=-i>>31&16383}b[o>>1]=p;p=a+16+((h+n|0)*20|0)+l+((k+f|0)*-5|0)>>5;if(p>>>0<16384>>>0){q=p&65535;r=o+(g<<1)|0;b[r>>1]=q;return}q=-p>>31&16383;r=o+(g<<1)|0;b[r>>1]=q;return}function TDa(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=h>>1;h=f+(-(i<<1)<<1)|0;f=0;j=d;while(1){k=e[h>>1]|0;l=e[h+2>>1]|0;m=e[h-2>>1]|0;n=e[h+4>>1]|0;o=e[h+6>>1]|0;c[j>>2]=(e[h-4>>1]|0)+((l+k|0)*20|0)+((n+m|0)*-5|0)+o;c[j+4>>2]=m+((n+l|0)*20|0)+((o+k|0)*-5|0)+(e[h+8>>1]|0);k=f+1|0;if((k|0)<7){h=h+(i<<1)|0;f=k;j=j+16|0}else{break}}j=a;f=g>>1;g=c[d+16>>2]|0;i=c[d+32>>2]|0;h=c[d+48>>2]|0;k=c[d+64>>2]|0;o=c[d+80>>2]|0;l=c[d+96>>2]|0;n=(c[d>>2]|0)+512+((h+i|0)*20|0)+o+((k+g|0)*-5|0)>>10;if(n>>>0<16384>>>0){p=n&65535}else{p=-n>>31&16383}b[j>>1]=p;p=g+512+((k+h|0)*20|0)+l+((o+i|0)*-5|0)>>10;if(p>>>0<16384>>>0){q=p&65535}else{q=-p>>31&16383}b[j+(f<<1)>>1]=q;q=a+2|0;a=c[d+20>>2]|0;j=c[d+36>>2]|0;p=c[d+52>>2]|0;i=c[d+68>>2]|0;o=c[d+84>>2]|0;l=c[d+100>>2]|0;h=(c[d+4>>2]|0)+512+((p+j|0)*20|0)+o+((i+a|0)*-5|0)>>10;if(h>>>0<16384>>>0){r=h&65535}else{r=-h>>31&16383}b[q>>1]=r;r=a+512+((i+p|0)*20|0)+l+((o+j|0)*-5|0)>>10;if(r>>>0<16384>>>0){s=r&65535;t=q+(f<<1)|0;b[t>>1]=s;return}s=-r>>31&16383;t=q+(f<<1)|0;b[t>>1]=s;return}function UDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<4096>>>0){m=l&65535}else{m=-l>>31&4095}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<4096>>>0){o=n&65535}else{o=-n>>31&4095}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<4096>>>0){p=i&65535}else{p=-i>>31&4095}b[h+4>>1]=p;i=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(i>>>0<4096>>>0){q=i&65535}else{q=-i>>31&4095}b[h+6>>1]=q;i=f+1|0;if((i|0)<4){f=i;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function VDa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d>>1;d=f<<1;g=f*3|0;h=c;c=a;a=0;while(1){i=e[h-8>>1]|0;j=e[h>>1]|0;k=e[h+8>>1]|0;l=e[h+16>>1]|0;m=e[h+24>>1]|0;n=e[h+32>>1]|0;o=e[h+40>>1]|0;p=e[h+48>>1]|0;q=(e[h-16>>1]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0<4096>>>0){r=q&65535}else{r=-q>>31&4095}b[c>>1]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0<4096>>>0){s=q&65535}else{s=-q>>31&4095}b[c+(f<<1)>>1]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0<4096>>>0){t=q&65535}else{t=-q>>31&4095}b[c+(d<<1)>>1]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0<4096>>>0){u=q&65535}else{u=-q>>31&4095}b[c+(g<<1)>>1]=u;q=a+1|0;if((q|0)<4){h=h+2|0;c=c+2|0;a=q}else{break}}return}function WDa(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=h>>1;h=f+(-(i<<1)<<1)|0;f=0;j=d;while(1){k=e[h>>1]|0;l=e[h+2>>1]|0;m=e[h-2>>1]|0;n=e[h+4>>1]|0;o=e[h+6>>1]|0;c[j>>2]=(e[h-4>>1]|0)+((l+k|0)*20|0)+((n+m|0)*-5|0)+o;p=e[h+8>>1]|0;c[j+4>>2]=m+((n+l|0)*20|0)+((o+k|0)*-5|0)+p;m=e[h+10>>1]|0;c[j+8>>2]=k+((o+n|0)*20|0)+((p+l|0)*-5|0)+m;c[j+12>>2]=l+((p+o|0)*20|0)+((m+n|0)*-5|0)+(e[h+12>>1]|0);n=f+1|0;if((n|0)<9){h=h+(i<<1)|0;f=n;j=j+32|0}else{break}}j=g>>1;g=j<<1;f=j*3|0;i=a;a=0;h=d+64|0;while(1){d=c[h-32>>2]|0;n=c[h>>2]|0;m=c[h+32>>2]|0;o=c[h+64>>2]|0;p=c[h+96>>2]|0;l=c[h+128>>2]|0;k=c[h+160>>2]|0;q=c[h+192>>2]|0;r=(c[h-64>>2]|0)+512+((m+n|0)*20|0)+p+((o+d|0)*-5|0)>>10;if(r>>>0<4096>>>0){s=r&65535}else{s=-r>>31&4095}b[i>>1]=s;r=d+512+((o+m|0)*20|0)+l+((p+n|0)*-5|0)>>10;if(r>>>0<4096>>>0){t=r&65535}else{t=-r>>31&4095}b[i+(j<<1)>>1]=t;r=n+512+((p+o|0)*20|0)+k+((l+m|0)*-5|0)>>10;if(r>>>0<4096>>>0){u=r&65535}else{u=-r>>31&4095}b[i+(g<<1)>>1]=u;r=m+512+((l+p|0)*20|0)+q+((k+o|0)*-5|0)>>10;if(r>>>0<4096>>>0){v=r&65535}else{v=-r>>31&4095}b[i+(f<<1)>>1]=v;r=a+1|0;if((r|0)<4){i=i+2|0;a=r;h=h+4|0}else{break}}return}function XDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<4096>>>0){m=l&65535}else{m=-l>>31&4095}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<4096>>>0){o=n&65535}else{o=-n>>31&4095}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<4096>>>0){p=i&65535}else{p=-i>>31&4095}b[h+4>>1]=p;i=a+12|0;q=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(q>>>0<4096>>>0){r=q&65535}else{r=-q>>31&4095}b[h+6>>1]=r;q=a+14|0;c=(((e[n>>1]|0)+(e[l>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[q>>1]|0)>>5;if(c>>>0<4096>>>0){s=c&65535}else{s=-c>>31&4095}b[h+8>>1]=s;c=a+16|0;j=(((e[i>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[q>>1]|0)+(e[l>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<4096>>>0){t=j&65535}else{t=-j>>31&4095}b[h+10>>1]=t;j=a+18|0;k=(((e[q>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[l>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<4096>>>0){u=k&65535}else{u=-k>>31&4095}b[h+12>>1]=u;k=(((e[c>>1]|0)+(e[q>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<4096>>>0){v=k&65535}else{v=-k>>31&4095}b[h+14>>1]=v;k=f+1|0;if((k|0)<8){f=k;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function YDa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<4096>>>0){L=K&65535}else{L=-K>>31&4095}b[c>>1]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0<4096>>>0){M=K&65535}else{M=-K>>31&4095}b[c+(g<<1)>>1]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0<4096>>>0){N=K&65535}else{N=-K>>31&4095}b[c+(r<<1)>>1]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0<4096>>>0){O=K&65535}else{O=-K>>31&4095}b[c+(s<<1)>>1]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0<4096>>>0){P=K&65535}else{P=-K>>31&4095}b[c+(t<<1)>>1]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0<4096>>>0){Q=K&65535}else{Q=-K>>31&4095}b[c+(u<<1)>>1]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0<4096>>>0){R=K&65535}else{R=-K>>31&4095}b[c+(v<<1)>>1]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0<4096>>>0){S=K&65535}else{S=-K>>31&4095}b[c+(w<<1)>>1]=S;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function ZDa(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=i>>1;i=f+(-(j<<1)<<1)|0;f=0;k=d;while(1){l=e[i>>1]|0;m=e[i+2>>1]|0;n=e[i-2>>1]|0;o=e[i+4>>1]|0;p=e[i+6>>1]|0;c[k>>2]=(e[i-4>>1]|0)+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;q=e[i+8>>1]|0;c[k+4>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+q;n=e[i+10>>1]|0;c[k+8>>2]=l+((p+o|0)*20|0)+((q+m|0)*-5|0)+n;l=e[i+12>>1]|0;c[k+12>>2]=m+((q+p|0)*20|0)+((n+o|0)*-5|0)+l;m=e[i+14>>1]|0;c[k+16>>2]=o+((n+q|0)*20|0)+((l+p|0)*-5|0)+m;o=e[i+16>>1]|0;c[k+20>>2]=p+((l+n|0)*20|0)+((m+q|0)*-5|0)+o;p=e[i+18>>1]|0;c[k+24>>2]=q+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;c[k+28>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+(e[i+20>>1]|0);l=f+1|0;if((l|0)<13){i=i+(j<<1)|0;f=l;k=k+(h<<2)|0}else{break}}k=g>>1;g=h*-2|0;f=-h|0;j=h<<1;i=h*3|0;l=h<<2;p=h*5|0;m=h*6|0;o=h*7|0;n=h<<3;q=h*9|0;r=h*10|0;s=k<<1;t=k*3|0;u=k<<2;v=k*5|0;w=k*6|0;x=k*7|0;y=a;a=0;z=d+(h<<1<<2)|0;while(1){d=c[z+(f<<2)>>2]|0;A=c[z>>2]|0;B=c[z+(h<<2)>>2]|0;C=c[z+(j<<2)>>2]|0;D=c[z+(i<<2)>>2]|0;E=c[z+(l<<2)>>2]|0;F=c[z+(p<<2)>>2]|0;G=c[z+(m<<2)>>2]|0;H=c[z+(o<<2)>>2]|0;I=c[z+(n<<2)>>2]|0;J=c[z+(q<<2)>>2]|0;K=c[z+(r<<2)>>2]|0;L=(c[z+(g<<2)>>2]|0)+512+((B+A|0)*20|0)+D+((C+d|0)*-5|0)>>10;if(L>>>0<4096>>>0){M=L&65535}else{M=-L>>31&4095}b[y>>1]=M;L=d+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(L>>>0<4096>>>0){N=L&65535}else{N=-L>>31&4095}b[y+(k<<1)>>1]=N;L=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(L>>>0<4096>>>0){O=L&65535}else{O=-L>>31&4095}b[y+(s<<1)>>1]=O;L=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(L>>>0<4096>>>0){P=L&65535}else{P=-L>>31&4095}b[y+(t<<1)>>1]=P;L=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(L>>>0<4096>>>0){Q=L&65535}else{Q=-L>>31&4095}b[y+(u<<1)>>1]=Q;L=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(L>>>0<4096>>>0){R=L&65535}else{R=-L>>31&4095}b[y+(v<<1)>>1]=R;L=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(L>>>0<4096>>>0){S=L&65535}else{S=-L>>31&4095}b[y+(w<<1)>>1]=S;L=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(L>>>0<4096>>>0){T=L&65535}else{T=-L>>31&4095}b[y+(x<<1)>>1]=T;L=a+1|0;if((L|0)<8){y=y+2|0;a=L;z=z+4|0}else{break}}return}function _Da(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=i>>1;i=f+(-(j<<1)<<1)|0;f=0;k=d;while(1){l=e[i>>1]|0;m=e[i+2>>1]|0;n=e[i-2>>1]|0;o=e[i+4>>1]|0;p=e[i+6>>1]|0;c[k>>2]=(e[i-4>>1]|0)+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;q=e[i+8>>1]|0;c[k+4>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+q;n=e[i+10>>1]|0;c[k+8>>2]=l+((p+o|0)*20|0)+((q+m|0)*-5|0)+n;l=e[i+12>>1]|0;c[k+12>>2]=m+((q+p|0)*20|0)+((n+o|0)*-5|0)+l;m=e[i+14>>1]|0;c[k+16>>2]=o+((n+q|0)*20|0)+((l+p|0)*-5|0)+m;o=e[i+16>>1]|0;c[k+20>>2]=p+((l+n|0)*20|0)+((m+q|0)*-5|0)+o;p=e[i+18>>1]|0;c[k+24>>2]=q+((m+l|0)*20|0)+((o+n|0)*-5|0)+p;c[k+28>>2]=n+((o+m|0)*20|0)+((p+l|0)*-5|0)+(e[i+20>>1]|0);l=f+1|0;if((l|0)<13){i=i+(j<<1)|0;f=l;k=k+(h<<2)|0}else{break}}k=g>>1;g=h*-2|0;f=-h|0;j=h<<1;i=h*3|0;l=h<<2;p=h*5|0;m=h*6|0;o=h*7|0;n=h<<3;q=h*9|0;r=h*10|0;s=k<<1;t=k*3|0;u=k<<2;v=k*5|0;w=k*6|0;x=k*7|0;y=a;a=0;z=d+(h<<1<<2)|0;while(1){d=c[z+(f<<2)>>2]|0;A=c[z>>2]|0;B=c[z+(h<<2)>>2]|0;C=c[z+(j<<2)>>2]|0;D=c[z+(i<<2)>>2]|0;E=c[z+(l<<2)>>2]|0;F=c[z+(p<<2)>>2]|0;G=c[z+(m<<2)>>2]|0;H=c[z+(o<<2)>>2]|0;I=c[z+(n<<2)>>2]|0;J=c[z+(q<<2)>>2]|0;K=c[z+(r<<2)>>2]|0;L=(c[z+(g<<2)>>2]|0)+512+((B+A|0)*20|0)+D+((C+d|0)*-5|0)>>10;if(L>>>0<4096>>>0){M=L}else{M=-L>>31&4095}b[y>>1]=((e[y>>1]|0)+1+M|0)>>>1;L=y+(k<<1)|0;N=d+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(N>>>0<4096>>>0){O=N}else{O=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+O|0)>>>1;L=y+(s<<1)|0;N=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(N>>>0<4096>>>0){P=N}else{P=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+P|0)>>>1;L=y+(t<<1)|0;N=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(N>>>0<4096>>>0){Q=N}else{Q=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+Q|0)>>>1;L=y+(u<<1)|0;N=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(N>>>0<4096>>>0){R=N}else{R=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+R|0)>>>1;L=y+(v<<1)|0;N=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(N>>>0<4096>>>0){S=N}else{S=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+S|0)>>>1;L=y+(w<<1)|0;N=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(N>>>0<4096>>>0){T=N}else{T=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+T|0)>>>1;L=y+(x<<1)|0;N=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(N>>>0<4096>>>0){U=N}else{U=-N>>31&4095}b[L>>1]=((e[L>>1]|0)+1+U|0)>>>1;L=a+1|0;if((L|0)<8){y=y+2|0;a=L;z=z+4|0}else{break}}return}function $Da(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<4096>>>0){L=K}else{L=-K>>31&4095}b[c>>1]=((e[c>>1]|0)+1+L|0)>>>1;K=c+(g<<1)|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0<4096>>>0){N=M}else{N=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=c+(r<<1)|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0<4096>>>0){O=M}else{O=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=c+(s<<1)|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0<4096>>>0){P=M}else{P=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=c+(t<<1)|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0<4096>>>0){Q=M}else{Q=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=c+(u<<1)|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0<4096>>>0){R=M}else{R=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=c+(v<<1)|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0<4096>>>0){S=M}else{S=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=c+(w<<1)|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0<4096>>>0){T=M}else{T=-M>>31&4095}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function aEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<4096>>>0){m=l}else{m=-l>>31&4095}b[h>>1]=((e[h>>1]|0)+1+m|0)>>>1;l=h+2|0;n=a+8|0;o=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(o>>>0<4096>>>0){p=o}else{p=-o>>31&4095}b[l>>1]=((e[l>>1]|0)+1+p|0)>>>1;l=h+4|0;o=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[n>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[o>>1]|0)>>5;if(i>>>0<4096>>>0){q=i}else{q=-i>>31&4095}b[l>>1]=((e[l>>1]|0)+1+q|0)>>>1;l=h+6|0;i=a+12|0;r=(((e[n>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[o>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(r>>>0<4096>>>0){s=r}else{s=-r>>31&4095}b[l>>1]=((e[l>>1]|0)+1+s|0)>>>1;l=h+8|0;r=a+14|0;c=(((e[o>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[r>>1]|0)>>5;if(c>>>0<4096>>>0){t=c}else{t=-c>>31&4095}b[l>>1]=((e[l>>1]|0)+1+t|0)>>>1;l=h+10|0;c=a+16|0;j=(((e[i>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[r>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<4096>>>0){u=j}else{u=-j>>31&4095}b[l>>1]=((e[l>>1]|0)+1+u|0)>>>1;l=h+12|0;j=a+18|0;k=(((e[r>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[c>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<4096>>>0){v=k}else{v=-k>>31&4095}b[l>>1]=((e[l>>1]|0)+1+v|0)>>>1;l=h+14|0;k=(((e[c>>1]|0)+(e[r>>1]|0)|0)*20|0)+16+(e[o>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<4096>>>0){w=k}else{w=-k>>31&4095}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;l=f+1|0;if((l|0)<8){f=l;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function bEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a;h=c;i=d>>1;d=f>>1;f=c+2|0;j=c-2|0;k=c+4|0;l=c+6|0;m=(((e[f>>1]|0)+(e[h>>1]|0)|0)*20|0)+16+(e[c-4>>1]|0)+(((e[k>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[g>>1]=n;n=(((e[k>>1]|0)+(e[f>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[l>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[c+8>>1]|0)>>5;if(n>>>0<4096>>>0){o=n&65535}else{o=-n>>31&4095}b[a+2>>1]=o;o=h+(d<<1)|0;a=h+(d+1<<1)|0;n=h+(d-1<<1)|0;c=h+(d+2<<1)|0;l=h+(d+3<<1)|0;j=(((e[a>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[h+(d-2<<1)>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(j>>>0<4096>>>0){p=j&65535}else{p=-j>>31&4095}b[g+(i<<1)>>1]=p;p=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[l>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[h+(d+4<<1)>>1]|0)>>5;if(p>>>0<4096>>>0){q=p&65535;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}q=-p>>31&4095;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}function cEa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a;g=d>>1;d=e[c-4>>1]|0;h=e[c>>1]|0;i=e[c+4>>1]|0;j=e[c+8>>1]|0;k=e[c+12>>1]|0;l=e[c+16>>1]|0;m=(e[c-8>>1]|0)+16+((i+h|0)*20|0)+k+((j+d|0)*-5|0)>>5;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[f>>1]=n;n=d+16+((j+i|0)*20|0)+l+((k+h|0)*-5|0)>>5;if(n>>>0<4096>>>0){o=n&65535}else{o=-n>>31&4095}b[f+(g<<1)>>1]=o;o=a+2|0;a=e[c-2>>1]|0;f=e[c+2>>1]|0;n=e[c+6>>1]|0;h=e[c+10>>1]|0;k=e[c+14>>1]|0;l=e[c+18>>1]|0;i=(e[c-6>>1]|0)+16+((n+f|0)*20|0)+k+((h+a|0)*-5|0)>>5;if(i>>>0<4096>>>0){p=i&65535}else{p=-i>>31&4095}b[o>>1]=p;p=a+16+((h+n|0)*20|0)+l+((k+f|0)*-5|0)>>5;if(p>>>0<4096>>>0){q=p&65535;r=o+(g<<1)|0;b[r>>1]=q;return}q=-p>>31&4095;r=o+(g<<1)|0;b[r>>1]=q;return}function dEa(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=h>>1;h=f+(-(i<<1)<<1)|0;f=0;j=d;while(1){k=e[h>>1]|0;l=e[h+2>>1]|0;m=e[h-2>>1]|0;n=e[h+4>>1]|0;o=e[h+6>>1]|0;c[j>>2]=(e[h-4>>1]|0)+((l+k|0)*20|0)+((n+m|0)*-5|0)+o;c[j+4>>2]=m+((n+l|0)*20|0)+((o+k|0)*-5|0)+(e[h+8>>1]|0);k=f+1|0;if((k|0)<7){h=h+(i<<1)|0;f=k;j=j+16|0}else{break}}j=a;f=g>>1;g=c[d+16>>2]|0;i=c[d+32>>2]|0;h=c[d+48>>2]|0;k=c[d+64>>2]|0;o=c[d+80>>2]|0;l=c[d+96>>2]|0;n=(c[d>>2]|0)+512+((h+i|0)*20|0)+o+((k+g|0)*-5|0)>>10;if(n>>>0<4096>>>0){p=n&65535}else{p=-n>>31&4095}b[j>>1]=p;p=g+512+((k+h|0)*20|0)+l+((o+i|0)*-5|0)>>10;if(p>>>0<4096>>>0){q=p&65535}else{q=-p>>31&4095}b[j+(f<<1)>>1]=q;q=a+2|0;a=c[d+20>>2]|0;j=c[d+36>>2]|0;p=c[d+52>>2]|0;i=c[d+68>>2]|0;o=c[d+84>>2]|0;l=c[d+100>>2]|0;h=(c[d+4>>2]|0)+512+((p+j|0)*20|0)+o+((i+a|0)*-5|0)>>10;if(h>>>0<4096>>>0){r=h&65535}else{r=-h>>31&4095}b[q>>1]=r;r=a+512+((i+p|0)*20|0)+l+((o+j|0)*-5|0)>>10;if(r>>>0<4096>>>0){s=r&65535;t=q+(f<<1)|0;b[t>>1]=s;return}s=-r>>31&4095;t=q+(f<<1)|0;b[t>>1]=s;return}function eEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<1024>>>0){m=l&65535}else{m=-l>>31&1023}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<1024>>>0){o=n&65535}else{o=-n>>31&1023}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<1024>>>0){p=i&65535}else{p=-i>>31&1023}b[h+4>>1]=p;i=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(i>>>0<1024>>>0){q=i&65535}else{q=-i>>31&1023}b[h+6>>1]=q;i=f+1|0;if((i|0)<4){f=i;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function fEa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d>>1;d=f<<1;g=f*3|0;h=c;c=a;a=0;while(1){i=e[h-8>>1]|0;j=e[h>>1]|0;k=e[h+8>>1]|0;l=e[h+16>>1]|0;m=e[h+24>>1]|0;n=e[h+32>>1]|0;o=e[h+40>>1]|0;p=e[h+48>>1]|0;q=(e[h-16>>1]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0<1024>>>0){r=q&65535}else{r=-q>>31&1023}b[c>>1]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0<1024>>>0){s=q&65535}else{s=-q>>31&1023}b[c+(f<<1)>>1]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0<1024>>>0){t=q&65535}else{t=-q>>31&1023}b[c+(d<<1)>>1]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0<1024>>>0){u=q&65535}else{u=-q>>31&1023}b[c+(g<<1)>>1]=u;q=a+1|0;if((q|0)<4){h=h+2|0;c=c+2|0;a=q}else{break}}return}function gEa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f>>1;f=d+(-(g<<1)<<1)|0;d=0;h=c;while(1){i=f+2|0;j=f-2|0;k=f+4|0;l=f+6|0;b[h>>1]=((((((b[i>>1]|0)+(b[f>>1]|0)&65535)*20&65535)-10230&65535)+(b[f-4>>1]|0)&65535)+(((b[k>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);m=f+8|0;b[h+2>>1]=((((((b[k>>1]|0)+(b[i>>1]|0)&65535)*20&65535)-10230&65535)+(b[j>>1]|0)&65535)+(((b[l>>1]|0)+(b[f>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);j=f+10|0;b[h+4>>1]=((((((b[l>>1]|0)+(b[k>>1]|0)&65535)*20&65535)-10230&65535)+(b[f>>1]|0)&65535)+(((b[m>>1]|0)+(b[i>>1]|0)&65535)*-5&65535)&65535)+(b[j>>1]|0);b[h+6>>1]=((((((b[m>>1]|0)+(b[l>>1]|0)&65535)*20&65535)-10230&65535)+(b[i>>1]|0)&65535)+(((b[j>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[f+12>>1]|0);k=d+1|0;if((k|0)<9){f=f+(g<<1)|0;d=k;h=h+16|0}else{break}}h=e>>1;e=h<<1;d=h*3|0;g=a;a=0;f=c+32|0;while(1){c=b[f-16>>1]|0;k=b[f>>1]|0;j=k+10230|0;i=b[f+16>>1]|0;l=i+10230|0;m=(b[f+32>>1]|0)+10230|0;n=(b[f+48>>1]|0)+10230|0;o=(b[f+64>>1]|0)+10230|0;p=(b[f+80>>1]|0)+10230|0;q=b[f+96>>1]|0;r=(b[f-32>>1]|0)+10742+((l+j|0)*20|0)+n+((m+(c+10230)|0)*-5|0)>>10;if(r>>>0<1024>>>0){s=r&65535}else{s=-r>>31&1023}b[g>>1]=s;r=c+10742+((m+l|0)*20|0)+o+((n+j|0)*-5|0)>>10;if(r>>>0<1024>>>0){t=r&65535}else{t=-r>>31&1023}b[g+(h<<1)>>1]=t;r=k+10742+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>10;if(r>>>0<1024>>>0){u=r&65535}else{u=-r>>31&1023}b[g+(e<<1)>>1]=u;r=i+20972+q+((o+n|0)*20|0)+((p+m|0)*-5|0)>>10;if(r>>>0<1024>>>0){v=r&65535}else{v=-r>>31&1023}b[g+(d<<1)>>1]=v;r=a+1|0;if((r|0)<4){g=g+2|0;a=r;f=f+2|0}else{break}}return}function hEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<1024>>>0){m=l&65535}else{m=-l>>31&1023}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<1024>>>0){o=n&65535}else{o=-n>>31&1023}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<1024>>>0){p=i&65535}else{p=-i>>31&1023}b[h+4>>1]=p;i=a+12|0;q=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(q>>>0<1024>>>0){r=q&65535}else{r=-q>>31&1023}b[h+6>>1]=r;q=a+14|0;c=(((e[n>>1]|0)+(e[l>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[q>>1]|0)>>5;if(c>>>0<1024>>>0){s=c&65535}else{s=-c>>31&1023}b[h+8>>1]=s;c=a+16|0;j=(((e[i>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[q>>1]|0)+(e[l>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<1024>>>0){t=j&65535}else{t=-j>>31&1023}b[h+10>>1]=t;j=a+18|0;k=(((e[q>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[l>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<1024>>>0){u=k&65535}else{u=-k>>31&1023}b[h+12>>1]=u;k=(((e[c>>1]|0)+(e[q>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<1024>>>0){v=k&65535}else{v=-k>>31&1023}b[h+14>>1]=v;k=f+1|0;if((k|0)<8){f=k;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function iEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<1024>>>0){L=K&65535}else{L=-K>>31&1023}b[c>>1]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0<1024>>>0){M=K&65535}else{M=-K>>31&1023}b[c+(g<<1)>>1]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0<1024>>>0){N=K&65535}else{N=-K>>31&1023}b[c+(r<<1)>>1]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0<1024>>>0){O=K&65535}else{O=-K>>31&1023}b[c+(s<<1)>>1]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0<1024>>>0){P=K&65535}else{P=-K>>31&1023}b[c+(t<<1)>>1]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0<1024>>>0){Q=K&65535}else{Q=-K>>31&1023}b[c+(u<<1)>>1]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0<1024>>>0){R=K&65535}else{R=-K>>31&1023}b[c+(v<<1)>>1]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0<1024>>>0){S=K&65535}else{S=-K>>31&1023}b[c+(w<<1)>>1]=S;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function jEa(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;h=g>>1;g=d+(-(h<<1)<<1)|0;d=0;i=c;while(1){j=g+2|0;k=g-2|0;l=g+4|0;m=g+6|0;b[i>>1]=((((((b[j>>1]|0)+(b[g>>1]|0)&65535)*20&65535)-10230&65535)+(b[g-4>>1]|0)&65535)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);n=g+8|0;b[i+2>>1]=((((((b[l>>1]|0)+(b[j>>1]|0)&65535)*20&65535)-10230&65535)+(b[k>>1]|0)&65535)+(((b[m>>1]|0)+(b[g>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);k=g+10|0;b[i+4>>1]=((((((b[m>>1]|0)+(b[l>>1]|0)&65535)*20&65535)-10230&65535)+(b[g>>1]|0)&65535)+(((b[n>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[k>>1]|0);o=g+12|0;b[i+6>>1]=((((((b[n>>1]|0)+(b[m>>1]|0)&65535)*20&65535)-10230&65535)+(b[j>>1]|0)&65535)+(((b[k>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[o>>1]|0);j=g+14|0;b[i+8>>1]=((((((b[k>>1]|0)+(b[n>>1]|0)&65535)*20&65535)-10230&65535)+(b[l>>1]|0)&65535)+(((b[o>>1]|0)+(b[m>>1]|0)&65535)*-5&65535)&65535)+(b[j>>1]|0);l=g+16|0;b[i+10>>1]=((((((b[o>>1]|0)+(b[k>>1]|0)&65535)*20&65535)-10230&65535)+(b[m>>1]|0)&65535)+(((b[j>>1]|0)+(b[n>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);m=g+18|0;b[i+12>>1]=((((((b[j>>1]|0)+(b[o>>1]|0)&65535)*20&65535)-10230&65535)+(b[n>>1]|0)&65535)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);b[i+14>>1]=((((((b[l>>1]|0)+(b[j>>1]|0)&65535)*20&65535)-10230&65535)+(b[k>>1]|0)&65535)+(((b[m>>1]|0)+(b[o>>1]|0)&65535)*-5&65535)&65535)+(b[g+20>>1]|0);o=d+1|0;if((o|0)<13){g=g+(h<<1)|0;d=o;i=i+(f<<1)|0}else{break}}i=e>>1;e=f*-2|0;d=-f|0;h=f<<1;g=f*3|0;o=f<<2;m=f*5|0;k=f*6|0;j=f*7|0;l=f<<3;n=f*9|0;p=f*10|0;q=i<<1;r=i*3|0;s=i<<2;t=i*5|0;u=i*6|0;v=i*7|0;w=a;a=0;x=c+(f<<1<<1)|0;while(1){c=b[x+(d<<1)>>1]|0;y=b[x>>1]|0;z=y+10230|0;A=b[x+(f<<1)>>1]|0;B=A+10230|0;C=b[x+(h<<1)>>1]|0;D=C+10230|0;E=b[x+(g<<1)>>1]|0;F=E+10230|0;G=b[x+(o<<1)>>1]|0;H=G+10230|0;I=b[x+(m<<1)>>1]|0;J=I+10230|0;K=(b[x+(k<<1)>>1]|0)+10230|0;L=(b[x+(j<<1)>>1]|0)+10230|0;M=(b[x+(l<<1)>>1]|0)+10230|0;N=(b[x+(n<<1)>>1]|0)+10230|0;O=b[x+(p<<1)>>1]|0;P=(b[x+(e<<1)>>1]|0)+10742+((B+z|0)*20|0)+F+((D+(c+10230)|0)*-5|0)>>10;if(P>>>0<1024>>>0){Q=P&65535}else{Q=-P>>31&1023}b[w>>1]=Q;P=c+10742+((D+B|0)*20|0)+H+((F+z|0)*-5|0)>>10;if(P>>>0<1024>>>0){R=P&65535}else{R=-P>>31&1023}b[w+(i<<1)>>1]=R;P=y+10742+((F+D|0)*20|0)+J+((H+B|0)*-5|0)>>10;if(P>>>0<1024>>>0){S=P&65535}else{S=-P>>31&1023}b[w+(q<<1)>>1]=S;P=A+10742+((H+F|0)*20|0)+K+((J+D|0)*-5|0)>>10;if(P>>>0<1024>>>0){T=P&65535}else{T=-P>>31&1023}b[w+(r<<1)>>1]=T;P=C+10742+((J+H|0)*20|0)+L+((K+F|0)*-5|0)>>10;if(P>>>0<1024>>>0){U=P&65535}else{U=-P>>31&1023}b[w+(s<<1)>>1]=U;P=E+10742+((K+J|0)*20|0)+M+((L+H|0)*-5|0)>>10;if(P>>>0<1024>>>0){V=P&65535}else{V=-P>>31&1023}b[w+(t<<1)>>1]=V;P=G+10742+((L+K|0)*20|0)+N+((M+J|0)*-5|0)>>10;if(P>>>0<1024>>>0){W=P&65535}else{W=-P>>31&1023}b[w+(u<<1)>>1]=W;P=I+20972+O+((M+L|0)*20|0)+((N+K|0)*-5|0)>>10;if(P>>>0<1024>>>0){X=P&65535}else{X=-P>>31&1023}b[w+(v<<1)>>1]=X;P=a+1|0;if((P|0)<8){w=w+2|0;a=P;x=x+2|0}else{break}}return}function kEa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;i=h>>1;h=d+(-(i<<1)<<1)|0;d=0;j=c;while(1){k=h+2|0;l=h-2|0;m=h+4|0;n=h+6|0;b[j>>1]=((((((b[k>>1]|0)+(b[h>>1]|0)&65535)*20&65535)-10230&65535)+(b[h-4>>1]|0)&65535)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);o=h+8|0;b[j+2>>1]=((((((b[m>>1]|0)+(b[k>>1]|0)&65535)*20&65535)-10230&65535)+(b[l>>1]|0)&65535)+(((b[n>>1]|0)+(b[h>>1]|0)&65535)*-5&65535)&65535)+(b[o>>1]|0);l=h+10|0;b[j+4>>1]=((((((b[n>>1]|0)+(b[m>>1]|0)&65535)*20&65535)-10230&65535)+(b[h>>1]|0)&65535)+(((b[o>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);p=h+12|0;b[j+6>>1]=((((((b[o>>1]|0)+(b[n>>1]|0)&65535)*20&65535)-10230&65535)+(b[k>>1]|0)&65535)+(((b[l>>1]|0)+(b[m>>1]|0)&65535)*-5&65535)&65535)+(b[p>>1]|0);k=h+14|0;b[j+8>>1]=((((((b[l>>1]|0)+(b[o>>1]|0)&65535)*20&65535)-10230&65535)+(b[m>>1]|0)&65535)+(((b[p>>1]|0)+(b[n>>1]|0)&65535)*-5&65535)&65535)+(b[k>>1]|0);m=h+16|0;b[j+10>>1]=((((((b[p>>1]|0)+(b[l>>1]|0)&65535)*20&65535)-10230&65535)+(b[n>>1]|0)&65535)+(((b[k>>1]|0)+(b[o>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);n=h+18|0;b[j+12>>1]=((((((b[k>>1]|0)+(b[p>>1]|0)&65535)*20&65535)-10230&65535)+(b[o>>1]|0)&65535)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);b[j+14>>1]=((((((b[m>>1]|0)+(b[k>>1]|0)&65535)*20&65535)-10230&65535)+(b[l>>1]|0)&65535)+(((b[n>>1]|0)+(b[p>>1]|0)&65535)*-5&65535)&65535)+(b[h+20>>1]|0);p=d+1|0;if((p|0)<13){h=h+(i<<1)|0;d=p;j=j+(g<<1)|0}else{break}}j=f>>1;f=g*-2|0;d=-g|0;i=g<<1;h=g*3|0;p=g<<2;n=g*5|0;l=g*6|0;k=g*7|0;m=g<<3;o=g*9|0;q=g*10|0;r=j<<1;s=j*3|0;t=j<<2;u=j*5|0;v=j*6|0;w=j*7|0;x=a;a=0;y=c+(g<<1<<1)|0;while(1){c=b[y+(d<<1)>>1]|0;z=b[y>>1]|0;A=z+10230|0;B=b[y+(g<<1)>>1]|0;C=B+10230|0;D=b[y+(i<<1)>>1]|0;E=D+10230|0;F=b[y+(h<<1)>>1]|0;G=F+10230|0;H=b[y+(p<<1)>>1]|0;I=H+10230|0;J=b[y+(n<<1)>>1]|0;K=J+10230|0;L=(b[y+(l<<1)>>1]|0)+10230|0;M=(b[y+(k<<1)>>1]|0)+10230|0;N=(b[y+(m<<1)>>1]|0)+10230|0;O=(b[y+(o<<1)>>1]|0)+10230|0;P=b[y+(q<<1)>>1]|0;Q=(b[y+(f<<1)>>1]|0)+10742+((C+A|0)*20|0)+G+((E+(c+10230)|0)*-5|0)>>10;if(Q>>>0<1024>>>0){R=Q}else{R=-Q>>31&1023}b[x>>1]=((e[x>>1]|0)+1+R|0)>>>1;Q=x+(j<<1)|0;S=c+10742+((E+C|0)*20|0)+I+((G+A|0)*-5|0)>>10;if(S>>>0<1024>>>0){T=S}else{T=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+T|0)>>>1;Q=x+(r<<1)|0;S=z+10742+((G+E|0)*20|0)+K+((I+C|0)*-5|0)>>10;if(S>>>0<1024>>>0){U=S}else{U=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+U|0)>>>1;Q=x+(s<<1)|0;S=B+10742+((I+G|0)*20|0)+L+((K+E|0)*-5|0)>>10;if(S>>>0<1024>>>0){V=S}else{V=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+V|0)>>>1;Q=x+(t<<1)|0;S=D+10742+((K+I|0)*20|0)+M+((L+G|0)*-5|0)>>10;if(S>>>0<1024>>>0){W=S}else{W=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+W|0)>>>1;Q=x+(u<<1)|0;S=F+10742+((L+K|0)*20|0)+N+((M+I|0)*-5|0)>>10;if(S>>>0<1024>>>0){X=S}else{X=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+X|0)>>>1;Q=x+(v<<1)|0;S=H+10742+((M+L|0)*20|0)+O+((N+K|0)*-5|0)>>10;if(S>>>0<1024>>>0){Y=S}else{Y=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+Y|0)>>>1;Q=x+(w<<1)|0;S=J+20972+P+((N+M|0)*20|0)+((O+L|0)*-5|0)>>10;if(S>>>0<1024>>>0){Z=S}else{Z=-S>>31&1023}b[Q>>1]=((e[Q>>1]|0)+1+Z|0)>>>1;Q=a+1|0;if((Q|0)<8){x=x+2|0;a=Q;y=y+2|0}else{break}}return}function lEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<1024>>>0){L=K}else{L=-K>>31&1023}b[c>>1]=((e[c>>1]|0)+1+L|0)>>>1;K=c+(g<<1)|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0<1024>>>0){N=M}else{N=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=c+(r<<1)|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0<1024>>>0){O=M}else{O=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=c+(s<<1)|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0<1024>>>0){P=M}else{P=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=c+(t<<1)|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0<1024>>>0){Q=M}else{Q=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=c+(u<<1)|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0<1024>>>0){R=M}else{R=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=c+(v<<1)|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0<1024>>>0){S=M}else{S=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=c+(w<<1)|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0<1024>>>0){T=M}else{T=-M>>31&1023}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function mEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<1024>>>0){m=l}else{m=-l>>31&1023}b[h>>1]=((e[h>>1]|0)+1+m|0)>>>1;l=h+2|0;n=a+8|0;o=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(o>>>0<1024>>>0){p=o}else{p=-o>>31&1023}b[l>>1]=((e[l>>1]|0)+1+p|0)>>>1;l=h+4|0;o=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[n>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[o>>1]|0)>>5;if(i>>>0<1024>>>0){q=i}else{q=-i>>31&1023}b[l>>1]=((e[l>>1]|0)+1+q|0)>>>1;l=h+6|0;i=a+12|0;r=(((e[n>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[o>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(r>>>0<1024>>>0){s=r}else{s=-r>>31&1023}b[l>>1]=((e[l>>1]|0)+1+s|0)>>>1;l=h+8|0;r=a+14|0;c=(((e[o>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[r>>1]|0)>>5;if(c>>>0<1024>>>0){t=c}else{t=-c>>31&1023}b[l>>1]=((e[l>>1]|0)+1+t|0)>>>1;l=h+10|0;c=a+16|0;j=(((e[i>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[r>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<1024>>>0){u=j}else{u=-j>>31&1023}b[l>>1]=((e[l>>1]|0)+1+u|0)>>>1;l=h+12|0;j=a+18|0;k=(((e[r>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[c>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<1024>>>0){v=k}else{v=-k>>31&1023}b[l>>1]=((e[l>>1]|0)+1+v|0)>>>1;l=h+14|0;k=(((e[c>>1]|0)+(e[r>>1]|0)|0)*20|0)+16+(e[o>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<1024>>>0){w=k}else{w=-k>>31&1023}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;l=f+1|0;if((l|0)<8){f=l;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function nEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a;h=c;i=d>>1;d=f>>1;f=c+2|0;j=c-2|0;k=c+4|0;l=c+6|0;m=(((e[f>>1]|0)+(e[h>>1]|0)|0)*20|0)+16+(e[c-4>>1]|0)+(((e[k>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[g>>1]=n;n=(((e[k>>1]|0)+(e[f>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[l>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[c+8>>1]|0)>>5;if(n>>>0<1024>>>0){o=n&65535}else{o=-n>>31&1023}b[a+2>>1]=o;o=h+(d<<1)|0;a=h+(d+1<<1)|0;n=h+(d-1<<1)|0;c=h+(d+2<<1)|0;l=h+(d+3<<1)|0;j=(((e[a>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[h+(d-2<<1)>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(j>>>0<1024>>>0){p=j&65535}else{p=-j>>31&1023}b[g+(i<<1)>>1]=p;p=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[l>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[h+(d+4<<1)>>1]|0)>>5;if(p>>>0<1024>>>0){q=p&65535;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}q=-p>>31&1023;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}function oEa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a;g=d>>1;d=e[c-4>>1]|0;h=e[c>>1]|0;i=e[c+4>>1]|0;j=e[c+8>>1]|0;k=e[c+12>>1]|0;l=e[c+16>>1]|0;m=(e[c-8>>1]|0)+16+((i+h|0)*20|0)+k+((j+d|0)*-5|0)>>5;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[f>>1]=n;n=d+16+((j+i|0)*20|0)+l+((k+h|0)*-5|0)>>5;if(n>>>0<1024>>>0){o=n&65535}else{o=-n>>31&1023}b[f+(g<<1)>>1]=o;o=a+2|0;a=e[c-2>>1]|0;f=e[c+2>>1]|0;n=e[c+6>>1]|0;h=e[c+10>>1]|0;k=e[c+14>>1]|0;l=e[c+18>>1]|0;i=(e[c-6>>1]|0)+16+((n+f|0)*20|0)+k+((h+a|0)*-5|0)>>5;if(i>>>0<1024>>>0){p=i&65535}else{p=-i>>31&1023}b[o>>1]=p;p=a+16+((h+n|0)*20|0)+l+((k+f|0)*-5|0)>>5;if(p>>>0<1024>>>0){q=p&65535;r=o+(g<<1)|0;b[r>>1]=q;return}q=-p>>31&1023;r=o+(g<<1)|0;b[r>>1]=q;return}function pEa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=d+(-(g<<1)<<1)|0;d=0;h=c;while(1){i=f+2|0;j=f-2|0;k=f+4|0;l=f+6|0;b[h>>1]=((((((b[i>>1]|0)+(b[f>>1]|0)&65535)*20&65535)-10230&65535)+(b[f-4>>1]|0)&65535)+(((b[k>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);b[h+2>>1]=((((((b[k>>1]|0)+(b[i>>1]|0)&65535)*20&65535)-10230&65535)+(b[j>>1]|0)&65535)+(((b[l>>1]|0)+(b[f>>1]|0)&65535)*-5&65535)&65535)+(b[f+8>>1]|0);l=d+1|0;if((l|0)<7){f=f+(g<<1)|0;d=l;h=h+8|0}else{break}}h=a;d=e>>1;e=b[c+8>>1]|0;g=(b[c+16>>1]|0)+10230|0;f=(b[c+24>>1]|0)+10230|0;l=(b[c+32>>1]|0)+10230|0;j=(b[c+40>>1]|0)+10230|0;i=b[c+48>>1]|0;k=(b[c>>1]|0)+10742+((f+g|0)*20|0)+j+((l+(e+10230)|0)*-5|0)>>10;if(k>>>0<1024>>>0){m=k&65535}else{m=-k>>31&1023}b[h>>1]=m;m=e+20972+i+((l+f|0)*20|0)+((j+g|0)*-5|0)>>10;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[h+(d<<1)>>1]=n;n=a+2|0;a=b[c+10>>1]|0;h=(b[c+18>>1]|0)+10230|0;m=(b[c+26>>1]|0)+10230|0;g=(b[c+34>>1]|0)+10230|0;j=(b[c+42>>1]|0)+10230|0;f=b[c+50>>1]|0;l=(b[c+2>>1]|0)+10742+((m+h|0)*20|0)+j+((g+(a+10230)|0)*-5|0)>>10;if(l>>>0<1024>>>0){o=l&65535}else{o=-l>>31&1023}b[n>>1]=o;o=a+20972+f+((g+m|0)*20|0)+((j+h|0)*-5|0)>>10;if(o>>>0<1024>>>0){p=o&65535;q=n+(d<<1)|0;b[q>>1]=p;return}p=-o>>31&1023;q=n+(d<<1)|0;b[q>>1]=p;return}function qEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<512>>>0){m=l&65535}else{m=-l>>31&511}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<512>>>0){o=n&65535}else{o=-n>>31&511}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<512>>>0){p=i&65535}else{p=-i>>31&511}b[h+4>>1]=p;i=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(i>>>0<512>>>0){q=i&65535}else{q=-i>>31&511}b[h+6>>1]=q;i=f+1|0;if((i|0)<4){f=i;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function rEa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d>>1;d=f<<1;g=f*3|0;h=c;c=a;a=0;while(1){i=e[h-8>>1]|0;j=e[h>>1]|0;k=e[h+8>>1]|0;l=e[h+16>>1]|0;m=e[h+24>>1]|0;n=e[h+32>>1]|0;o=e[h+40>>1]|0;p=e[h+48>>1]|0;q=(e[h-16>>1]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0<512>>>0){r=q&65535}else{r=-q>>31&511}b[c>>1]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0<512>>>0){s=q&65535}else{s=-q>>31&511}b[c+(f<<1)>>1]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0<512>>>0){t=q&65535}else{t=-q>>31&511}b[c+(d<<1)>>1]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0<512>>>0){u=q&65535}else{u=-q>>31&511}b[c+(g<<1)>>1]=u;q=a+1|0;if((q|0)<4){h=h+2|0;c=c+2|0;a=q}else{break}}return}function sEa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=f>>1;f=d+(-(g<<1)<<1)|0;d=0;h=c;while(1){i=f+2|0;j=f-2|0;k=f+4|0;l=f+6|0;b[h>>1]=(((b[f-4>>1]|0)+(((b[i>>1]|0)+(b[f>>1]|0)&65535)*20&65535)&65535)+(((b[k>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);m=f+8|0;b[h+2>>1]=(((b[j>>1]|0)+(((b[k>>1]|0)+(b[i>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[f>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);j=f+10|0;b[h+4>>1]=(((b[f>>1]|0)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[i>>1]|0)&65535)*-5&65535)&65535)+(b[j>>1]|0);b[h+6>>1]=(((b[i>>1]|0)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*20&65535)&65535)+(((b[j>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[f+12>>1]|0);k=d+1|0;if((k|0)<9){f=f+(g<<1)|0;d=k;h=h+16|0}else{break}}h=e>>1;e=h<<1;d=h*3|0;g=a;a=0;f=c+32|0;while(1){c=b[f-16>>1]|0;k=b[f>>1]|0;j=b[f+16>>1]|0;l=b[f+32>>1]|0;m=b[f+48>>1]|0;i=b[f+64>>1]|0;n=b[f+80>>1]|0;o=b[f+96>>1]|0;p=(b[f-32>>1]|0)+512+((j+k|0)*20|0)+m+((l+c|0)*-5|0)>>10;if(p>>>0<512>>>0){q=p&65535}else{q=-p>>31&511}b[g>>1]=q;p=c+512+((l+j|0)*20|0)+i+((m+k|0)*-5|0)>>10;if(p>>>0<512>>>0){r=p&65535}else{r=-p>>31&511}b[g+(h<<1)>>1]=r;p=k+512+((m+l|0)*20|0)+n+((i+j|0)*-5|0)>>10;if(p>>>0<512>>>0){s=p&65535}else{s=-p>>31&511}b[g+(e<<1)>>1]=s;p=j+512+((i+m|0)*20|0)+o+((n+l|0)*-5|0)>>10;if(p>>>0<512>>>0){t=p&65535}else{t=-p>>31&511}b[g+(d<<1)>>1]=t;p=a+1|0;if((p|0)<4){g=g+2|0;a=p;f=f+2|0}else{break}}return}function tEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<512>>>0){m=l&65535}else{m=-l>>31&511}b[h>>1]=m;l=a+8|0;n=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(n>>>0<512>>>0){o=n&65535}else{o=-n>>31&511}b[h+2>>1]=o;n=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[l>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(i>>>0<512>>>0){p=i&65535}else{p=-i>>31&511}b[h+4>>1]=p;i=a+12|0;q=(((e[l>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(q>>>0<512>>>0){r=q&65535}else{r=-q>>31&511}b[h+6>>1]=r;q=a+14|0;c=(((e[n>>1]|0)+(e[l>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[q>>1]|0)>>5;if(c>>>0<512>>>0){s=c&65535}else{s=-c>>31&511}b[h+8>>1]=s;c=a+16|0;j=(((e[i>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[q>>1]|0)+(e[l>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<512>>>0){t=j&65535}else{t=-j>>31&511}b[h+10>>1]=t;j=a+18|0;k=(((e[q>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[l>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<512>>>0){u=k&65535}else{u=-k>>31&511}b[h+12>>1]=u;k=(((e[c>>1]|0)+(e[q>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<512>>>0){v=k&65535}else{v=-k>>31&511}b[h+14>>1]=v;k=f+1|0;if((k|0)<8){f=k;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function uEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<512>>>0){L=K&65535}else{L=-K>>31&511}b[c>>1]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0<512>>>0){M=K&65535}else{M=-K>>31&511}b[c+(g<<1)>>1]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0<512>>>0){N=K&65535}else{N=-K>>31&511}b[c+(r<<1)>>1]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0<512>>>0){O=K&65535}else{O=-K>>31&511}b[c+(s<<1)>>1]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0<512>>>0){P=K&65535}else{P=-K>>31&511}b[c+(t<<1)>>1]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0<512>>>0){Q=K&65535}else{Q=-K>>31&511}b[c+(u<<1)>>1]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0<512>>>0){R=K&65535}else{R=-K>>31&511}b[c+(v<<1)>>1]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0<512>>>0){S=K&65535}else{S=-K>>31&511}b[c+(w<<1)>>1]=S;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function vEa(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;h=g>>1;g=d+(-(h<<1)<<1)|0;d=0;i=c;while(1){j=g+2|0;k=g-2|0;l=g+4|0;m=g+6|0;b[i>>1]=(((b[g-4>>1]|0)+(((b[j>>1]|0)+(b[g>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);n=g+8|0;b[i+2>>1]=(((b[k>>1]|0)+(((b[l>>1]|0)+(b[j>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[g>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);k=g+10|0;b[i+4>>1]=(((b[g>>1]|0)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*20&65535)&65535)+(((b[n>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[k>>1]|0);o=g+12|0;b[i+6>>1]=(((b[j>>1]|0)+(((b[n>>1]|0)+(b[m>>1]|0)&65535)*20&65535)&65535)+(((b[k>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[o>>1]|0);j=g+14|0;b[i+8>>1]=(((b[l>>1]|0)+(((b[k>>1]|0)+(b[n>>1]|0)&65535)*20&65535)&65535)+(((b[o>>1]|0)+(b[m>>1]|0)&65535)*-5&65535)&65535)+(b[j>>1]|0);l=g+16|0;b[i+10>>1]=(((b[m>>1]|0)+(((b[o>>1]|0)+(b[k>>1]|0)&65535)*20&65535)&65535)+(((b[j>>1]|0)+(b[n>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);m=g+18|0;b[i+12>>1]=(((b[n>>1]|0)+(((b[j>>1]|0)+(b[o>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);b[i+14>>1]=(((b[k>>1]|0)+(((b[l>>1]|0)+(b[j>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[o>>1]|0)&65535)*-5&65535)&65535)+(b[g+20>>1]|0);o=d+1|0;if((o|0)<13){g=g+(h<<1)|0;d=o;i=i+(f<<1)|0}else{break}}i=e>>1;e=f*-2|0;d=-f|0;h=f<<1;g=f*3|0;o=f<<2;m=f*5|0;j=f*6|0;l=f*7|0;k=f<<3;n=f*9|0;p=f*10|0;q=i<<1;r=i*3|0;s=i<<2;t=i*5|0;u=i*6|0;v=i*7|0;w=a;a=0;x=c+(f<<1<<1)|0;while(1){c=b[x+(d<<1)>>1]|0;y=b[x>>1]|0;z=b[x+(f<<1)>>1]|0;A=b[x+(h<<1)>>1]|0;B=b[x+(g<<1)>>1]|0;C=b[x+(o<<1)>>1]|0;D=b[x+(m<<1)>>1]|0;E=b[x+(j<<1)>>1]|0;F=b[x+(l<<1)>>1]|0;G=b[x+(k<<1)>>1]|0;H=b[x+(n<<1)>>1]|0;I=b[x+(p<<1)>>1]|0;J=(b[x+(e<<1)>>1]|0)+512+((z+y|0)*20|0)+B+((A+c|0)*-5|0)>>10;if(J>>>0<512>>>0){K=J&65535}else{K=-J>>31&511}b[w>>1]=K;J=c+512+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>10;if(J>>>0<512>>>0){L=J&65535}else{L=-J>>31&511}b[w+(i<<1)>>1]=L;J=y+512+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>10;if(J>>>0<512>>>0){M=J&65535}else{M=-J>>31&511}b[w+(q<<1)>>1]=M;J=z+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(J>>>0<512>>>0){N=J&65535}else{N=-J>>31&511}b[w+(r<<1)>>1]=N;J=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(J>>>0<512>>>0){O=J&65535}else{O=-J>>31&511}b[w+(s<<1)>>1]=O;J=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(J>>>0<512>>>0){P=J&65535}else{P=-J>>31&511}b[w+(t<<1)>>1]=P;J=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(J>>>0<512>>>0){Q=J&65535}else{Q=-J>>31&511}b[w+(u<<1)>>1]=Q;J=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(J>>>0<512>>>0){R=J&65535}else{R=-J>>31&511}b[w+(v<<1)>>1]=R;J=a+1|0;if((J|0)<8){w=w+2|0;a=J;x=x+2|0}else{break}}return}function wEa(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;i=h>>1;h=d+(-(i<<1)<<1)|0;d=0;j=c;while(1){k=h+2|0;l=h-2|0;m=h+4|0;n=h+6|0;b[j>>1]=(((b[h-4>>1]|0)+(((b[k>>1]|0)+(b[h>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);o=h+8|0;b[j+2>>1]=(((b[l>>1]|0)+(((b[m>>1]|0)+(b[k>>1]|0)&65535)*20&65535)&65535)+(((b[n>>1]|0)+(b[h>>1]|0)&65535)*-5&65535)&65535)+(b[o>>1]|0);l=h+10|0;b[j+4>>1]=(((b[h>>1]|0)+(((b[n>>1]|0)+(b[m>>1]|0)&65535)*20&65535)&65535)+(((b[o>>1]|0)+(b[k>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);p=h+12|0;b[j+6>>1]=(((b[k>>1]|0)+(((b[o>>1]|0)+(b[n>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[m>>1]|0)&65535)*-5&65535)&65535)+(b[p>>1]|0);k=h+14|0;b[j+8>>1]=(((b[m>>1]|0)+(((b[l>>1]|0)+(b[o>>1]|0)&65535)*20&65535)&65535)+(((b[p>>1]|0)+(b[n>>1]|0)&65535)*-5&65535)&65535)+(b[k>>1]|0);m=h+16|0;b[j+10>>1]=(((b[n>>1]|0)+(((b[p>>1]|0)+(b[l>>1]|0)&65535)*20&65535)&65535)+(((b[k>>1]|0)+(b[o>>1]|0)&65535)*-5&65535)&65535)+(b[m>>1]|0);n=h+18|0;b[j+12>>1]=(((b[o>>1]|0)+(((b[k>>1]|0)+(b[p>>1]|0)&65535)*20&65535)&65535)+(((b[m>>1]|0)+(b[l>>1]|0)&65535)*-5&65535)&65535)+(b[n>>1]|0);b[j+14>>1]=(((b[l>>1]|0)+(((b[m>>1]|0)+(b[k>>1]|0)&65535)*20&65535)&65535)+(((b[n>>1]|0)+(b[p>>1]|0)&65535)*-5&65535)&65535)+(b[h+20>>1]|0);p=d+1|0;if((p|0)<13){h=h+(i<<1)|0;d=p;j=j+(g<<1)|0}else{break}}j=f>>1;f=g*-2|0;d=-g|0;i=g<<1;h=g*3|0;p=g<<2;n=g*5|0;k=g*6|0;m=g*7|0;l=g<<3;o=g*9|0;q=g*10|0;r=j<<1;s=j*3|0;t=j<<2;u=j*5|0;v=j*6|0;w=j*7|0;x=a;a=0;y=c+(g<<1<<1)|0;while(1){c=b[y+(d<<1)>>1]|0;z=b[y>>1]|0;A=b[y+(g<<1)>>1]|0;B=b[y+(i<<1)>>1]|0;C=b[y+(h<<1)>>1]|0;D=b[y+(p<<1)>>1]|0;E=b[y+(n<<1)>>1]|0;F=b[y+(k<<1)>>1]|0;G=b[y+(m<<1)>>1]|0;H=b[y+(l<<1)>>1]|0;I=b[y+(o<<1)>>1]|0;J=b[y+(q<<1)>>1]|0;K=(b[y+(f<<1)>>1]|0)+512+((A+z|0)*20|0)+C+((B+c|0)*-5|0)>>10;if(K>>>0<512>>>0){L=K}else{L=-K>>31&511}b[x>>1]=((e[x>>1]|0)+1+L|0)>>>1;K=x+(j<<1)|0;M=c+512+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>10;if(M>>>0<512>>>0){N=M}else{N=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=x+(r<<1)|0;M=z+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(M>>>0<512>>>0){O=M}else{O=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=x+(s<<1)|0;M=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(M>>>0<512>>>0){P=M}else{P=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=x+(t<<1)|0;M=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(M>>>0<512>>>0){Q=M}else{Q=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=x+(u<<1)|0;M=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(M>>>0<512>>>0){R=M}else{R=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=x+(v<<1)|0;M=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(M>>>0<512>>>0){S=M}else{S=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=x+(w<<1)|0;M=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(M>>>0<512>>>0){T=M}else{T=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;a=K;y=y+2|0}else{break}}return}function xEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=d>>1;d=f>>1;f=d*-2|0;h=-d|0;i=d<<1;j=d*3|0;k=d<<2;l=d*5|0;m=d*6|0;n=d*7|0;o=d<<3;p=d*9|0;q=d*10|0;r=g<<1;s=g*3|0;t=g<<2;u=g*5|0;v=g*6|0;w=g*7|0;x=c;c=a;a=0;while(1){y=e[x+(h<<1)>>1]|0;z=e[x>>1]|0;A=e[x+(d<<1)>>1]|0;B=e[x+(i<<1)>>1]|0;C=e[x+(j<<1)>>1]|0;D=e[x+(k<<1)>>1]|0;E=e[x+(l<<1)>>1]|0;F=e[x+(m<<1)>>1]|0;G=e[x+(n<<1)>>1]|0;H=e[x+(o<<1)>>1]|0;I=e[x+(p<<1)>>1]|0;J=e[x+(q<<1)>>1]|0;K=(e[x+(f<<1)>>1]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0<512>>>0){L=K}else{L=-K>>31&511}b[c>>1]=((e[c>>1]|0)+1+L|0)>>>1;K=c+(g<<1)|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0<512>>>0){N=M}else{N=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+N|0)>>>1;K=c+(r<<1)|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0<512>>>0){O=M}else{O=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+O|0)>>>1;K=c+(s<<1)|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0<512>>>0){P=M}else{P=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+P|0)>>>1;K=c+(t<<1)|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0<512>>>0){Q=M}else{Q=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+Q|0)>>>1;K=c+(u<<1)|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0<512>>>0){R=M}else{R=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+R|0)>>>1;K=c+(v<<1)|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0<512>>>0){S=M}else{S=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+S|0)>>>1;K=c+(w<<1)|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0<512>>>0){T=M}else{T=-M>>31&511}b[K>>1]=((e[K>>1]|0)+1+T|0)>>>1;K=a+1|0;if((K|0)<8){x=x+2|0;c=c+2|0;a=K}else{break}}return}function yEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=d>>1;d=f>>1;f=0;h=a;a=c;while(1){c=a+2|0;i=a-2|0;j=a+4|0;k=a+6|0;l=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[k>>1]|0)>>5;if(l>>>0<512>>>0){m=l}else{m=-l>>31&511}b[h>>1]=((e[h>>1]|0)+1+m|0)>>>1;l=h+2|0;n=a+8|0;o=(((e[j>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[i>>1]|0)+(((e[k>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(o>>>0<512>>>0){p=o}else{p=-o>>31&511}b[l>>1]=((e[l>>1]|0)+1+p|0)>>>1;l=h+4|0;o=a+10|0;i=(((e[k>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[n>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[o>>1]|0)>>5;if(i>>>0<512>>>0){q=i}else{q=-i>>31&511}b[l>>1]=((e[l>>1]|0)+1+q|0)>>>1;l=h+6|0;i=a+12|0;r=(((e[n>>1]|0)+(e[k>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[o>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[i>>1]|0)>>5;if(r>>>0<512>>>0){s=r}else{s=-r>>31&511}b[l>>1]=((e[l>>1]|0)+1+s|0)>>>1;l=h+8|0;r=a+14|0;c=(((e[o>>1]|0)+(e[n>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[i>>1]|0)+(e[k>>1]|0)|0)*-5|0)+(e[r>>1]|0)>>5;if(c>>>0<512>>>0){t=c}else{t=-c>>31&511}b[l>>1]=((e[l>>1]|0)+1+t|0)>>>1;l=h+10|0;c=a+16|0;j=(((e[i>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[k>>1]|0)+(((e[r>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[c>>1]|0)>>5;if(j>>>0<512>>>0){u=j}else{u=-j>>31&511}b[l>>1]=((e[l>>1]|0)+1+u|0)>>>1;l=h+12|0;j=a+18|0;k=(((e[r>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[c>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<512>>>0){v=k}else{v=-k>>31&511}b[l>>1]=((e[l>>1]|0)+1+v|0)>>>1;l=h+14|0;k=(((e[c>>1]|0)+(e[r>>1]|0)|0)*20|0)+16+(e[o>>1]|0)+(((e[j>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+20>>1]|0)>>5;if(k>>>0<512>>>0){w=k}else{w=-k>>31&511}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;l=f+1|0;if((l|0)<8){f=l;h=h+(g<<1)|0;a=a+(d<<1)|0}else{break}}return}function zEa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a;h=c;i=d>>1;d=f>>1;f=c+2|0;j=c-2|0;k=c+4|0;l=c+6|0;m=(((e[f>>1]|0)+(e[h>>1]|0)|0)*20|0)+16+(e[c-4>>1]|0)+(((e[k>>1]|0)+(e[j>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[g>>1]=n;n=(((e[k>>1]|0)+(e[f>>1]|0)|0)*20|0)+16+(e[j>>1]|0)+(((e[l>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[c+8>>1]|0)>>5;if(n>>>0<512>>>0){o=n&65535}else{o=-n>>31&511}b[a+2>>1]=o;o=h+(d<<1)|0;a=h+(d+1<<1)|0;n=h+(d-1<<1)|0;c=h+(d+2<<1)|0;l=h+(d+3<<1)|0;j=(((e[a>>1]|0)+(e[o>>1]|0)|0)*20|0)+16+(e[h+(d-2<<1)>>1]|0)+(((e[c>>1]|0)+(e[n>>1]|0)|0)*-5|0)+(e[l>>1]|0)>>5;if(j>>>0<512>>>0){p=j&65535}else{p=-j>>31&511}b[g+(i<<1)>>1]=p;p=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[n>>1]|0)+(((e[l>>1]|0)+(e[o>>1]|0)|0)*-5|0)+(e[h+(d+4<<1)>>1]|0)>>5;if(p>>>0<512>>>0){q=p&65535;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}q=-p>>31&511;r=i+1|0;s=g+(r<<1)|0;b[s>>1]=q;return}function AEa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=a;g=d>>1;d=e[c-4>>1]|0;h=e[c>>1]|0;i=e[c+4>>1]|0;j=e[c+8>>1]|0;k=e[c+12>>1]|0;l=e[c+16>>1]|0;m=(e[c-8>>1]|0)+16+((i+h|0)*20|0)+k+((j+d|0)*-5|0)>>5;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[f>>1]=n;n=d+16+((j+i|0)*20|0)+l+((k+h|0)*-5|0)>>5;if(n>>>0<512>>>0){o=n&65535}else{o=-n>>31&511}b[f+(g<<1)>>1]=o;o=a+2|0;a=e[c-2>>1]|0;f=e[c+2>>1]|0;n=e[c+6>>1]|0;h=e[c+10>>1]|0;k=e[c+14>>1]|0;l=e[c+18>>1]|0;i=(e[c-6>>1]|0)+16+((n+f|0)*20|0)+k+((h+a|0)*-5|0)>>5;if(i>>>0<512>>>0){p=i&65535}else{p=-i>>31&511}b[o>>1]=p;p=a+16+((h+n|0)*20|0)+l+((k+f|0)*-5|0)>>5;if(p>>>0<512>>>0){q=p&65535;r=o+(g<<1)|0;b[r>>1]=q;return}q=-p>>31&511;r=o+(g<<1)|0;b[r>>1]=q;return}function BEa(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=d+(-(g<<1)<<1)|0;d=0;h=c;while(1){i=f+2|0;j=f-2|0;k=f+4|0;l=f+6|0;b[h>>1]=(((b[f-4>>1]|0)+(((b[i>>1]|0)+(b[f>>1]|0)&65535)*20&65535)&65535)+(((b[k>>1]|0)+(b[j>>1]|0)&65535)*-5&65535)&65535)+(b[l>>1]|0);b[h+2>>1]=(((b[j>>1]|0)+(((b[k>>1]|0)+(b[i>>1]|0)&65535)*20&65535)&65535)+(((b[l>>1]|0)+(b[f>>1]|0)&65535)*-5&65535)&65535)+(b[f+8>>1]|0);l=d+1|0;if((l|0)<7){f=f+(g<<1)|0;d=l;h=h+8|0}else{break}}h=a;d=e>>1;e=b[c+8>>1]|0;g=b[c+16>>1]|0;f=b[c+24>>1]|0;l=b[c+32>>1]|0;i=b[c+40>>1]|0;k=b[c+48>>1]|0;j=(b[c>>1]|0)+512+((f+g|0)*20|0)+i+((l+e|0)*-5|0)>>10;if(j>>>0<512>>>0){m=j&65535}else{m=-j>>31&511}b[h>>1]=m;m=e+512+((l+f|0)*20|0)+k+((i+g|0)*-5|0)>>10;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[h+(d<<1)>>1]=n;n=a+2|0;a=b[c+10>>1]|0;h=b[c+18>>1]|0;m=b[c+26>>1]|0;g=b[c+34>>1]|0;i=b[c+42>>1]|0;k=b[c+50>>1]|0;f=(b[c+2>>1]|0)+512+((m+h|0)*20|0)+i+((g+a|0)*-5|0)>>10;if(f>>>0<512>>>0){o=f&65535}else{o=-f>>31&511}b[n>>1]=o;o=a+512+((g+m|0)*20|0)+k+((i+h|0)*-5|0)>>10;if(o>>>0<512>>>0){p=o&65535;q=n+(d<<1)|0;b[q>>1]=p;return}p=-o>>31&511;q=n+(d<<1)|0;b[q>>1]=p;return}function CEa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=0;h=b;b=c;while(1){c=b+1|0;i=b-1|0;j=b+2|0;k=b+3|0;l=(((d[c]|0)+(d[b]|0)|0)*20|0)+16+(d[b-2|0]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[k]|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[h]=m;l=b+4|0;n=(((d[j]|0)+(d[c]|0)|0)*20|0)+16+(d[i]|0)+(((d[k]|0)+(d[b]|0)|0)*-5|0)+(d[l]|0)>>5;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[h+1|0]=o;n=b+5|0;i=(((d[k]|0)+(d[j]|0)|0)*20|0)+16+(d[b]|0)+(((d[l]|0)+(d[c]|0)|0)*-5|0)+(d[n]|0)>>5;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[h+2|0]=p;i=(((d[l]|0)+(d[k]|0)|0)*20|0)+16+(d[c]|0)+(((d[n]|0)+(d[j]|0)|0)*-5|0)+(d[b+6|0]|0)>>5;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[h+3|0]=q;i=g+1|0;if((i|0)<4){g=i;h=h+e|0;b=b+f|0}else{break}}return}function DEa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=e<<1;g=e*3|0;h=c;c=b;b=0;while(1){i=d[h-4|0]|0;j=d[h]|0;k=d[h+4|0]|0;l=d[h+8|0]|0;m=d[h+12|0]|0;n=d[h+16|0]|0;o=d[h+20|0]|0;p=d[h+24|0]|0;q=(d[h-8|0]|0)+16+((k+j|0)*20|0)+m+((l+i|0)*-5|0)>>5;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[c]=r;q=i+16+((l+k|0)*20|0)+n+((m+j|0)*-5|0)>>5;if(q>>>0>255>>>0){s=-q>>31&255}else{s=q&255}a[c+e|0]=s;q=j+16+((m+l|0)*20|0)+o+((n+k|0)*-5|0)>>5;if(q>>>0>255>>>0){t=-q>>31&255}else{t=q&255}a[c+f|0]=t;q=k+16+((n+m|0)*20|0)+p+((o+l|0)*-5|0)>>5;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[c+g|0]=u;q=b+1|0;if((q|0)<4){h=h+1|0;c=c+1|0;b=q}else{break}}return}function EEa(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=f+(-(h<<1)|0)|0;f=0;j=e;while(1){k=i+1|0;l=i-1|0;m=i+2|0;n=i+3|0;b[j>>1]=(((d[i-2|0]|0)+(((d[k]|0)+(d[i]|0)&65535)*20&65535)&65535)+(((d[m]|0)+(d[l]|0)&65535)*-5&65535)&65535)+(d[n]|0);o=i+4|0;b[j+2>>1]=(((d[l]|0)+(((d[m]|0)+(d[k]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[i]|0)&65535)*-5&65535)&65535)+(d[o]|0);l=i+5|0;b[j+4>>1]=(((d[i]|0)+(((d[n]|0)+(d[m]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[k]|0)&65535)*-5&65535)&65535)+(d[l]|0);b[j+6>>1]=(((d[k]|0)+(((d[o]|0)+(d[n]|0)&65535)*20&65535)&65535)+(((d[l]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[i+6|0]|0);m=f+1|0;if((m|0)<9){i=i+h|0;f=m;j=j+8|0}else{break}}j=g<<1;f=g*3|0;h=c;c=0;i=e+16|0;while(1){e=b[i-8>>1]|0;m=b[i>>1]|0;l=b[i+8>>1]|0;n=b[i+16>>1]|0;o=b[i+24>>1]|0;k=b[i+32>>1]|0;p=b[i+40>>1]|0;q=b[i+48>>1]|0;r=(b[i-16>>1]|0)+512+((l+m|0)*20|0)+o+((n+e|0)*-5|0)>>10;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[h]=s;r=e+512+((n+l|0)*20|0)+k+((o+m|0)*-5|0)>>10;if(r>>>0>255>>>0){t=-r>>31&255}else{t=r&255}a[h+g|0]=t;r=m+512+((o+n|0)*20|0)+p+((k+l|0)*-5|0)>>10;if(r>>>0>255>>>0){u=-r>>31&255}else{u=r&255}a[h+j|0]=u;r=l+512+((k+o|0)*20|0)+q+((p+n|0)*-5|0)>>10;if(r>>>0>255>>>0){v=-r>>31&255}else{v=r&255}a[h+f|0]=v;r=c+1|0;if((r|0)<4){h=h+1|0;c=r;i=i+2|0}else{break}}return}function FEa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=0;h=b;b=c;while(1){c=b+1|0;i=b-1|0;j=b+2|0;k=b+3|0;l=(((d[c]|0)+(d[b]|0)|0)*20|0)+16+(d[b-2|0]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[k]|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[h]=m;l=b+4|0;n=(((d[j]|0)+(d[c]|0)|0)*20|0)+16+(d[i]|0)+(((d[k]|0)+(d[b]|0)|0)*-5|0)+(d[l]|0)>>5;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[h+1|0]=o;n=b+5|0;i=(((d[k]|0)+(d[j]|0)|0)*20|0)+16+(d[b]|0)+(((d[l]|0)+(d[c]|0)|0)*-5|0)+(d[n]|0)>>5;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[h+2|0]=p;i=b+6|0;q=(((d[l]|0)+(d[k]|0)|0)*20|0)+16+(d[c]|0)+(((d[n]|0)+(d[j]|0)|0)*-5|0)+(d[i]|0)>>5;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[h+3|0]=r;q=b+7|0;c=(((d[n]|0)+(d[l]|0)|0)*20|0)+16+(d[j]|0)+(((d[i]|0)+(d[k]|0)|0)*-5|0)+(d[q]|0)>>5;if(c>>>0>255>>>0){s=-c>>31&255}else{s=c&255}a[h+4|0]=s;c=b+8|0;j=(((d[i]|0)+(d[n]|0)|0)*20|0)+16+(d[k]|0)+(((d[q]|0)+(d[l]|0)|0)*-5|0)+(d[c]|0)>>5;if(j>>>0>255>>>0){t=-j>>31&255}else{t=j&255}a[h+5|0]=t;j=b+9|0;k=(((d[q]|0)+(d[i]|0)|0)*20|0)+16+(d[l]|0)+(((d[c]|0)+(d[n]|0)|0)*-5|0)+(d[j]|0)>>5;if(k>>>0>255>>>0){u=-k>>31&255}else{u=k&255}a[h+6|0]=u;k=(((d[c]|0)+(d[q]|0)|0)*20|0)+16+(d[n]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[b+10|0]|0)>>5;if(k>>>0>255>>>0){v=-k>>31&255}else{v=k&255}a[h+7|0]=v;k=g+1|0;if((k|0)<8){g=k;h=h+e|0;b=b+f|0}else{break}}return}function GEa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=f*-2|0;h=-f|0;i=f<<1;j=f*3|0;k=f<<2;l=f*5|0;m=f*6|0;n=f*7|0;o=f<<3;p=f*9|0;q=f*10|0;r=e<<1;s=e*3|0;t=e<<2;u=e*5|0;v=e*6|0;w=e*7|0;x=c;c=b;b=0;while(1){y=d[x+h|0]|0;z=d[x]|0;A=d[x+f|0]|0;B=d[x+i|0]|0;C=d[x+j|0]|0;D=d[x+k|0]|0;E=d[x+l|0]|0;F=d[x+m|0]|0;G=d[x+n|0]|0;H=d[x+o|0]|0;I=d[x+p|0]|0;J=d[x+q|0]|0;K=(d[x+g|0]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0>255>>>0){L=-K>>31&255}else{L=K&255}a[c]=L;K=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(K>>>0>255>>>0){M=-K>>31&255}else{M=K&255}a[c+e|0]=M;K=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(K>>>0>255>>>0){N=-K>>31&255}else{N=K&255}a[c+r|0]=N;K=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(K>>>0>255>>>0){O=-K>>31&255}else{O=K&255}a[c+s|0]=O;K=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(K>>>0>255>>>0){P=-K>>31&255}else{P=K&255}a[c+t|0]=P;K=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(K>>>0>255>>>0){Q=-K>>31&255}else{Q=K&255}a[c+u|0]=Q;K=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(K>>>0>255>>>0){R=-K>>31&255}else{R=K&255}a[c+v|0]=R;K=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(K>>>0>255>>>0){S=-K>>31&255}else{S=K&255}a[c+w|0]=S;K=b+1|0;if((K|0)<8){x=x+1|0;c=c+1|0;b=K}else{break}}return}function HEa(c,e,f,g,h,i){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=f+(-(i<<1)|0)|0;f=0;k=e;while(1){l=j+1|0;m=j-1|0;n=j+2|0;o=j+3|0;b[k>>1]=(((d[j-2|0]|0)+(((d[l]|0)+(d[j]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[o]|0);p=j+4|0;b[k+2>>1]=(((d[m]|0)+(((d[n]|0)+(d[l]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[j]|0)&65535)*-5&65535)&65535)+(d[p]|0);m=j+5|0;b[k+4>>1]=(((d[j]|0)+(((d[o]|0)+(d[n]|0)&65535)*20&65535)&65535)+(((d[p]|0)+(d[l]|0)&65535)*-5&65535)&65535)+(d[m]|0);q=j+6|0;b[k+6>>1]=(((d[l]|0)+(((d[p]|0)+(d[o]|0)&65535)*20&65535)&65535)+(((d[m]|0)+(d[n]|0)&65535)*-5&65535)&65535)+(d[q]|0);l=j+7|0;b[k+8>>1]=(((d[n]|0)+(((d[m]|0)+(d[p]|0)&65535)*20&65535)&65535)+(((d[q]|0)+(d[o]|0)&65535)*-5&65535)&65535)+(d[l]|0);n=j+8|0;b[k+10>>1]=(((d[o]|0)+(((d[q]|0)+(d[m]|0)&65535)*20&65535)&65535)+(((d[l]|0)+(d[p]|0)&65535)*-5&65535)&65535)+(d[n]|0);o=j+9|0;b[k+12>>1]=(((d[p]|0)+(((d[l]|0)+(d[q]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[o]|0);b[k+14>>1]=(((d[m]|0)+(((d[n]|0)+(d[l]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[q]|0)&65535)*-5&65535)&65535)+(d[j+10|0]|0);q=f+1|0;if((q|0)<13){j=j+i|0;f=q;k=k+(h<<1)|0}else{break}}k=h*-2|0;f=-h|0;i=h<<1;j=h*3|0;q=h<<2;o=h*5|0;l=h*6|0;n=h*7|0;m=h<<3;p=h*9|0;r=h*10|0;s=g<<1;t=g*3|0;u=g<<2;v=g*5|0;w=g*6|0;x=g*7|0;y=c;c=0;z=e+(h<<1<<1)|0;while(1){e=b[z+(f<<1)>>1]|0;A=b[z>>1]|0;B=b[z+(h<<1)>>1]|0;C=b[z+(i<<1)>>1]|0;D=b[z+(j<<1)>>1]|0;E=b[z+(q<<1)>>1]|0;F=b[z+(o<<1)>>1]|0;G=b[z+(l<<1)>>1]|0;H=b[z+(n<<1)>>1]|0;I=b[z+(m<<1)>>1]|0;J=b[z+(p<<1)>>1]|0;K=b[z+(r<<1)>>1]|0;L=(b[z+(k<<1)>>1]|0)+512+((B+A|0)*20|0)+D+((C+e|0)*-5|0)>>10;if(L>>>0>255>>>0){M=-L>>31&255}else{M=L&255}a[y]=M;L=e+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(L>>>0>255>>>0){N=-L>>31&255}else{N=L&255}a[y+g|0]=N;L=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(L>>>0>255>>>0){O=-L>>31&255}else{O=L&255}a[y+s|0]=O;L=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(L>>>0>255>>>0){P=-L>>31&255}else{P=L&255}a[y+t|0]=P;L=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(L>>>0>255>>>0){Q=-L>>31&255}else{Q=L&255}a[y+u|0]=Q;L=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(L>>>0>255>>>0){R=-L>>31&255}else{R=L&255}a[y+v|0]=R;L=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(L>>>0>255>>>0){S=-L>>31&255}else{S=L&255}a[y+w|0]=S;L=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(L>>>0>255>>>0){T=-L>>31&255}else{T=L&255}a[y+x|0]=T;L=c+1|0;if((L|0)<8){y=y+1|0;c=L;z=z+2|0}else{break}}return}function IEa(c,e,f,g,h,i){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=f+(-(i<<1)|0)|0;f=0;k=e;while(1){l=j+1|0;m=j-1|0;n=j+2|0;o=j+3|0;b[k>>1]=(((d[j-2|0]|0)+(((d[l]|0)+(d[j]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[o]|0);p=j+4|0;b[k+2>>1]=(((d[m]|0)+(((d[n]|0)+(d[l]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[j]|0)&65535)*-5&65535)&65535)+(d[p]|0);m=j+5|0;b[k+4>>1]=(((d[j]|0)+(((d[o]|0)+(d[n]|0)&65535)*20&65535)&65535)+(((d[p]|0)+(d[l]|0)&65535)*-5&65535)&65535)+(d[m]|0);q=j+6|0;b[k+6>>1]=(((d[l]|0)+(((d[p]|0)+(d[o]|0)&65535)*20&65535)&65535)+(((d[m]|0)+(d[n]|0)&65535)*-5&65535)&65535)+(d[q]|0);l=j+7|0;b[k+8>>1]=(((d[n]|0)+(((d[m]|0)+(d[p]|0)&65535)*20&65535)&65535)+(((d[q]|0)+(d[o]|0)&65535)*-5&65535)&65535)+(d[l]|0);n=j+8|0;b[k+10>>1]=(((d[o]|0)+(((d[q]|0)+(d[m]|0)&65535)*20&65535)&65535)+(((d[l]|0)+(d[p]|0)&65535)*-5&65535)&65535)+(d[n]|0);o=j+9|0;b[k+12>>1]=(((d[p]|0)+(((d[l]|0)+(d[q]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[m]|0)&65535)*-5&65535)&65535)+(d[o]|0);b[k+14>>1]=(((d[m]|0)+(((d[n]|0)+(d[l]|0)&65535)*20&65535)&65535)+(((d[o]|0)+(d[q]|0)&65535)*-5&65535)&65535)+(d[j+10|0]|0);q=f+1|0;if((q|0)<13){j=j+i|0;f=q;k=k+(h<<1)|0}else{break}}k=h*-2|0;f=-h|0;i=h<<1;j=h*3|0;q=h<<2;o=h*5|0;l=h*6|0;n=h*7|0;m=h<<3;p=h*9|0;r=h*10|0;s=g<<1;t=g*3|0;u=g<<2;v=g*5|0;w=g*6|0;x=g*7|0;y=c;c=0;z=e+(h<<1<<1)|0;while(1){e=b[z+(f<<1)>>1]|0;A=b[z>>1]|0;B=b[z+(h<<1)>>1]|0;C=b[z+(i<<1)>>1]|0;D=b[z+(j<<1)>>1]|0;E=b[z+(q<<1)>>1]|0;F=b[z+(o<<1)>>1]|0;G=b[z+(l<<1)>>1]|0;H=b[z+(n<<1)>>1]|0;I=b[z+(m<<1)>>1]|0;J=b[z+(p<<1)>>1]|0;K=b[z+(r<<1)>>1]|0;L=(b[z+(k<<1)>>1]|0)+512+((B+A|0)*20|0)+D+((C+e|0)*-5|0)>>10;if(L>>>0>255>>>0){M=-L>>31&255}else{M=L&255}a[y]=((d[y]|0)+1+(M&255)|0)>>>1;L=y+g|0;N=e+512+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>10;if(N>>>0>255>>>0){O=-N>>31&255}else{O=N&255}a[L]=((d[L]|0)+1+(O&255)|0)>>>1;L=y+s|0;N=A+512+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>10;if(N>>>0>255>>>0){P=-N>>31&255}else{P=N&255}a[L]=((d[L]|0)+1+(P&255)|0)>>>1;L=y+t|0;N=B+512+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>10;if(N>>>0>255>>>0){Q=-N>>31&255}else{Q=N&255}a[L]=((d[L]|0)+1+(Q&255)|0)>>>1;L=y+u|0;N=C+512+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>10;if(N>>>0>255>>>0){R=-N>>31&255}else{R=N&255}a[L]=((d[L]|0)+1+(R&255)|0)>>>1;L=y+v|0;N=D+512+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>10;if(N>>>0>255>>>0){S=-N>>31&255}else{S=N&255}a[L]=((d[L]|0)+1+(S&255)|0)>>>1;L=y+w|0;N=E+512+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>10;if(N>>>0>255>>>0){T=-N>>31&255}else{T=N&255}a[L]=((d[L]|0)+1+(T&255)|0)>>>1;L=y+x|0;N=F+512+((I+H|0)*20|0)+K+((J+G|0)*-5|0)>>10;if(N>>>0>255>>>0){U=-N>>31&255}else{U=N&255}a[L]=((d[L]|0)+1+(U&255)|0)>>>1;L=c+1|0;if((L|0)<8){y=y+1|0;c=L;z=z+2|0}else{break}}return}function JEa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=f*-2|0;h=-f|0;i=f<<1;j=f*3|0;k=f<<2;l=f*5|0;m=f*6|0;n=f*7|0;o=f<<3;p=f*9|0;q=f*10|0;r=e<<1;s=e*3|0;t=e<<2;u=e*5|0;v=e*6|0;w=e*7|0;x=c;c=b;b=0;while(1){y=d[x+h|0]|0;z=d[x]|0;A=d[x+f|0]|0;B=d[x+i|0]|0;C=d[x+j|0]|0;D=d[x+k|0]|0;E=d[x+l|0]|0;F=d[x+m|0]|0;G=d[x+n|0]|0;H=d[x+o|0]|0;I=d[x+p|0]|0;J=d[x+q|0]|0;K=(d[x+g|0]|0)+16+((A+z|0)*20|0)+C+((B+y|0)*-5|0)>>5;if(K>>>0>255>>>0){L=-K>>31&255}else{L=K&255}a[c]=((d[c]|0)+1+(L&255)|0)>>>1;K=c+e|0;M=y+16+((B+A|0)*20|0)+D+((C+z|0)*-5|0)>>5;if(M>>>0>255>>>0){N=-M>>31&255}else{N=M&255}a[K]=((d[K]|0)+1+(N&255)|0)>>>1;K=c+r|0;M=z+16+((C+B|0)*20|0)+E+((D+A|0)*-5|0)>>5;if(M>>>0>255>>>0){O=-M>>31&255}else{O=M&255}a[K]=((d[K]|0)+1+(O&255)|0)>>>1;K=c+s|0;M=A+16+((D+C|0)*20|0)+F+((E+B|0)*-5|0)>>5;if(M>>>0>255>>>0){P=-M>>31&255}else{P=M&255}a[K]=((d[K]|0)+1+(P&255)|0)>>>1;K=c+t|0;M=B+16+((E+D|0)*20|0)+G+((F+C|0)*-5|0)>>5;if(M>>>0>255>>>0){Q=-M>>31&255}else{Q=M&255}a[K]=((d[K]|0)+1+(Q&255)|0)>>>1;K=c+u|0;M=C+16+((F+E|0)*20|0)+H+((G+D|0)*-5|0)>>5;if(M>>>0>255>>>0){R=-M>>31&255}else{R=M&255}a[K]=((d[K]|0)+1+(R&255)|0)>>>1;K=c+v|0;M=D+16+((G+F|0)*20|0)+I+((H+E|0)*-5|0)>>5;if(M>>>0>255>>>0){S=-M>>31&255}else{S=M&255}a[K]=((d[K]|0)+1+(S&255)|0)>>>1;K=c+w|0;M=E+16+((H+G|0)*20|0)+J+((I+F|0)*-5|0)>>5;if(M>>>0>255>>>0){T=-M>>31&255}else{T=M&255}a[K]=((d[K]|0)+1+(T&255)|0)>>>1;K=b+1|0;if((K|0)<8){x=x+1|0;c=c+1|0;b=K}else{break}}return}function KEa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=0;h=b;b=c;while(1){c=b+1|0;i=b-1|0;j=b+2|0;k=b+3|0;l=(((d[c]|0)+(d[b]|0)|0)*20|0)+16+(d[b-2|0]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[k]|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[h]=((d[h]|0)+1+(m&255)|0)>>>1;l=h+1|0;n=b+4|0;o=(((d[j]|0)+(d[c]|0)|0)*20|0)+16+(d[i]|0)+(((d[k]|0)+(d[b]|0)|0)*-5|0)+(d[n]|0)>>5;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[l]=((d[l]|0)+1+(p&255)|0)>>>1;l=h+2|0;o=b+5|0;i=(((d[k]|0)+(d[j]|0)|0)*20|0)+16+(d[b]|0)+(((d[n]|0)+(d[c]|0)|0)*-5|0)+(d[o]|0)>>5;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[l]=((d[l]|0)+1+(q&255)|0)>>>1;l=h+3|0;i=b+6|0;r=(((d[n]|0)+(d[k]|0)|0)*20|0)+16+(d[c]|0)+(((d[o]|0)+(d[j]|0)|0)*-5|0)+(d[i]|0)>>5;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;l=h+4|0;r=b+7|0;c=(((d[o]|0)+(d[n]|0)|0)*20|0)+16+(d[j]|0)+(((d[i]|0)+(d[k]|0)|0)*-5|0)+(d[r]|0)>>5;if(c>>>0>255>>>0){t=-c>>31&255}else{t=c&255}a[l]=((d[l]|0)+1+(t&255)|0)>>>1;l=h+5|0;c=b+8|0;j=(((d[i]|0)+(d[o]|0)|0)*20|0)+16+(d[k]|0)+(((d[r]|0)+(d[n]|0)|0)*-5|0)+(d[c]|0)>>5;if(j>>>0>255>>>0){u=-j>>31&255}else{u=j&255}a[l]=((d[l]|0)+1+(u&255)|0)>>>1;l=h+6|0;j=b+9|0;k=(((d[r]|0)+(d[i]|0)|0)*20|0)+16+(d[n]|0)+(((d[c]|0)+(d[o]|0)|0)*-5|0)+(d[j]|0)>>5;if(k>>>0>255>>>0){v=-k>>31&255}else{v=k&255}a[l]=((d[l]|0)+1+(v&255)|0)>>>1;l=h+7|0;k=(((d[c]|0)+(d[r]|0)|0)*20|0)+16+(d[o]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+(d[b+10|0]|0)>>5;if(k>>>0>255>>>0){w=-k>>31&255}else{w=k&255}a[l]=((d[l]|0)+1+(w&255)|0)>>>1;l=g+1|0;if((l|0)<8){g=l;h=h+e|0;b=b+f|0}else{break}}return}function LEa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=c+1|0;h=c-1|0;i=c+2|0;j=c+3|0;k=(((d[g]|0)+(d[c]|0)|0)*20|0)+16+(d[c-2|0]|0)+(((d[i]|0)+(d[h]|0)|0)*-5|0)+(d[j]|0)>>5;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[b]=l;l=(((d[i]|0)+(d[g]|0)|0)*20|0)+16+(d[h]|0)+(((d[j]|0)+(d[c]|0)|0)*-5|0)+(d[c+4|0]|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[b+1|0]=m;m=c+f|0;l=c+(f+1)|0;j=c+(f-1)|0;h=c+(f+2)|0;g=c+(f+3)|0;i=(((d[l]|0)+(d[m]|0)|0)*20|0)+16+(d[c+(f-2)|0]|0)+(((d[h]|0)+(d[j]|0)|0)*-5|0)+(d[g]|0)>>5;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b+e|0]=n;n=(((d[h]|0)+(d[l]|0)|0)*20|0)+16+(d[j]|0)+(((d[g]|0)+(d[m]|0)|0)*-5|0)+(d[c+(f+4)|0]|0)>>5;if(!(n>>>0>255>>>0)){o=n&255;p=e+1|0;q=b+p|0;a[q]=o;return}o=-n>>31&255;p=e+1|0;q=b+p|0;a[q]=o;return}function MEa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d[c-2|0]|0;g=d[c]|0;h=d[c+2|0]|0;i=d[c+4|0]|0;j=d[c+6|0]|0;k=d[c+8|0]|0;l=(d[c-4|0]|0)+16+((h+g|0)*20|0)+j+((i+f|0)*-5|0)>>5;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[b]=m;m=f+16+((i+h|0)*20|0)+k+((j+g|0)*-5|0)>>5;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[b+e|0]=n;n=d[c-1|0]|0;m=d[c+1|0]|0;g=d[c+3|0]|0;j=d[c+5|0]|0;k=d[c+7|0]|0;h=d[c+9|0]|0;i=(d[c-3|0]|0)+16+((g+m|0)*20|0)+k+((j+n|0)*-5|0)>>5;if(i>>>0>255>>>0){o=-i>>31&255}else{o=i&255}a[b+1|0]=o;o=n+16+((j+g|0)*20|0)+h+((k+m|0)*-5|0)>>5;if(!(o>>>0>255>>>0)){p=o&255;q=e+1|0;r=b+q|0;a[r]=p;return}p=-o>>31&255;q=e+1|0;r=b+q|0;a[r]=p;return}function NEa(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=f+(-(h<<1)|0)|0;f=0;j=e;while(1){k=i+1|0;l=i-1|0;m=i+2|0;n=i+3|0;b[j>>1]=(((d[i-2|0]|0)+(((d[k]|0)+(d[i]|0)&65535)*20&65535)&65535)+(((d[m]|0)+(d[l]|0)&65535)*-5&65535)&65535)+(d[n]|0);b[j+2>>1]=(((d[l]|0)+(((d[m]|0)+(d[k]|0)&65535)*20&65535)&65535)+(((d[n]|0)+(d[i]|0)&65535)*-5&65535)&65535)+(d[i+4|0]|0);n=f+1|0;if((n|0)<7){i=i+h|0;f=n;j=j+4|0}else{break}}j=b[e+4>>1]|0;f=b[e+8>>1]|0;h=b[e+12>>1]|0;i=b[e+16>>1]|0;n=b[e+20>>1]|0;k=b[e+24>>1]|0;m=(b[e>>1]|0)+512+((h+f|0)*20|0)+n+((i+j|0)*-5|0)>>10;if(m>>>0>255>>>0){o=-m>>31&255}else{o=m&255}a[c]=o;o=j+512+((i+h|0)*20|0)+k+((n+f|0)*-5|0)>>10;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c+g|0]=p;p=b[e+6>>1]|0;o=b[e+10>>1]|0;f=b[e+14>>1]|0;n=b[e+18>>1]|0;k=b[e+22>>1]|0;h=b[e+26>>1]|0;i=(b[e+2>>1]|0)+512+((f+o|0)*20|0)+k+((n+p|0)*-5|0)>>10;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[c+1|0]=q;q=p+512+((n+f|0)*20|0)+h+((k+o|0)*-5|0)>>10;if(!(q>>>0>255>>>0)){r=q&255;s=g+1|0;t=c+s|0;a[t]=r;return}r=-q>>31&255;s=g+1|0;t=c+s|0;a[t]=r;return}function OEa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=b+7380|0;c[g>>2]=0;a:do{if((e|0)>1){h=0;b:while(1){do{if((a[d+h|0]|0)==0){if((h|0)>0){i=h-1|0;j=(a[d+i|0]|0)==0?i:h}else{j=h}i=j+2|0;if((i|0)>=(e|0)){k=j;break}if((a[d+(j+1)|0]|0)!=0){k=j;break}l=a[d+i|0]|0;if((l&255)>>>0<4>>>0){break b}else{k=j}}else{k=h}}while(0);i=k+2|0;if((k+3|0)<(e|0)){h=i}else{m=i;n=e;break a}}m=j;n=l<<24>>24==3?e:j}else{m=0;n=e}}while(0);if((m|0)>=(n-1|0)){c[f+12>>2]=d;c[f+8>>2]=n;o=n;return o|0}xJb(f,f+4|0,n+16|0);e=c[f>>2]|0;if((e|0)==0){o=-12;return o|0}nrc(e|0,d|0,m)|0;j=m+2|0;c:do{if((j|0)<(n|0)){l=b+7388|0;k=b+7384|0;h=k;i=m;p=m;q=j;d:while(1){r=d+q|0;s=a[r]|0;do{if((s&255)>>>0>3>>>0){a[e+p|0]=a[d+i|0]|0;a[e+(p+1)|0]=a[d+(i+1)|0]|0;t=p+2|0;u=q;v=a[r]|0;w=26}else{x=a[d+i|0]|0;if(!(x<<24>>24==0)){t=p;u=i;v=x;w=26;break}if((a[d+(i+1)|0]|0)!=0){t=p;u=i;v=0;w=26;break}if(!(s<<24>>24==3)){y=p;z=i;break c}x=p+1|0;a[e+p|0]=0;A=p+2|0;a[e+x|0]=0;B=i+3|0;C=(c[g>>2]|0)+1|0;c[g>>2]=C;D=c[l>>2]|0;if((D|0)<(C|0)){C=D<<1;c[l>>2]=C;oJb(h,C,4)|0;C=c[k>>2]|0;if((C|0)==0){o=-12;break d}else{E=C}}else{C=c[k>>2]|0;if((C|0)==0){F=A;G=B;break}else{E=C}}c[E+((c[g>>2]|0)-1<<2)>>2]=x;F=A;G=B}}while(0);if((w|0)==26){w=0;a[e+t|0]=v;F=t+1|0;G=u+1|0}s=G+2|0;if((s|0)<(n|0)){i=G;p=F;q=s}else{H=G;I=F;w=15;break c}}return o|0}else{H=m;I=m;w=15}}while(0);do{if((w|0)==15){if((H|0)>=(n|0)){y=I;z=H;break}m=n+I|0;F=H;G=I;while(1){u=F+1|0;a[e+G|0]=a[d+F|0]|0;if((u|0)<(n|0)){F=u;G=G+1|0}else{break}}y=m-H|0;z=n}}while(0);mrc(e+y|0,0,16)|0;c[f+12>>2]=e;c[f+8>>2]=y;o=z;return o|0}function PEa(a){a=a|0;var b=0;mrc(c[a+60>>2]|0,0,7516)|0;b=hFa(a)|0;return((b|0)<0?b:0)|0}function QEa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c[d+60>>2]|0;g=f;h=c[e+60>>2]|0;do{if((a[f+7477|0]|0)==0){e=hFa(d)|0;if((e|0)<0){i=e}else{break}return i|0}}while(0);d=f+3484|0;e=h+3484|0;j=0;while(1){k=d+(j*72|0)|0;lGa(g,k,-1);if((c[(c[e+(j*72|0)>>2]|0)+360>>2]|0)!=0){l=G5a(d+(j*72|0)+4|0,e+(j*72|0)+4|0)|0;if((l|0)<0){i=l;m=28;break}l=eGb(c[e+(j*72|0)+56>>2]|0)|0;c[d+(j*72|0)+56>>2]=l;if((l|0)==0){m=10;break}c[d+(j*72|0)+16>>2]=c[e+(j*72|0)+16>>2];l=eGb(c[e+(j*72|0)+60>>2]|0)|0;c[d+(j*72|0)+60>>2]=l;if((l|0)==0){m=10;break}c[d+(j*72|0)+24>>2]=c[e+(j*72|0)+24>>2];l=eGb(c[e+(j*72|0)+64>>2]|0)|0;c[d+(j*72|0)+64>>2]=l;if((l|0)==0){m=10;break}c[d+(j*72|0)+32>>2]=c[e+(j*72|0)+32>>2];c[d+(j*72|0)+28>>2]=c[e+(j*72|0)+28>>2];l=d+(j*72|0)+40|0;n=e+(j*72|0)+40|0;c[l>>2]=c[n>>2];c[l+4>>2]=c[n+4>>2];c[l+8>>2]=c[n+8>>2];c[l+12>>2]=c[n+12>>2];a[d+(j*72|0)+70|0]=a[e+(j*72|0)+70|0]|0;b[d+(j*72|0)+68>>1]=b[e+(j*72|0)+68>>1]|0}n=j+1|0;if(n>>>0<32>>>0){j=n}else{m=4;break}}if((m|0)==4){j=f+188|0;e=h+188|0;d=0;do{n=j+(d<<2)|0;fGb(n);l=c[e+(d<<2)>>2]|0;if((l|0)!=0){o=eGb(l)|0;c[n>>2]=o;if((o|0)==0){i=-12;m=28;break}}d=d+1|0;}while(d>>>0<16>>>0);if((m|0)==28){return i|0}d=f+252|0;e=h+252|0;j=0;do{o=d+(j<<2)|0;fGb(o);n=c[e+(j<<2)>>2]|0;if((n|0)!=0){l=eGb(n)|0;c[o>>2]=l;if((l|0)==0){i=-12;m=28;break}}j=j+1|0;}while(j>>>0<32>>>0);if((m|0)==28){return i|0}j=f+380|0;e=h+380|0;d=0;do{l=j+(d<<2)|0;fGb(l);o=c[e+(d<<2)>>2]|0;if((o|0)!=0){n=eGb(o)|0;c[l>>2]=n;if((n|0)==0){i=-12;m=28;break}}d=d+1|0;}while(d>>>0<256>>>0);if((m|0)==28){return i|0}d=c[h+180>>2]|0;if((c[f+180>>2]|0)!=(d|0)){gFa(g,d)|0}d=b[h+7368>>1]|0;e=f+7368|0;b[e>>1]=d;b[f+7370>>1]=b[h+7370>>1]|0;c[f+5792>>2]=c[h+5792>>2];j=f+5804|0;c[j>>2]=c[h+5804>>2];a[f+7478|0]=a[h+7478|0]|0;c[f+7488>>2]=c[h+7488>>2];a[f+141|0]=a[h+141|0]|0;a[f+140|0]=a[h+140|0]|0;if((c[h+5800>>2]|0)==0){i=0;return i|0}b[e>>1]=d+1&255;c[j>>2]=2147483647;i=0;return i|0}else if((m|0)==10){lGa(g,k,-1);i=-12;return i|0}else if((m|0)==28){return i|0}return 0}function REa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=i;f=c[b+60>>2]|0;g=f;Imb();c[(c[b+64>>2]|0)+4>>2]=1;h=hFa(b)|0;if((h|0)<0){j=h;i=e;return j|0}c[f+7372>>2]=0;c[f+7512>>2]=0;h=b+816|0;if((c[h>>2]&2|0)==0){a[f+141|0]=1}else{a[f+141|0]=c[b+808>>2]}a:do{if((c[b+100>>2]|0)>0){if((c[b+96>>2]|0)==0){break}k=f+4|0;l=c[k>>2]|0;m=l+96|0;n=c[m>>2]|0;o=l+100|0;p=c[o>>2]|0;if(!((p|0)>-1)){KIb(0,0,2303384,(q=i,i=i+24|0,c[q>>2]=2292400,c[q+8>>2]=2285384,c[q+16>>2]=135,q)|0);i=q;Hd();return 0}r=n+p|0;b:do{if((p|0)>3){do{if((a[n]|0)==0){if((a[n+1|0]|0)!=0){break}if(!((d[n+2|0]|0)>>>0>1>>>0)){s=32;break b}}}while(0);a[f+7478|0]=1;t=r;u=p>>>0>21>>>0?21:p;v=n+u|0;if((p-u|0)<1){w=1;x=v}else{w=(a[v]&3)+1|0;x=n+(u+1)|0}c:do{if((t-x|0)<1){u=f+7488|0;c[u>>2]=2;y=u}else{u=a[x]|0;v=u&255;z=f+7488|0;c[z>>2]=2;if(u<<24>>24==0){y=z;break}u=x+1|0;A=0;d:while(1){if((t-u|0)<1){B=0;C=u}else{B=a[u]&63;C=u+1|0}do{if((t-C|0)<2){D=C}else{E=C+2|0;F=C;G=(d[F]|d[F+1|0]<<8)<<16>>16;F=(he(G|0)|0)&65535;if(G<<16>>16==0){D=E;break}else{H=E;I=0}while(1){E=t-H|0;if((E|0)<2){J=2}else{G=H;J=((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)+2|0}if(E>>>0<J>>>0){s=26;break d}K=WEa(g,H,J)|0;if((K|0)<0){s=28;break d}G=H+(E>>>0>J>>>0?J:E)|0;E=I+1|0;if((E|0)<(F|0)){H=G;I=E}else{D=G;break}}}}while(0);F=A+1|0;if((F|0)<(v|0)){u=D;A=F}else{y=z;break c}}if((s|0)==26){KIb(c[k>>2]|0,16,2313088,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;L=-1094995529;break b}else if((s|0)==28){KIb(l,16,2308432,(q=i,i=i+16|0,c[q>>2]=B,c[q+8>>2]=A,q)|0);i=q;L=K;break b}}}while(0);c[y>>2]=w;break a}else{s=32}}while(0);if((s|0)==32){a[f+7478|0]=0;l=WEa(g,c[m>>2]|0,c[o>>2]|0)|0;if((l|0)<0){L=l}else{break}}TEa(b)|0;j=L;i=e;return j|0}}while(0);do{if((c[h>>2]&1|0)!=0){if((c[b+808>>2]|0)<=1){break}a[f+140|0]=1;j=0;i=e;return j|0}}while(0);a[f+140|0]=2;j=0;i=e;return j|0}function SEa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;j=i;i=i+16|0;k=j|0;l=c[e+60>>2]|0;m=l;n=h+28|0;o=c[n>>2]|0;if((o|0)==0){p=rGa(m,f,1)|0;if((p|0)<0){q=p;i=j;return q|0}c[g>>2]=p;q=0;i=j;return q|0}p=l+3480|0;c[p>>2]=0;r=WEa(m,c[h+24>>2]|0,o)|0;if((r|0)<0){q=r;i=j;return q|0}r=e+696|0;o=l+5816|0;a:do{if((c[r>>2]&1|0)!=0){if((c[o>>2]|0)==0){break}if((a[l+7476|0]|0)==0){break}h=c[c[p>>2]>>2]|0;s=k|0;t=qKb(c[h+80>>2]|0)|0;b:do{if((t|0)==0){u=-22}else{v=(b[t+8>>1]&16384)>>>0>14336>>>0|0;w=l+4|0;KIb(c[w>>2]|0,48,2363024,(x=i,i=i+8|0,c[x>>2]=c[l+5788>>2],x)|0);i=x;y=h|0;z=c[w>>2]|0;c:do{if((c[y>>2]|0)==0){A=z}else{B=t+5|0;C=t+6|0;D=l+7424|0;E=0;F=y;G=z;while(1){H=c[G+128>>2]|0;I=c[G+132>>2]|0;if((E-1|0)>>>0<2>>>0){J=I>>d[C];K=H>>d[B]}else{J=I;K=H}bJb(c[D>>2]|0);if((J|0)>0){H=h+32+(E<<2)|0;I=K<<v;L=0;do{M=(c[F>>2]|0)+(ca(c[H>>2]|0,L)|0)|0;cJb(c[D>>2]|0,M,I);L=L+1|0;}while((L|0)<(J|0))}eJb(c[D>>2]|0,s);L=(grc(s,m+7428+(E<<4)|0,16)|0)==0;N=c[w>>2]|0;if(!L){break}KIb(N,48,2298104,(x=i,i=i+8|0,c[x>>2]=E,x)|0);i=x;L=c[w>>2]|0;I=0;do{KIb(L,48,2122048,(x=i,i=i+8|0,c[x>>2]=d[k+I|0]|0,x)|0);i=x;I=I+1|0;}while((I|0)<16);KIb(c[w>>2]|0,48,2247464,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;I=E+1|0;L=h+(I<<2)|0;H=c[w>>2]|0;if((c[L>>2]|0)==0){A=H;break c}else{E=I;F=L;G=H}}KIb(N,16,2205472,(x=i,i=i+8|0,c[x>>2]=E,x)|0);i=x;G=c[w>>2]|0;F=0;do{KIb(G,16,2122048,(x=i,i=i+8|0,c[x>>2]=d[k+F|0]|0,x)|0);i=x;F=F+1|0;}while((F|0)<16);KIb(c[w>>2]|0,16,2173312,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;F=c[w>>2]|0;G=0;do{KIb(F,16,2122048,(x=i,i=i+8|0,c[x>>2]=d[m+7428+(E<<4)+G|0]|0,x)|0);i=x;G=G+1|0;}while((G|0)<16);KIb(c[w>>2]|0,16,2145864,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;u=-1094995529;break b}}while(0);KIb(A,48,2145864,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;break a}}while(0);if((c[r>>2]&8|0)==0){break}lGa(m,c[p>>2]|0,-1);q=u;i=j;return q|0}}while(0);a[l+7476|0]=0;if((c[o>>2]|0)!=0){KIb(e,48,2452416,(x=i,i=i+8|0,c[x>>2]=c[l+5788>>2],x)|0);i=x;c[o>>2]=0}o=c[l+172>>2]|0;if((c[o+360>>2]|0)!=0){aIb(f,o);c[g>>2]=1}q=c[n>>2]|0;i=j;return q|0}function TEa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[b+60>>2]|0;b=d;e=d+136|0;VEa(b);mJb(d+7424|0);f=d+7416|0;g=d+7396|0;if((c[f>>2]|0)>0){h=g;i=0;do{mJb((c[h>>2]|0)+(i<<2)|0);i=i+1|0;}while((i|0)<(c[f>>2]|0))}mJb(d+7400|0);mJb(d+7392|0);mJb(g);mJb(d+152|0);VHb(d+168|0);VHb(d+172|0);g=d+3484|0;i=0;do{h=g+(i*72|0)|0;lGa(b,h,-1);VHb(h|0);i=i+1|0;}while(i>>>0<32>>>0);fGb(d+188|0);fGb(d+192|0);fGb(d+196|0);fGb(d+200|0);fGb(d+204|0);fGb(d+208|0);fGb(d+212|0);fGb(d+216|0);fGb(d+220|0);fGb(d+224|0);fGb(d+228|0);fGb(d+232|0);fGb(d+236|0);fGb(d+240|0);fGb(d+244|0);fGb(d+248|0);i=d+252|0;b=0;do{fGb(i+(b<<2)|0);b=b+1|0;}while(b>>>0<32>>>0);b=d+380|0;i=0;do{fGb(b+(i<<2)|0);i=i+1|0;}while(i>>>0<256>>>0);mJb(d+3056|0);mJb(d+3060|0);mJb(d+3064|0);i=d+141|0;b=a[i]|0;g=d+72|0;if((b&255)>>>0>1>>>0){h=g;j=d+8|0;k=1;l=b;while(1){b=h+(k<<2)|0;if((c[b>>2]|0)==0){m=l}else{mJb(b);mJb(j+(k<<2)|0);m=a[i]|0}b=k+1|0;if((b|0)<(m&255|0)){k=b;l=m}else{break}}}if((c[e>>2]|0)==(c[g>>2]|0)){c[e>>2]=0}mJb(g);g=d+7408|0;if((c[f>>2]|0)<=0){mJb(g);c[f>>2]=0;return 0}d=g;e=0;do{mJb((c[d>>2]|0)+(e<<4)|0);e=e+1|0;}while((e|0)<(c[f>>2]|0));mJb(g);c[f>>2]=0;return 0}function UEa(a){a=a|0;var b=0;b=c[a+60>>2]|0;oGa(b);c[b+5804>>2]=2147483647;return}function VEa(a){a=a|0;mJb(a+3464|0);mJb(a+3468|0);mJb(a+7320|0);mJb(a+7336|0);mJb(a+7340|0);mJb(a+7344|0);mJb(a+7348|0);mJb(a+7352|0);mJb(a+7316|0);mJb(a+7332|0);mJb(a+7356|0);mJb(a+7324|0);mJb(a+7328|0);mJb(a+3056|0);mJb(a+3064|0);mJb(a+3060|0);lGb(a+1404|0);lGb(a+1408|0);return}function WEa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;g=i;h=b+3480|0;c[h>>2]=0;j=b+5800|0;c[j>>2]=0;k=b+7412|0;c[k>>2]=0;a:do{if((f|0)>3){l=b+7478|0;m=b+7416|0;n=b+7408|0;o=b+7392|0;p=o;q=b+7400|0;r=q;s=b+7396|0;t=s;u=b+7388|0;v=b+7384|0;w=b+7380|0;x=b+136|0;y=b+3472|0;z=b+3476|0;A=b+4|0;B=b+7488|0;C=f;D=e;b:while(1){E=(a[l]|0)==0;if(E){F=D;G=C;c:while(1){H=F+1|0;do{if((a[F]|0)==0){if((a[H]|0)!=0){break}if((a[F+2|0]|0)==1){break c}}}while(0);I=G-1|0;if((I|0)<4){J=15;break b}else{F=H;G=I}}K=F+3|0;L=G-3|0;M=0}else{I=c[B>>2]|0;if((I|0)>0){N=0;O=0;while(1){P=d[D+O|0]|N<<8;Q=O+1|0;if((Q|0)<(I|0)){N=P;O=Q}else{R=P;break}}}else{R=0}O=C-I|0;if((R|0)>(O|0)){J=10;break}K=D+I|0;L=O;M=R}O=E?L:M;N=c[m>>2]|0;G=c[k>>2]|0;if((N|0)<(G+1|0)){F=N+1|0;N=nJb(c[n>>2]|0,F,16)|0;P=N;if((N|0)==0){S=-12;break a}c[n>>2]=P;N=c[m>>2]|0;mrc(P+(N<<4)|0,0,F-N<<4|0)|0;oJb(p,F,4)|0;oJb(r,F,4)|0;oJb(t,F,4)|0;N=c[q>>2]|0;c[N+(c[m>>2]<<2)>>2]=1024;P=c[m>>2]|0;Q=c[N+(P<<2)>>2]|0;if(Q>>>0>536870910>>>0){T=0;U=P}else{P=hJb(Q<<2)|0;T=P;U=c[m>>2]|0}c[(c[s>>2]|0)+(U<<2)>>2]=T;c[m>>2]=F;V=c[k>>2]|0}else{V=G}c[u>>2]=c[(c[q>>2]|0)+(V<<2)>>2];c[v>>2]=c[(c[s>>2]|0)+(V<<2)>>2];G=c[n>>2]|0;F=OEa(b,K,O,G+(V<<4)|0)|0;c[(c[o>>2]|0)+(c[k>>2]<<2)>>2]=c[w>>2];c[(c[q>>2]|0)+(c[k>>2]<<2)>>2]=c[u>>2];O=c[v>>2]|0;P=c[k>>2]|0;c[k>>2]=P+1;c[(c[s>>2]|0)+(P<<2)>>2]=O;if((F|0)<0){S=F;break a}O=c[x>>2]|0;P=c[G+(V<<4)+12>>2]|0;Q=c[G+(V<<4)+8>>2]|0;G=Q>>>0>268435455>>>0?-8:Q<<3;Q=G>>>0>2147483639>>>0|(P|0)==0;N=Q?0:P;P=Q?0:G;G=Q?-1094995529:0;c[O+9272>>2]=N;c[O+9284>>2]=P;c[O+9288>>2]=P+8;c[O+9276>>2]=N+(P>>3);c[O+9280>>2]=0;if(Q){S=G;break a}Q=c[x>>2]|0;O=Q+9280|0;P=c[O>>2]|0;N=c[Q+9272>>2]|0;W=d[N+(P>>>3)|0]|0;X=c[Q+9288>>2]|0;Q=((P|0)<(X|0))+P|0;c[O>>2]=Q;do{if((W&128>>>((P&7)>>>0)|0)==0){Y=N+(Q>>>3)|0;Z=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(Q&7)>>>26;Y=Q+6|0;_=X>>>0>Y>>>0?Y:X;c[O>>2]=_;c[y>>2]=Z;Y=N+(_>>>3)|0;$=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;Y=_+6|0;aa=X>>>0>Y>>>0?Y:X;c[O>>2]=aa;Y=N+(aa>>>3)|0;ba=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(aa&7)>>>29;Y=aa+3|0;c[O>>2]=X>>>0>Y>>>0?Y:X;Y=ba-1|0;c[z>>2]=Y;if((Y|0)<0){break}ba=(je($|0)|0)<<(_&7)>>>26;KIb(c[A>>2]|0,48,2317792,(ca=i,i=i+24|0,c[ca>>2]=Z,c[ca+8>>2]=ba,c[ca+16>>2]=Y,ca)|0);i=ca}}while(0);if(((c[y>>2]|0)-36|0)>>>0<2>>>0){c[j>>2]=1}X=L-F|0;if((X|0)>3){C=X;D=K+F|0}else{da=G;ea=o;fa=w;ga=s;ha=v;ia=n;J=4;break a}}if((J|0)==10){KIb(c[A>>2]|0,16,2639760,(ca=i,i=i+1|0,i=i+7&-8,c[ca>>2]=0,ca)|0);i=ca;S=-1094995529;break}else if((J|0)==15){KIb(c[A>>2]|0,16,2617008,(ca=i,i=i+1|0,i=i+7&-8,c[ca>>2]=0,ca)|0);i=ca;S=-1094995529;break}}else{da=0;ea=b+7392|0;fa=b+7380|0;ga=b+7396|0;ha=b+7384|0;ia=b+7408|0;J=4}}while(0);d:do{if((J|0)==4){K=0;while(1){if((K|0)>=(c[k>>2]|0)){S=da;break d}c[fa>>2]=c[(c[ea>>2]|0)+(K<<2)>>2];c[ha>>2]=c[(c[ga>>2]|0)+(K<<2)>>2];L=c[ia>>2]|0;if((XEa(b,c[L+(K<<4)+12>>2]|0,c[L+(K<<4)+8>>2]|0)|0)<0){break}K=K+1|0}KIb(c[b+4>>2]|0,24,2589824,(ca=i,i=i+8|0,c[ca>>2]=K,ca)|0);i=ca;S=da}}while(0);da=c[h>>2]|0;if((da|0)==0){i=g;return S|0}if((a[b+140|0]|0)!=1){i=g;return S|0}L5a(da+4|0,2147483647,0);i=g;return S|0}function XEa(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0;j=i;i=i+80|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=j+64|0;p=j+72|0;q=f+136|0;r=c[q>>2]|0;s=h>>>0>268435455>>>0?-8:h<<3;t=s>>>0>2147483639>>>0|(g|0)==0;u=t?0:g;v=t?0:s;c[r+9272>>2]=u;c[r+9284>>2]=v;c[r+9288>>2]=v+8;c[r+9276>>2]=u+(v>>3);c[r+9280>>2]=0;if(t){w=t?-1094995529:0;i=j;return w|0}t=c[q>>2]|0;r=t+9280|0;v=c[r>>2]|0;u=c[t+9272>>2]|0;s=d[u+(v>>>3)|0]|0;x=c[t+9288>>2]|0;t=((v|0)<(x|0))+v|0;c[r>>2]=t;a:do{if((s&128>>>((v&7)>>>0)|0)==0){y=u+(t>>>3)|0;z=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(t&7)>>>26;y=t+6|0;A=x>>>0>y>>>0?y:x;c[r>>2]=A;y=f+3472|0;c[y>>2]=z;B=u+(A>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>26;B=A+6|0;A=x>>>0>B>>>0?B:x;c[r>>2]=A;B=u+(A>>>3)|0;D=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>29;B=A+3|0;c[r>>2]=x>>>0>B>>>0?B:x;B=D-1|0;D=f+3476|0;c[D>>2]=B;if((B|0)<0){E=z;F=6;break}A=f+4|0;KIb(c[A>>2]|0,48,2317792,(G=i,i=i+24|0,c[G>>2]=z,c[G+8>>2]=C,c[G+16>>2]=B,G)|0);i=G;if((C|0)!=0){w=0;i=j;return w|0}C=c[y>>2]|0;switch(C|0){case 33:{B=fGa(f)|0;if((B|0)<0){H=B;break a}else{w=0}i=j;return w|0};case 35:case 38:{w=0;i=j;return w|0};case 32:{B=cGa(f)|0;if((B|0)<0){H=B;break a}else{w=0}i=j;return w|0};case 36:case 37:{B=f+7368|0;b[B>>1]=(b[B>>1]|0)+1&255;c[f+5804>>2]=2147483647;w=0;i=j;return w|0};case 39:case 40:{B=xGa(f)|0;if((B|0)<0){H=B;break a}else{w=0}i=j;return w|0};case 1:case 0:case 2:case 3:case 4:case 5:case 16:case 17:case 18:case 19:case 20:case 21:case 6:case 7:case 8:case 9:{B=c[q>>2]|0;z=B+9272|0;I=B+9280|0;J=c[I>>2]|0;K=z|0;L=d[(c[K>>2]|0)+(J>>>3)|0]<<(J&7)>>>7;M=B+9288|0;c[I>>2]=((J|0)<(c[M>>2]|0))+J;J=L&1;L=f+2412|0;a[L]=J;do{if((C-16|0)>>>0>4>>>0|J<<24>>24==0){N=C}else{B=f+7368|0;b[B>>1]=(b[B>>1]|0)+1&255;c[f+5804>>2]=2147483647;if(!((C-19|0)>>>0<2>>>0)){N=C;break}nGa(f);N=c[y>>2]|0}}while(0);if((N-16|0)>>>0<8>>>0){J=c[I>>2]|0;B=d[(c[K>>2]|0)+(J>>>3)|0]<<(J&7)>>>7;c[I>>2]=((J|0)<(c[M>>2]|0))+J;a[f+3010|0]=B&1}B=fFa(z)|0;c[f+2392>>2]=B;do{if(!(B>>>0>255>>>0)){J=c[f+380+(B<<2)>>2]|0;if((J|0)==0){break}do{if((a[L]|0)==0){O=f+184|0;P=c[J+4>>2]|0;if((c[O>>2]|0)==(P|0)){Q=P;R=O;break}KIb(c[A>>2]|0,16,2430728,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}else{Q=c[J+4>>2]|0;R=f+184|0}}while(0);c[R>>2]=Q;J=f+180|0;O=c[J>>2]|0;P=c[(c[f+252+(c[Q>>2]<<2)>>2]|0)+4>>2]|0;do{if((O|0)==(P|0)){S=O}else{c[J>>2]=P;nGa(f);T=gFa(f,c[J>>2]|0)|0;if((T|0)<0){w=T;i=j;return w|0}else{T=f+7368|0;b[T>>1]=(b[T>>1]|0)+1&255;c[f+5804>>2]=2147483647;S=c[J>>2]|0;break}}}while(0);P=c[A>>2]|0;c[P+840>>2]=d[S+302|0]|0;c[P+844>>2]=d[S+335|0]|0;O=f+2413|0;a[O]=0;do{if((a[L]|0)==0){if((a[(c[R>>2]|0)+41|0]|0)!=0){T=c[I>>2]|0;U=d[(c[K>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[I>>2]=((T|0)<(c[M>>2]|0))+T;a[O]=U&1}U=S+13104|0;T=S+13108|0;V=(ca(c[U>>2]<<1,c[T>>2]|0)|0)-2|0;W=V>>>0>65535>>>0;X=W?V>>>16:V;V=W?16:0;if((X&65280|0)==0){Y=V;Z=X}else{Y=V|8;Z=X>>>8}X=(d[1359664+Z|0]|0)+Y|0;V=c[I>>2]|0;W=c[M>>2]|0;_=(c[K>>2]|0)+(V>>>3)|0;$=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(V&7)>>>((32-X|0)>>>0);_=X+V|0;c[I>>2]=W>>>0>_>>>0?_:W;c[f+2396>>2]=$;if(!($>>>0<(ca(c[T>>2]|0,c[U>>2]|0)|0)>>>0)){KIb(P,16,2420528,(G=i,i=i+8|0,c[G>>2]=$,G)|0);i=G;w=-1094995529;i=j;return w|0}if((a[O]|0)==0){c[f+2400>>2]=$;$=f+5796|0;c[$>>2]=(c[$>>2]|0)+1;aa=f+156|0;F=37;break}$=f+156|0;if((a[$]|0)!=0){ba=$;da=c[R>>2]|0;break}KIb(P,16,2339680,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}else{c[f+2400>>2]=0;c[f+2396>>2]=0;c[f+5796>>2]=0;$=f+156|0;a[$]=0;aa=$;F=37}}while(0);b:do{if((F|0)==37){a[aa]=0;P=(c[R>>2]|0)+1624|0;if((c[P>>2]|0)>0){$=c[M>>2]|0;U=0;T=c[I>>2]|0;do{W=T+1|0;T=$>>>0>W>>>0?W:$;c[I>>2]=T;U=U+1|0;}while((U|0)<(c[P>>2]|0))}P=fFa(z)|0;U=f+2404|0;c[U>>2]=P;if(!(P>>>0<3>>>0)){KIb(c[A>>2]|0,16,2411232,(G=i,i=i+8|0,c[G>>2]=P,G)|0);i=G;w=-1094995529;i=j;return w|0}T=c[y>>2]|0;if(!((T-16|0)>>>0>7>>>0|(P|0)==2)){KIb(c[A>>2]|0,16,2403520,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}if((a[(c[R>>2]|0)+39|0]|0)!=0){P=c[I>>2]|0;$=d[(c[K>>2]|0)+(P>>>3)|0]<<(P&7)>>>7;c[I>>2]=((P|0)<(c[M>>2]|0))+P;a[f+2414|0]=$&1}$=c[J>>2]|0;if((a[$+8|0]|0)!=0){P=c[I>>2]|0;W=c[M>>2]|0;_=(c[K>>2]|0)+(P>>>3)|0;V=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(P&7)>>>30;_=P+2|0;c[I>>2]=W>>>0>_>>>0?_:W;a[f+2415|0]=V}do{if((T-19|0)>>>0<2>>>0){c[f+2584>>2]=0;c[f+5788>>2]=0;ea=$}else{V=c[$+64>>2]|0;W=c[I>>2]|0;_=c[M>>2]|0;P=(c[K>>2]|0)+(W>>>3)|0;X=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(W&7)>>>((32-V|0)>>>0);P=W+V|0;c[I>>2]=_>>>0>P>>>0?P:_;_=f+2408|0;c[_>>2]=X;P=vGa(f,X)|0;X=f+5788|0;do{if((a[L]|0)==0){V=c[X>>2]|0;if((P|0)==(V|0)){fa=P;break}KIb(c[A>>2]|0,24,2396576,(G=i,i=i+16|0,c[G>>2]=V,c[G+8>>2]=P,G)|0);i=G;if((c[(c[A>>2]|0)+696>>2]&8|0)==0){fa=c[X>>2]|0;break}else{w=-1094995529;i=j;return w|0}}else{fa=P}}while(0);c[X>>2]=fa;P=c[I>>2]|0;V=c[K>>2]|0;W=d[V+(P>>>3)|0]|0;ga=c[M>>2]|0;ha=((P|0)<(ga|0))+P|0;c[I>>2]=ha;do{if((W&128>>>((P&7)>>>0)|0)==0){ia=f+2416|0;ja=aGa(f,ia,c[J>>2]|0,1)|0;if((ja|0)<0){w=ja;i=j;return w|0}else{c[f+2584>>2]=ia;ka=c[J>>2]|0;break}}else{ia=c[J>>2]|0;ja=c[ia+2184>>2]|0;if((ja|0)==0){KIb(c[A>>2]|0,16,2389648,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}la=(ja<<1)-2|0;ja=la>>>0>65535>>>0;ma=ja?la>>>16:la;la=ja?16:0;if((ma&65280|0)==0){na=la;oa=ma}else{na=la|8;oa=ma>>>8}ma=(d[1359664+oa|0]|0)+na|0;if((ma|0)>0){la=V+(ha>>>3)|0;ja=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ha&7)>>>((32-ma|0)>>>0);la=ma+ha|0;c[I>>2]=ga>>>0>la>>>0?la:ga;pa=ja}else{pa=0}c[f+2584>>2]=ia+2188+(pa*168|0);ka=ia}}while(0);ga=ka+64|0;ha=c[ga>>2]|0;V=f+2748|0;a[V]=0;do{if((a[ka+12942|0]|0)!=0){P=ka+13040|0;if((a[P]|0)==0){qa=0}else{qa=fFa(z)|0}W=(fFa(z)|0)+qa|0;if(W>>>0>32>>>0){KIb(c[A>>2]|0,24,2382712,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;if((c[(c[A>>2]|0)+696>>2]&8|0)==0){break}else{w=-1094995529}i=j;return w|0}a[V]=W;if((W&255|0)==0){break}else{ra=0;sa=0}while(1){if(sa>>>0<qa>>>0){W=a[P]|0;if((W&255)>>>0>1>>>0){ia=((W&255)<<1)-2|0;W=ia>>>0>65535>>>0;ja=W?ia>>>16:ia;ia=W?16:0;if((ja&65280|0)==0){ta=ia;ua=ja}else{ta=ia|8;ua=ja>>>8}ja=(d[1359664+ua|0]|0)+ta|0;ia=c[I>>2]|0;W=c[M>>2]|0;la=(c[K>>2]|0)+(ia>>>3)|0;ma=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ia&7)>>>((32-ja|0)>>>0);la=ja+ia|0;c[I>>2]=W>>>0>la>>>0?la:W;va=ma&255}else{va=0}c[f+2588+(sa<<2)>>2]=e[ka+12944+(va<<1)>>1]|0;a[f+2716+sa|0]=a[ka+13008+va|0]|0}else{ma=c[ga>>2]|0;W=c[I>>2]|0;la=c[M>>2]|0;ia=c[K>>2]|0;ja=ia+(W>>>3)|0;wa=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(W&7)>>>((32-ma|0)>>>0);ja=W+ma|0;c[I>>2]=la>>>0>ja>>>0?ja:la;c[f+2588+(sa<<2)>>2]=wa;wa=c[I>>2]|0;la=d[ia+(wa>>>3)|0]<<(wa&7)>>>7;c[I>>2]=((wa|0)<(c[M>>2]|0))+wa;a[f+2716+sa|0]=la&1}la=c[I>>2]|0;wa=d[(c[K>>2]|0)+(la>>>3)|0]|0;c[I>>2]=((la|0)<(c[M>>2]|0))+la;if((wa&128>>>((la&7)>>>0)|0)==0){xa=ra}else{la=fFa(z)|0;wa=la+((sa|0)==0|(sa|0)==(qa|0)?0:ra)|0;la=f+2588+(sa<<2)|0;c[la>>2]=(c[X>>2]|0)-(wa<<ha)-(c[_>>2]|0)+(c[la>>2]|0);xa=wa}wa=sa+1|0;if((wa|0)<(d[V]|0)){ra=xa;sa=wa}else{break}}}}while(0);V=c[J>>2]|0;if((a[V+13060|0]|0)==0){a[f+3011|0]=0;ea=V;break}else{_=c[I>>2]|0;ha=d[(c[K>>2]|0)+(_>>>3)|0]<<(_&7)>>>7;c[I>>2]=((_|0)<(c[M>>2]|0))+_;a[f+3011|0]=ha&1;ea=V;break}}}while(0);c:do{if((c[D>>2]|0)==0){switch(c[y>>2]|0){case 0:case 2:case 4:case 6:case 7:case 8:case 9:{break c;break};default:{}}c[f+5792>>2]=c[f+5788>>2]}}while(0);if((a[ea+12941|0]|0)==0){a[f+3020|0]=0;a[f+3021|0]=0;a[f+3022|0]=0}else{$=c[I>>2]|0;T=d[(c[K>>2]|0)+($>>>3)|0]<<($&7)>>>7;c[I>>2]=(($|0)<(c[M>>2]|0))+$;a[f+3020|0]=T&1;T=c[I>>2]|0;$=d[(c[K>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[I>>2]=((T|0)<(c[M>>2]|0))+T;T=$&1;a[f+3022|0]=T;a[f+3021|0]=T}T=f+3016|0;c[T>>2]=0;$=f+3012|0;c[$>>2]=0;V=c[U>>2]|0;do{if(V>>>0<2>>>0){ha=c[R>>2]|0;c[$>>2]=c[ha+8>>2];if((V|0)==0){c[T>>2]=c[ha+12>>2]}ha=c[I>>2]|0;_=d[(c[K>>2]|0)+(ha>>>3)|0]|0;c[I>>2]=((ha|0)<(c[M>>2]|0))+ha;do{if((_&128>>>((ha&7)>>>0)|0)==0){F=95}else{X=(fFa(z)|0)+1|0;c[$>>2]=X;if((c[U>>2]|0)!=0){ya=X;break}c[T>>2]=(fFa(z)|0)+1;F=95}}while(0);if((F|0)==95){ya=c[$>>2]|0}ha=c[T>>2]|0;if(ya>>>0>16>>>0|ha>>>0>16>>>0){KIb(c[A>>2]|0,16,2376064,(G=i,i=i+16|0,c[G>>2]=ya,c[G+8>>2]=ha,G)|0);i=G;w=-1094995529;i=j;return w|0}ha=f+3008|0;a[ha]=0;_=f+3009|0;a[_]=0;X=wGa(f)|0;if((X|0)==0){KIb(c[A>>2]|0,16,2369376,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}do{if((a[(c[R>>2]|0)+1617|0]|0)!=0&(X|0)>1){ga=c[I>>2]|0;P=d[(c[K>>2]|0)+(ga>>>3)|0]<<(ga&7)>>>7;c[I>>2]=((ga|0)<(c[M>>2]|0))+ga;ga=P&1;a[ha]=ga;do{if(!(ga<<24>>24==0)){if((c[$>>2]|0)==0){break}P=(X<<1)-2|0;wa=P>>>0>65535>>>0;la=wa?P>>>16:P;P=wa?16:0;if((la&65280|0)==0){wa=(d[1359664+la|0]|0)+P|0;ia=32-wa|0;ja=c[K>>2]|0;ma=0;do{W=c[I>>2]|0;za=c[M>>2]|0;Aa=ja+(W>>>3)|0;Ba=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(W&7)>>>(ia>>>0);Aa=wa+W|0;c[I>>2]=za>>>0>Aa>>>0?Aa:za;c[f+2752+(ma<<2)>>2]=Ba;ma=ma+1|0;}while(ma>>>0<(c[$>>2]|0)>>>0)}else{ma=(d[1359664+(la>>>8)|0]|0)+(P|8)|0;wa=32-ma|0;ia=c[K>>2]|0;ja=0;do{Ba=c[I>>2]|0;za=c[M>>2]|0;Aa=ia+(Ba>>>3)|0;W=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Ba&7)>>>(wa>>>0);Aa=ma+Ba|0;c[I>>2]=za>>>0>Aa>>>0?Aa:za;c[f+2752+(ja<<2)>>2]=W;ja=ja+1|0;}while(ja>>>0<(c[$>>2]|0)>>>0)}}}while(0);ga=c[U>>2]|0;if((ga|0)!=0){Ca=ga;break}ga=c[I>>2]|0;ja=d[(c[K>>2]|0)+(ga>>>3)|0]<<(ga&7)>>>7;c[I>>2]=((ga|0)<(c[M>>2]|0))+ga;ga=ja&1;a[_]=ga;if((ga|0)==0){F=116;break}if((c[T>>2]|0)==0){F=116;break}ga=(X<<1)-2|0;ja=ga>>>0>65535>>>0;ma=ja?ga>>>16:ga;ga=ja?16:0;if((ma&65280|0)==0){ja=(d[1359664+ma|0]|0)+ga|0;wa=32-ja|0;ia=c[K>>2]|0;P=0;while(1){la=c[I>>2]|0;W=c[M>>2]|0;za=ia+(la>>>3)|0;Aa=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(la&7)>>>(wa>>>0);za=ja+la|0;c[I>>2]=W>>>0>za>>>0?za:W;c[f+2880+(P<<2)>>2]=Aa;Aa=P+1|0;if(Aa>>>0<(c[T>>2]|0)>>>0){P=Aa}else{F=116;break}}}else{P=(d[1359664+(ma>>>8)|0]|0)+(ga|8)|0;ja=32-P|0;wa=c[K>>2]|0;ia=0;while(1){Aa=c[I>>2]|0;W=c[M>>2]|0;za=wa+(Aa>>>3)|0;la=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Aa&7)>>>(ja>>>0);za=P+Aa|0;c[I>>2]=W>>>0>za>>>0?za:W;c[f+2880+(ia<<2)>>2]=la;la=ia+1|0;if(la>>>0<(c[T>>2]|0)>>>0){ia=la}else{F=116;break}}}}else{F=116}}while(0);do{if((F|0)==116){X=c[U>>2]|0;if((X|0)!=0){Ca=X;break}X=c[I>>2]|0;_=d[(c[K>>2]|0)+(X>>>3)|0]<<(X&7)>>>7;c[I>>2]=((X|0)<(c[M>>2]|0))+X;a[f+3023|0]=_&1;Ca=0}}while(0);_=c[R>>2]|0;if((a[_+5|0]|0)==0){a[f+3024|0]=0}else{X=c[I>>2]|0;ha=d[(c[K>>2]|0)+(X>>>3)|0]<<(X&7)>>>7;c[I>>2]=((X|0)<(c[M>>2]|0))+X;a[f+3024|0]=ha&1}ha=f+3028|0;c[ha>>2]=0;do{if((a[f+3011|0]|0)==0){Da=_}else{X=f+3027|0;a[X]=0;if((Ca|0)==0){ia=c[I>>2]|0;P=d[(c[K>>2]|0)+(ia>>>3)|0]<<(ia&7);c[I>>2]=((ia|0)<(c[M>>2]|0))+ia;ia=P>>>7&1^1;a[X]=ia;Ea=ia}else{Ea=0}if(!((c[f+3012+(Ea<<2)>>2]|0)>>>0>1>>>0)){Da=_;break}ia=fFa(z)|0;c[ha>>2]=ia;if(ia>>>0<(c[f+3012+(d[X]<<2)>>2]|0)>>>0){Da=c[R>>2]|0;break}KIb(c[A>>2]|0,16,2354648,(G=i,i=i+8|0,c[G>>2]=ia,G)|0);i=G;w=-1094995529;i=j;return w|0}}while(0);if((a[Da+37|0]|0)==0){F=130}else{if((c[U>>2]|0)==1){F=132}else{F=130}}do{if((F|0)==130){if((a[Da+38|0]|0)==0){break}if((c[U>>2]|0)==0){F=132}}}while(0);do{if((F|0)==132){ha=l|0;_=n|0;ia=f+3073|0;a[ia]=fFa(z)|0;X=c[J>>2]|0;if((c[X+4>>2]|0)!=0){P=c[I>>2]|0;ja=c[M>>2]|0;wa=c[K>>2]|0;ga=wa+(P>>>3)|0;ma=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(P&7);if(ma>>>0>134217727>>>0){ga=ma>>>23;la=(d[1382088+ga|0]|0)+P|0;c[I>>2]=ja>>>0>la>>>0?la:ja;Fa=a[1306768+ga|0]|0}else{ga=ma>>>0>65535>>>0;la=ga?ma>>>16:ma;ma=ga?16:0;if((la&65280|0)==0){Ga=ma;Ha=la}else{Ga=ma|8;Ha=la>>>8}la=(d[1359664+Ha|0]|0)+Ga|0;ma=31-la+P|0;P=ja>>>0>ma>>>0?ma:ja;ma=wa+(P>>>3)|0;wa=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(P&7)>>>(la>>>0);ma=P+(32-la)|0;c[I>>2]=ja>>>0>ma>>>0?ma:ja;ja=wa>>>1;Fa=(wa&1|0)==0?ja:-ja|0}ja=(d[ia]|0)+Fa|0;if((ja|0)<0){Ia=0}else{Ia=(ja|0)>7?7:ja&65535}b[f+3074>>1]=Ia}if((c[$>>2]|0)==0){Ja=X;Ka=0}else{X=c[K>>2]|0;ja=c[M>>2]|0;wa=0;ma=c[I>>2]|0;do{la=d[X+(ma>>>3)|0]<<(ma&7)>>>7;ma=((ma|0)<(ja|0))+ma|0;c[I>>2]=ma;P=la&1;a[k+wa|0]=P;if(P<<24>>24==0){b[f+3076+(wa<<1)>>1]=1<<d[ia];b[f+3268+(wa<<1)>>1]=0}wa=wa+1|0;La=c[$>>2]|0;}while(wa>>>0<La>>>0);Ja=c[J>>2]|0;Ka=La}wa=(Ka|0)==0;do{if((c[Ja+4>>2]|0)==0){if(wa){break}mrc(ha|0,0,(Ka>>>0>1>>>0?Ka:1)|0)|0;Ma=Ka;F=152}else{if(wa){break}ma=c[K>>2]|0;ja=c[M>>2]|0;X=0;P=c[I>>2]|0;while(1){la=d[ma+(P>>>3)|0]<<(P&7)>>>7;ga=((P|0)<(ja|0))+P|0;c[I>>2]=ga;a[l+X|0]=la&1;la=X+1|0;W=c[$>>2]|0;if(la>>>0<W>>>0){X=la;P=ga}else{Ma=W;F=152;break}}}}while(0);do{if((F|0)==152){if((Ma|0)==0){break}wa=f+3074|0;ha=0;do{if((a[k+ha|0]|0)!=0){P=c[I>>2]|0;X=c[M>>2]|0;ja=c[K>>2]|0;ma=ja+(P>>>3)|0;W=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(P&7);if(W>>>0>134217727>>>0){ma=W>>>23;ga=(d[1382088+ma|0]|0)+P|0;la=X>>>0>ga>>>0?ga:X;c[I>>2]=la;Na=a[1306768+ma|0]|0;Oa=la}else{la=W>>>0>65535>>>0;ma=la?W>>>16:W;W=la?16:0;if((ma&65280|0)==0){Pa=W;Qa=ma}else{Pa=W|8;Qa=ma>>>8}ma=(d[1359664+Qa|0]|0)+Pa|0;W=31-ma+P|0;P=X>>>0>W>>>0?W:X;W=ja+(P>>>3)|0;la=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(P&7)>>>(ma>>>0);W=P+(32-ma)|0;ma=X>>>0>W>>>0?W:X;c[I>>2]=ma;W=la>>>1;Na=(la&1|0)==0?W:-W|0;Oa=ma}b[f+3076+(ha<<1)>>1]=(1<<d[ia])+Na;ma=ja+(Oa>>>3)|0;W=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(Oa&7);if(W>>>0>134217727>>>0){ma=W>>>23;la=(d[1382088+ma|0]|0)+Oa|0;c[I>>2]=X>>>0>la>>>0?la:X;Ra=a[1306768+ma|0]|0}else{ma=W>>>0>65535>>>0;la=ma?W>>>16:W;W=ma?16:0;if((la&65280|0)==0){Sa=W;Ta=la}else{Sa=W|8;Ta=la>>>8}la=(d[1359664+Ta|0]|0)+Sa|0;W=31-la+Oa|0;ma=X>>>0>W>>>0?W:X;W=ja+(ma>>>3)|0;ja=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(ma&7)>>>(la>>>0);W=ma+(32-la)|0;c[I>>2]=X>>>0>W>>>0?W:X;X=ja>>>1;Ra=((ja&1|0)==0?X:-X|0)&65535}b[f+3268+(ha<<1)>>1]=Ra}if((a[l+ha|0]|0)==0){X=1<<b[wa>>1]&65535;b[f+3108+(ha<<2)>>1]=X;b[f+3300+(ha<<2)>>1]=0;b[f+3108+(ha<<2)+2>>1]=X;b[f+3300+(ha<<2)+2>>1]=0}else{X=c[M>>2]|0;ja=c[K>>2]|0;W=0;la=c[I>>2]|0;while(1){ma=ja+(la>>>3)|0;P=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(la&7);if(P>>>0>134217727>>>0){ma=P>>>23;ga=(d[1382088+ma|0]|0)+la|0;za=X>>>0>ga>>>0?ga:X;c[I>>2]=za;Ua=a[1306768+ma|0]|0;Va=za}else{za=P>>>0>65535>>>0;ma=za?P>>>16:P;P=za?16:0;if((ma&65280|0)==0){Wa=P;Xa=ma}else{Wa=P|8;Xa=ma>>>8}ma=(d[1359664+Xa|0]|0)+Wa|0;P=31-ma+la|0;za=X>>>0>P>>>0?P:X;P=ja+(za>>>3)|0;ga=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(za&7)>>>(ma>>>0);P=za+(32-ma)|0;ma=X>>>0>P>>>0?P:X;c[I>>2]=ma;P=ga>>>1;Ua=(ga&1|0)==0?P:-P|0;Va=ma}ma=ja+(Va>>>3)|0;P=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(Va&7);if(P>>>0>134217727>>>0){ma=P>>>23;ga=(d[1382088+ma|0]|0)+Va|0;za=X>>>0>ga>>>0?ga:X;c[I>>2]=za;Ya=a[1306768+ma|0]|0;Za=za}else{za=P>>>0>65535>>>0;ma=za?P>>>16:P;P=za?16:0;if((ma&65280|0)==0){_a=P;$a=ma}else{_a=P|8;$a=ma>>>8}ma=(d[1359664+$a|0]|0)+_a|0;P=31-ma+Va|0;za=X>>>0>P>>>0?P:X;P=ja+(za>>>3)|0;ga=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(za&7)>>>(ma>>>0);P=za+(32-ma)|0;ma=X>>>0>P>>>0?P:X;c[I>>2]=ma;P=ga>>>1;Ya=(ga&1|0)==0?P:-P|0;Za=ma}ma=(1<<b[wa>>1])+Ua&65535;b[f+3108+(ha<<2)+(W<<1)>>1]=ma;P=Ya-(ma<<16>>16<<7>>b[wa>>1])+128|0;if((P|0)<-128){ab=-128}else{ab=(P|0)>127?127:P&65535}b[f+3300+(ha<<2)+(W<<1)>>1]=ab;P=W+1|0;if((P|0)<2){W=P;la=Za}else{break}}}ha=ha+1|0;}while(ha>>>0<(c[$>>2]|0)>>>0)}}while(0);if((c[U>>2]|0)!=0){break}if((c[T>>2]|0)==0){bb=0}else{ha=c[K>>2]|0;wa=c[M>>2]|0;la=0;W=c[I>>2]|0;while(1){X=d[ha+(W>>>3)|0]<<(W&7)>>>7;ja=((W|0)<(wa|0))+W|0;c[I>>2]=ja;P=X&1;a[m+la|0]=P;if(P<<24>>24==0){b[f+3236+(la<<1)>>1]=1<<d[ia];b[f+3364+(la<<1)>>1]=0}P=la+1|0;X=c[T>>2]|0;if(P>>>0<X>>>0){la=P;W=ja}else{bb=X;break}}}W=(bb|0)==0;if((c[(c[J>>2]|0)+4>>2]|0)==0){if(W){break}mrc(_|0,0,(bb>>>0>1>>>0?bb:1)|0)|0;cb=bb}else{if(W){break}W=c[K>>2]|0;la=c[M>>2]|0;wa=0;ha=c[I>>2]|0;while(1){X=d[W+(ha>>>3)|0]<<(ha&7)>>>7;ja=((ha|0)<(la|0))+ha|0;c[I>>2]=ja;a[n+wa|0]=X&1;X=wa+1|0;P=c[T>>2]|0;if(X>>>0<P>>>0){wa=X;ha=ja}else{cb=P;break}}}if((cb|0)==0){break}ha=f+3074|0;wa=0;do{if((a[m+wa|0]|0)!=0){la=c[I>>2]|0;W=c[M>>2]|0;_=c[K>>2]|0;P=_+(la>>>3)|0;ja=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(la&7);if(ja>>>0>134217727>>>0){P=ja>>>23;X=(d[1382088+P|0]|0)+la|0;ma=W>>>0>X>>>0?X:W;c[I>>2]=ma;db=a[1306768+P|0]|0;eb=ma}else{ma=ja>>>0>65535>>>0;P=ma?ja>>>16:ja;ja=ma?16:0;if((P&65280|0)==0){fb=ja;gb=P}else{fb=ja|8;gb=P>>>8}P=(d[1359664+gb|0]|0)+fb|0;ja=31-P+la|0;la=W>>>0>ja>>>0?ja:W;ja=_+(la>>>3)|0;ma=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(la&7)>>>(P>>>0);ja=la+(32-P)|0;P=W>>>0>ja>>>0?ja:W;c[I>>2]=P;ja=ma>>>1;db=(ma&1|0)==0?ja:-ja|0;eb=P}b[f+3236+(wa<<1)>>1]=(1<<d[ia])+db;P=_+(eb>>>3)|0;ja=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(eb&7);if(ja>>>0>134217727>>>0){P=ja>>>23;ma=(d[1382088+P|0]|0)+eb|0;c[I>>2]=W>>>0>ma>>>0?ma:W;hb=a[1306768+P|0]|0}else{P=ja>>>0>65535>>>0;ma=P?ja>>>16:ja;ja=P?16:0;if((ma&65280|0)==0){ib=ja;jb=ma}else{ib=ja|8;jb=ma>>>8}ma=(d[1359664+jb|0]|0)+ib|0;ja=31-ma+eb|0;P=W>>>0>ja>>>0?ja:W;ja=_+(P>>>3)|0;_=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(P&7)>>>(ma>>>0);ja=P+(32-ma)|0;c[I>>2]=W>>>0>ja>>>0?ja:W;W=_>>>1;hb=((_&1|0)==0?W:-W|0)&65535}b[f+3364+(wa<<1)>>1]=hb}if((a[n+wa|0]|0)==0){W=1<<b[ha>>1]&65535;b[f+3172+(wa<<2)>>1]=W;b[f+3396+(wa<<2)>>1]=0;b[f+3172+(wa<<2)+2>>1]=W;b[f+3396+(wa<<2)+2>>1]=0}else{W=c[M>>2]|0;_=c[K>>2]|0;ja=0;ma=c[I>>2]|0;while(1){P=_+(ma>>>3)|0;la=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(ma&7);if(la>>>0>134217727>>>0){P=la>>>23;X=(d[1382088+P|0]|0)+ma|0;ga=W>>>0>X>>>0?X:W;c[I>>2]=ga;kb=a[1306768+P|0]|0;lb=ga}else{ga=la>>>0>65535>>>0;P=ga?la>>>16:la;la=ga?16:0;if((P&65280|0)==0){mb=la;nb=P}else{mb=la|8;nb=P>>>8}P=(d[1359664+nb|0]|0)+mb|0;la=31-P+ma|0;ga=W>>>0>la>>>0?la:W;la=_+(ga>>>3)|0;X=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ga&7)>>>(P>>>0);la=ga+(32-P)|0;P=W>>>0>la>>>0?la:W;c[I>>2]=P;la=X>>>1;kb=(X&1|0)==0?la:-la|0;lb=P}P=_+(lb>>>3)|0;la=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(lb&7);if(la>>>0>134217727>>>0){P=la>>>23;X=(d[1382088+P|0]|0)+lb|0;ga=W>>>0>X>>>0?X:W;c[I>>2]=ga;ob=a[1306768+P|0]|0;pb=ga}else{ga=la>>>0>65535>>>0;P=ga?la>>>16:la;la=ga?16:0;if((P&65280|0)==0){qb=la;rb=P}else{qb=la|8;rb=P>>>8}P=(d[1359664+rb|0]|0)+qb|0;la=31-P+lb|0;ga=W>>>0>la>>>0?la:W;la=_+(ga>>>3)|0;X=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ga&7)>>>(P>>>0);la=ga+(32-P)|0;P=W>>>0>la>>>0?la:W;c[I>>2]=P;la=X>>>1;ob=(X&1|0)==0?la:-la|0;pb=P}P=(1<<b[ha>>1])+kb&65535;b[f+3172+(wa<<2)+(ja<<1)>>1]=P;la=ob-(P<<16>>16<<7>>b[ha>>1])+128|0;if((la|0)<-128){sb=-128}else{sb=(la|0)>127?127:la&65535}b[f+3396+(wa<<2)+(ja<<1)>>1]=sb;la=ja+1|0;if((la|0)<2){ja=la;ma=pb}else{break}}}wa=wa+1|0;}while(wa>>>0<(c[T>>2]|0)>>>0)}}while(0);wa=fFa(z)|0;ha=5-wa|0;c[f+3052>>2]=ha;if(!((wa|0)==5|ha>>>0>5>>>0)){break}KIb(c[A>>2]|0,16,2345720,(G=i,i=i+8|0,c[G>>2]=ha,G)|0);i=G;w=-1094995529;i=j;return w|0}}while(0);T=c[I>>2]|0;U=c[M>>2]|0;$=c[K>>2]|0;V=$+(T>>>3)|0;ha=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7);if(ha>>>0>134217727>>>0){V=ha>>>23;wa=(d[1382088+V|0]|0)+T|0;c[I>>2]=U>>>0>wa>>>0?wa:U;tb=a[1306768+V|0]|0}else{V=ha>>>0>65535>>>0;wa=V?ha>>>16:ha;ha=V?16:0;if((wa&65280|0)==0){ub=ha;vb=wa}else{ub=ha|8;vb=wa>>>8}wa=(d[1359664+vb|0]|0)+ub|0;ha=31-wa+T|0;T=U>>>0>ha>>>0?ha:U;ha=$+(T>>>3)|0;V=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(T&7)>>>(wa>>>0);ha=T+(32-wa)|0;c[I>>2]=U>>>0>ha>>>0?ha:U;U=V>>>1;tb=(V&1|0)==0?U:-U|0}c[f+3032>>2]=tb;U=c[R>>2]|0;if((a[U+36|0]|0)==0){c[f+3036>>2]=0;c[f+3040>>2]=0}else{V=c[I>>2]|0;ha=c[M>>2]|0;wa=$+(V>>>3)|0;T=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(V&7);if(T>>>0>134217727>>>0){wa=T>>>23;ia=(d[1382088+wa|0]|0)+V|0;c[I>>2]=ha>>>0>ia>>>0?ia:ha;wb=a[1306768+wa|0]|0}else{wa=T>>>0>65535>>>0;ia=wa?T>>>16:T;T=wa?16:0;if((ia&65280|0)==0){xb=T;yb=ia}else{xb=T|8;yb=ia>>>8}ia=(d[1359664+yb|0]|0)+xb|0;T=31-ia+V|0;V=ha>>>0>T>>>0?T:ha;T=$+(V>>>3)|0;wa=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(V&7)>>>(ia>>>0);T=V+(32-ia)|0;c[I>>2]=ha>>>0>T>>>0?T:ha;ha=wa>>>1;wb=(wa&1|0)==0?ha:-ha|0}c[f+3036>>2]=wb;ha=c[I>>2]|0;wa=c[M>>2]|0;T=$+(ha>>>3)|0;ia=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(ha&7);if(ia>>>0>134217727>>>0){T=ia>>>23;V=(d[1382088+T|0]|0)+ha|0;c[I>>2]=wa>>>0>V>>>0?V:wa;zb=a[1306768+T|0]|0}else{T=ia>>>0>65535>>>0;V=T?ia>>>16:ia;ia=T?16:0;if((V&65280|0)==0){Ab=ia;Bb=V}else{Ab=ia|8;Bb=V>>>8}V=(d[1359664+Bb|0]|0)+Ab|0;ia=31-V+ha|0;ha=wa>>>0>ia>>>0?ia:wa;ia=$+(ha>>>3)|0;T=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(ha&7)>>>(V>>>0);ia=ha+(32-V)|0;c[I>>2]=wa>>>0>ia>>>0?ia:wa;wa=T>>>1;zb=(T&1|0)==0?wa:-wa|0}c[f+3040>>2]=zb}d:do{if((a[U+55|0]|0)==0){a[f+3025|0]=0;c[f+3044>>2]=0;c[f+3048>>2]=0}else{do{if((a[U+56|0]|0)!=0){wa=c[I>>2]|0;T=d[$+(wa>>>3)|0]|0;ia=c[M>>2]|0;V=((wa|0)<(ia|0))+wa|0;c[I>>2]=V;if((T&128>>>((wa&7)>>>0)|0)==0){break}wa=d[$+(V>>>3)|0]<<(V&7)>>>7;c[I>>2]=((V|0)<(ia|0))+V;V=wa&1;a[f+3025|0]=V;if(!(V<<24>>24==0)){break d}V=c[I>>2]|0;wa=c[M>>2]|0;ia=c[K>>2]|0;T=ia+(V>>>3)|0;ha=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(V&7);if(ha>>>0>134217727>>>0){T=ha>>>23;ma=(d[1382088+T|0]|0)+V|0;c[I>>2]=wa>>>0>ma>>>0?ma:wa;Cb=a[1306768+T|0]|0}else{T=ha>>>0>65535>>>0;ma=T?ha>>>16:ha;ha=T?16:0;if((ma&65280|0)==0){Db=ha;Eb=ma}else{Db=ha|8;Eb=ma>>>8}ma=(d[1359664+Eb|0]|0)+Db|0;ha=31-ma+V|0;V=wa>>>0>ha>>>0?ha:wa;ha=ia+(V>>>3)|0;T=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(V&7)>>>(ma>>>0);ha=V+(32-ma)|0;c[I>>2]=wa>>>0>ha>>>0?ha:wa;wa=T>>>1;Cb=(T&1|0)==0?wa:-wa|0}c[f+3044>>2]=Cb<<1;wa=c[I>>2]|0;T=c[M>>2]|0;ha=ia+(wa>>>3)|0;ma=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(wa&7);if(ma>>>0>134217727>>>0){ha=ma>>>23;V=(d[1382088+ha|0]|0)+wa|0;c[I>>2]=T>>>0>V>>>0?V:T;Fb=a[1306768+ha|0]|0}else{ha=ma>>>0>65535>>>0;V=ha?ma>>>16:ma;ma=ha?16:0;if((V&65280|0)==0){Gb=ma;Hb=V}else{Gb=ma|8;Hb=V>>>8}V=(d[1359664+Hb|0]|0)+Gb|0;ma=31-V+wa|0;wa=T>>>0>ma>>>0?ma:T;ma=ia+(wa>>>3)|0;ia=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(wa&7)>>>(V>>>0);ma=wa+(32-V)|0;c[I>>2]=T>>>0>ma>>>0?ma:T;T=ia>>>1;Fb=(ia&1|0)==0?T:-T|0}c[f+3048>>2]=Fb<<1;break d}}while(0);a[f+3025|0]=a[U+57|0]|0;c[f+3044>>2]=c[U+60>>2];c[f+3048>>2]=c[U+64>>2]}}while(0);$=a[U+54|0]|0;e:do{if(!($<<24>>24==0)){do{if((a[f+3020|0]|0)==0){if((a[f+3021|0]|0)!=0){break}if((a[f+3025|0]|0)!=0){break e}}}while(0);T=c[I>>2]|0;ia=d[(c[K>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[I>>2]=((T|0)<(c[M>>2]|0))+T;a[f+3026|0]=ia&1;ba=aa;da=U;break b}}while(0);a[f+3026|0]=$;ba=aa;da=U}}while(0);ia=f+3068|0;c[ia>>2]=0;if((a[da+42|0]|0)==0){if((a[da+43|0]|0)!=0){F=275}}else{F=275}f:do{if((F|0)==275){T=fFa(z)|0;c[ia>>2]=T;if((T|0)<=0){c[f+7372>>2]=0;break}T=(fFa(z)|0)+1|0;ma=T>>4;V=T&15;T=f+3056|0;mJb(T);wa=f+3060|0;mJb(wa);ha=f+3064|0;mJb(ha);c[T>>2]=hJb(c[ia>>2]<<2)|0;c[wa>>2]=hJb(c[ia>>2]<<2)|0;ja=hJb(c[ia>>2]<<2)|0;c[ha>>2]=ja;ha=c[T>>2]|0;do{if((ha|0)!=0){if((c[wa>>2]|0)==0|(ja|0)==0){break}g:do{if((c[ia>>2]|0)>0){T=(V|0)==0;W=32-V|0;if((ma|0)<=0){if(T){_=0;while(1){c[ha+(_<<2)>>2]=1;_=_+1|0;if((_|0)>=(c[ia>>2]|0)){break g}}}_=c[K>>2]|0;la=0;while(1){P=c[I>>2]|0;X=c[M>>2]|0;ga=_+(P>>>3)|0;za=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(P&7)>>>(W>>>0);ga=P+V|0;c[I>>2]=X>>>0>ga>>>0?ga:X;c[ha+(la<<2)>>2]=za+1;la=la+1|0;if((la|0)>=(c[ia>>2]|0)){break g}}}la=(ma|0)>1;_=c[K>>2]|0;za=0;do{X=c[I>>2]|0;ga=c[M>>2]|0;P=_+(X>>>3)|0;Aa=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(X&7)>>>16;P=X+16|0;X=ga>>>0>P>>>0?P:ga;c[I>>2]=X;if(la){P=1;Ba=Aa;Ib=X;while(1){Jb=P+1|0;Kb=_+(Ib>>>3)|0;Lb=(je(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(Ib&7)>>>16;Kb=Ib+16|0;Mb=ga>>>0>Kb>>>0?Kb:ga;c[I>>2]=Mb;if((Jb|0)<(ma|0)){P=Jb;Ba=Lb;Ib=Mb}else{break}}Nb=Ba<<16;Ob=Lb;Pb=Mb}else{Nb=0;Ob=Aa;Pb=X}Ib=Ob|Nb;if(T){Qb=Ib}else{P=_+(Pb>>>3)|0;Jb=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Pb&7)>>>(W>>>0);P=Pb+V|0;c[I>>2]=ga>>>0>P>>>0?P:ga;Qb=Jb+(Ib<<V)|0}c[ha+(za<<2)>>2]=Qb+1;za=za+1|0;}while((za|0)<(c[ia>>2]|0))}}while(0);za=f+141|0;do{if((d[za]|0)>>>0>1>>>0){W=c[R>>2]|0;if((c[W+48>>2]|0)<=1){if((c[W+44>>2]|0)<=1){break}}c[f+7372>>2]=0;a[za]=1;break f}}while(0);c[f+7372>>2]=0;break f}}while(0);c[ia>>2]=0;KIb(c[A>>2]|0,16,2333984,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-12;i=j;return w|0}}while(0);ha=c[R>>2]|0;if((a[ha+1628|0]|0)==0){Rb=ha}else{ha=fFa(z)|0;if((ha|0)!=0){V=c[M>>2]|0;ma=0;ja=c[I>>2]|0;do{wa=ja+8|0;ja=V>>>0>wa>>>0?wa:V;ma=ma+1|0;}while(ma>>>0<ha>>>0);c[I>>2]=ja}Rb=c[R>>2]|0}ha=(c[Rb+16>>2]|0)+26+(c[f+3032>>2]|0)&255;ma=f+3072|0;a[ma]=ha;do{if(ha<<24>>24>51){Sb=c[(c[J>>2]|0)+13164>>2]|0;Tb=ha<<24>>24}else{V=ha<<24>>24;wa=c[(c[J>>2]|0)+13164>>2]|0;if((V|0)<(-wa|0)){Sb=wa;Tb=V;break}V=c[f+2396>>2]|0;c[f+3460>>2]=V;wa=(a[O]|0)==0;do{if((V|0)==0){if(wa){Ub=1;break}KIb(c[A>>2]|0,16,2322816,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;w=-1094995529;i=j;return w|0}else{Ub=wa&1}}while(0);a[(c[q>>2]|0)+9271|0]=Ub;if((a[(c[R>>2]|0)+22|0]|0)==0){a[(c[q>>2]|0)+173182|0]=a[ma]|0}a[ba]=1;wa=f+5804|0;V=c[wa>>2]|0;U=c[y>>2]|0;h:do{if((V|0)==2147483647){switch(U|0){case 21:case 17:case 16:case 18:{$=c[f+5788>>2]|0;c[wa>>2]=$;Vb=$;break h;break};case 19:case 20:{c[wa>>2]=-2147483648;Vb=-2147483648;break h;break};default:{Vb=2147483647;break h}}}else{Vb=V}}while(0);do{if((U-8|0)>>>0<2>>>0){if((c[f+5788>>2]|0)>(Vb|0)){if((U|0)!=9){break}c[wa>>2]=-2147483648;break}else{c[f+5816>>2]=0;w=0;i=j;return w|0}}}while(0);i:do{if((a[L]|0)==0){if((c[f+3480>>2]|0)==0){KIb(c[A>>2]|0,16,2550048,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=0;break a}else{Wb=f+7420|0;break}}else{wa=c[q>>2]|0;U=c[J>>2]|0;V=c[U+13064>>2]|0;$=c[U+13096>>2]>>V;za=(c[U+13100>>2]>>V)+1|0;V=f+5808|0;U=f+5812|0;mrc(c[f+7324>>2]|0,0,ca(c[V>>2]<<1,(c[U>>2]|0)+1|0)|0)|0;mrc(c[f+7328>>2]|0,0,ca(c[V>>2]<<1,(c[U>>2]|0)+1|0)|0)|0;U=c[J>>2]|0;mrc(c[f+7348>>2]|0,0,ca(c[U+13128>>2]|0,c[U+13124>>2]|0)|0)|0;U=c[J>>2]|0;mrc(c[f+7352>>2]|0,0,ca(c[U+13136>>2]|0,c[U+13132>>2]|0)|0)|0;mrc(c[f+7332>>2]|0,-1|0,ca(($<<2)+4|0,za)|0)|0;c[f+5816>>2]=0;za=f+7420|0;c[za>>2]=c[y>>2];$=c[f+184>>2]|0;if((a[$+42|0]|0)==0){Xb=c[J>>2]|0}else{U=c[J>>2]|0;c[wa+173204>>2]=c[c[$+1632>>2]>>2]<<c[U+13080>>2];Xb=U}U=pGa(f,(a[Xb+12941|0]|0)!=0?f+164|0:f+160|0,c[f+5788>>2]|0)|0;j:do{if((U|0)<0){Yb=U}else{$=tGa(f)|0;if(($|0)<0){KIb(c[A>>2]|0,16,2459760,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Yb=$;break}$=c[c[f+3480>>2]>>2]|0;do{if((c[f+7496>>2]|0)!=0){wa=f+7500|0;if(!(((c[wa>>2]|0)-3|0)>>>0<3>>>0)){break}V=f+7504|0;if(!(((c[V>>2]|0)-1|0)>>>0<2>>>0)){break}W=iLb($)|0;if((W|0)==0){Yb=-12;break j}_=c[wa>>2]|0;do{if((_|0)==3){wa=W|0;if((c[f+7508>>2]|0)==0){c[wa>>2]=1;break}else{c[wa>>2]=5;break}}else if((_|0)==4){c[W>>2]=2}else if((_|0)==5){c[W>>2]=3}}while(0);if((c[V>>2]|0)!=2){break}c[W+4>>2]=1}}while(0);$=f+172|0;WHb(c[$>>2]|0);_=rGa(f,c[$>>2]|0,0)|0;if((_|0)<0){Yb=_;break}K5a(c[A>>2]|0);Wb=za;break i}}while(0);U=f+3480|0;_=c[U>>2]|0;do{if((_|0)!=0){if((a[f+140|0]|0)!=1){break}L5a(_+4|0,2147483647,0)}}while(0);c[U>>2]=0;if((Yb|0)<0){w=Yb}else{Wb=za;break}i=j;return w|0}}while(0);_=c[y>>2]|0;$=c[Wb>>2]|0;if((_|0)!=($|0)){KIb(c[A>>2]|0,16,2531968,(G=i,i=i+16|0,c[G>>2]=$,c[G+8>>2]=_,G)|0);i=G;w=-1094995529;i=j;return w|0}do{if((a[O]|0)==0){if((c[f+2404>>2]|0)==2){break}_=sGa(f)|0;if((_|0)>=0){break}KIb(c[A>>2]|0,24,2516720,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=_;break a}}while(0);_=f+141|0;do{if((d[_]|0)>>>0>1>>>0){$=c[ia>>2]|0;if(($|0)<=0){F=390;break}ga=c[q>>2]|0;X=hJb(($<<2)+4|0)|0;$=X;Aa=hJb((c[ia>>2]<<2)+4|0)|0;Ba=Aa;do{if((c[f+12>>2]|0)==0){O5a(c[A>>2]|0,(c[ia>>2]|0)+1|0)|0;if(!((d[_]|0)>>>0>1>>>0)){break}wa=f;T=1;do{la=hJb(7516)|0;Ib=f+8+(T<<2)|0;c[Ib>>2]=la;nrc(la|0,wa|0,7516)|0;la=hJb(184672)|0;c[f+72+(T<<2)>>2]=la;c[(c[Ib>>2]|0)+136>>2]=la;T=T+1|0;}while((T|0)<(d[_]|0))}}while(0);za=c[ga+9280>>2]>>3;U=f+3056|0;T=f+7380|0;wa=c[T>>2]|0;if((wa|0)>0){la=c[f+7384>>2]|0;Ib=(c[c[U>>2]>>2]|0)+za|0;Jb=0;P=0;while(1){Kb=c[la+(P<<2)>>2]|0;if((Kb|0)>=(za|0)&(Kb|0)<(Ib|0)){Zb=Jb+1|0;_b=Ib-1|0}else{Zb=Jb;_b=Ib}Kb=P+1|0;if((Kb|0)<(wa|0)){Ib=_b;Jb=Zb;P=Kb}else{$b=Zb;break}}}else{$b=0}P=c[ia>>2]|0;k:do{if((P|0)>1){Jb=c[U>>2]|0;Ib=c[f+3064>>2]|0;la=c[f+3060>>2]|0;ga=f+7384|0;Kb=za;ac=$b;bc=1;cc=wa;while(1){dc=bc-1|0;ec=(c[Jb+(dc<<2)>>2]|0)-ac+Kb|0;fc=c[Jb+(bc<<2)>>2]|0;if((cc|0)>0){gc=c[ga>>2]|0;hc=ec+fc|0;ic=0;jc=0;while(1){kc=c[gc+(jc<<2)>>2]|0;if((kc|0)>=(ec|0)&(kc|0)<(hc|0)){lc=ic+1|0;mc=hc-1|0}else{lc=ic;mc=hc}kc=jc+1|0;if((kc|0)<(cc|0)){hc=mc;ic=lc;jc=kc}else{nc=lc;break}}}else{nc=0}c[Ib+(dc<<2)>>2]=fc-nc;c[la+(dc<<2)>>2]=ec;jc=bc+1|0;ic=c[ia>>2]|0;if((jc|0)>=(ic|0)){oc=ec;pc=nc;qc=ic;break k}Kb=ec;ac=nc;bc=jc;cc=c[T>>2]|0}}else{oc=za;pc=$b;qc=P}}while(0);if((qc|0)!=0){P=qc-1|0;za=(c[(c[U>>2]|0)+(P<<2)>>2]|0)-pc+oc|0;c[(c[f+3064>>2]|0)+(P<<2)>>2]=h-za;c[(c[f+3060>>2]|0)+((c[ia>>2]|0)-1<<2)>>2]=za}c[f+7404>>2]=g;if((d[_]|0)>>>0>1>>>0){za=f+8|0;P=f;T=1;do{wa=f+8+(T<<2)|0;a[(c[(c[wa>>2]|0)+136>>2]|0)+9271|0]=1;a[(c[(c[wa>>2]|0)+136>>2]|0)+173182|0]=a[(c[(c[za>>2]|0)+136>>2]|0)+173182|0]|0;nrc(c[wa>>2]|0,P|0,7516)|0;c[(c[wa>>2]|0)+136>>2]=c[f+72+(T<<2)>>2];T=T+1|0;}while((T|0)<(d[_]|0))}c[f+7376>>2]=0;P5a(c[A>>2]|0);T=c[ia>>2]|0;if((T|0)>=0){mrc(X|0,0,((T|0)>0?(T<<2)+4|0:4)|0)|0;P=0;do{c[Ba+(P<<2)>>2]=P;P=P+1|0;}while((P|0)<=(T|0))}if((a[(c[f+184>>2]|0)+43|0]|0)==0){rc=T}else{P=c[A>>2]|0;Xe[c[P+828>>2]&511](P,430,Aa,$,T+1|0)|0;rc=c[ia>>2]|0}if((rc|0)<0){sc=0}else{P=0;Ba=0;while(1){za=(c[$+(P<<2)>>2]|0)+Ba|0;U=P+1|0;if((U|0)>(rc|0)){sc=za;break}else{P=U;Ba=za}}}kJb(X);kJb(Aa);tc=sc}else{F=390}}while(0);if((F|0)==390){_=c[A>>2]|0;c[o>>2]=0;c[o+4>>2]=1;Ba=p|0;se[c[_+824>>2]&127](_,142,o,Ba,1,4)|0;tc=c[Ba>>2]|0}Ba=c[J>>2]|0;do{if((tc|0)>=(ca(c[Ba+13108>>2]|0,c[Ba+13104>>2]|0)|0)){c[f+5816>>2]=1;if((a[(c[f+184>>2]|0)+40|0]|0)==0){if((a[Ba+13056|0]|0)==0){break}if((c[Ba+68>>2]|0)==0){break}}if((a[Ba+12941|0]|0)==0){break}_=1<<c[Ba+13084>>2];P=f+160|0;$=f+7352|0;T=f+164|0;za=0;U=Ba;while(1){wa=c[(c[P>>2]|0)+32+(za<<2)>>2]|0;cc=c[U+13140+(za<<2)>>2]|0;bc=c[U+13152+(za<<2)>>2]|0;if((c[U+13136>>2]|0)>0){ac=_>>cc;Kb=_>>bc;la=(Kb|0)>0;Ib=0;ga=U;while(1){Jb=c[ga+13132>>2]|0;if((Jb|0)>0){jc=0;ic=ga;hc=Jb;while(1){Jb=jc+(ca(hc,Ib)|0)|0;do{if((a[(c[$>>2]|0)+Jb|0]|0)==0){uc=ic}else{gc=c[ic+13084>>2]|0;W=ca(Ib<<gc>>bc,wa)|0;V=W+(jc<<gc>>cc<<c[ic+56>>2])|0;if(!la){uc=ic;break}gc=0;W=(c[(c[P>>2]|0)+(za<<2)>>2]|0)+V|0;kc=(c[(c[T>>2]|0)+(za<<2)>>2]|0)+V|0;while(1){nrc(kc|0,W|0,ac)|0;V=gc+1|0;if((V|0)<(Kb|0)){gc=V;W=W+wa|0;kc=kc+wa|0}else{break}}uc=c[J>>2]|0}}while(0);Jb=jc+1|0;kc=c[uc+13132>>2]|0;if((Jb|0)<(kc|0)){jc=Jb;ic=uc;hc=kc}else{vc=uc;break}}}else{vc=ga}hc=Ib+1|0;if((hc|0)<(c[vc+13136>>2]|0)){Ib=hc;ga=vc}else{wc=vc;break}}}else{wc=U}ga=za+1|0;if((ga|0)<3){za=ga;U=wc}else{break}}}}while(0);if((tc|0)<0){H=tc;break a}else{w=0}i=j;return w|0}}while(0);KIb(c[A>>2]|0,16,2328696,(G=i,i=i+16|0,c[G>>2]=Tb,c[G+8>>2]=-Sb,G)|0);i=G;w=-1094995529;i=j;return w|0}}while(0);KIb(c[A>>2]|0,16,2443120,(G=i,i=i+8|0,c[G>>2]=B,G)|0);i=G;w=-1094995529;i=j;return w|0};case 34:{y=hGa(f)|0;if((y|0)<0){H=y;break a}else{w=0}i=j;return w|0};default:{KIb(c[A>>2]|0,32,2502736,(G=i,i=i+8|0,c[G>>2]=C,G)|0);i=G;w=0;i=j;return w|0}}}else{E=c[f+3472>>2]|0;F=6}}while(0);if((F|0)==6){KIb(c[f+4>>2]|0,16,2568088,(G=i,i=i+8|0,c[G>>2]=E,G)|0);i=G;H=-1094995529}w=(c[(c[f+4>>2]|0)+696>>2]&8|0)==0?0:H;i=j;return w|0}function YEa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;e=c[b+60>>2]|0;b=e;f=e+180|0;g=c[f>>2]|0;h=1<<c[g+13080>>2];j=e+184|0;k=c[j>>2]|0;l=c[(c[k+1652>>2]|0)+(c[e+3460>>2]<<2)>>2]|0;m=(a[e+2413|0]|0)==0;do{if((l|0)==0){if(m){break}KIb(c[e+4>>2]|0,16,2489640,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=d;return o|0}else{if(m){break}if((c[(c[e+7332>>2]|0)+(c[(c[k+1656>>2]|0)+(l-1<<2)>>2]<<2)>>2]|0)==(c[e+2400>>2]|0)){break}KIb(c[e+4>>2]|0,16,2478744,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=d;return o|0}}while(0);n=h-1|0;k=e+3044|0;m=e+3468|0;p=e+3048|0;q=e+3026|0;r=e+7356|0;s=0;t=0;u=l;l=g;while(1){if((u|0)>=(c[l+13112>>2]|0)){v=s;w=t;x=u;y=l;break}z=c[(c[(c[j>>2]|0)+1656>>2]|0)+(u<<2)>>2]|0;g=c[l+13080>>2]|0;A=n+(c[l+13096>>2]|0)>>g;B=((z|0)%(A|0)|0)<<g;C=((z|0)/(A|0)|0)<<g;ZEa(b,B,C,u);jFa(b,u);g=c[(c[f>>2]|0)+13080>>2]|0;_Ea(b,B>>g,C>>g);g=c[m>>2]|0;c[g+(z<<3)>>2]=c[k>>2];c[g+(z<<3)+4>>2]=c[p>>2];a[(c[r>>2]|0)+z|0]=a[q]|0;D=$Ea(b,B,C,c[(c[f>>2]|0)+13080>>2]|0,0)|0;if((D|0)<0){E=10;break}g=u+1|0;iFa(b,g);TFa(b,B,C,h);A=c[f>>2]|0;if((D|0)==0){v=B;w=C;x=g;y=A;break}else{s=B;t=C;u=g;l=A}}if((E|0)==10){c[(c[e+7332>>2]|0)+(z<<2)>>2]=-1;o=D;i=d;return o|0}if((v+h|0)<(c[y+13096>>2]|0)){o=x;i=d;return o|0}if((w+h|0)<(c[y+13100>>2]|0)){o=x;i=d;return o|0}SFa(b,v,w);o=x;i=d;return o|0}function ZEa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=c[b+136>>2]|0;h=b+180|0;i=c[h>>2]|0;j=i+13080|0;k=1<<c[j>>2];l=b+184|0;m=c[l>>2]|0;n=c[(c[m+1656>>2]|0)+(f<<2)>>2]|0;o=c[b+2400>>2]|0;p=n-o|0;q=b+7332|0;c[(c[q>>2]|0)+(n<<2)>>2]=o;do{if((a[m+43|0]|0)==0){if((a[m+42|0]|0)==0){c[g+173204>>2]=c[i+13096>>2];r=i;break}if((f|0)==0){r=i;break}o=c[m+1660>>2]|0;if((c[o+(f<<2)>>2]|0)==(c[o+(f-1<<2)>>2]|0)){r=i;break}o=c[j>>2]|0;c[g+173204>>2]=(c[(c[m+1632>>2]|0)+(c[(c[m+1648>>2]|0)+(d>>o<<2)>>2]<<2)>>2]<<o)+d;a[g+9271|0]=1;r=c[h>>2]|0}else{do{if((d|0)==0){if((k-1&e|0)!=0){s=i;break}a[g+9271|0]=1;s=c[h>>2]|0}else{s=i}}while(0);c[g+173204>>2]=c[s+13096>>2];r=s}}while(0);s=k+e|0;k=c[r+13100>>2]|0;c[g+173208>>2]=(s|0)>(k|0)?k:s;s=c[l>>2]|0;do{if((a[s+42|0]|0)==0){t=0;u=(p|0)<(c[r+13104>>2]|0);v=(p|0)<1;w=0}else{if((d|0)>0){k=c[s+1660>>2]|0;i=n-1|0;m=c[q>>2]|0;x=(c[m+(n<<2)>>2]|0)!=(c[m+(i<<2)>>2]|0);y=(c[k+(f<<2)>>2]|0)!=(c[k+(c[(c[s+1652>>2]|0)+(i<<2)>>2]<<2)>>2]|0)|0}else{x=0;y=0}if((e|0)<=0){t=y;u=0;v=x;w=0;break}i=c[s+1660>>2]|0;k=n-(c[r+13104>>2]|0)|0;m=c[q>>2]|0;t=y;u=(c[m+(n<<2)>>2]|0)!=(c[m+(k<<2)>>2]|0);v=x;w=(c[i+(f<<2)>>2]|0)!=(c[i+(c[(c[s+1652>>2]|0)+(k<<2)>>2]<<2)>>2]|0)|0}}while(0);a[g+184648|0]=t<<1|v&1;a[g+184649|0]=u&1|w<<1;u=(d|0)>0;if(u&(p|0)>0){z=(t^1)&255}else{z=0}a[g+173200|0]=z;if((e|0)<=0){a[g+173201|0]=0;a[g+173202|0]=0;A=0;B=g+173203|0;a[B]=A;return}if((p|0)<(c[(c[h>>2]|0)+13104>>2]|0)){C=0}else{C=(w^1)&255}a[g+173201|0]=C;C=c[(c[h>>2]|0)+13104>>2]|0;if((p+1|0)<(C|0)){D=0}else{w=c[l>>2]|0;e=c[w+1660>>2]|0;D=(c[e+(f<<2)>>2]|0)==(c[e+(c[(c[w+1652>>2]|0)+(n+1-C<<2)>>2]<<2)>>2]|0)|0}a[g+173202|0]=D;if(!u){A=0;B=g+173203|0;a[B]=A;return}u=c[(c[h>>2]|0)+13104>>2]|0;if((p-1|0)<(u|0)){A=0;B=g+173203|0;a[B]=A;return}p=c[l>>2]|0;l=c[p+1660>>2]|0;A=(c[l+(f<<2)>>2]|0)==(c[l+(c[(c[p+1652>>2]|0)+(n-1-u<<2)>>2]<<2)>>2]|0)|0;B=g+173203|0;a[B]=A;return}function _Ea(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=c[b+136>>2]|0;g=b+180|0;h=c[g>>2]|0;i=c[h+52>>2]|0;j=i-((i|0)>10?10:i)|0;i=(ca(c[h+13104>>2]|0,e)|0)+d|0;h=b+3464|0;k=c[h>>2]|0;if((a[b+3020|0]|0)==0){if((a[b+3021|0]|0)==0){l=0;m=0}else{n=3}}else{n=3}do{if((n|0)==3){do{if((d|0)>0){if((a[f+173200|0]|0)==0){o=0;break}o=kFa(b)|0}else{o=0}}while(0);if(!((e|0)>0&(o|0)==0)){l=o;m=0;break}if((a[f+173201|0]|0)==0){l=0;m=0;break}l=0;m=(kFa(b)|0)!=0}}while(0);f=k+(i*184|0)+181|0;o=k+(i*184|0)+182|0;p=k+(i*184|0)+112|0;q=k+(i*184|0)+116|0;r=(l|0)==0;l=r&(m^1);s=e-1|0;t=d-1|0;u=0;do{a:do{if((a[b+3020+u|0]|0)==0){a[k+(i*184|0)+180+u|0]=0}else{v=(u|0)==2;do{if(v){w=a[f]|0;a[o]=w;c[q>>2]=c[p>>2];x=w;y=k+(i*184|0)+182|0}else{if(l){w=(mFa(b)|0)&255;z=k+(i*184|0)+180+u|0;a[z]=w;x=w;y=z;break}if(!r){z=t+(ca(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;w=a[(c[h>>2]|0)+(z*184|0)+180+u|0]|0;z=k+(i*184|0)+180+u|0;a[z]=w;x=w;y=z;break}if(m){z=(ca(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;w=a[(c[h>>2]|0)+(z*184|0)+180+u|0]|0;z=k+(i*184|0)+180+u|0;a[z]=w;x=w;y=z;break}else{a[k+(i*184|0)+180+u|0]=0;break a}}}while(0);if(x<<24>>24==0){break}do{if(l){c[k+(i*184|0)+(u<<4)>>2]=oFa(b)|0;n=66}else{do{if(r){if(m){z=(ca(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+(u<<4)>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)>>2];break}else{c[k+(i*184|0)+(u<<4)>>2]=0;n=29;break}}else{z=t+(ca(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+(u<<4)>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)>>2];n=29}}while(0);if((n|0)==29){n=0;if(l){n=66;break}}if(!r){z=t+(ca(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+(u<<4)+4>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+4>>2];break}if(m){z=(ca(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+(u<<4)+4>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+4>>2];break}else{c[k+(i*184|0)+(u<<4)+4>>2]=0;break}}}while(0);if((n|0)==66){n=0;c[k+(i*184|0)+(u<<4)+4>>2]=oFa(b)|0}b:do{if(l){c[k+(i*184|0)+(u<<4)+8>>2]=oFa(b)|0;n=80}else{do{if(r){if(m){z=(ca(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+(u<<4)+8>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+8>>2]}else{c[k+(i*184|0)+(u<<4)+8>>2]=0}if(l){n=80;break b}if(!r){break}if(m){z=(ca(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+(u<<4)+12>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+12>>2];break b}else{c[k+(i*184|0)+(u<<4)+12>>2]=0;break b}}else{z=t+(ca(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+(u<<4)+8>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+8>>2]}}while(0);z=t+(ca(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+(u<<4)+12>>2]=c[(c[h>>2]|0)+(z*184|0)+(u<<4)+12>>2]}}while(0);if((n|0)==80){n=0;c[k+(i*184|0)+(u<<4)+12>>2]=oFa(b)|0}do{if((a[y]|0)==1){z=0;do{do{if((c[k+(i*184|0)+(u<<4)+(z<<2)>>2]|0)==0){c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=0}else{if(l){c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=pFa(b)|0;break}if(!r){w=t+(ca(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=c[(c[h>>2]|0)+(w*184|0)+48+(u<<4)+(z<<2)>>2];break}if(m){w=(ca(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=c[(c[h>>2]|0)+(w*184|0)+48+(u<<4)+(z<<2)>>2];break}else{c[k+(i*184|0)+48+(u<<4)+(z<<2)>>2]=0;break}}}while(0);z=z+1|0;}while((z|0)<4);if(l){c[k+(i*184|0)+96+(u<<2)>>2]=nFa(b)|0;break}if(!r){z=t+(ca(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+96+(u<<2)>>2]=c[(c[h>>2]|0)+(z*184|0)+96+(u<<2)>>2];break}if(m){z=(ca(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+96+(u<<2)>>2]=c[(c[h>>2]|0)+(z*184|0)+96+(u<<2)>>2];break}else{c[k+(i*184|0)+96+(u<<2)>>2]=0;break}}else{if(v){break}if(l){c[k+(i*184|0)+108+(u<<2)>>2]=qFa(b)|0;break}if(!r){z=t+(ca(c[(c[g>>2]|0)+13104>>2]|0,e)|0)|0;c[k+(i*184|0)+108+(u<<2)>>2]=c[(c[h>>2]|0)+(z*184|0)+108+(u<<2)>>2];break}if(m){z=(ca(c[(c[g>>2]|0)+13104>>2]|0,s)|0)+d|0;c[k+(i*184|0)+108+(u<<2)>>2]=c[(c[h>>2]|0)+(z*184|0)+108+(u<<2)>>2];break}else{c[k+(i*184|0)+108+(u<<2)>>2]=0;break}}}while(0);c[k+(i*184|0)+120+(u*20|0)>>2]=0;v=c[k+(i*184|0)+(u<<4)>>2]<<j;z=k+(i*184|0)+120+(u*20|0)+4|0;c[z>>2]=v;do{if((a[y]|0)!=2){if((c[k+(i*184|0)+48+(u<<4)>>2]|0)==0){break}c[z>>2]=-v}}while(0);v=c[k+(i*184|0)+(u<<4)+4>>2]<<j;z=k+(i*184|0)+120+(u*20|0)+8|0;c[z>>2]=v;do{if((a[y]|0)!=2){if((c[k+(i*184|0)+48+(u<<4)+4>>2]|0)==0){break}c[z>>2]=-v}}while(0);v=c[k+(i*184|0)+(u<<4)+8>>2]<<j;z=k+(i*184|0)+120+(u*20|0)+12|0;c[z>>2]=v;do{if((a[y]|0)==2){c[z>>2]=-v}else{if((c[k+(i*184|0)+48+(u<<4)+8>>2]|0)==0){break}c[z>>2]=-v}}while(0);v=c[k+(i*184|0)+(u<<4)+12>>2]<<j;z=k+(i*184|0)+120+(u*20|0)+16|0;c[z>>2]=v;if((a[y]|0)==2){c[z>>2]=-v;break}if((c[k+(i*184|0)+48+(u<<4)+12>>2]|0)==0){break}c[z>>2]=-v}}while(0);u=u+1|0;}while((u|0)<3);return}function $Ea(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;j=i;i=i+48|0;k=j|0;l=j+16|0;m=j+24|0;n=b+136|0;o=c[n>>2]|0;p=1<<g;q=b+180|0;r=c[q>>2]|0;s=b+184|0;t=(1<<(c[r+13080>>2]|0)-(c[(c[s>>2]|0)+24>>2]|0))-1|0;c[o+184576>>2]=h;u=p+e|0;v=c[r+13096>>2]|0;do{if((u|0)>(v|0)){w=5}else{if((p+f|0)>(c[r+13100>>2]|0)){w=5;break}if(!((c[r+13064>>2]|0)>>>0<g>>>0)){w=5;break}x=(xFa(b,h,e,f)|0)&255;z=(ca(c[(c[q>>2]|0)+13096>>2]|0,f)|0)+e|0;a[(c[b+7320>>2]|0)+z|0]=x}}while(0);if((w|0)==5){x=(ca(v,f)|0)+e|0;a[(c[b+7320>>2]|0)+x|0]=(c[r+13064>>2]|0)>>>0<g>>>0|0}r=c[s>>2]|0;do{if((a[r+22|0]|0)!=0){if(((c[(c[q>>2]|0)+13080>>2]|0)-(c[r+24>>2]|0)|0)>>>0>g>>>0){break}a[o+173196|0]=0;c[o+173188>>2]=0}}while(0);r=c[q>>2]|0;x=(ca(c[r+13096>>2]|0,f)|0)+e|0;if((a[(c[b+7320>>2]|0)+x|0]|0)!=0){x=p>>1;v=x+e|0;z=x+f|0;A=g-1|0;B=h+1|0;h=$Ea(b,e,f,A,B)|0;if((h|0)<0){C=h;i=j;return C|0}do{if((h|0)==0){D=0}else{do{if((v|0)<(c[(c[q>>2]|0)+13096>>2]|0)){E=$Ea(b,v,f,A,B)|0;if((E|0)<0){C=E}else{F=E;break}i=j;return C|0}else{F=h}}while(0);if((F|0)==0){D=0;break}do{if((z|0)<(c[(c[q>>2]|0)+13100>>2]|0)){E=$Ea(b,e,z,A,B)|0;if((E|0)<0){C=E}else{G=E;break}i=j;return C|0}else{G=F}}while(0);if((G|0)==0){D=0;break}E=c[q>>2]|0;if((v|0)>=(c[E+13096>>2]|0)){D=G;break}if((z|0)>=(c[E+13100>>2]|0)){D=G;break}E=$Ea(b,v,z,A,B)|0;if((E|0)<0){C=E}else{D=E;break}i=j;return C|0}}while(0);do{if((t&u|0)==0){if((t&p+f|0)!=0){break}c[o+173184>>2]=a[o+173182|0]|0}}while(0);if((D|0)==0){C=0;i=j;return C|0}D=c[q>>2]|0;if((v+x|0)<(c[D+13096>>2]|0)){C=1;i=j;return C|0}C=(z+x|0)<(c[D+13100>>2]|0)|0;i=j;return C|0}D=c[n>>2]|0;x=c[r+13064>>2]|0;z=c[r+13116>>2]|0;v=e>>x;o=f>>x;t=1<<(c[r+13080>>2]|0)-(c[(c[s>>2]|0)+24>>2]|0);c[D+184580>>2]=e;c[D+184584>>2]=f;r=D+184596|0;a[r]=1;B=D+184588|0;c[B>>2]=1;A=D+184592|0;c[A>>2]=0;G=D+184598|0;a[G]=0;F=D+184597|0;a[F]=0;h=(ca(o,z)|0)+v|0;E=b+7336|0;a[(c[E>>2]|0)+h|0]=0;H=D+184612|0;y=16843009;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=p>>x;x=t-1|0;do{if((a[(c[s>>2]|0)+40|0]|0)==0){a[D+184600|0]=0}else{t=(sFa(b)|0)&255;a[D+184600|0]=t;if(t<<24>>24==0){break}t=c[q>>2]|0;I=c[t+13084>>2]|0;J=c[t+13132>>2]|0;K=c[t+13096>>2]|0;L=p+f|0;M=c[t+13100>>2]|0;t=f>>I;N=((L|0)>(M|0)?M:L)>>I;if((t|0)>=(N|0)){break}L=e>>I;M=((u|0)>(K|0)?K:u)>>I;I=(L|0)<(M|0);K=b+7352|0;O=t;do{if(I){t=ca(O,J)|0;P=L;do{a[(c[K>>2]|0)+(P+t)|0]=2;P=P+1|0;}while((P|0)<(M|0))}O=O+1|0;}while((O|0)<(N|0))}}while(0);N=b+2404|0;if((c[N>>2]|0)!=2){O=tFa(b,e,f,v,o)|0;o=O&255;c[B>>2]=2;if((H|0)>0){v=0;M=h;while(1){mrc((c[E>>2]|0)+M|0,o|0,H|0)|0;K=v+1|0;if((K|0)<(H|0)){v=K;M=M+z|0}else{break}}}c[B>>2]=(O&255|0)!=0?2:0}do{if((a[(c[E>>2]|0)+h|0]|0)==0){if((c[N>>2]|0)==2){Q=c[B>>2]|0}else{O=wFa(b)|0;c[B>>2]=O;Q=O}do{if((Q|0)==1){if((c[(c[q>>2]|0)+13064>>2]|0)==(g|0)){w=54;break}R=c[A>>2]|0;w=57}else{w=54}}while(0);a:do{if((w|0)==54){O=yFa(b,g)|0;c[A>>2]=O;M=c[B>>2]|0;if((O|0)==3){S=(M|0)==1|0}else{S=0}a[G]=S;if((M|0)==1){R=O;w=57;break}M=c[q>>2]|0;v=c[M+13084>>2]|0;o=p>>v;K=c[M+13132>>2]|0;M=c[(c[b+3480>>2]|0)+16>>2]|0;L=e>>v;J=f>>v;v=(o|0)==0?1:o;if((v|0)>0){o=b+7344|0;I=(c[n>>2]|0)+184588|0;P=0;do{t=(ca(P+J|0,K)|0)+L|0;mrc((c[o>>2]|0)+t|0,1,v|0)|0;T=0;do{a[M+((T+t|0)*14|0)+12|0]=(c[I>>2]|0)==1|0;T=T+1|0;}while((T|0)<(v|0));P=P+1|0;}while((P|0)<(v|0));U=c[A>>2]|0}else{U=O}switch(U|0){case 0:{aFa(b,e,f,p,p,g,0);break a;break};case 1:{v=(p|0)/2|0;aFa(b,e,f,p,v,g,0);aFa(b,e,v+f|0,p,v,g,1);break a;break};case 6:{v=(p|0)/4|0;aFa(b,e,f,v,p,g,0);aFa(b,v+e|0,f,(3<<g|0)/4|0,p,g,1);break a;break};case 7:{v=(3<<g|0)/4|0;aFa(b,e,f,v,p,g,0);aFa(b,v+e|0,f,(p|0)/4|0,p,g,1);break a;break};case 3:{v=(p|0)/2|0;aFa(b,e,f,v,v,g,0);P=v+e|0;aFa(b,P,f,v,v,g,1);I=v+f|0;aFa(b,e,I,v,v,g,2);aFa(b,P,I,v,v,g,3);break a;break};case 2:{v=(p|0)/2|0;aFa(b,e,f,v,p,g,0);aFa(b,v+e|0,f,v,p,g,1);break a;break};case 4:{v=(p|0)/4|0;aFa(b,e,f,p,v,g,0);aFa(b,e,v+f|0,p,(3<<g|0)/4|0,g,1);break a;break};case 5:{v=(3<<g|0)/4|0;aFa(b,e,f,p,v,g,0);aFa(b,e,v+f|0,p,(p|0)/4|0,g,1);break a;break};default:{break a}}}}while(0);do{if((w|0)==57){do{if((R|0)==0){v=c[q>>2]|0;if((c[v+68>>2]|0)==0){w=62;break}if((c[v+13048>>2]|0)>>>0>g>>>0){w=62;break}if((c[v+13052>>2]|0)>>>0<g>>>0){w=62;break}v=(zFa(b)|0)&255;a[F]=v;V=v}else{w=62}}while(0);if((w|0)==62){V=a[F]|0}if(!(V<<24>>24==0)){O=c[q>>2]|0;v=c[O+13084>>2]|0;I=p>>v;P=c[O+13132>>2]|0;M=c[(c[b+3480>>2]|0)+16>>2]|0;o=e>>v;L=f>>v;v=(I|0)==0?1:I;if((v|0)>0){I=b+7344|0;K=(c[n>>2]|0)+184588|0;J=0;do{T=(ca(J+L|0,P)|0)+o|0;mrc((c[I>>2]|0)+T|0,1,v|0)|0;t=0;do{a[M+((t+T|0)*14|0)+12|0]=(c[K>>2]|0)==1|0;t=t+1|0;}while((t|0)<(v|0));J=J+1|0;}while((J|0)<(v|0));W=c[q>>2]|0}else{W=O}v=c[n>>2]|0;J=c[b+160>>2]|0;K=c[J+32>>2]|0;M=c[W+56>>2]|0;I=c[J>>2]|0;o=c[J+36>>2]|0;P=c[W+13156>>2]|0;L=c[W+13144>>2]|0;t=c[J+4>>2]|0;T=c[J+40>>2]|0;X=c[W+13160>>2]|0;Y=c[W+13148>>2]|0;Z=c[J+8>>2]|0;J=p<<g;_=ca(d[W+13044|0]|0,J)|0;$=(ca(d[W+13045|0]|0,J>>1)|0)+_|0;_=v+9292|0;J=$+7>>3;aa=c[v+9308>>2]|0;ba=c[_>>2]|0;da=(ba&1|0)==0?aa:aa-1|0;aa=(ba&511|0)==0?da:da-1|0;da=(c[v+9312>>2]|0)-aa|0;if((da|0)<(J|0)){ea=0}else{Hmb(_,aa+J|0,da-J|0);ea=aa}QFa(b,e,f,g,d[v+184649|0]|0,d[v+184648|0]|0);v=$>>>0>2147483639>>>0|(ea|0)==0;aa=v?0:ea;J=v?0:$;c[m>>2]=aa;c[m+12>>2]=J;c[m+16>>2]=J+8;c[m+4>>2]=aa+(J+7>>3);c[m+8>>2]=0;if(v){fa=v?-1094995529:0}else{v=Z+((e>>Y<<M)+(ca(f>>X,T)|0))|0;X=t+((e>>L<<M)+(ca(f>>P,o)|0))|0;P=I+((e<<M)+(ca(K,f)|0))|0;M=b+5860|0;pe[c[M>>2]&1023](P,K,p,m,d[(c[q>>2]|0)+13044|0]|0);K=(p|0)/2|0;pe[c[M>>2]&1023](X,o,K,m,d[(c[q>>2]|0)+13045|0]|0);pe[c[M>>2]&1023](v,T,K,m,d[(c[q>>2]|0)+13045|0]|0);fa=0}K=c[q>>2]|0;do{if((a[K+13056|0]|0)!=0){T=c[K+13084>>2]|0;v=c[K+13132>>2]|0;M=c[K+13096>>2]|0;o=p+f|0;X=c[K+13100>>2]|0;P=f>>T;I=((o|0)>(X|0)?X:o)>>T;if((P|0)>=(I|0)){break}o=e>>T;X=((u|0)>(M|0)?M:u)>>T;T=(o|0)<(X|0);M=b+7352|0;L=P;do{if(T){P=ca(L,v)|0;t=o;do{a[(c[M>>2]|0)+(t+P)|0]=2;t=t+1|0;}while((t|0)<(X|0))}L=L+1|0;}while((L|0)<(I|0))}}while(0);if((fa|0)<0){C=fa}else{break}i=j;return C|0}K=c[n>>2]|0;O=(c[K+184592>>2]|0)==3;I=O?2:1;L=0;do{X=L<<1;M=0;do{a[l+(M+X)|0]=AFa(b)|0;M=M+1|0;}while((M|0)<(I|0));L=L+1|0;}while((L|0)<(I|0));L=p>>(O&1);M=K+184608|0;X=b+3480|0;o=k|0;v=k+4|0;T=k+8|0;t=b+7344|0;P=K+184604|0;Y=0;do{Z=Y<<1;J=(ca(Y,L)|0)+f|0;aa=J-1|0;$=0;do{da=$+Z|0;_=(a[l+da|0]|0)==0;if(_){c[M>>2]=CFa(b)|0}else{c[P>>2]=BFa(b)|0}ba=(ca($,L)|0)+e|0;ga=c[n>>2]|0;ha=c[q>>2]|0;ia=c[ha+13084>>2]|0;ja=ba>>ia;ka=J>>ia;la=c[ha+13132>>2]|0;ma=L>>ia;ia=c[ha+13080>>2]|0;ha=(1<<ia)-1|0;na=ha&ba;if((a[ga+173201|0]|0)==0){if((ha&J|0)==0){oa=1}else{w=93}}else{w=93}if((w|0)==93){w=0;ha=(ca(ka-1|0,la)|0)+ja|0;oa=d[(c[t>>2]|0)+ha|0]|0}if((a[ga+173200|0]|0)==0&(na|0)==0){pa=1}else{na=ja-1+(ca(ka,la)|0)|0;pa=d[(c[t>>2]|0)+na|0]|0}na=c[(c[X>>2]|0)+16>>2]|0;ha=(aa|0)<(J>>ia<<ia|0)?1:oa;do{if((pa|0)==(ha|0)){if(pa>>>0<2>>>0){c[o>>2]=0;c[v>>2]=1;c[T>>2]=26;qa=0;ra=1;sa=26;break}else{c[o>>2]=pa;ia=(pa+29&31)+2|0;c[v>>2]=ia;ba=(pa+31&31)+2|0;c[T>>2]=ba;qa=pa;ra=ia;sa=ba;break}}else{c[o>>2]=pa;c[v>>2]=ha;if(!((pa|0)==0|(ha|0)==0)){c[T>>2]=0;qa=pa;ra=ha;sa=0;break}if((pa|0)==1|(ha|0)==1){c[T>>2]=26;qa=pa;ra=ha;sa=26;break}else{c[T>>2]=1;qa=pa;ra=ha;sa=1;break}}}while(0);if(_){if((qa|0)>(ra|0)){c[v>>2]=qa;ha=ra&255;c[o>>2]=ha;ta=ha;ua=qa}else{ta=qa;ua=ra}if((ta|0)>(sa|0)){c[T>>2]=ta;ha=sa&255;c[o>>2]=ha;va=ta;wa=ha}else{va=sa;wa=ta}if((ua|0)>(va|0)){c[T>>2]=ua;ha=va&255;c[v>>2]=ha;xa=ha;ya=ua}else{xa=ua;ya=va}ha=c[ga+184608>>2]|0;ba=((ha|0)>=(wa|0))+ha|0;ha=((ba|0)>=(xa|0))+ba|0;za=((ha|0)>=(ya|0))+ha&255}else{za=c[k+(c[ga+184604>>2]<<2)>>2]&255}ha=(ma|0)==0?1:ma;if((ha|0)>0){ba=0;do{ia=(ca(ba+ka|0,la)|0)+ja|0;mrc((c[t>>2]|0)+ia|0,za|0,ha|0)|0;ia=ba+ja|0;Aa=0;do{Ba=ia+(ca(Aa+ka|0,la)|0)|0;a[na+(Ba*14|0)+12|0]=1;Aa=Aa+1|0;mrc(na+(Ba*14|0)|0,0,12)|0}while((Aa|0)<(ha|0));ba=ba+1|0;}while((ba|0)<(ha|0))}a[K+184612+da|0]=za;$=$+1|0;}while(($|0)<(I|0));Y=Y+1|0;}while((Y|0)<(I|0));I=DFa(b)|0;Y=a[K+184612|0]|0;if((I|0)==4){a[K+184621|0]=Y;break}t=a[1064472+I|0]|0;I=K+184621|0;if(Y<<24>>24==t<<24>>24){a[I]=34;break}else{a[I]=t;break}}}while(0);if((a[F]|0)!=0){break}do{if((c[B>>2]|0)==1){w=145}else{if((c[A>>2]|0)==0){if((a[D+184620|0]|0)!=0){w=145;break}}t=(JFa(b)|0)&255;a[r]=t;Ca=t}}while(0);if((w|0)==145){Ca=a[r]|0}if(Ca<<24>>24==0){if((a[b+3025|0]|0)!=0){break}QFa(b,e,f,g,d[D+184649|0]|0,d[D+184648|0]|0);break}t=c[q>>2]|0;if((c[B>>2]|0)==1){Da=(d[G]|0)+(c[t+13092>>2]|0)&255}else{Da=c[t+13088>>2]&255}a[D+184599|0]=Da;t=bFa(b,e,f,e,f,e,f,g,g,0,0)|0;if((t|0)<0){C=t}else{break}i=j;return C|0}else{aFa(b,e,f,p,p,g,0);t=c[q>>2]|0;I=c[t+13084>>2]|0;Y=p>>I;v=c[t+13132>>2]|0;t=c[(c[b+3480>>2]|0)+16>>2]|0;T=e>>I;o=f>>I;I=(Y|0)==0?1:Y;if((I|0)>0){Y=b+7344|0;X=(c[n>>2]|0)+184588|0;L=0;do{P=(ca(L+o|0,v)|0)+T|0;mrc((c[Y>>2]|0)+P|0,1,I|0)|0;M=0;do{a[t+((M+P|0)*14|0)+12|0]=(c[X>>2]|0)==1|0;M=M+1|0;}while((M|0)<(I|0));L=L+1|0;}while((L|0)<(I|0))}if((a[b+3025|0]|0)!=0){break}QFa(b,e,f,g,d[D+184649|0]|0,d[D+184648|0]|0)}}while(0);do{if((a[(c[s>>2]|0)+22|0]|0)!=0){if((a[D+173196|0]|0)!=0){break}PFa(b,e,f,e,f,g)}}while(0);if((H|0)>0){g=b+7316|0;s=D+173182|0;n=0;Da=h;while(1){mrc((c[g>>2]|0)+Da|0,a[s]|0,H|0)|0;h=n+1|0;if((h|0)<(H|0)){n=h;Da=Da+z|0}else{break}}}do{if((x&u|0)==0){if((x&p+f|0)!=0){break}c[D+173184>>2]=a[D+173182|0]|0}}while(0);x=c[q>>2]|0;z=c[x+13064>>2]|0;Da=p>>z;n=e>>z;e=f>>z;do{if((Da|0)>0){z=b+7340|0;H=c[D+184576>>2]&255;s=(ca(c[x+13116>>2]|0,e)|0)+n|0;mrc((c[z>>2]|0)+s|0,H|0,Da|0)|0;if((Da|0)>1){Ea=1}else{break}do{s=(ca(c[(c[q>>2]|0)+13116>>2]|0,Ea+e|0)|0)+n|0;mrc((c[z>>2]|0)+s|0,H|0,Da|0)|0;Ea=Ea+1|0;}while((Ea|0)<(Da|0))}}while(0);Da=c[q>>2]|0;q=1<<c[Da+13080>>2];do{if(((u|0)%(q|0)|0|0)!=0){if((u|0)<(c[Da+13096>>2]|0)){C=1}else{break}i=j;return C|0}}while(0);u=p+f|0;do{if(((u|0)%(q|0)|0|0)!=0){if((u|0)<(c[Da+13100>>2]|0)){C=1}else{break}i=j;return C|0}}while(0);C=(rFa(b)|0)==0|0;i=j;return C|0}function aFa(d,e,f,g,h,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;l=i;i=i+65552|0;m=l|0;n=l+16|0;o=l+8208|0;p=l+16400|0;q=l+24592|0;r=l+32784|0;s=l+40976|0;t=l+49168|0;u=l+57360|0;v=c[d+136>>2]|0;w=m;b[w>>1]=b[545896]|0;b[w+2>>1]=b[545897]|0;b[w+4>>1]=b[545898]|0;b[w+6>>1]=b[545899]|0;b[w+8>>1]=b[545900]|0;b[w+10>>1]=b[545901]|0;b[w+12>>1]=b[545902]|0;x=d+180|0;y=c[x>>2]|0;z=c[y+13132>>2]|0;A=c[d+3480>>2]|0;B=c[A+16>>2]|0;C=c[A+20>>2]|0;A=d+160|0;D=c[A>>2]|0;E=ca(c[D+32>>2]|0,f>>c[y+13152>>2])|0;F=c[y+56>>2]|0;G=(c[D>>2]|0)+((e>>c[y+13140>>2]<<F)+E)|0;E=ca(f>>c[y+13156>>2],c[D+36>>2]|0)|0;H=(c[D+4>>2]|0)+((e>>c[y+13144>>2]<<F)+E)|0;E=ca(f>>c[y+13160>>2],c[D+40>>2]|0)|0;I=(c[D+8>>2]|0)+((e>>c[y+13148>>2]<<F)+E)|0;E=c[y+13064>>2]|0;F=(ca(f>>E,c[y+13116>>2]|0)|0)+(e>>E)|0;a:do{if((a[(c[d+7336>>2]|0)+F|0]|0)==0){E=(FFa(d)|0)&255;a[v+184620|0]=E;if(!(E<<24>>24==0)){if((c[d+3052>>2]|0)>>>0>1>>>0){J=EFa(d)|0}else{J=0}VFa(d,e,f,g,h,j,k,J,m);E=c[(c[x>>2]|0)+13084>>2]|0;y=e>>E;D=f>>E;if((g>>E|0)>0){K=0;L=E}else{break}while(1){if((h>>L|0)>0){E=K+y|0;M=0;while(1){N=B+((E+(ca(M+D|0,z)|0)|0)*14|0)|0;b[N>>1]=b[w>>1]|0;b[N+2>>1]=b[w+2>>1]|0;b[N+4>>1]=b[w+4>>1]|0;b[N+6>>1]=b[w+6>>1]|0;b[N+8>>1]=b[w+8>>1]|0;b[N+10>>1]=b[w+10>>1]|0;b[N+12>>1]=b[w+12>>1]|0;N=M+1|0;O=c[(c[x>>2]|0)+13084>>2]|0;if((N|0)<(h>>O|0)){M=N}else{P=O;break}}}else{P=L}M=K+1|0;if((M|0)<(g>>P|0)){K=M;L=P}else{break a}}}UFa(d,e,f,g,h);if((c[d+2404>>2]|0)==0){D=GFa(d,g,h)|0;if((D|0)==1){Q=1;R=22}else{S=D;R=19}}else{S=0;R=19}if((R|0)==19){D=c[d+3012>>2]|0;if((D|0)!=0){a[m+8|0]=HFa(d,D)|0}a[m+10|0]=1;OFa(d,e,f,0);WFa(d,e,f,g,h,j,k,0,m,IFa(d)|0,0);D=m|0;b[D>>1]=(b[D>>1]|0)+(b[v+184616>>1]|0);D=m+2|0;b[D>>1]=(b[D>>1]|0)+(b[v+184618>>1]|0);if((S|0)!=0){Q=S;R=22}}if((R|0)==22){D=c[d+3016>>2]|0;if((D|0)!=0){a[m+9|0]=HFa(d,D)|0}if((a[d+3023|0]|0)==1&(Q|0)==2){D=v+184616|0;b[D>>1]=0;y=v+184618|0;b[y>>1]=0;T=D;U=y}else{OFa(d,e,f,1);T=v+184616|0;U=v+184618|0}a[m+11|0]=1;WFa(d,e,f,g,h,j,k,0,m,IFa(d)|0,1);y=m+4|0;b[y>>1]=(b[y>>1]|0)+(b[T>>1]|0);y=m+6|0;b[y>>1]=(b[y>>1]|0)+(b[U>>1]|0)}y=c[(c[x>>2]|0)+13084>>2]|0;D=e>>y;M=f>>y;if((g>>y|0)>0){V=0;W=y}else{break}while(1){if((h>>W|0)>0){y=V+D|0;E=0;while(1){O=B+((y+(ca(E+M|0,z)|0)|0)*14|0)|0;b[O>>1]=b[w>>1]|0;b[O+2>>1]=b[w+2>>1]|0;b[O+4>>1]=b[w+4>>1]|0;b[O+6>>1]=b[w+6>>1]|0;b[O+8>>1]=b[w+8>>1]|0;b[O+10>>1]=b[w+10>>1]|0;b[O+12>>1]=b[w+12>>1]|0;O=E+1|0;N=c[(c[x>>2]|0)+13084>>2]|0;if((O|0)<(h>>N|0)){E=O}else{X=N;break}}}else{X=W}E=V+1|0;if((E|0)<(g>>X|0)){V=E;W=X}else{break}}}else{if((c[d+3052>>2]|0)>>>0>1>>>0){Y=EFa(d)|0}else{Y=0}M=1<<j;VFa(d,e,f,M,M,j,k,Y,m);M=c[(c[x>>2]|0)+13084>>2]|0;D=e>>M;E=f>>M;if((g>>M|0)>0){Z=0;_=M}else{break}while(1){if((h>>_|0)>0){M=Z+D|0;y=0;while(1){N=B+((M+(ca(y+E|0,z)|0)|0)*14|0)|0;b[N>>1]=b[w>>1]|0;b[N+2>>1]=b[w+2>>1]|0;b[N+4>>1]=b[w+4>>1]|0;b[N+6>>1]=b[w+6>>1]|0;b[N+8>>1]=b[w+8>>1]|0;b[N+10>>1]=b[w+10>>1]|0;b[N+12>>1]=b[w+12>>1]|0;N=y+1|0;O=c[(c[x>>2]|0)+13084>>2]|0;if((N|0)<(h>>O|0)){y=N}else{$=O;break}}}else{$=_}y=Z+1|0;if((y|0)<(g>>$|0)){Z=y;_=$}else{break}}}}while(0);$=m+10|0;do{if((a[$]|0)==0){aa=0}else{_=c[C+(a[m+8|0]<<2)>>2]|0;if((_|0)==0){i=l;return}if((a[d+140|0]|0)!=1){aa=_;break}M5a(_+4|0,f+9+h+(b[m+2>>1]>>2)|0,0);aa=_}}while(0);_=m+11|0;do{if((a[_]|0)==0){ba=0}else{Z=c[C+196+(a[m+9|0]<<2)>>2]|0;if((Z|0)==0){i=l;return}if((a[d+140|0]|0)!=1){ba=Z;break}M5a(Z+4|0,f+9+h+(b[m+6>>1]>>2)|0,0);ba=Z}}while(0);Z=(a[_]|0)==0;if((a[$]|0)==0){if(Z|(ba|0)==0){i=l;return}$=p|0;p=ba|0;ba=c[p>>2]|0;_=m+4|0;x=m+6|0;cFa(d,$,c[ba>>2]|0,c[ba+32>>2]|0,b[_>>1]|0,b[x>>1]|0,e,f,g,h);ba=d+2404|0;w=c[ba>>2]|0;if((w|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=58}else{R=57}}else if((w|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=58}else{R=57}}else{R=58}if((R|0)==57){w=a[m+9|0]|0;Te[c[d+6024>>2]&255](a[d+3073|0]|0,b[d+3236+(w<<1)>>1]|0,b[d+3364+(w<<1)>>1]|0,G,c[(c[A>>2]|0)+32>>2]|0,$,64,g,h)}else if((R|0)==58){_e[c[d+6016>>2]&511](G,c[(c[A>>2]|0)+32>>2]|0,$,64,g,h)}w=q|0;q=(g|0)/2|0;z=(h|0)/2|0;dFa(d,$,w,c[p>>2]|0,b[_>>1]|0,b[x>>1]|0,(e|0)/2|0,(f|0)/2|0,q,z);x=c[ba>>2]|0;if((x|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=63}else{R=62}}else if((x|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=63}else{R=62}}else{R=63}if((R|0)==62){x=d+6024|0;ba=d+3074|0;_=m+9|0;p=a[_]|0;Te[c[x>>2]&255](b[ba>>1]&255,b[d+3172+(p<<2)>>1]|0,b[d+3396+(p<<2)>>1]|0,H,c[(c[A>>2]|0)+36>>2]|0,$,64,q,z);p=a[_]|0;Te[c[x>>2]&255](b[ba>>1]&255,b[d+3172+(p<<2)+2>>1]|0,b[d+3396+(p<<2)+2>>1]|0,I,c[(c[A>>2]|0)+40>>2]|0,w,64,q,z);i=l;return}else if((R|0)==63){p=d+6016|0;_e[c[p>>2]&511](H,c[(c[A>>2]|0)+36>>2]|0,$,64,q,z);_e[c[p>>2]&511](I,c[(c[A>>2]|0)+40>>2]|0,w,64,q,z);i=l;return}}if(Z){Z=n|0;n=aa|0;aa=c[n>>2]|0;z=m|0;q=m+2|0;cFa(d,Z,c[aa>>2]|0,c[aa+32>>2]|0,b[z>>1]|0,b[q>>1]|0,e,f,g,h);aa=d+2404|0;w=c[aa>>2]|0;if((w|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=47}else{R=46}}else if((w|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=47}else{R=46}}else{R=47}if((R|0)==46){w=a[m+8|0]|0;Te[c[d+6024>>2]&255](a[d+3073|0]|0,b[d+3076+(w<<1)>>1]|0,b[d+3268+(w<<1)>>1]|0,G,c[(c[A>>2]|0)+32>>2]|0,Z,64,g,h)}else if((R|0)==47){_e[c[d+6016>>2]&511](G,c[(c[A>>2]|0)+32>>2]|0,Z,64,g,h)}w=o|0;o=(g|0)/2|0;p=(h|0)/2|0;dFa(d,Z,w,c[n>>2]|0,b[z>>1]|0,b[q>>1]|0,(e|0)/2|0,(f|0)/2|0,o,p);q=c[aa>>2]|0;if((q|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=52}else{R=51}}else if((q|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=52}else{R=51}}else{R=52}if((R|0)==51){q=d+6024|0;aa=d+3074|0;z=m+8|0;n=a[z]|0;Te[c[q>>2]&255](b[aa>>1]&255,b[d+3108+(n<<2)>>1]|0,b[d+3300+(n<<2)>>1]|0,H,c[(c[A>>2]|0)+36>>2]|0,Z,64,o,p);n=a[z]|0;Te[c[q>>2]&255](b[aa>>1]&255,b[d+3108+(n<<2)+2>>1]|0,b[d+3300+(n<<2)+2>>1]|0,I,c[(c[A>>2]|0)+40>>2]|0,w,64,o,p);i=l;return}else if((R|0)==52){n=d+6016|0;_e[c[n>>2]&511](H,c[(c[A>>2]|0)+36>>2]|0,Z,64,o,p);_e[c[n>>2]&511](I,c[(c[A>>2]|0)+40>>2]|0,w,64,o,p);i=l;return}}p=m+8|0;o=c[C+(a[p]<<2)>>2]|0;w=m+9|0;n=c[C+196+(a[w]<<2)>>2]|0;if((o|0)==0|(n|0)==0){i=l;return}C=r|0;r=o|0;o=c[r>>2]|0;Z=m|0;aa=m+2|0;cFa(d,C,c[o>>2]|0,c[o+32>>2]|0,b[Z>>1]|0,b[aa>>1]|0,e,f,g,h);o=s|0;s=n|0;n=c[s>>2]|0;q=m+4|0;z=m+6|0;cFa(d,o,c[n>>2]|0,c[n+32>>2]|0,b[q>>1]|0,b[z>>1]|0,e,f,g,h);n=d+2404|0;m=c[n>>2]|0;if((m|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=69}else{R=68}}else if((m|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=69}else{R=68}}else{R=69}if((R|0)==68){m=a[p]|0;$=a[w]|0;af[c[d+6028>>2]&127](a[d+3073|0]|0,b[d+3076+(m<<1)>>1]|0,b[d+3236+($<<1)>>1]|0,b[d+3268+(m<<1)>>1]|0,b[d+3364+($<<1)>>1]|0,G,c[(c[A>>2]|0)+32>>2]|0,C,o,64,g,h)}else if((R|0)==69){Se[c[d+6020>>2]&1023](G,c[(c[A>>2]|0)+32>>2]|0,C,o,64,g,h)}G=(e|0)/2|0;e=(f|0)/2|0;f=(g|0)/2|0;g=(h|0)/2|0;dFa(d,C,o,c[r>>2]|0,b[Z>>1]|0,b[aa>>1]|0,G,e,f,g);aa=t|0;t=u|0;dFa(d,aa,t,c[s>>2]|0,b[q>>1]|0,b[z>>1]|0,G,e,f,g);e=c[n>>2]|0;if((e|0)==1){if((a[(c[d+184>>2]|0)+37|0]|0)==0){R=74}else{R=73}}else if((e|0)==0){if((a[(c[d+184>>2]|0)+38|0]|0)==0){R=74}else{R=73}}else{R=74}if((R|0)==73){e=d+6028|0;n=d+3074|0;G=a[p]|0;z=a[w]|0;af[c[e>>2]&127](b[n>>1]&255,b[d+3108+(G<<2)>>1]|0,b[d+3172+(z<<2)>>1]|0,b[d+3300+(G<<2)>>1]|0,b[d+3396+(z<<2)>>1]|0,H,c[(c[A>>2]|0)+36>>2]|0,C,aa,64,f,g);z=a[p]|0;p=a[w]|0;af[c[e>>2]&127](b[n>>1]&255,b[d+3108+(z<<2)+2>>1]|0,b[d+3172+(p<<2)+2>>1]|0,b[d+3300+(z<<2)+2>>1]|0,b[d+3396+(p<<2)+2>>1]|0,I,c[(c[A>>2]|0)+40>>2]|0,o,t,64,f,g);i=l;return}else if((R|0)==74){R=d+6020|0;Se[c[R>>2]&1023](H,c[(c[A>>2]|0)+36>>2]|0,C,aa,64,f,g);Se[c[R>>2]&1023](I,c[(c[A>>2]|0)+40>>2]|0,o,t,64,f,g);i=l;return}}function bFa(b,e,f,g,h,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;p=i;q=b+136|0;r=c[q>>2]|0;s=1<<m;t=s-1|0;if((n|0)>0&(m|0)==2){u=((t&h)<<7)+(t&g)|0;v=n-1|0;w=((t&f)<<7)+(t&e)|0;a[r+9340+(n<<14)+w|0]=a[r+9340+(v<<14)+u|0]|0;a[r+91260+(n<<14)+w|0]=a[r+91260+(v<<14)+u|0]|0}else{u=((t&f)<<7)+(t&e)|0;a[r+91260+(n<<14)+u|0]=0;a[r+9340+(n<<14)+u|0]=0}u=a[r+184598|0]|0;do{if(u<<24>>24==0){c[r+173192>>2]=d[r+184612|0]|0}else{if((n|0)!=1){break}c[r+173192>>2]=d[r+184612+o|0]|0}}while(0);v=r+173180|0;a[v]=1;w=b+180|0;do{if((c[(c[w>>2]|0)+13088>>2]|0)==0){if((c[r+184588>>2]|0)!=0){x=0;break}if((c[r+184592>>2]|0)==0){x=0;break}x=(n|0)==0|0}else{x=0}}while(0);a[r+173181|0]=x;y=c[w>>2]|0;z=(c[y+13076>>2]|0)>>>0<m>>>0;a:do{if(z){A=1}else{if((c[y+13072>>2]|0)>>>0<m>>>0){do{if((d[r+184599|0]|0)>(n|0)){if(u<<24>>24!=0&(n|0)==0){break}A=(KFa(b,m)|0)&255;break a}}while(0);if(z){A=1;break}}A=u<<24>>24!=0&(n|0)==0?1:x}}while(0);x=(m|0)>2;do{if(x){if((n|0)==0){u=((t&f)<<7)+(t&e)|0;a[r+9340+u|0]=LFa(b,0)|0;B=u}else{u=((t&h)<<7)+(t&g)|0;z=n-1|0;if((a[r+9340+(z<<14)+u|0]|0)!=0){a[((t&f)<<7)+(t&e)+(r+9340+(n<<14))|0]=LFa(b,n)|0}if((a[r+91260+(z<<14)+u|0]|0)==0){break}B=((t&f)<<7)+(t&e)|0}a[r+91260+(n<<14)+B|0]=LFa(b,n)|0}}while(0);do{if(A<<24>>24==0){B=c[w>>2]|0;u=c[B+13072>>2]|0;z=1<<u;y=c[B+13124>>2]|0;do{if((c[r+184588>>2]|0)!=1&(n|0)==0){B=((t&f)<<7)+(t&e)|0;if((a[r+9340+B|0]|0)!=0){C=35;break}if((a[r+91260+B|0]|0)!=0){C=35}}else{C=35}}while(0);if((C|0)==35){a[v]=MFa(b,n)|0}B=c[q>>2]|0;D=B+184588|0;do{if((c[D>>2]|0)==1){UFa(b,e,f,s,s);E=b+5820|0;pe[c[E>>2]&1023](b,e,f,m,0);if(x){F=s<<(c[(c[w>>2]|0)+13144>>2]|0)-1;UFa(b,e,f,F,F);F=m-1|0;pe[c[E>>2]&1023](b,e,f,F,1);pe[c[E>>2]&1023](b,e,f,F,2);break}if((o|0)!=3){break}F=s<<c[(c[w>>2]|0)+13144>>2];UFa(b,g,h,F,F);pe[c[E>>2]&1023](b,g,h,m,1);pe[c[E>>2]&1023](b,g,h,m,2)}}while(0);E=B+173180|0;do{if((a[E]|0)==0){F=((t&f)<<7)+(t&e)|0;if((a[B+9340+(n<<14)+F|0]|0)!=0){C=44;break}if((a[B+91260+(n<<14)+F|0]|0)!=0){C=44}}else{C=44}}while(0);do{if((C|0)==44){do{if((a[(c[b+184>>2]|0)+22|0]|0)!=0){F=B+173196|0;if((a[F]|0)!=0){break}G=uFa(b)|0;H=B+173188|0;c[H>>2]=G;do{if((G|0)==0){I=0}else{J=(vFa(b)|0)==1;K=c[H>>2]|0;if(!J){I=K;break}J=-K|0;c[H>>2]=J;I=J}}while(0);a[F]=1;H=(c[(c[w>>2]|0)+13164>>2]|0)/2|0;G=-26-H|0;J=H+25|0;if(!((I|0)<(G|0)|(I|0)>(J|0))){PFa(b,e,f,j,k,l);break}KIb(c[b+4>>2]|0,16,2469e3,(H=i,i=i+24|0,c[H>>2]=I,c[H+8>>2]=G,c[H+16>>2]=J,H)|0);i=H;L=-1094995529;i=p;return L|0}}while(0);do{if((c[D>>2]|0)==1&(m|0)<4){H=c[B+173192>>2]|0;if((H-6|0)>>>0<9>>>0){M=2}else{M=(H-22|0)>>>0<9>>>0|0}H=a[B+184621|0]|0;if((H-6&255)>>>0<9>>>0){N=2;O=M;break}N=(H-22&255)>>>0<9>>>0|0;O=M}else{N=0;O=0}}while(0);if((a[E]|0)!=0){NFa(b,e,f,m,O,0)}if(x){H=((t&f)<<7)+(t&e)|0;if((a[B+9340+(n<<14)+H|0]|0)!=0){NFa(b,e,f,m-1|0,N,1)}if((a[B+91260+(n<<14)+H|0]|0)==0){break}NFa(b,e,f,m-1|0,N,2);break}if((o|0)!=3){break}H=((t&h)<<7)+(t&g)|0;if((a[B+9340+(n<<14)+H|0]|0)!=0){NFa(b,g,h,m,N,1)}if((a[B+91260+(n<<14)+H|0]|0)==0){break}NFa(b,g,h,m,N,2)}}while(0);if((a[v]|0)!=0&(s|0)>0){B=b+7348|0;E=0;do{D=ca(E+f>>u,y)|0;H=0;do{a[(c[B>>2]|0)+((H+e>>u)+D)|0]=1;H=H+z|0;}while((H|0)<(s|0));E=E+z|0;}while((E|0)<(s|0))}if((a[b+3025|0]|0)!=0){break}QFa(b,e,f,m,d[r+184649|0]|0,d[r+184648|0]|0);if((a[(c[b+184>>2]|0)+40|0]|0)==0){break}if((a[r+184600|0]|0)==0){break}E=c[w>>2]|0;z=c[E+13084>>2]|0;u=c[E+13132>>2]|0;B=s+e|0;y=c[E+13096>>2]|0;H=s+f|0;D=c[E+13100>>2]|0;E=f>>z;J=((H|0)>(D|0)?D:H)>>z;if((E|0)>=(J|0)){break}H=e>>z;D=((B|0)>(y|0)?y:B)>>z;z=(H|0)<(D|0);B=b+7352|0;y=E;do{if(z){E=ca(y,u)|0;G=H;do{a[(c[B>>2]|0)+(G+E)|0]=2;G=G+1|0;}while((G|0)<(D|0))}y=y+1|0;}while((y|0)<(J|0))}else{J=s>>1;y=J+e|0;D=J+f|0;J=m-1|0;B=n+1|0;H=bFa(b,e,f,e,f,j,k,l,J,B,0)|0;if((H|0)<0){L=H;i=p;return L|0}H=bFa(b,y,f,e,f,j,k,l,J,B,1)|0;if((H|0)<0){L=H;i=p;return L|0}H=bFa(b,e,D,e,f,j,k,l,J,B,2)|0;if((H|0)<0){L=H;i=p;return L|0}H=bFa(b,y,D,e,f,j,k,l,J,B,3)|0;if((H|0)<0){L=H}else{break}i=p;return L|0}}while(0);L=0;i=p;return L|0}function cFa(a,b,e,f,g,h,i,j,k,l){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=c[a+136>>2]|0;n=c[a+180>>2]|0;o=c[n+13096>>2]|0;p=c[n+13100>>2]|0;q=g<<16>>16;g=q&3;r=h<<16>>16;h=r&3;s=d[1374912+g|0]|0;t=d[1374912+h|0]|0;u=(q>>2)+i|0;i=(r>>2)+j|0;j=ca(i,f)|0;r=c[n+56>>2]|0;n=(u<<r)+j|0;j=e+n|0;do{if(!((u|0)<(s|0)|(i|0)<(t|0))){if((u|0)>=(o-k-(d[1374920+g|0]|0)|0)){break}if((i|0)<(p-l-(d[1374920+h|0]|0)|0)){v=j;w=f}else{break}x=a+5936+(h<<4)+(g<<2)|0;y=c[x>>2]|0;z=m|0;Se[y&1023](b,64,v,w,k,l,z);return}}while(0);j=80<<r;q=ca(t,f)|0;A=s<<r;r=(ca(j,t)|0)+A|0;Ve[c[a+6064>>2]&127](m+173216|0,e+(n-q-A)|0,j,f,(d[1374928+g|0]|0)+k|0,(d[1374928+h|0]|0)+l|0,u-s|0,i-t|0,o,p);v=m+173216+r|0;w=j;x=a+5936+(h<<4)+(g<<2)|0;y=c[x>>2]|0;z=m|0;Se[y&1023](b,64,v,w,k,l,z);return}function dFa(a,b,d,e,f,g,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;l=c[a+136>>2]|0;m=c[e+4>>2]|0;n=c[e+8>>2]|0;o=c[e+36>>2]|0;p=c[e+40>>2]|0;e=c[a+180>>2]|0;q=c[e+13096>>2]>>1;r=c[e+13100>>2]>>1;s=f<<16>>16;f=s&7;t=g<<16>>16;g=t&7;u=(s>>3)+h|0;h=(t>>3)+i|0;i=ca(o,h)|0;t=c[e+56>>2]|0;e=u<<t;s=e+i|0;i=m+s|0;v=e+(ca(p,h)|0)|0;e=n+v|0;do{if(!((u|0)<1|(h|0)<2)){if((u|0)>=(-2-j+q|0)){break}if((h|0)>=(-2-k+r|0)){break}w=a+6e3+(((g|0)!=0)<<3)+(((f|0)!=0)<<2)|0;x=l|0;Te[c[w>>2]&255](b,64,i,o,j,k,f,g,x);Te[c[w>>2]&255](d,64,e,p,j,k,f,g,x);return}}while(0);e=80<<t;i=1<<t;t=a+6064|0;x=l+173216|0;w=j+3|0;y=k+3|0;z=u-1|0;u=h-1|0;Ve[c[t>>2]&127](x,m+(s-o-i)|0,e,o,w,y,z,u,q,r);o=e+i+(l+173216)|0;s=a+6e3+(((g|0)!=0)<<3)+(((f|0)!=0)<<2)|0;a=l|0;Te[c[s>>2]&255](b,64,o,e,j,k,f,g,a);Ve[c[t>>2]&127](x,n+(v-p-i)|0,e,p,w,y,z,u,q,r);Te[c[s>>2]&255](d,64,o,e,j,k,f,g,a);return}function eFa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c[a+60>>2]|0;a=c[g+180>>2]|0;h=c[a+13080>>2]|0;i=1<<h;j=c[b+(e<<2)>>2]|0;e=(ca(i-1+(c[a+13096>>2]|0)>>h,j)|0)+(c[g+3460>>2]|0)|0;h=c[(c[(c[g+184>>2]|0)+1652>>2]|0)+(e<<2)>>2]|0;a=(j|0)%(d[g+141|0]|0|0)|0;b=c[g+8+(f<<2)>>2]|0;f=c[b+136>>2]|0;do{if((j|0)!=0){k=b+7404|0;l=j-1|0;m=b+3060|0;n=(c[k>>2]|0)+(c[(c[m>>2]|0)+(l<<2)>>2]|0)|0;o=b+3064|0;p=c[(c[o>>2]|0)+(l<<2)>>2]|0;q=p>>>0>268435455>>>0?-8:p<<3;p=q>>>0>2147483639>>>0|(n|0)==0;r=p?0:n;n=p?0:q;c[f+9272>>2]=r;c[f+9284>>2]=n;c[f+9288>>2]=n+8;c[f+9276>>2]=r+(n>>3);c[f+9280>>2]=0;if(p){s=p?-1094995529:0;return s|0}else{Hmb(f+9292|0,(c[k>>2]|0)+(c[(c[m>>2]|0)+(l<<2)>>2]|0)|0,c[(c[o>>2]|0)+(l<<2)>>2]|0);break}}}while(0);f=b+180|0;l=b+4|0;o=g+7376|0;g=b+3068|0;m=b+184|0;k=0;p=e;e=h;a:while(1){if(k){break}h=c[f>>2]|0;if((e|0)>=(c[h+13112>>2]|0)){break}n=c[h+13104>>2]|0;r=c[h+13080>>2]|0;t=((p|0)%(n|0)|0)<<r;u=((p|0)/(n|0)|0)<<r;ZEa(b,t,u,e);Q5a(c[l>>2]|0,j,a,2);if((c[o>>2]|0)!=0){v=8;break}jFa(b,e);r=c[(c[f>>2]|0)+13080>>2]|0;_Ea(b,t>>r,u>>r);w=$Ea(b,t,u,c[(c[f>>2]|0)+13080>>2]|0,0)|0;if((w|0)<0){v=10;break}x=e+1|0;iFa(b,x);R5a(c[l>>2]|0,j,a,1);TFa(b,t,u,i);do{if((w|0)==0){r=t+i|0;n=c[f>>2]|0;h=c[n+13096>>2]|0;if((r|0)>=(h|0)){y=n;z=h;A=r;break}if((j|0)==(c[g>>2]|0)){y=n;z=h;A=r}else{v=15;break a}}else{r=c[f>>2]|0;y=r;z=c[r+13096>>2]|0;A=t+i|0}}while(0);if((A|0)>=(z|0)){v=18;break}k=(w|0)==0;p=c[(c[(c[m>>2]|0)+1656>>2]|0)+(x<<2)>>2]|0;e=x}do{if((v|0)==8){R5a(c[l>>2]|0,j,a,2);s=0;return s|0}else if((v|0)==10){c[(c[b+7332>>2]|0)+(p<<2)>>2]=-1;s=w;return s|0}else if((v|0)==15){c[o>>2]=1;R5a(c[l>>2]|0,j,a,2);s=0;return s|0}else if((v|0)==18){if((u+i|0)<(c[y+13100>>2]|0)){break}SFa(b,t,u);R5a(c[l>>2]|0,j,a,2);s=x;return s|0}}while(0);R5a(c[l>>2]|0,j,a,2);s=0;return s|0}function fFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a>>2]|0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;a=b+(f>>>3)|0;h=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7);a=f+16|0;i=g>>>0>a>>>0?a:g;a=b+(i>>>3)|0;j=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>16|h&-65536;i=j>>>0>65535>>>0;a=i?h>>>16:j;j=i?16:0;if((a&65280|0)==0){k=j;l=a}else{k=j|8;l=a>>>8}a=(d[1359664+l|0]|0)+k|0;k=31-a|0;l=-f|0;j=g-f|0;if((k|0)<(l|0)){m=l}else{m=(j|0)<(k|0)?j:k}j=m+f|0;c[e>>2]=j;f=k+1|0;if((f|0)==0){n=0;o=n-1|0;return o|0}m=b+(j>>>3)|0;l=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7);if((f|0)<26){m=j+f|0;c[e>>2]=g>>>0>m>>>0?m:g;n=l>>>(a>>>0);o=n-1|0;return o|0}else{a=j+16|0;j=g>>>0>a>>>0?a:g;c[e>>2]=j;a=k-15|0;m=b+(j>>>3)|0;b=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>((47-k|0)>>>0);k=j+a|0;c[e>>2]=g>>>0>k>>>0?k:g;n=b|l>>>16<<a;o=n-1|0;return o|0}return 0}function gFa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;VEa(b);f=c[e+13064>>2]|0;g=e+13096|0;h=c[g>>2]|0;i=e+13100|0;j=c[i>>2]|0;k=ca(j,h)|0;l=ca((j>>f)+1|0,(h>>f)+1|0)|0;f=ca(c[e+13108>>2]|0,c[e+13104>>2]|0)|0;m=ca(c[e+13136>>2]|0,c[e+13132>>2]|0)|0;n=b+5808|0;c[n>>2]=h>>3;h=b+5812|0;c[h>>2]=j>>3;if(f>>>0<11671106>>>0){j=b+3464|0;c[j>>2]=pJb(f*184|0)|0;o=j;p=4}else{j=b+3464|0;c[j>>2]=0;if(f>>>0<268435455>>>0){o=j;p=4}else{q=0;r=j}}if((p|0)==4){q=pJb(f<<3)|0;r=o}o=b+3468|0;c[o>>2]=q;q=hJb(k)|0;c[b+7320>>2]=q;do{if((c[r>>2]|0)==0){p=15}else{if((c[o>>2]|0)==0|(q|0)==0){p=15;break}k=b+7336|0;c[k>>2]=hJb(l)|0;j=hJb(ca(c[e+13116>>2]|0,c[e+13120>>2]|0)|0)|0;c[b+7340>>2]=j;if((c[k>>2]|0)==0|(j|0)==0){p=15;break}j=b+7348|0;c[j>>2]=hJb(ca(c[e+13128>>2]|0,c[e+13124>>2]|0)|0)|0;k=b+7344|0;c[k>>2]=pJb(m)|0;s=hJb(m)|0;c[b+7352>>2]=s;if((c[k>>2]|0)==0){p=15;break}if((c[j>>2]|0)==0|(s|0)==0){p=15;break}s=b+7356|0;c[s>>2]=hJb(f)|0;j=b+7332|0;c[j>>2]=hJb(l<<2)|0;k=hJb(l)|0;c[b+7316>>2]=k;if((k|0)==0){p=15;break}if((c[s>>2]|0)==0){p=15;break}if((c[j>>2]|0)==0){p=15;break}j=b+7324|0;c[j>>2]=pJb(ca(c[n>>2]<<1,(c[h>>2]|0)+1|0)|0)|0;s=pJb(ca(c[n>>2]<<1,(c[h>>2]|0)+1|0)|0)|0;c[b+7328>>2]=s;if((c[j>>2]|0)==0|(s|0)==0){p=15;break}s=b+1404|0;c[s>>2]=kGb(m*14|0,1736)|0;j=kGb(f*392|0,792)|0;c[b+1408>>2]=j;if((c[s>>2]|0)==0|(j|0)==0){p=15;break}j=b+4|0;s=c[j>>2]|0;c[s+128>>2]=c[g>>2];c[s+132>>2]=c[i>>2];c[s+120>>2]=c[e+12>>2];c[s+124>>2]=c[e+16>>2];c[s+140>>2]=c[e+60>>2];k=e+160|0;t=s+224|0;s=c[k+4>>2]|0;c[t>>2]=c[k>>2];c[t+4>>2]=s;s=c[j>>2]|0;c[s+176>>2]=c[e+76+(((c[e+72>>2]|0)-1|0)*12|0)+4>>2];if((c[e+176>>2]|0)==0){c[s+396>>2]=1}else{c[s+396>>2]=(c[e+184>>2]|0)!=0?2:1}if((c[e+188>>2]|0)==0){c[s+384>>2]=2;c[s+388>>2]=2;c[s+392>>2]=2}else{c[s+384>>2]=d[e+192|0]|0;c[s+388>>2]=d[e+193|0]|0;c[s+392>>2]=d[e+194|0]|0}s=e+52|0;qJa(b+5820|0,c[s>>2]|0);BGa(b+5860|0,c[s>>2]|0);G8a(b+6064|0,c[s>>2]|0);if((a[e+12941|0]|0)!=0){s=b+168|0;WHb(c[s>>2]|0);t=M4a(c[j>>2]|0,c[s>>2]|0,1)|0;if((t|0)<0){u=t;break}c[b+160>>2]=c[s>>2]}c[b+180>>2]=e;s=c[(c[b+188+(c[e>>2]<<2)>>2]|0)+4>>2]|0;c[b+176>>2]=s;do{if((a[s+444|0]|0)==0){if((c[e+240>>2]|0)==0){v=0;return v|0}else{w=e+248|0;x=e+244|0;break}}else{w=s+452|0;x=s+448|0}}while(0);s=c[w>>2]|0;t=c[x>>2]|0;if((t|0)==0|(s|0)==0){v=0;return v|0}k=c[j>>2]|0;xKb(k+104|0,k+108|0,t,0,s,0,1073741824,0)|0;v=0;return v|0}}while(0);if((p|0)==15){VEa(b);u=-12}VEa(b);c[b+180>>2]=0;v=u;return v|0}function hFa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[b+60>>2]|0;c[d+4>>2]=b;e=pJb(184672)|0;f=e;c[d+136>>2]=f;a:do{if((e|0)!=0){c[d+72>>2]=f;c[d+8>>2]=d;g=hJb(183)|0;c[d+152>>2]=g;if((g|0)==0){break}g=UHb()|0;c[d+168>>2]=g;if((g|0)==0){break}g=UHb()|0;c[d+172>>2]=g;if((g|0)==0){break}g=d+3484|0;h=0;do{i=UHb()|0;c[g+(h*72|0)>>2]=i;if((i|0)==0){break a}c[g+(h*72|0)+4>>2]=i;h=h+1|0;}while(h>>>0<32>>>0);c[d+5804>>2]=2147483647;h=aJb()|0;c[d+7424>>2]=h;if((h|0)==0){break}l8(d+6072|0,b);a[d+7477|0]=1;j=0;return j|0}}while(0);TEa(b)|0;j=-12;return j|0}function iFa(b,d){b=b|0;d=d|0;var e=0,f=0;if((a[(c[b+184>>2]|0)+43|0]|0)==0){return}e=c[(c[b+180>>2]|0)+13104>>2]|0;f=(d|0)%(e|0)|0;do{if((f|0)!=2){if((e|0)==2&(f|0)==0){break}return}}while(0);nrc(c[b+152>>2]|0,(c[b+136>>2]|0)+9088|0,183)|0;return}function jFa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=b+184|0;g=c[f>>2]|0;if((c[(c[g+1652>>2]|0)+(c[b+3460>>2]<<2)>>2]|0)==(e|0)){h=b+136|0;i=c[h>>2]|0;j=i+9280|0;k=c[i+9288>>2]|0;l=(c[j>>2]|0)+1|0;m=k>>>0>l>>>0?l:k;l=-m&7;if((l|0)==0){n=m}else{o=l+m|0;n=k>>>0>o>>>0?o:k}c[j>>2]=n;Hmb(i+9292|0,(c[i+9272>>2]|0)+((n|0)/8|0)|0,(7-n+(c[i+9284>>2]|0)|0)/8|0);i=b+2413|0;do{if((a[i]|0)==0){p=7}else{n=c[f>>2]|0;if((a[n+42|0]|0)==0){break}j=c[n+1660>>2]|0;if((c[j+(e<<2)>>2]|0)!=(c[j+(e-1<<2)>>2]|0)){p=7}}}while(0);if((p|0)==7){p=c[b+2404>>2]|0;j=2-p|0;n=(a[b+3024|0]|0)==0|(p|0)==2?j:j^3;j=b+3072|0;p=0;do{k=d[1071200+(n*183|0)+p|0]|0;o=a[j]|0;m=o<<24>>24;if(o<<24>>24<0){q=0}else{q=(m|0)>51?51:m}m=((k<<3&120)-16+((ca(q,((k>>>4)*5|0)-45|0)|0)>>4)<<1)-127|0;k=m>>31^m;if((k|0)>124){r=(k&1|124)&255}else{r=k&255}a[(c[h>>2]|0)+9088+p|0]=r;p=p+1|0;}while((p|0)<183)}if((a[b+2412|0]|0)!=0){return}if((a[(c[f>>2]|0)+43|0]|0)==0){return}p=c[(c[b+180>>2]|0)+13104>>2]|0;if(((e|0)%(p|0)|0|0)!=0){return}if((p|0)!=1){if((a[i]|0)!=1){return}nrc((c[h>>2]|0)+9088|0,c[b+152>>2]|0,183)|0;return}i=c[b+2404>>2]|0;p=2-i|0;r=(a[b+3024|0]|0)==0|(i|0)==2?p:p^3;p=b+3072|0;i=0;do{q=d[1071200+(r*183|0)+i|0]|0;j=a[p]|0;n=j<<24>>24;if(j<<24>>24<0){s=0}else{s=(n|0)>51?51:n}n=((q<<3&120)-16+((ca(s,((q>>>4)*5|0)-45|0)|0)>>4)<<1)-127|0;q=n>>31^n;if((q|0)>124){t=(q&1|124)&255}else{t=q&255}a[(c[h>>2]|0)+9088+i|0]=t;i=i+1|0;}while((i|0)<183);return}do{if((a[g+42|0]|0)==0){u=g}else{i=c[g+1660>>2]|0;if((c[i+(e<<2)>>2]|0)==(c[i+(e-1<<2)>>2]|0)){u=g;break}i=b+136|0;t=c[i>>2]|0;do{if((a[b+141|0]|0)==1){h=t+9292|0;s=c[t+9308>>2]|0;p=c[h>>2]|0;r=(p&1|0)==0?s:s-1|0;s=(p&511|0)==0?r:r-1|0;r=(c[t+9312>>2]|0)-s|0;if((r|0)<0){break}Hmb(h,s,r)}else{r=t+9280|0;s=c[t+9288>>2]|0;h=(c[r>>2]|0)+1|0;p=s>>>0>h>>>0?h:s;h=-p&7;if((h|0)==0){v=p}else{q=h+p|0;v=s>>>0>q>>>0?q:s}c[r>>2]=v;Hmb(t+9292|0,(c[t+9272>>2]|0)+((v|0)/8|0)|0,(7-v+(c[t+9284>>2]|0)|0)/8|0)}}while(0);t=c[b+2404>>2]|0;r=2-t|0;s=(a[b+3024|0]|0)==0|(t|0)==2?r:r^3;r=b+3072|0;t=0;do{q=d[1071200+(s*183|0)+t|0]|0;p=a[r]|0;h=p<<24>>24;if(p<<24>>24<0){w=0}else{w=(h|0)>51?51:h}h=((q<<3&120)-16+((ca(w,((q>>>4)*5|0)-45|0)|0)>>4)<<1)-127|0;q=h>>31^h;if((q|0)>124){x=(q&1|124)&255}else{x=q&255}a[(c[i>>2]|0)+9088+t|0]=x;t=t+1|0;}while((t|0)<183);u=c[f>>2]|0}}while(0);if((a[u+43|0]|0)==0){return}u=b+180|0;if(((e|0)%(c[(c[u>>2]|0)+13104>>2]|0)|0|0)!=0){return}e=b+136|0;f=c[e>>2]|0;x=f+9296|0;w=c[x>>2]|0;v=w-2|0;c[x>>2]=v;g=f+9292|0;t=c[g>>2]|0;do{if((t|0)<(v<<17|0)){i=(w-258|0)>>>31;c[x>>2]=v<<i;r=t<<i;c[g>>2]=r;if((r&65535|0)!=0){break}i=f+9308|0;s=c[i>>2]|0;c[g>>2]=r-65535+(d[s+1|0]<<1|d[s]<<9);if(!(s>>>0<(c[f+9312>>2]|0)>>>0)){break}c[i>>2]=s+2}}while(0);f=c[e>>2]|0;do{if((a[b+141|0]|0)==1){g=f+9292|0;t=c[f+9308>>2]|0;v=c[g>>2]|0;x=(v&1|0)==0?t:t-1|0;t=(v&511|0)==0?x:x-1|0;x=(c[f+9312>>2]|0)-t|0;if((x|0)<0){break}Hmb(g,t,x)}else{x=f+9280|0;t=c[f+9288>>2]|0;g=(c[x>>2]|0)+1|0;v=t>>>0>g>>>0?g:t;g=-v&7;if((g|0)==0){y=v}else{w=g+v|0;y=t>>>0>w>>>0?w:t}c[x>>2]=y;Hmb(f+9292|0,(c[f+9272>>2]|0)+((y|0)/8|0)|0,(7-y+(c[f+9284>>2]|0)|0)/8|0)}}while(0);if((c[(c[u>>2]|0)+13104>>2]|0)!=1){nrc((c[e>>2]|0)+9088|0,c[b+152>>2]|0,183)|0;return}u=c[b+2404>>2]|0;f=2-u|0;y=(a[b+3024|0]|0)==0|(u|0)==2?f:f^3;f=b+3072|0;b=0;do{u=d[1071200+(y*183|0)+b|0]|0;x=a[f]|0;t=x<<24>>24;if(x<<24>>24<0){z=0}else{z=(t|0)>51?51:t}t=((u<<3&120)-16+((ca(z,((u>>>4)*5|0)-45|0)|0)>>4)<<1)-127|0;u=t>>31^t;if((u|0)>124){A=(u&1|124)&255}else{A=u&255}a[(c[e>>2]|0)+9088+b|0]=A;b=b+1|0;}while((b|0)<183);return}function kFa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return lFa(b+9292|0,b+9088|0)|0}function lFa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[e]|0;g=b+4|0;h=c[g>>2]|0;i=d[1376824+((h<<1&384)+(f|512))|0]|0;j=h-i|0;h=j<<17;k=b|0;l=c[k>>2]|0;m=h-l>>31;c[k>>2]=l-(m&h);c[g>>2]=(m&i-j)+j;j=m^f;a[e]=a[j+1377976|0]|0;e=j&1;j=c[g>>2]|0;f=d[1376824+j|0]|0;c[g>>2]=j<<f;j=c[k>>2]<<f;c[k>>2]=j;if((j&65535|0)!=0){return e|0}f=b+16|0;g=c[f>>2]|0;c[k>>2]=(((d[g+1|0]|0)<<1|(d[g]|0)<<9)-65535<<7-(d[1376824+((j-1^j)>>15)|0]|0))+j;if(!(g>>>0<(c[b+20>>2]|0)>>>0)){return e|0}c[f>>2]=g+2;return e|0}function mFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+136|0;a=c[b>>2]|0;if((lFa(a+9292|0,a+9089|0)|0)==0){e=0;return e|0}a=c[b>>2]|0;b=a+9292|0;f=c[b>>2]<<1;c[b>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[b>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){e=1;return e|0}c[b>>2]=j-f;e=2;return e|0}function nFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=a+136|0;a=c[b>>2]|0;e=a+9292|0;f=c[e>>2]<<1;c[e>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[e>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){k=0}else{c[e>>2]=j-f;k=16}f=c[b>>2]|0;j=f+9292|0;e=c[j>>2]<<1;c[j>>2]=e;do{if((e&65534|0)==0){a=f+9308|0;i=c[a>>2]|0;h=e-65535+((d[i+1|0]|0)<<1|(d[i]|0)<<9)|0;c[j>>2]=h;if(!(i>>>0<(c[f+9312>>2]|0)>>>0)){l=h;break}c[a>>2]=i+2;l=h}else{l=e}}while(0);e=c[f+9296>>2]<<17;if((l|0)<(e|0)){m=0}else{c[j>>2]=l-e;m=8}e=m|k;k=c[b>>2]|0;m=k+9292|0;l=c[m>>2]<<1;c[m>>2]=l;do{if((l&65534|0)==0){j=k+9308|0;f=c[j>>2]|0;h=l-65535+((d[f+1|0]|0)<<1|(d[f]|0)<<9)|0;c[m>>2]=h;if(!(f>>>0<(c[k+9312>>2]|0)>>>0)){n=h;break}c[j>>2]=f+2;n=h}else{n=l}}while(0);l=c[k+9296>>2]<<17;if((n|0)<(l|0)){o=0}else{c[m>>2]=n-l;o=4}l=o|e;e=c[b>>2]|0;o=e+9292|0;n=c[o>>2]<<1;c[o>>2]=n;do{if((n&65534|0)==0){m=e+9308|0;k=c[m>>2]|0;h=n-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[o>>2]=h;if(!(k>>>0<(c[e+9312>>2]|0)>>>0)){p=h;break}c[m>>2]=k+2;p=h}else{p=n}}while(0);n=c[e+9296>>2]<<17;if((p|0)<(n|0)){q=0}else{c[o>>2]=p-n;q=2}n=q|l;l=c[b>>2]|0;b=l+9292|0;q=c[b>>2]<<1;c[b>>2]=q;do{if((q&65534|0)==0){p=l+9308|0;o=c[p>>2]|0;e=q-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9)|0;c[b>>2]=e;if(!(o>>>0<(c[l+9312>>2]|0)>>>0)){r=e;break}c[p>>2]=o+2;r=e}else{r=q}}while(0);q=c[l+9296>>2]<<17;if((r|0)<(q|0)){s=0;t=s|n;return t|0}c[b>>2]=r-q;s=1;t=s|n;return t|0}function oFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[(c[a+180>>2]|0)+52>>2]|0;e=(b|0)>10?31:(1<<b-5)-1|0;if((e|0)<=0){f=0;return f|0}b=a+136|0;a=0;while(1){g=c[b>>2]|0;h=g+9292|0;i=c[h>>2]<<1;c[h>>2]=i;do{if((i&65534|0)==0){j=g+9308|0;k=c[j>>2]|0;l=i-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[h>>2]=l;if(!(k>>>0<(c[g+9312>>2]|0)>>>0)){m=l;break}c[j>>2]=k+2;m=l}else{m=i}}while(0);i=c[g+9296>>2]<<17;if((m|0)<(i|0)){f=a;n=8;break}c[h>>2]=m-i;i=a+1|0;if((i|0)<(e|0)){a=i}else{f=i;n=8;break}}if((n|0)==8){return f|0}return 0}function pFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+136>>2]|0;a=b+9292|0;e=c[a>>2]<<1;c[a>>2]=e;do{if((e&65534|0)==0){f=b+9308|0;g=c[f>>2]|0;h=e-65535+((d[g+1|0]|0)<<1|(d[g]|0)<<9)|0;c[a>>2]=h;if(!(g>>>0<(c[b+9312>>2]|0)>>>0)){i=h;break}c[f>>2]=g+2;i=h}else{i=e}}while(0);e=c[b+9296>>2]<<17;if((i|0)<(e|0)){j=0;return j|0}c[a>>2]=i-e;j=1;return j|0}function qFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+136|0;a=c[b>>2]|0;e=a+9292|0;f=c[e>>2]<<1;c[e>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[e>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){k=0}else{c[e>>2]=j-f;k=2}f=c[b>>2]|0;b=f+9292|0;j=c[b>>2]<<1;c[b>>2]=j;do{if((j&65534|0)==0){e=f+9308|0;a=c[e>>2]|0;i=j-65535+((d[a+1|0]|0)<<1|(d[a]|0)<<9)|0;c[b>>2]=i;if(!(a>>>0<(c[f+9312>>2]|0)>>>0)){l=i;break}c[e>>2]=a+2;l=i}else{l=j}}while(0);j=c[f+9296>>2]<<17;if((l|0)<(j|0)){m=0;n=m|k;return n|0}c[b>>2]=l-j;m=1;n=m|k;return n|0}function rFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+136>>2]|0;a=b+9296|0;e=c[a>>2]|0;f=e-2|0;c[a>>2]=f;g=b+9292|0;h=c[g>>2]|0;if((h|0)>=(f<<17|0)){i=(c[b+9308>>2]|0)-(c[b+9304>>2]|0)|0;return i|0}j=(e-258|0)>>>31;c[a>>2]=f<<j;f=h<<j;c[g>>2]=f;if((f&65535|0)!=0){i=0;return i|0}j=b+9308|0;h=c[j>>2]|0;c[g>>2]=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9);if(!(h>>>0<(c[b+9312>>2]|0)>>>0)){i=0;return i|0}c[j>>2]=h+2;i=0;return i|0}function sFa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return lFa(b+9292|0,b+9093|0)|0}function tFa(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=c[b+180>>2]|0;i=c[h+13116>>2]|0;j=(1<<c[h+13080>>2])-1|0;h=j&e;e=c[b+136>>2]|0;if((a[e+173200|0]|0)==0){if((j&d|0)==0){k=0}else{l=3}}else{l=3}if((l|0)==3){l=f-1+(ca(i,g)|0)|0;k=(a[(c[b+7336>>2]|0)+l|0]|0)!=0|0}if((a[e+173201|0]|0)==0&(h|0)==0){m=k;n=e+9292|0;o=m+6|0;p=e+9088+o|0;q=lFa(n,p)|0;return q|0}h=(ca(i,g-1|0)|0)+f|0;m=((a[(c[b+7336>>2]|0)+h|0]|0)!=0)+k|0;n=e+9292|0;o=m+6|0;p=e+9088+o|0;q=lFa(n,p)|0;return q|0}function uFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;e=a+136|0;f=9;g=0;while(1){if((g|0)>=5){h=0;j=0;break}k=c[e>>2]|0;if((lFa(k+9292|0,k+9088+f|0)|0)==0){l=0;m=17;break}else{f=10;g=g+1|0}}if((m|0)==17){n=l+g|0;i=b;return n|0}while(1){m=c[e>>2]|0;f=m+9292|0;k=c[f>>2]<<1;c[f>>2]=k;do{if((k&65534|0)==0){o=m+9308|0;p=c[o>>2]|0;q=k-65535+((d[p+1|0]|0)<<1|(d[p]|0)<<9)|0;c[f>>2]=q;if(!(p>>>0<(c[m+9312>>2]|0)>>>0)){r=q;break}c[o>>2]=p+2;r=q}else{r=k}}while(0);k=c[m+9296>>2]<<17;if((r|0)<(k|0)){s=h;t=j;break}c[f>>2]=r-k;k=(1<<j)+h|0;q=j+1|0;if((q|0)<100){h=k;j=q}else{s=k;t=q;break}}if((t|0)==0){l=s;n=l+g|0;i=b;return n|0}else if((t|0)==100){KIb(c[a+4>>2]|0,16,2538232,(a=i,i=i+8|0,c[a>>2]=100,a)|0);i=a;u=s;v=100}else{u=s;v=t}while(1){t=v-1|0;s=c[e>>2]|0;a=s+9292|0;j=c[a>>2]<<1;c[a>>2]=j;do{if((j&65534|0)==0){h=s+9308|0;r=c[h>>2]|0;q=j-65535+((d[r+1|0]|0)<<1|(d[r]|0)<<9)|0;c[a>>2]=q;if(!(r>>>0<(c[s+9312>>2]|0)>>>0)){w=q;break}c[h>>2]=r+2;w=q}else{w=j}}while(0);j=c[s+9296>>2]<<17;if((w|0)<(j|0)){x=0}else{c[a>>2]=w-j;x=1}j=(x<<t)+u|0;if((t|0)==0){l=j;break}else{u=j;v=t}}n=l+g|0;i=b;return n|0}function vFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+136>>2]|0;a=b+9292|0;e=c[a>>2]<<1;c[a>>2]=e;do{if((e&65534|0)==0){f=b+9308|0;g=c[f>>2]|0;h=e-65535+((d[g+1|0]|0)<<1|(d[g]|0)<<9)|0;c[a>>2]=h;if(!(g>>>0<(c[b+9312>>2]|0)>>>0)){i=h;break}c[f>>2]=g+2;i=h}else{i=e}}while(0);e=c[b+9296>>2]<<17;if((i|0)<(e|0)){j=0;return j|0}c[a>>2]=i-e;j=1;return j|0}function wFa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return lFa(b+9292|0,b+9100|0)|0}function xFa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=c[b+180>>2]|0;i=(1<<c[h+13080>>2])-1|0;j=i&g;k=c[h+13064>>2]|0;l=f>>k;m=g>>k;k=c[b+136>>2]|0;if((a[k+173200|0]|0)==0){if((i&f|0)==0){n=0}else{o=3}}else{o=3}if((o|0)==3){o=l-1+(ca(c[h+13116>>2]|0,m)|0)|0;n=d[(c[b+7340>>2]|0)+o|0]|0}if((a[k+173201|0]|0)==0&(j|0)==0){p=0}else{j=(ca(c[h+13116>>2]|0,m-1|0)|0)+l|0;p=d[(c[b+7340>>2]|0)+j|0]|0}return lFa(k+9292|0,((n|0)>(e|0)|2)+((p|0)>(e|0))+(k+9088)|0)|0}function yFa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+136|0;g=c[f>>2]|0;if((lFa(g+9292|0,g+9101|0)|0)!=0){h=0;return h|0}g=c[b+180>>2]|0;if((c[g+13064>>2]|0)==(e|0)){b=c[f>>2]|0;if((c[b+184588>>2]|0)==1){h=3;return h|0}if((lFa(b+9292|0,b+9102|0)|0)!=0){h=1;return h|0}if((e|0)==3){h=2;return h|0}e=c[f>>2]|0;b=(lFa(e+9292|0,e+9103|0)|0)==0;h=b?3:2;return h|0}b=(a[g+12940|0]|0)==0;g=c[f>>2]|0;e=(lFa(g+9292|0,g+9102|0)|0)!=0;if(b){h=e?1:2;return h|0}b=c[f>>2]|0;g=(lFa(b+9292|0,b+9104|0)|0)!=0;if(e){if(g){h=1;return h|0}e=c[f>>2]|0;b=e+9292|0;i=c[b>>2]<<1;c[b>>2]=i;do{if((i&65534|0)==0){j=e+9308|0;k=c[j>>2]|0;l=i-65535+(d[k+1|0]<<1|d[k]<<9)|0;c[b>>2]=l;if(!(k>>>0<(c[e+9312>>2]|0)>>>0)){m=l;break}c[j>>2]=k+2;m=l}else{m=i}}while(0);i=c[e+9296>>2]<<17;if((m|0)<(i|0)){h=4;return h|0}c[b>>2]=m-i;h=5;return h|0}else{if(g){h=2;return h|0}g=c[f>>2]|0;f=g+9292|0;i=c[f>>2]<<1;c[f>>2]=i;do{if((i&65534|0)==0){m=g+9308|0;b=c[m>>2]|0;e=i-65535+(d[b+1|0]<<1|d[b]<<9)|0;c[f>>2]=e;if(!(b>>>0<(c[g+9312>>2]|0)>>>0)){n=e;break}c[m>>2]=b+2;n=e}else{n=i}}while(0);i=c[g+9296>>2]<<17;if((n|0)<(i|0)){h=6;return h|0}c[f>>2]=n-i;h=7;return h|0}return 0}function zFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+136>>2]|0;a=b+9296|0;e=c[a>>2]|0;f=e-2|0;c[a>>2]=f;g=b+9292|0;h=c[g>>2]|0;if((h|0)>=(f<<17|0)){i=(c[b+9308>>2]|0)-(c[b+9304>>2]|0)|0;return i|0}j=(e-258|0)>>>31;c[a>>2]=f<<j;f=h<<j;c[g>>2]=f;if((f&65535|0)!=0){i=0;return i|0}j=b+9308|0;h=c[j>>2]|0;c[g>>2]=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9);if(!(h>>>0<(c[b+9312>>2]|0)>>>0)){i=0;return i|0}c[j>>2]=h+2;i=0;return i|0}function AFa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return lFa(b+9292|0,b+9105|0)|0}function BFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+136|0;a=c[b>>2]|0;e=a+9292|0;f=c[e>>2]<<1;c[e>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[e>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){k=0;return k|0}c[e>>2]=j-f;f=c[b>>2]|0;b=f+9292|0;j=c[b>>2]<<1;c[b>>2]=j;do{if((j&65534|0)==0){e=f+9308|0;a=c[e>>2]|0;i=j-65535+((d[a+1|0]|0)<<1|(d[a]|0)<<9)|0;c[b>>2]=i;if(!(a>>>0<(c[f+9312>>2]|0)>>>0)){l=i;break}c[e>>2]=a+2;l=i}else{l=j}}while(0);j=c[f+9296>>2]<<17;if((l|0)<(j|0)){k=1;return k|0}c[b>>2]=l-j;k=2;return k|0}function CFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=a+136|0;a=c[b>>2]|0;e=a+9292|0;f=c[e>>2]<<1;c[e>>2]=f;do{if((f&65534|0)==0){g=a+9308|0;h=c[g>>2]|0;i=f-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[e>>2]=i;if(!(h>>>0<(c[a+9312>>2]|0)>>>0)){j=i;break}c[g>>2]=h+2;j=i}else{j=f}}while(0);f=c[a+9296>>2]<<17;if((j|0)<(f|0)){k=0}else{c[e>>2]=j-f;k=16}f=c[b>>2]|0;j=f+9292|0;e=c[j>>2]<<1;c[j>>2]=e;do{if((e&65534|0)==0){a=f+9308|0;i=c[a>>2]|0;h=e-65535+((d[i+1|0]|0)<<1|(d[i]|0)<<9)|0;c[j>>2]=h;if(!(i>>>0<(c[f+9312>>2]|0)>>>0)){l=h;break}c[a>>2]=i+2;l=h}else{l=e}}while(0);e=c[f+9296>>2]<<17;if((l|0)<(e|0)){m=0}else{c[j>>2]=l-e;m=8}e=m|k;k=c[b>>2]|0;m=k+9292|0;l=c[m>>2]<<1;c[m>>2]=l;do{if((l&65534|0)==0){j=k+9308|0;f=c[j>>2]|0;h=l-65535+((d[f+1|0]|0)<<1|(d[f]|0)<<9)|0;c[m>>2]=h;if(!(f>>>0<(c[k+9312>>2]|0)>>>0)){n=h;break}c[j>>2]=f+2;n=h}else{n=l}}while(0);l=c[k+9296>>2]<<17;if((n|0)<(l|0)){o=0}else{c[m>>2]=n-l;o=4}l=o|e;e=c[b>>2]|0;o=e+9292|0;n=c[o>>2]<<1;c[o>>2]=n;do{if((n&65534|0)==0){m=e+9308|0;k=c[m>>2]|0;h=n-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[o>>2]=h;if(!(k>>>0<(c[e+9312>>2]|0)>>>0)){p=h;break}c[m>>2]=k+2;p=h}else{p=n}}while(0);n=c[e+9296>>2]<<17;if((p|0)<(n|0)){q=0}else{c[o>>2]=p-n;q=2}n=q|l;l=c[b>>2]|0;b=l+9292|0;q=c[b>>2]<<1;c[b>>2]=q;do{if((q&65534|0)==0){p=l+9308|0;o=c[p>>2]|0;e=q-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9)|0;c[b>>2]=e;if(!(o>>>0<(c[l+9312>>2]|0)>>>0)){r=e;break}c[p>>2]=o+2;r=e}else{r=q}}while(0);q=c[l+9296>>2]<<17;if((r|0)<(q|0)){s=0;t=s|n;return t|0}c[b>>2]=r-q;s=1;t=s|n;return t|0}function DFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+136|0;a=c[b>>2]|0;if((lFa(a+9292|0,a+9106|0)|0)==0){e=4;return e|0}a=c[b>>2]|0;f=a+9292|0;g=c[f>>2]<<1;c[f>>2]=g;do{if((g&65534|0)==0){h=a+9308|0;i=c[h>>2]|0;j=g-65535+((d[i+1|0]|0)<<1|(d[i]|0)<<9)|0;c[f>>2]=j;if(!(i>>>0<(c[a+9312>>2]|0)>>>0)){k=j;break}c[h>>2]=i+2;k=j}else{k=g}}while(0);g=c[a+9296>>2]<<17;if((k|0)<(g|0)){l=0}else{c[f>>2]=k-g;l=2}g=c[b>>2]|0;b=g+9292|0;k=c[b>>2]<<1;c[b>>2]=k;do{if((k&65534|0)==0){f=g+9308|0;a=c[f>>2]|0;j=k-65535+((d[a+1|0]|0)<<1|(d[a]|0)<<9)|0;c[b>>2]=j;if(!(a>>>0<(c[g+9312>>2]|0)>>>0)){m=j;break}c[f>>2]=a+2;m=j}else{m=k}}while(0);k=c[g+9296>>2]<<17;if((m|0)<(k|0)){n=0}else{c[b>>2]=m-k;n=1}e=n|l;return e|0}function EFa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+136|0;e=c[b>>2]|0;f=lFa(e+9292|0,e+9109|0)|0;if((f|0)==0){g=0;return g|0}e=a+3052|0;if(f>>>0<((c[e>>2]|0)-1|0)>>>0){h=f}else{g=f;return g|0}while(1){f=c[b>>2]|0;a=f+9292|0;i=c[a>>2]<<1;c[a>>2]=i;do{if((i&65534|0)==0){j=f+9308|0;k=c[j>>2]|0;l=i-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[a>>2]=l;if(!(k>>>0<(c[f+9312>>2]|0)>>>0)){m=l;break}c[j>>2]=k+2;m=l}else{m=i}}while(0);i=c[f+9296>>2]<<17;if((m|0)<(i|0)){g=h;n=8;break}c[a>>2]=m-i;i=h+1|0;if(i>>>0<((c[e>>2]|0)-1|0)>>>0){h=i}else{g=i;n=8;break}}if((n|0)==8){return g|0}return 0}function FFa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return lFa(b+9292|0,b+9108|0)|0}function GFa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=a+136|0;a=c[e>>2]|0;f=a+9292|0;if((d+b|0)==12){g=lFa(f,a+9114|0)|0;return g|0}if((lFa(f,(c[a+184576>>2]|0)+22+(a+9088)|0)|0)!=0){g=2;return g|0}a=c[e>>2]|0;g=lFa(a+9292|0,a+9114|0)|0;return g|0}function HFa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b-1|0;b=(e|0)>2;f=b?2:e;g=a+136|0;a=0;while(1){if((a|0)>=(f|0)){break}h=c[g>>2]|0;if((lFa(h+9292|0,a+27+(h+9088)|0)|0)==0){break}else{a=a+1|0}}if((a|0)!=2|b^1){i=a;return i|0}else{j=2}while(1){a=c[g>>2]|0;b=a+9292|0;f=c[b>>2]<<1;c[b>>2]=f;do{if((f&65534|0)==0){h=a+9308|0;k=c[h>>2]|0;l=f-65535+((d[k+1|0]|0)<<1|(d[k]|0)<<9)|0;c[b>>2]=l;if(!(k>>>0<(c[a+9312>>2]|0)>>>0)){m=l;break}c[h>>2]=k+2;m=l}else{m=f}}while(0);f=c[a+9296>>2]<<17;if((m|0)<(f|0)){i=j;n=10;break}c[b>>2]=m-f;f=j+1|0;if((f|0)<(e|0)){j=f}else{i=f;n=10;break}}if((n|0)==10){return i|0}return 0}function IFa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return lFa(b+9292|0,b+9123|0)|0}function JFa(a){a=a|0;var b=0;b=c[a+136>>2]|0;return lFa(b+9292|0,b+9124|0)|0}function KFa(a,b){a=a|0;b=b|0;var d=0;d=c[a+136>>2]|0;return lFa(d+9292|0,42-b+(d+9088)|0)|0}function LFa(a,b){a=a|0;b=b|0;var d=0;d=c[a+136>>2]|0;return lFa(d+9292|0,b+42+(d+9088)|0)|0}function MFa(a,b){a=a|0;b=b|0;var d=0;d=c[a+136>>2]|0;return lFa(d+9292|0,((b|0)==0|40)+(d+9088)|0)|0}function NFa(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0;l=i;i=i+2144|0;m=l|0;n=l+2048|0;o=l+2112|0;p=l+2128|0;q=e+136|0;r=c[q>>2]|0;s=c[e+160>>2]|0;t=c[s+32+(k<<2)>>2]|0;u=e+180|0;v=c[u>>2]|0;w=ca(g>>c[v+13152+(k<<2)>>2],t)|0;g=(c[s+(k<<2)>>2]|0)+(w+(f>>c[v+13140+(k<<2)>>2]<<c[v+56>>2]))|0;mrc(m|0,0,2048)|0;mrc(n|0,0,64)|0;f=1<<h;w=r+184600|0;s=(a[w]|0)==0;do{if(s){x=a[r+173182|0]|0;if((k|0)==0){y=(c[v+13164>>2]|0)+x|0}else{z=c[e+184>>2]|0;if((k|0)==1){A=(c[e+3036>>2]|0)+(c[z+28>>2]|0)|0}else{A=(c[e+3040>>2]|0)+(c[z+32>>2]|0)|0}z=A+x|0;x=c[v+13164>>2]|0;B=-x|0;if((z|0)<(B|0)){C=B}else{C=(z|0)>57?57:z}do{if((C|0)<30){D=C}else{if((C|0)>43){D=C-6|0;break}else{D=c[1375088+(C-30<<2)>>2]|0;break}}}while(0);y=x+D|0}z=(c[v+52>>2]|0)+h|0;B=z-5|0;E=1<<z-6;z=d[1375144+(d[1375024+y|0]|0)|0]<<d[1375152+y|0];if((a[v+634|0]|0)==0){F=B;H=E;I=z;J=16;K=0;break}L=c[e+184>>2]|0;M=(a[L+68|0]|0)==0?v+635|0:L+69|0;L=(c[r+184588>>2]|0)!=1|0;if((h|0)==5){N=L;O=M+1152+(L<<6)|0}else{P=(-L&3)+k|0;L=M+((h-2|0)*384|0)+(P<<6)|0;if((h|0)>3){N=P;O=L}else{F=B;H=E;I=z;J=16;K=L;break}}F=B;H=E;I=z;J=d[M+1536+((h-4|0)*6|0)+N|0]|0;K=O}else{F=0;H=0;I=0;J=0;K=0}}while(0);O=e+184|0;do{if((a[(c[O>>2]|0)+21|0]|0)==0){Q=0}else{if(!(s&(h|0)==2)){Q=0;break}Q=lFa(r+9292|0,((k|0)!=0|46)+(r+9088)|0)|0}}while(0);s=(h<<1)-1|0;N=(k|0)==0;if(N){R=h+1>>2;S=(h*3|0)+42+(h-1>>2)|0}else{R=h-2|0;S=63}v=0;while(1){if((v|0)>=(s|0)){break}y=c[q>>2]|0;if((lFa(y+9292|0,(v>>R)+S+(y+9088)|0)|0)==0){break}else{v=v+1|0}}if(N){T=h+1>>2;U=(h*3|0)+60+(h-1>>2)|0}else{T=h-2|0;U=81}S=0;while(1){if((S|0)>=(s|0)){break}R=c[q>>2]|0;if((lFa(R+9292|0,(S>>T)+U+(R+9088)|0)|0)==0){break}else{S=S+1|0}}if((v|0)>3){U=(v>>1)-1|0;T=c[q>>2]|0;s=T+9292|0;R=c[s>>2]<<1;c[s>>2]=R;do{if((R&65534|0)==0){y=T+9308|0;D=c[y>>2]|0;C=R-65535+(d[D+1|0]<<1|d[D]<<9)|0;c[s>>2]=C;if(!(D>>>0<(c[T+9312>>2]|0)>>>0)){V=C;break}c[y>>2]=D+2;V=C}else{V=R}}while(0);R=c[T+9296>>2]<<17;if((V|0)<(R|0)){W=0}else{c[s>>2]=V-R;W=1}a:do{if((U|0)>1){R=2;V=W;while(1){s=V<<1;T=c[q>>2]|0;C=T+9292|0;D=c[C>>2]<<1;c[C>>2]=D;do{if((D&65534|0)==0){y=T+9308|0;A=c[y>>2]|0;M=D-65535+(d[A+1|0]<<1|d[A]<<9)|0;c[C>>2]=M;if(!(A>>>0<(c[T+9312>>2]|0)>>>0)){X=M;break}c[y>>2]=A+2;X=M}else{X=D}}while(0);D=c[T+9296>>2]<<17;if((X|0)<(D|0)){Y=0}else{c[C>>2]=X-D;Y=1}D=Y|s;if((R|0)>=(U|0)){Z=D;break a}R=R+1|0;V=D}}else{Z=W}}while(0);_=Z+((v&1|2)<<U)|0}else{_=v}if((S|0)>3){v=(S>>1)-1|0;U=c[q>>2]|0;Z=U+9292|0;W=c[Z>>2]<<1;c[Z>>2]=W;do{if((W&65534|0)==0){Y=U+9308|0;X=c[Y>>2]|0;V=W-65535+(d[X+1|0]<<1|d[X]<<9)|0;c[Z>>2]=V;if(!(X>>>0<(c[U+9312>>2]|0)>>>0)){$=V;break}c[Y>>2]=X+2;$=V}else{$=W}}while(0);W=c[U+9296>>2]<<17;if(($|0)<(W|0)){aa=0}else{c[Z>>2]=$-W;aa=1}b:do{if((v|0)>1){W=2;$=aa;while(1){Z=$<<1;U=c[q>>2]|0;V=U+9292|0;X=c[V>>2]<<1;c[V>>2]=X;do{if((X&65534|0)==0){Y=U+9308|0;R=c[Y>>2]|0;x=X-65535+(d[R+1|0]<<1|d[R]<<9)|0;c[V>>2]=x;if(!(R>>>0<(c[U+9312>>2]|0)>>>0)){ba=x;break}c[Y>>2]=R+2;ba=x}else{ba=X}}while(0);X=c[U+9296>>2]<<17;if((ba|0)<(X|0)){da=0}else{c[V>>2]=ba-X;da=1}X=da|Z;if((W|0)>=(v|0)){ea=X;break b}W=W+1|0;$=X}}else{ea=aa}}while(0);fa=ea+((S&1|2)<<v)|0}else{fa=S}S=(j|0)==2;v=S?_:fa;ea=S?fa:_;_=ea>>2;fa=v>>2;do{if((j|0)==0){S=d[(ea&3)+(1546992+((v&3)<<2))|0]|0;if((f|0)==8){ga=(d[1547008+(fa<<1)+_|0]<<4)+S|0;ha=1091776;ia=1091784;ja=1375472;ka=1375456;break}else if((f|0)==16){ga=(d[1546992+(fa<<2)+_|0]<<4)+S|0;ha=1375472;ia=1375456;ja=1375472;ka=1375456;break}else if((f|0)==4){ga=S;ha=5121816;ia=5121816;ja=1375472;ka=1375456;break}else{ga=(d[1546928+(fa<<3)+_|0]<<4)+S|0;ha=1375392;ia=1375328;ja=1375472;ka=1375456;break}}else if((j|0)==1){ga=d[1091680+(v<<3)+ea|0]|0;ha=1091784;ia=1091776;ja=1091760;ka=1091744}else{ga=d[1091680+(ea<<3)+v|0]|0;ha=1091776;ia=1091784;ja=1091744;ka=1091760}}while(0);v=ga+1|0;ea=ga>>4;if((ea|0)>-1){ga=(1<<h-2)-1|0;S=(k|0)>0;aa=S?86:84;da=o|0;ba=f-1>>2;f=(h|0)==2;$=(h|0)==3;W=(j|0)==0?9:15;j=(k|0)!=0?12:21;k=p|0;X=N?2:0;s=I;C=(I|0)<0|0?-1:0;I=H;T=(H|0)<0|0?-1:0;H=F;F=(h|0)<4;x=e+4|0;R=16;Y=ea;D=1;while(1){M=Y<<4;A=a[ha+Y|0]|0;y=A&255;z=a[ia+Y|0]|0;E=z&255;B=(Y|0)>0;if((Y|0)<(ea|0)&B){if((y|0)<(ga|0)){la=d[n+(y+1<<3)+E|0]|0}else{la=0}if((E|0)<(ga|0)){ma=(d[E+1+(n+(y<<3))|0]|0)+la|0}else{ma=la}L=c[q>>2]|0;P=(lFa(L+9292|0,((ma|0)>1?1:ma)+aa+(L+9088)|0)|0)&255;a[n+(y<<3)+E|0]=P;na=1;oa=P}else{do{if((y|0)==(_|0)&(E|0)==(fa|0)){pa=1}else{if(!(A<<24>>24==0)){pa=0;break}pa=z<<24>>24==0|0}}while(0);a[n+(y<<3)+E|0]=pa;na=0;oa=pa}z=v-M|0;A=(Y|0)==(ea|0);if(A){a[da]=z+255;qa=z-2|0;ra=1}else{qa=15;ra=0}if((y|0)<(ba|0)){sa=d[n+(y+1<<3)+E|0]|0}else{sa=0}if((E|0)<(ba|0)){ta=(d[E+1+(n+(y<<3))|0]<<1)+sa|0}else{ta=sa}c:do{if((qa|0)>-1){z=M>>4;P=d[ha+z|0]<<2;L=d[ia+z|0]<<2;z=y<<2;ua=E<<2;if(oa<<24>>24==0){va=qa;while(1){if((va|0)>0){va=va-1|0}else{wa=ra;break c}}}else{xa=qa;ya=na;za=ra;Aa=oa}while(1){va=P+(d[ja+xa|0]|0)|0;Z=L+(d[ka+xa|0]|0)|0;do{if((xa|0)>0|(ya|0)==0){do{if((va|0)==(-Z|0)){Ba=0}else{if(f){Ba=d[566368+((Z<<2)+va)|0]|0;break}do{if((ta|0)==2){V=va&3;Ca=(V|0)==3?0:2-V|0}else if((ta|0)==0){V=(Z&3)+(va&3)|0;if((V|0)==0){Ca=2;break}Ca=(V|0)<3|0}else if((ta|0)==1){V=Z&3;Ca=(V|0)==3?0:2-V|0}else{Ca=2}}while(0);if(N){Da=((Z|va)&2147483644|0)!=0?Ca+3|0:Ca}else{Da=Ca}if($){Ba=Da+W|0;break}else{Ba=Da+j|0;break}}}while(0);V=c[q>>2]|0;if((lFa(V+9292|0,(N?Ba:Ba+27|0)+88+(V+9088)|0)|0)!=1){Ea=za;Fa=ya;Ga=Aa;break}a[o+(za&255)|0]=xa;Ea=za+1&255;Fa=0;Ga=Aa}else{if((va|0)!=(z|0)){Ea=za;Fa=ya;Ga=Aa;break}if((Z|0)!=(ua|0)|(ya|0)==0){Ea=za;Fa=ya;Ga=Aa;break}if(Aa<<24>>24==0){Ea=za;Fa=ya;Ga=0;break}a[o+(za&255)|0]=xa;Ea=za+1&255;Fa=ya;Ga=Aa}}while(0);if((xa|0)>0){xa=xa-1|0;ya=Fa;za=Ea;Aa=Ga}else{wa=Ea;break}}}else{wa=ra}}while(0);E=wa&255;d:do{if(wa<<24>>24==0){Ha=D;Ia=R}else{mrc(k|0,0,16)|0;y=(B?X:0)|(D|0)==0&(A^1)&1;ua=a[da]|0;z=ua&255;L=E>>>0>8>>>0?8:E;e:do{if((L|0)==0){Ja=1;Ka=-1}else{P=y<<2;Z=1;va=1;V=-1;U=ua;while(1){La=U&255;Ma=va+P|0;Na=c[q>>2]|0;Oa=(lFa(Na+9292|0,(S?Ma+16|0:Ma)+130+(Na+9088)|0)|0)&255;a[p+La|0]=Oa;if(Oa<<24>>24==0){Pa=((va-1|0)>>>0<2>>>0)+va|0}else{Pa=0}Na=Oa<<24>>24!=0&(V|0)==-1?La:V;if((Z|0)>=(L|0)){Ja=Pa;Ka=Na;break e}La=a[o+Z|0]|0;Z=Z+1|0;va=Pa;V=Na;U=La}}}while(0);L=E-1|0;U=a[o+L|0]|0;if((z-(U&255)|0)>3){Qa=(a[w]|0)!=0}else{Qa=1}if(!((Ka|0)==-1)){V=c[q>>2]|0;va=lFa(V+9292|0,(S?y|4:y)+154+(V+9088)|0)|0;V=p+Ka|0;a[V]=(d[V]|0)+va}if((a[(c[O>>2]|0)+4|0]|0)==0|Qa){va=1;V=0;while(1){Z=c[q>>2]|0;P=Z+9292|0;La=c[P>>2]<<1;c[P>>2]=La;do{if((La&65534|0)==0){Na=Z+9308|0;Oa=c[Na>>2]|0;Ma=La-65535+(d[Oa+1|0]<<1|d[Oa]<<9)|0;c[P>>2]=Ma;if(!(Oa>>>0<(c[Z+9312>>2]|0)>>>0)){Ra=Ma;break}c[Na>>2]=Oa+2;Ra=Ma}else{Ra=La}}while(0);La=c[Z+9296>>2]<<17;if((Ra|0)<(La|0)){Sa=0}else{c[P>>2]=Ra-La;Sa=1}Ta=Sa|V;if((va|0)>=(E|0)){break}va=va+1|0;V=Ta<<1}Ua=Ta<<16-E&65535}else{V=L&255;f:do{if((L&255)<<24>>24==0){Va=0}else{va=1;y=0;while(1){z=c[q>>2]|0;La=z+9292|0;Ma=c[La>>2]<<1;c[La>>2]=Ma;do{if((Ma&65534|0)==0){Oa=z+9308|0;Na=c[Oa>>2]|0;Wa=Ma-65535+(d[Na+1|0]<<1|d[Na]<<9)|0;c[La>>2]=Wa;if(!(Na>>>0<(c[z+9312>>2]|0)>>>0)){Xa=Wa;break}c[Oa>>2]=Na+2;Xa=Wa}else{Xa=Ma}}while(0);Ma=c[z+9296>>2]<<17;if((Xa|0)<(Ma|0)){Ya=0}else{c[La>>2]=Xa-Ma;Ya=1}Ma=Ya|y;if((va|0)>=(V|0)){Va=Ma;break f}va=va+1|0;y=Ma<<1}}}while(0);Ua=Va<<17-E&65535}V=M>>4;L=d[ha+V|0]<<2;y=d[ia+V|0]<<2;V=R;va=0;P=0;Z=Ua;Ma=0;Wa=ua;while(1){Na=Wa&255;Oa=L+(d[ja+Na|0]|0)|0;Za=y+(d[ka+Na|0]|0)|0;_a=(d[p+Na|0]|0)+1|0;$a=0;if((va|0)<8){ab=(Na|0)==(Ka|0);bb=ab?0:0;cb=ab?3:2}else{bb=0;cb=1}do{if((_a|0)==(cb|0)&($a|0)==(bb|0)){ab=0;while(1){Na=c[q>>2]|0;db=Na+9292|0;eb=c[db>>2]<<1;c[db>>2]=eb;do{if((eb&65534|0)==0){fb=Na+9308|0;gb=c[fb>>2]|0;hb=eb-65535+(d[gb+1|0]<<1|d[gb]<<9)|0;c[db>>2]=hb;if(!(gb>>>0<(c[Na+9312>>2]|0)>>>0)){ib=hb;break}c[fb>>2]=gb+2;ib=hb}else{ib=eb}}while(0);eb=c[Na+9296>>2]<<17;if((ib|0)<(eb|0)){jb=ab;break}c[db>>2]=ib-eb;eb=ab+1|0;if((eb|0)<100){ab=eb}else{jb=eb;break}}do{if((jb|0)==100){KIb(c[x>>2]|0,16,2538232,(ab=i,i=i+8|0,c[ab>>2]=100,ab)|0);i=ab;kb=163}else{if((jb|0)>=3){kb=163;break}g:do{if((P|0)>0){ab=0;La=1;while(1){z=c[q>>2]|0;eb=z+9292|0;hb=c[eb>>2]<<1;c[eb>>2]=hb;do{if((hb&65534|0)==0){gb=z+9308|0;fb=c[gb>>2]|0;lb=hb-65535+(d[fb+1|0]<<1|d[fb]<<9)|0;c[eb>>2]=lb;if(!(fb>>>0<(c[z+9312>>2]|0)>>>0)){mb=lb;break}c[gb>>2]=fb+2;mb=lb}else{mb=hb}}while(0);hb=c[z+9296>>2]<<17;if((mb|0)<(hb|0)){nb=0}else{c[eb>>2]=mb-hb;nb=1}hb=nb|ab;if((La|0)>=(P|0)){ob=hb;break g}ab=hb<<1;La=La+1|0}}else{ob=0}}while(0);pb=ob+(jb<<P)|0}}while(0);if((kb|0)==163){kb=0;db=jb-3|0;Na=db+P|0;h:do{if((Na|0)>0){La=0;ab=1;while(1){hb=c[q>>2]|0;lb=hb+9292|0;fb=c[lb>>2]<<1;c[lb>>2]=fb;do{if((fb&65534|0)==0){gb=hb+9308|0;qb=c[gb>>2]|0;rb=fb-65535+(d[qb+1|0]<<1|d[qb]<<9)|0;c[lb>>2]=rb;if(!(qb>>>0<(c[hb+9312>>2]|0)>>>0)){sb=rb;break}c[gb>>2]=qb+2;sb=rb}else{sb=fb}}while(0);fb=c[hb+9296>>2]<<17;if((sb|0)<(fb|0)){tb=0}else{c[lb>>2]=sb-fb;tb=1}fb=tb|La;if((ab|0)>=(Na|0)){ub=fb;break h}La=fb<<1;ab=ab+1|0}}else{ub=0}}while(0);pb=ub+((1<<db)+2<<P)|0}Na=wrc(pb,(pb|0)<0|0?-1:0,_a,$a)|0;ab=G;La=3<<P;fb=(La|0)<0|0?-1:0;if(!((ab|0)>(fb|0)|(ab|0)==(fb|0)&Na>>>0>La>>>0)){vb=P;wb=ab;xb=Na;break}La=P+1|0;vb=(La|0)>4?4:La;wb=ab;xb=Na}else{vb=P;wb=$a;xb=_a}}while(0);do{if((a[(c[O>>2]|0)+4|0]|0)==0|Qa){yb=Ma;zb=wb;Ab=xb}else{_a=wrc(xb,wb,Ma,0)|0;$a=_a;if(!(Wa<<24>>24==U<<24>>24)){yb=$a;zb=wb;Ab=xb;break}_a=($a&1|0)==0;Na=xrc(0,0,xb,wb)|0;yb=$a;zb=_a?wb:G;Ab=_a?xb:Na}}while(0);Na=Z<<16>>16>-1;_a=xrc(0,0,Ab,zb)|0;$a=Na?Ab:_a;_a=Na?zb:G;Na=Z<<1;ab=$a&65535;do{if((a[w]|0)==0){do{if((a[(c[u>>2]|0)+634|0]|0)==0){Bb=V}else{if(!((Za|Oa|0)!=0|F)){Bb=J;break}if((h|0)==3){Cb=(Za<<3)+Oa|0}else if((h|0)==4){Cb=(Za>>>1<<3)+(Oa>>>1)|0}else if((h|0)==5){Cb=(Za>>>2<<3)+(Oa>>>2)|0}else{Cb=(Za<<2)+Oa|0}Bb=d[K+Cb|0]|0}}while(0);db=Erc($a,_a,s,C)|0;La=Erc(db,G,Bb,(Bb|0)<0|0?-1:0)|0;db=wrc(La,G,I,T)|0;La=Arc(db|0,G|0,H|0)|0;db=G;fb=0;if((db|0)<(fb|0)|(db|0)==(fb|0)&La>>>0<0>>>0){Db=(La&-32768|0)==(-32768|0)&(db&268435455|0)==268435455?La&65535:-32768;Eb=Bb;break}else{fb=0;Db=db>>>0>fb>>>0|db>>>0==fb>>>0&La>>>0>32767>>>0?32767:La&65535;Eb=Bb;break}}else{Db=ab;Eb=V}}while(0);b[m+((Za<<h)+Oa<<1)>>1]=Db;ab=va+1|0;if((ab|0)>=(E|0)){Ha=Ja;Ia=Eb;break d}V=Eb;va=ab;P=vb;Z=Na;Ma=yb;Wa=a[o+ab|0]|0}}}while(0);if(B){R=Ia;Y=Y-1|0;D=Ha}else{break}}}if((a[w]|0)!=0){ef[c[e+5864+(h-2<<2)>>2]&4095](g,m|0,t);i=l;return}if((Q|0)!=0){ef[c[e+5880>>2]&4095](g,m|0,t);i=l;return}if((c[r+184588>>2]|0)==1&N&(h|0)==2){ef[c[e+5884>>2]&4095](g,m|0,t);i=l;return}else{ef[c[e+5888+(h-2<<2)>>2]&4095](g,m|0,t);i=l;return}}function OFa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;f=a+136|0;e=c[f>>2]|0;h=lFa(e+9292|0,e+9119|0)|0;j=c[f>>2]|0;k=lFa(j+9292|0,j+9119|0)|0;if((h|0)==0){l=0}else{j=c[f>>2]|0;l=(lFa(j+9292|0,j+9122|0)|0)+h|0}if((k|0)==0){m=0}else{h=c[f>>2]|0;m=(lFa(h+9292|0,h+9122|0)|0)+k|0}if((l|0)==1){k=c[f>>2]|0;h=k+9292|0;j=c[h>>2]<<1;c[h>>2]=j;do{if((j&65534|0)==0){n=k+9308|0;o=c[n>>2]|0;p=j-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9)|0;c[h>>2]=p;if(!(o>>>0<(c[k+9312>>2]|0)>>>0)){q=p;break}c[n>>2]=o+2;q=p}else{q=j}}while(0);j=c[k+9296>>2]<<17;k=q-j|0;q=k>>31;c[h>>2]=(q&j)+k;b[e+184616>>1]=(q^65535)-q}else if((l|0)==0){b[e+184616>>1]=0}else if((l|0)==2){l=2;q=1;while(1){k=c[f>>2]|0;j=k+9292|0;h=c[j>>2]<<1;c[j>>2]=h;do{if((h&65534|0)==0){p=k+9308|0;o=c[p>>2]|0;n=h-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9)|0;c[j>>2]=n;if(!(o>>>0<(c[k+9312>>2]|0)>>>0)){r=n;break}c[p>>2]=o+2;r=n}else{r=h}}while(0);h=c[k+9296>>2]<<17;if((r|0)<(h|0)){s=l;t=q;break}c[j>>2]=r-h;h=(1<<q)+l|0;n=q+1|0;if((n|0)<100){l=h;q=n}else{s=h;t=n;break}}if((t|0)==100){KIb(c[a+4>>2]|0,16,2538232,(u=i,i=i+8|0,c[u>>2]=100,u)|0);i=u;q=c[f>>2]|0;v=s;w=100;x=q;y=q+9292|0;z=14}else{q=c[f>>2]|0;l=q+9292|0;if((t|0)==0){A=s;B=q;C=l}else{v=s;w=t;x=q;y=l;z=14}}if((z|0)==14){while(1){z=0;l=w-1|0;q=y|0;t=c[q>>2]<<1;c[q>>2]=t;do{if((t&65534|0)==0){s=x+9308|0;r=c[s>>2]|0;n=t-65535+((d[r+1|0]|0)<<1|(d[r]|0)<<9)|0;c[q>>2]=n;if(!(r>>>0<(c[x+9312>>2]|0)>>>0)){D=n;break}c[s>>2]=r+2;D=n}else{D=t}}while(0);t=c[x+9296>>2]<<17;if((D|0)<(t|0)){E=0}else{c[q>>2]=D-t;E=1}t=(E<<l)+v|0;j=c[f>>2]|0;k=j+9292|0;if((l|0)==0){A=t;B=j;C=k;break}else{v=t;w=l;x=j;y=k;z=14}}}y=-A|0;A=C|0;C=c[A>>2]<<1;c[A>>2]=C;do{if((C&65534|0)==0){x=B+9308|0;w=c[x>>2]|0;v=C-65535+((d[w+1|0]|0)<<1|(d[w]|0)<<9)|0;c[A>>2]=v;if(!(w>>>0<(c[B+9312>>2]|0)>>>0)){F=v;break}c[x>>2]=w+2;F=v}else{F=C}}while(0);C=c[B+9296>>2]<<17;B=F-C|0;F=B>>31;c[A>>2]=(F&C)+B;b[e+184616>>1]=(F^y)-F}if((m|0)==2){F=2;y=1;while(1){B=c[f>>2]|0;C=B+9292|0;A=c[C>>2]<<1;c[C>>2]=A;do{if((A&65534|0)==0){v=B+9308|0;w=c[v>>2]|0;x=A-65535+((d[w+1|0]|0)<<1|(d[w]|0)<<9)|0;c[C>>2]=x;if(!(w>>>0<(c[B+9312>>2]|0)>>>0)){G=x;break}c[v>>2]=w+2;G=x}else{G=A}}while(0);A=c[B+9296>>2]<<17;if((G|0)<(A|0)){H=F;I=y;break}c[C>>2]=G-A;A=(1<<y)+F|0;l=y+1|0;if((l|0)<100){F=A;y=l}else{H=A;I=l;break}}if((I|0)==100){KIb(c[a+4>>2]|0,16,2538232,(u=i,i=i+8|0,c[u>>2]=100,u)|0);i=u;u=c[f>>2]|0;J=H;K=100;L=u;M=u+9292|0;z=38}else{u=c[f>>2]|0;a=u+9292|0;if((I|0)==0){N=H;O=u;P=a}else{J=H;K=I;L=u;M=a;z=38}}if((z|0)==38){while(1){z=0;a=K-1|0;u=M|0;I=c[u>>2]<<1;c[u>>2]=I;do{if((I&65534|0)==0){H=L+9308|0;y=c[H>>2]|0;F=I-65535+((d[y+1|0]|0)<<1|(d[y]|0)<<9)|0;c[u>>2]=F;if(!(y>>>0<(c[L+9312>>2]|0)>>>0)){Q=F;break}c[H>>2]=y+2;Q=F}else{Q=I}}while(0);I=c[L+9296>>2]<<17;if((Q|0)<(I|0)){R=0}else{c[u>>2]=Q-I;R=1}I=(R<<a)+J|0;C=c[f>>2]|0;B=C+9292|0;if((a|0)==0){N=I;O=C;P=B;break}else{J=I;K=a;L=C;M=B;z=38}}}z=-N|0;N=P|0;P=c[N>>2]<<1;c[N>>2]=P;do{if((P&65534|0)==0){M=O+9308|0;L=c[M>>2]|0;K=P-65535+((d[L+1|0]|0)<<1|(d[L]|0)<<9)|0;c[N>>2]=K;if(!(L>>>0<(c[O+9312>>2]|0)>>>0)){S=K;break}c[M>>2]=L+2;S=K}else{S=P}}while(0);P=c[O+9296>>2]<<17;O=S-P|0;S=O>>31;c[N>>2]=(S&P)+O;b[e+184618>>1]=(S^z)-S;i=g;return}else if((m|0)==1){S=c[f>>2]|0;f=S+9292|0;z=c[f>>2]<<1;c[f>>2]=z;do{if((z&65534|0)==0){O=S+9308|0;P=c[O>>2]|0;N=z-65535+((d[P+1|0]|0)<<1|(d[P]|0)<<9)|0;c[f>>2]=N;if(!(P>>>0<(c[S+9312>>2]|0)>>>0)){T=N;break}c[O>>2]=P+2;T=N}else{T=z}}while(0);z=c[S+9296>>2]<<17;S=T-z|0;T=S>>31;c[f>>2]=(T&z)+S;b[e+184618>>1]=(T^65535)-T;i=g;return}else if((m|0)==0){b[e+184618>>1]=0;i=g;return}else{i=g;return}}function PFa(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=b+136|0;e=c[h>>2]|0;d=b+180|0;i=c[d>>2]|0;j=c[i+13080>>2]|0;k=(1<<j)-1|0;l=-1<<j-(c[(c[b+184>>2]|0)+24>>2]|0);j=l&f;m=l&g;n=c[i+13116>>2]|0;o=c[i+13064>>2]|0;i=j>>o;p=m>>o;if((k&f|0)==0){q=0}else{q=(j&k|0)!=0|0}if((k&g|0)==0){r=0}else{r=(m&k|0)!=0|0}k=e+9271|0;do{if((a[k]|0)==0){if((l&(g|f)|0)==0){s=7;break}t=c[e+173184>>2]|0}else{s=7}}while(0);if((s|0)==7){a[k]=(a[e+173196|0]|0)==0|0;t=a[b+3072|0]|0}if((q|0)==0){u=t}else{q=i-1+(ca(p,n)|0)|0;u=a[(c[b+7316>>2]|0)+q|0]|0}if((r|0)==0){v=t}else{t=(ca(p-1|0,n)|0)+i|0;v=a[(c[b+7316>>2]|0)+t|0]|0}t=u+1+v>>1;v=c[h>>2]|0;h=c[v+173188>>2]|0;if((h|0)==0){a[v+173182|0]=t;return}u=c[(c[d>>2]|0)+13164>>2]|0;d=h+52+t+(u<<1)|0;if((d|0)>0){w=d}else{w=-52-u+1+d|0}a[v+173182|0]=d-u-w+((w|0)%(u+52|0)|0);return}function QFa(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=b+3480|0;j=c[i>>2]|0;k=c[j+16>>2]|0;l=b+180|0;m=c[l>>2]|0;n=c[m+13084>>2]|0;o=c[m+13072>>2]|0;p=c[m+13132>>2]|0;q=c[m+13124>>2]|0;m=ca(p,e>>n)|0;r=d>>n;s=a[k+((m+r|0)*14|0)+12|0]|0;do{if((e|0)>0&(e&7|0)==0){t=e-1|0;u=1<<f;if((u|0)<=0){v=n;break}w=ca(p,t>>n)|0;x=ca(q,t>>o)|0;y=b+7348|0;z=ca(q,e>>o)|0;A=b+3026|0;B=(g&1|0)==0;C=b+184|0;D=(g&2|0)==0;E=(e|0)==0;F=b+3025|0;G=b+5808|0;H=b+7324|0;I=0;J=j;while(1){K=I+d|0;L=K>>n;M=K>>o;N=c[y>>2]|0;O=a[N+(M+x)|0]|0;P=a[N+(M+z)|0]|0;M=RFa(b,k+((L+m|0)*14|0)|0,P,k+((L+w|0)*14|0)|0,O,mGa(b,J,K,t)|0,1)|0;if((a[A]|0)!=0|B){Q=6}else{if(((e|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0){R=0}else{Q=6}}do{if((Q|0)==6){Q=0;if((a[(c[C>>2]|0)+53|0]|0)!=0|D){R=M;break}R=((e|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0?0:M}}while(0);do{if(!E){if((a[F]|0)==1|(R|0)==0){break}M=(ca(c[G>>2]|0,e)|0)+K>>2;a[(c[H>>2]|0)+M|0]=R}}while(0);K=I+4|0;if((K|0)>=(u|0)){break}I=K;J=c[i>>2]|0}v=c[(c[l>>2]|0)+13084>>2]|0}else{v=n}}while(0);R=s<<24>>24==0;do{if(v>>>0<f>>>0&R){s=1<<f;if((s|0)<=8){break}m=b+7348|0;j=b+3025|0;g=b+5808|0;J=b+7324|0;I=8;do{u=I+e|0;H=u-1|0;G=ca(H>>n,p)|0;F=ca(u>>n,p)|0;E=ca(H>>o,q)|0;D=ca(u>>o,q)|0;C=0;do{B=C+d|0;A=B>>n;t=B>>o;w=c[m>>2]|0;z=a[w+(t+E)|0]|0;x=a[w+(t+D)|0]|0;t=RFa(b,k+((A+F|0)*14|0)|0,x,k+((A+G|0)*14|0)|0,z,mGa(b,c[i>>2]|0,B,H)|0,0)|0;z=(a[j]|0)==1?0:t;if((z|0)!=0){t=(ca(c[g>>2]|0,u)|0)+B>>2;a[(c[J>>2]|0)+t|0]=z}C=C+4|0;}while((C|0)<(s|0));I=I+8|0;}while((I|0)<(s|0))}}while(0);a:do{if((d|0)>0&(d&7|0)==0){v=d-1|0;s=v>>n;I=v>>o;J=d>>o;g=1<<f;if((g|0)<=0){break}j=b+7348|0;m=b+3026|0;C=b+184|0;u=(h&2|0)==0;H=(d|0)==0;G=b+3025|0;F=d>>3;D=b+5808|0;E=b+7328|0;if((h&1|0)==0){z=0;while(1){t=z+e|0;B=ca(t>>n,p)|0;A=ca(t>>o,q)|0;x=c[j>>2]|0;w=a[x+(A+I)|0]|0;y=a[x+(A+J)|0]|0;A=RFa(b,k+((B+r|0)*14|0)|0,y,k+((B+s|0)*14|0)|0,w,mGa(b,c[i>>2]|0,v,t)|0,1)|0;if((a[(c[C>>2]|0)+53|0]|0)!=0|u){S=A}else{S=((d|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0?0:A}do{if(!H){if((a[G]|0)==1|(S|0)==0){break}A=(ca(c[D>>2]|0,t>>2)|0)+F|0;a[(c[E>>2]|0)+A|0]=S}}while(0);z=z+4|0;if((z|0)>=(g|0)){break a}}}else{T=0}do{z=T+e|0;t=ca(z>>n,p)|0;A=ca(z>>o,q)|0;w=c[j>>2]|0;B=a[w+(A+I)|0]|0;y=a[w+(A+J)|0]|0;A=RFa(b,k+((t+r|0)*14|0)|0,y,k+((t+s|0)*14|0)|0,B,mGa(b,c[i>>2]|0,v,z)|0,1)|0;if((a[m]|0)==0){if(((d|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0){U=0}else{Q=33}}else{Q=33}do{if((Q|0)==33){Q=0;if((a[(c[C>>2]|0)+53|0]|0)!=0|u){U=A;break}U=((d|0)%(1<<c[(c[l>>2]|0)+13080>>2]|0)|0|0)==0?0:A}}while(0);do{if(!H){if((a[G]|0)==1|(U|0)==0){break}A=(ca(c[D>>2]|0,z>>2)|0)+F|0;a[(c[E>>2]|0)+A|0]=U}}while(0);T=T+4|0;}while((T|0)<(g|0))}}while(0);if(!((n|0)<(f|0)&R)){return}R=1<<f;if((R|0)<=0){return}f=b+7348|0;T=b+3025|0;U=b+5808|0;l=b+7328|0;if((R|0)>8){V=0}else{Q=0;do{Q=Q+4|0;}while((Q|0)<(R|0));return}do{Q=V+e|0;r=ca(Q>>n,p)|0;S=ca(Q>>o,q)|0;h=Q>>2;g=8;do{E=g+d|0;F=E-1|0;D=c[f>>2]|0;G=a[D+((F>>o)+S)|0]|0;H=a[D+((E>>o)+S)|0]|0;D=RFa(b,k+(((E>>n)+r|0)*14|0)|0,H,k+(((F>>n)+r|0)*14|0)|0,G,mGa(b,c[i>>2]|0,F,Q)|0,0)|0;F=(a[T]|0)==1?0:D;if((F|0)!=0){D=(ca(c[U>>2]|0,h)|0)+(E>>3)|0;a[(c[l>>2]|0)+D|0]=F}g=g+8|0;}while((g|0)<(R|0));V=V+4|0;}while((V|0)<(R|0));return}function RFa(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=a[e+10|0]|0;l=(a[e+11|0]|0)+(k<<24>>24)|0;do{if((j|0)!=0){if((a[e+12|0]|0)!=0){m=2;return m|0}if((a[g+12|0]|0)!=0){m=2;return m|0}if((h|f)<<24>>24==0){break}else{m=1}return m|0}}while(0);f=a[g+10|0]|0;if((l|0)!=((a[g+11|0]|0)+(f<<24>>24)|0)){m=1;return m|0}if((l|0)!=2){if(k<<24>>24==0){n=(c[(c[d+3480>>2]|0)+20>>2]|0)+260+(a[e+9|0]<<2)|0;o=e+4|0;p=e+6|0}else{n=(c[(c[d+3480>>2]|0)+20>>2]|0)+64+(a[e+8|0]<<2)|0;o=e|0;p=e+2|0}if(f<<24>>24==0){q=i+260+(a[g+9|0]<<2)|0;r=g+4|0;s=g+6|0}else{q=i+64+(a[g+8|0]<<2)|0;r=g|0;s=g+2|0}if((c[n>>2]|0)!=(c[q>>2]|0)){m=1;return m|0}q=(b[o>>1]|0)-(b[r>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){m=1;return m|0}q=(b[p>>1]|0)-(b[s>>1]|0)|0;m=(((q|0)>-1?q:-q|0)|0)>3|0;return m|0}q=c[(c[d+3480>>2]|0)+20>>2]|0;d=c[q+64+(a[e+8|0]<<2)>>2]|0;s=c[i+64+(a[g+8|0]<<2)>>2]|0;p=(d|0)==(s|0);a:do{if(p){do{if((d|0)==(c[q+260+(a[e+9|0]<<2)>>2]|0)){if((d|0)!=(c[i+260+(a[g+9|0]<<2)>>2]|0)){if(p){break}else{t=20;break a}}r=b[g>>1]|0;o=b[e>>1]|0;n=r-o|0;do{if((((n|0)>-1?n:-n|0)|0)>3){t=14}else{f=(b[g+2>>1]|0)-(b[e+2>>1]|0)|0;if((((f|0)>-1?f:-f|0)|0)>3){t=14;break}f=(b[g+4>>1]|0)-(b[e+4>>1]|0)|0;if((((f|0)>-1?f:-f|0)|0)>3){t=14;break}f=(b[g+6>>1]|0)-(b[e+6>>1]|0)|0;if((((f|0)>-1?f:-f|0)|0)>3){t=14}}}while(0);do{if((t|0)==14){n=(b[g+4>>1]|0)-o|0;if((((n|0)>-1?n:-n|0)|0)>3){m=1;return m|0}n=(b[g+6>>1]|0)-(b[e+2>>1]|0)|0;if((((n|0)>-1?n:-n|0)|0)>3){m=1;return m|0}n=r-(b[e+4>>1]|0)|0;if((((n|0)>-1?n:-n|0)|0)>3){m=1;return m|0}n=(b[g+2>>1]|0)-(b[e+6>>1]|0)|0;if((((n|0)>-1?n:-n|0)|0)>3){m=1}else{break}return m|0}}while(0);m=0;return m|0}}while(0);r=c[i+260+(a[g+9|0]<<2)>>2]|0;if((r|0)!=(c[q+260+(a[e+9|0]<<2)>>2]|0)){u=r;break}r=(b[g>>1]|0)-(b[e>>1]|0)|0;if((((r|0)>-1?r:-r|0)|0)>3){m=1;return m|0}r=(b[g+2>>1]|0)-(b[e+2>>1]|0)|0;if((((r|0)>-1?r:-r|0)|0)>3){m=1;return m|0}r=(b[g+4>>1]|0)-(b[e+4>>1]|0)|0;if((((r|0)>-1?r:-r|0)|0)>3){m=1;return m|0}else{r=(b[g+6>>1]|0)-(b[e+6>>1]|0)|0;return(((r|0)>-1?r:-r|0)|0)>3|0}}else{t=20}}while(0);if((t|0)==20){u=c[i+260+(a[g+9|0]<<2)>>2]|0}if((u|0)!=(d|0)){m=1;return m|0}if((s|0)!=(c[q+260+(a[e+9|0]<<2)>>2]|0)){m=1;return m|0}q=(b[g+4>>1]|0)-(b[e>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){m=1;return m|0}q=(b[g+6>>1]|0)-(b[e+2>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){m=1;return m|0}q=(b[g>>1]|0)-(b[e+4>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){m=1;return m|0}q=(b[g+2>>1]|0)-(b[e+6>>1]|0)|0;m=(((q|0)>-1?q:-q|0)|0)>3|0;return m|0}function SFa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0;h=i;i=i+112|0;j=h|0;k=h+16|0;l=h+32|0;m=h+48|0;n=h+56|0;o=h+64|0;p=h+72|0;q=h+80|0;r=h+88|0;s=h+96|0;t=h+104|0;u=s;v=t;w=s;x=t;b[s>>1]=0;b[t>>1]=0;t=e+180|0;s=c[t>>2]|0;y=c[s+13080>>2]|0;z=1<<y;A=(ca(g>>y,c[s+13104>>2]|0)|0)+(f>>y)|0;y=c[e+3468>>2]|0;B=c[y+(A<<3)+4>>2]|0;C=c[y+(A<<3)>>2]|0;if((c[s+68>>2]|0)==0){D=3}else{if((a[s+13056|0]|0)==0){D=3}else{E=1}}if((D|0)==3){E=(a[(c[e+184>>2]|0)+40|0]|0)!=0}F=(f|0)!=0;if(F){G=A-1|0;H=c[y+(G<<3)+4>>2]|0;I=c[y+(G<<3)>>2]|0}else{H=0;I=0}G=z+f|0;y=c[s+13096>>2]|0;A=(G|0)>(y|0)?y:G;G=z+g|0;z=c[s+13100>>2]|0;s=(G|0)>(z|0)?z:G;G=(s|0)>(g|0);if(G){z=F?f:8;y=(z|0)<(A|0);J=e+5808|0;K=e+7328|0;L=e+7316|0;M=q|0;N=q+4|0;O=B-2&-2;P=r|0;Q=r+4|0;R=e+160|0;S=w+1|0;T=x+1|0;U=e+6052|0;V=e+7352|0;W=e+6036|0;X=g;while(1){if(y){Y=X>>2;Z=X+4|0;_=Z>>2;$=z;do{aa=$>>3;ba=c[J>>2]|0;da=(ca(ba,Y)|0)+aa|0;ea=c[K>>2]|0;fa=a[ea+da|0]|0;da=fa&255;ga=a[ea+((ca(ba,_)|0)+aa)|0]|0;aa=ga&255;ba=fa<<24>>24!=0;fa=ga<<24>>24==0;do{if(!(fa&(ba^1))){ga=$-1|0;ea=c[t>>2]|0;ha=c[L>>2]|0;ia=c[ea+13064>>2]|0;ja=c[ea+13116>>2]|0;ka=ga>>ia;la=ca(X>>ia,ja)|0;ma=$>>ia;na=(a[ha+(la+ka)|0]|0)+1+(a[ha+(la+ma)|0]|0)>>1;la=ca(Z>>ia,ja)|0;ja=(a[ha+(la+ka)|0]|0)+1+(a[ha+(la+ma)|0]|0)>>1;ma=na+C|0;if((ma|0)<0){oa=0}else{oa=(ma|0)>51?51:ma}c[M>>2]=d[1953840+oa|0]|0;ma=ja+C|0;if((ma|0)<0){pa=0}else{pa=(ma|0)>51?51:ma}c[N>>2]=d[1953840+pa|0]|0;if(ba){ma=(da<<1)+O+na|0;if((ma|0)<0){qa=0}else{qa=(ma|0)>53?53:ma}ra=d[311728+qa|0]|0}else{ra=0}c[P>>2]=ra;if(fa){sa=0}else{ma=(aa<<1)+O+ja|0;if((ma|0)<0){ta=0}else{ta=(ma|0)>53?53:ma}sa=d[311728+ta|0]|0}c[Q>>2]=sa;ma=c[R>>2]|0;ja=c[ma+32>>2]|0;na=ca(ja,X)|0;la=(c[ma>>2]|0)+(($<<c[ea+56>>2])+na)|0;if(!E){_e[c[W>>2]&511](la,ja,M,P,u,v);break}na=c[ea+13084>>2]|0;do{if((ga|X|0)<0){ua=2}else{ma=ga>>na;ha=X>>na;ka=c[ea+13132>>2]|0;if((ma|0)>=(ka|0)){ua=2;break}if((ha|0)>=(c[ea+13136>>2]|0)){ua=2;break}ia=(ca(ka,ha)|0)+ma|0;ua=a[(c[V>>2]|0)+ia|0]|0}}while(0);a[u]=ua;do{if((ga|Z|0)<0){va=2}else{ia=ga>>na;ma=Z>>na;ha=c[ea+13132>>2]|0;if((ia|0)>=(ha|0)){va=2;break}if((ma|0)>=(c[ea+13136>>2]|0)){va=2;break}ka=(ca(ha,ma)|0)+ia|0;va=a[(c[V>>2]|0)+ka|0]|0}}while(0);a[S]=va;do{if(($|X|0)<0){wa=2}else{ga=$>>na;ka=X>>na;ia=c[ea+13132>>2]|0;if((ga|0)>=(ia|0)){wa=2;break}if((ka|0)>=(c[ea+13136>>2]|0)){wa=2;break}ma=(ca(ia,ka)|0)+ga|0;wa=a[(c[V>>2]|0)+ma|0]|0}}while(0);a[v]=wa;do{if(($|Z|0)<0){xa=2}else{ma=$>>na;ga=Z>>na;ka=c[ea+13132>>2]|0;if((ma|0)>=(ka|0)){xa=2;break}if((ga|0)>=(c[ea+13136>>2]|0)){xa=2;break}ia=(ca(ka,ga)|0)+ma|0;xa=a[(c[V>>2]|0)+ia|0]|0}}while(0);a[T]=xa;_e[c[U>>2]&511](la,ja,M,P,u,v)}}while(0);$=$+8|0;}while(($|0)<(A|0))}$=X+8|0;if(($|0)<(s|0)){X=$}else{ya=J;za=K;Aa=L;Ba=R;Ca=S;Da=T;Ea=V;break}}}else{ya=e+5808|0;za=e+7328|0;Aa=e+7316|0;Ba=e+160|0;Ca=w+1|0;Da=x+1|0;Ea=e+7352|0}x=F?f:16;w=(x|0)<(A|0);V=e+184|0;T=B+2|0;S=p|0;R=p+4|0;p=e+6060|0;L=e+6044|0;K=1;do{if(G){J=(K|0)==1;X=g;do{if(w){P=X>>2;M=X+8|0;U=M>>2;xa=(X|0)/2|0;wa=x;do{va=wa>>3;ua=c[ya>>2]|0;W=(ca(ua,P)|0)+va|0;sa=c[za>>2]|0;Q=(a[sa+W|0]|0)==2;W=(a[sa+((ca(ua,U)|0)+va)|0]|0)==2;do{if(Q|W){va=wa-1|0;ua=c[t>>2]|0;sa=c[Aa>>2]|0;ta=c[ua+13064>>2]|0;O=c[ua+13116>>2]|0;ra=va>>ta;qa=ca(X>>ta,O)|0;pa=wa>>ta;N=ca(M>>ta,O)|0;O=(a[sa+(N+ra)|0]|0)+1+(a[sa+(N+pa)|0]|0)>>1;if(Q){N=c[V>>2]|0;ta=((a[sa+(qa+pa)|0]|0)+1+(a[sa+(qa+ra)|0]|0)>>1)+(c[(J?N+28|0:N+32|0)>>2]|0)|0;do{if((ta|0)<0){Fa=0}else{N=(ta|0)>57?57:ta;if((N|0)<30){Fa=N;break}if((N|0)>43){Fa=N-6|0;break}else{Fa=c[1705016+(N-30<<2)>>2]|0;break}}}while(0);ta=Fa+T|0;if((ta|0)<0){Ga=0}else{Ga=(ta|0)>53?53:ta}Ha=d[311728+Ga|0]|0}else{Ha=0}c[S>>2]=Ha;if(W){ta=c[V>>2]|0;N=(c[(J?ta+28|0:ta+32|0)>>2]|0)+O|0;do{if((N|0)<0){Ia=0}else{ta=(N|0)>57?57:N;if((ta|0)<30){Ia=ta;break}if((ta|0)>43){Ia=ta-6|0;break}else{Ia=c[1705016+(ta-30<<2)>>2]|0;break}}}while(0);N=Ia+T|0;if((N|0)<0){Ja=0}else{Ja=(N|0)>53?53:N}Ka=d[311728+Ja|0]|0}else{Ka=0}c[R>>2]=Ka;N=c[Ba>>2]|0;O=c[N+32+(K<<2)>>2]|0;ta=ca(O,xa)|0;ra=(c[N+(K<<2)>>2]|0)+((((wa|0)/2|0)<<c[ua+56>>2])+ta)|0;if(!E){pe[c[L>>2]&1023](ra,O,S,u,v);break}ta=c[ua+13084>>2]|0;do{if((va|X|0)<0){La=2}else{N=va>>ta;qa=X>>ta;sa=c[ua+13132>>2]|0;if((N|0)>=(sa|0)){La=2;break}if((qa|0)>=(c[ua+13136>>2]|0)){La=2;break}pa=(ca(sa,qa)|0)+N|0;La=a[(c[Ea>>2]|0)+pa|0]|0}}while(0);a[u]=La;do{if((va|M|0)<0){Ma=2}else{pa=va>>ta;N=M>>ta;qa=c[ua+13132>>2]|0;if((pa|0)>=(qa|0)){Ma=2;break}if((N|0)>=(c[ua+13136>>2]|0)){Ma=2;break}sa=(ca(qa,N)|0)+pa|0;Ma=a[(c[Ea>>2]|0)+sa|0]|0}}while(0);a[Ca]=Ma;do{if((wa|X|0)<0){Na=2}else{va=wa>>ta;sa=X>>ta;pa=c[ua+13132>>2]|0;if((va|0)>=(pa|0)){Na=2;break}if((sa|0)>=(c[ua+13136>>2]|0)){Na=2;break}N=(ca(pa,sa)|0)+va|0;Na=a[(c[Ea>>2]|0)+N|0]|0}}while(0);a[v]=Na;do{if((wa|M|0)<0){Oa=2}else{N=wa>>ta;va=M>>ta;sa=c[ua+13132>>2]|0;if((N|0)>=(sa|0)){Oa=2;break}if((va|0)>=(c[ua+13136>>2]|0)){Oa=2;break}pa=(ca(sa,va)|0)+N|0;Oa=a[(c[Ea>>2]|0)+pa|0]|0}}while(0);a[Da]=Oa;pe[c[p>>2]&1023](ra,O,S,u,v)}}while(0);wa=wa+16|0;}while((wa|0)<(A|0))}X=X+16|0;}while((X|0)<(s|0))}K=K+1|0;}while((K|0)<3);K=(A|0)==(c[(c[t>>2]|0)+13096>>2]|0)?A:A-8|0;A=(g|0)!=0;p=A?g:8;Oa=f-8|0;if((p|0)<(s|0)){Na=F?Oa:0;F=(Na|0)<(K|0);Ma=e+7324|0;La=q|0;L=q+4|0;q=r|0;Ka=r+4|0;r=e+6048|0;Ja=e+6032|0;Ia=p;while(1){if(F){p=Ia-1|0;Ha=Na;do{Ga=ca(c[ya>>2]|0,Ia)|0;Fa=c[Ma>>2]|0;za=a[Fa+(Ga+Ha>>2)|0]|0;x=za&255;w=Ha+4|0;G=a[Fa+(Ga+w>>2)|0]|0;Ga=G&255;Fa=za<<24>>24!=0;za=G<<24>>24==0;do{if(!(za&(Fa^1))){G=c[t>>2]|0;X=c[Aa>>2]|0;J=c[G+13064>>2]|0;wa=c[G+13116>>2]|0;M=Ha>>J;xa=ca(p>>J,wa)|0;U=ca(Ia>>J,wa)|0;wa=(a[X+(xa+M)|0]|0)+1+(a[X+(U+M)|0]|0)>>1;M=w>>J;J=(a[X+(xa+M)|0]|0)+1+(a[X+(U+M)|0]|0)>>1;M=(Ha|0)>=(f|0);U=M?B:H;X=M?C:I;M=wa+X|0;if((M|0)<0){Pa=0}else{Pa=(M|0)>51?51:M}c[La>>2]=d[1953840+Pa|0]|0;M=J+X|0;if((M|0)<0){Qa=0}else{Qa=(M|0)>51?51:M}c[L>>2]=d[1953840+Qa|0]|0;if(Fa){M=(x<<1)+(U-2&-2)+wa|0;if((M|0)<0){Ra=0}else{Ra=(M|0)>53?53:M}Sa=d[311728+Ra|0]|0}else{Sa=0}c[q>>2]=Sa;if(za){Ta=0}else{M=(Ga<<1)+(U-2&-2)+J|0;if((M|0)<0){Ua=0}else{Ua=(M|0)>53?53:M}Ta=d[311728+Ua|0]|0}c[Ka>>2]=Ta;M=c[Ba>>2]|0;J=c[M+32>>2]|0;U=ca(J,Ia)|0;wa=(c[M>>2]|0)+((Ha<<c[G+56>>2])+U)|0;if(!E){_e[c[Ja>>2]&511](wa,J,La,q,u,v);break}U=c[G+13084>>2]|0;do{if((Ha|p|0)<0){Va=2}else{M=Ha>>U;X=p>>U;xa=c[G+13132>>2]|0;if((M|0)>=(xa|0)){Va=2;break}if((X|0)>=(c[G+13136>>2]|0)){Va=2;break}P=(ca(xa,X)|0)+M|0;Va=a[(c[Ea>>2]|0)+P|0]|0}}while(0);a[u]=Va;do{if((w|p|0)<0){Wa=2}else{P=w>>U;M=p>>U;X=c[G+13132>>2]|0;if((P|0)>=(X|0)){Wa=2;break}if((M|0)>=(c[G+13136>>2]|0)){Wa=2;break}xa=(ca(X,M)|0)+P|0;Wa=a[(c[Ea>>2]|0)+xa|0]|0}}while(0);a[Ca]=Wa;do{if((Ha|Ia|0)<0){Xa=2}else{xa=Ha>>U;P=Ia>>U;M=c[G+13132>>2]|0;if((xa|0)>=(M|0)){Xa=2;break}if((P|0)>=(c[G+13136>>2]|0)){Xa=2;break}X=(ca(M,P)|0)+xa|0;Xa=a[(c[Ea>>2]|0)+X|0]|0}}while(0);a[v]=Xa;do{if((w|Ia|0)<0){Ya=2}else{X=w>>U;xa=Ia>>U;P=c[G+13132>>2]|0;if((X|0)>=(P|0)){Ya=2;break}if((xa|0)>=(c[G+13136>>2]|0)){Ya=2;break}M=(ca(P,xa)|0)+X|0;Ya=a[(c[Ea>>2]|0)+M|0]|0}}while(0);a[Da]=Ya;_e[c[r>>2]&511](wa,J,La,q,u,v)}}while(0);Ha=Ha+8|0;}while((Ha|0)<(K|0))}Ha=Ia+8|0;if((Ha|0)<(s|0)){Ia=Ha}else{Za=Ma;break}}}else{Za=e+7324|0}Ma=A?g:16;A=(Ma|0)<(s|0);Ia=(Oa|0)<(K|0);q=e+6056|0;La=e+6040|0;r=K-8|0;Ya=1;do{if(A){Xa=(Ya|0)==1;Wa=Ma;do{if(Ia){Va=Wa-1|0;Ja=(Wa|0)/2|0;Ta=Oa;do{do{if((Ta|0)<0){Ka=Ta+8+(ca(c[ya>>2]|0,Wa)|0)>>2;_a=d[(c[Za>>2]|0)+Ka|0]|0;$a=0}else{Ka=ca(c[ya>>2]|0,Wa)|0;Ua=c[Za>>2]|0;Sa=d[Ua+(Ka+Ta>>2)|0]|0;if((Ta|0)>=(r|0)){_a=0;$a=Sa;break}_a=d[Ua+(Ta+8+Ka>>2)|0]|0;$a=Sa}}while(0);J=($a|0)==2;wa=(_a|0)==2;do{if(J|wa){if(J){Sa=c[t>>2]|0;Ka=c[Aa>>2]|0;Ua=c[Sa+13064>>2]|0;Ra=c[Sa+13116>>2]|0;Sa=Ta>>Ua;Qa=a[Ka+((ca(Va>>Ua,Ra)|0)+Sa)|0]|0;ab=Qa+1+(a[Ka+((ca(Wa>>Ua,Ra)|0)+Sa)|0]|0)>>1}else{ab=0}if(wa){Sa=c[t>>2]|0;Ra=c[Aa>>2]|0;Ua=c[Sa+13064>>2]|0;Ka=c[Sa+13116>>2]|0;Sa=Ta+8>>Ua;Qa=a[Ra+((ca(Va>>Ua,Ka)|0)+Sa)|0]|0;bb=Qa+1+(a[Ra+((ca(Wa>>Ua,Ka)|0)+Sa)|0]|0)>>1}else{bb=0}if(J){Sa=(Ta|0)>=(f|0)?B:H;Ka=c[V>>2]|0;Ua=(c[(Xa?Ka+28|0:Ka+32|0)>>2]|0)+ab|0;do{if((Ua|0)<0){cb=0}else{Ka=(Ua|0)>57?57:Ua;if((Ka|0)<30){cb=Ka;break}if((Ka|0)>43){cb=Ka-6|0;break}else{cb=c[1705016+(Ka-30<<2)>>2]|0;break}}}while(0);Ua=Sa+2+cb|0;if((Ua|0)<0){db=0}else{db=(Ua|0)>53?53:Ua}eb=d[311728+db|0]|0}else{eb=0}c[S>>2]=eb;if(wa){Ua=c[V>>2]|0;O=(c[(Xa?Ua+28|0:Ua+32|0)>>2]|0)+bb|0;do{if((O|0)<0){fb=0}else{Ua=(O|0)>57?57:O;if((Ua|0)<30){fb=Ua;break}if((Ua|0)>43){fb=Ua-6|0;break}else{fb=c[1705016+(Ua-30<<2)>>2]|0;break}}}while(0);O=fb+T|0;if((O|0)<0){gb=0}else{gb=(O|0)>53?53:O}hb=d[311728+gb|0]|0}else{hb=0}c[R>>2]=hb;O=c[Ba>>2]|0;Sa=c[O+32+(Ya<<2)>>2]|0;Ua=ca(Sa,Ja)|0;ra=c[t>>2]|0;Ka=(c[O+(Ya<<2)>>2]|0)+((((Ta|0)/2|0)<<c[ra+56>>2])+Ua)|0;if(!E){pe[c[La>>2]&1023](Ka,Sa,S,u,v);break}Ua=c[ra+13084>>2]|0;do{if((Ta|Va|0)<0){ib=2}else{O=Ta>>Ua;Ra=Va>>Ua;Qa=c[ra+13132>>2]|0;if((O|0)>=(Qa|0)){ib=2;break}if((Ra|0)>=(c[ra+13136>>2]|0)){ib=2;break}L=(ca(Qa,Ra)|0)+O|0;ib=a[(c[Ea>>2]|0)+L|0]|0}}while(0);a[u]=ib;L=Ta+8|0;do{if((L|Va|0)<0){jb=2}else{O=L>>Ua;Ra=Va>>Ua;Qa=c[ra+13132>>2]|0;if((O|0)>=(Qa|0)){jb=2;break}if((Ra|0)>=(c[ra+13136>>2]|0)){jb=2;break}Pa=(ca(Qa,Ra)|0)+O|0;jb=a[(c[Ea>>2]|0)+Pa|0]|0}}while(0);a[Ca]=jb;do{if((Ta|Wa|0)<0){kb=2}else{Pa=Ta>>Ua;O=Wa>>Ua;Ra=c[ra+13132>>2]|0;if((Pa|0)>=(Ra|0)){kb=2;break}if((O|0)>=(c[ra+13136>>2]|0)){kb=2;break}Qa=(ca(Ra,O)|0)+Pa|0;kb=a[(c[Ea>>2]|0)+Qa|0]|0}}while(0);a[v]=kb;do{if((L|Wa|0)<0){lb=2}else{Qa=L>>Ua;Pa=Wa>>Ua;O=c[ra+13132>>2]|0;if((Qa|0)>=(O|0)){lb=2;break}if((Pa|0)>=(c[ra+13136>>2]|0)){lb=2;break}Ra=(ca(O,Pa)|0)+Qa|0;lb=a[(c[Ea>>2]|0)+Ra|0]|0}}while(0);a[Da]=lb;pe[c[q>>2]&1023](Ka,Sa,S,u,v)}}while(0);Ta=Ta+16|0;}while((Ta|0)<(K|0))}Wa=Wa+16|0;}while((Wa|0)<(s|0))}Ya=Ya+1|0;}while((Ya|0)<3);Ya=c[t>>2]|0;if((a[Ya+12941|0]|0)==0){i=h;return}s=m;K=n;v=o;u=m;S=n;q=o;lb=c[Ya+13080>>2]|0;Da=f>>lb;Ea=g>>lb;lb=Ya+13104|0;kb=(ca(Ea,c[lb>>2]|0)|0)+Da|0;jb=c[V>>2]|0;V=c[jb+1652>>2]|0;Ca=c[V+(kb<<2)>>2]|0;c[m>>2]=0;c[n>>2]=0;c[o>>2]=0;if((a[jb+42|0]|0)==0){mb=0}else{mb=(a[jb+53|0]|0)==0|0}o=c[e+3464>>2]|0;c[k>>2]=o+(kb*184|0);n=(Da|0)==0;m=j|0;c[m>>2]=n&1;ib=(Ea|0)==0;c[j+4>>2]=ib&1;La=(Da|0)==((c[lb>>2]|0)-1|0)|0;E=j+8|0;c[E>>2]=La;Ba=(Ea|0)==((c[Ya+13108>>2]|0)-1|0)|0;hb=j+12|0;c[hb>>2]=Ba;j=c[lb>>2]|0;lb=ca(j,Ea)|0;R=lb+Da|0;gb=c[e+7356>>2]|0;T=a[gb+R|0]|0;c[l>>2]=0;if(n){nb=1;ob=0;pb=0;qb=0}else{if((mb|0)==0){rb=0}else{fb=c[jb+1660>>2]|0;rb=(c[fb+(Ca<<2)>>2]|0)!=(c[fb+(c[V+(kb-1<<2)>>2]<<2)>>2]|0)|0}fb=Da-1+lb|0;c[k+4>>2]=o+(fb*184|0);if(T<<24>>24==0){bb=c[e+7332>>2]|0;if((c[bb+(R<<2)>>2]|0)==(c[bb+(fb<<2)>>2]|0)){D=192}else{sb=1}}else{D=192}if((D|0)==192){sb=rb}a[s]=sb;a[u+2|0]=sb;sb=a[gb+fb|0]|0;c[l+4>>2]=2;nb=2;ob=8;pb=sb;qb=rb}do{if(ib){tb=nb;ub=0}else{if((mb|0)==0){vb=0}else{rb=c[jb+1660>>2]|0;vb=(c[rb+(Ca<<2)>>2]|0)!=(c[rb+(c[V+(kb-j<<2)>>2]<<2)>>2]|0)|0}rb=ca(j,Ea-1|0)|0;sb=rb+Da|0;c[k+(nb<<2)>>2]=o+(sb*184|0);fb=T<<24>>24!=0;if(fb){D=199}else{s=c[e+7332>>2]|0;if((c[s+(R<<2)>>2]|0)==(c[s+(sb<<2)>>2]|0)){D=199}else{wb=1}}if((D|0)==199){wb=vb}a[K]=wb;a[S+1|0]=wb;s=a[gb+sb|0]|0;c[l+(nb<<2)>>2]=1;bb=nb+1|0;if(n){tb=bb;ub=4;break}c[l+(bb<<2)>>2]=3;eb=Da-1|0;db=rb+eb|0;c[k+(bb<<2)>>2]=o+(db*184|0);bb=nb+2|0;rb=s<<24>>24!=0;if(rb){D=203}else{s=c[e+7332>>2]|0;if((c[s+(sb<<2)>>2]|0)==(c[s+(db<<2)>>2]|0)){D=203}else{xb=1}}if((D|0)==203){xb=qb<<24>>24!=0|0}a[u+1|0]=xb;a[u+3|0]=xb;s=pb<<24>>24!=0;if(s){D=206}else{cb=c[e+7332>>2]|0;if((c[cb+(lb+eb<<2)>>2]|0)==(c[cb+(db<<2)>>2]|0)){D=206}else{yb=1}}if((D|0)==206){yb=vb}a[S+2|0]=yb;a[S+3|0]=yb;if(fb){if(qb<<24>>24==0){D=210}else{zb=1}}else{fb=c[e+7332>>2]|0;if((c[fb+(R<<2)>>2]|0)==(c[fb+(db<<2)>>2]|0)&qb<<24>>24==0){D=210}else{zb=1}}if((D|0)==210){zb=vb}a[v]=zb;a[q+3|0]=zb;db=c[e+7332>>2]|0;fb=c[db+(lb+eb<<2)>>2]|0;eb=c[db+(sb<<2)>>2]|0;if((fb|0)>(eb|0)){sb=s&qb<<24>>24==0?vb:1;a[q+2|0]=sb;a[q+1|0]=sb;tb=bb;ub=4;break}sb=qb<<24>>24==0;if((fb|0)<(eb|0)){eb=rb&sb?vb:1;a[q+1|0]=eb;a[q+2|0]=eb;tb=bb;ub=4;break}else{eb=sb?vb:1;a[q+2|0]=eb;a[q+1|0]=eb;tb=bb;ub=4;break}}}while(0);vb=e+160|0;qb=e+164|0;lb=0;zb=Ya;Ya=La;La=Ba;while(1){Ba=(lb|0)!=0|0;v=f>>Ba;D=g>>Ba;R=c[vb>>2]|0;yb=c[R+32+(lb<<2)>>2]|0;pb=c[zb+13140+(lb<<2)>>2]|0;xb=1<<c[zb+13080>>2]>>pb;nb=(c[zb+13096>>2]>>pb)-v|0;pb=(xb|0)>(nb|0)?nb:xb;nb=(c[zb+13100>>2]>>c[zb+13152+(lb<<2)>>2])-D|0;o=(xb|0)>(nb|0)?nb:xb;xb=ca(D,yb)|0;D=c[zb+56>>2]|0;nb=(v<<D)+xb|0;xb=c[R+(lb<<2)>>2]|0;R=xb+nb|0;v=c[(c[qb>>2]|0)+(lb<<2)>>2]|0;Da=v+nb|0;n=ub>>>(Ba>>>0);gb=ob>>>(Ba>>>0);Ba=nb-((gb<<D)+(ca(n,yb)|0))|0;nb=pb+((Ya|0)==0?0:gb)<<D;D=o+((La|0)==0?0:n)|0;if((D|0)>0){n=xb+Ba|0;xb=v+Ba|0;Ba=0;while(1){nrc(xb|0,n|0,nb)|0;v=Ba+1|0;if((v|0)<(D|0)){n=n+yb|0;xb=xb+yb|0;Ba=v}else{Ab=0;break}}}else{Ab=0}do{Ba=c[k+(Ab<<2)>>2]|0;xb=d[Ba+180+lb|0]|0;if((xb|0)==1){Ge[c[e+5904+(c[l+(Ab<<2)>>2]<<2)>>2]&255](Da,R,yb,Ba,m,pb,o,lb)}else if((xb|0)==2){xb=c[l+(Ab<<2)>>2]|0;we[c[e+5920+(xb<<2)>>2]&127](Da,R,yb,Ba,m,pb,o,lb,a[u+xb|0]|0,a[S+xb|0]|0,a[q+xb|0]|0)}Ab=Ab+1|0;}while((Ab|0)<(tb|0));o=lb+1|0;if((o|0)>=3){break}lb=o;zb=c[t>>2]|0;Ya=c[E>>2]|0;La=c[hb>>2]|0}i=h;return}function TFa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=(e|0)!=0;h=(d|0)==0;if(!(h|g^1)){SFa(b,d-f|0,e-f|0)}do{if(g){if(((c[(c[b+180>>2]|0)+13096>>2]|0)-f|0)>(d|0)){break}i=e-f|0;SFa(b,d,i);if((a[b+140|0]|0)!=1){break}L5a((c[b+3480>>2]|0)+4|0,i,0)}}while(0);if(h){return}if(((c[(c[b+180>>2]|0)+13100>>2]|0)-f|0)>(e|0)){return}SFa(b,d-f|0,e);return}function UFa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=c[b+136>>2]|0;j=(c[b+180>>2]|0)+13080|0;b=(1<<c[j>>2])-1|0;k=b&e;l=b&f;if((a[i+173201|0]|0)==0){m=(l|0)!=0|0}else{m=1}c[i+184632>>2]=m;if((a[i+173200|0]|0)==0){n=(k|0)!=0|0}else{n=1}c[i+184628>>2]=n;o=(l|0)==0;if((b&(f|e)|0)==0){p=d[i+173203|0]|0}else{p=(n|0)==0?0:m}c[i+184636>>2]=p;p=k+g|0;if((p|0)==(1<<c[j>>2]|0)){q=(a[i+173202|0]|0)==0?0:o&1}else{q=m}c[i+184644>>2]=q;if((p|0)==(1<<c[j>>2]|0)){if((a[i+173202|0]|0)!=0&o){r=13}else{s=0}}else{if((m|0)==0){s=0}else{r=13}}if((r|0)==13){s=(g+e|0)<(c[i+173204>>2]|0)|0}c[i+184640>>2]=s;c[i+184624>>2]=(h+f|0)<(c[i+173208>>2]|0)?n:0;return}function VFa(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;o=i;i=i+88|0;p=o|0;q=o+8|0;r=o+16|0;s=1<<k;k=r;mrc(k|0,0,70)|0;t=e+136|0;u=c[t>>2]|0;v=e+184|0;if((c[(c[v>>2]|0)+1620>>2]|0)>2&(s|0)==8){w=c[u+184580>>2]|0;x=c[u+184584>>2]|0;z=8;A=8;B=1;C=0}else{w=f;x=g;z=h;A=j;B=0;C=l}UFa(e,w,x,z,A);l=p;g=q;f=c[t>>2]|0;t=c[e+3480>>2]|0;u=c[t+20>>2]|0;D=c[t+16>>2]|0;t=c[e+180>>2]|0;E=c[t+13132>>2]|0;F=c[f+184624>>2]|0;G=c[f+184636>>2]|0;H=c[f+184632>>2]|0;I=c[f+184644>>2]|0;J=w-1|0;K=x+A|0;L=K-1|0;M=c[t+13084>>2]|0;N=J>>M;O=L>>M;P=w+z|0;Q=P-1|0;R=x-1|0;S=Q>>M;T=R>>M;U=P>>M;V=K>>M;M=e+2404|0;W=c[e+3012>>2]|0;if((c[M>>2]|0)==1){X=W}else{Y=c[e+3016>>2]|0;X=W>>>0>Y>>>0?Y:W}if((c[f+184628>>2]|0)==0){Z=0}else{Z=(a[D+(((ca(O,E)|0)+N|0)*14|0)+12|0]|0)==0|0}W=(C|0)==1;C=(B|0)==0&W;if(C){B=c[f+184592>>2]|0;if((B|0)==2|(B|0)==6|(B|0)==7){_=0;$=1}else{aa=9}}else{aa=9}do{if((aa|0)==9){B=c[(c[v>>2]|0)+1620>>2]&255;if((J>>B|0)==(w>>B|0)){if(!((Z|0)!=0&(L>>B|0)!=(x>>B|0))){_=0;$=1;break}}else{if((Z|0)==0){_=0;$=1;break}}B=D+(((ca(O,E)|0)+N|0)*14|0)|0;b[k>>1]=b[B>>1]|0;b[k+2>>1]=b[B+2>>1]|0;b[k+4>>1]=b[B+4>>1]|0;b[k+6>>1]=b[B+6>>1]|0;b[k+8>>1]=b[B+8>>1]|0;b[k+10>>1]=b[B+10>>1]|0;b[k+12>>1]=b[B+12>>1]|0;_=1;$=0}}while(0);if((H|0)==0){ba=0}else{ba=(a[D+(((ca(T,E)|0)+S|0)*14|0)+12|0]|0)==0|0}if(C){C=c[f+184592>>2]|0;if((C|0)==1|(C|0)==4|(C|0)==5){da=_;ea=1}else{aa=17}}else{aa=17}do{if((aa|0)==17){C=c[(c[v>>2]|0)+1620>>2]&255;if((Q>>C|0)==(w>>C|0)){if((R>>C|0)==(x>>C|0)){da=_;ea=1;break}}C=(ba|0)==0;if($|C){fa=0}else{fa=($Fa(D+(((ca(T,E)|0)+S|0)*14|0)|0,D+(((ca(O,E)|0)+N|0)*14|0)|0)|0)!=0}if(C|fa){da=_;ea=C;break}C=r+(_*14|0)|0;H=D+(((ca(T,E)|0)+S|0)*14|0)|0;b[C>>1]=b[H>>1]|0;b[C+2>>1]=b[H+2>>1]|0;b[C+4>>1]=b[H+4>>1]|0;b[C+6>>1]=b[H+6>>1]|0;b[C+8>>1]=b[H+8>>1]|0;b[C+10>>1]=b[H+10>>1]|0;b[C+12>>1]=b[H+12>>1]|0;da=_+1|0;ea=0}}while(0);_=f+184580|0;fa=c[_>>2]|0;do{if((fa|0)<(P|0)){ba=c[f+184584>>2]|0;if((ba|0)>=(R|0)){aa=31;break}if((fa+s|0)<=(P|0)){aa=31;break}if((ba+s|0)<=(R|0)){aa=31;break}if((z<<1|0)!=(s|0)){ga=1;aa=35;break}if(!((A<<1|0)==(s|0)&W)){ga=1;aa=35;break}if((fa+z|0)<=(P|0)){ga=1;aa=35;break}ga=(ba+A|0)>(R|0)|0;aa=35}else{aa=31}}while(0);do{if((aa|0)==31){ba=c[(c[v>>2]|0)+1672>>2]|0;Q=c[t+13072>>2]|0;H=c[t+13124>>2]|0;C=c[ba+((ca(x>>Q,H)|0)+(w>>Q)<<2)>>2]|0;if((P|R|0)<0){ha=0;break}if((c[t+13096>>2]|0)<=(P|0)){ha=0;break}if((c[t+13100>>2]|0)<=(R|0)){ha=0;break}ga=(c[ba+((ca(R>>Q,H)|0)+(P>>Q)<<2)>>2]|0)<=(C|0)|0;aa=35}}while(0);do{if((aa|0)==35){if((ga|0)==0|(I|0)==0){ha=0;break}ha=(a[D+(((ca(T,E)|0)+U|0)*14|0)+12|0]|0)==0|0}}while(0);I=c[v>>2]|0;v=I+1620|0;ga=c[v>>2]&255;if((P>>ga|0)==(w>>ga|0)){ia=(R>>ga|0)==(x>>ga|0)?0:ha}else{ia=ha}ha=(ia|0)==0;if(ea|ha){ja=0}else{ia=ca(T,E)|0;ja=($Fa(D+((ia+U|0)*14|0)|0,D+((ia+S|0)*14|0)|0)|0)!=0}if(ha|ja){ka=da;la=fa}else{fa=r+(da*14|0)|0;ja=D+(((ca(T,E)|0)+U|0)*14|0)|0;b[fa>>1]=b[ja>>1]|0;b[fa+2>>1]=b[ja+2>>1]|0;b[fa+4>>1]=b[ja+4>>1]|0;b[fa+6>>1]=b[ja+6>>1]|0;b[fa+8>>1]=b[ja+8>>1]|0;b[fa+10>>1]=b[ja+10>>1]|0;b[fa+12>>1]=b[ja+12>>1]|0;ka=da+1|0;la=c[_>>2]|0}do{if((la|0)<(J|0)){_=c[f+184584>>2]|0;if((_|0)>=(K|0)){aa=51;break}if((la+s|0)<=(J|0)){aa=51;break}if((_+s|0)<=(K|0)){aa=51;break}if((z<<1|0)!=(s|0)){ma=1;aa=55;break}if(!((A<<1|0)==(s|0)&W)){ma=1;aa=55;break}if((la+z|0)<=(J|0)){ma=1;aa=55;break}ma=(_+A|0)>(K|0)|0;aa=55}else{aa=51}}while(0);do{if((aa|0)==51){la=c[I+1672>>2]|0;W=c[t+13072>>2]|0;s=c[t+13124>>2]|0;f=c[la+((ca(x>>W,s)|0)+(w>>W)<<2)>>2]|0;if((J|K|0)<0){na=0;break}if((c[t+13096>>2]|0)<=(J|0)){na=0;break}if((c[t+13100>>2]|0)<=(K|0)){na=0;break}ma=(c[la+((ca(K>>W,s)|0)+(J>>W)<<2)>>2]|0)<=(f|0)|0;aa=55}}while(0);do{if((aa|0)==55){if((ma|0)==0|(F|0)==0){na=0;break}na=(a[D+(((ca(V,E)|0)+N|0)*14|0)+12|0]|0)==0|0}}while(0);F=c[v>>2]&255;if((J>>F|0)==(w>>F|0)){oa=(K>>F|0)==(x>>F|0)?0:na}else{oa=na}na=(oa|0)==0;if($|na){pa=0}else{pa=($Fa(D+(((ca(V,E)|0)+N|0)*14|0)|0,D+(((ca(O,E)|0)+N|0)*14|0)|0)|0)!=0}if(na|pa){qa=ka}else{pa=r+(ka*14|0)|0;na=D+(((ca(V,E)|0)+N|0)*14|0)|0;b[pa>>1]=b[na>>1]|0;b[pa+2>>1]=b[na+2>>1]|0;b[pa+4>>1]=b[na+4>>1]|0;b[pa+6>>1]=b[na+6>>1]|0;b[pa+8>>1]=b[na+8>>1]|0;b[pa+10>>1]=b[na+10>>1]|0;b[pa+12>>1]=b[na+12>>1]|0;qa=ka+1|0}if((G|0)==0){ra=0}else{ra=(a[D+(((ca(T,E)|0)+N|0)*14|0)+12|0]|0)==0|0}G=c[v>>2]&255;if((J>>G|0)==(w>>G|0)){sa=(R>>G|0)==(x>>G|0)?0:ra}else{sa=ra}ra=(sa|0)==0;if($|ra){ta=1}else{ta=($Fa(D+(((ca(T,E)|0)+N|0)*14|0)|0,D+(((ca(O,E)|0)+N|0)*14|0)|0)|0)==0|0}if(ea|ra){ua=0}else{ea=ca(T,E)|0;ua=($Fa(D+((ea+N|0)*14|0)|0,D+((ea+S|0)*14|0)|0)|0)!=0}if(ra|(ta|0)==0|ua|(qa|0)==4){va=qa}else{ua=r+(qa*14|0)|0;ta=D+(((ca(T,E)|0)+N|0)*14|0)|0;b[ua>>1]=b[ta>>1]|0;b[ua+2>>1]=b[ta+2>>1]|0;b[ua+4>>1]=b[ta+4>>1]|0;b[ua+6>>1]=b[ta+6>>1]|0;b[ua+8>>1]=b[ta+8>>1]|0;b[ua+10>>1]=b[ta+10>>1]|0;b[ua+12>>1]=b[ta+12>>1]|0;va=qa+1|0}qa=e+3052|0;do{if((a[e+3011|0]|0)==0){wa=va}else{if(!(va>>>0<(c[qa>>2]|0)>>>0)){wa=va;break}ta=YFa(e,w,x,z,A,0,l,0)|0;if((c[M>>2]|0)==0){xa=YFa(e,w,x,z,A,0,g,1)|0}else{xa=0}ua=(ta|0)!=0;N=(xa|0)==0;if(N&(ua^1)){wa=va;break}a[r+(va*14|0)+12|0]=0;a[r+(va*14|0)+10|0]=ta;a[r+(va*14|0)+11|0]=xa;if(ua){ua=r+(va*14|0)|0;y=c[p>>2]|0;b[ua>>1]=y;b[ua+2>>1]=y>>16;a[r+(va*14|0)+8|0]=0}if(!N){N=r+(va*14|0)+4|0;y=c[q>>2]|0;b[N>>1]=y;b[N+2>>1]=y>>16;a[r+(va*14|0)+9|0]=0}wa=va+1|0}}while(0);va=(c[M>>2]|0)==0;M=c[qa>>2]|0;do{if(va&(wa|0)>1&wa>>>0<M>>>0){qa=ca(wa-1|0,wa)|0;if((qa|0)>0){ya=0;za=wa}else{Aa=wa;break}while(1){q=d[1017224+(ya<<1)|0]|0;p=d[1017225+(ya<<1)|0]|0;xa=b[r+(q*14|0)>>1]|0;g=b[r+(q*14|0)+2>>1]|0;A=a[r+(q*14|0)+8|0]|0;z=b[r+(p*14|0)+4>>1]|0;x=b[r+(p*14|0)+6>>1]|0;w=a[r+(p*14|0)+9|0]|0;do{if((a[r+(q*14|0)+10|0]|0)==0){Ba=za}else{if((a[r+(p*14|0)+11|0]|0)==0){Ba=za;break}if((c[u+64+(A<<24>>24<<2)>>2]|0)==(c[u+260+(w<<24>>24<<2)>>2]|0)&xa<<16>>16==z<<16>>16&g<<16>>16==x<<16>>16){Ba=za;break}a[r+(za*14|0)+8|0]=A;a[r+(za*14|0)+9|0]=w;a[r+(za*14|0)+10|0]=1;a[r+(za*14|0)+11|0]=1;b[r+(za*14|0)>>1]=xa;b[r+(za*14|0)+2>>1]=g;b[r+(za*14|0)+4>>1]=z;b[r+(za*14|0)+6>>1]=x;a[r+(za*14|0)+12|0]=0;Ba=za+1|0}}while(0);x=ya+1|0;if(Ba>>>0<M>>>0&(x|0)<(qa|0)){ya=x;za=Ba}else{Aa=Ba;break}}}else{Aa=wa}}while(0);if(Aa>>>0<M>>>0){wa=va&1;va=Aa;Aa=0;while(1){a[r+(va*14|0)+10|0]=1;a[r+(va*14|0)+11|0]=wa;a[r+(va*14|0)+12|0]=0;Ba=(Aa|0)<(X|0)?Aa&255:0;za=r+(va*14|0)|0;ya=za|0;y=0;b[ya>>1]=y;b[ya+2>>1]=y>>16;ya=za+4|0;y=0;b[ya>>1]=y;b[ya+2>>1]=y>>16;a[r+(va*14|0)+8|0]=Ba;a[r+(va*14|0)+9|0]=Ba;Ba=va+1|0;if(Ba>>>0<M>>>0){va=Ba;Aa=Aa+1|0}else{break}}}Aa=r+(m*14|0)|0;if((a[r+(m*14|0)+10|0]|0)!=1){Ca=n;Da=Aa;b[Ca>>1]=b[Da>>1]|0;b[Ca+2>>1]=b[Da+2>>1]|0;b[Ca+4>>1]=b[Da+4>>1]|0;b[Ca+6>>1]=b[Da+6>>1]|0;b[Ca+8>>1]=b[Da+8>>1]|0;b[Ca+10>>1]=b[Da+10>>1]|0;b[Ca+12>>1]=b[Da+12>>1]|0;i=o;return}va=r+(m*14|0)+11|0;if((a[va]|0)!=1){Ca=n;Da=Aa;b[Ca>>1]=b[Da>>1]|0;b[Ca+2>>1]=b[Da+2>>1]|0;b[Ca+4>>1]=b[Da+4>>1]|0;b[Ca+6>>1]=b[Da+6>>1]|0;b[Ca+8>>1]=b[Da+8>>1]|0;b[Ca+10>>1]=b[Da+10>>1]|0;b[Ca+12>>1]=b[Da+12>>1]|0;i=o;return}if((j+h|0)!=12){Ca=n;Da=Aa;b[Ca>>1]=b[Da>>1]|0;b[Ca+2>>1]=b[Da+2>>1]|0;b[Ca+4>>1]=b[Da+4>>1]|0;b[Ca+6>>1]=b[Da+6>>1]|0;b[Ca+8>>1]=b[Da+8>>1]|0;b[Ca+10>>1]=b[Da+10>>1]|0;b[Ca+12>>1]=b[Da+12>>1]|0;i=o;return}a[r+(m*14|0)+9|0]=-1;a[va]=0;Ca=n;Da=Aa;b[Ca>>1]=b[Da>>1]|0;b[Ca+2>>1]=b[Da+2>>1]|0;b[Ca+4>>1]=b[Da+4>>1]|0;b[Ca+6>>1]=b[Da+6>>1]|0;b[Ca+8>>1]=b[Da+8>>1]|0;b[Ca+10>>1]=b[Da+10>>1]|0;b[Ca+12>>1]=b[Da+12>>1]|0;i=o;return}function WFa(f,g,h,j,k,l,m,n,o,p,q){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;n=i;i=i+8|0;r=n|0;s=r;t=i;i=i+4|0;i=i+7&-8;u=t;v=i;i=i+4|0;i=i+7&-8;w=v;x=i;i=i+4|0;i=i+7&-8;y=x;z=f+136|0;A=c[z>>2]|0;B=f+3480|0;C=c[B>>2]|0;D=c[C+16>>2]|0;E=f+180|0;F=c[E>>2]|0;G=c[F+13132>>2]|0;c[r>>2]=0;c[r+4>>2]=0;c[t>>2]=0;c[v>>2]=0;H=1<<c[F+13080>>2];I=H-1|0;J=I&g;K=I&h;L=(K|0)!=0|(a[A+173201|0]|0)!=0;M=(J|0)!=0|(a[A+173200|0]|0)!=0;N=(K|0)==0;if((I&(h|g)|0)==0){O=d[A+173203|0]|0}else{O=M&L&1}if((J+j|0)==(H|0)){P=6}else{if((j+g|0)<(c[A+173204>>2]|0)){Q=L}else{P=6}}if((P|0)==6){Q=N&(a[A+173202|0]|0)!=0}N=k+h|0;H=c[A+173208>>2]|0;J=a[o+8+q|0]|0;I=(q|0)==0|0;K=g-1|0;R=c[F+13084>>2]|0;S=K>>R;T=N>>R;U=c[A+184580>>2]|0;do{if((U|0)<(K|0)){V=c[A+184584>>2]|0;if((V|0)>=(N|0)){P=15;break}W=1<<l;if((U+W|0)<=(K|0)){P=15;break}if((V+W|0)<=(N|0)){P=15;break}if((j<<1|0)!=(W|0)){P=19;break}if(!((k<<1|0)==(W|0)&(m|0)==1)){P=19;break}if((U+j|0)<=(K|0)){P=19;break}if((V+k|0)>(N|0)){P=19}else{X=0}}else{P=15}}while(0);do{if((P|0)==15){U=c[(c[f+184>>2]|0)+1672>>2]|0;A=c[F+13072>>2]|0;V=c[F+13124>>2]|0;W=c[U+((ca(h>>A,V)|0)+(g>>A)<<2)>>2]|0;if((N|K|0)<0){X=0;break}if((c[F+13096>>2]|0)<=(K|0)){X=0;break}if((c[F+13100>>2]|0)<=(N|0)){X=0;break}if((c[U+((ca(N>>A,V)|0)+(K>>A)<<2)>>2]|0)>(W|0)){X=0}else{P=19}}}while(0);do{if((P|0)==19){if(!(M&(N|0)<(H|0))){X=0;break}X=(a[D+(((ca(T,G)|0)+S|0)*14|0)+12|0]|0)==0}}while(0);H=N-1>>R;if(M){Y=(a[D+(((ca(H,G)|0)+S|0)*14|0)+12|0]|0)==0}else{Y=0}M=X|Y;a:do{if(X){R=c[C+20>>2]|0;N=(ca(G,T)|0)+S|0;do{if((a[D+(N*14|0)+10+q|0]|0)==1){if((c[R+(q*196|0)+64+(a[D+(N*14|0)+8+q|0]<<2)>>2]|0)!=(c[R+(q*196|0)+64+(J<<2)>>2]|0)){break}F=D+(N*14|0)+(q<<2)|0;c[t>>2]=e[F>>1]|e[F+2>>1]<<16;Z=1;break a}}while(0);if((a[D+(N*14|0)+10+I|0]|0)!=1){P=30;break}if((c[R+(I*196|0)+64+(a[D+(N*14|0)+8+I|0]<<2)>>2]|0)!=(c[R+(q*196|0)+64+(J<<2)>>2]|0)){P=30;break}F=D+(N*14|0)+(I<<2)|0;c[t>>2]=e[F>>1]|e[F+2>>1]<<16;Z=1}else{P=30}}while(0);b:do{if((P|0)==30){do{if(Y){F=c[C+20>>2]|0;W=(ca(G,H)|0)+S|0;do{if((a[D+(W*14|0)+10+q|0]|0)==1){if((c[F+(q*196|0)+64+(a[D+(W*14|0)+8+q|0]<<2)>>2]|0)!=(c[F+(q*196|0)+64+(J<<2)>>2]|0)){break}A=D+(W*14|0)+(q<<2)|0;c[t>>2]=e[A>>1]|e[A+2>>1]<<16;Z=1;break b}}while(0);if((a[D+(W*14|0)+10+I|0]|0)!=1){break}if((c[F+(I*196|0)+64+(a[D+(W*14|0)+8+I|0]<<2)>>2]|0)!=(c[F+(q*196|0)+64+(J<<2)>>2]|0)){break}A=D+(W*14|0)+(I<<2)|0;c[t>>2]=e[A>>1]|e[A+2>>1]<<16;Z=1;break b}}while(0);if(X){N=XFa(f,S,T,q,u,q,J)|0;if((N|0)!=0){Z=N;break}_=XFa(f,S,T,I,u,q,J)|0}else{_=0}if(!(Y&(_|0)==0)){Z=_;break}N=XFa(f,S,H,q,u,q,J)|0;if((N|0)!=0){Z=N;break}Z=XFa(f,S,H,I,u,q,J)|0}}while(0);H=j+g|0;S=h-1|0;_=c[E>>2]|0;E=c[_+13084>>2]|0;Y=H>>E;T=S>>E;X=c[z>>2]|0;z=c[X+184580>>2]|0;do{if((z|0)<(H|0)){C=c[X+184584>>2]|0;if((C|0)>=(S|0)){P=51;break}N=1<<l;if((z+N|0)<=(H|0)){P=51;break}if((C+N|0)<=(S|0)){P=51;break}if((j<<1|0)!=(N|0)){$=1;P=55;break}if(!((k<<1|0)==(N|0)&(m|0)==1)){$=1;P=55;break}if((z+j|0)<=(H|0)){$=1;P=55;break}$=(C+k|0)>(S|0)|0;P=55}else{P=51}}while(0);do{if((P|0)==51){z=c[(c[f+184>>2]|0)+1672>>2]|0;m=c[_+13072>>2]|0;l=c[_+13124>>2]|0;X=c[z+((ca(h>>m,l)|0)+(g>>m)<<2)>>2]|0;if((H|S|0)<0){aa=0;P=63;break}if((c[_+13096>>2]|0)<=(H|0)){aa=0;P=63;break}if((c[_+13100>>2]|0)<=(S|0)){aa=0;P=63;break}$=(c[z+((ca(S>>m,l)|0)+(H>>m)<<2)>>2]|0)<=(X|0)|0;P=55}}while(0);c:do{if((P|0)==55){if(($|0)==0|Q^1){aa=0;P=63;break}if((a[D+(((ca(T,G)|0)+Y|0)*14|0)+12|0]|0)!=0){aa=0;P=63;break}S=c[B>>2]|0;X=c[S+16>>2]|0;m=c[S+20>>2]|0;S=(ca(c[_+13132>>2]|0,T)|0)+Y|0;do{if((a[X+(S*14|0)+10+q|0]|0)==1){if((c[m+(q*196|0)+64+(a[X+(S*14|0)+8+q|0]<<2)>>2]|0)!=(c[m+(q*196|0)+64+(J<<2)>>2]|0)){break}l=X+(S*14|0)+(q<<2)|0;z=e[l>>1]|e[l+2>>1]<<16;c[v>>2]=z;ba=1;da=0;ea=0;fa=0;ga=1;ha=0;ia=0;ja=0;ka=z;break c}}while(0);if((a[X+(S*14|0)+10+I|0]|0)!=1){aa=1;P=63;break}if((c[m+(I*196|0)+64+(a[X+(S*14|0)+8+I|0]<<2)>>2]|0)!=(c[m+(q*196|0)+64+(J<<2)>>2]|0)){aa=1;P=63;break}z=X+(S*14|0)+(I<<2)|0;l=e[z>>1]|e[z+2>>1]<<16;c[v>>2]=l;ba=1;da=0;ea=0;fa=0;ga=1;ha=0;ia=0;ja=0;ka=l}}while(0);d:do{if((P|0)==63){Q=H-1>>E;do{if(L){$=(a[D+(((ca(T,G)|0)+Q|0)*14|0)+12|0]|0)==0;l=$&1;if(!$){la=l;break}$=c[B>>2]|0;z=c[$+16>>2]|0;C=c[$+20>>2]|0;$=(ca(c[_+13132>>2]|0,T)|0)+Q|0;do{if((a[z+($*14|0)+10+q|0]|0)==1){if((c[C+(q*196|0)+64+(a[z+($*14|0)+8+q|0]<<2)>>2]|0)!=(c[C+(q*196|0)+64+(J<<2)>>2]|0)){break}N=z+($*14|0)+(q<<2)|0;R=e[N>>1]|e[N+2>>1]<<16;c[v>>2]=R;ba=1;da=0;ea=0;fa=0;ga=aa;ha=l;ia=T;ja=Q;ka=R;break d}}while(0);if((a[z+($*14|0)+10+I|0]|0)!=1){la=l;break}if((c[C+(I*196|0)+64+(a[z+($*14|0)+8+I|0]<<2)>>2]|0)!=(c[C+(q*196|0)+64+(J<<2)>>2]|0)){la=l;break}W=z+($*14|0)+(I<<2)|0;F=e[W>>1]|e[W+2>>1]<<16;c[v>>2]=F;ba=1;da=0;ea=0;fa=0;ga=aa;ha=l;ia=T;ja=Q;ka=F;break d}else{la=0}}while(0);S=K>>E;if((O|0)==0){ba=0;da=S;ea=T;fa=0;ga=aa;ha=la;ia=T;ja=Q;ka=0;break}X=(a[D+(((ca(T,G)|0)+S|0)*14|0)+12|0]|0)==0;m=X&1;if(!X){ba=0;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=0;break}X=c[B>>2]|0;F=c[X+16>>2]|0;W=c[X+20>>2]|0;X=(ca(c[_+13132>>2]|0,T)|0)+S|0;do{if((a[F+(X*14|0)+10+q|0]|0)==1){if((c[W+(q*196|0)+64+(a[F+(X*14|0)+8+q|0]<<2)>>2]|0)!=(c[W+(q*196|0)+64+(J<<2)>>2]|0)){break}R=F+(X*14|0)+(q<<2)|0;N=e[R>>1]|e[R+2>>1]<<16;c[v>>2]=N;ba=1;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=N;break d}}while(0);if((a[F+(X*14|0)+10+I|0]|0)!=1){ba=0;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=0;break}if((c[W+(I*196|0)+64+(a[F+(X*14|0)+8+I|0]<<2)>>2]|0)!=(c[W+(q*196|0)+64+(J<<2)>>2]|0)){ba=0;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=0;break}N=F+(X*14|0)+(I<<2)|0;R=e[N>>1]|e[N+2>>1]<<16;c[v>>2]=R;ba=1;da=S;ea=T;fa=m;ga=aa;ha=la;ia=T;ja=Q;ka=R}}while(0);do{if(M){ma=Z;na=ba}else{if((ba|0)==0){oa=Z}else{c[t>>2]=ka;oa=1}if(ga){la=XFa(f,Y,T,q,w,q,J)|0;if((la|0)!=0){ma=oa;na=la;break}pa=XFa(f,Y,T,I,w,q,J)|0}else{pa=0}if((ha|0)!=0&(pa|0)==0){la=XFa(f,ja,ia,q,w,q,J)|0;if((la|0)!=0){ma=oa;na=la;break}qa=XFa(f,ja,ia,I,w,q,J)|0}else{qa=pa}if(!((fa|0)!=0&(qa|0)==0)){ma=oa;na=qa;break}la=XFa(f,da,ea,q,w,q,J)|0;if((la|0)!=0){ma=oa;na=la;break}ma=oa;na=XFa(f,da,ea,I,w,q,J)|0}}while(0);I=(ma|0)!=0;if(I){c[r>>2]=c[t>>2];ra=1}else{ra=0}e:do{if((na|0)==0){sa=ra;P=98}else{do{if(I){if((b[t>>1]|0)!=(b[v>>1]|0)){break}if((b[u+2>>1]|0)==(b[w+2>>1]|0)){sa=ra;P=98;break e}}}while(0);Q=ra+1|0;c[s+(ra<<2)>>2]=c[v>>2];if(Q>>>0<2>>>0){sa=Q;P=98}else{ta=Q}}}while(0);do{if((P|0)==98){if((a[f+3011|0]|0)==0){ta=sa;break}if((YFa(f,g,h,j,k,J,y,q)|0)==0){ta=sa;break}c[s+(sa<<2)>>2]=c[x>>2];ta=sa+1|0}}while(0);if((ta|0)<2){ua=ta}else{va=s+(p<<2)|0;wa=b[va>>1]|0;xa=o+(q<<2)|0;b[xa>>1]=wa;ya=s+(p<<2)+2|0;za=b[ya>>1]|0;Aa=o+(q<<2)+2|0;b[Aa>>1]=za;i=n;return}while(1){ta=ua+1|0;b[s+(ua<<2)>>1]=0;b[s+(ua<<2)+2>>1]=0;if((ta|0)<2){ua=ta}else{break}}va=s+(p<<2)|0;wa=b[va>>1]|0;xa=o+(q<<2)|0;b[xa>>1]=wa;ya=s+(p<<2)+2|0;za=b[ya>>1]|0;Aa=o+(q<<2)+2|0;b[Aa>>1]=za;i=n;return}function XFa(d,f,g,h,i,j,k){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=d+3480|0;m=c[l>>2]|0;n=c[m+16>>2]|0;o=c[m+20>>2]|0;m=c[o+(j*196|0)+128+(k<<2)>>2]|0;p=(ca(c[(c[d+180>>2]|0)+13132>>2]|0,g)|0)+f|0;if((a[n+(p*14|0)+10+h|0]|0)==0){q=0;return q|0}if((c[o+(h*196|0)+128+(a[n+(p*14|0)+8+h|0]<<2)>>2]|0)!=(m|0)){q=0;return q|0}o=n+(p*14|0)+(h<<2)|0;n=i;f=e[o>>1]|e[o+2>>1]<<16;y=f;b[n>>1]=y;b[n+2>>1]=y>>16;if((m|0)!=0){q=1;return q|0}m=c[l>>2]|0;l=c[m+20>>2]|0;n=c[l+(h*196|0)+64+(a[(c[m+16>>2]|0)+(p*14|0)+8+h|0]<<2)>>2]|0;h=c[l+(j*196|0)+64+(k<<2)>>2]|0;if((n|0)==(h|0)){q=1;return q|0}k=c[d+5788>>2]|0;d=(k|0)==(n|0)?1:k-n|0;n=k-h|0;if((d+128|0)>>>0>255>>>0){r=(d>>31^127)&255}else{r=d&255}d=r<<24>>24;if((n+128|0)>>>0>255>>>0){s=(n>>31^127)&255}else{s=n&255}n=(d|0)/2|0;h=(ca(((r<<24>>24>-2?n:-n|0)+16384|0)/(d|0)|0,s<<24>>24)|0)+32>>6;if((h|0)<-4096){t=-4096}else{t=(h|0)>4095?4095:h}h=ca(f<<16>>16,t)|0;s=h+127+(h>>>31)|0;h=s>>8;if((h+32768|0)>>>0>65535>>>0){u=(s>>31^32767)&65535}else{u=h&65535}b[i>>1]=u;u=ca(f>>16,t)|0;t=u+127+(u>>>31)|0;u=t>>8;if((u+32768|0)>>>0>65535>>>0){v=(t>>31^32767)&65535}else{v=u&65535}b[i+2>>1]=v;q=1;return q|0}function YFa(d,e,f,g,h,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=i;i=i+16|0;n=m|0;o=d+180|0;p=c[(c[o>>2]|0)+13132>>2]|0;q=c[(c[d+3480>>2]|0)+36>>2]|0;if((q|0)==0){r=0;i=m;return r|0}s=c[q+16>>2]|0;t=c[q+32>>2]|0;u=g+e|0;v=h+f|0;if((a[d+140|0]|0)==1){M5a(q+4|0,v,0)}if((s|0)==0){r=0;i=m;return r|0}w=c[o>>2]|0;x=c[w+13080>>2]|0;do{if((f>>x|0)==(v>>x|0)){if((v|0)>=(c[w+13100>>2]|0)){break}if((u|0)>=(c[w+13096>>2]|0)){break}y=u&-16;z=v&-16;A=c[w+13084>>2]|0;B=n;C=s+(((ca(z>>A,p)|0)+(y>>A)|0)*14|0)|0;b[B>>1]=b[C>>1]|0;b[B+2>>1]=b[C+2>>1]|0;b[B+4>>1]=b[C+4>>1]|0;b[B+6>>1]=b[C+6>>1]|0;b[B+8>>1]=b[C+8>>1]|0;b[B+10>>1]=b[C+10>>1]|0;b[B+12>>1]=b[C+12>>1]|0;C=ZFa(d,n,j,k,l,t,mGa(d,q,y,z)|0)|0;if((C|0)==0){break}else{r=C}i=m;return r|0}}while(0);w=(g>>1)+e&-16;e=(h>>1)+f&-16;f=c[(c[o>>2]|0)+13084>>2]|0;o=n;h=s+(((ca(e>>f,p)|0)+(w>>f)|0)*14|0)|0;b[o>>1]=b[h>>1]|0;b[o+2>>1]=b[h+2>>1]|0;b[o+4>>1]=b[h+4>>1]|0;b[o+6>>1]=b[h+6>>1]|0;b[o+8>>1]=b[h+8>>1]|0;b[o+10>>1]=b[h+10>>1]|0;b[o+12>>1]=b[h+12>>1]|0;r=ZFa(d,n,j,k,l,t,mGa(d,q,w,e)|0)|0;i=m;return r|0}function ZFa(d,e,f,g,h,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;l=i;m=e;e=i;i=i+14|0;i=i+7&-8;c[e>>2]=c[m>>2];c[e+4>>2]=c[m+4>>2];c[e+8>>2]=c[m+8>>2];b[e+12>>1]=b[m+12>>1]|0;m=c[(c[d+3480>>2]|0)+20>>2]|0;if((a[e+12|0]|0)!=0){b[g>>1]=0;b[g+2>>1]=0;n=0;i=l;return n|0}o=a[e+10|0]|0;if((o<<24>>24|0)==0){n=_Fa(g,e+4|0,j,c[d+5788>>2]|0,m,h,f,k,1,a[e+9|0]|0)|0;i=l;return n|0}else if((o<<24>>24|0)==1){o=a[e+11|0]|0;if((o<<24>>24|0)==1){p=c[m+192>>2]|0;if((p|0)>0){q=c[d+5788>>2]|0;r=0;s=0;while(1){t=((c[m+64+(s<<2)>>2]|0)>(q|0))+r|0;u=s+1|0;if((u|0)<(p|0)){r=t;s=u}else{v=t;break}}}else{v=0}s=c[m+388>>2]|0;if((s|0)>0){r=c[d+5788>>2]|0;p=v;q=0;while(1){t=((c[m+260+(q<<2)>>2]|0)>(r|0))+p|0;u=q+1|0;if((u|0)<(s|0)){p=t;q=u}else{w=t;break}}}else{w=v}if((w|h|0)==0){n=_Fa(g,e|0,j,c[d+5788>>2]|0,m,h,f,k,0,a[e+8|0]|0)|0;i=l;return n|0}if((w|0)==0&(h|0)==1){n=_Fa(g,e+4|0,j,c[d+5788>>2]|0,m,1,f,k,1,a[e+9|0]|0)|0;i=l;return n|0}if((a[d+3027|0]|0)==1){n=_Fa(g,e|0,j,c[d+5788>>2]|0,m,h,f,k,0,a[e+8|0]|0)|0;i=l;return n|0}else{n=_Fa(g,e+4|0,j,c[d+5788>>2]|0,m,h,f,k,1,a[e+9|0]|0)|0;i=l;return n|0}}else if((o<<24>>24|0)==0){n=_Fa(g,e|0,j,c[d+5788>>2]|0,m,h,f,k,0,a[e+8|0]|0)|0;i=l;return n|0}else{n=0;i=l;return n|0}}else{n=0;i=l;return n|0}return 0}function _Fa(a,d,e,f,g,h,i,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;m=c[g+(h*196|0)+128+(i<<2)>>2]|0;if((m|0)!=(c[j+(k*196|0)+128+(l<<2)>>2]|0)){b[a>>1]=0;b[a+2>>1]=0;n=0;return n|0}o=c[j+(k*196|0)+64+(l<<2)>>2]|0;l=f-(c[g+(h*196|0)+64+(i<<2)>>2]|0)|0;i=(o|0)==(e|0)?1:e-o|0;if((m|0)!=0|(i|0)==(l|0)){b[a>>1]=b[d>>1]|0;b[a+2>>1]=b[d+2>>1]|0;n=1;return n|0}if((i+128|0)>>>0>255>>>0){p=(i>>31^127)&255}else{p=i&255}i=p<<24>>24;if((l+128|0)>>>0>255>>>0){q=(l>>31^127)&255}else{q=l&255}l=(i|0)/2|0;m=(ca(((p<<24>>24>-2?l:-l|0)+16384|0)/(i|0)|0,q<<24>>24)|0)+32>>6;if((m|0)<-4096){r=-4096}else{r=(m|0)>4095?4095:m}m=ca(b[d>>1]|0,r)|0;q=m+127+(m>>>31)|0;m=q>>8;if((m+32768|0)>>>0>65535>>>0){s=(q>>31^32767)&65535}else{s=m&65535}b[a>>1]=s;s=ca(b[d+2>>1]|0,r)|0;r=s+127+(s>>>31)|0;s=r>>8;if((s+32768|0)>>>0>65535>>>0){t=(r>>31^32767)&65535}else{t=s&65535}b[a+2>>1]=t;n=1;return n|0}function $Fa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=d;d=i;i=i+14|0;i=i+7&-8;c[d>>2]=c[g>>2];c[d+4>>2]=c[g+4>>2];c[d+8>>2]=c[g+8>>2];b[d+12>>1]=b[g+12>>1]|0;g=e;e=i;i=i+14|0;i=i+7&-8;c[e>>2]=c[g>>2];c[e+4>>2]=c[g+4>>2];c[e+8>>2]=c[g+8>>2];b[e+12>>1]=b[g+12>>1]|0;g=(a[d+11|0]|0)==0;do{if((a[d+10|0]|0)==0){if(g){h=0;break}if((a[e+10|0]|0)!=0){h=0;break}if((a[e+11|0]|0)==0){h=0;break}if((a[d+9|0]|0)!=(a[e+9|0]|0)){h=0;break}if((b[d+4>>1]|0)!=(b[e+4>>1]|0)){h=0;break}h=(b[d+6>>1]|0)==(b[e+6>>1]|0)|0}else{j=(a[e+10|0]|0)==0;if(g){if(j){h=0;break}if((a[e+11|0]|0)!=0){h=0;break}if((a[d+8|0]|0)!=(a[e+8|0]|0)){h=0;break}if((b[d>>1]|0)!=(b[e>>1]|0)){h=0;break}h=(b[d+2>>1]|0)==(b[e+2>>1]|0)|0;break}if(j){h=0;break}if((a[e+11|0]|0)==0){h=0;break}if((a[d+8|0]|0)!=(a[e+8|0]|0)){h=0;break}if((b[d>>1]|0)!=(b[e>>1]|0)){h=0;break}if((b[d+2>>1]|0)!=(b[e+2>>1]|0)){h=0;break}if((a[d+9|0]|0)!=(a[e+9|0]|0)){h=0;break}if((b[d+4>>1]|0)!=(b[e+4>>1]|0)){h=0;break}h=(b[d+6>>1]|0)==(b[e+6>>1]|0)|0}}while(0);i=f;return h|0}function aGa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;j=c[b+136>>2]|0;k=j+9272|0;l=f+2188|0;do{if((l|0)!=(e|0)){m=f+2184|0;if((c[m>>2]|0)==0){break}n=j+9280|0;o=c[n>>2]|0;p=k|0;q=c[p>>2]|0;r=d[q+(o>>>3)|0]|0;s=j+9288|0;t=c[s>>2]|0;u=((o|0)<(t|0))+o|0;c[n>>2]=u;if((r&128>>>((o&7)>>>0)|0)==0){break}do{if((g|0)==0){v=((e-l|0)/168|0)-1|0;w=u;x=q;y=t}else{o=(bGa(k)|0)+1|0;r=c[m>>2]|0;if(!(o>>>0>r>>>0)){v=r-o|0;w=c[n>>2]|0;x=c[p>>2]|0;y=c[s>>2]|0;break}KIb(c[b+4>>2]|0,16,2536912,(z=i,i=i+16|0,c[z>>2]=o,c[z+8>>2]=r,z)|0);i=z;A=-1094995529;i=h;return A|0}}while(0);m=(d[x+(w>>>3)|0]|0)<<(w&7)>>>7;c[n>>2]=((w|0)<(y|0))+w;t=ca(1-(m<<1&2)|0,(bGa(k)|0)+1|0)|0;m=f+2188+(v*168|0)+4|0;if((c[m>>2]|0)<0){c[e+4>>2]=0;c[e>>2]=0;A=0;i=h;return A|0}else{B=0;C=0;D=0}while(1){q=c[n>>2]|0;u=(d[(c[p>>2]|0)+(q>>>3)|0]|0)<<(q&7)>>>7;c[n>>2]=((q|0)<(c[s>>2]|0))+q;q=u&1;a[e+136+C|0]=q;if((q|0)==0){q=c[n>>2]|0;u=d[(c[p>>2]|0)+(q>>>3)|0]|0;c[n>>2]=((q|0)<(c[s>>2]|0))+q;if((u&128>>>((q&7)>>>0)|0)==0){E=D;F=C}else{G=13}}else{G=13}if((G|0)==13){G=0;if((B|0)<(c[m>>2]|0)){H=(c[f+2188+(v*168|0)+8+(B<<2)>>2]|0)+t|0}else{H=t}c[e+8+(C<<2)>>2]=H;E=(H>>>31)+D|0;F=C+1|0}q=B+1|0;if((q|0)>(c[m>>2]|0)){break}else{B=q;C=F;D=E}}m=e+4|0;c[m>>2]=F;t=e|0;c[t>>2]=E;if((F|0)>1){s=1;n=F;while(1){p=c[e+8+(s<<2)>>2]|0;q=a[e+136+s|0]|0;if((s|0)>0){u=s;while(1){r=u-1|0;o=e+8+(r<<2)|0;I=c[o>>2]|0;if((p|0)<(I|0)){c[e+8+(u<<2)>>2]=I;I=e+136+r|0;a[e+136+u|0]=a[I]|0;c[o>>2]=p;a[I]=q}if((r|0)>0){u=r}else{break}}J=c[m>>2]|0}else{J=n}u=s+1|0;if((u|0)<(J|0)){s=u;n=J}else{break}}K=c[t>>2]|0}else{K=E}if(K>>>0>1>>>0){L=0;M=K}else{A=0;i=h;return A|0}while(1){n=M-1|0;s=e+8+(L<<2)|0;m=c[s>>2]|0;u=e+136+L|0;q=a[u]|0;p=e+8+(n<<2)|0;c[s>>2]=c[p>>2];s=e+136+n|0;a[u]=a[s]|0;c[p>>2]=m;a[s]=q;q=L+1|0;if(q>>>0<(c[t>>2]|0)>>>1>>>0){L=q;M=n}else{A=0;break}}i=h;return A|0}}while(0);M=e|0;c[M>>2]=bGa(k)|0;L=bGa(k)|0;K=c[M>>2]|0;if(K>>>0>15>>>0|L>>>0>15>>>0){KIb(c[b+4>>2]|0,16,2604680,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=h;return A|0}z=K+L|0;c[e+4>>2]=z;if((z|0)==0){A=0;i=h;return A|0}if((K|0)!=0){K=j+9280|0;z=k|0;b=j+9288|0;E=0;J=0;do{J=J-1-(bGa(k)|0)|0;c[e+8+(E<<2)>>2]=J;F=c[K>>2]|0;D=(d[(c[z>>2]|0)+(F>>>3)|0]|0)<<(F&7)>>>7;c[K>>2]=((F|0)<(c[b>>2]|0))+F;a[e+136+E|0]=D&1;E=E+1|0;}while(E>>>0<(c[M>>2]|0)>>>0)}if((L|0)==0){A=0;i=h;return A|0}E=j+9280|0;b=k|0;K=j+9288|0;j=0;z=0;while(1){J=z+1+(bGa(k)|0)|0;c[e+8+((c[M>>2]|0)+j<<2)>>2]=J;D=c[E>>2]|0;F=(d[(c[b>>2]|0)+(D>>>3)|0]|0)<<(D&7)>>>7;c[E>>2]=((D|0)<(c[K>>2]|0))+D;a[(c[M>>2]|0)+j+(e+136)|0]=F&1;F=j+1|0;if(F>>>0<L>>>0){j=F;z=J}else{A=0;break}}i=h;return A|0}function bGa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a>>2]|0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;a=b+(f>>>3)|0;h=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7);a=f+16|0;i=g>>>0>a>>>0?a:g;a=b+(i>>>3)|0;j=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>16|h&-65536;i=j>>>0>65535>>>0;a=i?h>>>16:j;j=i?16:0;if((a&65280|0)==0){k=j;l=a}else{k=j|8;l=a>>>8}a=(d[1359664+l|0]|0)+k|0;k=31-a|0;l=-f|0;j=g-f|0;if((k|0)<(l|0)){m=l}else{m=(j|0)<(k|0)?j:k}j=m+f|0;c[e>>2]=j;f=k+1|0;if((f|0)==0){n=0;o=n-1|0;return o|0}m=b+(j>>>3)|0;l=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7);if((f|0)<26){m=j+f|0;c[e>>2]=g>>>0>m>>>0?m:g;n=l>>>(a>>>0);o=n-1|0;return o|0}else{a=j+16|0;j=g>>>0>a>>>0?a:g;c[e>>2]=j;a=k-15|0;m=b+(j>>>3)|0;b=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>((47-k|0)>>>0);k=j+a|0;c[e>>2]=g>>>0>k>>>0?k:g;n=b|l>>>16<<a;o=n-1|0;return o|0}return 0}function cGa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+8|0;f=e|0;g=c[b+136>>2]|0;h=g+9272|0;j=dGb(468)|0;c[f>>2]=j;if((j|0)==0){k=-12;i=e;return k|0}l=c[j+4>>2]|0;j=b+4|0;KIb(c[j>>2]|0,48,2452328,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=g+9280|0;o=c[n>>2]|0;p=g+9288|0;g=c[p>>2]|0;q=h|0;r=c[q>>2]|0;s=r+(o>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(o&7)>>>28;s=o+4|0;o=g>>>0>s>>>0?s:g;c[n>>2]=o;s=r+(o>>>3)|0;u=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(o&7);s=o+2|0;o=g>>>0>s>>>0?s:g;c[n>>2]=o;do{if((u&-1073741824|0)==-1073741824){s=r+(o>>>3)|0;v=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(o&7)>>>26;s=o+6|0;c[n>>2]=g>>>0>s>>>0?s:g;c[l+4>>2]=v+1;v=c[n>>2]|0;s=c[p>>2]|0;w=r+(v>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)>>>29;w=v+3|0;c[n>>2]=s>>>0>w>>>0?w:s;s=l+8|0;c[s>>2]=x+1;x=c[n>>2]|0;w=(d[r+(x>>>3)|0]|0)<<(x&7)>>>7;c[n>>2]=((x|0)<(c[p>>2]|0))+x;a[l]=w&1;w=c[n>>2]|0;x=c[p>>2]|0;v=(c[q>>2]|0)+(w>>>3)|0;y=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(w&7);v=w+16|0;c[n>>2]=x>>>0>v>>>0?v:x;if(!((y&-65536|0)==-65536)){KIb(c[j>>2]|0,16,2247416,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;break}y=c[s>>2]|0;if((y|0)>7){KIb(c[j>>2]|0,16,2205392,(m=i,i=i+8|0,c[m>>2]=y,m)|0);i=m;break}dGa(b,l+12|0,y);y=c[n>>2]|0;x=(d[(c[q>>2]|0)+(y>>>3)|0]|0)<<(y&7)>>>7;c[n>>2]=((y|0)<(c[p>>2]|0))+y;y=x&1;c[l+348>>2]=y;if((y|0)==0){z=(c[s>>2]|0)-1|0}else{z=0}y=l+352|0;x=l+380|0;v=l+408|0;w=z;while(1){if((w|0)>=(c[s>>2]|0)){A=17;break}B=y+(w<<2)|0;c[B>>2]=(bGa(h)|0)+1;C=x+(w<<2)|0;c[C>>2]=bGa(h)|0;c[v+(w<<2)>>2]=(bGa(h)|0)-1;D=c[B>>2]|0;if(D>>>0>16>>>0){A=13;break}E=c[C>>2]|0;if(E>>>0>(D-1|0)>>>0){A=16;break}w=w+1|0}if((A|0)==13){KIb(c[j>>2]|0,16,2173232,(m=i,i=i+8|0,c[m>>2]=D-1,m)|0);i=m;break}else if((A|0)==16){KIb(c[j>>2]|0,16,2145808,(m=i,i=i+8|0,c[m>>2]=E,m)|0);i=m;break}else if((A|0)==17){w=c[n>>2]|0;v=c[p>>2]|0;x=(c[q>>2]|0)+(w>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(w&7)>>>26;x=w+6|0;c[n>>2]=v>>>0>x>>>0?x:v;v=l+436|0;c[v>>2]=y;y=(bGa(h)|0)+1|0;x=l+440|0;c[x>>2]=y;if((y|0)>1){w=1;C=c[v>>2]|0;B=y;while(1){if((C|0)<0){F=C;G=B}else{y=c[p>>2]|0;H=0;I=c[n>>2]|0;do{J=I+1|0;I=y>>>0>J>>>0?J:y;c[n>>2]=I;H=H+1|0;K=c[v>>2]|0;}while((H|0)<=(K|0));F=K;G=c[x>>2]|0}H=w+1|0;if((H|0)<(G|0)){w=H;C=F;B=G}else{break}}}B=c[n>>2]|0;C=(d[(c[q>>2]|0)+(B>>>3)|0]|0)<<(B&7)>>>7;c[n>>2]=((B|0)<(c[p>>2]|0))+B;B=C&1;a[l+444|0]=B;do{if(!(B<<24>>24==0)){C=c[n>>2]|0;w=c[p>>2]|0;x=c[q>>2]|0;v=x+(C>>>3)|0;H=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(C&7)&-65536;v=C+16|0;C=w>>>0>v>>>0?v:w;c[n>>2]=C;v=x+(C>>>3)|0;I=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(C&7)>>>16;v=C+16|0;c[n>>2]=w>>>0>v>>>0?v:w;c[l+448>>2]=I|H;H=c[n>>2]|0;I=c[p>>2]|0;w=x+(H>>>3)|0;v=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(H&7)&-65536;w=H+16|0;H=I>>>0>w>>>0?w:I;c[n>>2]=H;w=x+(H>>>3)|0;C=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(H&7)>>>16;w=H+16|0;c[n>>2]=I>>>0>w>>>0?w:I;c[l+452>>2]=C|v;v=c[n>>2]|0;C=(d[x+(v>>>3)|0]|0)<<(v&7)>>>7;c[n>>2]=((v|0)<(c[p>>2]|0))+v;v=C&1;a[l+456|0]=v;if(!(v<<24>>24==0)){c[l+460>>2]=(bGa(h)|0)+1}v=bGa(h)|0;C=l+464|0;c[C>>2]=v;if((v|0)>0){L=0}else{break}do{bGa(h)|0;if((L|0)==0){M=1}else{v=c[n>>2]|0;x=(d[(c[q>>2]|0)+(v>>>3)|0]|0)<<(v&7)>>>7;c[n>>2]=((v|0)<(c[p>>2]|0))+v;M=x&1}eGa(b,M,c[s>>2]|0);L=L+1|0;}while((L|0)<(c[C>>2]|0))}}while(0);s=c[n>>2]|0;c[n>>2]=((s|0)<(c[p>>2]|0))+s;s=b+188+(t<<2)|0;fGb(s);c[s>>2]=c[f>>2];k=0;i=e;return k|0}}else{KIb(c[j>>2]|0,16,2298032,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);fGb(f);k=-1094995529;i=e;return k|0}function dGa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=c[b+136>>2]|0;kGa(b,e|0);h=g+9280|0;i=c[h>>2]|0;j=g+9288|0;k=c[j>>2]|0;l=g+9272|0;g=(c[l>>2]|0)+(i>>>3)|0;m=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(i&7)>>>24;g=i+8|0;c[h>>2]=k>>>0>g>>>0?g:k;a[e+35|0]=m;m=f-1|0;f=(m|0)>0;if(f){n=0}else{return}do{k=c[h>>2]|0;g=d[(c[l>>2]|0)+(k>>>3)|0]<<(k&7)>>>7;c[h>>2]=((k|0)<(c[j>>2]|0))+k;a[e+320+n|0]=g&1;g=c[h>>2]|0;k=d[(c[l>>2]|0)+(g>>>3)|0]<<(g&7)>>>7;c[h>>2]=((g|0)<(c[j>>2]|0))+g;a[e+327+n|0]=k&1;n=n+1|0;}while((n|0)<(m|0));if(!f){return}do{if((m|0)<8){n=c[j>>2]|0;k=m;g=c[h>>2]|0;do{i=g+2|0;g=n>>>0>i>>>0?i:n;k=k+1|0;}while((k|0)<8);c[h>>2]=g;if(f){o=0;break}return}else{o=0}}while(0);do{if((a[e+320+o|0]|0)!=0){kGa(b,e+40+(o*40|0)|0)}if((a[e+327+o|0]|0)!=0){f=c[h>>2]|0;k=c[j>>2]|0;n=(c[l>>2]|0)+(f>>>3)|0;i=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(f&7)>>>24;n=f+8|0;c[h>>2]=k>>>0>n>>>0?n:k;a[e+40+(o*40|0)+35|0]=i}o=o+1|0;}while((o|0)<(m|0));return}function eGa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a+136|0;a=c[f>>2]|0;g=a+9272|0;do{if((b|0)==0){h=0;i=0;j=0}else{k=a+9280|0;l=c[k>>2]|0;m=c[g>>2]|0;n=(d[m+(l>>>3)|0]|0)<<(l&7)>>>7;o=c[a+9288>>2]|0;p=((l|0)<(o|0))+l|0;c[k>>2]=p;l=n&1;q=(d[m+(p>>>3)|0]|0)<<(p&7)>>>7;r=((p|0)<(o|0))+p|0;c[k>>2]=r;p=q&1;if(((q|n)&1|0)==0){h=0;i=p;j=l;break}n=(d[m+(r>>>3)|0]|0)<<(r&7)>>>7;m=((r|0)<(o|0))+r|0;c[k>>2]=m;r=n&1;if((r|0)==0){n=m+4|0;q=o>>>0>n>>>0?n:o;c[k>>2]=q;n=q+4|0;s=o>>>0>n>>>0?n:o}else{n=m+8|0;m=(o>>>0>n>>>0?n:o)+5|0;n=(o>>>0>m>>>0?m:o)+1|0;m=(o>>>0>n>>>0?n:o)+5|0;n=(o>>>0>m>>>0?m:o)+4|0;m=(o>>>0>n>>>0?n:o)+4|0;n=o>>>0>m>>>0?m:o;c[k>>2]=n;m=n+4|0;s=o>>>0>m>>>0?m:o}m=s+5|0;n=(o>>>0>m>>>0?m:o)+5|0;m=(o>>>0>n>>>0?n:o)+5|0;c[k>>2]=o>>>0>m>>>0?m:o;h=r;i=p;j=l}}while(0);if((e|0)<=0){return}s=a+9280|0;b=g|0;l=a+9288|0;a=(i|0)==0;if((j|0)==0){j=1;while(1){i=c[s>>2]|0;p=c[b>>2]|0;r=d[p+(i>>>3)|0]|0;o=c[l>>2]|0;m=((i|0)<(o|0))+i|0;c[s>>2]=m;do{if((r&128>>>((i&7)>>>0)|0)==0){k=d[p+(m>>>3)|0]|0;n=((m|0)<(o|0))+m|0;c[s>>2]=n;if((k&128>>>((m&7)>>>0)|0)!=0){t=11;break}k=d[p+(n>>>3)|0]|0;c[s>>2]=((n|0)<(o|0))+n;if((k&128>>>((n&7)>>>0)|0)==0){t=13}else{u=1}}else{t=11}}while(0);if((t|0)==11){t=0;bGa(g)|0;t=13}if((t|0)==13){t=0;u=(bGa(g)|0)+1|0}if(!a){jGa(c[f>>2]|0,u,h)}if((j|0)>=(e|0)){break}j=j+1|0}return}else{j=1;while(1){u=c[s>>2]|0;o=c[b>>2]|0;p=d[o+(u>>>3)|0]|0;m=c[l>>2]|0;i=((u|0)<(m|0))+u|0;c[s>>2]=i;do{if((p&128>>>((u&7)>>>0)|0)==0){r=d[o+(i>>>3)|0]|0;n=((i|0)<(m|0))+i|0;c[s>>2]=n;if((r&128>>>((i&7)>>>0)|0)!=0){t=20;break}r=d[o+(n>>>3)|0]|0;c[s>>2]=((n|0)<(m|0))+n;if((r&128>>>((n&7)>>>0)|0)==0){t=22}else{v=1}}else{t=20}}while(0);if((t|0)==20){t=0;bGa(g)|0;t=22}if((t|0)==22){t=0;v=(bGa(g)|0)+1|0}jGa(c[f>>2]|0,v,h);if(!a){jGa(c[f>>2]|0,v,h)}if((j|0)>=(e|0)){break}j=j+1|0}return}}function fGa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;f=i;i=i+8|0;g=f|0;h=e+136|0;j=c[h>>2]|0;k=j+9272|0;l=dGb(13168)|0;c[g>>2]=l;if((l|0)==0){m=-12;i=f;return m|0}n=c[l+4>>2]|0;l=n;o=e+4|0;KIb(c[o>>2]|0,48,2122016,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=j+9280|0;r=c[q>>2]|0;s=j+9288|0;j=c[s>>2]|0;t=k|0;u=c[t>>2]|0;v=u+(r>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(r&7)>>>28;v=r+4|0;c[q>>2]=j>>>0>v>>>0?v:j;c[n>>2]=w;a:do{if((c[e+188+(w<<2)>>2]|0)==0){KIb(c[o>>2]|0,16,2639688,(p=i,i=i+8|0,c[p>>2]=w,p)|0);i=p;x=-1094995529}else{j=c[q>>2]|0;v=c[s>>2]|0;r=u+(j>>>3)|0;y=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(j&7)>>>29;r=j+3|0;c[q>>2]=v>>>0>r>>>0?r:v;v=y+1|0;y=n+72|0;c[y>>2]=v;if(v>>>0>7>>>0){KIb(c[o>>2]|0,16,2616912,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;x=-1094995529;break}v=c[s>>2]|0;r=(c[q>>2]|0)+1|0;c[q>>2]=v>>>0>r>>>0?r:v;dGa(e,n+300|0,c[y>>2]|0);v=bGa(k)|0;if(v>>>0>31>>>0){KIb(c[o>>2]|0,16,2589744,(p=i,i=i+8|0,c[p>>2]=v,p)|0);i=p;x=-1094995529;break}r=bGa(k)|0;j=n+4|0;c[j>>2]=r;if((r|0)!=1){RIb(c[o>>2]|0,2568056,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;x=-1163346256;break}r=n+13096|0;c[r>>2]=bGa(k)|0;z=bGa(k)|0;A=n+13100|0;c[A>>2]=z;B=tIb(c[r>>2]|0,z,0,c[o>>2]|0)|0;if((B|0)<0){x=B;break}z=c[q>>2]|0;C=d[(c[t>>2]|0)+(z>>>3)|0]|0;c[q>>2]=((z|0)<(c[s>>2]|0))+z;if((C&128>>>((z&7)>>>0)|0)!=0){z=n+36|0;C=z;c[C>>2]=(bGa(k)|0)<<1;D=n+40|0;c[D>>2]=(bGa(k)|0)<<1;E=n+44|0;c[E>>2]=(bGa(k)|0)<<1;F=(bGa(k)|0)<<1;c[n+48>>2]=F;G=c[o>>2]|0;if((c[G+92>>2]&65536|0)!=0){H=c[D>>2]|0;D=c[E>>2]|0;KIb(G,48,2549968,(p=i,i=i+32|0,c[p>>2]=c[C>>2],c[p+8>>2]=H,c[p+16>>2]=D,c[p+24>>2]=F,p)|0);i=p;mrc(z|0,0,16)|0}F=n+20|0;c[F>>2]=c[z>>2];c[F+4>>2]=c[z+4>>2];c[F+8>>2]=c[z+8>>2];c[F+12>>2]=c[z+12>>2]}z=n+52|0;c[z>>2]=(bGa(k)|0)+8;F=bGa(k)|0;D=F+8|0;H=c[z>>2]|0;if((D|0)!=(H|0)){KIb(c[o>>2]|0,16,2531880,(p=i,i=i+16|0,c[p>>2]=H,c[p+8>>2]=D,p)|0);i=p;x=-1094995529;break}if((c[j>>2]|0)!=1){KIb(c[o>>2]|0,16,2502688,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;m=-1163346256;i=f;return m|0}if((F|0)==1){c[n+60>>2]=70;I=70}else if((F|0)==2){c[n+60>>2]=72;I=72}else if((F|0)==0){c[n+60>>2]=0;I=0}else{KIb(c[o>>2]|0,16,2516688,(p=i,i=i+8|0,c[p>>2]=D,p)|0);i=p;x=-1163346256;break}D=n+60|0;F=qKb(I)|0;if((F|0)==0){x=-22;break}c[n+13152>>2]=0;c[n+13140>>2]=0;j=d[F+5|0]|0;c[n+13144>>2]=j;c[n+13148>>2]=j;j=d[F+6|0]|0;c[n+13156>>2]=j;c[n+13160>>2]=j;j=n+56|0;c[j>>2]=(c[z>>2]|0)>8;F=bGa(k)|0;H=F+4|0;C=n+64|0;c[C>>2]=H;if(H>>>0>16>>>0){KIb(c[o>>2]|0,16,2489584,(p=i,i=i+8|0,c[p>>2]=F,p)|0);i=p;x=-1094995529;break}F=c[q>>2]|0;H=d[(c[t>>2]|0)+(F>>>3)|0]|0;c[q>>2]=((F|0)<(c[s>>2]|0))+F;G=(H&128>>>((F&7)>>>0)|0)!=0;F=c[y>>2]|0;if(G){if((F|0)>0){J=0;K=30}}else{J=F-1|0;K=30}do{if((K|0)==30){F=n+76|0;H=J;do{E=F+(H*12|0)|0;c[E>>2]=(bGa(k)|0)+1;L=F+(H*12|0)+4|0;c[L>>2]=bGa(k)|0;c[F+(H*12|0)+8>>2]=(bGa(k)|0)-1;M=c[E>>2]|0;if((M|0)>16){K=32;break}N=c[L>>2]|0;if((N|0)>(M-1|0)){KIb(c[o>>2]|0,16,2468952,(p=i,i=i+8|0,c[p>>2]=N,p)|0);i=p;N=c[L>>2]|0;if((N|0)>15){x=-1094995529;break a}c[E>>2]=N+1}H=H+1|0;}while((H|0)<(c[y>>2]|0));if((K|0)==32){KIb(c[o>>2]|0,16,2478688,(p=i,i=i+8|0,c[p>>2]=M-1,p)|0);i=p;x=-1094995529;break a}if(!((J|0)>0&(G^1))){break}H=n+76|0;F=H+(J*12|0)|0;N=H+(J*12|0)+4|0;E=H+(J*12|0)+8|0;L=0;do{c[H+(L*12|0)>>2]=c[F>>2];c[H+(L*12|0)+4>>2]=c[N>>2];c[H+(L*12|0)+8>>2]=c[E>>2];L=L+1|0;}while((L|0)<(J|0))}}while(0);G=n+13064|0;c[G>>2]=(bGa(k)|0)+3;L=n+13068|0;c[L>>2]=bGa(k)|0;E=n+13072|0;c[E>>2]=(bGa(k)|0)+2;H=bGa(k)|0;N=c[E>>2]|0;F=n+13076|0;c[F>>2]=N+H;if(!(N>>>0<(c[G>>2]|0)>>>0)){KIb(c[o>>2]|0,16,2459720,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;x=-1094995529;break}N=n+13088|0;c[N>>2]=bGa(k)|0;H=n+13092|0;c[H>>2]=bGa(k)|0;O=c[q>>2]|0;P=(d[(c[t>>2]|0)+(O>>>3)|0]|0)<<(O&7)>>>7;c[q>>2]=((O|0)<(c[s>>2]|0))+O;O=P&1;a[n+634|0]=O;do{if(O<<24>>24==0){Q=B}else{P=n+635|0;mrc(P|0,16,16)|0;mrc(n+699|0,16,16)|0;mrc(n+763|0,16,16)|0;mrc(n+827|0,16,16)|0;mrc(n+891|0,16,16)|0;mrc(n+955|0,16,16)|0;mrc(n+2171|0,16,12)|0;nrc(n+1019|0,1575952,64)|0;nrc(n+1083|0,1575952,64)|0;nrc(n+1147|0,1575952,64)|0;nrc(n+1211|0,1576016,64)|0;nrc(n+1275|0,1576016,64)|0;nrc(n+1339|0,1576016,64)|0;nrc(n+1403|0,1575952,64)|0;nrc(n+1467|0,1575952,64)|0;nrc(n+1531|0,1575952,64)|0;nrc(n+1595|0,1576016,64)|0;nrc(n+1659|0,1576016,64)|0;nrc(n+1723|0,1576016,64)|0;nrc(n+1787|0,1575952,64)|0;nrc(n+1851|0,1576016,64)|0;R=c[q>>2]|0;S=d[(c[t>>2]|0)+(R>>>3)|0]|0;c[q>>2]=((R|0)<(c[s>>2]|0))+R;if((S&128>>>((R&7)>>>0)|0)==0){Q=B;break}R=gGa(e,P)|0;if((R|0)<0){x=R;break a}else{Q=R}}}while(0);B=c[q>>2]|0;O=(d[(c[t>>2]|0)+(B>>>3)|0]|0)<<(B&7)>>>7;c[q>>2]=((B|0)<(c[s>>2]|0))+B;a[n+12940|0]=O&1;O=c[q>>2]|0;B=(d[(c[t>>2]|0)+(O>>>3)|0]|0)<<(O&7)>>>7;c[q>>2]=((O|0)<(c[s>>2]|0))+O;a[n+12941|0]=B&1;B=c[q>>2]|0;O=c[t>>2]|0;R=(d[O+(B>>>3)|0]|0)<<(B&7)>>>7;c[q>>2]=((B|0)<(c[s>>2]|0))+B;B=R&1;c[n+68>>2]=B;do{if((B|0)!=0){R=c[q>>2]|0;P=c[s>>2]|0;S=O+(R>>>3)|0;T=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(R&7)>>>28;S=R+4|0;c[q>>2]=P>>>0>S>>>0?S:P;P=n+13044|0;a[P]=T+1;T=c[q>>2]|0;S=c[s>>2]|0;R=(c[t>>2]|0)+(T>>>3)|0;U=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(T&7)>>>28;R=T+4|0;c[q>>2]=S>>>0>R>>>0?R:S;a[n+13045|0]=U+1;U=(bGa(k)|0)+3|0;c[n+13048>>2]=U;c[n+13052>>2]=U+(bGa(k)|0);U=d[P]|0;P=c[z>>2]|0;if((U|0)>(P|0)){KIb(c[o>>2]|0,16,2443056,(p=i,i=i+16|0,c[p>>2]=U,c[p+8>>2]=P,p)|0);i=p;x=-1094995529;break a}else{P=c[q>>2]|0;U=(d[(c[t>>2]|0)+(P>>>3)|0]|0)<<(P&7)>>>7;c[q>>2]=((P|0)<(c[s>>2]|0))+P;a[n+13056|0]=U&1;break}}}while(0);O=bGa(k)|0;B=n+2184|0;c[B>>2]=O;if(O>>>0>64>>>0){KIb(c[o>>2]|0,16,2430696,(p=i,i=i+8|0,c[p>>2]=O,p)|0);i=p;x=-1094995529;break}U=n+2188|0;P=Q;S=0;R=O;while(1){if(!(S>>>0<R>>>0)){break}O=aGa(e,U+(S*168|0)|0,l,0)|0;if((O|0)<0){x=O;break a}P=O;S=S+1|0;R=c[B>>2]|0}B=c[q>>2]|0;R=(d[(c[t>>2]|0)+(B>>>3)|0]|0)<<(B&7)>>>7;c[q>>2]=((B|0)<(c[s>>2]|0))+B;B=R&1;a[n+12942|0]=B;do{if(!(B<<24>>24==0)){R=bGa(k)|0;S=n+13040|0;a[S]=R;if((R&255|0)==0){break}R=n+12944|0;U=0;do{O=c[C>>2]|0;T=c[q>>2]|0;V=c[s>>2]|0;W=c[t>>2]|0;X=W+(T>>>3)|0;Y=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(T&7)>>>((32-O|0)>>>0);X=T+O|0;O=V>>>0>X>>>0?X:V;c[q>>2]=O;b[R+(U<<1)>>1]=Y;Y=(d[W+(O>>>3)|0]|0)<<(O&7)>>>7;c[q>>2]=((O|0)<(V|0))+O;a[n+(U+13008)|0]=Y&1;U=U+1|0;}while((U|0)<(d[S]|0|0))}}while(0);C=c[q>>2]|0;B=(d[(c[t>>2]|0)+(C>>>3)|0]|0)<<(C&7)>>>7;c[q>>2]=((C|0)<(c[s>>2]|0))+C;a[n+13060|0]=B&1;B=c[q>>2]|0;C=(d[(c[t>>2]|0)+(B>>>3)|0]|0)<<(B&7)>>>7;c[q>>2]=((B|0)<(c[s>>2]|0))+B;a[n+13061|0]=C&1;C=n+160|0;B=C;c[B>>2]=0;S=n+164|0;c[S>>2]=1;U=c[q>>2]|0;R=d[(c[t>>2]|0)+(U>>>3)|0]|0;c[q>>2]=((U|0)<(c[s>>2]|0))+U;do{if((R&128>>>((U&7)>>>0)|0)!=0){Y=c[h>>2]|0;O=Y+9272|0;KIb(c[o>>2]|0,48,2277240,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;V=Y+9280|0;W=c[V>>2]|0;X=O|0;T=c[X>>2]|0;Z=d[T+(W>>>3)|0]|0;_=Y+9288|0;Y=c[_>>2]|0;$=((W|0)<(Y|0))+W|0;c[V>>2]=$;do{if((Z&128>>>((W&7)>>>0)|0)!=0){aa=T+($>>>3)|0;ba=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<($&7);aa=ba>>>24;da=$+8|0;ea=Y>>>0>da>>>0?da:Y;c[V>>2]=ea;if(ba>>>0<285212672>>>0){ba=190200+(aa<<3)|0;da=C;fa=c[ba+4>>2]|0;c[da>>2]=c[ba>>2];c[da+4>>2]=fa;break}if((aa|0)==255){fa=T+(ea>>>3)|0;da=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ea&7)>>>16;fa=ea+16|0;c[V>>2]=Y>>>0>fa>>>0?fa:Y;c[B>>2]=da;da=c[V>>2]|0;fa=c[_>>2]|0;ea=T+(da>>>3)|0;ba=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(da&7)>>>16;ea=da+16|0;c[V>>2]=fa>>>0>ea>>>0?ea:fa;c[S>>2]=ba;break}else{KIb(c[o>>2]|0,24,2272768,(p=i,i=i+8|0,c[p>>2]=aa,p)|0);i=p;break}}}while(0);T=c[V>>2]|0;Y=c[X>>2]|0;$=(d[Y+(T>>>3)|0]|0)<<(T&7)>>>7;c[V>>2]=((T|0)<(c[_>>2]|0))+T;T=$&1;c[n+168>>2]=T;if((T|0)!=0){T=c[V>>2]|0;$=(d[Y+(T>>>3)|0]|0)<<(T&7)>>>7;c[V>>2]=((T|0)<(c[_>>2]|0))+T;c[n+172>>2]=$&1}$=c[V>>2]|0;T=(d[Y+($>>>3)|0]|0)<<($&7)>>>7;c[V>>2]=(($|0)<(c[_>>2]|0))+$;$=T&1;c[n+176>>2]=$;do{if(($|0)!=0){T=c[V>>2]|0;W=c[_>>2]|0;Z=Y+(T>>>3)|0;aa=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(T&7)>>>29;Z=T+3|0;c[V>>2]=W>>>0>Z>>>0?Z:W;c[n+180>>2]=aa;aa=c[V>>2]|0;W=(d[Y+(aa>>>3)|0]|0)<<(aa&7)>>>7;c[V>>2]=((aa|0)<(c[_>>2]|0))+aa;aa=n+184|0;c[aa>>2]=W&1;W=c[V>>2]|0;Z=(d[Y+(W>>>3)|0]|0)<<(W&7)>>>7;c[V>>2]=((W|0)<(c[_>>2]|0))+W;W=Z&1;c[n+188>>2]=W;do{if((c[aa>>2]|0)!=0){if((c[D>>2]|0)!=0){break}c[D>>2]=12}}while(0);if((W|0)==0){break}aa=c[V>>2]|0;Z=c[_>>2]|0;T=Y+(aa>>>3)|0;ba=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(aa&7)>>>24;T=aa+8|0;c[V>>2]=Z>>>0>T>>>0?T:Z;Z=n+192|0;a[Z]=ba;ba=c[V>>2]|0;T=c[_>>2]|0;aa=(c[X>>2]|0)+(ba>>>3)|0;fa=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ba&7)>>>24;aa=ba+8|0;c[V>>2]=T>>>0>aa>>>0?aa:T;T=n+193|0;a[T]=fa;fa=c[V>>2]|0;aa=c[_>>2]|0;ba=(c[X>>2]|0)+(fa>>>3)|0;ea=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(fa&7)>>>24;ba=fa+8|0;c[V>>2]=aa>>>0>ba>>>0?ba:aa;aa=ea&255;ea=n+194|0;a[ea]=aa;if((d[Z]|0)>>>0>9>>>0){a[Z]=2}if((d[T]|0)>>>0>15>>>0){a[T]=2}if(!((aa&255)>>>0>10>>>0)){break}a[ea]=2}}while(0);Y=c[V>>2]|0;$=c[X>>2]|0;ea=(d[$+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[V>>2]=((Y|0)<(c[_>>2]|0))+Y;Y=ea&1;c[n+196>>2]=Y;if((Y|0)==0){ga=$}else{c[n+200>>2]=bGa(O)|0;c[n+204>>2]=bGa(O)|0;ga=c[X>>2]|0}$=c[V>>2]|0;Y=(d[ga+($>>>3)|0]|0)<<($&7)>>>7;c[V>>2]=(($|0)<(c[_>>2]|0))+$;c[n+208>>2]=Y&1;Y=c[V>>2]|0;$=(d[ga+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[V>>2]=((Y|0)<(c[_>>2]|0))+Y;c[n+212>>2]=$&1;$=c[V>>2]|0;Y=(d[ga+($>>>3)|0]|0)<<($&7)>>>7;c[V>>2]=(($|0)<(c[_>>2]|0))+$;c[n+216>>2]=Y&1;Y=c[V>>2]|0;$=(d[ga+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[V>>2]=((Y|0)<(c[_>>2]|0))+Y;Y=$&1;c[n+220>>2]=Y;do{if((Y|0)!=0){$=n+224|0;ea=$;c[ea>>2]=(bGa(O)|0)<<1;aa=n+228|0;c[aa>>2]=(bGa(O)|0)<<1;T=n+232|0;c[T>>2]=(bGa(O)|0)<<1;Z=(bGa(O)|0)<<1;c[n+236>>2]=Z;if((c[e+7480>>2]|0)==0){break}ba=c[o>>2]|0;if((c[ba+92>>2]&65536|0)==0){break}fa=c[aa>>2]|0;aa=c[T>>2]|0;KIb(ba,48,2267920,(p=i,i=i+32|0,c[p>>2]=c[ea>>2],c[p+8>>2]=fa,c[p+16>>2]=aa,c[p+24>>2]=Z,p)|0);i=p;mrc($|0,0,16)|0}}while(0);Y=c[V>>2]|0;$=c[X>>2]|0;Z=(d[$+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[V>>2]=((Y|0)<(c[_>>2]|0))+Y;Y=Z&1;c[n+240>>2]=Y;do{if((Y|0)==0){ha=$}else{Z=c[V>>2]|0;aa=c[_>>2]|0;fa=$+(Z>>>3)|0;ea=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Z&7)&-65536;fa=Z+16|0;Z=aa>>>0>fa>>>0?fa:aa;c[V>>2]=Z;fa=$+(Z>>>3)|0;ba=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Z&7)>>>16;fa=Z+16|0;c[V>>2]=aa>>>0>fa>>>0?fa:aa;c[n+244>>2]=ba|ea;ea=c[V>>2]|0;ba=c[_>>2]|0;aa=$+(ea>>>3)|0;fa=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ea&7)&-65536;aa=ea+16|0;ea=ba>>>0>aa>>>0?aa:ba;c[V>>2]=ea;aa=$+(ea>>>3)|0;Z=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ea&7)>>>16;aa=ea+16|0;c[V>>2]=ba>>>0>aa>>>0?aa:ba;c[n+248>>2]=Z|fa;fa=c[V>>2]|0;Z=(d[$+(fa>>>3)|0]|0)<<(fa&7)>>>7;c[V>>2]=((fa|0)<(c[_>>2]|0))+fa;fa=Z&1;c[n+252>>2]=fa;if((fa|0)==0){ia=$}else{c[n+256>>2]=bGa(O)|0;ia=c[X>>2]|0}fa=c[V>>2]|0;Z=(d[ia+(fa>>>3)|0]|0)<<(fa&7)>>>7;c[V>>2]=((fa|0)<(c[_>>2]|0))+fa;fa=Z&1;c[n+260>>2]=fa;if((fa|0)==0){ha=ia;break}eGa(e,1,c[y>>2]|0);ha=c[X>>2]|0}}while(0);X=c[V>>2]|0;$=(d[ha+(X>>>3)|0]|0)<<(X&7)>>>7;c[V>>2]=((X|0)<(c[_>>2]|0))+X;X=$&1;c[n+264>>2]=X;if((X|0)==0){break}X=c[V>>2]|0;$=(d[ha+(X>>>3)|0]|0)<<(X&7)>>>7;c[V>>2]=((X|0)<(c[_>>2]|0))+X;c[n+268>>2]=$&1;$=c[V>>2]|0;X=(d[ha+($>>>3)|0]|0)<<($&7)>>>7;c[V>>2]=(($|0)<(c[_>>2]|0))+$;c[n+272>>2]=X&1;X=c[V>>2]|0;$=(d[ha+(X>>>3)|0]|0)<<(X&7)>>>7;c[V>>2]=((X|0)<(c[_>>2]|0))+X;c[n+276>>2]=$&1;c[n+280>>2]=bGa(O)|0;c[n+284>>2]=bGa(O)|0;c[n+288>>2]=bGa(O)|0;c[n+292>>2]=bGa(O)|0;c[n+296>>2]=bGa(O)|0}}while(0);y=c[s>>2]|0;S=(c[q>>2]|0)+1|0;c[q>>2]=y>>>0>S>>>0?S:y;if((c[e+7480>>2]|0)==0){ja=c[n+20>>2]|0}else{y=n+20|0;S=(c[y>>2]|0)+(c[n+224>>2]|0)|0;c[y>>2]=S;y=n+24|0;c[y>>2]=(c[y>>2]|0)+(c[n+228>>2]|0);y=n+28|0;c[y>>2]=(c[y>>2]|0)+(c[n+232>>2]|0);y=n+32|0;c[y>>2]=(c[y>>2]|0)+(c[n+236>>2]|0);ja=S}S=n+20|0;y=31>>>((c[j>>2]|0)>>>0);do{if((y&ja|0)==0){ka=ja}else{B=c[o>>2]|0;if((c[B+88>>2]&1|0)!=0){ka=ja;break}C=ja&~y;c[S>>2]=C;KIb(B,24,2420448,(p=i,i=i+8|0,c[p>>2]=C,p)|0);i=p;ka=c[S>>2]|0}}while(0);S=c[r>>2]|0;y=S-ka-(c[n+24>>2]|0)|0;j=n+12|0;c[j>>2]=y;C=c[A>>2]|0;B=C-(c[n+28>>2]|0)-(c[n+32>>2]|0)|0;U=n+16|0;c[U>>2]=B;if((y|0)<1|(B|0)<1){KIb(c[o>>2]|0,24,2411184,(p=i,i=i+16|0,c[p>>2]=y,c[p+8>>2]=B,p)|0);i=p;R=c[o>>2]|0;if((c[R+696>>2]&8|0)!=0){x=-1094995529;break}KIb(R,24,2403480,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;mrc(n+36|0,0,16)|0;R=c[r>>2]|0;c[j>>2]=R;j=c[A>>2]|0;c[U>>2]=j;la=R;ma=j;na=R;oa=j}else{la=S;ma=C;na=y;oa=B}B=c[G>>2]|0;y=(c[L>>2]|0)+B|0;c[n+13080>>2]=y;C=B-1|0;c[n+13084>>2]=C;S=1<<y;j=la-1+S>>y;c[n+13104>>2]=j;R=ma-1+S>>y;c[n+13108>>2]=R;c[n+13112>>2]=ca(R,j)|0;c[n+13116>>2]=la>>B;c[n+13120>>2]=ma>>B;j=c[E>>2]|0;c[n+13124>>2]=la>>j;c[n+13128>>2]=ma>>j;c[n+13132>>2]=la>>C;c[n+13136>>2]=ma>>C;c[n+13164>>2]=((c[z>>2]|0)*6|0)-48;C=(1<<B)-1|0;do{if((C&la|0)==0){if((ma&C|0)!=0){break}if(y>>>0>6>>>0){KIb(c[o>>2]|0,16,2389616,(p=i,i=i+8|0,c[p>>2]=y,p)|0);i=p;x=P;break a}B=c[N>>2]|0;R=y-j|0;if(B>>>0>R>>>0){KIb(c[o>>2]|0,16,2382656,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;x=P;break a}B=c[H>>2]|0;if(B>>>0>R>>>0){KIb(c[o>>2]|0,16,2376008,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;x=P;break a}B=c[F>>2]|0;R=c[o>>2]|0;if(B>>>0>(y>>>0>5>>>0?5:y)>>>0){KIb(R,16,2369328,(p=i,i=i+8|0,c[p>>2]=B,p)|0);i=p;x=P;break a}if((c[R+688>>2]&4|0)!=0){B=mKb(c[D>>2]|0)|0;KIb(R,48,2354576,(p=i,i=i+48|0,c[p>>2]=v,c[p+8>>2]=la,c[p+16>>2]=ma,c[p+24>>2]=na,c[p+32>>2]=oa,c[p+40>>2]=B,p)|0);i=p}B=e+252+(v<<2)|0;R=c[B>>2]|0;do{if((R|0)==0){pa=0}else{S=c[g>>2]|0;if((grc(c[R+4>>2]|0,c[S+4>>2]|0,c[S+8>>2]|0)|0)!=0){pa=0;break}fGb(g);m=0;i=f;return m|0}}while(0);do{R=e+380+(pa<<2)|0;O=c[R>>2]|0;do{if((O|0)!=0){if((c[c[O+4>>2]>>2]|0)!=(v|0)){break}fGb(R)}}while(0);pa=pa+1|0;}while(pa>>>0<256>>>0);fGb(B);c[B>>2]=c[g>>2];m=0;i=f;return m|0}}while(0);KIb(c[o>>2]|0,16,2396536,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;x=P}}while(0);fGb(g);m=x;i=f;return m|0}function gGa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;f=i;g=c[b+136>>2]|0;h=g+9272|0;j=g+9280|0;k=h|0;l=g+9288|0;g=0;a:while(1){m=(g|0)==3?2:6;n=(g|0)>0?64:16;o=(g|0)>1;p=g-2|0;q=1<<(g<<1)+4;r=(q|0)<64?q:64;q=(r|0)>0;s=(g|0)==0;t=0;do{u=c[j>>2]|0;v=c[k>>2]|0;w=d[v+(u>>>3)|0]|0;x=c[l>>2]|0;y=((u|0)<(x|0))+u|0;c[j>>2]=y;do{if((w&128>>>((u&7)>>>0)|0)==0){z=bGa(h)|0;if((z|0)==0){break}if(t>>>0<z>>>0){break a}A=t-z|0;nrc(e+(g*384|0)+(t<<6)|0,e+(g*384|0)+(A<<6)|0,n)|0;if(!o){break}a[e+1536+(p*6|0)+t|0]=a[e+1536+(p*6|0)+A|0]|0}else{if(o){A=v+(y>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7);if(B>>>0>134217727>>>0){A=B>>>23;C=(d[1382088+A|0]|0)+y|0;c[j>>2]=x>>>0>C>>>0?C:x;D=a[1306768+A|0]|0}else{A=B>>>0>65535>>>0;C=A?B>>>16:B;B=A?16:0;if((C&65280|0)==0){E=B;F=C}else{E=B|8;F=C>>>8}C=(d[1359664+F|0]|0)+E|0;B=31-C+y|0;A=x>>>0>B>>>0?B:x;B=v+(A>>>3)|0;G=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>(C>>>0);B=A+(32-C)|0;c[j>>2]=x>>>0>B>>>0?B:x;B=G>>>1;D=(G&1|0)==0?B:-B|0}B=D+8|0;a[e+1536+(p*6|0)+t|0]=B;H=B}else{H=8}if(q){I=0;J=H}else{break}do{if(s){K=(d[1375456+I|0]<<2)+(d[1375472+I|0]|0)|0}else{K=(d[1375328+I|0]<<3)+(d[1375392+I|0]|0)|0}B=c[j>>2]|0;G=c[l>>2]|0;C=c[k>>2]|0;A=C+(B>>>3)|0;L=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(B&7);if(L>>>0>134217727>>>0){A=L>>>23;M=(d[1382088+A|0]|0)+B|0;c[j>>2]=G>>>0>M>>>0?M:G;N=a[1306768+A|0]|0}else{A=L>>>0>65535>>>0;M=A?L>>>16:L;L=A?16:0;if((M&65280|0)==0){O=L;P=M}else{O=L|8;P=M>>>8}M=(d[1359664+P|0]|0)+O|0;L=31-M+B|0;B=G>>>0>L>>>0?L:G;L=C+(B>>>3)|0;C=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(B&7)>>>(M>>>0);L=B+(32-M)|0;c[j>>2]=G>>>0>L>>>0?L:G;G=C>>>1;N=(C&1|0)==0?G:-G|0}J=(J+256+N|0)%256|0;a[e+(g*384|0)+(t<<6)+K|0]=J;I=I+1|0;}while((I|0)<(r|0))}}while(0);t=t+1|0;}while((t|0)<(m|0));m=g+1|0;if((m|0)<4){g=m}else{Q=0;R=28;break}}if((R|0)==28){i=f;return Q|0}KIb(c[b+4>>2]|0,16,2264192,(b=i,i=i+8|0,c[b>>2]=z,b)|0);i=b;Q=-1094995529;i=f;return Q|0}function hGa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=c[b+136>>2]|0;j=h+9272|0;k=pJb(1676)|0;c[g>>2]=k;if((k|0)==0){l=-12;i=e;return l|0}m=aGb(k,1676,144,0,0)|0;c[f>>2]=m;if((m|0)==0){mJb(g);l=-12;i=e;return l|0}m=b+4|0;KIb(c[m>>2]|0,48,2345704,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;a[(c[g>>2]|0)+53|0]=1;n=c[g>>2]|0;c[n+44>>2]=1;c[n+48>>2]=1;a[n+52|0]=1;a[(c[g>>2]|0)+57|0]=0;n=c[g>>2]|0;c[n+60>>2]=0;c[n+64>>2]=0;n=bGa(j)|0;a:do{if(n>>>0>255>>>0){KIb(c[m>>2]|0,16,2339648,(k=i,i=i+8|0,c[k>>2]=n,k)|0);i=k;o=-1094995529}else{p=bGa(j)|0;q=c[g>>2]|0;c[q>>2]=p;if(p>>>0>31>>>0){KIb(c[m>>2]|0,16,2589744,(k=i,i=i+8|0,c[k>>2]=p,k)|0);i=k;o=-1094995529;break}r=c[b+252+(p<<2)>>2]|0;if((r|0)==0){KIb(c[m>>2]|0,16,2333960,(k=i,i=i+8|0,c[k>>2]=p,k)|0);i=k;o=-1094995529;break}p=c[r+4>>2]|0;r=h+9280|0;s=c[r>>2]|0;t=j|0;u=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;v=h+9288|0;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[q+41|0]=u&1;u=c[r>>2]|0;q=d[(c[t>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[r>>2]=((u|0)<(c[v>>2]|0))+u;a[(c[g>>2]|0)+39|0]=q&1;q=c[r>>2]|0;u=c[v>>2]|0;s=c[t>>2]|0;w=s+(q>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(q&7)>>>29;w=q+3|0;c[r>>2]=u>>>0>w>>>0?w:u;u=c[g>>2]|0;c[u+1624>>2]=x;x=c[r>>2]|0;w=d[s+(x>>>3)|0]<<(x&7)>>>7;c[r>>2]=((x|0)<(c[v>>2]|0))+x;a[u+4|0]=w&1;w=c[r>>2]|0;u=d[(c[t>>2]|0)+(w>>>3)|0]<<(w&7)>>>7;c[r>>2]=((w|0)<(c[v>>2]|0))+w;a[(c[g>>2]|0)+5|0]=u&1;u=(bGa(j)|0)+1|0;c[(c[g>>2]|0)+8>>2]=u;u=(bGa(j)|0)+1|0;w=c[g>>2]|0;c[w+12>>2]=u;u=c[r>>2]|0;x=c[v>>2]|0;s=c[t>>2]|0;q=s+(u>>>3)|0;y=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(u&7);if(y>>>0>134217727>>>0){q=y>>>23;z=(d[1382088+q|0]|0)+u|0;c[r>>2]=x>>>0>z>>>0?z:x;A=a[1306768+q|0]|0}else{q=y>>>0>65535>>>0;z=q?y>>>16:y;y=q?16:0;if((z&65280|0)==0){B=y;C=z}else{B=y|8;C=z>>>8}z=(d[1359664+C|0]|0)+B|0;y=31-z+u|0;u=x>>>0>y>>>0?y:x;y=s+(u>>>3)|0;q=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(u&7)>>>(z>>>0);y=u+(32-z)|0;c[r>>2]=x>>>0>y>>>0?y:x;x=q>>>1;A=(q&1|0)==0?x:-x|0}c[w+16>>2]=A;x=c[r>>2]|0;q=d[s+(x>>>3)|0]<<(x&7)>>>7;c[r>>2]=((x|0)<(c[v>>2]|0))+x;a[w+20|0]=q&1;q=c[r>>2]|0;w=d[(c[t>>2]|0)+(q>>>3)|0]<<(q&7)>>>7;c[r>>2]=((q|0)<(c[v>>2]|0))+q;a[(c[g>>2]|0)+21|0]=w&1;w=c[r>>2]|0;q=d[(c[t>>2]|0)+(w>>>3)|0]<<(w&7)>>>7;c[r>>2]=((w|0)<(c[v>>2]|0))+w;a[(c[g>>2]|0)+22|0]=q&1;q=c[g>>2]|0;c[q+24>>2]=0;if((a[q+22|0]|0)==0){D=q}else{q=bGa(j)|0;w=c[g>>2]|0;c[w+24>>2]=q;D=w}w=c[r>>2]|0;q=c[v>>2]|0;x=c[t>>2]|0;s=x+(w>>>3)|0;y=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7);if(y>>>0>134217727>>>0){s=y>>>23;z=(d[1382088+s|0]|0)+w|0;c[r>>2]=q>>>0>z>>>0?z:q;E=a[1306768+s|0]|0}else{s=y>>>0>65535>>>0;z=s?y>>>16:y;y=s?16:0;if((z&65280|0)==0){F=y;H=z}else{F=y|8;H=z>>>8}z=(d[1359664+H|0]|0)+F|0;y=31-z+w|0;w=q>>>0>y>>>0?y:q;y=x+(w>>>3)|0;s=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>(z>>>0);y=w+(32-z)|0;c[r>>2]=q>>>0>y>>>0?y:q;q=s>>>1;E=(s&1|0)==0?q:-q|0}c[D+28>>2]=E;if((E+12|0)>>>0>24>>>0){KIb(c[m>>2]|0,16,2328656,(k=i,i=i+8|0,c[k>>2]=E,k)|0);i=k;o=-1094995529;break}q=c[r>>2]|0;s=c[v>>2]|0;y=x+(q>>>3)|0;z=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7);if(z>>>0>134217727>>>0){y=z>>>23;w=(d[1382088+y|0]|0)+q|0;c[r>>2]=s>>>0>w>>>0?w:s;I=a[1306768+y|0]|0}else{y=z>>>0>65535>>>0;w=y?z>>>16:z;z=y?16:0;if((w&65280|0)==0){J=z;K=w}else{J=z|8;K=w>>>8}w=(d[1359664+K|0]|0)+J|0;z=31-w+q|0;q=s>>>0>z>>>0?z:s;z=x+(q>>>3)|0;y=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(q&7)>>>(w>>>0);z=q+(32-w)|0;c[r>>2]=s>>>0>z>>>0?z:s;s=y>>>1;I=(y&1|0)==0?s:-s|0}c[D+32>>2]=I;if((I+12|0)>>>0>24>>>0){KIb(c[m>>2]|0,16,2322776,(k=i,i=i+8|0,c[k>>2]=I,k)|0);i=k;o=-1094995529;break}s=c[r>>2]|0;y=d[x+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[D+36|0]=y&1;y=c[r>>2]|0;s=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[(c[g>>2]|0)+37|0]=s&1;s=c[r>>2]|0;y=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[(c[g>>2]|0)+38|0]=y&1;y=c[r>>2]|0;s=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[(c[g>>2]|0)+40|0]=s&1;s=c[r>>2]|0;y=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[(c[g>>2]|0)+42|0]=y&1;y=c[r>>2]|0;s=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[(c[g>>2]|0)+43|0]=s&1;s=c[g>>2]|0;b:do{if((a[s+42|0]|0)==0){L=s}else{y=(bGa(j)|0)+1|0;c[(c[g>>2]|0)+44>>2]=y;y=bGa(j)|0;x=y+1|0;z=c[g>>2]|0;c[z+48>>2]=x;w=c[z+44>>2]|0;do{if((w|0)!=0){if((w|0)>=(c[p+13096>>2]|0)){break}do{if((x|0)!=0){if((x|0)>=(c[p+13100>>2]|0)){break}if(w>>>0>536870910>>>0){M=0;N=z}else{q=hJb(w<<2)|0;M=q;N=c[g>>2]|0}c[N+1632>>2]=M;q=c[g>>2]|0;u=c[q+48>>2]|0;if(u>>>0>536870910>>>0){O=0;P=q}else{q=hJb(u<<2)|0;O=q;P=c[g>>2]|0}c[P+1636>>2]=O;q=c[g>>2]|0;if((c[q+1632>>2]|0)==0){o=-12;break a}if((c[q+1636>>2]|0)==0){o=-12;break a}u=c[r>>2]|0;Q=d[(c[t>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[r>>2]=((u|0)<(c[v>>2]|0))+u;a[q+52|0]=Q&1;Q=c[g>>2]|0;do{if((a[Q+52|0]|0)==0){q=(c[Q+44>>2]|0)-1|0;if((q|0)>0){u=0;R=0;S=0;while(1){T=(bGa(j)|0)+1|0;U=c[g>>2]|0;c[(c[U+1632>>2]|0)+(S<<2)>>2]=T;V=wrc(T,0,R,u)|0;T=G;W=S+1|0;X=(c[U+44>>2]|0)-1|0;if((W|0)<(X|0)){u=T;R=V;S=W}else{Y=T;Z=V;_=X;$=U;break}}}else{Y=0;Z=0;_=q;$=Q}S=c[p+13104>>2]|0;R=S;u=(S|0)<0|0?-1:0;if(!(Y>>>0<u>>>0|Y>>>0==u>>>0&Z>>>0<R>>>0)){KIb(c[m>>2]|0,16,2308408,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;o=-1094995529;break a}S=xrc(R,u,Z,Y)|0;c[(c[$+1632>>2]|0)+(_<<2)>>2]=S;S=(c[$+48>>2]|0)-1|0;if((S|0)>0){u=0;R=0;U=0;while(1){X=(bGa(j)|0)+1|0;V=c[g>>2]|0;c[(c[V+1636>>2]|0)+(U<<2)>>2]=X;T=wrc(X,0,R,u)|0;X=G;W=U+1|0;aa=(c[V+48>>2]|0)-1|0;if((W|0)<(aa|0)){u=X;R=T;U=W}else{ba=X;da=T;ea=aa;fa=V;break}}}else{ba=0;da=0;ea=S;fa=$}U=c[p+13108>>2]|0;R=U;u=(U|0)<0|0?-1:0;if(ba>>>0<u>>>0|ba>>>0==u>>>0&da>>>0<R>>>0){U=xrc(R,u,da,ba)|0;c[(c[fa+1636>>2]|0)+(ea<<2)>>2]=U;ga=fa;break}else{KIb(c[m>>2]|0,16,2303360,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;o=-1094995529;break a}}else{ga=Q}}while(0);Q=c[r>>2]|0;U=d[(c[t>>2]|0)+(Q>>>3)|0]<<(Q&7)>>>7;c[r>>2]=((Q|0)<(c[v>>2]|0))+Q;a[ga+53|0]=U&1;L=c[g>>2]|0;break b}}while(0);KIb(c[m>>2]|0,16,2313048,(k=i,i=i+8|0,c[k>>2]=y,k)|0);i=k;o=-1094995529;break a}}while(0);KIb(c[m>>2]|0,16,2317744,(k=i,i=i+8|0,c[k>>2]=w-1,k)|0);i=k;o=-1094995529;break a}}while(0);s=c[r>>2]|0;y=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[L+54|0]=y&1;y=c[r>>2]|0;s=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[(c[g>>2]|0)+55|0]=s&1;s=c[g>>2]|0;do{if((a[s+55|0]|0)==0){ha=s}else{y=c[r>>2]|0;z=d[(c[t>>2]|0)+(y>>>3)|0]<<(y&7)>>>7;c[r>>2]=((y|0)<(c[v>>2]|0))+y;a[s+56|0]=z&1;z=c[r>>2]|0;y=d[(c[t>>2]|0)+(z>>>3)|0]<<(z&7)>>>7;c[r>>2]=((z|0)<(c[v>>2]|0))+z;a[(c[g>>2]|0)+57|0]=y&1;y=c[g>>2]|0;if((a[y+57|0]|0)!=0){ha=y;break}z=c[r>>2]|0;x=c[v>>2]|0;U=c[t>>2]|0;Q=U+(z>>>3)|0;u=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(z&7);if(u>>>0>134217727>>>0){Q=u>>>23;R=(d[1382088+Q|0]|0)+z|0;c[r>>2]=x>>>0>R>>>0?R:x;ia=a[1306768+Q|0]|0}else{Q=u>>>0>65535>>>0;R=Q?u>>>16:u;u=Q?16:0;if((R&65280|0)==0){ja=u;ka=R}else{ja=u|8;ka=R>>>8}R=(d[1359664+ka|0]|0)+ja|0;u=31-R+z|0;z=x>>>0>u>>>0?u:x;u=U+(z>>>3)|0;Q=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(z&7)>>>(R>>>0);u=z+(32-R)|0;c[r>>2]=x>>>0>u>>>0?u:x;x=Q>>>1;ia=(Q&1|0)==0?x:-x|0}x=y+60|0;c[x>>2]=ia<<1;Q=c[r>>2]|0;u=c[v>>2]|0;R=U+(Q>>>3)|0;z=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Q&7);if(z>>>0>134217727>>>0){R=z>>>23;q=(d[1382088+R|0]|0)+Q|0;c[r>>2]=u>>>0>q>>>0?q:u;la=a[1306768+R|0]|0}else{R=z>>>0>65535>>>0;q=R?z>>>16:z;z=R?16:0;if((q&65280|0)==0){ma=z;na=q}else{ma=z|8;na=q>>>8}q=(d[1359664+na|0]|0)+ma|0;z=31-q+Q|0;Q=u>>>0>z>>>0?z:u;z=U+(Q>>>3)|0;U=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(Q&7)>>>(q>>>0);z=Q+(32-q)|0;c[r>>2]=u>>>0>z>>>0?z:u;u=U>>>1;la=(U&1|0)==0?u:-u|0}u=la<<1;c[y+64>>2]=u;U=c[x>>2]|0;if((U+13|0)>>>0>26>>>0){KIb(c[m>>2]|0,16,2292360,(k=i,i=i+8|0,c[k>>2]=(U|0)/2|0,k)|0);i=k;o=-1094995529;break a}if(!((u+13|0)>>>0>26>>>0)){ha=y;break}KIb(c[m>>2]|0,16,2285344,(k=i,i=i+8|0,c[k>>2]=(u|0)/2|0,k)|0);i=k;o=-1094995529;break a}}while(0);s=c[r>>2]|0;u=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[ha+68|0]=u&1;u=c[g>>2]|0;if((a[u+68|0]|0)==0){oa=u}else{mrc(u+69|0,16,16)|0;mrc(u+133|0,16,16)|0;mrc(u+197|0,16,16)|0;mrc(u+261|0,16,16)|0;mrc(u+325|0,16,16)|0;mrc(u+389|0,16,16)|0;mrc(u+1605|0,16,12)|0;nrc(u+453|0,1575952,64)|0;nrc(u+517|0,1575952,64)|0;nrc(u+581|0,1575952,64)|0;nrc(u+645|0,1576016,64)|0;nrc(u+709|0,1576016,64)|0;nrc(u+773|0,1576016,64)|0;nrc(u+837|0,1575952,64)|0;nrc(u+901|0,1575952,64)|0;nrc(u+965|0,1575952,64)|0;nrc(u+1029|0,1576016,64)|0;nrc(u+1093|0,1576016,64)|0;nrc(u+1157|0,1576016,64)|0;nrc(u+1221|0,1575952,64)|0;nrc(u+1285|0,1576016,64)|0;s=gGa(b,u+69|0)|0;if((s|0)<0){o=s;break}oa=c[g>>2]|0}s=c[r>>2]|0;u=d[(c[t>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[v>>2]|0))+s;a[oa+1617|0]=u&1;u=bGa(j)|0;s=u+2|0;y=c[g>>2]|0;c[y+1620>>2]=s;U=p+13080|0;if(s>>>0>(c[U>>2]|0)>>>0){KIb(c[m>>2]|0,16,2281312,(k=i,i=i+8|0,c[k>>2]=u,k)|0);i=k;o=-1094995529;break}u=c[r>>2]|0;s=d[(c[t>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[r>>2]=((u|0)<(c[v>>2]|0))+u;a[y+1628|0]=s&1;s=c[v>>2]|0;y=(c[r>>2]|0)+1|0;c[r>>2]=s>>>0>y>>>0?y:s;s=c[g>>2]|0;y=(c[s+44>>2]|0)+1|0;if(y>>>0>536870910>>>0){pa=0;qa=s}else{s=hJb(y<<2)|0;pa=s;qa=c[g>>2]|0}c[qa+1640>>2]=pa;s=c[g>>2]|0;y=(c[s+48>>2]|0)+1|0;if(y>>>0>536870910>>>0){ra=0;sa=s}else{s=hJb(y<<2)|0;ra=s;sa=c[g>>2]|0}c[sa+1644>>2]=ra;s=p+13104|0;y=c[s>>2]|0;if(y>>>0>536870910>>>0){ta=0}else{ta=hJb(y<<2)|0}c[(c[g>>2]|0)+1648>>2]=ta;y=c[g>>2]|0;u=c[y+1640>>2]|0;if((u|0)==0){o=-12;break}if((c[y+1644>>2]|0)==0){o=-12;break}if((c[y+1648>>2]|0)==0){o=-12;break}if((a[y+52|0]|0)==0){ua=y;va=u}else{u=c[y+1632>>2]|0;if((u|0)==0){x=c[y+44>>2]|0;if(x>>>0>536870910>>>0){wa=0;xa=y}else{z=hJb(x<<2)|0;wa=z;xa=c[g>>2]|0}c[xa+1632>>2]=wa;z=c[g>>2]|0;x=c[z+48>>2]|0;if(x>>>0>536870910>>>0){ya=0;za=z}else{z=hJb(x<<2)|0;ya=z;za=c[g>>2]|0}c[za+1636>>2]=ya;z=c[g>>2]|0;x=c[z+1632>>2]|0;if((x|0)==0){o=-12;break}else{Aa=x;Ba=z}}else{Aa=u;Ba=y}y=c[Ba+1636>>2]|0;if((y|0)==0){o=-12;break}u=Ba+44|0;z=c[u>>2]|0;if((z|0)>0){x=0;q=z;while(1){z=x+1|0;Q=c[s>>2]|0;c[Aa+(x<<2)>>2]=((ca(Q,z)|0)/(q|0)|0)-((ca(Q,x)|0)/(q|0)|0);Q=c[u>>2]|0;if((z|0)<(Q|0)){x=z;q=Q}else{break}}}q=Ba+48|0;x=c[q>>2]|0;if((x|0)>0){u=p+13108|0;r=0;v=x;while(1){x=r+1|0;t=c[u>>2]|0;c[y+(r<<2)>>2]=((ca(t,x)|0)/(v|0)|0)-((ca(t,r)|0)/(v|0)|0);t=c[q>>2]|0;if((x|0)<(t|0)){r=x;v=t}else{break}}}ua=Ba;va=c[Ba+1640>>2]|0}c[va>>2]=0;v=ua+44|0;if((c[v>>2]|0)>0){r=c[ua+1632>>2]|0;q=0;y=0;do{y=(c[r+(q<<2)>>2]|0)+y|0;q=q+1|0;c[va+(q<<2)>>2]=y;}while((q|0)<(c[v>>2]|0))}v=c[ua+1644>>2]|0;c[v>>2]=0;q=ua+48|0;if((c[q>>2]|0)>0){y=c[ua+1636>>2]|0;r=0;u=0;do{u=(c[y+(r<<2)>>2]|0)+u|0;r=r+1|0;c[v+(r<<2)>>2]=u;}while((r|0)<(c[q>>2]|0))}q=c[s>>2]|0;if((q|0)>0){r=c[ua+1648>>2]|0;u=0;v=0;while(1){y=(v>>>0>(c[va+(u<<2)>>2]|0)>>>0)+u|0;c[r+(v<<2)>>2]=y;t=v+1|0;x=c[s>>2]|0;if((t|0)<(x|0)){u=y;v=t}else{Ca=x;break}}}else{Ca=q}v=ca(c[p+13108>>2]|0,Ca)|0;u=p+13116|0;r=p+13120|0;x=ca(c[r>>2]|0,c[u>>2]|0)|0;t=p+13124|0;y=p+13128|0;Q=ca(c[y>>2]|0,c[t>>2]|0)|0;if(v>>>0>536870910>>>0){c[ua+1652>>2]=0;c[(c[g>>2]|0)+1656>>2]=0;Da=0}else{z=v<<2;R=hJb(z)|0;c[(c[g>>2]|0)+1652>>2]=R;R=hJb(z)|0;c[(c[g>>2]|0)+1656>>2]=R;Da=hJb(z)|0}c[(c[g>>2]|0)+1660>>2]=Da;if(x>>>0>536870910>>>0){Ea=0}else{Ea=hJb(x<<2)|0}c[(c[g>>2]|0)+1668>>2]=Ea;if(Q>>>0>536870910>>>0){Fa=0}else{Fa=hJb(Q<<2)|0}c[(c[g>>2]|0)+1672>>2]=Fa;Q=c[g>>2]|0;x=c[Q+1652>>2]|0;if((x|0)==0){o=-12;break}z=c[Q+1656>>2]|0;if((z|0)==0){o=-12;break}R=c[Q+1660>>2]|0;if((R|0)==0){o=-12;break}if((c[Q+1668>>2]|0)==0){o=-12;break}if((c[Q+1672>>2]|0)==0){o=-12;break}if((v|0)>0){V=Q+44|0;aa=Q+48|0;T=c[Q+1644>>2]|0;X=c[Q+1632>>2]|0;W=c[Q+1640>>2]|0;Ga=Q+1636|0;Ha=0;while(1){Ia=c[s>>2]|0;Ja=(Ha|0)%(Ia|0)|0;Ka=(Ha|0)/(Ia|0)|0;La=c[V>>2]|0;Ma=0;while(1){if((Ma|0)>=(La|0)){Na=0;break}Oa=Ma+1|0;if(Ja>>>0<(c[W+(Oa<<2)>>2]|0)>>>0){Na=Ma;break}else{Ma=Oa}}Ma=c[aa>>2]|0;La=0;while(1){if((La|0)>=(Ma|0)){Pa=0;break}w=La+1|0;if(Ka>>>0<(c[T+(w<<2)>>2]|0)>>>0){Pa=La;break}else{La=w}}if((Na|0)>0){La=c[(c[Ga>>2]|0)+(Pa<<2)>>2]|0;Ma=0;w=0;while(1){Oa=(ca(c[X+(w<<2)>>2]|0,La)|0)+Ma|0;Qa=w+1|0;if((Qa|0)<(Na|0)){Ma=Oa;w=Qa}else{Ra=Oa;break}}}else{Ra=0}if((Pa|0)>0){w=c[Ga>>2]|0;Ma=Ra;La=0;while(1){Oa=(ca(c[w+(La<<2)>>2]|0,Ia)|0)+Ma|0;Qa=La+1|0;if((Qa|0)<(Pa|0)){Ma=Oa;La=Qa}else{Sa=Oa;break}}}else{Sa=Ra}La=ca(c[X+(Na<<2)>>2]|0,Ka-(c[T+(Pa<<2)>>2]|0)|0)|0;Ma=Sa+Ja+La-(c[W+(Na<<2)>>2]|0)|0;c[x+(Ha<<2)>>2]=Ma;c[z+(Ma<<2)>>2]=Ha;Ma=Ha+1|0;if((Ma|0)<(v|0)){Ha=Ma}else{Ta=aa;break}}}else{Ta=Q+48|0}aa=c[Ta>>2]|0;if((aa|0)>0){Ha=Q+44|0;v=Q+1644|0;z=Q+1640|0;W=0;T=0;X=c[Ha>>2]|0;Ga=aa;while(1){aa=T+1|0;if((X|0)>0){V=c[v>>2]|0;q=V+(aa<<2)|0;Ma=W;La=0;Ia=X;w=c[q>>2]|0;while(1){Oa=c[V+(T<<2)>>2]|0;Qa=La+1|0;if(Oa>>>0<w>>>0){Ua=c[z>>2]|0;Va=Ua+(Qa<<2)|0;Wa=Oa;Oa=w;Xa=c[Va>>2]|0;while(1){Ya=c[Ua+(La<<2)>>2]|0;if(Ya>>>0<Xa>>>0){Za=Ya;do{c[R+(c[x+((ca(c[s>>2]|0,Wa)|0)+Za<<2)>>2]<<2)>>2]=Ma;Za=Za+1|0;_a=c[Va>>2]|0;}while(Za>>>0<_a>>>0);$a=c[q>>2]|0;ab=_a}else{$a=Oa;ab=Xa}Za=Wa+1|0;if(Za>>>0<$a>>>0){Wa=Za;Oa=$a;Xa=ab}else{break}}bb=c[Ha>>2]|0;cb=$a}else{bb=Ia;cb=w}db=Ma+1|0;if((Qa|0)<(bb|0)){Ma=db;La=Qa;Ia=bb;w=cb}else{break}}eb=db;fb=bb;gb=c[Ta>>2]|0}else{eb=W;fb=X;gb=Ga}if((aa|0)<(gb|0)){W=eb;T=aa;X=fb;Ga=gb}else{break}}if(eb>>>0>536870910>>>0){hb=0;ib=Q}else{jb=eb;kb=151}}else{jb=0;kb=151}if((kb|0)==151){Ga=hJb(jb<<2)|0;hb=Ga;ib=c[g>>2]|0}c[ib+1664>>2]=hb;Ga=c[g>>2]|0;X=c[Ga+1664>>2]|0;if((X|0)==0){o=-12;break}T=Ga+48|0;W=c[T>>2]|0;if((W|0)>0){Ha=Ga+44|0;x=0;R=c[Ha>>2]|0;z=W;while(1){if((R|0)>0){W=c[Ga+1644>>2]|0;v=c[Ga+1640>>2]|0;w=0;Ia=R;do{La=ca(c[s>>2]|0,c[W+(x<<2)>>2]|0)|0;c[X+((ca(Ia,x)|0)+w<<2)>>2]=(c[v+(w<<2)>>2]|0)+La;w=w+1|0;Ia=c[Ha>>2]|0;}while((w|0)<(Ia|0));lb=Ia;mb=c[T>>2]|0}else{lb=R;mb=z}w=x+1|0;if((w|0)<(mb|0)){x=w;R=lb;z=mb}else{break}}}z=c[r>>2]|0;if((z|0)>0){R=p+13068|0;x=Ga+1652|0;T=Ga+1668|0;Ha=0;X=c[u>>2]|0;Q=z;while(1){if((X|0)>0){z=c[x>>2]|0;w=c[T>>2]|0;v=0;W=X;do{aa=c[R>>2]|0;La=c[z+((ca(c[s>>2]|0,Ha>>aa)|0)+(v>>aa)<<2)>>2]<<(aa<<1);if((aa|0)==0){nb=La}else{Ma=La;La=0;while(1){q=1<<La;if((q&Ha|0)==0){ob=0}else{ob=q<<1<<La}V=((q&v|0)==0?0:q<<La)+Ma+ob|0;q=La+1|0;if(q>>>0<aa>>>0){Ma=V;La=q}else{nb=V;break}}}c[w+((ca(W,Ha)|0)+v<<2)>>2]=nb;v=v+1|0;W=c[u>>2]|0;}while((v|0)<(W|0));pb=W;qb=c[r>>2]|0}else{pb=X;qb=Q}v=Ha+1|0;if((v|0)<(qb|0)){Ha=v;X=pb;Q=qb}else{break}}}Q=(c[U>>2]|0)-(c[p+13072>>2]|0)|0;X=c[y>>2]|0;if((X|0)>0){Ha=Ga+1652|0;r=Q<<1;u=(Q|0)>0;R=Ga+1672|0;T=0;x=c[t>>2]|0;v=X;while(1){if((x|0)>0){X=T>>Q;w=c[Ha>>2]|0;z=c[R>>2]|0;if(u){Ia=0;La=x;while(1){Ma=0;aa=c[w+((ca(c[s>>2]|0,X)|0)+(Ia>>Q)<<2)>>2]<<r;do{Qa=1<<Ma;if((Qa&T|0)==0){rb=0}else{rb=Qa<<1<<Ma}aa=((Qa&Ia|0)==0?0:Qa<<Ma)+aa+rb|0;Ma=Ma+1|0;}while((Ma|0)<(Q|0));c[z+((ca(La,T)|0)+Ia<<2)>>2]=aa;Ma=Ia+1|0;Qa=c[t>>2]|0;if((Ma|0)<(Qa|0)){Ia=Ma;La=Qa}else{sb=Qa;break}}}else{La=0;Ia=x;while(1){c[z+((ca(Ia,T)|0)+La<<2)>>2]=c[w+((ca(c[s>>2]|0,X)|0)+(La>>Q)<<2)>>2]<<r;W=La+1|0;Qa=c[t>>2]|0;if((W|0)<(Qa|0)){La=W;Ia=Qa}else{sb=Qa;break}}}tb=sb;ub=c[y>>2]|0}else{tb=x;ub=v}Ia=T+1|0;if((Ia|0)<(ub|0)){T=Ia;x=tb;v=ub}else{break}}}v=b+380+(n<<2)|0;fGb(v);c[v>>2]=c[f>>2];l=0;i=e;return l|0}}while(0);fGb(f);l=o;i=e;return l|0}function iGa(a,b){a=a|0;b=b|0;var d=0;a=i;i=i+8|0;d=a|0;c[d>>2]=b;mJb(b+1632|0);mJb(b+1636|0);mJb(b+1640|0);mJb(b+1644|0);mJb(b+1648|0);mJb(b+1652|0);mJb(b+1656|0);mJb(b+1664|0);mJb(b+1660|0);mJb(b+1668|0);mJb(b+1672|0);mJb(d);i=a;return}function jGa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+9272|0;if((b|0)==0){return}f=a+9280|0;g=a+9288|0;if((d|0)==0){d=0;do{bGa(e)|0;bGa(e)|0;a=c[g>>2]|0;h=(c[f>>2]|0)+1|0;c[f>>2]=a>>>0>h>>>0?h:a;d=d+1|0;}while(d>>>0<b>>>0);return}else{d=0;do{bGa(e)|0;bGa(e)|0;bGa(e)|0;bGa(e)|0;a=c[g>>2]|0;h=(c[f>>2]|0)+1|0;c[f>>2]=a>>>0>h>>>0?h:a;d=d+1|0;}while(d>>>0<b>>>0);return}}function kGa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=c[b+136>>2]|0;h=g+9280|0;j=c[h>>2]|0;k=g+9288|0;l=c[k>>2]|0;m=g+9272|0;g=(c[m>>2]|0)+(j>>>3)|0;n=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(j&7)>>>30;g=j+2|0;c[h>>2]=l>>>0>g>>>0?g:l;a[e|0]=n;n=c[h>>2]|0;l=(d[(c[m>>2]|0)+(n>>>3)|0]|0)<<(n&7)>>>7;c[h>>2]=((n|0)<(c[k>>2]|0))+n;a[e+1|0]=l&1;l=c[h>>2]|0;n=c[k>>2]|0;g=(c[m>>2]|0)+(l>>>3)|0;j=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(l&7)>>>27;g=l+5|0;c[h>>2]=n>>>0>g>>>0?g:n;a[e+2|0]=j;do{if((j|0)==2){KIb(c[b+4>>2]|0,48,2255960,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=0}else if((j|0)==1){KIb(c[b+4>>2]|0,48,2260392,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=0}else{n=c[b+4>>2]|0;if((j|0)==3){KIb(n,48,2251768,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=0;break}else{KIb(n,24,2241440,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;p=0;break}}}while(0);while(1){o=c[h>>2]|0;j=(d[(c[m>>2]|0)+(o>>>3)|0]|0)<<(o&7)>>>7;c[h>>2]=((o|0)<(c[k>>2]|0))+o;q=j&1;if((p|0)>=32){break}a[e+3+p|0]=q;p=p+1|0}a[e+36|0]=q;q=c[h>>2]|0;p=(d[(c[m>>2]|0)+(q>>>3)|0]|0)<<(q&7)>>>7;c[h>>2]=((q|0)<(c[k>>2]|0))+q;a[e+37|0]=p&1;p=c[h>>2]|0;q=(d[(c[m>>2]|0)+(p>>>3)|0]|0)<<(p&7)>>>7;c[h>>2]=((p|0)<(c[k>>2]|0))+p;a[e+38|0]=q&1;q=c[h>>2]|0;p=(d[(c[m>>2]|0)+(q>>>3)|0]|0)<<(q&7)>>>7;c[h>>2]=((q|0)<(c[k>>2]|0))+q;a[e+39|0]=p&1;p=c[k>>2]|0;k=(c[h>>2]|0)+16|0;e=(p>>>0>k>>>0?k:p)+16|0;k=(p>>>0>e>>>0?e:p)+12|0;c[h>>2]=p>>>0>k>>>0?k:p;i=f;return}function lGa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0;g=c[e>>2]|0;if((g|0)==0){return}if((c[g+360>>2]|0)==0){return}g=e+70|0;h=(d[g]|0)&(f^255)&255;a[g]=h;if(!(h<<24>>24==0)){return}H5a(c[b+4>>2]|0,e+4|0);fGb(e+56|0);c[e+16>>2]=0;fGb(e+64|0);fGb(e+60|0);c[e+24>>2]=0;c[e+20>>2]=0;c[e+36>>2]=0;return}function mGa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;if((e|d|0)<0){f=c[(c[a+3480>>2]|0)+20>>2]|0;return f|0}else{g=c[a+180>>2]|0;h=c[g+13080>>2]|0;i=(ca((1<<h)-1+(c[g+13096>>2]|0)>>h,e>>h)|0)+(d>>h)|0;f=c[(c[b+24>>2]|0)+(c[(c[(c[a+184>>2]|0)+1652>>2]|0)+(i<<2)>>2]<<2)>>2]|0;return f|0}return 0}function nGa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+4|0;e=0;do{f=c[b+3484+(e*72|0)>>2]|0;do{if((f|0)!=0){if((c[f+360>>2]|0)==0){break}g=b+3484+(e*72|0)+70|0;h=a[g]&-7;a[g]=h;if(!(h<<24>>24==0)){break}H5a(c[d>>2]|0,b+3484+(e*72|0)+4|0);fGb(b+3484+(e*72|0)+56|0);c[b+3484+(e*72|0)+16>>2]=0;fGb(b+3484+(e*72|0)+64|0);fGb(b+3484+(e*72|0)+60|0);c[b+3484+(e*72|0)+24>>2]=0;c[b+3484+(e*72|0)+20>>2]=0;c[b+3484+(e*72|0)+36>>2]=0}}while(0);e=e+1|0;}while(e>>>0<32>>>0);return}function oGa(b){b=b|0;var d=0,e=0,f=0;d=b+4|0;e=0;do{f=c[b+3484+(e*72|0)>>2]|0;do{if((f|0)!=0){if((c[f+360>>2]|0)==0){break}a[b+3484+(e*72|0)+70|0]=0;H5a(c[d>>2]|0,b+3484+(e*72|0)+4|0);fGb(b+3484+(e*72|0)+56|0);c[b+3484+(e*72|0)+16>>2]=0;fGb(b+3484+(e*72|0)+64|0);fGb(b+3484+(e*72|0)+60|0);c[b+3484+(e*72|0)+24>>2]=0;c[b+3484+(e*72|0)+20>>2]=0;c[b+3484+(e*72|0)+36>>2]=0}}while(0);e=e+1|0;}while(e>>>0<32>>>0);return}function pGa(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=d+7368|0;j=0;a:do{do{if((c[(c[d+3484+(j*72|0)>>2]|0)+360>>2]|0)!=0){if((b[d+3484+(j*72|0)+68>>1]|0)!=(b[h>>1]|0)){break}if((c[d+3484+(j*72|0)+32>>2]|0)==(f|0)){k=5;break a}}}while(0);j=j+1|0;}while(j>>>0<32>>>0);if((k|0)==5){KIb(c[d+4>>2]|0,16,2536056,(k=i,i=i+8|0,c[k>>2]=f,k)|0);i=k;l=-1094995529;i=g;return l|0}k=qGa(d)|0;if((k|0)==0){l=-12;i=g;return l|0}c[e>>2]=c[k>>2];c[d+3480>>2]=k;c[k+32>>2]=f;a[k+70|0]=3;b[k+68>>1]=b[h>>1]|0;h=k+40|0;k=(c[d+180>>2]|0)+20|0;c[h>>2]=c[k>>2];c[h+4>>2]=c[k+4>>2];c[h+8>>2]=c[k+8>>2];c[h+12>>2]=c[k+12>>2];l=0;i=g;return l|0}function qGa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=0;while(1){if(!(e>>>0<32>>>0)){f=17;break}g=b+3484+(e*72|0)|0;h=g|0;if((c[(c[h>>2]|0)+360>>2]|0)==0){break}else{e=e+1|0}}if((f|0)==17){KIb(c[b+4>>2]|0,16,2247376,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;j=0;i=d;return j|0}f=b+4|0;k=b+3484+(e*72|0)+4|0;if((J5a(c[f>>2]|0,k,1)|0)<0){j=0;i=d;return j|0}l=dGb((c[b+7412>>2]|0)*392|0)|0;m=b+3484+(e*72|0)+64|0;c[m>>2]=l;do{if((l|0)!=0){n=mGb(c[b+1404>>2]|0)|0;c[b+3484+(e*72|0)+56>>2]=n;if((n|0)==0){break}c[b+3484+(e*72|0)+16>>2]=c[n+4>>2];n=mGb(c[b+1408>>2]|0)|0;c[b+3484+(e*72|0)+60>>2]=n;if((n|0)==0){break}o=c[n+4>>2]|0;n=b+3484+(e*72|0)+24|0;c[n>>2]=o;p=c[b+180>>2]|0;q=ca(c[p+13108>>2]|0,c[p+13104>>2]|0)|0;c[b+3484+(e*72|0)+28>>2]=q;a:do{if((q|0)>0){p=0;r=o;while(1){c[r+(p<<2)>>2]=c[(c[m>>2]|0)+4>>2];s=p+1|0;if((s|0)>=(q|0)){break a}p=s;r=c[n>>2]|0}}}while(0);n=b+7512|0;q=c[h>>2]|0;c[q+300>>2]=(c[n>>2]|0)==1;o=c[n>>2]|0;if((o|0)==1){t=1}else{t=(o|0)==2|0}c[q+296>>2]=t;j=g;i=d;return j|0}}while(0);g=c[h>>2]|0;if((g|0)==0){j=0;i=d;return j|0}if((c[g+360>>2]|0)==0){j=0;i=d;return j|0}a[b+3484+(e*72|0)+70|0]=0;H5a(c[f>>2]|0,k);fGb(b+3484+(e*72|0)+56|0);c[b+3484+(e*72|0)+16>>2]=0;fGb(m);fGb(b+3484+(e*72|0)+60|0);c[b+3484+(e*72|0)+24>>2]=0;c[b+3484+(e*72|0)+20>>2]=0;c[b+3484+(e*72|0)+36>>2]=0;j=0;i=d;return j|0}function rGa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;j=e+7370|0;k=e+7368|0;l=e+180|0;a:do{if((g|0)==0){m=0;n=2147483647;o=0;p=0;b:while(1){if(o>>>0<32>>>0){q=o;r=n;s=m}else{do{if((b[j>>1]|0)==(b[k>>1]|0)){t=c[l>>2]|0;if((t|0)==0){break}if((m|0)<=(c[t+76+(((c[t+72>>2]|0)-1|0)*12|0)+4>>2]|0)){u=0;v=26;break b}}}while(0);if((m|0)!=0){w=p;break a}t=b[j>>1]|0;if(t<<16>>16==(b[k>>1]|0)){u=0;v=26;break}b[j>>1]=t+1&255;q=0;r=2147483647;s=0}do{if((a[e+3484+(q*72|0)+70|0]&1)==0){x=s;y=r;z=p}else{if((b[e+3484+(q*72|0)+68>>1]|0)!=(b[j>>1]|0)){x=s;y=r;z=p;break}t=c[e+3484+(q*72|0)+32>>2]|0;A=(t|0)<(r|0);x=s+1|0;y=A?t:r;z=A?q:p}}while(0);m=x;n=y;o=q+1|0;p=z}if((v|0)==26){i=h;return u|0}}else{p=0;o=2147483647;n=0;m=0;while(1){if(n>>>0<32>>>0){B=n;C=o;D=p}else{if((p|0)!=0){w=m;break a}A=b[j>>1]|0;if(A<<16>>16==(b[k>>1]|0)){u=0;break}b[j>>1]=A+1&255;B=0;C=2147483647;D=0}do{if((a[e+3484+(B*72|0)+70|0]&1)==0){E=D;F=C;G=m}else{if((b[e+3484+(B*72|0)+68>>1]|0)!=(b[j>>1]|0)){E=D;F=C;G=m;break}A=c[e+3484+(B*72|0)+32>>2]|0;t=(A|0)<(C|0);E=D+1|0;F=t?A:C;G=t?B:m}}while(0);p=E;o=F;n=B+1|0;m=G}i=h;return u|0}}while(0);G=e+3484+(w*72|0)|0;B=c[G>>2]|0;F=qKb(c[B+80>>2]|0)|0;E=(b[F+8>>1]&16384)>>>0>14336>>>0|0;C=YHb(f,B)|0;B=c[G>>2]|0;do{if((B|0)!=0){if((c[B+360>>2]|0)==0){break}G=e+3484+(w*72|0)+70|0;D=a[G]&-2;a[G]=D;if(!(D<<24>>24==0)){break}H5a(c[e+4>>2]|0,e+3484+(w*72|0)+4|0);fGb(e+3484+(w*72|0)+56|0);c[e+3484+(w*72|0)+16>>2]=0;fGb(e+3484+(w*72|0)+64|0);fGb(e+3484+(w*72|0)+60|0);c[e+3484+(w*72|0)+24>>2]=0;c[e+3484+(w*72|0)+20>>2]=0;c[e+3484+(w*72|0)+36>>2]=0}}while(0);if((C|0)<0){u=C;i=h;return u|0}C=F+5|0;B=F+6|0;F=c[e+3484+(w*72|0)+40>>2]|0;D=c[e+3484+(w*72|0)+48>>2]|0;G=(ca(D,c[f+32>>2]|0)|0)+(F<<E)|0;j=f|0;c[j>>2]=(c[j>>2]|0)+G;G=(ca(D>>d[B],c[f+36>>2]|0)|0)+(F>>d[C]<<E)|0;j=f+4|0;c[j>>2]=(c[j>>2]|0)+G;G=(ca(D>>d[B],c[f+40>>2]|0)|0)+(F>>d[C]<<E)|0;E=f+8|0;c[E>>2]=(c[E>>2]|0)+G;KIb(c[e+4>>2]|0,48,2604552,(G=i,i=i+8|0,c[G>>2]=c[e+3484+(w*72|0)+32>>2],G)|0);i=G;u=1;i=h;return u|0}function sGa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=i;i=i+200|0;e=d|0;f=(c[b+2404>>2]|0)==0;g=b+3480|0;h=c[g>>2]|0;j=c[h+28>>2]|0;k=c[(c[(c[b+184>>2]|0)+1652>>2]|0)+(c[b+2396>>2]<<2)>>2]|0;l=c[b+5796>>2]|0;m=h+64|0;n=c[m>>2]|0;if(!(l>>>0<(((c[n+8>>2]|0)>>>0)/392|0)>>>0)){o=-1094995529;i=d;return o|0}p=h+24|0;do{if((k|0)<(j|0)){c[(c[p>>2]|0)+(k<<2)>>2]=(c[n+4>>2]|0)+(l*392|0);q=k+1|0;if((q|0)<(j|0)){r=q}else{break}do{c[(c[p>>2]|0)+(r<<2)>>2]=(c[(c[m>>2]|0)+4>>2]|0)+(l*392|0);r=r+1|0;}while((r|0)<(j|0))}}while(0);c[h+20>>2]=c[(c[p>>2]|0)+(k<<2)>>2];k=b+2192|0;if(((c[b+1800>>2]|0)+(c[b+1604>>2]|0)|0)==(-(c[k>>2]|0)|0)){KIb(c[b+4>>2]|0,16,2452232,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;o=-1094995529;i=d;return o|0}p=f?2:1;f=e;h=e+192|0;j=b+3027|0;r=b+3028|0;l=0;m=0;a:while(1){mrc(f|0,0,196)|0;n=c[(c[g>>2]|0)+20>>2]|0;q=n+(m*196|0)|0;t=l<<24>>24!=0|0;u=t^1;v=b+3012+(m<<2)|0;w=c[v>>2]|0;if((w|0)==0){x=0}else{y=c[b+1412+(t*196|0)+192>>2]|0;z=0;while(1){b:do{if((y|0)>0){A=0;B=z;while(1){if((B|0)>=16){C=B;break b}c[e+64+(B<<2)>>2]=c[b+1412+(t*196|0)+64+(A<<2)>>2];c[e+(c[h>>2]<<2)>>2]=c[b+1412+(t*196|0)+(A<<2)>>2];c[e+128+(c[h>>2]<<2)>>2]=0;D=(c[h>>2]|0)+1|0;c[h>>2]=D;E=A+1|0;if((E|0)<(y|0)){A=E;B=D}else{C=D;break}}}else{C=z}}while(0);B=c[b+1412+(u*196|0)+192>>2]|0;c:do{if((B|0)>0){A=0;D=C;while(1){if((D|0)>=16){F=D;break c}c[e+64+(D<<2)>>2]=c[b+1412+(u*196|0)+64+(A<<2)>>2];c[e+(c[h>>2]<<2)>>2]=c[b+1412+(u*196|0)+(A<<2)>>2];c[e+128+(c[h>>2]<<2)>>2]=0;E=(c[h>>2]|0)+1|0;c[h>>2]=E;G=A+1|0;if((G|0)<(B|0)){A=G;D=E}else{F=E;break}}}else{F=C}}while(0);B=c[k>>2]|0;d:do{if((B|0)>0){D=0;A=F;while(1){if((A|0)>=16){H=A;break d}c[e+64+(A<<2)>>2]=c[b+2064+(D<<2)>>2];c[e+(c[h>>2]<<2)>>2]=c[b+2e3+(D<<2)>>2];c[e+128+(c[h>>2]<<2)>>2]=1;E=(c[h>>2]|0)+1|0;c[h>>2]=E;G=D+1|0;if((G|0)<(B|0)){D=G;A=E}else{H=E;break}}}else{H=F}}while(0);if(H>>>0<w>>>0){z=H}else{x=H;break}}}do{if((a[b+3008+m|0]|0)==0){nrc(q|0,f|0,196)|0;z=n+(m*196|0)+192|0;u=c[z>>2]|0;y=c[v>>2]|0;c[z>>2]=u>>>0>y>>>0?y:u}else{if((w|0)==0){break}u=n+(m*196|0)+192|0;y=0;do{z=c[b+2752+(m<<7)+(y<<2)>>2]|0;if((z|0)>=(x|0)){break a}c[n+(m*196|0)+64+(y<<2)>>2]=c[e+64+(z<<2)>>2];c[n+(m*196|0)+(y<<2)>>2]=c[e+(z<<2)>>2];c[n+(m*196|0)+128+(y<<2)>>2]=c[e+128+(z<<2)>>2];c[u>>2]=(c[u>>2]|0)+1;y=y+1|0;}while(y>>>0<(c[v>>2]|0)>>>0)}}while(0);do{if((a[j]|0)==l<<24>>24){v=c[r>>2]|0;if(!(v>>>0<(c[n+(m*196|0)+192>>2]|0)>>>0)){break}c[(c[g>>2]|0)+36>>2]=c[n+(m*196|0)+(v<<2)>>2]}}while(0);n=l+1&255;v=n&255;if(v>>>0<p>>>0){l=n;m=v}else{o=0;I=25;break}}if((I|0)==25){i=d;return o|0}KIb(c[b+4>>2]|0,16,2362936,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;o=-1094995529;i=d;return o|0}function tGa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[b+2584>>2]|0;if((e|0)==0){c[b+1800>>2]=0;c[b+1604>>2]=0;f=0;return f|0}g=b+3480|0;h=0;do{if((b+3484+(h*72|0)|0)!=(c[g>>2]|0)){i=b+3484+(h*72|0)+70|0;a[i]=a[i]&-7}h=h+1|0;}while(h>>>0<32>>>0);c[b+1604>>2]=0;c[b+1800>>2]=0;c[b+1996>>2]=0;c[b+2192>>2]=0;c[b+2388>>2]=0;h=e+4|0;g=b+5788|0;i=e|0;j=0;while(1){if((j|0)>=(c[h>>2]|0)){break}if((a[e+136+j|0]|0)==0){k=2}else{k=j>>>0>=(c[i>>2]|0)>>>0|0}l=uGa(b,b+1412+(k*196|0)|0,(c[e+8+(j<<2)>>2]|0)+(c[g>>2]|0)|0,2)|0;if((l|0)<0){f=l;m=21;break}else{j=j+1|0}}if((m|0)==21){return f|0}j=b+2748|0;g=0;while(1){if((g|0)>=(d[j]|0)){break}e=uGa(b,b+1412+(((a[b+2716+g|0]|0)!=0?3:4)*196|0)|0,c[b+2588+(g<<2)>>2]|0,4)|0;if((e|0)<0){f=e;m=21;break}else{g=g+1|0}}if((m|0)==21){return f|0}m=b+4|0;g=0;while(1){j=c[b+3484+(g*72|0)>>2]|0;do{if((j|0)!=0){if((c[j+360>>2]|0)==0){break}if((a[b+3484+(g*72|0)+70|0]|0)!=0){break}H5a(c[m>>2]|0,b+3484+(g*72|0)+4|0);fGb(b+3484+(g*72|0)+56|0);c[b+3484+(g*72|0)+16>>2]=0;fGb(b+3484+(g*72|0)+64|0);fGb(b+3484+(g*72|0)+60|0);c[b+3484+(g*72|0)+24>>2]=0;c[b+3484+(g*72|0)+20>>2]=0;c[b+3484+(g*72|0)+36>>2]=0}}while(0);j=g+1|0;if(j>>>0<32>>>0){g=j}else{f=0;break}}return f|0}function uGa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;j=d+180|0;k=(1<<c[(c[j>>2]|0)+64>>2])-1|0;l=d+7368|0;m=0;a:while(1){n=d+3484+(m*72|0)|0;do{if((c[(c[n>>2]|0)+360>>2]|0)!=0){if((b[d+3484+(m*72|0)+68>>1]|0)!=(b[l>>1]|0)){break}if((c[d+3484+(m*72|0)+32>>2]&k|0)==(f|0)){o=n;break a}}}while(0);n=m+1|0;if(n>>>0<32>>>0){m=n}else{p=0;q=6;break}}b:do{if((q|0)==6){while(1){q=0;m=d+3484+(p*72|0)|0;do{if((c[(c[m>>2]|0)+360>>2]|0)!=0){if((b[d+3484+(p*72|0)+68>>1]|0)!=(b[l>>1]|0)){break}n=c[d+3484+(p*72|0)+32>>2]|0;if((n|0)==(f|0)){o=m;break b}if((n&k|0)==(f|0)){o=m;break b}}}while(0);m=p+1|0;if(m>>>0<32>>>0){p=m;q=6}else{break}}KIb(c[d+4>>2]|0,16,2298e3,(m=i,i=i+8|0,c[m>>2]=f,m)|0);i=m;o=0}}while(0);if((o|0)==(c[d+3480>>2]|0)){r=-1094995529;i=h;return r|0}do{if((o|0)==0){q=qGa(d)|0;if((q|0)==0){r=-12;i=h;return r|0}p=c[j>>2]|0;k=q|0;m=c[k>>2]|0;do{if((c[p+56>>2]|0)==0){n=c[m+360>>2]|0;if((n|0)==0){break}mrc(c[n+4>>2]|0,1<<(c[p+52>>2]|0)-1&255|0,c[n+8>>2]|0)|0;n=c[(c[k>>2]|0)+364>>2]|0;if((n|0)==0){break}else{s=1;t=n}do{s=s+1|0;mrc(c[t+4>>2]|0,1<<(c[(c[j>>2]|0)+52>>2]|0)-1&255|0,c[t+8>>2]|0)|0;t=c[(c[k>>2]|0)+360+(s<<2)>>2]|0;}while((t|0)!=0)}else{if((c[m>>2]|0)==0){break}else{u=0;v=p;w=m}while(1){if((c[v+13100>>2]>>c[v+13152+(u<<2)>>2]|0)>0){n=0;x=v;while(1){if((c[x+13096>>2]>>c[x+13140+(u<<2)>>2]|0)>0){z=0;A=x;while(1){B=c[k>>2]|0;C=(c[B+(u<<2)>>2]|0)+((ca(c[B+32+(u<<2)>>2]|0,n)|0)+(z<<1))|0;y=1<<(c[A+52>>2]|0)-1&65535;a[C]=y;y=y>>8;a[C+1|0]=y;C=z+1|0;B=c[j>>2]|0;if((C|0)<(c[B+13096>>2]>>c[B+13140+(u<<2)>>2]|0)){z=C;A=B}else{D=B;break}}}else{D=x}A=n+1|0;if((A|0)<(c[D+13100>>2]>>c[D+13152+(u<<2)>>2]|0)){n=A;x=D}else{break}}E=D;F=c[k>>2]|0}else{E=v;F=w}x=u+1|0;if((c[F+(x<<2)>>2]|0)==0){break}else{u=x;v=E;w=F}}}}while(0);c[q+32>>2]=f;b[q+68>>1]=b[l>>1]|0;a[q+70|0]=0;if((a[d+140|0]|0)!=1){G=q;break}L5a(q+4|0,2147483647,0);G=q}else{G=o}}while(0);o=e+192|0;c[e+64+(c[o>>2]<<2)>>2]=c[G+32>>2];c[e+(c[o>>2]<<2)>>2]=G;c[o>>2]=(c[o>>2]|0)+1;o=G+70|0;a[o]=a[o]&-7&255|g;r=0;i=h;return r|0}function vGa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=1<<c[(c[a+180>>2]|0)+64>>2];e=c[a+5792>>2]|0;f=(e|0)%(d|0)|0;g=e-f|0;do{if((f|0)>(b|0)){if((f-b|0)<((d|0)/2|0|0)){h=4;break}i=g+d|0}else{h=4}}while(0);do{if((h|0)==4){if((f|0)>=(b|0)){i=g;break}i=g-((b-f|0)>((d|0)/2|0|0)?d:0)|0}}while(0);return(((c[a+3472>>2]|0)-16|0)>>>0<3>>>0?0:i)+b|0}function wGa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[b+2584>>2]|0;e=b+2588|0;do{if((d|0)==0){f=0}else{g=c[d>>2]|0;if((g|0)==0){h=0;i=0}else{j=g>>>0>1>>>0;k=0;l=0;do{l=((a[d+136+k|0]|0)!=0)+l|0;k=k+1|0;}while(k>>>0<g>>>0);h=j?g:1;i=l}k=c[d+4>>2]|0;if((h|0)<(k|0)){m=h;n=i}else{f=i;break}while(1){o=((a[d+136+m|0]|0)!=0)+n|0;p=m+1|0;if((p|0)<(k|0)){m=p;n=o}else{f=o;break}}}}while(0);if((e|0)==0){q=f;return q|0}e=a[b+2748|0]|0;if(e<<24>>24==0){q=f;return q|0}n=e&255;e=0;m=f;while(1){f=((a[b+2716+e|0]|0)!=0)+m|0;d=e+1|0;if((d|0)<(n|0)){e=d;m=f}else{q=f;break}}return q|0}function xGa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;b=i;e=a+136|0;f=a+4|0;g=a+3472|0;h=a+7496|0;j=a+7500|0;k=a+7508|0;l=a+7504|0;m=a+7484|0;n=a+7512|0;o=c[e>>2]|0;a:while(1){KIb(c[f>>2]|0,48,2535888,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=o+9280|0;r=o+9288|0;s=c[r>>2]|0;t=c[o+9272>>2]|0;u=0;v=c[q>>2]|0;while(1){w=t+(v>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)>>>24;w=v+8|0;y=s>>>0>w>>>0?w:s;c[q>>2]=y;z=x+u|0;if((x|0)==255){u=z;v=y}else{A=0;B=y;break}}do{v=t+(B>>>3)|0;u=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(B&7)>>>24;v=B+8|0;B=s>>>0>v>>>0?v:s;c[q>>2]=B;A=u+A|0;}while((u|0)==255);do{if((c[g>>2]|0)==39){if((z|0)==45){s=c[e>>2]|0;t=s+9280|0;u=c[t>>2]|0;v=s+9288|0;y=c[v>>2]|0;x=c[s+9272>>2]|0;s=x+(u>>>3)|0;w=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(u&7);if(w>>>0>134217727>>>0){s=(d[1382088+(w>>>23)|0]|0)+u|0;C=y>>>0>s>>>0?s:y}else{s=w>>>0>65535>>>0;D=s?w>>>16:w;w=s?16:0;if((D&65280|0)==0){E=w;F=D}else{E=w|8;F=D>>>8}D=63-((d[1359664+F|0]|0)+E<<1)+u|0;C=y>>>0>D>>>0?D:y}c[t>>2]=C;D=(d[x+(C>>>3)|0]|0)<<(C&7);c[t>>2]=((C|0)<(y|0))+C;y=D&128;c[h>>2]=y>>>7^1;D=c[t>>2]|0;u=c[v>>2]|0;if((y|0)==0){y=x+(D>>>3)|0;w=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(D&7)>>>25;y=D+7|0;c[t>>2]=u>>>0>y>>>0?y:u;c[j>>2]=w;w=c[t>>2]|0;y=(d[x+(w>>>3)|0]|0)<<(w&7)>>>7;c[t>>2]=((w|0)<(c[v>>2]|0))+w;c[k>>2]=y&1;y=c[t>>2]|0;w=c[v>>2]|0;s=x+(y>>>3)|0;x=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(y&7)>>>26;s=y+6|0;c[t>>2]=w>>>0>s>>>0?s:w;c[l>>2]=x;x=c[v>>2]|0;v=(c[t>>2]|0)+6|0;w=x>>>0>v>>>0?v:x;c[t>>2]=w;do{if((c[k>>2]|0)==0){if((c[j>>2]|0)==5){G=w;break}v=w+16|0;s=x>>>0>v>>>0?v:x;c[t>>2]=s;G=s}else{G=w}}while(0);w=G+8|0;s=(x>>>0>w>>>0?w:x)+1|0;w=x>>>0>s>>>0?s:x;c[t>>2]=w;H=w;I=x}else{H=D;I=u}w=H+1|0;c[t>>2]=I>>>0>w>>>0?w:I;break}else if((z|0)==1){w=c[e>>2]|0;s=c[a+252+(c[m>>2]<<2)>>2]|0;if((s|0)==0){J=37;break a}if((c[(c[s+4>>2]|0)+216>>2]|0)!=0){s=w+9280|0;v=c[s>>2]|0;y=w+9288|0;K=c[y>>2]|0;L=(c[w+9272>>2]|0)+(v>>>3)|0;w=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(v&7)>>>28;L=v+4|0;c[s>>2]=K>>>0>L>>>0?L:K;c[n>>2]=0;if((w|0)==2){KIb(c[f>>2]|0,48,2297984,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;c[n>>2]=2}else if((w|0)==1){KIb(c[f>>2]|0,48,2247360,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;c[n>>2]=1}w=c[y>>2]|0;y=(c[s>>2]|0)+2|0;K=(w>>>0>y>>>0?y:w)+1|0;c[s>>2]=w>>>0>K>>>0?K:w}KIb(c[f>>2]|0,48,2604488,(p=i,i=i+8|0,c[p>>2]=1,p)|0);i=p;w=c[r>>2]|0;K=(c[q>>2]|0)+(A<<3)|0;c[q>>2]=w>>>0>K>>>0?K:w;break}else if((z|0)==256){zGa(a);break}else if((z|0)==129){w=c[e>>2]|0;K=w+9272|0;s=w+9280|0;y=c[w+9288>>2]|0;w=(c[s>>2]|0)+4|0;L=(y>>>0>w>>>0?w:y)+1|0;w=(y>>>0>L>>>0?L:y)+1|0;c[s>>2]=y>>>0>w>>>0?w:y;y=AGa(K)|0;w=AGa(K)|0;do{if(w>>>0>31>>>0){KIb(c[f>>2]|0,16,2362896,(p=i,i=i+8|0,c[p>>2]=w,p)|0);i=p}else{c[m>>2]=w;if((y|0)<1){break}else{M=1}do{AGa(K)|0;M=M+1|0;}while((M|0)<=(y|0))}}while(0);KIb(c[f>>2]|0,48,2604488,(p=i,i=i+8|0,c[p>>2]=129,p)|0);i=p;break}else{KIb(c[f>>2]|0,48,2604488,(p=i,i=i+8|0,c[p>>2]=z,p)|0);i=p;y=c[r>>2]|0;K=(c[q>>2]|0)+(A<<3)|0;c[q>>2]=y>>>0>K>>>0?K:y;break}}else{if((z|0)==132){zGa(a);break}else{KIb(c[f>>2]|0,48,2452208,(p=i,i=i+8|0,c[p>>2]=z,p)|0);i=p;y=c[r>>2]|0;K=(c[q>>2]|0)+(A<<3)|0;c[q>>2]=y>>>0>K>>>0?K:y;break}}}while(0);y=c[e>>2]|0;K=c[y+9280>>2]|0;if(((c[y+9284>>2]|0)-K|0)<=0){N=1;J=38;break}w=(c[y+9272>>2]|0)+(K>>>3)|0;if(((je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(K&7)&-16777216|0)==-2147483648){N=1;J=38;break}else{o=y}}if((J|0)==37){KIb(c[f>>2]|0,48,2604488,(p=i,i=i+8|0,c[p>>2]=1,p)|0);i=p;p=c[r>>2]|0;r=(c[q>>2]|0)+(A<<3)|0;c[q>>2]=p>>>0>r>>>0?r:p;N=-12;i=b;return N|0}else if((J|0)==38){i=b;return N|0}return 0}function yGa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(f>>>3)|0;a=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(f&7)>>>((32-b|0)>>>0);h=f+b|0;c[e>>2]=g>>>0>h>>>0?h:g;return a|0}function zGa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[b+136>>2]|0;f=e+9272|0;g=e+9280|0;h=c[g>>2]|0;i=c[e+9288>>2]|0;e=(c[f>>2]|0)+(h>>>3)|0;j=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(h&7)>>>24;e=h+8|0;h=i>>>0>e>>>0?e:i;c[g>>2]=h;e=b+7476|0;if((j|0)==1){k=h+16|0;l=(i>>>0>k>>>0?k:i)+16|0;k=(i>>>0>l>>>0?l:i)+16|0;c[g>>2]=i>>>0>k>>>0?k:i;return}else if((j|0)==2){k=h+32|0;l=(i>>>0>k>>>0?k:i)+32|0;k=i>>>0>l>>>0?l:i;c[g>>2]=k;m=k}else if((j|0)==0){k=0;do{a[e]=1;a[b+7428+(k<<4)|0]=yGa(f,8)|0;a[b+7428+(k<<4)+1|0]=yGa(f,8)|0;a[b+7428+(k<<4)+2|0]=yGa(f,8)|0;a[b+7428+(k<<4)+3|0]=yGa(f,8)|0;a[b+7428+(k<<4)+4|0]=yGa(f,8)|0;a[b+7428+(k<<4)+5|0]=yGa(f,8)|0;a[b+7428+(k<<4)+6|0]=yGa(f,8)|0;a[b+7428+(k<<4)+7|0]=yGa(f,8)|0;a[b+7428+(k<<4)+8|0]=yGa(f,8)|0;a[b+7428+(k<<4)+9|0]=yGa(f,8)|0;a[b+7428+(k<<4)+10|0]=yGa(f,8)|0;a[b+7428+(k<<4)+11|0]=yGa(f,8)|0;a[b+7428+(k<<4)+12|0]=yGa(f,8)|0;a[b+7428+(k<<4)+13|0]=yGa(f,8)|0;a[b+7428+(k<<4)+14|0]=yGa(f,8)|0;a[b+7428+(k<<4)+15|0]=yGa(f,8)|0;k=k+1|0;}while((k|0)<3);return}else{m=h}if((j|0)!=2){return}j=m+32|0;c[g>>2]=i>>>0>j>>>0?j:i;return}function AGa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a>>2]|0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;a=b+(f>>>3)|0;h=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7);a=f+16|0;i=g>>>0>a>>>0?a:g;a=b+(i>>>3)|0;j=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>16|h&-65536;i=j>>>0>65535>>>0;a=i?h>>>16:j;j=i?16:0;if((a&65280|0)==0){k=j;l=a}else{k=j|8;l=a>>>8}a=(d[1359664+l|0]|0)+k|0;k=31-a|0;l=-f|0;j=g-f|0;if((k|0)<(l|0)){m=l}else{m=(j|0)<(k|0)?j:k}j=m+f|0;c[e>>2]=j;f=k+1|0;if((f|0)==0){n=0;o=n-1|0;return o|0}m=b+(j>>>3)|0;l=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7);if((f|0)<26){m=j+f|0;c[e>>2]=g>>>0>m>>>0?m:g;n=l>>>(a>>>0);o=n-1|0;return o|0}else{a=j+16|0;j=g>>>0>a>>>0?a:g;c[e>>2]=j;a=k-15|0;m=b+(j>>>3)|0;b=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>((47-k|0)>>>0);k=j+a|0;c[e>>2]=g>>>0>k>>>0?k:g;n=b|l>>>16<<a;o=n-1|0;return o|0}return 0}function BGa(a,b){a=a|0;b=b|0;if((b|0)==9){c[a>>2]=634;c[a+4>>2]=510;c[a+8>>2]=164;c[a+12>>2]=2082;c[a+16>>2]=1260;c[a+20>>2]=388;c[a+24>>2]=2190;c[a+28>>2]=1830;c[a+32>>2]=248;c[a+36>>2]=1078;c[a+40>>2]=2340;c[a+44>>2]=36;c[a+48>>2]=112;c[a+52>>2]=78;c[a+56>>2]=140;c[a+60>>2]=10;c[a+64>>2]=34;c[a+68>>2]=76;c[a+72>>2]=6;c[a+76>>2]=96;c[a+80>>2]=228;c[a+84>>2]=650;c[a+88>>2]=50;c[a+92>>2]=322;c[a+96>>2]=410;c[a+100>>2]=238;c[a+104>>2]=444;c[a+108>>2]=398;c[a+112>>2]=296;c[a+116>>2]=658;c[a+120>>2]=336;c[a+124>>2]=496;c[a+128>>2]=564;c[a+132>>2]=318;c[a+136>>2]=250;c[a+140>>2]=42;c[a+144>>2]=140;c[a+148>>2]=108;c[a+152>>2]=90;c[a+156>>2]=54;c[a+160>>2]=438;c[a+164>>2]=134;c[a+168>>2]=18;c[a+172>>2]=40;c[a+176>>2]=300;c[a+180>>2]=200;c[a+184>>2]=322;c[a+188>>2]=40;c[a+192>>2]=300;c[a+196>>2]=200;c[a+200>>2]=322;return}else if((b|0)==10){c[a>>2]=60;c[a+4>>2]=1532;c[a+8>>2]=1756;c[a+12>>2]=424;c[a+16>>2]=2256;c[a+20>>2]=1384;c[a+24>>2]=440;c[a+28>>2]=2144;c[a+32>>2]=906;c[a+36>>2]=2292;c[a+40>>2]=2224;c[a+44>>2]=88;c[a+48>>2]=126;c[a+52>>2]=86;c[a+56>>2]=124;c[a+60>>2]=30;c[a+64>>2]=56;c[a+68>>2]=62;c[a+72>>2]=74;c[a+76>>2]=82;c[a+80>>2]=432;c[a+84>>2]=558;c[a+88>>2]=396;c[a+92>>2]=460;c[a+96>>2]=548;c[a+100>>2]=346;c[a+104>>2]=358;c[a+108>>2]=100;c[a+112>>2]=340;c[a+116>>2]=196;c[a+120>>2]=514;c[a+124>>2]=262;c[a+128>>2]=544;c[a+132>>2]=530;c[a+136>>2]=366;c[a+140>>2]=154;c[a+144>>2]=86;c[a+148>>2]=88;c[a+152>>2]=158;c[a+156>>2]=80;c[a+160>>2]=26;c[a+164>>2]=66;c[a+168>>2]=14;c[a+172>>2]=82;c[a+176>>2]=74;c[a+180>>2]=454;c[a+184>>2]=582;c[a+188>>2]=82;c[a+192>>2]=74;c[a+196>>2]=454;c[a+200>>2]=582;return}else{c[a>>2]=632;c[a+4>>2]=512;c[a+8>>2]=166;c[a+12>>2]=2084;c[a+16>>2]=1262;c[a+20>>2]=390;c[a+24>>2]=2188;c[a+28>>2]=1832;c[a+32>>2]=250;c[a+36>>2]=204;c[a+40>>2]=2342;c[a+44>>2]=144;c[a+48>>2]=110;c[a+52>>2]=80;c[a+56>>2]=138;c[a+60>>2]=12;c[a+64>>2]=32;c[a+68>>2]=78;c[a+72>>2]=68;c[a+76>>2]=94;c[a+80>>2]=226;c[a+84>>2]=652;c[a+88>>2]=48;c[a+92>>2]=320;c[a+96>>2]=412;c[a+100>>2]=648;c[a+104>>2]=446;c[a+108>>2]=400;c[a+112>>2]=294;c[a+116>>2]=660;c[a+120>>2]=334;c[a+124>>2]=494;c[a+128>>2]=566;c[a+132>>2]=56;c[a+136>>2]=72;c[a+140>>2]=40;c[a+144>>2]=138;c[a+148>>2]=106;c[a+152>>2]=92;c[a+156>>2]=52;c[a+160>>2]=436;c[a+164>>2]=168;c[a+168>>2]=16;c[a+172>>2]=42;c[a+176>>2]=302;c[a+180>>2]=198;c[a+184>>2]=320;c[a+188>>2]=42;c[a+192>>2]=302;c[a+196>>2]=198;c[a+200>>2]=320;return}}function CGa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=e>>>1;if((f|0)<=0){return}e=g+8|0;j=g+16|0;k=g|0;g=32-h|0;l=9-h|0;m=0;n=a;while(1){a=c[j>>2]|0;o=c[k>>2]|0;p=0;q=c[e>>2]|0;do{r=o+(q>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>(g>>>0);r=q+h|0;q=a>>>0>r>>>0?r:a;c[e>>2]=q;b[n+(p<<1)>>1]=s<<l;p=p+1|0;}while((p|0)<(f|0));p=m+1|0;if((p|0)<(f|0)){m=p;n=n+(i<<1)|0}else{break}}return}function DGa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d>>>1;d=c;c=0;g=a;while(1){a=(b[d>>1]|0)+(e[g>>1]|0)|0;if(a>>>0<512>>>0){h=a&65535}else{h=-a>>31&511}b[g>>1]=h;a=g+2|0;i=(b[d+2>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){j=i&65535}else{j=-i>>31&511}b[a>>1]=j;a=g+4|0;i=(b[d+4>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){k=i&65535}else{k=-i>>31&511}b[a>>1]=k;a=g+6|0;i=(b[d+6>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){l=i&65535}else{l=-i>>31&511}b[a>>1]=l;a=c+1|0;if((a|0)<4){d=d+8|0;c=a;g=g+(f<<1)|0}else{break}}return}function EGa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d>>>1;d=c;c=0;g=a;while(1){a=(b[d>>1]|0)+(e[g>>1]|0)|0;if(a>>>0<512>>>0){h=a&65535}else{h=-a>>31&511}b[g>>1]=h;a=g+2|0;i=(b[d+2>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){j=i&65535}else{j=-i>>31&511}b[a>>1]=j;a=g+4|0;i=(b[d+4>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){k=i&65535}else{k=-i>>31&511}b[a>>1]=k;a=g+6|0;i=(b[d+6>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){l=i&65535}else{l=-i>>31&511}b[a>>1]=l;a=g+8|0;i=(b[d+8>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){m=i&65535}else{m=-i>>31&511}b[a>>1]=m;a=g+10|0;i=(b[d+10>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){n=i&65535}else{n=-i>>31&511}b[a>>1]=n;a=g+12|0;i=(b[d+12>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){o=i&65535}else{o=-i>>31&511}b[a>>1]=o;a=g+14|0;i=(b[d+14>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<512>>>0){p=i&65535}else{p=-i>>31&511}b[a>>1]=p;a=c+1|0;if((a|0)<8){d=d+16|0;c=a;g=g+(f<<1)|0}else{break}}return}function FGa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>>1;d=c;c=0;g=a;while(1){a=d;h=0;while(1){i=g+(h<<1)|0;j=(b[a>>1]|0)+(e[i>>1]|0)|0;if(j>>>0<512>>>0){k=j&65535}else{k=-j>>31&511}b[i>>1]=k;i=h+1|0;if((i|0)<16){a=a+2|0;h=i}else{break}}h=c+1|0;if((h|0)<16){d=d+32|0;c=h;g=g+(f<<1)|0}else{break}}return}function GGa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>>1;d=c;c=0;g=a;while(1){a=d;h=0;while(1){i=g+(h<<1)|0;j=(b[a>>1]|0)+(e[i>>1]|0)|0;if(j>>>0<512>>>0){k=j&65535}else{k=-j>>31&511}b[i>>1]=k;i=h+1|0;if((i|0)<32){a=a+2|0;h=i}else{break}}h=c+1|0;if((h|0)<32){d=d+64|0;c=h;g=g+(f<<1)|0}else{break}}return}function HGa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d>>>1;d=a;a=0;while(1){g=((b[c+(a<<1)>>1]|0)+8>>4)+(e[d>>1]|0)|0;if(g>>>0<512>>>0){h=g&65535}else{h=-g>>31&511}b[d>>1]=h;g=d+2|0;i=((b[c+((a|1)<<1)>>1]|0)+8>>4)+(e[g>>1]|0)|0;if(i>>>0<512>>>0){j=i&65535}else{j=-i>>31&511}b[g>>1]=j;g=d+4|0;i=((b[c+((a|2)<<1)>>1]|0)+8>>4)+(e[g>>1]|0)|0;if(i>>>0<512>>>0){k=i&65535}else{k=-i>>31&511}b[g>>1]=k;g=d+6|0;i=((b[c+((a|3)<<1)>>1]|0)+8>>4)+(e[g>>1]|0)|0;if(i>>>0<512>>>0){l=i&65535}else{l=-i>>31&511}b[g>>1]=l;g=a+4|0;if((g|0)<16){d=d+(f<<1)|0;a=g}else{break}}return}function IGa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=a;a=c;g=0;while(1){h=b[a>>1]|0;i=a+16|0;j=b[i>>1]|0;k=j+h|0;l=a+24|0;m=b[l>>1]|0;n=m+j|0;o=h-m|0;p=a+8|0;q=(b[p>>1]|0)*74|0;r=((h-j+m|0)*74|0)+64|0;m=r>>7;if((m+32768|0)>>>0>65535>>>0){s=(r>>31^32767)&65535}else{s=m&65535}b[i>>1]=s;i=(k*29|0)+64+(n*55|0)+q|0;m=i>>7;if((m+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=m&65535}b[a>>1]=t;m=(n*-29|0)+64+(o*55|0)+q|0;n=m>>7;if((n+32768|0)>>>0>65535>>>0){u=(m>>31^32767)&65535}else{u=n&65535}b[p>>1]=u;p=(k*55|0)+64+(o*29|0)-q|0;q=p>>7;if((q+32768|0)>>>0>65535>>>0){v=(p>>31^32767)&65535}else{v=q&65535}b[l>>1]=v;l=g+1|0;if((l|0)<4){a=a+2|0;g=l}else{break}}g=d>>>1;d=f;f=0;a=c;while(1){c=b[a>>1]|0;v=b[a+4>>1]|0;u=v+c|0;t=b[a+6>>1]|0;s=t+v|0;l=c-t|0;q=(b[a+2>>1]|0)*74|0;p=d+4|0;o=((c-v+t|0)*74|0)+1024|0;t=o>>11;if((t+32768|0)>>>0>65535>>>0){w=(o>>31^32767)&65535}else{w=t&65535}t=(w<<16>>16)+(e[p>>1]|0)|0;if(t>>>0<512>>>0){x=t&65535}else{x=-t>>31&511}b[p>>1]=x;p=(u*29|0)+1024+(s*55|0)+q|0;t=p>>11;if((t+32768|0)>>>0>65535>>>0){y=(p>>31^32767)&65535}else{y=t&65535}t=(y<<16>>16)+(e[d>>1]|0)|0;if(t>>>0<512>>>0){z=t&65535}else{z=-t>>31&511}b[d>>1]=z;t=d+2|0;p=(s*-29|0)+1024+(l*55|0)+q|0;s=p>>11;if((s+32768|0)>>>0>65535>>>0){A=(p>>31^32767)&65535}else{A=s&65535}s=(A<<16>>16)+(e[t>>1]|0)|0;if(s>>>0<512>>>0){B=s&65535}else{B=-s>>31&511}b[t>>1]=B;t=d+6|0;s=(u*55|0)+1024+(l*29|0)-q|0;q=s>>11;if((q+32768|0)>>>0>65535>>>0){C=(s>>31^32767)&65535}else{C=q&65535}q=(C<<16>>16)+(e[t>>1]|0)|0;if(q>>>0<512>>>0){D=q&65535}else{D=-q>>31&511}b[t>>1]=D;t=f+1|0;if((t|0)<4){d=d+(g<<1)|0;f=t;a=a+8|0}else{break}}return}function JGa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=a;a=c;g=0;while(1){h=b[a>>1]<<6;i=a+16|0;j=b[i>>1]|0;k=(j<<6)+h|0;l=(j*-64|0)+h|0;h=a+8|0;j=b[h>>1]|0;m=a+24|0;n=b[m>>1]|0;o=(n*36|0)+(j*83|0)|0;p=(n*-83|0)+(j*36|0)|0;j=k+64+o|0;n=j>>7;if((n+32768|0)>>>0>65535>>>0){q=(j>>31^32767)&65535}else{q=n&65535}b[a>>1]=q;n=l+64+p|0;j=n>>7;if((j+32768|0)>>>0>65535>>>0){r=(n>>31^32767)&65535}else{r=j&65535}b[h>>1]=r;h=l-p+64|0;p=h>>7;if((p+32768|0)>>>0>65535>>>0){s=(h>>31^32767)&65535}else{s=p&65535}b[i>>1]=s;i=k-o+64|0;o=i>>7;if((o+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=o&65535}b[m>>1]=t;m=g+1|0;if((m|0)<4){a=a+2|0;g=m}else{break}}g=d>>>1;d=f;f=0;a=c;while(1){c=b[a>>1]<<6;t=b[a+4>>1]|0;s=(t<<6)+c|0;r=(t*-64|0)+c|0;c=b[a+2>>1]|0;t=b[a+6>>1]|0;q=(t*36|0)+(c*83|0)|0;m=(t*-83|0)+(c*36|0)|0;c=s+1024+q|0;t=c>>11;if((t+32768|0)>>>0>65535>>>0){u=(c>>31^32767)&65535}else{u=t&65535}t=(u<<16>>16)+(e[d>>1]|0)|0;if(t>>>0<512>>>0){v=t&65535}else{v=-t>>31&511}b[d>>1]=v;t=d+2|0;c=r+1024+m|0;o=c>>11;if((o+32768|0)>>>0>65535>>>0){w=(c>>31^32767)&65535}else{w=o&65535}o=(w<<16>>16)+(e[t>>1]|0)|0;if(o>>>0<512>>>0){x=o&65535}else{x=-o>>31&511}b[t>>1]=x;t=d+4|0;o=r-m+1024|0;m=o>>11;if((m+32768|0)>>>0>65535>>>0){y=(o>>31^32767)&65535}else{y=m&65535}m=(y<<16>>16)+(e[t>>1]|0)|0;if(m>>>0<512>>>0){z=m&65535}else{z=-m>>31&511}b[t>>1]=z;t=d+6|0;m=s-q+1024|0;q=m>>11;if((q+32768|0)>>>0>65535>>>0){A=(m>>31^32767)&65535}else{A=q&65535}q=(A<<16>>16)+(e[t>>1]|0)|0;if(q>>>0<512>>>0){B=q&65535}else{B=-q>>31&511}b[t>>1]=B;t=f+1|0;if((t|0)<4){d=d+(g<<1)|0;f=t;a=a+8|0}else{break}}return}function KGa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=a;a=j;n=h|0;o=h+4|0;p=h+8|0;q=h+12|0;r=d;s=0;while(1){mrc(a|0,0,16)|0;t=r+16|0;u=r+48|0;v=r+80|0;w=r+112|0;x=((b[w>>1]|0)*18|0)+(((b[v>>1]|0)*50|0)+(((b[u>>1]|0)*75|0)+((b[t>>1]|0)*89|0)))|0;c[j>>2]=x;c[j+4>>2]=((b[w>>1]|0)*-50|0)+(((b[v>>1]|0)*-89|0)+(((b[u>>1]|0)*-18|0)+((b[t>>1]|0)*75|0)));c[j+8>>2]=((b[w>>1]|0)*75|0)+(((b[v>>1]|0)*18|0)+(((b[u>>1]|0)*-89|0)+((b[t>>1]|0)*50|0)));c[j+12>>2]=((b[w>>1]|0)*-89|0)+(((b[v>>1]|0)*75|0)+(((b[u>>1]|0)*-50|0)+((b[t>>1]|0)*18|0)));t=b[r>>1]<<6;u=b[r+64>>1]|0;v=(u<<6)+t|0;w=(u*-64|0)+t|0;t=b[r+32>>1]|0;u=b[r+96>>1]|0;y=(u*36|0)+(t*83|0)|0;z=(u*-83|0)+(t*36|0)|0;t=y+v|0;c[n>>2]=t;c[o>>2]=z+w;c[p>>2]=w-z;c[q>>2]=v-y;y=0;v=t;t=x;while(1){x=v+64+t|0;z=x>>7;if((z+32768|0)>>>0>65535>>>0){A=(x>>31^32767)&65535}else{A=z&65535}b[r+(y<<3<<1)>>1]=A;z=v-t+64|0;x=z>>7;if((x+32768|0)>>>0>65535>>>0){B=(z>>31^32767)&65535}else{B=x&65535}b[r+(7-y<<3<<1)>>1]=B;x=y+1|0;if((x|0)>=4){break}y=x;v=c[h+(x<<2)>>2]|0;t=c[j+(x<<2)>>2]|0}t=s+1|0;if((t|0)<8){r=r+2|0;s=t}else{break}}s=f>>>1;f=l;r=k|0;j=k+4|0;h=k+8|0;B=k+12|0;A=m;m=0;q=d;while(1){mrc(f|0,0,16)|0;d=q+2|0;p=q+6|0;o=q+10|0;n=q+14|0;a=((b[n>>1]|0)*18|0)+(((b[o>>1]|0)*50|0)+(((b[p>>1]|0)*75|0)+((b[d>>1]|0)*89|0)))|0;c[l>>2]=a;c[l+4>>2]=((b[n>>1]|0)*-50|0)+(((b[o>>1]|0)*-89|0)+(((b[p>>1]|0)*-18|0)+((b[d>>1]|0)*75|0)));c[l+8>>2]=((b[n>>1]|0)*75|0)+(((b[o>>1]|0)*18|0)+(((b[p>>1]|0)*-89|0)+((b[d>>1]|0)*50|0)));c[l+12>>2]=((b[n>>1]|0)*-89|0)+(((b[o>>1]|0)*75|0)+(((b[p>>1]|0)*-50|0)+((b[d>>1]|0)*18|0)));d=b[q>>1]<<6;p=b[q+8>>1]|0;o=(p<<6)+d|0;n=(p*-64|0)+d|0;d=b[q+4>>1]|0;p=b[q+12>>1]|0;t=(p*36|0)+(d*83|0)|0;v=(p*-83|0)+(d*36|0)|0;d=t+o|0;c[r>>2]=d;c[j>>2]=v+n;c[h>>2]=n-v;c[B>>2]=o-t;t=0;o=d;d=a;while(1){a=A+(t<<1)|0;v=o+1024+d|0;n=v>>11;if((n+32768|0)>>>0>65535>>>0){C=(v>>31^32767)&65535}else{C=n&65535}n=(C<<16>>16)+(e[a>>1]|0)|0;if(n>>>0<512>>>0){D=n&65535}else{D=-n>>31&511}b[a>>1]=D;a=A+(7-t<<1)|0;n=o-d+1024|0;v=n>>11;if((v+32768|0)>>>0>65535>>>0){E=(n>>31^32767)&65535}else{E=v&65535}v=(E<<16>>16)+(e[a>>1]|0)|0;if(v>>>0<512>>>0){F=v&65535}else{F=-v>>31&511}b[a>>1]=F;a=t+1|0;if((a|0)>=4){break}t=a;o=c[k+(a<<2)>>2]|0;d=c[l+(a<<2)>>2]|0}d=m+1|0;if((d|0)<8){A=A+(s<<1)|0;m=d;q=q+16|0}else{break}}i=g;return}function LGa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+128|0;j=h|0;k=h+32|0;l=h+64|0;m=h+96|0;n=d;d=k;o=f;p=0;while(1){mrc(d|0,0,32)|0;q=0;do{r=k+(q<<2)|0;s=(ca(b[o+32>>1]|0,a[305952+q|0]|0)|0)+(c[r>>2]|0)|0;t=(ca(b[o+96>>1]|0,a[306080+q|0]|0)|0)+s|0;s=(ca(b[o+160>>1]|0,a[306208+q|0]|0)|0)+t|0;t=(ca(b[o+224>>1]|0,a[306336+q|0]|0)|0)+s|0;s=(ca(b[o+288>>1]|0,a[306464+q|0]|0)|0)+t|0;t=(ca(b[o+352>>1]|0,a[306592+q|0]|0)|0)+s|0;s=(ca(b[o+416>>1]|0,a[306720+q|0]|0)|0)+t|0;c[r>>2]=(ca(b[o+480>>1]|0,a[306848+q|0]|0)|0)+s;q=q+1|0;}while((q|0)<8);q=o+64|0;s=o+192|0;r=o+320|0;t=o+448|0;u=((b[t>>1]|0)*18|0)+(((b[r>>1]|0)*50|0)+(((b[s>>1]|0)*75|0)+((b[q>>1]|0)*89|0)))|0;v=((b[t>>1]|0)*-50|0)+(((b[r>>1]|0)*-89|0)+(((b[s>>1]|0)*-18|0)+((b[q>>1]|0)*75|0)))|0;w=((b[t>>1]|0)*75|0)+(((b[r>>1]|0)*18|0)+(((b[s>>1]|0)*-89|0)+((b[q>>1]|0)*50|0)))|0;x=((b[t>>1]|0)*-89|0)+(((b[r>>1]|0)*75|0)+(((b[s>>1]|0)*-50|0)+((b[q>>1]|0)*18|0)))|0;q=b[o>>1]<<6;s=b[o+256>>1]|0;r=(s<<6)+q|0;t=(s*-64|0)+q|0;q=b[o+128>>1]|0;s=b[o+384>>1]|0;y=(s*36|0)+(q*83|0)|0;z=(s*-83|0)+(q*36|0)|0;q=y+r|0;s=z+t|0;A=t-z|0;z=r-y|0;y=u+q|0;c[j>>2]=y;c[j+28>>2]=q-u;c[j+4>>2]=v+s;c[j+24>>2]=s-v;c[j+8>>2]=w+A;c[j+20>>2]=A-w;c[j+12>>2]=x+z;c[j+16>>2]=z-x;x=0;z=y;while(1){y=c[k+(x<<2)>>2]|0;w=z+64+y|0;A=w>>7;if((A+32768|0)>>>0>65535>>>0){B=(w>>31^32767)&65535}else{B=A&65535}b[o+(x<<4<<1)>>1]=B;A=z-y+64|0;y=A>>7;if((y+32768|0)>>>0>65535>>>0){C=(A>>31^32767)&65535}else{C=y&65535}b[o+(15-x<<4<<1)>>1]=C;y=x+1|0;if((y|0)>=8){break}x=y;z=c[j+(y<<2)>>2]|0}z=p+1|0;if((z|0)<16){o=o+2|0;p=z}else{break}}p=g>>>1;g=m;o=n;n=0;j=f;while(1){mrc(g|0,0,32)|0;f=0;do{C=m+(f<<2)|0;B=(ca(b[j+2>>1]|0,a[305952+f|0]|0)|0)+(c[C>>2]|0)|0;k=(ca(b[j+6>>1]|0,a[306080+f|0]|0)|0)+B|0;B=(ca(b[j+10>>1]|0,a[306208+f|0]|0)|0)+k|0;k=(ca(b[j+14>>1]|0,a[306336+f|0]|0)|0)+B|0;B=(ca(b[j+18>>1]|0,a[306464+f|0]|0)|0)+k|0;k=(ca(b[j+22>>1]|0,a[306592+f|0]|0)|0)+B|0;B=(ca(b[j+26>>1]|0,a[306720+f|0]|0)|0)+k|0;c[C>>2]=(ca(b[j+30>>1]|0,a[306848+f|0]|0)|0)+B;f=f+1|0;}while((f|0)<8);f=j+4|0;B=j+12|0;C=j+20|0;k=j+28|0;d=((b[k>>1]|0)*18|0)+(((b[C>>1]|0)*50|0)+(((b[B>>1]|0)*75|0)+((b[f>>1]|0)*89|0)))|0;z=((b[k>>1]|0)*-50|0)+(((b[C>>1]|0)*-89|0)+(((b[B>>1]|0)*-18|0)+((b[f>>1]|0)*75|0)))|0;x=((b[k>>1]|0)*75|0)+(((b[C>>1]|0)*18|0)+(((b[B>>1]|0)*-89|0)+((b[f>>1]|0)*50|0)))|0;y=((b[k>>1]|0)*-89|0)+(((b[C>>1]|0)*75|0)+(((b[B>>1]|0)*-50|0)+((b[f>>1]|0)*18|0)))|0;f=b[j>>1]<<6;B=b[j+16>>1]|0;C=(B<<6)+f|0;k=(B*-64|0)+f|0;f=b[j+8>>1]|0;B=b[j+24>>1]|0;A=(B*36|0)+(f*83|0)|0;w=(B*-83|0)+(f*36|0)|0;f=A+C|0;B=w+k|0;v=k-w|0;w=C-A|0;A=d+f|0;c[l>>2]=A;c[l+28>>2]=f-d;c[l+4>>2]=z+B;c[l+24>>2]=B-z;c[l+8>>2]=x+v;c[l+20>>2]=v-x;c[l+12>>2]=y+w;c[l+16>>2]=w-y;y=0;w=A;while(1){A=o+(y<<1)|0;x=c[m+(y<<2)>>2]|0;v=w+1024+x|0;z=v>>11;if((z+32768|0)>>>0>65535>>>0){D=(v>>31^32767)&65535}else{D=z&65535}z=(D<<16>>16)+(e[A>>1]|0)|0;if(z>>>0<512>>>0){E=z&65535}else{E=-z>>31&511}b[A>>1]=E;A=o+(15-y<<1)|0;z=w-x+1024|0;x=z>>11;if((x+32768|0)>>>0>65535>>>0){F=(z>>31^32767)&65535}else{F=x&65535}x=(F<<16>>16)+(e[A>>1]|0)|0;if(x>>>0<512>>>0){G=x&65535}else{G=-x>>31&511}b[A>>1]=G;A=y+1|0;if((A|0)>=8){break}y=A;w=c[l+(A<<2)>>2]|0}w=n+1|0;if((w|0)<16){o=o+(p<<1)|0;n=w;j=j+32|0}else{break}}i=h;return}function MGa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+320|0;j=h|0;k=h+64|0;l=h+128|0;m=h+160|0;n=h+224|0;o=h+288|0;p=d;d=k;q=l;r=f;s=0;while(1){mrc(d|0,0,64)|0;t=0;do{u=k+(t<<2)|0;v=1;w=c[u>>2]|0;do{w=(ca(b[r+(v<<5<<1)>>1]|0,a[305888+(v<<5)+t|0]|0)|0)+w|0;v=v+2|0;}while((v|0)<32);c[u>>2]=w;t=t+1|0;}while((t|0)<16);mrc(q|0,0,32)|0;t=0;v=0;while(1){x=(ca(b[r+128>>1]|0,a[305952+t|0]|0)|0)+v|0;y=(ca(b[r+384>>1]|0,a[306080+t|0]|0)|0)+x|0;x=(ca(b[r+640>>1]|0,a[306208+t|0]|0)|0)+y|0;y=(ca(b[r+896>>1]|0,a[306336+t|0]|0)|0)+x|0;x=(ca(b[r+1152>>1]|0,a[306464+t|0]|0)|0)+y|0;y=(ca(b[r+1408>>1]|0,a[306592+t|0]|0)|0)+x|0;x=(ca(b[r+1664>>1]|0,a[306720+t|0]|0)|0)+y|0;c[l+(t<<2)>>2]=(ca(b[r+1920>>1]|0,a[306848+t|0]|0)|0)+x;x=t+1|0;if((x|0)>=8){break}t=x;v=c[l+(x<<2)>>2]|0}v=r+256|0;t=r+768|0;x=r+1280|0;y=r+1792|0;z=((b[y>>1]|0)*18|0)+(((b[x>>1]|0)*50|0)+(((b[t>>1]|0)*75|0)+((b[v>>1]|0)*89|0)))|0;A=((b[y>>1]|0)*-50|0)+(((b[x>>1]|0)*-89|0)+(((b[t>>1]|0)*-18|0)+((b[v>>1]|0)*75|0)))|0;B=((b[y>>1]|0)*75|0)+(((b[x>>1]|0)*18|0)+(((b[t>>1]|0)*-89|0)+((b[v>>1]|0)*50|0)))|0;C=((b[y>>1]|0)*-89|0)+(((b[x>>1]|0)*75|0)+(((b[t>>1]|0)*-50|0)+((b[v>>1]|0)*18|0)))|0;v=b[r>>1]<<6;t=b[r+1024>>1]|0;x=(t<<6)+v|0;y=(t*-64|0)+v|0;v=b[r+512>>1]|0;t=b[r+1536>>1]|0;D=(t*36|0)+(v*83|0)|0;E=(t*-83|0)+(v*36|0)|0;v=D+x|0;t=E+y|0;F=y-E|0;E=x-D|0;D=z+v|0;x=v-z|0;z=A+t|0;v=t-A|0;A=B+F|0;t=F-B|0;B=C+E|0;F=E-C|0;C=c[l>>2]|0;E=C+D|0;c[j>>2]=E;c[j+60>>2]=D-C;C=c[l+4>>2]|0;c[j+4>>2]=C+z;c[j+56>>2]=z-C;C=c[l+8>>2]|0;c[j+8>>2]=C+A;c[j+52>>2]=A-C;C=c[l+12>>2]|0;c[j+12>>2]=C+B;c[j+48>>2]=B-C;C=c[l+16>>2]|0;c[j+16>>2]=C+F;c[j+44>>2]=F-C;C=c[l+20>>2]|0;c[j+20>>2]=C+t;c[j+40>>2]=t-C;C=c[l+24>>2]|0;c[j+24>>2]=C+v;c[j+36>>2]=v-C;C=c[l+28>>2]|0;c[j+28>>2]=C+x;c[j+32>>2]=x-C;C=0;x=E;while(1){E=c[k+(C<<2)>>2]|0;v=x+64+E|0;t=v>>7;if((t+32768|0)>>>0>65535>>>0){G=(v>>31^32767)&65535}else{G=t&65535}b[r+(C<<5<<1)>>1]=G;t=x-E+64|0;E=t>>7;if((E+32768|0)>>>0>65535>>>0){H=(t>>31^32767)&65535}else{H=E&65535}b[r+(31-C<<5<<1)>>1]=H;E=C+1|0;if((E|0)>=16){break}C=E;x=c[j+(E<<2)>>2]|0}x=s+1|0;if((x|0)<32){r=r+2|0;s=x}else{break}}s=g>>>1;g=n;r=o;j=p;p=0;H=f;while(1){mrc(g|0,0,64)|0;f=0;do{G=n+(f<<2)|0;k=1;l=c[G>>2]|0;do{l=(ca(b[H+(k<<1)>>1]|0,a[305888+(k<<5)+f|0]|0)|0)+l|0;k=k+2|0;}while((k|0)<32);c[G>>2]=l;f=f+1|0;}while((f|0)<16);mrc(r|0,0,32)|0;f=0;k=0;while(1){w=(ca(b[H+4>>1]|0,a[305952+f|0]|0)|0)+k|0;u=(ca(b[H+12>>1]|0,a[306080+f|0]|0)|0)+w|0;w=(ca(b[H+20>>1]|0,a[306208+f|0]|0)|0)+u|0;u=(ca(b[H+28>>1]|0,a[306336+f|0]|0)|0)+w|0;w=(ca(b[H+36>>1]|0,a[306464+f|0]|0)|0)+u|0;u=(ca(b[H+44>>1]|0,a[306592+f|0]|0)|0)+w|0;w=(ca(b[H+52>>1]|0,a[306720+f|0]|0)|0)+u|0;c[o+(f<<2)>>2]=(ca(b[H+60>>1]|0,a[306848+f|0]|0)|0)+w;w=f+1|0;if((w|0)>=8){break}f=w;k=c[o+(w<<2)>>2]|0}k=H+8|0;f=H+24|0;w=H+40|0;u=H+56|0;q=((b[u>>1]|0)*18|0)+(((b[w>>1]|0)*50|0)+(((b[f>>1]|0)*75|0)+((b[k>>1]|0)*89|0)))|0;d=((b[u>>1]|0)*-50|0)+(((b[w>>1]|0)*-89|0)+(((b[f>>1]|0)*-18|0)+((b[k>>1]|0)*75|0)))|0;x=((b[u>>1]|0)*75|0)+(((b[w>>1]|0)*18|0)+(((b[f>>1]|0)*-89|0)+((b[k>>1]|0)*50|0)))|0;C=((b[u>>1]|0)*-89|0)+(((b[w>>1]|0)*75|0)+(((b[f>>1]|0)*-50|0)+((b[k>>1]|0)*18|0)))|0;k=b[H>>1]<<6;f=b[H+32>>1]|0;w=(f<<6)+k|0;u=(f*-64|0)+k|0;k=b[H+16>>1]|0;f=b[H+48>>1]|0;E=(f*36|0)+(k*83|0)|0;t=(f*-83|0)+(k*36|0)|0;k=E+w|0;f=t+u|0;v=u-t|0;t=w-E|0;E=q+k|0;w=k-q|0;q=d+f|0;k=f-d|0;d=x+v|0;f=v-x|0;x=C+t|0;v=t-C|0;C=c[o>>2]|0;t=C+E|0;c[m>>2]=t;c[m+60>>2]=E-C;C=c[o+4>>2]|0;c[m+4>>2]=C+q;c[m+56>>2]=q-C;C=c[o+8>>2]|0;c[m+8>>2]=C+d;c[m+52>>2]=d-C;C=c[o+12>>2]|0;c[m+12>>2]=C+x;c[m+48>>2]=x-C;C=c[o+16>>2]|0;c[m+16>>2]=C+v;c[m+44>>2]=v-C;C=c[o+20>>2]|0;c[m+20>>2]=C+f;c[m+40>>2]=f-C;C=c[o+24>>2]|0;c[m+24>>2]=C+k;c[m+36>>2]=k-C;C=c[o+28>>2]|0;c[m+28>>2]=C+w;c[m+32>>2]=w-C;C=0;w=t;while(1){t=j+(C<<1)|0;k=c[n+(C<<2)>>2]|0;f=w+1024+k|0;v=f>>11;if((v+32768|0)>>>0>65535>>>0){I=(f>>31^32767)&65535}else{I=v&65535}v=(I<<16>>16)+(e[t>>1]|0)|0;if(v>>>0<512>>>0){J=v&65535}else{J=-v>>31&511}b[t>>1]=J;t=j+(31-C<<1)|0;v=w-k+1024|0;k=v>>11;if((k+32768|0)>>>0>65535>>>0){K=(v>>31^32767)&65535}else{K=k&65535}k=(K<<16>>16)+(e[t>>1]|0)|0;if(k>>>0<512>>>0){L=k&65535}else{L=-k>>31&511}b[t>>1]=L;t=C+1|0;if((t|0)>=16){break}C=t;w=c[m+(t<<2)>>2]|0}w=p+1|0;if((w|0)<32){j=j+(s<<1)|0;p=w;H=H+64|0}else{break}}i=h;return}function NGa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;pJa(a,b,c,d,e,f,g,h,0);return}function OGa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;pJa(a,b,c,d,e,f,g,h,1);return}function PGa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;pJa(a,b,c,d,e,f,g,h,2);return}function QGa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;pJa(a,b,c,d,e,f,g,h,3);return}function RGa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;q=f;f=g;g=(m|0)!=0|0;r=i+120+(m*20|0)|0;s=c[i+108+(m<<2)>>2]|0;t=h>>>1;h=(c[j+8>>2]|0)==0;if(h){u=k-2-(8>>>(g>>>0))|0}else{u=k}k=(c[j+12>>2]|0)==0;if(k){v=l-2-(4>>>(g>>>0))|0}else{v=l}l=(s|0)!=1;if(l){do{if((c[j>>2]|0)==0){w=0}else{g=c[r>>2]|0;if((v|0)>0){x=0;y=0}else{w=1;break}while(1){z=(e[f+(x<<1)>>1]|0)+g|0;if(z>>>0<512>>>0){A=z&65535}else{A=-z>>31&511}b[q+(x<<1)>>1]=A;z=y+1|0;if((z|0)<(v|0)){x=x+t|0;y=z}else{w=1;break}}}}while(0);do{if(h){B=u}else{y=c[r>>2]|0;x=u-1|0;if((v|0)>0){C=x;D=0}else{B=x;break}while(1){A=(e[f+(C<<1)>>1]|0)+y|0;if(A>>>0<512>>>0){E=A&65535}else{E=-A>>31&511}b[q+(C<<1)>>1]=E;A=D+1|0;if((A|0)<(v|0)){C=C+t|0;D=A}else{B=x;break}}}}while(0);if((s|0)==0){F=0;G=v;H=B;I=w;J=1}else{K=B;L=w;M=17}}else{K=u;L=0;M=17}do{if((M|0)==17){do{if((c[j+4>>2]|0)==0){N=0}else{u=c[r>>2]|0;if((L|0)<(K|0)){O=L}else{N=1;break}while(1){w=(e[f+(O<<1)>>1]|0)+u|0;if(w>>>0<512>>>0){P=w&65535}else{P=-w>>31&511}b[q+(O<<1)>>1]=P;w=O+1|0;if((w|0)<(K|0)){O=w}else{N=1;break}}}}while(0);if(k){F=N;G=v;H=K;I=L;J=0;break}u=c[r>>2]|0;w=v-1|0;B=ca(w,t)|0;if((L|0)<(K|0)){Q=L}else{F=N;G=w;H=K;I=L;J=0;break}while(1){D=Q+B|0;C=(e[f+(D<<1)>>1]|0)+u|0;if(C>>>0<512>>>0){R=C&65535}else{R=-C>>31&511}b[q+(D<<1)>>1]=R;D=Q+1|0;if((D|0)<(K|0)){Q=D}else{F=N;G=w;H=K;I=L;J=0;break}}}}while(0);L=a[612e3+(s<<2)|0]|0;K=a[612002+(s<<2)|0]|0;if((F|0)<(G|0)){N=(I|0)<(H|0);Q=ca(F,t)|0;R=ca((a[612001+(s<<2)|0]|0)+F|0,t)|0;v=ca((a[612003+(s<<2)|0]|0)+F|0,t)|0;r=F;while(1){if(N){k=R+L|0;O=v+K|0;P=I;do{M=P+Q|0;w=b[f+(M<<1)>>1]|0;u=b[f+(k+P<<1)>>1]|0;if((w&65535)>>>0>(u&65535)>>>0){S=3}else{S=((w<<16>>16!=u<<16>>16)<<31>>31)+2|0}u=b[f+(O+P<<1)>>1]|0;if((w&65535)>>>0>(u&65535)>>>0){T=1}else{T=(w<<16>>16!=u<<16>>16)<<31>>31}u=(w&65535)+(c[i+120+(m*20|0)+(d[612016+(T+S)|0]<<2)>>2]|0)|0;if(u>>>0<512>>>0){U=u&65535}else{U=-u>>31&511}b[q+(M<<1)>>1]=U;P=P+1|0;}while((P|0)<(H|0))}P=r+1|0;if((P|0)<(G|0)){Q=Q+t|0;R=R+t|0;v=v+t|0;r=P}else{break}}}r=(s|0)==2;do{if(p<<24>>24==0&r){if((c[j>>2]|0)!=0){V=0;break}V=(c[j+4>>2]|0)==0|0}else{V=0}}while(0);do{if(!(n<<24>>24==0|l^1)){j=V+F|0;if((j|0)<(G|0)){W=j}else{break}do{j=ca(W,t)|0;b[q+(j<<1)>>1]=b[f+(j<<1)>>1]|0;W=W+1|0;}while((W|0)<(G|0))}}while(0);do{if(!(o<<24>>24==0|J)){G=V+I|0;if((G|0)<(H|0)){X=G}else{break}do{b[q+(X<<1)>>1]=b[f+(X<<1)>>1]|0;X=X+1|0;}while((X|0)<(H|0))}}while(0);if(!(p<<24>>24!=0&r)){return}b[q>>1]=b[f>>1]|0;return}function SGa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;l=f;f=g;g=(m|0)!=0|0;q=i+120+(m*20|0)|0;r=c[i+108+(m<<2)>>2]|0;s=h>>>1;h=4>>>(g>>>0);t=-2-h|0;u=(c[j+8>>2]|0)==0;if(u){v=k-2-(8>>>(g>>>0))|0}else{v=k}k=h+2|0;h=ca(t,s)|0;g=(r|0)!=1;do{if(g){do{if((c[j>>2]|0)==0){w=0}else{x=c[q>>2]|0;if((k|0)>0){y=0;z=0}else{w=1;break}while(1){A=y+h|0;B=(e[f+(A<<1)>>1]|0)+x|0;if(B>>>0<512>>>0){C=B&65535}else{C=-B>>31&511}b[l+(A<<1)>>1]=C;A=z+1|0;if((A|0)<(k|0)){y=y+s|0;z=A}else{w=1;break}}}}while(0);if(u){D=w;E=v;F=14;break}x=c[q>>2]|0;A=v-1|0;if((k|0)>0){G=A;H=0}else{I=A;J=w;break}while(1){B=G+h|0;K=(e[f+(B<<1)>>1]|0)+x|0;if(K>>>0<512>>>0){L=K&65535}else{L=-K>>31&511}b[l+(B<<1)>>1]=L;B=H+1|0;if((B|0)<(k|0)){G=G+s|0;H=B}else{D=w;E=A;F=14;break}}}else{D=0;E=v;F=14}}while(0);do{if((F|0)==14){if((k|0)<=0){I=E;J=D;break}v=(D|0)<(E|0);w=(a[612e3+(r<<2)|0]|0)+h|0;H=(a[612002+(r<<2)|0]|0)+h|0;G=0;L=ca(a[612001+(r<<2)|0]|0,s)|0;q=ca(a[612003+(r<<2)|0]|0,s)|0;u=0;while(1){if(v){z=G+h|0;y=w+L|0;C=H+q|0;A=D;do{x=z+A|0;B=b[f+(x<<1)>>1]|0;K=b[f+(y+A<<1)>>1]|0;if((B&65535)>>>0>(K&65535)>>>0){M=3}else{M=((B<<16>>16!=K<<16>>16)<<31>>31)+2|0}K=b[f+(C+A<<1)>>1]|0;if((B&65535)>>>0>(K&65535)>>>0){N=1}else{N=(B<<16>>16!=K<<16>>16)<<31>>31}K=(B&65535)+(c[i+120+(m*20|0)+(d[612016+(N+M)|0]<<2)>>2]|0)|0;if(K>>>0<512>>>0){O=K&65535}else{O=-K>>31&511}b[l+(x<<1)>>1]=O;A=A+1|0;}while((A|0)<(E|0))}A=u+1|0;if((A|0)<(k|0)){G=G+s|0;L=L+s|0;q=q+s|0;u=A}else{I=E;J=D;break}}}}while(0);D=(r|0)==3;if(p<<24>>24==0&D){P=(c[j>>2]|0)==0|0}else{P=0}do{if(!(n<<24>>24==0|g^1)){j=k-P|0;if((j|0)>0){Q=0}else{break}do{E=ca(Q+t|0,s)|0;b[l+(E<<1)>>1]=b[f+(E<<1)>>1]|0;Q=Q+1|0;}while((Q|0)<(j|0))}}while(0);do{if(!(o<<24>>24==0|(r|0)==0)){Q=P+J|0;if((Q|0)<(I|0)){R=Q}else{break}do{Q=R-s|0;b[l+(Q<<1)>>1]=b[f+(Q<<1)>>1]|0;R=R+1|0;}while((R|0)<(I|0))}}while(0);if(!(p<<24>>24!=0&D)){return}D=-s|0;b[l+(D<<1)>>1]=b[f+(D<<1)>>1]|0;return}function TGa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=f;q=g;r=(m|0)!=0|0;s=i+120+(m*20|0)|0;t=c[i+108+(m<<2)>>2]|0;u=h>>>1;h=8>>>(r>>>0);v=-2-h|0;w=h+2|0;h=(c[j+12>>2]|0)==0;if(h){x=l-2-(4>>>(r>>>0))|0}else{x=l}l=(t|0)!=0;do{if(l){do{if((c[j+4>>2]|0)==0){y=0}else{r=c[s>>2]|0;if((w|0)>0){z=0}else{y=1;break}while(1){A=z+v|0;B=(e[q+(A<<1)>>1]|0)+r|0;if(B>>>0<512>>>0){C=B&65535}else{C=-B>>31&511}b[k+(A<<1)>>1]=C;A=z+1|0;if((A|0)<(w|0)){z=A}else{y=1;break}}}}while(0);if(h){D=y;E=x;break}r=c[s>>2]|0;A=x-1|0;if((w|0)<=0){D=y;E=A;break}B=(ca(A,u)|0)+v|0;F=0;while(1){G=B+F|0;H=(e[q+(G<<1)>>1]|0)+r|0;if(H>>>0<512>>>0){I=H&65535}else{I=-H>>31&511}b[k+(G<<1)>>1]=I;G=F+1|0;if((G|0)<(w|0)){F=G}else{D=y;E=A;break}}}else{D=0;E=x}}while(0);if((D|0)<(E|0)){x=(w|0)>0;y=(a[612e3+(t<<2)|0]|0)+v|0;I=(a[612002+(t<<2)|0]|0)+v|0;s=ca(D,u)|0;h=ca((a[612001+(t<<2)|0]|0)+D|0,u)|0;z=ca((a[612003+(t<<2)|0]|0)+D|0,u)|0;C=D;while(1){if(x){A=s+v|0;F=y+h|0;r=I+z|0;B=0;do{G=A+B|0;H=b[q+(G<<1)>>1]|0;J=b[q+(F+B<<1)>>1]|0;if((H&65535)>>>0>(J&65535)>>>0){K=3}else{K=((H<<16>>16!=J<<16>>16)<<31>>31)+2|0}J=b[q+(r+B<<1)>>1]|0;if((H&65535)>>>0>(J&65535)>>>0){L=1}else{L=(H<<16>>16!=J<<16>>16)<<31>>31}J=(H&65535)+(c[i+120+(m*20|0)+(d[612016+(L+K)|0]<<2)>>2]|0)|0;if(J>>>0<512>>>0){M=J&65535}else{M=-J>>31&511}b[k+(G<<1)>>1]=M;B=B+1|0;}while((B|0)<(w|0))}B=C+1|0;if((B|0)<(E|0)){s=s+u|0;h=h+u|0;z=z+u|0;C=B}else{break}}}C=(t|0)==3;if(p<<24>>24==0&C){N=(c[j+4>>2]|0)==0|0}else{N=0}do{if(!(n<<24>>24==0|(t|0)==1)){j=N+D|0;if((j|0)<(E|0)){O=j}else{break}do{j=(ca(O,u)|0)-1|0;b[k+(j<<1)>>1]=b[q+(j<<1)>>1]|0;O=O+1|0;}while((O|0)<(E|0))}}while(0);do{if(!(o<<24>>24==0|l^1)){E=w-N|0;if((E|0)>0){P=0}else{break}do{O=P+v|0;b[k+(O<<1)>>1]=b[q+(O<<1)>>1]|0;P=P+1|0;}while((P|0)<(E|0))}}while(0);if(!(p<<24>>24!=0&C)){return}b[f-2>>1]=b[g-2>>1]|0;return}function UGa(e,f,g,h,i,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;k=e;e=f;f=(l|0)!=0|0;j=c[h+108+(l<<2)>>2]|0;i=g>>>1;g=4>>>(f>>>0);p=8>>>(f>>>0);f=p+2|0;q=g+2|0;r=ca(-2-g|0,i)|0;s=r+(-2-p)|0;if((q|0)>0){t=(f|0)>0;u=(a[612e3+(j<<2)|0]|0)+s|0;v=(a[612002+(j<<2)|0]|0)+s|0;w=0;x=ca(a[612001+(j<<2)|0]|0,i)|0;y=ca(a[612003+(j<<2)|0]|0,i)|0;z=0;while(1){if(t){A=w+s|0;B=u+x|0;C=v+y|0;D=0;do{E=A+D|0;F=b[e+(E<<1)>>1]|0;G=b[e+(B+D<<1)>>1]|0;if((F&65535)>>>0>(G&65535)>>>0){H=3}else{H=((F<<16>>16!=G<<16>>16)<<31>>31)+2|0}G=b[e+(C+D<<1)>>1]|0;if((F&65535)>>>0>(G&65535)>>>0){I=1}else{I=(F<<16>>16!=G<<16>>16)<<31>>31}G=(F&65535)+(c[h+120+(l*20|0)+(d[612016+(I+H)|0]<<2)>>2]|0)|0;if(G>>>0<512>>>0){J=G&65535}else{J=-G>>31&511}b[k+(E<<1)>>1]=J;D=D+1|0;}while((D|0)<(f|0))}D=z+1|0;if((D|0)<(q|0)){w=w+i|0;x=x+i|0;y=y+i|0;z=D}else{break}}}if(o<<24>>24==0){K=(j|0)==2|0}else{K=0}do{if(!(m<<24>>24==0|(j|0)==1)){z=q-K|0;if((z|0)<=0){break}y=r-1|0;x=0;do{w=y+(ca(x,i)|0)|0;b[k+(w<<1)>>1]=b[e+(w<<1)>>1]|0;x=x+1|0;}while((x|0)<(z|0))}}while(0);do{if(!(n<<24>>24==0|(j|0)==0)){r=f-K|0;if((r|0)<=0){break}q=s+(ca(g+1|0,i)|0)|0;m=0;do{z=q+m|0;b[k+(z<<1)>>1]=b[e+(z<<1)>>1]|0;m=m+1|0;}while((m|0)<(r|0))}}while(0);if(!(o<<24>>24!=0&(j|0)==2)){return}j=p+1+(ca(g+1|0,i)|0)+s|0;b[k+(j<<1)>>1]=b[e+(j<<1)>>1]|0;return}function VGa(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;h=e>>>1;if((g|0)>0&(f|0)>0){i=0;j=d;k=a}else{return}while(1){a=0;do{b[k+(a<<1)>>1]=b[j+(a<<1)>>1]<<5;a=a+1|0;}while((a|0)<(f|0));a=i+1|0;if((a|0)<(g|0)){i=a;j=j+(h<<1)|0;k=k+(c<<1)|0}else{break}}return}function WGa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)>0&(g|0)>0){j=0;k=d;l=a}else{return}while(1){a=0;while(1){d=a+1|0;b[l+(a<<1)>>1]=(((e[k+(a-2<<1)>>1]|0)<<2)-(e[k+(a-3<<1)>>1]|0)+((e[k+(a-1<<1)>>1]|0)*-10|0)+((e[k+(a<<1)>>1]|0)*58|0)+((e[k+(d<<1)>>1]|0)*17|0)+((e[k+(a+2<<1)>>1]|0)*-5|0)+(e[k+(a+3<<1)>>1]|0)|0)>>>1;if((d|0)<(g|0)){a=d}else{break}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;l=l+(c<<1)|0}else{break}}return}function XGa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-2<<1)>>1]|0)<<2)-(e[k+(a-3<<1)>>1]|0)+((e[k+(a+3<<1)>>1]|0)<<2)-(e[k+(a+4<<1)>>1]|0)+(((e[k+(l<<1)>>1]|0)+(e[k+(a<<1)>>1]|0)|0)*40|0)+(((e[k+(a+2<<1)>>1]|0)+(e[k+(a-1<<1)>>1]|0)|0)*-11|0)|0)>>>1;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function YGa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-1<<1)>>1]|0)*-5|0)+(e[k+(a-2<<1)>>1]|0)+((e[k+(a<<1)>>1]|0)*17|0)+((e[k+(l<<1)>>1]|0)*58|0)+((e[k+(a+2<<1)>>1]|0)*-10|0)+((e[k+(a+3<<1)>>1]|0)<<2)-(e[k+(a+4<<1)>>1]|0)|0)>>>1;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function ZGa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i*3|0;k=i<<1;l=0;m=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[m+(a-k<<1)>>1]|0)<<2)-(e[m+(a-j<<1)>>1]|0)+((e[m+(a-i<<1)>>1]|0)*-10|0)+((e[m+(a<<1)>>1]|0)*58|0)+((e[m+(a+i<<1)>>1]|0)*17|0)+((e[m+(a+k<<1)>>1]|0)*-5|0)+(e[m+(a+j<<1)>>1]|0)|0)>>>1;a=a+1|0;}while((a|0)<(g|0))}a=l+1|0;if((a|0)<(h|0)){l=a;m=m+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function _Ga(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374929]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374913]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374913]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function $Ga(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374929]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374913]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>1;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374913]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function aHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374929]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374913]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374913]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function bHa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i*3|0;k=i<<1;l=i<<2;m=0;n=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[n+(a-k<<1)>>1]|0)<<2)-(e[n+(a-j<<1)>>1]|0)+((e[n+(a+j<<1)>>1]|0)<<2)-(e[n+(a+l<<1)>>1]|0)+(((e[n+(a+i<<1)>>1]|0)+(e[n+(a<<1)>>1]|0)|0)*40|0)+(((e[n+(a+k<<1)>>1]|0)+(e[n+(a-i<<1)>>1]|0)|0)*-11|0)|0)>>>1;a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function cHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374930]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374914]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374914]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function dHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374930]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374914]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>1;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374914]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function eHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374930]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374914]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374914]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function fHa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i<<1;k=i*3|0;l=i<<2;m=0;n=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[n+(a-i<<1)>>1]|0)*-5|0)+(e[n+(a-j<<1)>>1]|0)+((e[n+(a<<1)>>1]|0)*17|0)+((e[n+(a+i<<1)>>1]|0)*58|0)+((e[n+(a+j<<1)>>1]|0)*-10|0)+((e[n+(a+k<<1)>>1]|0)<<2)-(e[n+(a+l<<1)>>1]|0)|0)>>>1;a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function gHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374931]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374915]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374915]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function hHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374931]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374915]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>1;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374915]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function iHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374931]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374915]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>1;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374915]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function jHa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;j=e>>>1;if((g|0)<=0){return}e=(f|0)>0;i=0;h=d;d=a;while(1){if(e){a=0;do{b[d+(a<<1)>>1]=b[h+(a<<1)>>1]<<5;a=a+1|0;}while((a|0)<(f|0))}a=i+1|0;if((a|0)<(g|0)){i=a;h=h+(j<<1)|0;d=d+(c<<1)|0}else{break}}return}function kHa(c,d,f,g,h,i,j,k,l){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>>1;g=j-1|0;if((i|0)<=0){return}j=(h|0)>0;k=a[1375216+(g<<4)|0]|0;m=a[1375217+(g<<4)|0]|0;n=a[1375218+(g<<4)|0]|0;o=a[1375219+(g<<4)|0]|0;g=f;f=0;p=c;while(1){if(j){c=0;while(1){q=ca(e[g+(c-1<<1)>>1]|0,k)|0;r=(ca(e[g+(c<<1)>>1]|0,m)|0)+q|0;q=c+1|0;s=r+(ca(e[g+(q<<1)>>1]|0,n)|0)|0;b[p+(c<<1)>>1]=(s+(ca(e[g+(c+2<<1)>>1]|0,o)|0)|0)>>>1;if((q|0)<(h|0)){c=q}else{break}}}c=f+1|0;if((c|0)<(i|0)){g=g+(l<<1)|0;f=c;p=p+(d<<1)|0}else{break}}return}function lHa(c,d,f,g,h,i,j,k,l){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>>1;g=k-1|0;if((i|0)<=0){return}k=(h|0)>0;j=a[1375216+(g<<4)|0]|0;m=a[1375217+(g<<4)|0]|0;n=a[1375218+(g<<4)|0]|0;o=a[1375219+(g<<4)|0]|0;g=l<<1;p=f;f=0;q=c;while(1){if(k){c=0;do{r=ca(e[p+(c-l<<1)>>1]|0,j)|0;s=(ca(e[p+(c<<1)>>1]|0,m)|0)+r|0;r=s+(ca(e[p+(c+l<<1)>>1]|0,n)|0)|0;b[q+(c<<1)>>1]=(r+(ca(e[p+(c+g<<1)>>1]|0,o)|0)|0)>>>1;c=c+1|0;}while((c|0)<(h|0))}c=f+1|0;if((c|0)<(i|0)){p=p+(l<<1)|0;f=c;q=q+(d<<1)|0}else{break}}return}function mHa(c,d,e,f,g,h,j,k,l){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=i;i=i+8576|0;m=l|0;n=f>>>1;f=j-1|0;j=k-1|0;k=1375216+(j<<4)|0;o=h+3|0;if((o|0)>0){p=(g|0)>0;q=a[1375216+(f<<4)|0]|0;r=a[1375217+(f<<4)|0]|0;s=a[1375218+(f<<4)|0]|0;t=a[1375219+(f<<4)|0]|0;f=e+(-n<<1)|0;e=0;u=m|0;while(1){if(p){v=0;w=b[f-2>>1]|0;x=b[f>>1]|0;y=b[f+2>>1]|0;while(1){z=v+1|0;A=(ca(x&65535,r)|0)+(ca(w&65535,q)|0)+(ca(y&65535,s)|0)|0;B=b[f+(v+2<<1)>>1]|0;b[u+(v<<1)>>1]=(A+(ca(B&65535,t)|0)|0)>>>1;if((z|0)<(g|0)){v=z;w=x;x=y;y=B}else{break}}}y=e+1|0;if((y|0)<(o|0)){f=f+(n<<1)|0;e=y;u=u+128|0}else{break}}}if((h|0)<=0){i=l;return}u=(g|0)>0;e=a[k]|0;k=a[1375217+(j<<4)|0]|0;n=a[1375218+(j<<4)|0]|0;f=a[1375219+(j<<4)|0]|0;j=0;o=c;c=m+128|0;while(1){if(u){m=0;do{t=ca(b[c+(m-64<<1)>>1]|0,e)|0;s=(ca(b[c+(m<<1)>>1]|0,k)|0)+t|0;t=s+(ca(b[c+(m+64<<1)>>1]|0,n)|0)|0;b[o+(m<<1)>>1]=(t+(ca(b[c+(m+128<<1)>>1]|0,f)|0)|0)>>>6;m=m+1|0;}while((m|0)<(g|0))}m=j+1|0;if((m|0)<(h|0)){j=m;o=o+(d<<1)|0;c=c+128|0}else{break}}i=l;return}function nHa(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c>>>1;if((g|0)<=0){return}c=(f|0)>0;i=a;a=0;j=d;while(1){if(c){d=0;do{k=(b[j+(d<<1)>>1]|0)+16>>5;if(k>>>0<512>>>0){l=k&65535}else{l=-k>>31&511}b[i+(d<<1)>>1]=l;d=d+1|0;}while((d|0)<(f|0))}d=a+1|0;if((d|0)<(g|0)){i=i+(h<<1)|0;a=d;j=j+(e<<1)|0}else{break}}return}function oHa(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=c>>>1;if((h|0)<=0){return}c=(g|0)>0;j=0;k=a;a=e;e=d;while(1){if(c){d=0;do{l=(b[e+(d<<1)>>1]|0)+32+(b[a+(d<<1)>>1]|0)>>6;if(l>>>0<512>>>0){m=l&65535}else{m=-l>>31&511}b[k+(d<<1)>>1]=m;d=d+1|0;}while((d|0)<(g|0))}d=j+1|0;if((d|0)<(h|0)){j=d;k=k+(i<<1)|0;a=a+(f<<1)|0;e=e+(f<<1)|0}else{break}}return}function pHa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=f>>>1;f=a&255;a=f+5|0;l=1<<f+4;f=c<<16>>16;c=d<<16>>16<<1;if((j|0)<=0){return}d=(i|0)>0;m=0;n=e;e=g;while(1){if(d){g=0;do{o=((ca(b[e+(g<<1)>>1]|0,f)|0)+l>>a)+c|0;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[n+(g<<1)>>1]=p;g=g+1|0;}while((g|0)<(i|0))}g=m+1|0;if((g|0)<(j|0)){m=g;n=n+(k<<1)|0;e=e+(h<<1)|0}else{break}}return}function qHa(a,c,d,e,f,g,h,i,j,k,l,m){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0;n=h>>>1;h=a&255;a=c<<16>>16;c=d<<16>>16;if((m|0)<=0){return}d=(l|0)>0;o=((f<<16>>16)+(e<<16>>16)<<1|1)<<h+5;e=h+6|0;h=j;j=0;f=g;g=i;while(1){if(d){i=0;do{p=ca(b[g+(i<<1)>>1]|0,a)|0;q=p+o+(ca(b[h+(i<<1)>>1]|0,c)|0)>>e;if(q>>>0<512>>>0){r=q&65535}else{r=-q>>31&511}b[f+(i<<1)>>1]=r;i=i+1|0;}while((i|0)<(l|0))}i=j+1|0;if((i|0)<(m|0)){h=h+(k<<1)|0;j=i;f=f+(n<<1)|0;g=g+(k<<1)|0}else{break}}return}function rHa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;oJa(a,b,2,c,d,e,f);return}function sHa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;oJa(a,2,b,c,d,e,f);return}function tHa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;nJa(a,b,2,c,d,e);return}function uHa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;nJa(a,2,b,c,d,e);return}function vHa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=e>>>1;if((f|0)<=0){return}e=g+8|0;j=g+16|0;k=g|0;g=32-h|0;l=10-h|0;m=0;n=a;while(1){a=c[j>>2]|0;o=c[k>>2]|0;p=0;q=c[e>>2]|0;do{r=o+(q>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>(g>>>0);r=q+h|0;q=a>>>0>r>>>0?r:a;c[e>>2]=q;b[n+(p<<1)>>1]=s<<l;p=p+1|0;}while((p|0)<(f|0));p=m+1|0;if((p|0)<(f|0)){m=p;n=n+(i<<1)|0}else{break}}return}function wHa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d>>>1;d=c;c=0;g=a;while(1){a=(b[d>>1]|0)+(e[g>>1]|0)|0;if(a>>>0<1024>>>0){h=a&65535}else{h=-a>>31&1023}b[g>>1]=h;a=g+2|0;i=(b[d+2>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){j=i&65535}else{j=-i>>31&1023}b[a>>1]=j;a=g+4|0;i=(b[d+4>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){k=i&65535}else{k=-i>>31&1023}b[a>>1]=k;a=g+6|0;i=(b[d+6>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){l=i&65535}else{l=-i>>31&1023}b[a>>1]=l;a=c+1|0;if((a|0)<4){d=d+8|0;c=a;g=g+(f<<1)|0}else{break}}return}function xHa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d>>>1;d=c;c=0;g=a;while(1){a=(b[d>>1]|0)+(e[g>>1]|0)|0;if(a>>>0<1024>>>0){h=a&65535}else{h=-a>>31&1023}b[g>>1]=h;a=g+2|0;i=(b[d+2>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){j=i&65535}else{j=-i>>31&1023}b[a>>1]=j;a=g+4|0;i=(b[d+4>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){k=i&65535}else{k=-i>>31&1023}b[a>>1]=k;a=g+6|0;i=(b[d+6>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){l=i&65535}else{l=-i>>31&1023}b[a>>1]=l;a=g+8|0;i=(b[d+8>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){m=i&65535}else{m=-i>>31&1023}b[a>>1]=m;a=g+10|0;i=(b[d+10>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){n=i&65535}else{n=-i>>31&1023}b[a>>1]=n;a=g+12|0;i=(b[d+12>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){o=i&65535}else{o=-i>>31&1023}b[a>>1]=o;a=g+14|0;i=(b[d+14>>1]|0)+(e[a>>1]|0)|0;if(i>>>0<1024>>>0){p=i&65535}else{p=-i>>31&1023}b[a>>1]=p;a=c+1|0;if((a|0)<8){d=d+16|0;c=a;g=g+(f<<1)|0}else{break}}return}function yHa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>>1;d=c;c=0;g=a;while(1){a=d;h=0;while(1){i=g+(h<<1)|0;j=(b[a>>1]|0)+(e[i>>1]|0)|0;if(j>>>0<1024>>>0){k=j&65535}else{k=-j>>31&1023}b[i>>1]=k;i=h+1|0;if((i|0)<16){a=a+2|0;h=i}else{break}}h=c+1|0;if((h|0)<16){d=d+32|0;c=h;g=g+(f<<1)|0}else{break}}return}function zHa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>>1;d=c;c=0;g=a;while(1){a=d;h=0;while(1){i=g+(h<<1)|0;j=(b[a>>1]|0)+(e[i>>1]|0)|0;if(j>>>0<1024>>>0){k=j&65535}else{k=-j>>31&1023}b[i>>1]=k;i=h+1|0;if((i|0)<32){a=a+2|0;h=i}else{break}}h=c+1|0;if((h|0)<32){d=d+64|0;c=h;g=g+(f<<1)|0}else{break}}return}function AHa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d>>>1;d=a;a=0;while(1){g=((b[c+(a<<1)>>1]|0)+4>>3)+(e[d>>1]|0)|0;if(g>>>0<1024>>>0){h=g&65535}else{h=-g>>31&1023}b[d>>1]=h;g=d+2|0;i=((b[c+((a|1)<<1)>>1]|0)+4>>3)+(e[g>>1]|0)|0;if(i>>>0<1024>>>0){j=i&65535}else{j=-i>>31&1023}b[g>>1]=j;g=d+4|0;i=((b[c+((a|2)<<1)>>1]|0)+4>>3)+(e[g>>1]|0)|0;if(i>>>0<1024>>>0){k=i&65535}else{k=-i>>31&1023}b[g>>1]=k;g=d+6|0;i=((b[c+((a|3)<<1)>>1]|0)+4>>3)+(e[g>>1]|0)|0;if(i>>>0<1024>>>0){l=i&65535}else{l=-i>>31&1023}b[g>>1]=l;g=a+4|0;if((g|0)<16){d=d+(f<<1)|0;a=g}else{break}}return}function BHa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=a;a=c;g=0;while(1){h=b[a>>1]|0;i=a+16|0;j=b[i>>1]|0;k=j+h|0;l=a+24|0;m=b[l>>1]|0;n=m+j|0;o=h-m|0;p=a+8|0;q=(b[p>>1]|0)*74|0;r=((h-j+m|0)*74|0)+64|0;m=r>>7;if((m+32768|0)>>>0>65535>>>0){s=(r>>31^32767)&65535}else{s=m&65535}b[i>>1]=s;i=(k*29|0)+64+(n*55|0)+q|0;m=i>>7;if((m+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=m&65535}b[a>>1]=t;m=(n*-29|0)+64+(o*55|0)+q|0;n=m>>7;if((n+32768|0)>>>0>65535>>>0){u=(m>>31^32767)&65535}else{u=n&65535}b[p>>1]=u;p=(k*55|0)+64+(o*29|0)-q|0;q=p>>7;if((q+32768|0)>>>0>65535>>>0){v=(p>>31^32767)&65535}else{v=q&65535}b[l>>1]=v;l=g+1|0;if((l|0)<4){a=a+2|0;g=l}else{break}}g=d>>>1;d=f;f=0;a=c;while(1){c=b[a>>1]|0;v=b[a+4>>1]|0;u=v+c|0;t=b[a+6>>1]|0;s=t+v|0;l=c-t|0;q=(b[a+2>>1]|0)*74|0;p=d+4|0;o=((c-v+t|0)*74|0)+512|0;t=o>>10;if((t+32768|0)>>>0>65535>>>0){w=(o>>31^32767)&65535}else{w=t&65535}t=(w<<16>>16)+(e[p>>1]|0)|0;if(t>>>0<1024>>>0){x=t&65535}else{x=-t>>31&1023}b[p>>1]=x;p=(u*29|0)+512+(s*55|0)+q|0;t=p>>10;if((t+32768|0)>>>0>65535>>>0){y=(p>>31^32767)&65535}else{y=t&65535}t=(y<<16>>16)+(e[d>>1]|0)|0;if(t>>>0<1024>>>0){z=t&65535}else{z=-t>>31&1023}b[d>>1]=z;t=d+2|0;p=(s*-29|0)+512+(l*55|0)+q|0;s=p>>10;if((s+32768|0)>>>0>65535>>>0){A=(p>>31^32767)&65535}else{A=s&65535}s=(A<<16>>16)+(e[t>>1]|0)|0;if(s>>>0<1024>>>0){B=s&65535}else{B=-s>>31&1023}b[t>>1]=B;t=d+6|0;s=(u*55|0)+512+(l*29|0)-q|0;q=s>>10;if((q+32768|0)>>>0>65535>>>0){C=(s>>31^32767)&65535}else{C=q&65535}q=(C<<16>>16)+(e[t>>1]|0)|0;if(q>>>0<1024>>>0){D=q&65535}else{D=-q>>31&1023}b[t>>1]=D;t=f+1|0;if((t|0)<4){d=d+(g<<1)|0;f=t;a=a+8|0}else{break}}return}function CHa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=a;a=c;g=0;while(1){h=b[a>>1]<<6;i=a+16|0;j=b[i>>1]|0;k=(j<<6)+h|0;l=(j*-64|0)+h|0;h=a+8|0;j=b[h>>1]|0;m=a+24|0;n=b[m>>1]|0;o=(n*36|0)+(j*83|0)|0;p=(n*-83|0)+(j*36|0)|0;j=k+64+o|0;n=j>>7;if((n+32768|0)>>>0>65535>>>0){q=(j>>31^32767)&65535}else{q=n&65535}b[a>>1]=q;n=l+64+p|0;j=n>>7;if((j+32768|0)>>>0>65535>>>0){r=(n>>31^32767)&65535}else{r=j&65535}b[h>>1]=r;h=l-p+64|0;p=h>>7;if((p+32768|0)>>>0>65535>>>0){s=(h>>31^32767)&65535}else{s=p&65535}b[i>>1]=s;i=k-o+64|0;o=i>>7;if((o+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=o&65535}b[m>>1]=t;m=g+1|0;if((m|0)<4){a=a+2|0;g=m}else{break}}g=d>>>1;d=f;f=0;a=c;while(1){c=b[a>>1]<<6;t=b[a+4>>1]|0;s=(t<<6)+c|0;r=(t*-64|0)+c|0;c=b[a+2>>1]|0;t=b[a+6>>1]|0;q=(t*36|0)+(c*83|0)|0;m=(t*-83|0)+(c*36|0)|0;c=s+512+q|0;t=c>>10;if((t+32768|0)>>>0>65535>>>0){u=(c>>31^32767)&65535}else{u=t&65535}t=(u<<16>>16)+(e[d>>1]|0)|0;if(t>>>0<1024>>>0){v=t&65535}else{v=-t>>31&1023}b[d>>1]=v;t=d+2|0;c=r+512+m|0;o=c>>10;if((o+32768|0)>>>0>65535>>>0){w=(c>>31^32767)&65535}else{w=o&65535}o=(w<<16>>16)+(e[t>>1]|0)|0;if(o>>>0<1024>>>0){x=o&65535}else{x=-o>>31&1023}b[t>>1]=x;t=d+4|0;o=r-m+512|0;m=o>>10;if((m+32768|0)>>>0>65535>>>0){y=(o>>31^32767)&65535}else{y=m&65535}m=(y<<16>>16)+(e[t>>1]|0)|0;if(m>>>0<1024>>>0){z=m&65535}else{z=-m>>31&1023}b[t>>1]=z;t=d+6|0;m=s-q+512|0;q=m>>10;if((q+32768|0)>>>0>65535>>>0){A=(m>>31^32767)&65535}else{A=q&65535}q=(A<<16>>16)+(e[t>>1]|0)|0;if(q>>>0<1024>>>0){B=q&65535}else{B=-q>>31&1023}b[t>>1]=B;t=f+1|0;if((t|0)<4){d=d+(g<<1)|0;f=t;a=a+8|0}else{break}}return}function DHa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=a;a=j;n=h|0;o=h+4|0;p=h+8|0;q=h+12|0;r=d;s=0;while(1){mrc(a|0,0,16)|0;t=r+16|0;u=r+48|0;v=r+80|0;w=r+112|0;x=((b[w>>1]|0)*18|0)+(((b[v>>1]|0)*50|0)+(((b[u>>1]|0)*75|0)+((b[t>>1]|0)*89|0)))|0;c[j>>2]=x;c[j+4>>2]=((b[w>>1]|0)*-50|0)+(((b[v>>1]|0)*-89|0)+(((b[u>>1]|0)*-18|0)+((b[t>>1]|0)*75|0)));c[j+8>>2]=((b[w>>1]|0)*75|0)+(((b[v>>1]|0)*18|0)+(((b[u>>1]|0)*-89|0)+((b[t>>1]|0)*50|0)));c[j+12>>2]=((b[w>>1]|0)*-89|0)+(((b[v>>1]|0)*75|0)+(((b[u>>1]|0)*-50|0)+((b[t>>1]|0)*18|0)));t=b[r>>1]<<6;u=b[r+64>>1]|0;v=(u<<6)+t|0;w=(u*-64|0)+t|0;t=b[r+32>>1]|0;u=b[r+96>>1]|0;y=(u*36|0)+(t*83|0)|0;z=(u*-83|0)+(t*36|0)|0;t=y+v|0;c[n>>2]=t;c[o>>2]=z+w;c[p>>2]=w-z;c[q>>2]=v-y;y=0;v=t;t=x;while(1){x=v+64+t|0;z=x>>7;if((z+32768|0)>>>0>65535>>>0){A=(x>>31^32767)&65535}else{A=z&65535}b[r+(y<<3<<1)>>1]=A;z=v-t+64|0;x=z>>7;if((x+32768|0)>>>0>65535>>>0){B=(z>>31^32767)&65535}else{B=x&65535}b[r+(7-y<<3<<1)>>1]=B;x=y+1|0;if((x|0)>=4){break}y=x;v=c[h+(x<<2)>>2]|0;t=c[j+(x<<2)>>2]|0}t=s+1|0;if((t|0)<8){r=r+2|0;s=t}else{break}}s=f>>>1;f=l;r=k|0;j=k+4|0;h=k+8|0;B=k+12|0;A=m;m=0;q=d;while(1){mrc(f|0,0,16)|0;d=q+2|0;p=q+6|0;o=q+10|0;n=q+14|0;a=((b[n>>1]|0)*18|0)+(((b[o>>1]|0)*50|0)+(((b[p>>1]|0)*75|0)+((b[d>>1]|0)*89|0)))|0;c[l>>2]=a;c[l+4>>2]=((b[n>>1]|0)*-50|0)+(((b[o>>1]|0)*-89|0)+(((b[p>>1]|0)*-18|0)+((b[d>>1]|0)*75|0)));c[l+8>>2]=((b[n>>1]|0)*75|0)+(((b[o>>1]|0)*18|0)+(((b[p>>1]|0)*-89|0)+((b[d>>1]|0)*50|0)));c[l+12>>2]=((b[n>>1]|0)*-89|0)+(((b[o>>1]|0)*75|0)+(((b[p>>1]|0)*-50|0)+((b[d>>1]|0)*18|0)));d=b[q>>1]<<6;p=b[q+8>>1]|0;o=(p<<6)+d|0;n=(p*-64|0)+d|0;d=b[q+4>>1]|0;p=b[q+12>>1]|0;t=(p*36|0)+(d*83|0)|0;v=(p*-83|0)+(d*36|0)|0;d=t+o|0;c[r>>2]=d;c[j>>2]=v+n;c[h>>2]=n-v;c[B>>2]=o-t;t=0;o=d;d=a;while(1){a=A+(t<<1)|0;v=o+512+d|0;n=v>>10;if((n+32768|0)>>>0>65535>>>0){C=(v>>31^32767)&65535}else{C=n&65535}n=(C<<16>>16)+(e[a>>1]|0)|0;if(n>>>0<1024>>>0){D=n&65535}else{D=-n>>31&1023}b[a>>1]=D;a=A+(7-t<<1)|0;n=o-d+512|0;v=n>>10;if((v+32768|0)>>>0>65535>>>0){E=(n>>31^32767)&65535}else{E=v&65535}v=(E<<16>>16)+(e[a>>1]|0)|0;if(v>>>0<1024>>>0){F=v&65535}else{F=-v>>31&1023}b[a>>1]=F;a=t+1|0;if((a|0)>=4){break}t=a;o=c[k+(a<<2)>>2]|0;d=c[l+(a<<2)>>2]|0}d=m+1|0;if((d|0)<8){A=A+(s<<1)|0;m=d;q=q+16|0}else{break}}i=g;return}function EHa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+128|0;j=h|0;k=h+32|0;l=h+64|0;m=h+96|0;n=d;d=k;o=f;p=0;while(1){mrc(d|0,0,32)|0;q=0;do{r=k+(q<<2)|0;s=(ca(b[o+32>>1]|0,a[305952+q|0]|0)|0)+(c[r>>2]|0)|0;t=(ca(b[o+96>>1]|0,a[306080+q|0]|0)|0)+s|0;s=(ca(b[o+160>>1]|0,a[306208+q|0]|0)|0)+t|0;t=(ca(b[o+224>>1]|0,a[306336+q|0]|0)|0)+s|0;s=(ca(b[o+288>>1]|0,a[306464+q|0]|0)|0)+t|0;t=(ca(b[o+352>>1]|0,a[306592+q|0]|0)|0)+s|0;s=(ca(b[o+416>>1]|0,a[306720+q|0]|0)|0)+t|0;c[r>>2]=(ca(b[o+480>>1]|0,a[306848+q|0]|0)|0)+s;q=q+1|0;}while((q|0)<8);q=o+64|0;s=o+192|0;r=o+320|0;t=o+448|0;u=((b[t>>1]|0)*18|0)+(((b[r>>1]|0)*50|0)+(((b[s>>1]|0)*75|0)+((b[q>>1]|0)*89|0)))|0;v=((b[t>>1]|0)*-50|0)+(((b[r>>1]|0)*-89|0)+(((b[s>>1]|0)*-18|0)+((b[q>>1]|0)*75|0)))|0;w=((b[t>>1]|0)*75|0)+(((b[r>>1]|0)*18|0)+(((b[s>>1]|0)*-89|0)+((b[q>>1]|0)*50|0)))|0;x=((b[t>>1]|0)*-89|0)+(((b[r>>1]|0)*75|0)+(((b[s>>1]|0)*-50|0)+((b[q>>1]|0)*18|0)))|0;q=b[o>>1]<<6;s=b[o+256>>1]|0;r=(s<<6)+q|0;t=(s*-64|0)+q|0;q=b[o+128>>1]|0;s=b[o+384>>1]|0;y=(s*36|0)+(q*83|0)|0;z=(s*-83|0)+(q*36|0)|0;q=y+r|0;s=z+t|0;A=t-z|0;z=r-y|0;y=u+q|0;c[j>>2]=y;c[j+28>>2]=q-u;c[j+4>>2]=v+s;c[j+24>>2]=s-v;c[j+8>>2]=w+A;c[j+20>>2]=A-w;c[j+12>>2]=x+z;c[j+16>>2]=z-x;x=0;z=y;while(1){y=c[k+(x<<2)>>2]|0;w=z+64+y|0;A=w>>7;if((A+32768|0)>>>0>65535>>>0){B=(w>>31^32767)&65535}else{B=A&65535}b[o+(x<<4<<1)>>1]=B;A=z-y+64|0;y=A>>7;if((y+32768|0)>>>0>65535>>>0){C=(A>>31^32767)&65535}else{C=y&65535}b[o+(15-x<<4<<1)>>1]=C;y=x+1|0;if((y|0)>=8){break}x=y;z=c[j+(y<<2)>>2]|0}z=p+1|0;if((z|0)<16){o=o+2|0;p=z}else{break}}p=g>>>1;g=m;o=n;n=0;j=f;while(1){mrc(g|0,0,32)|0;f=0;do{C=m+(f<<2)|0;B=(ca(b[j+2>>1]|0,a[305952+f|0]|0)|0)+(c[C>>2]|0)|0;k=(ca(b[j+6>>1]|0,a[306080+f|0]|0)|0)+B|0;B=(ca(b[j+10>>1]|0,a[306208+f|0]|0)|0)+k|0;k=(ca(b[j+14>>1]|0,a[306336+f|0]|0)|0)+B|0;B=(ca(b[j+18>>1]|0,a[306464+f|0]|0)|0)+k|0;k=(ca(b[j+22>>1]|0,a[306592+f|0]|0)|0)+B|0;B=(ca(b[j+26>>1]|0,a[306720+f|0]|0)|0)+k|0;c[C>>2]=(ca(b[j+30>>1]|0,a[306848+f|0]|0)|0)+B;f=f+1|0;}while((f|0)<8);f=j+4|0;B=j+12|0;C=j+20|0;k=j+28|0;d=((b[k>>1]|0)*18|0)+(((b[C>>1]|0)*50|0)+(((b[B>>1]|0)*75|0)+((b[f>>1]|0)*89|0)))|0;z=((b[k>>1]|0)*-50|0)+(((b[C>>1]|0)*-89|0)+(((b[B>>1]|0)*-18|0)+((b[f>>1]|0)*75|0)))|0;x=((b[k>>1]|0)*75|0)+(((b[C>>1]|0)*18|0)+(((b[B>>1]|0)*-89|0)+((b[f>>1]|0)*50|0)))|0;y=((b[k>>1]|0)*-89|0)+(((b[C>>1]|0)*75|0)+(((b[B>>1]|0)*-50|0)+((b[f>>1]|0)*18|0)))|0;f=b[j>>1]<<6;B=b[j+16>>1]|0;C=(B<<6)+f|0;k=(B*-64|0)+f|0;f=b[j+8>>1]|0;B=b[j+24>>1]|0;A=(B*36|0)+(f*83|0)|0;w=(B*-83|0)+(f*36|0)|0;f=A+C|0;B=w+k|0;v=k-w|0;w=C-A|0;A=d+f|0;c[l>>2]=A;c[l+28>>2]=f-d;c[l+4>>2]=z+B;c[l+24>>2]=B-z;c[l+8>>2]=x+v;c[l+20>>2]=v-x;c[l+12>>2]=y+w;c[l+16>>2]=w-y;y=0;w=A;while(1){A=o+(y<<1)|0;x=c[m+(y<<2)>>2]|0;v=w+512+x|0;z=v>>10;if((z+32768|0)>>>0>65535>>>0){D=(v>>31^32767)&65535}else{D=z&65535}z=(D<<16>>16)+(e[A>>1]|0)|0;if(z>>>0<1024>>>0){E=z&65535}else{E=-z>>31&1023}b[A>>1]=E;A=o+(15-y<<1)|0;z=w-x+512|0;x=z>>10;if((x+32768|0)>>>0>65535>>>0){F=(z>>31^32767)&65535}else{F=x&65535}x=(F<<16>>16)+(e[A>>1]|0)|0;if(x>>>0<1024>>>0){G=x&65535}else{G=-x>>31&1023}b[A>>1]=G;A=y+1|0;if((A|0)>=8){break}y=A;w=c[l+(A<<2)>>2]|0}w=n+1|0;if((w|0)<16){o=o+(p<<1)|0;n=w;j=j+32|0}else{break}}i=h;return}function FHa(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+320|0;j=h|0;k=h+64|0;l=h+128|0;m=h+160|0;n=h+224|0;o=h+288|0;p=d;d=k;q=l;r=f;s=0;while(1){mrc(d|0,0,64)|0;t=0;do{u=k+(t<<2)|0;v=1;w=c[u>>2]|0;do{w=(ca(b[r+(v<<5<<1)>>1]|0,a[305888+(v<<5)+t|0]|0)|0)+w|0;v=v+2|0;}while((v|0)<32);c[u>>2]=w;t=t+1|0;}while((t|0)<16);mrc(q|0,0,32)|0;t=0;v=0;while(1){x=(ca(b[r+128>>1]|0,a[305952+t|0]|0)|0)+v|0;y=(ca(b[r+384>>1]|0,a[306080+t|0]|0)|0)+x|0;x=(ca(b[r+640>>1]|0,a[306208+t|0]|0)|0)+y|0;y=(ca(b[r+896>>1]|0,a[306336+t|0]|0)|0)+x|0;x=(ca(b[r+1152>>1]|0,a[306464+t|0]|0)|0)+y|0;y=(ca(b[r+1408>>1]|0,a[306592+t|0]|0)|0)+x|0;x=(ca(b[r+1664>>1]|0,a[306720+t|0]|0)|0)+y|0;c[l+(t<<2)>>2]=(ca(b[r+1920>>1]|0,a[306848+t|0]|0)|0)+x;x=t+1|0;if((x|0)>=8){break}t=x;v=c[l+(x<<2)>>2]|0}v=r+256|0;t=r+768|0;x=r+1280|0;y=r+1792|0;z=((b[y>>1]|0)*18|0)+(((b[x>>1]|0)*50|0)+(((b[t>>1]|0)*75|0)+((b[v>>1]|0)*89|0)))|0;A=((b[y>>1]|0)*-50|0)+(((b[x>>1]|0)*-89|0)+(((b[t>>1]|0)*-18|0)+((b[v>>1]|0)*75|0)))|0;B=((b[y>>1]|0)*75|0)+(((b[x>>1]|0)*18|0)+(((b[t>>1]|0)*-89|0)+((b[v>>1]|0)*50|0)))|0;C=((b[y>>1]|0)*-89|0)+(((b[x>>1]|0)*75|0)+(((b[t>>1]|0)*-50|0)+((b[v>>1]|0)*18|0)))|0;v=b[r>>1]<<6;t=b[r+1024>>1]|0;x=(t<<6)+v|0;y=(t*-64|0)+v|0;v=b[r+512>>1]|0;t=b[r+1536>>1]|0;D=(t*36|0)+(v*83|0)|0;E=(t*-83|0)+(v*36|0)|0;v=D+x|0;t=E+y|0;F=y-E|0;E=x-D|0;D=z+v|0;x=v-z|0;z=A+t|0;v=t-A|0;A=B+F|0;t=F-B|0;B=C+E|0;F=E-C|0;C=c[l>>2]|0;E=C+D|0;c[j>>2]=E;c[j+60>>2]=D-C;C=c[l+4>>2]|0;c[j+4>>2]=C+z;c[j+56>>2]=z-C;C=c[l+8>>2]|0;c[j+8>>2]=C+A;c[j+52>>2]=A-C;C=c[l+12>>2]|0;c[j+12>>2]=C+B;c[j+48>>2]=B-C;C=c[l+16>>2]|0;c[j+16>>2]=C+F;c[j+44>>2]=F-C;C=c[l+20>>2]|0;c[j+20>>2]=C+t;c[j+40>>2]=t-C;C=c[l+24>>2]|0;c[j+24>>2]=C+v;c[j+36>>2]=v-C;C=c[l+28>>2]|0;c[j+28>>2]=C+x;c[j+32>>2]=x-C;C=0;x=E;while(1){E=c[k+(C<<2)>>2]|0;v=x+64+E|0;t=v>>7;if((t+32768|0)>>>0>65535>>>0){G=(v>>31^32767)&65535}else{G=t&65535}b[r+(C<<5<<1)>>1]=G;t=x-E+64|0;E=t>>7;if((E+32768|0)>>>0>65535>>>0){H=(t>>31^32767)&65535}else{H=E&65535}b[r+(31-C<<5<<1)>>1]=H;E=C+1|0;if((E|0)>=16){break}C=E;x=c[j+(E<<2)>>2]|0}x=s+1|0;if((x|0)<32){r=r+2|0;s=x}else{break}}s=g>>>1;g=n;r=o;j=p;p=0;H=f;while(1){mrc(g|0,0,64)|0;f=0;do{G=n+(f<<2)|0;k=1;l=c[G>>2]|0;do{l=(ca(b[H+(k<<1)>>1]|0,a[305888+(k<<5)+f|0]|0)|0)+l|0;k=k+2|0;}while((k|0)<32);c[G>>2]=l;f=f+1|0;}while((f|0)<16);mrc(r|0,0,32)|0;f=0;k=0;while(1){w=(ca(b[H+4>>1]|0,a[305952+f|0]|0)|0)+k|0;u=(ca(b[H+12>>1]|0,a[306080+f|0]|0)|0)+w|0;w=(ca(b[H+20>>1]|0,a[306208+f|0]|0)|0)+u|0;u=(ca(b[H+28>>1]|0,a[306336+f|0]|0)|0)+w|0;w=(ca(b[H+36>>1]|0,a[306464+f|0]|0)|0)+u|0;u=(ca(b[H+44>>1]|0,a[306592+f|0]|0)|0)+w|0;w=(ca(b[H+52>>1]|0,a[306720+f|0]|0)|0)+u|0;c[o+(f<<2)>>2]=(ca(b[H+60>>1]|0,a[306848+f|0]|0)|0)+w;w=f+1|0;if((w|0)>=8){break}f=w;k=c[o+(w<<2)>>2]|0}k=H+8|0;f=H+24|0;w=H+40|0;u=H+56|0;q=((b[u>>1]|0)*18|0)+(((b[w>>1]|0)*50|0)+(((b[f>>1]|0)*75|0)+((b[k>>1]|0)*89|0)))|0;d=((b[u>>1]|0)*-50|0)+(((b[w>>1]|0)*-89|0)+(((b[f>>1]|0)*-18|0)+((b[k>>1]|0)*75|0)))|0;x=((b[u>>1]|0)*75|0)+(((b[w>>1]|0)*18|0)+(((b[f>>1]|0)*-89|0)+((b[k>>1]|0)*50|0)))|0;C=((b[u>>1]|0)*-89|0)+(((b[w>>1]|0)*75|0)+(((b[f>>1]|0)*-50|0)+((b[k>>1]|0)*18|0)))|0;k=b[H>>1]<<6;f=b[H+32>>1]|0;w=(f<<6)+k|0;u=(f*-64|0)+k|0;k=b[H+16>>1]|0;f=b[H+48>>1]|0;E=(f*36|0)+(k*83|0)|0;t=(f*-83|0)+(k*36|0)|0;k=E+w|0;f=t+u|0;v=u-t|0;t=w-E|0;E=q+k|0;w=k-q|0;q=d+f|0;k=f-d|0;d=x+v|0;f=v-x|0;x=C+t|0;v=t-C|0;C=c[o>>2]|0;t=C+E|0;c[m>>2]=t;c[m+60>>2]=E-C;C=c[o+4>>2]|0;c[m+4>>2]=C+q;c[m+56>>2]=q-C;C=c[o+8>>2]|0;c[m+8>>2]=C+d;c[m+52>>2]=d-C;C=c[o+12>>2]|0;c[m+12>>2]=C+x;c[m+48>>2]=x-C;C=c[o+16>>2]|0;c[m+16>>2]=C+v;c[m+44>>2]=v-C;C=c[o+20>>2]|0;c[m+20>>2]=C+f;c[m+40>>2]=f-C;C=c[o+24>>2]|0;c[m+24>>2]=C+k;c[m+36>>2]=k-C;C=c[o+28>>2]|0;c[m+28>>2]=C+w;c[m+32>>2]=w-C;C=0;w=t;while(1){t=j+(C<<1)|0;k=c[n+(C<<2)>>2]|0;f=w+512+k|0;v=f>>10;if((v+32768|0)>>>0>65535>>>0){I=(f>>31^32767)&65535}else{I=v&65535}v=(I<<16>>16)+(e[t>>1]|0)|0;if(v>>>0<1024>>>0){J=v&65535}else{J=-v>>31&1023}b[t>>1]=J;t=j+(31-C<<1)|0;v=w-k+512|0;k=v>>10;if((k+32768|0)>>>0>65535>>>0){K=(v>>31^32767)&65535}else{K=k&65535}k=(K<<16>>16)+(e[t>>1]|0)|0;if(k>>>0<1024>>>0){L=k&65535}else{L=-k>>31&1023}b[t>>1]=L;t=C+1|0;if((t|0)>=16){break}C=t;w=c[m+(t<<2)>>2]|0}w=p+1|0;if((w|0)<32){j=j+(s<<1)|0;p=w;H=H+64|0}else{break}}i=h;return}function GHa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;mJa(a,b,c,d,e,f,g,h,0);return}function HHa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;mJa(a,b,c,d,e,f,g,h,1);return}function IHa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;mJa(a,b,c,d,e,f,g,h,2);return}function JHa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;mJa(a,b,c,d,e,f,g,h,3);return}function KHa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;q=f;f=g;g=(m|0)!=0|0;r=i+120+(m*20|0)|0;s=c[i+108+(m<<2)>>2]|0;t=h>>>1;h=(c[j+8>>2]|0)==0;if(h){u=k-2-(8>>>(g>>>0))|0}else{u=k}k=(c[j+12>>2]|0)==0;if(k){v=l-2-(4>>>(g>>>0))|0}else{v=l}l=(s|0)!=1;if(l){do{if((c[j>>2]|0)==0){w=0}else{g=c[r>>2]|0;if((v|0)>0){x=0;y=0}else{w=1;break}while(1){z=(e[f+(x<<1)>>1]|0)+g|0;if(z>>>0<1024>>>0){A=z&65535}else{A=-z>>31&1023}b[q+(x<<1)>>1]=A;z=y+1|0;if((z|0)<(v|0)){x=x+t|0;y=z}else{w=1;break}}}}while(0);do{if(h){B=u}else{y=c[r>>2]|0;x=u-1|0;if((v|0)>0){C=x;D=0}else{B=x;break}while(1){A=(e[f+(C<<1)>>1]|0)+y|0;if(A>>>0<1024>>>0){E=A&65535}else{E=-A>>31&1023}b[q+(C<<1)>>1]=E;A=D+1|0;if((A|0)<(v|0)){C=C+t|0;D=A}else{B=x;break}}}}while(0);if((s|0)==0){F=0;G=v;H=B;I=w;J=1}else{K=B;L=w;M=17}}else{K=u;L=0;M=17}do{if((M|0)==17){do{if((c[j+4>>2]|0)==0){N=0}else{u=c[r>>2]|0;if((L|0)<(K|0)){O=L}else{N=1;break}while(1){w=(e[f+(O<<1)>>1]|0)+u|0;if(w>>>0<1024>>>0){P=w&65535}else{P=-w>>31&1023}b[q+(O<<1)>>1]=P;w=O+1|0;if((w|0)<(K|0)){O=w}else{N=1;break}}}}while(0);if(k){F=N;G=v;H=K;I=L;J=0;break}u=c[r>>2]|0;w=v-1|0;B=ca(w,t)|0;if((L|0)<(K|0)){Q=L}else{F=N;G=w;H=K;I=L;J=0;break}while(1){D=Q+B|0;C=(e[f+(D<<1)>>1]|0)+u|0;if(C>>>0<1024>>>0){R=C&65535}else{R=-C>>31&1023}b[q+(D<<1)>>1]=R;D=Q+1|0;if((D|0)<(K|0)){Q=D}else{F=N;G=w;H=K;I=L;J=0;break}}}}while(0);L=a[612e3+(s<<2)|0]|0;K=a[612002+(s<<2)|0]|0;if((F|0)<(G|0)){N=(I|0)<(H|0);Q=ca(F,t)|0;R=ca((a[612001+(s<<2)|0]|0)+F|0,t)|0;v=ca((a[612003+(s<<2)|0]|0)+F|0,t)|0;r=F;while(1){if(N){k=R+L|0;O=v+K|0;P=I;do{M=P+Q|0;w=b[f+(M<<1)>>1]|0;u=b[f+(k+P<<1)>>1]|0;if((w&65535)>>>0>(u&65535)>>>0){S=3}else{S=((w<<16>>16!=u<<16>>16)<<31>>31)+2|0}u=b[f+(O+P<<1)>>1]|0;if((w&65535)>>>0>(u&65535)>>>0){T=1}else{T=(w<<16>>16!=u<<16>>16)<<31>>31}u=(w&65535)+(c[i+120+(m*20|0)+(d[612016+(T+S)|0]<<2)>>2]|0)|0;if(u>>>0<1024>>>0){U=u&65535}else{U=-u>>31&1023}b[q+(M<<1)>>1]=U;P=P+1|0;}while((P|0)<(H|0))}P=r+1|0;if((P|0)<(G|0)){Q=Q+t|0;R=R+t|0;v=v+t|0;r=P}else{break}}}r=(s|0)==2;do{if(p<<24>>24==0&r){if((c[j>>2]|0)!=0){V=0;break}V=(c[j+4>>2]|0)==0|0}else{V=0}}while(0);do{if(!(n<<24>>24==0|l^1)){j=V+F|0;if((j|0)<(G|0)){W=j}else{break}do{j=ca(W,t)|0;b[q+(j<<1)>>1]=b[f+(j<<1)>>1]|0;W=W+1|0;}while((W|0)<(G|0))}}while(0);do{if(!(o<<24>>24==0|J)){G=V+I|0;if((G|0)<(H|0)){X=G}else{break}do{b[q+(X<<1)>>1]=b[f+(X<<1)>>1]|0;X=X+1|0;}while((X|0)<(H|0))}}while(0);if(!(p<<24>>24!=0&r)){return}b[q>>1]=b[f>>1]|0;return}function LHa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;l=f;f=g;g=(m|0)!=0|0;q=i+120+(m*20|0)|0;r=c[i+108+(m<<2)>>2]|0;s=h>>>1;h=4>>>(g>>>0);t=-2-h|0;u=(c[j+8>>2]|0)==0;if(u){v=k-2-(8>>>(g>>>0))|0}else{v=k}k=h+2|0;h=ca(t,s)|0;g=(r|0)!=1;do{if(g){do{if((c[j>>2]|0)==0){w=0}else{x=c[q>>2]|0;if((k|0)>0){y=0;z=0}else{w=1;break}while(1){A=y+h|0;B=(e[f+(A<<1)>>1]|0)+x|0;if(B>>>0<1024>>>0){C=B&65535}else{C=-B>>31&1023}b[l+(A<<1)>>1]=C;A=z+1|0;if((A|0)<(k|0)){y=y+s|0;z=A}else{w=1;break}}}}while(0);if(u){D=w;E=v;F=14;break}x=c[q>>2]|0;A=v-1|0;if((k|0)>0){G=A;H=0}else{I=A;J=w;break}while(1){B=G+h|0;K=(e[f+(B<<1)>>1]|0)+x|0;if(K>>>0<1024>>>0){L=K&65535}else{L=-K>>31&1023}b[l+(B<<1)>>1]=L;B=H+1|0;if((B|0)<(k|0)){G=G+s|0;H=B}else{D=w;E=A;F=14;break}}}else{D=0;E=v;F=14}}while(0);do{if((F|0)==14){if((k|0)<=0){I=E;J=D;break}v=(D|0)<(E|0);w=(a[612e3+(r<<2)|0]|0)+h|0;H=(a[612002+(r<<2)|0]|0)+h|0;G=0;L=ca(a[612001+(r<<2)|0]|0,s)|0;q=ca(a[612003+(r<<2)|0]|0,s)|0;u=0;while(1){if(v){z=G+h|0;y=w+L|0;C=H+q|0;A=D;do{x=z+A|0;B=b[f+(x<<1)>>1]|0;K=b[f+(y+A<<1)>>1]|0;if((B&65535)>>>0>(K&65535)>>>0){M=3}else{M=((B<<16>>16!=K<<16>>16)<<31>>31)+2|0}K=b[f+(C+A<<1)>>1]|0;if((B&65535)>>>0>(K&65535)>>>0){N=1}else{N=(B<<16>>16!=K<<16>>16)<<31>>31}K=(B&65535)+(c[i+120+(m*20|0)+(d[612016+(N+M)|0]<<2)>>2]|0)|0;if(K>>>0<1024>>>0){O=K&65535}else{O=-K>>31&1023}b[l+(x<<1)>>1]=O;A=A+1|0;}while((A|0)<(E|0))}A=u+1|0;if((A|0)<(k|0)){G=G+s|0;L=L+s|0;q=q+s|0;u=A}else{I=E;J=D;break}}}}while(0);D=(r|0)==3;if(p<<24>>24==0&D){P=(c[j>>2]|0)==0|0}else{P=0}do{if(!(n<<24>>24==0|g^1)){j=k-P|0;if((j|0)>0){Q=0}else{break}do{E=ca(Q+t|0,s)|0;b[l+(E<<1)>>1]=b[f+(E<<1)>>1]|0;Q=Q+1|0;}while((Q|0)<(j|0))}}while(0);do{if(!(o<<24>>24==0|(r|0)==0)){Q=P+J|0;if((Q|0)<(I|0)){R=Q}else{break}do{Q=R-s|0;b[l+(Q<<1)>>1]=b[f+(Q<<1)>>1]|0;R=R+1|0;}while((R|0)<(I|0))}}while(0);if(!(p<<24>>24!=0&D)){return}D=-s|0;b[l+(D<<1)>>1]=b[f+(D<<1)>>1]|0;return}function MHa(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=f;q=g;r=(m|0)!=0|0;s=i+120+(m*20|0)|0;t=c[i+108+(m<<2)>>2]|0;u=h>>>1;h=8>>>(r>>>0);v=-2-h|0;w=h+2|0;h=(c[j+12>>2]|0)==0;if(h){x=l-2-(4>>>(r>>>0))|0}else{x=l}l=(t|0)!=0;do{if(l){do{if((c[j+4>>2]|0)==0){y=0}else{r=c[s>>2]|0;if((w|0)>0){z=0}else{y=1;break}while(1){A=z+v|0;B=(e[q+(A<<1)>>1]|0)+r|0;if(B>>>0<1024>>>0){C=B&65535}else{C=-B>>31&1023}b[k+(A<<1)>>1]=C;A=z+1|0;if((A|0)<(w|0)){z=A}else{y=1;break}}}}while(0);if(h){D=y;E=x;break}r=c[s>>2]|0;A=x-1|0;if((w|0)<=0){D=y;E=A;break}B=(ca(A,u)|0)+v|0;F=0;while(1){G=B+F|0;H=(e[q+(G<<1)>>1]|0)+r|0;if(H>>>0<1024>>>0){I=H&65535}else{I=-H>>31&1023}b[k+(G<<1)>>1]=I;G=F+1|0;if((G|0)<(w|0)){F=G}else{D=y;E=A;break}}}else{D=0;E=x}}while(0);if((D|0)<(E|0)){x=(w|0)>0;y=(a[612e3+(t<<2)|0]|0)+v|0;I=(a[612002+(t<<2)|0]|0)+v|0;s=ca(D,u)|0;h=ca((a[612001+(t<<2)|0]|0)+D|0,u)|0;z=ca((a[612003+(t<<2)|0]|0)+D|0,u)|0;C=D;while(1){if(x){A=s+v|0;F=y+h|0;r=I+z|0;B=0;do{G=A+B|0;H=b[q+(G<<1)>>1]|0;J=b[q+(F+B<<1)>>1]|0;if((H&65535)>>>0>(J&65535)>>>0){K=3}else{K=((H<<16>>16!=J<<16>>16)<<31>>31)+2|0}J=b[q+(r+B<<1)>>1]|0;if((H&65535)>>>0>(J&65535)>>>0){L=1}else{L=(H<<16>>16!=J<<16>>16)<<31>>31}J=(H&65535)+(c[i+120+(m*20|0)+(d[612016+(L+K)|0]<<2)>>2]|0)|0;if(J>>>0<1024>>>0){M=J&65535}else{M=-J>>31&1023}b[k+(G<<1)>>1]=M;B=B+1|0;}while((B|0)<(w|0))}B=C+1|0;if((B|0)<(E|0)){s=s+u|0;h=h+u|0;z=z+u|0;C=B}else{break}}}C=(t|0)==3;if(p<<24>>24==0&C){N=(c[j+4>>2]|0)==0|0}else{N=0}do{if(!(n<<24>>24==0|(t|0)==1)){j=N+D|0;if((j|0)<(E|0)){O=j}else{break}do{j=(ca(O,u)|0)-1|0;b[k+(j<<1)>>1]=b[q+(j<<1)>>1]|0;O=O+1|0;}while((O|0)<(E|0))}}while(0);do{if(!(o<<24>>24==0|l^1)){E=w-N|0;if((E|0)>0){P=0}else{break}do{O=P+v|0;b[k+(O<<1)>>1]=b[q+(O<<1)>>1]|0;P=P+1|0;}while((P|0)<(E|0))}}while(0);if(!(p<<24>>24!=0&C)){return}b[f-2>>1]=b[g-2>>1]|0;return}function NHa(e,f,g,h,i,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;k=e;e=f;f=(l|0)!=0|0;j=c[h+108+(l<<2)>>2]|0;i=g>>>1;g=4>>>(f>>>0);p=8>>>(f>>>0);f=p+2|0;q=g+2|0;r=ca(-2-g|0,i)|0;s=r+(-2-p)|0;if((q|0)>0){t=(f|0)>0;u=(a[612e3+(j<<2)|0]|0)+s|0;v=(a[612002+(j<<2)|0]|0)+s|0;w=0;x=ca(a[612001+(j<<2)|0]|0,i)|0;y=ca(a[612003+(j<<2)|0]|0,i)|0;z=0;while(1){if(t){A=w+s|0;B=u+x|0;C=v+y|0;D=0;do{E=A+D|0;F=b[e+(E<<1)>>1]|0;G=b[e+(B+D<<1)>>1]|0;if((F&65535)>>>0>(G&65535)>>>0){H=3}else{H=((F<<16>>16!=G<<16>>16)<<31>>31)+2|0}G=b[e+(C+D<<1)>>1]|0;if((F&65535)>>>0>(G&65535)>>>0){I=1}else{I=(F<<16>>16!=G<<16>>16)<<31>>31}G=(F&65535)+(c[h+120+(l*20|0)+(d[612016+(I+H)|0]<<2)>>2]|0)|0;if(G>>>0<1024>>>0){J=G&65535}else{J=-G>>31&1023}b[k+(E<<1)>>1]=J;D=D+1|0;}while((D|0)<(f|0))}D=z+1|0;if((D|0)<(q|0)){w=w+i|0;x=x+i|0;y=y+i|0;z=D}else{break}}}if(o<<24>>24==0){K=(j|0)==2|0}else{K=0}do{if(!(m<<24>>24==0|(j|0)==1)){z=q-K|0;if((z|0)<=0){break}y=r-1|0;x=0;do{w=y+(ca(x,i)|0)|0;b[k+(w<<1)>>1]=b[e+(w<<1)>>1]|0;x=x+1|0;}while((x|0)<(z|0))}}while(0);do{if(!(n<<24>>24==0|(j|0)==0)){r=f-K|0;if((r|0)<=0){break}q=s+(ca(g+1|0,i)|0)|0;m=0;do{z=q+m|0;b[k+(z<<1)>>1]=b[e+(z<<1)>>1]|0;m=m+1|0;}while((m|0)<(r|0))}}while(0);if(!(o<<24>>24!=0&(j|0)==2)){return}j=p+1+(ca(g+1|0,i)|0)+s|0;b[k+(j<<1)>>1]=b[e+(j<<1)>>1]|0;return}function OHa(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;h=e>>>1;if((g|0)<=0){return}e=(f|0)>0;i=0;j=d;d=a;while(1){if(e){a=0;do{b[d+(a<<1)>>1]=b[j+(a<<1)>>1]<<4;a=a+1|0;}while((a|0)<(f|0))}a=i+1|0;if((a|0)<(g|0)){i=a;j=j+(h<<1)|0;d=d+(c<<1)|0}else{break}}return}function PHa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-2<<1)>>1]|0)<<2)-(e[k+(a-3<<1)>>1]|0)+((e[k+(a-1<<1)>>1]|0)*-10|0)+((e[k+(a<<1)>>1]|0)*58|0)+((e[k+(l<<1)>>1]|0)*17|0)+((e[k+(a+2<<1)>>1]|0)*-5|0)+(e[k+(a+3<<1)>>1]|0)|0)>>>2;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function QHa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-2<<1)>>1]|0)<<2)-(e[k+(a-3<<1)>>1]|0)+((e[k+(a+3<<1)>>1]|0)<<2)-(e[k+(a+4<<1)>>1]|0)+(((e[k+(l<<1)>>1]|0)+(e[k+(a<<1)>>1]|0)|0)*40|0)+(((e[k+(a+2<<1)>>1]|0)+(e[k+(a-1<<1)>>1]|0)|0)*-11|0)|0)>>>2;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function RHa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=0;k=d;d=a;while(1){if(f){a=0;while(1){l=a+1|0;b[d+(a<<1)>>1]=(((e[k+(a-1<<1)>>1]|0)*-5|0)+(e[k+(a-2<<1)>>1]|0)+((e[k+(a<<1)>>1]|0)*17|0)+((e[k+(l<<1)>>1]|0)*58|0)+((e[k+(a+2<<1)>>1]|0)*-10|0)+((e[k+(a+3<<1)>>1]|0)<<2)-(e[k+(a+4<<1)>>1]|0)|0)>>>2;if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function SHa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i*3|0;k=i<<1;l=0;m=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[m+(a-k<<1)>>1]|0)<<2)-(e[m+(a-j<<1)>>1]|0)+((e[m+(a-i<<1)>>1]|0)*-10|0)+((e[m+(a<<1)>>1]|0)*58|0)+((e[m+(a+i<<1)>>1]|0)*17|0)+((e[m+(a+k<<1)>>1]|0)*-5|0)+(e[m+(a+j<<1)>>1]|0)|0)>>>2;a=a+1|0;}while((a|0)<(g|0))}a=l+1|0;if((a|0)<(h|0)){l=a;m=m+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function THa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374929]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374913]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374913]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function UHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374929]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374913]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>2;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374913]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function VHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374929]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374913]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374913]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+((b[a+(k-64<<1)>>1]|0)*-10|0)+((b[a+(k<<1)>>1]|0)*58|0)+((b[a+(k+64<<1)>>1]|0)*17|0)+((b[a+(k+128<<1)>>1]|0)*-5|0)+(b[a+(k+192<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function WHa(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i*3|0;k=i<<1;l=i<<2;m=0;n=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[n+(a-k<<1)>>1]|0)<<2)-(e[n+(a-j<<1)>>1]|0)+((e[n+(a+j<<1)>>1]|0)<<2)-(e[n+(a+l<<1)>>1]|0)+(((e[n+(a+i<<1)>>1]|0)+(e[n+(a<<1)>>1]|0)|0)*40|0)+(((e[n+(a+k<<1)>>1]|0)+(e[n+(a-i<<1)>>1]|0)|0)*-11|0)|0)>>>2;a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function XHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374930]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374914]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374914]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function YHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374930]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374914]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>2;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374914]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function ZHa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374930]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374914]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374914]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=((b[a+(k-128<<1)>>1]<<2)-(b[a+(k-192<<1)>>1]|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)+(((b[a+(k+64<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*40|0)+(((b[a+(k+128<<1)>>1]|0)+(b[a+(k-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function _Ha(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;i=f>>>1;if((h|0)<=0){return}f=(g|0)>0;j=i<<1;k=i*3|0;l=i<<2;m=0;n=d;d=a;while(1){if(f){a=0;do{b[d+(a<<1)>>1]=(((e[n+(a-i<<1)>>1]|0)*-5|0)+(e[n+(a-j<<1)>>1]|0)+((e[n+(a<<1)>>1]|0)*17|0)+((e[n+(a+i<<1)>>1]|0)*58|0)+((e[n+(a+j<<1)>>1]|0)*-10|0)+((e[n+(a+k<<1)>>1]|0)<<2)-(e[n+(a+l<<1)>>1]|0)|0)>>>2;a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+(i<<1)|0;d=d+(c<<1)|0}else{break}}return}function $Ha(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374931]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374915]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;while(1){w=p+1|0;x=b[o+(p+3<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((s&65535)*-10|0)+((t&65535)*58|0)+((u&65535)*17|0)+((v&65535)*-5|0)+(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374915]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function aIa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374931]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374915]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-6>>1]|0;r=b[o-4>>1]|0;s=b[o-2>>1]|0;t=b[o>>1]|0;u=b[o+2>>1]|0;v=b[o+4>>1]|0;w=b[o+6>>1]|0;while(1){x=p+1|0;y=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)<<2)-(q&65535)+((w&65535)<<2)-(y&65535)+(((u&65535)+(t&65535)|0)*40|0)+(((v&65535)+(s&65535)|0)*-11|0)|0)>>>2;if((x|0)<(g|0)){p=x;q=r;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=n+1|0;if((w|0)<(f|0)){n=w;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374915]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function bIa(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+9088|0;k=j|0;l=f>>>1;f=(d[1374931]|0)+h|0;if((f|0)>0){m=(g|0)>0;n=0;o=e+((ca(d[1374915]|0,-l|0)|0)<<1)|0;e=k|0;while(1){if(m){p=0;q=b[o-4>>1]|0;r=b[o-2>>1]|0;s=b[o>>1]|0;t=b[o+2>>1]|0;u=b[o+4>>1]|0;v=b[o+6>>1]|0;while(1){w=p+1|0;x=b[o+(p+4<<1)>>1]|0;b[e+(p<<1)>>1]=(((r&65535)*-5|0)+(q&65535)+((s&65535)*17|0)+((t&65535)*58|0)+((u&65535)*-10|0)+((v&65535)<<2)-(x&65535)|0)>>>2;if((w|0)<(g|0)){p=w;q=r;r=s;s=t;t=u;u=v;v=x}else{break}}}v=n+1|0;if((v|0)<(f|0)){n=v;o=o+(l<<1)|0;e=e+128|0}else{break}}}if((h|0)<=0){i=j;return}e=(g|0)>0;l=0;o=a;a=k+(d[1374915]<<6<<1)|0;while(1){if(e){k=0;do{b[o+(k<<1)>>1]=(((b[a+(k-64<<1)>>1]|0)*-5|0)+(b[a+(k-128<<1)>>1]|0)+((b[a+(k<<1)>>1]|0)*17|0)+((b[a+(k+64<<1)>>1]|0)*58|0)+((b[a+(k+128<<1)>>1]|0)*-10|0)+(b[a+(k+192<<1)>>1]<<2)-(b[a+(k+256<<1)>>1]|0)|0)>>>6;k=k+1|0;}while((k|0)<(g|0))}k=l+1|0;if((k|0)<(h|0)){l=k;o=o+(c<<1)|0;a=a+128|0}else{break}}i=j;return}function cIa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;j=e>>>1;if((g|0)<=0){return}e=(f|0)>0;i=0;h=d;d=a;while(1){if(e){a=0;do{b[d+(a<<1)>>1]=b[h+(a<<1)>>1]<<4;a=a+1|0;}while((a|0)<(f|0))}a=i+1|0;if((a|0)<(g|0)){i=a;h=h+(j<<1)|0;d=d+(c<<1)|0}else{break}}return}function dIa(c,d,f,g,h,i,j,k,l){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>>1;g=j-1|0;if((i|0)<=0){return}j=(h|0)>0;k=a[1375216+(g<<4)|0]|0;m=a[1375217+(g<<4)|0]|0;n=a[1375218+(g<<4)|0]|0;o=a[1375219+(g<<4)|0]|0;g=f;f=0;p=c;while(1){if(j){c=0;while(1){q=ca(e[g+(c-1<<1)>>1]|0,k)|0;r=(ca(e[g+(c<<1)>>1]|0,m)|0)+q|0;q=c+1|0;s=r+(ca(e[g+(q<<1)>>1]|0,n)|0)|0;b[p+(c<<1)>>1]=(s+(ca(e[g+(c+2<<1)>>1]|0,o)|0)|0)>>>2;if((q|0)<(h|0)){c=q}else{break}}}c=f+1|0;if((c|0)<(i|0)){g=g+(l<<1)|0;f=c;p=p+(d<<1)|0}else{break}}return}function eIa(c,d,f,g,h,i,j,k,l){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=g>>>1;g=k-1|0;if((i|0)<=0){return}k=(h|0)>0;j=a[1375216+(g<<4)|0]|0;m=a[1375217+(g<<4)|0]|0;n=a[1375218+(g<<4)|0]|0;o=a[1375219+(g<<4)|0]|0;g=l<<1;p=f;f=0;q=c;while(1){if(k){c=0;do{r=ca(e[p+(c-l<<1)>>1]|0,j)|0;s=(ca(e[p+(c<<1)>>1]|0,m)|0)+r|0;r=s+(ca(e[p+(c+l<<1)>>1]|0,n)|0)|0;b[q+(c<<1)>>1]=(r+(ca(e[p+(c+g<<1)>>1]|0,o)|0)|0)>>>2;c=c+1|0;}while((c|0)<(h|0))}c=f+1|0;if((c|0)<(i|0)){p=p+(l<<1)|0;f=c;q=q+(d<<1)|0}else{break}}return}function fIa(c,d,e,f,g,h,j,k,l){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=i;i=i+8576|0;m=l|0;n=f>>>1;f=j-1|0;j=k-1|0;k=1375216+(j<<4)|0;o=h+3|0;if((o|0)>0){p=(g|0)>0;q=a[1375216+(f<<4)|0]|0;r=a[1375217+(f<<4)|0]|0;s=a[1375218+(f<<4)|0]|0;t=a[1375219+(f<<4)|0]|0;f=e+(-n<<1)|0;e=0;u=m|0;while(1){if(p){v=0;w=b[f-2>>1]|0;x=b[f>>1]|0;y=b[f+2>>1]|0;while(1){z=v+1|0;A=(ca(x&65535,r)|0)+(ca(w&65535,q)|0)+(ca(y&65535,s)|0)|0;B=b[f+(v+2<<1)>>1]|0;b[u+(v<<1)>>1]=(A+(ca(B&65535,t)|0)|0)>>>2;if((z|0)<(g|0)){v=z;w=x;x=y;y=B}else{break}}}y=e+1|0;if((y|0)<(o|0)){f=f+(n<<1)|0;e=y;u=u+128|0}else{break}}}if((h|0)<=0){i=l;return}u=(g|0)>0;e=a[k]|0;k=a[1375217+(j<<4)|0]|0;n=a[1375218+(j<<4)|0]|0;f=a[1375219+(j<<4)|0]|0;j=0;o=c;c=m+128|0;while(1){if(u){m=0;do{t=ca(b[c+(m-64<<1)>>1]|0,e)|0;s=(ca(b[c+(m<<1)>>1]|0,k)|0)+t|0;t=s+(ca(b[c+(m+64<<1)>>1]|0,n)|0)|0;b[o+(m<<1)>>1]=(t+(ca(b[c+(m+128<<1)>>1]|0,f)|0)|0)>>>6;m=m+1|0;}while((m|0)<(g|0))}m=j+1|0;if((m|0)<(h|0)){j=m;o=o+(d<<1)|0;c=c+128|0}else{break}}i=l;return}function gIa(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c>>>1;if((g|0)<=0){return}c=(f|0)>0;i=a;a=0;j=d;while(1){if(c){d=0;do{k=(b[j+(d<<1)>>1]|0)+8>>4;if(k>>>0<1024>>>0){l=k&65535}else{l=-k>>31&1023}b[i+(d<<1)>>1]=l;d=d+1|0;}while((d|0)<(f|0))}d=a+1|0;if((d|0)<(g|0)){i=i+(h<<1)|0;a=d;j=j+(e<<1)|0}else{break}}return}function hIa(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=c>>>1;if((h|0)<=0){return}c=(g|0)>0;j=0;k=a;a=e;e=d;while(1){if(c){d=0;do{l=(b[e+(d<<1)>>1]|0)+16+(b[a+(d<<1)>>1]|0)>>5;if(l>>>0<1024>>>0){m=l&65535}else{m=-l>>31&1023}b[k+(d<<1)>>1]=m;d=d+1|0;}while((d|0)<(g|0))}d=j+1|0;if((d|0)<(h|0)){j=d;k=k+(i<<1)|0;a=a+(f<<1)|0;e=e+(f<<1)|0}else{break}}return}function iIa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=f>>>1;f=a&255;a=f+4|0;l=1<<f+3;f=c<<16>>16;c=d<<16>>16<<2;if((j|0)<=0){return}d=(i|0)>0;m=0;n=e;e=g;while(1){if(d){g=0;do{o=((ca(b[e+(g<<1)>>1]|0,f)|0)+l>>a)+c|0;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[n+(g<<1)>>1]=p;g=g+1|0;}while((g|0)<(i|0))}g=m+1|0;if((g|0)<(j|0)){m=g;n=n+(k<<1)|0;e=e+(h<<1)|0}else{break}}return}function jIa(a,c,d,e,f,g,h,i,j,k,l,m){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0;n=h>>>1;h=a&255;a=c<<16>>16;c=d<<16>>16;if((m|0)<=0){return}d=(l|0)>0;o=((f<<16>>16)+(e<<16>>16)<<2|1)<<h+4;e=h+5|0;h=j;j=0;f=g;g=i;while(1){if(d){i=0;do{p=ca(b[g+(i<<1)>>1]|0,a)|0;q=p+o+(ca(b[h+(i<<1)>>1]|0,c)|0)>>e;if(q>>>0<1024>>>0){r=q&65535}else{r=-q>>31&1023}b[f+(i<<1)>>1]=r;i=i+1|0;}while((i|0)<(l|0))}i=j+1|0;if((i|0)<(m|0)){h=h+(k<<1)|0;j=i;f=f+(n<<1)|0;g=g+(k<<1)|0}else{break}}return}function kIa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lJa(a,b,2,c,d,e,f);return}function lIa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lJa(a,2,b,c,d,e,f);return}function mIa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;kJa(a,b,2,c,d,e);return}function nIa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;kJa(a,2,b,c,d,e);return}function oIa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((f|0)<=0){return}i=g+8|0;j=g+16|0;k=g|0;g=32-h|0;l=8-h|0;m=0;n=b;while(1){b=0;do{o=c[i>>2]|0;p=c[j>>2]|0;q=(c[k>>2]|0)+(o>>>3)|0;r=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(o&7)>>>(g>>>0);q=o+h|0;c[i>>2]=p>>>0>q>>>0?q:p;a[n+b|0]=r<<l;b=b+1|0;}while((b|0)<(f|0));b=m+1|0;if((b|0)<(f|0)){m=b;n=n+e|0}else{break}}return}function pIa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=e;e=0;h=c;while(1){c=(b[g>>1]|0)+(d[h]|0)|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(b[g+2>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(b[g+4>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(b[g+6>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=e+1|0;if((c|0)<4){g=g+8|0;e=c;h=h+f|0}else{break}}return}function qIa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=e;e=0;h=c;while(1){c=(b[g>>1]|0)+(d[h]|0)|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(b[g+2>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(b[g+4>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(b[g+6>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=h+4|0;j=(b[g+8>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[c]=n;c=h+5|0;j=(b[g+10>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[c]=o;c=h+6|0;j=(b[g+12>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[c]=p;c=h+7|0;j=(b[g+14>>1]|0)+(d[c]|0)|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[c]=q;c=e+1|0;if((c|0)<8){g=g+16|0;e=c;h=h+f|0}else{break}}return}function rIa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e;e=0;h=c;while(1){c=g;i=0;while(1){j=h+i|0;k=(b[c>>1]|0)+(d[j]|0)|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=l;j=i+1|0;if((j|0)<16){c=c+2|0;i=j}else{break}}i=e+1|0;if((i|0)<16){g=g+32|0;e=i;h=h+f|0}else{break}}return}function sIa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e;e=0;h=c;while(1){c=g;i=0;while(1){j=h+i|0;k=(b[c>>1]|0)+(d[j]|0)|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=l;j=i+1|0;if((j|0)<32){c=c+2|0;i=j}else{break}}i=e+1|0;if((i|0)<32){g=g+64|0;e=i;h=h+f|0}else{break}}return}function tIa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;c=0;while(1){h=((b[e+(c<<1)>>1]|0)+16>>5)+(d[g]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[g]=i;h=g+1|0;j=((b[e+((c|1)<<1)>>1]|0)+16>>5)+(d[h]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=g+2|0;j=((b[e+((c|2)<<1)>>1]|0)+16>>5)+(d[h]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=g+3|0;j=((b[e+((c|3)<<1)>>1]|0)+16>>5)+(d[h]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=c+4|0;if((h|0)<16){g=g+f|0;c=h}else{break}}return}function uIa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=e;h=0;while(1){i=b[g>>1]|0;j=g+16|0;k=b[j>>1]|0;l=k+i|0;m=g+24|0;n=b[m>>1]|0;o=n+k|0;p=i-n|0;q=g+8|0;r=(b[q>>1]|0)*74|0;s=((i-k+n|0)*74|0)+64|0;n=s>>7;if((n+32768|0)>>>0>65535>>>0){t=(s>>31^32767)&65535}else{t=n&65535}b[j>>1]=t;j=(l*29|0)+64+(o*55|0)+r|0;n=j>>7;if((n+32768|0)>>>0>65535>>>0){u=(j>>31^32767)&65535}else{u=n&65535}b[g>>1]=u;n=(o*-29|0)+64+(p*55|0)+r|0;o=n>>7;if((o+32768|0)>>>0>65535>>>0){v=(n>>31^32767)&65535}else{v=o&65535}b[q>>1]=v;q=(l*55|0)+64+(p*29|0)-r|0;r=q>>7;if((r+32768|0)>>>0>65535>>>0){w=(q>>31^32767)&65535}else{w=r&65535}b[m>>1]=w;m=h+1|0;if((m|0)<4){g=g+2|0;h=m}else{x=c;y=0;z=e;break}}while(1){e=b[z>>1]|0;c=b[z+4>>1]|0;h=c+e|0;g=b[z+6>>1]|0;w=g+c|0;v=e-g|0;u=(b[z+2>>1]|0)*74|0;t=x+2|0;m=((e-c+g|0)*74|0)+2048|0;g=m>>12;if((g+32768|0)>>>0>65535>>>0){A=(m>>31^32767)&65535}else{A=g&65535}g=(A<<16>>16)+(d[t]|0)|0;if(g>>>0>255>>>0){B=-g>>31&255}else{B=g&255}a[t]=B;t=(h*29|0)+2048+(w*55|0)+u|0;g=t>>12;if((g+32768|0)>>>0>65535>>>0){C=(t>>31^32767)&65535}else{C=g&65535}g=(C<<16>>16)+(d[x]|0)|0;if(g>>>0>255>>>0){D=-g>>31&255}else{D=g&255}a[x]=D;g=x+1|0;t=(w*-29|0)+2048+(v*55|0)+u|0;w=t>>12;if((w+32768|0)>>>0>65535>>>0){E=(t>>31^32767)&65535}else{E=w&65535}w=(E<<16>>16)+(d[g]|0)|0;if(w>>>0>255>>>0){F=-w>>31&255}else{F=w&255}a[g]=F;g=x+3|0;w=(h*55|0)+2048+(v*29|0)-u|0;u=w>>12;if((u+32768|0)>>>0>65535>>>0){G=(w>>31^32767)&65535}else{G=u&65535}u=(G<<16>>16)+(d[g]|0)|0;if(u>>>0>255>>>0){H=-u>>31&255}else{H=u&255}a[g]=H;g=y+1|0;if((g|0)<4){x=x+f|0;y=g;z=z+8|0}else{break}}return}function vIa(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=e;h=0;while(1){i=b[g>>1]<<6;j=g+16|0;k=b[j>>1]|0;l=(k<<6)+i|0;m=(k*-64|0)+i|0;i=g+8|0;k=b[i>>1]|0;n=g+24|0;o=b[n>>1]|0;p=(o*36|0)+(k*83|0)|0;q=(o*-83|0)+(k*36|0)|0;k=l+64+p|0;o=k>>7;if((o+32768|0)>>>0>65535>>>0){r=(k>>31^32767)&65535}else{r=o&65535}b[g>>1]=r;o=m+64+q|0;k=o>>7;if((k+32768|0)>>>0>65535>>>0){s=(o>>31^32767)&65535}else{s=k&65535}b[i>>1]=s;i=m-q+64|0;q=i>>7;if((q+32768|0)>>>0>65535>>>0){t=(i>>31^32767)&65535}else{t=q&65535}b[j>>1]=t;j=l-p+64|0;p=j>>7;if((p+32768|0)>>>0>65535>>>0){u=(j>>31^32767)&65535}else{u=p&65535}b[n>>1]=u;n=h+1|0;if((n|0)<4){g=g+2|0;h=n}else{v=c;w=0;x=e;break}}while(1){e=b[x>>1]<<6;c=b[x+4>>1]|0;h=(c<<6)+e|0;g=(c*-64|0)+e|0;e=b[x+2>>1]|0;c=b[x+6>>1]|0;u=(c*36|0)+(e*83|0)|0;t=(c*-83|0)+(e*36|0)|0;e=h+2048+u|0;c=e>>12;if((c+32768|0)>>>0>65535>>>0){y=(e>>31^32767)&65535}else{y=c&65535}c=(y<<16>>16)+(d[v]|0)|0;if(c>>>0>255>>>0){z=-c>>31&255}else{z=c&255}a[v]=z;c=v+1|0;e=g+2048+t|0;s=e>>12;if((s+32768|0)>>>0>65535>>>0){A=(e>>31^32767)&65535}else{A=s&65535}s=(A<<16>>16)+(d[c]|0)|0;if(s>>>0>255>>>0){B=-s>>31&255}else{B=s&255}a[c]=B;c=v+2|0;s=g-t+2048|0;t=s>>12;if((t+32768|0)>>>0>65535>>>0){C=(s>>31^32767)&65535}else{C=t&65535}t=(C<<16>>16)+(d[c]|0)|0;if(t>>>0>255>>>0){D=-t>>31&255}else{D=t&255}a[c]=D;c=v+3|0;t=h-u+2048|0;u=t>>12;if((u+32768|0)>>>0>65535>>>0){E=(t>>31^32767)&65535}else{E=u&65535}u=(E<<16>>16)+(d[c]|0)|0;if(u>>>0>255>>>0){F=-u>>31&255}else{F=u&255}a[c]=F;c=w+1|0;if((c|0)<4){v=v+f|0;w=c;x=x+8|0}else{break}}return}function wIa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+64|0;j=h|0;k=h+16|0;l=h+32|0;m=h+48|0;n=k;o=j|0;p=j+4|0;q=j+8|0;r=j+12|0;s=f;t=0;while(1){mrc(n|0,0,16)|0;u=s+16|0;v=s+48|0;w=s+80|0;x=s+112|0;y=((b[x>>1]|0)*18|0)+(((b[w>>1]|0)*50|0)+(((b[v>>1]|0)*75|0)+((b[u>>1]|0)*89|0)))|0;c[k>>2]=y;c[k+4>>2]=((b[x>>1]|0)*-50|0)+(((b[w>>1]|0)*-89|0)+(((b[v>>1]|0)*-18|0)+((b[u>>1]|0)*75|0)));c[k+8>>2]=((b[x>>1]|0)*75|0)+(((b[w>>1]|0)*18|0)+(((b[v>>1]|0)*-89|0)+((b[u>>1]|0)*50|0)));c[k+12>>2]=((b[x>>1]|0)*-89|0)+(((b[w>>1]|0)*75|0)+(((b[v>>1]|0)*-50|0)+((b[u>>1]|0)*18|0)));u=b[s>>1]<<6;v=b[s+64>>1]|0;w=(v<<6)+u|0;x=(v*-64|0)+u|0;u=b[s+32>>1]|0;v=b[s+96>>1]|0;z=(v*36|0)+(u*83|0)|0;A=(v*-83|0)+(u*36|0)|0;u=z+w|0;c[o>>2]=u;c[p>>2]=A+x;c[q>>2]=x-A;c[r>>2]=w-z;z=0;w=u;u=y;while(1){y=w+64+u|0;A=y>>7;if((A+32768|0)>>>0>65535>>>0){B=(y>>31^32767)&65535}else{B=A&65535}b[s+(z<<3<<1)>>1]=B;A=w-u+64|0;y=A>>7;if((y+32768|0)>>>0>65535>>>0){C=(A>>31^32767)&65535}else{C=y&65535}b[s+(7-z<<3<<1)>>1]=C;y=z+1|0;if((y|0)>=4){break}z=y;w=c[j+(y<<2)>>2]|0;u=c[k+(y<<2)>>2]|0}u=t+1|0;if((u|0)<8){s=s+2|0;t=u}else{break}}t=m;s=l|0;k=l+4|0;j=l+8|0;C=l+12|0;B=e;e=0;r=f;while(1){mrc(t|0,0,16)|0;f=r+2|0;q=r+6|0;p=r+10|0;o=r+14|0;n=((b[o>>1]|0)*18|0)+(((b[p>>1]|0)*50|0)+(((b[q>>1]|0)*75|0)+((b[f>>1]|0)*89|0)))|0;c[m>>2]=n;c[m+4>>2]=((b[o>>1]|0)*-50|0)+(((b[p>>1]|0)*-89|0)+(((b[q>>1]|0)*-18|0)+((b[f>>1]|0)*75|0)));c[m+8>>2]=((b[o>>1]|0)*75|0)+(((b[p>>1]|0)*18|0)+(((b[q>>1]|0)*-89|0)+((b[f>>1]|0)*50|0)));c[m+12>>2]=((b[o>>1]|0)*-89|0)+(((b[p>>1]|0)*75|0)+(((b[q>>1]|0)*-50|0)+((b[f>>1]|0)*18|0)));f=b[r>>1]<<6;q=b[r+8>>1]|0;p=(q<<6)+f|0;o=(q*-64|0)+f|0;f=b[r+4>>1]|0;q=b[r+12>>1]|0;u=(q*36|0)+(f*83|0)|0;w=(q*-83|0)+(f*36|0)|0;f=u+p|0;c[s>>2]=f;c[k>>2]=w+o;c[j>>2]=o-w;c[C>>2]=p-u;u=0;p=f;f=n;while(1){n=B+u|0;w=p+2048+f|0;o=w>>12;if((o+32768|0)>>>0>65535>>>0){D=(w>>31^32767)&65535}else{D=o&65535}o=(D<<16>>16)+(d[n]|0)|0;if(o>>>0>255>>>0){E=-o>>31&255}else{E=o&255}a[n]=E;n=B+(7-u)|0;o=(c[l+(u<<2)>>2]|0)-(c[m+(u<<2)>>2]|0)+2048|0;w=o>>12;if((w+32768|0)>>>0>65535>>>0){F=(o>>31^32767)&65535}else{F=w&65535}w=(F<<16>>16)+(d[n]|0)|0;if(w>>>0>255>>>0){G=-w>>31&255}else{G=w&255}a[n]=G;n=u+1|0;if((n|0)>=4){break}u=n;p=c[l+(n<<2)>>2]|0;f=c[m+(n<<2)>>2]|0}f=e+1|0;if((f|0)<8){B=B+g|0;e=f;r=r+16|0}else{break}}i=h;return}function xIa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+128|0;j=h|0;k=h+32|0;l=h+64|0;m=h+96|0;n=k;o=f;p=0;while(1){mrc(n|0,0,32)|0;q=0;do{r=k+(q<<2)|0;s=(ca(b[o+32>>1]|0,a[305952+q|0]|0)|0)+(c[r>>2]|0)|0;t=(ca(b[o+96>>1]|0,a[306080+q|0]|0)|0)+s|0;s=(ca(b[o+160>>1]|0,a[306208+q|0]|0)|0)+t|0;t=(ca(b[o+224>>1]|0,a[306336+q|0]|0)|0)+s|0;s=(ca(b[o+288>>1]|0,a[306464+q|0]|0)|0)+t|0;t=(ca(b[o+352>>1]|0,a[306592+q|0]|0)|0)+s|0;s=(ca(b[o+416>>1]|0,a[306720+q|0]|0)|0)+t|0;c[r>>2]=(ca(b[o+480>>1]|0,a[306848+q|0]|0)|0)+s;q=q+1|0;}while((q|0)<8);q=o+64|0;s=o+192|0;r=o+320|0;t=o+448|0;u=((b[t>>1]|0)*18|0)+(((b[r>>1]|0)*50|0)+(((b[s>>1]|0)*75|0)+((b[q>>1]|0)*89|0)))|0;v=((b[t>>1]|0)*-50|0)+(((b[r>>1]|0)*-89|0)+(((b[s>>1]|0)*-18|0)+((b[q>>1]|0)*75|0)))|0;w=((b[t>>1]|0)*75|0)+(((b[r>>1]|0)*18|0)+(((b[s>>1]|0)*-89|0)+((b[q>>1]|0)*50|0)))|0;x=((b[t>>1]|0)*-89|0)+(((b[r>>1]|0)*75|0)+(((b[s>>1]|0)*-50|0)+((b[q>>1]|0)*18|0)))|0;q=b[o>>1]<<6;s=b[o+256>>1]|0;r=(s<<6)+q|0;t=(s*-64|0)+q|0;q=b[o+128>>1]|0;s=b[o+384>>1]|0;y=(s*36|0)+(q*83|0)|0;z=(s*-83|0)+(q*36|0)|0;q=y+r|0;s=z+t|0;A=t-z|0;z=r-y|0;y=u+q|0;c[j>>2]=y;c[j+28>>2]=q-u;c[j+4>>2]=v+s;c[j+24>>2]=s-v;c[j+8>>2]=w+A;c[j+20>>2]=A-w;c[j+12>>2]=x+z;c[j+16>>2]=z-x;x=0;z=y;while(1){y=c[k+(x<<2)>>2]|0;w=z+64+y|0;A=w>>7;if((A+32768|0)>>>0>65535>>>0){B=(w>>31^32767)&65535}else{B=A&65535}b[o+(x<<4<<1)>>1]=B;A=z-y+64|0;y=A>>7;if((y+32768|0)>>>0>65535>>>0){C=(A>>31^32767)&65535}else{C=y&65535}b[o+(15-x<<4<<1)>>1]=C;y=x+1|0;if((y|0)>=8){break}x=y;z=c[j+(y<<2)>>2]|0}z=p+1|0;if((z|0)<16){o=o+2|0;p=z}else{break}}p=m;o=e;e=0;j=f;while(1){mrc(p|0,0,32)|0;f=0;do{C=m+(f<<2)|0;B=(ca(b[j+2>>1]|0,a[305952+f|0]|0)|0)+(c[C>>2]|0)|0;k=(ca(b[j+6>>1]|0,a[306080+f|0]|0)|0)+B|0;B=(ca(b[j+10>>1]|0,a[306208+f|0]|0)|0)+k|0;k=(ca(b[j+14>>1]|0,a[306336+f|0]|0)|0)+B|0;B=(ca(b[j+18>>1]|0,a[306464+f|0]|0)|0)+k|0;k=(ca(b[j+22>>1]|0,a[306592+f|0]|0)|0)+B|0;B=(ca(b[j+26>>1]|0,a[306720+f|0]|0)|0)+k|0;c[C>>2]=(ca(b[j+30>>1]|0,a[306848+f|0]|0)|0)+B;f=f+1|0;}while((f|0)<8);f=j+4|0;B=j+12|0;C=j+20|0;k=j+28|0;n=((b[k>>1]|0)*18|0)+(((b[C>>1]|0)*50|0)+(((b[B>>1]|0)*75|0)+((b[f>>1]|0)*89|0)))|0;z=((b[k>>1]|0)*-50|0)+(((b[C>>1]|0)*-89|0)+(((b[B>>1]|0)*-18|0)+((b[f>>1]|0)*75|0)))|0;x=((b[k>>1]|0)*75|0)+(((b[C>>1]|0)*18|0)+(((b[B>>1]|0)*-89|0)+((b[f>>1]|0)*50|0)))|0;y=((b[k>>1]|0)*-89|0)+(((b[C>>1]|0)*75|0)+(((b[B>>1]|0)*-50|0)+((b[f>>1]|0)*18|0)))|0;f=b[j>>1]<<6;B=b[j+16>>1]|0;C=(B<<6)+f|0;k=(B*-64|0)+f|0;f=b[j+8>>1]|0;B=b[j+24>>1]|0;A=(B*36|0)+(f*83|0)|0;w=(B*-83|0)+(f*36|0)|0;f=A+C|0;B=w+k|0;v=k-w|0;w=C-A|0;A=n+f|0;c[l>>2]=A;c[l+28>>2]=f-n;c[l+4>>2]=z+B;c[l+24>>2]=B-z;c[l+8>>2]=x+v;c[l+20>>2]=v-x;c[l+12>>2]=y+w;c[l+16>>2]=w-y;y=0;w=A;while(1){A=o+y|0;x=m+(y<<2)|0;v=w+2048+(c[x>>2]|0)|0;z=v>>12;if((z+32768|0)>>>0>65535>>>0){D=(v>>31^32767)&65535}else{D=z&65535}z=(D<<16>>16)+(d[A]|0)|0;if(z>>>0>255>>>0){E=-z>>31&255}else{E=z&255}a[A]=E;A=o+(15-y)|0;z=(c[l+(y<<2)>>2]|0)-(c[x>>2]|0)+2048|0;x=z>>12;if((x+32768|0)>>>0>65535>>>0){F=(z>>31^32767)&65535}else{F=x&65535}x=(F<<16>>16)+(d[A]|0)|0;if(x>>>0>255>>>0){G=-x>>31&255}else{G=x&255}a[A]=G;A=y+1|0;if((A|0)>=8){break}y=A;w=c[l+(A<<2)>>2]|0}w=e+1|0;if((w|0)<16){o=o+g|0;e=w;j=j+32|0}else{break}}i=h;return}function yIa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+320|0;j=h|0;k=h+64|0;l=h+128|0;m=h+160|0;n=h+224|0;o=h+288|0;p=k;q=l;r=f;s=0;while(1){mrc(p|0,0,64)|0;t=0;do{u=k+(t<<2)|0;v=1;w=c[u>>2]|0;do{w=(ca(b[r+(v<<5<<1)>>1]|0,a[305888+(v<<5)+t|0]|0)|0)+w|0;v=v+2|0;}while((v|0)<32);c[u>>2]=w;t=t+1|0;}while((t|0)<16);mrc(q|0,0,32)|0;t=0;v=0;while(1){x=(ca(b[r+128>>1]|0,a[305952+t|0]|0)|0)+v|0;y=(ca(b[r+384>>1]|0,a[306080+t|0]|0)|0)+x|0;x=(ca(b[r+640>>1]|0,a[306208+t|0]|0)|0)+y|0;y=(ca(b[r+896>>1]|0,a[306336+t|0]|0)|0)+x|0;x=(ca(b[r+1152>>1]|0,a[306464+t|0]|0)|0)+y|0;y=(ca(b[r+1408>>1]|0,a[306592+t|0]|0)|0)+x|0;x=(ca(b[r+1664>>1]|0,a[306720+t|0]|0)|0)+y|0;c[l+(t<<2)>>2]=(ca(b[r+1920>>1]|0,a[306848+t|0]|0)|0)+x;x=t+1|0;if((x|0)>=8){break}t=x;v=c[l+(x<<2)>>2]|0}v=r+256|0;t=r+768|0;x=r+1280|0;y=r+1792|0;z=((b[y>>1]|0)*18|0)+(((b[x>>1]|0)*50|0)+(((b[t>>1]|0)*75|0)+((b[v>>1]|0)*89|0)))|0;A=((b[y>>1]|0)*-50|0)+(((b[x>>1]|0)*-89|0)+(((b[t>>1]|0)*-18|0)+((b[v>>1]|0)*75|0)))|0;B=((b[y>>1]|0)*75|0)+(((b[x>>1]|0)*18|0)+(((b[t>>1]|0)*-89|0)+((b[v>>1]|0)*50|0)))|0;C=((b[y>>1]|0)*-89|0)+(((b[x>>1]|0)*75|0)+(((b[t>>1]|0)*-50|0)+((b[v>>1]|0)*18|0)))|0;v=b[r>>1]<<6;t=b[r+1024>>1]|0;x=(t<<6)+v|0;y=(t*-64|0)+v|0;v=b[r+512>>1]|0;t=b[r+1536>>1]|0;D=(t*36|0)+(v*83|0)|0;E=(t*-83|0)+(v*36|0)|0;v=D+x|0;t=E+y|0;F=y-E|0;E=x-D|0;D=z+v|0;x=v-z|0;z=A+t|0;v=t-A|0;A=B+F|0;t=F-B|0;B=C+E|0;F=E-C|0;C=c[l>>2]|0;E=C+D|0;c[j>>2]=E;c[j+60>>2]=D-C;C=c[l+4>>2]|0;c[j+4>>2]=C+z;c[j+56>>2]=z-C;C=c[l+8>>2]|0;c[j+8>>2]=C+A;c[j+52>>2]=A-C;C=c[l+12>>2]|0;c[j+12>>2]=C+B;c[j+48>>2]=B-C;C=c[l+16>>2]|0;c[j+16>>2]=C+F;c[j+44>>2]=F-C;C=c[l+20>>2]|0;c[j+20>>2]=C+t;c[j+40>>2]=t-C;C=c[l+24>>2]|0;c[j+24>>2]=C+v;c[j+36>>2]=v-C;C=c[l+28>>2]|0;c[j+28>>2]=C+x;c[j+32>>2]=x-C;C=0;x=E;while(1){E=c[k+(C<<2)>>2]|0;v=x+64+E|0;t=v>>7;if((t+32768|0)>>>0>65535>>>0){G=(v>>31^32767)&65535}else{G=t&65535}b[r+(C<<5<<1)>>1]=G;t=x-E+64|0;E=t>>7;if((E+32768|0)>>>0>65535>>>0){H=(t>>31^32767)&65535}else{H=E&65535}b[r+(31-C<<5<<1)>>1]=H;E=C+1|0;if((E|0)>=16){break}C=E;x=c[j+(E<<2)>>2]|0}x=s+1|0;if((x|0)<32){r=r+2|0;s=x}else{break}}s=n;r=o;j=e;e=0;H=f;while(1){mrc(s|0,0,64)|0;f=0;do{G=n+(f<<2)|0;k=1;l=c[G>>2]|0;do{l=(ca(b[H+(k<<1)>>1]|0,a[305888+(k<<5)+f|0]|0)|0)+l|0;k=k+2|0;}while((k|0)<32);c[G>>2]=l;f=f+1|0;}while((f|0)<16);mrc(r|0,0,32)|0;f=0;k=0;while(1){w=(ca(b[H+4>>1]|0,a[305952+f|0]|0)|0)+k|0;u=(ca(b[H+12>>1]|0,a[306080+f|0]|0)|0)+w|0;w=(ca(b[H+20>>1]|0,a[306208+f|0]|0)|0)+u|0;u=(ca(b[H+28>>1]|0,a[306336+f|0]|0)|0)+w|0;w=(ca(b[H+36>>1]|0,a[306464+f|0]|0)|0)+u|0;u=(ca(b[H+44>>1]|0,a[306592+f|0]|0)|0)+w|0;w=(ca(b[H+52>>1]|0,a[306720+f|0]|0)|0)+u|0;c[o+(f<<2)>>2]=(ca(b[H+60>>1]|0,a[306848+f|0]|0)|0)+w;w=f+1|0;if((w|0)>=8){break}f=w;k=c[o+(w<<2)>>2]|0}k=H+8|0;f=H+24|0;w=H+40|0;u=H+56|0;q=((b[u>>1]|0)*18|0)+(((b[w>>1]|0)*50|0)+(((b[f>>1]|0)*75|0)+((b[k>>1]|0)*89|0)))|0;p=((b[u>>1]|0)*-50|0)+(((b[w>>1]|0)*-89|0)+(((b[f>>1]|0)*-18|0)+((b[k>>1]|0)*75|0)))|0;x=((b[u>>1]|0)*75|0)+(((b[w>>1]|0)*18|0)+(((b[f>>1]|0)*-89|0)+((b[k>>1]|0)*50|0)))|0;C=((b[u>>1]|0)*-89|0)+(((b[w>>1]|0)*75|0)+(((b[f>>1]|0)*-50|0)+((b[k>>1]|0)*18|0)))|0;k=b[H>>1]<<6;f=b[H+32>>1]|0;w=(f<<6)+k|0;u=(f*-64|0)+k|0;k=b[H+16>>1]|0;f=b[H+48>>1]|0;E=(f*36|0)+(k*83|0)|0;t=(f*-83|0)+(k*36|0)|0;k=E+w|0;f=t+u|0;v=u-t|0;t=w-E|0;E=q+k|0;w=k-q|0;q=p+f|0;k=f-p|0;p=x+v|0;f=v-x|0;x=C+t|0;v=t-C|0;C=c[o>>2]|0;t=C+E|0;c[m>>2]=t;c[m+60>>2]=E-C;C=c[o+4>>2]|0;c[m+4>>2]=C+q;c[m+56>>2]=q-C;C=c[o+8>>2]|0;c[m+8>>2]=C+p;c[m+52>>2]=p-C;C=c[o+12>>2]|0;c[m+12>>2]=C+x;c[m+48>>2]=x-C;C=c[o+16>>2]|0;c[m+16>>2]=C+v;c[m+44>>2]=v-C;C=c[o+20>>2]|0;c[m+20>>2]=C+f;c[m+40>>2]=f-C;C=c[o+24>>2]|0;c[m+24>>2]=C+k;c[m+36>>2]=k-C;C=c[o+28>>2]|0;c[m+28>>2]=C+w;c[m+32>>2]=w-C;C=0;w=t;while(1){t=j+C|0;k=n+(C<<2)|0;f=w+2048+(c[k>>2]|0)|0;v=f>>12;if((v+32768|0)>>>0>65535>>>0){I=(f>>31^32767)&65535}else{I=v&65535}v=(I<<16>>16)+(d[t]|0)|0;if(v>>>0>255>>>0){J=-v>>31&255}else{J=v&255}a[t]=J;t=j+(31-C)|0;v=(c[m+(C<<2)>>2]|0)-(c[k>>2]|0)+2048|0;k=v>>12;if((k+32768|0)>>>0>65535>>>0){K=(v>>31^32767)&65535}else{K=k&65535}k=(K<<16>>16)+(d[t]|0)|0;if(k>>>0>255>>>0){L=-k>>31&255}else{L=k&255}a[t]=L;t=C+1|0;if((t|0)>=16){break}C=t;w=c[m+(t<<2)>>2]|0}w=e+1|0;if((w|0)<32){j=j+g|0;e=w;H=H+64|0}else{break}}i=h;return}function zIa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;jJa(a,b,c,d,e,f,g,h,0);return}function AIa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;jJa(a,b,c,d,e,f,g,h,1);return}function BIa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;jJa(a,b,c,d,e,f,g,h,2);return}function CIa(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;jJa(a,b,c,d,e,f,g,h,3);return}function DIa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;o=(k|0)!=0|0;p=g+120+(k*20|0)|0;q=c[g+108+(k<<2)>>2]|0;r=h+8|0;s=c[r>>2]|0;if((s|0)==0){t=i-2-(8>>>(o>>>0))|0}else{t=i}i=h+12|0;if((c[i>>2]|0)==0){u=j-2-(4>>>(o>>>0))|0}else{u=j}j=(q|0)!=1;if(j){do{if((c[h>>2]|0)==0){v=0;w=s}else{o=c[p>>2]|0;if((u|0)>0){x=0;y=0}else{v=1;w=s;break}while(1){z=(d[e+x|0]|0)+o|0;if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}a[b+x|0]=A;z=y+1|0;if((z|0)<(u|0)){x=x+f|0;y=z}else{break}}v=1;w=c[r>>2]|0}}while(0);do{if((w|0)==0){B=t}else{r=c[p>>2]|0;y=t-1|0;if((u|0)>0){C=y;D=0}else{B=y;break}while(1){x=(d[e+C|0]|0)+r|0;if(x>>>0>255>>>0){E=-x>>31&255}else{E=x&255}a[b+C|0]=E;x=D+1|0;if((x|0)<(u|0)){C=C+f|0;D=x}else{B=y;break}}}}while(0);if((q|0)==0){F=0;G=u;H=B;I=v;J=1}else{K=B;L=v;M=18}}else{K=t;L=0;M=18}do{if((M|0)==18){do{if((c[h+4>>2]|0)==0){N=0}else{t=c[p>>2]|0;if((L|0)<(K|0)){O=L}else{N=1;break}while(1){v=(d[e+O|0]|0)+t|0;if(v>>>0>255>>>0){P=-v>>31&255}else{P=v&255}a[b+O|0]=P;v=O+1|0;if((v|0)<(K|0)){O=v}else{N=1;break}}}}while(0);if((c[i>>2]|0)==0){F=N;G=u;H=K;I=L;J=0;break}t=c[p>>2]|0;v=u-1|0;B=ca(v,f)|0;if((L|0)<(K|0)){Q=L}else{F=N;G=v;H=K;I=L;J=0;break}while(1){D=Q+B|0;C=(d[e+D|0]|0)+t|0;if(C>>>0>255>>>0){R=-C>>31&255}else{R=C&255}a[b+D|0]=R;D=Q+1|0;if((D|0)<(K|0)){Q=D}else{F=N;G=v;H=K;I=L;J=0;break}}}}while(0);L=a[612e3+(q<<2)|0]|0;K=a[612002+(q<<2)|0]|0;if((F|0)<(G|0)){N=(I|0)<(H|0);Q=ca(F,f)|0;R=ca((a[612001+(q<<2)|0]|0)+F|0,f)|0;u=ca((a[612003+(q<<2)|0]|0)+F|0,f)|0;p=F;while(1){if(N){i=R+L|0;O=u+K|0;P=I;do{M=P+Q|0;v=a[e+M|0]|0;t=a[e+(i+P)|0]|0;if((v&255)>>>0>(t&255)>>>0){S=3}else{S=((v<<24>>24!=t<<24>>24)<<31>>31)+2|0}t=a[e+(O+P)|0]|0;if((v&255)>>>0>(t&255)>>>0){T=1}else{T=(v<<24>>24!=t<<24>>24)<<31>>31}t=(v&255)+(c[g+120+(k*20|0)+(d[612016+(T+S)|0]<<2)>>2]|0)|0;if(t>>>0>255>>>0){U=-t>>31&255}else{U=t&255}a[b+M|0]=U;P=P+1|0;}while((P|0)<(H|0))}P=p+1|0;if((P|0)<(G|0)){Q=Q+f|0;R=R+f|0;u=u+f|0;p=P}else{break}}}p=(q|0)==2;do{if(n<<24>>24==0&p){if((c[h>>2]|0)!=0){V=0;break}V=(c[h+4>>2]|0)==0|0}else{V=0}}while(0);do{if(!(l<<24>>24==0|j^1)){h=V+F|0;if((h|0)<(G|0)){W=h}else{break}do{h=ca(W,f)|0;a[b+h|0]=a[e+h|0]|0;W=W+1|0;}while((W|0)<(G|0))}}while(0);do{if(!(m<<24>>24==0|J)){G=V+I|0;if((G|0)<(H|0)){X=G}else{break}do{a[b+X|0]=a[e+X|0]|0;X=X+1|0;}while((X|0)<(H|0))}}while(0);if(!(n<<24>>24!=0&p)){return}a[b]=a[e]|0;return}function EIa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=(k|0)!=0|0;o=g+120+(k*20|0)|0;p=c[g+108+(k<<2)>>2]|0;q=4>>>(j>>>0);r=-2-q|0;s=h+8|0;t=c[s>>2]|0;if((t|0)==0){u=i-2-(8>>>(j>>>0))|0}else{u=i}i=q+2|0;q=ca(r,f)|0;j=(p|0)!=1;do{if(j){do{if((c[h>>2]|0)==0){v=0;w=t}else{x=c[o>>2]|0;if((i|0)>0){y=0;z=0}else{v=1;w=t;break}while(1){A=y+q|0;B=(d[e+A|0]|0)+x|0;if(B>>>0>255>>>0){C=-B>>31&255}else{C=B&255}a[b+A|0]=C;A=z+1|0;if((A|0)<(i|0)){y=y+f|0;z=A}else{break}}v=1;w=c[s>>2]|0}}while(0);if((w|0)==0){D=v;E=u;F=15;break}x=c[o>>2]|0;A=u-1|0;if((i|0)>0){G=A;H=0}else{I=A;J=v;break}while(1){B=G+q|0;K=(d[e+B|0]|0)+x|0;if(K>>>0>255>>>0){L=-K>>31&255}else{L=K&255}a[b+B|0]=L;B=H+1|0;if((B|0)<(i|0)){G=G+f|0;H=B}else{D=v;E=A;F=15;break}}}else{D=0;E=u;F=15}}while(0);do{if((F|0)==15){if((i|0)<=0){I=E;J=D;break}u=(D|0)<(E|0);v=(a[612e3+(p<<2)|0]|0)+q|0;H=(a[612002+(p<<2)|0]|0)+q|0;G=0;L=ca(a[612001+(p<<2)|0]|0,f)|0;o=ca(a[612003+(p<<2)|0]|0,f)|0;w=0;while(1){if(u){s=G+q|0;z=v+L|0;y=H+o|0;C=D;do{t=s+C|0;A=a[e+t|0]|0;x=a[e+(z+C)|0]|0;if((A&255)>>>0>(x&255)>>>0){M=3}else{M=((A<<24>>24!=x<<24>>24)<<31>>31)+2|0}x=a[e+(y+C)|0]|0;if((A&255)>>>0>(x&255)>>>0){N=1}else{N=(A<<24>>24!=x<<24>>24)<<31>>31}x=(A&255)+(c[g+120+(k*20|0)+(d[612016+(N+M)|0]<<2)>>2]|0)|0;if(x>>>0>255>>>0){O=-x>>31&255}else{O=x&255}a[b+t|0]=O;C=C+1|0;}while((C|0)<(E|0))}C=w+1|0;if((C|0)<(i|0)){G=G+f|0;L=L+f|0;o=o+f|0;w=C}else{I=E;J=D;break}}}}while(0);D=(p|0)==3;if(n<<24>>24==0&D){P=(c[h>>2]|0)==0|0}else{P=0}do{if(!(l<<24>>24==0|j^1)){h=i-P|0;if((h|0)>0){Q=0}else{break}do{E=ca(Q+r|0,f)|0;a[b+E|0]=a[e+E|0]|0;Q=Q+1|0;}while((Q|0)<(h|0))}}while(0);do{if(!(m<<24>>24==0|(p|0)==0)){Q=P+J|0;if((Q|0)<(I|0)){R=Q}else{break}do{Q=R-f|0;a[b+Q|0]=a[e+Q|0]|0;R=R+1|0;}while((R|0)<(I|0))}}while(0);if(!(n<<24>>24!=0&D)){return}D=-f|0;a[b+D|0]=a[e+D|0]|0;return}function FIa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=(k|0)!=0|0;o=g+120+(k*20|0)|0;p=c[g+108+(k<<2)>>2]|0;q=8>>>(i>>>0);r=-2-q|0;s=q+2|0;q=h+12|0;t=c[q>>2]|0;if((t|0)==0){u=j-2-(4>>>(i>>>0))|0}else{u=j}j=(p|0)!=0;do{if(j){do{if((c[h+4>>2]|0)==0){v=0;w=t}else{i=c[o>>2]|0;if((s|0)>0){x=0}else{v=1;w=t;break}do{y=x+r|0;z=(d[e+y|0]|0)+i|0;if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}a[b+y|0]=A;x=x+1|0;}while((x|0)<(s|0));v=1;w=c[q>>2]|0}}while(0);if((w|0)==0){B=v;C=u;break}i=c[o>>2]|0;y=u-1|0;if((s|0)<=0){B=v;C=y;break}z=(ca(y,f)|0)+r|0;D=0;while(1){E=z+D|0;F=(d[e+E|0]|0)+i|0;if(F>>>0>255>>>0){G=-F>>31&255}else{G=F&255}a[b+E|0]=G;E=D+1|0;if((E|0)<(s|0)){D=E}else{B=v;C=y;break}}}else{B=0;C=u}}while(0);if((B|0)<(C|0)){u=(s|0)>0;v=(a[612e3+(p<<2)|0]|0)+r|0;G=(a[612002+(p<<2)|0]|0)+r|0;o=ca(B,f)|0;w=ca((a[612001+(p<<2)|0]|0)+B|0,f)|0;q=ca((a[612003+(p<<2)|0]|0)+B|0,f)|0;x=B;while(1){if(u){A=o+r|0;t=v+w|0;y=G+q|0;D=0;do{i=A+D|0;z=a[e+i|0]|0;E=a[e+(t+D)|0]|0;if((z&255)>>>0>(E&255)>>>0){H=3}else{H=((z<<24>>24!=E<<24>>24)<<31>>31)+2|0}E=a[e+(y+D)|0]|0;if((z&255)>>>0>(E&255)>>>0){I=1}else{I=(z<<24>>24!=E<<24>>24)<<31>>31}E=(z&255)+(c[g+120+(k*20|0)+(d[612016+(I+H)|0]<<2)>>2]|0)|0;if(E>>>0>255>>>0){J=-E>>31&255}else{J=E&255}a[b+i|0]=J;D=D+1|0;}while((D|0)<(s|0))}D=x+1|0;if((D|0)<(C|0)){o=o+f|0;w=w+f|0;q=q+f|0;x=D}else{break}}}x=(p|0)==3;if(n<<24>>24==0&x){K=(c[h+4>>2]|0)==0|0}else{K=0}do{if(!(l<<24>>24==0|(p|0)==1)){h=K+B|0;if((h|0)<(C|0)){L=h}else{break}do{h=(ca(L,f)|0)-1|0;a[b+h|0]=a[e+h|0]|0;L=L+1|0;}while((L|0)<(C|0))}}while(0);do{if(!(m<<24>>24==0|j^1)){C=s-K|0;if((C|0)>0){M=0}else{break}do{L=M+r|0;a[b+L|0]=a[e+L|0]|0;M=M+1|0;}while((M|0)<(C|0))}}while(0);if(!(n<<24>>24!=0&x)){return}a[b-1|0]=a[e-1|0]|0;return}function GIa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=(k|0)!=0|0;i=c[g+108+(k<<2)>>2]|0;h=4>>>(j>>>0);o=8>>>(j>>>0);j=o+2|0;p=h+2|0;q=ca(-2-h|0,f)|0;r=q+(-2-o)|0;if((p|0)>0){s=(j|0)>0;t=(a[612e3+(i<<2)|0]|0)+r|0;u=(a[612002+(i<<2)|0]|0)+r|0;v=0;w=ca(a[612001+(i<<2)|0]|0,f)|0;x=ca(a[612003+(i<<2)|0]|0,f)|0;y=0;while(1){if(s){z=v+r|0;A=t+w|0;B=u+x|0;C=0;do{D=z+C|0;E=a[e+D|0]|0;F=a[e+(A+C)|0]|0;if((E&255)>>>0>(F&255)>>>0){G=3}else{G=((E<<24>>24!=F<<24>>24)<<31>>31)+2|0}F=a[e+(B+C)|0]|0;if((E&255)>>>0>(F&255)>>>0){H=1}else{H=(E<<24>>24!=F<<24>>24)<<31>>31}F=(E&255)+(c[g+120+(k*20|0)+(d[612016+(H+G)|0]<<2)>>2]|0)|0;if(F>>>0>255>>>0){I=-F>>31&255}else{I=F&255}a[b+D|0]=I;C=C+1|0;}while((C|0)<(j|0))}C=y+1|0;if((C|0)<(p|0)){v=v+f|0;w=w+f|0;x=x+f|0;y=C}else{break}}}if(n<<24>>24==0){J=(i|0)==2|0}else{J=0}do{if(!(l<<24>>24==0|(i|0)==1)){y=p-J|0;if((y|0)<=0){break}x=q-1|0;w=0;do{v=x+(ca(w,f)|0)|0;a[b+v|0]=a[e+v|0]|0;w=w+1|0;}while((w|0)<(y|0))}}while(0);do{if(!(m<<24>>24==0|(i|0)==0)){q=j-J|0;if((q|0)<=0){break}p=r+(ca(h+1|0,f)|0)|0;l=0;do{y=p+l|0;a[b+y|0]=a[e+y|0]|0;l=l+1|0;}while((l|0)<(q|0))}}while(0);if(!(n<<24>>24!=0&(i|0)==2)){return}i=o+1+(ca(h+1|0,f)|0)+r|0;a[b+i|0]=a[e+i|0]|0;return}function HIa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;if((h|0)<=0){return}i=(g|0)>0;j=0;k=e;e=a;while(1){if(i){a=0;do{b[e+(a<<1)>>1]=(d[k+a|0]|0)<<6;a=a+1|0;}while((a|0)<(g|0))}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+f|0;e=e+(c<<1)|0}else{break}}return}function IIa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((h|0)<=0){return}i=(g|0)>0;j=0;k=e;e=a;while(1){if(i){a=0;while(1){l=a+1|0;b[e+(a<<1)>>1]=(((((((d[k+(a-2)|0]|0)<<2)-(d[k+(a-3)|0]|0)&65535)+((d[k+(a-1)|0]|0)*-10&65535)&65535)+((d[k+a|0]|0)*58&65535)&65535)+((d[k+l|0]|0)*17&65535)&65535)+((d[k+(a+2)|0]|0)*-5&65535)&65535)+(d[k+(a+3)|0]|0);if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+f|0;e=e+(c<<1)|0}else{break}}return}function JIa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((h|0)<=0){return}i=(g|0)>0;j=0;k=e;e=a;while(1){if(i){a=0;while(1){l=a+1|0;b[e+(a<<1)>>1]=((((((d[k+(a-2)|0]|0)<<2)-(d[k+(a-3)|0]|0)&65535)+((d[k+(a+3)|0]|0)<<2)&65535)-(d[k+(a+4)|0]|0)&65535)+(((d[k+l|0]|0)+(d[k+a|0]|0)&65535)*40&65535)&65535)+(((d[k+(a+2)|0]|0)+(d[k+(a-1)|0]|0)&65535)*-11&65535);if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+f|0;e=e+(c<<1)|0}else{break}}return}function KIa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((h|0)<=0){return}i=(g|0)>0;j=0;k=e;e=a;while(1){if(i){a=0;while(1){l=a+1|0;b[e+(a<<1)>>1]=(((((((d[k+(a-1)|0]|0)*-5&65535)+(d[k+(a-2)|0]|0)&65535)+((d[k+a|0]|0)*17&65535)&65535)+((d[k+l|0]|0)*58&65535)&65535)+((d[k+(a+2)|0]|0)*-10&65535)&65535)+((d[k+(a+3)|0]|0)<<2)&65535)-(d[k+(a+4)|0]|0);if((l|0)<(g|0)){a=l}else{break}}}a=j+1|0;if((a|0)<(h|0)){j=a;k=k+f|0;e=e+(c<<1)|0}else{break}}return}function LIa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((h|0)<=0){return}i=(g|0)>0;j=f*3|0;k=f<<1;l=0;m=e;e=a;while(1){if(i){a=0;do{b[e+(a<<1)>>1]=(((((((d[m+(a-k)|0]|0)<<2)-(d[m+(a-j)|0]|0)&65535)+((d[m+(a-f)|0]|0)*-10&65535)&65535)+((d[m+a|0]|0)*58&65535)&65535)+((d[m+(a+f)|0]|0)*17&65535)&65535)+((d[m+(a+k)|0]|0)*-5&65535)&65535)+(d[m+(a+j)|0]|0);a=a+1|0;}while((a|0)<(g|0))}a=l+1|0;if((a|0)<(h|0)){l=a;m=m+f|0;e=e+(c<<1)|0}else{break}}return}function MIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1374929]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374913]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;while(1){x=q+1|0;y=a[p+(q+3)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)<<2)-(r&255)&65535)+((t&255)*-10&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*17&65535)&65535)+((w&255)*-5&65535)&65535)+(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374913]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+((b[c+(l-64<<1)>>1]|0)*-10|0)+((b[c+(l<<1)>>1]|0)*58|0)+((b[c+(l+64<<1)>>1]|0)*17|0)+((b[c+(l+128<<1)>>1]|0)*-5|0)+(b[c+(l+192<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function NIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+9088|0;l=k|0;m=(d[1374929]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374913]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;x=a[p+3|0]|0;while(1){y=q+1|0;z=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=((((((s&255)<<2)-(r&255)&65535)+((x&255)<<2)&65535)-(z&255)&65535)+(((v&255)+(u&255)&65535)*40&65535)&65535)+(((w&255)+(t&255)&65535)*-11&65535);if((y|0)<(h|0)){q=y;r=s;s=t;t=u;u=v;v=w;w=x;x=z}else{break}}}x=o+1|0;if((x|0)<(m|0)){o=x;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374913]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+((b[c+(l-64<<1)>>1]|0)*-10|0)+((b[c+(l<<1)>>1]|0)*58|0)+((b[c+(l+64<<1)>>1]|0)*17|0)+((b[c+(l+128<<1)>>1]|0)*-5|0)+(b[c+(l+192<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function OIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1374929]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374913]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-2|0]|0;s=a[p-1|0]|0;t=a[p]|0;u=a[p+1|0]|0;v=a[p+2|0]|0;w=a[p+3|0]|0;while(1){x=q+1|0;y=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)*-5&65535)+(r&255)&65535)+((t&255)*17&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*-10&65535)&65535)+((w&255)<<2)&65535)-(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374913]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+((b[c+(l-64<<1)>>1]|0)*-10|0)+((b[c+(l<<1)>>1]|0)*58|0)+((b[c+(l+64<<1)>>1]|0)*17|0)+((b[c+(l+128<<1)>>1]|0)*-5|0)+(b[c+(l+192<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function PIa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;if((h|0)<=0){return}i=(g|0)>0;j=f*3|0;k=f<<1;l=f<<2;m=0;n=e;e=a;while(1){if(i){a=0;do{b[e+(a<<1)>>1]=((((((d[n+(a-k)|0]|0)<<2)-(d[n+(a-j)|0]|0)&65535)+((d[n+(a+j)|0]|0)<<2)&65535)-(d[n+(a+l)|0]|0)&65535)+(((d[n+(a+f)|0]|0)+(d[n+a|0]|0)&65535)*40&65535)&65535)+(((d[n+(a+k)|0]|0)+(d[n+(a-f)|0]|0)&65535)*-11&65535);a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+f|0;e=e+(c<<1)|0}else{break}}return}function QIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1374930]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374914]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;while(1){x=q+1|0;y=a[p+(q+3)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)<<2)-(r&255)&65535)+((t&255)*-10&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*17&65535)&65535)+((w&255)*-5&65535)&65535)+(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374914]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)+(((b[c+(l+64<<1)>>1]|0)+(b[c+(l<<1)>>1]|0)|0)*40|0)+(((b[c+(l+128<<1)>>1]|0)+(b[c+(l-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function RIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+9088|0;l=k|0;m=(d[1374930]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374914]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;x=a[p+3|0]|0;while(1){y=q+1|0;z=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=((((((s&255)<<2)-(r&255)&65535)+((x&255)<<2)&65535)-(z&255)&65535)+(((v&255)+(u&255)&65535)*40&65535)&65535)+(((w&255)+(t&255)&65535)*-11&65535);if((y|0)<(h|0)){q=y;r=s;s=t;t=u;u=v;v=w;w=x;x=z}else{break}}}x=o+1|0;if((x|0)<(m|0)){o=x;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374914]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)+(((b[c+(l+64<<1)>>1]|0)+(b[c+(l<<1)>>1]|0)|0)*40|0)+(((b[c+(l+128<<1)>>1]|0)+(b[c+(l-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function SIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1374930]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374914]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-2|0]|0;s=a[p-1|0]|0;t=a[p]|0;u=a[p+1|0]|0;v=a[p+2|0]|0;w=a[p+3|0]|0;while(1){x=q+1|0;y=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)*-5&65535)+(r&255)&65535)+((t&255)*17&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*-10&65535)&65535)+((w&255)<<2)&65535)-(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374914]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=((b[c+(l-128<<1)>>1]<<2)-(b[c+(l-192<<1)>>1]|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)+(((b[c+(l+64<<1)>>1]|0)+(b[c+(l<<1)>>1]|0)|0)*40|0)+(((b[c+(l+128<<1)>>1]|0)+(b[c+(l-64<<1)>>1]|0)|0)*-11|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function TIa(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;if((h|0)<=0){return}i=(g|0)>0;j=f<<1;k=f*3|0;l=f<<2;m=0;n=e;e=a;while(1){if(i){a=0;do{b[e+(a<<1)>>1]=(((((((d[n+(a-f)|0]|0)*-5&65535)+(d[n+(a-j)|0]|0)&65535)+((d[n+a|0]|0)*17&65535)&65535)+((d[n+(a+f)|0]|0)*58&65535)&65535)+((d[n+(a+j)|0]|0)*-10&65535)&65535)+((d[n+(a+k)|0]|0)<<2)&65535)-(d[n+(a+l)|0]|0);a=a+1|0;}while((a|0)<(g|0))}a=m+1|0;if((a|0)<(h|0)){m=a;n=n+f|0;e=e+(c<<1)|0}else{break}}return}function UIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1374931]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374915]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;while(1){x=q+1|0;y=a[p+(q+3)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)<<2)-(r&255)&65535)+((t&255)*-10&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*17&65535)&65535)+((w&255)*-5&65535)&65535)+(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374915]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=(((b[c+(l-64<<1)>>1]|0)*-5|0)+(b[c+(l-128<<1)>>1]|0)+((b[c+(l<<1)>>1]|0)*17|0)+((b[c+(l+64<<1)>>1]|0)*58|0)+((b[c+(l+128<<1)>>1]|0)*-10|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function VIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+9088|0;l=k|0;m=(d[1374931]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374915]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-3|0]|0;s=a[p-2|0]|0;t=a[p-1|0]|0;u=a[p]|0;v=a[p+1|0]|0;w=a[p+2|0]|0;x=a[p+3|0]|0;while(1){y=q+1|0;z=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=((((((s&255)<<2)-(r&255)&65535)+((x&255)<<2)&65535)-(z&255)&65535)+(((v&255)+(u&255)&65535)*40&65535)&65535)+(((w&255)+(t&255)&65535)*-11&65535);if((y|0)<(h|0)){q=y;r=s;s=t;t=u;u=v;v=w;w=x;x=z}else{break}}}x=o+1|0;if((x|0)<(m|0)){o=x;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374915]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=(((b[c+(l-64<<1)>>1]|0)*-5|0)+(b[c+(l-128<<1)>>1]|0)+((b[c+(l<<1)>>1]|0)*17|0)+((b[c+(l+64<<1)>>1]|0)*58|0)+((b[c+(l+128<<1)>>1]|0)*-10|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function WIa(c,e,f,g,h,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+9088|0;l=k|0;m=(d[1374931]|0)+j|0;if((m|0)>0){n=(h|0)>0;o=0;p=f+(ca(d[1374915]|0,-g|0)|0)|0;f=l|0;while(1){if(n){q=0;r=a[p-2|0]|0;s=a[p-1|0]|0;t=a[p]|0;u=a[p+1|0]|0;v=a[p+2|0]|0;w=a[p+3|0]|0;while(1){x=q+1|0;y=a[p+(q+4)|0]|0;b[f+(q<<1)>>1]=(((((((s&255)*-5&65535)+(r&255)&65535)+((t&255)*17&65535)&65535)+((u&255)*58&65535)&65535)+((v&255)*-10&65535)&65535)+((w&255)<<2)&65535)-(y&255);if((x|0)<(h|0)){q=x;r=s;s=t;t=u;u=v;v=w;w=y}else{break}}}w=o+1|0;if((w|0)<(m|0)){o=w;p=p+g|0;f=f+128|0}else{break}}}if((j|0)<=0){i=k;return}f=(h|0)>0;g=0;p=c;c=l+(d[1374915]<<6<<1)|0;while(1){if(f){l=0;do{b[p+(l<<1)>>1]=(((b[c+(l-64<<1)>>1]|0)*-5|0)+(b[c+(l-128<<1)>>1]|0)+((b[c+(l<<1)>>1]|0)*17|0)+((b[c+(l+64<<1)>>1]|0)*58|0)+((b[c+(l+128<<1)>>1]|0)*-10|0)+(b[c+(l+192<<1)>>1]<<2)-(b[c+(l+256<<1)>>1]|0)|0)>>>6;l=l+1|0;}while((l|0)<(h|0))}l=g+1|0;if((l|0)<(j|0)){g=l;p=p+(e<<1)|0;c=c+128|0}else{break}}i=k;return}function XIa(a,c,e,f,g,h,i,j,k){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;if((h|0)<=0){return}k=(g|0)>0;j=0;i=e;e=a;while(1){if(k){a=0;do{b[e+(a<<1)>>1]=(d[i+a|0]|0)<<6;a=a+1|0;}while((a|0)<(g|0))}a=j+1|0;if((a|0)<(h|0)){j=a;i=i+f|0;e=e+(c<<1)|0}else{break}}return}function YIa(c,e,f,g,h,i,j,k,l){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=j-1|0;if((i|0)<=0){return}j=(h|0)>0;k=a[1375216+(l<<4)|0]|0;m=a[1375217+(l<<4)|0]|0;n=a[1375218+(l<<4)|0]|0;o=a[1375219+(l<<4)|0]|0;l=f;f=0;p=c;while(1){if(j){c=0;while(1){q=ca(d[l+(c-1)|0]|0,k)|0;r=(ca(d[l+c|0]|0,m)|0)+q&65535;q=c+1|0;s=r+(ca(d[l+q|0]|0,n)|0)&65535;b[p+(c<<1)>>1]=s+(ca(d[l+(c+2)|0]|0,o)|0);if((q|0)<(h|0)){c=q}else{break}}}c=f+1|0;if((c|0)<(i|0)){l=l+g|0;f=c;p=p+(e<<1)|0}else{break}}return}function ZIa(c,e,f,g,h,i,j,k,l){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=k-1|0;if((i|0)<=0){return}k=(h|0)>0;j=a[1375216+(l<<4)|0]|0;m=a[1375217+(l<<4)|0]|0;n=a[1375218+(l<<4)|0]|0;o=a[1375219+(l<<4)|0]|0;l=g<<1;p=f;f=0;q=c;while(1){if(k){c=0;do{r=ca(d[p+(c-g)|0]|0,j)|0;s=(ca(d[p+c|0]|0,m)|0)+r&65535;r=s+(ca(d[p+(c+g)|0]|0,n)|0)&65535;b[q+(c<<1)>>1]=r+(ca(d[p+(c+l)|0]|0,o)|0);c=c+1|0;}while((c|0)<(h|0))}c=f+1|0;if((c|0)<(i|0)){p=p+g|0;f=c;q=q+(e<<1)|0}else{break}}return}function _Ia(c,d,e,f,g,h,j,k,l){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=i;i=i+8576|0;m=l|0;n=j-1|0;j=k-1|0;k=1375216+(j<<4)|0;o=h+3|0;if((o|0)>0){p=(g|0)>0;q=a[1375216+(n<<4)|0]|0;r=a[1375217+(n<<4)|0]|0;s=a[1375218+(n<<4)|0]|0;t=a[1375219+(n<<4)|0]|0;n=e+(-f|0)|0;e=0;u=m|0;while(1){if(p){v=0;w=a[n-1|0]|0;x=a[n]|0;y=a[n+1|0]|0;while(1){z=v+1|0;A=((ca(x&255,r)|0)+(ca(w&255,q)|0)&65535)+(ca(y&255,s)|0)&65535;B=a[n+(v+2)|0]|0;b[u+(v<<1)>>1]=A+(ca(B&255,t)|0);if((z|0)<(g|0)){v=z;w=x;x=y;y=B}else{break}}}y=e+1|0;if((y|0)<(o|0)){n=n+f|0;e=y;u=u+128|0}else{break}}}if((h|0)<=0){i=l;return}u=(g|0)>0;e=a[k]|0;k=a[1375217+(j<<4)|0]|0;f=a[1375218+(j<<4)|0]|0;n=a[1375219+(j<<4)|0]|0;j=0;o=c;c=m+128|0;while(1){if(u){m=0;do{t=ca(b[c+(m-64<<1)>>1]|0,e)|0;s=(ca(b[c+(m<<1)>>1]|0,k)|0)+t|0;t=s+(ca(b[c+(m+64<<1)>>1]|0,f)|0)|0;b[o+(m<<1)>>1]=(t+(ca(b[c+(m+128<<1)>>1]|0,n)|0)|0)>>>6;m=m+1|0;}while((m|0)<(g|0))}m=j+1|0;if((m|0)<(h|0)){j=m;o=o+(d<<1)|0;c=c+128|0}else{break}}i=l;return}function $Ia(c,d,e,f,g,h){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((h|0)<=0){return}i=(g|0)>0;j=c;c=0;k=e;while(1){if(i){e=0;do{l=(b[k+(e<<1)>>1]|0)+32>>6;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[j+e|0]=m;e=e+1|0;}while((e|0)<(g|0))}e=c+1|0;if((e|0)<(h|0)){j=j+d|0;c=e;k=k+(f<<1)|0}else{break}}return}function aJa(c,d,e,f,g,h,i){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;if((i|0)<=0){return}j=(h|0)>0;k=0;l=c;c=f;f=e;while(1){if(j){e=0;do{m=(b[f+(e<<1)>>1]|0)+64+(b[c+(e<<1)>>1]|0)>>7;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l+e|0]=n;e=e+1|0;}while((e|0)<(h|0))}e=k+1|0;if((e|0)<(i|0)){k=e;l=l+d|0;c=c+(g<<1)|0;f=f+(g<<1)|0}else{break}}return}function bJa(c,d,e,f,g,h,i,j,k){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0;l=c&255;c=l+6|0;m=1<<l+5;l=d<<16>>16;d=e<<16>>16;if((k|0)<=0){return}e=(j|0)>0;n=0;o=f;f=h;while(1){if(e){h=0;do{p=((ca(b[f+(h<<1)>>1]|0,l)|0)+m>>c)+d|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[o+h|0]=q;h=h+1|0;}while((h|0)<(j|0))}h=n+1|0;if((h|0)<(k|0)){n=h;o=o+g|0;f=f+(i<<1)|0}else{break}}return}function cJa(c,d,e,f,g,h,i,j,k,l,m,n){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0;o=c&255;c=d<<16>>16;d=e<<16>>16;if((n|0)<=0){return}e=(m|0)>0;p=(f<<16>>16)+1+(g<<16>>16)<<o+6;g=o+7|0;o=k;k=0;f=h;h=j;while(1){if(e){j=0;do{q=ca(b[h+(j<<1)>>1]|0,c)|0;r=q+p+(ca(b[o+(j<<1)>>1]|0,d)|0)>>g;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[f+j|0]=s;j=j+1|0;}while((j|0)<(m|0))}j=k+1|0;if((j|0)<(n|0)){o=o+(l<<1)|0;k=j;f=f+i|0;h=h+(l<<1)|0}else{break}}return}function dJa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;iJa(a,b,1,c,d,e,f);return}function eJa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;iJa(a,1,b,c,d,e,f);return}function fJa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;hJa(a,b,1,c,d,e);return}function gJa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;hJa(a,1,b,c,d,e);return}function hJa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=e*-2|0;k=-e|0;l=c[g>>2]|0;if((l|0)>=1){m=-l|0;n=(a[h]|0)==0;o=(a[i]|0)==0;p=b;q=0;while(1){r=p+k|0;s=d[r]|0;t=d[p]|0;u=(d[p+j|0]|0)+4-(d[p+e|0]|0)+(t-s<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}if(n){u=v+s|0;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}a[r]=w}if(o){r=t-v|0;if(r>>>0>255>>>0){x=-r>>31&255}else{x=r&255}a[p]=x}r=q+1|0;if((r|0)<4){p=p+f|0;q=r}else{break}}}q=c[g+4>>2]|0;if((q|0)<1){return}g=-q|0;p=(a[h+1|0]|0)==0;h=(a[i+1|0]|0)==0;i=b+(f<<2)|0;b=0;while(1){x=i+k|0;v=d[x]|0;o=d[i]|0;w=(d[i+j|0]|0)+4-(d[i+e|0]|0)+(o-v<<2)>>3;if((w|0)<(g|0)){y=g}else{y=(w|0)>(q|0)?q:w}if(p){w=y+v|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[x]=z}if(h){x=o-y|0;if(x>>>0>255>>>0){A=-x>>31&255}else{A=x&255}a[i]=A}x=b+1|0;if((x|0)<4){i=i+f|0;b=x}else{break}}return}function iJa(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;k=e*-3|0;l=e*-2|0;m=-e|0;n=e<<1;o=f*3|0;p=o+k|0;q=o+l|0;r=o-e|0;s=o+n|0;t=o+e|0;u=e*-4|0;v=e*3|0;w=o+u|0;x=(f+e|0)*3|0;y=f<<2;z=f<<2;A=b;b=0;while(1){B=a[A+k|0]|0;C=a[A+l|0]|0;D=a[A+m|0]|0;E=D&255;F=(B&255)-((C&255)<<1)+E|0;G=(F|0)>-1?F:-F|0;F=a[A+n|0]|0;H=a[A+e|0]|0;I=a[A]|0;J=I&255;K=(F&255)-((H&255)<<1)+J|0;L=(K|0)>-1?K:-K|0;K=d[A+r|0]|0;M=(d[A+p|0]|0)-((d[A+q|0]|0)<<1)+K|0;N=(M|0)>-1?M:-M|0;M=d[A+o|0]|0;O=(d[A+s|0]|0)-((d[A+t|0]|0)<<1)+M|0;P=(O|0)>-1?O:-O|0;O=L+G|0;Q=P+N|0;R=c[g+(b<<2)>>2]|0;S=c[h+(b<<2)>>2]|0;T=a[i+b|0]|0;U=a[j+b|0]|0;a:do{if((Q+O|0)<(R|0)){V=R>>3;W=R>>2;X=(S*5|0)+1>>1;Y=(d[A+u|0]|0)-E|0;Z=a[A+v|0]|0;_=(Z&255)-J|0;do{if((((_|0)>-1?_:-_|0)+((Y|0)>-1?Y:-Y|0)|0)<(V|0)){$=E-J|0;if(((($|0)>-1?$:-$|0)|0)>=(X|0)){break}$=(d[A+w|0]|0)-K|0;aa=(d[A+x|0]|0)-M|0;if((((aa|0)>-1?aa:-aa|0)+(($|0)>-1?$:-$|0)|0)>=(V|0)){break}$=K-M|0;if(((($|0)>-1?$:-$|0)|0)>=(X|0)){break}if((O<<1|0)>=(W|0)){break}if((Q<<1|0)>=(W|0)){break}$=S<<1;aa=T<<24>>24==0;ba=-$|0;ca=U<<24>>24==0;da=A;ea=1;fa=B;ga=C;ha=D;ia=I;ja=H;ka=F;la=Z;while(1){ma=da+k|0;na=fa&255;oa=da+l|0;pa=ga&255;qa=da+m|0;ra=ha&255;sa=ia&255;ta=da+e|0;ua=ja&255;va=da+n|0;wa=ka&255;xa=la&255;if(aa){ya=d[da+u|0]|0;za=(na+4+ua+(ra+pa+sa<<1)>>3)-ra|0;if((za|0)<(ba|0)){Aa=ba}else{Aa=(za|0)>($|0)?$:za}a[qa]=Aa+ra;qa=((na+2+pa+ra+sa|0)>>>2)-pa|0;if((qa|0)<(ba|0)){Ba=ba}else{Ba=(qa|0)>($|0)?$:qa}a[oa]=Ba+pa;oa=((na*3|0)+4+pa+ra+sa+(ya<<1)>>3)-na|0;if((oa|0)<(ba|0)){Ca=ba}else{Ca=(oa|0)>($|0)?$:oa}a[ma]=Ca+na}if(ca){na=(pa+4+wa+(sa+ra+ua<<1)>>3)-sa|0;if((na|0)<(ba|0)){Da=ba}else{Da=(na|0)>($|0)?$:na}a[da]=Da+sa;na=((ra+2+sa+ua+wa|0)>>>2)-ua|0;if((na|0)<(ba|0)){Ea=ba}else{Ea=(na|0)>($|0)?$:na}a[ta]=Ea+ua;ta=(ra+4+sa+ua+(wa*3|0)+(xa<<1)>>3)-wa|0;if((ta|0)<(ba|0)){Fa=ba}else{Fa=(ta|0)>($|0)?$:ta}a[va]=Fa+wa}wa=da+f|0;if((ea|0)>=4){break}va=a[da+(k+f)|0]|0;ta=a[da+(l+f)|0]|0;xa=a[da+(f-e)|0]|0;ua=a[da+(f+e)|0]|0;sa=a[da+(n+f)|0]|0;ra=a[da+(v+f)|0]|0;da=wa;ea=ea+1|0;fa=va;ga=ta;ha=xa;ia=a[wa]|0;ja=ua;ka=sa;la=ra}Ga=A+z|0;break a}}while(0);Z=S>>1;W=(R>>1)+R>>3;X=S*10|0;V=-S|0;Y=T<<24>>24!=0;_=U<<24>>24!=0;la=(N+G|0)<(W|0)&(Y^1);ka=-Z|0;ja=(P+L|0)<(W|0)&(_^1);W=A;ia=1;ha=B;ga=C;fa=D;ea=I;da=H;$=F;while(1){ba=ha&255;ca=W+l|0;aa=ga&255;ra=W+m|0;sa=fa&255;ua=ea&255;wa=W+e|0;xa=da&255;ta=$&255;va=((ua-sa|0)*9|0)+8+((xa-aa|0)*-3|0)>>4;do{if((((va|0)>-1?va:-va|0)|0)<(X|0)){if((va|0)<(V|0)){Ha=V}else{Ha=(va|0)>(S|0)?S:va}if(!Y){na=Ha+sa|0;if(na>>>0>255>>>0){Ia=-na>>31&255}else{Ia=na&255}a[ra]=Ia}if(!_){na=ua-Ha|0;if(na>>>0>255>>>0){Ja=-na>>31&255}else{Ja=na&255}a[W]=Ja}if(la){na=((ba+1+sa|0)>>>1)-aa+Ha>>1;if((na|0)<(ka|0)){Ka=ka}else{Ka=(na|0)>(Z|0)?Z:na}na=Ka+aa|0;if(na>>>0>255>>>0){La=-na>>31&255}else{La=na&255}a[ca]=La}if(!ja){break}na=((ua+1+ta|0)>>>1)-xa-Ha>>1;if((na|0)<(ka|0)){Ma=ka}else{Ma=(na|0)>(Z|0)?Z:na}na=Ma+xa|0;if(na>>>0>255>>>0){Na=-na>>31&255}else{Na=na&255}a[wa]=Na}}while(0);wa=W+f|0;if((ia|0)>=4){break}xa=a[W+(k+f)|0]|0;ta=a[W+(l+f)|0]|0;ua=a[W+(f-e)|0]|0;ca=a[W+(f+e)|0]|0;aa=a[W+(n+f)|0]|0;W=wa;ia=ia+1|0;ha=xa;ga=ta;fa=ua;ea=a[wa]|0;da=ca;$=aa}Ga=A+z|0}else{Ga=A+y|0}}while(0);S=b+1|0;if((S|0)<2){A=Ga;b=S}else{break}}return}function jJa(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;n=i;i=i+128|0;o=n|0;mrc(o|0,0,128)|0;p=(l|0)!=0|0;q=c[g+96+(l<<2)>>2]|0;do{if((m|0)==1){r=4>>>(p>>>0);if((c[h+8>>2]|0)==0){s=j-2-(8>>>(p>>>0))|0}else{s=j}t=0;u=-2-r|0;v=s;w=r+2|0}else if((m|0)==2){r=8>>>(p>>>0);x=-2-r|0;y=r+2|0;if((c[h+12>>2]|0)!=0){t=x;u=0;v=y;w=k;break}t=x;u=0;v=y;w=k-2-(4>>>(p>>>0))|0}else if((m|0)==3){y=4>>>(p>>>0);x=8>>>(p>>>0);t=-2-x|0;u=-2-y|0;v=x+2|0;w=y+2|0}else if((m|0)==0){if((c[h+8>>2]|0)==0){z=j-2-(8>>>(p>>>0))|0}else{z=j}if((c[h+12>>2]|0)!=0){t=0;u=0;v=z;w=k;break}t=0;u=0;v=z;w=k-2-(4>>>(p>>>0))|0}else{t=0;u=0;v=j;w=k}}while(0);k=(ca(u,f)|0)+t|0;c[o+((q&31)<<2)>>2]=c[g+120+(l*20|0)+4>>2];c[o+((q+1&31)<<2)>>2]=c[g+120+(l*20|0)+8>>2];c[o+((q+2&31)<<2)>>2]=c[g+120+(l*20|0)+12>>2];c[o+((q+3&31)<<2)>>2]=c[g+120+(l*20|0)+16>>2];if((w|0)<=0){i=n;return}l=(v|0)>0;g=e+k|0;e=0;q=b+k|0;while(1){if(l){k=0;do{b=d[g+k|0]|0;t=b+(c[o+(b>>>3<<2)>>2]|0)|0;if(t>>>0>255>>>0){A=-t>>31&255}else{A=t&255}a[q+k|0]=A;k=k+1|0;}while((k|0)<(v|0))}k=e+1|0;if((k|0)<(w|0)){g=g+f|0;e=k;q=q+f|0}else{break}}i=n;return}function kJa(d,f,g,h,i,j){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=d;d=f>>>1;f=g>>>1;g=d*-2|0;l=-d|0;m=c[h>>2]<<2;if((m|0)>=1){n=-m|0;o=(a[i]|0)==0;p=(a[j]|0)==0;q=k;r=0;while(1){s=q+(l<<1)|0;t=e[s>>1]|0;u=e[q>>1]|0;v=(e[q+(g<<1)>>1]|0)+4-(e[q+(d<<1)>>1]|0)+(u-t<<2)>>3;if((v|0)<(n|0)){w=n}else{w=(v|0)>(m|0)?m:v}if(o){v=w+t|0;if(v>>>0<1024>>>0){x=v&65535}else{x=-v>>31&1023}b[s>>1]=x}if(p){s=u-w|0;if(s>>>0<1024>>>0){y=s&65535}else{y=-s>>31&1023}b[q>>1]=y}s=r+1|0;if((s|0)<4){q=q+(f<<1)|0;r=s}else{break}}}r=c[h+4>>2]<<2;if((r|0)<1){return}h=-r|0;q=(a[i+1|0]|0)==0;i=(a[j+1|0]|0)==0;j=k+(f<<2<<1)|0;k=0;while(1){y=j+(l<<1)|0;w=e[y>>1]|0;p=e[j>>1]|0;x=(e[j+(g<<1)>>1]|0)+4-(e[j+(d<<1)>>1]|0)+(p-w<<2)>>3;if((x|0)<(h|0)){z=h}else{z=(x|0)>(r|0)?r:x}if(q){x=z+w|0;if(x>>>0<1024>>>0){A=x&65535}else{A=-x>>31&1023}b[y>>1]=A}if(i){y=p-z|0;if(y>>>0<1024>>>0){B=y&65535}else{B=-y>>31&1023}b[j>>1]=B}y=k+1|0;if((y|0)<4){j=j+(f<<1)|0;k=y}else{break}}return}function lJa(d,f,g,h,i,j,k){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;l=f>>>1;f=g>>>1;g=l*-3|0;m=l*-2|0;n=-l|0;o=l<<1;p=f*3|0;q=p+g|0;r=p+m|0;s=p-l|0;t=p+o|0;u=p+l|0;v=l*-4|0;w=l*3|0;x=p+v|0;y=(f+l|0)*3|0;z=f<<2;A=f<<2;B=d;d=0;while(1){C=b[B+(g<<1)>>1]|0;D=b[B+(m<<1)>>1]|0;E=b[B+(n<<1)>>1]|0;F=E&65535;G=(C&65535)-((D&65535)<<1)+F|0;H=(G|0)>-1?G:-G|0;G=b[B+(o<<1)>>1]|0;I=b[B+(l<<1)>>1]|0;J=b[B>>1]|0;K=J&65535;L=(G&65535)-((I&65535)<<1)+K|0;M=(L|0)>-1?L:-L|0;L=e[B+(s<<1)>>1]|0;N=(e[B+(q<<1)>>1]|0)-((e[B+(r<<1)>>1]|0)<<1)+L|0;O=(N|0)>-1?N:-N|0;N=e[B+(p<<1)>>1]|0;P=(e[B+(t<<1)>>1]|0)-((e[B+(u<<1)>>1]|0)<<1)+N|0;Q=(P|0)>-1?P:-P|0;P=M+H|0;R=Q+O|0;S=c[h+(d<<2)>>2]<<2;T=c[i+(d<<2)>>2]|0;U=T<<2;V=a[j+d|0]|0;W=a[k+d|0]|0;a:do{if((R+P|0)<(S|0)){X=S>>3;Y=S>>2;Z=(T*20|0)>>1;_=(e[B+(v<<1)>>1]|0)-F|0;$=b[B+(w<<1)>>1]|0;aa=($&65535)-K|0;do{if((((aa|0)>-1?aa:-aa|0)+((_|0)>-1?_:-_|0)|0)<(X|0)){ba=F-K|0;if((((ba|0)>-1?ba:-ba|0)|0)>=(Z|0)){break}ba=(e[B+(x<<1)>>1]|0)-L|0;ca=(e[B+(y<<1)>>1]|0)-N|0;if((((ca|0)>-1?ca:-ca|0)+((ba|0)>-1?ba:-ba|0)|0)>=(X|0)){break}ba=L-N|0;if((((ba|0)>-1?ba:-ba|0)|0)>=(Z|0)){break}if((P<<1|0)>=(Y|0)){break}if((R<<1|0)>=(Y|0)){break}ba=T<<3;ca=V<<24>>24==0;da=-ba|0;ea=W<<24>>24==0;fa=B;ga=1;ha=C;ia=D;ja=E;ka=J;la=I;ma=G;na=$;while(1){oa=fa+(g<<1)|0;pa=ha&65535;qa=fa+(m<<1)|0;ra=ia&65535;sa=fa+(n<<1)|0;ta=ja&65535;ua=ka&65535;va=fa+(l<<1)|0;wa=la&65535;xa=fa+(o<<1)|0;ya=ma&65535;za=na&65535;if(ca){Aa=e[fa+(v<<1)>>1]|0;Ba=(pa+4+wa+(ta+ra+ua<<1)>>3)-ta|0;if((Ba|0)<(da|0)){Ca=da}else{Ca=(Ba|0)>(ba|0)?ba:Ba}b[sa>>1]=Ca+ta;sa=((pa+2+ra+ta+ua|0)>>>2)-ra|0;if((sa|0)<(da|0)){Da=da}else{Da=(sa|0)>(ba|0)?ba:sa}b[qa>>1]=Da+ra;qa=((pa*3|0)+4+ra+ta+ua+(Aa<<1)>>3)-pa|0;if((qa|0)<(da|0)){Ea=da}else{Ea=(qa|0)>(ba|0)?ba:qa}b[oa>>1]=Ea+pa}if(ea){pa=(ra+4+ya+(ua+ta+wa<<1)>>3)-ua|0;if((pa|0)<(da|0)){Fa=da}else{Fa=(pa|0)>(ba|0)?ba:pa}b[fa>>1]=Fa+ua;pa=((ta+2+ua+wa+ya|0)>>>2)-wa|0;if((pa|0)<(da|0)){Ga=da}else{Ga=(pa|0)>(ba|0)?ba:pa}b[va>>1]=Ga+wa;va=(ta+4+ua+wa+(ya*3|0)+(za<<1)>>3)-ya|0;if((va|0)<(da|0)){Ha=da}else{Ha=(va|0)>(ba|0)?ba:va}b[xa>>1]=Ha+ya}ya=fa+(f<<1)|0;if((ga|0)>=4){break}xa=b[fa+(f+g<<1)>>1]|0;va=b[fa+(f+m<<1)>>1]|0;za=b[fa+(f-l<<1)>>1]|0;wa=b[fa+(f+l<<1)>>1]|0;ua=b[fa+(f+o<<1)>>1]|0;ta=b[fa+(f+w<<1)>>1]|0;fa=ya;ga=ga+1|0;ha=xa;ia=va;ja=za;ka=b[ya>>1]|0;la=wa;ma=ua;na=ta}Ia=B+(A<<1)|0;break a}}while(0);$=U>>1;Y=(S>>1)+S>>3;Z=T*40|0;X=-U|0;_=V<<24>>24!=0;aa=W<<24>>24!=0;na=(O+H|0)<(Y|0)&(_^1);ma=-$|0;la=(Q+M|0)<(Y|0)&(aa^1);Y=B;ka=1;ja=C;ia=D;ha=E;ga=J;fa=I;ba=G;while(1){da=ja&65535;ea=Y+(m<<1)|0;ca=ia&65535;ta=Y+(n<<1)|0;ua=ha&65535;wa=ga&65535;ya=Y+(l<<1)|0;za=fa&65535;va=ba&65535;xa=((wa-ua|0)*9|0)+8+((za-ca|0)*-3|0)>>4;do{if((((xa|0)>-1?xa:-xa|0)|0)<(Z|0)){if((xa|0)<(X|0)){Ja=X}else{Ja=(xa|0)>(U|0)?U:xa}if(!_){pa=Ja+ua|0;if(pa>>>0<1024>>>0){Ka=pa&65535}else{Ka=-pa>>31&1023}b[ta>>1]=Ka}if(!aa){pa=wa-Ja|0;if(pa>>>0<1024>>>0){La=pa&65535}else{La=-pa>>31&1023}b[Y>>1]=La}if(na){pa=((da+1+ua|0)>>>1)-ca+Ja>>1;if((pa|0)<(ma|0)){Ma=ma}else{Ma=(pa|0)>($|0)?$:pa}pa=Ma+ca|0;if(pa>>>0<1024>>>0){Na=pa&65535}else{Na=-pa>>31&1023}b[ea>>1]=Na}if(!la){break}pa=((wa+1+va|0)>>>1)-za-Ja>>1;if((pa|0)<(ma|0)){Oa=ma}else{Oa=(pa|0)>($|0)?$:pa}pa=Oa+za|0;if(pa>>>0<1024>>>0){Pa=pa&65535}else{Pa=-pa>>31&1023}b[ya>>1]=Pa}}while(0);ya=Y+(f<<1)|0;if((ka|0)>=4){break}za=b[Y+(f+g<<1)>>1]|0;va=b[Y+(f+m<<1)>>1]|0;wa=b[Y+(f-l<<1)>>1]|0;ea=b[Y+(f+l<<1)>>1]|0;ca=b[Y+(f+o<<1)>>1]|0;Y=ya;ka=ka+1|0;ja=za;ia=va;ha=wa;ga=b[ya>>1]|0;fa=ea;ba=ca}Ia=B+(A<<1)|0}else{Ia=B+(z<<1)|0}}while(0);U=d+1|0;if((U|0)<2){B=Ia;d=U}else{break}}return}function mJa(a,d,f,g,h,j,k,l,m){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;n=i;i=i+128|0;o=n|0;p=a;a=d;mrc(o|0,0,128)|0;d=(l|0)!=0|0;q=c[g+96+(l<<2)>>2]|0;r=f>>>1;do{if((m|0)==0){if((c[h+8>>2]|0)==0){s=j-2-(8>>>(d>>>0))|0}else{s=j}if((c[h+12>>2]|0)!=0){t=0;u=0;v=s;w=k;break}t=0;u=0;v=s;w=k-2-(4>>>(d>>>0))|0}else if((m|0)==2){f=8>>>(d>>>0);x=-2-f|0;y=f+2|0;if((c[h+12>>2]|0)!=0){t=x;u=0;v=y;w=k;break}t=x;u=0;v=y;w=k-2-(4>>>(d>>>0))|0}else if((m|0)==3){y=4>>>(d>>>0);x=8>>>(d>>>0);t=-2-x|0;u=-2-y|0;v=x+2|0;w=y+2|0}else if((m|0)==1){y=4>>>(d>>>0);if((c[h+8>>2]|0)==0){z=j-2-(8>>>(d>>>0))|0}else{z=j}t=0;u=-2-y|0;v=z;w=y+2|0}else{t=0;u=0;v=j;w=k}}while(0);k=(ca(u,r)|0)+t|0;c[o+((q&31)<<2)>>2]=c[g+120+(l*20|0)+4>>2];c[o+((q+1&31)<<2)>>2]=c[g+120+(l*20|0)+8>>2];c[o+((q+2&31)<<2)>>2]=c[g+120+(l*20|0)+12>>2];c[o+((q+3&31)<<2)>>2]=c[g+120+(l*20|0)+16>>2];if((w|0)<=0){i=n;return}l=(v|0)>0;g=a+(k<<1)|0;a=0;q=p+(k<<1)|0;while(1){if(l){k=0;do{p=e[g+(k<<1)>>1]|0;t=p+(c[o+(p>>>5<<2)>>2]|0)|0;if(t>>>0<1024>>>0){A=t&65535}else{A=-t>>31&1023}b[q+(k<<1)>>1]=A;k=k+1|0;}while((k|0)<(v|0))}k=a+1|0;if((k|0)<(w|0)){g=g+(r<<1)|0;a=k;q=q+(r<<1)|0}else{break}}i=n;return}function nJa(d,f,g,h,i,j){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=d;d=f>>>1;f=g>>>1;g=d*-2|0;l=-d|0;m=c[h>>2]<<1;if((m|0)>=1){n=-m|0;o=(a[i]|0)==0;p=(a[j]|0)==0;q=k;r=0;while(1){s=q+(l<<1)|0;t=e[s>>1]|0;u=e[q>>1]|0;v=(e[q+(g<<1)>>1]|0)+4-(e[q+(d<<1)>>1]|0)+(u-t<<2)>>3;if((v|0)<(n|0)){w=n}else{w=(v|0)>(m|0)?m:v}if(o){v=w+t|0;if(v>>>0<512>>>0){x=v&65535}else{x=-v>>31&511}b[s>>1]=x}if(p){s=u-w|0;if(s>>>0<512>>>0){y=s&65535}else{y=-s>>31&511}b[q>>1]=y}s=r+1|0;if((s|0)<4){q=q+(f<<1)|0;r=s}else{break}}}r=c[h+4>>2]<<1;if((r|0)<1){return}h=-r|0;q=(a[i+1|0]|0)==0;i=(a[j+1|0]|0)==0;j=k+(f<<2<<1)|0;k=0;while(1){y=j+(l<<1)|0;w=e[y>>1]|0;p=e[j>>1]|0;x=(e[j+(g<<1)>>1]|0)+4-(e[j+(d<<1)>>1]|0)+(p-w<<2)>>3;if((x|0)<(h|0)){z=h}else{z=(x|0)>(r|0)?r:x}if(q){x=z+w|0;if(x>>>0<512>>>0){A=x&65535}else{A=-x>>31&511}b[y>>1]=A}if(i){y=p-z|0;if(y>>>0<512>>>0){B=y&65535}else{B=-y>>31&511}b[j>>1]=B}y=k+1|0;if((y|0)<4){j=j+(f<<1)|0;k=y}else{break}}return}function oJa(d,f,g,h,i,j,k){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;l=f>>>1;f=g>>>1;g=l*-3|0;m=l*-2|0;n=-l|0;o=l<<1;p=f*3|0;q=p+g|0;r=p+m|0;s=p-l|0;t=p+o|0;u=p+l|0;v=l*-4|0;w=l*3|0;x=p+v|0;y=(f+l|0)*3|0;z=f<<2;A=f<<2;B=d;d=0;while(1){C=b[B+(g<<1)>>1]|0;D=b[B+(m<<1)>>1]|0;E=b[B+(n<<1)>>1]|0;F=E&65535;G=(C&65535)-((D&65535)<<1)+F|0;H=(G|0)>-1?G:-G|0;G=b[B+(o<<1)>>1]|0;I=b[B+(l<<1)>>1]|0;J=b[B>>1]|0;K=J&65535;L=(G&65535)-((I&65535)<<1)+K|0;M=(L|0)>-1?L:-L|0;L=e[B+(s<<1)>>1]|0;N=(e[B+(q<<1)>>1]|0)-((e[B+(r<<1)>>1]|0)<<1)+L|0;O=(N|0)>-1?N:-N|0;N=e[B+(p<<1)>>1]|0;P=(e[B+(t<<1)>>1]|0)-((e[B+(u<<1)>>1]|0)<<1)+N|0;Q=(P|0)>-1?P:-P|0;P=M+H|0;R=Q+O|0;S=c[h+(d<<2)>>2]<<1;T=c[i+(d<<2)>>2]|0;U=T<<1;V=a[j+d|0]|0;W=a[k+d|0]|0;a:do{if((R+P|0)<(S|0)){X=S>>3;Y=S>>2;Z=(T*10|0)>>1;_=(e[B+(v<<1)>>1]|0)-F|0;$=b[B+(w<<1)>>1]|0;aa=($&65535)-K|0;do{if((((aa|0)>-1?aa:-aa|0)+((_|0)>-1?_:-_|0)|0)<(X|0)){ba=F-K|0;if((((ba|0)>-1?ba:-ba|0)|0)>=(Z|0)){break}ba=(e[B+(x<<1)>>1]|0)-L|0;ca=(e[B+(y<<1)>>1]|0)-N|0;if((((ca|0)>-1?ca:-ca|0)+((ba|0)>-1?ba:-ba|0)|0)>=(X|0)){break}ba=L-N|0;if((((ba|0)>-1?ba:-ba|0)|0)>=(Z|0)){break}if((P<<1|0)>=(Y|0)){break}if((R<<1|0)>=(Y|0)){break}ba=T<<2;ca=V<<24>>24==0;da=-ba|0;ea=W<<24>>24==0;fa=B;ga=1;ha=C;ia=D;ja=E;ka=J;la=I;ma=G;na=$;while(1){oa=fa+(g<<1)|0;pa=ha&65535;qa=fa+(m<<1)|0;ra=ia&65535;sa=fa+(n<<1)|0;ta=ja&65535;ua=ka&65535;va=fa+(l<<1)|0;wa=la&65535;xa=fa+(o<<1)|0;ya=ma&65535;za=na&65535;if(ca){Aa=e[fa+(v<<1)>>1]|0;Ba=(pa+4+wa+(ta+ra+ua<<1)>>3)-ta|0;if((Ba|0)<(da|0)){Ca=da}else{Ca=(Ba|0)>(ba|0)?ba:Ba}b[sa>>1]=Ca+ta;sa=((pa+2+ra+ta+ua|0)>>>2)-ra|0;if((sa|0)<(da|0)){Da=da}else{Da=(sa|0)>(ba|0)?ba:sa}b[qa>>1]=Da+ra;qa=((pa*3|0)+4+ra+ta+ua+(Aa<<1)>>3)-pa|0;if((qa|0)<(da|0)){Ea=da}else{Ea=(qa|0)>(ba|0)?ba:qa}b[oa>>1]=Ea+pa}if(ea){pa=(ra+4+ya+(ua+ta+wa<<1)>>3)-ua|0;if((pa|0)<(da|0)){Fa=da}else{Fa=(pa|0)>(ba|0)?ba:pa}b[fa>>1]=Fa+ua;pa=((ta+2+ua+wa+ya|0)>>>2)-wa|0;if((pa|0)<(da|0)){Ga=da}else{Ga=(pa|0)>(ba|0)?ba:pa}b[va>>1]=Ga+wa;va=(ta+4+ua+wa+(ya*3|0)+(za<<1)>>3)-ya|0;if((va|0)<(da|0)){Ha=da}else{Ha=(va|0)>(ba|0)?ba:va}b[xa>>1]=Ha+ya}ya=fa+(f<<1)|0;if((ga|0)>=4){break}xa=b[fa+(f+g<<1)>>1]|0;va=b[fa+(f+m<<1)>>1]|0;za=b[fa+(f-l<<1)>>1]|0;wa=b[fa+(f+l<<1)>>1]|0;ua=b[fa+(f+o<<1)>>1]|0;ta=b[fa+(f+w<<1)>>1]|0;fa=ya;ga=ga+1|0;ha=xa;ia=va;ja=za;ka=b[ya>>1]|0;la=wa;ma=ua;na=ta}Ia=B+(A<<1)|0;break a}}while(0);$=U>>1;Y=(S>>1)+S>>3;Z=T*20|0;X=-U|0;_=V<<24>>24!=0;aa=W<<24>>24!=0;na=(O+H|0)<(Y|0)&(_^1);ma=-$|0;la=(Q+M|0)<(Y|0)&(aa^1);Y=B;ka=1;ja=C;ia=D;ha=E;ga=J;fa=I;ba=G;while(1){da=ja&65535;ea=Y+(m<<1)|0;ca=ia&65535;ta=Y+(n<<1)|0;ua=ha&65535;wa=ga&65535;ya=Y+(l<<1)|0;za=fa&65535;va=ba&65535;xa=((wa-ua|0)*9|0)+8+((za-ca|0)*-3|0)>>4;do{if((((xa|0)>-1?xa:-xa|0)|0)<(Z|0)){if((xa|0)<(X|0)){Ja=X}else{Ja=(xa|0)>(U|0)?U:xa}if(!_){pa=Ja+ua|0;if(pa>>>0<512>>>0){Ka=pa&65535}else{Ka=-pa>>31&511}b[ta>>1]=Ka}if(!aa){pa=wa-Ja|0;if(pa>>>0<512>>>0){La=pa&65535}else{La=-pa>>31&511}b[Y>>1]=La}if(na){pa=((da+1+ua|0)>>>1)-ca+Ja>>1;if((pa|0)<(ma|0)){Ma=ma}else{Ma=(pa|0)>($|0)?$:pa}pa=Ma+ca|0;if(pa>>>0<512>>>0){Na=pa&65535}else{Na=-pa>>31&511}b[ea>>1]=Na}if(!la){break}pa=((wa+1+va|0)>>>1)-za-Ja>>1;if((pa|0)<(ma|0)){Oa=ma}else{Oa=(pa|0)>($|0)?$:pa}pa=Oa+za|0;if(pa>>>0<512>>>0){Pa=pa&65535}else{Pa=-pa>>31&511}b[ya>>1]=Pa}}while(0);ya=Y+(f<<1)|0;if((ka|0)>=4){break}za=b[Y+(f+g<<1)>>1]|0;va=b[Y+(f+m<<1)>>1]|0;wa=b[Y+(f-l<<1)>>1]|0;ea=b[Y+(f+l<<1)>>1]|0;ca=b[Y+(f+o<<1)>>1]|0;Y=ya;ka=ka+1|0;ja=za;ia=va;ha=wa;ga=b[ya>>1]|0;fa=ea;ba=ca}Ia=B+(A<<1)|0}else{Ia=B+(z<<1)|0}}while(0);U=d+1|0;if((U|0)<2){B=Ia;d=U}else{break}}return}function pJa(a,d,f,g,h,j,k,l,m){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;n=i;i=i+128|0;o=n|0;p=a;a=d;mrc(o|0,0,128)|0;d=(l|0)!=0|0;q=c[g+96+(l<<2)>>2]|0;r=f>>>1;do{if((m|0)==1){f=4>>>(d>>>0);if((c[h+8>>2]|0)==0){s=j-2-(8>>>(d>>>0))|0}else{s=j}t=0;u=-2-f|0;v=s;w=f+2|0}else if((m|0)==2){f=8>>>(d>>>0);x=-2-f|0;y=f+2|0;if((c[h+12>>2]|0)!=0){t=x;u=0;v=y;w=k;break}t=x;u=0;v=y;w=k-2-(4>>>(d>>>0))|0}else if((m|0)==0){if((c[h+8>>2]|0)==0){z=j-2-(8>>>(d>>>0))|0}else{z=j}if((c[h+12>>2]|0)!=0){t=0;u=0;v=z;w=k;break}t=0;u=0;v=z;w=k-2-(4>>>(d>>>0))|0}else if((m|0)==3){y=4>>>(d>>>0);x=8>>>(d>>>0);t=-2-x|0;u=-2-y|0;v=x+2|0;w=y+2|0}else{t=0;u=0;v=j;w=k}}while(0);k=(ca(u,r)|0)+t|0;c[o+((q&31)<<2)>>2]=c[g+120+(l*20|0)+4>>2];c[o+((q+1&31)<<2)>>2]=c[g+120+(l*20|0)+8>>2];c[o+((q+2&31)<<2)>>2]=c[g+120+(l*20|0)+12>>2];c[o+((q+3&31)<<2)>>2]=c[g+120+(l*20|0)+16>>2];if((w|0)>0&(v|0)>0){A=a+(k<<1)|0;B=0;C=p+(k<<1)|0}else{i=n;return}while(1){k=0;do{p=e[A+(k<<1)>>1]|0;a=p+(c[o+(p>>>4<<2)>>2]|0)|0;if(a>>>0<512>>>0){D=a&65535}else{D=-a>>31&511}b[C+(k<<1)>>1]=D;k=k+1|0;}while((k|0)<(v|0));k=B+1|0;if((k|0)<(w|0)){A=A+(r<<1)|0;B=k;C=C+(r<<1)|0}else{break}}i=n;return}function qJa(a,b){a=a|0;b=b|0;if((b|0)==9){c[a>>2]=158;c[a+4>>2]=336;c[a+8>>2]=506;c[a+12>>2]=600;c[a+16>>2]=1034;c[a+20>>2]=188;c[a+24>>2]=66;c[a+28>>2]=214;c[a+32>>2]=168;c[a+36>>2]=310;return}else if((b|0)==10){c[a>>2]=202;c[a+4>>2]=536;c[a+8>>2]=712;c[a+12>>2]=406;c[a+16>>2]=710;c[a+20>>2]=30;c[a+24>>2]=144;c[a+28>>2]=250;c[a+32>>2]=142;c[a+36>>2]=14;return}else{c[a>>2]=160;c[a+4>>2]=338;c[a+8>>2]=752;c[a+12>>2]=602;c[a+16>>2]=1032;c[a+20>>2]=190;c[a+24>>2]=78;c[a+28>>2]=216;c[a+32>>2]=260;c[a+36>>2]=312;return}}function rJa(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;l=i;i=i+544|0;m=l|0;n=l+136|0;o=l+272|0;p=l+408|0;q=c[f+136>>2]|0;r=c[f+180>>2]|0;s=c[r+13140+(k<<2)>>2]|0;t=c[r+13152+(k<<2)>>2]|0;u=1<<j;v=u<<s;w=c[r+13072>>2]|0;x=v>>w;y=g>>w;z=h>>w;w=c[r+13124>>2]|0;A=(ca(z,w)|0)+y|0;B=c[f+184>>2]|0;C=c[B+1672>>2]|0;D=c[C+(A<<2)>>2]|0;A=c[f+160>>2]|0;E=(c[A+32+(k<<2)>>2]|0)>>>1;F=c[A+(k<<2)>>2]|0;A=(ca(E,h>>t)|0)+(g>>s)|0;G=F+(A<<1)|0;H=c[r+13132>>2]|0;if((k|0)==0){I=c[q+173192>>2]|0}else{I=d[q+184621|0]|0}J=m+2|0;K=o+2|0;L=n+2|0;M=p+2|0;if((c[q+184624>>2]|0)==0){N=0}else{N=(D|0)>(c[C+(y-1+(ca(w,z+x|0)|0)<<2)>>2]|0)}O=N&1;P=c[q+184628>>2]|0;Q=c[q+184636>>2]|0;R=c[q+184632>>2]|0;if((c[q+184640>>2]|0)==0){S=0}else{S=(D|0)>(c[C+(y+x+(ca(w,z-1|0)|0)<<2)>>2]|0)}z=S&1;w=v<<1;x=w+h|0;y=c[r+13100>>2]|0;C=v+h|0;D=((x|0)>(y|0)?y:x)-C>>t;x=w+g|0;w=c[r+13096>>2]|0;q=v+g|0;T=((x|0)>(w|0)?w:x)-q>>s;x=B+20|0;if((a[x]|0)==1){B=c[r+13084>>2]|0;U=v>>B;v=(1<<B)-1|0;V=v&h;W=((U|0)==0)+U|0;U=(v&g|0)!=0;do{if(U|N^1){X=O}else{v=g-1>>B;Y=C>>B;Z=(c[r+13136>>2]|0)-Y|0;_=(W|0)>(Z|0)?Z:W;if((_|0)<=0){X=0;break}Z=c[(c[f+3480>>2]|0)+16>>2]|0;$=0;aa=0;while(1){ba=d[Z+(((ca(aa+Y|0,H)|0)+v|0)*14|0)+12|0]|$;da=aa+1|0;if((da|0)<(_|0)){$=ba;aa=da}else{X=ba;break}}}}while(0);do{if((P|0)!=1|U){ea=P}else{C=g-1>>B;N=h>>B;aa=(c[r+13136>>2]|0)-N|0;$=(W|0)>(aa|0)?aa:W;if(($|0)<=0){ea=0;break}aa=c[(c[f+3480>>2]|0)+16>>2]|0;_=0;v=0;while(1){Y=d[aa+(((ca(v+N|0,H)|0)+C|0)*14|0)+12|0]|_;Z=v+1|0;if((Z|0)<($|0)){_=Y;v=Z}else{ea=Y;break}}}}while(0);if((Q|0)==1){U=(ca(h-1>>B,H)|0)+(g-1>>B)|0;fa=d[(c[(c[f+3480>>2]|0)+16>>2]|0)+(U*14|0)+12|0]|0}else{fa=Q}U=(V|0)!=0;do{if((R|0)!=1|U){ga=R}else{V=g>>B;v=H-V|0;_=(W|0)>(v|0)?v:W;if((_|0)<=0){ga=0;break}v=(ca(h-1>>B,H)|0)+V|0;V=c[(c[f+3480>>2]|0)+16>>2]|0;$=0;C=0;while(1){N=d[V+((v+C|0)*14|0)+12|0]|$;aa=C+1|0;if((aa|0)<(_|0)){$=N;C=aa}else{ga=N;break}}}}while(0);do{if(U|S^1){ha=z}else{C=q>>B;$=H-C|0;_=(W|0)>($|0)?$:W;if((_|0)<=0){ha=0;break}$=(ca(h-1>>B,H)|0)+C|0;C=c[(c[f+3480>>2]|0)+16>>2]|0;v=0;V=0;while(1){N=d[C+(($+V|0)*14|0)+12|0]|v;aa=V+1|0;if((aa|0)<(_|0)){v=N;V=aa}else{ha=N;break}}}}while(0);B=0;while(1){W=B+1|0;b[m+(W<<1)>>1]=128;b[o+(W<<1)>>1]=128;if((W|0)<64){B=W}else{ia=X;ja=ea;ka=fa;la=ga;ma=ha;break}}}else{ia=O;ja=P;ka=Q;la=R;ma=z}z=(ia|0)!=0;do{if(z){R=D+u|0;Q=u<<1;if((R|0)<(Q|0)){P=(-1<<s)+g|0;O=R-1|0;ha=(O<<t)+h|0;ga=F+(A-1+(ca(O,E)|0)<<1)|0;fa=c[r+13084>>2]|0;ea=c[(c[f+3480>>2]|0)+16>>2]|0;X=R;while(1){do{if((a[ea+(((ca(ha>>fa,H)|0)+(P>>fa)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=38;break}oa=X+1|0}else{na=38}}while(0);if((na|0)==38){na=0;B=X+1|0;b[m+(B<<1)>>1]=b[ga>>1]|0;oa=B}if((oa|0)<(Q|0)){X=oa}else{pa=O;break}}}else{pa=R-1|0}if((pa|0)<(u|0)){break}O=(-1<<s)+g|0;X=A-1|0;Q=c[r+13084>>2]|0;ga=c[(c[f+3480>>2]|0)+16>>2]|0;fa=R;P=pa;while(1){if((a[ga+(((ca((P<<t)+h>>Q,H)|0)+(O>>Q)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=43}}else{na=43}if((na|0)==43){na=0;b[m+(fa<<1)>>1]=b[F+(X+(ca(P,E)|0)<<1)>>1]|0}ha=P-1|0;if((ha|0)<(u|0)){break}else{fa=P;P=ha}}}}while(0);pa=(ja|0)!=0;if(pa&(u|0)>0){oa=(-1<<s)+g|0;P=A-1|0;fa=c[r+13084>>2]|0;X=c[(c[f+3480>>2]|0)+16>>2]|0;Q=u;while(1){O=Q-1|0;if((a[X+(((ca((O<<t)+h>>fa,H)|0)+(oa>>fa)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=49}}else{na=49}if((na|0)==49){na=0;b[m+(Q<<1)>>1]=b[F+(P+(ca(O,E)|0)<<1)>>1]|0}if((O|0)>0){Q=O}else{break}}}Q=(ka|0)!=0;do{if(Q){P=c[r+13084>>2]|0;fa=(ca((-1<<t)+h>>P,H)|0)+((-1<<s)+g>>P)|0;if((a[(c[(c[f+3480>>2]|0)+16>>2]|0)+(fa*14|0)+12|0]|0)==0){if((a[x]|0)!=0){break}}fa=b[F+(A+~E<<1)>>1]|0;b[m>>1]=fa;b[o>>1]=fa}}while(0);fa=(la|0)!=0;if(fa&(u|0)>0){P=(-1<<t)+h|0;oa=A-E|0;X=c[r+13084>>2]|0;O=c[(c[f+3480>>2]|0)+16>>2]|0;ga=u;while(1){R=ga-1|0;if((a[O+(((ca(P>>X,H)|0)+((R<<s)+g>>X)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=59}}else{na=59}if((na|0)==59){na=0;b[o+(ga<<1)>>1]=b[F+(oa+R<<1)>>1]|0}if((R|0)>0){ga=R}else{break}}}ga=(ma|0)!=0;do{if(ga){oa=T+u|0;X=u<<1;P=oa-1|0;if((oa|0)<(X|0)){O=(P<<s)+g|0;R=(-1<<t)+h|0;ha=F+(A-E+P<<1)|0;ea=c[r+13084>>2]|0;B=c[(c[f+3480>>2]|0)+16>>2]|0;W=oa;while(1){do{if((a[B+(((ca(R>>ea,H)|0)+(O>>ea)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=68;break}qa=W+1|0}else{na=68}}while(0);if((na|0)==68){na=0;S=W+1|0;b[o+(S<<1)>>1]=b[ha>>1]|0;qa=S}if((qa|0)<(X|0)){W=qa}else{break}}}if((P|0)<(u|0)){break}W=(-1<<t)+h|0;X=A-E|0;ha=c[r+13084>>2]|0;ea=c[(c[f+3480>>2]|0)+16>>2]|0;O=oa;R=P;while(1){if((a[ea+(((ca(W>>ha,H)|0)+((R<<s)+g>>ha)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=73}}else{na=73}if((na|0)==73){na=0;b[o+(O<<1)>>1]=b[F+(X+R<<1)>>1]|0}B=R-1|0;if((B|0)<(u|0)){break}else{O=R;R=B}}}}while(0);do{if((a[x]|0)==1){F=ia|ja;A=(F|0)!=0;qa=F|ka;F=(qa|0)==0;if((la|ma|qa|0)==0){break}qa=u<<1;if(((qa<<s)+g|0)<(w|0)){ra=qa}else{ra=w-g>>s}if(((qa<<t)+h|0)<(y|0)){sa=qa}else{sa=y-h>>t}T=(z?D:0)+u|0;do{if(ga){ta=ra}else{if((q|0)<(w|0)){ta=u;break}ta=w-g>>s}}while(0);do{if(z){ua=sa}else{if(((u<<t)+h|0)<(y|0)){ua=u;break}ua=y-h>>t}}while(0);do{if(F){R=(-1<<t)+h|0;O=f+3480|0;X=0;while(1){if((X|0)>=(ta|0)){break}ha=c[r+13084>>2]|0;W=(ca(R>>ha,H)|0)+((X<<s)+g>>ha)|0;if((a[(c[(c[O>>2]|0)+16>>2]|0)+(W*14|0)+12|0]|0)==0){X=X+1|0}else{break}}do{if((X|0)>0){if((g|0)>0){if(!((X|0)>-1)){break}W=c[r+13084>>2]|0;ha=c[(c[O>>2]|0)+16>>2]|0;ea=X;while(1){P=ea-1|0;if((a[ha+(((ca(R>>W,H)|0)+((P<<s)+g>>W)|0)*14|0)+12|0]|0)==0){b[o+(ea<<1)>>1]=b[o+(ea+1<<1)>>1]|0}if((ea|0)>0){ea=P}else{break}}}else{ea=c[r+13084>>2]|0;W=c[(c[O>>2]|0)+16>>2]|0;ha=X;while(1){P=ha-1|0;if((a[W+(((ca(R>>ea,H)|0)+((P<<s)+g>>ea)|0)*14|0)+12|0]|0)==0){b[o+(ha<<1)>>1]=b[o+(ha+1<<1)>>1]|0}if((P|0)>0){ha=P}else{break}}b[o>>1]=b[K>>1]|0;break}}}while(0);b[m>>1]=b[o>>1]|0;va=0}else{R=(-1<<s)+g|0;X=f+3480|0;O=T;while(1){wa=O-1|0;xa=c[r+13084>>2]|0;if((O|0)<=0){na=90;break}ha=(wa<<t)+h|0;ea=(ca(ha>>xa,H)|0)+(R>>xa)|0;W=c[(c[X>>2]|0)+16>>2]|0;if((a[W+(ea*14|0)+12|0]|0)==0){O=wa}else{ya=W;za=ha;break}}if((na|0)==90){ya=c[(c[X>>2]|0)+16>>2]|0;za=(wa<<t)+h|0}if((a[ya+(((ca(za>>xa,H)|0)+(R>>xa)|0)*14|0)+12|0]|0)!=0){va=wa;break}O=(-1<<t)+h|0;ha=0;while(1){if((ha|0)>=(ta|0)){break}if((a[ya+(((ca(O>>xa,H)|0)+((ha<<s)+g>>xa)|0)*14|0)+12|0]|0)==0){ha=ha+1|0}else{break}}if((ha|0)>-1){R=ha;while(1){X=R-1|0;if((a[ya+(((ca(O>>xa,H)|0)+((X<<s)+g>>xa)|0)*14|0)+12|0]|0)==0){b[o+(R<<1)>>1]=b[o+(R+1<<1)>>1]|0}if((R|0)>0){R=X}else{break}}}b[m>>1]=b[o>>1]|0;va=0}}while(0);if(A&(va|0)<(ua|0)){T=(-1<<s)+g|0;F=c[r+13084>>2]|0;R=c[(c[f+3480>>2]|0)+16>>2]|0;O=va;while(1){if((a[R+(((ca((O<<t)+h>>F,H)|0)+(T>>F)|0)*14|0)+12|0]|0)==0){ha=O+1|0;b[m+(ha<<1)>>1]=b[m+(O<<1)>>1]|0;Aa=ha}else{Aa=O+1|0}if((Aa|0)<(ua|0)){O=Aa}else{break}}}a:do{if((u|0)>0&(pa^1)){O=b[m>>1]|0;F=1;while(1){b[m+(F<<1)>>1]=O;if((F|0)>=(u|0)){break a}F=F+1|0}}}while(0);if((u|0)<(qa|0)&(z^1)){F=b[m+(u<<1)>>1]|0;O=u;do{O=O+1|0;b[m+(O<<1)>>1]=F;}while((O|0)<(qa|0))}qa=(g|0)==0;O=(h|0)==0;b:do{if(qa|O){F=ua-1|0;if(qa){if((ua|0)<=0){break}T=b[m+(ua<<1)>>1]|0;R=F;while(1){b[m+(R<<1)>>1]=T;if((R|0)>0){R=R-1|0}else{break b}}}if((F|0)<=0){break}R=(-1<<s)+g|0;T=c[r+13084>>2]|0;A=c[(c[f+3480>>2]|0)+16>>2]|0;ha=F;while(1){X=ha-1|0;if((a[A+(((ca((X<<t)+h>>T,H)|0)+(R>>T)|0)*14|0)+12|0]|0)==0){b[m+(ha<<1)>>1]=b[m+(ha+1<<1)>>1]|0}if((X|0)>0){ha=X}else{break}}}else{if((ua|0)<=0){break}ha=(-1<<s)+g|0;T=c[r+13084>>2]|0;R=c[(c[f+3480>>2]|0)+16>>2]|0;A=ua;while(1){F=A-1|0;if((a[R+(((ca((A-2<<t)+h>>T,H)|0)+(ha>>T)|0)*14|0)+12|0]|0)==0){b[m+(F<<1)>>1]=b[m+(A<<1)>>1]|0}if((F|0)>0){A=F}else{break}}}}while(0);b[o>>1]=b[m>>1]|0;if(!((ta|0)>0&(O^1))){break}qa=(-1<<t)+h|0;A=c[r+13084>>2]|0;T=c[(c[f+3480>>2]|0)+16>>2]|0;ha=0;while(1){if((a[T+(((ca(qa>>A,H)|0)+((ha<<s)+g>>A)|0)*14|0)+12|0]|0)==0){R=ha+1|0;b[o+(R<<1)>>1]=b[o+(ha<<1)>>1]|0;Ba=R}else{Ba=ha+1|0}if((Ba|0)<(ta|0)){ha=Ba}else{break}}}}while(0);c:do{if(z){na=176}else{if(pa){Ba=u<<1;if((u|0)>=(Ba|0)){na=176;break}ta=b[m+(u<<1)>>1]|0;g=u;while(1){s=g+1|0;b[m+(s<<1)>>1]=ta;if((s|0)<(Ba|0)){g=s}else{na=176;break c}}}if(Q){g=u<<1;if((g|0)<=0){na=178;break}Ba=b[m>>1]|0;ta=1;while(1){b[m+(ta<<1)>>1]=Ba;if((ta|0)>=(g|0)){na=178;break c}ta=ta+1|0}}if(fa){ta=b[K>>1]|0;b[m>>1]=ta;g=u<<1;if((g|0)>0){Ca=1}else{na=180;break}while(1){b[m+(Ca<<1)>>1]=ta;if((Ca|0)>=(g|0)){na=180;break c}Ca=Ca+1|0}}if(ga){if((u|0)>0){g=u;do{b[o+(g<<1)>>1]=b[o+(g+1<<1)>>1]|0;g=g-1|0;}while((g|0)>0)}g=b[K>>1]|0;b[m>>1]=g;ta=u<<1;if((ta|0)>0){Da=1}else{break}while(1){b[m+(Da<<1)>>1]=g;if((Da|0)>=(ta|0)){break c}Da=Da+1|0}}b[m>>1]=256;b[K>>1]=256;ta=u<<1;d:do{if((ta|0)>1){g=2;while(1){b[o+(g<<1)>>1]=256;if((g|0)>=(ta|0)){break d}g=g+1|0}}}while(0);if((ta|0)>0){Ea=1}else{na=176;break}while(1){b[m+(Ea<<1)>>1]=256;if((Ea|0)>=(ta|0)){na=176;break c}Ea=Ea+1|0}}}while(0);do{if((na|0)==176){if((ja|0)==0&(u|0)>0){Fa=u}else{na=178;break}while(1){b[m+(Fa<<1)>>1]=b[m+(Fa+1<<1)>>1]|0;Ea=Fa-1|0;if((Ea|0)>0){Fa=Ea}else{na=178;break}}}}while(0);do{if((na|0)==178){if((ka|0)!=0){na=180;break}b[m>>1]=b[J>>1]|0;na=180}}while(0);e:do{if((na|0)==180){if((la|0)!=0){break}ka=b[m>>1]|0;b[K>>1]=ka;if((u|0)>1){Ga=2}else{break}while(1){b[o+(Ga<<1)>>1]=ka;if((Ga|0)>=(u|0)){break e}Ga=Ga+1|0}}}while(0);do{if(!ga){Ga=u<<1;if((u|0)>=(Ga|0)){break}la=b[o+(u<<1)>>1]|0;na=u;do{na=na+1|0;b[o+(na<<1)>>1]=la;}while((na|0)<(Ga|0))}}while(0);ga=m|0;Ga=b[ga>>1]|0;b[o>>1]=Ga;f:do{if((k|0)!=0|(I|0)==1|(u|0)==4){Ha=J;Ia=K}else{na=I-26|0;la=(na|0)>-1?na:26-I|0;na=I-10|0;ka=(na|0)>-1?na:10-I|0;if((((la|0)>(ka|0)?ka:la)|0)<=(c[1064480+(j-3<<2)>>2]|0)){Ha=J;Ia=K;break}do{if((a[r+13061|0]|0)!=0&(j|0)==5){la=Ga&65535;ka=b[o+128>>1]|0;na=ka&65535;Fa=na+la-(e[o+64>>1]<<1)|0;if((((Fa|0)>-1?Fa:-Fa|0)|0)>=16){break}Fa=m+128|0;ja=b[Fa>>1]|0;Ea=(ja&65535)+la-(e[m+64>>1]<<1)|0;if((((Ea|0)>-1?Ea:-Ea|0)|0)>=16){break}b[p>>1]=Ga;b[p+128>>1]=ka;ka=0;while(1){Ea=ka+1|0;b[p+(Ea<<1)>>1]=((ca(la,63-ka|0)|0)+32+(ca(na,Ea)|0)|0)>>>6;if((Ea|0)<63){ka=Ea}else{Ja=0;Ka=Ga;La=ja;break}}while(1){ja=Ja+1|0;b[m+(ja<<1)>>1]=((ca(Ka&65535,63-Ja|0)|0)+32+(ca(La&65535,ja)|0)|0)>>>6;if((ja|0)>=63){Ha=J;Ia=M;break f}Ja=ja;Ka=b[ga>>1]|0;La=b[Fa>>1]|0}}}while(0);Fa=u<<1;ja=b[m+(Fa<<1)>>1]|0;b[n+(Fa<<1)>>1]=ja;ka=b[o+(Fa<<1)>>1]|0;b[p+(Fa<<1)>>1]=ka;na=Fa-2|0;Fa=(na|0)>-1;if(Fa){la=na;Ea=ja;while(1){ja=la+1|0;Da=b[m+(ja<<1)>>1]|0;b[n+(ja<<1)>>1]=((Ea&65535)+2+((Da&65535)<<1)+(e[m+(la<<1)>>1]|0)|0)>>>2;if((la|0)>0){la=la-1|0;Ea=Da}else{break}}}Ea=((e[J>>1]|0)+2+((Ga&65535)<<1)+(e[K>>1]|0)|0)>>>2&65535;b[n>>1]=Ea;b[p>>1]=Ea;if(Fa){Ma=na;Na=ka}else{Ha=L;Ia=M;break}while(1){Ea=Ma+1|0;la=b[o+(Ea<<1)>>1]|0;b[p+(Ea<<1)>>1]=((Na&65535)+2+((la&65535)<<1)+(e[o+(Ma<<1)>>1]|0)|0)>>>2;if((Ma|0)>0){Ma=Ma-1|0;Na=la}else{Ha=L;Ia=M;break}}}}while(0);if((I|0)==0){mf[c[f+5824+(j-2<<2)>>2]&2047](G,Ia,Ha,E);i=l;return}else if((I|0)==1){_e[c[f+5840>>2]&511](G,Ia,Ha,E,j,k);i=l;return}else{_e[c[f+5844+(j-2<<2)>>2]&511](G,Ia,Ha,E,k,I);i=l;return}}function sJa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=a;a=c;h=d;i=c+8|0;j=d+8|0;d=0;while(1){k=h+(d<<1)|0;l=3-d|0;m=d+1|0;n=ca(d,f)|0;o=ca(e[a>>1]|0,l)|0;b[g+(n<<1)>>1]=(((e[k>>1]|0)*3|0)+4+(e[i>>1]|0)+o+(ca(e[j>>1]|0,m)|0)|0)>>>3;o=ca(e[c+2>>1]|0,l)|0;b[g+(n+1<<1)>>1]=(((e[k>>1]|0)<<1)+4+((e[i>>1]|0)<<1)+o+(ca(e[j>>1]|0,m)|0)|0)>>>3;o=ca(e[c+4>>1]|0,l)|0;b[g+(n+2<<1)>>1]=((e[k>>1]|0)+4+((e[i>>1]|0)*3|0)+o+(ca(e[j>>1]|0,m)|0)|0)>>>3;o=ca(e[c+6>>1]|0,l)|0;b[g+(n+3<<1)>>1]=(((e[i>>1]|0)<<2)+4+o+(ca(e[j>>1]|0,m)|0)|0)>>>3;if((m|0)<4){d=m}else{break}}return}function tJa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+16|0;c=d+16|0;d=0;while(1){j=h+(d<<1)|0;k=7-d|0;l=d+1|0;m=ca(d,f)|0;n=0;while(1){o=ca(e[j>>1]|0,7-n|0)|0;p=n+1|0;q=ca(e[i>>1]|0,p)|0;r=ca(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+8+q+r+(ca(e[c>>1]|0,l)|0)|0)>>>4;if((p|0)<8){n=p}else{break}}if((l|0)<8){d=l}else{break}}return}function uJa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+32|0;c=d+32|0;d=0;while(1){j=h+(d<<1)|0;k=15-d|0;l=d+1|0;m=ca(d,f)|0;n=0;while(1){o=ca(e[j>>1]|0,15-n|0)|0;p=n+1|0;q=ca(e[i>>1]|0,p)|0;r=ca(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+16+q+r+(ca(e[c>>1]|0,l)|0)|0)>>>5;if((p|0)<16){n=p}else{break}}if((l|0)<16){d=l}else{break}}return}function vJa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+64|0;c=d+64|0;d=0;while(1){j=h+(d<<1)|0;k=31-d|0;l=d+1|0;m=ca(d,f)|0;n=0;while(1){o=ca(e[j>>1]|0,31-n|0)|0;p=n+1|0;q=ca(e[i>>1]|0,p)|0;r=ca(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+32+q+r+(ca(e[c>>1]|0,l)|0)|0)>>>6;if((p|0)<32){n=p}else{break}}if((l|0)<32){d=l}else{break}}return}function wJa(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=1<<h;k=a;a=d;d=f;f=(j|0)>0;do{if(f){l=j;m=0;do{l=(e[d+(m<<1)>>1]|0)+l+(e[a+(m<<1)>>1]|0)|0;m=m+1|0;}while((m|0)<(j|0));m=l>>h+1;n=Erc(m,(m|0)<0|0?-1:0,65537,65537)|0;o=G;if(!f){p=m;break}q=(j|0)/4|0;if((j|0)>3){r=0}else{p=m;break}while(1){s=ca(r,g)|0;t=0;do{u=k+((t<<2)+s<<1)|0;c[u>>2]=n;c[u+4>>2]=o;t=t+1|0;}while((t|0)<(q|0));t=r+1|0;if((t|0)<(j|0)){r=t}else{p=m;break}}}else{p=j>>h+1}}while(0);if(!((i|0)==0&(j|0)<32)){return}b[k>>1]=((p<<1)+2+(e[d>>1]|0)+(e[a>>1]|0)|0)>>>2;i=(j|0)>1;if(!i){return}h=(p*3|0)+2|0;r=1;do{b[k+(r<<1)>>1]=(h+(e[a+(r<<1)>>1]|0)|0)>>>2;r=r+1|0;}while((r|0)<(j|0));if(!i){return}i=(p*3|0)+2|0;p=1;do{b[k+((ca(p,g)|0)<<1)>>1]=(i+(e[d+(p<<1)>>1]|0)|0)>>>2;p=p+1|0;}while((p|0)<(j|0));return}function xJa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;k=i;i=i+200|0;l=k|0;m=a;n=d;o=f;p=c[700008+(j-2<<2)>>2]|0;q=l+8|0;r=p>>3;if((j|0)>17){s=d-2|0;t=s;u=j-11|0;do{if(u>>>0<15>>>0&(r|0)<-1){v=q;b[v>>1]=b[s>>1]|0;b[v+2>>1]=b[s+2>>1]|0;b[v+4>>1]=b[s+4>>1]|0;b[v+6>>1]=b[s+6>>1]|0;b[v+8>>1]=b[s+8>>1]|0;if((r|0)>=0){w=q;break}v=c[699944+(u<<2)>>2]|0;x=r;while(1){b[l+(x+4<<1)>>1]=b[o+(((ca(x,v)|0)+128>>8)-1<<1)>>1]|0;y=x+1|0;if((y|0)<0){x=y}else{w=q;break}}}else{w=t}}while(0);t=0;while(1){u=t+1|0;s=ca(u,p)|0;x=s>>5;v=s&31;if((v|0)==0){s=ca(t,g)|0;b[m+(s<<1)>>1]=b[w+(x+1<<1)>>1]|0;b[m+(s+1<<1)>>1]=b[w+(x+2<<1)>>1]|0;b[m+(s+2<<1)>>1]=b[w+(x+3<<1)>>1]|0;b[m+(s+3<<1)>>1]=b[w+(x+4<<1)>>1]|0}else{s=32-v|0;y=ca(t,g)|0;z=ca(e[w+(x+1<<1)>>1]|0,s)|0;b[m+(y<<1)>>1]=(z+16+(ca(e[w+(x+2<<1)>>1]|0,v)|0)|0)>>>5;z=ca(e[w+(x+2<<1)>>1]|0,s)|0;b[m+(y+1<<1)>>1]=(z+16+(ca(e[w+(x+3<<1)>>1]|0,v)|0)|0)>>>5;z=ca(e[w+(x+3<<1)>>1]|0,s)|0;b[m+(y+2<<1)>>1]=(z+16+(ca(e[w+(x+4<<1)>>1]|0,v)|0)|0)>>>5;z=ca(e[w+(x+4<<1)>>1]|0,s)|0;b[m+(y+3<<1)>>1]=(z+16+(ca(e[w+(x+5<<1)>>1]|0,v)|0)|0)>>>5}if((u|0)<4){t=u}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}t=f-2|0;w=((e[o>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(w>>>0<512>>>0){A=w&65535}else{A=-w>>31&511}b[m>>1]=A;A=((e[f+2>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(A>>>0<512>>>0){B=A&65535}else{B=-A>>31&511}b[m+(g<<1)>>1]=B;B=((e[f+4>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(B>>>0<512>>>0){C=B&65535}else{C=-B>>31&511}b[m+(g<<1<<1)>>1]=C;C=((e[f+6>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(C>>>0<512>>>0){D=C&65535}else{D=-C>>31&511}b[m+((g*3|0)<<1)>>1]=D;i=k;return}else{D=f-2|0;f=D;C=j-11|0;do{if(C>>>0<15>>>0&(r|0)<-1){t=q;b[t>>1]=b[D>>1]|0;b[t+2>>1]=b[D+2>>1]|0;b[t+4>>1]=b[D+4>>1]|0;b[t+6>>1]=b[D+6>>1]|0;b[t+8>>1]=b[D+8>>1]|0;if((r|0)>=0){E=q;break}t=c[699944+(C<<2)>>2]|0;B=r;while(1){b[l+(B+4<<1)>>1]=b[n+(((ca(B,t)|0)+128>>8)-1<<1)>>1]|0;A=B+1|0;if((A|0)<0){B=A}else{E=q;break}}}else{E=f}}while(0);f=0;while(1){q=f+1|0;l=ca(q,p)|0;r=l>>5;C=l&31;if((C|0)==0){b[m+(f<<1)>>1]=b[E+(r+1<<1)>>1]|0;b[m+(f+g<<1)>>1]=b[E+(r+2<<1)>>1]|0;b[m+((g<<1)+f<<1)>>1]=b[E+(r+3<<1)>>1]|0;b[m+((g*3|0)+f<<1)>>1]=b[E+(r+4<<1)>>1]|0}else{l=32-C|0;D=ca(e[E+(r+1<<1)>>1]|0,l)|0;b[m+(f<<1)>>1]=(D+16+(ca(e[E+(r+2<<1)>>1]|0,C)|0)|0)>>>5;D=ca(e[E+(r+2<<1)>>1]|0,l)|0;b[m+(f+g<<1)>>1]=(D+16+(ca(e[E+(r+3<<1)>>1]|0,C)|0)|0)>>>5;D=ca(e[E+(r+3<<1)>>1]|0,l)|0;b[m+((g<<1)+f<<1)>>1]=(D+16+(ca(e[E+(r+4<<1)>>1]|0,C)|0)|0)>>>5;D=ca(e[E+(r+4<<1)>>1]|0,l)|0;b[m+((g*3|0)+f<<1)>>1]=(D+16+(ca(e[E+(r+5<<1)>>1]|0,C)|0)|0)>>>5}if((q|0)<4){f=q}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;j=((e[n>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(j>>>0<512>>>0){F=j&65535}else{F=-j>>31&511}b[m>>1]=F;F=((e[d+2>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(F>>>0<512>>>0){G=F&65535}else{G=-F>>31&511}b[a+2>>1]=G;G=((e[d+4>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(G>>>0<512>>>0){H=G&65535}else{H=-G>>31&511}b[a+4>>1]=H;H=((e[d+6>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(H>>>0<512>>>0){I=H&65535}else{I=-H>>31&511}b[a+6>>1]=I;i=k;return}}function yJa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+200|0;l=k|0;m=a;a=d;n=f;o=c[700008+(j-2<<2)>>2]|0;p=l+16|0;q=o>>2;if((j|0)>17){r=d-2|0;s=r;t=j-11|0;do{if(t>>>0<15>>>0&(q|0)<-1){nrc(p|0,r|0,18)|0;if((q|0)>=0){u=p;break}v=c[699944+(t<<2)>>2]|0;w=q;while(1){b[l+(w+8<<1)>>1]=b[n+(((ca(w,v)|0)+128>>8)-1<<1)>>1]|0;x=w+1|0;if((x|0)<0){w=x}else{u=p;break}}}else{u=s}}while(0);s=0;while(1){t=s+1|0;r=ca(t,o)|0;w=r>>5;v=r&31;if((v|0)==0){r=ca(s,g)|0;b[m+(r<<1)>>1]=b[u+(w+1<<1)>>1]|0;b[m+(r+1<<1)>>1]=b[u+(w+2<<1)>>1]|0;b[m+(r+2<<1)>>1]=b[u+(w+3<<1)>>1]|0;b[m+(r+3<<1)>>1]=b[u+(w+4<<1)>>1]|0;b[m+(r+4<<1)>>1]=b[u+(w+5<<1)>>1]|0;b[m+(r+5<<1)>>1]=b[u+(w+6<<1)>>1]|0;b[m+(r+6<<1)>>1]=b[u+(w+7<<1)>>1]|0;b[m+(r+7<<1)>>1]=b[u+(w+8<<1)>>1]|0}else{r=32-v|0;x=ca(s,g)|0;y=0;do{z=y+w|0;A=ca(e[u+(z+1<<1)>>1]|0,r)|0;b[m+(y+x<<1)>>1]=(A+16+(ca(e[u+(z+2<<1)>>1]|0,v)|0)|0)>>>5;y=y+1|0;}while((y|0)<8)}if((t|0)<8){s=t}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}s=f-2|0;u=0;do{y=((e[n+(u<<1)>>1]|0)-(e[s>>1]|0)>>1)+(e[a>>1]|0)|0;if(y>>>0<512>>>0){B=y&65535}else{B=-y>>31&511}b[m+((ca(u,g)|0)<<1)>>1]=B;u=u+1|0;}while((u|0)<8);i=k;return}else{u=f-2|0;f=u;B=j-11|0;do{if(B>>>0<15>>>0&(q|0)<-1){nrc(p|0,u|0,18)|0;if((q|0)>=0){C=p;break}s=c[699944+(B<<2)>>2]|0;y=q;while(1){b[l+(y+8<<1)>>1]=b[a+(((ca(y,s)|0)+128>>8)-1<<1)>>1]|0;v=y+1|0;if((v|0)<0){y=v}else{C=p;break}}}else{C=f}}while(0);f=0;while(1){p=f+1|0;l=ca(p,o)|0;q=l>>5;B=l&31;if((B|0)==0){b[m+(f<<1)>>1]=b[C+(q+1<<1)>>1]|0;b[m+(f+g<<1)>>1]=b[C+(q+2<<1)>>1]|0;b[m+((g<<1)+f<<1)>>1]=b[C+(q+3<<1)>>1]|0;b[m+((g*3|0)+f<<1)>>1]=b[C+(q+4<<1)>>1]|0;b[m+((g<<2)+f<<1)>>1]=b[C+(q+5<<1)>>1]|0;b[m+((g*5|0)+f<<1)>>1]=b[C+(q+6<<1)>>1]|0;b[m+((g*6|0)+f<<1)>>1]=b[C+(q+7<<1)>>1]|0;b[m+((g*7|0)+f<<1)>>1]=b[C+(q+8<<1)>>1]|0}else{l=32-B|0;u=0;do{y=u+q|0;s=ca(e[C+(y+1<<1)>>1]|0,l)|0;b[m+((ca(u,g)|0)+f<<1)>>1]=(s+16+(ca(e[C+(y+2<<1)>>1]|0,B)|0)|0)>>>5;u=u+1|0;}while((u|0)<8)}if((p|0)<8){f=p}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;d=0;do{j=((e[a+(d<<1)>>1]|0)-(e[h>>1]|0)>>1)+(e[n>>1]|0)|0;if(j>>>0<512>>>0){D=j&65535}else{D=-j>>31&511}b[m+(d<<1)>>1]=D;d=d+1|0;}while((d|0)<8);i=k;return}}function zJa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+200|0;l=k|0;m=a;a=d;n=f;o=c[700008+(j-2<<2)>>2]|0;p=l+32|0;q=o>>1;if((j|0)>17){r=d-2|0;s=r;t=j-11|0;do{if(t>>>0<15>>>0&(q|0)<-1){nrc(p|0,r|0,34)|0;if((q|0)>=0){u=p;break}v=c[699944+(t<<2)>>2]|0;w=q;while(1){b[l+(w+16<<1)>>1]=b[n+(((ca(w,v)|0)+128>>8)-1<<1)>>1]|0;x=w+1|0;if((x|0)<0){w=x}else{u=p;break}}}else{u=s}}while(0);s=0;while(1){t=s+1|0;r=ca(t,o)|0;w=r>>5;v=r&31;if((v|0)==0){r=ca(s,g)|0;b[m+(r<<1)>>1]=b[u+(w+1<<1)>>1]|0;b[m+(r+1<<1)>>1]=b[u+(w+2<<1)>>1]|0;b[m+(r+2<<1)>>1]=b[u+(w+3<<1)>>1]|0;b[m+(r+3<<1)>>1]=b[u+(w+4<<1)>>1]|0;b[m+(r+4<<1)>>1]=b[u+(w+5<<1)>>1]|0;b[m+(r+5<<1)>>1]=b[u+(w+6<<1)>>1]|0;b[m+(r+6<<1)>>1]=b[u+(w+7<<1)>>1]|0;b[m+(r+7<<1)>>1]=b[u+(w+8<<1)>>1]|0;b[m+(r+8<<1)>>1]=b[u+(w+9<<1)>>1]|0;b[m+(r+9<<1)>>1]=b[u+(w+10<<1)>>1]|0;b[m+(r+10<<1)>>1]=b[u+(w+11<<1)>>1]|0;b[m+(r+11<<1)>>1]=b[u+(w+12<<1)>>1]|0;b[m+(r+12<<1)>>1]=b[u+(w+13<<1)>>1]|0;b[m+(r+13<<1)>>1]=b[u+(w+14<<1)>>1]|0;b[m+(r+14<<1)>>1]=b[u+(w+15<<1)>>1]|0;b[m+(r+15<<1)>>1]=b[u+(w+16<<1)>>1]|0}else{r=32-v|0;x=ca(s,g)|0;y=0;do{z=y+w|0;A=ca(e[u+(z+1<<1)>>1]|0,r)|0;b[m+(y+x<<1)>>1]=(A+16+(ca(e[u+(z+2<<1)>>1]|0,v)|0)|0)>>>5;y=y+1|0;}while((y|0)<16)}if((t|0)<16){s=t}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}s=f-2|0;u=0;do{y=((e[n+(u<<1)>>1]|0)-(e[s>>1]|0)>>1)+(e[a>>1]|0)|0;if(y>>>0<512>>>0){B=y&65535}else{B=-y>>31&511}b[m+((ca(u,g)|0)<<1)>>1]=B;u=u+1|0;}while((u|0)<16);i=k;return}u=f-2|0;f=u;B=j-11|0;do{if(B>>>0<15>>>0&(q|0)<-1){nrc(p|0,u|0,34)|0;if((q|0)>=0){C=p;break}s=c[699944+(B<<2)>>2]|0;y=q;while(1){b[l+(y+16<<1)>>1]=b[a+(((ca(y,s)|0)+128>>8)-1<<1)>>1]|0;v=y+1|0;if((v|0)<0){y=v}else{C=p;break}}}else{C=f}}while(0);f=0;while(1){p=f+1|0;l=ca(p,o)|0;q=l>>5;B=l&31;if((B|0)==0){l=q+1|0;u=0;do{b[m+((ca(u,g)|0)+f<<1)>>1]=b[C+(l+u<<1)>>1]|0;u=u+1|0;}while((u|0)<16)}else{u=32-B|0;l=0;do{y=l+q|0;s=ca(e[C+(y+1<<1)>>1]|0,u)|0;b[m+((ca(l,g)|0)+f<<1)>>1]=(s+16+(ca(e[C+(y+2<<1)>>1]|0,B)|0)|0)>>>5;l=l+1|0;}while((l|0)<16)}if((p|0)<16){f=p}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;d=0;do{j=((e[a+(d<<1)>>1]|0)-(e[h>>1]|0)>>1)+(e[n>>1]|0)|0;if(j>>>0<512>>>0){D=j&65535}else{D=-j>>31&511}b[m+(d<<1)>>1]=D;d=d+1|0;}while((d|0)<16);i=k;return}function AJa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+200|0;k=h|0;l=a;a=d;m=f;n=c[700008+(j-2<<2)>>2]|0;o=k+64|0;if((j|0)>17){p=d-2|0;d=p;q=j-11|0;if(q>>>0<15>>>0){nrc(o|0,p|0,66)|0;p=c[699944+(q<<2)>>2]|0;q=n;while(1){b[k+(q+32<<1)>>1]=b[m+(((ca(q,p)|0)+128>>8)-1<<1)>>1]|0;r=q+1|0;if((r|0)<0){q=r}else{s=o;break}}}else{s=d}d=0;while(1){q=d+1|0;p=ca(q,n)|0;m=p>>5;r=p&31;if((r|0)==0){p=m+1|0;t=ca(d,g)|0;u=0;do{b[l+(u+t<<1)>>1]=b[s+(p+u<<1)>>1]|0;u=u+1|0;}while((u|0)<32)}else{u=32-r|0;p=ca(d,g)|0;t=0;do{v=t+m|0;w=ca(e[s+(v+1<<1)>>1]|0,u)|0;b[l+(t+p<<1)>>1]=(w+16+(ca(e[s+(v+2<<1)>>1]|0,r)|0)|0)>>>5;t=t+1|0;}while((t|0)<32)}if((q|0)<32){d=q}else{break}}i=h;return}else{d=f-2|0;f=d;s=j-11|0;if(s>>>0<15>>>0){nrc(o|0,d|0,66)|0;d=c[699944+(s<<2)>>2]|0;s=n;while(1){b[k+(s+32<<1)>>1]=b[a+(((ca(s,d)|0)+128>>8)-1<<1)>>1]|0;j=s+1|0;if((j|0)<0){s=j}else{x=o;break}}}else{x=f}f=0;while(1){o=f+1|0;s=ca(o,n)|0;d=s>>5;a=s&31;if((a|0)==0){s=d+1|0;k=0;do{b[l+((ca(k,g)|0)+f<<1)>>1]=b[x+(s+k<<1)>>1]|0;k=k+1|0;}while((k|0)<32)}else{k=32-a|0;s=0;do{q=s+d|0;j=ca(e[x+(q+1<<1)>>1]|0,k)|0;b[l+((ca(s,g)|0)+f<<1)>>1]=(j+16+(ca(e[x+(q+2<<1)>>1]|0,a)|0)|0)>>>5;s=s+1|0;}while((s|0)<32)}if((o|0)<32){f=o}else{break}}i=h;return}}function BJa(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;l=i;i=i+544|0;m=l|0;n=l+136|0;o=l+272|0;p=l+408|0;q=c[f+136>>2]|0;r=c[f+180>>2]|0;s=c[r+13140+(k<<2)>>2]|0;t=c[r+13152+(k<<2)>>2]|0;u=1<<j;v=u<<s;w=c[r+13072>>2]|0;x=v>>w;y=g>>w;z=h>>w;w=c[r+13124>>2]|0;A=(ca(z,w)|0)+y|0;B=c[f+184>>2]|0;C=c[B+1672>>2]|0;D=c[C+(A<<2)>>2]|0;A=c[f+160>>2]|0;E=(c[A+32+(k<<2)>>2]|0)>>>1;F=c[A+(k<<2)>>2]|0;A=(ca(E,h>>t)|0)+(g>>s)|0;G=F+(A<<1)|0;H=c[r+13132>>2]|0;if((k|0)==0){I=c[q+173192>>2]|0}else{I=d[q+184621|0]|0}J=m+2|0;K=o+2|0;L=n+2|0;M=p+2|0;if((c[q+184624>>2]|0)==0){N=0}else{N=(D|0)>(c[C+(y-1+(ca(w,z+x|0)|0)<<2)>>2]|0)}O=N&1;P=c[q+184628>>2]|0;Q=c[q+184636>>2]|0;R=c[q+184632>>2]|0;if((c[q+184640>>2]|0)==0){S=0}else{S=(D|0)>(c[C+(y+x+(ca(w,z-1|0)|0)<<2)>>2]|0)}z=S&1;w=v<<1;x=w+h|0;y=c[r+13100>>2]|0;C=v+h|0;D=((x|0)>(y|0)?y:x)-C>>t;x=w+g|0;w=c[r+13096>>2]|0;q=v+g|0;T=((x|0)>(w|0)?w:x)-q>>s;x=B+20|0;if((a[x]|0)==1){B=c[r+13084>>2]|0;U=v>>B;v=(1<<B)-1|0;V=v&h;W=((U|0)==0)+U|0;U=(v&g|0)!=0;do{if(U|N^1){X=O}else{v=g-1>>B;Y=C>>B;Z=(c[r+13136>>2]|0)-Y|0;_=(W|0)>(Z|0)?Z:W;if((_|0)<=0){X=0;break}Z=c[(c[f+3480>>2]|0)+16>>2]|0;$=0;aa=0;while(1){ba=d[Z+(((ca(aa+Y|0,H)|0)+v|0)*14|0)+12|0]|$;da=aa+1|0;if((da|0)<(_|0)){$=ba;aa=da}else{X=ba;break}}}}while(0);do{if((P|0)!=1|U){ea=P}else{C=g-1>>B;N=h>>B;aa=(c[r+13136>>2]|0)-N|0;$=(W|0)>(aa|0)?aa:W;if(($|0)<=0){ea=0;break}aa=c[(c[f+3480>>2]|0)+16>>2]|0;_=0;v=0;while(1){Y=d[aa+(((ca(v+N|0,H)|0)+C|0)*14|0)+12|0]|_;Z=v+1|0;if((Z|0)<($|0)){_=Y;v=Z}else{ea=Y;break}}}}while(0);if((Q|0)==1){U=(ca(h-1>>B,H)|0)+(g-1>>B)|0;fa=d[(c[(c[f+3480>>2]|0)+16>>2]|0)+(U*14|0)+12|0]|0}else{fa=Q}U=(V|0)!=0;do{if((R|0)!=1|U){ga=R}else{V=g>>B;v=H-V|0;_=(W|0)>(v|0)?v:W;if((_|0)<=0){ga=0;break}v=(ca(h-1>>B,H)|0)+V|0;V=c[(c[f+3480>>2]|0)+16>>2]|0;$=0;C=0;while(1){N=d[V+((v+C|0)*14|0)+12|0]|$;aa=C+1|0;if((aa|0)<(_|0)){$=N;C=aa}else{ga=N;break}}}}while(0);do{if(U|S^1){ha=z}else{C=q>>B;$=H-C|0;_=(W|0)>($|0)?$:W;if((_|0)<=0){ha=0;break}$=(ca(h-1>>B,H)|0)+C|0;C=c[(c[f+3480>>2]|0)+16>>2]|0;v=0;V=0;while(1){N=d[C+(($+V|0)*14|0)+12|0]|v;aa=V+1|0;if((aa|0)<(_|0)){v=N;V=aa}else{ha=N;break}}}}while(0);B=0;while(1){W=B+1|0;b[m+(W<<1)>>1]=128;b[o+(W<<1)>>1]=128;if((W|0)<64){B=W}else{ia=X;ja=ea;ka=fa;la=ga;ma=ha;break}}}else{ia=O;ja=P;ka=Q;la=R;ma=z}z=(ia|0)!=0;do{if(z){R=D+u|0;Q=u<<1;if((R|0)<(Q|0)){P=(-1<<s)+g|0;O=R-1|0;ha=(O<<t)+h|0;ga=F+(A-1+(ca(O,E)|0)<<1)|0;fa=c[r+13084>>2]|0;ea=c[(c[f+3480>>2]|0)+16>>2]|0;X=R;while(1){do{if((a[ea+(((ca(ha>>fa,H)|0)+(P>>fa)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=38;break}oa=X+1|0}else{na=38}}while(0);if((na|0)==38){na=0;B=X+1|0;b[m+(B<<1)>>1]=b[ga>>1]|0;oa=B}if((oa|0)<(Q|0)){X=oa}else{pa=O;break}}}else{pa=R-1|0}if((pa|0)<(u|0)){break}O=(-1<<s)+g|0;X=A-1|0;Q=c[r+13084>>2]|0;ga=c[(c[f+3480>>2]|0)+16>>2]|0;fa=R;P=pa;while(1){if((a[ga+(((ca((P<<t)+h>>Q,H)|0)+(O>>Q)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=43}}else{na=43}if((na|0)==43){na=0;b[m+(fa<<1)>>1]=b[F+(X+(ca(P,E)|0)<<1)>>1]|0}ha=P-1|0;if((ha|0)<(u|0)){break}else{fa=P;P=ha}}}}while(0);pa=(ja|0)!=0;if(pa&(u|0)>0){oa=(-1<<s)+g|0;P=A-1|0;fa=c[r+13084>>2]|0;X=c[(c[f+3480>>2]|0)+16>>2]|0;Q=u;while(1){O=Q-1|0;if((a[X+(((ca((O<<t)+h>>fa,H)|0)+(oa>>fa)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=49}}else{na=49}if((na|0)==49){na=0;b[m+(Q<<1)>>1]=b[F+(P+(ca(O,E)|0)<<1)>>1]|0}if((O|0)>0){Q=O}else{break}}}Q=(ka|0)!=0;do{if(Q){P=c[r+13084>>2]|0;fa=(ca((-1<<t)+h>>P,H)|0)+((-1<<s)+g>>P)|0;if((a[(c[(c[f+3480>>2]|0)+16>>2]|0)+(fa*14|0)+12|0]|0)==0){if((a[x]|0)!=0){break}}fa=b[F+(A+~E<<1)>>1]|0;b[m>>1]=fa;b[o>>1]=fa}}while(0);fa=(la|0)!=0;if(fa&(u|0)>0){P=(-1<<t)+h|0;oa=A-E|0;X=c[r+13084>>2]|0;O=c[(c[f+3480>>2]|0)+16>>2]|0;ga=u;while(1){R=ga-1|0;if((a[O+(((ca(P>>X,H)|0)+((R<<s)+g>>X)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=59}}else{na=59}if((na|0)==59){na=0;b[o+(ga<<1)>>1]=b[F+(oa+R<<1)>>1]|0}if((R|0)>0){ga=R}else{break}}}ga=(ma|0)!=0;do{if(ga){oa=T+u|0;X=u<<1;P=oa-1|0;if((oa|0)<(X|0)){O=(P<<s)+g|0;R=(-1<<t)+h|0;ha=F+(A-E+P<<1)|0;ea=c[r+13084>>2]|0;B=c[(c[f+3480>>2]|0)+16>>2]|0;W=oa;while(1){do{if((a[B+(((ca(R>>ea,H)|0)+(O>>ea)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=68;break}qa=W+1|0}else{na=68}}while(0);if((na|0)==68){na=0;S=W+1|0;b[o+(S<<1)>>1]=b[ha>>1]|0;qa=S}if((qa|0)<(X|0)){W=qa}else{break}}}if((P|0)<(u|0)){break}W=(-1<<t)+h|0;X=A-E|0;ha=c[r+13084>>2]|0;ea=c[(c[f+3480>>2]|0)+16>>2]|0;O=oa;R=P;while(1){if((a[ea+(((ca(W>>ha,H)|0)+((R<<s)+g>>ha)|0)*14|0)+12|0]|0)==0){if((a[x]|0)==0){na=73}}else{na=73}if((na|0)==73){na=0;b[o+(O<<1)>>1]=b[F+(X+R<<1)>>1]|0}B=R-1|0;if((B|0)<(u|0)){break}else{O=R;R=B}}}}while(0);do{if((a[x]|0)==1){F=ia|ja;A=(F|0)!=0;qa=F|ka;F=(qa|0)==0;if((la|ma|qa|0)==0){break}qa=u<<1;if(((qa<<s)+g|0)<(w|0)){ra=qa}else{ra=w-g>>s}if(((qa<<t)+h|0)<(y|0)){sa=qa}else{sa=y-h>>t}T=(z?D:0)+u|0;do{if(ga){ta=ra}else{if((q|0)<(w|0)){ta=u;break}ta=w-g>>s}}while(0);do{if(z){ua=sa}else{if(((u<<t)+h|0)<(y|0)){ua=u;break}ua=y-h>>t}}while(0);do{if(F){R=(-1<<t)+h|0;O=f+3480|0;X=0;while(1){if((X|0)>=(ta|0)){break}ha=c[r+13084>>2]|0;W=(ca(R>>ha,H)|0)+((X<<s)+g>>ha)|0;if((a[(c[(c[O>>2]|0)+16>>2]|0)+(W*14|0)+12|0]|0)==0){X=X+1|0}else{break}}do{if((X|0)>0){if((g|0)>0){if(!((X|0)>-1)){break}W=c[r+13084>>2]|0;ha=c[(c[O>>2]|0)+16>>2]|0;ea=X;while(1){P=ea-1|0;if((a[ha+(((ca(R>>W,H)|0)+((P<<s)+g>>W)|0)*14|0)+12|0]|0)==0){b[o+(ea<<1)>>1]=b[o+(ea+1<<1)>>1]|0}if((ea|0)>0){ea=P}else{break}}}else{ea=c[r+13084>>2]|0;W=c[(c[O>>2]|0)+16>>2]|0;ha=X;while(1){P=ha-1|0;if((a[W+(((ca(R>>ea,H)|0)+((P<<s)+g>>ea)|0)*14|0)+12|0]|0)==0){b[o+(ha<<1)>>1]=b[o+(ha+1<<1)>>1]|0}if((P|0)>0){ha=P}else{break}}b[o>>1]=b[K>>1]|0;break}}}while(0);b[m>>1]=b[o>>1]|0;va=0}else{R=(-1<<s)+g|0;X=f+3480|0;O=T;while(1){wa=O-1|0;xa=c[r+13084>>2]|0;if((O|0)<=0){na=90;break}ha=(wa<<t)+h|0;ea=(ca(ha>>xa,H)|0)+(R>>xa)|0;W=c[(c[X>>2]|0)+16>>2]|0;if((a[W+(ea*14|0)+12|0]|0)==0){O=wa}else{ya=W;za=ha;break}}if((na|0)==90){ya=c[(c[X>>2]|0)+16>>2]|0;za=(wa<<t)+h|0}if((a[ya+(((ca(za>>xa,H)|0)+(R>>xa)|0)*14|0)+12|0]|0)!=0){va=wa;break}O=(-1<<t)+h|0;ha=0;while(1){if((ha|0)>=(ta|0)){break}if((a[ya+(((ca(O>>xa,H)|0)+((ha<<s)+g>>xa)|0)*14|0)+12|0]|0)==0){ha=ha+1|0}else{break}}if((ha|0)>-1){R=ha;while(1){X=R-1|0;if((a[ya+(((ca(O>>xa,H)|0)+((X<<s)+g>>xa)|0)*14|0)+12|0]|0)==0){b[o+(R<<1)>>1]=b[o+(R+1<<1)>>1]|0}if((R|0)>0){R=X}else{break}}}b[m>>1]=b[o>>1]|0;va=0}}while(0);if(A&(va|0)<(ua|0)){T=(-1<<s)+g|0;F=c[r+13084>>2]|0;R=c[(c[f+3480>>2]|0)+16>>2]|0;O=va;while(1){if((a[R+(((ca((O<<t)+h>>F,H)|0)+(T>>F)|0)*14|0)+12|0]|0)==0){ha=O+1|0;b[m+(ha<<1)>>1]=b[m+(O<<1)>>1]|0;Aa=ha}else{Aa=O+1|0}if((Aa|0)<(ua|0)){O=Aa}else{break}}}a:do{if((u|0)>0&(pa^1)){O=b[m>>1]|0;F=1;while(1){b[m+(F<<1)>>1]=O;if((F|0)>=(u|0)){break a}F=F+1|0}}}while(0);if((u|0)<(qa|0)&(z^1)){F=b[m+(u<<1)>>1]|0;O=u;do{O=O+1|0;b[m+(O<<1)>>1]=F;}while((O|0)<(qa|0))}qa=(g|0)==0;O=(h|0)==0;b:do{if(qa|O){F=ua-1|0;if(qa){if((ua|0)<=0){break}T=b[m+(ua<<1)>>1]|0;R=F;while(1){b[m+(R<<1)>>1]=T;if((R|0)>0){R=R-1|0}else{break b}}}if((F|0)<=0){break}R=(-1<<s)+g|0;T=c[r+13084>>2]|0;A=c[(c[f+3480>>2]|0)+16>>2]|0;ha=F;while(1){X=ha-1|0;if((a[A+(((ca((X<<t)+h>>T,H)|0)+(R>>T)|0)*14|0)+12|0]|0)==0){b[m+(ha<<1)>>1]=b[m+(ha+1<<1)>>1]|0}if((X|0)>0){ha=X}else{break}}}else{if((ua|0)<=0){break}ha=(-1<<s)+g|0;T=c[r+13084>>2]|0;R=c[(c[f+3480>>2]|0)+16>>2]|0;A=ua;while(1){F=A-1|0;if((a[R+(((ca((A-2<<t)+h>>T,H)|0)+(ha>>T)|0)*14|0)+12|0]|0)==0){b[m+(F<<1)>>1]=b[m+(A<<1)>>1]|0}if((F|0)>0){A=F}else{break}}}}while(0);b[o>>1]=b[m>>1]|0;if(!((ta|0)>0&(O^1))){break}qa=(-1<<t)+h|0;A=c[r+13084>>2]|0;T=c[(c[f+3480>>2]|0)+16>>2]|0;ha=0;while(1){if((a[T+(((ca(qa>>A,H)|0)+((ha<<s)+g>>A)|0)*14|0)+12|0]|0)==0){R=ha+1|0;b[o+(R<<1)>>1]=b[o+(ha<<1)>>1]|0;Ba=R}else{Ba=ha+1|0}if((Ba|0)<(ta|0)){ha=Ba}else{break}}}}while(0);c:do{if(z){na=176}else{if(pa){Ba=u<<1;if((u|0)>=(Ba|0)){na=176;break}ta=b[m+(u<<1)>>1]|0;g=u;while(1){s=g+1|0;b[m+(s<<1)>>1]=ta;if((s|0)<(Ba|0)){g=s}else{na=176;break c}}}if(Q){g=u<<1;if((g|0)<=0){na=178;break}Ba=b[m>>1]|0;ta=1;while(1){b[m+(ta<<1)>>1]=Ba;if((ta|0)>=(g|0)){na=178;break c}ta=ta+1|0}}if(fa){ta=b[K>>1]|0;b[m>>1]=ta;g=u<<1;if((g|0)>0){Ca=1}else{na=180;break}while(1){b[m+(Ca<<1)>>1]=ta;if((Ca|0)>=(g|0)){na=180;break c}Ca=Ca+1|0}}if(ga){if((u|0)>0){g=u;do{b[o+(g<<1)>>1]=b[o+(g+1<<1)>>1]|0;g=g-1|0;}while((g|0)>0)}g=b[K>>1]|0;b[m>>1]=g;ta=u<<1;if((ta|0)>0){Da=1}else{break}while(1){b[m+(Da<<1)>>1]=g;if((Da|0)>=(ta|0)){break c}Da=Da+1|0}}b[m>>1]=512;b[K>>1]=512;ta=u<<1;d:do{if((ta|0)>1){g=2;while(1){b[o+(g<<1)>>1]=512;if((g|0)>=(ta|0)){break d}g=g+1|0}}}while(0);if((ta|0)>0){Ea=1}else{na=176;break}while(1){b[m+(Ea<<1)>>1]=512;if((Ea|0)>=(ta|0)){na=176;break c}Ea=Ea+1|0}}}while(0);do{if((na|0)==176){if((ja|0)==0&(u|0)>0){Fa=u}else{na=178;break}while(1){b[m+(Fa<<1)>>1]=b[m+(Fa+1<<1)>>1]|0;Ea=Fa-1|0;if((Ea|0)>0){Fa=Ea}else{na=178;break}}}}while(0);do{if((na|0)==178){if((ka|0)!=0){na=180;break}b[m>>1]=b[J>>1]|0;na=180}}while(0);e:do{if((na|0)==180){if((la|0)!=0){break}ka=b[m>>1]|0;b[K>>1]=ka;if((u|0)>1){Ga=2}else{break}while(1){b[o+(Ga<<1)>>1]=ka;if((Ga|0)>=(u|0)){break e}Ga=Ga+1|0}}}while(0);do{if(!ga){Ga=u<<1;if((u|0)>=(Ga|0)){break}la=b[o+(u<<1)>>1]|0;na=u;do{na=na+1|0;b[o+(na<<1)>>1]=la;}while((na|0)<(Ga|0))}}while(0);ga=m|0;Ga=b[ga>>1]|0;b[o>>1]=Ga;f:do{if((k|0)!=0|(I|0)==1|(u|0)==4){Ha=J;Ia=K}else{na=I-26|0;la=(na|0)>-1?na:26-I|0;na=I-10|0;ka=(na|0)>-1?na:10-I|0;if((((la|0)>(ka|0)?ka:la)|0)<=(c[1064480+(j-3<<2)>>2]|0)){Ha=J;Ia=K;break}do{if((a[r+13061|0]|0)!=0&(j|0)==5){la=Ga&65535;ka=b[o+128>>1]|0;na=ka&65535;Fa=na+la-(e[o+64>>1]<<1)|0;if((((Fa|0)>-1?Fa:-Fa|0)|0)>=32){break}Fa=m+128|0;ja=b[Fa>>1]|0;Ea=(ja&65535)+la-(e[m+64>>1]<<1)|0;if((((Ea|0)>-1?Ea:-Ea|0)|0)>=32){break}b[p>>1]=Ga;b[p+128>>1]=ka;ka=0;while(1){Ea=ka+1|0;b[p+(Ea<<1)>>1]=((ca(la,63-ka|0)|0)+32+(ca(na,Ea)|0)|0)>>>6;if((Ea|0)<63){ka=Ea}else{Ja=0;Ka=Ga;La=ja;break}}while(1){ja=Ja+1|0;b[m+(ja<<1)>>1]=((ca(Ka&65535,63-Ja|0)|0)+32+(ca(La&65535,ja)|0)|0)>>>6;if((ja|0)>=63){Ha=J;Ia=M;break f}Ja=ja;Ka=b[ga>>1]|0;La=b[Fa>>1]|0}}}while(0);Fa=u<<1;ja=b[m+(Fa<<1)>>1]|0;b[n+(Fa<<1)>>1]=ja;ka=b[o+(Fa<<1)>>1]|0;b[p+(Fa<<1)>>1]=ka;na=Fa-2|0;Fa=(na|0)>-1;if(Fa){la=na;Ea=ja;while(1){ja=la+1|0;Da=b[m+(ja<<1)>>1]|0;b[n+(ja<<1)>>1]=((Ea&65535)+2+((Da&65535)<<1)+(e[m+(la<<1)>>1]|0)|0)>>>2;if((la|0)>0){la=la-1|0;Ea=Da}else{break}}}Ea=((e[J>>1]|0)+2+((Ga&65535)<<1)+(e[K>>1]|0)|0)>>>2&65535;b[n>>1]=Ea;b[p>>1]=Ea;if(Fa){Ma=na;Na=ka}else{Ha=L;Ia=M;break}while(1){Ea=Ma+1|0;la=b[o+(Ea<<1)>>1]|0;b[p+(Ea<<1)>>1]=((Na&65535)+2+((la&65535)<<1)+(e[o+(Ma<<1)>>1]|0)|0)>>>2;if((Ma|0)>0){Ma=Ma-1|0;Na=la}else{Ha=L;Ia=M;break}}}}while(0);if((I|0)==1){_e[c[f+5840>>2]&511](G,Ia,Ha,E,j,k);i=l;return}else if((I|0)==0){mf[c[f+5824+(j-2<<2)>>2]&2047](G,Ia,Ha,E);i=l;return}else{_e[c[f+5844+(j-2<<2)>>2]&511](G,Ia,Ha,E,k,I);i=l;return}}function CJa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=a;a=c;h=d;i=c+8|0;j=d+8|0;d=0;while(1){k=h+(d<<1)|0;l=3-d|0;m=d+1|0;n=ca(d,f)|0;o=ca(e[a>>1]|0,l)|0;b[g+(n<<1)>>1]=(((e[k>>1]|0)*3|0)+4+(e[i>>1]|0)+o+(ca(e[j>>1]|0,m)|0)|0)>>>3;o=ca(e[c+2>>1]|0,l)|0;b[g+(n+1<<1)>>1]=(((e[k>>1]|0)<<1)+4+((e[i>>1]|0)<<1)+o+(ca(e[j>>1]|0,m)|0)|0)>>>3;o=ca(e[c+4>>1]|0,l)|0;b[g+(n+2<<1)>>1]=((e[k>>1]|0)+4+((e[i>>1]|0)*3|0)+o+(ca(e[j>>1]|0,m)|0)|0)>>>3;o=ca(e[c+6>>1]|0,l)|0;b[g+(n+3<<1)>>1]=(((e[i>>1]|0)<<2)+4+o+(ca(e[j>>1]|0,m)|0)|0)>>>3;if((m|0)<4){d=m}else{break}}return}function DJa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+16|0;c=d+16|0;d=0;while(1){j=h+(d<<1)|0;k=7-d|0;l=d+1|0;m=ca(d,f)|0;n=0;while(1){o=ca(e[j>>1]|0,7-n|0)|0;p=n+1|0;q=ca(e[i>>1]|0,p)|0;r=ca(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+8+q+r+(ca(e[c>>1]|0,l)|0)|0)>>>4;if((p|0)<8){n=p}else{break}}if((l|0)<8){d=l}else{break}}return}function EJa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+32|0;c=d+32|0;d=0;while(1){j=h+(d<<1)|0;k=15-d|0;l=d+1|0;m=ca(d,f)|0;n=0;while(1){o=ca(e[j>>1]|0,15-n|0)|0;p=n+1|0;q=ca(e[i>>1]|0,p)|0;r=ca(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+16+q+r+(ca(e[c>>1]|0,l)|0)|0)>>>5;if((p|0)<16){n=p}else{break}}if((l|0)<16){d=l}else{break}}return}function FJa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a;a=c;h=d;i=c+64|0;c=d+64|0;d=0;while(1){j=h+(d<<1)|0;k=31-d|0;l=d+1|0;m=ca(d,f)|0;n=0;while(1){o=ca(e[j>>1]|0,31-n|0)|0;p=n+1|0;q=ca(e[i>>1]|0,p)|0;r=ca(e[a+(n<<1)>>1]|0,k)|0;b[g+(n+m<<1)>>1]=(o+32+q+r+(ca(e[c>>1]|0,l)|0)|0)>>>6;if((p|0)<32){n=p}else{break}}if((l|0)<32){d=l}else{break}}return}function GJa(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=1<<h;k=a;a=d;d=f;f=(j|0)>0;do{if(f){l=j;m=0;do{l=(e[d+(m<<1)>>1]|0)+l+(e[a+(m<<1)>>1]|0)|0;m=m+1|0;}while((m|0)<(j|0));m=l>>h+1;n=Erc(m,(m|0)<0|0?-1:0,65537,65537)|0;o=G;if(!f){p=m;break}q=(j|0)/4|0;if((j|0)>3){r=0}else{p=m;break}while(1){s=ca(r,g)|0;t=0;do{u=k+((t<<2)+s<<1)|0;c[u>>2]=n;c[u+4>>2]=o;t=t+1|0;}while((t|0)<(q|0));t=r+1|0;if((t|0)<(j|0)){r=t}else{p=m;break}}}else{p=j>>h+1}}while(0);if(!((i|0)==0&(j|0)<32)){return}b[k>>1]=((p<<1)+2+(e[d>>1]|0)+(e[a>>1]|0)|0)>>>2;i=(j|0)>1;if(!i){return}h=(p*3|0)+2|0;r=1;do{b[k+(r<<1)>>1]=(h+(e[a+(r<<1)>>1]|0)|0)>>>2;r=r+1|0;}while((r|0)<(j|0));if(!i){return}i=(p*3|0)+2|0;p=1;do{b[k+((ca(p,g)|0)<<1)>>1]=(i+(e[d+(p<<1)>>1]|0)|0)>>>2;p=p+1|0;}while((p|0)<(j|0));return}function HJa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;k=i;i=i+200|0;l=k|0;m=a;n=d;o=f;p=c[700008+(j-2<<2)>>2]|0;q=l+8|0;r=p>>3;if((j|0)>17){s=d-2|0;t=s;u=j-11|0;do{if(u>>>0<15>>>0&(r|0)<-1){v=q;b[v>>1]=b[s>>1]|0;b[v+2>>1]=b[s+2>>1]|0;b[v+4>>1]=b[s+4>>1]|0;b[v+6>>1]=b[s+6>>1]|0;b[v+8>>1]=b[s+8>>1]|0;if((r|0)>=0){w=q;break}v=c[699944+(u<<2)>>2]|0;x=r;while(1){b[l+(x+4<<1)>>1]=b[o+(((ca(x,v)|0)+128>>8)-1<<1)>>1]|0;y=x+1|0;if((y|0)<0){x=y}else{w=q;break}}}else{w=t}}while(0);t=0;while(1){u=t+1|0;s=ca(u,p)|0;x=s>>5;v=s&31;if((v|0)==0){s=ca(t,g)|0;b[m+(s<<1)>>1]=b[w+(x+1<<1)>>1]|0;b[m+(s+1<<1)>>1]=b[w+(x+2<<1)>>1]|0;b[m+(s+2<<1)>>1]=b[w+(x+3<<1)>>1]|0;b[m+(s+3<<1)>>1]=b[w+(x+4<<1)>>1]|0}else{s=32-v|0;y=ca(t,g)|0;z=ca(e[w+(x+1<<1)>>1]|0,s)|0;b[m+(y<<1)>>1]=(z+16+(ca(e[w+(x+2<<1)>>1]|0,v)|0)|0)>>>5;z=ca(e[w+(x+2<<1)>>1]|0,s)|0;b[m+(y+1<<1)>>1]=(z+16+(ca(e[w+(x+3<<1)>>1]|0,v)|0)|0)>>>5;z=ca(e[w+(x+3<<1)>>1]|0,s)|0;b[m+(y+2<<1)>>1]=(z+16+(ca(e[w+(x+4<<1)>>1]|0,v)|0)|0)>>>5;z=ca(e[w+(x+4<<1)>>1]|0,s)|0;b[m+(y+3<<1)>>1]=(z+16+(ca(e[w+(x+5<<1)>>1]|0,v)|0)|0)>>>5}if((u|0)<4){t=u}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}t=f-2|0;w=((e[o>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(w>>>0<1024>>>0){A=w&65535}else{A=-w>>31&1023}b[m>>1]=A;A=((e[f+2>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(A>>>0<1024>>>0){B=A&65535}else{B=-A>>31&1023}b[m+(g<<1)>>1]=B;B=((e[f+4>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(B>>>0<1024>>>0){C=B&65535}else{C=-B>>31&1023}b[m+(g<<1<<1)>>1]=C;C=((e[f+6>>1]|0)-(e[t>>1]|0)>>1)+(e[n>>1]|0)|0;if(C>>>0<1024>>>0){D=C&65535}else{D=-C>>31&1023}b[m+((g*3|0)<<1)>>1]=D;i=k;return}else{D=f-2|0;f=D;C=j-11|0;do{if(C>>>0<15>>>0&(r|0)<-1){t=q;b[t>>1]=b[D>>1]|0;b[t+2>>1]=b[D+2>>1]|0;b[t+4>>1]=b[D+4>>1]|0;b[t+6>>1]=b[D+6>>1]|0;b[t+8>>1]=b[D+8>>1]|0;if((r|0)>=0){E=q;break}t=c[699944+(C<<2)>>2]|0;B=r;while(1){b[l+(B+4<<1)>>1]=b[n+(((ca(B,t)|0)+128>>8)-1<<1)>>1]|0;A=B+1|0;if((A|0)<0){B=A}else{E=q;break}}}else{E=f}}while(0);f=0;while(1){q=f+1|0;l=ca(q,p)|0;r=l>>5;C=l&31;if((C|0)==0){b[m+(f<<1)>>1]=b[E+(r+1<<1)>>1]|0;b[m+(f+g<<1)>>1]=b[E+(r+2<<1)>>1]|0;b[m+((g<<1)+f<<1)>>1]=b[E+(r+3<<1)>>1]|0;b[m+((g*3|0)+f<<1)>>1]=b[E+(r+4<<1)>>1]|0}else{l=32-C|0;D=ca(e[E+(r+1<<1)>>1]|0,l)|0;b[m+(f<<1)>>1]=(D+16+(ca(e[E+(r+2<<1)>>1]|0,C)|0)|0)>>>5;D=ca(e[E+(r+2<<1)>>1]|0,l)|0;b[m+(f+g<<1)>>1]=(D+16+(ca(e[E+(r+3<<1)>>1]|0,C)|0)|0)>>>5;D=ca(e[E+(r+3<<1)>>1]|0,l)|0;b[m+((g<<1)+f<<1)>>1]=(D+16+(ca(e[E+(r+4<<1)>>1]|0,C)|0)|0)>>>5;D=ca(e[E+(r+4<<1)>>1]|0,l)|0;b[m+((g*3|0)+f<<1)>>1]=(D+16+(ca(e[E+(r+5<<1)>>1]|0,C)|0)|0)>>>5}if((q|0)<4){f=q}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;j=((e[n>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(j>>>0<1024>>>0){F=j&65535}else{F=-j>>31&1023}b[m>>1]=F;F=((e[d+2>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(F>>>0<1024>>>0){G=F&65535}else{G=-F>>31&1023}b[a+2>>1]=G;G=((e[d+4>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(G>>>0<1024>>>0){H=G&65535}else{H=-G>>31&1023}b[a+4>>1]=H;H=((e[d+6>>1]|0)-(e[h>>1]|0)>>1)+(e[o>>1]|0)|0;if(H>>>0<1024>>>0){I=H&65535}else{I=-H>>31&1023}b[a+6>>1]=I;i=k;return}}function IJa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+200|0;l=k|0;m=a;a=d;n=f;o=c[700008+(j-2<<2)>>2]|0;p=l+16|0;q=o>>2;if((j|0)>17){r=d-2|0;s=r;t=j-11|0;do{if(t>>>0<15>>>0&(q|0)<-1){nrc(p|0,r|0,18)|0;if((q|0)>=0){u=p;break}v=c[699944+(t<<2)>>2]|0;w=q;while(1){b[l+(w+8<<1)>>1]=b[n+(((ca(w,v)|0)+128>>8)-1<<1)>>1]|0;x=w+1|0;if((x|0)<0){w=x}else{u=p;break}}}else{u=s}}while(0);s=0;while(1){t=s+1|0;r=ca(t,o)|0;w=r>>5;v=r&31;if((v|0)==0){r=ca(s,g)|0;b[m+(r<<1)>>1]=b[u+(w+1<<1)>>1]|0;b[m+(r+1<<1)>>1]=b[u+(w+2<<1)>>1]|0;b[m+(r+2<<1)>>1]=b[u+(w+3<<1)>>1]|0;b[m+(r+3<<1)>>1]=b[u+(w+4<<1)>>1]|0;b[m+(r+4<<1)>>1]=b[u+(w+5<<1)>>1]|0;b[m+(r+5<<1)>>1]=b[u+(w+6<<1)>>1]|0;b[m+(r+6<<1)>>1]=b[u+(w+7<<1)>>1]|0;b[m+(r+7<<1)>>1]=b[u+(w+8<<1)>>1]|0}else{r=32-v|0;x=ca(s,g)|0;y=0;do{z=y+w|0;A=ca(e[u+(z+1<<1)>>1]|0,r)|0;b[m+(y+x<<1)>>1]=(A+16+(ca(e[u+(z+2<<1)>>1]|0,v)|0)|0)>>>5;y=y+1|0;}while((y|0)<8)}if((t|0)<8){s=t}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}s=f-2|0;u=0;do{y=((e[n+(u<<1)>>1]|0)-(e[s>>1]|0)>>1)+(e[a>>1]|0)|0;if(y>>>0<1024>>>0){B=y&65535}else{B=-y>>31&1023}b[m+((ca(u,g)|0)<<1)>>1]=B;u=u+1|0;}while((u|0)<8);i=k;return}else{u=f-2|0;f=u;B=j-11|0;do{if(B>>>0<15>>>0&(q|0)<-1){nrc(p|0,u|0,18)|0;if((q|0)>=0){C=p;break}s=c[699944+(B<<2)>>2]|0;y=q;while(1){b[l+(y+8<<1)>>1]=b[a+(((ca(y,s)|0)+128>>8)-1<<1)>>1]|0;v=y+1|0;if((v|0)<0){y=v}else{C=p;break}}}else{C=f}}while(0);f=0;while(1){p=f+1|0;l=ca(p,o)|0;q=l>>5;B=l&31;if((B|0)==0){b[m+(f<<1)>>1]=b[C+(q+1<<1)>>1]|0;b[m+(f+g<<1)>>1]=b[C+(q+2<<1)>>1]|0;b[m+((g<<1)+f<<1)>>1]=b[C+(q+3<<1)>>1]|0;b[m+((g*3|0)+f<<1)>>1]=b[C+(q+4<<1)>>1]|0;b[m+((g<<2)+f<<1)>>1]=b[C+(q+5<<1)>>1]|0;b[m+((g*5|0)+f<<1)>>1]=b[C+(q+6<<1)>>1]|0;b[m+((g*6|0)+f<<1)>>1]=b[C+(q+7<<1)>>1]|0;b[m+((g*7|0)+f<<1)>>1]=b[C+(q+8<<1)>>1]|0}else{l=32-B|0;u=0;do{y=u+q|0;s=ca(e[C+(y+1<<1)>>1]|0,l)|0;b[m+((ca(u,g)|0)+f<<1)>>1]=(s+16+(ca(e[C+(y+2<<1)>>1]|0,B)|0)|0)>>>5;u=u+1|0;}while((u|0)<8)}if((p|0)<8){f=p}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;d=0;do{j=((e[a+(d<<1)>>1]|0)-(e[h>>1]|0)>>1)+(e[n>>1]|0)|0;if(j>>>0<1024>>>0){D=j&65535}else{D=-j>>31&1023}b[m+(d<<1)>>1]=D;d=d+1|0;}while((d|0)<8);i=k;return}}function JJa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+200|0;l=k|0;m=a;a=d;n=f;o=c[700008+(j-2<<2)>>2]|0;p=l+32|0;q=o>>1;if((j|0)>17){r=d-2|0;s=r;t=j-11|0;do{if(t>>>0<15>>>0&(q|0)<-1){nrc(p|0,r|0,34)|0;if((q|0)>=0){u=p;break}v=c[699944+(t<<2)>>2]|0;w=q;while(1){b[l+(w+16<<1)>>1]=b[n+(((ca(w,v)|0)+128>>8)-1<<1)>>1]|0;x=w+1|0;if((x|0)<0){w=x}else{u=p;break}}}else{u=s}}while(0);s=0;while(1){t=s+1|0;r=ca(t,o)|0;w=r>>5;v=r&31;if((v|0)==0){r=ca(s,g)|0;b[m+(r<<1)>>1]=b[u+(w+1<<1)>>1]|0;b[m+(r+1<<1)>>1]=b[u+(w+2<<1)>>1]|0;b[m+(r+2<<1)>>1]=b[u+(w+3<<1)>>1]|0;b[m+(r+3<<1)>>1]=b[u+(w+4<<1)>>1]|0;b[m+(r+4<<1)>>1]=b[u+(w+5<<1)>>1]|0;b[m+(r+5<<1)>>1]=b[u+(w+6<<1)>>1]|0;b[m+(r+6<<1)>>1]=b[u+(w+7<<1)>>1]|0;b[m+(r+7<<1)>>1]=b[u+(w+8<<1)>>1]|0;b[m+(r+8<<1)>>1]=b[u+(w+9<<1)>>1]|0;b[m+(r+9<<1)>>1]=b[u+(w+10<<1)>>1]|0;b[m+(r+10<<1)>>1]=b[u+(w+11<<1)>>1]|0;b[m+(r+11<<1)>>1]=b[u+(w+12<<1)>>1]|0;b[m+(r+12<<1)>>1]=b[u+(w+13<<1)>>1]|0;b[m+(r+13<<1)>>1]=b[u+(w+14<<1)>>1]|0;b[m+(r+14<<1)>>1]=b[u+(w+15<<1)>>1]|0;b[m+(r+15<<1)>>1]=b[u+(w+16<<1)>>1]|0}else{r=32-v|0;x=ca(s,g)|0;y=0;do{z=y+w|0;A=ca(e[u+(z+1<<1)>>1]|0,r)|0;b[m+(y+x<<1)>>1]=(A+16+(ca(e[u+(z+2<<1)>>1]|0,v)|0)|0)>>>5;y=y+1|0;}while((y|0)<16)}if((t|0)<16){s=t}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}s=f-2|0;u=0;do{y=((e[n+(u<<1)>>1]|0)-(e[s>>1]|0)>>1)+(e[a>>1]|0)|0;if(y>>>0<1024>>>0){B=y&65535}else{B=-y>>31&1023}b[m+((ca(u,g)|0)<<1)>>1]=B;u=u+1|0;}while((u|0)<16);i=k;return}u=f-2|0;f=u;B=j-11|0;do{if(B>>>0<15>>>0&(q|0)<-1){nrc(p|0,u|0,34)|0;if((q|0)>=0){C=p;break}s=c[699944+(B<<2)>>2]|0;y=q;while(1){b[l+(y+16<<1)>>1]=b[a+(((ca(y,s)|0)+128>>8)-1<<1)>>1]|0;v=y+1|0;if((v|0)<0){y=v}else{C=p;break}}}else{C=f}}while(0);f=0;while(1){p=f+1|0;l=ca(p,o)|0;q=l>>5;B=l&31;if((B|0)==0){l=q+1|0;u=0;do{b[m+((ca(u,g)|0)+f<<1)>>1]=b[C+(l+u<<1)>>1]|0;u=u+1|0;}while((u|0)<16)}else{u=32-B|0;l=0;do{y=l+q|0;s=ca(e[C+(y+1<<1)>>1]|0,u)|0;b[m+((ca(l,g)|0)+f<<1)>>1]=(s+16+(ca(e[C+(y+2<<1)>>1]|0,B)|0)|0)>>>5;l=l+1|0;}while((l|0)<16)}if((p|0)<16){f=p}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=d-2|0;d=0;do{j=((e[a+(d<<1)>>1]|0)-(e[h>>1]|0)>>1)+(e[n>>1]|0)|0;if(j>>>0<1024>>>0){D=j&65535}else{D=-j>>31&1023}b[m+(d<<1)>>1]=D;d=d+1|0;}while((d|0)<16);i=k;return}function KJa(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+200|0;k=h|0;l=a;a=d;m=f;n=c[700008+(j-2<<2)>>2]|0;o=k+64|0;if((j|0)>17){p=d-2|0;d=p;q=j-11|0;if(q>>>0<15>>>0){nrc(o|0,p|0,66)|0;p=c[699944+(q<<2)>>2]|0;q=n;while(1){b[k+(q+32<<1)>>1]=b[m+(((ca(q,p)|0)+128>>8)-1<<1)>>1]|0;r=q+1|0;if((r|0)<0){q=r}else{s=o;break}}}else{s=d}d=0;while(1){q=d+1|0;p=ca(q,n)|0;m=p>>5;r=p&31;if((r|0)==0){p=m+1|0;t=ca(d,g)|0;u=0;do{b[l+(u+t<<1)>>1]=b[s+(p+u<<1)>>1]|0;u=u+1|0;}while((u|0)<32)}else{u=32-r|0;p=ca(d,g)|0;t=0;do{v=t+m|0;w=ca(e[s+(v+1<<1)>>1]|0,u)|0;b[l+(t+p<<1)>>1]=(w+16+(ca(e[s+(v+2<<1)>>1]|0,r)|0)|0)>>>5;t=t+1|0;}while((t|0)<32)}if((q|0)<32){d=q}else{break}}i=h;return}else{d=f-2|0;f=d;s=j-11|0;if(s>>>0<15>>>0){nrc(o|0,d|0,66)|0;d=c[699944+(s<<2)>>2]|0;s=n;while(1){b[k+(s+32<<1)>>1]=b[a+(((ca(s,d)|0)+128>>8)-1<<1)>>1]|0;j=s+1|0;if((j|0)<0){s=j}else{x=o;break}}}else{x=f}f=0;while(1){o=f+1|0;s=ca(o,n)|0;d=s>>5;a=s&31;if((a|0)==0){s=d+1|0;k=0;do{b[l+((ca(k,g)|0)+f<<1)>>1]=b[x+(s+k<<1)>>1]|0;k=k+1|0;}while((k|0)<32)}else{k=32-a|0;s=0;do{q=s+d|0;j=ca(e[x+(q+1<<1)>>1]|0,k)|0;b[l+((ca(s,g)|0)+f<<1)>>1]=(j+16+(ca(e[x+(q+2<<1)>>1]|0,a)|0)|0)>>>5;s=s+1|0;}while((s|0)<32)}if((o|0)<32){f=o}else{break}}i=h;return}}function LJa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;j=i;i=i+288|0;k=j|0;l=j+72|0;m=j+144|0;n=j+216|0;o=c[b+136>>2]|0;p=c[b+180>>2]|0;q=c[p+13140+(h<<2)>>2]|0;r=c[p+13152+(h<<2)>>2]|0;s=1<<g;t=s<<q;u=c[p+13072>>2]|0;v=t>>u;w=e>>u;x=f>>u;u=c[p+13124>>2]|0;y=(ca(x,u)|0)+w|0;z=c[b+184>>2]|0;A=c[z+1672>>2]|0;B=c[A+(y<<2)>>2]|0;y=c[b+160>>2]|0;C=c[y+32+(h<<2)>>2]|0;D=c[y+(h<<2)>>2]|0;y=(ca(C,f>>r)|0)+(e>>q)|0;E=D+y|0;F=c[p+13132>>2]|0;if((h|0)==0){G=c[o+173192>>2]|0}else{G=d[o+184621|0]|0}H=k+1|0;I=m+1|0;J=l+1|0;K=n+1|0;if((c[o+184624>>2]|0)==0){L=0}else{L=(B|0)>(c[A+(w-1+(ca(u,x+v|0)|0)<<2)>>2]|0)}M=L&1;N=c[o+184628>>2]|0;O=c[o+184636>>2]|0;P=c[o+184632>>2]|0;if((c[o+184640>>2]|0)==0){Q=0}else{Q=(B|0)>(c[A+(w+v+(ca(u,x-1|0)|0)<<2)>>2]|0)}x=Q&1;u=t<<1;v=u+f|0;w=p+13100|0;A=c[w>>2]|0;B=t+f|0;o=((v|0)>(A|0)?A:v)-B>>r;v=u+e|0;u=p+13096|0;A=c[u>>2]|0;R=t+e|0;S=((v|0)>(A|0)?A:v)-R>>q;v=z+20|0;if((a[v]|0)==1){z=c[p+13084>>2]|0;A=t>>z;t=(1<<z)-1|0;T=t&f;U=((A|0)==0)+A|0;A=(t&e|0)!=0;do{if(A|L^1){V=M}else{t=e-1>>z;W=B>>z;X=(c[p+13136>>2]|0)-W|0;Y=(U|0)>(X|0)?X:U;if((Y|0)<=0){V=0;break}X=c[(c[b+3480>>2]|0)+16>>2]|0;Z=0;_=0;while(1){$=d[X+(((ca(_+W|0,F)|0)+t|0)*14|0)+12|0]|Z;aa=_+1|0;if((aa|0)<(Y|0)){Z=$;_=aa}else{V=$;break}}}}while(0);do{if((N|0)!=1|A){ba=N}else{B=e-1>>z;L=f>>z;_=(c[p+13136>>2]|0)-L|0;Z=(U|0)>(_|0)?_:U;if((Z|0)<=0){ba=0;break}_=c[(c[b+3480>>2]|0)+16>>2]|0;Y=0;t=0;while(1){W=d[_+(((ca(t+L|0,F)|0)+B|0)*14|0)+12|0]|Y;X=t+1|0;if((X|0)<(Z|0)){Y=W;t=X}else{ba=W;break}}}}while(0);if((O|0)==1){A=(ca(f-1>>z,F)|0)+(e-1>>z)|0;da=d[(c[(c[b+3480>>2]|0)+16>>2]|0)+(A*14|0)+12|0]|0}else{da=O}A=(T|0)!=0;do{if((P|0)!=1|A){ea=P}else{T=e>>z;t=F-T|0;Y=(U|0)>(t|0)?t:U;if((Y|0)<=0){ea=0;break}t=(ca(f-1>>z,F)|0)+T|0;T=c[(c[b+3480>>2]|0)+16>>2]|0;Z=0;B=0;while(1){L=d[T+((t+B|0)*14|0)+12|0]|Z;_=B+1|0;if((_|0)<(Y|0)){Z=L;B=_}else{ea=L;break}}}}while(0);do{if(A|Q^1){fa=x}else{B=R>>z;Z=F-B|0;Y=(U|0)>(Z|0)?Z:U;if((Y|0)<=0){fa=0;break}Z=(ca(f-1>>z,F)|0)+B|0;B=c[(c[b+3480>>2]|0)+16>>2]|0;t=0;T=0;while(1){L=d[B+((Z+T|0)*14|0)+12|0]|t;_=T+1|0;if((_|0)<(Y|0)){t=L;T=_}else{fa=L;break}}}}while(0);mrc(H|0,-128|0,64)|0;mrc(I|0,-128|0,64)|0;ga=V;ha=ba;ia=da;ja=ea;ka=fa}else{ga=M;ha=N;ia=O;ja=P;ka=x}x=(ga|0)!=0;do{if(x){P=o+s|0;O=s<<1;if((P|0)<(O|0)){N=(-1<<q)+e|0;M=P-1|0;fa=(M<<r)+f|0;ea=D+(y-1+(ca(M,C)|0))|0;da=c[b+3480>>2]|0;ba=P;while(1){V=c[p+13084>>2]|0;z=(ca(fa>>V,F)|0)+(N>>V)|0;do{if((a[(c[da+16>>2]|0)+(z*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=37;break}ma=ba+1|0}else{la=37}}while(0);if((la|0)==37){la=0;z=ba+1|0;a[k+z|0]=a[ea]|0;ma=z}if((ma|0)<(O|0)){ba=ma}else{na=M;break}}}else{na=P-1|0}if((na|0)<(s|0)){break}M=(-1<<q)+e|0;ba=y-1|0;O=c[b+3480>>2]|0;ea=P;da=na;while(1){N=c[p+13084>>2]|0;fa=(ca((da<<r)+f>>N,F)|0)+(M>>N)|0;if((a[(c[O+16>>2]|0)+(fa*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=42}}else{la=42}if((la|0)==42){la=0;a[k+ea|0]=a[D+(ba+(ca(da,C)|0))|0]|0}fa=da-1|0;if((fa|0)<(s|0)){break}else{ea=da;da=fa}}}}while(0);na=(ha|0)!=0;if(na&(s|0)>0){ma=(-1<<q)+e|0;da=y-1|0;ea=c[b+3480>>2]|0;ba=s;while(1){O=ba-1|0;M=c[p+13084>>2]|0;P=(ca((O<<r)+f>>M,F)|0)+(ma>>M)|0;if((a[(c[ea+16>>2]|0)+(P*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=48}}else{la=48}if((la|0)==48){la=0;a[k+ba|0]=a[D+(da+(ca(O,C)|0))|0]|0}if((O|0)>0){ba=O}else{break}}}ba=(ia|0)!=0;do{if(ba){da=c[p+13084>>2]|0;ea=(ca((-1<<r)+f>>da,F)|0)+((-1<<q)+e>>da)|0;if((a[(c[(c[b+3480>>2]|0)+16>>2]|0)+(ea*14|0)+12|0]|0)==0){if((a[v]|0)!=0){break}}ea=a[D+(y+~C)|0]|0;a[k|0]=ea;a[m|0]=ea}}while(0);ea=(ja|0)!=0;if(ea&(s|0)>0){da=(-1<<r)+f|0;ma=y-C|0;O=c[b+3480>>2]|0;P=s;while(1){M=P-1|0;fa=c[p+13084>>2]|0;N=(ca(da>>fa,F)|0)+((M<<q)+e>>fa)|0;if((a[(c[O+16>>2]|0)+(N*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=58}}else{la=58}if((la|0)==58){la=0;a[m+P|0]=a[D+(ma+M)|0]|0}if((M|0)>0){P=M}else{break}}}P=(ka|0)!=0;do{if(P){ma=S+s|0;O=s<<1;da=ma-1|0;if((ma|0)<(O|0)){M=(da<<q)+e|0;N=(-1<<r)+f|0;fa=D+(y-C+da)|0;z=c[b+3480>>2]|0;V=ma;while(1){U=c[p+13084>>2]|0;Q=(ca(N>>U,F)|0)+(M>>U)|0;do{if((a[(c[z+16>>2]|0)+(Q*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=67;break}oa=V+1|0}else{la=67}}while(0);if((la|0)==67){la=0;Q=V+1|0;a[m+Q|0]=a[fa]|0;oa=Q}if((oa|0)<(O|0)){V=oa}else{break}}}if((da|0)<(s|0)){break}V=(-1<<r)+f|0;O=y-C|0;fa=c[b+3480>>2]|0;z=ma;M=da;while(1){N=c[p+13084>>2]|0;Q=(ca(V>>N,F)|0)+((M<<q)+e>>N)|0;if((a[(c[fa+16>>2]|0)+(Q*14|0)+12|0]|0)==0){if((a[v]|0)==0){la=72}}else{la=72}if((la|0)==72){la=0;a[m+z|0]=a[D+(O+M)|0]|0}Q=M-1|0;if((Q|0)<(s|0)){break}else{z=M;M=Q}}}}while(0);do{if((a[v]|0)==1){D=ga|ha;y=(D|0)!=0;oa=D|ia;D=(oa|0)==0;if((ja|ka|oa|0)==0){break}oa=s<<1;S=c[u>>2]|0;if(((oa<<q)+e|0)<(S|0)){pa=oa}else{pa=S-e>>q}M=c[w>>2]|0;if(((oa<<r)+f|0)<(M|0)){qa=oa}else{qa=M-f>>r}z=(x?o:0)+s|0;do{if(P){ra=pa}else{if((R|0)<(S|0)){ra=s;break}ra=S-e>>q}}while(0);do{if(x){sa=qa}else{if(((s<<r)+f|0)<(M|0)){sa=s;break}sa=M-f>>r}}while(0);do{if(D){M=(-1<<r)+f|0;S=b+3480|0;O=0;while(1){if((O|0)>=(ra|0)){break}fa=c[p+13084>>2]|0;V=(ca(M>>fa,F)|0)+((O<<q)+e>>fa)|0;if((a[(c[(c[S>>2]|0)+16>>2]|0)+(V*14|0)+12|0]|0)==0){O=O+1|0}else{break}}do{if((O|0)>0){if((e|0)>0){if(!((O|0)>-1)){break}V=c[S>>2]|0;fa=O;while(1){da=fa-1|0;ma=c[p+13084>>2]|0;Q=(ca(M>>ma,F)|0)+((da<<q)+e>>ma)|0;if((a[(c[V+16>>2]|0)+(Q*14|0)+12|0]|0)==0){a[m+fa|0]=a[m+(fa+1)|0]|0}if((fa|0)>0){fa=da}else{break}}}else{fa=c[S>>2]|0;V=O;while(1){da=V-1|0;Q=c[p+13084>>2]|0;ma=(ca(M>>Q,F)|0)+((da<<q)+e>>Q)|0;if((a[(c[fa+16>>2]|0)+(ma*14|0)+12|0]|0)==0){a[m+V|0]=a[m+(V+1)|0]|0}if((da|0)>0){V=da}else{break}}a[m|0]=a[I]|0;break}}}while(0);a[k|0]=a[m|0]|0;ta=0}else{M=(-1<<q)+e|0;O=b+3480|0;S=z;while(1){ua=S-1|0;va=c[p+13084>>2]|0;if((S|0)<=0){la=89;break}V=(ua<<r)+f|0;fa=(ca(V>>va,F)|0)+(M>>va)|0;da=c[O>>2]|0;ma=c[da+16>>2]|0;if((a[ma+(fa*14|0)+12|0]|0)==0){S=ua}else{wa=da;xa=ma;ya=V;break}}if((la|0)==89){S=c[O>>2]|0;wa=S;xa=c[S+16>>2]|0;ya=(ua<<r)+f|0}S=p+13084|0;V=wa+16|0;if((a[xa+(((ca(ya>>va,F)|0)+(M>>va)|0)*14|0)+12|0]|0)!=0){ta=ua;break}ma=(-1<<r)+f|0;da=0;while(1){if((da|0)>=(ra|0)){break}if((a[xa+(((ca(ma>>va,F)|0)+((da<<q)+e>>va)|0)*14|0)+12|0]|0)==0){da=da+1|0}else{break}}a:do{if((da|0)>-1){M=da;O=va;fa=xa;while(1){Q=M-1|0;if((a[fa+(((ca(ma>>O,F)|0)+((Q<<q)+e>>O)|0)*14|0)+12|0]|0)==0){a[m+M|0]=a[m+(M+1)|0]|0}if((M|0)<=0){break a}M=Q;O=c[S>>2]|0;fa=c[V>>2]|0}}}while(0);a[k|0]=a[m|0]|0;ta=0}}while(0);if(y&(ta|0)<(sa|0)){z=(-1<<q)+e|0;D=c[b+3480>>2]|0;V=ta;while(1){S=c[p+13084>>2]|0;ma=(ca((V<<r)+f>>S,F)|0)+(z>>S)|0;if((a[(c[D+16>>2]|0)+(ma*14|0)+12|0]|0)==0){ma=V+1|0;a[k+ma|0]=a[k+V|0]|0;za=ma}else{za=V+1|0}if((za|0)<(sa|0)){V=za}else{break}}}b:do{if((s|0)>0&(na^1)){V=a[k|0]|0;D=1;while(1){a[k+D|0]=V;if((D|0)>=(s|0)){break b}D=D+1|0}}}while(0);if((s|0)<(oa|0)&(x^1)){D=a[k+s|0]|0;V=s;do{V=V+1|0;a[k+V|0]=D;}while((V|0)<(oa|0))}oa=(e|0)==0;V=(f|0)==0;c:do{if(oa|V){D=sa-1|0;if(oa){if((sa|0)<=0){break}z=a[k+sa|0]|0;y=D;while(1){a[k+y|0]=z;if((y|0)>0){y=y-1|0}else{break c}}}if((D|0)<=0){break}y=(-1<<q)+e|0;z=c[b+3480>>2]|0;ma=D;while(1){S=c[p+13084>>2]|0;da=ma-1|0;fa=(ca((da<<r)+f>>S,F)|0)+(y>>S)|0;if((a[(c[z+16>>2]|0)+(fa*14|0)+12|0]|0)==0){a[k+ma|0]=a[k+(ma+1)|0]|0}if((da|0)>0){ma=da}else{break}}}else{if((sa|0)<=0){break}ma=(-1<<q)+e|0;z=c[b+3480>>2]|0;y=sa;while(1){D=y-1|0;da=c[p+13084>>2]|0;fa=(ca((y-2<<r)+f>>da,F)|0)+(ma>>da)|0;if((a[(c[z+16>>2]|0)+(fa*14|0)+12|0]|0)==0){a[k+D|0]=a[k+y|0]|0}if((D|0)>0){y=D}else{break}}}}while(0);a[m|0]=a[k|0]|0;if(!((ra|0)>0&(V^1))){break}oa=(-1<<r)+f|0;y=c[b+3480>>2]|0;z=0;while(1){ma=c[p+13084>>2]|0;D=(ca(oa>>ma,F)|0)+((z<<q)+e>>ma)|0;if((a[(c[y+16>>2]|0)+(D*14|0)+12|0]|0)==0){D=z+1|0;a[m+D|0]=a[m+z|0]|0;Aa=D}else{Aa=z+1|0}if((Aa|0)<(ra|0)){z=Aa}else{break}}}}while(0);d:do{if(x){la=176}else{if(na){Aa=s<<1;if((s|0)>=(Aa|0)){la=176;break}ra=a[k+s|0]|0;e=s;while(1){q=e+1|0;a[k+q|0]=ra;if((q|0)<(Aa|0)){e=q}else{la=176;break d}}}if(ba){e=s<<1;if((e|0)<=0){la=178;break}Aa=a[k|0]|0;ra=1;while(1){a[k+ra|0]=Aa;if((ra|0)>=(e|0)){la=178;break d}ra=ra+1|0}}if(ea){ra=a[I]|0;a[k|0]=ra;e=s<<1;if((e|0)>0){Ba=1}else{la=180;break}while(1){a[k+Ba|0]=ra;if((Ba|0)>=(e|0)){la=180;break d}Ba=Ba+1|0}}if(P){if((s|0)>0){e=s;do{a[m+e|0]=a[m+(e+1)|0]|0;e=e-1|0;}while((e|0)>0)}e=a[I]|0;a[k|0]=e;ra=s<<1;if((ra|0)>0){Ca=1}else{break}while(1){a[k+Ca|0]=e;if((Ca|0)>=(ra|0)){break d}Ca=Ca+1|0}}a[k|0]=-128;a[I]=-128;ra=s<<1;e:do{if((ra|0)>1){e=2;while(1){a[m+e|0]=-128;if((e|0)>=(ra|0)){break e}e=e+1|0}}}while(0);if((ra|0)>0){Da=1}else{la=176;break}while(1){a[k+Da|0]=-128;if((Da|0)>=(ra|0)){la=176;break d}Da=Da+1|0}}}while(0);do{if((la|0)==176){if((ha|0)==0&(s|0)>0){Ea=s}else{la=178;break}while(1){a[k+Ea|0]=a[k+(Ea+1)|0]|0;Da=Ea-1|0;if((Da|0)>0){Ea=Da}else{la=178;break}}}}while(0);do{if((la|0)==178){if((ia|0)!=0){la=180;break}a[k|0]=a[H]|0;la=180}}while(0);f:do{if((la|0)==180){if((ja|0)!=0){break}ia=a[k|0]|0;a[I]=ia;if((s|0)>1){Fa=2}else{break}while(1){a[m+Fa|0]=ia;if((Fa|0)>=(s|0)){break f}Fa=Fa+1|0}}}while(0);do{if(!P){Fa=s<<1;if((s|0)>=(Fa|0)){break}ja=a[m+s|0]|0;la=s;do{la=la+1|0;a[m+la|0]=ja;}while((la|0)<(Fa|0))}}while(0);P=k|0;Fa=a[P]|0;a[m|0]=Fa;g:do{if((h|0)!=0|(G|0)==1|(s|0)==4){Ga=H;Ha=I}else{la=G-26|0;ja=(la|0)>-1?la:26-G|0;la=G-10|0;ia=(la|0)>-1?la:10-G|0;if((((ja|0)>(ia|0)?ia:ja)|0)<=(c[1064480+(g-3<<2)>>2]|0)){Ga=H;Ha=I;break}do{if((a[p+13061|0]|0)!=0&(g|0)==5){ja=Fa&255;ia=a[m+64|0]|0;la=ia&255;Ea=la+ja-(d[m+32|0]<<1)|0;if((((Ea|0)>-1?Ea:-Ea|0)|0)>=8){break}Ea=k+64|0;ha=a[Ea]|0;Da=(ha&255)+ja-(d[k+32|0]<<1)|0;if((((Da|0)>-1?Da:-Da|0)|0)>=8){break}a[n|0]=Fa;a[n+64|0]=ia;ia=0;while(1){Da=ia+1|0;a[n+Da|0]=((ca(ja,63-ia|0)|0)+32+(ca(la,Da)|0)|0)>>>6;if((Da|0)<63){ia=Da}else{Ia=0;Ja=Fa;Ka=ha;break}}while(1){ha=Ia+1|0;a[k+ha|0]=((ca(Ja&255,63-Ia|0)|0)+32+(ca(Ka&255,ha)|0)|0)>>>6;if((ha|0)>=63){Ga=H;Ha=K;break g}Ia=ha;Ja=a[P]|0;Ka=a[Ea]|0}}}while(0);Ea=s<<1;ha=a[k+Ea|0]|0;a[l+Ea|0]=ha;ia=a[m+Ea|0]|0;a[n+Ea|0]=ia;la=Ea-2|0;Ea=(la|0)>-1;if(Ea){ja=la;Da=ha;while(1){ha=ja+1|0;Ca=a[k+ha|0]|0;a[l+ha|0]=((Da&255)+2+((Ca&255)<<1)+(d[k+ja|0]|0)|0)>>>2;if((ja|0)>0){ja=ja-1|0;Da=Ca}else{break}}}Da=((d[H]|0)+2+((Fa&255)<<1)+(d[I]|0)|0)>>>2&255;a[l|0]=Da;a[n|0]=Da;if(Ea){La=la;Ma=ia}else{Ga=J;Ha=K;break}while(1){Da=La+1|0;ja=a[m+Da|0]|0;a[n+Da|0]=((Ma&255)+2+((ja&255)<<1)+(d[m+La|0]|0)|0)>>>2;if((La|0)>0){La=La-1|0;Ma=ja}else{Ga=J;Ha=K;break}}}}while(0);if((G|0)==0){mf[c[b+5824+(g-2<<2)>>2]&2047](E,Ha,Ga,C);i=j;return}else if((G|0)==1){_e[c[b+5840>>2]&511](E,Ha,Ga,C,g,h);i=j;return}else{_e[c[b+5844+(g-2<<2)>>2]&511](E,Ha,Ga,C,h,G);i=j;return}}function MJa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c+4|0;h=e+4|0;i=0;while(1){j=e+i|0;k=3-i|0;l=i+1|0;m=ca(i,f)|0;n=ca(d[c]|0,k)|0;a[b+m|0]=(((d[j]|0)*3|0)+4+(d[g]|0)+n+(ca(d[h]|0,l)|0)|0)>>>3;n=ca(d[c+1|0]|0,k)|0;a[b+(m+1)|0]=(((d[j]|0)<<1)+4+((d[g]|0)<<1)+n+(ca(d[h]|0,l)|0)|0)>>>3;n=ca(d[c+2|0]|0,k)|0;a[b+(m+2)|0]=((d[j]|0)+4+((d[g]|0)*3|0)+n+(ca(d[h]|0,l)|0)|0)>>>3;n=ca(d[c+3|0]|0,k)|0;a[b+(m+3)|0]=(((d[g]|0)<<2)+4+n+(ca(d[h]|0,l)|0)|0)>>>3;if((l|0)<4){i=l}else{break}}return}function NJa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c+8|0;h=e+8|0;i=0;while(1){j=e+i|0;k=7-i|0;l=i+1|0;m=ca(i,f)|0;n=0;while(1){o=ca(d[j]|0,7-n|0)|0;p=n+1|0;q=ca(d[g]|0,p)|0;r=ca(d[c+n|0]|0,k)|0;a[b+(n+m)|0]=(o+8+q+r+(ca(d[h]|0,l)|0)|0)>>>4;if((p|0)<8){n=p}else{break}}if((l|0)<8){i=l}else{break}}return}function OJa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c+16|0;h=e+16|0;i=0;while(1){j=e+i|0;k=15-i|0;l=i+1|0;m=ca(i,f)|0;n=0;while(1){o=ca(d[j]|0,15-n|0)|0;p=n+1|0;q=ca(d[g]|0,p)|0;r=ca(d[c+n|0]|0,k)|0;a[b+(n+m)|0]=(o+16+q+r+(ca(d[h]|0,l)|0)|0)>>>5;if((p|0)<16){n=p}else{break}}if((l|0)<16){i=l}else{break}}return}function PJa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c+32|0;h=e+32|0;i=0;while(1){j=e+i|0;k=31-i|0;l=i+1|0;m=ca(i,f)|0;n=0;while(1){o=ca(d[j]|0,31-n|0)|0;p=n+1|0;q=ca(d[g]|0,p)|0;r=ca(d[c+n|0]|0,k)|0;a[b+(n+m)|0]=(o+32+q+r+(ca(d[h]|0,l)|0)|0)>>>6;if((p|0)<32){n=p}else{break}}if((l|0)<32){i=l}else{break}}return}function QJa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=1<<h;k=(j|0)>0;do{if(k){l=j;m=0;do{l=(d[f+m|0]|0)+l+(d[e+m|0]|0)|0;m=m+1|0;}while((m|0)<(j|0));m=l>>h+1;n=ca(m,16843009)|0;if(!k){o=m;break}p=(j|0)/4|0;if((j|0)>3){q=0}else{o=m;break}while(1){r=ca(q,g)|0;s=0;do{c[b+((s<<2)+r)>>2]=n;s=s+1|0;}while((s|0)<(p|0));s=q+1|0;if((s|0)<(j|0)){q=s}else{o=m;break}}}else{o=j>>h+1}}while(0);if(!((i|0)==0&(j|0)<32)){return}a[b]=((o<<1)+2+(d[f]|0)+(d[e]|0)|0)>>>2;i=(j|0)>1;if(!i){return}h=(o*3|0)+2|0;q=1;do{a[b+q|0]=(h+(d[e+q|0]|0)|0)>>>2;q=q+1|0;}while((q|0)<(j|0));if(!i){return}i=(o*3|0)+2|0;o=1;do{a[b+(ca(o,g)|0)|0]=(i+(d[f+o|0]|0)|0)>>>2;o=o+1|0;}while((o|0)<(j|0));return}function RJa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;k=i;i=i+104|0;l=k|0;m=c[700008+(j-2<<2)>>2]|0;n=l+4|0;o=m>>3;if((j|0)>17){p=e-1|0;q=j-11|0;do{if(q>>>0<15>>>0&(o|0)<-1){a[n]=a[p]|0;a[n+1|0]=a[p+1|0]|0;a[n+2|0]=a[p+2|0]|0;a[n+3|0]=a[p+3|0]|0;a[n+4|0]=a[p+4|0]|0;if((o|0)>=0){r=n;break}s=c[699944+(q<<2)>>2]|0;t=o;while(1){a[l+(t+4)|0]=a[f+(((ca(t,s)|0)+128>>8)-1)|0]|0;u=t+1|0;if((u|0)<0){t=u}else{r=n;break}}}else{r=p}}while(0);p=0;while(1){q=p+1|0;t=ca(q,m)|0;s=t>>5;u=t&31;if((u|0)==0){t=ca(p,g)|0;a[b+t|0]=a[r+(s+1)|0]|0;a[b+(t+1)|0]=a[r+(s+2)|0]|0;a[b+(t+2)|0]=a[r+(s+3)|0]|0;a[b+(t+3)|0]=a[r+(s+4)|0]|0}else{t=32-u|0;v=ca(p,g)|0;w=ca(d[r+(s+1)|0]|0,t)|0;a[b+v|0]=(w+16+(ca(d[r+(s+2)|0]|0,u)|0)|0)>>>5;w=ca(d[r+(s+2)|0]|0,t)|0;a[b+(v+1)|0]=(w+16+(ca(d[r+(s+3)|0]|0,u)|0)|0)>>>5;w=ca(d[r+(s+3)|0]|0,t)|0;a[b+(v+2)|0]=(w+16+(ca(d[r+(s+4)|0]|0,u)|0)|0)>>>5;w=ca(d[r+(s+4)|0]|0,t)|0;a[b+(v+3)|0]=(w+16+(ca(d[r+(s+5)|0]|0,u)|0)|0)>>>5}if((q|0)<4){p=q}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}p=f-1|0;r=((d[f]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(r>>>0>255>>>0){x=-r>>31&255}else{x=r&255}a[b]=x;x=((d[f+1|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(x>>>0>255>>>0){y=-x>>31&255}else{y=x&255}a[b+g|0]=y;y=((d[f+2|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}a[b+(g<<1)|0]=z;z=((d[f+3|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}a[b+(g*3|0)|0]=A;i=k;return}else{A=f-1|0;z=j-11|0;do{if(z>>>0<15>>>0&(o|0)<-1){a[n]=a[A]|0;a[n+1|0]=a[A+1|0]|0;a[n+2|0]=a[A+2|0]|0;a[n+3|0]=a[A+3|0]|0;a[n+4|0]=a[A+4|0]|0;if((o|0)>=0){B=n;break}p=c[699944+(z<<2)>>2]|0;y=o;while(1){a[l+(y+4)|0]=a[e+(((ca(y,p)|0)+128>>8)-1)|0]|0;x=y+1|0;if((x|0)<0){y=x}else{B=n;break}}}else{B=A}}while(0);A=0;while(1){n=A+1|0;l=ca(n,m)|0;o=l>>5;z=l&31;if((z|0)==0){a[b+A|0]=a[B+(o+1)|0]|0;a[b+(A+g)|0]=a[B+(o+2)|0]|0;a[b+((g<<1)+A)|0]=a[B+(o+3)|0]|0;a[b+((g*3|0)+A)|0]=a[B+(o+4)|0]|0}else{l=32-z|0;y=ca(d[B+(o+1)|0]|0,l)|0;a[b+A|0]=(y+16+(ca(d[B+(o+2)|0]|0,z)|0)|0)>>>5;y=ca(d[B+(o+2)|0]|0,l)|0;a[b+(A+g)|0]=(y+16+(ca(d[B+(o+3)|0]|0,z)|0)|0)>>>5;y=ca(d[B+(o+3)|0]|0,l)|0;a[b+((g<<1)+A)|0]=(y+16+(ca(d[B+(o+4)|0]|0,z)|0)|0)>>>5;y=ca(d[B+(o+4)|0]|0,l)|0;a[b+((g*3|0)+A)|0]=(y+16+(ca(d[B+(o+5)|0]|0,z)|0)|0)>>>5}if((n|0)<4){A=n}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=e-1|0;j=((d[e]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(j>>>0>255>>>0){C=-j>>31&255}else{C=j&255}a[b]=C;C=((d[e+1|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(C>>>0>255>>>0){D=-C>>31&255}else{D=C&255}a[b+1|0]=D;D=((d[e+2|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(D>>>0>255>>>0){E=-D>>31&255}else{E=D&255}a[b+2|0]=E;E=((d[e+3|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(E>>>0>255>>>0){F=-E>>31&255}else{F=E&255}a[b+3|0]=F;i=k;return}}function SJa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=i;i=i+104|0;l=k|0;m=c[700008+(j-2<<2)>>2]|0;n=l+8|0;o=m>>2;if((j|0)>17){p=e-1|0;q=j-11|0;do{if(q>>>0<15>>>0&(o|0)<-1){nrc(n|0,p|0,9)|0;if((o|0)>=0){r=n;break}s=c[699944+(q<<2)>>2]|0;t=o;while(1){a[l+(t+8)|0]=a[f+(((ca(t,s)|0)+128>>8)-1)|0]|0;u=t+1|0;if((u|0)<0){t=u}else{r=n;break}}}else{r=p}}while(0);p=0;while(1){q=p+1|0;t=ca(q,m)|0;s=t>>5;u=t&31;if((u|0)==0){t=ca(p,g)|0;a[b+t|0]=a[r+(s+1)|0]|0;a[b+(t+1)|0]=a[r+(s+2)|0]|0;a[b+(t+2)|0]=a[r+(s+3)|0]|0;a[b+(t+3)|0]=a[r+(s+4)|0]|0;a[b+(t+4)|0]=a[r+(s+5)|0]|0;a[b+(t+5)|0]=a[r+(s+6)|0]|0;a[b+(t+6)|0]=a[r+(s+7)|0]|0;a[b+(t+7)|0]=a[r+(s+8)|0]|0}else{t=32-u|0;v=ca(p,g)|0;w=0;do{x=w+s|0;y=ca(d[r+(x+1)|0]|0,t)|0;a[b+(w+v)|0]=(y+16+(ca(d[r+(x+2)|0]|0,u)|0)|0)>>>5;w=w+1|0;}while((w|0)<8)}if((q|0)<8){p=q}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}p=f-1|0;r=0;do{w=((d[f+r|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[b+(ca(r,g)|0)|0]=z;r=r+1|0;}while((r|0)<8);i=k;return}else{r=f-1|0;z=j-11|0;do{if(z>>>0<15>>>0&(o|0)<-1){nrc(n|0,r|0,9)|0;if((o|0)>=0){A=n;break}p=c[699944+(z<<2)>>2]|0;w=o;while(1){a[l+(w+8)|0]=a[e+(((ca(w,p)|0)+128>>8)-1)|0]|0;u=w+1|0;if((u|0)<0){w=u}else{A=n;break}}}else{A=r}}while(0);r=0;while(1){n=r+1|0;l=ca(n,m)|0;o=l>>5;z=l&31;if((z|0)==0){a[b+r|0]=a[A+(o+1)|0]|0;a[b+(r+g)|0]=a[A+(o+2)|0]|0;a[b+((g<<1)+r)|0]=a[A+(o+3)|0]|0;a[b+((g*3|0)+r)|0]=a[A+(o+4)|0]|0;a[b+((g<<2)+r)|0]=a[A+(o+5)|0]|0;a[b+((g*5|0)+r)|0]=a[A+(o+6)|0]|0;a[b+((g*6|0)+r)|0]=a[A+(o+7)|0]|0;a[b+((g*7|0)+r)|0]=a[A+(o+8)|0]|0}else{l=32-z|0;w=0;do{p=w+o|0;q=ca(d[A+(p+1)|0]|0,l)|0;a[b+((ca(w,g)|0)+r)|0]=(q+16+(ca(d[A+(p+2)|0]|0,z)|0)|0)>>>5;w=w+1|0;}while((w|0)<8)}if((n|0)<8){r=n}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=e-1|0;j=0;do{r=((d[e+j|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(r>>>0>255>>>0){B=-r>>31&255}else{B=r&255}a[b+j|0]=B;j=j+1|0;}while((j|0)<8);i=k;return}}function TJa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;k=i;i=i+104|0;l=k|0;m=c[700008+(j-2<<2)>>2]|0;n=l+16|0;o=m>>1;if((j|0)>17){p=e-1|0;q=j-11|0;do{if(q>>>0<15>>>0&(o|0)<-1){nrc(n|0,p|0,17)|0;if((o|0)>=0){r=n;break}s=c[699944+(q<<2)>>2]|0;t=o;while(1){a[l+(t+16)|0]=a[f+(((ca(t,s)|0)+128>>8)-1)|0]|0;u=t+1|0;if((u|0)<0){t=u}else{r=n;break}}}else{r=p}}while(0);p=0;while(1){q=p+1|0;t=ca(q,m)|0;s=t>>5;u=t&31;if((u|0)==0){t=ca(p,g)|0;a[b+t|0]=a[r+(s+1)|0]|0;a[b+(t+1)|0]=a[r+(s+2)|0]|0;a[b+(t+2)|0]=a[r+(s+3)|0]|0;a[b+(t+3)|0]=a[r+(s+4)|0]|0;a[b+(t+4)|0]=a[r+(s+5)|0]|0;a[b+(t+5)|0]=a[r+(s+6)|0]|0;a[b+(t+6)|0]=a[r+(s+7)|0]|0;a[b+(t+7)|0]=a[r+(s+8)|0]|0;a[b+(t+8)|0]=a[r+(s+9)|0]|0;a[b+(t+9)|0]=a[r+(s+10)|0]|0;a[b+(t+10)|0]=a[r+(s+11)|0]|0;a[b+(t+11)|0]=a[r+(s+12)|0]|0;a[b+(t+12)|0]=a[r+(s+13)|0]|0;a[b+(t+13)|0]=a[r+(s+14)|0]|0;a[b+(t+14)|0]=a[r+(s+15)|0]|0;a[b+(t+15)|0]=a[r+(s+16)|0]|0}else{t=32-u|0;v=ca(p,g)|0;w=0;do{x=w+s|0;y=ca(d[r+(x+1)|0]|0,t)|0;a[b+(w+v)|0]=(y+16+(ca(d[r+(x+2)|0]|0,u)|0)|0)>>>5;w=w+1|0;}while((w|0)<16)}if((q|0)<16){p=q}else{break}}if(!((j|0)==26&(h|0)==0)){i=k;return}p=f-1|0;r=0;do{w=((d[f+r|0]|0)-(d[p]|0)>>1)+(d[e]|0)|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[b+(ca(r,g)|0)|0]=z;r=r+1|0;}while((r|0)<16);i=k;return}r=f-1|0;z=j-11|0;do{if(z>>>0<15>>>0&(o|0)<-1){nrc(n|0,r|0,17)|0;if((o|0)>=0){A=n;break}p=c[699944+(z<<2)>>2]|0;w=o;while(1){a[l+(w+16)|0]=a[e+(((ca(w,p)|0)+128>>8)-1)|0]|0;u=w+1|0;if((u|0)<0){w=u}else{A=n;break}}}else{A=r}}while(0);r=0;while(1){n=r+1|0;l=ca(n,m)|0;o=l>>5;z=l&31;if((z|0)==0){l=o+1|0;w=0;do{a[b+((ca(w,g)|0)+r)|0]=a[A+(l+w)|0]|0;w=w+1|0;}while((w|0)<16)}else{w=32-z|0;l=0;do{p=l+o|0;q=ca(d[A+(p+1)|0]|0,w)|0;a[b+((ca(l,g)|0)+r)|0]=(q+16+(ca(d[A+(p+2)|0]|0,z)|0)|0)>>>5;l=l+1|0;}while((l|0)<16)}if((n|0)<16){r=n}else{break}}if(!((j|0)==10&(h|0)==0)){i=k;return}h=e-1|0;j=0;do{r=((d[e+j|0]|0)-(d[h]|0)>>1)+(d[f]|0)|0;if(r>>>0>255>>>0){B=-r>>31&255}else{B=r&255}a[b+j|0]=B;j=j+1|0;}while((j|0)<16);i=k;return}function UJa(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+104|0;k=h|0;l=c[700008+(j-2<<2)>>2]|0;m=k+32|0;if((j|0)>17){n=e-1|0;o=j-11|0;if(o>>>0<15>>>0){nrc(m|0,n|0,33)|0;p=c[699944+(o<<2)>>2]|0;o=l;while(1){a[k+(o+32)|0]=a[f+(((ca(o,p)|0)+128>>8)-1)|0]|0;q=o+1|0;if((q|0)<0){o=q}else{r=m;break}}}else{r=n}n=0;while(1){o=n+1|0;p=ca(o,l)|0;q=p>>5;s=p&31;if((s|0)==0){p=q+1|0;t=ca(n,g)|0;u=0;do{a[b+(u+t)|0]=a[r+(p+u)|0]|0;u=u+1|0;}while((u|0)<32)}else{u=32-s|0;p=ca(n,g)|0;t=0;do{v=t+q|0;w=ca(d[r+(v+1)|0]|0,u)|0;a[b+(t+p)|0]=(w+16+(ca(d[r+(v+2)|0]|0,s)|0)|0)>>>5;t=t+1|0;}while((t|0)<32)}if((o|0)<32){n=o}else{break}}i=h;return}else{n=f-1|0;f=j-11|0;if(f>>>0<15>>>0){nrc(m|0,n|0,33)|0;j=c[699944+(f<<2)>>2]|0;f=l;while(1){a[k+(f+32)|0]=a[e+(((ca(f,j)|0)+128>>8)-1)|0]|0;r=f+1|0;if((r|0)<0){f=r}else{x=m;break}}}else{x=n}n=0;while(1){m=n+1|0;f=ca(m,l)|0;j=f>>5;e=f&31;if((e|0)==0){f=j+1|0;k=0;do{a[b+((ca(k,g)|0)+n)|0]=a[x+(f+k)|0]|0;k=k+1|0;}while((k|0)<32)}else{k=32-e|0;f=0;do{o=f+j|0;r=ca(d[x+(o+1)|0]|0,k)|0;a[b+((ca(f,g)|0)+n)|0]=(r+16+(ca(d[x+(o+2)|0]|0,e)|0)|0)>>>5;f=f+1|0;}while((f|0)<32)}if((m|0)<32){n=m}else{break}}i=h;return}}function VJa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=c[b+60>>2]|0;if((c[b+100>>2]|0)<1){KIb(b,16,2639632,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1094995529;i=d;return g|0}a[e]=a[c[b+96>>2]|0]|0;c[b+140>>2]=11;h=b+120|0;c[e+4>>2]=c[h>>2];j=b+124|0;c[e+8>>2]=c[j>>2];k=e+20|0;l=k;c[l>>2]=pJb(ca(c[j>>2]|0,c[h>>2]|0)|0)|0;m=e+24|0;n=m;c[n>>2]=pJb(ca(c[j>>2]|0,c[h>>2]|0)|0)|0;o=pJb(ca(c[j>>2]|0,c[h>>2]|0)|0)|0;p=e+28|0;c[p>>2]=o;q=c[l>>2]|0;do{if((q|0)!=0){l=c[n>>2]|0;if((l|0)==0|(o|0)==0){break}r=c[j>>2]|0;if(!((ca(r,c[h>>2]|0)|0)!=0&(r&1|0)==0)){break}c[e+12>>2]=q;c[e+16>>2]=l;g=0;i=d;return g|0}}while(0);KIb(b,16,2616888,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;mJb(k);mJb(m);mJb(p);g=-12;i=d;return g|0}function WJa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0;h=i;j=e;k=b+60|0;l=c[k>>2]|0;m=g+28|0;n=c[m>>2]|0;if((n|0)<8){KIb(b,16,2452176,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}q=g+24|0;g=c[q>>2]|0;r=g+4|0;s=(d[r]|d[r+1|0]<<8)<<16>>16;a:do{if((s<<16>>16|0)==19536){if((a[g+7|0]|0)<0){t=(a[l]|0)==74}else{t=0}r=g+8|0;u=n-8|0;if(!((u|0)>-1)){KIb(0,0,2173168,(o=i,i=i+24|0,c[o>>2]=2145792,c[o+8>>2]=2121992,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}v=r;if((u|0)==0){break}w=g+n|0;x=l+32|0;if(t){y=r;z=v;while(1){if((w-z|0)<1){A=0;B=y}else{A=d[y]|0;B=y+1|0}C=A&255;if((w-B|0)<1){D=B;E=256;F=C;G=16}else{H=B+1|0;I=a[B]|0;if((A|0)==255&I<<24>>24==-1){break a}J=I<<24>>24==0?256:I&255;if(J<<16>>16==0){K=H}else{D=H;E=J;F=C;G=16}}if((G|0)==16){while(1){G=0;if((w-D|0)<3){L=0;M=D}else{L=d[D+1|0]<<8|d[D]<<16|d[D+2|0];M=D+3|0}c[x+((F&255)<<2)>>2]=L;C=E-1&65535;if(C<<16>>16==0){K=M;break}else{D=M;E=C;F=F+1&255;G=16}}}C=K;if((C-v|0)>>>0<u>>>0){y=K;z=C}else{break}}}else{z=r;y=v;while(1){if((w-y|0)<1){N=0;O=z}else{N=d[z]|0;O=z+1|0}C=N&255;if((w-O|0)<1){P=O;Q=256;R=C;G=25}else{J=O+1|0;H=a[O]|0;if((N|0)==255&H<<24>>24==-1){break a}I=H<<24>>24==0?256:H&255;if(I<<16>>16==0){S=J}else{P=J;Q=I;R=C;G=25}}if((G|0)==25){while(1){G=0;if((w-P|0)<3){T=0;U=P}else{T=(d[P+1|0]<<8|d[P]<<16|d[P+2|0])<<2;U=P+3|0}c[x+((R&255)<<2)>>2]=T;C=Q-1&65535;if(C<<16>>16==0){S=U;break}else{P=U;Q=C;R=R+1&255;G=25}}}C=S;if((C-v|0)>>>0<u>>>0){z=S;y=C}else{break}}}}else if((s<<16>>16|0)==21833){y=M4a(b,j,0)|0;if((y|0)<0){p=y;i=h;return p|0}y=c[q>>2]|0;z=y+8|0;u=c[m>>2]|0;v=u-8|0;x=c[k>>2]|0;w=(v|0)>-1;do{if((a[l]|0)==74){if(!w){KIb(0,0,2173168,(o=i,i=i+24|0,c[o>>2]=2145792,c[o+8>>2]=2121992,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}r=z;b:do{if((v|0)!=0){C=y+u|0;I=x+4|0;J=x+8|0;H=x+12|0;V=x+16|0;W=z;X=0;Y=r;c:while(1){Z=C-Y|0;do{if((Z|0)<1){_=W;G=93}else{$=a[W]|0;aa=$&63;ba=aa&255;if(aa<<24>>24==0){da=W+1|0;ea=($&255)>>>6;if((ea|0)==0){_=da;G=93;break}else if((ea|0)==3){break b}else if((ea|0)==2){fa=(c[I>>2]|0)+X|0;ga=da;G=104;break}else if((ea|0)!=1){fa=X;ga=da;G=104;break}ea=c[I>>2]|0;if(!((ea+X|0)>>>0<(ca(c[J>>2]|0,ea)|0)>>>0)){G=97;break c}if((C-da|0)<1){ha=0;ia=da}else{ha=a[da]|0;ia=W+2|0}a[(c[H>>2]|0)+X|0]=ha;if((C-ia|0)<1){ja=0;ka=ia}else{ja=a[ia]|0;ka=ia+1|0}a[(c[H>>2]|0)+((c[I>>2]|0)+X)|0]=ja;fa=X+1|0;ga=ka;G=104;break}da=$&255;$=da&64;ea=Z>>>0>1>>>0?1:Z;la=W+ea|0;if((C-la|0)<2){ma=0;na=la}else{oa=la;ma=(d[oa]|d[oa+1|0]<<8)<<16>>16&65535;na=W+(ea+2)|0}ea=ma+X|0;if((da&128|0)==0){pa=ea}else{if(ea>>>0<65536>>>0){G=111;break c}pa=ea-65536|0}ea=c[I>>2]|0;da=ca(c[J>>2]|0,ea)|0;if(!((pa+ba+ea|0)>>>0<da>>>0)){G=114;break c}if(!((ba+X+ea|0)>>>0<da>>>0)){G=116;break c}da=aa-1&255;if(($|0)==0){$=aa;ea=pa;ba=X;while(1){oa=c[H>>2]|0;a[oa+ba|0]=a[oa+ea|0]|0;oa=c[I>>2]|0;la=c[H>>2]|0;a[la+(oa+ba)|0]=a[la+(oa+ea)|0]|0;oa=$-1&255;if(oa<<24>>24==0){break}else{$=oa;ea=ea+1|0;ba=ba+1|0}}qa=X+1+da|0;ra=na;break}else{ba=aa;ea=pa;$=X;while(1){a[(c[H>>2]|0)+$|0]=a[(c[V>>2]|0)+ea|0]|0;oa=c[I>>2]|0;a[(c[H>>2]|0)+(oa+$)|0]=a[(c[V>>2]|0)+(oa+ea)|0]|0;oa=ba-1&255;if(oa<<24>>24==0){break}else{ba=oa;ea=ea+1|0;$=$+1|0}}qa=X+1+da|0;ra=na;break}}}while(0);if((G|0)==93){G=0;if((C-_|0)<1){sa=0;ta=_}else{sa=d[_]|0;ta=_+1|0}fa=sa+X|0;ga=ta;G=104}if((G|0)==104){G=0;if(fa>>>0>(ca(c[J>>2]|0,c[I>>2]|0)|0)>>>0){G=106;break}else{qa=fa;ra=ga}}Z=ra;if((Z-r|0)>>>0<v>>>0){W=ra;X=qa;Y=Z}else{break b}}if((G|0)==97){KIb(b,16,2297952,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==106){KIb(b,16,2297952,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==111){KIb(b,16,2247320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==114){KIb(b,16,2247320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==116){KIb(b,16,2205352,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);nrc(c[l+28>>2]|0,c[l+12>>2]|0,ca(c[l+8>>2]|0,c[l+4>>2]|0)|0)|0}else{if(!w){KIb(0,0,2173168,(o=i,i=i+24|0,c[o>>2]=2145792,c[o+8>>2]=2121992,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}r=z;d:do{if((v|0)!=0){Y=y+u|0;X=x+4|0;W=x+8|0;I=x+12|0;J=x+16|0;C=z;V=0;H=r;e:while(1){Z=Y-H|0;do{if((Z|0)<1){ua=C;G=129}else{$=a[C]|0;ea=$&255;ba=ea&31;if((ba|0)==0){aa=C+1|0;oa=ea>>>5;if((oa|0)==0){ua=aa;G=129;break}else if((oa|0)==2){if((Y-aa|0)<2){va=0;wa=aa}else{la=aa;va=((d[la]|d[la+1|0]<<8)<<16>>16&65535)<<1;wa=C+3|0}xa=va+V|0;ya=wa;G=152;break}else if((oa|0)==3){if((Y-aa|0)<1){za=0;Aa=aa}else{za=d[aa]<<1;Aa=C+2|0}la=za+V|0;if(la>>>0>(ca(c[W>>2]|0,c[X>>2]|0)|0)>>>0){G=147;break e}Ba=Y-Aa|0;if((za|0)>0){Ca=(Ba|0)<1;Da=za;Ea=V;while(1){if(Ca){Fa=0}else{Fa=a[Aa]|0}a[(c[I>>2]|0)+Ea|0]=Fa;Ga=Da-1|0;if((Ga|0)>0){Da=Ga;Ea=Ea+1|0}else{Ha=la;break}}}else{Ha=V}xa=Ha;ya=Aa+(Ba>>>0>1>>>0?1:Ba)|0;G=152;break}else if((oa|0)==1){if((Y-aa|0)<1){Ia=0;Ja=aa}else{Ia=d[aa]<<1;Ja=C+2|0}xa=Ia+V|0;ya=Ja;G=152;break}else{break d}}la=Z>>>0>1>>>0?1:Z;Ea=C+la|0;Da=Y-Ea|0;do{if((Da|0)<1){Ka=0;La=Ea;Ma=0}else{Ca=d[Ea]|0;if((Da|0)<2){Ka=0;La=Ea;Ma=Ca;break}da=Ea;Ka=(d[da]|d[da+1|0]<<8)<<16>>16&65534;La=C+(la+2)|0;Ma=Ca}}while(0);la=Ka+V|0;Ea=la-32768|0;Da=$<<24>>24<0;if(Da){aa=c[X>>2]|0;oa=c[W>>2]|0;if((la-32767|0)>=(ca(oa,aa)|0)){G=163;break e}Na=aa;Oa=oa;Pa=ba<<1}else{oa=ba<<1;aa=c[X>>2]|0;la=c[W>>2]|0;if((Ea+oa|0)>(ca(la,aa)|0)){G=160;break e}else{Na=aa;Oa=la;Pa=oa}}if((Pa+V|0)>>>0>(ca(Na,Oa)|0)>>>0){G=165;break e}oa=ea&64;la=(oa|0)!=0;aa=(Na<<1)-1&-(oa>>>6);if(Da){if((Ea|0)<(Pa-2+aa|0)){G=168;break e}}else{if((Ea|0)<(aa|0)){G=170;break e}}aa=Da?-2:2;Da=$&31;oa=-Da|0;Ba=(oa|0)>-1;Ca=(Ba?oa:2147483647)+Da<<1;if(($&32)==0){Da=Ea;da=ba;Ga=V;while(1){if(la){Qa=c[I>>2]|0;a[Qa+Ga|0]=a[Qa+(Da+1-(c[X>>2]<<1))|0]|0;Qa=c[I>>2]|0;a[Qa+(Ga+1)|0]=a[Qa+Da|0]|0}else{Qa=c[I>>2]|0;a[Qa+Ga|0]=a[Qa+Da|0]|0;Qa=c[I>>2]|0;a[Qa+(Ga+1)|0]=a[Qa+(Da+1)|0]|0}Qa=da-1|0;if((Qa|0)>0){Da=Da+aa|0;da=Qa;Ga=Ga+2|0}else{break}}}else{Ga=Ea;da=ba;Da=V;while(1){if(la){a[(c[I>>2]|0)+Da|0]=a[(c[J>>2]|0)+(Ga+1-(c[X>>2]<<1))|0]|0;a[(c[I>>2]|0)+(Da+1)|0]=a[(c[J>>2]|0)+Ga|0]|0}else{a[(c[I>>2]|0)+Da|0]=a[(c[J>>2]|0)+Ga|0]|0;a[(c[I>>2]|0)+(Da+1)|0]=a[(c[J>>2]|0)+(Ga+1)|0]|0}$=da-1|0;if(($|0)>0){Ga=Ga+aa|0;da=$;Da=Da+2|0}else{break}}}Da=V+2+Ca|0;if((Ma&1|0)==0){Ra=Da;Sa=La;break}da=ba;aa=Da-Pa|0;while(1){Ga=c[I>>2]|0;la=Ga+aa|0;Ea=a[la]|0;$=aa+1|0;a[la]=a[Ga+$|0]|0;a[(c[I>>2]|0)+$|0]=Ea;Ea=da-1|0;if((Ea|0)>0){da=Ea;aa=aa+2|0}else{break}}Ra=(Ba?(oa<<1)+2|0:0)+Da|0;Sa=La}}while(0);if((G|0)==129){G=0;Z=V+2|0;if(Z>>>0>(ca(c[W>>2]|0,c[X>>2]|0)|0)>>>0){G=130;break}if((Y-ua|0)<1){Ta=0;Ua=ua}else{Ta=a[ua]|0;Ua=ua+1|0}a[(c[I>>2]|0)+V|0]=Ta;if((Y-Ua|0)<1){Va=0;Wa=Ua}else{Va=a[Ua]|0;Wa=Ua+1|0}a[(c[I>>2]|0)+(V+1)|0]=Va;xa=Z;ya=Wa;G=152}if((G|0)==152){G=0;if(xa>>>0>(ca(c[W>>2]|0,c[X>>2]|0)|0)>>>0){G=154;break}else{Ra=xa;Sa=ya}}Z=Sa;if((Z-r|0)>>>0<v>>>0){C=Sa;V=Ra;H=Z}else{break d}}if((G|0)==130){KIb(b,16,2297952,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==147){KIb(b,16,2297952,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==154){KIb(b,16,2297952,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==160){KIb(b,16,2247320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==163){KIb(b,16,2247320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==165){KIb(b,16,2205352,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==168){KIb(b,16,2247320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==170){KIb(b,16,2247320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);r=c[k>>2]|0;H=r+8|0;V=c[H>>2]|0;if((V|0)==0){break}C=r+4|0;X=r+12|0;W=r+28|0;r=0;I=c[C>>2]|0;Y=V;while(1){V=r&1;if((I|0)==0){Xa=0;Ya=Y}else{J=(ca(r-V|0,I)|0)+V|0;V=0;Z=I;while(1){aa=(ca(Z,r)|0)+V|0;a[(c[W>>2]|0)+aa|0]=a[(c[X>>2]|0)+J|0]|0;aa=V+1|0;Za=c[C>>2]|0;if(aa>>>0<Za>>>0){J=J+2|0;V=aa;Z=Za}else{break}}Xa=Za;Ya=c[H>>2]|0}Z=r+1|0;if(Z>>>0<Ya>>>0){r=Z;I=Xa;Y=Ya}else{break}}}}while(0);v=c[k>>2]|0;z=v+8|0;if((c[z>>2]|0)>0){x=v+4|0;u=e+32|0;y=c[v+28>>2]|0;v=c[e>>2]|0;w=0;Y=c[x>>2]|0;while(1){nrc(v|0,y|0,Y)|0;I=c[x>>2]|0;r=w+1|0;if((r|0)<(c[z>>2]|0)){y=y+I|0;v=v+(c[u>>2]|0)|0;w=r;Y=I}else{break}}}c[e+88>>2]=2;c[e+84>>2]=0;nrc(c[e+4>>2]|0,l+32|0,1024)|0;c[f>>2]=1;Y=l+12|0;w=c[Y>>2]|0;u=l+16|0;c[Y>>2]=c[u>>2];c[u>>2]=w}else if((s<<16>>16|0)==23113){if((n|0)<12){KIb(b,16,2452176,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}w=M4a(b,j,0)|0;if((w|0)<0){p=w;i=h;return p|0}w=c[q>>2]|0;u=w+12|0;Y=c[m>>2]|0;v=Y-12|0;y=c[k>>2]|0;if(!((v|0)>-1)){KIb(0,0,2173168,(o=i,i=i+24|0,c[o>>2]=2145792,c[o+8>>2]=2121992,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}z=u;f:do{if((v|0)!=0){x=w+Y|0;I=y+4|0;r=y+8|0;H=y+12|0;C=u;X=0;W=0;Z=0;V=z;g:while(1){do{if((W|0)==0){if((x-V|0)<4){_a=29;$a=0;ab=C;bb=0;G=60;break}J=C;cb=32;db=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;eb=C+4|0;G=38}else{cb=W;db=X;eb=C;G=38}}while(0);do{if((G|0)==38){G=0;J=db<<1;aa=cb-1|0;if(!((db|0)>-1)){if(!(Z>>>0<(ca(c[r>>2]|0,c[I>>2]|0)|0)>>>0)){G=40;break g}if((x-eb|0)<1){fb=0;gb=eb}else{fb=a[eb]|0;gb=eb+1|0}a[(c[H>>2]|0)+Z|0]=fb;hb=Z+1|0;ib=aa;jb=J;kb=gb;break}if((aa|0)==0){if((x-eb|0)<4){_a=30;$a=0;ab=eb;bb=0;G=60;break}da=eb;lb=32;mb=d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0;nb=eb+4|0}else{lb=aa;mb=J;nb=eb}J=mb<<1;aa=lb-1|0;if(!((mb|0)>-1)){if((x-nb|0)<2){ob=nb;pb=-8192}else{da=nb+2|0;ba=nb;Ca=(d[ba]|d[ba+1|0]<<8)<<16>>16&65535;ba=Ca&7;Ea=Ca>>>3|-8192;if((ba|0)==0){ob=da;pb=Ea}else{qb=Ea;rb=ba;sb=aa;tb=J;ub=da;G=62;break}}if((x-ob|0)<1){break f}da=a[ob]|0;if(da<<24>>24==0){break f}else{qb=pb;rb=da&255;sb=aa;tb=J;ub=ob+1|0;G=62;break}}if((aa|0)==0){if((x-nb|0)<4){vb=0;wb=nb}else{aa=nb;vb=d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0;wb=nb+4|0}_a=31;$a=vb<<1;ab=wb;bb=vb>>>31<<1;G=60;break}else{aa=lb-2|0;J=mb>>>30<<1&2;if((aa|0)!=0){_a=aa;$a=mb<<2;ab=nb;bb=J;G=60;break}if((x-nb|0)<4){_a=32;$a=0;ab=nb;bb=J;G=60;break}aa=nb;_a=32;$a=d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0;ab=nb+4|0;bb=J;G=60;break}}}while(0);do{if((G|0)==60){G=0;J=$a<<1;aa=_a-1|0;da=$a>>>31|bb;if((x-ab|0)<1){qb=-256;rb=da;sb=aa;tb=J;ub=ab;G=62;break}qb=d[ab]|-256;rb=da;sb=aa;tb=J;ub=ab+1|0;G=62}}while(0);do{if((G|0)==62){G=0;J=rb+2|0;aa=qb+Z|0;if((aa|0)<0){G=64;break g}da=ca(c[r>>2]|0,c[I>>2]|0)|0;if(!((aa+J|0)>>>0<da>>>0)){G=64;break g}ba=J+Z|0;if(!(ba>>>0<da>>>0)){G=67;break g}if((J|0)==0){hb=Z;ib=sb;jb=tb;kb=ub;break}else{xb=J;yb=Z;zb=aa}while(1){aa=xb-1|0;J=c[H>>2]|0;a[J+yb|0]=a[J+zb|0]|0;if((aa|0)==0){hb=ba;ib=sb;jb=tb;kb=ub;break}else{xb=aa;yb=yb+1|0;zb=zb+1|0}}}}while(0);ba=kb;if((ba-z|0)>>>0<v>>>0){C=kb;X=jb;W=ib;Z=hb;V=ba}else{break f}}if((G|0)==40){KIb(b,16,2205352,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==64){KIb(b,16,2247320,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((G|0)==67){KIb(b,16,2205352,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);v=l+12|0;z=l+4|0;u=l+8|0;nrc(c[l+16>>2]|0,c[v>>2]|0,ca(c[u>>2]|0,c[z>>2]|0)|0)|0;do{if((a[l]|0)==74){nrc(c[l+28>>2]|0,c[v>>2]|0,ca(c[u>>2]|0,c[z>>2]|0)|0)|0}else{y=c[k>>2]|0;Y=y+8|0;w=c[Y>>2]|0;if((w|0)==0){break}V=y+4|0;Z=y+12|0;W=y+28|0;y=0;X=c[V>>2]|0;C=w;while(1){w=y&1;if((X|0)==0){Ab=0;Bb=C}else{H=(ca(y-w|0,X)|0)+w|0;w=0;I=X;while(1){r=(ca(I,y)|0)+w|0;a[(c[W>>2]|0)+r|0]=a[(c[Z>>2]|0)+H|0]|0;r=w+1|0;Cb=c[V>>2]|0;if(r>>>0<Cb>>>0){H=H+2|0;w=r;I=Cb}else{break}}Ab=Cb;Bb=c[Y>>2]|0}I=y+1|0;if(I>>>0<Bb>>>0){y=I;X=Ab;C=Bb}else{break}}}}while(0);z=c[k>>2]|0;u=z+8|0;if((c[u>>2]|0)>0){v=z+4|0;C=e+32|0;X=c[z+28>>2]|0;z=c[e>>2]|0;y=0;Y=c[v>>2]|0;while(1){nrc(z|0,X|0,Y)|0;V=c[v>>2]|0;Z=y+1|0;if((Z|0)<(c[u>>2]|0)){X=X+V|0;z=z+(c[C>>2]|0)|0;y=Z;Y=V}else{break}}}c[e+88>>2]=1;c[e+84>>2]=1;nrc(c[e+4>>2]|0,l+32|0,1024)|0;c[f>>2]=1}else{KIb(b,16,2362872,(o=i,i=i+8|0,c[o>>2]=s&65535,o)|0);i=o;p=-1094995529;i=h;return p|0}}while(0);p=c[m>>2]|0;i=h;return p|0}function XJa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+20|0);mJb(b+24|0);mJb(b+28|0);return 0}function YJa(a,b){a=a|0;b=b|0;c[a>>2]=652;c[a+4>>2]=514;c[a+8>>2]=424;c[a+12>>2]=804;c[a+16>>2]=208;c[a+20>>2]=784;c[a+24>>2]=688;c[a+28>>2]=850;c[a+32>>2]=70;c[a+36>>2]=348;c[a+40>>2]=254;c[a+44>>2]=230;c[a+48>>2]=202;c[a+52>>2]=718;c[a+56>>2]=392;c[a+60>>2]=868;c[a+128>>2]=694;c[a+132>>2]=932;c[a+136>>2]=846;c[a+140>>2]=368;c[a+144>>2]=208;c[a+148>>2]=16;c[a+152>>2]=440;c[a+156>>2]=414;c[a+64>>2]=546;c[a+68>>2]=246;c[a+72>>2]=642;c[a+76>>2]=136;c[a+80>>2]=670;c[a+84>>2]=990;c[a+88>>2]=232;c[a+92>>2]=716;c[a+96>>2]=28;c[a+100>>2]=196;c[a+104>>2]=118;c[a+108>>2]=234;c[a+112>>2]=696;c[a+116>>2]=450;c[a+120>>2]=978;c[a+124>>2]=518;c[a+192>>2]=526;c[a+196>>2]=270;c[a+200>>2]=194;c[a+204>>2]=586;return}function ZJa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){j=g;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=g+4|0;c[h+4>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=i+1|0;if((j|0)<(f|0)){g=g+e|0;h=h+e|0;i=j}else{break}}i=b+8|0;b=a+8|0;a=0;while(1){h=i;c[b>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=i+4|0;c[b+4>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=a+1|0;if((h|0)<(f|0)){i=i+e|0;b=b+e|0;a=h}else{break}}return}function _Ja(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>0){g=0}else{return}while(1){h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);j=h+4|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(h+5)|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=(h|i)-((h^i)>>>1&2139062143);i=g+1|0;if((i|0)<(f|0)){g=i}else{l=0;break}}do{g=ca(l,e)|0;i=g+8|0;h=b+i|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(g+9)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+i>>2]=(k|j)-((k^j)>>>1&2139062143);j=g+12|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(g+13)|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=(g|i)-((g^i)>>>1&2139062143);l=l+1|0;}while((l|0)<(f|0));return}function $Ja(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);j=h+4|0;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(j+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+j>>2]=(i|k)-((i^k)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));g=e+8|0;k=e+12|0;i=0;do{j=ca(i,e)|0;h=j+8|0;l=b+h|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(g+j)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+h>>2]=(n|m)-((n^m)>>>1&2139062143);m=j+12|0;n=b+m|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(k+j)|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[a+m>>2]=(j|h)-((j^h)>>>1&2139062143);i=i+1|0;}while((i|0)<(f|0));return}function aKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eKa(a,b,c,d);eKa(a+8|0,b+8|0,c,d);return}function bKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){a=g;c[h>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=g+4|0;c[h+4>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=i+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=a}else{break}}return}function cKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);j=h+4|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(h+5)|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=(h|i)-((h^i)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function dKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);j=h+4|0;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(j+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+j>>2]=(i|k)-((i^k)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function eKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=e+4-(ca(f+1|0,e)|0)|0;h=4-(ca(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+33686018+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;c[b>>2]=r+o+((a+l|0)>>>2&252645135);p=n+j|0;q=p;s=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+k|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=(s&50529027)+33686018+(t&50529027)|0;u=(t>>>2&1061109567)+(s>>>2&1061109567)|0;c[b+e>>2]=u+r+((q+a|0)>>>2&252645135);a=m+2|0;if((a|0)<(f|0)){l=q;o=u;m=a;n=p;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+33686018+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(p&50529027)+(b&50529027)|0;a=(p>>>2&1061109567)+(b>>>2&1061109567)|0;c[m>>2]=a+n+((h+o|0)>>>2&252645135);b=g+j|0;p=b;u=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+k|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=(u&50529027)+33686018+(q&50529027)|0;r=(q>>>2&1061109567)+(u>>>2&1061109567)|0;c[m+e>>2]=r+a+((p+h|0)>>>2&252645135);h=l+2|0;if((h|0)<(f|0)){o=p;n=r;l=h;g=b;m=m+j|0}else{break}}return}function fKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){a=g;c[h>>2]=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24;a=i+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=a}else{break}}return}function gKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function hKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=(k|j)-((k^j)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function iKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=b;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=b+1|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;if((f|0)<=0){return}g=e+1|0;j=e<<1;k=j|1;l=(i>>>2&1061109567)+(h>>>2&1061109567)|0;m=(h&50529027)+33686018+(i&50529027)|0;i=0;h=b;b=a;while(1){a=h+e|0;n=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=h+g|0;o=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(o&50529027)+(n&50529027)|0;p=(o>>>2&1061109567)+(n>>>2&1061109567)|0;c[b>>2]=p+l+((a+m|0)>>>2&252645135);n=h+j|0;o=n;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+k|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(q&50529027)+33686018+(r&50529027)|0;s=(r>>>2&1061109567)+(q>>>2&1061109567)|0;c[b+e>>2]=s+p+((o+a|0)>>>2&252645135);a=i+2|0;if((a|0)<(f|0)){l=s;m=o;i=a;h=n;b=b+j|0}else{break}}return}function jKa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((f|0)>0){g=c;h=a;i=0}else{return}while(1){a=g;b[h>>1]=(d[a]|d[a+1|0]<<8)<<16>>16;a=i+1|0;if((a|0)<(f|0)){g=g+e|0;h=h+e|0;i=a}else{break}}return}function kKa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=c+h|0;j=(d[i]|d[i+1|0]<<8)<<16>>16;i=c+(h+1)|0;k=(d[i]|d[i+1|0]<<8)<<16>>16;b[a+h>>1]=(k|j)-(((k^j)&65535)>>>1&32639);g=g+1|0;}while((g|0)<(f|0));return}function lKa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=c+h|0;j=(d[i]|d[i+1|0]<<8)<<16>>16;i=c+(h+e)|0;k=(d[i]|d[i+1|0]<<8)<<16>>16;b[a+h>>1]=(k|j)-(((k^j)&65535)>>>1&32639);g=g+1|0;}while((g|0)<(f|0));return}function mKa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=(d[c+1|0]|0)+2|0;if((f|0)<=0){return}h=e+1|0;i=e+2|0;j=e<<1;k=j|1;l=j+2|0;m=g+(d[c]|0)|0;n=g+(d[c+2|0]|0)|0;g=0;o=b;b=c;while(1){c=d[b+h|0]|0;p=c+(d[b+e|0]|0)|0;q=(d[b+i|0]|0)+c|0;a[o]=(p+m|0)>>>2;a[o+1|0]=(q+n|0)>>>2;c=b+j|0;r=(d[b+k|0]|0)+2|0;s=r+(d[c]|0)|0;t=r+(d[b+l|0]|0)|0;a[o+e|0]=(s+p|0)>>>2;a[o+h|0]=(t+q|0)>>>2;q=g+2|0;if((q|0)<(f|0)){m=s;n=t;g=q;o=o+j|0;b=c}else{break}}return}function nKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){j=g;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=g+4|0;c[h+4>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=i+1|0;if((j|0)<(f|0)){g=g+e|0;h=h+e|0;i=j}else{break}}i=b+8|0;b=a+8|0;a=0;while(1){h=i;c[b>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=i+4|0;c[b+4>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=a+1|0;if((h|0)<(f|0)){i=i+e|0;b=b+e|0;a=h}else{break}}return}function oKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>0){g=0}else{return}while(1){h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=((k^j)>>>1&2139062143)+(k&j);j=h+4|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(h+5)|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=((h^i)>>>1&2139062143)+(h&i);i=g+1|0;if((i|0)<(f|0)){g=i}else{l=0;break}}do{g=ca(l,e)|0;i=g+8|0;h=b+i|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(g+9)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+i>>2]=((k^j)>>>1&2139062143)+(k&j);j=g+12|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(g+13)|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=((g^i)>>>1&2139062143)+(g&i);l=l+1|0;}while((l|0)<(f|0));return}function pKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=((k^j)>>>1&2139062143)+(k&j);j=h+4|0;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(j+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+j>>2]=((i^k)>>>1&2139062143)+(i&k);g=g+1|0;}while((g|0)<(f|0));g=e+8|0;k=e+12|0;i=0;do{j=ca(i,e)|0;h=j+8|0;l=b+h|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(g+j)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+h>>2]=((n^m)>>>1&2139062143)+(n&m);m=j+12|0;n=b+m|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=b+(k+j)|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[a+m>>2]=((j^h)>>>1&2139062143)+(j&h);i=i+1|0;}while((i|0)<(f|0));return}function qKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tKa(a,b,c,d);tKa(a+8|0,b+8|0,c,d);return}function rKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=((k^j)>>>1&2139062143)+(k&j);j=h+4|0;k=b+j|0;i=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+(h+5)|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+j>>2]=((h^i)>>>1&2139062143)+(h&i);g=g+1|0;}while((g|0)<(f|0));return}function sKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+h>>2]=((k^j)>>>1&2139062143)+(k&j);j=h+4|0;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(j+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+j>>2]=((i^k)>>>1&2139062143)+(i&k);g=g+1|0;}while((g|0)<(f|0));return}function tKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=e+4-(ca(f+1|0,e)|0)|0;h=4-(ca(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+16843009+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;c[b>>2]=r+o+((a+l|0)>>>2&252645135);p=n+j|0;q=p;s=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+k|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=(s&50529027)+16843009+(t&50529027)|0;u=(t>>>2&1061109567)+(s>>>2&1061109567)|0;c[b+e>>2]=u+r+((q+a|0)>>>2&252645135);a=m+2|0;if((a|0)<(f|0)){l=q;o=u;m=a;n=p;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+16843009+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(p&50529027)+(b&50529027)|0;a=(p>>>2&1061109567)+(b>>>2&1061109567)|0;c[m>>2]=a+n+((h+o|0)>>>2&252645135);b=g+j|0;p=b;u=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+k|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=(u&50529027)+16843009+(q&50529027)|0;r=(q>>>2&1061109567)+(u>>>2&1061109567)|0;c[m+e>>2]=r+a+((p+h|0)>>>2&252645135);h=l+2|0;if((h|0)<(f|0)){o=p;n=r;l=h;g=b;m=m+j|0}else{break}}return}function uKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){j=h;k=c[j>>2]|0;l=g;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[j>>2]=(m|k)-((m^k)>>>1&2139062143);k=h+4|0;m=c[k>>2]|0;j=g+4|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=i+1|0;if((m|0)<(f|0)){g=g+e|0;h=h+e|0;i=m}else{break}}i=b+8|0;b=a+8|0;a=0;while(1){h=b;g=c[h>>2]|0;m=i;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[h>>2]=(l|g)-((l^g)>>>1&2139062143);g=b+4|0;l=c[g>>2]|0;h=i+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[g>>2]=(m|l)-((m^l)>>>1&2139062143);l=a+1|0;if((l|0)<(f|0)){i=i+e|0;b=b+e|0;a=l}else{break}}return}function vKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=0}else{return}while(1){h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;m=b+l|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+5)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+l|0;l=c[m>>2]|0;j=(h|i)-((h^i)>>>1&2139062143)|0;c[m>>2]=(j|l)-((j^l)>>>1&2139062143);l=g+1|0;if((l|0)<(f|0)){g=l}else{n=0;break}}do{g=ca(n,e)|0;l=g+8|0;j=b+l|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(g+9)|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+l|0;l=c[j>>2]|0;h=(i|m)-((i^m)>>>1&2139062143)|0;c[j>>2]=(h|l)-((h^l)>>>1&2139062143);l=g+12|0;h=b+l|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(g+13)|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;m=(g|j)-((g^j)>>>1&2139062143)|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);n=n+1|0;}while((n|0)<(f|0));return}function wKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(l+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;j=(i|m)-((i^m)>>>1&2139062143)|0;c[h>>2]=(j|l)-((j^l)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));g=e+8|0;l=e+12|0;j=0;do{h=ca(j,e)|0;m=h+8|0;i=b+m|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(g+h)|0;n=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+m|0;m=c[i>>2]|0;o=(n|k)-((n^k)>>>1&2139062143)|0;c[i>>2]=(o|m)-((o^m)>>>1&2139062143);m=h+12|0;o=b+m|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(l+h)|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+m|0;m=c[o>>2]|0;k=(h|i)-((h^i)>>>1&2139062143)|0;c[o>>2]=(k|m)-((k^m)>>>1&2139062143);j=j+1|0;}while((j|0)<(f|0));return}function xKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;BKa(a,b,c,d);BKa(a+8|0,b+8|0,c,d);return}function yKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){a=h;b=c[a>>2]|0;j=g;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a>>2]=(k|b)-((k^b)>>>1&2139062143);b=h+4|0;k=c[b>>2]|0;a=g+4|0;j=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;c[b>>2]=(j|k)-((j^k)>>>1&2139062143);k=i+1|0;if((k|0)<(f|0)){g=g+e|0;h=h+e|0;i=k}else{break}}return}function zKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;m=b+l|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+5)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+l|0;l=c[m>>2]|0;j=(h|i)-((h^i)>>>1&2139062143)|0;c[m>>2]=(j|l)-((j^l)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function AKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(l+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;j=(i|m)-((i^m)>>>1&2139062143)|0;c[h>>2]=(j|l)-((j^l)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function BKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=e+4-(ca(f+1|0,e)|0)|0;h=4-(ca(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+33686018+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;p=b;q=c[p>>2]|0;s=r+o+((a+l|0)>>>2&252645135)|0;c[p>>2]=(s|q)-((s^q)>>>1&2139062143);q=n+j|0;s=q;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+k|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=(p&50529027)+33686018+(t&50529027)|0;u=(t>>>2&1061109567)+(p>>>2&1061109567)|0;p=b+e|0;t=c[p>>2]|0;v=u+r+((s+a|0)>>>2&252645135)|0;c[p>>2]=(v|t)-((v^t)>>>1&2139062143);t=m+2|0;if((t|0)<(f|0)){l=s;o=u;m=t;n=q;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+33686018+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(q&50529027)+(b&50529027)|0;t=(q>>>2&1061109567)+(b>>>2&1061109567)|0;b=m;q=c[b>>2]|0;u=t+n+((h+o|0)>>>2&252645135)|0;c[b>>2]=(u|q)-((u^q)>>>1&2139062143);q=g+j|0;u=q;b=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=g+k|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=(b&50529027)+33686018+(s&50529027)|0;v=(s>>>2&1061109567)+(b>>>2&1061109567)|0;b=m+e|0;s=c[b>>2]|0;p=v+t+((u+h|0)>>>2&252645135)|0;c[b>>2]=(p|s)-((p^s)>>>1&2139062143);s=l+2|0;if((s|0)<(f|0)){o=u;n=v;l=s;g=q;m=m+j|0}else{break}}return}function CKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){a=h;b=c[a>>2]|0;j=g;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a>>2]=(k|b)-((k^b)>>>1&2139062143);b=i+1|0;if((b|0)<(f|0)){g=g+e|0;h=h+e|0;i=b}else{break}}return}function DKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;h=c[i>>2]|0;l=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(l|h)-((l^h)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function EKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;h=c[i>>2]|0;l=(k|j)-((k^j)>>>1&2139062143)|0;c[i>>2]=(l|h)-((l^h)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));return}function FKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=b;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=b+1|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;if((f|0)<=0){return}g=e+1|0;j=e<<1;k=j|1;l=(i>>>2&1061109567)+(h>>>2&1061109567)|0;m=(h&50529027)+33686018+(i&50529027)|0;i=0;h=b;b=a;while(1){a=h+e|0;n=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=h+g|0;o=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(o&50529027)+(n&50529027)|0;p=(o>>>2&1061109567)+(n>>>2&1061109567)|0;n=b;o=c[n>>2]|0;q=p+l+((a+m|0)>>>2&252645135)|0;c[n>>2]=(q|o)-((q^o)>>>1&2139062143);o=h+j|0;q=o;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+k|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=(n&50529027)+33686018+(r&50529027)|0;s=(r>>>2&1061109567)+(n>>>2&1061109567)|0;n=b+e|0;r=c[n>>2]|0;t=s+p+((q+a|0)>>>2&252645135)|0;c[n>>2]=(t|r)-((t^r)>>>1&2139062143);r=i+2|0;if((r|0)<(f|0)){l=s;m=q;i=r;h=o;b=b+j|0}else{break}}return}function GKa(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)>0){g=c;h=a;i=0}else{return}while(1){a=h;c=b[a>>1]|0;j=g;k=(d[j]|d[j+1|0]<<8)<<16>>16;b[a>>1]=(k|c)-(((k^c)&65535)>>>1&32639);c=i+1|0;if((c|0)<(f|0)){g=g+e|0;h=h+e|0;i=c}else{break}}return}function HKa(a,c,f,g){a=a|0;c=c|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)>0){h=0}else{return}do{i=ca(h,f)|0;j=c+i|0;k=(d[j]|d[j+1|0]<<8)<<16>>16;j=c+(i+1)|0;l=(d[j]|d[j+1|0]<<8)<<16>>16;j=a+i|0;i=e[j>>1]|0;m=((l|k)&65535)-(((l^k)&65535)>>>1&32639)|0;b[j>>1]=(m|i)-((m^i)>>>1&32639);h=h+1|0;}while((h|0)<(g|0));return}function IKa(a,c,f,g){a=a|0;c=c|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)>0){h=0}else{return}do{i=ca(h,f)|0;j=c+i|0;k=(d[j]|d[j+1|0]<<8)<<16>>16;j=c+(i+f)|0;l=(d[j]|d[j+1|0]<<8)<<16>>16;j=a+i|0;i=e[j>>1]|0;m=((l|k)&65535)-(((l^k)&65535)>>>1&32639)|0;b[j>>1]=(m|i)-((m^i)>>>1&32639);h=h+1|0;}while((h|0)<(g|0));return}function JKa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=(d[c+1|0]|0)+2|0;if((f|0)<=0){return}h=e+1|0;i=e+2|0;j=e<<1;k=j|1;l=j+2|0;m=g+(d[c]|0)|0;n=g+(d[c+2|0]|0)|0;g=0;o=b;b=c;while(1){c=d[b+h|0]|0;p=c+(d[b+e|0]|0)|0;q=(d[b+i|0]|0)+c|0;a[o]=(p+m|0)>>>2;a[o+1|0]=(q+n|0)>>>2;c=b+j|0;r=(d[b+k|0]|0)+2|0;s=r+(d[c]|0)|0;t=r+(d[b+l|0]|0)|0;a[o+e|0]=(s+p|0)>>>2;a[o+h|0]=(t+q|0)>>>2;q=g+2|0;if((q|0)<(f|0)){m=s;n=t;g=q;o=o+j|0;b=c}else{break}}return}function KKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=b;h=a;i=0}else{return}while(1){j=h;k=c[j>>2]|0;l=g;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[j>>2]=(m|k)-((m^k)>>>1&2139062143);k=h+4|0;m=c[k>>2]|0;j=g+4|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[k>>2]=(l|m)-((l^m)>>>1&2139062143);m=i+1|0;if((m|0)<(f|0)){g=g+e|0;h=h+e|0;i=m}else{break}}i=b+8|0;b=a+8|0;a=0;while(1){h=b;g=c[h>>2]|0;m=i;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[h>>2]=(l|g)-((l^g)>>>1&2139062143);g=b+4|0;l=c[g>>2]|0;h=i+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[g>>2]=(m|l)-((m^l)>>>1&2139062143);l=a+1|0;if((l|0)<(f|0)){i=i+e|0;b=b+e|0;a=l}else{break}}return}function LKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=0}else{return}while(1){h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+1)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=((k^j)>>>1&2139062143)+(k&j)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;m=b+l|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(h+5)|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+l|0;l=c[m>>2]|0;j=((h^i)>>>1&2139062143)+(h&i)|0;c[m>>2]=(j|l)-((j^l)>>>1&2139062143);l=g+1|0;if((l|0)<(f|0)){g=l}else{n=0;break}}do{g=ca(n,e)|0;l=g+8|0;j=b+l|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(g+9)|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+l|0;l=c[j>>2]|0;h=((i^m)>>>1&2139062143)+(i&m)|0;c[j>>2]=(h|l)-((h^l)>>>1&2139062143);l=g+12|0;h=b+l|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(g+13)|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;m=((g^j)>>>1&2139062143)+(g&j)|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);n=n+1|0;}while((n|0)<(f|0));return}function MKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)>0){g=0}else{return}do{h=ca(g,e)|0;i=b+h|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(h+e)|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;l=c[i>>2]|0;m=((k^j)>>>1&2139062143)+(k&j)|0;c[i>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+4|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(l+e)|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+l|0;l=c[h>>2]|0;j=((i^m)>>>1&2139062143)+(i&m)|0;c[h>>2]=(j|l)-((j^l)>>>1&2139062143);g=g+1|0;}while((g|0)<(f|0));g=e+8|0;l=e+12|0;j=0;do{h=ca(j,e)|0;m=h+8|0;i=b+m|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=b+(g+h)|0;n=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+m|0;m=c[i>>2]|0;o=((n^k)>>>1&2139062143)+(n&k)|0;c[i>>2]=(o|m)-((o^m)>>>1&2139062143);m=h+12|0;o=b+m|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(l+h)|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+m|0;m=c[o>>2]|0;k=((h^i)>>>1&2139062143)+(h&i)|0;c[o>>2]=(k|m)-((k^m)>>>1&2139062143);j=j+1|0;}while((j|0)<(f|0));return}function NKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;OKa(a,b,c,d);OKa(a+8|0,b+8|0,c,d);return}function OKa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=e+4-(ca(f+1|0,e)|0)|0;h=4-(ca(f,e)|0)|0;i=e+1|0;j=e<<1;k=j|1;if((f|0)<=0){return}l=b;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+1|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=(m&50529027)+16843009+(n&50529027)|0;o=(n>>>2&1061109567)+(m>>>2&1061109567)|0;m=0;n=b;b=a;while(1){a=n+e|0;p=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=n+i|0;q=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=(q&50529027)+(p&50529027)|0;r=(q>>>2&1061109567)+(p>>>2&1061109567)|0;p=b;q=c[p>>2]|0;s=r+o+((a+l|0)>>>2&252645135)|0;c[p>>2]=(s|q)-((s^q)>>>1&2139062143);q=n+j|0;s=q;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+k|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=(p&50529027)+16843009+(t&50529027)|0;u=(t>>>2&1061109567)+(p>>>2&1061109567)|0;p=b+e|0;t=c[p>>2]|0;v=u+r+((s+a|0)>>>2&252645135)|0;c[p>>2]=(v|t)-((v^t)>>>1&2139062143);t=m+2|0;if((t|0)<(f|0)){l=s;o=u;m=t;n=q;b=b+j|0}else{break}}m=n+(j+g)|0;o=m;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+(j+(g+1))|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=(l&50529027)+16843009+(g&50529027)|0;n=(g>>>2&1061109567)+(l>>>2&1061109567)|0;l=0;g=m;m=b+(j+h)|0;while(1){h=g+e|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+i|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=(q&50529027)+(b&50529027)|0;t=(q>>>2&1061109567)+(b>>>2&1061109567)|0;b=m;q=c[b>>2]|0;u=t+n+((h+o|0)>>>2&252645135)|0;c[b>>2]=(u|q)-((u^q)>>>1&2139062143);q=g+j|0;u=q;b=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=g+k|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=(b&50529027)+16843009+(s&50529027)|0;v=(s>>>2&1061109567)+(b>>>2&1061109567)|0;b=m+e|0;s=c[b>>2]|0;p=v+t+((u+h|0)>>>2&252645135)|0;c[b>>2]=(p|s)-((p^s)>>>1&2139062143);s=l+2|0;if((s|0)<(f|0)){o=u;n=v;l=s;g=q;m=m+j|0}else{break}}return}function PKa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=i;i=i+48|0;g=hJb(e<<4)|0;h=g;j=hJb(e<<3)|0;k=j;l=e<<1;m=hJb(l)|0;if((g|0)==0|(j|0)==0|(m|0)==0){n=-12;kJb(g);kJb(j);kJb(m);i=f;return n|0}o=(e|0)>0;p=(e|0)/2|0;q=(e|0)>1;r=f+32|0;s=e-1|0;t=l-1|0;u=(t|0)>(e|0);v=g;w=g+8|0;x=f|0;y=f+16|0;z=1;while(1){if(o){A=z;B=(z|0)<0|0?-1:0;C=0;do{c[h+(C<<4)+8>>2]=C;D=d+(C<<3)|0;E=c[D>>2]|0;F=wrc(E<<14|0>>>18,c[D+4>>2]<<14|E>>>18,A,B)|0;E=h+(C<<4)|0;c[E>>2]=F;c[E+4>>2]=G;C=C+1|0;}while((C|0)<(e|0))}if(q){C=p;do{C=C-1|0;B=C<<1|1;a:do{if((B|0)<(e|0)){A=C;E=B;while(1){if((E|0)<(s|0)){F=h+(E<<4)|0;D=c[F+4>>2]|0;H=E+1|0;I=h+(H<<4)|0;J=c[I+4>>2]|0;K=D>>>0>J>>>0|D>>>0==J>>>0&(c[F>>2]|0)>>>0>(c[I>>2]|0)>>>0?H:E}else{K=E}H=h+(A<<4)|0;I=H|0;F=c[I+4>>2]|0;J=h+(K<<4)|0;D=J|0;L=c[D+4>>2]|0;if(!(F>>>0>L>>>0|F>>>0==L>>>0&(c[I>>2]|0)>>>0>(c[D>>2]|0)>>>0)){break a}D=J;c[r>>2]=c[D>>2];c[r+4>>2]=c[D+4>>2];c[r+8>>2]=c[D+8>>2];c[r+12>>2]=c[D+12>>2];J=H;c[D>>2]=c[J>>2];c[D+4>>2]=c[J+4>>2];c[D+8>>2]=c[J+8>>2];c[D+12>>2]=c[J+12>>2];c[J>>2]=c[r>>2];c[J+4>>2]=c[r+4>>2];c[J+8>>2]=c[r+8>>2];c[J+12>>2]=c[r+12>>2];J=K<<1|1;if((J|0)<(e|0)){A=K;E=J}else{break}}}}while(0);}while((C|0)>0)}b:do{if(u){if(q){M=e}else{C=e;B=c[v+4>>2]|0;E=c[v>>2]|0;A=c[w>>2]|0;while(1){c[k+(A<<2)>>2]=C;c[w>>2]=C;J=wrc(E,B,-1,2147483647)|0;D=G;c[v>>2]=J;c[v+4>>2]=D;H=C+1|0;if((H|0)<(t|0)){A=C;C=H;B=D;E=J}else{break b}}}do{E=c[v>>2]|0;B=c[v+4>>2]|0;c[k+(c[w>>2]<<2)>>2]=M;c[v>>2]=-1;c[v+4>>2]=2147483647;C=0;A=1;while(1){if((A|0)<(s|0)){J=h+(A<<4)|0;D=c[J+4>>2]|0;H=A+1|0;I=h+(H<<4)|0;L=c[I+4>>2]|0;N=D>>>0>L>>>0|D>>>0==L>>>0&(c[J>>2]|0)>>>0>(c[I>>2]|0)>>>0?H:A}else{N=A}H=h+(C<<4)|0;I=H|0;J=c[I+4>>2]|0;L=h+(N<<4)|0;D=L|0;F=c[D+4>>2]|0;if(!(J>>>0>F>>>0|J>>>0==F>>>0&(c[I>>2]|0)>>>0>(c[D>>2]|0)>>>0)){break}D=L;c[x>>2]=c[D>>2];c[x+4>>2]=c[D+4>>2];c[x+8>>2]=c[D+8>>2];c[x+12>>2]=c[D+12>>2];L=H;c[D>>2]=c[L>>2];c[D+4>>2]=c[L+4>>2];c[D+8>>2]=c[L+8>>2];c[D+12>>2]=c[L+12>>2];c[L>>2]=c[x>>2];c[L+4>>2]=c[x+4>>2];c[L+8>>2]=c[x+8>>2];c[L+12>>2]=c[x+12>>2];L=N<<1|1;if((L|0)<(e|0)){C=N;A=L}else{break}}A=c[v>>2]|0;C=c[v+4>>2]|0;c[k+(c[w>>2]<<2)>>2]=M;c[w>>2]=M;L=wrc(A,C,E,B)|0;c[v>>2]=L;c[v+4>>2]=G;L=0;C=1;while(1){if((C|0)<(s|0)){A=h+(C<<4)|0;D=c[A+4>>2]|0;H=C+1|0;I=h+(H<<4)|0;F=c[I+4>>2]|0;O=D>>>0>F>>>0|D>>>0==F>>>0&(c[A>>2]|0)>>>0>(c[I>>2]|0)>>>0?H:C}else{O=C}H=h+(L<<4)|0;I=H|0;A=c[I+4>>2]|0;F=h+(O<<4)|0;D=F|0;J=c[D+4>>2]|0;if(!(A>>>0>J>>>0|A>>>0==J>>>0&(c[I>>2]|0)>>>0>(c[D>>2]|0)>>>0)){break}D=F;c[y>>2]=c[D>>2];c[y+4>>2]=c[D+4>>2];c[y+8>>2]=c[D+8>>2];c[y+12>>2]=c[D+12>>2];F=H;c[D>>2]=c[F>>2];c[D+4>>2]=c[F+4>>2];c[D+8>>2]=c[F+8>>2];c[D+12>>2]=c[F+12>>2];c[F>>2]=c[y>>2];c[F+4>>2]=c[y+4>>2];c[F+8>>2]=c[y+8>>2];c[F+12>>2]=c[y+12>>2];F=O<<1|1;if((F|0)<(e|0)){L=O;C=F}else{break}}M=M+1|0;}while((M|0)<(t|0))}}while(0);a[m+(l-2)|0]=0;C=l-3|0;if((C|0)<(e|0)){P=0}else{L=C;while(1){a[m+L|0]=(a[m+(c[k+(L<<2)>>2]|0)|0]|0)+1;C=L-1|0;if((C|0)<(e|0)){P=0;break}else{L=C}}}while(1){if((P|0)>=(e|0)){break}L=(a[m+(c[k+(P<<2)>>2]|0)|0]|0)+1&255;a[b+P|0]=L;if((L&255)>>>0>31>>>0){break}else{P=P+1|0}}if((P|0)==(e|0)){n=0;break}else{z=z<<1}}kJb(g);kJb(j);kJb(m);i=f;return n|0}function QKa(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+1800|0;l=k|0;m=k+1024|0;n=k+1536|0;o=k+1792|0;do{if((e|0)>0){p=0;q=0;r=0;do{b[g+(p<<3)>>1]=p;b[g+(p<<3)+2>>1]=-2;r=wrc(c[g+(p<<3)+4>>2]|0,0,r,q)|0;q=G;p=p+1|0;}while((p|0)<(e|0));p=0;if(!(q>>>0>p>>>0|q>>>0==p>>>0&r>>>0>2147483647>>>0)){break}KIb(a,16,2535368,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1;i=k;return t|0}}while(0);cd(g|0,e|0,8,h|0);h=e<<1;p=h-1|0;c[g+(p<<3)+4>>2]=0;if((p|0)>0){u=(j&1|0)==0;v=0;w=e;while(1){e=(c[g+((v|1)<<3)+4>>2]|0)+(c[g+(v<<3)+4>>2]|0)|0;x=v+2|0;a:do{if((w|0)>(x|0)){if(u){y=w;while(1){z=y-1|0;if(!(e>>>0<(c[g+(z<<3)+4>>2]|0)>>>0)){A=y;break a}B=g+(z<<3)|0;C=g+(y<<3)|0;D=c[B+4>>2]|0;c[C>>2]=c[B>>2];c[C+4>>2]=D;if((z|0)>(x|0)){y=z}else{A=z;break}}}else{y=w;while(1){z=y-1|0;if(e>>>0>(c[g+(z<<3)+4>>2]|0)>>>0){A=y;break a}D=g+(z<<3)|0;C=g+(y<<3)|0;B=c[D+4>>2]|0;c[C>>2]=c[D>>2];c[C+4>>2]=B;if((z|0)>(x|0)){y=z}else{A=z;break}}}}else{A=w}}while(0);b[g+(A<<3)>>1]=-1;c[g+(A<<3)+4>>2]=e;b[g+(A<<3)+2>>1]=v;if((x|0)<(p|0)){v=x;w=w+1|0}else{break}}}w=n|0;c[o>>2]=0;RKa(l|0,m|0,w,g,h-2|0,0,0,o,j>>>1&1^1);if(($2(d,f,c[o>>2]|0,m,2,2,l,4,4,w,1,1,0)|0)>=0){t=0;i=k;return t|0}KIb(a,16,2604392,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1;i=k;return t|0}function RKa(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;m=b[g+(h<<3)>>1]|0;n=m&255;o=j&65535;do{if(m<<16>>16==-1){if((l|0)==0){p=h;q=i;r=j;do{s=q<<1;r=r+1|0;t=g+(p<<3)+2|0;RKa(d,e,f,g,b[t>>1]|0,s,r,k,0);q=s|1;p=(b[t>>1]|0)+1|0;u=b[g+(p<<3)>>1]|0;}while(u<<16>>16==-1);v=q;w=r&65535;x=u&255;break}else{y=h;z=i;A=j;B=-1}while(1){if((c[g+(y<<3)+4>>2]|0)==0){C=6;break}p=z<<1;D=A+1|0;t=g+(y<<3)+2|0;RKa(d,e,f,g,b[t>>1]|0,p,D,k,l);E=p|1;p=(b[t>>1]|0)+1|0;t=b[g+(p<<3)>>1]|0;F=t&255;if(t<<16>>16==-1){y=p;z=E;A=D;B=F}else{C=7;break}}if((C|0)==6){v=z;w=A&65535;x=B;break}else if((C|0)==7){v=E;w=D&65535;x=F;break}}else{v=i;w=o;x=n}}while(0);c[d+(c[k>>2]<<2)>>2]=v;v=c[k>>2]|0;b[e+(v<<1)>>1]=w;a[f+v|0]=x;c[k>>2]=(c[k>>2]|0)+1;return}function SKa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+24|0;f=e|0;g=c[b+60>>2]|0;h=g;mrc(g+860320|0,0,80)|0;j=(c[b+124>>2]|0)>288|0;k=g+52|0;c[k>>2]=j;l=g+72|0;c[l>>2]=1;m=b+100|0;n=c[m>>2]|0;a:do{if((n|0)==0){c[g+64>>2]=0;o=0}else{p=c[b+792>>2]|0;if(!((p&7|0)==0|(p|0)==12)){c[g+64>>2]=1;o=1;break}do{if((n|0)>3){if((a[(c[b+96>>2]|0)+3|0]|0)!=0){break}c[g+64>>2]=2;o=2;break a}}while(0);c[g+64>>2]=3;o=3}}while(0);n=g+76|0;c[n>>2]=8;p=g+80|0;c[p>>2]=256;q=g+84|0;c[q>>2]=256;r=g+92|0;c[r>>2]=1;s=g+64|0;do{if(o>>>0>1>>>0){if((c[m>>2]|0)<4){t=-1;i=e;return t|0}u=c[b+96>>2]|0;v=d[u]|0;c[g+56>>2]=v>>>6&1;c[g+4>>2]=v&63;v=u+1|0;w=a[v]|0;x=w&255;do{if((o|0)==2){y=g+60|0;c[y>>2]=x;if(!(w<<24>>24==0)){break}c[y>>2]=c[b+792>>2]&-8}else{y=(x>>>4)+1|0;c[n>>2]=y;z=1<<y;c[p>>2]=z;c[q>>2]=(z|0)>16384?16384:z;c[g+100>>2]=a[v]&3;c[g+104>>2]=(d[v]|0)>>>2&3;z=u+2|0;c[g+96>>2]=a[z]&1;c[r>>2]=(a[z]&3)!=0;c[g+88>>2]=(d[z]|0)>>>2&1}}while(0);v=u+2|0;x=(d[v]|0)>>>4&3;if((x|0)==1){A=1}else{A=(x|0)==2?0:j}c[k>>2]=A;c[g+120>>2]=(d[v]|0)>>>6&1;if((VKa(h,u+4|0,(c[m>>2]|0)-4|0)|0)<0){t=-1094995529}else{break}i=e;return t|0}else{v=b+792|0;x=c[v>>2]|0;w=x&7;if((w|0)==2){c[g+4>>2]=0;c[g+56>>2]=1}else if((w|0)==4){c[g+4>>2]=2;c[g+56>>2]=0}else if((w|0)==1){c[g+4>>2]=0;c[g+56>>2]=0}else if((w|0)==3){c[g+4>>2]=1;c[g+56>>2]=(x|0)>23}else{c[g+4>>2]=0;c[g+56>>2]=0}x=g+60|0;c[x>>2]=c[v>>2]&-8;c[g+120>>2]=0;v=f|0;c[v>>2]=1703576;w=f+12|0;c[w>>2]=336;z=f+16|0;c[z>>2]=344;y=f+4|0;c[y>>2]=1703618;B=f+8|0;c[B>>2]=0;C=g+524448|0;if((_Ka(C,f,256)|0)<0){t=-1094995529;i=e;return t|0}c[v>>2]=1703640;c[w>>2]=472;c[z>>2]=480;c[y>>2]=1703699;c[B>>2]=0;B=g+540832|0;if((_Ka(B,f,256)|0)<0){t=-1094995529;i=e;return t|0}else{D=0}while(1){c[h+589984+(D<<2)>>2]=d[1703720+D|0]|0;y=D+1|0;if((y|0)<256){D=y}else{E=0;break}}do{c[h+655520+(E<<2)>>2]=d[1703976+E|0]|0;E=E+1|0;}while((E|0)<256);u=g+655520|0;if((c[x>>2]|0)>23){nrc(u|0,g+589984|0,1024)|0;nrc(B|0,C|0,256)|0}nrc(g+721056|0,u|0,1024)|0;nrc(g+557216|0,B|0,256)|0;u=0;while(1){if((u|0)>=4){break}y=h+860320+(u*20|0)|0;c3(y);if(($2(y,11,256,h+524448+(u<<14)|0,1,1,h+589984+(u<<16)|0,4,4,0,0,0,0)|0)<0){t=-1094995529;F=97;break}else{u=u+1|0}}if((F|0)==97){i=e;return t|0}if(($Ka(h)|0)<0){t=-1094995529}else{break}i=e;return t|0}}while(0);b:do{if((c[s>>2]|0)<3){F=c[g+60>>2]|0;do{if((F|0)==32){if((c[l>>2]|0)==0){KIb(0,0,2173136,(G=i,i=i+24|0,c[G>>2]=2616872,c[G+8>>2]=2121968,c[G+16>>2]=371,G)|0);i=G;Hd();return 0}else{c[b+140>>2]=30;c[g+88>>2]=1;H=30;break}}else if((F|0)==12){c[b+140>>2]=0;c[g+96>>2]=1;H=0}else if((F|0)==16){E=(c[g+68>>2]|0)==0?4:1;c[b+140>>2]=E;c[g+96>>2]=1;H=E}else if((F|0)==24){E=b+140|0;if((c[l>>2]|0)==0){c[E>>2]=3;H=3;break}else{c[E>>2]=298;H=298;break}}else{t=-1094995529;i=e;return t|0}}while(0);tKb(H,g+100|0,g+104|0)|0}else{switch(c[g+96>>2]<<9|c[r>>2]<<10|c[g+88>>2]<<8|c[g+100>>2]|(c[n>>2]<<4)-16|c[g+104>>2]<<2|0){case 1717:{c[b+140>>2]=302;break b;break};case 1749:{c[b+140>>2]=304;break b;break};case 1781:{c[b+140>>2]=54;break b;break};case 1653:{c[b+140>>2]=0;break b;break};case 1669:{c[b+140>>2]=70;break b;break};case 1685:{c[b+140>>2]=72;break b;break};case 1681:{c[b+140>>2]=74;break b;break};case 1713:{c[b+140>>2]=306;break b;break};case 1745:{c[b+140>>2]=308;break b;break};case 1392:{c[b+140>>2]=317;break b;break};case 1648:{c[b+140>>2]=5;break b;break};case 1776:{c[b+140>>2]=58;break b;break};case 1649:{c[b+140>>2]=4;break b;break};case 1665:{c[b+140>>2]=80;break b;break};case 1168:{c[b+140>>2]=86;break b;break};case 1200:{c[b+140>>2]=314;break b;break};case 1658:{c[b+140>>2]=6;break b;break};case 1904:{c[b+140>>2]=299;break b;break};case 1920:{c[b+140>>2]=96;break b;break};case 1936:{c[b+140>>2]=102;break b;break};case 368:{c[b+140>>2]=66;break b;break};case 1136:{c[b+140>>2]=82;break b;break};case 112:{c[b+140>>2]=8;break b;break};case 240:{c[b+140>>2]=32;break b;break};case 1937:{c[b+140>>2]=100;break b;break};case 2033:{c[b+140>>2]=106;break b;break};case 1909:{c[b+140>>2]=35;break b;break};case 1925:{c[b+140>>2]=92;break b;break};case 1232:{c[b+140>>2]=316;break b;break};case 1264:{c[b+140>>2]=88;break b;break};case 1664:{c[b+140>>2]=76;break b;break};case 1680:{c[b+140>>2]=78;break b;break};case 1152:{c[b+140>>2]=84;break b;break};case 2032:{c[b+140>>2]=108;break b;break};case 1905:{c[b+140>>2]=300;break b;break};case 1921:{c[b+140>>2]=94;break b;break};case 1941:{c[b+140>>2]=98;break b;break};case 2037:{c[b+140>>2]=104;break b;break};case 1777:{c[b+140>>2]=56;break b;break};case 1650:{c[b+140>>2]=7;break b;break};case 1652:{c[b+140>>2]=33;break b;break};case 1712:{c[b+140>>2]=310;break b;break};case 1744:{c[b+140>>2]=312;break b;break};default:{t=-1094995529;i=e;return t|0}}}}while(0);Ypb(b);n=c[b+140>>2]|0;do{if((n|0)==4|(n|0)==0){if((c[b+120>>2]&1|0)==0){break}KIb(b,16,2589688,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;t=-1094995529;i=e;return t|0}}while(0);do{if((c[g+4>>2]|0)==2&(n|0)==4){if((c[b+120>>2]&3|0)==0){break}KIb(b,16,2567992,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;t=-1094995529;i=e;return t|0}}while(0);if((Xpb(h)|0)==0){t=0;i=e;return t|0}Zpb(h);t=-12;i=e;return t|0}function TKa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;h=i;i=i+144|0;j=h|0;k=h+32|0;l=h+48|0;m=h+56|0;n=h+64|0;o=h+72|0;p=h+80|0;q=h+88|0;r=h+96|0;s=h+104|0;t=h+112|0;u=h+120|0;v=h+128|0;w=h+136|0;x=c[g+24>>2]|0;y=c[g+28>>2]|0;g=c[b+60>>2]|0;z=g;A=c[g+108>>2]|0;B=A>>1;C=g+112|0;D=c[C>>2]|0;E=e;c[k>>2]=E;c[k+4>>2]=0;c[k+8>>2]=0;F=g+860480|0;G=F;A4a(F,g+860484|0,y);F=c[G>>2]|0;if((F|0)==0){H=-12;i=h;return H|0}ef[c[g+861584>>2]&4095](F,x,(y|0)/4|0);x=J5a(b,k,0)|0;if((x|0)<0){H=x;i=h;return H|0}do{if((c[g+120>>2]|0)==0){I=0}else{x=VKa(z,c[G>>2]|0,y)|0;if((x|0)<0){H=-1094995529}else{I=x;break}i=h;return H|0}}while(0);x=y-I|0;if(x>>>0>268435454>>>0){H=-1094995529;i=h;return H|0}y=(c[G>>2]|0)+I|0;G=x<<3;x=G>>>0>2147483639>>>0|(y|0)==0;k=x?0:y;y=x?0:G;G=g+8|0;c[G>>2]=k;c[g+20>>2]=y;x=y+8|0;F=g+24|0;c[F>>2]=x;c[g+12>>2]=k+(y>>3);y=g+16|0;c[y>>2]=0;J=g+52|0;K=e+32|0;L=K;M=K;K=(c[J>>2]|0)!=0|0;N=c[M>>2]<<K;O=e+36|0;P=c[O>>2]<<K;Q=e+40|0;R=c[Q>>2]<<K;K=g+128|0;c[K>>2]=0;do{if((c[g+64>>2]|0)>2){S=g+92|0;T=c[S>>2]|0;U=g+88|0;if(((T<<1|1)+(c[U>>2]|0)|0)>0){V=g+4|0;W=e;X=g+132|0;Y=g+76|0;Z=g+861576|0;_=g+861560|0;$=g+861732|0;aa=g+80|0;ba=g+861748|0;da=g+861572|0;ea=g+861744|0;fa=g+100|0;ga=g+104|0;ha=0;ia=T;do{do{if((ia|0)==0){ja=A;ka=D;la=N}else{if(!((ha-1|0)>>>0<2>>>0)){ja=A;ka=D;la=N;break}ja=A>>c[fa>>2];ka=D>>c[ga>>2];la=(ha|0)==1?P:R}}while(0);T=c[V>>2]|0;do{if((T|0)==2){WKa(z,ja,ha);ma=W+(ha<<2)|0;na=c[ma>>2]|0;oa=c[X>>2]|0;if((c[Y>>2]|0)<9){pa=hf[c[Z>>2]&1023](na,oa,ja,0)|0}else{pa=Xe[c[ba>>2]&511](na,oa,(c[aa>>2]|0)-1|0,ja,0)|0}c[l>>2]=pa;if((c[J>>2]|0)==0){qa=2}else{WKa(z,ja,ha);oa=(c[ma>>2]|0)+(c[L+(ha<<2)>>2]|0)|0;na=c[X>>2]|0;ra=c[l>>2]|0;if((c[Y>>2]|0)<9){sa=hf[c[Z>>2]&1023](oa,na,ja,ra)|0}else{sa=Xe[c[ba>>2]&511](oa,na,(c[aa>>2]|0)-1|0,ja,ra)|0}c[l>>2]=sa;qa=3}c[m>>2]=d[c[ma>>2]|0]|0;WKa(z,ja,ha);ra=c[ma>>2]|0;na=ra+la|0;oa=c[X>>2]|0;if((c[Y>>2]|0)<9){_e[c[da>>2]&511](na,ra,oa,ja,l,m)}else{Se[c[ea>>2]&1023](na,ra,oa,(c[aa>>2]|0)-1|0,ja,l,m)}if((qa|0)>=(ka|0)){break}oa=L+(ha<<2)|0;ra=qa;do{WKa(z,ja,ha);na=c[ma>>2]|0;ta=ca(c[oa>>2]|0,ra)|0;ua=na+ta|0;va=na+(ta-la)|0;ta=c[X>>2]|0;if((c[Y>>2]|0)<9){_e[c[da>>2]&511](ua,va,ta,ja,l,m)}else{Se[c[ea>>2]&1023](ua,va,ta,(c[aa>>2]|0)-1|0,ja,l,m)}ra=ra+1|0;}while((ra|0)<(ka|0))}else if((T|0)==0|(T|0)==1){WKa(z,ja,ha);ra=W+(ha<<2)|0;oa=c[ra>>2]|0;ma=c[X>>2]|0;if((c[Y>>2]|0)<9){wa=hf[c[Z>>2]&1023](oa,ma,ja,0)|0}else{wa=Xe[c[ba>>2]&511](oa,ma,(c[aa>>2]|0)-1|0,ja,0)|0}c[l>>2]=wa;if((ka|0)<=1){break}ma=L+(ha<<2)|0;oa=1;do{ta=c[ra>>2]|0;va=ca(c[ma>>2]|0,oa)|0;ua=ta+va|0;WKa(z,ja,ha);na=c[X>>2]|0;xa=c[l>>2]|0;if((c[Y>>2]|0)<9){ya=hf[c[Z>>2]&1023](ua,na,ja,xa)|0}else{ya=Xe[c[ba>>2]&511](ua,na,(c[aa>>2]|0)-1|0,ja,xa)|0}c[l>>2]=ya;do{if((c[V>>2]|0)==1){if((oa|0)<=(c[J>>2]|0)){break}xa=ta+(va-la)|0;if((c[Y>>2]|0)<9){ef[c[_>>2]&4095](ua,xa,ja);break}else{mf[c[$>>2]&2047](ua,xa,(c[aa>>2]|0)-1|0,ja);break}}}while(0);oa=oa+1|0;}while((oa|0)<(ka|0))}}while(0);ha=ha+1|0;ia=c[S>>2]|0;}while((ha|0)<((ia<<1|1)+(c[U>>2]|0)|0))}U=c[g>>2]|0;ia=U+148|0;if((c[ia>>2]|0)==0){break}ha=c[K>>2]|0;S=ha>>((c[g+60>>2]|0)==12);aa=j|0;c[aa>>2]=ca(c[M>>2]|0,ha)|0;c[j+4>>2]=ca(S,c[O>>2]|0)|0;c[j+8>>2]=ca(c[Q>>2]|0,S)|0;mrc(j+12|0,0,20)|0;_e[c[ia>>2]&511](U,E,aa,ha,3,D-ha|0);c[K>>2]=D}else{ha=g+60|0;aa=c[ha>>2]|0;if((aa|0)>=24){U=ca(c[M>>2]|0,D-1|0)|0;ia=k;S=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;ia=S&255;c[y>>2]=x>>>0>8>>>0?8:x;$=S&255;if((aa|0)==32){aa=e;a[(c[aa>>2]|0)+(U+3)|0]=$;c[w>>2]=ia;S=c[y>>2]|0;_=c[F>>2]|0;Y=(c[G>>2]|0)+(S>>>3)|0;V=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(S&7)>>>24;Y=S+8|0;c[y>>2]=_>>>0>Y>>>0?Y:_;a[(c[aa>>2]|0)+(U+2)|0]=V;c[t>>2]=V;V=c[y>>2]|0;_=c[F>>2]|0;Y=(c[G>>2]|0)+(V>>>3)|0;S=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(V&7)>>>24;Y=V+8|0;c[y>>2]=_>>>0>Y>>>0?Y:_;a[(c[aa>>2]|0)+(U+1)|0]=S;c[u>>2]=S;S=c[y>>2]|0;_=c[F>>2]|0;Y=(c[G>>2]|0)+(S>>>3)|0;V=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(S&7)>>>24;Y=S+8|0;c[y>>2]=_>>>0>Y>>>0?Y:_;a[(c[aa>>2]|0)+U|0]=V;c[v>>2]=V}else{V=e;a[(c[V>>2]|0)+(U+2)|0]=$;c[t>>2]=ia;ia=c[y>>2]|0;$=c[F>>2]|0;aa=(c[G>>2]|0)+(ia>>>3)|0;_=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ia&7)>>>24;aa=ia+8|0;c[y>>2]=$>>>0>aa>>>0?aa:$;a[(c[V>>2]|0)+(U+1)|0]=_;c[u>>2]=_;_=c[y>>2]|0;$=c[F>>2]|0;aa=(c[G>>2]|0)+(_>>>3)|0;ia=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7)>>>24;aa=_+8|0;c[y>>2]=$>>>0>aa>>>0?aa:$;a[(c[V>>2]|0)+U|0]=ia;c[v>>2]=ia;a[(c[V>>2]|0)+(U+3)|0]=-1;c[w>>2]=255;V=c[F>>2]|0;ia=(c[y>>2]|0)+8|0;c[y>>2]=V>>>0>ia>>>0?ia:V}if((c[g+72>>2]|0)==0){KIb(b,16,2205312,(za=i,i=i+1|0,i=i+7&-8,c[za>>2]=0,za)|0);i=za;H=-1163346256;i=h;return H|0}V=g+4|0;if(!((c[V>>2]|0)>>>0<2>>>0)){KIb(b,16,2247288,(za=i,i=i+1|0,i=i+7&-8,c[za>>2]=0,za)|0);i=za;break}ia=A-1|0;ZKa(z,ia);$=g+861580|0;aa=e;_=g+132|0;Se[c[$>>2]&1023]((c[aa>>2]|0)+(U+4)|0,c[_>>2]|0,ia,t,u,v,w);ia=(c[C>>2]|0)-2|0;if((ia|0)>-1){U=g+861560|0;Y=ia;while(1){ZKa(z,A);ia=(c[aa>>2]|0)+(ca(c[M>>2]|0,Y)|0)|0;Se[c[$>>2]&1023](ia,c[_>>2]|0,A,t,u,v,w);do{if((c[V>>2]|0)==1){if((c[ha>>2]|0)!=32){c[w>>2]=0}ia=c[J>>2]|0;if((ia&Y|0)!=0){break}if((Y|0)>=((c[C>>2]|0)+~ia|0)){break}ia=c[aa>>2]|0;S=ca(c[M>>2]|0,Y)|0;ef[c[U>>2]&4095](ia+S|0,ia+(S+N)|0,N)}}while(0);if((Y|0)>0){Y=Y-1|0}else{break}}}Y=c[g>>2]|0;U=Y+148|0;if((c[U>>2]|0)==0){break}aa=c[K>>2]|0;V=aa>>((c[ha>>2]|0)==12);_=j|0;c[_>>2]=ca(c[M>>2]|0,aa)|0;c[j+4>>2]=ca(V,c[O>>2]|0)|0;c[j+8>>2]=ca(c[Q>>2]|0,V)|0;mrc(j+12|0,0,20)|0;_e[c[U>>2]&511](Y,E,_,aa,3,D-aa|0);c[K>>2]=D;break}aa=(c[g+68>>2]|0)==0;_=k;Y=d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0;c[y>>2]=x>>>0>8>>>0?8:x;_=Y&255;if(!aa){aa=e;a[(c[aa>>2]|0)+3|0]=_;U=c[y>>2]|0;V=c[F>>2]|0;$=(c[G>>2]|0)+(U>>>3)|0;S=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(U&7)>>>24;$=U+8|0;c[y>>2]=V>>>0>$>>>0?$:V;a[(c[aa>>2]|0)+2|0]=S;S=c[y>>2]|0;V=c[F>>2]|0;$=(c[G>>2]|0)+(S>>>3)|0;U=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(S&7)>>>24;$=S+8|0;c[y>>2]=V>>>0>$>>>0?$:V;a[(c[aa>>2]|0)+1|0]=U;U=c[y>>2]|0;V=c[F>>2]|0;$=(c[G>>2]|0)+(U>>>3)|0;S=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(U&7)>>>24;$=U+8|0;c[y>>2]=V>>>0>$>>>0?$:V;a[c[aa>>2]|0]=S;KIb(b,16,2297912,(za=i,i=i+1|0,i=i+7&-8,c[za>>2]=0,za)|0);i=za;H=-1163346256;i=h;return H|0}S=e+8|0;a[c[S>>2]|0]=_;c[p>>2]=Y&255;Y=c[y>>2]|0;_=c[F>>2]|0;aa=(c[G>>2]|0)+(Y>>>3)|0;V=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(Y&7)>>>24;aa=Y+8|0;c[y>>2]=_>>>0>aa>>>0?aa:_;_=e;a[(c[_>>2]|0)+1|0]=V;c[n>>2]=V;V=c[y>>2]|0;aa=c[F>>2]|0;Y=(c[G>>2]|0)+(V>>>3)|0;$=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(V&7)>>>24;Y=V+8|0;c[y>>2]=aa>>>0>Y>>>0?Y:aa;aa=e+4|0;a[c[aa>>2]|0]=$;c[o>>2]=$;$=c[y>>2]|0;Y=c[F>>2]|0;V=(c[G>>2]|0)+($>>>3)|0;U=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<($&7)>>>24;V=$+8|0;c[y>>2]=Y>>>0>V>>>0?V:Y;a[c[_>>2]|0]=U;U=g+4|0;Y=c[U>>2]|0;if((Y|0)==0|(Y|0)==1){V=A-2|0;XKa(z,V);$=g+861576|0;ia=g+132|0;c[n>>2]=hf[c[$>>2]&1023]((c[_>>2]|0)+2|0,c[ia>>2]|0,V,c[n>>2]|0)|0;V=g+116|0;if((c[V>>2]&8192|0)==0){ba=B-1|0;c[o>>2]=hf[c[$>>2]&1023]((c[aa>>2]|0)+1|0,c[g+136>>2]|0,ba,c[o>>2]|0)|0;c[p>>2]=hf[c[$>>2]&1023]((c[S>>2]|0)+1|0,c[g+140>>2]|0,ba,c[p>>2]|0)|0}a:do{if((c[C>>2]|0)>1){ba=g+861560|0;Z=j;X=g;W=g+136|0;ea=g+140|0;da=j|0;ga=j+4|0;fa=j+8|0;T=j+12|0;oa=1;ma=1;while(1){if((c[ha>>2]|0)==12){YKa(z,A);ra=c[_>>2]|0;ua=ca(c[M>>2]|0,oa)|0;va=ra+ua|0;c[n>>2]=hf[c[$>>2]&1023](va,c[ia>>2]|0,A,c[n>>2]|0)|0;do{if((c[U>>2]|0)==1){if((oa|0)<=(c[J>>2]|0)){break}ef[c[ba>>2]&4095](va,ra+(ua-N)|0,A)}}while(0);ua=oa+1|0;if((ua|0)<(c[C>>2]|0)){Aa=ua}else{Ba=Z;Ca=X;break a}}else{Aa=oa}ua=c[X>>2]|0;ra=ua+148|0;if((c[ra>>2]|0)!=0){va=c[K>>2]|0;ta=va>>((c[ha>>2]|0)==12);c[da>>2]=ca(c[M>>2]|0,va)|0;c[ga>>2]=ca(ta,c[O>>2]|0)|0;c[fa>>2]=ca(c[Q>>2]|0,ta)|0;mrc(T|0,0,20)|0;_e[c[ra>>2]&511](ua,E,da,va,3,Aa-va|0);c[K>>2]=Aa}va=c[_>>2]|0;ua=ca(c[M>>2]|0,Aa)|0;ra=va+ua|0;ta=c[aa>>2]|0;xa=ca(c[O>>2]|0,ma)|0;na=ta+xa|0;Da=c[S>>2]|0;Ea=ca(c[Q>>2]|0,ma)|0;Fa=Da+Ea|0;XKa(z,A);c[n>>2]=hf[c[$>>2]&1023](ra,c[ia>>2]|0,A,c[n>>2]|0)|0;if((c[V>>2]&8192|0)==0){c[o>>2]=hf[c[$>>2]&1023](na,c[W>>2]|0,B,c[o>>2]|0)|0;c[p>>2]=hf[c[$>>2]&1023](Fa,c[ea>>2]|0,B,c[p>>2]|0)|0}do{if((c[U>>2]|0)==1){if((ma|0)<=(c[J>>2]|0)){break}ef[c[ba>>2]&4095](ra,va+(ua-N)|0,A);if((c[V>>2]&8192|0)!=0){break}ef[c[ba>>2]&4095](na,ta+(xa-P)|0,B);ef[c[ba>>2]&4095](Fa,Da+(Ea-R)|0,B)}}while(0);Ea=Aa+1|0;if((Ea|0)<(c[C>>2]|0)){oa=Ea;ma=ma+1|0}else{Ba=Z;Ca=X;break}}}else{Ba=j;Ca=g}}while(0);V=c[Ca>>2]|0;U=V+148|0;if((c[U>>2]|0)==0){break}$=c[K>>2]|0;ia=$>>((c[ha>>2]|0)==12);X=j|0;c[X>>2]=ca(c[M>>2]|0,$)|0;c[j+4>>2]=ca(ia,c[O>>2]|0)|0;c[j+8>>2]=ca(c[Q>>2]|0,ia)|0;mrc(j+12|0,0,20)|0;_e[c[U>>2]&511](V,E,X,$,3,D-$|0);c[K>>2]=D;break}else if((Y|0)!=2){break}$=A-2|0;XKa(z,$);X=g+861576|0;V=g+132|0;c[n>>2]=hf[c[X>>2]&1023]((c[_>>2]|0)+2|0,c[V>>2]|0,$,c[n>>2]|0)|0;$=g+116|0;if((c[$>>2]&8192|0)==0){U=B-1|0;c[o>>2]=hf[c[X>>2]&1023]((c[aa>>2]|0)+1|0,c[g+136>>2]|0,U,c[o>>2]|0)|0;c[p>>2]=hf[c[X>>2]&1023]((c[S>>2]|0)+1|0,c[g+140>>2]|0,U,c[p>>2]|0)|0}do{if((c[J>>2]|0)==0){Ga=2}else{XKa(z,A);c[n>>2]=hf[c[X>>2]&1023]((c[_>>2]|0)+(c[M>>2]|0)|0,c[V>>2]|0,A,c[n>>2]|0)|0;if((c[$>>2]&8192|0)!=0){Ga=3;break}c[o>>2]=hf[c[X>>2]&1023]((c[aa>>2]|0)+(c[Q>>2]|0)|0,c[g+136>>2]|0,B,c[o>>2]|0)|0;c[p>>2]=hf[c[X>>2]&1023]((c[S>>2]|0)+(c[O>>2]|0)|0,c[g+140>>2]|0,B,c[p>>2]|0)|0;Ga=3}}while(0);XKa(z,4);c[n>>2]=hf[c[X>>2]&1023]((c[_>>2]|0)+N|0,c[V>>2]|0,4,c[n>>2]|0)|0;if((c[$>>2]&8192|0)==0){c[o>>2]=hf[c[X>>2]&1023]((c[aa>>2]|0)+P|0,c[g+136>>2]|0,2,c[o>>2]|0)|0;c[p>>2]=hf[c[X>>2]&1023]((c[S>>2]|0)+R|0,c[g+140>>2]|0,2,c[p>>2]|0)|0}c[q>>2]=d[(c[_>>2]|0)+3|0]|0;Y=A-4|0;XKa(z,Y);U=g+861572|0;ia=c[_>>2]|0;_e[c[U>>2]&511](ia+(N+4)|0,ia+4|0,c[V>>2]|0,Y,n,q);if((c[$>>2]&8192|0)==0){Y=c[aa>>2]|0;c[r>>2]=d[Y+1|0]|0;c[s>>2]=d[(c[S>>2]|0)+1|0]|0;ia=B-2|0;_e[c[U>>2]&511](Y+(P+2)|0,Y+2|0,c[g+136>>2]|0,ia,o,r);Y=c[S>>2]|0;_e[c[U>>2]&511](Y+(R+2)|0,Y+2|0,c[g+140>>2]|0,ia,p,s)}ia=g;b:do{if((Ga|0)<(D|0)){Y=g+136|0;Z=g+140|0;ma=j|0;oa=j+4|0;ba=j+8|0;ea=j+12|0;W=Ga;da=Ga;T=Ga<<1;while(1){if((c[ha>>2]|0)==12){fa=da<<1;if((fa|0)>(W|0)){ga=W;while(1){YKa(z,A);Ea=c[_>>2]|0;Da=ca(c[M>>2]|0,ga)|0;_e[c[U>>2]&511](Ea+Da|0,Ea+(Da-N)|0,c[V>>2]|0,A,n,q);Da=ga+1|0;if((fa|0)>(Da|0)){ga=Da}else{Ha=T;break}}}else{Ha=W}if((Ha|0)<(D|0)){Ia=Ha}else{break b}}else{Ia=W}ga=c[ia>>2]|0;fa=ga+148|0;if((c[fa>>2]|0)!=0){Da=c[K>>2]|0;Ea=Da>>((c[ha>>2]|0)==12);c[ma>>2]=ca(c[M>>2]|0,Da)|0;c[oa>>2]=ca(Ea,c[O>>2]|0)|0;c[ba>>2]=ca(c[Q>>2]|0,Ea)|0;mrc(ea|0,0,20)|0;_e[c[fa>>2]&511](ga,E,ma,Da,3,Ia-Da|0);c[K>>2]=Ia}XKa(z,A);Da=c[_>>2]|0;ga=ca(c[M>>2]|0,Ia)|0;fa=c[aa>>2]|0;Ea=ca(c[O>>2]|0,da)|0;Fa=c[S>>2]|0;xa=ca(c[Q>>2]|0,da)|0;_e[c[U>>2]&511](Da+ga|0,Da+(ga-N)|0,c[V>>2]|0,A,n,q);if((c[$>>2]&8192|0)==0){_e[c[U>>2]&511](fa+Ea|0,fa+(Ea-P)|0,c[Y>>2]|0,B,o,r);_e[c[U>>2]&511](Fa+xa|0,Fa+(xa-R)|0,c[Z>>2]|0,B,p,s)}xa=Ia+1|0;if((xa|0)<(D|0)){W=xa;da=da+1|0;T=T+2|0}else{break}}}}while(0);U=c[ia>>2]|0;$=U+148|0;if((c[$>>2]|0)==0){break}V=c[K>>2]|0;S=V>>((c[ha>>2]|0)==12);aa=j|0;c[aa>>2]=ca(c[M>>2]|0,V)|0;c[j+4>>2]=ca(S,c[O>>2]|0)|0;c[j+8>>2]=ca(c[Q>>2]|0,S)|0;mrc(j+12|0,0,20)|0;_e[c[$>>2]&511](U,E,aa,V,3,D-V|0);c[K>>2]=D}}while(0);c[f>>2]=1;H=((((c[y>>2]|0)+31|0)/32|0)<<2)+I|0;i=h;return H|0}function UKa(a){a=a|0;var b=0;b=c[a+60>>2]|0;Zpb(b);mJb(b+860480|0);c3(b+860320|0);c3(b+860340|0);c3(b+860360|0);c3(b+860380|0);c3(b+860400|0);c3(b+860420|0);c3(b+860440|0);c3(b+860460|0);return 0}function VKa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+24|0;f=e|0;g=d<<3;d=g>>>0>2147483639>>>0|(b|0)==0;h=d?0:b;b=d?0:g;c[f>>2]=h;c[f+12>>2]=b;c[f+16>>2]=b+8;c[f+4>>2]=h+(b>>3);b=f+8|0;c[b>>2]=0;if((c[a+64>>2]|0)>2){j=(c[a+88>>2]|0)+1+(c[a+92>>2]<<1)|0}else{j=3}h=a+84|0;g=0;while(1){if((g|0)>=(j|0)){k=8;break}d=a+524448+(g<<14)|0;if((_Ka(d,f,c[h>>2]|0)|0)<0){l=-1;k=10;break}m=a+589984+(g<<16)|0;if((Wpb(m,d,c[h>>2]|0)|0)<0){l=-1;k=10;break}n=a+860320+(g*20|0)|0;c3(n);o=$2(n,11,c[h>>2]|0,d,1,1,m,4,4,0,0,0,0)|0;if((o|0)<0){l=o;k=10;break}else{g=g+1|0}}if((k|0)==8){g=$Ka(a)|0;if((g|0)<0){l=g;i=e;return l|0}l=((c[b>>2]|0)+7|0)/8|0;i=e;return l|0}else if((k|0)==10){i=e;return l|0}return 0}function WKa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;h=(f|0)/2|0;i=c[e+76>>2]|0;if((i|0)<9){j=e+8|0;k=e+16|0;l=c[k>>2]|0;m=e+20|0;n=c[m>>2]|0;o=(f|0)>1;if((h|0)<((n-l|0)/62|0|0)){if(!o){return}p=e+860320+((g+4|0)*20|0)+4|0;q=e+24|0;r=j|0;s=e+860320+(g*20|0)+4|0;t=e+132|0;u=0;v=l;while(1){w=c[p>>2]|0;x=c[q>>2]|0;y=c[r>>2]|0;z=y+(v>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(v&7)>>>21;z=b[w+(A<<2)>>1]|0;B=z<<16>>16;C=(b[w+(A<<2)+2>>1]|0)+v|0;A=x>>>0>C>>>0?C:x;c[k>>2]=A;if((B&65535|0)==65535){C=c[s>>2]|0;w=y+(A>>>3)|0;D=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(A&7)>>>21;w=b[C+(D<<2)>>1]|0;E=b[C+(D<<2)+2>>1]|0;D=E<<16>>16;F=w&255;do{if(E<<16>>16<0){G=A+11|0;H=x>>>0>G>>>0?G:x;G=y+(H>>>3)|0;I=((je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>((D+32|0)>>>0))+(w<<16>>16)|0;G=b[C+(I<<2)>>1]|0;J=b[C+(I<<2)+2>>1]|0;I=J<<16>>16;if(!(J<<16>>16<0)){K=I;L=G&255;M=H;break}J=H-D|0;H=x>>>0>J>>>0?J:x;J=y+(H>>>3)|0;N=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>((I+32|0)>>>0))+(G<<16>>16)|0;K=b[C+(N<<2)+2>>1]|0;L=b[C+(N<<2)>>1]&255;M=H}else{K=D;L=F;M=A}}while(0);A=K+M|0;c[k>>2]=x>>>0>A>>>0?A:x;A=u<<1;a[(c[t>>2]|0)+A|0]=L;F=c[s>>2]|0;D=c[k>>2]|0;C=c[q>>2]|0;y=c[r>>2]|0;w=y+(D>>>3)|0;E=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(D&7)>>>21;w=b[F+(E<<2)>>1]|0;H=b[F+(E<<2)+2>>1]|0;E=H<<16>>16;N=w&255;do{if(H<<16>>16<0){G=D+11|0;I=C>>>0>G>>>0?G:C;G=y+(I>>>3)|0;J=((je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(I&7)>>>((E+32|0)>>>0))+(w<<16>>16)|0;G=b[F+(J<<2)>>1]|0;O=b[F+(J<<2)+2>>1]|0;J=O<<16>>16;if(!(O<<16>>16<0)){P=J;Q=G&255;R=I;break}O=I-E|0;I=C>>>0>O>>>0?O:C;O=y+(I>>>3)|0;S=((je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(I&7)>>>((J+32|0)>>>0))+(G<<16>>16)|0;P=b[F+(S<<2)+2>>1]|0;Q=b[F+(S<<2)>>1]&255;R=I}else{P=E;Q=N;R=D}}while(0);D=P+R|0;c[k>>2]=C>>>0>D>>>0?D:C;a[(c[t>>2]|0)+(A|1)|0]=Q}else{D=u<<1;a[(c[t>>2]|0)+D|0]=B>>>8;a[(c[t>>2]|0)+(D|1)|0]=z}D=u+1|0;if((D|0)>=(h|0)){break}u=D;v=c[k>>2]|0}return}if(!o){return}o=e+860320+((g+4|0)*20|0)+4|0;v=e+24|0;u=j|0;j=e+860320+(g*20|0)+4|0;t=e+132|0;Q=0;R=l;l=n;while(1){if((l-R|0)<=0){T=77;break}n=c[o>>2]|0;P=c[v>>2]|0;r=c[u>>2]|0;q=r+(R>>>3)|0;s=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(R&7)>>>21;q=b[n+(s<<2)>>1]|0;L=q<<16>>16;M=(b[n+(s<<2)+2>>1]|0)+R|0;s=P>>>0>M>>>0?M:P;c[k>>2]=s;if((L&65535|0)==65535){M=c[j>>2]|0;n=r+(s>>>3)|0;K=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(s&7)>>>21;n=b[M+(K<<2)>>1]|0;p=b[M+(K<<2)+2>>1]|0;K=p<<16>>16;D=n&255;do{if(p<<16>>16<0){N=s+11|0;E=P>>>0>N>>>0?N:P;N=r+(E>>>3)|0;F=((je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(E&7)>>>((K+32|0)>>>0))+(n<<16>>16)|0;N=b[M+(F<<2)>>1]|0;y=b[M+(F<<2)+2>>1]|0;F=y<<16>>16;if(!(y<<16>>16<0)){U=F;V=N&255;W=E;break}y=E-K|0;E=P>>>0>y>>>0?y:P;y=r+(E>>>3)|0;w=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(E&7)>>>((F+32|0)>>>0))+(N<<16>>16)|0;U=b[M+(w<<2)+2>>1]|0;V=b[M+(w<<2)>>1]&255;W=E}else{U=K;V=D;W=s}}while(0);s=U+W|0;c[k>>2]=P>>>0>s>>>0?s:P;s=Q<<1;a[(c[t>>2]|0)+s|0]=V;D=c[j>>2]|0;K=c[k>>2]|0;M=c[v>>2]|0;r=c[u>>2]|0;n=r+(K>>>3)|0;p=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(K&7)>>>21;n=b[D+(p<<2)>>1]|0;z=b[D+(p<<2)+2>>1]|0;p=z<<16>>16;B=n&255;do{if(z<<16>>16<0){A=K+11|0;C=M>>>0>A>>>0?A:M;A=r+(C>>>3)|0;E=((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(C&7)>>>((p+32|0)>>>0))+(n<<16>>16)|0;A=b[D+(E<<2)>>1]|0;w=b[D+(E<<2)+2>>1]|0;E=w<<16>>16;if(!(w<<16>>16<0)){X=E;Y=A&255;Z=C;break}w=C-p|0;C=M>>>0>w>>>0?w:M;w=r+(C>>>3)|0;N=((je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(C&7)>>>((E+32|0)>>>0))+(A<<16>>16)|0;X=b[D+(N<<2)+2>>1]|0;Y=b[D+(N<<2)>>1]&255;Z=C}else{X=p;Y=B;Z=K}}while(0);K=X+Z|0;c[k>>2]=M>>>0>K>>>0?K:M;a[(c[t>>2]|0)+(s|1)|0]=Y}else{K=Q<<1;a[(c[t>>2]|0)+K|0]=L>>>8;a[(c[t>>2]|0)+(K|1)|0]=q}K=Q+1|0;if((K|0)>=(h|0)){T=77;break}Q=K;R=c[k>>2]|0;l=c[m>>2]|0}if((T|0)==77){return}}m=e+8|0;l=e+16|0;k=c[l>>2]|0;R=c[e+20>>2]|0;Q=(h|0)>=((R-k|0)/62|0|0);t=(f|0)>1;if((i|0)>=15){if(!Q){if(!t){return}i=e+860320+(g*20|0)+4|0;f=e+144|0;Y=c[e+24>>2]|0;Z=c[m>>2]|0;X=0;u=k;do{v=c[i>>2]|0;j=Z+(u>>>3)|0;V=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(u&7)>>>21;j=b[v+(V<<2)>>1]|0;W=b[v+(V<<2)+2>>1]|0;V=W<<16>>16;do{if(W<<16>>16<0){U=u+11|0;o=Y>>>0>U>>>0?U:Y;U=Z+(o>>>3)|0;K=((je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(o&7)>>>((V+32|0)>>>0))+(j<<16>>16)|0;U=b[v+(K<<2)>>1]|0;B=b[v+(K<<2)+2>>1]|0;K=B<<16>>16;if(!(B<<16>>16<0)){_=K;$=U;aa=o;break}B=o-V|0;o=Y>>>0>B>>>0?B:Y;B=Z+(o>>>3)|0;p=((je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(o&7)>>>((K+32|0)>>>0))+(U<<16>>16)|0;_=b[v+(p<<2)+2>>1]|0;$=b[v+(p<<2)>>1]|0;aa=o}else{_=V;$=j;aa=u}}while(0);j=_+aa|0;V=Y>>>0>j>>>0?j:Y;c[l>>2]=V;j=$<<2;v=X<<1;W=c[f>>2]|0;q=W+(v<<1)|0;b[q>>1]=j;L=Z+(V>>>3)|0;s=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(V&7)>>>30;L=V+2|0;V=Y>>>0>L>>>0?L:Y;c[l>>2]=V;b[q>>1]=j&65535|s;s=c[i>>2]|0;j=Z+(V>>>3)|0;q=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(V&7)>>>21;j=b[s+(q<<2)>>1]|0;L=b[s+(q<<2)+2>>1]|0;q=L<<16>>16;do{if(L<<16>>16<0){M=V+11|0;o=Y>>>0>M>>>0?M:Y;M=Z+(o>>>3)|0;p=((je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(o&7)>>>((q+32|0)>>>0))+(j<<16>>16)|0;M=b[s+(p<<2)>>1]|0;U=b[s+(p<<2)+2>>1]|0;p=U<<16>>16;if(!(U<<16>>16<0)){ba=p;ca=M;da=o;break}U=o-q|0;o=Y>>>0>U>>>0?U:Y;U=Z+(o>>>3)|0;K=((je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(o&7)>>>((p+32|0)>>>0))+(M<<16>>16)|0;ba=b[s+(K<<2)+2>>1]|0;ca=b[s+(K<<2)>>1]|0;da=o}else{ba=q;ca=j;da=V}}while(0);V=ba+da|0;j=Y>>>0>V>>>0?V:Y;c[l>>2]=j;V=ca<<2;q=W+((v|1)<<1)|0;b[q>>1]=V;s=Z+(j>>>3)|0;L=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(j&7)>>>30;s=j+2|0;u=Y>>>0>s>>>0?s:Y;c[l>>2]=u;b[q>>1]=V&65535|L;X=X+1|0;}while((X|0)<(h|0));return}if(!t){return}X=e+860320+(g*20|0)+4|0;u=e+24|0;Y=m|0;Z=e+144|0;ca=0;da=k;while(1){if((R-da|0)<=0){T=77;break}ba=c[X>>2]|0;i=c[u>>2]|0;f=c[Y>>2]|0;$=f+(da>>>3)|0;aa=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(da&7)>>>21;$=b[ba+(aa<<2)>>1]|0;_=b[ba+(aa<<2)+2>>1]|0;aa=_<<16>>16;do{if(_<<16>>16<0){L=da+11|0;V=i>>>0>L>>>0?L:i;L=f+(V>>>3)|0;q=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(V&7)>>>((aa+32|0)>>>0))+($<<16>>16)|0;L=b[ba+(q<<2)>>1]|0;s=b[ba+(q<<2)+2>>1]|0;q=s<<16>>16;if(!(s<<16>>16<0)){ea=q;fa=L;ga=V;break}s=V-aa|0;V=i>>>0>s>>>0?s:i;s=f+(V>>>3)|0;j=((je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(V&7)>>>((q+32|0)>>>0))+(L<<16>>16)|0;ea=b[ba+(j<<2)+2>>1]|0;fa=b[ba+(j<<2)>>1]|0;ga=V}else{ea=aa;fa=$;ga=da}}while(0);$=ea+ga|0;aa=i>>>0>$>>>0?$:i;c[l>>2]=aa;$=fa<<2;ba=ca<<1;_=c[Z>>2]|0;v=_+(ba<<1)|0;b[v>>1]=$;W=f+(aa>>>3)|0;V=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(aa&7)>>>30;W=aa+2|0;aa=i>>>0>W>>>0?W:i;c[l>>2]=aa;b[v>>1]=$&65535|V;V=c[X>>2]|0;$=f+(aa>>>3)|0;v=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(aa&7)>>>21;$=b[V+(v<<2)>>1]|0;W=b[V+(v<<2)+2>>1]|0;v=W<<16>>16;do{if(W<<16>>16<0){j=aa+11|0;L=i>>>0>j>>>0?j:i;j=f+(L>>>3)|0;q=((je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(L&7)>>>((v+32|0)>>>0))+($<<16>>16)|0;j=b[V+(q<<2)>>1]|0;s=b[V+(q<<2)+2>>1]|0;q=s<<16>>16;if(!(s<<16>>16<0)){ha=q;ia=j;ja=L;break}s=L-v|0;L=i>>>0>s>>>0?s:i;s=f+(L>>>3)|0;o=((je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(L&7)>>>((q+32|0)>>>0))+(j<<16>>16)|0;ha=b[V+(o<<2)+2>>1]|0;ia=b[V+(o<<2)>>1]|0;ja=L}else{ha=v;ia=$;ja=aa}}while(0);aa=ha+ja|0;$=i>>>0>aa>>>0?aa:i;c[l>>2]=$;aa=ia<<2;v=_+((ba|1)<<1)|0;b[v>>1]=aa;V=f+($>>>3)|0;W=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<($&7)>>>30;V=$+2|0;$=i>>>0>V>>>0?V:i;c[l>>2]=$;b[v>>1]=aa&65535|W;W=ca+1|0;if((W|0)<(h|0)){ca=W;da=$}else{T=77;break}}if((T|0)==77){return}}if(!Q){if(!t){return}Q=e+860320+((g+4|0)*20|0)+4|0;da=e+860320+(g*20|0)+4|0;ca=e+144|0;ia=c[e+24>>2]|0;ja=c[m>>2]|0;ha=0;X=k;while(1){Z=c[Q>>2]|0;fa=ja+(X>>>3)|0;ga=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(X&7)>>>21;fa=b[Z+(ga<<2)>>1]|0;ea=(b[Z+(ga<<2)+2>>1]|0)+X|0;ga=ia>>>0>ea>>>0?ea:ia;c[l>>2]=ga;if(fa<<16>>16==-1){ea=c[da>>2]|0;Z=ja+(ga>>>3)|0;Y=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(ga&7)>>>21;Z=b[ea+(Y<<2)>>1]|0;u=b[ea+(Y<<2)+2>>1]|0;Y=u<<16>>16;do{if(u<<16>>16<0){$=ga+11|0;W=ia>>>0>$>>>0?$:ia;$=ja+(W>>>3)|0;aa=((je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(W&7)>>>((Y+32|0)>>>0))+(Z<<16>>16)|0;$=b[ea+(aa<<2)>>1]|0;v=b[ea+(aa<<2)+2>>1]|0;aa=v<<16>>16;if(!(v<<16>>16<0)){ka=aa;la=$;ma=W;break}v=W-Y|0;W=ia>>>0>v>>>0?v:ia;v=ja+(W>>>3)|0;V=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(W&7)>>>((aa+32|0)>>>0))+($<<16>>16)|0;ka=b[ea+(V<<2)+2>>1]|0;la=b[ea+(V<<2)>>1]|0;ma=W}else{ka=Y;la=Z;ma=ga}}while(0);Z=ka+ma|0;Y=ia>>>0>Z>>>0?Z:ia;c[l>>2]=Y;Z=ha<<1;ea=c[ca>>2]|0;b[ea+(Z<<1)>>1]=la;u=c[da>>2]|0;i=ja+(Y>>>3)|0;f=(je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(Y&7)>>>21;i=b[u+(f<<2)>>1]|0;ba=b[u+(f<<2)+2>>1]|0;f=ba<<16>>16;do{if(ba<<16>>16<0){_=Y+11|0;W=ia>>>0>_>>>0?_:ia;_=ja+(W>>>3)|0;V=((je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(W&7)>>>((f+32|0)>>>0))+(i<<16>>16)|0;_=b[u+(V<<2)>>1]|0;$=b[u+(V<<2)+2>>1]|0;V=$<<16>>16;if(!($<<16>>16<0)){na=V;oa=_;pa=W;break}$=W-f|0;W=ia>>>0>$>>>0?$:ia;$=ja+(W>>>3)|0;aa=((je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(W&7)>>>((V+32|0)>>>0))+(_<<16>>16)|0;na=b[u+(aa<<2)+2>>1]|0;oa=b[u+(aa<<2)>>1]|0;pa=W}else{na=f;oa=i;pa=Y}}while(0);Y=na+pa|0;i=ia>>>0>Y>>>0?Y:ia;c[l>>2]=i;b[ea+((Z|1)<<1)>>1]=oa;qa=i}else{i=fa&65535;Y=ha<<1;f=c[ca>>2]|0;b[f+(Y<<1)>>1]=i<<16>>24;b[f+((Y|1)<<1)>>1]=i<<24>>24;qa=ga}i=ha+1|0;if((i|0)<(h|0)){ha=i;X=qa}else{break}}return}if(!t){return}t=e+860320+((g+4|0)*20|0)+4|0;qa=e+24|0;X=m|0;m=e+860320+(g*20|0)+4|0;g=e+144|0;e=0;ha=k;while(1){if((R-ha|0)<=0){T=77;break}k=c[t>>2]|0;ca=c[qa>>2]|0;oa=c[X>>2]|0;ia=oa+(ha>>>3)|0;pa=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(ha&7)>>>21;ia=b[k+(pa<<2)>>1]|0;na=(b[k+(pa<<2)+2>>1]|0)+ha|0;pa=ca>>>0>na>>>0?na:ca;c[l>>2]=pa;if(ia<<16>>16==-1){na=c[m>>2]|0;k=oa+(pa>>>3)|0;ja=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(pa&7)>>>21;k=b[na+(ja<<2)>>1]|0;da=b[na+(ja<<2)+2>>1]|0;ja=da<<16>>16;do{if(da<<16>>16<0){la=pa+11|0;ma=ca>>>0>la>>>0?la:ca;la=oa+(ma>>>3)|0;ka=((je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>((ja+32|0)>>>0))+(k<<16>>16)|0;la=b[na+(ka<<2)>>1]|0;Q=b[na+(ka<<2)+2>>1]|0;ka=Q<<16>>16;if(!(Q<<16>>16<0)){ra=ka;sa=la;ta=ma;break}Q=ma-ja|0;ma=ca>>>0>Q>>>0?Q:ca;Q=oa+(ma>>>3)|0;i=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(ma&7)>>>((ka+32|0)>>>0))+(la<<16>>16)|0;ra=b[na+(i<<2)+2>>1]|0;sa=b[na+(i<<2)>>1]|0;ta=ma}else{ra=ja;sa=k;ta=pa}}while(0);k=ra+ta|0;ja=ca>>>0>k>>>0?k:ca;c[l>>2]=ja;k=e<<1;na=c[g>>2]|0;b[na+(k<<1)>>1]=sa;da=c[m>>2]|0;ga=oa+(ja>>>3)|0;fa=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(ja&7)>>>21;ga=b[da+(fa<<2)>>1]|0;Z=b[da+(fa<<2)+2>>1]|0;fa=Z<<16>>16;do{if(Z<<16>>16<0){ea=ja+11|0;ma=ca>>>0>ea>>>0?ea:ca;ea=oa+(ma>>>3)|0;i=((je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ma&7)>>>((fa+32|0)>>>0))+(ga<<16>>16)|0;ea=b[da+(i<<2)>>1]|0;la=b[da+(i<<2)+2>>1]|0;i=la<<16>>16;if(!(la<<16>>16<0)){ua=i;va=ea;wa=ma;break}la=ma-fa|0;ma=ca>>>0>la>>>0?la:ca;la=oa+(ma>>>3)|0;ka=((je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>((i+32|0)>>>0))+(ea<<16>>16)|0;ua=b[da+(ka<<2)+2>>1]|0;va=b[da+(ka<<2)>>1]|0;wa=ma}else{ua=fa;va=ga;wa=ja}}while(0);ja=ua+wa|0;ga=ca>>>0>ja>>>0?ja:ca;c[l>>2]=ga;b[na+((k|1)<<1)>>1]=va;xa=ga}else{ga=ia&65535;ja=e<<1;fa=c[g>>2]|0;b[fa+(ja<<1)>>1]=ga<<16>>24;b[fa+((ja|1)<<1)>>1]=ga<<24>>24;xa=pa}ga=e+1|0;if((ga|0)<(h|0)){e=ga;ha=xa}else{T=77;break}}if((T|0)==77){return}}function XKa(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;g=(f|0)/2|0;h=e+8|0;i=e+16|0;j=c[i>>2]|0;k=e+20|0;l=c[k>>2]|0;m=(f|0)>1;if((g|0)<((l-j|0)/124|0|0)){if(!m){return}f=e+860424|0;n=e+24|0;o=h|0;p=e+860324|0;q=e+132|0;r=e+860344|0;s=e+136|0;t=e+860444|0;u=e+860364|0;v=e+140|0;w=0;x=j;while(1){y=c[f>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;B=A+(x>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(x&7)>>>21;B=b[y+(C<<2)>>1]|0;D=B<<16>>16;E=(b[y+(C<<2)+2>>1]|0)+x|0;C=z>>>0>E>>>0?E:z;c[i>>2]=C;if((D&65535|0)==65535){E=c[p>>2]|0;y=A+(C>>>3)|0;F=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(C&7)>>>21;y=b[E+(F<<2)>>1]|0;G=b[E+(F<<2)+2>>1]|0;F=G<<16>>16;H=y&255;do{if(G<<16>>16<0){I=C+11|0;J=z>>>0>I>>>0?I:z;I=A+(J>>>3)|0;K=((je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>((F+32|0)>>>0))+(y<<16>>16)|0;I=b[E+(K<<2)>>1]|0;L=b[E+(K<<2)+2>>1]|0;K=L<<16>>16;if(!(L<<16>>16<0)){M=K;N=I&255;O=J;break}L=J-F|0;J=z>>>0>L>>>0?L:z;L=A+(J>>>3)|0;P=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(J&7)>>>((K+32|0)>>>0))+(I<<16>>16)|0;M=b[E+(P<<2)+2>>1]|0;N=b[E+(P<<2)>>1]&255;O=J}else{M=F;N=H;O=C}}while(0);C=M+O|0;c[i>>2]=z>>>0>C>>>0?C:z;a[(c[q>>2]|0)+(w<<1)|0]=N;C=c[r>>2]|0;H=c[i>>2]|0;F=c[n>>2]|0;E=c[o>>2]|0;A=E+(H>>>3)|0;y=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(H&7)>>>21;A=b[C+(y<<2)>>1]|0;G=b[C+(y<<2)+2>>1]|0;y=G<<16>>16;J=A&255;do{if(G<<16>>16<0){P=H+11|0;I=F>>>0>P>>>0?P:F;P=E+(I>>>3)|0;K=((je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(I&7)>>>((y+32|0)>>>0))+(A<<16>>16)|0;P=b[C+(K<<2)>>1]|0;L=b[C+(K<<2)+2>>1]|0;K=L<<16>>16;if(!(L<<16>>16<0)){Q=K;R=P&255;S=I;break}L=I-y|0;I=F>>>0>L>>>0?L:F;L=E+(I>>>3)|0;T=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(I&7)>>>((K+32|0)>>>0))+(P<<16>>16)|0;Q=b[C+(T<<2)+2>>1]|0;R=b[C+(T<<2)>>1]&255;S=I}else{Q=y;R=J;S=H}}while(0);H=Q+S|0;c[i>>2]=F>>>0>H>>>0?H:F;a[(c[s>>2]|0)+w|0]=R}else{a[(c[q>>2]|0)+(w<<1)|0]=D>>>8;a[(c[s>>2]|0)+w|0]=B}H=c[t>>2]|0;J=c[i>>2]|0;y=c[n>>2]|0;C=c[o>>2]|0;E=C+(J>>>3)|0;A=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(J&7)>>>21;E=b[H+(A<<2)>>1]|0;G=E<<16>>16;z=(b[H+(A<<2)+2>>1]|0)+J|0;J=y>>>0>z>>>0?z:y;c[i>>2]=J;if((G&65535|0)==65535){z=c[p>>2]|0;A=C+(J>>>3)|0;H=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(J&7)>>>21;A=b[z+(H<<2)>>1]|0;I=b[z+(H<<2)+2>>1]|0;H=I<<16>>16;T=A&255;do{if(I<<16>>16<0){P=J+11|0;K=y>>>0>P>>>0?P:y;P=C+(K>>>3)|0;L=((je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(K&7)>>>((H+32|0)>>>0))+(A<<16>>16)|0;P=b[z+(L<<2)>>1]|0;U=b[z+(L<<2)+2>>1]|0;L=U<<16>>16;if(!(U<<16>>16<0)){V=L;W=P&255;X=K;break}U=K-H|0;K=y>>>0>U>>>0?U:y;U=C+(K>>>3)|0;Y=((je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(K&7)>>>((L+32|0)>>>0))+(P<<16>>16)|0;V=b[z+(Y<<2)+2>>1]|0;W=b[z+(Y<<2)>>1]&255;X=K}else{V=H;W=T;X=J}}while(0);J=V+X|0;c[i>>2]=y>>>0>J>>>0?J:y;a[(c[q>>2]|0)+(w<<1|1)|0]=W;J=c[u>>2]|0;T=c[i>>2]|0;H=c[n>>2]|0;z=c[o>>2]|0;C=z+(T>>>3)|0;A=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(T&7)>>>21;C=b[J+(A<<2)>>1]|0;I=b[J+(A<<2)+2>>1]|0;A=I<<16>>16;B=C&255;do{if(I<<16>>16<0){D=T+11|0;F=H>>>0>D>>>0?D:H;D=z+(F>>>3)|0;K=((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(F&7)>>>((A+32|0)>>>0))+(C<<16>>16)|0;D=b[J+(K<<2)>>1]|0;Y=b[J+(K<<2)+2>>1]|0;K=Y<<16>>16;if(!(Y<<16>>16<0)){Z=K;_=D&255;$=F;break}Y=F-A|0;F=H>>>0>Y>>>0?Y:H;Y=z+(F>>>3)|0;P=((je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(F&7)>>>((K+32|0)>>>0))+(D<<16>>16)|0;Z=b[J+(P<<2)+2>>1]|0;_=b[J+(P<<2)>>1]&255;$=F}else{Z=A;_=B;$=T}}while(0);T=Z+$|0;c[i>>2]=H>>>0>T>>>0?T:H;a[(c[v>>2]|0)+w|0]=_}else{a[(c[q>>2]|0)+(w<<1|1)|0]=G>>>8;a[(c[v>>2]|0)+w|0]=E}T=w+1|0;if((T|0)>=(g|0)){break}w=T;x=c[i>>2]|0}return}a:do{if(m){x=e+860424|0;w=e+24|0;v=h|0;q=e+860324|0;_=e+132|0;$=e+860344|0;Z=e+136|0;o=e+860444|0;n=e+860364|0;u=e+140|0;W=0;X=j;V=l;while(1){if((V-X|0)<=0){aa=W;break a}p=c[x>>2]|0;t=c[w>>2]|0;s=c[v>>2]|0;R=s+(X>>>3)|0;S=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(X&7)>>>21;R=b[p+(S<<2)>>1]|0;Q=R<<16>>16;r=(b[p+(S<<2)+2>>1]|0)+X|0;S=t>>>0>r>>>0?r:t;c[i>>2]=S;if((Q&65535|0)==65535){r=c[q>>2]|0;p=s+(S>>>3)|0;N=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(S&7)>>>21;p=b[r+(N<<2)>>1]|0;O=b[r+(N<<2)+2>>1]|0;N=O<<16>>16;M=p&255;do{if(O<<16>>16<0){f=S+11|0;T=t>>>0>f>>>0?f:t;f=s+(T>>>3)|0;B=((je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(T&7)>>>((N+32|0)>>>0))+(p<<16>>16)|0;f=b[r+(B<<2)>>1]|0;A=b[r+(B<<2)+2>>1]|0;B=A<<16>>16;if(!(A<<16>>16<0)){ba=B;ca=f&255;da=T;break}A=T-N|0;T=t>>>0>A>>>0?A:t;A=s+(T>>>3)|0;J=((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(T&7)>>>((B+32|0)>>>0))+(f<<16>>16)|0;ba=b[r+(J<<2)+2>>1]|0;ca=b[r+(J<<2)>>1]&255;da=T}else{ba=N;ca=M;da=S}}while(0);S=ba+da|0;c[i>>2]=t>>>0>S>>>0?S:t;a[(c[_>>2]|0)+(W<<1)|0]=ca;S=c[$>>2]|0;M=c[i>>2]|0;N=c[w>>2]|0;r=c[v>>2]|0;s=r+(M>>>3)|0;p=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(M&7)>>>21;s=b[S+(p<<2)>>1]|0;O=b[S+(p<<2)+2>>1]|0;p=O<<16>>16;T=s&255;do{if(O<<16>>16<0){J=M+11|0;f=N>>>0>J>>>0?J:N;J=r+(f>>>3)|0;B=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(f&7)>>>((p+32|0)>>>0))+(s<<16>>16)|0;J=b[S+(B<<2)>>1]|0;A=b[S+(B<<2)+2>>1]|0;B=A<<16>>16;if(!(A<<16>>16<0)){ea=B;fa=J&255;ga=f;break}A=f-p|0;f=N>>>0>A>>>0?A:N;A=r+(f>>>3)|0;z=((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(f&7)>>>((B+32|0)>>>0))+(J<<16>>16)|0;ea=b[S+(z<<2)+2>>1]|0;fa=b[S+(z<<2)>>1]&255;ga=f}else{ea=p;fa=T;ga=M}}while(0);M=ea+ga|0;c[i>>2]=N>>>0>M>>>0?M:N;a[(c[Z>>2]|0)+W|0]=fa}else{a[(c[_>>2]|0)+(W<<1)|0]=Q>>>8;a[(c[Z>>2]|0)+W|0]=R}M=c[o>>2]|0;T=c[i>>2]|0;p=c[w>>2]|0;S=c[v>>2]|0;r=S+(T>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(T&7)>>>21;r=b[M+(s<<2)>>1]|0;O=r<<16>>16;t=(b[M+(s<<2)+2>>1]|0)+T|0;T=p>>>0>t>>>0?t:p;c[i>>2]=T;if((O&65535|0)==65535){t=c[q>>2]|0;s=S+(T>>>3)|0;M=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(T&7)>>>21;s=b[t+(M<<2)>>1]|0;f=b[t+(M<<2)+2>>1]|0;M=f<<16>>16;z=s&255;do{if(f<<16>>16<0){J=T+11|0;B=p>>>0>J>>>0?J:p;J=S+(B>>>3)|0;A=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(B&7)>>>((M+32|0)>>>0))+(s<<16>>16)|0;J=b[t+(A<<2)>>1]|0;C=b[t+(A<<2)+2>>1]|0;A=C<<16>>16;if(!(C<<16>>16<0)){ha=A;ia=J&255;ja=B;break}C=B-M|0;B=p>>>0>C>>>0?C:p;C=S+(B>>>3)|0;I=((je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7)>>>((A+32|0)>>>0))+(J<<16>>16)|0;ha=b[t+(I<<2)+2>>1]|0;ia=b[t+(I<<2)>>1]&255;ja=B}else{ha=M;ia=z;ja=T}}while(0);T=ha+ja|0;c[i>>2]=p>>>0>T>>>0?T:p;a[(c[_>>2]|0)+(W<<1|1)|0]=ia;T=c[n>>2]|0;z=c[i>>2]|0;M=c[w>>2]|0;t=c[v>>2]|0;S=t+(z>>>3)|0;s=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(z&7)>>>21;S=b[T+(s<<2)>>1]|0;f=b[T+(s<<2)+2>>1]|0;s=f<<16>>16;R=S&255;do{if(f<<16>>16<0){Q=z+11|0;N=M>>>0>Q>>>0?Q:M;Q=t+(N>>>3)|0;B=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(N&7)>>>((s+32|0)>>>0))+(S<<16>>16)|0;Q=b[T+(B<<2)>>1]|0;I=b[T+(B<<2)+2>>1]|0;B=I<<16>>16;if(!(I<<16>>16<0)){ka=B;la=Q&255;ma=N;break}I=N-s|0;N=M>>>0>I>>>0?I:M;I=t+(N>>>3)|0;J=((je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(N&7)>>>((B+32|0)>>>0))+(Q<<16>>16)|0;ka=b[T+(J<<2)+2>>1]|0;la=b[T+(J<<2)>>1]&255;ma=N}else{ka=s;la=R;ma=z}}while(0);z=ka+ma|0;c[i>>2]=M>>>0>z>>>0?z:M;a[(c[u>>2]|0)+W|0]=la}else{a[(c[_>>2]|0)+(W<<1|1)|0]=O>>>8;a[(c[u>>2]|0)+W|0]=r}z=W+1|0;if((z|0)>=(g|0)){aa=z;break a}W=z;X=c[i>>2]|0;V=c[k>>2]|0}}else{aa=0}}while(0);if((aa|0)>=(g|0)){return}k=e+140|0;i=e+132|0;la=e+136|0;e=aa;do{a[(c[k>>2]|0)+e|0]=-128;aa=e<<1;a[(c[i>>2]|0)+(aa|1)|0]=-128;a[(c[la>>2]|0)+e|0]=-128;a[(c[i>>2]|0)+aa|0]=-128;e=e+1|0;}while((e|0)<(g|0));return}function YKa(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=(f|0)/2|0;h=e+8|0;i=e+16|0;j=c[i>>2]|0;k=e+20|0;l=c[k>>2]|0;m=(f|0)>1;if((g|0)<((l-j|0)/62|0|0)){if(!m){return}f=e+860404|0;n=e+24|0;o=h|0;p=e+860324|0;q=e+132|0;r=0;s=j;while(1){t=c[f>>2]|0;u=c[n>>2]|0;v=c[o>>2]|0;w=v+(s>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(s&7)>>>21;w=b[t+(x<<2)>>1]|0;y=w<<16>>16;z=(b[t+(x<<2)+2>>1]|0)+s|0;x=u>>>0>z>>>0?z:u;c[i>>2]=x;if((y&65535|0)==65535){z=c[p>>2]|0;t=v+(x>>>3)|0;A=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(x&7)>>>21;t=b[z+(A<<2)>>1]|0;B=b[z+(A<<2)+2>>1]|0;A=B<<16>>16;C=t&255;do{if(B<<16>>16<0){D=x+11|0;E=u>>>0>D>>>0?D:u;D=v+(E>>>3)|0;F=((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>((A+32|0)>>>0))+(t<<16>>16)|0;D=b[z+(F<<2)>>1]|0;G=b[z+(F<<2)+2>>1]|0;F=G<<16>>16;if(!(G<<16>>16<0)){H=F;I=D&255;J=E;break}G=E-A|0;E=u>>>0>G>>>0?G:u;G=v+(E>>>3)|0;K=((je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7)>>>((F+32|0)>>>0))+(D<<16>>16)|0;H=b[z+(K<<2)+2>>1]|0;I=b[z+(K<<2)>>1]&255;J=E}else{H=A;I=C;J=x}}while(0);x=H+J|0;c[i>>2]=u>>>0>x>>>0?x:u;x=r<<1;a[(c[q>>2]|0)+x|0]=I;C=c[p>>2]|0;A=c[i>>2]|0;z=c[n>>2]|0;v=c[o>>2]|0;t=v+(A>>>3)|0;B=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(A&7)>>>21;t=b[C+(B<<2)>>1]|0;E=b[C+(B<<2)+2>>1]|0;B=E<<16>>16;K=t&255;do{if(E<<16>>16<0){D=A+11|0;F=z>>>0>D>>>0?D:z;D=v+(F>>>3)|0;G=((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(F&7)>>>((B+32|0)>>>0))+(t<<16>>16)|0;D=b[C+(G<<2)>>1]|0;L=b[C+(G<<2)+2>>1]|0;G=L<<16>>16;if(!(L<<16>>16<0)){M=G;N=D&255;O=F;break}L=F-B|0;F=z>>>0>L>>>0?L:z;L=v+(F>>>3)|0;P=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(F&7)>>>((G+32|0)>>>0))+(D<<16>>16)|0;M=b[C+(P<<2)+2>>1]|0;N=b[C+(P<<2)>>1]&255;O=F}else{M=B;N=K;O=A}}while(0);A=M+O|0;c[i>>2]=z>>>0>A>>>0?A:z;a[(c[q>>2]|0)+(x|1)|0]=N}else{A=r<<1;a[(c[q>>2]|0)+A|0]=y>>>8;a[(c[q>>2]|0)+(A|1)|0]=w}A=r+1|0;if((A|0)>=(g|0)){break}r=A;s=c[i>>2]|0}return}if(!m){return}m=e+860404|0;s=e+24|0;r=h|0;h=e+860324|0;q=e+132|0;e=0;N=j;j=l;while(1){if((j-N|0)<=0){Q=29;break}l=c[m>>2]|0;O=c[s>>2]|0;M=c[r>>2]|0;o=M+(N>>>3)|0;n=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(N&7)>>>21;o=b[l+(n<<2)>>1]|0;p=o<<16>>16;I=(b[l+(n<<2)+2>>1]|0)+N|0;n=O>>>0>I>>>0?I:O;c[i>>2]=n;if((p&65535|0)==65535){I=c[h>>2]|0;l=M+(n>>>3)|0;J=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(n&7)>>>21;l=b[I+(J<<2)>>1]|0;H=b[I+(J<<2)+2>>1]|0;J=H<<16>>16;f=l&255;do{if(H<<16>>16<0){A=n+11|0;K=O>>>0>A>>>0?A:O;A=M+(K>>>3)|0;B=((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(K&7)>>>((J+32|0)>>>0))+(l<<16>>16)|0;A=b[I+(B<<2)>>1]|0;C=b[I+(B<<2)+2>>1]|0;B=C<<16>>16;if(!(C<<16>>16<0)){R=B;S=A&255;T=K;break}C=K-J|0;K=O>>>0>C>>>0?C:O;C=M+(K>>>3)|0;v=((je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(K&7)>>>((B+32|0)>>>0))+(A<<16>>16)|0;R=b[I+(v<<2)+2>>1]|0;S=b[I+(v<<2)>>1]&255;T=K}else{R=J;S=f;T=n}}while(0);n=R+T|0;c[i>>2]=O>>>0>n>>>0?n:O;n=e<<1;a[(c[q>>2]|0)+n|0]=S;f=c[h>>2]|0;J=c[i>>2]|0;I=c[s>>2]|0;M=c[r>>2]|0;l=M+(J>>>3)|0;H=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(J&7)>>>21;l=b[f+(H<<2)>>1]|0;w=b[f+(H<<2)+2>>1]|0;H=w<<16>>16;y=l&255;do{if(w<<16>>16<0){x=J+11|0;z=I>>>0>x>>>0?x:I;x=M+(z>>>3)|0;K=((je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7)>>>((H+32|0)>>>0))+(l<<16>>16)|0;x=b[f+(K<<2)>>1]|0;v=b[f+(K<<2)+2>>1]|0;K=v<<16>>16;if(!(v<<16>>16<0)){U=K;V=x&255;W=z;break}v=z-H|0;z=I>>>0>v>>>0?v:I;v=M+(z>>>3)|0;A=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(z&7)>>>((K+32|0)>>>0))+(x<<16>>16)|0;U=b[f+(A<<2)+2>>1]|0;V=b[f+(A<<2)>>1]&255;W=z}else{U=H;V=y;W=J}}while(0);J=U+W|0;c[i>>2]=I>>>0>J>>>0?J:I;a[(c[q>>2]|0)+(n|1)|0]=V}else{J=e<<1;a[(c[q>>2]|0)+J|0]=p>>>8;a[(c[q>>2]|0)+(J|1)|0]=o}J=e+1|0;if((J|0)>=(g|0)){Q=29;break}e=J;N=c[i>>2]|0;j=c[k>>2]|0}if((Q|0)==29){return}}function ZKa(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;g=(c[e+60>>2]|0)==24;h=(f|0)>0;if((c[e+56>>2]|0)==0){if(g){if(!h){return}i=e+860404|0;j=e+16|0;k=e+24|0;l=e+8|0;m=e+860324|0;n=e+132|0;o=e+860344|0;p=e+860364|0;q=0;do{r=c[i>>2]|0;s=c[j>>2]|0;t=c[k>>2]|0;u=c[l>>2]|0;v=u+(s>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(s&7)>>>21;v=b[r+(w<<2)>>1]|0;x=(b[r+(w<<2)+2>>1]|0)+s|0;s=t>>>0>x>>>0?x:t;c[j>>2]=s;if(v<<16>>16==-1){x=c[m>>2]|0;w=u+(s>>>3)|0;r=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(s&7)>>>21;w=b[x+(r<<2)>>1]|0;y=b[x+(r<<2)+2>>1]|0;r=y<<16>>16;do{if(y<<16>>16<0){z=s+11|0;A=t>>>0>z>>>0?z:t;z=u+(A>>>3)|0;B=((je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(A&7)>>>((r+32|0)>>>0))+(w<<16>>16)|0;z=b[x+(B<<2)>>1]|0;C=b[x+(B<<2)+2>>1]|0;B=C<<16>>16;if(C<<16>>16<0){C=A-r|0;D=t>>>0>C>>>0?C:t;C=u+(D>>>3)|0;E=((je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)>>>((B+32|0)>>>0))+(z<<16>>16)|0;F=b[x+(E<<2)+2>>1]|0;G=b[x+(E<<2)>>1]&255;H=D;break}else{F=B;G=z&255;H=A;break}}else{F=r;G=w&255;H=s}}while(0);s=F+H|0;c[j>>2]=t>>>0>s>>>0?s:t;s=q<<2;a[(c[n>>2]|0)+s|0]=G;w=c[o>>2]|0;r=c[j>>2]|0;x=c[k>>2]|0;u=c[l>>2]|0;y=u+(r>>>3)|0;A=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(r&7)>>>21;y=b[w+(A<<2)>>1]|0;z=b[w+(A<<2)+2>>1]|0;A=z<<16>>16;B=y&255;do{if(z<<16>>16<0){D=r+11|0;E=x>>>0>D>>>0?D:x;D=u+(E>>>3)|0;C=((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>((A+32|0)>>>0))+(y<<16>>16)|0;D=b[w+(C<<2)>>1]|0;I=b[w+(C<<2)+2>>1]|0;C=I<<16>>16;if(!(I<<16>>16<0)){J=C;K=D&255;L=E;break}I=E-A|0;E=x>>>0>I>>>0?I:x;I=u+(E>>>3)|0;M=((je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(E&7)>>>((C+32|0)>>>0))+(D<<16>>16)|0;J=b[w+(M<<2)+2>>1]|0;K=b[w+(M<<2)>>1]&255;L=E}else{J=A;K=B;L=r}}while(0);r=J+L|0;c[j>>2]=x>>>0>r>>>0?r:x;a[(c[n>>2]|0)+(s|1)|0]=K;r=c[p>>2]|0;B=c[j>>2]|0;A=c[k>>2]|0;w=c[l>>2]|0;u=w+(B>>>3)|0;y=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(B&7)>>>21;u=b[r+(y<<2)>>1]|0;z=b[r+(y<<2)+2>>1]|0;y=z<<16>>16;t=u&255;do{if(z<<16>>16<0){E=B+11|0;M=A>>>0>E>>>0?E:A;E=w+(M>>>3)|0;D=((je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(M&7)>>>((y+32|0)>>>0))+(u<<16>>16)|0;E=b[r+(D<<2)>>1]|0;C=b[r+(D<<2)+2>>1]|0;D=C<<16>>16;if(!(C<<16>>16<0)){N=D;O=E&255;P=M;break}C=M-y|0;M=A>>>0>C>>>0?C:A;C=w+(M>>>3)|0;I=((je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(M&7)>>>((D+32|0)>>>0))+(E<<16>>16)|0;N=b[r+(I<<2)+2>>1]|0;O=b[r+(I<<2)>>1]&255;P=M}else{N=y;O=t;P=B}}while(0);B=N+P|0;c[j>>2]=A>>>0>B>>>0?B:A;a[(c[n>>2]|0)+(s|2)|0]=O}else{c[(c[n>>2]|0)+(q<<2)>>2]=c[e+852128+(v<<16>>16<<2)>>2]}q=q+1|0;}while((q|0)<(f|0));return}if(!h){return}q=e+860404|0;n=e+16|0;O=e+24|0;j=e+8|0;P=e+860324|0;N=e+132|0;l=e+860344|0;k=e+860364|0;p=0;do{K=c[q>>2]|0;L=c[n>>2]|0;J=c[O>>2]|0;o=c[j>>2]|0;G=o+(L>>>3)|0;H=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(L&7)>>>21;G=b[K+(H<<2)>>1]|0;F=(b[K+(H<<2)+2>>1]|0)+L|0;L=J>>>0>F>>>0?F:J;c[n>>2]=L;if(G<<16>>16==-1){F=c[P>>2]|0;H=o+(L>>>3)|0;K=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(L&7)>>>21;H=b[F+(K<<2)>>1]|0;m=b[F+(K<<2)+2>>1]|0;K=m<<16>>16;do{if(m<<16>>16<0){i=L+11|0;B=J>>>0>i>>>0?i:J;i=o+(B>>>3)|0;t=((je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(B&7)>>>((K+32|0)>>>0))+(H<<16>>16)|0;i=b[F+(t<<2)>>1]|0;y=b[F+(t<<2)+2>>1]|0;t=y<<16>>16;if(y<<16>>16<0){y=B-K|0;r=J>>>0>y>>>0?y:J;y=o+(r>>>3)|0;w=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(r&7)>>>((t+32|0)>>>0))+(i<<16>>16)|0;Q=b[F+(w<<2)+2>>1]|0;R=b[F+(w<<2)>>1]&255;S=r;break}else{Q=t;R=i&255;S=B;break}}else{Q=K;R=H&255;S=L}}while(0);L=Q+S|0;c[n>>2]=J>>>0>L>>>0?L:J;L=p<<2;a[(c[N>>2]|0)+L|0]=R;H=c[l>>2]|0;K=c[n>>2]|0;F=c[O>>2]|0;m=c[j>>2]|0;v=m+(K>>>3)|0;s=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(K&7)>>>21;v=b[H+(s<<2)>>1]|0;A=b[H+(s<<2)+2>>1]|0;s=A<<16>>16;B=v&255;do{if(A<<16>>16<0){i=K+11|0;t=F>>>0>i>>>0?i:F;i=m+(t>>>3)|0;r=((je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(t&7)>>>((s+32|0)>>>0))+(v<<16>>16)|0;i=b[H+(r<<2)>>1]|0;w=b[H+(r<<2)+2>>1]|0;r=w<<16>>16;if(!(w<<16>>16<0)){T=r;U=i&255;V=t;break}w=t-s|0;t=F>>>0>w>>>0?w:F;w=m+(t>>>3)|0;y=((je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(t&7)>>>((r+32|0)>>>0))+(i<<16>>16)|0;T=b[H+(y<<2)+2>>1]|0;U=b[H+(y<<2)>>1]&255;V=t}else{T=s;U=B;V=K}}while(0);K=T+V|0;c[n>>2]=F>>>0>K>>>0?K:F;a[(c[N>>2]|0)+(L|1)|0]=U;K=c[k>>2]|0;B=c[n>>2]|0;s=c[O>>2]|0;H=c[j>>2]|0;m=H+(B>>>3)|0;v=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7)>>>21;m=b[K+(v<<2)>>1]|0;A=b[K+(v<<2)+2>>1]|0;v=A<<16>>16;J=m&255;do{if(A<<16>>16<0){t=B+11|0;y=s>>>0>t>>>0?t:s;t=H+(y>>>3)|0;i=((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(y&7)>>>((v+32|0)>>>0))+(m<<16>>16)|0;t=b[K+(i<<2)>>1]|0;r=b[K+(i<<2)+2>>1]|0;i=r<<16>>16;if(!(r<<16>>16<0)){W=i;X=t&255;Y=y;break}r=y-v|0;y=s>>>0>r>>>0?r:s;r=H+(y>>>3)|0;w=((je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(y&7)>>>((i+32|0)>>>0))+(t<<16>>16)|0;W=b[K+(w<<2)+2>>1]|0;X=b[K+(w<<2)>>1]&255;Y=y}else{W=v;X=J;Y=B}}while(0);B=W+Y|0;c[n>>2]=s>>>0>B>>>0?B:s;a[(c[N>>2]|0)+(L|2)|0]=X;Z=c[j>>2]|0}else{c[(c[N>>2]|0)+(p<<2)>>2]=c[e+852128+(G<<16>>16<<2)>>2];Z=o}B=c[k>>2]|0;J=c[n>>2]|0;v=c[O>>2]|0;K=Z+(J>>>3)|0;H=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(J&7)>>>21;K=b[B+(H<<2)>>1]|0;m=b[B+(H<<2)+2>>1]|0;H=m<<16>>16;do{if(m<<16>>16<0){A=J+11|0;F=v>>>0>A>>>0?A:v;A=Z+(F>>>3)|0;y=((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(F&7)>>>((H+32|0)>>>0))+(K<<16>>16)|0;A=b[B+(y<<2)>>1]|0;w=b[B+(y<<2)+2>>1]|0;y=w<<16>>16;if(w<<16>>16<0){w=F-H|0;t=v>>>0>w>>>0?w:v;w=Z+(t>>>3)|0;i=((je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(t&7)>>>((y+32|0)>>>0))+(A<<16>>16)|0;_=b[B+(i<<2)+2>>1]|0;$=b[B+(i<<2)>>1]&255;aa=t;break}else{_=y;$=A&255;aa=F;break}}else{_=H;$=K&255;aa=J}}while(0);J=_+aa|0;c[n>>2]=v>>>0>J>>>0?J:v;a[(c[N>>2]|0)+(p<<2|3)|0]=$;p=p+1|0;}while((p|0)<(f|0));return}else{if(g){if(!h){return}g=e+860404|0;p=e+16|0;$=e+24|0;N=e+8|0;n=e+860324|0;aa=e+132|0;_=e+860344|0;Z=e+860364|0;O=0;do{k=c[g>>2]|0;j=c[p>>2]|0;X=c[$>>2]|0;Y=c[N>>2]|0;W=Y+(j>>>3)|0;U=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(j&7)>>>21;W=b[k+(U<<2)>>1]|0;V=(b[k+(U<<2)+2>>1]|0)+j|0;j=X>>>0>V>>>0?V:X;c[p>>2]=j;if(W<<16>>16==-1){V=c[_>>2]|0;U=Y+(j>>>3)|0;k=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(j&7)>>>21;U=b[V+(k<<2)>>1]|0;T=b[V+(k<<2)+2>>1]|0;k=T<<16>>16;do{if(T<<16>>16<0){l=j+11|0;R=X>>>0>l>>>0?l:X;l=Y+(R>>>3)|0;S=((je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(R&7)>>>((k+32|0)>>>0))+(U<<16>>16)|0;l=b[V+(S<<2)>>1]|0;Q=b[V+(S<<2)+2>>1]|0;S=Q<<16>>16;if(Q<<16>>16<0){Q=R-k|0;P=X>>>0>Q>>>0?Q:X;Q=Y+(P>>>3)|0;q=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(P&7)>>>((S+32|0)>>>0))+(l<<16>>16)|0;ba=b[V+(q<<2)+2>>1]|0;ca=b[V+(q<<2)>>1]&255;da=P;break}else{ba=S;ca=l&255;da=R;break}}else{ba=k;ca=U&255;da=j}}while(0);j=ba+da|0;c[p>>2]=X>>>0>j>>>0?j:X;j=O<<2;U=j|1;a[(c[aa>>2]|0)+U|0]=ca;k=c[n>>2]|0;V=c[p>>2]|0;Y=c[$>>2]|0;T=c[N>>2]|0;v=T+(V>>>3)|0;R=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(V&7)>>>21;v=b[k+(R<<2)>>1]|0;l=b[k+(R<<2)+2>>1]|0;R=l<<16>>16;do{if(l<<16>>16<0){S=V+11|0;P=Y>>>0>S>>>0?S:Y;S=T+(P>>>3)|0;q=((je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(P&7)>>>((R+32|0)>>>0))+v|0;S=b[k+(q<<2)>>1]|0;Q=b[k+(q<<2)+2>>1]|0;q=Q<<16>>16;if(!(Q<<16>>16<0)){ea=q;fa=S;ga=P;break}Q=P-R|0;P=Y>>>0>Q>>>0?Q:Y;Q=T+(P>>>3)|0;J=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(P&7)>>>((q+32|0)>>>0))+S|0;ea=b[k+(J<<2)+2>>1]|0;fa=b[k+(J<<2)>>1]|0;ga=P}else{ea=R;fa=v;ga=V}}while(0);V=ea+ga|0;c[p>>2]=Y>>>0>V>>>0?V:Y;V=c[aa>>2]|0;a[V+j|0]=(d[V+U|0]|0)+fa;V=c[Z>>2]|0;v=c[p>>2]|0;R=c[$>>2]|0;k=c[N>>2]|0;T=k+(v>>>3)|0;l=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(v&7)>>>21;T=b[V+(l<<2)>>1]|0;X=b[V+(l<<2)+2>>1]|0;l=X<<16>>16;do{if(X<<16>>16<0){P=v+11|0;J=R>>>0>P>>>0?P:R;P=k+(J>>>3)|0;S=((je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(J&7)>>>((l+32|0)>>>0))+T|0;P=b[V+(S<<2)>>1]|0;q=b[V+(S<<2)+2>>1]|0;S=q<<16>>16;if(!(q<<16>>16<0)){ha=S;ia=P;ja=J;break}q=J-l|0;J=R>>>0>q>>>0?q:R;q=k+(J>>>3)|0;Q=((je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(J&7)>>>((S+32|0)>>>0))+P|0;ha=b[V+(Q<<2)+2>>1]|0;ia=b[V+(Q<<2)>>1]|0;ja=J}else{ha=l;ia=T;ja=v}}while(0);v=ha+ja|0;c[p>>2]=R>>>0>v>>>0?v:R;v=c[aa>>2]|0;a[v+(j|2)|0]=(d[v+U|0]|0)+ia}else{c[(c[aa>>2]|0)+(O<<2)>>2]=c[e+852128+(W<<16>>16<<2)>>2]}O=O+1|0;}while((O|0)<(f|0));return}if(!h){return}h=e+860404|0;O=e+16|0;aa=e+24|0;ia=e+8|0;p=e+860324|0;ja=e+132|0;ha=e+860344|0;N=e+860364|0;$=0;do{Z=c[h>>2]|0;fa=c[O>>2]|0;ga=c[aa>>2]|0;ea=c[ia>>2]|0;n=ea+(fa>>>3)|0;ca=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(fa&7)>>>21;n=b[Z+(ca<<2)>>1]|0;da=(b[Z+(ca<<2)+2>>1]|0)+fa|0;fa=ga>>>0>da>>>0?da:ga;c[O>>2]=fa;if(n<<16>>16==-1){da=c[ha>>2]|0;ca=ea+(fa>>>3)|0;Z=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(fa&7)>>>21;ca=b[da+(Z<<2)>>1]|0;ba=b[da+(Z<<2)+2>>1]|0;Z=ba<<16>>16;do{if(ba<<16>>16<0){_=fa+11|0;g=ga>>>0>_>>>0?_:ga;_=ea+(g>>>3)|0;v=((je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(g&7)>>>((Z+32|0)>>>0))+(ca<<16>>16)|0;_=b[da+(v<<2)>>1]|0;T=b[da+(v<<2)+2>>1]|0;v=T<<16>>16;if(T<<16>>16<0){T=g-Z|0;l=ga>>>0>T>>>0?T:ga;T=ea+(l>>>3)|0;V=((je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(l&7)>>>((v+32|0)>>>0))+(_<<16>>16)|0;ka=b[da+(V<<2)+2>>1]|0;la=b[da+(V<<2)>>1]&255;ma=l;break}else{ka=v;la=_&255;ma=g;break}}else{ka=Z;la=ca&255;ma=fa}}while(0);fa=ka+ma|0;c[O>>2]=ga>>>0>fa>>>0?fa:ga;fa=$<<2;ca=fa|1;a[(c[ja>>2]|0)+ca|0]=la;Z=c[p>>2]|0;da=c[O>>2]|0;ba=c[aa>>2]|0;W=c[ia>>2]|0;U=W+(da>>>3)|0;j=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(da&7)>>>21;U=b[Z+(j<<2)>>1]|0;R=b[Z+(j<<2)+2>>1]|0;j=R<<16>>16;do{if(R<<16>>16<0){g=da+11|0;_=ba>>>0>g>>>0?g:ba;g=W+(_>>>3)|0;v=((je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(_&7)>>>((j+32|0)>>>0))+U|0;g=b[Z+(v<<2)>>1]|0;l=b[Z+(v<<2)+2>>1]|0;v=l<<16>>16;if(!(l<<16>>16<0)){na=v;oa=g;pa=_;break}l=_-j|0;_=ba>>>0>l>>>0?l:ba;l=W+(_>>>3)|0;V=((je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(_&7)>>>((v+32|0)>>>0))+g|0;na=b[Z+(V<<2)+2>>1]|0;oa=b[Z+(V<<2)>>1]|0;pa=_}else{na=j;oa=U;pa=da}}while(0);da=na+pa|0;c[O>>2]=ba>>>0>da>>>0?da:ba;da=c[ja>>2]|0;a[da+fa|0]=(d[da+ca|0]|0)+oa;da=c[N>>2]|0;U=c[O>>2]|0;j=c[aa>>2]|0;Z=c[ia>>2]|0;W=Z+(U>>>3)|0;R=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(U&7)>>>21;W=b[da+(R<<2)>>1]|0;ga=b[da+(R<<2)+2>>1]|0;R=ga<<16>>16;do{if(ga<<16>>16<0){_=U+11|0;V=j>>>0>_>>>0?_:j;_=Z+(V>>>3)|0;g=((je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(V&7)>>>((R+32|0)>>>0))+W|0;_=b[da+(g<<2)>>1]|0;v=b[da+(g<<2)+2>>1]|0;g=v<<16>>16;if(!(v<<16>>16<0)){qa=g;ra=_;sa=V;break}v=V-R|0;V=j>>>0>v>>>0?v:j;v=Z+(V>>>3)|0;l=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(V&7)>>>((g+32|0)>>>0))+_|0;qa=b[da+(l<<2)+2>>1]|0;ra=b[da+(l<<2)>>1]|0;sa=V}else{qa=R;ra=W;sa=U}}while(0);U=qa+sa|0;c[O>>2]=j>>>0>U>>>0?U:j;U=c[ja>>2]|0;a[U+(fa|2)|0]=(d[U+ca|0]|0)+ra;ta=c[ia>>2]|0}else{c[(c[ja>>2]|0)+($<<2)>>2]=c[e+852128+(n<<16>>16<<2)>>2];ta=ea}U=c[N>>2]|0;W=c[O>>2]|0;R=c[aa>>2]|0;da=ta+(W>>>3)|0;Z=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(W&7)>>>21;da=b[U+(Z<<2)>>1]|0;ga=b[U+(Z<<2)+2>>1]|0;Z=ga<<16>>16;do{if(ga<<16>>16<0){ba=W+11|0;V=R>>>0>ba>>>0?ba:R;ba=ta+(V>>>3)|0;l=((je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(V&7)>>>((Z+32|0)>>>0))+(da<<16>>16)|0;ba=b[U+(l<<2)>>1]|0;_=b[U+(l<<2)+2>>1]|0;l=_<<16>>16;if(_<<16>>16<0){_=V-Z|0;g=R>>>0>_>>>0?_:R;_=ta+(g>>>3)|0;v=((je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(g&7)>>>((l+32|0)>>>0))+(ba<<16>>16)|0;ua=b[U+(v<<2)+2>>1]|0;va=b[U+(v<<2)>>1]&255;wa=g;break}else{ua=l;va=ba&255;wa=V;break}}else{ua=Z;va=da&255;wa=W}}while(0);W=ua+wa|0;c[O>>2]=R>>>0>W>>>0?W:R;a[(c[ja>>2]|0)+($<<2|3)|0]=va;$=$+1|0;}while(($|0)<(f|0));return}}function _Ka(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;if((e|0)<=0){g=0;i=f;return g|0}h=b+8|0;j=b+16|0;k=b|0;l=b+12|0;b=0;while(1){m=c[h>>2]|0;n=c[j>>2]|0;o=c[k>>2]|0;p=o+(m>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>29;p=m+3|0;m=n>>>0>p>>>0?p:n;c[h>>2]=m;p=o+(m>>>3)|0;r=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>27;p=m+5|0;m=n>>>0>p>>>0?p:n;c[h>>2]=m;if((q|0)==0){p=o+(m>>>3)|0;o=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>24;p=m+8|0;s=n>>>0>p>>>0?p:n;c[h>>2]=s;t=o;u=s}else{t=q;u=m}m=t+b|0;if((m|0)>(e|0)){break}if(((c[l>>2]|0)-u|0)<0){break}if((t|0)==0){v=b}else{mrc(a+b|0,r&255|0,t|0)|0;v=m}if((v|0)<(e|0)){b=v}else{g=0;w=11;break}}if((w|0)==11){i=f;return g|0}KIb(0,16,2639600,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;g=-1;i=f;return g|0}function $Ka(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=i;i=i+10240|0;f=e|0;g=e+4096|0;h=e+8192|0;j=d+64|0;do{if((c[d+60>>2]|0)<24){k=3}else{if((c[j>>2]|0)>2){k=3;break}l=d+56|0;m=c[l>>2]|0;n=(m|0)==0|0;o=-16;p=0;a:while(1){q=o&255;r=a[d+524448+(m<<14)+q|0]|0;s=11-(r&255)|0;if((s|0)<2|r<<24>>24==0){t=p}else{u=d+589984+(m<<16)+(q<<2)|0;q=o&255;v=-16;w=p;while(1){x=v&255;y=a[d+524448+(n<<14)+x|0]|0;z=y&255;A=s-z|0;if((A|0)<1|y<<24>>24==0){B=w}else{C=(c[u>>2]<<z)+(c[d+589984+(n<<16)+(x<<2)>>2]|0)|0;x=y+r&255;y=v&255;z=v+o&255;D=-16;E=w;while(1){F=D&255;G=a[d+557216+F|0]|0;H=G&255;if((H|0)<=(A|0)&G<<24>>24!=0){if((E|0)>=2048){k=24;break a}a[h+E|0]=x+G;b[g+(E<<1)>>1]=(c[d+721056+(F<<2)>>2]|0)+(C<<H);H=d+852128+(E<<2)|0;F=H;if((c[l>>2]|0)==0){a[H]=q;a[F+1|0]=y;a[F+2|0]=D}else{a[F+1|0]=q;a[H]=z;a[F+2|0]=D+o}I=E+1|0}else{I=E}F=D+1|0;if((F|0)<16){D=F;E=I}else{B=I;break}}}E=v+1|0;if((E|0)<16){v=E;w=B}else{t=B;break}}}w=o+1|0;if((w|0)<16){o=w;p=t}else{break}}if((k|0)==24){KIb(0,0,2173136,(J=i,i=i+24|0,c[J>>2]=2145776,c[J+8>>2]=2121968,c[J+16>>2]=172,J)|0);i=J;Hd();return 0}p=d+860400|0;c3(p);o=$2(p,11,t,h|0,1,1,g,2,2,0,0,0,0)|0;if((o|0)<0){K=o}else{break}i=e;return K|0}}while(0);b:do{if((k|0)==3){t=d+84|0;B=h|0;I=g;o=f;p=0;c:while(1){if((p|0)>=4){break b}l=(c[j>>2]|0)>2?p:0;n=c[t>>2]|0;if((n|0)>0){m=0;w=0;while(1){v=a[d+524448+(l<<14)+m|0]|0;q=11-(v&255)|0;do{if((q|0)<1|v<<24>>24==0){L=w}else{r=n-1|0;if((r&m<<24>>24|0)!=(m|0)){L=w;break}u=d+589984+(l<<16)+(m<<2)|0;s=m<<8;E=0;D=w;while(1){z=a[d+524448+(p<<14)+E|0]|0;y=z&255;do{if((y|0)<=(q|0)&z<<24>>24!=0){if((r&E<<24>>24|0)!=(E|0)){M=D;break}if((D|0)>=2048){k=12;break c}a[h+D|0]=z+v;b[g+(D<<1)>>1]=(c[u>>2]<<y)+(c[d+589984+(p<<16)+(E<<2)>>2]|0);C=E&255|s;b[f+(D<<1)>>1]=C;M=((C&65535|0)!=65535)+D|0}else{M=D}}while(0);y=E+1|0;if((y|0)<(n|0)){E=y;D=M}else{L=M;break}}}}while(0);v=m+1|0;if((v|0)<(n|0)){m=v;w=L}else{N=L;break}}}else{N=0}w=d+860320+((p+4|0)*20|0)|0;c3(w);m=$2(w,11,N,B,1,1,I,2,2,o,2,2,0)|0;if((m|0)<0){K=m;k=34;break}else{p=p+1|0}}if((k|0)==12){KIb(0,0,2173136,(J=i,i=i+24|0,c[J>>2]=2145776,c[J+8>>2]=2121968,c[J+16>>2]=136,J)|0);i=J;Hd();return 0}else if((k|0)==34){i=e;return K|0}}}while(0);K=0;i=e;return K|0}function aLa(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;f=i;i=i+8|0;g=f|0;h=c[b+60>>2]|0;j=h;k=b+140|0;l=qKb(c[k>>2]|0)|0;Ypb(b);m=pJb(196612)|0;n=b+96|0;c[n>>2]=m;if((m|0)==0){o=-12;i=f;return o|0}m=h+116|0;do{if((c[m>>2]&512|0)!=0){p=pJb(4128772)|0;c[b+668>>2]=p;if((p|0)==0){o=-12}else{break}i=f;return o|0}}while(0);p=h+64|0;c[p>>2]=2;q=UHb()|0;c[b+804>>2]=q;if((q|0)==0){o=-12;i=f;return o|0}c[q+88>>2]=1;c[q+84>>2]=1;q=h+76|0;c[q>>2]=((e[l+8>>1]|0)>>>11&15)+1;r=l+7|0;s=l+4|0;if((a[r]&32)==0){t=(d[s]|0)>>>0>1>>>0|0}else{t=0}l=h+96|0;c[l>>2]=t;t=h+92|0;c[t>>2]=(d[s]|0)>>>0>2>>>0;s=h+88|0;c[s>>2]=(d[r]|0)>>>7&255;u=h+100|0;v=h+104|0;tKb(c[k>>2]|0,u,v)|0;w=c[k>>2]|0;a:do{switch(w|0){case 30:{c[h+60>>2]=32;x=32;break};case 2:{c[h+60>>2]=24;x=24;break};case 5:case 6:case 7:case 33:case 82:case 84:case 86:case 314:case 316:case 88:case 8:case 32:case 299:case 35:case 300:case 317:case 66:case 70:case 72:case 302:case 304:case 54:case 80:case 74:case 306:case 308:case 56:case 76:case 78:case 310:case 312:case 58:case 92:case 98:case 104:case 94:case 100:case 106:case 96:case 102:case 108:{c[p>>2]=3;x=c[h+60>>2]|0;break};case 0:case 4:{if((c[h+108>>2]&1|0)==0){k=(w|0)==0?12:16;c[h+60>>2]=k;x=k;break a}KIb(b,16,2589608,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0};default:{KIb(b,16,2567944,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}}}while(0);k=1<<c[q>>2];c[h+80>>2]=k;z=h+84|0;c[z>>2]=(k|0)>16384?16384:k;k=h+60|0;c[b+792>>2]=x;do{if((c[k>>2]|0)>23){if((c[l>>2]|0)!=0){A=0;break}A=((d[r]|0)>>>4&1^1)&255}else{A=0}}while(0);r=h+56|0;c[r>>2]=A;A=h+4|0;c[A>>2]=c[b+216>>2];x=(c[b+88>>2]|0)>>>29;B=h+52|0;c[B>>2]=x&1;C=b+572|0;D=h+120|0;do{if((c[C>>2]|0)==1){c[D>>2]=1;if((c[m>>2]&1536|0)==0){break}KIb(b,16,2549872,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}else{c[D>>2]=0}}while(0);do{if((c[(c[b+12>>2]|0)+12>>2]|0)==26){if((w|0)==0){KIb(b,16,2531760,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}if((c[C>>2]|0)!=0){KIb(b,16,2516504,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}if((c[p>>2]|0)>2){KIb(b,16,2502576,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}else{if(!((c[h+112>>2]|0)>288^(x&1|0)!=0)){break}KIb(b,32,2489496,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;break}}}while(0);x=c[p>>2]|0;do{if((x|0)>2){if(!((c[b+680>>2]|0)>-2)){break}KIb(b,16,2478456,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}}while(0);C=c[A>>2]|0;do{if((c[k>>2]|0)>23&(C|0)==2){if((x|0)>=3){E=2;break}KIb(b,16,2468888,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;o=-22;i=f;return o|0}else{E=C}}while(0);a[c[n>>2]|0]=c[r>>2]<<6|E;a[(c[n>>2]|0)+2|0]=(c[B>>2]|0)!=0?16:32;if((c[D>>2]|0)!=0){B=(c[n>>2]|0)+2|0;a[B]=a[B]|64}if((c[p>>2]|0)<3){a[(c[n>>2]|0)+1|0]=c[k>>2];a[(c[n>>2]|0)+3|0]=0}else{a[(c[n>>2]|0)+1|0]=(c[q>>2]<<4)+240|c[u>>2]|c[v>>2]<<2;if((c[t>>2]|0)!=0){t=(c[n>>2]|0)+2|0;a[t]=a[t]|((c[l>>2]|0)!=0?1:2)}if((c[s>>2]|0)!=0){s=(c[n>>2]|0)+2|0;a[s]=a[s]|4}a[(c[n>>2]|0)+3|0]=1}n=h;c[(c[n>>2]|0)+100>>2]=4;s=c[b+672>>2]|0;b=h+160|0;l=c[z>>2]|0;t=(l|0)>0;b:do{if((s|0)==0){if(t){F=0;H=l}else{break}do{v=H-F|0;u=1e8/(((F|0)>(v|0)?v:F)+1|0)|0;v=b+(F<<3)|0;c[v>>2]=u;c[v+4>>2]=(u|0)<0|0?-1:0;F=F+1|0;H=c[z>>2]|0;}while((F|0)<(H|0));if((H|0)>0){I=0;J=H}else{break}do{u=J-I|0;v=1e8/(((I|0)>(u|0)?u:I)+1|0)|0;u=b+131072+(I<<3)|0;c[u>>2]=v;c[u+4>>2]=(v|0)<0|0?-1:0;I=I+1|0;J=c[z>>2]|0;}while((I|0)<(J|0));if((J|0)>0){K=0;L=J}else{break}do{v=L-K|0;u=1e8/(((K|0)>(v|0)?v:K)+1|0)|0;v=b+262144+(K<<3)|0;c[v>>2]=u;c[v+4>>2]=(u|0)<0|0?-1:0;K=K+1|0;L=c[z>>2]|0;}while((K|0)<(L|0));if((L|0)>0){M=0;N=L}else{break}do{u=N-M|0;v=1e8/(((M|0)>(u|0)?u:M)+1|0)|0;u=b+393216+(M<<3)|0;c[u>>2]=v;c[u+4>>2]=(v|0)<0|0?-1:0;M=M+1|0;N=c[z>>2]|0;}while((M|0)<(N|0))}else{do{if(t){v=0;do{u=b+(v<<3)|0;c[u>>2]=1;c[u+4>>2]=0;v=v+1|0;O=c[z>>2]|0;}while((v|0)<(O|0));if((O|0)>0){P=0}else{Q=0;R=s;S=O;break}do{v=b+131072+(P<<3)|0;c[v>>2]=1;c[v+4>>2]=0;P=P+1|0;T=c[z>>2]|0;}while((P|0)<(T|0));if((T|0)>0){U=0}else{Q=0;R=s;S=T;break}do{v=b+262144+(U<<3)|0;c[v>>2]=1;c[v+4>>2]=0;U=U+1|0;V=c[z>>2]|0;}while((U|0)<(V|0));if((V|0)>0){W=0}else{Q=0;R=s;S=V;break}while(1){v=b+393216+(W<<3)|0;c[v>>2]=1;c[v+4>>2]=0;v=W+1|0;u=c[z>>2]|0;if((v|0)<(u|0)){W=v}else{Q=0;R=s;S=u;break}}}else{Q=0;R=s;S=l}}while(0);c:while(1){u=R+1|0;v=R+2|0;q=Q;while(1){if((q|0)<4){X=0;Y=R;Z=S;break}if((a[R]|0)==0){break b}if((a[u]|0)==0){break b}if((a[v]|0)==0){break b}else{q=0}}while(1){if((X|0)>=(Z|0)){break}v=rb(Y|0,g|0,0)|0;u=b+(q<<17)+(X<<3)|0;k=wrc(c[u>>2]|0,c[u+4>>2]|0,v,(v|0)<0|0?-1:0)|0;c[u>>2]=k;c[u+4>>2]=G;u=c[g>>2]|0;if((u|0)==(Y|0)){o=-1;break c}X=X+1|0;Y=u;Z=c[z>>2]|0}Q=q+1|0;R=Y;S=Z}i=f;return o|0}}while(0);Z=c[n>>2]|0;S=dLa(j,(c[Z+96>>2]|0)+(c[Z+100>>2]|0)|0)|0;if((S|0)<0){o=S;i=f;return o|0}Z=(c[n>>2]|0)+100|0;c[Z>>2]=(c[Z>>2]|0)+S;do{if((c[D>>2]|0)==0){S=h+160|0;if((c[z>>2]|0)>0){_=0}else{break}do{Z=S+(_<<3)|0;c[Z>>2]=0;c[Z+4>>2]=0;_=_+1|0;$=c[z>>2]|0;}while((_|0)<($|0));if(($|0)>0){aa=0}else{break}do{Z=S+131072+(aa<<3)|0;c[Z>>2]=0;c[Z+4>>2]=0;aa=aa+1|0;ba=c[z>>2]|0;}while((aa|0)<(ba|0));if((ba|0)>0){da=0}else{break}do{Z=S+262144+(da<<3)|0;c[Z>>2]=0;c[Z+4>>2]=0;da=da+1|0;ea=c[z>>2]|0;}while((da|0)<(ea|0));if((ea|0)>0){fa=0}else{break}do{Z=S+393216+(fa<<3)|0;c[Z>>2]=0;c[Z+4>>2]=0;fa=fa+1|0;}while((fa|0)<(c[z>>2]|0))}else{S=h+108|0;Z=h+112|0;n=h+160|0;Y=(ca(c[Z>>2]|0,c[S>>2]|0)|0)/10|0;R=c[z>>2]|0;if((R|0)>0){ga=0;ha=R}else{break}do{R=ha-ga|0;Q=(Y|0)/(((ga|0)>(R|0)?R:ga)+1|0)|0;R=n+(ga<<3)|0;c[R>>2]=Q;c[R+4>>2]=(Q|0)<0|0?-1:0;ga=ga+1|0;ha=c[z>>2]|0;}while((ga|0)<(ha|0));Y=(ca(c[Z>>2]|0,c[S>>2]|0)|0)/40|0;if((ha|0)>0){ia=0;ja=ha}else{break}do{Q=ja-ia|0;R=(Y|0)/(((ia|0)>(Q|0)?Q:ia)+1|0)|0;Q=n+131072+(ia<<3)|0;c[Q>>2]=R;c[Q+4>>2]=(R|0)<0|0?-1:0;ia=ia+1|0;ja=c[z>>2]|0;}while((ia|0)<(ja|0));Y=(ca(c[Z>>2]|0,c[S>>2]|0)|0)/40|0;if((ja|0)>0){ka=0;la=ja}else{break}do{R=la-ka|0;Q=(Y|0)/(((ka|0)>(R|0)?R:ka)+1|0)|0;R=n+262144+(ka<<3)|0;c[R>>2]=Q;c[R+4>>2]=(Q|0)<0|0?-1:0;ka=ka+1|0;la=c[z>>2]|0;}while((ka|0)<(la|0));Y=(ca(c[Z>>2]|0,c[S>>2]|0)|0)/40|0;if((la|0)>0){ma=0;na=la}else{break}do{Q=na-ma|0;R=(Y|0)/(((ma|0)>(Q|0)?Q:ma)+1|0)|0;Q=n+393216+(ma<<3)|0;c[Q>>2]=R;c[Q+4>>2]=(R|0)<0|0?-1:0;ma=ma+1|0;na=c[z>>2]|0;}while((ma|0)<(na|0))}}while(0);if((Xpb(j)|0)==0){c[h+124>>2]=0;o=0;i=f;return o|0}else{Zpb(j);o=-12;i=f;return o|0}return 0}function bLa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0;j=i;i=i+64|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;r=j+56|0;s=c[e+60>>2]|0;t=s;u=c[s+108>>2]|0;v=u>>1;w=s+112|0;x=c[w>>2]|0;z=s+52|0;A=g+32|0;B=(c[z>>2]|0)!=0|0;C=c[A>>2]<<B;D=g+36|0;E=c[D>>2]<<B;F=g+40|0;G=c[F>>2]<<B;B=(ca(u*12|0,x)|0)+16384|0;H=d5a(e,f,B,(B|0)<0|0?-1:0)|0;if((H|0)<0){I=H;i=j;return I|0}H=f+24|0;do{if((c[s+120>>2]|0)==0){J=0}else{B=dLa(t,c[H>>2]|0)|0;if((B|0)<0){I=B;i=j;return I|0}K=s+84|0;L=s+160|0;if((c[K>>2]|0)>0){M=0}else{J=B;break}do{N=L+(M<<3)|0;O=c[N+4>>2]|0;c[N>>2]=(c[N>>2]|0)>>>1|O<<31;c[N+4>>2]=O>>>1|0<<31;M=M+1|0;P=c[K>>2]|0;}while((M|0)<(P|0));if((P|0)>0){Q=0}else{J=B;break}do{O=L+131072+(Q<<3)|0;N=c[O+4>>2]|0;c[O>>2]=(c[O>>2]|0)>>>1|N<<31;c[O+4>>2]=N>>>1|0<<31;Q=Q+1|0;R=c[K>>2]|0;}while((Q|0)<(R|0));if((R|0)>0){S=0}else{J=B;break}do{N=L+262144+(S<<3)|0;O=c[N+4>>2]|0;c[N>>2]=(c[N>>2]|0)>>>1|O<<31;c[N+4>>2]=O>>>1|0<<31;S=S+1|0;T=c[K>>2]|0;}while((S|0)<(T|0));if((T|0)>0){U=0}else{J=B;break}while(1){O=L+393216+(U<<3)|0;N=c[O+4>>2]|0;c[O>>2]=(c[O>>2]|0)>>>1|N<<31;c[O+4>>2]=N>>>1|0<<31;N=U+1|0;if((N|0)<(c[K>>2]|0)){U=N}else{J=B;break}}}}while(0);U=f+28|0;T=(c[U>>2]|0)-J|0;S=(T|0)<0;R=S?0:(c[H>>2]|0)+J|0;Q=S?0:T;c[s+48>>2]=Q<<3;T=s+36|0;c[T>>2]=R;c[s+44>>2]=R+Q;Q=s+40|0;c[Q>>2]=R;S=s+32|0;c[S>>2]=32;P=s+28|0;c[P>>2]=0;M=c[e+140>>2]|0;a:do{if((M|0)==4|(M|0)==0){B=g+8|0;K=d[c[B>>2]|0]|0;c[m>>2]=K;L=c[P>>2]|0;N=c[S>>2]|0;if((N|0)>8){V=N-8|0;W=L<<8|K;X=R}else{O=R;y=je(K>>>((8-N|0)>>>0)|L<<N|0)|0;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;O=(c[Q>>2]|0)+4|0;c[Q>>2]=O;V=N+24|0;W=K;X=O}c[P>>2]=W;c[S>>2]=V;O=g|0;K=d[(c[O>>2]|0)+1|0]|0;c[k>>2]=K;N=c[P>>2]|0;L=c[S>>2]|0;if((L|0)>8){Y=L-8|0;Z=N<<8|K;_=X}else{$=X;y=je(K>>>((8-L|0)>>>0)|N<<L|0)|0;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;$=(c[Q>>2]|0)+4|0;c[Q>>2]=$;Y=L+24|0;Z=K;_=$}c[P>>2]=Z;c[S>>2]=Y;$=g+4|0;K=d[c[$>>2]|0]|0;c[l>>2]=K;L=c[P>>2]|0;N=c[S>>2]|0;if((N|0)>8){aa=N-8|0;ba=L<<8|K;da=_}else{ea=_;y=je(K>>>((8-N|0)>>>0)|L<<N|0)|0;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;ea=(c[Q>>2]|0)+4|0;c[Q>>2]=ea;aa=N+24|0;ba=K;da=ea}c[P>>2]=ba;c[S>>2]=aa;ea=c[O>>2]|0;K=d[ea]|0;if((aa|0)>8){fa=aa-8|0;ga=ba<<8|K;ha=ea}else{ea=da;y=je(K>>>((8-aa|0)>>>0)|ba<<aa|0)|0;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;fa=aa+24|0;ga=K;ha=c[O>>2]|0}c[P>>2]=ga;c[S>>2]=fa;K=s+132|0;c[k>>2]=eLa(t,c[K>>2]|0,ha,u,0)|0;ea=s+136|0;c[l>>2]=eLa(t,c[ea>>2]|0,c[$>>2]|0,v,0)|0;N=s+140|0;c[m>>2]=eLa(t,c[N>>2]|0,c[B>>2]|0,v,0)|0;fLa(t,2,u-2|0);L=s+4|0;if((c[L>>2]|0)!=2){if((x|0)<=1){break}ia=s+60|0;ja=s+861564|0;ka=1;la=1;while(1){if((c[ia>>2]|0)==12){ma=c[O>>2]|0;na=ca(c[A>>2]|0,la)|0;oa=ma+na|0;do{if((c[L>>2]|0)==1){if((c[z>>2]|0)>=(la|0)){pa=45;break}mf[c[ja>>2]&2047](c[ea>>2]|0,oa,ma+(na-C)|0,u);qa=eLa(t,c[K>>2]|0,c[ea>>2]|0,u,c[k>>2]|0)|0}else{pa=45}}while(0);if((pa|0)==45){pa=0;qa=eLa(t,c[K>>2]|0,oa,u,c[k>>2]|0)|0}c[k>>2]=qa;gLa(t,u);na=la+1|0;if((na|0)<(x|0)){ra=na}else{break a}}else{ra=la}na=c[O>>2]|0;ma=ca(c[A>>2]|0,ra)|0;sa=na+ma|0;ta=c[$>>2]|0;ua=ca(c[D>>2]|0,ka)|0;va=ta+ua|0;wa=c[B>>2]|0;xa=ca(c[F>>2]|0,ka)|0;ya=wa+xa|0;do{if((c[L>>2]|0)==1){if((c[z>>2]|0)>=(ka|0)){pa=50;break}mf[c[ja>>2]&2047](c[ea>>2]|0,sa,na+(ma-C)|0,u);mf[c[ja>>2]&2047](c[N>>2]|0,va,ta+(ua-E)|0,v);mf[c[ja>>2]&2047]((c[N>>2]|0)+v|0,ya,wa+(xa-G)|0,v);c[k>>2]=eLa(t,c[K>>2]|0,c[ea>>2]|0,u,c[k>>2]|0)|0;c[l>>2]=eLa(t,c[ea>>2]|0,c[N>>2]|0,v,c[l>>2]|0)|0;za=c[N>>2]|0;Aa=eLa(t,za,za+v|0,v,c[m>>2]|0)|0}else{pa=50}}while(0);if((pa|0)==50){pa=0;c[k>>2]=eLa(t,c[K>>2]|0,sa,u,c[k>>2]|0)|0;c[l>>2]=eLa(t,c[ea>>2]|0,va,v,c[l>>2]|0)|0;Aa=eLa(t,c[N>>2]|0,ya,v,c[m>>2]|0)|0}c[m>>2]=Aa;fLa(t,0,u);xa=ra+1|0;if((xa|0)<(x|0)){ka=ka+1|0;la=xa}else{break a}}}if((c[z>>2]|0)==0){Ba=2}else{c[k>>2]=eLa(t,c[K>>2]|0,(c[O>>2]|0)+(c[A>>2]|0)|0,u,c[k>>2]|0)|0;c[l>>2]=eLa(t,c[ea>>2]|0,(c[$>>2]|0)+(c[D>>2]|0)|0,v,c[l>>2]|0)|0;c[m>>2]=eLa(t,c[N>>2]|0,(c[B>>2]|0)+(c[F>>2]|0)|0,v,c[m>>2]|0)|0;fLa(t,0,u);Ba=3}la=c[K>>2]|0;ka=c[O>>2]|0;ja=c[k>>2]|0;L=s+76|0;ia=ka+C|0;if((c[L>>2]|0)<9){xa=a[ia]|0;a[la]=(xa&255)-ja;wa=a[ka+(C+1)|0]|0;a[la+1|0]=wa-xa;xa=a[ka+(C+2)|0]|0;a[la+2|0]=xa-wa;wa=a[ka+(C+3)|0]|0;a[la+3|0]=wa-xa;Ca=wa&255}else{wa=b[ia>>1]|0;b[la>>1]=(wa&65535)-ja;ja=b[ka+(C+2)>>1]|0;b[la+2>>1]=ja-wa;wa=b[ka+(C+4)>>1]|0;b[la+4>>1]=wa-ja;ja=b[ka+(C+6)>>1]|0;b[la+6>>1]=ja-wa;Ca=ja&65535}c[k>>2]=Ca;ja=c[ea>>2]|0;wa=c[$>>2]|0;la=c[l>>2]|0;ka=wa+E|0;if((c[L>>2]|0)<9){ia=a[ka]|0;a[ja]=(ia&255)-la;xa=a[wa+(E+1)|0]|0;a[ja+1|0]=xa-ia;Da=xa&255}else{xa=b[ka>>1]|0;b[ja>>1]=(xa&65535)-la;la=b[wa+(E+2)>>1]|0;b[ja+2>>1]=la-xa;Da=la&65535}c[l>>2]=Da;la=c[N>>2]|0;xa=c[B>>2]|0;ja=c[m>>2]|0;wa=xa+G|0;if((c[L>>2]|0)<9){L=a[wa]|0;a[la]=(L&255)-ja;ka=a[xa+(G+1)|0]|0;a[la+1|0]=ka-L;Ea=ka&255}else{ka=b[wa>>1]|0;b[la>>1]=(ka&65535)-ja;ja=b[xa+(G+2)>>1]|0;b[la+2>>1]=ja-ka;Ea=ja&65535}c[m>>2]=Ea;fLa(t,0,4);ja=c[O>>2]|0;c[n>>2]=d[ja+3|0]|0;c[o>>2]=d[(c[$>>2]|0)+1|0]|0;c[p>>2]=d[(c[B>>2]|0)+1|0]|0;ka=s+861568|0;la=u-4|0;_e[c[ka>>2]&511](c[K>>2]|0,ja+4|0,ja+(C+4)|0,la,k,n);ja=c[$>>2]|0;xa=v-2|0;_e[c[ka>>2]&511](c[ea>>2]|0,ja+2|0,ja+(E+2)|0,xa,l,o);ja=c[B>>2]|0;_e[c[ka>>2]&511](c[N>>2]|0,ja+2|0,ja+(G+2)|0,xa,m,p);fLa(t,0,la);if((Ba|0)>=(x|0)){break}la=s+60|0;xa=Ba;ja=Ba;wa=Ba<<1;while(1){if((c[la>>2]|0)==12){L=xa<<1;if((L|0)>(ja|0)){ia=ja;while(1){ua=c[O>>2]|0;ta=ca(c[A>>2]|0,ia)|0;_e[c[ka>>2]&511](c[K>>2]|0,ua+(ta-C)|0,ua+ta|0,u,k,n);gLa(t,u);ta=ia+1|0;if((L|0)>(ta|0)){ia=ta}else{Fa=wa;break}}}else{Fa=ja}if((Fa|0)<(x|0)){Ga=Fa}else{break a}}else{Ga=ja}ia=c[O>>2]|0;L=ca(c[A>>2]|0,Ga)|0;ya=c[$>>2]|0;va=ca(c[D>>2]|0,xa)|0;sa=c[B>>2]|0;ta=ca(c[F>>2]|0,xa)|0;_e[c[ka>>2]&511](c[K>>2]|0,ia+(L-C)|0,ia+L|0,u,k,n);_e[c[ka>>2]&511](c[ea>>2]|0,ya+(va-E)|0,ya+va|0,v,l,o);_e[c[ka>>2]&511](c[N>>2]|0,sa+(ta-G)|0,sa+ta|0,v,m,p);fLa(t,0,u);ta=Ga+1|0;if((ta|0)<(x|0)){xa=xa+1|0;ja=ta;wa=wa+2|0}else{break}}}else if((M|0)==30){wa=c[g>>2]|0;ja=c[A>>2]|0;xa=ca(ja,x-1|0)|0;N=a[wa+(xa+3)|0]|0;ka=N&255;c[P>>2]=ka;c[S>>2]=24;ea=a[wa+(xa+2)|0]|0;K=ka<<8|ea&255;c[P>>2]=K;c[S>>2]=16;ka=a[wa+(xa+1)|0]|0;B=K<<8|ka&255;c[P>>2]=B;c[S>>2]=8;K=a[wa+xa|0]|0;$=K&255;O=R;y=je($|B<<8|0)|0;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;c[P>>2]=$;c[S>>2]=32;$=s+132|0;O=c[$>>2]|0;B=xa+4|0;la=u-1|0;ta=(la|0)>4?4:la;if((ta|0)>0){sa=N;N=K;K=ka;ka=ea;ea=0;while(1){va=ea<<2;ya=va|2;L=a[wa+(ya+B)|0]|0;ia=va|1;ua=a[wa+(ia+B)|0]|0;ma=a[wa+(va+B)|0]|0;na=va|3;oa=a[wa+(na+B)|0]|0;a[O+ya|0]=L-ka;a[O+ia|0]=ua-K;a[O+va|0]=ma-N;a[O+na|0]=oa-sa;na=ea+1|0;if((na|0)<(ta|0)){sa=oa;N=ma;K=ua;ka=L;ea=na}else{break}}}ea=s+861564|0;ka=la<<2;mf[c[ea>>2]&2047](O+16|0,wa+(xa+20)|0,wa+(xa+16)|0,ka-16|0);K=a[wa+(ka-2+B)|0]|0;N=a[wa+(ka-3+B)|0]|0;sa=a[wa+(xa+ka)|0]|0;ta=a[wa+(ka-1+B)|0]|0;hLa(t,la,4);if((c[w>>2]|0)<=1){break}ka=s+4|0;na=s+136|0;L=u<<2;ua=(u|0)>4?4:u;ma=(ua|0)>0;oa=L-16|0;va=L-4|0;ia=L-2|0;ya=L-3|0;za=L-1|0;Ha=K;K=N;N=sa;sa=ta;ta=1;do{Ia=xa-(ca(ta,ja)|0)|0;Ja=wa+Ia|0;do{if((c[ka>>2]|0)==1){if((c[z>>2]|0)>=(ta|0)){pa=61;break}mf[c[ea>>2]&2047](c[na>>2]|0,Ja,wa+(Ia+C)|0,L);Ka=c[$>>2]|0;La=c[na>>2]|0;if(ma){Ma=sa;Na=N;Oa=K;Pa=Ha;Qa=0;while(1){Ra=Qa<<2;Sa=Ra|2;Ta=a[La+Sa|0]|0;Ua=Ra|1;Va=a[La+Ua|0]|0;Wa=a[La+Ra|0]|0;Xa=Ra|3;Ya=a[La+Xa|0]|0;a[Ka+Sa|0]=Ta-Pa;a[Ka+Ua|0]=Va-Oa;a[Ka+Ra|0]=Wa-Na;a[Ka+Xa|0]=Ya-Ma;Xa=Qa+1|0;if((Xa|0)<(ua|0)){Ma=Ya;Na=Wa;Oa=Va;Pa=Ta;Qa=Xa}else{break}}}mf[c[ea>>2]&2047](Ka+16|0,La+16|0,La+12|0,oa);Za=La+va|0;_a=La+ya|0;$a=La+ia|0;ab=La+za|0}else{pa=61}}while(0);if((pa|0)==61){pa=0;Ja=c[$>>2]|0;if(ma){Qa=sa;Pa=N;Oa=K;Na=Ha;Ma=0;while(1){Xa=Ma<<2;Ta=Xa|2;Va=a[wa+(Ta+Ia)|0]|0;Wa=Xa|1;Ya=a[wa+(Wa+Ia)|0]|0;Ra=a[wa+(Xa+Ia)|0]|0;Ua=Xa|3;Sa=a[wa+(Ua+Ia)|0]|0;a[Ja+Ta|0]=Va-Na;a[Ja+Wa|0]=Ya-Oa;a[Ja+Xa|0]=Ra-Pa;a[Ja+Ua|0]=Sa-Qa;Ua=Ma+1|0;if((Ua|0)<(ua|0)){Qa=Sa;Pa=Ra;Oa=Ya;Na=Va;Ma=Ua}else{break}}}mf[c[ea>>2]&2047](Ja+16|0,wa+(Ia+16)|0,wa+(Ia+12)|0,oa);Za=wa+(va+Ia)|0;_a=wa+(ya+Ia)|0;$a=wa+(ia+Ia)|0;ab=wa+(za+Ia)|0}N=a[Za]|0;K=a[_a]|0;Ha=a[$a]|0;sa=a[ab]|0;hLa(t,u,4);ta=ta+1|0;}while((ta|0)<(c[w>>2]|0))}else if((M|0)==2){ta=c[g>>2]|0;sa=c[A>>2]|0;Ha=ca(sa,x-1|0)|0;K=a[ta+Ha|0]|0;N=K&255;c[P>>2]=N;c[S>>2]=24;za=a[ta+(Ha+1)|0]|0;wa=N<<8|za&255;c[P>>2]=wa;c[S>>2]=16;N=a[ta+(Ha+2)|0]|0;ia=R;y=je((wa<<8|N&255)<<8|0)|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;c[P>>2]=0;c[S>>2]=32;ia=s+132|0;wa=c[ia>>2]|0;ya=Ha+3|0;va=u-1|0;oa=(va|0)>16?16:va;if((oa|0)>0){ea=N;N=za;za=K;K=0;while(1){ua=K*3|0;ma=a[ta+(ua+ya)|0]|0;$=ua+1|0;na=a[ta+($+ya)|0]|0;L=ua+2|0;ka=a[ta+(L+ya)|0]|0;a[wa+ua|0]=ma-za;a[wa+$|0]=na-N;a[wa+L|0]=ka-ea;L=K+1|0;if((L|0)<(oa|0)){ea=ka;N=na;za=ma;K=L}else{break}}}K=s+861564|0;za=va*3|0;mf[c[K>>2]&2047](wa+48|0,ta+(Ha+51)|0,ta+(Ha+48)|0,za-48|0);N=a[ta+(Ha+za)|0]|0;ea=a[ta+(za-2+ya)|0]|0;oa=a[ta+(za-1+ya)|0]|0;hLa(t,va,3);if((c[w>>2]|0)<=1){break}za=s+4|0;L=s+136|0;ma=u*3|0;na=(u|0)>16?16:u;ka=(na|0)>0;$=ma-48|0;ua=ma-3|0;ja=ma-2|0;xa=ma-1|0;la=N;N=ea;ea=oa;oa=1;do{B=Ha-(ca(oa,sa)|0)|0;O=ta+B|0;do{if((c[za>>2]|0)==1){if((c[z>>2]|0)>=(oa|0)){pa=74;break}mf[c[K>>2]&2047](c[L>>2]|0,O,ta+(B+C)|0,ma);Ma=c[ia>>2]|0;Na=c[L>>2]|0;if(ka){Oa=ea;Pa=N;Qa=la;Ua=0;while(1){Va=Ua*3|0;Ya=a[Na+Va|0]|0;Ra=Va+1|0;Sa=a[Na+Ra|0]|0;Xa=Va+2|0;Wa=a[Na+Xa|0]|0;a[Ma+Va|0]=Ya-Qa;a[Ma+Ra|0]=Sa-Pa;a[Ma+Xa|0]=Wa-Oa;Xa=Ua+1|0;if((Xa|0)<(na|0)){Oa=Wa;Pa=Sa;Qa=Ya;Ua=Xa}else{break}}}mf[c[K>>2]&2047](Ma+48|0,Na+48|0,Na+45|0,$);bb=Na+ja|0;cb=Na+ua|0;db=Na+xa|0}else{pa=74}}while(0);if((pa|0)==74){pa=0;O=c[ia>>2]|0;if(ka){Ia=ea;Ja=N;Ua=la;Qa=0;while(1){Pa=Qa*3|0;Oa=a[ta+(Pa+B)|0]|0;La=Pa+1|0;Ka=a[ta+(La+B)|0]|0;Xa=Pa+2|0;Ya=a[ta+(Xa+B)|0]|0;a[O+Pa|0]=Oa-Ua;a[O+La|0]=Ka-Ja;a[O+Xa|0]=Ya-Ia;Xa=Qa+1|0;if((Xa|0)<(na|0)){Ia=Ya;Ja=Ka;Ua=Oa;Qa=Xa}else{break}}}mf[c[K>>2]&2047](O+48|0,ta+(B+48)|0,ta+(B+45)|0,$);bb=ta+(ja+B)|0;cb=ta+(ua+B)|0;db=ta+(xa+B)|0}N=a[bb]|0;la=a[cb]|0;ea=a[db]|0;hLa(t,u,3);oa=oa+1|0;}while((oa|0)<(c[w>>2]|0))}else{if((c[s+64>>2]|0)<=2){KIb(e,16,2247200,(eb=i,i=i+1|0,i=i+7&-8,c[eb>>2]=0,eb)|0);i=eb;break}oa=s+92|0;ea=c[oa>>2]|0;la=s+88|0;if(((ea<<1|1)+(c[la>>2]|0)|0)<=0){break}N=s+132|0;xa=s+4|0;ta=s+76|0;ua=s+861568|0;ja=s+861740|0;$=s+80|0;K=s+136|0;na=s+861564|0;ka=s+861736|0;ia=s+100|0;L=s+104|0;ma=0;za=ea;do{do{if((za|0)==0){fb=C;gb=x;hb=u}else{if(!((ma-1|0)>>>0<2>>>0)){fb=C;gb=x;hb=u;break}fb=(ma|0)==1?E:G;gb=x>>c[L>>2];hb=u>>c[ia>>2]}}while(0);B=g+(ma<<2)|0;O=eLa(t,c[N>>2]|0,c[B>>2]|0,hb,0)|0;c[q>>2]=O;iLa(t,hb,ma);ea=c[xa>>2]|0;b:do{if((ea|0)==2){if((c[z>>2]|0)==0){ib=1}else{c[q>>2]=eLa(t,c[N>>2]|0,(c[B>>2]|0)+(c[g+32+(ma<<2)>>2]|0)|0,hb,O)|0;iLa(t,hb,ma);ib=2}sa=c[B>>2]|0;c[r>>2]=d[sa]|0;if((ib|0)>=(gb|0)){break}Ha=g+32+(ma<<2)|0;va=ib;ya=sa;while(1){sa=ca(c[Ha>>2]|0,va)|0;wa=ya+sa|0;Qa=c[N>>2]|0;Ua=ya+(sa-fb)|0;if((c[ta>>2]|0)<9){_e[c[ua>>2]&511](Qa,Ua,wa,hb,q,r)}else{Se[c[ja>>2]&1023](Qa,Ua,wa,(c[$>>2]|0)-1|0,hb,q,r)}iLa(t,hb,ma);wa=va+1|0;if((wa|0)>=(gb|0)){break b}va=wa;ya=c[B>>2]|0}}else{if((gb|0)<=1){break}ya=g+32+(ma<<2)|0;va=1;Ha=ea;while(1){Na=c[B>>2]|0;Ma=ca(c[ya>>2]|0,va)|0;wa=Na+Ma|0;do{if((Ha|0)==1){if((c[z>>2]|0)>=(va|0)){pa=102;break}Ua=c[K>>2]|0;Qa=Na+(Ma-fb)|0;if((c[ta>>2]|0)<9){mf[c[na>>2]&2047](Ua,wa,Qa,hb)}else{pe[c[ka>>2]&1023](Ua,wa,Qa,(c[$>>2]|0)-1|0,hb)}jb=eLa(t,c[N>>2]|0,c[K>>2]|0,hb,c[q>>2]|0)|0}else{pa=102}}while(0);if((pa|0)==102){pa=0;jb=eLa(t,c[N>>2]|0,wa,hb,c[q>>2]|0)|0}c[q>>2]=jb;iLa(t,hb,ma);Ma=va+1|0;if((Ma|0)>=(gb|0)){break b}va=Ma;Ha=c[xa>>2]|0}}}while(0);ma=ma+1|0;za=c[oa>>2]|0;}while((ma|0)<((za<<1|1)+(c[la>>2]|0)|0))}}while(0);gb=c[S>>2]|0;hb=c[Q>>2]|0;t=((63-gb+(hb-(c[T>>2]|0)<<3)|0)/8|0)+J|0;J=c[P>>2]|0;if((gb|0)>16){kb=gb-16|0;lb=J<<16;mb=hb}else{T=hb;y=je(J<<gb|0)|0;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=(c[Q>>2]|0)+4|0;c[Q>>2]=T;kb=gb+16|0;lb=0;mb=T}c[P>>2]=lb;c[S>>2]=kb;if((kb|0)>15){nb=kb-15|0;ob=lb<<15}else{T=mb;y=je(lb<<kb|0)|0;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;nb=kb+17|0;ob=0}c[P>>2]=ob;c[S>>2]=nb;nb=(t|0)/4|0;c:do{if((c[s+116>>2]&512|0)==0){pa=120}else{if((c[s+124>>2]&31|0)!=0){pa=120;break}t=c[e+668>>2]|0;ob=t+4128772|0;kb=s+84|0;T=ob;lb=s+160|0;mb=t;t=0;while(1){if((t|0)>=4){break c}gb=T-mb|0;if((c[kb>>2]|0)>0){J=0;hb=mb;jb=gb;while(1){q=lb+(t<<17)+(J<<3)|0;fb=c[q+4>>2]|0;Rb(hb|0,jb|0,2205296,(eb=i,i=i+16|0,c[eb>>2]=c[q>>2],c[eb+8>>2]=fb,eb)|0)|0;i=eb;fb=hb+(lrc(hb|0)|0)|0;c[q>>2]=0;c[q+4>>2]=0;q=J+1|0;z=T-fb|0;if((q|0)<(c[kb>>2]|0)){J=q;hb=fb;jb=z}else{pb=fb;qb=z;break}}}else{pb=mb;qb=gb}Rb(pb|0,qb|0,2173112,(eb=i,i=i+1|0,i=i+7&-8,c[eb>>2]=0,eb)|0)|0;i=eb;jb=pb+1|0;if(ob>>>0>jb>>>0){mb=jb;t=t+1|0}else{I=-12;break}}i=j;return I|0}}while(0);do{if((pa|0)==120){pb=c[e+668>>2]|0;if((pb|0)==0){break}a[pb]=0}}while(0);if((c[(c[s>>2]|0)+92>>2]&4|0)==0){e=c[S>>2]|0;d:do{if((e|0)<32){pa=c[P>>2]<<e;c[P>>2]=pa;pb=pa>>>24&255;while(1){pa=c[Q>>2]|0;c[Q>>2]=pa+1;a[pa]=pb;pa=c[P>>2]|0;c[P>>2]=pa<<8;eb=(c[S>>2]|0)+8|0;c[S>>2]=eb;if((eb|0)>=32){break d}pb=pa>>>16&255}}}while(0);c[S>>2]=32;c[P>>2]=0;P=c[H>>2]|0;ef[c[s+861584>>2]&4095](P,P,nb)}P=s+124|0;c[P>>2]=(c[P>>2]|0)+1;c[U>>2]=nb<<2;nb=f+36|0;c[nb>>2]=c[nb>>2]|1;c[h>>2]=1;I=0;i=j;return I|0}function cLa(a){a=a|0;Zpb(c[a+60>>2]|0);mJb(a+96|0);mJb(a+668|0);VHb(a+804|0);return 0}function dLa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;do{if((c[b+64>>2]|0)>2){f=(c[b+88>>2]|0)+1+(c[b+92>>2]<<1)|0;if((f|0)>0){g=f;break}else{h=0}i=e;return h|0}else{g=3}}while(0);f=b+84|0;j=0;k=0;a:while(1){l=b+524448+(j<<14)|0;m=PKa(l,b+160+(j<<17)|0,c[f>>2]|0)|0;if((m|0)<0){h=m;n=19;break}if((Wpb(b+589984+(j<<16)|0,l,c[f>>2]|0)|0)<0){h=-1;n=19;break}l=c[f>>2]|0;if((l|0)>0){m=k+1|0;o=0;p=0;while(1){q=a[b+524448+(j<<14)+p|0]|0;r=q&255;b:do{if((p|0)<(l|0)){s=0;t=p;while(1){u=s+1|0;v=t+1|0;if((v|0)>=(l|0)){w=v;x=u;break b}if((a[b+524448+(j<<14)+v|0]|0)==q<<24>>24&(u|0)<255){s=u;t=v}else{w=v;x=u;break}}}else{w=p;x=0}}while(0);if(!((q&255)>>>0<32>>>0&q<<24>>24!=0)){n=13;break a}if(!((x-1|0)>>>0<255>>>0)){n=13;break a}if((x|0)>7){a[d+(o+k)|0]=q;a[d+(m+o)|0]=x;y=o+2|0}else{a[d+(o+k)|0]=x<<5|r;y=o+1|0}if((w|0)<(l|0)){o=y;p=w}else{z=y;break}}}else{z=0}p=z+k|0;o=j+1|0;if((o|0)<(g|0)){j=o;k=p}else{h=p;n=19;break}}if((n|0)==13){KIb(0,0,2121912,(k=i,i=i+24|0,c[k>>2]=2639512,c[k+8>>2]=2616824,c[k+16>>2]=176,k)|0);i=k;Hd();return 0}else if((n|0)==19){i=e;return h|0}return 0}function eLa(f,g,h,i,j){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[f+76>>2]|0)<9){if((i|0)>=32){k=0;l=j;while(1){m=d[h+k|0]|0;a[g+k|0]=m-l;n=k+1|0;if((n|0)<16){k=n;l=m}else{break}}mf[c[f+861564>>2]&2047](g+16|0,h+16|0,h+15|0,i-16|0);o=d[h+(i-1)|0]|0;return o|0}if((i|0)>0){p=0;q=j}else{o=j;return o|0}while(1){l=d[h+p|0]|0;a[g+p|0]=l-q;k=p+1|0;if((k|0)<(i|0)){p=k;q=l}else{o=l;break}}return o|0}else{q=h;p=g;if((i|0)>=32){l=0;k=j;while(1){m=e[q+(l<<1)>>1]|0;b[p+(l<<1)>>1]=m-k;n=l+1|0;if((n|0)<16){l=n;k=m}else{break}}pe[c[f+861736>>2]&1023](g+32|0,h+32|0,h+30|0,(c[f+80>>2]|0)-1|0,i-16|0);o=e[q+(i-1<<1)>>1]|0;return o|0}if((i|0)>0){r=0;s=j}else{o=j;return o|0}while(1){j=e[q+(r<<1)>>1]|0;b[p+(r<<1)>>1]=j-s;f=r+1|0;if((f|0)<(i|0)){r=f;s=j}else{o=j;break}}return o|0}return 0}function fLa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=i;h=c[b+132>>2]|0;j=c[b+136>>2]|0;k=(e|0)/2|0;l=c[b+140>>2]|0;m=b+28|0;n=c[b+36>>2]|0;o=b+32|0;p=b+40|0;if(((c[b+44>>2]|0)-n-(32-(c[o>>2]|0)+((c[p>>2]|0)-n<<3)>>3)|0)<(f<<3|0)){KIb(c[b>>2]|0,16,2145720,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;i=g;return}n=(f|0)/2|0;if((c[b+116>>2]&512|0)!=0&(f|0)>1){q=0;do{r=q<<1;s=d[h+((r|1)+e)|0]|0;t=q+k|0;u=d[j+t|0]|0;v=d[l+t|0]|0;t=b+160+((d[h+(r+e)|0]|0)<<3)|0;r=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=r;c[t+4>>2]=G;t=b+131232+(u<<3)|0;u=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=u;c[t+4>>2]=G;t=b+160+(s<<3)|0;s=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=G;t=b+262304+(v<<3)|0;v=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=v;c[t+4>>2]=G;q=q+1|0;}while((q|0)<(n|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=g;return}q=(f|0)>1;if((c[b+120>>2]|0)==0){if(!q){i=g;return}f=m|0;t=0;v=c[f>>2]|0;s=c[o>>2]|0;while(1){u=t<<1;r=d[h+(u+e)|0]|0;w=d[h+((u|1)+e)|0]|0;u=t+k|0;x=d[j+u|0]|0;z=d[l+u|0]|0;u=d[b+524448+r|0]|0;A=c[b+589984+(r<<2)>>2]|0;if((s|0)>(u|0)){B=s-u|0;C=v<<u|A}else{r=je(A>>>((u-s|0)>>>0)|v<<s|0)|0;D=c[p>>2]|0;y=r;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;B=32-u+s|0;C=A}c[f>>2]=C;c[o>>2]=B;A=d[b+540832+x|0]|0;u=c[b+655520+(x<<2)>>2]|0;if((B|0)>(A|0)){E=B;F=C<<A|u}else{x=je(u>>>((A-B|0)>>>0)|C<<B|0)|0;D=c[p>>2]|0;y=x;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;E=B+32|0;F=u}u=E-A|0;c[f>>2]=F;c[o>>2]=u;A=d[b+524448+w|0]|0;D=c[b+589984+(w<<2)>>2]|0;if((u|0)>(A|0)){H=u;I=F<<A|D}else{w=je(D>>>((A-u|0)>>>0)|F<<u|0)|0;x=c[p>>2]|0;y=w;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;H=u+32|0;I=D}D=H-A|0;c[f>>2]=I;c[o>>2]=D;A=d[b+557216+z|0]|0;u=c[b+721056+(z<<2)>>2]|0;if((D|0)>(A|0)){J=D;K=I<<A|u}else{z=je(u>>>((A-D|0)>>>0)|I<<D|0)|0;x=c[p>>2]|0;y=z;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;J=D+32|0;K=u}u=J-A|0;c[f>>2]=K;c[o>>2]=u;A=t+1|0;if((A|0)<(n|0)){t=A;v=K;s=u}else{break}}i=g;return}else{if(!q){i=g;return}q=m|0;m=0;do{s=m<<1;K=d[h+(s+e)|0]|0;v=d[h+((s|1)+e)|0]|0;s=m+k|0;t=d[j+s|0]|0;f=d[l+s|0]|0;s=b+160+(K<<3)|0;J=wrc(c[s>>2]|0,c[s+4>>2]|0,1,0)|0;c[s>>2]=J;c[s+4>>2]=G;s=d[b+524448+K|0]|0;J=c[b+589984+(K<<2)>>2]|0;K=c[q>>2]|0;I=c[o>>2]|0;if((I|0)>(s|0)){L=I-s|0;M=K<<s|J}else{H=je(J>>>((s-I|0)>>>0)|K<<I|0)|0;K=c[p>>2]|0;y=H;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;L=32-s+I|0;M=J}c[q>>2]=M;c[o>>2]=L;J=b+131232+(t<<3)|0;I=wrc(c[J>>2]|0,c[J+4>>2]|0,1,0)|0;c[J>>2]=I;c[J+4>>2]=G;J=d[b+540832+t|0]|0;I=c[b+655520+(t<<2)>>2]|0;t=c[q>>2]|0;s=c[o>>2]|0;if((s|0)>(J|0)){N=s-J|0;O=t<<J|I}else{K=je(I>>>((J-s|0)>>>0)|t<<s|0)|0;t=c[p>>2]|0;y=K;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;N=32-J+s|0;O=I}c[q>>2]=O;c[o>>2]=N;I=b+160+(v<<3)|0;s=wrc(c[I>>2]|0,c[I+4>>2]|0,1,0)|0;c[I>>2]=s;c[I+4>>2]=G;I=d[b+524448+v|0]|0;s=c[b+589984+(v<<2)>>2]|0;v=c[q>>2]|0;J=c[o>>2]|0;if((J|0)>(I|0)){P=J-I|0;Q=v<<I|s}else{t=je(s>>>((I-J|0)>>>0)|v<<J|0)|0;v=c[p>>2]|0;y=t;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;P=32-I+J|0;Q=s}c[q>>2]=Q;c[o>>2]=P;s=b+262304+(f<<3)|0;J=wrc(c[s>>2]|0,c[s+4>>2]|0,1,0)|0;c[s>>2]=J;c[s+4>>2]=G;s=d[b+557216+f|0]|0;J=c[b+721056+(f<<2)>>2]|0;f=c[q>>2]|0;I=c[o>>2]|0;if((I|0)>(s|0)){R=I-s|0;S=f<<s|J}else{v=je(J>>>((s-I|0)>>>0)|f<<I|0)|0;f=c[p>>2]|0;y=v;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;R=32-s+I|0;S=J}c[q>>2]=S;c[o>>2]=R;m=m+1|0;}while((m|0)<(n|0));i=g;return}}function gLa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0;f=i;g=b+28|0;h=c[b+36>>2]|0;j=b+32|0;k=b+40|0;if(((c[b+44>>2]|0)-h-(32-(c[j>>2]|0)+((c[k>>2]|0)-h<<3)>>3)|0)<(e<<2|0)){KIb(c[b>>2]|0,16,2145720,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;i=f;return}h=(e|0)/2|0;if((c[b+116>>2]&512|0)!=0&(e|0)>1){l=b+132|0;m=0;do{n=m<<1;o=c[l>>2]|0;p=d[o+(n|1)|0]|0;q=b+160+((d[o+n|0]|0)<<3)|0;n=wrc(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;c[q>>2]=n;c[q+4>>2]=G;q=b+160+(p<<3)|0;p=wrc(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;c[q>>2]=p;c[q+4>>2]=G;m=m+1|0;}while((m|0)<(h|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=f;return}m=(e|0)>1;if((c[b+120>>2]|0)==0){if(!m){i=f;return}e=b+132|0;l=g|0;q=0;p=c[l>>2]|0;n=c[j>>2]|0;while(1){o=q<<1;r=c[e>>2]|0;s=d[r+o|0]|0;t=d[r+(o|1)|0]|0;o=d[b+524448+s|0]|0;r=c[b+589984+(s<<2)>>2]|0;if((n|0)>(o|0)){u=n-o|0;v=p<<o|r}else{s=je(r>>>((o-n|0)>>>0)|p<<n|0)|0;w=c[k>>2]|0;y=s;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;u=32-o+n|0;v=r}c[l>>2]=v;c[j>>2]=u;r=d[b+524448+t|0]|0;o=c[b+589984+(t<<2)>>2]|0;if((u|0)>(r|0)){x=u;z=v<<r|o}else{t=je(o>>>((r-u|0)>>>0)|v<<u|0)|0;w=c[k>>2]|0;y=t;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;x=u+32|0;z=o}o=x-r|0;c[l>>2]=z;c[j>>2]=o;r=q+1|0;if((r|0)<(h|0)){q=r;p=z;n=o}else{break}}i=f;return}else{if(!m){i=f;return}m=b+132|0;n=g|0;g=0;do{z=g<<1;p=c[m>>2]|0;q=d[p+z|0]|0;l=d[p+(z|1)|0]|0;z=b+160+(q<<3)|0;p=wrc(c[z>>2]|0,c[z+4>>2]|0,1,0)|0;c[z>>2]=p;c[z+4>>2]=G;z=b+160+(l<<3)|0;p=wrc(c[z>>2]|0,c[z+4>>2]|0,1,0)|0;c[z>>2]=p;c[z+4>>2]=G;z=d[b+524448+q|0]|0;p=c[b+589984+(q<<2)>>2]|0;q=c[n>>2]|0;x=c[j>>2]|0;if((x|0)>(z|0)){A=x-z|0;B=q<<z|p}else{u=je(p>>>((z-x|0)>>>0)|q<<x|0)|0;q=c[k>>2]|0;y=u;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;A=32-z+x|0;B=p}c[n>>2]=B;c[j>>2]=A;p=d[b+524448+l|0]|0;x=c[b+589984+(l<<2)>>2]|0;if((A|0)>(p|0)){C=A;D=B<<p|x}else{l=je(x>>>((p-A|0)>>>0)|B<<A|0)|0;z=c[k>>2]|0;y=l;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;C=A+32|0;D=x}c[n>>2]=D;c[j>>2]=C-p;g=g+1|0;}while((g|0)<(h|0));i=f;return}}function hLa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;g=i;h=b+28|0;j=c[b+36>>2]|0;k=b+32|0;l=c[k>>2]|0;m=b+40|0;n=c[m>>2]|0;if(((c[b+44>>2]|0)-j-(32-l+(n-j<<3)>>3)|0)<(ca(e<<2,f)|0)){KIb(c[b>>2]|0,16,2145720,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;i=g;return}j=(c[b+116>>2]&512|0)==0;do{if(!j){if((c[(c[b>>2]|0)+92>>2]&4|0)==0){break}if((e|0)<=0){i=g;return}o=(f|0)==3;p=b+132|0;q=(f|0)==4;r=0;do{if(o){s=r*3|0;t=c[p>>2]|0;u=d[t+(s+1)|0]|0;v=s;w=u;x=(d[t+(s+2)|0]|0)-u|0;z=t}else{t=r<<2;u=c[p>>2]|0;s=d[u+(t|1)|0]|0;v=t|2;w=s;x=(d[u+t|0]|0)-s|0;z=u}u=(d[z+v|0]|0)-w&255;s=a[z+((ca(r,f)|0)+3)|0]|0;t=b+160+((x&255)<<3)|0;A=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=A;c[t+4>>2]=G;t=b+131232+(w<<3)|0;A=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=A;c[t+4>>2]=G;t=b+262304+(u<<3)|0;u=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=u;c[t+4>>2]=G;if(q){t=b+262304+((s&255)<<3)|0;s=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=G}r=r+1|0;}while((r|0)<(e|0));i=g;return}}while(0);w=(e|0)>0;if((c[b+120>>2]|0)!=0|j^1){if(!w){i=g;return}j=(f|0)==3;x=b+132|0;z=(f|0)==4;v=h|0;r=0;do{if(j){q=r*3|0;p=c[x>>2]|0;o=d[p+(q+1)|0]|0;B=q;C=o;D=(d[p+(q+2)|0]|0)-o|0;E=p}else{p=r<<2;o=c[x>>2]|0;q=d[o+(p|1)|0]|0;B=p|2;C=q;D=(d[o+p|0]|0)-q|0;E=o}o=D&255;q=(d[E+B|0]|0)-C&255;p=d[E+((ca(r,f)|0)+3)|0]|0;t=b+160+(o<<3)|0;s=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=G;t=b+131232+(C<<3)|0;s=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=G;t=b+262304+(q<<3)|0;s=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=G;if(z){t=b+262304+(p<<3)|0;s=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=G}t=d[b+540832+C|0]|0;s=c[b+655520+(C<<2)>>2]|0;u=c[v>>2]|0;A=c[k>>2]|0;if((A|0)>(t|0)){F=A-t|0;H=u<<t|s}else{I=je(s>>>((t-A|0)>>>0)|u<<A|0)|0;u=c[m>>2]|0;y=I;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;F=32-t+A|0;H=s}c[v>>2]=H;c[k>>2]=F;s=d[b+524448+o|0]|0;A=c[b+589984+(o<<2)>>2]|0;if((F|0)>(s|0)){J=F;K=H<<s|A}else{o=je(A>>>((s-F|0)>>>0)|H<<F|0)|0;t=c[m>>2]|0;y=o;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;J=F+32|0;K=A}A=J-s|0;c[v>>2]=K;c[k>>2]=A;s=d[b+557216+q|0]|0;t=c[b+721056+(q<<2)>>2]|0;if((A|0)>(s|0)){L=A;M=K<<s|t}else{q=je(t>>>((s-A|0)>>>0)|K<<A|0)|0;o=c[m>>2]|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;L=A+32|0;M=t}t=L-s|0;c[v>>2]=M;c[k>>2]=t;if(z){s=d[b+557216+p|0]|0;A=c[b+721056+(p<<2)>>2]|0;if((t|0)>(s|0)){N=t;O=M<<s|A}else{p=je(A>>>((s-t|0)>>>0)|M<<t|0)|0;o=c[m>>2]|0;y=p;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;N=t+32|0;O=A}c[v>>2]=O;c[k>>2]=N-s}r=r+1|0;}while((r|0)<(e|0));i=g;return}if(!w){i=g;return}w=b+132|0;r=h|0;h=(f|0)==4;if((f|0)==3){N=0;O=l;v=n;while(1){M=N*3|0;z=c[w>>2]|0;L=d[z+(M+1)|0]|0;K=(d[z+(M+2)|0]|0)-L&255;J=(d[z+M|0]|0)-L&255;F=d[z+(M+3)|0]|0;M=d[b+540832+L|0]|0;z=c[b+655520+(L<<2)>>2]|0;L=c[r>>2]|0;if((O|0)>(M|0)){P=O-M|0;Q=L<<M|z;R=v}else{H=v;y=je(z>>>((M-O|0)>>>0)|L<<O|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=(c[m>>2]|0)+4|0;c[m>>2]=H;P=32-M+O|0;Q=z;R=H}c[r>>2]=Q;c[k>>2]=P;H=d[b+524448+K|0]|0;z=c[b+589984+(K<<2)>>2]|0;if((P|0)>(H|0)){S=P;T=Q<<H|z;U=R}else{K=R;y=je(z>>>((H-P|0)>>>0)|Q<<P|0)|0;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;K=(c[m>>2]|0)+4|0;c[m>>2]=K;S=P+32|0;T=z;U=K}K=S-H|0;c[r>>2]=T;c[k>>2]=K;H=d[b+557216+J|0]|0;z=c[b+721056+(J<<2)>>2]|0;if((K|0)>(H|0)){V=K;W=T<<H|z;X=U}else{J=U;y=je(z>>>((H-K|0)>>>0)|T<<K|0)|0;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;J=(c[m>>2]|0)+4|0;c[m>>2]=J;V=K+32|0;W=z;X=J}J=V-H|0;c[r>>2]=W;c[k>>2]=J;if(h){H=d[b+557216+F|0]|0;z=c[b+721056+(F<<2)>>2]|0;if((J|0)>(H|0)){Y=J;Z=W<<H|z;_=X}else{F=X;y=je(z>>>((H-J|0)>>>0)|W<<J|0)|0;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;F=(c[m>>2]|0)+4|0;c[m>>2]=F;Y=J+32|0;Z=z;_=F}F=Y-H|0;c[r>>2]=Z;c[k>>2]=F;$=F;aa=_}else{$=J;aa=X}J=N+1|0;if((J|0)<(e|0)){N=J;O=$;v=aa}else{break}}i=g;return}else{aa=0;v=l;l=n;while(1){n=aa<<2;$=c[w>>2]|0;O=d[$+(n|1)|0]|0;N=(d[$+n|0]|0)-O&255;X=(d[$+(n|2)|0]|0)-O&255;n=d[$+((ca(aa,f)|0)+3)|0]|0;$=d[b+540832+O|0]|0;_=c[b+655520+(O<<2)>>2]|0;O=c[r>>2]|0;if((v|0)>($|0)){ba=v-$|0;da=O<<$|_;ea=l}else{Z=l;y=je(_>>>(($-v|0)>>>0)|O<<v|0)|0;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;Z=(c[m>>2]|0)+4|0;c[m>>2]=Z;ba=32-$+v|0;da=_;ea=Z}c[r>>2]=da;c[k>>2]=ba;Z=d[b+524448+N|0]|0;_=c[b+589984+(N<<2)>>2]|0;if((ba|0)>(Z|0)){fa=ba;ga=da<<Z|_;ha=ea}else{N=ea;y=je(_>>>((Z-ba|0)>>>0)|da<<ba|0)|0;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;N=(c[m>>2]|0)+4|0;c[m>>2]=N;fa=ba+32|0;ga=_;ha=N}N=fa-Z|0;c[r>>2]=ga;c[k>>2]=N;Z=d[b+557216+X|0]|0;_=c[b+721056+(X<<2)>>2]|0;if((N|0)>(Z|0)){ia=N;ja=ga<<Z|_;ka=ha}else{X=ha;y=je(_>>>((Z-N|0)>>>0)|ga<<N|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=(c[m>>2]|0)+4|0;c[m>>2]=X;ia=N+32|0;ja=_;ka=X}X=ia-Z|0;c[r>>2]=ja;c[k>>2]=X;if(h){Z=d[b+557216+n|0]|0;_=c[b+721056+(n<<2)>>2]|0;if((X|0)>(Z|0)){la=X;ma=ja<<Z|_;na=ka}else{n=ka;y=je(_>>>((Z-X|0)>>>0)|ja<<X|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=(c[m>>2]|0)+4|0;c[m>>2]=n;la=X+32|0;ma=_;na=n}n=la-Z|0;c[r>>2]=ma;c[k>>2]=n;oa=n;pa=na}else{oa=X;pa=ka}X=aa+1|0;if((X|0)<(e|0)){aa=X;v=oa;l=pa}else{break}}i=g;return}}function iLa(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;h=i;j=b+28|0;k=c[b+36>>2]|0;l=b+32|0;m=b+40|0;n=c[b+76>>2]|0;if(((c[b+44>>2]|0)-k-(32-(c[l>>2]|0)+((c[m>>2]|0)-k<<3)>>3)|0)<((ca(n,f)|0)/2|0|0)){KIb(c[b>>2]|0,16,2145720,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;i=h;return}k=(f|0)/2|0;if((n|0)<9){if((c[b+116>>2]&512|0)!=0&(f|0)>1){o=b+132|0;p=0;do{q=p<<1;r=c[o>>2]|0;s=d[r+(q|1)|0]|0;t=b+160+(g<<17)+((d[r+q|0]|0)<<3)|0;q=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=q;c[t+4>>2]=G;t=b+160+(g<<17)+(s<<3)|0;s=wrc(c[t>>2]|0,c[t+4>>2]|0,1,0)|0;c[t>>2]=s;c[t+4>>2]=G;p=p+1|0;}while((p|0)<(k|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=h;return}p=(f|0)>1;if((c[b+120>>2]|0)==0){if(!p){i=h;return}o=b+132|0;t=j|0;s=0;q=c[t>>2]|0;r=c[l>>2]|0;while(1){u=s<<1;v=c[o>>2]|0;w=d[v+u|0]|0;x=d[v+(u|1)|0]|0;u=d[b+524448+(g<<14)+w|0]|0;v=c[b+589984+(g<<16)+(w<<2)>>2]|0;if((r|0)>(u|0)){z=r-u|0;A=q<<u|v}else{w=je(v>>>((u-r|0)>>>0)|q<<r|0)|0;B=c[m>>2]|0;y=w;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;z=32-u+r|0;A=v}c[t>>2]=A;c[l>>2]=z;v=d[b+524448+(g<<14)+x|0]|0;u=c[b+589984+(g<<16)+(x<<2)>>2]|0;if((z|0)>(v|0)){C=z;D=A<<v|u}else{x=je(u>>>((v-z|0)>>>0)|A<<z|0)|0;B=c[m>>2]|0;y=x;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;C=z+32|0;D=u}u=C-v|0;c[t>>2]=D;c[l>>2]=u;v=s+1|0;if((v|0)<(k|0)){s=v;q=D;r=u}else{break}}i=h;return}else{if(!p){i=h;return}p=b+132|0;r=j|0;D=0;do{q=D<<1;s=c[p>>2]|0;t=d[s+q|0]|0;C=d[s+(q|1)|0]|0;q=b+160+(g<<17)+(t<<3)|0;s=wrc(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;c[q>>2]=s;c[q+4>>2]=G;q=b+160+(g<<17)+(C<<3)|0;s=wrc(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;c[q>>2]=s;c[q+4>>2]=G;q=d[b+524448+(g<<14)+t|0]|0;s=c[b+589984+(g<<16)+(t<<2)>>2]|0;t=c[r>>2]|0;z=c[l>>2]|0;if((z|0)>(q|0)){E=z-q|0;F=t<<q|s}else{A=je(s>>>((q-z|0)>>>0)|t<<z|0)|0;t=c[m>>2]|0;y=A;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;E=32-q+z|0;F=s}c[r>>2]=F;c[l>>2]=E;s=d[b+524448+(g<<14)+C|0]|0;z=c[b+589984+(g<<16)+(C<<2)>>2]|0;if((E|0)>(s|0)){H=E;I=F<<s|z}else{C=je(z>>>((s-E|0)>>>0)|F<<E|0)|0;q=c[m>>2]|0;y=C;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;H=E+32|0;I=z}c[r>>2]=I;c[l>>2]=H-s;D=D+1|0;}while((D|0)<(k|0));i=h;return}}if((n|0)<15){n=(c[b+80>>2]|0)-1|0;if((c[b+116>>2]&512|0)!=0&(f|0)>1){D=b+144|0;H=0;do{I=H<<1;r=c[D>>2]|0;E=(e[r+((I|1)<<1)>>1]|0)&n;F=b+160+(g<<17)+(((e[r+(I<<1)>>1]|0)&n)<<3)|0;I=wrc(c[F>>2]|0,c[F+4>>2]|0,1,0)|0;c[F>>2]=I;c[F+4>>2]=G;F=b+160+(g<<17)+(E<<3)|0;E=wrc(c[F>>2]|0,c[F+4>>2]|0,1,0)|0;c[F>>2]=E;c[F+4>>2]=G;H=H+1|0;}while((H|0)<(k|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=h;return}H=(f|0)>1;if((c[b+120>>2]|0)==0){if(!H){i=h;return}D=b+144|0;F=j|0;E=0;I=c[F>>2]|0;r=c[l>>2]|0;while(1){p=E<<1;s=c[D>>2]|0;z=(e[s+(p<<1)>>1]|0)&n;q=(e[s+((p|1)<<1)>>1]|0)&n;p=d[b+524448+(g<<14)+z|0]|0;s=c[b+589984+(g<<16)+(z<<2)>>2]|0;if((r|0)>(p|0)){J=r-p|0;K=I<<p|s}else{z=je(s>>>((p-r|0)>>>0)|I<<r|0)|0;C=c[m>>2]|0;y=z;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;J=32-p+r|0;K=s}c[F>>2]=K;c[l>>2]=J;s=d[b+524448+(g<<14)+q|0]|0;p=c[b+589984+(g<<16)+(q<<2)>>2]|0;if((J|0)>(s|0)){L=J;M=K<<s|p}else{q=je(p>>>((s-J|0)>>>0)|K<<J|0)|0;C=c[m>>2]|0;y=q;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;L=J+32|0;M=p}p=L-s|0;c[F>>2]=M;c[l>>2]=p;s=E+1|0;if((s|0)<(k|0)){E=s;I=M;r=p}else{break}}i=h;return}else{if(!H){i=h;return}H=b+144|0;r=j|0;M=0;do{I=M<<1;E=c[H>>2]|0;F=(e[E+(I<<1)>>1]|0)&n;L=(e[E+((I|1)<<1)>>1]|0)&n;I=b+160+(g<<17)+(F<<3)|0;E=wrc(c[I>>2]|0,c[I+4>>2]|0,1,0)|0;c[I>>2]=E;c[I+4>>2]=G;I=b+160+(g<<17)+(L<<3)|0;E=wrc(c[I>>2]|0,c[I+4>>2]|0,1,0)|0;c[I>>2]=E;c[I+4>>2]=G;I=d[b+524448+(g<<14)+F|0]|0;E=c[b+589984+(g<<16)+(F<<2)>>2]|0;F=c[r>>2]|0;J=c[l>>2]|0;if((J|0)>(I|0)){N=J-I|0;O=F<<I|E}else{K=je(E>>>((I-J|0)>>>0)|F<<J|0)|0;F=c[m>>2]|0;y=K;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;N=32-I+J|0;O=E}c[r>>2]=O;c[l>>2]=N;E=d[b+524448+(g<<14)+L|0]|0;J=c[b+589984+(g<<16)+(L<<2)>>2]|0;if((N|0)>(E|0)){P=N;Q=O<<E|J}else{L=je(J>>>((E-N|0)>>>0)|O<<N|0)|0;I=c[m>>2]|0;y=L;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;P=N+32|0;Q=J}c[r>>2]=Q;c[l>>2]=P-E;M=M+1|0;}while((M|0)<(k|0));i=h;return}}if((c[b+116>>2]&512|0)!=0&(f|0)>1){M=b+144|0;P=0;do{Q=P<<1;r=c[M>>2]|0;N=e[r+((Q|1)<<1)>>1]|0;O=b+160+(g<<17)+((e[r+(Q<<1)>>1]|0)>>>2<<3)|0;Q=wrc(c[O>>2]|0,c[O+4>>2]|0,1,0)|0;c[O>>2]=Q;c[O+4>>2]=G;O=b+160+(g<<17)+(N>>>2<<3)|0;N=wrc(c[O>>2]|0,c[O+4>>2]|0,1,0)|0;c[O>>2]=N;c[O+4>>2]=G;P=P+1|0;}while((P|0)<(k|0))}if((c[(c[b>>2]|0)+92>>2]&4|0)!=0){i=h;return}P=(f|0)>1;if((c[b+120>>2]|0)==0){if(!P){i=h;return}f=b+144|0;M=j|0;O=0;N=c[M>>2]|0;Q=c[l>>2]|0;while(1){r=O<<1;n=c[f>>2]|0;H=e[n+(r<<1)>>1]|0;E=e[n+((r|1)<<1)>>1]|0;r=H>>>2;n=d[b+524448+(g<<14)+r|0]|0;J=c[b+589984+(g<<16)+(r<<2)>>2]|0;if((Q|0)>(n|0)){R=Q-n|0;S=N<<n|J}else{r=je(J>>>((n-Q|0)>>>0)|N<<Q|0)|0;I=c[m>>2]|0;y=r;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;R=32-n+Q|0;S=J}c[M>>2]=S;c[l>>2]=R;J=H&3;if((R|0)>2){T=R-2|0;U=S<<2|J}else{H=je(J>>>((2-R|0)>>>0)|S<<R|0)|0;n=c[m>>2]|0;y=H;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;T=R+30|0;U=J}c[M>>2]=U;c[l>>2]=T;J=E>>>2;n=d[b+524448+(g<<14)+J|0]|0;H=c[b+589984+(g<<16)+(J<<2)>>2]|0;if((T|0)>(n|0)){V=T;W=U<<n|H}else{J=je(H>>>((n-T|0)>>>0)|U<<T|0)|0;I=c[m>>2]|0;y=J;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;V=T+32|0;W=H}H=V-n|0;c[M>>2]=W;c[l>>2]=H;n=E&3;if((H|0)>2){X=H-2|0;Y=W<<2|n}else{E=je(n>>>((2-H|0)>>>0)|W<<H|0)|0;I=c[m>>2]|0;y=E;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;X=H+30|0;Y=n}c[M>>2]=Y;c[l>>2]=X;n=O+1|0;if((n|0)<(k|0)){O=n;N=Y;Q=X}else{break}}i=h;return}else{if(!P){i=h;return}P=b+144|0;X=j|0;j=0;do{Q=j<<1;Y=c[P>>2]|0;N=e[Y+(Q<<1)>>1]|0;O=e[Y+((Q|1)<<1)>>1]|0;Q=N>>>2;Y=b+160+(g<<17)+(Q<<3)|0;M=wrc(c[Y>>2]|0,c[Y+4>>2]|0,1,0)|0;c[Y>>2]=M;c[Y+4>>2]=G;Y=O>>>2;M=b+160+(g<<17)+(Y<<3)|0;W=wrc(c[M>>2]|0,c[M+4>>2]|0,1,0)|0;c[M>>2]=W;c[M+4>>2]=G;M=d[b+524448+(g<<14)+Q|0]|0;W=c[b+589984+(g<<16)+(Q<<2)>>2]|0;Q=c[X>>2]|0;V=c[l>>2]|0;if((V|0)>(M|0)){Z=V-M|0;_=Q<<M|W}else{T=je(W>>>((M-V|0)>>>0)|Q<<V|0)|0;Q=c[m>>2]|0;y=T;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;Z=32-M+V|0;_=W}c[X>>2]=_;c[l>>2]=Z;W=N&3;if((Z|0)>2){$=Z-2|0;aa=_<<2|W}else{N=je(W>>>((2-Z|0)>>>0)|_<<Z|0)|0;V=c[m>>2]|0;y=N;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;$=Z+30|0;aa=W}c[X>>2]=aa;c[l>>2]=$;W=d[b+524448+(g<<14)+Y|0]|0;V=c[b+589984+(g<<16)+(Y<<2)>>2]|0;if(($|0)>(W|0)){ba=$;da=aa<<W|V}else{Y=je(V>>>((W-$|0)>>>0)|aa<<$|0)|0;N=c[m>>2]|0;y=Y;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;ba=$+32|0;da=V}V=ba-W|0;c[X>>2]=da;c[l>>2]=V;W=O&3;if((V|0)>2){ea=V-2|0;fa=da<<2|W}else{O=je(W>>>((2-V|0)>>>0)|da<<V|0)|0;N=c[m>>2]|0;y=O;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;ea=V+30|0;fa=W}c[X>>2]=fa;c[l>>2]=ea;j=j+1|0;}while((j|0)<(k|0));i=h;return}}function jLa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=c[b+60>>2]|0;g=f;c[f>>2]=b;c[b+140>>2]=11;if((c[b+100>>2]|0)!=65536){KIb(b,16,2362752,(h=i,i=i+8|0,c[h>>2]=65536,h)|0);i=h;j=-1;i=e;return j|0}h=c[b+96>>2]|0;b=f+12|0;f=0;k=0;while(1){l=0;m=k;while(1){c[b+(f<<13)+(l<<4)>>2]=d[h+m|0]|0;n=l+1|0;if((n|0)<256){l=n;m=m+1|0}else{o=0;break}}do{a[g+12+(f<<13)+(o<<4)+4|0]=0;o=o+1|0;}while((o|0)<512);m=k+256|0;l=256;while(1){n=0;p=99999999;q=-1;while(1){if((a[g+12+(f<<13)+(n<<4)+4|0]|0)==0){r=c[g+12+(f<<13)+(n<<4)>>2]|0;s=(r|0)!=0&(r|0)<(p|0);t=s?n:q;u=s?r:p}else{t=q;u=p}r=n+1|0;if((r|0)<(l|0)){n=r;p=u;q=t}else{break}}if((t|0)==-1){v=l;w=13;break}a[g+12+(f<<13)+(t<<4)+4|0]=1;c[g+12+(f<<13)+(l<<4)+8>>2]=t;q=0;p=99999999;n=-1;while(1){if((a[g+12+(f<<13)+(q<<4)+4|0]|0)==0){r=c[g+12+(f<<13)+(q<<4)>>2]|0;s=(r|0)!=0&(r|0)<(p|0);x=s?q:n;y=s?r:p}else{x=n;y=p}r=q+1|0;if((r|0)<(l|0)){q=r;p=y;n=x}else{break}}if((x|0)==-1){w=19;break}a[g+12+(f<<13)+(x<<4)+4|0]=1;c[g+12+(f<<13)+(l<<4)+12>>2]=x;c[g+12+(f<<13)+(l<<4)>>2]=(c[g+12+(f<<13)+(x<<4)>>2]|0)+(c[g+12+(f<<13)+(t<<4)>>2]|0);n=l+1|0;if((n|0)>0){l=n}else{v=n;w=13;break}}if((w|0)==13){w=0;c[g+12+(f<<13)+(v<<4)+8>>2]=-1;z=v}else if((w|0)==19){w=0;c[g+12+(f<<13)+(l<<4)+12>>2]=-1;z=l}c[g+2097164+(f<<2)>>2]=z-1;n=f+1|0;if((n|0)<256){f=n;k=m}else{j=0;break}}i=e;return j|0}function kLa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;k=c[b+60>>2]|0;l=V1(f,0,0)|0;f=k+4|0;c[f>>2]=h;h=k+8|0;c[h>>2]=j;m=M4a(b,d,0)|0;if((m|0)<0){n=m;i=g;return n|0}m=k;b=d+32|0;o=c[b>>2]|0;p=k;q=c[p>>2]|0;a:do{if((ca(c[q+124>>2]|0,o)|0)>0){r=d;s=0;t=0;u=0;v=0;w=0;x=q;y=o;b:while(1){if((c[x+120>>2]|0)>0){z=s;A=t;B=u;C=v;D=w;E=x;while(1){F=c[m+2097164+(A<<2)>>2]|0;if((F|0)>255){G=B;H=C;I=D;J=F;while(1){if((H|0)==0){if((I|0)>=(c[h>>2]|0)){break b}K=I+1|0;L=8;M=a[(c[f>>2]|0)+I|0]|0}else{K=I;L=H;M=G}N=(M&255)>>>1;O=L-1|0;P=c[m+12+(A<<13)+(J<<4)+8+((M&1)<<2)>>2]|0;if((P|0)>255){G=N;H=O;I=K;J=P}else{Q=N;R=O;S=K;T=P;break}}}else{Q=B;R=C;S=D;T=F}a[(c[r>>2]|0)+z|0]=T;J=z+1|0;U=c[p>>2]|0;if((J|0)<((c[U+120>>2]|0)+s|0)){z=J;A=T;B=Q;C=R;D=S;E=U}else{break}}V=T;W=Q;X=R;Y=S;Z=c[b>>2]|0;_=U}else{V=t;W=u;X=v;Y=w;Z=y;_=x}D=Z+s|0;if((D|0)<(ca(c[_+124>>2]|0,Z)|0)){s=D;t=V;u=W;v=X;w=Y;x=_;y=Z}else{break a}}KIb(E,16,2452128,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;n=-1094995529;i=g;return n|0}}while(0);if((l|0)==0){$=k+2098188|0}else{c[d+304>>2]=1;E=k+2098188|0;nrc(E|0,l|0,1024)|0;$=E}nrc(c[d+4>>2]|0,$|0,1024)|0;c[e>>2]=1;n=j;i=g;return n|0}function lLa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=a+60|0;f=c[e>>2]|0;g=a+792|0;h=c[g>>2]|0;do{if((h|0)<9){j=c[a+100>>2]|0;k=(j|0)>1;if(k){l=c[a+96>>2]|0;m=j-((he((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&65535)|0}else{m=0}l=(h|0)<8;if(l|k^1){n=l?11:8}else{n=(m|0)!=0?11:8}c[a+140>>2]=n}else{if((h|0)>=33){o=-1094995529;i=b;return o|0}l=c[a+52>>2]|0;if((l|0)==1312966482){c[a+140>>2]=62;break}else if((l|0)==943867730){c[a+140>>2]=30;break}else if((l|0)==1346716996){break}else{if((h|0)==32){c[a+140>>2]=28;break}else if((h|0)==24){c[a+140>>2]=296;break}else{QIb(a,2516472,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;o=-1163346256;i=b;return o|0}}}}while(0);h=a+120|0;n=tIb(c[h>>2]|0,c[a+124>>2]|0,0,a)|0;if((n|0)!=0){o=n;i=b;return o|0}n=(c[h>>2]|0)+15>>3&-2;c[f+4>>2]=n;h=hJb(n+16|0)|0;c[f+8>>2]=h;if((h|0)==0){o=-12;i=b;return o|0}c[f+32>>2]=c[g>>2];g=UHb()|0;c[f>>2]=g;if((g|0)==0){g=c[e>>2]|0;VHb(g);mJb(g+8|0);mJb(g+12|0);mJb(g+16|0);o=-12;i=b;return o|0}else{g=oLa(a,0)|0;o=(g|0)<0?g:0;i=b;return o|0}return 0}function mLa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0;j=i;k=e+60|0;l=c[k>>2]|0;m=c[h+28>>2]|0;if((m|0)>1){n=c[h+24>>2]|0;o=n;p=(he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;q=m-p|0;r=n+p|0}else{q=0;r=0}p=r+q|0;n=oLa(e,h)|0;if((n|0)<0){s=n;i=j;return s|0}n=l;h=N4a(e,c[n>>2]|0)|0;if((h|0)<0){s=h;i=j;return s|0}h=l+52|0;do{if((c[h>>2]|0)==0){if((c[e+792>>2]|0)>=9){break}if((c[e+140>>2]|0)==11){m=pLa(e,c[(c[n>>2]|0)+4>>2]|0)|0;if((m|0)<0){s=m}else{break}i=j;return s|0}if((c[e+140>>2]|0)!=30){break}m=pLa(e,c[l+24>>2]|0)|0;if((m|0)<0){s=m}else{break}i=j;return s|0}}while(0);c[h>>2]=1;h=c[l+28>>2]|0;a:do{if((h|0)==4){if(!((q|0)>-1)){KIb(0,0,2452096,(t=i,i=i+24|0,c[t>>2]=2362736,c[t+8>>2]=2297872,c[t+16>>2]=135,t)|0);i=t;Hd();return 0}m=c[e+52>>2]|0;if((m|0)==943867730){o=c[n>>2]|0;u=c[o>>2]|0;v=c[e+120>>2]|0;w=c[e+124>>2]|0;x=c[o+32>>2]|0;o=p;if(q>>>0>3>>>0){y=0;z=0;A=r}else{break}while(1){if((o-A|0)<3){B=-16777216;C=A}else{B=(d[A]|0)<<16|(d[A+1|0]|0)<<8|(d[A+2|0]|0)|-16777216;C=A+3|0}if((o-C|0)<1){D=C;E=209}else{F=C+1|0;G=a[C]&127;if((G|0)==0){D=F;E=209}else{H=F;I=G;E=214}}if((E|0)==209){E=0;if((o-D|0)<1){J=D;E=211}else{G=D+1|0;F=a[D]|0;if(F<<24>>24==0){J=G;E=211}else{K=F&255;L=G}}if((E|0)==211){E=0;if((o-J|0)<2){break a}G=J;F=(d[G]|d[G+1|0]<<8)<<16>>16;G=(he(F|0)|0)&65535;if(F<<16>>16==0){break a}else{K=G;L=J+2|0}}if((K|0)==0){M=y;N=z;O=L}else{H=L;I=K;E=214}}if((E|0)==214){E=0;G=y;F=0;P=z;while(1){c[u+((ca(G,x)|0)+(P<<2))>>2]=B;Q=P+1|0;if((Q|0)<(v|0)){R=Q;S=G}else{Q=G+1|0;if((Q|0)<(w|0)){R=0;S=Q}else{break a}}Q=F+1|0;if((Q|0)<(I|0)){G=S;F=Q;P=R}else{M=S;N=R;O=H;break}}}if((o-O|0)>>>0>3>>>0){y=M;z=N;A=O}else{break}}}else if((m|0)==1312966482){o=c[n>>2]|0;w=c[o>>2]|0;v=c[e+120>>2]|0;x=c[e+124>>2]|0;u=c[o+32>>2]|0;o=p;if(q>>>0>1>>>0){T=0;U=0;V=r}else{break}while(1){P=V+2|0;F=V;G=he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0;F=G&7;Q=(G&65535)>>>4;if((F|0)==0){if((o-P|0)<1){W=P;E=223}else{G=V+3|0;X=a[P]|0;if(X<<24>>24==0){W=G;E=223}else{Y=X&255;Z=G}}if((E|0)==223){E=0;if((o-W|0)<2){break a}G=W;X=(d[G]|d[G+1|0]<<8)<<16>>16;G=(he(X|0)|0)&65535;if(X<<16>>16==0){break a}else{Y=G;Z=W+2|0}}if((Y|0)==0){_=T;$=U;aa=Z}else{ba=Z;da=Y;E=226}}else{ba=P;da=F;E=226}if((E|0)==226){E=0;F=T;P=U;G=0;while(1){b[w+((F<<1)+(ca(P,u)|0))>>1]=Q;X=F+1|0;if((X|0)<(v|0)){ea=P;fa=X}else{X=P+1|0;if((X|0)<(x|0)){ea=X;fa=0}else{break a}}X=G+1|0;if((X|0)<(da|0)){F=fa;P=ea;G=X}else{_=fa;$=ea;aa=ba;break}}}if((o-aa|0)>>>0>1>>>0){T=_;U=$;V=aa}else{break}}}else{o=c[k>>2]|0;x=c[o+32>>2]|0;v=c[o+36>>2]|0;QIb(e,2205256,(t=i,i=i+24|0,c[t>>2]=c[o+28>>2],c[t+8>>2]=x,c[t+16>>2]=v,t)|0);i=t;s=-1094995529;i=j;return s|0}}else if((h|0)==5){if((c[e+52>>2]|0)!=1346716996){v=c[k>>2]|0;x=c[v+32>>2]|0;o=c[v+36>>2]|0;QIb(e,2205256,(t=i,i=i+24|0,c[t>>2]=c[v+28>>2],c[t+8>>2]=x,c[t+16>>2]=o,t)|0);i=t;s=-1094995529;i=j;return s|0}if((oKb(qKb(c[e+140>>2]|0)|0)|0)!=32){o=c[k>>2]|0;x=c[o+32>>2]|0;v=c[o+36>>2]|0;QIb(e,2205256,(t=i,i=i+24|0,c[t>>2]=c[o+28>>2],c[t+8>>2]=x,c[t+16>>2]=v,t)|0);i=t;s=-1094995529;i=j;return s|0}v=c[n>>2]|0;x=c[v>>2]|0;o=c[e+120>>2]|0;u=c[e+124>>2]|0;w=c[v+32>>2]|0;v=l+56|0;m=q<<1;G=~o;P=0;F=0;Q=0;while(1){X=F+(ca(Q,w)|0)|0;ga=P;ha=0;ia=0;while(1){if((ga|0)>=(m|0)){break a}ja=d[r+(ga>>1)|0]|0;ka=b[v+(((ga&1|0)!=0?ja&15:ja>>>4)<<1)>>1]|0;ja=ga+1|0;do{if(ka<<16>>16==0){if((ja|0)>=(m|0)){break a}la=d[r+(ja>>1)|0]|0;ma=(ja&1|0)!=0?la&15:la>>>4;la=ma+1|0;na=ga+2|0;oa=o-ia|0;pa=(la|0)>(oa|0)?oa:la;if((pa|0)<=0){qa=na;ra=ha;sa=ia;break}la=ia+G|0;oa=-2-ma|0;ma=(la|0)>(oa|0);ta=ia;ua=0;while(1){a[x+(X+(ta<<2))|0]=ha;va=ua+1|0;if((va|0)<(pa|0)){ta=ta+1|0;ua=va}else{break}}qa=na;ra=ha;sa=ia-1-(ma?la:oa)|0}else{ua=(ka&255)+ha&255;a[x+(X+(ia<<2))|0]=ua;qa=ja;ra=ua;sa=ia+1|0}}while(0);if((sa|0)<(o|0)){ga=qa;ha=ra;ia=sa}else{break}}ia=F+1|0;if((ia|0)>3){ha=Q+1|0;if((ha|0)<(u|0)){wa=0;xa=ha}else{break a}}else{wa=ia;xa=Q}P=qa+1&-2;F=wa;Q=xa}}else if((h|0)==1){Q=c[e+52>>2]|0;if((Q|0)==541934160){F=c[e+140>>2]|0;if((F|0)==11|(F|0)==8){F=e+124|0;if((c[F>>2]|0)<=0){break}P=e+120|0;u=p;o=0;x=r;while(1){G=c[n>>2]|0;m=ca(c[G+32>>2]|0,o)|0;v=c[G>>2]|0;G=c[P>>2]|0;b:do{if((G|0)==0){ya=x}else{w=0;ia=x;c:while(1){za=ia;while(1){if(!(za>>>0<p>>>0)){break c}Aa=za+1|0;ha=a[za]|0;Ba=ha<<24>>24;if(ha<<24>>24>-1){E=166;break}if(ha<<24>>24==-128){za=Aa}else{E=167;break}}if((E|0)==166){E=0;oa=Ba+1|0;la=G-w|0;ma=oa>>>0>la>>>0?la:oa;oa=u-Aa|0;la=ma>>>0>oa>>>0?oa:ma;nrc(v+(w+m)|0,Aa|0,la)|0;Ca=za+(la+1)|0;Da=la}else if((E|0)==167){E=0;la=1-Ba|0;ma=G-w|0;oa=la>>>0>ma>>>0?ma:la;mrc(v+(w+m)|0,a[Aa]|0,oa|0)|0;Ca=za+2|0;Da=oa}oa=Da+w|0;if(oa>>>0<G>>>0){w=oa;ia=Ca}else{ya=Ca;break b}}KIb(0,24,2247160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;mrc(v+(w+m)|0,0,G-w|0)|0;ya=za}}while(0);G=o+1|0;if((G|0)>=(c[F>>2]|0)){break a}o=G;x=x+(ya-x)|0}}if((c[l+36>>2]|0)==0){x=c[k>>2]|0;o=c[x+32>>2]|0;F=c[x+36>>2]|0;QIb(e,2205256,(t=i,i=i+24|0,c[t>>2]=c[x+28>>2],c[t+8>>2]=o,c[t+16>>2]=F,t)|0);i=t;s=-1094995529;i=j;return s|0}F=e+124|0;if((c[F>>2]|0)<=0){break}o=l+12|0;x=e+120|0;u=p;P=l+16|0;G=l+4|0;m=0;v=r;while(1){ia=c[n>>2]|0;oa=ca(c[ia+32>>2]|0,m)|0;la=(c[ia>>2]|0)+oa|0;oa=c[o>>2]|0;ia=c[x>>2]|0;d:do{if((ia|0)==0){Ea=v}else{ma=0;na=v;e:while(1){Fa=na;while(1){if(!(Fa>>>0<p>>>0)){break e}Ga=Fa+1|0;ha=a[Fa]|0;Ha=ha<<24>>24;if(ha<<24>>24>-1){E=180;break}if(ha<<24>>24==-128){Fa=Ga}else{E=181;break}}if((E|0)==180){E=0;ha=Ha+1|0;ga=ia-ma|0;X=ha>>>0>ga>>>0?ga:ha;ha=u-Ga|0;ga=X>>>0>ha>>>0?ha:X;nrc(oa+ma|0,Ga|0,ga)|0;Ia=Fa+(ga+1)|0;Ja=ga}else if((E|0)==181){E=0;ga=1-Ha|0;X=ia-ma|0;ha=ga>>>0>X>>>0?X:ga;mrc(oa+ma|0,a[Ga]|0,ha|0)|0;Ia=Fa+2|0;Ja=ha}ha=Ja+ma|0;if(ha>>>0<ia>>>0){ma=ha;na=Ia}else{Ea=Ia;break d}}KIb(0,24,2247160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;mrc(oa+ma|0,0,ia-ma|0)|0;Ea=Fa}}while(0);qLa(la,c[o>>2]|0,c[P>>2]|0,c[G>>2]|0);ia=m+1|0;if((ia|0)<(c[F>>2]|0)){m=ia;v=v+(Ea-v)|0}else{break}}}else if((Q|0)==1346716996){if((oKb(qKb(c[e+140>>2]|0)|0)|0)!=32){v=c[k>>2]|0;m=c[v+32>>2]|0;F=c[v+36>>2]|0;QIb(e,2205256,(t=i,i=i+24|0,c[t>>2]=c[v+28>>2],c[t+8>>2]=m,c[t+16>>2]=F,t)|0);i=t;s=-1094995529;i=j;return s|0}F=c[n>>2]|0;m=c[F>>2]|0;v=c[e+120>>2]|0;G=c[e+124>>2]|0;P=c[F+32>>2]|0;if((q|0)<5){break}F=0;o=0;u=r;x=r+5|0;while(1){ia=u+1|0;oa=a[u]|0;na=oa<<24>>24;do{if(oa<<24>>24>-1){w=na+1|0;if((w|0)>0){Ka=0;La=F;Ma=o;Na=ia}else{Oa=ia;Pa=o;Qa=F;break}while(1){ha=w-Ka|0;ga=(ha|0)>(v|0)?v:ha;ha=ga<<2;nrc(m+((ca(La,P)|0)+(Ma<<2))|0,Na|0,ha)|0;X=Na+ha|0;ha=ga+Ma|0;if((ha|0)<(v|0)){Ra=ha;Sa=La}else{ha=La+1|0;if((ha|0)<(G|0)){Ra=0;Sa=ha}else{break a}}ha=Ka+1+ga|0;if((ha|0)<(w|0)){Ka=ha;La=Sa;Ma=Ra;Na=X}else{Oa=X;Pa=Ra;Qa=Sa;break}}}else{w=1-na|0;ma=ia;X=d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0;if((w|0)>0){Ta=0;Ua=F;Va=o}else{Oa=x;Pa=o;Qa=F;break}while(1){c[m+((ca(Ua,P)|0)+(Va<<2))>>2]=X;ma=Va+1|0;if((ma|0)<(v|0)){Wa=ma;Xa=Ua}else{ma=Ua+1|0;if((ma|0)<(G|0)){Wa=0;Xa=ma}else{break a}}ma=Ta+1|0;if((ma|0)<(w|0)){Ta=ma;Ua=Xa;Va=Wa}else{Oa=x;Pa=Wa;Qa=Xa;break}}}}while(0);ia=Oa+5|0;if(ia>>>0>p>>>0){break}else{F=Qa;o=Pa;u=Oa;x=ia}}}else if((Q|0)==1296190537){x=c[e+140>>2]|0;if((x|0)==11|(x|0)==8){x=e+124|0;if((c[x>>2]|0)<=0){break}u=e+120|0;o=l+32|0;F=l+8|0;G=l+4|0;v=p;P=0;m=r;while(1){ia=c[n>>2]|0;na=ca(c[ia+32>>2]|0,P)|0;oa=(c[ia>>2]|0)+na|0;mrc(oa|0,0,c[u>>2]|0)|0;if((c[o>>2]|0)==0){Ya=m}else{na=0;ia=m;while(1){la=c[F>>2]|0;w=c[G>>2]|0;f:do{if((w|0)==0){Za=ia}else{X=0;ma=ia;g:while(1){_a=ma;while(1){if(!(_a>>>0<p>>>0)){break g}$a=_a+1|0;ha=a[_a]|0;ab=ha<<24>>24;if(ha<<24>>24>-1){E=91;break}if(ha<<24>>24==-128){_a=$a}else{E=92;break}}if((E|0)==91){E=0;ha=ab+1|0;ga=w-X|0;ja=ha>>>0>ga>>>0?ga:ha;ha=v-$a|0;ga=ja>>>0>ha>>>0?ha:ja;nrc(la+X|0,$a|0,ga)|0;bb=_a+(ga+1)|0;cb=ga}else if((E|0)==92){E=0;ga=1-ab|0;ja=w-X|0;ha=ga>>>0>ja>>>0?ja:ga;mrc(la+X|0,a[$a]|0,ha|0)|0;bb=_a+2|0;cb=ha}ha=cb+X|0;if(ha>>>0<w>>>0){X=ha;ma=bb}else{Za=bb;break f}}KIb(0,24,2247160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;mrc(la+X|0,0,w-X|0)|0;Za=_a}}while(0);w=ia+(Za-ia)|0;if((na|0)>7){KIb(0,24,2173080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{la=oa;ma=c[F>>2]|0;ha=c[G>>2]|0;while(1){ga=la;ja=704256+(na<<11)+((d[ma]|0)<<3)|0;ka=c[ja+4>>2]|c[ga+4>>2];c[ga>>2]=c[ja>>2]|c[ga>>2];c[ga+4>>2]=ka;ka=ha-1|0;if((ka|0)==0){break}else{la=la+8|0;ma=ma+1|0;ha=ka}}}ha=na+1|0;if(ha>>>0<(c[o>>2]|0)>>>0){na=ha;ia=w}else{Ya=w;break}}}ia=P+1|0;if((ia|0)<(c[x>>2]|0)){P=ia;m=Ya}else{break a}}}if((c[e+792>>2]|0)<9){m=e+124|0;if((c[m>>2]|0)<=0){break}P=l+20|0;x=e+120|0;o=l+32|0;G=l+24|0;F=l+8|0;v=l+4|0;u=p;Q=0;ia=r;na=c[P>>2]|0;while(1){oa=c[n>>2]|0;ha=ca(c[oa+32>>2]|0,Q)|0;ma=(c[oa>>2]|0)+ha|0;mrc(na|0,0,c[x>>2]<<2|0)|0;if((c[o>>2]|0)==0){db=ia;eb=c[P>>2]|0}else{ha=0;oa=ia;la=c[F>>2]|0;while(1){ka=c[v>>2]|0;h:do{if((ka|0)==0){fb=oa}else{ga=0;ja=oa;i:while(1){gb=ja;while(1){if(!(gb>>>0<p>>>0)){break i}hb=gb+1|0;ua=a[gb]|0;ib=ua<<24>>24;if(ua<<24>>24>-1){E=112;break}if(ua<<24>>24==-128){gb=hb}else{E=113;break}}if((E|0)==112){E=0;ua=ib+1|0;ta=ka-ga|0;pa=ua>>>0>ta>>>0?ta:ua;ua=u-hb|0;ta=pa>>>0>ua>>>0?ua:pa;nrc(la+ga|0,hb|0,ta)|0;jb=gb+(ta+1)|0;kb=ta}else if((E|0)==113){E=0;ta=1-ib|0;pa=ka-ga|0;ua=ta>>>0>pa>>>0?pa:ta;mrc(la+ga|0,a[hb]|0,ua|0)|0;jb=gb+2|0;kb=ua}ua=kb+ga|0;if(ua>>>0<ka>>>0){ga=ua;ja=jb}else{fb=jb;break h}}KIb(0,24,2247160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;mrc(la+ga|0,0,ka-ga|0)|0;fb=gb}}while(0);ka=fb-oa|0;w=c[P>>2]|0;ja=c[F>>2]|0;X=w;ua=ja;ta=c[v>>2]|0;while(1){pa=(d[ua]|0)>>>2;va=pa&60;lb=va|1;c[X>>2]=c[X>>2]|c[720640+(ha<<8)+(va<<2)>>2];va=X+4|0;c[va>>2]=c[va>>2]|c[720640+(ha<<8)+(lb<<2)>>2];va=X+8|0;c[va>>2]=c[va>>2]|c[720640+(ha<<8)+(lb+1<<2)>>2];lb=X+12|0;c[lb>>2]=c[lb>>2]|c[720640+(ha<<8)+((pa|3)<<2)>>2];pa=(d[ua]|0)<<2&60;lb=pa|1;va=X+16|0;c[va>>2]=c[va>>2]|c[720640+(ha<<8)+(pa<<2)>>2];va=X+20|0;c[va>>2]=c[va>>2]|c[720640+(ha<<8)+(lb<<2)>>2];va=X+24|0;c[va>>2]=c[va>>2]|c[720640+(ha<<8)+(lb+1<<2)>>2];lb=X+28|0;c[lb>>2]=c[lb>>2]|c[720640+(ha<<8)+((pa|3)<<2)>>2];pa=ta-1|0;if((pa|0)==0){break}else{X=X+32|0;ua=ua+1|0;ta=pa}}ta=oa+ka|0;ua=ha+1|0;if(ua>>>0<(c[o>>2]|0)>>>0){ha=ua;oa=ta;la=ja}else{db=ta;eb=w;break}}}la=c[G>>2]|0;oa=c[x>>2]|0;ha=ma;ta=eb;while(1){c[ha>>2]=c[la+(c[ta>>2]<<2)>>2];ua=oa-1|0;if((ua|0)==0){break}else{oa=ua;ha=ha+4|0;ta=ta+4|0}}ta=Q+1|0;if((ta|0)<(c[m>>2]|0)){Q=ta;ia=db;na=eb}else{break a}}}na=e+124|0;ia=(c[na>>2]|0)>0;if((c[l+36>>2]|0)==0){if(!ia){break}Q=e+120|0;m=l+32|0;x=l+8|0;G=l+4|0;o=p;v=0;F=r;while(1){P=c[n>>2]|0;u=ca(c[P+32>>2]|0,v)|0;ta=(c[P>>2]|0)+u|0;mrc(ta|0,0,c[Q>>2]<<2|0)|0;if((c[m>>2]|0)==0){mb=F}else{u=ta;ta=0;P=F;ha=c[x>>2]|0;while(1){oa=c[G>>2]|0;j:do{if((oa|0)==0){nb=P}else{la=0;ma=P;k:while(1){ob=ma;while(1){if(!(ob>>>0<p>>>0)){break k}pb=ob+1|0;ua=a[ob]|0;qb=ua<<24>>24;if(ua<<24>>24>-1){E=150;break}if(ua<<24>>24==-128){ob=pb}else{E=151;break}}if((E|0)==150){E=0;ua=qb+1|0;X=oa-la|0;pa=ua>>>0>X>>>0?X:ua;ua=o-pb|0;X=pa>>>0>ua>>>0?ua:pa;nrc(ha+la|0,pb|0,X)|0;rb=ob+(X+1)|0;sb=X}else if((E|0)==151){E=0;X=1-qb|0;pa=oa-la|0;ua=X>>>0>pa>>>0?pa:X;mrc(ha+la|0,a[pb]|0,ua|0)|0;rb=ob+2|0;sb=ua}ua=sb+la|0;if(ua>>>0<oa>>>0){la=ua;ma=rb}else{nb=rb;break j}}KIb(0,24,2247160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;mrc(ha+la|0,0,oa-la|0)|0;nb=ob}}while(0);oa=nb-P|0;w=c[x>>2]|0;ja=u;ka=w;ma=c[G>>2]|0;while(1){ga=(d[ka]|0)>>>2;ua=ga&60;X=ua|1;c[ja>>2]=c[ja>>2]|c[720640+(ta<<8)+(ua<<2)>>2];ua=ja+4|0;c[ua>>2]=c[ua>>2]|c[720640+(ta<<8)+(X<<2)>>2];ua=ja+8|0;c[ua>>2]=c[ua>>2]|c[720640+(ta<<8)+(X+1<<2)>>2];X=ja+12|0;c[X>>2]=c[X>>2]|c[720640+(ta<<8)+((ga|3)<<2)>>2];ga=(d[ka]|0)<<2&60;X=ga|1;ua=ja+16|0;c[ua>>2]=c[ua>>2]|c[720640+(ta<<8)+(ga<<2)>>2];ua=ja+20|0;c[ua>>2]=c[ua>>2]|c[720640+(ta<<8)+(X<<2)>>2];ua=ja+24|0;c[ua>>2]=c[ua>>2]|c[720640+(ta<<8)+(X+1<<2)>>2];X=ja+28|0;c[X>>2]=c[X>>2]|c[720640+(ta<<8)+((ga|3)<<2)>>2];ga=ma-1|0;if((ga|0)==0){break}else{ja=ja+32|0;ka=ka+1|0;ma=ga}}ma=P+oa|0;ka=ta+1|0;if(ka>>>0<(c[m>>2]|0)>>>0){ta=ka;P=ma;ha=w}else{mb=ma;break}}}ha=v+1|0;if((ha|0)<(c[na>>2]|0)){v=ha;F=mb}else{break a}}}if(!ia){break}F=l+12|0;v=l+4|0;m=l+32|0;G=l+16|0;x=l+8|0;o=p;Q=0;ha=r;while(1){P=c[n>>2]|0;ta=ca(c[P+32>>2]|0,Q)|0;u=(c[P>>2]|0)+ta|0;mrc(c[F>>2]|0,0,c[v>>2]<<3|0)|0;if((c[m>>2]|0)==0){tb=ha}else{ta=0;P=ha;while(1){ma=c[x>>2]|0;ka=c[v>>2]|0;l:do{if((ka|0)==0){ub=P}else{ja=0;ga=P;m:while(1){vb=ga;while(1){if(!(vb>>>0<p>>>0)){break m}wb=vb+1|0;X=a[vb]|0;xb=X<<24>>24;if(X<<24>>24>-1){E=133;break}if(X<<24>>24==-128){vb=wb}else{E=134;break}}if((E|0)==133){E=0;X=xb+1|0;ua=ka-ja|0;pa=X>>>0>ua>>>0?ua:X;X=o-wb|0;ua=pa>>>0>X>>>0?X:pa;nrc(ma+ja|0,wb|0,ua)|0;yb=vb+(ua+1)|0;zb=ua}else if((E|0)==134){E=0;ua=1-xb|0;pa=ka-ja|0;X=ua>>>0>pa>>>0?pa:ua;mrc(ma+ja|0,a[wb]|0,X|0)|0;yb=vb+2|0;zb=X}X=zb+ja|0;if(X>>>0<ka>>>0){ja=X;ga=yb}else{ub=yb;break l}}KIb(0,24,2247160,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;mrc(ma+ja|0,0,ka-ja|0)|0;ub=vb}}while(0);ka=P+(ub-P)|0;if((ta|0)>7){KIb(0,24,2173080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{ma=c[F>>2]|0;w=c[x>>2]|0;oa=c[v>>2]|0;while(1){ga=ma;la=704256+(ta<<11)+((d[w]|0)<<3)|0;X=c[la+4>>2]|c[ga+4>>2];c[ga>>2]=c[la>>2]|c[ga>>2];c[ga+4>>2]=X;X=oa-1|0;if((X|0)==0){break}else{ma=ma+8|0;w=w+1|0;oa=X}}}oa=ta+1|0;if(oa>>>0<(c[m>>2]|0)>>>0){ta=oa;P=ka}else{tb=ka;break}}}qLa(u,c[F>>2]|0,c[G>>2]|0,c[v>>2]|0);P=Q+1|0;if((P|0)<(c[na>>2]|0)){Q=P;ha=tb}else{break}}}else{break}}else if((h|0)==0){ha=c[e+52>>2]|0;if((ha|0)==541934160){Q=c[e+140>>2]|0;if((Q|0)==11|(Q|0)==8){Q=e+124|0;if(!((c[Q>>2]|0)>0&(q|0)>0)){break}na=e+120|0;v=p;G=0;F=r;m=c[na>>2]|0;while(1){x=c[n>>2]|0;o=ca(c[x+32>>2]|0,G)|0;ia=v-F|0;nrc((c[x>>2]|0)+o|0,F|0,(m|0)>(ia|0)?ia:m)|0;m=c[na>>2]|0;F=F+(((m|0)%2|0)+m)|0;G=G+1|0;if(!((G|0)<(c[Q>>2]|0)&p>>>0>F>>>0)){break a}}}if((c[l+36>>2]|0)==0){F=c[k>>2]|0;Q=c[F+32>>2]|0;G=c[F+36>>2]|0;QIb(e,2205256,(t=i,i=i+24|0,c[t>>2]=c[F+28>>2],c[t+8>>2]=Q,c[t+16>>2]=G,t)|0);i=t;s=-1094995529;i=j;return s|0}G=e+124|0;if(!((c[G>>2]|0)>0&(q|0)>0)){break}Q=l+12|0;F=e+120|0;m=p;na=l+16|0;v=l+4|0;ia=0;o=r;do{x=c[n>>2]|0;P=ca(c[x+32>>2]|0,ia)|0;ta=(c[x>>2]|0)+P|0;P=c[F>>2]|0;x=m-o|0;nrc(c[Q>>2]|0,o|0,(P|0)>(x|0)?x:P)|0;P=c[F>>2]|0;o=o+((P&1)+P)|0;qLa(ta,c[Q>>2]|0,c[na>>2]|0,c[v>>2]|0);ia=ia+1|0;}while((ia|0)<(c[G>>2]|0)&p>>>0>o>>>0)}else if((ha|0)==1296188225){o=c[e+140>>2]|0;if((o|0)==11|(o|0)==8){o=c[n>>2]|0;G=e+124|0;mrc(c[o>>2]|0,0,ca(c[o+32>>2]|0,c[G>>2]|0)|0)|0;o=l+32|0;ia=c[o>>2]|0;if((ia|0)==0){break}v=l+4|0;na=p;Q=0;F=r;m=c[G>>2]|0;ta=ia;while(1){if((m|0)>0&F>>>0<p>>>0){if((Q|0)>7){ia=0;P=F;while(1){KIb(0,24,2173080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;x=c[G>>2]|0;oa=P+(c[v>>2]|0)|0;w=ia+1|0;if((w|0)<(x|0)&oa>>>0<p>>>0){ia=w;P=oa}else{Ab=oa;Bb=x;break}}}else{P=0;ia=F;u=c[v>>2]|0;while(1){x=c[n>>2]|0;oa=na-ia|0;w=ca(c[x+32>>2]|0,P)|0;ma=(c[x>>2]|0)+w|0;w=ia;x=(u|0)>(oa|0)?oa:u;while(1){oa=ma;X=704256+(Q<<11)+((d[w]|0)<<3)|0;ga=c[X+4>>2]|c[oa+4>>2];c[oa>>2]=c[X>>2]|c[oa>>2];c[oa+4>>2]=ga;ga=x-1|0;if((ga|0)==0){break}else{ma=ma+8|0;w=w+1|0;x=ga}}x=c[v>>2]|0;w=c[G>>2]|0;ma=ia+x|0;ka=P+1|0;if((ka|0)<(w|0)&ma>>>0<p>>>0){P=ka;ia=ma;u=x}else{Ab=ma;Bb=w;break}}}Cb=Ab;Db=Bb;Eb=c[o>>2]|0}else{Cb=F;Db=m;Eb=ta}u=Q+1|0;if(u>>>0<Eb>>>0){Q=u;F=Cb;m=Db;ta=Eb}else{break a}}}if((c[l+36>>2]|0)==0){ta=c[k>>2]|0;m=c[ta+32>>2]|0;F=c[ta+36>>2]|0;QIb(e,2205256,(t=i,i=i+24|0,c[t>>2]=c[ta+28>>2],c[t+8>>2]=m,c[t+16>>2]=F,t)|0);i=t;s=-1094995529;i=j;return s|0}F=c[n>>2]|0;m=e+124|0;mrc(c[F>>2]|0,0,ca(c[F+32>>2]|0,c[m>>2]|0)|0)|0;if((c[m>>2]|0)<=0){break}F=l+12|0;ta=l+4|0;Q=l+32|0;o=l+16|0;G=p;v=0;do{na=c[n>>2]|0;u=ca(c[na+32>>2]|0,v)|0;ia=(c[na>>2]|0)+u|0;mrc(c[F>>2]|0,0,c[ta>>2]<<3|0)|0;n:do{if((c[Q>>2]|0)!=0){u=0;do{na=(ca(c[m>>2]|0,u)|0)+v|0;P=c[ta>>2]|0;w=ca(na,P)|0;na=r+w|0;if((w|0)>=(q|0)){break n}w=G-na|0;if((u|0)>7){KIb(0,24,2173080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{ma=c[F>>2]|0;x=na;na=(P|0)>(w|0)?w:P;while(1){P=ma;w=704256+(u<<11)+((d[x]|0)<<3)|0;ka=c[w+4>>2]|c[P+4>>2];c[P>>2]=c[w>>2]|c[P>>2];c[P+4>>2]=ka;ka=na-1|0;if((ka|0)==0){break}else{ma=ma+8|0;x=x+1|0;na=ka}}}u=u+1|0;}while(u>>>0<(c[Q>>2]|0)>>>0)}}while(0);qLa(ia,c[F>>2]|0,c[o>>2]|0,c[ta>>2]|0);v=v+1|0;}while((v|0)<(c[m>>2]|0))}else if((ha|0)==1296190537){m=c[e+140>>2]|0;if((m|0)==11|(m|0)==8){m=e+124|0;if((c[m>>2]|0)<=0){break}v=e+120|0;ta=l+32|0;o=l+4|0;F=p;Q=0;G=r;while(1){u=c[n>>2]|0;na=ca(c[u+32>>2]|0,Q)|0;x=(c[u>>2]|0)+na|0;mrc(x|0,0,c[v>>2]|0)|0;if((c[ta>>2]|0)!=0&G>>>0<p>>>0){na=0;u=G;ma=c[o>>2]|0;while(1){ja=F-u|0;if((na|0)>7){KIb(0,24,2173080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{ka=x;P=u;w=(ma|0)>(ja|0)?ja:ma;while(1){ja=ka;ga=704256+(na<<11)+((d[P]|0)<<3)|0;oa=c[ga+4>>2]|c[ja+4>>2];c[ja>>2]=c[ga>>2]|c[ja>>2];c[ja+4>>2]=oa;oa=w-1|0;if((oa|0)==0){break}else{ka=ka+8|0;P=P+1|0;w=oa}}}w=c[o>>2]|0;P=u+w|0;ka=na+1|0;if(ka>>>0<(c[ta>>2]|0)>>>0&P>>>0<p>>>0){na=ka;u=P;ma=w}else{Fb=P;break}}}else{Fb=G}ma=Q+1|0;if((ma|0)<(c[m>>2]|0)){Q=ma;G=Fb}else{break a}}}G=e+124|0;Q=(c[G>>2]|0)>0;if((c[l+36>>2]|0)==0){if(!Q){break}m=e+120|0;ta=l+32|0;o=l+4|0;F=p;v=0;ma=r;while(1){u=c[n>>2]|0;na=ca(c[u+32>>2]|0,v)|0;x=(c[u>>2]|0)+na|0;mrc(x|0,0,c[m>>2]<<2|0)|0;if((c[ta>>2]|0)!=0&ma>>>0<p>>>0){na=x;x=0;u=ma;ia=c[o>>2]|0;while(1){P=F-u|0;w=na;ka=u;oa=(ia|0)>(P|0)?P:ia;while(1){P=(d[ka]|0)>>>2;ja=P&60;ga=ja|1;c[w>>2]=c[w>>2]|c[720640+(x<<8)+(ja<<2)>>2];ja=w+4|0;c[ja>>2]=c[ja>>2]|c[720640+(x<<8)+(ga<<2)>>2];ja=w+8|0;c[ja>>2]=c[ja>>2]|c[720640+(x<<8)+(ga+1<<2)>>2];ga=w+12|0;c[ga>>2]=c[ga>>2]|c[720640+(x<<8)+((P|3)<<2)>>2];P=(d[ka]|0)<<2&60;ga=P|1;ja=w+16|0;c[ja>>2]=c[ja>>2]|c[720640+(x<<8)+(P<<2)>>2];ja=w+20|0;c[ja>>2]=c[ja>>2]|c[720640+(x<<8)+(ga<<2)>>2];ja=w+24|0;c[ja>>2]=c[ja>>2]|c[720640+(x<<8)+(ga+1<<2)>>2];ga=w+28|0;c[ga>>2]=c[ga>>2]|c[720640+(x<<8)+((P|3)<<2)>>2];P=oa-1|0;if((P|0)==0){break}else{w=w+32|0;ka=ka+1|0;oa=P}}oa=c[o>>2]|0;ka=u+oa|0;w=x+1|0;if(w>>>0<(c[ta>>2]|0)>>>0&ka>>>0<p>>>0){x=w;u=ka;ia=oa}else{Gb=ka;break}}}else{Gb=ma}ia=v+1|0;if((ia|0)<(c[G>>2]|0)){v=ia;ma=Gb}else{break a}}}if(!Q){break}ma=l+12|0;v=l+4|0;ta=l+32|0;o=l+16|0;F=p;m=0;ia=r;while(1){u=c[n>>2]|0;x=ca(c[u+32>>2]|0,m)|0;na=(c[u>>2]|0)+x|0;mrc(c[ma>>2]|0,0,c[v>>2]<<3|0)|0;x=c[v>>2]|0;if((c[ta>>2]|0)!=0&ia>>>0<p>>>0){u=0;ka=ia;oa=x;while(1){w=F-ka|0;if((u|0)>7){KIb(0,24,2173080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}else{P=c[ma>>2]|0;ga=ka;ja=(oa|0)>(w|0)?w:oa;while(1){w=P;X=704256+(u<<11)+((d[ga]|0)<<3)|0;la=c[X+4>>2]|c[w+4>>2];c[w>>2]=c[X>>2]|c[w>>2];c[w+4>>2]=la;la=ja-1|0;if((la|0)==0){break}else{P=P+8|0;ga=ga+1|0;ja=la}}}ja=c[v>>2]|0;ga=ka+ja|0;P=u+1|0;if(P>>>0<(c[ta>>2]|0)>>>0&ga>>>0<p>>>0){u=P;ka=ga;oa=ja}else{Hb=ga;Ib=ja;break}}}else{Hb=ia;Ib=x}qLa(na,c[ma>>2]|0,c[o>>2]|0,Ib);oa=m+1|0;if((oa|0)<(c[G>>2]|0)){m=oa;ia=Hb}else{break}}}else if((ha|0)==1346716996){ia=e+140|0;m=qKb(c[ia>>2]|0)|0;G=e+120|0;o=c[G>>2]|0;ma=ca((oKb(m)|0)>>3,o)|0;o=e+124|0;if(!((c[o>>2]|0)>0&(q|0)>0)){break}m=p;ta=0;v=r;do{F=c[n>>2]|0;Q=ca(c[F+32>>2]|0,ta)|0;oa=c[F>>2]|0;F=m-v|0;nrc(oa+Q|0,v|0,(ma|0)>(F|0)?F:ma)|0;v=v+ma|0;do{if((c[ia>>2]|0)==28){if((c[G>>2]|0)>0){Jb=0}else{break}do{F=oa+((Jb<<2|3)+Q)|0;ka=a[F]|0;a[F]=ka&-16|(ka&255)>>>4;Jb=Jb+1|0;}while((Jb|0)<(c[G>>2]|0))}}while(0);ta=ta+1|0;}while((ta|0)<(c[o>>2]|0)&v>>>0<p>>>0)}else{break}}else{v=c[k>>2]|0;o=c[v+32>>2]|0;ta=c[v+36>>2]|0;QIb(e,2205256,(t=i,i=i+24|0,c[t>>2]=c[v+28>>2],c[t+8>>2]=o,c[t+16>>2]=ta,t)|0);i=t;s=-1094995529;i=j;return s|0}}while(0);t=YHb(f,c[n>>2]|0)|0;if((t|0)<0){s=t;i=j;return s|0}c[g>>2]=1;s=q;i=j;return s|0}function nLa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b);mJb(b+8|0);mJb(b+12|0);mJb(b+16|0);return 0}function oLa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=c[e+60>>2]|0;j=c[e+100>>2]|0;if((j|0)<2){KIb(e,16,2121888,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}m=e+96|0;n=c[m>>2]|0;o=n;p=he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0;o=p&65535;q=j-o|0;do{if((f|0)==0){if(!((p&65535)>>>0<2>>>0|(q|0)<0)){r=o;s=n;break}KIb(e,16,2616760,(k=i,i=i+16|0,c[k>>2]=o,c[k+8>>2]=q,k)|0);i=k;l=-1094995529;i=g;return l|0}else{j=c[f+28>>2]|0;if((j|0)<2){l=-1094995529;i=g;return l|0}t=c[f+24>>2]|0;u=t;v=he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=v&65535;w=j-u|0;if(!((v&65535)>>>0<2>>>0|(w|0)<2)){r=u;s=t;break}KIb(e,16,2639448,(k=i,i=i+16|0,c[k>>2]=u,c[k+8>>2]=w,k)|0);i=k;l=-1094995529;i=g;return l|0}}while(0);if(!(r>>>0>40>>>0)){l=0;i=g;return l|0}c[h+28>>2]=d[s+2|0]|0;r=a[s+3|0]|0;f=r&255;o=h+32|0;c[o>>2]=f;n=a[s+4|0]|0;p=h+36|0;c[p>>2]=n&255;c[h+40>>2]=d[s+5|0]|0;w=s+6|0;c[h+44>>2]=(he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535;w=d[s+8|0]|0;u=h+48|0;c[u>>2]=w;t=s+9|0;b[h+56>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+11|0;b[h+58>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+13|0;b[h+60>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+15|0;b[h+62>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+17|0;b[h+64>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+19|0;b[h+66>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+21|0;b[h+68>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+23|0;b[h+70>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+25|0;b[h+72>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+27|0;b[h+74>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+29|0;b[h+76>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+31|0;b[h+78>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+33|0;b[h+80>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+35|0;b[h+82>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+37|0;b[h+84>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=s+39|0;b[h+86>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;if((w|0)==0|(w|0)==2){x=f}else if((w|0)==1){y=11}else{KIb(e,16,2567920,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=g;return l|0}if((y|0)==11){do{if((r&255)>>>0>7>>>0&n<<24>>24==0){c[e+140>>2]=30;w=h+20|0;mJb(w);t=h+24|0;mJb(t);s=hJb(c[h+4>>2]<<5|16)|0;c[w>>2]=s;if((s|0)==0){l=-12;i=g;return l|0}s=c[o>>2]|0;if(s>>>0>16>>>0){KIb(e,16,2589576,(k=i,i=i+8|0,c[k>>2]=s,k)|0);i=k;mJb(w);l=-12;i=g;return l|0}v=hJb((8<<s)+16|0)|0;c[t>>2]=v;if((v|0)!=0){z=c[o>>2]|0;break}mJb(w);l=-12;i=g;return l|0}else{z=f}}while(0);f=z+1|0;c[o>>2]=f;x=f}if((x|0)==0|x>>>0>32>>>0){KIb(e,16,2549832,(k=i,i=i+8|0,c[k>>2]=x,k)|0);i=k;l=-1094995529;i=g;return l|0}x=c[p>>2]|0;if(x>>>0>7>>>0){KIb(e,16,2531712,(k=i,i=i+8|0,c[k>>2]=x,k)|0);i=k;l=-1094995529;i=g;return l|0}k=h+12|0;mJb(k);x=h+16|0;e=x;mJb(x);x=c[p>>2]|0;if((x|0)==0){l=0;i=g;return l|0}f=(q|0)/3|0;q=1<<x;x=(f|0)>(q|0)?q:f;f=c[m>>2]|0;m=f;q=(he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535;m=hJb((c[h+4>>2]<<3)+16|0)|0;c[k>>2]=m;if((m|0)==0){l=-12;i=g;return l|0}m=8<<c[p>>2];h=hJb((m<<((c[u>>2]|0)==1)<<2)+16|0)|0;z=h;c[e>>2]=z;if((h|0)==0){mJb(k);l=-12;i=g;return l|0}k=c[p>>2]|0;do{if((x|0)==0){n=1<<k;if((n|0)>0){A=0}else{break}while(1){r=A<<1;c[z+(r<<2)>>2]=-16777216;w=(A*255|0)>>c[p>>2];c[z+((r|1)<<2)>>2]=w|w<<8|w<<16|-16777216;w=A+1|0;if((w|0)<(n|0)){A=w}else{B=n;y=35;break}}}else{mrc(h|0,0,8<<k|0)|0;if((x|0)>0){n=c[e>>2]|0;w=0;do{r=(w*3|0)+q|0;c[n+((w<<1|1)<<2)>>2]=(d[f+(r+2)|0]|0)<<16|(d[f+(r+1)|0]|0)<<8|(d[f+r|0]|0)|-16777216;w=w+1|0;}while((w|0)<(x|0))}B=1<<c[p>>2];y=35}}while(0);do{if((y|0)==35){if((B|0)<=0){break}x=c[e>>2]|0;f=B<<1;q=B*3|0;k=0;do{h=c[p>>2]|0;A=k<<8-h;z=A>>>(h>>>0)|A;A=k+B<<1;c[x+(A<<2)>>2]=-16711681;h=k+f<<1;c[x+(h<<2)>>2]=-256;w=k+q<<1;c[x+(w<<2)>>2]=-65281;c[x+((A|1)<<2)>>2]=z<<16|-16777216;c[x+((h|1)<<2)>>2]=z|-16777216;c[x+((w|1)<<2)>>2]=z<<8|-16777216;k=k+1|0;}while((k|0)<(B|0))}}while(0);if(!((c[u>>2]|0)==1&(m|0)>0)){l=0;i=g;return l|0}u=c[e>>2]|0;e=0;while(1){c[u+((1<<c[o>>2])+e<<2)>>2]=c[u+(e<<2)>>2]|-16777216;B=e+1|0;if((B|0)<(m|0)){e=B}else{l=0;break}}i=g;return l|0}function pLa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[a+60>>2]|0;g=c[a+96>>2]|0;h=g;j=(he((d[h]|d[h+1|0]<<8)<<16>>16|0)|0)&65535;h=a+792|0;k=c[h>>2]|0;if((k|0)>8){KIb(a,16,2145672,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=e;return m|0}l=1<<k;n=((c[a+100>>2]|0)-j|0)/3|0;a=(n|0)>(l|0)?l:n;a:do{if((a|0)==0){if((l|0)>0){o=0;p=k}else{q=l;break}while(1){n=(o*255|0)>>p;c[b+(o<<2)>>2]=n|n<<8|n<<16|-16777216;n=o+1|0;if((n|0)>=(l|0)){q=l;break a}o=n;p=c[h>>2]|0}}else{if((a|0)>0){r=0}else{q=a;break}do{n=(r*3|0)+j|0;c[b+(r<<2)>>2]=(d[g+n|0]|0)<<16|(d[g+(n+1)|0]|0)<<8|(d[g+(n+2)|0]|0)|-16777216;r=r+1|0;}while((r|0)<(a|0));if((c[f+40>>2]|0)!=0&(a|0)>31){s=0}else{q=a;break}do{n=(s*3|0)+j|0;c[b+(s+32<<2)>>2]=((d[g+(n+1)|0]|0)<<8|(d[g+n|0]|0)<<16|(d[g+(n+2)|0]|0))>>>1&8355711|-16777216;s=s+1|0;}while((s|0)<32);q=(a|0)>64?a:64}}while(0);a=c[f+48>>2]|0;if((a|0)==1){nrc(b+(1<<c[h>>2]<<2)|0,b|0,q<<2)|0;if((q|0)>0){t=0}else{m=0;i=e;return m|0}while(1){s=b+(t<<2)|0;c[s>>2]=c[s>>2]&16777215;s=t+1|0;if((s|0)<(q|0)){t=s}else{m=0;break}}i=e;return m|0}else if((a|0)==2){a=c[f+44>>2]|0;if(!(a>>>0<1<<c[h>>2]>>>0)){m=0;i=e;return m|0}h=b+(a<<2)|0;c[h>>2]=c[h>>2]&16777215;m=0;i=e;return m|0}else{m=0;i=e;return m|0}return 0}function qLa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=a;a=b;b=c[e+4>>2]|0;h=f;while(1){f=(d[a]|0)<<1;i=(d[a+1|0]|0)<<1;j=c[e+(f<<2)>>2]&b|c[e+((f|1)<<2)>>2];c[g>>2]=j;f=j&c[e+(i<<2)>>2]|c[e+((i|1)<<2)>>2];c[g+4>>2]=f;i=(d[a+2|0]|0)<<1;j=(d[a+3|0]|0)<<1;k=c[e+(i<<2)>>2]&f|c[e+((i|1)<<2)>>2];c[g+8>>2]=k;i=k&c[e+(j<<2)>>2]|c[e+((j|1)<<2)>>2];c[g+12>>2]=i;j=(d[a+4|0]|0)<<1;k=(d[a+5|0]|0)<<1;f=c[e+(j<<2)>>2]&i|c[e+((j|1)<<2)>>2];c[g+16>>2]=f;j=f&c[e+(k<<2)>>2]|c[e+((k|1)<<2)>>2];c[g+20>>2]=j;k=(d[a+6|0]|0)<<1;f=(d[a+7|0]|0)<<1;i=c[e+(k<<2)>>2]&j|c[e+((k|1)<<2)>>2];c[g+24>>2]=i;k=i&c[e+(f<<2)>>2]|c[e+((f|1)<<2)>>2];c[g+28>>2]=k;f=h-1|0;if((f|0)==0){break}else{g=g+32|0;a=a+8|0;b=k;h=f}}return}function rLa(e){e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0.0,B=0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0;f=i;i=i+768|0;j=f|0;k=f+256|0;l=f+512|0;m=c[e+60>>2]|0;n=m;o=e+48|0;p=e+416|0;do{if((c[o>>2]|0)==86043){c[p>>2]=1;q=e+416|0;r=5}else{s=c[p>>2]|0;t=e+416|0;if((s|0)<=2){if((s|0)>0){q=t;r=5;break}else{u=t;break}}QIb(e,2567896,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1163346256;i=f;return w|0}}while(0);if((r|0)==5){r=m;p=0;while(1){t=m+((p*7044|0)+6016)|0;c[r+(p*7044|0)+7040>>2]=1;s=0;do{g[r+(p*7044|0)+(s<<2)>>2]=1.0;s=s+1|0;}while((s|0)<32);mrc(t|0,0,512)|0;s=p+1|0;if((s|0)<(c[q>>2]|0)){p=s}else{u=q;break}}}q=m+14088|0;p=q;G0a(q,256);q=0;do{r=p+(q<<2)|0;g[r>>2]=+g[r>>2]*1.4142135623730951;q=q+1|0;}while((q|0)<256);q=m+15112|0;p=m+16136|0;r=m+17160|0;s=m+18184|0;x=0;do{y=+(x|0);z=y*.00390625*3.141592653589793;g[q+(x<<2)>>2]=+U(z)*30517578125.0e-15;g[p+(x<<2)>>2]=+V(z)*30517578125.0e-15;z=(y*4.0+1.0)*.0009765625*3.141592653589793;y=+V(z);A=+U(z);z=y+A;if((x&1|0)==0){g[r+(x<<2)>>2]=z*-1.4142135623730951;g[s+(x<<2)>>2]=(y-A)*1.4142135623730951}else{g[r+(x<<2)>>2]=z*1.4142135623730951;g[s+(x<<2)>>2]=(y-A)*-1.4142135623730951}x=x+1|0;}while((x|0)<128);x=m+19208|0;s=0;while(1){g[x+(s<<2)>>2]=+S(+(s|0));r=s+1|0;if((r|0)<30){s=r}else{B=0;break}}do{s=B<<2;x=d[1073872+B|0]|0;r=c[256256+(s<<2)>>2]|0;c[5915316+(B*80|0)>>2]=3348928+(r<<2);p=s|1;q=c[256256+(p<<2)>>2]|0;c[5915324+(B*80|0)>>2]=q-r;$2(5915312+(B*80|0)|0,9,x,1073880+(B*72|0)|0,1,1,1074168+(B*144|0)|0,2,2,0,0,0,4)|0;c[5915336+(B*80|0)>>2]=3348928+(q<<2);c[5915344+(B*80|0)>>2]=(c[256256+(p+1<<2)>>2]|0)-q;$2(5915332+(B*80|0)|0,9,x,1073898+(B*72|0)|0,1,1,1074204+(B*144|0)|0,2,2,0,0,0,4)|0;q=c[256256+((s|2)<<2)>>2]|0;c[5915356+(B*80|0)>>2]=3348928+(q<<2);c[5915364+(B*80|0)>>2]=(c[256256+((s|3)<<2)>>2]|0)-q;$2(5915352+(B*80|0)|0,9,x,1073916+(B*72|0)|0,1,1,1074240+(B*144|0)|0,2,2,0,0,0,4)|0;q=s|3;s=c[256256+(q<<2)>>2]|0;c[5915376+(B*80|0)>>2]=3348928+(s<<2);c[5915384+(B*80|0)>>2]=(c[256256+(q+1<<2)>>2]|0)-s;$2(5915372+(B*80|0)|0,9,x,1073934+(B*72|0)|0,1,1,1074276+(B*144|0)|0,2,2,0,0,0,4)|0;B=B+1|0;}while((B|0)<4);if((c[o>>2]|0)==86075){A=+(c[e+412>>2]|0);y=A*.0009765625;z=A*.5;A=0.0;o=0;B=0;while(1){x=o+1|0;s=b[1959560+(x<<1)>>1]|0;C=y*+((B&65535)-1+(s&65535)|0);D=C/7500.0;E=+Z(D*D)*3.5+ +Z(C*76.0e-5)*13.0;if((o|0)>0){D=E-A;q=o-1|0;g[n+21800+(q<<2)>>2]=+T(+10.0,+(D*-1.0));g[n+21924+(q<<2)>>2]=+T(+10.0,+(D*-2.7))}h[k+(o<<3)>>3]=C;D=E+.5;F=C;while(1){if(!(F<z)){G=F;break}H=F+.5;I=H/7500.0;if(+Z(I*I)*3.5+ +Z(H*76.0e-5)*13.0>D){G=H;break}else{F=H}}h[l+(o<<3)>>3]=G;F=E+-.5;D=C;while(1){if(!(D>0.0)){J=D;break}H=D+-.5;I=H/7500.0;if(+Z(I*I)*3.5+ +Z(H*76.0e-5)*13.0>F){D=H}else{J=H;break}}h[j+(o<<3)>>3]=J;if((x|0)<32){A=E;o=x;B=s}else{K=0;break}}do{A=+h[l+(K<<3)>>3];B=31;while(1){if((B|0)<=0){break}if(A>+h[k+(B<<3)>>3]){break}else{B=B-1|0}}a[n+21736+K|0]=B+1;A=+h[j+(K<<3)>>3];s=0;while(1){if((s|0)>=32){break}if(A<+h[k+(s<<3)>>3]){break}else{s=s+1|0}}a[n+21768+K|0]=s+255;K=K+1|0;}while((K|0)<32)}else{nrc(m+21736|0,1617544,32)|0;nrc(m+21768|0,1617512,32)|0;nrc(m+21800|0,1073168,124)|0;nrc(m+21924|0,1073040,124)|0}K=pda(m+20628|0,7,1)|0;if((K|0)==0){l8(m+19348|0,e);qHb(m+20592|0,c[e+88>>2]&8388608);c[e+420>>2]=8;m=(c[u>>2]|0)==1;u=e+448|0;c[u>>2]=m?4:3;c[u+4>>2]=m?0:0;w=0;i=f;return w|0}else{KIb(e,32,2549808,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=K;i=f;return w|0}return 0}function sLa(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0.0,ra=0.0,sa=0.0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0.0,Ia=0.0,Ja=0,Ka=0.0,La=0,Ma=0,Na=0.0,Oa=0,Pa=0,Qa=0.0,Ra=0,Sa=0,Ta=0.0,Ua=0,Va=0,Wa=0,Xa=0.0,Ya=0,Za=0.0,_a=0,$a=0.0,ab=0,bb=0.0,cb=0.0,db=0,eb=0,fb=0,gb=0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0.0,Ab=0,Bb=0.0,Cb=0,Db=0,Eb=0.0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0;m=i;i=i+336|0;n=m|0;o=m+128|0;p=m+144|0;q=m+272|0;r=q|0;s=c[f+60>>2]|0;t=s;u=q;v=f+416|0;if((c[l+28>>2]|0)<(c[v>>2]<<6|0)){KIb(f,16,2247136,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1094995529;i=m;return x|0}y=c[l+24>>2]|0;c[j+76>>2]=256;l=M4a(f,j,0)|0;if((l|0)<0){x=l;i=m;return x|0}do{if((c[v>>2]|0)>0){l=j+64|0;z=s+21728|0;A=s+20448|0;B=q;C=s+19328|0;D=s+19340|0;E=s+19344|0;F=q+64|0;G=s+19332|0;H=s+19336|0;I=s+21732|0;J=f+48|0;K=p;L=s+20628|0;M=s+20660|0;N=s+20704|0;O=s+20664|0;P=p|0;Q=p+4|0;R=p+8|0;S=p+12|0;U=o|0;V=o+4|0;W=o+8|0;X=o+12|0;Y=0;Z=y;a:while(1){c[z>>2]=c[(c[l>>2]|0)+(Y<<2)>>2];ef[c[A>>2]&4095](u,Z,32);c[C>>2]=B;c[D>>2]=512;c[E>>2]=520;c[G>>2]=F;c[H>>2]=0;_=t+(Y*7044|0)|0;$=(je(c[r>>2]|0)|0)>>>23;c[H>>2]=9;if(($&24|0)!=0){aa=7;break}ba=B+1|0;da=je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0;ba=da>>>28;c[H>>2]=12;ea=ba&4;fa=(ea|0)!=0;ga=t+(Y*7044|0)+7040|0;if(fa){c[ga>>2]=1;ha=0;aa=12}else{if((c[ga>>2]|0)==0){ia=12;ja=B;ka=520}else{ha=0;aa=12}}if((aa|0)==12){while(1){aa=0;g[t+(Y*7044|0)+(ha<<2)>>2]=1.0;la=ha+1|0;if((la|0)<32){ha=la;aa=12}else{break}}mrc(t+(Y*7044|0)+896|0,0,1024)|0;c[ga>>2]=0;ia=c[H>>2]|0;ja=c[C>>2]|0;ka=c[E>>2]|0}la=d[ja+(ia>>>3)|0]<<(ia&7)>>>7;ma=((ia|0)<(ka|0))+ia|0;c[H>>2]=ma;na=la&1;la=(ba&1|0)!=0;oa=t+(Y*7044|0)+3200|0;if(la){pa=c[I>>2]|0;qa=2.0e4/+ad(+(+(c[oa>>2]|0)*.18945));g[t+(Y*7044|0)+128+(pa<<2)>>2]=qa;ra=+lc(+(+g[t+(Y*7044|0)+128>>2]));g[t+(Y*7044|0)+256+(pa<<2)>>2]=ra;sa=ra;ta=0;ua=t+(Y*7044|0)+3204|0;while(1){if((ta|0)==(pa|0)){va=ua}else{wa=c[ua>>2]|0;g[t+(Y*7044|0)+128+(ta<<2)>>2]=qa*+T(+10.0,+(+(-wa|0)*.4375));g[t+(Y*7044|0)+256+(ta<<2)>>2]=sa- +(wa|0)*1.4533435415;va=ua+4|0}wa=ta+1|0;if((wa|0)<32){ta=wa;ua=va}else{break}}}else{ua=da>>>29&3;c[U>>2]=5915312+(ua*80|0);c[V>>2]=5915332+(ua*80|0);c[W>>2]=5915352+(ua*80|0);c[X>>2]=5915372+(ua*80|0);if((ea|0)==0){xa=ja}else{ta=ja+(ma>>>3)|0;pa=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(ma&7)>>>25;ta=ma+7|0;c[H>>2]=ka>>>0>ta>>>0?ta:ka;c[oa>>2]=pa;xa=c[C>>2]|0}pa=ea>>>2;do{ta=c[o+(d[1074872+(ua<<5)+pa|0]<<2)>>2]|0;wa=c[ta+4>>2]|0;ya=c[ta>>2]|0;ta=c[H>>2]|0;za=c[E>>2]|0;Aa=xa+(ta>>>3)|0;Ba=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(ta&7)>>>((32-ya|0)>>>0);Aa=b[wa+(Ba<<2)>>1]|0;Ca=b[wa+(Ba<<2)+2>>1]|0;Ba=Ca<<16>>16;if(Ca<<16>>16<0){Ca=ta+ya|0;ya=za>>>0>Ca>>>0?Ca:za;Ca=xa+(ya>>>3)|0;Da=((je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(ya&7)>>>((Ba+32|0)>>>0))+Aa|0;Ea=b[wa+(Da<<2)+2>>1]|0;Fa=b[wa+(Da<<2)>>1]|0;Ga=ya}else{Ea=Ba;Fa=Aa;Ga=ta}ta=Ea+Ga|0;c[H>>2]=za>>>0>ta>>>0?ta:za;za=t+(Y*7044|0)+3200+(pa<<2)|0;c[za>>2]=Fa;if((Fa|0)==17){ta=c[H>>2]|0;Aa=c[E>>2]|0;Ba=xa+(ta>>>3)|0;ya=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(ta&7)>>>28;Ba=ta+4|0;c[H>>2]=Aa>>>0>Ba>>>0?Ba:Aa;c[za>>2]=ya+(c[za>>2]|0)}pa=pa+1|0;}while((pa|0)<32)}if(fa){sa=2.0e4/+ad(+(+(c[oa>>2]|0)*.18945));g[t+(Y*7044|0)+128>>2]=sa;qa=+lc(+sa);g[t+(Y*7044|0)+256>>2]=qa;pa=1;ra=sa;sa=qa;while(1){ua=c[t+(Y*7044|0)+3200+(pa<<2)>>2]|0;if((ua|0)==16){g[t+(Y*7044|0)+128+(pa<<2)>>2]=1.0;g[t+(Y*7044|0)+256+(pa<<2)>>2]=0.0;Ha=sa;Ia=ra}else{do{if((ua|0)<17){Ja=ua-7|0}else{if((ua|0)<25){Ja=ua-32|0;break}else{Ja=ua-16|0;break}}}while(0);qa=ra*+g[1074744+(Ja+15<<2)>>2];Ka=sa+ +(Ja|0)*.83048;g[t+(Y*7044|0)+128+(pa<<2)>>2]=qa;g[t+(Y*7044|0)+256+(pa<<2)>>2]=Ka;Ha=Ka;Ia=qa}ua=pa+1|0;if((ua|0)<32){pa=ua;ra=Ia;sa=Ha}else{La=0;break}}}else{pa=0;while(1){oa=t+(Y*7044|0)+128+(pa<<2)|0;g[oa>>2]=0.0;fa=c[t+(Y*7044|0)+3200+(pa<<2)>>2]|0;if((fa|0)<16){g[oa>>2]=+g[1074744+(fa+8<<2)>>2]*+g[t+(Y*7044|0)+(pa<<2)>>2];ua=t+(Y*7044|0)+256+(pa<<2)|0;g[ua>>2]=+(fa-7|0)*.83048+ +g[ua>>2]}else{g[oa>>2]=+g[t+(Y*7044|0)+(pa<<2)>>2]}oa=pa+1|0;if((oa|0)<32){pa=oa}else{La=0;break}}}while(1){if((La|0)>=32){break}if(+g[t+(Y*7044|0)+128+(La<<2)>>2]>2147483648.0){aa=43;break a}else{La=La+1|0}}nrc(_|0,t+(Y*7044|0)+128|0,128)|0;if(la){pa=0;oa=0;while(1){ua=pa+1|0;fa=e[1959560+(ua<<1)>>1]|0;c[t+(Y*7044|0)+1920+(pa<<2)>>2]=fa-oa;c[t+(Y*7044|0)+3328+(pa<<2)>>2]=0;g[t+(Y*7044|0)+384+(pa<<2)>>2]=+g[t+(Y*7044|0)+256+(pa<<2)>>2]*2.0;g[t+(Y*7044|0)+640+(pa<<2)>>2]=1.0;if((ua|0)<32){pa=ua;oa=fa}else{break}}}else{oa=0;while(1){if((c[t+(Y*7044|0)+3200+(oa<<2)>>2]|0)==16){c[t+(Y*7044|0)+1920+(oa<<2)>>2]=0;Ma=oa+1|0}else{pa=oa+1|0;c[t+(Y*7044|0)+1920+(oa<<2)>>2]=(e[1959560+(pa<<1)>>1]|0)-(e[1959560+(oa<<1)>>1]|0);Ma=pa}if((Ma|0)<32){oa=Ma}else{break}}mrc(t+(Y*7044|0)+3328|0,0,128)|0;oa=0;do{if((c[t+(Y*7044|0)+1920+(oa<<2)>>2]|0)!=0){pa=c[H>>2]|0;_=d[(c[C>>2]|0)+(pa>>>3)|0]<<(pa&7)>>>7;c[H>>2]=((pa|0)<(c[E>>2]|0))+pa;c[t+(Y*7044|0)+3328+(oa<<2)>>2]=_&1}oa=oa+1|0;}while((oa|0)<31);mrc(K|0,0,128)|0;oa=0;while(1){g[t+(Y*7044|0)+640+(oa<<2)>>2]=0.0;_=c[t+(Y*7044|0)+1920+(oa<<2)>>2]|0;if((_|0)==0){g[t+(Y*7044|0)+384+(oa<<2)>>2]=-3.0e4;Na=0.0}else{sa=+g[t+(Y*7044|0)+128+(oa<<2)>>2];g[t+(Y*7044|0)+384+(oa<<2)>>2]=+g[t+(Y*7044|0)+256+(oa<<2)>>2]*2.0;Na=sa*sa}sa=+(_|0)*Na*.01;g[n+(oa<<2)>>2]=sa>1.0000000031710769e-30?sa:0.0;_=oa+1|0;if((_|0)<32){oa=_}else{Oa=0;break}}while(1){oa=t+21736+Oa|0;sa=+g[n+(Oa<<2)>>2];if((Oa|0)<(a[oa]|0)){_=Oa;while(1){pa=t+(Y*7044|0)+640+(_<<2)|0;g[pa>>2]=sa+ +g[pa>>2];pa=_+1|0;if((pa|0)<(a[oa]|0)){_=pa}else{Pa=pa;break}}}else{Pa=Oa}_=p+(Pa-1<<2)|0;g[_>>2]=sa+ +g[_>>2];_=Oa+1|0;if((_|0)<32){Oa=_}else{Qa=0.0;Ra=1;break}}do{_=Ra-1|0;Qa=(Qa+ +g[p+(_<<2)>>2])*+g[t+21800+(_<<2)>>2];_=t+(Y*7044|0)+640+(Ra<<2)|0;g[_>>2]=+g[_>>2]+Qa;Ra=Ra+1|0;}while((Ra|0)<32);mrc(K|0,0,128)|0;_=0;while(1){oa=_-1|0;pa=t+21768+_|0;ra=+g[n+(_<<2)>>2];if((oa|0)>(a[pa]|0)){fa=oa;while(1){oa=t+(Y*7044|0)+640+(fa<<2)|0;g[oa>>2]=ra+ +g[oa>>2];oa=fa-1|0;if((oa|0)>(a[pa]|0)){fa=oa}else{Sa=fa;break}}}else{Sa=_}fa=p+(Sa<<2)|0;g[fa>>2]=ra+ +g[fa>>2];fa=_+1|0;if((fa|0)<32){_=fa}else{Ta=0.0;Ua=30;break}}while(1){sa=(Ta+ +g[p+(Ua+1<<2)>>2])*+g[t+21924+(Ua<<2)>>2];_=t+(Y*7044|0)+640+(Ua<<2)|0;g[_>>2]=+g[_>>2]+sa;if((Ua|0)>0){Ta=sa;Ua=Ua-1|0}else{break}}}_=ba&2;fa=(_|0)!=0;do{if(fa){c[t+(Y*7044|0)+2048>>2]=5;c[t+(Y*7044|0)+2176>>2]=5;c[t+(Y*7044|0)+2180>>2]=5;c[t+(Y*7044|0)+2184>>2]=5;if(la){c[t+(Y*7044|0)+2052>>2]=5;c[t+(Y*7044|0)+2188>>2]=5;c[t+(Y*7044|0)+2192>>2]=5;c[t+(Y*7044|0)+2196>>2]=5;c[t+(Y*7044|0)+2056>>2]=5;c[t+(Y*7044|0)+2200>>2]=5;c[t+(Y*7044|0)+2204>>2]=5;c[t+(Y*7044|0)+2208>>2]=5;c[t+(Y*7044|0)+2060>>2]=5;c[t+(Y*7044|0)+2212>>2]=5;c[t+(Y*7044|0)+2216>>2]=5;c[t+(Y*7044|0)+2220>>2]=5;Va=60;break}else{pa=(c[t+(Y*7044|0)+3204>>2]|0)==16?0:5;c[t+(Y*7044|0)+2052>>2]=pa;c[t+(Y*7044|0)+2188>>2]=pa;c[t+(Y*7044|0)+2192>>2]=pa;c[t+(Y*7044|0)+2196>>2]=pa;oa=(c[t+(Y*7044|0)+3208>>2]|0)==16?0:5;c[t+(Y*7044|0)+2056>>2]=oa;c[t+(Y*7044|0)+2200>>2]=oa;c[t+(Y*7044|0)+2204>>2]=oa;c[t+(Y*7044|0)+2208>>2]=oa;ua=(c[t+(Y*7044|0)+3212>>2]|0)==16?0:5;c[t+(Y*7044|0)+2060>>2]=ua;c[t+(Y*7044|0)+2212>>2]=ua;c[t+(Y*7044|0)+2216>>2]=ua;c[t+(Y*7044|0)+2220>>2]=ua;Va=((oa+pa+ua|0)*3|0)+15|0;break}}else{Va=0}}while(0);do{if((c[J>>2]|0)==86075){ba=((c[t+(Y*7044|0)+2044>>2]|0)!=0)+Va|0;if(fa){Wa=ba;break}Wa=ba+16|0}else{Wa=Va}}while(0);ba=c[H>>2]|0;sa=0.0;ua=0;do{qa=+g[t+(Y*7044|0)+128+(ua<<2)>>2];sa=sa>qa?sa:qa;ua=ua+1|0;}while((ua|0)<32);ua=512-Wa-ba|0;pa=0;do{Xa=+g[t+(Y*7044|0)+640+(pa<<2)>>2];if(!(Xa>0.0)){aa=79;break a}qa=+g[t+(Y*7044|0)+384+(pa<<2)>>2];g[t+(Y*7044|0)+512+(pa<<2)>>2]=qa- +lc(+Xa);pa=pa+1|0;}while((pa|0)<31);g[t+(Y*7044|0)+636>>2]=-100000002004087730000.0;qa=sa*.25;pa=0;ba=0;while(1){oa=pa+1|0;ea=b[1959560+(oa<<1)>>1]|0;ma=(ea&65535)-(ba&65535)|0;za=c[t+(Y*7044|0)+1920+(pa<<2)>>2]|0;ya=((ma|0)/2|0|0)<(za|0)?(ma|0)>(za|0)?1:((ma|0)!=(za|0))<<31>>31:2;if((ya|0)==-1){break a}za=t+(Y*7044|0)+512+(pa<<2)|0;g[za>>2]=+g[3216+(((+g[t+(Y*7044|0)+128+(pa<<2)>>2]<qa|ya<<1)<<1|na)<<2)>>2]+ +g[za>>2];if((oa|0)<32){pa=oa;ba=ea}else{break}}if(fa){g[t+(Y*7044|0)+512>>2]=-100000002004087730000.0;g[t+(Y*7044|0)+516>>2]=-100000002004087730000.0;g[t+(Y*7044|0)+520>>2]=-100000002004087730000.0;g[t+(Y*7044|0)+524>>2]=-100000002004087730000.0}ba=_<<1;qa=0.0;pa=0;na=ba;do{ea=c[t+(Y*7044|0)+1920+(na<<2)>>2]|0;pa=ea+pa|0;qa=qa+ +(ea|0)*+g[t+(Y*7044|0)+512+(na<<2)>>2];na=na+1|0;}while((na|0)<31);if((pa|0)==0){break}c[t+(Y*7044|0)+2044>>2]=0;na=8-ua|0;_=0;ea=1;sa=(qa*.5- +(ua|0))/+(pa|0);oa=0;za=0;while(1){if((na+oa|0)>>>0<17>>>0){Ya=oa;break}Ka=sa;ya=ba;ma=0;Aa=0;do{Za=+g[t+(Y*7044|0)+512+(ya<<2)>>2]*.5-Ka+.5;if(Za<0.0){_a=0}else{_a=Za>6.0?6:~~Za}c[t+(Y*7044|0)+2048+(ya<<2)>>2]=_a;Ba=c[t+(Y*7044|0)+1920+(ya<<2)>>2]|0;Aa=(ca(Ba,_a)|0)+Aa|0;ma=((_a|0)>0?Ba:0)+ma|0;ya=ya+1|0;}while((ya|0)<32);ya=(Aa|0)>(ua|0)?-1:1;Ba=((((za|0)==0?ya:ea)|0)!=(ya|0))+_|0;Ka=sa+ +(Aa-ua|0)/+(ca(Ba+1|0,ma)|0);ta=za+1|0;if((ta|0)<16){_=Ba;ea=ya;sa=Ka;oa=Aa;za=ta}else{Ya=Aa;break}}za=ba;oa=b[1959560+(ba<<1)>>1]|0;while(1){ea=za+1|0;_=b[1959560+(ea<<1)>>1]|0;if((oa&65535)>>>0<(_&65535)>>>0){na=t+(Y*7044|0)+2048+(za<<2)|0;pa=_&65535;ta=oa&65535;do{c[t+(Y*7044|0)+2176+(ta<<2)>>2]=c[na>>2];ta=ta+1|0;}while((ta|0)<(pa|0))}if((ea|0)<32){za=ea;oa=_}else{break}}b:do{if((Ya|0)<(ua|0)){oa=0;while(1){za=c[t+(Y*7044|0)+2048+(oa<<2)>>2]|0;if((za|0)==6){$a=-100000002004087730000.0}else{$a=+(za*-2|0|0)+ +g[t+(Y*7044|0)+512+(oa<<2)>>2]+-.415}g[p+(oa<<2)>>2]=$a;za=oa+1|0;if((za|0)<32){oa=za}else{ab=Ya;bb=0.0;break}}while(1){if(bb>-1.0e20){cb=-100000002004087730000.0;db=0;eb=0}else{fb=ab;break b}do{sa=+g[p+(db<<2)>>2];oa=sa>cb;cb=oa?sa:cb;eb=oa?db:eb;db=db+1|0;}while((db|0)<32);do{if(cb>-1.0e20){oa=p+(eb<<2)|0;g[oa>>2]=+g[oa>>2]+-2.0;_=t+(Y*7044|0)+2048+(eb<<2)|0;ea=(c[_>>2]|0)+1|0;c[_>>2]=ea;if((ea|0)==6){g[oa>>2]=-100000002004087730000.0}oa=b[1959560+(eb<<1)>>1]|0;ea=b[1959560+(eb+1<<1)>>1]|0;if(!((oa&65535)>>>0<(ea&65535)>>>0&(ab|0)<(ua|0))){gb=ab;break}_=oa&65535;oa=ea&65535;ea=_+1|0;za=_-(ea>>>0>oa>>>0?ea:oa)|0;ea=_;_=ab;do{ba=t+(Y*7044|0)+2176+(ea<<2)|0;c[ba>>2]=(c[ba>>2]|0)+1;_=_+1|0;ea=ea+1|0;}while((ea|0)<(oa|0)&(_|0)<(ua|0));_=ab-ua|0;gb=ab-(_>>>0>za>>>0?_:za)|0}else{gb=ab}}while(0);if((gb|0)<(ua|0)){ab=gb;bb=cb}else{fb=gb;break}}}else{fb=Ya}}while(0);if((fb|0)>(ua|0)){_=0;do{oa=c[t+(Y*7044|0)+2048+(_<<2)>>2]|0;if((oa|0)==0){hb=100000002004087730000.0}else{hb=+(oa*-2|0|0)+ +g[t+(Y*7044|0)+512+(_<<2)>>2]+1.585}g[p+(_<<2)>>2]=hb;_=_+1|0;}while((_|0)<32);if(fa){g[P>>2]=100000002004087730000.0;g[Q>>2]=100000002004087730000.0;g[R>>2]=100000002004087730000.0;g[S>>2]=100000002004087730000.0;ib=fb}else{ib=fb}while(1){_=0;sa=1.0e10;oa=0;do{qa=+g[p+(_<<2)>>2];ea=qa<sa;sa=ea?qa:sa;oa=ea?_:oa;_=_+1|0;}while((_|0)<32);_=p+(oa<<2)|0;g[_>>2]=sa+2.0;ea=t+(Y*7044|0)+2048+(oa<<2)|0;ba=(c[ea>>2]|0)-1|0;c[ea>>2]=ba;if((ba|0)==0){g[_>>2]=100000002004087730000.0}_=b[1959560+(oa<<1)>>1]|0;ba=b[1959560+(oa+1<<1)>>1]|0;if((_&65535)>>>0<(ba&65535)>>>0&(ib|0)>(ua|0)){ea=ba&65535;ba=_&65535;_=ib;while(1){pa=t+(Y*7044|0)+2176+(ba<<2)|0;ta=c[pa>>2]|0;if((ta|0)>0){c[pa>>2]=ta-1;jb=_-1|0}else{jb=_}ta=ba+1|0;if((ta|0)<(ea|0)&(jb|0)>(ua|0)){ba=ta;_=jb}else{kb=jb;break}}}else{kb=ib}if((kb|0)>(ua|0)){ib=kb}else{break}}}c:do{if(la){mrc(t+(Y*7044|0)+3968|0,0,128)|0;lb=0;mb=0}else{ua=0;fa=0;while(1){_=t+(Y*7044|0)+3456+(ua<<2)|0;c[_>>2]=0;ba=t+(Y*7044|0)+3584+(ua<<2)|0;c[ba>>2]=0;ea=1959560+(ua<<1)|0;oa=ua+1|0;ta=b[1959560+(oa<<1)>>1]|0;pa=ta&65535;if((fa&65535)>>>0<(ta&65535)>>>0){na=fa&65535;Aa=0;while(1){ma=(c[t+(Y*7044|0)+2176+(na<<2)>>2]|0)+Aa|0;c[_>>2]=ma;ya=na+1|0;if((ya|0)<(pa|0)){na=ya;Aa=ma}else{nb=ma;break}}}else{nb=0}do{if((c[t+(Y*7044|0)+3328+(ua<<2)>>2]|0)!=0){if(!(+(pa-(e[ea>>1]|0)|0)*1.5>+(nb|0)&(nb|0)>0)){break}c[ba>>2]=1}}while(0);if((oa|0)<32){ua=oa;fa=ta}else{break}}mrc(t+(Y*7044|0)+3712|0,0,256)|0;fa=0;while(1){d:do{if((c[t+(Y*7044|0)+3328+(fa<<2)>>2]|0)!=0){if((c[t+(Y*7044|0)+1920+(fa<<2)>>2]|0)==0){break}if((c[t+(Y*7044|0)+3584+(fa<<2)>>2]|0)==0){ua=b[1959560+(fa+1<<1)>>1]|0;ba=ua&65535;ea=b[1959560+(fa<<1)>>1]|0;pa=ea&65535;c[t+(Y*7044|0)+3712+(fa<<2)>>2]=ba-pa;if(!((ea&65535)>>>0<(ua&65535)>>>0)){break}ua=t+(Y*7044|0)+3840+(fa<<2)|0;ea=c[C>>2]|0;Aa=pa;while(1){pa=c[H>>2]|0;na=d[ea+(pa>>>3)|0]<<(pa&7)>>>7;c[H>>2]=((pa|0)<(c[E>>2]|0))+pa;pa=na&1;c[t+(Y*7044|0)+3968+(Aa<<2)>>2]=pa;if((pa|0)!=0){c[ua>>2]=(c[ua>>2]|0)+1}Aa=Aa+1|0;if((Aa|0)>=(ba|0)){break d}}}ba=e[1959560+(fa<<1)>>1]|0;Aa=e[1959560+(fa+1<<1)>>1]|0;ua=Aa-1|0;if((ba|0)<(ua|0)){ea=t+(Y*7044|0)+3712+(fa<<2)|0;za=t+(Y*7044|0)+3840+(fa<<2)|0;pa=ba+2|0;na=(ua|0)>(pa|0);_=c[C>>2]|0;ma=ba;do{ya=c[H>>2]|0;Ba=d[_+(ya>>>3)|0]|0;Da=c[E>>2]|0;wa=((ya|0)<(Da|0))+ya|0;c[H>>2]=wa;do{if((Ba&128>>>((ya&7)>>>0)|0)==0){c[ea>>2]=(c[ea>>2]|0)+1;c[t+(Y*7044|0)+3968+(ma<<2)>>2]=1;c[t+(Y*7044|0)+3968+(ma+1<<2)>>2]=1;c[za>>2]=(c[za>>2]|0)+2}else{Ca=d[_+(wa>>>3)|0]|0;c[H>>2]=((wa|0)<(Da|0))+wa;ob=c[ea>>2]|0;if((Ca&128>>>((wa&7)>>>0)|0)!=0){c[ea>>2]=ob+2;c[t+(Y*7044|0)+3968+(ma<<2)>>2]=0;c[t+(Y*7044|0)+3968+(ma+1<<2)>>2]=1;c[za>>2]=(c[za>>2]|0)+1;break}c[ea>>2]=ob+3;c[t+(Y*7044|0)+3968+(ma+1<<2)>>2]=0;ob=c[H>>2]|0;Ca=d[_+(ob>>>3)|0]|0;c[H>>2]=((ob|0)<(c[E>>2]|0))+ob;pb=t+(Y*7044|0)+3968+(ma<<2)|0;if((Ca&128>>>((ob&7)>>>0)|0)==0){c[pb>>2]=1;c[za>>2]=(c[za>>2]|0)+1;break}else{c[pb>>2]=0;break}}}while(0);ma=ma+2|0;}while((ma|0)<(ua|0));qb=(1-ba+(na?ua:pa)&-2)+ba|0}else{qb=ba}if((qb|0)>=(Aa|0)){break}ma=t+(Y*7044|0)+3712+(fa<<2)|0;c[ma>>2]=(c[ma>>2]|0)+1;ma=c[H>>2]|0;za=d[(c[C>>2]|0)+(ma>>>3)|0]<<(ma&7)>>>7;c[H>>2]=((ma|0)<(c[E>>2]|0))+ma;ma=za&1;c[t+(Y*7044|0)+3968+(qb<<2)>>2]=ma;if((ma|0)==0){break}ma=t+(Y*7044|0)+3840+(fa<<2)|0;c[ma>>2]=(c[ma>>2]|0)+1}}while(0);ta=fa+1|0;if((ta|0)<32){fa=ta}else{rb=0;break}}while(1){sa=+g[t+(Y*7044|0)+128+(rb<<2)>>2];fa=t+(Y*7044|0)+768+(rb<<2)|0;g[fa>>2]=sa;ta=rb+1|0;do{if((c[t+(Y*7044|0)+3328+(rb<<2)>>2]|0)!=0){oa=(e[1959560+(ta<<1)>>1]|0)-(e[1959560+(rb<<1)>>1]|0)|0;ma=c[t+(Y*7044|0)+3840+(rb<<2)>>2]|0;if((oa|0)==(ma|0)){break}g[fa>>2]=sa*(+g[t+19208+(oa<<2)>>2]/+g[t+19208+(oa-ma<<2)>>2])}}while(0);if((ta|0)<32){rb=ta}else{sb=0;tb=0;break}}while(1){if((c[t+(Y*7044|0)+3328+(sb<<2)>>2]|0)==0){ub=tb;vb=sb+1|0}else{fa=b[1959560+(sb<<1)>>1]|0;ma=sb+1|0;oa=b[1959560+(ma<<1)>>1]|0;if((fa&65535)>>>0<(oa&65535)>>>0){za=oa&65535;oa=fa&65535;fa=tb;while(1){if((c[t+(Y*7044|0)+3968+(oa<<2)>>2]|0)==0){wb=fa}else{_=t+(Y*7044|0)+2176+(oa<<2)|0;ea=(c[_>>2]|0)+fa|0;c[_>>2]=0;wb=ea}ea=oa+1|0;if((ea|0)<(za|0)){oa=ea;fa=wb}else{xb=wb;break}}}else{xb=tb}ub=xb-(c[t+(Y*7044|0)+3712+(sb<<2)>>2]|0)|0;vb=ma}if((vb|0)<32){sb=vb;tb=ub}else{yb=0;break}}do{fa=c[t+(Y*7044|0)+2048+(yb<<2)>>2]|0;if((fa|0)==6){zb=-100000002004087730000.0}else{zb=+(fa*-2|0|0)+ +g[t+(Y*7044|0)+512+(yb<<2)>>2]+-.415}g[p+(yb<<2)>>2]=zb;yb=yb+1|0;}while((yb|0)<32);if((ub|0)>0){Ab=0;Bb=0.0;Cb=0}else{lb=0;mb=0;break}while(1){fa=Cb;sa=Bb;while(1){if(sa>-1.0e20){Db=0;Eb=-100000002004087730000.0;Fb=fa}else{lb=0;mb=0;break c}do{qa=+g[p+(Db<<2)>>2];oa=qa>Eb;Eb=oa?qa:Eb;Fb=oa?Db:Fb;Db=Db+1|0;}while((Db|0)<32);if(Eb>-1.0e20){break}else{fa=Fb;sa=Eb}}fa=p+(Fb<<2)|0;g[fa>>2]=+g[fa>>2]+-2.0;ma=t+(Y*7044|0)+2048+(Fb<<2)|0;Aa=(c[ma>>2]|0)+1|0;c[ma>>2]=Aa;if((Aa|0)==6){g[fa>>2]=-100000002004087730000.0}fa=b[1959560+(Fb<<1)>>1]|0;Aa=b[1959560+(Fb+1<<1)>>1]|0;if((fa&65535)>>>0<(Aa&65535)>>>0&(Ab|0)<(ub|0)){ma=Aa&65535;Aa=Ab;ba=fa&65535;while(1){do{if((c[t+(Y*7044|0)+3968+(ba<<2)>>2]|0)==0){fa=t+(Y*7044|0)+2176+(ba<<2)|0;pa=c[fa>>2]|0;if((pa|0)>=6){Gb=Aa;break}c[fa>>2]=pa+1;Gb=Aa+1|0}else{Gb=Aa}}while(0);pa=ba+1|0;if((pa|0)<(ma|0)&(Gb|0)<(ub|0)){Aa=Gb;ba=pa}else{Hb=Gb;break}}}else{Hb=Ab}if((Hb|0)<(ub|0)){Ab=Hb;Bb=Eb;Cb=Fb}else{lb=0;mb=0;break}}}}while(0);while(1){la=t+(Y*7044|0)+3456+(lb<<2)|0;c[la>>2]=0;ba=lb+1|0;Aa=b[1959560+(ba<<1)>>1]|0;if((mb&65535)>>>0<(Aa&65535)>>>0){ma=Aa&65535;pa=mb&65535;fa=0;while(1){if((c[t+(Y*7044|0)+3968+(pa<<2)>>2]|0)==0){ua=(c[t+(Y*7044|0)+2176+(pa<<2)>>2]|0)+fa|0;c[la>>2]=ua;Ib=ua}else{Ib=fa}ua=pa+1|0;if((ua|0)<(ma|0)){pa=ua;fa=Ib}else{break}}}if((ba|0)<32){lb=ba;mb=Aa}else{break}}mrc(t+(Y*7044|0)+4992|0,0,1024)|0;fa=0;do{do{if((c[t+(Y*7044|0)+3456+(fa<<2)>>2]|0)!=0){pa=t+(Y*7044|0)+3328+(fa<<2)|0;if((c[pa>>2]|0)==0){if((c[t+(Y*7044|0)+1920+(fa<<2)>>2]|0)==0){break}}ma=b[1959560+(fa<<1)>>1]|0;la=b[1959560+(fa+1<<1)>>1]|0;if(!((ma&65535)>>>0<(la&65535)>>>0)){break}ua=la&65535;la=ma&65535;do{ma=c[t+(Y*7044|0)+2176+(la<<2)>>2]|0;na=c[H>>2]|0;oa=na+ma|0;if((oa|0)>512){aa=214;break a}do{if((ma|0)==0){Jb=0}else{if((c[pa>>2]|0)!=0){if((c[t+(Y*7044|0)+3968+(la<<2)>>2]|0)!=0){Jb=0;break}}za=c[E>>2]|0;ta=(c[C>>2]|0)+(na>>>3)|0;ea=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(na&7)>>>((32-ma|0)>>>0);c[H>>2]=za>>>0>oa>>>0?oa:za;Jb=ea}}while(0);c[t+(Y*7044|0)+4992+(la<<2)>>2]=Jb;la=la+1|0;}while((la|0)<(ua|0))}}while(0);fa=fa+1|0;}while((fa|0)<32);fa=da>>>29&1;Aa=0;ba=0;while(1){ua=Aa+1|0;la=b[1959560+(ua<<1)>>1]|0;if((ba&65535)>>>0<(la&65535)>>>0){pa=t+(Y*7044|0)+768+(Aa<<2)|0;oa=t+(Y*7044|0)+3328+(Aa<<2)|0;ma=la&65535;na=ba&65535;do{ea=t+(Y*7044|0)+896+(na<<2)|0;g[ea>>2]=0.0;za=c[t+(Y*7044|0)+2176+(na<<2)>>2]|0;do{if((za|0)>=1){if((c[t+(Y*7044|0)+3968+(na<<2)>>2]|0)!=0){break}ta=1<<za;_=ta>>1;wa=c[t+(Y*7044|0)+4992+(na<<2)>>2]|0;if((wa|0)>=(ta|0)|(wa|0)<0){aa=230;break a}if((za|0)>3){if((wa|0)<(_|0)){g[ea>>2]=+g[pa>>2]*(-0.0- +g[1073296+(fa*224|0)+(ta-9-wa<<2)>>2]);break}else{g[ea>>2]=+g[1073296+(fa*224|0)+(wa-8<<2)>>2]*+g[pa>>2];break}}else{Da=c[oa>>2]<<1|fa;if((wa|0)<(_|0)){g[ea>>2]=+g[pa>>2]*(-0.0- +g[1073744+(Da<<5)+(ta-2-wa<<2)>>2]);break}else{g[ea>>2]=+g[1073744+(Da<<5)+(wa-1<<2)>>2]*+g[pa>>2];break}}}}while(0);na=na+1|0;}while((na|0)<(ma|0))}if((ua|0)<32){Aa=ua;ba=la}else{break}}mrc(t+(Y*7044|0)+3968|0,0,1024)|0;ba=c[z>>2]|0;Aa=0;do{fa=t+17160+(Aa<<2)|0;da=Aa<<1;ma=t+(Y*7044|0)+896+(255-da<<2)|0;na=t+18184+(Aa<<2)|0;pa=t+(Y*7044|0)+896+(da<<2)|0;g[t+20704+(Aa<<3)>>2]=-0.0- +g[fa>>2]*+g[ma>>2]- +g[na>>2]*+g[pa>>2];g[t+20704+(Aa<<3)+4>>2]=+g[na>>2]*+g[ma>>2]- +g[fa>>2]*+g[pa>>2];Aa=Aa+1|0;}while((Aa|0)<128);re[c[M>>2]&1023](L,N);re[c[O>>2]&1023](L,N);Aa=0;pa=ba;fa=ba+1020|0;while(1){sa=+g[t+20704+(Aa<<3)>>2];qa=+g[t+15112+(Aa<<2)>>2];Ka=-0.0- +g[t+20704+(Aa<<3)+4>>2];ra=+g[t+16136+(Aa<<2)>>2];Za=sa*qa+ra*Ka;ma=Aa<<1;na=t+14088+(255-ma<<2)|0;da=t+(Y*7044|0)+6016+(Aa<<2)|0;oa=t+14088+(ma<<2)|0;g[pa>>2]=+g[na>>2]*+g[da>>2]+Za*+g[oa>>2];g[fa>>2]=+g[oa>>2]*+g[da>>2]-Za*+g[na>>2];g[da>>2]=qa*Ka-sa*ra;da=Aa+1|0;if((da|0)<128){Aa=da;pa=pa+8|0;fa=fa-8|0}else{break}}fa=Y+1|0;Kb=c[v>>2]|0;if((fa|0)<(Kb|0)){Y=fa;Z=Z+64|0}else{aa=236;break}}if((aa|0)==7){Z=f;KIb(Z,16,2205224,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;KIb(Z,16,2173064,(w=i,i=i+8|0,c[w>>2]=$,w)|0);i=w;x=-1094995529;i=m;return x|0}else if((aa|0)==43){KIb(f,16,2145640,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1094995529;i=m;return x|0}else if((aa|0)==79){KIb(0,16,2589552,(w=i,i=i+8|0,h[w>>3]=Xa,w)|0);i=w}else if((aa|0)==214){KIb(f,16,2639416,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;c[ga>>2]=1;x=-1094995529;i=m;return x|0}else if((aa|0)==230){KIb(f,16,2616712,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;c[ga>>2]=1;x=-1094995529;i=m;return x|0}else if((aa|0)==236){if((Kb|0)!=2){break}Z=c[j+64>>2]|0;ef[c[s+20620>>2]&4095](c[Z>>2]|0,c[Z+4>>2]|0,256);break}KIb(f,16,2121864,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;c[ga>>2]=1;x=-1094995529;i=m;return x|0}}while(0);c[k>>2]=1;x=c[v>>2]<<6;i=m;return x|0}function tLa(a){a=a|0;tda((c[a+60>>2]|0)+20628|0);return 0}function uLa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+14084>>2]=1;c[b+7040>>2]=1;return}function vLa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=i;g=qKb(a)|0;if((g|0)==0){KIb(0,0,2534376,(a=i,i=i+24|0,c[a>>2]=2604144,c[a+8>>2]=2452064,c[a+16>>2]=68,a)|0);i=a;Hd()}else{c[b>>2]=d[g+5|0]|0;c[e>>2]=d[g+6|0]|0;i=f;return}}function wLa(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;i=qKb(f)|0;j=qKb(d)|0;if(d>>>0>332>>>0){k=-1;return k|0}c[g>>2]=0;if((d|0)==(f|0)){k=2147483647;return k|0}l=qKb(f)|0;if((l|0)==0){k=-22;return k|0}if((a[l+4|0]|0)==0){k=-22;return k|0}l=qKb(d)|0;if((l|0)==0){k=-22;return k|0}if((a[l+4|0]|0)==0){k=-22;return k|0}l=a[i+7|0]|0;m=(l&2)==0;do{if(m){n=a[i+4|0]|0;if((n-1&255)>>>0<2>>>0){o=1;break}p=c[i>>2]|0;if((p|0)!=0){if((krc(p,2362688,4)|0)==0){o=3;break}}if(!((l&32)==0)){o=0;break}o=n<<24>>24==0?-1:2}else{o=0}}while(0);l=a[j+7|0]|0;n=(l&2)==0;p=a[j+4|0]|0;do{if(n){if((p-1&255)>>>0<2>>>0){q=1;break}r=c[j>>2]|0;if((r|0)!=0){if((krc(r,2362688,4)|0)==0){q=3;break}}if(!((l&32)==0)){q=0;break}q=p<<24>>24==0?-1:2}else{q=0}}while(0);l=a[i+4|0]|0;r=(l&255)>>>0>(p&255)>>>0?p:l;s=r&255;do{if(r<<24>>24==0){t=0;u=2147483646}else{if((h&2|0)==0){t=0;u=2147483646;break}else{v=0;w=0;x=2147483646}while(1){y=(e[j+8+(w<<1)>>1]|0)>>>11&15;if(((e[i+8+(w<<1)>>1]|0)>>>11&15)>>>0>(y&65535)>>>0){z=x-(65536>>>((y&65535)>>>0))|0;A=v|2}else{z=x;A=v}y=w+1|0;if((y|0)<(s|0)){v=A;w=y;x=z}else{t=A;u=z;break}}}}while(0);do{if((h&1|0)==0){B=u;C=t}else{z=a[j+5|0]|0;A=a[i+5|0]|0;if((z&255)>>>0>(A&255)>>>0){D=u-(256<<(z&255))|0;E=t|1}else{D=u;E=t}x=a[j+6|0]|0;w=a[i+6|0]|0;if((x&255)>>>0>(w&255)>>>0){F=D-(256<<(x&255))|0;G=E|1}else{F=D;G=E}if(!(z<<24>>24==1&A<<24>>24==0&x<<24>>24==1)){B=F;C=G;break}B=w<<24>>24==0?F+512|0:F;C=G}}while(0);do{if((h&4|0)==0){H=C}else{if((q|0)==0){H=o>>>0>1>>>0?C|4:C;break}else if((q|0)==1){H=(o|0)==1?C:C|4;break}else if((q|0)==2){H=(o|0)==2?C:C|4;break}else if((q|0)==3){H=(o-2|0)>>>0>1>>>0&(o|0)!=1?C|4:C;break}else{H=(o|0)==(q|0)?C:C|4;break}}}while(0);if((H&4|0)==0){I=B}else{C=b[j+8>>1]|0;j=b[i+8>>1]|0;I=B-(s<<16>>>((((((C&65535)>>>11&15)>>>0>((j&65535)>>>11&15)>>>0?j:C)&65535)>>>11&15)>>>0))|0}C=(o|0)==1;do{if((q|0)!=1|C){J=I;K=H}else{if((h&32|0)==0){J=I;K=H;break}J=I-131072|0;K=H|32}}while(0);do{if((p<<24>>24|0)==2|(p<<24>>24|0)==4){L=J;M=K}else{if(!n){L=J;M=K;break}if(!((l<<24>>24|0)==2|(l<<24>>24|0)==4)){if(m){L=J;M=K;break}}if((h&8|0)==0){L=J;M=K;break}L=J-65536|0;M=K|8}}while(0);do{if((d|0)==11){if((h&16|0)==0|(f|0)==11){N=L;O=M;break}if(C){if(!((l<<24>>24|0)==2|(l<<24>>24|0)==4)){if(m){N=L;O=M;break}}if((h&8|0)==0){N=L;O=M;break}}N=L-65536|0;O=M|16}else{N=L;O=M}}while(0);c[g>>2]=O;k=N;return k|0}function xLa(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+24|0;j=h|0;k=qKb(a)|0;l=qKb(b)|0;m=(g|0)!=0;if(m){n=~c[g>>2]}else{n=-1}o=(f|0)==0?n&-9:n;n=wLa(a,e,h+8|0,o)|0;p=wLa(b,e,h+16|0,o)|0;do{if((n|0)==(p|0)){o=pKb(l)|0;if((o|0)==(pKb(k)|0)){q=(d[l+4|0]|0)>>>0<(d[k+4|0]|0)>>>0?b:a;break}else{o=pKb(l)|0;r=(o|0)<(pKb(k)|0);q=r?b:a;break}}else{q=(n|0)<(p|0)?b:a}}while(0);if(!m){i=h;return q|0}m=wLa(q,e,j,(f|0)!=0?-1:-9)|0;c[g>>2]=(m|0)<0?m:c[j>>2]|0;i=h;return q|0}function yLa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((h|0)<=0){return}i=f<<1;if((g|0)<=3){j=e;k=b;l=h;while(1){if((g|0)>0){m=g;n=j;o=j+f|0;p=k;while(1){a[p]=((d[n]|0)+2+(d[n+1|0]|0)+(d[o]|0)+(d[o+1|0]|0)|0)>>>2;q=m-1|0;if((q|0)>0){m=q;n=n+2|0;o=o+2|0;p=p+1|0}else{break}}}p=l-1|0;if((p|0)>0){j=j+i|0;k=k+c|0;l=p}else{break}}return}l=g-4|0;k=l>>>2;j=k<<2;p=l-j|0;l=k<<3;k=f<<1;o=e;n=b;m=h;h=b+(j+4)|0;j=e+(l+f+8)|0;b=e+(l+8)|0;while(1){l=g;e=o;q=o+f|0;r=n;while(1){a[r]=((d[e]|0)+2+(d[e+1|0]|0)+(d[q]|0)+(d[q+1|0]|0)|0)>>>2;a[r+1|0]=((d[e+2|0]|0)+2+(d[e+3|0]|0)+(d[q+2|0]|0)+(d[q+3|0]|0)|0)>>>2;a[r+2|0]=((d[e+4|0]|0)+2+(d[e+5|0]|0)+(d[q+4|0]|0)+(d[q+5|0]|0)|0)>>>2;a[r+3|0]=((d[e+6|0]|0)+2+(d[e+7|0]|0)+(d[q+6|0]|0)+(d[q+7|0]|0)|0)>>>2;s=l-4|0;if((s|0)>3){l=s;e=e+8|0;q=q+8|0;r=r+4|0}else{break}}if((p|0)>0){r=p;q=b;e=j;l=h;while(1){a[l]=((d[q]|0)+2+(d[q+1|0]|0)+(d[e]|0)+(d[e+1|0]|0)|0)>>>2;s=r-1|0;if((s|0)>0){r=s;q=q+2|0;e=e+2|0;l=l+1|0}else{break}}}l=m-1|0;if((l|0)>0){o=o+i|0;n=n+c|0;m=l;h=h+c|0;j=j+k|0;b=b+k|0}else{break}}return}function zLa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((h|0)<=0){return}i=f<<1;j=i+f|0;k=f<<2;if((g|0)>0){l=e;m=b;n=h}else{return}while(1){h=g;b=l;e=l+f|0;o=l+i|0;p=l+j|0;q=m;while(1){a[q]=((d[b]|0)+8+(d[b+1|0]|0)+(d[b+2|0]|0)+(d[b+3|0]|0)+(d[e]|0)+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[o]|0)+(d[o+1|0]|0)+(d[o+2|0]|0)+(d[o+3|0]|0)+(d[p]|0)+(d[p+1|0]|0)+(d[p+2|0]|0)+(d[p+3|0]|0)|0)>>>4;r=h-1|0;if((r|0)>0){h=r;b=b+4|0;e=e+4|0;o=o+4|0;p=p+4|0;q=q+1|0}else{break}}q=n-1|0;if((q|0)>0){l=l+k|0;m=m+c|0;n=q}else{break}}return}function ALa(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((h|0)<=0){return}i=(g|0)>0;j=f<<3;k=j-(g<<3)|0;l=c-g|0;c=8-j|0;j=f*7|0;m=g<<3;n=e;e=b;b=h;while(1){if(i){h=n+m|0;o=n;p=e;q=g;while(1){r=o;s=0;t=0;while(1){u=(d[r]|0)+t+(d[r+1|0]|0)+(d[r+2|0]|0)+(d[r+3|0]|0)+(d[r+4|0]|0)+(d[r+5|0]|0)+(d[r+6|0]|0)+(d[r+7|0]|0)|0;v=s+1|0;if((v|0)<8){r=r+f|0;s=v;t=u}else{break}}a[p]=(u+32|0)>>>6;t=q-1|0;if((t|0)>0){o=o+(j+(c+f))|0;p=p+1|0;q=t}else{break}}w=h;x=e+g|0}else{w=n;x=e}q=b-1|0;if((q|0)>0){n=w+k|0;e=x+l|0;b=q}else{break}}return}function BLa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=6;a=UHb()|0;c[b+4>>2]=a;if((a|0)==0){d=-12;return d|0}c[1457863]=5831472;c[1457865]=16384;$2(5831448,14,143,1059298,4,2,1059296,4,2,0,0,0,6)|0;d=0;return d|0}function CLa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;h=c[b+60>>2]|0;j=h;k=c[f+24>>2]|0;l=c[f+28>>2]|0;f=d;d=c[h+4>>2]|0;m=N4a(b,d)|0;if((m|0)<0){n=m;i=g;return n|0}if((l|0)<49){KIb(c[h>>2]|0,16,2452016,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1094995529;i=g;return n|0}m=a[k+18|0]|0;c[h+28>>2]=m&255;o=k+48|0;k=(l<<3)-384|0;p=k>>>0>2147483639>>>0|(o|0)==0;q=p?0:o;o=p?0:k;c[h+8>>2]=q;c[h+20>>2]=o;c[h+24>>2]=o+8;c[h+12>>2]=q+(o>>3);c[h+16>>2]=0;h=b+120|0;o=c[h>>2]|0;q=b+124|0;b=c[q>>2]|0;k=c[d>>2]|0;p=c[d+32>>2]|0;do{if(m<<24>>24==0){r=FLa(j,o,b,k,p)|0;if((r|0)<0){n=r;i=g;return n|0}r=FLa(j,c[h>>2]>>2,c[q>>2]>>2,c[d+8>>2]|0,c[d+40>>2]|0)|0;if((r|0)<0){n=r;i=g;return n|0}r=FLa(j,c[h>>2]>>2,c[q>>2]>>2,c[d+4>>2]|0,c[d+36>>2]|0)|0;if((r|0)<0){n=r}else{break}i=g;return n|0}else{r=ELa(j,o,b,k,p)|0;if((r|0)<0){n=r;i=g;return n|0}r=ELa(j,c[h>>2]>>2,c[q>>2]>>2,c[d+8>>2]|0,c[d+40>>2]|0)|0;if((r|0)<0){n=r;i=g;return n|0}r=ELa(j,c[h>>2]>>2,c[q>>2]>>2,c[d+4>>2]|0,c[d+36>>2]|0)|0;if((r|0)<0){n=r}else{break}i=g;return n|0}}while(0);q=YHb(f,d)|0;if((q|0)<0){n=q;i=g;return n|0}c[e>>2]=1;n=l;i=g;return n|0}function DLa(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function ELa(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((f&1|0)!=0){j=-1094995529;return j|0}k=(f|0)>0;a:do{if(k){l=e+16|0;m=e+24|0;n=e+8|0;o=0;b:while(1){p=c[1457863]|0;q=c[l>>2]|0;r=c[m>>2]|0;s=(c[n>>2]|0)+(q>>>3)|0;t=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((q&7)>>>0)&16383;s=b[p+(t<<2)>>1]|0;u=(b[p+(t<<2)+2>>1]|0)+q|0;c[l>>2]=r>>>0>u>>>0?u:r;r=s+1|0;u=r<<1;do{if((r|0)>127){q=u-254|0;if((q+o|0)>(f|0)){j=-1094995529;break b}if((q|0)<=0){v=o;break}q=s<<1;mrc(h+o|0,-128|0,q-252|0)|0;v=o-252+q|0}else{a[h+o|0]=a[1059040+u|0]|0;a[h+(o+1)|0]=a[1059040+(u|1)|0]|0;v=o+2|0}}while(0);if((v|0)<(f|0)){o=v}else{break a}}return j|0}}while(0);if((g|0)<=1){j=0;return j|0}v=e+16|0;o=e+24|0;l=e+8|0;if(k){w=1;x=h}else{h=1;while(1){k=h+1|0;if((k|0)<(g|0)){h=k}else{j=0;break}}return j|0}c:while(1){h=x+i|0;k=0;while(1){e=c[1457863]|0;n=c[v>>2]|0;m=c[o>>2]|0;u=(c[l>>2]|0)+(n>>>3)|0;s=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((n&7)>>>0)&16383;u=b[e+(s<<2)>>1]|0;r=(b[e+(s<<2)+2>>1]|0)+n|0;c[v>>2]=m>>>0>r>>>0?r:m;m=u+1|0;do{if((m|0)>127){r=(m<<1)-254|0;if((r+k|0)>(f|0)){j=-1094995529;y=27;break c}if((r|0)<=0){z=k;break}n=u<<1;s=0;e=k;while(1){a[x+(e+i)|0]=a[x+e|0]|0;q=s+1|0;if((q|0)<(r|0)){s=q;e=e+1|0}else{break}}z=k-252+n|0}else{e=m<<1;s=(d[x+k|0]|0)-128+(d[1059040+e|0]|0)|0;if(s>>>0>255>>>0){A=-s>>31&255}else{A=s&255}a[x+(k+i)|0]=A;s=k+1|0;r=(d[x+s|0]|0)-128+(d[1059040+(e|1)|0]|0)|0;if(r>>>0>255>>>0){B=-r>>31&255}else{B=r&255}a[x+(s+i)|0]=B;z=k+2|0}}while(0);if((z|0)<(f|0)){k=z}else{break}}k=w+1|0;if((k|0)<(g|0)){w=k;x=h}else{j=0;y=27;break}}if((y|0)==27){return j|0}return 0}function FLa(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((f&1|0)!=0){j=-1094995529;return j|0}if((g|0)<=0){j=0;return j|0}k=(f|0)>0;l=e+16|0;m=e+24|0;n=e+8|0;e=h;h=0;while(1){if(k){o=0;while(1){p=c[1457863]|0;q=c[l>>2]|0;r=c[m>>2]|0;s=(c[n>>2]|0)+(q>>>3)|0;t=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((q&7)>>>0)&16383;s=b[p+(t<<2)>>1]|0;u=(b[p+(t<<2)+2>>1]|0)+q|0;c[l>>2]=r>>>0>u>>>0?u:r;r=s+1|0;if((r|0)>127){v=o-254+(r<<1)|0}else{s=e+o|0;u=r<<1;r=(((d[1059040+u|0]|0)*3|0)-384>>2)+(d[s]|0)|0;if(r>>>0>255>>>0){w=-r>>31&255}else{w=r&255}a[s]=w;s=e+(o+1)|0;r=(((d[1059040+(u|1)|0]|0)*3|0)-384>>2)+(d[s]|0)|0;if(r>>>0>255>>>0){x=-r>>31&255}else{x=r&255}a[s]=x;v=o+2|0}if((v|0)<(f|0)){o=v}else{break}}}o=h+1|0;if((o|0)<(g|0)){e=e+i|0;h=o}else{j=0;break}}return j|0}function GLa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[b+60>>2]|0;c[e>>2]=b;c[b+140>>2]=6;f=0;do{g=f+2|0;h=a[1898808+f|0]|0;i=d[1898816+f|0]|0;j=0;do{k=j+h|0;a[5410136+(f<<7)+j|0]=i-((k|0)%(g|0)|0)+k;j=j+1|0;}while((j|0)<128);f=f+1|0;}while((f|0)<8);a[5410263]=126;a[5410383]=118;a[5410384]=118;a[5410518]=124;a[5410519]=124;y=2021161080;a[5411028]=y;y=y>>8;a[5411029]=y;y=y>>8;a[5411030]=y;y=y>>8;a[5411031]=y;a[5410271]=10;a[5410656]=10;YJa(e+4|0,c[b+88>>2]|0);return NLa(e,b,c[b+120>>2]|0,c[b+124>>2]|0)|0}function HLa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;j=i;k=c[e+60>>2]|0;l=k;m=c[h+24>>2]|0;n=c[h+28>>2]|0;h=f;if(!((n|0)>-1)){KIb(0,0,2403392,(o=i,i=i+24|0,c[o>>2]=2396440,c[o+8>>2]=2389552,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}p=m+n|0;if((n|0)<4){q=0;r=m}else{s=m;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;r=m+4|0}if((p-r|0)<4){t=0;u=r}else{m=r;t=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;u=r+4|0}if((p-u|0)<4){v=0;w=u}else{r=u;v=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;w=u+4|0}if((p-w|0)<4){x=0;y=w}else{u=w;x=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;y=w+4|0}if((q^1179798856^t^x|0)!=(v|0)){KIb(e,16,2478424,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1094995529;i=j;return z|0}v=y;do{if((p-v|0)>=2){x=y+2|0;t=y;if(!((d[t]|d[t+1|0]<<8)<<16>>16<<16>>16==32)){break}c[k+260>>2]=q;if((p-x|0)<2){A=0;B=x}else{t=x;A=(d[t]|d[t+1|0]<<8)<<16>>16;B=y+4|0}t=k+268|0;b[t>>1]=A;if((p-B|0)<4){C=0;D=B}else{x=B;C=((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24)+7|0)>>>3;D=B+4|0}x=k+264|0;c[x>>2]=C;if((p-D|0)<1){E=0;F=D}else{E=a[D]|0;F=D+1|0}a[k+270|0]=E;a:do{if((C|0)!=16){w=n-16|0;c[x>>2]=C>>>0>w>>>0?w:C;w=p-F|0;u=w>>>0>3>>>0?3:w;w=F+u|0;if((p-w|0)<2){G=0;H=w}else{r=w;G=(d[r]|d[r+1|0]<<8)<<16>>16&65535;H=F+(u+2)|0}if((p-H|0)<2){I=0;J=H}else{u=H;I=(d[u]|d[u+1|0]<<8)<<16>>16&65535;J=H+2|0}u=e;if((tIb(I,G,0,u)|0)!=0){z=-1094995529;i=j;return z|0}r=k+256|0;if((I|0)==(b[r>>1]|0)){if((G|0)!=(b[k+258>>1]|0)){K=30}}else{K=30}b:do{if((K|0)==30){do{if(!((I-16|0)>>>0>624>>>0|G>>>0<16>>>0|G>>>0>480>>>0)){if((I&3|0)!=0){break}if((G&3|0)!=0){break}b[k+258>>1]=0;b[r>>1]=0;mJb(k+300|0);mJb(k+304|0);c[k+312>>2]=0;c[k+308>>2]=0;mJb(k+328|0);mJb(k+332|0);c[k+340>>2]=0;c[k+336>>2]=0;mJb(k+356|0);mJb(k+360|0);c[k+368>>2]=0;c[k+364>>2]=0;w=NLa(l,e,I,G)|0;if((w|0)<0){z=w;i=j;return z|0}w=H4a(e,I,G)|0;if((w|0)<0){z=w}else{break b}i=j;return z|0}}while(0);KIb(u,16,2459600,(o=i,i=i+16|0,c[o>>2]=I,c[o+8>>2]=G,o)|0);i=o;z=-1094995529;i=j;return z|0}}while(0);if((p-J|0)<4){L=0;M=J}else{r=J;L=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;M=J+4|0}if((p-M|0)<4){N=0;O=M}else{r=M;N=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;O=M+4|0}if((p-O|0)<4){P=0;Q=O}else{r=O;P=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;Q=O+4|0}r=p-Q|0;w=c[x>>2]|0;m=P>>>0<w>>>0;s=m&P>>>0>L>>>0?P:w;R=m&P>>>0>N>>>0?P:w;m=L>>>0>N>>>0;S=N>>>0<w>>>0&N>>>0>P>>>0?N:w;T=Q+(r>>>0>4>>>0?4:r)|0;r=(N>>>0<s>>>0&N>>>0>L>>>0?N:s)-L|0;s=k+284|0;c[s>>2]=r;U=(L>>>0<R>>>0&m?L:R)-N|0;R=k+288|0;c[R>>2]=U;V=(L>>>0<S>>>0&L>>>0>P>>>0?L:S)-P|0;S=k+292|0;c[S>>2]=V;W=m?L:N;do{if((W>>>0>P>>>0?W:P)>>>0<(w-16|0)>>>0){X=m?N:L;if((X>>>0>P>>>0?P:X)>>>0<(16-v+T|0)>>>0){break}X=(r|0)>(U|0)?U:r;if((((X|0)>(V|0)?V:X)|0)<1){break}X=k+272|0;c[X>>2]=y+L;Y=k+276|0;c[Y>>2]=y+N;Z=k+280|0;c[Z>>2]=y+P;c[k+296>>2]=T;if((w|0)==16){KIb(u,48,2430656,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break a}_=b[t>>1]|0;$=_&65535;if(($&2|0)!=0){QIb(u,2420416,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1163346256;i=j;return z|0}if(($&48|0)!=0){QIb(u,2411104,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1163346256;i=j;return z|0}do{if(!((_&256)==0)){if((c[e+856>>2]|0)>7){z=0}else{break}i=j;return z|0}}while(0);do{if((_&4)==0){if((c[e+856>>2]|0)>31){z=0}else{break}i=j;return z|0}}while(0);$=k+271|0;a[$]=(_&65535)>>>9&1;aa=M4a(e,h,0)|0;if((aa|0)<0){z=aa;i=j;return z|0}aa=k+300|0;ba=JLa(l,e,aa,c[X>>2]|0,c[s>>2]|0,40)|0;if((ba|0)!=0){z=ba;i=j;return z|0}ba=k+328|0;ca=JLa(l,e,ba,c[Z>>2]|0,c[S>>2]|0,10)|0;if((ca|0)!=0){z=ca;i=j;return z|0}ca=k+356|0;da=JLa(l,e,ca,c[Y>>2]|0,c[R>>2]|0,10)|0;if((da|0)!=0){z=da;i=j;return z|0}da=c[f+32>>2]|0;ea=e+124|0;fa=c[ea>>2]|0;ga=c[k+324>>2]|0;ha=c[k+320>>2]|0;ia=ha>>>0<fa>>>0?ha:fa;if((ia|0)>0){ha=k+316|0;ja=0;ka=c[aa+8+(d[$]<<2)>>2]|0;aa=c[f>>2]|0;la=c[ha>>2]|0;while(1){if(la>>>0>3>>>0){ma=0;na=ka;oa=aa;do{c[oa>>2]=c[na>>2]<<1&-16843010;na=na+4|0;oa=oa+4|0;ma=ma+1|0;pa=c[ha>>2]|0;}while(ma>>>0<pa>>>2>>>0);qa=ma<<2;ra=na;sa=oa;ta=pa}else{qa=0;ra=ka;sa=aa;ta=la}if(qa>>>0<ta>>>0){ua=qa;va=ra;wa=sa;while(1){xa=va+1|0;ya=wa+1|0;a[wa]=a[va]<<1;za=ua+1|0;Aa=c[ha>>2]|0;if(za>>>0<Aa>>>0){ua=za;va=xa;wa=ya}else{Ba=xa;Ca=ya;Da=Aa;break}}}else{Ba=ra;Ca=sa;Da=ta}wa=ja+1|0;if((wa|0)<(ia|0)){ja=wa;ka=Ba+(ga-Da)|0;aa=Ca+(da-Da)|0;la=Da}else{break}}Ea=c[ea>>2]|0}else{Ea=fa}la=c[f+36>>2]|0;da=Ea+3>>2;aa=c[k+352>>2]|0;ga=c[k+348>>2]|0;ka=ga>>>0<da>>>0?ga:da;if((ka|0)>0){da=k+344|0;ga=0;ja=c[ba+8+(d[$]<<2)>>2]|0;ia=c[f+4>>2]|0;ha=c[da>>2]|0;while(1){if(ha>>>0>3>>>0){Y=0;Z=ja;X=ia;do{c[X>>2]=c[Z>>2]<<1&-16843010;Z=Z+4|0;X=X+4|0;Y=Y+1|0;Fa=c[da>>2]|0;}while(Y>>>0<Fa>>>2>>>0);Ga=Y<<2;Ha=Z;Ia=X;Ja=Fa}else{Ga=0;Ha=ja;Ia=ia;Ja=ha}if(Ga>>>0<Ja>>>0){_=Ga;wa=Ha;va=Ia;while(1){ua=wa+1|0;oa=va+1|0;a[va]=a[wa]<<1;na=_+1|0;ma=c[da>>2]|0;if(na>>>0<ma>>>0){_=na;wa=ua;va=oa}else{Ka=ua;La=oa;Ma=ma;break}}}else{Ka=Ha;La=Ia;Ma=Ja}va=ga+1|0;if((va|0)<(ka|0)){ga=va;ja=Ka+(aa-Ma)|0;ia=La+(la-Ma)|0;ha=Ma}else{break}}Na=c[ea>>2]|0}else{Na=Ea}ha=c[f+40>>2]|0;la=Na+3>>2;ia=c[k+380>>2]|0;aa=c[k+376>>2]|0;ja=aa>>>0<la>>>0?aa:la;if((ja|0)>0){la=k+372|0;aa=0;ga=c[ca+8+(d[$]<<2)>>2]|0;ka=c[f+8>>2]|0;da=c[la>>2]|0;while(1){if(da>>>0>3>>>0){ba=0;fa=ga;va=ka;do{c[va>>2]=c[fa>>2]<<1&-16843010;fa=fa+4|0;va=va+4|0;ba=ba+1|0;Oa=c[la>>2]|0;}while(ba>>>0<Oa>>>2>>>0);Pa=ba<<2;Qa=fa;Ra=va;Sa=Oa}else{Pa=0;Qa=ga;Ra=ka;Sa=da}if(Pa>>>0<Sa>>>0){wa=Pa;_=Qa;X=Ra;while(1){Z=_+1|0;Y=X+1|0;a[X]=a[_]<<1;ma=wa+1|0;oa=c[la>>2]|0;if(ma>>>0<oa>>>0){wa=ma;_=Z;X=Y}else{Ta=Z;Ua=Y;Va=oa;break}}}else{Ta=Qa;Ua=Ra;Va=Sa}X=aa+1|0;if((X|0)<(ja|0)){aa=X;ga=Ta+(ia-Va)|0;ka=Ua+(ha-Va)|0;da=Va}else{break}}}c[g>>2]=1;z=n;i=j;return z|0}}while(0);KIb(u,16,2442936,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1094995529;i=j;return z|0}}while(0);c[g>>2]=0;z=n;i=j;return z|0}}while(0);KIb(e,16,2468856,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;z=-1094995529;i=j;return z|0}function ILa(a){a=a|0;var d=0;d=c[a+60>>2]|0;b[d+258>>1]=0;b[d+256>>1]=0;mJb(d+300|0);mJb(d+304|0);c[d+312>>2]=0;c[d+308>>2]=0;mJb(d+328|0);mJb(d+332|0);c[d+340>>2]=0;c[d+336>>2]=0;mJb(d+356|0);mJb(d+360|0);c[d+368>>2]=0;c[d+364>>2]=0;return 0}function JLa(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;l=i;i=i+16|0;m=l|0;n=h;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j-4|0;if(o>>>0>256>>>0){KIb(c[e>>2]|0,16,2451968,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;q=-1094995529;i=l;return q|0}p=o<<1;if(p>>>0>n>>>0){q=-1094995529;i=l;return q|0}c[e+252>>2]=o;c[e+248>>2]=(o|0)!=0?h+4|0:0;o=h+(p+4)|0;r=n-p<<3;p=r>>>0>2147483639>>>0|(o|0)==0;n=p?0:o;o=p?0:r;c[e+212>>2]=n;c[e+224>>2]=o;c[e+228>>2]=o+8;c[e+216>>2]=n+(o>>3);c[e+220>>2]=0;c[e+236>>2]=0;c[e+232>>2]=0;c[e+244>>2]=h+j;b[m+2>>1]=0;b[m>>1]=0;b[m+4>>1]=(c[g+16>>2]|0)>>>2;b[m+6>>1]=(c[g+20>>2]|0)>>>2;a[m+8|0]=0;c[m+12>>2]=0;q=KLa(e,f,g,2,m,20,k)|0;i=l;return q|0}function KLa(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;m=i;i=i+40|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;if((k|0)<1){KIb(f,16,2362640,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=m;return s|0}t=q;u=j;c[t>>2]=c[u>>2];c[t+4>>2]=c[u+4>>2];c[t+8>>2]=c[u+8>>2];c[t+12>>2]=c[u+12>>2];do{if((h|0)==0){u=j+6|0;t=b[u>>1]|0;if(t<<16>>16>2){v=((t<<16>>16)+2|0)>>>2<<1&65535}else{v=1}b[q+6>>1]=v;w=j+2|0;b[w>>1]=(b[w>>1]|0)+v;w=t-v&65535;b[u>>1]=w;if(w<<16>>16<1|v<<16>>16<1){s=-1094995529}else{break}i=m;return s|0}else if((h|0)==1){w=q+4|0;u=b[w>>1]|0;do{if((u|0)>(l|0)){t=(ca((u|0)<=(l<<1|0)?1:2,l)|0)&65535;x=t;y=b[j+4>>1]|0}else{t=b[j+4>>1]|0;if(!(t<<16>>16>2)){x=1;y=t;break}x=((t<<16>>16)+2|0)>>>2<<1&65535;y=t}}while(0);b[w>>1]=x;u=j|0;b[u>>1]=(b[u>>1]|0)+x;u=y-x&65535;b[j+4>>1]=u;if(u<<16>>16<1|x<<16>>16<1){s=-1094995529}else{break}i=m;return s|0}}while(0);x=e+220|0;j=c[x>>2]|0;y=e+224|0;h=c[y>>2]|0;if((h-j|0)<=1){s=-1094995529;i=m;return s|0}v=e+232|0;u=e+228|0;t=e+212|0;z=k-1|0;k=q+8|0;A=q+12|0;B=e+240|0;C=e+244|0;D=e+252|0;E=e+248|0;F=e+236|0;G=j;j=h;while(1){h=c[v>>2]|0;do{if((h|0)==0){H=G;I=0}else{if((G&7|0)!=0){H=G;I=h;break}J=c[F>>2]|0;K=-G|0;L=(c[u>>2]|0)-G|0;if((J|0)<(K|0)){M=K}else{M=(L|0)<(J|0)?L:J}J=M+G|0;c[x>>2]=J;c[F>>2]=0;c[v>>2]=0;H=J;I=0}}while(0);N=c[u>>2]|0;O=c[t>>2]|0;h=O+(H>>>3)|0;w=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(H&7)>>>30;h=H+2|0;P=N>>>0>h>>>0?h:N;c[x>>2]=P;if((w|0)==3){Q=(I|0)!=0;if((a[k]|0)!=0){R=49;break}if(Q){S=c[B>>2]|0}else{h=O+(P+7>>3)|0;c[B>>2]=h;S=h}if(!(S>>>0<(c[C>>2]|0)>>>0)){R=44;break}c[B>>2]=S+1;h=d[S]|0;if(!(h>>>0<(c[D>>2]|0)>>>0)){R=46;break}c[A>>2]=(c[E>>2]|0)+(h<<1);a[k]=1;c[F>>2]=(c[F>>2]|0)+8;c[v>>2]=1;T=P;U=j}else if((w|0)==2){if((a[k]|0)!=0){R=24;break}c[A>>2]=0;a[k]=1;T=P;U=j}else if((w|0)==0|(w|0)==1){if((KLa(e,f,g,w,q,z,l)|0)!=0){s=-1094995529;R=95;break}T=c[x>>2]|0;U=c[y>>2]|0}else{T=P;U=j}if((U-T|0)>1){G=T;j=U}else{s=-1094995529;R=95;break}}if((R|0)==24){do{if((I|0)==0){V=P}else{if((P&7|0)!=0){V=P;break}U=c[F>>2]|0;j=-P|0;T=N-P|0;if((U|0)<(j|0)){W=j}else{W=(T|0)<(U|0)?T:U}U=W+P|0;c[x>>2]=U;c[F>>2]=0;c[v>>2]=0;V=U}}while(0);W=O+(V>>>3)|0;I=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(V&7);W=I>>>30;U=V+2|0;c[x>>2]=N>>>0>U>>>0?U:N;if((I|0)<0){KIb(f,16,2297816,(r=i,i=i+8|0,c[r>>2]=W,r)|0);i=r;s=-1094995529;i=m;return s|0}if((W|0)==1){KIb(f,16,2247088,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}W=b[q>>1]|0;I=b[q+4>>1]|0;N=b[q+2>>1]|0;do{if((I+W|0)>>>0>(c[g+16>>2]|0)>>>2>>>0){X=b[q+6>>1]|0}else{U=b[q+6>>1]|0;if(((U<<16>>16)+(N<<16>>16)|0)>>>0>(c[g+20>>2]|0)>>>2>>>0){X=U;break}if((c[A>>2]|0)==0){s=-1094995529;i=m;return s|0}s=LLa(e,g,q)|0;i=m;return s|0}}while(0);KIb(f,16,2205184,(r=i,i=i+32|0,c[r>>2]=W,c[r+8>>2]=N<<16>>16,c[r+16>>2]=I,c[r+24>>2]=X<<16>>16,r)|0);i=r;s=-1094995529;i=m;return s|0}else if((R|0)==44){KIb(f,16,2173032,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=m;return s|0}else if((R|0)==46){KIb(f,16,2145600,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=m;return s|0}else if((R|0)==49){if(!Q){c[B>>2]=O+(P+7>>3)}P=b[q>>1]|0;O=q+4|0;Q=b[O>>1]|0;X=Q+P|0;I=c[g+16>>2]|0;N=b[q+2>>1]|0;do{if(X>>>0>I>>>2>>>0){Y=b[q+6>>1]|0}else{W=N<<16>>16;U=b[q+6>>1]|0;x=(U<<16>>16)+W|0;V=c[g+20>>2]|0;if(x>>>0>V>>>2>>>0){Y=U;break}U=c[B>>2]|0;T=c[C>>2]|0;c[n>>2]=U+1;j=a[U]|0;G=j&255;y=G>>>4;l=G&15;G=W<<2;W=g+24|0;z=c[W>>2]|0;k=P<<2;E=k+(ca(G,z)|0)|0;D=d[e+271|0]|0;S=c[g+8+(D<<2)>>2]|0;H=S+E|0;t=c[A>>2]|0;a:do{if((t|0)==0){Z=S+(E-z)|0;R=65}else{if((j&255)>>>0>159>>>0){u=LLa(e,g,q)|0;if((u|0)<0){_=u;break}else{Z=0;R=65;break}}u=a[t]|0;M=a[t+1|0]|0;do{if(!((u+G|0)<-1)){if((M+k|0)<0){break}if(((x<<2)+u|0)>>>0>V>>>0){break}if(((X<<2)+M|0)>>>0>I>>>0){break}w=M+E+(ca(u,z)|0)|0;Z=(c[g+8+((D^1)<<2)>>2]|0)+w|0;R=65;break a}}while(0);KIb(c[e>>2]|0,16,2121824,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;_=-1094995529}}while(0);b:do{if((R|0)==65){if((y|0)==4|(y|0)==1){D=a[(c[e+296>>2]|0)+l|0]|0;z=D&255;E=d[e+270|0]|0;$=l;aa=D;ba=(z&15)+E|0;da=(z>>>4)+E|0}else{E=(d[e+270|0]|0)+l|0;$=E;aa=j;ba=E;da=E}if((da|0)>23|(ba|0)>23){KIb(f,16,2639360,(r=i,i=i+16|0,c[r>>2]=da,c[r+8>>2]=ba,r)|0);i=r;_=-1094995529;break}E=p|0;c[E>>2]=190520+(ba*12|0);c[p+4>>2]=190520+(da*12|0);z=o|0;c[z>>2]=(ba|0)>15;c[o+4>>2]=(da|0)>15;do{if(!(($|0)<8|(Z|0)==0)){if((b[O>>1]<<2|0)<=0){break}D=$&7;V=0;do{x=Z+V|0;a[x]=a[(a[x]&127)+(5410136+(D<<7))|0]|0;V=V+1|0;}while((V|0)<(b[O>>1]<<2|0))}}while(0);c:do{switch(y|0){case 10:case 11:{V=(y|0)==10;D=(c[A>>2]|0)==0;do{if(V){if(!D){break}ea=MLa(q,H,Z,c[W>>2]|0,1,1,10,E,z,n,T)|0;break c}else{if(!D){break}KIb(f,16,2589480,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;_=-1094995529;break b}}while(0);ea=MLa(q,H,Z,c[W>>2]|0,V&1,1,y,E,z,n,T)|0;break};case 0:case 1:case 3:case 4:{D=(j&255)>>>0>47>>>0;do{if(D){if((c[A>>2]|0)==0){break}KIb(f,16,2616664,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;_=-1094995529;break b}}while(0);ea=MLa(q,H,Z,c[W>>2]|0,0,D&1,y,E,z,n,T)|0;break};default:{KIb(f,16,2567864,(r=i,i=i+8|0,c[r>>2]=y,r)|0);i=r;_=-1094995529;break b}}}while(0);switch(ea|0){case 1:{z=d[(c[n>>2]|0)-1|0]|0;KIb(f,16,2549744,(r=i,i=i+16|0,c[r>>2]=y,c[r+8>>2]=z,r)|0);i=r;_=-1094995529;break b;break};case 2:{KIb(f,16,2531680,(r=i,i=i+8|0,c[r>>2]=y,r)|0);i=r;_=-1094995529;break b;break};case 3:{KIb(f,16,2516432,(r=i,i=i+16|0,c[r>>2]=y,c[r+8>>2]=aa&255,r)|0);i=r;_=-1094995529;break b;break};case 4:{z=d[(c[n>>2]|0)-1|0]|0;KIb(f,16,2502536,(r=i,i=i+16|0,c[r>>2]=y,c[r+8>>2]=z,r)|0);i=r;_=-1094995529;break b;break};case 5:{KIb(f,16,2489448,(r=i,i=i+8|0,c[r>>2]=y,r)|0);i=r;_=-1094995529;break b;break};default:{_=(c[n>>2]|0)-U|0;break b}}}}while(0);if((_|0)<0){s=-1094995529;i=m;return s|0}c[F>>2]=(c[F>>2]|0)+(_<<3);c[v>>2]=1;c[B>>2]=(c[B>>2]|0)+_;s=0;i=m;return s|0}}while(0);KIb(f,16,2205184,(r=i,i=i+32|0,c[r>>2]=P,c[r+8>>2]=N<<16>>16,c[r+16>>2]=Q,c[r+24>>2]=Y<<16>>16,r)|0);i=r;s=-1094995529;i=m;return s|0}else if((R|0)==95){i=m;return s|0}return 0}function LLa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;j=b[g+2>>1]|0;k=j<<2;l=f+24|0;m=c[l>>2]|0;n=ca(k,m)|0;o=g|0;p=b[o>>1]|0;q=p<<16>>16;r=q<<2;s=r+n|0;n=d[e+271|0]|0;t=(c[f+8+(n<<2)>>2]|0)+s|0;u=c[g+12>>2]|0;if((u|0)==0){v=0;w=0}else{v=a[u]|0;w=a[u+1|0]|0}do{if(!((k+v|0)<-1)){if((r+w|0)<0){break}u=b[g+6>>1]|0;if(((u+j<<2)+v|0)>>>0>(c[f+20>>2]|0)>>>0){break}x=b[g+4>>1]|0;y=x<<16>>16;if(((y+q<<2)+w|0)>>>0>(c[f+16>>2]|0)>>>0){break}z=u<<2;if(!(x<<16>>16>0)){A=0;i=h;return A|0}x=ca(m,v)|0;u=e+20|0;B=e+36|0;C=e+4|0;D=y;y=(c[f+8+((n^1)<<2)>>2]|0)+(w+s+x)|0;x=t;E=p;while(1){if((E&3)==0&(D|0)>3){F=D-4|0;G=F>>>2;H=F-(G<<2)|0;F=G<<4;G=x;I=y;J=D;while(1){mf[c[C>>2]&2047](G,I,c[l>>2]|0,z);K=J-4|0;if((K|0)<=3){break}G=G+16|0;I=I+16|0;J=K}L=x+(F+16)|0;M=y+(F+16)|0;N=H;O=b[o>>1]|0}else{L=x;M=y;N=D;O=E}if((O&1)==0&(N|0)>1){mf[c[u>>2]&2047](L,M,c[l>>2]|0,z);P=L+8|0;Q=M+8|0;R=N-2|0}else{if((N|0)<=0){A=0;S=21;break}mf[c[B>>2]&2047](L,M,c[l>>2]|0,z);P=L+4|0;Q=M+4|0;R=N-1|0}if((R|0)<=0){A=0;S=21;break}D=R;y=Q;x=P;E=b[o>>1]|0}if((S|0)==21){i=h;return A|0}}}while(0);KIb(c[e>>2]|0,16,2121824,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;A=-1094995529;i=h;return A|0}function MLa(e,f,g,h,i,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0;p=e+4|0;q=b[p>>1]|0;r=q<<16>>16;s=(h<<j+2)-(r<<2)|0;t=(j|0)!=0?h:0;u=e+6|0;v=b[u>>1]|0;if((v<<16>>16&j|0)!=0){w=2;return w|0}if((r&i|0)!=0){w=2;return w|0}if(!(v<<16>>16>0)){w=0;return w|0}r=j+1|0;x=(k|0)<5;z=e+12|0;A=4<<j;B=(A|0)>0;C=(k|0)==10;D=4<<i;E=i+1|0;i=t+2|0;F=(k|0)>2;H=e+2|0;e=h+4|0;I=h+2|0;J=(k|0)>9;k=x^1;K=l+4|0;L=0;M=0;N=0;O=1;P=g;g=f;f=q;q=v;a:while(1){if(f<<16>>16>0){v=(O|0)==0;Q=(O|0)!=0;R=L;S=M;T=0;U=P;V=g;while(1){if((R|0)>0){do{if(x){if((S|0)!=0&(c[z>>2]|0)==0|B^1){break}else{W=U;X=V;Y=0}while(1){Z=W;_=X;y=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;_=Y+1|0;if((_|0)<(A|0)){W=W+h|0;X=X+h|0;Y=_}else{break}}}else{if(!C){break}if((c[z>>2]|0)!=0){break}_=U;Z=_|0;$=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;Z=_+4|0;aa=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;if(v){Z=V;c[Z>>2]=$;c[Z+4>>2]=aa;Z=V+h|0;c[Z>>2]=$;c[Z+4>>2]=aa;Z=h<<1;ba=V+Z|0;c[ba>>2]=$;c[ba+4>>2]=aa;ba=Z+h|0;Z=V+ba|0;c[Z>>2]=$;c[Z+4>>2]=aa;Z=ba+h|0;ba=V+Z|0;c[ba>>2]=$;c[ba+4>>2]=aa;ba=Z+h|0;Z=V+ba|0;c[Z>>2]=$;c[Z+4>>2]=aa;Z=ba+h|0;ba=V+Z|0;c[ba>>2]=$;c[ba+4>>2]=aa;ba=V+(Z+h)|0;c[ba>>2]=$;c[ba+4>>2]=aa;break}else{ba=$&16711935;$=aa&16711935;aa=ba<<8|0>>>24|ba;Z=$<<8|ba>>>24|$;$=V+h|0;c[$>>2]=aa;c[$+4>>2]=Z;ba=h<<1;da=V+ba|0;c[da>>2]=aa;c[da+4>>2]=Z;da=ba+h|0;ba=V+da|0;c[ba>>2]=aa;c[ba+4>>2]=Z;ba=da+h|0;da=V+ba|0;c[da>>2]=aa;c[da+4>>2]=Z;da=ba+h|0;ba=V+da|0;c[ba>>2]=aa;c[ba+4>>2]=Z;ba=da+h|0;da=V+ba|0;c[da>>2]=aa;c[da+4>>2]=Z;da=V+(ba+h)|0;c[da>>2]=aa;c[da+4>>2]=Z;Z=_|0;da=_+4|0;_=$|0;aa=$+4|0;$=wrc(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0,d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0,d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0,d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0;da=G;Z=V;c[Z>>2]=($>>>1|da<<31)&2139062143;c[Z+4>>2]=(da>>>1|0<<31)&2139062143;break}}}while(0);ea=S;fa=R-1|0}else{da=0;Z=R;$=V;aa=U;_=S;while(1){ba=(da|0)==0;ga=ba&Q;if(x){ha=l+((da&1)<<2)|0}else{ha=K}ia=c[ha>>2]|0;ja=c[n>>2]|0;if(!(ja>>>0<o>>>0)){w=5;ka=79;break a}la=ja+1|0;c[n>>2]=la;ma=a[ja]|0;na=ma&255;b:do{if((ma&255)>>>0<248>>>0){oa=ia+8|0;pa=a[oa]|0;if((ma&255)>>>0<(pa&255)>>>0){if(!(la>>>0<o>>>0)){w=5;ka=79;break a}c[n>>2]=ja+2;qa=a[la]|0;if((qa&255)>>>0>=(d[oa]|0)>>>0|(qa&255)>>>0>247>>>0){w=2;ka=79;break a}else{ra=na;sa=qa&255}}else{qa=na-(pa&255)&255;pa=d[ia+9|0]|0;oa=(qa>>>0)/(pa>>>0)|0;ta=(qa>>>0)%(pa>>>0)|0;pa=(c[m+((da&1)<<2)>>2]|0)==0;ra=pa?ta:oa;sa=pa?oa:ta}if(x){ta=aa;oa=ia|0;b[$+t>>1]=(b[(c[oa>>2]|0)+(sa<<1)>>1]|0)+((d[ta]|d[ta+1|0]<<8)<<16>>16)&32639;ta=aa+2|0;b[$+i>>1]=(b[(c[oa>>2]|0)+(ra<<1)>>1]|0)+((d[ta]|d[ta+1|0]<<8)<<16>>16)&32639;if(!F){ua=_;va=Z;wa=1;break}do{if(ga){if((b[H>>1]|0)!=0){break}ta=$+h|0;oa=$;y=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;ua=_;va=Z;wa=1;break b}}while(0);oa=aa;ta=$+h|0;c[$>>2]=((d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)|0)>>>1&2139062143;ua=_;va=Z;wa=1;break}if(!C){oa=$;ta=ia|0;b[oa>>1]=(b[(c[ta>>2]|0)+(sa<<1)>>1]|0)+((d[oa]|d[oa+1|0]<<8)<<16>>16)&32639;oa=$+2|0;b[oa>>1]=(b[(c[ta>>2]|0)+(ra<<1)>>1]|0)+((d[oa]|d[oa+1|0]<<8)<<16>>16)&32639;oa=$+h|0;b[oa>>1]=(b[(c[ta>>2]|0)+(sa<<1)>>1]|0)+((d[oa]|d[oa+1|0]<<8)<<16>>16)&32639;oa=$+I|0;b[oa>>1]=(b[(c[ta>>2]|0)+(ra<<1)>>1]|0)+((d[oa]|d[oa+1|0]<<8)<<16>>16)&32639;ua=_;va=Z;wa=1;break}if((c[z>>2]|0)!=0){oa=$;ta=ia+4|0;c[oa>>2]=(c[(c[ta>>2]|0)+(sa<<2)>>2]|0)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&2139062143;oa=$+4|0;c[oa>>2]=(c[(c[ta>>2]|0)+(ra<<2)>>2]|0)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&2139062143;oa=$+h|0;c[oa>>2]=(c[(c[ta>>2]|0)+(sa<<2)>>2]|0)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&2139062143;oa=$+e|0;c[oa>>2]=(c[(c[ta>>2]|0)+(ra<<2)>>2]|0)+(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&2139062143;ua=_;va=Z;wa=1;break}oa=aa;ta=d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0;do{if(ga){oa=ta&16711935;pa=ia+4|0;qa=$+h|0;c[qa>>2]=(c[(c[pa>>2]|0)+(sa<<2)>>2]|0)+(oa<<8|oa)&2139062143;oa=aa+4|0;xa=(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24)&16711935;c[$+e>>2]=(xa<<8|xa)+(c[(c[pa>>2]|0)+(ra<<2)>>2]|0)&2139062143;if((b[H>>1]|0)!=0){break}pa=qa;qa=pa|0;xa=pa+4|0;pa=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;xa=$;oa=xa|0;y=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;oa=xa+4|0;y=pa;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;ua=_;va=Z;wa=1;break b}else{oa=ia+4|0;c[$+h>>2]=(c[(c[oa>>2]|0)+(sa<<2)>>2]|0)+ta&2139062143;pa=aa+4|0;c[$+e>>2]=(c[(c[oa>>2]|0)+(ra<<2)>>2]|0)+(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24)&2139062143}}while(0);ta=aa;pa=ta|0;oa=ta+4|0;ta=$+h|0;xa=ta|0;qa=ta+4|0;ta=wrc(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0,d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0,d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0,d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0;oa=G;pa=$;c[pa>>2]=(ta>>>1|oa<<31)&2139062143;c[pa+4>>2]=(oa>>>1|0<<31)&2139062143;ua=_;va=Z;wa=1}else{switch(na|0){case 252:{ya=0;za=-3;Aa=1;break};case 255:case 254:case 253:{ya=_;za=ma;Aa=Z;break};case 250:{Ba=_;Ca=Z;ka=72;break};case 251:{if(!(la>>>0<o>>>0)){w=5;ka=79;break a}c[n>>2]=ja+2;oa=a[la]|0;pa=oa&255;ta=(pa&31)-1|0;if((oa&255)>>>0>63>>>0|(ta|0)<0){w=3;ka=79;break a}oa=pa&32;pa=4-da|0;if(!J){if(!((c[z>>2]|0)!=0|(oa|0)==0)){ua=oa;va=ta;wa=pa;break b}}if(x){qa=pa<<j;if((qa|0)>0){Da=aa;Ea=$;Fa=0}else{ua=oa;va=ta;wa=pa;break b}while(1){xa=Da;Ga=Ea;y=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;a[Ga]=y;y=y>>8;a[Ga+1|0]=y;y=y>>8;a[Ga+2|0]=y;y=y>>8;a[Ga+3|0]=y;Ga=Fa+1|0;if((Ga|0)<(qa|0)){Da=Da+h|0;Ea=Ea+h|0;Fa=Ga}else{ua=oa;va=ta;wa=pa;break b}}}if(!C){ua=oa;va=ta;wa=pa;break b}if((c[z>>2]|0)!=0){ua=oa;va=ta;wa=pa;break b}qa=aa;Ga=qa|0;xa=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;Ga=qa+4|0;Ha=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;if(!ga){Ga=pa<<1;if((Ga|0)>0){Ia=Ga;Ja=$}else{ua=oa;va=ta;wa=pa;break b}while(1){Ga=Ja;c[Ga>>2]=xa;c[Ga+4>>2]=Ha;Ga=Ia-1|0;if((Ga|0)>0){Ia=Ga;Ja=Ja+h|0}else{ua=oa;va=ta;wa=pa;break b}}}Ga=xa&16711935;Ka=Ha&16711935;La=Ga<<8|0>>>24|Ga;Ma=Ka<<8|Ga>>>24|Ka;Ka=$+h|0;Ga=(pa<<1)-1|0;if((Ga|0)>0){Na=Ga;Ga=Ka;while(1){Oa=Ga;c[Oa>>2]=La;c[Oa+4>>2]=Ma;Oa=Na-1|0;if((Oa|0)>0){Na=Oa;Ga=Ga+h|0}else{break}}Ga=qa|0;Na=qa+4|0;Pa=d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0;Qa=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0}else{Pa=Ha;Qa=xa}Ga=Ka;Na=Ga|0;Ma=Ga+4|0;Ga=wrc(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0,d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0,Qa,Pa)|0;Ma=G;Na=$;c[Na>>2]=(Ga>>>1|Ma<<31)&2139062143;c[Na+4>>2]=(Ma>>>1|0<<31)&2139062143;ua=oa;va=ta;wa=pa;break b;break};case 249:{Ba=1;Ca=1;ka=72;break};default:{w=4;ka=79;break a}}if((ka|0)==72){ka=0;if(!ba){w=1;ka=79;break a}if((c[z>>2]|0)==0|k|B^1){ua=Ba;va=Ca;wa=4;break}else{Ra=aa;Sa=$;Ta=0}while(1){Ma=Ra;Na=Sa;y=d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0;a[Na]=y;y=y>>8;a[Na+1|0]=y;y=y>>8;a[Na+2|0]=y;y=y>>8;a[Na+3|0]=y;Na=Ta+1|0;if((Na|0)<(A|0)){Ra=Ra+h|0;Sa=Sa+h|0;Ta=Na}else{ua=Ba;va=Ca;wa=4;break b}}}pa=257-(za&255)-da|0;if((pa|0)<1){w=1;ka=79;break a}if(x){ta=pa<<j;if((ta|0)>0){Ua=aa;Va=$;Wa=0}else{ua=ya;va=Aa;wa=pa;break}while(1){oa=Ua;Ka=Va;y=d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0;a[Ka]=y;y=y>>8;a[Ka+1|0]=y;y=y>>8;a[Ka+2|0]=y;y=y>>8;a[Ka+3|0]=y;Ka=Wa+1|0;if((Ka|0)<(ta|0)){Ua=Ua+h|0;Va=Va+h|0;Wa=Ka}else{ua=ya;va=Aa;wa=pa;break b}}}if(!C){ua=ya;va=Aa;wa=pa;break}if((c[z>>2]|0)!=0){ua=ya;va=Aa;wa=pa;break}ta=aa;Ka=ta|0;oa=d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0;Ka=ta+4|0;xa=d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0;if(!ga){Ka=pa<<1;if((Ka|0)>0){Xa=Ka;Ya=$}else{ua=ya;va=Aa;wa=pa;break}while(1){Ka=Ya;c[Ka>>2]=oa;c[Ka+4>>2]=xa;Ka=Xa-1|0;if((Ka|0)>0){Xa=Ka;Ya=Ya+h|0}else{ua=ya;va=Aa;wa=pa;break b}}}Ka=oa&16711935;Ha=xa&16711935;qa=Ka<<8|0>>>24|Ka;Na=Ha<<8|Ka>>>24|Ha;Ha=$+h|0;Ka=(pa<<1)-1|0;if((Ka|0)>0){Ma=Ka;Ka=Ha;while(1){Ga=Ka;c[Ga>>2]=qa;c[Ga+4>>2]=Na;Ga=Ma-1|0;if((Ga|0)>0){Ma=Ga;Ka=Ka+h|0}else{break}}Ka=ta|0;Ma=ta+4|0;Za=d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0;_a=d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0}else{Za=xa;_a=oa}Ka=Ha;Ma=Ka|0;Na=Ka+4|0;Ka=wrc(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0,d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0,_a,Za)|0;Na=G;Ma=$;c[Ma>>2]=(Ka>>>1|Na<<31)&2139062143;c[Ma+4>>2]=(Na>>>1|0<<31)&2139062143;ua=ya;va=Aa;wa=pa}}while(0);ga=wa+da|0;ba=ca(wa<<j,h)|0;if((ga|0)<4){da=ga;Z=va;$=$+ba|0;aa=aa+ba|0;_=ua}else{ea=ua;fa=va;break}}}$a=V+D|0;ab=U+D|0;_=E+T|0;bb=b[p>>1]|0;if((_|0)<(bb<<16>>16|0)){R=fa;S=ea;T=_;U=ab;V=$a}else{break}}cb=fa;db=ea;eb=ab;fb=$a;gb=bb;hb=b[u>>1]|0}else{cb=L;db=M;eb=P;fb=g;gb=f;hb=q}V=r+N|0;if((V|0)<(hb<<16>>16|0)){L=cb;M=db;N=V;O=0;P=eb+s|0;g=fb+s|0;f=gb;q=hb}else{w=0;ka=79;break}}if((ka|0)==79){return w|0}return 0}function NLa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;do{if(!((e-16|0)>>>0>624>>>0)){if((f-16|0)>>>0>464>>>0){break}if((e&3|0)!=0){break}if((f&3|0)!=0){break}h=a+256|0;b[h>>1]=e;j=a+258|0;b[j>>1]=f;k=(e>>2)+3&-4;l=(f>>2)+3&-4;m=e+15&-16;n=k+15&-16;o=ca(m,f+1|0)|0;p=ca(n,l|1)|0;q=0;while(1){r=(q|0)!=0;s=a+300+(q*28|0)+24|0;c[s>>2]=r?n:m;c[a+300+(q*28|0)+16>>2]=r?k:e;t=a+300+(q*28|0)+20|0;c[t>>2]=r?l:f;u=r?p:o;r=a+300+(q*28|0)|0;c[r>>2]=hJb(u)|0;v=hJb(u)|0;u=a+300+(q*28|0)+4|0;c[u>>2]=v;w=c[r>>2]|0;if((w|0)==0|(v|0)==0){break}mrc(w|0,64,c[s>>2]|0)|0;mrc(c[u>>2]|0,64,c[s>>2]|0)|0;w=c[s>>2]|0;v=(c[r>>2]|0)+w|0;c[a+300+(q*28|0)+8>>2]=v;r=a+300+(q*28|0)+12|0;c[r>>2]=(c[u>>2]|0)+w;mrc(v|0,0,ca(c[t>>2]|0,w)|0)|0;mrc(c[r>>2]|0,0,ca(c[t>>2]|0,c[s>>2]|0)|0)|0;s=q+1|0;if((s|0)<3){q=s}else{x=0;y=10;break}}if((y|0)==10){i=g;return x|0}b[j>>1]=0;b[h>>1]=0;mJb(a+300|0);mJb(a+304|0);c[a+312>>2]=0;c[a+308>>2]=0;mJb(a+328|0);mJb(a+332|0);c[a+340>>2]=0;c[a+336>>2]=0;mJb(a+356|0);mJb(a+360|0);c[a+368>>2]=0;c[a+364>>2]=0;x=-12;i=g;return x|0}}while(0);KIb(d,16,2459600,(d=i,i=i+16|0,c[d>>2]=e,c[d+8>>2]=f,d)|0);i=d;x=-1094995529;i=g;return x|0}function OLa(a){a=a|0;var d=0;d=c[a+60>>2]|0;PMa();nrc(d+20|0,1362376,4626)|0;b[d+4692>>1]=0;b[d+4694>>1]=0;c[a+140>>2]=6;c[d+4872>>2]=196;c[d+4876>>2]=24;c[d+4880>>2]=194;c[d+4884>>2]=512;c[d+4888>>2]=728;return 0}function PLa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;h=i;i=i+16|0;j=h|0;k=f|0;l=f+8|0;m=c[l>>2]|0;n=f+16|0;o=c[n>>2]|0;p=f|0;q=c[p>>2]|0;r=q+(m>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&262143;r=m+18|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;if((s|0)!=262136){KIb(g,16,2442904,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}s=f+4652|0;c[f+4656>>2]=c[s>>2];r=q+(m>>>3)|0;v=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&7;r=m+3|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;c[s>>2]=v;if((v|0)==7){KIb(g,16,2430632,(t=i,i=i+8|0,c[t>>2]=7,t)|0);i=t;u=-1094995529;i=h;return u|0}s=(d[q+(m>>>3)|0]|0)>>>((m&7)>>>0);r=((m|0)<(o|0))+m|0;c[l>>2]=r;c[f+4668>>2]=s&1;s=d[q+(r>>>3)|0]|0;m=((r|0)<(o|0))+r|0;c[l>>2]=m;if((s&1<<(r&7)|0)!=0){KIb(g,16,2420392,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}r=d[q+(m>>>3)|0]|0;s=((m|0)<(o|0))+m|0;c[l>>2]=s;if((r&1<<(m&7)|0)==0){w=0;x=s}else{m=q+(s>>>3)|0;r=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((s&7)>>>0)&16777215;m=s+24|0;s=o>>>0>m>>>0?m:o;c[l>>2]=s;w=r;x=s}c[f+4660>>2]=w;if(v>>>0>4>>>0){u=0;i=h;return u|0}v=d[q+(x>>>3)|0]|0;w=((x|0)<(o|0))+x|0;c[l>>2]=w;if((v&1<<(x&7)|0)==0){y=w}else{x=-w|0;v=o-w|0;if((x|0)>32){z=x}else{z=(v|0)<32?v:32}v=z+w|0;c[l>>2]=v;y=v}v=q+(y>>>3)|0;w=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((y&7)>>>0)&7;v=y+3|0;y=o>>>0>v>>>0?v:o;c[l>>2]=y;if((w|0)==7){v=q+(y>>>3)|0;z=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((y&7)>>>0);v=y+16|0;x=o>>>0>v>>>0?v:o;c[l>>2]=x;v=z&65535;b[j+2>>1]=v;z=q+(x>>>3)|0;s=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((x&7)>>>0);z=x+16|0;x=o>>>0>z>>>0?z:o;c[l>>2]=x;z=s&65535;b[j>>1]=z;A=x;B=v;C=z}else{z=w<<1;w=b[1057648+((z|1)<<1)>>1]|0;b[j+2>>1]=w;v=b[1057648+(z<<1)>>1]|0;b[j>>1]=v;A=y;B=w;C=v}v=d[q+(A>>>3)|0]|0;w=((A|0)<(o|0))+A|0;c[l>>2]=w;if((v&1<<(A&7)|0)==0){b[j+10>>1]=B;b[j+8>>1]=C;D=w;E=C;F=B}else{A=q+(w>>>3)|0;v=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((w&7)>>>0)&15;A=w+4|0;w=o>>>0>A>>>0?A:o;c[l>>2]=w;if((v|0)==15){G=B}else{G=(v<<5)+32&65535}b[j+10>>1]=G;v=q+(w>>>3)|0;A=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((w&7)>>>0)&15;v=w+4|0;w=o>>>0>v>>>0?v:o;c[l>>2]=w;if((A|0)==15){H=C}else{H=(A<<5)+32&65535}b[j+8>>1]=H;D=w;E=H;F=G}G=q+(D>>>3)|0;H=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;G=D+2|0;w=o>>>0>G>>>0?G:o;c[l>>2]=w;if((H&3<<(D&7)|0)!=0){KIb(g,16,2411064,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}D=((B&65535)+3|0)>>>2&65535;b[j+6>>1]=D;H=((C&65535)+3|0)>>>2&65535;b[j+4>>1]=H;G=q+(w>>>3)|0;A=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((w&7)>>>0)&3;G=w+2|0;w=o>>>0>G>>>0?G:o;c[l>>2]=w;a:do{if((A|0)==3){I=1;J=w;K=30}else if((A|0)==2){G=0;v=w;while(1){if((G|0)>=4){I=4;J=v;K=30;break a}y=q+(v>>>3)|0;z=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((v&7)>>>0)&3;y=v+2|0;x=o>>>0>y>>>0?y:o;c[l>>2]=x;if((z|0)==3){G=G+1|0;v=x}else{K=29;break}}}else{K=29}}while(0);do{if((K|0)==29){a[j+12|0]=0;a[j+13|0]=0;c[f+4664>>2]=1;L=0;M=0}else if((K|0)==30){w=j+12|0;a[w]=I;A=j+13|0;a[A]=0;v=q+(J>>>3)|0;G=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((J&7)>>>0)&3;v=J+2|0;x=o>>>0>v>>>0?v:o;c[l>>2]=x;b:do{if((G|0)==3){N=1;O=x}else if((G|0)==2){v=0;z=x;while(1){if((v|0)>=4){N=4;O=z;break b}y=q+(z>>>3)|0;s=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((z&7)>>>0)&3;y=z+2|0;r=o>>>0>y>>>0?y:o;c[l>>2]=r;if((s|0)==3){v=v+1|0;z=r}else{N=0;O=r;break}}}else{N=0;O=x}}while(0);a[A]=N;if(I<<24>>24==1){x=N<<24>>24!=1;G=f+4664|0;c[G>>2]=x&1;if(x){L=N;M=1;break}else{P=G;Q=1}}else{G=f+4664|0;c[G>>2]=1;if(!(I<<24>>24==4)){L=N;M=I;break}if(N<<24>>24==1){P=G;Q=4}else{L=N;M=4;break}}G=f+4692|0;do{if(C<<16>>16==(b[G>>1]|0)){if(!(B<<16>>16==(b[f+4694>>1]|0))){K=47;break}if(!(H<<16>>16==(b[f+4696>>1]|0))){K=47;break}if(!(D<<16>>16==(b[f+4698>>1]|0))){K=47;break}if(!(E<<16>>16==(b[f+4700>>1]|0))){K=47;break}if(!(F<<16>>16==(b[f+4702>>1]|0))){K=47;break}if(!(Q<<24>>24==(a[f+4704|0]|0))){K=47;break}if((a[f+4705|0]|0)==1){R=O;S=q;T=o}else{K=47}}else{K=47}}while(0);do{if((K|0)==47){x=f+4708|0;if((SMa(x,j)|0)!=0){KIb(g,16,2396400,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;a[f+4704|0]=0;u=-12;i=h;return u|0}z=G;v=j;b[z>>1]=b[v>>1]|0;b[z+2>>1]=b[v+2>>1]|0;b[z+4>>1]=b[v+4>>1]|0;b[z+6>>1]=b[v+6>>1]|0;b[z+8>>1]=b[v+8>>1]|0;b[z+10>>1]=b[v+10>>1]|0;b[z+12>>1]=b[v+12>>1]|0;if((a[w]|0)!=0){v=c[f+4716>>2]|0;z=0;do{c[v+(z*332|0)+56>>2]=(c[P>>2]|0)==0?16:8;c[v+(z*332|0)+60>>2]=8;z=z+1|0;}while((z|0)<(d[w]|0))}do{if((a[A]|0)!=0){z=c[f+4728>>2]|0;v=0;do{c[z+(v*332|0)+56>>2]=4;c[z+(v*332|0)+60>>2]=4;v=v+1|0;U=a[A]|0;}while((v|0)<(U&255|0));if(U<<24>>24==0){break}v=c[f+4740>>2]|0;z=0;do{c[v+(z*332|0)+56>>2]=4;c[v+(z*332|0)+60>>2]=4;z=z+1|0;}while((z|0)<(d[A]|0))}}while(0);if((UMa(x,e[f+4700>>1]|0,e[f+4702>>1]|0)|0)==0){R=c[l>>2]|0;S=c[p>>2]|0;T=c[n>>2]|0;break}KIb(g,16,2389504,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-12;i=h;return u|0}}while(0);A=d[S+(R>>>3)|0]|0;w=((R|0)<(T|0))+R|0;c[l>>2]=w;if((A&1<<(R&7)|0)==0){V=0;W=w}else{A=S+(w>>>3)|0;G=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((w&7)>>>0)&1048575;A=w+20|0;w=T>>>0>A>>>0?A:T;c[l>>2]=w;V=G;W=w}c[f+4648>>2]=V;w=((W|0)<(T|0))+W|0;if((d[S+(W>>>3)|0]&1<<(W&7)|0)==0){X=w}else{G=w+8|0;X=T>>>0>G>>>0?G:T}c[l>>2]=X;G=(d[S+(X>>>3)|0]|0)>>>((X&7)>>>0);c[l>>2]=((X|0)<(T|0))+X;if((RMa(k,G&1,0,f+4760|0,g)|0)!=0){u=-1094995529;i=h;return u|0}G=c[l>>2]|0;w=(d[(c[p>>2]|0)+(G>>>3)|0]|0)>>>((G&7)>>>0);c[l>>2]=((G|0)<(c[n>>2]|0))+G;if((RMa(k,w&1,1,f+4808|0,g)|0)!=0){u=-1094995529;i=h;return u|0}w=c[l>>2]|0;G=c[p>>2]|0;A=d[G+(w>>>3)|0]|0;z=c[n>>2]|0;v=((w|0)<(z|0))+w|0;c[l>>2]=v;if((A&1<<(w&7)|0)==0){Y=8;Z=v}else{w=G+(v>>>3)|0;A=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((v&7)>>>0);w=v+3|0;v=z>>>0>w>>>0?w:z;c[l>>2]=v;Y=A&7;Z=v}a[f+4856|0]=Y;v=(d[G+(Z>>>3)|0]|0)>>>((Z&7)>>>0);A=((Z|0)<(z|0))+Z|0;c[l>>2]=A;a[f+4857|0]=v&1;v=(d[G+(A>>>3)|0]|0)>>>((A&7)>>>0);w=((A|0)<(z|0))+A|0;c[l>>2]=w;a[f+4858|0]=v&1;v=G+(w>>>3)|0;A=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((w&7)>>>0);v=w+5|0;w=z>>>0>v>>>0?v:z;c[l>>2]=w;a[f+4859|0]=A&31;A=d[G+(w>>>3)|0]|0;v=((w|0)<(z|0))+w|0;c[l>>2]=v;if((A&1<<(w&7)|0)==0){_=0;$=v}else{w=G+(v>>>3)|0;A=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((v&7)>>>0);w=v+3|0;v=z>>>0>w>>>0?w:z;c[l>>2]=v;_=A&7;$=v}a[f+4860|0]=_;v=d[G+($>>>3)|0]|0;A=(($|0)<(z|0))+$|0;c[l>>2]=A;if((v&1<<($&7)|0)==0){aa=0;ba=A}else{v=G+(A>>>3)|0;w=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((A&7)>>>0);v=A+16|0;A=z>>>0>v>>>0?v:z;c[l>>2]=A;aa=w&65535;ba=A}b[f+4690>>1]=aa;A=d[G+(ba>>>3)|0]|0;w=((ba|0)<(z|0))+ba|0;c[l>>2]=w;if((A&1<<(ba&7)|0)==0){ca=w}else{A=w;while(1){w=A+8|0;v=z>>>0>w>>>0?w:z;c[l>>2]=v;w=d[G+(v>>>3)|0]|0;r=((v|0)<(z|0))+v|0;c[l>>2]=r;if((w&1<<(v&7)|0)==0){ca=r;break}else{A=r}}}A=d[G+(ca>>>3)|0]|0;r=((ca|0)<(z|0))+ca|0;c[l>>2]=r;if((A&1<<(ca&7)|0)==0){da=r}else{KIb(g,16,2382584,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;da=c[l>>2]|0}r=-da&7;if((r|0)==0){u=0;i=h;return u|0}A=c[n>>2]|0;v=r+da|0;c[l>>2]=A>>>0>v>>>0?v:A;u=0;i=h;return u|0}}while(0);KIb(g,16,2403320,(t=i,i=i+16|0,c[t>>2]=M&255,c[t+8>>2]=L&255,t)|0);i=t;u=-1094995529;i=h;return u|0}function QLa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;h=b|0;j=b+8|0;k=c[j>>2]|0;l=b+16|0;m=c[l>>2]|0;n=b|0;o=c[n>>2]|0;p=o+(k>>>3)|0;q=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((k&7)>>>0)&3;p=k+2|0;k=m>>>0>p>>>0?p:m;c[j>>2]=k;p=o+(k>>>3)|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;s=m>>>0>p>>>0?p:m;c[j>>2]=s;do{if((c[e>>2]|0)==(q|0)){if((c[e+4>>2]|0)!=(r>>>((k&7)>>>0)&15|0)){break}p=(d[o+(s>>>3)|0]|0)>>>((s&7)>>>0);c[j>>2]=((s|0)<(m|0))+s;t=p&1;c[e+52>>2]=t;p=e+60|0;a:do{if((t|0)==0){u=c[p>>2]|0;v=c[j>>2]|0;w=c[l>>2]|0;x=((v|0)<(w|0))+v|0;if(((d[o+(v>>>3)|0]|0)&1<<(v&7)|0)==0){y=x}else{v=x+16|0;y=w>>>0>v>>>0?v:w}c[j>>2]=y;v=o+(y>>>3)|0;x=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((y&7)>>>0)&3;v=y+2|0;c[j>>2]=w>>>0>v>>>0?v:w;c[e+64>>2]=x;if(x>>>0>1>>>0){KIb(f,16,2172992,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z;A=-1094995529;i=g;return A|0}x=c[j>>2]|0;w=(d[o+(x>>>3)|0]|0)>>>((x&7)>>>0);c[j>>2]=((x|0)<(c[l>>2]|0))+x;x=w&1;c[e+308>>2]=x;if((x|0)!=0){x=c[j>>2]|0;w=c[l>>2]|0;v=o+(x>>>3)|0;B=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((x&7)>>>0)&65535;v=x+16|0;c[j>>2]=w>>>0>v>>>0?v:w;c[e+304>>2]=B}B=c[j>>2]|0;w=c[l>>2]|0;v=o+(B>>>3)|0;x=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((B&7)>>>0)&3;v=B+2|0;c[j>>2]=w>>>0>v>>>0?v:w;if((x|0)==3){KIb(f,16,2145576,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}c[e+56>>2]=16>>>(x>>>0);c[p>>2]=8>>>(x>>>1>>>0);x=c[j>>2]|0;w=(d[o+(x>>>3)|0]|0)>>>((x&7)>>>0);c[j>>2]=((x|0)<(c[l>>2]|0))+x;c[e+68>>2]=w&1;w=c[j>>2]|0;x=(d[o+(w>>>3)|0]|0)>>>((w&7)>>>0);c[j>>2]=((w|0)<(c[l>>2]|0))+w;c[e+72>>2]=x&1;x=c[j>>2]|0;w=c[l>>2]|0;v=o+(x>>>3)|0;B=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((x&7)>>>0)&31;v=x+5|0;c[j>>2]=w>>>0>v>>>0?v:w;c[e+84>>2]=B;B=c[j>>2]|0;w=d[o+(B>>>3)|0]|0;v=c[l>>2]|0;x=((B|0)<(v|0))+B|0;c[j>>2]=x;do{if((w&1<<(B&7)|0)==0){C=16}else{if((c[b+4652>>2]|0)==0){C=16;break}if((u|0)==(c[p>>2]|0)){D=o;E=c[e+80>>2]|0;break}KIb(f,16,2502472,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}}while(0);b:do{if((C|0)==16){u=o+(x>>>3)|0;B=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((x&7)>>>0)&31;u=x+5|0;c[j>>2]=v>>>0>u>>>0?u:v;do{if(!(B>>>0>17>>>0)){if((136064>>>(B>>>0)&1|0)!=0){break}if((B-7|0)>>>0<3>>>0|(B|0)==17){QIb(f,2639344,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1163346256;i=g;return A|0}u=B>>>0<10>>>0;w=c[p>>2]|0;if(u&(w|0)<8){KIb(f,16,2616640,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}c[e+288>>2]=c[305672+(B*12|0)>>2];c[e+296>>2]=c[305676+(B*12|0)>>2];c[e+300>>2]=c[305680+(B*12|0)>>2];F=u?8:4;c[e+292>>2]=F;if((w|0)!=(F|0)){KIb(f,16,2589432,(z=i,i=i+16|0,c[z>>2]=F,c[z+8>>2]=w,z)|0);i=z;A=-1094995529;i=g;return A|0}w=c[j>>2]|0;F=c[l>>2]|0;u=(c[n>>2]|0)+(w>>>3)|0;G=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((w&7)>>>0)&15;u=w+4|0;c[j>>2]=F>>>0>u>>>0?u:F;if((G|0)==15){KIb(f,16,2567824,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}F=c[p>>2]|0;do{if((G-5|0)>>>0<5>>>0){if((F|0)==4){break}KIb(f,16,2549712,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}else{if((F|0)==8){break}KIb(f,16,2549712,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}}while(0);c[e+88>>2]=c[601984+(G<<2)>>2];c[e+92>>2]=F;u=c[j>>2]|0;w=c[l>>2]|0;H=c[n>>2]|0;I=H+(u>>>3)|0;J=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((u&7)>>>0)&31;I=u+5|0;c[j>>2]=w>>>0>I>>>0?I:w;if((J|0)==31){KIb(f,16,2531640,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}if(!(J>>>0>21>>>0)){c[e+80>>2]=J;D=H;E=J;break b}QIb(f,2516408,(z=i,i=i+8|0,c[z>>2]=J,z)|0);i=z;A=-1094995529;i=g;return A|0}}while(0);QIb(f,2121808,(z=i,i=i+8|0,c[z>>2]=B,z)|0);i=z;A=-1163346256;i=g;return A|0}}while(0);v=e+80|0;x=c[p>>2]|0;if((29184>>>(E>>>0)&1|0)!=0&(x|0)==4){KIb(f,16,2489392,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;c[v>>2]=0;A=-1094995529;i=g;return A|0}if((c[e+92>>2]|0)!=(x|0)){KIb(f,16,2549712,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}if((c[e+292>>2]|0)==8&(x|0)<8){KIb(f,16,2478392,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}x=c[j>>2]|0;J=d[D+(x>>>3)|0]|0;H=c[l>>2]|0;w=((x|0)<(H|0))+x|0;c[j>>2]=w;do{if((J&1<<(x&7)|0)==0){c[e+100>>2]=c[b+4812>>2];K=w;L=H}else{if((RMa(h,1,1,e+96|0,f)|0)==0){K=c[j>>2]|0;L=c[l>>2]|0;break}else{A=-1094995529;i=g;return A|0}}}while(0);H=c[n>>2]|0;w=d[H+(K>>>3)|0]|0;x=((K|0)<(L|0))+K|0;c[j>>2]=x;if((w&1<<(K&7)|0)==0){M=8}else{w=H+(x>>>3)|0;J=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((x&7)>>>0)&7;w=x+3|0;c[j>>2]=L>>>0>w>>>0?w:L;M=J}c[e+272>>2]=M;J=e+144|0;c[J>>2]=0;w=c[j>>2]|0;x=d[H+(w>>>3)|0]|0;I=c[l>>2]|0;u=((w|0)<(I|0))+w|0;c[j>>2]=u;if((x&1<<(w&7)|0)==0){N=v;break}w=H+(u>>>3)|0;x=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((u&7)>>>0)&255;w=u+8|0;c[j>>2]=I>>>0>w>>>0?w:I;c[J>>2]=x;if(x>>>0>61>>>0){KIb(f,16,2468824,(z=i,i=i+8|0,c[z>>2]=x,z)|0);i=z;A=-1094995529;i=g;return A|0}if((x|0)==0){N=v;break}else{O=0;P=H}while(1){H=c[j>>2]|0;x=c[l>>2]|0;I=P+(H>>>3)|0;w=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((H&7)>>>0);I=H+8|0;c[j>>2]=x>>>0>I>>>0?I:x;a[e+148+O|0]=w;w=O+1|0;if((w|0)>=(c[J>>2]<<1|0)){N=v;break a}O=w;P=c[n>>2]|0}}else{N=e+80|0}}while(0);t=d[688304+(c[N>>2]|0)|0]|0;if((c[p>>2]|0)==8){c[e+316>>2]=1055008+(t<<7);c[e+320>>2]=1056160+(t<<7)}else{c[e+316>>2]=1057312+(t<<5);c[e+320>>2]=1057472+(t<<5)}c[e+324>>2]=0;c[e+328>>2]=0;t=c[j>>2]|0;v=-t&7;if((v|0)!=0){J=c[l>>2]|0;w=v+t|0;c[j>>2]=J>>>0>w>>>0?w:J}if((c[e+88>>2]|0)!=0){A=0;i=g;return A|0}KIb(f,16,2459576,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}}while(0);KIb(f,16,2205152,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;A=-1094995529;i=g;return A|0}function RLa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0;j=i;k=f+56|0;l=c[k>>2]|0;m=f+48|0;n=c[m>>2]|0;o=ca(n,l)|0;p=g+4|0;q=c[p>>2]|0;r=g|0;s=(l|0)!=(c[f+60>>2]|0)?4:1;t=e+4652|0;u=(c[t>>2]|0)==3?2:1;v=c[(c[e+4716>>2]|0)+56>>2]>>3;w=l>>3;x=v-w|0;y=g+8|0;z=c[y>>2]|0;A=l-1|0;B=g+12|0;C=c[B>>2]|0;D=ca((A+C|0)/(l|0)|0,(A+z|0)/(l|0)|0)|0;A=c[g+28>>2]|0;if((D|0)!=(A|0)){KIb(h,16,2451880,(E=i,i=i+32|0,c[E>>2]=z,c[E+8>>2]=C,c[E+16>>2]=l,c[E+24>>2]=A,E)|0);i=E;F=-1;i=j;return F|0}a:do{if((C|0)>0){A=ca(q,n)|0;D=c[r>>2]|0;G=e+8|0;H=e|0;I=e+16|0;J=f+68|0;K=32-u|0;L=32-s|0;M=f+72|0;N=f|0;O=f+4|0;P=e+4858|0;Q=e+4764|0;R=(v|0)==(w|0);S=x-1|0;T=f+64|0;U=f+312|0;V=D+A|0;A=0;W=0;X=q;Y=c[g+32>>2]|0;Z=c[g+36>>2]|0;_=z;$=l;aa=q;ba=C;da=D;b:while(1){if((_|0)>0){D=X&65535;ea=X-1|0;fa=V;ga=A;ha=W;ia=da;ja=Y;ka=Z;while(1){b[ja>>1]=ia;b[ja+2>>1]=D;c[ja+4>>2]=fa;la=c[G>>2]|0;ma=c[H>>2]|0;na=d[ma+(la>>>3)|0]|0;oa=c[I>>2]|0;pa=((la|0)<(oa|0))+la|0;c[G>>2]=pa;do{if((na&1<<(la&7)|0)==0){do{if((c[J>>2]|0)==0){if((c[t>>2]|0)>>>0<2>>>0){a[ja+8|0]=0;break}else{qa=ma+(pa>>>3)|0;ra=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((pa&7)>>>0)<<K>>>(K>>>0);qa=pa+u|0;c[G>>2]=oa>>>0>qa>>>0?qa:oa;a[ja+8|0]=ra;break}}else{if((ka|0)==0){sa=21;break b}a[ja+8|0]=a[ka+8|0]|0}}while(0);ra=c[G>>2]|0;qa=c[I>>2]|0;ta=(c[H>>2]|0)+(ra>>>3)|0;ua=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((ra&7)>>>0)<<L>>>(L>>>0);ta=ra+s|0;c[G>>2]=qa>>>0>ta>>>0?ta:qa;qa=ua&255;a[ja+9|0]=qa;ua=ja+10|0;a[ua]=0;do{if((c[M>>2]|0)==0){if(qa<<24>>24==0){if((c[N>>2]|0)!=0){break}if((c[O>>2]|0)!=0){break}if((a[P]|0)==0){break}}ta=c[(c[Q>>2]|0)+4>>2]|0;ra=c[G>>2]|0;va=c[I>>2]|0;wa=(c[H>>2]|0)+(ra>>>3)|0;xa=(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)>>>((ra&7)>>>0)&8191;wa=b[ta+(xa<<2)>>1]|0;ya=(b[ta+(xa<<2)+2>>1]|0)+ra|0;c[G>>2]=va>>>0>ya>>>0?ya:va;a[ua]=-(wa<<24>>25^-(wa&1))}else{if((ka|0)==0){break}a[ua]=a[ka+10|0]|0}}while(0);if((a[ja+8|0]|0)==0){a[ja+12|0]=0;a[ja+11|0]=0;za=ha;Aa=ga;break}if((c[J>>2]|0)==0){ua=c[(c[Q>>2]|0)+4>>2]|0;qa=c[G>>2]|0;wa=c[I>>2]|0;va=c[H>>2]|0;ya=va+(qa>>>3)|0;ra=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((qa&7)>>>0)&8191;ya=b[ua+(ra<<2)>>1]|0;xa=(b[ua+(ra<<2)+2>>1]|0)+qa|0;qa=wa>>>0>xa>>>0?xa:wa;c[G>>2]=qa;xa=ga-(ya>>1^-(ya&1))|0;ya=va+(qa>>>3)|0;va=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((qa&7)>>>0)&8191;ya=b[ua+(va<<2)>>1]|0;ra=(b[ua+(va<<2)+2>>1]|0)+qa|0;c[G>>2]=wa>>>0>ra>>>0?ra:wa;wa=ha-(ya>>1^-(ya&1))|0;a[ja+11|0]=wa;a[ja+12|0]=xa;za=wa;Aa=xa;break}if((ka|0)==0){za=ha;Aa=ga;break}xa=a[ka+11|0]|0;if(R){a[ja+11|0]=xa;a[ja+12|0]=a[ka+12|0]|0;za=ha;Aa=ga;break}else{a[ja+11|0]=S+(xa<<24>>24)+(xa<<24>>24>0)>>x;xa=a[ka+12|0]|0;a[ja+12|0]=S+(xa<<24>>24)+(xa<<24>>24>0)>>x;za=ha;Aa=ga;break}}else{if((c[t>>2]|0)==0){sa=10;break b}a[ja+8|0]=1;a[ja+9|0]=0;xa=ja+10|0;a[xa]=0;do{if((c[N>>2]|0)==0){if((c[O>>2]|0)!=0){break}if((a[P]|0)==0){break}wa=c[(c[Q>>2]|0)+4>>2]|0;ya=c[G>>2]|0;ra=c[I>>2]|0;qa=(c[H>>2]|0)+(ya>>>3)|0;va=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((ya&7)>>>0)&8191;qa=b[wa+(va<<2)>>1]|0;ua=(b[wa+(va<<2)+2>>1]|0)+ya|0;c[G>>2]=ra>>>0>ua>>>0?ua:ra;a[xa]=-(qa<<24>>25^-(qa&1))}}while(0);xa=ja+12|0;a[xa]=0;qa=ja+11|0;a[qa]=0;if((c[J>>2]|0)==0|(ka|0)==0){za=ha;Aa=ga;break}ra=a[ka+11|0]|0;if(R){a[qa]=ra;a[xa]=a[ka+12|0]|0;za=ha;Aa=ga;break}else{a[qa]=S+(ra<<24>>24)+(ra<<24>>24>0)>>x;ra=a[ka+12|0]|0;a[xa]=S+(ra<<24>>24)+(ra<<24>>24>0)>>x;za=ha;Aa=ga;break}}}while(0);Ba=c[T>>2]|0;if((a[ja+8|0]|0)==0){Ca=c[k>>2]|0}else{Da=a[ja+11|0]|0;Ea=a[ja+12|0]|0;oa=c[m>>2]|0;if(((Da>>Ba)+ia+(ca((Ea>>Ba)+X|0,oa)|0)|0)<0){sa=46;break b}pa=c[k>>2]|0;ma=ia-1+(Da+Ba>>Ba)+pa+(ca(ea+(Ea+Ba>>Ba)+pa|0,oa)|0)|0;if((ma|0)>((c[U>>2]|0)-1|0)){sa=46;break b}else{Ca=pa}}Fa=ja+16|0;Ga=(ka|0)==0?0:ka+16|0;pa=Ca+ia|0;Ha=c[r>>2]|0;Ia=c[y>>2]|0;if((pa|0)<(Ia+Ha|0)){fa=Ca+fa|0;ga=Aa;ha=za;ia=pa;ja=Fa;ka=Ga}else{break}}Ja=Aa;Ka=za;La=Fa;Ma=Ga;Na=Ia;Oa=Ca;Pa=c[p>>2]|0;Qa=c[B>>2]|0;Ra=Ha}else{Ja=A;Ka=W;La=Y;Ma=Z;Na=_;Oa=$;Pa=aa;Qa=ba;Ra=da}ka=Oa+X|0;if((ka|0)<(Qa+Pa|0)){V=V+o|0;A=Ja;W=Ka;X=ka;Y=La;Z=Ma;_=Na;$=Oa;aa=Pa;ba=Qa;da=Ra}else{Sa=G;break a}}if((sa|0)==10){KIb(h,16,2362584,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;i=j;return F|0}else if((sa|0)==21){KIb(h,16,2297744,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;F=-1094995529;i=j;return F|0}else if((sa|0)==46){G=Da+(ca(Ba,ia)|0)|0;da=Ea+(ca(Ba,X)|0)|0;KIb(h,16,2247016,(E=i,i=i+16|0,c[E>>2]=G,c[E+8>>2]=da,E)|0);i=E;F=-1094995529;i=j;return F|0}}else{Sa=e+8|0}}while(0);E=c[Sa>>2]|0;h=-E&7;if((h|0)==0){F=0;i=j;return F|0}Ba=c[e+16>>2]|0;e=h+E|0;c[Sa>>2]=Ba>>>0>e>>>0?e:Ba;F=0;i=j;return F|0}function SLa(a){a=a|0;var b=0,d=0,e=0,f=0;if((c[a+4656>>2]|0)>>>0<3>>>0){b=a+4744|0;d=c[b>>2]|0;e=d^1;c[b>>2]=e;c[a+4748>>2]=e;c[a+4752>>2]=d}d=c[a+4652>>2]|0;if((d|0)==0|(d|0)==1){c[a+4744>>2]=0;f=0}else if((d|0)==2){f=c[a+4744>>2]|0}else{return}c[a+4748>>2]=f;c[a+4752>>2]=f^1;return}function TLa(a){a=a|0;return(c[a+4652>>2]|0)<5|0}function ULa(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=c[d+60>>2]|0;PMa();nrc(f+20|0,1362376,4626)|0;g=c[d+120>>2]|0;h=g&65535;j=f+4692|0;b[j>>1]=h;k=c[d+124>>2]|0;l=k&65535;b[f+4694>>1]=l;b[f+4696>>1]=(g+3|0)>>>2;b[f+4698>>1]=(k+3|0)>>>2;b[f+4700>>1]=h;b[f+4702>>1]=l;a[f+4705|0]=1;a[f+4704|0]=1;if((SMa(f+4708|0,j)|0)==0){c[f+4744>>2]=0;c[f+4676>>2]=0;c[f+4872>>2]=162;c[f+4876>>2]=140;c[f+4880>>2]=702;c[f+4884>>2]=38;c[f+4888>>2]=332;c[d+140>>2]=6;m=0;i=e;return m|0}else{KIb(d,16,2451824,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;m=-1094995529;i=e;return m|0}return 0}function VLa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;h=i;i=i+16|0;j=h|0;k=f|0;l=f+8|0;m=c[l>>2]|0;n=f+16|0;o=c[n>>2]|0;p=f|0;q=c[p>>2]|0;r=q+(m>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&31;r=m+5|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;if((s|0)!=31){KIb(g,16,2172960,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}s=f+4652|0;c[f+4656>>2]=c[s>>2];r=q+(m>>>3)|0;v=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&7;r=m+3|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;c[s>>2]=v;if(v>>>0>4>>>0){KIb(g,16,2145544,(t=i,i=i+8|0,c[t>>2]=v,t)|0);i=t;u=-1094995529;i=h;return u|0}r=q+(m>>>3)|0;w=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0)&255;r=m+8|0;m=o>>>0>r>>>0?r:o;c[l>>2]=m;c[f+4648>>2]=w;a:do{if((v|0)==0){w=j;r=q+(m>>>3)|0;x=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((m&7)>>>0);r=m+8|0;y=o>>>0>r>>>0?r:o;c[l>>2]=y;r=x&255;z=f+4864|0;a[z]=r;if((x&1|0)==0){A=0;B=y}else{x=q+(y>>>3)|0;C=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((y&7)>>>0);x=y+16|0;y=o>>>0>x>>>0?x:o;c[l>>2]=y;A=C&65535;B=y}b[f+4862>>1]=A;if((r&32)==0){D=B}else{y=q+(B>>>3)|0;C=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((B&7)>>>0)&65535;y=B+16|0;x=o>>>0>y>>>0?y:o;c[l>>2]=x;y=q+(x>>>3)|0;E=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((x&7)>>>0);y=x+16|0;x=o>>>0>y>>>0?y:o;c[l>>2]=x;c[f+4868>>2]=E<<16|C;D=x}do{if((r&64)==0){F=0;G=D;H=13}else{x=q+(D>>>3)|0;C=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((D&7)>>>0)&3;x=D+2|0;E=o>>>0>x>>>0?x:o;c[l>>2]=E;x=64<<C;if((x|0)<=256){F=x;G=E;H=13;break}KIb(g,16,2616616,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;I=-1094995529}}while(0);b:do{if((H|0)==13){x=q+(G>>>3)|0;E=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((G&7)>>>0)&3;x=G+2|0;C=o>>>0>x>>>0?x:o;c[l>>2]=C;x=(E*3|0)+1|0;E=x&255;y=j+12|0;a[y]=E;J=(d[q+(C>>>3)|0]|0)>>>((C&7)>>>0);K=((C|0)<(o|0))+C|0;c[l>>2]=K;C=(-(J&1)&3)+1|0;J=C&255;L=j+13|0;a[L]=J;if((E<<24>>24|0)==1){M=(C&255|0)!=1;if(M){H=16}else{N=M&1}}else if((E<<24>>24|0)==4){if(J<<24>>24==1){N=1}else{H=16}}else{H=16}if((H|0)==16){KIb(g,16,2589336,(t=i,i=i+16|0,c[t>>2]=x&255,c[t+8>>2]=C&255,t)|0);i=t;I=-1094995529;break}C=q+(K>>>3)|0;x=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((K&7)>>>0)&15;C=K+4|0;K=o>>>0>C>>>0?C:o;c[l>>2]=K;if((x|0)==15){C=q+(K>>>3)|0;M=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((K&7)>>>0);C=K+13|0;K=o>>>0>C>>>0?C:o;c[l>>2]=K;C=M&8191;b[j+2>>1]=C;M=q+(K>>>3)|0;O=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((K&7)>>>0);M=K+13|0;c[l>>2]=o>>>0>M>>>0?M:o;M=O&8191;b[j>>1]=M;P=C;Q=M}else{M=x<<1;x=d[1053616+(M|1)|0]<<2;b[j+2>>1]=x;C=d[1053616+M|0]<<2;b[j>>1]=C;P=x;Q=C}if(!((r&2)==0)){RIb(g,2567800,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1163346256;break}C=((P&65535)+3|0)>>>2&65535;b[j+6>>1]=C;x=((Q&65535)+3|0)>>>2&65535;b[j+4>>1]=x;if((F|0)==0){b[j+10>>1]=P;b[j+8>>1]=Q;R=Q;S=P}else{M=F&65535;b[j+8>>1]=M;b[j+10>>1]=M;R=M;S=M}M=f+4692|0;do{if(Q<<16>>16==(b[M>>1]|0)){if(!(P<<16>>16==(b[f+4694>>1]|0))){H=34;break}if(!(x<<16>>16==(b[f+4696>>1]|0))){H=34;break}if(!(C<<16>>16==(b[f+4698>>1]|0))){H=34;break}if(!(R<<16>>16==(b[f+4700>>1]|0))){H=34;break}if(!(S<<16>>16==(b[f+4702>>1]|0))){H=34;break}if(!(E<<24>>24==(a[f+4704|0]|0))){H=34;break}if(!(J<<24>>24==(a[f+4705|0]|0))){H=34;break}if((c[f+4892>>2]|0)==0){T=0;U=0}else{H=34}}else{H=34}}while(0);do{if((H|0)==34){J=SMa(f+4708|0,j)|0;if((J|0)<0){KIb(g,16,2549672,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=J;break b}else{J=M;b[J>>1]=b[w>>1]|0;b[J+2>>1]=b[w+2>>1]|0;b[J+4>>1]=b[w+4>>1]|0;b[J+6>>1]=b[w+6>>1]|0;b[J+8>>1]=b[w+8>>1]|0;b[J+10>>1]=b[w+10>>1]|0;b[J+12>>1]=b[w+12>>1]|0;c[f+4664>>2]=N;T=0;U=1;break}}}while(0);c:while(1){M=(T|0)!=0;J=f+4708+(T*12|0)+8|0;E=(T|0)==0;C=T<<2;x=0;V=U;while(1){W=a[L]|0;if((x|0)>=((M?W:a[y]|0)&255|0)){break}O=c[J>>2]|0;K=c[l>>2]|0;X=c[p>>2]|0;Y=(d[X+(K>>>3)|0]|0)>>>((K&7)>>>0);c[l>>2]=((K|0)<(c[n>>2]|0))+K;c[O+(x*332|0)+64>>2]=Y&1;Y=c[l>>2]|0;K=d[X+(Y>>>3)|0]|0;Z=c[n>>2]|0;_=((Y|0)<(Z|0))+Y|0;c[l>>2]=_;$=(d[X+(_>>>3)|0]|0)>>>((_&7)>>>0);aa=((_|0)<(Z|0))+_|0;c[l>>2]=aa;_=8>>>(($&1)>>>0);$=_<<((K&1<<(Y&7)|0)==0);if(E&(_|0)==4){H=42;break c}Y=O+(x*332|0)+56|0;K=O+(x*332|0)+60|0;if(($|0)==(c[Y>>2]|0)){ba=(_|0)!=(c[K>>2]|0);ca=ba&1;if(ba){da=ca;H=45}else{ea=ca;fa=aa;ga=Z}}else{da=1;H=45}if((H|0)==45){H=0;c[Y>>2]=$;c[K>>2]=_;ea=da;fa=c[l>>2]|0;ga=c[n>>2]|0}_=d[X+(fa>>>3)|0]|0;c[l>>2]=((fa|0)<(ga|0))+fa;if((_&1<<(fa&7)|0)!=0){H=47;break c}switch(x+C|0){case 2:{c[O+(x*332|0)+288>>2]=948;c[O+(x*332|0)+296>>2]=552;c[O+(x*332|0)+88>>2]=1367016;c[O+(x*332|0)+292>>2]=8;ha=948;H=55;break};case 4:{c[O+(x*332|0)+288>>2]=864;c[O+(x*332|0)+296>>2]=6;c[O+(x*332|0)+88>>2]=1367080;c[O+(x*332|0)+292>>2]=4;ha=864;H=55;break};case 1:{c[O+(x*332|0)+288>>2]=516;c[O+(x*332|0)+296>>2]=258;c[O+(x*332|0)+88>>2]=1362312;c[O+(x*332|0)+292>>2]=8;ha=516;H=55;break};case 0:{c[O+(x*332|0)+288>>2]=186;c[O+(x*332|0)+296>>2]=6;c[O+(x*332|0)+88>>2]=1242080;c[O+(x*332|0)+292>>2]=8;ia=1;break};case 3:{c[O+(x*332|0)+288>>2]=164;c[O+(x*332|0)+296>>2]=862;c[O+(x*332|0)+88>>2]=1367016;c[O+(x*332|0)+292>>2]=8;ha=164;H=55;break};default:{_=c[O+(x*332|0)+288>>2]|0;if((_|0)==186){ia=1}else{ha=_;H=55}}}if((H|0)==55){H=0;ia=(ha|0)==864|0}c[O+(x*332|0)+300>>2]=ia;ja=c[O+(x*332|0)+292>>2]|0;ka=c[K>>2]|0;if((ja|0)!=(ka|0)){H=57;break c}if(M){la=5}else{la=(d[y]|0)>>>0>1>>>0?x+1|0:0}if((ja|0)==8){if((la|0)>4){H=62;break c}c[O+(x*332|0)+316>>2]=1053648+(la<<7);c[O+(x*332|0)+320>>2]=1054288+(la<<7);c[O+(x*332|0)+324>>2]=1053328+(la*24|0);c[O+(x*332|0)+328>>2]=1053448+(la*24|0)}else{c[O+(x*332|0)+316>>2]=1054928;c[O+(x*332|0)+320>>2]=1054960;c[O+(x*332|0)+324>>2]=1053568;c[O+(x*332|0)+328>>2]=1053592}O=c[l>>2]|0;K=c[n>>2]|0;_=(c[p>>2]|0)+(O>>>3)|0;X=d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0;_=O+2|0;c[l>>2]=K>>>0>_>>>0?_:K;if((X&3<<(O&7)|0)!=0){H=67;break c}x=x+1|0;V=ea}x=T+1|0;if((x|0)<2){T=x;U=V}else{H=38;break}}if((H|0)==38){if(!(W<<24>>24==0)){y=f+4728|0;x=f+4740|0;M=0;do{C=c[y>>2]|0;E=c[x>>2]|0;c[E+(M*332|0)+8>>2]=c[C+(M*332|0)+8>>2];c[E+(M*332|0)+12>>2]=c[C+(M*332|0)+12>>2];c[E+(M*332|0)+56>>2]=c[C+(M*332|0)+56>>2];c[E+(M*332|0)+60>>2]=c[C+(M*332|0)+60>>2];c[E+(M*332|0)+64>>2]=c[C+(M*332|0)+64>>2];c[E+(M*332|0)+316>>2]=c[C+(M*332|0)+316>>2];c[E+(M*332|0)+320>>2]=c[C+(M*332|0)+320>>2];c[E+(M*332|0)+324>>2]=c[C+(M*332|0)+324>>2];c[E+(M*332|0)+328>>2]=c[C+(M*332|0)+328>>2];c[E+(M*332|0)+88>>2]=c[C+(M*332|0)+88>>2];c[E+(M*332|0)+288>>2]=c[C+(M*332|0)+288>>2];c[E+(M*332|0)+296>>2]=c[C+(M*332|0)+296>>2];c[E+(M*332|0)+300>>2]=c[C+(M*332|0)+300>>2];c[E+(M*332|0)+292>>2]=c[C+(M*332|0)+292>>2];M=M+1|0;}while((M|0)<(d[L]|0))}do{if((V|0)!=0){L=UMa(f+4708|0,e[j+8>>1]|0,e[j+10>>1]|0)|0;if((L|0)>=0){break}KIb(g,16,2468776,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=L;break b}}while(0);L=c[l>>2]|0;M=c[n>>2]|0;do{if((a[z]&8)==0){ma=L}else{x=c[p>>2]|0;y=x+(L>>>3)|0;C=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=L+3|0;E=M>>>0>y>>>0?y:M;c[l>>2]=E;if((C&7<<(L&7)|0)!=0){KIb(g,16,2459544,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1094995529;break b}C=d[x+(E>>>3)|0]|0;x=((E|0)<(M|0))+E|0;c[l>>2]=x;if((C&1<<(E&7)|0)==0){ma=x;break}E=-x|0;C=M-x|0;if((E|0)>24){na=E}else{na=(C|0)<24?C:24}C=na+x|0;c[l>>2]=C;ma=C}}while(0);L=-ma&7;if((L|0)==0){oa=ma}else{C=L+ma|0;L=M>>>0>C>>>0?C:M;c[l>>2]=L;oa=L}L=oa+23|0;C=M>>>0>L>>>0?L:M;c[l>>2]=C;L=c[p>>2]|0;x=d[L+(C>>>3)|0]|0;E=((C|0)<(M|0))+C|0;c[l>>2]=E;if((1<<(C&7)&x|0)==0){pa=E}else{x=E;while(1){E=L+(x>>>3)|0;C=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=x+16|0;y=M>>>0>E>>>0?E:M;c[l>>2]=y;if((32768<<(x&7)&C|0)==0){pa=y;break}else{x=y}}}x=-pa&7;if((x|0)==0){qa=pa}else{y=x+pa|0;x=M>>>0>y>>>0?y:M;c[l>>2]=x;qa=x}c[f+4892>>2]=0;ra=c[s>>2]|0;sa=qa;ta=M;ua=L;break a}else if((H|0)==42){KIb(g,16,2531600,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1163346256;break}else if((H|0)==47){RIb(g,2516384,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1163346256;break}else if((H|0)==57){KIb(g,16,2502424,(t=i,i=i+16|0,c[t>>2]=ja,c[t+8>>2]=ka,t)|0);i=t;I=-1094995529;break}else if((H|0)==62){KIb(g,16,2489360,(t=i,i=i+8|0,c[t>>2]=la,t)|0);i=t;I=-1;break}else if((H|0)==67){KIb(g,16,2478368,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;I=-1094995529;break}}}while(0);KIb(g,16,2121768,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;c[f+4892>>2]=1;u=I;i=h;return u|0}else{ra=v;sa=m;ta=o;ua=q}}while(0);do{if((ra|0)==2){if((c[f+4664>>2]|0)!=0){H=91;break}KIb(g,16,2639296,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;c[s>>2]=1;u=-1094995529;i=h;return u|0}else if((ra|0)==4){va=sa;wa=ta}else{H=91}}while(0);do{if((H|0)==91){ra=ua+(sa>>>3)|0;s=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)>>>((sa&7)>>>0);ra=sa+8|0;t=ta>>>0>ra>>>0?ra:ta;c[l>>2]=t;ra=s&255;a[f+4688|0]=ra;if((s&1|0)==0){xa=0;ya=t}else{q=ua+(t>>>3)|0;o=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((t&7)>>>0)&16777215;q=t+24|0;t=ta>>>0>q>>>0?q:ta;c[l>>2]=t;xa=o;ya=t}c[f+4684>>2]=xa;if((ra&16)==0){za=0;Aa=ya}else{t=ua+(ya>>>3)|0;o=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((ya&7)>>>0);t=ya+16|0;q=ta>>>0>t>>>0?t:ta;c[l>>2]=q;za=o&65535;Aa=q}b[f+4690>>1]=za;d:do{if(!((ra&32)==0)){q=Aa;while(1){o=ua+(q>>>3)|0;t=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((q&7)>>>0)&255;o=q+8|0;m=ta>>>0>o>>>0?o:ta;c[l>>2]=m;if((t|0)==0){break d}else{Ba=0;Ca=m}do{m=Ca+8|0;Ca=ta>>>0>m>>>0?m:ta;Ba=Ba+1|0;}while((Ba|0)<(t|0));c[l>>2]=Ca;q=Ca}}}while(0);ra=RMa(k,s&64,0,f+4760|0,g)|0;if((ra|0)<0){u=ra;i=h;return u|0}else{ra=c[n>>2]|0;q=(c[l>>2]|0)+3|0;L=ra>>>0>q>>>0?q:ra;c[l>>2]=L;va=L;wa=ra;break}}}while(0);n=-va&7;if((n|0)==0){u=0;i=h;return u|0}g=n+va|0;c[l>>2]=wa>>>0>g>>>0?g:wa;u=0;i=h;return u|0}function WLa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;h=b|0;j=b+8|0;k=c[j>>2]|0;l=b+16|0;m=c[l>>2]|0;n=b|0;o=c[n>>2]|0;p=o+(k>>>3)|0;q=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((k&7)>>>0);p=k+8|0;k=m>>>0>p>>>0?p:m;c[j>>2]=k;if((q&1|0)!=0){c[e+52>>2]=1;r=0;i=g;return r|0}if((a[b+4688|0]|0)<0){b=o+(k>>>3)|0;p=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((k&7)>>>0)&16777215;b=k+24|0;c[j>>2]=m>>>0>b>>>0?b:m;s=p}else{s=0}c[e+24>>2]=s;c[e+68>>2]=q&2;s=e+72|0;c[s>>2]=q&8;p=q&4;c[e+76>>2]=p;if((p|0)==0){c[s>>2]=1}s=e+144|0;c[s>>2]=0;a:do{if((q&16|0)!=0){p=c[j>>2]|0;m=c[l>>2]|0;b=o+(p>>>3)|0;k=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((p&7)>>>0)&255;b=p+8|0;c[j>>2]=m>>>0>b>>>0?b:m;c[s>>2]=k;if(k>>>0>61>>>0){KIb(f,16,2205120,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;r=-1094995529;i=g;return r|0}if((k|0)==0){break}else{t=0;u=o}while(1){k=c[j>>2]|0;m=c[l>>2]|0;b=u+(k>>>3)|0;p=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((k&7)>>>0);b=k+8|0;c[j>>2]=m>>>0>b>>>0?b:m;a[e+148+t|0]=p;p=t+1|0;if((p|0)>=(c[s>>2]<<1|0)){break a}t=p;u=c[n>>2]|0}}}while(0);if((q&64|0)==0){v=8}else{u=c[j>>2]|0;t=c[l>>2]|0;s=(c[n>>2]|0)+(u>>>3)|0;o=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((u&7)>>>0)&7;s=u+3|0;c[j>>2]=t>>>0>s>>>0?s:t;v=o}c[e+272>>2]=v;v=RMa(h,q&128,1,e+96|0,f)|0;if((v|0)<0){r=v;i=g;return r|0}v=c[j>>2]|0;f=c[n>>2]|0;n=(d[f+(v>>>3)|0]|0)>>>((v&7)>>>0);c[j>>2]=((v|0)<(c[l>>2]|0))+v;v=n&1;c[e+308>>2]=v;if((v|0)!=0){v=c[j>>2]|0;n=c[l>>2]|0;h=f+(v>>>3)|0;o=(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>((v&7)>>>0)&65535;h=v+16|0;c[j>>2]=n>>>0>h>>>0?h:n;c[e+304>>2]=o}o=c[j>>2]|0;n=c[l>>2]|0;h=f+(o>>>3)|0;v=(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>((o&7)>>>0)&31;h=o+5|0;c[j>>2]=n>>>0>h>>>0?h:n;c[e+84>>2]=v;v=c[j>>2]|0;b:do{if((q&32|0)==0){w=v}else{e=-v&7;n=c[l>>2]|0;if((e|0)==0){x=v}else{h=e+v|0;e=n>>>0>h>>>0?h:n;c[j>>2]=e;x=e}while(1){e=f+(x>>>3)|0;h=(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>((x&7)>>>0)&255;e=x+8|0;o=n>>>0>e>>>0?e:n;c[j>>2]=o;if((h|0)==0){w=o;break b}else{y=0;z=o}do{o=z+8|0;z=n>>>0>o>>>0?o:n;y=y+1|0;}while((y|0)<(h|0));c[j>>2]=z;x=z}}}while(0);z=-w&7;if((z|0)==0){r=0;i=g;return r|0}x=c[l>>2]|0;l=z+w|0;c[j>>2]=x>>>0>l>>>0?l:x;r=0;i=g;return r|0}function XLa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0;j=i;k=f+56|0;l=c[k>>2]|0;m=f+48|0;n=c[m>>2]|0;o=ca(n,l)|0;p=c[g+32>>2]|0;q=c[g+36>>2]|0;r=g+4|0;s=c[r>>2]|0;t=ca(s,n)|0;n=g|0;u=c[n>>2]|0;v=t+u|0;do{if((q|0)==0){do{if((c[f+76>>2]|0)!=0){if((c[f+72>>2]|0)==0){break}else{w=-1094995529}i=j;return w|0}}while(0);if((c[f+68>>2]|0)==0){break}else{w=-1094995529}i=j;return w|0}}while(0);t=c[g+28>>2]|0;x=g+8|0;y=c[x>>2]|0;z=g+12|0;g=c[z>>2]|0;A=ca((l-1+g|0)/(l|0)|0,(y-1+l|0)/(l|0)|0)|0;if((t|0)!=(A|0)){KIb(h,16,2362528,(B=i,i=i+16|0,c[B>>2]=t,c[B+8>>2]=A,B)|0);i=B;w=-1094995529;i=j;return w|0}A=c[(c[e+4716>>2]|0)+56>>2]>>3;t=l>>3;C=A-t|0;D=e+8|0;a:do{if((g|0)>0){E=e|0;F=e+16|0;G=f+68|0;H=e+4652|0;I=f+60|0;J=f+76|0;K=e+4764|0;L=(A|0)==(t|0);M=C-1|0;N=f+72|0;O=f|0;P=f+4|0;Q=e+4688|0;R=f+64|0;S=f+312|0;T=0;U=v;V=0;W=s;X=p;Y=q;Z=y;_=l;$=s;aa=g;ba=u;b:while(1){if((Z|0)>0){da=W&65535;ea=W-1|0;fa=T;ga=U;ha=V;ia=ba;ja=X;ka=Y;while(1){b[ja>>1]=ia;b[ja+2>>1]=da;c[ja+4>>2]=ga;la=c[D>>2]|0;ma=c[E>>2]|0;na=d[ma+(la>>>3)|0]|0;oa=c[F>>2]|0;pa=((la|0)<(oa|0))+la|0;c[D>>2]=pa;do{if((na&1<<(la&7)|0)==0){qa=(ka|0)==0;do{if((c[G>>2]|0)==0|qa){if((c[H>>2]|0)==0){a[ja+8|0]=0;break}else{ra=(d[ma+(pa>>>3)|0]|0)>>>((pa&7)>>>0);c[D>>2]=((pa|0)<(oa|0))+pa;a[ja+8|0]=ra&1;break}}else{a[ja+8|0]=a[ka+8|0]|0}}while(0);ra=(c[k>>2]|0)!=(c[I>>2]|0)?4:1;sa=c[D>>2]|0;ta=c[F>>2]|0;ua=(c[E>>2]|0)+(sa>>>3)|0;va=32-ra|0;wa=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((sa&7)>>>0)<<va>>>(va>>>0);va=ra+sa|0;c[D>>2]=ta>>>0>va>>>0?va:ta;ta=wa&255;a[ja+9|0]=ta;wa=ja+10|0;a[wa]=0;do{if((c[J>>2]|0)!=0){if((c[N>>2]|0)!=0){if(qa){break}a[wa]=a[ka+10|0]|0;break}if(ta<<24>>24==0){if((c[O>>2]|0)!=0){break}if((c[P>>2]|0)!=0){break}if((a[Q]&8)==0){break}}va=c[(c[K>>2]|0)+4>>2]|0;sa=c[D>>2]|0;ra=c[F>>2]|0;ua=(c[E>>2]|0)+(sa>>>3)|0;xa=(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)>>>((sa&7)>>>0)&8191;ua=b[va+(xa<<2)>>1]|0;ya=(b[va+(xa<<2)+2>>1]|0)+sa|0;c[D>>2]=ra>>>0>ya>>>0?ya:ra;a[wa]=-(ua<<24>>25^-(ua&1))}}while(0);if((a[ja+8|0]|0)==0){a[ja+12|0]=0;a[ja+11|0]=0;za=ha;Aa=fa;Ba=0;Ca=0;break}if((c[G>>2]|0)==0|qa){wa=c[(c[K>>2]|0)+4>>2]|0;ta=c[D>>2]|0;ua=c[F>>2]|0;ra=c[E>>2]|0;ya=ra+(ta>>>3)|0;sa=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((ta&7)>>>0)&8191;ya=b[wa+(sa<<2)>>1]|0;xa=(b[wa+(sa<<2)+2>>1]|0)+ta|0;ta=ua>>>0>xa>>>0?xa:ua;c[D>>2]=ta;xa=fa-(ya>>1^-(ya&1))|0;ya=ra+(ta>>>3)|0;ra=(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)>>>((ta&7)>>>0)&8191;ya=b[wa+(ra<<2)>>1]|0;sa=(b[wa+(ra<<2)+2>>1]|0)+ta|0;c[D>>2]=ua>>>0>sa>>>0?sa:ua;ua=ha-(ya>>1^-(ya&1))|0;ya=ua&255;a[ja+11|0]=ya;sa=xa&255;a[ja+12|0]=sa;za=ua;Aa=xa;Ba=ya;Ca=sa;break}sa=a[ka+11|0]|0;if(L){a[ja+11|0]=sa;ya=a[ka+12|0]|0;a[ja+12|0]=ya;za=ha;Aa=fa;Ba=sa;Ca=ya;break}else{ya=M+(sa<<24>>24)+(sa<<24>>24>0)>>C&255;a[ja+11|0]=ya;sa=a[ka+12|0]|0;xa=M+(sa<<24>>24)+(sa<<24>>24>0)>>C&255;a[ja+12|0]=xa;za=ha;Aa=fa;Ba=ya;Ca=xa;break}}else{if((c[H>>2]|0)==0){Da=13;break b}a[ja+8|0]=1;a[ja+9|0]=0;xa=ja+10|0;a[xa]=0;do{if((c[O>>2]|0)==0){if((c[P>>2]|0)!=0){break}if((a[Q]&8)==0){break}ya=c[(c[K>>2]|0)+4>>2]|0;sa=c[D>>2]|0;ua=c[F>>2]|0;ta=(c[E>>2]|0)+(sa>>>3)|0;ra=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((sa&7)>>>0)&8191;ta=b[ya+(ra<<2)>>1]|0;wa=(b[ya+(ra<<2)+2>>1]|0)+sa|0;c[D>>2]=ua>>>0>wa>>>0?wa:ua;a[xa]=-(ta<<24>>25^-(ta&1))}}while(0);xa=ja+12|0;a[xa]=0;qa=ja+11|0;a[qa]=0;if((c[G>>2]|0)==0|(ka|0)==0){za=ha;Aa=fa;Ba=0;Ca=0;break}ta=a[ka+11|0]|0;if(L){a[qa]=ta;ua=a[ka+12|0]|0;a[xa]=ua;za=ha;Aa=fa;Ba=ta;Ca=ua;break}else{ua=M+(ta<<24>>24)+(ta<<24>>24>0)>>C&255;a[qa]=ua;qa=a[ka+12|0]|0;ta=M+(qa<<24>>24)+(qa<<24>>24>0)>>C&255;a[xa]=ta;za=ha;Aa=fa;Ba=ua;Ca=ta;break}}}while(0);Ea=c[R>>2]|0;if((a[ja+8|0]|0)==0){Fa=c[k>>2]|0}else{Ga=Ba<<24>>24;Ha=Ca<<24>>24;pa=c[m>>2]|0;if(((Ga>>Ea)+ia+(ca((Ha>>Ea)+W|0,pa)|0)|0)<0){Da=47;break b}oa=c[k>>2]|0;ma=ia-1+(Ga+Ea>>Ea)+oa+(ca(ea+(Ha+Ea>>Ea)+oa|0,pa)|0)|0;if((ma|0)>((c[S>>2]|0)-1|0)){Da=47;break b}else{Fa=oa}}Ia=ja+16|0;Ja=(ka|0)==0?0:ka+16|0;oa=Fa+ia|0;Ka=c[n>>2]|0;La=c[x>>2]|0;if((oa|0)<(La+Ka|0)){fa=Aa;ga=Fa+ga|0;ha=za;ia=oa;ja=Ia;ka=Ja}else{break}}Ma=Aa;Na=za;Oa=Ia;Pa=Ja;Qa=La;Ra=Fa;Sa=c[r>>2]|0;Ta=c[z>>2]|0;Ua=Ka}else{Ma=T;Na=V;Oa=X;Pa=Y;Qa=Z;Ra=_;Sa=$;Ta=aa;Ua=ba}ka=Ra+W|0;if((ka|0)<(Ta+Sa|0)){T=Ma;U=U+o|0;V=Na;W=ka;X=Oa;Y=Pa;Z=Qa;_=Ra;$=Sa;aa=Ta;ba=Ua}else{break a}}if((Da|0)==13){KIb(h,16,2297704,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;w=-1094995529;i=j;return w|0}else if((Da|0)==47){ba=Ga+(ca(Ea,ia)|0)|0;aa=Ha+(ca(Ea,W)|0)|0;KIb(h,16,2246960,(B=i,i=i+16|0,c[B>>2]=ba,c[B+8>>2]=aa,B)|0);i=B;w=-1094995529;i=j;return w|0}}}while(0);B=c[D>>2]|0;h=-B&7;if((h|0)==0){w=0;i=j;return w|0}Ea=c[e+16>>2]|0;e=h+B|0;c[D>>2]=Ea>>>0>e>>>0?e:Ea;w=0;i=j;return w|0}function YLa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+4656>>2]|0;if((b|0)==2){d=a+4676|0;e=a+4756|0;if((c[d>>2]|0)==0){c[e>>2]=2;c[d>>2]=1;f=2}else{f=c[e>>2]|0}e=a+4748|0;d=c[e>>2]|0;c[a+4756>>2]=d;c[e>>2]=f;c[a+4752>>2]=d}else if((b|0)==0|(b|0)==1){b=a+4744|0;d=c[b>>2]|0;f=d^1;c[b>>2]=f;c[a+4748>>2]=f;c[a+4752>>2]=d}d=c[a+4652>>2]|0;if((d|0)==0){c[a+4744>>2]=0;g=0}else if((d|0)==1){g=c[a+4744>>2]|0}else{return}c[a+4676>>2]=0;c[a+4748>>2]=g;c[a+4752>>2]=g^1;return}function ZLa(a){a=a|0;return(c[a+4652>>2]|0)!=4|0}function _La(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;f=a+14128|0;g=c[f>>2]|0;h=a+14136|0;j=c[h>>2]|0;k=a+14120|0;l=c[k>>2]|0;m=l+(g>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(g&7);m=g+22|0;g=j>>>0>m>>>0?m:j;c[f>>2]=g;if((n&-1024|0)!=32768){KIb(c[a+4>>2]|0,16,253e4,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}n=l+(g>>>3)|0;m=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(g&7)>>>24;n=g+8|0;g=j>>>0>n>>>0?n:j;c[f>>2]=g;c[a+108>>2]=m;m=d[l+(g>>>3)|0]|0;n=((g|0)<(j|0))+g|0;c[f>>2]=n;if((m&128>>>((g&7)>>>0)|0)==0){KIb(c[a+4>>2]|0,16,2603696,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}g=d[l+(n>>>3)|0]|0;m=((n|0)<(j|0))+n|0;c[f>>2]=m;if((g&128>>>((n&7)>>>0)|0)!=0){KIb(c[a+4>>2]|0,16,2451704,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}n=m+1|0;m=(j>>>0>n>>>0?n:j)+1|0;n=(j>>>0>m>>>0?m:j)+1|0;m=j>>>0>n>>>0?n:j;c[f>>2]=m;n=l+(m>>>3)|0;g=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(m&7);n=g>>>29;q=m+3|0;m=j>>>0>q>>>0?q:j;c[f>>2]=m;if((n|0)==6|(n|0)==0){KIb(c[a+4>>2]|0,16,2362416,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}c[a+40>>2]=0;q=(d[l+(m>>>3)|0]|0)<<(m&7)>>>7;r=((m|0)<(j|0))+m|0;c[f>>2]=r;c[a+9992>>2]=(q&1)+1;q=(d[l+(r>>>3)|0]|0)<<(r&7)>>>7;m=((r|0)<(j|0))+r|0;c[f>>2]=m;r=q&1;c[a+10052>>2]=r;q=d[l+(m>>>3)|0]|0;s=((m|0)<(j|0))+m|0;c[f>>2]=s;if((q&128>>>((m&7)>>>0)|0)!=0){KIb(c[a+4>>2]|0,16,2297624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}m=(d[l+(s>>>3)|0]|0)<<(s&7)>>>7;q=((s|0)<(j|0))+s|0;c[f>>2]=q;s=m&1;c[a+13788>>2]=s;c[a+10048>>2]=(s|0)==0?r:1;r=(d[l+(q>>>3)|0]|0)<<(q&7)>>>7;s=((q|0)<(j|0))+q|0;c[f>>2]=s;q=a+36|0;c[q>>2]=r&1;do{if(g>>>0<3221225472>>>0){c[a+8>>2]=e[1379168+(n<<2)>>1]|0;c[a+12>>2]=e[1379170+(n<<2)>>1]|0;r=c[a+4>>2]|0;c[r+224>>2]=12;c[r+228>>2]=11;t=n}else{r=l+(s>>>3)|0;m=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>29;r=s+3|0;u=j>>>0>r>>>0?r:j;c[f>>2]=u;if((m|0)==7|(m|0)==0){KIb(c[a+4>>2]|0,16,2246840,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=b;return p|0}r=l+(u>>>3)|0;v=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;r=u+2|0;w=j>>>0>r>>>0?r:j;c[f>>2]=w;r=a+4|0;if((v&-1073741824>>>((u&7)>>>0)|0)==0){x=w;y=l;z=j}else{KIb(c[r>>2]|0,16,2205064,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;x=c[f>>2]|0;y=c[k>>2]|0;z=c[h>>2]|0}w=(d[y+(x>>>3)|0]|0)<<(x&7)>>>7;u=((x|0)<(z|0))+x|0;c[f>>2]=u;v=c[r>>2]|0;c[a+13836>>2]=w&1&-((c[v+800>>2]|0)==0|0);w=d[y+(u>>>3)|0]|0;A=((u|0)<(z|0))+u|0;c[f>>2]=A;if((w&128>>>((u&7)>>>0)|0)==0){B=A;C=y;D=z}else{KIb(v,16,2205064,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;B=c[f>>2]|0;C=c[k>>2]|0;D=c[h>>2]|0}v=d[C+(B>>>3)|0]|0;A=((B|0)<(D|0))+B|0;c[f>>2]=A;if((v&128>>>((B&7)>>>0)|0)!=0){c[q>>2]=2}v=C+(A>>>3)|0;u=je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=A+5|0;w=D>>>0>v>>>0?v:D;c[f>>2]=w;if((u&-134217728>>>((A&7)>>>0)|0)==0){E=w;F=D;G=C}else{KIb(c[r>>2]|0,16,2205064,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;E=c[f>>2]|0;F=c[h>>2]|0;G=c[k>>2]|0}w=G+(E>>>3)|0;A=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(E&7);w=E+5|0;c[f>>2]=F>>>0>w>>>0?w:F;if((A&-134217728|0)==134217728){t=m;break}KIb(c[r>>2]|0,16,2172920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=m}}while(0);do{if((t|0)==6){F=c[f>>2]|0;E=c[h>>2]|0;G=c[k>>2]|0;C=G+(F>>>3)|0;D=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(F&7)>>>28;C=F+4|0;F=(E>>>0>C>>>0?C:E)+9|0;C=(E>>>0>F>>>0?F:E)+1|0;F=(E>>>0>C>>>0?C:E)+9|0;C=E>>>0>F>>>0?F:E;c[f>>2]=C;if((D|0)==15){F=G+(C>>>3)|0;B=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(C&7)>>>24;F=C+8|0;c[f>>2]=E>>>0>F>>>0?F:E;E=c[a+4>>2]|0;c[E+224>>2]=B;B=c[f>>2]|0;F=c[h>>2]|0;C=G+(B>>>3)|0;G=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7)>>>24;C=B+8|0;c[f>>2]=F>>>0>C>>>0?C:F;c[E+228>>2]=G;H=E}else{E=a+4|0;G=1378736+(D<<3)|0;D=(c[E>>2]|0)+224|0;F=c[G+4>>2]|0;c[D>>2]=c[G>>2];c[D+4>>2]=F;H=c[E>>2]|0}if((c[H+224>>2]|0)!=0){break}KIb(H,16,2145520,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);o=c[f>>2]|0;H=c[h>>2]|0;h=c[k>>2]|0;k=h+(o>>>3)|0;t=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(o&7)>>>27;k=o+5|0;c[a+9960>>2]=t;c[a+9964>>2]=t;t=(H>>>0>k>>>0?k:H)+1|0;k=H>>>0>t>>>0?t:H;c[f>>2]=k;if((c[q>>2]|0)==0){I=k}else{q=k+3|0;k=(H>>>0>q>>>0?q:H)+2|0;q=H>>>0>k>>>0?k:H;c[f>>2]=q;I=q}q=c[a+14132>>2]|0;if((q-I|0)<1){p=-1094995529;i=b;return p|0}else{J=I}while(1){I=d[h+(J>>>3)|0]|0;k=((J|0)<(H|0))+J|0;c[f>>2]=k;if((I&128>>>((J&7)>>>0)|0)==0){break}I=k+8|0;k=H>>>0>I>>>0?I:H;c[f>>2]=k;if((q-k|0)<1){p=-1094995529;K=37;break}else{J=k}}if((K|0)==37){i=b;return p|0}c[a+11556>>2]=1;c[a+9892>>2]=1347360;c[a+9888>>2]=1347360;CMa(a);p=0;i=b;return p|0}function $La(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;c[b>>2]=a;d=(c[a+792>>2]|0)==16;c[b+228>>2]=d&1;c[a+140>>2]=d?46:11;YJa(b+4|0,c[a+88>>2]|0);a=b+216|0;c[a>>2]=UHb()|0;d=UHb()|0;e=b+212|0;c[e>>2]=d;if(!((c[a>>2]|0)==0|(d|0)==0)){f=0;return f|0}VHb(a);VHb(e);f=-12;return f|0}function aMa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;k=c[a+60>>2]|0;l=k;m=b;n=(ca(c[a+124>>2]|0,c[a+120>>2]|0)|0)/128|0;o=k+224|0;c[o>>2]=n;if((j|0)<(n|0)){p=j;i=g;return p|0}if((V1(f,2,0)|0)!=0){WHb(c[k+216>>2]|0);WHb(c[k+212>>2]|0)}n=k+220|0;c[n>>2]=h;q=c[o>>2]|0;r=h+q|0;if(!((j-q|0)>-1)){KIb(0,0,2567768,(s=i,i=i+24|0,c[s>>2]=2549656,c[s+8>>2]=2531576,c[s+16>>2]=135,s)|0);i=s;Hd();return 0}q=k+232|0;t=q;c[t>>2]=r;c[k+240>>2]=r;r=k+236|0;c[r>>2]=h+j;h=M4a(a,m,1)|0;if((h|0)<0){p=h;i=g;return p|0}h=k+228|0;do{if((c[h>>2]|0)==0){a=V1(f,0,0)|0;if((a|0)==0){break}c[b+304>>2]=1;nrc(k+272|0,a|0,1024)|0}}while(0);f=c[t>>2]|0;a=c[r>>2]|0;u=a-f|0;v=u>>>0>14>>>0?14:u;u=f+v|0;c[t>>2]=u;w=c[h>>2]|0;if((w|0)==0){nrc(c[b+4>>2]|0,k+272|0,1024)|0;x=c[b+32>>2]|0;c[k+264>>2]=x;y=x;z=c[h>>2]|0}else{x=c[b+32>>2]>>1;c[k+264>>2]=x;A=k+244|0;c[A>>2]=c[q>>2];c[A+4>>2]=c[q+4>>2];c[A+8>>2]=c[q+8>>2];if((a-u|0)<2){B=0}else{c[t>>2]=f+(v+2);v=u;B=(d[v]|d[v+1|0]<<8)<<16>>16&65535}v=A;A=c[v>>2]|0;u=(c[k+248>>2]|0)-A|0;c[v>>2]=A+(u>>>0>B>>>0?B:u);y=x;z=w}c[k+260>>2]=y-8;y=k;w=c[y>>2]|0;x=w+124|0;u=b+32|0;B=ca((c[x>>2]|0)-8|0,c[u>>2]|0)|0;c[k+268>>2]=(ca((c[w+120>>2]|0)-8|0,z+1|0)|0)+B;B=c[n>>2]|0;n=c[o>>2]<<3;o=n>>>0>2147483639>>>0|(B|0)==0;z=o?0:B;B=o?8:n+8|0;a:do{if((c[x>>2]|0)>0){n=b;o=k+256|0;A=0;v=0;f=w;b:while(1){if((c[f+120>>2]|0)>0){a=A;C=0;while(1){q=z+(a>>>3)|0;D=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((a&7)>>>0)&15;q=a+4|0;E=B>>>0>q>>>0?q:B;q=c[n>>2]|0;if((c[h>>2]|0)==0){c[o>>2]=q+((ca(c[u>>2]|0,v)|0)+C);F=We[c[1060056+(D<<2)>>2]&2047](l,m)|0}else{c[o>>2]=q+((ca(c[u>>2]|0,v)|0)+(C<<1));F=We[c[1059992+(D<<2)>>2]&2047](l,m)|0}if((F|0)!=0){break b}D=C+8|0;q=c[y>>2]|0;if((D|0)<(c[q+120>>2]|0)){a=E;C=D}else{G=q;H=E;break}}}else{G=f;H=A}a=v+8|0;if((a|0)<(c[G+124>>2]|0)){A=H;v=a;f=G}else{I=G;J=25;break a}}f=c[y>>2]|0;KIb(f,16,2451584,(s=i,i=i+24|0,c[s>>2]=c[f+428>>2],c[s+8>>2]=C,c[s+16>>2]=v,s)|0);i=s}else{I=w;J=25}}while(0);do{if((J|0)==25){w=(c[r>>2]|0)-(c[t>>2]|0)|0;if(!(w>>>0>1>>>0)){break}KIb(I,16,2362320,(s=i,i=i+8|0,c[s>>2]=w,s)|0);i=s}}while(0);c[e>>2]=1;e=k+212|0;WHb(c[e>>2]|0);s=k+216|0;k=c[s>>2]|0;I=c[e>>2]|0;c[s>>2]=I;c[e>>2]=k;k=YHb(I,m)|0;p=(k|0)<0?k:j;i=g;return p|0}function bMa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+216|0);VHb(b+212|0);return 0}function cMa(a,b){a=a|0;b=b|0;return rMa(a,c[a+216>>2]|0,c[b>>2]|0,c[b+32>>2]|0,0,0)|0}function dMa(a,b){a=a|0;b=b|0;return rMa(a,c[a+212>>2]|0,c[b>>2]|0,c[b+32>>2]|0,0,0)|0}function eMa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((c[b+228>>2]|0)==0){e=b+232|0;f=c[e>>2]|0;if(((c[b+236>>2]|0)-f|0)<1){g=0;h=7;break}c[e>>2]=f+1;i=f;h=6}else{f=b+244|0;e=c[f>>2]|0;if(((c[b+248>>2]|0)-e|0)<1){g=0;h=7;break}c[f>>2]=e+1;i=e;h=6}}while(0);do{if((h|0)==6){e=a[i]|0;if((e&255)>>>0<56>>>0){g=e;h=7;break}f=(e&255)-56|0;j=((f|0)/29|0)+8|0;k=((f|0)%29|0)-14|0}}while(0);if((h|0)==7){j=((g&255)/7|0)&255;k=((g&255)%7|0)&255|8}return rMa(b,c[b+212>>2]|0,c[d>>2]|0,c[d+32>>2]|0,k,j)|0}function fMa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((c[b+228>>2]|0)==0){e=b+232|0;f=c[e>>2]|0;if(((c[b+236>>2]|0)-f|0)<1){g=0;h=7;break}c[e>>2]=f+1;i=f;h=6}else{f=b+244|0;e=c[f>>2]|0;if(((c[b+248>>2]|0)-e|0)<1){g=0;h=7;break}c[f>>2]=e+1;i=e;h=6}}while(0);do{if((h|0)==6){e=a[i]|0;if((e&255)>>>0<56>>>0){g=e;h=7;break}f=(e&255)-56|0;j=-8-((f|0)/29|0)|0;k=14-((f|0)%29|0)|0}}while(0);if((h|0)==7){j=-(((g&255)/7|0)&255)|0;k=-(((g&255)%7|0)&255|8)|0}return rMa(b,d,c[d>>2]|0,c[d+32>>2]|0,k,j)|0}function gMa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;do{if((c[b+228>>2]|0)==0){e=b+232|0;f=c[e>>2]|0;if(((c[b+236>>2]|0)-f|0)<1){g=0;break}c[e>>2]=f+1;g=a[f]|0}else{f=b+244|0;e=c[f>>2]|0;if(((c[b+248>>2]|0)-e|0)<1){g=0;break}c[f>>2]=e+1;g=a[e]|0}}while(0);return rMa(b,c[b+216>>2]|0,c[d>>2]|0,c[d+32>>2]|0,(g&15)-8|0,((g&255)>>>4&255)-8|0)|0}function hMa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+232|0;f=c[e>>2]|0;g=c[b+236>>2]|0;if((g-f|0)<1){h=0;i=f}else{j=f+1|0;c[e>>2]=j;h=a[f]|0;i=j}if((g-i|0)<1){k=0}else{c[e>>2]=i+1;k=a[i]|0}return rMa(b,c[b+216>>2]|0,c[d>>2]|0,c[d+32>>2]|0,h,k)|0}function iMa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+232|0;f=c[e>>2]|0;g=c[b+236>>2]|0;if((g-f|0)<1){h=0;i=f}else{j=f+1|0;c[e>>2]=j;h=a[f]|0;i=j}if((g-i|0)<1){k=0}else{c[e>>2]=i+1;k=a[i]|0}return rMa(b,c[b+212>>2]|0,c[d>>2]|0,c[d+32>>2]|0,h,k)|0}function jMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=c[a+256>>2]|0;h=a+232|0;j=c[h>>2]|0;k=c[a+236>>2]|0;if((k-j|0)<2){l=0;m=j}else{n=j+2|0;c[h>>2]=n;o=j;l=(d[o]|d[o+1|0]<<8)<<16>>16;m=n}b[f>>1]=l;if((k-m|0)<2){p=0;q=m}else{n=m+2|0;c[h>>2]=n;o=m;p=(d[o]|d[o+1|0]<<8)<<16>>16;q=n}b[f+2>>1]=p;if(l<<16>>16<0){if((k-q|0)<2){r=0}else{c[h>>2]=q+2;l=q;r=(d[l]|d[l+1|0]<<8)<<16>>16&65535}l=c[a+264>>2]|0;p=l<<1;n=0;o=r;r=g;while(1){m=b[f+((o&1)<<1)>>1]|0;b[r+(l+1<<1)>>1]=m;b[r+(l<<1)>>1]=m;b[r+2>>1]=m;b[r>>1]=m;m=b[f+((o>>>1&1)<<1)>>1]|0;b[r+(l+3<<1)>>1]=m;b[r+(l+2<<1)>>1]=m;b[r+6>>1]=m;b[r+4>>1]=m;m=b[f+((o>>>2&1)<<1)>>1]|0;b[r+(l+5<<1)>>1]=m;b[r+(l+4<<1)>>1]=m;b[r+10>>1]=m;b[r+8>>1]=m;m=b[f+((o>>>3&1)<<1)>>1]|0;b[r+(l+7<<1)>>1]=m;b[r+(l+6<<1)>>1]=m;b[r+14>>1]=m;b[r+12>>1]=m;m=n+2|0;if((m|0)<8){n=m;o=o>>>4;r=r+(p<<1)|0}else{break}}i=e;return 0}p=a+260|0;a=0;r=g;g=q;while(1){if((k-g|0)<1){s=256;t=g}else{q=g+1|0;c[h>>2]=q;s=d[g]|0|256;t=q}q=s;o=r;while(1){b[o>>1]=b[f+((q&1)<<1)>>1]|0;n=q>>>1;if((n|0)==1){break}else{q=n;o=o+2|0}}q=a+1|0;if((q|0)<8){a=q;r=o+((c[p>>2]|0)+1<<1)|0;g=t}else{break}}i=e;return 0}function kMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+8|0;f=e|0;g=c[a+256>>2]|0;h=a+232|0;j=c[h>>2]|0;k=c[a+236>>2]|0;if((k-j|0)<2){l=0;m=j}else{n=j+2|0;c[h>>2]=n;o=j;l=(d[o]|d[o+1|0]<<8)<<16>>16;m=n}n=f|0;b[n>>1]=l;if((k-m|0)<2){p=0;q=m}else{o=m+2|0;c[h>>2]=o;j=m;p=(d[j]|d[j+1|0]<<8)<<16>>16;q=o}o=f+2|0;b[o>>1]=p;if(!(l<<16>>16<0)){l=a+264|0;p=0;j=0;m=g;r=q;while(1){do{if((p&3|0)==0){if((p|0)==0){s=r}else{if((k-r|0)<2){t=0;u=r}else{v=r+2|0;c[h>>2]=v;w=r;t=(d[w]|d[w+1|0]<<8)<<16>>16;u=v}b[n>>1]=t;if((k-u|0)<2){x=0;y=u}else{v=u+2|0;c[h>>2]=v;w=u;x=(d[w]|d[w+1|0]<<8)<<16>>16;y=v}b[o>>1]=x;s=y}if((k-s|0)<2){z=0;A=s;break}v=s+2|0;c[h>>2]=v;w=s;z=(d[w]|d[w+1|0]<<8)<<16>>16&65535;A=v}else{z=j;A=r}}while(0);b[m>>1]=b[f+((z&1)<<1)>>1]|0;b[m+2>>1]=b[f+((z>>>1&1)<<1)>>1]|0;b[m+4>>1]=b[f+((z>>>2&1)<<1)>>1]|0;b[m+6>>1]=b[f+((z>>>3&1)<<1)>>1]|0;v=z>>>4;w=c[l>>2]|0;if((p|0)==7){p=p+1|0;j=v;m=m+((-(w<<3)|4)+w<<1)|0;r=A;continue}else{B=p+1|0;if((B|0)<16){p=B;j=v;m=m+(w<<1)|0;r=A;continue}else{break}}}i=e;return 0}if((k-q|0)<4){C=0;D=q}else{A=q+4|0;c[h>>2]=A;r=q;C=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;D=A}if((k-D|0)<2){E=0;F=D}else{A=D+2|0;c[h>>2]=A;r=D;E=(d[r]|d[r+1|0]<<8)<<16>>16;F=A}A=f+4|0;b[A>>1]=E;if((k-F|0)<2){G=0;H=F}else{r=F+2|0;c[h>>2]=r;D=F;G=(d[D]|d[D+1|0]<<8)<<16>>16;H=r}r=f+6|0;b[r>>1]=G;if(E<<16>>16<0){E=a+260|0;G=0;D=C;F=g;q=H;while(1){do{if((G|0)==4){b[n>>1]=b[A>>1]|0;b[o>>1]=b[r>>1]|0;if((k-q|0)<4){I=0;J=q;break}m=q+4|0;c[h>>2]=m;j=q;I=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;J=m}else{I=D;J=q}}while(0);b[F>>1]=b[f+((I&1)<<1)>>1]|0;b[F+2>>1]=b[f+((I>>>1&1)<<1)>>1]|0;b[F+4>>1]=b[f+((I>>>2&1)<<1)>>1]|0;b[F+6>>1]=b[f+((I>>>3&1)<<1)>>1]|0;b[F+8>>1]=b[f+((I>>>4&1)<<1)>>1]|0;b[F+10>>1]=b[f+((I>>>5&1)<<1)>>1]|0;b[F+12>>1]=b[f+((I>>>6&1)<<1)>>1]|0;b[F+14>>1]=b[f+((I>>>7&1)<<1)>>1]|0;m=G+1|0;if((m|0)<8){G=m;D=I>>>8;F=F+((c[E>>2]|0)+8<<1)|0;q=J}else{break}}i=e;return 0}J=c[a+264>>2]|0;a=0;q=C;C=g;g=H;a:while(1){b[C>>1]=b[f+((q&1)<<1)>>1]|0;b[C+2>>1]=b[f+((q>>>1&1)<<1)>>1]|0;b[C+4>>1]=b[f+((q>>>2&1)<<1)>>1]|0;b[C+6>>1]=b[f+((q>>>3&1)<<1)>>1]|0;H=q>>>4;E=J-4|0;do{if((a|0)==7){F=4-(J<<3)|0;b[n>>1]=b[A>>1]|0;b[o>>1]=b[r>>1]|0;if((k-g|0)<4){a=a+1|0;q=0;C=C+(F+J<<1)|0;g=g;continue a}else{I=g+4|0;c[h>>2]=I;D=g;K=F+E|0;L=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;M=I;break}}else{K=E;L=H;M=g}}while(0);H=a+1|0;if((H|0)<16){a=H;q=L;C=C+(K+4<<1)|0;g=M}else{break}}i=e;return 0}function lMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+8|0;f=e|0;g=c[a+256>>2]|0;h=a+232|0;j=c[h>>2]|0;k=c[a+236>>2]|0;if((k-j|0)<2){l=0;m=j}else{n=j+2|0;c[h>>2]=n;o=j;l=(d[o]|d[o+1|0]<<8)<<16>>16;m=n}b[f>>1]=l;if((k-m|0)<2){p=0;q=m}else{n=m+2|0;c[h>>2]=n;o=m;p=(d[o]|d[o+1|0]<<8)<<16>>16;q=n}b[f+2>>1]=p;if((k-q|0)<2){r=0;s=q}else{p=q+2|0;c[h>>2]=p;n=q;r=(d[n]|d[n+1|0]<<8)<<16>>16;s=p}b[f+4>>1]=r;if((k-s|0)<2){t=0;u=s}else{p=s+2|0;c[h>>2]=p;n=s;t=(d[n]|d[n+1|0]<<8)<<16>>16;u=p}b[f+6>>1]=t;t=g;if(l<<16>>16<0){if((k-u|0)<8){v=0;w=0}else{c[h>>2]=u+8;l=u;g=l|0;p=l+4|0;v=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;w=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0}g=c[a+264>>2]|0;if(!(r<<16>>16<0)){p=0;l=t;n=v;s=w;while(1){q=b[f+((s&3)<<1)>>1]|0;b[l+2>>1]=q;b[l>>1]=q;q=b[f+(((s>>>2|n<<30)&3)<<1)>>1]|0;b[l+6>>1]=q;b[l+4>>1]=q;q=b[f+(((s>>>4|n<<28)&3)<<1)>>1]|0;b[l+10>>1]=q;b[l+8>>1]=q;q=b[f+(((s>>>6|n<<26)&3)<<1)>>1]|0;b[l+14>>1]=q;b[l+12>>1]=q;q=s>>>8|n<<24;o=p+1|0;if((o|0)<8){p=o;l=l+(g<<1)|0;n=n>>>8|0<<24;s=q}else{break}}i=e;return 0}s=g<<1;n=0;l=t;p=v;v=w;while(1){w=b[f+((v&3)<<1)>>1]|0;b[l+(g<<1)>>1]=w;b[l>>1]=w;w=b[f+(((v>>>2|p<<30)&3)<<1)>>1]|0;b[l+(g+1<<1)>>1]=w;b[l+2>>1]=w;w=b[f+(((v>>>4|p<<28)&3)<<1)>>1]|0;b[l+(g+2<<1)>>1]=w;b[l+4>>1]=w;w=b[f+(((v>>>6|p<<26)&3)<<1)>>1]|0;b[l+(g+3<<1)>>1]=w;b[l+6>>1]=w;w=b[f+(((v>>>8|p<<24)&3)<<1)>>1]|0;b[l+(g+4<<1)>>1]=w;b[l+8>>1]=w;w=b[f+(((v>>>10|p<<22)&3)<<1)>>1]|0;b[l+(g+5<<1)>>1]=w;b[l+10>>1]=w;w=b[f+(((v>>>12|p<<20)&3)<<1)>>1]|0;b[l+(g+6<<1)>>1]=w;b[l+12>>1]=w;w=b[f+(((v>>>14|p<<18)&3)<<1)>>1]|0;b[l+(g+7<<1)>>1]=w;b[l+14>>1]=w;w=v>>>16|p<<16;q=n+2|0;if((q|0)<8){n=q;l=l+(s<<1)|0;p=p>>>16|0<<16;v=w}else{break}}i=e;return 0}if(r<<16>>16<0){if((k-u|0)<4){x=0}else{c[h>>2]=u+4;r=u;x=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0}r=c[a+264>>2]|0;v=r<<1;p=0;s=t;l=x;while(1){x=b[f+((l&3)<<1)>>1]|0;b[s+(r+1<<1)>>1]=x;b[s+(r<<1)>>1]=x;b[s+2>>1]=x;b[s>>1]=x;x=b[f+((l>>>2&3)<<1)>>1]|0;b[s+(r+3<<1)>>1]=x;b[s+(r+2<<1)>>1]=x;b[s+6>>1]=x;b[s+4>>1]=x;x=b[f+((l>>>4&3)<<1)>>1]|0;b[s+(r+5<<1)>>1]=x;b[s+(r+4<<1)>>1]=x;b[s+10>>1]=x;b[s+8>>1]=x;x=b[f+((l>>>6&3)<<1)>>1]|0;b[s+(r+7<<1)>>1]=x;b[s+(r+6<<1)>>1]=x;b[s+14>>1]=x;b[s+12>>1]=x;x=p+2|0;if((x|0)<8){p=x;s=s+(v<<1)|0;l=l>>>8}else{break}}i=e;return 0}else{l=a+260|0;a=0;v=t;t=u;while(1){if((k-t|0)<2){y=0;z=t}else{u=t+2|0;c[h>>2]=u;s=t;y=(d[s]|d[s+1|0]<<8)<<16>>16&65535;z=u}b[v>>1]=b[f+((y&3)<<1)>>1]|0;b[v+2>>1]=b[f+((y>>>2&3)<<1)>>1]|0;b[v+4>>1]=b[f+((y>>>4&3)<<1)>>1]|0;b[v+6>>1]=b[f+((y>>>6&3)<<1)>>1]|0;b[v+8>>1]=b[f+((y>>>8&3)<<1)>>1]|0;b[v+10>>1]=b[f+((y>>>10&3)<<1)>>1]|0;b[v+12>>1]=b[f+((y>>>12&3)<<1)>>1]|0;b[v+14>>1]=b[f+(y>>>14<<1)>>1]|0;u=a+1|0;if((u|0)<8){a=u;v=v+((c[l>>2]|0)+8<<1)|0;t=z}else{break}}i=e;return 0}return 0}function mMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;e=i;i=i+16|0;f=e|0;g=f;h=c[a+256>>2]|0;j=a+232|0;k=c[j>>2]|0;l=c[a+236>>2]|0;if((l-k|0)<2){m=0;n=k}else{o=k+2|0;c[j>>2]=o;p=k;m=(d[p]|d[p+1|0]<<8)<<16>>16;n=o}o=f;b[o>>1]=m;if((l-n|0)<2){q=0;r=n}else{p=n+2|0;c[j>>2]=p;k=n;q=(d[k]|d[k+1|0]<<8)<<16>>16;r=p}p=g+2|0;b[p>>1]=q;if((l-r|0)<2){s=0;t=r}else{q=r+2|0;c[j>>2]=q;k=r;s=(d[k]|d[k+1|0]<<8)<<16>>16;t=q}q=g+4|0;b[q>>1]=s;if((l-t|0)<2){u=0;v=t}else{s=t+2|0;c[j>>2]=s;k=t;u=(d[k]|d[k+1|0]<<8)<<16>>16;v=s}s=g+6|0;b[s>>1]=u;u=f|0;k=h;if(!(m<<16>>16<0)){m=a+264|0;h=0;t=0;r=k;n=v;while(1){do{if((h&3|0)==0){if((h|0)==0){w=n}else{if((l-n|0)<2){x=0;y=n}else{z=n+2|0;c[j>>2]=z;A=n;x=(d[A]|d[A+1|0]<<8)<<16>>16;y=z}b[o>>1]=x;if((l-y|0)<2){B=0;C=y}else{z=y+2|0;c[j>>2]=z;A=y;B=(d[A]|d[A+1|0]<<8)<<16>>16;C=z}b[p>>1]=B;if((l-C|0)<2){D=0;E=C}else{z=C+2|0;c[j>>2]=z;A=C;D=(d[A]|d[A+1|0]<<8)<<16>>16;E=z}b[q>>1]=D;if((l-E|0)<2){F=0;G=E}else{z=E+2|0;c[j>>2]=z;A=E;F=(d[A]|d[A+1|0]<<8)<<16>>16;G=z}b[s>>1]=F;w=G}if((l-w|0)<4){H=0;I=w;break}z=w+4|0;c[j>>2]=z;A=w;H=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;I=z}else{H=t;I=n}}while(0);b[r>>1]=b[g+((H&3)<<1)>>1]|0;b[r+2>>1]=b[g+((H>>>2&3)<<1)>>1]|0;b[r+4>>1]=b[g+((H>>>4&3)<<1)>>1]|0;b[r+6>>1]=b[g+((H>>>6&3)<<1)>>1]|0;z=H>>8;A=c[m>>2]|0;if((h|0)==7){h=h+1|0;t=z;r=r+((-(A<<3)|4)+A<<1)|0;n=I;continue}else{J=h+1|0;if((J|0)<16){h=J;t=z;r=r+(A<<1)|0;n=I;continue}else{break}}}i=e;return 0}if((l-v|0)<8){K=0;L=0;M=v}else{I=v+8|0;c[j>>2]=I;n=v;v=n|0;r=n+4|0;K=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;L=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;M=I}if((l-M|0)<2){N=0;O=M}else{I=M+2|0;c[j>>2]=I;v=M;N=(d[v]|d[v+1|0]<<8)<<16>>16;O=I}b[f+8>>1]=N;if((l-O|0)<2){P=0;Q=O}else{I=O+2|0;c[j>>2]=I;v=O;P=(d[v]|d[v+1|0]<<8)<<16>>16;Q=I}b[g+10>>1]=P;if((l-Q|0)<2){R=0;S=Q}else{P=Q+2|0;c[j>>2]=P;I=Q;R=(d[I]|d[I+1|0]<<8)<<16>>16;S=P}b[g+12>>1]=R;if((l-S|0)<2){T=0;U=S}else{R=S+2|0;c[j>>2]=R;P=S;T=(d[P]|d[P+1|0]<<8)<<16>>16;U=R}b[g+14>>1]=T;T=f+8|0;f=a+264|0;R=a+260|0;if(N<<16>>16>-1){N=0;a=k;P=K;S=L;I=U;a:while(1){b[a>>1]=b[g+((S&3)<<1)>>1]|0;b[a+2>>1]=b[g+(((S>>>2|P<<30)&3)<<1)>>1]|0;b[a+4>>1]=b[g+(((S>>>4|P<<28)&3)<<1)>>1]|0;b[a+6>>1]=b[g+(((S>>>6|P<<26)&3)<<1)>>1]|0;Q=S>>>8|P<<24;v=P>>>8|0<<24;O=c[f>>2]|0;M=a+(O<<1)|0;do{if((N|0)==7){r=a+((-(O<<3)|4)+O<<1)|0;n=c[T+4>>2]|0;c[u>>2]=c[T>>2];c[u+4>>2]=n;if((l-I|0)<8){N=N+1|0;a=r;P=0;S=0;I=I;continue a}else{n=I+8|0;c[j>>2]=n;t=I;h=t|0;m=t+4|0;V=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;W=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;X=r;Y=n;break}}else{V=v;W=Q;X=M;Y=I}}while(0);M=N+1|0;if((M|0)<16){N=M;a=X;P=V;S=W;I=Y}else{break}}i=e;return 0}else{Z=0;_=k;$=K;aa=L;ba=U}while(1){b[_>>1]=b[g+((aa&3)<<1)>>1]|0;b[_+2>>1]=b[g+(((aa>>>2|$<<30)&3)<<1)>>1]|0;b[_+4>>1]=b[g+(((aa>>>4|$<<28)&3)<<1)>>1]|0;b[_+6>>1]=b[g+(((aa>>>6|$<<26)&3)<<1)>>1]|0;U=aa>>>8|$<<24;L=$>>>8|0<<24;if((Z&1|0)==0){ca=_+8|0}else{ca=_+((c[R>>2]|0)+4<<1)|0}if((Z|0)!=7){K=Z+1|0;if((K|0)<16){Z=K;_=ca;$=L;aa=U;ba=ba;continue}else{break}}U=c[T+4>>2]|0;c[u>>2]=c[T>>2];c[u+4>>2]=U;if((l-ba|0)<8){da=0;ea=0;fa=ba}else{U=ba+8|0;c[j>>2]=U;L=ba;K=L|0;k=L+4|0;da=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;ea=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;fa=U}Z=Z+1|0;_=ca;$=da;aa=ea;ba=fa}i=e;return 0}function nMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=a+232|0;f=a+264|0;g=c[a+236>>2]|0;h=0;i=c[a+256>>2]|0;a=c[e>>2]|0;while(1){j=g;if((j-a|0)<2){k=0;l=a}else{m=a+2|0;c[e>>2]=m;n=a;k=(d[n]|d[n+1|0]<<8)<<16>>16;l=m}b[i>>1]=k;if((j-l|0)<2){o=0;p=l}else{m=l+2|0;c[e>>2]=m;n=l;o=(d[n]|d[n+1|0]<<8)<<16>>16;p=m}b[i+2>>1]=o;if((j-p|0)<2){q=0;r=p}else{m=p+2|0;c[e>>2]=m;n=p;q=(d[n]|d[n+1|0]<<8)<<16>>16;r=m}b[i+4>>1]=q;if((j-r|0)<2){s=0;t=r}else{m=r+2|0;c[e>>2]=m;n=r;s=(d[n]|d[n+1|0]<<8)<<16>>16;t=m}b[i+6>>1]=s;if((j-t|0)<2){u=0;v=t}else{m=t+2|0;c[e>>2]=m;n=t;u=(d[n]|d[n+1|0]<<8)<<16>>16;v=m}b[i+8>>1]=u;if((j-v|0)<2){w=0;x=v}else{m=v+2|0;c[e>>2]=m;n=v;w=(d[n]|d[n+1|0]<<8)<<16>>16;x=m}b[i+10>>1]=w;if((j-x|0)<2){y=0;z=x}else{m=x+2|0;c[e>>2]=m;n=x;y=(d[n]|d[n+1|0]<<8)<<16>>16;z=m}b[i+12>>1]=y;if((j-z|0)<2){A=0;B=z}else{j=z+2|0;c[e>>2]=j;m=z;A=(d[m]|d[m+1|0]<<8)<<16>>16;B=j}b[i+14>>1]=A;j=h+1|0;if((j|0)<8){h=j;i=i+(c[f>>2]<<1)|0;a=B}else{break}}return 0}function oMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=a+232|0;f=a+264|0;g=c[a+236>>2]|0;h=0;i=c[a+256>>2]|0;a=c[e>>2]|0;while(1){j=g;if((j-a|0)<2){k=0;l=a}else{m=a+2|0;c[e>>2]=m;n=a;k=(d[n]|d[n+1|0]<<8)<<16>>16;l=m}m=c[f>>2]|0;b[i+(m+1<<1)>>1]=k;b[i+(m<<1)>>1]=k;b[i+2>>1]=k;b[i>>1]=k;if((j-l|0)<2){o=0;p=l}else{n=l+2|0;c[e>>2]=n;q=l;o=(d[q]|d[q+1|0]<<8)<<16>>16;p=n}b[i+(m+3<<1)>>1]=o;b[i+(m+2<<1)>>1]=o;b[i+6>>1]=o;b[i+4>>1]=o;if((j-p|0)<2){r=0;s=p}else{n=p+2|0;c[e>>2]=n;q=p;r=(d[q]|d[q+1|0]<<8)<<16>>16;s=n}b[i+(m+5<<1)>>1]=r;b[i+(m+4<<1)>>1]=r;b[i+10>>1]=r;b[i+8>>1]=r;if((j-s|0)<2){t=0;u=s}else{j=s+2|0;c[e>>2]=j;n=s;t=(d[n]|d[n+1|0]<<8)<<16>>16;u=j}b[i+(m+7<<1)>>1]=t;b[i+(m+6<<1)>>1]=t;b[i+14>>1]=t;b[i+12>>1]=t;j=h+2|0;if((j|0)<8){h=j;i=i+(m<<1<<1)|0;a=u}else{break}}return 0}function pMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=a+236|0;h=a+232|0;j=f|0;k=f+2|0;f=a+264|0;l=0;m=c[a+256>>2]|0;while(1){if((l&3|0)==0){a=c[h>>2]|0;n=c[g>>2]|0;if((n-a|0)<2){o=0;p=a}else{q=a+2|0;c[h>>2]=q;r=a;o=(d[r]|d[r+1|0]<<8)<<16>>16;p=q}b[j>>1]=o;if((n-p|0)<2){s=0}else{c[h>>2]=p+2;n=p;s=(d[n]|d[n+1|0]<<8)<<16>>16}b[k>>1]=s;t=o}else{t=b[j>>1]|0}b[m>>1]=t;b[m+2>>1]=b[j>>1]|0;b[m+4>>1]=b[j>>1]|0;b[m+6>>1]=b[j>>1]|0;b[m+8>>1]=b[k>>1]|0;b[m+10>>1]=b[k>>1]|0;b[m+12>>1]=b[k>>1]|0;b[m+14>>1]=b[k>>1]|0;n=l+1|0;if((n|0)<8){l=n;m=m+(c[f>>2]<<1)|0}else{break}}i=e;return 0}function qMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0;e=c[a+256>>2]|0;f=e;g=a+232|0;h=c[g>>2]|0;if(((c[a+236>>2]|0)-h|0)<2){i=0}else{c[g>>2]=h+2;g=h;i=(d[g]|d[g+1|0]<<8)<<16>>16}g=c[a+264>>2]|0;b[f>>1]=i;b[e+2>>1]=i;b[e+4>>1]=i;b[e+6>>1]=i;b[e+8>>1]=i;b[e+10>>1]=i;b[e+12>>1]=i;b[e+14>>1]=i;b[f+(g<<1)>>1]=i;b[f+(g+1<<1)>>1]=i;b[f+(g+2<<1)>>1]=i;b[f+(g+3<<1)>>1]=i;b[f+(g+4<<1)>>1]=i;b[f+(g+5<<1)>>1]=i;b[f+(g+6<<1)>>1]=i;b[f+(g+7<<1)>>1]=i;e=g<<1;b[f+(e<<1)>>1]=i;b[f+((e|1)<<1)>>1]=i;b[f+(e+2<<1)>>1]=i;b[f+(e+3<<1)>>1]=i;b[f+(e+4<<1)>>1]=i;b[f+(e+5<<1)>>1]=i;b[f+(e+6<<1)>>1]=i;b[f+(e+7<<1)>>1]=i;a=e+g|0;b[f+(a<<1)>>1]=i;b[f+(a+1<<1)>>1]=i;b[f+(a+2<<1)>>1]=i;b[f+(a+3<<1)>>1]=i;b[f+(a+4<<1)>>1]=i;b[f+(a+5<<1)>>1]=i;b[f+(a+6<<1)>>1]=i;b[f+(a+7<<1)>>1]=i;e=a+g|0;b[f+(e<<1)>>1]=i;b[f+(e+1<<1)>>1]=i;b[f+(e+2<<1)>>1]=i;b[f+(e+3<<1)>>1]=i;b[f+(e+4<<1)>>1]=i;b[f+(e+5<<1)>>1]=i;b[f+(e+6<<1)>>1]=i;b[f+(e+7<<1)>>1]=i;a=e+g|0;b[f+(a<<1)>>1]=i;b[f+(a+1<<1)>>1]=i;b[f+(a+2<<1)>>1]=i;b[f+(a+3<<1)>>1]=i;b[f+(a+4<<1)>>1]=i;b[f+(a+5<<1)>>1]=i;b[f+(a+6<<1)>>1]=i;b[f+(a+7<<1)>>1]=i;e=a+g|0;b[f+(e<<1)>>1]=i;b[f+(e+1<<1)>>1]=i;b[f+(e+2<<1)>>1]=i;b[f+(e+3<<1)>>1]=i;b[f+(e+4<<1)>>1]=i;b[f+(e+5<<1)>>1]=i;b[f+(e+6<<1)>>1]=i;b[f+(e+7<<1)>>1]=i;a=e+g|0;b[f+(a<<1)>>1]=i;b[f+(a+1<<1)>>1]=i;b[f+(a+2<<1)>>1]=i;b[f+(a+3<<1)>>1]=i;b[f+(a+4<<1)>>1]=i;b[f+(a+5<<1)>>1]=i;b[f+(a+6<<1)>>1]=i;b[f+(a+7<<1)>>1]=i;return 0}function rMa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=c[a+256>>2]|0;k=ca(g,e)|0;g=c[a+228>>2]|0;l=k-d+j+(ca(g+1|0,f)|0)|0;if((l|0)<0){KIb(c[a>>2]|0,16,2297600,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;n=-1094995529;i=h;return n|0}f=c[a+268>>2]|0;if((l|0)>(f|0)){KIb(c[a>>2]|0,16,2246800,(m=i,i=i+16|0,c[m>>2]=l,c[m+8>>2]=f,m)|0);i=m;n=-1094995529;i=h;return n|0}f=c[b>>2]|0;if((f|0)==0){KIb(c[a>>2]|0,16,2205024,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=h;return n|0}else{mf[c[a+4+(((g|0)==0)<<4)>>2]&2047](j,f+l|0,e,8);n=0;i=h;return n|0}return 0}function sMa(a,b){a=a|0;b=b|0;b=i;KIb(c[a>>2]|0,16,2589304,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function tMa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+8|0;f=e|0;g=b+232|0;h=c[g>>2]|0;j=b+236|0;k=c[j>>2]|0;l=k;m=l-h|0;if(m>>>0<4>>>0){KIb(c[b>>2]|0,16,2616584,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=e;return o|0}if((m|0)<1){p=0;q=h}else{m=h+1|0;c[g>>2]=m;p=a[h]|0;q=m}a[f|0]=p;if((l-q|0)<1){r=0;s=q}else{m=q+1|0;c[g>>2]=m;r=d[q]|0;s=m}a[f+1|0]=r;if((p&255)>>>0>r>>>0){if((l-s|0)<2){t=0}else{c[g>>2]=s+2;l=s;t=(d[l]|d[l+1|0]<<8)<<16>>16&65535}l=b+264|0;r=b+256|0;p=0;m=t;t=c[l>>2]|0;q=c[r>>2]|0;while(1){h=a[f+(m&1)|0]|0;a[q+(t+1)|0]=h;a[(c[r>>2]|0)+(c[l>>2]|0)|0]=h;a[(c[r>>2]|0)+1|0]=h;a[c[r>>2]|0]=h;h=a[f+(m>>>1&1)|0]|0;a[(c[r>>2]|0)+((c[l>>2]|0)+3)|0]=h;a[(c[r>>2]|0)+((c[l>>2]|0)+2)|0]=h;a[(c[r>>2]|0)+3|0]=h;a[(c[r>>2]|0)+2|0]=h;h=a[f+(m>>>2&1)|0]|0;a[(c[r>>2]|0)+((c[l>>2]|0)+5)|0]=h;a[(c[r>>2]|0)+((c[l>>2]|0)+4)|0]=h;a[(c[r>>2]|0)+5|0]=h;a[(c[r>>2]|0)+4|0]=h;h=a[f+(m>>>3&1)|0]|0;a[(c[r>>2]|0)+((c[l>>2]|0)+7)|0]=h;a[(c[r>>2]|0)+((c[l>>2]|0)+6)|0]=h;a[(c[r>>2]|0)+7|0]=h;a[(c[r>>2]|0)+6|0]=h;h=c[l>>2]|0;n=(c[r>>2]|0)+(h<<1)|0;c[r>>2]=n;u=p+2|0;if((u|0)<8){p=u;m=m>>>4;t=h;q=n}else{o=0;break}}i=e;return o|0}q=b+256|0;t=b+260|0;b=1;m=k;k=s;while(1){if((m-k|0)<1){v=256}else{c[g>>2]=k+1;v=d[k]|0|256}do{s=a[f+(v&1)|0]|0;p=c[q>>2]|0;c[q>>2]=p+1;a[p]=s;v=v>>>1;}while((v|0)!=1);c[q>>2]=(c[q>>2]|0)+(c[t>>2]|0);if((b|0)>=8){o=0;break}b=b+1|0;m=c[j>>2]|0;k=c[g>>2]|0}i=e;return o|0}function uMa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;i=i+8|0;f=e|0;g=b+232|0;h=c[g>>2]|0;j=b+236|0;k=c[j>>2]|0;l=k-h|0;if(l>>>0<12>>>0){KIb(c[b>>2]|0,16,2639248,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}if((l|0)<1){o=0;p=h}else{l=h+1|0;c[g>>2]=l;o=a[h]|0;p=l}l=f|0;a[l]=o;if((k-p|0)<1){q=0;r=p}else{h=p+1|0;c[g>>2]=h;q=d[p]|0;r=h}h=f+1|0;a[h]=q;if(!((o&255)>>>0>q>>>0)){q=b+256|0;o=b+264|0;p=0;m=0;while(1){do{if((p&3|0)==0){s=c[j>>2]|0;t=c[g>>2]|0;if((p|0)==0){u=t}else{v=s;if((v-t|0)<1){w=0;x=t}else{y=t+1|0;c[g>>2]=y;w=a[t]|0;x=y}a[l]=w;if((v-x|0)<1){z=0;A=x}else{v=x+1|0;c[g>>2]=v;z=a[x]|0;A=v}a[h]=z;u=A}if((s-u|0)<2){B=0;break}c[g>>2]=u+2;s=u;B=(d[s]|d[s+1|0]<<8)<<16>>16&65535}else{B=m}}while(0);s=a[f+(B&1)|0]|0;v=c[q>>2]|0;c[q>>2]=v+1;a[v]=s;s=a[f+(B>>>1&1)|0]|0;v=c[q>>2]|0;c[q>>2]=v+1;a[v]=s;s=a[f+(B>>>2&1)|0]|0;v=c[q>>2]|0;c[q>>2]=v+1;a[v]=s;s=a[f+(B>>>3&1)|0]|0;v=c[q>>2]|0;c[q>>2]=v+1;a[v]=s;s=B>>>4;v=c[o>>2]|0;y=c[q>>2]|0;if((p|0)==7){c[q>>2]=y+(v*-7|0);p=p+1|0;m=s;continue}else{c[q>>2]=y+(v-4);v=p+1|0;if((v|0)<16){p=v;m=s;continue}else{n=0;break}}}i=e;return n|0}if((k-r|0)<4){C=0;D=r}else{m=r+4|0;c[g>>2]=m;p=r;C=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;D=m}if((k-D|0)<1){E=0;F=D}else{m=D+1|0;c[g>>2]=m;E=a[D]|0;F=m}m=f+2|0;a[m]=E;if((k-F|0)<1){G=0}else{c[g>>2]=F+1;G=d[F]|0}F=G&255;k=f+3|0;a[k]=F;D=b+256|0;if((E&255)>>>0>G>>>0){G=b+260|0;p=0;r=C;while(1){do{if((p|0)==4){a[l]=E;a[h]=F;q=c[g>>2]|0;if(((c[j>>2]|0)-q|0)<4){H=0;break}c[g>>2]=q+4;o=q;H=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0}else{H=r}}while(0);o=a[f+(H&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>1&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>2&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>3&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>4&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>5&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>6&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;o=a[f+(H>>>7&1)|0]|0;q=c[D>>2]|0;c[D>>2]=q+1;a[q]=o;c[D>>2]=(c[D>>2]|0)+(c[G>>2]|0);o=p+1|0;if((o|0)<8){p=o;r=H>>>8}else{n=0;break}}i=e;return n|0}H=b+264|0;b=0;r=C;C=c[D>>2]|0;a:while(1){p=a[f+(r&1)|0]|0;c[D>>2]=C+1;a[C]=p;p=a[f+(r>>>1&1)|0]|0;G=c[D>>2]|0;c[D>>2]=G+1;a[G]=p;p=a[f+(r>>>2&1)|0]|0;G=c[D>>2]|0;c[D>>2]=G+1;a[G]=p;p=a[f+(r>>>3&1)|0]|0;G=c[D>>2]|0;c[D>>2]=G+1;a[G]=p;p=r>>>4;G=c[H>>2]|0;F=c[D>>2]|0;E=F+(G-4)|0;c[D>>2]=E;do{if((b|0)==7){o=F+(G*-7|0)|0;c[D>>2]=o;a[l]=a[m]|0;a[h]=a[k]|0;q=c[g>>2]|0;if(((c[j>>2]|0)-q|0)<4){b=b+1|0;r=0;C=o;continue a}else{c[g>>2]=q+4;B=q;I=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;J=o;break}}else{I=p;J=E}}while(0);E=b+1|0;if((E|0)<16){b=E;r=I;C=J}else{n=0;break}}i=e;return n|0}function vMa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+8|0;f=e|0;g=f;h=b+232|0;j=c[h>>2]|0;k=b+236|0;l=c[k>>2]|0;m=l;if((m-j|0)>>>0<8>>>0){KIb(c[b>>2]|0,16,2121728,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=e;return o|0}n=j;c[f>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+4|0;c[h>>2]=n;if((d[f]|0)>>>0>(d[g+1|0]|0)>>>0){if((m-n|0)<8){p=0;q=0}else{c[h>>2]=j+12;f=n;r=f|0;s=f+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0}if((d[g+2|0]|0)>>>0>(d[g+3|0]|0)>>>0){r=b+264|0;s=b+256|0;f=0;t=p;u=q;v=c[r>>2]|0;w=c[s>>2]|0;while(1){x=a[g+(u&3)|0]|0;a[w+v|0]=x;a[c[s>>2]|0]=x;x=a[g+((u>>>2|t<<30)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+1)|0]=x;a[(c[s>>2]|0)+1|0]=x;x=a[g+((u>>>4|t<<28)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+2)|0]=x;a[(c[s>>2]|0)+2|0]=x;x=a[g+((u>>>6|t<<26)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+3)|0]=x;a[(c[s>>2]|0)+3|0]=x;x=a[g+((u>>>8|t<<24)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+4)|0]=x;a[(c[s>>2]|0)+4|0]=x;x=a[g+((u>>>10|t<<22)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+5)|0]=x;a[(c[s>>2]|0)+5|0]=x;x=a[g+((u>>>12|t<<20)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+6)|0]=x;a[(c[s>>2]|0)+6|0]=x;x=a[g+((u>>>14|t<<18)&3)|0]|0;a[(c[s>>2]|0)+((c[r>>2]|0)+7)|0]=x;a[(c[s>>2]|0)+7|0]=x;x=u>>>16|t<<16;y=c[r>>2]|0;z=(c[s>>2]|0)+(y<<1)|0;c[s>>2]=z;A=f+2|0;if((A|0)<8){f=A;t=t>>>16|0<<16;u=x;v=y;w=z}else{o=0;break}}i=e;return o|0}else{w=b+256|0;v=b+264|0;u=0;t=p;p=q;q=c[w>>2]|0;while(1){f=a[g+(p&3)|0]|0;a[q+1|0]=f;a[c[w>>2]|0]=f;f=a[g+((p>>>2|t<<30)&3)|0]|0;a[(c[w>>2]|0)+3|0]=f;a[(c[w>>2]|0)+2|0]=f;f=a[g+((p>>>4|t<<28)&3)|0]|0;a[(c[w>>2]|0)+5|0]=f;a[(c[w>>2]|0)+4|0]=f;f=a[g+((p>>>6|t<<26)&3)|0]|0;a[(c[w>>2]|0)+7|0]=f;a[(c[w>>2]|0)+6|0]=f;f=p>>>8|t<<24;s=(c[w>>2]|0)+(c[v>>2]|0)|0;c[w>>2]=s;r=u+1|0;if((r|0)<8){u=r;t=t>>>8|0<<24;p=f;q=s}else{o=0;break}}i=e;return o|0}}if((d[g+2|0]|0)>>>0>(d[g+3|0]|0)>>>0){if((m-n|0)<4){B=0}else{c[h>>2]=j+8;j=n;B=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0}j=b+264|0;m=b+256|0;q=0;p=B;B=c[j>>2]|0;t=c[m>>2]|0;while(1){u=a[g+(p&3)|0]|0;a[t+(B+1)|0]=u;a[(c[m>>2]|0)+(c[j>>2]|0)|0]=u;a[(c[m>>2]|0)+1|0]=u;a[c[m>>2]|0]=u;u=a[g+(p>>>2&3)|0]|0;a[(c[m>>2]|0)+((c[j>>2]|0)+3)|0]=u;a[(c[m>>2]|0)+((c[j>>2]|0)+2)|0]=u;a[(c[m>>2]|0)+3|0]=u;a[(c[m>>2]|0)+2|0]=u;u=a[g+(p>>>4&3)|0]|0;a[(c[m>>2]|0)+((c[j>>2]|0)+5)|0]=u;a[(c[m>>2]|0)+((c[j>>2]|0)+4)|0]=u;a[(c[m>>2]|0)+5|0]=u;a[(c[m>>2]|0)+4|0]=u;u=a[g+(p>>>6&3)|0]|0;a[(c[m>>2]|0)+((c[j>>2]|0)+7)|0]=u;a[(c[m>>2]|0)+((c[j>>2]|0)+6)|0]=u;a[(c[m>>2]|0)+7|0]=u;a[(c[m>>2]|0)+6|0]=u;u=c[j>>2]|0;w=(c[m>>2]|0)+(u<<1)|0;c[m>>2]=w;v=q+2|0;if((v|0)<8){q=v;p=p>>>8;B=u;t=w}else{o=0;break}}i=e;return o|0}t=b+256|0;B=b+260|0;b=1;p=l;l=n;while(1){if((p-l|0)<2){C=0}else{c[h>>2]=l+2;n=l;C=(d[n]|d[n+1|0]<<8)<<16>>16&65535}n=a[g+(C&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>2&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>4&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>6&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>8&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>10&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>12&3)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;n=a[g+(C>>>14)|0]|0;q=c[t>>2]|0;c[t>>2]=q+1;a[q]=n;c[t>>2]=(c[t>>2]|0)+(c[B>>2]|0);if((b|0)>=8){o=0;break}b=b+1|0;p=c[k>>2]|0;l=c[h>>2]|0}i=e;return o|0}function wMa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;i=i+8|0;f=e|0;g=f|0;h=f;j=b+232|0;k=c[j>>2]|0;l=b+236|0;m=c[l>>2]|0;if((m-k|0)>>>0<16>>>0){KIb(c[b>>2]|0,16,2145488,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=e;return o|0}n=f;p=k;c[f>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=k+4|0;c[j>>2]=p;if(!((d[n]|0)>>>0>(d[h+1|0]|0)>>>0)){q=b+256|0;r=b+264|0;s=0;t=0;while(1){do{if((s&3|0)==0){u=c[l>>2]|0;v=c[j>>2]|0;if((s|0)==0){w=v}else{x=u-v|0;y=x>>>0>4>>>0?4:x;nrc(n|0,v|0,y)|0;x=v+y|0;c[j>>2]=x;w=x}if((u-w|0)<4){z=0;break}c[j>>2]=w+4;u=w;z=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0}else{z=t}}while(0);u=a[h+(z&3)|0]|0;x=c[q>>2]|0;c[q>>2]=x+1;a[x]=u;u=a[h+(z>>>2&3)|0]|0;x=c[q>>2]|0;c[q>>2]=x+1;a[x]=u;u=a[h+(z>>>4&3)|0]|0;x=c[q>>2]|0;c[q>>2]=x+1;a[x]=u;u=a[h+(z>>>6&3)|0]|0;x=c[q>>2]|0;c[q>>2]=x+1;a[x]=u;u=z>>8;x=c[r>>2]|0;y=c[q>>2]|0;if((s|0)==7){c[q>>2]=y+(x*-7|0);s=s+1|0;t=u;continue}else{c[q>>2]=y+(x-4);x=s+1|0;if((x|0)<16){s=x;t=u;continue}else{o=0;break}}}i=e;return o|0}if((m-p|0)<8){A=0;B=0;C=p}else{t=k+12|0;c[j>>2]=t;k=p;p=k|0;s=k+4|0;A=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;B=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;C=t}t=f+4|0;f=t;p=m-C|0;m=p>>>0>4>>>0?4:p;nrc(f|0,C|0,m)|0;c[j>>2]=C+m;m=b+256|0;C=b+260|0;p=b+264|0;if((d[f]|0)>>>0>(d[h+5|0]|0)>>>0){D=0;E=A;F=B}else{f=0;b=A;A=B;a:while(1){B=a[h+(A&3)|0]|0;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=B;B=a[h+((A>>>2|b<<30)&3)|0]|0;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=B;B=a[h+((A>>>4|b<<28)&3)|0]|0;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=B;B=a[h+((A>>>6|b<<26)&3)|0]|0;s=c[m>>2]|0;c[m>>2]=s+1;a[s]=B;B=A>>>8|b<<24;s=b>>>8|0<<24;k=c[p>>2]|0;q=c[m>>2]|0;c[m>>2]=q+(k-4);do{if((f|0)==7){c[m>>2]=q+(k*-7|0);c[g>>2]=c[t>>2];r=c[j>>2]|0;if(((c[l>>2]|0)-r|0)<8){f=f+1|0;b=0;A=0;continue a}else{c[j>>2]=r+8;z=r;r=z|0;w=z+4|0;G=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;H=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;break}}else{G=s;H=B}}while(0);B=f+1|0;if((B|0)<16){f=B;b=G;A=H}else{o=0;break}}i=e;return o|0}while(1){H=a[h+(F&3)|0]|0;A=c[m>>2]|0;c[m>>2]=A+1;a[A]=H;H=a[h+((F>>>2|E<<30)&3)|0]|0;A=c[m>>2]|0;c[m>>2]=A+1;a[A]=H;H=a[h+((F>>>4|E<<28)&3)|0]|0;A=c[m>>2]|0;c[m>>2]=A+1;a[A]=H;H=a[h+((F>>>6|E<<26)&3)|0]|0;A=c[m>>2]|0;c[m>>2]=A+1;a[A]=H;H=F>>>8|E<<24;A=E>>>8|0<<24;if((D&1|0)!=0){c[m>>2]=(c[m>>2]|0)+(c[C>>2]|0)}do{if((D|0)==7){c[g>>2]=c[t>>2];G=c[j>>2]|0;if(((c[l>>2]|0)-G|0)<8){I=0;J=0;break}c[j>>2]=G+8;b=G;G=b|0;f=b+4|0;I=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;J=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0}else{I=A;J=H}}while(0);H=D+1|0;if((H|0)<16){D=H;E=I;F=J}else{o=0;break}}i=e;return o|0}function xMa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+256|0;d=a+236|0;e=a+232|0;f=a+264|0;a=0;g=c[b>>2]|0;h=c[e>>2]|0;do{i=(c[d>>2]|0)-h|0;j=i>>>0>8>>>0?8:i;nrc(g|0,h|0,j)|0;h=(c[e>>2]|0)+j|0;c[e>>2]=h;g=(c[b>>2]|0)+(c[f>>2]|0)|0;c[b>>2]=g;a=a+1|0;}while((a|0)<8);return 0}function yMa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b+236|0;e=b+232|0;f=b+264|0;g=b+256|0;b=0;do{h=c[e>>2]|0;if(((c[d>>2]|0)-h|0)<1){i=0}else{c[e>>2]=h+1;i=a[h]|0}a[(c[g>>2]|0)+((c[f>>2]|0)+1)|0]=i;a[(c[g>>2]|0)+(c[f>>2]|0)|0]=i;a[(c[g>>2]|0)+1|0]=i;a[c[g>>2]|0]=i;h=c[e>>2]|0;if(((c[d>>2]|0)-h|0)<1){j=0}else{c[e>>2]=h+1;j=a[h]|0}a[(c[g>>2]|0)+((c[f>>2]|0)+3)|0]=j;a[(c[g>>2]|0)+((c[f>>2]|0)+2)|0]=j;a[(c[g>>2]|0)+3|0]=j;a[(c[g>>2]|0)+2|0]=j;h=c[e>>2]|0;if(((c[d>>2]|0)-h|0)<1){k=0}else{c[e>>2]=h+1;k=a[h]|0}a[(c[g>>2]|0)+((c[f>>2]|0)+5)|0]=k;a[(c[g>>2]|0)+((c[f>>2]|0)+4)|0]=k;a[(c[g>>2]|0)+5|0]=k;a[(c[g>>2]|0)+4|0]=k;h=c[e>>2]|0;if(((c[d>>2]|0)-h|0)<1){l=0}else{c[e>>2]=h+1;l=a[h]|0}a[(c[g>>2]|0)+((c[f>>2]|0)+7)|0]=l;a[(c[g>>2]|0)+((c[f>>2]|0)+6)|0]=l;a[(c[g>>2]|0)+7|0]=l;a[(c[g>>2]|0)+6|0]=l;c[g>>2]=(c[g>>2]|0)+(c[f>>2]<<1);b=b+2|0;}while((b|0)<8);return 0}function zMa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=b+232|0;f=b+236|0;if(((c[f>>2]|0)-(c[e>>2]|0)|0)>>>0<4>>>0){KIb(c[b>>2]|0,16,2172888,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1094995529;i=d;return h|0}g=b+256|0;j=b+264|0;b=0;k=0;l=0;while(1){do{if((b&3|0)==0){m=c[e>>2]|0;n=c[f>>2]|0;if((n-m|0)<1){o=0;p=m}else{q=m+1|0;c[e>>2]=q;o=a[m]|0;p=q}if((n-p|0)<1){r=o;s=0;break}c[e>>2]=p+1;r=o;s=a[p]|0}else{r=l;s=k}}while(0);mrc(c[g>>2]|0,r|0,4)|0;mrc((c[g>>2]|0)+4|0,s|0,4)|0;c[g>>2]=(c[g>>2]|0)+(c[j>>2]|0);n=b+1|0;if((n|0)<8){b=n;k=s;l=r}else{h=0;break}}i=d;return h|0}function AMa(b,d){b=b|0;d=d|0;var e=0,f=0;d=b+232|0;e=c[d>>2]|0;if(((c[b+236>>2]|0)-e|0)<1){f=0}else{c[d>>2]=e+1;f=a[e]|0}e=b+256|0;d=b+264|0;mrc(c[e>>2]|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;mrc(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;mrc(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;mrc(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;mrc(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;mrc(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;mrc(b|0,f|0,8)|0;b=(c[e>>2]|0)+(c[d>>2]|0)|0;c[e>>2]=b;mrc(b|0,f|0,8)|0;c[e>>2]=(c[e>>2]|0)+(c[d>>2]|0);return 0}function BMa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;e=d|0;f=b+232|0;g=c[f>>2]|0;h=c[b+236>>2]|0;if((h-g|0)<1){j=0;k=g}else{l=g+1|0;c[f>>2]=l;j=a[g]|0;k=l}a[e|0]=j;if((h-k|0)<1){m=0}else{c[f>>2]=k+1;m=a[k]|0}a[e+1|0]=m;m=b+256|0;k=b+260|0;b=0;f=c[m>>2]|0;do{h=b&1;j=a[e+h|0]|0;l=a[e+(h^1)|0]|0;c[m>>2]=f+1;a[f]=j;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=l;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=j;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=l;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=j;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=l;h=c[m>>2]|0;c[m>>2]=h+1;a[h]=j;j=c[m>>2]|0;c[m>>2]=j+1;a[j]=l;f=(c[m>>2]|0)+(c[k>>2]|0)|0;c[m>>2]=f;b=b+1|0;}while((b|0)<8);i=d;return 0}function CMa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=a+4|0;e=c[d>>2]|0;if((c[e+688>>2]&1|0)==0){i=b;return}f=c[a+9960>>2]|0;g=(BLb(c[a+9992>>2]|0)|0)<<24>>24;h=c[a+14132>>2]|0;j=1-(c[a+12472>>2]|0)|0;k=(c[a+13788>>2]|0)!=0?2603600:10230472;l=(c[a+13816>>2]|0)!=0?2362312:10230472;m=(c[a+10052>>2]|0)!=0?2297592:10230472;n=(c[a+40>>2]|0)!=0?2246792:10230472;o=(c[a+228>>2]|0)!=0?2205016:10230472;p=(c[a+13828>>2]|0)!=0?2172880:10230472;q=(c[a+13832>>2]|0)!=0?2145480:10230472;r=(c[a+13836>>2]|0)!=0?2121720:10230472;s=(c[a+13824>>2]|0)!=0?2639240:10230472;a=c[d>>2]|0;d=c[a+108>>2]|0;t=c[a+104>>2]|0;KIb(e,48,2528184,(e=i,i=i+120|0,c[e>>2]=f,c[e+8>>2]=g,c[e+16>>2]=h,c[e+24>>2]=j,c[e+32>>2]=k,c[e+40>>2]=l,c[e+48>>2]=m,c[e+56>>2]=n,c[e+64>>2]=o,c[e+72>>2]=p,c[e+80>>2]=q,c[e+88>>2]=r,c[e+96>>2]=s,c[e+104>>2]=d,c[e+112>>2]=t,e)|0);i=e;i=b;return}function DMa(){var a=0;if((c[2093350]|0)!=0){return}c[2055815]=8231288;c[2055817]=72;$2(8223256,6,9,1379080,1,1,1379064,1,1,0,0,0,4)|0;c[2055821]=8230496;c[2055823]=198;$2(8223280,7,28,1379128,1,1,1379096,1,1,0,0,0,4)|0;c[2093353]=8230240;c[2093355]=64;$2(8373408,6,16,1379529,2,1,1379528,2,1,0,0,0,4)|0;c[1371171]=8228088;c[1371173]=538;$2(5484680,9,33,1339809,2,1,1339808,2,1,0,0,0,4)|0;ATa(1378528,8222472);ATa(1316048,8222862);c[344644]=8225872;c[344646]=554;a=c[344634]|0;$2(1378572,9,(c[344632]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[344648]|0)==0){a=0;do{c[1378592+(a<<2)>>2]=8302488+(a*2216|0);a=a+1|0;}while((a|0)<32);BTa(1378528)}c[329024]=8223656;c[329026]=554;a=c[329014]|0;$2(1316092,9,(c[329012]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[329028]|0)==0){a=0;do{c[1316112+(a<<2)>>2]=8231576+(a*2216|0);a=a+1|0;}while((a|0)<32);BTa(1316048)}c[1487661]=8223336;c[1487663]=80;$2(5950640,6,15,1379001,2,1,1379e3,2,1,0,0,0,4)|0;c[2467041]=8223304;c[2467043]=8;$2(9868160,3,4,1412969,2,1,1412968,2,1,0,0,0,4)|0;c[2093350]=1;return}function EMa(a){a=a|0;var b=0,f=0,g=0,h=0,i=0;b=a+144|0;f=0;while(1){if((f|0)>=6){break}if(((c[b>>2]|0)-1|0)>(e[1358712+(f<<1)>>1]|0|0)){f=f+1|0}else{break}}b=d[1358728+f|0]|0;f=a+14128|0;g=c[f>>2]|0;h=(c[a+14120>>2]|0)+(g>>>3)|0;i=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(g&7)>>>((32-b|0)>>>0);c[f>>2]=g+b;b=c[a+116>>2]|0;c[a+12476>>2]=(i|0)%(b|0)|0;c[a+12480>>2]=(i|0)/(b|0)|0;return i|0}function FMa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+24|0;e=b|0;f=a+48|0;g=(c[f>>2]|0)==13;h=a+14128|0;j=c[h>>2]|0;do{if(g){k=j+1|0;c[h>>2]=k;l=j&7;if((l|0)==7){m=k;break}n=(l^7)+k|0;c[h>>2]=n;m=n}else{m=j}}while(0);j=a+14120|0;h=j|0;n=a+14128|0;k=(c[h>>2]|0)+(m>>>3)|0;do{if(((je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)&-65536>>>((m&7)>>>0)|0)==0){if(g){o=NRa(c[(c[a+4>>2]|0)+60>>2]|0)|0}else{o=GMa(a)|0}if((o|0)>-1){p=m}else{break}i=b;return p|0}}while(0);m=j;j=a+13712|0;c[m>>2]=c[j>>2];c[m+4>>2]=c[j+4>>2];c[m+8>>2]=c[j+8>>2];c[m+12>>2]=c[j+12>>2];c[m+16>>2]=c[j+16>>2];j=c[n>>2]|0;o=-j&7;if((o|0)==0){q=j}else{g=o+j|0;c[n>>2]=g;q=g}g=(c[a+14132>>2]|0)-q|0;if((g|0)<=27){p=-1;i=b;return p|0}j=e;e=a+4|0;o=g;g=q;while(1){q=(c[h>>2]|0)+(g>>>3)|0;if(((je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)&-65536>>>((g&7)>>>0)|0)==0){c[j>>2]=c[m>>2];c[j+4>>2]=c[m+4>>2];c[j+8>>2]=c[m+8>>2];c[j+12>>2]=c[m+12>>2];c[j+16>>2]=c[m+16>>2];if((c[f>>2]|0)==13){r=NRa(c[(c[e>>2]|0)+60>>2]|0)|0}else{r=GMa(a)|0}if((r|0)>-1){p=g;s=20;break}c[m>>2]=c[j>>2];c[m+4>>2]=c[j+4>>2];c[m+8>>2]=c[j+8>>2];c[m+12>>2]=c[j+12>>2];c[m+16>>2]=c[j+16>>2];t=c[n>>2]|0}else{t=g}q=t+8|0;c[n>>2]=q;k=o-8|0;if((k|0)>27){o=k;g=q}else{p=-1;s=20;break}}if((s|0)==20){i=b;return p|0}return 0}function GMa(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[a+14120>>2]|0;f=a+14128|0;g=c[f>>2]|0;h=b+(g>>>3)|0;if(((je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)&-65536>>>((g&7)>>>0)|0)!=0){i=-1;return i|0}h=g+16|0;c[f>>2]=h;g=(c[a+14132>>2]|0)-h|0;j=h;while(1){if((g|0)<=13){i=-1;k=18;break}h=d[b+(j>>>3)|0]|0;l=j+1|0;c[f>>2]=l;if((h&128>>>((j&7)>>>0)|0)==0){g=g-1|0;j=l}else{break}}if((k|0)==18){return i|0}if((g|0)<14){i=-1;return i|0}g=b+(l>>>3)|0;do{if((c[a+13824>>2]|0)==0){k=g;h=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(l&7)>>>27;c[a+12476>>2]=0;k=ca(h,c[a+13784>>2]|0)|0;c[a+12480>>2]=k;h=j+8|0;c[f>>2]=h;m=b+(h>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7)>>>27;c[f>>2]=j+13;c[a+9960>>2]=n;o=k;p=n}else{n=d[g]|0;k=j+2|0;c[f>>2]=k;if((n&128>>>((l&7)>>>0)|0)==0){i=-1;return i|0}n=a+144|0;h=0;while(1){if((h|0)>=6){break}if(((c[n>>2]|0)-1|0)>(e[1358712+(h<<1)>>1]|0|0)){h=h+1|0}else{break}}m=d[1358728+h|0]|0;q=b+(k>>>3)|0;r=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(k&7)>>>((32-m|0)>>>0);q=k+m|0;c[f>>2]=q;m=c[a+116>>2]|0;c[a+12476>>2]=(r|0)%(m|0)|0;s=(r|0)/(m|0)|0;c[a+12480>>2]=s;do{if((c[n>>2]|0)>1583){m=d[b+(q>>>3)|0]|0;r=q+1|0;c[f>>2]=r;if((m&128>>>((q&7)>>>0)|0)==0){i=-1}else{t=r;break}return i|0}else{t=q}}while(0);q=b+(t>>>3)|0;n=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(t&7)>>>27;q=t+5|0;c[f>>2]=q;c[a+9960>>2]=n;k=d[b+(q>>>3)|0]|0;c[f>>2]=t+6;if((k&128>>>((q&7)>>>0)|0)==0){i=-1;return i|0}else{c[f>>2]=t+8;o=s;p=n;break}}}while(0);if((o|0)>=(c[a+120>>2]|0)){i=-1;return i|0}i=((p|0)==0)<<31>>31;return i|0}function HMa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=c[1371171]|0;h=a+14128|0;i=c[h>>2]|0;j=c[a+14120>>2]|0;k=j+(i>>>3)|0;l=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(i&7)>>>23;k=b[g+(l<<2)>>1]|0;m=b[g+(l<<2)+2>>1]|0;l=m<<16>>16;if(m<<16>>16<0){m=i+9|0;n=j+(m>>>3)|0;o=((je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(m&7)>>>((l+32|0)>>>0))+k|0;p=b[g+(o<<2)+2>>1]|0;q=m;r=b[g+(o<<2)>>1]|0}else{p=l;q=i;r=k}k=p+q|0;c[h>>2]=k;if((r|0)==0){s=e;return s|0}if((r|0)<0){s=65535;return s|0}q=d[j+(k>>>3)|0]|0;p=k+1|0;c[h>>2]=p;i=f-1|0;if((i|0)==0){t=r}else{l=j+(p>>>3)|0;j=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(p&7)>>>((33-f|0)>>>0);c[h>>2]=k+f;t=(j|r-1<<i)+1|0}i=((q&128>>>((k&7)>>>0)|0)==0?t:-t|0)+e|0;if((c[a+10052>>2]|0)==0){a=27-f|0;s=i<<a>>a;return s|0}a=(e|0)<-31&(i|0)<-63?i+64|0:i;if(!((e|0)>32&(a|0)>63)){s=a;return s|0}s=a-64|0;return s|0}function IMa(a){a=a|0;var b=0,e=0,f=0;b=a+8|0;e=c[b>>2]|0;f=(d[(c[a>>2]|0)+(e>>>3)|0]|0)<<(e&7)>>>7;c[b>>2]=e+1;return f&1|0}function JMa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;f=i;i=i+232|0;g=f|0;h=f+128|0;j=f+152|0;k=f+176|0;l=f+184|0;m=f+192|0;n=f+200|0;o=f+208|0;p=f+216|0;q=f+224|0;r=a+12476|0;s=c[r>>2]|0;t=a+12480|0;u=c[t>>2]|0;v=a+124|0;w=(ca(c[v>>2]|0,u)|0)+s|0;c[q>>2]=0;x=a+9992|0;y=c[x>>2]|0;a:do{if((y|0)==3){z=c[a+128>>2]|0;A=(ca(u,z)|0)+s<<1;B=c[a+9148>>2]|0;C=c[a+9152>>2]|0;D=z<<1;z=D+3|0;b[C+(A<<2)+(z<<1)>>1]=0;E=D|1;b[C+(A<<2)+(E<<1)>>1]=0;b[C+(A<<2)+6>>1]=0;b[C+(A<<2)+2>>1]=0;F=D+2|0;b[C+(A<<2)+(F<<1)>>1]=0;b[C+(A<<2)+(D<<1)>>1]=0;b[C+(A<<2)+4>>1]=0;b[C+(A<<2)>>1]=0;b[B+(A<<2)+(z<<1)>>1]=0;b[B+(A<<2)+(E<<1)>>1]=0;b[B+(A<<2)+6>>1]=0;b[B+(A<<2)+2>>1]=0;b[B+(A<<2)+(F<<1)>>1]=0;b[B+(A<<2)+(D<<1)>>1]=0;b[B+(A<<2)+4>>1]=0;b[B+(A<<2)>>1]=0;A=a+14128|0;B=a+14120|0;C=c[1487661]|0;G=c[B>>2]|0;H=c[A>>2]|0;do{I=G+(H>>>3)|0;J=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(H&7)>>>26;I=b[C+(J<<2)>>1]|0;K=b[C+(J<<2)+2>>1]|0;J=K<<16>>16;if(K<<16>>16<0){K=H+6|0;L=G+(K>>>3)|0;M=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(K&7)>>>((J+32|0)>>>0))+I|0;N=b[C+(M<<2)+2>>1]|0;O=K;P=b[C+(M<<2)>>1]|0}else{N=J;O=H;P=I}H=N+O|0;c[A>>2]=H;if((P|0)<0){Q=48;break}R=c[1145808+(P<<2)>>2]|0;}while((P|0)==12);if((Q|0)==48){KIb(c[a+4>>2]|0,16,2468744,(S=i,i=i+16|0,c[S>>2]=s,c[S+8>>2]=u,S)|0);i=S;T=-1;i=f;return T|0}H=a+12488|0;c[H>>2]=R&7;do{if((28086>>>(P>>>0)&1|0)==0){U=0}else{qe[c[a+10096>>2]&1023](c[a+14340>>2]|0);C=c[2467041]|0;G=c[A>>2]|0;I=c[B>>2]|0;J=I+(G>>>3)|0;M=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(G&7)>>>29;J=b[C+(M<<2)>>1]|0;K=(b[C+(M<<2)+2>>1]|0)+G|0;c[A>>2]=K;if((c[H>>2]|0)!=0){V=J;W=R&65536;Q=71;break a}G=c[2093353]|0;M=I+(K>>>3)|0;I=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>26;M=b[G+(I<<2)>>1]|0;C=M<<16>>16;c[A>>2]=(b[G+(I<<2)+2>>1]|0)+K;if(!(M<<16>>16<0)){M=J&3;J=(c[a+13828>>2]|0)!=0&(M|0)==3;U=(J?C:C^15)<<2|(J?3:M);break}M=c[t>>2]|0;KIb(c[a+4>>2]|0,16,2459512,(S=i,i=i+16|0,c[S>>2]=c[r>>2],c[S+8>>2]=M,S)|0);i=S;T=-1;i=f;return T|0}}while(0);if((18724>>>(P>>>0)&1|0)!=0){LMa(a)}A=a+11736|0;do{if(P>>>0<3>>>0){c[A>>2]=7;X=HRa(a,0,0)|0|R}else{c[A>>2]=0;c[a+11740>>2]=0;if((3647>>>(P>>>0)&1|0)!=0){H=Rga(a,0,0,o,p)|0;c[A>>2]=1;c[o>>2]=HMa(a,c[o>>2]|0,1)|0;B=HMa(a,c[p>>2]|0,1)|0;c[p>>2]=B;M=c[o>>2]|0;c[a+11744>>2]=M;c[a+11748>>2]=B;J=M&65535;b[H+(F<<1)>>1]=J;b[H+(D<<1)>>1]=J;b[H+4>>1]=J;b[H>>1]=J;J=B&65535;b[H+(z<<1)>>1]=J;b[H+(E<<1)>>1]=J;b[H+6>>1]=J;b[H+2>>1]=J}if((4039>>>(P>>>0)&1|0)==0){X=R;break}J=Rga(a,0,1,o,p)|0;c[A>>2]=c[A>>2]|2;c[o>>2]=HMa(a,c[o>>2]|0,1)|0;H=HMa(a,c[p>>2]|0,1)|0;c[p>>2]=H;B=c[o>>2]|0;c[a+11776>>2]=B;c[a+11780>>2]=H;M=B&65535;b[J+(F<<1)>>1]=M;b[J+(D<<1)>>1]=M;b[J+4>>1]=M;b[J>>1]=M;M=H&65535;b[J+(z<<1)>>1]=M;b[J+(E<<1)>>1]=M;b[J+6>>1]=M;b[J+2>>1]=M;X=R}}while(0);c[(c[a+9160>>2]|0)+(w<<2)>>2]=X;Y=U;Q=85}else if((y|0)==2){E=a+14120|0;z=a+14128|0;D=E|0;F=c[D>>2]|0;A=c[z>>2]|0;while(1){M=d[F+(A>>>3)|0]|0;J=A+1|0;c[z>>2]=J;if((M&128>>>((A&7)>>>0)|0)!=0){Q=5;break}M=c[2055821]|0;H=F+(J>>>3)|0;B=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>25;H=b[M+(B<<2)>>1]|0;C=b[M+(B<<2)+2>>1]|0;B=C<<16>>16;if(C<<16>>16<0){C=A+8|0;K=F+(C>>>3)|0;I=((je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(C&7)>>>((B+32|0)>>>0))+H|0;Z=b[M+(I<<2)+2>>1]|0;_=C;$=b[M+(I<<2)>>1]|0}else{Z=B;_=J;$=H}H=Z+_|0;c[z>>2]=H;if(($|0)<0){Q=9;break}if(($|0)==20){A=H}else{Q=11;break}}if((Q|0)==5){c[a+12488>>2]=0;mrc(a+180|0,-1|0,24)|0;c[a+11736>>2]=1;c[a+11740>>2]=0;c[(c[a+9160>>2]|0)+(w<<2)>>2]=14344;c[a+11744>>2]=0;c[a+11748>>2]=0;c[a+9924>>2]=(c[a+13836>>2]|c[a+13788>>2]|0)==0;break}else if((Q|0)==9){KIb(c[a+4>>2]|0,16,2478344,(S=i,i=i+16|0,c[S>>2]=s,c[S+8>>2]=u,S)|0);i=S;T=-1;i=f;return T|0}else if((Q|0)==11){qe[c[a+10096>>2]&1023](c[a+14340>>2]|0);A=$&8;F=$&4;c[a+12488>>2]=F>>>2;if((F|0)!=0){V=$;W=A;Q=71;break}F=c[a+36>>2]|0;do{if((F|0)==0){aa=0}else{H=c[z>>2]|0;J=d[(c[D>>2]|0)+(H>>>3)|0]|0;c[z>>2]=H+1;if((J&128>>>((H&7)>>>0)|0)==0){aa=0;break}aa=KMa(E,F,q)|0}}while(0);F=c[2093353]|0;E=c[z>>2]|0;H=(c[D>>2]|0)+(E>>>3)|0;J=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>26;H=b[F+(J<<2)>>1]|0;c[z>>2]=(b[F+(J<<2)+2>>1]|0)+E;E=$&3;J=(c[a+13828>>2]|0)!=0&(E|0)==3;F=(J?H:H^15)<<2|(J?3:E);if((A|0)!=0){LMa(a)}c[a+11736>>2]=1;E=(c[a+9160>>2]|0)+(w<<2)|0;if(($&16|0)==0){c[E>>2]=12296;c[a+11740>>2]=0;Rga(a,0,0,m,n)|0;J=a+13816|0;H=c[m>>2]|0;if((c[J>>2]|0)==0){ba=HMa(a,H,1)|0}else{ba=MMa(a,H)|0}c[o>>2]=ba;if((ba|0)>65534){T=-1;i=f;return T|0}H=c[n>>2]|0;if((c[J>>2]|0)==0){da=HMa(a,H,1)|0}else{da=MMa(a,H)|0}c[p>>2]=da;if((da|0)>65534){T=-1;i=f;return T|0}H=c[o>>2]|0;c[a+11744>>2]=H;c[a+11748>>2]=da;if((c[J>>2]|0)==0){ea=F;fa=aa;Q=84;break}if((H-(c[m>>2]|0)|0)!=1){ea=F;fa=aa;Q=84;break}if((da-(c[n>>2]|0)|0)!=1){ea=F;fa=aa;Q=84;break}c[z>>2]=(c[z>>2]|0)+1;ea=F;fa=aa;Q=84;break}c[E>>2]=12352;c[a+11740>>2]=1;E=a+13816|0;H=0;while(1){J=Rga(a,H,0,m,n)|0;B=c[m>>2]|0;if((c[E>>2]|0)==0){ga=HMa(a,B,1)|0}else{ga=MMa(a,B)|0}c[o>>2]=ga;if((ga|0)>65534){T=-1;Q=138;break}B=c[n>>2]|0;if((c[E>>2]|0)==0){ha=HMa(a,B,1)|0}else{ha=MMa(a,B)|0}c[p>>2]=ha;if((ha|0)>65534){T=-1;Q=138;break}B=c[o>>2]|0;c[a+11744+(H<<3)>>2]=B;c[a+11744+(H<<3)+4>>2]=ha;do{if((c[E>>2]|0)!=0){if((B-(c[m>>2]|0)|0)!=1){break}if((ha-(c[n>>2]|0)|0)!=1){break}c[z>>2]=(c[z>>2]|0)+1}}while(0);b[J>>1]=B;b[J+2>>1]=ha;I=H+1|0;if((I|0)<4){H=I}else{ea=F;fa=aa;Q=84;break a}}if((Q|0)==138){i=f;return T|0}}}else{F=a+14128|0;H=c[2055815]|0;z=c[a+14120>>2]|0;E=c[F>>2]|0;while(1){A=z+(E>>>3)|0;D=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(E&7)>>>26;A=b[H+(D<<2)>>1]|0;I=b[H+(D<<2)+2>>1]|0;D=I<<16>>16;if(I<<16>>16<0){I=E+6|0;M=z+(I>>>3)|0;C=((je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(I&7)>>>((D+32|0)>>>0))+A|0;ia=b[H+(C<<2)+2>>1]|0;ja=I;ka=b[H+(C<<2)>>1]|0}else{ia=D;ja=E;ka=A}A=ia+ja|0;c[F>>2]=A;if((ka|0)<0){break}if((ka|0)==8){E=A}else{Q=70;break}}if((Q|0)==70){qe[c[a+10096>>2]&1023](c[a+14340>>2]|0);c[a+12488>>2]=1;V=ka;W=ka&4;Q=71;break}KIb(c[a+4>>2]|0,16,2442856,(S=i,i=i+16|0,c[S>>2]=s,c[S+8>>2]=u,S)|0);i=S;T=-1;i=f;return T|0}}while(0);if((Q|0)==71){u=(c[a+9160>>2]|0)+(w<<2)|0;c[u>>2]=1;do{if((c[a+228>>2]|0)==0){c[a+176>>2]=0}else{w=a+14128|0;s=c[w>>2]|0;ka=c[a+14120>>2]|0;ja=d[ka+(s>>>3)|0]<<(s&7)>>>7;c[w>>2]=s+1;s=ja&1;c[a+176>>2]=s;if((s|0)==0){break}c[u>>2]=513;s=c[w>>2]|0;ja=d[ka+(s>>>3)|0]<<(s&7)>>>7;c[w>>2]=s+1;c[a+13820>>2]=ja&1}}while(0);u=a+36|0;ja=c[u>>2]|0;do{if((ja|0)==0){la=0;ma=a+14128|0}else{s=a+14120|0;w=a+14128|0;ka=c[w>>2]|0;ia=d[(c[s>>2]|0)+(ka>>>3)|0]|0;c[w>>2]=ka+1;if((ia&128>>>((ka&7)>>>0)|0)==0){la=0;ma=w;break}la=KMa(s,ja,q)|0;ma=w}}while(0);ja=c[2093353]|0;w=c[ma>>2]|0;s=(c[a+14120>>2]|0)+(w>>>3)|0;ka=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7)>>>26;s=b[ja+(ka<<2)>>1]|0;c[ma>>2]=(b[ja+(ka<<2)+2>>1]|0)+w;if(s<<16>>16<0){w=c[t>>2]|0;KIb(c[a+4>>2]|0,16,2430600,(S=i,i=i+16|0,c[S>>2]=c[r>>2],c[S+8>>2]=w,S)|0);i=S;T=-1;i=f;return T|0}if((W|0)!=0){LMa(a)}ea=s<<16>>16<<2|V&3;fa=((c[u>>2]|0)!=0)+la|0;Q=84}do{if((Q|0)==84){if((fa|0)==0){Y=ea;Q=85;break}else{na=fa}while(1){la=na-1|0;HMa(a,0,1)|0;HMa(a,0,1)|0;if((la|0)==0){Y=ea;Q=85;break}else{na=la}}}}while(0);do{if((Q|0)==85){if((NMa(a,e|0,0,Y&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,e+128|0,1,Y<<1&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,e+256|0,2,Y<<2&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,e+384|0,3,Y<<3&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,e+512|0,4,Y<<4&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,e+640|0,5,Y<<5&32)|0)<0){T=-1;i=f;return T|0}do{if((c[a+36>>2]|0)!=0){na=c[q>>2]|0;ea=h;fa=g|0;la=a+12488|0;u=c[la>>2]|0;V=a+180|0;c[ea>>2]=c[V>>2];c[ea+4>>2]=c[V+4>>2];c[ea+8>>2]=c[V+8>>2];c[ea+12>>2]=c[V+12>>2];c[ea+16>>2]=c[V+16>>2];c[ea+20>>2]=c[V+20>>2];c[la>>2]=0;if((NMa(a,fa,0,na&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,fa,1,na<<1&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,fa,2,na<<2&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,fa,3,na<<3&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,fa,4,na<<4&32)|0)<0){T=-1;i=f;return T|0}if((NMa(a,fa,5,na<<5&32)|0)<0){T=-1;i=f;return T|0}else{c[la>>2]=u;c[V>>2]=c[ea>>2];c[V+4>>2]=c[ea+4>>2];c[V+8>>2]=c[ea+8>>2];c[V+12>>2]=c[ea+12>>2];c[V+16>>2]=c[ea+16>>2];c[V+20>>2]=c[ea+20>>2];break}}}while(0);if((c[a+13788>>2]|0)==0){break}if((c[a+12488>>2]|0)!=0){break}if((c[x>>2]|0)!=2){break}ea=(c[r>>2]|0)+1|0;if((ea|0)>=(c[a+116>>2]|0)){break}if((c[a+13732>>2]|0)==1){break}V=j;u=a+14120|0;la=u;c[V>>2]=c[la>>2];c[V+4>>2]=c[la+4>>2];c[V+8>>2]=c[la+8>>2];c[V+12>>2]=c[la+12>>2];c[V+16>>2]=c[la+16>>2];na=ca(c[v>>2]|0,c[t>>2]|0)|0;fa=c[a+128>>2]|0;s=a+12496|0;W=(c[s>>2]|0)+2|0;c[s>>2]=W;S=a+12500|0;c[S>>2]=(c[S>>2]|0)+2;w=a+12504|0;c[w>>2]=(c[w>>2]|0)+2;ka=a+12508|0;c[ka>>2]=(c[ka>>2]|0)+2;ja=na+ea|0;na=fa<<1;fa=a+12512|0;c[fa>>2]=(c[fa>>2]|0)+1;ma=a+12516|0;c[ma>>2]=(c[ma>>2]|0)+1;c[r>>2]=ea;ea=a+14128|0;ia=c[u>>2]|0;u=c[ea>>2]|0;while(1){aa=d[ia+(u>>>3)|0]|0;ha=u+1|0;c[ea>>2]=ha;if((aa&128>>>((u&7)>>>0)|0)!=0){Q=102;break}aa=c[2055821]|0;n=ia+(ha>>>3)|0;m=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(ha&7)>>>25;n=b[aa+(m<<2)>>1]|0;o=b[aa+(m<<2)+2>>1]|0;m=o<<16>>16;if(o<<16>>16<0){o=u+8|0;p=ia+(o>>>3)|0;ga=((je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(o&7)>>>((m+32|0)>>>0))+n|0;oa=b[aa+(ga<<2)+2>>1]|0;pa=o;qa=b[aa+(ga<<2)>>1]|0}else{oa=m;pa=ha;qa=n}ra=oa+pa|0;c[ea>>2]=ra;if((qa|0)==20){u=ra}else{Q=106;break}}do{if((Q|0)==102){u=c[a+9148>>2]|0;b[u+(W<<2)+(na+2<<1)>>1]=0;b[u+(W<<2)+(na<<1)>>1]=0;b[u+(W<<2)+4>>1]=0;b[u+(W<<2)>>1]=0;b[u+(W<<2)+(na+3<<1)>>1]=0;b[u+(W<<2)+((na|1)<<1)>>1]=0;b[u+(W<<2)+6>>1]=0;b[u+(W<<2)+2>>1]=0;c[(c[a+9160>>2]|0)+(ja<<2)>>2]=14344}else if((Q|0)==106){if((qa&4|0)!=0){c[(c[a+9160>>2]|0)+(ja<<2)>>2]=1;break}u=c[2093353]|0;n=ia+(ra>>>3)|0;ha=(b[u+((je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(ra&7)>>>26<<2)+2>>1]|0)+ra|0;c[ea>>2]=ha;do{if((qa&8|0)!=0){if((c[a+13832>>2]|0)==0){c[ea>>2]=ha+2;break}n=d[ia+(ha>>>3)|0]|0;c[ea>>2]=ha+1;if((n&128>>>((ha&7)>>>0)|0)==0){c[ea>>2]=ha+6;break}else{c[ea>>2]=ha+2;break}}}while(0);ha=(c[a+9160>>2]|0)+(ja<<2)|0;if((qa&16|0)==0){c[ha>>2]=12296;J=Rga(a,0,0,k,l)|0;B=a+13816|0;n=c[k>>2]|0;if((c[B>>2]|0)==0){sa=(HMa(a,n,1)|0)&65535}else{sa=(MMa(a,n)|0)&65535}n=c[l>>2]|0;if((c[B>>2]|0)==0){ta=(HMa(a,n,1)|0)&65535}else{ta=(MMa(a,n)|0)&65535}b[J+(na+2<<1)>>1]=sa;b[J+(na<<1)>>1]=sa;b[J+4>>1]=sa;b[J>>1]=sa;b[J+(na+3<<1)>>1]=ta;b[J+((na|1)<<1)>>1]=ta;b[J+6>>1]=ta;b[J+2>>1]=ta;break}c[ha>>2]=12352;ha=a+13816|0;J=0;do{n=Rga(a,J,0,k,l)|0;B=c[k>>2]|0;if((c[ha>>2]|0)==0){ua=HMa(a,B,1)|0}else{ua=MMa(a,B)|0}B=c[l>>2]|0;if((c[ha>>2]|0)==0){va=HMa(a,B,1)|0}else{va=MMa(a,B)|0}do{if((c[ha>>2]|0)!=0){if((ua-(c[k>>2]|0)|0)!=1){break}if((va-(c[l>>2]|0)|0)!=1){break}c[ea>>2]=(c[ea>>2]|0)+1}}while(0);b[n>>1]=ua;b[n+2>>1]=va;J=J+1|0;}while((J|0)<4)}}while(0);c[s>>2]=(c[s>>2]|0)-2;c[S>>2]=(c[S>>2]|0)-2;c[w>>2]=(c[w>>2]|0)-2;c[ka>>2]=(c[ka>>2]|0)-2;c[fa>>2]=(c[fa>>2]|0)-1;c[ma>>2]=(c[ma>>2]|0)-1;c[r>>2]=(c[r>>2]|0)-1;c[la>>2]=c[V>>2];c[la+4>>2]=c[V+4>>2];c[la+8>>2]=c[V+8>>2];c[la+12>>2]=c[V+12>>2];c[la+16>>2]=c[V+16>>2];}}while(0);r=c[a+14128>>2]|0;va=(c[a+14120>>2]|0)+(r>>>3)|0;ua=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(r&7)>>>16;va=(c[a+14132>>2]|0)-r|0;if((va|0)<16){wa=ua>>>((16-va|0)>>>0)}else{wa=ua}T=(wa|0)==0?-2:0;i=f;return T|0}function KMa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=a+8|0;do{if((b|0)<3){g=c[f>>2]|0;h=c[a>>2]|0;i=(d[h+(g>>>3)|0]|0)<<(g&7)>>>7;j=g+1|0;c[f>>2]=j;k=i&1;if((b|0)!=2|(k|0)==0){l=1;m=k;break}i=(d[h+(j>>>3)|0]|0)<<(j&7);c[f>>2]=g+2;l=i>>>7&1^1;m=k}else{k=a|0;i=0;while(1){if((i|0)>=4){n=6;break}g=c[f>>2]|0;j=d[(c[k>>2]|0)+(g>>>3)|0]|0;c[f>>2]=g+1;h=i+1|0;if((j&128>>>((g&7)>>>0)|0)==0){o=h;break}else{i=h}}if((n|0)==6){o=i+1|0}l=o>>>1&1;m=o&1}}while(0);if((m|0)==0){return l|0}m=c[f>>2]|0;o=(c[a>>2]|0)+(m>>>3)|0;a=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(m&7)>>>26;c[f>>2]=m+6;c[e>>2]=a;return l|0}function LMa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b+14120|0;f=b+14128|0;g=c[f>>2]|0;if((c[b+13832>>2]|0)==0){h=(c[e>>2]|0)+(g>>>3)|0;i=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(g&7)>>>30;c[f>>2]=g+2;h=b+9960|0;j=(c[h>>2]|0)+(a[1145920+i|0]|0)|0;c[h>>2]=j;k=j;QTa(b,k);return}j=c[e>>2]|0;e=d[j+(g>>>3)|0]|0;h=g+1|0;c[f>>2]=h;if((e&128>>>((g&7)>>>0)|0)==0){e=j+(h>>>3)|0;i=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(h&7)>>>27;c[f>>2]=g+6;c[b+9960>>2]=i;k=i;QTa(b,k);return}else{i=b+9960|0;e=c[i>>2]|0;l=d[j+(h>>>3)|0]<<(h&7)>>>7;c[f>>2]=g+2;g=d[1351960+((l&1)<<5)+e|0]|0;c[i>>2]=g;k=g;QTa(b,k);return}}function MMa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a+14120|0;f=a+14128|0;a=c[f>>2]|0;g=e|0;h=d[(c[g>>2]|0)+(a>>>3)|0]|0;c[f>>2]=a+1;if((h&128>>>((a&7)>>>0)|0)!=0){i=b;return i|0}a=(IMa(e)|0)+2|0;if((IMa(e)|0)==0){j=a}else{h=a;while(1){a=c[f>>2]|0;k=(d[(c[g>>2]|0)+(a>>>3)|0]|0)<<(a&7)>>>7;c[f>>2]=a+1;a=k&1|h<<1;if((IMa(e)|0)==0){j=a;break}else{h=a}}}h=j>>1;i=((j&1|0)!=0?-h|0:h)+b|0;return i|0}function NMa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+48|0;k=j|0;l=j+8|0;m=j+16|0;n=e+14120|0;o=j+24|0;p=n;c[o>>2]=c[p>>2];c[o+4>>2]=c[p+4>>2];c[o+8>>2]=c[p+8>>2];c[o+12>>2]=c[p+12>>2];c[o+16>>2]=c[p+16>>2];q=e+368|0;r=e+228|0;s=(c[e+12488>>2]|0)==0;do{if((c[r>>2]|0)==0){if(s){t=0;u=q;v=1378528;break}a:do{if((c[e+48>>2]|0)==6){do{if((c[e+14028>>2]|0)==3){if((c[e+9992>>2]|0)!=1){break}w=(g|0)<4?0:g-3|0;x=e+9860+(w<<2)|0;y=c[x>>2]|0;c[k>>2]=y;z=e+14032+(w<<2)|0;if((c[z>>2]|0)==0){c[z>>2]=1;A=y&65535;break a}y=OZa(e,g)|0;if((y|0)==65535){B=-1;i=j;return B|0}else{z=(c[k>>2]|0)+y&255;c[k>>2]=z;c[x>>2]=z;A=z&65535;break a}}}while(0);z=e+14128|0;x=c[z>>2]|0;y=(c[n>>2]|0)+(x>>>3)|0;w=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>24;c[z>>2]=x+8;c[k>>2]=w;if((w|0)!=255){A=w&65535;break}c[k>>2]=128;A=128}else{w=e+14128|0;x=c[w>>2]|0;z=(c[n>>2]|0)+(x>>>3)|0;y=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>24;c[w>>2]=x+8;c[k>>2]=y;do{if((y&127|0)==0){x=c[e+12476>>2]|0;w=c[e+12480>>2]|0;KIb(c[e+4>>2]|0,16,2285304,(C=i,i=i+24|0,c[C>>2]=y,c[C+8>>2]=x,c[C+16>>2]=w,C)|0);i=C;if((c[e+13740>>2]&131074|0)==0){D=c[k>>2]|0;break}else{B=-1;i=j;return B|0}}else{D=y}}while(0);if((D|0)!=255){A=D&65535;break}c[k>>2]=128;A=128}}while(0);b[f>>1]=A;t=1;u=q;v=1378528}else{if(s){t=0;u=q;v=1378528;break}if((c[e+176>>2]|0)==0){t=0;u=q;v=1316048;break}if((c[e+13820>>2]|0)==0){t=0;u=e+500|0;v=1316048;break}else{t=0;u=e+632|0;v=1316048;break}}}while(0);do{if((h|0)==0){if((c[e+12488>>2]|0)!=0){if((c[r>>2]|0)!=0){E=51;break}}c[e+180+(g<<2)>>2]=t-1;B=0;i=j;return B|0}else{q=e+14128|0;s=n|0;A=e+44|0;D=e+48|0;y=e+13828|0;w=e+12488|0;x=e+10092|0;z=t;F=v;b:while(1){G=F+48|0;H=F|0;I=F+12|0;J=F+16|0;K=F+4|0;L=z;while(1){M=c[G>>2]|0;N=c[q>>2]|0;O=c[s>>2]|0;P=O+(N>>>3)|0;Q=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(N&7)>>>23;P=b[M+(Q<<2)>>1]|0;R=b[M+(Q<<2)+2>>1]|0;Q=R<<16>>16;if(R<<16>>16<0){R=N+9|0;S=O+(R>>>3)|0;T=((je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(R&7)>>>((Q+32|0)>>>0))+P|0;U=b[M+(T<<2)+2>>1]|0;V=R;W=b[M+(T<<2)>>1]|0}else{U=Q;V=N;W=P}P=U+V|0;c[q>>2]=P;if((W|0)<0){E=31;break b}do{if((W|0)==(c[H>>2]|0)){if((c[A>>2]|0)>1){tfa(n,k,m,l);X=c[m>>2]|0;break}N=d[O+(P>>>3)|0]<<(P&7)>>>7;Q=P+1|0;c[q>>2]=Q;c[l>>2]=N&1;N=O+(Q>>>3)|0;T=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Q&7)>>>26;Q=P+7|0;c[q>>2]=Q;c[m>>2]=T;N=O+(Q>>>3)|0;M=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Q&7);Q=P+15|0;c[q>>2]=Q;N=M>>24;c[k>>2]=N;if(!((N|0)==-128)){X=T;break}N=(c[D>>2]|0)==6;M=O+(Q>>>3)|0;R=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Q&7);if(N){c[q>>2]=P+27;c[k>>2]=R>>20;X=T;break}else{N=R>>>27;R=P+20|0;c[q>>2]=R;c[k>>2]=N;Q=O+(R>>>3)|0;M=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(R&7)>>26;c[q>>2]=P+26;c[k>>2]=M<<5|N;X=T;break}}else{T=a[(c[I>>2]|0)+W|0]|0;c[m>>2]=T;N=a[(c[J>>2]|0)+W|0]|0;c[k>>2]=N;c[l>>2]=(W|0)>=(c[K>>2]|0);M=d[O+(P>>>3)|0]|0;c[q>>2]=P+1;if((M&128>>>((P&7)>>>0)|0)==0){X=T;break}c[k>>2]=-N;X=T}}while(0);Y=X+L|0;if((Y|0)>63){break}b[f+(d[u+Y|0]<<1)>>1]=c[k>>2];if((c[l>>2]|0)!=0){E=49;break b}L=Y+1|0}if(!((c[y>>2]|0)!=0&(F|0)==1378528)){E=46;break}if((c[w>>2]|0)!=0){E=46;break}c[p>>2]=c[o>>2];c[p+4>>2]=c[o+4>>2];c[p+8>>2]=c[o+8>>2];c[p+12>>2]=c[o+12>>2];c[p+16>>2]=c[o+16>>2];qe[c[x>>2]&1023](f);z=0;F=1316048}if((E|0)==31){F=c[e+12480>>2]|0;KIb(c[e+4>>2]|0,16,2281280,(C=i,i=i+16|0,c[C>>2]=c[e+12476>>2],c[C+8>>2]=F,C)|0);i=C;B=-1;i=j;return B|0}else if((E|0)==46){F=c[e+12480>>2]|0;z=c[w>>2]|0;KIb(c[e+4>>2]|0,16,2277208,(C=i,i=i+24|0,c[C>>2]=c[e+12476>>2],c[C+8>>2]=F,c[C+16>>2]=z,C)|0);i=C;B=-1;i=j;return B|0}else if((E|0)==49){if((c[w>>2]|0)==0){Z=Y;break}if((c[r>>2]|0)==0){Z=Y;break}else{E=51;break}}}}while(0);if((E|0)==51){Qga(e,f,g);Z=63}c[e+180+(g<<2)>>2]=Z;B=0;i=j;return B|0}function OMa(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;g=a+14128|0;h=c[g>>2]|0;j=-h&7;if((j|0)==0){k=h}else{l=j+h|0;c[g>>2]=l;k=l}l=a+14120|0;h=c[l>>2]|0;j=h+(k>>>3)|0;do{if(((je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(k&7)&-1073741824|0)==-2147483648){m=c[a+4>>2]|0;if((c[m+428>>2]|0)!=0){n=k;o=h;break}KIb(m,24,2420352,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=c[g>>2]|0;o=c[l>>2]|0}else{n=k;o=h}}while(0);h=o+(n>>>3)|0;k=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(n&7)>>>18;h=n+14|0;c[g>>2]=h;n=a+14132|0;j=(c[n>>2]|0)-h|0;m=k;k=h;while(1){if((j|0)<=24){q=9;break}h=o+(k>>>3)|0;r=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(k&7)>>>24;h=k+8|0;c[g>>2]=h;s=r|m<<8&4194048;if((s|0)==32){t=h;break}else{j=j-8|0;m=s;k=h}}do{if((q|0)==9){if((m|0)==32){t=k;break}KIb(c[a+4>>2]|0,16,2411040,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}}while(0);k=o+(t>>>3)|0;m=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(t&7)>>>24;k=t+8|0;c[g>>2]=k;j=a+108|0;h=c[j>>2]|0;s=h&-256;c[j>>2]=((s|m|0)<(h|0)?m|256:m)+s;s=d[o+(k>>>3)|0]|0;m=t+9|0;c[g>>2]=m;if((s&128>>>((k&7)>>>0)|0)==0){KIb(c[a+4>>2]|0,16,2403304,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}k=d[o+(m>>>3)|0]|0;c[g>>2]=t+10;if((k&128>>>((m&7)>>>0)|0)!=0){KIb(c[a+4>>2]|0,16,2396384,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}m=t+13|0;c[g>>2]=m;k=o+(m>>>3)|0;s=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(m&7)>>>29;m=t+16|0;c[g>>2]=m;k=a+40|0;do{if((s-6|0)>>>0>1>>>0){c[k>>2]=0;h=b[1379168+(s<<2)>>1]|0;r=e[1379170+(s<<2)>>1]|0;if(h<<16>>16==0){u=-1;i=f;return u|0}v=(d[o+(m>>>3)|0]|0)<<(m&7)>>>7;w=t+17|0;c[g>>2]=w;c[a+9992>>2]=(v&1)+1;v=(d[o+(w>>>3)|0]|0)<<(w&7)>>>7;w=t+18|0;c[g>>2]=w;x=v&1;c[a+10052>>2]=x;v=d[o+(w>>>3)|0]|0;y=t+19|0;c[g>>2]=y;if((v&128>>>((w&7)>>>0)|0)==0){w=(d[o+(y>>>3)|0]|0)<<(y&7)>>>7;y=t+20|0;c[g>>2]=y;v=w&1;c[a+13788>>2]=v;c[a+10048>>2]=(x|0)==0?v:1;v=(d[o+(y>>>3)|0]|0)<<(y&7)>>>7;y=t+21|0;c[g>>2]=y;c[a+36>>2]=v&1;v=o+(y>>>3)|0;x=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(y&7)>>>27;c[a+9960>>2]=x;c[a+9964>>2]=x;c[g>>2]=t+27;x=a+8|0;c[x>>2]=h&65535;c[a+12>>2]=r;r=a+4|0;h=c[r>>2]|0;c[h+224>>2]=12;c[h+228>>2]=11;h=c[r>>2]|0;c[h+104>>2]=1001;c[h+108>>2]=3e4;z=x;break}KIb(c[a+4>>2]|0,16,2389480,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}else{c[k>>2]=1;x=o+(m>>>3)|0;h=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(m&7)>>>29;x=t+19|0;c[g>>2]=x;if((h|0)==0){A=s;B=x;C=o}else if((h|0)==1){q=21}else{KIb(c[a+4>>2]|0,16,2354488,(p=i,i=i+8|0,c[p>>2]=h,p)|0);i=p;u=-1;i=f;return u|0}if((q|0)==21){r=o+(x>>>3)|0;y=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(x&7)>>>29;x=t+22|0;c[g>>2]=x;r=(d[o+(x>>>3)|0]|0)<<(x&7)>>>7;x=t+23|0;c[g>>2]=x;c[a+13840>>2]=r&1;r=(d[o+(x>>>3)|0]|0)<<(x&7)>>>7;x=t+24|0;c[g>>2]=x;v=r&1;r=a+13816|0;c[r>>2]=v;w=d[o+(x>>>3)|0]|0;D=t+25|0;c[g>>2]=D;if((w&128>>>((x&7)>>>0)|0)==0){E=D;F=o;H=v}else{KIb(c[a+4>>2]|0,16,2382520,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;E=c[g>>2]|0;F=c[l>>2]|0;H=c[r>>2]|0}r=(d[F+(E>>>3)|0]|0)<<(E&7)>>>7;v=E+1|0;c[g>>2]=v;D=r&1;c[a+13788>>2]=D;r=(d[F+(v>>>3)|0]|0)<<(v&7)>>>7;v=E+2|0;c[g>>2]=v;c[a+228>>2]=r&1;r=(d[F+(v>>>3)|0]|0)<<(v&7)>>>7;v=E+3|0;c[g>>2]=v;x=r&1;r=a+13836|0;c[r>>2]=x;if((H|0)==0){I=(D|0)==0?x:1}else{I=1}c[a+10048>>2]=I;x=a+4|0;D=c[x>>2]|0;if((c[D+800>>2]|0)!=0){c[r>>2]=0}r=(d[F+(v>>>3)|0]|0)<<(v&7)>>>7;v=E+4|0;c[g>>2]=v;c[a+13824>>2]=r&1;r=d[F+(v>>>3)|0]|0;w=E+5|0;c[g>>2]=w;if((r&128>>>((v&7)>>>0)|0)==0){J=w;K=F}else{KIb(D,16,2375872,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;J=c[g>>2]|0;K=c[l>>2]|0}D=d[K+(J>>>3)|0]|0;w=J+1|0;c[g>>2]=w;if((D&128>>>((J&7)>>>0)|0)==0){L=w;M=K}else{KIb(c[x>>2]|0,16,2369216,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=c[g>>2]|0;M=c[l>>2]|0}x=(d[M+(L>>>3)|0]|0)<<(L&7)>>>7;w=L+1|0;c[g>>2]=w;c[a+13828>>2]=x&1;x=(d[M+(w>>>3)|0]|0)<<(w&7)>>>7;c[g>>2]=L+2;w=x&1;c[a+13832>>2]=w;if((w|0)!=0){c[a+9896>>2]=1379496}w=L+6|0;c[g>>2]=w;A=y;B=w;C=M}w=C+(B>>>3)|0;y=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(B&7)>>>29;c[g>>2]=B+3;w=a+9992|0;c[w>>2]=y;switch(y|0){case 1:{c[w>>2]=2;break};case 2:{c[w>>2]=2;c[a+36>>2]=3;break};case 7:{c[w>>2]=1;break};case 0:{c[w>>2]=1;break};case 3:{c[w>>2]=3;break};default:{u=-1;i=f;return u|0}}w=B+5|0;c[g>>2]=w;c[a+12472>>2]=(d[C+(w>>>3)|0]|0)<<(w&7)>>>7&1;w=B+10|0;c[g>>2]=w;y=(h|0)!=0;do{if(y){do{if((A|0)==6){h=C+(w>>>3)|0;x=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(w&7)>>>28;h=B+14|0;c[g>>2]=h;c[a+13928>>2]=x;D=C+(h>>>3)|0;v=((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(h&7)>>>23<<2)+4|0;h=B+24|0;c[g>>2]=h;D=C+(h>>>3)|0;r=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(h&7)>>>23;h=B+33|0;c[g>>2]=h;D=r<<2;if((x|0)==15){r=C+(h>>>3)|0;N=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(h&7)>>>24;c[g>>2]=B+41;h=c[a+4>>2]|0;c[h+224>>2]=N;N=c[g>>2]|0;r=C+(N>>>3)|0;O=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(N&7)>>>24;c[g>>2]=N+8;c[h+228>>2]=O;P=v;Q=D;break}else{O=1378736+(x<<3)|0;x=(c[a+4>>2]|0)+224|0;h=c[O+4>>2]|0;c[x>>2]=c[O>>2];c[x+4>>2]=h;P=v;Q=D;break}}else{D=e[1379168+(A<<2)>>1]|0;v=e[1379170+(A<<2)>>1]|0;h=c[a+4>>2]|0;c[h+224>>2]=12;c[h+228>>2]=11;P=D;Q=v}}while(0);v=c[a+4>>2]|0;D=v+228|0;c[D>>2]=c[D>>2]<<c[a+13812>>2];if((P|0)==0|(Q|0)==0){u=-1;i=f;return u|0}c[a+8>>2]=P;c[a+12>>2]=Q;D=a+13840|0;if((c[D>>2]|0)==0){c[v+104>>2]=1001;c[v+108>>2]=3e4;R=D;break}h=v+108|0;c[h>>2]=18e5;x=c[g>>2]|0;O=c[l>>2]|0;N=(d[O+(x>>>3)|0]|0)<<(x&7)>>>7;c[g>>2]=x+1;x=v+104|0;c[x>>2]=N&1|1e3;N=c[g>>2]|0;v=O+(N>>>3)|0;O=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(N&7)>>>25;c[g>>2]=N+7;N=ca(c[x>>2]|0,O)|0;c[x>>2]=N;if((N|0)!=0){O=c[h>>2]|0;v=TIb(O,(O|0)<0|0?-1:0,N,(N|0)<0|0?-1:0)|0;r=v;c[h>>2]=(O|0)/(r|0)|0;c[x>>2]=(N|0)/(r|0)|0;R=D;break}KIb(a,16,2345640,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}else{R=a+13840|0}}while(0);if((c[R>>2]|0)!=0){c[g>>2]=(c[g>>2]|0)+2}do{if(y){do{if((c[a+13816>>2]|0)!=0){w=c[g>>2]|0;D=d[(c[l>>2]|0)+(w>>>3)|0]|0;c[g>>2]=w+1;if((D&128>>>((w&7)>>>0)|0)!=0){break}c[g>>2]=w+2}}while(0);if((c[a+13824>>2]|0)==0){break}w=c[g>>2]|0;D=c[l>>2]|0;r=d[D+(w>>>3)|0]|0;N=w+1|0;c[g>>2]=N;if((r&128>>>((w&7)>>>0)|0)==0){S=N;T=D}else{KIb(c[a+4>>2]|0,16,2339600,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;S=c[g>>2]|0;T=c[l>>2]|0}D=d[T+(S>>>3)|0]|0;c[g>>2]=S+1;if((D&128>>>((S&7)>>>0)|0)==0){break}KIb(c[a+4>>2]|0,16,2333872,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);y=c[g>>2]|0;D=(c[l>>2]|0)+(y>>>3)|0;N=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(y&7)>>>27;c[g>>2]=y+5;c[a+9960>>2]=N;z=a+8|0}}while(0);S=c[z>>2]|0;do{if((S|0)!=0){z=c[a+12>>2]|0;if((z|0)==0){break}T=(S+15|0)/16|0;R=a+116|0;c[R>>2]=T;Q=(z+15|0)/16|0;c[a+120>>2]=Q;z=a+144|0;c[z>>2]=ca(T,Q)|0;if((c[a+36>>2]|0)!=0){Q=c[g>>2]|0;T=Q+3|0;c[g>>2]=T;if((c[a+13840>>2]|0)==0){U=T}else{T=Q+5|0;c[g>>2]=T;U=T}c[g>>2]=U+2}T=a+9992|0;Q=(c[T>>2]|0)==3;P=c[j>>2]|0;A=P;C=(P|0)<0|0?-1:0;P=a+13856|0;c[P>>2]=A;c[P+4>>2]=C;if(Q){Q=a+13872|0;P=b[Q>>1]|0;B=a+13864|0;M=xrc(A,C,c[B>>2]|0,c[B+4>>2]|0)|0;B=wrc(M,G,P&65535,0)|0;M=a+13874|0;b[M>>1]=B;L=B&65535;if((P&65535)>>>0<=L>>>0|(L|0)==0|P<<16>>16==0){b[Q>>1]=2;b[M>>1]=1}GRa(a)}else{M=a+13864|0;Q=xrc(A,C,c[M>>2]|0,c[M+4>>2]|0)|0;b[a+13872>>1]=Q;c[M>>2]=A;c[M+4>>2]=C}C=c[g>>2]|0;M=c[n>>2]|0;if((M-C|0)<1){u=-1094995529;i=f;return u|0}A=c[l>>2]|0;Q=C;while(1){C=d[A+(Q>>>3)|0]|0;V=Q+1|0;c[g>>2]=V;if((C&128>>>((Q&7)>>>0)|0)==0){break}C=Q+9|0;c[g>>2]=C;if((M-C|0)<1){u=-1094995529;q=101;break}else{Q=C}}if((q|0)==101){i=f;return u|0}do{if((c[a+13824>>2]|0)!=0){M=d[A+(V>>>3)|0]|0;C=Q+2|0;c[g>>2]=C;if((M&128>>>((V&7)>>>0)|0)==0){KIb(c[a+4>>2]|0,16,2322696,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}else{W=0}while(1){if((W|0)>=6){break}if(((c[z>>2]|0)-1|0)>(e[1358712+(W<<1)>>1]|0|0)){W=W+1|0}else{break}}M=d[1358728+W|0]|0;P=A+(C>>>3)|0;L=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(C&7)>>>((32-M|0)>>>0);P=C+M|0;c[g>>2]=P;M=c[R>>2]|0;c[a+12476>>2]=(L|0)%(M|0)|0;c[a+12480>>2]=(L|0)/(M|0)|0;M=d[A+(P>>>3)|0]|0;c[g>>2]=P+1;if((M&128>>>((P&7)>>>0)|0)!=0){break}KIb(c[a+4>>2]|0,16,2317664,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}}while(0);c[a+11556>>2]=1;A=a+9892|0;if((c[a+228>>2]|0)==0){c[A>>2]=1347360;c[a+9888>>2]=1347360}else{c[A>>2]=1434232;c[a+9888>>2]=1434232}CMa(a);if((c[T>>2]|0)!=1){u=0;i=f;return u|0}if((c[a+88>>2]|0)!=1330075994){u=0;i=f;return u|0}A=c[g>>2]|0;if(((c[n>>2]|0)-A|0)<=758){u=0;i=f;return u|0}R=a+4|0;z=1;Q=c[R>>2]|0;P=A;while(1){A=(d[(c[l>>2]|0)+(P>>>3)|0]|0)<<(P&7)>>>7;c[g>>2]=P+1;KIb(Q,48,2308400,(p=i,i=i+8|0,c[p>>2]=A&1,p)|0);i=p;X=c[R>>2]|0;if((z|0)>=85){break}z=z+1|0;Q=X;P=c[g>>2]|0}KIb(X,48,2303352,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;P=0;while(1){Q=c[g>>2]|0;z=c[l>>2]|0;T=z+(Q>>>3)|0;A=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(Q&7)>>>24;T=Q+8|0;c[g>>2]=T;M=z+(T>>>3)|0;z=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(T&7)>>24;c[g>>2]=Q+16;KIb(c[R>>2]|0,48,2292272,(p=i,i=i+8|0,c[p>>2]=z<<8|A,p)|0);i=p;A=c[g>>2]|0;z=c[l>>2]|0;Q=z+(A>>>3)|0;T=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(A&7)>>>24;Q=A+8|0;c[g>>2]=Q;M=z+(Q>>>3)|0;z=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Q&7)>>24;c[g>>2]=A+16;KIb(c[R>>2]|0,48,2292272,(p=i,i=i+8|0,c[p>>2]=z<<8|T,p)|0);i=p;T=c[g>>2]|0;z=c[l>>2]|0;A=z+(T>>>3)|0;Q=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(T&7)>>>24;A=T+8|0;c[g>>2]=A;M=z+(A>>>3)|0;z=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(A&7)>>24;c[g>>2]=T+16;KIb(c[R>>2]|0,48,2292272,(p=i,i=i+8|0,c[p>>2]=z<<8|Q,p)|0);i=p;KIb(c[R>>2]|0,48,2303352,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Q=P+1|0;if((Q|0)<13){P=Q}else{Y=0;break}}while(1){P=c[R>>2]|0;Q=c[g>>2]|0;z=(d[(c[l>>2]|0)+(Q>>>3)|0]|0)<<(Q&7)>>>7;c[g>>2]=Q+1;KIb(P,48,2308400,(p=i,i=i+8|0,c[p>>2]=z&1,p)|0);i=p;z=Y+1|0;if((z|0)<50){Y=z}else{u=0;break}}i=f;return u|0}}while(0);KIb(c[a+4>>2]|0,16,2328536,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;u=-1;i=f;return u|0}function PMa(){var b=0,d=0;if(a[1367008]|0){return}else{b=0}do{d=b<<14;c[5830364+(b*20|0)>>2]=7698160+(d<<2);c[5830372+(b*20|0)>>2]=8192;QMa(1053008+(b*20|0)|0,5830360+(b*20|0)|0,1)|0;c[5830524+(b*20|0)>>2]=7698160+((d|8192)<<2);c[5830532+(b*20|0)>>2]=8192;QMa(1053168+(b*20|0)|0,5830520+(b*20|0)|0,1)|0;b=b+1|0;}while((b|0)<8);a[1367008]=1;return}function QMa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+768|0;j=h|0;k=h+512|0;l=c[e>>2]|0;a:do{if((l|0)>0){m=0;n=0;while(1){o=d[e+4+m|0]|0;p=1<<o;q=(m|0)!=(l-1|0)|0;r=(1<<m)-1<<o+q;if((p|0)<1|(n|0)>255){s=n}else{t=q+m+o|0;u=t&255;o=t&255;t=8-o|0;q=16-o|0;if(o>>>0>13>>>0){break}if(o>>>0<9>>>0){o=0;v=n;while(1){w=k+v|0;a[w]=u;b[j+(v<<1)>>1]=(d[1316536+((o|r)&65535)|0]|0)>>>(t>>>0);if(u<<24>>24==0){a[w]=1}w=v+1|0;x=o+1|0;if((x|0)>=(p|0)|(w|0)>255){s=w;break}else{o=x;v=w}}}else{v=0;o=n;while(1){t=k+o|0;a[t]=u;w=v|r;b[j+(o<<1)>>1]=((d[1316536+(w&255)|0]|0)<<8|(d[1316536+(w>>>8&255)|0]|0))>>>(q>>>0);if(u<<24>>24==0){a[t]=1}t=o+1|0;w=v+1|0;if((w|0)>=(p|0)|(t|0)>255){s=t;break}else{v=w;o=t}}}}o=m+1|0;if((o|0)<(l|0)){m=o;n=s}else{y=s;break a}}a[k+n|0]=u;z=-1094995529;i=h;return z|0}else{y=0}}while(0);z=$2(f,13,y,k|0,1,1,j,2,2,0,0,0,(g|0)!=0?6:2)|0;i=h;return z|0}function RMa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+24|0;k=j|0;if((e|0)==0){c[g+4>>2]=(f|0)!=0?5830660:5830500;l=0;i=j;return l|0}e=b+8|0;m=c[e>>2]|0;n=b+16|0;o=c[n>>2]|0;p=c[b>>2]|0;b=p+(m>>>3)|0;q=(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)>>>((m&7)>>>0)&7;b=m+3|0;c[e>>2]=o>>>0>b>>>0?b:o;c[g>>2]=q;if((q|0)!=7){c[g+4>>2]=((f|0)==0?5830360:5830520)+(q*20|0);l=0;i=j;return l|0}q=c[e>>2]|0;f=c[n>>2]|0;n=p+(q>>>3)|0;o=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((q&7)>>>0)&15;n=q+4|0;q=f>>>0>n>>>0?n:f;c[e>>2]=q;n=k|0;c[n>>2]=o;if((o|0)==0){KIb(h,16,2527328,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;l=-1094995529;i=j;return l|0}else{s=0;t=q}do{q=p+(t>>>3)|0;o=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((t&7)>>>0);q=t+4|0;t=f>>>0>q>>>0?q:f;c[e>>2]=t;a[k+4+s|0]=o&15;s=s+1|0;u=c[n>>2]|0;}while((s|0)<(u|0));s=g+8|0;n=s|0;do{if((u|0)==(c[n>>2]|0)){t=k+4|0;e=g+12|0;if((grc(t,e,u)|0)!=0){v=e;w=t;x=12;break}if((c[g+32>>2]|0)==0){v=e;w=t;x=12;break}y=g+28|0}else{v=g+12|0;w=k+4|0;x=12}}while(0);do{if((x|0)==12){c[n>>2]=u;nrc(v|0,w|0,u)|0;k=g+28|0;if((c[g+32>>2]|0)!=0){c3(k)}t=QMa(s,k,0)|0;if((t|0)==0){y=k;break}c[n>>2]=0;KIb(h,16,2603400,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;l=t;i=j;return l|0}}while(0);c[g+4>>2]=y;l=0;i=j;return l|0}function SMa(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;TMa(f);h=g|0;i=b[h>>1]|0;if(i<<16>>16==0){j=-1094995529;return j|0}k=g+2|0;if((b[k>>1]|0)==0){j=-1094995529;return j|0}l=g+12|0;if((a[l]|0)==0){j=-1094995529;return j|0}m=g+13|0;if((a[m]|0)==0){j=-1094995529;return j|0}b[f>>1]=i;b[f+2>>1]=b[k>>1]|0;i=a[l]|0;a[f+4|0]=i;g=((e[h>>1]|0)+3|0)>>>2&65535;b[f+24>>1]=g;b[f+12>>1]=g;g=((e[k>>1]|0)+3|0)>>>2&65535;b[f+26>>1]=g;b[f+14>>1]=g;g=a[m]|0;a[f+28|0]=g;a[f+16|0]=g;g=0;m=i;a:while(1){i=f+(g*12|0)+4|0;k=pJb((m&255)*332|0)|0;h=k;n=f+(g*12|0)+8|0;c[n>>2]=h;if((k|0)==0){j=-12;o=18;break}k=a[i]|0;p=e[f+(g*12|0)>>1]|0;if(k<<24>>24==1){q=e[f+(g*12|0)+2>>1]|0;r=p;s=0}else{q=((e[f+(g*12|0)+2>>1]|0)+1|0)>>>1;r=(p+1|0)>>>1;s=k<<24>>24==0}k=(g|0)!=0?8:16;p=k-1|0;t=-k|0;k=p+r&t;u=p+q&t;t=ca(u,k)|0;p=t<<1;if(!s){v=t&2147483584;t=0;w=h;do{c[w+(t*332|0)>>2]=g;c[w+(t*332|0)+4>>2]=t;c[w+(t*332|0)+8>>2]=r;c[w+(t*332|0)+12>>2]=q;c[w+(t*332|0)+48>>2]=k;c[w+(t*332|0)+16>>2]=u;h=w+(t*332|0)+36|0;c[h>>2]=pJb(p)|0;x=pJb(p)|0;c[w+(t*332|0)+40>>2]=x;c[w+(t*332|0)+312>>2]=v;if((c[h>>2]|0)==0|(x|0)==0){j=-12;o=18;break a}if((d[l]|0)>>>0>1>>>0){x=pJb(p)|0;c[w+(t*332|0)+44>>2]=x;if((x|0)==0){j=-12;o=18;break a}}w=c[n>>2]|0;c[w+104>>2]=0;t=t+1|0;}while((t|0)<(d[i]|0))}i=g+1|0;if((i|0)>=3){j=0;o=18;break}g=i;m=a[f+(i*12|0)+4|0]|0}if((o|0)==18){return j|0}return 0}function TMa(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=0;do{f=b+(e*12|0)+8|0;g=c[f>>2]|0;h=b+(e*12|0)+4|0;a:do{if((g|0)!=0){if((a[h]|0)==0){break}else{i=0;j=g}while(1){mJb(j+(i*332|0)+36|0);mJb((c[f>>2]|0)+(i*332|0)+40|0);mJb((c[f>>2]|0)+(i*332|0)+44|0);k=c[f>>2]|0;if((c[k+(i*332|0)+128>>2]|0)==0){l=k}else{c3(k+(i*332|0)+124|0);l=c[f>>2]|0}k=l+(i*332|0)+284|0;if((c[l+(i*332|0)+280>>2]|0)>0){m=0;n=k;while(1){mJb((c[n>>2]|0)+(m*40|0)+32|0);o=m+1|0;p=c[f>>2]|0;q=p+(i*332|0)+284|0;if((o|0)<(c[p+(i*332|0)+280>>2]|0)){m=o;n=q}else{r=q;break}}}else{r=k}mJb(r);n=i+1|0;if((n|0)>=(d[h]|0)){break a}i=n;j=c[f>>2]|0}}}while(0);mJb(f);a[h]=0;e=e+1|0;}while((e|0)<3);return}function UMa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;h=b+4|0;j=b+8|0;k=e+3>>2;l=f+3>>2;m=0;a:while(1){if((m|0)==0){n=(a[h]|0)==4;o=f>>(n&1);p=e>>(n&1)}else{o=l;p=k}if((p|0)<1|(o|0)<1){q=-22;r=22;break}n=b+(m*12|0)+4|0;if((a[n]|0)!=0){s=b+(m*12|0)+8|0;t=p-1|0;u=o-1|0;v=0;do{w=c[s>>2]|0;x=w+(v*332|0)+8|0;y=w+(v*332|0)+12|0;z=w+(v*332|0)+280|0;c[z>>2]=ca((u+(c[y>>2]|0)|0)/(o|0)|0,(t+(c[x>>2]|0)|0)/(p|0)|0)|0;A=w+(v*332|0)+284|0;mJb(A);B=pJb((c[z>>2]|0)*40|0)|0;z=B;c[A>>2]=z;if((B|0)==0){q=-12;r=22;break a}B=c[y>>2]|0;if((B|0)>0){A=w+(v*332|0)+56|0;w=(v|m|0)==0;C=c[(c[j>>2]|0)+284>>2]|0;D=0;E=z;z=c[x>>2]|0;F=B;while(1){if((z|0)>0){if(w){B=0;G=E;while(1){c[G>>2]=B;c[G+4>>2]=D;c[G+16>>2]=c[A>>2];H=(c[x>>2]|0)-B|0;I=(H|0)>(p|0)?p:H;c[G+8>>2]=I;H=(c[y>>2]|0)-D|0;J=(H|0)>(o|0)?o:H;c[G+12>>2]=J;c[G+24>>2]=0;c[G+20>>2]=0;H=c[A>>2]|0;K=H-1|0;L=G+28|0;c[L>>2]=ca((K+J|0)/(H|0)|0,(K+I|0)/(H|0)|0)|0;H=G+32|0;mJb(H);I=pJb(c[L>>2]<<4)|0;c[H>>2]=I;if((I|0)==0){q=-12;r=22;break a}c[G+36>>2]=0;I=G+40|0;H=B+p|0;L=c[x>>2]|0;if((H|0)<(L|0)){B=H;G=I}else{M=C;N=I;O=L;break}}}else{G=C;B=0;L=E;while(1){c[L>>2]=B;c[L+4>>2]=D;c[L+16>>2]=c[A>>2];I=(c[x>>2]|0)-B|0;H=(I|0)>(p|0)?p:I;c[L+8>>2]=H;I=(c[y>>2]|0)-D|0;K=(I|0)>(o|0)?o:I;c[L+12>>2]=K;c[L+24>>2]=0;c[L+20>>2]=0;I=c[A>>2]|0;J=I-1|0;P=L+28|0;c[P>>2]=ca((J+K|0)/(I|0)|0,(J+H|0)/(I|0)|0)|0;I=L+32|0;mJb(I);H=pJb(c[P>>2]<<4)|0;c[I>>2]=H;if((H|0)==0){q=-12;r=22;break a}H=L+36|0;c[H>>2]=0;if((c[P>>2]|0)!=(c[G+28>>2]|0)){r=16;break a}c[H>>2]=c[G+32>>2];H=G+40|0;P=L+40|0;I=B+p|0;J=c[x>>2]|0;if((I|0)<(J|0)){G=H;B=I;L=P}else{M=H;N=P;O=J;break}}}Q=M;R=N;S=O;T=c[y>>2]|0}else{Q=C;R=E;S=z;T=F}L=D+o|0;if((L|0)<(T|0)){C=Q;D=L;E=R;z=S;F=T}else{break}}}v=v+1|0;}while((v|0)<(d[n]|0))}n=m+1|0;if((n|0)<3){m=n}else{q=0;r=22;break}}if((r|0)==16){KIb(0,48,2420328,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;q=-1094995529;i=g;return q|0}else if((r|0)==22){i=g;return q|0}return 0}function VMa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0;k=i;i=i+272|0;l=k|0;m=k+8|0;n=k+264|0;o=c[f+60>>2]|0;p=o;q=c[j+24>>2]|0;r=g;s=c[j+28>>2]|0;j=s<<3;t=j>>>0>2147483639>>>0|(q|0)==0;u=t?0:q;v=t?0:j;j=o;c[j>>2]=u;t=o+12|0;c[t>>2]=v;w=o+16|0;c[w>>2]=v+8;c[o+4>>2]=u+(v>>3);v=o+8|0;c[v>>2]=0;u=o+4672|0;c[u>>2]=q;c[o+4680>>2]=s;q=We[c[o+4872>>2]&2047](p,f)|0;if((q|0)!=0){KIb(f,16,2451528,(x=i,i=i+8|0,c[x>>2]=q,x)|0);i=x;y=q;i=k;return y|0}if((c[o+4892>>2]|0)!=0){y=-1094995529;i=k;return y|0}if(!((a[o+4864|0]&32)==0)){RIb(f,2362280,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1163346256;i=k;return y|0}q=o+4708|0;z=q;A=q;B=o+4716|0;if((c[B>>2]|0)==0){KIb(f,16,2297544,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=k;return y|0}qe[c[o+4884>>2]&1023](p);C=o+4888|0;do{if((ve[c[C>>2]&4095](p)|0)==0){if((c[o+4664>>2]|0)==0){D=0}else{y=-1094995529;i=k;return y|0}while(1){if((D|0)>=3){E=151;break}if((c[(c[z+(D*12|0)+8>>2]|0)+28>>2]|0)==0){y=-1094995529;E=198;break}else{D=D+1|0}}if((E|0)==151){F=o+4748|0;G=o+4896|0;break}else if((E|0)==198){i=k;return y|0}}else{H=o+4748|0;I=o+4896|0;c[I+(c[H>>2]<<2)>>2]=1;J=o+4752|0;K=o+4876|0;L=o+4880|0;M=f+48|0;N=l;O=m;P=l;Q=m|0;R=f;S=0;a:while(1){T=z+(S*12|0)+4|0;U=z+(S*12|0)+8|0;V=0;while(1){if((V|0)>=(d[T]|0)){break}W=c[U>>2]|0;X=W+(V*332|0)|0;Y=c[W+(V*332|0)+36+(c[H>>2]<<2)>>2]|0;Z=W+(V*332|0)+28|0;c[Z>>2]=Y;if((Y|0)==0){E=13;break a}Y=W+(V*332|0)+32|0;c[Y>>2]=c[W+(V*332|0)+36+(c[J>>2]<<2)>>2];c[W+(V*332|0)+20>>2]=(c[u>>2]|0)+(c[v>>2]>>3);_=Ee[c[K>>2]&511](p,X,f)|0;do{if((_|0)==0){if((c[W+(V*332|0)+52>>2]|0)!=0){E=17;break a}$=p+20+((c[W+(V*332|0)+272>>2]|0)*514|0)|0;aa=W+(V*332|0)+276|0;c[aa>>2]=$;ba=W+(V*332|0)+144|0;b:do{if((c[ba>>2]|0)>0){da=0;ea=$;while(1){fa=da<<1;ga=a[W+(V*332|0)+148+fa|0]|0;ha=ga&255;ia=a[(fa|1)+(W+(V*332|0)+148)|0]|0;fa=ia&255;ja=ea+2+fa|0;ka=a[ja]|0;a[ja]=a[ea+2+ha|0]|0;a[(c[aa>>2]|0)+2+ha|0]=ka;ka=c[aa>>2]|0;ja=ka+258+fa|0;fa=a[ja]|0;a[ja]=a[ka+258+ha|0]|0;a[(c[aa>>2]|0)+258+ha|0]=fa;fa=c[aa>>2]|0;ha=fa|0;ka=a[ha]|0;if(ga<<24>>24==ka<<24>>24|ia<<24>>24==ka<<24>>24){a[ha]=ia^ga^ka;la=c[aa>>2]|0}else{la=fa}fa=la+1|0;ka=a[fa]|0;if(ga<<24>>24==ka<<24>>24|ia<<24>>24==ka<<24>>24){a[fa]=ia^ga^ka}ka=da+1|0;if((ka|0)>=(c[ba>>2]|0)){break b}da=ka;ea=c[aa>>2]|0}}}while(0);$=W+(V*332|0)+280|0;c:do{if((c[$>>2]|0)>0){ea=W+(V*332|0)+284|0;da=W+(V*332|0)+56|0;ka=W+(V*332|0)+60|0;ga=W+(V*332|0)+84|0;ia=W+(V*332|0)+324|0;fa=W+(V*332|0)+328|0;ha=W+(V*332|0)+48|0;ja=W+(V*332|0)+16|0;ma=W+(V*332|0)+296|0;na=W+(V*332|0)+316|0;oa=W+(V*332|0)+320|0;pa=W+(V*332|0)+292|0;qa=W+(V*332|0)+88|0;ra=W+(V*332|0)+100|0;sa=W+(V*332|0)+300|0;ta=W+(V*332|0)+288|0;ua=W+(V*332|0)+64|0;va=W+(V*332|0)+76|0;wa=X|0;xa=W+(V*332|0)+4|0;ya=W+(V*332|0)+72|0;za=W+(V*332|0)+68|0;Aa=c[v>>2]|0;Ba=0;d:while(1){Ca=c[ea>>2]|0;Da=Ca+(Ba*40|0)|0;Ea=c[Ca+(Ba*40|0)+16>>2]|0;Fa=c[da>>2]|0;if((Ea|0)!=(Fa|0)){E=28;break a}Ga=c[v>>2]|0;Ha=c[j>>2]|0;Ia=(d[Ha+(Ga>>>3)|0]|0)>>>((Ga&7)>>>0);c[v>>2]=((Ga|0)<(c[w>>2]|0))+Ga;Ga=Ia&1;c[Ca+(Ba*40|0)+20>>2]=Ga;e:do{if((Ga|0)==0){Ia=c[v>>2]|0;Ja=d[Ha+(Ia>>>3)|0]|0;Ka=c[w>>2]|0;La=((Ia|0)<(Ka|0))+Ia|0;c[v>>2]=La;do{if((Ja&1<<(Ia&7)|0)==0){Ma=0;Na=La}else{Oa=Ha+(La>>>3)|0;Pa=(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)>>>((La&7)>>>0)&255;Oa=La+8|0;Qa=Ka>>>0>Oa>>>0?Oa:Ka;c[v>>2]=Qa;if((Pa|0)!=255){Ma=Pa;Na=Qa;break}Pa=Ha+(Qa>>>3)|0;Oa=(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)>>>((Qa&7)>>>0)&16777215;Pa=Qa+24|0;Qa=Ka>>>0>Pa>>>0?Pa:Ka;c[v>>2]=Qa;Ma=Oa;Na=Qa}}while(0);La=-Na&7;if((La|0)!=0){Ia=La+Na|0;c[v>>2]=Ka>>>0>Ia>>>0?Ia:Ka}Ia=Ca+(Ba*40|0)+24|0;c[Ia>>2]=Ma;if((Ma|0)==0){E=75;break d}La=hf[c[L>>2]&1023](p,X,Da,f)|0;if((La|0)<0){Ra=La;break c}c[n>>2]=0;La=c[ka>>2]|0;Ja=(c[da>>2]|0)!=(La|0)?4:1;Qa=(La|0)==8;Oa=Qa?332:306;Pa=Qa?770:14;Qa=Ca+(Ba*40|0)+28|0;if((c[Qa>>2]|0)>0){Sa=La-1|0;Ta=0;Ua=0;Va=c[Ca+(Ba*40|0)+32>>2]|0;Wa=0;Xa=0;while(1){Ya=(a[Va+8|0]|0)==0;Za=d[Va+9|0]|0;_a=c[Va+4>>2]|0;$a=(a[Va+10|0]|0)+(c[ga>>2]|0)|0;ab=($a|0)<0;do{if((c[M>>2]|0)==112){if(ab){bb=0;break}bb=($a|0)>31?31:$a}else{if(ab){bb=0;break}bb=($a|0)>23?23:$a}}while(0);$a=c[(Ya?ia:fa)>>2]|0;if(($a|0)==0){cb=bb}else{cb=d[$a+bb|0]|0}if(Ya){db=Wa;eb=Ua;fb=Ta}else{$a=a[Va+11|0]|0;ab=a[Va+12|0]|0;gb=c[ua>>2]|0;if((gb|0)==0){hb=Wa;ib=ab;jb=$a}else{hb=ab<<1&2|$a&1;ib=ab>>1;jb=$a>>1}kb=(b[Va>>1]|0)+($a>>gb)|0;if((kb|0)<0){break d}lb=c[da>>2]|0;if((kb+(gb&$a)+lb|0)>(c[ha>>2]|0)){break d}$a=(b[Va+2>>1]|0)+(ab>>gb)|0;if(($a|0)<0){break d}if((lb+(ab&gb)+$a|0)>(c[ja>>2]|0)){break d}else{db=hb;eb=ib;fb=jb}}$a=Ya?na:oa;gb=Za;ab=_a;lb=0;while(1){do{if((lb&1|0)==0){if((lb|0)!=2){mb=ab;break}mb=ab-La+(ca(c[ha>>2]|0,La)|0)|0}else{mb=ab+La|0}}while(0);do{if((gb&1|0)==0){if(!Ya){XMa(X,Pa,mb,fb,eb,db);break}kb=c[ha>>2]|0;if(((ca(kb,Sa)|0)+La|0)>((ca(c[ja>>2]|0,kb)|0)-mb|0)){break d}mf[c[ma>>2]&2047](n,(c[Z>>2]|0)+(mb<<1)|0,kb,La)}else{kb=c[$a>>2]|0;nb=c[aa>>2]|0;ob=c[ka>>2]|0;pb=ca(ob,ob)|0;qb=ob-1|0;ob=c[ha>>2]|0;rb=c[pa>>2]|0;sb=(ca(rb-1|0,ob)|0)+rb|0;if((sb|0)>((ca(c[ja>>2]|0,ob)|0)-mb|0)){break d}ob=c[qa>>2]|0;if((ob|0)==0){E=101;break d}mrc(O|0,0,pb<<2|0)|0;c[l>>2]=0;c[l+4>>2]=0;sb=nb|0;rb=nb+1|0;tb=c[w>>2]|0;ub=c[j>>2]|0;vb=(c[ra>>2]|0)+4|0;wb=-1;xb=c[v>>2]|0;while(1){yb=c[vb>>2]|0;zb=ub+(xb>>>3)|0;Ab=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((xb&7)>>>0)&8191;zb=b[yb+(Ab<<2)>>1]|0;Bb=zb<<16>>16;Cb=(b[yb+(Ab<<2)+2>>1]|0)+xb|0;Ab=tb>>>0>Cb>>>0?Cb:tb;c[v>>2]=Ab;if((Bb|0)==(d[sb]|0)){Db=wb;break}if((Bb|0)==(d[rb]|0)){Cb=ub+(Ab>>>3)|0;Eb=(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)>>>((Ab&7)>>>0)&8191;Cb=b[yb+(Eb<<2)>>1]|0;Fb=(b[yb+(Eb<<2)+2>>1]|0)+Ab|0;Eb=tb>>>0>Fb>>>0?Fb:tb;c[v>>2]=Eb;Fb=ub+(Eb>>>3)|0;Gb=(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)>>>((Eb&7)>>>0)&8191;Fb=b[yb+(Gb<<2)>>1]|0;Hb=(b[yb+(Gb<<2)+2>>1]|0)+Eb|0;Eb=tb>>>0>Hb>>>0?Hb:tb;c[v>>2]=Eb;Hb=ub+(Eb>>>3)|0;Gb=(d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0)>>>((Eb&7)>>>0)&8191;Hb=b[yb+(Gb<<2)>>1]|0;Ib=(b[yb+(Gb<<2)+2>>1]|0)+Eb|0;Eb=tb>>>0>Ib>>>0?Ib:tb;c[v>>2]=Eb;Jb=Cb+1|0;Kb=-((Hb<<6|Fb)>>>1^-(Fb&1))|0;Lb=Eb}else{if((zb&65535)>>>0>255>>>0){E=107;break d}Jb=d[nb+2+Bb|0]|0;Kb=a[nb+258+Bb|0]|0;Lb=Ab}Ab=Jb+wb|0;if((Ab|0)>=(pb|0)|(Ab|0)<0){Db=Ab;break}zb=d[ob+Ab|0]|0;Eb=ca(e[kb+(zb<<1)>>1]|0,cb)|0;Fb=Eb>>>9;if(Eb>>>0>1023>>>0){Eb=ca(Fb,Kb)|0;Mb=(ca(((Fb^1)-1|0)>>>1,(Kb|0)>0?1:-1)|0)+Eb|0}else{Mb=Kb}c[m+(zb<<2)>>2]=Mb;Eb=P+(zb&qb)|0;a[Eb]=(Mb|0)!=0|a[Eb];if((Ab|0)>(pb|0)){Db=Ab;break}else{wb=Ab;xb=Lb}}if((Db|0)<0){break d}if((Db|0)>=(pb|0)){if((Bb|0)!=(d[sb]|0)){break d}}do{if(Ya){if((c[sa>>2]|0)==0){break}xb=(c[n>>2]|0)+(c[Q>>2]|0)|0;c[n>>2]=xb;c[Q>>2]=xb;a[N]=(xb|0)!=0|a[N]}}while(0);if((c[pa>>2]|0)>(c[ka>>2]|0)){E=120;break d}mf[c[ta>>2]&2047](Q,(c[Z>>2]|0)+(mb<<1)|0,c[ha>>2]|0,N);if(Ya){break}XMa(X,Oa,mb,fb,eb,db)}}while(0);sb=lb+1|0;if((sb|0)<(Ja|0)){gb=gb>>>1;ab=mb;lb=sb}else{break}}lb=Xa+1|0;if((lb|0)<(c[Qa>>2]|0)){Ta=fb;Ua=eb;Va=Va+16|0;Wa=db;Xa=lb}else{break}}}Xa=c[v>>2]|0;Wa=-Xa&7;if((Wa|0)==0){Nb=Xa}else{Va=c[w>>2]|0;Ua=Wa+Xa|0;Xa=Va>>>0>Ua>>>0?Ua:Va;c[v>>2]=Xa;Nb=Xa}Xa=Nb-Aa>>3;if((Xa|0)!=(c[Ia>>2]|0)){E=133;break d}Ob=(Xa<<3)+Aa|0}else{Xa=c[(c[B>>2]|0)+56>>2]>>3;Va=c[da>>2]|0;Ua=Va>>3;Wa=Xa-Ua|0;Ta=Ca+(Ba*40|0)+28|0;Pb=c[Ta>>2]|0;Qa=Ca+(Ba*40|0)+8|0;Ja=c[Qa>>2]|0;Oa=Va-1|0;La=Ca+(Ba*40|0)+12|0;Sa=c[La>>2]|0;Qb=ca((Sa+Oa|0)/(Va|0)|0,(Ja+Oa|0)/(Va|0)|0)|0;if((Pb|0)!=(Qb|0)){E=31;break d}Oa=Ca+(Ba*40|0)+4|0;Pa=c[Oa>>2]|0;Ka=c[ha>>2]|0;lb=Da|0;ab=Ca+(Ba*40|0)+32|0;gb=ca(Ka,Va)|0;if((Sa|0)<=0){Ob=Aa;break}Ya=c[lb>>2]|0;$a=ca(Ka,Pa)|0;Ka=(Xa|0)==(Ua|0);Ua=Wa-1|0;Xa=Ya+$a|0;$a=c[ab>>2]|0;_a=c[Ca+(Ba*40|0)+36>>2]|0;Za=0;sb=Pa;pb=Ja;Ja=Va;Va=Pa;Pa=Sa;Sa=Ya;while(1){if((pb|0)>0){Ya=sb&65535;xb=Ya<<16>>16;wb=Xa;qb=$a;kb=_a;ob=Za;nb=Sa;while(1){tb=nb&65535;b[qb>>1]=tb;b[qb+2>>1]=Ya;c[qb+4>>2]=wb;a[qb+8|0]=1;a[qb+9|0]=0;do{if((c[va>>2]|0)==0){if((c[wa>>2]|0)!=0){break}if((c[xa>>2]|0)!=0){break}a[qb+10|0]=c[ga>>2];a[qb+11|0]=0;a[qb+12|0]=0}}while(0);ub=(kb|0)==0;if(!((c[ya>>2]|0)==0|ub)){a[qb+10|0]=a[kb+10|0]|0}if((c[za>>2]|0)==0|ub){Rb=ob;Sb=c[da>>2]|0}else{rb=a[kb+11|0]|0;if(Ka){a[qb+11|0]=rb;vb=a[kb+12|0]|0;a[qb+12|0]=vb;Tb=rb;Ub=vb}else{vb=(rb<<24>>24)+Ua+(rb<<24>>24>0)>>Wa&255;a[qb+11|0]=vb;rb=a[kb+12|0]|0;Ab=(rb<<24>>24)+Ua+(rb<<24>>24>0)>>Wa&255;a[qb+12|0]=Ab;Tb=vb;Ub=Ab}if(Tb<<24>>24==0){Vb=Ub<<24>>24!=0|0}else{Vb=1}Ab=Tb<<24>>24;vb=c[ua>>2]|0;rb=Ub<<24>>24;Eb=(Ab>>vb)+(tb<<16>>16)|0;if((Eb|0)<0){E=53;break d}zb=c[da>>2]|0;if((Eb+(vb&Ab)+zb|0)>(c[ha>>2]|0)){E=53;break d}Ab=(rb>>vb)+xb|0;if((Ab|0)<0){E=53;break d}if((Ab+(vb&rb)+zb|0)>(c[ja>>2]|0)){E=53;break d}else{Rb=Vb|ob;Sb=zb}}Wb=qb+16|0;Xb=ub?0:kb+16|0;ub=Sb+nb|0;Yb=c[lb>>2]|0;Zb=c[Qa>>2]|0;if((ub|0)<(Zb+Yb|0)){wb=Sb+wb|0;qb=Wb;kb=Xb;ob=Rb;nb=ub}else{break}}_b=Wb;$b=Xb;ac=Rb;bc=Zb;cc=Sb;dc=c[Oa>>2]|0;ec=c[La>>2]|0;fc=Yb}else{_b=$a;$b=_a;ac=Za;bc=pb;cc=Ja;dc=Va;ec=Pa;fc=Sa}nb=cc+sb|0;if((nb|0)<(dc+ec|0)){Xa=Xa+gb|0;$a=_b;_a=$b;Za=ac;sb=nb;pb=bc;Ja=cc;Va=dc;Pa=ec;Sa=fc}else{break}}if((c[za>>2]|0)==0|(ac|0)==0){Sa=(ca(c[ha>>2]|0,dc)|0)+fc|0;if((ec|0)<=0){Ob=Aa;break}Pa=(c[Z>>2]|0)+(Sa<<1)|0;Va=(c[Y>>2]|0)+(Sa<<1)|0;nrc(Pa|0,Va|0,bc<<1)|0;if((c[La>>2]|0)>1){gc=1;hc=Pa;ic=Va}else{Ob=Aa;break}while(1){Va=c[ha>>2]|0;Pa=hc+(Va<<1)|0;Sa=ic+(Va<<1)|0;Va=gc+1|0;nrc(Pa|0,Sa|0,c[Qa>>2]<<1)|0;if((Va|0)<(c[La>>2]|0)){gc=Va;hc=Pa;ic=Sa}else{Ob=Aa;break e}}}La=c[ka>>2]|0;Qa=(cc|0)!=(La|0)?4:1;Sa=(La|0)==8?770:14;if((c[Ta>>2]|0)<=0){Ob=Aa;break}La=c[ab>>2]|0;Pa=1;while(1){Va=a[La+11|0]|0;Ja=a[La+12|0]|0;if((c[ua>>2]|0)==0){jc=Va;kc=0;lc=Ja}else{jc=Va>>1;kc=Ja<<1&2|Va&1;lc=Ja>>1}Ja=La+4|0;Va=0;do{XMa(X,Sa,(ca((c[ha>>2]&-(Va>>>1&1))+(Va&1)|0,c[ka>>2]|0)|0)+(c[Ja>>2]|0)|0,jc,lc,kc);Va=Va+1|0;}while((Va|0)<(Qa|0));if((Pa|0)>=(c[Ta>>2]|0)){Ob=Aa;break e}La=La+16|0;Pa=Pa+1|0}}}while(0);Ca=Ba+1|0;if((Ca|0)<(c[$>>2]|0)){Aa=Ob;Ba=Ca}else{Ra=0;break c}}if((E|0)==31){E=0;KIb(R,16,2442776,(x=i,i=i+16|0,c[x>>2]=Pb,c[x+8>>2]=Qb,x)|0);i=x;Ra=-1094995529;break}else if((E|0)==53){E=0;KIb(R,16,2430576,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Ra=-1094995529;break}else if((E|0)==75){E=0;KIb(R,16,2616552,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Ra=-1094995529;break}else if((E|0)==101){E=0;KIb(R,16,2478312,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}else if((E|0)==107){E=0;KIb(R,16,2468712,(x=i,i=i+8|0,c[x>>2]=Bb,x)|0);i=x}else if((E|0)==120){E=0;KIb(0,16,2459488,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}else if((E|0)==133){E=0;KIb(R,16,2567736,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Ra=-1094995529;break}KIb(R,16,2589264,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;Ra=-1094995529}else{Ra=0}}while(0);$=c[ba>>2]|0;if(($|0)>0){Ba=$;do{Ba=Ba-1|0;$=Ba<<1;Aa=a[W+(V*332|0)+148+$|0]|0;ka=Aa&255;ha=a[($|1)+(W+(V*332|0)+148)|0]|0;$=ha&255;ua=c[aa>>2]|0;za=ua+2+$|0;ja=a[za]|0;a[za]=a[ua+2+ka|0]|0;a[(c[aa>>2]|0)+2+ka|0]=ja;ja=c[aa>>2]|0;ua=ja+258+$|0;$=a[ua]|0;a[ua]=a[ja+258+ka|0]|0;a[(c[aa>>2]|0)+258+ka|0]=$;$=c[aa>>2]|0;ka=$|0;ja=a[ka]|0;if(Aa<<24>>24==ja<<24>>24|ha<<24>>24==ja<<24>>24){a[ka]=ha^Aa^ja;mc=c[aa>>2]|0}else{mc=$}$=mc+1|0;ja=a[$]|0;if(Aa<<24>>24==ja<<24>>24|ha<<24>>24==ja<<24>>24){a[$]=ha^Aa^ja}}while((Ba|0)>0)}Ba=c[v>>2]|0;aa=-Ba&7;if((aa|0)==0){nc=Ra;break}ba=c[w>>2]|0;ja=aa+Ba|0;c[v>>2]=ba>>>0>ja>>>0?ja:ba;nc=Ra}else{KIb(R,16,2145432,(x=i,i=i+8|0,c[x>>2]=_,x)|0);i=x;nc=_}}while(0);if((nc|0)<0){oc=nc;break a}else{V=V+1|0}}U=S+1|0;if((U|0)<3){S=U}else{E=147;break}}if((E|0)==13){KIb(R,16,2172840,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;oc=-1094995529}else if((E|0)==17){KIb(R,16,2121688,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;oc=-1094995529}else if((E|0)==28){KIb(R,16,2639208,(x=i,i=i+16|0,c[x>>2]=Fa,c[x+8>>2]=Ea,x)|0);i=x;oc=-1094995529}else if((E|0)==147){c[I+(c[H>>2]<<2)>>2]=0;F=H;G=I;break}KIb(R,16,2246696,(x=i,i=i+16|0,c[x>>2]=V,c[x+8>>2]=S,x)|0);i=x;y=oc;i=k;return y|0}}while(0);if((c[G+(c[F>>2]<<2)>>2]|0)!=0){y=-1;i=k;return y|0}F=f+48|0;do{if((c[F>>2]|0)==112){if((c[o+4652>>2]|0)!=0){break}G=c[w>>2]|0;oc=c[j>>2]|0;V=c[v>>2]|0;while(1){Ea=oc+(V>>>3)|0;Fa=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0;Ea=V+8|0;pc=G>>>0>Ea>>>0?Ea:G;c[v>>2]=pc;if((Fa&255<<(V&7)|0)==0){break}if(((c[t>>2]|0)-pc|0)<8){y=-1094995529;E=198;break}else{V=pc}}if((E|0)==198){i=k;return y|0}V=-pc|0;S=G-pc|0;if((V|0)>64){qc=V}else{qc=(S|0)<64?S:64}S=qc+pc|0;c[v>>2]=S;if(((c[t>>2]|0)-S|0)<=18){break}V=oc+(S>>>3)|0;if(((d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((S&7)>>>0)&262143|0)!=262136){break}KIb(f,16,2204976,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}}while(0);if((ve[c[C>>2]&4095](p)|0)==0){y=s;i=k;return y|0}p=q;q=o+4710|0;C=H4a(f,e[p>>1]|0,e[q>>1]|0)|0;if((C|0)<0){y=C;i=k;return y|0}C=M4a(f,r,0)|0;if((C|0)<0){y=C;i=k;return y|0}do{if((c[o+4664>>2]|0)==0){C=c[g+32>>2]|0;r=c[B>>2]|0;f=c[r+28>>2]|0;x=c[r+48>>2]|0;if((f|0)==0){break}r=b[q>>1]|0;if(r<<16>>16==0){break}t=0;v=f;f=c[g>>2]|0;pc=b[p>>1]|0;qc=r;while(1){if(pc<<16>>16==0){rc=0;sc=qc}else{r=0;do{E=b[v+(r<<1)>>1]|0;j=E+128|0;if(j>>>0>255>>>0){tc=-128-E>>31&255}else{tc=j&255}a[f+r|0]=tc;r=r+1|0;uc=b[p>>1]|0;}while((r|0)<(uc&65535|0));rc=uc;sc=b[q>>1]|0}r=t+1|0;if((r|0)<(sc&65535|0)){t=r;v=v+(x<<1)|0;f=f+C|0;pc=rc;qc=sc}else{break}}}else{qc=c[g>>2]|0;pc=c[g+32>>2]|0;if((c[F>>2]|0)==112){ZMa(A,qc,pc);break}else{YMa(A,qc,pc);break}}}while(0);A=o+4732|0;F=c[g+4>>2]|0;sc=c[g+36>>2]|0;rc=c[o+4740>>2]|0;q=c[rc+28>>2]|0;uc=c[rc+48>>2]|0;do{if((q|0)!=0){rc=o+4734|0;p=b[rc>>1]|0;if(p<<16>>16==0){break}tc=A;B=0;pc=q;qc=F;C=b[tc>>1]|0;f=p;while(1){if(C<<16>>16==0){vc=0;wc=f}else{p=0;do{x=b[pc+(p<<1)>>1]|0;v=x+128|0;if(v>>>0>255>>>0){xc=-128-x>>31&255}else{xc=v&255}a[qc+p|0]=xc;p=p+1|0;yc=b[tc>>1]|0;}while((p|0)<(yc&65535|0));vc=yc;wc=b[rc>>1]|0}p=B+1|0;if((p|0)<(wc&65535|0)){B=p;pc=pc+(uc<<1)|0;qc=qc+sc|0;C=vc;f=wc}else{break}}}}while(0);wc=o+4720|0;vc=c[g+8>>2]|0;sc=c[g+40>>2]|0;g=c[o+4728>>2]|0;uc=c[g+28>>2]|0;yc=c[g+48>>2]|0;do{if((uc|0)!=0){g=o+4722|0;xc=b[g>>1]|0;if(xc<<16>>16==0){break}F=wc;q=0;A=uc;f=vc;C=b[F>>1]|0;qc=xc;while(1){if(C<<16>>16==0){zc=0;Ac=qc}else{xc=0;do{pc=b[A+(xc<<1)>>1]|0;B=pc+128|0;if(B>>>0>255>>>0){Bc=-128-pc>>31&255}else{Bc=B&255}a[f+xc|0]=Bc;xc=xc+1|0;Cc=b[F>>1]|0;}while((xc|0)<(Cc&65535|0));zc=Cc;Ac=b[g>>1]|0}xc=q+1|0;if((xc|0)<(Ac&65535|0)){q=xc;A=A+(yc<<1)|0;f=f+sc|0;C=zc;qc=Ac}else{break}}}}while(0);c[h>>2]=1;y=s;i=k;return y|0}function WMa(a){a=a|0;var b=0;b=c[a+60>>2]|0;TMa(b+4708|0);if((c[b+4792>>2]|0)==0){return 0}c3(b+4788|0);return 0}function XMa(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;j=c[a+48>>2]|0;k=e+d+(ca(j,f)|0)|0;f=ca(c[a+16>>2]|0,j)|0;e=c[a+60>>2]|0;l=ca(e-1|0,j)|0;if(!((k|d|0)>-1)){KIb(0,0,2549616,(m=i,i=i+24|0,c[m>>2]=2531528,c[m+8>>2]=2516360,c[m+16>>2]=83,m)|0);i=m;Hd()}n=c[a+32>>2]|0;if((n|0)==0){KIb(0,0,2549616,(m=i,i=i+24|0,c[m>>2]=2531528,c[m+8>>2]=2516360,c[m+16>>2]=83,m)|0);i=m;Hd()}o=f-e-l|0;if((o|0)<(d|0)){KIb(0,0,2549616,(m=i,i=i+24|0,c[m>>2]=2502392,c[m+8>>2]=2516360,c[m+16>>2]=84,m)|0);i=m;Hd()}if((o-((j&-((g|0)>1|0))+(g&1))|0)<(k|0)){KIb(0,0,2549616,(m=i,i=i+24|0,c[m>>2]=2489312,c[m+8>>2]=2516360,c[m+16>>2]=85,m)|0);i=m;Hd()}else{mf[b&2047]((c[a+28>>2]|0)+(d<<1)|0,n+(k<<1)|0,j,g);i=h;return}}function YMa(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;g=c[d+8>>2]|0;h=d+2|0;i=b[h>>1]|0;if(i<<16>>16==0){return}j=d|0;d=f<<1;k=0;l=c[g+48>>2]|0;m=0;n=c[g+28>>2]|0;o=c[g+360>>2]|0;p=c[g+692>>2]|0;q=c[g+1024>>2]|0;g=e;e=i&65535;r=b[j>>1]|0;s=i;while(1){i=k+2|0;t=(i|0)<(e|0)?l:0;u=b[o+(m<<1)>>1]|0;v=b[o>>1]|0;w=b[p>>1]|0;x=b[p+(t<<1)>>1]|0;y=b[q+(m<<1)>>1]|0;z=b[q>>1]|0;A=(z*-6|0)+y+(b[q+(t<<1)>>1]|0)|0;if(r<<16>>16==0){B=n;C=o;D=p;E=q;F=0;G=s;H=t+1|0}else{I=t+1|0;J=m+1|0;K=u;L=v;M=(v*-6|0)+u+(b[o+(t<<1)>>1]|0)|0;u=b[n+(t<<1)>>1]|0;v=w;N=w;w=b[n>>1]|0;O=x;P=x;x=0;Q=y;R=y;y=z;S=z;z=0;T=A;U=A;A=n;V=o;W=p;X=q;Y=r&65535;while(1){Z=z+2|0;if((Z|0)<(Y|0)){_=X;$=W;aa=V;ba=A}else{_=X-2|0;$=W-2|0;aa=V-2|0;ba=A-2|0}ca=x+1|0;da=b[ba+(ca<<1)>>1]|0;ea=I+x|0;fa=b[ba+(ea<<1)>>1]|0;ga=da+w|0;ha=b[aa+(ca<<1)>>1]|0;ia=J+x|0;ja=b[aa+(ia<<1)>>1]|0;ka=(L*-6|0)+K+M|0;la=ja+(ha*-6|0)+(b[aa+(ea<<1)>>1]|0)|0;ma=L+K|0;na=b[$+(ca<<1)>>1]|0;oa=b[$+(ea<<1)>>1]|0;pa=N+v|0;qa=(N*-6|0)+v+na|0;ra=b[_+(ca<<1)>>1]|0;sa=b[_+(ia<<1)>>1]|0;ia=y+Q|0;ta=S+R|0;ua=sa+(ra*-6|0)+(b[_+(ea<<1)>>1]|0)|0;ea=(ta+ia<<2)+(w<<4)+(pa+ma<<3)>>6;va=ea+128|0;if(va>>>0>255>>>0){wa=-128-ea>>31&255}else{wa=va&255}a[g+z|0]=wa;va=((ta*-6|0)+ia+ra+sa<<1)+(ga<<3)+(ha+ma+ja+qa<<2)>>6;ma=va+128|0;if(ma>>>0>255>>>0){xa=-128-va>>31&255}else{xa=ma&255}a[g+(z|1)|0]=xa;ma=(U+T<<1)+(w+u<<3)+(pa+ka+O+P<<2)>>6;pa=ma+128|0;if(pa>>>0>255>>>0){ya=-128-ma>>31&255}else{ya=pa&255}pa=z+f|0;a[g+pa|0]=ya;ma=(U*-6|0)+T+(ga+u+fa<<2)+ua+(O+ka+(P*-6|0)+la+qa+oa<<1)>>6;qa=ma+128|0;if(qa>>>0>255>>>0){za=-128-ma>>31&255}else{za=qa&255}a[g+(pa+1)|0]=za;Aa=b[j>>1]|0;pa=Aa&65535;if((Z|0)<(pa|0)){K=ja;L=ha;M=la;u=fa;v=N;N=na;w=da;O=P;P=oa;x=ca;Q=R;R=sa;y=S;S=ra;z=Z;T=U;U=ua;A=ba;V=aa;W=$;X=_;Y=pa}else{break}}B=ba;C=aa;D=$;E=_;F=Aa;G=b[h>>1]|0;H=I}Y=G&65535;if((i|0)<(Y|0)){k=i;l=t;m=-t|0;n=B+(H<<1)|0;o=C+(H<<1)|0;p=D+(H<<1)|0;q=E+(H<<1)|0;g=g+d|0;e=Y;r=F;s=G}else{break}}return}function ZMa(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=c[d+8>>2]|0;h=c[g+48>>2]|0;i=d+2|0;j=b[i>>1]|0;if(j<<16>>16==0){return}k=d|0;d=f<<1;l=0;m=c[g+28>>2]|0;n=c[g+360>>2]|0;o=c[g+692>>2]|0;p=c[g+1024>>2]|0;g=e;e=b[k>>1]|0;q=j;while(1){if(e<<16>>16==0){r=0;s=q}else{j=0;t=0;while(1){u=b[m+(j<<1)>>1]|0;v=b[n+(j<<1)>>1]|0;w=b[o+(j<<1)>>1]|0;x=b[p+(j<<1)>>1]|0;y=v+u|0;z=w+2|0;A=z+y+x>>2;B=2-w|0;w=B+y-x>>2;y=u-v|0;v=z+y-x>>2;z=B+y+x>>2;x=A+128|0;if(x>>>0>255>>>0){C=-128-A>>31&255}else{C=x&255}a[g+t|0]=C;x=w+128|0;if(x>>>0>255>>>0){D=-128-w>>31&255}else{D=x&255}a[g+(t|1)|0]=D;x=v+128|0;if(x>>>0>255>>>0){E=-128-v>>31&255}else{E=x&255}x=t+f|0;a[g+x|0]=E;v=z+128|0;if(v>>>0>255>>>0){F=-128-z>>31&255}else{F=v&255}a[g+(x+1)|0]=F;x=t+2|0;G=b[k>>1]|0;if((x|0)<(G&65535|0)){j=j+1|0;t=x}else{break}}r=G;s=b[i>>1]|0}t=l+2|0;if((t|0)<(s&65535|0)){l=t;m=m+(h<<1)|0;n=n+(h<<1)|0;o=o+(h<<1)|0;p=p+(h<<1)|0;g=g+d|0;e=r;q=s}else{break}}return}function _Ma(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=i;i=i+256|0;j=h|0;k=0;l=d;d=j;while(1){if((a[g+k|0]|0)==0){c[d+224>>2]=0;c[d+192>>2]=0;c[d+160>>2]=0;c[d+128>>2]=0;c[d+96>>2]=0;c[d+64>>2]=0;c[d+32>>2]=0;c[d>>2]=0}else{m=k>>>2&1^1;n=c[l+64>>2]<<m;o=c[l+96>>2]<<m;p=c[l>>2]<<m<<1;q=c[l+32>>2]<<m<<1;m=p-q>>1;r=q+p>>1;p=r-n>>1;q=r+n>>1;n=m-o>>1;r=m+o>>1;o=c[l+128>>2]|0;m=c[l+160>>2]|0;s=c[l+192>>2]|0;t=c[l+224>>2]|0;c[d>>2]=q+o>>1;c[d+32>>2]=q-o>>1;c[d+64>>2]=p+m>>1;c[d+96>>2]=p-m>>1;c[d+128>>2]=r+s>>1;c[d+160>>2]=r-s>>1;c[d+192>>2]=n+t>>1;c[d+224>>2]=n-t>>1}t=k+1|0;if((t|0)<8){k=t;l=l+4|0;d=d+4|0}else{u=0;v=e;w=j;break}}while(1){j=c[w>>2]|0;e=c[w+4>>2]|0;do{if((j|e|0)==0){if((c[w+8>>2]|0)!=0){x=0;y=14;break}if((c[w+12>>2]|0)!=0){x=0;y=14;break}if((c[w+16>>2]|0)!=0){x=0;y=14;break}if((c[w+20>>2]|0)!=0){x=0;y=14;break}if((c[w+24>>2]|0)!=0){x=0;y=14;break}if((c[w+28>>2]|0)!=0){x=0;y=14;break}mrc(v|0,0,16)|0}else{x=e;y=14}}while(0);if((y|0)==14){y=0;e=j<<1;d=x<<1;l=e-d>>1;k=d+e>>1;e=c[w+8>>2]|0;d=k-e>>1;g=k+e>>1;e=c[w+12>>2]|0;k=l-e>>1;t=l+e>>1;e=c[w+16>>2]|0;l=c[w+20>>2]|0;n=c[w+24>>2]|0;s=c[w+28>>2]|0;b[v>>1]=(g+e|0)>>>1;b[v+2>>1]=(g-e|0)>>>1;b[v+4>>1]=(d+l|0)>>>1;b[v+6>>1]=(d-l|0)>>>1;b[v+8>>1]=(t+n|0)>>>1;b[v+10>>1]=(t-n|0)>>>1;b[v+12>>1]=(s+k|0)>>>1;b[v+14>>1]=(k-s|0)>>>1}s=u+1|0;if((s|0)<8){u=s;v=v+(f<<1)|0;w=w+32|0}else{break}}i=h;return}function $Ma(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=0;g=d;d=a;while(1){a=c[d>>2]|0;h=c[d+4>>2]|0;do{if((a|h|0)==0){if((c[d+8>>2]|0)!=0){i=0;j=10;break}if((c[d+12>>2]|0)!=0){i=0;j=10;break}if((c[d+16>>2]|0)!=0){i=0;j=10;break}if((c[d+20>>2]|0)!=0){i=0;j=10;break}if((c[d+24>>2]|0)!=0){i=0;j=10;break}if((c[d+28>>2]|0)!=0){i=0;j=10;break}mrc(g|0,0,16)|0}else{i=h;j=10}}while(0);if((j|0)==10){j=0;h=a<<1;k=i<<1;l=h-k>>1;m=k+h>>1;h=c[d+8>>2]|0;k=m-h>>1;n=m+h>>1;h=c[d+12>>2]|0;m=l-h>>1;o=l+h>>1;h=c[d+16>>2]|0;l=c[d+20>>2]|0;p=c[d+24>>2]|0;q=c[d+28>>2]|0;b[g>>1]=(n+h|0)>>>1;b[g+2>>1]=(n-h|0)>>>1;b[g+4>>1]=(k+l|0)>>>1;b[g+6>>1]=(k-l|0)>>>1;b[g+8>>1]=(o+p|0)>>>1;b[g+10>>1]=(o-p|0)>>>1;b[g+12>>1]=(q+m|0)>>>1;b[g+14>>1]=(m-q|0)>>>1}q=f+1|0;if((q|0)<8){f=q;g=g+(e<<1)|0;d=d+32|0}else{break}}return}function aNa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=f*7|0;i=f*6|0;j=f*5|0;k=f<<2;l=f*3|0;m=f<<1;n=0;o=e;e=d;while(1){if((a[g+n|0]|0)==0){b[o+(h<<1)>>1]=0;b[o+(i<<1)>>1]=0;b[o+(j<<1)>>1]=0;b[o+(k<<1)>>1]=0;b[o+(l<<1)>>1]=0;b[o+(m<<1)>>1]=0;b[o+(f<<1)>>1]=0;b[o>>1]=0}else{d=c[e>>2]<<1;p=c[e+32>>2]<<1;q=d-p>>1;r=p+d>>1;d=c[e+64>>2]|0;p=r-d>>1;s=r+d>>1;d=c[e+96>>2]|0;r=q-d>>1;t=q+d>>1;d=c[e+128>>2]|0;q=c[e+160>>2]|0;u=c[e+192>>2]|0;v=c[e+224>>2]|0;b[o>>1]=(s+d|0)>>>1;b[o+(f<<1)>>1]=(s-d|0)>>>1;b[o+(m<<1)>>1]=(p+q|0)>>>1;b[o+(l<<1)>>1]=(p-q|0)>>>1;b[o+(k<<1)>>1]=(t+u|0)>>>1;b[o+(j<<1)>>1]=(t-u|0)>>>1;b[o+(i<<1)>>1]=(v+r|0)>>>1;b[o+(h<<1)>>1]=(r-v|0)>>>1}v=n+1|0;if((v|0)<8){n=v;o=o+2|0;e=e+4|0}else{break}}return}function bNa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+64|0;j=h|0;k=0;l=d;d=j;while(1){if((a[g+k|0]|0)==0){c[d+48>>2]=0;c[d+32>>2]=0;c[d+16>>2]=0;c[d>>2]=0}else{m=k>>>1&1^1;n=c[l>>2]<<m;o=c[l+16>>2]<<m;m=n-o>>1;p=o+n>>1;n=c[l+32>>2]|0;c[d>>2]=p+n>>1;c[d+16>>2]=p-n>>1;n=c[l+48>>2]|0;c[d+32>>2]=m+n>>1;c[d+48>>2]=m-n>>1}n=k+1|0;if((n|0)<4){k=n;l=l+4|0;d=d+4|0}else{q=0;r=e;s=j;break}}while(1){j=c[s>>2]|0;e=c[s+4>>2]|0;do{if((j|e|0)==0){if((c[s+8>>2]|0)!=0){t=0;u=10;break}if((c[s+12>>2]|0)!=0){t=0;u=10;break}d=r;l=d|0;y=0;b[l>>1]=y;b[l+2>>1]=y>>16;l=d+4|0;y=0;b[l>>1]=y;b[l+2>>1]=y>>16}else{t=e;u=10}}while(0);if((u|0)==10){u=0;e=j-t>>1;l=t+j>>1;d=c[s+8>>2]|0;b[r>>1]=(l+d|0)>>>1;b[r+2>>1]=(l-d|0)>>>1;d=c[s+12>>2]|0;b[r+4>>1]=(e+d|0)>>>1;b[r+6>>1]=(e-d|0)>>>1}d=q+1|0;if((d|0)<4){q=d;r=r+(f<<1)|0;s=s+16|0}else{break}}i=h;return}function cNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;f=0;g=d;d=a;while(1){a=c[d>>2]|0;h=c[d+4>>2]|0;do{if((a|h|0)==0){if((c[d+8>>2]|0)!=0){i=0;j=6;break}if((c[d+12>>2]|0)!=0){i=0;j=6;break}k=g;l=k|0;y=0;b[l>>1]=y;b[l+2>>1]=y>>16;l=k+4|0;y=0;b[l>>1]=y;b[l+2>>1]=y>>16}else{i=h;j=6}}while(0);if((j|0)==6){j=0;h=a-i>>1;l=i+a>>1;k=c[d+8>>2]|0;b[g>>1]=(l+k|0)>>>1;b[g+2>>1]=(l-k|0)>>>1;k=c[d+12>>2]|0;b[g+4>>1]=(h+k|0)>>>1;b[g+6>>1]=(h-k|0)>>>1}k=f+1|0;if((k|0)<4){f=k;g=g+(e<<1)|0;d=d+16|0}else{break}}return}function dNa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=f*3|0;i=f<<1;j=0;k=e;e=d;while(1){if((a[g+j|0]|0)==0){b[k+(h<<1)>>1]=0;b[k+(i<<1)>>1]=0;b[k+(f<<1)>>1]=0;b[k>>1]=0}else{d=c[e>>2]|0;l=c[e+16>>2]|0;m=d-l>>1;n=l+d>>1;d=c[e+32>>2]|0;b[k>>1]=(n+d|0)>>>1;b[k+(f<<1)>>1]=(n-d|0)>>>1;d=c[e+48>>2]|0;b[k+(i<<1)>>1]=(m+d|0)>>>1;b[k+(h<<1)>>1]=(m-d|0)>>>1}d=j+1|0;if((d|0)<4){j=d;k=k+2|0;e=e+4|0}else{break}}return}function eNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=(c[a>>2]|0)>>>3&65535;if((f|0)>0){h=0;i=d}else{return}while(1){d=0;do{b[i+(d<<1)>>1]=g;d=d+1|0;}while((d|0)<(f|0));d=h+1|0;if((d|0)<(f|0)){h=d;i=i+(e<<1)|0}else{break}}return}function fNa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+256|0;j=h|0;k=0;l=d;d=j;while(1){if((a[g+k|0]|0)==0){c[d+224>>2]=0;c[d+192>>2]=0;c[d+160>>2]=0;c[d+128>>2]=0;c[d+96>>2]=0;c[d+64>>2]=0;c[d+32>>2]=0;c[d>>2]=0}else{m=c[l+96>>2]|0;n=c[l+32>>2]|0;o=(4-m+(n<<2)>>3)+m|0;p=(4-(m<<2)-n>>3)+n|0;n=c[l>>2]|0;m=n-p|0;q=p+n|0;n=c[l+128>>2]|0;p=c[l+160>>2]|0;r=n-p|0;s=p+n|0;n=c[l+224>>2]|0;p=c[l+192>>2]|0;t=n-p|0;u=p+n|0;n=c[l+64>>2]|0;p=o-n|0;v=n+o|0;o=q-s|0;n=q+s|0;s=((t<<1)+2+v>>2)+v|0;q=(2-t+(v<<1)>>2)-t|0;t=m-r|0;v=m+r|0;r=((u<<1)+2+p>>2)+p|0;m=(2-u+(p<<1)>>2)-u|0;c[d>>2]=s+n;c[d+32>>2]=q+o;c[d+64>>2]=o-q;c[d+96>>2]=n-s;c[d+128>>2]=r+v;c[d+160>>2]=m+t;c[d+192>>2]=t-m;c[d+224>>2]=v-r}r=k+1|0;if((r|0)<8){k=r;l=l+4|0;d=d+4|0}else{w=e;x=0;y=j;break}}while(1){j=c[y>>2]|0;e=c[y+4>>2]|0;do{if((j|e|0)==0){if((c[y+8>>2]|0)!=0){z=0;A=14;break}if((c[y+12>>2]|0)!=0){z=0;A=14;break}if((c[y+16>>2]|0)!=0){z=0;A=14;break}if((c[y+20>>2]|0)!=0){z=0;A=14;break}if((c[y+24>>2]|0)!=0){z=0;A=14;break}if((c[y+28>>2]|0)!=0){z=0;A=14;break}mrc(w|0,0,16)|0}else{z=e;A=14}}while(0);if((A|0)==14){A=0;e=c[y+12>>2]|0;d=(4-e+(z<<2)>>3)+e|0;l=(4-(e<<2)-z>>3)+z|0;e=j-l|0;k=l+j|0;l=c[y+16>>2]|0;g=c[y+20>>2]|0;r=l-g|0;v=g+l|0;l=c[y+28>>2]|0;g=c[y+24>>2]|0;m=l-g|0;t=g+l|0;l=c[y+8>>2]|0;g=d-l|0;s=l+d|0;d=((m<<1)+2+s>>2)+s|0;l=(2-m+(s<<1)>>2)-m|0;m=((t<<1)+2+g>>2)+g|0;s=(2-t+(g<<1)>>2)-t|0;t=k+v+1|0;b[w>>1]=(t+d|0)>>>1;g=k-v+1|0;b[w+2>>1]=(g+l|0)>>>1;b[w+4>>1]=(g-l|0)>>>1;b[w+6>>1]=(t-d|0)>>>1;d=e+r+1|0;b[w+8>>1]=(d+m|0)>>>1;t=e-r+1|0;b[w+10>>1]=(t+s|0)>>>1;b[w+12>>1]=(t-s|0)>>>1;b[w+14>>1]=(d-m|0)>>>1}m=x+1|0;if((m|0)<8){w=w+(f<<1)|0;x=m;y=y+32|0}else{break}}i=h;return}function gNa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;h=i;i=i+64|0;j=h|0;k=j|0;if((a[g]|0)==0){c[j+48>>2]=0;c[j+32>>2]=0;c[j+16>>2]=0;c[k>>2]=0;l=0}else{m=c[d>>2]|0;n=c[d+32>>2]|0;o=m-n|0;p=n+m|0;m=c[d+16>>2]|0;n=c[d+48>>2]|0;q=(m+2+(n<<1)>>2)+m|0;r=(2-n+(m<<1)>>2)-n|0;n=q+p|0;c[k>>2]=n;c[j+16>>2]=r+o;c[j+32>>2]=o-r;c[j+48>>2]=p-q;l=n}n=j+4|0;if((a[g+1|0]|0)==0){c[j+52>>2]=0;c[j+36>>2]=0;c[j+20>>2]=0;c[n>>2]=0}else{q=c[d+4>>2]|0;p=c[d+36>>2]|0;r=q-p|0;o=p+q|0;q=c[d+20>>2]|0;p=c[d+52>>2]|0;m=(q+2+(p<<1)>>2)+q|0;s=(2-p+(q<<1)>>2)-p|0;c[n>>2]=m+o;c[j+20>>2]=s+r;c[j+36>>2]=r-s;c[j+52>>2]=o-m}m=j+8|0;if((a[g+2|0]|0)==0){c[j+56>>2]=0;c[j+40>>2]=0;c[j+24>>2]=0;c[m>>2]=0}else{o=c[d+8>>2]|0;s=c[d+40>>2]|0;r=o-s|0;n=s+o|0;o=c[d+24>>2]|0;s=c[d+56>>2]|0;p=(o+2+(s<<1)>>2)+o|0;q=(2-s+(o<<1)>>2)-s|0;c[m>>2]=p+n;c[j+24>>2]=q+r;c[j+40>>2]=r-q;c[j+56>>2]=n-p}p=j+12|0;if((a[g+3|0]|0)==0){c[j+60>>2]=0;c[j+44>>2]=0;c[j+28>>2]=0;c[p>>2]=0;t=e;u=1;v=k;w=l}else{g=c[d+12>>2]|0;n=c[d+44>>2]|0;q=g-n|0;r=n+g|0;g=c[d+28>>2]|0;n=c[d+60>>2]|0;d=(g+2+(n<<1)>>2)+g|0;m=(2-n+(g<<1)>>2)-n|0;c[p>>2]=d+r;c[j+28>>2]=m+q;c[j+44>>2]=q-m;c[j+60>>2]=r-d;t=e;u=1;v=k;w=l}while(1){l=c[v+4>>2]|0;do{if((w|l|0)==0){if((c[v+8>>2]|0)!=0){x=0;z=9;break}if((c[v+12>>2]|0)!=0){x=0;z=9;break}k=t;e=k|0;y=0;b[e>>1]=y;b[e+2>>1]=y>>16;e=k+4|0;y=0;b[e>>1]=y;b[e+2>>1]=y>>16}else{x=l;z=9}}while(0);if((z|0)==9){z=0;l=c[v+8>>2]|0;e=c[v+12>>2]|0;k=(x+2+(e<<1)>>2)+x|0;d=(2-e+(x<<1)>>2)-e|0;e=l+w+1|0;b[t>>1]=(e+k|0)>>>1;r=w-l+1|0;b[t+2>>1]=(r+d|0)>>>1;b[t+4>>1]=(r-d|0)>>>1;b[t+6>>1]=(e-k|0)>>>1}k=v+16|0;if((u|0)>=4){break}t=t+(f<<1)|0;u=u+1|0;v=k;w=c[k>>2]|0}i=h;return}function hNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=((c[a>>2]|0)+1|0)>>>1&65535;if((f|0)>0){h=0;i=d}else{return}while(1){d=0;do{b[i+(d<<1)>>1]=g;d=d+1|0;}while((d|0)<(f|0));d=h+1|0;if((d|0)<(f|0)){h=d;i=i+(e<<1)|0}else{break}}return}function iNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=0;g=d;d=a;while(1){a=c[d>>2]|0;h=c[d+4>>2]|0;do{if((a|h|0)==0){if((c[d+8>>2]|0)!=0){i=0;j=10;break}if((c[d+12>>2]|0)!=0){i=0;j=10;break}if((c[d+16>>2]|0)!=0){i=0;j=10;break}if((c[d+20>>2]|0)!=0){i=0;j=10;break}if((c[d+24>>2]|0)!=0){i=0;j=10;break}if((c[d+28>>2]|0)!=0){i=0;j=10;break}mrc(g|0,0,16)|0}else{i=h;j=10}}while(0);if((j|0)==10){j=0;h=c[d+12>>2]|0;k=(4-h+(i<<2)>>3)+h|0;l=(4-(h<<2)-i>>3)+i|0;h=a-l|0;m=l+a|0;l=c[d+16>>2]|0;n=c[d+20>>2]|0;o=l-n|0;p=n+l|0;l=c[d+28>>2]|0;n=c[d+24>>2]|0;q=l-n|0;r=n+l|0;l=c[d+8>>2]|0;n=k-l|0;s=l+k|0;k=((q<<1)+2+s>>2)+s|0;l=(2-q+(s<<1)>>2)-q|0;q=((r<<1)+2+n>>2)+n|0;s=(2-r+(n<<1)>>2)-r|0;r=m+p+1|0;b[g>>1]=(r+k|0)>>>1;n=m-p+1|0;b[g+2>>1]=(n+l|0)>>>1;b[g+4>>1]=(n-l|0)>>>1;b[g+6>>1]=(r-k|0)>>>1;k=h+o+1|0;b[g+8>>1]=(k+q|0)>>>1;r=h-o+1|0;b[g+10>>1]=(r+s|0)>>>1;b[g+12>>1]=(r-s|0)>>>1;b[g+14>>1]=(k-q|0)>>>1}q=f+1|0;if((q|0)<8){f=q;g=g+(e<<1)|0;d=d+32|0}else{break}}return}function jNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=((c[a>>2]|0)+1|0)>>>1&65535;if((f|0)>0){h=0}else{return}do{b[d+(h<<1)>>1]=g;h=h+1|0;}while((h|0)<(f|0));if((f|0)<=1){return}h=f<<1;g=1;a=0;while(1){mrc(d+((ca(a,e)|0)+e<<1)|0,0,h|0)|0;i=g+1|0;if((i|0)<(f|0)){g=i;a=a+1|0}else{break}}return}function kNa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=f<<1;i=f<<2;j=f*7|0;k=i+h|0;l=i+f|0;m=h+f|0;n=0;o=e;e=d;while(1){if((a[g+n|0]|0)==0){b[o+(j<<1)>>1]=0;b[o+(k<<1)>>1]=0;b[o+(l<<1)>>1]=0;b[o+(i<<1)>>1]=0;b[o+(m<<1)>>1]=0;b[o+(h<<1)>>1]=0;b[o+(f<<1)>>1]=0;b[o>>1]=0}else{d=c[e+96>>2]|0;p=c[e+32>>2]|0;q=(4-d+(p<<2)>>3)+d|0;r=(4-(d<<2)-p>>3)+p|0;p=c[e>>2]|0;d=p-r|0;s=r+p|0;p=c[e+128>>2]|0;r=c[e+160>>2]|0;t=p-r|0;u=r+p|0;p=c[e+224>>2]|0;r=c[e+192>>2]|0;v=p-r|0;w=r+p|0;p=c[e+64>>2]|0;r=q-p|0;x=p+q|0;q=((v<<1)+2+x>>2)+x|0;p=(2-v+(x<<1)>>2)-v|0;v=((w<<1)+2+r>>2)+r|0;x=(2-w+(r<<1)>>2)-w|0;w=s+u+1|0;b[o>>1]=(w+q|0)>>>1;r=s-u+1|0;b[o+(f<<1)>>1]=(r+p|0)>>>1;b[o+(h<<1)>>1]=(r-p|0)>>>1;b[o+(m<<1)>>1]=(w-q|0)>>>1;q=d+t+1|0;b[o+(i<<1)>>1]=(q+v|0)>>>1;w=d-t+1|0;b[o+(l<<1)>>1]=(w+x|0)>>>1;b[o+(k<<1)>>1]=(w-x|0)>>>1;b[o+(j<<1)>>1]=(q-v|0)>>>1}v=n+1|0;if((v|0)<8){n=v;o=o+2|0;e=e+4|0}else{break}}return}function lNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=((c[a>>2]|0)+1|0)>>>1&65535;if((f|0)<=0){return}if((f|0)<=1){a=0;h=d;while(1){b[h>>1]=g;i=a+1|0;if((i|0)<(f|0)){a=i;h=h+(e<<1)|0}else{break}}return}h=(f<<1)-2|0;a=0;i=d;while(1){b[i>>1]=g;mrc(d+((ca(a,e)|0)+1<<1)|0,0,h|0)|0;j=a+1|0;if((j|0)<(f|0)){a=j;i=i+(e<<1)|0}else{break}}return}function mNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=0;g=d;d=a;while(1){a=c[d>>2]|0;h=c[d+4>>2]|0;do{if((a|h|0)==0){if((c[d+8>>2]|0)!=0){i=0;j=6;break}if((c[d+12>>2]|0)!=0){i=0;j=6;break}k=g;l=k|0;y=0;b[l>>1]=y;b[l+2>>1]=y>>16;l=k+4|0;y=0;b[l>>1]=y;b[l+2>>1]=y>>16}else{i=h;j=6}}while(0);if((j|0)==6){j=0;h=c[d+8>>2]|0;l=c[d+12>>2]|0;k=(i+2+(l<<1)>>2)+i|0;m=(2-l+(i<<1)>>2)-l|0;l=h+a+1|0;b[g>>1]=(l+k|0)>>>1;n=a-h+1|0;b[g+2>>1]=(n+m|0)>>>1;b[g+4>>1]=(n-m|0)>>>1;b[g+6>>1]=(l-k|0)>>>1}k=f+1|0;if((k|0)<4){f=k;g=g+(e<<1)|0;d=d+16|0}else{break}}return}function nNa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=f<<1;i=h+f|0;j=0;k=e;e=d;while(1){if((a[g+j|0]|0)==0){b[k+(i<<1)>>1]=0;b[k+(h<<1)>>1]=0;b[k+(f<<1)>>1]=0;b[k>>1]=0}else{d=c[e>>2]|0;l=c[e+32>>2]|0;m=c[e+16>>2]|0;n=c[e+48>>2]|0;o=(m+2+(n<<1)>>2)+m|0;p=(2-n+(m<<1)>>2)-n|0;n=l+d+1|0;b[k>>1]=(n+o|0)>>>1;m=d-l+1|0;b[k+(f<<1)>>1]=(m+p|0)>>>1;b[k+(h<<1)>>1]=(m-p|0)>>>1;b[k+(i<<1)>>1]=(n-o|0)>>>1}o=j+1|0;if((o|0)<4){j=o;k=k+2|0;e=e+4|0}else{break}}return}function oNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0;f=d;d=a;a=0;while(1){b[f>>1]=c[d>>2];b[f+2>>1]=c[d+4>>2];b[f+4>>1]=c[d+8>>2];b[f+6>>1]=c[d+12>>2];b[f+8>>1]=c[d+16>>2];b[f+10>>1]=c[d+20>>2];b[f+12>>1]=c[d+24>>2];b[f+14>>1]=c[d+28>>2];g=a+1|0;if((g|0)<8){f=f+(e<<1)|0;d=d+32|0;a=g}else{break}}return}function pNa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;b[d>>1]=c[a>>2];mrc(d+2|0,0,14)|0;mrc(d+(e<<1)|0,0,16)|0;a=e<<1;mrc(d+(a<<1)|0,0,16)|0;f=a+e|0;mrc(d+(f<<1)|0,0,16)|0;a=f+e|0;mrc(d+(a<<1)|0,0,16)|0;f=a+e|0;mrc(d+(f<<1)|0,0,16)|0;a=f+e|0;mrc(d+(a<<1)|0,0,16)|0;mrc(d+(a+e<<1)|0,0,16)|0;return}function qNa(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((e|0)==1){f=c;g=a;h=0;while(1){i=f+2|0;b[g>>1]=((b[i>>1]|0)+(b[f>>1]|0)|0)>>>1;j=f+4|0;b[g+2>>1]=((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1;i=f+6|0;b[g+4>>1]=((b[i>>1]|0)+(b[j>>1]|0)|0)>>>1;j=f+8|0;b[g+6>>1]=((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1;i=f+10|0;b[g+8>>1]=((b[i>>1]|0)+(b[j>>1]|0)|0)>>>1;j=f+12|0;b[g+10>>1]=((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1;i=f+14|0;b[g+12>>1]=((b[i>>1]|0)+(b[j>>1]|0)|0)>>>1;b[g+14>>1]=((b[f+16>>1]|0)+(b[i>>1]|0)|0)>>>1;i=h+1|0;if((i|0)<8){f=f+(d<<1)|0;g=g+(d<<1)|0;h=i}else{break}}return}else if((e|0)==2){h=a;g=0;f=c;while(1){i=f+(d<<1)|0;b[h>>1]=((b[i>>1]|0)+(b[f>>1]|0)|0)>>>1;b[h+2>>1]=((b[f+(d+1<<1)>>1]|0)+(b[f+2>>1]|0)|0)>>>1;b[h+4>>1]=((b[f+(d+2<<1)>>1]|0)+(b[f+4>>1]|0)|0)>>>1;b[h+6>>1]=((b[f+(d+3<<1)>>1]|0)+(b[f+6>>1]|0)|0)>>>1;b[h+8>>1]=((b[f+(d+4<<1)>>1]|0)+(b[f+8>>1]|0)|0)>>>1;b[h+10>>1]=((b[f+(d+5<<1)>>1]|0)+(b[f+10>>1]|0)|0)>>>1;b[h+12>>1]=((b[f+(d+6<<1)>>1]|0)+(b[f+12>>1]|0)|0)>>>1;b[h+14>>1]=((b[f+(d+7<<1)>>1]|0)+(b[f+14>>1]|0)|0)>>>1;j=g+1|0;if((j|0)<8){h=h+(d<<1)|0;g=j;f=i}else{break}}return}else if((e|0)==3){f=a;g=0;h=c;while(1){i=0;while(1){j=i+1|0;b[f+(i<<1)>>1]=((b[h+(j<<1)>>1]|0)+(b[h+(i<<1)>>1]|0)+(b[h+(i+d<<1)>>1]|0)+(b[h+(j+d<<1)>>1]|0)|0)>>>2;if((j|0)<8){i=j}else{break}}i=g+1|0;if((i|0)<8){f=f+(d<<1)|0;g=i;h=h+(d<<1)|0}else{break}}return}else if((e|0)==0){e=c;c=a;a=0;while(1){b[c>>1]=b[e>>1]|0;b[c+2>>1]=b[e+2>>1]|0;b[c+4>>1]=b[e+4>>1]|0;b[c+6>>1]=b[e+6>>1]|0;b[c+8>>1]=b[e+8>>1]|0;b[c+10>>1]=b[e+10>>1]|0;b[c+12>>1]=b[e+12>>1]|0;b[c+14>>1]=b[e+14>>1]|0;h=a+1|0;if((h|0)<8){e=e+(d<<1)|0;c=c+(d<<1)|0;a=h}else{break}}return}else{return}}function rNa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)==0){g=c;h=a;i=0;while(1){b[h>>1]=(b[h>>1]|0)+(b[g>>1]|0);j=h+2|0;b[j>>1]=(b[j>>1]|0)+(b[g+2>>1]|0);j=h+4|0;b[j>>1]=(b[j>>1]|0)+(b[g+4>>1]|0);j=h+6|0;b[j>>1]=(b[j>>1]|0)+(b[g+6>>1]|0);j=h+8|0;b[j>>1]=(b[j>>1]|0)+(b[g+8>>1]|0);j=h+10|0;b[j>>1]=(b[j>>1]|0)+(b[g+10>>1]|0);j=h+12|0;b[j>>1]=(b[j>>1]|0)+(b[g+12>>1]|0);j=h+14|0;b[j>>1]=(b[j>>1]|0)+(b[g+14>>1]|0);j=i+1|0;if((j|0)<8){g=g+(d<<1)|0;h=h+(d<<1)|0;i=j}else{break}}return}else if((f|0)==1){i=c;h=a;g=0;while(1){j=i+2|0;b[h>>1]=(((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1)+(e[h>>1]|0);k=i+4|0;l=h+2|0;b[l>>1]=(((b[k>>1]|0)+(b[j>>1]|0)|0)>>>1)+(e[l>>1]|0);l=i+6|0;j=h+4|0;b[j>>1]=(((b[l>>1]|0)+(b[k>>1]|0)|0)>>>1)+(e[j>>1]|0);j=i+8|0;k=h+6|0;b[k>>1]=(((b[j>>1]|0)+(b[l>>1]|0)|0)>>>1)+(e[k>>1]|0);k=i+10|0;l=h+8|0;b[l>>1]=(((b[k>>1]|0)+(b[j>>1]|0)|0)>>>1)+(e[l>>1]|0);l=i+12|0;j=h+10|0;b[j>>1]=(((b[l>>1]|0)+(b[k>>1]|0)|0)>>>1)+(e[j>>1]|0);j=i+14|0;k=h+12|0;b[k>>1]=(((b[j>>1]|0)+(b[l>>1]|0)|0)>>>1)+(e[k>>1]|0);k=h+14|0;b[k>>1]=(((b[i+16>>1]|0)+(b[j>>1]|0)|0)>>>1)+(e[k>>1]|0);k=g+1|0;if((k|0)<8){i=i+(d<<1)|0;h=h+(d<<1)|0;g=k}else{break}}return}else if((f|0)==2){g=a;h=0;i=c;while(1){k=i+(d<<1)|0;b[g>>1]=(((b[k>>1]|0)+(b[i>>1]|0)|0)>>>1)+(e[g>>1]|0);j=g+2|0;b[j>>1]=(((b[i+(d+1<<1)>>1]|0)+(b[i+2>>1]|0)|0)>>>1)+(e[j>>1]|0);j=g+4|0;b[j>>1]=(((b[i+(d+2<<1)>>1]|0)+(b[i+4>>1]|0)|0)>>>1)+(e[j>>1]|0);j=g+6|0;b[j>>1]=(((b[i+(d+3<<1)>>1]|0)+(b[i+6>>1]|0)|0)>>>1)+(e[j>>1]|0);j=g+8|0;b[j>>1]=(((b[i+(d+4<<1)>>1]|0)+(b[i+8>>1]|0)|0)>>>1)+(e[j>>1]|0);j=g+10|0;b[j>>1]=(((b[i+(d+5<<1)>>1]|0)+(b[i+10>>1]|0)|0)>>>1)+(e[j>>1]|0);j=g+12|0;b[j>>1]=(((b[i+(d+6<<1)>>1]|0)+(b[i+12>>1]|0)|0)>>>1)+(e[j>>1]|0);j=g+14|0;b[j>>1]=(((b[i+(d+7<<1)>>1]|0)+(b[i+14>>1]|0)|0)>>>1)+(e[j>>1]|0);j=h+1|0;if((j|0)<8){g=g+(d<<1)|0;h=j;i=k}else{break}}return}else if((f|0)==3){f=a;a=0;i=c;while(1){c=0;while(1){h=c+1|0;g=f+(c<<1)|0;b[g>>1]=(((b[i+(h<<1)>>1]|0)+(b[i+(c<<1)>>1]|0)+(b[i+(c+d<<1)>>1]|0)+(b[i+(h+d<<1)>>1]|0)|0)>>>2)+(e[g>>1]|0);if((h|0)<8){c=h}else{break}}c=a+1|0;if((c|0)<8){f=f+(d<<1)|0;a=c;i=i+(d<<1)|0}else{break}}return}else{return}}function sNa(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((e|0)==3){f=a;g=0;h=c;while(1){i=h+2|0;j=h+(d<<1)|0;k=h+(d+1<<1)|0;b[f>>1]=((b[i>>1]|0)+(b[h>>1]|0)+(b[j>>1]|0)+(b[k>>1]|0)|0)>>>2;l=h+4|0;m=h+(d+2<<1)|0;b[f+2>>1]=((b[l>>1]|0)+(b[i>>1]|0)+(b[k>>1]|0)+(b[m>>1]|0)|0)>>>2;k=h+6|0;i=h+(d+3<<1)|0;b[f+4>>1]=((b[k>>1]|0)+(b[l>>1]|0)+(b[m>>1]|0)+(b[i>>1]|0)|0)>>>2;b[f+6>>1]=((b[h+8>>1]|0)+(b[k>>1]|0)+(b[i>>1]|0)+(b[h+(d+4<<1)>>1]|0)|0)>>>2;i=g+1|0;if((i|0)<4){f=f+(d<<1)|0;g=i;h=j}else{break}}return}else if((e|0)==0){b[a>>1]=b[c>>1]|0;b[a+2>>1]=b[c+2>>1]|0;b[a+4>>1]=b[c+4>>1]|0;b[a+6>>1]=b[c+6>>1]|0;b[a+(d<<1)>>1]=b[c+(d<<1)>>1]|0;b[a+(d+1<<1)>>1]=b[c+(d+1<<1)>>1]|0;b[a+(d+2<<1)>>1]=b[c+(d+2<<1)>>1]|0;b[a+(d+3<<1)>>1]=b[c+(d+3<<1)>>1]|0;h=d<<1;g=d<<1;b[a+(h<<1)>>1]=b[c+(g<<1)>>1]|0;b[a+((h|1)<<1)>>1]=b[c+((g|1)<<1)>>1]|0;b[a+(h+2<<1)>>1]=b[c+(g+2<<1)>>1]|0;b[a+(h+3<<1)>>1]=b[c+(g+3<<1)>>1]|0;f=h+d|0;h=g+d|0;b[a+(f<<1)>>1]=b[c+(h<<1)>>1]|0;b[a+(f+1<<1)>>1]=b[c+(h+1<<1)>>1]|0;b[a+(f+2<<1)>>1]=b[c+(h+2<<1)>>1]|0;b[a+(f+3<<1)>>1]=b[c+(h+3<<1)>>1]|0;return}else if((e|0)==1){h=c;f=a;g=0;while(1){j=h+2|0;b[f>>1]=((b[j>>1]|0)+(b[h>>1]|0)|0)>>>1;i=h+4|0;b[f+2>>1]=((b[i>>1]|0)+(b[j>>1]|0)|0)>>>1;j=h+6|0;b[f+4>>1]=((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1;b[f+6>>1]=((b[h+8>>1]|0)+(b[j>>1]|0)|0)>>>1;j=g+1|0;if((j|0)<4){h=h+(d<<1)|0;f=f+(d<<1)|0;g=j}else{break}}return}else if((e|0)==2){e=a;a=0;g=c;while(1){c=g+(d<<1)|0;b[e>>1]=((b[c>>1]|0)+(b[g>>1]|0)|0)>>>1;b[e+2>>1]=((b[g+(d+1<<1)>>1]|0)+(b[g+2>>1]|0)|0)>>>1;b[e+4>>1]=((b[g+(d+2<<1)>>1]|0)+(b[g+4>>1]|0)|0)>>>1;b[e+6>>1]=((b[g+(d+3<<1)>>1]|0)+(b[g+6>>1]|0)|0)>>>1;f=a+1|0;if((f|0)<4){e=e+(d<<1)|0;a=f;g=c}else{break}}return}else{return}}function tNa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((f|0)==2){g=a;h=0;i=c;while(1){j=i+(d<<1)|0;b[g>>1]=(((b[j>>1]|0)+(b[i>>1]|0)|0)>>>1)+(e[g>>1]|0);k=g+2|0;b[k>>1]=(((b[i+(d+1<<1)>>1]|0)+(b[i+2>>1]|0)|0)>>>1)+(e[k>>1]|0);k=g+4|0;b[k>>1]=(((b[i+(d+2<<1)>>1]|0)+(b[i+4>>1]|0)|0)>>>1)+(e[k>>1]|0);k=g+6|0;b[k>>1]=(((b[i+(d+3<<1)>>1]|0)+(b[i+6>>1]|0)|0)>>>1)+(e[k>>1]|0);k=h+1|0;if((k|0)<4){g=g+(d<<1)|0;h=k;i=j}else{break}}return}else if((f|0)==0){b[a>>1]=(b[a>>1]|0)+(b[c>>1]|0);i=a+2|0;b[i>>1]=(b[i>>1]|0)+(b[c+2>>1]|0);i=a+4|0;b[i>>1]=(b[i>>1]|0)+(b[c+4>>1]|0);i=a+6|0;b[i>>1]=(b[i>>1]|0)+(b[c+6>>1]|0);i=a+(d<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(d<<1)>>1]|0);i=a+(d+1<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(d+1<<1)>>1]|0);i=a+(d+2<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(d+2<<1)>>1]|0);i=a+(d+3<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(d+3<<1)>>1]|0);i=d<<1;h=a+(i<<1)|0;g=d<<1;b[h>>1]=(b[h>>1]|0)+(b[c+(g<<1)>>1]|0);h=a+((i|1)<<1)|0;b[h>>1]=(b[h>>1]|0)+(b[c+((g|1)<<1)>>1]|0);h=a+(i+2<<1)|0;b[h>>1]=(b[h>>1]|0)+(b[c+(g+2<<1)>>1]|0);h=a+(i+3<<1)|0;b[h>>1]=(b[h>>1]|0)+(b[c+(g+3<<1)>>1]|0);h=i+d|0;i=a+(h<<1)|0;j=g+d|0;b[i>>1]=(b[i>>1]|0)+(b[c+(j<<1)>>1]|0);i=a+(h+1<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(j+1<<1)>>1]|0);i=a+(h+2<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(j+2<<1)>>1]|0);i=a+(h+3<<1)|0;b[i>>1]=(b[i>>1]|0)+(b[c+(j+3<<1)>>1]|0);return}else if((f|0)==1){j=c;i=a;h=0;while(1){g=j+2|0;b[i>>1]=(((b[g>>1]|0)+(b[j>>1]|0)|0)>>>1)+(e[i>>1]|0);k=j+4|0;l=i+2|0;b[l>>1]=(((b[k>>1]|0)+(b[g>>1]|0)|0)>>>1)+(e[l>>1]|0);l=j+6|0;g=i+4|0;b[g>>1]=(((b[l>>1]|0)+(b[k>>1]|0)|0)>>>1)+(e[g>>1]|0);g=i+6|0;b[g>>1]=(((b[j+8>>1]|0)+(b[l>>1]|0)|0)>>>1)+(e[g>>1]|0);g=h+1|0;if((g|0)<4){j=j+(d<<1)|0;i=i+(d<<1)|0;h=g}else{break}}return}else if((f|0)==3){f=a;a=0;h=c;while(1){c=h+2|0;i=h+(d<<1)|0;j=h+(d+1<<1)|0;b[f>>1]=(((b[c>>1]|0)+(b[h>>1]|0)+(b[i>>1]|0)+(b[j>>1]|0)|0)>>>2)+(e[f>>1]|0);g=h+4|0;l=h+(d+2<<1)|0;k=f+2|0;b[k>>1]=(((b[g>>1]|0)+(b[c>>1]|0)+(b[j>>1]|0)+(b[l>>1]|0)|0)>>>2)+(e[k>>1]|0);k=h+6|0;j=h+(d+3<<1)|0;c=f+4|0;b[c>>1]=(((b[k>>1]|0)+(b[g>>1]|0)+(b[l>>1]|0)+(b[j>>1]|0)|0)>>>2)+(e[c>>1]|0);c=f+6|0;b[c>>1]=(((b[h+8>>1]|0)+(b[k>>1]|0)+(b[j>>1]|0)+(b[h+(d+4<<1)>>1]|0)|0)>>>2)+(e[c>>1]|0);c=a+1|0;if((c|0)<4){f=f+(d<<1)|0;a=c;h=i}else{break}}return}else{return}}function uNa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;f=i;g=c[e+60>>2]|0;h=g+80|0;j=g;c[j>>2]=e;KIb(e,48,2639136,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=h;mrc(g+96|0,15,66)|0;c[l>>2]=7;c[g+84>>2]=7;a[g+88|0]=4;a[g+89|0]=4;m=(c[e+216>>2]|0)!=0;n=g+90|0;a[n]=m?1:2;a[g+453|0]=1;o=g+36|0;c[o>>2]=256;p=g+40|0;c[p>>2]=256;a[g+452|0]=m?0:2;m=g+8|0;c[m>>2]=c[e+120>>2];q=g+12|0;c[q>>2]=c[e+124>>2];mrc(g+16|0,8,3)|0;r=g;s=e+140|0;e=c[s>>2]|0;if((e|0)==8){c[g+32>>2]=1}else if((e|0)==2){c[g+32>>2]=3}else{a[g+28|0]=1;c[g+32>>2]=3;vLa(c[s>>2]|0,g+20|0,g+24|0)}JNa();sUa();s=0;do{e=(s*384|0)-18432|0;c[5790800+(s<<2)>>2]=(e|0)>0?e:0;e=ca(s,s)|0;t=(e<<1)+64&-128;c[5790288+(s<<2)>>2]=(t|0)>0?t:0;t=s>>>5&2|1;u=64-(ca(t<<4,t)|0)+(ca(t-2|0,s)|0)<<7;c[5791824+(s<<2)>>2]=(u|0)>0?u:0;u=((1-(s<<2)<<5)+e<<1)+8192&-128;c[5791312+(s<<2)>>2]=(u|0)>0?u:0;s=s+1|0;}while((s|0)<128);s=g+32|0;u=c[s>>2]|0;if((u|0)>0){e=0;t=0;v=c[l>>2]|0;w=u;while(1){if((v|0)>0){u=r+16+t|0;x=0;y=e;z=0;A=v;while(1){B=A+~z|0;C=(z|0)!=0?3:1;D=(z|0)>0|0;E=x;F=y;G=0;while(1){if((a[n]|0)==2){H=8192e4/(c[1515408+((G+D|0)*40|0)+(B<<2)>>2]|0)|0;I=H>>>0>65535>>>0;J=I?H>>>16:H;K=I?16:0;if((J&65280|0)==0){L=K;M=J}else{L=K|8;M=J>>>8}J=(d[1359664+M|0]|0)+L|0;K=11-J|0;if((K|0)<0){N=H>>J-11&65535}else{N=H<<K&65535}O=N&2047;P=13-J+(d[u]|0)&255}else{O=F;P=(G>>>1&1)+D+(d[u]|0)&255}a[r+164+E|0]=P;b[r+260+(E<<1)>>1]=O;J=G+1|0;if((J|0)<(C|0)){E=E+1|0;F=O;G=J}else{break}}G=z+1|0;Q=c[l>>2]|0;if((G|0)<(Q|0)){x=x+C|0;y=O;z=G;A=Q}else{break}}R=O;S=Q;T=c[s>>2]|0}else{R=e;S=v;T=w}A=t+1|0;if((A|0)<(T|0)){e=R;t=A;v=S;w=T}else{break}}}T=h;h=g+164|0;w=c[o>>2]|0;S=((c[m>>2]|0)-1+w|0)/(w|0)|0;w=g+44|0;c[w>>2]=S;v=c[p>>2]|0;t=((c[q>>2]|0)-1+v|0)/(v|0)|0;v=g+48|0;c[v>>2]=t;R=hJb(ca(S<<2,t)|0)|0;t=g+456|0;c[t>>2]=R;if((R|0)==0){U=-12;i=f;return U|0}R=c[v>>2]|0;a:do{if((R|0)>0){S=g+20|0;e=g+24|0;Q=0;O=0;l=c[w>>2]|0;P=R;b:while(1){N=Q+1|0;if((l|0)>0){L=0;M=O;n=c[s>>2]|0;while(1){A=c[t>>2]|0;z=pJb(n*232|0)|0;y=A+(M<<2)|0;c[y>>2]=z;if((z|0)==0){U=-12;V=42;break b}z=L+1|0;A=0;while(1){W=c[s>>2]|0;if((A|0)>=(W|0)){break}x=c[y>>2]|0;u=x+(A*232|0)|0;G=c[o>>2]|0;F=ca(G,L)|0;E=F&65535;D=x+(A*232|0)+224|0;b[D>>1]=E;B=x+(A*232|0)+216|0;b[B>>1]=E;E=ca(G,z)|0;G=c[m>>2]|0;J=(E|0)>(G|0)?G:E;E=J&65535;G=x+(A*232|0)+226|0;b[G>>1]=E;K=x+(A*232|0)+218|0;b[K>>1]=E;E=c[p>>2]|0;H=ca(E,Q)|0;I=H&65535;X=x+(A*232|0)+228|0;b[X>>1]=I;Y=x+(A*232|0)+220|0;b[Y>>1]=I;I=ca(E,N)|0;E=c[q>>2]|0;Z=(I|0)>(E|0)?E:I;I=Z&65535;E=x+(A*232|0)+230|0;b[E>>1]=I;_=x+(A*232|0)+222|0;b[_>>1]=I;do{if((A|0)>0){I=c[S>>2]|0;x=1<<I;$=(F&65535)-1+x>>I&65535;b[D>>1]=$;b[B>>1]=$;$=(J&65535)-1+x>>I&65535;b[G>>1]=$;b[K>>1]=$;$=c[e>>2]|0;x=1<<$;aa=(H&65535)-1+x>>$&65535;b[X>>1]=aa;b[Y>>1]=aa;aa=(Z&65535)-1+x>>$&65535;b[E>>1]=aa;b[_>>1]=aa;ba=d[r+16+A|0]|0;da=I;ea=$;V=36}else{$=d[r+16+A|0]|0;if((A|0)==0){fa=1;ga=1;ha=$;break}ba=$;da=c[S>>2]|0;ea=c[e>>2]|0;V=36}}while(0);if((V|0)==36){V=0;fa=1<<ea;ga=1<<da;ha=ba}_=LNa(u,T,h,ha,ga,fa,c[j>>2]|0)|0;if((_|0)==0){A=A+1|0}else{U=_;V=42;break b}}ia=M+1|0;ja=c[w>>2]|0;if((z|0)<(ja|0)){L=z;M=ia;n=W}else{break}}ka=ia;la=ja;ma=c[v>>2]|0}else{ka=O;la=l;ma=P}if((N|0)<(ma|0)){Q=N;O=ka;l=la;P=ma}else{break a}}if((V|0)==42){i=f;return U|0}}}while(0);KIb(c[j>>2]|0,48,2616512,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;U=0;i=f;return U|0}



function uMb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0;g=i;i=i+1928|0;h=g|0;j=g+160|0;k=g+232|0;l=g+776|0;m=g+840|0;n=g+1384|0;o=f+8632|0;p=c[o>>2]|0;q=c[f+28816>>2]|0;r=f+18648|0;s=c[r>>2]|0;t=f+19360|0;c[t>>2]=0;u=f+27984|0;a[u]=0;if((p|0)!=3){v=f+19344|0;w=c[v>>2]|0;if((w|0)==3){pe[c[f+37436>>2]&1023](c[f+24568>>2]|0,32,c[f+24544>>2]|0,16,16);x=16>>>((c[f+18576>>2]|0)>>>0);y=f+37448|0;pe[c[y>>2]&1023](c[f+24572>>2]|0,32,c[f+24548>>2]|0,16,x);pe[c[y>>2]&1023](c[f+24576>>2]|0,32,c[f+24552>>2]|0,16,x);i=g;return}do{if((c[f+18944>>2]|0)==0){if((w|0)==6){c[v>>2]=4;z=1;A=301;break}else if((w|0)==18){c[v>>2]=7;z=1;A=301;break}else{B=1;A=196;break}}else{B=0;A=196}}while(0);a:do{if((A|0)==196){switch(w|0){case 2:{c[f+19356>>2]=0;x=k+31&-32;y=l+31&-32;C=f+28836|0;D=f+37600|0;E=f+18644|0;F=f+37760|0;G=f+33820|0;H=f+33816|0;I=f+18640|0;J=f+37720|0;K=f+37644|0;L=f+37736|0;M=f+37764|0;N=f+37628|0;O=f+37724|0;P=f+37632|0;Q=f+37740|0;R=f+37608|0;S=f+37604|0;T=f+37656|0;U=f+37436|0;V=f+37464|0;W=c[f+24544>>2]|0;X=c[f+24568>>2]|0;Y=(s|0)!=0?0:9;Z=c[f+19368>>2]|0;do{if((c[C>>2]|0)==0){qe[c[f+36532+(Z<<2)>>2]&1023](X)}else{_=c[(c[f+15144>>2]|0)+156>>2]<<c[f+18660>>2];if((Z|0)==1){pe[c[V>>2]&1023](X,32,(c[f+24556>>2]|0)-1|0,_,16);break}else if((Z|0)==0){pe[c[U>>2]&1023](X,32,(c[f+24556>>2]|0)+(-_|0)|0,_,16);break}else{qe[c[f+36532+(Z<<2)>>2]&1023](X);break}}}while(0);if((c[C>>2]|0)!=0){Z=0;U=0;do{V=hf[c[T>>2]&1023](f+17024+(Z<<5)|0,W+(d[1901416+Z|0]|0)|0,X+(e[1901496+(Z<<1)>>1]|0)|0,y+(d[1901320+Z|0]<<1)|0)|0;a[(d[19280+Z|0]|0)+(f+27984)|0]=V;U=V|U;Z=Z+1|0;}while((Z|0)<16);c[t>>2]=c[t>>2]|(U*15|0);Z=0;while(1){if((Z|0)>=16){$=0;break}if((c[y+(Z<<1)>>2]|0)==0){Z=Z+2|0}else{$=1;break}}a[f+27984|0]=$;re[c[K>>2]&1023](f+15360|0,y);aa=B;break a}Z=f+27996|0;c[Z>>2]=0;U=f+28004|0;c[U>>2]=0;T=f+28012|0;c[T>>2]=0;C=f+28020|0;c[C>>2]=0;ef[c[D>>2]&4095](x,W,X);if((c[E>>2]|0)==0){ba=0}else{V=0;while(1){mf[c[F>>2]&2047](x+(V<<5)|0,c[G>>2]|0,c[H>>2]|0,16);_=V+1|0;if((_|0)<16){V=_}else{ba=0;break}}}do{V=x+(ba<<5)|0;b[y+(d[1901528+ba|0]<<1)>>1]=b[V>>1]|0;b[V>>1]=0;ba=ba+1|0;}while((ba|0)<16);if((c[I>>2]|0)==0){V=f+1716|0;H=f+1748|0;G=f+1652|0;F=Y;E=0;W=0;while(1){D=W<<2;_=Ee[c[J>>2]&511](x+(D<<5)|0,(c[V>>2]|0)+(q<<5)|0,(c[H>>2]|0)+(q<<5)|0)|0;if((_|0)==0){da=E;ea=F}else{fa=F;ga=D;D=_;while(1){_=d[98856+D|0]|0;ha=_+ga|0;ia=D>>_+1;ja=_+ga|0;_=f+17024+(ja<<5)|0;ka=x+(ha<<5)|0;re[c[K>>2]&1023](_,ka);ef[c[L>>2]&4095](ka,c[G>>2]|0,q);if((fa|0)<6){la=(ve[c[M>>2]&4095](_)|0)+fa|0}else{la=fa}a[(d[19280+ja|0]|0)+(f+27984)|0]=1;if((ia|0)==0){da=15;ea=la;break}else{fa=la;ga=ha+1|0;D=ia}}}D=W+1|0;if((D|0)<4){F=ea;E=da;W=D}else{ma=da;na=ea;break}}}else{W=f+1652|0;E=Y;F=0;G=0;while(1){H=x+(G<<5)|0;if((_Tb(f,H,0,q,1,1,0,G)|0)==0){oa=F;pa=E}else{V=f+17024+(G<<5)|0;re[c[K>>2]&1023](V,H);ef[c[L>>2]&4095](H,c[W>>2]|0,q);if((E|0)<6){qa=(ve[c[M>>2]&4095](V)|0)+E|0}else{qa=E}a[(d[19280+G|0]|0)+(f+27984)|0]=1;oa=15;pa=qa}V=G+1|0;if((V|0)<16){E=pa;F=oa;G=V}else{ma=oa;na=pa;break}}}if((na|0)<6){c[Z>>2]=0;c[U>>2]=0;c[T>>2]=0;c[C>>2]=0;ra=0}else{c[t>>2]=c[t>>2]|ma;ra=ma}qe[c[N>>2]&1023](y);if((c[I>>2]|0)==0){sa=Ee[c[O>>2]&511](y,(e[(c[f+1716>>2]|0)+(q<<5)>>1]|0)>>>1,e[(c[f+1748>>2]|0)+(q<<5)>>1]<<1)|0}else{sa=YTb(f,y,0,q,0,1,48)|0}a[f+27984|0]=sa;G=(sa|0)!=0;do{if(G){re[c[K>>2]&1023](f+15360|0,y);qe[c[P>>2]&1023](y);ef[c[Q>>2]&4095](y,c[f+1652>>2]|0,q);if((ra|0)==0){break}else{ta=0}while(1){b[x+(ta<<5)>>1]=b[y+(d[1901528+ta|0]<<1)>>1]|0;F=ta+1|0;if((F|0)<16){ta=F}else{A=254;break}}}else{A=254}}while(0);do{if((A|0)==254){if((ra|0)==0){if(G){break}else{aa=B;break a}}else{re[c[S>>2]&1023](X,x);aa=B;break a}}}while(0);re[c[R>>2]&1023](X,y);aa=B;break a;break};case 1:{c[f+19356>>2]=1;x=f+19376|0;do{if((c[x>>2]|0)!=0){pe[c[f+37436>>2]&1023](c[f+24568>>2]|0,32,f+22112|0,16,16);c[f+27996>>2]=c[f+23248>>2];c[f+28004>>2]=c[f+23252>>2];c[f+28012>>2]=c[f+23256>>2];c[f+28020>>2]=c[f+23260>>2];c[t>>2]=c[f+23268>>2];if((c[x>>2]|0)!=2){break}Ee[c[f+37520>>2]&511](f+15488|0,f+22368|0,384)|0}}while(0);y=h+31&-32;X=j+31&-32;R=f+36740|0;S=f+28836|0;G=f+37612|0;Q=f+18644|0;P=f+18640|0;K=f+37712|0;O=f+37640|0;I=f+37732|0;N=f+37616|0;C=f+37760|0;T=f+33820|0;U=f+33816|0;Z=f+37648|0;F=f+15144|0;E=f+18660|0;M=f+37448|0;W=f+24544|0;L=f+24568|0;Y=f+1732|0;V=f+1764|0;H=f+1668|0;J=f+24556|0;D=(c[x>>2]|0)!=0?3:0;while(1){ga=d[19280+(D<<2)|0]|0;fa=a[f+27936+ga|0]|0;ia=D>>1;ha=D<<3&8;ja=(c[W>>2]|0)+(ha|ia<<7)|0;_=(c[L>>2]|0)+(ha|ia<<8)|0;mf[c[R>>2]&2047](_,X,c[f+18788+(D<<2)>>2]|0,d[19488+fa|0]|0);do{if((c[S>>2]|0)==0){re[c[f+36560+(fa<<2)>>2]&1023](_,X)}else{ia=c[(c[F>>2]|0)+156>>2]<<c[E>>2];ka=c[J>>2]|0;ua=(ca(D>>>1<<3,ia)|0)+ha|0;if((fa|0)==1){pe[c[M>>2]&1023](_,32,ka+(ua-1)|0,ia,8);break}else if((fa|0)==0){pe[c[M>>2]&1023](_,32,ka+(ua-ia)|0,ia,8);break}else{re[c[f+36560+(fa<<2)>>2]&1023](_,X);break}}}while(0);do{if((c[S>>2]|0)==0){ef[c[G>>2]&4095](y,ja,_);if((c[Q>>2]|0)!=0){mf[c[C>>2]&2047](y,(c[T>>2]|0)+256|0,(c[U>>2]|0)+128|0,64)}if((c[P>>2]|0)==0){va=Ee[c[K>>2]&511](y,(c[Y>>2]|0)+(q<<7)|0,(c[V>>2]|0)+(q<<7)|0)|0}else{va=$Tb(f,y,0,q,5,1,0,D)|0}if((va|0)==0){b[f+27984+ga>>1]=0;b[ga+8+(f+27984)>>1]=0;break}else{c[t>>2]=c[t>>2]|1<<D;re[c[O>>2]&1023](f+15488+(D<<7)|0,y);ef[c[I>>2]&4095](y,c[H>>2]|0,q);re[c[N>>2]&1023](_,y);b[f+27984+ga>>1]=257;b[ga+8+(f+27984)>>1]=257;break}}else{fa=Ee[c[Z>>2]&511](f+15488+(D<<7)|0,ja,_)|0;ha=(fa*257|0)&65535;b[f+27984+ga>>1]=ha;b[ga+8+(f+27984)>>1]=ha;c[t>>2]=c[t>>2]|fa<<D}}while(0);ga=D+1|0;if((ga|0)<4){D=ga}else{aa=B;break}}break};case 18:{if((c[f+19380>>2]|0)==0){YOb(f);wa=c[o>>2]|0}else{wa=p}c[f+27996>>2]=0;c[f+28004>>2]=0;c[f+28012>>2]=0;c[f+28020>>2]=0;c[f+28036>>2]=0;c[f+28044>>2]=0;c[f+28076>>2]=0;c[f+28084>>2]=0;if((wa|0)>1){c[f+28052>>2]=0;c[f+28060>>2]=0;c[f+28092>>2]=0;c[f+28100>>2]=0}c[t>>2]=0;c[f+19364>>2]=0;b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]=0;i=g;return};case 6:{do{if((c[f+19380>>2]|0)==0){D=b[f+28240>>1]|0;Z=c[f+18668>>2]|0;y=c[f+18676>>2]|0;if((D|0)<(Z|0)){xa=Z}else{xa=(D|0)>(y|0)?y:D}D=b[f+28242>>1]|0;y=c[f+18672>>2]|0;Z=c[f+18680>>2]|0;if((D|0)<(y|0)){ya=y}else{ya=(D|0)>(Z|0)?Z:D}Te[c[f+37376>>2]&255](c[f+24568>>2]|0,32,f+24588|0,c[f+27916>>2]|0,xa,ya,16,16,f+3584|0);D=c[f+18576>>2]|0;Z=16>>>(D>>>0);if((ya|xa|0)==0){mf[c[f+37476>>2]&2047](c[f+24572>>2]|0,c[f+24604>>2]|0,c[f+27920>>2]|0,Z)}else{Te[c[f+37384>>2]&255](c[f+24572>>2]|0,c[f+24576>>2]|0,32,c[f+24604>>2]|0,c[f+27920>>2]|0,xa,ya<<1>>D,8,Z)}D=c[f+3676>>2]|0;if((D|0)!=0){y=c[f+24572>>2]|0;_e[c[D+8>>2]&511](y,32,y,32,f+3632|0,Z)}y=c[f+3724>>2]|0;if((y|0)==0){break}D=c[f+24576>>2]|0;_e[c[y+8>>2]&511](D,32,D,32,f+3680|0,Z)}}while(0);c[f+27996>>2]=0;c[f+28004>>2]=0;c[f+28012>>2]=0;c[f+28020>>2]=0;c[f+28036>>2]=0;c[f+28044>>2]=0;c[f+28076>>2]=0;c[f+28084>>2]=0;if((c[o>>2]|0)>1){c[f+28052>>2]=0;c[f+28060>>2]=0;c[f+28092>>2]=0;c[f+28100>>2]=0}c[t>>2]=0;c[f+19364>>2]=0;b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]=0;i=g;return};case 0:{c[f+19356>>2]=0;Z=f+19376|0;do{if((c[Z>>2]|0)!=0){pe[c[f+37436>>2]&1023](c[f+24568>>2]|0,32,f+21856|0,16,16);c[f+27996>>2]=c[f+23232>>2];c[f+28004>>2]=c[f+23236>>2];c[f+28012>>2]=c[f+23240>>2];c[f+28020>>2]=c[f+23244>>2];c[t>>2]=c[f+23264>>2];if((c[Z>>2]|0)!=2){break}Ee[c[f+37520>>2]&511](f+17024|0,f+22752|0,480)|0}}while(0);D=l+31&-32;y=f+28836|0;N=f+37572|0;H=f+18644|0;I=f+18640|0;O=f+37716|0;V=f+37644|0;Y=f+37736|0;K=f+37576|0;P=f+37760|0;U=f+33820|0;T=f+33816|0;C=f+37652|0;Q=f+15144|0;G=f+18660|0;S=f+37460|0;X=f+24568|0;M=f+24544|0;J=f+1716|0;E=f+1748|0;F=f+1652|0;R=f+24556|0;L=(c[Z>>2]|0)!=0?15:0;while(1){W=e[1901496+(L<<1)>>1]|0;x=c[X>>2]|0;ga=d[19280+L|0]|0;_=a[f+27936+ga|0]|0;if((c[f+18804+(L<<2)>>2]&6|0)==2){c[x+(W-28)>>2]=ca(d[x+(W-29)|0]|0,16843009)|0;za=c[X>>2]|0}else{za=x}x=(c[M>>2]|0)+(d[1901416+L|0]|0)|0;ja=za+W|0;do{if((c[y>>2]|0)==0){qe[c[f+36608+(_<<2)>>2]&1023](ja)}else{W=c[(c[Q>>2]|0)+156>>2]<<c[G>>2];fa=c[R>>2]|0;ha=(ca(W<<2,d[1901384+L|0]|0)|0)+(d[1901592+L|0]<<2)|0;if((_|0)==0){pe[c[S>>2]&1023](ja,32,fa+(ha-W)|0,W,4);break}else if((_|0)==1){pe[c[S>>2]&1023](ja,32,fa+(ha-1)|0,W,4);break}else{qe[c[f+36608+(_<<2)>>2]&1023](ja);break}}}while(0);do{if((c[y>>2]|0)==0){ef[c[N>>2]&4095](D,x,ja);if((c[H>>2]|0)!=0){mf[c[P>>2]&2047](D,c[U>>2]|0,c[T>>2]|0,16)}if((c[I>>2]|0)==0){Aa=Ee[c[O>>2]&511](D,(c[J>>2]|0)+(q<<5)|0,(c[E>>2]|0)+(q<<5)|0)|0}else{Aa=_Tb(f,D,0,q,2,1,0,L)|0}a[f+27984+ga|0]=Aa;if((Aa|0)==0){break}c[t>>2]=c[t>>2]|1<<(L>>2);re[c[V>>2]&1023](f+17024+(L<<5)|0,D);ef[c[Y>>2]&4095](D,c[F>>2]|0,q);re[c[K>>2]&1023](ja,D)}else{_=Ee[c[C>>2]&511](f+17024+(L<<5)|0,x,ja)|0;a[f+27984+ga|0]=_;c[t>>2]=c[t>>2]|_<<(L>>2)}}while(0);ga=L+1|0;if((ga|0)<16){L=ga}else{aa=B;break}}break};default:{z=B;A=301;break a}}}}while(0);b:do{if((A|0)==301){if((c[f+19380>>2]|0)==0){YOb(f)}B=(c[f+19356>>2]|0)!=0;if((c[f+28836>>2]|0)!=0){if(B){Aa=f+37648|0;za=f+24544|0;ya=f+24568|0;xa=Ee[c[Aa>>2]&511](f+15488|0,c[za>>2]|0,c[ya>>2]|0)|0;wa=(xa*257|0)&65535;b[f+27996>>1]=wa;b[f+28004>>1]=wa;c[t>>2]=c[t>>2]|xa;xa=Ee[c[Aa>>2]&511](f+15616|0,(c[za>>2]|0)+8|0,(c[ya>>2]|0)+8|0)|0;wa=(xa*257|0)&65535;b[f+27998>>1]=wa;b[f+28006>>1]=wa;c[t>>2]=c[t>>2]|xa<<1;xa=Ee[c[Aa>>2]&511](f+15744|0,(c[za>>2]|0)+128|0,(c[ya>>2]|0)+256|0)|0;wa=(xa*257|0)&65535;b[f+28012>>1]=wa;b[f+28020>>1]=wa;c[t>>2]=c[t>>2]|xa<<2;xa=Ee[c[Aa>>2]&511](f+15872|0,(c[za>>2]|0)+136|0,(c[ya>>2]|0)+264|0)|0;ya=(xa*257|0)&65535;b[f+28014>>1]=ya;b[f+28022>>1]=ya;c[t>>2]=c[t>>2]|xa<<3;aa=z;break}xa=f+37652|0;ya=f+24544|0;za=f+24568|0;Aa=0;while(1){wa=Ee[c[xa>>2]&511](f+17024+(Aa<<5)|0,(c[ya>>2]|0)+(d[1901416+Aa|0]|0)|0,(c[za>>2]|0)+(e[1901496+(Aa<<1)>>1]|0)|0)|0;a[(d[19280+Aa|0]|0)+(f+27984)|0]=wa;c[t>>2]=c[t>>2]|wa<<(Aa>>2);wa=Aa+1|0;if((wa|0)<16){Aa=wa}else{aa=z;break b}}}if(B){Aa=m+31&-32;za=f+18640|0;if((c[za>>2]|0)==0){Ba=1}else{Ba=(c[f+152>>2]|0)==0|0}ya=f+18644|0;xa=f+37712|0;wa=f+37640|0;p=(Ba&s|0)==0;va=f+37772|0;ra=f+37760|0;ta=f+33820|0;sa=f+33816|0;ma=f+37732|0;na=f+37616|0;c[f+27996>>2]=0;c[f+28004>>2]=0;c[f+28012>>2]=0;c[f+28020>>2]=0;pa=f+24568|0;ef[c[f+37620>>2]&4095](Aa,c[f+24544>>2]|0,c[pa>>2]|0);oa=(c[f+33824>>2]|0)+4|0;c[oa>>2]=(c[oa>>2]|0)+(c[ya>>2]<<2);oa=f+1736|0;qa=f+1768|0;if(p){ea=0;da=0;while(1){la=Aa+(da<<7)|0;if((c[ya>>2]|0)!=0){mf[c[ra>>2]&2047](la,(c[ta>>2]|0)+256|0,(c[sa>>2]|0)+128|0,64)}if((c[za>>2]|0)==0){Ca=Ee[c[xa>>2]&511](la,(c[oa>>2]|0)+(q<<7)|0,(c[qa>>2]|0)+(q<<7)|0)|0}else{Ca=$Tb(f,la,1,q,5,0,0,da)|0}if((Ca|0)==0){Da=ea}else{re[c[wa>>2]&1023](f+15488+(da<<7)|0,la);Da=1<<da|ea}la=da+1|0;if((la|0)<4){ea=Da;da=la}else{Ea=0;Fa=Da;break}}}else{da=0;ea=0;B=0;while(1){la=Aa+(B<<7)|0;if((c[ya>>2]|0)!=0){mf[c[ra>>2]&2047](la,(c[ta>>2]|0)+256|0,(c[sa>>2]|0)+128|0,64)}if((c[za>>2]|0)==0){Ga=Ee[c[xa>>2]&511](la,(c[oa>>2]|0)+(q<<7)|0,(c[qa>>2]|0)+(q<<7)|0)|0}else{Ga=$Tb(f,la,1,q,5,0,0,B)|0}do{if((Ga|0)==0){Ha=ea;Ia=da}else{ba=f+15488+(B<<7)|0;re[c[wa>>2]&1023](ba,la);$=ve[c[va>>2]&4095](ba)|0;ba=$+da|0;if(($|0)<=3){Ha=ea;Ia=ba;break}Ha=1<<B|ea;Ia=ba}}while(0);la=B+1|0;if((la|0)<4){da=Ia;ea=Ha;B=la}else{Ea=Ia;Fa=Ha;break}}}if(!((Ea|0)>5|p)){aa=z;break}c[t>>2]=c[t>>2]|Fa;if((Fa|0)==0){aa=z;break}B=f+1672|0;ea=0;da=Fa;while(1){va=d[98856+da|0]|0;wa=va+ea|0;qa=da>>va+1;va=Aa+(wa<<7)|0;ef[c[ma>>2]&4095](va,c[B>>2]|0,q);re[c[na>>2]&1023]((c[pa>>2]|0)+(wa<<3&8|wa>>>1<<8)|0,va);va=d[19280+(wa<<2)|0]|0;b[f+27984+va>>1]=257;b[va+8+(f+27984)>>1]=257;if((qa|0)==0){aa=z;break}else{ea=wa+1|0;da=qa}}}else{da=n+31&-32;ea=f+37760|0;pa=f+33820|0;na=f+33816|0;B=(s|0)!=0?0:6;ma=f+18640|0;Aa=f+37720|0;p=f+1720|0;qa=f+1752|0;wa=f+37644|0;va=f+37736|0;oa=f+37768|0;xa=f+37588|0;za=f+27996|0;c[za>>2]=0;sa=f+28004|0;c[sa>>2]=0;ta=f+28012|0;c[ta>>2]=0;ra=f+28020|0;c[ra>>2]=0;ya=f+24568|0;ef[c[f+37600>>2]&4095](da,c[f+24544>>2]|0,c[ya>>2]|0);if((c[f+18644>>2]|0)!=0){la=c[f+33824>>2]|0;c[la>>2]=(c[la>>2]|0)+16;la=0;do{mf[c[ea>>2]&2047](da+(la<<5)|0,c[pa>>2]|0,c[na>>2]|0,16);la=la+1|0;}while((la|0)<16)}la=f+1656|0;na=0;pa=0;ea=0;while(1){do{if((c[ma>>2]|0)==0){ba=ea<<2;$=Ee[c[Aa>>2]&511](da+(ba<<5)|0,(c[p>>2]|0)+(q<<5)|0,(c[qa>>2]|0)+(q<<5)|0)|0;if(($|0)==0){Ja=pa;Ka=na;break}else{La=B;Ma=ba;Na=$}while(1){ba=d[98856+Na|0]|0;w=ba+Ma|0;L=Na>>ba+1;ba=f+17024+(w<<5)|0;C=da+(w<<5)|0;re[c[wa>>2]&1023](ba,C);ef[c[va>>2]&4095](C,c[la>>2]|0,q);if((La|0)<6){Oa=(ve[c[oa>>2]&4095](ba)|0)+La|0}else{Oa=La}a[(d[19280+w|0]|0)+(f+27984)|0]=1;if((L|0)==0){Pa=$;Qa=Oa;A=348;break}else{La=Oa;Ma=w+1|0;Na=L}}}else{$=ea<<2;L=B;w=0;ba=0;while(1){C=ba+$|0;D=da+(C<<5)|0;if((_Tb(f,D,1,q,2,0,0,C)|0)==0){Ra=w;Sa=L}else{K=f+17024+(C<<5)|0;re[c[wa>>2]&1023](K,D);ef[c[va>>2]&4095](D,c[la>>2]|0,q);if((L|0)<6){Ta=(ve[c[oa>>2]&4095](K)|0)+L|0}else{Ta=L}a[(d[19280+C|0]|0)+(f+27984)|0]=1;Ra=1;Sa=Ta}C=ba+1|0;if((C|0)<4){L=Sa;w=Ra;ba=C}else{Pa=Ra;Qa=Sa;A=348;break}}}}while(0);do{if((A|0)==348){A=0;if((Pa|0)==0){Ja=pa;Ka=na;break}ba=Qa+na|0;if((Qa|0)<4){w=d[19280+(ea<<2)|0]|0;b[f+27984+w>>1]=0;b[w+8+(f+27984)>>1]=0;Ja=pa;Ka=ba;break}else{Ja=1<<ea|pa;Ka=ba;break}}}while(0);ba=ea+1|0;if((ba|0)<4){na=Ka;pa=Ja;ea=ba}else{break}}if((Ka|0)<6){c[za>>2]=0;c[sa>>2]=0;c[ta>>2]=0;c[ra>>2]=0;aa=z;break}c[t>>2]=c[t>>2]|Ja;if((Ja|0)==0){aa=z;break}else{Ua=0;Va=Ja}while(1){ea=d[98856+Va|0]|0;pa=ea+Ua|0;na=Va>>ea+1;re[c[xa>>2]&1023]((c[ya>>2]|0)+(pa<<3&8|pa>>>1<<8)|0,da+(pa<<2<<5)|0);if((na|0)==0){aa=z;break}else{Ua=pa+1|0;Va=na}}}}}while(0);Va=c[v>>2]|0;if(Va>>>0<4>>>0){Ua=c[f+19372>>2]|0;if((c[f+28836>>2]|0)==0){z=f+36656+(Ua<<2)|0;qe[c[z>>2]&1023](c[f+24572>>2]|0);qe[c[z>>2]&1023](c[f+24576>>2]|0)}else{qMb(f,Ua)}Ua=c[v>>2]|0;if(Ua>>>0<3>>>0){Wa=0}else{Xa=Ua;A=362}}else{Xa=Va;A=362}if((A|0)==362){Wa=(Xa|0)!=3|0}pMb(f,Wa,c[f+28820>>2]|0);Wa=c[f+19364>>2]|0;Xa=c[t>>2]|0;Va=Wa<<4|Xa;if((c[f+152>>2]|0)==0){Ya=Va&65535}else{Ya=(d[u]<<8|Va|d[f+28024|0]<<9|d[f+28064|0]<<10)&65535}b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]=Ya;if((aa|0)!=0){i=g;return}aa=c[v>>2]|0;if((aa|0)==7){if((Wa|Xa|0)!=0){i=g;return}c[v>>2]=18;i=g;return}else if((aa|0)==4){if((c[f+19348>>2]|0)!=16){i=g;return}if((Wa|Xa|0)!=0){i=g;return}if((c[f+28240>>2]|0)!=(c[f+28756>>2]|0)){i=g;return}if((a[f+28116|0]|0)!=0){i=g;return}c[v>>2]=6;i=g;return}else{i=g;return}}v=f+28024|0;a[v]=0;Xa=f+28064|0;a[Xa]=0;Wa=f+19344|0;aa=c[Wa>>2]|0;if((aa|0)==3){Ya=f+37436|0;pe[c[Ya>>2]&1023](c[f+24568>>2]|0,32,c[f+24544>>2]|0,16,16);pe[c[Ya>>2]&1023](c[f+24572>>2]|0,32,c[f+24548>>2]|0,16,16);pe[c[Ya>>2]&1023](c[f+24576>>2]|0,32,c[f+24552>>2]|0,16,16);i=g;return}do{if((c[f+18944>>2]|0)==0){if((aa|0)==6){c[Wa>>2]=4;Za=1;A=119;break}else if((aa|0)==18){c[Wa>>2]=7;Za=1;A=119;break}else{_a=1;A=9;break}}else{_a=0;A=9}}while(0);c:do{if((A|0)==9){switch(aa|0){case 0:{c[f+19356>>2]=0;Ya=f+19376|0;do{if((c[Ya>>2]|0)!=0){pe[c[f+37436>>2]&1023](c[f+24568>>2]|0,32,f+21856|0,16,16);c[f+27996>>2]=c[f+23232>>2];c[f+28004>>2]=c[f+23236>>2];c[f+28012>>2]=c[f+23240>>2];c[f+28020>>2]=c[f+23244>>2];c[t>>2]=c[f+23264>>2];if((c[Ya>>2]|0)!=2){break}Ee[c[f+37520>>2]&511](f+17024|0,f+22752|0,480)|0}}while(0);Va=l+31&-32;Ua=f+28836|0;z=f+37572|0;Ja=f+18644|0;Ka=f+18640|0;Qa=f+37716|0;Pa=f+37644|0;Sa=f+37736|0;Ra=f+37576|0;Ta=f+37760|0;Na=f+33820|0;Ma=f+33816|0;Oa=f+37652|0;La=f+15144|0;Fa=f+18660|0;Ea=f+37460|0;Ha=f+28820|0;Ia=0;Ga=q;while(1){if((Ia|0)==0){$a=(c[Ya>>2]|0)!=0?15:0}else{$a=0}Da=f+24568+(Ia<<2)|0;Ca=f+24544+(Ia<<2)|0;Ba=1625038+Ia|0;da=(Ia|0)!=0;ya=da?2:0;xa=f+1716+(ya<<2)|0;ra=f+1748+(ya<<2)|0;ta=Ia<<4;sa=f+1652+(ya<<2)|0;za=da&1;da=za<<1;na=f+24556+(Ia<<2)|0;pa=$a;do{ea=e[1901496+(pa<<1)>>1]|0;oa=c[Da>>2]|0;la=a[(d[19280+pa|0]|0)+(f+27936)|0]|0;if((c[f+18804+(pa<<2)>>2]&6|0)==2){c[oa+(ea-28)>>2]=ca(d[oa+(ea-29)|0]|0,16843009)|0;ab=c[Da>>2]|0}else{ab=oa}oa=(c[Ca>>2]|0)+(d[1901416+pa|0]|0)|0;va=ab+ea|0;do{if((c[Ua>>2]|0)==0){qe[c[f+36608+(la<<2)>>2]&1023](va)}else{ea=c[(c[La>>2]|0)+156+(Ia<<2)>>2]<<c[Fa>>2];wa=c[na>>2]|0;B=(ca(ea<<2,d[1901384+pa|0]|0)|0)+(d[1901592+pa|0]<<2)|0;if((la|0)==0){pe[c[Ea>>2]&1023](va,32,wa+(B-ea)|0,ea,4);break}else if((la|0)==1){pe[c[Ea>>2]&1023](va,32,wa+(B-1)|0,ea,4);break}else{qe[c[f+36608+(la<<2)>>2]&1023](va);break}}}while(0);do{if((c[Ua>>2]|0)==0){ef[c[z>>2]&4095](Va,oa,va);la=d[Ba]|0;if((c[Ja>>2]|0)!=0){mf[c[Ta>>2]&2047](Va,(c[Na>>2]|0)+(da<<8)|0,(c[Ma>>2]|0)+(da<<7)|0,16)}if((c[Ka>>2]|0)==0){bb=Ee[c[Qa>>2]&511](Va,(c[xa>>2]|0)+(Ga<<5)|0,(c[ra>>2]|0)+(Ga<<5)|0)|0;cb=pa+ta|0}else{ea=pa+ta|0;bb=_Tb(f,Va,ya,Ga,la,1,za,ea)|0;cb=ea}a[(d[19280+cb|0]|0)+(f+27984)|0]=bb;if((bb|0)==0){break}c[t>>2]=c[t>>2]|1<<(pa>>2);re[c[Pa>>2]&1023](f+17024+(cb<<5)|0,Va);ef[c[Sa>>2]&4095](Va,c[sa>>2]|0,Ga);re[c[Ra>>2]&1023](va,Va)}else{ea=pa+ta|0;la=Ee[c[Oa>>2]&511](f+17024+(ea<<5)|0,oa,va)|0;a[(d[19280+ea|0]|0)+(f+27984)|0]=la;c[t>>2]=c[t>>2]|la<<(pa>>2)}}while(0);pa=pa+1|0;}while((pa|0)<16);pa=Ia+1|0;if((pa|0)<3){Ia=pa;Ga=c[Ha>>2]|0}else{db=_a;break}}break};case 6:{if((c[f+19380>>2]|0)==0){Ha=b[f+28240>>1]|0;Ga=c[f+18668>>2]|0;Ia=c[f+18676>>2]|0;if((Ha|0)<(Ga|0)){eb=Ga}else{eb=(Ha|0)>(Ia|0)?Ia:Ha}Ha=b[f+28242>>1]|0;Ia=c[f+18672>>2]|0;Ga=c[f+18680>>2]|0;if((Ha|0)<(Ia|0)){fb=Ia}else{fb=(Ha|0)>(Ga|0)?Ga:Ha}Ha=f+37376|0;Te[c[Ha>>2]&255](c[f+24568>>2]|0,32,f+24588|0,c[f+27916>>2]|0,eb,fb,16,16,f+3584|0);Te[c[Ha>>2]&255](c[f+24572>>2]|0,32,f+24604|0,c[f+27920>>2]|0,eb,fb,16,16,f+3632|0);Te[c[Ha>>2]&255](c[f+24576>>2]|0,32,f+24620|0,c[f+27924>>2]|0,eb,fb,16,16,f+3680|0);gb=(c[o>>2]|0)>1}else{gb=1}c[f+27996>>2]=0;c[f+28004>>2]=0;c[f+28012>>2]=0;c[f+28020>>2]=0;c[f+28036>>2]=0;c[f+28044>>2]=0;c[f+28076>>2]=0;c[f+28084>>2]=0;if(gb){c[f+28052>>2]=0;c[f+28060>>2]=0;c[f+28092>>2]=0;c[f+28100>>2]=0}c[t>>2]=0;c[f+19364>>2]=0;b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]=0;i=g;return};case 18:{if((c[f+19380>>2]|0)==0){YOb(f);hb=(c[o>>2]|0)>1}else{hb=1}c[f+27996>>2]=0;c[f+28004>>2]=0;c[f+28012>>2]=0;c[f+28020>>2]=0;c[f+28036>>2]=0;c[f+28044>>2]=0;c[f+28076>>2]=0;c[f+28084>>2]=0;if(hb){c[f+28052>>2]=0;c[f+28060>>2]=0;c[f+28092>>2]=0;c[f+28100>>2]=0}c[t>>2]=0;c[f+19364>>2]=0;b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]=0;i=g;return};case 1:{c[f+19356>>2]=1;Ha=f+19376|0;do{if((c[Ha>>2]|0)!=0){pe[c[f+37436>>2]&1023](c[f+24568>>2]|0,32,f+22112|0,16,16);c[f+27996>>2]=c[f+23248>>2];c[f+28004>>2]=c[f+23252>>2];c[f+28012>>2]=c[f+23256>>2];c[f+28020>>2]=c[f+23260>>2];c[t>>2]=c[f+23268>>2];if((c[Ha>>2]|0)!=2){break}Ee[c[f+37520>>2]&511](f+15488|0,f+22368|0,384)|0}}while(0);Ga=h+31&-32;Ia=j+31&-32;Oa=f+36740|0;Va=f+28836|0;Ra=f+37612|0;Sa=f+18644|0;Pa=f+18640|0;Qa=f+37712|0;Ka=f+37640|0;Ma=f+37732|0;Na=f+37616|0;Ta=f+37760|0;Ja=f+33820|0;z=f+33816|0;Ua=f+37648|0;Ea=f+15144|0;Fa=f+18660|0;La=f+37448|0;Ya=f+28820|0;pa=0;ta=q;while(1){if((pa|0)==0){ib=(c[Ha>>2]|0)!=0?3:0}else{ib=0}sa=f+24544+(pa<<2)|0;za=f+24568+(pa<<2)|0;ya=1625047+pa|0;ra=(pa|0)!=0;xa=ra?2:0;da=f+1732+(xa<<2)|0;Ba=f+1764+(xa<<2)|0;na=pa<<4;Ca=pa<<2;Da=f+1668+(xa<<2)|0;va=ra&1;ra=va<<1|1;oa=f+24556+(pa<<2)|0;la=ib;do{ea=la<<2;B=a[(d[19280+ea|0]|0)+(f+27936)|0]|0;wa=la>>1;qa=la<<3&8;p=(c[sa>>2]|0)+(qa|wa<<7)|0;Aa=(c[za>>2]|0)+(qa|wa<<8)|0;mf[c[Oa>>2]&2047](Aa,Ia,c[f+18788+(la<<2)>>2]|0,d[19488+B|0]|0);do{if((c[Va>>2]|0)==0){re[c[f+36560+(B<<2)>>2]&1023](Aa,Ia)}else{wa=c[(c[Ea>>2]|0)+156+(pa<<2)>>2]<<c[Fa>>2];ma=c[oa>>2]|0;ba=(ca(la>>>1<<3,wa)|0)+qa|0;if((B|0)==0){pe[c[La>>2]&1023](Aa,32,ma+(ba-wa)|0,wa,8);break}else if((B|0)==1){pe[c[La>>2]&1023](Aa,32,ma+(ba-1)|0,wa,8);break}else{re[c[f+36560+(B<<2)>>2]&1023](Aa,Ia);break}}}while(0);do{if((c[Va>>2]|0)==0){ef[c[Ra>>2]&4095](Ga,p,Aa);B=d[ya]|0;if((c[Sa>>2]|0)!=0){mf[c[Ta>>2]&2047](Ga,(c[Ja>>2]|0)+(ra<<8)|0,(c[z>>2]|0)+(ra<<7)|0,64)}if((c[Pa>>2]|0)==0){jb=Ee[c[Qa>>2]&511](Ga,(c[da>>2]|0)+(ta<<7)|0,(c[Ba>>2]|0)+(ta<<7)|0)|0}else{jb=$Tb(f,Ga,xa,ta,B,1,va,la+Ca|0)|0}if((jb|0)==0){B=d[19280+(ea+na)|0]|0;b[f+27984+B>>1]=0;b[B+8+(f+27984)>>1]=0;break}else{c[t>>2]=c[t>>2]|1<<la;re[c[Ka>>2]&1023](f+15488+(la+Ca<<7)|0,Ga);ef[c[Ma>>2]&4095](Ga,c[Da>>2]|0,ta);re[c[Na>>2]&1023](Aa,Ga);B=d[19280+(ea+na)|0]|0;b[f+27984+B>>1]=257;b[B+8+(f+27984)>>1]=257;break}}else{B=Ee[c[Ua>>2]&511](f+15488+(la+Ca<<7)|0,p,Aa)|0;qa=(B*257|0)&65535;wa=d[19280+(ea+na)|0]|0;b[f+27984+wa>>1]=qa;b[wa+8+(f+27984)>>1]=qa;c[t>>2]=c[t>>2]|B<<la}}while(0);la=la+1|0;}while((la|0)<4);la=pa+1|0;if((la|0)<3){pa=la;ta=c[Ya>>2]|0}else{db=_a;break}}break};case 2:{c[f+19356>>2]=0;Ya=k+31&-32;ta=l+31&-32;pa=f+19368|0;Ua=f+28836|0;Ga=f+37600|0;Na=f+18644|0;Ma=f+37760|0;Ka=f+33820|0;Qa=f+33816|0;Pa=f+18640|0;z=f+37720|0;Ja=f+37644|0;Ta=f+37736|0;Sa=f+37764|0;Ra=f+37628|0;Va=f+37724|0;Ia=f+37632|0;La=f+37740|0;Fa=f+37608|0;Ea=f+37604|0;Oa=f+28820|0;Ha=f+37656|0;la=f+15144|0;na=f+18660|0;Ca=f+37436|0;Da=f+37464|0;va=0;xa=q;Ba=s;while(1){da=c[f+24544+(va<<2)>>2]|0;ra=c[f+24568+(va<<2)>>2]|0;ya=(Ba|0)!=0?0:9;oa=(va|0)!=0;za=oa?2:0;sa=c[pa>>2]|0;do{if((c[Ua>>2]|0)==0){qe[c[f+36532+(sa<<2)>>2]&1023](ra)}else{ea=c[(c[la>>2]|0)+156+(va<<2)>>2]<<c[na>>2];if((sa|0)==0){pe[c[Ca>>2]&1023](ra,32,(c[f+24556+(va<<2)>>2]|0)+(-ea|0)|0,ea,16);break}else if((sa|0)==1){pe[c[Da>>2]&1023](ra,32,(c[f+24556+(va<<2)>>2]|0)-1|0,ea,16);break}else{qe[c[f+36532+(sa<<2)>>2]&1023](ra);break}}}while(0);sa=va<<4;d:do{if((c[Ua>>2]|0)==0){ea=d[19280+sa|0]|0;Aa=f+27984+ea|0;c[Aa>>2]=0;p=ea+8+(f+27984)|0;c[p>>2]=0;B=ea+16+(f+27984)|0;c[B>>2]=0;qa=ea+24+(f+27984)|0;c[qa>>2]=0;ef[c[Ga>>2]&4095](Ya,da,ra);if((c[Na>>2]|0)==0){kb=0}else{ea=0;while(1){mf[c[Ma>>2]&2047](Ya+(ea<<5)|0,c[Ka>>2]|0,c[Qa>>2]|0,16);wa=ea+1|0;if((wa|0)<16){ea=wa}else{kb=0;break}}}do{ea=Ya+(kb<<5)|0;b[ta+(d[1901528+kb|0]<<1)>>1]=b[ea>>1]|0;b[ea>>1]=0;kb=kb+1|0;}while((kb|0)<16);if((c[Pa>>2]|0)==0){ea=f+1716+(za<<2)|0;wa=f+1748+(za<<2)|0;ba=f+1652+(za<<2)|0;ma=ya;w=0;L=0;while(1){$=L<<2;C=Ee[c[z>>2]&511](Ya+($<<5)|0,(c[ea>>2]|0)+(xa<<5)|0,(c[wa>>2]|0)+(xa<<5)|0)|0;if((C|0)==0){lb=w;mb=ma}else{K=ma;D=$;$=C;while(1){C=d[98856+$|0]|0;F=C+D|0;Y=$>>C+1;C=F+sa|0;V=f+17024+(C<<5)|0;E=Ya+(F<<5)|0;re[c[Ja>>2]&1023](V,E);ef[c[Ta>>2]&4095](E,c[ba>>2]|0,xa);if((K|0)<6){nb=(ve[c[Sa>>2]&4095](V)|0)+K|0}else{nb=K}a[(d[19280+C|0]|0)+(f+27984)|0]=1;if((Y|0)==0){lb=15;mb=nb;break}else{K=nb;D=F+1|0;$=Y}}}$=L+1|0;if(($|0)<4){ma=mb;w=lb;L=$}else{ob=lb;pb=mb;break}}}else{L=d[1625035+va|0]|0;w=oa&1;ma=f+1652+(za<<2)|0;ba=ya;wa=0;ea=0;while(1){$=Ya+(ea<<5)|0;if((_Tb(f,$,za,xa,L,1,w,ea)|0)==0){qb=wa;rb=ba}else{D=ea+sa|0;K=f+17024+(D<<5)|0;re[c[Ja>>2]&1023](K,$);ef[c[Ta>>2]&4095]($,c[ma>>2]|0,xa);if((ba|0)<6){sb=(ve[c[Sa>>2]&4095](K)|0)+ba|0}else{sb=ba}a[(d[19280+D|0]|0)+(f+27984)|0]=1;qb=15;rb=sb}D=ea+1|0;if((D|0)<16){ba=rb;wa=qb;ea=D}else{ob=qb;pb=rb;break}}}if((pb|0)<6){c[Aa>>2]=0;c[p>>2]=0;c[B>>2]=0;c[qa>>2]=0;tb=0}else{c[t>>2]=c[t>>2]|ob;tb=ob}qe[c[Ra>>2]&1023](ta);if((c[Pa>>2]|0)==0){ub=Ee[c[Va>>2]&511](ta,(e[(c[f+1716+(za<<2)>>2]|0)+(xa<<5)>>1]|0)>>>1,e[(c[f+1748+(za<<2)>>2]|0)+(xa<<5)>>1]<<1)|0;vb=va+48|0}else{ea=va+48|0;ub=YTb(f,ta,za,xa,d[1625032+va|0]|0,1,ea)|0;vb=ea}a[(d[19280+vb|0]|0)+(f+27984)|0]=ub;ea=(ub|0)!=0;do{if(ea){re[c[Ja>>2]&1023](f+15360+(va<<5)|0,ta);qe[c[Ia>>2]&1023](ta);ef[c[La>>2]&4095](ta,c[f+1652+(za<<2)>>2]|0,xa);if((tb|0)==0){break}else{wb=0}while(1){b[Ya+(wb<<5)>>1]=b[ta+(d[1901528+wb|0]<<1)>>1]|0;wa=wb+1|0;if((wa|0)<16){wb=wa}else{A=62;break}}}else{A=62}}while(0);do{if((A|0)==62){A=0;if((tb|0)==0){if(ea){break}else{break d}}else{re[c[Ea>>2]&1023](ra,Ya);break d}}}while(0);re[c[Fa>>2]&1023](ra,ta)}else{ea=0;qa=0;do{B=ea+sa|0;p=hf[c[Ha>>2]&1023](f+17024+(B<<5)|0,da+(d[1901416+ea|0]|0)|0,ra+(e[1901496+(ea<<1)>>1]|0)|0,ta+(d[1901320+ea|0]<<1)|0)|0;a[(d[19280+B|0]|0)+(f+27984)|0]=p;qa=p|qa;ea=ea+1|0;}while((ea|0)<16);c[t>>2]=c[t>>2]|(qa*15|0);ea=0;while(1){if((ea|0)>=16){xb=0;break}if((c[ta+(ea<<1)>>2]|0)==0){ea=ea+2|0}else{xb=1;break}}a[(d[va+19328|0]|0)+(f+27984)|0]=xb;re[c[Ja>>2]&1023](f+15360+(va<<5)|0,ta)}}while(0);ra=va+1|0;if((ra|0)>=3){db=_a;break c}va=ra;xa=c[Oa>>2]|0;Ba=c[r>>2]|0}break};default:{Za=_a;A=119;break c}}}}while(0);e:do{if((A|0)==119){if((c[f+19380>>2]|0)==0){YOb(f)}_a=(c[f+19356>>2]|0)!=0;if((c[f+28836>>2]|0)!=0){if(_a){r=f+37648|0;xb=0;while(1){tb=xb<<2;wb=f+24544+(xb<<2)|0;ub=f+24568+(xb<<2)|0;vb=xb<<4;ob=Ee[c[r>>2]&511](f+15488+(tb<<7)|0,c[wb>>2]|0,c[ub>>2]|0)|0;pb=(ob*257|0)&65535;rb=d[19280+vb|0]|0;b[f+27984+rb>>1]=pb;b[rb+8+(f+27984)>>1]=pb;c[t>>2]=c[t>>2]|ob;ob=Ee[c[r>>2]&511](f+15488+((tb|1)<<7)|0,(c[wb>>2]|0)+8|0,(c[ub>>2]|0)+8|0)|0;pb=(ob*257|0)&65535;rb=d[19280+(vb|4)|0]|0;b[f+27984+rb>>1]=pb;b[rb+8+(f+27984)>>1]=pb;c[t>>2]=c[t>>2]|ob<<1;ob=Ee[c[r>>2]&511](f+15488+((tb|2)<<7)|0,(c[wb>>2]|0)+128|0,(c[ub>>2]|0)+256|0)|0;pb=(ob*257|0)&65535;rb=d[19280+(vb|8)|0]|0;b[f+27984+rb>>1]=pb;b[rb+8+(f+27984)>>1]=pb;c[t>>2]=c[t>>2]|ob<<2;ob=Ee[c[r>>2]&511](f+15488+((tb|3)<<7)|0,(c[wb>>2]|0)+136|0,(c[ub>>2]|0)+264|0)|0;ub=(ob*257|0)&65535;wb=d[19280+(vb|12)|0]|0;b[f+27984+wb>>1]=ub;b[wb+8+(f+27984)>>1]=ub;c[t>>2]=c[t>>2]|ob<<3;ob=xb+1|0;if((ob|0)<3){xb=ob}else{db=Za;break e}}}xb=f+37652|0;r=f+24544|0;ob=f+24568|0;ub=0;do{wb=Ee[c[xb>>2]&511](f+17024+(ub<<5)|0,(c[r>>2]|0)+(d[1901416+ub|0]|0)|0,(c[ob>>2]|0)+(e[1901496+(ub<<1)>>1]|0)|0)|0;a[(d[19280+ub|0]|0)+(f+27984)|0]=wb;c[t>>2]=c[t>>2]|wb<<(ub>>2);ub=ub+1|0;}while((ub|0)<16);ub=f+24548|0;ob=f+24572|0;r=0;do{wb=r+16|0;vb=Ee[c[xb>>2]&511](f+17024+(wb<<5)|0,(c[ub>>2]|0)+(d[1901416+r|0]|0)|0,(c[ob>>2]|0)+(e[1901496+(r<<1)>>1]|0)|0)|0;a[(d[19280+wb|0]|0)+(f+27984)|0]=vb;c[t>>2]=c[t>>2]|vb<<(r>>2);r=r+1|0;}while((r|0)<16);r=f+24552|0;ob=f+24576|0;ub=0;while(1){vb=ub+32|0;wb=Ee[c[xb>>2]&511](f+17024+(vb<<5)|0,(c[r>>2]|0)+(d[1901416+ub|0]|0)|0,(c[ob>>2]|0)+(e[1901496+(ub<<1)>>1]|0)|0)|0;a[(d[19280+vb|0]|0)+(f+27984)|0]=wb;c[t>>2]=c[t>>2]|wb<<(ub>>2);wb=ub+1|0;if((wb|0)<16){ub=wb}else{db=Za;break e}}}if(_a){ub=m+31&-32;ob=f+18640|0;if((c[ob>>2]|0)==0){yb=1}else{yb=(c[f+152>>2]|0)==0|0}r=f+37620|0;xb=f+18644|0;wb=f+33824|0;vb=f+37712|0;tb=f+37640|0;pb=(yb&s|0)==0;rb=f+37772|0;qb=f+37760|0;sb=f+33820|0;mb=f+33816|0;lb=f+37732|0;nb=f+37616|0;kb=f+28820|0;l=0;k=0;jb=q;while(1){ib=k<<4;j=d[19280+ib|0]|0;c[f+27984+j>>2]=0;c[j+8+(f+27984)>>2]=0;c[j+16+(f+27984)>>2]=0;c[j+24+(f+27984)>>2]=0;j=f+24568+(k<<2)|0;ef[c[r>>2]&4095](ub,c[f+24544+(k<<2)>>2]|0,c[j>>2]|0);h=(k|0)!=0;hb=h&1;o=hb<<1|1;gb=(c[wb>>2]|0)+(o<<2)|0;c[gb>>2]=(c[gb>>2]|0)+(c[xb>>2]<<2);gb=d[1625047+k|0]|0;fb=h?3:1;h=f+1732+(fb<<2)|0;eb=f+1764+(fb<<2)|0;cb=k<<2;if(pb){bb=0;ab=0;while(1){$a=ub+(ab<<7)|0;if((c[xb>>2]|0)!=0){mf[c[qb>>2]&2047]($a,(c[sb>>2]|0)+(o<<8)|0,(c[mb>>2]|0)+(o<<7)|0,64)}if((c[ob>>2]|0)==0){zb=Ee[c[vb>>2]&511]($a,(c[h>>2]|0)+(jb<<7)|0,(c[eb>>2]|0)+(jb<<7)|0)|0}else{zb=$Tb(f,$a,fb,jb,gb,0,hb,ab+cb|0)|0}if((zb|0)==0){Ab=bb}else{re[c[tb>>2]&1023](f+15488+(ab+cb<<7)|0,$a);Ab=1<<ab|bb}$a=ab+1|0;if(($a|0)<4){bb=Ab;ab=$a}else{Bb=l;Cb=Ab;break}}}else{ab=l;bb=0;$a=0;while(1){aa=ub+($a<<7)|0;if((c[xb>>2]|0)!=0){mf[c[qb>>2]&2047](aa,(c[sb>>2]|0)+(o<<8)|0,(c[mb>>2]|0)+(o<<7)|0,64)}if((c[ob>>2]|0)==0){Db=Ee[c[vb>>2]&511](aa,(c[h>>2]|0)+(jb<<7)|0,(c[eb>>2]|0)+(jb<<7)|0)|0}else{Db=$Tb(f,aa,fb,jb,gb,0,hb,$a+cb|0)|0}do{if((Db|0)==0){Eb=bb;Fb=ab}else{Ba=f+15488+($a+cb<<7)|0;re[c[tb>>2]&1023](Ba,aa);Oa=ve[c[rb>>2]&4095](Ba)|0;Ba=Oa+ab|0;if((Oa|0)<=3){Eb=bb;Fb=Ba;break}Eb=1<<$a|bb;Fb=Ba}}while(0);aa=$a+1|0;if((aa|0)<4){ab=Fb;bb=Eb;$a=aa}else{Bb=Fb;Cb=Eb;break}}}do{if((Bb|0)>5|pb){c[t>>2]=c[t>>2]|Cb;if((Cb|0)==0){break}$a=f+1668+(fb<<2)|0;bb=0;ab=Cb;while(1){cb=d[98856+ab|0]|0;hb=cb+bb|0;gb=ab>>cb+1;cb=ub+(hb<<7)|0;ef[c[lb>>2]&4095](cb,c[$a>>2]|0,jb);re[c[nb>>2]&1023]((c[j>>2]|0)+(hb<<3&8|hb>>>1<<8)|0,cb);cb=d[19280+((hb<<2)+ib)|0]|0;b[f+27984+cb>>1]=257;b[cb+8+(f+27984)>>1]=257;if((gb|0)==0){break}else{bb=hb+1|0;ab=gb}}}}while(0);ib=k+1|0;if((ib|0)<3){l=Bb;k=ib;jb=c[kb>>2]|0}else{db=Za;break}}}else{kb=n+31&-32;jb=f+37600|0;k=f+18644|0;l=f+33824|0;nb=f+37760|0;lb=f+33820|0;ub=f+33816|0;pb=(s|0)!=0?0:6;rb=f+18640|0;tb=f+37720|0;vb=f+1720|0;ob=f+1752|0;mb=f+37644|0;sb=f+37736|0;qb=f+37768|0;xb=f+28820|0;wb=f+37588|0;r=0;_a=0;ib=q;while(1){j=_a<<4;fb=d[19280+j|0]|0;ab=f+27984+fb|0;c[ab>>2]=0;bb=fb+8+(f+27984)|0;c[bb>>2]=0;$a=fb+16+(f+27984)|0;c[$a>>2]=0;gb=fb+24+(f+27984)|0;c[gb>>2]=0;fb=f+24568+(_a<<2)|0;ef[c[jb>>2]&4095](kb,c[f+24544+(_a<<2)>>2]|0,c[fb>>2]|0);if((c[k>>2]|0)!=0){hb=((_a|0)!=0)<<1;cb=(c[l>>2]|0)+(hb<<2)|0;c[cb>>2]=(c[cb>>2]|0)+16;cb=0;do{mf[c[nb>>2]&2047](kb+(cb<<5)|0,(c[lb>>2]|0)+(hb<<8)|0,(c[ub>>2]|0)+(hb<<7)|0,16);cb=cb+1|0;}while((cb|0)<16)}cb=(_a|0)!=0;hb=f+1652+((cb?3:1)<<2)|0;eb=1625038+_a|0;h=cb&1;cb=r;o=0;aa=0;while(1){do{if((c[rb>>2]|0)==0){Ba=aa<<2;Oa=Ee[c[tb>>2]&511](kb+(Ba<<5)|0,(c[vb>>2]|0)+(ib<<5)|0,(c[ob>>2]|0)+(ib<<5)|0)|0;if((Oa|0)==0){Gb=o;Hb=cb;break}else{Ib=pb;Jb=Ba;Kb=Oa}while(1){Ba=d[98856+Kb|0]|0;xa=Ba+Jb|0;va=Kb>>Ba+1;Ba=xa+j|0;ta=f+17024+(Ba<<5)|0;Ja=kb+(xa<<5)|0;re[c[mb>>2]&1023](ta,Ja);ef[c[sb>>2]&4095](Ja,c[hb>>2]|0,ib);if((Ib|0)<6){Lb=(ve[c[qb>>2]&4095](ta)|0)+Ib|0}else{Lb=Ib}a[(d[19280+Ba|0]|0)+(f+27984)|0]=1;if((va|0)==0){Mb=Oa;Nb=Lb;A=171;break}else{Ib=Lb;Jb=xa+1|0;Kb=va}}}else{Oa=aa<<2;va=d[eb]|0;xa=pb;Ba=0;ta=0;while(1){Ja=ta+Oa|0;Ha=kb+(Ja<<5)|0;Fa=Ja+j|0;if((_Tb(f,Ha,1,ib,va,0,h,Fa)|0)==0){Ob=Ba;Pb=xa}else{Ja=f+17024+(Fa<<5)|0;re[c[mb>>2]&1023](Ja,Ha);ef[c[sb>>2]&4095](Ha,c[hb>>2]|0,ib);if((xa|0)<6){Qb=(ve[c[qb>>2]&4095](Ja)|0)+xa|0}else{Qb=xa}a[(d[19280+Fa|0]|0)+(f+27984)|0]=1;Ob=1;Pb=Qb}Fa=ta+1|0;if((Fa|0)<4){xa=Pb;Ba=Ob;ta=Fa}else{Mb=Ob;Nb=Pb;A=171;break}}}}while(0);do{if((A|0)==171){A=0;if((Mb|0)==0){Gb=o;Hb=cb;break}ta=Nb+cb|0;if((Nb|0)<4){Ba=d[19280+((aa<<2)+j)|0]|0;b[f+27984+Ba>>1]=0;b[Ba+8+(f+27984)>>1]=0;Gb=o;Hb=ta;break}else{Gb=1<<aa|o;Hb=ta;break}}}while(0);ta=aa+1|0;if((ta|0)<4){cb=Hb;o=Gb;aa=ta}else{break}}do{if((Hb|0)<6){c[ab>>2]=0;c[bb>>2]=0;c[$a>>2]=0;c[gb>>2]=0}else{c[t>>2]=c[t>>2]|Gb;if((Gb|0)==0){break}else{Rb=0;Sb=Gb}while(1){aa=d[98856+Sb|0]|0;o=aa+Rb|0;cb=Sb>>aa+1;re[c[wb>>2]&1023]((c[fb>>2]|0)+(o<<3&8|o>>>1<<8)|0,kb+(o<<2<<5)|0);if((cb|0)==0){break}else{Rb=o+1|0;Sb=cb}}}}while(0);fb=_a+1|0;if((fb|0)<3){r=Hb;_a=fb;ib=c[xb>>2]|0}else{db=Za;break}}}}}while(0);c[f+19364>>2]=0;Za=c[t>>2]|0;if((c[f+152>>2]|0)==0){Tb=Za&65535}else{Tb=(d[u]<<8|Za|d[v]<<9|d[Xa]<<10)&65535}b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]=Tb;if((db|0)!=0){i=g;return}db=c[Wa>>2]|0;if((db|0)==4){if(!((c[f+19348>>2]|0)==16&(Za|0)==0)){i=g;return}if((c[f+28240>>2]|0)!=(c[f+28756>>2]|0)){i=g;return}if((a[f+28116|0]|0)!=0){i=g;return}c[Wa>>2]=6;i=g;return}else if((db|0)==7){if((Za|0)!=0){i=g;return}c[Wa>>2]=18;i=g;return}else{i=g;return}}function vMb(a,f){a=a|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;g=i;i=i+336|0;h=g|0;j=g+288|0;k=g+320|0;l=c[a+8632>>2]|0;if((l|0)==2){m=h+31&-32;n=a+28758|0;o=a+18672|0;p=a+18680|0;q=a+37376|0;r=a+37580|0;s=a+18644|0;t=a+37720|0;u=a+37644|0;v=j|0;w=a+37768|0;x=a+37760|0;y=a+33820|0;z=a+33816|0;A=a+28820|0;B=m|0;C=m+32|0;D=m+64|0;E=m+96|0;F=c[a+28816>>2]|0;if((f|0)==0){G=b[a+28756>>1]|0;H=c[a+18668>>2]|0;I=c[a+18676>>2]|0;if((G|0)<(H|0)){J=H&65535}else{J=((G|0)>(I|0)?I:G)&65535}G=b[n>>1]|0;n=c[o>>2]|0;o=c[p>>2]|0;if((G|0)<(n|0)){K=n&65535}else{K=((G|0)>(o|0)?o:G)&65535}G=a+24568|0;Te[c[q>>2]&255](c[G>>2]|0,32,a+24588|0,c[a+27916>>2]|0,J<<16>>16,K<<16>>16,16,16,a+3584|0);L=K;M=J;N=G}else{L=0;M=0;N=a+24568|0}G=a+24544|0;J=a+1720|0;K=a+1752|0;q=0;o=0;a:while(1){n=o<<3&8;p=o>>1;ef[c[r>>2]&4095](m,(c[G>>2]|0)+(n|p<<7)|0,(c[N>>2]|0)+(n|p<<8)|0);if((c[s>>2]|0)!=0){mf[c[x>>2]&2047](B,c[y>>2]|0,c[z>>2]|0,16);mf[c[x>>2]&2047](C,c[y>>2]|0,c[z>>2]|0,16);mf[c[x>>2]&2047](D,c[y>>2]|0,c[z>>2]|0,16);mf[c[x>>2]&2047](E,c[y>>2]|0,c[z>>2]|0,16)}p=Ee[c[t>>2]&511](m,(c[J>>2]|0)+(F<<5)|0,(c[K>>2]|0)+(F<<5)|0)|0;if((p|0)==0){O=q}else{n=0;I=p;p=q;while(1){H=d[98856+I|0]|0;P=H+n|0;re[c[u>>2]&1023](v,m+(P<<5)|0);Q=(ve[c[w>>2]&4095](v)|0)+p|0;if((Q|0)>5){R=0;S=92;break a}T=I>>H+1;if((T|0)==0){O=Q;break}else{n=P+1|0;I=T;p=Q}}}p=o+1|0;if((p|0)<4){q=O;o=p}else{break}}if((S|0)==92){i=g;return R|0}o=c[A>>2]|0;A=(c[97424+(o<<2)>>2]|0)+16>>5;O=(f|0)!=0;do{if(!O){if(((L&65535)<<16|M&65535|0)==0){mf[c[a+37476>>2]&2047](c[a+24572>>2]|0,c[a+24604>>2]|0,c[a+27920>>2]|0,16);break}else{Te[c[a+37384>>2]&255](c[a+24572>>2]|0,c[a+24576>>2]|0,32,c[a+24604>>2]|0,c[a+27920>>2]|0,M<<16>>16,L<<16>>16<<1,8,16);break}}}while(0);L=a+36784|0;M=a+37596|0;q=k|0;w=a+37728|0;F=o+3|0;K=a+1728|0;J=a+1760|0;N=A<<2;G=a+37764|0;p=0;b:while(1){I=p+1|0;n=c[a+24544+(I<<2)>>2]|0;Q=c[a+24568+(I<<2)>>2]|0;do{if(!O){T=c[a+3584+(I*48|0)+44>>2]|0;if((T|0)==0){break}_e[c[T+8>>2]&511](Q,32,Q,32,a+3584+(I*48|0)|0,16)}}while(0);T=hf[c[L>>2]&1023](Q,32,n,16)|0;do{if((T|0)>=(A|0)){if((c[s>>2]|0)==0){ef[c[M>>2]&4095](q,n,Q);U=0}else{ef[c[r>>2]&4095](m,n,Q);ef[c[r>>2]&4095](m+128|0,n+128|0,Q+256|0);mf[c[x>>2]&2047](B,(c[y>>2]|0)+512|0,(c[z>>2]|0)+256|0,16);b[q>>1]=b[B>>1]|0;b[B>>1]=0;mf[c[x>>2]&2047](C,(c[y>>2]|0)+512|0,(c[z>>2]|0)+256|0,16);b[k+2>>1]=b[C>>1]|0;b[C>>1]=0;mf[c[x>>2]&2047](D,(c[y>>2]|0)+512|0,(c[z>>2]|0)+256|0,16);b[k+4>>1]=b[D>>1]|0;b[D>>1]=0;mf[c[x>>2]&2047](E,(c[y>>2]|0)+512|0,(c[z>>2]|0)+256|0,16);b[k+6>>1]=b[E>>1]|0;b[E>>1]=0;P=m+128|0;mf[c[x>>2]&2047](P,(c[y>>2]|0)+512|0,(c[z>>2]|0)+256|0,16);b[k+8>>1]=b[P>>1]|0;b[P>>1]=0;P=m+160|0;mf[c[x>>2]&2047](P,(c[y>>2]|0)+512|0,(c[z>>2]|0)+256|0,16);b[k+10>>1]=b[P>>1]|0;b[P>>1]=0;P=m+192|0;mf[c[x>>2]&2047](P,(c[y>>2]|0)+512|0,(c[z>>2]|0)+256|0,16);b[k+12>>1]=b[P>>1]|0;b[P>>1]=0;P=m+224|0;mf[c[x>>2]&2047](P,(c[y>>2]|0)+512|0,(c[z>>2]|0)+256|0,16);b[k+14>>1]=b[P>>1]|0;b[P>>1]=0;U=0}while(1){if((U|0)>1){break}if((Ee[c[w>>2]&511](k+(U<<2<<1)|0,(e[(c[K>>2]|0)+(F<<5)>>1]|0)>>>1,e[(c[J>>2]|0)+(F<<5)>>1]<<1)|0)==0){U=U+1|0}else{R=0;S=92;break b}}if((T|0)<(N|0)){break}if((c[s>>2]|0)==0){ef[c[r>>2]&4095](m,n,Q);b[B>>1]=0;b[C>>1]=0;b[D>>1]=0;b[E>>1]=0;P=m+128|0;ef[c[r>>2]&4095](P,n+128|0,Q+256|0);b[P>>1]=0;b[m+160>>1]=0;b[m+192>>1]=0;b[m+224>>1]=0}P=Ee[c[t>>2]&511](m,(c[K>>2]|0)+(o<<5)|0,(c[J>>2]|0)+(o<<5)|0)|0;if((P|0)==0){V=0}else{H=0;W=0;X=P;while(1){P=d[98856+X|0]|0;Y=P+W|0;re[c[u>>2]&1023](v,m+(Y<<5)|0);Z=(ve[c[G>>2]&4095](v)|0)+H|0;if((Z|0)>6){R=0;S=92;break b}_=X>>P+1;if((_|0)==0){V=Z;break}else{H=Z;W=Y+1|0;X=_}}}X=Ee[c[t>>2]&511](m+128|0,(c[K>>2]|0)+(o<<5)|0,(c[J>>2]|0)+(o<<5)|0)|0;if((X|0)==0){break}else{$=V;aa=4;ba=X}while(1){X=d[98856+ba|0]|0;W=X+aa|0;re[c[u>>2]&1023](v,m+(W<<5)|0);H=(ve[c[G>>2]&4095](v)|0)+$|0;if((H|0)>6){R=0;S=92;break b}_=ba>>X+1;if((_|0)==0){break}else{$=H;aa=W+1|0;ba=_}}}}while(0);if((I|0)<2){p=I}else{S=55;break}}if((S|0)==55){c[a+19380>>2]=1;R=1;i=g;return R|0}else if((S|0)==92){i=g;return R|0}}else if((l|0)==3){l=h+31&-32;p=(f|0)==0;ba=a+28756|0;aa=a+18668|0;$=a+18676|0;v=a+28758|0;G=a+18672|0;m=a+18680|0;u=a+37376|0;V=a+37580|0;o=a+18644|0;J=a+37720|0;K=a+37644|0;t=j|0;r=a+37768|0;E=a+37760|0;D=a+33820|0;C=a+33816|0;B=a+28820|0;s=l|0;N=l+32|0;U=l+64|0;F=l+96|0;w=0;z=a+28816|0;c:while(1){y=c[z>>2]|0;x=(w|0)!=0;q=x?3:1;if(p){M=b[ba>>1]|0;A=c[aa>>2]|0;L=c[$>>2]|0;if((M|0)<(A|0)){ca=A&65535}else{ca=((M|0)>(L|0)?L:M)&65535}M=b[v>>1]|0;L=c[G>>2]|0;A=c[m>>2]|0;if((M|0)<(L|0)){da=L&65535}else{da=((M|0)>(A|0)?A:M)&65535}M=a+24568+(w<<2)|0;Te[c[u>>2]&255](c[M>>2]|0,32,a+24588+(w<<2<<2)|0,c[a+27916+(w<<2)>>2]|0,ca<<16>>16,da<<16>>16,16,16,a+3584+(w*48|0)|0);ea=M}else{ea=a+24568+(w<<2)|0}M=a+24544+(w<<2)|0;A=a+1716+(q<<2)|0;L=a+1748+(q<<2)|0;q=(x&1)<<1;x=0;O=0;while(1){Q=O<<3&8;n=O>>1;ef[c[V>>2]&4095](l,(c[M>>2]|0)+(Q|n<<7)|0,(c[ea>>2]|0)+(Q|n<<8)|0);if((c[o>>2]|0)!=0){mf[c[E>>2]&2047](s,(c[D>>2]|0)+(q<<8)|0,(c[C>>2]|0)+(q<<7)|0,16);mf[c[E>>2]&2047](N,(c[D>>2]|0)+(q<<8)|0,(c[C>>2]|0)+(q<<7)|0,16);mf[c[E>>2]&2047](U,(c[D>>2]|0)+(q<<8)|0,(c[C>>2]|0)+(q<<7)|0,16);mf[c[E>>2]&2047](F,(c[D>>2]|0)+(q<<8)|0,(c[C>>2]|0)+(q<<7)|0,16)}n=Ee[c[J>>2]&511](l,(c[A>>2]|0)+(y<<5)|0,(c[L>>2]|0)+(y<<5)|0)|0;if((n|0)==0){fa=x}else{Q=0;T=n;n=x;while(1){_=d[98856+T|0]|0;W=_+Q|0;re[c[K>>2]&1023](t,l+(W<<5)|0);H=(ve[c[r>>2]&4095](t)|0)+n|0;if((H|0)>5){R=0;S=92;break c}X=T>>_+1;if((X|0)==0){fa=H;break}else{Q=W+1|0;T=X;n=H}}}n=O+1|0;if((n|0)<4){x=fa;O=n}else{break}}O=w+1|0;if((O|0)<3){w=O;z=B}else{break}}if((S|0)==92){i=g;return R|0}c[a+19380>>2]=1;R=1;i=g;return R|0}else{B=h+31&-32;h=a+28758|0;z=a+18672|0;w=a+18680|0;fa=a+37376|0;t=a+37580|0;r=a+18644|0;l=a+37720|0;K=a+37644|0;J=j|0;j=a+37768|0;C=a+37760|0;D=a+33820|0;F=a+33816|0;E=a+28820|0;U=B|0;N=B+32|0;s=B+64|0;o=B+96|0;ea=c[a+28816>>2]|0;if((f|0)==0){V=b[a+28756>>1]|0;da=c[a+18668>>2]|0;ca=c[a+18676>>2]|0;if((V|0)<(da|0)){ga=da&65535}else{ga=((V|0)>(ca|0)?ca:V)&65535}V=b[h>>1]|0;h=c[z>>2]|0;z=c[w>>2]|0;if((V|0)<(h|0)){ha=h&65535}else{ha=((V|0)>(z|0)?z:V)&65535}V=a+24568|0;Te[c[fa>>2]&255](c[V>>2]|0,32,a+24588|0,c[a+27916>>2]|0,ga<<16>>16,ha<<16>>16,16,16,a+3584|0);ia=ha;ja=ga;ka=V}else{ia=0;ja=0;ka=a+24568|0}V=a+24544|0;ga=a+1720|0;ha=a+1752|0;fa=0;z=0;d:while(1){h=z<<3&8;w=z>>1;ef[c[t>>2]&4095](B,(c[V>>2]|0)+(h|w<<7)|0,(c[ka>>2]|0)+(h|w<<8)|0);if((c[r>>2]|0)!=0){mf[c[C>>2]&2047](U,c[D>>2]|0,c[F>>2]|0,16);mf[c[C>>2]&2047](N,c[D>>2]|0,c[F>>2]|0,16);mf[c[C>>2]&2047](s,c[D>>2]|0,c[F>>2]|0,16);mf[c[C>>2]&2047](o,c[D>>2]|0,c[F>>2]|0,16)}w=Ee[c[l>>2]&511](B,(c[ga>>2]|0)+(ea<<5)|0,(c[ha>>2]|0)+(ea<<5)|0)|0;if((w|0)==0){la=fa}else{h=0;ca=w;w=fa;while(1){da=d[98856+ca|0]|0;u=da+h|0;re[c[K>>2]&1023](J,B+(u<<5)|0);m=(ve[c[j>>2]&4095](J)|0)+w|0;if((m|0)>5){R=0;S=92;break d}G=ca>>da+1;if((G|0)==0){la=m;break}else{h=u+1|0;ca=G;w=m}}}w=z+1|0;if((w|0)<4){fa=la;z=w}else{break}}if((S|0)==92){i=g;return R|0}z=c[E>>2]|0;E=(c[97424+(z<<2)>>2]|0)+32>>6;la=(f|0)!=0;do{if(!la){if(((ia&65535)<<16|ja&65535|0)==0){mf[c[a+37476>>2]&2047](c[a+24572>>2]|0,c[a+24604>>2]|0,c[a+27920>>2]|0,8);break}else{Te[c[a+37384>>2]&255](c[a+24572>>2]|0,c[a+24576>>2]|0,32,c[a+24604>>2]|0,c[a+27920>>2]|0,ja<<16>>16,ia<<16>>16,8,8);break}}}while(0);ia=a+36788|0;ja=k|0;f=a+37584|0;fa=a+37728|0;j=a+1728|0;ea=a+1760|0;ha=E<<2;ga=a+37764|0;ka=0;e:while(1){V=ka+1|0;w=c[a+24544+(V<<2)>>2]|0;ca=c[a+24568+(V<<2)>>2]|0;do{if(!la){h=c[a+3584+(V*48|0)+44>>2]|0;if((h|0)==0){break}_e[c[h+8>>2]&511](ca,32,ca,32,a+3584+(V*48|0)|0,8)}}while(0);h=hf[c[ia>>2]&1023](ca,32,w,16)|0;do{if((h|0)>=(E|0)){if((c[r>>2]|0)==0){ef[c[f>>2]&4095](ja,w,ca);ma=0}else{ef[c[t>>2]&4095](B,w,ca);mf[c[C>>2]&2047](U,(c[D>>2]|0)+512|0,(c[F>>2]|0)+256|0,16);b[ja>>1]=b[U>>1]|0;b[U>>1]=0;mf[c[C>>2]&2047](N,(c[D>>2]|0)+512|0,(c[F>>2]|0)+256|0,16);b[k+2>>1]=b[N>>1]|0;b[N>>1]=0;mf[c[C>>2]&2047](s,(c[D>>2]|0)+512|0,(c[F>>2]|0)+256|0,16);b[k+4>>1]=b[s>>1]|0;b[s>>1]=0;mf[c[C>>2]&2047](o,(c[D>>2]|0)+512|0,(c[F>>2]|0)+256|0,16);b[k+6>>1]=b[o>>1]|0;b[o>>1]=0;ma=0}while(1){if((ma|0)>0){break}if((Ee[c[fa>>2]&511](k+(ma<<2<<1)|0,(e[(c[j>>2]|0)+(z<<5)>>1]|0)>>>1,e[(c[ea>>2]|0)+(z<<5)>>1]<<1)|0)==0){ma=ma+1|0}else{R=0;S=92;break e}}if((h|0)<(ha|0)){break}if((c[r>>2]|0)==0){ef[c[t>>2]&4095](B,w,ca);b[U>>1]=0;b[N>>1]=0;b[s>>1]=0;b[o>>1]=0}m=Ee[c[l>>2]&511](B,(c[j>>2]|0)+(z<<5)|0,(c[ea>>2]|0)+(z<<5)|0)|0;if((m|0)==0){break}else{na=0;oa=0;pa=m}while(1){m=d[98856+pa|0]|0;G=m+oa|0;re[c[K>>2]&1023](J,B+(G<<5)|0);u=(ve[c[ga>>2]&4095](J)|0)+na|0;if((u|0)>6){R=0;S=92;break e}da=pa>>m+1;if((da|0)==0){break}else{na=u;oa=G+1|0;pa=da}}}}while(0);if((V|0)<2){ka=V}else{S=91;break}}if((S|0)==91){c[a+19380>>2]=1;R=1;i=g;return R|0}else if((S|0)==92){i=g;return R|0}}return 0}function wMb(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[a+33816>>2]=a+33856;d=a+33820|0;c[d>>2]=a+34368;e=a+33824|0;c[e>>2]=a+36416;f=a+8632|0;g=a+584|0;h=0;do{i=(h&1|0)!=0;j=i?64:16;k=i?98424:98744;l=a+36416+(h<<2)|0;m=c[l>>2]|0;if(m>>>0>(i?65536:262144)>>>0){i=c[d>>2]|0;n=0;do{o=i+(h<<8)+(n<<2)|0;c[o>>2]=(c[o>>2]|0)>>>1;n=n+1|0;}while((n|0)<(j|0));n=(c[e>>2]|0)+(h<<2)|0;c[n>>2]=(c[n>>2]|0)>>>1;p=c[l>>2]|0}else{p=m}n=c[g>>2]|0;i=Erc(p,0,n,(n|0)<0|0?-1:0)|0;n=G;o=0;do{q=c[a+34368+(h<<8)+(o<<2)>>2]|0;r=wrc(q>>>1,0,i,n)|0;s=G;t=Erc(c[k+(o<<2)>>2]|0,0,q,0)|0;q=G;u=wrc(t>>>8|q<<24,q>>>8|0<<24,1,0)|0;q=Frc(r,s,u,G)|0;b[a+33856+(h<<7)+(o<<1)>>1]=q;o=o+1|0;}while((o|0)<(j|0));b[a+33856+(h<<7)>>1]=0;h=h+1|0;}while((h|0)<(((c[f>>2]|0)==3?4:3)|0));return}function xMb(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;h=i;i=i+432|0;j=h|0;k=h+8|0;l=h+16|0;m=h+176|0;n=h+336|0;o=c[f+8632>>2]|0;if((o|0)==2){p=c[f+18648>>2]|0;q=c[f+28816>>2]|0;r=g&1;s=g>>1;t=f+19364|0;c[t>>2]=0;u=1<<g;v=f+19360|0;c[v>>2]=c[v>>2]&~u;if((c[f+19380>>2]|0)==0){UOb(f,g)}if((c[f+28836>>2]|0)!=0){w=r<<3;x=g<<2;y=x+4|0;z=f+37652|0;A=s<<8;B=s<<7;C=f+24544|0;D=f+24568|0;if((c[f+19356>>2]|0)==0){E=x;F=0;while(1){G=Ee[c[z>>2]&511](f+17024+(E<<5)|0,(c[C>>2]|0)+(d[1901416+E|0]|0)|0,(c[D>>2]|0)+(e[1901496+(E<<1)>>1]|0)|0)|0;a[(d[19280+E|0]|0)+(f+27984)|0]=G;H=G|F;G=E+1|0;if((G|0)<(y|0)){E=G;F=H}else{I=H;break}}}else{F=Ee[c[f+37648>>2]&511](f+15488+(g<<7)|0,(c[C>>2]|0)+(w|B)|0,(c[D>>2]|0)+(w|A)|0)|0;w=(F*257|0)&65535;D=d[19280+x|0]|0;b[f+27984+D>>1]=w;b[D+8+(f+27984)>>1]=w;I=F}c[v>>2]=c[v>>2]|I<<g;I=r<<2;F=B|I;B=A|I;I=s<<3;A=f+37656|0;w=c[f+24548>>2]|0;D=c[f+24572>>2]|0;x=I|r;C=x+16|0;E=(hf[c[A>>2]&1023](f+17024+(C<<5)|0,w+F|0,D+B|0,k)|0)&255;a[(d[19280+C|0]|0)+(f+27984)|0]=E;E=I|r|2;I=E+16|0;C=F|64;y=B|128;z=(hf[c[A>>2]&1023](f+17024+(I<<5)|0,w+C|0,D+y|0,k)|0)&255;a[(d[19280+I|0]|0)+(f+27984)|0]=z;z=c[f+24552>>2]|0;I=c[f+24576>>2]|0;D=x+32|0;x=(hf[c[A>>2]&1023](f+17024+(D<<5)|0,z+F|0,I+B|0,k)|0)&255;a[(d[19280+D|0]|0)+(f+27984)|0]=x;x=E+32|0;E=(hf[c[A>>2]&1023](f+17024+(x<<5)|0,z+C|0,I+y|0,k)|0)&255;a[(d[19280+x|0]|0)+(f+27984)|0]=E;c[t>>2]=2;i=h;return}E=r<<3;x=s<<7;k=E|x;y=s<<8;s=E|y;do{if((c[f+19356>>2]|0)==0){E=(p|0)!=0?0:4;I=m+31&-32;C=g<<2;z=f+37644|0;A=f+37736|0;D=f+37768|0;B=f+37588|0;F=f+37760|0;w=f+33820|0;H=f+33816|0;G=(c[f+24568>>2]|0)+s|0;ef[c[f+37580>>2]&4095](I,(c[f+24544>>2]|0)+k|0,G);J=d[19280+C|0]|0;K=f+27984+J|0;b[K>>1]=0;L=J+8+(f+27984)|0;b[L>>1]=0;if((c[f+18644>>2]|0)!=0){mf[c[F>>2]&2047](I|0,c[w>>2]|0,c[H>>2]|0,16);mf[c[F>>2]&2047](I+32|0,c[w>>2]|0,c[H>>2]|0,16);mf[c[F>>2]&2047](I+64|0,c[w>>2]|0,c[H>>2]|0,16);mf[c[F>>2]&2047](I+96|0,c[w>>2]|0,c[H>>2]|0,16)}if((c[f+18640>>2]|0)==0){H=Ee[c[f+37720>>2]&511](I,(c[f+1720>>2]|0)+(q<<5)|0,(c[f+1752>>2]|0)+(q<<5)|0)|0;if((H|0)==0){M=z;N=A;break}w=f+1656|0;F=E;J=0;O=H;while(1){P=d[98856+O|0]|0;Q=P+J|0;R=O>>P+1;P=Q+C|0;S=f+17024+(P<<5)|0;T=I+(Q<<5)|0;re[c[z>>2]&1023](S,T);ef[c[A>>2]&4095](T,c[w>>2]|0,q);if((F|0)<4){U=(ve[c[D>>2]&4095](S)|0)+F|0}else{U=F}a[(d[19280+P|0]|0)+(f+27984)|0]=1;if((R|0)==0){V=H;W=U;break}else{F=U;J=Q+1|0;O=R}}}else{O=f+1656|0;J=E;F=0;H=0;while(1){w=I+(H<<5)|0;R=H+C|0;if((_Tb(f,w,1,q,2,0,0,R)|0)==0){X=F;Y=J}else{Q=f+17024+(R<<5)|0;re[c[z>>2]&1023](Q,w);ef[c[A>>2]&4095](w,c[O>>2]|0,q);if((J|0)<4){Z=(ve[c[D>>2]&4095](Q)|0)+J|0}else{Z=J}a[(d[19280+R|0]|0)+(f+27984)|0]=1;X=1;Y=Z}R=H+1|0;if((R|0)<4){J=Y;F=X;H=R}else{V=X;W=Y;break}}}if((V|0)==0){M=z;N=A;break}if((W|0)<4){b[K>>1]=0;b[L>>1]=0;M=z;N=A;break}else{re[c[B>>2]&1023](G,I);c[v>>2]=c[v>>2]|u;M=z;N=A;break}}else{H=l+31&-32;F=f+18640|0;J=g<<2;D=(p|0)==0;O=f+37732|0;C=f+37616|0;E=f+37772|0;R=(c[f+24568>>2]|0)+s|0;ef[c[f+37612>>2]&4095](H,(c[f+24544>>2]|0)+k|0,R);if((c[f+18644>>2]|0)!=0){mf[c[f+37760>>2]&2047](H,(c[f+33820>>2]|0)+256|0,(c[f+33816>>2]|0)+128|0,64)}if((c[F>>2]|0)==0){_=Ee[c[f+37712>>2]&511](H,(c[f+1736>>2]|0)+(q<<7)|0,(c[f+1768>>2]|0)+(q<<7)|0)|0}else{_=$Tb(f,H,1,q,5,0,0,g)|0}do{if((_|0)==0){Q=d[19280+J|0]|0;b[f+27984+Q>>1]=0;b[Q+8+(f+27984)>>1]=0}else{Q=f+15488+(g<<7)|0;re[c[f+37640>>2]&1023](Q,H);do{if(D){$=_}else{if((c[F>>2]|0)!=0){$=_;break}$=(ve[c[E>>2]&4095](Q)|0)>3|0}}while(0);if(($|0)==0){Q=d[19280+J|0]|0;b[f+27984+Q>>1]=0;b[Q+8+(f+27984)>>1]=0;break}else{ef[c[O>>2]&4095](H,c[f+1672>>2]|0,q);re[c[C>>2]&1023](R,H);Q=d[19280+J|0]|0;b[f+27984+Q>>1]=257;b[Q+8+(f+27984)>>1]=257;c[v>>2]=c[v>>2]|u;break}}}while(0);M=f+37644|0;N=f+37736|0}}while(0);u=c[f+28820>>2]|0;v=n+31&-32;q=r<<2;r=x|q;x=y|q;q=f+37572|0;y=f+18644|0;$=f+18640|0;_=f+37716|0;k=f+1728|0;s=f+1760|0;p=f+1664|0;W=f+37576|0;V=f+37760|0;Y=f+33820|0;X=f+33816|0;Z=(g*5|0)&9|16;U=0;while(1){J=U+1|0;H=c[f+24544+(J<<2)>>2]|0;R=c[f+24568+(J<<2)>>2]|0;C=Z+(U<<4)|0;O=0;while(1){E=v+(O<<5)|0;F=R+((O<<7)+x)|0;ef[c[q>>2]&4095](E,H+((O<<6)+r)|0,F);if((c[y>>2]|0)!=0){mf[c[V>>2]&2047](E,(c[Y>>2]|0)+512|0,(c[X>>2]|0)+256|0,16)}b[E>>1]=0;if((c[$>>2]|0)==0){aa=Ee[c[_>>2]&511](E,(c[k>>2]|0)+(u<<5)|0,(c[s>>2]|0)+(u<<5)|0)|0}else{aa=_Tb(f,E,3,u,4,0,1,0)|0}D=C+(O<<1)|0;a[(d[19280+D|0]|0)+(f+27984)|0]=aa;if((aa|0)!=0){re[c[M>>2]&1023](f+17024+(D<<5)|0,E);ef[c[N>>2]&4095](E,c[p>>2]|0,u);re[c[W>>2]&1023](F,E)}if((O|0)>0){break}else{O=O+1|0}}if((J|0)<2){U=J}else{break}}c[t>>2]=2;i=h;return}else if((o|0)==3){o=c[f+18648>>2]|0;t=c[f+28816>>2]|0;U=g&1;W=g>>1;c[f+19364>>2]=0;u=1<<g;p=f+19360|0;c[p>>2]=c[p>>2]&~u;if((c[f+19380>>2]|0)==0){UOb(f,g)}if((c[f+28836>>2]|0)!=0){N=U<<3;M=f+19356|0;aa=g<<2;s=aa+4|0;k=f+37652|0;_=N|W<<8;$=N|W<<7;N=f+37648|0;X=0;do{Y=f+24544+(X<<2)|0;V=f+24568+(X<<2)|0;if((c[M>>2]|0)==0){y=X<<4;r=aa;q=0;while(1){x=r+y|0;v=Ee[c[k>>2]&511](f+17024+(x<<5)|0,(c[Y>>2]|0)+(d[1901416+r|0]|0)|0,(c[V>>2]|0)+(e[1901496+(r<<1)>>1]|0)|0)|0;a[(d[19280+x|0]|0)+(f+27984)|0]=v;x=v|q;v=r+1|0;if((v|0)<(s|0)){r=v;q=x}else{ba=x;break}}}else{q=Ee[c[N>>2]&511](f+15488+((X<<2)+g<<7)|0,(c[Y>>2]|0)+$|0,(c[V>>2]|0)+_|0)|0;r=(q*257|0)&65535;y=d[19280+((X<<4)+aa)|0]|0;b[f+27984+y>>1]=r;b[y+8+(f+27984)>>1]=r;ba=q}c[p>>2]=c[p>>2]|ba<<g;X=X+1|0;}while((X|0)<3);i=h;return}X=U<<3;U=X|W<<7;ba=X|W<<8;if((c[f+19356>>2]|0)!=0){W=l+31&-32;X=f+37612|0;aa=f+18644|0;_=f+18640|0;$=f+37712|0;N=g<<2;s=f+28820|0;k=f+37640|0;M=(o|0)==0;q=f+37732|0;r=f+37616|0;y=f+37772|0;J=f+37760|0;x=f+33820|0;v=f+33816|0;Z=0;O=t;while(1){C=(Z|0)!=0;H=C?3:1;R=(c[f+24568+(Z<<2)>>2]|0)+ba|0;ef[c[X>>2]&4095](W,(c[f+24544+(Z<<2)>>2]|0)+U|0,R);E=d[1625047+Z|0]|0;if((c[aa>>2]|0)!=0){F=(C&1)<<1|1;mf[c[J>>2]&2047](W,(c[x>>2]|0)+(F<<8)|0,(c[v>>2]|0)+(F<<7)|0,64)}if((c[_>>2]|0)==0){ca=Ee[c[$>>2]&511](W,(c[f+1732+(H<<2)>>2]|0)+(O<<7)|0,(c[f+1764+(H<<2)>>2]|0)+(O<<7)|0)|0}else{ca=$Tb(f,W,H,O,E,0,C&1,(Z<<2)+g|0)|0}do{if((ca|0)==0){C=d[19280+((Z<<4)+N)|0]|0;b[f+27984+C>>1]=0;b[C+8+(f+27984)>>1]=0}else{C=f+15488+((Z<<2)+g<<7)|0;re[c[k>>2]&1023](C,W);do{if(M){da=ca}else{if((c[_>>2]|0)!=0){da=ca;break}da=(ve[c[y>>2]&4095](C)|0)>3|0}}while(0);if((da|0)==0){C=d[19280+((Z<<4)+N)|0]|0;b[f+27984+C>>1]=0;b[C+8+(f+27984)>>1]=0;break}else{ef[c[q>>2]&4095](W,c[f+1668+(H<<2)>>2]|0,O);re[c[r>>2]&1023](R,W);C=d[19280+((Z<<4)+N)|0]|0;b[f+27984+C>>1]=257;b[C+8+(f+27984)>>1]=257;c[p>>2]=c[p>>2]|u;break}}}while(0);R=Z+1|0;if((R|0)<3){Z=R;O=c[s>>2]|0}else{break}}i=h;return}s=(o|0)!=0?0:4;o=m+31&-32;O=f+37580|0;Z=g<<2;N=f+18644|0;W=f+18640|0;r=f+37720|0;q=f+37644|0;da=f+37736|0;y=f+37768|0;ca=f+28820|0;_=f+37588|0;M=f+37760|0;k=f+33820|0;$=f+33816|0;v=o|0;x=o+32|0;J=o+64|0;aa=o+96|0;X=0;R=t;while(1){t=(X|0)!=0;H=t?3:1;V=(c[f+24568+(X<<2)>>2]|0)+ba|0;ef[c[O>>2]&4095](o,(c[f+24544+(X<<2)>>2]|0)+U|0,V);Y=(X<<4)+Z|0;C=d[19280+Y|0]|0;E=f+27984+C|0;b[E>>1]=0;F=C+8+(f+27984)|0;b[F>>1]=0;if((c[N>>2]|0)!=0){C=(t&1)<<1;mf[c[M>>2]&2047](v,(c[k>>2]|0)+(C<<8)|0,(c[$>>2]|0)+(C<<7)|0,16);mf[c[M>>2]&2047](x,(c[k>>2]|0)+(C<<8)|0,(c[$>>2]|0)+(C<<7)|0,16);mf[c[M>>2]&2047](J,(c[k>>2]|0)+(C<<8)|0,(c[$>>2]|0)+(C<<7)|0,16);mf[c[M>>2]&2047](aa,(c[k>>2]|0)+(C<<8)|0,(c[$>>2]|0)+(C<<7)|0,16)}do{if((c[W>>2]|0)==0){C=Ee[c[r>>2]&511](o,(c[f+1716+(H<<2)>>2]|0)+(R<<5)|0,(c[f+1748+(H<<2)>>2]|0)+(R<<5)|0)|0;if((C|0)==0){break}D=f+1652+(H<<2)|0;A=s;z=0;I=C;while(1){G=d[98856+I|0]|0;B=G+z|0;L=I>>G+1;G=B+Y|0;K=f+17024+(G<<5)|0;Q=o+(B<<5)|0;re[c[q>>2]&1023](K,Q);ef[c[da>>2]&4095](Q,c[D>>2]|0,R);if((A|0)<4){ea=(ve[c[y>>2]&4095](K)|0)+A|0}else{ea=A}a[(d[19280+G|0]|0)+(f+27984)|0]=1;if((L|0)==0){fa=C;ga=ea;ha=42;break}else{A=ea;z=B+1|0;I=L}}}else{I=d[1625038+X|0]|0;z=t&1;A=f+1652+(H<<2)|0;C=s;D=0;L=0;while(1){B=o+(L<<5)|0;G=L+Y|0;if((_Tb(f,B,H,R,I,0,z,G)|0)==0){ia=D;ja=C}else{K=f+17024+(G<<5)|0;re[c[q>>2]&1023](K,B);ef[c[da>>2]&4095](B,c[A>>2]|0,R);if((C|0)<4){ka=(ve[c[y>>2]&4095](K)|0)+C|0}else{ka=C}a[(d[19280+G|0]|0)+(f+27984)|0]=1;ia=1;ja=ka}G=L+1|0;if((G|0)<4){C=ja;D=ia;L=G}else{fa=ia;ga=ja;ha=42;break}}}}while(0);do{if((ha|0)==42){ha=0;if((fa|0)==0){break}if((ga|0)<4){b[E>>1]=0;b[F>>1]=0;break}else{re[c[_>>2]&1023](V,o);c[p>>2]=c[p>>2]|u;break}}}while(0);V=X+1|0;if((V|0)<3){X=V;R=c[ca>>2]|0}else{break}}i=h;return}else{ca=c[f+18648>>2]|0;R=c[f+28816>>2]|0;X=g&1;u=g>>1;p=f+19364|0;c[p>>2]=0;o=1<<g;_=f+19360|0;c[_>>2]=c[_>>2]&~o;if((c[f+19380>>2]|0)==0){UOb(f,g)}if((c[f+28836>>2]|0)!=0){ga=X<<3;fa=g<<2;ha=fa+4|0;ja=f+37652|0;ia=u<<7;ka=f+24544|0;y=f+24568|0;if((c[f+19356>>2]|0)==0){da=fa;q=0;while(1){s=Ee[c[ja>>2]&511](f+17024+(da<<5)|0,(c[ka>>2]|0)+(d[1901416+da|0]|0)|0,(c[y>>2]|0)+(e[1901496+(da<<1)>>1]|0)|0)|0;a[(d[19280+da|0]|0)+(f+27984)|0]=s;ea=s|q;s=da+1|0;if((s|0)<(ha|0)){da=s;q=ea}else{la=ea;break}}}else{q=Ee[c[f+37648>>2]&511](f+15488+(g<<7)|0,(c[ka>>2]|0)+(ga|ia)|0,(c[y>>2]|0)+(ga|u<<8)|0)|0;ga=(q*257|0)&65535;y=d[19280+fa|0]|0;b[f+27984+y>>1]=ga;b[y+8+(f+27984)>>1]=ga;la=q}c[_>>2]=c[_>>2]|la<<g;la=X<<2;q=u<<6|la;ga=ia|la;la=f+37656|0;ia=g+16|0;y=(d[19280+ia|0]|0)+(f+27984)|0;a[y]=hf[c[la>>2]&1023](f+17024+(ia<<5)|0,(c[f+24548>>2]|0)+q|0,(c[f+24572>>2]|0)+ga|0,j)|0;ia=g+32|0;y=(d[19280+ia|0]|0)+(f+27984)|0;a[y]=hf[c[la>>2]&1023](f+17024+(ia<<5)|0,(c[f+24552>>2]|0)+q|0,(c[f+24576>>2]|0)+ga|0,j)|0;c[p>>2]=2;i=h;return}j=X<<3;ga=u<<7;q=j|ga;ia=j|u<<8;do{if((c[f+19356>>2]|0)==0){j=(ca|0)!=0?0:4;la=m+31&-32;y=g<<2;fa=f+37644|0;ka=f+37736|0;da=f+37768|0;ha=f+37588|0;ja=f+37760|0;ea=f+33820|0;s=f+33816|0;r=(c[f+24568>>2]|0)+ia|0;ef[c[f+37580>>2]&4095](la,(c[f+24544>>2]|0)+q|0,r);W=d[19280+y|0]|0;$=f+27984+W|0;b[$>>1]=0;k=W+8+(f+27984)|0;b[k>>1]=0;if((c[f+18644>>2]|0)!=0){mf[c[ja>>2]&2047](la|0,c[ea>>2]|0,c[s>>2]|0,16);mf[c[ja>>2]&2047](la+32|0,c[ea>>2]|0,c[s>>2]|0,16);mf[c[ja>>2]&2047](la+64|0,c[ea>>2]|0,c[s>>2]|0,16);mf[c[ja>>2]&2047](la+96|0,c[ea>>2]|0,c[s>>2]|0,16)}if((c[f+18640>>2]|0)==0){s=Ee[c[f+37720>>2]&511](la,(c[f+1720>>2]|0)+(R<<5)|0,(c[f+1752>>2]|0)+(R<<5)|0)|0;if((s|0)==0){ma=fa;na=ka;break}ea=f+1656|0;ja=j;W=0;aa=s;while(1){M=d[98856+aa|0]|0;J=M+W|0;x=aa>>M+1;M=J+y|0;v=f+17024+(M<<5)|0;N=la+(J<<5)|0;re[c[fa>>2]&1023](v,N);ef[c[ka>>2]&4095](N,c[ea>>2]|0,R);if((ja|0)<4){oa=(ve[c[da>>2]&4095](v)|0)+ja|0}else{oa=ja}a[(d[19280+M|0]|0)+(f+27984)|0]=1;if((x|0)==0){pa=s;qa=oa;break}else{ja=oa;W=J+1|0;aa=x}}}else{aa=f+1656|0;W=j;ja=0;s=0;while(1){ea=la+(s<<5)|0;x=s+y|0;if((_Tb(f,ea,1,R,2,0,0,x)|0)==0){ra=ja;sa=W}else{J=f+17024+(x<<5)|0;re[c[fa>>2]&1023](J,ea);ef[c[ka>>2]&4095](ea,c[aa>>2]|0,R);if((W|0)<4){ta=(ve[c[da>>2]&4095](J)|0)+W|0}else{ta=W}a[(d[19280+x|0]|0)+(f+27984)|0]=1;ra=1;sa=ta}x=s+1|0;if((x|0)<4){W=sa;ja=ra;s=x}else{pa=ra;qa=sa;break}}}if((pa|0)==0){ma=fa;na=ka;break}if((qa|0)<4){b[$>>1]=0;b[k>>1]=0;ma=fa;na=ka;break}else{re[c[ha>>2]&1023](r,la);c[_>>2]=c[_>>2]|o;ma=fa;na=ka;break}}else{s=l+31&-32;ja=f+18640|0;W=g<<2;da=(ca|0)==0;aa=f+37732|0;y=f+37616|0;j=f+37772|0;x=(c[f+24568>>2]|0)+ia|0;ef[c[f+37612>>2]&4095](s,(c[f+24544>>2]|0)+q|0,x);if((c[f+18644>>2]|0)!=0){mf[c[f+37760>>2]&2047](s,(c[f+33820>>2]|0)+256|0,(c[f+33816>>2]|0)+128|0,64)}if((c[ja>>2]|0)==0){ua=Ee[c[f+37712>>2]&511](s,(c[f+1736>>2]|0)+(R<<7)|0,(c[f+1768>>2]|0)+(R<<7)|0)|0}else{ua=$Tb(f,s,1,R,5,0,0,g)|0}do{if((ua|0)==0){J=d[19280+W|0]|0;b[f+27984+J>>1]=0;b[J+8+(f+27984)>>1]=0}else{J=f+15488+(g<<7)|0;re[c[f+37640>>2]&1023](J,s);do{if(da){va=ua}else{if((c[ja>>2]|0)!=0){va=ua;break}va=(ve[c[j>>2]&4095](J)|0)>3|0}}while(0);if((va|0)==0){J=d[19280+W|0]|0;b[f+27984+J>>1]=0;b[J+8+(f+27984)>>1]=0;break}else{ef[c[aa>>2]&4095](s,c[f+1672>>2]|0,R);re[c[y>>2]&1023](x,s);J=d[19280+W|0]|0;b[f+27984+J>>1]=257;b[J+8+(f+27984)>>1]=257;c[_>>2]=c[_>>2]|o;break}}}while(0);ma=f+37644|0;na=f+37736|0}}while(0);o=c[f+28820>>2]|0;_=n+31&-32;n=X<<2;X=u<<6|n;u=ga|n;n=f+37572|0;ga=f+18644|0;R=f+18640|0;va=f+37716|0;ua=f+1728|0;q=f+1760|0;ia=f+1664|0;ca=f+37576|0;l=f+37760|0;qa=f+33820|0;pa=f+33816|0;sa=g+16|0;g=0;while(1){ra=g+1|0;ta=sa+(g<<4)|0;oa=(d[19280+ta|0]|0)+(f+27984)|0;m=_|0;W=(c[f+24568+(ra<<2)>>2]|0)+u|0;ef[c[n>>2]&4095](m,(c[f+24544+(ra<<2)>>2]|0)+X|0,W);if((c[ga>>2]|0)!=0){mf[c[l>>2]&2047](m,(c[qa>>2]|0)+512|0,(c[pa>>2]|0)+256|0,16)}b[m>>1]=0;if((c[R>>2]|0)==0){wa=Ee[c[va>>2]&511](m,(c[ua>>2]|0)+(o<<5)|0,(c[q>>2]|0)+(o<<5)|0)|0}else{wa=_Tb(f,m,3,o,4,0,1,0)|0}a[oa]=wa;if((wa|0)!=0){re[c[ma>>2]&1023](f+17024+(ta<<5)|0,m);ef[c[na>>2]&4095](m,c[ia>>2]|0,o);re[c[ca>>2]&1023](W,m)}if((ra|0)<2){g=ra}else{break}}c[p>>2]=2;i=h;return}}function yMb(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;i=i+64|0;h=b+28816|0;j=d[1901416+f|0]|0;k=e[1901496+(f<<1)>>1]|0;l=b+28836|0;m=g+31&-32;n=b+37572|0;o=b+18644|0;p=b+18640|0;q=b+37716|0;r=b+37644|0;s=b+37736|0;t=b+37576|0;u=b+37760|0;v=b+33820|0;w=b+33816|0;x=b+28820|0;y=b+37652|0;if((c[b+8632>>2]|0)==3){z=0;A=h;while(1){B=c[A>>2]|0;C=(z|0)!=0;D=C?3:1;E=(c[b+24544+(z<<2)>>2]|0)+j|0;F=(c[b+24568+(z<<2)>>2]|0)+k|0;do{if((c[l>>2]|0)==0){ef[c[n>>2]&4095](m,E,F);G=d[1625038+z|0]|0;if((c[o>>2]|0)!=0){H=(C&1)<<1;mf[c[u>>2]&2047](m,(c[v>>2]|0)+(H<<8)|0,(c[w>>2]|0)+(H<<7)|0,16)}if((c[p>>2]|0)==0){I=Ee[c[q>>2]&511](m,(c[b+1716+(D<<2)>>2]|0)+(B<<5)|0,(c[b+1748+(D<<2)>>2]|0)+(B<<5)|0)|0;J=(z<<4)+f|0}else{H=(z<<4)+f|0;I=_Tb(b,m,D,B,G,0,C&1,H)|0;J=H}a[(d[19280+J|0]|0)+(b+27984)|0]=I;if((I|0)==0){break}re[c[r>>2]&1023](b+17024+(J<<5)|0,m);ef[c[s>>2]&4095](m,c[b+1652+(D<<2)>>2]|0,B);re[c[t>>2]&1023](F,m)}else{H=(z<<4)+f|0;G=(Ee[c[y>>2]&511](b+17024+(H<<5)|0,E,F)|0)&255;a[(d[19280+H|0]|0)+(b+27984)|0]=G}}while(0);F=z+1|0;if((F|0)<3){z=F;A=x}else{break}}i=g;return}x=c[h>>2]|0;h=(c[b+24544>>2]|0)+j|0;j=(c[b+24568>>2]|0)+k|0;if((c[l>>2]|0)!=0){l=(Ee[c[y>>2]&511](b+17024+(f<<5)|0,h,j)|0)&255;a[(d[19280+f|0]|0)+(b+27984)|0]=l;i=g;return}ef[c[n>>2]&4095](m,h,j);if((c[o>>2]|0)!=0){mf[c[u>>2]&2047](m,c[v>>2]|0,c[w>>2]|0,16)}if((c[p>>2]|0)==0){K=Ee[c[q>>2]&511](m,(c[b+1720>>2]|0)+(x<<5)|0,(c[b+1752>>2]|0)+(x<<5)|0)|0}else{K=_Tb(b,m,1,x,2,0,0,f)|0}a[(d[19280+f|0]|0)+(b+27984)|0]=K;if((K|0)==0){i=g;return}re[c[r>>2]&1023](b+17024+(f<<5)|0,m);ef[c[s>>2]&4095](m,c[b+1656>>2]|0,x);re[c[t>>2]&1023](j,m);i=g;return}function zMb(a,e,f){a=a|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0,A=0.0,B=0,C=0,D=0.0,E=0,F=0.0,H=0.0,I=0,J=0,K=0.0,L=0.0,M=0,N=0,O=0.0,P=0.0,Q=0.0,R=0,S=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0,aa=0,ba=0,da=0,ea=0.0,fa=0,ga=0,ha=0,ia=0,ja=0;h=e+8600|0;c[h>>2]=0;i=e+8616|0;j=e+8604|0;c[j>>2]=0;k=e+8624|0;l=e+8608|0;c[l>>2]=0;m=e+8632|0;n=a+684|0;mrc(i|0,0,24)|0;o=c[n>>2]|0;a:do{if((o|0)==0){p=17}else{q=a+688|0;r=+g[q>>2];if(r==0.0){if((f|0)==0){s=a+18568|0;mrc(c[e+8500>>2]|0,0,c[s>>2]<<2|0)|0;mrc(c[e+8504>>2]|0,0,c[s>>2]<<2|0)|0;if((c[a+15136>>2]|0)==0){p=17;break}t=c[s>>2]|0;if((t|0)<=0){p=17;break}s=c[e+8520>>2]|0;u=0;while(1){b[s+(u<<1)>>1]=256;v=u+1|0;if((v|0)<(t|0)){u=v}else{p=17;break a}}}u=c[a+18568>>2]|0;t=(u|0)>0;if(t){s=c[e+8504>>2]|0;v=c[e+8500>>2]|0;w=0;do{x=+g[f+(w<<2)>>2];g[s+(w<<2)>>2]=x;g[v+(w<<2)>>2]=x;w=w+1|0;}while((w|0)<(u|0))}if((c[a+15136>>2]|0)==0|t^1){p=17;break}w=e+8520|0;v=c[e+8500>>2]|0;s=0;while(1){y=~~(+g[v+(s<<2)>>2]*-10.666666984558105+512.5);do{if((y|0)<0){z=0}else{if((y|0)>1023){z=-1;break}z=(d[97768+(y&63)|0]|0|256)<<(y>>6)>>>8&65535}}while(0);b[(c[w>>2]|0)+(s<<1)>>1]=z;y=s+1|0;if((y|0)<(u|0)){s=y}else{p=17;break a}}}if((o|0)==2){s=a+18564|0;u=c[s>>2]|0;if((u|0)>0){w=a+18560|0;v=a+18580|0;t=e+8500|0;x=0.0;y=0;A=0.0;B=c[w>>2]|0;C=u;while(1){if((B|0)>0){D=x;E=0;F=A;do{H=+T(+(+(((AMb(a,E,y,e)|0)+1|0)>>>0>>>0)),+.125);I=(ca(c[v>>2]|0,y)|0)+E|0;g[(c[t>>2]|0)+(I<<2)>>2]=H;F=F+H;D=D+H*H;E=E+1|0;J=c[w>>2]|0;}while((E|0)<(J|0));K=D;L=F;M=J;N=c[s>>2]|0}else{K=x;L=A;M=B;N=C}E=y+1|0;if((E|0)<(N|0)){x=K;y=E;A=L;B=M;C=N}else{break}}O=K;P=L;Q=+g[q>>2];R=N}else{O=0.0;P=0.0;Q=r;R=u}A=+(c[a+18568>>2]|0);x=P/A;S=x*Q;U=x-(O/A+-14.0)*.5/x;V=R}else{S=r*1.0397000312805176;U=0.0;V=c[a+18564>>2]|0}C=a+18564|0;if((V|0)<=0){W=V;break}B=a+18560|0;y=a+18580|0;s=e+8500|0;w=(f|0)==0;t=e+8504|0;v=a+15136|0;E=e+8520|0;I=0;X=c[B>>2]|0;while(1){if((X|0)>0){if(w){Y=0;while(1){Z=(ca(c[y>>2]|0,I)|0)+Y|0;if((c[n>>2]|0)==2){_=+g[(c[s>>2]|0)+(Z<<2)>>2]-U}else{$=AMb(a,Y,I,e)|0;aa=$>>>0>1>>>0?$:1;$=rrc(aa|0)|0;_=+g[95680+((aa<<$>>>24&127)<<2)>>2]+ +g[95552+($<<2)>>2]+ -14.427000045776367}x=S*_;g[(c[t>>2]|0)+(Z<<2)>>2]=x;g[(c[s>>2]|0)+(Z<<2)>>2]=x;if((c[v>>2]|0)!=0){$=~~(x*-10.666666984558105+512.5);do{if(($|0)<0){ba=0}else{if(($|0)>1023){ba=-1;break}ba=(d[97768+($&63)|0]|0|256)<<($>>6)>>>8&65535}}while(0);b[(c[E>>2]|0)+(Z<<1)>>1]=ba}$=Y+1|0;aa=c[B>>2]|0;if(($|0)<(aa|0)){Y=$}else{da=aa;break}}}else{Y=0;while(1){aa=(ca(c[y>>2]|0,I)|0)+Y|0;if((c[n>>2]|0)==2){ea=+g[(c[s>>2]|0)+(aa<<2)>>2]-U}else{$=AMb(a,Y,I,e)|0;fa=$>>>0>1>>>0?$:1;$=rrc(fa|0)|0;ea=+g[95680+((fa<<$>>>24&127)<<2)>>2]+ +g[95552+($<<2)>>2]+ -14.427000045776367}F=S*ea+ +g[f+(aa<<2)>>2];g[(c[t>>2]|0)+(aa<<2)>>2]=F;g[(c[s>>2]|0)+(aa<<2)>>2]=F;if((c[v>>2]|0)!=0){$=~~(F*-10.666666984558105+512.5);do{if(($|0)<0){ga=0}else{if(($|0)>1023){ga=-1;break}ga=(d[97768+($&63)|0]|0|256)<<($>>6)>>>8&65535}}while(0);b[(c[E>>2]|0)+(aa<<1)>>1]=ga}$=Y+1|0;Z=c[B>>2]|0;if(($|0)<(Z|0)){Y=$}else{da=Z;break}}}}else{da=X}Y=I+1|0;Z=c[C>>2]|0;if((Y|0)<(Z|0)){I=Y;X=da}else{W=Z;break}}}}while(0);do{if((p|0)==17){if((c[a+528>>2]|0)==0){return}da=a+18564|0;ga=c[da>>2]|0;if((ga|0)<=0){W=ga;break}f=a+18560|0;n=0;ba=c[f>>2]|0;V=ga;while(1){if((ba|0)>0){ga=0;do{AMb(a,ga,n,e)|0;ga=ga+1|0;ha=c[f>>2]|0;}while((ga|0)<(ha|0));ia=ha;ja=c[da>>2]|0}else{ia=ba;ja=V}ga=n+1|0;if((ga|0)<(ja|0)){n=ga;ba=ia;V=ja}else{W=ja;break}}}}while(0);ja=a+18564|0;ia=a+18572|0;ha=a+18576|0;e=c[i>>2]|0;p=c[i+4>>2]|0;V=c[h>>2]|0;h=0;ba=c[a+18560>>2]<<4;a=Erc(V,h,V,h)|0;h=ca(W<<4,ba)|0;W=(h|0)/2|0;V=wrc(W,(W|0)<0|0?-1:0,a,G)|0;a=Frc(V,G,h,(h|0)<0|0?-1:0)|0;h=xrc(e,p,a,G)|0;c[i>>2]=h;c[i+4>>2]=G;i=c[k>>2]|0;h=c[k+4>>2]|0;a=c[j>>2]|0;j=0;p=ba>>((c[ia>>2]|0)!=0);e=c[ja>>2]<<4>>((c[ha>>2]|0)!=0);V=Erc(a,j,a,j)|0;j=ca(e,p)|0;p=(j|0)/2|0;e=wrc(p,(p|0)<0|0?-1:0,V,G)|0;V=Frc(e,G,j,(j|0)<0|0?-1:0)|0;j=xrc(i,h,V,G)|0;c[k>>2]=j;c[k+4>>2]=G;k=c[m>>2]|0;j=c[m+4>>2]|0;V=c[l>>2]|0;l=0;h=ba>>((c[ia>>2]|0)!=0);ia=c[ja>>2]<<4>>((c[ha>>2]|0)!=0);ha=Erc(V,l,V,l)|0;l=ca(ia,h)|0;h=(l|0)/2|0;ia=wrc(h,(h|0)<0|0?-1:0,ha,G)|0;ha=Frc(ia,G,l,(l|0)<0|0?-1:0)|0;l=xrc(k,j,ha,G)|0;c[m>>2]=l;c[m+4>>2]=G;return}function AMb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;g=i;i=i+256|0;h=g|0;dPb(a,f,b,e);if((c[a+18664>>2]|0)!=0){j=f+156|0;k=c[j>>2]|0;l=b<<4;m=e&-2;n=m<<4;o=-(e&1)|0;p=(ca(k,n)|0)+l+(k&o)|0;q=a+37080|0;r=f+204|0;s=We[c[q>>2]&2047]((c[r>>2]|0)+p|0,k<<1)|0;k=G;p=k;t=0;u=f+8600|0;c[u>>2]=(c[u>>2]|0)+s;u=f+8616|0;v=wrc(c[u>>2]|0,c[u+4>>2]|0,p,t)|0;c[u>>2]=v;c[u+4>>2]=G;u=s|0;s=k&0;k=Erc(u,s,u,s)|0;s=G;u=xrc(p,t,k>>>8|s<<24,s>>>8|0<<24)|0;s=u;u=c[j>>2]|0;j=e<<4;k=(ca(u,j)|0)+l|0;t=We[c[q>>2]&2047]((c[r>>2]|0)+k|0,u)|0;u=G;k=t|0;t=u&0;r=Erc(k,t,k,t)|0;t=G;k=xrc(u,0,r>>>8|t<<24,t>>>8|0<<24)|0;t=k;if((c[a+8632>>2]|0)==3){k=f+160|0;r=c[k>>2]|0;u=(ca(r,n)|0)+l+(r&o)|0;p=f+208|0;v=We[c[q>>2]&2047]((c[p>>2]|0)+u|0,r<<1)|0;r=G;u=r;w=0;x=f+8604|0;c[x>>2]=(c[x>>2]|0)+v;x=f+8624|0;y=wrc(c[x>>2]|0,c[x+4>>2]|0,u,w)|0;c[x>>2]=y;c[x+4>>2]=G;x=v|0;v=r&0;r=Erc(x,v,x,v)|0;v=G;x=xrc(u,w,r>>>8|v<<24,v>>>8|0<<24)|0;v=c[k>>2]|0;k=(ca(v,j)|0)+l|0;r=We[c[q>>2]&2047]((c[p>>2]|0)+k|0,v)|0;v=G;k=r|0;r=v&0;p=Erc(k,r,k,r)|0;r=G;k=xrc(v,0,p>>>8|r<<24,r>>>8|0<<24)|0;r=f+164|0;p=c[r>>2]|0;v=(ca(p,n)|0)+l+(p&o)|0;n=f+212|0;w=We[c[q>>2]&2047]((c[n>>2]|0)+v|0,p<<1)|0;p=G;v=p;u=0;y=f+8608|0;c[y>>2]=(c[y>>2]|0)+w;y=f+8632|0;z=wrc(c[y>>2]|0,c[y+4>>2]|0,v,u)|0;c[y>>2]=z;c[y+4>>2]=G;y=w|0;w=p&0;p=Erc(y,w,y,w)|0;w=G;y=xrc(v,u,p>>>8|w<<24,w>>>8|0<<24)|0;w=c[r>>2]|0;r=(ca(w,j)|0)+l|0;j=We[c[q>>2]&2047]((c[n>>2]|0)+r|0,w)|0;w=G;r=j|0;j=w&0;n=Erc(r,j,r,j)|0;j=G;r=xrc(w,0,n>>>8|j<<24,j>>>8|0<<24)|0;A=k+t+r|0;B=x+s+y|0}else{y=h|0;x=a+18576|0;r=c[x>>2]|0;k=16>>>(r>>>0);j=f+160|0;n=c[j>>2]|0;w=(n&o)+l+(ca(ca(k,m)|0,n)|0)|0;m=a+36448|0;o=d[m]|0;q=a+37472|0;p=f+208|0;mf[c[q>>2]&2047](y,(c[p>>2]|0)+w|0,n<<1,k);k=a+37080+(o<<2)|0;o=We[c[k>>2]&2047](y,16)|0;n=G;w=n;u=0;v=f+8604|0;c[v>>2]=(c[v>>2]|0)+o;v=f+8624|0;z=wrc(c[v>>2]|0,c[v+4>>2]|0,w,u)|0;c[v>>2]=z;c[v+4>>2]=G;v=o|0;o=n&0;n=Erc(v,o,v,o)|0;o=7-r|0;r=zrc(n|0,G|0,o|0)|0;n=xrc(w,u,r,G)|0;r=h+8|0;u=We[c[k>>2]&2047](r,16)|0;k=G;w=k;v=0;z=f+8608|0;c[z>>2]=(c[z>>2]|0)+u;z=f+8632|0;C=wrc(c[z>>2]|0,c[z+4>>2]|0,w,v)|0;c[z>>2]=C;c[z+4>>2]=G;z=u|0;u=k&0;k=Erc(z,u,z,u)|0;u=zrc(k|0,G|0,o|0)|0;o=xrc(w,v,u,G)|0;u=c[x>>2]|0;x=16>>>(u>>>0);v=c[j>>2]|0;j=(ca(ca(x,e)|0,v)|0)+l|0;l=d[m]|0;mf[c[q>>2]&2047](y,(c[p>>2]|0)+j|0,v,x);x=a+37080+(l<<2)|0;l=We[c[x>>2]&2047](y,16)|0;y=G;v=l|0;l=y&0;j=Erc(v,l,v,l)|0;l=7-u|0;u=zrc(j|0,G|0,l|0)|0;j=xrc(y,0,u,G)|0;u=We[c[x>>2]&2047](r,16)|0;r=G;x=u|0;u=r&0;y=Erc(x,u,x,u)|0;u=zrc(y|0,G|0,l|0)|0;l=xrc(r,0,u,G)|0;A=j+t+l|0;B=n+s+o|0}D=B>>>0<A>>>0?B:A;i=g;return D|0}A=a+160|0;B=c[A>>2]|0;o=c[f+156>>2]|0;s=b<<4;b=e<<4;if((B|0)==0){E=(ca(o,b)|0)+s|0}else{E=(ca(o,b&-32)|0)+s+(o&-(e&1))|0}n=a+37080|0;l=We[c[n>>2]&2047]((c[f+204>>2]|0)+E|0,o<<B)|0;B=G;o=B;E=0;t=f+8600|0;c[t>>2]=(c[t>>2]|0)+l;t=f+8616|0;j=wrc(c[t>>2]|0,c[t+4>>2]|0,o,E)|0;c[t>>2]=j;c[t+4>>2]=G;t=l|0;l=B&0;B=Erc(t,l,t,l)|0;l=G;t=xrc(o,E,B>>>8|l<<24,l>>>8|0<<24)|0;l=t;t=c[A>>2]|0;if((c[a+8632>>2]|0)!=3){B=h|0;E=c[a+18576>>2]|0;o=16>>>(E>>>0);j=c[f+160>>2]|0;if((t|0)==0){F=(ca(ca(o,e)|0,j)|0)+s|0}else{F=(j&-(e&1))+s+(ca(ca(o,e&-2)|0,j)|0)|0}u=d[a+36448|0]|0;mf[c[a+37472>>2]&2047](B,(c[f+208>>2]|0)+F|0,j<<t,o);o=a+37080+(u<<2)|0;u=We[c[o>>2]&2047](B,16)|0;B=G;a=B;j=0;F=f+8604|0;c[F>>2]=(c[F>>2]|0)+u;F=f+8624|0;r=wrc(c[F>>2]|0,c[F+4>>2]|0,a,j)|0;c[F>>2]=r;c[F+4>>2]=G;F=u|0;u=B&0;B=Erc(F,u,F,u)|0;u=7-E|0;E=zrc(B|0,G|0,u|0)|0;B=xrc(a,j,E,G)|0;E=We[c[o>>2]&2047](h+8|0,16)|0;h=G;o=h;j=0;a=f+8608|0;c[a>>2]=(c[a>>2]|0)+E;a=f+8632|0;F=wrc(c[a>>2]|0,c[a+4>>2]|0,o,j)|0;c[a>>2]=F;c[a+4>>2]=G;a=E|0;E=h&0;h=Erc(a,E,a,E)|0;E=zrc(h|0,G|0,u|0)|0;u=xrc(o,j,E,G)|0;D=B+l+u|0;i=g;return D|0}u=c[f+160>>2]|0;if((t|0)==0){H=(ca(u,b)|0)+s|0}else{H=(ca(u,b&-32)|0)+s+(u&-(e&1))|0}B=We[c[n>>2]&2047]((c[f+208>>2]|0)+H|0,u<<t)|0;t=G;u=t;H=0;E=f+8604|0;c[E>>2]=(c[E>>2]|0)+B;E=f+8624|0;j=wrc(c[E>>2]|0,c[E+4>>2]|0,u,H)|0;c[E>>2]=j;c[E+4>>2]=G;E=B|0;B=t&0;t=Erc(E,B,E,B)|0;B=G;E=xrc(u,H,t>>>8|B<<24,B>>>8|0<<24)|0;B=c[A>>2]|0;A=c[f+164>>2]|0;if((B|0)==0){I=(ca(A,b)|0)+s|0}else{I=(ca(A,b&-32)|0)+s+(A&-(e&1))|0}e=We[c[n>>2]&2047]((c[f+212>>2]|0)+I|0,A<<B)|0;B=G;A=B;I=0;n=f+8608|0;c[n>>2]=(c[n>>2]|0)+e;n=f+8632|0;f=wrc(c[n>>2]|0,c[n+4>>2]|0,A,I)|0;c[n>>2]=f;c[n+4>>2]=G;n=e|0;e=B&0;B=Erc(n,e,n,e)|0;e=G;n=xrc(A,I,B>>>8|e<<24,e>>>8|0<<24)|0;D=E+l+n|0;i=g;return D|0}function BMb(e,f,h){e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0,J=0,K=0.0,L=0,M=0.0,N=0,O=0,P=0.0,Q=0;j=i;i=i+8|0;k=j|0;l=c[e+30496>>2]|0;m=c[f+92>>2]|0;n=c[l+268>>2]|0;o=c[n+(m*192|0)>>2]|0;if((c[n+(m*192|0)+8>>2]|0)==0){zMb(e,f,h);p=0;i=j;return p|0}h=l+400|0;m=c[h>>2]|0;a:do{if((m|0)<0){n=l+260|0;q=l+404|0;r=o&255;s=o&255;t=m;while(1){c[h>>2]=t+1;if((Ed(k|0,1,1,c[n>>2]|0)|0)==0){u=48;break}v=Ed(c[l+392+(c[h>>2]<<2)>>2]|0,2,c[q>>2]|0,c[n>>2]|0)|0;if((v|0)!=(c[q>>2]|0)){u=48;break}w=a[k]|0;x=w&255;if((x|0)!=(r|0)){if((c[h>>2]|0)==1){u=9;break}}if(w<<24>>24==s<<24>>24){y=v;break a}t=c[h>>2]|0}if((u|0)==9){ILb(e,0,2433536,(z=i,i=i+16|0,c[z>>2]=x,c[z+8>>2]=r,z)|0);i=z;p=-1;i=j;return p|0}else if((u|0)==48){ILb(e,0,2583272,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;p=-1;i=j;return p|0}}else{y=c[l+404>>2]|0}}while(0);z=(c[l+408>>2]|0)==0;u=l+412|0;x=f+8500|0;k=c[(z?x:u)>>2]|0;if((y|0)>0){m=c[l+392+(c[h>>2]<<2)>>2]|0;o=0;do{g[k+(o<<2)>>2]=+((he(b[m+(o<<1)>>1]|0)|0)<<16>>16|0)*.00390625;o=o+1|0;}while((o|0)<(y|0))}do{if(!z){y=c[x>>2]|0;o=l+416|0;m=c[l+420>>2]|0;k=c[l+444>>2]|0;t=c[l+448>>2]|0;if((t|0)>0){s=c[l+428>>2]|0;q=c[e+18560>>2]|0;n=(q|0)>0;v=(m|0)>0;w=l+436|0;A=k-1|0;B=c[u>>2]|0;C=c[o>>2]|0;D=0;while(1){if(n){E=s;F=0;while(1){if(v){G=c[(c[w>>2]|0)+(F<<2)>>2]|0;H=0.0;I=0;while(1){if((G|0)<0){J=0}else{J=(G|0)>(A|0)?A:G}K=H+ +g[B+(J<<2)>>2]*+g[E+(I<<2)>>2];L=I+1|0;if((L|0)<(m|0)){G=G+1|0;H=K;I=L}else{M=K;break}}}else{M=0.0}g[C+(F<<2)>>2]=M;I=F+1|0;if((I|0)<(q|0)){E=E+(m<<2)|0;F=I}else{break}}}F=D+1|0;if((F|0)<(t|0)){B=B+(k<<2)|0;C=C+(q<<2)|0;D=F}else{N=q;break}}}else{N=c[e+18560>>2]|0}q=c[l+424>>2]|0;if((N|0)<=0){break}D=c[l+432>>2]|0;C=c[e+18564>>2]|0;k=(C|0)>0;B=(q|0)>0;m=l+440|0;A=t-1|0;w=c[o>>2]|0;v=y;s=0;while(1){b:do{if(k){if(!B){n=0;while(1){g[v+((ca(n,N)|0)<<2)>>2]=0.0;n=n+1|0;if((n|0)>=(C|0)){break b}}}n=c[m>>2]|0;r=D;F=0;while(1){E=c[n+(F<<2)>>2]|0;H=0.0;I=0;while(1){if((E|0)<0){O=0}else{O=(E|0)>(A|0)?A:E}K=+g[w+((ca(O,N)|0)<<2)>>2];P=H+K*+g[r+(I<<2)>>2];G=I+1|0;if((G|0)<(q|0)){E=E+1|0;H=P;I=G}else{break}}g[v+((ca(F,N)|0)<<2)>>2]=P;I=F+1|0;if((I|0)<(C|0)){r=r+(q<<2)|0;F=I}else{break}}}}while(0);F=s+1|0;if((F|0)<(N|0)){w=w+4|0;v=v+4|0;s=F}else{break}}}}while(0);do{if((c[e+15136>>2]|0)!=0){N=c[e+18568>>2]|0;if((N|0)<=0){break}O=f+8520|0;l=c[x>>2]|0;J=0;do{u=~~(+g[l+(J<<2)>>2]*-10.666666984558105+512.5);do{if((u|0)<0){Q=0}else{if((u|0)>1023){Q=-1;break}Q=(d[97768+(u&63)|0]|0|256)<<(u>>6)>>>8&65535}}while(0);b[(c[O>>2]|0)+(J<<1)>>1]=Q;J=J+1|0;}while((J|0)<(N|0))}}while(0);c[h>>2]=(c[h>>2]|0)-1;p=0;i=j;return p|0}function CMb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+2432|0;d=b|0;e=b+64|0;f=b+2368|0;g=c[(c[a+30496>>2]|0)+64>>2]|0;h=a+15152|0;if((c[g+168>>2]|0)!=(c[h>>2]|0)){j=-1;i=b;return j|0}nrc(d|0,a+15160|0,64)|0;nrc(f|0,g+104|0,64)|0;g=a+15144|0;k=c[g>>2]|0;nrc(e|0,k+400|0,2304)|0;mrc(k+544|0,0,2160)|0;k=c[h>>2]|0;if((k|0)>1){l=1;m=k}else{j=0;i=b;return j|0}while(1){if((m|0)>1){k=-1;n=1;o=1;while(1){p=c[f+(o<<2)>>2]|0;q=(p|0)>(k|0);r=q?o:n;s=o+1|0;if((s|0)<(m|0)){k=q?p:k;n=r;o=s}else{t=r;break}}}else{t=1}c[f+(t<<2)>>2]=-1;c[a+15160+(l<<2)>>2]=c[d+(t<<2)>>2];nrc((c[g>>2]|0)+400+(l*144|0)|0,e+(t*144|0)|0,144)|0;o=l+1|0;n=c[h>>2]|0;if((o|0)<(n|0)){l=o;m=n}else{j=0;break}}i=b;return j|0}function DMb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0.0,S=0.0,U=0.0,V=0;d=i;e=c[a+30496>>2]|0;f=(b|0)!=0;do{if(!f){if((c[e+4>>2]|0)==0){break}i=d;return}}while(0);b=a+624|0;if((c[b>>2]|0)==1){j=+(ca((c[a+112>>2]|0)!=0?120:80,c[a+18568>>2]|0)|0);if((c[a+692>>2]|0)==0){k=0.0}else{k=(1.0- +g[a+716>>2])*13.5}l=+T(+j,+(1.0- +h[e+40>>3]));h[e+216>>3]=l/(+ad(+((k+ +g[a+648>>2]+0.0+-12.0)/6.0))*.8500000238418579)}m=a+660|0;n=c[m>>2]|0;if((n|0)<=0){i=d;return}o=a+664|0;p=c[o>>2]|0;if((p|0)<=0){i=d;return}q=e+12|0;if((c[q>>2]|0)==0){r=n}else{n=c[a+644>>2]|0;c[m>>2]=n;r=n}n=e+16|0;s=~~(+(r|0)/+h[n>>3]);if((p|0)<(s|0)){c[o>>2]=s;ILb(a,1,2438584,(t=i,i=i+8|0,c[t>>2]=s,t)|0);i=t;u=c[o>>2]|0;v=c[m>>2]|0}else{u=p;v=r}r=(c[a+136>>2]|0)!=0?1024:1e3;p=ca(r,u)|0;u=ca(v,r)|0;v=c[a+48>>2]|0;s=(v|0)==0;do{if(s|f^1){if(s|f){w=p;x=u;y=a+8564|0;z=a+8568|0;break}ILb(a,1,2351304,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;i=d;return}else{c[a+8544>>2]=1;c[a+8572>>2]=(v|0)==2;c[a+8588>>2]=0;A=(src(u|0)|0)-6|0;if((A|0)<0){B=0}else{B=(A|0)>15?15:A}c[a+8548>>2]=B;A=B+6|0;C=u>>A;c[a+8556>>2]=C;D=C<<A;A=a+8564|0;c[A>>2]=D;C=(src(p|0)|0)-4|0;if((C|0)<0){E=0}else{E=(C|0)>15?15:C}c[a+8552>>2]=E;C=E+4|0;G=p>>C;c[a+8560>>2]=G;H=G<<C;C=a+8568|0;c[C>>2]=H;k=+((c[a+8528>>2]|0)>>>0>>>0);l=+((c[a+8524>>2]|0)>>>0>>>0);j=+(c[a+96>>2]|0)*.5*k/l;if(j<2147483647.0){I=~~j}else{I=2147483647}G=~~(+(c[a+8624>>2]|0)*.5*k/l);J=32-(rrc(~~(+(H|0)*9.0e4/+(D|0)+.5)|0)|0)|0;if(J>>>0<4>>>0){K=6}else{K=J>>>0>22>>>0?24:J+2|0}c[a+8576>>2]=K;J=32-(rrc(I|0)|0)|0;if(J>>>0<4>>>0){L=4}else{L=J>>>0>31>>>0?31:J}c[a+8580>>2]=L;J=32-(rrc(G|0)|0)|0;if(J>>>0<4>>>0){M=4}else{M=J>>>0>31>>>0?31:J}c[a+8584>>2]=M;w=H;x=D;y=A;z=C}}while(0);c[y>>2]=x;c[z>>2]=w;if((c[q>>2]|0)==0){N=+h[e+24>>3]}else{l=+(r|0)*+(c[a+644>>2]|0);h[e+24>>3]=l;N=l}l=+(x|0);k=+h[n>>3];j=l/k;n=e+120|0;h[n>>3]=j;h[e+128>>3]=l;l=+(w|0);w=e+96|0;h[w>>3]=l;c[e+140>>2]=j*1.1>l;O=1.5-j*k/N;h[e+192>>3]=1.0-j/l*.5*(O<0.0?0.0:O);do{if((c[b>>2]|0)==1){O=+g[a+652>>2];if(!(O!=0.0)){break}l=O- +g[a+648>>2];x=e+144|0;g[x>>2]=l;if(l>0.0){break}ILb(a,1,2289648,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;g[x>>2]=0.0}}while(0);if(!f){i=d;return}f=a+668|0;l=+g[f>>2];if(l>1.0){O=l/+(c[o>>2]|0);if(O<0.0){P=0.0}else{P=O>1.0?1.0:O}g[f>>2]=P;S=P}else{S=l}l=S;S=+h[w>>3];P=+h[n>>3]/S;O=l>P?l:P;if(O<0.0){U=0.0}else{U=O>1.0?1.0:O}g[f>>2]=U;O=S*U*+((c[a+8528>>2]|0)>>>0>>>0);f=(F=+O,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);n=e+104|0;c[n>>2]=~~+O>>>0;c[n+4>>2]=f;c[e+8>>2]=1;do{if((c[e+4>>2]|0)==0){if((c[b>>2]|0)!=2){V=0;break}V=(c[m>>2]|0)<=(c[a+644>>2]|0)|0}else{V=0}}while(0);c[q>>2]=V;i=d;return}function EMb(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,aa=0,da=0,ea=0,fa=0.0,ga=0.0,ia=0,ja=0.0,ka=0,la=0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0.0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0.0,Pa=0,Qa=0.0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0.0,Wa=0.0,Xa=0.0,Ya=0.0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0,gb=0.0,hb=0.0,ib=0.0,jb=0,kb=0,lb=0.0,mb=0.0,nb=0.0,ob=0.0,pb=0.0,qb=0.0,rb=0.0,sb=0.0,tb=0.0,ub=0.0,vb=0.0,wb=0.0,xb=0.0,yb=0,zb=0.0,Ab=0,Bb=0,Cb=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0.0,Sb=0.0,Tb=0.0,Ub=0,Vb=0.0,Wb=0.0,Xb=0.0,Yb=0,Zb=0.0,$b=0.0,ac=0.0,bc=0.0,cc=0.0,dc=0,ec=0.0,fc=0.0,hc=0,ic=0.0,jc=0.0,kc=0,nc=0,oc=0.0,pc=0.0,qc=0,rc=0.0,sc=0.0,tc=0.0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0.0,Ac=0.0,Bc=0,Cc=0,Dc=0.0,Ec=0;e=i;i=i+168|0;f=e|0;j=e+8|0;k=e+16|0;l=e+24|0;m=e+32|0;n=e+40|0;o=e+48|0;p=e+56|0;q=e+64|0;r=e+72|0;t=e+80|0;u=e+88|0;v=e+96|0;w=e+104|0;x=e+112|0;z=e+120|0;A=e+136|0;B=e+144|0;C=e+152|0;D=e+160|0;E=d|0;H=d+4|0;I=MLb((c[H>>2]|0)*664|0)|0;J=d+30496|0;c[J>>2]=I;if((I|0)==0){K=-1;i=e;return K|0}mrc(I|0,0,(c[H>>2]|0)*664|0|0)|0;I=c[J>>2]|0;L=d+624|0;if((c[L>>2]|0)==0){M=0}else{M=(c[d+708>>2]|0)==0|0}N=I|0;c[N>>2]=M;if((c[L>>2]|0)==2){O=(c[d+708>>2]|0)!=0|0}else{O=0}c[I+4>>2]=O;O=c[d+784>>2]|0;do{if((O|0)==0){P=9}else{M=c[d+788>>2]|0;if((M|0)==0){P=9;break}h[I+16>>3]=+(O>>>0>>>0)/+(M>>>0>>>0)}}while(0);if((P|0)==9){h[I+16>>3]=25.0}O=d+692|0;if((c[O>>2]|0)==0){h[I+40>>3]=+g[d+716>>2]}else{g[d+676>>2]=1.0;h[I+40>>3]=1.0}M=d+644|0;U=I+24|0;h[U>>3]=+(c[M>>2]|0)*((c[d+136>>2]|0)!=0?1024.0:1.0e3);V=I+32|0;h[V>>3]=+g[d+656>>2];W=d+18568|0;X=I+48|0;c[X>>2]=c[W>>2];Y=I+304|0;c[Y>>2]=-1;h[I+192>>3]=1.0;do{if((c[L>>2]|0)==1){if((c[d+708>>2]|0)==0){break}ILb(d,0,2239176,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);DMb(d,1);do{if((c[d+48>>2]|0)!=0){_=c[d+8564>>2]|0;aa=d+8528|0;da=Erc(c[aa>>2]|0,0,_,(_|0)<0|0?-1:0)|0;c[q>>2]=da;c[q+4>>2]=G;c[r>>2]=18e4;c[r+4>>2]=0;PLb(r,q);da=Frc(18e4,0,c[r>>2]|0,c[r+4>>2]|0)|0;_=G;ea=I+656|0;c[ea>>2]=da;c[ea+4>>2]=_;ea=Frc(18e4,0,da,_)|0;fa=+lc(+(+(ea>>>0)+ +(G>>>0)*4294967296.0));ga=fa+ +lc(+(+((c[aa>>2]|0)>>>0>>>0)));if(ga+ +lc(+(+(c[d+8568>>2]|0)))<63.0){break}ILb(d,0,2198216,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);if(+h[V>>3]<.01){ILb(d,1,2166728,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;h[V>>3]=.01}if((c[I+8>>2]|0)==0){ia=(c[d+684>>2]|0)!=0|0}else{ia=1}V=d+28832|0;c[V>>2]=ia;if((c[N>>2]|0)!=0){h[I+320>>3]=.01;if((c[L>>2]|0)==1){ja=(+g[d+648>>2]+0.0)*.01}else{ja=.24}h[I+312>>3]=ja;ja=+T(+7.0e5,+(+h[I+40>>3]))*.01;h[I+160>>3]=ja*+R(+(+S(+(c[W>>2]|0))));h[I+184>>3]=+h[U>>3]/+h[I+16>>3];c[Y>>2]=2}Y=d+672|0;ja=+lc(+(+g[Y>>2]))*6.0;h[I+224>>3]=ja;U=d+676|0;ga=+lc(+(+g[U>>2]))*6.0;h[I+232>>3]=ga;N=d+628|0;c[I+52>>2]=c[N>>2];ia=~~(+(c[N>>2]|0)-ja+.5);if((ia|0)<0){ka=0}else{ka=(ia|0)>69?69:ia}c[I+60>>2]=ka;ka=~~(+(c[N>>2]|0)+ga+.5);if((ka|0)<0){la=0}else{la=(ka|0)>69?69:ka}c[I+56>>2]=la;la=d+19388|0;c[la>>2]=~~(ja+.5);h[I+384>>3]=+ad(+(+(c[d+640>>2]|0)/6.0));h[I+272>>3]=+ad(2.3333332538604736)*.8500000238418579;ka=(ca(c[H>>2]|0,c[d+12>>2]|0)|0)+1|0;N=MLb(ka*100|0)|0;ia=I+136|0;c[ia>>2]=N;if((N|0)==0){K=-1;i=e;return K|0}N=MLb(20)|0;r=I+604|0;c[r>>2]=N;if((N|0)==0){K=-1;i=e;return K|0}N=d+648|0;q=d+632|0;aa=d+636|0;ea=(ka|0)>0;_=c[L>>2]|0;da=0;do{if((_|0)==1){ma=+g[N>>2]+0.0+-12.0}else{ma=12.0}h[I+280+(da<<3)>>3]=+ad(+(ma/6.0))*.8500000238418579;h[I+336+(da<<3)>>3]=+ad(+((+(c[q>>2]|0)+-12.0)/6.0))*.8500000238418579;h[I+360+(da<<3)>>3]=+ad(+((+(c[aa>>2]|0)+-12.0)/6.0))*.8500000238418579;if(ea){na=c[ia>>2]|0;oa=0;do{pa=(oa*5|0)+da|0;g[na+(pa*20|0)>>2]=.5;g[na+(pa*20|0)+4>>2]=2.0;g[na+(pa*20|0)+8>>2]=1.0;g[na+(pa*20|0)+12>>2]=.5;g[na+(pa*20|0)+16>>2]=0.0;oa=oa+1|0;}while((oa|0)<(ka|0))}g[I+484+(da*40|0)>>2]=.0625;g[I+484+(da*40|0)+4>>2]=.25;g[I+484+(da*40|0)+8>>2]=1.0;g[I+484+(da*40|0)+12>>2]=.5;g[I+484+(da*40|0)+16>>2]=0.0;g[I+484+(da*40|0)+20>>2]=.0625;g[I+484+(da*40|0)+24>>2]=.25;g[I+484+(da*40|0)+28>>2]=1.0;g[I+484+(da*40|0)+32>>2]=.5;g[I+484+(da*40|0)+36>>2]=0.0;da=da+1|0;}while((da|0)<3);da=c[r>>2]|0;r=c[ia>>2]|0;c[da>>2]=c[r>>2];c[da+4>>2]=c[r+4>>2];c[da+8>>2]=c[r+8>>2];c[da+12>>2]=c[r+12>>2];c[da+16>>2]=c[r+16>>2];r=c[J>>2]|0;da=d+736|0;ia=c[da>>2]|0;ka=d+732|0;a:do{if((ia|0)==0){P=66}else{ea=c[ka>>2]|0;if((ea|0)!=0){qa=ea;P=67;break}ea=MLb((lrc(ia|0)|0)+1|0)|0;if((ea|0)==0){break}prc(ea|0,c[da>>2]|0)|0;c[ka>>2]=1;N=a[ea]|0;if(N<<24>>24==0){ra=24}else{_=ea;oa=N;N=1;do{N=(oa<<24>>24==47)+N|0;c[ka>>2]=N;_=_+1|0;oa=a[_]|0;}while(!(oa<<24>>24==0));ra=N*24|0}oa=MLb(ra)|0;_=d+728|0;c[_>>2]=oa;if((oa|0)==0){break}b:do{if((c[ka>>2]|0)>0){oa=d;na=0;pa=ea;c:while(1){sa=mc(pa|0,2625584)|0;a[pa+sa|0]=0;ta=c[_>>2]|0;c[k>>2]=0;c[l>>2]=0;ua=ta+(na*24|0)+20|0;c[ua>>2]=0;va=ta+(na*24|0)+16|0;g[va>>2]=1.0;wa=ta+(na*24|0)|0;xa=ta+(na*24|0)+4|0;ya=Bd(pa|0,2621328,(Z=i,i=i+32|0,c[Z>>2]=wa,c[Z+8>>2]=xa,c[Z+16>>2]=ta+(na*24|0)+12,c[Z+24>>2]=k,Z)|0)|0;i=Z;do{if((ya|0)>2){c[ta+(na*24|0)+8>>2]=1}else{za=Bd(pa|0,2618432,(Z=i,i=i+32|0,c[Z>>2]=wa,c[Z+8>>2]=xa,c[Z+16>>2]=va,c[Z+24>>2]=k,Z)|0)|0;i=Z;if((za|0)>2){c[ta+(na*24|0)+8>>2]=0;break}za=Bd(pa|0,2611712,(Z=i,i=i+24|0,c[Z>>2]=wa,c[Z+8>>2]=xa,c[Z+16>>2]=k,Z)|0)|0;i=Z;if((za|0)<=1){P=55;break c}c[ta+(na*24|0)+8>>2]=0}}while(0);ta=pa+(c[k>>2]|0)|0;d:do{if((a[ta]|0)!=0){xa=MLb(860)|0;c[ua>>2]=xa;if((xa|0)==0){break a}nrc(xa|0,oa|0,860)|0;c[(c[ua>>2]|0)+852>>2]=122;xa=ta;while(1){Aa=Fd(xa|0,2605840,l|0)|0;if((Aa|0)==0){break d}wa=_b(Aa|0,61)|0;if((wa|0)==0){Ba=0}else{a[wa]=0;Ba=wa+1|0}if((JLb(c[ua>>2]|0,Aa,Ba)|0)==0){xa=0}else{P=63;break c}}}}while(0);ua=na+1|0;if((ua|0)<(c[ka>>2]|0)){na=ua;pa=pa+(sa+1)|0}else{break b}}if((P|0)==55){ILb(d,0,2608680,(Z=i,i=i+8|0,c[Z>>2]=pa,Z)|0);i=Z;break a}else if((P|0)==63){ILb(d,0,2603568,(Z=i,i=i+16|0,c[Z>>2]=Aa,c[Z+8>>2]=Ba,Z)|0);i=Z;break a}}}while(0);NLb(ea);P=66}}while(0);if((P|0)==66){qa=c[ka>>2]|0;P=67}e:do{if((P|0)==67){do{if((qa|0)>0){ka=d+728|0;Ba=0;while(1){if((Ba|0)>=(qa|0)){P=74;break}Aa=c[ka>>2]|0;Ca=c[Aa+(Ba*24|0)>>2]|0;Da=c[Aa+(Ba*24|0)+4>>2]|0;Ea=+g[Aa+(Ba*24|0)+16>>2];if((Ca|0)<0|(Ca|0)>(Da|0)){P=71;break}if((c[Aa+(Ba*24|0)+8>>2]|0)!=0|Ea>0.0){Ba=Ba+1|0}else{P=73;break}}if((P|0)==71){ILb(d,0,2624392,(Z=i,i=i+16|0,c[Z>>2]=Ca,c[Z+8>>2]=Da,Z)|0);i=Z;break e}else if((P|0)==73){ILb(d,0,2622888,(Z=i,i=i+8|0,h[Z>>3]=Ea,Z)|0);i=Z;break e}else if((P|0)==74){Ba=qa+1|0;pa=r+616|0;c[pa>>2]=Ba;Aa=MLb(Ba*24|0)|0;Ba=r+620|0;c[Ba>>2]=Aa;if((Aa|0)==0){break e}nrc(Aa+24|0,c[ka>>2]|0,((c[pa>>2]|0)*24|0)-24|0)|0;Aa=c[Ba>>2]|0;c[Aa>>2]=0;c[Aa+4>>2]=2147483647;c[Aa+8>>2]=0;g[Aa+16>>2]=1.0;Aa=MLb(860)|0;c[(c[Ba>>2]|0)+20>>2]=Aa;Aa=c[(c[Ba>>2]|0)+20>>2]|0;if((Aa|0)==0){break e}nrc(Aa|0,d|0,860)|0;Aa=c[pa>>2]|0;if((Aa|0)>1){Fa=1}else{break}do{pa=c[Ba>>2]|0;l=pa+(Fa*24|0)+20|0;if((c[l>>2]|0)==0){c[l>>2]=c[pa+20>>2]}Fa=Fa+1|0;}while((Fa|0)<(Aa|0))}}}while(0);ea=d+708|0;f:do{if((c[ea>>2]|0)!=0){Aa=d+712|0;Ba=c[Aa>>2]|0;if((Ba|0)==0){Cd(2116880,2634784,861,2649288);return 0}ka=QLb(Ba)|0;if((ka|0)==0){ILb(d,0,2611240,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}do{if((c[O>>2]|0)!=0){Ba=c[Aa>>2]|0;pa=MLb((lrc(Ba|0)|0)+8|0)|0;if((pa|0)==0){K=-1;i=e;return K|0}prc(pa|0,Ba|0)|0;Ba=pa+(lrc(pa|0)|0)|0;l=Ba|0;y=1952607534;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=Ba+4|0;y=6645106;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=I+260|0;c[l>>2]=Qc(pa|0,2564e3)|0;NLb(pa);if((c[l>>2]|0)!=0){break}ILb(d,0,2546064,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);if((krc(ka,2528408,9)|0)!=0){ILb(d,0,2513384,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}Aa=_b(ka|0,10)|0;if((Aa|0)==0){K=-1;i=e;return K|0}a[Aa]=0;l=Aa+1|0;Aa=Bd(ka|0,2499784,(Z=i,i=i+16|0,c[Z>>2]=t,c[Z+8>>2]=u,Z)|0)|0;i=Z;if((Aa|0)!=2){ILb(d,0,2487072,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}if((c[O>>2]|0)!=0){c[I+444>>2]=c[t>>2];c[I+448>>2]=c[u>>2]}ma=+(c[d+28>>2]|0)*+(c[d+32>>2]|0)/+(ca(c[u>>2]|0,c[t>>2]|0)|0);ja=+T(+ma,+.699999988079071);Aa=Db(ka|0,2475688)|0;do{if((Aa|0)!=0){pa=Bd(Aa|0,2466616,(Z=i,i=i+16|0,c[Z>>2]=v,c[Z+8>>2]=w,Z)|0)|0;i=Z;if((pa|0)!=2){break}pa=c[v>>2]|0;Ba=c[d+792>>2]|0;do{if((pa|0)==(Ba|0)){k=c[w>>2]|0;ra=c[d+796>>2]|0;if((k|0)!=(ra|0)){Ga=ra;Ha=k;break}k=Db(ka|0,2428752)|0;do{if((k|0)!=0){ra=Bd(k|0,2418136,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;da=c[t>>2]|0;if(!((ra|0)!=0&(da|0)!=8)){break}ILb(d,0,2409264,(Z=i,i=i+16|0,c[Z>>2]=8,c[Z+8>>2]=da,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=Db(ka|0,2401528)|0;do{if((k|0)!=0){da=Bd(k|0,2394800,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;if((da|0)==0){break}da=c[d+528>>2]|0;ra=(da|0)<0?0:da;da=c[t>>2]|0;if((ra|0)==(da|0)){break}ILb(d,0,2387600,(Z=i,i=i+16|0,c[Z>>2]=ra,c[Z+8>>2]=da,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=Db(ka|0,2380768)|0;do{if((k|0)!=0){da=Bd(k|0,2374344,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;if((da|0)==0){break}da=c[d+112>>2]|0;ra=c[t>>2]|0;if((da|0)==(ra|0)){break}ILb(d,0,2367024,(Z=i,i=i+16|0,c[Z>>2]=da,c[Z+8>>2]=ra,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=Db(ka|0,2352248)|0;do{if((k|0)!=0){ra=Bd(k|0,2344320,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;if((ra|0)==0){break}ra=c[d+124>>2]|0;da=c[t>>2]|0;if((ra|0)==(da|0)){break}ILb(d,0,2338272,(Z=i,i=i+16|0,c[Z>>2]=ra,c[Z+8>>2]=da,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=Db(ka|0,2332648)|0;do{if((k|0)!=0){da=Bd(k|0,2327128,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;if((da|0)==0){break}da=c[d+108>>2]|0;ra=c[t>>2]|0;if((da|0)==(ra|0)){break}ILb(d,0,2321408,(Z=i,i=i+16|0,c[Z>>2]=da,c[Z+8>>2]=ra,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=Db(ka|0,2316344)|0;do{if((k|0)!=0){ra=Bd(k|0,2311952,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;if((ra|0)==0){break}ra=c[d+128>>2]|0;da=c[t>>2]|0;if((ra|0)==(da|0)){break}ILb(d,0,2307256,(Z=i,i=i+16|0,c[Z>>2]=ra,c[Z+8>>2]=da,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=Db(ka|0,2301288)|0;do{if((k|0)!=0){da=Bd(k|0,2290248,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;if((da|0)==0){break}da=c[d+132>>2]|0;ra=c[t>>2]|0;if((da|0)==(ra|0)){break}ILb(d,0,2284144,(Z=i,i=i+16|0,c[Z>>2]=da,c[Z+8>>2]=ra,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=Db(ka|0,2280424)|0;do{if((k|0)!=0){if((c[d+160>>2]|0)==0){Ia=(c[d+808>>2]|0)!=0?2266960:2263376}else{Ia=(c[d+800>>2]|0)!=0?2276184:2271568}ra=x|0;Bd(k|0,2259536,(Z=i,i=i+8|0,c[Z>>2]=ra,Z)|0)|0;i=Z;if((irc(Ia,ra)|0)==0){break}ILb(d,0,2255184,(Z=i,i=i+16|0,c[Z>>2]=Ia,c[Z+8>>2]=ra,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=Db(ka|0,2250016)|0;do{if((k|0)!=0){ra=k+7|0;da=z|0;nrc(da|0,19392,13)|0;ia=c[d+96>>2]|0;if((ia|0)!=1073741824){gc(da|0,2239832,(Z=i,i=i+8|0,c[Z>>2]=ia,Z)|0)|0;i=Z}ia=lrc(da|0)|0;if((krc(ra,da,ia)|0)==0){break}_=mc(ra|0,2231064)|0;ILb(d,0,2234680,(Z=i,i=i+32|0,c[Z>>2]=ia-1,c[Z+8>>2]=da,c[Z+16>>2]=_,c[Z+24>>2]=ra,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);do{if((Db(ka|0,2227248)|0)!=0){if((c[L>>2]|0)!=2){break}ILb(d,1,2222528,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z}}while(0);do{if((Db(ka|0,2218872)|0)==0){if((c[d+536>>2]|0)!=3){break}ILb(d,1,2215928,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;c[d+28844>>2]=1}}while(0);k=Db(ka|0,2213376)|0;do{if((k|0)==0){P=151}else{ra=Bd(k|0,2211080,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;_=c[t>>2]|0;if(!((ra|0)!=0&(_|0)>-1&(_|0)<3)){P=151;break}c[d+116>>2]=_}}while(0);do{if((P|0)==151){if((c[d+112>>2]|0)==0){break}ILb(d,0,2207576,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);if((c[O>>2]|0)==0){if((c[d+664>>2]|0)!=0){P=155}}else{P=155}do{if((P|0)==155){k=Db(ka|0,2198872)|0;if((k|0)==0){break}_=Bd(k|0,2194944,(Z=i,i=i+8|0,c[Z>>2]=t,Z)|0)|0;i=Z;if((_|0)==0){break}c[d+696>>2]=c[t>>2]}}while(0);do{if((l|0)==0){Ja=-1}else{_=-1;k=l;do{k=_b(k+1|0,59)|0;_=_+1|0;}while((k|0)!=0);if((_|0)!=0){Ja=_;break}ILb(d,0,2192488,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);k=I+264|0;c[k>>2]=Ja;ra=d+44|0;da=c[ra>>2]|0;if((da|0)<(Ja|0)&(da|0)>0){ILb(d,1,2190008,(Z=i,i=i+16|0,c[Z>>2]=da,c[Z+8>>2]=Ja,Z)|0);i=Z;Ka=c[ra>>2]|0;La=c[k>>2]|0}else{Ka=da;La=Ja}if((Ka|0)>(La|0)){ILb(d,0,2187456,(Z=i,i=i+16|0,c[Z>>2]=Ka,c[Z+8>>2]=La,Z)|0);i=Z;K=-1;i=e;return K|0}da=MLb(La*192|0)|0;ra=I+268|0;c[ra>>2]=da;if((da|0)==0){K=-1;i=e;return K|0}mrc(da|0,0,(c[k>>2]|0)*192|0|0)|0;da=c[k>>2]|0;g:do{if((da|0)>0){ia=c[ra>>2]|0;N=0;do{c[ia+(N*192|0)>>2]=0;ga=+ad(1.3333333730697632)*.8500000238418579;h[ia+(N*192|0)+56>>3]=ga;h[ia+(N*192|0)+16>>3]=ga;c[ia+(N*192|0)+32>>2]=(c[X>>2]|0)+10;c[ia+(N*192|0)+64>>2]=0;N=N+1|0;Ma=c[k>>2]|0;}while((N|0)<(Ma|0));if((Ma|0)>0){Na=l;Oa=0.0;Pa=0}else{Qa=0.0;Ra=Ma;break}h:while(1){N=_b(Na|0,59)|0;if((N|0)==0){Sa=0}else{a[N]=0;Sa=N+1|0}N=Bd(Na|0,2184904,(Z=i,i=i+8|0,c[Z>>2]=A,Z)|0)|0;i=Z;Ta=c[A>>2]|0;if((Ta|0)<0){P=175;break}if((Ta|0)>=(c[k>>2]|0)){P=175;break}ia=c[ra>>2]|0;_=ia+(Ta*192|0)|0;na=ia+(Ta*192|0)+84|0;a[na]=0;oa=ia+(Ta*192|0)+28|0;ua=ia+(Ta*192|0)+24|0;ta=ia+(Ta*192|0)+32|0;xa=ia+(Ta*192|0)+68|0;wa=ia+(Ta*192|0)+72|0;va=ia+(Ta*192|0)+76|0;ya=Bd(Na|0,2180600,(Z=i,i=i+96|0,c[Z>>2]=B,c[Z+8>>2]=ia+(Ta*192|0)+176,c[Z+16>>2]=ia+(Ta*192|0)+184,c[Z+24>>2]=C,c[Z+32>>2]=D,c[Z+40>>2]=oa,c[Z+48>>2]=ua,c[Z+56>>2]=ta,c[Z+64>>2]=xa,c[Z+72>>2]=wa,c[Z+80>>2]=va,c[Z+88>>2]=na,Z)|0)|0;i=Z;na=ya+N|0;c[oa>>2]=~~(ja*+(c[oa>>2]|0));c[ua>>2]=~~(ja*+(c[ua>>2]|0));c[ta>>2]=~~(ja*+(c[ta>>2]|0));c[xa>>2]=~~(ma*+(c[xa>>2]|0));c[wa>>2]=~~(ma*+(c[wa>>2]|0));c[va>>2]=~~(ma*+(c[va>>2]|0));va=Db(Na|0,2178416)|0;if((va|0)==0){Ua=na;P=194;break}wa=0;xa=va+4|0;while(1){if((wa|0)>=16){break}va=Bd(xa|0,2175208,(Z=i,i=i+8|0,c[Z>>2]=ia+(Ta*192|0)+104+(wa<<2),Z)|0)|0;i=Z;if((va|0)!=1){break}va=_b(xa+1|0,32)|0;if((va|0)==0){Ua=na;P=194;break h}else{wa=wa+1|0;xa=va}}c[ia+(Ta*192|0)+168>>2]=wa;va=ia+(Ta*192|0)+100|0;b[va>>1]=-1;ta=ia+(Ta*192|0)+98|0;b[ta>>1]=-1;ua=_b(xa|0,119)|0;do{if((ua|0)!=0){oa=Bd(ua|0,2167264,(Z=i,i=i+64|0,c[Z>>2]=ta,c[Z+8>>2]=ia+(Ta*192|0)+86,c[Z+16>>2]=ia+(Ta*192|0)+88,c[Z+24>>2]=va,c[Z+32>>2]=ia+(Ta*192|0)+90,c[Z+40>>2]=ia+(Ta*192|0)+92,c[Z+48>>2]=ia+(Ta*192|0)+94,c[Z+56>>2]=ia+(Ta*192|0)+96,Z)|0)|0;i=Z;if((oa|0)==8){break}else if((oa|0)==3){b[va>>1]=-1;break}else{b[va>>1]=-1;b[ta>>1]=-1;break}}}while(0);ta=a[B]|0;if(!(ta<<24>>24==98)){c[ia+(Ta*192|0)+8>>2]=1}switch(ta<<24>>24|0){case 73:{c[ia+(Ta*192|0)+4>>2]=1;c[_>>2]=2;break};case 105:{c[ia+(Ta*192|0)+4>>2]=2;c[_>>2]=2;break};case 80:{c[ia+(Ta*192|0)+4>>2]=3;c[_>>2]=0;break};case 66:{c[ia+(Ta*192|0)+4>>2]=4;c[_>>2]=1;break};case 98:{c[ia+(Ta*192|0)+4>>2]=5;c[_>>2]=1;break};default:{Ua=-1;P=194;break h}}if((na|0)<13){Ua=na;P=194;break}h[ia+(Ta*192|0)+16>>3]=+ad(+((+g[C>>2]+-12.0)/6.0))*.8500000238418579;ga=Oa+ +g[D>>2];ta=Pa+1|0;va=c[k>>2]|0;if((ta|0)<(va|0)){Na=Sa;Oa=ga;Pa=ta}else{Qa=ga;Ra=va;break g}}if((P|0)==175){ILb(d,0,2182648,(Z=i,i=i+16|0,c[Z>>2]=Ta,c[Z+8>>2]=Pa,Z)|0);i=Z;K=-1;i=e;return K|0}else if((P|0)==194){ILb(d,0,2163704,(Z=i,i=i+16|0,c[Z>>2]=Pa,c[Z+8>>2]=Ua,Z)|0);i=Z;K=-1;i=e;return K|0}}else{Qa=0.0;Ra=da}}while(0);if((c[d+812>>2]|0)==0){da=~~(Qa/+(Ra|0)+.5);c[d+8672>>2]=(da|0)<51?da:51}NLb(ka);if((c[L>>2]|0)!=2){break f}da=c[J>>2]|0;ga=+((c[d+8524>>2]|0)>>>0>>>0)/+((c[d+8528>>2]|0)>>>0>>>0);k=da+264|0;ra=c[k>>2]|0;va=(ra|0)>0;if(va){ta=c[da+268>>2]|0;ua=0;fa=0.0;while(1){xa=ta+(ua*192|0)+176|0;Va=fa+(+((c[xa>>2]|0)>>>0)+ +(c[xa+4>>2]|0)*4294967296.0);xa=ua+1|0;if((xa|0)<(ra|0)){ua=xa;fa=Va}else{Wa=Va;break}}}else{Wa=0.0}fa=ga*Wa*+(c[M>>2]|0)*1.0e3;ua=~~+fa>>>0;ta=(F=+fa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);fa=+g[d+720>>2];Va=fa;Xa=+g[d+724>>2];xa=~~(Va*4.0)|1;Ya=+(ca((c[d+112>>2]|0)!=0?120:80,c[W>>2]|0)|0);if(va){wa=c[da+268>>2]|0;oa=0;N=0;ya=0;while(1){za=c[wa+(oa*192|0)+32>>2]|0;Za=wrc(za,(za|0)<0|0?-1:0,ya,N)|0;za=G;_a=oa+1|0;if((_a|0)<(ra|0)){oa=_a;N=za;ya=Za}else{$a=za;ab=Za;break}}}else{$a=0;ab=0}if(ta>>>0<$a>>>0|ta>>>0==$a>>>0&ua>>>0<ab>>>0){ILb(d,0,2117344,(Z=i,i=i+8|0,c[Z>>2]=~~((+(ab>>>0)+ +($a>>>0)*4294967296.0)*+h[da+16>>3]/(+(ra|0)*1.0e3)),Z)|0);i=Z;K=-1;i=e;return K|0}if(va){bb=Xa*2.0;ya=bb>1.0;N=d+756|0;oa=da+48|0;wa=c[da+268>>2]|0;Za=0;do{i:do{if(ya){za=ra-Za|0;cb=0.0;db=1.0;_a=1;eb=0.0;while(1){if((_a|0)>=(za|0)){fb=0;gb=eb;hb=1.0;ib=cb;break i}jb=_a+Za|0;kb=wa+(jb*192|0)+176|0;lb=ga*(+((c[kb>>2]|0)>>>0)+ +(c[kb+4>>2]|0)*4294967296.0);mb=(c[N>>2]|0)==5?2.0:1.0;nb=.009999999776482582/mb;ob=1.0/mb;if(lb<nb){pb=nb}else{pb=lb>ob?ob:lb}lb=+(c[wa+(jb*192|0)+68>>2]|0)/+(c[oa>>2]|0);ob=db*(1.0-lb*lb);if(ob<1.0e-4){fb=0;gb=eb;hb=1.0;ib=cb;break i}lb=ob*+$(+(ca(_a,-_a|0)|0)/200.0);nb=eb+lb;qb=+h[wa+(jb*192|0)+16>>3];rb=(+(c[wa+(jb*192|0)+28>>2]|0)+.1)*+T(+qb,1.1);sb=qb>1.0?qb:1.0;qb=+R(+(+S(sb)));tb=+(c[wa+(jb*192|0)+32>>2]|0);ub=cb+lb*(tb+(rb+ +(c[wa+(jb*192|0)+24>>2]|0)*(sb==-s?s:qb))-tb)/(pb/(.03999999910593033/mb));jb=_a+1|0;if(+(jb|0)<bb){cb=ub;db=ob;_a=jb;eb=nb}else{fb=0;gb=nb;hb=1.0;ib=ub;break}}}else{fb=0;gb=0.0;hb=1.0;ib=0.0}}while(0);while(1){if(+(fb|0)>bb|(fb|0)>(Za|0)){vb=gb;wb=ib;break}_a=Za-fb|0;za=wa+(_a*192|0)+176|0;eb=ga*(+((c[za>>2]|0)>>>0)+ +(c[za+4>>2]|0)*4294967296.0);db=(c[N>>2]|0)==5?2.0:1.0;cb=.009999999776482582/db;ub=1.0/db;if(eb<cb){xb=cb}else{xb=eb>ub?ub:eb}eb=hb*+$(+(ca(fb,-fb|0)|0)/200.0);ub=gb+eb;cb=+h[wa+(_a*192|0)+16>>3];nb=(+(c[wa+(_a*192|0)+28>>2]|0)+.1)*+T(+cb,1.1);ob=cb>1.0?cb:1.0;cb=+R(+(+S(ob)));mb=+(c[wa+(_a*192|0)+32>>2]|0);tb=ib+eb*(mb+(nb+ +(c[wa+(_a*192|0)+24>>2]|0)*(ob==-s?s:cb))-mb)/(xb/(.03999999910593033/db));db=+(c[wa+(_a*192|0)+68>>2]|0)/+(c[oa>>2]|0);mb=hb*(1.0-db*db);if(mb<1.0e-4){vb=ub;wb=tb;break}else{fb=fb+1|0;gb=ub;hb=mb;ib=tb}}g[wa+(Za*192|0)+80>>2]=wb/vb;Za=Za+1|0;}while((Za|0)<(ra|0))}Za=MLb(ra<<3)|0;wa=Za;if((Za|0)==0){K=-1;i=e;return K|0}oa=(xa|0)>1;do{if(oa){N=MLb(c[k>>2]<<3)|0;if((N|0)==0){K=-1}else{yb=N;break}i=e;return K|0}else{yb=wa}}while(0);ra=c[k>>2]|0;if((ra|0)>0){N=da+268|0;ya=0;ga=1.0;while(1){bb=+UMb(d,(c[N>>2]|0)+(ya*192|0)|0,1.0,ya);va=c[N>>2]|0;Xa=bb<.1?.1:bb;tb=+h[va+(ya*192|0)+16>>3];mb=(+(c[va+(ya*192|0)+28>>2]|0)+.1)*+T(+(tb/Xa),1.1);ub=(tb>1.0?tb:1.0)/(Xa>1.0?Xa:1.0);Xa=+R(+(+S(ub)));tb=ga+(+(c[va+(ya*192|0)+32>>2]|0)+(mb+ +(c[va+(ya*192|0)+24>>2]|0)*(ub==-s?s:Xa)));h[da+280+(c[va+(ya*192|0)>>2]<<3)>>3]=bb;va=ya+1|0;_a=c[k>>2]|0;if((va|0)<(_a|0)){ya=va;ga=tb}else{zb=tb;Ab=_a;break}}}else{zb=1.0;Ab=ra}ga=+(ua>>>0)+ +(ta>>>0)*4294967296.0;tb=ga/zb;bb=tb*1.0e4;Xa=tb*1.0e-7;j:do{if(bb>Xa){ya=da+304|0;N=da+328|0;_a=da+320|0;va=da+40|0;za=da+296|0;ia=da+288|0;na=da+280|0;_=da+268|0;jb=((xa|0)%2|0|0)==1;kb=(xa|0)>0;Bb=(xa|0)/-2|0;Cb=fa==0.0;tb=Va*Va;ub=bb;mb=0.0;Eb=Ab;k:while(1){db=mb+ub;c[ya>>2]=-1;h[N>>3]=1.0;h[_a>>3]=0.0;cb=+T(+Ya,+(1.0- +h[va>>3]))/db;h[za>>3]=cb;h[ia>>3]=cb;h[na>>3]=cb;if((Eb|0)>0){Fb=0;while(1){cb=+UMb(d,(c[_>>2]|0)+(Fb*192|0)|0,db,-1);h[wa+(Fb<<3)>>3]=cb;h[da+280+(c[(c[_>>2]|0)+(Fb*192|0)>>2]<<3)>>3]=cb;Gb=Fb+1|0;Hb=c[k>>2]|0;if((Gb|0)<(Hb|0)){Fb=Gb}else{Ib=Hb;break}}}else{Ib=Eb}while(1){Fb=Ib-1|0;if((Ib|0)<=0){break}Hb=c[_>>2]|0;Gb=wa+(Fb<<3)|0;cb=+h[Gb>>3];Jb=c[J>>2]|0;Kb=c[Hb+(Fb*192|0)>>2]|0;Lb=c[Jb+616>>2]|0;l:do{if((Lb|0)>0){Mb=c[Jb+620>>2]|0;Nb=Lb;while(1){Ob=Nb-1|0;Pb=Mb+(Ob*24|0)|0;if((c[Pb>>2]|0)<=(Fb|0)){if((c[Mb+(Ob*24|0)+4>>2]|0)>=(Fb|0)){Qb=Pb;break l}}if((Ob|0)>0){Nb=Ob}else{Qb=0;break}}}else{Qb=0}}while(0);ob=+h[Jb+280>>3];Lb=Jb+304|0;Nb=c[Lb>>2]|0;nb=+h[Jb+280+(Nb<<3)>>3];Mb=(Kb|0)==2;do{if(Mb){eb=+h[Jb+320>>3];qb=+ad(+((+h[Jb+312>>3]/eb+-12.0)/6.0))*.8500000238418579;sb=+g[Y>>2];rb=+R(+sb);if(!(eb>0.0)){Rb=cb;break}if(sb<0.0){Rb=cb/rb;break}if(eb<1.0){Rb=cb*(1.0-eb)+eb*qb/rb;break}else{Rb=qb/rb;break}}else{if((Kb|0)==1){rb=+g[U>>2];qb=rb>0.0?nb:cb;if((c[Hb+(Fb*192|0)+8>>2]|0)!=0){Rb=qb;break}Rb=qb*+R(+rb);break}else if((Kb|0)==0){if((Nb|0)!=0){Rb=cb;break}Rb=(c[Hb+(Fb*192|0)+28>>2]|0)==0?ob:cb;break}else{Rb=cb;break}}}while(0);m:do{if((Nb|0)==(Kb|0)){do{if(Mb){if(+h[Jb+328>>3]<1.0){break}h[Jb+296>>3]=Rb;Sb=Rb;P=258;break m}}while(0);Ob=Jb+280+(Kb<<3)|0;cb=+h[Ob>>3];ob=+h[Jb+384>>3];nb=cb*ob;rb=cb/ob;if(Rb>nb){Tb=nb;Ub=Ob;P=257;break}if(!(Rb<rb)){Tb=Rb;Ub=Ob;P=257;break}Tb=rb;Ub=Ob;P=257}else{Tb=Rb;Ub=Jb+280+(Kb<<3)|0;P=257}}while(0);if((P|0)==257){P=0;h[Ub>>3]=Tb;if((Kb|0)==1){Vb=Tb}else{Sb=Tb;P=258}}if((P|0)==258){P=0;c[Lb>>2]=Kb;Vb=Sb}do{if(Mb){h[Jb+328>>3]=+h[Jb+320>>3];mrc(Jb+312|0,0,16)|0}else{if((Kb|0)!=0){break}rb=+(c[Hb+(Fb*192|0)+68>>2]|0)/+(c[Jb+48>>2]|0);nb=1.0-rb*rb;rb=+lc(+(Vb/.8500000238418579))*6.0+12.0;Nb=Jb+312|0;h[Nb>>3]=nb*(+h[Nb>>3]+rb);Nb=Jb+320|0;h[Nb>>3]=nb*(+h[Nb>>3]+1.0)}}while(0);do{if((Qb|0)==0){Wb=Vb}else{if((c[Qb+8>>2]|0)==0){Wb=Vb/+g[Qb+16>>2];break}else{Wb=+ad(+((+(c[Qb+12>>2]|0)+-12.0)/6.0))*.8500000238418579;break}}}while(0);h[Gb>>3]=Wb;if(Wb<0.0){P=268;break k}else{Ib=Fb}}do{if(oa){if(!jb){P=274;break k}Jb=c[k>>2]|0;if((Jb|0)<=0){Xb=0.0;Yb=Jb;break}Hb=c[_>>2]|0;Kb=0;while(1){if(kb){Mb=Hb+(Kb*192|0)|0;Lb=Kb+Bb|0;nb=0.0;rb=0.0;Nb=0;while(1){Ob=Lb+Nb|0;ob=+(Ob-Kb|0);if(Cb){Zb=1.0}else{Zb=+$(ob*(-0.0-ob)/tb)}do{if((Ob|0)>-1&(Ob|0)<(Jb|0)){if((c[Mb>>2]|0)!=(c[Hb+(Ob*192|0)>>2]|0)){$b=rb;ac=nb;break}$b=rb+Zb;ac=nb+Zb*+h[wa+(Ob<<3)>>3]}else{$b=rb;ac=nb}}while(0);Ob=Nb+1|0;if((Ob|0)<(xa|0)){nb=ac;rb=$b;Nb=Ob}else{bc=ac;cc=$b;break}}}else{bc=0.0;cc=0.0}h[yb+(Kb<<3)>>3]=bc/cc;Nb=Kb+1|0;if((Nb|0)<(Jb|0)){Kb=Nb}else{dc=Jb;P=284;break}}}else{dc=c[k>>2]|0;P=284}}while(0);do{if((P|0)==284){P=0;if((dc|0)<=0){Xb=0.0;Yb=dc;break}Jb=c[_>>2]|0;rb=0.0;Kb=0;while(1){nb=+VMb(d,c[Jb+(Kb*192|0)>>2]|0,+h[yb+(Kb<<3)>>3]);h[Jb+(Kb*192|0)+56>>3]=nb;if(nb<0.0){P=287;break k}ob=nb<.1?.1:nb;nb=+h[Jb+(Kb*192|0)+16>>3];cb=(+(c[Jb+(Kb*192|0)+28>>2]|0)+.1)*+T(+(nb/ob),1.1);qb=(nb>1.0?nb:1.0)/(ob>1.0?ob:1.0);ob=+R(+(+S(qb)));nb=rb+(+(c[Jb+(Kb*192|0)+32>>2]|0)+(cb+ +(c[Jb+(Kb*192|0)+24>>2]|0)*(qb==-s?s:ob)));Hb=Kb+1|0;if((Hb|0)<(dc|0)){rb=nb;Kb=Hb}else{Xb=nb;Yb=dc;break}}}}while(0);if(Xb>ga){ec=db-ub}else{ec=db}rb=ub*.5;if(rb>Xa){ub=rb;mb=ec;Eb=Yb}else{break j}}if((P|0)==268){Cd(2114448,2634784,2969,2652056);return 0}else if((P|0)==274){Cd(2112712,2634784,2975,2652056);return 0}else if((P|0)==287){Cd(2110744,2634784,3002,2652056);return 0}}}while(0);NLb(Za);if(oa){NLb(yb)}xa=da+8|0;if((c[xa>>2]|0)!=0){wa=c[J>>2]|0;Xa=+ad(+((+(c[q>>2]|0)+-12.0)/6.0))*.8500000238418579;Ya=+ad(+((+(c[aa>>2]|0)+-12.0)/6.0))*.8500000238418579;ta=wa+264|0;ua=MLb((c[ta>>2]<<3)+8|0)|0;if((ua|0)==0){K=-1;i=e;return K|0}ra=ua+8|0;Eb=wa+96|0;_=d+668|0;Cb=ua;bb=ga*.995;Va=0.0;while(1){n:do{if(Va!=0.0){fa=Va/ga;if(fa<.999){fc=fa<=.9?.9:fa}else{fc=.999}h[Cb>>3]=+h[Eb>>3]*+g[_>>2];c[f>>2]=0;while(1){if((WMb(d,ra,f,j,1)|0)==0){break n}Bb=c[f>>2]|0;hc=c[j>>2]|0;kb=((Bb|0)>0)+Bb|0;if((kb|0)>(hc|0)){break}Bb=c[(c[J>>2]|0)+268>>2]|0;jb=0;na=kb;while(1){kb=Bb+(na*192|0)+56|0;fa=+h[kb>>3];if(fa<Xa){ic=Xa}else{ic=fa>Ya?Ya:fa}fa=fc*ic;if(fa<Xa){jc=Xa}else{jc=fa>Ya?Ya:fa}h[kb>>3]=jc;if((jb|0)==0){kc=jc!=ic|0}else{kc=1}kb=na+1|0;if((kb|0)>(hc|0)){break}else{jb=kc;na=kb}}c[f>>2]=hc;if((kc|0)==0){break n}}c[f>>2]=hc}}while(0);h[Cb>>3]=+h[Eb>>3]*(1.0- +g[_>>2]);c[f>>2]=0;while(1){if((WMb(d,ra,f,j,0)|0)==0){nc=1;break}na=c[f>>2]|0;jb=c[j>>2]|0;Bb=((na|0)>0)+na|0;if((Bb|0)>(jb|0)){nc=0;break}na=c[(c[J>>2]|0)+268>>2]|0;kb=0;ia=Bb;while(1){Bb=na+(ia*192|0)+56|0;db=+h[Bb>>3];if(db<Xa){oc=Xa}else{oc=db>Ya?Ya:db}db=oc*1.001;if(db<Xa){pc=Xa}else{pc=db>Ya?Ya:db}h[Bb>>3]=pc;if((kb|0)==0){qc=pc!=oc|0}else{qc=1}Bb=ia+1|0;if((Bb|0)>(jb|0)){break}else{kb=qc;ia=Bb}}if((qc|0)==0){nc=0;break}}ia=c[J>>2]|0;kb=c[ia+264>>2]|0;if((kb|0)>0){jb=c[ia+268>>2]|0;ia=0;db=0.0;while(1){na=(F=+db,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Bb=jb+(ia*192|0)+40|0;c[Bb>>2]=~~+db>>>0;c[Bb+4>>2]=na;fa=+h[jb+(ia*192|0)+56>>3];mb=fa<.1?.1:fa;fa=+h[jb+(ia*192|0)+16>>3];ub=(+(c[jb+(ia*192|0)+28>>2]|0)+.1)*+T(+(fa/mb),1.1);tb=(fa>1.0?fa:1.0)/(mb>1.0?mb:1.0);mb=+R(+(+S(tb)));fa=db+(+(c[jb+(ia*192|0)+32>>2]|0)+(ub+ +(c[jb+(ia*192|0)+24>>2]|0)*(tb==-s?s:mb)));na=ia+1|0;if((na|0)<(kb|0)){ia=na;db=fa}else{rc=fa;break}}}else{rc=0.0}if(!(rc<bb)){break}db=rc+.5;ia=(F=+db,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);fa=Va+.5;kb=(F=+fa,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);if((ia|0)>(kb|0)|(ia|0)==(kb|0)&~~+db>>>0>>>0>~~+fa>>>0>>>0){Va=rc}else{break}}if(!nc){ILb(d,1,2632488,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z}_=c[ta>>2]|0;if((_|0)>0){Cb=c[wa+268>>2]|0;oa=0;do{h[Cb+(oa*192|0)+48>>3]=+h[Eb>>3]- +h[ra+(oa<<3)>>3];oa=oa+1|0;}while((oa|0)<(_|0))}NLb(ua)}_=c[J>>2]|0;oa=c[_+264>>2]|0;if((oa|0)>0){ra=c[_+268>>2]|0;_=0;Va=0.0;while(1){Eb=(F=+Va,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);Cb=ra+(_*192|0)+40|0;c[Cb>>2]=~~+Va>>>0;c[Cb+4>>2]=Eb;bb=+h[ra+(_*192|0)+56>>3];Ya=bb<.1?.1:bb;bb=+h[ra+(_*192|0)+16>>3];Xa=(+(c[ra+(_*192|0)+28>>2]|0)+.1)*+T(+(bb/Ya),1.1);fa=(bb>1.0?bb:1.0)/(Ya>1.0?Ya:1.0);Ya=+R(+(+S(fa)));bb=Va+(+(c[ra+(_*192|0)+32>>2]|0)+(Xa+ +(c[ra+(_*192|0)+24>>2]|0)*(fa==-s?s:Ya)));Eb=_+1|0;if((Eb|0)<(oa|0)){_=Eb;Va=bb}else{sc=bb;break}}}else{sc=0.0}if(!(+R(+(sc/ga+-1.0))>.01)){break f}_=c[k>>2]|0;if((_|0)>0){oa=c[da+268>>2]|0;Va=0.0;ra=0;while(1){bb=Va+ +h[oa+(ra*192|0)+56>>3];ua=ra+1|0;if((ua|0)<(_|0)){Va=bb;ra=ua}else{tc=bb;break}}}else{tc=0.0}Va=+lc(+(tc/+(_|0)/.8500000238418579))*6.0+12.0;ra=sc>ga;if(ra){P=345}else{if((c[xa>>2]|0)==0){P=345}else{uc=_}}if((P|0)==345){ILb(d,1,2109224,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;uc=c[k>>2]|0}bb=sc*+h[da+16>>3]/(+(uc|0)*1.0e3);ILb(d,1,2107592,(Z=i,i=i+24|0,h[Z>>3]=+(c[M>>2]|0),h[Z+8>>3]=bb,h[Z+16>>3]=Va,Z)|0);i=Z;do{if(sc<ga){oa=c[q>>2]|0;if(!(Va<+(oa+2|0))){break}if((oa|0)>0){ILb(d,1,2106312,(Z=i,i=i+8|0,c[Z>>2]=oa,Z)|0);i=Z;break f}else{ILb(d,1,2104800,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;break f}}}while(0);do{if(ra){k=c[aa>>2]|0;if(!(Va>+(k-2|0))){break}if((k|0)<69){ILb(d,1,2644032,(Z=i,i=i+8|0,c[Z>>2]=k,Z)|0);i=Z;break f}else{ILb(d,1,2641144,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;break f}}}while(0);if((c[da+4>>2]|0)!=0){if((c[xa>>2]|0)!=0){break f}}ILb(d,1,2635160,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;break f}else{Ga=c[d+796>>2]|0;Ha=c[w>>2]|0}}while(0);ILb(d,0,2439560,(Z=i,i=i+32|0,c[Z>>2]=Ba,c[Z+8>>2]=Ga,c[Z+16>>2]=pa,c[Z+24>>2]=Ha,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);ILb(d,0,2456776,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);ka=d+700|0;do{if((c[ka>>2]|0)==0){P=375}else{l=d+704|0;Aa=c[l>>2]|0;sa=MLb((lrc(Aa|0)|0)+6|0)|0;if((sa|0)==0){c[I+244>>2]=0;K=-1;i=e;return K|0}prc(sa|0,Aa|0)|0;Aa=sa+(lrc(sa|0)|0)|0;a[Aa]=a[2161640]|0;a[Aa+1|0]=a[2161641]|0;a[Aa+2|0]=a[2161642]|0;a[Aa+3|0]=a[2161643]|0;a[Aa+4|0]=a[2161644]|0;a[Aa+5|0]=a[2161645]|0;c[I+244>>2]=sa;Aa=Qc(sa|0,2159640)|0;sa=I+240|0;c[sa>>2]=Aa;if((Aa|0)==0){ILb(d,0,2611240,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}Aa=RLb(E,1)|0;if((Aa|0)!=0){Id(c[sa>>2]|0,2157664,(Z=i,i=i+8|0,c[Z>>2]=Aa,Z)|0)|0;i=Z}NLb(Aa);if((c[O>>2]|0)==0){break}if((c[ea>>2]|0)!=0){P=375;break}Aa=c[l>>2]|0;sa=MLb((lrc(Aa|0)|0)+13|0)|0;if((sa|0)==0){vc=0}else{prc(sa|0,Aa|0)|0;nrc(sa+(lrc(sa|0)|0)|0,2156016,13)|0;vc=sa}sa=I+252|0;c[sa>>2]=vc;Aa=c[l>>2]|0;l=MLb((lrc(Aa|0)|0)+8|0)|0;if((l|0)==0){c[I+256>>2]=0;K=-1;i=e;return K|0}prc(l|0,Aa|0)|0;Aa=l+(lrc(l|0)|0)|0;ra=Aa|0;y=1952607534;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;ra=Aa+4|0;y=6645106;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;c[I+256>>2]=l;l=c[sa>>2]|0;if((l|0)==0){K=-1;i=e;return K|0}sa=Qc(l|0,2159640)|0;c[I+248>>2]=sa;if((sa|0)!=0){P=375;break}ILb(d,0,2546064,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}}while(0);do{if((P|0)==375){if((c[O>>2]|0)==0){break}if((c[ea>>2]|0)==0){if((c[ka>>2]|0)==0){break}c[I+444>>2]=c[d+28>>2];c[I+448>>2]=c[d+32>>2]}sa=I+444|0;ma=+(c[sa>>2]|0)*.0625;g[m>>2]=ma;l=I+448|0;ja=+(c[l>>2]|0)*.0625;g[m+4>>2]=ja;Va=+(c[d+28>>2]|0)*.0625;g[n>>2]=Va;ga=+(c[d+32>>2]|0)*.0625;g[n+4>>2]=ga;ra=~~+ba(ma);c[o>>2]=ra;Aa=o+4|0;k=~~+ba(ja);c[Aa>>2]=k;_=~~+ba(Va);c[p>>2]=_;oa=p+4|0;ua=~~+ba(ga);c[oa>>2]=ua;if((c[d+160>>2]|0)==0){wc=k;xc=ua}else{Eb=k+1&-2;c[Aa>>2]=Eb;Aa=ua+1&-2;c[oa>>2]=Aa;wc=Eb;xc=Aa}Aa=ca(wc,ra)|0;Eb=I+404|0;c[Eb>>2]=Aa;oa=MLb(Aa<<1)|0;c[I+392>>2]=oa;if((oa|0)==0){K=-1;i=e;return K|0}do{if((c[d+124>>2]|0)!=0){if((c[ea>>2]|0)==0){break}oa=MLb(c[Eb>>2]<<1)|0;c[I+396>>2]=oa;if((oa|0)==0){K=-1}else{break}i=e;return K|0}}while(0);c[I+400>>2]=-1;if((ra|0)==(_|0)&(wc|0)==(xc|0)){break}c[I+408>>2]=1;Eb=MLb(ca(ra<<2,wc)|0)|0;c[I+412>>2]=Eb;if((Eb|0)==0){K=-1;i=e;return K|0}Eb=MLb(ca(_<<2,wc)|0)|0;c[I+416>>2]=Eb;if((Eb|0)==0){K=-1;i=e;return K|0}else{yc=0;zc=ma;Ac=Va}while(1){if(zc>Ac){Eb=c[p+(yc<<2)>>2]|0;oa=((Eb-1+(c[o+(yc<<2)>>2]<<1)|0)/(Eb|0)|0)+1|0;c[I+420+(yc<<2)>>2]=oa;Bc=oa<<2;Cc=Eb}else{c[I+420+(yc<<2)>>2]=3;Bc=12;Cc=c[p+(yc<<2)>>2]|0}Eb=MLb(ca(Bc,Cc)|0)|0;oa=I+428+(yc<<2)|0;c[oa>>2]=Eb;if((Eb|0)==0){K=-1;P=411;break}Eb=MLb(Cc<<2)|0;Aa=Eb;c[I+436+(yc<<2)>>2]=Aa;if((Eb|0)==0){K=-1;P=411;break}ga=zc/Ac;if(ga>1.0){Dc=Ac/zc}else{Dc=1.0}Eb=c[I+420+(yc<<2)>>2]|0;if((Cc|0)>0){ja=(+(Eb|0)+-2.0)*.5;ua=(Eb|0)>0;k=0;bb=ga*.5+-.5;while(1){Cb=~~(bb-ja);c[Aa+(k<<2)>>2]=Cb;if(ua){wa=ca(k,Eb)|0;ta=c[oa>>2]|0;Ya=0.0;Za=0;do{fa=1.0-Dc*+R(+(+(Za+Cb|0)-bb));Xa=fa>0.0?fa:0.0;g[ta+(Za+wa<<2)>>2]=Xa;Ya=Ya+Xa;Za=Za+1|0;}while((Za|0)<(Eb|0));Xa=1.0/Ya;Za=0;do{Cb=ta+(Za+wa<<2)|0;g[Cb>>2]=Xa*+g[Cb>>2];Za=Za+1|0;}while((Za|0)<(Eb|0))}Za=k+1|0;if((Za|0)<(Cc|0)){k=Za;bb=ga+bb}else{break}}}k=yc+1|0;if((k|0)>=2){P=405;break}yc=k;zc=+g[m+(k<<2)>>2];Ac=+g[n+(k<<2)>>2]}if((P|0)==405){c[sa>>2]=ra;c[l>>2]=wc;break}else if((P|0)==411){i=e;return K|0}}}while(0);ea=c[H>>2]|0;if((ea|0)<=0){K=0;i=e;return K|0}ka=I;_=d;k=0;Eb=ea;while(1){ea=I+(k*664|0)|0;oa=d+860+(k<<2)|0;c[(c[oa>>2]|0)+30496>>2]=ea;if((k|0)==0){Ec=Eb}else{nrc(ea|0,ka|0,664)|0;nrc(c[oa>>2]|0,_|0,860)|0;ea=c[oa>>2]|0;c[ea+28832>>2]=c[V>>2];c[ea+19388>>2]=c[la>>2];Ec=c[H>>2]|0}ea=k+1|0;if((ea|0)<(Ec|0)){k=ea;Eb=Ec}else{K=0;break}}i=e;return K|0}}while(0);ILb(d,0,2140224,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;K=-1;i=e;return K|0}function FMb(a){a=a|0;var b=0,d=0,e=0.0,f=0.0,j=0.0;b=i;d=c[a+30496>>2]|0;if((c[d>>2]|0)==0){i=b;return}if((c[a+624>>2]|0)!=2){i=b;return}if(!(+h[d+192>>3]>.9999)){i=b;return}e=+(ca((c[a+112>>2]|0)!=0?120:80,c[a+18568>>2]|0)|0);if((c[a+692>>2]|0)==0){f=0.0}else{f=(1.0- +g[a+716>>2])*13.5}j=+T(+e,+(1.0- +h[d+40>>3]));e=+lc(+(j*+h[d+160>>3]/+h[d+184>>3]/.8500000238418579))*6.0+12.0-f;ILb(a,2,2154256,(a=i,i=i+8|0,h[a>>3]=e,a)|0);i=a;i=b;return}function GMb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+160|0;d=b|0;e=b+80|0;f=c[a+30496>>2]|0;g=f+240|0;h=c[g>>2]|0;if((h|0)!=0){if((sd(Fb(h|0)|0,e|0)|0)==0){j=(c[e+12>>2]&61440|0)!=32768}else{j=0}nb(c[g>>2]|0)|0;g=f+244|0;do{if(!((c[a+1540>>2]|0)<(c[f+264>>2]|0)|j)){e=a+704|0;if((Gc(c[g>>2]|0,c[e>>2]|0)|0)==0){break}h=c[e>>2]|0;ILb(a,0,2152528,(k=i,i=i+16|0,c[k>>2]=c[g>>2],c[k+8>>2]=h,k)|0);i=k}}while(0);NLb(c[g>>2]|0)}g=f+248|0;j=c[g>>2]|0;if((j|0)!=0){if((sd(Fb(j|0)|0,d|0)|0)==0){l=(c[d+12>>2]&61440|0)!=32768}else{l=0}nb(c[g>>2]|0)|0;g=f+252|0;do{if((c[a+1540>>2]|0)<(c[f+264>>2]|0)|l){m=f+256|0}else{d=f+256|0;if((Gc(c[g>>2]|0,c[d>>2]|0)|0)==0){m=d;break}j=c[d>>2]|0;ILb(a,0,2152528,(k=i,i=i+16|0,c[k>>2]=c[g>>2],c[k+8>>2]=j,k)|0);i=k;m=d}}while(0);NLb(c[g>>2]|0);NLb(c[m>>2]|0)}m=c[f+260>>2]|0;if((m|0)!=0){nb(m|0)|0}NLb(c[f+136>>2]|0);NLb(c[f+604>>2]|0);NLb(c[f+268>>2]|0);NLb(c[f+392>>2]|0);NLb(c[f+412>>2]|0);NLb(c[f+428>>2]|0);NLb(c[f+436>>2]|0);NLb(c[f+396>>2]|0);NLb(c[f+416>>2]|0);NLb(c[f+432>>2]|0);NLb(c[f+440>>2]|0);m=f+620|0;g=c[m>>2]|0;if((g|0)==0){n=f;NLb(n);i=b;return}NLb(c[g+20>>2]|0);g=f+616|0;k=c[g>>2]|0;a=c[m>>2]|0;if((k|0)>1){l=1;d=a;j=k;while(1){k=c[d+(l*24|0)+20>>2]|0;do{if((k|0)==(c[d+20>>2]|0)){o=j;p=d}else{h=c[k+852>>2]|0;if((h|0)==0){o=j;p=d;break}qe[h&1023](k);o=c[g>>2]|0;p=c[m>>2]|0}}while(0);k=l+1|0;if((k|0)<(o|0)){l=k;d=p;j=o}else{q=p;break}}}else{q=a}NLb(q);n=f;NLb(n);i=b;return}function HMb(b,e,f){b=b|0;e=e|0;f=f|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0,C=0.0,D=0,E=0,F=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0.0,N=0,O=0,P=0.0,Q=0.0,R=0,S=0.0;i=b+30496|0;j=c[i>>2]|0;k=b+15144|0;l=c[(c[k>>2]|0)+92>>2]|0;m=c[j+616>>2]|0;a:do{if((m|0)>0){n=c[j+620>>2]|0;o=m;while(1){p=o-1|0;q=n+(p*24|0)|0;if((c[q>>2]|0)<=(l|0)){if((c[n+(p*24|0)+4>>2]|0)>=(l|0)){break}}if((p|0)>0){o=p}else{r=0;s=0;break a}}if((q|0)==0){r=0;s=0;break}o=c[j+624>>2]|0;t=c[n+(p*24|0)+20>>2]|0;if((o|0)!=0){if((t|0)==(c[o+20>>2]|0)){r=q;s=1;break}}XLb(b,t)|0;r=q;s=1}else{r=0;s=0}}while(0);c[j+624>>2]=r;do{if((c[b+708>>2]|0)==0){u=0}else{q=c[(c[k>>2]|0)+92>>2]|0;if(!((q|0)>-1)){Cd(2150168,2634784,1405,2649264)}if((q|0)>=(c[j+264>>2]|0)){Cd(2150168,2634784,1405,2649264)}p=c[i>>2]|0;l=c[p+268>>2]|0;m=l+(q*192|0)|0;c[p+64>>2]=m;if((c[b+3240>>2]|0)!=1){u=m;break}if((c[b+536>>2]|0)!=3){u=m;break}p=l+(q*192|0)+84|0;c[b+3296>>2]=(a[p]|0)==115;q=a[p]|0;if(q<<24>>24==115){v=1}else{v=q<<24>>24==116|0}c[b+28840>>2]=v;u=m}}while(0);do{if((c[j+8>>2]|0)==0){w=b+3240|0}else{v=b+15148|0;m=b+18564|0;mrc(c[(c[v>>2]|0)+8488>>2]|0,0,c[m>>2]<<2|0)|0;mrc(c[(c[v>>2]|0)+8492>>2]|0,0,c[m>>2]<<2|0)|0;mrc(c[(c[v>>2]|0)+8496>>2]|0,0,c[m>>2]<<2|0)|0;v=b+3240|0;c[j+480>>2]=j+484+((c[v>>2]|0)*40|0);q=(c[k>>2]|0)+64|0;x=+((c[q>>2]|0)>>>0)+ +(c[q+4>>2]|0)*4294967296.0;y=+((c[b+8524>>2]|0)>>>0>>>0);q=c[b+8528>>2]|0;z=+(q>>>0>>>0);h[j+120>>3]=x*+h[j+128>>3]*y/z;p=c[i>>2]|0;l=c[(c[b+860>>2]|0)+30496>>2]|0;t=l+104|0;o=Crc(c[t>>2]|0,c[t+4>>2]|0,q,0)|0;A=+(o>>>0)+ +(G|0)*4294967296.0;o=p+112|0;h[o>>3]=A;q=c[b+1548>>2]|0;if((q|0)>1){t=(p-l|0)/664|0;l=p+96|0;B=1;C=A;while(1){D=c[b+860+(((B+t|0)%(q|0)|0)<<2)>>2]|0;E=c[D+30496>>2]|0;F=+h[E+464>>3];if((c[D+1440>>2]|0)==0){H=C}else{I=+g[E+452>>2];J=C-(F>I?F:I);I=J>0.0?J:0.0;h[o>>3]=I;J=+h[E+120>>3]+I;I=+h[l>>3];F=J<I?J:I;h[o>>3]=F;H=F}E=B+1|0;if((E|0)<(q|0)){B=E;C=H}else{K=H;L=l;break}}}else{K=A;L=p+96|0}C=+h[L>>3];h[o>>3]=(K<C?K:C)- +(f|0);l=b+40|0;B=96192;while(1){q=c[B>>2]|0;if((q|0)==0){break}if((q|0)==(c[l>>2]|0)){break}else{B=B+52|0}}l=(c[b+132>>2]|0)==0?c[B+36>>2]|0:4;if((c[b+8372>>2]|0)>100){h[j+456>>3]=1.0e9;w=v;break}if((c[b+1540>>2]|0)==0){A=+(ca(c[m>>2]|0,c[b+18560>>2]|0)|0);C=+(c[B+4>>2]|0)*.005813953488372093;h[j+456>>3]=(A>C?A:C)*3072.0/+(l|0);w=v;break}else{h[j+456>>3]=x*y/z*3072.0*+(c[B+4>>2]|0)/+(l|0);w=v;break}}}while(0);if((c[w>>2]|0)!=1){c[j+608>>2]=d[(c[k>>2]|0)+130|0]|0}do{if((c[j>>2]|0)==0){if((c[j+4>>2]|0)!=0){K=+IMb(b);h[u+56>>3]=K;M=+lc(+(K/.8500000238418579))*6.0+12.0;break}k=c[w>>2]|0;do{if((k|0)==1){if((c[(c[b+15148>>2]|0)+116>>2]|0)==0){N=44;break}O=((c[j+52>>2]|0)+(c[j+56>>2]|0)|0)/2|0}else{N=44}}while(0);if((N|0)==44){O=c[j+52+(k<<2)>>2]|0}z=+(O|0);if(!s){M=z;break}if((c[r+8>>2]|0)==0){M=z- +lc(+(+g[r+16>>2]))*6.0;break}else{M=z+ +((c[r+12>>2]|0)-(c[j+52>>2]|0)|0);break}}else{M=+lc(+(+IMb(b)/.8500000238418579))*6.0+12.0}}while(0);if((e|0)==0){P=M}else{P=+(e-1|0)}M=P;P=+(c[b+632>>2]|0);z=+(c[b+636>>2]|0);if(M<P){Q=P}else{Q=M>z?z:M}M=Q;e=~~(M+.5);mrc(j+76|0,0,16)|0;if((e|0)<0){R=0}else{R=(e|0)>69?69:e}c[j+68>>2]=R;e=j+72|0;g[e>>2]=M;r=c[b+15148>>2]|0;g[r+136>>2]=M;g[r+132>>2]=M;if((u|0)!=0){c[u+64>>2]=R}M=+g[e>>2];e=c[w>>2]|0;R=c[i>>2]|0;i=R+312|0;Q=+h[i>>3]*.95;h[i>>3]=Q;u=R+320|0;h[u>>3]=+h[u>>3]*.95+1.0;z=M;if((e|0)==2){S=Q+(z+ +h[R+224>>3])}else{S=z+Q}h[i>>3]=S;i=c[w>>2]|0;if((i|0)==1){return}c[j+304>>2]=i;return}function IMb(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,H=0.0,I=0.0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0.0,$=0.0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0.0,ia=0,ja=0,ka=0.0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0.0,ta=0.0,ua=0.0,va=0.0,wa=0.0,xa=0.0,ya=0.0,za=0.0,Aa=0.0,Ba=0.0;d=i;i=i+192|0;e=d|0;f=b+30496|0;j=c[f>>2]|0;k=b+3240|0;l=c[k>>2]|0;m=b+31264|0;n=b+31248|0;o=wrc(c[n>>2]|0,c[n+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;m=b+31256|0;n=wrc(o,G,c[m>>2]|0,c[m+4>>2]|0)|0;m=j+176|0;o=xrc(n<<3|0>>>29,G<<3|n>>>29,c[m>>2]|0,c[m+4>>2]|0)|0;m=G;n=j+4|0;do{if((c[n>>2]|0)!=0){nrc(e|0,c[j+64>>2]|0,192)|0;p=c[e>>2]|0;if((l|0)==(p|0)){break}q=a[564408+p|0]|0;ILb(b,0,2630424,(p=i,i=i+16|0,c[p>>2]=a[564408+l|0]|0,c[p+8>>2]=q,p)|0);i=p}}while(0);if((l|0)==1){p=c[b+15312>>2]|0;q=c[p+16>>2]|0;r=q-1|0;t=r>>>0<2>>>0;u=c[b+15316>>2]|0;v=c[u+16>>2]|0;w=v-1|0;x=c[b+15144>>2]|0;y=c[x+4>>2]|0;z=y-(c[p+4>>2]|0)|0;A=(z|0)>-1?z:-z|0;z=y-(c[u+4>>2]|0)|0;y=(z|0)>-1?z:-z|0;B=+g[p+132>>2];C=+g[u+132>>2];if((q|0)==4){D=B- +h[j+232>>3]*.5}else{D=B}if((v|0)==4){E=C- +h[j+232>>3]*.5}else{E=C}do{if((w|r)>>>0>1>>>0){if(t|w>>>0<2>>>0){H=t?E:D;break}else{H=(+(y|0)*D+ +(A|0)*E)/+(y+A|0);break}}else{H=(D+E)*.5+ +h[j+224>>3]}}while(0);E=+h[j+232>>3];if((c[x+116>>2]|0)==0){I=H+E}else{I=H+E*.5}E=I;x=c[j+8>>2]|0;do{if((c[n>>2]|0)==0){J=x;K=20}else{if((x|0)==0){J=0;K=20;break}I=+ad(+((E+-12.0)/6.0))*.8500000238418579;H=I<.1?.1:I;I=+h[e+16>>3];D=(+(c[e+28>>2]|0)+.1)*+T(+(I/H),1.1);C=(I>1.0?I:1.0)/(H>1.0?H:1.0);H=+R(+(+S(C)));I=+(c[e+32>>2]|0)+(D+ +(c[e+24>>2]|0)*(C==-s?s:H));h[j+464>>3]=I;L=I;K=22}}while(0);do{if((K|0)==20){x=c[j+604>>2]|0;I=+ad(+((E+-12.0)/6.0))*.8500000238418579;H=(+g[x+4>>2]*+(c[(c[b+15236+((c[b+15156>>2]|0)-1<<2)>>2]|0)+7112>>2]|0)+ +g[x+16>>2])/(I*+g[x+8>>2]);I=H;h[j+464>>3]=I;if((J|0)!=0){L=I;K=22;break}g[(c[f>>2]|0)+452>>2]=H}}while(0);if((K|0)==22){H=+h[j+456>>3];I=L<H?L:H;h[j+464>>3]=I;g[(c[f>>2]|0)+452>>2]=I;c[j+148>>2]=AUb(b)|0}g[j+92>>2]=E;M=+ad(+((E+-12.0)/6.0))*.8500000238418579;i=d;return+M}J=j+24|0;E=+h[J>>3];I=+h[j+32>>3]*2.0*E;do{if((c[n>>2]|0)==0){x=AUb(b)|0;A=j+148|0;c[A>>2]=x;y=j+200|0;H=+h[y>>3]*.5;h[y>>3]=H;t=j+208|0;L=+h[t>>3]*.5;h[t>>3]=L;w=b+15144|0;r=c[w>>2]|0;C=+g[r+56>>2];D=(c[b+756>>2]|0)==5?2.0:1.0;B=.009999999776482582/D;N=1.0/D;if(C<B){O=B}else{O=C>N?N:C}C=+(x|0)/(O/(.03999999910593033/D))+H;h[y>>3]=C;H=L+1.0;h[t>>3]=H;c[e+28>>2]=x;g[e+80>>2]=C/H;c[e+24>>2]=0;c[e+72>>2]=c[j+48>>2];c[e+68>>2]=0;c[e+76>>2]=0;h[e+16>>3]=1.0;c[e>>2]=l;x=r+48|0;t=c[x+4>>2]|0;y=e+176|0;c[y>>2]=c[x>>2];c[y+4>>2]=t;t=b+624|0;do{if((c[t>>2]|0)==1){P=1.0;U=+UMb(b,e,+h[j+216>>3],c[r+92>>2]|0)}else{H=+UMb(b,e,+h[j+184>>3]/+h[j+160>>3],c[r+92>>2]|0);if((c[j+12>>2]|0)!=0){P=1.0;U=H;break}if((c[A>>2]|0)==0){P=1.0;U=H;break}y=(c[b+1540>>2]|0)+1-(c[b+1548>>2]|0)|0;C=+(y|0)/+h[j+16>>3];if((c[b+776>>2]|0)!=0&(y|0)>0){y=(c[w>>2]|0)+40|0;x=b+15336|0;v=xrc(c[y>>2]|0,c[y+4>>2]|0,c[x>>2]|0,c[x+4>>2]|0)|0;V=(+(v>>>0)+ +(G|0)*4294967296.0)*+((c[b+792>>2]|0)>>>0>>>0)/+((c[b+796>>2]|0)>>>0>>>0)}else{V=C}C=V*+h[J>>3];if(!(C>0.0)){P=1.0;U=H;break}L=+S(V);D=(+(o>>>0)+ +(m|0)*4294967296.0-C)/(I*(L<1.0?1.0:L))+1.0;if(D<.5){W=.5}else{W=D>2.0?2.0:D}P=W;U=H*W}}while(0);do{if((l|0)==2){if((c[b+96>>2]|0)<=1){K=70;break}if((c[j+304>>2]|0)==2){K=70;break}H=+ad(+((+h[j+312>>3]/+h[j+320>>3]+-12.0)/6.0))*.8500000238418579;X=H/+R(+(+g[b+672>>2]))}else{K=70}}while(0);do{if((K|0)==70){w=c[b+1540>>2]|0;A=(c[t>>2]|0)==1;if((w|0)<=0){if(!A){X=U;break}if(!(+h[j+40>>3]!=1.0)){X=U;break}H=+ad(+((+g[b+648>>2]+0.0+-12.0)/6.0))*.8500000238418579;X=H/+R(+(+g[b+672>>2]));break}if(A){X=U;break}H=+h[j+280+(l<<3)>>3];D=+h[j+384>>3];L=H/D;C=H*D;do{if(P>1.1&(w|0)>3){Y=D*C;Z=L}else{if(!(P<.9)){Y=C;Z=L;break}Y=C;Z=L/D}}while(0);D=U;if(D<Z){_=Z}else{_=D>Y?Y:D}X=_}}while(0);g[j+92>>2]=+lc(+(X/.8500000238418579))*6.0+12.0;$=+VMb(b,l,X)}else{D=+h[j+336+(l<<3)>>3];L=+h[j+360+(l<<3)>>3];t=(c[j+8>>2]|0)==0;do{if(t){w=c[b+1540>>2]|0;A=c[b+1548>>2]|0;if((w|0)<(A|0)){C=+(o>>>0)+ +(m|0)*4294967296.0+E*+(w|0)/+h[j+16>>3];aa=(F=+C,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);ca=~~+C>>>0;da=A;break}else{C=+(o>>>0)+ +(m|0)*4294967296.0+E*+(A-1|0)/+h[j+16>>3];aa=(F=+C,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);ca=~~+C>>>0;da=A;break}}else{A=c[b+1548>>2]|0;if((A|0)<=1){aa=m;ca=o;da=A;break}w=((c[f>>2]|0)-(c[(c[b+860>>2]|0)+30496>>2]|0)|0)/664|0;r=1;v=m;x=o;while(1){y=c[b+860+(((r+w|0)%(A|0)|0)<<2)>>2]|0;q=c[y+30496>>2]|0;C=+h[q+464>>3];if((c[y+1440>>2]|0)==0){ea=v;fa=x}else{H=+g[q+452>>2];N=C>H?C:H;q=wrc(~~+N>>>0,(F=+N,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0),x,v)|0;ea=G;fa=q}q=r+1|0;if((q|0)<(A|0)){r=q;v=ea;x=fa}else{aa=ea;ca=fa;da=A;break}}}}while(0);A=c[j+264>>2]|0;x=c[b+1540>>2]|0;if((A|0)>(x|0)){v=(c[j+268>>2]|0)+((A-1|0)*192|0)+40|0;r=e+40|0;w=c[r>>2]|0;q=c[r+4>>2]|0;N=+S(+(A|0)*(1.0-(+(w>>>0)+ +(q>>>0)*4294967296.0)/(+((c[v>>2]|0)>>>0)+ +((c[v+4>>2]|0)>>>0)*4294967296.0)));ga=I*(N>.5?N*.5:.25);ia=q;ja=w}else{w=e+40|0;ga=I;ia=c[w+4>>2]|0;ja=c[w>>2]|0}w=xrc(ca,aa,ja,ia)|0;N=+h[e+56>>3];H=(ga-(+(w>>>0)+ +(G|0)*4294967296.0))/ga;if(H<.5){ka=.5}else{ka=H>2.0?2.0:H}H=N/ka;do{if(+(x+1-da|0)<+h[j+16>>3]){la=H}else{C=+h[j+168>>3];if(!(C>0.0)){la=H;break}B=+(x|0)/+(A|0)*100.0;if(B<0.0){ma=0.0}else{ma=B>1.0?1.0:B}la=H*+T(+((+(o>>>0)+ +(m|0)*4294967296.0)/C),+ma)}}while(0);g[j+92>>2]=+lc(+(la/.8500000238418579))*6.0+12.0;if(t){na=la}else{H=la;C=H<.1?.1:H;B=+(c[e+28>>2]|0)+.1;oa=+h[e+16>>3];pa=B*+T(+(oa/C),1.1);qa=+(c[e+24>>2]|0);ra=oa>1.0?oa:1.0;sa=ra/(C>1.0?C:1.0);C=+R(+(+S(sa)));ta=+(c[e+32>>2]|0);ua=+h[j+112>>3]+ +h[j+120>>3];va=+h[e+48>>3];wa=va/+h[j+96>>3];xa=H*(2.0-wa);H=wa<.05?L:xa>N?xa:N;xa=H<L?H:L;H=va/(wa+1.0);wa=la;va=pa+qa*(sa==-s?s:C);while(1){C=ua-(ta+va);if(C<H){if(!(wa<xa)){K=48}}else{K=48}if((K|0)==48){K=0;if(!(C<0.0)){break}if(!(wa<L)){break}}C=wa*1.05;sa=C;pa=sa<.1?.1:sa;sa=B*+T(+(oa/pa),1.1);ya=ra/(pa>1.0?pa:1.0);pa=+R(+(+S(ya)));wa=C;va=sa+qa*(ya==-s?s:pa)}c[j+148>>2]=AUb(b)|0;na=wa}qa=na;if(qa<D){$=D;break}$=qa>L?L:qa}}while(0);na=$;$=na;h[j+272>>3]=$;h[j+280+(l<<3)>>3]=$;l=(c[n>>2]|0)==0;if(l){K=85}else{if((c[j+8>>2]|0)==0){K=88}else{K=85}}if((K|0)==85){if((c[(c[b+15144>>2]|0)+92>>2]|0)==0){h[j+280>>3]=$*+R(+(+g[b+672>>2]))}if(l){K=90}else{K=88}}do{if((K|0)==88){if((c[j+8>>2]|0)==0){K=90;break}la=$<.1?.1:$;ma=+h[e+16>>3];ka=(+(c[e+28>>2]|0)+.1)*+T(+(ma/la),1.1);ga=(ma>1.0?ma:1.0)/(la>1.0?la:1.0);la=+R(+(+S(ga)));ma=+(c[e+32>>2]|0)+(ka+ +(c[e+24>>2]|0)*(ga==-s?s:la));h[j+464>>3]=ma;za=ma}}while(0);if((K|0)==90){K=c[k>>2]|0;k=c[j+136>>2]|0;$=(+g[k+(K*20|0)+4>>2]*+(c[j+148>>2]|0)+ +g[k+(K*20|0)+16>>2])/(na*+g[k+(K*20|0)+8>>2]);h[j+464>>3]=$;za=$}if((c[j+140>>2]|0)==0){Aa=za}else{za=+h[j+120>>3];h[j+464>>3]=za;Aa=za}if((c[j+8>>2]|0)==0){Ba=Aa}else{za=+h[j+456>>3];$=Aa<za?Aa:za;h[j+464>>3]=$;Ba=$}g[(c[f>>2]|0)+452>>2]=Ba;M=na;i=d;return+M}function JMb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0.0,s=0,t=0,u=0,v=0.0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0.0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0.0,$=0.0,aa=0.0;d=c[a+30496>>2]|0;e=a+18612|0;f=c[e>>2]|0;i=c[a+15148>>2]|0;j=c[i+8488>>2]|0;k=j+(f<<2)|0;c[k>>2]=(c[k>>2]|0)+b;b=d+84|0;l=(c[b>>2]|0)+(c[a+28816>>2]|0)|0;c[b>>2]=l;m=c[a+18560>>2]|0;if((c[a+18608>>2]|0)!=(m-1|0)){n=0;return n|0}o=d+72|0;p=+g[o>>2];q=d+76|0;g[q>>2]=+g[q>>2]+ +(m|0)*p;if((c[d+8>>2]|0)==0){n=0;return n|0}r=+ad(+((p+-12.0)/6.0))*.8500000238418579;m=c[i+8492>>2]|0;s=m+(f<<2)|0;g[s>>2]=p;g[(c[i+8496>>2]|0)+(f<<2)>>2]=r;t=c[d+480>>2]|0;p=+(c[(c[i+8484>>2]|0)+(f<<2)>>2]|0);if(!(p<10.0)){u=t+4|0;v=+g[u>>2];w=t+8|0;x=+g[w>>2];y=v/x;z=r*+(c[k>>2]|0);A=z/p;B=+g[t>>2];C=A>B?A:B;B=y/1.5;A=y*1.5;if(C<B){D=B}else{D=C>A?A:C}A=z-p*D;E=A<0.0;p=+g[t+12>>2];F=t+16|0;z=p*+g[F>>2];g[w>>2]=x*p+1.0;g[u>>2]=v*p+(E?C:D);g[F>>2]=z+(E?0.0:A)}E=c[a+3240>>2]|0;do{if((E|0)==0){if(!(+g[o>>2]<+g[(c[(c[a+15160>>2]|0)+8492>>2]|0)+(f<<2)>>2])){break}A=+(c[(c[i+7188>>2]|0)+(f<<2)>>2]|0);if(A<10.0){break}F=t+44|0;z=+g[F>>2];u=t+48|0;D=+g[u>>2];C=z/D;p=r*+(c[k>>2]|0);v=p/A;x=+g[t+40>>2];B=v>x?v:x;x=C/1.5;v=C*1.5;if(B<x){G=x}else{G=B>v?v:B}v=p-A*G;w=v<0.0;A=+g[t+52>>2];H=t+56|0;p=A*+g[H>>2];g[u>>2]=D*A+1.0;g[F>>2]=z*A+(w?B:G);g[H>>2]=p+(w?0.0:v)}}while(0);t=a+3260|0;i=c[t>>2]|0;do{if((i|0)!=0){if((f&1|0)==0){n=0}else{break}return n|0}}while(0);w=(c[a+3244>>2]|0)<=(ca((c[e>>2]|0)-i|0,c[a+18580>>2]|0)|0);G=+g[s>>2];r=+(c[a+636>>2]|0);v=+g[d+144>>2];if(v!=0.0){p=v+ +g[d+92>>2];I=r<p?r:p}else{I=r}r=+(c[a+640>>2]|0);p=G+r;v=p<I?p:I;p=G-r;r=+(c[a+632>>2]|0);B=p>r?p:r;r=+h[d+112>>3];p=+h[d+464>>3];A=r-p;s=(c[a+12>>2]|0)==0;if(s){J=p}else{J=+h[d+472>>3]}z=J;J=1.0/+(c[a+18564>>2]|0);if(J<.05000000074505806){K=.05000000074505806}else{K=J}if(s){L=0.0}else{s=c[a+4>>2]|0;if((s|0)>0){J=0.0;D=0.0;i=0;while(1){e=c[a+860+(i<<2)>>2]|0;if((e|0)==(a|0)){M=D;N=J}else{H=c[e+30496>>2]|0;M=D+ +h[H+472>>3];N=J+ +g[H+452>>2]}H=i+1|0;if((H|0)<(s|0)){J=N;D=M;i=H}else{O=N;P=M;break}}}else{O=0.0;P=0.0}L=P+(O-P)*(+h[d+472>>3]/p)}do{if((f|0)<((c[a+1456>>2]|0)-1|0)){if((E|0)==1){i=f+1|0;P=+g[(c[(c[a+15160>>2]|0)+8492>>2]|0)+(i<<2)>>2];O=+g[(c[(c[a+15236>>2]|0)+8492>>2]|0)+(i<<2)>>2];M=P>O?P:O;O=B>M?B:M;M=+g[o>>2];P=M>O?M:O;g[o>>2]=P;Q=O;R=P}else{Q=B;R=+g[o>>2]}P=A/+(c[a+4>>2]|0)*+h[d+32>>3];O=L+ +KMb(a,f,R);i=c[a+1452>>2]|0;if((i|0)>(f|0)){S=0.0}else{s=0;H=i;do{s=(c[j+(H<<2)>>2]|0)+s|0;H=H+1|0;}while((H|0)<=(f|0));S=+(s|0)}H=S<z*.05000000074505806;M=H?G:v;N=H?G:I;if((E|0)==2){T=P}else{T=P*.5}H=d+92|0;if((c[d+12>>2]|0)==0){D=+g[H>>2];U=Q>D?Q:D}else{U=Q}a:do{if(R<M){D=T;J=A*.5;x=O;C=R;while(1){y=x;do{if(!(y>D+p)){if(r-y<J){break}if(!(y>p)){V=x;W=C;break a}if(!(C<+g[H>>2])){V=x;W=C;break a}}}while(0);y=C+.5;g[o>>2]=y;X=L+ +KMb(a,f,y);if(y<M){x=X;C=y}else{V=X;W=y;break}}}else{V=O;W=R}}while(0);H=d+140|0;b:do{if(W>U){s=d+96|0;i=d+120|0;O=V;P=W;while(1){if(!(P>+g[m>>2])){if((c[H>>2]|0)==0){Y=O;Z=P;break b}}C=O;if(C>=p*.800000011920929|P>G){if(!(C<(r- +h[s>>3]+ +h[i>>3])*1.100000023841858)){Y=O;Z=P;break b}}C=P+-.5;g[o>>2]=C;x=L+ +KMb(a,f,C);if(C>U){O=x;P=C}else{Y=x;Z=C;break}}}else{Y=V;Z=W}}while(0);H=d+456|0;c:do{if(Z<N){P=+h[d+120>>3];O=Y;C=Z;while(1){x=O;if(!(r-x<K*P)){J=+h[H>>3];if(!(J-x<K*J)){_=O;$=C;break c}}J=C+.5;g[o>>2]=J;x=L+ +KMb(a,f,J);if(J<N){O=x;C=J}else{_=x;$=J;break}}}else{_=Y;$=Z}}while(0);g[d+452>>2]=_-L;if(G>=M|$<=M|w^1){break}N=(G+$)*.5;C=G+1.0;if(N<C){aa=C}else{aa=N>M?M:N}g[o>>2]=aa;g[q>>2]=+g[d+80>>2];c[b>>2]=c[d+88>>2];c[k>>2]=0;c[j+(f-(c[t>>2]|0)<<2)>>2]=0;n=-1;return n|0}else{N=+g[o>>2];C=+KMb(a,f,N);g[d+452>>2]=C;if(!(L+C>r-K*+h[d+120>>3])){break}if(N>=v|w^1){break}g[o>>2]=v;g[q>>2]=+g[d+80>>2];c[b>>2]=c[d+88>>2];c[k>>2]=0;c[j+(f-(c[t>>2]|0)<<2)>>2]=0;n=-1;return n|0}}while(0);g[d+80>>2]=+g[q>>2];c[d+88>>2]=l;n=0;return n|0}function KMb(a,b,d){a=a|0;b=b|0;d=+d;var e=0.0,f=0,h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0,x=0.0,y=0,z=0;e=+ad(+((d+-12.0)/6.0))*.8500000238418579;f=c[a+1452>>2]|0;if((f|0)>(b|0)){h=0.0}else{i=c[(c[a+15148>>2]|0)+8488>>2]|0;j=0;k=f;do{j=(c[i+(k<<2)>>2]|0)+j|0;k=k+1|0;}while((k|0)<=(b|0));h=+(j|0)}j=b+1|0;b=c[a+1456>>2]|0;if((j|0)>=(b|0)){l=h;return+l}k=c[(c[a+30496>>2]|0)+480>>2]|0;i=c[a+15148>>2]|0;f=c[i+8484>>2]|0;d=+g[k+4>>2];m=+g[k+16>>2];n=e*+g[k+8>>2];o=c[a+3240>>2]|0;p=(o|0)==2;q=a+15160|0;a=i+7188|0;r=k+44|0;s=k+48|0;t=k+56|0;k=(o|0)==0;o=i+16|0;u=h;i=j;while(1){j=c[f+(i<<2)>>2]|0;h=(d*+(j|0)+m)/n;do{if(p){v=h}else{w=c[q>>2]|0;x=+g[(c[w+8496>>2]|0)+(i<<2)>>2];if(x>e){v=h+(+g[r>>2]*+(c[(c[a>>2]|0)+(i<<2)>>2]|0)+ +g[t>>2])/(e*+g[s>>2]);break}if(!k){v=h;break}if(!((c[w+16>>2]|0)==(c[o>>2]|0)&x>0.0)){v=h;break}y=c[(c[w+8484>>2]|0)+(i<<2)>>2]|0;if((y|0)<=0){v=h;break}z=y-j|0;if((((z|0)>-1?z:-z|0)|0)>=((j|0)/2|0|0)){v=h;break}v=(h+x*+((ca(c[(c[w+8488>>2]|0)+(i<<2)>>2]|0,j)|0)/(y|0)|0|0)/e)*.5}}while(0);h=u+v;j=i+1|0;if((j|0)<(b|0)){u=h;i=j}else{l=h;break}}return+l}function LMb(a){a=a|0;var b=0,d=0,e=0,f=0;b=~~(+g[(c[a+30496>>2]|0)+72>>2]+.5);d=c[a+632>>2]|0;e=c[a+636>>2]|0;if((b|0)<(d|0)){f=d;return f|0}f=(b|0)>(e|0)?e:b;return f|0}function MMb(a){a=a|0;var b=0.0,d=0.0,e=0,f=0.0,h=0.0,i=0,j=0,k=0;b=+g[(c[a+30496>>2]|0)+72>>2];if((c[a+684>>2]|0)==0){d=b}else{e=c[a+15144>>2]|0;f=+g[(c[((c[(c[a+15148>>2]|0)+116>>2]|0)==0?e+8504|0:e+8500|0)>>2]|0)+(c[a+18616>>2]<<2)>>2];if(b>51.0){h=f*((69.0-b)/18.0)}else{h=f}d=b+h}e=~~(d+.5);i=c[a+632>>2]|0;j=c[a+636>>2]|0;if((e|0)<(i|0)){k=i;return k|0}k=(e|0)>(j|0)?j:e;return k|0}function NMb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0;d=i;e=c[a+30496>>2]|0;if((c[a+708>>2]|0)==0){f=0;i=d;return f|0}j=e+264|0;if((c[j>>2]|0)>(b|0)){f=c[(c[e+268>>2]|0)+(b*192|0)+4>>2]|0;i=d;return f|0}b=c[a+31232>>2]|0;if((b|0)==0){k=a+628|0;c[k>>2]=24;l=24;m=k;n=6}else{k=~~(+h[a+31272>>3]/+(b|0)+1.0);b=a+628|0;c[b>>2]=k;if((k|0)<0){o=0;p=b}else{l=k;m=b;n=6}}if((n|0)==6){o=(l|0)>69?69:l;p=m}c[e+52>>2]=o;q=+ad(+((+(c[p>>2]|0)+-12.0)/6.0))*.8500000238418579;o=~~(+lc(+(q/+R(+(+g[a+672>>2]))/.8500000238418579))*6.0+12.0+.5);if((o|0)<0){r=0}else{r=(o|0)>69?69:o}c[e+60>>2]=r;q=+ad(+((+(c[p>>2]|0)+-12.0)/6.0))*.8500000238418579;r=~~(+lc(+(q*+R(+(+g[a+676>>2]))/.8500000238418579))*6.0+12.0+.5);if((r|0)<0){s=0}else{s=(r|0)>69?69:r}c[e+56>>2]=s;ILb(a,0,2147624,(s=i,i=i+8|0,c[s>>2]=c[j>>2],s)|0);i=s;ILb(a,0,2140800,(s=i,i=i+8|0,c[s>>2]=c[p>>2],s)|0);i=s;if((c[a+116>>2]|0)!=0){ILb(a,0,2137776,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}s=a+4|0;if((c[s>>2]|0)>0){t=0}else{f=0;i=d;return f|0}while(1){p=c[a+860+(t<<2)>>2]|0;j=c[p+30496>>2]|0;c[j>>2]=0;c[j+4>>2]=0;c[p+624>>2]=0;c[p+708>>2]=0;c[p+116>>2]=0;c[p+104>>2]=0;c[p+692>>2]=0;j=p+112|0;if((c[j>>2]|0)>1){c[j>>2]=1}j=t+1|0;if((j|0)<(c[s>>2]|0)){t=j}else{f=0;break}}i=d;return f|0}function OMb(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[d+92>>2]|0;f=c[(c[a+30496>>2]|0)+268>>2]|0;if((c[a+528>>2]|0)<1){return}g=b[f+(e*192|0)+98>>1]|0;if(g<<16>>16>-1){c[d+436>>2]=b[f+(e*192|0)+86>>1]|0;c[d+432>>2]=g<<16>>16;c[d+440>>2]=b[f+(e*192|0)+88>>1]|0;re[c[a+37560>>2]&1023](a,d+400|0)}g=f+(e*192|0)+100|0;h=b[g>>1]|0;if(!(h<<16>>16>-1)){return}c[d+484>>2]=b[f+(e*192|0)+90>>1]|0;c[d+480>>2]=h<<16>>16;c[d+488>>2]=b[f+(e*192|0)+92>>1]|0;h=a+37560|0;re[c[h>>2]&1023](a,d+448|0);c[d+532>>2]=b[f+(e*192|0)+94>>1]|0;c[d+528>>2]=b[g>>1]|0;c[d+536>>2]=b[f+(e*192|0)+96>>1]|0;re[c[h>>2]&1023](a,d+496|0);return}function PMb(d,e,f){d=d|0;e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,t=0,u=0.0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0.0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0.0,ha=0;j=i;i=i+8|0;k=j|0;l=d+30496|0;m=c[l>>2]|0;n=(c[d+30588>>2]|0)+(c[d+30540>>2]|0)|0;c[d+30600>>2]=n;o=(c[d+30520>>2]|0)+(c[d+30524>>2]|0)+(c[d+30516>>2]|0)|0;c[d+30592>>2]=o;p=(c[d+30536>>2]|0)+(c[d+30532>>2]|0)+(c[d+30544>>2]|0)+(c[d+30548>>2]|0)+(c[d+30552>>2]|0)+(c[d+30556>>2]|0)+(c[d+30560>>2]|0)+(c[d+30564>>2]|0)+(c[d+30568>>2]|0)+(c[d+30572>>2]|0)+(c[d+30576>>2]|0)+(c[d+30580>>2]|0)|0;c[d+30596>>2]=p;q=d+18568|0;r=+(c[q>>2]|0);t=m+76|0;u=+g[t>>2]/r;g[t>>2]=u;v=c[d+15148>>2]|0;g[v+132>>2]=u;w=+(c[m+84>>2]|0)/r;g[v+136>>2]=w;g[v+140>>2]=+g[d+648>>2]+u- +g[m+92>>2];a:do{if((c[d+700>>2]|0)!=0){v=d+3240|0;x=c[v>>2]|0;if((x|0)==2){y=(c[(c[d+15144>>2]|0)+4>>2]|0)==0?73:105}else if((x|0)==0){y=80}else{y=(c[(c[d+15144>>2]|0)+116>>2]|0)!=0?66:98}x=(c[d+31184>>2]|0)-(c[d+31180>>2]|0)|0;z=(c[d+33796>>2]|0)-(c[d+33792>>2]|0)|0;do{if((c[d+28844>>2]|0)==0){A=45}else{if((x|0)>0){A=115;break}if((x|0)<0){A=116;break}if((z|0)>0){A=115;break}A=(z>>31&71)+45|0}}while(0);z=m+240|0;x=d+15144|0;B=c[x>>2]|0;C=c[d+1540>>2]|0;D=B+48|0;E=c[D>>2]|0;F=c[D+4>>2]|0;D=B+64|0;H=c[D>>2]|0;I=c[D+4>>2]|0;u=+g[t>>2];D=c[d+30508>>2]|0;J=c[d+30504>>2]|0;K=c[d+30512>>2]|0;L=Id(c[z>>2]|0,2136096,(M=i,i=i+128|0,c[M>>2]=c[B+92>>2],c[M+8>>2]=C,c[M+16>>2]=y&255,c[M+24>>2]=E,c[M+32>>2]=F,c[M+40>>2]=H,c[M+48>>2]=I,h[M+56>>3]=u,h[M+64>>3]=w,c[M+72>>2]=D,c[M+80>>2]=J,c[M+88>>2]=K,c[M+96>>2]=o,c[M+104>>2]=p,c[M+112>>2]=n,c[M+120>>2]=A,M)|0)|0;i=M;b:do{if((L|0)>=0){K=d+708|0;J=m+64|0;if((c[K>>2]|0)==0){N=0}else{N=(c[(c[J>>2]|0)+168>>2]|0)>1}D=d+160|0;I=d+15152|0;H=0;while(1){if(N){O=(c[J>>2]|0)+168|0}else{O=I}if((H|0)>=(c[O>>2]|0)){break}do{if(N){P=c[(c[J>>2]|0)+104+(H<<2)>>2]|0}else{if((c[D>>2]|0)==0){P=c[d+30612+(H<<2)>>2]|0;break}else{F=H<<1;P=(c[d+30612+((F|1)<<2)>>2]|0)+(c[d+30612+(F<<2)>>2]|0)|0;break}}}while(0);F=Id(c[z>>2]|0,2239832,(M=i,i=i+8|0,c[M>>2]=P,M)|0)|0;i=M;if((F|0)<0){break b}else{H=H+1|0}}c:do{if((c[d+528>>2]|0)>0){if((c[d+3628>>2]|0)==0){break}H=c[d+3620>>2]|0;D=c[d+3624>>2]|0;J=Id(c[z>>2]|0,2134240,(M=i,i=i+24|0,c[M>>2]=c[d+3616>>2],c[M+8>>2]=H,c[M+16>>2]=D,M)|0)|0;i=M;if((J|0)<0){break b}do{if((c[d+3676>>2]|0)==0){if((c[d+3724>>2]|0)!=0){break}sb(32,c[z>>2]|0)|0;break c}}while(0);J=c[d+3668>>2]|0;D=c[d+3672>>2]|0;H=c[d+3716>>2]|0;I=c[d+3720>>2]|0;F=Id(c[z>>2]|0,2132352,(M=i,i=i+40|0,c[M>>2]=c[d+3664>>2],c[M+8>>2]=J,c[M+16>>2]=D,c[M+24>>2]=H,c[M+32>>2]=I,M)|0)|0;i=M;if((F|0)<0){break b}}}while(0);ub(2130888,2,1,c[z>>2]|0)|0;if((c[d+692>>2]|0)==0){break a}F=c[x>>2]|0;if((c[F+116>>2]|0)==0){break a}if((c[K>>2]|0)!=0){break a}a[k]=c[v>>2];I=c[q>>2]|0;if((I|0)>0){H=c[F+8500>>2]|0;F=c[m+392>>2]|0;D=0;do{b[F+(D<<1)>>1]=he(~~(+g[H+(D<<2)>>2]*256.0)|0)|0;D=D+1|0;}while((D|0)<(I|0))}I=m+248|0;if((ub(k|0,1,1,c[I>>2]|0)|0)==0){break}D=ub(c[m+392>>2]|0,2,c[q>>2]|0,c[I>>2]|0)|0;if(!(D>>>0<(c[q>>2]|0)>>>0)){break a}}}while(0);ILb(d,0,2129320,(M=i,i=i+1|0,i=i+7&-8,c[M>>2]=0,M)|0);i=M;Q=-1;i=j;return Q|0}}while(0);if((c[m>>2]|0)!=0){k=(c[d+3240>>2]|0)==1;w=+(e|0)*+ad(+((+g[t>>2]+-12.0)/6.0))*.8500000238418579;u=+h[m+152>>3];if(k){r=w/(u*+R(+(+g[d+676>>2])));k=m+160|0;U=r+ +h[k>>3];h[k>>3]=U;V=U}else{k=m+160|0;U=w/u+ +h[k>>3];h[k>>3]=U;V=U}U=+h[m+192>>3];h[m+160>>3]=U*V;k=m+184|0;h[k>>3]=(+h[k>>3]+ +g[(c[d+15144>>2]|0)+56>>2]*+h[m+24>>3])*U}if((c[m+4>>2]|0)!=0){k=c[m+64>>2]|0;U=+ad(+((+(c[k+64>>2]|0)+-12.0)/6.0))*.8500000238418579;V=U<.1?.1:U;U=+h[k+16>>3];u=(+(c[k+28>>2]|0)+.1)*+T(+(U/V),1.1);w=(U>1.0?U:1.0)/(V>1.0?V:1.0);V=+R(+(+S(w)));P=m+168|0;h[P>>3]=+h[P>>3]+(+(c[k+32>>2]|0)+(u+ +(c[k+24>>2]|0)*(w==-s?s:V)))}do{if((c[d+28832>>2]|0)!=0){if((c[d+3240>>2]|0)!=1){break}k=m+612|0;P=(c[k>>2]|0)+e|0;c[k>>2]=P;if((a[(c[d+15144>>2]|0)+129|0]|0)==0){break}N=c[m+604>>2]|0;V=+(c[(c[d+15236+((c[d+15156>>2]|0)-1<<2)>>2]|0)+7112>>2]|0);if(!(V<10.0)){O=(P|0)/(c[m+608>>2]|0)|0;w=+ad(+((+g[t>>2]+-12.0)/6.0))*.8500000238418579;P=N+4|0;u=+g[P>>2];A=N+8|0;U=+g[A>>2];r=u/U;W=+(O|0)*w;w=W/V;X=+g[N>>2];Y=w>X?w:X;X=r/1.5;w=r*1.5;if(Y<X){Z=X}else{Z=Y>w?w:Y}w=W-V*Z;O=w<0.0;V=+g[N+12>>2];n=N+16|0;W=V*+g[n>>2];g[A>>2]=U*V+1.0;g[P>>2]=u*V+(O?Y:Z);g[n>>2]=W+(O?0.0:w)}c[k>>2]=0}}while(0);t=d+8564|0;k=c[t>>2]|0;O=c[l>>2]|0;l=c[(c[d+860>>2]|0)+30496>>2]|0;n=c[d+8568>>2]|0;P=d+8528|0;A=c[P>>2]|0;N=A;p=0;o=Erc(N,p,n,(n|0)<0|0?-1:0)|0;n=G;y=c[O+148>>2]|0;do{if((y|0)>=(c[q>>2]|0)){v=c[d+3240>>2]|0;x=c[l+136>>2]|0;Z=+(y|0);if(Z<10.0){break}w=+ad(+((+g[O+76>>2]+-12.0)/6.0))*.8500000238418579;z=x+(v*20|0)+4|0;W=+g[z>>2];L=x+(v*20|0)+8|0;Y=+g[L>>2];V=W/Y;u=+(e|0)*w;w=u/Z;U=+g[x+(v*20|0)>>2];X=w>U?w:U;U=V/1.5;w=V*1.5;if(X<U){_=U}else{_=X>w?w:X}w=u-Z*_;D=w<0.0;Z=+g[x+(v*20|0)+12>>2];I=x+(v*20|0)+16|0;u=Z*+g[I>>2];g[L>>2]=Y*Z+1.0;g[z>>2]=W*Z+(D?X:_);g[I>>2]=u+(D?0.0:w)}}while(0);if((c[O+8>>2]|0)==0){$=0}else{y=Erc(N,p,e,(e|0)<0|0?-1:0)|0;p=l+104|0;l=xrc(c[p>>2]|0,c[p+4>>2]|0,y,G)|0;y=G;c[p>>2]=l;c[p+4>>2]=y;N=0;d:do{if((y|0)<(N|0)|(y|0)==(N|0)&l>>>0<0>>>0){_=(+(l>>>0)+ +(y|0)*4294967296.0)/+(A>>>0>>>0);w=+g[O+144>>2];do{if(w!=0.0){if(+g[O+72>>2]<w+ +g[O+92>>2]){break}ILb(d,3,2628424,(M=i,i=i+16|0,c[M>>2]=c[d+1540>>2],h[M+8>>3]=_,M)|0);i=M;break d}}while(0);ILb(d,1,2627048,(M=i,i=i+16|0,c[M>>2]=c[d+1540>>2],h[M+8>>3]=_,M)|0);i=M}}while(0);M=c[p>>2]|0;O=c[p+4>>2]|0;A=0;y=(O|0)>(A|0)|(O|0)==(A|0)&M>>>0>0>>>0;A=y?M:0;M=y?O:0;c[p>>2]=A;c[p+4>>2]=M;O=d+136|0;if((c[O>>2]|0)==0){y=Erc(c[d+8524>>2]|0,0,k,(k|0)<0|0?-1:0)|0;k=(c[d+15144>>2]|0)+64|0;l=Erc(y,G,c[k>>2]|0,c[k+4>>2]|0)|0;aa=G;ba=l}else{aa=n;ba=o}l=wrc(ba,aa,A,M)|0;M=G;c[p>>2]=l;c[p+4>>2]=M;if((c[d+680>>2]|0)!=0&(M>>>0>n>>>0|M>>>0==n>>>0&l>>>0>o>>>0)){A=c[P>>2]|0;aa=0;ba=A<<3|0>>>29;k=aa<<3|A>>>29;y=wrc(l,M,~o,~n)|0;N=wrc(y,G,ba,k)|0;y=Frc(N,G,ba,k)|0;k=y;if((c[O>>2]|0)==0){O=6-(c[d+768>>2]|0)|0;ca=(O|0)>(k|0)?O:k}else{ca=k}O=ca<<3;ca=Erc(O,(O|0)<0|0?-1:0,A,aa)|0;aa=xrc(l,M,ca,G)|0;da=k;ea=G;fa=aa}else{aa=M>>>0<n>>>0|M>>>0==n>>>0&l>>>0<o>>>0;da=0;ea=aa?M:n;fa=aa?l:o}c[p>>2]=fa;c[p+4>>2]=ea;$=da}c[f>>2]=$;da=$<<3;$=m+176|0;ea=wrc(da,(da|0)<0|0?-1:0,c[$>>2]|0,c[$+4>>2]|0)|0;c[$>>2]=ea;c[$+4>>2]=G;if((c[d+8536>>2]|0)==0){Q=0;i=j;return Q|0}$=c[d+15144>>2]|0;do{if((c[$+92>>2]|0)==0){h[$+8640>>3]=0.0;ea=c[d+15328>>2]|0;c[m+628>>2]=ea;c[m+632>>2]=c[d+15332>>2];w=+(ea|0)/9.0e4;h[m+640>>3]=w;h[$+8656>>3]=w}else{ea=m+640|0;w=+h[ea>>3];da=$+72|0;p=d+1616|0;fa=xrc(c[da>>2]|0,c[da+4>>2]|0,c[p>>2]|0,c[p+4>>2]|0)|0;u=w+(+(fa>>>0)+ +(G|0)*4294967296.0)*+((c[d+8524>>2]|0)>>>0>>>0)/+((c[P>>2]|0)>>>0>>>0);h[$+8656>>3]=u;fa=m+628|0;w=u- +(c[fa>>2]|0)/9.0e4;if((c[$+124>>2]|0)==0){ga=w- +(c[m+632>>2]|0)/9.0e4}else{h[ea>>3]=u;c[fa>>2]=c[d+15328>>2];c[m+632>>2]=c[d+15332>>2];ga=w}w=+h[m+648>>3];if((c[d+8572>>2]|0)==0){h[$+8640>>3]=w>ga?w:ga;break}else{h[$+8640>>3]=w;break}}}while(0);fa=c[f>>2]|0;if((fa|0)==0){ha=0}else{f=6-(c[d+768>>2]|0)|0;ha=((f|0)>(fa|0)?f:fa)<<3}ga=+h[$+8640>>3]+ +(ha+e|0)/+(c[t>>2]|0);h[m+648>>3]=ga;h[$+8648>>3]=ga;m=$+80|0;h[$+8664>>3]=(+((c[m>>2]|0)>>>0)+ +(c[m+4>>2]|0)*4294967296.0)*+((c[d+8524>>2]|0)>>>0>>>0)/+((c[P>>2]|0)>>>0>>>0)+ +h[$+8656>>3];Q=0;i=j;return Q|0}function QMb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0;b=i;d=c[(c[a+860>>2]|0)+30496>>2]|0;e=c[a+8564>>2]|0;f=c[a+8528>>2]|0;g=0;j=Erc(f,g,e,(e|0)<0|0?-1:0)|0;e=d+656|0;k=c[e>>2]|0;l=c[e+4>>2]|0;e=Frc(j,G,k,l)|0;j=G;m=d+104|0;d=c[m>>2]|0;n=c[m+4>>2]|0;m=c[a+8568>>2]|0;o=Erc(m,(m|0)<0|0?-1:0,f,g)|0;g=G;f=Frc(18e4,0,k,l)|0;l=G;k=0;m=(n|0)<(k|0)|(n|0)==(k|0)&d>>>0<0>>>0;if(m|(n>>>0>g>>>0|n>>>0==g>>>0&d>>>0>o>>>0)){p=+(e>>>0)+ +(j>>>0)*4294967296.0;ILb(a,1,2127872,(k=i,i=i+24|0,c[k>>2]=m?2125968:2123632,h[k+8>>3]=(+(d>>>0)+ +(n|0)*4294967296.0)/p,h[k+16>>3]=(+(o>>>0)+ +(g>>>0)*4294967296.0)/p,k)|0);i=k}k=Erc(f,l,d,n)|0;n=wrc(k,G,e,j)|0;k=e<<1|0>>>31;d=j<<1|e>>>31;m=Frc(n,G,k,d)|0;n=G;c[a+15328>>2]=m;q=Erc(o,g,f,l)|0;l=wrc(q,G,e,j)|0;j=Frc(l,G,k,d)|0;d=xrc(j,G,m,n)|0;c[a+15332>>2]=d;i=b;return}function RMb(a){a=a|0;var b=0,d=0,e=0.0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0.0,G=0,H=0.0,I=0;b=a+30496|0;d=c[b>>2]|0;e=+ad(+((+g[d+72>>2]+-12.0)/6.0))*.8500000238418579;f=a+4|0;i=c[f>>2]|0;do{if((c[a+1540>>2]|0)==0){if((i|0)<=0){j=i;k=5;break}l=d+484|0;m=0;n=i;while(1){o=c[a+860+(m<<2)>>2]|0;if((o|0)==(a|0)){p=n}else{nrc((c[o+30496>>2]|0)+484|0,l|0,120)|0;p=c[f>>2]|0}o=m+1|0;if((o|0)<(p|0)){m=o;n=p}else{q=p;k=4;break}}}else{q=i;k=4}}while(0);do{if((k|0)==4){i=a+4|0;if((q|0)<=0){j=q;k=5;break}p=a+3240|0;f=d+8|0;n=d+464|0;m=d+136|0;l=a+15148|0;o=d;r=0;while(1){s=c[a+860+(r<<2)>>2]|0;t=s+30496|0;if((s|0)!=(a|0)){nrc(c[t>>2]|0,o|0,480)|0}u=c[p>>2]|0;v=c[t>>2]|0;c[v+480>>2]=v+484+(u*40|0);v=c[f>>2]|0;do{if((v|0)==0){k=19}else{if(!(+h[n>>3]!=0.0)){k=19;break}w=c[s+1452>>2]|0;x=c[s+1456>>2]|0;if((w|0)<(x|0)){y=c[(c[l>>2]|0)+8484>>2]|0;z=0;A=w;do{z=(c[y+(A<<2)>>2]|0)+z|0;A=A+1|0;}while((A|0)<(x|0));B=+(z|0)}else{B=0.0}x=(r*5|0)+5+u|0;A=c[m>>2]|0;h[(c[t>>2]|0)+472>>3]=(B*+g[A+(x*20|0)+4>>2]+ +g[A+(x*20|0)+16>>2])/(e*+g[A+(x*20|0)+8>>2])}}while(0);if((k|0)==19){k=0;h[(c[t>>2]|0)+472>>3]=0.0}u=r+1|0;s=c[i>>2]|0;if((u|0)<(s|0)){r=u}else{C=s;D=v;break}}}}while(0);if((k|0)==5){C=j;D=c[d+8>>2]|0}if((D|0)==0){return}D=d+464|0;if(!(+h[D>>3]!=0.0)){return}if((C|0)>0){j=0;e=0.0;do{e=e+ +h[(c[(c[a+860+(j<<2)>>2]|0)+30496>>2]|0)+472>>3];j=j+1|0;}while((j|0)<(C|0));B=+h[(c[b>>2]|0)+464>>3]/e;j=0;do{k=(c[(c[a+860+(j<<2)>>2]|0)+30496>>2]|0)+472|0;h[k>>3]=B*+h[k>>3];j=j+1|0;}while((j|0)<(C|0))}if((c[d+140>>2]|0)!=0){d=(C|0)>0;if(d){E=0}else{return}do{j=c[a+860+(E<<2)>>2]|0;B=1.0/+((c[j+1456>>2]|0)-(c[j+1452>>2]|0)|0);if(B<.05){F=.10000000149011612}else{F=B*2.0}k=(c[j+30496>>2]|0)+472|0;h[k>>3]=F*+h[D>>3]+ +h[k>>3];E=E+1|0;}while((E|0)<(C|0));if(d){G=0;H=0.0}else{return}do{H=H+ +h[(c[(c[a+860+(G<<2)>>2]|0)+30496>>2]|0)+472>>3];G=G+1|0;}while((G|0)<(C|0));F=+h[(c[b>>2]|0)+464>>3]/H;b=0;do{G=(c[(c[a+860+(b<<2)>>2]|0)+30496>>2]|0)+472|0;h[G>>3]=F*+h[G>>3];b=b+1|0;}while((b|0)<(C|0))}if((C|0)>0){I=0}else{return}do{b=c[(c[a+860+(I<<2)>>2]|0)+30496>>2]|0;g[b+452>>2]=+h[b+472>>3];I=I+1|0;}while((I|0)<(C|0));return}function SMb(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0,x=0,y=0.0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0;b=c[a+30496>>2]|0;d=a+4|0;e=c[d>>2]|0;if((e|0)<=0){return}f=a+664|0;h=b+76|0;i=b+84|0;j=a+3240|0;k=b+136|0;b=a+18560|0;l=a+15148|0;m=0;n=e;while(1){e=c[a+860+(m<<2)>>2]|0;o=c[e+30496>>2]|0;do{if((c[f>>2]|0)!=0){p=c[e+1452>>2]|0;q=c[e+1456>>2]|0;if((p|0)>=(q|0)){break}r=c[(c[l>>2]|0)+8484>>2]|0;s=p;t=0;do{t=(c[r+(s<<2)>>2]|0)+t|0;s=s+1|0;}while((s|0)<(q|0));u=+(t|0);s=(m*5|0)+5+(c[j>>2]|0)|0;r=c[k>>2]|0;if(u<10.0){break}v=+(ca(q-p|0,c[b>>2]|0)|0);w=c[e+30512>>2]|0;x=(c[e+30504>>2]|0)+(c[e+30508>>2]|0)|0;y=+ad(+((+g[o+76>>2]/v+-12.0)/6.0))*.8500000238418579;z=r+(s*20|0)+4|0;v=+g[z>>2];A=r+(s*20|0)+8|0;B=+g[A>>2];C=v/B;D=y*+(x+w|0);y=D/u;E=+g[r+(s*20|0)>>2];F=y>E?y:E;E=C/1.5;y=C*1.5;if(F<E){G=E}else{G=F>y?y:F}y=D-u*G;w=y<0.0;u=+g[r+(s*20|0)+12>>2];x=r+(s*20|0)+16|0;D=u*+g[x>>2];g[A>>2]=B*u+1.0;g[z>>2]=v*u+(w?F:G);g[x>>2]=D+(w?0.0:y)}}while(0);if((m|0)==0){H=n}else{g[h>>2]=+g[o+76>>2]+ +g[h>>2];c[i>>2]=(c[i>>2]|0)+(c[o+84>>2]|0);H=c[d>>2]|0}e=m+1|0;if((e|0)<(H|0)){m=e;n=H}else{break}}return}function TMb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0;if((a|0)!=(b|0)){e=a+30496|0;f=b+30496|0;h[(c[e>>2]|0)+312>>3]=+h[(c[f>>2]|0)+312>>3];h[(c[e>>2]|0)+320>>3]=+h[(c[f>>2]|0)+320>>3];c[(c[e>>2]|0)+148>>2]=c[(c[f>>2]|0)+148>>2];h[(c[e>>2]|0)+152>>3]=+h[(c[f>>2]|0)+152>>3];b=(c[e>>2]|0)+280|0;i=(c[f>>2]|0)+280|0;c[b>>2]=c[i>>2];c[b+4>>2]=c[i+4>>2];c[b+8>>2]=c[i+8>>2];c[b+12>>2]=c[i+12>>2];c[b+16>>2]=c[i+16>>2];c[b+20>>2]=c[i+20>>2];c[(c[e>>2]|0)+304>>2]=c[(c[f>>2]|0)+304>>2];h[(c[e>>2]|0)+200>>3]=+h[(c[f>>2]|0)+200>>3];h[(c[e>>2]|0)+208>>3]=+h[(c[f>>2]|0)+208>>3];c[(c[e>>2]|0)+608>>2]=c[(c[f>>2]|0)+608>>2];c[(c[e>>2]|0)+624>>2]=c[(c[f>>2]|0)+624>>2];c[(c[e>>2]|0)+400>>2]=c[(c[f>>2]|0)+400>>2];h[(c[e>>2]|0)+24>>3]=+h[(c[f>>2]|0)+24>>3];h[(c[e>>2]|0)+96>>3]=+h[(c[f>>2]|0)+96>>3];h[(c[e>>2]|0)+120>>3]=+h[(c[f>>2]|0)+120>>3];h[(c[e>>2]|0)+128>>3]=+h[(c[f>>2]|0)+128>>3];c[(c[e>>2]|0)+140>>2]=c[(c[f>>2]|0)+140>>2];h[(c[e>>2]|0)+192>>3]=+h[(c[f>>2]|0)+192>>3];h[(c[e>>2]|0)+216>>3]=+h[(c[f>>2]|0)+216>>3];g[(c[e>>2]|0)+144>>2]=+g[(c[f>>2]|0)+144>>2]}if((a|0)==(d|0)){return}f=c[a+30496>>2]|0;a=c[d+30496>>2]|0;h[a+160>>3]=+h[f+160>>3];h[a+168>>3]=+h[f+168>>3];d=f+176|0;e=c[d+4>>2]|0;i=a+176|0;c[i>>2]=c[d>>2];c[i+4>>2]=e;h[a+184>>3]=+h[f+184>>3];c[a+612>>2]=c[f+612>>2];c[a+628>>2]=c[f+628>>2];c[a+632>>2]=c[f+632>>2];h[a+640>>3]=+h[f+640>>3];h[a+648>>3]=+h[f+648>>3];return}function UMb(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0,i=0,j=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0.0,x=0.0;f=c[a+30496>>2]|0;i=c[f+616>>2]|0;a:do{if((i|0)>0){j=c[f+620>>2]|0;l=i;while(1){m=l-1|0;n=j+(m*24|0)|0;if((c[n>>2]|0)<=(e|0)){if((c[j+(m*24|0)+4>>2]|0)>=(e|0)){o=n;break a}}if((m|0)>0){l=m}else{o=0;break}}}else{o=0}}while(0);if((c[a+692>>2]|0)==0){p=+T(+(+g[b+80>>2]),+(1.0- +h[f+40>>3]))}else{q=(c[a+756>>2]|0)==5?2.0:1.0;e=b+176|0;r=+((c[a+8524>>2]|0)>>>0>>>0)/+((c[a+8528>>2]|0)>>>0>>>0)*(+((c[e>>2]|0)>>>0)+ +(c[e+4>>2]|0)*4294967296.0);s=.009999999776482582/q;t=1.0/q;if(r<s){u=s}else{u=r>t?t:r}p=+T(+(.03999999910593033/q/u),+(1.0- +g[a+716>>2]))}h[k>>3]=p;a=c[k+4>>2]&2146435072;e=2146435072;do{if(a>>>0<e>>>0|a>>>0==e>>>0&(c[k>>2]&0)>>>0<0>>>0){if((c[b+28>>2]|0)==(-(c[b+24>>2]|0)|0)){v=13;break}h[f+152>>3]=p;u=p/d;h[f+272>>3]=u;w=u}else{v=13}}while(0);if((v|0)==13){w=+h[f+280+(c[b>>2]<<3)>>3]}if((o|0)==0){x=w;return+x}if((c[o+8>>2]|0)==0){x=w/+g[o+16>>2];return+x}else{x=+ad(+((+(c[o+12>>2]|0)+-12.0)/6.0))*.8500000238418579;return+x}return 0.0}function VMb(b,d,e){b=b|0;d=d|0;e=+e;var f=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0.0,u=0.0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0,M=0.0,N=0.0,O=0,P=0,Q=0.0,R=0,S=0.0,T=0,U=0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0,_=0,ba=0,ca=0.0,da=0.0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0,ja=0.0,ka=0,la=0.0,ma=0.0,na=0.0,oa=0,pa=0,qa=0,ra=0.0,sa=0,ta=0.0,ua=0.0,va=0.0,wa=0.0,xa=0.0,ya=0.0;f=i;i=i+24|0;j=f|0;k=c[b+30496>>2]|0;l=+h[k+336+(d<<3)>>3];m=+h[k+360+(d<<3)>>3];n=+g[k+144>>2];do{if(n!=0.0){o=+ad(+((n+ +g[k+92>>2]+-12.0)/6.0))*.8500000238418579;if(m<o){p=m;break}p=o}else{p=m}}while(0);do{if((c[k+8>>2]|0)==0){q=e}else{r=c[k+148>>2]|0;if((r|0)<=0){q=e;break}a:do{if((c[b+696>>2]|0)==0){if((d|0)==2){if((c[k+304>>2]|0)==2){s=26}else{t=e}}else if((d|0)==0){s=26}else{t=e}do{if((s|0)==26){m=+h[k+112>>3];n=+h[k+96>>3];if(!(m/n<.5)){t=e;break}o=m*2.0/n;if(o<.5){u=.5}else{u=o>1.0?1.0:o}t=e/u}}while(0);v=c[b+3240>>2]|0;w=c[k+136>>2]|0;o=+g[w+(v*20|0)+4>>2];n=+g[w+(v*20|0)+8>>2];m=+g[w+(v*20|0)+16>>2];x=(o*+(r|0)+m)/(t*n);y=+(c[b+664>>2]|0)>=+((c[b+660>>2]|0)*5|0|0)/+h[k+16>>3]?2.0:1.0;z=(c[k+140>>2]|0)!=0?1.0:2.0;A=+h[k+112>>3];do{if(x>A/y){B=A/(x*y);if(B<.2){C=.2;break}C=B>1.0?1.0:B}else{C=1.0}}while(0);y=t/C;B=x*C;D=+h[k+120>>3];if(B<D/z){E=y*(z*B/D)}else{E=y}F=E<e?e:E;G=v;H=o;I=n;J=m;K=A}else{w=c[b+3240>>2]|0;L=c[k+136>>2]|0;y=+g[L+(w*20|0)+4>>2];D=+g[L+(w*20|0)+8>>2];B=+g[L+(w*20|0)+16>>2];M=y*+(r|0)+B;N=+h[k+112>>3];O=(w|0)==2;P=j|0;Q=+g[b+676>>2];R=j+8|0;S=+g[b+672>>2];T=j+16|0;U=b+15144|0;V=+h[k+128>>3];W=+h[k+96>>3];X=W*.5;Y=W*.8;Z=k+12|0;_=0;ba=0;ca=e;while(1){da=N-M/(ca*D);if(O){ea=ca*S}else{ea=ca}h[P>>3]=ea;h[R>>3]=ea*Q;h[T>>3]=ea/S;b:do{if(da<0.0){fa=da;ga=0.0}else{ha=0.0;ia=0;ja=da;while(1){if(ja>W){fa=ja;ga=ha;break b}ka=c[U>>2]|0;la=+h[ka+9928+(ia<<3)>>3];ma=ha+la;na=ja+la*V;oa=a[ka+8672+ia|0]|0;pa=c[ka+8924+(ia<<2)>>2]|0;if(oa<<24>>24==0){fa=na;ga=ma;break b}do{if((oa-1&255)>>>0<2>>>0){qa=2}else{if(oa<<24>>24==5){qa=1;break}qa=oa<<24>>24==4|0}}while(0);la=na-(+(pa|0)*+g[L+(qa*20|0)+4>>2]+ +g[L+(qa*20|0)+16>>2])/(+h[j+(qa<<3)>>3]*+g[L+(qa*20|0)+8>>2]);if(la<0.0){fa=la;ga=ma;break}else{ha=ma;ia=ia+1|0;ja=la}}}}while(0);da=ga*V*.5;ja=N+da;if(fa<(ja<X?ja:X)){ra=ca*1.01;sa=ba|1}else{ja=N-da;if(ja<Y){ta=Y}else{ta=ja>W?W:ja}if(!((c[Z>>2]|0)!=0&fa>ta)){F=ca;G=w;H=y;I=D;J=B;K=N;break a}ra=ca/1.01;sa=ba|2}ia=_+1|0;if((ia|0)>999|(sa|0)==3){F=ra;G=w;H=y;I=D;J=B;K=N;break}else{_=ia;ba=sa;ca=ra}}}}while(0);ca=+(r|0);N=H*ca+J;B=N/(F*I);D=+h[k+456>>3];if(B>D){ua=F*(B/D)}else{ua=F}D=N/(ua*I);do{if((G|0)==0){if((c[k+140>>2]|0)!=0){va=ua;break}ba=c[k+608>>2]|0;_=c[k+604>>2]|0;N=(ca*+g[_+4>>2]+ +g[_+16>>2])/(+g[_+8>>2]*ua*+g[b+676>>2]);_=c[b+15144>>2]|0;if((ba|0)>0){B=0.0;w=0;while(1){Z=w+1|0;y=B+ +h[_+9928+(Z<<3)>>3];if((Z|0)<(ba|0)){B=y;w=Z}else{wa=y;break}}}else{wa=0.0}B=+(ba|0);y=+h[k+128>>3];W=D+N*(B*N>wa*y?0.0:B);B=+h[k+96>>3];Y=K+y*(wa+ +h[_+9928>>3])-B;if(W<Y){y=W/Y;Y=D/(B*.5);xa=ua*(y>Y?y:Y)}else{xa=ua}Y=e*.5;va=Y>xa?Y:xa}else{va=ua}}while(0);if((c[k+12>>2]|0)!=0){q=va;break}q=va<e?e:va}}while(0);if(l==p){ya=l;i=f;return+ya}if((c[k+4>>2]|0)!=0){va=+aa(l);e=+aa(p)-va;ya=+$(va+e*(1.0/(+$(((+aa(q)-va)/e+-.5)*-4.0)+1.0)));i=f;return+ya}if(q<l){ya=l;i=f;return+ya}ya=q>p?p:q;i=f;return+ya}function WMb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0.0,k=0.0,l=0.0,m=0,n=0.0,o=0,p=0,q=0,r=0,t=0.0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0,C=0,D=0,E=0;g=c[a+30496>>2]|0;i=g+96|0;j=+h[i>>3];k=j*.1;l=j*.9;m=c[d>>2]|0;n=(f|0)!=0?1.0:-1.0;f=c[g+264>>2]|0;if((m|0)>=(f|0)){c[d>>2]=-1;c[e>>2]=-1;o=0;return o|0}p=g+128|0;q=c[g+268>>2]|0;g=c[a+8524>>2]|0;r=c[a+8528>>2]|0;t=+h[b+(m-1<<3)>>3];a=-1;u=-1;v=m;w=j;while(1){m=q+(v*192|0)+184|0;j=+h[q+(v*192|0)+56>>3];x=j<.1?.1:j;j=+h[q+(v*192|0)+16>>3];y=(+(c[q+(v*192|0)+28>>2]|0)+.1)*+T(+(j/x),1.1);z=(j>1.0?j:1.0)/(x>1.0?x:1.0);x=+R(+(+S(z)));j=t+n*((+((c[m>>2]|0)>>>0)+ +(c[m+4>>2]|0)*4294967296.0)*+h[p>>3]*+(g>>>0>>>0)/+(r>>>0>>>0)-(+(c[q+(v*192|0)+32>>2]|0)+(y+ +(c[q+(v*192|0)+24>>2]|0)*(z==-s?s:x))));if(j<0.0){A=0.0}else{A=j>w?w:j}h[b+(v<<3)>>3]=A;if(A<=k|(v|0)==0){if((u|0)>-1){B=a;C=u;break}else{D=u;E=v}}else{D=A>=l&(a|0)>-1?v:u;E=a}m=v+1|0;if((m|0)>=(f|0)){B=E;C=D;break}t=A;a=E;u=D;v=m;w=+h[i>>3]}c[d>>2]=B;c[e>>2]=C;if(!((B|0)>-1)){o=0;return o|0}o=C>>>31^1;return o|0}function XMb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;g=a+4|0;h=c[g>>2]|0;i=h&3;if((i|0)==0){j=h}else{k=h+(-i|0)|0;c[g>>2]=k;h=4-i<<3;c[a+16>>2]=h;c[a+12>>2]=(je(c[k>>2]|0)|0)>>>(h>>>0);j=k}k=f-255|0;h=a+16|0;if((k|0)<0){l=0;m=j;n=c[h>>2]|0}else{i=a+12|0;o=0;p=j;j=c[h>>2]|0;while(1){if((j|0)>8){c[i>>2]=c[i>>2]<<8|255;q=j-8|0;r=p}else{s=8-j|0;c[p>>2]=je(c[i>>2]<<j|255>>>(s>>>0)|0)|0;t=(c[g>>2]|0)+4|0;c[g>>2]=t;c[i>>2]=255;q=32-s|0;r=t}c[h>>2]=q;t=o+255|0;if((t|0)>(k|0)){l=t;m=r;n=q;break}else{o=t;p=r;j=q}}}q=f-l|0;l=a+16|0;if((n|0)>8){f=a+12|0;j=c[f>>2]<<8|q;c[f>>2]=j;u=n-8|0;v=j;w=m}else{j=8-n|0;f=a+12|0;c[m>>2]=je(c[f>>2]<<n|q>>>(j>>>0)|0)|0;n=(c[g>>2]|0)+4|0;c[g>>2]=n;c[f>>2]=q;u=32-j|0;v=q;w=n}c[l>>2]=u;n=e-255|0;if((n|0)<0){x=0;y=u;z=v;A=w}else{q=a+12|0;j=0;f=w;w=u;u=v;while(1){if((w|0)>8){v=u<<8|255;c[q>>2]=v;B=w-8|0;C=v;D=f}else{v=8-w|0;c[f>>2]=je(u<<w|255>>>(v>>>0)|0)|0;m=(c[g>>2]|0)+4|0;c[g>>2]=m;c[q>>2]=255;B=32-v|0;C=255;D=m}c[l>>2]=B;m=j+255|0;if((m|0)>(n|0)){x=m;y=B;z=C;A=D;break}else{j=m;f=D;w=B;u=C}}}C=e-x|0;if((y|0)>8){x=z<<8|C;c[a+12>>2]=x;E=y-8|0;F=x;G=A}else{x=8-y|0;c[A>>2]=je(z<<y|C>>>(x>>>0)|0)|0;y=(c[g>>2]|0)+4|0;c[g>>2]=y;c[a+12>>2]=C;E=32-x|0;F=C;G=y}c[l>>2]=E;y=a+12|0;if((e|0)>0){a=0;C=G;x=E;z=F;while(1){A=d[b+a|0]|0;if((x|0)>8){u=z<<8|A;c[y>>2]=u;H=x-8|0;I=u;J=C}else{u=8-x|0;c[C>>2]=je(z<<x|A>>>(u>>>0)|0)|0;B=(c[g>>2]|0)+4|0;c[g>>2]=B;c[y>>2]=A;H=32-u|0;I=A;J=B}c[l>>2]=H;B=a+1|0;if((B|0)<(e|0)){a=B;C=J;x=H;z=I}else{K=I;L=H;M=J;break}}}else{K=F;L=E;M=G}G=K<<1|1;c[y>>2]=G;K=L-1|0;c[l>>2]=K;do{if((K|0)==0){c[M>>2]=je(G|0)|0;E=(c[g>>2]|0)+4|0;c[g>>2]=E;c[l>>2]=32;N=c[y>>2]|0;O=32;P=0;Q=E}else{E=K&7;if((K|0)>(E|0)){N=G;O=K;P=E;Q=M;break}c[M>>2]=je(G<<K|0)|0;F=(c[g>>2]|0)+4|0;c[g>>2]=F;c[y>>2]=0;R=L+31|0;S=E;T=0;U=F;V=R-S|0;c[l>>2]=V;W=V&31;X=T<<W;Y=je(X|0)|0;Z=U;c[Z>>2]=Y;_=c[l>>2]|0;$=_>>3;aa=4-$|0;ba=c[g>>2]|0;ca=ba+aa|0;c[g>>2]=ca;c[l>>2]=32;return}}while(0);L=N<<P;c[y>>2]=L;R=O;S=P;T=L;U=Q;V=R-S|0;c[l>>2]=V;W=V&31;X=T<<W;Y=je(X|0)|0;Z=U;c[Z>>2]=Y;_=c[l>>2]|0;$=_>>3;aa=4-$|0;ba=c[g>>2]|0;ca=ba+aa|0;c[g>>2]=ca;c[l>>2]=32;return}function YMb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0;e=c[d+36>>2]&255;c[a>>2]=b;b=d+28|0;f=((c[b>>2]|0)+15|0)/16|0;c[a+48>>2]=f;g=d+32|0;h=((c[g>>2]|0)+15|0)/16|0;i=a+52|0;c[i>>2]=h;if(e>>>0>7>>>0){j=3}else{j=e>>>0>3>>>0?2:1}c[a+264>>2]=j;if((c[d+624>>2]|0)==0){k=(c[d+628>>2]|0)==0;c[a+260>>2]=k&1;if(k){l=j;m=7}else{m=6}}else{c[a+260>>2]=0;m=6}a:do{if((m|0)==6){if((j|0)==2){c[a+4>>2]=122;n=122;o=2;break}else if((j|0)==3){l=3;m=7;break}do{if((c[d+524>>2]|0)==0){if((c[d+168>>2]|0)!=0){break}do{if((c[d+152>>2]|0)==0){if((c[d+112>>2]|0)>0){break}if((c[d+160>>2]|0)!=0){break}if((c[d+808>>2]|0)!=0){break}if((c[d+528>>2]|0)>0){break}c[a+4>>2]=66;n=66;o=j;break a}}while(0);c[a+4>>2]=77;n=77;o=j;break a}}while(0);c[a+4>>2]=100;n=100;o=j}}while(0);if((m|0)==7){c[a+4>>2]=244;n=244;o=l}c[a+12>>2]=(n|0)==66;c[a+16>>2]=n>>>0<78>>>0;c[a+20>>2]=0;l=a+24|0;c[l>>2]=0;j=d+40|0;k=a+8|0;c[k>>2]=c[j>>2];do{if((c[j>>2]|0)==9){if(!((n|0)==66|(n|0)==77)){break}c[l>>2]=1;c[k>>2]=11}}while(0);k=d+96|0;if((c[k>>2]|0)==1&n>>>0>100>>>0){c[l>>2]=1}l=d+124|0;if((c[l>>2]|0)==0){p=(c[d+112>>2]|0)!=0|0}else{p=2}c[a+252>>2]=p;n=c[d+88>>2]|0;j=p+1|0;p=(c[l>>2]|0)!=0?4:1;q=c[d+92>>2]|0;r=(p|0)>(q|0)?p:q;q=(j|0)>(r|0)?j:r;r=(n|0)>(q|0);if(((r?n:q)|0)>16){s=16}else{s=r?n:q}q=a+40|0;c[q>>2]=s;n=a+256|0;c[n>>2]=s;c[q>>2]=s-((c[l>>2]|0)==1);if((c[k>>2]|0)==1){c[q>>2]=0;c[n>>2]=0;t=0}else{t=s}s=(ca((c[l>>2]|0)!=0?2:1,t)|0)+1|0;if((c[d+108>>2]|0)==0){u=s}else{t=f-1|0;n=c[k>>2]|0;q=((t|0)<(n|0)?t:n)+(c[d+112>>2]|0)|0;u=(s|0)>(q|0)?s:q}q=4;while(1){if((1<<q|0)>(u|0)){break}else{q=q+1|0}}c[a+28>>2]=q;q=d+112|0;if((c[q>>2]|0)==0){u=d+160|0;s=(c[u>>2]|0)!=0;c[a+32>>2]=s?0:2;if(s){m=37}else{v=u}}else{c[a+32>>2]=0;m=37}if((m|0)==37){u=ca((c[q>>2]<<2)+8|0,(c[l>>2]|0)!=0?2:1)|0;l=4;while(1){if((1<<l|0)>(u|0)){break}else{l=l+1|0}}c[a+36>>2]=l;v=d+160|0}c[a+88>>2]=1;c[a+44>>2]=0;if((c[v>>2]|0)==0){l=(c[d+808>>2]|0)==0;u=a+56|0;c[u>>2]=l&1;if(l){w=u;x=h}else{y=u;m=43}}else{u=a+56|0;c[u>>2]=0;y=u;m=43}if((m|0)==43){u=h+1&-2;c[i>>2]=u;w=y;x=u}c[a+60>>2]=c[v>>2];c[a+64>>2]=1;v=c[d+740>>2]|0;c[a+72>>2]=v;u=c[d+744>>2]|0;c[a+80>>2]=u;y=(f<<4)+(c[d+748>>2]|0)|0;f=c[b>>2]|0;c[a+76>>2]=y-f;b=((x<<4)+(c[d+752>>2]|0)-(c[g>>2]|0)|0)>>>(((c[w>>2]|0)==0|0)>>>0);c[a+84>>2]=b;if((v|u|0)==0&(y|0)==(f|0)){z=(b|0)!=0|0}else{z=1}c[a+68>>2]=z;z=a+92|0;c[z>>2]=0;b=d+56|0;do{if((c[b>>2]|0)>0){f=d+52|0;if((c[f>>2]|0)<=0){break}c[z>>2]=1;c[a+96>>2]=c[b>>2];c[a+100>>2]=c[f>>2]}}while(0);b=d+60|0;z=((c[b>>2]|0)-1|0)>>>0<2>>>0;c[a+104>>2]=z&1;if(z){c[a+108>>2]=(c[b>>2]|0)==2}b=a+112|0;c[b>>2]=0;z=c[d+64>>2]|0;f=z>>>0>5>>>0?5:z;c[a+116>>2]=f;z=c[d+68>>2]|0;if(z>>>0<2>>>0){A=z}else{A=e>>>0>9>>>0|0}c[a+120>>2]=A;z=a+124|0;c[z>>2]=0;y=c[d+72>>2]|0;u=y>>>0<10>>>0?y:2;c[a+128>>2]=u;y=c[d+76>>2]|0;v=y>>>0<16>>>0?y:2;c[a+132>>2]=v;y=c[d+80>>2]|0;if(y>>>0<11>>>0){B=y}else{B=e>>>0>9>>>0?0:2}c[a+136>>2]=B;if((u|0)==2){if((v|0)==2&(B|0)==2){C=1}else{m=57}}else{m=57}if((m|0)==57){c[z>>2]=1;C=0}if(!((f|0)==5&(A|0)==0&C)){c[b>>2]=1}b=d+84|0;do{if(((c[b>>2]|0)-1|0)>>>0<5>>>0){C=(o|0)==1;c[a+140>>2]=C&1;if(!C){break}c[a+144>>2]=c[b>>2];c[a+148>>2]=c[b>>2]}else{c[a+140>>2]=0}}while(0);b=d+792|0;do{if((c[b>>2]|0)==0){c[a+152>>2]=0}else{o=d+796|0;C=(c[o>>2]|0)!=0;c[a+152>>2]=C&1;if(!C){break}c[a+156>>2]=c[b>>2];c[a+160>>2]=c[o>>2]<<1;c[a+164>>2]=(c[d+776>>2]|0)==0}}while(0);c[a+172>>2]=0;c[a+168>>2]=(c[d+48>>2]|0)!=0;c[a+224>>2]=c[d+804>>2];b=(c[k>>2]|0)>1;c[a+228>>2]=b&1;if(!b){return}c[a+232>>2]=1;c[a+236>>2]=0;c[a+240>>2]=0;b=(c[d+552>>2]<<2)-1|0;if((b|0)<1){D=1.0}else{D=+(b|0)}b=~~+lc(+D)+1|0;c[a+248>>2]=b;c[a+244>>2]=b;return}function ZMb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0;e=a+4|0;f=c[e>>2]|0;g=f&3;if((g|0)==0){h=f;i=c[a+16>>2]|0}else{j=f+(-g|0)|0;c[e>>2]=j;f=4-g<<3;c[a+16>>2]=f;c[a+12>>2]=(je(c[j>>2]|0)|0)>>>(f>>>0);h=j;i=f}f=b+4|0;j=c[f>>2]|0;g=a+16|0;if((i|0)>8){k=a+12|0;l=c[k>>2]<<8|j;c[k>>2]=l;m=i-8|0;n=l;o=h}else{l=8-i|0;k=a+12|0;c[h>>2]=je(c[k>>2]<<i|j>>>(l>>>0)|0)|0;i=(c[e>>2]|0)+4|0;c[e>>2]=i;c[k>>2]=j;m=32-l|0;n=j;o=i}c[g>>2]=m;i=a+12|0;a=n<<1|c[b+12>>2];c[i>>2]=a;n=m-1|0;c[g>>2]=n;if((n|0)==0){c[o>>2]=je(a|0)|0;m=(c[e>>2]|0)+4|0;c[e>>2]=m;c[g>>2]=32;p=c[i>>2]|0;q=32;r=m}else{p=a;q=n;r=o}o=p<<1|c[b+16>>2];c[i>>2]=o;p=q-1|0;c[g>>2]=p;if((p|0)==0){c[r>>2]=je(o|0)|0;q=(c[e>>2]|0)+4|0;c[e>>2]=q;c[g>>2]=32;s=c[i>>2]|0;t=32;u=q}else{s=o;t=p;u=r}r=s<<1|c[b+20>>2];c[i>>2]=r;s=t-1|0;c[g>>2]=s;if((s|0)==0){c[u>>2]=je(r|0)|0;t=(c[e>>2]|0)+4|0;c[e>>2]=t;c[g>>2]=32;v=c[i>>2]|0;w=32;x=t}else{v=r;w=s;x=u}u=v<<1|c[b+24>>2];c[i>>2]=u;v=w-1|0;c[g>>2]=v;do{if((v|0)==0){c[x>>2]=je(u|0)|0;s=(c[e>>2]|0)+4|0;c[e>>2]=s;c[g>>2]=32;y=32;z=c[i>>2]|0;A=s;B=16}else{if((v|0)>4){y=v;z=u;A=x;B=16;break}c[x>>2]=je(u<<v|0)|0;s=(c[e>>2]|0)+4|0;c[e>>2]=s;c[i>>2]=0;C=w+27|0;D=0;E=s}}while(0);if((B|0)==16){w=z<<4;c[i>>2]=w;C=y-4|0;D=w;E=A}c[g>>2]=C;A=c[b+8>>2]|0;if((C|0)>8){w=D<<8|A;c[i>>2]=w;F=C-8|0;G=w;H=E}else{w=8-C|0;c[E>>2]=je(D<<C|A>>>(w>>>0)|0)|0;C=(c[e>>2]|0)+4|0;c[e>>2]=C;c[i>>2]=A;F=32-w|0;G=A;H=C}c[g>>2]=F;C=(c[b>>2]|0)+1|0;A=(C|0)>65535;w=A?32:0;D=A?C>>16:C;if((D|0)>255){I=D>>8;J=w|16}else{I=D;J=w}w=(d[16720+I|0]|0)+J>>1;if((F|0)>(w|0)){J=G<<w;c[i>>2]=J;K=F;L=J;M=H}else{c[H>>2]=je(G<<F|0)|0;G=(c[e>>2]|0)+4|0;c[e>>2]=G;c[i>>2]=0;K=F+32|0;L=0;M=G}G=K-w|0;c[g>>2]=G;K=w+1|0;if((G|0)>(K|0)){w=L<<K|C;c[i>>2]=w;N=G-K|0;O=w;P=M}else{w=K-G|0;c[M>>2]=je(C>>>(w>>>0)|L<<G|0)|0;G=(c[e>>2]|0)+4|0;c[e>>2]=G;c[i>>2]=C;N=32-w|0;O=C;P=G}c[g>>2]=N;do{if((c[f>>2]|0)>99){G=b+264|0;C=(c[G>>2]|0)+1|0;w=(C|0)>65535;L=w?32:0;M=w?C>>16:C;if((M|0)>255){Q=M>>8;R=L|16}else{Q=M;R=L}L=(d[16720+Q|0]|0)+R>>1;if((N|0)>(L|0)){M=O<<L;c[i>>2]=M;S=N;T=M;U=P}else{c[P>>2]=je(O<<N|0)|0;M=(c[e>>2]|0)+4|0;c[e>>2]=M;c[i>>2]=0;S=N+32|0;T=0;U=M}M=S-L|0;c[g>>2]=M;w=L+1|0;if((M|0)>(w|0)){L=T<<w|C;c[i>>2]=L;V=M-w|0;W=L;X=U}else{L=w-M|0;c[U>>2]=je(C>>>(L>>>0)|T<<M|0)|0;M=(c[e>>2]|0)+4|0;c[e>>2]=M;c[i>>2]=C;V=32-L|0;W=C;X=M}c[g>>2]=V;do{if((c[G>>2]|0)==3){M=W<<1;c[i>>2]=M;C=V-1|0;c[g>>2]=C;if((C|0)!=0){Y=C;Z=M;B=41;break}c[X>>2]=je(M|0)|0;M=(c[e>>2]|0)+4|0;c[e>>2]=M;c[g>>2]=32;_=32;$=c[i>>2]|0;aa=M;B=42}else{Y=V;Z=W;B=41}}while(0);do{if((B|0)==41){if((Y|0)>0){_=Y;$=Z;aa=X;B=42;break}c[X>>2]=je(Z<<Y|0)|0;G=(c[e>>2]|0)+4|0;c[e>>2]=G;c[i>>2]=0;ba=Y+32|0;ca=0;da=G}}while(0);if((B|0)==42){c[i>>2]=$;ba=_;ca=$;da=aa}c[g>>2]=ba;if((ba|0)>1){G=ca<<1|1;c[i>>2]=G;ea=ba-1|0;fa=G;ga=da}else{G=1-ba|0;c[da>>2]=je(1>>>(G>>>0)|ca<<ba|0)|0;M=(c[e>>2]|0)+4|0;c[e>>2]=M;c[i>>2]=1;ea=32-G|0;fa=1;ga=M}c[g>>2]=ea;if((ea|0)>0){c[i>>2]=fa;ha=ea;ia=fa;ja=ga}else{c[ga>>2]=je(fa<<ea|0)|0;M=(c[e>>2]|0)+4|0;c[e>>2]=M;c[i>>2]=0;ha=ea+32|0;ia=0;ja=M}c[g>>2]=ha;if((ha|0)>1){M=ia<<1|1;c[i>>2]=M;ka=ha-1|0;la=M<<1;ma=ja}else{M=1-ha|0;c[ja>>2]=je(1>>>(M>>>0)|ia<<ha|0)|0;G=(c[e>>2]|0)+4|0;c[e>>2]=G;c[i>>2]=1;ka=32-M|0;la=2;ma=G}c[g>>2]=ka;G=la|c[b+260>>2];c[i>>2]=G;M=ka-1|0;c[g>>2]=M;if((M|0)==0){c[ma>>2]=je(G|0)|0;M=(c[e>>2]|0)+4|0;c[e>>2]=M;c[i>>2]=c[i>>2]<<1;c[g>>2]=31;na=31;oa=M;break}M=G<<1;c[i>>2]=M;G=ka-2|0;c[g>>2]=G;if((G|0)!=0){na=G;oa=ma;break}c[ma>>2]=je(M|0)|0;M=(c[e>>2]|0)+4|0;c[e>>2]=M;c[g>>2]=32;na=32;oa=M}else{na=N;oa=P}}while(0);P=(c[b+28>>2]|0)-3|0;N=(P|0)>65535;ma=N?32:0;ka=N?P>>16:P;if((ka|0)>255){pa=ka>>8;qa=ma|16}else{pa=ka;qa=ma}ma=(d[16720+pa|0]|0)+qa>>1;qa=c[i>>2]|0;if((na|0)>(ma|0)){pa=qa<<ma;c[i>>2]=pa;ra=na;sa=pa;ta=oa}else{c[oa>>2]=je(qa<<na|0)|0;qa=(c[e>>2]|0)+4|0;c[e>>2]=qa;c[i>>2]=0;ra=na+32|0;sa=0;ta=qa}qa=ra-ma|0;c[g>>2]=qa;ra=ma+1|0;if((qa|0)>(ra|0)){ma=sa<<ra|P;c[i>>2]=ma;ua=qa-ra|0;va=ma;wa=ta}else{ma=ra-qa|0;c[ta>>2]=je(P>>>(ma>>>0)|sa<<qa|0)|0;qa=(c[e>>2]|0)+4|0;c[e>>2]=qa;c[i>>2]=P;ua=32-ma|0;va=P;wa=qa}c[g>>2]=ua;qa=b+32|0;P=(c[qa>>2]|0)+1|0;ma=(P|0)>65535;sa=ma?32:0;ta=ma?P>>16:P;if((ta|0)>255){xa=ta>>8;ya=sa|16}else{xa=ta;ya=sa}sa=(d[16720+xa|0]|0)+ya>>1;if((ua|0)>(sa|0)){ya=va<<sa;c[i>>2]=ya;za=ua;Aa=ya;Ba=wa}else{c[wa>>2]=je(va<<ua|0)|0;va=(c[e>>2]|0)+4|0;c[e>>2]=va;c[i>>2]=0;za=ua+32|0;Aa=0;Ba=va}va=za-sa|0;c[g>>2]=va;za=sa+1|0;if((va|0)>(za|0)){sa=Aa<<za|P;c[i>>2]=sa;Ca=va-za|0;Da=sa;Ea=Ba}else{sa=za-va|0;c[Ba>>2]=je(P>>>(sa>>>0)|Aa<<va|0)|0;va=(c[e>>2]|0)+4|0;c[e>>2]=va;c[i>>2]=P;Ca=32-sa|0;Da=P;Ea=va}c[g>>2]=Ca;if((c[qa>>2]|0)==0){qa=(c[b+36>>2]|0)-3|0;va=(qa|0)>65535;P=va?32:0;sa=va?qa>>16:qa;if((sa|0)>255){Fa=sa>>8;Ga=P|16}else{Fa=sa;Ga=P}P=(d[16720+Fa|0]|0)+Ga>>1;if((Ca|0)>(P|0)){Ga=Da<<P;c[i>>2]=Ga;Ha=Ca;Ia=Ga;Ja=Ea}else{c[Ea>>2]=je(Da<<Ca|0)|0;Ga=(c[e>>2]|0)+4|0;c[e>>2]=Ga;c[i>>2]=0;Ha=Ca+32|0;Ia=0;Ja=Ga}Ga=Ha-P|0;c[g>>2]=Ga;Ha=P+1|0;if((Ga|0)>(Ha|0)){P=Ia<<Ha|qa;c[i>>2]=P;Ka=Ga-Ha|0;La=P;Ma=Ja}else{P=Ha-Ga|0;c[Ja>>2]=je(qa>>>(P>>>0)|Ia<<Ga|0)|0;Ga=(c[e>>2]|0)+4|0;c[e>>2]=Ga;c[i>>2]=qa;Ka=32-P|0;La=qa;Ma=Ga}c[g>>2]=Ka;Na=Ka;Oa=La;Pa=Ma}else{Na=Ca;Oa=Da;Pa=Ea}Ea=(c[b+40>>2]|0)+1|0;Da=(Ea|0)>65535;Ca=Da?32:0;Ma=Da?Ea>>16:Ea;if((Ma|0)>255){Qa=Ma>>8;Ra=Ca|16}else{Qa=Ma;Ra=Ca}Ca=(d[16720+Qa|0]|0)+Ra>>1;if((Na|0)>(Ca|0)){Ra=Oa<<Ca;c[i>>2]=Ra;Sa=Na;Ta=Ra;Ua=Pa}else{c[Pa>>2]=je(Oa<<Na|0)|0;Oa=(c[e>>2]|0)+4|0;c[e>>2]=Oa;c[i>>2]=0;Sa=Na+32|0;Ta=0;Ua=Oa}Oa=Sa-Ca|0;c[g>>2]=Oa;Sa=Ca+1|0;if((Oa|0)>(Sa|0)){Ca=Ta<<Sa|Ea;c[i>>2]=Ca;Va=Oa-Sa|0;Wa=Ca;Xa=Ua}else{Ca=Sa-Oa|0;c[Ua>>2]=je(Ea>>>(Ca>>>0)|Ta<<Oa|0)|0;Oa=(c[e>>2]|0)+4|0;c[e>>2]=Oa;c[i>>2]=Ea;Va=32-Ca|0;Wa=Ea;Xa=Oa}c[g>>2]=Va;Oa=Wa<<1|c[b+44>>2];c[i>>2]=Oa;Wa=Va-1|0;c[g>>2]=Wa;if((Wa|0)==0){c[Xa>>2]=je(Oa|0)|0;Oa=(c[e>>2]|0)+4|0;c[e>>2]=Oa;c[g>>2]=32;Ya=32;Za=Oa}else{Ya=Wa;Za=Xa}Xa=c[b+48>>2]|0;Wa=(Xa|0)>65535;Oa=Wa?32:0;Va=Wa?Xa>>16:Xa;if((Va|0)>255){_a=Va>>8;$a=Oa|16}else{_a=Va;$a=Oa}Oa=(d[16720+_a|0]|0)+$a>>1;$a=c[i>>2]|0;if((Ya|0)>(Oa|0)){_a=$a<<Oa;c[i>>2]=_a;ab=Ya;bb=_a;cb=Za}else{c[Za>>2]=je($a<<Ya|0)|0;$a=(c[e>>2]|0)+4|0;c[e>>2]=$a;c[i>>2]=0;ab=Ya+32|0;bb=0;cb=$a}$a=ab-Oa|0;c[g>>2]=$a;ab=Oa+1|0;if(($a|0)>(ab|0)){Oa=bb<<ab|Xa;c[i>>2]=Oa;db=$a-ab|0;eb=Oa;fb=cb}else{Oa=ab-$a|0;c[cb>>2]=je(Xa>>>(Oa>>>0)|bb<<$a|0)|0;$a=(c[e>>2]|0)+4|0;c[e>>2]=$a;c[i>>2]=Xa;db=32-Oa|0;eb=Xa;fb=$a}c[g>>2]=db;$a=b+56|0;Xa=c[b+52>>2]>>((c[$a>>2]|0)==0);Oa=(Xa|0)>65535;bb=Oa?32:0;cb=Oa?Xa>>16:Xa;if((cb|0)>255){gb=cb>>8;hb=bb|16}else{gb=cb;hb=bb}bb=(d[16720+gb|0]|0)+hb>>1;if((db|0)>(bb|0)){hb=eb<<bb;c[i>>2]=hb;ib=db;jb=hb;kb=fb}else{c[fb>>2]=je(eb<<db|0)|0;eb=(c[e>>2]|0)+4|0;c[e>>2]=eb;c[i>>2]=0;ib=db+32|0;jb=0;kb=eb}eb=ib-bb|0;c[g>>2]=eb;ib=bb+1|0;if((eb|0)>(ib|0)){bb=jb<<ib|Xa;c[i>>2]=bb;lb=eb-ib|0;mb=bb;nb=kb}else{bb=ib-eb|0;c[kb>>2]=je(Xa>>>(bb>>>0)|jb<<eb|0)|0;eb=(c[e>>2]|0)+4|0;c[e>>2]=eb;c[i>>2]=Xa;lb=32-bb|0;mb=Xa;nb=eb}c[g>>2]=lb;eb=mb<<1|c[$a>>2];c[i>>2]=eb;mb=lb-1|0;c[g>>2]=mb;if((mb|0)==0){c[nb>>2]=je(eb|0)|0;eb=(c[e>>2]|0)+4|0;c[e>>2]=eb;c[g>>2]=32;ob=32;pb=eb}else{ob=mb;pb=nb}do{if((c[$a>>2]|0)==0){nb=c[i>>2]<<1|c[b+60>>2];c[i>>2]=nb;mb=ob-1|0;c[g>>2]=mb;if((mb|0)!=0){qb=mb;rb=pb;break}c[pb>>2]=je(nb|0)|0;nb=(c[e>>2]|0)+4|0;c[e>>2]=nb;c[g>>2]=32;qb=32;rb=nb}else{qb=ob;rb=pb}}while(0);pb=c[i>>2]<<1|c[b+64>>2];c[i>>2]=pb;ob=qb-1|0;c[g>>2]=ob;if((ob|0)==0){c[rb>>2]=je(pb|0)|0;qb=(c[e>>2]|0)+4|0;c[e>>2]=qb;c[g>>2]=32;sb=c[i>>2]|0;tb=32;ub=qb}else{sb=pb;tb=ob;ub=rb}rb=b+68|0;ob=sb<<1|c[rb>>2];c[i>>2]=ob;sb=tb-1|0;c[g>>2]=sb;if((sb|0)==0){c[ub>>2]=je(ob|0)|0;ob=(c[e>>2]|0)+4|0;c[e>>2]=ob;c[g>>2]=32;vb=32;wb=ob}else{vb=sb;wb=ub}if((c[rb>>2]|0)==0){xb=vb;yb=wb;zb=c[i>>2]|0}else{rb=c[b+264>>2]|0;ub=(rb|0)==1;if(ub){Ab=1}else{Ab=(rb|0)==2|0}rb=ub&1;ub=(c[b+72>>2]>>Ab)+1|0;sb=(ub|0)>65535;ob=sb?32:0;tb=sb?ub>>16:ub;if((tb|0)>255){Bb=tb>>8;Cb=ob|16}else{Bb=tb;Cb=ob}ob=(d[16720+Bb|0]|0)+Cb>>1;Cb=c[i>>2]|0;if((vb|0)>(ob|0)){Bb=Cb<<ob;c[i>>2]=Bb;Db=vb;Eb=Bb;Fb=wb}else{c[wb>>2]=je(Cb<<vb|0)|0;Cb=(c[e>>2]|0)+4|0;c[e>>2]=Cb;c[i>>2]=0;Db=vb+32|0;Eb=0;Fb=Cb}Cb=Db-ob|0;c[g>>2]=Cb;Db=ob+1|0;if((Cb|0)>(Db|0)){ob=Eb<<Db|ub;c[i>>2]=ob;Gb=Cb-Db|0;Hb=Fb;Ib=ob}else{ob=Db-Cb|0;c[Fb>>2]=je(ub>>>(ob>>>0)|Eb<<Cb|0)|0;Cb=(c[e>>2]|0)+4|0;c[e>>2]=Cb;c[i>>2]=ub;Gb=32-ob|0;Hb=Cb;Ib=ub}c[g>>2]=Gb;ub=(c[b+76>>2]>>Ab)+1|0;Ab=(ub|0)>65535;Cb=Ab?32:0;ob=Ab?ub>>16:ub;if((ob|0)>255){Jb=ob>>8;Kb=Cb|16}else{Jb=ob;Kb=Cb}Cb=(d[16720+Jb|0]|0)+Kb>>1;if((Gb|0)>(Cb|0)){Kb=Ib<<Cb;c[i>>2]=Kb;Lb=Gb;Mb=Kb;Nb=Hb}else{c[Hb>>2]=je(Ib<<Gb|0)|0;Ib=(c[e>>2]|0)+4|0;c[e>>2]=Ib;c[i>>2]=0;Lb=Gb+32|0;Mb=0;Nb=Ib}Ib=Lb-Cb|0;c[g>>2]=Ib;Lb=Cb+1|0;if((Ib|0)>(Lb|0)){Cb=Mb<<Lb|ub;c[i>>2]=Cb;Ob=Ib-Lb|0;Pb=Nb;Qb=Cb}else{Cb=Lb-Ib|0;c[Nb>>2]=je(ub>>>(Cb>>>0)|Mb<<Ib|0)|0;Ib=(c[e>>2]|0)+4|0;c[e>>2]=Ib;c[i>>2]=ub;Ob=32-Cb|0;Pb=Ib;Qb=ub}c[g>>2]=Ob;ub=(c[b+80>>2]>>rb)+1|0;Ib=(ub|0)>65535;Cb=Ib?32:0;Mb=Ib?ub>>16:ub;if((Mb|0)>255){Rb=Mb>>8;Sb=Cb|16}else{Rb=Mb;Sb=Cb}Cb=(d[16720+Rb|0]|0)+Sb>>1;if((Ob|0)>(Cb|0)){Sb=Qb<<Cb;c[i>>2]=Sb;Tb=Ob;Ub=Sb;Vb=Pb}else{c[Pb>>2]=je(Qb<<Ob|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=0;Tb=Ob+32|0;Ub=0;Vb=Qb}Qb=Tb-Cb|0;c[g>>2]=Qb;Tb=Cb+1|0;if((Qb|0)>(Tb|0)){Cb=Ub<<Tb|ub;c[i>>2]=Cb;Wb=Qb-Tb|0;Xb=Vb;Yb=Cb}else{Cb=Tb-Qb|0;c[Vb>>2]=je(ub>>>(Cb>>>0)|Ub<<Qb|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=ub;Wb=32-Cb|0;Xb=Qb;Yb=ub}c[g>>2]=Wb;ub=(c[b+84>>2]>>rb)+1|0;rb=(ub|0)>65535;Qb=rb?32:0;Cb=rb?ub>>16:ub;if((Cb|0)>255){Zb=Cb>>8;_b=Qb|16}else{Zb=Cb;_b=Qb}Qb=(d[16720+Zb|0]|0)+_b>>1;if((Wb|0)>(Qb|0)){_b=Yb<<Qb;c[i>>2]=_b;$b=Wb;ac=_b;bc=Xb}else{c[Xb>>2]=je(Yb<<Wb|0)|0;Yb=(c[e>>2]|0)+4|0;c[e>>2]=Yb;c[i>>2]=0;$b=Wb+32|0;ac=0;bc=Yb}Yb=$b-Qb|0;c[g>>2]=Yb;$b=Qb+1|0;if((Yb|0)>($b|0)){Qb=ac<<$b|ub;c[i>>2]=Qb;cc=Yb-$b|0;dc=bc;ec=Qb}else{Qb=$b-Yb|0;c[bc>>2]=je(ub>>>(Qb>>>0)|ac<<Yb|0)|0;Yb=(c[e>>2]|0)+4|0;c[e>>2]=Yb;c[i>>2]=ub;cc=32-Qb|0;dc=Yb;ec=ub}c[g>>2]=cc;xb=cc;yb=dc;zb=ec}ec=b+88|0;dc=zb<<1|c[ec>>2];c[i>>2]=dc;zb=xb-1|0;c[g>>2]=zb;if((zb|0)==0){c[yb>>2]=je(dc|0)|0;dc=(c[e>>2]|0)+4|0;c[e>>2]=dc;c[g>>2]=32;fc=32;gc=dc}else{fc=zb;gc=yb}do{if((c[ec>>2]|0)==0){hc=fc}else{yb=b+92|0;zb=c[i>>2]<<1|c[yb>>2];c[i>>2]=zb;dc=fc-1|0;c[g>>2]=dc;if((dc|0)==0){c[gc>>2]=je(zb|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[g>>2]=32;ic=32;jc=zb}else{ic=dc;jc=gc}do{if((c[yb>>2]|0)==0){kc=ic;lc=jc;mc=c[i>>2]|0}else{dc=b+96|0;zb=c[dc>>2]|0;xb=b+100|0;cc=0;ub=18650;while(1){if((d[18648+(cc*3|0)|0]|0|0)==(zb|0)){if((d[18649+(cc*3|0)|0]|0|0)==(c[xb>>2]|0)){nc=ub;oc=0;break}}Yb=cc+1|0;Qb=18650+(Yb*3|0)|0;if((Yb|0)==16){nc=Qb;oc=1;break}else{cc=Yb;ub=Qb}}ub=d[nc]|0;if((ic|0)>8){cc=c[i>>2]<<8|ub;c[i>>2]=cc;pc=ic-8|0;qc=jc;rc=cc}else{cc=8-ic|0;c[jc>>2]=je(c[i>>2]<<ic|ub>>>(cc>>>0)|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=ub;pc=32-cc|0;qc=zb;rc=ub}c[g>>2]=pc;if(!oc){kc=pc;lc=qc;mc=rc;break}ub=c[dc>>2]|0;if((pc|0)>16){zb=rc<<16|ub;c[i>>2]=zb;sc=pc-16|0;tc=qc;uc=zb}else{zb=16-pc|0;c[qc>>2]=je(rc<<pc|ub>>>(zb>>>0)|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=ub;sc=32-zb|0;tc=cc;uc=ub}c[g>>2]=sc;ub=c[xb>>2]|0;if((sc|0)>16){cc=uc<<16|ub;c[i>>2]=cc;vc=sc-16|0;wc=tc;xc=cc}else{cc=16-sc|0;c[tc>>2]=je(uc<<sc|ub>>>(cc>>>0)|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=ub;vc=32-cc|0;wc=zb;xc=ub}c[g>>2]=vc;kc=vc;lc=wc;mc=xc}}while(0);yb=b+104|0;ub=mc<<1|c[yb>>2];c[i>>2]=ub;zb=kc-1|0;c[g>>2]=zb;if((zb|0)==0){c[lc>>2]=je(ub|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[g>>2]=32;yc=32;zc=ub}else{yc=zb;zc=lc}do{if((c[yb>>2]|0)==0){Ac=yc;Bc=zc}else{zb=c[i>>2]<<1|c[b+108>>2];c[i>>2]=zb;ub=yc-1|0;c[g>>2]=ub;if((ub|0)!=0){Ac=ub;Bc=zc;break}c[zc>>2]=je(zb|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[g>>2]=32;Ac=32;Bc=zb}}while(0);yb=b+112|0;zb=c[i>>2]<<1|c[yb>>2];c[i>>2]=zb;ub=Ac-1|0;c[g>>2]=ub;if((ub|0)==0){c[Bc>>2]=je(zb|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[g>>2]=32;Cc=32;Dc=zb}else{Cc=ub;Dc=Bc}do{if((c[yb>>2]|0)==0){Ec=Cc;Fc=Dc}else{ub=c[b+116>>2]|0;if((Cc|0)>3){zb=c[i>>2]<<3|ub;c[i>>2]=zb;Gc=Cc-3|0;Hc=Dc;Ic=zb}else{zb=3-Cc|0;c[Dc>>2]=je(c[i>>2]<<Cc|ub>>>(zb>>>0)|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=ub;Gc=32-zb|0;Hc=cc;Ic=ub}c[g>>2]=Gc;ub=Ic<<1|c[b+120>>2];c[i>>2]=ub;cc=Gc-1|0;c[g>>2]=cc;if((cc|0)==0){c[Hc>>2]=je(ub|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[g>>2]=32;Jc=zb;Kc=c[i>>2]|0;Lc=32}else{Jc=Hc;Kc=ub;Lc=cc}cc=b+124|0;ub=Kc<<1|c[cc>>2];c[i>>2]=ub;zb=Lc-1|0;c[g>>2]=zb;if((zb|0)==0){c[Jc>>2]=je(ub|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[g>>2]=32;Mc=32;Nc=ub}else{Mc=zb;Nc=Jc}if((c[cc>>2]|0)==0){Ec=Mc;Fc=Nc;break}cc=c[b+128>>2]|0;if((Mc|0)>8){zb=c[i>>2]<<8|cc;c[i>>2]=zb;Oc=Mc-8|0;Pc=Nc;Qc=zb}else{zb=8-Mc|0;c[Nc>>2]=je(c[i>>2]<<Mc|cc>>>(zb>>>0)|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[i>>2]=cc;Oc=32-zb|0;Pc=ub;Qc=cc}c[g>>2]=Oc;cc=c[b+132>>2]|0;if((Oc|0)>8){ub=Qc<<8|cc;c[i>>2]=ub;Rc=Oc-8|0;Sc=Pc;Tc=ub}else{ub=8-Oc|0;c[Pc>>2]=je(Qc<<Oc|cc>>>(ub>>>0)|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=cc;Rc=32-ub|0;Sc=zb;Tc=cc}c[g>>2]=Rc;cc=c[b+136>>2]|0;if((Rc|0)>8){c[i>>2]=Tc<<8|cc;Uc=Rc-8|0;Vc=Sc}else{zb=8-Rc|0;c[Sc>>2]=je(Tc<<Rc|cc>>>(zb>>>0)|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[i>>2]=cc;Uc=32-zb|0;Vc=ub}c[g>>2]=Uc;Ec=Uc;Fc=Vc}}while(0);yb=b+140|0;ub=c[i>>2]<<1|c[yb>>2];c[i>>2]=ub;zb=Ec-1|0;c[g>>2]=zb;if((zb|0)==0){c[Fc>>2]=je(ub|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[g>>2]=32;Wc=32;Xc=ub}else{Wc=zb;Xc=Fc}if((c[yb>>2]|0)==0){Yc=Wc;Zc=Xc;_c=c[i>>2]|0}else{yb=(c[b+144>>2]|0)+1|0;zb=(yb|0)>65535;ub=zb?32:0;cc=zb?yb>>16:yb;if((cc|0)>255){$c=cc>>8;ad=ub|16}else{$c=cc;ad=ub}ub=(d[16720+$c|0]|0)+ad>>1;cc=c[i>>2]|0;if((Wc|0)>(ub|0)){zb=cc<<ub;c[i>>2]=zb;bd=Wc;cd=zb;dd=Xc}else{c[Xc>>2]=je(cc<<Wc|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=0;bd=Wc+32|0;cd=0;dd=cc}cc=bd-ub|0;c[g>>2]=cc;zb=ub+1|0;if((cc|0)>(zb|0)){ub=cd<<zb|yb;c[i>>2]=ub;ed=cc-zb|0;fd=dd;gd=ub}else{ub=zb-cc|0;c[dd>>2]=je(yb>>>(ub>>>0)|cd<<cc|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=yb;ed=32-ub|0;fd=cc;gd=yb}c[g>>2]=ed;yb=(c[b+148>>2]|0)+1|0;cc=(yb|0)>65535;ub=cc?32:0;zb=cc?yb>>16:yb;if((zb|0)>255){hd=zb>>8;id=ub|16}else{hd=zb;id=ub}ub=(d[16720+hd|0]|0)+id>>1;if((ed|0)>(ub|0)){zb=gd<<ub;c[i>>2]=zb;jd=ed;kd=zb;ld=fd}else{c[fd>>2]=je(gd<<ed|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=0;jd=ed+32|0;kd=0;ld=zb}zb=jd-ub|0;c[g>>2]=zb;cc=ub+1|0;if((zb|0)>(cc|0)){ub=kd<<cc|yb;c[i>>2]=ub;md=zb-cc|0;nd=ld;od=ub}else{ub=cc-zb|0;c[ld>>2]=je(yb>>>(ub>>>0)|kd<<zb|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=yb;md=32-ub|0;nd=zb;od=yb}c[g>>2]=md;Yc=md;Zc=nd;_c=od}yb=b+152|0;zb=_c<<1|c[yb>>2];c[i>>2]=zb;ub=Yc-1|0;c[g>>2]=ub;if((ub|0)==0){c[Zc>>2]=je(zb|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[g>>2]=32;pd=32;qd=zb}else{pd=ub;qd=Zc}do{if((c[yb>>2]|0)==0){rd=pd;sd=qd}else{ub=c[b+156>>2]|0;zb=ub>>>16;if((pd|0)>16){cc=c[i>>2]<<16|zb;c[i>>2]=cc;td=pd-16|0;ud=cc;vd=qd}else{cc=16-pd|0;c[qd>>2]=je(c[i>>2]<<pd|zb>>>(cc>>>0)|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=zb;td=32-cc|0;ud=zb;vd=Qb}c[g>>2]=td;if((td|0)>16){Qb=ud<<16|ub;c[i>>2]=Qb;wd=td-16|0;xd=vd;yd=Qb}else{Qb=16-td|0;c[vd>>2]=je(ub>>>(Qb>>>0)|ud<<td|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=ub;wd=32-Qb|0;xd=zb;yd=ub}c[g>>2]=wd;ub=c[b+160>>2]|0;zb=ub>>>16;if((wd|0)>16){Qb=yd<<16|zb;c[i>>2]=Qb;zd=wd-16|0;Ad=Qb;Bd=xd}else{Qb=16-wd|0;c[xd>>2]=je(yd<<wd|zb>>>(Qb>>>0)|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=zb;zd=32-Qb|0;Ad=zb;Bd=cc}c[g>>2]=zd;if((zd|0)>16){cc=Ad<<16|ub;c[i>>2]=cc;Cd=zd-16|0;Dd=Bd;Ed=cc}else{cc=16-zd|0;c[Bd>>2]=je(ub>>>(cc>>>0)|Ad<<zd|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=ub;Cd=32-cc|0;Dd=zb;Ed=ub}c[g>>2]=Cd;ub=Ed<<1|c[b+164>>2];c[i>>2]=ub;zb=Cd-1|0;c[g>>2]=zb;if((zb|0)!=0){rd=zb;sd=Dd;break}c[Dd>>2]=je(ub|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[g>>2]=32;rd=32;sd=ub}}while(0);yb=b+168|0;ub=c[i>>2]<<1|c[yb>>2];c[i>>2]=ub;zb=rd-1|0;c[g>>2]=zb;if((zb|0)==0){c[sd>>2]=je(ub|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[g>>2]=32;Fd=32;Gd=ub}else{Fd=zb;Gd=sd}if((c[yb>>2]|0)==0){Hd=Fd;Id=Gd;Jd=c[i>>2]|0}else{zb=c[b+176>>2]|0;ub=(zb|0)>65535;cc=ub?32:0;Qb=ub?zb>>16:zb;if((Qb|0)>255){Kd=Qb>>8;Ld=cc|16}else{Kd=Qb;Ld=cc}cc=(d[16720+Kd|0]|0)+Ld>>1;Qb=c[i>>2]|0;if((Fd|0)>(cc|0)){ub=Qb<<cc;c[i>>2]=ub;Md=Fd;Nd=ub;Od=Gd}else{c[Gd>>2]=je(Qb<<Fd|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=0;Md=Fd+32|0;Nd=0;Od=Qb}Qb=Md-cc|0;c[g>>2]=Qb;ub=cc+1|0;if((Qb|0)>(ub|0)){cc=Nd<<ub|zb;c[i>>2]=cc;Pd=Qb-ub|0;Qd=Od;Rd=cc}else{cc=ub-Qb|0;c[Od>>2]=je(zb>>>(cc>>>0)|Nd<<Qb|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=zb;Pd=32-cc|0;Qd=Qb;Rd=zb}c[g>>2]=Pd;zb=c[b+180>>2]|0;if((Pd|0)>4){Qb=Rd<<4|zb;c[i>>2]=Qb;Sd=Pd-4|0;Td=Qd;Ud=Qb}else{Qb=4-Pd|0;c[Qd>>2]=je(Rd<<Pd|zb>>>(Qb>>>0)|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=zb;Sd=32-Qb|0;Td=cc;Ud=zb}c[g>>2]=Sd;zb=c[b+184>>2]|0;if((Sd|0)>4){cc=Ud<<4|zb;c[i>>2]=cc;Vd=Sd-4|0;Wd=Td;Xd=cc}else{cc=4-Sd|0;c[Td>>2]=je(Ud<<Sd|zb>>>(cc>>>0)|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=zb;Vd=32-cc|0;Wd=Qb;Xd=zb}c[g>>2]=Vd;zb=c[b+188>>2]|0;Qb=(zb|0)>65535;cc=Qb?32:0;ub=Qb?zb>>16:zb;if((ub|0)>255){Yd=ub>>8;Zd=cc|16}else{Yd=ub;Zd=cc}cc=(d[16720+Yd|0]|0)+Zd>>1;if((Vd|0)>(cc|0)){ub=Xd<<cc;c[i>>2]=ub;_d=Vd;$d=ub;ae=Wd}else{c[Wd>>2]=je(Xd<<Vd|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[i>>2]=0;_d=Vd+32|0;$d=0;ae=ub}ub=_d-cc|0;c[g>>2]=ub;Qb=cc+1|0;if((ub|0)>(Qb|0)){cc=$d<<Qb|zb;c[i>>2]=cc;be=ub-Qb|0;ce=ae;de=cc}else{cc=Qb-ub|0;c[ae>>2]=je(zb>>>(cc>>>0)|$d<<ub|0)|0;ub=(c[e>>2]|0)+4|0;c[e>>2]=ub;c[i>>2]=zb;be=32-cc|0;ce=ub;de=zb}c[g>>2]=be;zb=c[b+192>>2]|0;ub=(zb|0)>65535;cc=ub?32:0;Qb=ub?zb>>16:zb;if((Qb|0)>255){ee=Qb>>8;fe=cc|16}else{ee=Qb;fe=cc}cc=(d[16720+ee|0]|0)+fe>>1;if((be|0)>(cc|0)){Qb=de<<cc;c[i>>2]=Qb;ge=be;he=Qb;ie=ce}else{c[ce>>2]=je(de<<be|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=0;ge=be+32|0;he=0;ie=Qb}Qb=ge-cc|0;c[g>>2]=Qb;ub=cc+1|0;if((Qb|0)>(ub|0)){cc=he<<ub|zb;c[i>>2]=cc;ke=Qb-ub|0;le=ie;me=cc}else{cc=ub-Qb|0;c[ie>>2]=je(zb>>>(cc>>>0)|he<<Qb|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=zb;ke=32-cc|0;le=Qb;me=zb}c[g>>2]=ke;zb=me<<1|c[b+204>>2];c[i>>2]=zb;Qb=ke-1|0;c[g>>2]=Qb;do{if((Qb|0)==0){c[le>>2]=je(zb|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[g>>2]=32;ne=32;oe=(c[b+208>>2]|0)-1|0;pe=cc;qe=c[i>>2]|0;B=278}else{cc=(c[b+208>>2]|0)-1|0;if((Qb|0)>5){ne=Qb;oe=cc;pe=le;qe=zb;B=278;break}ub=6-ke|0;c[le>>2]=je(zb<<Qb|cc>>>(ub>>>0)|0)|0;Yb=(c[e>>2]|0)+4|0;c[e>>2]=Yb;c[i>>2]=cc;re=32-ub|0;se=Yb;te=cc}}while(0);if((B|0)==278){Qb=qe<<5|oe;c[i>>2]=Qb;re=ne-5|0;se=pe;te=Qb}c[g>>2]=re;Qb=(c[b+212>>2]|0)-1|0;if((re|0)>5){zb=te<<5|Qb;c[i>>2]=zb;ue=re-5|0;ve=se;we=zb}else{zb=5-re|0;c[se>>2]=je(te<<re|Qb>>>(zb>>>0)|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=Qb;ue=32-zb|0;ve=cc;we=Qb}c[g>>2]=ue;Qb=(c[b+216>>2]|0)-1|0;if((ue|0)>5){cc=we<<5|Qb;c[i>>2]=cc;xe=ue-5|0;ye=ve;ze=cc}else{cc=5-ue|0;c[ve>>2]=je(we<<ue|Qb>>>(cc>>>0)|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=Qb;xe=32-cc|0;ye=zb;ze=Qb}c[g>>2]=xe;Qb=c[b+220>>2]|0;if((xe|0)>5){zb=ze<<5|Qb;c[i>>2]=zb;Ae=xe-5|0;Be=ye;Ce=zb}else{zb=5-xe|0;c[ye>>2]=je(ze<<xe|Qb>>>(zb>>>0)|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=Qb;Ae=32-zb|0;Be=cc;Ce=Qb}c[g>>2]=Ae;Hd=Ae;Id=Be;Jd=Ce}Qb=b+172|0;cc=Jd<<1|c[Qb>>2];c[i>>2]=cc;zb=Hd-1|0;c[g>>2]=zb;if((zb|0)==0){c[Id>>2]=je(cc|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[g>>2]=32;De=32;Ee=cc}else{De=zb;Ee=Id}if((c[yb>>2]|0)==0){if((c[Qb>>2]|0)==0){Fe=De;Ge=Ee}else{B=294}}else{B=294}do{if((B|0)==294){Qb=c[i>>2]<<1;c[i>>2]=Qb;zb=De-1|0;c[g>>2]=zb;if((zb|0)!=0){Fe=zb;Ge=Ee;break}c[Ee>>2]=je(Qb|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[g>>2]=32;Fe=32;Ge=Qb}}while(0);yb=c[i>>2]<<1|c[b+224>>2];c[i>>2]=yb;Qb=Fe-1|0;c[g>>2]=Qb;if((Qb|0)==0){c[Ge>>2]=je(yb|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[g>>2]=32;He=c[i>>2]|0;Ie=32;Je=zb}else{He=yb;Ie=Qb;Je=Ge}Qb=b+228|0;yb=He<<1|c[Qb>>2];c[i>>2]=yb;zb=Ie-1|0;c[g>>2]=zb;if((zb|0)==0){c[Je>>2]=je(yb|0)|0;yb=(c[e>>2]|0)+4|0;c[e>>2]=yb;c[g>>2]=32;Ke=32;Le=yb}else{Ke=zb;Le=Je}if((c[Qb>>2]|0)==0){hc=Ke;break}Qb=c[i>>2]<<1|c[b+232>>2];c[i>>2]=Qb;zb=Ke-1|0;c[g>>2]=zb;if((zb|0)==0){c[Le>>2]=je(Qb|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[g>>2]=32;Me=32;Ne=Qb}else{Me=zb;Ne=Le}zb=(c[b+236>>2]|0)+1|0;Qb=(zb|0)>65535;yb=Qb?32:0;cc=Qb?zb>>16:zb;if((cc|0)>255){Oe=cc>>8;Pe=yb|16}else{Oe=cc;Pe=yb}yb=(d[16720+Oe|0]|0)+Pe>>1;cc=c[i>>2]|0;if((Me|0)>(yb|0)){Qb=cc<<yb;c[i>>2]=Qb;Qe=Me;Re=Qb;Se=Ne}else{c[Ne>>2]=je(cc<<Me|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=0;Qe=Me+32|0;Re=0;Se=cc}cc=Qe-yb|0;c[g>>2]=cc;Qb=yb+1|0;if((cc|0)>(Qb|0)){yb=Re<<Qb|zb;c[i>>2]=yb;Te=cc-Qb|0;Ue=yb;Ve=Se}else{yb=Qb-cc|0;c[Se>>2]=je(zb>>>(yb>>>0)|Re<<cc|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=zb;Te=32-yb|0;Ue=zb;Ve=cc}c[g>>2]=Te;cc=(c[b+240>>2]|0)+1|0;zb=(cc|0)>65535;yb=zb?32:0;Qb=zb?cc>>16:cc;if((Qb|0)>255){We=Qb>>8;Xe=yb|16}else{We=Qb;Xe=yb}yb=(d[16720+We|0]|0)+Xe>>1;if((Te|0)>(yb|0)){Qb=Ue<<yb;c[i>>2]=Qb;Ye=Te;Ze=Qb;_e=Ve}else{c[Ve>>2]=je(Ue<<Te|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=0;Ye=Te+32|0;Ze=0;_e=Qb}Qb=Ye-yb|0;c[g>>2]=Qb;zb=yb+1|0;if((Qb|0)>(zb|0)){yb=Ze<<zb|cc;c[i>>2]=yb;$e=Qb-zb|0;af=yb;bf=_e}else{yb=zb-Qb|0;c[_e>>2]=je(cc>>>(yb>>>0)|Ze<<Qb|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=cc;$e=32-yb|0;af=cc;bf=Qb}c[g>>2]=$e;Qb=(c[b+244>>2]|0)+1|0;cc=(Qb|0)>65535;yb=cc?32:0;zb=cc?Qb>>16:Qb;if((zb|0)>255){cf=zb>>8;df=yb|16}else{cf=zb;df=yb}yb=(d[16720+cf|0]|0)+df>>1;if(($e|0)>(yb|0)){zb=af<<yb;c[i>>2]=zb;ef=$e;ff=zb;gf=bf}else{c[bf>>2]=je(af<<$e|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=0;ef=$e+32|0;ff=0;gf=zb}zb=ef-yb|0;c[g>>2]=zb;cc=yb+1|0;if((zb|0)>(cc|0)){yb=ff<<cc|Qb;c[i>>2]=yb;hf=zb-cc|0;jf=yb;kf=gf}else{yb=cc-zb|0;c[gf>>2]=je(Qb>>>(yb>>>0)|ff<<zb|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=Qb;hf=32-yb|0;jf=Qb;kf=zb}c[g>>2]=hf;zb=(c[b+248>>2]|0)+1|0;Qb=(zb|0)>65535;yb=Qb?32:0;cc=Qb?zb>>16:zb;if((cc|0)>255){lf=cc>>8;mf=yb|16}else{lf=cc;mf=yb}yb=(d[16720+lf|0]|0)+mf>>1;if((hf|0)>(yb|0)){cc=jf<<yb;c[i>>2]=cc;nf=hf;of=cc;pf=kf}else{c[kf>>2]=je(jf<<hf|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=0;nf=hf+32|0;of=0;pf=cc}cc=nf-yb|0;c[g>>2]=cc;Qb=yb+1|0;if((cc|0)>(Qb|0)){yb=of<<Qb|zb;c[i>>2]=yb;qf=cc-Qb|0;rf=yb;sf=pf}else{yb=Qb-cc|0;c[pf>>2]=je(zb>>>(yb>>>0)|of<<cc|0)|0;cc=(c[e>>2]|0)+4|0;c[e>>2]=cc;c[i>>2]=zb;qf=32-yb|0;rf=zb;sf=cc}c[g>>2]=qf;cc=(c[b+252>>2]|0)+1|0;zb=(cc|0)>65535;yb=zb?32:0;Qb=zb?cc>>16:cc;if((Qb|0)>255){tf=Qb>>8;uf=yb|16}else{tf=Qb;uf=yb}yb=(d[16720+tf|0]|0)+uf>>1;if((qf|0)>(yb|0)){Qb=rf<<yb;c[i>>2]=Qb;vf=qf;wf=Qb;xf=sf}else{c[sf>>2]=je(rf<<qf|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=0;vf=qf+32|0;wf=0;xf=Qb}Qb=vf-yb|0;c[g>>2]=Qb;zb=yb+1|0;if((Qb|0)>(zb|0)){yb=wf<<zb|cc;c[i>>2]=yb;yf=Qb-zb|0;zf=yb;Af=xf}else{yb=zb-Qb|0;c[xf>>2]=je(cc>>>(yb>>>0)|wf<<Qb|0)|0;Qb=(c[e>>2]|0)+4|0;c[e>>2]=Qb;c[i>>2]=cc;yf=32-yb|0;zf=cc;Af=Qb}c[g>>2]=yf;Qb=(c[b+256>>2]|0)+1|0;cc=(Qb|0)>65535;yb=cc?32:0;zb=cc?Qb>>16:Qb;if((zb|0)>255){Bf=zb>>8;Cf=yb|16}else{Bf=zb;Cf=yb}yb=(d[16720+Bf|0]|0)+Cf>>1;if((yf|0)>(yb|0)){zb=zf<<yb;c[i>>2]=zb;Df=yf;Ef=zb;Ff=Af}else{c[Af>>2]=je(zf<<yf|0)|0;zb=(c[e>>2]|0)+4|0;c[e>>2]=zb;c[i>>2]=0;Df=yf+32|0;Ef=0;Ff=zb}zb=Df-yb|0;c[g>>2]=zb;cc=yb+1|0;if((zb|0)>(cc|0)){c[i>>2]=Ef<<cc|Qb;Gf=zb-cc|0}else{yb=cc-zb|0;c[Ff>>2]=je(Qb>>>(yb>>>0)|Ef<<zb|0)|0;c[e>>2]=(c[e>>2]|0)+4;c[i>>2]=Qb;Gf=32-yb|0}c[g>>2]=Gf;hc=Gf}}while(0);Gf=c[i>>2]<<1|1;c[i>>2]=Gf;Ef=hc-1|0;c[g>>2]=Ef;do{if((Ef|0)==0){Ff=je(Gf|0)|0;c[c[e>>2]>>2]=Ff;c[e>>2]=(c[e>>2]|0)+4;c[g>>2]=32;Hf=c[i>>2]|0;If=32;Jf=0}else{Ff=Ef&7;if((Ef|0)>(Ff|0)){Hf=Gf;If=Ef;Jf=Ff;break}Df=je(Gf<<Ef|0)|0;c[c[e>>2]>>2]=Df;c[e>>2]=(c[e>>2]|0)+4;c[i>>2]=0;Kf=hc+31|0;Lf=Ff;Mf=0;Nf=Kf-Lf|0;c[g>>2]=Nf;Of=Nf&31;Pf=Mf<<Of;Qf=je(Pf|0)|0;Rf=c[e>>2]|0;Sf=Rf;c[Sf>>2]=Qf;Tf=c[g>>2]|0;Uf=Tf>>3;Vf=4-Uf|0;Wf=c[e>>2]|0;Xf=Wf+Vf|0;c[e>>2]=Xf;c[g>>2]=32;return}}while(0);hc=Hf<<Jf;c[i>>2]=hc;Kf=If;Lf=Jf;Mf=hc;Nf=Kf-Lf|0;c[g>>2]=Nf;Of=Nf&31;Pf=Mf<<Of;Qf=je(Pf|0)|0;Rf=c[e>>2]|0;Sf=Rf;c[Sf>>2]=Qf;Tf=c[g>>2]|0;Uf=Tf>>3;Vf=4-Uf|0;Wf=c[e>>2]|0;Xf=Wf+Vf|0;c[e>>2]=Xf;c[g>>2]=32;return}function _Mb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[b>>2]=d;c[b+4>>2]=c[f>>2];c[b+8>>2]=c[e+152>>2];if((c[e+136>>2]|0)==0){g=(c[e+160>>2]|0)!=0|0}else{g=0}c[b+12>>2]=g;c[b+16>>2]=1;c[b+20>>2]=c[e+88>>2];c[b+24>>2]=1;c[b+28>>2]=(c[e+528>>2]|0)>0;c[b+32>>2]=(c[e+532>>2]|0)!=0?2:0;do{if((c[e+624>>2]|0)==2){h=26}else{if((c[e+812>>2]|0)!=0){h=26;break}g=c[e+628>>2]|0;h=(g|0)<51?g:51}}while(0);c[b+36>>2]=h;c[b+40>>2]=26;c[b+44>>2]=c[e+540>>2];c[b+48>>2]=1;c[b+52>>2]=c[e+164>>2];c[b+56>>2]=0;c[b+60>>2]=(c[e+524>>2]|0)!=0;h=c[e+168>>2]|0;c[b+64>>2]=h;if((h|0)==0){c[b+68>>2]=99224;c[b+72>>2]=99224;c[b+76>>2]=99224;c[b+80>>2]=99224;c[b+84>>2]=99224;c[b+88>>2]=99224;c[b+92>>2]=99224;c[b+96>>2]=99224;return}else if((h|0)==1){c[b+68>>2]=99176;c[b+72>>2]=99144;c[b+76>>2]=99176;c[b+80>>2]=99144;c[b+84>>2]=99064;c[b+88>>2]=98936;c[b+92>>2]=99064;c[b+96>>2]=98936;return}else if((h|0)==2){h=e+180|0;g=a[h]|0;f=e+177|0;a[h]=a[f]|0;a[f]=g;g=0;while(1){f=g+8+(e+176)|0;h=a[f]|0;d=(g<<2|2)+(e+176)|0;a[f]=a[d]|0;a[d]=h;h=g+1|0;if((h|0)<2){g=h}else{i=0;break}}do{g=i+12+(e+176)|0;h=a[g]|0;d=(i<<2|3)+(e+176)|0;a[g]=a[d]|0;a[d]=h;i=i+1|0;}while((i|0)<3);i=e+176|0;h=e+196|0;d=a[h]|0;g=e+193|0;a[h]=a[g]|0;a[g]=d;d=0;while(1){g=d+8+(e+192)|0;h=a[g]|0;f=(d<<2|2)+(e+192)|0;a[g]=a[f]|0;a[f]=h;h=d+1|0;if((h|0)<2){d=h}else{j=0;break}}do{d=j+12+(e+192)|0;h=a[d]|0;f=(j<<2|3)+(e+192)|0;a[d]=a[f]|0;a[f]=h;j=j+1|0;}while((j|0)<3);j=e+192|0;h=e+212|0;f=a[h]|0;d=e+209|0;a[h]=a[d]|0;a[d]=f;f=0;while(1){d=f+8+(e+208)|0;h=a[d]|0;g=(f<<2|2)+(e+208)|0;a[d]=a[g]|0;a[g]=h;h=f+1|0;if((h|0)<2){f=h}else{k=0;break}}do{f=k+12+(e+208)|0;h=a[f]|0;g=(k<<2|3)+(e+208)|0;a[f]=a[g]|0;a[g]=h;k=k+1|0;}while((k|0)<3);k=e+208|0;h=e+228|0;g=a[h]|0;f=e+225|0;a[h]=a[f]|0;a[f]=g;g=0;while(1){f=g+8+(e+224)|0;h=a[f]|0;d=(g<<2|2)+(e+224)|0;a[f]=a[d]|0;a[d]=h;h=g+1|0;if((h|0)<2){g=h}else{l=0;break}}do{g=l+12+(e+224)|0;h=a[g]|0;d=(l<<2|3)+(e+224)|0;a[g]=a[d]|0;a[d]=h;l=l+1|0;}while((l|0)<3);l=e+224|0;h=0;do{if((h|0)>0){d=h<<3;g=0;do{f=g+d+(e+240)|0;m=a[f]|0;n=(g<<3)+h+(e+240)|0;a[f]=a[n]|0;a[n]=m;g=g+1|0;}while((g|0)<(h|0))}h=h+1|0;}while((h|0)<8);h=e+240|0;g=0;do{if((g|0)>0){d=g<<3;m=0;do{n=m+d+(e+304)|0;f=a[n]|0;o=(m<<3)+g+(e+304)|0;a[n]=a[o]|0;a[o]=f;m=m+1|0;}while((m|0)<(g|0))}g=g+1|0;}while((g|0)<8);g=e+304|0;m=0;do{if((m|0)>0){d=m<<3;f=0;do{o=f+d+(e+368)|0;n=a[o]|0;p=(f<<3)+m+(e+368)|0;a[o]=a[p]|0;a[p]=n;f=f+1|0;}while((f|0)<(m|0))}m=m+1|0;}while((m|0)<8);m=e+368|0;f=0;do{if((f|0)>0){d=f<<3;n=0;do{p=n+d+(e+432)|0;o=a[p]|0;q=(n<<3)+f+(e+432)|0;a[p]=a[q]|0;a[q]=o;n=n+1|0;}while((n|0)<(f|0))}f=f+1|0;}while((f|0)<8);c[b+68>>2]=i;c[b+72>>2]=j;c[b+76>>2]=k;c[b+80>>2]=l;c[b+84>>2]=h;c[b+88>>2]=g;c[b+92>>2]=m;c[b+96>>2]=e+432;e=0;m=i;while(1){i=(e|0)<4?16:64;g=b+68+(e<<2)|0;h=99192+(e<<2)|0;l=0;k=m;while(1){if((a[k+l|0]|0)==0){j=c[h>>2]|0;c[g>>2]=j;r=j}else{r=k}j=l+1|0;if((j|0)<(i|0)){l=j;k=r}else{break}}k=e+1|0;if((k|0)>=8){break}e=k;m=c[b+68+(k<<2)>>2]|0}return}else{return}}function $Mb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;f=a+4|0;g=c[f>>2]|0;h=g&3;if((h|0)==0){i=g}else{j=g+(-h|0)|0;c[f>>2]=j;g=4-h<<3;c[a+16>>2]=g;c[a+12>>2]=(je(c[j>>2]|0)|0)>>>(g>>>0);i=j}j=(c[e>>2]|0)+1|0;g=(j|0)>65535;h=g?32:0;k=g?j>>16:j;if((k|0)>255){l=k>>8;m=h|16}else{l=k;m=h}h=(d[16720+l|0]|0)+m>>1;m=a+16|0;l=c[m>>2]|0;k=a+12|0;g=c[k>>2]|0;if((l|0)>(h|0)){n=g<<h;c[k>>2]=n;o=l;p=n;q=i}else{c[i>>2]=je(g<<l|0)|0;g=(c[f>>2]|0)+4|0;c[f>>2]=g;c[k>>2]=0;o=l+32|0;p=0;q=g}g=o-h|0;c[m>>2]=g;o=h+1|0;if((g|0)>(o|0)){h=p<<o|j;c[k>>2]=h;r=g-o|0;s=h;t=q}else{h=o-g|0;c[q>>2]=je(j>>>(h>>>0)|p<<g|0)|0;g=(c[f>>2]|0)+4|0;c[f>>2]=g;c[k>>2]=j;r=32-h|0;s=j;t=g}c[m>>2]=r;g=(c[e+4>>2]|0)+1|0;j=(g|0)>65535;h=j?32:0;p=j?g>>16:g;if((p|0)>255){u=p>>8;v=h|16}else{u=p;v=h}h=(d[16720+u|0]|0)+v>>1;if((r|0)>(h|0)){v=s<<h;c[k>>2]=v;w=r;x=v;y=t}else{c[t>>2]=je(s<<r|0)|0;s=(c[f>>2]|0)+4|0;c[f>>2]=s;c[k>>2]=0;w=r+32|0;x=0;y=s}s=w-h|0;c[m>>2]=s;w=h+1|0;if((s|0)>(w|0)){h=x<<w|g;c[k>>2]=h;z=s-w|0;A=h;B=y}else{h=w-s|0;c[y>>2]=je(g>>>(h>>>0)|x<<s|0)|0;s=(c[f>>2]|0)+4|0;c[f>>2]=s;c[k>>2]=g;z=32-h|0;A=g;B=s}c[m>>2]=z;s=A<<1|c[e+8>>2];c[k>>2]=s;A=z-1|0;c[m>>2]=A;if((A|0)==0){c[B>>2]=je(s|0)|0;z=(c[f>>2]|0)+4|0;c[f>>2]=z;c[m>>2]=32;C=c[k>>2]|0;D=32;E=z}else{C=s;D=A;E=B}B=C<<1|c[e+12>>2];c[k>>2]=B;C=D-1|0;c[m>>2]=C;if((C|0)==0){c[E>>2]=je(B|0)|0;B=(c[f>>2]|0)+4|0;c[f>>2]=B;c[m>>2]=32;F=32;G=B}else{F=C;G=E}E=c[e+16>>2]|0;C=(E|0)>65535;B=C?32:0;D=C?E>>16:E;if((D|0)>255){H=D>>8;I=B|16}else{H=D;I=B}B=(d[16720+H|0]|0)+I>>1;I=c[k>>2]|0;if((F|0)>(B|0)){H=I<<B;c[k>>2]=H;J=F;K=H;L=G}else{c[G>>2]=je(I<<F|0)|0;I=(c[f>>2]|0)+4|0;c[f>>2]=I;c[k>>2]=0;J=F+32|0;K=0;L=I}I=J-B|0;c[m>>2]=I;J=B+1|0;if((I|0)>(J|0)){B=K<<J|E;c[k>>2]=B;M=I-J|0;N=B;O=L}else{B=J-I|0;c[L>>2]=je(E>>>(B>>>0)|K<<I|0)|0;I=(c[f>>2]|0)+4|0;c[f>>2]=I;c[k>>2]=E;M=32-B|0;N=E;O=I}c[m>>2]=M;I=c[e+20>>2]|0;E=(I|0)>65535;B=E?32:0;K=E?I>>16:I;if((K|0)>255){P=K>>8;Q=B|16}else{P=K;Q=B}B=(d[16720+P|0]|0)+Q>>1;if((M|0)>(B|0)){Q=N<<B;c[k>>2]=Q;R=M;S=Q;T=O}else{c[O>>2]=je(N<<M|0)|0;N=(c[f>>2]|0)+4|0;c[f>>2]=N;c[k>>2]=0;R=M+32|0;S=0;T=N}N=R-B|0;c[m>>2]=N;R=B+1|0;if((N|0)>(R|0)){B=S<<R|I;c[k>>2]=B;U=N-R|0;V=B;W=T}else{B=R-N|0;c[T>>2]=je(I>>>(B>>>0)|S<<N|0)|0;N=(c[f>>2]|0)+4|0;c[f>>2]=N;c[k>>2]=I;U=32-B|0;V=I;W=N}c[m>>2]=U;N=c[e+24>>2]|0;I=(N|0)>65535;B=I?32:0;S=I?N>>16:N;if((S|0)>255){X=S>>8;Y=B|16}else{X=S;Y=B}B=(d[16720+X|0]|0)+Y>>1;if((U|0)>(B|0)){Y=V<<B;c[k>>2]=Y;Z=U;_=Y;$=W}else{c[W>>2]=je(V<<U|0)|0;V=(c[f>>2]|0)+4|0;c[f>>2]=V;c[k>>2]=0;Z=U+32|0;_=0;$=V}V=Z-B|0;c[m>>2]=V;Z=B+1|0;if((V|0)>(Z|0)){B=_<<Z|N;c[k>>2]=B;aa=V-Z|0;ba=B;ca=$}else{B=Z-V|0;c[$>>2]=je(N>>>(B>>>0)|_<<V|0)|0;V=(c[f>>2]|0)+4|0;c[f>>2]=V;c[k>>2]=N;aa=32-B|0;ba=N;ca=V}c[m>>2]=aa;V=ba<<1|c[e+28>>2];c[k>>2]=V;ba=aa-1|0;c[m>>2]=ba;do{if((ba|0)==0){c[ca>>2]=je(V|0)|0;N=(c[f>>2]|0)+4|0;c[f>>2]=N;c[m>>2]=32;da=32;ea=c[e+32>>2]|0;fa=c[k>>2]|0;ga=N;ha=50}else{N=c[e+32>>2]|0;if((ba|0)>2){da=ba;ea=N;fa=V;ga=ca;ha=50;break}B=3-aa|0;c[ca>>2]=je(V<<ba|N>>>(B>>>0)|0)|0;_=(c[f>>2]|0)+4|0;c[f>>2]=_;c[k>>2]=N;ia=32-B|0;ja=N;ka=_}}while(0);if((ha|0)==50){ba=fa<<2|ea;c[k>>2]=ba;ia=da-2|0;ja=ba;ka=ga}c[m>>2]=ia;ga=c[e+36>>2]<<1;ba=53-ga|0;da=(ba|0)<0?ga-52|0:ba;ba=(da|0)>255;ga=(ba?16:0)+(d[16720+(ba?da>>8:da)|0]|0)|0;if((ia|0)>(ga|0)){ba=ja<<ga|da;c[k>>2]=ba;la=ia-ga|0;ma=ba;na=ka}else{ba=ga-ia|0;c[ka>>2]=je(ja<<ia|da>>>(ba>>>0)|0)|0;ia=(c[f>>2]|0)+4|0;c[f>>2]=ia;c[k>>2]=da;la=32-ba|0;ma=da;na=ia}c[m>>2]=la;ia=c[e+40>>2]<<1;da=53-ia|0;ba=(da|0)<0?ia-52|0:da;da=(ba|0)>255;ia=(da?16:0)+(d[16720+(da?ba>>8:ba)|0]|0)|0;if((la|0)>(ia|0)){da=ma<<ia|ba;c[k>>2]=da;oa=la-ia|0;pa=da;qa=na}else{da=ia-la|0;c[na>>2]=je(ma<<la|ba>>>(da>>>0)|0)|0;la=(c[f>>2]|0)+4|0;c[f>>2]=la;c[k>>2]=ba;oa=32-da|0;pa=ba;qa=la}c[m>>2]=oa;la=e+44|0;ba=c[la>>2]<<1;da=1-ba|0;ma=(da|0)<0?ba:da;da=(ma|0)>255;ba=(da?16:0)+(d[16720+(da?ma>>8:ma)|0]|0)|0;if((oa|0)>(ba|0)){da=pa<<ba|ma;c[k>>2]=da;ra=oa-ba|0;sa=da;ta=qa}else{da=ba-oa|0;c[qa>>2]=je(pa<<oa|ma>>>(da>>>0)|0)|0;oa=(c[f>>2]|0)+4|0;c[f>>2]=oa;c[k>>2]=ma;ra=32-da|0;sa=ma;ta=oa}c[m>>2]=ra;oa=sa<<1|c[e+48>>2];c[k>>2]=oa;sa=ra-1|0;c[m>>2]=sa;if((sa|0)==0){c[ta>>2]=je(oa|0)|0;ra=(c[f>>2]|0)+4|0;c[f>>2]=ra;c[m>>2]=32;ua=c[k>>2]|0;va=32;wa=ra}else{ua=oa;va=sa;wa=ta}ta=ua<<1|c[e+52>>2];c[k>>2]=ta;ua=va-1|0;c[m>>2]=ua;if((ua|0)==0){c[wa>>2]=je(ta|0)|0;va=(c[f>>2]|0)+4|0;c[f>>2]=va;c[m>>2]=32;xa=c[k>>2]|0;ya=32;za=va}else{xa=ta;ya=ua;za=wa}wa=xa<<1|c[e+56>>2];c[k>>2]=wa;xa=ya-1|0;c[m>>2]=xa;if((xa|0)==0){c[za>>2]=je(wa|0)|0;wa=(c[f>>2]|0)+4|0;c[f>>2]=wa;c[m>>2]=32;Aa=32;Ba=wa}else{Aa=xa;Ba=za}za=e+60|0;xa=c[za>>2]|0;do{if((xa|0)==0){if((c[e+64>>2]|0)!=0){ha=70;break}Ca=Aa;Da=c[k>>2]|0}else{ha=70}}while(0);if((ha|0)==70){ha=c[k>>2]<<1|xa;c[k>>2]=ha;xa=Aa-1|0;c[m>>2]=xa;if((xa|0)==0){c[Ba>>2]=je(ha|0)|0;Aa=(c[f>>2]|0)+4|0;c[f>>2]=Aa;c[m>>2]=32;Ea=c[k>>2]|0;Fa=32;Ga=Aa}else{Ea=ha;Fa=xa;Ga=Ba}Ba=e+64|0;xa=Ea<<1|(c[Ba>>2]|0)!=0;c[k>>2]=xa;Ea=Fa-1|0;c[m>>2]=Ea;if((Ea|0)==0){c[Ga>>2]=je(xa|0)|0;c[f>>2]=(c[f>>2]|0)+4;c[m>>2]=32;Ha=32}else{Ha=Ea}do{if((c[Ba>>2]|0)==0){Ia=Ha}else{aNb(a,e,0);aNb(a,e,2);Ea=c[k>>2]<<1;c[k>>2]=Ea;xa=(c[m>>2]|0)-1|0;c[m>>2]=xa;if((xa|0)==0){xa=je(Ea|0)|0;c[c[f>>2]>>2]=xa;c[f>>2]=(c[f>>2]|0)+4;c[m>>2]=32}aNb(a,e,1);aNb(a,e,3);xa=c[k>>2]<<1;c[k>>2]=xa;Ea=(c[m>>2]|0)-1|0;c[m>>2]=Ea;if((Ea|0)==0){Ga=je(xa|0)|0;c[c[f>>2]>>2]=Ga;c[f>>2]=(c[f>>2]|0)+4;c[m>>2]=32;Ja=32}else{Ja=Ea}if((c[za>>2]|0)==0){Ia=Ja;break}Ea=(c[b+264>>2]|0)==3;aNb(a,e,4);if(!Ea){aNb(a,e,5);Ia=c[m>>2]|0;break}aNb(a,e,6);Ea=c[k>>2]<<1;c[k>>2]=Ea;Ga=(c[m>>2]|0)-1|0;c[m>>2]=Ga;if((Ga|0)==0){Ga=je(Ea|0)|0;c[c[f>>2]>>2]=Ga;c[f>>2]=(c[f>>2]|0)+4;c[m>>2]=32}aNb(a,e,5);aNb(a,e,7);Ga=c[k>>2]<<1;c[k>>2]=Ga;Ea=(c[m>>2]|0)-1|0;c[m>>2]=Ea;if((Ea|0)!=0){Ia=Ea;break}Ea=je(Ga|0)|0;c[c[f>>2]>>2]=Ea;c[f>>2]=(c[f>>2]|0)+4;c[m>>2]=32;Ia=32}}while(0);e=c[la>>2]<<1;la=1-e|0;a=(la|0)<0?e:la;la=(a|0)>255;e=(la?16:0)+(d[16720+(la?a>>8:a)|0]|0)|0;if((Ia|0)>(e|0)){la=c[k>>2]<<e|a;c[k>>2]=la;Ka=Ia-e|0;La=la}else{la=e-Ia|0;e=je(c[k>>2]<<Ia|a>>>(la>>>0)|0)|0;c[c[f>>2]>>2]=e;c[f>>2]=(c[f>>2]|0)+4;c[k>>2]=a;Ka=32-la|0;La=a}c[m>>2]=Ka;Ca=Ka;Da=La}La=Da<<1|1;c[k>>2]=La;Da=Ca-1|0;c[m>>2]=Da;do{if((Da|0)==0){Ka=je(La|0)|0;c[c[f>>2]>>2]=Ka;Ka=(c[f>>2]|0)+4|0;c[f>>2]=Ka;c[m>>2]=32;Ma=c[k>>2]|0;Na=32;Oa=0;Pa=Ka}else{Ka=Da&7;if((Da|0)>(Ka|0)){Ma=La;Na=Da;Oa=Ka;Pa=c[f>>2]|0;break}a=je(La<<Da|0)|0;c[c[f>>2]>>2]=a;a=(c[f>>2]|0)+4|0;c[f>>2]=a;c[k>>2]=0;Qa=Ca+31|0;Ra=Ka;Sa=0;Ta=a;Ua=Qa-Ra|0;c[m>>2]=Ua;Va=Ua&31;Wa=Sa<<Va;Xa=je(Wa|0)|0;Ya=Ta;c[Ya>>2]=Xa;Za=c[m>>2]|0;_a=Za>>3;$a=4-_a|0;ab=c[f>>2]|0;bb=ab+$a|0;c[f>>2]=bb;c[m>>2]=32;return}}while(0);Ca=Ma<<Oa;c[k>>2]=Ca;Qa=Na;Ra=Oa;Sa=Ca;Ta=Pa;Ua=Qa-Ra|0;c[m>>2]=Ua;Va=Ua&31;Wa=Sa<<Va;Xa=je(Wa|0)|0;Ya=Ta;c[Ya>>2]=Xa;Za=c[m>>2]|0;_a=Za>>3;$a=4-_a|0;ab=c[f>>2]|0;bb=ab+$a|0;c[f>>2]=bb;c[m>>2]=32;return}function aNb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=(f|0)<4;h=g?16:64;i=g?16064:15904;g=c[e+68+(f<<2)>>2]|0;if((f|0)==7){j=e+88|0}else if((f|0)==6){j=e+84|0}else if((f|0)==2){j=e+68|0}else if((f|0)==3){j=e+72|0}else{j=99192+(f<<2)|0}if((grc(g,c[j>>2]|0,h)|0)==0){j=b+12|0;e=c[j>>2]<<1;c[j>>2]=e;j=b+16|0;k=(c[j>>2]|0)-1|0;c[j>>2]=k;if((k|0)!=0){return}k=je(e|0)|0;e=b+4|0;c[c[e>>2]>>2]=k;c[e>>2]=(c[e>>2]|0)+4;c[j>>2]=32;return}j=(grc(g,c[99192+(f<<2)>>2]|0,h)|0)==0;f=b+12|0;e=c[f>>2]<<1|1;c[f>>2]=e;k=b+16|0;l=(c[k>>2]|0)-1|0;c[k>>2]=l;if((l|0)==0){m=je(e|0)|0;e=b+4|0;c[c[e>>2]>>2]=m;c[e>>2]=(c[e>>2]|0)+4;c[k>>2]=32;n=32}else{n=l}if(j){if((n|0)>9){c[f>>2]=c[f>>2]<<9|17;o=n-9|0}else{j=9-n|0;l=je(c[f>>2]<<n|17>>>(j>>>0)|0)|0;e=b+4|0;c[c[e>>2]>>2]=l;c[e>>2]=(c[e>>2]|0)+4;c[f>>2]=17;o=32-j|0}c[k>>2]=o;return}else{p=h}while(1){if((p|0)<=1){break}o=p-1|0;if((a[g+(d[i+o|0]|0)|0]|0)==(a[g+(d[i+(p-2)|0]|0)|0]|0)){p=o}else{break}}if((p|0)<(h|0)){o=(-(a[g+(d[i+p|0]|0)|0]|0)&255)<<24>>24<<1;j=1-o|0;e=(j|0)<0?o:j;if((e|0)<256){q=d[16720+e|0]|0}else{q=(d[16720+(e>>8)|0]|0)+16|0}r=(h-p|0)<(q|0)?h:p}else{r=p}if((r|0)>0){p=b+4|0;q=0;e=n;while(1){if((q|0)>0){s=a[g+(d[i+(q-1)|0]|0)|0]|0}else{s=8}j=((a[g+(d[i+q|0]|0)|0]|0)-s&255)<<24>>24<<1;o=1-j|0;l=(o|0)<0?j:o;o=(l|0)>255;j=(o?16:0)+(d[16720+(o?l>>8:l)|0]|0)|0;if((e|0)>(j|0)){c[f>>2]=c[f>>2]<<j|l;t=e-j|0}else{o=j-e|0;j=je(c[f>>2]<<e|l>>>(o>>>0)|0)|0;c[c[p>>2]>>2]=j;c[p>>2]=(c[p>>2]|0)+4;c[f>>2]=l;t=32-o|0}c[k>>2]=t;o=q+1|0;if((o|0)<(r|0)){q=o;e=t}else{u=t;break}}}else{u=n}if((r|0)>=(h|0)){return}h=(-(a[g+(d[i+r|0]|0)|0]|0)&255)<<24>>24<<1;r=1-h|0;i=(r|0)<0?h:r;r=(i|0)>255;h=(r?16:0)+(d[16720+(r?i>>8:i)|0]|0)|0;if((u|0)>(h|0)){c[f>>2]=c[f>>2]<<h|i;v=u-h|0}else{r=h-u|0;h=je(c[f>>2]<<u|i>>>(r>>>0)|0)|0;u=b+4|0;c[c[u>>2]>>2]=h;c[u>>2]=(c[u>>2]|0)+4;c[f>>2]=i;v=32-r|0}c[k>>2]=v;return}function bNb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;a=i;i=i+104|0;f=a|0;g=f|0;h=f&3;j=f+(-h|0)|0;k=j;l=k&3;if((l|0)==0){m=j;n=0;o=4-h<<3}else{j=f+(-(h+l|0)|0)|0;h=4-l<<3;m=j;n=(je(c[j>>2]|0)|0)>>>(h>>>0);o=h}h=e+1|0;e=(h|0)>65535;j=e?32:0;l=e?h>>16:h;if((l|0)>255){p=l>>8;q=j|16}else{p=l;q=j}j=(d[16720+p|0]|0)+q>>1;if((o|0)>(j|0)){r=o;s=n<<j;t=m}else{c[m>>2]=je(n<<o|0)|0;r=o+32|0;s=0;t=m+4|0}m=r-j|0;r=j+1|0;if((m|0)>(r|0)){u=m-r|0;v=t;w=s<<r|h}else{j=r-m|0;c[t>>2]=je(h>>>(j>>>0)|s<<m|0)|0;u=32-j|0;v=t+4|0;w=h}h=w<<1|1;do{if((u|0)==1){c[v>>2]=je(h|0)|0;x=h<<1;y=31;z=v+4|0;A=16}else{w=h<<1;t=u-2|0;if((t|0)==0){c[v>>2]=je(w|0)|0;x=w;y=32;z=v+4|0;A=16;break}if((t|0)>2){x=w;y=t;z=v;A=16;break}c[v>>2]=je(w<<t|0)|0;B=u+28|0;C=v+4|0;D=0}}while(0);if((A|0)==16){B=y-2|0;C=z;D=x<<2}x=B&7;do{if((x|0)==0){E=C;F=D;G=B}else{z=1<<x-1;if((B|0)>(x|0)){E=C;F=z|D<<x;G=B-x|0;break}else{y=x-B|0;c[C>>2]=je(z>>>(y>>>0)|D<<B|0)|0;E=C+4|0;F=z;G=32-y|0;break}}}while(0);c[E>>2]=je(F<<(G&31)|0)|0;XMb(b,g,(E+(4-(G>>3))-k<<3|0)/8|0,6);i=a;return}function cNb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=RLb(a|0,0)|0;if((e|0)==0){f=-1;i=d;return f|0}a=MLb((lrc(e|0)|0)+200|0)|0;if((a|0)==0){NLb(e);f=-1;i=d;return f|0}else{nrc(a|0,18928,16)|0;gc(a+16|0,2417576,(g=i,i=i+32|0,c[g>>2]=142,c[g+8>>2]=10230704,c[g+16>>2]=2436608,c[g+24>>2]=e,g)|0)|0;i=g;XMb(b,a,(lrc(a|0)|0)+1|0,5);NLb(e);NLb(a);f=0;i=d;return f|0}return 0}function dNb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i;i=i+104|0;f=e|0;g=f|0;h=f&3;j=f+(-h|0)|0;k=j;l=k&3;if((l|0)==0){m=j;n=0;o=4-h<<3}else{j=f+(-(h+l|0)|0)|0;h=4-l<<3;m=j;n=(je(c[j>>2]|0)|0)>>>(h>>>0);o=h}h=(c[a+8368>>2]|0)+1|0;j=(h|0)>65535;l=j?32:0;f=j?h>>16:h;if((f|0)>255){p=f>>8;q=l|16}else{p=f;q=l}l=(d[16720+p|0]|0)+q>>1;if((o|0)>(l|0)){r=o;s=n<<l;t=m}else{c[m>>2]=je(n<<o|0)|0;r=o+32|0;s=0;t=m+4|0}m=r-l|0;r=l+1|0;if((m|0)>(r|0)){u=m-r|0;v=t;w=s<<r|h}else{l=r-m|0;c[t>>2]=je(h>>>(l>>>0)|s<<m|0)|0;u=32-l|0;v=t+4|0;w=h}do{if((c[a+8536>>2]|0)==0){x=v;y=w;z=u}else{h=a+8576|0;t=c[h>>2]|0;l=c[a+15328>>2]|0;if((u|0)>(t|0)){A=u-t|0;B=v;C=w<<t|l;D=t}else{m=t-u|0;c[v>>2]=je(l>>>(m>>>0)|w<<u|0)|0;A=32-m|0;B=v+4|0;C=l;D=c[h>>2]|0}h=c[a+15332>>2]|0;if((A|0)>(D|0)){x=B;y=C<<D|h;z=A-D|0;break}else{l=D-A|0;c[B>>2]=je(h>>>(l>>>0)|C<<A|0)|0;x=B+4|0;y=h;z=32-l|0;break}}}while(0);B=z&7;do{if((B|0)==0){E=x;F=y;G=z}else{A=1<<B-1;if((z|0)>(B|0)){E=x;F=A|y<<B;G=z-B|0;break}else{C=B-z|0;c[x>>2]=je(A>>>(C>>>0)|y<<z|0)|0;E=x+4|0;F=A;G=32-C|0;break}}}while(0);c[E>>2]=je(F<<(G&31)|0)|0;XMb(b,g,(E+(4-(G>>3))-k<<3|0)/8|0,0);i=e;return}function eNb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+104|0;f=e|0;g=f|0;h=f&3;j=f+(-h|0)|0;k=j;l=k&3;if((l|0)==0){m=j;n=0;o=4-h<<3}else{j=f+(-(h+l|0)|0)|0;h=4-l<<3;m=j;n=(je(c[j>>2]|0)|0)>>>(h>>>0);o=h}if((c[a+8536>>2]|0)==0){if((c[a+8540>>2]|0)==0){p=m;q=n;r=o}else{s=5}}else{s=5}do{if((s|0)==5){h=c[a+8580>>2]|0;j=c[a+15144>>2]|0;l=j+72|0;f=a+1616|0;t=xrc(c[l>>2]|0,c[l+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=t;if((o|0)>(h|0)){u=o-h|0;v=m;w=f|n<<h}else{t=h-o|0;c[m>>2]=je(f>>>(t>>>0)|n<<o|0)|0;u=32-t|0;v=m+4|0;w=f}f=c[a+8584>>2]|0;t=c[j+80>>2]|0;if((u|0)>(f|0)){p=v;q=t|w<<f;r=u-f|0;break}else{j=f-u|0;c[v>>2]=je(t>>>(j>>>0)|w<<u|0)|0;p=v+4|0;q=t;r=32-j|0;break}}}while(0);do{if((c[a+8592>>2]|0)==0){x=p;y=q;z=r}else{v=a+15144|0;u=c[v>>2]|0;w=c[u+120>>2]|0;m=w-1|0;if((r|0)>4){A=p;B=m|q<<4;C=r-4|0;D=u;E=w}else{w=4-r|0;c[p>>2]=je(m>>>(w>>>0)|q<<r|0)|0;u=c[v>>2]|0;A=p+4|0;B=m;C=32-w|0;D=u;E=c[u+120>>2]|0}if((E|0)==0){x=A;y=B;z=C;break}else{F=C;G=B;H=A;I=0;J=D}while(1){u=G<<1;w=F-1|0;if((w|0)==0){c[H>>2]=je(u|0)|0;K=H+4|0;L=32;M=c[v>>2]|0}else{K=H;L=w;M=J}w=I+1|0;if((w|0)<(d[777664+(c[M+120>>2]|0)|0]|0|0)){F=L;G=u;H=K;I=w;J=M}else{x=K;y=u;z=L;break}}}}while(0);L=z&7;if((L|0)==0){N=x;O=y;P=z;Q=P&31;R=O<<Q;S=je(R|0)|0;T=N;c[T>>2]=S;U=P>>3;V=4-U|0;W=N+V|0;X=W;Y=X-k|0;Z=Y<<3;_=(Z|0)/8|0;XMb(b,g,_,1);i=e;return}K=1<<L-1;if((z|0)>(L|0)){N=x;O=K|y<<L;P=z-L|0;Q=P&31;R=O<<Q;S=je(R|0)|0;T=N;c[T>>2]=S;U=P>>3;V=4-U|0;W=N+V|0;X=W;Y=X-k|0;Z=Y<<3;_=(Z|0)/8|0;XMb(b,g,_,1);i=e;return}else{M=L-z|0;c[x>>2]=je(K>>>(M>>>0)|y<<z|0)|0;N=x+4|0;O=K;P=32-M|0;Q=P&31;R=O<<Q;S=je(R|0)|0;T=N;c[T>>2]=S;U=P>>3;V=4-U|0;W=N+V|0;X=W;Y=X-k|0;Z=Y<<3;_=(Z|0)/8|0;XMb(b,g,_,1);i=e;return}}function fNb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;d=i;i=i+104|0;e=d|0;f=a+756|0;g=(c[f>>2]|0)==0;h=g&1;j=e|0;k=e&3;l=e+(-k|0)|0;m=l;n=m&3;if((n|0)==0){o=l;p=0;q=4-k<<3}else{l=e+(-(k+n|0)|0)|0;k=4-n<<3;o=l;p=(je(c[l>>2]|0)|0)>>>(k>>>0);q=k}if((q|0)>0){r=q;s=p;t=o}else{c[o>>2]=je(p<<q|0)|0;r=q+32|0;s=0;t=o+4|0}if((r|0)>1){u=r-1|0;v=t;w=s<<2|2}else{o=1-r|0;c[t>>2]=je(1>>>(o>>>0)|s<<r|0)|0;u=32-o|0;v=t+4|0;w=2}t=u-1|0;do{if((t|0)==0){c[v>>2]=je(w|0)|0;x=32;y=v+4|0;z=c[f>>2]|0;A=11}else{o=c[f>>2]|0;if((t|0)>7){x=t;y=v;z=o;A=11;break}r=8-u|0;c[v>>2]=je(o>>>(r>>>0)|w<<t|0)|0;B=32-r|0;C=v+4|0;D=o}}while(0);if((A|0)==11){B=x-7|0;C=y;D=z|w<<7}w=D<<1|h;h=B-1|0;do{if((h|0)==0){c[C>>2]=je(w|0)|0;E=32;F=C+4|0;A=16}else{if((h|0)>6){E=h;F=C;A=16;break}D=7-B|0;c[C>>2]=je(w<<h|1>>>(D>>>0)|0)|0;G=32-D|0;H=C+4|0;I=2}}while(0);if((A|0)==16){G=E-6|0;H=F;I=w<<7|2}do{if((G|0)==1){c[H>>2]=je(I|0)|0;J=30;K=I<<1;A=22}else{w=I<<1;if((G|0)==2){c[H>>2]=je(w|0)|0;J=31;K=w;A=22;break}w=I<<2;F=G-3|0;if((F|0)!=0){L=H;M=F;N=w;break}c[H>>2]=je(w|0)|0;L=H+4|0;M=32;N=w}}while(0);if((A|0)==22){L=H+4|0;M=J;N=K<<1}if((c[f>>2]|0)==5){O=c[(c[a+15144>>2]|0)+92>>2]&1^1}else{O=0}a=O|N<<1;do{if((M|0)==1){c[L>>2]=je(a|0)|0;P=30;Q=a<<1;A=31}else{N=a<<1;if((M|0)==2){c[L>>2]=je(N|0)|0;P=31;Q=N;A=31;break}N=a<<2;O=M-3|0;if((O|0)!=0){R=L;S=O;T=N;break}c[L>>2]=je(N|0)|0;R=L+4|0;S=32;T=N}}while(0);if((A|0)==31){R=L+4|0;S=P;T=Q<<1}do{if(g){U=R;V=T;W=S}else{if((c[f>>2]|0)==5){U=R;V=T;W=S;break}if((S|0)>4){X=S-4|0;Y=R;Z=T<<4}else{c[R>>2]=je(T<<S|0)|0;X=S+28|0;Y=R+4|0;Z=0}if((X|0)>4){_=X-4|0;$=Y;aa=Z<<4}else{c[Y>>2]=je(Z<<X|0)|0;_=X+28|0;$=Y+4|0;aa=0}if((_|0)>4){ba=_-4|0;ca=$;da=aa<<4}else{c[$>>2]=je(aa<<_|0)|0;ba=_+28|0;ca=$+4|0;da=0}if((ba|0)>4){U=ca;V=da<<4;W=ba-4|0;break}else{c[ca>>2]=je(da<<ba|0)|0;U=ca+4|0;V=0;W=ba+28|0;break}}}while(0);if((W|0)>8){ea=W-8|0;fa=U;ga=V<<8}else{c[U>>2]=je(V<<W|0)|0;ea=W+24|0;fa=U+4|0;ga=0}if((ea|0)>1){ha=ea;ia=ga<<1;ja=fa}else{c[fa>>2]=je(ga<<ea|0)|0;ha=ea+32|0;ia=0;ja=fa+4|0}fa=ha-1|0;if((fa|0)>2){ka=ha-3|0;la=ja;ma=ia<<3|4}else{ea=3-ha|0;c[ja>>2]=je(ia<<fa|2>>>(ea>>>0)|0)|0;ka=32-ea|0;la=ja+4|0;ma=4}ja=ka-1|0;if((ja|0)==0){c[la>>2]=je(ma|0)|0;na=la+4|0;oa=ma;pa=32;qa=pa&31;ra=oa<<qa;sa=je(ra|0)|0;ta=na;c[ta>>2]=sa;ua=pa>>3;va=4-ua|0;wa=na+va|0;xa=wa;ya=xa-m|0;za=ya<<3;Aa=(za|0)/8|0;XMb(b,j,Aa,45);i=d;return}ka=ja&7;if((ka|0)==0){na=la;oa=ma;pa=ja;qa=pa&31;ra=oa<<qa;sa=je(ra|0)|0;ta=na;c[ta>>2]=sa;ua=pa>>3;va=4-ua|0;wa=na+va|0;xa=wa;ya=xa-m|0;za=ya<<3;Aa=(za|0)/8|0;XMb(b,j,Aa,45);i=d;return}ea=1<<ka-1;if((ja|0)>(ka|0)){na=la;oa=ea|ma<<ka;pa=ja-ka|0;qa=pa&31;ra=oa<<qa;sa=je(ra|0)|0;ta=na;c[ta>>2]=sa;ua=pa>>3;va=4-ua|0;wa=na+va|0;xa=wa;ya=xa-m|0;za=ya<<3;Aa=(za|0)/8|0;XMb(b,j,Aa,45);i=d;return}else{fa=ka-ja|0;c[la>>2]=je(ea>>>(fa>>>0)|ma<<ja|0)|0;na=la+4|0;oa=ea;pa=32-fa|0;qa=pa&31;ra=oa<<qa;sa=je(ra|0)|0;ta=na;c[ta>>2]=sa;ua=pa>>3;va=4-ua|0;wa=na+va|0;xa=wa;ya=xa-m|0;za=ya<<3;Aa=(za|0)/8|0;XMb(b,j,Aa,45);i=d;return}}function gNb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;a=b+4|0;e=c[a>>2]|0;f=e&3;if((f|0)==0){g=e}else{h=e+(-f|0)|0;c[a>>2]=h;e=4-f<<3;c[b+16>>2]=e;c[b+12>>2]=(je(c[h>>2]|0)|0)>>>(e>>>0);g=h}if((d|0)>0){h=b+16|0;e=b+12|0;f=0;i=g;j=c[h>>2]|0;while(1){if((j|0)>8){k=c[e>>2]<<8|255;c[e>>2]=k;l=j-8|0;m=i;n=k}else{k=8-j|0;c[i>>2]=je(c[e>>2]<<j|255>>>(k>>>0)|0)|0;o=(c[a>>2]|0)+4|0;c[a>>2]=o;c[e>>2]=255;l=32-k|0;m=o;n=255}c[h>>2]=l;o=f+1|0;if((o|0)<(d|0)){f=o;i=m;j=l}else{p=m;q=n;r=l;break}}}else{p=g;q=c[b+12>>2]|0;r=c[b+16>>2]|0}g=b+12|0;l=q<<1|1;c[g>>2]=l;q=b+16|0;b=r-1|0;c[q>>2]=b;do{if((b|0)==0){c[p>>2]=je(l|0)|0;n=(c[a>>2]|0)+4|0;c[a>>2]=n;c[q>>2]=32;s=c[g>>2]|0;t=32;u=0;v=n}else{n=b&7;if((b|0)>(n|0)){s=l;t=b;u=n;v=p;break}c[p>>2]=je(l<<b|0)|0;m=(c[a>>2]|0)+4|0;c[a>>2]=m;c[g>>2]=0;w=r+31|0;x=n;y=0;z=m;A=w-x|0;c[q>>2]=A;B=A&31;C=y<<B;D=je(C|0)|0;E=z;c[E>>2]=D;F=c[q>>2]|0;G=F>>3;H=4-G|0;I=c[a>>2]|0;J=I+H|0;c[a>>2]=J;c[q>>2]=32;return}}while(0);r=s<<u;c[g>>2]=r;w=t;x=u;y=r;z=v;A=w-x|0;c[q>>2]=A;B=A&31;C=y<<B;D=je(C|0)|0;E=z;c[E>>2]=D;F=c[q>>2]|0;G=F>>3;H=4-G|0;I=c[a>>2]|0;J=I+H|0;c[a>>2]=J;c[q>>2]=32;return}function hNb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;e=i;i=i+104|0;f=e|0;g=f|0;h=f&3;j=f+(-h|0)|0;k=j;l=k&3;if((l|0)==0){m=j;n=0;o=4-h<<3}else{j=f+(-(h+l|0)|0)|0;h=4-l<<3;m=j;n=(je(c[j>>2]|0)|0)>>>(h>>>0)<<1;o=h}h=o-1|0;j=(c[a+8776>>2]|0)+1|0;l=(j|0)>65535;f=l?32:0;p=l?j>>16:j;if((p|0)>255){q=p>>8;r=f|16}else{q=p;r=f}f=(d[16720+q|0]|0)+r>>1;if((h|0)>(f|0)){s=h;t=n<<f;u=m}else{c[m>>2]=je(n<<h|0)|0;s=o+31|0;t=0;u=m+4|0}m=s-f|0;s=f+1|0;if((m|0)>(s|0)){v=m-s|0;w=u;x=t<<s|j}else{f=s-m|0;c[u>>2]=je(j>>>(f>>>0)|t<<m|0)|0;v=32-f|0;w=u+4|0;x=j}do{if((c[a+8424>>2]|0)==0){j=x<<1;u=v-1|0;if((u|0)!=0){y=w;z=j;A=u;break}c[w>>2]=je(j|0)|0;y=w+4|0;z=j;A=32}else{y=w;z=x;A=v}}while(0);v=a+13716|0;x=c[v>>2]|0;w=(x|0)>0|z<<1;z=A-1|0;if((z|0)==0){c[y>>2]=je(w|0)|0;B=y+4|0;C=32;D=c[v>>2]|0}else{B=y;C=z;D=x}do{if((D|0)>0){x=C;z=w;y=B;A=0;while(1){if((x|0)>1){E=x;F=z<<1;G=y}else{c[y>>2]=je(z<<x|0)|0;E=x+32|0;F=0;G=y+4|0}j=E-1|0;if((j|0)>2){H=E-3|0;I=G;J=F<<2|2}else{u=3-E|0;c[G>>2]=je(F<<j|2>>>(u>>>0)|0)|0;H=32-u|0;I=G+4|0;J=2}u=c[a+13720+(A<<3)>>2]|0;j=(u|0)>65535;f=j?32:0;m=j?u>>16:u;if((m|0)>255){K=m>>8;L=f|16}else{K=m;L=f}f=(d[16720+K|0]|0)+L>>1;if((H|0)>(f|0)){M=H;N=J<<f;O=I}else{c[I>>2]=je(J<<H|0)|0;M=H+32|0;N=0;O=I+4|0}m=M-f|0;j=f+1|0;if((m|0)>(j|0)){P=m-j|0;Q=O;R=N<<j|u}else{f=j-m|0;c[O>>2]=je(u>>>(f>>>0)|N<<m|0)|0;P=32-f|0;Q=O+4|0;R=u}u=A+1|0;if((u|0)<(c[v>>2]|0)){x=P;z=R;y=Q;A=u}else{break}}if((P|0)>0){S=P;T=R;U=Q}else{c[Q>>2]=je(R<<P|0)|0;S=P+32|0;T=0;U=Q+4|0}if((S|0)>1){V=U;W=T<<1|1;X=S-1|0;break}else{A=1-S|0;c[U>>2]=je(1>>>(A>>>0)|T<<S|0)|0;V=U+4|0;W=1;X=32-A|0;break}}else{V=B;W=w;X=C}}while(0);C=X&7;if((C|0)==0){Y=V;Z=W;_=X;$=_&31;aa=Z<<$;ba=je(aa|0)|0;ca=Y;c[ca>>2]=ba;da=_>>3;ea=4-da|0;fa=Y+ea|0;ga=fa;ha=ga-k|0;ia=ha<<3;ja=(ia|0)/8|0;XMb(b,g,ja,7);i=e;return}w=1<<C-1;if((X|0)>(C|0)){Y=V;Z=w|W<<C;_=X-C|0;$=_&31;aa=Z<<$;ba=je(aa|0)|0;ca=Y;c[ca>>2]=ba;da=_>>3;ea=4-da|0;fa=Y+ea|0;ga=fa;ha=ga-k|0;ia=ha<<3;ja=(ia|0)/8|0;XMb(b,g,ja,7);i=e;return}else{B=C-X|0;c[V>>2]=je(w>>>(B>>>0)|W<<X|0)|0;Y=V+4|0;Z=w;_=32-B|0;$=_&31;aa=Z<<$;ba=je(aa|0)|0;ca=Y;c[ca>>2]=ba;da=_>>3;ea=4-da|0;fa=Y+ea|0;ga=fa;ha=ga-k|0;ia=ha<<3;ja=(ia|0)/8|0;XMb(b,g,ja,7);i=e;return}}function iNb(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;c=i;i=i+512|0;d=c|0;e=d|0;mrc(e|0,-1|0,497)|0;nrc(e|0,1998160,16)|0;f=d+16|0;y=1145654613;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;a[d+20|0]=19;a[d+22|0]=0;a[d+21|0]=0;a[d+28|0]=20;a[d+36|0]=96;a[d+41|0]=34;XMb(b+1500|0,e,497,5);i=c;return 0}function jNb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;d=i;i=i+6e3|0;f=d|0;if(e>>>0>6e3>>>0){ILb(b,0,2238168,(g=i,i=i+8|0,c[g>>2]=e,g)|0);i=g;h=-1;i=d;return h|0}else{g=f|0;mrc(g|0,-1|0,e|0)|0;nrc(g|0,1998160,16)|0;j=f+16|0;y=1129202006;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;XMb(b+1500|0,g,e,5);h=0;i=d;return h|0}return 0}function kNb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;e=c[a+8416>>2]|0;f=c[a+8420>>2]|0;g=ca(f,e)|0;h=a+8624|0;j=ca(g,c[h>>2]|0)|0;k=c[a+8372>>2]|0;do{if((k|0)>121){l=16}else{if((k|0)==110){l=12;break}l=(k|0)==100?5:4}}while(0);k=a+40|0;m=96192;while(1){n=c[m>>2]|0;if((n|0)==0){break}if((n|0)==(c[k>>2]|0)){break}else{m=m+52|0}}k=c[m+8>>2]|0;do{if((k|0)<(g|0)){o=10}else{n=k<<3;if((n|0)<(ca(e,e)|0)){o=10;break}if((n|0)<(ca(f,f)|0)){o=10}else{p=0}}}while(0);do{if((o|0)==10){if((b|0)==0){p=1;break}ILb(a,1,2197536,(q=i,i=i+24|0,c[q>>2]=e,c[q+8>>2]=f,c[q+16>>2]=k,q)|0);i=q;p=1}}while(0);k=c[m+12>>2]|0;do{if((j|0)>(k|0)){if((b|0)==0){r=1;break}ILb(a,1,2165992,(q=i,i=i+32|0,c[q>>2]=c[h>>2],c[q+8>>2]=j,c[q+16>>2]=(k|0)/(g|0)|0,c[q+24>>2]=k,q)|0);i=q;r=1}else{r=p}}while(0);p=c[a+660>>2]|0;k=(ca(c[m+16>>2]|0,l)|0)/4|0;do{if((p|0)>(k|0)){if((b|0)==0){s=1;break}ILb(a,1,2139712,(q=i,i=i+24|0,c[q>>2]=p,c[q+8>>2]=(p|0)<0|0?-1:0,c[q+16>>2]=k,q)|0);i=q;s=1}else{s=r}}while(0);r=c[a+664>>2]|0;k=(ca(c[m+20>>2]|0,l)|0)/4|0;do{if((r|0)>(k|0)){if((b|0)==0){t=1;break}ILb(a,1,2116328,(q=i,i=i+24|0,c[q>>2]=r,c[q+8>>2]=(r|0)<0|0?-1:0,c[q+16>>2]=k,q)|0);i=q;t=1}else{t=s}}while(0);s=c[a+552>>2]|0;k=c[m+24>>2]|0;do{if((s|0)>(k|0)){if((b|0)==0){u=1;break}ILb(a,1,2634184,(q=i,i=i+24|0,c[q>>2]=s,c[q+8>>2]=(s|0)<0|0?-1:0,c[q+16>>2]=k,q)|0);i=q;u=1}else{u=t}}while(0);t=c[a+160>>2]|0;k=m+48|0;s=c[k>>2]|0;r=(s|0)==0|0;do{if((t|0)>(r|0)){if((b|0)==0){v=1;w=s;break}ILb(a,1,2610464,(q=i,i=i+24|0,c[q>>2]=t,c[q+8>>2]=(t|0)<0|0?-1:0,c[q+16>>2]=r,q)|0);i=q;v=1;w=c[k>>2]|0}else{v=u;w=s}}while(0);s=c[a+808>>2]|0;u=(w|0)==0|0;do{if((s|0)>(u|0)){if((b|0)==0){x=1;break}ILb(a,1,2583984,(q=i,i=i+24|0,c[q>>2]=s,c[q+8>>2]=(s|0)<0|0?-1:0,c[q+16>>2]=u,q)|0);i=q;x=1}else{x=v}}while(0);v=c[a+788>>2]|0;if((v|0)==0){y=x;i=d;return y|0}u=Erc(c[a+784>>2]|0,0,g,(g|0)<0|0?-1:0)|0;g=Crc(u,G,v,0)|0;v=G;u=c[m+4>>2]|0;m=(u|0)<0|0?-1:0;if(!((v|0)>(m|0)|(v|0)==(m|0)&g>>>0>u>>>0)){y=x;i=d;return y|0}if((b|0)==0){y=1;i=d;return y|0}ILb(a,1,2563320,(q=i,i=i+24|0,c[q>>2]=g,c[q+8>>2]=v,c[q+16>>2]=u,q)|0);i=q;y=1;i=d;return y|0}function lNb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=e+24|0;g=c[f>>2]|0;h=e+20|0;i=g+(c[h>>2]|0)|0;j=b+768|0;if((c[j>>2]|0)==0){k=d+4|0}else{if((c[e+8>>2]|0)==0){l=d}else{a[d]=0;l=d+1|0}a[l]=0;a[l+1|0]=0;a[l+2|0]=1;k=l+3|0}a[k]=c[e>>2]<<5|c[e+4>>2];e=(Ee[c[b+38008>>2]&511](k+1|0,g,i)|0)-d|0;i=e-4|0;if((c[j>>2]|0)!=0){c[h>>2]=e;c[f>>2]=d;return}a[d]=i>>>24;a[d+1|0]=i>>>16;a[d+2|0]=i>>>8;a[d+3|0]=i;c[h>>2]=e;c[f>>2]=d;return}function mNb(a,b){a=a|0;b=b|0;mrc(b|0,0,16)|0;c[b>>2]=18;return}function nNb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(c>>>0<d>>>0){a[b]=a[c]|0;e=b+1|0;f=c+1|0}else{e=b;f=c}if(f>>>0<d>>>0){a[e]=a[f]|0;g=e+1|0;h=f+1|0}else{g=e;h=f}if(h>>>0<d>>>0){i=h;j=g}else{k=g;return k|0}while(1){g=a[i]|0;do{if((g&255)>>>0<4>>>0){if((a[j-2|0]|0)!=0){l=j;m=g;break}if((a[j-1|0]|0)!=0){l=j;m=g;break}a[j]=3;l=j+1|0;m=a[i]|0}else{l=j;m=g}}while(0);g=i+1|0;h=l+1|0;a[l]=m;if(g>>>0<d>>>0){i=g;j=h}else{k=h;break}}return k|0}function oNb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(c[b+8632>>2]|0)==3?1024:460;b=0;do{if((b|0)==0){e=107600}else{e=101456+(b-1<<11)|0}f=0;do{g=0;do{h=(ca(a[e+(g<<1)|0]|0,f)|0)>>4;i=h+(a[e+(g<<1)+1|0]|0)|0;if((i|0)<1){j=1}else{j=(i|0)>126?126:i}i=127-j|0;a[3062960+(b*53248|0)+(f<<10)+g|0]=((j|0)<(i|0)?j:i)<<1|j>>>6;g=g+1|0;}while((g|0)<(d|0));f=f+1|0;}while((f|0)<52);b=b+1|0;}while((b|0)<4);return}function pNb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;nrc(b+36|0,3062960+(((d|0)==2?0:f+1|0)*53248|0)+(e<<10)|0,(c[a+8632>>2]|0)==3?1024:460)|0;return}function qNb(a){a=a|0;c[a>>2]=0;c[a+4>>2]=510;c[a+8>>2]=-9;c[a+12>>2]=0;return}function rNb(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=0;c[a+4>>2]=510;c[a+8>>2]=-9;c[a+12>>2]=0;c[a+16>>2]=b;c[a+20>>2]=b;c[a+24>>2]=d;return}function sNb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=b+36+e|0;e=d[g]|0;h=b+4|0;i=c[h>>2]|0;j=d[(i>>6)-4+(100872+(e>>>1<<2))|0]|0;k=i-j|0;c[h>>2]=k;i=b|0;if((e&1|0)!=(f|0)){c[i>>2]=(c[i>>2]|0)+k;c[h>>2]=j}a[g]=a[100552+(e<<1)+f|0]|0;f=c[h>>2]|0;e=d[100808+(f>>3)|0]|0;c[h>>2]=f<<e;f=c[i>>2]<<e;c[i>>2]=f;h=b+8|0;g=(c[h>>2]|0)+e|0;c[h>>2]=g;if(!((g|0)>-1)){return}e=f>>g+10;c[i>>2]=(1024<<g)-1&f;c[h>>2]=g-8;if((e&255|0)==255){g=b+12|0;c[g>>2]=(c[g>>2]|0)+1;return}g=e>>8;h=b+12|0;f=c[h>>2]|0;i=b+20|0;b=(c[i>>2]|0)-1|0;a[b]=(d[b]|0)+g;if((f|0)>0){b=g+255&255;g=f;do{f=c[i>>2]|0;c[i>>2]=f+1;a[f]=b;g=g-1|0;}while((g|0)>0)}g=c[i>>2]|0;c[i>>2]=g+1;a[g]=e;c[h>>2]=0;return}function tNb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b|0;g=(c[b+4>>2]&e)+(c[f>>2]<<1)|0;c[f>>2]=g;e=b+8|0;h=c[e>>2]|0;i=h+1|0;c[e>>2]=i;if(!((i|0)>-1)){return}j=g>>h+11;c[f>>2]=g&(1024<<i)-1;c[e>>2]=h-7;if((j&255|0)==255){h=b+12|0;c[h>>2]=(c[h>>2]|0)+1;return}h=j>>8;e=b+12|0;i=c[e>>2]|0;g=b+20|0;b=(c[g>>2]|0)-1|0;a[b]=(d[b]|0)+h;if((i|0)>0){b=h+255&255;h=i;do{i=c[g>>2]|0;c[g>>2]=i+1;a[i]=b;h=h-1|0;}while((h|0)>0)}h=c[g>>2]|0;c[g>>2]=h+1;a[h]=j;c[e>>2]=0;return}function uNb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=(1<<e)+f|0;f=(rrc(g|0)|0)^31;h=(c[1898688+(f-e<<2)>>2]<<e)+g|0;g=(f<<1|1)-e|0;e=b|0;f=b+4|0;i=b+8|0;j=b+12|0;k=b+20|0;b=(g+7&7)+1|0;l=g;while(1){g=l-b|0;m=(ca(h>>>(g>>>0)&255,c[f>>2]|0)|0)+(c[e>>2]<<b)|0;c[e>>2]=m;n=(c[i>>2]|0)+b|0;c[i>>2]=n;do{if((n|0)>-1){o=m>>n+10;c[e>>2]=m&(1024<<n)-1;c[i>>2]=n-8;if((o&255|0)==255){c[j>>2]=(c[j>>2]|0)+1;break}p=o>>8;q=c[j>>2]|0;r=(c[k>>2]|0)-1|0;a[r]=(d[r]|0)+p;if((q|0)>0){r=p+255&255;p=q;do{q=c[k>>2]|0;c[k>>2]=q+1;a[q]=r;p=p-1|0;}while((p|0)>0)}p=c[k>>2]|0;c[k>>2]=p+1;a[p]=o;c[j>>2]=0}}while(0);if((g|0)>0){b=8;l=g}else{break}}return}function vNb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b+4|0;f=(c[e>>2]|0)-2|0;g=d[100808+(f>>3)|0]|0;c[e>>2]=f<<g;f=b|0;e=c[f>>2]<<g;c[f>>2]=e;h=b+8|0;i=(c[h>>2]|0)+g|0;c[h>>2]=i;if(!((i|0)>-1)){return}g=e>>i+10;c[f>>2]=(1024<<i)-1&e;c[h>>2]=i-8;if((g&255|0)==255){i=b+12|0;c[i>>2]=(c[i>>2]|0)+1;return}i=g>>8;h=b+12|0;e=c[h>>2]|0;f=b+20|0;b=(c[f>>2]|0)-1|0;a[b]=(d[b]|0)+i;if((e|0)>0){b=i+255&255;i=e;do{e=c[f>>2]|0;c[f>>2]=e+1;a[e]=b;i=i-1|0;}while((i|0)>0)}i=c[f>>2]|0;c[f>>2]=i+1;a[i]=g;c[h>>2]=0;return}function wNb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=e|0;g=(c[e+4>>2]|0)+8388606+(c[f>>2]|0)<<9|512;c[f>>2]=g;h=e+8|0;i=c[h>>2]|0;j=i+9|0;c[h>>2]=j;do{if((j|0)>-1){k=g>>i+19;c[f>>2]=g&(1024<<j)-1;l=i+1|0;c[h>>2]=l;if((k&255|0)==255){m=e+12|0;n=(c[m>>2]|0)+1|0;c[m>>2]=n;o=l;p=n}else{n=k>>8;l=e+12|0;m=c[l>>2]|0;q=e+20|0;r=(c[q>>2]|0)-1|0;a[r]=(d[r]|0)+n;if((m|0)>0){r=n+255&255;n=m;do{m=c[q>>2]|0;c[q>>2]=m+1;a[m]=r;n=n-1|0;}while((n|0)>0)}n=c[q>>2]|0;c[q>>2]=n+1;a[n]=k;c[l>>2]=0;o=c[h>>2]|0;p=0}if(!((o|0)>-1)){s=o;break}n=c[f>>2]|0;r=n>>o+10;c[f>>2]=n&(1024<<o)-1;n=o-8|0;c[h>>2]=n;if((r&255|0)==255){c[e+12>>2]=p+1;s=n;break}n=r>>8;m=e+12|0;t=e+20|0;u=(c[t>>2]|0)-1|0;a[u]=(d[u]|0)+n;if((p|0)>0){u=n+255&255;n=p;do{v=c[t>>2]|0;c[t>>2]=v+1;a[v]=u;n=n-1|0;}while((n|0)>0)}n=c[t>>2]|0;c[t>>2]=n+1;a[n]=r;c[m>>2]=0;s=c[h>>2]|0}else{s=j}}while(0);j=c[f>>2]<<-s;c[f>>2]=j;s=(899998965>>>((c[b+1540>>2]&31)>>>0)<<10&1024|j)>>10;c[f>>2]=j&1023;c[h>>2]=-8;if((s&255|0)==255){h=e+12|0;f=(c[h>>2]|0)+1|0;c[h>>2]=f;h=e+12|0;if((f|0)<=0){return}f=e+20|0;do{b=c[f>>2]|0;c[f>>2]=b+1;a[b]=-1;b=(c[h>>2]|0)-1|0;c[h>>2]=b;}while((b|0)>0);return}else{h=j>>18;j=e+12|0;f=c[j>>2]|0;b=e+20|0;e=(c[b>>2]|0)-1|0;a[e]=(d[e]|0)+h;if((f|0)>0){e=h+255&255;h=f;do{f=c[b>>2]|0;c[b>>2]=f+1;a[f]=e;h=h-1|0;}while((h|0)>0)}h=c[b>>2]|0;c[b>>2]=h+1;a[h]=s;c[j>>2]=0;return}}function xNb(a,b){a=a|0;b=b|0;c[b>>2]=152;c[b+4>>2]=434;c[b+8>>2]=2302;c[b+12>>2]=2370;c[b+16>>2]=80;c[b+20>>2]=50;c[b+24>>2]=2254;c[b+28>>2]=2204;c[b+32>>2]=438;c[b+36>>2]=314;c[b+40>>2]=332;c[b+44>>2]=640;c[b+48>>2]=1024;c[b+52>>2]=436;c[b+56>>2]=224;c[b+60>>2]=124;c[b+64>>2]=248;return}function yNb(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+64|0;g=f|0;h=f+32|0;b[g>>1]=(d[c]|0)-(d[e]|0);b[g+2>>1]=(d[c+1|0]|0)-(d[e+1|0]|0);b[g+4>>1]=(d[c+2|0]|0)-(d[e+2|0]|0);b[g+6>>1]=(d[c+3|0]|0)-(d[e+3|0]|0);b[g+8>>1]=(d[c+16|0]|0)-(d[e+32|0]|0);b[g+10>>1]=(d[c+17|0]|0)-(d[e+33|0]|0);b[g+12>>1]=(d[c+18|0]|0)-(d[e+34|0]|0);b[g+14>>1]=(d[c+19|0]|0)-(d[e+35|0]|0);b[g+16>>1]=(d[c+32|0]|0)-(d[e+64|0]|0);b[g+18>>1]=(d[c+33|0]|0)-(d[e+65|0]|0);b[g+20>>1]=(d[c+34|0]|0)-(d[e+66|0]|0);b[g+22>>1]=(d[c+35|0]|0)-(d[e+67|0]|0);b[g+24>>1]=(d[c+48|0]|0)-(d[e+96|0]|0);b[g+26>>1]=(d[c+49|0]|0)-(d[e+97|0]|0);b[g+28>>1]=(d[c+50|0]|0)-(d[e+98|0]|0);b[g+30>>1]=(d[c+51|0]|0)-(d[e+99|0]|0);e=0;while(1){c=e<<2;j=b[g+(c<<1)>>1]|0;k=b[g+((c|3)<<1)>>1]|0;l=k+j|0;m=b[g+((c|1)<<1)>>1]|0;n=b[g+((c|2)<<1)>>1]|0;c=n+m|0;o=j-k|0;k=m-n|0;b[h+(e<<1)>>1]=c+l;b[h+(e+4<<1)>>1]=k+(o<<1);b[h+(e+8<<1)>>1]=l-c;b[h+(e+12<<1)>>1]=o-(k<<1);k=e+1|0;if((k|0)<4){e=k}else{p=0;break}}do{e=p<<2;g=b[h+(e<<1)>>1]|0;k=e|3;o=b[h+(k<<1)>>1]|0;c=o+g|0;l=e|1;n=b[h+(l<<1)>>1]|0;m=e|2;j=b[h+(m<<1)>>1]|0;q=j+n|0;r=g-o|0;o=n-j|0;b[a+(e<<1)>>1]=q+c;b[a+(l<<1)>>1]=o+(r<<1);b[a+(m<<1)>>1]=c-q;b[a+(k<<1)>>1]=r-(o<<1);p=p+1|0;}while((p|0)<4);i=f;return}function zNb(c,e){c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+64|0;g=f|0;h=f+32|0;j=0;while(1){k=b[e+(j<<1)>>1]|0;l=b[e+(j+8<<1)>>1]|0;m=l+k|0;n=k-l|0;l=b[e+(j+4<<1)>>1]|0;k=b[e+(j+12<<1)>>1]|0;o=(k>>1)+l|0;p=(l>>1)-k|0;k=j<<2;b[h+(k<<1)>>1]=o+m;b[h+((k|1)<<1)>>1]=p+n;b[h+((k|2)<<1)>>1]=n-p;b[h+((k|3)<<1)>>1]=m-o;o=j+1|0;if((o|0)<4){j=o}else{q=0;break}}while(1){j=b[h+(q<<1)>>1]|0;e=q+8|0;o=b[h+(e<<1)>>1]|0;m=q+4|0;k=b[h+(m<<1)>>1]|0;p=q+12|0;n=b[h+(p<<1)>>1]|0;l=(n>>1)+k|0;r=(k>>1)-n|0;n=o+j+32|0;b[g+(q<<1)>>1]=(n+l|0)>>>6;k=j-o+32|0;b[g+(m<<1)>>1]=(k+r|0)>>>6;b[g+(e<<1)>>1]=(k-r|0)>>>6;b[g+(p<<1)>>1]=(n-l|0)>>>6;l=q+1|0;if((l|0)<4){q=l}else{s=c;t=0;break}}while(1){c=t<<2;q=(b[g+(c<<1)>>1]|0)+(d[s]|0)|0;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[s]=u;q=s+1|0;h=(b[g+((c|1)<<1)>>1]|0)+(d[q]|0)|0;if(h>>>0>255>>>0){v=-h>>31&255}else{v=h&255}a[q]=v;q=s+2|0;h=(b[g+((c|2)<<1)>>1]|0)+(d[q]|0)|0;if(h>>>0>255>>>0){w=-h>>31&255}else{w=h&255}a[q]=w;q=s+3|0;h=(b[g+((c|3)<<1)>>1]|0)+(d[q]|0)|0;if(h>>>0>255>>>0){x=-h>>31&255}else{x=h&255}a[q]=x;q=t+1|0;if((q|0)<4){s=s+32|0;t=q}else{break}}i=f;return}function ANb(a,b,c){a=a|0;b=b|0;c=c|0;yNb(a|0,b,c);yNb(a+32|0,b+4|0,c+4|0);yNb(a+64|0,b+64|0,c+128|0);yNb(a+96|0,b+68|0,c+132|0);return}function BNb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=($Nb(c,d)|0)&65535;b[a>>1]=e;f=($Nb(c+4|0,d+4|0)|0)&65535;g=a+2|0;b[g>>1]=f;h=($Nb(c+64|0,d+128|0)|0)&65535;i=a+4|0;b[i>>1]=h;j=e<<16>>16;e=f<<16>>16;f=e+j|0;k=h<<16>>16;h=($Nb(c+68|0,d+132|0)|0)<<16>>16;d=k+h|0;c=j-e|0;e=k-h|0;b[a>>1]=d+f;b[g>>1]=f-d;b[i>>1]=e+c;b[a+6>>1]=c-e;return}function CNb(a,b){a=a|0;b=b|0;zNb(a,b|0);zNb(a+4|0,b+32|0);zNb(a+128|0,b+64|0);zNb(a+132|0,b+96|0);return}function DNb(c,e){c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=((b[e>>1]|0)+32|0)>>>6<<16>>16;g=c;h=0;while(1){i=(d[g]|0)+f|0;if(i>>>0>255>>>0){j=-i>>31&255}else{j=i&255}a[g]=j;i=g+1|0;k=(d[i]|0)+f|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i]=l;i=g+2|0;k=(d[i]|0)+f|0;if(k>>>0>255>>>0){m=-k>>31&255}else{m=k&255}a[i]=m;i=g+3|0;k=(d[i]|0)+f|0;if(k>>>0>255>>>0){n=-k>>31&255}else{n=k&255}a[i]=n;i=h+1|0;if((i|0)<4){g=g+32|0;h=i}else{break}}h=((b[e+2>>1]|0)+32|0)>>>6<<16>>16;g=c+4|0;n=0;while(1){f=(d[g]|0)+h|0;if(f>>>0>255>>>0){o=-f>>31&255}else{o=f&255}a[g]=o;f=g+1|0;m=(d[f]|0)+h|0;if(m>>>0>255>>>0){p=-m>>31&255}else{p=m&255}a[f]=p;f=g+2|0;m=(d[f]|0)+h|0;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[f]=q;f=g+3|0;m=(d[f]|0)+h|0;if(m>>>0>255>>>0){r=-m>>31&255}else{r=m&255}a[f]=r;f=n+1|0;if((f|0)<4){g=g+32|0;n=f}else{break}}n=((b[e+4>>1]|0)+32|0)>>>6<<16>>16;g=c+128|0;r=0;while(1){h=(d[g]|0)+n|0;if(h>>>0>255>>>0){s=-h>>31&255}else{s=h&255}a[g]=s;h=g+1|0;q=(d[h]|0)+n|0;if(q>>>0>255>>>0){t=-q>>31&255}else{t=q&255}a[h]=t;h=g+2|0;q=(d[h]|0)+n|0;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[h]=u;h=g+3|0;q=(d[h]|0)+n|0;if(q>>>0>255>>>0){v=-q>>31&255}else{v=q&255}a[h]=v;h=r+1|0;if((h|0)<4){g=g+32|0;r=h}else{break}}r=((b[e+6>>1]|0)+32|0)>>>6<<16>>16;e=c+132|0;c=0;while(1){g=(d[e]|0)+r|0;if(g>>>0>255>>>0){w=-g>>31&255}else{w=g&255}a[e]=w;g=e+1|0;v=(d[g]|0)+r|0;if(v>>>0>255>>>0){x=-v>>31&255}else{x=v&255}a[g]=x;g=e+2|0;v=(d[g]|0)+r|0;if(v>>>0>255>>>0){y=-v>>31&255}else{y=v&255}a[g]=y;g=e+3|0;v=(d[g]|0)+r|0;if(v>>>0>255>>>0){z=-v>>31&255}else{z=v&255}a[g]=z;g=c+1|0;if((g|0)<4){e=e+32|0;c=g}else{break}}return}function ENb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=$Nb(c,d)|0;f=$Nb(c+4|0,d+4|0)|0;g=$Nb(c+64|0,d+128|0)|0;h=$Nb(c+68|0,d+132|0)|0;i=$Nb(c+128|0,d+256|0)|0;j=$Nb(c+132|0,d+260|0)|0;k=$Nb(c+192|0,d+384|0)|0;l=$Nb(c+196|0,d+388|0)|0;d=f+e|0;c=h+g|0;m=j+i|0;n=l+k|0;o=e-f|0;f=g-h|0;h=i-j|0;j=k-l|0;l=c+d|0;k=n+m|0;i=f+o|0;g=j+h|0;e=d-c|0;c=m-n|0;n=o-f|0;f=h-j|0;b[a>>1]=k+l;b[a+2>>1]=g+i;b[a+4>>1]=l-k;b[a+6>>1]=i-g;b[a+8>>1]=e-c;b[a+10>>1]=n-f;b[a+12>>1]=c+e;b[a+14>>1]=f+n;return}function FNb(a,b,c){a=a|0;b=b|0;c=c|0;yNb(a|0,b,c);yNb(a+32|0,b+4|0,c+4|0);yNb(a+64|0,b+64|0,c+128|0);yNb(a+96|0,b+68|0,c+132|0);yNb(a+128|0,b+8|0,c+8|0);yNb(a+160|0,b+12|0,c+12|0);yNb(a+192|0,b+72|0,c+136|0);yNb(a+224|0,b+76|0,c+140|0);yNb(a+256|0,b+128|0,c+256|0);yNb(a+288|0,b+132|0,c+260|0);yNb(a+320|0,b+192|0,c+384|0);yNb(a+352|0,b+196|0,c+388|0);yNb(a+384|0,b+136|0,c+264|0);yNb(a+416|0,b+140|0,c+268|0);yNb(a+448|0,b+200|0,c+392|0);yNb(a+480|0,b+204|0,c+396|0);return}function GNb(a,b){a=a|0;b=b|0;zNb(a,b|0);zNb(a+4|0,b+32|0);zNb(a+128|0,b+64|0);zNb(a+132|0,b+96|0);zNb(a+8|0,b+128|0);zNb(a+12|0,b+160|0);zNb(a+136|0,b+192|0);zNb(a+140|0,b+224|0);zNb(a+256|0,b+256|0);zNb(a+260|0,b+288|0);zNb(a+384|0,b+320|0);zNb(a+388|0,b+352|0);zNb(a+264|0,b+384|0);zNb(a+268|0,b+416|0);zNb(a+392|0,b+448|0);zNb(a+396|0,b+480|0);return}function HNb(c,e){c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=c;c=e;e=0;while(1){g=((b[c>>1]|0)+32|0)>>>6<<16>>16;h=f;i=0;while(1){j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;j=h+1|0;l=(d[j]|0)+g|0;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[j]=m;j=h+2|0;l=(d[j]|0)+g|0;if(l>>>0>255>>>0){n=-l>>31&255}else{n=l&255}a[j]=n;j=h+3|0;l=(d[j]|0)+g|0;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[j]=o;j=i+1|0;if((j|0)<4){h=h+32|0;i=j}else{break}}i=((b[c+2>>1]|0)+32|0)>>>6<<16>>16;h=f+4|0;g=0;while(1){j=(d[h]|0)+i|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;j=h+1|0;l=(d[j]|0)+i|0;if(l>>>0>255>>>0){q=-l>>31&255}else{q=l&255}a[j]=q;j=h+2|0;l=(d[j]|0)+i|0;if(l>>>0>255>>>0){r=-l>>31&255}else{r=l&255}a[j]=r;j=h+3|0;l=(d[j]|0)+i|0;if(l>>>0>255>>>0){s=-l>>31&255}else{s=l&255}a[j]=s;j=g+1|0;if((j|0)<4){h=h+32|0;g=j}else{break}}g=((b[c+4>>1]|0)+32|0)>>>6<<16>>16;h=f+8|0;i=0;while(1){j=(d[h]|0)+g|0;if(j>>>0>255>>>0){t=-j>>31&255}else{t=j&255}a[h]=t;j=h+1|0;l=(d[j]|0)+g|0;if(l>>>0>255>>>0){u=-l>>31&255}else{u=l&255}a[j]=u;j=h+2|0;l=(d[j]|0)+g|0;if(l>>>0>255>>>0){v=-l>>31&255}else{v=l&255}a[j]=v;j=h+3|0;l=(d[j]|0)+g|0;if(l>>>0>255>>>0){w=-l>>31&255}else{w=l&255}a[j]=w;j=i+1|0;if((j|0)<4){h=h+32|0;i=j}else{break}}i=((b[c+6>>1]|0)+32|0)>>>6<<16>>16;h=f+12|0;g=0;while(1){j=(d[h]|0)+i|0;if(j>>>0>255>>>0){x=-j>>31&255}else{x=j&255}a[h]=x;j=h+1|0;l=(d[j]|0)+i|0;if(l>>>0>255>>>0){y=-l>>31&255}else{y=l&255}a[j]=y;j=h+2|0;l=(d[j]|0)+i|0;if(l>>>0>255>>>0){z=-l>>31&255}else{z=l&255}a[j]=z;j=h+3|0;l=(d[j]|0)+i|0;if(l>>>0>255>>>0){A=-l>>31&255}else{A=l&255}a[j]=A;j=g+1|0;if((j|0)<4){h=h+32|0;g=j}else{break}}g=e+1|0;if((g|0)<4){f=f+128|0;c=c+8|0;e=g}else{break}}return}function INb(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+128|0;g=f|0;h=e;e=c;c=0;while(1){j=c<<3;b[g+(j<<1)>>1]=(d[e]|0)-(d[h]|0);b[g+((j|1)<<1)>>1]=(d[e+1|0]|0)-(d[h+1|0]|0);b[g+((j|2)<<1)>>1]=(d[e+2|0]|0)-(d[h+2|0]|0);b[g+((j|3)<<1)>>1]=(d[e+3|0]|0)-(d[h+3|0]|0);b[g+((j|4)<<1)>>1]=(d[e+4|0]|0)-(d[h+4|0]|0);b[g+((j|5)<<1)>>1]=(d[e+5|0]|0)-(d[h+5|0]|0);b[g+((j|6)<<1)>>1]=(d[e+6|0]|0)-(d[h+6|0]|0);b[g+((j|7)<<1)>>1]=(d[e+7|0]|0)-(d[h+7|0]|0);j=c+1|0;if((j|0)<8){h=h+32|0;e=e+16|0;c=j}else{k=0;break}}while(1){c=g+(k<<1)|0;e=b[c>>1]|0;h=g+(k+56<<1)|0;j=b[h>>1]|0;l=j+e|0;m=g+(k+8<<1)|0;n=b[m>>1]|0;o=g+(k+48<<1)|0;p=b[o>>1]|0;q=p+n|0;r=g+(k+16<<1)|0;s=b[r>>1]|0;t=g+(k+40<<1)|0;u=b[t>>1]|0;v=u+s|0;w=g+(k+24<<1)|0;x=b[w>>1]|0;y=g+(k+32<<1)|0;z=b[y>>1]|0;A=z+x|0;B=A+l|0;C=v+q|0;D=l-A|0;A=q-v|0;v=e-j|0;j=n-p|0;p=s-u|0;u=x-z|0;z=(v>>1)+v+j+p|0;x=v-u-((p>>1)+p)|0;s=v-j-(j>>1)+u|0;v=u+(j-p)+(u>>1)|0;b[c>>1]=B+C;b[m>>1]=(v>>>2)+z;b[r>>1]=D+(A>>>1);b[w>>1]=x+(s>>>2);b[y>>1]=B-C;b[t>>1]=s-(x>>>2);b[o>>1]=(D>>>1)-A;b[h>>1]=(z>>>2)-v;v=k+1|0;if((v|0)<8){k=v}else{E=0;break}}do{k=E<<3;v=b[g+(k<<1)>>1]|0;z=b[g+((k|7)<<1)>>1]|0;h=z+v|0;A=b[g+((k|1)<<1)>>1]|0;D=b[g+((k|6)<<1)>>1]|0;o=D+A|0;x=b[g+((k|2)<<1)>>1]|0;s=b[g+((k|5)<<1)>>1]|0;t=s+x|0;C=b[g+((k|3)<<1)>>1]|0;B=b[g+((k|4)<<1)>>1]|0;k=B+C|0;y=k+h|0;w=t+o|0;r=h-k|0;k=o-t|0;t=v-z|0;z=A-D|0;D=x-s|0;s=C-B|0;B=(t>>1)+t+z+D|0;C=t-s-((D>>1)+D)|0;x=t-z-(z>>1)+s|0;t=s+(z-D)+(s>>1)|0;b[a+(E<<1)>>1]=y+w;b[a+(E+8<<1)>>1]=(t>>>2)+B;b[a+(E+16<<1)>>1]=r+(k>>>1);b[a+(E+24<<1)>>1]=C+(x>>>2);b[a+(E+32<<1)>>1]=y-w;b[a+(E+40<<1)>>1]=x-(C>>>2);b[a+(E+48<<1)>>1]=(r>>>1)-k;b[a+(E+56<<1)>>1]=(B>>>2)-t;E=E+1|0;}while((E|0)<8);i=f;return}function JNb(c,e){c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=(b[e>>1]|0)+32&65535;b[e>>1]=f;g=0;h=f;while(1){f=h<<16>>16;i=e+(g+32<<1)|0;j=b[i>>1]|0;k=j+f|0;l=f-j|0;j=e+(g+16<<1)|0;f=b[j>>1]|0;m=e+(g+48<<1)|0;n=b[m>>1]|0;o=(f>>1)-n|0;p=(n>>1)+f|0;f=p+k|0;n=o+l|0;q=l-o|0;o=k-p|0;p=e+(g+24<<1)|0;k=b[p>>1]|0;l=e+(g+40<<1)|0;r=b[l>>1]|0;s=e+(g+56<<1)|0;t=b[s>>1]|0;u=r-k-t-(t>>1)|0;v=e+(g+8<<1)|0;w=b[v>>1]|0;x=t-((k>>1)+k)+w|0;y=t+r+(r>>1)-w|0;t=r+k+w+(w>>1)|0;w=(t>>2)+u|0;k=(y>>2)+x|0;r=(x>>2)-y|0;y=t-(u>>2)|0;b[e+(g<<1)>>1]=y+f;b[v>>1]=r+n;b[j>>1]=k+q;b[p>>1]=w+o;b[i>>1]=o-w;b[l>>1]=q-k;b[m>>1]=n-r;b[s>>1]=f-y;y=g+1|0;if((y|0)>=8){z=0;break}g=y;h=b[e+(y<<1)>>1]|0}do{h=z<<3;g=b[e+(h<<1)>>1]|0;y=b[e+((h|4)<<1)>>1]|0;f=y+g|0;s=g-y|0;y=b[e+((h|2)<<1)>>1]|0;g=b[e+((h|6)<<1)>>1]|0;r=(y>>1)-g|0;n=(g>>1)+y|0;y=n+f|0;g=r+s|0;m=s-r|0;r=f-n|0;n=b[e+((h|3)<<1)>>1]|0;f=b[e+((h|5)<<1)>>1]|0;s=b[e+((h|7)<<1)>>1]|0;k=f-n-s-(s>>1)|0;q=b[e+((h|1)<<1)>>1]|0;h=s-((n>>1)+n)+q|0;l=s+f+(f>>1)-q|0;s=f+n+q+(q>>1)|0;q=(s>>2)+k|0;n=(l>>2)+h|0;f=(h>>2)-l|0;l=s-(k>>2)|0;k=c+z|0;s=(l+y>>6)+(d[k]|0)|0;if(s>>>0>255>>>0){A=-s>>31&255}else{A=s&255}a[k]=A;k=c+(z+32)|0;s=(d[k]|0)+(f+g>>6)|0;if(s>>>0>255>>>0){B=-s>>31&255}else{B=s&255}a[k]=B;k=c+(z+64)|0;s=(d[k]|0)+(n+m>>6)|0;if(s>>>0>255>>>0){C=-s>>31&255}else{C=s&255}a[k]=C;k=c+(z+96)|0;s=(d[k]|0)+(q+r>>6)|0;if(s>>>0>255>>>0){D=-s>>31&255}else{D=s&255}a[k]=D;k=c+(z+128)|0;s=(d[k]|0)+(r-q>>6)|0;if(s>>>0>255>>>0){E=-s>>31&255}else{E=s&255}a[k]=E;k=c+(z+160)|0;s=(d[k]|0)+(m-n>>6)|0;if(s>>>0>255>>>0){F=-s>>31&255}else{F=s&255}a[k]=F;k=c+(z+192)|0;s=(d[k]|0)+(g-f>>6)|0;if(s>>>0>255>>>0){G=-s>>31&255}else{G=s&255}a[k]=G;k=c+(z+224)|0;s=(d[k]|0)+(y-l>>6)|0;if(s>>>0>255>>>0){H=-s>>31&255}else{H=s&255}a[k]=H;z=z+1|0;}while((z|0)<8);return}function KNb(a,b,c){a=a|0;b=b|0;c=c|0;INb(a|0,b,c);INb(a+128|0,b+8|0,c+8|0);INb(a+256|0,b+128|0,c+256|0);INb(a+384|0,b+136|0,c+264|0);return}function LNb(a,b){a=a|0;b=b|0;JNb(a,b|0);JNb(a+8|0,b+128|0);JNb(a+256|0,b+256|0);JNb(a+264|0,b+384|0);return}function MNb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=i;i=i+32|0;d=c|0;e=0;while(1){f=e<<2;g=b[a+(f<<1)>>1]|0;h=b[a+((f|1)<<1)>>1]|0;j=h+g|0;k=g-h|0;h=b[a+((f|2)<<1)>>1]|0;g=b[a+((f|3)<<1)>>1]|0;f=g+h|0;l=h-g|0;b[d+(e<<1)>>1]=f+j;b[d+(e+4<<1)>>1]=j-f;b[d+(e+8<<1)>>1]=k-l;b[d+(e+12<<1)>>1]=l+k;k=e+1|0;if((k|0)<4){e=k}else{m=0;break}}do{e=m<<2;k=b[d+(e<<1)>>1]|0;l=e|1;f=b[d+(l<<1)>>1]|0;j=e|2;g=b[d+(j<<1)>>1]|0;h=e|3;n=b[d+(h<<1)>>1]|0;o=n+g|0;p=g-n|0;n=f+k+1|0;b[a+(e<<1)>>1]=(n+o|0)>>>1;b[a+(l<<1)>>1]=(n-o|0)>>>1;o=k-f+1|0;b[a+(j<<1)>>1]=(o-p|0)>>>1;b[a+(h<<1)>>1]=(o+p|0)>>>1;m=m+1|0;}while((m|0)<4);i=c;return}function NNb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=i;i=i+32|0;d=c|0;e=0;while(1){f=e<<2;g=b[a+(f<<1)>>1]|0;h=b[a+((f|1)<<1)>>1]|0;j=h+g|0;k=g-h|0;h=b[a+((f|2)<<1)>>1]|0;g=b[a+((f|3)<<1)>>1]|0;f=g+h|0;l=h-g|0;b[d+(e<<1)>>1]=f+j;b[d+(e+4<<1)>>1]=j-f;b[d+(e+8<<1)>>1]=k-l;b[d+(e+12<<1)>>1]=l+k;k=e+1|0;if((k|0)<4){e=k}else{m=0;break}}do{e=m<<2;k=b[d+(e<<1)>>1]|0;l=e|1;f=b[d+(l<<1)>>1]|0;j=f+k|0;g=k-f|0;f=e|2;k=b[d+(f<<1)>>1]|0;h=e|3;n=b[d+(h<<1)>>1]|0;o=n+k|0;p=k-n|0;b[a+(e<<1)>>1]=o+j;b[a+(l<<1)>>1]=j-o;b[a+(f<<1)>>1]=g-p;b[a+(h<<1)>>1]=p+g;m=m+1|0;}while((m|0)<4);i=c;return}function ONb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c|0;e=b[d>>1]|0;f=c+32|0;g=b[f>>1]|0;h=g+e|0;i=c+64|0;j=b[i>>1]|0;k=c+96|0;l=b[k>>1]|0;m=l+j|0;n=c+128|0;o=b[n>>1]|0;p=c+160|0;q=b[p>>1]|0;r=q+o|0;s=c+192|0;t=b[s>>1]|0;u=c+224|0;c=b[u>>1]|0;v=c+t|0;w=e-g|0;g=j-l|0;l=o-q|0;q=t-c|0;c=m+h|0;t=v+r|0;o=g+w|0;j=q+l|0;e=h-m|0;m=r-v|0;v=w-g|0;g=l-q|0;b[a>>1]=t+c;b[a+2>>1]=j+o;b[a+4>>1]=c-t;b[a+6>>1]=o-j;b[a+8>>1]=e-m;b[a+10>>1]=v-g;b[a+12>>1]=m+e;b[a+14>>1]=g+v;b[d>>1]=0;b[f>>1]=0;b[i>>1]=0;b[k>>1]=0;b[n>>1]=0;b[p>>1]=0;b[s>>1]=0;b[u>>1]=0;return}function PNb(a,b,d){a=a|0;b=b|0;d=d|0;c[d>>2]=386;c[b>>2]=184;c[d+4>>2]=254;c[b+4>>2]=464;c[d+8>>2]=42;c[b+8>>2]=192;c[d+12>>2]=4;c[b+12>>2]=94;c[d+16>>2]=296;c[b+16>>2]=520;c[b+20>>2]=394;c[d+20>>2]=394;return}function QNb(a,c){a=a|0;c=c|0;b[a>>1]=b[c>>1]|0;b[a+2>>1]=b[c+2>>1]|0;b[a+4>>1]=b[c+4>>1]|0;b[a+6>>1]=b[c+16>>1]|0;b[a+8>>1]=b[c+18>>1]|0;b[a+10>>1]=b[c+6>>1]|0;b[a+12>>1]=b[c+8>>1]|0;b[a+14>>1]=b[c+20>>1]|0;b[a+16>>1]=b[c+32>>1]|0;b[a+18>>1]=b[c+22>>1]|0;b[a+20>>1]=b[c+10>>1]|0;b[a+22>>1]=b[c+12>>1]|0;b[a+24>>1]=b[c+14>>1]|0;b[a+26>>1]=b[c+24>>1]|0;b[a+28>>1]=b[c+34>>1]|0;b[a+30>>1]=b[c+48>>1]|0;b[a+32>>1]=b[c+36>>1]|0;b[a+34>>1]=b[c+26>>1]|0;b[a+36>>1]=b[c+28>>1]|0;b[a+38>>1]=b[c+30>>1]|0;b[a+40>>1]=b[c+38>>1]|0;b[a+42>>1]=b[c+50>>1]|0;b[a+44>>1]=b[c+64>>1]|0;b[a+46>>1]=b[c+52>>1]|0;b[a+48>>1]=b[c+40>>1]|0;b[a+50>>1]=b[c+42>>1]|0;b[a+52>>1]=b[c+44>>1]|0;b[a+54>>1]=b[c+46>>1]|0;b[a+56>>1]=b[c+54>>1]|0;b[a+58>>1]=b[c+66>>1]|0;b[a+60>>1]=b[c+80>>1]|0;b[a+62>>1]=b[c+68>>1]|0;b[a+64>>1]=b[c+56>>1]|0;b[a+66>>1]=b[c+58>>1]|0;b[a+68>>1]=b[c+60>>1]|0;b[a+70>>1]=b[c+62>>1]|0;b[a+72>>1]=b[c+70>>1]|0;b[a+74>>1]=b[c+82>>1]|0;b[a+76>>1]=b[c+96>>1]|0;b[a+78>>1]=b[c+84>>1]|0;b[a+80>>1]=b[c+72>>1]|0;b[a+82>>1]=b[c+74>>1]|0;b[a+84>>1]=b[c+76>>1]|0;b[a+86>>1]=b[c+78>>1]|0;b[a+88>>1]=b[c+86>>1]|0;b[a+90>>1]=b[c+98>>1]|0;b[a+92>>1]=b[c+100>>1]|0;b[a+94>>1]=b[c+88>>1]|0;b[a+96>>1]=b[c+90>>1]|0;b[a+98>>1]=b[c+92>>1]|0;b[a+100>>1]=b[c+94>>1]|0;b[a+102>>1]=b[c+102>>1]|0;b[a+104>>1]=b[c+112>>1]|0;b[a+106>>1]=b[c+114>>1]|0;b[a+108>>1]=b[c+104>>1]|0;b[a+110>>1]=b[c+106>>1]|0;b[a+112>>1]=b[c+108>>1]|0;b[a+114>>1]=b[c+110>>1]|0;b[a+116>>1]=b[c+116>>1]|0;b[a+118>>1]=b[c+118>>1]|0;b[a+120>>1]=b[c+120>>1]|0;b[a+122>>1]=b[c+122>>1]|0;b[a+124>>1]=b[c+124>>1]|0;b[a+126>>1]=b[c+126>>1]|0;return}function RNb(a,c){a=a|0;c=c|0;b[a>>1]=b[c>>1]|0;b[a+2>>1]=b[c+16>>1]|0;b[a+4>>1]=b[c+2>>1]|0;b[a+6>>1]=b[c+4>>1]|0;b[a+8>>1]=b[c+18>>1]|0;b[a+10>>1]=b[c+32>>1]|0;b[a+12>>1]=b[c+48>>1]|0;b[a+14>>1]=b[c+34>>1]|0;b[a+16>>1]=b[c+20>>1]|0;b[a+18>>1]=b[c+6>>1]|0;b[a+20>>1]=b[c+8>>1]|0;b[a+22>>1]=b[c+22>>1]|0;b[a+24>>1]=b[c+36>>1]|0;b[a+26>>1]=b[c+50>>1]|0;b[a+28>>1]=b[c+64>>1]|0;b[a+30>>1]=b[c+80>>1]|0;b[a+32>>1]=b[c+66>>1]|0;b[a+34>>1]=b[c+52>>1]|0;b[a+36>>1]=b[c+38>>1]|0;b[a+38>>1]=b[c+24>>1]|0;b[a+40>>1]=b[c+10>>1]|0;b[a+42>>1]=b[c+12>>1]|0;b[a+44>>1]=b[c+26>>1]|0;b[a+46>>1]=b[c+40>>1]|0;b[a+48>>1]=b[c+54>>1]|0;b[a+50>>1]=b[c+68>>1]|0;b[a+52>>1]=b[c+82>>1]|0;b[a+54>>1]=b[c+96>>1]|0;b[a+56>>1]=b[c+112>>1]|0;b[a+58>>1]=b[c+98>>1]|0;b[a+60>>1]=b[c+84>>1]|0;b[a+62>>1]=b[c+70>>1]|0;b[a+64>>1]=b[c+56>>1]|0;b[a+66>>1]=b[c+42>>1]|0;b[a+68>>1]=b[c+28>>1]|0;b[a+70>>1]=b[c+14>>1]|0;b[a+72>>1]=b[c+30>>1]|0;b[a+74>>1]=b[c+44>>1]|0;b[a+76>>1]=b[c+58>>1]|0;b[a+78>>1]=b[c+72>>1]|0;b[a+80>>1]=b[c+86>>1]|0;b[a+82>>1]=b[c+100>>1]|0;b[a+84>>1]=b[c+114>>1]|0;b[a+86>>1]=b[c+116>>1]|0;b[a+88>>1]=b[c+102>>1]|0;b[a+90>>1]=b[c+88>>1]|0;b[a+92>>1]=b[c+74>>1]|0;b[a+94>>1]=b[c+60>>1]|0;b[a+96>>1]=b[c+46>>1]|0;b[a+98>>1]=b[c+62>>1]|0;b[a+100>>1]=b[c+76>>1]|0;b[a+102>>1]=b[c+90>>1]|0;b[a+104>>1]=b[c+104>>1]|0;b[a+106>>1]=b[c+118>>1]|0;b[a+108>>1]=b[c+120>>1]|0;b[a+110>>1]=b[c+106>>1]|0;b[a+112>>1]=b[c+92>>1]|0;b[a+114>>1]=b[c+78>>1]|0;b[a+116>>1]=b[c+94>>1]|0;b[a+118>>1]=b[c+108>>1]|0;b[a+120>>1]=b[c+122>>1]|0;b[a+122>>1]=b[c+124>>1]|0;b[a+124>>1]=b[c+110>>1]|0;b[a+126>>1]=b[c+126>>1]|0;return}function SNb(a,c){a=a|0;c=c|0;var d=0,f=0;d=c;f=a;y=e[d>>1]|e[d+2>>1]<<16;b[f>>1]=y;b[f+2>>1]=y>>16;b[a+4>>1]=b[c+8>>1]|0;b[a+6>>1]=b[c+4>>1]|0;b[a+8>>1]=b[c+6>>1]|0;b[a+10>>1]=b[c+10>>1]|0;nrc(a+12|0,c+12|0,20)|0;return}function TNb(a,c){a=a|0;c=c|0;b[a>>1]=b[c>>1]|0;b[a+2>>1]=b[c+8>>1]|0;b[a+4>>1]=b[c+2>>1]|0;b[a+6>>1]=b[c+4>>1]|0;b[a+8>>1]=b[c+10>>1]|0;b[a+10>>1]=b[c+16>>1]|0;b[a+12>>1]=b[c+24>>1]|0;b[a+14>>1]=b[c+18>>1]|0;b[a+16>>1]=b[c+12>>1]|0;b[a+18>>1]=b[c+6>>1]|0;b[a+20>>1]=b[c+14>>1]|0;b[a+22>>1]=b[c+20>>1]|0;b[a+24>>1]=b[c+26>>1]|0;b[a+26>>1]=b[c+28>>1]|0;b[a+28>>1]=b[c+22>>1]|0;b[a+30>>1]=b[c+30>>1]|0;return}function UNb(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;g=(d[e]|0)-(d[f]|0)&65535;b[a>>1]=g;h=e+16|0;i=f+32|0;j=(d[h]|0)-(d[i]|0)&65535;b[a+2>>1]=j;k=e+32|0;l=f+64|0;m=(d[k]|0)-(d[l]|0)&65535;b[a+4>>1]=m;n=(d[e+1|0]|0)-(d[f+1|0]|0)&65535;b[a+6>>1]=n;o=(d[e+17|0]|0)-(d[f+33|0]|0)&65535;b[a+8>>1]=o;p=e+48|0;q=f+96|0;r=(d[p]|0)-(d[q]|0)&65535;b[a+10>>1]=r;s=e+64|0;t=f+128|0;u=(d[s]|0)-(d[t]|0)&65535;b[a+12>>1]=u;v=(d[e+33|0]|0)-(d[f+65|0]|0)&65535;b[a+14>>1]=v;w=(d[e+2|0]|0)-(d[f+2|0]|0)&65535;b[a+16>>1]=w;x=(d[e+49|0]|0)-(d[f+97|0]|0)&65535;b[a+18>>1]=x;y=e+80|0;z=f+160|0;A=(d[y]|0)-(d[z]|0)&65535;b[a+20>>1]=A;B=e+96|0;C=f+192|0;D=(d[B]|0)-(d[C]|0)&65535;b[a+22>>1]=D;E=e+112|0;F=f+224|0;G=(d[E]|0)-(d[F]|0)&65535;b[a+24>>1]=G;H=(d[e+65|0]|0)-(d[f+129|0]|0)&65535;b[a+26>>1]=H;I=(d[e+18|0]|0)-(d[f+34|0]|0)&65535;b[a+28>>1]=I;J=(d[e+3|0]|0)-(d[f+3|0]|0)&65535;b[a+30>>1]=J;K=(d[e+34|0]|0)-(d[f+66|0]|0)&65535;b[a+32>>1]=K;L=(d[e+81|0]|0)-(d[f+161|0]|0)&65535;b[a+34>>1]=L;M=(d[e+97|0]|0)-(d[f+193|0]|0)&65535;b[a+36>>1]=M;N=(d[e+113|0]|0)-(d[f+225|0]|0)&65535;b[a+38>>1]=N;O=(d[e+50|0]|0)-(d[f+98|0]|0)&65535;b[a+40>>1]=O;P=(d[e+19|0]|0)-(d[f+35|0]|0)&65535;b[a+42>>1]=P;Q=e+4|0;R=f+4|0;S=(d[Q]|0)-(d[R]|0)&65535;b[a+44>>1]=S;T=(d[e+35|0]|0)-(d[f+67|0]|0)&65535;b[a+46>>1]=T;U=(d[e+66|0]|0)-(d[f+130|0]|0)&65535;b[a+48>>1]=U;V=(d[e+82|0]|0)-(d[f+162|0]|0)&65535;b[a+50>>1]=V;W=(d[e+98|0]|0)-(d[f+194|0]|0)&65535;b[a+52>>1]=W;X=(d[e+114|0]|0)-(d[f+226|0]|0)&65535;b[a+54>>1]=X;Y=(d[e+51|0]|0)-(d[f+99|0]|0)&65535;b[a+56>>1]=Y;Z=e+20|0;_=f+36|0;$=(d[Z]|0)-(d[_]|0)&65535;b[a+58>>1]=$;aa=(d[e+5|0]|0)-(d[f+5|0]|0)&65535;b[a+60>>1]=aa;ba=e+36|0;ca=f+68|0;da=(d[ba]|0)-(d[ca]|0)&65535;b[a+62>>1]=da;ea=(d[e+67|0]|0)-(d[f+131|0]|0)&65535;b[a+64>>1]=ea;fa=(d[e+83|0]|0)-(d[f+163|0]|0)&65535;b[a+66>>1]=fa;ga=(d[e+99|0]|0)-(d[f+195|0]|0)&65535;b[a+68>>1]=ga;ha=(d[e+115|0]|0)-(d[f+227|0]|0)&65535;b[a+70>>1]=ha;ia=e+52|0;ja=f+100|0;ka=(d[ia]|0)-(d[ja]|0)&65535;b[a+72>>1]=ka;la=(d[e+21|0]|0)-(d[f+37|0]|0)&65535;b[a+74>>1]=la;ma=(d[e+6|0]|0)-(d[f+6|0]|0)&65535;b[a+76>>1]=ma;na=(d[e+37|0]|0)-(d[f+69|0]|0)&65535;b[a+78>>1]=na;oa=e+68|0;pa=f+132|0;qa=(d[oa]|0)-(d[pa]|0)&65535;b[a+80>>1]=qa;ra=e+84|0;sa=f+164|0;ta=(d[ra]|0)-(d[sa]|0)&65535;b[a+82>>1]=ta;ua=e+100|0;va=f+196|0;wa=(d[ua]|0)-(d[va]|0)&65535;b[a+84>>1]=wa;xa=e+116|0;ya=f+228|0;za=(d[xa]|0)-(d[ya]|0)&65535;b[a+86>>1]=za;Aa=(d[e+53|0]|0)-(d[f+101|0]|0)&65535;b[a+88>>1]=Aa;Ba=(d[e+22|0]|0)-(d[f+38|0]|0)&65535;b[a+90>>1]=Ba;Ca=(d[e+38|0]|0)-(d[f+70|0]|0)&65535;b[a+92>>1]=Ca;Da=(d[e+69|0]|0)-(d[f+133|0]|0)&65535;b[a+94>>1]=Da;Ea=(d[e+85|0]|0)-(d[f+165|0]|0)&65535;b[a+96>>1]=Ea;Fa=(d[e+101|0]|0)-(d[f+197|0]|0)&65535;b[a+98>>1]=Fa;Ga=(d[e+117|0]|0)-(d[f+229|0]|0)&65535;b[a+100>>1]=Ga;Ha=(d[e+54|0]|0)-(d[f+102|0]|0)&65535;b[a+102>>1]=Ha;Ia=(d[e+7|0]|0)-(d[f+7|0]|0)&65535;b[a+104>>1]=Ia;Ja=(d[e+23|0]|0)-(d[f+39|0]|0)&65535;b[a+106>>1]=Ja;Ka=(d[e+70|0]|0)-(d[f+134|0]|0)&65535;b[a+108>>1]=Ka;La=(d[e+86|0]|0)-(d[f+166|0]|0)&65535;b[a+110>>1]=La;Ma=(d[e+102|0]|0)-(d[f+198|0]|0)&65535;b[a+112>>1]=Ma;Na=(d[e+118|0]|0)-(d[f+230|0]|0)&65535;b[a+114>>1]=Na;Oa=(d[e+39|0]|0)-(d[f+71|0]|0)&65535;b[a+116>>1]=Oa;Pa=(d[e+55|0]|0)-(d[f+103|0]|0)&65535;b[a+118>>1]=Pa;Qa=(d[e+71|0]|0)-(d[f+135|0]|0)&65535;b[a+120>>1]=Qa;Ra=(d[e+87|0]|0)-(d[f+167|0]|0)&65535;b[a+122>>1]=Ra;Sa=(d[e+103|0]|0)-(d[f+199|0]|0)&65535;b[a+124>>1]=Sa;Ta=(d[e+119|0]|0)-(d[f+231|0]|0)&65535;b[a+126>>1]=Ta;c[f>>2]=c[e>>2];c[R>>2]=c[Q>>2];c[i>>2]=c[h>>2];c[_>>2]=c[Z>>2];c[l>>2]=c[k>>2];c[ca>>2]=c[ba>>2];c[q>>2]=c[p>>2];c[ja>>2]=c[ia>>2];c[t>>2]=c[s>>2];c[pa>>2]=c[oa>>2];c[z>>2]=c[y>>2];c[sa>>2]=c[ra>>2];c[C>>2]=c[B>>2];c[va>>2]=c[ua>>2];c[F>>2]=c[E>>2];c[ya>>2]=c[xa>>2];return(j|g|m|n|o|r|u|v|w|x|A|D|G|H|I|J|K|L|M|N|O|P|S|T|U|V|W|X|Y|$|aa|da|ea|fa|ga|ha|ka|la|ma|na|qa|ta|wa|za|Aa|Ba|Ca|Da|Ea|Fa|Ga|Ha|Ia|Ja|Ka|La|Ma|Na|Oa|Pa|Qa|Ra|Sa|Ta)<<16>>16!=0|0}function VNb(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;g=(d[e]|0)-(d[f]|0)&65535;b[a>>1]=g;h=(d[e+1|0]|0)-(d[f+1|0]|0)&65535;b[a+2>>1]=h;i=e+16|0;j=f+32|0;k=(d[i]|0)-(d[j]|0)&65535;b[a+4>>1]=k;l=e+32|0;m=f+64|0;n=(d[l]|0)-(d[m]|0)&65535;b[a+6>>1]=n;o=(d[e+17|0]|0)-(d[f+33|0]|0)&65535;b[a+8>>1]=o;p=(d[e+2|0]|0)-(d[f+2|0]|0)&65535;b[a+10>>1]=p;q=(d[e+3|0]|0)-(d[f+3|0]|0)&65535;b[a+12>>1]=q;r=(d[e+18|0]|0)-(d[f+34|0]|0)&65535;b[a+14>>1]=r;s=(d[e+33|0]|0)-(d[f+65|0]|0)&65535;b[a+16>>1]=s;t=e+48|0;u=f+96|0;v=(d[t]|0)-(d[u]|0)&65535;b[a+18>>1]=v;w=e+64|0;x=f+128|0;y=(d[w]|0)-(d[x]|0)&65535;b[a+20>>1]=y;z=(d[e+49|0]|0)-(d[f+97|0]|0)&65535;b[a+22>>1]=z;A=(d[e+34|0]|0)-(d[f+66|0]|0)&65535;b[a+24>>1]=A;B=(d[e+19|0]|0)-(d[f+35|0]|0)&65535;b[a+26>>1]=B;C=e+4|0;D=f+4|0;E=(d[C]|0)-(d[D]|0)&65535;b[a+28>>1]=E;F=(d[e+5|0]|0)-(d[f+5|0]|0)&65535;b[a+30>>1]=F;G=e+20|0;H=f+36|0;I=(d[G]|0)-(d[H]|0)&65535;b[a+32>>1]=I;J=(d[e+35|0]|0)-(d[f+67|0]|0)&65535;b[a+34>>1]=J;K=(d[e+50|0]|0)-(d[f+98|0]|0)&65535;b[a+36>>1]=K;L=(d[e+65|0]|0)-(d[f+129|0]|0)&65535;b[a+38>>1]=L;M=e+80|0;N=f+160|0;O=(d[M]|0)-(d[N]|0)&65535;b[a+40>>1]=O;P=e+96|0;Q=f+192|0;R=(d[P]|0)-(d[Q]|0)&65535;b[a+42>>1]=R;S=(d[e+81|0]|0)-(d[f+161|0]|0)&65535;b[a+44>>1]=S;T=(d[e+66|0]|0)-(d[f+130|0]|0)&65535;b[a+46>>1]=T;U=(d[e+51|0]|0)-(d[f+99|0]|0)&65535;b[a+48>>1]=U;V=e+36|0;W=f+68|0;X=(d[V]|0)-(d[W]|0)&65535;b[a+50>>1]=X;Y=(d[e+21|0]|0)-(d[f+37|0]|0)&65535;b[a+52>>1]=Y;Z=(d[e+6|0]|0)-(d[f+6|0]|0)&65535;b[a+54>>1]=Z;_=(d[e+7|0]|0)-(d[f+7|0]|0)&65535;b[a+56>>1]=_;$=(d[e+22|0]|0)-(d[f+38|0]|0)&65535;b[a+58>>1]=$;aa=(d[e+37|0]|0)-(d[f+69|0]|0)&65535;b[a+60>>1]=aa;ba=e+52|0;ca=f+100|0;da=(d[ba]|0)-(d[ca]|0)&65535;b[a+62>>1]=da;ea=(d[e+67|0]|0)-(d[f+131|0]|0)&65535;b[a+64>>1]=ea;fa=(d[e+82|0]|0)-(d[f+162|0]|0)&65535;b[a+66>>1]=fa;ga=(d[e+97|0]|0)-(d[f+193|0]|0)&65535;b[a+68>>1]=ga;ha=e+112|0;ia=f+224|0;ja=(d[ha]|0)-(d[ia]|0)&65535;b[a+70>>1]=ja;ka=(d[e+113|0]|0)-(d[f+225|0]|0)&65535;b[a+72>>1]=ka;la=(d[e+98|0]|0)-(d[f+194|0]|0)&65535;b[a+74>>1]=la;ma=(d[e+83|0]|0)-(d[f+163|0]|0)&65535;b[a+76>>1]=ma;na=e+68|0;oa=f+132|0;pa=(d[na]|0)-(d[oa]|0)&65535;b[a+78>>1]=pa;qa=(d[e+53|0]|0)-(d[f+101|0]|0)&65535;b[a+80>>1]=qa;ra=(d[e+38|0]|0)-(d[f+70|0]|0)&65535;b[a+82>>1]=ra;sa=(d[e+23|0]|0)-(d[f+39|0]|0)&65535;b[a+84>>1]=sa;ta=(d[e+39|0]|0)-(d[f+71|0]|0)&65535;b[a+86>>1]=ta;ua=(d[e+54|0]|0)-(d[f+102|0]|0)&65535;b[a+88>>1]=ua;va=(d[e+69|0]|0)-(d[f+133|0]|0)&65535;b[a+90>>1]=va;wa=e+84|0;xa=f+164|0;ya=(d[wa]|0)-(d[xa]|0)&65535;b[a+92>>1]=ya;za=(d[e+99|0]|0)-(d[f+195|0]|0)&65535;b[a+94>>1]=za;Aa=(d[e+114|0]|0)-(d[f+226|0]|0)&65535;b[a+96>>1]=Aa;Ba=(d[e+115|0]|0)-(d[f+227|0]|0)&65535;b[a+98>>1]=Ba;Ca=e+100|0;Da=f+196|0;Ea=(d[Ca]|0)-(d[Da]|0)&65535;b[a+100>>1]=Ea;Fa=(d[e+85|0]|0)-(d[f+165|0]|0)&65535;b[a+102>>1]=Fa;Ga=(d[e+70|0]|0)-(d[f+134|0]|0)&65535;b[a+104>>1]=Ga;Ha=(d[e+55|0]|0)-(d[f+103|0]|0)&65535;b[a+106>>1]=Ha;Ia=(d[e+71|0]|0)-(d[f+135|0]|0)&65535;b[a+108>>1]=Ia;Ja=(d[e+86|0]|0)-(d[f+166|0]|0)&65535;b[a+110>>1]=Ja;Ka=(d[e+101|0]|0)-(d[f+197|0]|0)&65535;b[a+112>>1]=Ka;La=e+116|0;Ma=f+228|0;Na=(d[La]|0)-(d[Ma]|0)&65535;b[a+114>>1]=Na;Oa=(d[e+117|0]|0)-(d[f+229|0]|0)&65535;b[a+116>>1]=Oa;Pa=(d[e+102|0]|0)-(d[f+198|0]|0)&65535;b[a+118>>1]=Pa;Qa=(d[e+87|0]|0)-(d[f+167|0]|0)&65535;b[a+120>>1]=Qa;Ra=(d[e+103|0]|0)-(d[f+199|0]|0)&65535;b[a+122>>1]=Ra;Sa=(d[e+118|0]|0)-(d[f+230|0]|0)&65535;b[a+124>>1]=Sa;Ta=(d[e+119|0]|0)-(d[f+231|0]|0)&65535;b[a+126>>1]=Ta;c[f>>2]=c[e>>2];c[D>>2]=c[C>>2];c[j>>2]=c[i>>2];c[H>>2]=c[G>>2];c[m>>2]=c[l>>2];c[W>>2]=c[V>>2];c[u>>2]=c[t>>2];c[ca>>2]=c[ba>>2];c[x>>2]=c[w>>2];c[oa>>2]=c[na>>2];c[N>>2]=c[M>>2];c[xa>>2]=c[wa>>2];c[Q>>2]=c[P>>2];c[Da>>2]=c[Ca>>2];c[ia>>2]=c[ha>>2];c[Ma>>2]=c[La>>2];return(h|g|k|n|o|p|q|r|s|v|y|z|A|B|E|F|I|J|K|L|O|R|S|T|U|X|Y|Z|_|$|aa|da|ea|fa|ga|ja|ka|la|ma|pa|qa|ra|sa|ta|ua|va|ya|za|Aa|Ba|Ea|Fa|Ga|Ha|Ia|Ja|Ka|Na|Oa|Pa|Qa|Ra|Sa|Ta)<<16>>16!=0|0}function WNb(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=(d[e]|0)-(d[f]|0)&65535;b[a>>1]=g;h=e+16|0;i=f+32|0;j=(d[h]|0)-(d[i]|0)&65535;b[a+2>>1]=j;k=(d[e+1|0]|0)-(d[f+1|0]|0)&65535;b[a+4>>1]=k;l=e+32|0;m=f+64|0;n=(d[l]|0)-(d[m]|0)&65535;b[a+6>>1]=n;o=e+48|0;p=f+96|0;q=(d[o]|0)-(d[p]|0)&65535;b[a+8>>1]=q;r=(d[e+17|0]|0)-(d[f+33|0]|0)&65535;b[a+10>>1]=r;s=(d[e+33|0]|0)-(d[f+65|0]|0)&65535;b[a+12>>1]=s;t=(d[e+49|0]|0)-(d[f+97|0]|0)&65535;b[a+14>>1]=t;u=(d[e+2|0]|0)-(d[f+2|0]|0)&65535;b[a+16>>1]=u;v=(d[e+18|0]|0)-(d[f+34|0]|0)&65535;b[a+18>>1]=v;w=(d[e+34|0]|0)-(d[f+66|0]|0)&65535;b[a+20>>1]=w;x=(d[e+50|0]|0)-(d[f+98|0]|0)&65535;b[a+22>>1]=x;y=(d[e+3|0]|0)-(d[f+3|0]|0)&65535;b[a+24>>1]=y;z=(d[e+19|0]|0)-(d[f+35|0]|0)&65535;b[a+26>>1]=z;A=(d[e+35|0]|0)-(d[f+67|0]|0)&65535;b[a+28>>1]=A;B=(d[e+51|0]|0)-(d[f+99|0]|0)&65535;b[a+30>>1]=B;c[f>>2]=c[e>>2];c[i>>2]=c[h>>2];c[m>>2]=c[l>>2];c[p>>2]=c[o>>2];return(j|g|k|n|q|r|s|t|u|v|w|x|y|z|A|B)<<16>>16!=0|0}function XNb(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=(d[e]|0)-(d[f]|0)&65535;b[a>>1]=g;h=(d[e+1|0]|0)-(d[f+1|0]|0)&65535;b[a+2>>1]=h;i=e+16|0;j=f+32|0;k=(d[i]|0)-(d[j]|0)&65535;b[a+4>>1]=k;l=e+32|0;m=f+64|0;n=(d[l]|0)-(d[m]|0)&65535;b[a+6>>1]=n;o=(d[e+17|0]|0)-(d[f+33|0]|0)&65535;b[a+8>>1]=o;p=(d[e+2|0]|0)-(d[f+2|0]|0)&65535;b[a+10>>1]=p;q=(d[e+3|0]|0)-(d[f+3|0]|0)&65535;b[a+12>>1]=q;r=(d[e+18|0]|0)-(d[f+34|0]|0)&65535;b[a+14>>1]=r;s=(d[e+33|0]|0)-(d[f+65|0]|0)&65535;b[a+16>>1]=s;t=e+48|0;u=f+96|0;v=(d[t]|0)-(d[u]|0)&65535;b[a+18>>1]=v;w=(d[e+49|0]|0)-(d[f+97|0]|0)&65535;b[a+20>>1]=w;x=(d[e+34|0]|0)-(d[f+66|0]|0)&65535;b[a+22>>1]=x;y=(d[e+19|0]|0)-(d[f+35|0]|0)&65535;b[a+24>>1]=y;z=(d[e+35|0]|0)-(d[f+67|0]|0)&65535;b[a+26>>1]=z;A=(d[e+50|0]|0)-(d[f+98|0]|0)&65535;b[a+28>>1]=A;B=(d[e+51|0]|0)-(d[f+99|0]|0)&65535;b[a+30>>1]=B;c[f>>2]=c[e>>2];c[j>>2]=c[i>>2];c[m>>2]=c[l>>2];c[u>>2]=c[t>>2];return(h|g|k|n|o|p|q|r|s|v|w|x|y|z|A|B)<<16>>16!=0|0}function YNb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b[g>>1]=(d[e]|0)-(d[f]|0);b[a>>1]=0;g=e+16|0;h=f+32|0;i=(d[g]|0)-(d[h]|0)&65535;b[a+2>>1]=i;j=(d[e+1|0]|0)-(d[f+1|0]|0)&65535;b[a+4>>1]=j;k=e+32|0;l=f+64|0;m=(d[k]|0)-(d[l]|0)&65535;b[a+6>>1]=m;n=e+48|0;o=f+96|0;p=(d[n]|0)-(d[o]|0)&65535;b[a+8>>1]=p;q=(d[e+17|0]|0)-(d[f+33|0]|0)&65535;b[a+10>>1]=q;r=(d[e+33|0]|0)-(d[f+65|0]|0)&65535;b[a+12>>1]=r;s=(d[e+49|0]|0)-(d[f+97|0]|0)&65535;b[a+14>>1]=s;t=(d[e+2|0]|0)-(d[f+2|0]|0)&65535;b[a+16>>1]=t;u=(d[e+18|0]|0)-(d[f+34|0]|0)&65535;b[a+18>>1]=u;v=(d[e+34|0]|0)-(d[f+66|0]|0)&65535;b[a+20>>1]=v;w=(d[e+50|0]|0)-(d[f+98|0]|0)&65535;b[a+22>>1]=w;x=(d[e+3|0]|0)-(d[f+3|0]|0)&65535;b[a+24>>1]=x;y=(d[e+19|0]|0)-(d[f+35|0]|0)&65535;b[a+26>>1]=y;z=(d[e+35|0]|0)-(d[f+67|0]|0)&65535;b[a+28>>1]=z;A=(d[e+51|0]|0)-(d[f+99|0]|0)&65535;b[a+30>>1]=A;c[f>>2]=c[e>>2];c[h>>2]=c[g>>2];c[l>>2]=c[k>>2];c[o>>2]=c[n>>2];return(j|i|m|p|q|r|s|t|u|v|w|x|y|z|A)<<16>>16!=0|0}function ZNb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b[g>>1]=(d[e]|0)-(d[f]|0);b[a>>1]=0;g=(d[e+1|0]|0)-(d[f+1|0]|0)&65535;b[a+2>>1]=g;h=e+16|0;i=f+32|0;j=(d[h]|0)-(d[i]|0)&65535;b[a+4>>1]=j;k=e+32|0;l=f+64|0;m=(d[k]|0)-(d[l]|0)&65535;b[a+6>>1]=m;n=(d[e+17|0]|0)-(d[f+33|0]|0)&65535;b[a+8>>1]=n;o=(d[e+2|0]|0)-(d[f+2|0]|0)&65535;b[a+10>>1]=o;p=(d[e+3|0]|0)-(d[f+3|0]|0)&65535;b[a+12>>1]=p;q=(d[e+18|0]|0)-(d[f+34|0]|0)&65535;b[a+14>>1]=q;r=(d[e+33|0]|0)-(d[f+65|0]|0)&65535;b[a+16>>1]=r;s=e+48|0;t=f+96|0;u=(d[s]|0)-(d[t]|0)&65535;b[a+18>>1]=u;v=(d[e+49|0]|0)-(d[f+97|0]|0)&65535;b[a+20>>1]=v;w=(d[e+34|0]|0)-(d[f+66|0]|0)&65535;b[a+22>>1]=w;x=(d[e+19|0]|0)-(d[f+35|0]|0)&65535;b[a+24>>1]=x;y=(d[e+35|0]|0)-(d[f+67|0]|0)&65535;b[a+26>>1]=y;z=(d[e+50|0]|0)-(d[f+98|0]|0)&65535;b[a+28>>1]=z;A=(d[e+51|0]|0)-(d[f+99|0]|0)&65535;b[a+30>>1]=A;c[f>>2]=c[e>>2];c[i>>2]=c[h>>2];c[l>>2]=c[k>>2];c[t>>2]=c[s>>2];return(j|g|m|n|o|p|q|r|u|v|w|x|y|z|A)<<16>>16!=0|0}function _Nb(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=0;g=0;do{h=b[d+(g<<2<<1)>>1]|0;f=h<<16>>16|f;b[c+(g<<1)>>1]=h;g=g+1|0;}while((g|0)<16);a[e]=(f|0)!=0|0;f=0;g=0;do{h=b[d+((g<<2|1)<<1)>>1]|0;f=h<<16>>16|f;b[c+(g+16<<1)>>1]=h;g=g+1|0;}while((g|0)<16);a[e+1|0]=(f|0)!=0|0;f=0;g=0;do{h=b[d+((g<<2|2)<<1)>>1]|0;f=h<<16>>16|f;b[c+(g+32<<1)>>1]=h;g=g+1|0;}while((g|0)<16);a[e+8|0]=(f|0)!=0|0;f=0;g=0;do{h=b[d+((g<<2|3)<<1)>>1]|0;f=h<<16>>16|f;b[c+(g+48<<1)>>1]=h;g=g+1|0;}while((g|0)<16);a[e+9|0]=(f|0)!=0|0;return}function $Nb(a,b){a=a|0;b=b|0;return(d[a+48|0]|0)+((d[a+32|0]|0)+((d[a+16|0]|0)+((d[a]|0)+(d[a+1|0]|0)+(d[a+2|0]|0)+(d[a+3|0]|0)-(d[b]|0)-(d[b+1|0]|0)-(d[b+2|0]|0)-(d[b+3|0]|0))+(d[a+17|0]|0)+(d[a+18|0]|0)+(d[a+19|0]|0)-(d[b+32|0]|0)-(d[b+33|0]|0)-(d[b+34|0]|0)-(d[b+35|0]|0))+(d[a+33|0]|0)+(d[a+34|0]|0)+(d[a+35|0]|0)-(d[b+64|0]|0)-(d[b+65|0]|0)-(d[b+66|0]|0)-(d[b+67|0]|0))+(d[a+49|0]|0)+(d[a+50|0]|0)+(d[a+51|0]|0)-(d[b+96|0]|0)-(d[b+97|0]|0)-(d[b+98|0]|0)-(d[b+99|0]|0)|0}function aOb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0;g=i;i=i+8|0;h=g|0;j=e+3260|0;k=c[j>>2]|0;l=c[e+8352>>2]|0;m=c[e+8356>>2]|0;n=c[e+8680>>2]|0;o=15-((l|0)<(m|0)?l:m)+((n|0)<0?0:-n|0)|0;n=e+15148|0;p=c[n>>2]|0;q=c[p+156>>2]|0;r=c[p+160>>2]|0;s=e+8632|0;t=(c[s>>2]|0)==3;u=e+18576|0;v=16>>>((c[u>>2]|0)>>>0);if(t){w=(c[p+212>>2]|0)-(c[p+208>>2]|0)|0}else{w=1}x=e+18560|0;if((c[x>>2]|0)<=0){i=g;return}y=e+8348|0;z=e+18784|0;A=e+18580|0;B=e+18616|0;C=e+160|0;D=e+18660|0;E=e+18920|0;F=e+18908|0;G=e+18900|0;H=e+18904|0;I=e+19272|0;J=e+19268|0;K=e+18956|0;L=e+12|0;M=q<<4;N=ca(v,r)|0;O=e+18964|0;P=e+3216|0;Q=e+18960|0;R=e+18968|0;S=k^1;T=e+37936|0;U=h|0;V=h+1|0;W=h+2|0;X=h+3|0;h=e+37928|0;Y=(k|0)!=0;Z=e+19276|0;_=q<<1;$=r<<1;aa=e+37952|0;ba=e+37960|0;da=e+37924|0;ea=e+37932|0;fa=w+12|0;ga=w+8|0;ha=w+4|0;ia=(k|0)==0;ja=e+37948|0;ka=e+37956|0;la=e+37972|0;ma=e+37976|0;na=e+37988|0;oa=e+37992|0;pa=t&1^1;qa=q*-15|0;ra=ca(v-1|0,r)|0;v=0;sa=f;f=p;while(1){dPb(e,f,v,sa);p=(c[y>>2]|0)!=2;c[z>>2]=0;ta=c[A>>2]|0;ua=(ca(ta,sa)|0)+v|0;c[B>>2]=ua;if((c[C>>2]|0)==0){va=0}else{va=(a[(c[Z>>2]|0)+ua|0]|0)!=0|0}c[D>>2]=va;wa=sa-(1<<va)|0;c[E>>2]=wa;xa=(ca(wa,ta)|0)+v|0;c[F>>2]=xa;ya=ua-1|0;c[G>>2]=ya;c[H>>2]=ya;do{if((c[j>>2]|0)==0){za=ya;Aa=xa;Ba=19}else{if((sa&1|0)!=0){if((v|0)==0){Ca=va;Da=2;Ea=xa;Fa=0;Ga=ya;break}if((d[(c[Z>>2]|0)+ya|0]|0)==(va|0)){za=ya;Aa=xa;Ba=19;break}Ha=ya-ta|0;c[G>>2]=Ha;za=Ha;Aa=xa;Ba=19;break}do{if((xa|0)>-1){if((va|0)==0){Ia=0;Ja=xa;break}if((a[(c[Z>>2]|0)+xa|0]|0)!=0){Ia=va;Ja=xa;break}Ha=xa+ta|0;c[F>>2]=Ha;c[E>>2]=wa+1;Ia=va;Ja=Ha}else{Ia=va;Ja=xa}}while(0);if((v|0)==0){Ca=Ia;Da=2;Ea=Ja;Fa=0;Ga=ya;break}if((d[(c[Z>>2]|0)+ya|0]|0)==(va|0)){za=ya;Aa=Ja;Ba=19;break}c[H>>2]=ya+ta;za=ya;Aa=Ja;Ba=19}}while(0);do{if((Ba|0)==19){Ba=0;if((v|0)<=0){Ca=va;Da=2;Ea=Aa;Fa=0;Ga=za;break}if(!p){ta=c[I>>2]|0;if((b[ta+(za<<1)>>1]|0)!=(b[ta+(ua<<1)>>1]|0)){Ca=va;Da=2;Ea=Aa;Fa=0;Ga=za;break}}c[z>>2]=1;Ca=va;Da=3;Ea=Aa;Fa=1;Ga=za}}while(0);do{if((Ca|0)<(sa|0)){if(!p){ta=c[I>>2]|0;if((b[ta+(Ea<<1)>>1]|0)!=(b[ta+(ua<<1)>>1]|0)){Ka=Fa;break}}c[z>>2]=Da;Ka=Da}else{Ka=Fa}}while(0);p=a[(c[J>>2]|0)+ua|0]|0;ta=c[K>>2]|0;xa=(d[ta+ua|0]|0)>>>0<4>>>0;wa=(c[L>>2]|0)!=0?ua:v;Ha=sa&1;La=c[e+36524+(Ha<<2)>>2]|0;Ma=La+(wa<<6)|0;Na=c[n>>2]|0;Oa=c[Na+204>>2]|0;Pa=v<<4;Qa=(ca(M,sa)|0)+Pa|0;Ra=c[Na+208>>2]|0;Sa=(ca(N,sa)|0)+Pa|0;if((va&sa|0)==0){Ta=Qa;Ua=Sa}else{Ta=Qa+qa|0;Ua=Sa-ra|0}Sa=Ra+Ua|0;Qa=Oa+Ta|0;Pa=q<<va;Va=r<<va;Wa=c[O>>2]|0;Xa=a[Wa+ua|0]|0;Ya=c[P>>2]|0;Za=d[Ya+Xa|0]|0;if((a[(c[Q>>2]|0)+ua|0]|0)==16){if((b[(c[R>>2]|0)+(ua<<1)>>1]|0)!=0|xa){Ba=31}else{_a=1}}else{Ba=31}if((Ba|0)==31){Ba=0;_a=(Xa|0)<=(o|0)}a:do{if((Ka&1|0)!=0){do{if(!ia){if((d[(c[Z>>2]|0)+Ga|0]|0)==(va|0)){break}$a=c[la>>2]|0;ab=c[ma>>2]|0;bb=c[na>>2]|0;cb=c[oa>>2]|0;db=a[Wa+Ga|0]|0;eb=Xa+1|0;fb=eb+db>>1;gb=Za+1|0;hb=(gb+(d[Ya+db|0]|0)|0)>>>1;do{if(xa){Ba=37}else{if((d[ta+Ga|0]|0)>>>0<4>>>0){Ba=37;break}db=fb+l|0;ib=fb+m|0;jb=db+24|0;kb=d[1078288+jb|0]|0;lb=d[ib+1078224|0]|0;mb=Ma;nb=c[mb>>2]|0;do{if((nb|0)!=0){if(!((db-16|0)>>>0<48>>>0)){break}if(!((ib-16|0)>>>0<48>>>0)){break}a[U]=a[(nb&255)+(1077408+(jb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+1|0]|0)+(1077408+(jb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+2|0]|0)+(1077408+(jb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+3|0]|0)+(1077408+(jb<<2))|0]|0;pe[$a&1023](Qa,_,kb,lb,U)}}while(0);lb=hb+l|0;kb=hb+m|0;jb=lb+24|0;nb=d[1078288+jb|0]|0;ib=d[kb+1078224|0]|0;db=c[mb>>2]|0;do{if((db|0)!=0){if(!((lb-16|0)>>>0<48>>>0)){break}if(!((kb-16|0)>>>0<48>>>0)){break}a[U]=(d[(db&255)+(1077408+(jb<<2))|0]|0)+pa;a[V]=(d[(d[La+(wa<<6)+1|0]|0)+(1077408+(jb<<2))|0]|0)+pa;a[W]=(d[(d[La+(wa<<6)+2|0]|0)+(1077408+(jb<<2))|0]|0)+pa;a[X]=(d[(d[La+(wa<<6)+3|0]|0)+(1077408+(jb<<2))|0]|0)+pa;pe[ab&1023](Sa,$,nb,ib,U)}}while(0);if(!t){break}db=c[mb>>2]|0;if((db|0)==0){break}if(!((lb-16|0)>>>0<48>>>0)){break}if(!((kb-16|0)>>>0<48>>>0)){break}a[U]=(d[(db&255)+(1077408+(jb<<2))|0]|0)+pa;a[V]=(d[(d[La+(wa<<6)+1|0]|0)+(1077408+(jb<<2))|0]|0)+pa;a[W]=(d[(d[La+(wa<<6)+2|0]|0)+(1077408+(jb<<2))|0]|0)+pa;a[X]=(d[(d[La+(wa<<6)+3|0]|0)+(1077408+(jb<<2))|0]|0)+pa;pe[ab&1023](Ra+(Ua+w)|0,$,nb,ib,U)}}while(0);do{if((Ba|0)==37){Ba=0;db=fb+l|0;ob=fb+m|0;pb=d[db+1078312|0]|0;qb=d[ob+1078224|0]|0;do{if((db-16|0)>>>0<48>>>0){if(!((ob-16|0)>>>0<48>>>0)){break}mf[bb&2047](Qa,_,pb,qb)}}while(0);qb=hb+l|0;pb=hb+m|0;ob=d[qb+1078312|0]|0;db=d[pb+1078224|0]|0;ib=(qb-16|0)>>>0<48>>>0;do{if(ib){if(!((pb-16|0)>>>0<48>>>0)){break}mf[cb&2047](Sa,$,ob,db)}}while(0);if(!t){break}if(!ib){break}if(!((pb-16|0)>>>0<48>>>0)){break}mf[cb&2047](Ra+(Ua+w)|0,$,ob,db)}}while(0);hb=(c[D>>2]|0)!=0;fb=hb?4:0;if(hb){rb=4-(c[u>>2]|0)|0}else{rb=0}hb=c[H>>2]|0;qb=a[(c[O>>2]|0)+hb|0]|0;nb=eb+qb>>1;jb=(gb+(d[(c[P>>2]|0)+qb|0]|0)|0)>>>1;do{if(!xa){if((d[(c[K>>2]|0)+hb|0]|0)>>>0<4>>>0){break}qb=Oa+((q<<fb)+Ta)|0;kb=nb+l|0;lb=nb+m|0;mb=kb+24|0;sb=d[1078288+mb|0]|0;tb=d[lb+1078224|0]|0;ub=La+(wa<<6)+16|0;vb=c[ub>>2]|0;do{if((vb|0)!=0){if(!((kb-16|0)>>>0<48>>>0)){break}if(!((lb-16|0)>>>0<48>>>0)){break}a[U]=a[(vb&255)+(1077408+(mb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+17|0]|0)+(1077408+(mb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+18|0]|0)+(1077408+(mb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+19|0]|0)+(1077408+(mb<<2))|0]|0;pe[$a&1023](qb,_,sb,tb,U)}}while(0);tb=r<<rb;sb=Ra+(tb+Ua)|0;qb=jb+l|0;mb=jb+m|0;vb=qb+24|0;lb=d[1078288+vb|0]|0;kb=d[mb+1078224|0]|0;db=c[ub>>2]|0;do{if((db|0)!=0){if(!((qb-16|0)>>>0<48>>>0)){break}if(!((mb-16|0)>>>0<48>>>0)){break}a[U]=(d[(db&255)+(1077408+(vb<<2))|0]|0)+pa;a[V]=(d[(d[La+(wa<<6)+17|0]|0)+(1077408+(vb<<2))|0]|0)+pa;a[W]=(d[(d[La+(wa<<6)+18|0]|0)+(1077408+(vb<<2))|0]|0)+pa;a[X]=(d[(d[La+(wa<<6)+19|0]|0)+(1077408+(vb<<2))|0]|0)+pa;pe[ab&1023](sb,$,lb,kb,U)}}while(0);if(!t){break a}sb=c[ub>>2]|0;if((sb|0)==0){break a}if(!((qb-16|0)>>>0<48>>>0)){break a}if(!((mb-16|0)>>>0<48>>>0)){break a}a[U]=(d[(sb&255)+(1077408+(vb<<2))|0]|0)+pa;a[V]=(d[(d[La+(wa<<6)+17|0]|0)+(1077408+(vb<<2))|0]|0)+pa;a[W]=(d[(d[La+(wa<<6)+18|0]|0)+(1077408+(vb<<2))|0]|0)+pa;a[X]=(d[(d[La+(wa<<6)+19|0]|0)+(1077408+(vb<<2))|0]|0)+pa;pe[ab&1023](Ra+(Ua+w+tb)|0,$,lb,kb,U);break a}}while(0);ab=Oa+((q<<fb)+Ta)|0;$a=nb+l|0;hb=nb+m|0;gb=d[$a+1078312|0]|0;eb=d[hb+1078224|0]|0;do{if(($a-16|0)>>>0<48>>>0){if(!((hb-16|0)>>>0<48>>>0)){break}mf[bb&2047](ab,_,gb,eb)}}while(0);eb=r<<rb;gb=Ra+(eb+Ua)|0;ab=jb+l|0;bb=jb+m|0;hb=d[ab+1078312|0]|0;$a=d[bb+1078224|0]|0;nb=(ab-16|0)>>>0<48>>>0;do{if(nb){if(!((bb-16|0)>>>0<48>>>0)){break}mf[cb&2047](gb,$,hb,$a)}}while(0);if(!t){break a}if(!nb){break a}if(!((bb-16|0)>>>0<48>>>0)){break a}mf[cb&2047](Ra+(Ua+w+eb)|0,$,hb,$a);break a}}while(0);gb=a[Wa+ya|0]|0;jb=Xa+1+gb>>1;ab=(Za+1+(d[Ya+gb|0]|0)|0)>>>1;gb=xa|(d[ta+ya|0]|0)>>>0<4>>>0;fb=c[Na+12012>>2]|0;do{if((fb|0)!=0){if((c[Ma>>2]|0)==0){break}sb=(c[Na+2936>>2]|0)+ua|0;a[sb]=a[sb]|-(a[fb+ua|0]&1)&255;sb=c[G>>2]|0;db=c[n>>2]|0;ob=(c[db+2936>>2]|0)+sb|0;a[ob]=a[ob]|-(a[(c[db+12012>>2]|0)+sb|0]&1)&255}}while(0);if(gb){fb=c[ja>>2]|0;sb=jb+l|0;db=jb+m|0;ob=d[sb+1078312|0]|0;pb=d[db+1078224|0]|0;do{if((sb-16|0)>>>0<48>>>0){if(!((db-16|0)>>>0<48>>>0)){break}mf[fb&2047](Qa,Pa,ob,pb)}}while(0);pb=c[s>>2]|0;do{if((pb|0)==1){ob=ab+l|0;fb=ab+m|0;if(!((ob-16|0)>>>0<48>>>0)){Ba=103;break}if(!((fb-16|0)>>>0<48>>>0)){Ba=103;break}mf[c[ka>>2]&2047](Sa,Va,d[ob+1078312|0]|0,d[fb+1078224|0]|0);Ba=103}else if((pb|0)==3){fb=c[ja>>2]|0;ob=ab+l|0;db=ab+m|0;sb=d[ob+1078312|0]|0;gb=d[db+1078224|0]|0;if(!((ob-16|0)>>>0<48>>>0)){Ba=103;break}if((db-16|0)>>>0<48>>>0){mf[fb&2047](Sa,Va,sb,gb);wb=c[ja>>2]|0}else{wb=fb}if(!((db-16|0)>>>0<48>>>0)){Ba=103;break}mf[wb&2047](Ra+(Ua+w)|0,Va,sb,gb);Ba=103}else{xb=pb}}while(0);if((Ba|0)==103){Ba=0;xb=c[s>>2]|0}if((xb|0)!=2){break}pb=ab+l|0;gb=ab+m|0;if(!((pb-16|0)>>>0<48>>>0)){break}if(!((gb-16|0)>>>0<48>>>0)){break}mf[c[ka>>2]&2047](Sa,Va,d[pb+1078312|0]|0,d[gb+1078224|0]|0);break}gb=c[da>>2]|0;pb=jb+l|0;sb=jb+m|0;db=pb+24|0;fb=d[1078288+db|0]|0;ob=d[sb+1078224|0]|0;ib=Ma;yb=c[ib>>2]|0;do{if((yb|0)!=0){if(!((pb-16|0)>>>0<48>>>0)){break}if(!((sb-16|0)>>>0<48>>>0)){break}a[U]=a[(yb&255)+(1077408+(db<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+1|0]|0)+(1077408+(db<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+2|0]|0)+(1077408+(db<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+3|0]|0)+(1077408+(db<<2))|0]|0;pe[gb&1023](Qa,Pa,fb,ob,U)}}while(0);ob=c[s>>2]|0;do{if((ob|0)==1){fb=c[ea>>2]|0;gb=ab+l|0;db=ab+m|0;yb=gb+24|0;sb=d[1078288+yb|0]|0;pb=d[db+1078224|0]|0;jb=c[ib>>2]|0;if((jb|0)==0){Ba=125;break}if(!((gb-16|0)>>>0<48>>>0)){Ba=125;break}if(!((db-16|0)>>>0<48>>>0)){Ba=125;break}a[U]=(a[(jb&255)+(1077408+(yb<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+1|0]|0)+(1077408+(yb<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+2|0]|0)+(1077408+(yb<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+3|0]|0)+(1077408+(yb<<2))|0]|0)+1;pe[fb&1023](Sa,Va,sb,pb,U);Ba=125}else if((ob|0)==3){pb=c[da>>2]|0;sb=ab+l|0;fb=ab+m|0;yb=sb+24|0;jb=d[1078288+yb|0]|0;db=d[fb+1078224|0]|0;gb=c[ib>>2]|0;do{if((gb|0)==0){zb=pb}else{if(!((sb-16|0)>>>0<48>>>0)){zb=pb;break}if(!((fb-16|0)>>>0<48>>>0)){zb=pb;break}a[U]=a[(gb&255)+(1077408+(yb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+1|0]|0)+(1077408+(yb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+2|0]|0)+(1077408+(yb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+3|0]|0)+(1077408+(yb<<2))|0]|0;pe[pb&1023](Sa,Va,jb,db,U);zb=c[da>>2]|0}}while(0);pb=c[ib>>2]|0;if((pb|0)==0){Ba=125;break}if(!((sb-16|0)>>>0<48>>>0)){Ba=125;break}if(!((fb-16|0)>>>0<48>>>0)){Ba=125;break}a[U]=a[(pb&255)+(1077408+(yb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+1|0]|0)+(1077408+(yb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+2|0]|0)+(1077408+(yb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+3|0]|0)+(1077408+(yb<<2))|0]|0;pe[zb&1023](Ra+(Ua+w)|0,Va,jb,db,U);Ba=125}else{Ab=ob}}while(0);if((Ba|0)==125){Ba=0;Ab=c[s>>2]|0}if((Ab|0)!=2){break}ob=c[ea>>2]|0;pb=ab+l|0;gb=ab+m|0;$a=pb+24|0;hb=d[1078288+$a|0]|0;eb=d[gb+1078224|0]|0;cb=c[ib>>2]|0;if((cb|0)==0){break}if(!((pb-16|0)>>>0<48>>>0)){break}if(!((gb-16|0)>>>0<48>>>0)){break}a[U]=(a[(cb&255)+(1077408+($a<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+1|0]|0)+(1077408+($a<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+2|0]|0)+(1077408+($a<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+3|0]|0)+(1077408+($a<<2))|0]|0)+1;pe[ob&1023](Sa,Va,hb,eb,U)}}while(0);do{if(!_a){Ma=p<<24>>24!=0;do{if(Ma){Na=Xa+l|0;ya=Xa+m|0;ta=Na+24|0;Bb=Na;Cb=ya;Db=ta;Eb=1078288+ta|0;Fb=ya+1078224|0}else{ya=Oa+(Ta+4)|0;ta=c[da>>2]|0;Na=Xa+l|0;Ya=Xa+m|0;Wa=Na+24|0;eb=1078288+Wa|0;hb=d[eb]|0;ob=Ya+1078224|0;$a=d[ob]|0;cb=La+(wa<<6)+4|0;gb=c[cb>>2]|0;do{if((gb|0)!=0){if(!((Na-16|0)>>>0<48>>>0)){break}if(!((Ya-16|0)>>>0<48>>>0)){break}a[U]=a[(gb&255)+(1077408+(Wa<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+5|0]|0)+(1077408+(Wa<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+6|0]|0)+(1077408+(Wa<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+7|0]|0)+(1077408+(Wa<<2))|0]|0;pe[ta&1023](ya,Pa,hb,$a,U)}}while(0);if((c[s>>2]|0)!=3){Bb=Na;Cb=Ya;Db=Wa;Eb=eb;Fb=ob;break}$a=Ra+(Ua+4)|0;hb=c[da>>2]|0;ya=Za+l|0;ta=Za+m|0;gb=ya+24|0;db=d[1078288+gb|0]|0;jb=d[ta+1078224|0]|0;yb=c[cb>>2]|0;do{if((yb|0)==0){Gb=hb}else{if(!((ya-16|0)>>>0<48>>>0)){Gb=hb;break}if(!((ta-16|0)>>>0<48>>>0)){Gb=hb;break}a[U]=a[(yb&255)+(1077408+(gb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+5|0]|0)+(1077408+(gb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+6|0]|0)+(1077408+(gb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+7|0]|0)+(1077408+(gb<<2))|0]|0;pe[hb&1023]($a,Va,db,jb,U);Gb=c[da>>2]|0}}while(0);$a=c[cb>>2]|0;if(($a|0)==0){Bb=Na;Cb=Ya;Db=Wa;Eb=eb;Fb=ob;break}if(!((ya-16|0)>>>0<48>>>0)){Bb=Na;Cb=Ya;Db=Wa;Eb=eb;Fb=ob;break}if(!((ta-16|0)>>>0<48>>>0)){Bb=Na;Cb=Ya;Db=Wa;Eb=eb;Fb=ob;break}a[U]=a[($a&255)+(1077408+(gb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+5|0]|0)+(1077408+(gb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+6|0]|0)+(1077408+(gb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+7|0]|0)+(1077408+(gb<<2))|0]|0;pe[Gb&1023](Ra+(ha+Ua)|0,Va,db,jb,U);Bb=Na;Cb=Ya;Db=Wa;Eb=eb;Fb=ob}}while(0);ib=Oa+(Ta+8)|0;ab=c[da>>2]|0;$a=d[Eb]|0;hb=d[Fb]|0;yb=La+(wa<<6)+8|0;fb=c[yb>>2]|0;do{if((fb|0)!=0){if(!((Bb-16|0)>>>0<48>>>0)){break}if(!((Cb-16|0)>>>0<48>>>0)){break}a[U]=a[(fb&255)+(1077408+(Db<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+9|0]|0)+(1077408+(Db<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+10|0]|0)+(1077408+(Db<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+11|0]|0)+(1077408+(Db<<2))|0]|0;pe[ab&1023](ib,Pa,$a,hb,U)}}while(0);ib=c[s>>2]|0;do{if((ib|0)==1){ab=c[ea>>2]|0;fb=Za+l|0;sb=Za+m|0;pb=fb+24|0;bb=d[1078288+pb|0]|0;nb=d[sb+1078224|0]|0;Hb=c[yb>>2]|0;if((Hb|0)==0){Ba=164;break}if(!((fb-16|0)>>>0<48>>>0)){Ba=164;break}if(!((sb-16|0)>>>0<48>>>0)){Ba=164;break}a[U]=(a[(Hb&255)+(1077408+(pb<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+9|0]|0)+(1077408+(pb<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+10|0]|0)+(1077408+(pb<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+11|0]|0)+(1077408+(pb<<2))|0]|0)+1;pe[ab&1023](Ra+(Ua+8)|0,Va,bb,nb,U);Ba=164}else if((ib|0)==3){nb=Ra+(Ua+8)|0;bb=c[da>>2]|0;ab=Za+l|0;pb=Za+m|0;Hb=ab+24|0;sb=d[1078288+Hb|0]|0;fb=d[pb+1078224|0]|0;Ib=c[yb>>2]|0;do{if((Ib|0)==0){Jb=bb}else{if(!((ab-16|0)>>>0<48>>>0)){Jb=bb;break}if(!((pb-16|0)>>>0<48>>>0)){Jb=bb;break}a[U]=a[(Ib&255)+(1077408+(Hb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+9|0]|0)+(1077408+(Hb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+10|0]|0)+(1077408+(Hb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+11|0]|0)+(1077408+(Hb<<2))|0]|0;pe[bb&1023](nb,Va,sb,fb,U);Jb=c[da>>2]|0}}while(0);nb=c[yb>>2]|0;if((nb|0)==0){Ba=164;break}if(!((ab-16|0)>>>0<48>>>0)){Ba=164;break}if(!((pb-16|0)>>>0<48>>>0)){Ba=164;break}a[U]=a[(nb&255)+(1077408+(Hb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+9|0]|0)+(1077408+(Hb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+10|0]|0)+(1077408+(Hb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+11|0]|0)+(1077408+(Hb<<2))|0]|0;pe[Jb&1023](Ra+(ga+Ua)|0,Va,sb,fb,U);Ba=164}else{Kb=ib}}while(0);if((Ba|0)==164){Ba=0;Kb=c[s>>2]|0}do{if((Kb|0)==2){ib=c[ea>>2]|0;nb=Za+l|0;bb=Za+m|0;Ib=nb+24|0;ob=d[1078288+Ib|0]|0;eb=d[bb+1078224|0]|0;Wa=c[yb>>2]|0;if((Wa|0)==0){break}if(!((nb-16|0)>>>0<48>>>0)){break}if(!((bb-16|0)>>>0<48>>>0)){break}a[U]=(a[(Wa&255)+(1077408+(Ib<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+9|0]|0)+(1077408+(Ib<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+10|0]|0)+(1077408+(Ib<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+11|0]|0)+(1077408+(Ib<<2))|0]|0)+1;pe[ib&1023](Ra+(Ua+8)|0,Va,ob,eb,U)}}while(0);if(Ma){break}yb=Oa+(Ta+12)|0;eb=c[da>>2]|0;ob=La+(wa<<6)+12|0;ib=c[ob>>2]|0;do{if((ib|0)!=0){if(!((Bb-16|0)>>>0<48>>>0)){break}if(!((Cb-16|0)>>>0<48>>>0)){break}a[U]=a[(ib&255)+(1077408+(Db<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+13|0]|0)+(1077408+(Db<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+14|0]|0)+(1077408+(Db<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+15|0]|0)+(1077408+(Db<<2))|0]|0;pe[eb&1023](yb,Pa,$a,hb,U)}}while(0);if((c[s>>2]|0)!=3){break}hb=Ra+(Ua+12)|0;$a=c[da>>2]|0;yb=Za+l|0;eb=Za+m|0;ib=yb+24|0;Ma=d[1078288+ib|0]|0;Ib=d[eb+1078224|0]|0;Wa=c[ob>>2]|0;do{if((Wa|0)==0){Lb=$a}else{if(!((yb-16|0)>>>0<48>>>0)){Lb=$a;break}if(!((eb-16|0)>>>0<48>>>0)){Lb=$a;break}a[U]=a[(Wa&255)+(1077408+(ib<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+13|0]|0)+(1077408+(ib<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+14|0]|0)+(1077408+(ib<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+15|0]|0)+(1077408+(ib<<2))|0]|0;pe[$a&1023](hb,Va,Ma,Ib,U);Lb=c[da>>2]|0}}while(0);hb=c[ob>>2]|0;if((hb|0)==0){break}if(!((yb-16|0)>>>0<48>>>0)){break}if(!((eb-16|0)>>>0<48>>>0)){break}a[U]=a[(hb&255)+(1077408+(ib<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+13|0]|0)+(1077408+(ib<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+14|0]|0)+(1077408+(ib<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+15|0]|0)+(1077408+(ib<<2))|0]|0;pe[Lb&1023](Ra+(fa+Ua)|0,Va,Ma,Ib,U)}}while(0);b:do{if((c[z>>2]&2|0)!=0){do{if(Y&(Ha|0)==0){if((c[D>>2]|0)!=0){break}if((a[(c[Z>>2]|0)+(c[F>>2]|0)|0]|0)==0){break}hb=ua-(c[A>>2]<<1)|0;$a=Xa+1|0;Wa=Za+1|0;bb=Ua+w|0;if(xa){nb=0;Ya=hb;while(1){Na=a[(c[O>>2]|0)+Ya|0]|0;jb=$a+Na>>1;db=(Wa+(d[(c[P>>2]|0)+Na|0]|0)|0)>>>1;Na=nb<<2;gb=La+(wa<<6)+32+(Na<<2)|0;c[gb>>2]=50529027;ta=Oa+((ca(nb,q)|0)+Ta)|0;ya=c[h>>2]|0;cb=jb+l|0;Mb=jb+m|0;jb=cb+24|0;Nb=d[1078288+jb|0]|0;Ob=d[Mb+1078224|0]|0;Pb=c[gb>>2]|0;do{if((Pb|0)!=0){if(!((cb-16|0)>>>0<48>>>0)){break}if(!((Mb-16|0)>>>0<48>>>0)){break}a[U]=a[(Pb&255)+(1077408+(jb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+32+(Na<<2)+1|0]|0)+(1077408+(jb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+32+(Na<<2)+2|0]|0)+(1077408+(jb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+32+(Na<<2)+3|0]|0)+(1077408+(jb<<2))|0]|0;pe[ya&1023](ta,_,Nb,Ob,U)}}while(0);Ob=ca(nb,r)|0;Nb=Ra+(Ob+Ua)|0;do{if(t){ta=c[h>>2]|0;ya=db+l|0;jb=db+m|0;Pb=ya+24|0;Mb=d[1078288+Pb|0]|0;cb=d[jb+1078224|0]|0;kb=c[gb>>2]|0;do{if((kb|0)==0){Qb=ta}else{if(!((ya-16|0)>>>0<48>>>0)){Qb=ta;break}if(!((jb-16|0)>>>0<48>>>0)){Qb=ta;break}a[U]=a[(kb&255)+(1077408+(Pb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+32+(Na<<2)+1|0]|0)+(1077408+(Pb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+32+(Na<<2)+2|0]|0)+(1077408+(Pb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+32+(Na<<2)+3|0]|0)+(1077408+(Pb<<2))|0]|0;pe[ta&1023](Nb,$,Mb,cb,U);Qb=c[h>>2]|0}}while(0);ta=c[gb>>2]|0;if((ta|0)==0){break}if(!((ya-16|0)>>>0<48>>>0)){break}if(!((jb-16|0)>>>0<48>>>0)){break}a[U]=a[(ta&255)+(1077408+(Pb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+32+(Na<<2)+1|0]|0)+(1077408+(Pb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+32+(Na<<2)+2|0]|0)+(1077408+(Pb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+32+(Na<<2)+3|0]|0)+(1077408+(Pb<<2))|0]|0;pe[Qb&1023](Ra+(bb+Ob)|0,$,Mb,cb,U)}else{ta=c[T>>2]|0;kb=db+l|0;lb=db+m|0;tb=kb+24|0;vb=d[1078288+tb|0]|0;mb=d[lb+1078224|0]|0;qb=c[gb>>2]|0;if((qb|0)==0){break}if(!((kb-16|0)>>>0<48>>>0)){break}if(!((lb-16|0)>>>0<48>>>0)){break}a[U]=(a[(qb&255)+(1077408+(tb<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+32+(Na<<2)+1|0]|0)+(1077408+(tb<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+32+(Na<<2)+2|0]|0)+(1077408+(tb<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+32+(Na<<2)+3|0]|0)+(1077408+(tb<<2))|0]|0)+1;pe[ta&1023](Nb,$,vb,mb,U)}}while(0);Nb=nb+1|0;if((Nb|0)>=2){break b}nb=Nb;Ya=(c[A>>2]|0)+Ya|0}}else{Rb=0;Sb=hb}while(1){Ya=a[(c[O>>2]|0)+Sb|0]|0;nb=$a+Ya>>1;fb=(Wa+(d[(c[P>>2]|0)+Ya|0]|0)|0)>>>1;Ya=Rb<<2;sb=La+(wa<<6)+32+(Ya<<2)|0;if((d[(c[K>>2]|0)+Sb|0]|0)>>>0<4>>>0){c[sb>>2]=50529027}Hb=Oa+((ca(Rb,q)|0)+Ta)|0;pb=c[h>>2]|0;ab=nb+l|0;Nb=nb+m|0;nb=ab+24|0;Na=d[1078288+nb|0]|0;gb=d[Nb+1078224|0]|0;db=c[sb>>2]|0;do{if((db|0)!=0){if(!((ab-16|0)>>>0<48>>>0)){break}if(!((Nb-16|0)>>>0<48>>>0)){break}a[U]=a[(db&255)+(1077408+(nb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+32+(Ya<<2)+1|0]|0)+(1077408+(nb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+32+(Ya<<2)+2|0]|0)+(1077408+(nb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+32+(Ya<<2)+3|0]|0)+(1077408+(nb<<2))|0]|0;pe[pb&1023](Hb,_,Na,gb,U)}}while(0);gb=ca(Rb,r)|0;Na=Ra+(gb+Ua)|0;do{if(t){Hb=c[h>>2]|0;pb=fb+l|0;nb=fb+m|0;db=pb+24|0;Nb=d[1078288+db|0]|0;ab=d[nb+1078224|0]|0;Ob=c[sb>>2]|0;do{if((Ob|0)==0){Tb=Hb}else{if(!((pb-16|0)>>>0<48>>>0)){Tb=Hb;break}if(!((nb-16|0)>>>0<48>>>0)){Tb=Hb;break}a[U]=a[(Ob&255)+(1077408+(db<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+32+(Ya<<2)+1|0]|0)+(1077408+(db<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+32+(Ya<<2)+2|0]|0)+(1077408+(db<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+32+(Ya<<2)+3|0]|0)+(1077408+(db<<2))|0]|0;pe[Hb&1023](Na,$,Nb,ab,U);Tb=c[h>>2]|0}}while(0);Hb=c[sb>>2]|0;if((Hb|0)==0){break}if(!((pb-16|0)>>>0<48>>>0)){break}if(!((nb-16|0)>>>0<48>>>0)){break}a[U]=a[(Hb&255)+(1077408+(db<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+32+(Ya<<2)+1|0]|0)+(1077408+(db<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+32+(Ya<<2)+2|0]|0)+(1077408+(db<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+32+(Ya<<2)+3|0]|0)+(1077408+(db<<2))|0]|0;pe[Tb&1023](Ra+(bb+gb)|0,$,Nb,ab,U)}else{Hb=c[T>>2]|0;Ob=fb+l|0;cb=fb+m|0;Mb=Ob+24|0;Pb=d[1078288+Mb|0]|0;jb=d[cb+1078224|0]|0;ya=c[sb>>2]|0;if((ya|0)==0){break}if(!((Ob-16|0)>>>0<48>>>0)){break}if(!((cb-16|0)>>>0<48>>>0)){break}a[U]=(a[(ya&255)+(1077408+(Mb<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+32+(Ya<<2)+1|0]|0)+(1077408+(Mb<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+32+(Ya<<2)+2|0]|0)+(1077408+(Mb<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+32+(Ya<<2)+3|0]|0)+(1077408+(Mb<<2))|0]|0)+1;pe[Hb&1023](Na,$,Pb,jb,U)}}while(0);Na=Rb+1|0;if((Na|0)>=2){break b}Rb=Na;Sb=(c[A>>2]|0)+Sb|0}}}while(0);Ib=c[F>>2]|0;Ma=a[(c[O>>2]|0)+Ib|0]|0;ib=Xa+1+Ma>>1;eb=(Za+1+(d[(c[P>>2]|0)+Ma|0]|0)|0)>>>1;Ma=xa|(d[(c[K>>2]|0)+Ib|0]|0)>>>0<4>>>0;Ib=c[n>>2]|0;yb=c[Ib+12012>>2]|0;do{if((yb|0)!=0){if((c[La+(wa<<6)+32>>2]|0)==0){break}ob=(c[Ib+2936>>2]|0)+ua|0;a[ob]=a[ob]|-(a[yb+ua|0]&1)&255;ob=c[F>>2]|0;bb=c[n>>2]|0;Wa=(c[bb+2936>>2]|0)+ob|0;a[Wa]=a[Wa]|-(a[(c[bb+12012>>2]|0)+ob|0]&1)&255}}while(0);do{if(Y){if((c[D>>2]|0)==0){if(!((a[(c[Z>>2]|0)+(c[F>>2]|0)|0]|0)!=0|Ma^1)){Ba=236;break}}if(!Ma){break}c[La+(wa<<6)+32>>2]=50529027}else{if(Ma){Ba=236}}}while(0);if((Ba|0)==236){Ba=0;Ma=c[aa>>2]|0;yb=ib+l|0;Ib=ib+m|0;ob=d[yb+1078312|0]|0;bb=d[Ib+1078224|0]|0;do{if((yb-16|0)>>>0<48>>>0){if(!((Ib-16|0)>>>0<48>>>0)){break}mf[Ma&2047](Qa,Pa,ob,bb)}}while(0);bb=c[s>>2]|0;do{if((bb|0)==3){ob=c[aa>>2]|0;Ma=eb+l|0;Ib=eb+m|0;yb=d[Ma+1078312|0]|0;Wa=d[Ib+1078224|0]|0;if(!((Ma-16|0)>>>0<48>>>0)){Ba=248;break}if((Ib-16|0)>>>0<48>>>0){mf[ob&2047](Sa,Va,yb,Wa);Ub=c[aa>>2]|0}else{Ub=ob}if(!((Ib-16|0)>>>0<48>>>0)){Ba=248;break}mf[Ub&2047](Ra+(Ua+w)|0,Va,yb,Wa);Ba=248}else if((bb|0)==1){Wa=eb+l|0;yb=eb+m|0;if(!((Wa-16|0)>>>0<48>>>0)){Ba=248;break}if(!((yb-16|0)>>>0<48>>>0)){Ba=248;break}mf[c[ba>>2]&2047](Sa,Va,d[Wa+1078312|0]|0,d[yb+1078224|0]|0);Ba=248}else{Vb=bb}}while(0);if((Ba|0)==248){Ba=0;Vb=c[s>>2]|0}if((Vb|0)!=2){break}bb=eb+l|0;yb=eb+m|0;if(!((bb-16|0)>>>0<48>>>0)){break}if(!((yb-16|0)>>>0<48>>>0)){break}mf[c[ba>>2]&2047](Sa,Va,d[bb+1078312|0]|0,d[yb+1078224|0]|0);break}yb=c[h>>2]|0;bb=ib+l|0;Wa=ib+m|0;Ib=bb+24|0;ob=d[1078288+Ib|0]|0;Ma=d[Wa+1078224|0]|0;$a=La+(wa<<6)+32|0;hb=c[$a>>2]|0;do{if((hb|0)!=0){if(!((bb-16|0)>>>0<48>>>0)){break}if(!((Wa-16|0)>>>0<48>>>0)){break}a[U]=a[(hb&255)+(1077408+(Ib<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+33|0]|0)+(1077408+(Ib<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+34|0]|0)+(1077408+(Ib<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+35|0]|0)+(1077408+(Ib<<2))|0]|0;pe[yb&1023](Qa,Pa,ob,Ma,U)}}while(0);Ma=c[s>>2]|0;do{if((Ma|0)==1){ob=c[T>>2]|0;yb=eb+l|0;Ib=eb+m|0;hb=yb+24|0;Wa=d[1078288+hb|0]|0;bb=d[Ib+1078224|0]|0;ib=c[$a>>2]|0;if((ib|0)==0){Ba=272;break}if(!((yb-16|0)>>>0<48>>>0)){Ba=272;break}if(!((Ib-16|0)>>>0<48>>>0)){Ba=272;break}a[U]=(a[(ib&255)+(1077408+(hb<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+33|0]|0)+(1077408+(hb<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+34|0]|0)+(1077408+(hb<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+35|0]|0)+(1077408+(hb<<2))|0]|0)+1;pe[ob&1023](Sa,Va,Wa,bb,U);Ba=272}else if((Ma|0)==3){bb=c[h>>2]|0;Wa=eb+l|0;ob=eb+m|0;hb=Wa+24|0;ib=d[1078288+hb|0]|0;Ib=d[ob+1078224|0]|0;yb=c[$a>>2]|0;do{if((yb|0)==0){Wb=bb}else{if(!((Wa-16|0)>>>0<48>>>0)){Wb=bb;break}if(!((ob-16|0)>>>0<48>>>0)){Wb=bb;break}a[U]=a[(yb&255)+(1077408+(hb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+33|0]|0)+(1077408+(hb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+34|0]|0)+(1077408+(hb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+35|0]|0)+(1077408+(hb<<2))|0]|0;pe[bb&1023](Sa,Va,ib,Ib,U);Wb=c[h>>2]|0}}while(0);bb=c[$a>>2]|0;if((bb|0)==0){Ba=272;break}if(!((Wa-16|0)>>>0<48>>>0)){Ba=272;break}if(!((ob-16|0)>>>0<48>>>0)){Ba=272;break}a[U]=a[(bb&255)+(1077408+(hb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+33|0]|0)+(1077408+(hb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+34|0]|0)+(1077408+(hb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+35|0]|0)+(1077408+(hb<<2))|0]|0;pe[Wb&1023](Ra+(Ua+w)|0,Va,ib,Ib,U);Ba=272}else{Xb=Ma}}while(0);if((Ba|0)==272){Ba=0;Xb=c[s>>2]|0}if((Xb|0)!=2){break}Ma=c[T>>2]|0;bb=eb+l|0;yb=eb+m|0;Na=bb+24|0;Ya=d[1078288+Na|0]|0;sb=d[yb+1078224|0]|0;fb=c[$a>>2]|0;if((fb|0)==0){break}if(!((bb-16|0)>>>0<48>>>0)){break}if(!((yb-16|0)>>>0<48>>>0)){break}a[U]=(a[(fb&255)+(1077408+(Na<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+33|0]|0)+(1077408+(Na<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+34|0]|0)+(1077408+(Na<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+35|0]|0)+(1077408+(Na<<2))|0]|0)+1;pe[Ma&1023](Sa,Va,Ya,sb,U)}}while(0);do{if(!_a){Sa=p<<24>>24!=0;do{if(Sa){Ba=293}else{Qa=Oa+((Pa<<2)+Ta)|0;ua=c[h>>2]|0;xa=Xa+l|0;Ha=Xa+m|0;sb=xa+24|0;Ya=d[1078288+sb|0]|0;Ma=d[Ha+1078224|0]|0;Na=La+(wa<<6)+36|0;fb=c[Na>>2]|0;do{if((fb|0)!=0){if(!((xa-16|0)>>>0<48>>>0)){break}if(!((Ha-16|0)>>>0<48>>>0)){break}a[U]=a[(fb&255)+(1077408+(sb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+37|0]|0)+(1077408+(sb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+38|0]|0)+(1077408+(sb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+39|0]|0)+(1077408+(sb<<2))|0]|0;pe[ua&1023](Qa,Pa,Ya,Ma,U)}}while(0);Ma=c[s>>2]|0;if((Ma|0)!=3){Yb=Ma;break}Ma=Va<<2;Ya=Ra+(Ma+Ua)|0;Qa=c[h>>2]|0;ua=Za+l|0;sb=Za+m|0;fb=ua+24|0;Ha=d[1078288+fb|0]|0;xa=d[sb+1078224|0]|0;Ib=c[Na>>2]|0;do{if((Ib|0)==0){Zb=Qa}else{if(!((ua-16|0)>>>0<48>>>0)){Zb=Qa;break}if(!((sb-16|0)>>>0<48>>>0)){Zb=Qa;break}a[U]=a[(Ib&255)+(1077408+(fb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+37|0]|0)+(1077408+(fb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+38|0]|0)+(1077408+(fb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+39|0]|0)+(1077408+(fb<<2))|0]|0;pe[Qa&1023](Ya,Va,Ha,xa,U);Zb=c[h>>2]|0}}while(0);Ya=c[Na>>2]|0;if((Ya|0)==0){Ba=293;break}if(!((ua-16|0)>>>0<48>>>0)){Ba=293;break}if(!((sb-16|0)>>>0<48>>>0)){Ba=293;break}a[U]=a[(Ya&255)+(1077408+(fb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+37|0]|0)+(1077408+(fb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+38|0]|0)+(1077408+(fb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+39|0]|0)+(1077408+(fb<<2))|0]|0;pe[Zb&1023](Ra+(Ua+w+Ma)|0,Va,Ha,xa,U);Ba=293}}while(0);if((Ba|0)==293){Ba=0;Yb=c[s>>2]|0}do{if((Yb|0)==2){$a=c[T>>2]|0;eb=Za+l|0;Ya=Za+m|0;Qa=eb+24|0;Ib=d[1078288+Qa|0]|0;ib=d[Ya+1078224|0]|0;hb=c[La+(wa<<6)+36>>2]|0;if((hb|0)==0){break}if(!((eb-16|0)>>>0<48>>>0)){break}if(!((Ya-16|0)>>>0<48>>>0)){break}a[U]=(a[(hb&255)+(1077408+(Qa<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+37|0]|0)+(1077408+(Qa<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+38|0]|0)+(1077408+(Qa<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+39|0]|0)+(1077408+(Qa<<2))|0]|0)+1;pe[$a&1023](Ra+((Va<<2)+Ua)|0,Va,Ib,ib,U)}}while(0);ib=Oa+((Pa<<3)+Ta)|0;Ib=c[h>>2]|0;$a=Xa+l|0;Qa=Xa+m|0;hb=$a+24|0;Ya=d[1078288+hb|0]|0;eb=d[Qa+1078224|0]|0;ob=La+(wa<<6)+40|0;Wa=c[ob>>2]|0;do{if((Wa|0)!=0){if(!(($a-16|0)>>>0<48>>>0)){break}if(!((Qa-16|0)>>>0<48>>>0)){break}a[U]=a[(Wa&255)+(1077408+(hb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+41|0]|0)+(1077408+(hb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+42|0]|0)+(1077408+(hb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+43|0]|0)+(1077408+(hb<<2))|0]|0;pe[Ib&1023](ib,Pa,Ya,eb,U)}}while(0);ib=c[s>>2]|0;do{if((ib|0)==1){Ib=c[T>>2]|0;Wa=Za+l|0;yb=Za+m|0;bb=Wa+24|0;gb=d[1078288+bb|0]|0;jb=d[yb+1078224|0]|0;Pb=c[ob>>2]|0;if((Pb|0)==0){Ba=316;break}if(!((Wa-16|0)>>>0<48>>>0)){Ba=316;break}if(!((yb-16|0)>>>0<48>>>0)){Ba=316;break}a[U]=(a[(Pb&255)+(1077408+(bb<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+41|0]|0)+(1077408+(bb<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+42|0]|0)+(1077408+(bb<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+43|0]|0)+(1077408+(bb<<2))|0]|0)+1;pe[Ib&1023](Ra+((Va<<2)+Ua)|0,Va,gb,jb,U);Ba=316}else if((ib|0)==3){jb=Va<<3;gb=Ra+(jb+Ua)|0;Ib=c[h>>2]|0;bb=Za+l|0;Pb=Za+m|0;yb=bb+24|0;Wa=d[1078288+yb|0]|0;Hb=d[Pb+1078224|0]|0;Mb=c[ob>>2]|0;do{if((Mb|0)==0){_b=Ib}else{if(!((bb-16|0)>>>0<48>>>0)){_b=Ib;break}if(!((Pb-16|0)>>>0<48>>>0)){_b=Ib;break}a[U]=a[(Mb&255)+(1077408+(yb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+41|0]|0)+(1077408+(yb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+42|0]|0)+(1077408+(yb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+43|0]|0)+(1077408+(yb<<2))|0]|0;pe[Ib&1023](gb,Va,Wa,Hb,U);_b=c[h>>2]|0}}while(0);gb=c[ob>>2]|0;if((gb|0)==0){Ba=316;break}if(!((bb-16|0)>>>0<48>>>0)){Ba=316;break}if(!((Pb-16|0)>>>0<48>>>0)){Ba=316;break}a[U]=a[(gb&255)+(1077408+(yb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+41|0]|0)+(1077408+(yb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+42|0]|0)+(1077408+(yb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+43|0]|0)+(1077408+(yb<<2))|0]|0;pe[_b&1023](Ra+(Ua+w+jb)|0,Va,Wa,Hb,U);Ba=316}else{$b=ib}}while(0);if((Ba|0)==316){Ba=0;$b=c[s>>2]|0}do{if(($b|0)==2){ib=c[T>>2]|0;gb=Za+l|0;Ib=Za+m|0;Mb=gb+24|0;xa=d[1078288+Mb|0]|0;Ha=d[Ib+1078224|0]|0;Ma=c[ob>>2]|0;if((Ma|0)==0){break}if(!((gb-16|0)>>>0<48>>>0)){break}if(!((Ib-16|0)>>>0<48>>>0)){break}a[U]=(a[(Ma&255)+(1077408+(Mb<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+41|0]|0)+(1077408+(Mb<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+42|0]|0)+(1077408+(Mb<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+43|0]|0)+(1077408+(Mb<<2))|0]|0)+1;pe[ib&1023](Ra+((Va<<3)+Ua)|0,Va,xa,Ha,U)}}while(0);do{if(Sa){Ba=336}else{ob=Oa+((Pa*12|0)+Ta)|0;Ha=c[h>>2]|0;xa=La+(wa<<6)+44|0;ib=c[xa>>2]|0;do{if((ib|0)!=0){if(!(($a-16|0)>>>0<48>>>0)){break}if(!((Qa-16|0)>>>0<48>>>0)){break}a[U]=a[(ib&255)+(1077408+(hb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+45|0]|0)+(1077408+(hb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+46|0]|0)+(1077408+(hb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+47|0]|0)+(1077408+(hb<<2))|0]|0;pe[Ha&1023](ob,Pa,Ya,eb,U)}}while(0);ob=c[s>>2]|0;if((ob|0)!=3){ac=ob;break}ob=Va*12|0;Ha=Ra+(ob+Ua)|0;ib=c[h>>2]|0;Hb=Za+l|0;Wa=Za+m|0;jb=Hb+24|0;yb=d[1078288+jb|0]|0;Pb=d[Wa+1078224|0]|0;bb=c[xa>>2]|0;do{if((bb|0)==0){bc=ib}else{if(!((Hb-16|0)>>>0<48>>>0)){bc=ib;break}if(!((Wa-16|0)>>>0<48>>>0)){bc=ib;break}a[U]=a[(bb&255)+(1077408+(jb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+45|0]|0)+(1077408+(jb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+46|0]|0)+(1077408+(jb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+47|0]|0)+(1077408+(jb<<2))|0]|0;pe[ib&1023](Ha,Va,yb,Pb,U);bc=c[h>>2]|0}}while(0);Ha=c[xa>>2]|0;if((Ha|0)==0){Ba=336;break}if(!((Hb-16|0)>>>0<48>>>0)){Ba=336;break}if(!((Wa-16|0)>>>0<48>>>0)){Ba=336;break}a[U]=a[(Ha&255)+(1077408+(jb<<2))|0]|0;a[V]=a[(d[La+(wa<<6)+45|0]|0)+(1077408+(jb<<2))|0]|0;a[W]=a[(d[La+(wa<<6)+46|0]|0)+(1077408+(jb<<2))|0]|0;a[X]=a[(d[La+(wa<<6)+47|0]|0)+(1077408+(jb<<2))|0]|0;pe[bc&1023](Ra+(Ua+w+ob)|0,Va,yb,Pb,U);Ba=336}}while(0);if((Ba|0)==336){Ba=0;ac=c[s>>2]|0}if((ac|0)!=2){break}eb=c[T>>2]|0;Ya=Za+l|0;hb=Za+m|0;Qa=Ya+24|0;$a=d[1078288+Qa|0]|0;Sa=d[hb+1078224|0]|0;Ha=c[La+(wa<<6)+44>>2]|0;if((Ha|0)==0){break}if(!((Ya-16|0)>>>0<48>>>0)){break}if(!((hb-16|0)>>>0<48>>>0)){break}a[U]=(a[(Ha&255)+(1077408+(Qa<<2))|0]|0)+1;a[V]=(a[(d[La+(wa<<6)+45|0]|0)+(1077408+(Qa<<2))|0]|0)+1;a[W]=(a[(d[La+(wa<<6)+46|0]|0)+(1077408+(Qa<<2))|0]|0)+1;a[X]=(a[(d[La+(wa<<6)+47|0]|0)+(1077408+(Qa<<2))|0]|0)+1;pe[eb&1023](Ra+((Va*12|0)+Ua)|0,Va,$a,Sa,U)}}while(0);Va=((sa|S)&1)+v|0;if((Va|0)>=(c[x>>2]|0)){break}v=Va;sa=sa^k;f=c[n>>2]|0}i=g;return}function bOb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+8|0;f=e|0;g=c[b+8352>>2]|0;h=c[b+8356>>2]|0;j=c[b+8680>>2]|0;k=15-((g|0)<(h|0)?g:h)+((j|0)<0?0:-j|0)|0;j=(c[b+19344>>2]|0)>>>0<4>>>0;l=c[b+28816>>2]|0;m=c[b+28820>>2]|0;do{if((c[b+19348>>2]|0)==16){if(((c[b+19360>>2]|0)!=0|j)&(l|0)>(k|0)){break}i=e;return}else{if((l|0)>(k|0)){break}i=e;return}}while(0);k=c[b+28808>>2]|0;if(j){mrc(k+4|0,3,12)|0;mrc(k+36|0,3,12)|0}else{_e[c[b+38004>>2]&511](b+27984|0,b+28104|0,b+28192|0,k,4>>>((c[b+18660>>2]|0)>>>0),(c[b+3240>>2]|0)==1|0)}j=(c[b+19356>>2]|0)!=0;n=b+24568|0;do{if(j){o=l+g|0;p=l+h|0;q=o+24|0;r=b+37924|0;s=f|0;t=o;u=p;v=q;w=1078288+q|0;x=p+1078224|0}else{p=(c[n>>2]|0)+4|0;q=b+37924|0;o=c[q>>2]|0;y=f|0;z=l+g|0;A=l+h|0;B=z+24|0;C=1078288+B|0;D=d[C]|0;E=A+1078224|0;F=d[E]|0;G=k+4|0;H=c[G>>2]|0;do{if((H|0)!=0){if(!((z-16|0)>>>0<48>>>0)){break}if(!((A-16|0)>>>0<48>>>0)){break}a[y]=a[(H&255)+(1077408+(B<<2))|0]|0;a[f+1|0]=a[(d[k+5|0]|0)+(1077408+(B<<2))|0]|0;a[f+2|0]=a[(d[k+6|0]|0)+(1077408+(B<<2))|0]|0;a[f+3|0]=a[(d[k+7|0]|0)+(1077408+(B<<2))|0]|0;pe[o&1023](p,32,D,F,y)}}while(0);if((c[b+8632>>2]|0)!=3){r=q;s=y;t=z;u=A;v=B;w=C;x=E;break}F=(c[b+24572>>2]|0)+4|0;D=c[q>>2]|0;p=m+g|0;o=m+h|0;H=p+24|0;I=d[1078288+H|0]|0;J=d[o+1078224|0]|0;K=c[G>>2]|0;do{if((K|0)==0){L=D}else{if(!((p-16|0)>>>0<48>>>0)){L=D;break}if(!((o-16|0)>>>0<48>>>0)){L=D;break}a[y]=a[(K&255)+(1077408+(H<<2))|0]|0;a[f+1|0]=a[(d[k+5|0]|0)+(1077408+(H<<2))|0]|0;a[f+2|0]=a[(d[k+6|0]|0)+(1077408+(H<<2))|0]|0;a[f+3|0]=a[(d[k+7|0]|0)+(1077408+(H<<2))|0]|0;pe[D&1023](F,32,I,J,y);L=c[q>>2]|0}}while(0);F=(c[b+24576>>2]|0)+4|0;D=c[G>>2]|0;if((D|0)==0){r=q;s=y;t=z;u=A;v=B;w=C;x=E;break}if(!((p-16|0)>>>0<48>>>0)){r=q;s=y;t=z;u=A;v=B;w=C;x=E;break}if(!((o-16|0)>>>0<48>>>0)){r=q;s=y;t=z;u=A;v=B;w=C;x=E;break}a[y]=a[(D&255)+(1077408+(H<<2))|0]|0;a[f+1|0]=a[(d[k+5|0]|0)+(1077408+(H<<2))|0]|0;a[f+2|0]=a[(d[k+6|0]|0)+(1077408+(H<<2))|0]|0;a[f+3|0]=a[(d[k+7|0]|0)+(1077408+(H<<2))|0]|0;pe[L&1023](F,32,I,J,y);r=q;s=y;t=z;u=A;v=B;w=C;x=E}}while(0);L=(c[n>>2]|0)+8|0;l=c[r>>2]|0;F=d[w]|0;w=d[x]|0;x=k+8|0;D=c[x>>2]|0;do{if((D|0)!=0){if(!((t-16|0)>>>0<48>>>0)){break}if(!((u-16|0)>>>0<48>>>0)){break}a[s]=a[(D&255)+(1077408+(v<<2))|0]|0;a[f+1|0]=a[(d[k+9|0]|0)+(1077408+(v<<2))|0]|0;a[f+2|0]=a[(d[k+10|0]|0)+(1077408+(v<<2))|0]|0;a[f+3|0]=a[(d[k+11|0]|0)+(1077408+(v<<2))|0]|0;pe[l&1023](L,32,F,w,s)}}while(0);L=b+8632|0;do{if((c[L>>2]|0)==3){l=(c[b+24572>>2]|0)+8|0;D=c[r>>2]|0;K=m+g|0;M=m+h|0;N=K+24|0;O=d[1078288+N|0]|0;P=d[M+1078224|0]|0;Q=c[x>>2]|0;do{if((Q|0)==0){R=D}else{if(!((K-16|0)>>>0<48>>>0)){R=D;break}if(!((M-16|0)>>>0<48>>>0)){R=D;break}a[s]=a[(Q&255)+(1077408+(N<<2))|0]|0;a[f+1|0]=a[(d[k+9|0]|0)+(1077408+(N<<2))|0]|0;a[f+2|0]=a[(d[k+10|0]|0)+(1077408+(N<<2))|0]|0;a[f+3|0]=a[(d[k+11|0]|0)+(1077408+(N<<2))|0]|0;pe[D&1023](l,32,O,P,s);R=c[r>>2]|0}}while(0);l=(c[b+24576>>2]|0)+8|0;D=c[x>>2]|0;if((D|0)==0){break}if(!((K-16|0)>>>0<48>>>0)){break}if(!((M-16|0)>>>0<48>>>0)){break}a[s]=a[(D&255)+(1077408+(N<<2))|0]|0;a[f+1|0]=a[(d[k+9|0]|0)+(1077408+(N<<2))|0]|0;a[f+2|0]=a[(d[k+10|0]|0)+(1077408+(N<<2))|0]|0;a[f+3|0]=a[(d[k+11|0]|0)+(1077408+(N<<2))|0]|0;pe[R&1023](l,32,O,P,s)}}while(0);do{if(!j){R=(c[n>>2]|0)+12|0;x=c[r>>2]|0;l=k+12|0;D=c[l>>2]|0;do{if((D|0)!=0){if(!((t-16|0)>>>0<48>>>0)){break}if(!((u-16|0)>>>0<48>>>0)){break}a[s]=a[(D&255)+(1077408+(v<<2))|0]|0;a[f+1|0]=a[(d[k+13|0]|0)+(1077408+(v<<2))|0]|0;a[f+2|0]=a[(d[k+14|0]|0)+(1077408+(v<<2))|0]|0;a[f+3|0]=a[(d[k+15|0]|0)+(1077408+(v<<2))|0]|0;pe[x&1023](R,32,F,w,s)}}while(0);do{if((c[L>>2]|0)==3){R=(c[b+24572>>2]|0)+12|0;x=c[r>>2]|0;D=m+g|0;P=m+h|0;O=D+24|0;N=d[1078288+O|0]|0;M=d[P+1078224|0]|0;K=c[l>>2]|0;do{if((K|0)==0){S=x}else{if(!((D-16|0)>>>0<48>>>0)){S=x;break}if(!((P-16|0)>>>0<48>>>0)){S=x;break}a[s]=a[(K&255)+(1077408+(O<<2))|0]|0;a[f+1|0]=a[(d[k+13|0]|0)+(1077408+(O<<2))|0]|0;a[f+2|0]=a[(d[k+14|0]|0)+(1077408+(O<<2))|0]|0;a[f+3|0]=a[(d[k+15|0]|0)+(1077408+(O<<2))|0]|0;pe[x&1023](R,32,N,M,s);S=c[r>>2]|0}}while(0);R=(c[b+24576>>2]|0)+12|0;x=c[l>>2]|0;if((x|0)==0){break}if(!((D-16|0)>>>0<48>>>0)){break}if(!((P-16|0)>>>0<48>>>0)){break}a[s]=a[(x&255)+(1077408+(O<<2))|0]|0;a[f+1|0]=a[(d[k+13|0]|0)+(1077408+(O<<2))|0]|0;a[f+2|0]=a[(d[k+14|0]|0)+(1077408+(O<<2))|0]|0;a[f+3|0]=a[(d[k+15|0]|0)+(1077408+(O<<2))|0]|0;pe[S&1023](R,32,N,M,s)}}while(0);l=(c[n>>2]|0)+128|0;R=b+37928|0;x=c[R>>2]|0;K=k+36|0;Q=c[K>>2]|0;do{if((Q|0)!=0){if(!((t-16|0)>>>0<48>>>0)){break}if(!((u-16|0)>>>0<48>>>0)){break}a[s]=a[(Q&255)+(1077408+(v<<2))|0]|0;a[f+1|0]=a[(d[k+37|0]|0)+(1077408+(v<<2))|0]|0;a[f+2|0]=a[(d[k+38|0]|0)+(1077408+(v<<2))|0]|0;a[f+3|0]=a[(d[k+39|0]|0)+(1077408+(v<<2))|0]|0;pe[x&1023](l,32,F,w,s)}}while(0);if((c[L>>2]|0)!=3){break}l=(c[b+24572>>2]|0)+128|0;x=c[R>>2]|0;Q=m+g|0;E=m+h|0;C=Q+24|0;B=d[1078288+C|0]|0;A=d[E+1078224|0]|0;z=c[K>>2]|0;do{if((z|0)==0){T=x}else{if(!((Q-16|0)>>>0<48>>>0)){T=x;break}if(!((E-16|0)>>>0<48>>>0)){T=x;break}a[s]=a[(z&255)+(1077408+(C<<2))|0]|0;a[f+1|0]=a[(d[k+37|0]|0)+(1077408+(C<<2))|0]|0;a[f+2|0]=a[(d[k+38|0]|0)+(1077408+(C<<2))|0]|0;a[f+3|0]=a[(d[k+39|0]|0)+(1077408+(C<<2))|0]|0;pe[x&1023](l,32,B,A,s);T=c[R>>2]|0}}while(0);R=(c[b+24576>>2]|0)+128|0;l=c[K>>2]|0;if((l|0)==0){break}if(!((Q-16|0)>>>0<48>>>0)){break}if(!((E-16|0)>>>0<48>>>0)){break}a[s]=a[(l&255)+(1077408+(C<<2))|0]|0;a[f+1|0]=a[(d[k+37|0]|0)+(1077408+(C<<2))|0]|0;a[f+2|0]=a[(d[k+38|0]|0)+(1077408+(C<<2))|0]|0;a[f+3|0]=a[(d[k+39|0]|0)+(1077408+(C<<2))|0]|0;pe[T&1023](R,32,B,A,s)}}while(0);T=(c[n>>2]|0)+256|0;S=b+37928|0;r=c[S>>2]|0;R=k+40|0;l=c[R>>2]|0;do{if((l|0)!=0){if(!((t-16|0)>>>0<48>>>0)){break}if(!((u-16|0)>>>0<48>>>0)){break}a[s]=a[(l&255)+(1077408+(v<<2))|0]|0;a[f+1|0]=a[(d[k+41|0]|0)+(1077408+(v<<2))|0]|0;a[f+2|0]=a[(d[k+42|0]|0)+(1077408+(v<<2))|0]|0;a[f+3|0]=a[(d[k+43|0]|0)+(1077408+(v<<2))|0]|0;pe[r&1023](T,32,F,w,s)}}while(0);do{if((c[L>>2]|0)==3){T=(c[b+24572>>2]|0)+256|0;r=c[S>>2]|0;l=m+g|0;x=m+h|0;z=l+24|0;y=d[1078288+z|0]|0;q=d[x+1078224|0]|0;J=c[R>>2]|0;do{if((J|0)==0){U=r}else{if(!((l-16|0)>>>0<48>>>0)){U=r;break}if(!((x-16|0)>>>0<48>>>0)){U=r;break}a[s]=a[(J&255)+(1077408+(z<<2))|0]|0;a[f+1|0]=a[(d[k+41|0]|0)+(1077408+(z<<2))|0]|0;a[f+2|0]=a[(d[k+42|0]|0)+(1077408+(z<<2))|0]|0;a[f+3|0]=a[(d[k+43|0]|0)+(1077408+(z<<2))|0]|0;pe[r&1023](T,32,y,q,s);U=c[S>>2]|0}}while(0);T=(c[b+24576>>2]|0)+256|0;r=c[R>>2]|0;if((r|0)==0){break}if(!((l-16|0)>>>0<48>>>0)){break}if(!((x-16|0)>>>0<48>>>0)){break}a[s]=a[(r&255)+(1077408+(z<<2))|0]|0;a[f+1|0]=a[(d[k+41|0]|0)+(1077408+(z<<2))|0]|0;a[f+2|0]=a[(d[k+42|0]|0)+(1077408+(z<<2))|0]|0;a[f+3|0]=a[(d[k+43|0]|0)+(1077408+(z<<2))|0]|0;pe[U&1023](T,32,y,q,s)}}while(0);if(j){i=e;return}j=(c[n>>2]|0)+384|0;n=c[S>>2]|0;U=k+44|0;R=c[U>>2]|0;do{if((R|0)!=0){if(!((t-16|0)>>>0<48>>>0)){break}if(!((u-16|0)>>>0<48>>>0)){break}a[s]=a[(R&255)+(1077408+(v<<2))|0]|0;a[f+1|0]=a[(d[k+45|0]|0)+(1077408+(v<<2))|0]|0;a[f+2|0]=a[(d[k+46|0]|0)+(1077408+(v<<2))|0]|0;a[f+3|0]=a[(d[k+47|0]|0)+(1077408+(v<<2))|0]|0;pe[n&1023](j,32,F,w,s)}}while(0);if((c[L>>2]|0)!=3){i=e;return}L=(c[b+24572>>2]|0)+384|0;w=c[S>>2]|0;F=m+g|0;g=m+h|0;h=F+24|0;m=d[1078288+h|0]|0;j=d[g+1078224|0]|0;n=c[U>>2]|0;do{if((n|0)==0){V=w}else{if(!((F-16|0)>>>0<48>>>0)){V=w;break}if(!((g-16|0)>>>0<48>>>0)){V=w;break}a[s]=a[(n&255)+(1077408+(h<<2))|0]|0;a[f+1|0]=a[(d[k+45|0]|0)+(1077408+(h<<2))|0]|0;a[f+2|0]=a[(d[k+46|0]|0)+(1077408+(h<<2))|0]|0;a[f+3|0]=a[(d[k+47|0]|0)+(1077408+(h<<2))|0]|0;pe[w&1023](L,32,m,j,s);V=c[S>>2]|0}}while(0);S=(c[b+24576>>2]|0)+384|0;b=c[U>>2]|0;if((b|0)==0){i=e;return}if(!((F-16|0)>>>0<48>>>0)){i=e;return}if(!((g-16|0)>>>0<48>>>0)){i=e;return}a[s]=a[(b&255)+(1077408+(h<<2))|0]|0;a[f+1|0]=a[(d[k+45|0]|0)+(1077408+(h<<2))|0]|0;a[f+2|0]=a[(d[k+46|0]|0)+(1077408+(h<<2))|0]|0;a[f+3|0]=a[(d[k+47|0]|0)+(1077408+(h<<2))|0]|0;pe[V&1023](S,32,m,j,s);i=e;return}function cOb(a,b,d){a=a|0;b=b|0;d=d|0;c[b+4>>2]=222;c[b>>2]=424;c[b+12>>2]=290;c[b+16>>2]=432;c[b+20>>2]=484;c[b+28>>2]=818;c[b+24>>2]=658;c[b+36>>2]=494;c[b+40>>2]=252;c[b+44>>2]=248;c[b+48>>2]=144;c[b+56>>2]=574;c[b+64>>2]=318;c[b+72>>2]=486;c[b+80>>2]=156;c[b+60>>2]=432;c[b+76>>2]=252;return}function dOb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;tOb(a,b,1,c,d,e);return}function eOb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;tOb(a,1,b,c,d,e);return}function fOb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=c*-2|0;i=-c|0;j=h|1;k=1-c|0;l=c+1|0;m=0;n=b;while(1){b=g+m|0;o=a[b]|0;a:do{if(!(o<<24>>24<1)){p=n;q=1;r=o;while(1){s=d[p+h|0]|0;t=p+i|0;u=d[t]|0;v=d[p]|0;w=d[p+c|0]|0;x=u-v|0;do{if((((x|0)>-1?x:-x|0)|0)<(e|0)){y=s-u|0;if((((y|0)>-1?y:-y|0)|0)>=(f|0)){z=r;break}y=w-v|0;if((((y|0)>-1?y:-y|0)|0)>=(f|0)){z=r;break}y=s+4-w+(v-u<<2)>>3;A=r<<24>>24;B=-A|0;if((y|0)<(B|0)){C=B}else{C=(y|0)>(A|0)?A:y}y=C+u|0;if(y>>>0>255>>>0){D=-y>>31&255}else{D=y&255}a[t]=D;y=v-C|0;if(y>>>0>255>>>0){E=-y>>31&255}else{E=y&255}a[p]=E;z=a[b]|0}else{z=r}}while(0);v=p+1|0;t=d[p+j|0]|0;u=p+k|0;w=d[u]|0;s=d[v]|0;x=d[p+l|0]|0;y=w-s|0;do{if((((y|0)>-1?y:-y|0)|0)<(e|0)){A=t-w|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-s|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=t+4-x+(s-w<<2)>>3;B=z<<24>>24;F=-B|0;if((A|0)<(F|0)){G=F}else{G=(A|0)>(B|0)?B:A}A=G+w|0;if(A>>>0>255>>>0){H=-A>>31&255}else{H=A&255}a[u]=H;A=s-G|0;if(A>>>0>255>>>0){I=-A>>31&255}else{I=A&255}a[v]=I}}while(0);if((q|0)>=2){break a}p=p+2|0;q=q+1|0;r=a[b]|0}}}while(0);b=m+1|0;if((b|0)<4){m=b;n=n+4|0}else{break}}return}function gOb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=c<<1;i=0;j=b;while(1){b=g+i|0;k=a[b]|0;a:do{if(!(k<<24>>24<1)){l=j;m=1;n=k;while(1){o=d[l-4|0]|0;p=l-2|0;q=d[p]|0;r=d[l]|0;s=d[l+2|0]|0;t=q-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(e|0)){u=o-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){v=n;break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){v=n;break}u=o+4-s+(r-q<<2)>>3;w=n<<24>>24;x=-w|0;if((u|0)<(x|0)){y=x}else{y=(u|0)>(w|0)?w:u}u=y+q|0;if(u>>>0>255>>>0){z=-u>>31&255}else{z=u&255}a[p]=z;u=r-y|0;if(u>>>0>255>>>0){A=-u>>31&255}else{A=u&255}a[l]=A;v=a[b]|0}else{v=n}}while(0);r=l+1|0;p=d[l-3|0]|0;q=l-1|0;s=d[q]|0;o=d[r]|0;t=d[l+3|0]|0;u=s-o|0;do{if((((u|0)>-1?u:-u|0)|0)<(e|0)){w=p-s|0;if((((w|0)>-1?w:-w|0)|0)>=(f|0)){break}w=t-o|0;if((((w|0)>-1?w:-w|0)|0)>=(f|0)){break}w=p+4-t+(o-s<<2)>>3;x=v<<24>>24;B=-x|0;if((w|0)<(B|0)){C=B}else{C=(w|0)>(x|0)?x:w}w=C+s|0;if(w>>>0>255>>>0){D=-w>>31&255}else{D=w&255}a[q]=D;w=o-C|0;if(w>>>0>255>>>0){E=-w>>31&255}else{E=w&255}a[r]=E}}while(0);if((m|0)>=2){break a}l=l+c|0;m=m+1|0;n=a[b]|0}}}while(0);b=i+1|0;if((b|0)<4){i=b;j=j+h|0}else{break}}return}function hOb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=c<<2;i=0;j=b;while(1){b=g+i|0;k=a[b]|0;a:do{if(!(k<<24>>24<1)){l=j;m=1;n=k;while(1){o=d[l-4|0]|0;p=l-2|0;q=d[p]|0;r=d[l]|0;s=d[l+2|0]|0;t=q-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(e|0)){u=o-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){v=n;break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){v=n;break}u=o+4-s+(r-q<<2)>>3;w=n<<24>>24;x=-w|0;if((u|0)<(x|0)){y=x}else{y=(u|0)>(w|0)?w:u}u=y+q|0;if(u>>>0>255>>>0){z=-u>>31&255}else{z=u&255}a[p]=z;u=r-y|0;if(u>>>0>255>>>0){A=-u>>31&255}else{A=u&255}a[l]=A;v=a[b]|0}else{v=n}}while(0);r=l+1|0;p=d[l-3|0]|0;q=l-1|0;s=d[q]|0;o=d[r]|0;t=d[l+3|0]|0;u=s-o|0;do{if((((u|0)>-1?u:-u|0)|0)<(e|0)){w=p-s|0;if((((w|0)>-1?w:-w|0)|0)>=(f|0)){break}w=t-o|0;if((((w|0)>-1?w:-w|0)|0)>=(f|0)){break}w=p+4-t+(o-s<<2)>>3;x=v<<24>>24;B=-x|0;if((w|0)<(B|0)){C=B}else{C=(w|0)>(x|0)?x:w}w=C+s|0;if(w>>>0>255>>>0){D=-w>>31&255}else{D=w&255}a[q]=D;w=o-C|0;if(w>>>0>255>>>0){E=-w>>31&255}else{E=w&255}a[r]=E}}while(0);if((m|0)>=4){break a}l=l+c|0;m=m+1|0;n=a[b]|0}}}while(0);b=i+1|0;if((b|0)<4){i=b;j=j+h|0}else{break}}return}function iOb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;sOb(a,b,1,c,d);return}function jOb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;sOb(a,1,b,c,d);return}function kOb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c*-2|0;h=-c|0;i=b;b=0;while(1){j=d[i+g|0]|0;k=i+h|0;l=d[k]|0;m=d[i]|0;n=d[i+c|0]|0;o=l-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(e|0)){p=j-l|0;if((((p|0)>-1?p:-p|0)|0)>=(f|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(f|0)){break}a[k]=(l+2+(j<<1)+n|0)>>>2;a[i]=(j+2+m+(n<<1)|0)>>>2}}while(0);n=b+1|0;if((n|0)<16){i=i+1|0;b=n}else{break}}return}function lOb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=b;b=0;while(1){h=d[g-4|0]|0;i=g-2|0;j=d[i]|0;k=d[g]|0;l=d[g+2|0]|0;m=j-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=h-j|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[i]=(j+2+(h<<1)+l|0)>>>2;a[g]=(h+2+k+(l<<1)|0)>>>2}}while(0);l=g+1|0;k=d[g-3|0]|0;h=g-1|0;j=d[h]|0;i=d[l]|0;m=d[g+3|0]|0;n=j-i|0;do{if((((n|0)>-1?n:-n|0)|0)<(e|0)){o=k-j|0;if((((o|0)>-1?o:-o|0)|0)>=(f|0)){break}o=m-i|0;if((((o|0)>-1?o:-o|0)|0)>=(f|0)){break}a[h]=(j+2+(k<<1)+m|0)>>>2;a[l]=(k+2+i+(m<<1)|0)>>>2}}while(0);m=b+1|0;if((m|0)<8){g=g+c|0;b=m}else{break}}return}function mOb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=b;b=0;while(1){h=d[g-4|0]|0;i=g-2|0;j=d[i]|0;k=d[g]|0;l=d[g+2|0]|0;m=j-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=h-j|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[i]=(j+2+(h<<1)+l|0)>>>2;a[g]=(h+2+k+(l<<1)|0)>>>2}}while(0);l=g+1|0;k=d[g-3|0]|0;h=g-1|0;j=d[h]|0;i=d[l]|0;m=d[g+3|0]|0;n=j-i|0;do{if((((n|0)>-1?n:-n|0)|0)<(e|0)){o=k-j|0;if((((o|0)>-1?o:-o|0)|0)>=(f|0)){break}o=m-i|0;if((((o|0)>-1?o:-o|0)|0)>=(f|0)){break}a[h]=(j+2+(k<<1)+m|0)>>>2;a[l]=(k+2+i+(m<<1)|0)>>>2}}while(0);m=b+1|0;if((m|0)<16){g=g+c|0;b=m}else{break}}return}function nOb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=b;b=0;while(1){i=a[g+(b>>1)|0]|0;j=d[h-3|0]|0;k=h-2|0;l=d[k]|0;m=h-1|0;n=d[m]|0;o=d[h]|0;p=h+1|0;q=d[p]|0;r=d[h+2|0]|0;s=n-o|0;do{if((((s|0)>-1?s:-s|0)|0)<(e|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=i<<24>>24;u=j-n|0;if((((u|0)>-1?u:-u|0)|0)<(f|0)){if(!(i<<24>>24==0)){u=((((n+1+o|0)>>>1)+j|0)>>>1)-l|0;v=-t|0;if((u|0)<(v|0)){w=v}else{w=(u|0)>(t|0)?t:u}a[k]=w+l}x=t+1|0}else{x=t}u=r-o|0;if((((u|0)>-1?u:-u|0)|0)<(f|0)){if(!(i<<24>>24==0)){u=((r+((n+1+o|0)>>>1)|0)>>>1)-q|0;v=-t|0;if((u|0)<(v|0)){y=v}else{y=(u|0)>(t|0)?t:u}a[p]=y+q}z=x+1|0}else{z=x}u=l+4-q+(o-n<<2)>>3;t=-z|0;if((u|0)<(t|0)){A=t}else{A=(u|0)>(z|0)?z:u}u=A+n|0;if(u>>>0>255>>>0){B=-u>>31&255}else{B=u&255}a[m]=B;u=o-A|0;if(u>>>0>255>>>0){C=-u>>31&255}else{C=u&255}a[h]=C}}while(0);o=b+1|0;if((o|0)<8){h=h+c|0;b=o}else{break}}return}function oOb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=0;i=b;while(1){b=g+h|0;j=a[b]|0;do{if(!(j<<24>>24<1)){k=d[i-4|0]|0;l=i-2|0;m=d[l]|0;n=d[i]|0;o=d[i+2|0]|0;p=m-n|0;do{if((((p|0)>-1?p:-p|0)|0)<(e|0)){q=k-m|0;if((((q|0)>-1?q:-q|0)|0)>=(f|0)){r=j;break}q=o-n|0;if((((q|0)>-1?q:-q|0)|0)>=(f|0)){r=j;break}q=k+4-o+(n-m<<2)>>3;s=j<<24>>24;t=-s|0;if((q|0)<(t|0)){u=t}else{u=(q|0)>(s|0)?s:q}q=u+m|0;if(q>>>0>255>>>0){v=-q>>31&255}else{v=q&255}a[l]=v;q=n-u|0;if(q>>>0>255>>>0){w=-q>>31&255}else{w=q&255}a[i]=w;r=a[b]|0}else{r=j}}while(0);n=i+1|0;l=d[i-3|0]|0;m=i-1|0;o=d[m]|0;k=d[n]|0;p=d[i+3|0]|0;q=o-k|0;if((((q|0)>-1?q:-q|0)|0)>=(e|0)){break}q=l-o|0;if((((q|0)>-1?q:-q|0)|0)>=(f|0)){break}q=p-k|0;if((((q|0)>-1?q:-q|0)|0)>=(f|0)){break}q=l+4-p+(k-o<<2)>>3;p=r<<24>>24;l=-p|0;if((q|0)<(l|0)){x=l}else{x=(q|0)>(p|0)?p:q}q=x+o|0;if(q>>>0>255>>>0){y=-q>>31&255}else{y=q&255}a[m]=y;m=k-x|0;if(m>>>0>255>>>0){z=-m>>31&255}else{z=m&255}a[n]=z}}while(0);j=h+1|0;if((j|0)<4){h=j;i=i+c|0}else{break}}return}function pOb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=(e>>2)+2|0;h=b;b=0;while(1){i=h-3|0;j=d[i]|0;k=h-2|0;l=d[k]|0;m=h-1|0;n=d[m]|0;o=d[h]|0;p=h+1|0;q=d[p]|0;r=h+2|0;s=d[r]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(e|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}if((u|0)>=(g|0)){a[m]=(n+2+(l<<1)+q|0)>>>2;a[h]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[h-4|0]|0;a[m]=(j+4+q+(n+l+o<<1)|0)>>>3;a[k]=(j+2+l+n+o|0)>>>2;a[i]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{a[m]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[h+3|0]|0;a[h]=(l+4+s+(o+n+q<<1)|0)>>>3;a[p]=(n+2+o+q+s|0)>>>2;a[r]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{a[h]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=b+1|0;if((q|0)<8){h=h+c|0;b=q}else{break}}return}function qOb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=b;b=0;while(1){h=d[g-4|0]|0;i=g-2|0;j=d[i]|0;k=d[g]|0;l=d[g+2|0]|0;m=j-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=h-j|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[i]=(j+2+(h<<1)+l|0)>>>2;a[g]=(h+2+k+(l<<1)|0)>>>2}}while(0);l=g+1|0;k=d[g-3|0]|0;h=g-1|0;j=d[h]|0;i=d[l]|0;m=d[g+3|0]|0;n=j-i|0;do{if((((n|0)>-1?n:-n|0)|0)<(e|0)){o=k-j|0;if((((o|0)>-1?o:-o|0)|0)>=(f|0)){break}o=m-i|0;if((((o|0)>-1?o:-o|0)|0)>=(f|0)){break}a[h]=(j+2+(k<<1)+m|0)>>>2;a[l]=(k+2+i+(m<<1)|0)>>>2}}while(0);m=b+1|0;if((m|0)<4){g=g+c|0;b=m}else{break}}return}function rOb(c,d,e,f,g,h){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=(h|0)==0;h=0;do{j=(h|0)!=0;k=j?1:8;l=j?8:1;j=0;do{m=0;n=(ca(j,l)|0)+12|0;while(1){o=n-l|0;a:do{if((a[c+n|0]|0)==0){if((a[c+o|0]|0)!=0){p=6;break}do{if((a[d+n|0]|0)==(a[d+o|0]|0)){q=(b[e+(n<<2)>>1]|0)-(b[e+(o<<2)>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){break}q=(b[e+(n<<2)+2>>1]|0)-(b[e+(o<<2)+2>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>=(g|0)){break}if(!i){if((a[d+40+n|0]|0)!=(a[d+40+o|0]|0)){break}q=(b[e+160+(n<<2)>>1]|0)-(b[e+160+(o<<2)>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>3){break}q=(b[e+160+(n<<2)+2>>1]|0)-(b[e+160+(o<<2)+2>>1]|0)|0;if((((q|0)>-1?q:-q|0)|0)>=(g|0)){break}}a[f+(h<<5)+(j<<2)+m|0]=0;break a}}while(0);a[f+(h<<5)+(j<<2)+m|0]=1}else{p=6}}while(0);if((p|0)==6){p=0;a[f+(h<<5)+(j<<2)+m|0]=2}o=m+1|0;if((o|0)<4){m=o;n=n+k|0}else{break}}j=j+1|0;}while((j|0)<4);h=h+1|0;}while((h|0)<2);return}function sOb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=c*-3|0;i=c*-2|0;j=-c|0;k=c<<1;l=(f>>2)+2|0;m=c*-4|0;n=c*3|0;o=b;b=0;while(1){p=o+h|0;q=d[p]|0;r=o+i|0;s=d[r]|0;t=o+j|0;u=d[t]|0;v=d[o]|0;w=o+c|0;x=d[w]|0;y=o+k|0;z=d[y]|0;A=u-v|0;B=(A|0)>-1?A:-A|0;do{if((B|0)<(f|0)){A=s-u|0;if((((A|0)>-1?A:-A|0)|0)>=(g|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(g|0)){break}if((B|0)>=(l|0)){a[t]=(u+2+(s<<1)+x|0)>>>2;a[o]=(s+2+v+(x<<1)|0)>>>2;break}A=q-u|0;if((((A|0)>-1?A:-A|0)|0)<(g|0)){A=d[o+m|0]|0;a[t]=(q+4+x+(u+s+v<<1)|0)>>>3;a[r]=(q+2+s+u+v|0)>>>2;a[p]=((q*3|0)+4+s+u+v+(A<<1)|0)>>>3}else{a[t]=(u+2+(s<<1)+x|0)>>>2}A=z-v|0;if((((A|0)>-1?A:-A|0)|0)<(g|0)){A=d[o+n|0]|0;a[o]=(s+4+z+(v+u+x<<1)|0)>>>3;a[w]=(u+2+v+x+z|0)>>>2;a[y]=(u+4+v+x+(z*3|0)+(A<<1)|0)>>>3;break}else{a[o]=(s+2+v+(x<<1)|0)>>>2;break}}}while(0);x=b+1|0;if((x|0)<16){o=o+e|0;b=x}else{break}}return}function tOb(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=b;b=0;while(1){n=h+b|0;o=a[n]|0;a:do{if(!(o<<24>>24<0)){p=m;q=1;r=o;while(1){s=d[p+i|0]|0;t=p+j|0;u=d[t]|0;v=p+k|0;w=d[v]|0;x=d[p]|0;y=p+c|0;z=d[y]|0;A=d[p+l|0]|0;B=w-x|0;do{if((((B|0)>-1?B:-B|0)|0)<(f|0)){C=u-w|0;if((((C|0)>-1?C:-C|0)|0)>=(g|0)){break}C=z-x|0;if((((C|0)>-1?C:-C|0)|0)>=(g|0)){break}C=r<<24>>24;D=s-w|0;if((((D|0)>-1?D:-D|0)|0)<(g|0)){if(!(r<<24>>24==0)){D=((((w+1+x|0)>>>1)+s|0)>>>1)-u|0;E=-C|0;if((D|0)<(E|0)){F=E}else{F=(D|0)>(C|0)?C:D}a[t]=F+u}G=C+1|0}else{G=C}D=A-x|0;if((((D|0)>-1?D:-D|0)|0)<(g|0)){if(!(r<<24>>24==0)){D=((A+((w+1+x|0)>>>1)|0)>>>1)-z|0;E=-C|0;if((D|0)<(E|0)){H=E}else{H=(D|0)>(C|0)?C:D}a[y]=H+z}I=G+1|0}else{I=G}D=u+4-z+(x-w<<2)>>3;C=-I|0;if((D|0)<(C|0)){J=C}else{J=(D|0)>(I|0)?I:D}D=J+w|0;if(D>>>0>255>>>0){K=-D>>31&255}else{K=D&255}a[v]=K;D=x-J|0;if(D>>>0>255>>>0){L=-D>>31&255}else{L=D&255}a[p]=L}}while(0);if((q|0)>=4){break a}p=p+e|0;q=q+1|0;r=a[n]|0}}}while(0);n=b+1|0;if((n|0)<4){m=m+(e<<2)|0;b=n}else{break}}return}function uOb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[a+2768>>2]|0)!=0){b=a;NLb(b);return}NLb(c[a>>2]|0);d=c[a+88>>2]|0;do{if((d|0)!=0){e=c[d+852>>2]|0;if((e|0)==0){break}qe[e&1023](d)}}while(0);d=c[a+12016>>2]|0;if((d|0)!=0){qe[d&1023](c[a+12012>>2]|0)}d=a+12004|0;e=c[d>>2]|0;if((e|0)!=0){f=a+11996|0;g=a+12e3|0;h=c[g>>2]|0;if((c[f>>2]|0)>0){i=0;j=e;k=h;while(1){qe[j&1023](c[k+(i*12|0)+8>>2]|0);l=i+1|0;m=c[d>>2]|0;n=c[g>>2]|0;if((l|0)<(c[f>>2]|0)){i=l;j=m;k=n}else{o=m;p=n;break}}}else{o=e;p=h}qe[o&1023](p)}nQb(a);b=a;NLb(b);return}function vOb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;f=d+36|0;g=c[f>>2]|0;h=g&255;switch(h|0){case 8:case 9:case 10:case 11:case 12:{j=8;break};case 3:case 1:case 2:{j=3;break};case 6:case 4:case 5:case 7:{j=6;break};default:{j=0}}if((c[b+148>>2]|0)!=(j|0)){ILb(a,0,2412456,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=e;return l|0}if((g&8192|0)!=0){ILb(a,0,2578576,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=e;return l|0}if((h|0)==7){ILb(a,0,2435840,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=e;return l|0}c[b+16>>2]=c[d>>2];c[b+20>>2]=c[d+4>>2];g=d+16|0;j=c[g>>2]|0;m=c[g+4>>2]|0;g=b+40|0;c[g>>2]=j;c[g+4>>2]=m;g=b+24|0;c[g>>2]=j;c[g+4>>2]=m;c[b+88>>2]=c[d+32>>2];c[b+120>>2]=c[d+8>>2];m=b+11996|0;g=d+176|0;c[m>>2]=c[g>>2];c[m+4>>2]=c[g+4>>2];c[m+8>>2]=c[g+8>>2];c[b+12008>>2]=c[d+188>>2];if((c[a+600>>2]|0)==0){c[b+12012>>2]=0;n=0}else{c[b+12012>>2]=c[d+88>>2];n=c[d+92>>2]|0}c[b+12016>>2]=n;if(h>>>0>9>>>0){n=c[d+44>>2]|0;g=c[d+60>>2]|0;m=c[a+32>>2]|0;if((c[f>>2]&4096|0)==0){o=n;p=g}else{o=-n|0;p=g+(ca(m-1|0,n)|0)|0}n=(h|0)==12;g=n?2:1;j=2-(n&1)|0;we[c[a+37492>>2]&127](c[b+204+(g<<2)>>2]|0,c[b+156+(g<<2)>>2]|0,c[b+204>>2]|0,c[b+156>>2]|0,c[b+204+(j<<2)>>2]|0,c[b+156+(j<<2)>>2]|0,p,o,(h|0)==11?4:3,c[a+28>>2]|0,m);l=0;i=e;return l|0}m=c[a+18576>>2]|0;o=a+28|0;p=c[o>>2]|0;j=a+32|0;g=c[d+60>>2]|0;n=c[d+44>>2]|0;if((c[f>>2]&4096|0)==0){q=n;r=g}else{q=-n|0;r=g+(ca((c[j>>2]|0)-1|0,n)|0)|0}if((p|0)>(((q|0)>-1?q:-q|0)|0)){ILb(a,0,2165648,(k=i,i=i+16|0,c[k>>2]=p,c[k+8>>2]=q,k)|0);i=k;l=-1;i=e;return l|0}n=a+37480|0;_e[c[n>>2]&511](c[b+204>>2]|0,c[b+156>>2]|0,r,q,p,c[j>>2]|0);if((h|0)==6|(h|0)==3){p=c[o>>2]|0;q=c[d+64>>2]|0;r=c[d+48>>2]|0;if((c[f>>2]&4096|0)==0){s=r;t=q}else{s=-r|0;t=q+(ca((c[j>>2]>>m)-1|0,r)|0)|0}if((p|0)>(((s|0)>-1?s:-s|0)|0)){ILb(a,0,2165648,(k=i,i=i+16|0,c[k>>2]=p,c[k+8>>2]=s,k)|0);i=k;l=-1;i=e;return l|0}else{_e[c[n>>2]&511](c[b+208>>2]|0,c[b+160>>2]|0,t,s,p,c[j>>2]>>m);l=0;i=e;return l|0}}if((h|0)==1|(h|0)==4|(h|0)==5){u=(h|0)==5}else if((h|0)==2){u=1}else{p=(h|0)==8;h=p?1:2;s=c[o>>2]|0;t=c[d+60+(h<<2)>>2]|0;r=c[d+44+(h<<2)>>2]|0;h=(c[f>>2]&4096|0)==0;if(h){v=r;w=t}else{v=-r|0;w=t+(ca((c[j>>2]|0)-1|0,r)|0)|0}if((s|0)>(((v|0)>-1?v:-v|0)|0)){ILb(a,0,2165648,(k=i,i=i+16|0,c[k>>2]=s,c[k+8>>2]=v,k)|0);i=k;l=-1;i=e;return l|0}r=p?2:1;p=c[d+60+(r<<2)>>2]|0;t=c[d+44+(r<<2)>>2]|0;if(h){x=t;y=p}else{x=-t|0;y=p+(ca((c[j>>2]|0)-1|0,t)|0)|0}if((s|0)>(((x|0)>-1?x:-x|0)|0)){ILb(a,0,2165648,(k=i,i=i+16|0,c[k>>2]=s,c[k+8>>2]=x,k)|0);i=k;l=-1;i=e;return l|0}else{_e[c[n>>2]&511](c[b+208>>2]|0,c[b+160>>2]|0,w,v,s,c[j>>2]|0);_e[c[n>>2]&511](c[b+212>>2]|0,c[b+164>>2]|0,y,x,c[o>>2]|0,c[j>>2]|0);l=0;i=e;return l|0}}x=u?2:1;y=c[o>>2]>>1;o=c[d+60+(x<<2)>>2]|0;n=c[d+44+(x<<2)>>2]|0;x=(c[f>>2]&4096|0)==0;if(x){z=n;A=o}else{z=-n|0;A=o+(ca((c[j>>2]>>m)-1|0,n)|0)|0}if((y|0)>(((z|0)>-1?z:-z|0)|0)){ILb(a,0,2165648,(k=i,i=i+16|0,c[k>>2]=y,c[k+8>>2]=z,k)|0);i=k;l=-1;i=e;return l|0}n=u?1:2;u=c[d+60+(n<<2)>>2]|0;o=c[d+44+(n<<2)>>2]|0;if(x){B=o;C=u}else{B=-o|0;C=u+(ca((c[j>>2]>>m)-1|0,o)|0)|0}if((y|0)>(((B|0)>-1?B:-B|0)|0)){ILb(a,0,2165648,(k=i,i=i+16|0,c[k>>2]=y,c[k+8>>2]=B,k)|0);i=k;l=-1;i=e;return l|0}else{Ge[c[a+37484>>2]&255](c[b+208>>2]|0,c[b+160>>2]|0,A,z,C,B,y,c[j>>2]>>m);l=0;i=e;return l|0}return 0}function wOb(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0;g=(f|0)==0;h=d+18564|0;i=d+3260|0;j=c[i>>2]|0;k=1<<j;l=((c[h>>2]|0)-k|0)==(f|0);m=(c[d+1452>>2]|0)==(f|0);if((j&f|0)!=0){return}j=e+152|0;if((c[j>>2]|0)<=0){return}n=d+18560|0;o=((c[d+1456>>2]|0)-k|0)!=(f|0)|m;k=(f<<4)-((m&1)<<2^4)|0;m=d+18572|0;p=d+18576|0;d=0;do{if((d|0)==0){q=0;r=0}else{q=(c[p>>2]|0)!=0|0;r=(c[m>>2]|0)!=0|0}s=c[e+156+(d<<2)>>2]|0;t=c[n>>2]<<4;if(l){u=c[i>>2]|0;v=(c[h>>2]|0)-f<<4>>u;w=u}else{v=16;w=c[i>>2]|0}u=v>>q;x=32>>>(q>>>0);if(o){y=u}else{y=(4>>>((w+q|0)>>>0))+u|0}do{if((w|0)==0){u=c[e+204+(d<<2)>>2]|0;z=(ca(s,k)|0)>>q;if((y|0)>0){A=1<<r;B=(A|0)==1;C=32>>>(r>>>0)<<r;D=B^1;E=(A|0)<3;A=C-3|0;F=C-1|0;G=t+~r+z|0;H=0;do{I=ca(H,s)|0;J=I-32+z|0;K=u+J|0;L=u+(I+z)|0;M=a[L]|0;do{if(B){N=(M&255)*257|0;O=151}else{P=b[L>>1]|0;if(E){N=P&65535;O=151;break}Q=0;R=0;S=P;T=c[L>>2]|0}}while(0);do{if((O|0)==151){O=0;L=N*65537|0;P=N&65535;U=K;if((U&3|0)==0){Q=0;R=1;S=P;T=L;break}do{if(B){if((U&1|0)==0){V=0;break}a[K]=M;V=1}else{V=0}}while(0);if((U&2|0)==0){Q=V;R=1;S=P;T=L;break}b[u+(J+V)>>1]=P;Q=V|2;R=1;S=P;T=L}}while(0);if((Q|0)<(A|0)){K=Q;while(1){c[u+(J+K)>>2]=T;W=K+4|0;if((W|0)<(A|0)){K=W}else{X=W;break}}}else{X=Q}do{if(R){if((X|0)<(F|0)){b[u+(J+X)>>1]=S;Y=X+2|0}else{Y=X}if((Y|0)==(C|0)|D){break}a[u+(J+Y)|0]=M}}while(0);M=I+t+z|0;J=u+M|0;K=u+(G+I)|0;W=a[K]|0;do{if(B){Z=(W&255)*257|0;O=168}else{_=b[K>>1]|0;if(E){Z=_&65535;O=168;break}$=0;aa=0;ba=_;da=c[K>>2]|0}}while(0);do{if((O|0)==168){O=0;K=Z*65537|0;I=Z&65535;_=J;if((_&3|0)==0){$=0;aa=1;ba=I;da=K;break}do{if(B){if((_&1|0)==0){ea=0;break}a[J]=W;ea=1}else{ea=0}}while(0);if((_&2|0)==0){$=ea;aa=1;ba=I;da=K;break}b[u+(M+ea)>>1]=I;$=ea|2;aa=1;ba=I;da=K}}while(0);if(($|0)<(A|0)){J=$;while(1){c[u+(M+J)>>2]=da;L=J+4|0;if((L|0)<(A|0)){J=L}else{fa=L;break}}}else{fa=$}do{if(aa){if((fa|0)<(F|0)){b[u+(M+fa)>>1]=ba;ga=fa+2|0}else{ga=fa}if((ga|0)==(C|0)|D){break}a[u+(M+ga)|0]=W}}while(0);H=H+1|0;}while((H|0)<(y|0))}H=(x|0)>0;if(g&H){D=z-32|0;C=u+D|0;F=t+64|0;A=0;do{nrc(u+(D+(ca(s,~A)|0))|0,C|0,F)|0;A=A+1|0;}while((A|0)<(x|0))}if(!(l&H)){break}A=z-32|0;F=u+(A+(ca(y-1|0,s)|0))|0;C=t+64|0;D=0;do{nrc(u+(A+(ca(D+y|0,s)|0))|0,F|0,C)|0;D=D+1|0;}while((D|0)<(x|0))}else{D=c[e+216+(d<<2)>>2]|0;C=(ca(s,k)|0)>>q;F=s<<1;A=(y|0)>0;if(A){u=1<<r;z=(u|0)==1;H=32>>>(r>>>0)<<r;B=z^1;E=(u|0)<3;u=H-3|0;G=H-1|0;W=t+~r+C|0;M=0;do{J=ca(M,F)|0;L=J-32|0;P=L+C|0;U=D+P|0;ha=D+(J+C)|0;ia=a[ha]|0;do{if(z){ja=(ia&255)*257|0;O=18}else{ka=b[ha>>1]|0;if(E){ja=ka&65535;O=18;break}la=0;ma=0;na=ka;oa=c[ha>>2]|0}}while(0);do{if((O|0)==18){O=0;ha=ja*65537|0;ka=ja&65535;pa=U;if((pa&3|0)==0){la=0;ma=1;na=ka;oa=ha;break}do{if(z){if((pa&1|0)==0){qa=0;break}a[U]=ia;qa=1}else{qa=0}}while(0);if((pa&2|0)==0){la=qa;ma=1;na=ka;oa=ha;break}b[D+((qa|L)+C)>>1]=ka;la=qa|2;ma=1;na=ka;oa=ha}}while(0);if((la|0)<(u|0)){L=la;while(1){c[D+(P+L)>>2]=oa;U=L+4|0;if((U|0)<(u|0)){L=U}else{ra=U;break}}}else{ra=la}do{if(ma){if((ra|0)<(G|0)){b[D+(P+ra)>>1]=na;sa=ra+2|0}else{sa=ra}if((sa|0)==(H|0)|B){break}a[D+(P+sa)|0]=ia}}while(0);ia=J+t|0;P=ia+C|0;L=D+P|0;U=D+(W+J)|0;K=a[U]|0;do{if(z){ta=(K&255)*257|0;O=35}else{I=b[U>>1]|0;if(E){ta=I&65535;O=35;break}ua=0;va=0;wa=I;xa=c[U>>2]|0}}while(0);do{if((O|0)==35){O=0;U=ta*65537|0;J=ta&65535;I=L;if((I&3|0)==0){ua=0;va=1;wa=J;xa=U;break}do{if(z){if((I&1|0)==0){ya=0;break}a[L]=K;ya=1}else{ya=0}}while(0);if((I&2|0)==0){ua=ya;va=1;wa=J;xa=U;break}b[D+((ya|ia)+C)>>1]=J;ua=ya|2;va=1;wa=J;xa=U}}while(0);if((ua|0)<(u|0)){ia=ua;while(1){c[D+(P+ia)>>2]=xa;L=ia+4|0;if((L|0)<(u|0)){ia=L}else{za=L;break}}}else{za=ua}do{if(va){if((za|0)<(G|0)){b[D+(P+za)>>1]=wa;Aa=za+2|0}else{Aa=za}if((Aa|0)==(H|0)|B){break}a[D+(P+Aa)|0]=K}}while(0);M=M+1|0;}while((M|0)<(y|0))}M=(x|0)>0;B=g&M;if(B){H=C-32|0;G=D+H|0;u=t+64|0;z=0;do{nrc(D+(H+(ca(F,~z)|0))|0,G|0,u)|0;z=z+1|0;}while((z|0)<(x|0))}z=l&M;if(z){u=C-32|0;G=D+(u+(ca(y-1|0,F)|0))|0;H=t+64|0;E=0;do{nrc(D+(u+(ca(E+y|0,F)|0))|0,G|0,H)|0;E=E+1|0;}while((E|0)<(x|0))}E=C+s|0;if(A){H=1<<r;G=(H|0)==1;u=32>>>(r>>>0)<<r;M=G^1;W=(H|0)<3;H=u-3|0;K=u-1|0;P=t+~r+E|0;ia=0;do{L=ca(ia,F)|0;ha=L-32|0;ka=ha+E|0;pa=D+ka|0;_=D+(L+E)|0;Ba=a[_]|0;do{if(G){Ca=(Ba&255)*257|0;O=61}else{Da=b[_>>1]|0;if(W){Ca=Da&65535;O=61;break}Ea=0;Fa=0;Ga=Da;Ha=c[_>>2]|0}}while(0);do{if((O|0)==61){O=0;_=Ca*65537|0;Da=Ca&65535;Ia=pa;if((Ia&3|0)==0){Ea=0;Fa=1;Ga=Da;Ha=_;break}do{if(G){if((Ia&1|0)==0){Ja=0;break}a[pa]=Ba;Ja=1}else{Ja=0}}while(0);if((Ia&2|0)==0){Ea=Ja;Fa=1;Ga=Da;Ha=_;break}b[D+((Ja|ha)+E)>>1]=Da;Ea=Ja|2;Fa=1;Ga=Da;Ha=_}}while(0);if((Ea|0)<(H|0)){ha=Ea;while(1){c[D+(ka+ha)>>2]=Ha;pa=ha+4|0;if((pa|0)<(H|0)){ha=pa}else{Ka=pa;break}}}else{Ka=Ea}do{if(Fa){if((Ka|0)<(K|0)){b[D+(ka+Ka)>>1]=Ga;La=Ka+2|0}else{La=Ka}if((La|0)==(u|0)|M){break}a[D+(ka+La)|0]=Ba}}while(0);Ba=L+t|0;ka=Ba+E|0;ha=D+ka|0;pa=D+(P+L)|0;U=a[pa]|0;do{if(G){Ma=(U&255)*257|0;O=78}else{J=b[pa>>1]|0;if(W){Ma=J&65535;O=78;break}Na=0;Oa=0;Pa=J;Qa=c[pa>>2]|0}}while(0);do{if((O|0)==78){O=0;pa=Ma*65537|0;L=Ma&65535;J=ha;if((J&3|0)==0){Na=0;Oa=1;Pa=L;Qa=pa;break}do{if(G){if((J&1|0)==0){Ra=0;break}a[ha]=U;Ra=1}else{Ra=0}}while(0);if((J&2|0)==0){Na=Ra;Oa=1;Pa=L;Qa=pa;break}b[D+((Ra|Ba)+E)>>1]=L;Na=Ra|2;Oa=1;Pa=L;Qa=pa}}while(0);if((Na|0)<(H|0)){Ba=Na;while(1){c[D+(ka+Ba)>>2]=Qa;ha=Ba+4|0;if((ha|0)<(H|0)){Ba=ha}else{Sa=ha;break}}}else{Sa=Na}do{if(Oa){if((Sa|0)<(K|0)){b[D+(ka+Sa)>>1]=Pa;Ta=Sa+2|0}else{Ta=Sa}if((Ta|0)==(u|0)|M){break}a[D+(ka+Ta)|0]=U}}while(0);ia=ia+1|0;}while((ia|0)<(y|0))}if(B){ia=E-32|0;M=D+ia|0;u=t+64|0;K=0;do{nrc(D+(ia+(ca(F,~K)|0))|0,M|0,u)|0;K=K+1|0;}while((K|0)<(x|0))}if(z){K=E-32|0;u=D+(K+(ca(y-1|0,F)|0))|0;M=t+64|0;ia=0;do{nrc(D+(K+(ca(ia+y|0,F)|0))|0,u|0,M)|0;ia=ia+1|0;}while((ia|0)<(x|0))}if(l){Ua=(c[h>>2]|0)-f<<4}else{Ua=32}ia=Ua>>q;if(o){Va=ia}else{Va=ia+(4>>>(q>>>0))|0}ia=c[e+204+(d<<2)>>2]|0;if((Va|0)>0){M=1<<r;u=(M|0)==1;F=32>>>(r>>>0)<<r;K=u^1;D=(M|0)<3;M=F-3|0;E=F-1|0;H=t+~r+C|0;G=0;do{W=ca(G,s)|0;P=W-32+C|0;A=ia+P|0;U=ia+(W+C)|0;ka=a[U]|0;do{if(u){Wa=(ka&255)*257|0;O=108}else{Ba=b[U>>1]|0;if(D){Wa=Ba&65535;O=108;break}Xa=0;Ya=0;Za=Ba;_a=c[U>>2]|0}}while(0);do{if((O|0)==108){O=0;U=Wa*65537|0;Ba=Wa&65535;ha=A;if((ha&3|0)==0){Xa=0;Ya=1;Za=Ba;_a=U;break}do{if(u){if((ha&1|0)==0){$a=0;break}a[A]=ka;$a=1}else{$a=0}}while(0);if((ha&2|0)==0){Xa=$a;Ya=1;Za=Ba;_a=U;break}b[ia+(P+$a)>>1]=Ba;Xa=$a|2;Ya=1;Za=Ba;_a=U}}while(0);if((Xa|0)<(M|0)){A=Xa;while(1){c[ia+(P+A)>>2]=_a;pa=A+4|0;if((pa|0)<(M|0)){A=pa}else{ab=pa;break}}}else{ab=Xa}do{if(Ya){if((ab|0)<(E|0)){b[ia+(P+ab)>>1]=Za;bb=ab+2|0}else{bb=ab}if((bb|0)==(F|0)|K){break}a[ia+(P+bb)|0]=ka}}while(0);ka=W+t+C|0;P=ia+ka|0;A=ia+(H+W)|0;pa=a[A]|0;do{if(u){cb=(pa&255)*257|0;O=125}else{L=b[A>>1]|0;if(D){cb=L&65535;O=125;break}db=0;eb=0;fb=L;gb=c[A>>2]|0}}while(0);do{if((O|0)==125){O=0;A=cb*65537|0;W=cb&65535;L=P;if((L&3|0)==0){db=0;eb=1;fb=W;gb=A;break}do{if(u){if((L&1|0)==0){hb=0;break}a[P]=pa;hb=1}else{hb=0}}while(0);if((L&2|0)==0){db=hb;eb=1;fb=W;gb=A;break}b[ia+(ka+hb)>>1]=W;db=hb|2;eb=1;fb=W;gb=A}}while(0);if((db|0)<(M|0)){P=db;while(1){c[ia+(ka+P)>>2]=gb;U=P+4|0;if((U|0)<(M|0)){P=U}else{ib=U;break}}}else{ib=db}do{if(eb){if((ib|0)<(E|0)){b[ia+(ka+ib)>>1]=fb;jb=ib+2|0}else{jb=ib}if((jb|0)==(F|0)|K){break}a[ia+(ka+jb)|0]=pa}}while(0);G=G+1|0;}while((G|0)<(Va|0))}if(B){G=C-32|0;K=ia+G|0;F=t+64|0;E=0;do{nrc(ia+(G+(ca(s,~E)|0))|0,K|0,F)|0;E=E+1|0;}while((E|0)<(x|0))}if(!z){break}E=C-32|0;F=ia+(E+(ca(Va-1|0,s)|0))|0;K=t+64|0;G=0;do{nrc(ia+(E+(ca(G+Va|0,s)|0))|0,F|0,K)|0;G=G+1|0;}while((G|0)<(x|0))}}while(0);d=d+1|0;}while((d|0)<(c[j>>2]|0));return}function xOb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;h=(f|0)==0;i=c[d+18560>>2]<<4|8;j=(g|0)==0;if(j){k=16;l=d+3260|0}else{m=d+3260|0;k=((c[d+18564>>2]|0)-f<<4>>c[m>>2])+16|0;l=m}m=d+8632|0;d=f<<4;f=d-8|0;n=i-1|0;o=i+56|0;p=d-16|0;d=(k|0)>0;q=(g|0)!=0;g=k-1|0;r=0;do{s=e+156+(r<<2)|0;t=1;do{u=c[s>>2]|0;do{if((c[l>>2]|0)!=0){v=c[e+276+(r<<4)+(t<<2)>>2]|0;w=ca(u,p)|0;x=w-4|0;y=u<<1;if(d){z=n+x|0;A=0;do{B=ca(A,y)|0;C=B-28|0;D=C+x|0;E=v+D|0;F=a[v+(B+x)|0]|0;G=F&255;H=ca(G,16843009)|0;I=(G*257|0)&65535;G=E;do{if((G&3|0)==0){J=0}else{if((G&1|0)==0){K=0}else{a[E]=F;K=1}if((G&2|0)==0){J=K;break}b[v+((K|C)+x)>>1]=I;J=K|2}}while(0);C=24-J&-4;G=J+4+C|0;E=J;do{c[v+(D+E)>>2]=H;E=E+4|0;}while((E|0)<25);if((G|0)<27){b[v+(D+G)>>1]=I;L=J+C+6|0}else{L=G}if((L|0)!=28){a[v+(D+L)|0]=F}E=B+i|0;H=E+x|0;M=v+H|0;N=a[v+(z+B)|0]|0;O=N&255;P=ca(O,16843009)|0;Q=(O*257|0)&65535;O=M;do{if((O&3|0)==0){R=0}else{if((O&1|0)==0){S=0}else{a[M]=N;S=1}if((O&2|0)==0){R=S;break}b[v+((S|E)+x)>>1]=Q;R=S|2}}while(0);E=24-R&-4;O=R+4+E|0;M=R;do{c[v+(H+M)>>2]=P;M=M+4|0;}while((M|0)<25);if((O|0)<27){b[v+(H+O)>>1]=Q;T=R+E+6|0}else{T=O}if((T|0)!=28){a[v+(H+T)|0]=N}A=A+1|0;}while((A|0)<(k|0))}if(h){A=w-32|0;z=v+A|0;M=0;do{nrc(v+(A+(ca(y,~M)|0))|0,z|0,o)|0;M=M+1|0;}while((M|0)<24)}if(q){M=v+((ca(y,g)|0)-28+x)|0;z=w-32|0;A=0;do{nrc(v+(z+(ca(A+k|0,y)|0))|0,M|0,o)|0;A=A+1|0;}while((A|0)<24)}A=x+u|0;if(d){M=n+A|0;z=0;do{w=ca(z,y)|0;P=w-28|0;B=P+A|0;F=v+B|0;D=a[v+(w+A)|0]|0;G=D&255;C=ca(G,16843009)|0;I=(G*257|0)&65535;G=F;do{if((G&3|0)==0){U=0}else{if((G&1|0)==0){V=0}else{a[F]=D;V=1}if((G&2|0)==0){U=V;break}b[v+((V|P)+A)>>1]=I;U=V|2}}while(0);P=24-U&-4;G=U+4+P|0;F=U;do{c[v+(B+F)>>2]=C;F=F+4|0;}while((F|0)<25);if((G|0)<27){b[v+(B+G)>>1]=I;W=U+P+6|0}else{W=G}if((W|0)!=28){a[v+(B+W)|0]=D}F=w+i|0;C=F+A|0;N=v+C|0;H=a[v+(M+w)|0]|0;O=H&255;E=ca(O,16843009)|0;Q=(O*257|0)&65535;O=N;do{if((O&3|0)==0){X=0}else{if((O&1|0)==0){Y=0}else{a[N]=H;Y=1}if((O&2|0)==0){X=Y;break}b[v+((Y|F)+A)>>1]=Q;X=Y|2}}while(0);F=24-X&-4;O=X+4+F|0;N=X;do{c[v+(C+N)>>2]=E;N=N+4|0;}while((N|0)<25);if((O|0)<27){b[v+(C+O)>>1]=Q;Z=X+F+6|0}else{Z=O}if((Z|0)!=28){a[v+(C+Z)|0]=H}z=z+1|0;}while((z|0)<(k|0))}if(h){z=A-28|0;M=v+z|0;x=0;do{nrc(v+(z+(ca(y,~x)|0))|0,M|0,o)|0;x=x+1|0;}while((x|0)<24)}if(!q){break}x=v+((ca(y,g)|0)-28+A)|0;M=A-28|0;z=0;do{nrc(v+(M+(ca(z+k|0,y)|0))|0,x|0,o)|0;z=z+1|0;}while((z|0)<24)}}while(0);z=c[e+228+(r<<4)+(t<<2)>>2]|0;x=ca(u,f)|0;y=x-4|0;M=k<<c[l>>2];if((M|0)>0){v=n+y|0;A=0;do{N=ca(A,u)|0;E=N-28+y|0;w=z+E|0;D=a[z+(N+y)|0]|0;B=D&255;G=ca(B,16843009)|0;P=(B*257|0)&65535;B=w;do{if((B&3|0)==0){_=0}else{if((B&1|0)==0){$=0}else{a[w]=D;$=1}if((B&2|0)==0){_=$;break}b[z+(E+$)>>1]=P;_=$|2}}while(0);B=24-_&-4;w=_+4+B|0;I=_;do{c[z+(E+I)>>2]=G;I=I+4|0;}while((I|0)<25);if((w|0)<27){b[z+(E+w)>>1]=P;aa=_+B+6|0}else{aa=w}if((aa|0)!=28){a[z+(E+aa)|0]=D}I=N+i+y|0;G=z+I|0;ba=a[z+(v+N)|0]|0;da=ba&255;ea=ca(da,16843009)|0;fa=(da*257|0)&65535;da=G;do{if((da&3|0)==0){ga=0}else{if((da&1|0)==0){ha=0}else{a[G]=ba;ha=1}if((da&2|0)==0){ga=ha;break}b[z+(I+ha)>>1]=fa;ga=ha|2}}while(0);da=24-ga&-4;G=ga+4+da|0;N=ga;do{c[z+(I+N)>>2]=ea;N=N+4|0;}while((N|0)<25);if((G|0)<27){b[z+(I+G)>>1]=fa;ia=ga+da+6|0}else{ia=G}if((ia|0)!=28){a[z+(I+ia)|0]=ba}A=A+1|0;}while((A|0)<(M|0))}if(h){A=x-32|0;v=z+A|0;y=0;do{nrc(z+(A+(ca(u,~y)|0))|0,v|0,o)|0;y=y+1|0;}while((y|0)<24)}if(!j){y=x-32|0;v=z+(y+(ca(M-1|0,u)|0))|0;A=0;do{nrc(z+(y+(ca(A+M|0,u)|0))|0,v|0,o)|0;A=A+1|0;}while((A|0)<24)}t=t+1|0;}while((t|0)<4);r=r+1|0;}while((r|0)<(((c[m>>2]|0)==3?3:1)|0));return}function yOb(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=d+192|0;f=d+196|0;g=d+200|0;h=0;do{i=c[d+324+(h<<2)>>2]|0;j=c[e>>2]|0;k=c[f>>2]|0;l=c[g>>2]|0;if((l|0)>0){m=k-1|0;n=0;do{o=ca(n,j)|0;p=o-32|0;q=i+p|0;r=a[i+o|0]|0;s=r&255;t=ca(s,16843009)|0;u=(s*257|0)&65535;s=q;do{if((s&3|0)==0){v=0}else{if((s&1|0)==0){w=0}else{a[q]=r;w=1}if((s&2|0)==0){v=w;break}b[i+(w+p)>>1]=u;v=w|2}}while(0);s=28-v&-4;q=v+4+s|0;x=v;do{c[i+(x+p)>>2]=t;x=x+4|0;}while((x|0)<29);if((q|0)<31){b[i+(q+p)>>1]=u;y=v+s+6|0}else{y=q}if((y|0)!=32){a[i+(y+p)|0]=r}x=o+k|0;t=i+x|0;z=a[i+(m+o)|0]|0;A=z&255;B=ca(A,16843009)|0;C=(A*257|0)&65535;A=t;do{if((A&3|0)==0){D=0}else{if((A&1|0)==0){E=0}else{a[t]=z;E=1}if((A&2|0)==0){D=E;break}b[i+(E+x)>>1]=C;D=E|2}}while(0);A=28-D&-4;t=D+4+A|0;o=D;do{c[i+(o+x)>>2]=B;o=o+4|0;}while((o|0)<29);if((t|0)<31){b[i+(t+x)>>1]=C;F=D+A+6|0}else{F=t}if((F|0)!=32){a[i+(F+x)|0]=z}n=n+1|0;}while((n|0)<(l|0))}n=i-32|0;m=k+64|0;o=0;do{nrc(i+((ca(j,~o)|0)-32)|0,n|0,m)|0;o=o+1|0;}while((o|0)<32);o=i+((ca(l-1|0,j)|0)-32)|0;n=0;do{nrc(i+((ca(n+l|0,j)|0)-32)|0,o|0,m)|0;n=n+1|0;}while((n|0)<32);h=h+1|0;}while((h|0)<4);return}function zOb(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=c[d+18576>>2]|0;h=c[e+204+(f<<2)>>2]|0;i=c[e+156+(f<<2)>>2]|0;f=c[d+18560>>2]<<4;e=c[d+18564>>2]<<4>>g;j=32>>>(g>>>0);g=c[d+18572>>2]|0;if((e|0)>0){d=1<<g;k=(d|0)==1;l=32>>>(g>>>0)<<g;m=k^1;n=f-1-g|0;g=(d|0)<3;d=l-3|0;o=l-1|0;p=0;do{q=ca(p,i)|0;r=q-32|0;s=h+r|0;t=h+q|0;u=a[t]|0;do{if(k){v=(u&255)*257|0;w=7}else{x=b[t>>1]|0;if(g){v=x&65535;w=7;break}y=0;z=0;A=x;B=c[t>>2]|0}}while(0);do{if((w|0)==7){w=0;t=v*65537|0;x=v&65535;C=s;if((C&3|0)==0){y=0;z=1;A=x;B=t;break}do{if(k){if((C&1|0)==0){D=0;break}a[s]=u;D=1}else{D=0}}while(0);if((C&2|0)==0){y=D;z=1;A=x;B=t;break}b[h+(D+r)>>1]=x;y=D|2;z=1;A=x;B=t}}while(0);if((y|0)<(d|0)){s=y;while(1){c[h+(s+r)>>2]=B;E=s+4|0;if((E|0)<(d|0)){s=E}else{F=E;break}}}else{F=y}do{if(z){if((F|0)<(o|0)){b[h+(F+r)>>1]=A;G=F+2|0}else{G=F}if((G|0)==(l|0)|m){break}a[h+(G+r)|0]=u}}while(0);u=q+f|0;r=h+u|0;s=h+(n+q)|0;E=a[s]|0;do{if(k){H=(E&255)*257|0;w=24}else{I=b[s>>1]|0;if(g){H=I&65535;w=24;break}J=0;K=0;L=I;M=c[s>>2]|0}}while(0);do{if((w|0)==24){w=0;s=H*65537|0;q=H&65535;I=r;if((I&3|0)==0){J=0;K=1;L=q;M=s;break}do{if(k){if((I&1|0)==0){N=0;break}a[r]=E;N=1}else{N=0}}while(0);if((I&2|0)==0){J=N;K=1;L=q;M=s;break}b[h+(N+u)>>1]=q;J=N|2;K=1;L=q;M=s}}while(0);if((J|0)<(d|0)){r=J;while(1){c[h+(r+u)>>2]=M;t=r+4|0;if((t|0)<(d|0)){r=t}else{O=t;break}}}else{O=J}do{if(K){if((O|0)<(o|0)){b[h+(O+u)>>1]=L;P=O+2|0}else{P=O}if((P|0)==(l|0)|m){break}a[h+(P+u)|0]=E}}while(0);p=p+1|0;}while((p|0)<(e|0))}if((j|0)<=0){return}p=h-32|0;P=f+64|0;f=0;do{nrc(h+((ca(i,~f)|0)-32)|0,p|0,P)|0;f=f+1|0;}while((f|0)<(j|0));f=h+((ca(e-1|0,i)|0)-32)|0;p=0;do{nrc(h+((ca(p+e|0,i)|0)-32)|0,f|0,P)|0;p=p+1|0;}while((p|0)<(j|0));return}function AOb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=e+152|0;if((c[f>>2]|0)<=0){return}g=d+28|0;h=d+32|0;i=d+18560|0;j=d+18564|0;k=d+160|0;l=d+18572|0;m=d+18576|0;d=0;do{n=c[g>>2]|0;if((d|0)==0){o=0;p=0}else{o=(c[m>>2]|0)!=0|0;p=(c[l>>2]|0)!=0|0}q=c[h>>2]|0;r=q>>o;s=c[i>>2]<<4;t=(c[j>>2]<<4)-q>>o;if((s|0)!=(n|0)&(r|0)>0){q=e+156+(d<<2)|0;u=e+204+(d<<2)|0;v=~p;w=1<<p;x=(w|0)==1;y=s-n>>p<<p;z=x^1;A=(w|0)<3;if(x){x=0;do{w=(ca(c[q>>2]|0,x)|0)+n|0;B=c[u>>2]|0;C=B+w|0;D=a[B+(w+v)|0]|0;E=D&255;F=ca(E,16843009)|0;G=(E*257|0)&65535;E=C;do{if((E&3|0)==0){H=0}else{if((E&1|0)==0){I=0}else{a[C]=D;I=1}if((E&2|0)==0){H=I;break}b[B+(I+w)>>1]=G;H=I|2}}while(0);E=y-3|0;if((H|0)<(E|0)){C=H;while(1){c[B+(C+w)>>2]=F;J=C+4|0;if((J|0)<(E|0)){C=J}else{K=J;break}}}else{K=H}if((K|0)<(y-1|0)){b[B+(K+w)>>1]=G;L=K+2|0}else{L=K}if(!((L|0)==(y|0)|z)){a[B+(L+w)|0]=D}x=x+1|0;}while((x|0)<(r|0))}else{x=0;do{C=ca(c[q>>2]|0,x)|0;E=C+n|0;F=c[u>>2]|0;J=F+(E+v)|0;M=a[J]|0;N=b[J>>1]|0;do{if(A){O=(N&65535)*65537|0;P=F+E|0;if((P&3|0)==0|(P&2|0)==0){Q=0;R=1;S=O;break}b[F+(C+n)>>1]=N;Q=2;R=1;S=O}else{Q=0;R=0;S=c[J>>2]|0}}while(0);J=y-3|0;if((Q|0)<(J|0)){C=Q;while(1){c[F+(C+E)>>2]=S;D=C+4|0;if((D|0)<(J|0)){C=D}else{T=D;break}}}else{T=Q}do{if(R){if((T|0)<(y-1|0)){b[F+(T+E)>>1]=N;U=T+2|0}else{U=T}if((U|0)==(y|0)|z){break}a[F+(U+E)|0]=M}}while(0);x=x+1|0;}while((x|0)<(r|0))}}do{if((t|0)!=0){x=t+r|0;if((t|0)<=0){break}z=e+156+(d<<2)|0;y=e+204+(d<<2)|0;n=r-1|0;A=r;do{v=c[z>>2]|0;u=ca(v,A)|0;q=c[y>>2]|0;nrc(q+u|0,q+(ca(n-(c[k>>2]&~A)|0,v)|0)|0,s)|0;A=A+1|0;}while((A|0)<(x|0))}}while(0);d=d+1|0;}while((d|0)<(c[f>>2]|0));return}function BOb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a+15144|0;e=c[d>>2]|0;if((c[e+152>>2]|0)<=0){return}f=a+32|0;g=a+18564|0;h=b<<4;b=a+18576|0;a=0;i=e;while(1){if((a|0)==0){j=0}else{j=(c[b>>2]|0)!=0|0}e=c[i+156+(a<<2)>>2]|0;k=c[f>>2]|0;l=k>>j;m=(c[g>>2]<<4)-k>>j;k=c[i+204+(a<<2)>>2]|0;n=m+l|0;if((m|0)>0){m=k+((ca(l-1|0,e)|0)+h)|0;o=l;do{nrc(k+((ca(o,e)|0)+h)|0,m|0,16)|0;o=o+1|0;}while((o|0)<(n|0));p=c[d>>2]|0}else{p=i}n=a+1|0;if((n|0)<(c[p+152>>2]|0)){a=n;i=p}else{break}}return}function COb(a,b){a=a|0;b=b|0;c[a+11952>>2]=b;return}function DOb(a,b){a=a|0;b=b|0;if((c[a+11952>>2]|0)<(b|0)){while(1){}}else{return}}function EOb(a,b){a=a|0;b=b|0;c[a+1460>>2]=b;return}function FOb(a,b){a=a|0;b=b|0;if((c[a+1460>>2]|0)<(b|0)){while(1){}}else{return}}function GOb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+848|0;do{if((c[d>>2]|0)!=0){a=b+11972|0;e=c[a>>2]|0;c[a>>2]=e+1;if((e|0)<(c[d>>2]|0)){break}else{f=-1}return f|0}}while(0);f=0;return f|0}function HOb(a,b){a=a|0;b=b|0;var d=0,e=0;d=0;while(1){e=a+(d<<2)|0;if((c[e>>2]|0)==0){break}else{d=d+1|0}}c[e>>2]=b;return}function IOb(a){a=a|0;var b=0,d=0;if((c[a>>2]|0)==0){Cd(2349368,2287680,722,2649568);return 0}else{b=0}while(1){d=b+1|0;if((c[a+(d<<2)>>2]|0)==0){break}else{b=d}}d=a+(b<<2)|0;b=c[d>>2]|0;c[d>>2]=0;return b|0}function JOb(a,b){a=a|0;b=b|0;var d=0,e=0;d=0;while(1){if((c[a+(d<<2)>>2]|0)==0){break}else{d=d+1|0}}if((d|0)==0){c[a>>2]=b;return}else{e=d}while(1){d=e-1|0;c[a+(e<<2)>>2]=c[a+(d<<2)>>2];if((d|0)==0){break}else{e=d}}c[a>>2]=b;return}function KOb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a>>2]|0;d=(b|0)==0;do{if(!d){e=0;f=a;while(1){g=e+1|0;h=a+(g<<2)|0;c[f>>2]=c[h>>2];if((c[h>>2]|0)==0){break}else{e=g;f=h}}if(d){break}return b|0}}while(0);Cd(2237856,2287680,744,2649488);return 0}function LOb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=b+11960|0;f=c[e>>2]|0;if((f|0)<=0){Cd(2197192,2287680,750,2649512)}g=f-1|0;c[e>>2]=g;if((g|0)!=0){return}g=c[a+14964+((d[b+128|0]|0)<<2)>>2]|0;a=0;while(1){h=g+(a<<2)|0;if((c[h>>2]|0)==0){break}else{a=a+1|0}}c[h>>2]=b;return}function MOb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;e=i;i=i+4096|0;f=e|0;g=c[b+14964+(d<<2)>>2]|0;a:do{if((c[g>>2]|0)==0){switch(c[b+36>>2]&255|0){case 3:case 1:case 2:{h=3;break};case 8:case 9:case 10:case 11:case 12:{h=8;break};case 6:case 4:case 5:case 7:{h=6;break};default:{h=0}}j=b+18568|0;k=c[j>>2]|0;l=b+160|0;m=32<<c[l>>2];n=c[b>>2]|0;if((n&262144|0)==0){o=(n&139264|0)==0?16:32}else{o=64}n=MLb(12080)|0;p=n;do{if((n|0)!=0){mrc(n|0,0,12080)|0;q=c[b+18560>>2]|0;r=q<<4;s=c[b+18564>>2]|0;t=s<<4;u=o+63|0;v=-o|0;w=r+u&v;x=((w&1008|0)==0?o:0)+w|0;w=(h|0)==3;if((h|0)==8){c[n+152>>2]=3;c[n+168>>2]=r;c[n+180>>2]=t;c[n+156>>2]=x;c[n+172>>2]=r;c[n+184>>2]=t;c[n+160>>2]=x;c[n+176>>2]=r;c[n+188>>2]=t;c[n+164>>2]=x;y=3}else if((h|0)==6|(h|0)==3){c[n+152>>2]=2;c[n+168>>2]=r;c[n+180>>2]=t;c[n+156>>2]=x;c[n+172>>2]=q<<3;c[n+184>>2]=t>>(w&1);c[n+160>>2]=x;y=1}else{break}c[n+148>>2]=h;x=(r|0)/2|0;c[n+196>>2]=x;r=n+180|0;q=r;z=r;c[n+200>>2]=(t|0)/2|0;t=x+u&v;v=n+192|0;c[v>>2]=((t&2032|0)==0?o:0)+t;t=b+112|0;u=(c[t>>2]|0)+2|0;if((u|0)>0){x=n+7188|0;r=(s<<2)+31&-32;A=(u|0)>1?u:1;B=ca(A,r)|0;C=0;D=0;E=0;while(1){F=0;G=D;H=E;while(1){I=x+(C*72|0)+(F<<2)|0;c[I>>2]=G;c[f+(H<<2)>>2]=I;I=F+1|0;if((I|0)<(u|0)){F=I;G=G+r|0;H=H+1|0}else{break}}H=C+1|0;if((H|0)<(u|0)){C=H;D=D+B|0;E=E+A|0}else{break}}J=ca(B,u)|0;K=ca(A,u)|0}else{J=0;K=0}c[n+4>>2]=-1;c[n+16>>2]=0;c[n+20>>2]=0;E=n+24|0;c[E>>2]=-1;c[E+4>>2]=-1;c[n+92>>2]=-1;c[n+112>>2]=-1;c[n+11952>>2]=-1;a[n+128|0]=d;c[n+120>>2]=0;E=n+104|0;c[E>>2]=-1;c[E+4>>2]=-1;E=n+48|0;c[E>>2]=0;c[E+4>>2]=0;mrc(n+64|0,0,24)|0;mrc(n+11936|0,-1|0,16)|0;c[n+2772>>2]=p;do{if((h|0)==6|(h|0)==3){E=ca((c[n+184>>2]|0)+(m>>(w&1)<<1)|0,c[n+160>>2]|0)|0;D=n+348|0;c[D>>2]=J;C=K+1|0;c[f+(K<<2)>>2]=D;D=E+31&-32;E=D+J|0;if((c[l>>2]|0)==0){L=C;M=E;break}r=n+364|0;c[r>>2]=E;c[f+(C<<2)>>2]=r;L=K+2|0;M=E+D|0}else{L=K;M=J}}while(0);u=n+156|0;A=u;B=m<<1;D=b+560|0;E=(c[D>>2]|0)==0|(d|0)==0;r=n+344|0;C=n+360|0;x=0;H=M;G=L;while(1){F=ca((c[q+(x<<2)>>2]|0)+B|0,c[A+(x<<2)>>2]|0)|0;I=(F&1023|0)==0?F+128|0:F;F=r+(x<<2)|0;c[F>>2]=H;N=G+1|0;c[f+(G<<2)>>2]=F;do{if(E){F=I+31&-32;O=F+H|0;if((c[l>>2]|0)==0){P=N;Q=O;break}R=C+(x<<2)|0;c[R>>2]=O;c[f+(N<<2)>>2]=R;P=G+2|0;Q=O+F|0}else{F=(I<<2)+31&-32;O=F+H|0;if((c[l>>2]|0)==0){P=N;Q=O;break}R=C+(x<<2)|0;c[R>>2]=O;c[f+(N<<2)>>2]=R;P=G+2|0;Q=O+F|0}}while(0);N=x+1|0;if((N|0)<(y|0)){x=N;H=Q;G=P}else{break}}c[n+2768>>2]=0;G=(d|0)!=0;do{if(G){H=n+2776|0;c[H>>2]=Q;c[f+(P<<2)>>2]=H;H=k+31&-32;x=Q+H|0;E=n+2780|0;c[E>>2]=x;c[f+(P+1<<2)>>2]=E;E=x+H|0;x=n+2784|0;c[x>>2]=E;c[f+(P+2<<2)>>2]=x;x=k<<6;N=E+x|0;E=n+2792|0;c[E>>2]=N;c[f+(P+3<<2)>>2]=E;E=k<<2;I=N+(E+35&-32)|0;N=n+4372|0;c[N>>2]=I;F=P+5|0;c[f+(P+4<<2)>>2]=N;N=E+31&-32;E=I+N|0;if((c[t>>2]|0)==0){c[n+2788>>2]=0;c[n+4376>>2]=0;S=F;T=E}else{I=n+2788|0;c[I>>2]=E;c[f+(F<<2)>>2]=I;I=E+x|0;x=n+4376|0;c[x>>2]=I;c[f+(P+6<<2)>>2]=x;S=P+7|0;T=I+N|0}N=n+8488|0;c[N>>2]=T;c[f+(S<<2)>>2]=N;N=(s<<2)+31&-32;I=T+N|0;x=n+8492|0;c[x>>2]=I;c[f+(S+1<<2)>>2]=x;x=I+N|0;I=n+8496|0;c[I>>2]=x;E=S+3|0;c[f+(S+2<<2)>>2]=I;I=x+N|0;if((c[b+544>>2]|0)>2){N=n+356|0;c[N>>2]=I;c[f+(E<<2)>>2]=N;N=ca(c[u>>2]<<1,(c[z>>2]|0)+B|0)|0;U=S+4|0;V=((N<<c[b+15140>>2])+31&-32)+I|0}else{U=E;V=I}if((c[l>>2]|0)==0){W=U;X=V}else{I=n+2932|0;c[I>>2]=V;c[f+(U<<2)>>2]=I;W=U+1|0;X=V+H|0}if((c[b+600>>2]|0)==0){Y=W;Z=X;break}I=n+2936|0;c[I>>2]=X;c[f+(W<<2)>>2]=I;Y=W+1|0;Z=X+H|0}else{H=(c[b+15136>>2]|0)==0;do{if(H){_=P;$=Q}else{I=ca(((c[z>>2]|0)/2|0)+64|0,c[v>>2]|0)|0;E=n+376|0;c[E>>2]=Q;c[f+(P<<2)>>2]=E;E=c[t>>2]|0;N=(E|0)<0;x=(E|0)!=0|0;F=n+2796|0;O=n+4236|0;R=(E|0)>0?E<<1:0;aa=R+2|0;ba=((((I&1023|0)==0?I+128|0:I)<<2)+31&-32)+Q|0;I=P+1|0;da=0;while(1){if(N){ea=ba;fa=I}else{ga=(c[j>>2]<<2)+31&-32;ha=(ca(R,ga)|0)+ba|0;ia=ba;ja=I;ka=0;while(1){la=F+(da*68|0)+(ka<<2)|0;c[la>>2]=ia;c[f+(ja<<2)>>2]=la;la=ia+ga|0;ma=O+(da*68|0)+(ka<<2)|0;c[ma>>2]=la;c[f+(ja+1<<2)>>2]=ma;ma=ka+1|0;if((ma|0)>(E|0)){break}else{ia=la+ga|0;ja=ja+2|0;ka=ma}}ea=ha+(ga<<1)|0;fa=aa+I|0}ka=da+1|0;if((ka|0)>(x|0)){break}else{ba=ea;I=fa;da=ka}}da=n+8516|0;c[da>>2]=ea;I=fa+1|0;c[f+(fa<<2)>>2]=da;da=k<<1;ba=da+45&-32;x=ea+ba|0;aa=E+1|0;if((aa|0)<0){_=I;$=x;break}O=n+2940|0;F=da+37&-32;da=(aa|0)>0?aa:0;R=da+1|0;N=ca(R,F)|0;ka=da+(ca(aa,R)|0)+2|0;da=ba+(ca(ca(F,E+2|0)|0,R)|0)|0;ba=x;x=I;I=0;while(1){ja=ba;ia=x;ma=0;while(1){la=O+(I*72|0)+(ma<<2)|0;c[la>>2]=ja;c[f+(ia<<2)>>2]=la;la=ma+1|0;if((la|0)>(aa|0)){break}else{ja=ja+F|0;ia=ia+1|0;ma=la}}ma=I+1|0;if((ma|0)>(aa|0)){break}else{ba=ba+N|0;x=R+x|0;I=ma}}_=ka+fa|0;$=da+ea|0}}while(0);if((c[b+684>>2]|0)==0){Y=_;Z=$;break}I=n+8500|0;c[I>>2]=$;c[f+(_<<2)>>2]=I;I=c[j>>2]|0;x=(I<<2)+31&-32;R=x+$|0;N=n+8504|0;c[N>>2]=R;ba=_+2|0;c[f+(_+1<<2)>>2]=N;N=R+x|0;if(H){Y=ba;Z=N;break}x=n+8520|0;c[x>>2]=N;c[f+(ba<<2)>>2]=x;Y=_+3|0;Z=N+((I<<1)+37&-32)|0}}while(0);s=MLb(Z)|0;I=n;c[I>>2]=s;if((s|0)==0){break}do{if((Y|0)!=0){N=Y-1|0;x=c[f+(N<<2)>>2]|0;c[x>>2]=(c[x>>2]|0)+s;if((N|0)==0){break}else{na=N}do{na=na-1|0;N=c[f+(na<<2)>>2]|0;c[N>>2]=(c[N>>2]|0)+(c[I>>2]|0);}while((na|0)!=0)}}while(0);do{if((h|0)==6|(h|0)==3){I=(ca(c[n+160>>2]|0,m>>(w&1))|0)+32|0;c[n+208>>2]=(c[n+348>>2]|0)+I;if((c[l>>2]|0)==0){break}c[n+220>>2]=(c[n+364>>2]|0)+I}}while(0);w=n+204|0;I=n+228|0;s=n+216|0;H=n+276|0;if(G){N=(c[D>>2]|0)==0;x=0;do{ba=A+(x<<2)|0;R=c[ba>>2]|0;aa=ca((c[q+(x<<2)>>2]|0)+B|0,R)|0;F=(aa&1023|0)==0?aa+128|0:aa;aa=r+(x<<2)|0;if(N){O=(c[aa>>2]|0)+((ca(R,m)|0)+32)|0;c[w+(x<<2)>>2]=O;c[I+(x<<4)>>2]=O;O=(c[C+(x<<2)>>2]|0)+((ca(c[ba>>2]|0,m)|0)+32)|0;c[s+(x<<2)>>2]=O;c[H+(x<<4)>>2]=O}else{O=C+(x<<2)|0;E=(c[aa>>2]|0)+((ca(R,m)|0)+32)|0;c[I+(x<<4)>>2]=E;R=H+(x<<4)|0;c[R>>2]=(c[O>>2]|0)+((ca(c[ba>>2]|0,m)|0)+32);ma=F+32|0;c[I+(x<<4)+4>>2]=(c[aa>>2]|0)+((ca(c[ba>>2]|0,m)|0)+ma);c[H+(x<<4)+4>>2]=(c[O>>2]|0)+((ca(c[ba>>2]|0,m)|0)+ma);ma=(F<<1)+32|0;c[I+(x<<4)+8>>2]=(c[aa>>2]|0)+((ca(c[ba>>2]|0,m)|0)+ma);c[H+(x<<4)+8>>2]=(c[O>>2]|0)+((ca(c[ba>>2]|0,m)|0)+ma);ma=(F*3|0)+32|0;c[I+(x<<4)+12>>2]=(c[aa>>2]|0)+((ca(c[ba>>2]|0,m)|0)+ma);c[H+(x<<4)+12>>2]=(c[O>>2]|0)+((ca(c[ba>>2]|0,m)|0)+ma);c[w+(x<<2)>>2]=E;c[s+(x<<2)>>2]=c[R>>2]}x=x+1|0;}while((x|0)<(y|0))}else{x=0;do{N=A+(x<<2)|0;B=(c[r+(x<<2)>>2]|0)+((ca(c[N>>2]|0,m)|0)+32)|0;c[w+(x<<2)>>2]=B;c[I+(x<<4)>>2]=B;B=(c[C+(x<<2)>>2]|0)+((ca(c[N>>2]|0,m)|0)+32)|0;c[s+(x<<2)>>2]=B;c[H+(x<<4)>>2]=B;x=x+1|0;}while((x|0)<(y|0))}do{if(G){x=n+2792|0;c[c[x>>2]>>2]=0;c[x>>2]=(c[x>>2]|0)+4;if((c[b+544>>2]|0)<=2){break}c[n+340>>2]=(c[n+356>>2]|0)+((ca(c[u>>2]|0,m)|0)+32<<1)}else{if((c[b+15136>>2]|0)==0){break}x=c[v>>2]|0;H=ca(((c[z>>2]|0)/2|0)+64|0,x)|0;s=(H&1023|0)==0?H+128|0:H;H=c[n+376>>2]|0;C=(x<<5)+32|0;c[n+324>>2]=H+C;c[n+328>>2]=H+(C+s);c[n+332>>2]=H+(C+(s<<1));c[n+336>>2]=H+(C+(s*3|0));s=n+2796|0;C=0;H=c[t>>2]|0;while(1){if((H|0)<0){oa=H}else{x=0;while(1){mrc(c[s+(C*68|0)+(x<<2)>>2]|0,0,c[j>>2]<<2|0)|0;I=x+1|0;w=c[t>>2]|0;if((I|0)>(w|0)){oa=w;break}else{x=I}}}x=C+1|0;if((x|0)>((oa|0)!=0|0)){break}else{C=x;H=oa}}H=c[n+2940>>2]|0;c[n+8512>>2]=H;mrc(H|0,-1|0,(k<<1)+6|0)|0;if((c[b+684>>2]|0)==0){break}mrc(c[n+8520>>2]|0,0,(c[j>>2]<<1)+6|0)|0}}while(0);c[n+12020>>2]=c[b+38028>>2];pa=p;break a}}while(0);NLb(n);qa=0;i=e;return qa|0}else{p=0;while(1){j=p+1|0;if((c[g+(j<<2)>>2]|0)==0){break}else{p=j}}n=g+(p<<2)|0;j=c[n>>2]|0;c[n>>2]=0;pa=j}}while(0);if((pa|0)==0){qa=0;i=e;return qa|0}a[pa+129|0]=0;c[pa+11960>>2]=1;c[pa+8508>>2]=0;c[pa+8524>>2]=1;c[pa+124>>2]=0;c[pa+11992>>2]=0;if((c[b+12>>2]|0)==0){ra=1}else{ra=c[b+4>>2]|0}c[pa+11972>>2]=ra;mrc(pa+400|0,0,2304)|0;mrc(pa+8528|0,0,72)|0;qa=pa;i=e;return qa|0}function NOb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=b+11960|0;e=c[d>>2]|0;if((e|0)<=0){Cd(2197192,2287680,781,2649536)}f=e-1|0;c[d>>2]=f;if((f|0)!=0){return}f=c[a+14972>>2]|0;a=0;while(1){g=f+(a<<2)|0;if((c[g>>2]|0)==0){break}else{a=a+1|0}}c[g>>2]=b;return}function OOb(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+14972>>2]|0;if((c[b>>2]|0)==0){d=MLb(12080)|0}else{a=0;while(1){e=a+1|0;if((c[b+(e<<2)>>2]|0)==0){break}else{a=e}}e=b+(a<<2)|0;a=c[e>>2]|0;c[e>>2]=0;d=a}if((d|0)==0){f=0;return f|0}c[d+2768>>2]=1;c[d+11960>>2]=1;f=d;return f|0}function POb(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((h|0)<=0){return}a=g-8|0;j=(a|0)>0;k=i+44|0;l=d<<4;m=f<<4;n=e;e=h;h=b;while(1){if(j){b=(e|0)<16?e:16;o=0;while(1){_e[c[(c[k>>2]|0)+16>>2]&511](h+o|0,d,n+o|0,f,i,b);p=o+16|0;if((p|0)<(a|0)){o=p}else{q=p;break}}}else{q=0}if((q|0)<(g|0)){_e[c[(c[k>>2]|0)+8>>2]&511](h+q|0,d,n+q|0,f,i,(e|0)<16?e:16)}o=e-16|0;if((o|0)>0){n=n+m|0;e=o;h=h+l|0}else{break}}return}function QOb(a){a=a|0;var b=0,d=0,e=0;if((a|0)==0){return}b=c[a>>2]|0;if((b|0)!=0){d=0;e=b;do{d=d+1|0;uOb(e);e=c[a+(d<<2)>>2]|0;}while((e|0)!=0)}NLb(a);return}function ROb(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)<0){d=-1;return d|0}c[a+4>>2]=b;c[a+8>>2]=0;e=(b<<2)+4|0;b=MLb(e)|0;c[a>>2]=b;if((b|0)==0){d=-1;return d|0}mrc(b|0,0,e|0)|0;d=0;return d|0}function SOb(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;if((b|0)==0){return}a=c[b>>2]|0;if((a|0)!=0){d=0;e=a;do{d=d+1|0;uOb(e);e=c[b+(d<<2)>>2]|0;}while((e|0)!=0)}NLb(b);return}function TOb(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+8|0;e=c[d>>2]|0;if((e|0)==(c[a+4>>2]|0)){while(1){}}else{c[d>>2]=e+1;c[(c[a>>2]|0)+(e<<2)>>2]=b;return}}function UOb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=e<<1&2;g=e>>1;h=g<<1;if((c[b+3240>>2]|0)!=0){i=g<<4|f|12;if(!((a[b+28104+i|0]|0)>-1)){XOb(b,f,h,2,2);return}if((a[b+28144+i|0]|0)>-1){WOb(b,f,h,2,2);return}else{VOb(b,f,h,2,2);return}}i=d[b+19352+e|0]|0;if((i|0)==0){VOb(b,f,h,1,1);e=f|1;VOb(b,e,h,1,1);g=h|1;VOb(b,f,g,1,1);VOb(b,e,g,1,1);return}else if((i|0)==1){VOb(b,f,h,2,1);VOb(b,f,h|1,2,1);return}else if((i|0)==2){VOb(b,f,h,1,2);VOb(b,f|1,h,1,2);return}else if((i|0)==3){VOb(b,f,h,2,2);return}else{return}}function VOb(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=e+12+(f<<3)|0;j=a[d+28104+i|0]|0;k=b[d+28192+(i<<2)>>1]|0;l=c[d+18668>>2]|0;m=c[d+18676>>2]|0;if((k|0)<(l|0)){n=l}else{n=(k|0)>(m|0)?m:k}k=n+(e<<4)|0;n=b[d+28192+(i<<2)+2>>1]|0;i=c[d+18672>>2]|0;m=c[d+18680>>2]|0;if((n|0)<(i|0)){o=i}else{o=(n|0)>(m|0)?m:n}n=o+(f<<4)|0;o=d+37376|0;m=(f<<7)+(e<<2)|0;i=g<<2;l=h<<2;Te[c[o>>2]&255]((c[d+24568>>2]|0)+m|0,32,d+24588+(j*48|0)|0,c[d+27916>>2]|0,k,n,i,l,d+3584+(j*144|0)|0);if((c[d+8632>>2]|0)==3){Te[c[o>>2]&255]((c[d+24572>>2]|0)+m|0,32,d+24588+(j*48|0)+16|0,c[d+27920>>2]|0,k,n,i,l,d+3584+(j*144|0)+48|0);Te[c[o>>2]&255]((c[d+24576>>2]|0)+m|0,32,d+24588+(j*48|0)+32|0,c[d+27924>>2]|0,k,n,i,l,d+3584+(j*144|0)+96|0);return}i=c[d+18576>>2]|0;if((i&j&c[d+18660>>2]|0)==0){p=n}else{p=n-2+(c[d+18612>>2]<<2&4)|0}n=(ca(128>>>(i>>>0),f)|0)+(e<<1)|0;e=l>>i;l=d+24572|0;f=d+24576|0;Te[c[d+37384>>2]&255]((c[l>>2]|0)+n|0,(c[f>>2]|0)+n|0,32,c[d+24588+(j*48|0)+16>>2]|0,c[d+27920>>2]|0,k,p<<1>>i,g<<1,e);i=c[d+3584+(j*144|0)+92>>2]|0;if((i|0)!=0){p=(c[l>>2]|0)+n|0;_e[c[i+(g>>1<<2)>>2]&511](p,32,p,32,d+3584+(j*144|0)+48|0,e)}p=c[d+3584+(j*144|0)+140>>2]|0;if((p|0)==0){return}i=(c[f>>2]|0)+n|0;_e[c[p+(g>>1<<2)>>2]&511](i,32,i,32,d+3584+(j*144|0)+96|0,e);return}function WOb(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;k=i;i=i+592|0;l=k|0;m=k+8|0;n=f+12+(g<<3)|0;o=a[e+28104+n|0]|0;p=a[e+28144+n|0]|0;q=a[(c[e+30412>>2]|0)+(o<<2)+p|0]|0;r=b[e+28192+(n<<2)>>1]|0;s=c[e+18668>>2]|0;t=c[e+18676>>2]|0;if((r|0)<(s|0)){u=s}else{u=(r|0)>(t|0)?t:r}r=f<<4;v=u+r|0;u=b[e+28352+(n<<2)>>1]|0;if((u|0)<(s|0)){w=s}else{w=(u|0)>(t|0)?t:u}u=w+r|0;r=b[e+28192+(n<<2)+2>>1]|0;w=c[e+18672>>2]|0;t=c[e+18680>>2]|0;if((r|0)<(w|0)){x=w}else{x=(r|0)>(t|0)?t:r}r=g<<4;s=x+r|0;x=b[e+28352+(n<<2)+2>>1]|0;if((x|0)<(w|0)){y=w}else{y=(x|0)>(t|0)?t:x}x=y+r|0;r=d[18704+(j*5|0)+h|0]|0;c[l>>2]=16;c[m>>2]=16;y=k+47&-32;t=k+335&-32;w=e+37380|0;n=e+27916|0;z=h<<2;A=j<<2;j=Ke[c[w>>2]&63](y,l,e+24588+(o*48|0)|0,c[n>>2]|0,v,s,z,A,2772248)|0;B=Ke[c[w>>2]&63](t,m,e+26124+(p*48|0)|0,c[n>>2]|0,u,x,z,A,2772248)|0;n=e+37388+(r<<2)|0;C=(g<<7)+(f<<2)|0;Se[c[n>>2]&1023]((c[e+24568>>2]|0)+C|0,32,j,c[l>>2]|0,B,c[m>>2]|0,q);if((c[e+8632>>2]|0)==3){B=e+27920|0;j=Ke[c[w>>2]&63](y,l,e+24588+(o*48|0)+16|0,c[B>>2]|0,v,s,z,A,2772248)|0;D=Ke[c[w>>2]&63](t,m,e+26124+(p*48|0)+16|0,c[B>>2]|0,u,x,z,A,2772248)|0;Se[c[n>>2]&1023]((c[e+24572>>2]|0)+C|0,32,j,c[l>>2]|0,D,c[m>>2]|0,q);D=e+27924|0;j=Ke[c[w>>2]&63](y,l,e+24588+(o*48|0)+32|0,c[D>>2]|0,v,s,z,A,2772248)|0;B=Ke[c[w>>2]&63](t,m,e+26124+(p*48|0)+32|0,c[D>>2]|0,u,x,z,A,2772248)|0;Se[c[n>>2]&1023]((c[e+24576>>2]|0)+C|0,32,j,c[l>>2]|0,B,c[m>>2]|0,q);i=k;return}m=c[e+18576>>2]|0;B=c[e+18660>>2]|0;if((m&o&B|0)==0){E=s}else{E=s-2+(c[e+18612>>2]<<2&4)|0}if((m&p&B|0)==0){F=x}else{F=x-2+(c[e+18612>>2]<<2&4)|0}x=e+37384|0;B=y+8|0;s=e+27920|0;l=h<<1;h=A>>m;Te[c[x>>2]&255](y,B,16,c[e+24588+(o*48|0)+16>>2]|0,c[s>>2]|0,v,E<<1>>m,l,h);E=t+8|0;Te[c[x>>2]&255](t,E,16,c[e+26124+(p*48|0)+16>>2]|0,c[s>>2]|0,u,F<<1>>m,l,h);h=(ca(128>>>(m>>>0),g)|0)+(f<<1)|0;f=e+37388+(d[e+36448+r|0]<<2)|0;Se[c[f>>2]&1023]((c[e+24572>>2]|0)+h|0,32,y,16,t,16,q);Se[c[f>>2]&1023]((c[e+24576>>2]|0)+h|0,32,B,16,E,16,q);i=k;return}function XOb(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=e+12+(f<<3)|0;j=a[d+28144+i|0]|0;k=b[d+28352+(i<<2)>>1]|0;l=c[d+18668>>2]|0;m=c[d+18676>>2]|0;if((k|0)<(l|0)){n=l}else{n=(k|0)>(m|0)?m:k}k=n+(e<<4)|0;n=b[d+28352+(i<<2)+2>>1]|0;i=c[d+18672>>2]|0;m=c[d+18680>>2]|0;if((n|0)<(i|0)){o=i}else{o=(n|0)>(m|0)?m:n}n=o+(f<<4)|0;o=d+37376|0;m=(f<<7)+(e<<2)|0;i=g<<2;l=h<<2;Te[c[o>>2]&255]((c[d+24568>>2]|0)+m|0,32,d+26124+(j*48|0)|0,c[d+27916>>2]|0,k,n,i,l,2772248);if((c[d+8632>>2]|0)==3){Te[c[o>>2]&255]((c[d+24572>>2]|0)+m|0,32,d+26124+(j*48|0)+16|0,c[d+27920>>2]|0,k,n,i,l,2772248);Te[c[o>>2]&255]((c[d+24576>>2]|0)+m|0,32,d+26124+(j*48|0)+32|0,c[d+27924>>2]|0,k,n,i,l,2772248);return}i=c[d+18576>>2]|0;if((i&j&c[d+18660>>2]|0)==0){p=n}else{p=n-2+(c[d+18612>>2]<<2&4)|0}n=(ca(128>>>(i>>>0),f)|0)+(e<<1)|0;Te[c[d+37384>>2]&255]((c[d+24572>>2]|0)+n|0,(c[d+24576>>2]|0)+n|0,32,c[d+26124+(j*48|0)+16>>2]|0,c[d+27920>>2]|0,k,p<<1>>i,g<<1,l>>i);return}function YOb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[b+19348>>2]|0;if((d|0)==13){UOb(b,0);UOb(b,1);UOb(b,2);UOb(b,3);return}e=a[b+28116|0]|0;f=a[b+28134|0]|0;g=a[b+28156|0]|0;h=a[b+28174|0]|0;if((d|0)==15){do{if(e<<24>>24>-1){if(g<<24>>24>-1){WOb(b,0,0,2,4);break}else{VOb(b,0,0,2,4);break}}else{XOb(b,0,0,2,4)}}while(0);if(!(f<<24>>24>-1)){XOb(b,2,0,2,4);return}if(h<<24>>24>-1){WOb(b,2,0,2,4);return}else{VOb(b,2,0,2,4);return}}else if((d|0)==16){if(!(e<<24>>24>-1)){XOb(b,0,0,4,4);return}if(g<<24>>24>-1){WOb(b,0,0,4,4);return}else{VOb(b,0,0,4,4);return}}else if((d|0)==14){do{if(e<<24>>24>-1){if(g<<24>>24>-1){WOb(b,0,0,4,2);break}else{VOb(b,0,0,4,2);break}}else{XOb(b,0,0,4,2)}}while(0);if(!(f<<24>>24>-1)){XOb(b,0,2,4,2);return}if(h<<24>>24>-1){WOb(b,0,2,4,2);return}else{VOb(b,0,2,4,2);return}}else{return}}function ZOb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=i;i=i+4096|0;d=b|0;e=c[a+18568>>2]|0;f=c[a+18560>>2]|0;c[a+18580>>2]=f;c[a+18584>>2]=f<<1;c[a+18588>>2]=f<<2;f=a+160|0;g=c[f>>2]|0;c[a+18660>>2]=g;h=a+18964|0;c[h>>2]=0;c[d>>2]=h;h=e+31&-32;j=a+18968|0;c[j>>2]=h;c[d+4>>2]=j;j=e<<1;k=j+31&-32;l=k+h|0;m=a+19268|0;c[m>>2]=l;c[d+8>>2]=m;m=l+h|0;l=a+19272|0;c[l>>2]=m;c[d+12>>2]=l;n=m+k|0;k=a+18972|0;c[k>>2]=n;c[d+16>>2]=k;k=n+((e<<3)+31&-32)|0;n=a+18976|0;c[n>>2]=k;c[d+20>>2]=n;n=k+((e*48|0)+31&-32)|0;do{if((c[a+152>>2]|0)==0){o=n;p=6}else{k=a+19264|0;c[k>>2]=n;c[d+24>>2]=k;k=n+h|0;m=a+18980|0;c[m>>2]=k;c[d+28>>2]=m;m=k+h|0;k=a+18992|0;c[k>>2]=m;c[d+32>>2]=k;k=(e<<4)+31&-32;q=m+k|0;if((c[a+112>>2]|0)==0){o=q;p=9;break}m=a+18996|0;c[m>>2]=q;c[d+36>>2]=m;o=q+k|0;p=10}}while(0);h=a+124|0;n=a+528|0;k=(e<<2)+35&-32;e=a+88|0;q=c[e>>2]|0;m=((q|0)>16?16:q)<<g;if((c[n>>2]|0)==2){g=m+2|0;r=(g|0)>16?16:g}else{r=m}if((r|0)>1){m=ca(k,r-1|0)|0;g=r+p|0;q=p;s=o;t=1;while(1){u=a+19008+(t<<2)|0;c[u>>2]=s;c[d+(q<<2)>>2]=u;u=t+1|0;if((u|0)<(r|0)){q=q+1|0;s=s+k|0;t=u}else{break}}v=g-1|0;w=o+m|0}else{v=p;w=o}o=((c[h>>2]|0)!=0?2:1)<<c[f>>2];p=c[n>>2]|0;if((p|0)==2){m=o+2|0;x=(m|0)>16?16:m}else{x=o}if((x|0)>0){o=ca(k,x)|0;m=x+v|0;g=v;t=w;s=0;while(1){q=a+19136+(s<<2)|0;c[q>>2]=t;c[d+(g<<2)>>2]=q;q=s+1|0;if((q|0)<(x|0)){g=g+1|0;t=t+k|0;s=q}else{break}}y=m;z=w+o|0;A=c[n>>2]|0}else{y=v;z=w;A=p}do{if((A|0)==0){B=z;C=y}else{p=32<<c[f>>2];if((A|0)==-1){if((c[a+24>>2]|0)!=0){if((c[a+860+(c[a+4>>2]<<2)>>2]|0)!=(a|0)){B=z;C=y;break}}D=1;E=ca((c[a+18564>>2]<<3)+(p<<1)|0,c[(c[a+15148>>2]|0)+192>>2]|0)|0}else{w=ca((ca(16<<((c[a+8632>>2]|0)==2),c[a+18564>>2]|0)|0)+(p<<1)|0,c[(c[a+15148>>2]|0)+156>>2]|0)|0;D=(A|0)==2?2:1;E=w}w=E+31&-32;p=D>>>0>1>>>0?D:1;v=(ca(w,p)|0)+z|0;o=y;m=z;s=0;while(1){k=a+19280+(s<<2)|0;c[k>>2]=m;c[d+(o<<2)>>2]=k;k=s+1|0;if((k|0)<(D|0)){o=o+1|0;m=m+w|0;s=k}else{break}}B=v;C=p+y|0}}while(0);y=MLb(B)|0;B=a+18952|0;c[B>>2]=y;if((y|0)==0){F=-1;i=b;return F|0}a:do{if((C|0)!=0){D=C;z=y;while(1){E=D-1|0;A=c[d+(E<<2)>>2]|0;c[A>>2]=(c[A>>2]|0)+z;if((E|0)==0){break a}D=E;z=c[B>>2]|0}}}while(0);mrc(c[l>>2]|0,-1|0,j|0)|0;j=c[e>>2]|0;e=((j|0)>16?16:j)<<c[f>>2];if((c[n>>2]|0)==2){j=e+2|0;G=(j|0)>16?16:j}else{G=e}if((G|0)>1){e=1;do{j=a+19008+(e<<2)|0;c[c[j>>2]>>2]=0;c[j>>2]=(c[j>>2]|0)+4;e=e+1|0;}while((e|0)<(G|0))}G=((c[h>>2]|0)!=0?2:1)<<c[f>>2];if((c[n>>2]|0)==2){n=G+2|0;H=(n|0)>16?16:n}else{H=G}if((H|0)>0){I=0}else{F=0;i=b;return F|0}while(1){G=a+19136+(I<<2)|0;c[c[G>>2]>>2]=0;c[G>>2]=(c[G>>2]|0)+4;G=I+1|0;if((G|0)<(H|0)){I=G}else{F=0;break}}i=b;return F|0}function _Ob(a){a=a|0;NLb(c[a+18952>>2]|0);return}function $Ob(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a:do{if((b|0)==0){d=a+160|0;e=a+8632|0;f=a+8416|0;g=0;do{h=0;do{i=MLb((c[f>>2]<<4)+32|0)|0;j=a+36464+(g*12|0)+(h<<2)|0;c[j>>2]=i;if((i|0)==0){break a}c[j>>2]=i+16;h=h+1|0;}while((h|0)<(((c[e>>2]|0)==3?3:2)|0));g=g+1|0;k=c[d>>2]|0;}while((g|0)<(((k|0)!=0?5:2)|0));if((k|0)>=0){g=a+12|0;e=a+18560|0;f=a+36528|0;h=a+860|0;i=a+18568|0;j=a+36524|0;l=0;do{do{if((c[g>>2]|0)==0){m=MLb(c[e>>2]<<6)|0;n=m;c[a+36524+(l<<2)>>2]=n;if((m|0)==0){break a}else{o=n}}else{n=c[h>>2]|0;if((n|0)==(a|0)&(l|0)==0){m=MLb(c[i>>2]<<6)|0;p=m;c[j>>2]=p;if((m|0)==0){break a}else{o=p;break}}else{p=c[n+36524>>2]|0;c[a+36524+(l<<2)>>2]=p;o=p;break}}}while(0);c[f>>2]=o;l=l+1|0;}while((l|0)<=(c[d>>2]|0))}d=(c[(c[(c[a+860>>2]|0)+15148>>2]|0)+168>>2]<<1)+160|0;l=ca(c[a+620>>2]<<5,((c[a+28>>2]|0)/4|0)+3|0)|0;f=c[a+548>>2]|0;j=c[a+552>>2]|0;i=(f|0)<(j|0)?f:j;j=(i<<2)+48+(ca((i<<5)+32|0,i+4|0)|0)&-((c[a+544>>2]|0)>2|0);i=(l|0)>(j|0)?l:j;q=(d|0)>(i|0)?d:i;r=16}else{q=0;r=16}}while(0);do{if((r|0)==16){o=ca((c[a+18560>>2]|0)+7&-8,c[a+692>>2]|0)|0;k=o<<1;b=(q|0)>(k|0)?q:k;if((b|0)==0){c[a+36456>>2]=0}else{k=MLb(b)|0;c[a+36456>>2]=k;if((k|0)==0){break}}k=((c[a+8>>2]|0)*36|0)+(c[a+18564>>2]|0)<<3;b=o*24|0;o=MLb((k|0)>(b|0)?k:b)|0;c[a+36460>>2]=o;if((o|0)==0){break}else{s=0}return s|0}}while(0);s=-1;return s|0}function aPb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((b|0)!=0){d=a+36456|0;e=c[d>>2]|0;NLb(e);f=a+36460|0;g=c[f>>2]|0;NLb(g);return}b=a+160|0;h=c[b>>2]|0;if((h|0)>=0){i=a+12|0;j=a+860|0;k=0;l=h;while(1){if((c[i>>2]|0)==0){m=7}else{if((c[j>>2]|0)==(a|0)&(k|0)==0){m=7}else{n=l}}if((m|0)==7){m=0;NLb(c[a+36524+(k<<2)>>2]|0);n=c[b>>2]|0}h=k+1|0;if((h|0)>(n|0)){break}else{k=h;l=n}}}n=a+8632|0;l=0;do{k=0;do{NLb((c[a+36464+(l*12|0)+(k<<2)>>2]|0)-16|0);k=k+1|0;}while((k|0)<(((c[n>>2]|0)==3?3:2)|0));l=l+1|0;}while((l|0)<(((c[b>>2]|0)!=0?5:2)|0));d=a+36456|0;e=c[d>>2]|0;NLb(e);f=a+36460|0;g=c[f>>2]|0;NLb(g);return}function bPb(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=d+15148|0;f=c[e>>2]|0;c[d+18984>>2]=c[f+2784>>2];c[d+18988>>2]=c[f+2788>>2];c[d+19008>>2]=c[f+2792>>2];c[d+19e3>>2]=c[f+4372>>2];c[d+19004>>2]=c[f+4376>>2];c[d+18956>>2]=c[f+2776>>2];c[d+18960>>2]=c[f+2780>>2];c[d+19276>>2]=c[f+2932>>2];g=d+15152|0;c[f+4380>>2]=c[g>>2];h=d+15156|0;c[f+4384>>2]=c[h>>2];i=c[g>>2]|0;if((i|0)>0){j=0;while(1){c[f+4388+(j<<2)>>2]=c[(c[d+15160+(j<<2)>>2]|0)+4>>2];k=j+1|0;l=c[g>>2]|0;if((k|0)<(l|0)){j=k}else{m=l;break}}}else{m=i}i=c[d+3240>>2]|0;do{if((i|0)==1){if((c[h>>2]|0)>0){j=0;do{c[f+4452+(j<<2)>>2]=c[(c[d+15236+(j<<2)>>2]|0)+4>>2];j=j+1|0;}while((j|0)<(c[h>>2]|0))}a[d+30417|0]=-1;a[d+30416|0]=-2;j=d+15236|0;l=c[j>>2]|0;if((c[l+4380>>2]|0)>0){k=0;n=l;do{l=c[n+4388+(k<<2)>>2]|0;o=k+2+(d+30416)|0;a[o]=-2;p=c[g>>2]|0;q=0;while(1){if((q|0)>=(p|0)){break}if((c[(c[d+15160+(q<<2)>>2]|0)+4>>2]|0)==(l|0)){r=10;break}else{q=q+1|0}}if((r|0)==10){r=0;a[o]=q}k=k+1|0;n=c[j>>2]|0;}while((k|0)<(c[n+4380>>2]|0))}s=c[g>>2]|0}else if((i|0)==0){if((c[d+8348>>2]|0)==1){s=m;break}if((c[d+528>>2]|0)!=2){s=m;break}a[d+30440|0]=-2;a[d+30441|0]=-1;n=d+3260|0;if((m<<c[n>>2]|0)<=0){s=m;break}k=d+18660|0;j=0;while(1){if((c[k>>2]|0)==0){a[j+2+(d+30440)|0]=c[(c[d+15160+(j<<2)>>2]|0)+112>>2]&63}else{a[j+2+(d+30440)|0]=c[(c[d+15160+(j>>1<<2)>>2]|0)+112>>2]<<1&126|j&1}l=j+1|0;p=c[g>>2]|0;if((l|0)<(p<<c[n>>2]|0)){j=l}else{s=p;break}}}else{s=m}}while(0);mrc(d+28104|0,-2|0,80)|0;if((s|0)<=0){t=d+18860|0;c[t>>2]=15;u=d+18852|0;c[u>>2]=15;v=d+18840|0;c[v>>2]=15;w=d+18828|0;c[w>>2]=15;x=d+18800|0;c[x>>2]=11;y=d+18864|0;c[y>>2]=11;z=d+18856|0;c[z>>2]=11;A=d+18848|0;c[A>>2]=11;B=d+18832|0;c[B>>2]=11;C=d+18816|0;c[C>>2]=11;return}s=c[d+3260>>2]|0;if((s|0)<0){t=d+18860|0;c[t>>2]=15;u=d+18852|0;c[u>>2]=15;v=d+18840|0;c[v>>2]=15;w=d+18828|0;c[w>>2]=15;x=d+18800|0;c[x>>2]=11;y=d+18864|0;c[y>>2]=11;z=d+18856|0;c[z>>2]=11;A=d+18848|0;c[A>>2]=11;B=d+18832|0;c[B>>2]=11;C=d+18816|0;c[C>>2]=11;return}m=c[e>>2]|0;e=m+4|0;g=c[d+15160>>2]|0;i=c[g+4>>2]|0;r=0;do{h=(c[m+8+(r<<2)>>2]|0)+(c[e>>2]|0)-i-(c[g+8+(r<<2)>>2]|0)|0;b[m+4516+(r<<1)>>1]=(((h|0)/2|0)+256|0)/(h|0)|0;r=r+1|0;}while((r|0)<=(s|0));t=d+18860|0;c[t>>2]=15;u=d+18852|0;c[u>>2]=15;v=d+18840|0;c[v>>2]=15;w=d+18828|0;c[w>>2]=15;x=d+18800|0;c[x>>2]=11;y=d+18864|0;c[y>>2]=11;z=d+18856|0;c[z>>2]=11;A=d+18848|0;c[A>>2]=11;B=d+18832|0;c[B>>2]=11;C=d+18816|0;c[C>>2]=11;return}function cPb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[a+18628>>2]=c[a+544>>2];b=c[a+560>>2]|0;d=a+18632|0;c[d>>2]=b;e=c[a+3240>>2]|0;f=(e|0)==1;do{if(f){if(!((b|0)==6|(b|0)==8)){g=b;break}h=b-1|0;c[d>>2]=h;g=h}else{g=b}}while(0);do{if((c[a+564>>2]|0)==0){c[a+18636>>2]=0;if((e|0)==1){i=1}else{j=e;k=9}}else{b=(e|0)==0&(g|0)>4;if(b|f^1){c[a+18636>>2]=b&1;j=b?0:e;k=9;break}else{c[a+18636>>2]=(g|0)>8;i=1;break}}}while(0);do{if((k|0)==9){if((c[a+580>>2]|0)==0){i=0;break}i=(j|0)!=2|0}}while(0);c[a+18648>>2]=i;c[a+18896>>2]=-1;c[a+24544>>2]=a+19424;c[a+24568>>2]=a+20256;c[a+24548>>2]=a+19680;c[a+24572>>2]=a+20800;if((c[a+8632>>2]|0)==3){c[a+24552>>2]=a+19936;c[a+24576>>2]=a+21344;return}else{c[a+24552>>2]=a+19688;c[a+24576>>2]=a+20816;return}}function dPb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=c[b+156>>2]|0;g=c[b+160>>2]|0;h=d<<4;i=e<<4;e=(ca(f,i)|0)+h|0;j=ca(g,i)|0;pe[c[a+37504>>2]&1023]((c[b+204>>2]|0)+e|0,f,(c[b+208>>2]|0)+((j>>c[a+18576>>2])+h)|0,g,d);return}function ePb(b,c){b=b|0;c=c|0;a[b-128|0]=a[c-128|0]|0;a[b-96|0]=a[c-96|0]|0;a[b-64|0]=a[c-64|0]|0;a[b-32|0]=a[c-32|0]|0;a[b]=a[c]|0;a[b+32|0]=a[c+32|0]|0;a[b+64|0]=a[c+64|0]|0;a[b+96|0]=a[c+96|0]|0;return}function fPb(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;j=i;i=i+8|0;k=j|0;l=h-1|0;m=f+18580|0;n=c[m>>2]|0;o=(ca(n,l)|0)+g|0;c[f+18608>>2]=g;c[f+18612>>2]=h;p=(ca(n,h)|0)+g|0;n=f+18616|0;c[n>>2]=p;q=f+18584|0;r=(ca(c[q>>2]|0,h)|0)+g<<1;s=f+18620|0;c[s>>2]=r;t=f+18588|0;u=(ca(c[t>>2]|0,h)|0)+g<<2;v=f+18624|0;c[v>>2]=u;w=f+18592|0;x=f+18784|0;z=w;c[z>>2]=-1;c[z+4>>2]=-1;c[x>>2]=0;z=f+18868|0;c[z>>2]=0;A=f+18872|0;c[A>>2]=0;B=f+18908|0;C=f+18920|0;D=f+18904|0;E=f+18900|0;F=f+18912|0;G=f+18916|0;H=f+18876|0;I=f+18880|0;J=f+18888|0;K=f+18892|0;L=f+18932|0;mrc(H|0,-1|0,20)|0;mrc(E|0,-1|0,24)|0;c[L>>2]=1012676;c[f+18940>>2]=0;M=p-1|0;p=r-2|0;c[f+18596>>2]=p;c[w>>2]=p;p=u-4|0;c[f+18604>>2]=p;c[f+18600>>2]=p;do{if((g|0)>0){c[A>>2]=1;c[E>>2]=M;c[D>>2]=M;p=(c[f+18956>>2]|0)+M|0;u=a[p]|0;c[I>>2]=u<<24>>24;c[f+18884>>2]=a[p]|0;if((e[(c[f+19272>>2]|0)+(M<<1)>>1]|0)!=(c[f+3244>>2]|0)){N=1;O=3;P=2;Q=2;break}c[x>>2]=1;if(!((c[f+164>>2]|0)==0|(u&255)>>>0<4>>>0)){N=1;O=3;P=3;Q=2;break}c[z>>2]=1;N=1;O=3;P=3;Q=3}else{N=0;O=2;P=2;Q=2}}while(0);do{if((c[f+1452>>2]|0)!=(h|0)){do{if((o|0)>-1){c[A>>2]=O;c[B>>2]=o;c[C>>2]=l;M=a[(c[f+18956>>2]|0)+o|0]|0;c[H>>2]=M<<24>>24;if((e[(c[f+19272>>2]|0)+(o<<1)>>1]|0)!=(c[f+3244>>2]|0)){break}c[x>>2]=P;if((c[f+164>>2]|0)==0|(M&255)>>>0<4>>>0){c[z>>2]=Q}}}while(0);M=(h|0)>0;do{if(N&M){c[A>>2]=c[A>>2]|8;u=g-1+(ca(c[m>>2]|0,l)|0)|0;c[F>>2]=u;c[f+18924>>2]=l;p=a[(c[f+18956>>2]|0)+u|0]|0;c[J>>2]=p<<24>>24;if((e[(c[f+19272>>2]|0)+(u<<1)>>1]|0)!=(c[f+3244>>2]|0)){break}c[x>>2]=c[x>>2]|8;if(!((c[f+164>>2]|0)==0|(p&255)>>>0<4>>>0)){break}c[z>>2]=c[z>>2]|8}}while(0);if(!(((c[f+18560>>2]|0)-1|0)>(g|0)&M)){break}c[A>>2]=c[A>>2]|4;p=g+1+(ca(c[m>>2]|0,l)|0)|0;c[G>>2]=p;c[f+18928>>2]=l;u=a[(c[f+18956>>2]|0)+p|0]|0;c[K>>2]=u<<24>>24;if((e[(c[f+19272>>2]|0)+(p<<1)>>1]|0)!=(c[f+3244>>2]|0)){break}c[x>>2]=c[x>>2]|4;if(!((c[f+164>>2]|0)==0|(u&255)>>>0<4>>>0)){break}c[z>>2]=c[z>>2]|4}}while(0);K=c[B>>2]|0;B=c[C>>2]|0;C=c[q>>2]|0;q=c[t>>2]|0;t=(ca(B<<1|1,C)|0)+(g<<1)|0;l=(ca(B<<2|3,q)|0)+(g<<2)|0;B=f+3240|0;G=1<<c[B>>2]&3;m=c[f+18972>>2]|0;A=c[f+18976>>2]|0;J=c[f+18968>>2]|0;F=c[L>>2]|0;if((c[f+12>>2]|0)==0){R=g}else{R=c[n>>2]|0}n=h&1;c[f+28808>>2]=(c[f+36524+(n<<2)>>2]|0)+(R<<6);R=c[x>>2]|0;do{if((R&2|0)==0){c[f+28768>>2]=-1;c[f+27940>>2]=-1;c[f+27988>>2]=-2139062144;c[f+28028>>2]=-2139062144;c[f+28068>>2]=-2139062144;S=R}else{c[f+28768>>2]=b[J+(K<<1)>>1]|0;c[f+27940>>2]=c[m+(K<<3)>>2];c[f+27988>>2]=c[A+(K*48|0)+12>>2];L=16>>>((c[f+18576>>2]|0)>>>0);c[f+28028>>2]=c[L+12+(A+(K*48|0))>>2];c[f+28068>>2]=c[L+28+(A+(K*48|0))>>2];if((G|0)==0){S=R;break}L=0;while(1){N=L+1|0;if((N|0)<(G|0)){L=N}else{break}}S=c[x>>2]|0}}while(0);R=(S&1|0)==0;do{if(R){c[f+28772>>2]=-1;a[f+27971|0]=-1;a[f+27963|0]=-1;a[f+27955|0]=-1;a[f+27947|0]=-1;a[f+28083|0]=-128;a[f+28075|0]=-128;a[f+28043|0]=-128;a[f+28035|0]=-128;a[f+28019|0]=-128;a[f+28011|0]=-128;a[f+28003|0]=-128;a[f+27995|0]=-128;if((c[f+8632>>2]|0)<=1){break}a[f+28099|0]=-128;a[f+28091|0]=-128;a[f+28059|0]=-128;a[f+28051|0]=-128}else{L=c[E>>2]|0;c[f+28772>>2]=b[J+(L<<1)>>1]|0;a[f+27947|0]=a[(d[F|0]|0)+(m+(L<<3))|0]|0;a[f+27955|0]=a[(d[F+1|0]|0)+(m+(L<<3))|0]|0;a[f+27963|0]=a[(d[F+2|0]|0)+(m+(L<<3))|0]|0;a[f+27971|0]=a[(d[F+3|0]|0)+(m+(L<<3))|0]|0;M=F+4|0;a[f+27995|0]=a[(d[M]|0)+(A+(L*48|0))|0]|0;N=F+5|0;a[f+28003|0]=a[(d[N]|0)+(A+(L*48|0))|0]|0;Q=F+6|0;a[f+28011|0]=a[(d[Q]|0)+(A+(L*48|0))|0]|0;P=F+7|0;a[f+28019|0]=a[(d[P]|0)+(A+(L*48|0))|0]|0;if((c[f+8632>>2]|0)>1){o=4>>>((c[f+18572>>2]|0)>>>0);O=o+12|0;a[f+28035|0]=a[O+(d[M]|0)+(A+(L*48|0))|0]|0;a[f+28043|0]=a[(d[N]|0)+O+(A+(L*48|0))|0]|0;a[f+28051|0]=a[(d[Q]|0)+O+(A+(L*48|0))|0]|0;a[f+28059|0]=a[(d[P]|0)+O+(A+(L*48|0))|0]|0;O=o+28|0;a[f+28075|0]=a[(d[M]|0)+O+(A+(L*48|0))|0]|0;a[f+28083|0]=a[(d[N]|0)+O+(A+(L*48|0))|0]|0;a[f+28091|0]=a[(d[Q]|0)+O+(A+(L*48|0))|0]|0;a[f+28099|0]=a[(d[P]|0)+O+(A+(L*48|0))|0]|0;break}else{a[f+28035|0]=a[(d[F+8|0]|0)+(A+(L*48|0))|0]|0;a[f+28043|0]=a[(d[F+9|0]|0)+(A+(L*48|0))|0]|0;a[f+28075|0]=a[(d[F+10|0]|0)+(A+(L*48|0))|0]|0;a[f+28083|0]=a[(d[F+11|0]|0)+(A+(L*48|0))|0]|0;break}}}while(0);if((c[f+8696>>2]|0)!=0){if(R){T=0}else{T=(a[(c[f+19268>>2]|0)+(c[E>>2]|0)|0]|0)!=0|0}if((S&2|0)==0){U=0}else{U=(a[(c[f+19268>>2]|0)+K|0]|0)!=0|0}c[f+28760>>2]=U+T}T=f+24568|0;U=c[T>>2]|0;ePb(U+127|0,U+143|0);U=c[T>>2]|0;ePb(U+383|0,U+399|0);U=f+15148|0;S=c[U>>2]|0;R=c[S+156>>2]|0;A=g<<4;m=h<<4;J=(ca(R,m)|0)+A|0;L=c[S+204>>2]|0;S=n^1;O=c[f+36464+(S*12|0)>>2]|0;P=k|0;c[P>>2]=J;Q=k+4|0;c[Q>>2]=J;c[f+27916>>2]=R;N=f+15144|0;M=(c[(c[N>>2]|0)+204>>2]|0)+J|0;c[f+24556>>2]=M;o=f+37436|0;pe[c[o>>2]&1023](c[f+24544>>2]|0,16,M,R,16);nrc((c[T>>2]|0)-32|0,O+A|0,24)|0;M=A-1|0;a[(c[T>>2]|0)-33|0]=a[O+M|0]|0;O=f+19384|0;if((c[O>>2]|0)!=0){u=J-1|0;J=0;do{p=a[L+(u+(ca(J,R)|0))|0]|0;a[(c[T>>2]|0)+((J<<5)-1)|0]=p;J=J+1|0;}while((J|0)<16)}J=f+24580|0;if((c[J>>2]|0)>0){T=0;do{R=c[f+15160+(T<<2)>>2]|0;u=c[k+((T&1)<<2)>>2]|0;L=(c[R+204>>2]|0)+u|0;c[f+24588+(T*48|0)>>2]=L;c[f+24588+(T*48|0)+4>>2]=(c[R+232>>2]|0)+u;c[f+24588+(T*48|0)+8>>2]=(c[R+236>>2]|0)+u;c[f+24588+(T*48|0)+12>>2]=(c[R+240>>2]|0)+u;if((c[f+3584+(T*144|0)+44>>2]|0)==0){c[f+27660+(T<<2)>>2]=L}else{c[f+27660+(T<<2)>>2]=(c[(c[N>>2]|0)+2704+(T<<2)>>2]|0)+u}T=T+1|0;}while((T|0)<(c[J>>2]|0))}do{if((c[B>>2]|0)==1){T=f+24584|0;if((c[T>>2]|0)>0){V=0}else{break}do{u=c[f+15236+(V<<2)>>2]|0;L=c[k+((V&1)<<2)>>2]|0;c[f+26124+(V*48|0)>>2]=(c[u+204>>2]|0)+L;c[f+26124+(V*48|0)+4>>2]=(c[u+232>>2]|0)+L;c[f+26124+(V*48|0)+8>>2]=(c[u+236>>2]|0)+L;c[f+26124+(V*48|0)+12>>2]=(c[u+240>>2]|0)+L;V=V+1|0;}while((V|0)<(c[T>>2]|0))}}while(0);V=f+8632|0;T=f+24572|0;L=c[T>>2]|0;u=L+127|0;do{if((c[V>>2]|0)==3){ePb(u,L+143|0);R=c[T>>2]|0;ePb(R+383|0,R+399|0);R=f+24576|0;p=c[R>>2]|0;ePb(p+127|0,p+143|0);p=c[R>>2]|0;ePb(p+383|0,p+399|0);p=c[U>>2]|0;w=c[p+160>>2]|0;r=(ca(w,m)|0)+A|0;W=c[p+208>>2]|0;p=c[f+36464+(S*12|0)+4>>2]|0;c[P>>2]=r;c[Q>>2]=r;c[f+27920>>2]=w;X=(c[(c[N>>2]|0)+208>>2]|0)+r|0;c[f+24560>>2]=X;pe[c[o>>2]&1023](c[f+24548>>2]|0,16,X,w,16);nrc((c[T>>2]|0)-32|0,p+A|0,24)|0;a[(c[T>>2]|0)-33|0]=a[p+M|0]|0;if((c[O>>2]|0)!=0){p=r-1|0;r=0;do{X=a[W+(p+(ca(r,w)|0))|0]|0;a[(c[T>>2]|0)+((r<<5)-1)|0]=X;r=r+1|0;}while((r|0)<16)}if((c[J>>2]|0)>0){r=0;do{w=c[f+15160+(r<<2)>>2]|0;p=c[k+((r&1)<<2)>>2]|0;c[f+24588+(r*48|0)+16>>2]=(c[w+208>>2]|0)+p;c[f+24588+(r*48|0)+20>>2]=(c[w+248>>2]|0)+p;c[f+24588+(r*48|0)+24>>2]=(c[w+252>>2]|0)+p;c[f+24588+(r*48|0)+28>>2]=(c[w+256>>2]|0)+p;r=r+1|0;}while((r|0)<(c[J>>2]|0))}do{if((c[B>>2]|0)==1){r=f+24584|0;if((c[r>>2]|0)>0){Y=0}else{break}do{p=c[f+15236+(Y<<2)>>2]|0;w=c[k+((Y&1)<<2)>>2]|0;c[f+26124+(Y*48|0)+16>>2]=(c[p+208>>2]|0)+w;c[f+26124+(Y*48|0)+20>>2]=(c[p+248>>2]|0)+w;c[f+26124+(Y*48|0)+24>>2]=(c[p+252>>2]|0)+w;c[f+26124+(Y*48|0)+28>>2]=(c[p+256>>2]|0)+w;Y=Y+1|0;}while((Y|0)<(c[r>>2]|0))}}while(0);r=c[U>>2]|0;w=c[r+164>>2]|0;p=(ca(w,m)|0)+A|0;W=c[r+212>>2]|0;r=c[f+36464+(S*12|0)+8>>2]|0;c[P>>2]=p;c[Q>>2]=p;c[f+27924>>2]=w;X=(c[(c[N>>2]|0)+212>>2]|0)+p|0;c[f+24564>>2]=X;pe[c[o>>2]&1023](c[f+24552>>2]|0,16,X,w,16);nrc((c[R>>2]|0)-32|0,r+A|0,24)|0;a[(c[R>>2]|0)-33|0]=a[r+M|0]|0;if((c[O>>2]|0)!=0){r=p-1|0;p=0;do{X=a[W+(r+(ca(p,w)|0))|0]|0;a[(c[R>>2]|0)+((p<<5)-1)|0]=X;p=p+1|0;}while((p|0)<16)}if((c[J>>2]|0)>0){p=0;do{R=c[f+15160+(p<<2)>>2]|0;w=c[k+((p&1)<<2)>>2]|0;c[f+24588+(p*48|0)+32>>2]=(c[R+212>>2]|0)+w;c[f+24588+(p*48|0)+36>>2]=(c[R+264>>2]|0)+w;c[f+24588+(p*48|0)+40>>2]=(c[R+268>>2]|0)+w;c[f+24588+(p*48|0)+44>>2]=(c[R+272>>2]|0)+w;p=p+1|0;}while((p|0)<(c[J>>2]|0))}if((c[B>>2]|0)!=1){break}p=f+24584|0;if((c[p>>2]|0)>0){Z=0}else{break}do{w=c[f+15236+(Z<<2)>>2]|0;R=c[k+((Z&1)<<2)>>2]|0;c[f+26124+(Z*48|0)+32>>2]=(c[w+212>>2]|0)+R;c[f+26124+(Z*48|0)+36>>2]=(c[w+264>>2]|0)+R;c[f+26124+(Z*48|0)+40>>2]=(c[w+268>>2]|0)+R;c[f+26124+(Z*48|0)+44>>2]=(c[w+272>>2]|0)+R;Z=Z+1|0;}while((Z|0)<(c[p>>2]|0))}else{ePb(u,L+135|0);p=f+24576|0;R=c[p>>2]|0;ePb(R+127|0,R+135|0);if((c[V>>2]|0)==2){R=c[T>>2]|0;ePb(R+383|0,R+391|0);R=c[p>>2]|0;ePb(R+383|0,R+391|0)}R=16>>>((c[f+18576>>2]|0)>>>0);w=c[U>>2]|0;r=c[w+160>>2]|0;W=(ca(ca(R,h)|0,r)|0)+A|0;X=c[w+208>>2]|0;w=c[f+36464+(S*12|0)+4>>2]|0;c[P>>2]=W;c[Q>>2]=W;c[f+27920>>2]=r;_=(c[(c[N>>2]|0)+208>>2]|0)+W|0;c[f+24560>>2]=_;mf[c[f+37472>>2]&2047](c[f+24548>>2]|0,_,r,R);_=w+A|0;$=(c[T>>2]|0)-32|0;aa=_|0;ba=_+4|0;_=d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0;ba=$|0;y=d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;ba=$+4|0;y=_;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;ba=w+(A|8)|0;_=(c[p>>2]|0)-32|0;$=ba|0;aa=ba+4|0;ba=d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0;aa=_|0;y=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;aa=_+4|0;y=ba;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;a[(c[T>>2]|0)-33|0]=a[w+(A-9)|0]|0;a[(c[p>>2]|0)-33|0]=a[w+M|0]|0;if((c[O>>2]|0)!=0&(R|0)>0){w=W-2|0;aa=W-1|0;W=0;do{ba=ca(W,r)|0;_=(W<<5)-1|0;a[(c[T>>2]|0)+_|0]=a[X+(w+ba)|0]|0;a[(c[p>>2]|0)+_|0]=a[X+(aa+ba)|0]|0;W=W+1|0;}while((W|0)<(R|0))}R=c[J>>2]|0;if((R|0)>0){W=0;do{c[f+24588+(W*48|0)+16>>2]=(c[(c[f+15160+(W<<2)>>2]|0)+208>>2]|0)+(c[k+((W&1)<<2)>>2]|0);W=W+1|0;}while((W|0)<(R|0))}if((c[B>>2]|0)!=1){break}R=c[f+24584>>2]|0;if((R|0)>0){da=0}else{break}do{c[f+26124+(da*48|0)+16>>2]=(c[(c[f+15236+(da<<2)>>2]|0)+208>>2]|0)+(c[k+((da&1)<<2)>>2]|0);da=da+1|0;}while((da|0)<(R|0))}}while(0);da=c[U>>2]|0;do{if((c[da+340>>2]|0)!=0){U=(ca(c[da+156>>2]|0,h)|0)+g<<4;if((c[J>>2]|0)>0){k=0;do{c[f+27788+(k<<2)>>2]=(c[(c[f+15160+(k<<2)>>2]|0)+340>>2]|0)+(U<<1);k=k+1|0;}while((k|0)<(c[J>>2]|0))}k=f+24584|0;if((c[k>>2]|0)>0){ea=0}else{break}do{c[f+27852+(ea<<2)>>2]=(c[(c[f+15236+(ea<<2)>>2]|0)+340>>2]|0)+(U<<1);ea=ea+1|0;}while((ea|0)<(c[k>>2]|0))}}while(0);ea=c[N>>2]|0;N=c[ea+156>>2]|0;J=c[ea+160>>2]|0;h=(ca(N,m)|0)+A|0;da=ca(J,m)|0;pe[c[f+37504>>2]&1023]((c[ea+204>>2]|0)+h|0,N,(c[ea+208>>2]|0)+((da>>c[f+18576>>2])+A)|0,J,g);g=f+152|0;if((G|0)!=0){J=F+2|0;A=F+3|0;da=F|0;ea=F+1|0;F=q<<1;N=q*3|0;h=t+2|0;m=l+4|0;k=t+1|0;U=t-1|0;T=l-1|0;O=0;do{M=c[f+18984+(O<<2)>>2]|0;Q=c[f+19e3+(O<<2)>>2]|0;if((c[x>>2]&8|0)==0){a[f+28104+(O*40|0)+3|0]=-2;c[f+28192+(O*160|0)+12>>2]=0}else{a[f+28104+(O*40|0)+3|0]=a[Q+U|0]|0;c[f+28192+(O*160|0)+12>>2]=c[M+(T<<2)>>2]}P=c[x>>2]|0;if((P&2|0)==0){mrc(f+28192+(O*160|0)+16|0,0,16)|0;c[f+28104+(O*40|0)+4>>2]=-16843010}else{S=a[Q+t|0]|0;a[f+28104+(O*40|0)+5|0]=S;a[f+28104+(O*40|0)+4|0]=S;S=a[Q+k|0]|0;a[f+28104+(O*40|0)+7|0]=S;a[f+28104+(O*40|0)+6|0]=S;S=f+28192+(O*160|0)+16|0;V=M+(l<<2)|0;c[S>>2]=c[V>>2];c[S+4>>2]=c[V+4>>2];c[S+8>>2]=c[V+8>>2];c[S+12>>2]=c[V+12>>2]}if((P&4|0)==0){a[f+28104+(O*40|0)+8|0]=-2}else{a[f+28104+(O*40|0)+8|0]=a[Q+h|0]|0;c[f+28192+(O*160|0)+32>>2]=c[M+(m<<2)>>2]}if((c[x>>2]&1|0)==0){a[f+28104+(O*40|0)+11|0]=-2;c[f+28192+(O*160|0)+44>>2]=0;a[f+28104+(O*40|0)+19|0]=-2;c[f+28192+(O*160|0)+76>>2]=0;a[f+28104+(O*40|0)+27|0]=-2;c[f+28192+(O*160|0)+108>>2]=0;a[f+28104+(O*40|0)+35|0]=-2;c[f+28192+(O*160|0)+140>>2]=0}else{P=(c[s>>2]|0)-1|0;V=(c[v>>2]|0)-1|0;S=a[Q+P|0]|0;a[f+28104+(O*40|0)+19|0]=S;a[f+28104+(O*40|0)+11|0]=S;S=a[Q+(P+C)|0]|0;a[f+28104+(O*40|0)+35|0]=S;a[f+28104+(O*40|0)+27|0]=S;c[f+28192+(O*160|0)+44>>2]=c[M+(V<<2)>>2];c[f+28192+(O*160|0)+76>>2]=c[M+(V+q<<2)>>2];c[f+28192+(O*160|0)+108>>2]=c[M+(V+F<<2)>>2];c[f+28192+(O*160|0)+140>>2]=c[M+(V+N<<2)>>2]}do{if((c[g>>2]|0)!=0){V=c[f+18992+(O<<2)>>2]|0;M=c[x>>2]|0;if((M&2|0)==0){S=f+28512+(O*80|0)+8|0;c[S>>2]=0;c[S+4>>2]=0}else{S=V+(K<<4)|0;P=c[S+4>>2]|0;Q=f+28512+(O*80|0)+8|0;c[Q>>2]=c[S>>2];c[Q+4>>2]=P}if((M&1|0)==0){b[f+28512+(O*80|0)+22>>1]=0;b[f+28512+(O*80|0)+38>>1]=0;b[f+28512+(O*80|0)+54>>1]=0;b[f+28512+(O*80|0)+70>>1]=0;break}else{b[f+28512+(O*80|0)+22>>1]=b[V+(c[E>>2]<<4)+(d[da]<<1)>>1]|0;b[f+28512+(O*80|0)+38>>1]=b[V+(c[E>>2]<<4)+(d[ea]<<1)>>1]|0;M=c[D>>2]|0;b[f+28512+(O*80|0)+54>>1]=b[V+(M<<4)+(d[J]<<1)>>1]|0;b[f+28512+(O*80|0)+70>>1]=b[V+(M<<4)+(d[A]<<1)>>1]|0;break}}}while(0);O=O+1|0;}while((O|0)<(G|0))}c[f+18944>>2]=1;G=(c[g>>2]|0)==0;if(!G){g=c[x>>2]|0;do{if((g&1|0)==0){fa=0}else{O=c[I>>2]|0;if((O|0)==6){fa=0;break}fa=(O|0)!=18|0}}while(0);do{if((g&2|0)==0){ga=0}else{I=c[H>>2]|0;if((I|0)==6){ga=0;break}ga=(I|0)!=18|0}}while(0);c[f+28764>>2]=ga+fa}fa=c[B>>2]|0;if((fa|0)==1){B=c[f+18660>>2]|0;ga=B&n;c[f+30412>>2]=f+29900+(B<<8)+(ga<<7);c[f+29896>>2]=f+28872+(B<<9)+(ga<<8);if(G){ha=c[z>>2]|0;ia=ha&11;ja=ha<<1;ka=ja&4;la=ka|ia;ma=f+18788|0;c[ma>>2]=la;na=f+18804|0;c[na>>2]=la;oa=ha&2;pa=(oa|0)!=0;qa=pa?15:1;ra=f+18808|0;c[ra>>2]=qa;sa=f+18820|0;c[sa>>2]=qa;ta=ha&1;ua=(ta|0)!=0;va=ua?15:6;wa=f+18796|0;c[wa>>2]=va;xa=f+18844|0;c[xa>>2]=va;ya=f+18836|0;c[ya>>2]=va;za=f+18812|0;c[za>>2]=va;Aa=ha&4;Ba=pa?10:0;Ca=Aa|Ba;Da=Ca|1;Ea=f+18792|0;c[Ea>>2]=Da;Fa=f+18824|0;c[Fa>>2]=Da;i=j;return}c[f+28684>>2]=0;c[f+28692>>2]=0;c[f+28700>>2]=0;c[f+28708>>2]=0;G=c[x>>2]|0;if((G&1|0)==0){Ga=0}else{Ga=a[(c[f+19264>>2]|0)+(c[E>>2]|0)|0]|0}a[f+28683|0]=Ga&2;a[f+28699|0]=Ga&8;if((G&2|0)==0){Ha=0}else{Ha=a[(c[f+19264>>2]|0)+K|0]|0}a[f+28676|0]=Ha&4;a[f+28678|0]=Ha&8;ha=c[z>>2]|0;ia=ha&11;ja=ha<<1;ka=ja&4;la=ka|ia;ma=f+18788|0;c[ma>>2]=la;na=f+18804|0;c[na>>2]=la;oa=ha&2;pa=(oa|0)!=0;qa=pa?15:1;ra=f+18808|0;c[ra>>2]=qa;sa=f+18820|0;c[sa>>2]=qa;ta=ha&1;ua=(ta|0)!=0;va=ua?15:6;wa=f+18796|0;c[wa>>2]=va;xa=f+18844|0;c[xa>>2]=va;ya=f+18836|0;c[ya>>2]=va;za=f+18812|0;c[za>>2]=va;Aa=ha&4;Ba=pa?10:0;Ca=Aa|Ba;Da=Ca|1;Ea=f+18792|0;c[Ea>>2]=Da;Fa=f+18824|0;c[Fa>>2]=Da;i=j;return}else if((fa|0)==0){fQb(f,f+28756|0);ha=c[z>>2]|0;ia=ha&11;ja=ha<<1;ka=ja&4;la=ka|ia;ma=f+18788|0;c[ma>>2]=la;na=f+18804|0;c[na>>2]=la;oa=ha&2;pa=(oa|0)!=0;qa=pa?15:1;ra=f+18808|0;c[ra>>2]=qa;sa=f+18820|0;c[sa>>2]=qa;ta=ha&1;ua=(ta|0)!=0;va=ua?15:6;wa=f+18796|0;c[wa>>2]=va;xa=f+18844|0;c[xa>>2]=va;ya=f+18836|0;c[ya>>2]=va;za=f+18812|0;c[za>>2]=va;Aa=ha&4;Ba=pa?10:0;Ca=Aa|Ba;Da=Ca|1;Ea=f+18792|0;c[Ea>>2]=Da;Fa=f+18824|0;c[Fa>>2]=Da;i=j;return}else{ha=c[z>>2]|0;ia=ha&11;ja=ha<<1;ka=ja&4;la=ka|ia;ma=f+18788|0;c[ma>>2]=la;na=f+18804|0;c[na>>2]=la;oa=ha&2;pa=(oa|0)!=0;qa=pa?15:1;ra=f+18808|0;c[ra>>2]=qa;sa=f+18820|0;c[sa>>2]=qa;ta=ha&1;ua=(ta|0)!=0;va=ua?15:6;wa=f+18796|0;c[wa>>2]=va;xa=f+18844|0;c[xa>>2]=va;ya=f+18836|0;c[ya>>2]=va;za=f+18812|0;c[za>>2]=va;Aa=ha&4;Ba=pa?10:0;Ca=Aa|Ba;Da=Ca|1;Ea=f+18792|0;c[Ea>>2]=Da;Fa=f+18824|0;c[Fa>>2]=Da;i=j;return}}function gPb(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0;j=i;i=i+8|0;k=j|0;l=f+18660|0;m=(c[l>>2]|0)!=0;n=m&1;o=h-(1<<n)|0;p=f+18560|0;q=f+18580|0;r=c[q>>2]|0;s=ca(o,r)|0;t=s+g|0;c[f+18608>>2]=g;c[f+18612>>2]=h;u=(ca(r,h)|0)+g|0;v=f+18616|0;c[v>>2]=u;w=f+18584|0;x=c[w>>2]|0;z=(ca(x,h)|0)+g<<1;c[f+18620>>2]=z;A=f+18588|0;B=c[A>>2]|0;C=(ca(B,h)|0)+g<<2;c[f+18624>>2]=C;D=f+18596|0;E=f+18592|0;F=f+18604|0;G=f+18600|0;H=f+18784|0;I=E;c[I>>2]=-1;c[I+4>>2]=-1;c[H>>2]=0;I=f+18868|0;c[I>>2]=0;J=f+18872|0;c[J>>2]=0;K=f+18908|0;L=f+18920|0;M=f+18904|0;N=f+18900|0;O=f+18912|0;P=f+18916|0;Q=f+18876|0;R=f+18884|0;S=f+18880|0;T=f+18888|0;U=f+18892|0;V=f+18932|0;mrc(Q|0,-1|0,20)|0;mrc(N|0,-1|0,24)|0;c[V>>2]=1012676;W=f+18940|0;c[W>>2]=0;X=u-1|0;Y=z-2|0;c[D>>2]=Y;c[E>>2]=Y;z=C-4|0;c[F>>2]=z;c[G>>2]=z;c[f+18936>>2]=u-(r<<1);u=f+18924|0;c[u>>2]=-1;C=f+18928|0;c[C>>2]=-1;Z=h&1;_=(Z|0)==0;do{if(_){do{if(m&(t|0)>-1){$=c[f+19276>>2]|0;if((a[$+t|0]|0)==0){aa=t+r|0;ba=o+1|0}else{aa=t;ba=o}if((g|0)==0){da=o}else{da=((a[$+(g-1+s)|0]|0)==0)+o|0}if(((c[p>>2]|0)-1|0)<=(g|0)){ea=o;fa=da;ga=aa;ha=ba;break}ea=((a[$+(g+1+s)|0]|0)==0)+o|0;fa=da;ga=aa;ha=ba}else{ea=o;fa=o;ga=t;ha=o}}while(0);if((g|0)==0){ia=ha;ja=ga;ka=fa;la=ea;ma=0;na=2;oa=2;pa=2;break}if((n|0)==(d[(c[f+19276>>2]|0)+X|0]|0)){qa=X;ra=X;sa=ea;ta=fa;ua=ga;va=ha;wa=20;break}if(m){c[V>>2]=1012656;c[D>>2]=Y+(x<<1);c[F>>2]=z+(B<<2);qa=X;ra=X+r|0;sa=ea;ta=fa;ua=ga;va=ha;wa=20;break}else{c[V>>2]=1012616;qa=X;ra=X;sa=ea;ta=fa;ua=ga;va=ha;wa=20;break}}else{do{if((g|0)==0){xa=X;ya=X;za=o}else{if((n|0)==(d[(c[f+19276>>2]|0)+X|0]|0)){xa=X;ya=X;za=o;break}$=X-r|0;Aa=Y-(x<<1)|0;c[D>>2]=Aa;c[E>>2]=Aa;Aa=z-(B<<2)|0;c[F>>2]=Aa;c[G>>2]=Aa;if(m){c[V>>2]=1012656;c[D>>2]=Y;c[F>>2]=z;xa=$;ya=X;za=o;break}else{c[V>>2]=1012636;c[W>>2]=1;xa=$;ya=$;za=o+1|0;break}}}while(0);qa=xa;ra=ya;sa=m?o:-1;ta=za;ua=t;va=o;wa=20}}while(0);do{if((wa|0)==20){if((g|0)<=0){ia=va;ja=ua;ka=ta;la=sa;ma=0;na=2;oa=2;pa=2;break}c[J>>2]=1;c[N>>2]=qa;c[M>>2]=ra;o=c[f+18956>>2]|0;t=a[o+qa|0]|0;c[S>>2]=t<<24>>24;c[R>>2]=a[o+ra|0]|0;if((e[(c[f+19272>>2]|0)+(qa<<1)>>1]|0)!=(c[f+3244>>2]|0)){ia=va;ja=ua;ka=ta;la=sa;ma=1;na=3;oa=2;pa=2;break}c[H>>2]=1;if(!((c[f+164>>2]|0)==0|(t&255)>>>0<4>>>0)){ia=va;ja=ua;ka=ta;la=sa;ma=1;na=3;oa=3;pa=2;break}c[I>>2]=1;ia=va;ja=ua;ka=ta;la=sa;ma=1;na=3;oa=3;pa=3}}while(0);do{if((c[f+1452>>2]>>n|0)!=(h>>n|0)){do{if((ja|0)>-1){c[J>>2]=na;c[K>>2]=ja;c[L>>2]=ia;sa=a[(c[f+18956>>2]|0)+ja|0]|0;c[Q>>2]=sa<<24>>24;if((e[(c[f+19272>>2]|0)+(ja<<1)>>1]|0)!=(c[f+3244>>2]|0)){break}c[H>>2]=oa;if((c[f+164>>2]|0)==0|(sa&255)>>>0<4>>>0){c[I>>2]=pa}}}while(0);do{if(ma&(ka|0)>-1){c[J>>2]=c[J>>2]|8;sa=g-1+(ca(c[q>>2]|0,ka)|0)|0;c[O>>2]=sa;c[u>>2]=ka;ta=a[(c[f+18956>>2]|0)+sa|0]|0;c[T>>2]=ta<<24>>24;if((e[(c[f+19272>>2]|0)+(sa<<1)>>1]|0)!=(c[f+3244>>2]|0)){break}c[H>>2]=c[H>>2]|8;if(!((c[f+164>>2]|0)==0|(ta&255)>>>0<4>>>0)){break}c[I>>2]=c[I>>2]|8}}while(0);if(!(((c[p>>2]|0)-1|0)>(g|0)&(la|0)>-1)){break}c[J>>2]=c[J>>2]|4;ta=g+1+(ca(c[q>>2]|0,la)|0)|0;c[P>>2]=ta;c[C>>2]=la;sa=a[(c[f+18956>>2]|0)+ta|0]|0;c[U>>2]=sa<<24>>24;if((e[(c[f+19272>>2]|0)+(ta<<1)>>1]|0)!=(c[f+3244>>2]|0)){break}c[H>>2]=c[H>>2]|4;if(!((c[f+164>>2]|0)==0|(sa&255)>>>0<4>>>0)){break}c[I>>2]=c[I>>2]|4}}while(0);U=c[K>>2]|0;la=c[L>>2]|0;L=c[w>>2]|0;w=c[A>>2]|0;A=(ca(la<<1|1,L)|0)+(g<<1)|0;J=(ca(la<<2|3,w)|0)+(g<<2)|0;la=f+3240|0;p=1<<c[la>>2]&3;T=c[f+18972>>2]|0;ka=c[f+18976>>2]|0;ma=c[f+18968>>2]|0;pa=c[V>>2]|0;if((c[f+12>>2]|0)==0){Ba=g}else{Ba=c[v>>2]|0}c[f+28808>>2]=(c[f+36524+(Z<<2)>>2]|0)+(Ba<<6);Ba=c[H>>2]|0;do{if((Ba&2|0)==0){c[f+28768>>2]=-1;c[f+27940>>2]=-1;c[f+27988>>2]=-2139062144;c[f+28028>>2]=-2139062144;c[f+28068>>2]=-2139062144;Ca=Ba}else{c[f+28768>>2]=b[ma+(U<<1)>>1]|0;c[f+27940>>2]=c[T+(U<<3)>>2];c[f+27988>>2]=c[ka+(U*48|0)+12>>2];V=16>>>((c[f+18576>>2]|0)>>>0);c[f+28028>>2]=c[V+12+(ka+(U*48|0))>>2];c[f+28068>>2]=c[V+28+(ka+(U*48|0))>>2];if((p|0)==0){Ca=Ba;break}V=0;while(1){oa=V+1|0;if((oa|0)<(p|0)){V=oa}else{break}}Ca=c[H>>2]|0}}while(0);Ba=(Ca&1|0)==0;do{if(Ba){c[f+28772>>2]=-1;a[f+27971|0]=-1;a[f+27963|0]=-1;a[f+27955|0]=-1;a[f+27947|0]=-1;a[f+28083|0]=-128;a[f+28075|0]=-128;a[f+28043|0]=-128;a[f+28035|0]=-128;a[f+28019|0]=-128;a[f+28011|0]=-128;a[f+28003|0]=-128;a[f+27995|0]=-128;if((c[f+8632>>2]|0)<=1){break}a[f+28099|0]=-128;a[f+28091|0]=-128;a[f+28059|0]=-128;a[f+28051|0]=-128}else{V=c[N>>2]|0;oa=c[M>>2]|0;ja=b[ma+(V<<1)>>1]|0;c[f+28772>>2]=ja>>(a[pa+12|0]&254)&2|ja&65520|b[ma+(oa<<1)>>1]>>(a[pa+14|0]&254)<<2&8;a[f+27947|0]=a[(d[pa|0]|0)+(T+(V<<3))|0]|0;a[f+27955|0]=a[(d[pa+1|0]|0)+(T+(V<<3))|0]|0;a[f+27963|0]=a[(d[pa+2|0]|0)+(T+(oa<<3))|0]|0;a[f+27971|0]=a[(d[pa+3|0]|0)+(T+(oa<<3))|0]|0;ja=pa+4|0;a[f+27995|0]=a[(d[ja]|0)+(ka+(V*48|0))|0]|0;Q=pa+5|0;a[f+28003|0]=a[(d[Q]|0)+(ka+(V*48|0))|0]|0;ia=pa+6|0;a[f+28011|0]=a[(d[ia]|0)+(ka+(oa*48|0))|0]|0;na=pa+7|0;a[f+28019|0]=a[(d[na]|0)+(ka+(oa*48|0))|0]|0;if((c[f+8632>>2]|0)>1){n=4>>>((c[f+18572>>2]|0)>>>0);sa=n+12|0;a[f+28035|0]=a[sa+(d[ja]|0)+(ka+(V*48|0))|0]|0;a[f+28043|0]=a[(d[Q]|0)+sa+(ka+(V*48|0))|0]|0;a[f+28051|0]=a[(d[ia]|0)+sa+(ka+(oa*48|0))|0]|0;a[f+28059|0]=a[(d[na]|0)+sa+(ka+(oa*48|0))|0]|0;sa=n+28|0;a[f+28075|0]=a[(d[ja]|0)+sa+(ka+(V*48|0))|0]|0;a[f+28083|0]=a[(d[Q]|0)+sa+(ka+(V*48|0))|0]|0;a[f+28091|0]=a[(d[ia]|0)+sa+(ka+(oa*48|0))|0]|0;a[f+28099|0]=a[(d[na]|0)+sa+(ka+(oa*48|0))|0]|0;break}else{a[f+28035|0]=a[(d[pa+8|0]|0)+(ka+(V*48|0))|0]|0;a[f+28043|0]=a[(d[pa+9|0]|0)+(ka+(oa*48|0))|0]|0;a[f+28075|0]=a[(d[pa+10|0]|0)+(ka+(V*48|0))|0]|0;a[f+28083|0]=a[(d[pa+11|0]|0)+(ka+(oa*48|0))|0]|0;break}}}while(0);if((c[f+8696>>2]|0)!=0){if(Ba){Da=0}else{Da=(a[(c[f+19268>>2]|0)+(c[N>>2]|0)|0]|0)!=0|0}if((Ca&2|0)==0){Ea=0}else{Ea=(a[(c[f+19268>>2]|0)+U|0]|0)!=0|0}c[f+28760>>2]=Ea+Da}Da=c[l>>2]|0;Ea=f+24580|0;c[Ea>>2]=c[f+15152>>2]<<Da;Ca=f+24584|0;c[Ca>>2]=c[f+15156>>2]<<Da;Ba=(Da|0)!=0;Da=Ba&1;ka=f+15148|0;T=c[ka>>2]|0;ma=c[T+156>>2]|0;oa=ma<<Da;V=g<<4;sa=h<<4;if(Ba){na=(ca(ma,sa&-32)|0)+V+(ma&-Z)|0;ia=c[T+204>>2]|0;Q=c[f+36464+((Z+3|0)*12|0)>>2]|0;c[k>>2]=na;Fa=na+(ca(ma,1-(h<<1&2)|0)|0)|0;Ga=Q;Ha=k+4|0;Ia=na;Ja=ia}else{ia=(ca(ma,sa)|0)+V|0;ma=c[T+204>>2]|0;T=c[f+36464+(((Z<<1^2)+2|0)*12|0)>>2]|0;c[k>>2]=ia;Fa=ia;Ga=T;Ha=k+4|0;Ia=ia;Ja=ma}c[Ha>>2]=Fa;c[f+27916>>2]=oa;Fa=f+15144|0;Ha=(c[(c[Fa>>2]|0)+204>>2]|0)+Ia|0;c[f+24556>>2]=Ha;ma=f+37436|0;pe[c[ma>>2]&1023](c[f+24544>>2]|0,16,Ha,oa,16);Ha=f+24568|0;nrc((c[Ha>>2]|0)-32|0,Ga+V|0,24)|0;ia=V-1|0;a[(c[Ha>>2]|0)-33|0]=a[Ga+ia|0]|0;Ga=Ia-1|0;Ia=0;do{T=a[Ja+(Ga+(ca(Ia,oa)|0))|0]|0;a[(c[Ha>>2]|0)+((Ia<<5)-1)|0]=T;Ia=Ia+1|0;}while((Ia|0)<16);if((c[Ea>>2]|0)>0){Ia=0;do{if(Ba){Ha=c[f+15160+(Ia>>1<<2)>>2]|0;Ka=Ha+276|0;La=Ha+216|0}else{Ha=c[f+15160+(Ia<<2)>>2]|0;Ka=Ha+228|0;La=Ha+204|0}Ha=c[k+((Ia&1)<<2)>>2]|0;oa=(c[La>>2]|0)+Ha|0;c[f+24588+(Ia*48|0)>>2]=oa;c[f+24588+(Ia*48|0)+4>>2]=(c[Ka+4>>2]|0)+Ha;c[f+24588+(Ia*48|0)+8>>2]=(c[Ka+8>>2]|0)+Ha;c[f+24588+(Ia*48|0)+12>>2]=(c[Ka+12>>2]|0)+Ha;if((c[f+3584+(Ia*144|0)+44>>2]|0)==0){c[f+27660+(Ia<<2)>>2]=oa}else{c[f+27660+(Ia<<2)>>2]=(c[(c[Fa>>2]|0)+2704+(Ia>>Da<<2)>>2]|0)+Ha}Ia=Ia+1|0;}while((Ia|0)<(c[Ea>>2]|0))}do{if((c[la>>2]|0)==1){if((c[Ca>>2]|0)<=0){break}if(Ba){Ia=0;do{Da=c[f+15236+(Ia>>1<<2)>>2]|0;Ka=c[k+((Ia&1)<<2)>>2]|0;c[f+26124+(Ia*48|0)>>2]=(c[Da+216>>2]|0)+Ka;c[f+26124+(Ia*48|0)+4>>2]=(c[Da+280>>2]|0)+Ka;c[f+26124+(Ia*48|0)+8>>2]=(c[Da+284>>2]|0)+Ka;c[f+26124+(Ia*48|0)+12>>2]=(c[Da+288>>2]|0)+Ka;Ia=Ia+1|0;}while((Ia|0)<(c[Ca>>2]|0))}else{Ia=0;do{Ka=c[f+15236+(Ia<<2)>>2]|0;Da=c[k+((Ia&1)<<2)>>2]|0;c[f+26124+(Ia*48|0)>>2]=(c[Ka+204>>2]|0)+Da;c[f+26124+(Ia*48|0)+4>>2]=(c[Ka+232>>2]|0)+Da;c[f+26124+(Ia*48|0)+8>>2]=(c[Ka+236>>2]|0)+Da;c[f+26124+(Ia*48|0)+12>>2]=(c[Ka+240>>2]|0)+Da;Ia=Ia+1|0;}while((Ia|0)<(c[Ca>>2]|0))}}}while(0);Ba=(c[l>>2]|0)!=0;Ia=Ba&1;do{if((c[f+8632>>2]|0)==3){Da=c[ka>>2]|0;Ka=c[Da+160>>2]|0;La=Ka<<Ia;if(Ba){Ha=(ca(Ka,sa&-32)|0)+V+(Ka&-Z)|0;oa=c[Da+208>>2]|0;Ga=c[f+36464+((Z+3|0)*12|0)+4>>2]|0;c[k>>2]=Ha;Ma=Ha+(ca(Ka,1-(h<<1&2)|0)|0)|0;Na=Ga;Oa=k+4|0;Pa=Ha;Qa=oa}else{oa=(ca(Ka,sa)|0)+V|0;Ka=c[Da+208>>2]|0;Da=c[f+36464+(((Z<<1^2)+2|0)*12|0)+4>>2]|0;c[k>>2]=oa;Ma=oa;Na=Da;Oa=k+4|0;Pa=oa;Qa=Ka}c[Oa>>2]=Ma;c[f+27920>>2]=La;Ka=(c[(c[Fa>>2]|0)+208>>2]|0)+Pa|0;c[f+24560>>2]=Ka;pe[c[ma>>2]&1023](c[f+24548>>2]|0,16,Ka,La,16);Ka=f+24572|0;nrc((c[Ka>>2]|0)-32|0,Na+V|0,24)|0;a[(c[Ka>>2]|0)-33|0]=a[Na+ia|0]|0;oa=Pa-1|0;Da=0;do{Ha=a[Qa+(oa+(ca(Da,La)|0))|0]|0;a[(c[Ka>>2]|0)+((Da<<5)-1)|0]=Ha;Da=Da+1|0;}while((Da|0)<16);if((c[Ea>>2]|0)>0){Da=0;do{if(Ba){Ka=c[f+15160+(Da>>1<<2)>>2]|0;Ra=Ka+292|0;Sa=Ka+220|0}else{Ka=c[f+15160+(Da<<2)>>2]|0;Ra=Ka+244|0;Sa=Ka+208|0}Ka=c[k+((Da&1)<<2)>>2]|0;c[f+24588+(Da*48|0)+16>>2]=(c[Sa>>2]|0)+Ka;c[f+24588+(Da*48|0)+20>>2]=(c[Ra+4>>2]|0)+Ka;c[f+24588+(Da*48|0)+24>>2]=(c[Ra+8>>2]|0)+Ka;c[f+24588+(Da*48|0)+28>>2]=(c[Ra+12>>2]|0)+Ka;Da=Da+1|0;}while((Da|0)<(c[Ea>>2]|0))}do{if((c[la>>2]|0)==1){if((c[Ca>>2]|0)<=0){break}if(Ba){Da=0;do{Ka=c[f+15236+(Da>>1<<2)>>2]|0;La=c[k+((Da&1)<<2)>>2]|0;c[f+26124+(Da*48|0)+16>>2]=(c[Ka+220>>2]|0)+La;c[f+26124+(Da*48|0)+20>>2]=(c[Ka+296>>2]|0)+La;c[f+26124+(Da*48|0)+24>>2]=(c[Ka+300>>2]|0)+La;c[f+26124+(Da*48|0)+28>>2]=(c[Ka+304>>2]|0)+La;Da=Da+1|0;}while((Da|0)<(c[Ca>>2]|0))}else{Da=0;do{La=c[f+15236+(Da<<2)>>2]|0;Ka=c[k+((Da&1)<<2)>>2]|0;c[f+26124+(Da*48|0)+16>>2]=(c[La+208>>2]|0)+Ka;c[f+26124+(Da*48|0)+20>>2]=(c[La+248>>2]|0)+Ka;c[f+26124+(Da*48|0)+24>>2]=(c[La+252>>2]|0)+Ka;c[f+26124+(Da*48|0)+28>>2]=(c[La+256>>2]|0)+Ka;Da=Da+1|0;}while((Da|0)<(c[Ca>>2]|0))}}}while(0);Da=(c[l>>2]|0)!=0;Ka=c[ka>>2]|0;La=c[Ka+164>>2]|0;oa=La<<(Da&1);if(Da){Ha=(ca(La,sa&-32)|0)+V+(La&-Z)|0;Ga=c[Ka+212>>2]|0;Ja=c[f+36464+((Z+3|0)*12|0)+8>>2]|0;c[k>>2]=Ha;Ta=Ha+(ca(La,1-(h<<1&2)|0)|0)|0;Ua=Ja;Va=k+4|0;Wa=Ha;Xa=Ga}else{Ga=(ca(La,sa)|0)+V|0;La=c[Ka+212>>2]|0;Ka=c[f+36464+(((Z<<1^2)+2|0)*12|0)+8>>2]|0;c[k>>2]=Ga;Ta=Ga;Ua=Ka;Va=k+4|0;Wa=Ga;Xa=La}c[Va>>2]=Ta;c[f+27924>>2]=oa;La=(c[(c[Fa>>2]|0)+212>>2]|0)+Wa|0;c[f+24564>>2]=La;pe[c[ma>>2]&1023](c[f+24552>>2]|0,16,La,oa,16);La=f+24576|0;nrc((c[La>>2]|0)-32|0,Ua+V|0,24)|0;a[(c[La>>2]|0)-33|0]=a[Ua+ia|0]|0;Ga=Wa-1|0;Ka=0;do{Ha=a[Xa+(Ga+(ca(Ka,oa)|0))|0]|0;a[(c[La>>2]|0)+((Ka<<5)-1)|0]=Ha;Ka=Ka+1|0;}while((Ka|0)<16);if((c[Ea>>2]|0)>0){Ka=0;do{if(Da){La=c[f+15160+(Ka>>1<<2)>>2]|0;Ya=La+308|0;Za=La+224|0}else{La=c[f+15160+(Ka<<2)>>2]|0;Ya=La+260|0;Za=La+212|0}La=c[k+((Ka&1)<<2)>>2]|0;c[f+24588+(Ka*48|0)+32>>2]=(c[Za>>2]|0)+La;c[f+24588+(Ka*48|0)+36>>2]=(c[Ya+4>>2]|0)+La;c[f+24588+(Ka*48|0)+40>>2]=(c[Ya+8>>2]|0)+La;c[f+24588+(Ka*48|0)+44>>2]=(c[Ya+12>>2]|0)+La;Ka=Ka+1|0;}while((Ka|0)<(c[Ea>>2]|0))}if((c[la>>2]|0)!=1){break}if((c[Ca>>2]|0)<=0){break}if(Da){Ka=0;do{La=c[f+15236+(Ka>>1<<2)>>2]|0;oa=c[k+((Ka&1)<<2)>>2]|0;c[f+26124+(Ka*48|0)+32>>2]=(c[La+224>>2]|0)+oa;c[f+26124+(Ka*48|0)+36>>2]=(c[La+312>>2]|0)+oa;c[f+26124+(Ka*48|0)+40>>2]=(c[La+316>>2]|0)+oa;c[f+26124+(Ka*48|0)+44>>2]=(c[La+320>>2]|0)+oa;Ka=Ka+1|0;}while((Ka|0)<(c[Ca>>2]|0))}else{Ka=0;do{Da=c[f+15236+(Ka<<2)>>2]|0;oa=c[k+((Ka&1)<<2)>>2]|0;c[f+26124+(Ka*48|0)+32>>2]=(c[Da+212>>2]|0)+oa;c[f+26124+(Ka*48|0)+36>>2]=(c[Da+264>>2]|0)+oa;c[f+26124+(Ka*48|0)+40>>2]=(c[Da+268>>2]|0)+oa;c[f+26124+(Ka*48|0)+44>>2]=(c[Da+272>>2]|0)+oa;Ka=Ka+1|0;}while((Ka|0)<(c[Ca>>2]|0))}}else{Ka=16>>>((c[f+18576>>2]|0)>>>0);oa=c[ka>>2]|0;Da=c[oa+160>>2]|0;La=Da<<Ia;if(Ba){Ga=(ca(ca(Ka,h&-2)|0,Da)|0)+V+(Da&-Z)|0;Ha=c[oa+208>>2]|0;Ja=c[f+36464+((Z+3|0)*12|0)+4>>2]|0;c[k>>2]=Ga;_a=Ga+(ca(Da,1-(h<<1&2)|0)|0)|0;$a=Ja;ab=k+4|0;bb=Ga;cb=Ha}else{Ha=(ca(ca(Ka,h)|0,Da)|0)+V|0;Da=c[oa+208>>2]|0;oa=c[f+36464+(((Z<<1^2)+2|0)*12|0)+4>>2]|0;c[k>>2]=Ha;_a=Ha;$a=oa;ab=k+4|0;bb=Ha;cb=Da}c[ab>>2]=_a;c[f+27920>>2]=La;Da=(c[(c[Fa>>2]|0)+208>>2]|0)+bb|0;c[f+24560>>2]=Da;mf[c[f+37472>>2]&2047](c[f+24548>>2]|0,Da,La,Ka);Da=f+24572|0;Ha=$a+V|0;oa=(c[Da>>2]|0)-32|0;Ga=Ha|0;Ja=Ha+4|0;Ha=d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0;Ja=oa|0;y=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;a[Ja]=y;y=y>>8;a[Ja+1|0]=y;y=y>>8;a[Ja+2|0]=y;y=y>>8;a[Ja+3|0]=y;Ja=oa+4|0;y=Ha;a[Ja]=y;y=y>>8;a[Ja+1|0]=y;y=y>>8;a[Ja+2|0]=y;y=y>>8;a[Ja+3|0]=y;Ja=f+24576|0;Ha=$a+(V|8)|0;oa=(c[Ja>>2]|0)-32|0;Ga=Ha|0;T=Ha+4|0;Ha=d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0;T=oa|0;y=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=oa+4|0;y=Ha;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;a[(c[Da>>2]|0)-33|0]=a[$a+(V-9)|0]|0;a[(c[Ja>>2]|0)-33|0]=a[$a+ia|0]|0;if((Ka|0)>0){T=bb-2|0;Ha=bb-1|0;oa=0;do{Ga=ca(oa,La)|0;na=(oa<<5)-1|0;a[(c[Da>>2]|0)+na|0]=a[cb+(T+Ga)|0]|0;a[(c[Ja>>2]|0)+na|0]=a[cb+(Ha+Ga)|0]|0;oa=oa+1|0;}while((oa|0)<(Ka|0))}Ka=c[Ea>>2]|0;if((Ka|0)>0){oa=0;do{if(Ba){db=(c[f+15160+(oa>>1<<2)>>2]|0)+220|0}else{db=(c[f+15160+(oa<<2)>>2]|0)+208|0}c[f+24588+(oa*48|0)+16>>2]=(c[db>>2]|0)+(c[k+((oa&1)<<2)>>2]|0);oa=oa+1|0;}while((oa|0)<(Ka|0))}if((c[la>>2]|0)!=1){break}Ka=c[Ca>>2]|0;if((Ka|0)<=0){break}if(Ba){oa=0;do{c[f+26124+(oa*48|0)+16>>2]=(c[(c[f+15236+(oa>>1<<2)>>2]|0)+220>>2]|0)+(c[k+((oa&1)<<2)>>2]|0);oa=oa+1|0;}while((oa|0)<(Ka|0))}else{oa=0;do{c[f+26124+(oa*48|0)+16>>2]=(c[(c[f+15236+(oa<<2)>>2]|0)+208>>2]|0)+(c[k+((oa&1)<<2)>>2]|0);oa=oa+1|0;}while((oa|0)<(Ka|0))}}}while(0);k=c[ka>>2]|0;do{if((c[k+340>>2]|0)!=0){ka=(ca(c[k+156>>2]|0,h)|0)+g<<4;if((c[Ea>>2]|0)>0){Ba=0;do{c[f+27788+(Ba<<2)>>2]=(c[(c[f+15160+(Ba<<2)>>2]|0)+340>>2]|0)+(ka<<1);Ba=Ba+1|0;}while((Ba|0)<(c[Ea>>2]|0))}if((c[Ca>>2]|0)>0){eb=0}else{break}do{c[f+27852+(eb<<2)>>2]=(c[(c[f+15236+(eb<<2)>>2]|0)+340>>2]|0)+(ka<<1);eb=eb+1|0;}while((eb|0)<(c[Ca>>2]|0))}}while(0);Ca=c[Fa>>2]|0;Fa=c[Ca+156>>2]|0;eb=c[Ca+160>>2]|0;Ea=(ca(Fa,sa)|0)+V|0;k=ca(eb,sa)|0;pe[c[f+37504>>2]&1023]((c[Ca+204>>2]|0)+Ea|0,Fa,(c[Ca+208>>2]|0)+((k>>c[f+18576>>2])+V)|0,eb,g);if((p|0)!=0){eb=f+19276|0;V=pa+16|0;k=L<<1|1;Ca=pa+18|0;Fa=pa+12|0;Ea=w<<2|3;sa=pa+13|0;ka=pa+14|0;Ba=L+1|0;db=f+152|0;cb=(U|0)>-1;bb=pa+2|0;ia=pa+3|0;$a=pa|0;_a=pa+1|0;ab=pa+17|0;Ia=pa+19|0;Ya=pa+15|0;Za=w<<1;Xa=w*3|0;Wa=g+1|0;Ua=A+1|0;ma=Xa-1|0;Ta=0;do{Va=c[f+18984+(Ta<<2)>>2]|0;Ra=c[f+19e3+(Ta<<2)>>2]|0;if((c[H>>2]&8|0)==0){a[f+28104+(Ta*40|0)+3|0]=-2;c[f+28192+(Ta*160|0)+12>>2]=0}else{Sa=c[u>>2]|0;Qa=((ca(Sa,L)|0)+g<<1)-1|0;Pa=ma+((ca(Sa,w)|0)+g<<2)|0;Sa=(c[W>>2]|0)==0;a[f+28104+(Ta*40|0)+3|0]=a[Ra+(Qa+(Sa?L:0))|0]|0;c[f+28192+(Ta*160|0)+12>>2]=c[Va+(Pa+(Sa?0:-Za|0)<<2)>>2]}Sa=c[H>>2]|0;if((Sa&2|0)==0){mrc(f+28192+(Ta*160|0)+16|0,0,16)|0;c[f+28104+(Ta*40|0)+4>>2]=-16843010}else{Pa=a[Ra+A|0]|0;a[f+28104+(Ta*40|0)+5|0]=Pa;a[f+28104+(Ta*40|0)+4|0]=Pa;Pa=a[Ra+Ua|0]|0;a[f+28104+(Ta*40|0)+7|0]=Pa;a[f+28104+(Ta*40|0)+6|0]=Pa;Pa=f+28192+(Ta*160|0)+16|0;Qa=Va+(J<<2)|0;c[Pa>>2]=c[Qa>>2];c[Pa+4>>2]=c[Qa+4>>2];c[Pa+8>>2]=c[Qa+8>>2];c[Pa+12>>2]=c[Qa+12>>2]}if((Sa&4|0)==0){a[f+28104+(Ta*40|0)+8|0]=-2}else{Sa=c[C>>2]|0;Qa=((ca(Sa,w)|0)+Wa<<2)+Xa|0;a[f+28104+(Ta*40|0)+8|0]=a[Ra+(((ca(Sa,L)|0)+Wa<<1)+L)|0]|0;c[f+28192+(Ta*160|0)+32>>2]=c[Va+(Qa<<2)>>2]}if((c[H>>2]&1|0)==0){a[f+28104+(Ta*40|0)+11|0]=-2;c[f+28192+(Ta*160|0)+44>>2]=0;a[f+28104+(Ta*40|0)+19|0]=-2;c[f+28192+(Ta*160|0)+76>>2]=0;a[f+28104+(Ta*40|0)+27|0]=-2;c[f+28192+(Ta*160|0)+108>>2]=0;a[f+28104+(Ta*40|0)+35|0]=-2;c[f+28192+(Ta*160|0)+140>>2]=0}else{a[f+28104+(Ta*40|0)+11|0]=a[Ra+((c[E>>2]|0)+1+(ca(d[V]|0,L)|0))|0]|0;a[f+28104+(Ta*40|0)+19|0]=a[Ra+((c[E>>2]|0)+1+(ca(d[ab]|0,L)|0))|0]|0;Qa=(c[D>>2]|0)+1|0;a[f+28104+(Ta*40|0)+27|0]=a[Ra+((ca(d[Ca]|0,L)|0)+Qa)|0]|0;a[f+28104+(Ta*40|0)+35|0]=a[Ra+((ca(d[Ia]|0,L)|0)+Qa)|0]|0;Qa=(c[G>>2]|0)+3|0;c[f+28192+(Ta*160|0)+44>>2]=c[Va+((ca(d[Fa]|0,w)|0)+Qa<<2)>>2];c[f+28192+(Ta*160|0)+76>>2]=c[Va+((ca(d[sa]|0,w)|0)+Qa<<2)>>2];c[f+28192+(Ta*160|0)+108>>2]=c[Va+((c[F>>2]|0)+3+(ca(d[ka]|0,w)|0)<<2)>>2];c[f+28192+(Ta*160|0)+140>>2]=c[Va+((c[F>>2]|0)+3+(ca(d[Ya]|0,w)|0)<<2)>>2]}do{if((c[H>>2]&1|0)!=0){Qa=c[v>>2]|0;if((c[l>>2]|0)==0){if((a[(c[eb>>2]|0)+(Qa-1)|0]|0)==0){break}a[f+28800+(Ta*3|0)|0]=a[Ra+((c[E>>2]|0)+k+(ca(d[V]|0,L)|0))|0]|0;a[f+28800+(Ta*3|0)+1|0]=a[Ra+((c[E>>2]|0)+k+(ca(d[V]|0,L)|0))|0]|0;a[f+28800+(Ta*3|0)+2|0]=a[Ra+((c[E>>2]|0)+k+(ca(d[Ca]|0,L)|0))|0]|0;c[f+28776+(Ta*12|0)>>2]=c[Va+((c[G>>2]|0)+Ea+(ca(d[Fa]|0,w)|0)<<2)>>2];c[f+28776+(Ta*12|0)+4>>2]=c[Va+((c[G>>2]|0)+Ea+(ca(d[sa]|0,w)|0)<<2)>>2];c[f+28776+(Ta*12|0)+8>>2]=c[Va+((c[G>>2]|0)+Ea+(ca(d[ka]|0,w)|0)<<2)>>2];break}else{if((a[(c[eb>>2]|0)+(Qa-1)|0]|0)!=0){break}a[f+28800+(Ta*3|0)|0]=a[Ra+((c[E>>2]|0)+1)|0]|0;a[f+28800+(Ta*3|0)+1|0]=a[Ra+(Ba+(c[E>>2]|0))|0]|0;a[f+28800+(Ta*3|0)+2|0]=a[Ra+((c[D>>2]|0)+1)|0]|0;c[f+28776+(Ta*12|0)>>2]=c[Va+((c[G>>2]|0)+3+(ca((d[Fa]|0)+1|0,w)|0)<<2)>>2];c[f+28776+(Ta*12|0)+4>>2]=c[Va+((c[G>>2]|0)+3+(ca((d[sa]|0)+1|0,w)|0)<<2)>>2];c[f+28776+(Ta*12|0)+8>>2]=c[Va+((c[F>>2]|0)+3+(ca((d[ka]|0)+1|0,w)|0)<<2)>>2];break}}}while(0);a:do{if((c[db>>2]|0)!=0){Va=c[f+18992+(Ta<<2)>>2]|0;Ra=c[H>>2]|0;if((Ra&2|0)==0){Qa=f+28512+(Ta*80|0)+8|0;c[Qa>>2]=0;c[Qa+4>>2]=0}else{Qa=Va+(U<<4)|0;Sa=c[Qa+4>>2]|0;Pa=f+28512+(Ta*80|0)+8|0;c[Pa>>2]=c[Qa>>2];c[Pa+4>>2]=Sa}do{if((Ra&1|0)==0){b[f+28512+(Ta*80|0)+22>>1]=0;b[f+28512+(Ta*80|0)+38>>1]=0}else{if((a[f+28104+(Ta*40|0)+11|0]|0)>-1){b[f+28512+(Ta*80|0)+22>>1]=b[Va+(c[N>>2]<<4)+(d[$a]<<1)>>1]|0;b[f+28512+(Ta*80|0)+38>>1]=b[Va+(c[N>>2]<<4)+(d[_a]<<1)>>1]|0}else{b[f+28512+(Ta*80|0)+22>>1]=0;b[f+28512+(Ta*80|0)+38>>1]=0}if(!((a[f+28104+(Ta*40|0)+27|0]|0)>-1)){break}Sa=c[M>>2]|0;b[f+28512+(Ta*80|0)+54>>1]=b[Va+(Sa<<4)+(d[bb]<<1)>>1]|0;b[f+28512+(Ta*80|0)+70>>1]=b[Va+(Sa<<4)+(d[ia]<<1)>>1]|0;break a}}while(0);b[f+28512+(Ta*80|0)+54>>1]=0;b[f+28512+(Ta*80|0)+70>>1]=0}}while(0);Va=c[O>>2]|0;Ra=(Va|0)>-1;do{if((c[l>>2]|0)==0){do{if(Ra){if((a[(c[eb>>2]|0)+Va|0]|0)==0){break}Sa=f+28104+(Ta*40|0)+3|0;Pa=a[Sa]|0;if(!(Pa<<24>>24>-1)){break}a[Sa]=Pa<<24>>24>>>1;Pa=f+28192+(Ta*160|0)+14|0;b[Pa>>1]=b[Pa>>1]<<1;Pa=f+28512+(Ta*80|0)+7|0;a[Pa]=a[Pa]<<1}}while(0);do{if(cb){if((a[(c[eb>>2]|0)+U|0]|0)==0){break}Pa=f+28104+(Ta*40|0)+4|0;Sa=a[Pa]|0;if(Sa<<24>>24>-1){a[Pa]=Sa<<24>>24>>>1;Sa=f+28192+(Ta*160|0)+18|0;b[Sa>>1]=b[Sa>>1]<<1;Sa=f+28512+(Ta*80|0)+9|0;a[Sa]=a[Sa]<<1}Sa=f+28104+(Ta*40|0)+5|0;Pa=a[Sa]|0;if(Pa<<24>>24>-1){a[Sa]=Pa<<24>>24>>>1;Pa=f+28192+(Ta*160|0)+22|0;b[Pa>>1]=b[Pa>>1]<<1;Pa=f+28512+(Ta*80|0)+11|0;a[Pa]=a[Pa]<<1}Pa=f+28104+(Ta*40|0)+6|0;Sa=a[Pa]|0;if(Sa<<24>>24>-1){a[Pa]=Sa<<24>>24>>>1;Sa=f+28192+(Ta*160|0)+26|0;b[Sa>>1]=b[Sa>>1]<<1;Sa=f+28512+(Ta*80|0)+13|0;a[Sa]=a[Sa]<<1}Sa=f+28104+(Ta*40|0)+7|0;Pa=a[Sa]|0;if(!(Pa<<24>>24>-1)){break}a[Sa]=Pa<<24>>24>>>1;Pa=f+28192+(Ta*160|0)+30|0;b[Pa>>1]=b[Pa>>1]<<1;Pa=f+28512+(Ta*80|0)+15|0;a[Pa]=a[Pa]<<1}}while(0);Pa=c[P>>2]|0;do{if((Pa|0)>-1){if((a[(c[eb>>2]|0)+Pa|0]|0)==0){break}Sa=f+28104+(Ta*40|0)+8|0;Qa=a[Sa]|0;if(!(Qa<<24>>24>-1)){break}a[Sa]=Qa<<24>>24>>>1;Qa=f+28192+(Ta*160|0)+34|0;b[Qa>>1]=b[Qa>>1]<<1;Qa=f+28512+(Ta*80|0)+17|0;a[Qa]=a[Qa]<<1}}while(0);Pa=c[N>>2]|0;if(!((Pa|0)>-1)){break}if((a[(c[eb>>2]|0)+Pa|0]|0)==0){break}Pa=f+28104+(Ta*40|0)+11|0;Qa=a[Pa]|0;if(Qa<<24>>24>-1){a[Pa]=Qa<<24>>24>>>1;Qa=f+28192+(Ta*160|0)+46|0;b[Qa>>1]=b[Qa>>1]<<1;Qa=f+28512+(Ta*80|0)+23|0;a[Qa]=a[Qa]<<1}Qa=f+28104+(Ta*40|0)+19|0;Pa=a[Qa]|0;if(Pa<<24>>24>-1){a[Qa]=Pa<<24>>24>>>1;Pa=f+28192+(Ta*160|0)+78|0;b[Pa>>1]=b[Pa>>1]<<1;Pa=f+28512+(Ta*80|0)+39|0;a[Pa]=a[Pa]<<1}Pa=f+28104+(Ta*40|0)+27|0;Qa=a[Pa]|0;if(Qa<<24>>24>-1){a[Pa]=Qa<<24>>24>>>1;Qa=f+28192+(Ta*160|0)+110|0;b[Qa>>1]=b[Qa>>1]<<1;Qa=f+28512+(Ta*80|0)+55|0;a[Qa]=a[Qa]<<1}Qa=f+28104+(Ta*40|0)+35|0;Pa=a[Qa]|0;if(Pa<<24>>24>-1){a[Qa]=Pa<<24>>24>>>1;Pa=f+28192+(Ta*160|0)+142|0;b[Pa>>1]=b[Pa>>1]<<1;Pa=f+28512+(Ta*80|0)+71|0;a[Pa]=a[Pa]<<1}Pa=f+28800+(Ta*3|0)|0;Qa=a[Pa]|0;if(Qa<<24>>24>-1){a[Pa]=Qa<<24>>24>>>1;Qa=f+28776+(Ta*12|0)+2|0;b[Qa>>1]=b[Qa>>1]<<1;Qa=f+28512+(Ta*80|0)+1|0;a[Qa]=a[Qa]<<1}Qa=f+28800+(Ta*3|0)+1|0;Pa=a[Qa]|0;if(Pa<<24>>24>-1){a[Qa]=Pa<<24>>24>>>1;Pa=f+28776+(Ta*12|0)+6|0;b[Pa>>1]=b[Pa>>1]<<1;Pa=f+28512+(Ta*80|0)+3|0;a[Pa]=a[Pa]<<1}Pa=f+28800+(Ta*3|0)+2|0;Qa=a[Pa]|0;if(!(Qa<<24>>24>-1)){break}a[Pa]=Qa<<24>>24>>>1;Qa=f+28776+(Ta*12|0)+10|0;b[Qa>>1]=b[Qa>>1]<<1;Qa=f+28512+(Ta*80|0)+5|0;a[Qa]=a[Qa]<<1}else{do{if(Ra){if((a[(c[eb>>2]|0)+Va|0]|0)!=0){break}Qa=f+28104+(Ta*40|0)+3|0;Pa=a[Qa]|0;if(!(Pa<<24>>24>-1)){break}a[Qa]=Pa<<1;Pa=f+28192+(Ta*160|0)+14|0;b[Pa>>1]=(b[Pa>>1]|0)/2|0;Pa=f+28512+(Ta*80|0)+7|0;a[Pa]=(d[Pa]|0)>>>1}}while(0);do{if(cb){if((a[(c[eb>>2]|0)+U|0]|0)!=0){break}Pa=f+28104+(Ta*40|0)+4|0;Qa=a[Pa]|0;if(Qa<<24>>24>-1){a[Pa]=Qa<<1;Qa=f+28192+(Ta*160|0)+18|0;b[Qa>>1]=(b[Qa>>1]|0)/2|0;Qa=f+28512+(Ta*80|0)+9|0;a[Qa]=(d[Qa]|0)>>>1}Qa=f+28104+(Ta*40|0)+5|0;Pa=a[Qa]|0;if(Pa<<24>>24>-1){a[Qa]=Pa<<1;Pa=f+28192+(Ta*160|0)+22|0;b[Pa>>1]=(b[Pa>>1]|0)/2|0;Pa=f+28512+(Ta*80|0)+11|0;a[Pa]=(d[Pa]|0)>>>1}Pa=f+28104+(Ta*40|0)+6|0;Qa=a[Pa]|0;if(Qa<<24>>24>-1){a[Pa]=Qa<<1;Qa=f+28192+(Ta*160|0)+26|0;b[Qa>>1]=(b[Qa>>1]|0)/2|0;Qa=f+28512+(Ta*80|0)+13|0;a[Qa]=(d[Qa]|0)>>>1}Qa=f+28104+(Ta*40|0)+7|0;Pa=a[Qa]|0;if(!(Pa<<24>>24>-1)){break}a[Qa]=Pa<<1;Pa=f+28192+(Ta*160|0)+30|0;b[Pa>>1]=(b[Pa>>1]|0)/2|0;Pa=f+28512+(Ta*80|0)+15|0;a[Pa]=(d[Pa]|0)>>>1}}while(0);Pa=c[P>>2]|0;do{if((Pa|0)>-1){if((a[(c[eb>>2]|0)+Pa|0]|0)!=0){break}Qa=f+28104+(Ta*40|0)+8|0;Sa=a[Qa]|0;if(!(Sa<<24>>24>-1)){break}a[Qa]=Sa<<1;Sa=f+28192+(Ta*160|0)+34|0;b[Sa>>1]=(b[Sa>>1]|0)/2|0;Sa=f+28512+(Ta*80|0)+17|0;a[Sa]=(d[Sa]|0)>>>1}}while(0);Pa=c[N>>2]|0;if(!((Pa|0)>-1)){break}if((a[(c[eb>>2]|0)+Pa|0]|0)!=0){break}Pa=f+28104+(Ta*40|0)+11|0;Sa=a[Pa]|0;if(Sa<<24>>24>-1){a[Pa]=Sa<<1;Sa=f+28192+(Ta*160|0)+46|0;b[Sa>>1]=(b[Sa>>1]|0)/2|0;Sa=f+28512+(Ta*80|0)+23|0;a[Sa]=(d[Sa]|0)>>>1}Sa=f+28104+(Ta*40|0)+19|0;Pa=a[Sa]|0;if(Pa<<24>>24>-1){a[Sa]=Pa<<1;Pa=f+28192+(Ta*160|0)+78|0;b[Pa>>1]=(b[Pa>>1]|0)/2|0;Pa=f+28512+(Ta*80|0)+39|0;a[Pa]=(d[Pa]|0)>>>1}Pa=f+28104+(Ta*40|0)+27|0;Sa=a[Pa]|0;if(Sa<<24>>24>-1){a[Pa]=Sa<<1;Sa=f+28192+(Ta*160|0)+110|0;b[Sa>>1]=(b[Sa>>1]|0)/2|0;Sa=f+28512+(Ta*80|0)+55|0;a[Sa]=(d[Sa]|0)>>>1}Sa=f+28104+(Ta*40|0)+35|0;Pa=a[Sa]|0;if(Pa<<24>>24>-1){a[Sa]=Pa<<1;Pa=f+28192+(Ta*160|0)+142|0;b[Pa>>1]=(b[Pa>>1]|0)/2|0;Pa=f+28512+(Ta*80|0)+71|0;a[Pa]=(d[Pa]|0)>>>1}Pa=f+28800+(Ta*3|0)|0;Sa=a[Pa]|0;if(Sa<<24>>24>-1){a[Pa]=Sa<<1;Sa=f+28776+(Ta*12|0)+2|0;b[Sa>>1]=(b[Sa>>1]|0)/2|0;Sa=f+28512+(Ta*80|0)+1|0;a[Sa]=(d[Sa]|0)>>>1}Sa=f+28800+(Ta*3|0)+1|0;Pa=a[Sa]|0;if(Pa<<24>>24>-1){a[Sa]=Pa<<1;Pa=f+28776+(Ta*12|0)+6|0;b[Pa>>1]=(b[Pa>>1]|0)/2|0;Pa=f+28512+(Ta*80|0)+3|0;a[Pa]=(d[Pa]|0)>>>1}Pa=f+28800+(Ta*3|0)+2|0;Sa=a[Pa]|0;if(!(Sa<<24>>24>-1)){break}a[Pa]=Sa<<1;Sa=f+28776+(Ta*12|0)+10|0;b[Sa>>1]=(b[Sa>>1]|0)/2|0;Sa=f+28512+(Ta*80|0)+5|0;a[Sa]=(d[Sa]|0)>>>1}}while(0);Ta=Ta+1|0;}while((Ta|0)<(p|0))}do{if((Z|g|0)==0){p=c[K>>2]|0;if((p|0)<(c[f+3244>>2]|0)){c[f+18948>>2]=0;fb=0;break}else{Ta=d[(c[f+19276>>2]|0)+p|0]|0;c[f+18948>>2]=Ta;fb=Ta;break}}else{fb=c[f+18948>>2]|0}}while(0);K=f+18944|0;c[K>>2]=1;Ta=c[l>>2]|0;do{if(!((Ta|0)==(fb|0)|_)){l=a[(c[f+18956>>2]|0)+((c[v>>2]|0)-(c[q>>2]|0))|0]|0;if(!((l<<24>>24|0)==6|(l<<24>>24|0)==18)){break}c[K>>2]=0}}while(0);K=(c[f+152>>2]|0)==0;if(!K){v=c[q>>2]|0;q=(ca(v,h&-2)|0)+g|0;_=q-1|0;l=(Z|0)!=0;p=(g|0)>0;if(l&p){gb=((fb|0)==(d[(c[f+19276>>2]|0)+_|0]|0)?v:0)+_|0}else{gb=_}do{if((fb|0)==0){hb=(ca(v,h-1|0)|0)+g|0}else{_=q-v|0;if(!((_|0)>-1&(l^1))){hb=_;break}if((e[(c[f+19272>>2]|0)+(_<<1)>>1]|0)!=(c[f+3244>>2]|0)){hb=_;break}hb=_-((a[(c[f+19276>>2]|0)+_|0]|0)==0?0:v)|0}}while(0);do{if(p){if((e[(c[f+19272>>2]|0)+(gb<<1)>>1]|0)!=(c[f+3244>>2]|0)){ib=0;break}v=a[(c[f+18956>>2]|0)+gb|0]|0;if(v<<24>>24==6){ib=0;break}ib=v<<24>>24!=18|0}else{ib=0}}while(0);do{if((hb|0)>-1){if((e[(c[f+19272>>2]|0)+(hb<<1)>>1]|0)!=(c[f+3244>>2]|0)){jb=0;break}gb=a[(c[f+18956>>2]|0)+hb|0]|0;if(gb<<24>>24==6){jb=0;break}jb=gb<<24>>24!=18|0}else{jb=0}}while(0);c[f+28764>>2]=jb+ib}ib=c[la>>2]|0;if((ib|0)==0){fQb(f,f+28756|0);kb=c[I>>2]|0;lb=kb&11;mb=kb<<1;nb=mb&4;ob=nb|lb;pb=f+18788|0;c[pb>>2]=ob;qb=f+18804|0;c[qb>>2]=ob;rb=kb&2;sb=(rb|0)!=0;tb=sb?15:1;ub=f+18808|0;c[ub>>2]=tb;vb=f+18820|0;c[vb>>2]=tb;wb=kb&1;xb=(wb|0)!=0;yb=xb?15:6;zb=f+18796|0;c[zb>>2]=yb;Ab=f+18844|0;c[Ab>>2]=yb;Bb=f+18836|0;c[Bb>>2]=yb;Cb=f+18812|0;c[Cb>>2]=yb;Db=kb&4;Eb=sb?10:0;Fb=Db|Eb;Gb=Fb|1;Hb=f+18792|0;c[Hb>>2]=Gb;Ib=f+18824|0;c[Ib>>2]=Gb;i=j;return}else if((ib|0)==1){ib=Ta&Z;c[f+30412>>2]=f+29900+(Ta<<8)+(ib<<7);c[f+29896>>2]=f+28872+(Ta<<9)+(ib<<8);if(K){kb=c[I>>2]|0;lb=kb&11;mb=kb<<1;nb=mb&4;ob=nb|lb;pb=f+18788|0;c[pb>>2]=ob;qb=f+18804|0;c[qb>>2]=ob;rb=kb&2;sb=(rb|0)!=0;tb=sb?15:1;ub=f+18808|0;c[ub>>2]=tb;vb=f+18820|0;c[vb>>2]=tb;wb=kb&1;xb=(wb|0)!=0;yb=xb?15:6;zb=f+18796|0;c[zb>>2]=yb;Ab=f+18844|0;c[Ab>>2]=yb;Bb=f+18836|0;c[Bb>>2]=yb;Cb=f+18812|0;c[Cb>>2]=yb;Db=kb&4;Eb=sb?10:0;Fb=Db|Eb;Gb=Fb|1;Hb=f+18792|0;c[Hb>>2]=Gb;Ib=f+18824|0;c[Ib>>2]=Gb;i=j;return}c[f+28684>>2]=0;c[f+28692>>2]=0;c[f+28700>>2]=0;c[f+28708>>2]=0;K=c[H>>2]|0;if((K&1|0)==0){a[f+28683|0]=0;Jb=0}else{a[f+28683|0]=(d[(c[f+19264>>2]|0)+(c[N>>2]|0)|0]|0)>>>((d[pa+12|0]|1)>>>0)&1;Jb=d[(c[f+19264>>2]|0)+(c[M>>2]|0)|0]|0}a[f+28699|0]=Jb>>>((d[pa+14|0]|1)>>>0)&1;if((K&2|0)==0){Kb=0}else{Kb=a[(c[f+19264>>2]|0)+U|0]|0}a[f+28676|0]=Kb&4;a[f+28678|0]=Kb&8;kb=c[I>>2]|0;lb=kb&11;mb=kb<<1;nb=mb&4;ob=nb|lb;pb=f+18788|0;c[pb>>2]=ob;qb=f+18804|0;c[qb>>2]=ob;rb=kb&2;sb=(rb|0)!=0;tb=sb?15:1;ub=f+18808|0;c[ub>>2]=tb;vb=f+18820|0;c[vb>>2]=tb;wb=kb&1;xb=(wb|0)!=0;yb=xb?15:6;zb=f+18796|0;c[zb>>2]=yb;Ab=f+18844|0;c[Ab>>2]=yb;Bb=f+18836|0;c[Bb>>2]=yb;Cb=f+18812|0;c[Cb>>2]=yb;Db=kb&4;Eb=sb?10:0;Fb=Db|Eb;Gb=Fb|1;Hb=f+18792|0;c[Hb>>2]=Gb;Ib=f+18824|0;c[Ib>>2]=Gb;i=j;return}else{kb=c[I>>2]|0;lb=kb&11;mb=kb<<1;nb=mb&4;ob=nb|lb;pb=f+18788|0;c[pb>>2]=ob;qb=f+18804|0;c[qb>>2]=ob;rb=kb&2;sb=(rb|0)!=0;tb=sb?15:1;ub=f+18808|0;c[ub>>2]=tb;vb=f+18820|0;c[vb>>2]=tb;wb=kb&1;xb=(wb|0)!=0;yb=xb?15:6;zb=f+18796|0;c[zb>>2]=yb;Ab=f+18844|0;c[Ab>>2]=yb;Bb=f+18836|0;c[Bb>>2]=yb;Cb=f+18812|0;c[Cb>>2]=yb;Db=kb&4;Eb=sb?10:0;Fb=Db|Eb;Gb=Fb|1;Hb=f+18792|0;c[Hb>>2]=Gb;Ib=f+18824|0;c[Ib>>2]=Gb;i=j;return}}function hPb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;f=i;i=i+8|0;g=f|0;h=c[e+28808>>2]|0;if((c[e+19344>>2]|0)>>>0<4>>>0){mrc(h+4|0,3,12)|0;mrc(h+36|0,3,12)|0;i=f;return}j=e+19356|0;do{if((c[j>>2]|0)!=0){if((c[e+8632>>2]|0)==3){break}k=15>>>((c[e+18576>>2]|0)>>>0);if((c[e+19360>>2]&k|0)!=(k|0)){break}c[h>>2]=33686018;c[h+8>>2]=33686018;c[h+16>>2]=33686018;mrc(h+32|0,2,20)|0;i=f;return}}while(0);if((c[e+8348>>2]|0)==2){l=0}else{k=c[e+18872>>2]|0;m=e+18784|0;n=k&~c[m>>2];c[m>>2]=k;l=n}n=e+3260|0;k=(c[n>>2]|0)==0;do{if(!k){if((c[e+18784>>2]&1|0)==0){break}m=(c[e+18616>>2]|0)-1|0;if((d[(c[e+19276>>2]|0)+m|0]|0)==(c[e+18660>>2]|0)){break}o=e+18900|0;c[o>>2]=m;p=e+18904|0;c[p>>2]=m;q=c[e+18580>>2]|0;if((c[e+18612>>2]&1|0)==0){c[p>>2]=q+m;break}else{c[o>>2]=m-q;break}}}while(0);if((l|0)!=0){q=c[e+18920>>2]|0;m=c[e+18584>>2]|0;o=ca(q<<1|1,m)|0;p=c[e+18608>>2]|0;r=o+(p<<1)|0;o=c[e+18588>>2]|0;s=(ca(o,q<<2|3)|0)+(p<<2)|0;p=c[e+18976>>2]|0;if(k){t=1012676}else{t=c[e+18932>>2]|0}k=(l&2|0)!=0;if(k){c[e+27988>>2]=c[p+((c[e+18908>>2]|0)*48|0)+12>>2]}q=(l&1|0)!=0;if(q){l=c[e+18900>>2]|0;a[e+27995|0]=a[(d[t+4|0]|0)+(p+(l*48|0))|0]|0;a[e+28003|0]=a[(d[t+5|0]|0)+(p+(l*48|0))|0]|0;l=c[e+18904>>2]|0;a[e+28011|0]=a[(d[t+6|0]|0)+(p+(l*48|0))|0]|0;a[e+28019|0]=a[(d[t+7|0]|0)+(p+(l*48|0))|0]|0}l=e+3240|0;p=r+1|0;u=e+18592|0;v=t+16|0;w=e+18596|0;x=t+18|0;y=e+18600|0;z=t+12|0;A=t+13|0;B=e+18604|0;C=t+14|0;D=t+15|0;t=0;do{E=c[e+18984+(t<<2)>>2]|0;F=c[e+19e3+(t<<2)>>2]|0;if(k){G=a[F+r|0]|0;a[e+28104+(t*40|0)+5|0]=G;a[e+28104+(t*40|0)+4|0]=G;G=a[F+p|0]|0;a[e+28104+(t*40|0)+7|0]=G;a[e+28104+(t*40|0)+6|0]=G;G=e+28192+(t*160|0)+16|0;H=E+(s<<2)|0;c[G>>2]=c[H>>2];c[G+4>>2]=c[H+4>>2];c[G+8>>2]=c[H+8>>2];c[G+12>>2]=c[H+12>>2]}if(q){H=a[F+((c[u>>2]|0)+1+(ca(d[v]|0,m)|0))|0]|0;a[e+28104+(t*40|0)+19|0]=H;a[e+28104+(t*40|0)+11|0]=H;H=a[F+((c[w>>2]|0)+1+(ca(d[x]|0,m)|0))|0]|0;a[e+28104+(t*40|0)+35|0]=H;a[e+28104+(t*40|0)+27|0]=H;H=(c[y>>2]|0)+3|0;c[e+28192+(t*160|0)+44>>2]=c[E+(H+(ca(d[z]|0,o)|0)<<2)>>2];c[e+28192+(t*160|0)+76>>2]=c[E+(H+(ca(d[A]|0,o)|0)<<2)>>2];c[e+28192+(t*160|0)+108>>2]=c[E+((c[B>>2]|0)+3+(ca(d[C]|0,o)|0)<<2)>>2];c[e+28192+(t*160|0)+140>>2]=c[E+((c[B>>2]|0)+3+(ca(d[D]|0,o)|0)<<2)>>2]}t=t+1|0;}while((t|0)<=((c[l>>2]|0)==1|0))}do{if((c[e+528>>2]|0)==2){if((c[e+3240>>2]|0)!=0){break}l=e+28108|0;t=a[(a[l]|0)+2+(e+30440)|0]|0;a[e+28109|0]=t;a[l]=t;t=e+28110|0;l=a[(a[t]|0)+2+(e+30440)|0]|0;a[e+28111|0]=l;a[t]=l;l=e+28115|0;t=a[(a[l]|0)+2+(e+30440)|0]|0;a[e+28123|0]=t;a[l]=t;t=e+28131|0;l=a[(a[t]|0)+2+(e+30440)|0]|0;a[e+28139|0]=l;a[t]=l;l=e+28116|0;t=e+28132|0;o=(d[(a[e+28118|0]|0)+2+(e+30440)|0]<<16|d[(a[l]|0)+2+(e+30440)|0])*257|0;D=(d[(a[e+28134|0]|0)+2+(e+30440)|0]<<16|d[(a[t]|0)+2+(e+30440)|0])*257|0;c[l>>2]=o;c[e+28124>>2]=o;c[t>>2]=D;c[e+28140>>2]=D}}while(0);D=e+152|0;do{if((c[D>>2]|0)==0){if((c[e+8696>>2]|0)==0){break}t=c[e+18976>>2]|0;o=c[e+18908>>2]|0;l=e+18900|0;B=c[e+18784>>2]|0;do{if((B&2|0)!=0){if((a[(c[e+19268>>2]|0)+o|0]|0)==0){break}C=b[t+(o*48|0)+14>>1]|b[t+(o*48|0)+10>>1];b[e+27988>>1]=(b[t+(o*48|0)+12>>1]|b[t+(o*48|0)+8>>1])<<16>>16!=0?257:0;b[e+27990>>1]=C<<16>>16!=0?257:0}}while(0);do{if((B&1|0)!=0){o=c[l>>2]|0;C=c[e+19268>>2]|0;if((a[C+o|0]|0)!=0){A=(b[t+(o*48|0)+6>>1]|b[t+(o*48|0)+2>>1])<<16>>16!=0|0;a[e+27995|0]=A;a[e+28003|0]=A}A=c[e+18904>>2]|0;if((a[C+A|0]|0)==0){break}C=(b[t+(A*48|0)+14>>1]|b[t+(A*48|0)+10>>1])<<16>>16!=0|0;a[e+28011|0]=C;a[e+28019|0]=C}}while(0);if((c[j>>2]|0)==0){break}t=e+27996|0;l=e+28004|0;B=e+28012|0;C=e+28020|0;A=(((b[e+28006>>1]|b[e+27998>>1])<<16>>16!=0)<<16|(b[l>>1]|b[t>>1])<<16>>16!=0)*257|0;o=(((b[e+28022>>1]|b[e+28014>>1])<<16>>16!=0)<<16|(b[C>>1]|b[B>>1])<<16>>16!=0)*257|0;c[t>>2]=A;c[l>>2]=A;c[B>>2]=o;c[C>>2]=o}}while(0);j=e+18660|0;_e[c[e+38004>>2]&511](e+27984|0,e+28104|0,e+28192|0,h,4>>>((c[j>>2]|0)>>>0),(c[e+3240>>2]|0)==1|0);if((c[n>>2]|0)==0){i=f;return}n=g;o=g;C=e+18784|0;do{if((c[C>>2]&1|0)!=0){B=c[j>>2]|0;if((d[(c[e+19276>>2]|0)+(c[e+18900>>2]|0)|0]|0)==(B|0)){break}A=c[e+18612>>2]&1;l=c[e+18976>>2]|0;t=(B|0)!=0;z=(c[D>>2]|0)==0;y=e+8696|0;m=e+19268|0;x=0;do{w=c[e+18900+((t?x>>2:x&1)<<2)>>2]|0;v=a[(x>>>1<<3)+12+(e+27984)|0]|0;u=d[95464+(B<<4)+(A<<3)+x|0]<<2;q=d[(u|3)+(l+(w*48|0))|0]|0;do{if(z){if((c[y>>2]|0)==0){I=q;break}if((a[(c[m>>2]|0)+w|0]|0)==0){I=q;break}I=(b[(u|6)+(l+(w*48|0))>>1]|b[(u&1016|2)+(l+(w*48|0))>>1])<<16>>16!=0|0}else{I=q}}while(0);if((I|0)==0){J=v<<24>>24!=0?2:1}else{J=2}a[o+x|0]=J;x=x+1|0;}while((x|0)<8);if(t){c[h>>2]=c[g>>2];c[h+16>>2]=c[g+4>>2];break}else{a[h|0]=a[n]|0;a[h+1|0]=a[o+2|0]|0;a[h+2|0]=a[g+4|0]|0;a[h+3|0]=a[o+6|0]|0;a[h+16|0]=a[o+1|0]|0;a[h+17|0]=a[o+3|0]|0;a[h+18|0]=a[o+5|0]|0;a[h+19|0]=a[o+7|0]|0;break}}}while(0);if((c[C>>2]&2|0)==0){i=f;return}C=c[j>>2]|0;if((C|0)==(d[(c[e+19276>>2]|0)+(c[e+18908>>2]|0)|0]|0)){i=f;return}if((c[e+18612>>2]&1|C|0)!=0){C=h+32|0;j=a[C]|0;a[C]=(j&255)>>>0>1>>>0?j:1;j=h+33|0;C=a[j]|0;a[j]=(C&255)>>>0>1>>>0?C:1;C=h+34|0;j=a[C]|0;a[C]=(j&255)>>>0>1>>>0?j:1;j=h+35|0;C=a[j]|0;a[j]=(C&255)>>>0>1>>>0?C:1;i=f;return}C=e+18580|0;j=(c[e+18616>>2]|0)-(c[C>>2]<<1)|0;o=e+18976|0;g=e+8696|0;n=e+19268|0;J=e+27996|0;I=e+27997|0;x=e+27998|0;l=e+27999|0;e=c[o>>2]|0;m=c[e+(j*48|0)+12>>2]|0;y=m&65535;z=m&255;A=m>>>8&255;B=m>>>16&255;q=m>>>24&255;do{if((c[D>>2]|0)==0){if((c[g>>2]|0)==0){K=z;L=A;M=B;N=q;break}if((a[(c[n>>2]|0)+j|0]|0)==0){K=z;L=A;M=B;N=q;break}if((b[e+(j*48|0)+8>>1]|0)==0){O=y<<16>>16!=0|0}else{O=1}if((b[e+(j*48|0)+10>>1]|0)!=0){K=O;L=O;M=1;N=1;break}m=(b[e+(j*48|0)+14>>1]|0)!=0|0;K=O;L=O;M=m;N=m}else{K=z;L=A;M=B;N=q}}while(0);if((a[J]|0)==0){P=K<<24>>24!=0?2:1}else{P=2}a[h+32|0]=P;if((a[I]|0)==0){Q=L<<24>>24!=0?2:1}else{Q=2}a[h+33|0]=Q;if((a[x]|0)==0){R=M<<24>>24!=0?2:1}else{R=2}a[h+34|0]=R;if((a[l]|0)==0){S=N<<24>>24!=0?2:1}else{S=2}a[h+35|0]=S;S=(c[C>>2]|0)+j|0;j=c[o>>2]|0;o=c[j+(S*48|0)+12>>2]|0;C=o&65535;N=o&255;R=o>>>8&255;M=o>>>16&255;Q=o>>>24&255;do{if((c[D>>2]|0)==0){if((c[g>>2]|0)==0){T=N;U=R;V=M;W=Q;break}if((a[(c[n>>2]|0)+S|0]|0)==0){T=N;U=R;V=M;W=Q;break}if((b[j+(S*48|0)+8>>1]|0)==0){X=C<<16>>16!=0|0}else{X=1}if((b[j+(S*48|0)+10>>1]|0)!=0){T=X;U=X;V=1;W=1;break}o=(b[j+(S*48|0)+14>>1]|0)!=0|0;T=X;U=X;V=o;W=o}else{T=N;U=R;V=M;W=Q}}while(0);if((a[J]|0)==0){Y=T<<24>>24!=0?2:1}else{Y=2}a[h+48|0]=Y;if((a[I]|0)==0){Z=U<<24>>24!=0?2:1}else{Z=2}a[h+49|0]=Z;if((a[x]|0)==0){_=V<<24>>24!=0?2:1}else{_=2}a[h+50|0]=_;if((a[l]|0)==0){$=W<<24>>24!=0?2:1}else{$=2}a[h+51|0]=$;i=f;return}function iPb(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=c[e+18616>>2]|0;g=e+19344|0;h=c[g>>2]|0;i=a[95080+h|0]|0;j=i&255;k=c[e+18584>>2]|0;l=c[e+18588>>2]|0;m=c[e+18624>>2]|0;n=c[e+18620>>2]|0;o=c[e+18972>>2]|0;p=o+(f<<3)|0;q=c[e+18976>>2]|0;r=q+(f*48|0)|0;s=e+18608|0;t=c[s>>2]|0;u=e+18612|0;v=c[u>>2]&1;do{if((c[e+3260>>2]|0)==0){w=t<<4;x=e+24568|0;nrc((c[e+36464+(v*12|0)>>2]|0)+w|0,(c[x>>2]|0)+480|0,16)|0;z=e+8632|0;if((c[z>>2]|0)==3){nrc((c[e+36464+(v*12|0)+4>>2]|0)+w|0,(c[e+24572>>2]|0)+480|0,16)|0;nrc((c[e+36464+(v*12|0)+8>>2]|0)+w|0,(c[e+24576>>2]|0)+480|0,16)|0}else{A=15>>>((c[e+18576>>2]|0)>>>0)<<5;B=e+36464+(v*12|0)+4|0;C=(c[e+24572>>2]|0)+A|0;D=(c[B>>2]|0)+w|0;E=C|0;F=C+4|0;C=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;F=D|0;y=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;F=D+4|0;y=C;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;F=(c[e+24576>>2]|0)+A|0;A=(c[B>>2]|0)+(w|8)|0;w=F|0;B=F+4|0;F=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=A|0;y=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;B=A+4|0;y=F;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y}B=e+15148|0;F=c[B>>2]|0;A=c[F+156>>2]|0;w=(ca(A,c[u>>2]|0)|0)+(c[s>>2]|0)<<4;C=e+37436|0;pe[c[C>>2]&1023]((c[F+204>>2]|0)+w|0,A,c[x>>2]|0,32,16);x=c[s>>2]|0;A=c[u>>2]|0;if((c[z>>2]|0)==3){z=c[B>>2]|0;w=c[z+160>>2]|0;F=(ca(w,A)|0)+x<<4;pe[c[C>>2]&1023]((c[z+208>>2]|0)+F|0,w,c[e+24572>>2]|0,32,16);w=c[B>>2]|0;F=c[w+164>>2]|0;z=(ca(F,c[u>>2]|0)|0)+(c[s>>2]|0)<<4;pe[c[C>>2]&1023]((c[w+212>>2]|0)+z|0,F,c[e+24576>>2]|0,32,16);break}else{F=16>>>((c[e+18576>>2]|0)>>>0);z=c[B>>2]|0;B=c[z+160>>2]|0;w=(ca(ca(F,A)|0,B)|0)+(x<<4)|0;pe[c[e+37468>>2]&1023]((c[z+208>>2]|0)+w|0,B,c[e+24572>>2]|0,c[e+24576>>2]|0,F);break}}else{F=(v|0)==0;if(F){G=(c[e+18660>>2]|0)!=0?0:2}else{G=1}B=t<<4;w=e+24568|0;nrc((c[e+36464+(G*12|0)>>2]|0)+B|0,(c[w>>2]|0)+480|0,16)|0;z=e+8632|0;if((c[z>>2]|0)==3){nrc((c[e+36464+(G*12|0)+4>>2]|0)+B|0,(c[e+24572>>2]|0)+480|0,16)|0;nrc((c[e+36464+(G*12|0)+8>>2]|0)+B|0,(c[e+24576>>2]|0)+480|0,16)|0}else{x=15>>>((c[e+18576>>2]|0)>>>0)<<5;A=e+36464+(G*12|0)+4|0;C=(c[e+24572>>2]|0)+x|0;D=(c[A>>2]|0)+B|0;E=C|0;H=C+4|0;C=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=D|0;y=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=D+4|0;y=C;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=(c[e+24576>>2]|0)+x|0;x=(c[A>>2]|0)+(B|8)|0;A=H|0;C=H+4|0;H=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=x|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=x+4|0;y=H;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y}C=e+18660|0;do{if(!F){H=(c[C>>2]|0)!=0;x=H?224:448;A=H?2:0;nrc((c[e+36464+(A*12|0)>>2]|0)+B|0,(c[w>>2]|0)+x|0,16)|0;H=c[z>>2]|0;if((H|0)==3){nrc((c[e+36464+(A*12|0)+4>>2]|0)+B|0,(c[e+24572>>2]|0)+x|0,16)|0;nrc((c[e+36464+(A*12|0)+8>>2]|0)+B|0,(c[e+24576>>2]|0)+x|0,16)|0;break}else if((H|0)==1){I=(c[C>>2]|0)!=0?96:192}else{I=x}x=e+36464+(A*12|0)+4|0;A=(c[e+24572>>2]|0)+I|0;H=(c[x>>2]|0)+B|0;D=A|0;E=A+4|0;A=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=H|0;y=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;E=H+4|0;y=A;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;E=(c[e+24576>>2]|0)+I|0;A=(c[x>>2]|0)+(B|8)|0;x=E|0;H=E+4|0;E=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=A|0;y=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=A+4|0;y=E;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y}}while(0);B=c[u>>2]|0;F=e+15148|0;H=c[F>>2]|0;E=c[H+156>>2]|0;A=c[C>>2]|0;x=c[s>>2]<<4;D=B<<4;if((A|0)==0){J=(ca(E,D)|0)+x|0}else{J=(ca(D&-32,E)|0)+x+(E&-(B&1))|0}B=e+37436|0;pe[c[B>>2]&1023]((c[H+204>>2]|0)+J|0,E<<((A|0)!=0),c[w>>2]|0,32,16);A=c[s>>2]|0;E=c[u>>2]|0;if((c[z>>2]|0)!=3){H=16>>>((c[e+18576>>2]|0)>>>0);x=c[F>>2]|0;D=c[x+160>>2]|0;K=c[C>>2]|0;L=A<<4;if((K|0)==0){M=(ca(ca(H,E)|0,D)|0)+L|0}else{M=(ca(ca(H,E&-2)|0,D)|0)+L+(D&-(E&1))|0}pe[c[e+37468>>2]&1023]((c[x+208>>2]|0)+M|0,D<<((K|0)!=0),c[e+24572>>2]|0,c[e+24576>>2]|0,H);break}H=c[F>>2]|0;K=c[H+160>>2]|0;D=c[C>>2]|0;x=A<<4;A=E<<4;if((D|0)==0){N=(ca(K,A)|0)+x|0}else{N=(ca(K,A&-32)|0)+x+(K&-(E&1))|0}pe[c[B>>2]&1023]((c[H+208>>2]|0)+N|0,K<<((D|0)!=0),c[e+24572>>2]|0,32,16);D=c[u>>2]|0;K=c[F>>2]|0;F=c[K+164>>2]|0;H=c[C>>2]|0;E=c[s>>2]<<4;x=D<<4;if((H|0)==0){O=(ca(F,x)|0)+E|0}else{O=(ca(x&-32,F)|0)+E+(F&-(D&1))|0}pe[c[B>>2]&1023]((c[K+212>>2]|0)+O|0,F<<((H|0)!=0),c[e+24576>>2]|0,32,16)}}while(0);O=c[e+15148>>2]|0;N=c[s>>2]|0;s=c[O+156>>2]|0;M=c[O+160>>2]|0;J=N<<4;I=c[u>>2]<<4;u=(ca(s,I)|0)+J|0;G=ca(M,I)|0;pe[c[e+37504>>2]&1023]((c[O+204>>2]|0)+u|0,s,(c[O+208>>2]|0)+((G>>c[e+18576>>2])+J)|0,M,N);a[(c[e+18956>>2]|0)+f|0]=i;b[(c[e+19272>>2]|0)+(f<<1)>>1]=c[e+3244>>2];i=(h|0)==3;N=h>>>0<4>>>0;if(N){P=16}else{P=c[e+19348>>2]&255}a[(c[e+18960>>2]|0)+f|0]=P;c[e+18896>>2]=f;do{if(h>>>0<2>>>0){c[p>>2]=c[e+27972>>2];c[o+(f<<3)+4>>2]=(a[e+27959|0]<<8)+(a[e+27951|0]|0)+(a[e+27967|0]<<16)}else{P=p;if((c[e+164>>2]|0)==0|N){c[P>>2]=33686018;c[P+4>>2]=33686018;break}else{c[P>>2]=-1;c[P+4>>2]=-1;break}}}while(0);if(i){a[(c[e+18964>>2]|0)+f|0]=0;c[e+28828>>2]=0;i=e+8632|0;p=(c[i>>2]|0)==3?0:2;c[e+19364>>2]=p;c[e+19360>>2]=15;b[(c[e+18968>>2]|0)+(f<<1)>>1]=p<<4|1807;c[e+19356>>2]=0;p=e+152|0;o=0;while(1){a[(d[19224+o|0]|0)+(e+27984)|0]=(c[p>>2]|0)!=0?1:16;P=o+1|0;if((P|0)<48){o=P}else{Q=i;break}}}else{do{if((c[g>>2]|0)!=2){if((c[e+19360>>2]|0)!=0){break}if((c[e+19364>>2]|0)!=0){break}c[e+28816>>2]=c[e+28824>>2]}}while(0);i=e+28816|0;a[(c[e+18964>>2]|0)+f|0]=c[i>>2];o=c[i>>2]|0;i=e+28824|0;c[e+28828>>2]=o-(c[i>>2]|0);c[i>>2]=o;Q=e+8632|0}c[r>>2]=c[e+27996>>2];c[q+(f*48|0)+4>>2]=c[e+28004>>2];c[q+(f*48|0)+8>>2]=c[e+28012>>2];c[q+(f*48|0)+12>>2]=c[e+28020>>2];c[q+(f*48|0)+16>>2]=c[e+28036>>2];c[q+(f*48|0)+20>>2]=c[e+28044>>2];c[q+(f*48|0)+32>>2]=c[e+28076>>2];c[q+(f*48|0)+36>>2]=c[e+28084>>2];if((c[Q>>2]|0)>1){c[q+(f*48|0)+24>>2]=c[e+28052>>2];c[q+(f*48|0)+28>>2]=c[e+28060>>2];c[q+(f*48|0)+40>>2]=c[e+28092>>2];c[q+(f*48|0)+44>>2]=c[e+28100>>2]}do{if((c[e+19360>>2]|0)==0){if((c[g>>2]|0)==1){break}c[e+19356>>2]=0}}while(0);a[(c[e+19268>>2]|0)+f|0]=c[e+19356>>2];g=e+3240|0;do{if((c[g>>2]|0)!=2){q=c[e+18984>>2]|0;Q=q+(m<<2)|0;r=c[e+18988>>2]|0;o=r+(m<<2)|0;i=c[e+19e3>>2]|0;p=i+n|0;P=c[e+19004>>2]|0;M=P+n|0;if(N){b[p>>1]=-1;J=n+k|0;b[i+J>>1]=-1;G=Q;c[G>>2]=0;c[G+4>>2]=0;G=m+2|0;O=q+(G<<2)|0;c[O>>2]=0;c[O+4>>2]=0;O=m+l|0;s=q+(O<<2)|0;c[s>>2]=0;c[s+4>>2]=0;s=O+2|0;u=q+(s<<2)|0;c[u>>2]=0;c[u+4>>2]=0;u=m+(l<<1)|0;I=q+(u<<2)|0;c[I>>2]=0;c[I+4>>2]=0;I=u+2|0;t=q+(I<<2)|0;c[t>>2]=0;c[t+4>>2]=0;t=m+(l*3|0)|0;v=q+(t<<2)|0;c[v>>2]=0;c[v+4>>2]=0;v=t+2|0;H=q+(v<<2)|0;c[H>>2]=0;c[H+4>>2]=0;if((c[g>>2]|0)!=1){break}b[M>>1]=-1;b[P+J>>1]=-1;J=o;c[J>>2]=0;c[J+4>>2]=0;J=r+(G<<2)|0;c[J>>2]=0;c[J+4>>2]=0;J=r+(O<<2)|0;c[J>>2]=0;c[J+4>>2]=0;J=r+(s<<2)|0;c[J>>2]=0;c[J+4>>2]=0;J=r+(u<<2)|0;c[J>>2]=0;c[J+4>>2]=0;J=r+(I<<2)|0;c[J>>2]=0;c[J+4>>2]=0;J=r+(t<<2)|0;c[J>>2]=0;c[J+4>>2]=0;J=r+(v<<2)|0;c[J>>2]=0;c[J+4>>2]=0;break}else{a[p]=a[e+28116|0]|0;p=n+1|0;a[i+p|0]=a[e+28118|0]|0;J=n+k|0;a[i+J|0]=a[e+28132|0]|0;v=k+1+n|0;a[i+v|0]=a[e+28134|0]|0;i=Q;Q=e+28240|0;c[i>>2]=c[Q>>2];c[i+4>>2]=c[Q+4>>2];c[i+8>>2]=c[Q+8>>2];c[i+12>>2]=c[Q+12>>2];Q=m+l|0;i=q+(Q<<2)|0;t=e+28272|0;c[i>>2]=c[t>>2];c[i+4>>2]=c[t+4>>2];c[i+8>>2]=c[t+8>>2];c[i+12>>2]=c[t+12>>2];t=m+(l<<1)|0;i=q+(t<<2)|0;I=e+28304|0;c[i>>2]=c[I>>2];c[i+4>>2]=c[I+4>>2];c[i+8>>2]=c[I+8>>2];c[i+12>>2]=c[I+12>>2];I=m+(l*3|0)|0;i=q+(I<<2)|0;q=e+28336|0;c[i>>2]=c[q>>2];c[i+4>>2]=c[q+4>>2];c[i+8>>2]=c[q+8>>2];c[i+12>>2]=c[q+12>>2];if((c[g>>2]|0)!=1){break}a[M]=a[e+28156|0]|0;a[P+p|0]=a[e+28158|0]|0;a[P+J|0]=a[e+28172|0]|0;a[P+v|0]=a[e+28174|0]|0;v=o;o=e+28400|0;c[v>>2]=c[o>>2];c[v+4>>2]=c[o+4>>2];c[v+8>>2]=c[o+8>>2];c[v+12>>2]=c[o+12>>2];o=r+(Q<<2)|0;Q=e+28432|0;c[o>>2]=c[Q>>2];c[o+4>>2]=c[Q+4>>2];c[o+8>>2]=c[Q+8>>2];c[o+12>>2]=c[Q+12>>2];Q=r+(t<<2)|0;t=e+28464|0;c[Q>>2]=c[t>>2];c[Q+4>>2]=c[t+4>>2];c[Q+8>>2]=c[t+8>>2];c[Q+12>>2]=c[t+12>>2];t=r+(I<<2)|0;I=e+28496|0;c[t>>2]=c[I>>2];c[t+4>>2]=c[I+4>>2];c[t+8>>2]=c[I+8>>2];c[t+12>>2]=c[I+12>>2];break}}}while(0);if((c[e+152>>2]|0)==0){return}l=c[e+18992>>2]|0;m=l+(f<<4)|0;n=c[e+18996>>2]|0;k=n+(f<<4)|0;if(h>>>0<3>>>0){a[(c[e+18980>>2]|0)+f|0]=a[95360+(c[e+19372>>2]|0)|0]|0}else{a[(c[e+18980>>2]|0)+f|0]=0}do{if((261936>>>(j>>>0)&1|0)==0){mrc(m|0,0,16)|0;if((c[g>>2]|0)==1){mrc(k|0,0,16)|0;break}else{return}}else{N=e+28584|0;I=c[N+4>>2]|0;t=m;c[t>>2]=c[N>>2];c[t+4>>2]=I;b[l+(f<<4)+8>>1]=b[e+28542>>1]|0;b[l+(f<<4)+10>>1]=b[e+28558>>1]|0;b[l+(f<<4)+12>>1]=b[e+28574>>1]|0;if((c[g>>2]|0)==1){I=e+28664|0;t=c[I+4>>2]|0;N=k;c[N>>2]=c[I>>2];c[N+4>>2]=t;b[n+(f<<4)+8>>1]=b[e+28622>>1]|0;b[n+(f<<4)+10>>1]=b[e+28638>>1]|0;b[n+(f<<4)+12>>1]=b[e+28654>>1]|0;break}else{return}}}while(0);if((c[g>>2]|0)!=1){return}if((h|0)==17){a[(c[e+19264>>2]|0)+f|0]=((a[e+19353|0]|0)==12)<<1|(a[e+19352|0]|0)==12|((a[e+19354|0]|0)==12)<<2|((a[e+19355|0]|0)==12)<<3;return}else if((h|0)==18|(h|0)==7){a[(c[e+19264>>2]|0)+f|0]=15;return}else{a[(c[e+19264>>2]|0)+f|0]=0;return}}function jPb(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=d+3260|0;f=c[e>>2]|0;if((f|0)<0){return}g=d+15152|0;h=d+15156|0;i=d+15148|0;j=d+532|0;k=0;l=f;a:while(1){if((l|0)<0){m=l}else{f=0;n=c[g>>2]|0;o=l;while(1){if((n<<k|0)>0){p=0;q=c[h>>2]|0;r=n;while(1){s=c[d+15160+(p>>k<<2)>>2]|0;t=(ca(c[s+8+((p&1^f)<<2)>>2]|0,k)|0)+(c[s+4>>2]|0)|0;if((q<<k|0)>0){s=0;do{u=c[d+15236+(s>>k<<2)>>2]|0;v=c[i>>2]|0;w=c[v+4>>2]|0;x=c[v+8+(f<<2)>>2]|0;v=(c[u+4>>2]|0)-t+(ca(c[u+8+((s&1^f)<<2)>>2]|0,k)|0)|0;if((v|0)<-128){y=-128;z=10}else{u=(v|0)>127?127:v;if((u|0)==0){A=256}else{y=u;z=10}}do{if((z|0)==10){z=0;u=w-t+(ca(x,k)|0)|0;if((u|0)<-128){B=-128}else{B=(u|0)>127?127:u}u=(ca(((((y|0)>-1?y:-y|0)>>1)+16384|0)/(y|0)|0,B)|0)+32>>6;if((u|0)<-1024){A=-1024;break}A=(u|0)>1023?1023:u}}while(0);b[d+28872+(k<<9)+(f<<8)+(p<<3)+(s<<1)>>1]=A;x=A>>2;do{if((c[j>>2]|0)==0){z=18}else{if(!((x+64|0)>>>0<193>>>0)){z=18;break}a[d+29900+(k<<8)+(f<<7)+(p<<2)+s|0]=64-x;if(!((x+63|0)>>>0<191>>>0)){z=17;break a}}}while(0);if((z|0)==18){z=0;a[d+29900+(k<<8)+(f<<7)+(p<<2)+s|0]=32}s=s+1|0;C=c[h>>2]|0;}while((s|0)<(C<<k|0));D=C;E=c[g>>2]|0}else{D=q;E=r}s=p+1|0;if((s|0)<(E<<k|0)){p=s;q=D;r=E}else{break}}F=E;G=c[e>>2]|0}else{F=n;G=o}r=f+1|0;if((r|0)>(G|0)){m=G;break}else{f=r;n=F;o=G}}}o=k+1|0;if((o|0)>(m|0)){z=25;break}else{k=o;l=m}}if((z|0)==17){Cd(2406944,2577528,1904,2649408)}else if((z|0)==25){return}}function kPb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((f|0)==0){return}else{g=c;h=a;i=f}while(1){f=i-1|0;nrc(h|0,g|0,e)|0;if((f|0)==0){break}else{g=g+d|0;h=h+b|0;i=f}}return}function lPb(b,c,d,e,f,g,h,i){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((i|0)>0&(h|0)>0){j=f;k=d;l=b;m=0}else{return}while(1){b=0;do{d=b<<1;a[l+d|0]=a[k+b|0]|0;a[l+(d|1)|0]=a[j+b|0]|0;b=b+1|0;}while((b|0)<(h|0));b=m+1|0;if((b|0)<(i|0)){j=j+g|0;k=k+e|0;l=l+c|0;m=b}else{break}}return}function mPb(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;if((j|0)>0&(i|0)>0){k=g;l=e;m=b;n=0}else{return}while(1){b=m;e=l;g=k;o=0;while(1){a[e]=c[g>>2];a[b]=(c[g>>2]|0)>>>10;a[e+1|0]=(c[g>>2]|0)>>>20;p=g+4|0;a[b+1|0]=c[p>>2];a[e+2|0]=(c[p>>2]|0)>>>10;a[b+2|0]=(c[p>>2]|0)>>>20;p=o+3|0;if((p|0)<(i|0)){b=b+3|0;e=e+3|0;g=g+8|0;o=p}else{break}}o=n+1|0;if((o|0)<(j|0)){k=k+(h<<2)|0;l=l+f|0;m=m+d|0;n=o}else{break}}return}function nPb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c[e+204>>2]|0;g=c[e+156>>2]|0;h=c[e+180>>2]|0;i=c[e+168>>2]|0;if((h|0)>0){j=i-1|0;k=0;do{l=ca(k,g)|0;a[f+(l+i)|0]=a[f+(j+l)|0]|0;k=k+1|0;}while((k|0)<(h|0))}nrc(f+(ca(h,g)|0)|0,f+(ca(h-1|0,g)|0)|0,i+1|0)|0;Te[c[d+37544>>2]&255](f,c[e+324>>2]|0,c[e+328>>2]|0,c[e+332>>2]|0,c[e+336>>2]|0,g,c[e+192>>2]|0,c[e+196>>2]|0,c[e+200>>2]|0);yOb(e);mrc(e+4520|0,-1|0,1296)|0;g=d+112|0;d=c[g>>2]|0;if((d+2|0)>0){f=0;i=d;while(1){if((i+2|0)>0){h=0;while(1){c[c[e+7188+(f*72|0)+(h<<2)>>2]>>2]=-1;k=h+1|0;j=c[g>>2]|0;if((k|0)<(j+2|0)){h=k}else{m=j;break}}}else{m=i}h=f+1|0;if((h|0)<(m+2|0)){f=h;i=m}else{n=m;break}}}else{n=d}d=(n|0)!=0|0;if((n|0)<0){return}else{o=0}do{m=0;do{b[c[e+2796+(o*68|0)+(m<<2)>>2]>>1]=32767;m=m+1|0;}while((m|0)<=(n|0));o=o+1|0;}while((o|0)<=(d|0));return}function oPb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;c[b>>2]=146;c[b+4>>2]=12;c[b+8>>2]=8;c[b+12>>2]=188;c[b+16>>2]=34;c[b+20>>2]=32;c[b+24>>2]=254;c[b+28>>2]=510;c[b+40>>2]=516;c[b+32>>2]=66;c[b+36>>2]=386;c[b+44>>2]=68;c[b+48>>2]=630;c[b+52>>2]=634;c[b+56>>2]=632;c[b+172>>2]=94736;c[b+176>>2]=94736;c[b+180>>2]=94736;c[b+184>>2]=558;c[b+88>>2]=350;c[b+60>>2]=350;c[b+72>>2]=460;c[b+84>>2]=436;c[b+92>>2]=396;c[b+96>>2]=702;c[b+100>>2]=66;c[b+104>>2]=288;c[b+108>>2]=54;c[b+112>>2]=100;c[b+116>>2]=60;c[b+120>>2]=44;c[b+124>>2]=106;c[b+132>>2]=244;c[b+136>>2]=244;c[b+140>>2]=1844;c[b+144>>2]=438;c[b+148>>2]=482;c[b+168>>2]=114;c[b+152>>2]=2030;c[b+156>>2]=104;c[b+160>>2]=2374;c[b+164>>2]=28;a=b+188|0;c[a>>2]=582;e=b+192|0;c[e>>2]=82;if((d|0)==0){return}c[a>>2]=582;c[e>>2]=82;return}function pPb(b,e,f,g,h,i,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;m=i&3;n=h&3;o=m<<2|n;p=(ca(i>>2,g)|0)+(h>>2)|0;h=(c[f+((d[1091664+o|0]|0)<<2)>>2]|0)+((-((m|0)==3|0)&g)+p)|0;if((o&5|0)==0){if((c[l+44>>2]|0)==0){if((k|0)>0){q=b;r=h;s=0}else{return}while(1){nrc(q|0,r|0,j)|0;m=s+1|0;if((m|0)<(k|0)){q=q+e|0;r=r+g|0;s=m}else{break}}return}s=c[l+32>>2]|0;r=c[l+36>>2]|0;q=c[l+40>>2]|0;m=(k|0)>0;if((s|0)>0){if(!m){return}i=(j|0)>0;t=1<<s-1;u=h;v=b;w=0;while(1){if(i){x=0;do{y=((ca(d[u+x|0]|0,r)|0)+t>>s)+q|0;if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}a[v+x|0]=z;x=x+1|0;}while((x|0)<(j|0))}x=w+1|0;if((x|0)<(k|0)){u=u+g|0;v=v+e|0;w=x}else{break}}return}else{if(!m){return}m=(j|0)>0;w=h;v=b;u=0;while(1){if(m){z=0;do{s=(ca(d[w+z|0]|0,r)|0)+q|0;if(s>>>0>255>>>0){A=-s>>31&255}else{A=s&255}a[v+z|0]=A;z=z+1|0;}while((z|0)<(j|0))}z=u+1|0;if((z|0)<(k|0)){w=w+g|0;v=v+e|0;u=z}else{break}}return}}u=(k|0)>0;v=(j|0)>0;if(u&v){w=(c[f+((d[1091648+o|0]|0)<<2)>>2]|0)+(p+((n|0)==3))|0;n=h;h=b;p=0;while(1){o=0;do{a[h+o|0]=((d[n+o|0]|0)+1+(d[w+o|0]|0)|0)>>>1;o=o+1|0;}while((o|0)<(j|0));o=p+1|0;if((o|0)<(k|0)){w=w+g|0;n=n+g|0;h=h+e|0;p=o}else{break}}}if((c[l+44>>2]|0)==0){return}p=c[l+32>>2]|0;h=c[l+36>>2]|0;g=c[l+40>>2]|0;if((p|0)<=0){if(u){B=b;C=0}else{return}while(1){if(v){l=0;do{n=B+l|0;w=(ca(d[n]|0,h)|0)+g|0;if(w>>>0>255>>>0){D=-w>>31&255}else{D=w&255}a[n]=D;l=l+1|0;}while((l|0)<(j|0))}l=C+1|0;if((l|0)<(k|0)){B=B+e|0;C=l}else{break}}return}if(!u){return}u=1<<p-1;C=b;b=0;while(1){if(v){B=0;do{D=C+B|0;l=((ca(d[D]|0,h)|0)+u>>p)+g|0;if(l>>>0>255>>>0){E=-l>>31&255}else{E=l&255}a[D]=E;B=B+1|0;}while((B|0)<(j|0))}B=b+1|0;if((B|0)<(k|0)){C=C+e|0;b=B}else{break}}return}function qPb(b,e,f,g,h,i,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;m=i&3;n=h&3;o=m<<2|n;p=(ca(i>>2,g)|0)+(h>>2)|0;h=(c[f+((d[1091664+o|0]|0)<<2)>>2]|0)+((-((m|0)==3|0)&g)+p)|0;if((o&5|0)==0){if((c[l+44>>2]|0)==0){c[e>>2]=g;q=h;return q|0}m=c[e>>2]|0;i=c[l+32>>2]|0;r=c[l+36>>2]|0;s=c[l+40>>2]|0;t=(k|0)>0;if((i|0)>0){if(!t){q=b;return q|0}u=(j|0)>0;v=1<<i-1;w=h;x=b;y=0;while(1){if(u){z=0;do{A=((ca(d[w+z|0]|0,r)|0)+v>>i)+s|0;if(A>>>0>255>>>0){B=-A>>31&255}else{B=A&255}a[x+z|0]=B;z=z+1|0;}while((z|0)<(j|0))}z=y+1|0;if((z|0)<(k|0)){w=w+g|0;x=x+m|0;y=z}else{q=b;break}}return q|0}else{if(!t){q=b;return q|0}t=(j|0)>0;y=h;x=b;w=0;while(1){if(t){B=0;do{i=(ca(d[y+B|0]|0,r)|0)+s|0;if(i>>>0>255>>>0){C=-i>>31&255}else{C=i&255}a[x+B|0]=C;B=B+1|0;}while((B|0)<(j|0))}B=w+1|0;if((B|0)<(k|0)){y=y+g|0;x=x+m|0;w=B}else{q=b;break}}return q|0}}w=c[e>>2]|0;m=(k|0)>0;x=(j|0)>0;if(m&x){y=(c[f+((d[1091648+o|0]|0)<<2)>>2]|0)+(p+((n|0)==3))|0;n=h;h=b;p=0;while(1){o=0;do{a[h+o|0]=((d[n+o|0]|0)+1+(d[y+o|0]|0)|0)>>>1;o=o+1|0;}while((o|0)<(j|0));o=p+1|0;if((o|0)<(k|0)){y=y+g|0;n=n+g|0;h=h+w|0;p=o}else{break}}}if((c[l+44>>2]|0)==0){q=b;return q|0}p=c[e>>2]|0;e=c[l+32>>2]|0;w=c[l+36>>2]|0;h=c[l+40>>2]|0;if((e|0)<=0){if(m){D=b;E=0}else{q=b;return q|0}while(1){if(x){l=0;do{g=D+l|0;n=(ca(d[g]|0,w)|0)+h|0;if(n>>>0>255>>>0){F=-n>>31&255}else{F=n&255}a[g]=F;l=l+1|0;}while((l|0)<(j|0))}l=E+1|0;if((l|0)<(k|0)){D=D+p|0;E=l}else{q=b;break}}return q|0}if(!m){q=b;return q|0}m=1<<e-1;E=b;D=0;while(1){if(x){F=0;do{l=E+F|0;g=((ca(d[l]|0,w)|0)+m>>e)+h|0;if(g>>>0>255>>>0){G=-g>>31&255}else{G=g&255}a[l]=G;F=F+1|0;}while((F|0)<(j|0))}F=D+1|0;if((F|0)<(k|0)){E=E+p|0;D=F}else{q=b;break}}return q|0}function rPb(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=h&7;m=i&7;n=8-l|0;o=8-m|0;p=ca(o,n)|0;q=ca(o,l)|0;o=ca(n,m)|0;n=ca(m,l)|0;l=(ca(i>>3,g)|0)+(h>>3<<1)|0;if((k|0)<=0){return}h=(j|0)>0;i=f+(l+g)|0;m=f+l|0;l=c;c=b;b=0;while(1){if(h){f=0;do{r=f<<1;s=ca(d[m+r|0]|0,p)|0;t=r+2|0;u=ca(d[m+t|0]|0,q)|0;v=ca(d[i+r|0]|0,o)|0;a[c+f|0]=(s+32+u+v+(ca(d[i+t|0]|0,n)|0)|0)>>>6;t=r|1;v=ca(d[m+t|0]|0,p)|0;u=r+3|0;r=ca(d[m+u|0]|0,q)|0;s=ca(d[i+t|0]|0,o)|0;a[l+f|0]=(v+32+r+s+(ca(d[i+u|0]|0,n)|0)|0)>>>6;f=f+1|0;}while((f|0)<(j|0))}f=b+1|0;if((f|0)<(k|0)){m=i;i=i+g|0;l=l+e|0;c=c+e|0;b=f}else{break}}return}function sPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){n=0;do{a[l+n|0]=((d[k+n|0]|0)+1+(d[j+n|0]|0)|0)>>>1;n=n+1|0;}while((n|0)<16);n=m+1|0;if((n|0)<16){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=g;g=e;e=b;b=0;while(1){k=0;do{j=ca(d[g+k|0]|0,i)|0;n=j+32+(ca(d[l+k|0]|0,m)|0)>>6;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[e+k|0]=o;k=k+1|0;}while((k|0)<16);k=b+1|0;if((k|0)<16){l=l+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function tPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){n=0;do{a[l+n|0]=((d[k+n|0]|0)+1+(d[j+n|0]|0)|0)>>>1;n=n+1|0;}while((n|0)<16);n=m+1|0;if((n|0)<8){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=g;g=e;e=b;b=0;while(1){k=0;do{j=ca(d[g+k|0]|0,i)|0;n=j+32+(ca(d[l+k|0]|0,m)|0)>>6;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[e+k|0]=o;k=k+1|0;}while((k|0)<16);k=b+1|0;if((k|0)<8){l=l+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function uPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){a[l]=((d[k]|0)+1+(d[j]|0)|0)>>>1;a[l+1|0]=((d[k+1|0]|0)+1+(d[j+1|0]|0)|0)>>>1;a[l+2|0]=((d[k+2|0]|0)+1+(d[j+2|0]|0)|0)>>>1;a[l+3|0]=((d[k+3|0]|0)+1+(d[j+3|0]|0)|0)>>>1;a[l+4|0]=((d[k+4|0]|0)+1+(d[j+4|0]|0)|0)>>>1;a[l+5|0]=((d[k+5|0]|0)+1+(d[j+5|0]|0)|0)>>>1;a[l+6|0]=((d[k+6|0]|0)+1+(d[j+6|0]|0)|0)>>>1;a[l+7|0]=((d[k+7|0]|0)+1+(d[j+7|0]|0)|0)>>>1;n=m+1|0;if((n|0)<16){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=g;g=e;e=b;b=0;while(1){k=0;do{j=ca(d[g+k|0]|0,i)|0;n=j+32+(ca(d[l+k|0]|0,m)|0)>>6;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[e+k|0]=o;k=k+1|0;}while((k|0)<8);k=b+1|0;if((k|0)<16){l=l+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function vPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){a[l]=((d[k]|0)+1+(d[j]|0)|0)>>>1;a[l+1|0]=((d[k+1|0]|0)+1+(d[j+1|0]|0)|0)>>>1;a[l+2|0]=((d[k+2|0]|0)+1+(d[j+2|0]|0)|0)>>>1;a[l+3|0]=((d[k+3|0]|0)+1+(d[j+3|0]|0)|0)>>>1;a[l+4|0]=((d[k+4|0]|0)+1+(d[j+4|0]|0)|0)>>>1;a[l+5|0]=((d[k+5|0]|0)+1+(d[j+5|0]|0)|0)>>>1;a[l+6|0]=((d[k+6|0]|0)+1+(d[j+6|0]|0)|0)>>>1;a[l+7|0]=((d[k+7|0]|0)+1+(d[j+7|0]|0)|0)>>>1;n=m+1|0;if((n|0)<8){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=g;g=e;e=b;b=0;while(1){k=0;do{j=ca(d[g+k|0]|0,i)|0;n=j+32+(ca(d[l+k|0]|0,m)|0)>>6;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[e+k|0]=o;k=k+1|0;}while((k|0)<8);k=b+1|0;if((k|0)<8){l=l+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function wPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){a[l]=((d[k]|0)+1+(d[j]|0)|0)>>>1;a[l+1|0]=((d[k+1|0]|0)+1+(d[j+1|0]|0)|0)>>>1;a[l+2|0]=((d[k+2|0]|0)+1+(d[j+2|0]|0)|0)>>>1;a[l+3|0]=((d[k+3|0]|0)+1+(d[j+3|0]|0)|0)>>>1;a[l+4|0]=((d[k+4|0]|0)+1+(d[j+4|0]|0)|0)>>>1;a[l+5|0]=((d[k+5|0]|0)+1+(d[j+5|0]|0)|0)>>>1;a[l+6|0]=((d[k+6|0]|0)+1+(d[j+6|0]|0)|0)>>>1;a[l+7|0]=((d[k+7|0]|0)+1+(d[j+7|0]|0)|0)>>>1;n=m+1|0;if((n|0)<4){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=0;while(1){k=ca(d[e+l|0]|0,i)|0;j=k+32+(ca(d[g+l|0]|0,m)|0)>>6;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[b+l|0]=o;j=l+1|0;if((j|0)<8){l=j}else{p=0;break}}do{l=ca(d[e+(p+f)|0]|0,i)|0;o=l+32+(ca(d[g+(p+h)|0]|0,m)|0)>>6;if(o>>>0>255>>>0){q=-o>>31&255}else{q=o&255}a[b+(p+c)|0]=q;p=p+1|0;}while((p|0)<8);p=c<<1;q=f<<1;o=h<<1;l=0;do{j=ca(d[e+(q+l)|0]|0,i)|0;k=j+32+(ca(d[g+(o+l)|0]|0,m)|0)>>6;if(k>>>0>255>>>0){r=-k>>31&255}else{r=k&255}a[b+(p+l)|0]=r;l=l+1|0;}while((l|0)<8);l=p+c|0;c=q+f|0;f=o+h|0;h=0;do{o=ca(d[e+(c+h)|0]|0,i)|0;q=o+32+(ca(d[g+(f+h)|0]|0,m)|0)>>6;if(q>>>0>255>>>0){s=-q>>31&255}else{s=q&255}a[b+(l+h)|0]=s;h=h+1|0;}while((h|0)<8);return}function xPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){a[l]=((d[k]|0)+1+(d[j]|0)|0)>>>1;a[l+1|0]=((d[k+1|0]|0)+1+(d[j+1|0]|0)|0)>>>1;a[l+2|0]=((d[k+2|0]|0)+1+(d[j+2|0]|0)|0)>>>1;a[l+3|0]=((d[k+3|0]|0)+1+(d[j+3|0]|0)|0)>>>1;n=m+1|0;if((n|0)<16){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=g;g=e;e=b;b=0;while(1){k=ca(d[g]|0,i)|0;j=k+32+(ca(d[l]|0,m)|0)>>6;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[e]=o;j=ca(d[g+1|0]|0,i)|0;k=j+32+(ca(d[l+1|0]|0,m)|0)>>6;if(k>>>0>255>>>0){p=-k>>31&255}else{p=k&255}a[e+1|0]=p;k=ca(d[g+2|0]|0,i)|0;j=k+32+(ca(d[l+2|0]|0,m)|0)>>6;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[e+2|0]=q;j=ca(d[g+3|0]|0,i)|0;k=j+32+(ca(d[l+3|0]|0,m)|0)>>6;if(k>>>0>255>>>0){r=-k>>31&255}else{r=k&255}a[e+3|0]=r;k=b+1|0;if((k|0)<16){l=l+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function yPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){a[l]=((d[k]|0)+1+(d[j]|0)|0)>>>1;a[l+1|0]=((d[k+1|0]|0)+1+(d[j+1|0]|0)|0)>>>1;a[l+2|0]=((d[k+2|0]|0)+1+(d[j+2|0]|0)|0)>>>1;a[l+3|0]=((d[k+3|0]|0)+1+(d[j+3|0]|0)|0)>>>1;n=m+1|0;if((n|0)<8){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=g;g=e;e=b;b=0;while(1){k=ca(d[g]|0,i)|0;j=k+32+(ca(d[l]|0,m)|0)>>6;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[e]=o;j=ca(d[g+1|0]|0,i)|0;k=j+32+(ca(d[l+1|0]|0,m)|0)>>6;if(k>>>0>255>>>0){p=-k>>31&255}else{p=k&255}a[e+1|0]=p;k=ca(d[g+2|0]|0,i)|0;j=k+32+(ca(d[l+2|0]|0,m)|0)>>6;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[e+2|0]=q;j=ca(d[g+3|0]|0,i)|0;k=j+32+(ca(d[l+3|0]|0,m)|0)>>6;if(k>>>0>255>>>0){r=-k>>31&255}else{r=k&255}a[e+3|0]=r;k=b+1|0;if((k|0)<8){l=l+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function zPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){a[l]=((d[k]|0)+1+(d[j]|0)|0)>>>1;a[l+1|0]=((d[k+1|0]|0)+1+(d[j+1|0]|0)|0)>>>1;a[l+2|0]=((d[k+2|0]|0)+1+(d[j+2|0]|0)|0)>>>1;a[l+3|0]=((d[k+3|0]|0)+1+(d[j+3|0]|0)|0)>>>1;n=m+1|0;if((n|0)<4){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=g;g=e;e=b;b=0;while(1){k=ca(d[g]|0,i)|0;j=k+32+(ca(d[l]|0,m)|0)>>6;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[e]=o;j=ca(d[g+1|0]|0,i)|0;k=j+32+(ca(d[l+1|0]|0,m)|0)>>6;if(k>>>0>255>>>0){p=-k>>31&255}else{p=k&255}a[e+1|0]=p;k=ca(d[g+2|0]|0,i)|0;j=k+32+(ca(d[l+2|0]|0,m)|0)>>6;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[e+2|0]=q;j=ca(d[g+3|0]|0,i)|0;k=j+32+(ca(d[l+3|0]|0,m)|0)>>6;if(k>>>0>255>>>0){r=-k>>31&255}else{r=k&255}a[e+3|0]=r;k=b+1|0;if((k|0)<4){l=l+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function APb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((i|0)==32){a[b]=((d[e]|0)+1+(d[g]|0)|0)>>>1;a[b+1|0]=((d[e+1|0]|0)+1+(d[g+1|0]|0)|0)>>>1;a[b+2|0]=((d[e+2|0]|0)+1+(d[g+2|0]|0)|0)>>>1;a[b+3|0]=((d[e+3|0]|0)+1+(d[g+3|0]|0)|0)>>>1;a[b+c|0]=((d[e+f|0]|0)+1+(d[g+h|0]|0)|0)>>>1;a[b+(c+1)|0]=((d[e+(f+1)|0]|0)+1+(d[g+(h+1)|0]|0)|0)>>>1;a[b+(c+2)|0]=((d[e+(f+2)|0]|0)+1+(d[g+(h+2)|0]|0)|0)>>>1;a[b+(c+3)|0]=((d[e+(f+3)|0]|0)+1+(d[g+(h+3)|0]|0)|0)>>>1;return}j=64-i|0;k=ca(d[e]|0,i)|0;l=k+32+(ca(d[g]|0,j)|0)>>6;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[b]=m;m=ca(d[e+1|0]|0,i)|0;l=m+32+(ca(d[g+1|0]|0,j)|0)>>6;if(l>>>0>255>>>0){n=-l>>31&255}else{n=l&255}a[b+1|0]=n;n=ca(d[e+2|0]|0,i)|0;l=n+32+(ca(d[g+2|0]|0,j)|0)>>6;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[b+2|0]=o;o=ca(d[e+3|0]|0,i)|0;l=o+32+(ca(d[g+3|0]|0,j)|0)>>6;if(l>>>0>255>>>0){p=-l>>31&255}else{p=l&255}a[b+3|0]=p;p=ca(d[e+f|0]|0,i)|0;l=p+32+(ca(d[g+h|0]|0,j)|0)>>6;if(l>>>0>255>>>0){q=-l>>31&255}else{q=l&255}a[b+c|0]=q;q=ca(d[e+(f+1)|0]|0,i)|0;l=q+32+(ca(d[g+(h+1)|0]|0,j)|0)>>6;if(l>>>0>255>>>0){r=-l>>31&255}else{r=l&255}a[b+(c+1)|0]=r;r=ca(d[e+(f+2)|0]|0,i)|0;l=r+32+(ca(d[g+(h+2)|0]|0,j)|0)>>6;if(l>>>0>255>>>0){s=-l>>31&255}else{s=l&255}a[b+(c+2)|0]=s;s=ca(d[e+(f+3)|0]|0,i)|0;i=s+32+(ca(d[g+(h+3)|0]|0,j)|0)>>6;if(i>>>0>255>>>0){t=-i>>31&255}else{t=i&255}a[b+(c+3)|0]=t;return}function BPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((i|0)==32){j=g;k=e;l=b;m=0;while(1){a[l]=((d[k]|0)+1+(d[j]|0)|0)>>>1;a[l+1|0]=((d[k+1|0]|0)+1+(d[j+1|0]|0)|0)>>>1;n=m+1|0;if((n|0)<8){j=j+h|0;k=k+f|0;l=l+c|0;m=n}else{break}}return}m=64-i|0;l=g;g=e;e=b;b=0;while(1){k=ca(d[g]|0,i)|0;j=k+32+(ca(d[l]|0,m)|0)>>6;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[e]=o;j=ca(d[g+1|0]|0,i)|0;k=j+32+(ca(d[l+1|0]|0,m)|0)>>6;if(k>>>0>255>>>0){p=-k>>31&255}else{p=k&255}a[e+1|0]=p;k=b+1|0;if((k|0)<8){l=l+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function CPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((i|0)==32){a[b]=((d[e]|0)+1+(d[g]|0)|0)>>>1;a[b+1|0]=((d[e+1|0]|0)+1+(d[g+1|0]|0)|0)>>>1;a[b+c|0]=((d[e+f|0]|0)+1+(d[g+h|0]|0)|0)>>>1;a[b+(c+1)|0]=((d[e+(f+1)|0]|0)+1+(d[g+(h+1)|0]|0)|0)>>>1;j=f<<1;k=h<<1;l=c<<1;a[b+l|0]=((d[e+j|0]|0)+1+(d[g+k|0]|0)|0)>>>1;a[b+(l|1)|0]=((d[e+(j|1)|0]|0)+1+(d[g+(k|1)|0]|0)|0)>>>1;m=j+f|0;j=k+h|0;k=l+c|0;a[b+k|0]=((d[e+m|0]|0)+1+(d[g+j|0]|0)|0)>>>1;a[b+(k+1)|0]=((d[e+(m+1)|0]|0)+1+(d[g+(j+1)|0]|0)|0)>>>1;return}j=64-i|0;m=g;g=e;e=b;b=0;while(1){k=ca(d[g]|0,i)|0;l=k+32+(ca(d[m]|0,j)|0)>>6;if(l>>>0>255>>>0){n=-l>>31&255}else{n=l&255}a[e]=n;l=ca(d[g+1|0]|0,i)|0;k=l+32+(ca(d[m+1|0]|0,j)|0)>>6;if(k>>>0>255>>>0){o=-k>>31&255}else{o=k&255}a[e+1|0]=o;k=b+1|0;if((k|0)<4){m=m+h|0;g=g+f|0;e=e+c|0;b=k}else{break}}return}function DPb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((i|0)==32){a[b]=((d[e]|0)+1+(d[g]|0)|0)>>>1;a[b+1|0]=((d[e+1|0]|0)+1+(d[g+1|0]|0)|0)>>>1;a[b+c|0]=((d[e+f|0]|0)+1+(d[g+h|0]|0)|0)>>>1;a[b+(c+1)|0]=((d[e+(f+1)|0]|0)+1+(d[g+(h+1)|0]|0)|0)>>>1;return}j=64-i|0;k=ca(d[e]|0,i)|0;l=k+32+(ca(d[g]|0,j)|0)>>6;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[b]=m;m=ca(d[e+1|0]|0,i)|0;l=m+32+(ca(d[g+1|0]|0,j)|0)>>6;if(l>>>0>255>>>0){n=-l>>31&255}else{n=l&255}a[b+1|0]=n;n=ca(d[e+f|0]|0,i)|0;l=n+32+(ca(d[g+h|0]|0,j)|0)>>6;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[b+c|0]=o;o=ca(d[e+(f+1)|0]|0,i)|0;i=o+32+(ca(d[g+(h+1)|0]|0,j)|0)>>6;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[b+(c+1)|0]=p;return}function EPb(a,b){a=a|0;b=b|0;c[b+44>>2]=c[a+37548>>2];return}function FPb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((e|0)>0){f=a;g=c;h=0}else{return}while(1){nrc(f|0,g|0,16)|0;c=h+1|0;if((c|0)<(e|0)){f=f+b|0;g=g+d|0;h=c}else{break}}return}function GPb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=b;i=e;j=0}else{return}while(1){e=i;b=h;k=e|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=b+4|0;y=e;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=j+1|0;if((l|0)<(g|0)){h=h+c|0;i=i+f|0;j=l}else{break}}return}function HPb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)>0){h=b;i=e;j=0}else{return}while(1){e=i;b=h;y=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=j+1|0;if((b|0)<(g|0)){h=h+c|0;i=i+f|0;j=b}else{break}}return}function IPb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((f|0)>0){g=d;h=e;i=b;j=0}else{return}while(1){a[i]=a[g]|0;a[i+1|0]=a[h]|0;a[i+2|0]=a[g+1|0]|0;a[i+3|0]=a[h+1|0]|0;a[i+4|0]=a[g+2|0]|0;a[i+5|0]=a[h+2|0]|0;a[i+6|0]=a[g+3|0]|0;a[i+7|0]=a[h+3|0]|0;a[i+8|0]=a[g+4|0]|0;a[i+9|0]=a[h+4|0]|0;a[i+10|0]=a[g+5|0]|0;a[i+11|0]=a[h+5|0]|0;a[i+12|0]=a[g+6|0]|0;a[i+13|0]=a[h+6|0]|0;a[i+14|0]=a[g+7|0]|0;a[i+15|0]=a[h+7|0]|0;b=j+1|0;if((b|0)<(f|0)){g=g+32|0;h=h+32|0;i=i+c|0;j=b}else{break}}return}function JPb(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((e|0)<=0){return}f=c;c=b+8|0;g=b;b=0;while(1){a[g]=a[f]|0;a[c]=a[f+1|0]|0;a[g+1|0]=a[f+2|0]|0;a[c+1|0]=a[f+3|0]|0;a[g+2|0]=a[f+4|0]|0;a[c+2|0]=a[f+5|0]|0;a[g+3|0]=a[f+6|0]|0;a[c+3|0]=a[f+7|0]|0;a[g+4|0]=a[f+8|0]|0;a[c+4|0]=a[f+9|0]|0;a[g+5|0]=a[f+10|0]|0;a[c+5|0]=a[f+11|0]|0;a[g+6|0]=a[f+12|0]|0;a[c+6|0]=a[f+13|0]|0;a[g+7|0]=a[f+14|0]|0;a[c+7|0]=a[f+15|0]|0;h=b+1|0;if((h|0)<(e|0)){f=f+d|0;c=c+16|0;g=g+16|0;b=h}else{break}}return}function KPb(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((e|0)<=0){return}f=c;c=b+16|0;g=b;b=0;while(1){a[g]=a[f]|0;a[c]=a[f+1|0]|0;a[g+1|0]=a[f+2|0]|0;a[c+1|0]=a[f+3|0]|0;a[g+2|0]=a[f+4|0]|0;a[c+2|0]=a[f+5|0]|0;a[g+3|0]=a[f+6|0]|0;a[c+3|0]=a[f+7|0]|0;a[g+4|0]=a[f+8|0]|0;a[c+4|0]=a[f+9|0]|0;a[g+5|0]=a[f+10|0]|0;a[c+5|0]=a[f+11|0]|0;a[g+6|0]=a[f+12|0]|0;a[c+6|0]=a[f+13|0]|0;a[g+7|0]=a[f+14|0]|0;a[c+7|0]=a[f+15|0]|0;h=b+1|0;if((h|0)<(e|0)){f=f+d|0;c=c+32|0;g=g+32|0;b=h}else{break}}return}function LPb(b,c,d,e,f,g,h,i){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((i|0)<=0){return}j=(h|0)>0;k=f;f=d;d=b;b=0;while(1){if(j){l=0;do{m=l<<1;a[d+l|0]=a[k+m|0]|0;a[f+l|0]=a[k+(m|1)|0]|0;l=l+1|0;}while((l|0)<(h|0))}l=b+1|0;if((l|0)<(i|0)){k=k+g|0;f=f+e|0;d=d+c|0;b=l}else{break}}return}function MPb(b,c,d,e,f,g,h,i,j,k,l){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0;if((l|0)<=0){return}m=(k|0)>0;n=h;h=f;f=d;d=b;b=0;while(1){if(m){o=0;do{p=ca(o,j)|0;a[d+o|0]=a[n+p|0]|0;a[f+o|0]=a[n+(p+1)|0]|0;a[h+o|0]=a[n+(p+2)|0]|0;o=o+1|0;}while((o|0)<(k|0))}o=b+1|0;if((o|0)<(l|0)){n=n+i|0;h=h+g|0;f=f+e|0;d=d+c|0;b=o}else{break}}return}function NPb(c,e,f,g,h,i,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((j|0)<=0){return}l=i+3|0;m=(l|0)>-2;n=(i|0)>0;o=h<<1;p=h*3|0;q=g;g=f;f=e;e=0;r=c;while(1){if(m){c=-2;do{s=(d[q+(c+p)|0]|0)+(d[q+(c-o)|0]|0)+(((d[q+(c+o)|0]|0)+(d[q+(c-h)|0]|0)|0)*-5|0)+(((d[q+(c+h)|0]|0)+(d[q+c|0]|0)|0)*20|0)|0;t=s+16>>5;if(t>>>0>255>>>0){u=-t>>31&255}else{u=t&255}a[f+c|0]=u;b[k+(c+2<<1)>>1]=s;c=c+1|0;}while((c|0)<(l|0))}do{if(n){c=0;while(1){s=c+1|0;t=(b[k+(c<<1)>>1]|0)+512+(b[k+(c+5<<1)>>1]|0)+(((b[k+(c+4<<1)>>1]|0)+(b[k+(s<<1)>>1]|0)|0)*-5|0)+(((b[k+(c+3<<1)>>1]|0)+(b[k+(c+2<<1)>>1]|0)|0)*20|0)>>10;if(t>>>0>255>>>0){v=-t>>31&255}else{v=t&255}a[g+c|0]=v;if((s|0)<(i|0)){c=s}else{break}}if(n){w=0}else{break}while(1){c=w+1|0;s=(d[q+(w-2)|0]|0)+16+(d[q+(w+3)|0]|0)+(((d[q+(w+2)|0]|0)+(d[q+(w-1)|0]|0)|0)*-5|0)+(((d[q+c|0]|0)+(d[q+w|0]|0)|0)*20|0)>>5;if(s>>>0>255>>>0){x=-s>>31&255}else{x=s&255}a[r+w|0]=x;if((c|0)<(i|0)){w=c}else{break}}}}while(0);c=e+1|0;if((c|0)<(j|0)){q=q+h|0;g=g+h|0;f=f+h|0;e=c;r=r+h|0}else{break}}return}function OPb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return}function PPb(a,b,c){a=a|0;b=b|0;c=c|0;return}function QPb(a,b){a=a|0;b=b|0;mrc(a|0,0,b|0)|0;return}function RPb(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((k|0)<=0){return}l=h<<1;m=(j|0)>0;n=g;g=f;f=e;e=0;o=c;c=b;while(1){if(m){b=0;do{p=b<<1;q=c+(p+h)|0;r=p|1;s=c+r|0;t=c+(r+h)|0;a[o+b|0]=((((d[c+p|0]|0)+1+(d[q]|0)|0)>>>1)+1+(((d[s]|0)+1+(d[t]|0)|0)>>>1)|0)>>>1;u=p+2|0;v=c+(u+h)|0;a[f+b|0]=((((d[s]|0)+1+(d[t]|0)|0)>>>1)+1+(((d[c+u|0]|0)+1+(d[v]|0)|0)>>>1)|0)>>>1;s=c+(r+l)|0;a[g+b|0]=((((d[q]|0)+1+(d[c+(p+l)|0]|0)|0)>>>1)+1+(((d[t]|0)+1+(d[s]|0)|0)>>>1)|0)>>>1;a[n+b|0]=((((d[t]|0)+1+(d[s]|0)|0)>>>1)+1+(((d[v]|0)+1+(d[c+(u+l)|0]|0)|0)>>>1)|0)>>>1;b=b+1|0;}while((b|0)<(j|0))}b=e+1|0;if((b|0)<(k|0)){n=n+i|0;g=g+i|0;f=f+i|0;e=b;o=o+i|0;c=c+l|0}else{break}}return}function SPb(a,c,f){a=a|0;c=c|0;f=f|0;var g=0,h=0,i=0,j=0;g=f-4|0;if((g|0)<=0){return}h=(d[c+1|0]|0)+(d[c]|0)+(d[c+2|0]|0)+(d[c+3|0]|0)|0;i=0;while(1){b[a+(i<<1)>>1]=(e[a+(i-f<<1)>>1]|0)+h;j=i+1|0;if((j|0)<(g|0)){h=(d[c+(i+4)|0]|0)+h-(d[c+i|0]|0)|0;i=j}else{break}}return}function TPb(a,c,f){a=a|0;c=c|0;f=f|0;var g=0,h=0,i=0,j=0;g=f-8|0;if((g|0)<=0){return}h=(d[c+1|0]|0)+(d[c]|0)+(d[c+2|0]|0)+(d[c+3|0]|0)+(d[c+4|0]|0)+(d[c+5|0]|0)+(d[c+6|0]|0)+(d[c+7|0]|0)|0;i=0;while(1){b[a+(i<<1)>>1]=(e[a+(i-f<<1)>>1]|0)+h;j=i+1|0;if((j|0)<(g|0)){h=(d[c+(i+8)|0]|0)+h-(d[c+i|0]|0)|0;i=j}else{break}}return}function UPb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=d-8|0;f=(e|0)>0;if(!f){return}g=d<<2;h=0;do{b[c+(h<<1)>>1]=(b[a+(h+g<<1)>>1]|0)-(b[a+(h<<1)>>1]|0);h=h+1|0;}while((h|0)<(e|0));if(!f){return}f=d<<3;d=0;do{h=d+f|0;g=a+(d<<1)|0;b[g>>1]=(((b[a+(h+4<<1)>>1]|0)+(b[a+(h<<1)>>1]|0)&65535)-(b[g>>1]|0)&65535)-(b[a+(d+4<<1)>>1]|0);d=d+1|0;}while((d|0)<(e|0));return}function VPb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0;d=c-8|0;if((d|0)<=0){return}e=c<<3;c=0;do{f=a+(c<<1)|0;b[f>>1]=(b[a+(c+e<<1)>>1]|0)-(b[f>>1]|0);c=c+1|0;}while((c|0)<(d|0));return}function WPb(a,c,d,f,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0.0,l=0,m=0,n=0.0,o=0;k=+g[i>>2];if((j|0)>0){l=0}else{return}do{i=e[d+(l<<1)>>1]|0;m=b[f+(l<<1)>>1]&16383;n=+(ca(e[h+(l<<1)>>1]|0,i)|0);o=~~((+(e[c+(l<<1)>>1]|0|0)+k*n)*+(i-(i>>>0<m>>>0?i:m)|0)/+(i|0)+.5);b[a+(l<<1)>>1]=(o|0)<32767?o&65535:32767;l=l+1|0;}while((l|0)<(j|0));return}function XPb(a,d,f,g,h,i,j,k,l){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=c[a+18580>>2]|0;n=c[a+18560>>2]|0;o=c[a+18564>>2]|0;if((k|0)==0){return}a=1<<l;l=ca(m,j)|0;p=n-1|0;q=o-1|0;r=0;do{s=(e[h+(r<<1)>>1]|0)>>>14;do{if((s&a|0)!=0){t=b[g+(r<<1)>>1]|0;if((s|0)==3){u=(ca(t,i)|0)+32>>6}else{u=t}t=c[f+(r<<2)>>2]|0;if((t|0)==0){v=d+(r+l<<1)|0;w=(e[v>>1]|0)+u|0;b[v>>1]=(w|0)<32767?w&65535:32767;break}w=b[f+(r<<2)+2>>1]|0;v=(t<<16>>21)+r|0;x=(w>>5)+j|0;y=(ca(x,m)|0)+v|0;z=y+m|0;A=t&31;t=w&31;w=32-t|0;B=ca(32-A|0,u)|0;C=(ca(B,w)|0)+512>>10;D=ca(A,u)|0;A=(ca(D,w)|0)+512>>10;w=(ca(B,t)|0)+512>>10;B=(ca(D,t)|0)+512>>10;if(v>>>0<p>>>0&x>>>0<q>>>0){t=d+(y<<1)|0;D=(e[t>>1]|0)+C|0;b[t>>1]=(D|0)<32767?D&65535:32767;D=d+(y+1<<1)|0;t=(e[D>>1]|0)+A|0;b[D>>1]=(t|0)<32767?t&65535:32767;t=d+(z<<1)|0;D=(e[t>>1]|0)+w|0;b[t>>1]=(D|0)<32767?D&65535:32767;D=d+(z+1<<1)|0;t=(e[D>>1]|0)+B|0;b[D>>1]=(t|0)<32767?t&65535:32767;break}do{if(x>>>0<o>>>0){if(v>>>0<n>>>0){t=d+(y<<1)|0;D=(e[t>>1]|0)+C|0;b[t>>1]=(D|0)<32767?D&65535:32767}if(!((v+1|0)>>>0<n>>>0)){break}D=d+(y+1<<1)|0;t=(e[D>>1]|0)+A|0;b[D>>1]=(t|0)<32767?t&65535:32767}}while(0);if(!((x+1|0)>>>0<o>>>0)){break}if(v>>>0<n>>>0){A=d+(z<<1)|0;y=(e[A>>1]|0)+w|0;b[A>>1]=(y|0)<32767?y&65535:32767}if(!((v+1|0)>>>0<n>>>0)){break}y=d+(z+1<<1)|0;A=(e[y>>1]|0)+B|0;b[y>>1]=(A|0)<32767?A&65535:32767}}while(0);r=r+1|0;}while(r>>>0<k>>>0);return}function YPb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=c[a+160>>2]|0;g=d<<4;h=(e|0)!=0;if(h){i=(c[b+180>>2]|0)+(f<<4)|0}else{i=f+d<<4}e=i+8|0;if((f&d|0)!=0){return}j=a+8632|0;k=(f|0)!=0;f=a+18664|0;l=d<<3;d=l-8|0;m=a+37500|0;n=8-l+8|0;l=a+36456|0;o=0;p=g-8|0;while(1){q=b+156+(o<<2)|0;r=c[q>>2]|0;s=c[b+168+(o<<2)>>2]|0;t=(ca(r,p)|0)-8|0;if(k){if((c[f>>2]|0)==0){u=r;v=10}else{v=8}}else{v=8}do{if((v|0)==8){v=0;Ge[c[m>>2]&255]((c[b+228+(o<<4)+4>>2]|0)+t|0,(c[b+228+(o<<4)+8>>2]|0)+t|0,(c[b+228+(o<<4)+12>>2]|0)+t|0,(c[b+204+(o<<2)>>2]|0)+t|0,r,s+16|0,e-p|0,c[l>>2]|0);if(!k){w=p;break}u=c[q>>2]|0;v=10}}while(0);if((v|0)==10){v=0;r=u<<1;if(h){x=c[b+180+(o<<2)>>2]|0}else{x=g}t=(ca(r,d)|0)-8|0;y=b+276+(o<<4)+4|0;z=b+276+(o<<4)+8|0;A=b+276+(o<<4)+12|0;B=b+216+(o<<2)|0;C=s+16|0;D=n+(x>>1)|0;Ge[c[m>>2]&255]((c[y>>2]|0)+t|0,(c[z>>2]|0)+t|0,(c[A>>2]|0)+t|0,(c[B>>2]|0)+t|0,r,C,D,c[l>>2]|0);E=(c[q>>2]|0)+t|0;Ge[c[m>>2]&255]((c[y>>2]|0)+E|0,(c[z>>2]|0)+E|0,(c[A>>2]|0)+E|0,(c[B>>2]|0)+E|0,r,C,D,c[l>>2]|0);w=d}D=o+1|0;if((D|0)<(((c[j>>2]|0)==3?3:1)|0)){o=D;p=w}else{break}}p=b+340|0;o=c[p>>2]|0;if((o|0)==0){return}j=c[b+156>>2]|0;if((w|0)<0){mrc(o+(-32-(j<<5)<<1)|0,0,j<<1|0)|0;F=-32}else{F=w}w=h?i+31|0:e;if((F|0)>=(w|0)){return}e=b+204|0;i=a+15140|0;h=a+37532|0;o=a+37540|0;d=j<<3;l=a+37528|0;m=b+180|0;b=a+37536|0;a=F;while(1){F=(c[e>>2]|0)+((ca(a,j)|0)-32)|0;x=c[p>>2]|0;n=a+1|0;g=(ca(n,j)|0)-32|0;u=x+(g<<1)|0;do{if((c[i>>2]|0)==0){ef[c[h>>2]&4095](u,F,j);if(!((a|0)>-25)){break}re[c[o>>2]&1023](x+(g-d<<1)|0,j)}else{ef[c[l>>2]&4095](u,F,j);v=g-d|0;if(!((a|0)>-25)){break}k=x+((ca((c[m>>2]|0)+64|0,j)|0)+v<<1)|0;ef[c[b>>2]&4095](x+(v<<1)|0,k,j)}}while(0);if((n|0)<(w|0)){a=n}else{break}}return}function ZPb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=c[h+32>>2]|0;k=c[h+36>>2]|0;l=c[h+40>>2]|0;h=(i|0)>0;if((j|0)<=0){if(h){m=f;n=b;o=0}else{return}while(1){p=(ca(d[m]|0,k)|0)+l|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[n]=q;p=(ca(d[m+1|0]|0,k)|0)+l|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[n+1|0]=r;p=o+1|0;if((p|0)<(i|0)){m=m+g|0;n=n+e|0;o=p}else{break}}return}if(!h){return}h=1<<j-1;o=f;f=b;b=0;while(1){n=((ca(d[o]|0,k)|0)+h>>j)+l|0;if(n>>>0>255>>>0){s=-n>>31&255}else{s=n&255}a[f]=s;n=((ca(d[o+1|0]|0,k)|0)+h>>j)+l|0;if(n>>>0>255>>>0){t=-n>>31&255}else{t=n&255}a[f+1|0]=t;n=b+1|0;if((n|0)<(i|0)){o=o+g|0;f=f+e|0;b=n}else{break}}return}function _Pb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=c[h+32>>2]|0;k=c[h+36>>2]|0;l=c[h+40>>2]|0;h=(i|0)>0;if((j|0)<=0){if(h){m=f;n=b;o=0}else{return}while(1){p=(ca(d[m]|0,k)|0)+l|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[n]=q;p=(ca(d[m+1|0]|0,k)|0)+l|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[n+1|0]=r;p=(ca(d[m+2|0]|0,k)|0)+l|0;if(p>>>0>255>>>0){s=-p>>31&255}else{s=p&255}a[n+2|0]=s;p=(ca(d[m+3|0]|0,k)|0)+l|0;if(p>>>0>255>>>0){t=-p>>31&255}else{t=p&255}a[n+3|0]=t;p=o+1|0;if((p|0)<(i|0)){m=m+g|0;n=n+e|0;o=p}else{break}}return}if(!h){return}h=1<<j-1;o=f;f=b;b=0;while(1){n=((ca(d[o]|0,k)|0)+h>>j)+l|0;if(n>>>0>255>>>0){u=-n>>31&255}else{u=n&255}a[f]=u;n=((ca(d[o+1|0]|0,k)|0)+h>>j)+l|0;if(n>>>0>255>>>0){v=-n>>31&255}else{v=n&255}a[f+1|0]=v;n=((ca(d[o+2|0]|0,k)|0)+h>>j)+l|0;if(n>>>0>255>>>0){w=-n>>31&255}else{w=n&255}a[f+2|0]=w;n=((ca(d[o+3|0]|0,k)|0)+h>>j)+l|0;if(n>>>0>255>>>0){x=-n>>31&255}else{x=n&255}a[f+3|0]=x;n=b+1|0;if((n|0)<(i|0)){o=o+g|0;f=f+e|0;b=n}else{break}}return}function $Pb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;j=c[h+32>>2]|0;k=c[h+36>>2]|0;l=c[h+40>>2]|0;h=(i|0)>0;if((j|0)>0){if(!h){return}m=1<<j-1;n=f;o=b;p=0;while(1){q=0;do{r=((ca(d[n+q|0]|0,k)|0)+m>>j)+l|0;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[o+q|0]=s;q=q+1|0;}while((q|0)<8);q=p+1|0;if((q|0)<(i|0)){n=n+g|0;o=o+e|0;p=q}else{break}}return}if(h){t=f;u=b;v=0}else{return}while(1){b=(ca(d[t]|0,k)|0)+l|0;if(b>>>0>255>>>0){w=-b>>31&255}else{w=b&255}a[u]=w;b=(ca(d[t+1|0]|0,k)|0)+l|0;if(b>>>0>255>>>0){x=-b>>31&255}else{x=b&255}a[u+1|0]=x;b=(ca(d[t+2|0]|0,k)|0)+l|0;if(b>>>0>255>>>0){y=-b>>31&255}else{y=b&255}a[u+2|0]=y;b=(ca(d[t+3|0]|0,k)|0)+l|0;if(b>>>0>255>>>0){z=-b>>31&255}else{z=b&255}a[u+3|0]=z;b=(ca(d[t+4|0]|0,k)|0)+l|0;if(b>>>0>255>>>0){A=-b>>31&255}else{A=b&255}a[u+4|0]=A;b=(ca(d[t+5|0]|0,k)|0)+l|0;if(b>>>0>255>>>0){B=-b>>31&255}else{B=b&255}a[u+5|0]=B;b=(ca(d[t+6|0]|0,k)|0)+l|0;if(b>>>0>255>>>0){C=-b>>31&255}else{C=b&255}a[u+6|0]=C;b=(ca(d[t+7|0]|0,k)|0)+l|0;if(b>>>0>255>>>0){D=-b>>31&255}else{D=b&255}a[u+7|0]=D;b=v+1|0;if((b|0)<(i|0)){t=t+g|0;u=u+e|0;v=b}else{break}}return}function aQb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=c[h+32>>2]|0;k=c[h+36>>2]|0;l=c[h+40>>2]|0;h=(i|0)>0;if((j|0)<=0){if(h){m=f;n=b;o=0}else{return}while(1){p=0;do{q=(ca(d[m+p|0]|0,k)|0)+l|0;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[n+p|0]=r;p=p+1|0;}while((p|0)<12);p=o+1|0;if((p|0)<(i|0)){m=m+g|0;n=n+e|0;o=p}else{break}}return}if(!h){return}h=1<<j-1;o=f;f=b;b=0;while(1){n=0;do{m=((ca(d[o+n|0]|0,k)|0)+h>>j)+l|0;if(m>>>0>255>>>0){s=-m>>31&255}else{s=m&255}a[f+n|0]=s;n=n+1|0;}while((n|0)<12);n=b+1|0;if((n|0)<(i|0)){o=o+g|0;f=f+e|0;b=n}else{break}}return}function bQb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=c[h+32>>2]|0;k=c[h+36>>2]|0;l=c[h+40>>2]|0;h=(i|0)>0;if((j|0)<=0){if(h){m=f;n=b;o=0}else{return}while(1){p=0;do{q=(ca(d[m+p|0]|0,k)|0)+l|0;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[n+p|0]=r;p=p+1|0;}while((p|0)<16);p=o+1|0;if((p|0)<(i|0)){m=m+g|0;n=n+e|0;o=p}else{break}}return}if(!h){return}h=1<<j-1;o=f;f=b;b=0;while(1){n=0;do{m=((ca(d[o+n|0]|0,k)|0)+h>>j)+l|0;if(m>>>0>255>>>0){s=-m>>31&255}else{s=m&255}a[f+n|0]=s;n=n+1|0;}while((n|0)<16);n=b+1|0;if((n|0)<(i|0)){o=o+g|0;f=f+e|0;b=n}else{break}}return}function cQb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=c[h+32>>2]|0;k=c[h+36>>2]|0;l=c[h+40>>2]|0;h=(i|0)>0;if((j|0)<=0){if(h){m=f;n=b;o=0}else{return}while(1){p=0;do{q=(ca(d[m+p|0]|0,k)|0)+l|0;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[n+p|0]=r;p=p+1|0;}while((p|0)<20);p=o+1|0;if((p|0)<(i|0)){m=m+g|0;n=n+e|0;o=p}else{break}}return}if(!h){return}h=1<<j-1;o=f;f=b;b=0;while(1){n=0;do{m=((ca(d[o+n|0]|0,k)|0)+h>>j)+l|0;if(m>>>0>255>>>0){s=-m>>31&255}else{s=m&255}a[f+n|0]=s;n=n+1|0;}while((n|0)<20);n=b+1|0;if((n|0)<(i|0)){o=o+g|0;f=f+e|0;b=n}else{break}}return}function dQb(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=d[19168+g|0]|0;k=a[e+28104+(f*40|0)+j|0]|0;l=k<<24>>24;m=j-1|0;n=a[e+28104+(f*40|0)+m|0]|0;o=e+28192+(f*160|0)+(m<<2)|0;p=j-8|0;q=a[e+28104+(f*40|0)+p|0]|0;r=e+28192+(f*160|0)+(p<<2)|0;s=p+h|0;t=a[e+28104+(f*40|0)+s|0]|0;if((g&3)>>>0<(h&1|2)>>>0){if(t<<24>>24==-2){u=3}else{v=t<<24>>24;w=e+28192+(f*160|0)+(s<<2)|0}}else{u=3}do{if((u|0)==3){s=j-9|0;t=a[e+28104+(f*40|0)+s|0]|0;h=e+28192+(f*160|0)+(s<<2)|0;if((c[e+3260>>2]|0)==0){v=t;w=h;break}if((a[e+28104+(f*40|0)+11|0]|0)==-2){v=t;w=h;break}if((c[e+18660>>2]|0)==(d[(c[e+19276>>2]|0)+(c[e+18900>>2]|0)|0]|0)){v=t;w=h;break}if((g|0)==2){v=a[e+28800+(f*3|0)|0]|0;w=e+28776+(f*12|0)|0;break}else if((g|0)==10){v=a[e+28800+(f*3|0)+2|0]|0;w=e+28776+(f*12|0)+8|0;break}else if((g|0)==8){v=a[e+28800+(f*3|0)+1|0]|0;w=e+28776+(f*12|0)+4|0;break}else{v=t;w=h;break}}}while(0);j=c[e+19348>>2]|0;do{if((j|0)==15){if((g|0)==0){if(!(n<<24>>24==k<<24>>24)){break}c[i>>2]=c[o>>2];return}else{if((v|0)!=(l|0)){break}c[i>>2]=c[w>>2];return}}else if((j|0)==14){if((g|0)==0){if(!(q<<24>>24==k<<24>>24)){break}c[i>>2]=c[r>>2];return}else{if(!(n<<24>>24==k<<24>>24)){break}c[i>>2]=c[o>>2];return}}}while(0);g=n<<24>>24==k<<24>>24;j=q<<24>>24==k<<24>>24;k=(j&1)+(g&1)+((v|0)==(l|0))|0;do{if((k|0)<=1){if((k|0)!=1){if((v|0)!=-2|q<<24>>24!=-2|n<<24>>24==-2){break}c[i>>2]=c[o>>2];return}if(g){c[i>>2]=c[o>>2];return}if(j){c[i>>2]=c[r>>2];return}else{c[i>>2]=c[w>>2];return}}}while(0);j=b[o>>1]|0;o=b[r>>1]|0;r=j-o|0;g=r>>31&r;r=g+o|0;o=r-(b[w>>1]|0)|0;n=r-(o>>31&o)|0;o=j-g-n|0;b[i>>1]=(o>>31&o)+n;n=b[e+28192+(f*160|0)+(m<<2)+2>>1]|0;m=b[e+28192+(f*160|0)+(p<<2)+2>>1]|0;p=n-m|0;f=p>>31&p;p=f+m|0;m=p-(b[w+2>>1]|0)|0;w=p-(m>>31&m)|0;m=n-f-w|0;b[i+2>>1]=(m>>31&m)+w;return}function eQb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=a[d+28104+(e*40|0)+11|0]|0;i=d+28192+(e*160|0)+44|0;j=a[d+28104+(e*40|0)+4|0]|0;k=d+28192+(e*160|0)+16|0;l=a[d+28104+(e*40|0)+8|0]|0;if(l<<24>>24==-2){m=a[d+28104+(e*40|0)+3|0]|0;n=d+28192+(e*160|0)+12|0}else{m=l;n=d+28192+(e*160|0)+32|0}l=(h<<24>>24|0)==(f|0);o=(j<<24>>24|0)==(f|0);p=(o&1)+(l&1)+((m<<24>>24|0)==(f|0))|0;do{if((p|0)<=1){if((p|0)!=1){if(m<<24>>24!=-2|j<<24>>24!=-2|h<<24>>24==-2){break}c[g>>2]=c[i>>2];return}if(l){c[g>>2]=c[i>>2];return}if(o){c[g>>2]=c[k>>2];return}else{c[g>>2]=c[n>>2];return}}}while(0);o=b[i>>1]|0;i=b[k>>1]|0;k=o-i|0;l=k>>31&k;k=l+i|0;i=k-(b[n>>1]|0)|0;h=k-(i>>31&i)|0;i=o-l-h|0;b[g>>1]=(i>>31&i)+h;h=b[d+28192+(e*160|0)+46>>1]|0;i=b[d+28192+(e*160|0)+18>>1]|0;e=h-i|0;d=e>>31&e;e=d+i|0;i=e-(b[n+2>>1]|0)|0;n=e-(i>>31&i)|0;i=h-d-n|0;b[g+2>>1]=(i>>31&i)+n;return}function fQb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a[b+28115|0]|0;f=a[b+28108|0]|0;g=f<<24>>24;h=b+28208|0;do{if(!(e<<24>>24==-2|f<<24>>24==-2)){if((c[b+28236>>2]|e<<24>>24|0)==0){break}if((c[h>>2]|g|0)==0){break}eQb(b,0,0,d);return}}while(0);c[d>>2]=0;return}function gQb(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;h=i;i=i+48|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;if((c[f+536>>2]|0)==0){p=0;i=h;return p|0}a:do{if((c[f+3296>>2]|0)==0){q=c[f+18608>>2]|0;r=f+18612|0;s=c[r>>2]|0;t=c[f+18616>>2]|0;u=n|0;v=f+15236|0;w=c[v>>2]|0;x=c[w+2776>>2]|0;y=a[x+t|0]|0;c[u>>2]=y;z=n+4|0;c[z>>2]=y;y=c[w+2780>>2]|0;A=f+18660|0;B=c[A>>2]|0;C=f+19348|0;c[C>>2]=d[y+t|0]|0;b:do{if((c[f+160>>2]|0)==0){D=s;E=t;F=B;G=1;H=1}else{if((d[(c[w+2932>>2]|0)+t|0]|0)==(B|0)){D=s;E=t;F=B;G=1;H=1;break}if((B|0)==0){I=c[f+15148>>2]|0;J=(c[w+4>>2]|0)-((c[I+8>>2]|0)+(c[I+4>>2]|0))|0;I=J+(c[w+8>>2]|0)|0;K=(c[w+12>>2]|0)+J|0;J=(((I|0)>-1?I:-I|0)|0)>=(((K|0)>-1?K:-K|0)|0)|s&-2;K=(ca(J,c[f+18580>>2]|0)|0)+q|0;I=a[x+K|0]|0;c[z>>2]=I;c[u>>2]=I;c[C>>2]=d[y+K|0]|0;D=J;E=K;F=1;G=0;H=2;break}K=s&-2;J=c[f+18580>>2]|0;I=(ca(J,K)|0)+q|0;L=a[x+I|0]|0;c[u>>2]=L<<24>>24;M=I+J|0;J=a[x+M|0]|0;c[z>>2]=J<<24>>24;N=a[y+I|0]|0;O=a[y+M|0]|0;do{if((L&255)>>>0<4>>>0|N<<24>>24==16){if((J&255)>>>0<4>>>0){if(N<<24>>24==13){break}}else{if(O<<24>>24!=16|N<<24>>24==13){break}}c[C>>2]=14;D=K;E=I;F=0;G=0;H=0;break b}}while(0);c[C>>2]=13;D=K;E=I;F=0;G=0;H=0}}while(0);y=c[f+18580>>2]|0;z=(ca(D<<4,y)|0)+(q<<2)|0;x=(ca(D<<2,y)|0)+(q<<1)|0;re[c[25117]&1023](f+28156|0,0);y=c[C>>2]|0;u=16-y|0;s=u+1|0;w=(y|0)==14?2:1;y=f+18720|0;if((s|0)<=0){break}t=f+3260|0;N=(4>>>((u&1)>>>0))-3+(4>>>(u>>1>>>0)<<1)|0;u=100432+(N<<2)|0;O=100512+(N<<2)|0;N=f+18584|0;J=f+29896|0;L=f+18588|0;M=f+4|0;P=0;while(1){Q=P&1;R=P>>1;do{if((c[t>>2]|0)==0){S=105}else{T=c[A>>2]|0;if((d[(c[(c[v>>2]|0)+2932>>2]|0)+E|0]|0)==(T|0)){S=105;break}if((T|0)==0){U=(c[r>>2]<<1&2)+R|0;break}else{U=R*6|0;break}}}while(0);if((S|0)==105){S=0;U=R*3|0}if((c[n+(R<<2)>>2]|0)>>>0<4>>>0){I=Q<<1|R<<4|12;re[c[u>>2]&1023](f+28104+I|0,0);re[c[O>>2]&1023](f+28192+(I<<2)|0,0);re[c[O>>2]&1023](f+28352+(I<<2)|0,0)}else{I=(ca(c[N>>2]|0,U>>1)|0)+(Q|x)|0;K=c[v>>2]|0;T=a[(c[K+4372>>2]|0)+I|0]|0;I=(a[(T>>F)+2+(f+30416)|0]<<B)+(T&G&c[A>>2])|0;if(!((I|0)>-1)){p=0;S=125;break}T=b[(c[J>>2]|0)+(I<<3)>>1]|0;V=(ca(c[L>>2]|0,U)|0)+(-Q&3|z)|0;W=c[K+2784>>2]|0;K=W+(V<<2)|0;X=(ca(b[K>>1]|0,T)|0)+128>>8;Y=((b[W+(V<<2)+2>>1]<<H|0)/2|0)<<16>>16;V=(ca(Y,T)|0)+128>>8;if((c[M>>2]|0)>1){T=c[y>>2]|0;if((V|0)>(T|0)){p=0;S=125;break}W=V-Y|0;if((W|0)>(T|0)){p=0;S=125;break}else{Z=W}}else{Z=V-Y|0}Y=Q<<1|R<<4|12;re[c[u>>2]&1023](f+28104+Y|0,I&255);re[c[O>>2]&1023](f+28192+(Y<<2)|0,V<<16|X&65535);re[c[O>>2]&1023](f+28352+(Y<<2)|0,X-(e[K>>1]|0)&65535|Z<<16)}P=P+w|0;if((P|0)>=(s|0)){break a}}if((S|0)==125){i=h;return p|0}}else{if((c[f+3260>>2]|0)==0){s=j;P=k;w=0;do{O=a[f+28104+(w*40|0)+11|0]|0;u=O<<24>>24;y=f+28192+(w*160|0)+44|0;M=a[f+28104+(w*40|0)+4|0]|0;z=M<<24>>24;L=f+28192+(w*160|0)+16|0;J=a[f+28104+(w*40|0)+8|0]|0;if(J<<24>>24==-2){_=a[f+28104+(w*40|0)+3|0]|0;$=f+28192+(w*160|0)+12|0}else{_=J;$=f+28192+(w*160|0)+32|0}J=_<<24>>24;A=z>>>0<J>>>0?z:J;B=u>>>0<A>>>0?u:A;do{if((B|0)<0){c[P+(w<<2)>>2]=0;aa=-1;ba=0}else{A=(u|0)==(B|0);v=(z|0)==(B|0);if(((A&1)+(v&1)+((J|0)==(B|0))|0)>1){x=P+(w<<2)|0;N=b[y>>1]|0;r=b[L>>1]|0;t=N-r|0;C=t>>31&t;t=C+r|0;r=t-(b[$>>1]|0)|0;q=t-(r>>31&r)|0;r=N-C-q|0;b[x>>1]=(r>>31&r)+q;q=b[f+28192+(w*160|0)+46>>1]|0;r=b[f+28192+(w*160|0)+18>>1]|0;C=q-r|0;N=C>>31&C;C=N+r|0;r=C-(b[$+2>>1]|0)|0;t=C-(r>>31&r)|0;r=q-N-t|0;b[P+(w<<2)+2>>1]=(r>>31&r)+t;aa=B&255;ba=c[x>>2]|0;break}if(A){A=c[y>>2]|0;c[P+(w<<2)>>2]=A;aa=O;ba=A;break}if(v){v=c[L>>2]|0;c[P+(w<<2)>>2]=v;aa=M;ba=v;break}else{v=c[$>>2]|0;c[P+(w<<2)>>2]=v;aa=B&255;ba=v;break}}}while(0);re[c[25117]&1023](f+28104+(w*40|0)+12|0,aa&255);re[c[25137]&1023](f+28192+(w*160|0)+48|0,ba);a[s+w|0]=aa;w=w+1|0;}while((w|0)<2);w=c[f+18616>>2]|0;B=c[f+15236>>2]|0;M=a[(c[B+2776>>2]|0)+w|0]|0;L=a[(c[B+2780>>2]|0)+w|0]|0;w=L&255;c[f+19348>>2]=w;O=c[f+18624>>2]|0;y=c[f+18620>>2]|0;J=c[B+4372>>2]|0;z=c[B+4376>>2]|0;c[o>>2]=(c[B+2784>>2]|0)+(O<<2);c[o+4>>2]=(c[B+2788>>2]|0)+(O<<2);O=b[j>>1]|0;B=O&255;if((O&-32640)<<16>>16==-32640){re[c[25117]&1023](f+28116|0,0);re[c[25117]&1023](f+28156|0,0);break}do{if((c[f+4>>2]|0)>1){O=c[f+18720>>2]|0;if((b[k+2>>1]|0)>(O|0)){p=0;i=h;return p|0}if((b[P+6>>1]|0)>(O|0)){p=0}else{break}i=h;return p|0}}while(0);P=k|0;if((c[P>>2]|0)==0&(c[P+4>>2]|0)==0|(M&255)>>>0<4>>>0){break}P=B<<24>>24==0;if(!P){if((a[s+1|0]|0)!=0){break}}O=16-w|0;u=O+1|0;R=L<<24>>24==14?2:1;if((u|0)<=0){break}Q=f+18584|0;v=f+18588|0;A=100512+((4>>>((O&1)>>>0))-3+(4>>>(O>>1>>>0)<<1)<<2)|0;O=s+1|0;x=0;while(1){t=x&1;r=x>>1;N=r*3|0;q=ca(N>>1,c[Q>>2]|0)|0;C=(ca(c[v>>2]|0,N)|0)+(-t&3)|0;N=t+y+q|0;q=a[J+N|0]|0;do{if(q<<24>>24==0){da=0;S=81}else{if(!(q<<24>>24<0)){break}if((a[z+N|0]|0)==0){da=1;S=81}}}while(0);do{if((S|0)==81){S=0;N=c[o+(da<<2)>>2]|0;q=b[N+(C<<2)>>1]|0;K=q<<16>>16;if(((q<<16>>16>-1?K:-K|0)|0)>=2){break}K=b[N+(C<<2)+2>>1]|0;N=K<<16>>16;if(((K<<16>>16>-1?N:-N|0)|0)>=2){break}if(P){re[c[A>>2]&1023](f+28192+((r<<4|t<<1|12)<<2)|0,0)}if((a[O]|0)!=0){break}re[c[A>>2]&1023](f+28352+((r<<4|t<<1|12)<<2)|0,0)}}while(0);x=x+R|0;if((x|0)>=(u|0)){break a}}}u=l;x=m;R=0;do{A=a[f+28104+(R*40|0)+11|0]|0;O=A<<24>>24;P=f+28192+(R*160|0)+44|0;z=a[f+28104+(R*40|0)+4|0]|0;J=z<<24>>24;y=f+28192+(R*160|0)+16|0;v=a[f+28104+(R*40|0)+8|0]|0;if(v<<24>>24==-2){ea=a[f+28104+(R*40|0)+3|0]|0;fa=f+28192+(R*160|0)+12|0}else{ea=v;fa=f+28192+(R*160|0)+32|0}v=ea<<24>>24;Q=J>>>0<v>>>0?J:v;s=O>>>0<Q>>>0?O:Q;do{if((s|0)<0){c[x+(R<<2)>>2]=0;ga=-1;ha=0}else{Q=(O|0)==(s|0);L=(J|0)==(s|0);if(((Q&1)+(L&1)+((v|0)==(s|0))|0)>1){w=x+(R<<2)|0;B=b[P>>1]|0;M=b[y>>1]|0;t=B-M|0;r=t>>31&t;t=r+M|0;M=t-(b[fa>>1]|0)|0;C=t-(M>>31&M)|0;M=B-r-C|0;b[w>>1]=(M>>31&M)+C;C=b[f+28192+(R*160|0)+46>>1]|0;M=b[f+28192+(R*160|0)+18>>1]|0;r=C-M|0;B=r>>31&r;r=B+M|0;M=r-(b[fa+2>>1]|0)|0;t=r-(M>>31&M)|0;M=C-B-t|0;b[x+(R<<2)+2>>1]=(M>>31&M)+t;ga=s&255;ha=c[w>>2]|0;break}if(Q){Q=c[P>>2]|0;c[x+(R<<2)>>2]=Q;ga=A;ha=Q;break}if(L){L=c[y>>2]|0;c[x+(R<<2)>>2]=L;ga=z;ha=L;break}else{L=c[fa>>2]|0;c[x+(R<<2)>>2]=L;ga=s&255;ha=L;break}}}while(0);re[c[25117]&1023](f+28104+(R*40|0)+12|0,ga&255);re[c[25137]&1023](f+28192+(R*160|0)+48|0,ha);a[u+R|0]=ga;R=R+1|0;}while((R|0)<2);R=c[f+18608>>2]|0;s=f+18612|0;z=c[s>>2]|0;y=c[f+18616>>2]|0;A=n|0;P=f+15236|0;v=c[P>>2]|0;J=c[v+2776>>2]|0;O=a[J+y|0]|0;c[A>>2]=O;L=n+4|0;c[L>>2]=O;O=c[v+2780>>2]|0;Q=d[O+y|0]|0;w=f+19348|0;c[w>>2]=Q;t=c[v+2932>>2]|0;M=f+18660|0;B=c[M>>2]|0;if((d[t+y|0]|0)==(B|0)){ia=Q;ja=z;ka=y;la=ca(c[f+18588>>2]|0,z)|0}else{c:do{if((B|0)==0){y=c[f+15148>>2]|0;Q=(c[v+4>>2]|0)-((c[y+8>>2]|0)+(c[y+4>>2]|0))|0;y=Q+(c[v+8>>2]|0)|0;C=(c[v+12>>2]|0)+Q|0;Q=(((y|0)>-1?y:-y|0)|0)>=(((C|0)>-1?C:-C|0)|0)|z&-2;C=(ca(Q,c[f+18580>>2]|0)|0)+R|0;y=a[J+C|0]|0;c[L>>2]=y;c[A>>2]=y;y=d[O+C|0]|0;c[w>>2]=y;ma=C;na=Q;oa=y}else{y=z&-2;Q=c[f+18580>>2]|0;C=(ca(Q,y)|0)+R|0;r=a[J+C|0]|0;c[A>>2]=r<<24>>24;N=C+Q|0;Q=a[J+N|0]|0;c[L>>2]=Q<<24>>24;K=a[O+C|0]|0;q=a[O+N|0]|0;do{if((r&255)>>>0<4>>>0|K<<24>>24==16){if((Q&255)>>>0<4>>>0){if(K<<24>>24==13){break}}else{if(q<<24>>24!=16|K<<24>>24==13){break}}c[w>>2]=14;ma=C;na=y;oa=14;break c}}while(0);c[w>>2]=13;ma=C;na=y;oa=13}}while(0);ia=oa;ja=na;ka=ma;la=ca(c[f+18588>>2]|0,na)|0}w=la+R<<2;O=f+18584|0;L=(ca(c[O>>2]|0,ja)|0)+R<<1;J=c[v+4372>>2]|0;A=c[v+4376>>2]|0;c[o>>2]=(c[v+2784>>2]|0)+(w<<2);c[o+4>>2]=(c[v+2788>>2]|0)+(w<<2);w=b[l>>1]|0;z=w&255;if((w&-32640)<<16>>16==-32640){re[c[25117]&1023](f+28116|0,0);re[c[25117]&1023](f+28156|0,0);break}do{if((c[f+4>>2]|0)>1){w=c[f+18720>>2]|0;if((b[m+2>>1]|0)>(w|0)){p=0;i=h;return p|0}if((b[x+6>>1]|0)>(w|0)){p=0}else{break}i=h;return p|0}}while(0);x=m|0;if((c[x>>2]|0)==0&(c[x+4>>2]|0)==0){break}x=z<<24>>24==0;if(!x){if((a[u+1|0]|0)!=0){break}}v=16-ia|0;R=v+1|0;w=(ia|0)==14?2:1;if((R|0)<=0){break}K=f+18588|0;q=100512+((4>>>((v&1)>>>0))-3+(4>>>(v>>1>>>0)<<1)<<2)|0;v=u+1|0;Q=0;r=t;N=B;while(1){X=Q&1;Y=Q>>1;do{if((d[r+ka|0]|0)==(N|0)){pa=Y*3|0}else{if((N|0)==0){pa=(c[s>>2]<<1&2)+Y|0;break}else{pa=Y*6|0;break}}}while(0);y=(ca(c[K>>2]|0,pa)|0)+(-X&3)|0;do{if(!((c[n+(Y<<2)>>2]|0)>>>0<4>>>0)){C=(ca(c[O>>2]|0,pa>>1)|0)+(X|L)|0;V=a[J+C|0]|0;if(V<<24>>24==0){qa=0}else{if(!(V<<24>>24<0)){break}if((a[A+C|0]|0)==0){qa=1}else{break}}C=c[o+(qa<<2)>>2]|0;V=b[C+(y<<2)>>1]|0;I=V<<16>>16;if(((V<<16>>16>-1?I:-I|0)|0)>=2){break}I=b[C+(y<<2)+2>>1]|0;C=I<<16>>16;if(((I<<16>>16>-1?C:-C|0)|0)>=2){break}if(x){re[c[q>>2]&1023](f+28192+((Y<<4|X<<1|12)<<2)|0,0)}if((a[v]|0)!=0){break}re[c[q>>2]&1023](f+28352+((Y<<4|X<<1|12)<<2)|0,0)}}while(0);X=Q+w|0;if((X|0)>=(R|0)){break a}Q=X;r=c[(c[P>>2]|0)+2932>>2]|0;N=c[M>>2]|0}}}while(0);d:do{if((g|0)==0){ra=f+28240|0;sa=f+28116|0;ta=f+28744|0;ua=f+28400|0;va=f+28728|0;wa=f+28156|0;xa=f+28748|0}else{qa=f+28240|0;o=f+28728|0;pa=f+28400|0;n=f+28744|0;ka=f+28116|0;ia=f+28748|0;m=f+28156|0;l=c[pa>>2]^c[o>>2]|c[qa>>2]^c[f+28712>>2]|(a[ka]^a[n])<<24>>24|(a[m]^a[ia])<<24>>24;e:do{if((l|0)==0){ja=c[f+19348>>2]|0;do{if((ja|0)!=16){la=c[f+28312>>2]^c[f+28724>>2]|c[f+28472>>2]^c[f+28740>>2]|(a[f+28134|0]^a[f+28747|0])<<24>>24|(a[f+28174|0]^a[f+28751|0])<<24>>24;if((la|0)!=0){ya=la;break e}if((ja|0)!=13){break}la=c[f+28408>>2]^c[f+28732>>2]|c[f+28248>>2]^c[f+28716>>2]|c[f+28304>>2]^c[f+28720>>2]|c[f+28464>>2]^c[f+28736>>2]|(a[f+28118|0]^a[f+28745|0])<<24>>24|(a[f+28158|0]^a[f+28749|0])<<24>>24|(a[f+28132|0]^a[f+28746|0])<<24>>24|(a[f+28172|0]^a[f+28750|0])<<24>>24;c[g>>2]=la;if((la|0)==0){p=1}else{ra=qa;sa=ka;ta=n;ua=pa;va=o;wa=m;xa=ia;break d}i=h;return p|0}}while(0);c[g>>2]=0;p=1;i=h;return p|0}else{ya=l}}while(0);c[g>>2]=ya;ra=qa;sa=ka;ta=n;ua=pa;va=o;wa=m;xa=ia}}while(0);ya=f+28752|0;c[f+28712>>2]=c[ra>>2];c[f+28716>>2]=c[f+28248>>2];c[f+28720>>2]=c[f+28304>>2];c[f+28724>>2]=c[f+28312>>2];a[ta]=a[sa]|0;a[f+28745|0]=a[f+28118|0]|0;a[f+28746|0]=a[f+28132|0]|0;a[f+28747|0]=a[f+28134|0]|0;sa=c[f+19348>>2]|0;c[ya>>2]=sa;c[va>>2]=c[ua>>2];c[f+28732>>2]=c[f+28408>>2];c[f+28736>>2]=c[f+28464>>2];c[f+28740>>2]=c[f+28472>>2];a[xa]=a[wa]|0;a[f+28749|0]=a[f+28158|0]|0;a[f+28750|0]=a[f+28172|0]|0;a[f+28751|0]=a[f+28174|0]|0;c[ya>>2]=sa;p=1;i=h;return p|0}function hQb(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=c[e+19008+(f<<7)+(g<<2)>>2]|0;do{if((c[e+3240>>2]|0)==1){if((a[e+28104+(f*40|0)+30|0]|0)!=(g|0)){k=0;break}c[h>>2]=c[e+28192+(f*160|0)+120>>2];k=1}else{k=0}}while(0);do{if((g|0)==0){if((c[e+15136>>2]|0)==0){l=k;break}if((f|0)==0){m=c[e+15144>>2]|0;n=(c[m+92>>2]|0)-(c[(c[e+15160>>2]|0)+92>>2]|0)|0;o=m}else{m=c[e+15144>>2]|0;n=(c[(c[e+15236>>2]|0)+92>>2]|0)-(c[m+92>>2]|0)|0;o=m}m=n-1|0;if((m|0)>(c[e+112>>2]|0)){l=k;break}p=c[o+2796+(f*68|0)+(m<<2)>>2]|0;if((b[p>>1]|0)==32767){l=k;break}c[h+(k<<2)>>2]=c[p+(c[e+18616>>2]<<2)>>2]<<1&-65538;l=k+1|0}else{l=k}}while(0);k=e+3260|0;o=c[e+18900>>2]|0;do{if((c[k>>2]|0)==0){c[h+(l<<2)>>2]=c[j+(o<<2)>>2];c[h+(l+1<<2)>>2]=c[j+(c[e+18908>>2]<<2)>>2];c[h+(l+2<<2)>>2]=c[j+(c[e+18912>>2]<<2)>>2];c[h+(l+3<<2)>>2]=c[j+(c[e+18916>>2]<<2)>>2];q=l+4|0}else{if((o|0)>-1){n=(c[e+18660>>2]|0)+1-(d[(c[e+19276>>2]|0)+o|0]|0)|0;p=c[e+19008+(f<<7)+(g<<1>>n<<2)>>2]|0;b[h+(l<<2)>>1]=b[p+(o<<2)>>1]|0;b[h+(l<<2)+2>>1]=b[p+(o<<2)+2>>1]<<1>>n;r=l+1|0}else{r=l}n=c[e+18908>>2]|0;if((n|0)>-1){p=(c[e+18660>>2]|0)+1-(d[(c[e+19276>>2]|0)+n|0]|0)|0;m=c[e+19008+(f<<7)+(g<<1>>p<<2)>>2]|0;b[h+(r<<2)>>1]=b[m+(n<<2)>>1]|0;b[h+(r<<2)+2>>1]=b[m+(n<<2)+2>>1]<<1>>p;s=r+1|0}else{s=r}p=c[e+18912>>2]|0;if((p|0)>-1){n=(c[e+18660>>2]|0)+1-(d[(c[e+19276>>2]|0)+p|0]|0)|0;m=c[e+19008+(f<<7)+(g<<1>>n<<2)>>2]|0;b[h+(s<<2)>>1]=b[m+(p<<2)>>1]|0;b[h+(s<<2)+2>>1]=b[m+(p<<2)+2>>1]<<1>>n;t=s+1|0}else{t=s}n=c[e+18916>>2]|0;if(!((n|0)>-1)){q=t;break}p=(c[e+18660>>2]|0)+1-(d[(c[e+19276>>2]|0)+n|0]|0)|0;m=c[e+19008+(f<<7)+(g<<1>>p<<2)>>2]|0;b[h+(t<<2)>>1]=b[m+(n<<2)>>1]|0;b[h+(t<<2)+2>>1]=b[m+(n<<2)+2>>1]<<1>>p;q=t+1|0}}while(0);t=c[e+15160>>2]|0;if((c[t+4380>>2]|0)<=0){u=q;c[i>>2]=u;return}s=c[e+18612>>2]|0;r=s&1;l=c[e+15148>>2]|0;o=c[e+18616>>2]|0;j=(c[l+8+(r<<2)>>2]|0)+(c[l+4>>2]|0)-(c[(c[e+15160+(f*76|0)+(g>>c[k>>2]<<2)>>2]|0)+4>>2]|0)-(c[t+8+((r^g&1)<<2)>>2]|0)|0;g=t+4516+((c[e+18660>>2]&r)<<1)|0;r=ca(b[g>>1]|0,j)|0;k=c[t+2792>>2]|0;b[h+(q<<2)>>1]=((ca(b[k+(o<<2)>>1]|0,r)|0)+128|0)>>>8;b[h+(q<<2)+2>>1]=((ca(b[k+(o<<2)+2>>1]|0,r)|0)+128|0)>>>8;r=q+1|0;if((c[e+18608>>2]|0)<((c[e+18560>>2]|0)-1|0)){t=o+1|0;f=ca(b[g>>1]|0,j)|0;b[h+(r<<2)>>1]=((ca(b[k+(t<<2)>>1]|0,f)|0)+128|0)>>>8;b[h+(r<<2)+2>>1]=((ca(b[k+(t<<2)+2>>1]|0,f)|0)+128|0)>>>8;v=q+2|0}else{v=r}if((s|0)>=((c[e+18564>>2]|0)-1|0)){u=v;c[i>>2]=u;return}s=(c[e+18580>>2]|0)+o|0;o=ca(b[g>>1]|0,j)|0;b[h+(v<<2)>>1]=((ca(b[k+(s<<2)>>1]|0,o)|0)+128|0)>>>8;b[h+(v<<2)+2>>1]=((ca(b[k+(s<<2)+2>>1]|0,o)|0)+128|0)>>>8;u=v+1|0;c[i>>2]=u;return}function iQb(){var a=0,b=0,d=0,e=0,f=0,g=0;a=MLb(116)|0;b=a;if((a|0)==0){d=0;return d|0}mrc(a|0,0,116)|0;e=Mc(2405032,2)|0;f=a;c[f>>2]=e;if((e|0)!=0){g=Dd(e|0,2576896)|0;c[a+4>>2]=g;do{if((g|0)!=0){e=Dd(c[f>>2]|0,2434384)|0;c[a+8>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2348712)|0;c[a+12>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2287112)|0;c[a+16>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2237488)|0;c[a+20>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2196928)|0;c[a+24>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2165408)|0;c[a+28>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2139256)|0;c[a+32>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2115928)|0;c[a+36>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2633784)|0;c[a+40>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2610056)|0;c[a+44>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2583472)|0;c[a+48>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2562896)|0;c[a+52>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2545424)|0;c[a+56>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2527688)|0;c[a+60>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2512624)|0;c[a+64>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2499048)|0;c[a+68>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2486688)|0;c[a+72>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2475e3)|0;c[a+76>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2466256)|0;c[a+80>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2456064)|0;c[a+84>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2438776)|0;c[a+88>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2428224)|0;c[a+92>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2417720)|0;c[a+96>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2408680)|0;c[a+100>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2401224)|0;c[a+104>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2394336)|0;c[a+108>>2]=e;if((e|0)==0){break}e=Dd(c[f>>2]|0,2387312)|0;c[a+112>>2]=e;if((e|0)==0){break}else{d=b}return d|0}}while(0);Eb(c[f>>2]|0)|0}NLb(a);d=0;return d|0}function jQb(a){a=a|0;if((a|0)==0){return}Eb(c[a>>2]|0)|0;NLb(a);return}function kQb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;b=i;i=i+464|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=b+32|0;j=b+40|0;k=b+48|0;l=b+56|0;m=b+64|0;n=b+72|0;o=b+136|0;p=b+200|0;q=b+264|0;r=b+272|0;s=b+280|0;t=b+288|0;u=b+296|0;v=b+304|0;w=b+352|0;x=b+360|0;y=b+368|0;z=b+376|0;A=b+384|0;B=b+392|0;C=b+400|0;D=a+38028|0;E=c[D>>2]|0;c[x>>2]=0;F=E+76|0;G=Ee[c[F>>2]&511](0,0,x)|0;c[y>>2]=G;do{if((G|0)==0){H=c[x>>2]|0;if((H|0)==0){break}I=MLb(H<<2)|0;H=I;if((I|0)==0){ILb(a,1,2374040,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=0;L=0;M=-1;N=H;O=L;NLb(O);P=K;NLb(P);Q=N;NLb(Q);i=b;return M|0}I=Ee[c[F>>2]&511](c[x>>2]|0,H,0)|0;c[y>>2]=I;if((I|0)!=0){ILb(a,1,2380432,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=0;L=0;M=-1;N=H;O=L;NLb(O);P=K;NLb(P);Q=N;NLb(Q);i=b;return M|0}a:do{if((c[x>>2]|0)==0){R=-1;S=0;T=0;U=0}else{I=E+64|0;V=a+38036|0;W=a+824|0;X=E+68|0;Y=A;Z=E+16|0;_=a;$=E+88|0;aa=C|0;ba=a+820|0;ca=E+12|0;da=a+38040|0;ea=E+96|0;fa=0;ga=0;ha=0;ia=0;b:while(1){c[z>>2]=0;ja=H+(ia<<2)|0;ka=se[c[I>>2]&127](c[ja>>2]|0,4,0,0,0,z)|0;c[y>>2]=ka;do{if((ka|0)!=0|(c[z>>2]|0)==0){la=ha;ma=ga;na=fa}else{NLb(fa);oa=MLb(c[z>>2]<<2)|0;pa=oa;if((oa|0)==0){la=ha;ma=ga;na=pa;break}oa=se[c[I>>2]&127](c[ja>>2]|0,4,0,c[z>>2]|0,pa,0)|0;c[y>>2]=oa;if((oa|0)!=0|(c[z>>2]|0)==0){la=ha;ma=ga;na=pa;break}else{qa=ga;ra=ha;sa=0}while(1){oa=pa+(sa<<2)|0;ta=c[oa>>2]|0;c[V>>2]=ta;ua=c[W>>2]|0;if((ua|0)==0){va=15}else{if((c[oa>>2]|0)==(ua|0)){va=15}else{wa=ra;xa=qa}}c:do{if((va|0)==15){va=0;c[A>>2]=0;ua=Xe[c[X>>2]&511](ta,4118,4,Y,0)|0;c[y>>2]=ua;if((ua|0)!=0|(c[A>>2]|0)==0){wa=ra;xa=qa;break}if((ra|0)!=0){ve[c[ea>>2]&4095](ra)|0}ya=se[c[Z>>2]&127](0,1,V,500,_,y)|0;if((c[y>>2]|0)!=0|(ya|0)==0){wa=ya;xa=qa;break}c[B>>2]=0;ua=me[c[$>>2]&255](ya,1,0,4337,0,0,B)|0;c[y>>2]=ua;if((ua|0)!=0|(c[B>>2]|0)==0){wa=ya;xa=qa;break}NLb(qa);ua=MLb(c[B>>2]<<3)|0;za=ua;if((ua|0)==0){wa=ya;xa=za;break}ua=me[c[$>>2]&255](ya,1,0,4337,c[B>>2]|0,za,0)|0;c[y>>2]=ua;if((ua|0)!=0){wa=ya;xa=za;break}ua=c[B>>2]|0;do{if((ua|0)!=0){oa=0;Aa=0;Ba=0;while(1){Ca=c[za+(Ba<<3)>>2]|0;if((Ca|0)==4277){Da=(c[za+(Ba<<3)+4>>2]|0)==4314?1:Aa;Ea=oa}else if((Ca|0)==4272){Da=Aa;Ea=(c[za+(Ba<<3)+4>>2]|0)==4316?1:oa}else{Da=Aa;Ea=oa}Ca=Ba+1|0;if(Ca>>>0<ua>>>0){oa=Ea;Aa=Da;Ba=Ca}else{break}}if((Ea|0)==0|(Da|0)==0){break}Ba=c[ba>>2]|0;if((Ba|0)==0){Aa=Xe[c[ca>>2]&511](ya,c[V>>2]|0,0,0,y)|0;c[da>>2]=Aa;if((c[y>>2]|0)!=0|(Aa|0)==0){wa=ya;xa=za;break c}else{break b}}else{c[ba>>2]=Ba-1;wa=ya;xa=za;break c}}}while(0);ua=Xe[c[X>>2]&511](c[V>>2]|0,4139,64,aa,0)|0;c[y>>2]=ua;if((ua|0)!=0){wa=ya;xa=za;break}ILb(a,(c[W>>2]|0)!=0?1:3,2366528,(J=i,i=i+8|0,c[J>>2]=aa,J)|0);i=J;wa=ya;xa=za}}while(0);ta=sa+1|0;if(ta>>>0<(c[z>>2]|0)>>>0){qa=xa;ra=wa;sa=ta}else{la=wa;ma=xa;na=pa;break}}}}while(0);ja=ia+1|0;if(ja>>>0<(c[x>>2]|0)>>>0){fa=na;ga=ma;ha=la;ia=ja}else{R=-1;S=la;T=ma;U=na;break a}}c[a+38032>>2]=ya;R=0;S=0;T=za;U=pa}}while(0);ia=a+828|0;if((c[ia>>2]|0)==0){c[ia>>2]=2351504}d:do{if((R|0)==0){if((c[a+696>>2]|0)==0){Fa=-1;break}c[v>>2]=a+50424;c[v+4>>2]=a+50428;c[v+8>>2]=a+50372;c[v+12>>2]=a+50376;c[v+16>>2]=a+50380;c[v+20>>2]=a+50420;c[v+24>>2]=a+50396;c[v+28>>2]=a+50392;c[v+32>>2]=a+50440;c[v+36>>2]=a+50444;c[v+40>>2]=a+50464;c[v+44>>2]=a+50468;ha=c[D>>2]|0;ga=n|0;fa=o|0;aa=p|0;W=r;V=ha+68|0;X=a+38036|0;ba=Xe[c[V>>2]&511](c[X>>2]|0,4139,64,ga,0)|0;da=Xe[c[V>>2]&511](c[X>>2]|0,4140,64,fa,0)|0|ba;ba=da|(Xe[c[V>>2]&511](c[X>>2]|0,4141,64,aa,0)|0);c[q>>2]=ba;e:do{if((ba|0)==0){da=(irc(fa,2259280)|0)==0;ca=da&1;$=a+50356|0;c[$>>2]=0;do{if(da){_=Mc(2180488,257)|0;if((_|0)==0){Ga=0}else{Z=Dd(_|0,2178312)|0;ea=Dd(_|0,2174992)|0;Y=ea;I=Dd(_|0,2166944)|0;ja=I;ka=Dd(_|0,2163560)|0;ta=ka;do{if((Z|0)==0|(ea|0)==0|(I|0)==0|(ka|0)==0){Ha=0}else{if((We[Z&2047](1112,1)|0)!=0){Ha=0;break}c[j>>2]=0;f:do{if((ve[ja&4095](j)|0)==0){ua=0;while(1){if((ua|0)>=(c[j>>2]|0)){Ia=0;break f}if((hf[ta&1023](ua,k,l,m)|0)!=0){Ia=0;break f}if((c[k>>2]|0)>1){Ia=1;break}else{ua=ua+1|0}}}else{Ia=0}}while(0);Ce[Y&1]()|0;Ha=Ia}}while(0);Eb(_|0)|0;Ga=Ha}if((Ga|0)!=0){ILb(a,2,2254856,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Ja=0;break e}c[r>>2]=4;Y=Xe[c[V>>2]&511](c[X>>2]|0,16450,4,W,0)|0;c[q>>2]=Y;if((Y|0)==0&(c[r>>2]|0)==1){c[$>>2]=1;Ka=0;La=2239312;break}else{Ka=ca;La=(c[$>>2]|0)!=0?2239312:10230184;break}}else{Ka=ca;La=10230184}}while(0);ILb(a,2,2249664,(J=i,i=i+24|0,c[J>>2]=fa,c[J+8>>2]=ga,c[J+16>>2]=La,J)|0);i=J;ca=Qc(c[ia>>2]|0,2182552)|0;if((ca|0)==0){Ma=0}else{$=c[D>>2]|0;Rd(ca|0,0,2)|0;da=dc(ca|0)|0;c[f>>2]=da;Ud(ca|0);Y=MLb(da)|0;do{if((Y|0)==0){Na=0}else{Ed(Y|0,1,da|0,ca|0)|0;c[g>>2]=Y;ta=lrc(ga|0)|0;ja=c[f>>2]|0;if(!(ja>>>0>ta>>>0)){Na=0;break}if((krc(Y,ga,ta)|0)!=0){Na=0;break}Z=ta+1|0;ta=ja-Z|0;c[f>>2]=ta;ja=Y+Z|0;c[g>>2]=ja;ka=lrc(fa|0)|0;if(!(ta>>>0>ka>>>0)){Na=0;break}if((krc(ja,fa,ka)|0)!=0){Na=0;break}ja=ka+1|0;ka=ta-ja|0;c[f>>2]=ka;ta=ja+Z|0;Z=Y+ta|0;c[g>>2]=Z;ja=lrc(aa|0)|0;if(!(ka>>>0>ja>>>0)){Na=0;break}if((krc(Z,aa,ja)|0)!=0){Na=0;break}Z=ja+1|0;ja=ka-Z|0;c[f>>2]=ja;ka=Z+ta|0;ta=Y+ka|0;c[g>>2]=ta;if(ja>>>0<33>>>0){Na=0;break}if((krc(ta,19568,32)|0)!=0){Na=0;break}c[f>>2]=ja-33;c[g>>2]=Y+(ka+33);ka=me[c[$+28>>2]&255](c[a+38032>>2]|0,1,X,f,g,0,h)|0;Na=(c[h>>2]|0)==0?ka:0}}while(0);nb(ca|0)|0;NLb(Y);Ma=Na}do{if((Ma|0)==0){ILb(a,2,2230896,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;c[s>>2]=19608;c[t>>2]=74832;$=Xe[c[ha+32>>2]&511](c[a+38032>>2]|0,1,s,t,q)|0;if(!((c[q>>2]|0)!=0|($|0)==0)){Oa=$;break}ILb(a,1,2227040,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Ja=0;break e}else{Oa=Ma}}while(0);Y=se[c[ha+4>>2]&127](Oa,1,X,(Ka|0)!=0?2222352:10230184,0,0)|0;c[q>>2]=Y;if((Y|0)==0){Y=d;ca=Qc(c[ia>>2]|0,2192368)|0;if((ca|0)==0){ILb(a,2,2189856,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Ja=Oa;break}$=c[D>>2]|0;c[d>>2]=0;c[e>>2]=0;da=$+84|0;do{if((Xe[c[da>>2]&511](Oa,4453,4,e,0)|0)==0){$=c[e>>2]|0;if(($|0)==0){va=77;break}ka=MLb($)|0;c[d>>2]=ka;if((ka|0)==0){break}if((Xe[c[da>>2]&511](Oa,4454,4,Y,0)|0)==0){xb(ga|0,ca|0)|0;sb(10,ca|0)|0;xb(fa|0,ca|0)|0;sb(10,ca|0)|0;xb(aa|0,ca|0)|0;sb(10,ca|0)|0;ub(19568,32,1,ca|0)|0;sb(10,ca|0)|0;ub(c[d>>2]|0,1,c[e>>2]|0,ca|0)|0;break}else{ILb(a,2,2184744,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;break}}else{va=77}}while(0);if((va|0)==77){ILb(a,2,2187296,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J}nb(ca|0)|0;NLb(c[d>>2]|0);Ja=Oa;break}c[u>>2]=0;Y=ha+80|0;da=se[c[Y>>2]&127](Oa,c[X>>2]|0,4483,0,0,u)|0;c[q>>2]=da;do{if((da|0)==0){ka=c[u>>2]|0;if((ka|0)==0){va=85;break}$=MLb(ka)|0;if(($|0)==0){ILb(a,1,2215712,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Pa=0;break}ka=se[c[Y>>2]&127](Oa,c[X>>2]|0,4483,c[u>>2]|0,$,0)|0;c[q>>2]=ka;if((ka|0)!=0){ILb(a,1,2213096,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Pa=$;break}ka=Qc(2210944,2207288)|0;if((ka|0)==0){ILb(a,1,2198424,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Pa=$;break}else{ub($|0,1,c[u>>2]|0,ka|0)|0;nb(ka|0)|0;ILb(a,1,2194720,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Pa=$;break}}else{va=85}}while(0);if((va|0)==85){ILb(a,1,2218672,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Pa=0}NLb(Pa);if((Oa|0)==0){Ja=0;break}ve[c[ha+108>>2]&4095](Oa)|0;Ja=0}else{Ja=0}}while(0);X=a+38044|0;c[X>>2]=Ja;do{if((Ja|0)!=0){aa=ha+24|0;fa=0;while(1){if(!(fa>>>0<12>>>0)){break}Qa=c[94456+(fa<<2)>>2]|0;ga=Ee[c[aa>>2]&511](c[X>>2]|0,Qa,w)|0;c[c[v+(fa<<2)>>2]>>2]=ga;Ra=c[w>>2]|0;if((Ra|0)==0){fa=fa+1|0}else{va=99;break}}if((va|0)==99){ILb(a,1,2271328,(J=i,i=i+16|0,c[J>>2]=Qa,c[J+8>>2]=Ra,J)|0);i=J;break}fa=se[c[ha+8>>2]&127](c[a+38032>>2]|0,18,0,33554432,0,w)|0;c[a+38052>>2]=fa;aa=c[w>>2]|0;if((aa|0)!=0){ILb(a,1,2266696,(J=i,i=i+8|0,c[J>>2]=aa,J)|0);i=J;break}c[a+38056>>2]=Be[c[ha+40>>2]&7](c[a+38040>>2]|0,fa,1,3,0,0,33554432,0,0,0,w)|0;fa=c[w>>2]|0;if((fa|0)==0){Fa=0;break d}ILb(a,1,2263136,(J=i,i=i+8|0,c[J>>2]=fa,J)|0);i=J}}while(0);mQb(a);Fa=-1}else{ILb(a,1,2343952,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;Fa=R}}while(0);if((S|0)==0){K=U;L=T;M=Fa;N=H;O=L;NLb(O);P=K;NLb(P);Q=N;NLb(Q);i=b;return M|0}ve[c[E+96>>2]&4095](S)|0;K=U;L=T;M=Fa;N=H;O=L;NLb(O);P=K;NLb(P);Q=N;NLb(Q);i=b;return M|0}}while(0);ILb(a,1,2380432,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=0;L=0;M=-1;N=0;O=L;NLb(O);P=K;NLb(P);Q=N;NLb(Q);i=b;return M|0}function lQb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=i;b=e;c[e+816>>2]=0;c[e+50360>>2]=1;ILb(b,0,2161560,(e=i,i=i+8|0,c[e>>2]=a,e)|0);i=e;ILb(b,0,2159496,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}function mQb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+38028|0;d=c[b>>2]|0;if((d|0)==0){return}e=a+38040|0;f=c[e>>2]|0;if((f|0)==0){g=d}else{ve[c[d+56>>2]&4095](f)|0;g=c[b>>2]|0}b=a+50372|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50376|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50380|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50392|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50396|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50420|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50424|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50428|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50440|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50444|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50464|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+50468|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+100>>2]&4095](f)|0;c[b>>2]=0}b=a+38044|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+108>>2]&4095](f)|0;c[b>>2]=0}b=a+38052|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[g+104>>2]&4095](f)|0;c[b>>2]=0}b=a+50384|0;f=c[b>>2]|0;h=g+104|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50388|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50400|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50404|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50408|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50412|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50416|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50432|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50436|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50448|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50452|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50456|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50460|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50472|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50476|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50480|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=a+50484|0;f=c[b>>2]|0;if((f|0)!=0){ve[c[h>>2]&4095](f)|0;c[b>>2]=0}b=c[e>>2]|0;if((b|0)!=0){ve[c[d+92>>2]&4095](b)|0;c[e>>2]=0}e=a+38032|0;a=c[e>>2]|0;if((a|0)==0){return}ve[c[d+96>>2]&4095](a)|0;c[e>>2]=0;return}function nQb(a){a=a|0;var b=0,d=0,e=0;b=c[a+12020>>2]|0;if((b|0)==0){return}d=b+104|0;b=a+12024|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12028|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12032|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12036|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12040|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12044|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12048|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12052|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12056|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12060|0;e=c[b>>2]|0;if((e|0)!=0){ve[c[d>>2]&4095](e)|0;c[b>>2]=0}b=a+12064|0;a=c[b>>2]|0;if((a|0)==0){return}ve[c[d>>2]&4095](a)|0;c[b>>2]=0;return}function oQb(a){a=a|0;return MLb(a)|0}function pQb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;j=(b|e|f|g)&15;k=i-15|0;if((k|0)>0){l=h-15|0;m=a+32|0;n=h-7|0;o=a+40|0;p=0;q=0;r=0;while(1){if((j|0)!=0|(l|0)<1){s=q;t=r;u=0}else{v=ca(p,e)|0;w=ca(p,g)|0;x=0;y=q;z=r;while(1){A=hf[c[m>>2]&1023](b+(x+v)|0,e,f+(x+w)|0,g)|0;B=wrc(A,(A|0)<0|0?-1:0,z,y)|0;A=G;C=x+16|0;if((C|0)<(l|0)){x=C;y=A;z=B}else{s=A;t=B;u=C;break}}}if((u|0)<(n|0)){z=ca(p,e)|0;y=ca(p,g)|0;x=u;w=s;v=t;while(1){C=hf[c[o>>2]&1023](b+(x+z)|0,e,f+(x+y)|0,g)|0;B=wrc(C,(C|0)<0|0?-1:0,v,w)|0;C=G;A=x+8|0;if((A|0)<(n|0)){x=A;w=C;v=B}else{D=C;E=B;break}}}else{D=s;E=t}v=p+16|0;if((v|0)<(k|0)){p=v;q=D;r=E}else{F=v;H=D;I=E;break}}}else{F=0;H=0;I=0}do{if((F|0)<(i-7|0)){E=h-7|0;if((E|0)<=0){J=H;K=I;break}D=a+44|0;r=ca(F,e)|0;q=ca(F,g)|0;p=0;k=H;t=I;while(1){s=hf[c[D>>2]&1023](b+(p+r)|0,e,f+(p+q)|0,g)|0;n=wrc(s,(s|0)<0|0?-1:0,t,k)|0;s=G;o=p+8|0;if((o|0)<(E|0)){p=o;k=s;t=n}else{J=s;K=n;break}}}else{J=H;K=I}}while(0);do{if((h&7|0)==0){L=J;M=K}else{I=i&-8;if((I|0)<=0){L=J;M=K;break}H=h&-8;if((H|0)<(h|0)){N=0;O=J;P=K}else{L=J;M=K;break}while(1){F=ca(N,e)|0;a=ca(N,g)|0;t=H;k=O;p=P;do{E=(d[b+(t+F)|0]|0)-(d[f+(t+a)|0]|0)|0;p=wrc(ca(E,E)|0,0,p,k)|0;k=G;t=t+1|0;}while((t|0)<(h|0));t=N+1|0;if((t|0)<(I|0)){N=t;O=k;P=p}else{L=k;M=p;break}}}}while(0);if((i&7|0)==0){Q=L;R=M;return(G=Q,R)|0}P=i&-8;if((P|0)<(i|0)&(h|0)>0){S=P;T=L;U=M}else{Q=L;R=M;return(G=Q,R)|0}while(1){M=ca(S,e)|0;L=ca(S,g)|0;P=0;O=T;N=U;do{K=(d[b+(P+M)|0]|0)-(d[f+(P+L)|0]|0)|0;N=wrc(ca(K,K)|0,0,N,O)|0;O=G;P=P+1|0;}while((P|0)<(h|0));P=S+1|0;if((P|0)<(i|0)){S=P;T=O;U=N}else{Q=O;R=N;break}}return(G=Q,R)|0}function qQb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;l=h&-8;Ge[c[a+384>>2]&255](b,e,f,g,l,i,j,k);a=h&7;if((a|0)==0){return}if((i|0)>0){h=0;m=f+l|0;f=b+l|0;l=0;b=0;n=0;o=0;while(1){p=0;q=l;r=b;s=n;t=o;do{u=p<<1;v=(d[f+u|0]|0)-(d[m+u|0]|0)|0;w=u|1;u=(d[f+w|0]|0)-(d[m+w|0]|0)|0;r=wrc(ca(v,v)|0,0,r,q)|0;q=G;t=wrc(ca(u,u)|0,0,t,s)|0;s=G;p=p+1|0;}while((p|0)<(a|0));p=h+1|0;if((p|0)<(i|0)){h=p;m=m+g|0;f=f+e|0;l=q;b=r;n=s;o=t}else{x=q;y=r;z=s;A=t;break}}}else{x=0;y=0;z=0;A=0}o=wrc(c[j>>2]|0,c[j+4>>2]|0,y,x)|0;c[j>>2]=o;c[j+4>>2]=G;j=wrc(c[k>>2]|0,c[k+4>>2]|0,A,z)|0;c[k>>2]=j;c[k+4>>2]=G;return}function rQb(a,b,e,f,g,h,i,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0;c[i>>2]=0;c[i+4>>2]=0;c[j>>2]=0;c[j+4>>2]=0;if((h|0)>0&(g|0)>0){k=0;l=e;m=a}else{return}while(1){a=0;do{e=a<<1;n=(d[m+e|0]|0)-(d[l+e|0]|0)|0;o=e|1;e=(d[m+o|0]|0)-(d[l+o|0]|0)|0;o=ca(n,n)|0;n=wrc(o,0,c[i>>2]|0,c[i+4>>2]|0)|0;c[i>>2]=n;c[i+4>>2]=G;n=ca(e,e)|0;e=wrc(n,0,c[j>>2]|0,c[j+4>>2]|0)|0;c[j>>2]=e;c[j+4>>2]=G;a=a+1|0;}while((a|0)<(g|0));a=k+1|0;if((a|0)<(h|0)){k=a;l=l+f|0;m=m+b|0}else{break}}return}function sQb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;i=i+256|0;f=e|0;mSb(f,b);c[d>>2]=tQb(f,32,a,16)|0;lSb(f,b);c[d+4>>2]=tQb(f,32,a,16)|0;kSb(f,b);c[d+8>>2]=tQb(f,32,a,16)|0;i=e;return}function tQb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c;c=a;a=0;g=0;while(1){h=(d[c]|0)-(d[f]|0)|0;i=(d[c+1|0]|0)-(d[f+1|0]|0)|0;j=(d[c+2|0]|0)-(d[f+2|0]|0)|0;k=(d[c+3|0]|0)-(d[f+3|0]|0)|0;l=(d[c+4|0]|0)-(d[f+4|0]|0)|0;m=(d[c+5|0]|0)-(d[f+5|0]|0)|0;n=(d[c+6|0]|0)-(d[f+6|0]|0)|0;o=(d[c+7|0]|0)-(d[f+7|0]|0)|0;p=((o|0)>-1?o:-o|0)+(((n|0)>-1?n:-n|0)+(((m|0)>-1?m:-m|0)+(((l|0)>-1?l:-l|0)+(((k|0)>-1?k:-k|0)+(((j|0)>-1?j:-j|0)+(((i|0)>-1?i:-i|0)+(((h|0)>-1?h:-h|0)+a)))))))|0;h=g+1|0;if((h|0)<8){f=f+e|0;c=c+b|0;a=p;g=h}else{break}}return p|0}function uQb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;i=i+256|0;f=e|0;mSb(f,b);c[d>>2]=(VRb(f,32,a,16)|0)+2>>2;lSb(f,b);c[d+4>>2]=(VRb(f,32,a,16)|0)+2>>2;kSb(f,b);c[d+8>>2]=(VRb(f,32,a,16)|0)+2>>2;i=e;return}function vQb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return(VRb(a,b,c,d)|0)+2>>2|0}function wQb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;jSb(b);f=a;g=b;h=0;i=0;while(1){j=(d[g]|0)-(d[f]|0)|0;k=(d[g+1|0]|0)-(d[f+1|0]|0)|0;l=(d[g+2|0]|0)-(d[f+2|0]|0)|0;m=(d[g+3|0]|0)-(d[f+3|0]|0)|0;n=((j|0)>-1?j:-j|0)+h+((k|0)>-1?k:-k|0)+((l|0)>-1?l:-l|0)+((m|0)>-1?m:-m|0)|0;m=i+1|0;if((m|0)<4){f=f+16|0;g=g+32|0;h=n;i=m}else{break}}c[e>>2]=n;iSb(b);n=a;i=b;h=0;g=0;while(1){f=(d[i]|0)-(d[n]|0)|0;m=(d[i+1|0]|0)-(d[n+1|0]|0)|0;l=(d[i+2|0]|0)-(d[n+2|0]|0)|0;k=(d[i+3|0]|0)-(d[n+3|0]|0)|0;o=((f|0)>-1?f:-f|0)+h+((m|0)>-1?m:-m|0)+((l|0)>-1?l:-l|0)+((k|0)>-1?k:-k|0)|0;k=g+1|0;if((k|0)<4){n=n+16|0;i=i+32|0;h=o;g=k}else{break}}c[e+4>>2]=o;hSb(b);o=a;a=b;b=0;g=0;while(1){h=(d[a]|0)-(d[o]|0)|0;i=(d[a+1|0]|0)-(d[o+1|0]|0)|0;n=(d[a+2|0]|0)-(d[o+2|0]|0)|0;k=(d[a+3|0]|0)-(d[o+3|0]|0)|0;p=((h|0)>-1?h:-h|0)+b+((i|0)>-1?i:-i|0)+((n|0)>-1?n:-n|0)+((k|0)>-1?k:-k|0)|0;k=g+1|0;if((k|0)<4){o=o+16|0;a=a+32|0;b=p;g=k}else{break}}c[e+8>>2]=p;return}function xQb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c;c=a;a=0;g=0;while(1){h=(d[c]|0)-(d[f]|0)|0;i=(d[c+1|0]|0)-(d[f+1|0]|0)|0;j=(d[c+2|0]|0)-(d[f+2|0]|0)|0;k=(d[c+3|0]|0)-(d[f+3|0]|0)|0;l=((k|0)>-1?k:-k|0)+(((j|0)>-1?j:-j|0)+(((i|0)>-1?i:-i|0)+(((h|0)>-1?h:-h|0)+a)))|0;h=g+1|0;if((h|0)<4){f=f+e|0;c=c+b|0;a=l;g=h}else{break}}return l|0}function yQb(a,b,d){a=a|0;b=b|0;d=d|0;jSb(b);c[d>>2]=zQb(b,32,a,16)|0;iSb(b);c[d+4>>2]=zQb(b,32,a,16)|0;hSb(b);c[d+8>>2]=zQb(b,32,a,16)|0;return}function zQb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+32|0;h=g|0;j=0;k=e;e=a;while(1){a=(d[e]|0)-(d[k]|0)|0;l=(d[e+1|0]|0)-(d[k+1|0]|0)|0;m=l+a+(a-l<<16)|0;l=(d[e+2|0]|0)-(d[k+2|0]|0)|0;a=(d[e+3|0]|0)-(d[k+3|0]|0)|0;n=a+l+(l-a<<16)|0;c[h+(j<<3)>>2]=n+m;c[h+(j<<3)+4>>2]=m-n;n=j+1|0;if((n|0)<4){j=n;k=k+f|0;e=e+b|0}else{break}}b=c[h>>2]|0;e=c[h+8>>2]|0;f=e+b|0;k=b-e|0;e=c[h+16>>2]|0;b=c[h+24>>2]|0;j=b+e|0;n=e-b|0;b=j+f|0;e=f-j|0;j=n+k|0;f=k-n|0;n=(b>>>15&65537)*65535|0;k=(j>>>15&65537)*65535|0;m=(e>>>15&65537)*65535|0;a=(f>>>15&65537)*65535|0;l=(n+b^n)+(k+j^k)+(m+e^m)+(a+f^a)|0;a=c[h+4>>2]|0;f=c[h+12>>2]|0;m=f+a|0;e=a-f|0;f=c[h+20>>2]|0;a=c[h+28>>2]|0;h=a+f|0;k=f-a|0;a=h+m|0;f=m-h|0;h=k+e|0;m=e-k|0;k=(a>>>15&65537)*65535|0;e=(h>>>15&65537)*65535|0;j=(f>>>15&65537)*65535|0;n=(m>>>15&65537)*65535|0;b=(k+a^k)+(e+h^e)+(j+f^j)+(n+m^n)|0;i=g;return((b>>>16)+((l>>>16)+(l&65535))+(b&65535)|0)>>>1|0}function AQb(a,b,d){a=a|0;b=b|0;d=d|0;$Rb(b);c[d>>2]=tQb(b,32,a,16)|0;aSb(b);c[d+4>>2]=tQb(b,32,a,16)|0;bSb(b);c[d+8>>2]=tQb(b,32,a,16)|0;return}function BQb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;$Rb(b);e=nRb(b,32,a,16)|0;f=b+128|0;g=a+64|0;c[d>>2]=(nRb(f,32,g,16)|0)+e;aSb(b);e=nRb(b,32,a,16)|0;c[d+4>>2]=(nRb(f,32,g,16)|0)+e;bSb(b);e=nRb(b,32,a,16)|0;c[d+8>>2]=(nRb(f,32,g,16)|0)+e;return}function CQb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=nRb(a,b,c,d)|0;return(nRb(a+(b<<2)|0,b,c+(d<<2)|0,d)|0)+e|0}function DQb(a,b,d){a=a|0;b=b|0;d=d|0;dSb(b);c[d>>2]=EQb(b,32,a,16)|0;eSb(b);c[d+4>>2]=EQb(b,32,a,16)|0;fSb(b);c[d+8>>2]=EQb(b,32,a,16)|0;return}function EQb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c;c=a;a=0;g=0;while(1){h=(d[c]|0)-(d[f]|0)|0;i=(d[c+1|0]|0)-(d[f+1|0]|0)|0;j=(d[c+2|0]|0)-(d[f+2|0]|0)|0;k=(d[c+3|0]|0)-(d[f+3|0]|0)|0;l=(d[c+4|0]|0)-(d[f+4|0]|0)|0;m=(d[c+5|0]|0)-(d[f+5|0]|0)|0;n=(d[c+6|0]|0)-(d[f+6|0]|0)|0;o=(d[c+7|0]|0)-(d[f+7|0]|0)|0;p=((o|0)>-1?o:-o|0)+(((n|0)>-1?n:-n|0)+(((m|0)>-1?m:-m|0)+(((l|0)>-1?l:-l|0)+(((k|0)>-1?k:-k|0)+(((j|0)>-1?j:-j|0)+(((i|0)>-1?i:-i|0)+(((h|0)>-1?h:-h|0)+a)))))))|0;h=g+1|0;if((h|0)<16){f=f+e|0;c=c+b|0;a=p;g=h}else{break}}return p|0}function FQb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;dSb(b);e=nRb(b,32,a,16)|0;f=b+128|0;g=a+64|0;h=nRb(f,32,g,16)|0;i=b+256|0;j=a+128|0;k=nRb(i,32,j,16)|0;l=b+384|0;m=a+192|0;c[d>>2]=h+e+k+(nRb(l,32,m,16)|0);eSb(b);k=nRb(b,32,a,16)|0;e=nRb(f,32,g,16)|0;h=nRb(i,32,j,16)|0;c[d+4>>2]=e+k+h+(nRb(l,32,m,16)|0);fSb(b);h=nRb(b,32,a,16)|0;a=nRb(f,32,g,16)|0;g=nRb(i,32,j,16)|0;c[d+8>>2]=a+h+g+(nRb(l,32,m,16)|0);return}function GQb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=nRb(a,b,c,d)|0;f=nRb(a+(b<<2)|0,b,c+(d<<2)|0,d)|0;g=nRb(a+(b<<3)|0,b,c+(d<<3)|0,d)|0;return f+e+g+(nRb(a+(b*12|0)|0,b,c+(d*12|0)|0,d)|0)|0}function HQb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;ZRb(b);f=a;g=b;h=0;i=0;while(1){j=h;k=0;do{l=(d[g+k|0]|0)-(d[f+k|0]|0)|0;j=((l|0)>-1?l:-l|0)+j|0;k=k+1|0;}while((k|0)<16);k=i+1|0;if((k|0)<16){f=f+16|0;g=g+32|0;h=j;i=k}else{break}}c[e>>2]=j;YRb(b);j=a;i=b;h=0;g=0;while(1){m=h;f=0;do{k=(d[i+f|0]|0)-(d[j+f|0]|0)|0;m=((k|0)>-1?k:-k|0)+m|0;f=f+1|0;}while((f|0)<16);f=g+1|0;if((f|0)<16){j=j+16|0;i=i+32|0;h=m;g=f}else{break}}c[e+4>>2]=m;XRb(b);m=a;a=b;b=0;g=0;while(1){n=b;h=0;do{i=(d[a+h|0]|0)-(d[m+h|0]|0)|0;n=((i|0)>-1?i:-i|0)+n|0;h=h+1|0;}while((h|0)<16);h=g+1|0;if((h|0)<16){m=m+16|0;a=a+32|0;b=n;g=h}else{break}}c[e+8>>2]=n;return}function IQb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=c;c=a;a=0;g=0;while(1){h=a;i=0;do{j=(d[c+i|0]|0)-(d[f+i|0]|0)|0;h=((j|0)>-1?j:-j|0)+h|0;i=i+1|0;}while((i|0)<16);i=g+1|0;if((i|0)<16){f=f+e|0;c=c+b|0;a=h;g=i}else{break}}return h|0}function JQb(a,b,d){a=a|0;b=b|0;d=d|0;ZRb(b);c[d>>2]=KQb(b,32,a,16)|0;YRb(b);c[d+4>>2]=KQb(b,32,a,16)|0;XRb(b);c[d+8>>2]=KQb(b,32,a,16)|0;return}function KQb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=nRb(a,b,c,d)|0;f=b<<2;g=d<<2;h=nRb(a+f|0,b,c+g|0,d)|0;i=nRb(a+8|0,b,c+8|0,d)|0;j=nRb(a+(f+8)|0,b,c+(g+8)|0,d)|0;g=b<<3;f=d<<3;k=nRb(a+g|0,b,c+f|0,d)|0;l=b*12|0;m=d*12|0;n=nRb(a+l|0,b,c+m|0,d)|0;o=nRb(a+(g+8)|0,b,c+(f+8)|0,d)|0;return h+e+i+j+k+n+o+(nRb(a+(l+8)|0,b,c+(m+8)|0,d)|0)|0}function LQb(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0.0,K=0.0;k=i;i=g>>2;g=h>>2;if((g|0)<=1){l=0.0;m=i-1|0;n=g-1|0;o=ca(n,m)|0;c[j>>2]=o;return+l}h=i-1|0;p=(h|0)>0;q=a+392|0;r=(i|0)>0;s=a+388|0;a=0;t=0.0;u=k;v=k+(i+3<<4)|0;k=1;w=2;while(1){a:do{if((a|0)>(k|0)){x=a;y=u;z=v}else{if(r){A=a;B=u;C=v}else{D=a;E=u;F=v;while(1){G=D+1|0;if((G|0)>(k|0)){x=w;y=F;z=E;break a}else{H=E;E=F;D=G;F=H}}}while(1){F=ca(A,d)|0;D=ca(A,f)|0;E=0;do{pe[c[s>>2]&1023](b+(E+F<<2)|0,d,e+(E+D<<2)|0,f,C+(E<<4)|0);E=E+2|0;}while((E|0)<(i|0));E=A+1|0;if((E|0)>(k|0)){x=w;y=C;z=B;break}else{D=B;B=C;A=E;C=D}}}}while(0);if(p){I=t;D=0;while(1){E=i-D-1|0;J=I+ +Ae[c[q>>2]&7](y+(D<<4)|0,z+(D<<4)|0,(E|0)>4?4:E);E=D+4|0;if((E|0)<(h|0)){I=J;D=E}else{K=J;break}}}else{K=t}D=k+1|0;if((D|0)<(g|0)){a=x;t=K;u=y;v=z;k=D;w=w+1|0}else{l=K;m=h;break}}n=g-1|0;o=ca(n,m)|0;c[j>>2]=o;return+l}function MQb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=c[a+15144>>2]|0;g=c[f+156>>2]|0;h=c[a+18580>>2]|0;i=c[f+204>>2]|0;f=(ca(g,e)|0)+b<<4;j=i+f|0;k=(ca(h,e)|0)+b|0;l=(c[a+32>>2]|0)-(e<<4)|0;m=(l|0)<32?l:32;l=a+37068|0;n=Ee[c[l>>2]&511](j,g,m)|0;o=g<<1;p=m>>1;m=Ee[c[l>>2]&511](j,o,p)|0;j=(Ee[c[l>>2]&511](i+(f+g)|0,o,p)|0)+m|0;if((b|0)>0){q=j+512-((d[(c[a+19276>>2]|0)+(k-1)|0]|0)<<10)|0}else{q=j}if((e|0)<=0){r=q;s=(r|0)<(n|0);t=s&1;return t|0}r=q+512-((d[(c[a+19276>>2]|0)+(k-h)|0]|0)<<10)|0;s=(r|0)<(n|0);t=s&1;return t|0}function NQb(a,b){a=a|0;b=b|0;mrc(b|0,0,632)|0;c[b>>2]=698;c[b+4>>2]=202;c[b+8>>2]=508;c[b+12>>2]=574;c[b+16>>2]=576;c[b+20>>2]=28;c[b+24>>2]=24;c[b+28>>2]=308;c[b+292>>2]=698;c[b+296>>2]=202;c[b+300>>2]=508;c[b+304>>2]=574;c[b+308>>2]=576;c[b+312>>2]=28;c[b+316>>2]=24;c[b+320>>2]=308;c[b+396>>2]=46;c[b+400>>2]=32;c[b+404>>2]=166;c[b+408>>2]=296;c[b+412>>2]=348;c[b+416>>2]=224;c[b+420>>2]=244;c[b+424>>2]=472;c[b+428>>2]=542;c[b+432>>2]=594;c[b+436>>2]=298;c[b+440>>2]=642;c[b+444>>2]=44;c[b+448>>2]=46;c[b+32>>2]=118;c[b+36>>2]=618;c[b+40>>2]=680;c[b+44>>2]=294;c[b+48>>2]=292;c[b+52>>2]=160;c[b+56>>2]=162;c[b+60>>2]=398;c[b+64>>2]=20;c[b+68>>2]=144;c[b+72>>2]=526;c[b+76>>2]=466;c[b+80>>2]=206;c[b+84>>2]=186;c[b+88>>2]=188;c[b+92>>2]=152;c[b+452>>2]=228;c[b+456>>2]=268;c[b+460>>2]=130;c[b+464>>2]=318;c[b+468>>2]=320;c[b+472>>2]=122;c[b+476>>2]=76;c[b+480>>2]=426;c[b+484>>2]=490;c[b+488>>2]=488;c[b+492>>2]=256;c[b+496>>2]=258;c[b+500>>2]=690;c[b+504>>2]=688;c[b+368>>2]=128;c[b+372>>2]=840;c[b+376>>2]=552;c[b+380>>2]=522;c[b+508>>2]=150;c[b+512>>2]=60;c[b+520>>2]=148;c[b+124>>2]=594;c[b+136>>2]=116;c[b+336>>2]=122;c[b+344>>2]=744;c[b+348>>2]=98;c[b+360>>2]=144;c[b+364>>2]=62;c[b+384>>2]=32;c[b+388>>2]=280;c[b+392>>2]=4;c[b+324>>2]=44;c[b+328>>2]=66;c[b+556>>2]=1e3;c[b+552>>2]=824;c[b+604>>2]=1880;c[b+600>>2]=180;c[b+592>>2]=1510;c[b+588>>2]=748;c[b+580>>2]=1472;c[b+576>>2]=1758;c[b+544>>2]=1092;c[b+540>>2]=1516;c[b+528>>2]=60;c[b+524>>2]=60;c[b+516>>2]=60;c[b+532>>2]=148;return}function OQb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=c;c=a;a=0;g=0;while(1){h=a;i=0;do{j=(d[c+i|0]|0)-(d[f+i|0]|0)|0;h=((j|0)>-1?j:-j|0)+h|0;i=i+1|0;}while((i|0)<16);i=g+1|0;if((i|0)<8){f=f+e|0;c=c+b|0;a=h;g=i}else{break}}return h|0}function PQb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c;c=a;a=0;g=0;while(1){h=(d[c]|0)-(d[f]|0)|0;i=(d[c+1|0]|0)-(d[f+1|0]|0)|0;j=(d[c+2|0]|0)-(d[f+2|0]|0)|0;k=(d[c+3|0]|0)-(d[f+3|0]|0)|0;l=(d[c+4|0]|0)-(d[f+4|0]|0)|0;m=(d[c+5|0]|0)-(d[f+5|0]|0)|0;n=(d[c+6|0]|0)-(d[f+6|0]|0)|0;o=(d[c+7|0]|0)-(d[f+7|0]|0)|0;p=((o|0)>-1?o:-o|0)+(((n|0)>-1?n:-n|0)+(((m|0)>-1?m:-m|0)+(((l|0)>-1?l:-l|0)+(((k|0)>-1?k:-k|0)+(((j|0)>-1?j:-j|0)+(((i|0)>-1?i:-i|0)+(((h|0)>-1?h:-h|0)+a)))))))|0;h=g+1|0;if((h|0)<4){f=f+e|0;c=c+b|0;a=p;g=h}else{break}}return p|0}function QQb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c;c=a;a=0;g=0;while(1){h=(d[c]|0)-(d[f]|0)|0;i=(d[c+1|0]|0)-(d[f+1|0]|0)|0;j=(d[c+2|0]|0)-(d[f+2|0]|0)|0;k=(d[c+3|0]|0)-(d[f+3|0]|0)|0;l=((k|0)>-1?k:-k|0)+(((j|0)>-1?j:-j|0)+(((i|0)>-1?i:-i|0)+(((h|0)>-1?h:-h|0)+a)))|0;h=g+1|0;if((h|0)<8){f=f+e|0;c=c+b|0;a=l;g=h}else{break}}return l|0}function RQb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c;c=a;a=0;g=0;while(1){h=(d[c]|0)-(d[f]|0)|0;i=(d[c+1|0]|0)-(d[f+1|0]|0)|0;j=(d[c+2|0]|0)-(d[f+2|0]|0)|0;k=(d[c+3|0]|0)-(d[f+3|0]|0)|0;l=((k|0)>-1?k:-k|0)+(((j|0)>-1?j:-j|0)+(((i|0)>-1?i:-i|0)+(((h|0)>-1?h:-h|0)+a)))|0;h=g+1|0;if((h|0)<16){f=f+e|0;c=c+b|0;a=l;g=h}else{break}}return l|0}function SQb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=b;b=a;j=0;k=0;while(1){l=j;m=0;do{n=(d[b+m|0]|0)-(d[i+m|0]|0)|0;l=((n|0)>-1?n:-n|0)+l|0;m=m+1|0;}while((m|0)<16);m=k+1|0;if((m|0)<16){i=i+g|0;b=b+16|0;j=l;k=m}else{break}}c[h>>2]=l;l=e;e=a;k=0;j=0;while(1){o=k;b=0;do{i=(d[e+b|0]|0)-(d[l+b|0]|0)|0;o=((i|0)>-1?i:-i|0)+o|0;b=b+1|0;}while((b|0)<16);b=j+1|0;if((b|0)<16){l=l+g|0;e=e+16|0;k=o;j=b}else{break}}c[h+4>>2]=o;o=f;f=a;a=0;j=0;while(1){p=a;k=0;do{e=(d[f+k|0]|0)-(d[o+k|0]|0)|0;p=((e|0)>-1?e:-e|0)+p|0;k=k+1|0;}while((k|0)<16);k=j+1|0;if((k|0)<16){o=o+g|0;f=f+16|0;a=p;j=k}else{break}}c[h+8>>2]=p;return}function TQb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=b;b=a;j=0;k=0;while(1){l=j;m=0;do{n=(d[b+m|0]|0)-(d[i+m|0]|0)|0;l=((n|0)>-1?n:-n|0)+l|0;m=m+1|0;}while((m|0)<16);m=k+1|0;if((m|0)<8){i=i+g|0;b=b+16|0;j=l;k=m}else{break}}c[h>>2]=l;l=e;e=a;k=0;j=0;while(1){o=k;b=0;do{i=(d[e+b|0]|0)-(d[l+b|0]|0)|0;o=((i|0)>-1?i:-i|0)+o|0;b=b+1|0;}while((b|0)<16);b=j+1|0;if((b|0)<8){l=l+g|0;e=e+16|0;k=o;j=b}else{break}}c[h+4>>2]=o;o=f;f=a;a=0;j=0;while(1){p=a;k=0;do{e=(d[f+k|0]|0)-(d[o+k|0]|0)|0;p=((e|0)>-1?e:-e|0)+p|0;k=k+1|0;}while((k|0)<16);k=j+1|0;if((k|0)<8){o=o+g|0;f=f+16|0;a=p;j=k}else{break}}c[h+8>>2]=p;return}function UQb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[g>>2]=EQb(a,16,b,f)|0;c[g+4>>2]=EQb(a,16,d,f)|0;c[g+8>>2]=EQb(a,16,e,f)|0;return}function VQb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[g>>2]=tQb(a,16,b,f)|0;c[g+4>>2]=tQb(a,16,d,f)|0;c[g+8>>2]=tQb(a,16,e,f)|0;return}function WQb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[g>>2]=PQb(a,16,b,f)|0;c[g+4>>2]=PQb(a,16,d,f)|0;c[g+8>>2]=PQb(a,16,e,f)|0;return}function XQb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=b;b=a;j=0;k=0;while(1){l=(d[b]|0)-(d[i]|0)|0;m=(d[b+1|0]|0)-(d[i+1|0]|0)|0;n=(d[b+2|0]|0)-(d[i+2|0]|0)|0;o=(d[b+3|0]|0)-(d[i+3|0]|0)|0;p=((l|0)>-1?l:-l|0)+j+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)|0;o=k+1|0;if((o|0)<8){i=i+g|0;b=b+16|0;j=p;k=o}else{break}}c[h>>2]=p;p=e;e=a;k=0;j=0;while(1){b=(d[e]|0)-(d[p]|0)|0;i=(d[e+1|0]|0)-(d[p+1|0]|0)|0;o=(d[e+2|0]|0)-(d[p+2|0]|0)|0;n=(d[e+3|0]|0)-(d[p+3|0]|0)|0;q=((b|0)>-1?b:-b|0)+k+((i|0)>-1?i:-i|0)+((o|0)>-1?o:-o|0)+((n|0)>-1?n:-n|0)|0;n=j+1|0;if((n|0)<8){p=p+g|0;e=e+16|0;k=q;j=n}else{break}}c[h+4>>2]=q;q=f;f=a;a=0;j=0;while(1){k=(d[f]|0)-(d[q]|0)|0;e=(d[f+1|0]|0)-(d[q+1|0]|0)|0;p=(d[f+2|0]|0)-(d[q+2|0]|0)|0;n=(d[f+3|0]|0)-(d[q+3|0]|0)|0;r=((k|0)>-1?k:-k|0)+a+((e|0)>-1?e:-e|0)+((p|0)>-1?p:-p|0)+((n|0)>-1?n:-n|0)|0;n=j+1|0;if((n|0)<8){q=q+g|0;f=f+16|0;a=r;j=n}else{break}}c[h+8>>2]=r;return}function YQb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=b;b=a;j=0;k=0;while(1){l=(d[b]|0)-(d[i]|0)|0;m=(d[b+1|0]|0)-(d[i+1|0]|0)|0;n=(d[b+2|0]|0)-(d[i+2|0]|0)|0;o=(d[b+3|0]|0)-(d[i+3|0]|0)|0;p=((l|0)>-1?l:-l|0)+j+((m|0)>-1?m:-m|0)+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)|0;o=k+1|0;if((o|0)<4){i=i+g|0;b=b+16|0;j=p;k=o}else{break}}c[h>>2]=p;p=e;e=a;k=0;j=0;while(1){b=(d[e]|0)-(d[p]|0)|0;i=(d[e+1|0]|0)-(d[p+1|0]|0)|0;o=(d[e+2|0]|0)-(d[p+2|0]|0)|0;n=(d[e+3|0]|0)-(d[p+3|0]|0)|0;q=((b|0)>-1?b:-b|0)+k+((i|0)>-1?i:-i|0)+((o|0)>-1?o:-o|0)+((n|0)>-1?n:-n|0)|0;n=j+1|0;if((n|0)<4){p=p+g|0;e=e+16|0;k=q;j=n}else{break}}c[h+4>>2]=q;q=f;f=a;a=0;j=0;while(1){k=(d[f]|0)-(d[q]|0)|0;e=(d[f+1|0]|0)-(d[q+1|0]|0)|0;p=(d[f+2|0]|0)-(d[q+2|0]|0)|0;n=(d[f+3|0]|0)-(d[q+3|0]|0)|0;r=((k|0)>-1?k:-k|0)+a+((e|0)>-1?e:-e|0)+((p|0)>-1?p:-p|0)+((n|0)>-1?n:-n|0)|0;n=j+1|0;if((n|0)<4){q=q+g|0;f=f+16|0;a=r;j=n}else{break}}c[h+8>>2]=r;return}function ZQb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=b;b=a;k=0;l=0;while(1){m=k;n=0;do{o=(d[b+n|0]|0)-(d[j+n|0]|0)|0;m=((o|0)>-1?o:-o|0)+m|0;n=n+1|0;}while((n|0)<16);n=l+1|0;if((n|0)<16){j=j+h|0;b=b+16|0;k=m;l=n}else{break}}c[i>>2]=m;m=e;e=a;l=0;k=0;while(1){p=l;b=0;do{j=(d[e+b|0]|0)-(d[m+b|0]|0)|0;p=((j|0)>-1?j:-j|0)+p|0;b=b+1|0;}while((b|0)<16);b=k+1|0;if((b|0)<16){m=m+h|0;e=e+16|0;l=p;k=b}else{break}}c[i+4>>2]=p;p=f;f=a;k=0;l=0;while(1){q=k;e=0;do{m=(d[f+e|0]|0)-(d[p+e|0]|0)|0;q=((m|0)>-1?m:-m|0)+q|0;e=e+1|0;}while((e|0)<16);e=l+1|0;if((e|0)<16){p=p+h|0;f=f+16|0;k=q;l=e}else{break}}c[i+8>>2]=q;q=g;g=a;a=0;l=0;while(1){r=a;k=0;do{f=(d[g+k|0]|0)-(d[q+k|0]|0)|0;r=((f|0)>-1?f:-f|0)+r|0;k=k+1|0;}while((k|0)<16);k=l+1|0;if((k|0)<16){q=q+h|0;g=g+16|0;a=r;l=k}else{break}}c[i+12>>2]=r;return}function _Qb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=b;b=a;k=0;l=0;while(1){m=k;n=0;do{o=(d[b+n|0]|0)-(d[j+n|0]|0)|0;m=((o|0)>-1?o:-o|0)+m|0;n=n+1|0;}while((n|0)<16);n=l+1|0;if((n|0)<8){j=j+h|0;b=b+16|0;k=m;l=n}else{break}}c[i>>2]=m;m=e;e=a;l=0;k=0;while(1){p=l;b=0;do{j=(d[e+b|0]|0)-(d[m+b|0]|0)|0;p=((j|0)>-1?j:-j|0)+p|0;b=b+1|0;}while((b|0)<16);b=k+1|0;if((b|0)<8){m=m+h|0;e=e+16|0;l=p;k=b}else{break}}c[i+4>>2]=p;p=f;f=a;k=0;l=0;while(1){q=k;e=0;do{m=(d[f+e|0]|0)-(d[p+e|0]|0)|0;q=((m|0)>-1?m:-m|0)+q|0;e=e+1|0;}while((e|0)<16);e=l+1|0;if((e|0)<8){p=p+h|0;f=f+16|0;k=q;l=e}else{break}}c[i+8>>2]=q;q=g;g=a;a=0;l=0;while(1){r=a;k=0;do{f=(d[g+k|0]|0)-(d[q+k|0]|0)|0;r=((f|0)>-1?f:-f|0)+r|0;k=k+1|0;}while((k|0)<16);k=l+1|0;if((k|0)<8){q=q+h|0;g=g+16|0;a=r;l=k}else{break}}c[i+12>>2]=r;return}function $Qb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;c[h>>2]=EQb(a,16,b,g)|0;c[h+4>>2]=EQb(a,16,d,g)|0;c[h+8>>2]=EQb(a,16,e,g)|0;c[h+12>>2]=EQb(a,16,f,g)|0;return}function aRb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;c[h>>2]=tQb(a,16,b,g)|0;c[h+4>>2]=tQb(a,16,d,g)|0;c[h+8>>2]=tQb(a,16,e,g)|0;c[h+12>>2]=tQb(a,16,f,g)|0;return}function bRb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;c[h>>2]=PQb(a,16,b,g)|0;c[h+4>>2]=PQb(a,16,d,g)|0;c[h+8>>2]=PQb(a,16,e,g)|0;c[h+12>>2]=PQb(a,16,f,g)|0;return}function cRb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=b;b=a;k=0;l=0;while(1){m=(d[b]|0)-(d[j]|0)|0;n=(d[b+1|0]|0)-(d[j+1|0]|0)|0;o=(d[b+2|0]|0)-(d[j+2|0]|0)|0;p=(d[b+3|0]|0)-(d[j+3|0]|0)|0;q=((m|0)>-1?m:-m|0)+k+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)|0;p=l+1|0;if((p|0)<8){j=j+h|0;b=b+16|0;k=q;l=p}else{break}}c[i>>2]=q;q=e;e=a;l=0;k=0;while(1){b=(d[e]|0)-(d[q]|0)|0;j=(d[e+1|0]|0)-(d[q+1|0]|0)|0;p=(d[e+2|0]|0)-(d[q+2|0]|0)|0;o=(d[e+3|0]|0)-(d[q+3|0]|0)|0;r=((b|0)>-1?b:-b|0)+l+((j|0)>-1?j:-j|0)+((p|0)>-1?p:-p|0)+((o|0)>-1?o:-o|0)|0;o=k+1|0;if((o|0)<8){q=q+h|0;e=e+16|0;l=r;k=o}else{break}}c[i+4>>2]=r;r=f;f=a;k=0;l=0;while(1){e=(d[f]|0)-(d[r]|0)|0;q=(d[f+1|0]|0)-(d[r+1|0]|0)|0;o=(d[f+2|0]|0)-(d[r+2|0]|0)|0;p=(d[f+3|0]|0)-(d[r+3|0]|0)|0;s=((e|0)>-1?e:-e|0)+k+((q|0)>-1?q:-q|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)|0;p=l+1|0;if((p|0)<8){r=r+h|0;f=f+16|0;k=s;l=p}else{break}}c[i+8>>2]=s;s=g;g=a;a=0;l=0;while(1){k=(d[g]|0)-(d[s]|0)|0;f=(d[g+1|0]|0)-(d[s+1|0]|0)|0;r=(d[g+2|0]|0)-(d[s+2|0]|0)|0;p=(d[g+3|0]|0)-(d[s+3|0]|0)|0;t=((k|0)>-1?k:-k|0)+a+((f|0)>-1?f:-f|0)+((r|0)>-1?r:-r|0)+((p|0)>-1?p:-p|0)|0;p=l+1|0;if((p|0)<8){s=s+h|0;g=g+16|0;a=t;l=p}else{break}}c[i+12>>2]=t;return}function dRb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=b;b=a;k=0;l=0;while(1){m=(d[b]|0)-(d[j]|0)|0;n=(d[b+1|0]|0)-(d[j+1|0]|0)|0;o=(d[b+2|0]|0)-(d[j+2|0]|0)|0;p=(d[b+3|0]|0)-(d[j+3|0]|0)|0;q=((m|0)>-1?m:-m|0)+k+((n|0)>-1?n:-n|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)|0;p=l+1|0;if((p|0)<4){j=j+h|0;b=b+16|0;k=q;l=p}else{break}}c[i>>2]=q;q=e;e=a;l=0;k=0;while(1){b=(d[e]|0)-(d[q]|0)|0;j=(d[e+1|0]|0)-(d[q+1|0]|0)|0;p=(d[e+2|0]|0)-(d[q+2|0]|0)|0;o=(d[e+3|0]|0)-(d[q+3|0]|0)|0;r=((b|0)>-1?b:-b|0)+l+((j|0)>-1?j:-j|0)+((p|0)>-1?p:-p|0)+((o|0)>-1?o:-o|0)|0;o=k+1|0;if((o|0)<4){q=q+h|0;e=e+16|0;l=r;k=o}else{break}}c[i+4>>2]=r;r=f;f=a;k=0;l=0;while(1){e=(d[f]|0)-(d[r]|0)|0;q=(d[f+1|0]|0)-(d[r+1|0]|0)|0;o=(d[f+2|0]|0)-(d[r+2|0]|0)|0;p=(d[f+3|0]|0)-(d[r+3|0]|0)|0;s=((e|0)>-1?e:-e|0)+k+((q|0)>-1?q:-q|0)+((o|0)>-1?o:-o|0)+((p|0)>-1?p:-p|0)|0;p=l+1|0;if((p|0)<4){r=r+h|0;f=f+16|0;k=s;l=p}else{break}}c[i+8>>2]=s;s=g;g=a;a=0;l=0;while(1){k=(d[g]|0)-(d[s]|0)|0;f=(d[g+1|0]|0)-(d[s+1|0]|0)|0;r=(d[g+2|0]|0)-(d[s+2|0]|0)|0;p=(d[g+3|0]|0)-(d[s+3|0]|0)|0;t=((k|0)>-1?k:-k|0)+a+((f|0)>-1?f:-f|0)+((r|0)>-1?r:-r|0)+((p|0)>-1?p:-p|0)|0;p=l+1|0;if((p|0)<4){s=s+h|0;g=g+16|0;a=t;l=p}else{break}}c[i+12>>2]=t;return}function eRb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=c;c=0;g=0;h=a;while(1){i=c;a=0;do{j=(d[h+a|0]|0)-(d[f+a|0]|0)|0;i=(ca(j,j)|0)+i|0;a=a+1|0;}while((a|0)<16);a=g+1|0;if((a|0)<16){f=f+e|0;c=i;g=a;h=h+b|0}else{break}}return i|0}function fRb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=0;g=0;while(1){h=(d[a+g|0]|0)-(d[c+g|0]|0)|0;i=(ca(h,h)|0)+f|0;h=g+1|0;if((h|0)<16){f=i;g=h}else{j=i;k=0;break}}do{g=(d[a+(k+b)|0]|0)-(d[c+(k+e)|0]|0)|0;j=(ca(g,g)|0)+j|0;k=k+1|0;}while((k|0)<16);k=b<<1;g=e<<1;f=j;j=0;do{i=(d[a+(k+j)|0]|0)-(d[c+(g+j)|0]|0)|0;f=(ca(i,i)|0)+f|0;j=j+1|0;}while((j|0)<16);j=k+b|0;k=g+e|0;g=f;f=0;do{i=(d[a+(j+f)|0]|0)-(d[c+(k+f)|0]|0)|0;g=(ca(i,i)|0)+g|0;f=f+1|0;}while((f|0)<16);f=j+b|0;j=k+e|0;k=g;g=0;do{i=(d[a+(f+g)|0]|0)-(d[c+(j+g)|0]|0)|0;k=(ca(i,i)|0)+k|0;g=g+1|0;}while((g|0)<16);g=f+b|0;f=j+e|0;j=k;k=0;do{i=(d[a+(g+k)|0]|0)-(d[c+(f+k)|0]|0)|0;j=(ca(i,i)|0)+j|0;k=k+1|0;}while((k|0)<16);k=g+b|0;g=f+e|0;f=j;j=0;do{i=(d[a+(k+j)|0]|0)-(d[c+(g+j)|0]|0)|0;f=(ca(i,i)|0)+f|0;j=j+1|0;}while((j|0)<16);j=k+b|0;b=g+e|0;e=f;f=0;do{g=(d[a+(j+f)|0]|0)-(d[c+(b+f)|0]|0)|0;e=(ca(g,g)|0)+e|0;f=f+1|0;}while((f|0)<16);return e|0}function gRb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c;c=0;g=0;h=a;while(1){a=(d[h]|0)-(d[f]|0)|0;i=(ca(a,a)|0)+c|0;a=(d[h+1|0]|0)-(d[f+1|0]|0)|0;j=(ca(a,a)|0)+i|0;i=(d[h+2|0]|0)-(d[f+2|0]|0)|0;a=(ca(i,i)|0)+j|0;j=(d[h+3|0]|0)-(d[f+3|0]|0)|0;i=(ca(j,j)|0)+a|0;a=(d[h+4|0]|0)-(d[f+4|0]|0)|0;j=(ca(a,a)|0)+i|0;i=(d[h+5|0]|0)-(d[f+5|0]|0)|0;a=(ca(i,i)|0)+j|0;j=(d[h+6|0]|0)-(d[f+6|0]|0)|0;i=(ca(j,j)|0)+a|0;a=(d[h+7|0]|0)-(d[f+7|0]|0)|0;k=(ca(a,a)|0)+i|0;i=g+1|0;if((i|0)<16){f=f+e|0;c=k;g=i;h=h+b|0}else{break}}return k|0}function hRb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c;c=0;g=0;h=a;while(1){a=(d[h]|0)-(d[f]|0)|0;i=(ca(a,a)|0)+c|0;a=(d[h+1|0]|0)-(d[f+1|0]|0)|0;j=(ca(a,a)|0)+i|0;i=(d[h+2|0]|0)-(d[f+2|0]|0)|0;a=(ca(i,i)|0)+j|0;j=(d[h+3|0]|0)-(d[f+3|0]|0)|0;i=(ca(j,j)|0)+a|0;a=(d[h+4|0]|0)-(d[f+4|0]|0)|0;j=(ca(a,a)|0)+i|0;i=(d[h+5|0]|0)-(d[f+5|0]|0)|0;a=(ca(i,i)|0)+j|0;j=(d[h+6|0]|0)-(d[f+6|0]|0)|0;i=(ca(j,j)|0)+a|0;a=(d[h+7|0]|0)-(d[f+7|0]|0)|0;k=(ca(a,a)|0)+i|0;i=g+1|0;if((i|0)<8){f=f+e|0;c=k;g=i;h=h+b|0}else{break}}return k|0}function iRb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c;c=0;g=0;h=a;while(1){a=(d[h]|0)-(d[f]|0)|0;i=(ca(a,a)|0)+c|0;a=(d[h+1|0]|0)-(d[f+1|0]|0)|0;j=(ca(a,a)|0)+i|0;i=(d[h+2|0]|0)-(d[f+2|0]|0)|0;a=(ca(i,i)|0)+j|0;j=(d[h+3|0]|0)-(d[f+3|0]|0)|0;i=(ca(j,j)|0)+a|0;a=(d[h+4|0]|0)-(d[f+4|0]|0)|0;j=(ca(a,a)|0)+i|0;i=(d[h+5|0]|0)-(d[f+5|0]|0)|0;a=(ca(i,i)|0)+j|0;j=(d[h+6|0]|0)-(d[f+6|0]|0)|0;i=(ca(j,j)|0)+a|0;a=(d[h+7|0]|0)-(d[f+7|0]|0)|0;k=(ca(a,a)|0)+i|0;i=g+1|0;if((i|0)<4){f=f+e|0;c=k;g=i;h=h+b|0}else{break}}return k|0}function jRb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c;c=0;g=0;h=a;while(1){a=(d[h]|0)-(d[f]|0)|0;i=(ca(a,a)|0)+c|0;a=(d[h+1|0]|0)-(d[f+1|0]|0)|0;j=(ca(a,a)|0)+i|0;i=(d[h+2|0]|0)-(d[f+2|0]|0)|0;a=(ca(i,i)|0)+j|0;j=(d[h+3|0]|0)-(d[f+3|0]|0)|0;k=(ca(j,j)|0)+a|0;a=g+1|0;if((a|0)<8){f=f+e|0;c=k;g=a;h=h+b|0}else{break}}return k|0}function kRb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=(d[a]|0)-(d[c]|0)|0;g=ca(f,f)|0;f=(d[a+1|0]|0)-(d[c+1|0]|0)|0;h=(ca(f,f)|0)+g|0;g=(d[a+2|0]|0)-(d[c+2|0]|0)|0;f=(ca(g,g)|0)+h|0;h=(d[a+3|0]|0)-(d[c+3|0]|0)|0;g=(ca(h,h)|0)+f|0;f=(d[a+b|0]|0)-(d[c+e|0]|0)|0;h=(ca(f,f)|0)+g|0;g=(d[a+(b+1)|0]|0)-(d[c+(e+1)|0]|0)|0;f=(ca(g,g)|0)+h|0;h=(d[a+(b+2)|0]|0)-(d[c+(e+2)|0]|0)|0;g=(ca(h,h)|0)+f|0;f=(d[a+(b+3)|0]|0)-(d[c+(e+3)|0]|0)|0;h=(ca(f,f)|0)+g|0;g=b<<1;f=e<<1;i=(d[a+g|0]|0)-(d[c+f|0]|0)|0;j=(ca(i,i)|0)+h|0;h=(d[a+(g|1)|0]|0)-(d[c+(f|1)|0]|0)|0;i=(ca(h,h)|0)+j|0;j=(d[a+(g+2)|0]|0)-(d[c+(f+2)|0]|0)|0;h=(ca(j,j)|0)+i|0;i=(d[a+(g+3)|0]|0)-(d[c+(f+3)|0]|0)|0;j=(ca(i,i)|0)+h|0;h=g+b|0;b=f+e|0;e=(d[a+h|0]|0)-(d[c+b|0]|0)|0;f=(ca(e,e)|0)+j|0;j=(d[a+(h+1)|0]|0)-(d[c+(b+1)|0]|0)|0;e=(ca(j,j)|0)+f|0;f=(d[a+(h+2)|0]|0)-(d[c+(b+2)|0]|0)|0;j=(ca(f,f)|0)+e|0;e=(d[a+(h+3)|0]|0)-(d[c+(b+3)|0]|0)|0;return(ca(e,e)|0)+j|0}function lRb(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c;c=0;g=0;h=a;while(1){a=(d[h]|0)-(d[f]|0)|0;i=(ca(a,a)|0)+c|0;a=(d[h+1|0]|0)-(d[f+1|0]|0)|0;j=(ca(a,a)|0)+i|0;i=(d[h+2|0]|0)-(d[f+2|0]|0)|0;a=(ca(i,i)|0)+j|0;j=(d[h+3|0]|0)-(d[f+3|0]|0)|0;k=(ca(j,j)|0)+a|0;a=g+1|0;if((a|0)<16){f=f+e|0;c=k;g=a;h=h+b|0}else{break}}return k|0}function mRb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=nRb(a,b,c,d)|0;f=b<<2;g=d<<2;h=nRb(a+f|0,b,c+g|0,d)|0;i=nRb(a+8|0,b,c+8|0,d)|0;return h+e+i+(nRb(a+(f+8)|0,b,c+(g+8)|0,d)|0)|0}function nRb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+64|0;h=g|0;j=0;k=e;e=a;while(1){a=((d[e+4|0]|0)-(d[k+4|0]|0)<<16)+((d[e]|0)-(d[k]|0))|0;l=((d[e+5|0]|0)-(d[k+5|0]|0)<<16)+((d[e+1|0]|0)-(d[k+1|0]|0))|0;m=((d[e+6|0]|0)-(d[k+6|0]|0)<<16)+((d[e+2|0]|0)-(d[k+2|0]|0))|0;n=((d[e+7|0]|0)-(d[k+7|0]|0)<<16)+((d[e+3|0]|0)-(d[k+3|0]|0))|0;o=l+a|0;p=a-l|0;l=n+m|0;a=m-n|0;c[h+(j<<4)>>2]=l+o;c[h+(j<<4)+8>>2]=o-l;c[h+(j<<4)+4>>2]=a+p;c[h+(j<<4)+12>>2]=p-a;a=j+1|0;if((a|0)<4){j=a;k=k+f|0;e=e+b|0}else{q=0;r=0;break}}do{b=c[h+(r<<2)>>2]|0;e=c[h+16+(r<<2)>>2]|0;f=e+b|0;k=b-e|0;e=c[h+32+(r<<2)>>2]|0;b=c[h+48+(r<<2)>>2]|0;j=b+e|0;a=e-b|0;b=j+f|0;e=f-j|0;j=a+k|0;f=k-a|0;a=(b>>>15&65537)*65535|0;k=(j>>>15&65537)*65535|0;p=(e>>>15&65537)*65535|0;l=(f>>>15&65537)*65535|0;q=(k+j^k)+q+(a+b^a)+(p+e^p)+(l+f^l)|0;r=r+1|0;}while((r|0)<4);i=g;return((q&65535)+(q>>>16)|0)>>>1|0}function oRb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=zQb(a,b,c,d)|0;return(zQb(a+(b<<2)|0,b,c+(d<<2)|0,d)|0)+e|0}function pRb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=zQb(a,b,c,d)|0;f=zQb(a+(b<<2)|0,b,c+(d<<2)|0,d)|0;g=zQb(a+(b<<3)|0,b,c+(d<<3)|0,d)|0;return f+e+g+(zQb(a+(b*12|0)|0,b,c+(d*12|0)|0,d)|0)|0}function qRb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[g>>2]=KQb(a,16,b,f)|0;c[g+4>>2]=KQb(a,16,d,f)|0;c[g+8>>2]=KQb(a,16,e,f)|0;return}function rRb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=nRb(a,16,b,f)|0;i=a+64|0;j=f<<2;k=nRb(i,16,b+j|0,f)|0;l=a+8|0;m=nRb(l,16,b+8|0,f)|0;n=a+72|0;o=j+8|0;c[g>>2]=k+h+m+(nRb(n,16,b+o|0,f)|0);b=nRb(a,16,d,f)|0;m=nRb(i,16,d+j|0,f)|0;h=nRb(l,16,d+8|0,f)|0;c[g+4>>2]=m+b+h+(nRb(n,16,d+o|0,f)|0);d=nRb(a,16,e,f)|0;a=nRb(i,16,e+j|0,f)|0;j=nRb(l,16,e+8|0,f)|0;c[g+8>>2]=a+d+j+(nRb(n,16,e+o|0,f)|0);return}function sRb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=nRb(a,16,b,f)|0;i=a+64|0;j=f<<2;k=nRb(i,16,b+j|0,f)|0;l=a+128|0;m=f<<3;n=nRb(l,16,b+m|0,f)|0;o=a+192|0;p=f*12|0;c[g>>2]=k+h+n+(nRb(o,16,b+p|0,f)|0);b=nRb(a,16,d,f)|0;n=nRb(i,16,d+j|0,f)|0;h=nRb(l,16,d+m|0,f)|0;c[g+4>>2]=n+b+h+(nRb(o,16,d+p|0,f)|0);d=nRb(a,16,e,f)|0;a=nRb(i,16,e+j|0,f)|0;j=nRb(l,16,e+m|0,f)|0;c[g+8>>2]=a+d+j+(nRb(o,16,e+p|0,f)|0);return}function tRb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=nRb(a,16,b,f)|0;i=a+64|0;j=f<<2;c[g>>2]=(nRb(i,16,b+j|0,f)|0)+h;h=nRb(a,16,d,f)|0;c[g+4>>2]=(nRb(i,16,d+j|0,f)|0)+h;h=nRb(a,16,e,f)|0;c[g+8>>2]=(nRb(i,16,e+j|0,f)|0)+h;return}function uRb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[g>>2]=nRb(a,16,b,f)|0;c[g+4>>2]=nRb(a,16,d,f)|0;c[g+8>>2]=nRb(a,16,e,f)|0;return}function vRb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=zQb(a,16,b,f)|0;i=a+64|0;j=f<<2;c[g>>2]=(zQb(i,16,b+j|0,f)|0)+h;h=zQb(a,16,d,f)|0;c[g+4>>2]=(zQb(i,16,d+j|0,f)|0)+h;h=zQb(a,16,e,f)|0;c[g+8>>2]=(zQb(i,16,e+j|0,f)|0)+h;return}function wRb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[g>>2]=zQb(a,16,b,f)|0;c[g+4>>2]=zQb(a,16,d,f)|0;c[g+8>>2]=zQb(a,16,e,f)|0;return}function xRb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;c[h>>2]=KQb(a,16,b,g)|0;c[h+4>>2]=KQb(a,16,d,g)|0;c[h+8>>2]=KQb(a,16,e,g)|0;c[h+12>>2]=KQb(a,16,f,g)|0;return}function yRb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=nRb(a,16,b,g)|0;j=a+64|0;k=g<<2;l=nRb(j,16,b+k|0,g)|0;m=a+8|0;n=nRb(m,16,b+8|0,g)|0;o=a+72|0;p=k+8|0;c[h>>2]=l+i+n+(nRb(o,16,b+p|0,g)|0);b=nRb(a,16,d,g)|0;n=nRb(j,16,d+k|0,g)|0;i=nRb(m,16,d+8|0,g)|0;c[h+4>>2]=n+b+i+(nRb(o,16,d+p|0,g)|0);d=nRb(a,16,e,g)|0;i=nRb(j,16,e+k|0,g)|0;b=nRb(m,16,e+8|0,g)|0;c[h+8>>2]=i+d+b+(nRb(o,16,e+p|0,g)|0);e=nRb(a,16,f,g)|0;a=nRb(j,16,f+k|0,g)|0;k=nRb(m,16,f+8|0,g)|0;c[h+12>>2]=a+e+k+(nRb(o,16,f+p|0,g)|0);return}function zRb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=nRb(a,16,b,g)|0;j=a+64|0;k=g<<2;l=nRb(j,16,b+k|0,g)|0;m=a+128|0;n=g<<3;o=nRb(m,16,b+n|0,g)|0;p=a+192|0;q=g*12|0;c[h>>2]=l+i+o+(nRb(p,16,b+q|0,g)|0);b=nRb(a,16,d,g)|0;o=nRb(j,16,d+k|0,g)|0;i=nRb(m,16,d+n|0,g)|0;c[h+4>>2]=o+b+i+(nRb(p,16,d+q|0,g)|0);d=nRb(a,16,e,g)|0;i=nRb(j,16,e+k|0,g)|0;b=nRb(m,16,e+n|0,g)|0;c[h+8>>2]=i+d+b+(nRb(p,16,e+q|0,g)|0);e=nRb(a,16,f,g)|0;a=nRb(j,16,f+k|0,g)|0;k=nRb(m,16,f+n|0,g)|0;c[h+12>>2]=a+e+k+(nRb(p,16,f+q|0,g)|0);return}function ARb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=nRb(a,16,b,g)|0;j=a+64|0;k=g<<2;c[h>>2]=(nRb(j,16,b+k|0,g)|0)+i;i=nRb(a,16,d,g)|0;c[h+4>>2]=(nRb(j,16,d+k|0,g)|0)+i;i=nRb(a,16,e,g)|0;c[h+8>>2]=(nRb(j,16,e+k|0,g)|0)+i;i=nRb(a,16,f,g)|0;c[h+12>>2]=(nRb(j,16,f+k|0,g)|0)+i;return}function BRb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;c[h>>2]=nRb(a,16,b,g)|0;c[h+4>>2]=nRb(a,16,d,g)|0;c[h+8>>2]=nRb(a,16,e,g)|0;c[h+12>>2]=nRb(a,16,f,g)|0;return}function CRb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=zQb(a,16,b,g)|0;j=a+64|0;k=g<<2;c[h>>2]=(zQb(j,16,b+k|0,g)|0)+i;i=zQb(a,16,d,g)|0;c[h+4>>2]=(zQb(j,16,d+k|0,g)|0)+i;i=zQb(a,16,e,g)|0;c[h+8>>2]=(zQb(j,16,e+k|0,g)|0)+i;i=zQb(a,16,f,g)|0;c[h+12>>2]=(zQb(j,16,f+k|0,g)|0)+i;return}function DRb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;c[h>>2]=zQb(a,16,b,g)|0;c[h+4>>2]=zQb(a,16,d,g)|0;c[h+8>>2]=zQb(a,16,e,g)|0;c[h+12>>2]=zQb(a,16,f,g)|0;return}function ERb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=WRb(a,b)|0;d=G;e=WRb(a+8|0,b)|0;f=wrc(e,G,c,d)|0;d=G;c=b<<3;e=WRb(a+c|0,b)|0;g=wrc(f,d,e,G)|0;e=G;d=WRb(a+(c+8)|0,b)|0;b=wrc(g,e,d,G)|0;return(G=G>>>2|0<<30|0,b>>>1|0)|0}function FRb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=WRb(a,b)|0;d=G;e=WRb(a+8|0,b)|0;b=wrc(e,G,c,d)|0;return(G=G>>>2|0<<30|0,b>>>1|0)|0}function GRb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=WRb(a,b)|0;d=G;e=WRb(a+(b<<3)|0,b)|0;b=wrc(e,G,c,d)|0;return(G=G>>>2|0<<30|0,b>>>1|0)|0}function HRb(a,b){a=a|0;b=b|0;var c=0;c=WRb(a,b)|0;return(G=G>>>2|0<<30|0,c>>>1|0)|0}function IRb(a,d,f,g,h,i,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((i|0)<=0){k=0;return k|0}l=c[a>>2]|0;m=c[a+4>>2]|0;n=c[a+8>>2]|0;o=c[a+12>>2]|0;a=f+8|0;p=0;q=0;r=d;while(1){d=l-(e[r>>1]|0)|0;s=m-(e[r+16>>1]|0)|0;t=n-(e[r+(f<<1)>>1]|0)|0;u=o-(e[r+(a<<1)>>1]|0)|0;if((((s|0)>-1?s:-s|0)+((d|0)>-1?d:-d|0)+((t|0)>-1?t:-t|0)+(e[g+(q<<1)>>1]|0)+((u|0)>-1?u:-u|0)|0)<(j|0)){b[h+(p<<1)>>1]=q;v=p+1|0}else{v=p}u=q+1|0;if((u|0)<(i|0)){p=v;q=u;r=r+2|0}else{k=v;break}}return k|0}function JRb(a,d,f,g,h,i,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((i|0)<=0){k=0;return k|0}l=c[a>>2]|0;m=c[a+4>>2]|0;a=0;n=0;o=d;while(1){d=l-(e[o>>1]|0)|0;p=m-(e[o+(f<<1)>>1]|0)|0;if(((e[g+(n<<1)>>1]|0)+((d|0)>-1?d:-d|0)+((p|0)>-1?p:-p|0)|0)<(j|0)){b[h+(a<<1)>>1]=n;q=a+1|0}else{q=a}p=n+1|0;if((p|0)<(i|0)){a=q;n=p;o=o+2|0}else{k=q;break}}return k|0}function KRb(a,d,f,g,h,i,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;if((i|0)<=0){k=0;return k|0}f=c[a>>2]|0;a=0;l=0;m=d;while(1){d=f-(e[m>>1]|0)|0;if((((d|0)>-1?d:-d|0)+(e[g+(l<<1)>>1]|0)|0)<(j|0)){b[h+(a<<1)>>1]=l;n=a+1|0}else{n=a}d=l+1|0;if((d|0)<(i|0)){a=n;l=d;m=m+2|0}else{k=n;break}}return k|0}function LRb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=VRb(a,b,c,d)|0;f=VRb(a+8|0,b,c+8|0,d)|0;g=b<<3;h=d<<3;i=VRb(a+g|0,b,c+h|0,d)|0;return e+2+f+i+(VRb(a+(g+8)|0,b,c+(h+8)|0,d)|0)>>2|0}function MRb(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;c=a;a=0;e=0;f=0;while(1){g=d[c]|0;h=(ca(g,g)|0)+e|0;i=d[c+1|0]|0;j=(ca(i,i)|0)+h|0;h=d[c+2|0]|0;k=(ca(h,h)|0)+j|0;j=d[c+3|0]|0;l=(ca(j,j)|0)+k|0;k=d[c+4|0]|0;m=(ca(k,k)|0)+l|0;l=d[c+5|0]|0;n=(ca(l,l)|0)+m|0;m=d[c+6|0]|0;o=(ca(m,m)|0)+n|0;n=d[c+7|0]|0;p=(ca(n,n)|0)+o|0;o=d[c+8|0]|0;q=(ca(o,o)|0)+p|0;p=d[c+9|0]|0;r=(ca(p,p)|0)+q|0;q=d[c+10|0]|0;s=(ca(q,q)|0)+r|0;r=d[c+11|0]|0;t=(ca(r,r)|0)+s|0;s=d[c+12|0]|0;u=(ca(s,s)|0)+t|0;t=d[c+13|0]|0;v=(ca(t,t)|0)+u|0;u=d[c+14|0]|0;w=(ca(u,u)|0)+v|0;v=d[c+15|0]|0;x=v+(u+(t+(s+(r+(q+(p+(o+(n+(m+(l+(k+(j+(h+(i+(g+a)))))))))))))))|0;y=(ca(v,v)|0)+w|0;w=f+1|0;if((w|0)<16){c=c+b|0;a=x;e=y;f=w}else{break}}return(G=y|0,x|0)|0}function NRb(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=a;a=0;e=0;f=0;while(1){g=d[c]|0;h=(ca(g,g)|0)+e|0;i=d[c+1|0]|0;j=(ca(i,i)|0)+h|0;h=d[c+2|0]|0;k=(ca(h,h)|0)+j|0;j=d[c+3|0]|0;l=(ca(j,j)|0)+k|0;k=d[c+4|0]|0;m=(ca(k,k)|0)+l|0;l=d[c+5|0]|0;n=(ca(l,l)|0)+m|0;m=d[c+6|0]|0;o=(ca(m,m)|0)+n|0;n=d[c+7|0]|0;p=n+(m+(l+(k+(j+(h+(i+(g+a)))))))|0;q=(ca(n,n)|0)+o|0;o=f+1|0;if((o|0)<16){c=c+b|0;a=p;e=q;f=o}else{break}}return(G=q|0,p|0)|0}function ORb(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=a;a=0;e=0;f=0;while(1){g=d[c]|0;h=(ca(g,g)|0)+e|0;i=d[c+1|0]|0;j=(ca(i,i)|0)+h|0;h=d[c+2|0]|0;k=(ca(h,h)|0)+j|0;j=d[c+3|0]|0;l=(ca(j,j)|0)+k|0;k=d[c+4|0]|0;m=(ca(k,k)|0)+l|0;l=d[c+5|0]|0;n=(ca(l,l)|0)+m|0;m=d[c+6|0]|0;o=(ca(m,m)|0)+n|0;n=d[c+7|0]|0;p=n+(m+(l+(k+(j+(h+(i+(g+a)))))))|0;q=(ca(n,n)|0)+o|0;o=f+1|0;if((o|0)<8){c=c+b|0;a=p;e=q;f=o}else{break}}return(G=q|0,p|0)|0}function PRb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=e;e=0;i=0;j=0;k=a;while(1){a=(d[k]|0)-(d[h]|0)|0;l=(ca(a,a)|0)+i|0;m=(d[k+1|0]|0)-(d[h+1|0]|0)|0;n=(ca(m,m)|0)+l|0;l=(d[k+2|0]|0)-(d[h+2|0]|0)|0;o=(ca(l,l)|0)+n|0;n=(d[k+3|0]|0)-(d[h+3|0]|0)|0;p=(ca(n,n)|0)+o|0;o=(d[k+4|0]|0)-(d[h+4|0]|0)|0;q=(ca(o,o)|0)+p|0;p=(d[k+5|0]|0)-(d[h+5|0]|0)|0;r=(ca(p,p)|0)+q|0;q=(d[k+6|0]|0)-(d[h+6|0]|0)|0;s=(ca(q,q)|0)+r|0;r=(d[k+7|0]|0)-(d[h+7|0]|0)|0;t=r+(q+(p+(o+(n+(l+(m+(a+e)))))))|0;u=(ca(r,r)|0)+s|0;s=j+1|0;if((s|0)<16){h=h+f|0;e=t;i=u;j=s;k=k+b|0}else{break}}b=(t|0)>-1?t:-t|0;t=0;k=Erc(b,t,b,t)|0;t=G;b=xrc(u,0,k>>>7|t<<25,t>>>7|0<<25)|0;c[g>>2]=u;return b|0}function QRb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=e;e=0;i=0;j=0;k=a;while(1){a=(d[k]|0)-(d[h]|0)|0;l=(ca(a,a)|0)+i|0;m=(d[k+1|0]|0)-(d[h+1|0]|0)|0;n=(ca(m,m)|0)+l|0;l=(d[k+2|0]|0)-(d[h+2|0]|0)|0;o=(ca(l,l)|0)+n|0;n=(d[k+3|0]|0)-(d[h+3|0]|0)|0;p=(ca(n,n)|0)+o|0;o=(d[k+4|0]|0)-(d[h+4|0]|0)|0;q=(ca(o,o)|0)+p|0;p=(d[k+5|0]|0)-(d[h+5|0]|0)|0;r=(ca(p,p)|0)+q|0;q=(d[k+6|0]|0)-(d[h+6|0]|0)|0;s=(ca(q,q)|0)+r|0;r=(d[k+7|0]|0)-(d[h+7|0]|0)|0;t=r+(q+(p+(o+(n+(l+(m+(a+e)))))))|0;u=(ca(r,r)|0)+s|0;s=j+1|0;if((s|0)<8){h=h+f|0;e=t;i=u;j=s;k=k+b|0}else{break}}b=(t|0)>-1?t:-t|0;t=0;k=Erc(b,t,b,t)|0;t=G;b=xrc(u,0,k>>>6|t<<26,t>>>6|0<<26)|0;c[g>>2]=u;return b|0}function RRb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=0;i=e;e=a;while(1){a=0;j=0;k=0;l=0;m=0;do{n=ca(m,b)|0;o=ca(m,f)|0;p=d[e+n|0]|0;q=d[i+o|0]|0;r=(ca(p,p)|0)+k+(ca(q,q)|0)|0;s=(ca(q,p)|0)+l|0;t=d[e+(n+1)|0]|0;u=d[i+(o+1)|0]|0;v=(ca(t,t)|0)+r+(ca(u,u)|0)|0;r=(ca(u,t)|0)+s|0;s=d[e+(n+2)|0]|0;w=d[i+(o+2)|0]|0;x=(ca(s,s)|0)+v+(ca(w,w)|0)|0;v=(ca(w,s)|0)+r|0;r=d[e+(n+3)|0]|0;n=d[i+(o+3)|0]|0;a=r+(s+(t+(p+a)))|0;j=n+(w+(u+(q+j)))|0;k=(ca(r,r)|0)+x+(ca(n,n)|0)|0;l=(ca(n,r)|0)+v|0;m=m+1|0;}while((m|0)<4);c[g+(h<<4)>>2]=a;c[g+(h<<4)+4>>2]=j;c[g+(h<<4)+8>>2]=k;c[g+(h<<4)+12>>2]=l;m=h+1|0;if((m|0)<2){h=m;i=i+4|0;e=e+4|0}else{break}}return}function SRb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0.0,f=0.0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0;if((d|0)<=0){e=0.0;return+e}f=0.0;g=0;h=c[a>>2]|0;i=c[b>>2]|0;j=c[a+4>>2]|0;k=c[b+4>>2]|0;l=c[a+8>>2]|0;m=c[b+8>>2]|0;n=c[a+12>>2]|0;o=c[b+12>>2]|0;while(1){p=g+1|0;q=c[a+(p<<4)>>2]|0;r=c[b+(p<<4)>>2]|0;s=q+h+i+r|0;t=c[a+(p<<4)+4>>2]|0;u=c[b+(p<<4)+4>>2]|0;v=t+j+k+u|0;w=c[a+(p<<4)+8>>2]|0;x=c[b+(p<<4)+8>>2]|0;y=c[a+(p<<4)+12>>2]|0;z=c[b+(p<<4)+12>>2]|0;A=ca(s,s)|0;B=ca(v,v)|0;C=f+ +((ca(s<<1,v)|0)+416|0)*+(((y+n+o+z<<6)-(ca(v,s)|0)<<1)+235963|0)/(+(A+416+B|0)*+(235963-A-B+(w+l+m+x<<6)|0));if((p|0)<(d|0)){f=C;g=p;h=q;i=r;j=t;k=u;l=w;m=x;n=y;o=z}else{e=C;break}}return+e}function TRb(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((c|0)>1){e=a;f=0;g=1}else{h=0;return h|0}while(1){a=f;i=0;do{j=(d[e+i|0]|0)-(d[e+(i+b)|0]|0)|0;a=((j|0)>-1?j:-j|0)+a|0;i=i+1|0;}while((i|0)<16);i=g+1|0;if((i|0)<(c|0)){e=e+b|0;f=a;g=i}else{h=a;break}}return h|0}function URb(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)>0){g=c;h=a;i=0;j=0}else{k=0;l=(k|0)>-1;m=-k|0;n=l?k:m;return n|0}while(1){a=(d[h+7|0]|0)+((d[h+6|0]|0)+((d[h+5|0]|0)+((d[h+4|0]|0)+((d[h+3|0]|0)+((d[h+2|0]|0)+((d[h+1|0]|0)+((d[h]|0)+i-(d[g]|0))-(d[g+1|0]|0))-(d[g+2|0]|0))-(d[g+3|0]|0))-(d[g+4|0]|0))-(d[g+5|0]|0))-(d[g+6|0]|0))-(d[g+7|0]|0)|0;c=j+1|0;if((c|0)<(f|0)){g=g+e|0;h=h+b|0;i=a;j=c}else{k=a;break}}l=(k|0)>-1;m=-k|0;n=l?k:m;return n|0}function VRb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+128|0;h=g|0;j=0;k=e;e=a;while(1){a=(d[e]|0)-(d[k]|0)|0;l=(d[e+1|0]|0)-(d[k+1|0]|0)|0;m=l+a+(a-l<<16)|0;l=(d[e+2|0]|0)-(d[k+2|0]|0)|0;a=(d[e+3|0]|0)-(d[k+3|0]|0)|0;n=a+l+(l-a<<16)|0;a=(d[e+4|0]|0)-(d[k+4|0]|0)|0;l=(d[e+5|0]|0)-(d[k+5|0]|0)|0;o=l+a+(a-l<<16)|0;l=(d[e+6|0]|0)-(d[k+6|0]|0)|0;a=(d[e+7|0]|0)-(d[k+7|0]|0)|0;p=a+l+(l-a<<16)|0;a=n+m|0;l=m-n|0;n=p+o|0;m=o-p|0;c[h+(j<<4)>>2]=n+a;c[h+(j<<4)+8>>2]=a-n;c[h+(j<<4)+4>>2]=m+l;c[h+(j<<4)+12>>2]=l-m;m=j+1|0;if((m|0)<8){j=m;k=k+f|0;e=e+b|0}else{q=0;r=0;break}}do{b=c[h+(r<<2)>>2]|0;e=c[h+16+(r<<2)>>2]|0;f=e+b|0;k=b-e|0;e=c[h+32+(r<<2)>>2]|0;b=c[h+48+(r<<2)>>2]|0;j=b+e|0;m=e-b|0;b=j+f|0;e=f-j|0;j=m+k|0;f=k-m|0;m=c[h+64+(r<<2)>>2]|0;k=c[h+80+(r<<2)>>2]|0;l=k+m|0;n=m-k|0;k=c[h+96+(r<<2)>>2]|0;m=c[h+112+(r<<2)>>2]|0;a=m+k|0;p=k-m|0;m=a+l|0;k=l-a|0;a=p+n|0;l=n-p|0;p=m+b|0;n=(p>>>15&65537)*65535|0;o=b-m|0;m=(o>>>15&65537)*65535|0;b=a+j|0;s=(b>>>15&65537)*65535|0;t=j-a|0;a=(t>>>15&65537)*65535|0;j=k+e|0;u=(j>>>15&65537)*65535|0;v=e-k|0;k=(v>>>15&65537)*65535|0;e=l+f|0;w=(e>>>15&65537)*65535|0;x=f-l|0;l=(x>>>15&65537)*65535|0;f=(n+p^n)+(m+o^m)+(a+t^a)+(s+b^s)+(k+v^k)+(u+j^u)+(l+x^l)+(w+e^w)|0;q=(f>>>16)+q+(f&65535)|0;r=r+1|0;}while((r|0)<4);i=g;return q|0}function WRb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+128|0;f=e|0;g=0;h=a;while(1){a=g<<2&16|g&3;j=d[h]|0;k=d[h+1|0]|0;l=k+j+(j-k<<16)|0;k=d[h+2|0]|0;j=d[h+3|0]|0;m=j+k+(k-j<<16)|0;c[f+(a<<2)>>2]=m+l;c[f+((a|4)<<2)>>2]=l-m;m=d[h+4|0]|0;l=d[h+5|0]|0;j=l+m+(m-l<<16)|0;l=d[h+6|0]|0;m=d[h+7|0]|0;k=m+l+(l-m<<16)|0;c[f+((a|8)<<2)>>2]=k+j;c[f+((a|12)<<2)>>2]=j-k;k=g+1|0;if((k|0)<8){g=k;h=h+b|0}else{n=0;o=0;break}}while(1){b=n<<2;h=f+(b<<2)|0;g=c[h>>2]|0;k=f+((b|1)<<2)|0;j=c[k>>2]|0;a=j+g|0;m=g-j|0;j=f+((b|2)<<2)|0;g=c[j>>2]|0;l=f+((b|3)<<2)|0;b=c[l>>2]|0;p=b+g|0;q=g-b|0;b=p+a|0;g=a-p|0;p=q+m|0;a=m-q|0;c[h>>2]=b;c[k>>2]=p;c[j>>2]=g;c[l>>2]=a;l=(b>>>15&65537)*65535|0;j=(p>>>15&65537)*65535|0;k=(g>>>15&65537)*65535|0;h=(a>>>15&65537)*65535|0;r=(j+p^j)+o+(l+b^l)+(k+g^k)+(h+a^h)|0;h=n+1|0;if((h|0)<8){n=h;o=r}else{s=0;t=0;break}}do{o=c[f+(t<<2)>>2]|0;n=c[f+(t+8<<2)>>2]|0;h=n+o|0;a=o-n|0;n=c[f+(t+16<<2)>>2]|0;o=c[f+(t+24<<2)>>2]|0;k=o+n|0;g=n-o|0;o=k+h|0;n=h-k|0;k=g+a|0;h=a-g|0;g=(o>>>15&65537)*65535|0;a=(k>>>15&65537)*65535|0;l=(n>>>15&65537)*65535|0;b=(h>>>15&65537)*65535|0;s=(a+k^a)+s+(g+o^g)+(l+n^l)+(b+h^b)|0;t=t+1|0;}while((t|0)<8);t=(c[f+32>>2]|0)+(c[f>>2]|0)+(c[f+64>>2]|0)+(c[f+96>>2]|0)&65535;i=e;return(G=(s&65535)+(s>>>16)-t|0,(r&65535)+(r>>>16)-t|0)|0}function XRb(a){a=a|0;var b=0,e=0;b=0;e=0;do{b=(d[a+((e<<5)-1)|0]|0)+b+(d[a+(e-32)|0]|0)|0;e=e+1|0;}while((e|0)<16);e=ca(b+16>>5,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+8>>2]=e;c[a+12>>2]=e;c[a+32>>2]=e;c[a+36>>2]=e;c[a+40>>2]=e;c[a+44>>2]=e;c[a+64>>2]=e;c[a+68>>2]=e;c[a+72>>2]=e;c[a+76>>2]=e;c[a+96>>2]=e;c[a+100>>2]=e;c[a+104>>2]=e;c[a+108>>2]=e;c[a+128>>2]=e;c[a+132>>2]=e;c[a+136>>2]=e;c[a+140>>2]=e;c[a+160>>2]=e;c[a+164>>2]=e;c[a+168>>2]=e;c[a+172>>2]=e;c[a+192>>2]=e;c[a+196>>2]=e;c[a+200>>2]=e;c[a+204>>2]=e;c[a+224>>2]=e;c[a+228>>2]=e;c[a+232>>2]=e;c[a+236>>2]=e;c[a+256>>2]=e;c[a+260>>2]=e;c[a+264>>2]=e;c[a+268>>2]=e;c[a+288>>2]=e;c[a+292>>2]=e;c[a+296>>2]=e;c[a+300>>2]=e;c[a+320>>2]=e;c[a+324>>2]=e;c[a+328>>2]=e;c[a+332>>2]=e;c[a+352>>2]=e;c[a+356>>2]=e;c[a+360>>2]=e;c[a+364>>2]=e;c[a+384>>2]=e;c[a+388>>2]=e;c[a+392>>2]=e;c[a+396>>2]=e;c[a+416>>2]=e;c[a+420>>2]=e;c[a+424>>2]=e;c[a+428>>2]=e;c[a+448>>2]=e;c[a+452>>2]=e;c[a+456>>2]=e;c[a+460>>2]=e;c[a+480>>2]=e;c[a+484>>2]=e;c[a+488>>2]=e;c[a+492>>2]=e;return}function YRb(a){a=a|0;var b=0,e=0;b=0;e=a;while(1){a=ca(d[e-1|0]|0,16843009)|0;c[e>>2]=a;c[e+4>>2]=a;c[e+8>>2]=a;c[e+12>>2]=a;a=b+1|0;if((a|0)<16){b=a;e=e+32|0}else{break}}return}function ZRb(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a-32>>2]|0;d=c[a-28>>2]|0;e=c[a-24>>2]|0;f=c[a-20>>2]|0;c[a>>2]=b;c[a+4>>2]=d;c[a+8>>2]=e;c[a+12>>2]=f;c[a+32>>2]=b;c[a+36>>2]=d;c[a+40>>2]=e;c[a+44>>2]=f;c[a+64>>2]=b;c[a+68>>2]=d;c[a+72>>2]=e;c[a+76>>2]=f;c[a+96>>2]=b;c[a+100>>2]=d;c[a+104>>2]=e;c[a+108>>2]=f;c[a+128>>2]=b;c[a+132>>2]=d;c[a+136>>2]=e;c[a+140>>2]=f;c[a+160>>2]=b;c[a+164>>2]=d;c[a+168>>2]=e;c[a+172>>2]=f;c[a+192>>2]=b;c[a+196>>2]=d;c[a+200>>2]=e;c[a+204>>2]=f;c[a+224>>2]=b;c[a+228>>2]=d;c[a+232>>2]=e;c[a+236>>2]=f;c[a+256>>2]=b;c[a+260>>2]=d;c[a+264>>2]=e;c[a+268>>2]=f;c[a+288>>2]=b;c[a+292>>2]=d;c[a+296>>2]=e;c[a+300>>2]=f;c[a+320>>2]=b;c[a+324>>2]=d;c[a+328>>2]=e;c[a+332>>2]=f;c[a+352>>2]=b;c[a+356>>2]=d;c[a+360>>2]=e;c[a+364>>2]=f;c[a+384>>2]=b;c[a+388>>2]=d;c[a+392>>2]=e;c[a+396>>2]=f;c[a+416>>2]=b;c[a+420>>2]=d;c[a+424>>2]=e;c[a+428>>2]=f;c[a+448>>2]=b;c[a+452>>2]=d;c[a+456>>2]=e;c[a+460>>2]=f;c[a+480>>2]=b;c[a+484>>2]=d;c[a+488>>2]=e;c[a+492>>2]=f;return}function _Rb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=0;e=0;f=0;while(1){g=c+1|0;h=6-c|0;i=(ca((d[b+(c-24)|0]|0)-(d[b+(h-32)|0]|0)|0,g)|0)+f|0;j=(ca((d[b+((c<<5)+255)|0]|0)-(d[b+((h<<5)-1)|0]|0)|0,g)|0)+e|0;if((g|0)<8){c=g;e=j;f=i}else{break}}f=(i*5|0)+32>>6;i=(j*5|0)+32>>6;j=b;e=((d[b-17|0]|0)+(d[b+479|0]|0)<<4)+16+((f+i|0)*-7|0)|0;b=0;while(1){c=e;g=0;while(1){h=c>>5;if(h>>>0>255>>>0){k=-h>>31&255}else{k=h&255}a[j+g|0]=k;h=g+1|0;if((h|0)<16){c=c+f|0;g=h}else{break}}g=b+1|0;if((g|0)<16){j=j+32|0;e=e+i|0;b=g}else{break}}return}function $Rb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=(d[a-25|0]|0)+((d[a-26|0]|0)+((d[a-27|0]|0)+(d[a-28|0]|0)))|0;e=(d[a+223|0]|0)+((d[a+191|0]|0)+((d[a+159|0]|0)+(d[a+127|0]|0)))|0;f=ca((d[a+95|0]|0)+((d[a+63|0]|0)+((d[a+31|0]|0)+(d[a-1|0]|0)))+4+((d[a-29|0]|0)+((d[a-30|0]|0)+((d[a-31|0]|0)+(d[a-32|0]|0))))>>3,16843009)|0;g=ca((b+2|0)>>>2,16843009)|0;h=ca(e+4+b>>3,16843009)|0;c[a>>2]=f;c[a+4>>2]=g;c[a+32>>2]=f;c[a+36>>2]=g;c[a+64>>2]=f;c[a+68>>2]=g;c[a+96>>2]=f;c[a+100>>2]=g;g=ca((e+2|0)>>>2,16843009)|0;c[a+128>>2]=g;c[a+132>>2]=h;c[a+160>>2]=g;c[a+164>>2]=h;c[a+192>>2]=g;c[a+196>>2]=h;c[a+224>>2]=g;c[a+228>>2]=h;return}function aSb(a){a=a|0;var b=0;b=ca(d[a-1|0]|0,16843009)|0;c[a>>2]=b;c[a+4>>2]=b;b=ca(d[a+31|0]|0,16843009)|0;c[a+32>>2]=b;c[a+36>>2]=b;b=ca(d[a+63|0]|0,16843009)|0;c[a+64>>2]=b;c[a+68>>2]=b;b=ca(d[a+95|0]|0,16843009)|0;c[a+96>>2]=b;c[a+100>>2]=b;b=ca(d[a+127|0]|0,16843009)|0;c[a+128>>2]=b;c[a+132>>2]=b;b=ca(d[a+159|0]|0,16843009)|0;c[a+160>>2]=b;c[a+164>>2]=b;b=ca(d[a+191|0]|0,16843009)|0;c[a+192>>2]=b;c[a+196>>2]=b;b=ca(d[a+223|0]|0,16843009)|0;c[a+224>>2]=b;c[a+228>>2]=b;return}function bSb(a){a=a|0;var b=0,d=0;b=c[a-32>>2]|0;d=c[a-28>>2]|0;c[a>>2]=b;c[a+4>>2]=d;c[a+32>>2]=b;c[a+36>>2]=d;c[a+64>>2]=b;c[a+68>>2]=d;c[a+96>>2]=b;c[a+100>>2]=d;c[a+128>>2]=b;c[a+132>>2]=d;c[a+160>>2]=b;c[a+164>>2]=d;c[a+192>>2]=b;c[a+196>>2]=d;c[a+224>>2]=b;c[a+228>>2]=d;return}function cSb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=d[b-25|0]|0;e=d[b-33|0]|0;f=d[b+223|0]|0;g=(((c-e<<2)+((((d[b-26|0]|0)-(d[b-32|0]|0)|0)*3|0)+(((d[b-27|0]|0)-(d[b-31|0]|0)<<1)+((d[b-28|0]|0)-(d[b-30|0]|0))))|0)*17|0)+16>>5;h=(((f-e<<2)+((((d[b+191|0]|0)-(d[b-1|0]|0)|0)*3|0)+(((d[b+159|0]|0)-(d[b+31|0]|0)<<1)+((d[b+127|0]|0)-(d[b+63|0]|0))))|0)*17|0)+16>>5;e=b;b=(c+f<<4)+16+((g+h|0)*-3|0)|0;f=0;while(1){c=b>>5;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[e]=i;c=b+g|0;j=c>>5;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[e+1|0]=k;j=c+g|0;c=j>>5;if(c>>>0>255>>>0){l=-c>>31&255}else{l=c&255}a[e+2|0]=l;c=j+g|0;j=c>>5;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[e+3|0]=m;j=c+g|0;c=j>>5;if(c>>>0>255>>>0){n=-c>>31&255}else{n=c&255}a[e+4|0]=n;c=j+g|0;j=c>>5;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[e+5|0]=o;j=c+g|0;c=j>>5;if(c>>>0>255>>>0){p=-c>>31&255}else{p=c&255}a[e+6|0]=p;c=j+g>>5;if(c>>>0>255>>>0){q=-c>>31&255}else{q=c&255}a[e+7|0]=q;c=f+1|0;if((c|0)<8){e=e+32|0;b=b+h|0;f=c}else{break}}return}function dSb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(d[a-25|0]|0)+((d[a-26|0]|0)+((d[a-27|0]|0)+(d[a-28|0]|0)))|0;e=(d[a+223|0]|0)+((d[a+191|0]|0)+((d[a+159|0]|0)+(d[a+127|0]|0)))|0;f=(d[a+351|0]|0)+((d[a+319|0]|0)+((d[a+287|0]|0)+(d[a+255|0]|0)))|0;g=(d[a+479|0]|0)+((d[a+447|0]|0)+((d[a+415|0]|0)+(d[a+383|0]|0)))|0;h=ca((d[a+95|0]|0)+((d[a+63|0]|0)+((d[a+31|0]|0)+(d[a-1|0]|0)))+4+((d[a-29|0]|0)+((d[a-30|0]|0)+((d[a-31|0]|0)+(d[a-32|0]|0))))>>3,16843009)|0;i=ca((b+2|0)>>>2,16843009)|0;j=ca(g+4+b>>3,16843009)|0;c[a>>2]=h;c[a+4>>2]=i;c[a+32>>2]=h;c[a+36>>2]=i;c[a+64>>2]=h;c[a+68>>2]=i;c[a+96>>2]=h;c[a+100>>2]=i;i=ca((e+2|0)>>>2,16843009)|0;h=ca(e+4+b>>3,16843009)|0;e=ca((f+2|0)>>>2,16843009)|0;k=ca(f+4+b>>3,16843009)|0;b=ca((g+2|0)>>>2,16843009)|0;c[a+128>>2]=i;c[a+132>>2]=h;c[a+160>>2]=i;c[a+164>>2]=h;c[a+192>>2]=i;c[a+196>>2]=h;c[a+224>>2]=i;c[a+228>>2]=h;c[a+256>>2]=e;c[a+260>>2]=k;c[a+288>>2]=e;c[a+292>>2]=k;c[a+320>>2]=e;c[a+324>>2]=k;c[a+352>>2]=e;c[a+356>>2]=k;c[a+384>>2]=b;c[a+388>>2]=j;c[a+416>>2]=b;c[a+420>>2]=j;c[a+448>>2]=b;c[a+452>>2]=j;c[a+480>>2]=b;c[a+484>>2]=j;return}function eSb(a){a=a|0;var b=0;b=ca(d[a-1|0]|0,16843009)|0;c[a>>2]=b;c[a+4>>2]=b;b=ca(d[a+31|0]|0,16843009)|0;c[a+32>>2]=b;c[a+36>>2]=b;b=ca(d[a+63|0]|0,16843009)|0;c[a+64>>2]=b;c[a+68>>2]=b;b=ca(d[a+95|0]|0,16843009)|0;c[a+96>>2]=b;c[a+100>>2]=b;b=ca(d[a+127|0]|0,16843009)|0;c[a+128>>2]=b;c[a+132>>2]=b;b=ca(d[a+159|0]|0,16843009)|0;c[a+160>>2]=b;c[a+164>>2]=b;b=ca(d[a+191|0]|0,16843009)|0;c[a+192>>2]=b;c[a+196>>2]=b;b=ca(d[a+223|0]|0,16843009)|0;c[a+224>>2]=b;c[a+228>>2]=b;b=ca(d[a+255|0]|0,16843009)|0;c[a+256>>2]=b;c[a+260>>2]=b;b=ca(d[a+287|0]|0,16843009)|0;c[a+288>>2]=b;c[a+292>>2]=b;b=ca(d[a+319|0]|0,16843009)|0;c[a+320>>2]=b;c[a+324>>2]=b;b=ca(d[a+351|0]|0,16843009)|0;c[a+352>>2]=b;c[a+356>>2]=b;b=ca(d[a+383|0]|0,16843009)|0;c[a+384>>2]=b;c[a+388>>2]=b;b=ca(d[a+415|0]|0,16843009)|0;c[a+416>>2]=b;c[a+420>>2]=b;b=ca(d[a+447|0]|0,16843009)|0;c[a+448>>2]=b;c[a+452>>2]=b;b=ca(d[a+479|0]|0,16843009)|0;c[a+480>>2]=b;c[a+484>>2]=b;return}function fSb(a){a=a|0;var b=0,d=0;b=c[a-32>>2]|0;d=c[a-28>>2]|0;c[a>>2]=b;c[a+4>>2]=d;c[a+32>>2]=b;c[a+36>>2]=d;c[a+64>>2]=b;c[a+68>>2]=d;c[a+96>>2]=b;c[a+100>>2]=d;c[a+128>>2]=b;c[a+132>>2]=d;c[a+160>>2]=b;c[a+164>>2]=d;c[a+192>>2]=b;c[a+196>>2]=d;c[a+224>>2]=b;c[a+228>>2]=d;c[a+256>>2]=b;c[a+260>>2]=d;c[a+288>>2]=b;c[a+292>>2]=d;c[a+320>>2]=b;c[a+324>>2]=d;c[a+352>>2]=b;c[a+356>>2]=d;c[a+384>>2]=b;c[a+388>>2]=d;c[a+416>>2]=b;c[a+420>>2]=d;c[a+448>>2]=b;c[a+452>>2]=d;c[a+480>>2]=b;c[a+484>>2]=d;return}function gSb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=d[b-25|0]|0;e=d[b-33|0]|0;f=d[b+479|0]|0;g=(((c-e<<2)+((((d[b-26|0]|0)-(d[b-32|0]|0)|0)*3|0)+(((d[b-27|0]|0)-(d[b-31|0]|0)<<1)+((d[b-28|0]|0)-(d[b-30|0]|0))))|0)*17|0)+16>>5;h=(((f-e<<3)+((((d[b+447|0]|0)-(d[b-1|0]|0)|0)*7|0)+((((d[b+415|0]|0)-(d[b+31|0]|0)|0)*6|0)+((((d[b+383|0]|0)-(d[b+63|0]|0)|0)*5|0)+(((d[b+351|0]|0)-(d[b+95|0]|0)<<2)+((((d[b+319|0]|0)-(d[b+127|0]|0)|0)*3|0)+(((d[b+287|0]|0)-(d[b+159|0]|0)<<1)+((d[b+255|0]|0)-(d[b+191|0]|0))))))))|0)*5|0)+32>>6;e=b;b=(g*-3|0)+16+(h*-7|0)+(c+f<<4)|0;f=0;while(1){c=b>>5;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[e]=i;c=b+g|0;j=c>>5;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[e+1|0]=k;j=c+g|0;c=j>>5;if(c>>>0>255>>>0){l=-c>>31&255}else{l=c&255}a[e+2|0]=l;c=j+g|0;j=c>>5;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[e+3|0]=m;j=c+g|0;c=j>>5;if(c>>>0>255>>>0){n=-c>>31&255}else{n=c&255}a[e+4|0]=n;c=j+g|0;j=c>>5;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[e+5|0]=o;j=c+g|0;c=j>>5;if(c>>>0>255>>>0){p=-c>>31&255}else{p=c&255}a[e+6|0]=p;c=j+g>>5;if(c>>>0>255>>>0){q=-c>>31&255}else{q=c&255}a[e+7|0]=q;c=f+1|0;if((c|0)<16){e=e+32|0;b=b+h|0;f=c}else{break}}return}function hSb(a){a=a|0;var b=0;b=ca((d[a-1|0]|0)+4+(d[a+31|0]|0)+(d[a+63|0]|0)+(d[a+95|0]|0)+(d[a-32|0]|0)+(d[a-31|0]|0)+(d[a-30|0]|0)+(d[a-29|0]|0)>>3,16843009)|0;c[a+96>>2]=b;c[a+64>>2]=b;c[a+32>>2]=b;c[a>>2]=b;return}function iSb(a){a=a|0;c[a>>2]=ca(d[a-1|0]|0,16843009)|0;c[a+32>>2]=ca(d[a+31|0]|0,16843009)|0;c[a+64>>2]=ca(d[a+63|0]|0,16843009)|0;c[a+96>>2]=ca(d[a+95|0]|0,16843009)|0;return}function jSb(a){a=a|0;var b=0;b=c[a-32>>2]|0;c[a+96>>2]=b;c[a+64>>2]=b;c[a+32>>2]=b;c[a>>2]=b;return}function kSb(a,b){a=a|0;b=b|0;var e=0;e=ca((d[b+14|0]|0)+8+(d[b+13|0]|0)+(d[b+12|0]|0)+(d[b+11|0]|0)+(d[b+10|0]|0)+(d[b+9|0]|0)+(d[b+8|0]|0)+(d[b+7|0]|0)+(d[b+16|0]|0)+(d[b+17|0]|0)+(d[b+18|0]|0)+(d[b+19|0]|0)+(d[b+20|0]|0)+(d[b+21|0]|0)+(d[b+22|0]|0)+(d[b+23|0]|0)>>4,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+32>>2]=e;c[a+36>>2]=e;c[a+64>>2]=e;c[a+68>>2]=e;c[a+96>>2]=e;c[a+100>>2]=e;c[a+128>>2]=e;c[a+132>>2]=e;c[a+160>>2]=e;c[a+164>>2]=e;c[a+192>>2]=e;c[a+196>>2]=e;c[a+224>>2]=e;c[a+228>>2]=e;return}function lSb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=d[b+13|0]|0;f=d[b+12|0]|0;g=d[b+11|0]|0;h=d[b+10|0]|0;i=d[b+9|0]|0;j=d[b+8|0]|0;k=d[b+7|0]|0;l=ca(d[b+14|0]|0,16843009)|0;c[a+4>>2]=l;c[a>>2]=l;l=ca(e,16843009)|0;c[a+36>>2]=l;c[a+32>>2]=l;l=ca(f,16843009)|0;c[a+68>>2]=l;c[a+64>>2]=l;l=ca(g,16843009)|0;c[a+100>>2]=l;c[a+96>>2]=l;l=ca(h,16843009)|0;c[a+132>>2]=l;c[a+128>>2]=l;l=ca(i,16843009)|0;c[a+164>>2]=l;c[a+160>>2]=l;l=ca(j,16843009)|0;c[a+196>>2]=l;c[a+192>>2]=l;l=ca(k,16843009)|0;c[a+228>>2]=l;c[a+224>>2]=l;return}function mSb(a,b){a=a|0;b=b|0;var d=0,e=0;d=c[b+16>>2]|0;e=c[b+20>>2]|0;c[a>>2]=d;c[a+4>>2]=e;c[a+32>>2]=d;c[a+36>>2]=e;c[a+64>>2]=d;c[a+68>>2]=e;c[a+96>>2]=d;c[a+100>>2]=e;c[a+128>>2]=d;c[a+132>>2]=e;c[a+160>>2]=d;c[a+164>>2]=e;c[a+192>>2]=d;c[a+196>>2]=e;c[a+224>>2]=d;c[a+228>>2]=e;return}function nSb(a,b){a=a|0;b=b|0;c[b>>2]=174;c[b+4>>2]=324;c[b+8>>2]=552;c[b+12>>2]=40;c[b+16>>2]=352;c[b+20>>2]=558;c[b+24>>2]=110;return}function oSb(a){a=a|0;var b=0;b=ca((d[a+479|0]|0)+((d[a+447|0]|0)+((d[a+415|0]|0)+((d[a+383|0]|0)+((d[a+351|0]|0)+((d[a+319|0]|0)+((d[a+287|0]|0)+((d[a+255|0]|0)+((d[a+223|0]|0)+((d[a+191|0]|0)+((d[a+159|0]|0)+((d[a+127|0]|0)+((d[a+95|0]|0)+((d[a+63|0]|0)+((d[a+31|0]|0)+(d[a-1|0]|0)))))))))))))))+8>>4,16843009)|0;c[a>>2]=b;c[a+4>>2]=b;c[a+8>>2]=b;c[a+12>>2]=b;c[a+32>>2]=b;c[a+36>>2]=b;c[a+40>>2]=b;c[a+44>>2]=b;c[a+64>>2]=b;c[a+68>>2]=b;c[a+72>>2]=b;c[a+76>>2]=b;c[a+96>>2]=b;c[a+100>>2]=b;c[a+104>>2]=b;c[a+108>>2]=b;c[a+128>>2]=b;c[a+132>>2]=b;c[a+136>>2]=b;c[a+140>>2]=b;c[a+160>>2]=b;c[a+164>>2]=b;c[a+168>>2]=b;c[a+172>>2]=b;c[a+192>>2]=b;c[a+196>>2]=b;c[a+200>>2]=b;c[a+204>>2]=b;c[a+224>>2]=b;c[a+228>>2]=b;c[a+232>>2]=b;c[a+236>>2]=b;c[a+256>>2]=b;c[a+260>>2]=b;c[a+264>>2]=b;c[a+268>>2]=b;c[a+288>>2]=b;c[a+292>>2]=b;c[a+296>>2]=b;c[a+300>>2]=b;c[a+320>>2]=b;c[a+324>>2]=b;c[a+328>>2]=b;c[a+332>>2]=b;c[a+352>>2]=b;c[a+356>>2]=b;c[a+360>>2]=b;c[a+364>>2]=b;c[a+384>>2]=b;c[a+388>>2]=b;c[a+392>>2]=b;c[a+396>>2]=b;c[a+416>>2]=b;c[a+420>>2]=b;c[a+424>>2]=b;c[a+428>>2]=b;c[a+448>>2]=b;c[a+452>>2]=b;c[a+456>>2]=b;c[a+460>>2]=b;c[a+480>>2]=b;c[a+484>>2]=b;c[a+488>>2]=b;c[a+492>>2]=b;return}function pSb(a){a=a|0;var b=0;b=ca((d[a-17|0]|0)+((d[a-18|0]|0)+((d[a-19|0]|0)+((d[a-20|0]|0)+((d[a-21|0]|0)+((d[a-22|0]|0)+((d[a-23|0]|0)+((d[a-24|0]|0)+((d[a-25|0]|0)+((d[a-26|0]|0)+((d[a-27|0]|0)+((d[a-28|0]|0)+((d[a-29|0]|0)+((d[a-30|0]|0)+((d[a-31|0]|0)+(d[a-32|0]|0)))))))))))))))+8>>4,16843009)|0;c[a>>2]=b;c[a+4>>2]=b;c[a+8>>2]=b;c[a+12>>2]=b;c[a+32>>2]=b;c[a+36>>2]=b;c[a+40>>2]=b;c[a+44>>2]=b;c[a+64>>2]=b;c[a+68>>2]=b;c[a+72>>2]=b;c[a+76>>2]=b;c[a+96>>2]=b;c[a+100>>2]=b;c[a+104>>2]=b;c[a+108>>2]=b;c[a+128>>2]=b;c[a+132>>2]=b;c[a+136>>2]=b;c[a+140>>2]=b;c[a+160>>2]=b;c[a+164>>2]=b;c[a+168>>2]=b;c[a+172>>2]=b;c[a+192>>2]=b;c[a+196>>2]=b;c[a+200>>2]=b;c[a+204>>2]=b;c[a+224>>2]=b;c[a+228>>2]=b;c[a+232>>2]=b;c[a+236>>2]=b;c[a+256>>2]=b;c[a+260>>2]=b;c[a+264>>2]=b;c[a+268>>2]=b;c[a+288>>2]=b;c[a+292>>2]=b;c[a+296>>2]=b;c[a+300>>2]=b;c[a+320>>2]=b;c[a+324>>2]=b;c[a+328>>2]=b;c[a+332>>2]=b;c[a+352>>2]=b;c[a+356>>2]=b;c[a+360>>2]=b;c[a+364>>2]=b;c[a+384>>2]=b;c[a+388>>2]=b;c[a+392>>2]=b;c[a+396>>2]=b;c[a+416>>2]=b;c[a+420>>2]=b;c[a+424>>2]=b;c[a+428>>2]=b;c[a+448>>2]=b;c[a+452>>2]=b;c[a+456>>2]=b;c[a+460>>2]=b;c[a+480>>2]=b;c[a+484>>2]=b;c[a+488>>2]=b;c[a+492>>2]=b;return}function qSb(a){a=a|0;c[a+32>>2]=-2139062144;mrc(a|0,-128|0,16)|0;c[a+36>>2]=-2139062144;c[a+40>>2]=-2139062144;c[a+44>>2]=-2139062144;c[a+64>>2]=-2139062144;c[a+68>>2]=-2139062144;c[a+72>>2]=-2139062144;c[a+76>>2]=-2139062144;c[a+96>>2]=-2139062144;c[a+100>>2]=-2139062144;c[a+104>>2]=-2139062144;c[a+108>>2]=-2139062144;c[a+128>>2]=-2139062144;c[a+132>>2]=-2139062144;c[a+136>>2]=-2139062144;c[a+140>>2]=-2139062144;c[a+160>>2]=-2139062144;c[a+164>>2]=-2139062144;c[a+168>>2]=-2139062144;c[a+172>>2]=-2139062144;c[a+192>>2]=-2139062144;c[a+196>>2]=-2139062144;c[a+200>>2]=-2139062144;c[a+204>>2]=-2139062144;c[a+224>>2]=-2139062144;c[a+228>>2]=-2139062144;c[a+232>>2]=-2139062144;c[a+236>>2]=-2139062144;c[a+256>>2]=-2139062144;c[a+260>>2]=-2139062144;c[a+264>>2]=-2139062144;c[a+268>>2]=-2139062144;c[a+288>>2]=-2139062144;c[a+292>>2]=-2139062144;c[a+296>>2]=-2139062144;c[a+300>>2]=-2139062144;c[a+320>>2]=-2139062144;c[a+324>>2]=-2139062144;c[a+328>>2]=-2139062144;c[a+332>>2]=-2139062144;c[a+352>>2]=-2139062144;c[a+356>>2]=-2139062144;c[a+360>>2]=-2139062144;c[a+364>>2]=-2139062144;c[a+384>>2]=-2139062144;c[a+388>>2]=-2139062144;c[a+392>>2]=-2139062144;c[a+396>>2]=-2139062144;c[a+416>>2]=-2139062144;c[a+420>>2]=-2139062144;c[a+424>>2]=-2139062144;c[a+428>>2]=-2139062144;c[a+448>>2]=-2139062144;c[a+452>>2]=-2139062144;c[a+456>>2]=-2139062144;c[a+460>>2]=-2139062144;c[a+480>>2]=-2139062144;c[a+484>>2]=-2139062144;c[a+488>>2]=-2139062144;c[a+492>>2]=-2139062144;return}function rSb(a,b){a=a|0;b=b|0;c[b+8>>2]=220;c[b+4>>2]=148;c[b>>2]=438;c[b+12>>2]=76;c[b+16>>2]=396;c[b+20>>2]=450;c[b+24>>2]=214;return}function sSb(a){a=a|0;var b=0,e=0;b=ca(((d[a+95|0]|0)+((d[a+63|0]|0)+((d[a+31|0]|0)+(d[a-1|0]|0)))+2|0)>>>2,16843009)|0;e=ca(((d[a+223|0]|0)+((d[a+191|0]|0)+((d[a+159|0]|0)+(d[a+127|0]|0)))+2|0)>>>2,16843009)|0;c[a>>2]=b;c[a+4>>2]=b;c[a+32>>2]=b;c[a+36>>2]=b;c[a+64>>2]=b;c[a+68>>2]=b;c[a+96>>2]=b;c[a+100>>2]=b;c[a+128>>2]=e;c[a+132>>2]=e;c[a+160>>2]=e;c[a+164>>2]=e;c[a+192>>2]=e;c[a+196>>2]=e;c[a+224>>2]=e;c[a+228>>2]=e;return}function tSb(a){a=a|0;var b=0,e=0;b=ca(((d[a-29|0]|0)+((d[a-30|0]|0)+((d[a-31|0]|0)+(d[a-32|0]|0)))+2|0)>>>2,16843009)|0;e=ca(((d[a-25|0]|0)+((d[a-26|0]|0)+((d[a-27|0]|0)+(d[a-28|0]|0)))+2|0)>>>2,16843009)|0;c[a>>2]=b;c[a+4>>2]=e;c[a+32>>2]=b;c[a+36>>2]=e;c[a+64>>2]=b;c[a+68>>2]=e;c[a+96>>2]=b;c[a+100>>2]=e;c[a+128>>2]=b;c[a+132>>2]=e;c[a+160>>2]=b;c[a+164>>2]=e;c[a+192>>2]=b;c[a+196>>2]=e;c[a+224>>2]=b;c[a+228>>2]=e;return}function uSb(a){a=a|0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+32>>2]=-2139062144;c[a+36>>2]=-2139062144;c[a+64>>2]=-2139062144;c[a+68>>2]=-2139062144;c[a+96>>2]=-2139062144;c[a+100>>2]=-2139062144;c[a+128>>2]=-2139062144;c[a+132>>2]=-2139062144;c[a+160>>2]=-2139062144;c[a+164>>2]=-2139062144;c[a+192>>2]=-2139062144;c[a+196>>2]=-2139062144;c[a+224>>2]=-2139062144;c[a+228>>2]=-2139062144;return}function vSb(a,b){a=a|0;b=b|0;c[b+8>>2]=172;c[b+4>>2]=334;c[b>>2]=218;c[b+12>>2]=254;c[b+16>>2]=240;c[b+20>>2]=320;c[b+24>>2]=108;return}function wSb(a){a=a|0;var b=0;b=ca(((d[a+95|0]|0)+((d[a+63|0]|0)+((d[a+31|0]|0)+(d[a-1|0]|0)))+2|0)>>>2,16843009)|0;c[a>>2]=b;c[a+4>>2]=b;c[a+32>>2]=b;c[a+36>>2]=b;c[a+64>>2]=b;c[a+68>>2]=b;c[a+96>>2]=b;c[a+100>>2]=b;b=ca(((d[a+223|0]|0)+((d[a+191|0]|0)+((d[a+159|0]|0)+(d[a+127|0]|0)))+2|0)>>>2,16843009)|0;c[a+128>>2]=b;c[a+132>>2]=b;c[a+160>>2]=b;c[a+164>>2]=b;c[a+192>>2]=b;c[a+196>>2]=b;c[a+224>>2]=b;c[a+228>>2]=b;b=ca(((d[a+351|0]|0)+((d[a+319|0]|0)+((d[a+287|0]|0)+(d[a+255|0]|0)))+2|0)>>>2,16843009)|0;c[a+256>>2]=b;c[a+260>>2]=b;c[a+288>>2]=b;c[a+292>>2]=b;c[a+320>>2]=b;c[a+324>>2]=b;c[a+352>>2]=b;c[a+356>>2]=b;b=ca(((d[a+479|0]|0)+((d[a+447|0]|0)+((d[a+415|0]|0)+(d[a+383|0]|0)))+2|0)>>>2,16843009)|0;c[a+384>>2]=b;c[a+388>>2]=b;c[a+416>>2]=b;c[a+420>>2]=b;c[a+448>>2]=b;c[a+452>>2]=b;c[a+480>>2]=b;c[a+484>>2]=b;return}function xSb(a){a=a|0;var b=0,e=0;b=ca(((d[a-29|0]|0)+((d[a-30|0]|0)+((d[a-31|0]|0)+(d[a-32|0]|0)))+2|0)>>>2,16843009)|0;e=ca(((d[a-25|0]|0)+((d[a-26|0]|0)+((d[a-27|0]|0)+(d[a-28|0]|0)))+2|0)>>>2,16843009)|0;c[a>>2]=b;c[a+4>>2]=e;c[a+32>>2]=b;c[a+36>>2]=e;c[a+64>>2]=b;c[a+68>>2]=e;c[a+96>>2]=b;c[a+100>>2]=e;c[a+128>>2]=b;c[a+132>>2]=e;c[a+160>>2]=b;c[a+164>>2]=e;c[a+192>>2]=b;c[a+196>>2]=e;c[a+224>>2]=b;c[a+228>>2]=e;c[a+256>>2]=b;c[a+260>>2]=e;c[a+288>>2]=b;c[a+292>>2]=e;c[a+320>>2]=b;c[a+324>>2]=e;c[a+352>>2]=b;c[a+356>>2]=e;c[a+384>>2]=b;c[a+388>>2]=e;c[a+416>>2]=b;c[a+420>>2]=e;c[a+448>>2]=b;c[a+452>>2]=e;c[a+480>>2]=b;c[a+484>>2]=e;return}function ySb(a){a=a|0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+32>>2]=-2139062144;c[a+36>>2]=-2139062144;c[a+64>>2]=-2139062144;c[a+68>>2]=-2139062144;c[a+96>>2]=-2139062144;c[a+100>>2]=-2139062144;c[a+128>>2]=-2139062144;c[a+132>>2]=-2139062144;c[a+160>>2]=-2139062144;c[a+164>>2]=-2139062144;c[a+192>>2]=-2139062144;c[a+196>>2]=-2139062144;c[a+224>>2]=-2139062144;c[a+228>>2]=-2139062144;c[a+256>>2]=-2139062144;c[a+260>>2]=-2139062144;c[a+288>>2]=-2139062144;c[a+292>>2]=-2139062144;c[a+320>>2]=-2139062144;c[a+324>>2]=-2139062144;c[a+352>>2]=-2139062144;c[a+356>>2]=-2139062144;c[a+384>>2]=-2139062144;c[a+388>>2]=-2139062144;c[a+416>>2]=-2139062144;c[a+420>>2]=-2139062144;c[a+448>>2]=-2139062144;c[a+452>>2]=-2139062144;c[a+480>>2]=-2139062144;c[a+484>>2]=-2139062144;return}function zSb(a,b,d){a=a|0;b=b|0;d=d|0;c[b>>2]=332;c[b+4>>2]=272;c[b+8>>2]=194;c[b+12>>2]=574;c[b+16>>2]=414;c[b+20>>2]=498;c[b+24>>2]=458;c[b+28>>2]=648;c[b+32>>2]=192;c[b+36>>2]=16;c[b+40>>2]=312;c[b+44>>2]=532;c[d>>2]=572;return}function ASb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=d[c+17|0]|0;f=d[c+18|0]|0;g=d[c+19|0]|0;h=d[c+20|0]|0;i=d[c+21|0]|0;j=d[c+22|0]|0;k=d[c+23|0]|0;l=d[c+24|0]|0;m=d[c+25|0]|0;n=d[c+26|0]|0;o=d[c+27|0]|0;p=d[c+28|0]|0;q=d[c+29|0]|0;r=d[c+30|0]|0;s=d[c+31|0]|0;a[b]=((d[c+16|0]|0)+2+(e<<1)+f|0)>>>2;c=(e+2+(f<<1)+g|0)>>>2&255;a[b+1|0]=c;a[b+32|0]=c;c=(f+2+(g<<1)+h|0)>>>2&255;a[b+2|0]=c;a[b+33|0]=c;a[b+64|0]=c;c=(g+2+(h<<1)+i|0)>>>2&255;a[b+3|0]=c;a[b+34|0]=c;a[b+65|0]=c;a[b+96|0]=c;c=(h+2+(i<<1)+j|0)>>>2&255;a[b+4|0]=c;a[b+35|0]=c;a[b+66|0]=c;a[b+97|0]=c;a[b+128|0]=c;c=(i+2+(j<<1)+k|0)>>>2&255;a[b+5|0]=c;a[b+36|0]=c;a[b+67|0]=c;a[b+98|0]=c;a[b+129|0]=c;a[b+160|0]=c;c=(j+2+(k<<1)+l|0)>>>2&255;a[b+6|0]=c;a[b+37|0]=c;a[b+68|0]=c;a[b+99|0]=c;a[b+130|0]=c;a[b+161|0]=c;a[b+192|0]=c;c=(k+2+(l<<1)+m|0)>>>2&255;a[b+7|0]=c;a[b+38|0]=c;a[b+69|0]=c;a[b+100|0]=c;a[b+131|0]=c;a[b+162|0]=c;a[b+193|0]=c;a[b+224|0]=c;c=(l+2+(m<<1)+n|0)>>>2&255;a[b+39|0]=c;a[b+70|0]=c;a[b+101|0]=c;a[b+132|0]=c;a[b+163|0]=c;a[b+194|0]=c;a[b+225|0]=c;c=(m+2+(n<<1)+o|0)>>>2&255;a[b+71|0]=c;a[b+102|0]=c;a[b+133|0]=c;a[b+164|0]=c;a[b+195|0]=c;a[b+226|0]=c;c=(n+2+(o<<1)+p|0)>>>2&255;a[b+103|0]=c;a[b+134|0]=c;a[b+165|0]=c;a[b+196|0]=c;a[b+227|0]=c;c=(o+2+(p<<1)+q|0)>>>2&255;a[b+135|0]=c;a[b+166|0]=c;a[b+197|0]=c;a[b+228|0]=c;c=(p+2+(q<<1)+r|0)>>>2&255;a[b+167|0]=c;a[b+198|0]=c;a[b+229|0]=c;c=(q+2+(r<<1)+s|0)>>>2&255;a[b+199|0]=c;a[b+230|0]=c;a[b+231|0]=(r+2+s+(s<<1)|0)>>>2;return}function BSb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=d[c+16|0]|0;f=d[c+17|0]|0;g=d[c+18|0]|0;h=d[c+19|0]|0;i=d[c+20|0]|0;j=d[c+21|0]|0;k=d[c+22|0]|0;l=d[c+23|0]|0;m=d[c+14|0]|0;n=d[c+13|0]|0;o=d[c+12|0]|0;p=d[c+11|0]|0;q=d[c+10|0]|0;r=d[c+9|0]|0;s=d[c+8|0]|0;t=d[c+15|0]|0;a[b+224|0]=(r+2+(s<<1)+(d[c+7|0]|0)|0)>>>2;c=(q+2+(r<<1)+s|0)>>>2&255;a[b+225|0]=c;a[b+192|0]=c;c=(p+2+(q<<1)+r|0)>>>2&255;a[b+226|0]=c;a[b+193|0]=c;a[b+160|0]=c;c=(o+2+(p<<1)+q|0)>>>2&255;a[b+227|0]=c;a[b+194|0]=c;a[b+161|0]=c;a[b+128|0]=c;c=(n+2+(o<<1)+p|0)>>>2&255;a[b+228|0]=c;a[b+195|0]=c;a[b+162|0]=c;a[b+129|0]=c;a[b+96|0]=c;c=(m+2+(n<<1)+o|0)>>>2&255;a[b+229|0]=c;a[b+196|0]=c;a[b+163|0]=c;a[b+130|0]=c;a[b+97|0]=c;a[b+64|0]=c;c=((m<<1)+2+n+t|0)>>>2&255;a[b+230|0]=c;a[b+197|0]=c;a[b+164|0]=c;a[b+131|0]=c;a[b+98|0]=c;a[b+65|0]=c;a[b+32|0]=c;c=e+2|0;n=(c+m+(t<<1)|0)>>>2&255;a[b+231|0]=n;a[b+198|0]=n;a[b+165|0]=n;a[b+132|0]=n;a[b+99|0]=n;a[b+66|0]=n;a[b+33|0]=n;a[b]=n;n=((e<<1)+2+f+t|0)>>>2&255;a[b+199|0]=n;a[b+166|0]=n;a[b+133|0]=n;a[b+100|0]=n;a[b+67|0]=n;a[b+34|0]=n;a[b+1|0]=n;n=(c+(f<<1)+g|0)>>>2&255;a[b+167|0]=n;a[b+134|0]=n;a[b+101|0]=n;a[b+68|0]=n;a[b+35|0]=n;a[b+2|0]=n;n=(f+2+(g<<1)+h|0)>>>2&255;a[b+135|0]=n;a[b+102|0]=n;a[b+69|0]=n;a[b+36|0]=n;a[b+3|0]=n;n=(g+2+(h<<1)+i|0)>>>2&255;a[b+103|0]=n;a[b+70|0]=n;a[b+37|0]=n;a[b+4|0]=n;n=(h+2+(i<<1)+j|0)>>>2&255;a[b+71|0]=n;a[b+38|0]=n;a[b+5|0]=n;n=(i+2+(j<<1)+k|0)>>>2&255;a[b+39|0]=n;a[b+6|0]=n;a[b+7|0]=(j+2+(k<<1)+l|0)>>>2;return}function CSb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=d[c+16|0]|0;f=d[c+17|0]|0;g=d[c+18|0]|0;h=d[c+19|0]|0;i=d[c+20|0]|0;j=d[c+21|0]|0;k=d[c+22|0]|0;l=d[c+23|0]|0;m=d[c+14|0]|0;n=d[c+13|0]|0;o=d[c+12|0]|0;p=d[c+11|0]|0;q=d[c+10|0]|0;r=d[c+9|0]|0;s=d[c+8|0]|0;t=d[c+15|0]|0;a[b+192|0]=(p+2+(q<<1)+r|0)>>>2;a[b+224|0]=(q+2+(r<<1)+s|0)>>>2;s=(n+2+(o<<1)+p|0)>>>2&255;a[b+193|0]=s;a[b+128|0]=s;s=(o+2+(p<<1)+q|0)>>>2&255;a[b+225|0]=s;a[b+160|0]=s;s=((m<<1)+2+n+t|0)>>>2&255;a[b+194|0]=s;a[b+129|0]=s;a[b+64|0]=s;s=(m+2+(n<<1)+o|0)>>>2&255;a[b+226|0]=s;a[b+161|0]=s;a[b+96|0]=s;s=e+2|0;o=(s+m+(t<<1)|0)>>>2&255;a[b+227|0]=o;a[b+162|0]=o;a[b+97|0]=o;a[b+32|0]=o;o=e+1|0;m=(o+t|0)>>>1&255;a[b+195|0]=m;a[b+130|0]=m;a[b+65|0]=m;a[b]=m;m=((e<<1)+2+f+t|0)>>>2&255;a[b+228|0]=m;a[b+163|0]=m;a[b+98|0]=m;a[b+33|0]=m;m=(o+f|0)>>>1&255;a[b+196|0]=m;a[b+131|0]=m;a[b+66|0]=m;a[b+1|0]=m;m=(s+(f<<1)+g|0)>>>2&255;a[b+229|0]=m;a[b+164|0]=m;a[b+99|0]=m;a[b+34|0]=m;m=(f+1+g|0)>>>1&255;a[b+197|0]=m;a[b+132|0]=m;a[b+67|0]=m;a[b+2|0]=m;m=(f+2+(g<<1)+h|0)>>>2&255;a[b+230|0]=m;a[b+165|0]=m;a[b+100|0]=m;a[b+35|0]=m;m=(g+1+h|0)>>>1&255;a[b+198|0]=m;a[b+133|0]=m;a[b+68|0]=m;a[b+3|0]=m;m=(g+2+(h<<1)+i|0)>>>2&255;a[b+231|0]=m;a[b+166|0]=m;a[b+101|0]=m;a[b+36|0]=m;m=(h+1+i|0)>>>1&255;a[b+199|0]=m;a[b+134|0]=m;a[b+69|0]=m;a[b+4|0]=m;m=(h+2+(i<<1)+j|0)>>>2&255;a[b+167|0]=m;a[b+102|0]=m;a[b+37|0]=m;m=(i+1+j|0)>>>1&255;a[b+135|0]=m;a[b+70|0]=m;a[b+5|0]=m;m=(i+2+(j<<1)+k|0)>>>2&255;a[b+103|0]=m;a[b+38|0]=m;m=(j+1+k|0)>>>1&255;a[b+71|0]=m;a[b+6|0]=m;a[b+39|0]=(j+2+(k<<1)+l|0)>>>2;a[b+7|0]=(k+1+l|0)>>>1;return}function DSb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=d[b+16|0]|0;f=d[b+17|0]|0;g=d[b+18|0]|0;h=d[b+19|0]|0;i=d[b+20|0]|0;j=d[b+21|0]|0;k=d[b+14|0]|0;l=d[b+13|0]|0;m=d[b+12|0]|0;n=d[b+11|0]|0;o=d[b+10|0]|0;p=d[b+9|0]|0;q=d[b+8|0]|0;r=d[b+7|0]|0;s=d[b+15|0]|0;t=((o+2+(p<<1)+q|0)>>>2<<8)+((p+1+q|0)>>>1)|0;u=((n+2+(o<<1)+p|0)>>>2<<8)+((o+1+p|0)>>>1)|0;v=((m+2+(n<<1)+o|0)>>>2<<8)+((n+1+o|0)>>>1)|0;o=((l+2+(m<<1)+n|0)>>>2<<8)+((m+1+n|0)>>>1)|0;n=((k+2+(l<<1)+m|0)>>>2<<8)+((l+1+m|0)>>>1)|0;m=k+1|0;w=(((k<<1)+2+l+s|0)>>>2<<8)+((m+l|0)>>>1)|0;l=e+2|0;x=((l+k+(s<<1)|0)>>>2<<8)+((m+s|0)>>>1)|0;m=(((e<<1)+2+f+s|0)>>>2)+((l+(f<<1)+g|0)>>>2<<8)|0;l=((g+2+(h<<1)+i|0)>>>2<<8)+((f+2+(g<<1)+h|0)>>>2)|0;g=((i+2+(j<<1)+(d[b+22|0]|0)|0)>>>2<<8)+((h+2+(i<<1)+j|0)>>>2)|0;c[a+224>>2]=((p+2+(q<<1)+r|0)>>>2<<8)+((q+1+r|0)>>>1)+(t<<16);c[a+192>>2]=(u<<16)+t;t=(v<<16)+u|0;c[a+160>>2]=t;c[a+228>>2]=t;t=(o<<16)+v|0;c[a+128>>2]=t;c[a+196>>2]=t;t=(n<<16)+o|0;c[a+96>>2]=t;c[a+164>>2]=t;t=(w<<16)+n|0;c[a+64>>2]=t;c[a+132>>2]=t;t=(x<<16)+w|0;c[a+32>>2]=t;c[a+100>>2]=t;t=x+(m<<16)|0;c[a>>2]=t;c[a+68>>2]=t;c[a+36>>2]=m+(l<<16);c[a+4>>2]=(g<<16)+l;return}function ESb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d[c+16|0]|0;f=d[c+17|0]|0;g=d[c+18|0]|0;h=d[c+19|0]|0;i=d[c+20|0]|0;j=d[c+21|0]|0;k=d[c+22|0]|0;l=d[c+23|0]|0;m=d[c+24|0]|0;n=d[c+25|0]|0;o=d[c+26|0]|0;p=d[c+27|0]|0;q=d[c+28|0]|0;a[b]=(e+1+f|0)>>>1;a[b+32|0]=(e+2+(f<<1)+g|0)>>>2;e=(f+1+g|0)>>>1&255;a[b+1|0]=e;a[b+64|0]=e;e=(f+2+(g<<1)+h|0)>>>2&255;a[b+33|0]=e;a[b+96|0]=e;e=(g+1+h|0)>>>1&255;a[b+2|0]=e;a[b+65|0]=e;a[b+128|0]=e;e=(g+2+(h<<1)+i|0)>>>2&255;a[b+34|0]=e;a[b+97|0]=e;a[b+160|0]=e;e=(h+1+i|0)>>>1&255;a[b+3|0]=e;a[b+66|0]=e;a[b+129|0]=e;a[b+192|0]=e;e=(h+2+(i<<1)+j|0)>>>2&255;a[b+35|0]=e;a[b+98|0]=e;a[b+161|0]=e;a[b+224|0]=e;e=(i+1+j|0)>>>1&255;a[b+4|0]=e;a[b+67|0]=e;a[b+130|0]=e;a[b+193|0]=e;e=(i+2+(j<<1)+k|0)>>>2&255;a[b+36|0]=e;a[b+99|0]=e;a[b+162|0]=e;a[b+225|0]=e;e=(j+1+k|0)>>>1&255;a[b+5|0]=e;a[b+68|0]=e;a[b+131|0]=e;a[b+194|0]=e;e=(j+2+(k<<1)+l|0)>>>2&255;a[b+37|0]=e;a[b+100|0]=e;a[b+163|0]=e;a[b+226|0]=e;e=(k+1+l|0)>>>1&255;a[b+6|0]=e;a[b+69|0]=e;a[b+132|0]=e;a[b+195|0]=e;e=(k+2+(l<<1)+m|0)>>>2&255;a[b+38|0]=e;a[b+101|0]=e;a[b+164|0]=e;a[b+227|0]=e;e=(l+1+m|0)>>>1&255;a[b+7|0]=e;a[b+70|0]=e;a[b+133|0]=e;a[b+196|0]=e;e=(l+2+(m<<1)+n|0)>>>2&255;a[b+39|0]=e;a[b+102|0]=e;a[b+165|0]=e;a[b+228|0]=e;e=(m+1+n|0)>>>1&255;a[b+71|0]=e;a[b+134|0]=e;a[b+197|0]=e;e=(m+2+(n<<1)+o|0)>>>2&255;a[b+103|0]=e;a[b+166|0]=e;a[b+229|0]=e;e=(n+1+o|0)>>>1&255;a[b+135|0]=e;a[b+198|0]=e;e=(n+2+(o<<1)+p|0)>>>2&255;a[b+167|0]=e;a[b+230|0]=e;a[b+199|0]=(o+1+p|0)>>>1;a[b+231|0]=(o+2+(p<<1)+q|0)>>>2;return}function FSb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=d[b+14|0]|0;f=d[b+13|0]|0;g=d[b+12|0]|0;h=d[b+11|0]|0;i=d[b+10|0]|0;j=d[b+9|0]|0;k=d[b+8|0]|0;l=d[b+7|0]|0;b=((f+2+(g<<1)+h|0)>>>2<<8)+((f+1+g|0)>>>1)|0;m=((g+2+(h<<1)+i|0)>>>2<<8)+((g+1+h|0)>>>1)|0;n=((h+2+(i<<1)+j|0)>>>2<<8)+((h+1+i|0)>>>1)|0;h=((i+2+(j<<1)+k|0)>>>2<<8)+((i+1+j|0)>>>1)|0;i=((j+2+(k<<1)+l|0)>>>2<<8)+((j+1+k|0)>>>1)|0;j=((k+2+l+(l<<1)|0)>>>2<<8)+((k+1+l|0)>>>1)|0;c[a>>2]=((e+2+(f<<1)+g|0)>>>2<<8)+((e+1+f|0)>>>1)+(b<<16);c[a+32>>2]=(m<<16)+b;b=(n<<16)+m|0;c[a+64>>2]=b;c[a+4>>2]=b;b=(h<<16)+n|0;c[a+96>>2]=b;c[a+36>>2]=b;b=(i<<16)+h|0;c[a+128>>2]=b;c[a+68>>2]=b;b=(j<<16)+i|0;c[a+160>>2]=b;c[a+100>>2]=b;b=j+(ca(l,16842752)|0)|0;c[a+192>>2]=b;c[a+132>>2]=b;b=ca(l,16843009)|0;c[a+228>>2]=b;c[a+224>>2]=b;c[a+196>>2]=b;c[a+164>>2]=b;return}function GSb(a,b){a=a|0;b=b|0;var e=0;e=ca((d[b+14|0]|0)+4+(d[b+13|0]|0)+(d[b+12|0]|0)+(d[b+11|0]|0)+(d[b+10|0]|0)+(d[b+9|0]|0)+(d[b+8|0]|0)+(d[b+7|0]|0)>>3,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+32>>2]=e;c[a+36>>2]=e;c[a+64>>2]=e;c[a+68>>2]=e;c[a+96>>2]=e;c[a+100>>2]=e;c[a+128>>2]=e;c[a+132>>2]=e;c[a+160>>2]=e;c[a+164>>2]=e;c[a+192>>2]=e;c[a+196>>2]=e;c[a+224>>2]=e;c[a+228>>2]=e;return}function HSb(a,b){a=a|0;b=b|0;var e=0;e=ca((d[b+16|0]|0)+4+(d[b+17|0]|0)+(d[b+18|0]|0)+(d[b+19|0]|0)+(d[b+20|0]|0)+(d[b+21|0]|0)+(d[b+22|0]|0)+(d[b+23|0]|0)>>3,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+32>>2]=e;c[a+36>>2]=e;c[a+64>>2]=e;c[a+68>>2]=e;c[a+96>>2]=e;c[a+100>>2]=e;c[a+128>>2]=e;c[a+132>>2]=e;c[a+160>>2]=e;c[a+164>>2]=e;c[a+192>>2]=e;c[a+196>>2]=e;c[a+224>>2]=e;c[a+228>>2]=e;return}function ISb(a,b){a=a|0;b=b|0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+32>>2]=-2139062144;c[a+36>>2]=-2139062144;c[a+64>>2]=-2139062144;c[a+68>>2]=-2139062144;c[a+96>>2]=-2139062144;c[a+100>>2]=-2139062144;c[a+128>>2]=-2139062144;c[a+132>>2]=-2139062144;c[a+160>>2]=-2139062144;c[a+164>>2]=-2139062144;c[a+192>>2]=-2139062144;c[a+196>>2]=-2139062144;c[a+224>>2]=-2139062144;c[a+228>>2]=-2139062144;return}function JSb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=f&8;if((g&1|0)!=0){i=b-33|0;j=b-1|0;a[e+15|0]=((d[b-32|0]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;k=a[j]|0;l=b+31|0;a[e+14|0]=(((k&255)<<1)+2+(((h|0)==0?k:a[i]|0)&255)+(d[l]|0)|0)>>>2;i=b+63|0;a[e+13|0]=((d[j]|0)+2+((d[l]|0)<<1)+(d[i]|0)|0)>>>2;j=b+95|0;a[e+12|0]=((d[l]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;l=b+127|0;a[e+11|0]=((d[i]|0)+2+((d[j]|0)<<1)+(d[l]|0)|0)>>>2;i=b+159|0;a[e+10|0]=((d[j]|0)+2+((d[l]|0)<<1)+(d[i]|0)|0)>>>2;j=b+191|0;a[e+9|0]=((d[l]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;l=b+223|0;a[e+8|0]=((d[i]|0)+2+((d[j]|0)<<1)+(d[l]|0)|0)>>>2;i=((d[j]|0)+2+((d[l]|0)*3|0)|0)>>>2&255;a[e+7|0]=i;a[e+6|0]=i}if((g&2|0)==0){return}i=b-32|0;l=b-31|0;a[e+16|0]=((d[(h|0)==0?i:b-33|0]|0)+2+((d[i]|0)<<1)+(d[l]|0)|0)>>>2;h=b-30|0;a[e+17|0]=((d[i]|0)+2+((d[l]|0)<<1)+(d[h]|0)|0)>>>2;i=b-29|0;a[e+18|0]=((d[l]|0)+2+((d[h]|0)<<1)+(d[i]|0)|0)>>>2;l=b-28|0;a[e+19|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[l]|0)|0)>>>2;h=b-27|0;a[e+20|0]=((d[i]|0)+2+((d[l]|0)<<1)+(d[h]|0)|0)>>>2;i=b-26|0;a[e+21|0]=((d[l]|0)+2+((d[h]|0)<<1)+(d[i]|0)|0)>>>2;l=b-25|0;a[e+22|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[l]|0)|0)>>>2;h=a[l]|0;j=(f&4|0)!=0;if(j){m=a[b-24|0]|0}else{m=h}a[e+23|0]=((d[i]|0)+2+((h&255)<<1)+(m&255)|0)>>>2;if((g&4|0)==0){return}g=d[l]|0;if(j){j=b-24|0;m=b-23|0;a[e+24|0]=(g+2+((d[j]|0)<<1)+(d[m]|0)|0)>>>2;h=b-22|0;a[e+25|0]=((d[j]|0)+2+((d[m]|0)<<1)+(d[h]|0)|0)>>>2;j=b-21|0;a[e+26|0]=((d[m]|0)+2+((d[h]|0)<<1)+(d[j]|0)|0)>>>2;m=b-20|0;a[e+27|0]=((d[h]|0)+2+((d[j]|0)<<1)+(d[m]|0)|0)>>>2;h=b-19|0;a[e+28|0]=((d[j]|0)+2+((d[m]|0)<<1)+(d[h]|0)|0)>>>2;j=b-18|0;a[e+29|0]=((d[m]|0)+2+((d[h]|0)<<1)+(d[j]|0)|0)>>>2;m=b-17|0;a[e+30|0]=((d[h]|0)+2+((d[j]|0)<<1)+(d[m]|0)|0)>>>2;h=((d[j]|0)+2+((d[m]|0)*3|0)|0)>>>2&255;a[e+32|0]=h;a[e+31|0]=h;return}else{c[e+24>>2]=ca(g,16843009)|0;c[e+28>>2]=ca(d[l]|0,16843009)|0;a[e+32|0]=a[l]|0;return}}function KSb(a,b){a=a|0;b=b|0;c[b>>2]=284;c[b+4>>2]=420;c[b+8>>2]=80;c[b+12>>2]=364;c[b+16>>2]=206;c[b+20>>2]=66;c[b+24>>2]=16;c[b+28>>2]=196;c[b+32>>2]=368;c[b+36>>2]=236;c[b+40>>2]=48;c[b+44>>2]=582;return}function LSb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=d[b-31|0]|0;e=d[b-30|0]|0;f=d[b-29|0]|0;g=d[b-28|0]|0;h=d[b-27|0]|0;i=d[b-26|0]|0;j=d[b-25|0]|0;a[b]=((d[b-32|0]|0)+2+(c<<1)+e|0)>>>2;k=(c+2+(e<<1)+f|0)>>>2&255;a[b+32|0]=k;a[b+1|0]=k;k=(e+2+(f<<1)+g|0)>>>2&255;a[b+64|0]=k;a[b+33|0]=k;a[b+2|0]=k;k=(f+2+(g<<1)+h|0)>>>2&255;a[b+96|0]=k;a[b+65|0]=k;a[b+34|0]=k;a[b+3|0]=k;k=(g+2+(h<<1)+i|0)>>>2&255;a[b+97|0]=k;a[b+66|0]=k;a[b+35|0]=k;k=(h+2+(i<<1)+j|0)>>>2&255;a[b+98|0]=k;a[b+67|0]=k;a[b+99|0]=(i+2+j+(j<<1)|0)>>>2;return}function MSb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=d[b-33|0]|0;e=d[b-1|0]|0;f=d[b+31|0]|0;g=d[b+63|0]|0;h=d[b+95|0]|0;i=d[b-32|0]|0;j=d[b-31|0]|0;k=d[b-30|0]|0;a[b+3|0]=(j+2+(k<<1)+(d[b-29|0]|0)|0)>>>2;l=(i+2+(j<<1)+k|0)>>>2&255;a[b+35|0]=l;a[b+2|0]=l;l=c+2|0;k=(l+(i<<1)+j|0)>>>2&255;a[b+67|0]=k;a[b+34|0]=k;a[b+1|0]=k;k=((c<<1)+2+e+i|0)>>>2&255;a[b+99|0]=k;a[b+66|0]=k;a[b+33|0]=k;a[b]=k;k=(l+(e<<1)+f|0)>>>2&255;a[b+98|0]=k;a[b+65|0]=k;a[b+32|0]=k;k=(e+2+(f<<1)+g|0)>>>2&255;a[b+97|0]=k;a[b+64|0]=k;a[b+96|0]=(f+2+(g<<1)+h|0)>>>2;return}function NSb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=d[b-33|0]|0;e=d[b-1|0]|0;f=d[b+31|0]|0;g=d[b-32|0]|0;h=d[b-31|0]|0;i=d[b-30|0]|0;j=d[b-29|0]|0;a[b+96|0]=(e+2+(f<<1)+(d[b+63|0]|0)|0)>>>2;k=c+2|0;a[b+64|0]=(k+(e<<1)+f|0)>>>2;f=((c<<1)+2+e+g|0)>>>2&255;a[b+97|0]=f;a[b+32|0]=f;f=(c+1+g|0)>>>1&255;a[b+65|0]=f;a[b]=f;f=(k+(g<<1)+h|0)>>>2&255;a[b+98|0]=f;a[b+33|0]=f;f=(g+1+h|0)>>>1&255;a[b+66|0]=f;a[b+1|0]=f;f=(g+2+(h<<1)+i|0)>>>2&255;a[b+99|0]=f;a[b+34|0]=f;f=(h+1+i|0)>>>1&255;a[b+67|0]=f;a[b+2|0]=f;a[b+35|0]=(h+2+(i<<1)+j|0)>>>2;a[b+3|0]=(i+1+j|0)>>>1;return}function OSb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=d[b-33|0]|0;e=d[b-1|0]|0;f=d[b+31|0]|0;g=d[b+63|0]|0;h=d[b+95|0]|0;i=d[b-32|0]|0;j=d[b-31|0]|0;k=d[b-30|0]|0;a[b+96|0]=(g+1+h|0)>>>1;a[b+97|0]=(f+2+(g<<1)+h|0)>>>2;h=(f+1+g|0)>>>1&255;a[b+98|0]=h;a[b+64|0]=h;h=(e+2+(f<<1)+g|0)>>>2&255;a[b+99|0]=h;a[b+65|0]=h;h=(e+1+f|0)>>>1&255;a[b+66|0]=h;a[b+32|0]=h;h=c+2|0;g=(h+(e<<1)+f|0)>>>2&255;a[b+67|0]=g;a[b+33|0]=g;g=(c+1+e|0)>>>1&255;a[b+34|0]=g;a[b]=g;g=((c<<1)+2+e+i|0)>>>2&255;a[b+35|0]=g;a[b+1|0]=g;a[b+2|0]=(h+(i<<1)+j|0)>>>2;a[b+3|0]=(i+2+(j<<1)+k|0)>>>2;return}function PSb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0;c=d[b-32|0]|0;e=d[b-31|0]|0;f=d[b-30|0]|0;g=d[b-29|0]|0;h=d[b-28|0]|0;i=d[b-27|0]|0;j=d[b-26|0]|0;a[b]=(c+1+e|0)>>>1;a[b+32|0]=(c+2+(e<<1)+f|0)>>>2;c=(e+1+f|0)>>>1&255;a[b+64|0]=c;a[b+1|0]=c;c=(e+2+(f<<1)+g|0)>>>2&255;a[b+96|0]=c;a[b+33|0]=c;c=(f+1+g|0)>>>1&255;a[b+65|0]=c;a[b+2|0]=c;c=(f+2+(g<<1)+h|0)>>>2&255;a[b+97|0]=c;a[b+34|0]=c;c=(g+1+h|0)>>>1&255;a[b+66|0]=c;a[b+3|0]=c;c=(g+2+(h<<1)+i|0)>>>2&255;a[b+98|0]=c;a[b+35|0]=c;a[b+67|0]=(h+1+i|0)>>>1;a[b+99|0]=(h+2+(i<<1)+j|0)>>>2;return}function QSb(b){b=b|0;var c=0,e=0,f=0,g=0,h=0;c=d[b-1|0]|0;e=d[b+31|0]|0;f=d[b+63|0]|0;g=a[b+95|0]|0;h=g&255;a[b]=(c+1+e|0)>>>1;a[b+1|0]=(c+2+(e<<1)+f|0)>>>2;c=(e+1+f|0)>>>1&255;a[b+32|0]=c;a[b+2|0]=c;c=(e+2+(f<<1)+h|0)>>>2&255;a[b+33|0]=c;a[b+3|0]=c;c=(f+1+h|0)>>>1&255;a[b+64|0]=c;a[b+34|0]=c;c=(f+2+h+(h<<1)|0)>>>2&255;a[b+65|0]=c;a[b+35|0]=c;a[b+66|0]=g;a[b+67|0]=g;mrc(b+96|0,g|0,4)|0;return}function RSb(a){a=a|0;var b=0;b=ca(((d[a-1|0]|0)+2+(d[a+31|0]|0)+(d[a+63|0]|0)+(d[a+95|0]|0)|0)>>>2,16843009)|0;c[a+96>>2]=b;c[a+64>>2]=b;c[a+32>>2]=b;c[a>>2]=b;return}function SSb(a){a=a|0;var b=0;b=ca(((d[a-32|0]|0)+2+(d[a-31|0]|0)+(d[a-30|0]|0)+(d[a-29|0]|0)|0)>>>2,16843009)|0;c[a+96>>2]=b;c[a+64>>2]=b;c[a+32>>2]=b;c[a>>2]=b;return}function TSb(a){a=a|0;c[a+96>>2]=-2139062144;c[a+64>>2]=-2139062144;c[a+32>>2]=-2139062144;c[a>>2]=-2139062144;return}function USb(a,b,d){a=a|0;b=b|0;d=d|0;c[d>>2]=14;c[d+4>>2]=72;c[d+8>>2]=170;c[d+12>>2]=180;c[d+16>>2]=142;c[d+24>>2]=322;c[d+28>>2]=828;c[d+20>>2]=1160;c[d+32>>2]=76;c[d+36>>2]=2174;c[d+40>>2]=880;c[d+44>>2]=956;c[d+48>>2]=100;c[d+52>>2]=1478;c[d+56>>2]=1476;c[d+60>>2]=2966;c[d+120>>2]=1956;c[d+124>>2]=1960;c[d+68>>2]=2204;c[d+72>>2]=2208;c[d+84>>2]=930;c[d+180>>2]=440;c[d+184>>2]=438;c[d+132>>2]=592;c[d+136>>2]=594;c[d+112>>2]=2208;c[d+96>>2]=2208;c[d+104>>2]=2208;c[d+88>>2]=2208;c[d+64>>2]=2208;c[d+108>>2]=2204;c[d+92>>2]=2204;c[d+80>>2]=2204;c[d+116>>2]=930;c[d+100>>2]=930;c[d+176>>2]=594;c[d+160>>2]=594;c[d+168>>2]=594;c[d+152>>2]=594;c[d+128>>2]=594;c[d+172>>2]=592;c[d+156>>2]=592;c[d+144>>2]=592;return}function VSb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=0;g=0;do{h=a+(g<<1)|0;i=b[h>>1]|0;j=i<<16>>16;k=e[d+(g<<1)>>1]|0;if(i<<16>>16>0){l=(ca(e[c+(g<<1)>>1]|0,k+j|0)|0)>>>16&65535}else{l=-((ca(e[c+(g<<1)>>1]|0,k-j|0)|0)>>>16)&65535}b[h>>1]=l;f=l<<16>>16|f;g=g+1|0;}while((g|0)<64);return(f|0)!=0|0}function WSb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=0;g=0;do{h=a+(g<<1)|0;i=b[h>>1]|0;j=i<<16>>16;k=e[d+(g<<1)>>1]|0;if(i<<16>>16>0){l=(ca(e[c+(g<<1)>>1]|0,k+j|0)|0)>>>16&65535}else{l=-((ca(e[c+(g<<1)>>1]|0,k-j|0)|0)>>>16)&65535}b[h>>1]=l;f=l<<16>>16|f;g=g+1|0;}while((g|0)<16);return(f|0)!=0|0}function XSb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=0;g=0;do{h=0;i=0;do{j=a+(g<<5)+(i<<1)|0;k=b[j>>1]|0;l=k<<16>>16;m=e[d+(i<<1)>>1]|0;if(k<<16>>16>0){n=(ca(e[c+(i<<1)>>1]|0,m+l|0)|0)>>>16&65535}else{n=-((ca(e[c+(i<<1)>>1]|0,m-l|0)|0)>>>16)&65535}b[j>>1]=n;h=n<<16>>16|h;i=i+1|0;}while((i|0)<16);f=((h|0)!=0)<<g|f;g=g+1|0;}while((g|0)<4);return f|0}function YSb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=0;f=0;do{g=a+(f<<1)|0;h=b[g>>1]|0;i=h<<16>>16;if(h<<16>>16>0){j=(ca(i+d|0,c)|0)>>>16&65535}else{j=-((ca(d-i|0,c)|0)>>>16)&65535}b[g>>1]=j;e=j<<16>>16|e;f=f+1|0;}while((f|0)<16);return(e|0)!=0|0}function ZSb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[a>>1]|0;f=e<<16>>16;if(e<<16>>16>0){g=(ca(f+d|0,c)|0)>>>16&65535}else{g=-((ca(d-f|0,c)|0)>>>16)&65535}b[a>>1]=g;f=a+2|0;e=b[f>>1]|0;h=e<<16>>16;if(e<<16>>16>0){i=(ca(h+d|0,c)|0)>>>16&65535}else{i=-((ca(d-h|0,c)|0)>>>16)&65535}b[f>>1]=i;f=a+4|0;h=b[f>>1]|0;e=h<<16>>16;if(h<<16>>16>0){j=(ca(e+d|0,c)|0)>>>16&65535}else{j=-((ca(d-e|0,c)|0)>>>16)&65535}b[f>>1]=j;f=i|g|j;j=a+6|0;a=b[j>>1]|0;g=a<<16>>16;if(a<<16>>16>0){k=(ca(g+d|0,c)|0)>>>16&65535;b[j>>1]=k;l=f|k;m=l<<16>>16!=0;n=m&1;return n|0}else{k=-((ca(d-g|0,c)|0)>>>16)&65535;b[j>>1]=k;l=f|k;m=l<<16>>16!=0;n=m&1;return n|0}return 0}function _Sb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=(e|0)%6|0;g=(e|0)/6|0;e=g-4|0;if((e|0)>-1){h=0;do{i=a+(h<<1)|0;b[i>>1]=(ca(b[i>>1]|0,c[d+(f<<6)+(h<<2)>>2]|0)|0)<<e;h=h+1|0;}while((h|0)<16);return}h=4-g|0;g=1<<h-1;e=0;do{i=a+(e<<1)|0;b[i>>1]=(ca(b[i>>1]|0,c[d+(f<<6)+(e<<2)>>2]|0)|0)+g>>h;e=e+1|0;}while((e|0)<16);return}function $Sb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=(e|0)/6|0;g=f-6|0;h=c[d+(((e|0)%6|0)<<6)>>2]|0;if((g|0)>-1){e=h<<g;b[a>>1]=ca(b[a>>1]|0,e)|0;g=a+2|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+4|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+6|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+8|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+10|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+12|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+14|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+16|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+18|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+20|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+22|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+24|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+26|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+28|0;b[g>>1]=ca(b[g>>1]|0,e)|0;g=a+30|0;b[g>>1]=ca(b[g>>1]|0,e)|0;return}e=6-f|0;f=1<<e-1;g=0;do{d=a+(g<<1)|0;b[d>>1]=(ca(b[d>>1]|0,h)|0)+f>>e;g=g+1|0;}while((g|0)<16);return}function aTb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=(e|0)%6|0;g=(e|0)/6|0;e=g-6|0;if((e|0)>-1){h=0;do{i=a+(h<<1)|0;b[i>>1]=(ca(b[i>>1]|0,c[d+(f<<8)+(h<<2)>>2]|0)|0)<<e;h=h+1|0;}while((h|0)<64);return}h=6-g|0;g=1<<h-1;e=0;do{i=a+(e<<1)|0;b[i>>1]=(ca(b[i>>1]|0,c[d+(f<<8)+(e<<2)>>2]|0)|0)+g>>h;e=e+1|0;}while((e|0)<64);return}function bTb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=b[a>>1]|0;h=b[a+2>>1]|0;i=h+g|0;j=b[a+4>>1]|0;k=b[a+6>>1]|0;l=k+j|0;m=b[a+8>>1]|0;n=b[a+10>>1]|0;o=n+m|0;p=b[a+12>>1]|0;q=b[a+14>>1]|0;a=q+p|0;r=g-h|0;h=j-k|0;k=m-n|0;n=p-q|0;q=l+i|0;p=a+o|0;m=h+r|0;j=n+k|0;g=i-l|0;l=o-a|0;a=r-h|0;h=k-n|0;n=c[e+(((f|0)%6|0)<<6)>>2]<<((f|0)/6|0);b[d>>1]=((ca(p+q|0,n)|0)+32|0)>>>6;b[d+32>>1]=((ca(j+m|0,n)|0)+32|0)>>>6;b[d+64>>1]=((ca(q-p|0,n)|0)+32|0)>>>6;b[d+96>>1]=((ca(m-j|0,n)|0)+32|0)>>>6;b[d+128>>1]=((ca(g-l|0,n)|0)+32|0)>>>6;b[d+160>>1]=((ca(a-h|0,n)|0)+32|0)>>>6;b[d+192>>1]=((ca(l+g|0,n)|0)+32|0)>>>6;b[d+224>>1]=((ca(h+a|0,n)|0)+32|0)>>>6;return}function cTb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=b[a>>1]|0;g=a+2|0;h=b[g>>1]|0;i=h+f|0;j=a+4|0;k=b[j>>1]|0;l=a+6|0;m=b[l>>1]|0;n=m+k|0;o=a+8|0;p=b[o>>1]|0;q=a+10|0;r=b[q>>1]|0;s=r+p|0;t=a+12|0;u=b[t>>1]|0;v=a+14|0;w=b[v>>1]|0;x=w+u|0;y=f-h|0;h=k-m|0;m=p-r|0;r=u-w|0;w=n+i|0;u=x+s|0;p=h+y|0;k=r+m|0;f=i-n|0;n=s-x|0;x=y-h|0;h=m-r|0;r=c[d+(((e|0)%6|0)<<6)>>2]<<((e|0)/6|0);b[a>>1]=((ca(u+w|0,r)|0)+32|0)>>>6;b[g>>1]=((ca(k+p|0,r)|0)+32|0)>>>6;b[j>>1]=((ca(w-u|0,r)|0)+32|0)>>>6;b[l>>1]=((ca(p-k|0,r)|0)+32|0)>>>6;b[o>>1]=((ca(f-n|0,r)|0)+32|0)>>>6;b[q>>1]=((ca(x-h|0,r)|0)+32|0)>>>6;b[t>>1]=((ca(n+f|0,r)|0)+32|0)>>>6;b[v>>1]=((ca(h+x|0,r)|0)+32|0)>>>6;return}function dTb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=b[a>>1]|0;e=a+2|0;f=b[e>>1]|0;g=f+d|0;h=a+4|0;i=b[h>>1]|0;j=a+6|0;k=b[j>>1]|0;l=k<<16>>16;m=l+i|0;n=d-f|0;f=i-l|0;l=((ca(m+g|0,c)|0)>>>5)+32|0;i=((ca(g-m|0,c)|0)>>>5)+32|0;m=((ca(f+n|0,c)|0)>>>5)+32|0;g=((ca(n-f|0,c)|0)>>>5)+32|0;if((l|i|m|g)<<16>>16>>>0>63>>>0){o=3;p=0;q=k}else{r=0;return r|0}while(1){k=a+(o<<1)|0;f=q<<16>>16;n=f>>31|1;d=f;while(1){if((d|0)==0){s=p;break}f=d-n|0;b[k>>1]=f;t=b[a>>1]|0;u=b[e>>1]|0;v=u+t|0;w=b[h>>1]|0;x=b[j>>1]|0;y=x+w|0;z=t-u|0;u=w-x|0;if((g^((ca(z-u|0,c)|0)>>>5)+32|(m^((ca(u+z|0,c)|0)>>>5)+32|(i^((ca(v-y|0,c)|0)>>>5)+32|((ca(y+v|0,c)|0)>>>5)+32^l)))<<16>>16>>>0<64>>>0){d=f}else{A=5;break}}if((A|0)==5){A=0;b[k>>1]=d;s=1}n=o-1|0;if((o|0)<=0){r=s;break}o=n;p=s;q=b[a+(n<<1)>>1]|0}return r|0}function eTb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=b[a>>1]|0;e=a+2|0;f=b[e>>1]|0;g=f+d|0;h=a+4|0;i=b[h>>1]|0;j=a+6|0;k=b[j>>1]|0;l=k+i|0;m=a+8|0;n=b[m>>1]|0;o=a+10|0;p=b[o>>1]|0;q=p+n|0;r=a+12|0;s=b[r>>1]|0;t=a+14|0;u=b[t>>1]|0;v=u<<16>>16;w=v+s|0;x=d-f|0;f=i-k|0;k=n-p|0;p=s-v|0;v=l+g|0;s=w+q|0;n=f+x|0;i=p+k|0;d=g-l|0;l=q-w|0;w=x-f|0;f=k-p|0;p=(ca(s+v|0,c)|0)+2080|0;k=(ca(i+n|0,c)|0)+2080|0;x=(ca(v-s|0,c)|0)+2080|0;s=(ca(n-i|0,c)|0)+2080|0;i=(ca(d-l|0,c)|0)+2080|0;n=(ca(w-f|0,c)|0)+2080|0;v=(ca(l+d|0,c)|0)+2080|0;d=(ca(f+w|0,c)|0)+2080|0;if((p|k|x|s|i|n|v|d)>>>6<<16>>16>>>0>63>>>0){y=7;z=0;A=u}else{B=0;return B|0}while(1){u=a+(y<<1)|0;w=A<<16>>16;f=w>>31|1;l=w;while(1){if((l|0)==0){C=z;break}w=l-f|0;b[u>>1]=w;q=b[a>>1]|0;g=b[e>>1]|0;D=g+q|0;E=b[h>>1]|0;F=b[j>>1]|0;G=F+E|0;H=b[m>>1]|0;I=b[o>>1]|0;J=I+H|0;K=b[r>>1]|0;L=b[t>>1]|0;M=L+K|0;N=q-g|0;g=E-F|0;F=H-I|0;I=K-L|0;L=G+D|0;K=M+J|0;H=g+N|0;E=I+F|0;q=D-G|0;G=J-M|0;M=N-g|0;g=F-I|0;if((d^(ca(g+M|0,c)|0)+2080|(v^(ca(G+q|0,c)|0)+2080|(n^(ca(M-g|0,c)|0)+2080|(i^(ca(q-G|0,c)|0)+2080|(s^(ca(H-E|0,c)|0)+2080|(x^(ca(L-K|0,c)|0)+2080|(k^(ca(E+H|0,c)|0)+2080|(ca(K+L|0,c)|0)+2080^p)))))))>>>6<<16>>16>>>0<64>>>0){l=w}else{O=5;break}}if((O|0)==5){O=0;b[u>>1]=l;C=1}f=y-1|0;if((y|0)<=0){B=C;break}y=f;z=C;A=b[a+(f<<1)>>1]|0}return B|0}function fTb(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if((g|0)>0){h=0}else{return}do{i=a+(h<<1)|0;j=b[i>>1]|0;k=j>>31;l=k+j^k;j=d+(h<<2)|0;c[j>>2]=l+(c[j>>2]|0);j=l-(e[f+(h<<1)>>1]|0)|0;if((j|0)<0){m=0}else{m=(j^k)-k&65535}b[i>>1]=m;h=h+1|0;}while((h|0)<(g|0));return}function gTb(a){a=a|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=15;while(1){e=c-1|0;if((c|0)<=0){f=0;g=10;break}h=b[a+(c<<1)>>1]|0;if(h<<16>>16==0){c=e}else{break}}if((g|0)==10){return f|0}if(((h<<16>>16)+1|0)>>>0>2>>>0){f=9;return f|0}else{i=e;j=0}a:while(1){k=0;e=i;while(1){l=e-1|0;if((e|0)<=0){break a}m=b[a+(e<<1)>>1]|0;if(m<<16>>16==0){k=k+1|0;e=l}else{break}}if(((m<<16>>16)+1|0)>>>0>2>>>0){f=9;g=10;break}else{i=l;j=(d[98152+k|0]|0)+j|0}}if((g|0)==10){return f|0}f=(d[98152+k|0]|0)+j|0;return f|0}function hTb(a){a=a|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=16;while(1){e=c-1|0;if((c|0)<=0){f=0;g=10;break}h=b[a+(e<<1)>>1]|0;if(h<<16>>16==0){c=e}else{break}}if((g|0)==10){return f|0}if(((h<<16>>16)+1|0)>>>0>2>>>0){f=9;return f|0}else{i=e;j=0}a:while(1){k=0;e=i;while(1){l=e-1|0;if((e|0)<=0){break a}m=b[a+(l<<1)>>1]|0;if(m<<16>>16==0){k=k+1|0;e=l}else{break}}if(((m<<16>>16)+1|0)>>>0>2>>>0){f=9;g=10;break}else{i=l;j=(d[98152+k|0]|0)+j|0}}if((g|0)==10){return f|0}f=(d[98152+k|0]|0)+j|0;return f|0}function iTb(a){a=a|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=64;while(1){e=c-1|0;if((c|0)<=0){f=0;g=10;break}h=b[a+(e<<1)>>1]|0;if(h<<16>>16==0){c=e}else{break}}if((g|0)==10){return f|0}if(((h<<16>>16)+1|0)>>>0>2>>>0){f=9;return f|0}else{i=e;j=0}a:while(1){k=0;e=i;while(1){l=e-1|0;if((e|0)<=0){break a}m=b[a+(l<<1)>>1]|0;if(m<<16>>16==0){k=k+1|0;e=l}else{break}}if(((m<<16>>16)+1|0)>>>0>2>>>0){f=9;g=10;break}else{i=l;j=(d[98088+k|0]|0)+j|0}}if((g|0)==10){return f|0}f=(d[98088+k|0]|0)+j|0;return f|0}function jTb(a){a=a|0;var c=0,d=0;c=3;while(1){if(!((c|0)>-1)){d=4;break}if((b[a+(c<<1)>>1]|0)==0){c=c-1|0}else{d=4;break}}if((d|0)==4){return c|0}return 0}function kTb(a){a=a|0;var c=0,d=0;c=7;while(1){if(!((c|0)>-1)){d=4;break}if((b[a+(c<<1)>>1]|0)==0){c=c-1|0}else{d=4;break}}if((d|0)==4){return c|0}return 0}function lTb(a){a=a|0;var c=0,d=0;c=14;while(1){if(!((c|0)>-1)){d=4;break}if((b[a+(c<<1)>>1]|0)==0){c=c-1|0}else{d=4;break}}if((d|0)==4){return c|0}return 0}function mTb(a){a=a|0;var c=0,d=0;c=15;while(1){if(!((c|0)>-1)){d=4;break}if((b[a+(c<<1)>>1]|0)==0){c=c-1|0}else{d=4;break}}if((d|0)==4){return c|0}return 0}function nTb(a){a=a|0;var c=0,d=0;c=63;while(1){if(!((c|0)>-1)){d=4;break}if((b[a+(c<<1)>>1]|0)==0){c=c-1|0}else{d=4;break}}if((d|0)==4){return c|0}return 0}function oTb(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=3;while(1){f=b[a+(e<<1)>>1]|0;if(!((e|0)>-1)){break}if(f<<16>>16==0){e=e-1|0}else{break}}c[d>>2]=e;g=0;h=0;i=e;e=f;a:while(1){j=h+1|0;b[d+16+(h<<1)>>1]=e;k=g|1<<i;f=i;while(1){l=f-1|0;if((f|0)<=0){break a}m=b[a+(l<<1)>>1]|0;if(m<<16>>16==0){f=l}else{g=k;h=j;i=l;e=m;continue a}}}c[d+4>>2]=k;return j|0}function pTb(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=7;while(1){f=b[a+(e<<1)>>1]|0;if(!((e|0)>-1)){break}if(f<<16>>16==0){e=e-1|0}else{break}}c[d>>2]=e;g=0;h=0;i=e;e=f;a:while(1){j=h+1|0;b[d+16+(h<<1)>>1]=e;k=g|1<<i;f=i;while(1){l=f-1|0;if((f|0)<=0){break a}m=b[a+(l<<1)>>1]|0;if(m<<16>>16==0){f=l}else{g=k;h=j;i=l;e=m;continue a}}}c[d+4>>2]=k;return j|0}function qTb(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=14;while(1){f=b[a+(e<<1)>>1]|0;if(!((e|0)>-1)){break}if(f<<16>>16==0){e=e-1|0}else{break}}c[d>>2]=e;g=0;h=0;i=e;e=f;a:while(1){j=h+1|0;b[d+16+(h<<1)>>1]=e;k=g|1<<i;f=i;while(1){l=f-1|0;if((f|0)<=0){break a}m=b[a+(l<<1)>>1]|0;if(m<<16>>16==0){f=l}else{g=k;h=j;i=l;e=m;continue a}}}c[d+4>>2]=k;return j|0}function rTb(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=15;while(1){f=b[a+(e<<1)>>1]|0;if(!((e|0)>-1)){break}if(f<<16>>16==0){e=e-1|0}else{break}}c[d>>2]=e;g=0;h=0;i=e;e=f;a:while(1){j=h+1|0;b[d+16+(h<<1)>>1]=e;k=g|1<<i;f=i;while(1){l=f-1|0;if((f|0)<=0){break a}m=b[a+(l<<1)>>1]|0;if(m<<16>>16==0){f=l}else{g=k;h=j;i=l;e=m;continue a}}}c[d+4>>2]=k;return j|0}function sTb(a,b){a=a|0;b=b|0;c[a>>2]=b;return}function tTb(a,b){a=a|0;b=b|0;c[a>>2]=b;c[a+4>>2]=b;return}function uTb(a,b){a=a|0;b=b|0;c[a>>2]=b;c[a+32>>2]=b;return}function vTb(a,b){a=a|0;b=b|0;c[a>>2]=b;c[a+4>>2]=b;c[a+32>>2]=b;c[a+36>>2]=b;return}function wTb(a,b){a=a|0;b=b|0;c[a>>2]=b;c[a+4>>2]=b;c[a+8>>2]=b;c[a+12>>2]=b;c[a+32>>2]=b;c[a+36>>2]=b;c[a+40>>2]=b;c[a+44>>2]=b;return}function xTb(a,b){a=a|0;b=b|0;c[a>>2]=b;c[a+4>>2]=b;c[a+32>>2]=b;c[a+36>>2]=b;c[a+64>>2]=b;c[a+68>>2]=b;c[a+96>>2]=b;c[a+100>>2]=b;return}function yTb(a,b){a=a|0;b=b|0;c[a>>2]=b;c[a+4>>2]=b;c[a+8>>2]=b;c[a+12>>2]=b;c[a+32>>2]=b;c[a+36>>2]=b;c[a+40>>2]=b;c[a+44>>2]=b;c[a+64>>2]=b;c[a+68>>2]=b;c[a+72>>2]=b;c[a+76>>2]=b;c[a+96>>2]=b;c[a+100>>2]=b;c[a+104>>2]=b;c[a+108>>2]=b;return}function zTb(a,c){a=a|0;c=c|0;b[a>>1]=c;return}function ATb(a,b){a=a|0;b=b|0;c[a>>2]=b*65537|0;return}function BTb(a,c){a=a|0;c=c|0;var d=0;d=c&65535;b[a>>1]=d;b[a+16>>1]=d;return}function CTb(a,b){a=a|0;b=b|0;var d=0;d=b*65537|0;c[a>>2]=d;c[a+16>>2]=d;return}function DTb(a,b){a=a|0;b=b|0;var d=0;d=b*65537|0;c[a>>2]=d;c[a+4>>2]=d;c[a+16>>2]=d;c[a+20>>2]=d;return}function ETb(a,b){a=a|0;b=b|0;var d=0;d=b*65537|0;c[a>>2]=d;c[a+16>>2]=d;c[a+32>>2]=d;c[a+48>>2]=d;return}function FTb(a,b){a=a|0;b=b|0;var d=0;d=b*65537|0;c[a>>2]=d;c[a+4>>2]=d;c[a+16>>2]=d;c[a+20>>2]=d;c[a+32>>2]=d;c[a+36>>2]=d;c[a+48>>2]=d;c[a+52>>2]=d;return}function GTb(a,b){a=a|0;b=b|0;Cd(2433640,2574872,118,2649376)}function HTb(a,c){a=a|0;c=c|0;b[a>>1]=c*257|0;return}function ITb(a,b){a=a|0;b=b|0;Cd(2433640,2574872,118,2649376)}function JTb(a,c){a=a|0;c=c|0;var d=0;d=(c*257|0)&65535;b[a>>1]=d;b[a+8>>1]=d;return}function KTb(a,b){a=a|0;b=b|0;var d=0;d=ca(b,16843009)|0;c[a>>2]=d;c[a+8>>2]=d;return}function LTb(a,c){a=a|0;c=c|0;var d=0;d=(c*257|0)&65535;b[a>>1]=d;b[a+8>>1]=d;b[a+16>>1]=d;b[a+24>>1]=d;return}function MTb(a,b){a=a|0;b=b|0;var d=0;d=ca(b,16843009)|0;c[a>>2]=d;c[a+8>>2]=d;c[a+16>>2]=d;c[a+24>>2]=d;return}function NTb(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0.0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;f=i;i=i+11536|0;g=f|0;h=f+384|0;j=f+1920|0;k=f+2304|0;l=f+3840|0;m=f+5376|0;n=f+11520|0;c[n>>2]=32-(c[a+612>>2]|0);c[n+4>>2]=32-(c[a+608>>2]|0);c[n+8>>2]=21;c[n+12>>2]=11;o=a+8632|0;if((c[o>>2]|0)==3){p=4}else{p=(c[a+524>>2]|0)!=0?2:0}q=0;while(1){r=a+8704+(q<<2)|0;s=0;while(1){if((s|0)>=(q|0)){t=9;break}if((grc(c[r>>2]|0,c[a+8704+(s<<2)>>2]|0,16)|0)==0){t=8;break}else{s=s+1|0}}if((t|0)==8){t=0;c[a+1716+(q<<2)>>2]=c[a+1716+(s<<2)>>2];c[a+1652+(q<<2)>>2]=c[a+1652+(s<<2)>>2];c[a+1684+(q<<2)>>2]=c[a+1684+(s<<2)>>2]}else if((t|0)==9){t=0;u=MLb(1664)|0;c[a+1716+(q<<2)>>2]=u;if((u|0)==0){break}u=MLb(384)|0;c[a+1652+(q<<2)>>2]=u;if((u|0)==0){break}u=MLb(3328)|0;c[a+1684+(q<<2)>>2]=u;if((u|0)==0){break}}a:do{if((q|0)>0){u=c[n+(q<<2)>>2]|0;v=0;while(1){if((c[n+(v<<2)>>2]|0)==(u|0)){if((grc(c[r>>2]|0,c[a+8704+(v<<2)>>2]|0,16)|0)==0){break}}w=v+1|0;if((w|0)<(q|0)){v=w}else{t=18;break a}}c[a+1748+(q<<2)>>2]=c[a+1748+(v<<2)>>2];c[a+1780+(q<<2)>>2]=c[a+1780+(v<<2)>>2]}else{t=18}}while(0);if((t|0)==18){t=0;r=MLb(1664)|0;c[a+1748+(q<<2)>>2]=r;if((r|0)==0){break}r=MLb(1664)|0;c[a+1780+(q<<2)>>2]=r;if((r|0)==0){break}}r=q+1|0;if((r|0)<4){q=r}else{t=5;break}}b:do{if((t|0)==5){q=(p|0)==0;if(q){x=0}else{r=0;while(1){s=a+8704+(r+4<<2)|0;u=0;while(1){if((u|0)>=(r|0)){t=25;break}if((grc(c[s>>2]|0,c[a+8704+(u+4<<2)>>2]|0,64)|0)==0){t=24;break}else{u=u+1|0}}if((t|0)==24){t=0;c[a+1732+(r<<2)>>2]=c[a+1732+(u<<2)>>2];c[a+1668+(r<<2)>>2]=c[a+1668+(u<<2)>>2];c[a+1700+(r<<2)>>2]=c[a+1700+(u<<2)>>2]}else if((t|0)==25){t=0;v=MLb(6656)|0;c[a+1732+(r<<2)>>2]=v;if((v|0)==0){break b}v=MLb(1536)|0;c[a+1668+(r<<2)>>2]=v;if((v|0)==0){break b}v=MLb(13312)|0;c[a+1700+(r<<2)>>2]=v;if((v|0)==0){break b}}c:do{if((r|0)>0){v=c[n+(r<<2)>>2]|0;w=0;while(1){if((c[n+(w<<2)>>2]|0)==(v|0)){if((grc(c[s>>2]|0,c[a+8704+(w+4<<2)>>2]|0,64)|0)==0){break}}y=w+1|0;if((y|0)<(r|0)){w=y}else{t=34;break c}}c[a+1764+(r<<2)>>2]=c[a+1764+(w<<2)>>2];c[a+1796+(r<<2)>>2]=c[a+1796+(w<<2)>>2]}else{t=34}}while(0);if((t|0)==34){t=0;s=MLb(6656)|0;c[a+1764+(r<<2)>>2]=s;if((s|0)==0){break b}s=MLb(6656)|0;c[a+1796+(r<<2)>>2]=s;if((s|0)==0){break b}}s=r+1|0;if((s|0)<(p|0)){r=s}else{x=0;break}}}do{r=0;while(1){s=(r>>>2&1)+(r&1)|0;c[j+(x<<6)+(r<<2)>>2]=d[1552272+(x*3|0)+s|0]|0;c[g+(x<<6)+(r<<2)>>2]=e[689576+(x*6|0)+(s<<1)>>1]|0;s=r+1|0;if((s|0)<16){r=s}else{z=0;break}}do{r=d[688976+(z>>>1&12|z&3)|0]|0;c[k+(x<<8)+(z<<2)>>2]=d[1552176+(x*6|0)+r|0]|0;c[h+(x<<8)+(z<<2)>>2]=e[688992+(x*12|0)+(r<<1)>>1]|0;z=z+1|0;}while((z|0)<64);x=x+1|0;}while((x|0)<6);r=c[a+8704>>2]|0;s=c[a+1652>>2]|0;u=0;do{v=0;do{y=r+v|0;c[s+(u<<6)+(v<<2)>>2]=ca(d[y]|0,c[j+(u<<6)+(v<<2)>>2]|0)|0;A=d[y]|0;c[l+(u<<6)+(v<<2)>>2]=((A>>>1)+(c[g+(u<<6)+(v<<2)>>2]<<4)|0)/(A|0)|0;v=v+1|0;}while((v|0)<16);v=c[a+8708>>2]|0;A=c[a+1656>>2]|0;y=0;do{B=v+y|0;c[A+(u<<6)+(y<<2)>>2]=ca(d[B]|0,c[j+(u<<6)+(y<<2)>>2]|0)|0;C=d[B]|0;c[l+384+(u<<6)+(y<<2)>>2]=((C>>>1)+(c[g+(u<<6)+(y<<2)>>2]<<4)|0)/(C|0)|0;y=y+1|0;}while((y|0)<16);y=c[a+8712>>2]|0;A=c[a+1660>>2]|0;v=0;do{C=y+v|0;c[A+(u<<6)+(v<<2)>>2]=ca(d[C]|0,c[j+(u<<6)+(v<<2)>>2]|0)|0;B=d[C]|0;c[l+768+(u<<6)+(v<<2)>>2]=((B>>>1)+(c[g+(u<<6)+(v<<2)>>2]<<4)|0)/(B|0)|0;v=v+1|0;}while((v|0)<16);v=c[a+8716>>2]|0;A=c[a+1664>>2]|0;y=0;do{B=v+y|0;c[A+(u<<6)+(y<<2)>>2]=ca(d[B]|0,c[j+(u<<6)+(y<<2)>>2]|0)|0;C=d[B]|0;c[l+1152+(u<<6)+(y<<2)>>2]=((C>>>1)+(c[g+(u<<6)+(y<<2)>>2]<<4)|0)/(C|0)|0;y=y+1|0;}while((y|0)<16);if(!q){y=0;do{A=c[a+8704+(y+4<<2)>>2]|0;v=c[a+1668+(y<<2)>>2]|0;C=0;do{B=A+C|0;c[v+(u<<8)+(C<<2)>>2]=ca(d[B]|0,c[k+(u<<8)+(C<<2)>>2]|0)|0;D=d[B]|0;c[m+(y*1536|0)+(u<<8)+(C<<2)>>2]=((D>>>1)+(c[h+(u<<8)+(C<<2)>>2]<<4)|0)/(D|0)|0;C=C+1|0;}while((C|0)<64);y=y+1|0;}while((y|0)<(p|0))}u=u+1|0;}while((u|0)<6);u=a+524|0;s=0;r=70;y=-1;C=-1;while(1){v=(s|0)/6|0;A=yrc(1,0,v+23|0)|0;w=G;D=(s|0)%6|0;B=v-1|0;E=(B|0)<1;F=1-v|0;H=1<<v-2;I=0;J=r;K=y;L=C;while(1){M=c[a+1684+(I<<2)>>2]|0;N=c[a+1716+(I<<2)>>2]|0;O=n+(I<<2)|0;P=a+1748+(I<<2)|0;Q=a+1780+(I<<2)|0;R=I>>>0<2>>>0;S=(I-2|0)>>>0<2>>>0;T=0;U=J;V=K;W=L;while(1){X=c[l+(I*384|0)+(D<<6)+(T<<2)>>2]|0;Y=Frc(A,w,X,(X|0)<0|0?-1:0)|0;c[M+(s<<6)+(T<<2)>>2]=Y;if(E){Z=X<<F}else{Z=X+H>>B}b[N+(s<<5)+(T<<1)>>1]=Z;do{if((Z|0)==0){_=W;$=V;aa=(U|0)<(s|0)?U:s}else{X=((c[O>>2]<<10)+(Z>>1)|0)/(Z|0)|0;Y=32768/(Z|0)|0;b[(c[P>>2]|0)+(s<<5)+(T<<1)>>1]=(X|0)<(Y|0)?X:Y;b[(c[Q>>2]|0)+(s<<5)+(T<<1)>>1]=Y;Y=(Z|0)>65535;X=Y&(s|0)>(W|0)&R?s:W;if(!(Y&(s|0)>(V|0))){_=X;$=V;aa=U;break}_=X;$=S?s:V;aa=U}}while(0);X=T+1|0;if((X|0)<16){T=X;U=aa;V=$;W=_}else{break}}W=I+1|0;if((W|0)<4){I=W;J=aa;K=$;L=_}else{break}}if((c[u>>2]|0)==0|q){ba=_;da=$;ea=aa}else{L=yrc(1,0,v+24|0)|0;K=G;J=(s|0)<6;I=-v|0;H=1<<B;F=0;E=aa;w=$;A=_;while(1){W=c[a+1700+(F<<2)>>2]|0;V=c[a+1732+(F<<2)>>2]|0;U=n+(F<<2)|0;T=a+1764+(F<<2)|0;S=a+1796+(F<<2)|0;R=F>>>0<2>>>0;Q=(F-2|0)>>>0<2>>>0;P=0;O=E;N=w;M=A;while(1){X=c[m+(F*1536|0)+(D<<8)+(P<<2)>>2]|0;Y=Frc(L,K,X,(X|0)<0|0?-1:0)|0;c[W+(s<<8)+(P<<2)>>2]=Y;if(J){fa=X<<I}else{fa=X+H>>v}b[V+(s<<7)+(P<<1)>>1]=fa;do{if((fa|0)==0){ga=M;ha=N;ia=(O|0)<(s|0)?O:s}else{X=((c[U>>2]<<10)+(fa>>1)|0)/(fa|0)|0;Y=32768/(fa|0)|0;b[(c[T>>2]|0)+(s<<7)+(P<<1)>>1]=(X|0)<(Y|0)?X:Y;b[(c[S>>2]|0)+(s<<7)+(P<<1)>>1]=Y;Y=(fa|0)>65535;X=Y&(s|0)>(M|0)&R?s:M;if(!(Y&(s|0)>(N|0))){ga=X;ha=N;ia=O;break}ga=X;ha=Q?s:N;ia=O}}while(0);X=P+1|0;if((X|0)<64){P=X;O=ia;N=ha;M=ga}else{break}}M=F+1|0;if((M|0)<(p|0)){F=M;E=ia;w=ha;A=ga}else{ba=ga;da=ha;ea=ia;break}}}A=s+1|0;if((A|0)<52){s=A;r=ea;y=da;C=ba}else{break}}C=MLb(9216)|0;y=C;c[a+1812>>2]=y;if((C|0)==0){break}C=a+1704|0;r=a+1688|0;s=c[u>>2]|0;q=0;while(1){A=(q|0)==17;w=q+1|0;E=0;do{F=E&1;d:do{if((s|0)!=0|(F|0)==0){v=(F|0)!=0;H=v?64:16;I=(E|0)>1?0:12;if(A){J=0;while(1){b[y+8704+(E<<7)+(J<<1)>>1]=32767;J=J+1|0;if((J|0)>=(H|0)){break d}}}if(v){J=0;do{K=(J|0)==0?12:I;if((q|0)<(K|0)){b[y+(q<<9)+(E<<7)+(J<<1)>>1]=0}else{ja=+(c[(c[C>>2]|0)+13056+(J<<2)>>2]|0);ka=ja*(+ad(+(+(w-K|0)/+(18-K|0)*18.0/10.0))*.003+-.003)+.5;if(ka<32767.0){la=~~ka}else{la=32767}b[y+(q<<9)+(E<<7)+(J<<1)>>1]=la}J=J+1|0;}while((J|0)<(H|0))}else{J=0;do{v=(J|0)==0?12:I;if((q|0)<(v|0)){b[y+(q<<9)+(E<<7)+(J<<1)>>1]=0}else{ka=+(c[(c[r>>2]|0)+3264+(J<<2)>>2]|0);ja=ka*(+ad(+(+(w-v|0)/+(18-v|0)*18.0/10.0))*.003+-.003)+.5;if(ja<32767.0){ma=~~ja}else{ma=32767}b[y+(q<<9)+(E<<7)+(J<<1)>>1]=ma}J=J+1|0;}while((J|0)<(H|0))}}}while(0);E=E+1|0;}while((E|0)<(((c[o>>2]|0)==3?4:3)|0));if((w|0)<18){q=w}else{break}}if((c[a+28836>>2]|0)!=0){na=0;i=f;return na|0}q=a+632|0;y=c[q>>2]|0;r=c[a+3216>>2]|0;if((d[r+((y|0)<51?y:51)|0]|0|0)>(da|0)){oa=y}else{C=y;while(1){y=C+1|0;c[q>>2]=y;if((d[r+((y|0)<51?y:51)|0]|0|0)>(da|0)){oa=y;break}else{C=y}}}C=a+636|0;y=c[C>>2]|0;if((ea|0)>(y|0)){pa=y}else{y=ea-1|0;c[C>>2]=y;pa=y}if((ba|0)<(oa|0)){qa=oa}else{y=ba+1|0;c[q>>2]=y;qa=y}do{if((c[a+152>>2]|0)==0){if((c[a+8372>>2]|0)>=100){ra=pa;break}if((d[r+((pa|0)<51?pa:51)|0]|0)>>>0<13>>>0|(pa|0)<13){sa=pa}else{ra=pa;break}while(1){y=sa+1|0;c[C>>2]=y;if((d[r+((y|0)<51?y:51)|0]|0)>>>0<13>>>0|(y|0)<13){sa=y}else{ra=y;break}}}else{ra=pa}}while(0);if((qa|0)<=(ra|0)){na=0;i=f;return na|0}ILb(a,0,2393176,(r=i,i=i+16|0,c[r>>2]=qa,c[r+8>>2]=ra,r)|0);i=r;na=-1;i=f;return na|0}}while(0);OTb(a);na=-1;i=f;return na|0}function OTb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=0;do{d=a+1716+(b<<2)|0;e=0;while(1){if((e|0)>=(b|0)){break}if((c[d>>2]|0)==(c[a+1716+(e<<2)>>2]|0)){break}else{e=e+1|0}}if((e|0)==(b|0)){NLb(c[d>>2]|0);NLb(c[a+1652+(b<<2)>>2]|0);NLb(c[a+1684+(b<<2)>>2]|0)}f=a+1748+(b<<2)|0;g=0;while(1){if((g|0)>=(b|0)){break}if((c[f>>2]|0)==(c[a+1748+(g<<2)>>2]|0)){break}else{g=g+1|0}}if((g|0)==(b|0)){NLb(c[f>>2]|0);NLb(c[a+1780+(b<<2)>>2]|0)}b=b+1|0;}while((b|0)<4);b=a+8632|0;d=0;do{e=a+1732+(d<<2)|0;h=0;while(1){if((h|0)>=(d|0)){break}if((c[e>>2]|0)==(c[a+1732+(h<<2)>>2]|0)){break}else{h=h+1|0}}if((h|0)==(d|0)){NLb(c[e>>2]|0);NLb(c[a+1668+(d<<2)>>2]|0);NLb(c[a+1700+(d<<2)>>2]|0)}f=a+1764+(d<<2)|0;g=0;while(1){if((g|0)>=(d|0)){break}if((c[f>>2]|0)==(c[a+1764+(g<<2)>>2]|0)){break}else{g=g+1|0}}if((g|0)==(d|0)){NLb(c[f>>2]|0);NLb(c[a+1796+(d<<2)>>2]|0)}d=d+1|0;}while((d|0)<(((c[b>>2]|0)==3?4:2)|0));NLb(c[a+1812>>2]|0);return}function PTb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;c[a+168>>2]=2;e=QLb(b)|0;if((e|0)==0){ILb(a,0,2574848,(f=i,i=i+8|0,c[f>>2]=b,f)|0);i=f;g=-1;i=d;return g|0}f=_b(e|0,35)|0;if((f|0)!=0){b=f;do{mrc(b|0,32,mc(b|0,2433632)|0)|0;b=_b(e|0,35)|0;}while((b|0)!=0)}b=QTb(a,e,2348088,a+176|0,99160,16)|0;f=QTb(a,e,2286776,a+192|0,99128,16)|0|b;b=f|(QTb(a,e,2237008,a+208|0,99160,16)|0);f=b|(QTb(a,e,2196752,a+224|0,99128,16)|0);b=f|(QTb(a,e,2165136,a+240|0,99e3,64)|0);f=b|(QTb(a,e,2139120,a+304|0,98872,64)|0);if((c[a+8632>>2]|0)==3){b=QTb(a,e,2115712,a+368|0,99e3,64)|0|f;h=b|(QTb(a,e,2633552,a+432|0,98872,64)|0)}else{h=f}NLb(e);g=h;i=d;return g|0}function QTb(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=i;i=i+8|0;k=j|0;l=Db(d|0,e|0)|0;if((l|0)==0){mrc(f|0,16,h|0)|0;m=0;i=j;return m|0}d=lrc(e|0)|0;n=l+d|0;if(((a[n]|0)-85&255)>>>0<2>>>0){o=l+(d+1)|0}else{o=n}n=Db(o|0,2609856)|0;a:do{if((h|0)>0){d=0;l=o;while(1){p=ae(l|0,2583304)|0;if((p|0)==0){q=0;r=d;break a}s=ae(p|0,2562768)|0;if((s|0)==0){q=0;r=d;break a}c[k>>2]=-1;Bd(s|0,2545192,(t=i,i=i+8|0,c[t>>2]=k,t)|0)|0;i=t;p=c[k>>2]|0;if((d|p|0)==0){u=9;break}if((p-1|0)>>>0>254>>>0){u=11;break}a[f+d|0]=p;p=d+1|0;if((p|0)<(h|0)){d=p;l=s}else{q=s;r=p;break a}}if((u|0)==9){nrc(f|0,g|0,h)|0;m=0;i=j;return m|0}else if((u|0)==11){ILb(b,0,2527528,(t=i,i=i+8|0,c[t>>2]=e,t)|0);i=t;m=-1;i=j;return m|0}}else{q=o;r=0}}while(0);if((q>>>0<=n>>>0|(n|0)==0)&(r|0)==(h|0)){m=0;i=j;return m|0}ILb(b,0,2512448,(t=i,i=i+8|0,c[t>>2]=e,t)|0);i=t;m=-1;i=j;return m|0}function RTb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;i=i+96|0;g=f|0;h=f+64|0;j=0;while(1){k=j+1|0;l=1<<j;m=l+65535|0;n=(j|0)==0;o=(n&1)+j|0;p=3<<o-1;q=o&255;r=(o|0)<6;s=o+1&255;o=j+15&255;t=15<<j;a:do{if(n){u=-64;v=-64;while(1){w=v>>15;x=(w^v)-w|0;y=(x<<1)-w|0;w=y-2|0;z=v+64|0;A=3035176+(z<<2)|0;do{if((w|0)<14){a[3035178+(z<<2)|0]=k+w;b[A>>1]=(w&m)+l}else{if((w|0)<30){a[3035178+(z<<2)|0]=19;b[A>>1]=y;break}else{a[3035178+(z<<2)|0]=28;b[A>>1]=w-t+4081;break}}}while(0);a[3035179+(z<<2)|0]=(x|0)>(p|0)&r?s:q;w=u+1&65535;if(w<<16>>16<64){u=w;v=w<<16>>16}else{break}}}else{if((j|0)>0){B=-64;C=-64}else{v=-64;u=-64;while(1){w=u>>15;A=(w^u)-w|0;y=(A<<1)-w-2|0;w=u+64|0;D=3035176+(j<<9)+(w<<2)|0;E=y>>j;if((E|0)<14){a[3035176+(j<<9)+(w<<2)+2|0]=k+E;b[D>>1]=(y&m)+l}else{a[3035176+(j<<9)+(w<<2)+2|0]=28;b[D>>1]=y-t+4096}a[3035176+(j<<9)+(w<<2)+3|0]=(A|0)>(p|0)&r?s:q;A=v+1&65535;if(A<<16>>16<64){v=A;u=A<<16>>16}else{break a}}}while(1){u=C>>15;v=(u^C)-u|0;A=(v<<1)-u-2|0;u=C+64|0;w=3035176+(j<<9)+(u<<2)|0;y=A>>j;do{if((y|0)<14){a[3035176+(j<<9)+(u<<2)+2|0]=k+y;b[w>>1]=(A&m)+l}else{if((y|0)==14){a[3035176+(j<<9)+(u<<2)+2|0]=o;b[w>>1]=(A&m)+l;break}else{a[3035176+(j<<9)+(u<<2)+2|0]=28;b[w>>1]=A-t+4096;break}}}while(0);a[3035176+(j<<9)+(u<<2)+3|0]=(v|0)>(p|0)&r?s:q;A=B+1&65535;if(A<<16>>16<64){B=A;C=A<<16>>16}else{break}}}}while(0);if((k|0)<7){j=k}else{break}}j=e+37848|0;e=h|0;C=g|0;B=1;do{b[e>>1]=B&1;b[h+2>>1]=B&2;b[h+4>>1]=B&4;b[h+6>>1]=B&8;b[h+8>>1]=B&16;b[h+10>>1]=B&32;b[h+12>>1]=B&64;b[h+14>>1]=B&128;b[h+16>>1]=B&256;b[h+18>>1]=B&512;b[h+20>>1]=B&1024;b[h+22>>1]=B&2048;b[h+24>>1]=B&4096;b[h+26>>1]=B&8192;b[h+28>>1]=B&16384;b[h+30>>1]=B&65535&-32768;q=We[c[j>>2]&2047](e,g)|0;s=1-q+(c[C>>2]|0)|0;r=q-1|0;if((r|0)>0&(s|0)>0){q=0;p=0;t=s;s=B<<(rrc(B|0)|0)+1;l=0;while(1){m=(t|0)<7?t-1|0:6;o=rrc(s|0)|0;n=d[676656+(m<<5)+(o<<1)+1|0]|0;F=n+q|0;G=p<<n|(d[676656+(m<<5)+(o<<1)|0]|0);m=t-o|0;n=l+1|0;if((n|0)<(r|0)&(m|0)>0){q=F;p=G;t=m;s=s<<o+1;l=n}else{break}}H=F;I=G<<5}else{H=0;I=0}c[2772392+(B<<2)>>2]=I+H;B=B+1|0;}while((B|0)<65536);i=f;return}function STb(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=c[f+18660>>2]|0;k=e[18864+(j<<5)+(h<<1)>>1]|0;l=e[97192+(j<<5)+(h<<1)>>1]|0;m=e[100176+(h<<1)>>1]|0;n=ve[c[f+37776+(h<<2)>>2]&4095](i)|0;h=b[i+(n<<1)>>1]|0;f=h<<16>>16;o=h<<16>>16>-1?f:-f|0;if((n|0)!=63){f=(d[18736+(j<<6)+n|0]|0)+k+(g+36)|0;h=d[f]|0;a[f]=a[100553+(h<<1)|0]|0;f=g+32|0;c[f>>2]=(c[f>>2]|0)+(e[101200+((h^1)<<1)>>1]|0);h=(d[97128+n|0]|0)+l+(g+36)|0;p=d[h]|0;a[h]=a[100553+(p<<1)|0]|0;c[f>>2]=(c[f>>2]|0)+(e[101200+((p^1)<<1)>>1]|0)}p=m+1+(g+36)|0;f=d[p]|0;do{if((o|0)>1){a[p]=a[100553+(f<<1)|0]|0;h=g+32|0;q=(c[h>>2]|0)+(e[101200+((f^1)<<1)>>1]|0)|0;c[h>>2]=q;r=m+5+(g+36)|0;s=d[r]|0;if((o|0)<15){t=o-1|0;c[h>>2]=(e[3059120+(t<<8)+(s<<1)>>1]|0)+q;a[r]=a[(d[r]|0)+(3057200+(t<<7))|0]|0;u=4;break}c[h>>2]=(e[3062704+(s<<1)>>1]|0)+q;a[r]=a[3058992+(d[r]|0)|0]|0;r=o-14|0;if((o-15|0)>>>0<255>>>0){v=d[16464+r|0]|0}else{v=(d[16464+(r>>>8)|0]|0)+16|0}c[h>>2]=(c[h>>2]|0)+(v<<8);u=4}else{a[p]=a[100552+(f<<1)|0]|0;h=g+32|0;c[h>>2]=(e[101200+(f<<1)>>1]|0)+256+(c[h>>2]|0);u=1}}while(0);if((n|0)<=0){return}f=g+32|0;p=u;u=n;a:while(1){n=u;while(1){w=n-1|0;x=b[i+(w<<1)>>1]|0;if(!(x<<16>>16==0)){break}v=(d[18736+(j<<6)+w|0]|0)+k+(g+36)|0;o=d[v]|0;a[v]=a[100552+(o<<1)|0]|0;c[f>>2]=(c[f>>2]|0)+(e[101200+(o<<1)>>1]|0);if((w|0)>0){n=w}else{y=26;break a}}n=x<<16>>16;o=x<<16>>16>-1?n:-n|0;n=(d[18736+(j<<6)+w|0]|0)+k+(g+36)|0;v=d[n]|0;a[n]=a[100553+(v<<1)|0]|0;c[f>>2]=(c[f>>2]|0)+(e[101200+((v^1)<<1)>>1]|0);v=(d[97128+w|0]|0)+l+(g+36)|0;n=d[v]|0;a[v]=a[100552+(n<<1)|0]|0;c[f>>2]=(c[f>>2]|0)+(e[101200+(n<<1)>>1]|0);n=(d[1648664+p|0]|0)+m+(g+36)|0;v=d[n]|0;if((o|0)>1){a[n]=a[100553+(v<<1)|0]|0;h=(c[f>>2]|0)+(e[101200+((v^1)<<1)>>1]|0)|0;c[f>>2]=h;r=(d[1648616+p|0]|0)+m+(g+36)|0;q=d[r]|0;if((o|0)<15){s=o-1|0;c[f>>2]=(e[3059120+(s<<8)+(q<<1)>>1]|0)+h;a[r]=a[(d[r]|0)+(3057200+(s<<7))|0]|0}else{c[f>>2]=(e[3062704+(q<<1)>>1]|0)+h;a[r]=a[3058992+(d[r]|0)|0]|0;r=o-14|0;if((o-15|0)>>>0<255>>>0){z=d[16464+r|0]|0}else{z=(d[16464+(r>>>8)|0]|0)+16|0}c[f>>2]=(c[f>>2]|0)+(z<<8)}A=a[1648648+p|0]|0}else{a[n]=a[100552+(v<<1)|0]|0;n=a[1648640+p|0]|0;c[f>>2]=(e[101200+(v<<1)>>1]|0)+256+(c[f>>2]|0);A=n}if((w|0)>0){p=A&255;u=w}else{y=26;break}}if((y|0)==26){return}}function TTb(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=c[f+18660>>2]|0;k=e[18864+(j<<5)+(h<<1)>>1]|0;l=e[97192+(j<<5)+(h<<1)>>1]|0;j=e[100176+(h<<1)>>1]|0;m=ve[c[f+37776+(h<<2)>>2]&4095](i)|0;f=b[i+(m<<1)>>1]|0;n=f<<16>>16;o=f<<16>>16>-1?n:-n|0;if((m|0)!=(d[99288+h|0]|0|0)){h=m+k+(g+36)|0;n=d[h]|0;a[h]=a[100553+(n<<1)|0]|0;h=g+32|0;c[h>>2]=(c[h>>2]|0)+(e[101200+((n^1)<<1)>>1]|0);n=m+l+(g+36)|0;f=d[n]|0;a[n]=a[100553+(f<<1)|0]|0;c[h>>2]=(c[h>>2]|0)+(e[101200+((f^1)<<1)>>1]|0)}f=j+1+(g+36)|0;h=d[f]|0;do{if((o|0)>1){a[f]=a[100553+(h<<1)|0]|0;n=g+32|0;p=(c[n>>2]|0)+(e[101200+((h^1)<<1)>>1]|0)|0;c[n>>2]=p;q=j+5+(g+36)|0;r=d[q]|0;if((o|0)<15){s=o-1|0;c[n>>2]=(e[3059120+(s<<8)+(r<<1)>>1]|0)+p;a[q]=a[(d[q]|0)+(3057200+(s<<7))|0]|0;t=4;break}c[n>>2]=(e[3062704+(r<<1)>>1]|0)+p;a[q]=a[3058992+(d[q]|0)|0]|0;q=o-14|0;if((o-15|0)>>>0<255>>>0){u=d[16464+q|0]|0}else{u=(d[16464+(q>>>8)|0]|0)+16|0}c[n>>2]=(c[n>>2]|0)+(u<<8);t=4}else{a[f]=a[100552+(h<<1)|0]|0;n=g+32|0;c[n>>2]=(e[101200+(h<<1)>>1]|0)+256+(c[n>>2]|0);t=1}}while(0);if((m|0)<=0){return}h=g+32|0;f=t;t=m;a:while(1){m=t;while(1){v=m-1|0;w=b[i+(v<<1)>>1]|0;if(!(w<<16>>16==0)){break}u=v+k+(g+36)|0;o=d[u]|0;a[u]=a[100552+(o<<1)|0]|0;c[h>>2]=(c[h>>2]|0)+(e[101200+(o<<1)>>1]|0);if((v|0)>0){m=v}else{x=26;break a}}m=w<<16>>16;o=w<<16>>16>-1?m:-m|0;m=v+k+(g+36)|0;u=d[m]|0;a[m]=a[100553+(u<<1)|0]|0;c[h>>2]=(c[h>>2]|0)+(e[101200+((u^1)<<1)>>1]|0);u=v+l+(g+36)|0;m=d[u]|0;a[u]=a[100552+(m<<1)|0]|0;c[h>>2]=(c[h>>2]|0)+(e[101200+(m<<1)>>1]|0);m=(d[1648664+f|0]|0)+j+(g+36)|0;u=d[m]|0;if((o|0)>1){a[m]=a[100553+(u<<1)|0]|0;n=(c[h>>2]|0)+(e[101200+((u^1)<<1)>>1]|0)|0;c[h>>2]=n;q=(d[1648616+f|0]|0)+j+(g+36)|0;p=d[q]|0;if((o|0)<15){r=o-1|0;c[h>>2]=(e[3059120+(r<<8)+(p<<1)>>1]|0)+n;a[q]=a[(d[q]|0)+(3057200+(r<<7))|0]|0}else{c[h>>2]=(e[3062704+(p<<1)>>1]|0)+n;a[q]=a[3058992+(d[q]|0)|0]|0;q=o-14|0;if((o-15|0)>>>0<255>>>0){y=d[16464+q|0]|0}else{y=(d[16464+(q>>>8)|0]|0)+16|0}c[h>>2]=(c[h>>2]|0)+(y<<8)}z=a[1648648+f|0]|0}else{a[m]=a[100552+(u<<1)|0]|0;m=a[1648640+f|0]|0;c[h>>2]=(e[101200+(u<<1)>>1]|0)+256+(c[h>>2]|0);z=m}if((v|0)>0){f=z&255;t=v}else{x=26;break}}if((x|0)==26){return}}function UTb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;j=i;i=i+2144|0;k=j|0;l=j+1072|0;m=g>>2;if((h|0)==0){n=VTb(b,f)|0;o=(n|0)<0|0?-1:0;p=n;i=j;return(G=o,p)|0}if((h|0)>3){yMb(b,g);if((h|0)==4){yMb(b,g+1|0)}else if((h|0)==5){yMb(b,g+2|0)}n=d[1901576+g|0]|0;q=n<<2;r=d[1901368+g|0]|0;s=WTb(b,h,0,q,r<<2)|0;t=s;u=(s|0)<0|0?-1:0;s=b+8632|0;if((c[s>>2]|0)==3){v=(r<<7)+q|0;w=(r<<6)+q|0;q=b+36776+(h<<2)|0;x=hf[c[q>>2]&1023]((c[b+24548>>2]|0)+w|0,16,(c[b+24572>>2]|0)+v|0,32)|0;y=(hf[c[q>>2]&1023]((c[b+24552>>2]|0)+w|0,16,(c[b+24576>>2]|0)+v|0,32)|0)+x|0;x=c[b+28868>>2]|0;v=Erc(y,(y|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=wrc(v,G,128,0)|0;v=x>>>8|G<<24;x=wrc(v,(v|0)<0|0?-1:0,t,u)|0;z=G;A=x}else{z=u;A=t}if((c[b+152>>2]|0)==0){t=(c[s>>2]|0)==3?3:1;u=(h|0)==4;x=b+1520|0;c[x>>2]=0;UUb(b,0,g,u?2:1);v=(h|0)==6;y=2-(u&1)|0;u=0;do{w=(u<<4)+g|0;q=d[19112+w|0]|0;B=(d[q-8+(b+27984)|0]|0)+(d[q-1+(b+27984)|0]|0)|0;if((B|0)<128){C=(B+1|0)>>>1}else{C=B}B=d[1625080+(C&127)|0]|0;D=b+27984+q|0;if((a[D]|0)==0){c[x>>2]=(c[x>>2]|0)+(d[100209+(B<<1)|0]|0)}else{a[D]=JUb(b,2,b+17024+(w<<5)|0,B)|0}do{if(!v){B=w+y|0;D=d[19112+B|0]|0;q=(d[D-8+(b+27984)|0]|0)+(d[D-1+(b+27984)|0]|0)|0;if((q|0)<128){E=(q+1|0)>>>1}else{E=q}q=d[1625080+(E&127)|0]|0;F=b+27984+D|0;if((a[F]|0)==0){c[x>>2]=(c[x>>2]|0)+(d[100209+(q<<1)|0]|0);break}else{a[F]=JUb(b,2,b+17024+(B<<5)|0,q)|0;break}}}while(0);u=u+1|0;}while((u|0)<(t|0));t=c[x>>2]|0;H=(t|0)<0|0?-1:0;I=t}else{t=k+32|0;Ee[c[b+37520>>2]&511](t,b+13920|0,(c[s>>2]|0)==3?1040:464)|0;x=(h|0)==4;u=x&1;E=(c[s>>2]|0)==3?3:1;s=(h|0)==6;if(s){y=WUb(b,k,0,g,1)|0;re[c[25118]&1023](b+28512+(n+12+(r<<3)<<1)|0,y&65535);J=2-u|0}else{y=x?2:1;x=WUb(b,k,0,g,y)|0;v=2-u|0;re[c[100472+(y-3+(v<<1)<<2)>>2]&1023](b+28512+(n+12+(r<<3)<<1)|0,x&65535);J=v}v=0;do{x=d[1625014+v|0]|0;r=(v<<4)+g|0;n=d[19112+r|0]|0;y=e[109680+(x<<1)>>1]|0;u=((a[n-1+(b+27984)|0]&127)!=0)+y+(((a[n-8+(b+27984)|0]&127)!=0)<<1)+(k+36)|0;C=d[u]|0;if((a[b+27984+n|0]|0)==0){a[u]=a[100552+(C<<1)|0]|0;c[t>>2]=(c[t>>2]|0)+(e[101200+(C<<1)>>1]|0)}else{a[u]=a[100553+(C<<1)|0]|0;c[t>>2]=(c[t>>2]|0)+(e[101200+((C^1)<<1)>>1]|0);TTb(b,k,x,b+17024+(r<<5)|0)}do{if(!s){C=r+J|0;u=d[19112+C|0]|0;n=((a[u-1+(b+27984)|0]&127)!=0)+y+(((a[u-8+(b+27984)|0]&127)!=0)<<1)+(k+36)|0;w=d[n]|0;if((a[b+27984+u|0]|0)==0){a[n]=a[100552+(w<<1)|0]|0;c[t>>2]=(c[t>>2]|0)+(e[101200+(w<<1)>>1]|0);break}else{a[n]=a[100553+(w<<1)|0]|0;c[t>>2]=(c[t>>2]|0)+(e[101200+((w^1)<<1)>>1]|0);TTb(b,k,x,b+17024+(C<<5)|0);break}}}while(0);v=v+1|0;}while((v|0)<(E|0));E=c[t>>2]|0;t=Erc(E,(E|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;E=wrc(t,G,128,0)|0;t=G;H=t>>>8|0<<24;I=E>>>8|t<<24}t=wrc(I,H,A<<8|0>>>24,z<<8|A>>>24)|0;o=G;p=t;i=j;return(G=o,p)|0}t=b+19360|0;c[t>>2]=0;xMb(b,m);if((h|0)==1){xMb(b,m+1|0)}else if((h|0)==2){xMb(b,m+2|0)}A=m<<3&8;z=g>>3<<3;g=WTb(b,h,0,A,z)|0;H=g;I=(g|0)<0|0?-1:0;g=b+18572|0;E=A>>>((c[g>>2]|0)>>>0);v=b+18576|0;k=z>>c[v>>2];J=b+36776+(d[b+36448+h|0]<<2)|0;s=hf[c[J>>2]&1023]((c[b+24548>>2]|0)+((k<<4)+E)|0,16,(c[b+24572>>2]|0)+((k<<5)+E)|0,32)|0;E=A>>>((c[g>>2]|0)>>>0);g=z>>c[v>>2];v=(hf[c[J>>2]&1023]((c[b+24552>>2]|0)+((g<<4)+E)|0,16,(c[b+24576>>2]|0)+((g<<5)+E)|0,32)|0)+s|0;s=c[b+28868>>2]|0;E=Erc(v,(v|0)<0|0?-1:0,s,(s|0)<0|0?-1:0)|0;s=G;if((c[b+152>>2]|0)==0){v=c[b+19344>>2]|0;g=(c[b+19348>>2]|0)==15|0;J=b+8632|0;z=(c[J>>2]|0)==3?3:1;do{if((v|0)==5){TUb(b,m);A=b+1520|0;c[A>>2]=(c[A>>2]|0)+(d[(d[552752+(d[b+19352+m|0]|0)|0]|0)+16465|0]|0)}else if((v|0)==4){UUb(b,0,m<<2,4>>>(g>>>0))}else{if((v-8|0)>>>0<9>>>0){A=(m|0)!=0|0;if((a[94920+(v<<2)+A|0]|0)!=0){UUb(b,0,m<<2,4>>>(g>>>0))}if((a[94922+(v<<2)+A|0]|0)==0){break}UUb(b,1,m<<2,4>>>(g>>>0));break}else{A=b+19352+m|0;k=a[A]|0;if((a[95296+(k&255)|0]|0)==0){K=k}else{UUb(b,0,m<<2,2);K=a[A]|0}if((a[95313+(K&255)|0]|0)==0){break}UUb(b,1,m<<2,2);break}}}while(0);K=b+19356|0;g=b+1520|0;v=b+37660|0;A=b+19364|0;k=(d[19529+(h<<1)|0]|0)>>>3;x=(h|0)<3|0;y=m;while(1){r=1<<y;C=y<<2;w=19112+C|0;n=0;do{do{if((c[K>>2]|0)!=0){if((a[(d[w]|0)+(b+27984)|0]|0)==0){break}u=(n<<4)+C|0;ef[c[v>>2]&4095](b+17024+(u<<5)|0,b+15488+((n<<2)+y<<7)|0,(d[19112+u|0]|0)+(b+27984)|0)}}while(0);if((c[t>>2]&r|0)!=0){u=(n<<4)+C|0;q=0;do{B=u+q|0;F=d[19112+B|0]|0;D=(d[F-8+(b+27984)|0]|0)+(d[F-1+(b+27984)|0]|0)|0;if((D|0)<128){L=(D+1|0)>>>1}else{L=D}D=d[1625080+(L&127)|0]|0;M=b+27984+F|0;if((a[M]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(D<<1)|0]|0)}else{a[M]=JUb(b,2,b+17024+(B<<5)|0,D)|0}q=q+1|0;}while((q|0)<4)}n=n+1|0;}while((n|0)<(z|0));do{if((c[A>>2]|0)!=0){if((c[J>>2]|0)!=2){n=y+16|0;C=d[19112+n|0]|0;r=(d[C-8+(b+27984)|0]|0)+(d[C-1+(b+27984)|0]|0)|0;if((r|0)<128){N=(r+1|0)>>>1}else{N=r}r=d[1625080+(N&127)|0]|0;w=b+27984+C|0;if((a[w]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(r<<1)|0]|0)}else{a[w]=JUb(b,4,b+17024+(n<<5)+2|0,r)|0}r=y+32|0;n=d[19112+r|0]|0;w=(d[n-8+(b+27984)|0]|0)+(d[n-1+(b+27984)|0]|0)|0;if((w|0)<128){O=(w+1|0)>>>1}else{O=w}w=d[1625080+(O&127)|0]|0;C=b+27984+n|0;if((a[C]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(w<<1)|0]|0);break}else{a[C]=JUb(b,4,b+17024+(r<<5)+2|0,w)|0;break}}w=(y*5|0)&9;r=w|16;C=d[19112+r|0]|0;n=(d[C-8+(b+27984)|0]|0)+(d[C-1+(b+27984)|0]|0)|0;if((n|0)<128){P=(n+1|0)>>>1}else{P=n}n=d[1625080+(P&127)|0]|0;q=b+27984+C|0;if((a[q]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(n<<1)|0]|0)}else{a[q]=JUb(b,4,b+17024+(r<<5)+2|0,n)|0}n=w|18;r=d[19112+n|0]|0;q=(d[r-8+(b+27984)|0]|0)+(d[r-1+(b+27984)|0]|0)|0;if((q|0)<128){Q=(q+1|0)>>>1}else{Q=q}q=d[1625080+(Q&127)|0]|0;C=b+27984+r|0;if((a[C]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(q<<1)|0]|0)}else{a[C]=JUb(b,4,b+17024+(n<<5)+2|0,q)|0}q=w|32;n=d[19112+q|0]|0;C=(d[n-8+(b+27984)|0]|0)+(d[n-1+(b+27984)|0]|0)|0;if((C|0)<128){R=(C+1|0)>>>1}else{R=C}C=d[1625080+(R&127)|0]|0;r=b+27984+n|0;if((a[r]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(C<<1)|0]|0)}else{a[r]=JUb(b,4,b+17024+(q<<5)+2|0,C)|0}C=w|34;w=d[19112+C|0]|0;q=(d[w-8+(b+27984)|0]|0)+(d[w-1+(b+27984)|0]|0)|0;if((q|0)<128){S=(q+1|0)>>>1}else{S=q}q=d[1625080+(S&127)|0]|0;r=b+27984+w|0;if((a[r]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(q<<1)|0]|0);break}else{a[r]=JUb(b,4,b+17024+(C<<5)+2|0,q)|0;break}}}while(0);if((x|0)>0){x=x-1|0;y=y+k|0}else{break}}k=ca(c[g>>2]|0,f)|0;T=(k|0)<0|0?-1:0;U=k}else{k=l+32|0;g=b+8632|0;Ee[c[b+37520>>2]&511](k,b+13920|0,(c[g>>2]|0)==3?1040:464)|0;y=c[b+19344>>2]|0;x=(c[b+19348>>2]|0)==15|0;S=(c[g>>2]|0)==3?3:1;do{if((y|0)==5){VUb(b,l,m);R=a[b+19352+m|0]|0;Q=l+57|0;P=d[Q]|0;if(R<<24>>24==3){a[Q]=a[100553+(P<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((P^1)<<1)>>1]|0);break}a[Q]=a[100552+(P<<1)|0]|0;Q=(c[k>>2]|0)+(e[101200+(P<<1)>>1]|0)|0;c[k>>2]=Q;P=l+58|0;O=d[P]|0;if(R<<24>>24==1){a[P]=a[100552+(O<<1)|0]|0;c[k>>2]=(e[101200+(O<<1)>>1]|0)+Q;break}else{a[P]=a[100553+(O<<1)|0]|0;P=(e[101200+((O^1)<<1)>>1]|0)+Q|0;Q=R<<24>>24==2|0;R=l+59|0;O=d[R]|0;a[R]=a[100552+(O<<1)+Q|0]|0;c[k>>2]=P+(e[101200+((O^Q)<<1)>>1]|0);break}}else if((y|0)==4){Q=m<<2;O=4>>>(x>>>0);P=WUb(b,l,0,Q,O)|0;re[c[100472+(O-3+(4<<x)<<2)>>2]&1023](b+28512+((d[1901576+Q|0]|0)+12+(d[1901368+Q|0]<<3)<<1)|0,P&65535)}else{if((y-8|0)>>>0<9>>>0){P=(m|0)!=0|0;if((a[94920+(y<<2)+P|0]|0)!=0){Q=m<<2;O=4>>>(x>>>0);R=WUb(b,l,0,Q,O)|0;re[c[100472+(O-3+(4<<x)<<2)>>2]&1023](b+28512+((d[1901576+Q|0]|0)+12+(d[1901368+Q|0]<<3)<<1)|0,R&65535)}if((a[94922+(y<<2)+P|0]|0)==0){break}P=m<<2;R=4>>>(x>>>0);Q=WUb(b,l,1,P,R)|0;re[c[100472+(R-3+(4<<x)<<2)>>2]&1023](b+28592+((d[1901576+P|0]|0)+12+(d[1901368+P|0]<<3)<<1)|0,Q&65535);break}else{Q=b+19352+m|0;P=a[Q]|0;if((a[95296+(P&255)|0]|0)==0){V=P}else{P=m<<2;R=WUb(b,l,0,P,2)|0;re[c[25121]&1023](b+28512+((d[1901576+P|0]|0)+12+(d[1901368+P|0]<<3)<<1)|0,R&65535);V=a[Q]|0}if((a[95313+(V&255)|0]|0)==0){break}Q=m<<2;R=WUb(b,l,1,Q,2)|0;re[c[25121]&1023](b+28592+((d[1901576+Q|0]|0)+12+(d[1901368+Q|0]<<3)<<1)|0,R&65535);break}}}while(0);V=b+19364|0;x=(d[19529+(h<<1)|0]|0)>>>3;y=b+19356|0;R=(h|0)<3|0;h=m;while(1){do{if((c[t>>2]&1<<h|0)!=0){if((c[y>>2]|0)==0){m=h<<2;Q=0;do{P=d[1625014+Q|0]|0;O=(Q<<4)+m|0;N=e[109680+(P<<1)>>1]|0;J=0;do{A=O+J|0;z=d[19112+A|0]|0;L=((a[z-1+(b+27984)|0]&127)!=0)+N+(((a[z-8+(b+27984)|0]&127)!=0)<<1)+(l+36)|0;v=d[L]|0;if((a[b+27984+z|0]|0)==0){a[L]=a[100552+(v<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+(v<<1)>>1]|0)}else{a[L]=a[100553+(v<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((v^1)<<1)>>1]|0);TTb(b,l,P,b+17024+(A<<5)|0)}J=J+1|0;}while((J|0)<4);Q=Q+1|0;}while((Q|0)<(S|0))}else{if((c[g>>2]|0)!=3){STb(b,l,5,b+15488+(h<<7)|0);break}Q=h<<2;m=0;do{J=d[1625023+m|0]|0;P=d[19112+((m<<4)+Q)|0]|0;N=((a[P-1+(b+27984)|0]&127)!=0)+(e[109680+(J<<1)>>1]|0)+(((a[P-8+(b+27984)|0]&127)!=0)<<1)+(l+36)|0;O=d[N]|0;if((a[b+27984+P|0]|0)==0){a[N]=a[100552+(O<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+(O<<1)>>1]|0)}else{a[N]=a[100553+(O<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((O^1)<<1)>>1]|0);STb(b,l,J,b+15488+((m<<2)+h<<7)|0)}m=m+1|0;}while((m|0)<3)}}}while(0);do{if((c[V>>2]|0)!=0){if((c[g>>2]|0)!=2){m=h+16|0;Q=d[19112+m|0]|0;J=(((a[Q-8+(b+27984)|0]&127)!=0)<<1)+((a[Q-1+(b+27984)|0]&127)!=0?102:101)+(l+36)|0;O=d[J]|0;if((a[b+27984+Q|0]|0)==0){a[J]=a[100552+(O<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+(O<<1)>>1]|0)}else{a[J]=a[100553+(O<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((O^1)<<1)>>1]|0);TTb(b,l,4,b+17024+(m<<5)+2|0)}m=h+32|0;O=d[19112+m|0]|0;J=(((a[O-8+(b+27984)|0]&127)!=0)<<1)+((a[O-1+(b+27984)|0]&127)!=0?102:101)+(l+36)|0;Q=d[J]|0;if((a[b+27984+O|0]|0)==0){a[J]=a[100552+(Q<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+(Q<<1)>>1]|0);break}else{a[J]=a[100553+(Q<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((Q^1)<<1)>>1]|0);TTb(b,l,4,b+17024+(m<<5)+2|0);break}}m=(h*5|0)&9;Q=m|16;J=d[19112+Q|0]|0;O=(((a[J-8+(b+27984)|0]&127)!=0)<<1)+((a[J-1+(b+27984)|0]&127)!=0?102:101)+(l+36)|0;N=d[O]|0;if((a[b+27984+J|0]|0)==0){a[O]=a[100552+(N<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+(N<<1)>>1]|0)}else{a[O]=a[100553+(N<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((N^1)<<1)>>1]|0);TTb(b,l,4,b+17024+(Q<<5)+2|0)}Q=m|18;N=d[19112+Q|0]|0;O=(((a[N-8+(b+27984)|0]&127)!=0)<<1)+((a[N-1+(b+27984)|0]&127)!=0?102:101)+(l+36)|0;J=d[O]|0;if((a[b+27984+N|0]|0)==0){a[O]=a[100552+(J<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+(J<<1)>>1]|0)}else{a[O]=a[100553+(J<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((J^1)<<1)>>1]|0);TTb(b,l,4,b+17024+(Q<<5)+2|0)}Q=m|32;J=d[19112+Q|0]|0;O=(((a[J-8+(b+27984)|0]&127)!=0)<<1)+((a[J-1+(b+27984)|0]&127)!=0?102:101)+(l+36)|0;N=d[O]|0;if((a[b+27984+J|0]|0)==0){a[O]=a[100552+(N<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+(N<<1)>>1]|0)}else{a[O]=a[100553+(N<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((N^1)<<1)>>1]|0);TTb(b,l,4,b+17024+(Q<<5)+2|0)}Q=m|34;m=d[19112+Q|0]|0;N=(((a[m-8+(b+27984)|0]&127)!=0)<<1)+((a[m-1+(b+27984)|0]&127)!=0?102:101)+(l+36)|0;O=d[N]|0;if((a[b+27984+m|0]|0)==0){a[N]=a[100552+(O<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+(O<<1)>>1]|0);break}else{a[N]=a[100553+(O<<1)|0]|0;c[k>>2]=(c[k>>2]|0)+(e[101200+((O^1)<<1)>>1]|0);TTb(b,l,4,b+17024+(Q<<5)+2|0);break}}}while(0);if((R|0)<=0){break}R=R-1|0;h=h+x|0}x=c[k>>2]|0;k=Erc(x,(x|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=wrc(k,G,128,0)|0;k=G;T=k>>>8|0<<24;U=f>>>8|k<<24}k=wrc(H<<8|0>>>24|128,I<<8|H>>>24|0,E,s)|0;s=wrc(U,T,k&-256,G|0)|0;o=G;p=s;i=j;return(G=o,p)|0}function VTb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;f=i;i=i+1072|0;g=f|0;h=b+19356|0;j=c[h>>2]|0;k=b+19344|0;l=c[k>>2]|0;uMb(b);if((c[b+19392>>2]|0)!=0){bOb(b)}m=mUb(b)|0;n=c[k>>2]|0;if((n|0)==6|(n|0)==18){o=e+128>>8;c[h>>2]=j;c[k>>2]=l;p=o+m|0;i=f;return p|0}if((c[b+152>>2]|0)!=0){q=g+32|0;Ee[c[b+37520>>2]&511](q,b+13920|0,(c[b+8632>>2]|0)==3?1040:464)|0;XUb(b,g);g=c[q>>2]|0;q=Erc(g,(g|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;g=wrc(q,G,32768,0)|0;o=g>>>16|G<<16;c[h>>2]=j;c[k>>2]=l;p=o+m|0;i=f;return p|0}g=(c[b+8632>>2]|0)==3;q=g?3:1;r=g&1^1;g=b+1520|0;c[g>>2]=0;do{if((c[b+3260>>2]|0)==0){s=0}else{if((c[b+18612>>2]&1|0)!=0){t=a[(c[b+18956>>2]|0)+((c[b+18616>>2]|0)-(c[b+18580>>2]|0))|0]|0;if(!((t<<24>>24|0)==6|(t<<24>>24|0)==18)){s=0;break}}c[g>>2]=1;s=1}}while(0);t=c[b+3240>>2]|0;do{if((t|0)==1){if((n|0)==17){u=b+19352|0;v=d[u]|0;w=b+19353|0;x=a[w]|0;y=x&255;z=b+19354|0;A=d[z]|0;B=b+19355|0;C=d[B]|0;D=s+9+(d[(d[552776+v|0]|0)+16465|0]|0)+(d[(d[552776+y|0]|0)+16465|0]|0)+(d[(d[552776+A|0]|0)+16465|0]|0)+(d[(d[552776+C|0]|0)+16465|0]|0)|0;c[g>>2]=D;E=c[b+24580>>2]|0;do{if((E|0)>1){if((a[95296+v|0]|0)==0){F=D}else{if((E|0)==2){H=1}else{H=d[(a[b+28116|0]|0)+16465|0]|0}I=H+D|0;c[g>>2]=I;F=I}if((a[95296+y|0]|0)==0){J=F}else{if((E|0)==2){K=1}else{K=d[(a[b+28118|0]|0)+16465|0]|0}I=K+F|0;c[g>>2]=I;J=I}if((a[95296+A|0]|0)==0){L=J}else{if((E|0)==2){M=1}else{M=d[(a[b+28132|0]|0)+16465|0]|0}I=M+J|0;c[g>>2]=I;L=I}if((a[95296+C|0]|0)==0){N=L;break}if((E|0)==2){O=1}else{O=d[(a[b+28134|0]|0)+16465|0]|0}I=O+L|0;c[g>>2]=I;N=I}else{N=D}}while(0);D=c[b+24584>>2]|0;do{if((D|0)>1){if((a[95313+v|0]|0)==0){P=N}else{if((D|0)==2){Q=1}else{Q=d[(a[b+28156|0]|0)+16465|0]|0}E=Q+N|0;c[g>>2]=E;P=E}if((a[95313+y|0]|0)==0){R=P}else{if((D|0)==2){S=1}else{S=d[(a[b+28158|0]|0)+16465|0]|0}E=S+P|0;c[g>>2]=E;R=E}if((a[95313+A|0]|0)==0){T=R}else{if((D|0)==2){U=1}else{U=d[(a[b+28172|0]|0)+16465|0]|0}E=U+R|0;c[g>>2]=E;T=E}if((a[95313+C|0]|0)==0){break}if((D|0)==2){V=1}else{V=d[(a[b+28174|0]|0)+16465|0]|0}c[g>>2]=V+T}}while(0);if((a[95296+v|0]|0)==0){W=x}else{UUb(b,0,0,2);W=a[w]|0}if((a[95296+(W&255)|0]|0)!=0){UUb(b,0,4,2)}if((a[95296+(d[z]|0)|0]|0)!=0){UUb(b,0,8,2)}if((a[95296+(d[B]|0)|0]|0)!=0){UUb(b,0,12,2)}if((a[95313+(d[u]|0)|0]|0)!=0){UUb(b,1,0,2)}if((a[95313+(d[w]|0)|0]|0)!=0){UUb(b,1,4,2)}if((a[95313+(d[z]|0)|0]|0)!=0){UUb(b,1,8,2)}if((a[95313+(d[B]|0)|0]|0)==0){X=147;break}UUb(b,1,12,2);X=147;break}D=n-8|0;if(!(D>>>0<9>>>0)){if((n|0)==7){c[g>>2]=s+1;X=148;break}else{YUb(b,n,23,r);X=147;break}}C=94920+(n<<2)|0;A=(c[b+24580>>2]|0)-1|0;y=(c[b+24584>>2]|0)-1|0;E=c[b+19348>>2]|0;I=(d[(d[832952+((E-14|0)*9|0)+D|0]|0)+16465|0]|0)+s|0;c[g>>2]=I;D=(A|0)!=0;if((E|0)==16){do{if(D){if((a[C|0]|0)==0){Y=I;break}if((A|0)==1){Z=1}else{Z=d[(a[b+28116|0]|0)+16465|0]|0}_=Z+I|0;c[g>>2]=_;Y=_}else{Y=I}}while(0);do{if((y|0)!=0){if(!((n-11|0)>>>0<6>>>0)){break}if((y|0)==1){$=1}else{$=d[(a[b+28156|0]|0)+16465|0]|0}c[g>>2]=$+Y}}while(0);if((a[C|0]|0)!=0){UUb(b,0,0,4)}if(!((n-11|0)>>>0<6>>>0)){X=147;break}UUb(b,1,0,4);X=147;break}do{if(D){do{if((a[C|0]|0)==0){aa=I}else{if((A|0)==1){B=I+1|0;c[g>>2]=B;aa=B;break}else{B=(d[(a[b+28116|0]|0)+16465|0]|0)+I|0;c[g>>2]=B;aa=B;break}}}while(0);if((93520>>>(n>>>0)&1|0)==0){ba=aa;break}if((A|0)==1){da=1}else{da=d[(a[b+28134|0]|0)+16465|0]|0}B=da+aa|0;c[g>>2]=B;ba=B}else{ba=I}}while(0);do{if((y|0)!=0){if((n-11|0)>>>0<6>>>0){if((y|0)==1){ea=1}else{ea=d[(a[b+28156|0]|0)+16465|0]|0}I=ea+ba|0;c[g>>2]=I;fa=I}else{fa=ba}if((112128>>>(n>>>0)&1|0)==0){break}if((y|0)==1){ga=1}else{ga=d[(a[b+28174|0]|0)+16465|0]|0}c[g>>2]=ga+fa}}while(0);y=(a[C|0]|0)!=0;if((E|0)==14){if(y){UUb(b,0,0,4)}if((93520>>>(n>>>0)&1|0)!=0){UUb(b,0,8,4)}if(!((n-11|0)>>>0>5>>>0)){UUb(b,1,0,4)}if((112128>>>(n>>>0)&1|0)==0){X=147;break}UUb(b,1,8,4);X=147;break}else{if(y){UUb(b,0,0,2)}if((93520>>>(n>>>0)&1|0)!=0){UUb(b,0,4,2)}if(!((n-11|0)>>>0>5>>>0)){UUb(b,1,0,2)}if((112128>>>(n>>>0)&1|0)==0){X=147;break}UUb(b,1,4,2);X=147;break}}else if((t|0)==0){if((n|0)==5){y=a[b+28116|0]|0;I=a[b+28118|0]|0;A=a[b+28132|0]|0;D=a[b+28134|0]|0;B=s+5|0;c[g>>2]=B;if((c[b+520>>2]&32|0)==0){ha=s+9|0}else{z=(d[(d[552752+(d[b+19352|0]|0)|0]|0)+16465|0]|0)+B+(d[(d[552752+(d[b+19353|0]|0)|0]|0)+16465|0]|0)+(d[(d[552752+(d[b+19354|0]|0)|0]|0)+16465|0]|0)|0;c[g>>2]=z;ha=(d[(d[552752+(d[b+19355|0]|0)|0]|0)+16465|0]|0)+z|0}c[g>>2]=ha;if(!((I|y|A|D)<<24>>24==0)){if((c[b+24580>>2]|0)==2){z=ha+3|0;c[g>>2]=z;ia=1;ja=z}else{z=(d[(y<<24>>24)+16465|0]|0)+ha+(d[(I<<24>>24)+16465|0]|0)+(d[(A<<24>>24)+16465|0]|0)|0;c[g>>2]=z;ia=d[(D<<24>>24)+16465|0]|0;ja=z}c[g>>2]=ia+ja}TUb(b,0);TUb(b,1);TUb(b,2);TUb(b,3);X=147;break}else if((n|0)==4){z=c[b+19348>>2]|0;if((z|0)==15){D=s+3|0;c[g>>2]=D;A=c[b+24580>>2]|0;if((A|0)>1){if((A|0)==2){A=s|4;c[g>>2]=A;ka=1;la=A}else{A=(d[(a[b+28116|0]|0)+16465|0]|0)+D|0;c[g>>2]=A;ka=d[(a[b+28118|0]|0)+16465|0]|0;la=A}c[g>>2]=ka+la}UUb(b,0,0,2);UUb(b,0,4,2);X=147;break}else if((z|0)==16){A=s+1|0;c[g>>2]=A;D=c[b+24580>>2]|0;if((D|0)>1){if((D|0)==2){ma=1}else{ma=d[(a[b+28116|0]|0)+16465|0]|0}c[g>>2]=ma+A}UUb(b,0,0,4);X=147;break}else if((z|0)==14){z=s+3|0;c[g>>2]=z;A=c[b+24580>>2]|0;if((A|0)>1){if((A|0)==2){A=s|4;c[g>>2]=A;na=1;oa=A}else{A=(d[(a[b+28116|0]|0)+16465|0]|0)+z|0;c[g>>2]=A;na=d[(a[b+28132|0]|0)+16465|0]|0;oa=A}c[g>>2]=na+oa}UUb(b,0,0,4);UUb(b,0,8,4);X=147;break}else{X=148;break}}else{YUb(b,n,5,r);X=147;break}}else{YUb(b,n,0,r);X=147}}while(0);if((X|0)==147){if((n|0)==2){pa=1}else{X=148}}if((X|0)==148){if(n>>>0<3>>>0){qa=1}else{qa=(n|0)==3|0}c[g>>2]=(c[g>>2]|0)+(d[(d[(c[b+19364>>2]<<4|c[b+19360>>2])+(1722240+(r*96|0)+(qa*48|0))|0]|0)+16465|0]|0);pa=0}do{if((c[b+8696>>2]|0)!=0){qa=c[k>>2]|0;if((qa|0)==5){ra=(c[b+19352>>2]|0)==50529027|0}else{ra=d[17936+qa|0]|0}if((ra|0)==0){break}if((c[b+19360>>2]|0)==0){break}c[g>>2]=(c[g>>2]|0)+1}}while(0);do{if(pa){ra=c[b+28816>>2]|0;qa=c[b+28824>>2]|0;r=ra-qa|0;do{if((c[k>>2]|0)==2){if((c[b+19364>>2]|c[b+19360>>2]|0)!=0){sa=r;break}if((a[b+27984|0]|0)!=0){sa=r;break}if((a[b+28024|0]|0)!=0){sa=r;break}sa=(a[b+28064|0]|0)==0&(ra|0)>(qa|0)?0:r}else{sa=r}}while(0);do{if((sa|0)==0){ta=0}else{if((sa|0)<-26){ta=sa+52|0;break}else{ta=(sa|0)>25?sa-52|0:sa;break}}}while(0);r=ta<<1;qa=1-r|0;ra=(qa|0)<0?r:qa;if((ra|0)<256){ua=d[16464+ra|0]|0}else{ua=(d[16464+(ra>>8)|0]|0)+16|0}c[g>>2]=(c[g>>2]|0)+ua;ra=b+19360|0;qa=0;do{r=qa<<4;E=a[19112+r|0]|0;C=E&255;n=(d[C-8+(b+27984)|0]|0)+(d[C-1+(b+27984)|0]|0)|0;if((n|0)<128){va=(n+1|0)>>>1}else{va=n}n=d[1625080+(va&127)|0]|0;C=(d[qa+19160|0]|0)+(b+27984)|0;if((a[C]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(n<<1)|0]|0)}else{a[C]=JUb(b,0,b+15360+(qa<<5)|0,n)|0}a:do{if((c[ra>>2]|0)!=0){n=r+16|0;C=r;X=E;while(1){oa=X&255;na=(d[oa-8+(b+27984)|0]|0)+(d[oa-1+(b+27984)|0]|0)|0;if((na|0)<128){wa=(na+1|0)>>>1}else{wa=na}na=d[1625080+(wa&127)|0]|0;s=b+27984+oa|0;if((a[s]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(na<<1)|0]|0)}else{a[s]=JUb(b,1,b+17024+(C<<5)+2|0,na)|0}na=C+1|0;if((na|0)>=(n|0)){break a}C=na;X=a[19112+na|0]|0}}}while(0);qa=qa+1|0;}while((qa|0)<(q|0));xa=b+19364|0}else{qa=b+19360|0;ra=b+19364|0;if((c[ra>>2]|c[qa>>2]|0)==0){xa=ra;break}E=c[b+28816>>2]|0;r=c[b+28824>>2]|0;X=E-r|0;do{if((E|0)==(r|0)){ya=0}else{if((X|0)<-26){ya=X+52|0;break}else{ya=(X|0)>25?X-52|0:X;break}}}while(0);X=ya<<1;r=1-X|0;E=(r|0)<0?X:r;if((E|0)<256){za=d[16464+E|0]|0}else{za=(d[16464+(E>>8)|0]|0)+16|0}c[g>>2]=(c[g>>2]|0)+za;if((c[h>>2]|0)==0){Aa=0}else{E=b+37660|0;r=0;while(1){X=r<<4;C=r<<2;n=(d[19112+X|0]|0)+(b+27984)|0;if((a[n]|0)!=0){ef[c[E>>2]&4095](b+17024+(X<<5)|0,b+15488+(C<<7)|0,n)}n=X|4;na=(d[19112+n|0]|0)+(b+27984)|0;if((a[na]|0)!=0){ef[c[E>>2]&4095](b+17024+(n<<5)|0,b+15488+((C|1)<<7)|0,na)}na=X|8;n=(d[19112+na|0]|0)+(b+27984)|0;if((a[n]|0)!=0){ef[c[E>>2]&4095](b+17024+(na<<5)|0,b+15488+((C|2)<<7)|0,n)}n=X|12;X=(d[19112+n|0]|0)+(b+27984)|0;if((a[X]|0)!=0){ef[c[E>>2]&4095](b+17024+(n<<5)|0,b+15488+((C|3)<<7)|0,X)}X=r+1|0;if((X|0)<(q|0)){r=X}else{Aa=0;break}}}while(1){r=c[qa>>2]|0;if((r|0)!=0){E=Aa<<4;X=0;C=r;while(1){r=d[98840+C|0]|0;n=r+X|0;na=(n<<2)+E|0;s=0;do{oa=na+s|0;ma=d[19112+oa|0]|0;la=(d[ma-8+(b+27984)|0]|0)+(d[ma-1+(b+27984)|0]|0)|0;if((la|0)<128){Ba=(la+1|0)>>>1}else{Ba=la}la=d[1625080+(Ba&127)|0]|0;ka=b+27984+ma|0;if((a[ka]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(la<<1)|0]|0)}else{a[ka]=JUb(b,2,b+17024+(oa<<5)|0,la)|0}s=s+1|0;}while((s|0)<4);s=C>>r+1;if((s|0)==0){break}else{X=n+1|0;C=s}}}C=Aa+1|0;if((C|0)<(q|0)){Aa=C}else{xa=ra;break}}}}while(0);do{if((c[xa>>2]|0)!=0){Aa=b+18576|0;q=c[Aa>>2]|0;Ba=5-q|0;za=b+28024|0;if((a[za]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(Ba<<1)|0]|0);Ca=q}else{a[za]=JUb(b,3,b+15456|0,Ba)|0;Ca=c[Aa>>2]|0}Ba=5-Ca|0;za=b+28064|0;if((a[za]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(Ba<<1)|0]|0)}else{a[za]=JUb(b,3,b+15472|0,Ba)|0}if((c[xa>>2]|0)!=2){break}Ba=8<<c[Aa>>2];Aa=16;do{za=Aa+4|0;q=Aa;do{ya=d[19112+q|0]|0;wa=(d[ya-8+(b+27984)|0]|0)+(d[ya-1+(b+27984)|0]|0)|0;if((wa|0)<128){Da=(wa+1|0)>>>1}else{Da=wa}wa=d[1625080+(Da&127)|0]|0;va=b+27984+ya|0;if((a[va]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(wa<<1)|0]|0)}else{a[va]=JUb(b,4,b+17024+(q<<5)+2|0,wa)|0}q=q+1|0;}while((q|0)<(za|0));Aa=Aa+Ba|0;}while((Aa|0)<48)}}while(0);o=(ca(c[g>>2]|0,e)|0)+128>>8;c[h>>2]=j;c[k>>2]=l;p=o+m|0;i=f;return p|0}function WTb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=(c[a+24568+(e<<2)>>2]|0)+((g<<5)+f)|0;i=(g<<4)+f|0;j=(c[a+24544+(e<<2)>>2]|0)+i|0;if((e|0)!=0){k=0;l=a+36776+(b<<2)|0;m=c[l>>2]|0;n=hf[m&1023](j,16,h,32)|0;o=n+k|0;return o|0}e=a+18652|0;if((c[e>>2]|0)==0){k=0;l=a+36776+(b<<2)|0;m=c[l>>2]|0;n=hf[m&1023](j,16,h,32)|0;o=n+k|0;return o|0}if((b|0)<4){p=a+37112+(b<<2)|0;q=We[c[p>>2]&2047](h,32)|0;r=G;s=a+24320+((g>>(d[1888936+b|0]|0))+(f>>(d[1888944+b|0]|0))+(d[1888952+b|0]|0)<<3)|0;t=c[s>>2]|0;u=c[s+4>>2]|0;if((t|0)==0&(u|0)==0){v=We[c[p>>2]&2047]((c[a+24544>>2]|0)+i|0,16)|0;p=G;w=wrc(v,p,1,0)|0;c[s>>2]=w;c[s+4>>2]=G;x=v;y=p}else{p=wrc(t,u,-1,-1)|0;x=p;y=G}p=q-x|0;x=r-y|0;z=((x|0)>-1?x:-x|0)+((p|0)>-1?p:-p|0)>>1}else{p=a+36744+(b<<2)|0;x=(hf[c[p>>2]&1023](h,32,5093520,0)|0)>>1;y=a+36808+(b<<2)|0;r=(hf[c[y>>2]&1023](h,32,5093520,0)|0)-x|0;x=b-4|0;q=a+24416+((g>>(d[1888912+x|0]|0))+(f>>(d[1888920+x|0]|0))+(d[1888928+x|0]|0)<<2)|0;x=c[q>>2]|0;if((x|0)==0){f=(c[a+24544>>2]|0)+i|0;i=(hf[c[p>>2]&1023](f,16,9881072,0)|0)>>1;p=(hf[c[y>>2]&1023](f,16,9881072,0)|0)-i|0;c[q>>2]=p+1;A=p}else{A=x-1|0}x=r-A|0;z=(x|0)>-1?x:-x|0}x=ca(c[e>>2]|0,z)|0;k=(ca(x,c[a+28864>>2]|0)|0)+128>>8;l=a+36776+(b<<2)|0;m=c[l>>2]|0;n=hf[m&1023](j,16,h,32)|0;o=n+k|0;return o|0}function XTb(){var c=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=0;while(1){f=(c|0)>1;g=(c-1|0)>>>0<13>>>0;h=0;do{i=h&255;if(f){j=i;k=0;l=1;while(1){m=j&255;n=a[100553+(m<<1)|0]|0;o=(e[101200+((m^1)<<1)>>1]|0)+k|0;m=l+1|0;if((m|0)<(c|0)){j=n;k=o;l=m}else{p=n;q=o;break}}}else{p=i;q=0}if(g){l=p&255;r=(e[101200+(l<<1)>>1]|0)+q|0;s=a[100552+(l<<1)|0]|0}else{r=q;s=p}b[3059120+(c<<8)+(h<<1)>>1]=r+256;a[3057200+(c<<7)+h|0]=s;h=h+1|0;}while((h|0)<128);h=c+1|0;if((h|0)<15){c=h}else{t=0;break}}do{c=t&255;s=d[100553+(c<<1)|0]|0;r=d[100553+(s<<1)|0]|0;p=d[100553+(r<<1)|0]|0;q=d[100553+(p<<1)|0]|0;h=a[100553+(q<<1)|0]|0;b[9881216+(t<<1)>>1]=((b[101200+((q^1)<<1)>>1]|0)+((b[101200+((p^1)<<1)>>1]|0)+((b[101200+((r^1)<<1)>>1]|0)+((b[101200+((s^1)<<1)>>1]|0)+(b[101200+((c^1)<<1)>>1]|0)&65535)&65535)&65535)&65535)+256;a[9881088+t|0]=h;t=t+1|0;}while((t|0)<128);return}function YTb(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;n=i;i=i+4912|0;o=n|0;p=n+64|0;q=n+96|0;r=n+160|0;s=n+320|0;t=n+480|0;u=n+4576|0;v=n+4832|0;w=n+4848|0;x=n+4864|0;y=n+4880|0;z=n+4896|0;A=(c[f+1716+(h<<2)>>2]|0)+(j<<5)|0;if((c[f+152>>2]|0)==0){B=(c[f+1684+(h<<2)>>2]|0)+(j<<6)|0;C=c[f+18660>>2]|0;D=c[f+28848+(l<<2)>>2]|0;mrc(p|0,0,32)|0;E=d[19112+((m<<4)-768)|0]|0;m=(d[E-8+(f+27984)|0]|0)+(d[E-1+(f+27984)|0]|0)|0;if((m|0)<128){F=(m+1|0)>>>1}else{F=m}m=d[1625080+(F&127)|0]|0;F=D<<4;D=15;while(1){if((D|0)<0){H=0;I=57;break}E=b[A>>1]|0;if(((ca((E&65535)>>>1,b[g+(d[16032+(C<<4)+D|0]<<1)>>1]|0)|0)+32767|0)>>>0>65535>>>0){J=0;K=0;L=0;M=E;break}else{D=D-1|0}}if((I|0)==57){i=n;return H|0}while(1){E=b[g+(d[16032+(C<<4)+L|0]<<1)>>1]|0;N=E<<16>>16;O=E<<16>>16>-1?N:-N|0;N=E<<16>>16<0?-1:1;E=(ca((M&65535)>>>1,O)|0)+32768>>16;P=(ca(E,N)|0)&65535;Q=o+(L<<1)|0;b[Q>>1]=P;b[o+32+(L<<1)>>1]=P;R=p+(L<<1)|0;b[R>>1]=P;do{if((E|0)==0){c[q+(L<<2)>>2]=0;S=J;T=P}else{U=c[B>>2]<<1;V=(ca((e[A>>1]|0)>>>1,O)|0)+16384>>16;W=E-1|0;X=O-((ca(U,E)|0)+128>>8)|0;Y=O-((ca(U,W)|0)+128>>8)|0;c[q+(L<<2)>>2]=(ca(Y,Y)|0)-(ca(X,X)|0)<<8;X=(ca(W,N)|0)&65535;b[Q>>1]=X;if((V|0)==(E|0)){S=J|1<<L;T=P;break}else{b[R>>1]=X;S=J;T=X;break}}}while(0);Z=(T<<16>>16!=0)<<L|K;R=L+1|0;if((R|0)>(D|0)){break}J=S;K=Z;L=R;M=b[A>>1]|0}M=f+1520|0;c[M>>2]=0;if((Z|0)==0){L=100209+(m<<1)|0;K=d[L]|0;c[M>>2]=K;_=K;$=L;aa=p|0;ba=0}else{L=p|0;JUb(f,0,L,m)|0;_=c[M>>2]|0;$=100209+(m<<1)|0;aa=L;ba=Z}Z=F;L=(F|0)<0|0?-1:0;F=Erc(_,(_|0)<0|0?-1:0,Z,L)|0;_=S;S=ba;ba=G;K=F;while(1){F=ba;J=K;T=0;B=-1;R=S;P=_;E=0;while(1){Q=c[q+(E<<2)>>2]|0;if((Q|0)==0){da=P;ea=R;fa=B;ga=T;ha=F;ia=J}else{N=1<<E;O=N^_;X=O>>>(E>>>0)&1;V=p+(E<<1)|0;W=b[V>>1]|0;Y=b[o+(X<<5)+(E<<1)>>1]|0;U=(Y<<16>>16!=0)<<E|S&~N;N=ca((X<<1^2)-1|0,Q)|0;b[V>>1]=Y;c[M>>2]=0;if((U|0)==0){Y=d[$]|0;c[M>>2]=Y;ja=Y}else{JUb(f,0,aa,m)|0;ja=c[M>>2]|0}Y=Erc(ja,(ja|0)<0|0?-1:0,Z,L)|0;Q=wrc(Y,G,N,(N|0)<0|0?-1:0)|0;Y=G;b[V>>1]=W;W=(Y|0)<(F|0)|(Y|0)==(F|0)&Q>>>0<J>>>0;da=W?O:P;ea=W?U:R;fa=W?E:B;ga=W?N:T;ha=W?Y:F;ia=W?Q:J}Q=E+1|0;if((Q|0)>(D|0)){break}else{F=ha;J=ia;T=ga;B=fa;R=ea;P=da;E=Q}}if(!((fa|0)>-1)){break}E=xrc(ia,ha,ga,(ga|0)<0|0?-1:0)|0;b[p+(fa<<1)>>1]=b[o+((da>>>(fa>>>0)&1)<<5)+(fa<<1)>>1]|0;c[q+(fa<<2)>>2]=0;_=da;S=ea;ba=G;K=E}if((S|0)==0){H=0;i=n;return H|0}else{ka=0}while(1){b[g+(d[16032+(C<<4)+ka|0]<<1)>>1]=b[p+(ka<<1)>>1]|0;S=ka+1|0;if((S|0)<16){ka=S}else{H=1;break}}i=n;return H|0}ka=(c[f+1780+(h<<2)>>2]|0)+(j<<5)|0;p=(c[f+1684+(h<<2)>>2]|0)+(j<<6)|0;j=c[f+18660>>2]|0;h=c[f+28848+(l<<2)>>2]|0;l=v|0;C=r+31&-32;r=C;S=s+31&-32;s=e[18864+(j<<5)+(k<<1)>>1]|0;K=e[97192+(j<<5)+(k<<1)>>1]|0;nrc(C|0,g|0,32)|0;if((Ee[c[f+37724>>2]&511](g,(e[A>>1]|0)>>>1,e[ka>>1]<<1)|0)==0){H=0;i=n;return H|0}re[c[f+37644>>2]&1023](S,g);ka=ve[c[f+37776+(k<<2)>>2]&4095](S)|0;A=e[100176+(k<<1)>>1]|0;k=f+13924+A|0;C=u|0;ba=u+16|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=u+32|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=u+48|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=u|0;c[ba>>2]=0;c[ba+4>>2]=268435456;c[u+8>>2]=0;ba=t|0;b[t+2>>1]=0;b[t>>1]=0;nrc(l|0,k|0,10)|0;a[v+12|0]=a[k]|0;a[v+13|0]=a[A+4+(f+13924)|0]|0;a[v+14|0]=a[A+8+(f+13924)|0]|0;a[v+15|0]=a[A+9+(f+13924)|0]|0;A=(ka|0)<0;a:do{if(A){la=C;I=5}else{v=h;k=(h|0)<0|0?-1:0;ea=w|0;da=w+4|0;_=w+8|0;fa=y|0;q=x|0;o=x+8|0;ga=y+8|0;ha=ka;ia=u+128|0;D=C;L=1;while(1){Z=b[S+(ha<<1)>>1]|0;if(Z<<16>>16==0){ja=Erc(e[101200+(d[ha+s+(f+13924)|0]<<1)>>1]|0,0,v,k)|0;M=G;m=D|0;aa=xrc(c[m>>2]|0,c[m+4>>2]|0,ja>>>4|M<<28,M>>>4|0<<28)|0;c[m>>2]=aa;c[m+4>>2]=G;m=D+24|0;c[t+(L<<2)>>2]=c[m>>2];c[m>>2]=L;m=L+1|0;aa=D+40|0;c[t+(m<<2)>>2]=c[aa>>2];c[aa>>2]=m;m=L+2|0;aa=D+56|0;c[t+(m<<2)>>2]=c[aa>>2];c[aa>>2]=m;ma=L+3|0;na=D;oa=ia}else{m=b[r+(d[16032+(j<<4)+ha|0]<<1)>>1]|0;aa=m<<16>>16;M=Z<<16>>16;ja=ia|0;c[ja>>2]=-1;c[ja+4>>2]=-1;ja=ia+16|0;c[ja>>2]=-1;c[ja+4>>2]=-1;ja=ia+32|0;c[ja>>2]=-1;c[ja+4>>2]=-1;ja=ia+48|0;c[ja>>2]=-1;c[ja+4>>2]=-1;ja=ia+64|0;c[ja>>2]=-1;c[ja+4>>2]=-1;ja=ia+80|0;c[ja>>2]=-1;c[ja+4>>2]=-1;ja=ia+96|0;c[ja>>2]=-1;c[ja+4>>2]=-1;ja=ia+112|0;c[ja>>2]=-1;c[ja+4>>2]=-1;ja=m<<16>>16>-1?aa:-aa|0;pa=Z<<16>>16>-1?M:-M|0;if((ha|0)<15){M=d[ha+s+(f+13924)|0]|0;Z=b[101200+(M<<1)>>1]|0;c[ea>>2]=Z&65535;aa=e[101200+((M^1)<<1)>>1]|0;M=d[ha+K+(f+13924)|0]|0;c[da>>2]=(e[101200+(M<<1)>>1]|0)+aa;c[_>>2]=(e[101200+((M^1)<<1)>>1]|0)+aa;qa=0;ra=Z&65535}else{c[_>>2]=0;c[da>>2]=0;c[ea>>2]=0;qa=0;ra=0}sa=pa-1|0;Z=c[p>>2]<<1;aa=ja-((ca(Z,sa)|0)+128>>8)|0;M=aa;m=(aa|0)<0|0?-1:0;ta=Erc(M<<8|0>>>24,m<<8|M>>>24,M,m)|0;ua=G;c[fa>>2]=ta;c[fa+4>>2]=ua;c[q>>2]=ta;c[q+4>>2]=ua;m=ja-((ca(Z,pa)|0)+128>>8)|0;Z=m;ja=(m|0)<0|0?-1:0;m=Erc(Z<<8|0>>>24,ja<<8|Z>>>24,Z,ja)|0;ja=G;c[ga>>2]=m;c[ga+4>>2]=ja;c[o>>2]=m;c[o+4>>2]=ja;if((pa|0)==2){I=13;break}else if((pa|0)!=1){I=16;break}ja=Erc(ra,qa,v,k)|0;m=G;Z=ja>>>4|m<<28;ja=m>>>4|0<<28;m=wrc(ta,ua,Z,ja)|0;c[fa>>2]=m;c[fa+4>>2]=G;m=xrc(0,0,Z,ja)|0;ja=NUb(m,G,ia,D,ba,L)|0;m=c[fa>>2]|0;Z=c[fa+4>>2]|0;M=xrc(c[o>>2]|0,c[o+4>>2]|0,m,Z)|0;aa=G;$=xrc(c[ga>>2]|0,c[ga+4>>2]|0,m,Z)|0;ma=OUb(M,aa,$,G,ea,ia,D,ba,ja,h,l)|0;na=ia;oa=D}ja=ha-1|0;if((ja|0)<0){la=na;I=5;break a}else{ha=ja;ia=oa;D=na;L=ma}}if((I|0)==13){fa=OUb(ta,ua,ta,ua,ea,ia,D,ba,L,h,l)|0;va=PUb(2,c[o>>2]|0,c[o+4>>2]|0,c[ga>>2]|0,c[ga+4>>2]|0,ea,ia,D,ba,fa,h,l)|0}else if((I|0)==16){fa=PUb(sa,ta,ua,ta,ua,ea,ia,D,ba,L,h,l)|0;va=PUb(pa,c[o>>2]|0,c[o+4>>2]|0,c[ga>>2]|0,c[ga+4>>2]|0,ea,ia,D,ba,fa,h,l)|0}fa=ha-1|0;b:do{if((fa|0)<0){wa=ia}else{q=z|0;da=z+4|0;_=D;ja=ia;$=va;aa=fa;while(1){M=ja+24|0;Z=ja+40|0;m=ja+56|0;E=ja+72|0;P=ja+88|0;R=ja+104|0;B=ja+120|0;T=$;J=aa;while(1){xa=b[S+(J<<1)>>1]|0;if(!(xa<<16>>16==0)){break}c[t+(T<<2)>>2]=c[M>>2];c[M>>2]=T;F=T+1|0;c[t+(F<<2)>>2]=c[Z>>2];c[Z>>2]=F;F=T+2|0;c[t+(F<<2)>>2]=c[m>>2];c[m>>2]=F;F=T+3|0;c[t+(F<<2)>>2]=c[E>>2];c[E>>2]=F;F=T+4|0;c[t+(F<<2)>>2]=c[P>>2];c[P>>2]=F;F=T+5|0;c[t+(F<<2)>>2]=c[R>>2];c[R>>2]=F;F=T+6|0;c[t+(F<<2)>>2]=c[B>>2];c[B>>2]=F;F=J-1|0;if((F|0)<0){wa=ja;break b}else{T=T+7|0;J=F}}B=b[r+(d[16032+(j<<4)+J|0]<<1)>>1]|0;R=B<<16>>16;P=xa<<16>>16;E=_+16|0;c[E>>2]=-1;c[E+4>>2]=-1;E=_+32|0;c[E>>2]=-1;c[E+4>>2]=-1;E=_+48|0;c[E>>2]=-1;c[E+4>>2]=-1;E=_+64|0;c[E>>2]=-1;c[E+4>>2]=-1;E=_+80|0;c[E>>2]=-1;c[E+4>>2]=-1;E=_+96|0;c[E>>2]=-1;c[E+4>>2]=-1;E=_+112|0;c[E>>2]=-1;c[E+4>>2]=-1;E=B<<16>>16>-1?R:-R|0;R=xa<<16>>16>-1?P:-P|0;P=d[J+s+(f+13924)|0]|0;B=b[101200+(P<<1)>>1]|0;c[q>>2]=B&65535;c[da>>2]=(e[101200+(d[J+K+(f+13924)|0]<<1)>>1]|0)+(e[101200+((P^1)<<1)>>1]|0);P=R-1|0;m=c[p>>2]<<1;Z=E-((ca(m,P)|0)+128>>8)|0;M=Z;F=(Z|0)<0|0?-1:0;Z=Erc(M<<8|0>>>24,F<<8|M>>>24,M,F)|0;F=G;M=E-((ca(m,R)|0)+128>>8)|0;m=M;E=(M|0)<0|0?-1:0;M=Erc(m<<8|0>>>24,E<<8|m>>>24,m,E)|0;E=G;if((R|0)==2){ya=SUb(2,M,E,q,_,ja,ba,RUb(Z,F,q,_,ja,ba,T,h,l)|0,h,l,9)|0}else if((R|0)==1){m=Erc(B&65535,0,v,k)|0;B=G;Q=QUb(_,ja,ba,T)|0;W=wrc(Z,F,m>>>4|B<<28,B>>>4|0<<28)|0;B=xrc(M,E,W,G)|0;ya=RUb(B,G,q,_,ja,ba,Q,h,l)|0}else{ya=SUb(R,M,E,q,_,ja,ba,SUb(P,Z,F,q,_,ja,ba,T,h,l,9)|0,h,l,9)|0}F=J-1|0;if((F|0)<0){wa=_;break}else{Z=_;_=ja;$=ya;aa=F;ja=Z}}}}while(0);k=wa+16|0;v=wa+32|0;fa=v|0;ia=c[fa+4>>2]|0;D=k|0;ha=c[D+4>>2]|0;ea=ia>>>0<ha>>>0|ia>>>0==ha>>>0&(c[fa>>2]|0)>>>0<(c[D>>2]|0)>>>0?v:k;k=wa+48|0;v=k|0;D=c[v+4>>2]|0;fa=ea|0;ha=c[fa+4>>2]|0;ia=D>>>0<ha>>>0|D>>>0==ha>>>0&(c[v>>2]|0)>>>0<(c[fa>>2]|0)>>>0?k:ea;ea=wa+64|0;k=ea|0;fa=c[k+4>>2]|0;v=ia|0;ha=c[v+4>>2]|0;D=fa>>>0<ha>>>0|fa>>>0==ha>>>0&(c[k>>2]|0)>>>0<(c[v>>2]|0)>>>0?ea:ia;ia=wa+80|0;ea=ia|0;v=c[ea+4>>2]|0;k=D|0;ha=c[k+4>>2]|0;fa=v>>>0<ha>>>0|v>>>0==ha>>>0&(c[ea>>2]|0)>>>0<(c[k>>2]|0)>>>0?ia:D;D=wa+96|0;ia=D|0;k=c[ia+4>>2]|0;ea=fa|0;ha=c[ea+4>>2]|0;v=k>>>0<ha>>>0|k>>>0==ha>>>0&(c[ia>>2]|0)>>>0<(c[ea>>2]|0)>>>0?D:fa;fa=wa+112|0;D=fa|0;ea=c[D+4>>2]|0;ia=v|0;ha=c[ia+4>>2]|0;za=ea>>>0<ha>>>0|ea>>>0==ha>>>0&(c[D>>2]|0)>>>0<(c[ia>>2]|0)>>>0?fa:v}}while(0);do{if((I|0)==5){wa=la+16|0;ya=wa|0;l=c[ya+4>>2]|0;h=la|0;ba=c[h+4>>2]|0;p=l>>>0<ba>>>0|l>>>0==ba>>>0&(c[ya>>2]|0)>>>0<(c[h>>2]|0)>>>0?wa:la;wa=la+32|0;h=wa|0;ya=c[h+4>>2]|0;ba=p|0;l=c[ba+4>>2]|0;f=ya>>>0<l>>>0|ya>>>0==l>>>0&(c[h>>2]|0)>>>0<(c[ba>>2]|0)>>>0?wa:p;p=la+48|0;wa=p|0;ba=c[wa+4>>2]|0;h=f|0;l=c[h+4>>2]|0;ya=ba>>>0<l>>>0|ba>>>0==l>>>0&(c[wa>>2]|0)>>>0<(c[h>>2]|0)>>>0?p:f;if((ya|0)==(la|0)){H=0}else{za=ya;break}i=n;return H|0}}while(0);if(A){H=1;i=n;return H|0}A=0;la=c[za+8>>2]|0;while(1){za=g+(d[16032+(j<<4)+A|0]<<1)|0;I=b[za>>1]>>31;b[za>>1]=(I^e[t+(la<<2)+2>>1])-I;I=A+1|0;if((I|0)>(ka|0)){H=1;break}else{A=I;la=e[t+(la<<2)>>1]|0}}i=n;return H|0}function ZTb(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;k=i;i=i+4912|0;l=k|0;m=k+64|0;n=k+96|0;o=k+160|0;p=k+320|0;q=k+480|0;r=k+4576|0;s=k+4832|0;t=k+4848|0;u=k+4864|0;v=k+4880|0;w=k+4896|0;x=3-j|0;y=(c[f+8632>>2]|0)==2;z=y?16096:16104;A=y?8:4;B=(c[f+1716+(x<<2)>>2]|0)+(h<<5)|0;if((c[f+152>>2]|0)==0){C=(c[f+1684+(x<<2)>>2]|0)+(h<<6)|0;D=c[f+28856+(j<<2)>>2]|0;mrc(m|0,0,32)|0;E=(A>>>2)+3|0;F=D<<4;D=A;while(1){H=D-1|0;if((H|0)<0){I=0;J=64;break}K=b[B>>1]|0;if(((ca((K&65535)>>>1,b[g+(d[z+H|0]<<1)>>1]|0)|0)+32767|0)>>>0>65535>>>0){L=0;M=0;N=0;O=K;break}else{D=H}}if((J|0)==64){i=k;return I|0}while(1){D=b[g+(d[z+N|0]<<1)>>1]|0;K=D<<16>>16;P=D<<16>>16>-1?K:-K|0;K=D<<16>>16<0?-1:1;D=(ca((O&65535)>>>1,P)|0)+32768>>16;Q=(ca(D,K)|0)&65535;R=l+(N<<1)|0;b[R>>1]=Q;b[l+32+(N<<1)>>1]=Q;S=m+(N<<1)|0;b[S>>1]=Q;do{if((D|0)==0){c[n+(N<<2)>>2]=0;T=L;U=Q}else{V=c[C>>2]<<1;W=(ca((e[B>>1]|0)>>>1,P)|0)+16384>>16;X=D-1|0;Y=P-((ca(V,D)|0)+128>>8)|0;Z=P-((ca(V,X)|0)+128>>8)|0;c[n+(N<<2)>>2]=(ca(Z,Z)|0)-(ca(Y,Y)|0)<<8;Y=(ca(X,K)|0)&65535;b[R>>1]=Y;if((W|0)==(D|0)){T=L|1<<N;U=Q;break}else{b[S>>1]=Y;T=L;U=Y;break}}}while(0);_=(U<<16>>16!=0)<<N|M;S=N+1|0;if((S|0)>(H|0)){break}L=T;M=_;N=S;O=b[B>>1]|0}O=f+1520|0;c[O>>2]=0;if((_|0)==0){N=100209+(E<<1)|0;M=d[N]|0;c[O>>2]=M;$=M;aa=N;ba=m|0;da=0}else{N=m|0;JUb(f,3,N,E)|0;$=c[O>>2]|0;aa=100209+(E<<1)|0;ba=N;da=_}_=F;N=(F|0)<0|0?-1:0;F=Erc($,($|0)<0|0?-1:0,_,N)|0;$=T;T=da;da=G;M=F;while(1){F=da;L=M;U=0;C=-1;S=T;Q=$;D=0;while(1){R=c[n+(D<<2)>>2]|0;if((R|0)==0){ea=Q;fa=S;ga=C;ha=U;ia=F;ja=L}else{K=1<<D;P=K^$;Y=P>>>(D>>>0)&1;W=m+(D<<1)|0;X=b[W>>1]|0;Z=b[l+(Y<<5)+(D<<1)>>1]|0;V=(Z<<16>>16!=0)<<D|T&~K;K=ca((Y<<1^2)-1|0,R)|0;b[W>>1]=Z;c[O>>2]=0;if((V|0)==0){Z=d[aa]|0;c[O>>2]=Z;ka=Z}else{JUb(f,3,ba,E)|0;ka=c[O>>2]|0}Z=Erc(ka,(ka|0)<0|0?-1:0,_,N)|0;R=wrc(Z,G,K,(K|0)<0|0?-1:0)|0;Z=G;b[W>>1]=X;X=(Z|0)<(F|0)|(Z|0)==(F|0)&R>>>0<L>>>0;ea=X?P:Q;fa=X?V:S;ga=X?D:C;ha=X?K:U;ia=X?Z:F;ja=X?R:L}R=D+1|0;if((R|0)>(H|0)){break}else{F=ia;L=ja;U=ha;C=ga;S=fa;Q=ea;D=R}}if(!((ga|0)>-1)){break}D=xrc(ja,ia,ha,(ha|0)<0|0?-1:0)|0;b[m+(ga<<1)>>1]=b[l+((ea>>>(ga>>>0)&1)<<5)+(ga<<1)>>1]|0;c[n+(ga<<2)>>2]=0;$=ea;T=fa;da=G;M=D}if((T|0)==0){I=0;i=k;return I|0}else{la=0}while(1){b[g+(d[z+la|0]<<1)>>1]=b[m+(la<<1)>>1]|0;T=la+1|0;if((T|0)<(A|0)){la=T}else{I=1;break}}i=k;return I|0}la=(c[f+1780+(x<<2)>>2]|0)+(h<<5)|0;m=(c[f+1684+(x<<2)>>2]|0)+(h<<6)|0;h=c[f+28856+(j<<2)>>2]|0;j=s|0;x=o+31&-32;o=x;T=p+31&-32;p=c[f+18660>>2]|0;M=e[18870+(p<<5)>>1]|0;da=e[97198+(p<<5)>>1]|0;nrc(x|0,g|0,A<<1)|0;x=f+37728|0;p=Ee[c[x>>2]&511](g,(e[B>>1]|0)>>>1,e[la>>1]<<1)|0;if(y){ma=Ee[c[x>>2]&511](g+8|0,(e[B>>1]|0)>>>1,e[la>>1]<<1)|0|p}else{ma=p}if((ma|0)==0){I=0;i=k;return I|0}else{na=0}do{b[T+(na<<1)>>1]=b[g+(d[z+na|0]<<1)>>1]|0;na=na+1|0;}while((na|0)<(A|0));na=ve[c[f+37788>>2]&4095](T)|0;ma=f+14181|0;p=r|0;la=r+16|0;c[la>>2]=-1;c[la+4>>2]=-1;la=r+32|0;c[la>>2]=-1;c[la+4>>2]=-1;la=r+48|0;c[la>>2]=-1;c[la+4>>2]=-1;la=r|0;c[la>>2]=0;c[la+4>>2]=268435456;c[r+8>>2]=0;la=q|0;b[q+2>>1]=0;b[q>>1]=0;nrc(j|0,ma|0,10)|0;a[s+12|0]=a[ma]|0;a[s+13|0]=a[f+14185|0]|0;a[s+14|0]=a[f+14189|0]|0;a[s+15|0]=a[f+14190|0]|0;s=(na|0)<0;a:do{if(s){oa=p;J=8}else{ma=h;B=(h|0)<0|0?-1:0;x=A-1|0;fa=t|0;ea=t+4|0;$=t+8|0;ga=v|0;n=u|0;l=u+8|0;ha=v+8|0;ia=na;ja=r+128|0;H=p;N=1;while(1){_=b[T+(ia<<1)>>1]|0;if(_<<16>>16==0){if(y){pa=d[100168+ia|0]|0}else{pa=ia}ka=Erc(e[101200+(d[pa+M+(f+13924)|0]<<1)>>1]|0,0,ma,B)|0;O=G;E=H|0;ba=xrc(c[E>>2]|0,c[E+4>>2]|0,ka>>>4|O<<28,O>>>4|0<<28)|0;c[E>>2]=ba;c[E+4>>2]=G;E=H+24|0;c[q+(N<<2)>>2]=c[E>>2];c[E>>2]=N;E=N+1|0;ba=H+40|0;c[q+(E<<2)>>2]=c[ba>>2];c[ba>>2]=E;E=N+2|0;ba=H+56|0;c[q+(E<<2)>>2]=c[ba>>2];c[ba>>2]=E;qa=N+3|0;ra=H;sa=ja}else{E=b[o+(d[z+ia|0]<<1)>>1]|0;ba=E<<16>>16;O=_<<16>>16;ka=ja|0;c[ka>>2]=-1;c[ka+4>>2]=-1;ka=ja+16|0;c[ka>>2]=-1;c[ka+4>>2]=-1;ka=ja+32|0;c[ka>>2]=-1;c[ka+4>>2]=-1;ka=ja+48|0;c[ka>>2]=-1;c[ka+4>>2]=-1;ka=ja+64|0;c[ka>>2]=-1;c[ka+4>>2]=-1;ka=ja+80|0;c[ka>>2]=-1;c[ka+4>>2]=-1;ka=ja+96|0;c[ka>>2]=-1;c[ka+4>>2]=-1;ka=ja+112|0;c[ka>>2]=-1;c[ka+4>>2]=-1;ka=E<<16>>16>-1?ba:-ba|0;ta=_<<16>>16>-1?O:-O|0;if((ia|0)<(x|0)){if(y){ua=d[100168+ia|0]|0}else{ua=ia}O=d[ua+M+(f+13924)|0]|0;_=b[101200+(O<<1)>>1]|0;c[fa>>2]=_&65535;ba=e[101200+((O^1)<<1)>>1]|0;O=d[ua+da+(f+13924)|0]|0;c[ea>>2]=(e[101200+(O<<1)>>1]|0)+ba;c[$>>2]=(e[101200+((O^1)<<1)>>1]|0)+ba;va=0;wa=_&65535}else{c[$>>2]=0;c[ea>>2]=0;c[fa>>2]=0;va=0;wa=0}xa=ta-1|0;_=c[m>>2]<<1;ba=ka-((ca(_,xa)|0)+128>>8)|0;O=ba;E=(ba|0)<0|0?-1:0;ya=Erc(O<<8|0>>>24,E<<8|O>>>24,O,E)|0;za=G;c[ga>>2]=ya;c[ga+4>>2]=za;c[n>>2]=ya;c[n+4>>2]=za;E=ka-((ca(_,ta)|0)+128>>8)|0;_=E;ka=(E|0)<0|0?-1:0;E=Erc(_<<8|0>>>24,ka<<8|_>>>24,_,ka)|0;ka=G;c[ha>>2]=E;c[ha+4>>2]=ka;c[l>>2]=E;c[l+4>>2]=ka;if((ta|0)==2){J=20;break}else if((ta|0)!=1){J=23;break}ka=Erc(wa,va,ma,B)|0;E=G;_=ka>>>4|E<<28;ka=E>>>4|0<<28;E=wrc(ya,za,_,ka)|0;c[ga>>2]=E;c[ga+4>>2]=G;E=xrc(0,0,_,ka)|0;ka=NUb(E,G,ja,H,la,N)|0;E=c[ga>>2]|0;_=c[ga+4>>2]|0;O=xrc(c[l>>2]|0,c[l+4>>2]|0,E,_)|0;ba=G;aa=xrc(c[ha>>2]|0,c[ha+4>>2]|0,E,_)|0;qa=OUb(O,ba,aa,G,fa,ja,H,la,ka,h,j)|0;ra=ja;sa=H}ka=ia-1|0;if((ka|0)<0){oa=ra;J=8;break a}else{ia=ka;ja=sa;H=ra;N=qa}}if((J|0)==20){ga=OUb(ya,za,ya,za,fa,ja,H,la,N,h,j)|0;Aa=PUb(2,c[l>>2]|0,c[l+4>>2]|0,c[ha>>2]|0,c[ha+4>>2]|0,fa,ja,H,la,ga,h,j)|0}else if((J|0)==23){ga=PUb(xa,ya,za,ya,za,fa,ja,H,la,N,h,j)|0;Aa=PUb(ta,c[l>>2]|0,c[l+4>>2]|0,c[ha>>2]|0,c[ha+4>>2]|0,fa,ja,H,la,ga,h,j)|0}ga=ia-1|0;b:do{if((ga|0)<0){Ba=ja}else{n=w|0;ea=w+4|0;$=H;x=ja;ka=Aa;aa=ga;while(1){ba=x+24|0;O=x+40|0;_=x+56|0;E=x+72|0;D=x+88|0;Q=x+104|0;S=x+120|0;C=ka;U=aa;while(1){Ca=b[T+(U<<1)>>1]|0;if(!(Ca<<16>>16==0)){break}c[q+(C<<2)>>2]=c[ba>>2];c[ba>>2]=C;L=C+1|0;c[q+(L<<2)>>2]=c[O>>2];c[O>>2]=L;L=C+2|0;c[q+(L<<2)>>2]=c[_>>2];c[_>>2]=L;L=C+3|0;c[q+(L<<2)>>2]=c[E>>2];c[E>>2]=L;L=C+4|0;c[q+(L<<2)>>2]=c[D>>2];c[D>>2]=L;L=C+5|0;c[q+(L<<2)>>2]=c[Q>>2];c[Q>>2]=L;L=C+6|0;c[q+(L<<2)>>2]=c[S>>2];c[S>>2]=L;L=U-1|0;if((L|0)<0){Ba=x;break b}else{C=C+7|0;U=L}}S=b[o+(d[z+U|0]<<1)>>1]|0;Q=S<<16>>16;D=Ca<<16>>16;E=$+16|0;c[E>>2]=-1;c[E+4>>2]=-1;E=$+32|0;c[E>>2]=-1;c[E+4>>2]=-1;E=$+48|0;c[E>>2]=-1;c[E+4>>2]=-1;E=$+64|0;c[E>>2]=-1;c[E+4>>2]=-1;E=$+80|0;c[E>>2]=-1;c[E+4>>2]=-1;E=$+96|0;c[E>>2]=-1;c[E+4>>2]=-1;E=$+112|0;c[E>>2]=-1;c[E+4>>2]=-1;E=S<<16>>16>-1?Q:-Q|0;Q=Ca<<16>>16>-1?D:-D|0;if(y){Da=d[100168+U|0]|0}else{Da=U}D=d[Da+M+(f+13924)|0]|0;S=b[101200+(D<<1)>>1]|0;c[n>>2]=S&65535;c[ea>>2]=(e[101200+(d[Da+da+(f+13924)|0]<<1)>>1]|0)+(e[101200+((D^1)<<1)>>1]|0);D=Q-1|0;_=c[m>>2]<<1;O=E-((ca(_,D)|0)+128>>8)|0;ba=O;L=(O|0)<0|0?-1:0;O=Erc(ba<<8|0>>>24,L<<8|ba>>>24,ba,L)|0;L=G;ba=E-((ca(_,Q)|0)+128>>8)|0;_=ba;E=(ba|0)<0|0?-1:0;ba=Erc(_<<8|0>>>24,E<<8|_>>>24,_,E)|0;E=G;if((Q|0)==2){Ea=SUb(2,ba,E,n,$,x,la,RUb(O,L,n,$,x,la,C,h,j)|0,h,j,8)|0}else if((Q|0)==1){_=Erc(S&65535,0,ma,B)|0;S=G;F=QUb($,x,la,C)|0;R=wrc(O,L,_>>>4|S<<28,S>>>4|0<<28)|0;S=xrc(ba,E,R,G)|0;Ea=RUb(S,G,n,$,x,la,F,h,j)|0}else{Ea=SUb(Q,ba,E,n,$,x,la,SUb(D,O,L,n,$,x,la,C,h,j,8)|0,h,j,8)|0}L=U-1|0;if((L|0)<0){Ba=$;break}else{O=$;$=x;ka=Ea;aa=L;x=O}}}}while(0);B=Ba+16|0;ma=Ba+32|0;ga=ma|0;ja=c[ga+4>>2]|0;H=B|0;ia=c[H+4>>2]|0;fa=ja>>>0<ia>>>0|ja>>>0==ia>>>0&(c[ga>>2]|0)>>>0<(c[H>>2]|0)>>>0?ma:B;B=Ba+48|0;ma=B|0;H=c[ma+4>>2]|0;ga=fa|0;ia=c[ga+4>>2]|0;ja=H>>>0<ia>>>0|H>>>0==ia>>>0&(c[ma>>2]|0)>>>0<(c[ga>>2]|0)>>>0?B:fa;fa=Ba+64|0;B=fa|0;ga=c[B+4>>2]|0;ma=ja|0;ia=c[ma+4>>2]|0;H=ga>>>0<ia>>>0|ga>>>0==ia>>>0&(c[B>>2]|0)>>>0<(c[ma>>2]|0)>>>0?fa:ja;ja=Ba+80|0;fa=ja|0;ma=c[fa+4>>2]|0;B=H|0;ia=c[B+4>>2]|0;ga=ma>>>0<ia>>>0|ma>>>0==ia>>>0&(c[fa>>2]|0)>>>0<(c[B>>2]|0)>>>0?ja:H;H=Ba+96|0;ja=H|0;B=c[ja+4>>2]|0;fa=ga|0;ia=c[fa+4>>2]|0;ma=B>>>0<ia>>>0|B>>>0==ia>>>0&(c[ja>>2]|0)>>>0<(c[fa>>2]|0)>>>0?H:ga;ga=Ba+112|0;H=ga|0;fa=c[H+4>>2]|0;ja=ma|0;ia=c[ja+4>>2]|0;Fa=fa>>>0<ia>>>0|fa>>>0==ia>>>0&(c[H>>2]|0)>>>0<(c[ja>>2]|0)>>>0?ga:ma}}while(0);do{if((J|0)==8){Ba=oa+16|0;Ea=Ba|0;j=c[Ea+4>>2]|0;h=oa|0;la=c[h+4>>2]|0;m=j>>>0<la>>>0|j>>>0==la>>>0&(c[Ea>>2]|0)>>>0<(c[h>>2]|0)>>>0?Ba:oa;Ba=oa+32|0;h=Ba|0;Ea=c[h+4>>2]|0;la=m|0;j=c[la+4>>2]|0;f=Ea>>>0<j>>>0|Ea>>>0==j>>>0&(c[h>>2]|0)>>>0<(c[la>>2]|0)>>>0?Ba:m;m=oa+48|0;Ba=m|0;la=c[Ba+4>>2]|0;h=f|0;j=c[h+4>>2]|0;Ea=la>>>0<j>>>0|la>>>0==j>>>0&(c[Ba>>2]|0)>>>0<(c[h>>2]|0)>>>0?m:f;if((Ea|0)==(oa|0)){I=0}else{Fa=Ea;break}i=k;return I|0}}while(0);if(s){I=1;i=k;return I|0}s=0;oa=c[Fa+8>>2]|0;while(1){Fa=g+(d[z+s|0]<<1)|0;J=b[Fa>>1]>>31;b[Fa>>1]=(J^e[q+(oa<<2)+2>>1])-J;J=s+1|0;if((J|0)>(na|0)){I=1;break}else{s=J;oa=e[q+(oa<<2)>>1]|0}}i=k;return I|0}function _Tb(f,g,h,j,k,l,m,n){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0;o=i;i=i+4912|0;p=o|0;q=o+64|0;r=o+96|0;s=o+160|0;t=o+320|0;u=o+480|0;v=o+4576|0;w=o+4832|0;x=o+4848|0;y=o+4864|0;z=o+4880|0;A=o+4896|0;B=d[19408+k|0]|0;C=c[f+1716+(h<<2)>>2]|0;if((c[f+152>>2]|0)==0){D=c[f+1684+(h<<2)>>2]|0;E=c[f+18660>>2]|0;F=c[f+28848+(m<<3)+(l<<2)>>2]|0;mrc(q|0,0,32)|0;H=(m|0)!=0;I=d[19112+n|0]|0;J=(d[I-8+(f+27984)|0]|0)+(d[I-1+(f+27984)|0]|0)|0;if((J|0)<128){K=(J+1|0)>>>1}else{K=J}J=d[1625080+(K&127)|0]|0;K=n&15;I=F<<4;F=15;while(1){if((F|0)<(B|0)){break}L=d[16032+(E<<4)+F|0]|0;if(((ca(e[C+(j<<5)+(L<<1)>>1]|0,b[g+(L<<1)>>1]|0)|0)+32767|0)>>>0>65535>>>0){M=46;break}else{F=F-1|0}}do{if((M|0)==46){L=f+18656|0;N=0;O=0;P=B;while(1){Q=d[16032+(E<<4)+P|0]|0;R=b[g+(Q<<1)>>1]|0;S=R<<16>>16;T=R<<16>>16>-1?S:-S|0;U=R<<16>>16<0?-1:1;R=C+(j<<5)+(Q<<1)|0;V=(ca(e[R>>1]|0,T)|0)+32768>>16;W=(ca(V,U)|0)&65535;X=p+(P<<1)|0;b[X>>1]=W;b[p+32+(P<<1)>>1]=W;Y=q+(P<<1)|0;b[Y>>1]=W;do{if((V|0)==0){c[r+(P<<2)>>2]=0;Z=N;_=W}else{$=c[D+(j<<6)+(Q<<2)>>2]|0;aa=(ca(e[R>>1]|0,T)|0)+16384>>16;ba=(ca($,V)|0)+128>>8;da=V-1|0;ea=(ca($,da)|0)+128>>8;$=T-ba|0;fa=T-ea|0;ga=(ca(fa,fa)|0)-(ca($,$)|0)|0;$=ca(ga,c[98744+(Q<<2)>>2]|0)|0;ga=r+(P<<2)|0;c[ga>>2]=$;fa=c[L>>2]|0;if(!((fa|0)==0|(P|0)==0|H)){ha=(b[f+23792+(K<<5)+(Q<<1)>>1]|0)-S|0;ia=ha+(ca(ea,U)|0)|0;ea=ha+(ca(ba,U)|0)|0;c[ga>>2]=(ca(ca(c[98680+(Q<<2)>>2]|0,fa)|0,((ia|0)>-1?ia:-ia|0)-((ea|0)>-1?ea:-ea|0)|0)|0)+$}$=(ca(da,U)|0)&65535;b[X>>1]=$;if((aa|0)==(V|0)){Z=N|1<<P;_=W;break}else{b[Y>>1]=$;Z=N;_=$;break}}}while(0);ja=(_<<16>>16!=0)<<P|O;Y=P+1|0;if((Y|0)>(F|0)){break}else{N=Z;O=ja;P=Y}}P=f+1520|0;c[P>>2]=0;if((ja|0)==0){O=100209+(J<<1)|0;N=d[O]|0;c[P>>2]=N;ka=N;la=O;ma=q+(B<<1)|0;na=0}else{O=q+(B<<1)|0;JUb(f,k,O,J)|0;ka=c[P>>2]|0;la=100209+(J<<1)|0;ma=O;na=ja}O=I;N=(I|0)<0|0?-1:0;L=Erc(ka,(ka|0)<0|0?-1:0,O,N)|0;Y=Z;W=na;V=G;X=L;while(1){L=V;U=X;Q=0;S=-1;T=W;R=Y;$=B;while(1){aa=c[r+($<<2)>>2]|0;if((aa|0)==0){oa=R;pa=T;qa=S;ra=Q;sa=L;ta=U}else{da=1<<$;ea=da^Y;ia=ea>>>($>>>0)&1;fa=q+($<<1)|0;ga=b[fa>>1]|0;ba=b[p+(ia<<5)+($<<1)>>1]|0;ha=(ba<<16>>16!=0)<<$|W&~da;da=ca((ia<<1^2)-1|0,aa)|0;b[fa>>1]=ba;c[P>>2]=0;if((ha|0)==0){ba=d[la]|0;c[P>>2]=ba;ua=ba}else{JUb(f,k,ma,J)|0;ua=c[P>>2]|0}ba=Erc(ua,(ua|0)<0|0?-1:0,O,N)|0;aa=wrc(ba,G,da,(da|0)<0|0?-1:0)|0;ba=G;b[fa>>1]=ga;ga=(ba|0)<(L|0)|(ba|0)==(L|0)&aa>>>0<U>>>0;oa=ga?ea:R;pa=ga?ha:T;qa=ga?$:S;ra=ga?da:Q;sa=ga?ba:L;ta=ga?aa:U}aa=$+1|0;if((aa|0)>(F|0)){break}else{L=sa;U=ta;Q=ra;S=qa;T=pa;R=oa;$=aa}}if(!((qa|0)>-1)){break}$=xrc(ta,sa,ra,(ra|0)<0|0?-1:0)|0;b[q+(qa<<1)>>1]=b[p+((oa>>>(qa>>>0)&1)<<5)+(qa<<1)>>1]|0;c[r+(qa<<2)>>2]=0;Y=oa;W=pa;V=G;X=$}if((W|0)==0){break}else{va=B}while(1){b[g+(d[16032+(E<<4)+va|0]<<1)>>1]=b[q+(va<<1)>>1]|0;X=va+1|0;if((X|0)<16){va=X}else{wa=1;break}}i=o;return wa|0}}while(0);mrc(g|0,0,32)|0;wa=0;i=o;return wa|0}va=(c[f+1780+(h<<2)>>2]|0)+(j<<5)|0;q=c[f+1684+(h<<2)>>2]|0;h=c[f+18660>>2]|0;E=c[f+28848+(m<<3)+(l<<2)>>2]|0;l=w|0;pa=s+31&-32;s=pa;oa=t+31&-32;t=e[18864+(h<<5)+(k<<1)>>1]|0;qa=e[97192+(h<<5)+(k<<1)>>1]|0;r=(m|0)!=0;m=g;nrc(pa|0,m|0,32)|0;if((Ee[c[f+37716>>2]&511](g,C+(j<<5)|0,va)|0)==0){wa=0;i=o;return wa|0}re[c[f+37644>>2]&1023](oa,g);va=ve[c[f+37776+(k<<2)>>2]&4095](oa+(B<<1)|0)|0;C=va+B|0;pa=e[100176+(k<<1)>>1]|0;k=f+13924+pa|0;if((C|0)==0){p=(MUb(b[s>>1]|0,b[oa>>1]|0,c[q+(j<<6)>>2]|0,c[24686]|0,E,k,(e[101200+((d[f+13924+qa|0]^1)<<1)>>1]|0)+(e[101200+((d[f+13924+t|0]^1)<<1)>>1]|0)|0)|0)&65535;b[g>>1]=p;wa=p<<16>>16!=0|0;i=o;return wa|0}p=v|0;ra=v+16|0;c[ra>>2]=-1;c[ra+4>>2]=-1;ra=v+32|0;c[ra>>2]=-1;c[ra+4>>2]=-1;ra=v+48|0;c[ra>>2]=-1;c[ra+4>>2]=-1;ra=v|0;c[ra>>2]=0;c[ra+4>>2]=268435456;c[v+8>>2]=0;ra=u|0;b[u+2>>1]=0;b[u>>1]=0;nrc(l|0,k|0,10)|0;a[w+12|0]=a[k]|0;a[w+13|0]=a[pa+4+(f+13924)|0]|0;a[w+14|0]=a[pa+8+(f+13924)|0]|0;a[w+15|0]=a[pa+9+(f+13924)|0]|0;pa=n&15;n=(va|0)<0;a:do{if(n){xa=p;M=7}else{va=E;w=(E|0)<0|0?-1:0;k=x|0;sa=x+4|0;ta=x+8|0;F=f+18656|0;ua=z|0;J=y|0;ma=y+8|0;la=z+8|0;na=C;Z=v+128|0;ka=p;I=1;while(1){ja=b[oa+(na<<1)>>1]|0;if(ja<<16>>16==0){_=Erc(e[101200+(d[na+t+(f+13924)|0]<<1)>>1]|0,0,va,w)|0;K=G;H=ka|0;D=xrc(c[H>>2]|0,c[H+4>>2]|0,_>>>4|K<<28,K>>>4|0<<28)|0;c[H>>2]=D;c[H+4>>2]=G;H=ka+24|0;c[u+(I<<2)>>2]=c[H>>2];c[H>>2]=I;H=I+1|0;D=ka+40|0;c[u+(H<<2)>>2]=c[D>>2];c[D>>2]=H;H=I+2|0;D=ka+56|0;c[u+(H<<2)>>2]=c[D>>2];c[D>>2]=H;ya=I+3|0;za=ka;Aa=Z}else{H=d[16032+(h<<4)+na|0]|0;D=b[s+(H<<1)>>1]|0;K=D<<16>>16;_=ja<<16>>16;W=Z|0;c[W>>2]=-1;c[W+4>>2]=-1;W=Z+16|0;c[W>>2]=-1;c[W+4>>2]=-1;W=Z+32|0;c[W>>2]=-1;c[W+4>>2]=-1;W=Z+48|0;c[W>>2]=-1;c[W+4>>2]=-1;W=Z+64|0;c[W>>2]=-1;c[W+4>>2]=-1;W=Z+80|0;c[W>>2]=-1;c[W+4>>2]=-1;W=Z+96|0;c[W>>2]=-1;c[W+4>>2]=-1;W=Z+112|0;c[W>>2]=-1;c[W+4>>2]=-1;W=D<<16>>16>-1?K:-K|0;Ba=ja<<16>>16>-1?_:-_|0;if((na|0)<15){_=d[na+t+(f+13924)|0]|0;ja=b[101200+(_<<1)>>1]|0;c[k>>2]=ja&65535;D=e[101200+((_^1)<<1)>>1]|0;_=d[na+qa+(f+13924)|0]|0;c[sa>>2]=(e[101200+(_<<1)>>1]|0)+D;c[ta>>2]=(e[101200+((_^1)<<1)>>1]|0)+D;Ca=0;Da=ja&65535}else{c[ta>>2]=0;c[sa>>2]=0;c[k>>2]=0;Ca=0;Da=0}Ea=Ba-1|0;ja=c[F>>2]|0;D=(na|0)==0;_=(ja|0)==0|D|r;X=K>>31;V=K>>>31|8;Y=c[q+(j<<6)+(H<<2)>>2]|0;N=98744+(H<<2)|0;O=f+23792+(pa<<5)+(H<<1)|0;P=98680+(H<<2)|0;H=(ca(Y,Ea)|0)+128>>8;$=W-H|0;if(_){R=$;T=($|0)<0|0?-1:0;S=Erc(R,T,R,T)|0;T=c[N>>2]|0;R=Erc(S,G,T,0)|0;Fa=T;Ga=G;Ha=R}else{R=((b[O>>1]|0)-K^X)-X+H|0;T=ca(c[P>>2]|0,ja)|0;S=$;Q=($|0)<0|0?-1:0;$=Erc(S,Q,S,Q)|0;Q=c[N>>2]|0;N=Erc($,G,Q,0)|0;$=ca(T,(R|0)>-1?R:-R|0)|0;R=xrc(N,G,$,($|0)<0|0?-1:0)|0;Fa=Q;Ga=G;Ha=R}c[ua>>2]=Ha;c[ua+4>>2]=Ga;if(D){R=K-((H^X)+V&-16)|0;H=R;Q=(R|0)<0|0?-1:0;R=Erc(H,Q,H,Q)|0;Q=Erc(R,G,Fa,0)|0;Ia=G;Ja=Q}else{Ia=Ga;Ja=Ha}c[J>>2]=Ja;c[J+4>>2]=Ia;Q=(ca(Y,Ba)|0)+128>>8;Y=W-Q|0;if(_){_=Y;W=(Y|0)<0|0?-1:0;R=Erc(_,W,_,W)|0;W=Erc(R,G,Fa,0)|0;Ka=G;La=W}else{W=((b[O>>1]|0)-K^X)-X+Q|0;O=ca(c[P>>2]|0,ja)|0;ja=Y;P=(Y|0)<0|0?-1:0;Y=Erc(ja,P,ja,P)|0;P=Erc(Y,G,Fa,0)|0;Y=ca(O,(W|0)>-1?W:-W|0)|0;W=xrc(P,G,Y,(Y|0)<0|0?-1:0)|0;Ka=G;La=W}c[la>>2]=La;c[la+4>>2]=Ka;if(D){D=K-((Q^X)+V&-16)|0;V=D;X=(D|0)<0|0?-1:0;D=Erc(V,X,V,X)|0;X=Erc(D,G,Fa,0)|0;Ma=G;Na=X}else{Ma=Ka;Na=La}c[ma>>2]=Na;c[ma+4>>2]=Ma;if((Ba|0)==2){M=20;break}else if((Ba|0)!=1){M=23;break}X=Erc(Da,Ca,va,w)|0;D=G;V=wrc(Ha,Ga,X>>>4|D<<28,D>>>4|0<<28)|0;D=G;c[ua>>2]=V;c[ua+4>>2]=D;X=xrc(Ja,Ia,V,D)|0;D=NUb(X,G,Z,ka,ra,I)|0;X=c[ua>>2]|0;V=c[ua+4>>2]|0;Q=xrc(c[ma>>2]|0,c[ma+4>>2]|0,X,V)|0;K=G;W=xrc(c[la>>2]|0,c[la+4>>2]|0,X,V)|0;ya=OUb(Q,K,W,G,k,Z,ka,ra,D,E,l)|0;za=Z;Aa=ka}D=na-1|0;if((D|0)<(B|0)){xa=za;M=7;break a}else{na=D;Z=Aa;ka=za;I=ya}}if((M|0)==20){ua=OUb(Ja,Ia,Ha,Ga,k,Z,ka,ra,I,E,l)|0;Oa=PUb(2,c[ma>>2]|0,c[ma+4>>2]|0,c[la>>2]|0,c[la+4>>2]|0,k,Z,ka,ra,ua,E,l)|0}else if((M|0)==23){ua=PUb(Ea,Ja,Ia,Ha,Ga,k,Z,ka,ra,I,E,l)|0;Oa=PUb(Ba,c[ma>>2]|0,c[ma+4>>2]|0,c[la>>2]|0,c[la+4>>2]|0,k,Z,ka,ra,ua,E,l)|0}ua=na-1|0;b:do{if((ua|0)<(B|0)){Pa=Z}else{J=A|0;sa=A+4|0;ta=ka;D=Z;W=Oa;K=ua;while(1){Q=D+24|0;V=D+40|0;X=D+56|0;Y=D+72|0;P=D+88|0;O=D+104|0;ja=D+120|0;R=W;_=K;while(1){Qa=b[oa+(_<<1)>>1]|0;if(!(Qa<<16>>16==0)){break}c[u+(R<<2)>>2]=c[Q>>2];c[Q>>2]=R;H=R+1|0;c[u+(H<<2)>>2]=c[V>>2];c[V>>2]=H;H=R+2|0;c[u+(H<<2)>>2]=c[X>>2];c[X>>2]=H;H=R+3|0;c[u+(H<<2)>>2]=c[Y>>2];c[Y>>2]=H;H=R+4|0;c[u+(H<<2)>>2]=c[P>>2];c[P>>2]=H;H=R+5|0;c[u+(H<<2)>>2]=c[O>>2];c[O>>2]=H;H=R+6|0;c[u+(H<<2)>>2]=c[ja>>2];c[ja>>2]=H;H=_-1|0;if((H|0)<(B|0)){Pa=D;break b}else{R=R+7|0;_=H}}ja=d[16032+(h<<4)+_|0]|0;O=b[s+(ja<<1)>>1]|0;P=O<<16>>16;Y=Qa<<16>>16;X=ta+16|0;c[X>>2]=-1;c[X+4>>2]=-1;X=ta+32|0;c[X>>2]=-1;c[X+4>>2]=-1;X=ta+48|0;c[X>>2]=-1;c[X+4>>2]=-1;X=ta+64|0;c[X>>2]=-1;c[X+4>>2]=-1;X=ta+80|0;c[X>>2]=-1;c[X+4>>2]=-1;X=ta+96|0;c[X>>2]=-1;c[X+4>>2]=-1;X=ta+112|0;c[X>>2]=-1;c[X+4>>2]=-1;X=O<<16>>16>-1?P:-P|0;O=Qa<<16>>16>-1?Y:-Y|0;Y=d[_+t+(f+13924)|0]|0;V=b[101200+(Y<<1)>>1]|0;c[J>>2]=V&65535;c[sa>>2]=(e[101200+(d[_+qa+(f+13924)|0]<<1)>>1]|0)+(e[101200+((Y^1)<<1)>>1]|0);Y=O-1|0;Q=c[F>>2]|0;H=P>>31;$=c[q+(j<<6)+(ja<<2)>>2]|0;N=(ca($,Y)|0)+128>>8;T=X-N|0;if((Q|0)==0|(_|0)==0|r){S=T;U=(T|0)<0|0?-1:0;L=Erc(S,U,S,U)|0;U=c[98744+(ja<<2)>>2]|0;S=Erc(L,G,U,0)|0;L=G;aa=X-((ca($,O)|0)+128>>8)|0;ga=aa;ba=(aa|0)<0|0?-1:0;aa=Erc(ga,ba,ga,ba)|0;ba=Erc(aa,G,U,0)|0;Ra=G;Sa=ba;Ta=L;Ua=S}else{S=((b[f+23792+(pa<<5)+(ja<<1)>>1]|0)-P^H)-H+N|0;N=ca(c[98680+(ja<<2)>>2]|0,Q)|0;L=T;ba=(T|0)<0|0?-1:0;T=Erc(L,ba,L,ba)|0;ba=c[98744+(ja<<2)>>2]|0;L=Erc(T,G,ba,0)|0;T=ca(N,(S|0)>-1?S:-S|0)|0;S=xrc(L,G,T,(T|0)<0|0?-1:0)|0;T=G;L=(ca($,O)|0)+128>>8;$=X-L|0;X=((b[f+23792+(pa<<5)+(ja<<1)>>1]|0)-P^H)-H+L|0;L=ca(c[98680+(ja<<2)>>2]|0,Q)|0;Q=$;ja=($|0)<0|0?-1:0;$=Erc(Q,ja,Q,ja)|0;ja=Erc($,G,ba,0)|0;ba=ca(L,(X|0)>-1?X:-X|0)|0;X=xrc(ja,G,ba,(ba|0)<0|0?-1:0)|0;Ra=G;Sa=X;Ta=T;Ua=S}if((O|0)==1){S=Erc(V&65535,0,va,w)|0;V=G;T=QUb(ta,D,ra,R)|0;X=wrc(Ua,Ta,S>>>4|V<<28,V>>>4|0<<28)|0;V=xrc(Sa,Ra,X,G)|0;Va=RUb(V,G,J,ta,D,ra,T,E,l)|0}else if((O|0)==2){Va=SUb(2,Sa,Ra,J,ta,D,ra,RUb(Ua,Ta,J,ta,D,ra,R,E,l)|0,E,l,9)|0}else{Va=SUb(O,Sa,Ra,J,ta,D,ra,SUb(Y,Ua,Ta,J,ta,D,ra,R,E,l,9)|0,E,l,9)|0}Y=_-1|0;if((Y|0)<(B|0)){Pa=ta;break}else{O=ta;ta=D;W=Va;K=Y;D=O}}}}while(0);w=Pa+16|0;va=Pa+32|0;F=va|0;ua=c[F+4>>2]|0;Z=w|0;ka=c[Z+4>>2]|0;na=ua>>>0<ka>>>0|ua>>>0==ka>>>0&(c[F>>2]|0)>>>0<(c[Z>>2]|0)>>>0?va:w;w=Pa+48|0;va=w|0;Z=c[va+4>>2]|0;F=na|0;ka=c[F+4>>2]|0;ua=Z>>>0<ka>>>0|Z>>>0==ka>>>0&(c[va>>2]|0)>>>0<(c[F>>2]|0)>>>0?w:na;na=Pa+64|0;w=na|0;F=c[w+4>>2]|0;va=ua|0;ka=c[va+4>>2]|0;Z=F>>>0<ka>>>0|F>>>0==ka>>>0&(c[w>>2]|0)>>>0<(c[va>>2]|0)>>>0?na:ua;ua=Pa+80|0;na=ua|0;va=c[na+4>>2]|0;w=Z|0;ka=c[w+4>>2]|0;F=va>>>0<ka>>>0|va>>>0==ka>>>0&(c[na>>2]|0)>>>0<(c[w>>2]|0)>>>0?ua:Z;Z=Pa+96|0;ua=Z|0;w=c[ua+4>>2]|0;na=F|0;ka=c[na+4>>2]|0;va=w>>>0<ka>>>0|w>>>0==ka>>>0&(c[ua>>2]|0)>>>0<(c[na>>2]|0)>>>0?Z:F;F=Pa+112|0;Z=F|0;na=c[Z+4>>2]|0;ua=va|0;ka=c[ua+4>>2]|0;Wa=na>>>0<ka>>>0|na>>>0==ka>>>0&(c[Z>>2]|0)>>>0<(c[ua>>2]|0)>>>0?F:va}}while(0);do{if((M|0)==7){Pa=xa+16|0;Va=Pa|0;l=c[Va+4>>2]|0;E=xa|0;ra=c[E+4>>2]|0;Ta=l>>>0<ra>>>0|l>>>0==ra>>>0&(c[Va>>2]|0)>>>0<(c[E>>2]|0)>>>0?Pa:xa;Pa=xa+32|0;E=Pa|0;Va=c[E+4>>2]|0;ra=Ta|0;l=c[ra+4>>2]|0;Ua=Va>>>0<l>>>0|Va>>>0==l>>>0&(c[E>>2]|0)>>>0<(c[ra>>2]|0)>>>0?Pa:Ta;Ta=xa+48|0;Pa=Ta|0;ra=c[Pa+4>>2]|0;E=Ua|0;l=c[E+4>>2]|0;Va=ra>>>0<l>>>0|ra>>>0==l>>>0&(c[Pa>>2]|0)>>>0<(c[E>>2]|0)>>>0?Ta:Ua;if((Va|0)!=(xa|0)){Wa=Va;break}mrc(m|0,0,32)|0;wa=0;i=o;return wa|0}}while(0);if(n){wa=1;i=o;return wa|0}n=B;B=c[Wa+8>>2]|0;while(1){Wa=g+(d[16032+(h<<4)+n|0]<<1)|0;m=b[Wa>>1]>>31;b[Wa>>1]=(m^e[u+(B<<2)+2>>1])-m;m=n+1|0;if((m|0)>(C|0)){wa=1;break}else{n=m;B=e[u+(B<<2)>>1]|0}}i=o;return wa|0}function $Tb(f,g,h,j,k,l,m,n){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0;o=i;i=i+4912|0;p=o|0;q=o+64|0;r=o+96|0;s=o+160|0;t=o+320|0;u=o+480|0;v=o+4576|0;w=o+4832|0;x=o+4848|0;y=o+4864|0;z=o+4880|0;A=o+4896|0;B=f+1732+(h<<2)|0;if((c[f+152>>2]|0)==0){C=f+1700+(h<<2)|0;D=f+18660|0;E=f+28848+(m<<3)+(l<<2)|0;F=n<<2;H=q;I=(m|0)!=0;J=f+1520|0;K=q|0;L=f+18656|0;M=0;N=0;do{O=c[B>>2]|0;P=c[C>>2]|0;Q=c[D>>2]|0;R=c[E>>2]|0;S=N+F|0;mrc(H|0,0,32)|0;T=d[19112+S|0]|0;U=(d[T-8+(f+27984)|0]|0)+(d[T-1+(f+27984)|0]|0)|0;if((U|0)<128){V=(U+1|0)>>>1}else{V=U}U=d[1625080+(V&127)|0]|0;W=S&3;X=W|60;Y=R<<4;R=X;while(1){if((R|0)<(W|0)){Z=W;_=74;break}$=d[15776+(Q<<6)+R|0]|0;if(((ca(e[O+(j<<7)+($<<1)>>1]|0,b[g+($<<1)>>1]|0)|0)+32767|0)>>>0>65535>>>0){_=46;break}else{R=R-4|0}}a:do{if((_|0)==46){_=0;$=R>>2;aa=($|0)<0;do{if(aa){c[J>>2]=0;ba=0;_=58}else{da=S>>>2&3;ea=0;fa=0;ga=W;ha=0;while(1){ia=d[15776+(Q<<6)+ga|0]|0;ja=b[g+(ia<<1)>>1]|0;ka=ja<<16>>16;la=ja<<16>>16>-1?ka:-ka|0;ma=ja<<16>>16<0?-1:1;ja=O+(j<<7)+(ia<<1)|0;na=(ca(e[ja>>1]|0,la)|0)+32768>>16;oa=(ca(na,ma)|0)&65535;pa=p+(ha<<1)|0;b[pa>>1]=oa;b[p+32+(ha<<1)>>1]=oa;qa=q+(ha<<1)|0;b[qa>>1]=oa;do{if((na|0)==0){c[r+(ha<<2)>>2]=0;ra=ea;sa=oa}else{ta=c[P+(j<<8)+(ia<<2)>>2]|0;ua=(ca(e[ja>>1]|0,la)|0)+16384>>16;va=(ca(ta,na)|0)+128>>8;wa=na-1|0;xa=(ca(ta,wa)|0)+128>>8;ta=la-va|0;ya=la-xa|0;za=(ca(ya,ya)|0)-(ca(ta,ta)|0)|0;ta=ca(za,c[98424+(ia<<2)>>2]|0)|0;za=r+(ha<<2)|0;c[za>>2]=ta;ya=c[L>>2]|0;if(!((ya|0)==0|(ga|0)==0|I)){Aa=(b[f+23280+(da<<7)+(ia<<1)>>1]|0)-ka|0;Ba=Aa+(ca(xa,ma)|0)|0;xa=Aa+(ca(va,ma)|0)|0;c[za>>2]=(ca(ca(c[98168+(ia<<2)>>2]|0,ya)|0,((Ba|0)>-1?Ba:-Ba|0)-((xa|0)>-1?xa:-xa|0)|0)|0)+ta}ta=(ca(wa,ma)|0)&65535;b[pa>>1]=ta;if((ua|0)==(na|0)){ra=ea|1<<ha;sa=oa;break}else{b[qa>>1]=ta;ra=ea;sa=ta;break}}}while(0);Ca=(sa<<16>>16!=0)<<ha|fa;qa=ha+1|0;if((qa|0)>($|0)){break}else{ea=ra;fa=Ca;ga=ga+4|0;ha=qa}}c[J>>2]=0;if((Ca|0)==0){ba=ra;_=58;break}JUb(f,2,K,U)|0;Da=c[J>>2]|0;Ea=100209+(U<<1)|0;Fa=Ca;Ga=ra}}while(0);if((_|0)==58){_=0;ha=100209+(U<<1)|0;ga=d[ha]|0;c[J>>2]=ga;Da=ga;Ea=ha;Fa=0;Ga=ba}ha=Y;ga=(Y|0)<0|0?-1:0;b:do{if(aa){Ha=Fa}else{fa=Erc(Da,(Da|0)<0|0?-1:0,ha,ga)|0;ea=Ga;da=Fa;qa=G;oa=fa;while(1){fa=qa;na=oa;pa=0;ma=-1;ia=da;ka=ea;la=0;while(1){ja=c[r+(la<<2)>>2]|0;if((ja|0)==0){Ia=ka;Ja=ia;Ka=ma;La=pa;Ma=fa;Na=na}else{ta=1<<la;ua=ta^ea;wa=ua>>>(la>>>0)&1;xa=q+(la<<1)|0;Ba=b[xa>>1]|0;ya=b[p+(wa<<5)+(la<<1)>>1]|0;za=(ya<<16>>16!=0)<<la|da&~ta;ta=ca((wa<<1^2)-1|0,ja)|0;b[xa>>1]=ya;c[J>>2]=0;if((za|0)==0){ya=d[Ea]|0;c[J>>2]=ya;Oa=ya}else{JUb(f,2,K,U)|0;Oa=c[J>>2]|0}ya=Erc(Oa,(Oa|0)<0|0?-1:0,ha,ga)|0;ja=wrc(ya,G,ta,(ta|0)<0|0?-1:0)|0;ya=G;b[xa>>1]=Ba;Ba=(ya|0)<(fa|0)|(ya|0)==(fa|0)&ja>>>0<na>>>0;Ia=Ba?ua:ka;Ja=Ba?za:ia;Ka=Ba?la:ma;La=Ba?ta:pa;Ma=Ba?ya:fa;Na=Ba?ja:na}ja=la+1|0;if((ja|0)>($|0)){break}else{fa=Ma;na=Na;pa=La;ma=Ka;ia=Ja;ka=Ia;la=ja}}if(!((Ka|0)>-1)){Ha=da;break b}la=xrc(Na,Ma,La,(La|0)<0|0?-1:0)|0;b[q+(Ka<<1)>>1]=b[p+((Ia>>>(Ka>>>0)&1)<<5)+(Ka<<1)>>1]|0;c[r+(Ka<<2)>>2]=0;ea=Ia;da=Ja;qa=G;oa=la}}}while(0);if((Ha|0)==0){Z=W;_=74;break}else{Pa=W;Qa=0}while(1){b[g+(d[15776+(Q<<6)+Pa|0]<<1)>>1]=b[q+(Qa<<1)>>1]|0;$=Qa+1|0;if(($|0)>=16){Ra=1;break a}Pa=Pa+4|0;Qa=$}}}while(0);if((_|0)==74){while(1){_=0;b[g+(d[15776+(Q<<6)+Z|0]<<1)>>1]=0;W=Z+4|0;if((W|0)>(X|0)){Ra=0;break}else{Z=W;_=74}}}a[f+27984+T|0]=Ra;M=Ra|M;N=N+1|0;}while((N|0)<4);N=d[19112+F|0]|0;b[f+27984+N>>1]=0;b[N+8+(f+27984)>>1]=0;Sa=M;i=o;return Sa|0}M=(c[B>>2]|0)+(j<<7)|0;B=(c[f+1796+(h<<2)>>2]|0)+(j<<7)|0;N=c[f+1700+(h<<2)>>2]|0;h=c[f+18660>>2]|0;F=c[f+28848+(m<<3)+(l<<2)>>2]|0;l=w|0;Ra=s+31&-32;s=Ra;Z=t+31&-32;t=e[18864+(h<<5)+(k<<1)>>1]|0;Qa=e[97192+(h<<5)+(k<<1)>>1]|0;Pa=(m|0)!=0;Ee[c[f+37520>>2]&511](Ra,g,128)|0;if((Ee[c[f+37712>>2]&511](g,M,B)|0)==0){Sa=0;i=o;return Sa|0}re[c[f+37640>>2]&1023](Z,g);B=ve[c[f+37776+(k<<2)>>2]&4095](Z)|0;M=e[100176+(k<<1)>>1]|0;k=f+13924+M|0;if((B|0)==0){Ra=(MUb(b[s>>1]|0,b[Z>>1]|0,c[N+(j<<8)>>2]|0,c[24606]|0,F,k,(e[101200+((d[f+13924+Qa|0]^1)<<1)>>1]|0)+(e[101200+((d[f+13924+t|0]^1)<<1)>>1]|0)|0)|0)&65535;b[g>>1]=Ra;Sa=Ra<<16>>16!=0|0;i=o;return Sa|0}Ra=v|0;m=v+16|0;c[m>>2]=-1;c[m+4>>2]=-1;m=v+32|0;c[m>>2]=-1;c[m+4>>2]=-1;m=v+48|0;c[m>>2]=-1;c[m+4>>2]=-1;m=v|0;c[m>>2]=0;c[m+4>>2]=268435456;c[v+8>>2]=0;m=u|0;b[u+2>>1]=0;b[u>>1]=0;nrc(l|0,k|0,10)|0;a[w+12|0]=a[k]|0;a[w+13|0]=a[M+4+(f+13924)|0]|0;a[w+14|0]=a[M+8+(f+13924)|0]|0;a[w+15|0]=a[M+9+(f+13924)|0]|0;M=n&3;n=(B|0)<0;c:do{if(n){Ta=Ra;_=8}else{w=F;k=(F|0)<0|0?-1:0;q=x|0;Ha=x+4|0;Ja=x+8|0;Ia=f+18656|0;Ka=z|0;r=y|0;p=y+8|0;La=z+8|0;Ma=B;Na=v+128|0;Oa=Ra;J=1;while(1){K=b[Z+(Ma<<1)>>1]|0;if(K<<16>>16==0){Ea=Erc(e[101200+(d[(d[18736+(h<<6)+Ma|0]|0)+t+(f+13924)|0]<<1)>>1]|0,0,w,k)|0;Fa=G;Ga=Oa|0;Da=xrc(c[Ga>>2]|0,c[Ga+4>>2]|0,Ea>>>4|Fa<<28,Fa>>>4|0<<28)|0;c[Ga>>2]=Da;c[Ga+4>>2]=G;Ga=Oa+24|0;c[u+(J<<2)>>2]=c[Ga>>2];c[Ga>>2]=J;Ga=J+1|0;Da=Oa+40|0;c[u+(Ga<<2)>>2]=c[Da>>2];c[Da>>2]=Ga;Ga=J+2|0;Da=Oa+56|0;c[u+(Ga<<2)>>2]=c[Da>>2];c[Da>>2]=Ga;Ua=J+3|0;Va=Oa;Wa=Na}else{Ga=d[15776+(h<<6)+Ma|0]|0;Da=b[s+(Ga<<1)>>1]|0;Fa=Da<<16>>16;Ea=K<<16>>16;ba=Na|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=Na+16|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=Na+32|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=Na+48|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=Na+64|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=Na+80|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=Na+96|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=Na+112|0;c[ba>>2]=-1;c[ba+4>>2]=-1;ba=Da<<16>>16>-1?Fa:-Fa|0;Xa=K<<16>>16>-1?Ea:-Ea|0;if((Ma|0)<63){Ea=d[97128+Ma|0]|0;K=d[(d[18736+(h<<6)+Ma|0]|0)+t+(f+13924)|0]|0;Da=b[101200+(K<<1)>>1]|0;c[q>>2]=Da&65535;ra=e[101200+((K^1)<<1)>>1]|0;K=d[Ea+Qa+(f+13924)|0]|0;c[Ha>>2]=(e[101200+(K<<1)>>1]|0)+ra;c[Ja>>2]=(e[101200+((K^1)<<1)>>1]|0)+ra;Ya=0;Za=Da&65535}else{c[Ja>>2]=0;c[Ha>>2]=0;c[q>>2]=0;Ya=0;Za=0}_a=Xa-1|0;Da=c[Ia>>2]|0;ra=(Ma|0)==0;K=(Da|0)==0|ra|Pa;Ea=Fa>>31;Ca=Fa>>>31|8;sa=c[N+(j<<8)+(Ga<<2)>>2]|0;I=98424+(Ga<<2)|0;L=f+23280+(M<<7)+(Ga<<1)|0;V=98168+(Ga<<2)|0;Ga=(ca(sa,_a)|0)+128>>8;H=ba-Ga|0;if(K){E=H;D=(H|0)<0|0?-1:0;C=Erc(E,D,E,D)|0;D=c[I>>2]|0;E=Erc(C,G,D,0)|0;$a=D;ab=G;bb=E}else{E=((b[L>>1]|0)-Fa^Ea)-Ea+Ga|0;D=ca(c[V>>2]|0,Da)|0;C=H;X=(H|0)<0|0?-1:0;H=Erc(C,X,C,X)|0;X=c[I>>2]|0;I=Erc(H,G,X,0)|0;H=ca(D,(E|0)>-1?E:-E|0)|0;E=xrc(I,G,H,(H|0)<0|0?-1:0)|0;$a=X;ab=G;bb=E}c[Ka>>2]=bb;c[Ka+4>>2]=ab;if(ra){E=Fa-((Ga^Ea)+Ca&-16)|0;Ga=E;X=(E|0)<0|0?-1:0;E=Erc(Ga,X,Ga,X)|0;X=Erc(E,G,$a,0)|0;cb=G;db=X}else{cb=ab;db=bb}c[r>>2]=db;c[r+4>>2]=cb;X=(ca(sa,Xa)|0)+128>>8;sa=ba-X|0;if(K){K=sa;ba=(sa|0)<0|0?-1:0;E=Erc(K,ba,K,ba)|0;ba=Erc(E,G,$a,0)|0;eb=G;fb=ba}else{ba=((b[L>>1]|0)-Fa^Ea)-Ea+X|0;L=ca(c[V>>2]|0,Da)|0;Da=sa;V=(sa|0)<0|0?-1:0;sa=Erc(Da,V,Da,V)|0;V=Erc(sa,G,$a,0)|0;sa=ca(L,(ba|0)>-1?ba:-ba|0)|0;ba=xrc(V,G,sa,(sa|0)<0|0?-1:0)|0;eb=G;fb=ba}c[La>>2]=fb;c[La+4>>2]=eb;if(ra){ra=Fa-((X^Ea)+Ca&-16)|0;Ca=ra;Ea=(ra|0)<0|0?-1:0;ra=Erc(Ca,Ea,Ca,Ea)|0;Ea=Erc(ra,G,$a,0)|0;gb=G;hb=Ea}else{gb=eb;hb=fb}c[p>>2]=hb;c[p+4>>2]=gb;if((Xa|0)==2){_=21;break}else if((Xa|0)!=1){_=24;break}Ea=Erc(Za,Ya,w,k)|0;ra=G;Ca=wrc(bb,ab,Ea>>>4|ra<<28,ra>>>4|0<<28)|0;ra=G;c[Ka>>2]=Ca;c[Ka+4>>2]=ra;Ea=xrc(db,cb,Ca,ra)|0;ra=NUb(Ea,G,Na,Oa,m,J)|0;Ea=c[Ka>>2]|0;Ca=c[Ka+4>>2]|0;X=xrc(c[p>>2]|0,c[p+4>>2]|0,Ea,Ca)|0;Fa=G;ba=xrc(c[La>>2]|0,c[La+4>>2]|0,Ea,Ca)|0;Ua=OUb(X,Fa,ba,G,q,Na,Oa,m,ra,F,l)|0;Va=Na;Wa=Oa}ra=Ma-1|0;if((ra|0)<0){Ta=Va;_=8;break c}else{Ma=ra;Na=Wa;Oa=Va;J=Ua}}if((_|0)==21){Ka=OUb(db,cb,bb,ab,q,Na,Oa,m,J,F,l)|0;ib=PUb(2,c[p>>2]|0,c[p+4>>2]|0,c[La>>2]|0,c[La+4>>2]|0,q,Na,Oa,m,Ka,F,l)|0}else if((_|0)==24){Ka=PUb(_a,db,cb,bb,ab,q,Na,Oa,m,J,F,l)|0;ib=PUb(Xa,c[p>>2]|0,c[p+4>>2]|0,c[La>>2]|0,c[La+4>>2]|0,q,Na,Oa,m,Ka,F,l)|0}Ka=Ma-1|0;d:do{if((Ka|0)<0){jb=Na}else{r=A|0;Ha=A+4|0;Ja=Oa;T=Na;ra=ib;ba=Ka;while(1){Fa=T+24|0;X=T+40|0;Ca=T+56|0;Ea=T+72|0;sa=T+88|0;V=T+104|0;L=T+120|0;Da=ra;E=ba;while(1){kb=b[Z+(E<<1)>>1]|0;if(!(kb<<16>>16==0)){break}c[u+(Da<<2)>>2]=c[Fa>>2];c[Fa>>2]=Da;K=Da+1|0;c[u+(K<<2)>>2]=c[X>>2];c[X>>2]=K;K=Da+2|0;c[u+(K<<2)>>2]=c[Ca>>2];c[Ca>>2]=K;K=Da+3|0;c[u+(K<<2)>>2]=c[Ea>>2];c[Ea>>2]=K;K=Da+4|0;c[u+(K<<2)>>2]=c[sa>>2];c[sa>>2]=K;K=Da+5|0;c[u+(K<<2)>>2]=c[V>>2];c[V>>2]=K;K=Da+6|0;c[u+(K<<2)>>2]=c[L>>2];c[L>>2]=K;K=E-1|0;if((K|0)<0){jb=T;break d}else{Da=Da+7|0;E=K}}L=d[15776+(h<<6)+E|0]|0;V=b[s+(L<<1)>>1]|0;sa=V<<16>>16;Ea=kb<<16>>16;Ca=Ja+16|0;c[Ca>>2]=-1;c[Ca+4>>2]=-1;Ca=Ja+32|0;c[Ca>>2]=-1;c[Ca+4>>2]=-1;Ca=Ja+48|0;c[Ca>>2]=-1;c[Ca+4>>2]=-1;Ca=Ja+64|0;c[Ca>>2]=-1;c[Ca+4>>2]=-1;Ca=Ja+80|0;c[Ca>>2]=-1;c[Ca+4>>2]=-1;Ca=Ja+96|0;c[Ca>>2]=-1;c[Ca+4>>2]=-1;Ca=Ja+112|0;c[Ca>>2]=-1;c[Ca+4>>2]=-1;Ca=V<<16>>16>-1?sa:-sa|0;V=kb<<16>>16>-1?Ea:-Ea|0;Ea=d[97128+E|0]|0;X=d[(d[18736+(h<<6)+E|0]|0)+t+(f+13924)|0]|0;Fa=b[101200+(X<<1)>>1]|0;c[r>>2]=Fa&65535;c[Ha>>2]=(e[101200+(d[Ea+Qa+(f+13924)|0]<<1)>>1]|0)+(e[101200+((X^1)<<1)>>1]|0);X=V-1|0;Ea=c[Ia>>2]|0;K=sa>>31;Ga=c[N+(j<<8)+(L<<2)>>2]|0;H=(ca(Ga,X)|0)+128>>8;I=Ca-H|0;if((Ea|0)==0|(E|0)==0|Pa){D=I;C=(I|0)<0|0?-1:0;Q=Erc(D,C,D,C)|0;C=c[98424+(L<<2)>>2]|0;D=Erc(Q,G,C,0)|0;Q=G;W=Ca-((ca(Ga,V)|0)+128>>8)|0;U=W;Y=(W|0)<0|0?-1:0;W=Erc(U,Y,U,Y)|0;Y=Erc(W,G,C,0)|0;lb=G;mb=Y;nb=Q;ob=D}else{D=((b[f+23280+(M<<7)+(L<<1)>>1]|0)-sa^K)-K+H|0;H=ca(c[98168+(L<<2)>>2]|0,Ea)|0;Q=I;Y=(I|0)<0|0?-1:0;I=Erc(Q,Y,Q,Y)|0;Y=c[98424+(L<<2)>>2]|0;Q=Erc(I,G,Y,0)|0;I=ca(H,(D|0)>-1?D:-D|0)|0;D=xrc(Q,G,I,(I|0)<0|0?-1:0)|0;I=G;Q=(ca(Ga,V)|0)+128>>8;Ga=Ca-Q|0;Ca=((b[f+23280+(M<<7)+(L<<1)>>1]|0)-sa^K)-K+Q|0;Q=ca(c[98168+(L<<2)>>2]|0,Ea)|0;Ea=Ga;L=(Ga|0)<0|0?-1:0;Ga=Erc(Ea,L,Ea,L)|0;L=Erc(Ga,G,Y,0)|0;Y=ca(Q,(Ca|0)>-1?Ca:-Ca|0)|0;Ca=xrc(L,G,Y,(Y|0)<0|0?-1:0)|0;lb=G;mb=Ca;nb=I;ob=D}if((V|0)==1){D=Erc(Fa&65535,0,w,k)|0;Fa=G;I=QUb(Ja,T,m,Da)|0;Ca=wrc(ob,nb,D>>>4|Fa<<28,Fa>>>4|0<<28)|0;Fa=xrc(mb,lb,Ca,G)|0;pb=RUb(Fa,G,r,Ja,T,m,I,F,l)|0}else if((V|0)==2){pb=SUb(2,mb,lb,r,Ja,T,m,RUb(ob,nb,r,Ja,T,m,Da,F,l)|0,F,l,9)|0}else{pb=SUb(V,mb,lb,r,Ja,T,m,SUb(X,ob,nb,r,Ja,T,m,Da,F,l,9)|0,F,l,9)|0}X=E-1|0;if((X|0)<0){jb=Ja;break}else{V=Ja;Ja=T;ra=pb;ba=X;T=V}}}}while(0);k=jb+16|0;w=jb+32|0;Ia=w|0;Ka=c[Ia+4>>2]|0;Na=k|0;Oa=c[Na+4>>2]|0;Ma=Ka>>>0<Oa>>>0|Ka>>>0==Oa>>>0&(c[Ia>>2]|0)>>>0<(c[Na>>2]|0)>>>0?w:k;k=jb+48|0;w=k|0;Na=c[w+4>>2]|0;Ia=Ma|0;Oa=c[Ia+4>>2]|0;Ka=Na>>>0<Oa>>>0|Na>>>0==Oa>>>0&(c[w>>2]|0)>>>0<(c[Ia>>2]|0)>>>0?k:Ma;Ma=jb+64|0;k=Ma|0;Ia=c[k+4>>2]|0;w=Ka|0;Oa=c[w+4>>2]|0;Na=Ia>>>0<Oa>>>0|Ia>>>0==Oa>>>0&(c[k>>2]|0)>>>0<(c[w>>2]|0)>>>0?Ma:Ka;Ka=jb+80|0;Ma=Ka|0;w=c[Ma+4>>2]|0;k=Na|0;Oa=c[k+4>>2]|0;Ia=w>>>0<Oa>>>0|w>>>0==Oa>>>0&(c[Ma>>2]|0)>>>0<(c[k>>2]|0)>>>0?Ka:Na;Na=jb+96|0;Ka=Na|0;k=c[Ka+4>>2]|0;Ma=Ia|0;Oa=c[Ma+4>>2]|0;w=k>>>0<Oa>>>0|k>>>0==Oa>>>0&(c[Ka>>2]|0)>>>0<(c[Ma>>2]|0)>>>0?Na:Ia;Ia=jb+112|0;Na=Ia|0;Ma=c[Na+4>>2]|0;Ka=w|0;Oa=c[Ka+4>>2]|0;qb=Ma>>>0<Oa>>>0|Ma>>>0==Oa>>>0&(c[Na>>2]|0)>>>0<(c[Ka>>2]|0)>>>0?Ia:w}}while(0);do{if((_|0)==8){jb=Ta+16|0;pb=jb|0;l=c[pb+4>>2]|0;F=Ta|0;m=c[F+4>>2]|0;nb=l>>>0<m>>>0|l>>>0==m>>>0&(c[pb>>2]|0)>>>0<(c[F>>2]|0)>>>0?jb:Ta;jb=Ta+32|0;F=jb|0;pb=c[F+4>>2]|0;m=nb|0;l=c[m+4>>2]|0;ob=pb>>>0<l>>>0|pb>>>0==l>>>0&(c[F>>2]|0)>>>0<(c[m>>2]|0)>>>0?jb:nb;nb=Ta+48|0;jb=nb|0;m=c[jb+4>>2]|0;F=ob|0;l=c[F+4>>2]|0;pb=m>>>0<l>>>0|m>>>0==l>>>0&(c[jb>>2]|0)>>>0<(c[F>>2]|0)>>>0?nb:ob;if((pb|0)==(Ta|0)){Sa=0}else{qb=pb;break}i=o;return Sa|0}}while(0);if(n){Sa=1;i=o;return Sa|0}n=0;Ta=c[qb+8>>2]|0;while(1){qb=g+(d[15776+(h<<6)+n|0]<<1)|0;_=b[qb>>1]>>31;b[qb>>1]=(_^e[u+(Ta<<2)+2>>1])-_;_=n+1|0;if((_|0)>(B|0)){Sa=1;break}else{n=_;Ta=e[u+(Ta<<2)>>1]|0}}i=o;return Sa|0}function aUb(a){a=a|0;var b=0,c=0,d=0;a=MLb(65540)|0;b=a;if((a|0)==0){c=0;return c|0}g[b>>2]=.7179999947547913;a=1;while(1){d=a+1|0;g[b+(a<<2)>>2]=+lc(+(+(d|0)))*2.0+1.718000054359436;if((d|0)<16385){a=d}else{c=b;break}}return c|0}function bUb(a,e,f){a=a|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0;h=b[97256+(f<<1)>>1]|0;i=h&65535;j=a+1816+(f<<2)|0;if((c[j>>2]|0)!=0){k=0;return k|0}l=MLb(65538)|0;c[j>>2]=l;if((l|0)==0){k=-1;return k|0}m=l+32768|0;c[j>>2]=m;n=+(i|0);l=0;while(1){o=n*+g[e+(l<<2)>>2]+.5;if(o<65535.0){p=~~o}else{p=-1}b[m+(l<<1)>>1]=p;b[m+(-l<<1)>>1]=p;q=l+1|0;if((q|0)<16385){l=q}else{r=0;break}}while(1){b[3038792+(f*198|0)+(r<<1)>>1]=0;l=r+1|0;if((l|0)<33){r=l}else{s=0;break}}while(1){b[3038858+(f*198|0)+(s<<1)>>1]=h;r=s+1|0;if((r|0)<33){s=r}else{t=0;break}}do{s=t+1|0;r=(ca(d[16464+s|0]|0,i)|0)>>>0>65534>>>0;if(r){u=r<<31>>31}else{u=ca(d[16464+s|0]|0,h)|0}b[3038924+(f*198|0)+(t<<1)>>1]=u;t=t+1|0;}while((t|0)<33);do{if((c[a+544>>2]|0)>2){t=a+2096+(f<<4)|0;if((c[t>>2]|0)!=0){break}u=MLb(16386)|0;c[t>>2]=u;if((u|0)==0){k=-1;return k|0}i=u+8192|0;c[t>>2]=i;t=c[j>>2]|0;u=-4096;do{b[i+(u<<1)>>1]=b[t+(u<<2<<1)>>1]|0;u=u+1|0;}while((u|0)<4096);u=MLb(16386)|0;t=a+2096+(f<<4)+4|0;c[t>>2]=u;if((u|0)==0){k=-1;return k|0}i=u+8192|0;c[t>>2]=i;t=c[j>>2]|0;u=-4096;do{b[i+(u<<1)>>1]=b[t+((u<<2|1)<<1)>>1]|0;u=u+1|0;}while((u|0)<4096);u=MLb(16386)|0;t=a+2096+(f<<4)+8|0;c[t>>2]=u;if((u|0)==0){k=-1;return k|0}i=u+8192|0;c[t>>2]=i;t=c[j>>2]|0;u=-4096;do{b[i+(u<<1)>>1]=b[t+((u<<2|2)<<1)>>1]|0;u=u+1|0;}while((u|0)<4096);u=MLb(16386)|0;t=a+2096+(f<<4)+12|0;c[t>>2]=u;if((u|0)==0){k=-1;return k|0}i=u+8192|0;c[t>>2]=i;t=c[j>>2]|0;u=-4096;do{b[i+(u<<1)>>1]=b[t+((u<<2|3)<<1)>>1]|0;u=u+1|0;}while((u|0)<4096)}}while(0);j=f<<5;f=h*3&65535;h=0;while(1){b[(3052719&-64)+(h+j<<1)>>1]=f&(-((h|0)!=8|0)&65535);a=h+1|0;if((a|0)<17){h=a}else{k=0;break}}return k|0}function cUb(a){a=a|0;var b=0,d=0;b=0;do{d=c[a+1816+(b<<2)>>2]|0;if((d|0)!=0){NLb(d-32768|0)}d=c[a+2096+(b<<4)>>2]|0;if((d|0)!=0){NLb(d-8192|0);NLb((c[a+2096+(b<<4)+4>>2]|0)-8192|0);NLb((c[a+2096+(b<<4)+8>>2]|0)-8192|0);NLb((c[a+2096+(b<<4)+12>>2]|0)-8192|0)}b=b+1|0;}while((b|0)<70);return}function dUb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a+15152|0;e=c[d>>2]|0;f=0;while(1){if((f|0)>=(e|0)){g=11;break}h=c[a+3584+(f*144|0)+44>>2]|0;if((h|0)==0){f=f+1|0}else{break}}if((g|0)==11){return}g=c[a+15160+(f<<2)>>2]|0;e=(c[g+168>>2]|0)+64|0;i=32<<c[a+160>>2];j=c[g+228>>2]|0;k=g+156|0;l=c[k>>2]|0;m=-32-(ca(l,i)|0)|0;n=b+16+i|0;b=(c[g+180>>2]|0)+(i<<1)|0;g=(n|0)<(b|0)?n:b;b=a+15144|0;n=(c[b>>2]|0)+11956|0;o=c[n>>2]|0;p=g-o|0;q=ca(o,l)|0;c[n>>2]=g;if((g|0)==(o|0)){return}o=c[d>>2]|0;if((f|0)>=(o|0)){return}g=q-32|0;n=j+(m+q)|0;q=f;f=o;o=h;while(1){if((o|0)==0){r=f}else{h=c[b>>2]|0;m=(c[h+2704+(q<<2)>>2]|0)+(g-(ca(c[h+156>>2]|0,i)|0))|0;h=c[k>>2]|0;POb(a,m,h,n,h,e,p,a+3584+(q*144|0)|0);r=c[d>>2]|0}h=q+1|0;if((h|0)>=(r|0)){break}q=h;f=r;o=c[a+3584+(h*144|0)+44>>2]|0}return}function eUb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,qe=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ff=0,gf=0,jf=0,kf=0,lf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0;g=i;i=i+17208|0;h=g|0;j=g+256|0;k=g+264|0;l=g+392|0;m=g+400|0;n=g+408|0;o=g+416|0;p=g+544|0;q=g+552|0;r=g+680|0;s=g+1736|0;t=g+2280|0;u=g+2568|0;v=g+2856|0;w=g+2864|0;x=g+2872|0;z=g+2880|0;A=g+2920|0;B=g+2928|0;C=g+2936|0;D=g+3064|0;E=g+3320|0;F=g+3832|0;H=g+3960|0;I=g+4088|0;J=g+4104|0;K=g+4112|0;L=g+4240|0;M=g+4368|0;N=g+4376|0;O=g+4408|0;P=g+4416|0;Q=g+17184|0;R=g+17192|0;S=g+17200|0;T=MMb(f)|0;U=f+28816|0;c[U>>2]=T;do{if((c[f+684>>2]|0)==0){V=T}else{if((c[f+560>>2]|0)>=10){V=T;break}W=f+28824|0;X=T-(c[W>>2]|0)|0;Y=c[((((X|0)>-1?X:-X|0)|0)==1?W:U)>>2]|0;c[U>>2]=Y;V=Y}}while(0);if((c[f+600>>2]|0)==0){Z=V}else{a[(c[(c[f+15148>>2]|0)+2936>>2]|0)+(c[f+18616>>2]|0)|0]=V;Z=c[U>>2]|0}V=f+560|0;T=c[V>>2]|0;Y=f+3240|0;W=T-((c[Y>>2]|0)==1)|0;X=P+24|0;c[X>>2]=((W|0)>7)+((T|0)>9)+((W|0)>5);if((T|0)>8){_=(c[f+8348>>2]|0)!=1|0}else{_=0}c[f+19392>>2]=_;_=P+12756|0;c[_>>2]=(T|0)<11;iUb(f,P,Z);Z=f+19356|0;c[Z>>2]=0;T=P+312|0;c[T>>2]=268435456;W=P+240|0;c[W>>2]=268435456;$=P+80|0;c[$>>2]=268435456;aa=P+44|0;c[aa>>2]=268435456;ba=f+18572|0;da=f+18576|0;ea=(2048>>>(((c[da>>2]|0)+(c[ba>>2]|0)|0)>>>0)<<1)+2064|0;fa=P+4|0;ga=c[fa>>2]|0;ha=Erc(ea,(ea|0)<0|0?-1:0,ga,(ga|0)<0|0?-1:0)|0;ga=wrc(ha,G,128,0)|0;ha=G;ea=ga>>>8|ha<<24;do{if((c[f+136>>2]|0)==0){if((c[f+18652>>2]|0)!=0){ia=268435456;break}if((c[X>>2]|0)==0){ia=268435456;break}ja=16;ia=ha>>>0<ja>>>0|ha>>>0==ja>>>0&ga>>>0<0>>>0?ea:268435456}else{ia=268435456}}while(0);ea=P+308|0;c[ea>>2]=ia;ia=P+28|0;c[ia>>2]=0;ga=P+36|0;c[ga>>2]=0;ha=f+28836|0;do{if((c[ha>>2]|0)==0){if((c[X>>2]|0)!=0){ka=2;break}if((c[f+572>>2]|0)!=0){ka=0;break}ka=(c[f+584>>2]|0)==0|0}else{ka=0}}while(0);ja=f+19376|0;c[ja>>2]=ka;ka=c[Y>>2]|0;a:do{if((ka|0)==2){la=80}else{ma=c[f+552>>2]<<2;na=f+18608|0;oa=c[na>>2]|0;pa=(oa*-64|0)-96|0;c[f+18668>>2]=pa;qa=(c[f+18560>>2]|0)-oa<<6|32;c[f+18676>>2]=qa;ra=-ma|0;sa=ma-1|0;if((pa|0)<(ra|0)){ta=ra}else{ta=(pa|0)>(sa|0)?sa:pa}c[f+18708>>2]=ta;if((qa|0)<(ra|0)){ua=ra}else{ua=(qa|0)>(sa|0)?sa:qa}qa=f+18716|0;c[qa>>2]=ua;pa=f+108|0;do{if((c[pa>>2]|0)!=0&(ka|0)==0){va=-12-(oa<<6)+(c[(c[f+15160>>2]|0)+11984>>2]<<6)|0;if((va|0)<=0){wa=ua;xa=0;break}if((oa|0)>=(c[(c[f+15148>>2]|0)+11980>>2]|0)){wa=ua;xa=0;break}ya=(ua|0)<(va|0)?ua:va;c[qa>>2]=ya;wa=ya;xa=0}else{wa=ua;xa=ka}}while(0);b[f+18752>>1]=(ta>>>2)+6;b[f+18756>>1]=(wa>>>2)+65530;do{if((oa|0)==0){qa=f+18612|0;ya=c[qa>>2]|0;va=f+160|0;za=c[va>>2]|0;if((za&ya|0)!=0){Aa=za;la=47;break}Ba=ya>>c[f+3260>>2];if((c[f+1548>>2]|0)>1){Ca=(za|ya)<<4;ya=f+556|0;Da=(c[ya>>2]|0)+Ca|0;Ea=(xa|0)==1|0;Fa=ma;while(1){Ga=f+15152+(Ea<<2)|0;if((c[Ga>>2]|0)>0){Ha=0;Ia=Fa;while(1){Ja=f+15160+(Ea*76|0)+(Ha<<2)|0;DOb(c[(c[Ja>>2]|0)+2772>>2]|0,Da);Ka=(c[(c[(c[Ja>>2]|0)+2772>>2]|0)+11952>>2]|0)-Ca|0;Ja=(Ia|0)<(Ka|0)?Ia:Ka;Ka=Ha+1|0;if((Ka|0)<(c[Ga>>2]|0)){Ha=Ka;Ia=Ja}else{La=Ja;break}}}else{La=Fa}if((Ea|0)>0){Ea=Ea-1|0;Fa=La}else{break}}if((c[f+16>>2]|0)==0){Ma=La}else{Ma=c[ya>>2]|0}Fa=Ma>>((c[va>>2]|0)!=0);dUb(f,Fa+Ca|0);Na=Fa;Oa=c[va>>2]|0}else{Na=ma;Oa=za}if((Oa|0)==0){Fa=(Ba*-64|0)-96|0;c[f+18672>>2]=Fa;Ea=(c[f+18564>>2]|0)-Ba<<6|32;c[f+18680>>2]=Ea;if((Fa|0)<(ra|0)){Pa=ra}else{Pa=(Fa|0)>(ma|0)?ma:Fa}c[f+18712>>2]=Pa;if((Ea|0)<(ra|0)){Qa=ra}else{Qa=(Ea|0)>(sa|0)?sa:Ea}Ea=Na<<2;Fa=(Qa|0)<(Ea|0)?Qa:Ea;c[f+18720>>2]=Fa;b[f+18754>>1]=(Pa>>>2)+6;b[f+18758>>1]=(Fa>>>2)+65530;break}Fa=Na<<2;Ea=c[qa>>2]|0;Da=(Ea*-64|0)-96|0;c[f+18684>>2]=Da;Ia=c[f+18564>>2]|0;Ha=Ia-Ea<<6|32;c[f+18696>>2]=Ha;if((Da|0)<(ra|0)){Ra=ra}else{Ra=(Da|0)>(ma|0)?ma:Da}c[f+18724>>2]=Ra;if((Ha|0)<(ra|0)){Sa=ra}else{Sa=(Ha|0)>(sa|0)?sa:Ha}Ha=(Sa|0)<(Fa|0)?Sa:Fa;c[f+18736>>2]=Ha;c[f+18760>>2]=(Ra>>2)+6;c[f+18772>>2]=(Ha>>2)-6;Ha=Ea+1|0;Da=(Ha*-64|0)-96|0;c[f+18688>>2]=Da;Ga=Ia-Ha<<6|32;c[f+18700>>2]=Ga;if((Da|0)<(ra|0)){Ta=ra}else{Ta=(Da|0)>(ma|0)?ma:Da}c[f+18728>>2]=Ta;if((Ga|0)<(ra|0)){Ua=ra}else{Ua=(Ga|0)>(sa|0)?sa:Ga}Ga=(Ua|0)<(Fa|0)?Ua:Fa;c[f+18740>>2]=Ga;c[f+18764>>2]=(Ta>>2)+6;c[f+18776>>2]=(Ga>>2)-6;Ga=Ea>>1;Ea=(Ga*-64|0)-96|0;c[f+18692>>2]=Ea;Da=(Ia>>>1)-Ga<<6|32;c[f+18704>>2]=Da;if((Ea|0)<(ra|0)){Va=ra}else{Va=(Ea|0)>(ma|0)?ma:Ea}c[f+18732>>2]=Va;if((Da|0)<(ra|0)){Wa=ra}else{Wa=(Da|0)>(sa|0)?sa:Da}Da=(Wa|0)<(Fa|0)?Wa:Fa;c[f+18744>>2]=Da;c[f+18768>>2]=(Va>>2)+6;c[f+18780>>2]=(Da>>2)-6;Aa=Oa;la=47}else{Aa=c[f+160>>2]|0;la=47}}while(0);do{if((la|0)==47){if((Aa|0)==0){break}if((c[f+18660>>2]|0)==0){Xa=c[f+18612>>2]&1}else{Xa=2}c[f+18672>>2]=c[f+18684+(Xa<<2)>>2];c[f+18680>>2]=c[f+18696+(Xa<<2)>>2];c[f+18712>>2]=c[f+18724+(Xa<<2)>>2];c[f+18720>>2]=c[f+18736+(Xa<<2)>>2];b[f+18754>>1]=c[f+18760+(Xa<<2)>>2];b[f+18758>>1]=c[f+18772+(Xa<<2)>>2]}}while(0);sa=P+6208|0;c[sa>>2]=268435456;ra=P+5936|0;c[ra>>2]=268435456;ma=P+624|0;c[ma>>2]=268435456;oa=P+352|0;c[oa>>2]=268435456;Da=P+476|0;c[Da>>2]=268435456;Fa=c[Y>>2]|0;do{if((Fa|0)==1){c[P+12704>>2]=268435456;c[P+12700>>2]=268435456;c[P+12616>>2]=268435456;c[P+12612>>2]=268435456;c[P+12608>>2]=268435456;c[P+12720>>2]=268435456;c[P+12716>>2]=268435456;c[P+12724>>2]=268435456;c[P+12712>>2]=268435456;c[P+12708>>2]=268435456;c[P+12336>>2]=268435456;c[P+12064>>2]=268435456;c[P+12632>>2]=268435456;c[P+12628>>2]=268435456;c[P+12624>>2]=268435456;c[P+12620>>2]=268435456;c[P+6752>>2]=268435456;c[P+6480>>2]=268435456;c[P+6604>>2]=268435456}else{if((c[f+520>>2]&32|0)==0){break}c[P+4896>>2]=268435456;c[P+3856>>2]=268435456;c[P+1792>>2]=268435456;c[P+4900>>2]=268435456;c[P+3860>>2]=268435456;c[P+1796>>2]=268435456;c[P+4904>>2]=268435456;c[P+3864>>2]=268435456;c[P+1800>>2]=268435456;c[P+4908>>2]=268435456;c[P+3868>>2]=268435456;c[P+1804>>2]=268435456}}while(0);do{if((c[_>>2]|0)==0){Ya=Fa}else{Ea=c[f+18616>>2]|0;Ga=Ea-(c[f+3244>>2]|0)|0;if((Ga|0)<=4){Ya=Fa;break}if((c[f+18632>>2]|0)>2){if((c[f+18880>>2]|0)>>>0<4>>>0){Ya=Fa;break}if((c[f+18876>>2]|0)>>>0<4>>>0){Ya=Fa;break}if((c[f+18888>>2]|0)>>>0<4>>>0){Ya=Fa;break}if((c[f+18892>>2]|0)>>>0<4>>>0){Ya=Fa;break}if((Fa|0)==0){if((d[(c[(c[f+15160>>2]|0)+2776>>2]|0)+Ea|0]|0)>>>0<4>>>0){Ya=0;break}}if((Ga|0)<(((c[f+30520>>2]|0)+(c[f+30516>>2]|0)+(c[f+30524>>2]|0)|0)*3|0|0)){Ya=Fa;break}}c[ia>>2]=1;Ya=Fa}}while(0);Fa=f+19380|0;c[Fa>>2]=0;b:do{if((c[pa>>2]|0)!=0&(Ya|0)==0){Ga=c[na>>2]|0;Ea=c[f+15148>>2]|0;do{if((Ga|0)>=(c[Ea+11980>>2]|0)){Ia=Ea+11984|0;if((Ga|0)>(c[Ia>>2]|0)){break}c[P+32>>2]=1;c[ia>>2]=0;c[ga>>2]=(Ga|0)==(c[Ia>>2]|0);break b}}while(0);c[P+32>>2]=0}else{c[P+32>>2]=0;if((Ya|0)==2){la=80;break a}else if((Ya|0)==0){break}else if((Ya|0)!=1){break a}Ga=c[X>>2]|0;do{if((Ga|0)!=0){Ea=(Ga|0)>1;c:do{if((c[f+572>>2]|0)==2){if((c[f+18656>>2]|0)==0){break}do{if((c[f+524>>2]|0)==0){if((c[Z>>2]|0)==0){Za=f+24544|0;break}else{qa=f+24544|0;ef[c[f+37620>>2]&4095](f+23280|0,c[qa>>2]|0,3034536);if((c[Z>>2]|0)==0){Za=qa;break}else{break c}}}else{qa=f+24544|0;ef[c[f+37620>>2]&4095](f+23280|0,c[qa>>2]|0,3034536);Za=qa}}while(0);ef[c[f+37600>>2]&4095](f+23792|0,c[Za>>2]|0,3034536)}}while(0);if((c[f+18652>>2]|0)==0){break}qa=f+37524|0;re[c[qa>>2]&1023](f+24320|0,72);if(!Ea){break}re[c[qa>>2]&1023](f+24416|0,128)}}while(0);Ga=f+19344|0;c[Ga>>2]=18;qa=f+28844|0;do{if((c[qa>>2]|0)==0){Ba=gQb(f,0)|0;c[P+12752>>2]=Ba;_a=0;$a=Ba;la=411}else{Ba=f+3296|0;za=P+12752|0;c[Q>>2]=1;c[Ba>>2]=c[Ba>>2]^1;va=gQb(f,0)|0;c[za>>2]=va;if((va|0)==0){ab=0}else{if((c[Q>>2]|0)==0){bb=0}else{YOb(f);bb=vMb(f,1)|0}va=f+31180+(c[Ba>>2]<<2)|0;c[va>>2]=(c[va>>2]|0)+bb;ab=bb}c[Q>>2]=1;c[Ba>>2]=c[Ba>>2]^1;va=gQb(f,(c[za>>2]|0)==0?0:Q)|0;c[za>>2]=va;if((va|0)==0){Ca=P+40|0;c[Ca>>2]=0;cb=268435456;db=Ca;eb=P+12752|0;break}if((c[Q>>2]|0)==0){fb=ab;gb=va}else{YOb(f);va=vMb(f,1)|0;fb=va;gb=c[za>>2]|0}za=f+31180+(c[Ba>>2]<<2)|0;c[za>>2]=(c[za>>2]|0)+fb;_a=fb;$a=gb;la=411}}while(0);d:do{if((la|0)==411){za=P+40|0;c[za>>2]=0;Ba=P+12752|0;do{if(($a|0)==0){hb=_a;ib=268435456}else{if((c[qa>>2]|0)==0){YOb(f)}if((c[f+18660>>2]|0)==0){if((c[f+18612>>2]<<4|0)<(c[f+32>>2]|0)){la=416}else{jb=268435456;kb=1}}else{la=416}if((la|0)==416){do{if((c[X>>2]|0)==0){if((c[qa>>2]|0)!=0){lb=_a;mb=268435456;break}va=vMb(f,1)|0;c[za>>2]=va;lb=(c[V>>2]|0)<3?va:_a;mb=268435456}else{va=mUb(f)|0;Ca=(va|0)<=(((c[fa>>2]|0)*6|0)+128>>8|0)|0;c[Fa>>2]=Ca;lb=Ca;mb=va}}while(0);if((lb|0)==0){cb=mb;db=za;eb=Ba;break d}else{jb=mb;kb=lb}}va=f+24580|0;if((c[va>>2]|0)>0){Ca=f+18616|0;ya=0;do{c[(c[f+19008+(ya<<2)>>2]|0)+(c[Ca>>2]<<2)>>2]=0;ya=ya+1|0;}while((ya|0)<(c[va>>2]|0))}va=f+24584|0;if((c[va>>2]|0)<=0){hb=kb;ib=jb;break}ya=f+18616|0;Ca=0;while(1){c[(c[f+19136+(Ca<<2)>>2]|0)+(c[ya>>2]<<2)>>2]=0;Ia=Ca+1|0;if((Ia|0)<(c[va>>2]|0)){Ca=Ia}else{hb=kb;ib=jb;break}}}}while(0);if((hb|0)==0){cb=ib;db=za;eb=Ba}else{break a}}}while(0);qa=c[f+520>>2]|0;c[Fa>>2]=0;c[Ga>>2]=7;Ea=c[P+8>>2]|0;Ca=P+12|0;c[Ca>>2]=c[f+1816+(Ea<<2)>>2];va=(c[f+3304>>2]|0)-1|0;if((va|0)<0){nb=0}else{nb=(va|0)>2?2:va}va=P+16|0;c[va>>2]=3038792+(Ea*198|0)+(nb*66|0);ya=(c[f+3308>>2]|0)-1|0;if((ya|0)<0){ob=0}else{ob=(ya|0)>2?2:ya}ya=P+20|0;c[ya>>2]=3038792+(Ea*198|0)+(ob*66|0);do{if((c[eb>>2]|0)!=0){Ea=c[f+24544>>2]|0;Ia=c[f+24568>>2]|0;Ha=P|0;Ja=P+12612|0;c[Ja>>2]=c[Ha>>2];if((qa&256|0)==0){Ka=hf[c[f+36884>>2]&1023](Ea,16,Ia,32)|0;c[Ja>>2]=(c[Ja>>2]|0)+Ka;if((c[f+18636>>2]|0)==0){break}Ka=f+36884+(d[f+36448|0]<<2)|0;pb=hf[c[Ka>>2]&1023](c[f+24548>>2]|0,16,c[f+24572>>2]|0,32)|0;qb=(hf[c[Ka>>2]&1023](c[f+24552>>2]|0,16,c[f+24576>>2]|0,32)|0)+pb|0;c[Ja>>2]=qb+(c[Ja>>2]|0);break}qb=f+36896|0;pb=f+18636|0;Ka=f+36884+(d[f+36451|0]<<2)|0;rb=f+24548|0;sb=f+24572|0;tb=f+24552|0;ub=f+24576|0;vb=0;do{wb=vb<<3&8;xb=vb>>1;yb=hf[c[qb>>2]&1023](Ea+(wb|xb<<7)|0,16,Ia+(wb|xb<<8)|0,32)|0;zb=P+12620+(vb<<2)|0;c[zb>>2]=yb;if((c[pb>>2]|0)==0){Ab=yb}else{yb=wb>>>((c[ba>>2]|0)>>>0);wb=xb<<3>>c[da>>2];xb=(wb<<4)+yb|0;Bb=(wb<<5)+yb|0;yb=hf[c[Ka>>2]&1023]((c[rb>>2]|0)+xb|0,16,(c[sb>>2]|0)+Bb|0,32)|0;wb=(hf[c[Ka>>2]&1023]((c[tb>>2]|0)+xb|0,16,(c[ub>>2]|0)+Bb|0,32)|0)+yb|0;yb=wb+(c[zb>>2]|0)|0;c[zb>>2]=yb;Ab=yb}c[Ja>>2]=(c[Ja>>2]|0)+Ab;c[zb>>2]=(c[zb>>2]|0)+(c[Ha>>2]|0);vb=vb+1|0;}while((vb|0)<4)}}while(0);vb=C;Ha=D|0;Ja=E|0;ub=t+31&-32;tb=u+31&-32;c[v>>2]=16;c[w>>2]=16;Ka=c[db>>2]|0;c[A>>2]=2147483647;c[A+4>>2]=2147483647;sb=B|0;if((c[_>>2]|0)==0){c[sb>>2]=0;Cb=0;Db=f+24584|0;Eb=B+4|0}else{c[sb>>2]=(c[f+24580>>2]|0)>1?A:0;sb=f+24584|0;Cb=(c[sb>>2]|0)>1?A+4|0:0;Db=sb;Eb=B+4|0}c[Eb>>2]=Cb;c[C>>2]=0;c[C+4>>2]=c[Ca>>2];sb=f+27916|0;c[C+88>>2]=c[sb>>2];rb=f+27920|0;c[C+92>>2]=c[rb>>2];pb=f+27924|0;c[C+96>>2]=c[pb>>2];Ia=f+24544|0;c[C+72>>2]=c[Ia>>2];Ea=f+24548|0;c[C+76>>2]=c[Ea>>2];qb=f+24552|0;c[C+80>>2]=c[qb>>2];Ba=P+352|0;za=P+368|0;c[Da>>2]=2147483647;zb=P+6480|0;yb=P+6496|0;wb=P+6604|0;c[wb>>2]=2147483647;Bb=C+8|0;xb=C+20|0;Fb=C+68|0;Gb=C+24|0;Hb=C+28|0;Ib=C+32|0;Jb=f+8632|0;Kb=C+36|0;Lb=C+40|0;Mb=C+44|0;Nb=C+48|0;Ob=C+52|0;Pb=C+56|0;Qb=C+60|0;Rb=C+64|0;Sb=C+84|0;Tb=C+16|0;Ub=C+12|0;Vb=C+100|0;Wb=z|0;Xb=C+108|0;Yb=f+37520|0;Zb=C+112|0;_b=f+18616|0;$b=1;ac=0;bc=Ka;e:while(1){Ka=($b|0)!=0;cc=Ka?zb:Ba;if((ac|0)==0){dc=0}else{dc=($b|0)==1|0}ec=f+24580+($b<<2)|0;f:do{if((dc|0)<(c[ec>>2]|0)){fc=($b|0)==1;gc=P+16+($b<<2)|0;hc=B+($b<<2)|0;ic=cc+124|0;jc=cc+16|0;kc=cc+128|0;lc=f+28712+($b<<4)|0;mc=cc+130|0;nc=f+28712+($b<<4)+2|0;oc=bc;pc=dc;while(1){qc=(oc|0)!=0;if(qc&fc&(pc|0)>0){rc=1;sc=oc;tc=pc;break f}c[Bb>>2]=e[(c[gc>>2]|0)+(pc<<1)>>1]|0;uc=c[f+24588+($b*1536|0)+(pc*48|0)>>2]|0;c[xb>>2]=uc;c[Fb>>2]=uc;c[Gb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+4>>2];c[Hb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+8>>2];c[Ib>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+12>>2];uc=(c[Jb>>2]|0)==3;c[Kb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+16>>2];if(uc){c[Lb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+20>>2];c[Mb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+24>>2];c[Nb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+28>>2];c[Ob>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+32>>2];c[Pb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+36>>2];c[Qb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+40>>2];c[Rb>>2]=c[f+24588+($b*1536|0)+(pc*48|0)+44>>2]}c[Sb>>2]=c[f+27788+($b<<6)+(pc<<2)>>2];c[Tb>>2]=2772248;c[Ub>>2]=pc;eQb(f,$b,pc,Vb);hQb(f,$b,pc,Wb,x);oVb(f,C,Wb,c[x>>2]|0,c[hc>>2]|0);uc=(c[Xb>>2]|0)+(c[Bb>>2]|0)|0;c[Xb>>2]=uc;if((uc|0)<(c[ic>>2]|0)){Ee[c[Yb>>2]&511](jc,vb,128)|0}uc=c[Zb>>2]|0;c[cc+276+(pc*20|0)>>2]=uc;c[(c[f+19008+($b<<7)+(pc<<2)>>2]|0)+(c[_b>>2]<<2)>>2]=uc;if((pc|0)!=0|qc^1){vc=oc}else{qc=(b[kc>>1]|0)-(b[lc>>1]|0)|0;uc=(b[mc>>1]|0)-(b[nc>>1]|0)|0;wc=(((uc|0)>-1?uc:-uc|0)+((qc|0)>-1?qc:-qc|0)|0)>1;if(wc|Ka){vc=wc?0:oc}else{la=455;break e}}wc=pc+1|0;if((wc|0)<(c[ec>>2]|0)){oc=vc;pc=wc}else{rc=ac;sc=vc;tc=wc;break}}}else{rc=ac;sc=bc;tc=dc}}while(0);ec=(rc|0)!=0;if(ec&($b|0)==1){if((tc|0)==(c[Db>>2]|0)){la=460;break}}Ka=ec&($b|0)==0?1:$b-1|0;if((Ka|0)>-1){$b=Ka;ac=rc;bc=sc}else{la=460;break}}if((la|0)==455){c[Ga>>2]=18;lUb(f,P)}else if((la|0)==460){Ee[c[Yb>>2]&511](P+496|0,za,128)|0;Ee[c[Yb>>2]&511](P+6624|0,yb,128)|0;bc=P+508|0;ac=c[bc>>2]|0;$b=P+6636|0;Zb=(e[(c[ya>>2]|0)+(c[$b>>2]<<1)>>1]|0)+(e[(c[va>>2]|0)+(ac<<1)>>1]|0)|0;vb=f+37380|0;Xb=P+608|0;Bb=P+610|0;Wb=Ke[c[vb>>2]&63](ub,v,f+24588+(ac*48|0)|0,c[sb>>2]|0,b[Xb>>1]|0,b[Bb>>1]|0,16,16,2772248)|0;ac=P+6736|0;Vb=P+6738|0;Ub=Ke[c[vb>>2]&63](tb,w,f+26124+((c[$b>>2]|0)*48|0)|0,c[sb>>2]|0,b[ac>>1]|0,b[Vb>>1]|0,16,16,2772248)|0;vb=f+37388|0;Tb=f+30412|0;Se[c[vb>>2]&1023](ub,16,Wb,c[v>>2]|0,Ub,c[w>>2]|0,a[(c[$b>>2]|0)+((c[Tb>>2]|0)+(c[bc>>2]<<2))|0]|0);Ub=f+36884|0;Wb=(hf[c[Ub>>2]&1023](c[Ia>>2]|0,16,ub,16)|0)+Zb|0;Sb=P+600|0;Rb=P+6728|0;Qb=Wb+(c[Sb>>2]|0)+(c[Rb>>2]|0)|0;Wb=P+12608|0;c[Wb>>2]=Qb;Pb=f+18636|0;if((c[Pb>>2]|0)==0){xc=Qb}else{Qb=r+31&-32;Ob=s+31&-32;Nb=d[f+36448|0]|0;if((c[Jb>>2]|0)==3){Mb=f+37376|0;Lb=P+608|0;Te[c[Mb>>2]&255](Qb|0,16,P+532|0,c[P+588>>2]|0,b[Lb>>1]|0,b[Bb>>1]|0,16,16,2772248);Te[c[Mb>>2]&255](Qb+256|0,16,P+548|0,c[P+592>>2]|0,b[Lb>>1]|0,b[Bb>>1]|0,16,16,2772248);Lb=P+6736|0;Te[c[Mb>>2]&255](Qb+512|0,16,P+6660|0,c[P+6716>>2]|0,b[Lb>>1]|0,b[Vb>>1]|0,16,16,2772248);Te[c[Mb>>2]&255](Qb+768|0,16,P+6676|0,c[P+6720>>2]|0,b[Lb>>1]|0,b[Vb>>1]|0,16,16,2772248)}else{Lb=c[da>>2]|0;Mb=c[f+18660>>2]&Lb;if((Mb&c[bc>>2]|0)==0){yc=0}else{yc=(c[f+18612>>2]<<2&4)-2|0}if((c[$b>>2]&Mb|0)==0){zc=0}else{zc=(c[f+18612>>2]<<2&4)-2|0}Mb=f+37384|0;Kb=16>>>(Lb>>>0);Te[c[Mb>>2]&255](Qb|0,Qb+256|0,16,c[P+532>>2]|0,c[P+588>>2]|0,b[P+608>>1]|0,(b[Bb>>1]|0)+yc<<1>>Lb,8,Kb);Te[c[Mb>>2]&255](Qb+512|0,Qb+768|0,16,c[P+6660>>2]|0,c[P+6716>>2]|0,b[P+6736>>1]|0,(b[Vb>>1]|0)+zc<<1>>Lb,8,Kb)}Kb=f+37388+(Nb<<2)|0;Lb=Ob|0;Se[c[Kb>>2]&1023](Lb,16,Qb|0,16,Qb+512|0,16,a[(c[$b>>2]|0)+((c[Tb>>2]|0)+(c[bc>>2]<<2))|0]|0);Vb=Ob+256|0;Se[c[Kb>>2]&1023](Vb,16,Qb+256|0,16,Qb+768|0,16,a[(c[$b>>2]|0)+((c[Tb>>2]|0)+(c[bc>>2]<<2))|0]|0);Qb=f+36884+(Nb<<2)|0;Nb=hf[c[Qb>>2]&1023](c[P+572>>2]|0,16,Lb,16)|0;Lb=(hf[c[Qb>>2]&1023](c[P+576>>2]|0,16,Vb,16)|0)+Nb|0;Nb=Lb+(c[Wb>>2]|0)|0;c[Wb>>2]=Nb;xc=Nb}Nb=Xb;Xb=ac;do{if((c[Xb>>2]|c[Nb>>2]|0)==0){Ac=xc}else{ac=c[P+500>>2]|0;Lb=(e[ac+(-(b[P+598>>1]|0)<<1)>>1]|0)+(e[ac+(-(b[P+596>>1]|0)<<1)>>1]|0)|0;ac=c[P+6628>>2]|0;Vb=(e[ac+(-(b[P+6726>>1]|0)<<1)>>1]|0)+(e[ac+(-(b[P+6724>>1]|0)<<1)>>1]|0)|0;ac=c[bc>>2]|0;Qb=c[sb>>2]|0;Kb=c[$b>>2]|0;Se[c[vb>>2]&1023](ub,16,c[f+24588+(ac*48|0)>>2]|0,Qb,c[f+26124+(Kb*48|0)>>2]|0,Qb,a[(c[Tb>>2]|0)+(ac<<2)+Kb|0]|0);Kb=Lb+Zb+Vb+(hf[c[Ub>>2]&1023](c[Ia>>2]|0,16,ub,16)|0)|0;do{if((c[Pb>>2]|0)==0){Bc=Kb}else{if((Kb|0)>=(c[Wb>>2]|0)){Bc=Kb;break}if((c[Jb>>2]|0)==3){ac=c[bc>>2]|0;Qb=c[rb>>2]|0;Ob=c[$b>>2]|0;Se[c[vb>>2]&1023](Ha,16,c[f+24588+(ac*48|0)+16>>2]|0,Qb,c[f+26124+(Ob*48|0)+16>>2]|0,Qb,a[(c[Tb>>2]|0)+(ac<<2)+Ob|0]|0);Ob=(hf[c[Ub>>2]&1023](c[Ea>>2]|0,16,Ha,16)|0)+Kb|0;ac=c[bc>>2]|0;Qb=c[pb>>2]|0;Mb=c[$b>>2]|0;Se[c[vb>>2]&1023](Ha,16,c[f+24588+(ac*48|0)+32>>2]|0,Qb,c[f+26124+(Mb*48|0)+32>>2]|0,Qb,a[(c[Tb>>2]|0)+(ac<<2)+Mb|0]|0);Bc=Ob+(hf[c[Ub>>2]&1023](c[qb>>2]|0,16,Ha,16)|0)|0;break}Ob=d[f+36448|0]|0;Mb=c[da>>2]|0;ac=f+18660|0;Qb=c[bc>>2]|0;if((c[ac>>2]&Mb&Qb|0)==0){mf[c[f+37472>>2]&2047](Ja,c[f+24588+(Qb*48|0)+16>>2]|0,c[rb>>2]|0,16>>>(Mb>>>0))}else{Te[c[f+37384>>2]&255](Ja,E+8|0,16,c[f+24588+(Qb*48|0)+16>>2]|0,c[rb>>2]|0,0,(c[f+18612>>2]<<2&4)-2|0,8,8)}Qb=c[$b>>2]|0;if((c[ac>>2]&Mb&Qb|0)==0){mf[c[f+37472>>2]&2047](E+256|0,c[f+26124+(Qb*48|0)+16>>2]|0,c[rb>>2]|0,16>>>(Mb>>>0));Cc=E+264|0}else{Mb=E+264|0;Te[c[f+37384>>2]&255](E+256|0,Mb,16,c[f+26124+(Qb*48|0)+16>>2]|0,c[rb>>2]|0,0,(c[f+18612>>2]<<2&4)-2|0,8,8);Cc=Mb}Mb=f+37388+(Ob<<2)|0;Se[c[Mb>>2]&1023](Ha,16,Ja,16,E+256|0,16,a[(c[$b>>2]|0)+((c[Tb>>2]|0)+(c[bc>>2]<<2))|0]|0);Qb=D+8|0;Se[c[Mb>>2]&1023](Qb,16,E+8|0,16,Cc,16,a[(c[$b>>2]|0)+((c[Tb>>2]|0)+(c[bc>>2]<<2))|0]|0);Mb=f+36884+(Ob<<2)|0;Ob=hf[c[Mb>>2]&1023](c[Ea>>2]|0,16,Ha,16)|0;Bc=Ob+Kb+(hf[c[Mb>>2]&1023](c[qb>>2]|0,16,Qb,16)|0)|0}}while(0);Kb=c[Wb>>2]|0;if((Bc|0)>=(Kb|0)){Ac=Kb;break}c[Nb>>2]=0;c[Xb>>2]=0;c[Sb>>2]=Lb;c[Rb>>2]=Vb;c[Wb>>2]=Bc;Ac=Bc}}while(0);Rb=c[P>>2]|0;c[Wb>>2]=(Rb*5|0)+Ac;Sb=Rb*3|0;c[Da>>2]=(c[Da>>2]|0)+Sb;c[wb>>2]=(c[wb>>2]|0)+Sb}if((c[Ga>>2]|0)==18){Sb=f+24580|0;if((c[Sb>>2]|0)>1){Rb=1;do{c[(c[f+19008+(Rb<<2)>>2]|0)+(c[_b>>2]<<2)>>2]=0;Rb=Rb+1|0;}while((Rb|0)<(c[Sb>>2]|0))}Sb=f+24584|0;if((c[Sb>>2]|0)>1){Dc=1}else{i=g;return}do{c[(c[f+19136+(Dc<<2)>>2]|0)+(c[_b>>2]<<2)>>2]=0;Dc=Dc+1|0;}while((Dc|0)<(c[Sb>>2]|0));i=g;return}Sb=c[Da>>2]|0;_b=c[wb>>2]|0;Rb=(_b|0)<(Sb|0);Wb=Rb?_b:Sb;Sb=c[P+12608>>2]|0;_b=(Sb|0)<(Wb|0);Xb=_b?Sb:Wb;Wb=c[P+12612>>2]|0;Sb=(Wb|0)<(Xb|0);Nb=Sb?Wb:Xb;Xb=Sb?7:_b?16:Rb?12:8;do{if((c[X>>2]|0)!=0){if((c[_>>2]|0)==0){break}if((Wb|0)>((Nb*33|0|0)/32|0|0)){break}nUb(f,P,Nb);if((cb|0)>=(c[P+12712>>2]|0)){break}if((cb|0)>=(c[P+12708>>2]|0)){break}if((cb|0)>=(c[Ba>>2]|0)){break}if((cb|0)>=(c[zb>>2]|0)){break}c[Ga>>2]=18;lUb(f,P);i=g;return}}while(0);do{if((qa&256|0)==0){Ec=16;Fc=Xb;Gc=Nb}else{if((c[f+568>>2]|0)==0){Wb=o|0;Rb=m;_b=P+380|0;c[l>>2]=f+24588+((c[_b>>2]|0)*48|0);Sb=P+6508|0;c[l+4>>2]=f+26124+((c[Sb>>2]|0)*48|0);c[f+19348>>2]=13;Ha=P+12616|0;c[Ha>>2]=0;bc=f+37380|0;Tb=f+37400|0;$b=n|0;Ja=m;Ub=n+4|0;vb=Rb+4|0;Pb=f+30412|0;ub=f+36896|0;Zb=P|0;tb=f+18636|0;va=r+31&-32;ya=s+31&-32;Kb=f+36451|0;Qb=f+37376|0;Mb=va|0;Ob=va+256|0;ac=va+512|0;Bb=va+768|0;va=ya|0;Ib=ya+256|0;ya=f+18660|0;Hb=f+37384|0;Gb=f+18612|0;Fb=0;while(1){xb=Fb&1;Ka=Fb>>1;c[m>>2]=8;c[m+4>>2]=8;ec=xb<<3;cc=Ka<<3;pc=ec|Ka<<7;oc=xb<<1|Ka<<4|12;Ka=Fb<<2;xb=Fb+1|0;nc=0;mc=0;do{lc=(nc|0)!=0?zb:Ba;kc=lc+928+(Fb<<7)|0;c[kc>>2]=3;c[lc+928+(Fb<<7)+4>>2]=c[Ca>>2];jc=c[sb>>2]|0;ic=lc+928+(Fb<<7)+88|0;c[ic>>2]=jc;hc=c[rb>>2]|0;c[lc+928+(Fb<<7)+92>>2]=hc;gc=c[pb>>2]|0;c[lc+928+(Fb<<7)+96>>2]=gc;c[lc+928+(Fb<<7)+72>>2]=(c[Ia>>2]|0)+pc;fc=cc>>c[da>>2];wc=(fc<<4)+(ec>>>((c[ba>>2]|0)>>>0))|0;c[lc+928+(Fb<<7)+76>>2]=(c[Ea>>2]|0)+wc;c[lc+928+(Fb<<7)+80>>2]=(c[qb>>2]|0)+wc;wc=lc+28|0;qc=c[wc>>2]|0;uc=lc+928+(Fb<<7)+8|0;c[uc>>2]=e[(c[P+16+(nc<<2)>>2]|0)+(qc<<1)>>1]|0;Hc=lc+928+(Fb<<7)+12|0;c[Hc>>2]=qc;Ic=(ca(jc,cc)|0)+ec|0;jc=c[l+(nc<<2)>>2]|0;Jc=(c[jc>>2]|0)+Ic|0;Kc=lc+928+(Fb<<7)+20|0;c[Kc>>2]=Jc;c[lc+928+(Fb<<7)+68>>2]=Jc;c[lc+928+(Fb<<7)+24>>2]=(c[jc+4>>2]|0)+Ic;c[lc+928+(Fb<<7)+28>>2]=(c[jc+8>>2]|0)+Ic;c[lc+928+(Fb<<7)+32>>2]=(c[jc+12>>2]|0)+Ic;if((c[Jb>>2]|0)==3){Jc=(ca(hc,cc)|0)+ec|0;c[lc+928+(Fb<<7)+36>>2]=(c[jc+16>>2]|0)+Jc;c[lc+928+(Fb<<7)+40>>2]=(c[jc+20>>2]|0)+Jc;c[lc+928+(Fb<<7)+44>>2]=(c[jc+24>>2]|0)+Jc;c[lc+928+(Fb<<7)+48>>2]=(c[jc+28>>2]|0)+Jc;Jc=(ca(gc,cc)|0)+ec|0;c[lc+928+(Fb<<7)+52>>2]=(c[jc+32>>2]|0)+Jc;c[lc+928+(Fb<<7)+56>>2]=(c[jc+36>>2]|0)+Jc;c[lc+928+(Fb<<7)+60>>2]=(c[jc+40>>2]|0)+Jc;c[lc+928+(Fb<<7)+64>>2]=(c[jc+44>>2]|0)+Jc}else{Jc=(ca(fc,hc)|0)+ec|0;c[lc+928+(Fb<<7)+36>>2]=(c[jc+16>>2]|0)+Jc}c[lc+928+(Fb<<7)+84>>2]=(c[f+27788+(nc<<6)+(qc<<2)>>2]|0)+(Ic<<1);c[lc+928+(Fb<<7)+16>>2]=2772248;c[Hc>>2]=qc;re[c[25111]&1023](f+28104+(nc*40|0)+oc|0,qc&255);dQb(f,nc,Ka,2,lc+928+(Fb<<7)+100|0);oVb(f,kc,lc+128|0,1,0);kc=lc+928+(Fb<<7)+108|0;qc=lc+928+(Fb<<7)+104|0;c[P+12636+(nc<<4)+(Fb<<2)>>2]=(c[kc>>2]|0)-(c[qc>>2]|0);c[kc>>2]=(c[kc>>2]|0)+(c[uc>>2]|0);kc=lc+928+(Fb<<7)+112|0;Hc=kc;re[c[25131]&1023](f+28192+(nc*160|0)+(oc<<2)|0,c[Hc>>2]|0);c[lc+276+((c[wc>>2]|0)*20|0)+(xb<<2)>>2]=c[Hc>>2];c[n+(nc<<2)>>2]=Ke[c[bc>>2]&63](o+(nc<<6)|0,Rb+(nc<<2)|0,Kc,c[ic>>2]|0,b[kc>>1]|0,b[lc+928+(Fb<<7)+114>>1]|0,8,8,2772248)|0;mc=(c[qc>>2]|0)+mc+(c[uc>>2]|0)|0;nc=nc+1|0;}while((nc|0)<2);Se[c[Tb>>2]&1023](Wb,8,c[$b>>2]|0,c[Ja>>2]|0,c[Ub>>2]|0,c[vb>>2]|0,a[(c[Sb>>2]|0)+((c[Pb>>2]|0)+(c[_b>>2]<<2))|0]|0);nc=hf[c[ub>>2]&1023](c[P+1280+(Fb<<7)+72>>2]|0,16,Wb,8)|0;oc=P+12668+(Fb<<2)|0;c[oc>>2]=nc;Ka=c[Zb>>2]|0;ec=nc+mc+(Ka*5|0)|0;nc=Ka*3|0;Ka=P+1280+(Fb<<7)+108|0;cc=(c[Ka>>2]|0)+nc|0;c[Ka>>2]=cc;pc=P+7408+(Fb<<7)+108|0;uc=(c[pc>>2]|0)+nc|0;c[pc>>2]=uc;if((c[tb>>2]|0)==0){Lc=ec;Mc=cc;Nc=uc}else{uc=d[Kb]|0;if((c[Jb>>2]|0)==3){cc=P+1280+(Fb<<7)+112|0;nc=P+1280+(Fb<<7)+114|0;Te[c[Qb>>2]&255](Mb,16,P+1280+(Fb<<7)+36|0,c[P+1280+(Fb<<7)+92>>2]|0,b[cc>>1]|0,b[nc>>1]|0,8,8,2772248);Te[c[Qb>>2]&255](Ob,16,P+1280+(Fb<<7)+52|0,c[P+1280+(Fb<<7)+96>>2]|0,b[cc>>1]|0,b[nc>>1]|0,8,8,2772248);nc=P+7408+(Fb<<7)+112|0;cc=P+7408+(Fb<<7)+114|0;Te[c[Qb>>2]&255](ac,16,P+7408+(Fb<<7)+36|0,c[P+7408+(Fb<<7)+92>>2]|0,b[nc>>1]|0,b[cc>>1]|0,8,8,2772248);Te[c[Qb>>2]&255](Bb,16,P+7408+(Fb<<7)+52|0,c[P+7408+(Fb<<7)+96>>2]|0,b[nc>>1]|0,b[cc>>1]|0,8,8,2772248);Oc=P+7408+(Fb<<7)+12|0;Pc=P+1280+(Fb<<7)+12|0}else{cc=c[da>>2]|0;nc=c[ya>>2]&cc;qc=P+1280+(Fb<<7)+12|0;if((nc&c[qc>>2]|0)==0){Qc=0}else{Qc=(c[Gb>>2]<<2&4)-2|0}lc=P+7408+(Fb<<7)+12|0;if((c[lc>>2]&nc|0)==0){Rc=0}else{Rc=(c[Gb>>2]<<2&4)-2|0}nc=8>>>(cc>>>0);Te[c[Hb>>2]&255](Mb,Ob,16,c[P+1280+(Fb<<7)+36>>2]|0,c[P+1280+(Fb<<7)+92>>2]|0,b[P+1280+(Fb<<7)+112>>1]|0,(b[P+1280+(Fb<<7)+114>>1]|0)+Qc<<1>>cc,4,nc);Te[c[Hb>>2]&255](ac,Bb,16,c[P+7408+(Fb<<7)+36>>2]|0,c[P+7408+(Fb<<7)+92>>2]|0,b[P+7408+(Fb<<7)+112>>1]|0,(b[P+7408+(Fb<<7)+114>>1]|0)+Rc<<1>>cc,4,nc);Oc=lc;Pc=qc}qc=f+37388+(uc<<2)|0;Se[c[qc>>2]&1023](va,16,Mb,16,ac,16,a[(c[Oc>>2]|0)+((c[Pb>>2]|0)+(c[Pc>>2]<<2))|0]|0);Se[c[qc>>2]&1023](Ib,16,Ob,16,Bb,16,a[(c[Oc>>2]|0)+((c[Pb>>2]|0)+(c[Pc>>2]<<2))|0]|0);qc=f+36884+(uc<<2)|0;uc=hf[c[qc>>2]&1023](c[P+1280+(Fb<<7)+76>>2]|0,16,va,16)|0;lc=(hf[c[qc>>2]&1023](c[P+1280+(Fb<<7)+80>>2]|0,16,Ib,16)|0)+uc|0;c[oc>>2]=(c[oc>>2]|0)+lc;Lc=lc+ec|0;Mc=c[Ka>>2]|0;Nc=c[pc>>2]|0}pc=f+19352+Fb|0;Ka=(Nc|0)<(Mc|0);ec=Ka?Nc:Mc;lc=(Lc|0)<(ec|0);oc=lc?Lc:ec;a[pc]=lc?11:Ka?7:3;Ka=c[P+12620+(Fb<<2)>>2]|0;if((Ka|0)<(oc|0)){a[pc]=12;Sc=Ka}else{Sc=oc}c[Ha>>2]=(c[Ha>>2]|0)+Sc;GUb(f,P,Fb,0);if((xb|0)<4){Fb=xb}else{break}}Fb=(c[Ha>>2]|0)+((c[Zb>>2]|0)*9|0)|0;c[Ha>>2]=Fb;Tc=Fb}else{Fb=o|0;Ib=q;va=J|0;Pb=(c[f+24580>>2]|0)-1|0;c[va>>2]=Pb;Bb=J+4|0;Ob=(c[f+24584>>2]|0)-1|0;c[Bb>>2]=Ob;ac=f+18876|0;Mb=f+18880|0;do{if((Pb|0)>0){if((c[P+380>>2]|0)!=0){break}if((c[ac>>2]|0)<=0){break}if((c[Mb>>2]|0)<=0){break}c[va>>2]=0;Hb=a[f+28107|0]|0;if(Hb<<24>>24>0){Gb=Hb<<24>>24;c[va>>2]=Gb;Uc=Gb}else{Uc=0}Gb=a[f+28108|0]|0;if((Gb|0)>(Uc|0)){c[va>>2]=Gb;Vc=Gb}else{Vc=Uc}Gb=a[f+28110|0]|0;if((Gb|0)>(Vc|0)){c[va>>2]=Gb;Wc=Gb}else{Wc=Vc}Gb=a[f+28112|0]|0;if((Gb|0)>(Wc|0)){c[va>>2]=Gb;Xc=Gb}else{Xc=Wc}Gb=a[f+28115|0]|0;if((Gb|0)>(Xc|0)){c[va>>2]=Gb;Yc=Gb}else{Yc=Xc}Gb=a[f+28131|0]|0;if((Gb|0)<=(Yc|0)){break}c[va>>2]=Gb}}while(0);do{if((Ob|0)>0){if((c[P+6508>>2]|0)!=0){break}if((c[ac>>2]|0)<=0){break}if((c[Mb>>2]|0)<=0){break}c[Bb>>2]=0;va=a[f+28147|0]|0;if(va<<24>>24>0){Pb=va<<24>>24;c[Bb>>2]=Pb;Zc=Pb}else{Zc=0}Pb=a[f+28148|0]|0;if((Pb|0)>(Zc|0)){c[Bb>>2]=Pb;_c=Pb}else{_c=Zc}Pb=a[f+28150|0]|0;if((Pb|0)>(_c|0)){c[Bb>>2]=Pb;$c=Pb}else{$c=_c}Pb=a[f+28152|0]|0;if((Pb|0)>($c|0)){c[Bb>>2]=Pb;ad=Pb}else{ad=$c}Pb=a[f+28155|0]|0;if((Pb|0)>(ad|0)){c[Bb>>2]=Pb;bd=Pb}else{bd=ad}Pb=a[f+28171|0]|0;if((Pb|0)<=(bd|0)){break}c[Bb>>2]=Pb}}while(0);c[f+19348>>2]=13;Bb=P+12616|0;c[Bb>>2]=0;Mb=q|0;ac=q+4|0;Ob=q+88|0;Pb=q+92|0;va=q+96|0;Ha=q+72|0;Zb=q+76|0;Gb=q+80|0;Hb=q+8|0;ya=q+20|0;Qb=q+68|0;Kb=q+24|0;tb=q+28|0;Wb=q+32|0;ub=q+36|0;_b=q+40|0;Sb=q+44|0;vb=q+48|0;Ub=q+52|0;Ja=q+56|0;$b=q+60|0;Tb=q+64|0;Rb=q+84|0;bc=q+16|0;Vb=q+12|0;Lb=q+100|0;oc=q+108|0;Ka=q+104|0;pc=q+112|0;lc=f+37380|0;ec=p;uc=o+64|0;qc=p+4|0;nc=f+37400|0;cc=f+30412|0;kc=f+36896|0;ic=P|0;Kc=f+18636|0;Hc=r+31&-32;wc=s+31&-32;Ic=f+36451|0;Jc=f+37376|0;jc=Hc|0;hc=Hc+256|0;fc=Hc+512|0;gc=Hc+768|0;Hc=wc|0;cd=wc+256|0;wc=f+18660|0;dd=f+37384|0;ed=f+18612|0;fd=0;while(1){gd=fd&1;hd=fd>>1;c[p>>2]=8;c[p+4>>2]=8;c[Mb>>2]=3;c[ac>>2]=c[Ca>>2];c[Ob>>2]=c[sb>>2];c[Pb>>2]=c[rb>>2];c[va>>2]=c[pb>>2];id=gd<<3;jd=hd<<3;c[Ha>>2]=(c[Ia>>2]|0)+(id|hd<<7);kd=(jd>>c[da>>2]<<4)+(id>>>((c[ba>>2]|0)>>>0))|0;c[Zb>>2]=(c[Ea>>2]|0)+kd;c[Gb>>2]=(c[qb>>2]|0)+kd;kd=gd<<1|hd<<4|12;hd=fd<<2;gd=fd+1|0;ld=0;do{md=(ld|0)!=0?zb:Ba;nd=md+928+(fd<<7)+108|0;c[nd>>2]=2147483647;od=c[J+(ld<<2)>>2]|0;if((od|0)>=0){pd=P+16+(ld<<2)|0;qd=f+28104+(ld*40|0)+kd|0;rd=md+928+(fd<<7)|0;sd=P+12636+(ld<<4)+(fd<<2)|0;td=0;do{c[Hb>>2]=e[(c[pd>>2]|0)+(td<<1)>>1]|0;ud=(ca(c[Ob>>2]|0,jd)|0)+id|0;vd=(c[f+24588+(ld*1536|0)+(td*48|0)>>2]|0)+ud|0;c[ya>>2]=vd;c[Qb>>2]=vd;c[Kb>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+4>>2]|0)+ud;c[tb>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+8>>2]|0)+ud;c[Wb>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+12>>2]|0)+ud;if((c[Jb>>2]|0)==3){vd=(ca(c[Pb>>2]|0,jd)|0)+id|0;c[ub>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+16>>2]|0)+vd;c[_b>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+20>>2]|0)+vd;c[Sb>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+24>>2]|0)+vd;c[vb>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+28>>2]|0)+vd;vd=(ca(c[va>>2]|0,jd)|0)+id|0;c[Ub>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+32>>2]|0)+vd;c[Ja>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+36>>2]|0)+vd;c[$b>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+40>>2]|0)+vd;c[Tb>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+44>>2]|0)+vd}else{vd=(ca(jd>>c[da>>2],c[Pb>>2]|0)|0)+id|0;c[ub>>2]=(c[f+24588+(ld*1536|0)+(td*48|0)+16>>2]|0)+vd}c[Rb>>2]=(c[f+27788+(ld<<6)+(td<<2)>>2]|0)+(ud<<1);c[bc>>2]=2772248;c[Vb>>2]=td;re[c[25111]&1023](qd,td&255);dQb(f,ld,hd,2,Lb);oVb(f,q,md+276+(td*20|0)|0,gd,0);ud=(c[oc>>2]|0)+(c[Hb>>2]|0)|0;c[oc>>2]=ud;if((ud|0)<(c[nd>>2]|0)){Ee[c[Yb>>2]&511](rd,Ib,128)|0;c[sd>>2]=(c[oc>>2]|0)-(c[Ka>>2]|0)-(c[Hb>>2]|0)}c[md+276+(td*20|0)+(gd<<2)>>2]=c[pc>>2];td=td+1|0;}while((td|0)<=(od|0))}ld=ld+1|0;}while((ld|0)<2);ld=P+1280+(fd<<7)+112|0;hd=P+1280+(fd<<7)+114|0;id=Ke[c[lc>>2]&63](Fb,ec,P+1280+(fd<<7)+20|0,c[P+1280+(fd<<7)+88>>2]|0,b[ld>>1]|0,b[hd>>1]|0,8,8,2772248)|0;jd=P+7408+(fd<<7)+112|0;kd=P+7408+(fd<<7)+114|0;xb=Ke[c[lc>>2]&63](uc,qc,P+7408+(fd<<7)+20|0,c[P+7408+(fd<<7)+88>>2]|0,b[jd>>1]|0,b[kd>>1]|0,8,8,2772248)|0;mc=P+7408+(fd<<7)+12|0;od=P+1280+(fd<<7)+12|0;Se[c[nc>>2]&1023](Fb,8,id,c[ec>>2]|0,xb,c[qc>>2]|0,a[(c[mc>>2]|0)+((c[cc>>2]|0)+(c[od>>2]<<2))|0]|0);xb=hf[c[kc>>2]&1023](c[P+1280+(fd<<7)+72>>2]|0,16,Fb,8)|0;id=P+12668+(fd<<2)|0;c[id>>2]=xb;td=c[ic>>2]|0;md=(c[P+1280+(fd<<7)+104>>2]|0)+xb+(c[P+7408+(fd<<7)+104>>2]|0)+(c[P+1280+(fd<<7)+8>>2]|0)+(c[P+7408+(fd<<7)+8>>2]|0)+(td*5|0)|0;if((c[Kc>>2]|0)==0){wd=md;xd=td}else{td=d[Ic]|0;if((c[Jb>>2]|0)==3){Te[c[Jc>>2]&255](jc,16,P+1280+(fd<<7)+36|0,c[P+1280+(fd<<7)+92>>2]|0,b[ld>>1]|0,b[hd>>1]|0,8,8,2772248);Te[c[Jc>>2]&255](hc,16,P+1280+(fd<<7)+52|0,c[P+1280+(fd<<7)+96>>2]|0,b[ld>>1]|0,b[hd>>1]|0,8,8,2772248);Te[c[Jc>>2]&255](fc,16,P+7408+(fd<<7)+36|0,c[P+7408+(fd<<7)+92>>2]|0,b[jd>>1]|0,b[kd>>1]|0,8,8,2772248);Te[c[Jc>>2]&255](gc,16,P+7408+(fd<<7)+52|0,c[P+7408+(fd<<7)+96>>2]|0,b[jd>>1]|0,b[kd>>1]|0,8,8,2772248)}else{xb=c[da>>2]|0;sd=c[wc>>2]&xb;if((sd&c[od>>2]|0)==0){yd=0}else{yd=(c[ed>>2]<<2&4)-2|0}if((c[mc>>2]&sd|0)==0){zd=0}else{zd=(c[ed>>2]<<2&4)-2|0}sd=8>>>(xb>>>0);Te[c[dd>>2]&255](jc,hc,16,c[P+1280+(fd<<7)+36>>2]|0,c[P+1280+(fd<<7)+92>>2]|0,b[ld>>1]|0,(b[hd>>1]|0)+yd<<1>>xb,4,sd);Te[c[dd>>2]&255](fc,gc,16,c[P+7408+(fd<<7)+36>>2]|0,c[P+7408+(fd<<7)+92>>2]|0,b[jd>>1]|0,(b[kd>>1]|0)+zd<<1>>xb,4,sd)}sd=f+37388+(td<<2)|0;Se[c[sd>>2]&1023](Hc,16,jc,16,fc,16,a[(c[mc>>2]|0)+((c[cc>>2]|0)+(c[od>>2]<<2))|0]|0);Se[c[sd>>2]&1023](cd,16,hc,16,gc,16,a[(c[mc>>2]|0)+((c[cc>>2]|0)+(c[od>>2]<<2))|0]|0);od=f+36884+(td<<2)|0;td=hf[c[od>>2]&1023](c[P+1280+(fd<<7)+76>>2]|0,16,Hc,16)|0;mc=(hf[c[od>>2]&1023](c[P+1280+(fd<<7)+80>>2]|0,16,cd,16)|0)+td|0;c[id>>2]=(c[id>>2]|0)+mc;wd=mc+md|0;xd=c[ic>>2]|0}md=xd*3|0;mc=P+1280+(fd<<7)+108|0;id=(c[mc>>2]|0)+md|0;c[mc>>2]=id;mc=P+7408+(fd<<7)+108|0;td=(c[mc>>2]|0)+md|0;c[mc>>2]=td;mc=f+19352+fd|0;md=(td|0)<(id|0);od=md?td:id;id=(wd|0)<(od|0);td=id?wd:od;a[mc]=id?11:md?7:3;md=c[P+12620+(fd<<2)>>2]|0;if((md|0)<(td|0)){a[mc]=12;Ad=md}else{Ad=td}c[Bb>>2]=(c[Bb>>2]|0)+Ad;GUb(f,P,fd,0);if((gd|0)<4){fd=gd}else{break}}fd=(c[Bb>>2]|0)+((c[ic>>2]|0)*9|0)|0;c[Bb>>2]=fd;Tc=fd}fd=(Tc|0)<(Nb|0);cd=fd?17:Xb;Hc=0;do{cc=Hc<<1;gc=cc|1;hc=(c[P+12652+(gc<<2)>>2]|0)+(c[P+12652+(cc<<2)>>2]|0)|0;fc=(c[P+12668+(gc<<2)>>2]|0)+(c[P+12668+(cc<<2)>>2]|0)|0;jc=(c[P+1280+(cc<<7)+104>>2]|0)+1+(c[P+1280+(cc<<7)+8>>2]|0)+(c[P+1280+(gc<<7)+104>>2]|0)+(c[P+1280+(gc<<7)+8>>2]|0)>>1;dd=(c[P+7408+(cc<<7)+104>>2]|0)+1+(c[P+7408+(cc<<7)+8>>2]|0)+(c[P+7408+(gc<<7)+104>>2]|0)+(c[P+7408+(gc<<7)+8>>2]|0)>>1;ed=(c[P+12636+(gc<<2)>>2]|0)+(c[P+12636+(cc<<2)>>2]|0)+jc|0;if((ed|0)<268435456){c[R+(Hc<<2)>>2]=3;Bd=ed}else{Bd=268435456}ed=hc+dd|0;if((ed|0)<(Bd|0)){c[R+(Hc<<2)>>2]=7;Dd=ed}else{Dd=Bd}ed=fc+jc+dd|0;if((ed|0)<(Dd|0)){c[R+(Hc<<2)>>2]=11;Ed=ed}else{Ed=Dd}c[P+12684+(Hc<<2)>>2]=Ed;ed=Hc+2|0;dd=(c[P+12652+(ed<<2)>>2]|0)+(c[P+12652+(Hc<<2)>>2]|0)|0;jc=(c[P+12668+(ed<<2)>>2]|0)+(c[P+12668+(Hc<<2)>>2]|0)|0;fc=(c[P+1280+(Hc<<7)+104>>2]|0)+1+(c[P+1280+(Hc<<7)+8>>2]|0)+(c[P+1280+(ed<<7)+104>>2]|0)+(c[P+1280+(ed<<7)+8>>2]|0)>>1;hc=(c[P+7408+(Hc<<7)+104>>2]|0)+1+(c[P+7408+(Hc<<7)+8>>2]|0)+(c[P+7408+(ed<<7)+104>>2]|0)+(c[P+7408+(ed<<7)+8>>2]|0)>>1;cc=(c[P+12636+(ed<<2)>>2]|0)+(c[P+12636+(Hc<<2)>>2]|0)+fc|0;if((cc|0)<268435456){c[S+(Hc<<2)>>2]=3;Fd=cc}else{Fd=268435456}cc=dd+hc|0;if((cc|0)<(Fd|0)){c[S+(Hc<<2)>>2]=7;Gd=cc}else{Gd=Fd}cc=jc+fc+hc|0;if((cc|0)<(Gd|0)){c[S+(Hc<<2)>>2]=11;Hd=cc}else{Hd=Gd}c[P+12692+(Hc<<2)>>2]=Hd;Hc=Hc+1|0;}while((Hc|0)<2);Hc=fd?Tc:Nb;Bb=fd?13:16;ic=P|0;cc=c[ic>>2]|0;hc=ca(d[1078080+(((c[R>>2]>>2)*3|0)+8+(c[R+4>>2]>>2))|0]|0,cc)|0;fc=P+12688|0;jc=hc+(c[fc>>2]|0)|0;c[fc>>2]=jc;fc=jc+(c[P+12684>>2]|0)|0;jc=ca(d[1078080+(((c[S>>2]>>2)*3|0)+8+(c[S+4>>2]>>2))|0]|0,cc)|0;cc=P+12696|0;hc=jc+(c[cc>>2]|0)|0;c[cc>>2]=hc;jc=hc+(c[P+12692>>2]|0)|0;hc=(fc|0)<(jc|0);do{if(hc){if(!((c[_>>2]|0)==0|(fc|0)<(Hc|0))){Id=Bb;Jd=cd;Kd=Hc;break}oUb(f,P,Hc);dd=c[P+12700>>2]|0;if((dd|0)>=(Hc|0)){Id=Bb;Jd=cd;Kd=Hc;break}Id=14;Jd=c[P+12744>>2]|0;Kd=dd}else{Id=Bb;Jd=cd;Kd=Hc}}while(0);do{if((c[_>>2]|0)==0|(jc|0)<(Kd|0)){Hc=h|0;cd=k;c[f+19348>>2]=15;Bb=P+12704|0;c[Bb>>2]=0;fd=k|0;dd=k+4|0;ed=k+88|0;gc=k+92|0;wc=k+96|0;Jc=k+72|0;Ic=k+76|0;Kc=k+80|0;Fb=J|0;kc=J+4|0;qc=k+8|0;ec=k+20|0;nc=k+68|0;uc=k+24|0;lc=k+28|0;pc=k+32|0;Hb=k+36|0;Ka=k+40|0;oc=k+44|0;Ib=k+48|0;Lb=k+52|0;Vb=k+56|0;bc=k+60|0;Rb=k+64|0;ub=k+84|0;Pb=k+16|0;Tb=k+12|0;$b=I;Ja=I|0;Ub=I+4|0;va=I+8|0;vb=k+100|0;Sb=k+108|0;_b=f+37380|0;Wb=j;tb=h+128|0;Kb=j+4|0;Qb=f+37396|0;ya=f+30412|0;Ob=f+36892|0;Gb=f+18636|0;Zb=f+18652|0;Ha=r+31&-32;ac=s+31&-32;Mb=f+36450|0;td=f+37376|0;md=Ha|0;mc=Ha+256|0;id=Ha+512|0;od=Ha+768|0;Ha=ac|0;sd=ac+256|0;ac=f+18660|0;xb=f+37384|0;kd=f+18612|0;jd=0;while(1){c[j>>2]=8;c[j+4>>2]=8;c[fd>>2]=2;c[dd>>2]=c[Ca>>2];c[ed>>2]=c[sb>>2];c[gc>>2]=c[rb>>2];c[wc>>2]=c[pb>>2];hd=jd<<3;c[Jc>>2]=(c[Ia>>2]|0)+hd;ld=hd>>c[ba>>2];c[Ic>>2]=(c[Ea>>2]|0)+ld;c[Kc>>2]=(c[qb>>2]|0)+ld;ld=jd+2|0;rd=jd+1|0;nd=jd+3|0;qd=(jd<<1)+12|0;pd=jd<<2;ud=0;do{vd=(ud|0)!=0?zb:Ba;Ld=c[vd+928+(jd<<7)+12>>2]|0;c[Fb>>2]=Ld;Md=c[vd+928+(ld<<7)+12>>2]|0;c[kc>>2]=Md;Nd=(Ld|0)==(Md|0)?1:2;Md=vd+5872+(jd<<7)+108|0;c[Md>>2]=2147483647;Od=P+16+(ud<<2)|0;Pd=f+28104+(ud*40|0)+qd|0;Qd=vd+5872+(jd<<7)|0;Rd=1;Sd=Ld;while(1){c[qc>>2]=e[(c[Od>>2]|0)+(Sd<<1)>>1]|0;Ld=(c[f+24588+(ud*1536|0)+(Sd*48|0)>>2]|0)+hd|0;c[ec>>2]=Ld;c[nc>>2]=Ld;c[uc>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+4>>2]|0)+hd;c[lc>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+8>>2]|0)+hd;c[pc>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+12>>2]|0)+hd;Ld=(c[Jb>>2]|0)==3;c[Hb>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+16>>2]|0)+hd;if(Ld){c[Ka>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+20>>2]|0)+hd;c[oc>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+24>>2]|0)+hd;c[Ib>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+28>>2]|0)+hd;c[Lb>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+32>>2]|0)+hd;c[Vb>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+36>>2]|0)+hd;c[bc>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+40>>2]|0)+hd;c[Rb>>2]=(c[f+24588+(ud*1536|0)+(Sd*48|0)+44>>2]|0)+hd}c[ub>>2]=(c[f+27788+(ud<<6)+(Sd<<2)>>2]|0)+(hd<<1);c[Pb>>2]=2772248;c[Tb>>2]=Sd;c[Ja>>2]=c[vd+276+(Sd*20|0)>>2];c[Ub>>2]=c[vd+276+(Sd*20|0)+(rd<<2)>>2];c[va>>2]=c[vd+276+(Sd*20|0)+(nd<<2)>>2];re[c[25115]&1023](Pd,Sd&255);dQb(f,ud,pd,2,vb);oVb(f,k,$b,3,0);Ld=(c[Sb>>2]|0)+(c[qc>>2]|0)|0;c[Sb>>2]=Ld;if((Ld|0)<(c[Md>>2]|0)){Ee[c[Yb>>2]&511](Qd,cd,128)|0}if((Rd|0)>=(Nd|0)){break}Ld=c[J+(Rd<<2)>>2]|0;Rd=Rd+1|0;Sd=Ld}ud=ud+1|0;}while((ud|0)<2);ud=P+6224+(jd<<7)+112|0;pd=P+6224+(jd<<7)+114|0;nd=Ke[c[_b>>2]&63](Hc,Wb,P+6224+(jd<<7)+20|0,c[P+6224+(jd<<7)+88>>2]|0,b[ud>>1]|0,b[pd>>1]|0,8,16,2772248)|0;hd=P+12352+(jd<<7)+112|0;ld=P+12352+(jd<<7)+114|0;Sd=Ke[c[_b>>2]&63](tb,Kb,P+12352+(jd<<7)+20|0,c[P+12352+(jd<<7)+88>>2]|0,b[hd>>1]|0,b[ld>>1]|0,8,16,2772248)|0;Rd=P+12352+(jd<<7)+12|0;Nd=P+6224+(jd<<7)+12|0;Se[c[Qb>>2]&1023](Hc,8,nd,c[Wb>>2]|0,Sd,c[Kb>>2]|0,a[(c[Rd>>2]|0)+((c[ya>>2]|0)+(c[Nd>>2]<<2))|0]|0);Sd=hf[c[Ob>>2]&1023](c[P+6224+(jd<<7)+72>>2]|0,16,Hc,8)|0;nd=(c[P+6224+(jd<<7)+104>>2]|0)+Sd+(c[P+12352+(jd<<7)+104>>2]|0)+(c[P+6224+(jd<<7)+8>>2]|0)+(c[P+12352+(jd<<7)+8>>2]|0)|0;if((c[Gb>>2]|0)==0){Td=nd}else{Sd=d[Mb]|0;if((c[Jb>>2]|0)==3){Te[c[td>>2]&255](md,16,P+6224+(jd<<7)+36|0,c[P+6224+(jd<<7)+92>>2]|0,b[ud>>1]|0,b[pd>>1]|0,8,16,2772248);Te[c[td>>2]&255](mc,16,P+6224+(jd<<7)+52|0,c[P+6224+(jd<<7)+96>>2]|0,b[ud>>1]|0,b[pd>>1]|0,8,16,2772248);Te[c[td>>2]&255](id,16,P+12352+(jd<<7)+36|0,c[P+12352+(jd<<7)+92>>2]|0,b[hd>>1]|0,b[ld>>1]|0,8,16,2772248);Te[c[td>>2]&255](od,16,P+12352+(jd<<7)+52|0,c[P+12352+(jd<<7)+96>>2]|0,b[hd>>1]|0,b[ld>>1]|0,8,16,2772248)}else{Qd=c[da>>2]|0;Md=c[ac>>2]&Qd;if((Md&c[Nd>>2]|0)==0){Ud=0}else{Ud=(c[kd>>2]<<2&4)-2|0}if((c[Rd>>2]&Md|0)==0){Vd=0}else{Vd=(c[kd>>2]<<2&4)-2|0}Md=16>>>(Qd>>>0);Te[c[xb>>2]&255](md,mc,16,c[P+6224+(jd<<7)+36>>2]|0,c[P+6224+(jd<<7)+92>>2]|0,b[ud>>1]|0,(b[pd>>1]|0)+Ud<<1>>Qd,4,Md);Te[c[xb>>2]&255](id,od,16,c[P+12352+(jd<<7)+36>>2]|0,c[P+12352+(jd<<7)+92>>2]|0,b[hd>>1]|0,(b[ld>>1]|0)+Vd<<1>>Qd,4,Md)}Md=f+37388+(Sd<<2)|0;Se[c[Md>>2]&1023](Ha,16,md,16,id,16,a[(c[Rd>>2]|0)+((c[ya>>2]|0)+(c[Nd>>2]<<2))|0]|0);Se[c[Md>>2]&1023](sd,16,mc,16,od,16,a[(c[Rd>>2]|0)+((c[ya>>2]|0)+(c[Nd>>2]<<2))|0]|0);Md=f+36884+(Sd<<2)|0;Sd=hf[c[Md>>2]&1023](c[P+6224+(jd<<7)+76>>2]|0,16,Ha,16)|0;Td=Sd+nd+(hf[c[Md>>2]&1023](c[P+6224+(jd<<7)+80>>2]|0,16,sd,16)|0)|0}Md=c[P+6224+(jd<<7)+108>>2]|0;nd=P+12736+(jd<<2)|0;c[nd>>2]=3;Sd=c[P+12352+(jd<<7)+108>>2]|0;if((Sd|0)<(Md|0)){c[nd>>2]=7;Wd=Sd}else{Wd=Md}if(((c[ic>>2]|0)+Td|0)<(Wd|0)){c[nd>>2]=11;Xd=Td}else{Xd=Wd}c[Bb>>2]=(c[Bb>>2]|0)+Xd;if((c[_>>2]|0)!=0&(jd|0)==0){if(((c[cc>>2]|0)+Xd|0)>((ca(((c[X>>2]|0)!=0|16)+((c[Zb>>2]|0)!=0)|0,Kd)|0)/16|0|0)){Yd=268435456;break}}if((a[95296+(c[nd>>2]|0)|0]|0)==0){re[c[25115]&1023](f+28104+qd|0,255);re[c[25135]&1023](f+28192+(qd<<2)|0,0)}else{re[c[25115]&1023](f+28104+qd|0,c[Nd>>2]&255);re[c[25135]&1023](f+28192+(qd<<2)|0,c[ud>>2]|0)}if((a[95313+(c[nd>>2]|0)|0]|0)==0){re[c[25115]&1023](f+28144+qd|0,255);re[c[25135]&1023](f+28352+(qd<<2)|0,0)}else{re[c[25115]&1023](f+28144+qd|0,c[Rd>>2]&255);re[c[25135]&1023](f+28352+(qd<<2)|0,c[hd>>2]|0)}if((rd|0)<2){jd=rd}else{la=625;break}}if((la|0)==625){jd=((c[P+12736>>2]>>2)*3|0)+8+(c[P+12740>>2]>>2)|0;c[P+12748>>2]=jd;Zb=ca(d[1078080+jd|0]|0,c[ic>>2]|0)|0;Yd=Zb+(c[Bb>>2]|0)|0}c[Bb>>2]=Yd;if((Yd|0)>=(Kd|0)){Zd=Id;_d=Jd;$d=Kd;break}Zd=15;_d=c[P+12748>>2]|0;$d=Yd}else{Zd=Id;_d=Jd;$d=Kd}}while(0);if(hc){Ec=Zd;Fc=_d;Gc=$d;break}if(!((c[_>>2]|0)==0|(fc|0)<($d|0))){Ec=Zd;Fc=_d;Gc=$d;break}oUb(f,P,$d);ic=c[P+12700>>2]|0;if((ic|0)>=($d|0)){Ec=Zd;Fc=_d;Gc=$d;break}Ec=14;Fc=c[P+12744>>2]|0;Gc=ic}}while(0);if((c[X>>2]|0)==0){do{if((c[f+18632>>2]|0)==0){ae=Gc}else{if((Ec|0)==13){Yb=P|0;qb=P+12616|0;Ea=0;while(1){Ia=a[f+19352+Ea|0]|0;pb=Ia&255;rb=Ia<<24>>24==11;do{if(!(Ia<<24>>24==12)){do{if((a[95296+pb|0]|0)!=0){sb=P+1280+(Ea<<7)+108|0;Ca=c[sb>>2]|0;Nb=(c[Yb>>2]|0)*3|0;c[sb>>2]=Ca-Nb;qVb(f,P+1280+(Ea<<7)|0);if(rb){break}c[qb>>2]=Nb-Ca+(c[sb>>2]|0)+(c[qb>>2]|0)}}while(0);if((a[95313+pb|0]|0)==0){break}rd=P+7408+(Ea<<7)+108|0;qd=c[rd>>2]|0;sb=(c[Yb>>2]|0)*3|0;c[rd>>2]=qd-sb;qVb(f,P+7408+(Ea<<7)|0);if(rb){break}c[qb>>2]=sb-qd+(c[rd>>2]|0)+(c[qb>>2]|0)}}while(0);rb=Ea+1|0;if((rb|0)<4){Ea=rb}else{ae=Gc;break}}}else if((Ec|0)==15){Ea=P+12736|0;if((c[Ea>>2]|0)==7){la=646}else{qVb(f,P+6224|0);if((c[Ea>>2]|0)!=3){la=646}}if((la|0)==646){qVb(f,P+12352|0)}Ea=P+12740|0;if((c[Ea>>2]|0)!=7){qVb(f,P+6352|0);if((c[Ea>>2]|0)==3){ae=Gc;break}}qVb(f,P+12480|0);ae=Gc;break}else if((Ec|0)==14){Ea=P+12728|0;if((c[Ea>>2]|0)==7){la=643}else{qVb(f,P+5952|0);if((c[Ea>>2]|0)!=3){la=643}}if((la|0)==643){qVb(f,P+12080|0)}Ea=P+12732|0;if((c[Ea>>2]|0)!=7){qVb(f,P+6080|0);if((c[Ea>>2]|0)==3){ae=Gc;break}}qVb(f,P+12208|0);ae=Gc;break}else if((Ec|0)==16){Ea=P|0;qb=(c[Ea>>2]|0)*-3|0;c[Da>>2]=(c[Da>>2]|0)+qb;c[wb>>2]=(c[wb>>2]|0)+qb;if((Fc|0)==8){qVb(f,za);ae=((c[Ea>>2]|0)*3|0)+(c[Da>>2]|0)|0;break}else if((Fc|0)==12){qVb(f,yb);ae=((c[Ea>>2]|0)*3|0)+(c[wb>>2]|0)|0;break}else if((Fc|0)==16){qVb(f,P+496|0);qVb(f,P+6624|0);ae=Gc;break}else{ae=Gc;break}}else{ae=Gc;break}}}while(0);if((c[X>>2]|0)==0){be=Ec;ce=Fc;de=ae;ee=ae}else{fe=ae;la=657}}else{fe=Gc;la=657}if((la|0)==657){nUb(f,P,fe);Ea=c[Ba>>2]|0;qb=(Ea|0)<(cb|0);Yb=qb?Ea:cb;Ea=c[zb>>2]|0;fc=(Ea|0)<(Yb|0);hc=fc?Ea:Yb;Yb=c[P+12708>>2]|0;Ea=(Yb|0)<(hc|0);rb=Ea?Yb:hc;hc=c[P+12712>>2]|0;Yb=(hc|0)<(rb|0);pb=Yb?hc:rb;rb=c[P+12716>>2]|0;if((rb|0)<(pb|0)){ge=14;he=c[P+12744>>2]|0;ie=rb}else{ge=16;he=Yb?7:Ea?16:fc?12:qb?8:18;ie=pb}pb=c[P+12720>>2]|0;if((pb|0)<(ie|0)){je=15;ke=c[P+12748>>2]|0;le=pb}else{je=ge;ke=he;le=ie}pb=c[P+12724>>2]|0;qb=(pb|0)<(le|0);fc=qb?17:ke;Ea=qb?13:je;c[Ga>>2]=fc;c[f+19348>>2]=Ea;be=Ea;ce=fc;de=qb?pb:le;ee=fe}if((c[f+18636>>2]|0)==0){fUb(f,P,ee)}else{if((c[Jb>>2]|0)==3){fUb(f,P,ee);kUb(f,P)}else{kUb(f,P);fUb(f,P,ee-(c[T>>2]|0)|0)}pb=c[T>>2]|0;c[aa>>2]=(c[aa>>2]|0)+pb;c[$>>2]=(c[$>>2]|0)+pb;c[W>>2]=(c[W>>2]|0)+pb}if((c[X>>2]|0)==0){me=de;ne=0}else{do{if((c[f+524>>2]|0)==0){oe=ee;qe=de}else{if((c[f+8696>>2]|0)==0){oe=ee;qe=de;break}pb=f+19352|0;qb=c[pb>>2]|0;fc=c[Ga>>2]|0;if((fc|0)==5){c[pb>>2]=50529027}else{if((262064>>>(fc>>>0)&1|0)==0){oe=ee;qe=de;break}}lUb(f,P);c[Z>>2]=c[Z>>2]^1;fc=VTb(f,c[fa>>2]|0)|0;if((de|0)<(fc|0)){c[Z>>2]=c[Z>>2]^1;c[pb>>2]=qb;oe=ee;qe=de;break}if((de|0)<=0){oe=ee;qe=fc;break}qb=Erc(fc,(fc|0)<0|0?-1:0,ee,(ee|0)<0|0?-1:0)|0;pb=Crc(qb,G,de,(de|0)<0|0?-1:0)|0;oe=pb;qe=fc}}while(0);gUb(f,P,((oe*17|0|0)/16|0)+1|0);me=qe;ne=(c[X>>2]|0)>1}Jb=c[aa>>2]|0;zb=(Jb|0)<(me|0);Ba=zb?Jb:me;Jb=c[$>>2]|0;fc=(Jb|0)<(Ba|0);pb=fc?Jb:Ba;Ba=c[W>>2]|0;Jb=(Ba|0)<(pb|0);qb=Jb?Ba:pb;pb=c[ea>>2]|0;Ba=(pb|0)<(qb|0);Ea=Ba?pb:qb;qb=Ba?3:Jb?0:fc?1:zb?2:ce;c[Ga>>2]=qb;zb=f+19348|0;c[zb>>2]=be;if(ne&qb>>>0<3>>>0){hUb(f,P)}do{if((c[f+18632>>2]|0)>4){fc=c[Ga>>2]|0;if(fc>>>0<4>>>0){break}Jb=c[zb>>2]|0;if((Jb|0)==13){Ba=f+30412|0;if((a[f+19352|0]|0)==11){sVb(f,P+1280|0,P+7408|0,a[(c[P+7420>>2]|0)+((c[Ba>>2]|0)+(c[P+1292>>2]<<2))|0]|0)}if((a[f+19353|0]|0)==11){sVb(f,P+1408|0,P+7536|0,a[(c[P+7548>>2]|0)+((c[Ba>>2]|0)+(c[P+1420>>2]<<2))|0]|0)}if((a[f+19354|0]|0)==11){sVb(f,P+1536|0,P+7664|0,a[(c[P+7676>>2]|0)+((c[Ba>>2]|0)+(c[P+1548>>2]<<2))|0]|0)}if((a[f+19355|0]|0)!=11){break}sVb(f,P+1664|0,P+7792|0,a[(c[P+7804>>2]|0)+((c[Ba>>2]|0)+(c[P+1676>>2]<<2))|0]|0);break}else if((Jb|0)==15){Ba=f+30412|0;if((c[P+12736>>2]|0)==11){sVb(f,P+6224|0,P+12352|0,a[(c[P+12364>>2]|0)+((c[Ba>>2]|0)+(c[P+6236>>2]<<2))|0]|0)}if((c[P+12740>>2]|0)!=11){break}sVb(f,P+6352|0,P+12480|0,a[(c[P+12492>>2]|0)+((c[Ba>>2]|0)+(c[P+6364>>2]<<2))|0]|0);break}else if((Jb|0)==14){Ba=f+30412|0;if((c[P+12728>>2]|0)==11){sVb(f,P+5952|0,P+12080|0,a[(c[P+12092>>2]|0)+((c[Ba>>2]|0)+(c[P+5964>>2]<<2))|0]|0)}if((c[P+12732>>2]|0)!=11){break}sVb(f,P+6080|0,P+12208|0,a[(c[P+12220>>2]|0)+((c[Ba>>2]|0)+(c[P+6092>>2]<<2))|0]|0);break}else if((Jb|0)==16){if((fc|0)!=16){break}sVb(f,P+496|0,P+6624|0,a[(c[P+6636>>2]|0)+((c[f+30412>>2]|0)+(c[P+508>>2]<<2))|0]|0);break}else{break}}}while(0);if((c[X>>2]|0)<=1){break a}if(!((qb-8|0)>>>0<10>>>0)){break a}lUb(f,P);if((be|0)==13){zb=f+30412|0;Ga=0;while(1){fc=a[f+19352+Ga|0]|0;if((fc<<24>>24|0)==3){uVb(f,P+1280+(Ga<<7)|0,c[fa>>2]|0,Ga<<2,0)}else if((fc<<24>>24|0)==7){uVb(f,P+7408+(Ga<<7)|0,c[fa>>2]|0,Ga<<2,1)}else if((fc<<24>>24|0)==11){tVb(f,P+1280+(Ga<<7)|0,P+7408+(Ga<<7)|0,a[(c[P+7408+(Ga<<7)+12>>2]|0)+((c[zb>>2]|0)+(c[P+1280+(Ga<<7)+12>>2]<<2))|0]|0,Ga,c[fa>>2]|0)}Ga=Ga+1|0;if((Ga|0)>=4){break a}}}else if((be|0)==15){Ga=f+30412|0;zb=c[P+12736>>2]|0;fc=zb&255;a[f+19354|0]=fc;a[f+19352|0]=fc;if((zb|0)==3){uVb(f,P+6224|0,c[fa>>2]|0,0,0)}else if((zb|0)==7){uVb(f,P+12352|0,c[fa>>2]|0,0,1)}else if((zb|0)==11){tVb(f,P+6224|0,P+12352|0,a[(c[P+12364>>2]|0)+((c[Ga>>2]|0)+(c[P+6236>>2]<<2))|0]|0,0,c[fa>>2]|0)}zb=c[P+12740>>2]|0;fc=zb&255;a[f+19355|0]=fc;a[f+19353|0]=fc;if((zb|0)==11){tVb(f,P+6352|0,P+12480|0,a[(c[P+12492>>2]|0)+((c[Ga>>2]|0)+(c[P+6364>>2]<<2))|0]|0,1,c[fa>>2]|0);break a}else if((zb|0)==7){uVb(f,P+12480|0,c[fa>>2]|0,4,1);break a}else if((zb|0)==3){uVb(f,P+6352|0,c[fa>>2]|0,4,0);break a}else{break a}}else if((be|0)==14){zb=f+30412|0;Ga=c[P+12728>>2]|0;fc=Ga&255;a[f+19353|0]=fc;a[f+19352|0]=fc;if((Ga|0)==3){uVb(f,P+5952|0,c[fa>>2]|0,0,0)}else if((Ga|0)==7){uVb(f,P+12080|0,c[fa>>2]|0,0,1)}else if((Ga|0)==11){tVb(f,P+5952|0,P+12080|0,a[(c[P+12092>>2]|0)+((c[zb>>2]|0)+(c[P+5964>>2]<<2))|0]|0,0,c[fa>>2]|0)}Ga=c[P+12732>>2]|0;fc=Ga&255;a[f+19355|0]=fc;a[f+19354|0]=fc;if((Ga|0)==11){tVb(f,P+6080|0,P+12208|0,a[(c[P+12220>>2]|0)+((c[zb>>2]|0)+(c[P+6092>>2]<<2))|0]|0,2,c[fa>>2]|0);break a}else if((Ga|0)==7){uVb(f,P+12208|0,c[fa>>2]|0,8,1);break a}else if((Ga|0)==3){uVb(f,P+6080|0,c[fa>>2]|0,8,0);break a}else{break a}}else if((be|0)==16){if((qb|0)==8){c[Da>>2]=Ea;uVb(f,za,c[fa>>2]|0,0,0);break a}else if((qb|0)==12){c[wb>>2]=Ea;uVb(f,yb,c[fa>>2]|0,0,1);break a}else if((qb|0)==16){tVb(f,P+496|0,P+6624|0,a[(c[P+6636>>2]|0)+((c[f+30412>>2]|0)+(c[P+508>>2]<<2))|0]|0,0,c[fa>>2]|0);break a}else{break a}}else{break a}}}while(0);Fa=f+37516|0;pa=f+27916|0;ef[c[Fa>>2]&4095](c[f+24588+((c[na>>2]&3)<<2)>>2]|0,c[pa>>2]|0,0);Ga=P+40|0;c[Ga>>2]=0;zb=P+32|0;g:do{if((c[zb>>2]|0)==0){fc=c[f+15148>>2]|0;Jb=c[fc+12012>>2]|0;h:do{if((Jb|0)==0){la=118}else{Ba=c[f+18616>>2]|0;pb=Jb+Ba|0;Yb=a[pb]|0;if((Yb&1)==0){la=118;break}do{if((c[f+3260>>2]|0)==0){rb=c[f+15160>>2]|0;if(((c[fc+92>>2]|0)-(c[rb+92>>2]|0)|0)!=1){break}if((c[f+3576>>2]|0)!=0){break}if((d[(c[rb+2936>>2]|0)+Ba|0]|0)>(c[U>>2]|0)){break}c[f+19348>>2]=16;rb=f+19344|0;if((c[f+28756>>2]|0)==0){c[rb>>2]=6;break h}else{c[rb>>2]=4;c[P+380>>2]=0;c[P+480>>2]=0;break h}}}while(0);if((c[f+604>>2]|0)==0){la=118;break}a[pb]=Yb&-2;la=118}}while(0);do{if((la|0)==118){fc=f+1548|0;if((c[fc>>2]|0)>1){se=(b[f+28758>>1]|0)>(c[f+18720>>2]|0)}else{se=0}do{if((c[f+18660>>2]|0)==0){if((c[f+18612>>2]<<4|0)<(c[f+32>>2]|0)|se){la=122;break}ef[c[Fa>>2]&4095](c[f+24588+((c[na>>2]&3)<<2)>>2]|0,c[pa>>2]|0,1)}else{la=122}}while(0);if((la|0)==122){if((c[f+576>>2]|0)==0|se){ef[c[Fa>>2]&4095](c[f+24588+((c[na>>2]&3)<<2)>>2]|0,c[pa>>2]|0,1);break g}if((c[V>>2]|0)>2){c[Ga>>2]=1;ef[c[Fa>>2]&4095](c[f+24588+((c[na>>2]&3)<<2)>>2]|0,c[pa>>2]|0,1);break g}do{if((c[f+18880>>2]|0)!=6){if((c[f+18876>>2]|0)==6){break}if((c[f+18888>>2]|0)==6){break}if((c[f+18892>>2]|0)==6){break}ef[c[Fa>>2]&4095](c[f+24588+((c[na>>2]&3)<<2)>>2]|0,c[pa>>2]|0,1);break g}}while(0);Yb=(vMb(f,0)|0)==0;ef[c[Fa>>2]&4095](c[f+24588+((c[na>>2]&3)<<2)>>2]|0,c[pa>>2]|0,1);if(Yb){break g}}c[f+19344>>2]=6;c[f+19348>>2]=16;if((b[f+28758>>1]|0)<=(c[f+18720>>2]|0)){break}if((c[fc>>2]|0)==1){break}Cd(2391232,2574424,3138,2649440)}}while(0);Yb=f+24580|0;if((c[Yb>>2]|0)<=0){break a}pb=f+18616|0;Jb=0;while(1){c[(c[f+19008+(Jb<<2)>>2]|0)+(c[pb>>2]<<2)>>2]=0;Jb=Jb+1|0;if((Jb|0)>=(c[Yb>>2]|0)){break a}}}else{if((c[f+596>>2]|0)==0){Yb=(c[U>>2]|0)-(c[f+19388>>2]|0)|0;Jb=c[f+632>>2]|0;iUb(f,P,(Yb|0)>(Jb|0)?Yb:Jb);la=80;break a}else{ef[c[Fa>>2]&4095](c[f+24588+((c[na>>2]&3)<<2)>>2]|0,c[pa>>2]|0,1);break}}}while(0);na=f+520|0;Fa=c[na>>2]|0;Jb=c[P+8>>2]|0;Yb=c[f+1816+(Jb<<2)>>2]|0;pb=P+12|0;c[pb>>2]=Yb;qb=(c[f+3304>>2]|0)-1|0;if((qb|0)<0){te=0}else{te=(qb|0)>2?2:qb}qb=3038792+(Jb*198|0)+(te*66|0)|0;yb=P+16|0;c[yb>>2]=qb;Ea=(c[f+3308>>2]|0)-1|0;if((Ea|0)<0){ue=0}else{ue=(Ea|0)>2?2:Ea}c[P+20>>2]=3038792+(Jb*198|0)+(ue*66|0);Jb=L;c[O>>2]=2147483647;Ea=f+24580|0;wb=c[Ea>>2]|0;za=(c[_>>2]|0)!=0&(wb|0)>1?O:0;c[L>>2]=0;c[L+4>>2]=Yb;c[L+88>>2]=c[pa>>2];Yb=f+27920|0;c[L+92>>2]=c[Yb>>2];Ba=f+27924|0;c[L+96>>2]=c[Ba>>2];rb=f+24544|0;c[L+72>>2]=c[rb>>2];hc=f+24548|0;c[L+76>>2]=c[hc>>2];Ia=f+24552|0;c[L+80>>2]=c[Ia>>2];c[Da>>2]=2147483647;i:do{if((wb|0)>0){Bb=L+8|0;rd=L+20|0;qd=L+68|0;sb=L+24|0;Ca=L+28|0;Nb=L+32|0;Xb=f+8632|0;qa=L+36|0;ic=L+40|0;cc=L+44|0;jc=L+48|0;Zb=L+52|0;jd=L+56|0;sd=L+60|0;Ha=L+64|0;ya=L+84|0;od=L+16|0;mc=L+12|0;id=L+100|0;md=f+30436|0;xb=P+628|0;kd=L+112|0;ac=L+112|0;td=f+18616|0;Mb=L+108|0;Gb=L+104|0;Hc=P|0;Ob=f+28756|0;Kb=L+114|0;Wb=f+28758|0;Qb=f+37520|0;tb=P+368|0;_b=N|0;cd=0;Sb=2147483647;qc=qb;j:while(1){$b=e[qc+(cd<<1)>>1]|0;c[Bb>>2]=$b;c[O>>2]=Sb-$b;$b=c[f+24588+(cd*48|0)>>2]|0;c[rd>>2]=$b;c[qd>>2]=$b;c[sb>>2]=c[f+24588+(cd*48|0)+4>>2];c[Ca>>2]=c[f+24588+(cd*48|0)+8>>2];c[Nb>>2]=c[f+24588+(cd*48|0)+12>>2];$b=(c[Xb>>2]|0)==3;c[qa>>2]=c[f+24588+(cd*48|0)+16>>2];if($b){c[ic>>2]=c[f+24588+(cd*48|0)+20>>2];c[cc>>2]=c[f+24588+(cd*48|0)+24>>2];c[jc>>2]=c[f+24588+(cd*48|0)+28>>2];c[Zb>>2]=c[f+24588+(cd*48|0)+32>>2];c[jd>>2]=c[f+24588+(cd*48|0)+36>>2];c[sd>>2]=c[f+24588+(cd*48|0)+40>>2];c[Ha>>2]=c[f+24588+(cd*48|0)+44>>2]}c[ya>>2]=c[f+27788+(cd<<2)>>2];c[mc>>2]=cd;c[qd>>2]=c[f+27660+(cd<<2)>>2];c[od>>2]=f+3584+(cd*144|0);eQb(f,0,cd,id);if((c[md>>2]|0)==(cd|0)){c[kd>>2]=c[xb>>2];rVb(f,L,za)}else{hQb(f,0,cd,_b,M);oVb(f,L,_b,c[M>>2]|0,za)}c[(c[f+19008+(cd<<2)>>2]|0)+(c[td>>2]<<2)>>2]=c[ac>>2];$b=c[ac>>2]|0;c[P+628+(cd*20|0)>>2]=$b;do{if((cd|0)==0){if((c[Ga>>2]|0)==0){break}if(((c[Mb>>2]|0)-(c[Gb>>2]|0)|0)>=((c[Hc>>2]|0)*300|0|0)){break}vb=($b<<16>>16)-(b[Ob>>1]|0)|0;va=(b[Kb>>1]|0)-(b[Wb>>1]|0)|0;if((((va|0)>-1?va:-va|0)+((vb|0)>-1?vb:-vb|0)|0)>=2){break}if((vMb(f,0)|0)!=0){break j}}}while(0);$b=c[Bb>>2]|0;fc=(c[Mb>>2]|0)+$b|0;c[Mb>>2]=fc;c[O>>2]=(c[O>>2]|0)+$b;if((fc|0)<(c[Da>>2]|0)){Ee[c[Qb>>2]&511](tb,Jb,128)|0}fc=cd+1|0;if((fc|0)>=(c[Ea>>2]|0)){la=161;break i}cd=fc;Sb=c[O>>2]|0;qc=c[yb>>2]|0}c[f+19344>>2]=6;lUb(f,P);if((b[Wb>>1]|0)<=(c[f+18720>>2]|0)){break}if((c[f+1548>>2]|0)==1){break}Cd(2391232,2574424,1418,2649344)}else{la=161}}while(0);do{if((la|0)==161){Jb=P+380|0;re[c[25117]&1023](f+28116|0,c[Jb>>2]&255);do{if((b[P+482>>1]|0)>(c[f+18720>>2]|0)){if((c[f+1548>>2]|0)==1){break}Cd(2380256,2574424,1430,2649344)}}while(0);Wb=f+19344|0;c[Wb>>2]=4;Ga=c[X>>2]|0;if((Ga|0)==0){break}if((Ga|0)>1){ve=1}else{ve=(c[na>>2]|0)>>>5&1}k:do{if((c[f+572>>2]|0)==2){if((c[f+18656>>2]|0)==0){break}do{if((c[f+524>>2]|0)==0){if((c[Z>>2]|0)==0){break}ef[c[f+37620>>2]&4095](f+23280|0,c[rb>>2]|0,3034536);if((c[Z>>2]|0)!=0){break k}}else{ef[c[f+37620>>2]&4095](f+23280|0,c[rb>>2]|0,3034536)}}while(0);ef[c[f+37600>>2]&4095](f+23792|0,c[rb>>2]|0,3034536)}}while(0);do{if((c[f+18652>>2]|0)!=0){Ga=f+37524|0;re[c[Ga>>2]&1023](f+24320|0,72);if((ve|0)==0){break}re[c[Ga>>2]&1023](f+24416|0,128)}}while(0);if((c[Jb>>2]|0)!=0){break}Ga=c[P+480>>2]|0;if((Ga|0)!=(c[f+28756>>2]|0)){break}if((c[zb>>2]|0)!=0){break}c[f+19348>>2]=16;re[c[25137]&1023](f+28240|0,Ga);c[oa>>2]=VTb(f,c[fa>>2]|0)|0;if((c[f+19364>>2]|c[f+19360>>2]|0)!=0){break}c[Wb>>2]=6}}while(0);Ga=f+19344|0;if((c[Ga>>2]|0)==6){if((c[Ea>>2]|0)<=1){i=g;return}za=f+18616|0;qb=1;do{c[(c[f+19008+(qb<<2)>>2]|0)+(c[za>>2]<<2)>>2]=0;qb=qb+1|0;}while((qb|0)<(c[Ea>>2]|0));i=g;return}do{if((Fa&16|0)==0){we=4;xe=16;ye=c[Da>>2]|0;ze=P+368|0}else{if((c[f+568>>2]|0)==0){qb=c[P+380>>2]|0;za=(c[f+30436>>2]|0)==(qb|0)?0:qb;qb=f+152|0;if((za|c[qb>>2]|0)==0){Ae=0}else{Ae=e[(c[yb>>2]|0)+(za<<1)>>1]|0}wb=P+628+(za*20|0)|0;c[f+19348>>2]=13;c[wb>>2]=c[P+480>>2];qc=f+24588+(za*48|0)|0;Sb=f+24588+(za*48|0)+4|0;cd=f+24588+(za*48|0)+8|0;tb=f+24588+(za*48|0)+12|0;Qb=f+8632|0;Mb=f+24588+(za*48|0)+16|0;Bb=f+24588+(za*48|0)+20|0;Kb=f+24588+(za*48|0)+24|0;Ob=f+24588+(za*48|0)+28|0;Hc=f+24588+(za*48|0)+32|0;Gb=f+24588+(za*48|0)+36|0;ac=f+24588+(za*48|0)+40|0;td=f+24588+(za*48|0)+44|0;_b=f+27788+(za<<2)|0;xb=f+27660+(za<<2)|0;kd=f+3584+(za*144|0)|0;md=P|0;id=0;od=1;do{qd=P+1280+(id<<7)|0;mc=id&1;ya=id>>1;c[qd>>2]=3;c[P+1280+(id<<7)+8>>2]=Ae;c[P+1280+(id<<7)+4>>2]=c[pb>>2];Ha=c[pa>>2]|0;c[P+1280+(id<<7)+88>>2]=Ha;sd=c[Yb>>2]|0;c[P+1280+(id<<7)+92>>2]=sd;jd=c[Ba>>2]|0;c[P+1280+(id<<7)+96>>2]=jd;Zb=mc<<3;jc=ya<<3;c[P+1280+(id<<7)+72>>2]=(c[rb>>2]|0)+(Zb|ya<<7);cc=jc>>c[da>>2];ic=(cc<<4)+(Zb>>>((c[ba>>2]|0)>>>0))|0;c[P+1280+(id<<7)+76>>2]=(c[hc>>2]|0)+ic;c[P+1280+(id<<7)+80>>2]=(c[Ia>>2]|0)+ic;ic=(ca(Ha,jc)|0)+Zb|0;Ha=(c[qc>>2]|0)+ic|0;c[P+1280+(id<<7)+20>>2]=Ha;qa=P+1280+(id<<7)+68|0;c[qa>>2]=Ha;c[P+1280+(id<<7)+24>>2]=(c[Sb>>2]|0)+ic;c[P+1280+(id<<7)+28>>2]=(c[cd>>2]|0)+ic;c[P+1280+(id<<7)+32>>2]=(c[tb>>2]|0)+ic;if((c[Qb>>2]|0)==3){Ha=(ca(sd,jc)|0)+Zb|0;c[P+1280+(id<<7)+36>>2]=(c[Mb>>2]|0)+Ha;c[P+1280+(id<<7)+40>>2]=(c[Bb>>2]|0)+Ha;c[P+1280+(id<<7)+44>>2]=(c[Kb>>2]|0)+Ha;c[P+1280+(id<<7)+48>>2]=(c[Ob>>2]|0)+Ha;Ha=(ca(jd,jc)|0)+Zb|0;c[P+1280+(id<<7)+52>>2]=(c[Hc>>2]|0)+Ha;c[P+1280+(id<<7)+56>>2]=(c[Gb>>2]|0)+Ha;c[P+1280+(id<<7)+60>>2]=(c[ac>>2]|0)+Ha;c[P+1280+(id<<7)+64>>2]=(c[td>>2]|0)+Ha}else{Ha=(ca(cc,sd)|0)+Zb|0;c[P+1280+(id<<7)+36>>2]=(c[Mb>>2]|0)+Ha}c[P+1280+(id<<7)+84>>2]=(c[_b>>2]|0)+(ic<<1);c[P+1280+(id<<7)+12>>2]=za;c[qa>>2]=(c[xb>>2]|0)+ic;c[P+1280+(id<<7)+16>>2]=kd;dQb(f,0,id<<2,2,P+1280+(id<<7)+100|0);oVb(f,qd,wb,od,0);qd=P+1280+(id<<7)+112|0;re[c[25131]&1023](f+28192+((mc<<1|ya<<4|12)<<2)|0,c[qd>>2]|0);c[P+628+(za*20|0)+(od<<2)>>2]=c[qd>>2];od=od+1|0;qd=P+1280+(id<<7)+108|0;c[P+12636+(id<<2)>>2]=(c[qd>>2]|0)-(c[P+1280+(id<<7)+104>>2]|0);ya=(c[qd>>2]|0)+Ae|0;c[qd>>2]=ya;Be=(c[qb>>2]|0)==0;if(Be){la=240}else{if((c[na>>2]&32|0)!=0){la=240}}if((la|0)==240){la=0;c[qd>>2]=(c[md>>2]|0)+ya}id=id+1|0;}while((id|0)<4);id=(c[P+1516>>2]|0)+(c[P+1388>>2]|0)+(c[P+1644>>2]|0)+(c[P+1772>>2]|0)-(Be?0:Ae)|0;c[ma>>2]=id;md=f+19352|0;y=50529027;a[md]=y;y=y>>8;a[md+1|0]=y;y=y>>8;a[md+2|0]=y;y=y>>8;a[md+3|0]=y;Ce=id}else{id=K;md=(c[Ea>>2]|0)-1|0;c[f+19348>>2]=13;do{if((c[_>>2]|0)!=0&(md|0)>0){qb=c[P+380>>2]|0;if((qb|0)!=0){if((qb|0)!=(c[f+30436>>2]|0)){De=md;break}}if((c[f+18876>>2]|0)<=0){De=md;break}if((c[f+18880>>2]|0)<=0){De=md;break}qb=a[f+28107|0]|0;od=qb<<24>>24;if(qb<<24>>24>0){Fe=(od|0)==(c[f+30436>>2]|0)?0:od}else{Fe=0}od=a[f+28108|0]|0;if((od|0)>(Fe|0)){Ge=(od|0)==(c[f+30436>>2]|0)?Fe:od}else{Ge=Fe}od=a[f+28110|0]|0;if((od|0)>(Ge|0)){He=(od|0)==(c[f+30436>>2]|0)?Ge:od}else{He=Ge}od=a[f+28112|0]|0;if((od|0)>(He|0)){Ie=(od|0)==(c[f+30436>>2]|0)?He:od}else{Ie=He}od=a[f+28115|0]|0;if((od|0)>(Ie|0)){Je=(od|0)==(c[f+30436>>2]|0)?Ie:od}else{Je=Ie}od=a[f+28131|0]|0;if((od|0)<=(Je|0)){De=Je;break}De=(od|0)==(c[f+30436>>2]|0)?Je:od}else{De=md}}while(0);if((De|0)>=0){md=c[f+18616>>2]|0;od=0;do{c[P+628+(od*20|0)>>2]=c[(c[f+19008+(od<<2)>>2]|0)+(md<<2)>>2];od=od+1|0;}while((od|0)<=(De|0))}od=K|0;md=K+4|0;qb=K+88|0;za=K+92|0;wb=K+96|0;kd=K+72|0;xb=K+76|0;_b=K+80|0;Mb=f+30436|0;td=K+8|0;ac=K+20|0;Gb=K+68|0;Hc=K+24|0;Ob=K+28|0;Kb=K+32|0;Bb=f+8632|0;Qb=K+36|0;tb=K+40|0;cd=K+44|0;Sb=K+48|0;qc=K+52|0;Wb=K+56|0;Jb=K+60|0;ya=K+64|0;qd=K+84|0;mc=K+16|0;ic=K+12|0;qa=K+100|0;Ha=K+112|0;Zb=K+108|0;sd=f+37520|0;cc=f+152|0;jc=P|0;jd=0;while(1){Xb=jd&1;Nb=jd>>1;c[od>>2]=3;c[md>>2]=c[pb>>2];c[qb>>2]=c[pa>>2];c[za>>2]=c[Yb>>2];c[wb>>2]=c[Ba>>2];Ca=Xb<<3;sb=Nb<<3;c[kd>>2]=(c[rb>>2]|0)+(Ca|Nb<<7);rd=(sb>>c[da>>2]<<4)+(Ca>>>((c[ba>>2]|0)>>>0))|0;c[xb>>2]=(c[hc>>2]|0)+rd;c[_b>>2]=(c[Ia>>2]|0)+rd;rd=P+1280+(jd<<7)+108|0;c[rd>>2]=2147483647;fc=Xb<<1|Nb<<4|12;Nb=f+28104+fc|0;Xb=jd<<2;$b=jd+1|0;vb=P+628+($b<<2)|0;va=P+1280+(jd<<7)|0;Ub=0;while(1){if((Ub|0)>(De|0)){if((Ub|0)!=(c[Mb>>2]|0)){break}}c[td>>2]=e[(c[yb>>2]|0)+(Ub<<1)>>1]|0;Ja=(ca(c[qb>>2]|0,sb)|0)+Ca|0;Tb=(c[f+24588+(Ub*48|0)>>2]|0)+Ja|0;c[ac>>2]=Tb;c[Gb>>2]=Tb;c[Hc>>2]=(c[f+24588+(Ub*48|0)+4>>2]|0)+Ja;c[Ob>>2]=(c[f+24588+(Ub*48|0)+8>>2]|0)+Ja;c[Kb>>2]=(c[f+24588+(Ub*48|0)+12>>2]|0)+Ja;if((c[Bb>>2]|0)==3){Tb=(ca(c[za>>2]|0,sb)|0)+Ca|0;c[Qb>>2]=(c[f+24588+(Ub*48|0)+16>>2]|0)+Tb;c[tb>>2]=(c[f+24588+(Ub*48|0)+20>>2]|0)+Tb;c[cd>>2]=(c[f+24588+(Ub*48|0)+24>>2]|0)+Tb;c[Sb>>2]=(c[f+24588+(Ub*48|0)+28>>2]|0)+Tb;Tb=(ca(c[wb>>2]|0,sb)|0)+Ca|0;c[qc>>2]=(c[f+24588+(Ub*48|0)+32>>2]|0)+Tb;c[Wb>>2]=(c[f+24588+(Ub*48|0)+36>>2]|0)+Tb;c[Jb>>2]=(c[f+24588+(Ub*48|0)+40>>2]|0)+Tb;c[ya>>2]=(c[f+24588+(Ub*48|0)+44>>2]|0)+Tb}else{Tb=(ca(sb>>c[da>>2],c[za>>2]|0)|0)+Ca|0;c[Qb>>2]=(c[f+24588+(Ub*48|0)+16>>2]|0)+Tb}c[qd>>2]=(c[f+27788+(Ub<<2)>>2]|0)+(Ja<<1);c[ic>>2]=Ub;c[Gb>>2]=(c[f+27660+(Ub<<2)>>2]|0)+Ja;c[mc>>2]=f+3584+(Ub*144|0);re[c[25111]&1023](Nb,Ub&255);dQb(f,0,Xb,2,qa);if((c[Mb>>2]|0)==(Ub|0)){c[Ha>>2]=c[vb>>2];rVb(f,K,0)}else{oVb(f,K,P+628+(Ub*20|0)|0,$b,0)}Ja=(c[Zb>>2]|0)+(c[td>>2]|0)|0;c[Zb>>2]=Ja;c[P+628+(Ub*20|0)+($b<<2)>>2]=c[Ha>>2];if((Ja|0)<(c[rd>>2]|0)){Ee[c[sd>>2]&511](va,id,128)|0}if((Ub|0)==(De|0)){Ja=c[Mb>>2]|0;if((De|0)<(Ja|0)){Ub=Ja;continue}}Ub=Ub+1|0}re[c[25131]&1023](f+28192+(fc<<2)|0,c[P+1280+(jd<<7)+112>>2]|0);re[c[25111]&1023](Nb,c[P+1280+(jd<<7)+12>>2]&255);c[P+12636+(jd<<2)>>2]=(c[rd>>2]|0)-(c[P+1280+(jd<<7)+104>>2]|0)-(c[P+1280+(jd<<7)+8>>2]|0);Le=(c[cc>>2]|0)==0;if(Le){la=226}else{if((c[na>>2]&32|0)!=0){la=226}}if((la|0)==226){la=0;c[rd>>2]=(c[rd>>2]|0)+(c[jc>>2]|0)}if(($b|0)<4){jd=$b}else{break}}jd=(c[P+1516>>2]|0)+(c[P+1388>>2]|0)+(c[P+1644>>2]|0)+(c[P+1772>>2]|0)|0;c[ma>>2]=jd;do{if(Le){if((c[P+1420>>2]|c[P+1292>>2]|c[P+1548>>2]|c[P+1676>>2]|0)!=0){Me=jd;break}jc=jd-(e[c[yb>>2]>>1]<<2)|0;c[ma>>2]=jc;Me=jc}else{Me=jd}}while(0);jd=f+19352|0;y=50529027;a[jd]=y;y=y>>8;a[jd+1|0]=y;y=y>>8;a[jd+2|0]=y;y=y>>8;a[jd+3|0]=y;Ce=Me}jd=P+368|0;jc=c[Da>>2]|0;do{if((c[_>>2]|0)==0|(Ce|0)<(jc|0)){if((Fa&32|0)==0){Ne=5;Oe=13;Pe=Ce;Qe=Ce;break}cc=f+19348|0;Mb=f+8632|0;id=P|0;sd=f+18636|0;Ha=Ce;Zb=0;while(1){td=P+1280+(Zb<<7)+12|0;qa=c[td>>2]|0;mc=f+24588+(qa*48|0)|0;c[cc>>2]=13;Gb=Zb<<2;ic=f+24588+(qa*48|0)+4|0;qd=f+24588+(qa*48|0)+8|0;Qb=f+24588+(qa*48|0)+12|0;za=f+24588+(qa*48|0)+16|0;ya=f+24588+(qa*48|0)+20|0;Jb=f+24588+(qa*48|0)+24|0;Wb=f+24588+(qa*48|0)+28|0;qc=f+24588+(qa*48|0)+32|0;wb=f+24588+(qa*48|0)+36|0;Sb=f+24588+(qa*48|0)+40|0;cd=f+24588+(qa*48|0)+44|0;tb=f+27788+(qa<<2)|0;Bb=f+27660+(qa<<2)|0;Kb=f+3584+(qa*144|0)|0;Ob=P+1280+(Zb<<7)+112|0;Hc=0;do{ac=Hc+Gb|0;qb=d[1901576+ac|0]|0;_b=d[1901368+ac|0]|0;xb=P+1808+(Zb<<9)+(Hc<<7)|0;c[xb>>2]=6;c[P+1808+(Zb<<9)+(Hc<<7)+4>>2]=c[pb>>2];kd=c[pa>>2]|0;c[P+1808+(Zb<<9)+(Hc<<7)+88>>2]=kd;md=c[Yb>>2]|0;c[P+1808+(Zb<<9)+(Hc<<7)+92>>2]=md;od=c[Ba>>2]|0;c[P+1808+(Zb<<9)+(Hc<<7)+96>>2]=od;Ub=qb<<2;va=_b<<2;c[P+1808+(Zb<<9)+(Hc<<7)+72>>2]=(c[rb>>2]|0)+((_b<<6)+Ub);vb=va>>>((c[da>>2]|0)>>>0);Xb=(vb<<4)+(Ub>>>((c[ba>>2]|0)>>>0))|0;c[P+1808+(Zb<<9)+(Hc<<7)+76>>2]=(c[hc>>2]|0)+Xb;c[P+1808+(Zb<<9)+(Hc<<7)+80>>2]=(c[Ia>>2]|0)+Xb;Xb=(ca(kd,va)|0)+Ub|0;kd=(c[mc>>2]|0)+Xb|0;c[P+1808+(Zb<<9)+(Hc<<7)+20>>2]=kd;Ca=P+1808+(Zb<<9)+(Hc<<7)+68|0;c[Ca>>2]=kd;c[P+1808+(Zb<<9)+(Hc<<7)+24>>2]=(c[ic>>2]|0)+Xb;c[P+1808+(Zb<<9)+(Hc<<7)+28>>2]=(c[qd>>2]|0)+Xb;c[P+1808+(Zb<<9)+(Hc<<7)+32>>2]=(c[Qb>>2]|0)+Xb;if((c[Mb>>2]|0)==3){kd=(ca(md,va)|0)+Ub|0;c[P+1808+(Zb<<9)+(Hc<<7)+36>>2]=(c[za>>2]|0)+kd;c[P+1808+(Zb<<9)+(Hc<<7)+40>>2]=(c[ya>>2]|0)+kd;c[P+1808+(Zb<<9)+(Hc<<7)+44>>2]=(c[Jb>>2]|0)+kd;c[P+1808+(Zb<<9)+(Hc<<7)+48>>2]=(c[Wb>>2]|0)+kd;kd=(ca(od,va)|0)+Ub|0;c[P+1808+(Zb<<9)+(Hc<<7)+52>>2]=(c[qc>>2]|0)+kd;c[P+1808+(Zb<<9)+(Hc<<7)+56>>2]=(c[wb>>2]|0)+kd;c[P+1808+(Zb<<9)+(Hc<<7)+60>>2]=(c[Sb>>2]|0)+kd;c[P+1808+(Zb<<9)+(Hc<<7)+64>>2]=(c[cd>>2]|0)+kd}else{kd=(ca(vb,md)|0)+Ub|0;c[P+1808+(Zb<<9)+(Hc<<7)+36>>2]=(c[za>>2]|0)+kd}c[P+1808+(Zb<<9)+(Hc<<7)+84>>2]=(c[tb>>2]|0)+(Xb<<1);c[P+1808+(Zb<<9)+(Hc<<7)+12>>2]=qa;c[Ca>>2]=(c[Bb>>2]|0)+Xb;c[P+1808+(Zb<<9)+(Hc<<7)+16>>2]=Kb;dQb(f,0,ac,1,P+1808+(Zb<<9)+(Hc<<7)+100|0);oVb(f,xb,Ob,(Hc|0)==0|0,0);re[c[25128]&1023](f+28192+(qb+12+(_b<<3)<<2)|0,c[P+1808+(Zb<<9)+(Hc<<7)+112>>2]|0);Hc=Hc+1|0;}while((Hc|0)<4);Hc=(c[P+1808+(Zb<<9)+236>>2]|0)+(c[P+1808+(Zb<<9)+108>>2]|0)+(c[P+1808+(Zb<<9)+364>>2]|0)+(c[P+1808+(Zb<<9)+492>>2]|0)+(e[(c[yb>>2]|0)+(qa<<1)>>1]|0)+((c[id>>2]|0)*5|0)|0;Ob=P+1792+(Zb<<2)|0;c[Ob>>2]=Hc;if((c[sd>>2]|0)==0){Re=Hc}else{Hc=HUb(f,P,mc,Zb,6)|0;Kb=(c[Ob>>2]|0)+Hc|0;c[Ob>>2]=Kb;Re=Kb}if((c[_>>2]|0)==0){la=255}else{if((Re|0)<((c[P+1808+(Zb<<9)+232>>2]|0)+(c[P+1808+(Zb<<9)+360>>2]|0)+(c[P+1280+(Zb<<7)+108>>2]|0)|0)){la=255}else{Ue=Ha}}if((la|0)==255){la=0;Kb=f+19352+Zb|0;a[Kb]=0;Ob=c[td>>2]|0;Hc=f+24588+(Ob*48|0)|0;c[cc>>2]=13;Bb=f+24588+(Ob*48|0)+4|0;tb=f+24588+(Ob*48|0)+8|0;za=f+24588+(Ob*48|0)+12|0;cd=f+24588+(Ob*48|0)+16|0;Sb=f+24588+(Ob*48|0)+20|0;wb=f+24588+(Ob*48|0)+24|0;qc=f+24588+(Ob*48|0)+28|0;Wb=f+24588+(Ob*48|0)+32|0;Jb=f+24588+(Ob*48|0)+36|0;ya=f+24588+(Ob*48|0)+40|0;Qb=f+24588+(Ob*48|0)+44|0;qd=f+27788+(Ob<<2)|0;ic=f+27660+(Ob<<2)|0;_b=f+3584+(Ob*144|0)|0;qb=P+1808+(Zb<<9)+112|0;xb=0;do{ac=(xb<<1)+Gb|0;Xb=d[1901576+ac|0]|0;Ca=d[1901368+ac|0]|0;kd=P+3872+(Zb<<8)+(xb<<7)|0;c[kd>>2]=4;c[P+3872+(Zb<<8)+(xb<<7)+4>>2]=c[pb>>2];Ub=c[pa>>2]|0;c[P+3872+(Zb<<8)+(xb<<7)+88>>2]=Ub;md=c[Yb>>2]|0;c[P+3872+(Zb<<8)+(xb<<7)+92>>2]=md;vb=c[Ba>>2]|0;c[P+3872+(Zb<<8)+(xb<<7)+96>>2]=vb;va=Xb<<2;od=Ca<<2;c[P+3872+(Zb<<8)+(xb<<7)+72>>2]=(c[rb>>2]|0)+((Ca<<6)+va);sb=od>>>((c[da>>2]|0)>>>0);Ja=(sb<<4)+(va>>>((c[ba>>2]|0)>>>0))|0;c[P+3872+(Zb<<8)+(xb<<7)+76>>2]=(c[hc>>2]|0)+Ja;c[P+3872+(Zb<<8)+(xb<<7)+80>>2]=(c[Ia>>2]|0)+Ja;Ja=(ca(Ub,od)|0)+va|0;Ub=(c[Hc>>2]|0)+Ja|0;c[P+3872+(Zb<<8)+(xb<<7)+20>>2]=Ub;Tb=P+3872+(Zb<<8)+(xb<<7)+68|0;c[Tb>>2]=Ub;c[P+3872+(Zb<<8)+(xb<<7)+24>>2]=(c[Bb>>2]|0)+Ja;c[P+3872+(Zb<<8)+(xb<<7)+28>>2]=(c[tb>>2]|0)+Ja;c[P+3872+(Zb<<8)+(xb<<7)+32>>2]=(c[za>>2]|0)+Ja;if((c[Mb>>2]|0)==3){Ub=(ca(md,od)|0)+va|0;c[P+3872+(Zb<<8)+(xb<<7)+36>>2]=(c[cd>>2]|0)+Ub;c[P+3872+(Zb<<8)+(xb<<7)+40>>2]=(c[Sb>>2]|0)+Ub;c[P+3872+(Zb<<8)+(xb<<7)+44>>2]=(c[wb>>2]|0)+Ub;c[P+3872+(Zb<<8)+(xb<<7)+48>>2]=(c[qc>>2]|0)+Ub;Ub=(ca(vb,od)|0)+va|0;c[P+3872+(Zb<<8)+(xb<<7)+52>>2]=(c[Wb>>2]|0)+Ub;c[P+3872+(Zb<<8)+(xb<<7)+56>>2]=(c[Jb>>2]|0)+Ub;c[P+3872+(Zb<<8)+(xb<<7)+60>>2]=(c[ya>>2]|0)+Ub;c[P+3872+(Zb<<8)+(xb<<7)+64>>2]=(c[Qb>>2]|0)+Ub}else{Ub=(ca(sb,md)|0)+va|0;c[P+3872+(Zb<<8)+(xb<<7)+36>>2]=(c[cd>>2]|0)+Ub}c[P+3872+(Zb<<8)+(xb<<7)+84>>2]=(c[qd>>2]|0)+(Ja<<1);c[P+3872+(Zb<<8)+(xb<<7)+12>>2]=Ob;c[Tb>>2]=(c[ic>>2]|0)+Ja;c[P+3872+(Zb<<8)+(xb<<7)+16>>2]=_b;dQb(f,0,ac,2,P+3872+(Zb<<8)+(xb<<7)+100|0);oVb(f,kd,qb,(xb|0)==0|0,0);re[c[25129]&1023](f+28192+(Xb+12+(Ca<<3)<<2)|0,c[P+3872+(Zb<<8)+(xb<<7)+112>>2]|0);xb=xb+1|0;}while((xb|0)<2);xb=(c[P+3872+(Zb<<8)+236>>2]|0)+(c[P+3872+(Zb<<8)+108>>2]|0)+(e[(c[yb>>2]|0)+(Ob<<1)>>1]|0)+((c[id>>2]|0)*3|0)|0;_b=P+3856+(Zb<<2)|0;c[_b>>2]=xb;if((c[sd>>2]|0)==0){Ve=xb}else{xb=HUb(f,P,Hc,Zb,4)|0;ic=(c[_b>>2]|0)+xb|0;c[_b>>2]=ic;Ve=ic}if((Ve|0)<(Re|0)){a[Kb]=1;We=Ve}else{We=Re}ic=c[td>>2]|0;_b=f+24588+(ic*48|0)|0;c[cc>>2]=13;xb=f+24588+(ic*48|0)+4|0;qd=f+24588+(ic*48|0)+8|0;cd=f+24588+(ic*48|0)+12|0;Qb=f+24588+(ic*48|0)+16|0;ya=f+24588+(ic*48|0)+20|0;Jb=f+24588+(ic*48|0)+24|0;Wb=f+24588+(ic*48|0)+28|0;qc=f+24588+(ic*48|0)+32|0;wb=f+24588+(ic*48|0)+36|0;Sb=f+24588+(ic*48|0)+40|0;za=f+24588+(ic*48|0)+44|0;tb=f+27788+(ic<<2)|0;Bb=f+27660+(ic<<2)|0;mc=f+3584+(ic*144|0)|0;qa=0;do{Ca=qa+Gb|0;Xb=d[1901576+Ca|0]|0;kd=d[1901368+Ca|0]|0;ac=P+4912+(Zb<<8)+(qa<<7)|0;c[ac>>2]=5;c[P+4912+(Zb<<8)+(qa<<7)+4>>2]=c[pb>>2];Ja=c[pa>>2]|0;c[P+4912+(Zb<<8)+(qa<<7)+88>>2]=Ja;Tb=c[Yb>>2]|0;c[P+4912+(Zb<<8)+(qa<<7)+92>>2]=Tb;Ub=c[Ba>>2]|0;c[P+4912+(Zb<<8)+(qa<<7)+96>>2]=Ub;va=Xb<<2;md=kd<<2;c[P+4912+(Zb<<8)+(qa<<7)+72>>2]=(c[rb>>2]|0)+((kd<<6)+va);sb=md>>>((c[da>>2]|0)>>>0);od=(sb<<4)+(va>>>((c[ba>>2]|0)>>>0))|0;c[P+4912+(Zb<<8)+(qa<<7)+76>>2]=(c[hc>>2]|0)+od;c[P+4912+(Zb<<8)+(qa<<7)+80>>2]=(c[Ia>>2]|0)+od;od=(ca(Ja,md)|0)+va|0;Ja=(c[_b>>2]|0)+od|0;c[P+4912+(Zb<<8)+(qa<<7)+20>>2]=Ja;vb=P+4912+(Zb<<8)+(qa<<7)+68|0;c[vb>>2]=Ja;c[P+4912+(Zb<<8)+(qa<<7)+24>>2]=(c[xb>>2]|0)+od;c[P+4912+(Zb<<8)+(qa<<7)+28>>2]=(c[qd>>2]|0)+od;c[P+4912+(Zb<<8)+(qa<<7)+32>>2]=(c[cd>>2]|0)+od;if((c[Mb>>2]|0)==3){Ja=(ca(Tb,md)|0)+va|0;c[P+4912+(Zb<<8)+(qa<<7)+36>>2]=(c[Qb>>2]|0)+Ja;c[P+4912+(Zb<<8)+(qa<<7)+40>>2]=(c[ya>>2]|0)+Ja;c[P+4912+(Zb<<8)+(qa<<7)+44>>2]=(c[Jb>>2]|0)+Ja;c[P+4912+(Zb<<8)+(qa<<7)+48>>2]=(c[Wb>>2]|0)+Ja;Ja=(ca(Ub,md)|0)+va|0;c[P+4912+(Zb<<8)+(qa<<7)+52>>2]=(c[qc>>2]|0)+Ja;c[P+4912+(Zb<<8)+(qa<<7)+56>>2]=(c[wb>>2]|0)+Ja;c[P+4912+(Zb<<8)+(qa<<7)+60>>2]=(c[Sb>>2]|0)+Ja;c[P+4912+(Zb<<8)+(qa<<7)+64>>2]=(c[za>>2]|0)+Ja}else{Ja=(ca(sb,Tb)|0)+va|0;c[P+4912+(Zb<<8)+(qa<<7)+36>>2]=(c[Qb>>2]|0)+Ja}c[P+4912+(Zb<<8)+(qa<<7)+84>>2]=(c[tb>>2]|0)+(od<<1);c[P+4912+(Zb<<8)+(qa<<7)+12>>2]=ic;c[vb>>2]=(c[Bb>>2]|0)+od;c[P+4912+(Zb<<8)+(qa<<7)+16>>2]=mc;dQb(f,0,Ca,1,P+4912+(Zb<<8)+(qa<<7)+100|0);oVb(f,ac,qb,(qa|0)==0|0,0);re[c[25130]&1023](f+28192+(Xb+12+(kd<<3)<<2)|0,c[P+4912+(Zb<<8)+(qa<<7)+112>>2]|0);qa=qa+1|0;}while((qa|0)<2);qa=(c[P+4912+(Zb<<8)+236>>2]|0)+(c[P+4912+(Zb<<8)+108>>2]|0)+(e[(c[yb>>2]|0)+(ic<<1)>>1]|0)+((c[id>>2]|0)*3|0)|0;qb=P+4896+(Zb<<2)|0;c[qb>>2]=qa;if((c[sd>>2]|0)==0){Xe=qa}else{qa=HUb(f,P,_b,Zb,5)|0;mc=(c[qb>>2]|0)+qa|0;c[qb>>2]=mc;Xe=mc}if((Xe|0)<(We|0)){a[Kb]=2;Ye=Xe}else{Ye=We}Ue=Ye+Ha-(c[P+1280+(Zb<<7)+108>>2]|0)|0}jUb(f,P,Zb);mc=Zb+1|0;if((mc|0)<4){Ha=Ue;Zb=mc}else{break}}c[ma>>2]=Ue;Ne=5;Oe=13;Pe=Ue;Qe=Ue}else{Ne=4;Oe=16;Pe=jc;Qe=Ce}}while(0);jc=P+1512|0;Zb=c[P+1640>>2]|0;if((c[_>>2]|0)!=0){if((Qe|0)>=(Zb+(c[jc>>2]|0)+(c[Da>>2]|0)|0)){we=Ne;xe=Oe;ye=Pe;ze=jd;break}}Ha=P+1768|0;sd=P+1672|0;id=P+12648|0;Mb=P+12688|0;c[Mb>>2]=(c[id>>2]|0)+(c[P+12644>>2]|0)+(Zb+1+(c[P+1544>>2]|0)+(c[Ha>>2]|0)+(c[sd>>2]|0)>>1);Zb=H;cc=f+19348|0;c[cc>>2]=14;$b=J|0;rd=J+4|0;Nb=H|0;fc=H+4|0;mc=H+88|0;qb=H+92|0;qa=H+96|0;Bb=H+72|0;tb=H+76|0;Qb=H+80|0;za=H+8|0;Sb=I;wb=I|0;qc=I+4|0;Wb=I+8|0;Jb=H+20|0;ya=H+68|0;cd=H+24|0;qd=H+28|0;xb=H+32|0;Gb=f+8632|0;td=H+36|0;Hc=H+40|0;Ob=H+44|0;kd=H+48|0;Xb=H+52|0;ac=H+56|0;Ca=H+60|0;od=H+64|0;vb=H+84|0;Ja=H+16|0;va=H+12|0;Tb=H+100|0;sb=f+30436|0;md=H+108|0;Ub=f+37520|0;Pb=0;while(1){ub=Pb<<1;Rb=c[P+1280+(ub<<7)+12>>2]|0;bc=ub|1;Vb=c[P+1280+(bc<<7)+12>>2]|0;Lb=(Rb|0)<(Vb|0)?Rb:Vb;Ib=(Rb|0)>(Vb|0)?Rb:Vb;c[$b>>2]=Lb;c[rd>>2]=Ib;Vb=(Lb|0)==(Ib|0)?1:2;c[Nb>>2]=1;c[fc>>2]=c[pb>>2];Ib=c[pa>>2]|0;c[mc>>2]=Ib;c[qb>>2]=c[Yb>>2];c[qa>>2]=c[Ba>>2];Rb=Pb<<3;c[Bb>>2]=(c[rb>>2]|0)+(Pb<<7);oc=Rb>>c[da>>2]<<4;c[tb>>2]=(c[hc>>2]|0)+oc;c[Qb>>2]=(c[Ia>>2]|0)+oc;oc=P+5952+(Pb<<7)+108|0;c[oc>>2]=2147483647;Ka=ub+2|0;ub=Pb<<4|12;Hb=f+28104+ub|0;pc=P+5952+(Pb<<7)|0;lc=(Lb|0)!=0;uc=1;nc=Lb;Lb=Ib;while(1){c[za>>2]=e[(c[yb>>2]|0)+(nc<<1)>>1]|0;c[wb>>2]=c[P+628+(nc*20|0)>>2];c[qc>>2]=c[P+628+(nc*20|0)+(bc<<2)>>2];c[Wb>>2]=c[P+628+(nc*20|0)+(Ka<<2)>>2];Ib=ca(Lb,Rb)|0;ec=(c[f+24588+(nc*48|0)>>2]|0)+Ib|0;c[Jb>>2]=ec;c[ya>>2]=ec;c[cd>>2]=(c[f+24588+(nc*48|0)+4>>2]|0)+Ib;c[qd>>2]=(c[f+24588+(nc*48|0)+8>>2]|0)+Ib;c[xb>>2]=(c[f+24588+(nc*48|0)+12>>2]|0)+Ib;if((c[Gb>>2]|0)==3){ec=ca(c[qb>>2]|0,Rb)|0;c[td>>2]=(c[f+24588+(nc*48|0)+16>>2]|0)+ec;c[Hc>>2]=(c[f+24588+(nc*48|0)+20>>2]|0)+ec;c[Ob>>2]=(c[f+24588+(nc*48|0)+24>>2]|0)+ec;c[kd>>2]=(c[f+24588+(nc*48|0)+28>>2]|0)+ec;ec=ca(c[qa>>2]|0,Rb)|0;c[Xb>>2]=(c[f+24588+(nc*48|0)+32>>2]|0)+ec;c[ac>>2]=(c[f+24588+(nc*48|0)+36>>2]|0)+ec;c[Ca>>2]=(c[f+24588+(nc*48|0)+40>>2]|0)+ec;c[od>>2]=(c[f+24588+(nc*48|0)+44>>2]|0)+ec}else{ec=ca(Rb>>c[da>>2],c[qb>>2]|0)|0;c[td>>2]=(c[f+24588+(nc*48|0)+16>>2]|0)+ec}c[vb>>2]=(c[f+27788+(nc<<2)>>2]|0)+(Ib<<1);c[va>>2]=nc;c[ya>>2]=(c[f+27660+(nc<<2)>>2]|0)+Ib;c[Ja>>2]=f+3584+(nc*144|0);re[c[25113]&1023](Hb,nc&255);dQb(f,0,Rb,4,Tb);if((c[sb>>2]|0)!=(nc|0)|lc){oVb(f,H,Sb,3,0)}else{rVb(f,H,0)}Ib=(c[md>>2]|0)+(c[za>>2]|0)|0;c[md>>2]=Ib;if((Ib|0)<(c[oc>>2]|0)){Ee[c[Ub>>2]&511](pc,Zb,128)|0}if((uc|0)>=(Vb|0)){break}Ib=c[J+(uc<<2)>>2]|0;uc=uc+1|0;nc=Ib;Lb=c[mc>>2]|0}if((c[_>>2]|0)!=0&(Pb|0)==0){if(((c[Mb>>2]|0)+(c[oc>>2]|0)|0)>((ca((c[X>>2]|0)!=0|4,Pe)|0)/4|0|0)){Ze=268435456;break}}re[c[25133]&1023](f+28192+(ub<<2)|0,c[P+5952+(Pb<<7)+112>>2]|0);re[c[25113]&1023](Hb,c[P+5952+(Pb<<7)+12>>2]&255);Lb=Pb+1|0;if((Lb|0)<2){Pb=Lb}else{la=293;break}}if((la|0)==293){Ze=(c[P+6188>>2]|0)+(c[P+6060>>2]|0)|0}c[ra>>2]=Ze;Pb=(Ze|0)<(Pe|0);Mb=Pb?Ze:Pe;mc=Pb?14:Oe;Zb=Pb?4:Ne;Pb=P+12696|0;c[Pb>>2]=(c[id>>2]|0)+(c[P+12640>>2]|0)+((c[jc>>2]|0)+1+(c[P+1416>>2]|0)+(c[Ha>>2]|0)+(c[sd>>2]|0)>>1);md=F;c[cc>>2]=15;za=F|0;Tb=F+4|0;Ja=F+88|0;ya=F+92|0;va=F+96|0;vb=F+72|0;td=F+76|0;qb=F+80|0;od=F+8|0;Ca=F+20|0;ac=F+68|0;Xb=F+24|0;qa=F+28|0;kd=F+32|0;Ob=F+36|0;Hc=F+40|0;xb=F+44|0;qd=F+48|0;cd=F+52|0;Jb=F+56|0;Qb=F+60|0;tb=F+64|0;Bb=F+84|0;fc=F+16|0;Nb=F+12|0;Lb=F+100|0;nc=F+108|0;uc=0;while(1){Vb=c[P+1280+(uc<<7)+12>>2]|0;pc=c[P+1280+(uc+2<<7)+12>>2]|0;lc=(Vb|0)<(pc|0)?Vb:pc;Rb=(Vb|0)>(pc|0)?Vb:pc;c[$b>>2]=lc;c[rd>>2]=Rb;pc=(lc|0)==(Rb|0)?1:2;c[za>>2]=2;c[Tb>>2]=c[pb>>2];c[Ja>>2]=c[pa>>2];c[ya>>2]=c[Yb>>2];c[va>>2]=c[Ba>>2];Rb=uc<<3;c[vb>>2]=(c[rb>>2]|0)+Rb;Vb=Rb>>c[ba>>2];c[td>>2]=(c[hc>>2]|0)+Vb;c[qb>>2]=(c[Ia>>2]|0)+Vb;Vb=P+6224+(uc<<7)+108|0;c[Vb>>2]=2147483647;Ka=uc+1|0;bc=uc+3|0;Ib=(uc<<1)+12|0;ec=f+28104+Ib|0;kc=uc<<2;Fb=P+6224+(uc<<7)|0;Kc=(lc|0)!=0;Ic=1;Jc=lc;while(1){c[od>>2]=e[(c[yb>>2]|0)+(Jc<<1)>>1]|0;c[wb>>2]=c[P+628+(Jc*20|0)>>2];c[qc>>2]=c[P+628+(Jc*20|0)+(Ka<<2)>>2];c[Wb>>2]=c[P+628+(Jc*20|0)+(bc<<2)>>2];lc=(c[f+24588+(Jc*48|0)>>2]|0)+Rb|0;c[Ca>>2]=lc;c[ac>>2]=lc;c[Xb>>2]=(c[f+24588+(Jc*48|0)+4>>2]|0)+Rb;c[qa>>2]=(c[f+24588+(Jc*48|0)+8>>2]|0)+Rb;c[kd>>2]=(c[f+24588+(Jc*48|0)+12>>2]|0)+Rb;lc=(c[Gb>>2]|0)==3;c[Ob>>2]=(c[f+24588+(Jc*48|0)+16>>2]|0)+Rb;if(lc){c[Hc>>2]=(c[f+24588+(Jc*48|0)+20>>2]|0)+Rb;c[xb>>2]=(c[f+24588+(Jc*48|0)+24>>2]|0)+Rb;c[qd>>2]=(c[f+24588+(Jc*48|0)+28>>2]|0)+Rb;c[cd>>2]=(c[f+24588+(Jc*48|0)+32>>2]|0)+Rb;c[Jb>>2]=(c[f+24588+(Jc*48|0)+36>>2]|0)+Rb;c[Qb>>2]=(c[f+24588+(Jc*48|0)+40>>2]|0)+Rb;c[tb>>2]=(c[f+24588+(Jc*48|0)+44>>2]|0)+Rb}c[Bb>>2]=(c[f+27788+(Jc<<2)>>2]|0)+(Rb<<1);c[Nb>>2]=Jc;c[ac>>2]=(c[f+27660+(Jc<<2)>>2]|0)+Rb;c[fc>>2]=f+3584+(Jc*144|0);re[c[25115]&1023](ec,Jc&255);dQb(f,0,kc,2,Lb);if((c[sb>>2]|0)!=(Jc|0)|Kc){oVb(f,F,Sb,3,0)}else{rVb(f,F,0)}lc=(c[nc>>2]|0)+(c[od>>2]|0)|0;c[nc>>2]=lc;if((lc|0)<(c[Vb>>2]|0)){Ee[c[Ub>>2]&511](Fb,md,128)|0}if((Ic|0)>=(pc|0)){break}lc=c[J+(Ic<<2)>>2]|0;Ic=Ic+1|0;Jc=lc}if((c[_>>2]|0)!=0&(uc|0)==0){if(((c[Pb>>2]|0)+(c[Vb>>2]|0)|0)>((ca((c[X>>2]|0)!=0|4,Mb)|0)/4|0|0)){_e=268435456;break}}re[c[25135]&1023](f+28192+(Ib<<2)|0,c[P+6224+(uc<<7)+112>>2]|0);re[c[25115]&1023](ec,c[P+6224+(uc<<7)+12>>2]&255);if((Ka|0)<2){uc=Ka}else{la=308;break}}if((la|0)==308){_e=(c[P+6460>>2]|0)+(c[P+6332>>2]|0)|0}c[sa>>2]=_e;uc=(_e|0)<(Mb|0);we=uc?4:Zb;xe=uc?15:mc;ye=uc?_e:Mb;ze=jd}}while(0);yb=f+19348|0;c[yb>>2]=xe;do{if((c[X>>2]|0)==0){if((c[f+18632>>2]|0)==0){$e=ye;break}if((xe|0)==14){qVb(f,P+5952|0);qVb(f,P+6080|0);$e=(c[P+6188>>2]|0)+(c[P+6060>>2]|0)|0;break}else if((xe|0)==15){qVb(f,P+6224|0);qVb(f,P+6352|0);$e=(c[P+6460>>2]|0)+(c[P+6332>>2]|0)|0;break}else if((xe|0)==13){rb=0;Ba=0;while(1){Yb=d[f+19352+Ba|0]|0;if((Yb|0)==3){qVb(f,P+1280+(Ba<<7)|0);af=(c[P+1280+(Ba<<7)+108>>2]|0)+rb|0}else if((Yb|0)==1){qVb(f,P+3872+(Ba<<8)|0);qVb(f,P+3872+(Ba<<8)+128|0);af=(c[P+3872+(Ba<<8)+108>>2]|0)+rb+(c[P+3872+(Ba<<8)+236>>2]|0)|0}else if((Yb|0)==2){qVb(f,P+4912+(Ba<<8)|0);qVb(f,P+4912+(Ba<<8)+128|0);af=(c[P+4912+(Ba<<8)+108>>2]|0)+rb+(c[P+4912+(Ba<<8)+236>>2]|0)|0}else if((Yb|0)==0){qVb(f,P+1808+(Ba<<9)|0);qVb(f,P+1808+(Ba<<9)+128|0);qVb(f,P+1808+(Ba<<9)+256|0);qVb(f,P+1808+(Ba<<9)+384|0);af=(c[P+1808+(Ba<<9)+108>>2]|0)+rb+(c[P+1808+(Ba<<9)+236>>2]|0)+(c[P+1808+(Ba<<9)+364>>2]|0)+(c[P+1808+(Ba<<9)+492>>2]|0)|0}else{ILb(f,0,2433416,(Yb=i,i=i+1|0,i=i+7&-8,c[Yb>>2]=0,Yb)|0);i=Yb;af=rb}Yb=Ba+1|0;if((Yb|0)<4){rb=af;Ba=Yb}else{$e=af;break}}}else if((xe|0)==16){qVb(f,ze);$e=c[Da>>2]|0;break}else{$e=ye;break}}else{$e=ye}}while(0);if((c[f+18636>>2]|0)==0){fUb(f,P,$e);bf=c[aa>>2]|0;cf=c[$>>2]|0;df=c[W>>2]|0}else{if((c[f+8632>>2]|0)==3){fUb(f,P,$e);kUb(f,P)}else{kUb(f,P);fUb(f,P,$e-(c[T>>2]|0)|0)}Ba=c[T>>2]|0;rb=(c[aa>>2]|0)+Ba|0;c[aa>>2]=rb;jd=(c[$>>2]|0)+Ba|0;c[$>>2]=jd;Mb=(c[W>>2]|0)+Ba|0;c[W>>2]=Mb;bf=rb;cf=jd;df=Mb}Mb=(cf|0)<(df|0)?cf:df;jd=(bf|0)<(Mb|0)?bf:Mb;if((c[X>>2]|0)==0){ff=we;gf=xe;jf=$e;kf=bf;lf=cf;nf=df}else{Mb=($e|0)<(jd|0)?$e:jd;jd=(c[_>>2]|0)==0;if(jd){of=268435456}else{of=((Mb*5|0|0)/4|0)+1|0}c[Ga>>2]=4;do{if((c[oa>>2]|0)==268435456){if(!jd){if((c[Da>>2]|0)>((Mb*3|0|0)/2|0|0)){break}}c[yb>>2]=16;lUb(f,P);c[oa>>2]=VTb(f,c[fa>>2]|0)|0}}while(0);if((c[ra>>2]|0)<(of|0)){c[yb>>2]=14;lUb(f,P);pf=VTb(f,c[fa>>2]|0)|0}else{pf=268435456}c[ra>>2]=pf;if((c[sa>>2]|0)<(of|0)){c[yb>>2]=15;lUb(f,P);qf=VTb(f,c[fa>>2]|0)|0}else{qf=268435456}c[sa>>2]=qf;if((c[ma>>2]|0)<(of|0)){c[Ga>>2]=5;c[yb>>2]=13;if((c[na>>2]&32|0)==0){lUb(f,P)}else{re[c[25111]&1023](f+28116|0,c[P+1292>>2]&255);re[c[25111]&1023](f+28118|0,c[P+1420>>2]&255);re[c[25111]&1023](f+28132|0,c[P+1548>>2]&255);re[c[25111]&1023](f+28134|0,c[P+1676>>2]&255);Mb=0;do{jd=c[P+1792+(Mb<<2)>>2]|0;rb=c[P+3856+(Mb<<2)>>2]|0;Ba=c[P+4896+(Mb<<2)>>2]|0;mc=c[P+1280+(Mb<<7)+108>>2]|0;if((c[_>>2]|0)==0){rf=268435456}else{Zb=(Ba|0)<(mc|0)?Ba:mc;Yb=(rb|0)<(Zb|0)?rb:Zb;rf=(((jd|0)<(Yb|0)?jd:Yb)*5|0|0)/4|0}Yb=f+19352+Mb|0;Zb=Mb<<2;if((jd|0)>(rf|0)){sf=268435456;tf=0;uf=3}else{a[Yb]=0;jUb(f,P,Mb);jd=UTb(f,c[fa>>2]|0,Zb,3)|0;pa=G;pb=268435456;Fa=pa>>>0<pb>>>0|pa>>>0==pb>>>0&jd>>>0<0>>>0;sf=Fa?pa:268435456;tf=Fa?jd:0;uf=Fa?0:3}if((rb|0)>(rf|0)){vf=sf;wf=tf;xf=uf}else{a[Yb]=1;jUb(f,P,Mb);rb=UTb(f,c[fa>>2]|0,Zb,3)|0;Fa=G;jd=Fa>>>0<sf>>>0|Fa>>>0==sf>>>0&rb>>>0<tf>>>0;vf=jd?Fa:sf;wf=jd?rb:tf;xf=jd?1:uf}do{if((Ba|0)>(rf|0)){yf=vf;zf=wf;Af=xf}else{a[Yb]=2;jUb(f,P,Mb);if((xf|0)==2){yf=vf;zf=wf;Af=2;break}jd=UTb(f,c[fa>>2]|0,Zb,3)|0;rb=G;Fa=rb>>>0<vf>>>0|rb>>>0==vf>>>0&jd>>>0<wf>>>0;yf=Fa?rb:vf;zf=Fa?jd:wf;Af=Fa?2:xf}}while(0);do{if((mc|0)>(rf|0)){Bf=Af}else{a[Yb]=3;jUb(f,P,Mb);if((Af|0)==3){Bf=3;break}Ba=UTb(f,c[fa>>2]|0,Zb,3)|0;Fa=G;Bf=Fa>>>0<yf>>>0|Fa>>>0==yf>>>0&Ba>>>0<zf>>>0?3:Af}}while(0);if((d[Yb]|0)!=(Bf|0)){a[Yb]=Bf;jUb(f,P,Mb)}Mb=Mb+1|0;}while((Mb|0)<4)}Mb=VTb(f,c[fa>>2]|0)|0;Cf=Mb;Df=c[sa>>2]|0}else{Cf=268435456;Df=qf}c[ma>>2]=Cf;Mb=c[oa>>2]|0;na=c[ra>>2]|0;Zb=(na|0)<(Mb|0);mc=Zb?na:Mb;Mb=(Df|0)<(mc|0);na=Mb?Df:mc;mc=(Cf|0)<(na|0);Ba=mc?Cf:na;na=mc?13:Mb?15:Zb?14:16;Zb=mc?5:4;c[Ga>>2]=Zb;c[yb>>2]=na;do{if((Ba|0)<268435456){if((c[f+524>>2]|0)==0){Ef=$e;Ff=Ba;break}if((c[f+8696>>2]|0)==0){Ef=$e;Ff=Ba;break}Mb=f+19352|0;Fa=c[Mb>>2]|0;if(mc){c[Mb>>2]=50529027}else{if((262064>>>(Zb>>>0)&1|0)==0){Ef=$e;Ff=Ba;break}}lUb(f,P);c[Z>>2]=c[Z>>2]^1;jd=VTb(f,c[fa>>2]|0)|0;if((Ba|0)<(jd|0)){c[Z>>2]=c[Z>>2]^1;c[Mb>>2]=Fa;Ef=$e;Ff=Ba;break}if((Ba|0)<=0){Ef=$e;Ff=jd;break}Fa=Erc(jd,(jd|0)<0|0?-1:0,$e,($e|0)<0|0?-1:0)|0;Mb=Crc(Fa,G,Ba,(Ba|0)<0|0?-1:0)|0;Ef=Mb;Ff=jd}else{Ef=$e;Ff=Ba}}while(0);gUb(f,P,((Ef*5|0|0)/4|0)+1|0);ff=Zb;gf=na;jf=Ff;kf=c[aa>>2]|0;lf=c[$>>2]|0;nf=c[W>>2]|0}Ba=(kf|0)<(jf|0);mc=Ba?kf:jf;yb=(lf|0)<(mc|0);ra=yb?lf:mc;mc=(nf|0)<(ra|0);oa=mc?nf:ra;ra=mc?0:yb?1:Ba?2:ff;Ba=c[ea>>2]|0;do{if((Ba|0)<(oa|0)){c[Ga>>2]=3;Gf=Ba;Hf=3}else{c[Ga>>2]=ra;if((c[zb>>2]|0)==0|ra>>>0<4>>>0){Gf=oa;Hf=ra;break}lUb(f,P);uMb(f);yb=f+8632|0;mc=f+37436|0;ma=0;do{pe[c[mc>>2]&1023](c[f+24544+(ma<<2)>>2]|0,16,c[f+24568+(ma<<2)>>2]|0,32,16);ma=ma+1|0;If=(c[yb>>2]|0)==3;}while((ma|0)<((If?3:1)|0));if(!If){ma=16>>>((c[da>>2]|0)>>>0);yb=f+37448|0;pe[c[yb>>2]&1023](c[hc>>2]|0,16,c[f+24572>>2]|0,32,ma);pe[c[yb>>2]&1023](c[Ia>>2]|0,16,c[f+24576>>2]|0,32,ma)}ma=(c[U>>2]|0)-(c[f+19388>>2]|0)|0;yb=c[f+632>>2]|0;iUb(f,P,(ma|0)>(yb|0)?ma:yb);la=80;break a}}while(0);if((c[X>>2]|0)<=1){break}if((Hf|0)==3){break}else if((Hf|0)==0|(Hf|0)==1|(Hf|0)==2){hUb(f,P);break}if((gf|0)==16){re[c[25117]&1023](f+28116|0,c[P+380>>2]&255);c[Da>>2]=Gf;uVb(f,ze,c[fa>>2]|0,0,0);break}else if((gf|0)==14){Ia=f+19352|0;y=50529027;a[Ia]=y;y=y>>8;a[Ia+1|0]=y;y=y>>8;a[Ia+2|0]=y;y=y>>8;a[Ia+3|0]=y;re[c[25113]&1023](f+28116|0,c[P+5964>>2]&255);re[c[25113]&1023](f+28132|0,c[P+6092>>2]&255);uVb(f,P+5952|0,c[fa>>2]|0,0,0);uVb(f,P+6080|0,c[fa>>2]|0,8,0);break}else if((gf|0)==15){Ia=f+19352|0;y=50529027;a[Ia]=y;y=y>>8;a[Ia+1|0]=y;y=y>>8;a[Ia+2|0]=y;y=y>>8;a[Ia+3|0]=y;re[c[25115]&1023](f+28116|0,c[P+6236>>2]&255);re[c[25115]&1023](f+28118|0,c[P+6364>>2]&255);uVb(f,P+6224|0,c[fa>>2]|0,0,0);uVb(f,P+6352|0,c[fa>>2]|0,4,0);break}else if((gf|0)==13){lUb(f,P);Ia=0;do{hc=a[f+19352+Ia|0]|0;if((hc<<24>>24|0)==3){uVb(f,P+1280+(Ia<<7)|0,c[fa>>2]|0,Ia<<2,0)}else if((hc<<24>>24|0)==1){ra=Ia<<2;uVb(f,P+3872+(Ia<<8)|0,c[fa>>2]|0,ra,0);uVb(f,P+3872+(Ia<<8)+128|0,c[fa>>2]|0,ra|2,0)}else if((hc<<24>>24|0)==2){ra=Ia<<2;uVb(f,P+4912+(Ia<<8)|0,c[fa>>2]|0,ra,0);uVb(f,P+4912+(Ia<<8)+128|0,c[fa>>2]|0,ra|1,0)}else if((hc<<24>>24|0)==0){hc=Ia<<2;uVb(f,P+1808+(Ia<<9)|0,c[fa>>2]|0,hc,0);uVb(f,P+1808+(Ia<<9)+128|0,c[fa>>2]|0,hc|1,0);uVb(f,P+1808+(Ia<<9)+256|0,c[fa>>2]|0,hc|2,0);uVb(f,P+1808+(Ia<<9)+384|0,c[fa>>2]|0,hc|3,0)}Ia=Ia+1|0;}while((Ia|0)<4)}else{break}}}while(0);do{if((la|0)==80){gf=c[X>>2]|0;do{if((gf|0)!=0){ze=(gf|0)>1;l:do{if((c[f+572>>2]|0)==2){if((c[f+18656>>2]|0)==0){break}do{if((c[f+524>>2]|0)==0){if((c[Z>>2]|0)==0){Jf=f+24544|0;break}else{Gf=f+24544|0;ef[c[f+37620>>2]&4095](f+23280|0,c[Gf>>2]|0,3034536);if((c[Z>>2]|0)==0){Jf=Gf;break}else{break l}}}else{Gf=f+24544|0;ef[c[f+37620>>2]&4095](f+23280|0,c[Gf>>2]|0,3034536);Jf=Gf}}while(0);ef[c[f+37600>>2]&4095](f+23792|0,c[Jf>>2]|0,3034536)}}while(0);if((c[f+18652>>2]|0)==0){break}Ka=f+37524|0;re[c[Ka>>2]&1023](f+24320|0,72);if(!ze){break}re[c[Ka>>2]&1023](f+24416|0,128)}}while(0);fUb(f,P,268435456);if((c[X>>2]|0)!=0){gUb(f,P,268435456)}gf=c[aa>>2]|0;Ka=f+19344|0;c[Ka>>2]=2;ec=c[W>>2]|0;if((ec|0)<(gf|0)){c[Ka>>2]=0;Kf=ec}else{Kf=gf}gf=c[$>>2]|0;if((gf|0)<(Kf|0)){c[Ka>>2]=1;Lf=gf}else{Lf=Kf}if((c[ea>>2]|0)<(Lf|0)){c[Ka>>2]=3;break}if((c[X>>2]|0)<=1){break}hUb(f,P)}}while(0);lUb(f,P);P=c[X>>2]|0;do{if((P|0)>1){Lf=c[f+19344>>2]|0;ea=(d[95496+Lf|0]|0)-1|0;if((4368>>>(Lf>>>0)&1|0)==0){Mf=P;la=748;break}Lf=f+19348|0;if((c[Lf>>2]|0)==16){la=731;break}if((c[f+28192+(ea*160|0)+48>>2]|0)!=(c[f+28192+(ea*160|0)+120>>2]|0)){la=731;break}if((a[f+28104+(ea*40|0)+12|0]|0)!=(a[f+28104+(ea*40|0)+30|0]|0)){la=731;break}c[Lf>>2]=16;la=731}else{la=731}}while(0);do{if((la|0)==731){if((P|0)!=0){Mf=P;la=748;break}if((c[f+8696>>2]|0)==0){break}Lf=c[f+19344>>2]|0;if((Lf|0)==5){Nf=(c[f+19352>>2]|0)==50529027|0}else{Nf=d[17936+Lf|0]|0}if((Nf|0)==0){break}if((c[f+524>>2]|0)==0){break}if((c[ha>>2]|0)!=0){break}YOb(f);if((c[f+8632>>2]|0)==3){Of=(c[f+18636>>2]|0)!=0?3:1}else{Of=1}Lf=f+37076|0;ea=c[Lf>>2]|0;do{if((ea|0)==0){Kf=f+36868|0;$=f+36808|0;W=0;aa=0;Jf=0;while(1){Ka=f+24544+(Jf<<2)|0;gf=f+24568+(Jf<<2)|0;ec=(hf[c[Kf>>2]&1023](c[Ka>>2]|0,16,c[gf>>2]|0,32)|0)+W|0;Ib=(hf[c[$>>2]&1023](c[Ka>>2]|0,16,c[gf>>2]|0,32)|0)+aa|0;gf=Jf+1|0;if((gf|0)<(Of|0)){W=ec;aa=Ib;Jf=gf}else{Pf=Ib;Qf=ec;break}}}else{Jf=hf[ea&1023](c[f+24544>>2]|0,16,c[f+24568>>2]|0,32)|0;aa=G;if((Of|0)==1){Pf=aa;Qf=Jf;break}else{Rf=aa;Sf=Jf;Tf=1}do{Jf=hf[c[Lf>>2]&1023](c[f+24544+(Tf<<2)>>2]|0,16,c[f+24568+(Tf<<2)>>2]|0,32)|0;Sf=wrc(Jf,G,Sf,Rf)|0;Rf=G;Tf=Tf+1|0;}while((Tf|0)<(Of|0));Pf=Rf;Qf=Sf}}while(0);c[Z>>2]=(Qf|0)<(Pf|0);c[f+19380>>2]=1;Mf=c[X>>2]|0;la=748}}while(0);do{if((la|0)==748){if((Mf|0)!=3){break}X=f+19344|0;Pf=c[X>>2]|0;if((Pf|0)==6|(Pf|0)==18){break}Pf=c[U>>2]|0;Qf=VTb(f,c[fa>>2]|0)|0;Sf=f+18616|0;Rf=f+18968|0;Of=(b[(c[Rf>>2]|0)+(c[Sf>>2]<<1)>>1]|0)!=0;Tf=f+18652|0;ha=f+28824|0;Nf=f+636|0;P=f+632|0;Lf=f+3216|0;ea=f+28820|0;Jf=Pf;aa=0;W=Qf;$=Of?1:-1;while(1){Kf=(c[Tf>>2]|0)!=0;ze=c[ha>>2]|0;ec=($|0)==-1;if((ze|0)<(Pf|0)&ec){la=753}else{if((ze|0)>(Pf|0)&($|0)==1){la=753}else{Uf=Kf&1}}if((la|0)==753){la=0;Uf=Kf?2:1}c[U>>2]=Pf;if(Of|ec^1){Vf=268435456;Wf=-1}else{ec=Pf-Uf-1|0;Kf=c[P>>2]|0;ze=(Kf|0)<51?Kf:51;Kf=(ec|0)>(ze|0)?ec:ze;c[U>>2]=Kf;c[ea>>2]=d[(c[Lf>>2]|0)+Kf|0]|0;Kf=VTb(f,c[fa>>2]|0)|0;if((b[(c[Rf>>2]|0)+(c[Sf>>2]<<1)>>1]|0)==0){la=756;break}ze=c[U>>2]|0;c[U>>2]=Pf;Vf=Kf;Wf=ze}ze=$+Pf|0;c[U>>2]=ze;m:do{if((ze|0)<(c[P>>2]|0)){Xf=W;Yf=aa;Zf=Jf;la=769}else{Kf=($|0)==1;ec=Qf;Ib=1;gf=Jf;Ka=aa;Vb=W;Gf=ze;while(1){Hf=c[Nf>>2]|0;if((Gf|0)>(((Hf|0)<51?Hf:51)|0)){Xf=Vb;Yf=Ka;Zf=gf;la=769;break m}Hf=(c[ha>>2]|0)==(Gf|0)?1:Ka;do{if((Gf|0)==(Wf|0)){_f=Vb;$f=gf;ag=Vf}else{c[ea>>2]=d[(c[Lf>>2]|0)+Gf|0]|0;da=VTb(f,c[fa>>2]|0)|0;if((da|0)>=(Vb|0)){_f=Vb;$f=gf;ag=da;break}_f=da;$f=c[U>>2]|0;ag=da}}while(0);Kb=(ag|0)<(ec|0)?0:Ib;if((Kb|0)>(Uf|0)){Xf=_f;Yf=Hf;Zf=$f;la=769;break m}if(Kf){if((b[(c[Rf>>2]|0)+(c[Sf>>2]<<1)>>1]|0)==0){bg=$f;cg=Hf;dg=_f;break m}}_b=(c[U>>2]|0)+$|0;c[U>>2]=_b;if((_b|0)<(c[P>>2]|0)){Xf=_f;Yf=Hf;Zf=$f;la=769;break m}ec=ag;Ib=Kb+1|0;gf=$f;Ka=Hf;Vb=_f;Gf=_b}}}while(0);if((la|0)==769){la=0;if(($|0)>0){bg=Zf;cg=Yf;dg=Xf}else{eg=Yf;fg=Zf;gg=Xf;break}}Jf=bg;aa=cg;W=dg;$=$-2|0}if((la|0)==756){eg=(c[ha>>2]|0)>(c[U>>2]|0)?1:aa;fg=Jf;gg=W}do{if((eg|0)==0){$=c[ha>>2]|0;c[U>>2]=$;c[ea>>2]=d[(c[Lf>>2]|0)+$|0]|0;$=VTb(f,c[fa>>2]|0)|0;if(($|0)>=(gg|0)){hg=gg;ig=fg;break}hg=$;ig=c[U>>2]|0}else{hg=gg;ig=fg}}while(0);c[U>>2]=ig;c[ea>>2]=d[(c[Lf>>2]|0)+ig|0]|0;if((ig|0)==(Pf|0)){break}if((c[f+524>>2]|0)==0){break}if((c[f+8696>>2]|0)==0){break}ha=c[X>>2]|0;if((ha|0)==5){jg=(c[f+19352>>2]|0)==50529027|0}else{jg=d[17936+ha|0]|0}if((jg|0)==0){break}c[Z>>2]=c[Z>>2]^1;if((VTb(f,c[fa>>2]|0)|0)<=(hg|0)){break}c[Z>>2]=c[Z>>2]^1}}while(0);hg=c[f+572>>2]|0;fa=f+18640|0;c[fa>>2]=hg;jg=f+18644|0;do{if((c[jg>>2]|0)==0){if((c[f+584>>2]|0)==0){kg=0;break}ig=c[f+19344>>2]|0;if(ig>>>0<3>>>0){kg=0;break}kg=(ig|0)!=3|0}else{kg=1}}while(0);c[jg>>2]=kg;kg=c[f+19344>>2]|0;do{if(!((kg|0)==6|(kg|0)==18)){if(!((c[f+18656>>2]|0)!=0&(hg|0)==1)){break}if((c[Z>>2]|0)==0){lg=f+24544|0}else{ig=f+24544|0;ef[c[f+37620>>2]&4095](f+23280|0,c[ig>>2]|0,3034536);if((c[Z>>2]|0)==0){lg=ig}else{break}}ef[c[f+37600>>2]&4095](f+23792|0,c[lg>>2]|0,3034536)}}while(0);do{if((c[fa>>2]|0)!=1){if((c[jg>>2]|0)!=0){break}i=g;return}}while(0);c[ja>>2]=0;i=g;return}function fUb(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;j=i;i=i+376|0;k=j|0;l=j+160|0;m=j+224|0;n=j+296|0;o=j+336|0;p=f+3240|0;q=c[((c[p>>2]|0)==2?f+516|0:f+520|0)>>2]|0;r=f+24544|0;s=c[r>>2]|0;t=f+24568|0;u=c[t>>2]|0;v=c[g>>2]|0;do{if((c[f+136>>2]|0)==0){w=c[f+18868>>2]|0;x=(w&11|0)==11;y=1078584+((x?4:w&3)*5|0)|0;if((c[g+28>>2]|0)==0){z=268435456}else{z=(ca(d[95432+(c[f+18632>>2]|0)|0]|0,h)|0)>>1}w=f+28836|0;A=c[w>>2]|0;a:do{if((A|0)!=0|x^1){B=f+36884|0;C=g+44|0;D=g+76|0;E=y;F=a[y]|0;G=A;while(1){H=F<<24>>24;if((G|0)==0){qe[c[f+36532+(H<<2)>>2]&1023](u)}else{tMb(f,0,H)}I=hf[c[B>>2]&1023](u,32,s,16)|0;J=(ca(d[(d[95184+H|0]|0)+16465|0]|0,v)|0)+I|0;if((J|0)<(c[C>>2]|0)){c[C>>2]=J;c[D>>2]=H}c[g+48+(H<<2)>>2]=J;J=E+1|0;H=a[J]|0;if(!(H<<24>>24>-1)){break a}E=J;F=H;G=c[w>>2]|0}}else{G=g+48|0;ef[c[f+37280>>2]&4095](s,u,G);F=(c[G>>2]|0)+v|0;c[G>>2]=F;G=v*3|0;E=g+52|0;D=(c[E>>2]|0)+G|0;c[E>>2]=D;E=g+56|0;C=(c[E>>2]|0)+G|0;c[E>>2]=C;E=g+44|0;G=c[E>>2]|0;if((F|0)<(G|0)){c[E>>2]=F;c[g+76>>2]=0;K=F}else{K=G}if((D|0)<(K|0)){c[E>>2]=D;c[g+76>>2]=1;L=D}else{L=K}if((C|0)<(L|0)){c[E>>2]=C;c[g+76>>2]=2;M=C}else{M=L}if((M|0)>(z|0)){break}qe[c[f+36544>>2]&1023](u);C=(hf[c[f+36884>>2]&1023](u,32,s,16)|0)+(v*5|0)|0;c[g+60>>2]=C;if((C|0)>=(c[E>>2]|0)){break}c[E>>2]=C;c[g+76>>2]=3}}while(0);if((c[p>>2]|0)==1){w=g+44|0;A=(c[w>>2]|0)+(v*9|0)|0;c[w>>2]=A;N=A}else{N=c[g+44>>2]|0}if((N|0)<=(z|0)){break}i=j;return}}while(0);z=g+8|0;N=c[z>>2]<<5|8;do{if((q&2|0)!=0){M=m+31&-32;L=c[((c[f+36884>>2]|0)==(c[f+36808>>2]|0)?f+36880|0:f+36896|0)>>2]|0;K=g+24|0;if((c[K>>2]|0)==0){A=c[g+44>>2]|0;O=(A|0)>(h|0)?h:A}else{O=268435456}A=v<<2;w=f+19360|0;c[w>>2]=0;if((c[p>>2]|0)==1){P=A+(v*9|0)|0}else{P=A}y=g+36|0;x=f+36740|0;C=f+37364|0;E=f+28836|0;D=f+37340|0;G=n|0;F=n+4|0;B=v*-3|0;H=g+28|0;J=v*3|0;I=k+31&-32;Q=f+37612|0;R=f+18644|0;S=f+18640|0;T=f+37712|0;U=f+1732|0;V=f+1764|0;W=f+37640|0;X=f+37732|0;Y=f+1668|0;Z=f+37616|0;_=f+37760|0;$=f+33820|0;aa=f+33816|0;ba=f+37648|0;da=0;ea=P;b:while(1){fa=da&1;ga=da>>1;ha=fa<<3;ia=ga<<7;ja=s+(ha|ia)|0;ka=ga<<8;la=u+(ha|ka)|0;ha=d[19112+(da<<2)|0]|0;ma=a[(a[ha-1+(f+27936)|0]|0)+95137|0]|0;na=a[(a[ha-8+(f+27936)|0]|0)+95137|0]|0;oa=ma<<24>>24<na<<24>>24?ma:na;na=oa<<24>>24<0?2:oa<<24>>24;oa=c[f+18788+(da<<2)>>2]|0;ma=(c[y>>2]|0)==0?0:fa;pa=(oa&11|0)==11?4:oa&3;qa=1078376+(ma*50|0)+(pa*10|0)|0;mf[c[x>>2]&2047](la,M,oa,15);oa=c[C>>2]|0;do{if((oa|0)==0){ra=36}else{if(!((a[1078376+(ma*50|0)+(pa*10|0)+8|0]|0)>-1)){ra=36;break}sa=Xe[oa&511](ja,la,M,(3052719&-64)+(N-na<<1)|0,g+96+(da<<5)|0)|0;ta=(sa&65535)+ea|0;ua=sa>>16;c[g+224+(da<<2)>>2]=ua;if((da|0)==3|(ta|0)>(O|0)){va=ta;break b}sa=ga<<4|fa<<1|12;wa=(ua*257|0)&65535;b[f+27936+sa>>1]=wa;b[sa+8+(f+27936)>>1]=wa;xa=ta}}while(0);if((ra|0)==36){ra=0;do{if((c[E>>2]|0)==0){if(!((a[1078376+(ma*50|0)+(pa*10|0)+5|0]|0)>-1)){ya=268435456;za=qa;break}ef[c[D>>2]&4095](ja,M,G);oa=(c[F>>2]|0)>(c[G>>2]|0);ta=n+(na<<2)|0;c[ta>>2]=(c[ta>>2]|0)+B;ta=g+224+(da<<2)|0;wa=c[n+8>>2]|0;b[g+96+(da<<5)+4>>1]=wa+A;if((wa|0)<268435456){c[ta>>2]=2;Aa=wa}else{Aa=268435456}wa=c[F>>2]|0;b[g+96+(da<<5)+2>>1]=wa+A;if((wa|0)<(Aa|0)){c[ta>>2]=1;Ba=wa}else{Ba=Aa}wa=c[G>>2]|0;b[g+96+(da<<5)>>1]=wa+A;if((wa|0)<(Ba|0)){c[ta>>2]=0;Ca=wa}else{Ca=Ba}if((c[K>>2]|0)<((c[H>>2]|0)+1|0)){ya=Ca;za=95376+((c[y>>2]|0)*20|0)+(((d[1078376+(ma*50|0)+(pa*10|0)+8|0]|0)>>>7&255^1)*10|0)+((oa&1)*5|0)|0;break}else{ya=Ca;za=1078376+(ma*50|0)+(pa*10|0)+3|0;break}}else{ya=268435456;za=qa}}while(0);qa=a[za]|0;c:do{if(qa<<24>>24>-1){pa=g+224+(da<<2)|0;ma=za;oa=ya;wa=qa;while(1){if(!((oa|0)>-1)){if((c[K>>2]|0)<=1){Da=oa;break c}}ta=wa<<24>>24;if((c[E>>2]|0)==0){re[c[f+36560+(ta<<2)>>2]&1023](la,M)}else{sMb(f,la,0,da,ta,M)}sa=hf[L&1023](la,32,ja,16)|0;ua=sa+((na|0)==(a[ta+95137|0]|0)?B:0)|0;if((ua|0)<(oa|0)){c[pa>>2]=ta;Ea=ua}else{Ea=oa}b[g+96+(da<<5)+(ta<<1)>>1]=ua+A;ua=ma+1|0;ta=a[ua]|0;if(ta<<24>>24>-1){ma=ua;oa=Ea;wa=ta}else{Da=Ea;break}}}else{Da=ya}}while(0);na=ea+J+Da|0;if((da|0)==3|(na|0)>(O|0)){va=na;break}ja=g+224+(da<<2)|0;qa=c[ja>>2]|0;if((c[E>>2]|0)==0){re[c[f+36560+(qa<<2)>>2]&1023](la,M)}else{sMb(f,la,0,da,qa,M)}qa=ga<<4|fa<<1|12;wa=((c[ja>>2]|0)*257|0)&65535;b[f+27936+qa>>1]=wa;b[qa+8+(f+27936)>>1]=wa;xa=na}na=c[z>>2]|0;wa=da<<3&8;qa=(c[r>>2]|0)+(wa|ia)|0;ja=(c[t>>2]|0)+(wa|ka)|0;do{if((c[E>>2]|0)==0){ef[c[Q>>2]&4095](I,qa,ja);if((c[R>>2]|0)!=0){mf[c[_>>2]&2047](I,(c[$>>2]|0)+256|0,(c[aa>>2]|0)+128|0,64)}if((c[S>>2]|0)==0){Fa=Ee[c[T>>2]&511](I,(c[U>>2]|0)+(na<<7)|0,(c[V>>2]|0)+(na<<7)|0)|0}else{Fa=$Tb(f,I,0,na,5,1,0,da)|0}if((Fa|0)==0){b[f+27984+ha>>1]=0;b[ha+8+(f+27984)>>1]=0;break}else{c[w>>2]=c[w>>2]|1<<da;re[c[W>>2]&1023](f+15488+(da<<7)|0,I);ef[c[X>>2]&4095](I,c[Y>>2]|0,na);re[c[Z>>2]&1023](ja,I);b[f+27984+ha>>1]=257;b[ha+8+(f+27984)>>1]=257;break}}else{wa=Ee[c[ba>>2]&511](f+15488+(da<<7)|0,qa,ja)|0;oa=(wa*257|0)&65535;b[f+27984+ha>>1]=oa;b[ha+8+(f+27984)>>1]=oa;c[w>>2]=c[w>>2]|wa<<da}}while(0);da=da+1|0;ea=xa}ea=g+80|0;do{if((da|0)==3){c[ea>>2]=va;ba=f+19376|0;if((c[ba>>2]|0)==0){Ga=va;break}pe[c[f+37436>>2]&1023](f+22112|0,16,u,32,16);c[f+23248>>2]=c[f+27996>>2];c[f+23252>>2]=c[f+28004>>2];c[f+23256>>2]=c[f+28012>>2];c[f+23260>>2]=c[f+28020>>2];c[f+23268>>2]=c[w>>2];if((c[ba>>2]|0)!=2){Ga=va;break}Ee[c[f+37520>>2]&511](f+22368|0,f+15488|0,384)|0;Ga=va}else{c[ea>>2]=268435456;Ga=(ca(e[95448+(da<<1)>>1]|0,va)|0)>>8}}while(0);if((c[g+12756>>2]|0)==0){break}da=c[g+44>>2]|0;if((((Ga|0)<(da|0)?Ga:da)|0)<=((ca(d[95416+(c[f+18632>>2]|0)|0]|0,h)|0)>>2|0)){break}i=j;return}}while(0);if((q&1|0)==0){i=j;return}q=v*40|0;Ga=g+12756|0;if((c[Ga>>2]|0)==0){Ha=268435456}else{va=c[g+44>>2]|0;xa=c[g+80>>2]|0;Fa=(va|0)<(xa|0)?va:xa;Ha=(Fa|0)>(h|0)?h:Fa}Fa=f+19360|0;c[Fa>>2]=0;do{if((c[Ga>>2]|0)==0){Ia=Ha}else{if((c[g+24>>2]|0)==0){Ia=Ha;break}Ia=(ca(10-(c[g+28>>2]|0)|0,Ha)|0)/8|0}}while(0);if((c[p>>2]|0)==1){Ja=v*49|0}else{Ja=q}q=g+36|0;p=f+37352|0;Ha=f+28836|0;Ga=f+37292|0;h=o|0;xa=o+4|0;va=v*-3|0;O=o+8|0;Da=g+24|0;ya=g+28|0;Ea=v*3|0;v=f+36908|0;za=l+31&-32;l=f+37572|0;Ca=f+18644|0;Ba=f+18640|0;Aa=f+37716|0;n=f+1716|0;P=f+1748|0;k=f+37644|0;m=f+37736|0;da=f+1652|0;ea=f+37576|0;w=f+37760|0;ba=f+33820|0;I=f+33816|0;Z=f+37652|0;Y=0;X=Ja;d:while(1){Ja=d[1901400+Y|0]|0;W=s+Ja|0;V=e[1901464+(Y<<1)>>1]|0;U=u+V|0;T=d[19112+Y|0]|0;S=a[(a[T-1+(f+27936)|0]|0)+95137|0]|0;aa=a[(a[T-8+(f+27936)|0]|0)+95137|0]|0;$=S<<24>>24<aa<<24>>24?S:aa;aa=$<<24>>24<0?2:$<<24>>24;$=c[f+18804+(Y<<2)>>2]|0;if((c[q>>2]|0)==0){Ka=0}else{Ka=(Y&5|0)==5|0}S=($&11|0)==11?4:$&3;_=1078480+(Ka*50|0)+(S*10|0)|0;if(($&6|0)==2){c[u+(V-28)>>2]=ca(d[u+(V-29)|0]|0,16843009)|0}$=c[p>>2]|0;do{if(($|0)==0){ra=93}else{if(!((a[1078480+(Ka*50|0)+(S*10|0)+8|0]|0)>-1)){ra=93;break}R=Ee[$&511](W,U,(3052719&-64)+(N-aa<<1)|0)|0;Q=(R&65535)+X|0;E=R>>16;c[g+244+(Y<<2)>>2]=E;if((Q|0)>(Ia|0)|(Y|0)==15){La=Q;break d}a[f+27936+T|0]=E;Ma=Q}}while(0);if((ra|0)==93){ra=0;do{if((c[Ha>>2]|0)==0){if(!((a[1078480+(Ka*50|0)+(S*10|0)+5|0]|0)>-1)){Na=_;Oa=268435456;ra=103;break}ef[c[Ga>>2]&4095](W,U,h);$=(c[xa>>2]|0)>(c[h>>2]|0)|0;Q=o+(aa<<2)|0;c[Q>>2]=(c[Q>>2]|0)+va;Q=c[O>>2]|0;E=g+244+(Y<<2)|0;c[E>>2]=2;R=c[xa>>2]|0;if((R|0)<(Q|0)){c[E>>2]=1;Pa=R}else{Pa=Q}Q=c[h>>2]|0;if((Q|0)<(Pa|0)){c[E>>2]=0;Qa=Q}else{Qa=Pa}if((c[Da>>2]|0)<((c[ya>>2]|0)+1|0)){Ra=95376+((c[q>>2]|0)*20|0)+(((d[1078480+(Ka*50|0)+(S*10|0)+8|0]|0)>>>7&255^1)*10|0)+($*5|0)|0}else{Ra=1078480+(Ka*50|0)+(S*10|0)+3|0}if((Qa|0)>0){Na=Ra;Oa=Qa;ra=103}else{Sa=Qa}}else{Na=_;Oa=268435456;ra=103}}while(0);e:do{if((ra|0)==103){ra=0;_=a[Na]|0;if(!(_<<24>>24>-1)){Sa=Oa;break}S=g+244+(Y<<2)|0;$=Oa;Q=Na;E=_;while(1){Ta=E<<24>>24;if((c[Ha>>2]|0)==0){qe[c[f+36608+(Ta<<2)>>2]&1023](U)}else{rMb(f,U,0,Y,Ta)}_=hf[c[v>>2]&1023](U,32,W,16)|0;if((aa|0)==(a[Ta+95137|0]|0)){Ua=_+va|0;if((Ua|0)<1){break}else{Va=Ua}}else{Va=_}if((Va|0)<($|0)){c[S>>2]=Ta;Wa=Va}else{Wa=$}_=Q+1|0;R=a[_]|0;if(R<<24>>24>-1){$=Wa;Q=_;E=R}else{Sa=Wa;break e}}c[S>>2]=Ta;Sa=Ua}}while(0);aa=X+Ea+Sa|0;if((aa|0)>(Ia|0)|(Y|0)==15){La=aa;break}W=g+244+(Y<<2)|0;E=c[W>>2]|0;if((c[Ha>>2]|0)==0){qe[c[f+36608+(E<<2)>>2]&1023](U)}else{rMb(f,U,0,Y,E)}a[f+27936+T|0]=c[W>>2];Ma=aa}aa=c[z>>2]|0;W=(c[r>>2]|0)+Ja|0;E=(c[t>>2]|0)+V|0;do{if((c[Ha>>2]|0)==0){ef[c[l>>2]&4095](za,W,E);if((c[Ca>>2]|0)!=0){mf[c[w>>2]&2047](za,c[ba>>2]|0,c[I>>2]|0,16)}if((c[Ba>>2]|0)==0){Xa=Ee[c[Aa>>2]&511](za,(c[n>>2]|0)+(aa<<5)|0,(c[P>>2]|0)+(aa<<5)|0)|0}else{Xa=_Tb(f,za,0,aa,2,1,0,Y)|0}a[f+27984+T|0]=Xa;if((Xa|0)==0){break}c[Fa>>2]=c[Fa>>2]|1<<(Y>>2);re[c[k>>2]&1023](f+17024+(Y<<5)|0,za);ef[c[m>>2]&4095](za,c[da>>2]|0,aa);re[c[ea>>2]&1023](E,za)}else{Q=Ee[c[Z>>2]&511](f+17024+(Y<<5)|0,W,E)|0;a[f+27984+T|0]=Q;c[Fa>>2]=c[Fa>>2]|Q<<(Y>>2)}}while(0);Y=Y+1|0;X=Ma}Ma=g+240|0;if((Y|0)!=15){c[Ma>>2]=268435456;i=j;return}c[Ma>>2]=La;La=f+19376|0;if((c[La>>2]|0)==0){i=j;return}pe[c[f+37436>>2]&1023](f+21856|0,16,u,32,16);c[f+23232>>2]=c[f+27996>>2];c[f+23236>>2]=c[f+28004>>2];c[f+23240>>2]=c[f+28012>>2];c[f+23244>>2]=c[f+28020>>2];c[f+23264>>2]=c[Fa>>2];if((c[La>>2]|0)!=2){i=j;return}Ee[c[f+37520>>2]&511](f+22752|0,f+17024|0,480)|0;i=j;return}function gUb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=(c[b+12756>>2]|0)==0?268435456:d;d=b+44|0;if((c[d>>2]|0)<(e|0)){c[a+19344>>2]=2;lUb(a,b);f=VTb(a,c[b+4>>2]|0)|0}else{f=268435456}c[d>>2]=f;f=b+240|0;if((c[f>>2]|0)<(e|0)){c[a+19344>>2]=0;lUb(a,b);g=VTb(a,c[b+4>>2]|0)|0}else{g=268435456}c[f>>2]=g;g=b+80|0;if((c[g>>2]|0)<(e|0)){c[a+19344>>2]=1;lUb(a,b);c[g>>2]=VTb(a,c[b+4>>2]|0)|0;c[b+84>>2]=c[a+19360>>2];return}else{c[g>>2]=268435456;return}}function hUb(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0;h=i;i=i+2768|0;j=h|0;k=h+64|0;l=h+1136|0;m=h+1296|0;n=h+1368|0;o=h+2440|0;p=h+2448|0;q=h+2496|0;r=h+2512|0;s=h+2528|0;t=h+2688|0;u=h+2712|0;v=h+2736|0;w=h+2752|0;x=f+8632|0;y=c[x>>2]|0;z=(y|0)==3?3:1;c[f+19376>>2]=0;A=f+19344|0;if((c[A>>2]|0)==2){B=g+76|0;C=c[B>>2]|0;D=c[f+18868>>2]|0;E=1078584+(((D&11|0)==11?4:D&3)*5|0)|0;if((c[g+12756>>2]|0)==0){F=268435456}else{F=((c[g+48+(C<<2)>>2]|0)*9|0|0)/8|0}D=c[g+44>>2]|0;H=f+19368|0;I=g+4|0;J=E;K=(D|0)<0|0?-1:0;L=D;D=a[E]|0;while(1){E=D<<24>>24;do{if((E|0)==(C|0)){M=K;N=L}else{if((c[g+48+(E<<2)>>2]|0)>(F|0)){M=K;N=L;break}c[H>>2]=E;O=VTb(f,c[I>>2]|0)|0;P=O;Q=(O|0)<0|0?-1:0;if(!(Q>>>0<K>>>0|Q>>>0==K>>>0&P>>>0<L>>>0)){M=K;N=L;break}c[B>>2]=E;M=Q;N=P}}while(0);E=J+1|0;P=a[E]|0;if(P<<24>>24>-1){J=E;K=M;L=N;D=P}else{break}}R=c[x>>2]|0}else{R=y}do{if((R|0)!=3){y=c[f+18868>>2]|0;D=(y&11|0)==11?4:y&3;y=1705200+(D*5|0)|0;if((D|0)==0){break}if((c[g+12756>>2]|0)==0){S=268435456}else{S=((c[g+312>>2]|0)*5|0|0)/4|0}D=g+344|0;N=0;L=y;M=a[y]|0;while(1){y=M<<24>>24;do{if((c[g+316+(y<<2)>>2]|0)<(S|0)){if((y|0)==(c[D>>2]|0)){T=N;break}a[o+N|0]=M;T=N+1|0}else{T=N}}while(0);y=L+1|0;K=a[y]|0;if(K<<24>>24>-1){N=T;L=y;M=K}else{break}}if((T|0)<=0){break}M=f+19364|0;L=c[M>>2]|0;N=c[97424+(c[f+28820>>2]<<2)>>2]|0;D=g+344|0;K=IUb(f,N,c[D>>2]|0,0)|0;y=f+28836|0;J=f+24572|0;B=f+24576|0;I=0;H=L;L=G;F=K;while(1){K=a[o+I|0]|0;if((c[y>>2]|0)==0){C=f+36656+(K<<2)|0;qe[c[C>>2]&1023](c[J>>2]|0);qe[c[C>>2]&1023](c[B>>2]|0)}else{qMb(f,K)}C=IUb(f,N,K,(c[M>>2]|0)!=0|0)|0;P=G;if(P>>>0<L>>>0|P>>>0==L>>>0&C>>>0<F>>>0){c[D>>2]=K;U=P;V=C;W=c[M>>2]|0}else{U=L;V=F;W=H}C=I+1|0;if((C|0)<(T|0)){I=C;H=W;L=U;F=V}else{break}}c[f+19372>>2]=c[D>>2];c[M>>2]=W}}while(0);W=c[A>>2]|0;if((W|0)==1){A=s+31&-32;mrc(t|0,0,24)|0;mrc(u|0,0,21)|0;mrc(v|0,0,12)|0;s=w|0;V=f+24568|0;U=w+4|0;T=f+24572|0;o=w+8|0;S=f+24576|0;R=g+12756|0;F=g+36|0;L=f+36740|0;H=g+84|0;I=f+19360|0;N=g+4|0;B=f+28816|0;J=f+19356|0;y=l+31&-32;l=m+31&-32;m=f+28836|0;C=f+37612|0;P=f+18644|0;K=f+18640|0;E=f+37712|0;Q=f+37640|0;O=f+37732|0;X=f+37616|0;Y=f+37760|0;Z=f+33820|0;_=f+33816|0;$=f+28820|0;aa=f+37648|0;ba=f+24548|0;da=f+36788|0;ea=f+24552|0;fa=f+28868|0;ga=f+152|0;ha=f+1520|0;ia=f+19364|0;ja=f+37660|0;ka=f+37520|0;la=n+32|0;ma=la;na=f+13920|0;oa=n+104|0;pa=f+28768|0;qa=f+28772|0;ra=n+105|0;sa=0;do{ta=sa&1;ua=sa>>1;va=ua<<4|ta<<1|12;wa=ua<<8;xa=ta<<3|wa;ya=(c[V>>2]|0)+xa|0;c[s>>2]=ya;c[U>>2]=(c[T>>2]|0)+xa;c[o>>2]=(c[S>>2]|0)+xa;if((c[R>>2]|0)==0){za=268435456}else{za=((e[g+96+(sa<<5)+(c[g+224+(sa<<2)>>2]<<1)>>1]|0)*11|0)>>>3}xa=f+18788+(sa<<2)|0;Aa=c[xa>>2]|0;Ba=(c[F>>2]|0)==0;Ca=(Aa&11|0)==11?4:Aa&3;Da=0;Ea=ya;ya=Aa;while(1){mf[c[L>>2]&2047](Ea,A+(Da<<5)|0,ya,15);Aa=Da+1|0;if((Aa|0)>=(z|0)){break}Da=Aa;Ea=c[w+(Aa<<2)>>2]|0;ya=c[xa>>2]|0}ya=1078376+((Ba?0:ta)*50|0)+(Ca*10|0)|0;Ea=a[ya]|0;if(Ea<<24>>24>-1){Da=1<<sa;M=~Da;D=sa<<3&8;Aa=D|ua<<7;Fa=D|wa;Ga=sa<<2;Ha=ua<<3;Ia=19112+Ga|0;Ja=g+224+(sa<<2)|0;Ka=(ta|0)==0;La=va+8|0;Ma=f+15488+(sa<<7)|0;Na=0;Oa=268435456;Pa=0;Qa=ya;ya=Ea;while(1){Ea=ya<<24>>24;do{if((e[g+96+(sa<<5)+(Ea<<1)>>1]|0)>>>0>za>>>0){Ra=Oa;Sa=Pa;Ta=Na}else{Ua=c[H>>2]|0;c[I>>2]=Ua;Va=c[N>>2]|0;Wa=(c[x>>2]|0)==3?3:1;Xa=c[B>>2]|0;c[I>>2]=Ua&M;c[J>>2]=1;Ua=19472+Ea|0;Ya=f+36560+(Ea<<2)|0;Za=Xa;Xa=0;while(1){_a=A+(Xa<<5)|0;$a=(c[f+24544+(Xa<<2)>>2]|0)+Aa|0;ab=(c[f+24568+(Xa<<2)>>2]|0)+Fa|0;if((_a|0)==0){mf[c[L>>2]&2047](ab,l,c[xa>>2]|0,d[Ua]|0);bb=l}else{bb=_a}if((c[m>>2]|0)==0){re[c[Ya>>2]&1023](ab,bb)}else{sMb(f,ab,Xa,sa,Ea,bb)}do{if((c[m>>2]|0)==0){ef[c[C>>2]&4095](y,$a,ab);_a=d[1625023+Xa|0]|0;cb=(Xa|0)!=0;db=cb?2:0;if((c[P>>2]|0)!=0){eb=(cb&1)<<1|1;mf[c[Y>>2]&2047](y,(c[Z>>2]|0)+(eb<<8)|0,(c[_>>2]|0)+(eb<<7)|0,64)}if((c[K>>2]|0)==0){fb=Ee[c[E>>2]&511](y,(c[f+1732+(db<<2)>>2]|0)+(Za<<7)|0,(c[f+1764+(db<<2)>>2]|0)+(Za<<7)|0)|0}else{fb=$Tb(f,y,db,Za,_a,1,cb&1,(Xa<<2)+sa|0)|0}if((fb|0)==0){cb=d[19112+((Xa<<4)+Ga)|0]|0;b[f+27984+cb>>1]=0;b[cb+8+(f+27984)>>1]=0;break}else{c[I>>2]=c[I>>2]|Da;re[c[Q>>2]&1023](f+15488+((Xa<<2)+sa<<7)|0,y);ef[c[O>>2]&4095](y,c[f+1668+(db<<2)>>2]|0,Za);re[c[X>>2]&1023](ab,y);db=d[19112+((Xa<<4)+Ga)|0]|0;b[f+27984+db>>1]=257;b[db+8+(f+27984)>>1]=257;break}}else{db=Ee[c[aa>>2]&511](f+15488+((Xa<<2)+sa<<7)|0,$a,ab)|0;cb=(db*257|0)&65535;_a=d[19112+((Xa<<4)+Ga)|0]|0;b[f+27984+_a>>1]=cb;b[_a+8+(f+27984)>>1]=cb;c[I>>2]=c[I>>2]|db<<sa}}while(0);ab=Xa+1|0;if((ab|0)<(Wa|0)){Za=c[$>>2]|0;Xa=ab}else{break}}Xa=WTb(f,3,0,D,Ha)|0;Za=Xa;Wa=(Xa|0)<0|0?-1:0;if((c[x>>2]|0)==3){Xa=hf[c[da>>2]&1023]((c[ba>>2]|0)+Aa|0,16,(c[T>>2]|0)+Fa|0,32)|0;Ya=(hf[c[da>>2]&1023]((c[ea>>2]|0)+Aa|0,16,(c[S>>2]|0)+Fa|0,32)|0)+Xa|0;Xa=c[fa>>2]|0;Ua=Erc(Ya,(Ya|0)<0|0?-1:0,Xa,(Xa|0)<0|0?-1:0)|0;Xa=wrc(Ua,G,128,0)|0;Ua=Xa>>>8|G<<24;Xa=wrc(Ua,(Ua|0)<0|0?-1:0,Za,Wa)|0;gb=G;hb=Xa}else{gb=Wa;hb=Za}if((c[ga>>2]|0)==0){Za=c[x>>2]|0;Wa=(Za|0)==3?3:1;Xa=d[Ia]|0;Ua=a[(a[Xa-1+(f+27936)|0]|0)+95137|0]|0;Ya=a[(a[Xa-8+(f+27936)|0]|0)+95137|0]|0;ab=Ua<<24>>24<Ya<<24>>24?Ua:Ya;c[ha>>2]=(d[(d[(c[ia>>2]<<4|c[I>>2])+(1722288+(((Za|0)!=3|0)*96|0))|0]|0)+16465|0]|0)+(((ab<<24>>24<0?2:ab<<24>>24)|0)==(a[Ea+95137|0]|0)?1:4);ab=f+27984+Xa|0;Xa=0;do{do{if((c[J>>2]|0)!=0){if((a[ab]|0)==0){break}Za=(Xa<<4)+Ga|0;ef[c[ja>>2]&4095](f+17024+(Za<<5)|0,f+15488+((Xa<<2)+sa<<7)|0,(d[19112+Za|0]|0)+(f+27984)|0)}}while(0);if((c[I>>2]&Da|0)!=0){Za=(Xa<<4)+Ga|0;Ya=0;do{Ua=Za+Ya|0;$a=d[19112+Ua|0]|0;db=(d[$a-8+(f+27984)|0]|0)+(d[$a-1+(f+27984)|0]|0)|0;if((db|0)<128){ib=(db+1|0)>>>1}else{ib=db}db=d[1625080+(ib&127)|0]|0;cb=f+27984+$a|0;if((a[cb]|0)==0){c[ha>>2]=(c[ha>>2]|0)+(d[100209+(db<<1)|0]|0)}else{a[cb]=JUb(f,2,f+17024+(Ua<<5)|0,db)|0}Ya=Ya+1|0;}while((Ya|0)<4)}Xa=Xa+1|0;}while((Xa|0)<(Wa|0));Wa=ca(c[ha>>2]|0,Va)|0;jb=(Wa|0)<0|0?-1:0;kb=Wa}else{Ee[c[ka>>2]&511](ma,na,(c[x>>2]|0)==3?1040:464)|0;Wa=d[Ia]|0;Xa=a[(a[Wa-1+(f+27936)|0]|0)+95137|0]|0;ab=a[(a[Wa-8+(f+27936)|0]|0)+95137|0]|0;Wa=Xa<<24>>24<ab<<24>>24?Xa:ab;ab=Wa<<24>>24<0?2:Wa<<24>>24;Wa=a[Ea+95137|0]|0;Xa=d[oa]|0;if((ab|0)==(Wa|0)){a[oa]=a[100553+(Xa<<1)|0]|0;lb=(c[la>>2]|0)+(e[101200+((Xa^1)<<1)>>1]|0)|0}else{a[oa]=a[100552+(Xa<<1)|0]|0;Ya=(((Wa|0)>(ab|0))<<31>>31)+Wa|0;Wa=Ya&1;ab=d[ra]|0;Za=Ya>>>1&1;db=d[100552+(ab<<1)+Wa|0]|0;Ua=(c[la>>2]|0)+(e[101200+(Xa<<1)>>1]|0)+(e[101200+((ab^Wa)<<1)>>1]|0)+(e[101200+((db^Za)<<1)>>1]|0)|0;Wa=Ya>>2;Ya=d[100552+(db<<1)+Za|0]|0;a[ra]=a[100552+(Ya<<1)+Wa|0]|0;lb=Ua+(e[101200+((Ya^Wa)<<1)>>1]|0)|0}c[la>>2]=lb;Wa=c[I>>2]|0;Ya=c[pa>>2]|0;Ua=c[qa>>2]|0;Za=Wa&1;db=76-(Ya>>>1&2)-(Ua>>>1&1)+(n+36)|0;ab=d[db]|0;a[db]=a[100552+(ab<<1)+Za|0]|0;c[la>>2]=(c[la>>2]|0)+(e[101200+((ab^Za)<<1)>>1]|0);ab=Wa>>>1&1;db=76-Za-(Ya>>>2&2)+(n+36)|0;Ya=d[db]|0;a[db]=a[100552+(Ya<<1)+ab|0]|0;c[la>>2]=(c[la>>2]|0)+(e[101200+((Ya^ab)<<1)>>1]|0);ab=Wa>>>2&1;Ya=76-(Wa<<1&2)-(Ua>>>3&1)+(n+36)|0;Ua=d[Ya]|0;a[Ya]=a[100552+(Ua<<1)+ab|0]|0;Ya=(c[la>>2]|0)+(e[101200+((Ua^ab)<<1)>>1]|0)|0;c[la>>2]=Ya;c[la>>2]=(e[101200+((d[76-(Wa&2)-ab+(n+36)|0]^Wa>>>3&1)<<1)>>1]|0)+Ya;do{if((Wa&Da|0)!=0){if((c[x>>2]|0)==3){mb=0}else{STb(f,n,5,Ma);break}do{Ya=d[1625023+mb|0]|0;ab=d[19112+((mb<<4)+Ga)|0]|0;Ua=(e[109680+(Ya<<1)>>1]|0)+((a[ab-1+(f+27984)|0]|0)!=0)+(((a[ab-8+(f+27984)|0]|0)!=0)<<1)+(n+36)|0;db=d[Ua]|0;if((a[f+27984+ab|0]|0)==0){a[Ua]=a[100552+(db<<1)|0]|0;c[la>>2]=(c[la>>2]|0)+(e[101200+(db<<1)>>1]|0)}else{a[Ua]=a[100553+(db<<1)|0]|0;c[la>>2]=(c[la>>2]|0)+(e[101200+((db^1)<<1)>>1]|0);STb(f,n,Ya,f+15488+((mb<<2)+sa<<7)|0)}mb=mb+1|0;}while((mb|0)<3)}}while(0);Wa=c[la>>2]|0;Ya=Erc(Wa,(Wa|0)<0|0?-1:0,Va,(Va|0)<0|0?-1:0)|0;Wa=wrc(Ya,G,128,0)|0;Ya=G;jb=Ya>>>8|0<<24;kb=Wa>>>8|Ya<<24}Ya=wrc(kb,jb,hb<<8|0>>>24,gb<<8|hb>>>24)|0;Wa=G;if(!(Oa>>>0>Wa>>>0|Oa>>>0==Wa>>>0&Pa>>>0>Ya>>>0)){Ra=Oa;Sa=Pa;Ta=Na;break}c[Ja>>2]=Ea;db=c[I>>2]|0;Ua=0;while(1){ab=c[w+(Ua<<2)>>2]|0;c[t+(Ua<<3)>>2]=c[ab+224>>2];c[t+(Ua<<3)+4>>2]=c[ab+228>>2];if(Ka){a[u+(Ua*7|0)|0]=a[ab+7|0]|0;a[u+(Ua*7|0)+1|0]=a[ab+39|0]|0;a[u+(Ua*7|0)+2|0]=a[ab+71|0]|0;a[u+(Ua*7|0)+3|0]=a[ab+103|0]|0;a[u+(Ua*7|0)+4|0]=a[ab+135|0]|0;a[u+(Ua*7|0)+5|0]=a[ab+167|0]|0;a[u+(Ua*7|0)+6|0]=a[ab+199|0]|0}ab=Ua<<4;b[v+(Ua<<2)>>1]=b[ab+va+(f+27984)>>1]|0;b[v+(Ua<<2)+2>>1]=b[La+ab+(f+27984)>>1]|0;ab=Ua+1|0;if((ab|0)<(z|0)){Ua=ab}else{Ra=Wa;Sa=Ya;Ta=db;break}}}}while(0);Ea=Qa+1|0;db=a[Ea]|0;if(db<<24>>24>-1){Na=Ta;Oa=Ra;Pa=Sa;Qa=Ea;ya=db}else{nb=Ta;ob=La;break}}}else{nb=0;ob=va+8|0}c[H>>2]=nb;La=(ta|0)==0;ya=0;do{Qa=c[w+(ya<<2)>>2]|0;c[Qa+224>>2]=c[t+(ya<<3)>>2];c[Qa+228>>2]=c[t+(ya<<3)+4>>2];if(La){a[Qa+7|0]=a[u+(ya*7|0)|0]|0;a[Qa+39|0]=a[u+(ya*7|0)+1|0]|0;a[Qa+71|0]=a[u+(ya*7|0)+2|0]|0;a[Qa+103|0]=a[u+(ya*7|0)+3|0]|0;a[Qa+135|0]=a[u+(ya*7|0)+4|0]|0;a[Qa+167|0]=a[u+(ya*7|0)+5|0]|0;a[Qa+199|0]=a[u+(ya*7|0)+6|0]|0}Qa=ya<<4;b[Qa+va+(f+27984)>>1]=b[v+(ya<<2)>>1]|0;b[ob+Qa+(f+27984)>>1]=b[v+(ya<<2)+2>>1]|0;ya=ya+1|0;}while((ya|0)<(z|0));ya=((c[g+224+(sa<<2)>>2]|0)*257|0)&65535;b[f+27936+va>>1]=ya;b[f+27936+ob>>1]=ya;sa=sa+1|0;}while((sa|0)<4);i=h;return}else if((W|0)==0){mrc(p|0,0,48)|0;mrc(q|0,0,12)|0;W=r|0;sa=f+24568|0;ob=r+4|0;v=f+24572|0;u=r+8|0;t=f+24576|0;w=g+36|0;nb=g+4|0;H=f+28816|0;Ta=j+31&-32;j=f+28836|0;Sa=f+37572|0;Ra=f+18644|0;I=f+18640|0;hb=f+37716|0;gb=f+19360|0;jb=f+37644|0;kb=f+37736|0;la=f+37576|0;mb=f+37760|0;n=f+33820|0;qa=f+33816|0;pa=f+28820|0;lb=f+37652|0;ra=f+24548|0;oa=f+36800|0;na=f+24552|0;ma=f+28868|0;ka=f+152|0;ha=f+1520|0;ib=f+37520|0;ja=k+32|0;J=ja;ia=f+13920|0;ga=k+104|0;fa=k+105|0;S=0;do{ea=e[1901464+(S<<1)>>1]|0;da=(c[sa>>2]|0)+ea|0;c[W>>2]=da;c[ob>>2]=(c[v>>2]|0)+ea;c[u>>2]=(c[t>>2]|0)+ea;T=c[f+18804+(S<<2)>>2]|0;if((c[w>>2]|0)==0){pb=0}else{pb=(S&5|0)==5|0}ba=1078480+(pb*50|0)+(((T&11|0)==11?4:T&3)*10|0)|0;a:do{if((T&6|0)==2){$=1;aa=da;while(1){c[aa-28>>2]=ca(d[aa-29|0]|0,16843009)|0;if(($|0)>=(z|0)){break a}y=c[r+($<<2)>>2]|0;$=$+1|0;aa=y}}}while(0);da=a[ba]|0;if(da<<24>>24>-1){T=d[1901400+S|0]|0;va=S>>2;aa=1<<va;$=d[1901576+S|0]<<2;y=d[1901368+S|0]|0;X=y<<2;O=(y<<7)+$|0;Q=(y<<6)+$|0;y=19112+S|0;fb=g+244+(S<<2)|0;E=ba;K=268435456;_=0;Z=da;while(1){da=Z<<24>>24;Y=c[nb>>2]|0;P=(c[x>>2]|0)==3?3:1;C=f+36608+(da<<2)|0;m=H;bb=0;while(1){l=c[m>>2]|0;L=(c[f+24544+(bb<<2)>>2]|0)+T|0;A=(c[f+24568+(bb<<2)>>2]|0)+ea|0;if((c[j>>2]|0)==0){qe[c[C>>2]&1023](A)}else{rMb(f,A,bb,S,da)}do{if((c[j>>2]|0)==0){ef[c[Sa>>2]&4095](Ta,L,A);B=d[1625014+bb|0]|0;N=(bb|0)!=0;za=N?2:0;if((c[Ra>>2]|0)!=0){F=(N&1)<<1;mf[c[mb>>2]&2047](Ta,(c[n>>2]|0)+(F<<8)|0,(c[qa>>2]|0)+(F<<7)|0,16)}if((c[I>>2]|0)==0){qb=Ee[c[hb>>2]&511](Ta,(c[f+1716+(za<<2)>>2]|0)+(l<<5)|0,(c[f+1748+(za<<2)>>2]|0)+(l<<5)|0)|0;rb=(bb<<4)+S|0}else{F=(bb<<4)+S|0;qb=_Tb(f,Ta,za,l,B,1,N&1,F)|0;rb=F}a[(d[19112+rb|0]|0)+(f+27984)|0]=qb;if((qb|0)==0){break}c[gb>>2]=c[gb>>2]|aa;re[c[jb>>2]&1023](f+17024+(rb<<5)|0,Ta);ef[c[kb>>2]&4095](Ta,c[f+1652+(za<<2)>>2]|0,l);re[c[la>>2]&1023](A,Ta)}else{za=(bb<<4)+S|0;F=Ee[c[lb>>2]&511](f+17024+(za<<5)|0,L,A)|0;a[(d[19112+za|0]|0)+(f+27984)|0]=F;c[gb>>2]=c[gb>>2]|F<<va}}while(0);A=bb+1|0;if((A|0)<(P|0)){m=pa;bb=A}else{break}}bb=WTb(f,6,0,$,X)|0;m=bb;P=(bb|0)<0|0?-1:0;if((c[x>>2]|0)==3){bb=hf[c[oa>>2]&1023]((c[ra>>2]|0)+Q|0,16,(c[v>>2]|0)+O|0,32)|0;C=(hf[c[oa>>2]&1023]((c[na>>2]|0)+Q|0,16,(c[t>>2]|0)+O|0,32)|0)+bb|0;bb=c[ma>>2]|0;A=Erc(C,(C|0)<0|0?-1:0,bb,(bb|0)<0|0?-1:0)|0;bb=wrc(A,G,128,0)|0;A=bb>>>8|G<<24;bb=wrc(A,(A|0)<0|0?-1:0,m,P)|0;sb=G;tb=bb}else{sb=P;tb=m}if((c[ka>>2]|0)==0){m=(c[x>>2]|0)==3?3:1;P=d[y]|0;bb=a[(a[P-1+(f+27936)|0]|0)+95137|0]|0;A=a[(a[P-8+(f+27936)|0]|0)+95137|0]|0;P=bb<<24>>24<A<<24>>24?bb:A;c[ha>>2]=((P<<24>>24<0?2:P<<24>>24)|0)==(a[da+95137|0]|0)?1:4;P=0;do{A=(P<<4)+S|0;bb=d[19112+A|0]|0;C=(d[bb-8+(f+27984)|0]|0)+(d[bb-1+(f+27984)|0]|0)|0;if((C|0)<128){ub=(C+1|0)>>>1}else{ub=C}C=d[1625080+(ub&127)|0]|0;L=f+27984+bb|0;if((a[L]|0)==0){c[ha>>2]=(c[ha>>2]|0)+(d[100209+(C<<1)|0]|0)}else{a[L]=JUb(f,2,f+17024+(A<<5)|0,C)|0}P=P+1|0;}while((P|0)<(m|0));m=ca(c[ha>>2]|0,Y)|0;vb=(m|0)<0|0?-1:0;wb=m}else{Ee[c[ib>>2]&511](J,ia,(c[x>>2]|0)==3?1040:464)|0;m=d[y]|0;P=a[(a[m-1+(f+27936)|0]|0)+95137|0]|0;C=a[(a[m-8+(f+27936)|0]|0)+95137|0]|0;m=P<<24>>24<C<<24>>24?P:C;C=m<<24>>24<0?2:m<<24>>24;m=(c[x>>2]|0)==3?3:1;P=a[da+95137|0]|0;A=d[ga]|0;if((C|0)==(P|0)){a[ga]=a[100553+(A<<1)|0]|0;xb=(c[ja>>2]|0)+(e[101200+((A^1)<<1)>>1]|0)|0}else{a[ga]=a[100552+(A<<1)|0]|0;L=(((P|0)>(C|0))<<31>>31)+P|0;P=L&1;C=d[fa]|0;bb=L>>>1&1;l=d[100552+(C<<1)+P|0]|0;F=(c[ja>>2]|0)+(e[101200+(A<<1)>>1]|0)+(e[101200+((C^P)<<1)>>1]|0)+(e[101200+((l^bb)<<1)>>1]|0)|0;P=L>>2;L=d[100552+(l<<1)+bb|0]|0;a[fa]=a[100552+(L<<1)+P|0]|0;xb=F+(e[101200+((L^P)<<1)>>1]|0)|0}c[ja>>2]=xb;P=0;do{L=d[1625014+P|0]|0;F=(P<<4)+S|0;bb=d[19112+F|0]|0;l=(e[109680+(L<<1)>>1]|0)+((a[bb-1+(f+27984)|0]|0)!=0)+(((a[bb-8+(f+27984)|0]|0)!=0)<<1)+(k+36)|0;C=d[l]|0;if((a[f+27984+bb|0]|0)==0){a[l]=a[100552+(C<<1)|0]|0;c[ja>>2]=(c[ja>>2]|0)+(e[101200+(C<<1)>>1]|0)}else{a[l]=a[100553+(C<<1)|0]|0;c[ja>>2]=(c[ja>>2]|0)+(e[101200+((C^1)<<1)>>1]|0);TTb(f,k,L,f+17024+(F<<5)|0)}P=P+1|0;}while((P|0)<(m|0));m=c[ja>>2]|0;P=Erc(m,(m|0)<0|0?-1:0,Y,(Y|0)<0|0?-1:0)|0;m=wrc(P,G,128,0)|0;P=G;vb=P>>>8|0<<24;wb=m>>>8|P<<24}P=wrc(wb,vb,tb<<8|0>>>24,sb<<8|tb>>>24)|0;m=G;if(K>>>0>m>>>0|K>>>0==m>>>0&_>>>0>P>>>0){c[fb>>2]=da;F=0;while(1){L=c[r+(F<<2)>>2]|0;c[p+(F<<4)>>2]=c[L>>2];c[p+(F<<4)+4>>2]=c[L+32>>2];c[p+(F<<4)+8>>2]=c[L+64>>2];c[p+(F<<4)+12>>2]=c[L+96>>2];c[q+(F<<2)>>2]=d[(d[19112+((F<<4)+S)|0]|0)+(f+27984)|0]|0;L=F+1|0;if((L|0)<(z|0)){F=L}else{yb=m;zb=P;break}}}else{yb=K;zb=_}P=E+1|0;m=a[P]|0;if(m<<24>>24>-1){E=P;K=yb;_=zb;Z=m}else{Ab=0;break}}}else{Ab=0}do{Z=c[r+(Ab<<2)>>2]|0;c[Z>>2]=c[p+(Ab<<4)>>2];c[Z+32>>2]=c[p+(Ab<<4)+4>>2];c[Z+64>>2]=c[p+(Ab<<4)+8>>2];c[Z+96>>2]=c[p+(Ab<<4)+12>>2];a[(d[19112+((Ab<<4)+S)|0]|0)+(f+27984)|0]=c[q+(Ab<<2)>>2];Ab=Ab+1|0;}while((Ab|0)<(z|0));a[(d[19112+S|0]|0)+(f+27936)|0]=c[g+244+(S<<2)>>2];S=S+1|0;}while((S|0)<16);i=h;return}else{i=h;return}}function iUb(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=c[b+3216>>2]|0;i=g-51|0;j=(d[h+((g|0)<51?g:51)|0]|0)+((i|0)>0?i:0)|0;i=f|0;c[i>>2]=e[97256+(g<<1)>>1]|0;c[f+4>>2]=c[97424+(g<<2)>>2];k=c[b+572>>2]|0;if((k|0)>1){c[b+18640>>2]=(c[f+24>>2]|0)!=0;l=4}else{c[b+18640>>2]=0;if((k|0)!=0){l=4}}if((l|0)==4){c[b+28848>>2]=c[17232+(g<<2)>>2];c[b+28852>>2]=c[17560+(g<<2)>>2];c[b+28856>>2]=c[17232+(j<<2)>>2];c[b+28860>>2]=c[17560+(j<<2)>>2]}c[b+28864>>2]=c[i>>2];i=g-j+12|0;if((c[b+596>>2]|0)==0){m=256}else{m=e[100272+(((i|0)<36?i:36)<<1)>>1]|0}c[b+28868>>2]=m;if((g|0)>51){c[b+33816>>2]=(c[b+1812>>2]|0)+(g-52<<9);c[b+33820>>2]=b+35392;c[b+33824>>2]=b+36432;c[b+18644>>2]=1;n=51;o=b+28816|0;c[o>>2]=n;p=f+8|0;c[p>>2]=n;q=h+n|0;r=a[q]|0;s=r&255;t=b+28820|0;c[t>>2]=s;return}else{c[b+33816>>2]=b+33856;c[b+33820>>2]=b+34368;c[b+33824>>2]=b+36416;c[b+18644>>2]=0;n=g;o=b+28816|0;c[o>>2]=n;p=f+8|0;c[p>>2]=n;q=h+n|0;r=a[q]|0;s=r&255;t=b+28820|0;c[t>>2]=s;return}}function jUb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=e<<1&2;h=e&2;j=d[a+19352+e|0]|0;if((j|0)==2){k=h<<3|g;re[c[25130]&1023](a+28192+((k|12)<<2)|0,c[b+4912+(e<<8)+112>>2]|0);re[c[25130]&1023](a+28192+((k|13)<<2)|0,c[b+4912+(e<<8)+240>>2]|0);i=f;return}else if((j|0)==0){k=g|12;l=h<<3;re[c[25128]&1023](a+28192+((k|l)<<2)|0,c[b+1808+(e<<9)+112>>2]|0);m=g|13;re[c[25128]&1023](a+28192+((m|l)<<2)|0,c[b+1808+(e<<9)+240>>2]|0);n=l|8;re[c[25128]&1023](a+28192+(k+n<<2)|0,c[b+1808+(e<<9)+368>>2]|0);re[c[25128]&1023](a+28192+(m+n<<2)|0,c[b+1808+(e<<9)+496>>2]|0);i=f;return}else if((j|0)==3){re[c[25131]&1023](a+28192+((h<<3|g|12)<<2)|0,c[b+1280+(e<<7)+112>>2]|0);i=f;return}else if((j|0)==1){j=g|12;g=h<<3;re[c[25129]&1023](a+28192+((j|g)<<2)|0,c[b+3872+(e<<8)+112>>2]|0);re[c[25129]&1023](a+28192+(j+(g|8)<<2)|0,c[b+3872+(e<<8)+240>>2]|0);i=f;return}else{ILb(a,0,2387248,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=f;return}}function kUb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+32|0;g=f|0;h=f+16|0;j=e+312|0;if((c[j>>2]|0)<268435456){i=f;return}if((c[b+8632>>2]|0)==3){if((c[b+18636>>2]|0)==0){c[j>>2]=0;i=f;return}k=e+76|0;l=c[k>>2]|0;if((c[b+28836>>2]|0)==0){m=b+24572|0;qe[c[b+36532+(l<<2)>>2]&1023](c[m>>2]|0);n=b+24576|0;qe[c[b+36532+(c[k>>2]<<2)>>2]&1023](c[n>>2]|0);o=m;p=n}else{tMb(b,1,l);tMb(b,2,c[k>>2]|0);o=b+24572|0;p=b+24576|0}k=b+36884|0;l=hf[c[k>>2]&1023](c[o>>2]|0,32,c[b+24548>>2]|0,16)|0;c[j>>2]=(hf[c[k>>2]&1023](c[p>>2]|0,32,c[b+24552>>2]|0,16)|0)+l;i=f;return}l=c[b+18868>>2]|0;p=(l&11|0)==11;k=1705200+((p?4:l&3)*5|0)|0;l=d[b+36448|0]|0;do{if(p){if((c[b+28836>>2]|0)!=0){q=11;break}o=b+37304|0;n=b+24548|0;m=b+24572|0;ef[c[o>>2]&4095](c[n>>2]|0,c[m>>2]|0,g|0);r=b+24552|0;s=b+24576|0;ef[c[o>>2]&4095](c[r>>2]|0,c[s>>2]|0,h|0);o=b+36668|0;qe[c[o>>2]&1023](c[m>>2]|0);qe[c[o>>2]&1023](c[s>>2]|0);o=b+36884+(l<<2)|0;c[g+12>>2]=hf[c[o>>2]&1023](c[m>>2]|0,32,c[n>>2]|0,16)|0;c[h+12>>2]=hf[c[o>>2]&1023](c[s>>2]|0,32,c[r>>2]|0,16)|0;r=e|0;s=e+344|0;o=k;n=a[k]|0;do{m=n<<24>>24;t=(c[h+(m<<2)>>2]|0)+(c[g+(m<<2)>>2]|0)+(ca(d[m+16465|0]|0,c[r>>2]|0)|0)|0;c[e+316+(m<<2)>>2]=t;if((t|0)<(c[j>>2]|0)){c[j>>2]=t;c[s>>2]=m}o=o+1|0;n=a[o]|0;}while(n<<24>>24>-1)}else{q=11}}while(0);if((q|0)==11){q=b+28836|0;g=b+24572|0;h=b+24576|0;p=b+36884+(l<<2)|0;l=b+24548|0;n=b+24552|0;o=e|0;s=e+344|0;r=k;m=a[k]|0;do{k=m<<24>>24;if((c[q>>2]|0)==0){t=b+36656+(k<<2)|0;qe[c[t>>2]&1023](c[g>>2]|0);qe[c[t>>2]&1023](c[h>>2]|0)}else{qMb(b,k)}t=hf[c[p>>2]&1023](c[g>>2]|0,32,c[l>>2]|0,16)|0;u=(hf[c[p>>2]&1023](c[h>>2]|0,32,c[n>>2]|0,16)|0)+t|0;t=u+(ca(d[(d[95352+k|0]|0)+16465|0]|0,c[o>>2]|0)|0)|0;c[e+316+(k<<2)>>2]=t;if((t|0)<(c[j>>2]|0)){c[j>>2]=t;c[s>>2]=k}r=r+1|0;m=a[r]|0;}while(m<<24>>24>-1)}c[b+19372>>2]=c[e+344>>2];i=f;return}function lUb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;h=e+19344|0;j=c[h>>2]|0;a:do{switch(j|0){case 5:{re[c[25111]&1023](e+28116|0,c[f+1292>>2]&255);re[c[25111]&1023](e+28118|0,c[f+1420>>2]&255);re[c[25111]&1023](e+28132|0,c[f+1548>>2]&255);re[c[25111]&1023](e+28134|0,c[f+1676>>2]&255);jUb(e,f,0);jUb(e,f,1);jUb(e,f,2);jUb(e,f,3);break};case 1:{k=((c[f+224>>2]|0)*257|0)&65535;b[e+27948>>1]=k;b[e+27956>>1]=k;k=((c[f+228>>2]|0)*257|0)&65535;b[e+27950>>1]=k;b[e+27958>>1]=k;k=((c[f+232>>2]|0)*257|0)&65535;b[e+27964>>1]=k;b[e+27972>>1]=k;k=((c[f+236>>2]|0)*257|0)&65535;b[e+27966>>1]=k;b[e+27974>>1]=k;kUb(e,f);break};case 4:{k=c[e+19348>>2]|0;if((k|0)==14){re[c[25113]&1023](e+28116|0,c[f+5964>>2]&255);re[c[25113]&1023](e+28132|0,c[f+6092>>2]&255);re[c[25133]&1023](e+28240|0,c[f+6064>>2]|0);re[c[25133]&1023](e+28304|0,c[f+6192>>2]|0);break a}else if((k|0)==16){re[c[25117]&1023](e+28116|0,c[f+380>>2]&255);re[c[25137]&1023](e+28240|0,c[f+480>>2]|0);break a}else if((k|0)==15){re[c[25115]&1023](e+28116|0,c[f+6236>>2]&255);re[c[25115]&1023](e+28118|0,c[f+6364>>2]&255);re[c[25135]&1023](e+28240|0,c[f+6336>>2]|0);re[c[25135]&1023](e+28248|0,c[f+6464>>2]|0);break a}else{ILb(e,0,2512232,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;break a}break};case 6:{c[e+19348>>2]=16;re[c[25117]&1023](e+28116|0,0);re[c[25137]&1023](e+28240|0,c[e+28756>>2]|0);break};case 3:{break};case 17:{GUb(e,f,0,1);GUb(e,f,1,1);GUb(e,f,2,1);GUb(e,f,3,1);break};case 18:case 7:{c[e+19348>>2]=c[e+28752>>2];re[c[25111]&1023](e+28116|0,d[e+28744|0]|0);re[c[25111]&1023](e+28156|0,d[e+28748|0]|0);re[c[25131]&1023](e+28240|0,c[e+28712>>2]|0);re[c[25131]&1023](e+28400|0,c[e+28728>>2]|0);re[c[25111]&1023](e+28118|0,d[e+28745|0]|0);re[c[25111]&1023](e+28158|0,d[e+28749|0]|0);re[c[25131]&1023](e+28248|0,c[e+28716>>2]|0);re[c[25131]&1023](e+28408|0,c[e+28732>>2]|0);re[c[25111]&1023](e+28132|0,d[e+28746|0]|0);re[c[25111]&1023](e+28172|0,d[e+28750|0]|0);re[c[25131]&1023](e+28304|0,c[e+28720>>2]|0);re[c[25131]&1023](e+28464|0,c[e+28736>>2]|0);re[c[25111]&1023](e+28134|0,d[e+28747|0]|0);re[c[25111]&1023](e+28174|0,d[e+28751|0]|0);re[c[25131]&1023](e+28312|0,c[e+28724>>2]|0);re[c[25131]&1023](e+28472|0,c[e+28740>>2]|0);break};case 0:{k=0;do{a[(d[19112+k|0]|0)+(e+27936)|0]=c[f+244+(k<<2)>>2];k=k+1|0;}while((k|0)<16);kUb(e,f);break};case 2:{c[e+19368>>2]=c[f+76>>2];kUb(e,f);break};default:{k=c[e+19348>>2]|0;if((k|0)==14){m=f+12728|0;if((a[95296+(c[m>>2]|0)|0]|0)==0){re[c[25113]&1023](e+28116|0,255);re[c[25133]&1023](e+28240|0,0);re[c[25123]&1023](e+28536|0,0)}else{re[c[25113]&1023](e+28116|0,c[f+5964>>2]&255);re[c[25133]&1023](e+28240|0,c[f+6064>>2]|0)}if((a[95313+(c[m>>2]|0)|0]|0)==0){re[c[25113]&1023](e+28156|0,255);re[c[25133]&1023](e+28400|0,0);re[c[25123]&1023](e+28616|0,0)}else{re[c[25113]&1023](e+28156|0,c[f+12092>>2]&255);re[c[25133]&1023](e+28400|0,c[f+12192>>2]|0)}m=f+12732|0;if((a[95296+(c[m>>2]|0)|0]|0)==0){re[c[25113]&1023](e+28132|0,255);re[c[25133]&1023](e+28304|0,0);re[c[25123]&1023](e+28568|0,0)}else{re[c[25113]&1023](e+28132|0,c[f+6092>>2]&255);re[c[25133]&1023](e+28304|0,c[f+6192>>2]|0)}if((a[95313+(c[m>>2]|0)|0]|0)==0){re[c[25113]&1023](e+28172|0,255);re[c[25133]&1023](e+28464|0,0);re[c[25123]&1023](e+28648|0,0);break a}else{re[c[25113]&1023](e+28172|0,c[f+12220>>2]&255);re[c[25133]&1023](e+28464|0,c[f+12320>>2]|0);break a}}else if((k|0)==16){if((j|0)==8){re[c[25117]&1023](e+28116|0,c[f+380>>2]&255);re[c[25137]&1023](e+28240|0,c[f+480>>2]|0);re[c[25117]&1023](e+28156|0,255);re[c[25137]&1023](e+28400|0,0);re[c[25127]&1023](e+28616|0,0);break a}else if((j|0)==16){re[c[25117]&1023](e+28116|0,c[f+508>>2]&255);re[c[25137]&1023](e+28240|0,c[f+608>>2]|0);re[c[25117]&1023](e+28156|0,c[f+6636>>2]&255);re[c[25137]&1023](e+28400|0,c[f+6736>>2]|0);break a}else if((j|0)==12){re[c[25117]&1023](e+28116|0,255);re[c[25137]&1023](e+28240|0,0);re[c[25127]&1023](e+28536|0,0);re[c[25117]&1023](e+28156|0,c[f+6508>>2]&255);re[c[25137]&1023](e+28400|0,c[f+6608>>2]|0);break a}else{break a}}else if((k|0)==15){k=f+12736|0;if((a[95296+(c[k>>2]|0)|0]|0)==0){re[c[25115]&1023](e+28116|0,255);re[c[25135]&1023](e+28240|0,0);re[c[25125]&1023](e+28536|0,0)}else{re[c[25115]&1023](e+28116|0,c[f+6236>>2]&255);re[c[25135]&1023](e+28240|0,c[f+6336>>2]|0)}if((a[95313+(c[k>>2]|0)|0]|0)==0){re[c[25115]&1023](e+28156|0,255);re[c[25135]&1023](e+28400|0,0);re[c[25125]&1023](e+28616|0,0)}else{re[c[25115]&1023](e+28156|0,c[f+12364>>2]&255);re[c[25135]&1023](e+28400|0,c[f+12464>>2]|0)}k=f+12740|0;if((a[95296+(c[k>>2]|0)|0]|0)==0){re[c[25115]&1023](e+28118|0,255);re[c[25135]&1023](e+28248|0,0);re[c[25125]&1023](e+28540|0,0)}else{re[c[25115]&1023](e+28118|0,c[f+6364>>2]&255);re[c[25135]&1023](e+28248|0,c[f+6464>>2]|0)}if((a[95313+(c[k>>2]|0)|0]|0)==0){re[c[25115]&1023](e+28158|0,255);re[c[25135]&1023](e+28408|0,0);re[c[25125]&1023](e+28620|0,0);break a}else{re[c[25115]&1023](e+28158|0,c[f+12492>>2]&255);re[c[25135]&1023](e+28408|0,c[f+12592>>2]|0);break a}}else{ILb(e,0,2498800,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break a}}}}while(0);if((c[e+1548>>2]|0)<=1){i=g;return}if((c[h>>2]|0)>>>0<4>>>0){i=g;return}j=e+3240|0;k=e+18660|0;m=e+18612|0;n=e+18720|0;o=e+18608|0;p=f+76|0;q=e+19368|0;r=0;do{s=a[e+28104+(r*40|0)+12|0]|0;t=s<<24>>24;do{if(!(s<<24>>24<0)){u=c[k>>2]|0;v=c[(c[(c[e+15160+(r*76|0)+(t>>u<<2)>>2]|0)+2772>>2]|0)+11952>>2]|0;w=e+28192+(r*160|0)+158|0;if(((b[w>>1]>>2-u)+(c[m>>2]<<4)|0)<=(v|0)){break}ILb(e,1,2486560,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;ILb(e,3,2474888,(l=i,i=i+8|0,c[l>>2]=c[h>>2],l)|0);i=l;u=b[e+28192+(r*160|0)+156>>1]|0;x=b[w>>1]|0;ILb(e,3,2466192,(l=i,i=i+32|0,c[l>>2]=r,c[l+8>>2]=t,c[l+16>>2]=u,c[l+24>>2]=x,l)|0);i=l;ILb(e,3,2455784,(l=i,i=i+8|0,c[l>>2]=c[n>>2],l)|0);i=l;x=c[m>>2]|0;ILb(e,3,2438528,(l=i,i=i+16|0,c[l>>2]=c[o>>2],c[l+8>>2]=x,l)|0);i=l;ILb(e,3,2427784,(l=i,i=i+8|0,c[l>>2]=v,l)|0);i=l;ILb(e,1,2417512,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;fUb(e,f,268435456);c[h>>2]=2;c[q>>2]=c[p>>2];kUb(e,f)}}while(0);r=r+1|0;}while((r|0)<=((c[j>>2]|0)==1|0));i=g;return}function mUb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=a+36776+((d[a+36448|0]|0)<<2)|0;e=hf[c[b>>2]&1023](c[a+24548>>2]|0,16,c[a+24572>>2]|0,32)|0;f=(hf[c[b>>2]&1023](c[a+24552>>2]|0,16,c[a+24576>>2]|0,32)|0)+e|0;e=c[a+28868>>2]|0;b=Erc(f,(f|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=wrc(b,G,128,0)|0;b=e>>>8|G<<24;e=c[a+24568>>2]|0;f=a+24544|0;g=c[f>>2]|0;h=a+18652|0;if((c[h>>2]|0)==0){i=0;j=a+36776|0;k=c[j>>2]|0;l=hf[k&1023](g,16,e,32)|0;m=i+b|0;n=m+l|0;return n|0}o=a+37112|0;p=We[c[o>>2]&2047](e,32)|0;q=G;r=a+24320|0;s=c[r>>2]|0;t=c[r+4>>2]|0;if((s|0)==0&(t|0)==0){u=We[c[o>>2]&2047](c[f>>2]|0,16)|0;f=G;o=wrc(u,f,1,0)|0;c[r>>2]=o;c[r+4>>2]=G;v=u;w=f}else{f=wrc(s,t,-1,-1)|0;v=f;w=G}f=p-v|0;v=q-w|0;i=(ca(ca(c[a+28864>>2]|0,c[h>>2]|0)|0,((v|0)>-1?v:-v|0)+((f|0)>-1?f:-f|0)>>1)|0)+128>>8;j=a+36776|0;k=c[j>>2]|0;l=hf[k&1023](g,16,e,32)|0;m=i+b|0;n=m+l|0;return n|0}function nUb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;if((c[b+12756>>2]|0)==0){e=268435456}else{e=((ca((c[a+18652>>2]|0)!=0?18:17,d)|0)/16|0)+1|0}do{if((c[b+12752>>2]|0)!=0){d=b+12712|0;if((c[d>>2]|0)!=268435456){break}c[a+19344>>2]=7;f=a+19380|0;c[f>>2]=1;lUb(a,b);c[d>>2]=VTb(a,c[b+4>>2]|0)|0;c[f>>2]=0}}while(0);f=a+19348|0;c[f>>2]=16;do{if((c[b+476>>2]|0)<(e|0)){d=b+352|0;if((c[d>>2]|0)!=268435456){break}c[a+19344>>2]=8;lUb(a,b);c[d>>2]=VTb(a,c[b+4>>2]|0)|0}}while(0);do{if((c[b+6604>>2]|0)<(e|0)){d=b+6480|0;if((c[d>>2]|0)!=268435456){break}c[a+19344>>2]=12;lUb(a,b);c[d>>2]=VTb(a,c[b+4>>2]|0)|0}}while(0);do{if((c[b+12608>>2]|0)<(e|0)){d=b+12708|0;if((c[d>>2]|0)!=268435456){break}c[a+19344>>2]=16;lUb(a,b);c[d>>2]=VTb(a,c[b+4>>2]|0)|0}}while(0);do{if((c[b+12616>>2]|0)<(e|0)){d=b+12724|0;if((c[d>>2]|0)!=268435456){break}c[a+19344>>2]=17;c[f>>2]=13;lUb(a,b);c[d>>2]=VTb(a,c[b+4>>2]|0)|0;c[a+28684>>2]=0;c[a+28692>>2]=0;c[a+28700>>2]=0;c[a+28708>>2]=0}}while(0);do{if((c[b+12700>>2]|0)<(e|0)){d=b+12716|0;if((c[d>>2]|0)!=268435456){break}c[a+19344>>2]=c[b+12744>>2];c[f>>2]=14;lUb(a,b);c[d>>2]=VTb(a,c[b+4>>2]|0)|0}}while(0);if((c[b+12704>>2]|0)>=(e|0)){return}e=b+12720|0;if((c[e>>2]|0)!=268435456){return}c[a+19344>>2]=c[b+12748>>2];c[f>>2]=15;lUb(a,b);c[e>>2]=VTb(a,c[b+4>>2]|0)|0;return}function oUb(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;j=i;i=i+1912|0;k=j+1888|0;l=j+1904|0;m=i;i=i+128|0;n=i;i=i+8|0;o=j+1631&-32;c[f+19348>>2]=14;p=g+12700|0;c[p>>2]=0;q=m|0;r=g+12|0;s=m+4|0;t=f+27916|0;u=m+88|0;v=f+27920|0;w=m+92|0;x=f+27924|0;y=m+96|0;z=f+24544|0;A=m+72|0;B=f+18576|0;C=f+24548|0;D=m+76|0;E=f+24552|0;F=m+80|0;G=g+6480|0;H=g+352|0;I=n|0;J=n+4|0;K=m+8|0;L=m+20|0;M=m+68|0;N=m+24|0;O=m+28|0;P=m+32|0;Q=f+8632|0;R=m+36|0;S=m+40|0;T=m+44|0;U=m+48|0;V=m+52|0;W=m+56|0;X=m+60|0;Y=m+64|0;Z=m+84|0;_=m+16|0;$=m+12|0;aa=k;ba=k|0;da=k+4|0;ea=k+8|0;k=m+100|0;fa=m+108|0;ga=f+37520|0;ha=m;ia=f+37380|0;ja=o|0;ka=l;la=o+128|0;o=l+4|0;ma=f+37392|0;na=f+30412|0;oa=f+36888|0;pa=f+18636|0;qa=g|0;ra=g+12756|0;sa=g+12688|0;ta=g+24|0;ua=f+18652|0;va=j+31&-32;wa=j+1087&-32;xa=f+36449|0;ya=f+37376|0;za=va|0;Aa=va+256|0;Ba=va+512|0;Ca=va+768|0;va=wa|0;Da=wa+256|0;wa=f+18660|0;Ea=f+37384|0;Fa=f+18612|0;Ga=0;do{c[l>>2]=16;c[l+4>>2]=16;c[q>>2]=1;c[s>>2]=c[r>>2];c[u>>2]=c[t>>2];c[w>>2]=c[v>>2];c[y>>2]=c[x>>2];Ha=Ga<<3;c[A>>2]=(c[z>>2]|0)+(Ga<<7);Ia=Ha>>c[B>>2]<<4;c[D>>2]=(c[C>>2]|0)+Ia;c[F>>2]=(c[E>>2]|0)+Ia;Ia=Ga<<1;Ja=Ia|1;Ka=Ia+2|0;La=Ga<<4|12;Ma=0;do{Na=(Ma|0)!=0?G:H;Oa=c[Na+928+(Ia<<7)+12>>2]|0;c[I>>2]=Oa;Pa=c[Na+928+(Ja<<7)+12>>2]|0;c[J>>2]=Pa;Qa=(Oa|0)==(Pa|0)?1:2;Pa=Na+5600+(Ga<<7)+108|0;c[Pa>>2]=2147483647;Ra=g+16+(Ma<<2)|0;Sa=f+28104+(Ma*40|0)+La|0;Ta=Na+5600+(Ga<<7)|0;Ua=1;Va=Oa;while(1){c[K>>2]=e[(c[Ra>>2]|0)+(Va<<1)>>1]|0;Oa=ca(c[u>>2]|0,Ha)|0;Wa=(c[f+24588+(Ma*1536|0)+(Va*48|0)>>2]|0)+Oa|0;c[L>>2]=Wa;c[M>>2]=Wa;c[N>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+4>>2]|0)+Oa;c[O>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+8>>2]|0)+Oa;c[P>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+12>>2]|0)+Oa;if((c[Q>>2]|0)==3){Wa=ca(c[w>>2]|0,Ha)|0;c[R>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+16>>2]|0)+Wa;c[S>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+20>>2]|0)+Wa;c[T>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+24>>2]|0)+Wa;c[U>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+28>>2]|0)+Wa;Wa=ca(c[y>>2]|0,Ha)|0;c[V>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+32>>2]|0)+Wa;c[W>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+36>>2]|0)+Wa;c[X>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+40>>2]|0)+Wa;c[Y>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+44>>2]|0)+Wa}else{Wa=ca(Ha>>c[B>>2],c[w>>2]|0)|0;c[R>>2]=(c[f+24588+(Ma*1536|0)+(Va*48|0)+16>>2]|0)+Wa}c[Z>>2]=(c[f+27788+(Ma<<6)+(Va<<2)>>2]|0)+(Oa<<1);c[_>>2]=2772248;c[$>>2]=Va;c[ba>>2]=c[Na+276+(Va*20|0)>>2];c[da>>2]=c[Na+276+(Va*20|0)+(Ja<<2)>>2];c[ea>>2]=c[Na+276+(Va*20|0)+(Ka<<2)>>2];re[c[25113]&1023](Sa,Va&255);dQb(f,Ma,Ha,4,k);oVb(f,m,aa,3,0);Oa=(c[fa>>2]|0)+(c[K>>2]|0)|0;c[fa>>2]=Oa;if((Oa|0)<(c[Pa>>2]|0)){Ee[c[ga>>2]&511](Ta,ha,128)|0}if((Ua|0)>=(Qa|0)){break}Oa=c[n+(Ua<<2)>>2]|0;Ua=Ua+1|0;Va=Oa}Ma=Ma+1|0;}while((Ma|0)<2);Ma=g+5952+(Ga<<7)+112|0;Ha=g+5952+(Ga<<7)+114|0;Ka=Ke[c[ia>>2]&63](ja,ka,g+5952+(Ga<<7)+20|0,c[g+5952+(Ga<<7)+88>>2]|0,b[Ma>>1]|0,b[Ha>>1]|0,16,8,2772248)|0;Ja=g+12080+(Ga<<7)+112|0;Ia=g+12080+(Ga<<7)+114|0;Va=Ke[c[ia>>2]&63](la,o,g+12080+(Ga<<7)+20|0,c[g+12080+(Ga<<7)+88>>2]|0,b[Ja>>1]|0,b[Ia>>1]|0,16,8,2772248)|0;Ua=g+12080+(Ga<<7)+12|0;Qa=g+5952+(Ga<<7)+12|0;Se[c[ma>>2]&1023](ja,16,Ka,c[ka>>2]|0,Va,c[o>>2]|0,a[(c[Ua>>2]|0)+((c[na>>2]|0)+(c[Qa>>2]<<2))|0]|0);Va=hf[c[oa>>2]&1023](c[g+5952+(Ga<<7)+72>>2]|0,16,ja,16)|0;Ka=(c[g+5952+(Ga<<7)+104>>2]|0)+Va+(c[g+12080+(Ga<<7)+104>>2]|0)+(c[g+5952+(Ga<<7)+8>>2]|0)+(c[g+12080+(Ga<<7)+8>>2]|0)|0;if((c[pa>>2]|0)==0){Xa=Ka}else{Va=d[xa]|0;if((c[Q>>2]|0)==3){Te[c[ya>>2]&255](za,16,g+5952+(Ga<<7)+36|0,c[g+5952+(Ga<<7)+92>>2]|0,b[Ma>>1]|0,b[Ha>>1]|0,16,8,2772248);Te[c[ya>>2]&255](Aa,16,g+5952+(Ga<<7)+52|0,c[g+5952+(Ga<<7)+96>>2]|0,b[Ma>>1]|0,b[Ha>>1]|0,16,8,2772248);Te[c[ya>>2]&255](Ba,16,g+12080+(Ga<<7)+36|0,c[g+12080+(Ga<<7)+92>>2]|0,b[Ja>>1]|0,b[Ia>>1]|0,16,8,2772248);Te[c[ya>>2]&255](Ca,16,g+12080+(Ga<<7)+52|0,c[g+12080+(Ga<<7)+96>>2]|0,b[Ja>>1]|0,b[Ia>>1]|0,16,8,2772248)}else{Ta=c[B>>2]|0;Pa=c[wa>>2]&Ta;if((Pa&c[Qa>>2]|0)==0){Ya=0}else{Ya=(c[Fa>>2]<<2&4)-2|0}if((c[Ua>>2]&Pa|0)==0){Za=0}else{Za=(c[Fa>>2]<<2&4)-2|0}Pa=8>>>(Ta>>>0);Te[c[Ea>>2]&255](za,Aa,16,c[g+5952+(Ga<<7)+36>>2]|0,c[g+5952+(Ga<<7)+92>>2]|0,b[Ma>>1]|0,(b[Ha>>1]|0)+Ya<<1>>Ta,8,Pa);Te[c[Ea>>2]&255](Ba,Ca,16,c[g+12080+(Ga<<7)+36>>2]|0,c[g+12080+(Ga<<7)+92>>2]|0,b[Ja>>1]|0,(b[Ia>>1]|0)+Za<<1>>Ta,8,Pa)}Pa=f+37388+(Va<<2)|0;Se[c[Pa>>2]&1023](va,16,za,16,Ba,16,a[(c[Ua>>2]|0)+((c[na>>2]|0)+(c[Qa>>2]<<2))|0]|0);Se[c[Pa>>2]&1023](Da,16,Aa,16,Ca,16,a[(c[Ua>>2]|0)+((c[na>>2]|0)+(c[Qa>>2]<<2))|0]|0);Pa=f+36884+(Va<<2)|0;Va=hf[c[Pa>>2]&1023](c[g+5952+(Ga<<7)+76>>2]|0,16,va,16)|0;Xa=Va+Ka+(hf[c[Pa>>2]&1023](c[g+5952+(Ga<<7)+80>>2]|0,16,Da,16)|0)|0}Pa=c[g+5952+(Ga<<7)+108>>2]|0;Ka=g+12728+(Ga<<2)|0;c[Ka>>2]=3;Va=c[g+12080+(Ga<<7)+108>>2]|0;if((Va|0)<(Pa|0)){c[Ka>>2]=7;_a=Va}else{_a=Pa}if(((c[qa>>2]|0)+Xa|0)<(_a|0)){c[Ka>>2]=11;$a=Xa}else{$a=_a}c[p>>2]=(c[p>>2]|0)+$a;if((c[ra>>2]|0)!=0&(Ga|0)==0){if(((c[sa>>2]|0)+$a|0)>((ca(((c[ta>>2]|0)!=0|16)+((c[ua>>2]|0)!=0)|0,h)|0)/16|0|0)){ab=268435456;bb=35;break}}if((a[95296+(c[Ka>>2]|0)|0]|0)==0){re[c[25113]&1023](f+28104+La|0,255);re[c[25133]&1023](f+28192+(La<<2)|0,0)}else{re[c[25113]&1023](f+28104+La|0,c[Qa>>2]&255);re[c[25133]&1023](f+28192+(La<<2)|0,c[Ma>>2]|0)}if((a[95313+(c[Ka>>2]|0)|0]|0)==0){re[c[25113]&1023](f+28144+La|0,255);re[c[25133]&1023](f+28352+(La<<2)|0,0)}else{re[c[25113]&1023](f+28144+La|0,c[Ua>>2]&255);re[c[25133]&1023](f+28352+(La<<2)|0,c[Ja>>2]|0)}Ga=Ga+1|0;}while((Ga|0)<2);if((bb|0)==35){c[p>>2]=ab;i=j;return}bb=((c[g+12728>>2]>>2)*3|0)+8+(c[g+12732>>2]>>2)|0;c[g+12744>>2]=bb;g=ca(d[1078080+bb|0]|0,c[qa>>2]|0)|0;ab=g+(c[p>>2]|0)|0;c[p>>2]=ab;i=j;return}function pUb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0.0,K=0,L=0.0,M=0,N=0,O=0,P=0,Q=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ba=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0.0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0;h=i;i=i+12824|0;j=h|0;k=h+8|0;l=h+24|0;m=h+40|0;n=h+56|0;c[j>>2]=b;o=(c[b+92>>2]|0)-1-(c[e+92>>2]|0)|0;p=b+436|0;c[p>>2]=1;q=b+432|0;c[q>>2]=0;r=b+440|0;c[r>>2]=0;s=b+444|0;c[s>>2]=0;t=b+484|0;c[t>>2]=1;u=b+480|0;c[u>>2]=0;c[b+488>>2]=0;v=b+492|0;c[v>>2]=0;w=b+532|0;c[w>>2]=1;x=b+528|0;c[x>>2]=0;c[b+536>>2]=0;y=b+540|0;c[y>>2]=0;z=(f|0)!=0;A=(z&1)<<1^2;B=0;do{C=b+8616+(B<<3)|0;D=e+8616+(B<<3)|0;E=c[D>>2]|0;F=c[D+4>>2]|0;D=(E|0)==0&(F|0)==0&1;H=0;I=wrc(D,H,c[C>>2]|0,c[C+4>>2]|0)|0;J=+(I>>>0)+ +(G>>>0)*4294967296.0;I=wrc(D,H,E,F)|0;g[k+(B<<2)>>2]=+S(J/(+(I>>>0)+ +(G>>>0)*4294967296.0));I=(B|0)!=0|0;J=+(ca(c[b+168+(I<<2)>>2]|0,c[b+180+(I<<2)>>2]|0)|0);g[l+(B<<2)>>2]=+((c[b+8600+(B<<2)>>2]|0)>>>0>>>0)/J;g[m+(B<<2)>>2]=+((c[e+8600+(B<<2)>>2]|0)>>>0>>>0)/J;B=B+1|0;}while((B|0)<=(A|0));A=b+400|0;do{if(z){K=7}else{J=+g[k+4>>2];L=+g[k+8>>2];if(J<.9921875&L<.9921875){K=7;break}if(J<1.984375&L<1.984375){K=6;break}if(J<3.96875&L<3.96875){K=5;break}if(J<7.9375&L<7.9375){K=4;break}if(J<15.875&L<15.875){K=3;break}if(J<31.75&L<31.75){K=2;break}K=J<63.5&L<63.5&1}}while(0);B=z^1;L=+(1<<K|0);I=n+8|0;F=n|0;E=a+1864|0;H=n+12|0;D=a+3304|0;C=n+16|0;M=a+3308|0;N=n+20|0;O=a+560|0;P=a+544|0;Q=a+18628|0;T=a+18632|0;U=a+18636|0;V=a+19280|0;W=a+8632|0;X=a+37560|0;Y=a+528|0;J=+(f|0)*.5;f=0;Z=0;a:while(1){_=(f|0)!=0;if(_){if(!((c[s>>2]|0)!=0&B)){$=75;break}}aa=+g[m+(f<<2)>>2];ba=+g[l+(f<<2)>>2];do{if(+R(+(aa-ba))<.5){if(!(+R(+(1.0- +g[k+(f<<2)>>2]))<.0078125)){$=12;break}c[b+400+(f*48|0)+36>>2]=1;c[b+400+(f*48|0)+32>>2]=0;c[b+400+(f*48|0)+40>>2]=0;c[b+400+(f*48|0)+44>>2]=0;da=Z}else{$=12}}while(0);b:do{if(($|0)==12){$=0;do{if(_){ea=b+400+(f*48|0)+32|0;c[ea>>2]=K;fa=~~+Nb(+(L*+g[k+(f<<2)>>2]));if((fa|0)<0){ga=b+400+(f*48|0)+36|0;c[ga>>2]=0;ha=K;ia=0;ja=ea;ka=ga;$=22;break}ga=(fa|0)>255?255:fa;fa=b+400+(f*48|0)+36|0;c[fa>>2]=ga;if((ga|0)>127){$=17;break a}la=b+400+(f*48|0)|0;ma=ea;na=K;oa=fa;pa=ga;$=32}else{ga=~~+Nb(+(+g[k>>2]*128.0));c[r>>2]=0;c[q>>2]=7;c[p>>2]=ga;if((ga|0)>127){fa=7;ea=ga;do{fa=fa-1|0;ea=ea>>1;}while((fa|0)>0&(ea|0)>127);c[q>>2]=fa;c[p>>2]=ea;qa=ea;ra=fa}else{qa=ga;ra=7}sa=(qa|0)<127?qa:127;c[p>>2]=sa;ha=ra;ia=sa;ja=b+432|0;ka=b+436|0;$=22}}while(0);do{if(($|0)==22){$=0;sa=b+400+(f*48|0)|0;if(_){la=sa;ma=ja;na=ha;oa=ka;pa=ia;$=32;break}ta=c[j>>2]|0;if((c[ta+8508>>2]|0)==0){c[I>>2]=12;c[F>>2]=1;c[H>>2]=c[E>>2];ua=(c[D>>2]|0)-1|0;if((ua|0)<0){va=0}else{va=(ua|0)>2?2:ua}c[C>>2]=3041168+(va*66|0);ua=(c[M>>2]|0)-1|0;if((ua|0)<0){wa=0}else{wa=(ua|0)>2?2:ua}c[N>>2]=3041168+(wa*66|0);if((c[O>>2]|0)>1){ua=c[P>>2]|0;xa=4;ya=(ua|0)>1?1:ua}else{xa=2;ya=0}c[Q>>2]=ya;c[T>>2]=xa;c[U>>2]=0;qUb(a,n,j,0,0,0,0)|0;za=c[j>>2]|0}else{za=ta}ta=rUb(a,za,e,c[V>>2]|0)|0;Aa=Z;Ba=sUb(a,c[j>>2]|0,ta,0)|0;Ca=ta;Da=sa;Ea=ja;Fa=ha;Ga=ka;Ha=ia}}while(0);do{if(($|0)==32){$=0;if((c[W>>2]|0)==3){sa=tUb(a,c[j>>2]|0,e,c[V>>2]|0,f)|0;Aa=Z;Ba=uUb(a,c[j>>2]|0,sa,0,f)|0;Ca=sa;Da=la;Ea=ma;Fa=na;Ga=oa;Ha=pa;break}sa=c[V>>2]|0;ta=c[j>>2]|0;ua=c[ta+160>>2]|0;Ia=c[ta+184>>2]|0;Ja=sa+(ca(Ia,ua)|0)|0;if((Z|0)==0){vUb(a,ta,e,sa,Ja);Ka=c[j>>2]|0;La=Ka;Ma=c[Ka+160>>2]|0;Na=c[Ka+184>>2]|0}else{La=ta;Ma=ua;Na=Ia}Ia=(f|0)==1?sa:Ja;Aa=Z+1|0;Ba=wUb(a,Ma,c[La+172>>2]|0,Na,Ia,0)|0;Ca=Ia;Da=la;Ea=ma;Fa=na;Ga=oa;Ha=pa}}while(0);if((Ba|0)==0){da=Aa;break}if(z){Oa=0;Pa=0}else{Ia=c[O>>2]|0;Oa=d[16113+(Ia<<1)|0]|0;Pa=d[16112+(Ia<<1)|0]|0}Ia=Ha-Pa|0;if((Ia|0)<0){Qa=0}else{Qa=(Ia|0)>127?127:Ia}Ia=Pa+Ha|0;if((Ia|0)<0){Ra=0}else{Ra=(Ia|0)>127?127:Ia}if((Qa|0)>(Ra|0)){Sa=0;Ta=Ba;Ua=Ha;Va=0}else{Wa=+(1<<Fa|0);Ia=b+400+(f*48|0)+40|0;Ja=0;sa=Ba;ua=Qa;ta=Ha;Ka=0;while(1){Xa=~~(J+(ba- +(ua|0)*aa/Wa));do{if((Xa+128|0)>>>0>255>>>0){if((Xa|0)<-128){Ya=-128}else{Ya=(Xa|0)>127?127:Xa}Za=~~(Wa*(ba- +(Ya|0))/aa+.5);if((Za|0)<0){_a=Ya;$a=0;break}_a=Ya;$a=(Za|0)>127?127:Za}else{_a=Xa;$a=ua}}while(0);Xa=_a-Oa|0;if((Xa|0)<-128){ab=-128}else{ab=(Xa|0)>127?127:Xa}Xa=_a+Oa|0;if((Xa|0)<-128){bb=-128}else{bb=(Xa|0)>127?127:Xa}Xa=Ka;ga=ab;fa=ta;ea=sa;Za=Ja;while(1){if((ga|0)>(bb|0)){cb=Xa;db=fa;eb=ea;fb=Za;break}c[Ga>>2]=$a;c[Ea>>2]=Fa;c[Ia>>2]=ga;re[c[X>>2]&1023](a,Da);do{if(_){gb=c[j>>2]|0;if((c[W>>2]|0)==3){hb=uUb(a,gb,Ca,Da,f)|0;break}else{hb=wUb(a,c[gb+160>>2]|0,c[gb+172>>2]|0,c[gb+184>>2]|0,Ca,Da)|0;break}}else{hb=sUb(a,c[j>>2]|0,Ca,Da)|0}}while(0);gb=hb>>>0<ea>>>0;ib=gb?1:Za;jb=gb?hb:ea;kb=gb?$a:fa;lb=gb?ga:Xa;if((lb|0)!=(ab|0)|(ga|0)==(ab|0)){Xa=lb;ga=ga+1|0;fa=kb;ea=jb;Za=ib}else{cb=ab;db=kb;eb=jb;fb=ib;break}}Za=ua+1|0;if((Za|0)>(Ra|0)){Sa=fb;Ta=eb;Ua=db;Va=cb;break}else{Ja=fb;sa=eb;ua=Za;ta=db;Ka=cb}}}c:do{if((Fa|0)>0&(_^1)){Ka=Fa;ta=Ua;while(1){if((ta&1|0)!=0){mb=ta;nb=Ka;break c}ua=Ka-1|0;sa=ta>>1;if((ua|0)>0){Ka=ua;ta=sa}else{mb=sa;nb=ua;break}}}else{mb=Ua;nb=Fa}}while(0);do{if((Sa|0)!=0){if((mb|0)==(1<<nb|0)&(Va|0)==0){break}Wa=+(Ta>>>0>>>0)/+(Ba>>>0>>>0);if(Wa>.9980000257492065){break}c[Ga>>2]=mb;c[Ea>>2]=nb;c[b+400+(f*48|0)+40>>2]=Va;re[c[X>>2]&1023](a,Da);if(!((c[Y>>2]|0)==-1)){da=Aa;break b}if((c[s>>2]|0)==0|_){da=Aa;break b}g[(c[j>>2]|0)+8528+(o<<2)>>2]=Wa;da=Aa;break b}}while(0);c[Ga>>2]=1;c[Ea>>2]=0;c[b+400+(f*48|0)+40>>2]=0;c[b+400+(f*48|0)+44>>2]=0;da=Aa}}while(0);_=f+1|0;if((_|0)<3){f=_;Z=da}else{$=75;break}}do{if(($|0)==17){c[y>>2]=0;c[v>>2]=0}else if(($|0)==75){da=c[v>>2]|0;if((da|0)==0){Z=c[y>>2]|0;if((Z|0)==0){break}ob=1;pb=x;qb=0;rb=Z}else{Z=c[y>>2]|0;ob=(Z|0)==0;pb=u;qb=da;rb=Z}Z=c[pb>>2]|0;da=rb;d:while(1){do{if(ob&(Z|0)==7){sb=da}else{if((Z|0)<=0){$=82;break d}if((qb|0)!=0){if((c[t>>2]&1|0)!=0){$=90;break d}}if((da|0)==0){sb=0;break}if((c[w>>2]&1|0)==0){sb=da}else{$=82;break d}}}while(0);f=Z-1|0;if((qb|0)!=0){c[t>>2]=c[t>>2]>>1;c[u>>2]=f}if((sb|0)==0){Z=f;da=0;continue}c[w>>2]=c[w>>2]>>1;c[x>>2]=f;Z=f;da=sb}if(($|0)==82){if((qb|0)==0){tb=da}else{$=90}}if(($|0)==90){re[c[X>>2]&1023](a,b+448|0);tb=c[y>>2]|0}if((tb|0)==0){break}re[c[X>>2]&1023](a,b+496|0)}}while(0);if((c[s>>2]|0)==0|B){i=h;return}B=e+192|0;s=c[B>>2]|0;POb(a,c[V>>2]|0,s,c[e+376>>2]|0,s,(c[e+196>>2]|0)+64|0,(c[e+200>>2]|0)+64|0,A);c[(c[j>>2]|0)+2704>>2]=(c[V>>2]|0)+((c[B>>2]<<5)+32);i=h;return}function qUb(a,d,f,g,h,j,k){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0;l=i;i=i+816|0;m=l|0;n=l+8|0;o=l+16|0;p=l+304|0;q=l+560|0;r=l+568|0;s=l+576|0;t=l+592|0;u=l+600|0;v=l+608|0;w=l+648|0;x=l+664|0;y=l+672|0;z=l+744|0;A=f+(j<<2)|0;B=c[A>>2]|0;C=h-j|0;D=j-g|0;E=B+4520|0;F=B+4520+(D*72|0)+(C<<2)|0;H=c[F>>2]|0;do{if((H|0)>-1){if((c[a+664>>2]|0)==0){I=H;break}if((c[c[B+7188+(D*72|0)+(C<<2)>>2]>>2]|0)==-1){J=4}else{I=H}}else{J=4}}while(0);do{if((J|0)==4){H=(j|0)!=(g|0);if(H){K=(b[c[B+2796+(D-1<<2)>>2]>>1]|0)==32767|0}else{K=0}c[x>>2]=K;L=(j|0)!=(h|0);if(L){M=(b[c[B+2864+(C-1<<2)>>2]>>1]|0)==32767|0}else{M=0}c[x+4>>2]=M;N=(K|0)==0;if(N){O=2772248}else{if((c[a+528>>2]|0)!=0&(j|0)==(h|0)){pUb(a,B,c[f+(g<<2)>>2]|0,1);P=B+400|0}else{P=2772248}b[c[B+2796+(D-1<<2)>>2]>>1]=0;O=P}Q=(M|0)==0;if(!Q){b[c[B+2864+(C-1<<2)>>2]>>1]=0}R=(h|0)==(g|0);if(R){S=128}else{T=h-g|0;S=((D<<8)+(T>>1)|0)/(T|0)|0}T=a+18564|0;U=c[T>>2]|0;V=a+8|0;W=c[V>>2]|0;X=(W*36|0)+U|0;Y=c[a+36460>>2]|0;Z=Y;c[y>>2]=Z;_=Z+(X<<2)|0;c[z>>2]=_;if((c[a+816>>2]|0)!=0){$=d|0;wVb(a,B,c[$>>2]|0)|0;if(!N){wVb(a,c[f+(g<<2)>>2]|0,c[$>>2]|0)|0;xVb(a,f,j,g,0,c[$>>2]|0,O)|0}if(!Q){wVb(a,c[f+(h<<2)>>2]|0,c[$>>2]|0)|0;xVb(a,f,j,h,1,c[$>>2]|0,0)|0}if(H){zVb(a,c[$>>2]|0,f,g,h,j,S)|0}vVb(a);I=c[F>>2]|0;break}do{if((W|0)>1){$=a+18628|0;H=a+18632|0;Q=a+18636|0;N=0;aa=Z;ba=_;while(1){da=c[a+1376+(N<<2)>>2]|0;c[da+18628>>2]=c[$>>2];c[da+18632>>2]=c[H>>2];c[da+18636>>2]=c[Q>>2];ea=ca(c[T>>2]|0,N)|0;fa=c[V>>2]|0;ga=(((fa|0)/2|0)+ea|0)/(fa|0)|0;c[da+1452>>2]=ga;fa=N+1|0;ea=ca(c[T>>2]|0,fa)|0;ha=c[V>>2]|0;ia=(((ha|0)/2|0)+ea|0)/(ha|0)|0;c[da+1456>>2]=ia;da=ia-ga|0;ga=(da<<2)+16|0;mrc(aa|0,0,ga|0)|0;mrc(ba|0,0,ga|0)|0;c[ba+12>>2]=da;c[aa+12>>2]=da;ga=da+36|0;da=aa+(ga<<2)|0;c[y+(fa<<2)>>2]=da;ia=(c[z+(N<<2)>>2]|0)+(ga<<2)|0;c[z+(fa<<2)>>2]=ia;if((fa|0)<(c[V>>2]|0)){N=fa;aa=da;ba=ia}else{break}}}else{ba=a+1452|0;c[ba>>2]=0;aa=a+1456|0;c[aa>>2]=U;N=(X<<2)-128|0;mrc(Y|0,0,N|0)|0;mrc(_|0,0,N|0)|0;N=c[T>>2]|0;c[Z+(X+3<<2)>>2]=N;c[Y+12>>2]=N;do{if((c[a+692>>2]|0)==0){if((c[a+664>>2]|0)!=0){ja=1;break}if((c[a+18560>>2]|0)<3){ja=1;break}ja=(c[T>>2]|0)<3|0}else{ja=1}}while(0);N=(c[aa>>2]|0)-1|0;Q=ja|-2;H=(c[T>>2]|0)+Q|0;$=(N|0)<(H|0)?N:H;H=c[ba>>2]|0;N=ja^1;ia=(H|0)>(N|0)?H:N;H=a+18560|0;da=(c[H>>2]|0)+Q|0;Q=a+18612|0;c[Q>>2]=$;if(($|0)<(ia|0)){break}fa=a+18608|0;ga=(da|0)<(N|0);ha=o|0;ea=v|0;ka=s;la=a+532|0;ma=m|0;na=m+4|0;oa=n|0;pa=n+4|0;qa=o+8|0;ra=a+19424|0;sa=a+24544|0;ta=a+37448|0;ua=o+4|0;va=o+36|0;wa=o+68|0;xa=o+100|0;ya=o+132|0;za=o+164|0;Aa=o+196|0;Ba=o+228|0;Ca=o+260|0;Da=o+40|0;Ea=a+37328|0;Fa=w|0;Ga=w+4|0;Ha=w+8|0;Ia=a+560|0;Ja=a+36696|0;Ka=a+36896|0;La=a+36740|0;Ma=a+36572|0;Na=a+36576|0;Oa=a+36580|0;Pa=a+36584|0;Qa=a+36588|0;Ra=a+36592|0;Sa=a+684|0;Ta=a+18752|0;Ua=a+18756|0;Va=a+18708|0;Wa=a+18716|0;Xa=p|0;Ya=p+4|0;Za=p+88|0;_a=p+72|0;$a=p+16|0;ab=p+12|0;bb=p+20|0;cb=p+24|0;db=p+28|0;eb=p+32|0;fb=p+68|0;gb=p+128|0;hb=p+132|0;ib=p+216|0;jb=p+200|0;kb=p+140|0;lb=p+144|0;mb=p+148|0;nb=p+152|0;ob=p+156|0;pb=p+160|0;qb=p+196|0;rb=a+18712|0;sb=a+18720|0;tb=a+37400|0;ub=a+37380|0;vb=s;wb=s;xb=s|0;yb=s+8|0;zb=yb;Ab=yb|0;yb=s+4|0;Bb=wb+2|0;Cb=yb+2|0;Db=zb+2|0;Eb=p+112|0;Fb=p+240|0;Gb=Fb;Hb=p+114|0;Ib=p+242|0;Jb=a+18754|0;Kb=a+18758|0;Lb=f+(g<<2)|0;Mb=f+(h<<2)|0;Nb=(j|0)<(h|0);Ob=D-1|0;Pb=C-1|0;Qb=d|0;Rb=Z+(X+1<<2)|0;Sb=Y+4|0;Tb=Y+8|0;Ub=d+12|0;Vb=O+44|0;Wb=h+~g|0;Xb=Nb?2:1;Yb=64-(S>>2)|0;Zb=$;do{c[fa>>2]=da;if(ga){_b=Zb}else{$=da;$b=Zb;while(1){ac=c[Lb>>2]|0;bc=c[Mb>>2]|0;cc=c[A>>2]|0;dc=c[H>>2]|0;ec=(ca(dc,$b)|0)+$|0;fc=c[cc+192>>2]|0;gc=(ca(fc,$b)|0)+$<<3;hc=(c[la>>2]|0)==0?32:Yb;ic=(c[cc+2796+(Ob<<2)>>2]|0)+(ec<<2)|0;c[ma>>2]=ic;c[na>>2]=(c[cc+2864+(Pb<<2)>>2]|0)+(ec<<2);c[oa>>2]=(c[cc+4236+(Ob<<2)>>2]|0)+(ec<<2);c[pa>>2]=(c[cc+4304+(Pb<<2)>>2]|0)+(ec<<2);jc=($|0)>0;do{if(jc){if(!(($|0)<(dc-1|0)&($b|0)>0)){J=37;break}kc=c[T>>2]|0;if(($b|0)<(kc-1|0)|(dc|0)<3){lc=1}else{mc=kc;J=39}}else{J=37}}while(0);do{if((J|0)==37){J=0;if((dc|0)<3){lc=1;break}mc=c[T>>2]|0;J=39}}while(0);if((J|0)==39){J=0;lc=(mc|0)<3}c[sa>>2]=ra;kc=cc+324|0;pe[c[ta>>2]&1023](ra,16,(c[kc>>2]|0)+gc|0,fc,8);do{if(R){nc=268435456;oc=0}else{pc=c[fa>>2]|0;qc=(pc*-8|0)+65532&65535;b[Ta>>1]=qc;rc=c[H>>2]|0;sc=(rc-pc<<3)+65532&65535;b[Ua>>1]=sc;tc=(qc<<16>>16<<2)-32|0;c[Va>>2]=tc;qc=(sc<<16>>16<<2)+32|0;c[Wa>>2]=qc;if((pc|0)>=(rc-2|0)){rc=c[Q>>2]|0;pc=(rc*-8|0)+65532&65535;b[Jb>>1]=pc;sc=((c[T>>2]|0)-rc<<3)+65532&65535;b[Kb>>1]=sc;c[rb>>2]=(pc<<16>>16<<2)-32;c[sb>>2]=(sc<<16>>16<<2)+32}c[Xa>>2]=3;sc=c[Ub>>2]|0;c[Ya>>2]=sc;c[Za>>2]=fc;pc=c[sa>>2]|0;c[_a>>2]=pc;c[$a>>2]=O;c[ab>>2]=0;rc=(c[ac+324>>2]|0)+gc|0;c[bb>>2]=rc;c[cb>>2]=(c[ac+328>>2]|0)+gc;c[db>>2]=(c[ac+332>>2]|0)+gc;c[eb>>2]=(c[ac+336>>2]|0)+gc;c[fb>>2]=rc;if((c[Vb>>2]|0)!=0){c[fb>>2]=(c[cc+2704>>2]|0)+gc}do{if(Nb){rc=c[bc+2796+(Wb<<2)>>2]|0;c[gb>>2]=3;c[hb>>2]=sc;c[ib>>2]=fc;c[jb>>2]=pc;c[kb>>2]=0;c[lb>>2]=2772248;uc=(c[bc+324>>2]|0)+gc|0;c[mb>>2]=uc;c[nb>>2]=(c[bc+328>>2]|0)+gc;c[ob>>2]=(c[bc+332>>2]|0)+gc;c[pb>>2]=(c[bc+336>>2]|0)+gc;c[qb>>2]=uc;uc=b[rc+(ec<<2)>>1]|0;vc=((ca(uc,S)|0)+128|0)>>>8;wc=b[rc+(ec<<2)+2>>1]|0;rc=vc<<16>>16;vc=((ca(wc,S)|0)+128|0)>>>8<<16>>16;xc=tc&65535;if((rc|0)<(tc|0)){yc=xc}else{yc=((rc|0)>(qc|0)?qc:rc)&65535}zc=c[rb>>2]|0;Ac=c[sb>>2]|0;Bc=zc&65535;if((vc|0)<(zc|0)){Cc=Bc}else{Cc=((vc|0)>(Ac|0)?Ac:vc)&65535}Dc=rc-uc<<16>>16;if((Dc|0)<(tc|0)){Ec=xc}else{Ec=((Dc|0)>(qc|0)?qc:Dc)&65535}Dc=vc-wc<<16>>16;if((Dc|0)<(zc|0)){Fc=Bc}else{Fc=((Dc|0)>(Ac|0)?Ac:Dc)&65535}if((c[Ia>>2]|0)<2){Dc=yc&-2;Ac=Cc&-2;Bc=Ec&-2;zc=Fc&-2;wc=Dc<<16>>16;vc=Ac<<16>>16;xc=Bc<<16>>16;uc=zc<<16>>16;rc=(c[p+20+((vc&2|wc>>>1&1)<<2)>>2]|0)+((ca(vc>>2,fc)|0)+(wc>>2))|0;wc=(c[p+148+((uc&2|xc>>>1&1)<<2)>>2]|0)+((ca(uc>>2,fc)|0)+(xc>>2))|0;Se[c[tb>>2]&1023](ha,16,rc,fc,wc,fc,hc);Gc=Dc;Hc=Ac;Ic=Bc;Jc=zc}else{c[q>>2]=16;c[r>>2]=16;zc=Ke[c[ub>>2]&63](ha,q,bb,fc,yc<<16>>16,Cc<<16>>16,8,8,O)|0;Bc=Ke[c[ub>>2]&63](qa,r,mb,c[ib>>2]|0,Ec<<16>>16,Fc<<16>>16,8,8,O)|0;Se[c[tb>>2]&1023](ha,16,zc,c[q>>2]|0,Bc,c[r>>2]|0,hc);Gc=yc;Hc=Cc;Ic=Ec;Jc=Fc}Bc=hf[c[Ka>>2]&1023](c[_a>>2]|0,16,ha,16)|0;zc=(Bc|0)<268435456;Ac=zc?3:0;Dc=zc?Bc:268435456;Bc=Hc&65535;if((0<<16|0>>>16|(Bc<<16|0>>>16)|Gc&65535|0)==0&(Ic&65535|((Jc&65535)<<16|0>>>16)|(0<<16|Bc>>>16)|0)==0){Kc=Dc;Lc=Ac;break}Se[c[tb>>2]&1023](ha,16,c[bb>>2]|0,c[Za>>2]|0,c[mb>>2]|0,c[ib>>2]|0,hc);Bc=hf[c[Ka>>2]&1023](c[_a>>2]|0,16,ha,16)|0;zc=(Bc|0)<(Dc|0);Kc=zc?Bc:Dc;Lc=zc?3:Ac}else{Kc=268435456;Lc=0}}while(0);qc=dc-1|0;tc=dc+1|0;pc=0;sc=Lc;Ac=Kc;zc=ic;while(1){if((c[x+(pc<<2)>>2]|0)==0){c[p+(pc<<7)+112>>2]=c[zc>>2];Dc=c[c[n+(pc<<2)>>2]>>2]|0;c[p+(pc<<7)+108>>2]=Dc;Mc=Dc}else{c[xb>>2]=0;c[Ab>>2]=0;Dc=($|0)<((c[H>>2]|0)-1|0);if(Dc){Bc=c[zc+4>>2]|0;c[xb>>2]=Bc;Nc=1;Oc=Bc}else{Nc=0;Oc=0}do{if(($b|0)<((c[aa>>2]|0)-1|0)){c[ka+(Nc<<2)>>2]=c[zc+(dc<<2)>>2];Bc=Nc+1|0;if(jc){c[ka+(Bc<<2)>>2]=c[zc+(qc<<2)>>2];Pc=Nc|2}else{Pc=Bc}if(Dc){c[ka+(Pc<<2)>>2]=c[zc+(tc<<2)>>2];Qc=Pc+1|0}else{Qc=Pc}if((Qc|0)<2){Rc=Qc;Sc=c[xb>>2]|0;J=70;break}else{Bc=p+(pc<<7)+100|0;wc=b[wb>>1]|0;rc=b[yb>>1]|0;xc=wc-rc|0;uc=xc>>31&xc;xc=uc+rc|0;rc=xc-(b[zb>>1]|0)|0;vc=xc-(rc>>31&rc)|0;rc=wc-uc-vc|0;b[Bc>>1]=(rc>>31&rc)+vc;vc=b[Bb>>1]|0;rc=b[Cb>>1]|0;uc=vc-rc|0;wc=uc>>31&uc;uc=wc+rc|0;rc=uc-(b[Db>>1]|0)|0;xc=uc-(rc>>31&rc)|0;rc=vc-wc-xc|0;b[p+(pc<<7)+102>>1]=(rc>>31&rc)+xc;Tc=Qc;Uc=c[Bc>>2]|0;break}}else{Rc=Nc;Sc=Oc;J=70}}while(0);if((J|0)==70){J=0;c[p+(pc<<7)+100>>2]=Sc;Tc=Rc;Uc=Sc}Dc=p+(pc<<7)|0;do{if((Uc|0)==0){Bc=hf[c[Ka>>2]&1023](c[p+(pc<<7)+72>>2]|0,16,c[p+(pc<<7)+20>>2]|0,c[p+(pc<<7)+88>>2]|0)|0;xc=p+(pc<<7)+108|0;c[xc>>2]=Bc;if((Bc|0)>=64){Vc=xc;J=76;break}c[p+(pc<<7)+112>>2]=0;Wc=0}else{Vc=p+(pc<<7)+108|0;J=76}}while(0);do{if((J|0)==76){J=0;oVb(a,Dc,vb,Tc,0);xc=(c[Vc>>2]|0)-(e[c[Ub>>2]>>1]|0)|0;c[Vc>>2]=xc;Bc=c[p+(pc<<7)+112>>2]|0;if((Bc|0)==0){Wc=0;break}c[Vc>>2]=((c[Qb>>2]|0)*5|0)+xc;Wc=Bc}}while(0);c[zc>>2]=Wc;Dc=p+(pc<<7)+108|0;c[c[n+(pc<<2)>>2]>>2]=c[Dc>>2];Mc=c[Dc>>2]|0}Dc=(Mc|0)<(Ac|0);Bc=pc+1|0;Xc=Dc?Bc:sc;Yc=Dc?Mc:Ac;if((Bc|0)>=(Xb|0)){break}pc=Bc;sc=Xc;Ac=Yc;zc=c[m+(Bc<<2)>>2]|0}if(!Nb){nc=Yc;oc=Xc;break}zc=c[Eb>>2]|0;Ac=zc&65535;if((zc|0)==0){if((c[Gb>>2]|0)==0){nc=Yc;oc=Xc;break}}if((c[Ia>>2]|0)<2){zc=Ac<<16>>16;sc=b[Hb>>1]|0;pc=b[Fb>>1]|0;tc=b[Ib>>1]|0;qc=c[Za>>2]|0;Bc=(c[p+20+((sc&2|zc>>>1&1)<<2)>>2]|0)+((ca(qc,sc>>2)|0)+(zc>>2))|0;zc=c[ib>>2]|0;sc=(c[p+148+((pc>>>1&1|tc&2)<<2)>>2]|0)+((ca(zc,tc>>2)|0)+(pc>>2))|0;Se[c[tb>>2]&1023](ha,16,Bc,qc,sc,zc,hc)}else{c[t>>2]=16;c[u>>2]=16;zc=Ke[c[ub>>2]&63](ha,t,bb,c[Za>>2]|0,Ac<<16>>16,b[Hb>>1]|0,8,8,O)|0;Ac=Ke[c[ub>>2]&63](qa,u,mb,c[ib>>2]|0,b[Fb>>1]|0,b[Ib>>1]|0,8,8,O)|0;Se[c[tb>>2]&1023](ha,16,zc,c[t>>2]|0,Ac,c[u>>2]|0,hc)}Ac=(c[Qb>>2]|0)*5|0;zc=(hf[c[Ka>>2]&1023](c[_a>>2]|0,16,ha,16)|0)+Ac|0;Ac=(zc|0)<(Yc|0);nc=Ac?zc:Yc;oc=Ac?3:Xc}}while(0);do{if((c[cc+8508>>2]|0)==0){hc=c[kc>>2]|0;jc=c[Qb>>2]|0;nrc(qa|0,hc+(gc-fc)|0,16)|0;dc=gc-4|0;c[ua>>2]=c[hc+(dc-fc)>>2];c[va>>2]=c[hc+dc>>2];c[wa>>2]=c[hc+(dc+fc)>>2];c[xa>>2]=c[hc+(dc+(fc<<1))>>2];c[ya>>2]=c[hc+(dc+(fc*3|0))>>2];c[za>>2]=c[hc+(dc+(fc<<2))>>2];c[Aa>>2]=c[hc+(dc+(fc*5|0))>>2];c[Ba>>2]=c[hc+(dc+(fc*6|0))>>2];c[Ca>>2]=c[hc+(dc+(fc*7|0))>>2];ef[c[Ea>>2]&4095](c[sa>>2]|0,Da,Fa);dc=c[Fa>>2]|0;hc=c[Ga>>2]|0;ic=c[Ha>>2]|0;bc=(hc|0)<(ic|0)?hc:ic;ic=(dc|0)<(bc|0)?dc:bc;if((c[Ia>>2]|0)>1){qe[c[Ja>>2]&1023](Da);bc=hf[c[Ka>>2]&1023](Da,32,c[sa>>2]|0,16)|0;dc=(ic|0)<(bc|0)?ic:bc;mf[c[La>>2]&2047](Da,ea,15,15);re[c[Ma>>2]&1023](Da,ea);bc=hf[c[Ka>>2]&1023](Da,32,c[sa>>2]|0,16)|0;hc=(dc|0)<(bc|0)?dc:bc;re[c[Na>>2]&1023](Da,ea);bc=hf[c[Ka>>2]&1023](Da,32,c[sa>>2]|0,16)|0;dc=(hc|0)<(bc|0)?hc:bc;re[c[Oa>>2]&1023](Da,ea);bc=hf[c[Ka>>2]&1023](Da,32,c[sa>>2]|0,16)|0;hc=(dc|0)<(bc|0)?dc:bc;re[c[Pa>>2]&1023](Da,ea);bc=hf[c[Ka>>2]&1023](Da,32,c[sa>>2]|0,16)|0;dc=(hc|0)<(bc|0)?hc:bc;re[c[Qa>>2]&1023](Da,ea);bc=hf[c[Ka>>2]&1023](Da,32,c[sa>>2]|0,16)|0;hc=(dc|0)<(bc|0)?dc:bc;re[c[Ra>>2]&1023](Da,ea);bc=hf[c[Ka>>2]&1023](Da,32,c[sa>>2]|0,16)|0;Zc=(hc|0)<(bc|0)?hc:bc}else{Zc=ic}ic=(jc*5|0)+4+Zc|0;b[(c[cc+8512>>2]|0)+(ec<<1)>>1]=ic;if((c[Sa>>2]|0)==0){_c=ic}else{_c=(ca(e[(c[cc+8520>>2]|0)+(ec<<1)>>1]|0,ic)|0)+128>>8}jc=Z+(X+((c[Q>>2]|0)+4-(c[ba>>2]|0))<<2)|0;c[jc>>2]=(c[jc>>2]|0)+_c;if(!lc){break}c[_>>2]=(c[_>>2]|0)+ic;c[Rb>>2]=(c[Rb>>2]|0)+_c}}while(0);fc=nc+4|0;do{if(Nb){$c=fc;ad=oc}else{gc=e[(c[cc+8512>>2]|0)+(ec<<1)>>1]|0;kc=(gc|0)<(fc|0);ic=kc?0:oc;jc=kc?gc:fc;if(!lc){$c=jc;ad=ic;break}c[Tb>>2]=(c[Tb>>2]|0)+(kc&1);$c=jc;ad=ic}}while(0);do{if(!R){if((c[Sa>>2]|0)==0){bd=$c}else{bd=(ca(e[(c[cc+8520>>2]|0)+(ec<<1)>>1]|0,$c)|0)+128>>8}fc=Z+((c[Q>>2]|0)+4-(c[ba>>2]|0)<<2)|0;c[fc>>2]=(c[fc>>2]|0)+bd;if(!lc){break}c[Z>>2]=(c[Z>>2]|0)+$c;c[Sb>>2]=(c[Sb>>2]|0)+bd}}while(0);b[(c[cc+2940+(D*72|0)+(C<<2)>>2]|0)+(ec<<1)>>1]=(($c|0)<16383?$c:16383)+(ad<<14);fc=(c[fa>>2]|0)-1|0;c[fa>>2]=fc;ic=c[Q>>2]|0;if((fc|0)<(N|0)){_b=ic;break}else{$=fc;$b=ic}}}Zb=_b-1|0;c[Q>>2]=Zb;}while((Zb|0)>=(ia|0))}}while(0);Z=(j|0)==(h|0);if(Z){c[B+7116+(D<<2)>>2]=0}R=B+8508|0;if((c[R>>2]|0)==0){c[E>>2]=0;c[B+5816>>2]=0}c[F>>2]=0;_=B+5816+(D*72|0)+(C<<2)|0;c[_>>2]=0;if((c[V>>2]|0)>0){X=B+7116+(D<<2)|0;T=E|0;Y=B+5816|0;U=a+664|0;W=c[B+7188+(D*72|0)+(C<<2)>>2]|0;ia=c[B+7188>>2]|0;Zb=0;while(1){if(Z){c[X>>2]=(c[X>>2]|0)+(c[(c[y+(Zb<<2)>>2]|0)+8>>2]|0)}if((c[R>>2]|0)==0){Q=c[z+(Zb<<2)>>2]|0;c[T>>2]=(c[T>>2]|0)+(c[Q>>2]|0);c[Y>>2]=(c[Y>>2]|0)+(c[Q+4>>2]|0)}Q=c[y+(Zb<<2)>>2]|0;c[F>>2]=(c[F>>2]|0)+(c[Q>>2]|0);c[_>>2]=(c[_>>2]|0)+(c[Q+4>>2]|0);if((c[U>>2]|0)==0){cd=ia;dd=W}else{N=c[Q+12>>2]|0;fa=N<<2;nrc(W|0,Q+16|0,fa)|0;if((c[R>>2]|0)==0){nrc(ia|0,(c[z+(Zb<<2)>>2]|0)+16|0,fa)|0}cd=ia+(N<<2)|0;dd=W+(N<<2)|0}N=Zb+1|0;if((N|0)<(c[V>>2]|0)){W=dd;ia=cd;Zb=N}else{break}}ed=c[F>>2]|0}else{ed=0}if(L){Zb=Erc(ed,(ed|0)<0|0?-1:0,100,0)|0;ia=(c[a+120>>2]|0)+120|0;W=Frc(Zb,G,ia,(ia|0)<0|0?-1:0)|0;fd=W}else{c[R>>2]=1;fd=ed}c[F>>2]=fd;I=fd}}while(0);if((k|0)==0){gd=I;i=l;return gd|0}k=c[a+18560>>2]|0;fd=c[a+18564>>2]|0;if((k|0)>2&(fd|0)>2){hd=ca(fd-2|0,k-2|0)|0}else{hd=ca(fd,k)|0}k=I;fd=(I|0)<0|0?-1:0;I=c[B+7116+(D<<2)>>2]|0;D=Erc(I,(I|0)<0|0?-1:0,k,fd)|0;I=hd<<3;hd=Frc(D,G,I,(I|0)<0|0?-1:0)|0;I=wrc(hd,G,k,fd)|0;gd=I;i=l;return gd|0}function rUb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d+2796+((c[d+92>>2]|0)-1-(c[e+92>>2]|0)<<2)|0;if((b[c[g>>2]>>1]|0)==32767){h=c[e+324>>2]|0;return h|0}i=c[d+192>>2]|0;j=c[d+200>>2]|0;k=c[d+196>>2]|0;if((j|0)<=0){h=f;return h|0}d=(k|0)>0;l=i<<3;m=a+37376|0;a=e+324|0;e=f;n=0;o=0;while(1){if(d){p=n<<2;q=0;r=o;while(1){s=c[g>>2]|0;Te[c[m>>2]&255](e+q|0,i,a,i,(b[s+(r<<2)>>1]|0)+(q<<2)|0,(b[s+(r<<2)+2>>1]|0)+p|0,8,8,2772248);s=q+8|0;t=r+1|0;if((s|0)<(k|0)){q=s;r=t}else{u=t;break}}}else{u=o}r=n+8|0;if((r|0)<(j|0)){e=e+l|0;n=r;o=u}else{h=f;break}}return h|0}function sUb(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;i=i+64|0;h=g|0;j=c[b+192>>2]|0;k=c[b+200>>2]|0;l=c[b+196>>2]|0;m=c[b+324>>2]|0;n=(k|0)>0;if((f|0)==0){if(!n){o=0;i=g;return o|0}p=(l|0)>0;q=a+36896|0;r=b+8512|0;s=0;t=0;u=0;v=0;while(1){if(p){w=s;x=t;y=0;z=v;while(1){A=hf[c[q>>2]&1023](d+x|0,j,m+x|0,j)|0;B=e[(c[r>>2]|0)+(w<<1)>>1]|0;C=((A|0)<(B|0)?A:B)+z|0;B=y+8|0;A=w+1|0;if((B|0)<(l|0)){w=A;x=x+8|0;y=B;z=C}else{D=A;E=C;break}}}else{D=s;E=v}z=u+8|0;y=ca(z,j)|0;if((z|0)<(k|0)){s=D;t=y;u=z;v=E}else{o=E;break}}i=g;return o|0}else{if(n){n=(l|0)>0;E=f+44|0;v=h|0;h=a+36896|0;u=b+8512|0;b=0;t=0;D=0;s=0;while(1){if(n){r=b;q=0;p=D;z=s;while(1){_e[c[(c[E>>2]|0)+8>>2]&511](v,8,d+p|0,j,f,8);y=hf[c[h>>2]&1023](v,8,m+p|0,j)|0;x=e[(c[u>>2]|0)+(r<<1)>>1]|0;w=((y|0)<(x|0)?y:x)+z|0;x=q+8|0;y=r+1|0;if((x|0)<(l|0)){r=y;q=x;p=p+8|0;z=w}else{F=y;G=w;break}}}else{F=b;G=s}z=t+8|0;p=ca(z,j)|0;if((z|0)<(k|0)){b=F;t=z;D=p;s=G}else{H=G;break}}}else{H=0}o=(FUb(a,f,0)|0)+H|0;i=g;return o|0}return 0}function tUb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=c[d+156+(g<<2)>>2]|0;i=c[d+180+(g<<2)>>2]|0;j=c[d+168+(g<<2)>>2]|0;k=d+2796+((c[d+92>>2]|0)-1-(c[e+92>>2]|0)<<2)|0;if((b[c[k>>2]>>1]|0)==32767){l=c[e+204+(g<<2)>>2]|0;return l|0}zOb(a,e,g);if((i|0)<=0){l=f;return l|0}d=(j|0)>0;m=e+204+(g<<2)|0;g=a+37464|0;a=0;e=0;n=0;while(1){if(d){o=0;p=e;while(1){q=o+a|0;r=c[k>>2]|0;s=(c[m>>2]|0)+(((b[r+(p<<2)>>1]|0)/2|0)+q+(ca((b[r+(p<<2)+2>>1]|0)/2|0,h)|0))|0;pe[c[g>>2]&1023](f+q|0,h,s,h,16);s=o+16|0;q=p+1|0;if((s|0)<(j|0)){o=s;p=q}else{t=q;break}}}else{t=e}p=n+16|0;o=ca(p,h)|0;if((p|0)<(i|0)){a=o;e=t;n=p}else{l=f;break}}return l|0}function uUb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+256|0;h=g|0;j=c[b+156+(f<<2)>>2]|0;k=c[b+180+(f<<2)>>2]|0;l=c[b+168+(f<<2)>>2]|0;m=c[b+204+(f<<2)>>2]|0;f=(k|0)>0;if((e|0)==0){if(!f){n=0;i=g;return n|0}b=(l|0)>0;o=a+36884|0;p=0;q=0;r=0;while(1){if(b){s=p;t=q;u=0;while(1){v=(hf[c[o>>2]&1023](d+t|0,j,m+t|0,j)|0)+s|0;w=u+16|0;if((w|0)<(l|0)){s=v;t=t+16|0;u=w}else{x=v;break}}}else{x=p}u=r+16|0;t=ca(u,j)|0;if((u|0)<(k|0)){p=x;q=t;r=u}else{n=x;break}}i=g;return n|0}else{if(f){f=(l|0)>0;x=e+44|0;r=h|0;h=a+36884|0;q=0;p=0;o=0;while(1){if(f){b=q;u=p;t=0;while(1){_e[c[(c[x>>2]|0)+16>>2]&511](r,16,d+u|0,j,e,16);s=(hf[c[h>>2]&1023](r,16,m+u|0,j)|0)+b|0;v=t+16|0;if((v|0)<(l|0)){b=s;u=u+16|0;t=v}else{y=s;break}}}else{y=q}t=o+16|0;u=ca(t,j)|0;if((t|0)<(k|0)){q=y;p=u;o=t}else{z=y;break}}}else{z=0}n=(FUb(a,e,1)|0)+z|0;i=g;return n|0}return 0}function vUb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=c[d+160>>2]|0;i=(h|0)/2|0;j=c[d+184>>2]|0;k=c[d+172>>2]|0;l=c[a+18576>>2]|0;m=c[a+18560>>2]<<3;n=c[a+18564>>2]<<4>>l;o=16>>>(l>>>0);p=d+2796+((c[d+92>>2]|0)-1-(c[e+92>>2]|0)<<2)|0;if((b[c[p>>2]>>1]|0)==32767){q=a+37488|0;Ge[c[q>>2]&255](f,h,g,h,c[e+208>>2]|0,h,m,n);r=q;s=c[r>>2]|0;t=f+i|0;u=g+i|0;v=d+208|0;w=c[v>>2]|0;Ge[s&255](t,h,u,h,w,h,m,n);return}zOb(a,e,1);if((j|0)>0){q=(k|0)>0;x=e+208|0;e=a+37384|0;y=0;z=0;A=0;while(1){if(q){B=0;C=z;while(1){D=B+y|0;E=c[p>>2]|0;Te[c[e>>2]&255](f+D|0,g+D|0,h,(c[x>>2]|0)+((B<<1)+y)|0,h,b[E+(C<<2)>>1]|0,b[E+(C<<2)+2>>1]<<1>>l,8,o);E=B+8|0;D=C+1|0;if((E|0)<(k|0)){B=E;C=D}else{F=D;break}}}else{F=z}C=A+o|0;B=ca(C,h)|0;if((C|0)<(j|0)){y=B;z=F;A=C}else{break}}}r=a+37488|0;s=c[r>>2]|0;t=f+i|0;u=g+i|0;v=d+208|0;w=c[v>>2]|0;Ge[s&255](t,h,u,h,w,h,m,n);return}function wUb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+128|0;j=h|0;k=b>>1;l=16>>>((c[a+18576>>2]|0)>>>0);m=(e|0)>0;if((g|0)==0){if(!m){n=0;i=h;return n|0}o=(d|0)>0;p=a+37072|0;q=0;r=0;s=0;while(1){if(o){t=q;u=r;v=0;while(1){w=(Xe[c[p>>2]&511](f+t|0,b,f+(t+k)|0,b,l)|0)+u|0;x=v+8|0;if((x|0)<(d|0)){t=t+8|0;u=w;v=x}else{y=w;break}}}else{y=r}v=s+l|0;u=ca(v,b)|0;if((v|0)<(e|0)){q=u;r=y;s=v}else{n=y;break}}i=h;return n|0}else{if(m){m=(d|0)>0;y=g+44|0;s=j|0;j=a+37072|0;r=0;q=0;p=0;while(1){if(m){o=r;v=q;u=0;while(1){_e[c[(c[y>>2]|0)+8>>2]&511](s,8,f+o|0,b,g,l);t=(Xe[c[j>>2]&511](s,8,f+(o+k)|0,b,l)|0)+v|0;w=u+8|0;if((w|0)<(d|0)){o=o+8|0;v=t;u=w}else{z=t;break}}}else{z=q}u=p+l|0;v=ca(u,b)|0;if((u|0)<(e|0)){r=v;q=z;p=u}else{A=z;break}}}else{A=0}n=(FUb(a,g,1)|0)+A|0;i=h;return n|0}return 0}function xUb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;e=i;i=i+18560|0;f=e|0;g=e+504|0;j=e+13272|0;k=e+14288|0;mrc(j|0,0,1012)|0;l=c[b+18560>>2]|0;m=c[b+18564>>2]|0;if((l|0)>2&(m|0)>2){n=ca(m-2|0,l-2|0)|0}else{n=ca(m,l)|0}l=c[b+38024>>2]|0;m=c[l+52>>2]|0;o=(m|0)<250?m:250;if((c[b+664>>2]|0)==0){p=0}else{p=(c[b+696>>2]|0)!=0}if((c[b+16>>2]|0)==0){q=o}else{m=1-d+(c[l+8>>2]|0)|0;q=(o|0)<(m|0)?o:m}m=(d|0)!=0;d=m&1;if((c[b+15136>>2]|0)==0){Cd(2347976,2286680,1461,2649160)}o=c[l+12>>2]|0;if((o|0)==0){i=e;return}r=j|0;c[r>>2]=o;a:do{if((q|0)>0){o=0;while(1){s=c[(c[l+44>>2]|0)+(o<<2)>>2]|0;if((c[s+16>>2]|0)!=0){t=o;break a}u=o+1|0;c[j+(u<<2)>>2]=s;if((u|0)<(q|0)){o=u}else{t=u;break}}}else{t=0}}while(0);c[g+8>>2]=12;o=g|0;c[o>>2]=1;c[g+12>>2]=c[b+1864>>2];u=(c[b+3304>>2]|0)-1|0;if((u|0)<0){v=0}else{v=(u|0)>2?2:u}c[g+16>>2]=3041168+(v*66|0);v=(c[b+3308>>2]|0)-1|0;if((v|0)<0){w=0}else{w=(v|0)>2?2:v}c[g+20>>2]=3041168+(w*66|0);if((c[b+560>>2]|0)>1){w=c[b+544>>2]|0;c[b+18628>>2]=(w|0)>1?1:w;c[b+18632>>2]=4}else{c[b+18628>>2]=0;c[b+18632>>2]=2}c[b+18636>>2]=0;if((t|0)==0){if((c[b+692>>2]|0)==0){i=e;return}yUb(b,g,r,0,d);i=e;return}w=b+96|0;v=(c[l+4>>2]|0)+((c[w>>2]|0)-(c[(c[r>>2]|0)+92>>2]|0))|0;l=v-1|0;u=b+108|0;if((c[u>>2]|0)==0){x=(t|0)<(l|0)?t:l}else{x=t}if((c[b+596>>2]|0)==0){if(p){z=t}else{A=29}}else{if((c[b+692>>2]|0)!=0|p){z=t}else{A=29}}do{if((A|0)==29){if((c[b+128>>2]|0)!=0&(x|0)<(t|0)){z=x+1|0;break}if((x|0)!=0){z=x;break}c[(c[j+4>>2]|0)+16>>2]=2;i=e;return}}while(0);t=b+104|0;l=b+112|0;do{if((c[t>>2]|0)!=0){s=c[l>>2]|0;do{if((s|0)!=0){B=(c[b+116>>2]|0)==2?s+1|0:2;C=(B|0)<(x|0)?B:x;if((C|0)>=1){D=1;do{if((CUb(b,g,r,0,D,0)|0)==0&(D|0)>0){E=D;do{c[(c[j+(E<<2)>>2]|0)+8524>>2]=0;E=E-1|0;}while((E|0)>0)}D=D+1|0;}while((D|0)<=(C|0))}if((C|0)<0){break}D=(B|0)>(q|0);E=0;do{do{if(D){A=44}else{if((E|0)>=(C|0)){break}if((CUb(b,g,r,E,C,0)|0)!=0){A=44}}}while(0);if((A|0)==44){A=0;c[(c[j+(E<<2)>>2]|0)+8524>>2]=0}E=E+1|0;}while((E|0)<=(C|0))}}while(0);s=j+4|0;if((c[(c[s>>2]|0)+8524>>2]|0)==0){break}if((CUb(b,g,r,0,1,1)|0)==0){break}c[(c[s>>2]|0)+16>>2]=2;i=e;return}}while(0);AVb(b,r,z,c[o>>2]|0);q=c[l>>2]|0;do{if((q|0)==0){if((z|0)>=1){x=1;do{c[(c[j+(x<<2)>>2]|0)+16>>2]=3;x=x+1|0;}while((x|0)<=(z|0))}F=2-d|0}else{x=c[b+116>>2]|0;b:do{if((x|0)==1){s=z-2|0;if((s|0)>=0){C=(n|0)/2|0;E=b+816|0;D=b+120|0;B=z-1|0;H=(n|0)/3|0;I=0;while(1){J=I+2|0;K=qUb(b,g,r,I,J,J,1)|0;L=c[j+(J<<2)>>2]|0;do{if((c[L+7124>>2]|0)>(C|0)){c[(c[j+(I+1<<2)>>2]|0)+16>>2]=3;c[L+16>>2]=3;M=J}else{do{if((c[E>>2]|0)==0){N=I+1|0}else{O=I+1|0;P=CVb(b,r,c[o>>2]|0,I,J,O)|0;Q=CVb(b,r,c[o>>2]|0,I,O,O)|0|P;if((Q|(CVb(b,r,c[o>>2]|0,O,J,J)|0)|0)==0){N=O;break}vVb(b);N=O}}while(0);O=qUb(b,g,r,I,J,N,0)|0;Q=qUb(b,g,r,I,N,N,0)|0;P=((qUb(b,g,r,N,J,J,0)|0)+Q|0)<(O+K|0);O=(c[j+(N<<2)>>2]|0)+16|0;if(P){c[O>>2]=3;M=N;break}c[O>>2]=5;O=(c[l>>2]|0)+I|0;c:do{if((J|0)>(((O|0)<(B|0)?O:B)|0)){R=J}else{P=J;while(1){Q=P-I|0;S=300-(ca(50-(c[D>>2]|0)|0,Q-1|0)|0)|0;T=P+1|0;if((qUb(b,g,r,I,T,T,1)|0)>(ca((S|0)>30?S:30,n)|0)){R=P;break c}if((c[(c[j+(T<<2)>>2]|0)+7116+(Q+1<<2)>>2]|0)>(H|0)){R=P;break c}c[(c[j+(P<<2)>>2]|0)+16>>2]=5;Q=(c[l>>2]|0)+I|0;if((T|0)>(((Q|0)<(B|0)?Q:B)|0)){R=T;break}else{P=T}}}}while(0);c[(c[j+(R<<2)>>2]|0)+16>>2]=3;M=R}}while(0);if((M|0)>(s|0)){break}else{I=M}}}c[(c[j+(z<<2)>>2]|0)+16>>2]=3;I=0;while(1){if((I|0)>=(z|0)){U=I;break b}s=I+1|0;if((c[(c[j+(s<<2)>>2]|0)+16>>2]|0)==5){I=s}else{U=I;break}}}else if((x|0)==2){if((z|0)>1){mrc(k|0,0,4267)|0;a[k+251|0]=80;I=(z|0)%17|0;s=b+124|0;B=2;H=q;while(1){D=H+1|0;E=(D|0)<(B|0)?D:B;if((E|0)>0){D=0;C=0;J=268435456;while(1){K=D+1|0;L=B-K|0;O=f+(C*251|0)|0;nrc(O|0,k+(((L|0)%17|0)*251|0)|0,L)|0;mrc(f+(C*251|0)+L|0,66,D|0)|0;P=L+D+(f+(C*251|0))|0;y=80;a[P]=y;y=y>>8;a[P+1|0]=y;d:do{if((a[O]|0)==0){V=0}else{P=1;L=0;T=0;while(1){Q=P;while(1){W=Q+1|0;if((a[Q-1+(f+(C*251|0))|0]|0)==80){break}else{Q=W}}S=(qUb(b,g,r,T,Q,Q,0)|0)+L|0;if((S|0)>(J|0)){V=S;break d}do{if((c[s>>2]|0)==0){A=63}else{X=Q-T|0;if((X|0)<=2){A=63;break}Y=((X|0)/2|0)+T|0;X=(qUb(b,g,r,T,Q,Y,0)|0)+S|0;if((P|0)<(Y|0)&(X|0)<(J|0)){Z=X;_=P;while(1){$=(qUb(b,g,r,T,Y,_,0)|0)+Z|0;aa=_+1|0;if((aa|0)<(Y|0)&($|0)<(J|0)){Z=$;_=aa}else{ba=$;break}}}else{ba=X}_=Y+1|0;if((_|0)<(Q|0)&(ba|0)<(J|0)){da=ba;ea=_}else{fa=ba;break}while(1){_=(qUb(b,g,r,Y,Q,ea,0)|0)+da|0;Z=ea+1|0;if((Z|0)<(Q|0)&(_|0)<(J|0)){da=_;ea=Z}else{fa=_;break}}}}while(0);do{if((A|0)==63){A=0;if((P|0)<(Q|0)&(S|0)<(J|0)){ga=S;ha=P}else{fa=S;break}while(1){Y=(qUb(b,g,r,T,Q,ha,0)|0)+ga|0;X=ha+1|0;if((X|0)<(Q|0)&(Y|0)<(J|0)){ga=Y;ha=X}else{fa=Y;break}}}}while(0);if((a[f+(C*251|0)+Q|0]|0)==0){V=fa;break}else{P=W;L=fa;T=Q}}}}while(0);O=(V|0)<(J|0);ia=O&1^C;if((K|0)<(E|0)){D=K;C=ia;J=O?V:J}else{break}}ja=ia^1}else{ja=1}nrc(k+(((B|0)%17|0)*251|0)|0,f+(ja*251|0)|0,B)|0;J=B+1|0;if((J|0)>(z|0)){break}B=J;H=c[l>>2]|0}H=ud(k+(I*251|0)|0,2236840)|0;B=1;while(1){c[(c[j+(B<<2)>>2]|0)+16>>2]=(a[B-1+(k+(I*251|0))|0]|0)==66?5:3;s=B+1|0;if((s|0)<(z|0)){B=s}else{ka=H;break}}}else{ka=0}c[(c[j+(z<<2)>>2]|0)+16>>2]=3;U=ka}else{H=z-1|0;B=(H|0)<(q|0)?H:q;if((z|0)>1){H=B+1|0;I=1;do{c[(c[j+(I<<2)>>2]|0)+16>>2]=((I|0)%(H|0)|0|0)!=0?5:3;I=I+1|0;}while((I|0)<(z|0))}c[(c[j+(z<<2)>>2]|0)+16>>2]=3;U=B}}while(0);x=U+1|0;e:do{if((U|0)>0){I=1;f:while(1){H=I+1|0;do{if((c[t>>2]|0)!=0){if((c[(c[j+(H<<2)>>2]|0)+8524>>2]|0)==0){break}if((CUb(b,g,r,I,H,0)|0)!=0){break f}}}while(0);if((H|0)<(x|0)){I=H}else{la=z;break e}}c[(c[j+(I<<2)>>2]|0)+16>>2]=3;la=I}else{la=z}}while(0);if(m){F=1;break}x=U+2|0;B=la+1|0;F=(x|0)<(B|0)?x:B}}while(0);la=b+692|0;if((c[la>>2]|0)!=0){U=c[w>>2]|0;yUb(b,g,r,(z|0)<(U|0)?z:U,d)}if((c[u>>2]|0)!=0|(v|0)>(z|0)){ma=F}else{d=b+128|0;U=b+132|0;t=F;F=v;while(1){c[(c[j+(F<<2)>>2]|0)+16>>2]=2;v=F+1|0;q=(t|0)<(v|0)?t:v;do{if((c[d>>2]|0)==0){na=F}else{if((c[U>>2]|0)==0){na=F;break}else{oa=F}while(1){v=oa-1|0;if(((c[(c[j+(v<<2)>>2]|0)+16>>2]|0)-4|0)>>>0<2>>>0){oa=v}else{na=oa;break}}}}while(0);I=(c[w>>2]|0)+na|0;if((I|0)>(z|0)){ma=q;break}else{t=q;F=I}}}if(p){p=1;while(1){pa=c[j+(p<<2)>>2]|0;if((p|0)>=(z|0)){qa=0;break}if((c[pa+16>>2]|0)==5){p=p+1|0}else{qa=1;break}}F=m?0:p;m=pa+11936|0;t=c[m>>2]|0;na=c[m+4>>2]|0;m=-1;if((na|0)>(m|0)|(na|0)==(m|0)&t>>>0>-1>>>0){m=b+1600|0;c[m>>2]=t;c[m+4>>2]=na;na=pa+11944|0;pa=c[na+4>>2]|0;m=b+1608|0;c[m>>2]=c[na>>2];c[m+4>>2]=pa}if(qa){qa=b+684|0;pa=j+(F<<2)|0;m=b+1600|0;na=b+1608|0;t=b+8620|0;w=b+8524|0;oa=b+8528|0;U=0;d=0;I=0;v=p;p=0;while(1){if((F|0)==(v|0)){ra=I;sa=d;ta=U}else{ka=j+(v<<2)|0;k=((c[(c[ka>>2]|0)+16>>2]|0)-1|0)>>>0<2>>>0?v:p;l=qUb(b,g,r,k,v,v,0)|0;do{if((c[qa>>2]|0)==0){ua=l}else{if((c[la>>2]|0)==0){ua=c[(c[ka>>2]|0)+5816+((v-k|0)*72|0)>>2]|0;break}else{ua=BUb(b,r,k,v,v)|0;break}}}while(0);k=c[pa>>2]|0;c[k+8924+(U<<2)>>2]=ua;a[k+8672+U|0]=c[(c[ka>>2]|0)+16>>2];k=c[m+4>>2]|0;l=c[ka>>2]|0;q=l+11936|0;c[q>>2]=c[m>>2];c[q+4>>2]=k;k=c[na+4>>2]|0;q=l+11944|0;c[q>>2]=c[na>>2];c[q+4>>2]=k;k=c[na>>2]|0;q=c[na+4>>2]|0;ja=l+72|0;c[ja>>2]=k;c[ja+4>>2]=q;f=l+104|0;ia=xrc(c[f>>2]|0,c[f+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;f=l+80|0;V=c[t>>2]<<1;fa=wrc(V,(V|0)<0|0?-1:0,ia,G)|0;ia=G;c[f>>2]=fa;c[f+4>>2]=ia;V=0;if((ia|0)<(V|0)|(ia|0)==(V|0)&fa>>>0<0>>>0){V=wrc(fa,ia,k,q)|0;c[ja>>2]=V;c[ja+4>>2]=G;c[f>>2]=0;c[f+4>>2]=0}do{if((c[l+124>>2]|0)!=0){if((c[u>>2]|0)!=0){break}c[na>>2]=0;c[na+4>>2]=0}}while(0);ka=l+48|0;f=wrc(c[na>>2]|0,c[na+4>>2]|0,c[ka>>2]|0,c[ka+4>>2]|0)|0;c[na>>2]=f;c[na+4>>2]=G;f=wrc(c[m>>2]|0,c[m+4>>2]|0,c[ka>>2]|0,c[ka+4>>2]|0)|0;c[m>>2]=f;c[m+4>>2]=G;f=c[ka>>2]|0;ja=c[ka+4>>2]|0;ka=l+64|0;c[ka>>2]=f;c[ka+4>>2]=ja;if((d|0)==0){va=c[w>>2]|0;wa=c[oa>>2]|0;xa=c[pa>>2]|0}else{ka=d+64|0;V=c[w>>2]|0;q=c[oa>>2]|0;k=c[pa>>2]|0;h[k+9928+(I<<3)>>3]=(+((c[ka>>2]|0)>>>0)+ +(c[ka+4>>2]|0)*4294967296.0)*+(V>>>0>>>0)/+(q>>>0>>>0);va=V;wa=q;xa=k}h[xa+9928+(U<<3)>>3]=(+(f>>>0)+ +(ja|0)*4294967296.0)*+(va>>>0>>>0)/+(wa>>>0>>>0);ra=U;sa=l;ta=U+1|0}ja=p+1|0;if((ja|0)<(v|0)){f=ta;k=sa;q=ra;V=ja;while(1){ja=qUb(b,g,r,p,v,V,0)|0;do{if((c[qa>>2]|0)==0){ya=ja}else{if((c[la>>2]|0)==0){ya=c[(c[j+(V<<2)>>2]|0)+5816+((V-p|0)*72|0)+(v-V<<2)>>2]|0;break}else{ya=BUb(b,r,p,v,V)|0;break}}}while(0);ja=c[pa>>2]|0;c[ja+8924+(f<<2)>>2]=ya;a[ja+8672+f|0]=5;ja=c[m+4>>2]|0;za=c[j+(V<<2)>>2]|0;ka=za+11936|0;c[ka>>2]=c[m>>2];c[ka+4>>2]=ja;ja=c[na+4>>2]|0;ka=za+11944|0;c[ka>>2]=c[na>>2];c[ka+4>>2]=ja;ja=c[na>>2]|0;ka=c[na+4>>2]|0;ia=za+72|0;c[ia>>2]=ja;c[ia+4>>2]=ka;fa=za+104|0;W=xrc(c[fa>>2]|0,c[fa+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;fa=za+80|0;ha=c[t>>2]<<1;ga=wrc(ha,(ha|0)<0|0?-1:0,W,G)|0;W=G;c[fa>>2]=ga;c[fa+4>>2]=W;ha=0;if((W|0)<(ha|0)|(W|0)==(ha|0)&ga>>>0<0>>>0){ha=wrc(ga,W,ja,ka)|0;c[ia>>2]=ha;c[ia+4>>2]=G;c[fa>>2]=0;c[fa+4>>2]=0}do{if((c[za+124>>2]|0)!=0){if((c[u>>2]|0)!=0){break}c[na>>2]=0;c[na+4>>2]=0}}while(0);fa=za+48|0;ia=wrc(c[na>>2]|0,c[na+4>>2]|0,c[fa>>2]|0,c[fa+4>>2]|0)|0;c[na>>2]=ia;c[na+4>>2]=G;ia=wrc(c[m>>2]|0,c[m+4>>2]|0,c[fa>>2]|0,c[fa+4>>2]|0)|0;c[m>>2]=ia;c[m+4>>2]=G;ia=c[fa>>2]|0;ha=c[fa+4>>2]|0;fa=za+64|0;c[fa>>2]=ia;c[fa+4>>2]=ha;if((k|0)==0){Aa=c[w>>2]|0;Ba=c[oa>>2]|0;Ca=c[pa>>2]|0}else{fa=k+64|0;ka=c[w>>2]|0;ja=c[oa>>2]|0;W=c[pa>>2]|0;h[W+9928+(q<<3)>>3]=(+((c[fa>>2]|0)>>>0)+ +(c[fa+4>>2]|0)*4294967296.0)*+(ka>>>0>>>0)/+(ja>>>0>>>0);Aa=ka;Ba=ja;Ca=W}h[Ca+9928+(f<<3)>>3]=(+(ia>>>0)+ +(ha|0)*4294967296.0)*+(Aa>>>0>>>0)/+(Ba>>>0>>>0);ha=V+1|0;if((ha|0)<(v|0)){q=f;f=f+1|0;k=za;V=ha}else{break}}Da=v+~p+ta|0;Ea=za;Fa=-2-p+v+ta|0}else{Da=ta;Ea=sa;Fa=ra}V=v;do{V=V+1|0;if((V|0)>(z|0)){break}}while((c[(c[j+(V<<2)>>2]|0)+16>>2]|0)==5);if((V|0)<(z|0)){U=Da;d=Ea;I=Fa;p=v;v=V}else{Ga=Da;Ha=pa;break}}}else{Ga=0;Ha=j+(F<<2)|0}a[(c[Ha>>2]|0)+8672+Ga|0]=0}if((ma|0)<=(z|0)){Ga=ma;do{c[(c[j+(Ga<<2)>>2]|0)+16>>2]=0;Ga=Ga+1|0;}while((Ga|0)<=(z|0))}BVb(b);i=e;return}function yUb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0.0,j=0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=(f|0)!=0;f=h&1^1;if((e|0)<0){i=0.0}else{j=0;k=0.0;while(1){l=k+ +g[(c[d+(j<<2)>>2]|0)+56>>2];m=j+1|0;if((m|0)>(e|0)){i=l;break}else{j=m;k=l}}}k=i/+(e+1|0);if(h){qUb(a,b,d,0,0,0,0)|0;n=e}else{n=e}while(1){if((n|0)<=0){break}if((c[(c[d+(n<<2)>>2]|0)+16>>2]|0)==5){n=n-1|0}else{break}}e=a+696|0;do{if((c[e>>2]|0)==0){if(!h){j=(c[d+(n<<2)>>2]|0)+8516|0;m=c[j>>2]|0;c[j>>2]=c[(c[d>>2]|0)+8516>>2];c[(c[d>>2]|0)+8516>>2]=m;mrc(c[(c[d>>2]|0)+8516>>2]|0,0,c[a+18568>>2]<<1|0)|0;break}m=a+18568|0;mrc(c[(c[d>>2]|0)+8516>>2]|0,0,c[m>>2]<<1|0)|0;j=c[d>>2]|0;nrc(c[j+8500>>2]|0,c[j+8504>>2]|0,c[m>>2]<<2)|0;return}else{if((n|0)<(f|0)){return}else{mrc(c[(c[d+(n<<2)>>2]|0)+8516>>2]|0,0,c[a+18568>>2]<<1|0)|0;break}}}while(0);a:do{if((n|0)>(f|0)){h=a+18568|0;m=a+124|0;j=0;o=n;p=n;while(1){q=p-1|0;r=q;while(1){s=d+(r<<2)|0;if((c[(c[s>>2]|0)+16>>2]|0)==5&(r|0)>0){r=r-1|0}else{break}}if((r|0)<(f|0)){t=j;u=o;break a}qUb(a,b,d,r,o,o,0)|0;mrc(c[(c[s>>2]|0)+8516>>2]|0,0,c[h>>2]<<1|0)|0;v=o-r|0;w=v-1|0;do{if((c[m>>2]|0)!=0&(w|0)>1){x=((v|0)/2|0)+r|0;qUb(a,b,d,r,o,x,0)|0;mrc(c[(c[d+(x<<2)>>2]|0)+8516>>2]|0,0,c[h>>2]<<1|0)|0;if((q|0)>(r|0)){y=q;while(1){z=(y|0)>(x|0)?x:r;A=(y|0)<(x|0)?x:o;if((y|0)!=(x|0)){qUb(a,b,d,z,A,y,0)|0;DUb(a,d,k,z,A,y,0)}A=y-1|0;if((A|0)>(r|0)){y=A}else{B=r;break}}}else{B=q}DUb(a,d,k,r,o,x,1);C=B}else{if((q|0)>(r|0)){D=q}else{C=q;break}while(1){qUb(a,b,d,r,o,D,0)|0;DUb(a,d,k,r,o,D,0);y=D-1|0;if((y|0)>(r|0)){D=y}else{C=r;break}}}}while(0);DUb(a,d,k,r,o,o,1);if((C|0)>(f|0)){j=w;o=r;p=C}else{t=w;u=r;break}}}else{t=0;u=n}}while(0);if((c[e>>2]|0)==0){qUb(a,b,d,0,u,u,0)|0;DUb(a,d,k,0,u,u,1);b=d+(u<<2)|0;e=(c[b>>2]|0)+8516|0;n=c[e>>2]|0;c[e>>2]=c[(c[d>>2]|0)+8516>>2];c[(c[d>>2]|0)+8516>>2]=n;E=b}else{E=d+(u<<2)|0}EUb(a,c[E>>2]|0,k,u);if(!((c[a+124>>2]|0)!=0&(t|0)>1)){return}if((c[a+664>>2]|0)!=0){return}EUb(a,c[d+(((t+1|0)/2|0)+u<<2)>>2]|0,k,0);return}function zUb(b){b=b|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;e=i;i=i+12848|0;f=e|0;j=e+72|0;k=e+12840|0;l=b+38024|0;m=c[l>>2]|0;n=m+52|0;o=c[n>>2]|0;if((o|0)==0){i=e;return}if((o|0)>0){p=b+1576|0;q=b+8524|0;r=b+8528|0;s=b+1568|0;t=b+1560|0;u=c[b+776>>2]|0;v=o;w=0;x=o;while(1){y=m+44|0;do{if((u|0)==0){z=c[(c[y>>2]|0)+(w<<2)>>2]|0;A=d[1552560+(c[z+120>>2]|0)|0]|0;B=0;C=z+48|0;c[C>>2]=A;c[C+4>>2]=B;D=v;E=z;F=B;H=A}else{A=v-1|0;if((v|0)>1){B=c[y>>2]|0;z=(c[B+(w+1<<2)>>2]|0)+24|0;C=c[B+(w<<2)>>2]|0;B=C+24|0;I=xrc(c[z>>2]|0,c[z+4>>2]|0,c[B>>2]|0,c[B+4>>2]|0)|0;B=I<<1|0>>>31;z=G<<1|I>>>31;I=C+48|0;c[I>>2]=B;c[I+4>>2]=z;D=A;E=C;F=z;H=B;break}else{B=c[p>>2]|0;z=c[p+4>>2]|0;C=c[(c[y>>2]|0)+(w<<2)>>2]|0;I=C+48|0;c[I>>2]=B;c[I+4>>2]=z;D=A;E=C;F=z;H=B;break}}}while(0);y=E+48|0;c[p>>2]=H;c[p+4>>2]=F;B=c[y>>2]|0;z=c[y+4>>2]|0;g[E+56>>2]=(+(B>>>0)+ +(z|0)*4294967296.0)*+((c[q>>2]|0)>>>0>>>0)/+((c[r>>2]|0)>>>0>>>0);C=c[E+92>>2]|0;do{if((C|0)>(c[s>>2]|0)&(D|0)>0){A=c[t+4>>2]|0;I=E+104|0;c[I>>2]=c[t>>2];c[I+4>>2]=A;A=wrc(c[t>>2]|0,c[t+4>>2]|0,B,z)|0;c[t>>2]=A;c[t+4>>2]=G;c[s>>2]=C;J=c[n>>2]|0}else{if((D|0)!=0){J=x;break}A=c[t+4>>2]|0;I=E+104|0;c[I>>2]=c[t>>2];c[I+4>>2]=A;A=c[p+4>>2]|0;c[y>>2]=c[p>>2];c[y+4>>2]=A;J=x}}while(0);y=w+1|0;if((y|0)<(J|0)){v=D;w=y;x=J}else{K=J;break}}}else{K=o}o=b+708|0;a:do{if((c[o>>2]|0)==0){J=b+112|0;if((c[J>>2]|0)==0){L=20}else{if((c[b+116>>2]|0)==0){L=20}}do{if((L|0)==20){if((c[b+104>>2]|0)!=0){break}if((c[b+692>>2]|0)!=0){break}if((c[b+664>>2]|0)==0){M=J;break a}if((c[b+696>>2]|0)==0){M=J;break a}}}while(0);xUb(b,0);M=J}else{if((K|0)>0){x=0;w=c[m+44>>2]|0;do{D=NMb(b,c[(c[w+(x<<2)>>2]|0)+92>>2]|0)|0;v=c[l>>2]|0;w=c[v+44>>2]|0;c[(c[w+(x<<2)>>2]|0)+16>>2]=D;x=x+1|0;}while((x|0)<(c[v+52>>2]|0))}M=b+112|0}}while(0);m=b+124|0;K=b+88|0;x=b+128|0;w=b+108|0;J=b+96|0;v=b+100|0;D=b+132|0;p=0;t=0;while(1){E=c[(c[(c[l>>2]|0)+44>>2]|0)+(p<<2)>>2]|0;N=E+16|0;n=c[N>>2]|0;if((n|0)==4){s=c[m>>2]|0;do{if((s|0)<2&(t|0)==(s|0)){c[N>>2]=5;r=c[109720+(c[m>>2]<<2)>>2]|0;ILb(b,1,2196616,(O=i,i=i+16|0,c[O>>2]=c[E+92>>2],c[O+8>>2]=r,O)|0);i=O}else{if((s|0)!=2|(t|0)==0){break}if((c[K>>2]|0)>(t+3|0)){break}c[N>>2]=5;r=c[109720+(c[m>>2]<<2)>>2]|0;q=c[K>>2]|0;ILb(b,1,2164936,(O=i,i=i+24|0,c[O>>2]=c[E+92>>2],c[O+8>>2]=r,c[O+16>>2]=q,O)|0);i=O}}while(0);P=c[N>>2]|0}else{P=n}if((P|0)==6){s=(c[x>>2]|0)!=0?2:1;c[N>>2]=s;Q=s}else{Q=P}s=c[E+92>>2]|0;if((c[w>>2]|0)==0){R=s;L=38}else{if((s|0)==0){R=0;L=38}else{S=Q}}do{if((L|0)==38){L=0;s=c[(c[l>>2]|0)+4>>2]|0;if((R-s|0)<(c[J>>2]|0)){S=Q;break}if((Q|0)==0|(Q|0)==2){if((c[x>>2]|0)==0){T=1}else{T=(s>>31)+2|0}c[N>>2]=T;U=T}else{U=Q}s=(U|0)!=1;q=s&1;do{if(s){if((c[x>>2]|0)==0){V=q;break}V=(U-1|0)>>>0>1>>>0|0}else{V=q}}while(0);if((V|0)==0){S=U;break}ILb(b,1,2138928,(O=i,i=i+16|0,c[O>>2]=U,c[O+8>>2]=R,O)|0);i=O;if((c[x>>2]|0)==0){W=1}else{W=(c[(c[l>>2]|0)+4>>2]>>31)+2|0}c[N>>2]=W;S=W}}while(0);do{if((S|0)==2){n=c[E+92>>2]|0;q=c[l>>2]|0;s=q+4|0;if((n-(c[s>>2]|0)|0)<(c[v>>2]|0)){X=p;break}if((c[x>>2]|0)==0){c[N>>2]=1;Y=n;Z=q;L=59;break}c[s>>2]=n;if((c[D>>2]|0)!=0){c[s>>2]=n-p}c[E+124>>2]=1;_=c[N>>2]|0;L=57}else{_=S;L=57}}while(0);do{if((L|0)==57){L=0;if((_|0)!=1){X=p;break}Y=c[E+92>>2]|0;Z=c[l>>2]|0;L=59}}while(0);do{if((L|0)==59){L=0;c[Z+4>>2]=Y;c[E+124>>2]=1;if((p|0)<=0){X=p;break}n=p-1|0;c[(c[(c[Z+44>>2]|0)+(n<<2)>>2]|0)+16>>2]=3;X=n}}while(0);do{if((X|0)==(c[M>>2]|0)){L=64}else{if((c[(c[(c[l>>2]|0)+44>>2]|0)+(X+1<<2)>>2]|0)==0){L=64;break}$=c[N>>2]|0}}while(0);if((L|0)==64){L=0;E=c[N>>2]|0;if((E-4|0)>>>0<2>>>0){ILb(b,1,2115592,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;aa=c[N>>2]|0}else{aa=E}if((aa|0)==0|(aa|0)==5|(aa|0)==4){L=67;break}else{$=aa}}E=(($|0)==4)+t|0;if(($|0)==0){c[N>>2]=5}else if(!(($|0)==5|($|0)==4)){ba=E;break}p=X+1|0;t=E}if((L|0)==67){c[N>>2]=3;ba=t}t=(X|0)!=0;if(t){a[(c[(c[(c[l>>2]|0)+44>>2]|0)+(X-1<<2)>>2]|0)+129|0]=1}a[(c[(c[(c[l>>2]|0)+44>>2]|0)+(X<<2)>>2]|0)+130|0]=X;if((c[m>>2]|0)!=0&(X|0)>1&(ba|0)==0){c[(c[(c[(c[l>>2]|0)+44>>2]|0)+(((X|0)/2|0)<<2)>>2]|0)+16>>2]=4;ca=1}else{ca=ba}do{if((c[b+624>>2]|0)==0){da=X}else{ba=X+1|0;c[j+8>>2]=12;c[j>>2]=1;c[j+12>>2]=c[b+1864>>2];m=(c[b+3304>>2]|0)-1|0;if((m|0)<0){ea=0}else{ea=(m|0)>2?2:m}c[j+16>>2]=3041168+(ea*66|0);m=(c[b+3308>>2]|0)-1|0;if((m|0)<0){fa=0}else{fa=(m|0)>2?2:m}c[j+20>>2]=3041168+(fa*66|0);if((c[b+560>>2]|0)>1){m=c[b+544>>2]|0;c[b+18628>>2]=(m|0)>1?1:m;c[b+18632>>2]=4}else{c[b+18628>>2]=0;c[b+18632>>2]=2}c[b+18636>>2]=0;m=c[l>>2]|0;N=f|0;c[N>>2]=c[m+12>>2];L=m+44|0;nrc(f+4|0,c[L>>2]|0,ba<<2)|0;m=((c[(c[(c[L>>2]|0)+(X<<2)>>2]|0)+16>>2]|0)-1|0)>>>0<2>>>0?ba:0;qUb(b,j,N,m,ba,ba,0)|0;if(!((m|0)!=(ba|0)|t)){da=0;break}if((c[b+664>>2]|0)==0){da=X;break}qUb(b,j,N,ba,ba,ba,0)|0;if((X|0)<1){da=X;break}else{ga=0;ha=1}while(1){m=f+(ha<<2)|0;b:do{if((c[(c[m>>2]|0)+16>>2]|0)==5){L=ha;p=1;while(1){$=L+1|0;if(!p){ia=L;break b}L=$;p=(c[(c[f+($<<2)>>2]|0)+16>>2]|0)==5}}else{ia=ba}}while(0);qUb(b,j,N,ga,ia,ha,0)|0;p=ha+1|0;if((p|0)>(X|0)){da=X;break}else{ga=(c[(c[m>>2]|0)+16>>2]|0)==4?ha:ga;ha=p}}}}while(0);do{if((c[o>>2]|0)==0){ha=c[l>>2]|0;ga=c[(c[ha+44>>2]|0)+(da<<2)>>2]|0;if((c[ga+16>>2]|0)!=3){break}if((c[b+528>>2]|0)<=0){break}pUb(b,ga,c[ha+12>>2]|0,0)}}while(0);o=(c[l>>2]|0)+44|0;ha=c[o>>2]|0;ga=c[ha>>2]|0;X=c[ga+92>>2]|0;if(t){c[k>>2]=ca+1;c[k+4>>2]=1;c:do{if((da|0)>0){ca=1;t=ga;while(1){ia=k+(((c[t+16>>2]|0)==4)<<2)|0;j=c[ia>>2]|0;c[ia>>2]=j+1;c[f+(j<<2)>>2]=t;ia=c[o>>2]|0;fa=(c[ia+(j<<2)>>2]|0)+24|0;j=c[fa+4>>2]|0;ea=t+40|0;c[ea>>2]=c[fa>>2];c[ea+4>>2]=j;if((ca|0)>=(da|0)){ja=ia;break c}j=c[ia+(ca<<2)>>2]|0;ca=ca+1|0;t=j}}else{ja=ha}}while(0);ha=c[ja+(da<<2)>>2]|0;c[f>>2]=ha;ja=c[o>>2]|0;o=(c[ja>>2]|0)+24|0;k=c[o+4>>2]|0;ga=ha+40|0;c[ga>>2]=c[o>>2];c[ga+4>>2]=k;nrc(ja|0,f|0,(da<<2)+4|0)|0}if((da|0)<0){i=e;return}f=c[(c[l>>2]|0)+44>>2]|0;l=b+1592|0;ja=b+1584|0;k=b+8620|0;ga=b+8524|0;o=b+8528|0;b=c[f>>2]|0;ha=X;X=0;t=b;while(1){ca=ha+1|0;c[t+96>>2]=ha;if((X|0)==0){j=c[l>>2]|0;ia=c[l+4>>2]|0;ea=t+72|0;c[ea>>2]=j;c[ea+4>>2]=ia;fa=t+104|0;N=xrc(c[fa>>2]|0,c[fa+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;fa=t+80|0;ba=c[k>>2]<<1;p=wrc(ba,(ba|0)<0|0?-1:0,N,G)|0;N=G;c[fa>>2]=p;c[fa+4>>2]=N;ba=0;if((N|0)<(ba|0)|(N|0)==(ba|0)&p>>>0<0>>>0){ba=wrc(p,N,j,ia)|0;c[ea>>2]=ba;c[ea+4>>2]=G;c[fa>>2]=0;c[fa+4>>2]=0}do{if((c[t+124>>2]|0)!=0){if((c[w>>2]|0)!=0){break}c[l>>2]=0;c[l+4>>2]=0}}while(0);fa=t+48|0;ea=wrc(c[l>>2]|0,c[l+4>>2]|0,c[fa>>2]|0,c[fa+4>>2]|0)|0;c[l>>2]=ea;c[l+4>>2]=G;ea=wrc(c[ja>>2]|0,c[ja+4>>2]|0,c[fa>>2]|0,c[fa+4>>2]|0)|0;c[ja>>2]=ea;c[ja+4>>2]=G;ea=c[fa>>2]|0;ba=c[fa+4>>2]|0;fa=t+64|0;c[fa>>2]=ea;c[fa+4>>2]=ba;ka=ba;la=ea;ma=c[ga>>2]|0;na=c[o>>2]|0}else{ea=X-1|0;ba=c[l>>2]|0;fa=c[l+4>>2]|0;ia=t+72|0;c[ia>>2]=ba;c[ia+4>>2]=fa;j=t+104|0;N=xrc(c[j>>2]|0,c[j+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;j=t+80|0;p=c[k>>2]<<1;L=wrc(p,(p|0)<0|0?-1:0,N,G)|0;N=G;c[j>>2]=L;c[j+4>>2]=N;p=0;if((N|0)<(p|0)|(N|0)==(p|0)&L>>>0<0>>>0){p=wrc(L,N,ba,fa)|0;c[ia>>2]=p;c[ia+4>>2]=G;c[j>>2]=0;c[j+4>>2]=0}do{if((c[t+124>>2]|0)!=0){if((c[w>>2]|0)!=0){break}c[l>>2]=0;c[l+4>>2]=0}}while(0);j=t+48|0;ia=wrc(c[l>>2]|0,c[l+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;c[l>>2]=ia;c[l+4>>2]=G;ia=wrc(c[ja>>2]|0,c[ja+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;c[ja>>2]=ia;c[ja+4>>2]=G;ia=c[j>>2]|0;p=c[j+4>>2]|0;j=t+64|0;c[j>>2]=ia;c[j+4>>2]=p;j=(c[f+(ea<<2)>>2]|0)+64|0;fa=c[ga>>2]|0;ba=c[o>>2]|0;h[b+9928+(ea<<3)>>3]=(+((c[j>>2]|0)>>>0)+ +(c[j+4>>2]|0)*4294967296.0)*+(fa>>>0>>>0)/+(ba>>>0>>>0);ka=p;la=ia;ma=fa;na=ba}h[b+9928+(X<<3)>>3]=(+(la>>>0)+ +(ka|0)*4294967296.0)*+(ma>>>0>>>0)/+(na>>>0>>>0);ba=X+1|0;if((ba|0)>(da|0)){break}ha=ca;X=ba;t=c[f+(ba<<2)>>2]|0}i=e;return}function AUb(a){a=a|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=a+15144|0;h=c[f>>2]|0;i=c[h+16>>2]|0;if((i|0)==3){j=(d[h+130|0]|0)+1|0;k=j;l=j}else if((i|0)==2|(i|0)==1){k=0;l=0}else{i=c[(c[a+15312>>2]|0)+4>>2]|0;k=((c[(c[a+15316>>2]|0)+4>>2]|0)-i|0)/2|0;l=((c[h+4>>2]|0)-i|0)/2|0}i=f+(-l<<2)|0;j=k-l|0;m=c[h+4520+(l*72|0)+(j<<2)>>2]|0;if(!((m|0)>-1)){Cd(2633520,2286680,1887,2649240);return 0}do{if((c[a+692>>2]|0)==0){n=11}else{if((c[a+708>>2]|0)!=0){n=11;break}o=BUb(a,i,0,k,l)|0;if((l|0)==0){p=o;break}if((c[a+664>>2]|0)==0){p=o;break}BUb(a,i,l,l,l)|0;p=o}}while(0);do{if((n|0)==11){if((c[a+684>>2]|0)==0){p=m;break}p=c[h+5816+(l*72|0)+(j<<2)>>2]|0}}while(0);h=c[f>>2]|0;c[h+8484>>2]=c[h+7188+(l*72|0)+(j<<2)>>2];h=a+15148|0;m=c[h>>2]|0;c[m+8484>>2]=c[m+7188+(l*72|0)+(j<<2)>>2];m=c[h>>2]|0;c[m+7112>>2]=p;n=a+18564|0;nrc(c[m+8484>>2]|0,c[(c[f>>2]|0)+8484>>2]|0,c[n>>2]<<2)|0;m=c[f>>2]|0;if(!(((c[m+16>>2]|0)-1|0)>>>0<2>>>0)){nrc(c[(c[h>>2]|0)+7188>>2]|0,c[m+7188>>2]|0,c[n>>2]<<2)|0}if((c[a+108>>2]|0)==0){q=p;return q|0}if((c[a+664>>2]|0)==0){q=p;return q|0}m=c[f>>2]|0;if((c[m+16>>2]|0)!=3){q=p;return q|0}f=~~(+g[a+672>>2]*256.0);i=c[n>>2]|0;if((i|0)<=0){q=p;return q|0}k=a+18580|0;o=c[h>>2]|0;h=o+11980|0;r=o+11984|0;s=a+684|0;a=0;t=p;p=i;i=c[r>>2]|0;while(1){u=c[h>>2]|0;if((u|0)>(i|0)){v=t;w=p;x=i}else{y=u+(ca(c[k>>2]|0,a)|0)|0;z=c[m+8512>>2]|0;A=c[m+2940+(l*72|0)+(j<<2)>>2]|0;B=m+8520|0;C=y;y=u;u=t;while(1){D=(ca(e[z+(C<<1)>>1]|0,f)|0)+128>>8;E=D-(b[A+(C<<1)>>1]&16383)|0;if((c[s>>2]|0)==0){D=(c[o+8484>>2]|0)+(a<<2)|0;c[D>>2]=(c[D>>2]|0)+E}else{D=(ca(e[(c[B>>2]|0)+(C<<1)>>1]|0,E)|0)+128>>8;F=(c[o+8484>>2]|0)+(a<<2)|0;c[F>>2]=D+(c[F>>2]|0)}G=E+u|0;E=y+1|0;H=c[r>>2]|0;if((E|0)>(H|0)){break}else{C=C+1|0;y=E;u=G}}v=G;w=c[n>>2]|0;x=H}u=a+1|0;if((u|0)<(w|0)){a=u;t=v;p=w;i=x}else{q=v;break}}return q|0}function BUb(a,e,f,h,i){a=a|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=h-i|0;h=i-f|0;f=e+(i<<2)|0;i=c[f>>2]|0;e=c[i+7188+(h*72|0)+(j<<2)>>2]|0;k=c[(((c[i+16>>2]|0)-4|0)>>>0<2>>>0?i+8504|0:i+8500|0)>>2]|0;i=a+18564|0;l=a+18612|0;m=c[i>>2]|0;n=m-1|0;c[l>>2]=n;if((m|0)<=0){o=0;return o|0}m=a+18560|0;p=a+18608|0;q=a+18580|0;a=0;r=n;while(1){c[e+(r<<2)>>2]=0;n=a;s=m;a:while(1){t=s;b:while(1){u=c[t>>2]|0;v=u-1|0;c[p>>2]=v;w=c[l>>2]|0;if((u|0)<=0){break a}u=(ca(c[q>>2]|0,w)|0)+v|0;v=b[(c[(c[f>>2]|0)+2940+(h*72|0)+(j<<2)>>2]|0)+(u<<1)>>1]&16383;x=~~(+g[k+(u<<2)>>2]*-10.666666984558105+512.5);do{if((x|0)<0){y=0}else{if((x|0)>1023){y=65535;break}y=(d[97768+(x&63)|0]|0|256)<<(x>>6)>>8}}while(0);z=(ca(y,v)|0)+128>>8;x=e+(w<<2)|0;c[x>>2]=z+(c[x>>2]|0);x=c[l>>2]|0;do{if((x|0)>0){if((x|0)>=((c[i>>2]|0)-1|0)){A=14;break}u=c[p>>2]|0;if((u|0)<=0){A=14;break}B=c[m>>2]|0;if((u|0)<(B-1|0)){break b}else{C=B}}else{A=14}}while(0);if((A|0)==14){A=0;C=c[m>>2]|0}if((C|0)<3){break}if((c[i>>2]|0)<3){break}else{t=p}}n=z+n|0;s=p}s=w-1|0;c[l>>2]=s;if((w|0)>0){a=n;r=s}else{o=n;break}}return o|0}function CUb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0.0,r=0,s=0.0,t=0;j=i;k=c[d+(f<<2)>>2]|0;l=(g|0)!=0;do{if(l){if((c[a+756>>2]|0)!=5){break}if((c[k+92>>2]&1|0)==0){break}else{m=0}i=j;return m|0}}while(0);qUb(a,b,d,e,f,f,0)|0;d=c[k+4520>>2]|0;b=f-e|0;e=c[k+4520+(b*72|0)>>2]|0;f=c[k+92>>2]|0;g=f-(c[(c[a+38024>>2]|0)+4>>2]|0)|0;n=+(c[a+104>>2]|0)/100.0;o=c[a+100>>2]|0;p=c[a+96>>2]|0;q=(o|0)==(p|0)?n:n*.25;do{if((g|0)>((o|0)/4|0|0)){if((c[a+108>>2]|0)!=0){r=6;break}if((g|0)>(o|0)){s=q+ +(g-o|0)*(n-q)/+(p-o|0);break}else{s=+(g|0)*q/+(o|0);break}}else{r=6}}while(0);if((r|0)==6){s=q*.25}q=+(e|0);n=s;s=+(d|0);r=q>=s*(1.0-n);o=r&1;if(!(r&l)){m=o;i=j;return m|0}l=c[k+7116+(b<<2)>>2]|0;b=c[a+18560>>2]|0;k=c[a+18564>>2]|0;if((b|0)>2&(k|0)>2){t=ca(k-2|0,b-2|0)|0}else{t=ca(k,b)|0}ILb(a,3,2527392,(a=i,i=i+64|0,c[a>>2]=f,c[a+8>>2]=d,c[a+16>>2]=e,h[a+24>>3]=1.0-q/s,h[a+32>>3]=n,c[a+40>>2]=g,c[a+48>>2]=l,c[a+56>>2]=t-l,a)|0);i=a;m=o;i=j;return m|0}function DUb(a,b,d,e,f,h,j){a=a|0;b=b|0;d=+d;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;k=i;i=i+8|0;l=k|0;m=c[(c[b+(e<<2)>>2]|0)+8516>>2]|0;n=c[(c[b+(f<<2)>>2]|0)+8516>>2]|0;o=h-e|0;p=f-e|0;if((c[a+532>>2]|0)==0){q=32}else{q=64-((((o<<8)+(p>>1)|0)/(p|0)|0)>>2)|0}p=b+(h<<2)|0;b=c[p>>2]|0;e=c[b+2796+(o-1<<2)>>2]|0;r=f-h|0;s=c[b+2864+(r-1<<2)>>2]|0;t=64-q|0;u=c[a+36456>>2]|0;v=c[b+8516>>2]|0;w=c[b+2940+(o*72|0)+(r<<2)>>2]|0;x=+g[b+56>>2];y=(c[a+756>>2]|0)==5?2.0:1.0;z=.009999999776482582/y;A=1.0/y;if(x<z){B=z}else{B=x>A?A:x}if(z>d){C=z}else{C=A<d?A:d}g[l>>2]=B/(C*256.0)*.5;b=(j|0)!=0;if(!b){mrc(v|0,0,c[a+18560>>2]<<1|0)|0}j=a+18612|0;c[j>>2]=0;r=a+18564|0;if((c[r>>2]|0)>0){D=a+18580|0;E=a+37564|0;F=a+18560|0;G=a+37568|0;H=(h|0)==(f|0);I=0;J=v;while(1){v=ca(c[D>>2]|0,I)|0;K=c[p>>2]|0;L=w+(v<<1)|0;Se[c[E>>2]&1023](u,J,(c[K+8512>>2]|0)+(v<<1)|0,L,(c[K+8520>>2]|0)+(v<<1)|0,l,c[F>>2]|0);K=c[F>>2]|0;if(b){M=J+(K<<1)|0}else{M=J}Te[c[G>>2]&255](a,m,e+(v<<2)|0,u,L,q,c[j>>2]|0,K,0);if(!H){Te[c[G>>2]&255](a,n,s+(v<<2)|0,u,L,t,c[j>>2]|0,c[F>>2]|0,1)}L=(c[j>>2]|0)+1|0;c[j>>2]=L;if((L|0)<(c[r>>2]|0)){I=L;J=M}else{break}}}if((c[a+664>>2]|0)==0){i=k;return}if((c[a+696>>2]|0)==0|b^1){i=k;return}EUb(a,c[p>>2]|0,d,(h|0)==(f|0)?o:0);i=k;return}function EUb(a,b,d,f){a=a|0;b=b|0;d=+d;f=f|0;var h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=(c[a+756>>2]|0)==5?2.0:1.0;i=.009999999776482582/h;j=1.0/h;if(i>d){k=i}else{k=j<d?j:d}d=+g[b+56>>2];if(d<i){l=i}else{l=d>j?j:d}m=~~+Nb(+(k/l*256.0*2.0));do{if((f|0)==0){n=0.0}else{l=+g[b+8528+(f-1<<2)>>2];if(!(l>0.0)){n=0.0;break}n=1.0-l}}while(0);l=(1.0- +g[a+716>>2])*5.0;f=c[a+18568>>2]|0;if((f|0)<=0){return}a=c[b+8512>>2]|0;o=c[b+8520>>2]|0;p=b+8516|0;q=b+8504|0;r=b+8500|0;b=0;do{s=((ca(e[o+(b<<1)>>1]|0,e[a+(b<<1)>>1]|0)|0)+128|0)>>>8;if((s|0)!=0){t=((ca(e[(c[p>>2]|0)+(b<<1)>>1]|0,m)|0)+128>>8)+s|0;u=rrc(t|0)|0;k=+g[95680+((t<<u>>>24&127)<<2)>>2]+ +g[95552+(u<<2)>>2];u=rrc(s|0)|0;g[(c[r>>2]|0)+(b<<2)>>2]=+g[(c[q>>2]|0)+(b<<2)>>2]-l*(n+(k-(+g[95680+((s<<u>>>24&127)<<2)>>2]+ +g[95552+(u<<2)>>2])))}b=b+1|0;}while((b|0)<(f|0));return}function FUb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(e|0)==0?1:4;g=c[a+844>>2]|0;do{if((g|0)==0){h=c[a+836>>2]|0;if((h|0)==0){i=1;break}i=(h-1+(ca(c[a+18564>>2]|0,c[a+18560>>2]|0)|0)|0)/(h|0)|0}else{i=g}}while(0);g=ca(i,f)|0;f=(ca(d[(c[b+32>>2]|0)+16465|0]|0,2-e|0)|0)+10|0;e=c[b+36>>2]<<1;i=1-e|0;a=(i|0)<0?e:i;if((a|0)<256){j=d[16464+a|0]|0}else{j=(d[16464+(a>>8)|0]|0)+16|0}a=c[b+40>>2]<<1;b=1-a|0;i=(b|0)<0?a:b;if((i|0)<256){k=d[16464+i|0]|0;l=k+j|0;m=l<<1;n=f+m|0;o=ca(g,n)|0;return o|0}else{k=(d[16464+(i>>8)|0]|0)+16|0;l=k+j|0;m=l<<1;n=f+m|0;o=ca(g,n)|0;return o|0}return 0}function GUb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=g<<1&2;j=g&2;k=e+19352+g|0;l=a[k]|0;if(l<<24>>24==12){m=i|g<<3&16|12;re[c[25111]&1023](e+28104+m|0,d[e+28744+g|0]|0);re[c[25111]&1023](e+28144+m|0,d[e+28748+g|0]|0);re[c[25131]&1023](e+28192+(m<<2)|0,c[e+28712+(g<<2)>>2]|0);re[c[25131]&1023](e+28352+(m<<2)|0,c[e+28728+(g<<2)>>2]|0);if((h|0)==0){return}m=i|j<<3|12;re[c[25121]&1023](e+28512+(m<<1)|0,0);re[c[25121]&1023](e+28592+(m<<1)|0,0);b[e+28672+m>>1]=257;b[m+8+(e+28672)>>1]=257;return}do{if((a[95296+(l&255)|0]|0)==0){m=j<<3|i|12;re[c[25111]&1023](e+28104+m|0,255);re[c[25131]&1023](e+28192+(m<<2)|0,0);if((h|0)==0){break}re[c[25121]&1023](e+28512+(m<<1)|0,0)}else{m=j<<3|i|12;re[c[25111]&1023](e+28104+m|0,c[f+1280+(g<<7)+12>>2]&255);re[c[25131]&1023](e+28192+(m<<2)|0,c[f+1280+(g<<7)+112>>2]|0)}}while(0);if((a[95313+(d[k]|0)|0]|0)!=0){k=j<<3|i|12;re[c[25111]&1023](e+28144+k|0,c[f+7408+(g<<7)+12>>2]&255);re[c[25131]&1023](e+28352+(k<<2)|0,c[f+7408+(g<<7)+112>>2]|0);return}g=j<<3|i|12;re[c[25111]&1023](e+28144+g|0,255);re[c[25131]&1023](e+28352+(g<<2)|0,0);if((h|0)==0){return}re[c[25121]&1023](e+28592+(g<<1)|0,0);return}function HUb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+288|0;j=h|0;k=c[a+8632>>2]|0;if((k|0)==3){l=j+31&-32;m=l+8|0;n=c[a+27920>>2]|0;o=f&1;p=f<<2&8;q=c[d+1280+(f<<7)+12>>2]|0;if((g|0)==6){r=b[d+1808+(f<<9)+112>>1]|0;s=b[d+1808+(f<<9)+114>>1]|0;t=a+37376|0;u=a+24588+(q*48|0)+16|0;v=a+3584+(q*144|0)+48|0;Te[c[t>>2]&255](l,16,u,n,r,s,4,4,v);w=a+24588+(q*48|0)+32|0;x=a+3584+(q*144|0)+96|0;Te[c[t>>2]&255](m,16,w,n,r,s,4,4,x);s=(b[d+1808+(f<<9)+240>>1]|0)+16|0;r=b[d+1808+(f<<9)+242>>1]|0;Te[c[t>>2]&255](l+4|0,16,u,n,s,r,4,4,v);Te[c[t>>2]&255](l+12|0,16,w,n,s,r,4,4,x);r=b[d+1808+(f<<9)+368>>1]|0;s=(b[d+1808+(f<<9)+370>>1]|0)+16|0;Te[c[t>>2]&255](l+64|0,16,u,n,r,s,4,4,v);Te[c[t>>2]&255](l+72|0,16,w,n,r,s,4,4,x);s=(b[d+1808+(f<<9)+496>>1]|0)+16|0;r=(b[d+1808+(f<<9)+498>>1]|0)+16|0;Te[c[t>>2]&255](l+68|0,16,u,n,s,r,4,4,v);Te[c[t>>2]&255](l+76|0,16,w,n,s,r,4,4,x);y=p<<4|-o&8}else if((g|0)==4){x=b[d+3872+(f<<8)+112>>1]|0;r=b[d+3872+(f<<8)+114>>1]|0;s=a+37376|0;w=a+24588+(q*48|0)+16|0;t=a+3584+(q*144|0)+48|0;Te[c[s>>2]&255](l,16,w,n,x,r,8,4,t);v=a+24588+(q*48|0)+32|0;u=a+3584+(q*144|0)+96|0;Te[c[s>>2]&255](m,16,v,n,x,r,8,4,u);r=b[d+3872+(f<<8)+240>>1]|0;x=(b[d+3872+(f<<8)+242>>1]|0)+16|0;Te[c[s>>2]&255](l+64|0,16,w,n,r,x,8,4,t);Te[c[s>>2]&255](l+72|0,16,v,n,r,x,8,4,u);z=6}else{u=b[d+4912+(f<<8)+112>>1]|0;x=b[d+4912+(f<<8)+114>>1]|0;r=a+37376|0;v=a+24588+(q*48|0)+16|0;s=a+3584+(q*144|0)+48|0;Te[c[r>>2]&255](l,16,v,n,u,x,4,8,s);t=a+24588+(q*48|0)+32|0;w=a+3584+(q*144|0)+96|0;Te[c[r>>2]&255](m,16,t,n,u,x,4,8,w);x=(b[d+4912+(f<<8)+240>>1]|0)+16|0;u=b[d+4912+(f<<8)+242>>1]|0;Te[c[r>>2]&255](l+4|0,16,v,n,x,u,4,8,s);Te[c[r>>2]&255](l+12|0,16,t,n,x,u,4,8,w);z=6}if((z|0)==6){y=p<<4|-o&8}o=a+36896|0;p=hf[c[o>>2]&1023]((c[a+24548>>2]|0)+y|0,16,l,16)|0;A=(hf[c[o>>2]&1023]((c[a+24552>>2]|0)+y|0,16,m,16)|0)+p|0;i=h;return A|0}else if((k|0)==2){k=j+31&-32;p=k+8|0;m=c[a+27920>>2]|0;y=f&1;o=f<<2&8;l=(ca(m,o)|0)+(y<<3)|0;z=c[d+1280+(f<<7)+12>>2]|0;do{if((g|0)==6){w=a+37384|0;u=e+16|0;Te[c[w>>2]&255](k,p,16,(c[u>>2]|0)+l|0,m,b[d+1808+(f<<9)+112>>1]|0,b[d+1808+(f<<9)+114>>1]<<1,2,4);x=a+3584+(z*144|0)+92|0;n=c[x>>2]|0;if((n|0)!=0){_e[c[n>>2]&511](k,16,k,16,a+3584+(z*144|0)+48|0,4)}n=a+3584+(z*144|0)+140|0;t=c[n>>2]|0;if((t|0)!=0){_e[c[t>>2]&511](p,16,p,16,a+3584+(z*144|0)+96|0,4)}t=k+2|0;r=k+10|0;Te[c[w>>2]&255](t,r,16,(c[u>>2]|0)+(l|4)|0,m,b[d+1808+(f<<9)+240>>1]|0,b[d+1808+(f<<9)+242>>1]<<1,2,4);s=c[x>>2]|0;if((s|0)!=0){_e[c[s>>2]&511](t,16,t,16,a+3584+(z*144|0)+48|0,4)}t=c[n>>2]|0;if((t|0)!=0){_e[c[t>>2]&511](r,16,r,16,a+3584+(z*144|0)+96|0,4)}r=k+64|0;t=k+72|0;s=m<<2;Te[c[w>>2]&255](r,t,16,(c[u>>2]|0)+(l+s)|0,m,b[d+1808+(f<<9)+368>>1]|0,b[d+1808+(f<<9)+370>>1]<<1,2,4);v=c[x>>2]|0;if((v|0)!=0){_e[c[v>>2]&511](r,16,r,16,a+3584+(z*144|0)+48|0,4)}r=c[n>>2]|0;if((r|0)!=0){_e[c[r>>2]&511](t,16,t,16,a+3584+(z*144|0)+96|0,4)}t=k+66|0;r=k+74|0;Te[c[w>>2]&255](t,r,16,(c[u>>2]|0)+(s+4+l)|0,m,b[d+1808+(f<<9)+496>>1]|0,b[d+1808+(f<<9)+498>>1]<<1,2,4);s=c[x>>2]|0;if((s|0)!=0){_e[c[s>>2]&511](t,16,t,16,a+3584+(z*144|0)+48|0,4)}t=c[n>>2]|0;if((t|0)==0){break}_e[c[t>>2]&511](r,16,r,16,a+3584+(z*144|0)+96|0,4)}else if((g|0)==4){r=a+37384|0;t=e+16|0;Te[c[r>>2]&255](k,p,16,(c[t>>2]|0)+l|0,m,b[d+3872+(f<<8)+112>>1]|0,b[d+3872+(f<<8)+114>>1]<<1,4,4);n=a+3584+(z*144|0)+92|0;s=c[n>>2]|0;if((s|0)!=0){_e[c[s+4>>2]&511](k,16,k,16,a+3584+(z*144|0)+48|0,4)}s=a+3584+(z*144|0)+140|0;x=c[s>>2]|0;if((x|0)!=0){_e[c[x+4>>2]&511](p,16,p,16,a+3584+(z*144|0)+96|0,4)}x=k+64|0;u=k+72|0;Te[c[r>>2]&255](x,u,16,(c[t>>2]|0)+(l+(m<<2))|0,m,b[d+3872+(f<<8)+240>>1]|0,b[d+3872+(f<<8)+242>>1]<<1,4,4);t=c[n>>2]|0;if((t|0)!=0){_e[c[t+4>>2]&511](x,16,x,16,a+3584+(z*144|0)+48|0,4)}x=c[s>>2]|0;if((x|0)==0){break}_e[c[x+4>>2]&511](u,16,u,16,a+3584+(z*144|0)+96|0,4)}else{u=a+37384|0;x=e+16|0;Te[c[u>>2]&255](k,p,16,(c[x>>2]|0)+l|0,m,b[d+4912+(f<<8)+112>>1]|0,b[d+4912+(f<<8)+114>>1]<<1,2,8);s=a+3584+(z*144|0)+92|0;t=c[s>>2]|0;if((t|0)!=0){_e[c[t>>2]&511](k,16,k,16,a+3584+(z*144|0)+48|0,8)}t=a+3584+(z*144|0)+140|0;n=c[t>>2]|0;if((n|0)!=0){_e[c[n>>2]&511](p,16,p,16,a+3584+(z*144|0)+96|0,8)}n=k+2|0;r=k+10|0;Te[c[u>>2]&255](n,r,16,(c[x>>2]|0)+(l|4)|0,m,b[d+4912+(f<<8)+240>>1]|0,b[d+4912+(f<<8)+242>>1]<<1,2,8);x=c[s>>2]|0;if((x|0)!=0){_e[c[x>>2]&511](n,16,n,16,a+3584+(z*144|0)+48|0,8)}n=c[t>>2]|0;if((n|0)==0){break}_e[c[n>>2]&511](r,16,r,16,a+3584+(z*144|0)+96|0,8)}}while(0);z=o<<4|-y&4;y=a+36904|0;o=hf[c[y>>2]&1023]((c[a+24548>>2]|0)+z|0,16,k,16)|0;A=(hf[c[y>>2]&1023]((c[a+24552>>2]|0)+z|0,16,p,16)|0)+o|0;i=h;return A|0}else{o=j+31&-32;j=o+8|0;p=c[a+27920>>2]|0;z=f&1;y=f<<1&4;k=(ca(p,y)|0)+(z<<3)|0;m=c[d+1280+(f<<7)+12>>2]|0;if((c[a+18660>>2]&m|0)==0){B=0}else{B=(c[a+18612>>2]<<2&4)-2|0}do{if((g|0)==4){l=a+37384|0;r=e+16|0;Te[c[l>>2]&255](o,j,16,(c[r>>2]|0)+k|0,p,b[d+3872+(f<<8)+112>>1]|0,(b[d+3872+(f<<8)+114>>1]|0)+B|0,4,2);n=a+3584+(m*144|0)+92|0;t=c[n>>2]|0;if((t|0)!=0){_e[c[t+4>>2]&511](o,16,o,16,a+3584+(m*144|0)+48|0,2)}t=a+3584+(m*144|0)+140|0;x=c[t>>2]|0;if((x|0)!=0){_e[c[x+4>>2]&511](j,16,j,16,a+3584+(m*144|0)+96|0,2)}x=o+32|0;s=o+40|0;Te[c[l>>2]&255](x,s,16,(c[r>>2]|0)+(k+(p<<1))|0,p,b[d+3872+(f<<8)+240>>1]|0,(b[d+3872+(f<<8)+242>>1]|0)+B|0,4,2);r=c[n>>2]|0;if((r|0)!=0){_e[c[r+4>>2]&511](x,16,x,16,a+3584+(m*144|0)+48|0,2)}x=c[t>>2]|0;if((x|0)==0){break}_e[c[x+4>>2]&511](s,16,s,16,a+3584+(m*144|0)+96|0,2)}else if((g|0)==6){s=a+37384|0;x=e+16|0;Te[c[s>>2]&255](o,j,16,(c[x>>2]|0)+k|0,p,b[d+1808+(f<<9)+112>>1]|0,(b[d+1808+(f<<9)+114>>1]|0)+B|0,2,2);t=a+3584+(m*144|0)+92|0;r=c[t>>2]|0;if((r|0)!=0){_e[c[r>>2]&511](o,16,o,16,a+3584+(m*144|0)+48|0,2)}r=a+3584+(m*144|0)+140|0;n=c[r>>2]|0;if((n|0)!=0){_e[c[n>>2]&511](j,16,j,16,a+3584+(m*144|0)+96|0,2)}n=o+2|0;l=o+10|0;Te[c[s>>2]&255](n,l,16,(c[x>>2]|0)+(k+4)|0,p,b[d+1808+(f<<9)+240>>1]|0,(b[d+1808+(f<<9)+242>>1]|0)+B|0,2,2);u=c[t>>2]|0;if((u|0)!=0){_e[c[u>>2]&511](n,16,n,16,a+3584+(m*144|0)+48|0,2)}n=c[r>>2]|0;if((n|0)!=0){_e[c[n>>2]&511](l,16,l,16,a+3584+(m*144|0)+96|0,2)}l=o+32|0;n=o+40|0;u=p<<1;Te[c[s>>2]&255](l,n,16,(c[x>>2]|0)+(k+u)|0,p,b[d+1808+(f<<9)+368>>1]|0,(b[d+1808+(f<<9)+370>>1]|0)+B|0,2,2);w=c[t>>2]|0;if((w|0)!=0){_e[c[w>>2]&511](l,16,l,16,a+3584+(m*144|0)+48|0,2)}l=c[r>>2]|0;if((l|0)!=0){_e[c[l>>2]&511](n,16,n,16,a+3584+(m*144|0)+96|0,2)}n=o+34|0;l=o+42|0;Te[c[s>>2]&255](n,l,16,(c[x>>2]|0)+(u+4+k)|0,p,b[d+1808+(f<<9)+496>>1]|0,(b[d+1808+(f<<9)+498>>1]|0)+B|0,2,2);u=c[t>>2]|0;if((u|0)!=0){_e[c[u>>2]&511](n,16,n,16,a+3584+(m*144|0)+48|0,2)}n=c[r>>2]|0;if((n|0)==0){break}_e[c[n>>2]&511](l,16,l,16,a+3584+(m*144|0)+96|0,2)}else{l=a+37384|0;n=e+16|0;Te[c[l>>2]&255](o,j,16,(c[n>>2]|0)+k|0,p,b[d+4912+(f<<8)+112>>1]|0,(b[d+4912+(f<<8)+114>>1]|0)+B|0,2,4);r=a+3584+(m*144|0)+92|0;u=c[r>>2]|0;if((u|0)!=0){_e[c[u>>2]&511](o,16,o,16,a+3584+(m*144|0)+48|0,4)}u=a+3584+(m*144|0)+140|0;t=c[u>>2]|0;if((t|0)!=0){_e[c[t>>2]&511](j,16,j,16,a+3584+(m*144|0)+96|0,4)}t=o+2|0;x=o+10|0;Te[c[l>>2]&255](t,x,16,(c[n>>2]|0)+(k+4)|0,p,b[d+4912+(f<<8)+240>>1]|0,(b[d+4912+(f<<8)+242>>1]|0)+B|0,2,4);n=c[r>>2]|0;if((n|0)!=0){_e[c[n>>2]&511](t,16,t,16,a+3584+(m*144|0)+48|0,4)}t=c[u>>2]|0;if((t|0)==0){break}_e[c[t>>2]&511](x,16,x,16,a+3584+(m*144|0)+96|0,4)}}while(0);m=y<<4|-z&4;z=a+36908|0;y=hf[c[z>>2]&1023]((c[a+24548>>2]|0)+m|0,16,o,16)|0;A=(hf[c[z>>2]&1023]((c[a+24552>>2]|0)+m|0,16,j,16)|0)+y|0;i=h;return A|0}return 0}function IUb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;i=i+1072|0;k=j|0;if((h|0)!=0){pMb(b,0,c[b+28820>>2]|0)}h=b+36776+(d[b+36448|0]<<2)|0;l=hf[c[h>>2]&1023](c[b+24548>>2]|0,16,c[b+24572>>2]|0,32)|0;m=(hf[c[h>>2]&1023](c[b+24552>>2]|0,16,c[b+24576>>2]|0,32)|0)+l|0;l=m;h=(m|0)<0|0?-1:0;c[b+19372>>2]=g;if((c[b+152>>2]|0)==0){m=d[(d[95352+g|0]|0)+16465|0]|0;g=b+1520|0;c[g>>2]=m;n=b+19364|0;do{if((c[n>>2]|0)!=0){o=b+18576|0;p=c[o>>2]|0;q=5-p|0;r=b+28024|0;if((a[r]|0)==0){c[g>>2]=(d[100209+(q<<1)|0]|0)+m;s=p}else{a[r]=JUb(b,3,b+15456|0,q)|0;s=c[o>>2]|0}q=5-s|0;r=b+28064|0;if((a[r]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(q<<1)|0]|0)}else{a[r]=JUb(b,3,b+15472|0,q)|0}if((c[n>>2]|0)!=2){break}q=8<<c[o>>2];o=16;do{r=o+4|0;p=o;do{t=d[19112+p|0]|0;u=(d[t-8+(b+27984)|0]|0)+(d[t-1+(b+27984)|0]|0)|0;if((u|0)<128){v=(u+1|0)>>>1}else{v=u}u=d[1625080+(v&127)|0]|0;w=b+27984+t|0;if((a[w]|0)==0){c[g>>2]=(c[g>>2]|0)+(d[100209+(u<<1)|0]|0)}else{a[w]=JUb(b,4,b+17024+(p<<5)+2|0,u)|0}p=p+1|0;}while((p|0)<(r|0));o=o+q|0;}while((o|0)<48)}}while(0);v=ca(c[g>>2]|0,f)|0;x=(v|0)<0|0?-1:0;y=v;z=l<<8|0>>>24;A=h<<8|l>>>24;B=wrc(y,x,z,A)|0;C=G;i=j;return(G=C,B)|0}v=k+32|0;g=b+8632|0;Ee[c[b+37520>>2]&511](v,b+13920|0,(c[g>>2]|0)==3?1040:464)|0;KUb(b,k);n=b+28772|0;s=c[n>>2]|0;m=s&48;o=b+28768|0;q=c[o>>2]|0;r=q&48;p=(s|0)==-1;u=((m|0)==0|p)&1^1;if((r|0)==0){D=u}else{D=(q|0)==-1?u:u|2}u=b+19364|0;w=c[u>>2]|0;t=d[D+77+(k+36)|0]|0;do{if((w|0)==0){c[v>>2]=(c[v>>2]|0)+(e[101200+(t<<1)>>1]|0)}else{D=(c[v>>2]|0)+(e[101200+((t^1)<<1)>>1]|0)|0;c[v>>2]=D;E=(m|0)==32?5:4;c[v>>2]=(e[101200+((d[((r|0)==32?E|2:E)+77+(k+36)|0]^w>>1)<<1)>>1]|0)+D;if(p){F=1}else{F=s>>>9&1}if((q|0)==-1){H=2}else{H=q>>>9<<1&2}D=(a[b+28024|0]|0)==0;E=(H|F)+97+(k+36)|0;I=d[E]|0;do{if((c[g>>2]|0)==2){if(D){a[E]=a[100552+(I<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+(I<<1)>>1]|0);J=s}else{a[E]=a[100553+(I<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+((I^1)<<1)>>1]|0);LUb(c[b+18660>>2]|0,c[b+37788>>2]|0,k,b+15456|0);J=c[n>>2]|0}if((J|0)==-1){K=1}else{K=J>>>10&1}L=c[o>>2]|0;if((L|0)==-1){M=2}else{M=L>>>10<<1&2}L=(M|K)+97+(k+36)|0;N=d[L]|0;if((a[b+28064|0]|0)==0){a[L]=a[100552+(N<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+(N<<1)>>1]|0);break}else{a[L]=a[100553+(N<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+((N^1)<<1)>>1]|0);LUb(c[b+18660>>2]|0,c[b+37788>>2]|0,k,b+15472|0);break}}else{if(D){a[E]=a[100552+(I<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+(I<<1)>>1]|0);O=s}else{a[E]=a[100553+(I<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+((I^1)<<1)>>1]|0);TTb(b,k,3,b+15456|0);O=c[n>>2]|0}if((O|0)==-1){P=1}else{P=O>>>10&1}N=c[o>>2]|0;if((N|0)==-1){Q=2}else{Q=N>>>10<<1&2}N=(Q|P)+97+(k+36)|0;L=d[N]|0;if((a[b+28064|0]|0)==0){a[N]=a[100552+(L<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+(L<<1)>>1]|0);break}else{a[N]=a[100553+(L<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+((L^1)<<1)>>1]|0);TTb(b,k,3,b+15472|0);break}}}while(0);if((c[u>>2]|0)!=2){break}I=8<<c[b+18576>>2];E=16;do{D=E+4|0;L=E;do{N=d[19112+L|0]|0;R=(((a[N-8+(b+27984)|0]|0)!=0)<<1)+((a[N-1+(b+27984)|0]|0)!=0?102:101)+(k+36)|0;S=d[R]|0;if((a[b+27984+N|0]|0)==0){a[R]=a[100552+(S<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+(S<<1)>>1]|0)}else{a[R]=a[100553+(S<<1)|0]|0;c[v>>2]=(c[v>>2]|0)+(e[101200+((S^1)<<1)>>1]|0);TTb(b,k,4,b+17024+(L<<5)+2|0)}L=L+1|0;}while((L|0)<(D|0));E=E+I|0;}while((E|0)<48)}}while(0);b=c[v>>2]|0;v=Erc(b,(b|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=wrc(v,G,128,0)|0;v=G;x=v>>>8|0<<24;y=f>>>8|v<<24;z=l<<8|0>>>24;A=h<<8|l>>>24;B=wrc(y,x,z,A)|0;C=G;i=j;return(G=C,B)|0}function JUb(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;j=i;i=i+64|0;k=j|0;l=We[c[a+37840+(f<<2)>>2]&2047](g,k)|0;g=k+4|0;m=1-l+(c[k>>2]|0)|0;b[k+16+(l<<1)>>1]=2;b[k+16+(l+1<<1)>>1]=2;n=b[k+16>>1]|0;o=b[k+18>>1]|0;p=b[k+20>>1]|0;q=(o+1|1-o)>>31&2|(n+1|1-n)>>>31|(p+1|1-p)>>31&4;p=d[100360+q|0]|0;n=l-1|0;o=a+1520|0;r=(c[o>>2]|0)+(d[99400+(h<<7)+(n<<3)+(p<<1)+1|0]|0)|0;c[o>>2]=r;if((l|0)>10){s=(q|0)!=0|0}else{s=0}h=r+p|0;c[o>>2]=h;do{if((p|0)<(l|0)){r=b[k+16+(p<<1)>>1]|0;t=r+64|0;u=r-((r>>31|1)&-((q|0)!=0|0))|0;if(t>>>0<128>>>0){r=(d[3035176+(s<<9)+(u+64<<2)+2|0]|0)+h|0;c[o>>2]=r;v=d[3035176+(s<<9)+(t<<2)+3|0]|0;w=r}else{r=u>>31;t=(r^u)-r|0;u=(t<<1)-r-2|0;r=u>>s;if((r|0)<15){x=s+1+h+r|0}else{r=u-(15<<s)|0;u=(s|0)==0?r-15|0:r;do{if((u|0)>4095){if((c[a+8372>>2]|0)<=99){r=h+2e3|0;c[o>>2]=r;y=30;z=r;break}if((u|0)>4096){A=15;B=u;C=4096}else{y=30;z=h;break}while(1){r=B-C|0;D=A+1|0;E=1<<A-2;if((r|0)>(E|0)){A=D;B=r;C=E}else{break}}y=D<<1;z=h}else{y=30;z=h}}while(0);x=z-2+y|0}c[o>>2]=x;u=(s^1)+s|0;v=((t|0)>(e[100416+(u<<1)>>1]|0))+u|0;w=x}u=p+1|0;if((u|0)>=(l|0)){F=w;break}E=a+8372|0;r=v;G=u;u=w;while(1){H=b[k+16+(G<<1)>>1]|0;I=H+64|0;if(I>>>0<128>>>0){J=u+(d[3035176+(r<<9)+(I<<2)+2|0]|0)|0;c[o>>2]=J;K=d[3035176+(r<<9)+(I<<2)+3|0]|0;L=J}else{J=H>>31;I=(J^H)-J|0;H=(I<<1)-J-2|0;J=H>>r;if((J|0)<15){M=r+1+J+u|0}else{J=H-(15<<r)|0;H=(r|0)==0?J-15|0:J;do{if((H|0)>4095){if((c[E>>2]|0)<=99){J=u+2e3|0;c[o>>2]=J;N=30;O=J;break}if((H|0)>4096){P=15;Q=H;R=4096}else{N=30;O=u;break}while(1){J=Q-R|0;S=P+1|0;T=1<<P-2;if((J|0)>(T|0)){P=S;Q=J;R=T}else{break}}N=S<<1;O=u}else{N=30;O=u}}while(0);M=O-2+N|0}c[o>>2]=M;H=((r|0)==0)+r|0;K=((I|0)>(e[100416+(H<<1)>>1]|0))+H|0;L=M}H=G+1|0;if((H|0)<(l|0)){r=K;G=H;u=L}else{F=L;break}}}else{F=h}}while(0);if((f|0)!=3){if(!((l&255)>>>0<(d[100384+f|0]|0)>>>0)){U=F;V=c[g>>2]|0;W=2772392+(V<<2)|0;X=c[W>>2]|0;Y=X&31;Z=U+Y|0;c[o>>2]=Z;i=j;return l|0}f=F+(d[18168+(n<<5)+(m<<1)+1|0]|0)|0;c[o>>2]=f;U=f;V=c[g>>2]|0;W=2772392+(V<<2)|0;X=c[W>>2]|0;Y=X&31;Z=U+Y|0;c[o>>2]=Z;i=j;return l|0}if((l|0)>=(8>>>((c[a+18576>>2]|0)>>>0)|0)){U=F;V=c[g>>2]|0;W=2772392+(V<<2)|0;X=c[W>>2]|0;Y=X&31;Z=U+Y|0;c[o>>2]=Z;i=j;return l|0}if((c[a+8632>>2]|0)==1){_=18144+(n<<3)+(m<<1)+1|0}else{_=18032+(n<<4)+(m<<1)+1|0}m=F+(d[_]|0)|0;c[o>>2]=m;U=m;V=c[g>>2]|0;W=2772392+(V<<2)|0;X=c[W>>2]|0;Y=X&31;Z=U+Y|0;c[o>>2]=Z;i=j;return l|0}function KUb(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c[b+19372>>2]|0;h=c[b+18784>>2]|0;if((h&1|0)==0){i=0}else{i=(a[(c[b+18980>>2]|0)+(c[b+18900>>2]|0)|0]|0)!=0|0}if((h&2|0)==0){j=i}else{j=((a[(c[b+18980>>2]|0)+(c[b+18908>>2]|0)|0]|0)!=0)+i|0}i=(g-1|0)>>>0<3>>>0;b=f+32|0;h=(c[b>>2]|0)+(e[101200+((d[j+64+(f+36)|0]^i&1)<<1)>>1]|0)|0;c[b>>2]=h;if(!i){return}i=(g-2|0)>>>0<2>>>0;j=i&1;k=f+103|0;f=d[k]|0;l=a[100552+(f<<1)+j|0]|0;a[k]=l;k=h+(e[101200+((f^j)<<1)>>1]|0)|0;c[b>>2]=k;if(!i){return}c[b>>2]=(e[101200+((l&255^(g|0)==3)<<1)>>1]|0)+k;return}function LUb(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=e[18870+(f<<5)>>1]|0;k=e[97198+(f<<5)>>1]|0;f=ve[g&4095](i)|0;g=b[i+(f<<1)>>1]|0;l=g<<16>>16;m=g<<16>>16>-1?l:-l|0;if((f|0)!=7){l=d[100168+f|0]|0;g=l+j+(h+36)|0;n=d[g]|0;a[g]=a[100553+(n<<1)|0]|0;g=h+32|0;c[g>>2]=(c[g>>2]|0)+(e[101200+((n^1)<<1)>>1]|0);n=l+k+(h+36)|0;l=d[n]|0;a[n]=a[100553+(l<<1)|0]|0;c[g>>2]=(c[g>>2]|0)+(e[101200+((l^1)<<1)>>1]|0)}l=h+294|0;g=d[l]|0;do{if((m|0)>1){a[l]=a[100553+(g<<1)|0]|0;n=h+32|0;o=(c[n>>2]|0)+(e[101200+((g^1)<<1)>>1]|0)|0;c[n>>2]=o;p=h+298|0;q=d[p]|0;if((m|0)<15){r=m-1|0;c[n>>2]=(e[3059120+(r<<8)+(q<<1)>>1]|0)+o;a[p]=a[3057200+(r<<7)+q|0]|0;s=4;break}r=(e[3062704+(q<<1)>>1]|0)+o|0;c[n>>2]=r;a[p]=a[3058992+q|0]|0;q=m-14|0;if((m-15|0)>>>0<255>>>0){t=d[16464+q|0]|0}else{t=(d[16464+(q>>>8)|0]|0)+16|0}c[n>>2]=r+(t<<8);s=4}else{a[l]=a[100552+(g<<1)|0]|0;r=h+32|0;c[r>>2]=(e[101200+(g<<1)>>1]|0)+256+(c[r>>2]|0);s=1}}while(0);if((f|0)<=0){return}g=h+32|0;l=s;s=f;a:while(1){f=s;while(1){u=f-1|0;v=b[i+(u<<1)>>1]|0;if(!(v<<16>>16==0)){break}t=(d[100168+u|0]|0)+j+(h+36)|0;m=d[t]|0;a[t]=a[100552+(m<<1)|0]|0;c[g>>2]=(c[g>>2]|0)+(e[101200+(m<<1)>>1]|0);if((u|0)>0){f=u}else{w=26;break a}}f=v<<16>>16;m=v<<16>>16>-1?f:-f|0;f=d[100168+u|0]|0;t=f+j+(h+36)|0;r=d[t]|0;a[t]=a[100553+(r<<1)|0]|0;c[g>>2]=(c[g>>2]|0)+(e[101200+((r^1)<<1)>>1]|0);r=f+k+(h+36)|0;f=d[r]|0;a[r]=a[100552+(f<<1)|0]|0;c[g>>2]=(c[g>>2]|0)+(e[101200+(f<<1)>>1]|0);f=(d[1648664+l|0]|0)+257+(h+36)|0;r=d[f]|0;if((m|0)>1){a[f]=a[100553+(r<<1)|0]|0;t=(c[g>>2]|0)+(e[101200+((r^1)<<1)>>1]|0)|0;c[g>>2]=t;n=(d[1648600+l|0]|0)+257+(h+36)|0;q=d[n]|0;if((m|0)<15){p=m-1|0;c[g>>2]=(e[3059120+(p<<8)+(q<<1)>>1]|0)+t;a[n]=a[(d[n]|0)+(3057200+(p<<7))|0]|0}else{c[g>>2]=(e[3062704+(q<<1)>>1]|0)+t;a[n]=a[3058992+(d[n]|0)|0]|0;n=m-14|0;if((m-15|0)>>>0<255>>>0){x=d[16464+n|0]|0}else{x=(d[16464+(n>>>8)|0]|0)+16|0}c[g>>2]=(c[g>>2]|0)+(x<<8)}y=a[1648648+l|0]|0}else{a[f]=a[100552+(r<<1)|0]|0;f=a[1648640+l|0]|0;c[g>>2]=(e[101200+(r<<1)>>1]|0)+256+(c[g>>2]|0);y=f}if((u|0)>0){l=y&255;s=u}else{w=26;break}}if((w|0)==26){return}}function MUb(a,b,c,f,g,h,i){a=a|0;b=b|0;c=c|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=(b|0)>-1?b:-b|0;b=a>>31;k=a>>>31|8;l=f;m=(f|0)<0|0?-1:0;f=h+1|0;n=h+5|0;h=g;o=(g|0)<0|0?-1:0;g=j-1|0;p=0;q=-1;r=-1;while(1){s=a-(k+((ca(g,c)|0)+128>>8^b)&-16)|0;t=s;u=(s|0)<0|0?-1:0;s=Erc(t,u,l,m)|0;v=Erc(s,G,t,u)|0;u=G;if((g|0)==0){w=u;x=v}else{t=g-1|0;s=(t|0)<14?t:14;t=(e[101200+(((d[f]|0)^(s|0)>0)<<1)>>1]|0)+i+(e[3059120+(s<<8)+((d[n]|0)<<1)>>1]|0)|0;if((g|0)>14){s=g-14|0;if((g-15|0)>>>0<255>>>0){y=d[16464+s|0]|0}else{y=(d[16464+(s>>>8)|0]|0)+16|0}z=(y<<8)+t|0}else{z=t}t=Erc(z,0,h,o)|0;s=G;A=wrc(t>>>4|s<<28,s>>>4|0<<28,v,u)|0;w=G;x=A}A=w>>>0<q>>>0|w>>>0==q>>>0&x>>>0<r>>>0;B=A?g:p;u=g+1|0;if((u|0)>(j|0)){break}else{g=u;p=B;q=A?w:q;r=A?x:r}}return(B^b)-b|0}function NUb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=e|0;i=wrc(c[h>>2]|0,c[h+4>>2]|0,a,b)|0;b=d|0;c[b>>2]=i;c[b+4>>2]=G;c[d+8>>2]=c[e+8>>2];b=e+16|0;i=c[b>>2]|0;a=c[b+4>>2]|0;b=-1;if(!((a|0)>(b|0)|(a|0)==(b|0)&i>>>0>-1>>>0)){j=g;return j|0}b=d+16|0;c[b>>2]=i;c[b+4>>2]=a;c[f+(g<<2)>>2]=c[e+24>>2];c[d+24>>2]=g;a=g+1|0;b=e+32|0;i=c[b>>2]|0;h=c[b+4>>2]|0;b=-1;if(!((h|0)>(b|0)|(h|0)==(b|0)&i>>>0>-1>>>0)){j=a;return j|0}b=d+32|0;c[b>>2]=i;c[b+4>>2]=h;c[f+(a<<2)>>2]=c[e+40>>2];c[d+40>>2]=a;a=g+2|0;h=e+48|0;b=c[h>>2]|0;i=c[h+4>>2]|0;h=-1;if(!((i|0)>(h|0)|(i|0)==(h|0)&b>>>0>-1>>>0)){j=a;return j|0}h=d+48|0;c[h>>2]=b;c[h+4>>2]=i;c[d+60>>2]=c[e+60>>2];c[f+(a<<2)>>2]=c[e+56>>2];c[d+56>>2]=a;j=g+3|0;return j|0}function OUb(b,f,g,h,i,j,k,l,m,n,o){b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;p=k|0;q=wrc(c[p>>2]|0,c[p+4>>2]|0,b,f)|0;f=G;b=n;p=(n|0)<0|0?-1:0;n=Erc((c[i+8>>2]|0)+256+(e[101200+((d[o+1|0]|0)<<1)>>1]|0)|0,0,b,p)|0;r=G;s=wrc(q,f,n>>>4|r<<28,r>>>4|0<<28)|0;r=G;n=j+16|0;f=c[n+4>>2]|0;if(r>>>0<f>>>0|r>>>0==f>>>0&s>>>0<(c[n>>2]|0)>>>0){c[n>>2]=s;c[n+4>>2]=r;r=k+8|0;n=j+24|0;c[n>>2]=c[r>>2];c[l+(m<<2)>>2]=(c[r>>2]|0)+65536;c[n>>2]=m;t=m+1|0}else{t=m}m=k+16|0;n=c[m>>2]|0;r=c[m+4>>2]|0;m=-1;if(!((r|0)>(m|0)|(r|0)==(m|0)&n>>>0>-1>>>0)){u=t;return u|0}m=wrc(n,r,g,h)|0;r=G;n=i+4|0;i=Erc((c[n>>2]|0)+256+(e[101200+((d[o+2|0]|0)<<1)>>1]|0)|0,0,b,p)|0;s=G;f=wrc(m,r,i>>>4|s<<28,s>>>4|0<<28)|0;s=G;i=j+32|0;r=c[i+4>>2]|0;if(s>>>0<r>>>0|s>>>0==r>>>0&f>>>0<(c[i>>2]|0)>>>0){c[i>>2]=f;c[i+4>>2]=s;s=k+24|0;i=j+40|0;c[i>>2]=c[s>>2];c[l+(t<<2)>>2]=(c[s>>2]|0)+65536;c[i>>2]=t;v=t+1|0}else{v=t}t=k+32|0;i=c[t>>2]|0;s=c[t+4>>2]|0;t=-1;if(!((s|0)>(t|0)|(s|0)==(t|0)&i>>>0>-1>>>0)){u=v;return u|0}t=wrc(i,s,g,h)|0;s=G;i=Erc((c[n>>2]|0)+256+(e[101200+((d[o+3|0]|0)<<1)>>1]|0)|0,0,b,p)|0;f=G;r=wrc(t,s,i>>>4|f<<28,f>>>4|0<<28)|0;f=G;i=j+48|0;s=c[i+4>>2]|0;if(f>>>0<s>>>0|f>>>0==s>>>0&r>>>0<(c[i>>2]|0)>>>0){c[i>>2]=r;c[i+4>>2]=f;c[j+60>>2]=c[o+12>>2];o=k+40|0;f=j+56|0;c[f>>2]=c[o>>2];c[l+(v<<2)>>2]=(c[o>>2]|0)+65536;c[f>>2]=v;w=v+1|0}else{w=v}v=k+48|0;f=c[v>>2]|0;o=c[v+4>>2]|0;v=-1;if(!((o|0)>(v|0)|(o|0)==(v|0)&f>>>0>-1>>>0)){u=w;return u|0}v=wrc(f,o,g,h)|0;h=G;g=d[k+61|0]|0;o=Erc((c[n>>2]|0)+256+(e[101200+(g<<1)>>1]|0)|0,0,b,p)|0;p=G;b=wrc(v,h,o>>>4|p<<28,p>>>4|0<<28)|0;p=G;o=c[i+4>>2]|0;if(!(p>>>0<o>>>0|p>>>0==o>>>0&b>>>0<(c[i>>2]|0)>>>0)){u=w;return u|0}c[i>>2]=b;c[i+4>>2]=p;c[j+60>>2]=c[k+60>>2];a[j+61|0]=a[100552+(g<<1)|0]|0;g=k+56|0;k=j+56|0;c[k>>2]=c[g>>2];c[l+(w<<2)>>2]=(c[g>>2]|0)+65536;c[k>>2]=w;u=w+1|0;return u|0}function PUb(b,f,g,h,i,j,k,l,m,n,o,p){b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;q=b-1|0;r=(q|0)<14?q:14;if((b|0)>14){q=b-14|0;if((b-15|0)>>>0<255>>>0){s=d[16464+q|0]|0}else{s=(d[16464+(q>>>8)|0]|0)+16|0}t=s<<8}else{t=0}s=l|0;q=wrc(c[s>>2]|0,c[s+4>>2]|0,f,g)|0;g=G;f=p+5|0;s=o;u=(o|0)<0|0?-1:0;o=Erc((c[j+8>>2]|0)+t+(e[101200+(((d[p+1|0]|0)^1)<<1)>>1]|0)+(e[3059120+(r<<8)+((d[f]|0)<<1)>>1]|0)|0,0,s,u)|0;v=G;w=wrc(q,g,o>>>4|v<<28,v>>>4|0<<28)|0;v=G;o=k+64|0;g=c[o+4>>2]|0;if(v>>>0<g>>>0|v>>>0==g>>>0&w>>>0<(c[o>>2]|0)>>>0){c[o>>2]=w;c[o+4>>2]=v;c[k+76>>2]=c[p+12>>2];v=l+8|0;w=k+72|0;c[w>>2]=c[v>>2];c[m+(n<<2)>>2]=(c[v>>2]|0)+(b<<16);c[w>>2]=n;x=n+1|0}else{x=n}n=l+16|0;w=c[n>>2]|0;v=c[n+4>>2]|0;n=-1;if(!((v|0)>(n|0)|(v|0)==(n|0)&w>>>0>-1>>>0)){y=x;return y|0}n=wrc(w,v,h,i)|0;v=G;w=j+4|0;j=Erc((c[w>>2]|0)+t+(e[101200+(((d[p+2|0]|0)^1)<<1)>>1]|0)+(e[3059120+(r<<8)+((d[f]|0)<<1)>>1]|0)|0,0,s,u)|0;g=G;q=wrc(n,v,j>>>4|g<<28,g>>>4|0<<28)|0;g=G;j=c[o+4>>2]|0;if(g>>>0<j>>>0|g>>>0==j>>>0&q>>>0<(c[o>>2]|0)>>>0){c[o>>2]=q;c[o+4>>2]=g;c[k+76>>2]=c[p+12>>2];g=l+24|0;q=k+72|0;c[q>>2]=c[g>>2];c[m+(x<<2)>>2]=(c[g>>2]|0)+(b<<16);c[q>>2]=x;z=x+1|0}else{z=x}x=l+32|0;q=c[x>>2]|0;g=c[x+4>>2]|0;x=-1;if(!((g|0)>(x|0)|(g|0)==(x|0)&q>>>0>-1>>>0)){y=z;return y|0}x=wrc(q,g,h,i)|0;g=G;q=Erc((c[w>>2]|0)+t+(e[101200+(((d[p+3|0]|0)^1)<<1)>>1]|0)+(e[3059120+(r<<8)+((d[f]|0)<<1)>>1]|0)|0,0,s,u)|0;j=G;v=wrc(x,g,q>>>4|j<<28,j>>>4|0<<28)|0;j=G;q=c[o+4>>2]|0;if(j>>>0<q>>>0|j>>>0==q>>>0&v>>>0<(c[o>>2]|0)>>>0){c[o>>2]=v;c[o+4>>2]=j;c[k+76>>2]=c[p+12>>2];j=l+40|0;v=k+72|0;c[v>>2]=c[j>>2];c[m+(z<<2)>>2]=(c[j>>2]|0)+(b<<16);c[v>>2]=z;A=z+1|0}else{A=z}z=l+48|0;v=c[z>>2]|0;j=c[z+4>>2]|0;z=-1;if(!((j|0)>(z|0)|(j|0)==(z|0)&v>>>0>-1>>>0)){y=A;return y|0}z=wrc(v,j,h,i)|0;i=G;h=d[l+61|0]|0;j=Erc((c[w>>2]|0)+t+(e[101200+((h^1)<<1)>>1]|0)+(e[3059120+(r<<8)+((d[f]|0)<<1)>>1]|0)|0,0,s,u)|0;u=G;s=wrc(z,i,j>>>4|u<<28,u>>>4|0<<28)|0;u=G;j=c[o+4>>2]|0;if(!(u>>>0<j>>>0|u>>>0==j>>>0&s>>>0<(c[o>>2]|0)>>>0)){y=A;return y|0}c[o>>2]=s;c[o+4>>2]=u;c[k+76>>2]=c[p+12>>2];a[k+77|0]=a[100553+(h<<1)|0]|0;h=l+56|0;l=k+72|0;c[l>>2]=c[h>>2];c[m+(A<<2)>>2]=(c[h>>2]|0)+(b<<16);c[l>>2]=A;y=A+1|0;return y|0}function QUb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=e;e=1;while(1){g=b+(e<<4)|0;h=c[g>>2]|0;i=c[g+4>>2]|0;g=-1;if((i|0)>(g|0)|(i|0)==(g|0)&h>>>0>-1>>>0){g=a+(e<<4)|0;c[g>>2]=h;c[g+4>>2]=i;if((e|0)>2){c[a+(e<<4)+12>>2]=c[b+(e<<4)+12>>2]}c[d+(f<<2)>>2]=c[b+(e<<4)+8>>2];c[a+(e<<4)+8>>2]=f;j=f+1|0}else{j=f}i=e+1|0;if((i|0)<8){f=j;e=i}else{break}}return j|0}function RUb(b,f,g,h,i,j,k,l,m){b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;n=i+16|0;o=c[n>>2]|0;p=c[n+4>>2]|0;n=-1;do{if((p|0)>(n|0)|(p|0)==(n|0)&o>>>0>-1>>>0){q=wrc(o,p,b,f)|0;r=G;s=Erc((c[g+4>>2]|0)+256+(e[101200+((d[m+2|0]|0)<<1)>>1]|0)|0,0,l,(l|0)<0|0?-1:0)|0;t=G;u=wrc(q,r,s>>>4|t<<28,t>>>4|0<<28)|0;t=G;s=h+32|0;r=c[s+4>>2]|0;if(!(t>>>0<r>>>0|t>>>0==r>>>0&u>>>0<(c[s>>2]|0)>>>0)){v=k;break}c[s>>2]=u;c[s+4>>2]=t;t=i+24|0;s=h+40|0;c[s>>2]=c[t>>2];c[j+(k<<2)>>2]=(c[t>>2]|0)+65536;c[s>>2]=k;v=k+1|0}else{v=k}}while(0);k=i+32|0;p=c[k>>2]|0;o=c[k+4>>2]|0;k=-1;do{if((o|0)>(k|0)|(o|0)==(k|0)&p>>>0>-1>>>0){n=wrc(p,o,b,f)|0;s=G;t=Erc((c[g+4>>2]|0)+256+(e[101200+((d[m+3|0]|0)<<1)>>1]|0)|0,0,l,(l|0)<0|0?-1:0)|0;u=G;r=wrc(n,s,t>>>4|u<<28,u>>>4|0<<28)|0;u=G;t=h+48|0;s=c[t+4>>2]|0;if(!(u>>>0<s>>>0|u>>>0==s>>>0&r>>>0<(c[t>>2]|0)>>>0)){w=v;break}c[t>>2]=r;c[t+4>>2]=u;c[h+60>>2]=c[m+12>>2];u=i+40|0;t=h+56|0;c[t>>2]=c[u>>2];c[j+(v<<2)>>2]=(c[u>>2]|0)+65536;c[t>>2]=v;w=v+1|0}else{w=v}}while(0);v=i+48|0;m=c[v>>2]|0;o=c[v+4>>2]|0;v=-1;do{if((o|0)>(v|0)|(o|0)==(v|0)&m>>>0>-1>>>0){p=wrc(m,o,b,f)|0;k=G;t=d[i+61|0]|0;u=Erc((c[g+4>>2]|0)+256+(e[101200+(t<<1)>>1]|0)|0,0,l,(l|0)<0|0?-1:0)|0;r=G;s=wrc(p,k,u>>>4|r<<28,r>>>4|0<<28)|0;r=G;u=h+48|0;k=c[u+4>>2]|0;if(!(r>>>0<k>>>0|r>>>0==k>>>0&s>>>0<(c[u>>2]|0)>>>0)){x=w;break}c[u>>2]=s;c[u+4>>2]=r;c[h+60>>2]=c[i+60>>2];a[h+61|0]=a[100552+(t<<1)|0]|0;t=i+56|0;r=h+56|0;c[r>>2]=c[t>>2];c[j+(w<<2)>>2]=(c[t>>2]|0)+65536;c[r>>2]=w;x=w+1|0}else{x=w}}while(0);w=i+64|0;o=c[w>>2]|0;m=c[w+4>>2]|0;w=-1;do{if((m|0)>(w|0)|(m|0)==(w|0)&o>>>0>-1>>>0){v=wrc(o,m,b,f)|0;r=G;t=i+76|0;u=d[t]|0;s=Erc((c[g+4>>2]|0)+256+(e[101200+(u<<1)>>1]|0)|0,0,l,(l|0)<0|0?-1:0)|0;k=G;p=wrc(v,r,s>>>4|k<<28,k>>>4|0<<28)|0;k=G;s=h+64|0;r=c[s+4>>2]|0;if(!(k>>>0<r>>>0|k>>>0==r>>>0&p>>>0<(c[s>>2]|0)>>>0)){y=x;break}c[s>>2]=p;c[s+4>>2]=k;k=h+76|0;c[k>>2]=c[t>>2];a[k]=a[100552+(u<<1)|0]|0;u=i+72|0;k=h+72|0;c[k>>2]=c[u>>2];c[j+(x<<2)>>2]=(c[u>>2]|0)+65536;c[k>>2]=x;y=x+1|0}else{y=x}}while(0);x=i+80|0;m=c[x>>2]|0;o=c[x+4>>2]|0;x=-1;do{if((o|0)>(x|0)|(o|0)==(x|0)&m>>>0>-1>>>0){w=wrc(m,o,b,f)|0;k=G;u=i+92|0;t=d[u]|0;s=Erc((c[g+4>>2]|0)+256+(e[101200+(t<<1)>>1]|0)|0,0,l,(l|0)<0|0?-1:0)|0;p=G;r=wrc(w,k,s>>>4|p<<28,p>>>4|0<<28)|0;p=G;s=h+80|0;k=c[s+4>>2]|0;if(!(p>>>0<k>>>0|p>>>0==k>>>0&r>>>0<(c[s>>2]|0)>>>0)){z=y;break}c[s>>2]=r;c[s+4>>2]=p;p=h+92|0;c[p>>2]=c[u>>2];a[p]=a[100552+(t<<1)|0]|0;t=i+88|0;p=h+88|0;c[p>>2]=c[t>>2];c[j+(y<<2)>>2]=(c[t>>2]|0)+65536;c[p>>2]=y;z=y+1|0}else{z=y}}while(0);y=i+96|0;o=c[y>>2]|0;m=c[y+4>>2]|0;y=-1;do{if((m|0)>(y|0)|(m|0)==(y|0)&o>>>0>-1>>>0){x=wrc(o,m,b,f)|0;p=G;t=i+108|0;u=d[t]|0;s=Erc((c[g+4>>2]|0)+256+(e[101200+(u<<1)>>1]|0)|0,0,l,(l|0)<0|0?-1:0)|0;r=G;k=wrc(x,p,s>>>4|r<<28,r>>>4|0<<28)|0;r=G;s=h+96|0;p=c[s+4>>2]|0;if(!(r>>>0<p>>>0|r>>>0==p>>>0&k>>>0<(c[s>>2]|0)>>>0)){A=z;break}c[s>>2]=k;c[s+4>>2]=r;r=h+108|0;c[r>>2]=c[t>>2];a[r]=a[100552+(u<<1)|0]|0;u=i+104|0;r=h+104|0;c[r>>2]=c[u>>2];c[j+(z<<2)>>2]=(c[u>>2]|0)+65536;c[r>>2]=z;A=z+1|0}else{A=z}}while(0);z=i+112|0;m=c[z>>2]|0;o=c[z+4>>2]|0;z=-1;if(!((o|0)>(z|0)|(o|0)==(z|0)&m>>>0>-1>>>0)){B=A;return B|0}z=wrc(m,o,b,f)|0;f=G;b=i+124|0;o=d[b]|0;m=Erc((c[g+4>>2]|0)+256+(e[101200+(o<<1)>>1]|0)|0,0,l,(l|0)<0|0?-1:0)|0;l=G;g=wrc(z,f,m>>>4|l<<28,l>>>4|0<<28)|0;l=G;m=h+112|0;f=c[m+4>>2]|0;if(!(l>>>0<f>>>0|l>>>0==f>>>0&g>>>0<(c[m>>2]|0)>>>0)){B=A;return B|0}c[m>>2]=g;c[m+4>>2]=l;l=h+124|0;c[l>>2]=c[b>>2];a[l]=a[100552+(o<<1)|0]|0;o=i+120|0;i=h+120|0;c[i>>2]=c[o>>2];c[j+(A<<2)>>2]=(c[o>>2]|0)+65536;c[i>>2]=A;B=A+1|0;return B|0}function SUb(b,f,g,h,i,j,k,l,m,n,o){b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;p=b-1|0;q=(p|0)<14?p:14;if((b|0)>14){p=b-14|0;if((b-15|0)>>>0<255>>>0){r=d[16464+p|0]|0}else{r=(d[16464+(p>>>8)|0]|0)+16|0}s=r<<8}else{s=0}r=j+16|0;p=c[r>>2]|0;t=c[r+4>>2]|0;r=-1;do{if((t|0)>(r|0)|(t|0)==(r|0)&p>>>0>-1>>>0){u=wrc(p,t,f,g)|0;v=G;w=Erc((c[h+4>>2]|0)+s+(e[101200+(((d[n+2|0]|0)^1)<<1)>>1]|0)+(e[3059120+(q<<8)+((d[n+5|0]|0)<<1)>>1]|0)|0,0,m,(m|0)<0|0?-1:0)|0;x=G;y=wrc(u,v,w>>>4|x<<28,x>>>4|0<<28)|0;x=G;w=i+64|0;v=c[w+4>>2]|0;if(!(x>>>0<v>>>0|x>>>0==v>>>0&y>>>0<(c[w>>2]|0)>>>0)){z=l;break}c[w>>2]=y;c[w+4>>2]=x;c[i+76>>2]=c[n+12>>2];x=j+24|0;w=i+72|0;c[w>>2]=c[x>>2];c[k+(l<<2)>>2]=(c[x>>2]|0)+(b<<16);c[w>>2]=l;z=l+1|0}else{z=l}}while(0);l=j+32|0;t=c[l>>2]|0;p=c[l+4>>2]|0;l=-1;do{if((p|0)>(l|0)|(p|0)==(l|0)&t>>>0>-1>>>0){r=wrc(t,p,f,g)|0;w=G;x=Erc((c[h+4>>2]|0)+s+(e[101200+(((d[n+3|0]|0)^1)<<1)>>1]|0)+(e[3059120+(q<<8)+((d[n+5|0]|0)<<1)>>1]|0)|0,0,m,(m|0)<0|0?-1:0)|0;y=G;v=wrc(r,w,x>>>4|y<<28,y>>>4|0<<28)|0;y=G;x=i+64|0;w=c[x+4>>2]|0;if(!(y>>>0<w>>>0|y>>>0==w>>>0&v>>>0<(c[x>>2]|0)>>>0)){A=z;break}c[x>>2]=v;c[x+4>>2]=y;c[i+76>>2]=c[n+12>>2];y=j+40|0;x=i+72|0;c[x>>2]=c[y>>2];c[k+(z<<2)>>2]=(c[y>>2]|0)+(b<<16);c[x>>2]=z;A=z+1|0}else{A=z}}while(0);z=j+48|0;p=c[z>>2]|0;t=c[z+4>>2]|0;z=-1;do{if((t|0)>(z|0)|(t|0)==(z|0)&p>>>0>-1>>>0){l=wrc(p,t,f,g)|0;x=G;y=d[j+61|0]|0;v=Erc((c[h+4>>2]|0)+s+(e[101200+((y^1)<<1)>>1]|0)+(e[3059120+(q<<8)+((d[n+5|0]|0)<<1)>>1]|0)|0,0,m,(m|0)<0|0?-1:0)|0;w=G;r=wrc(l,x,v>>>4|w<<28,w>>>4|0<<28)|0;w=G;v=i+64|0;x=c[v+4>>2]|0;if(!(w>>>0<x>>>0|w>>>0==x>>>0&r>>>0<(c[v>>2]|0)>>>0)){B=A;break}c[v>>2]=r;c[v+4>>2]=w;c[i+76>>2]=c[n+12>>2];a[i+77|0]=a[100553+(y<<1)|0]|0;y=j+56|0;w=i+72|0;c[w>>2]=c[y>>2];c[k+(A<<2)>>2]=(c[y>>2]|0)+(b<<16);c[w>>2]=A;B=A+1|0}else{B=A}}while(0);A=j+64|0;t=c[A>>2]|0;p=c[A+4>>2]|0;A=-1;do{if((p|0)>(A|0)|(p|0)==(A|0)&t>>>0>-1>>>0){z=wrc(t,p,f,g)|0;w=G;y=j+76|0;v=d[y]|0;r=Erc((c[h+4>>2]|0)+s+(e[101200+((v^1)<<1)>>1]|0)+(e[3059120+(q<<8)+((d[n+6|0]|0)<<1)>>1]|0)|0,0,m,(m|0)<0|0?-1:0)|0;x=G;l=wrc(z,w,r>>>4|x<<28,x>>>4|0<<28)|0;x=G;r=i+80|0;w=c[r+4>>2]|0;if(!(x>>>0<w>>>0|x>>>0==w>>>0&l>>>0<(c[r>>2]|0)>>>0)){C=B;break}c[r>>2]=l;c[r+4>>2]=x;x=i+92|0;c[x>>2]=c[y>>2];a[x]=a[100553+(v<<1)|0]|0;v=j+72|0;x=i+88|0;c[x>>2]=c[v>>2];c[k+(B<<2)>>2]=(c[v>>2]|0)+(b<<16);c[x>>2]=B;C=B+1|0}else{C=B}}while(0);B=j+80|0;p=c[B>>2]|0;t=c[B+4>>2]|0;B=-1;do{if((t|0)>(B|0)|(t|0)==(B|0)&p>>>0>-1>>>0){A=wrc(p,t,f,g)|0;x=G;v=j+92|0;y=d[v]|0;r=Erc((c[h+4>>2]|0)+s+(e[101200+((y^1)<<1)>>1]|0)+(e[3059120+(q<<8)+((d[n+7|0]|0)<<1)>>1]|0)|0,0,m,(m|0)<0|0?-1:0)|0;l=G;w=wrc(A,x,r>>>4|l<<28,l>>>4|0<<28)|0;l=G;r=i+96|0;x=c[r+4>>2]|0;if(!(l>>>0<x>>>0|l>>>0==x>>>0&w>>>0<(c[r>>2]|0)>>>0)){D=C;break}c[r>>2]=w;c[r+4>>2]=l;l=i+108|0;c[l>>2]=c[v>>2];a[l]=a[100553+(y<<1)|0]|0;y=j+88|0;l=i+104|0;c[l>>2]=c[y>>2];c[k+(C<<2)>>2]=(c[y>>2]|0)+(b<<16);c[l>>2]=C;D=C+1|0}else{D=C}}while(0);C=j+96|0;n=c[C>>2]|0;t=c[C+4>>2]|0;C=-1;do{if((t|0)>(C|0)|(t|0)==(C|0)&n>>>0>-1>>>0){p=wrc(n,t,f,g)|0;B=G;l=j+108|0;y=d[l]|0;v=d[j+110|0]|0;r=Erc((c[h+4>>2]|0)+s+(e[101200+((y^1)<<1)>>1]|0)+(e[3059120+(q<<8)+(v<<1)>>1]|0)|0,0,m,(m|0)<0|0?-1:0)|0;w=G;x=wrc(p,B,r>>>4|w<<28,w>>>4|0<<28)|0;w=G;r=i+112|0;B=c[r+4>>2]|0;if(!(w>>>0<B>>>0|w>>>0==B>>>0&x>>>0<(c[r>>2]|0)>>>0)){E=D;break}c[r>>2]=x;c[r+4>>2]=w;w=i+124|0;c[w>>2]=c[l>>2];a[w]=a[100553+(y<<1)|0]|0;a[i+126|0]=a[3057200+(q<<7)+v|0]|0;v=j+104|0;y=i+120|0;c[y>>2]=c[v>>2];c[k+(D<<2)>>2]=(c[v>>2]|0)+(b<<16);c[y>>2]=D;E=D+1|0}else{E=D}}while(0);D=j+112|0;t=c[D>>2]|0;n=c[D+4>>2]|0;D=-1;if(!((n|0)>(D|0)|(n|0)==(D|0)&t>>>0>-1>>>0)){F=E;return F|0}D=wrc(t,n,f,g)|0;g=G;f=j+124|0;n=d[f]|0;t=o-6|0;o=d[j+124+t|0]|0;C=Erc((c[h+4>>2]|0)+s+(e[101200+((n^1)<<1)>>1]|0)+(e[3059120+(q<<8)+(o<<1)>>1]|0)|0,0,m,(m|0)<0|0?-1:0)|0;m=G;s=wrc(D,g,C>>>4|m<<28,m>>>4|0<<28)|0;m=G;C=i+112|0;g=c[C+4>>2]|0;if(!(m>>>0<g>>>0|m>>>0==g>>>0&s>>>0<(c[C>>2]|0)>>>0)){F=E;return F|0}c[C>>2]=s;c[C+4>>2]=m;m=i+124|0;c[m>>2]=c[f>>2];a[m]=a[100553+(n<<1)|0]|0;a[i+124+t|0]=a[3057200+(q<<7)+o|0]|0;o=j+120|0;j=i+120|0;c[j>>2]=c[o>>2];c[k+(E<<2)>>2]=(c[o>>2]|0)+(b<<16);c[j>>2]=E;F=E+1|0;return F|0}function TUb(a,b){a=a|0;b=b|0;var c=0,e=0;c=d[a+19352+b|0]|0;if((c|0)==3){UUb(a,0,b<<2,2);return}else if((c|0)==1){e=b<<2;UUb(a,0,e,2);UUb(a,0,e|2,2);return}else if((c|0)==0){e=b<<2;UUb(a,0,e,1);UUb(a,0,e|1,1);UUb(a,0,e|2,1);UUb(a,0,e|3,1);return}else if((c|0)==2){c=b<<2;UUb(a,0,c,1);UUb(a,0,c|1,1);return}else{return}}function UUb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;i=i+8|0;j=h|0;k=j|0;dQb(a,e,f,g,k);g=d[19112+f|0]|0;f=(b[a+28192+(e*160|0)+(g<<2)>>1]|0)-(b[k>>1]|0)<<1;k=1-f|0;l=(k|0)<0?f:k;if((l|0)<256){m=d[16464+l|0]|0}else{m=(d[16464+(l>>8)|0]|0)+16|0}l=a+1520|0;k=(c[l>>2]|0)+m|0;c[l>>2]=k;m=(b[a+28192+(e*160|0)+(g<<2)+2>>1]|0)-(b[j+2>>1]|0)<<1;j=1-m|0;g=(j|0)<0?m:j;if((g|0)<256){n=d[16464+g|0]|0;o=k+n|0;c[l>>2]=o;i=h;return}else{n=(d[16464+(g>>8)|0]|0)+16|0;o=k+n|0;c[l>>2]=o;i=h;return}}function VUb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=d[a+19352+e|0]|0;if((f|0)==1){g=e<<2;h=WUb(a,b,0,g,2)|0;re[c[25119]&1023](a+28512+((d[1901576+g|0]|0)+12+((d[1901368+g|0]|0)<<3)<<1)|0,h&65535);h=g|2;g=WUb(a,b,0,h,2)|0;re[c[25119]&1023](a+28512+((d[1901576+h|0]|0)+12+((d[1901368+h|0]|0)<<3)<<1)|0,g&65535);return}else if((f|0)==3){g=e<<2;h=WUb(a,b,0,g,2)|0;re[c[25121]&1023](a+28512+((d[1901576+g|0]|0)+12+((d[1901368+g|0]|0)<<3)<<1)|0,h&65535);return}else if((f|0)==0){h=e<<2;g=WUb(a,b,0,h,1)|0;re[c[25118]&1023](a+28512+((d[1901576+h|0]|0)+12+((d[1901368+h|0]|0)<<3)<<1)|0,g&65535);g=h|1;i=WUb(a,b,0,g,1)|0;re[c[25118]&1023](a+28512+((d[1901576+g|0]|0)+12+((d[1901368+g|0]|0)<<3)<<1)|0,i&65535);i=h|2;g=WUb(a,b,0,i,1)|0;re[c[25118]&1023](a+28512+((d[1901576+i|0]|0)+12+((d[1901368+i|0]|0)<<3)<<1)|0,g&65535);g=h|3;h=WUb(a,b,0,g,1)|0;re[c[25118]&1023](a+28512+((d[1901576+g|0]|0)+12+((d[1901368+g|0]|0)<<3)<<1)|0,h&65535);return}else if((f|0)==2){f=e<<2;e=WUb(a,b,0,f,1)|0;re[c[25120]&1023](a+28512+((d[1901576+f|0]|0)+12+((d[1901368+f|0]|0)<<3)<<1)|0,e&65535);e=f|1;f=WUb(a,b,0,e,1)|0;re[c[25120]&1023](a+28512+((d[1901576+e|0]|0)+12+((d[1901368+e|0]|0)<<3)<<1)|0,f&65535);return}else{Cd(2394224,2373984,377,2649632)}}function WUb(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;l=i;i=i+8|0;m=l|0;n=m|0;dQb(f,h,j,k,n);k=d[19112+j|0]|0;j=b[f+28192+(h*160|0)+(k<<2)>>1]|0;o=b[n>>1]|0;n=(j<<16>>16)-(o<<16>>16)|0;p=b[f+28192+(h*160|0)+(k<<2)+2>>1]|0;q=b[m+2>>1]|0;m=(p<<16>>16)-(q<<16>>16)|0;r=k-1|0;s=k-8|0;k=(d[f+28512+(h*80|0)+(s<<1)|0]|0)+(d[f+28512+(h*80|0)+(r<<1)|0]|0)|0;t=(d[f+28512+(h*80|0)+(s<<1)+1|0]|0)+(d[f+28512+(h*80|0)+(r<<1)+1|0]|0)|0;r=(((k|0)>2)+((k|0)>32)&65535)+((((t|0)>2)+((t|0)>32)&65535)<<8)&65535;t=r&255;if(j<<16>>16==o<<16>>16){o=t+40+(g+36)|0;j=d[o]|0;a[o]=a[100552+(j<<1)|0]|0;o=g+32|0;c[o>>2]=(c[o>>2]|0)+(e[101200+(j<<1)>>1]|0);u=0}else{j=(n|0)>-1?n:-n|0;n=t+40+(g+36)|0;t=d[n]|0;a[n]=a[100553+(t<<1)|0]|0;n=g+32|0;o=(c[n>>2]|0)+(e[101200+((t^1)<<1)>>1]|0)|0;c[n>>2]=o;do{if((j|0)<4){if((j|0)>1){t=1;do{k=t+42+(g+36)|0;h=d[k]|0;a[k]=a[100553+(h<<1)|0]|0;c[n>>2]=(c[n>>2]|0)+(e[101200+((h^1)<<1)>>1]|0);t=t+1|0;}while((t|0)<(j|0))}t=j+42+(g+36)|0;h=d[t]|0;a[t]=a[100552+(h<<1)|0]|0;c[n>>2]=(e[101200+(h<<1)>>1]|0)+256+(c[n>>2]|0)}else{h=g+79|0;t=d[h]|0;a[h]=a[100553+(t<<1)|0]|0;h=o+(e[101200+((t^1)<<1)>>1]|0)|0;t=g+80|0;k=d[t]|0;a[t]=a[100553+(k<<1)|0]|0;t=h+(e[101200+((k^1)<<1)>>1]|0)|0;k=g+81|0;h=d[k]|0;a[k]=a[100553+(h<<1)|0]|0;k=t+(e[101200+((h^1)<<1)>>1]|0)|0;c[n>>2]=k;h=g+82|0;t=d[h]|0;if((j|0)<9){f=j-3|0;c[n>>2]=(e[3059120+(f<<8)+(t<<1)>>1]|0)+k;a[h]=a[3057200+(f<<7)+t|0]|0;break}f=(e[9881216+(t<<1)>>1]|0)+k|0;c[n>>2]=f;a[h]=a[9881088+t|0]|0;t=j-1|0;if((j-2|0)>>>0<255>>>0){v=d[16464+t|0]|0}else{v=(d[16464+(t>>>8)|0]|0)+16|0}c[n>>2]=(v<<8)-768+f}}while(0);u=(j|0)<66?j:66}j=r>>>8;if(p<<16>>16==q<<16>>16){q=j+47+(g+36)|0;p=d[q]|0;a[q]=a[100552+(p<<1)|0]|0;q=g+32|0;c[q>>2]=(c[q>>2]|0)+(e[101200+(p<<1)>>1]|0);w=0;x=w+u|0;y=x&65535;i=l;return y|0}p=(m|0)>-1?m:-m|0;m=j+47+(g+36)|0;j=d[m]|0;a[m]=a[100553+(j<<1)|0]|0;m=g+32|0;q=(c[m>>2]|0)+(e[101200+((j^1)<<1)>>1]|0)|0;c[m>>2]=q;do{if((p|0)<4){if((p|0)>1){j=1;do{r=j+49+(g+36)|0;v=d[r]|0;a[r]=a[100553+(v<<1)|0]|0;c[m>>2]=(c[m>>2]|0)+(e[101200+((v^1)<<1)>>1]|0);j=j+1|0;}while((j|0)<(p|0))}j=p+49+(g+36)|0;v=d[j]|0;a[j]=a[100552+(v<<1)|0]|0;c[m>>2]=(e[101200+(v<<1)>>1]|0)+256+(c[m>>2]|0)}else{v=g+86|0;j=d[v]|0;a[v]=a[100553+(j<<1)|0]|0;v=q+(e[101200+((j^1)<<1)>>1]|0)|0;j=g+87|0;r=d[j]|0;a[j]=a[100553+(r<<1)|0]|0;j=v+(e[101200+((r^1)<<1)>>1]|0)|0;r=g+88|0;v=d[r]|0;a[r]=a[100553+(v<<1)|0]|0;r=j+(e[101200+((v^1)<<1)>>1]|0)|0;c[m>>2]=r;v=g+89|0;j=d[v]|0;if((p|0)<9){n=p-3|0;c[m>>2]=(e[3059120+(n<<8)+(j<<1)>>1]|0)+r;a[v]=a[3057200+(n<<7)+j|0]|0;break}n=(e[9881216+(j<<1)>>1]|0)+r|0;c[m>>2]=n;a[v]=a[9881088+j|0]|0;j=p-1|0;if((p-2|0)>>>0<255>>>0){z=d[16464+j|0]|0}else{z=(d[16464+(j>>>8)|0]|0)+16|0}c[m>>2]=(z<<8)-768+n}}while(0);w=(p|0)<66?p<<8:16896;x=w+u|0;y=x&65535;i=l;return y|0}function XUb(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0;h=f+8632|0;i=f+19344|0;j=c[i>>2]|0;k=c[f+3240>>2]|0;if((c[h>>2]|0)==3){a:do{if((k|0)==1){l=c[f+18784>>2]|0;do{if((l&1|0)==0){m=0}else{n=c[f+18880>>2]|0;if((n|0)==18|(n|0)==7){m=0;break}m=1}}while(0);do{if((l&2|0)==0){o=m}else{n=c[f+18876>>2]|0;if((n|0)==18|(n|0)==7){o=m;break}o=m+1|0}}while(0);l=d[o+27+(g+36)|0]|0;if((j|0)==7){n=g+32|0;c[n>>2]=(c[n>>2]|0)+(e[101200+(l<<1)>>1]|0);p=134;break}n=g+32|0;q=(c[n>>2]|0)+(e[101200+((l^1)<<1)>>1]|0)|0;c[n>>2]=q;if((j|0)!=17){if(!((j-8|0)>>>0<9>>>0)){l=g+68|0;r=d[l]|0;s=d[100553+(r<<1)|0]|0;t=(e[101200+((d[g+66|0]^1)<<1)>>1]|0)+q+(e[101200+((d[g+67|0]^1)<<1)>>1]|0)+(e[101200+((r^1)<<1)>>1]|0)+(e[101200+(s<<1)>>1]|0)|0;r=d[100552+(s<<1)|0]|0;a[l]=a[100553+(r<<1)|0]|0;c[n>>2]=t+(e[101200+((r^1)<<1)>>1]|0);ZUb(f,g,j,32,33,34,34,35,35);if((j|0)==3){p=134;break}else if((j|0)==2){u=1;break}r=f+19356|0;if((c[f+8696>>2]|0)!=0){c[n>>2]=(c[n>>2]|0)+(e[101200+((d[(c[f+28760>>2]|0)+399+(g+36)|0]^c[r>>2])<<1)>>1]|0)}t=(c[r>>2]|0)!=0?4:1;r=g+104|0;l=g+105|0;s=0;v=a[r]|0;while(1){w=d[19112+s|0]|0;x=a[(a[w-1+(f+27936)|0]|0)+95137|0]|0;y=a[(a[w-8+(f+27936)|0]|0)+95137|0]|0;z=x<<24>>24<y<<24>>24?x:y;y=z<<24>>24<0?2:z<<24>>24;z=a[(a[f+27936+w|0]|0)+95137|0]|0;w=v&255;if((y|0)==(z|0)){x=a[100553+(w<<1)|0]|0;a[r]=x;A=x;B=(c[n>>2]|0)+(e[101200+((w^1)<<1)>>1]|0)|0}else{x=a[100552+(w<<1)|0]|0;a[r]=x;C=(((z|0)>(y|0))<<31>>31)+z|0;z=C&1;y=d[l]|0;D=C>>>1&1;E=d[100552+(y<<1)+z|0]|0;F=(c[n>>2]|0)+(e[101200+(w<<1)>>1]|0)+(e[101200+((y^z)<<1)>>1]|0)+(e[101200+((E^D)<<1)>>1]|0)|0;z=C>>2;C=d[100552+(E<<1)+D|0]|0;a[l]=a[100552+(C<<1)+z|0]|0;A=x;B=F+(e[101200+((C^z)<<1)>>1]|0)|0}c[n>>2]=B;z=s+t|0;if((z|0)<16){s=z;v=A}else{p=133;break a}}}v=f+19348|0;s=d[101168+((j*3|0)-38+(c[v>>2]|0))|0]|0;t=s&1;c[n>>2]=(e[101200+((d[g+66|0]^t)<<1)>>1]|0)+q;l=s>>>1&1;r=32-t+(g+36)|0;t=d[r]|0;a[r]=a[100552+(t<<1)+l|0]|0;r=(c[n>>2]|0)+(e[101200+((t^l)<<1)>>1]|0)|0;c[n>>2]=r;l=s>>>2;do{if((l|0)!=1){t=l&1;z=g+68|0;C=d[z]|0;F=s>>>3&1;x=d[100552+(C<<1)+t|0]|0;D=(e[101200+((C^t)<<1)>>1]|0)+r+(e[101200+((x^F)<<1)>>1]|0)|0;t=s>>>4&1;C=d[100552+(x<<1)+F|0]|0;F=a[100552+(C<<1)+t|0]|0;a[z]=F;z=D+(e[101200+((C^t)<<1)>>1]|0)|0;c[n>>2]=z;t=s>>>5;if((t|0)==1){break}c[n>>2]=(e[101200+((F&255^t&1)<<1)>>1]|0)+z}}while(0);do{if((c[f+24580>>2]|0)>1){if((407727>>>(j>>>0)&1|0)==0){_Ub(f,g,0,0)}if((93520>>>(j>>>0)&1|0)==0){break}s=c[v>>2]|0;if((s|0)==16){break}_Ub(f,g,0,8>>>(((s|0)==15|0)>>>0))}}while(0);do{if((c[f+24584>>2]|0)>1){if(!((j-11|0)>>>0>5>>>0)){_Ub(f,g,1,0)}if((112128>>>(j>>>0)&1|0)==0){G=0;p=78;break}s=c[v>>2]|0;if((s|0)==16){H=0;p=79;break}_Ub(f,g,1,8>>>(((s|0)==15|0)>>>0));G=0;p=78}else{G=0;p=78}}while(0);b:while(1){do{if((p|0)==78){p=0;s=c[v>>2]|0;if((s|0)==16){H=G;p=79;continue b}r=(a[94920+(j<<2)+(G<<1)|0]|0)!=0;if((s|0)==14){if(r){s=WUb(f,g,G,0,4)|0;re[c[25123]&1023](f+28512+(G*80|0)+24|0,s&65535)}if((a[94920+(j<<2)+(G<<1)+1|0]|0)==0){I=G;break}s=WUb(f,g,G,8,4)|0;re[c[25123]&1023](f+28512+(G*80|0)+56|0,s&65535);I=G;break}else{if(r){r=WUb(f,g,G,0,2)|0;re[c[25125]&1023](f+28512+(G*80|0)+24|0,r&65535)}if((a[94920+(j<<2)+(G<<1)+1|0]|0)==0){I=G;break}r=WUb(f,g,G,4,2)|0;re[c[25125]&1023](f+28512+(G*80|0)+28|0,r&65535);I=G;break}}else if((p|0)==79){p=0;if((a[94920+(j<<2)+(H<<1)|0]|0)==0){I=H;break}r=WUb(f,g,H,0,4)|0;re[c[25127]&1023](f+28512+(H*80|0)+24|0,r&65535);I=H}}while(0);r=I+1|0;if((r|0)<2){G=r;p=78}else{p=133;break a}}}v=g+68|0;r=d[v]|0;s=(e[101200+((d[g+66|0]^1)<<1)>>1]|0)+q+(e[101200+((d[g+67|0]^1)<<1)>>1]|0)+(e[101200+((r^1)<<1)>>1]|0)|0;l=d[100553+(r<<1)|0]|0;r=a[100553+(l<<1)|0]|0;a[v]=r;v=s+(e[101200+((l^1)<<1)>>1]|0)+(e[101200+((r&255^1)<<1)>>1]|0)|0;c[n>>2]=v;r=g+72|0;l=g+73|0;s=g+74|0;z=g+75|0;t=0;F=a[r]|0;C=v;while(1){v=a[f+19352+t|0]|0;D=F&255;do{if(v<<24>>24==12){x=a[100552+(D<<1)|0]|0;a[r]=x;E=(e[101200+(D<<1)>>1]|0)+C|0;c[n>>2]=E;J=x;K=E}else{E=a[100553+(D<<1)|0]|0;a[r]=E;x=(e[101200+((D^1)<<1)>>1]|0)+C|0;c[n>>2]=x;y=d[l]|0;if(v<<24>>24==11){a[l]=a[100553+(y<<1)|0]|0;w=(e[101200+((y^1)<<1)>>1]|0)+x|0;L=d[s]|0;a[s]=a[100552+(L<<1)|0]|0;M=d[z]|0;N=w+(e[101200+(L<<1)>>1]|0)+(e[101200+(M<<1)>>1]|0)|0;L=d[100552+(M<<1)|0]|0;a[z]=a[100552+(L<<1)|0]|0;M=N+(e[101200+(L<<1)>>1]|0)|0;c[n>>2]=M;J=E;K=M;break}else{a[l]=a[100552+(y<<1)|0]|0;M=(e[101200+(y<<1)>>1]|0)+x|0;x=v<<24>>24==7|0;y=d[z]|0;a[z]=a[100552+(y<<1)+x|0]|0;L=M+(e[101200+((y^x)<<1)>>1]|0)|0;c[n>>2]=L;J=E;K=L;break}}}while(0);v=t+1|0;if((v|0)<4){t=v;F=J;C=K}else{break}}C=f+19352|0;do{if((c[f+24580>>2]|0)>1){if((a[95296+(d[C]|0)|0]|0)!=0){_Ub(f,g,0,0)}if((a[95296+(d[f+19353|0]|0)|0]|0)!=0){_Ub(f,g,0,4)}if((a[95296+(d[f+19354|0]|0)|0]|0)!=0){_Ub(f,g,0,8)}if((a[95296+(d[f+19355|0]|0)|0]|0)==0){break}_Ub(f,g,0,12)}}while(0);do{if((c[f+24584>>2]|0)>1){if((a[95313+(d[C]|0)|0]|0)!=0){_Ub(f,g,1,0)}if((a[95313+(d[f+19353|0]|0)|0]|0)!=0){_Ub(f,g,1,4)}if((a[95313+(d[f+19354|0]|0)|0]|0)!=0){_Ub(f,g,1,8)}if((a[95313+(d[f+19355|0]|0)|0]|0)==0){break}_Ub(f,g,1,12)}}while(0);if((a[95296+(d[C]|0)|0]|0)!=0){F=WUb(f,g,0,0,2)|0;re[c[25121]&1023](f+28536|0,F&65535)}F=f+19353|0;if((a[95296+(d[F]|0)|0]|0)!=0){t=WUb(f,g,0,4,2)|0;re[c[25121]&1023](f+28540|0,t&65535)}t=f+19354|0;if((a[95296+(d[t]|0)|0]|0)!=0){n=WUb(f,g,0,8,2)|0;re[c[25121]&1023](f+28568|0,n&65535)}n=f+19355|0;if((a[95296+(d[n]|0)|0]|0)!=0){z=WUb(f,g,0,12,2)|0;re[c[25121]&1023](f+28572|0,z&65535)}if((a[95313+(d[C]|0)|0]|0)!=0){z=WUb(f,g,1,0,2)|0;re[c[25121]&1023](f+28616|0,z&65535)}if((a[95313+(d[F]|0)|0]|0)!=0){F=WUb(f,g,1,4,2)|0;re[c[25121]&1023](f+28620|0,F&65535)}if((a[95313+(d[t]|0)|0]|0)!=0){t=WUb(f,g,1,8,2)|0;re[c[25121]&1023](f+28648|0,t&65535)}if((a[95313+(d[n]|0)|0]|0)==0){p=133;break}n=WUb(f,g,1,12,2)|0;re[c[25121]&1023](f+28652|0,n&65535);p=133}else if((k|0)==0){if((j|0)==4){n=g+32|0;t=(c[n>>2]|0)+(e[101200+(d[g+50|0]<<1)>>1]|0)|0;c[n>>2]=t;F=c[f+19348>>2]|0;if((F|0)==16){c[n>>2]=(e[101200+(d[g+51|0]<<1)>>1]|0)+t+(e[101200+(d[g+52|0]<<1)>>1]|0);if((c[f+24580>>2]|0)>1){$Ub(f,g,0)}z=WUb(f,g,0,0,4)|0;re[c[25127]&1023](f+28536|0,z&65535);p=133;break}z=(e[101200+((d[g+51|0]^1)<<1)>>1]|0)+t|0;c[n>>2]=z;t=d[g+53|0]|0;if((F|0)==14){c[n>>2]=(e[101200+((t^1)<<1)>>1]|0)+z;if((c[f+24580>>2]|0)>1){$Ub(f,g,0);$Ub(f,g,8)}F=WUb(f,g,0,0,4)|0;re[c[25123]&1023](f+28536|0,F&65535);F=WUb(f,g,0,8,4)|0;re[c[25123]&1023](f+28568|0,F&65535);p=133;break}else{c[n>>2]=(e[101200+(t<<1)>>1]|0)+z;if((c[f+24580>>2]|0)>1){$Ub(f,g,0);$Ub(f,g,4)}z=WUb(f,g,0,0,2)|0;re[c[25125]&1023](f+28536|0,z&65535);z=WUb(f,g,0,4,2)|0;re[c[25125]&1023](f+28540|0,z&65535);p=133;break}}else if((j|0)==5){z=g+32|0;t=(c[z>>2]|0)+(e[101200+(d[g+50|0]<<1)>>1]|0)+(e[101200+(d[g+51|0]<<1)>>1]|0)+(e[101200+((d[g+52|0]^1)<<1)>>1]|0)|0;c[z>>2]=t;n=g+57|0;F=g+58|0;l=g+59|0;s=0;r=a[n]|0;q=t;while(1){t=a[f+19352+s|0]|0;v=r&255;do{if(t<<24>>24==3){D=a[100553+(v<<1)|0]|0;a[n]=D;L=(e[101200+((v^1)<<1)>>1]|0)+q|0;c[z>>2]=L;O=D;P=L}else{L=a[100552+(v<<1)|0]|0;a[n]=L;D=(e[101200+(v<<1)>>1]|0)+q|0;c[z>>2]=D;E=d[F]|0;if(t<<24>>24==1){a[F]=a[100552+(E<<1)|0]|0;x=(e[101200+(E<<1)>>1]|0)+D|0;c[z>>2]=x;O=L;P=x;break}else{a[F]=a[100553+(E<<1)|0]|0;x=(e[101200+((E^1)<<1)>>1]|0)+D|0;D=t<<24>>24==2|0;E=d[l]|0;a[l]=a[100552+(E<<1)+D|0]|0;y=x+(e[101200+((E^D)<<1)>>1]|0)|0;c[z>>2]=y;O=L;P=y;break}}}while(0);t=s+1|0;if((t|0)<4){s=t;r=O;q=P}else{break}}if((c[f+24580>>2]|0)>1){$Ub(f,g,0);$Ub(f,g,4);$Ub(f,g,8);$Ub(f,g,12)}VUb(f,g,0);VUb(f,g,1);VUb(f,g,2);VUb(f,g,3);p=133;break}else{q=g+32|0;c[q>>2]=(c[q>>2]|0)+(e[101200+((d[g+50|0]^1)<<1)>>1]|0);ZUb(f,g,j,17,18,19,19,20,20);if((j|0)==3){p=134;break}else if((j|0)==2){u=1;break}r=f+19356|0;if((c[f+8696>>2]|0)!=0){c[q>>2]=(c[q>>2]|0)+(e[101200+((d[(c[f+28760>>2]|0)+399+(g+36)|0]^c[r>>2])<<1)>>1]|0)}s=(c[r>>2]|0)!=0?4:1;r=g+104|0;z=g+105|0;l=0;F=a[r]|0;while(1){n=d[19112+l|0]|0;C=a[(a[n-1+(f+27936)|0]|0)+95137|0]|0;t=a[(a[n-8+(f+27936)|0]|0)+95137|0]|0;v=C<<24>>24<t<<24>>24?C:t;t=v<<24>>24<0?2:v<<24>>24;v=a[(a[f+27936+n|0]|0)+95137|0]|0;n=F&255;if((t|0)==(v|0)){C=a[100553+(n<<1)|0]|0;a[r]=C;Q=C;R=(c[q>>2]|0)+(e[101200+((n^1)<<1)>>1]|0)|0}else{C=a[100552+(n<<1)|0]|0;a[r]=C;y=(((v|0)>(t|0))<<31>>31)+v|0;v=y&1;t=d[z]|0;L=y>>>1&1;D=d[100552+(t<<1)+v|0]|0;E=(c[q>>2]|0)+(e[101200+(n<<1)>>1]|0)+(e[101200+((t^v)<<1)>>1]|0)+(e[101200+((D^L)<<1)>>1]|0)|0;v=y>>2;y=d[100552+(D<<1)+L|0]|0;a[z]=a[100552+(y<<1)+v|0]|0;Q=C;R=E+(e[101200+((y^v)<<1)>>1]|0)|0}c[q>>2]=R;v=l+s|0;if((v|0)<16){l=v;F=Q}else{p=133;break}}}}else{F=c[f+18784>>2]|0;if((F&1|0)==0){S=0}else{S=(c[f+18880>>2]|0)!=0|0}if((F&2|0)==0){T=S}else{T=((c[f+18876>>2]|0)!=0)+S|0}ZUb(f,g,j,T+3|0,6,7,8,9,10);if((j|0)==3){p=134;break}else if((j|0)==2){u=1;break}F=f+19356|0;if((c[f+8696>>2]|0)==0){U=g+32|0}else{l=g+32|0;c[l>>2]=(c[l>>2]|0)+(e[101200+((d[(c[f+28760>>2]|0)+399+(g+36)|0]^c[F>>2])<<1)>>1]|0);U=l}l=(c[F>>2]|0)!=0?4:1;F=g+104|0;s=g+105|0;q=0;z=a[F]|0;while(1){r=d[19112+q|0]|0;v=a[(a[r-1+(f+27936)|0]|0)+95137|0]|0;y=a[(a[r-8+(f+27936)|0]|0)+95137|0]|0;E=v<<24>>24<y<<24>>24?v:y;y=E<<24>>24<0?2:E<<24>>24;E=a[(a[f+27936+r|0]|0)+95137|0]|0;r=z&255;if((y|0)==(E|0)){v=a[100553+(r<<1)|0]|0;a[F]=v;V=v;W=(c[U>>2]|0)+(e[101200+((r^1)<<1)>>1]|0)|0}else{v=a[100552+(r<<1)|0]|0;a[F]=v;C=(((E|0)>(y|0))<<31>>31)+E|0;E=C&1;y=d[s]|0;L=C>>>1&1;D=d[100552+(y<<1)+E|0]|0;t=(c[U>>2]|0)+(e[101200+(r<<1)>>1]|0)+(e[101200+((y^E)<<1)>>1]|0)+(e[101200+((D^L)<<1)>>1]|0)|0;E=C>>2;C=d[100552+(D<<1)+L|0]|0;a[s]=a[100552+(C<<1)+E|0]|0;V=v;W=t+(e[101200+((C^E)<<1)>>1]|0)|0}c[U>>2]=W;E=q+l|0;if((E|0)<16){q=E;z=V}else{p=133;break}}}}while(0);if((p|0)==133){if((j|0)==2){u=1}else{p=134}}if((p|0)==134){V=c[f+19360>>2]|0;W=c[f+28768>>2]|0;U=c[f+28772>>2]|0;T=V&1;S=76-(W>>>1&2)-(U>>>1&1)+(g+36)|0;Q=d[S]|0;a[S]=a[100552+(Q<<1)+T|0]|0;S=g+32|0;c[S>>2]=(c[S>>2]|0)+(e[101200+((Q^T)<<1)>>1]|0);Q=V>>>1&1;R=76-T-(W>>>2&2)+(g+36)|0;W=d[R]|0;a[R]=a[100552+(W<<1)+Q|0]|0;c[S>>2]=(c[S>>2]|0)+(e[101200+((W^Q)<<1)>>1]|0);Q=V>>>2&1;W=76-(V<<1&2)-(U>>>3&1)+(g+36)|0;U=d[W]|0;a[W]=a[100552+(U<<1)+Q|0]|0;W=(c[S>>2]|0)+(e[101200+((U^Q)<<1)>>1]|0)|0;c[S>>2]=W;c[S>>2]=(e[101200+((d[76-(V&2)-Q+(g+36)|0]^V>>>3&1)<<1)>>1]|0)+W;u=0}do{if((c[f+8696>>2]|0)!=0){W=c[i>>2]|0;if((W|0)==5){X=(c[f+19352>>2]|0)==50529027|0}else{X=d[17936+W|0]|0}if((X|0)==0){break}if((c[f+19360>>2]|0)==0){break}W=g+32|0;c[W>>2]=(c[W>>2]|0)+(e[101200+((d[(c[f+28760>>2]|0)+399+(g+36)|0]^c[f+19356>>2])<<1)>>1]|0)}}while(0);X=f+19360|0;if(!((c[X>>2]|0)!=0|u)){return}if(j>>>0<3>>>0){Y=255}else{Y=((j|0)==3)<<7|127}W=c[f+28816>>2]|0;V=c[f+28824>>2]|0;Q=W-V|0;if((c[i>>2]|0)==2){Z=(b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]|0)==0&(W|0)>(V|0)?0:Q}else{Z=Q}do{if((c[f+28828>>2]|0)==0){_=0}else{Q=c[f+18896>>2]|0;if((a[(c[f+18956>>2]|0)+Q|0]|0)==2){_=1;break}_=(b[(c[f+18968>>2]|0)+(Q<<1)>>1]&63)!=0|0}}while(0);if((Z|0)==0){$=_;aa=c[g+32>>2]|0}else{Q=Z<<1;Z=1-Q|0;V=(Z|0)<0?Q:Z;Z=V-1|0;Q=g+32|0;W=(Z|0)>50&(Z|0)!=52?104-V|0:Z;Z=_;while(1){_=Z+60+(g+36)|0;V=d[_]|0;a[_]=a[100553+(V<<1)|0]|0;_=(c[Q>>2]|0)+(e[101200+((V^1)<<1)>>1]|0)|0;c[Q>>2]=_;V=(Z>>1)+2|0;S=W-1|0;if((S|0)==0){$=V;aa=_;break}else{W=S;Z=V}}}Z=g+32|0;c[Z>>2]=(e[101200+(d[$+60+(g+36)|0]<<1)>>1]|0)+aa;if(u){u=f+28772|0;aa=f+28768|0;$=0;do{W=a[1625008+$|0]|0;Q=$+48|0;V=c[u>>2]|0;if(W<<24>>24==3){if((V|0)==-1){ba=1}else{ba=V>>>(($+8|0)>>>0)&1}S=c[aa>>2]|0;if((S|0)==-1){ca=2}else{ca=S>>>(($+8|0)>>>0)<<1&2}da=(ca|ba)+97|0}else{S=$+8|0;da=(e[109680+((W&255)<<1)>>1]|0)+(V>>>(S>>>0)&1)+((c[aa>>2]|0)>>>(S>>>0)<<1&2)|0}S=g+36+da|0;V=d[S]|0;if((a[(d[19112+Q|0]|0)+(f+27984)|0]|0)==0){a[S]=a[100552+(V<<1)|0]|0;c[Z>>2]=(c[Z>>2]|0)+(e[101200+(V<<1)>>1]|0)}else{a[S]=a[100553+(V<<1)|0]|0;c[Z>>2]=(c[Z>>2]|0)+(e[101200+((V^1)<<1)>>1]|0);TTb(f,g,W&255,f+15360+($<<5)|0)}if((c[X>>2]|0)!=0){W=$<<4;V=W+16|0;S=d[1625011+$|0]|0;Q=e[109680+(S<<1)>>1]|0;_=W;do{W=d[19112+_|0]|0;U=((a[W-1+(f+27984)|0]|0)!=0)+Q+(((a[W-8+(f+27984)|0]|0)!=0)<<1)+(g+36)|0;R=d[U]|0;if((a[f+27984+W|0]|0)==0){a[U]=a[100552+(R<<1)|0]|0;c[Z>>2]=(c[Z>>2]|0)+(e[101200+(R<<1)>>1]|0)}else{a[U]=a[100553+(R<<1)|0]|0;c[Z>>2]=(c[Z>>2]|0)+(e[101200+((R^1)<<1)>>1]|0);TTb(f,g,S,f+17024+(_<<5)+2|0)}_=_+1|0;}while((_|0)<(V|0))}$=$+1|0;}while(($|0)<3);return}if((c[f+19356>>2]|0)==0){$=0;do{da=c[X>>2]|0;if((da|0)!=0){aa=d[1625014+$|0]|0;ba=$<<4;ca=e[109680+(aa<<1)>>1]|0;u=0;V=da;while(1){da=d[98840+V|0]|0;_=da+u|0;S=(_<<2)+ba|0;Q=0;do{R=S+Q|0;U=d[19112+R|0]|0;W=((d[U-1+(f+27984)|0]&Y|0)!=0)+ca+(((d[U-8+(f+27984)|0]&Y|0)!=0)<<1)+(g+36)|0;T=d[W]|0;if((a[f+27984+U|0]|0)==0){a[W]=a[100552+(T<<1)|0]|0;c[Z>>2]=(c[Z>>2]|0)+(e[101200+(T<<1)>>1]|0)}else{a[W]=a[100553+(T<<1)|0]|0;c[Z>>2]=(c[Z>>2]|0)+(e[101200+((T^1)<<1)>>1]|0);TTb(f,g,aa,f+17024+(R<<5)|0)}Q=Q+1|0;}while((Q|0)<4);Q=V>>da+1;if((Q|0)==0){break}else{u=_+1|0;V=Q}}}$=$+1|0;}while(($|0)<3);return}$=f+18784|0;V=c[$>>2]|0;do{if((V&1|0)==0){ea=0;fa=0;ga=0;ha=0;ia=0;ja=0;ka=0;la=0;ma=0;na=0;oa=0;pa=0}else{u=c[f+19268>>2]|0;if((a[u+(c[f+18900>>2]|0)|0]|0)==0){aa=f+27995|0;ca=a[aa]|0;a[aa]=-128;aa=f+28003|0;ba=a[aa]|0;a[aa]=-128;aa=f+28035|0;Q=a[aa]|0;a[aa]=-128;aa=f+28043|0;S=a[aa]|0;a[aa]=-128;aa=f+28075|0;R=a[aa]|0;a[aa]=-128;aa=f+28083|0;T=a[aa]|0;a[aa]=-128;qa=T;ra=R;sa=S;ta=ca;ua=ba;va=Q}else{qa=0;ra=0;sa=0;ta=0;ua=0;va=0}if((a[u+(c[f+18904>>2]|0)|0]|0)!=0){ea=0;fa=0;ga=0;ha=0;ia=0;ja=0;ka=va;la=ua;ma=ta;na=sa;oa=ra;pa=qa;break}u=f+28011|0;Q=a[u]|0;a[u]=-128;u=f+28019|0;ba=a[u]|0;a[u]=-128;u=f+28051|0;ca=a[u]|0;a[u]=-128;u=f+28059|0;S=a[u]|0;a[u]=-128;u=f+28091|0;R=a[u]|0;a[u]=-128;u=f+28099|0;T=a[u]|0;a[u]=-128;ea=T;fa=R;ga=S;ha=ca;ia=Q;ja=ba;ka=va;la=ua;ma=ta;na=sa;oa=ra;pa=qa}}while(0);do{if((V&2|0)==0){wa=0;xa=0;ya=0}else{if((a[(c[f+19268>>2]|0)+(c[f+18908>>2]|0)|0]|0)!=0){wa=0;xa=0;ya=0;break}qa=f+27988|0;ra=c[qa>>2]|0;c[qa>>2]=-2139062144;qa=f+28028|0;sa=c[qa>>2]|0;c[qa>>2]=-2139062144;qa=f+28068|0;ta=c[qa>>2]|0;c[qa>>2]=-2139062144;wa=ta;xa=sa;ya=ra}}while(0);V=0;do{ra=c[X>>2]|0;if((ra|0)!=0){sa=d[1625023+V|0]|0;ta=V<<4;qa=e[109680+(sa<<1)>>1]|0;ua=V<<2;va=0;ba=ra;while(1){ra=d[98840+ba|0]|0;Q=ra+va|0;ca=ba>>ra+1;ra=d[19112+((Q<<2)+ta)|0]|0;S=((d[ra-1+(f+27984)|0]&Y|0)!=0)+qa+(((d[ra-8+(f+27984)|0]&Y|0)!=0)<<1)+(g+36)|0;R=d[S]|0;if((a[f+27984+ra|0]|0)==0){a[S]=a[100552+(R<<1)|0]|0;c[Z>>2]=(c[Z>>2]|0)+(e[101200+(R<<1)>>1]|0)}else{a[S]=a[100553+(R<<1)|0]|0;c[Z>>2]=(c[Z>>2]|0)+(e[101200+((R^1)<<1)>>1]|0);STb(f,g,sa,f+15488+(Q+ua<<7)|0)}if((ca|0)==0){break}else{va=Q+1|0;ba=ca}}}V=V+1|0;}while((V|0)<3);V=c[$>>2]|0;do{if((V&1|0)!=0){$=c[f+19268>>2]|0;if((a[$+(c[f+18900>>2]|0)|0]|0)==0){a[f+27995|0]=ma;a[f+28003|0]=la;a[f+28035|0]=ka;a[f+28043|0]=na;a[f+28075|0]=oa;a[f+28083|0]=pa}if((a[$+(c[f+18904>>2]|0)|0]|0)!=0){break}a[f+28011|0]=ia;a[f+28019|0]=ja;a[f+28051|0]=ha;a[f+28059|0]=ga;a[f+28091|0]=fa;a[f+28099|0]=ea}}while(0);if((V&2|0)==0){return}if((a[(c[f+19268>>2]|0)+(c[f+18908>>2]|0)|0]|0)!=0){return}c[f+27988>>2]=ya;c[f+28028>>2]=xa;c[f+28068>>2]=wa;return}c:do{if((k|0)==0){if((j|0)==4){wa=g+32|0;xa=(c[wa>>2]|0)+(e[101200+(d[g+50|0]<<1)>>1]|0)|0;c[wa>>2]=xa;ya=c[f+19348>>2]|0;if((ya|0)==16){c[wa>>2]=(e[101200+(d[g+51|0]<<1)>>1]|0)+xa+(e[101200+(d[g+52|0]<<1)>>1]|0);if((c[f+24580>>2]|0)>1){$Ub(f,g,0)}V=WUb(f,g,0,0,4)|0;re[c[25127]&1023](f+28536|0,V&65535);p=341;break}V=(e[101200+((d[g+51|0]^1)<<1)>>1]|0)+xa|0;c[wa>>2]=V;xa=d[g+53|0]|0;if((ya|0)==14){c[wa>>2]=(e[101200+((xa^1)<<1)>>1]|0)+V;if((c[f+24580>>2]|0)>1){$Ub(f,g,0);$Ub(f,g,8)}ya=WUb(f,g,0,0,4)|0;re[c[25123]&1023](f+28536|0,ya&65535);ya=WUb(f,g,0,8,4)|0;re[c[25123]&1023](f+28568|0,ya&65535);p=341;break}else{c[wa>>2]=(e[101200+(xa<<1)>>1]|0)+V;if((c[f+24580>>2]|0)>1){$Ub(f,g,0);$Ub(f,g,4)}V=WUb(f,g,0,0,2)|0;re[c[25125]&1023](f+28536|0,V&65535);V=WUb(f,g,0,4,2)|0;re[c[25125]&1023](f+28540|0,V&65535);p=341;break}}else if((j|0)==5){V=g+32|0;xa=(c[V>>2]|0)+(e[101200+(d[g+50|0]<<1)>>1]|0)+(e[101200+(d[g+51|0]<<1)>>1]|0)+(e[101200+((d[g+52|0]^1)<<1)>>1]|0)|0;c[V>>2]=xa;wa=g+57|0;ya=g+58|0;ea=g+59|0;fa=0;ga=a[wa]|0;ha=xa;while(1){xa=a[f+19352+fa|0]|0;ja=ga&255;do{if(xa<<24>>24==3){ia=a[100553+(ja<<1)|0]|0;a[wa]=ia;pa=(e[101200+((ja^1)<<1)>>1]|0)+ha|0;c[V>>2]=pa;za=ia;Aa=pa}else{pa=a[100552+(ja<<1)|0]|0;a[wa]=pa;ia=(e[101200+(ja<<1)>>1]|0)+ha|0;c[V>>2]=ia;oa=d[ya]|0;if(xa<<24>>24==1){a[ya]=a[100552+(oa<<1)|0]|0;na=(e[101200+(oa<<1)>>1]|0)+ia|0;c[V>>2]=na;za=pa;Aa=na;break}else{a[ya]=a[100553+(oa<<1)|0]|0;na=(e[101200+((oa^1)<<1)>>1]|0)+ia|0;ia=xa<<24>>24==2|0;oa=d[ea]|0;a[ea]=a[100552+(oa<<1)+ia|0]|0;ka=na+(e[101200+((oa^ia)<<1)>>1]|0)|0;c[V>>2]=ka;za=pa;Aa=ka;break}}}while(0);xa=fa+1|0;if((xa|0)<4){fa=xa;ga=za;ha=Aa}else{break}}if((c[f+24580>>2]|0)>1){$Ub(f,g,0);$Ub(f,g,4);$Ub(f,g,8);$Ub(f,g,12)}VUb(f,g,0);VUb(f,g,1);VUb(f,g,2);VUb(f,g,3);p=341;break}else{ha=g+32|0;c[ha>>2]=(c[ha>>2]|0)+(e[101200+((d[g+50|0]^1)<<1)>>1]|0);ZUb(f,g,j,17,18,19,19,20,20);if((j|0)==3){p=342;break}else if((j|0)!=2){ga=f+19356|0;if((c[f+8696>>2]|0)!=0){c[ha>>2]=(c[ha>>2]|0)+(e[101200+((d[(c[f+28760>>2]|0)+399+(g+36)|0]^c[ga>>2])<<1)>>1]|0)}fa=(c[ga>>2]|0)!=0?4:1;ga=g+104|0;V=g+105|0;ea=0;ya=a[ga]|0;while(1){wa=d[19112+ea|0]|0;xa=a[(a[wa-1+(f+27936)|0]|0)+95137|0]|0;ja=a[(a[wa-8+(f+27936)|0]|0)+95137|0]|0;_=xa<<24>>24<ja<<24>>24?xa:ja;ja=_<<24>>24<0?2:_<<24>>24;_=a[(a[f+27936+wa|0]|0)+95137|0]|0;wa=ya&255;if((ja|0)==(_|0)){xa=a[100553+(wa<<1)|0]|0;a[ga]=xa;Ba=xa;Ca=(c[ha>>2]|0)+(e[101200+((wa^1)<<1)>>1]|0)|0}else{xa=a[100552+(wa<<1)|0]|0;a[ga]=xa;da=(((_|0)>(ja|0))<<31>>31)+_|0;_=da&1;ja=d[V]|0;ka=da>>>1&1;pa=d[100552+(ja<<1)+_|0]|0;ia=(c[ha>>2]|0)+(e[101200+(wa<<1)>>1]|0)+(e[101200+((ja^_)<<1)>>1]|0)+(e[101200+((pa^ka)<<1)>>1]|0)|0;_=da>>2;da=d[100552+(pa<<1)+ka|0]|0;a[V]=a[100552+(da<<1)+_|0]|0;Ba=xa;Ca=ia+(e[101200+((da^_)<<1)>>1]|0)|0}c[ha>>2]=Ca;_=ea+fa|0;if((_|0)<16){ea=_;ya=Ba}else{break}}}KUb(f,g);p=341;break}}else if((k|0)==1){ya=c[f+18784>>2]|0;do{if((ya&1|0)==0){Da=0}else{ea=c[f+18880>>2]|0;if((ea|0)==18|(ea|0)==7){Da=0;break}Da=1}}while(0);do{if((ya&2|0)==0){Ea=Da}else{ea=c[f+18876>>2]|0;if((ea|0)==18|(ea|0)==7){Ea=Da;break}Ea=Da+1|0}}while(0);ya=d[Ea+27+(g+36)|0]|0;if((j|0)==7){ea=g+32|0;c[ea>>2]=(c[ea>>2]|0)+(e[101200+(ya<<1)>>1]|0);p=342;break}ea=g+32|0;fa=(c[ea>>2]|0)+(e[101200+((ya^1)<<1)>>1]|0)|0;c[ea>>2]=fa;if((j|0)!=17){if(!((j-8|0)>>>0<9>>>0)){ya=g+68|0;ha=d[ya]|0;V=d[100553+(ha<<1)|0]|0;ga=(e[101200+((d[g+66|0]^1)<<1)>>1]|0)+fa+(e[101200+((d[g+67|0]^1)<<1)>>1]|0)+(e[101200+((ha^1)<<1)>>1]|0)+(e[101200+(V<<1)>>1]|0)|0;ha=d[100552+(V<<1)|0]|0;a[ya]=a[100553+(ha<<1)|0]|0;c[ea>>2]=ga+(e[101200+((ha^1)<<1)>>1]|0);ZUb(f,g,j,32,33,34,34,35,35);if((j|0)==3){p=342;break}else if((j|0)!=2){ha=f+19356|0;if((c[f+8696>>2]|0)!=0){c[ea>>2]=(c[ea>>2]|0)+(e[101200+((d[(c[f+28760>>2]|0)+399+(g+36)|0]^c[ha>>2])<<1)>>1]|0)}ga=(c[ha>>2]|0)!=0?4:1;ha=g+104|0;ya=g+105|0;V=0;_=a[ha]|0;while(1){da=d[19112+V|0]|0;ia=a[(a[da-1+(f+27936)|0]|0)+95137|0]|0;xa=a[(a[da-8+(f+27936)|0]|0)+95137|0]|0;ka=ia<<24>>24<xa<<24>>24?ia:xa;xa=ka<<24>>24<0?2:ka<<24>>24;ka=a[(a[f+27936+da|0]|0)+95137|0]|0;da=_&255;if((xa|0)==(ka|0)){ia=a[100553+(da<<1)|0]|0;a[ha]=ia;Fa=ia;Ga=(c[ea>>2]|0)+(e[101200+((da^1)<<1)>>1]|0)|0}else{ia=a[100552+(da<<1)|0]|0;a[ha]=ia;pa=(((ka|0)>(xa|0))<<31>>31)+ka|0;ka=pa&1;xa=d[ya]|0;ja=pa>>>1&1;wa=d[100552+(xa<<1)+ka|0]|0;oa=(c[ea>>2]|0)+(e[101200+(da<<1)>>1]|0)+(e[101200+((xa^ka)<<1)>>1]|0)+(e[101200+((wa^ja)<<1)>>1]|0)|0;ka=pa>>2;pa=d[100552+(wa<<1)+ja|0]|0;a[ya]=a[100552+(pa<<1)+ka|0]|0;Fa=ia;Ga=oa+(e[101200+((pa^ka)<<1)>>1]|0)|0}c[ea>>2]=Ga;ka=V+ga|0;if((ka|0)<16){V=ka;_=Fa}else{break}}}KUb(f,g);p=341;break}_=f+19348|0;V=d[101168+((j*3|0)-38+(c[_>>2]|0))|0]|0;ga=V&1;c[ea>>2]=(e[101200+((d[g+66|0]^ga)<<1)>>1]|0)+fa;ya=V>>>1&1;ha=32-ga+(g+36)|0;ga=d[ha]|0;a[ha]=a[100552+(ga<<1)+ya|0]|0;ha=(c[ea>>2]|0)+(e[101200+((ga^ya)<<1)>>1]|0)|0;c[ea>>2]=ha;ya=V>>>2;do{if((ya|0)!=1){ga=ya&1;ka=g+68|0;pa=d[ka]|0;oa=V>>>3&1;ia=d[100552+(pa<<1)+ga|0]|0;ja=(e[101200+((pa^ga)<<1)>>1]|0)+ha+(e[101200+((ia^oa)<<1)>>1]|0)|0;ga=V>>>4&1;pa=d[100552+(ia<<1)+oa|0]|0;oa=a[100552+(pa<<1)+ga|0]|0;a[ka]=oa;ka=ja+(e[101200+((pa^ga)<<1)>>1]|0)|0;c[ea>>2]=ka;ga=V>>>5;if((ga|0)==1){break}c[ea>>2]=(e[101200+((oa&255^ga&1)<<1)>>1]|0)+ka}}while(0);do{if((c[f+24580>>2]|0)>1){if((407727>>>(j>>>0)&1|0)==0){_Ub(f,g,0,0)}if((93520>>>(j>>>0)&1|0)==0){break}V=c[_>>2]|0;if((V|0)==16){break}_Ub(f,g,0,8>>>(((V|0)==15|0)>>>0))}}while(0);do{if((c[f+24584>>2]|0)>1){if(!((j-11|0)>>>0>5>>>0)){_Ub(f,g,1,0)}if((112128>>>(j>>>0)&1|0)==0){Ha=0;p=284;break}V=c[_>>2]|0;if((V|0)==16){Ia=0;p=285;break}_Ub(f,g,1,8>>>(((V|0)==15|0)>>>0));Ha=0;p=284}else{Ha=0;p=284}}while(0);d:while(1){do{if((p|0)==284){p=0;V=c[_>>2]|0;if((V|0)==16){Ia=Ha;p=285;continue d}ha=(a[94920+(j<<2)+(Ha<<1)|0]|0)!=0;if((V|0)==14){if(ha){V=WUb(f,g,Ha,0,4)|0;re[c[25123]&1023](f+28512+(Ha*80|0)+24|0,V&65535)}if((a[94920+(j<<2)+(Ha<<1)+1|0]|0)==0){Ja=Ha;break}V=WUb(f,g,Ha,8,4)|0;re[c[25123]&1023](f+28512+(Ha*80|0)+56|0,V&65535);Ja=Ha;break}else{if(ha){ha=WUb(f,g,Ha,0,2)|0;re[c[25125]&1023](f+28512+(Ha*80|0)+24|0,ha&65535)}if((a[94920+(j<<2)+(Ha<<1)+1|0]|0)==0){Ja=Ha;break}ha=WUb(f,g,Ha,4,2)|0;re[c[25125]&1023](f+28512+(Ha*80|0)+28|0,ha&65535);Ja=Ha;break}}else if((p|0)==285){p=0;if((a[94920+(j<<2)+(Ia<<1)|0]|0)==0){Ja=Ia;break}ha=WUb(f,g,Ia,0,4)|0;re[c[25127]&1023](f+28512+(Ia*80|0)+24|0,ha&65535);Ja=Ia}}while(0);ha=Ja+1|0;if((ha|0)<2){Ha=ha;p=284}else{p=341;break c}}}_=g+68|0;ha=d[_]|0;V=(e[101200+((d[g+66|0]^1)<<1)>>1]|0)+fa+(e[101200+((d[g+67|0]^1)<<1)>>1]|0)+(e[101200+((ha^1)<<1)>>1]|0)|0;ya=d[100553+(ha<<1)|0]|0;ha=a[100553+(ya<<1)|0]|0;a[_]=ha;_=V+(e[101200+((ya^1)<<1)>>1]|0)+(e[101200+((ha&255^1)<<1)>>1]|0)|0;c[ea>>2]=_;ha=g+72|0;ya=g+73|0;V=g+74|0;ka=g+75|0;ga=0;oa=a[ha]|0;pa=_;while(1){_=a[f+19352+ga|0]|0;ja=oa&255;do{if(_<<24>>24==12){ia=a[100552+(ja<<1)|0]|0;a[ha]=ia;wa=(e[101200+(ja<<1)>>1]|0)+pa|0;c[ea>>2]=wa;Ka=ia;La=wa}else{wa=a[100553+(ja<<1)|0]|0;a[ha]=wa;ia=(e[101200+((ja^1)<<1)>>1]|0)+pa|0;c[ea>>2]=ia;xa=d[ya]|0;if(_<<24>>24==11){a[ya]=a[100553+(xa<<1)|0]|0;da=(e[101200+((xa^1)<<1)>>1]|0)+ia|0;na=d[V]|0;a[V]=a[100552+(na<<1)|0]|0;la=d[ka]|0;ma=da+(e[101200+(na<<1)>>1]|0)+(e[101200+(la<<1)>>1]|0)|0;na=d[100552+(la<<1)|0]|0;a[ka]=a[100552+(na<<1)|0]|0;la=ma+(e[101200+(na<<1)>>1]|0)|0;c[ea>>2]=la;Ka=wa;La=la;break}else{a[ya]=a[100552+(xa<<1)|0]|0;la=(e[101200+(xa<<1)>>1]|0)+ia|0;ia=_<<24>>24==7|0;xa=d[ka]|0;a[ka]=a[100552+(xa<<1)+ia|0]|0;na=la+(e[101200+((xa^ia)<<1)>>1]|0)|0;c[ea>>2]=na;Ka=wa;La=na;break}}}while(0);_=ga+1|0;if((_|0)<4){ga=_;oa=Ka;pa=La}else{break}}pa=f+19352|0;do{if((c[f+24580>>2]|0)>1){if((a[95296+(d[pa]|0)|0]|0)!=0){_Ub(f,g,0,0)}if((a[95296+(d[f+19353|0]|0)|0]|0)!=0){_Ub(f,g,0,4)}if((a[95296+(d[f+19354|0]|0)|0]|0)!=0){_Ub(f,g,0,8)}if((a[95296+(d[f+19355|0]|0)|0]|0)==0){break}_Ub(f,g,0,12)}}while(0);do{if((c[f+24584>>2]|0)>1){if((a[95313+(d[pa]|0)|0]|0)!=0){_Ub(f,g,1,0)}if((a[95313+(d[f+19353|0]|0)|0]|0)!=0){_Ub(f,g,1,4)}if((a[95313+(d[f+19354|0]|0)|0]|0)!=0){_Ub(f,g,1,8)}if((a[95313+(d[f+19355|0]|0)|0]|0)==0){break}_Ub(f,g,1,12)}}while(0);if((a[95296+(d[pa]|0)|0]|0)!=0){oa=WUb(f,g,0,0,2)|0;re[c[25121]&1023](f+28536|0,oa&65535)}oa=f+19353|0;if((a[95296+(d[oa]|0)|0]|0)!=0){ga=WUb(f,g,0,4,2)|0;re[c[25121]&1023](f+28540|0,ga&65535)}ga=f+19354|0;if((a[95296+(d[ga]|0)|0]|0)!=0){ea=WUb(f,g,0,8,2)|0;re[c[25121]&1023](f+28568|0,ea&65535)}ea=f+19355|0;if((a[95296+(d[ea]|0)|0]|0)!=0){ka=WUb(f,g,0,12,2)|0;re[c[25121]&1023](f+28572|0,ka&65535)}if((a[95313+(d[pa]|0)|0]|0)!=0){ka=WUb(f,g,1,0,2)|0;re[c[25121]&1023](f+28616|0,ka&65535)}if((a[95313+(d[oa]|0)|0]|0)!=0){oa=WUb(f,g,1,4,2)|0;re[c[25121]&1023](f+28620|0,oa&65535)}if((a[95313+(d[ga]|0)|0]|0)!=0){ga=WUb(f,g,1,8,2)|0;re[c[25121]&1023](f+28648|0,ga&65535)}if((a[95313+(d[ea]|0)|0]|0)==0){p=341;break}ea=WUb(f,g,1,12,2)|0;re[c[25121]&1023](f+28652|0,ea&65535);p=341}else{ea=c[f+18784>>2]|0;if((ea&1|0)==0){Ma=0}else{Ma=(c[f+18880>>2]|0)!=0|0}if((ea&2|0)==0){Na=Ma}else{Na=((c[f+18876>>2]|0)!=0)+Ma|0}ZUb(f,g,j,Na+3|0,6,7,8,9,10);if((j|0)==3){p=342;break}else if((j|0)!=2){ea=f+19356|0;if((c[f+8696>>2]|0)==0){Oa=g+32|0}else{ga=g+32|0;c[ga>>2]=(c[ga>>2]|0)+(e[101200+((d[(c[f+28760>>2]|0)+399+(g+36)|0]^c[ea>>2])<<1)>>1]|0);Oa=ga}ga=(c[ea>>2]|0)!=0?4:1;ea=g+104|0;oa=g+105|0;ka=0;ya=a[ea]|0;while(1){V=d[19112+ka|0]|0;ha=a[(a[V-1+(f+27936)|0]|0)+95137|0]|0;fa=a[(a[V-8+(f+27936)|0]|0)+95137|0]|0;_=ha<<24>>24<fa<<24>>24?ha:fa;fa=_<<24>>24<0?2:_<<24>>24;_=a[(a[f+27936+V|0]|0)+95137|0]|0;V=ya&255;if((fa|0)==(_|0)){ha=a[100553+(V<<1)|0]|0;a[ea]=ha;Pa=ha;Qa=(c[Oa>>2]|0)+(e[101200+((V^1)<<1)>>1]|0)|0}else{ha=a[100552+(V<<1)|0]|0;a[ea]=ha;ja=(((_|0)>(fa|0))<<31>>31)+_|0;_=ja&1;fa=d[oa]|0;na=ja>>>1&1;wa=d[100552+(fa<<1)+_|0]|0;ia=(c[Oa>>2]|0)+(e[101200+(V<<1)>>1]|0)+(e[101200+((fa^_)<<1)>>1]|0)+(e[101200+((wa^na)<<1)>>1]|0)|0;_=ja>>2;ja=d[100552+(wa<<1)+na|0]|0;a[oa]=a[100552+(ja<<1)+_|0]|0;Pa=ha;Qa=ia+(e[101200+((ja^_)<<1)>>1]|0)|0}c[Oa>>2]=Qa;_=ka+ga|0;if((_|0)<16){ka=_;ya=Pa}else{break}}}KUb(f,g);p=341}}while(0);if((p|0)==341){if((j|0)==2){Ra=1}else{p=342}}do{if((p|0)==342){Pa=c[f+19360>>2]|0;Qa=f+28768|0;Oa=c[Qa>>2]|0;Na=f+28772|0;Ma=c[Na>>2]|0;La=Pa&1;Ka=76-(Oa>>>1&2)-(Ma>>>1&1)+(g+36)|0;Ha=d[Ka]|0;a[Ka]=a[100552+(Ha<<1)+La|0]|0;Ka=g+32|0;c[Ka>>2]=(c[Ka>>2]|0)+(e[101200+((Ha^La)<<1)>>1]|0);Ha=Pa>>>1&1;Ja=76-La-(Oa>>>2&2)+(g+36)|0;Oa=d[Ja]|0;a[Ja]=a[100552+(Oa<<1)+Ha|0]|0;c[Ka>>2]=(c[Ka>>2]|0)+(e[101200+((Oa^Ha)<<1)>>1]|0);Ha=Pa>>>2&1;Oa=76-(Pa<<1&2)-(Ma>>>3&1)+(g+36)|0;Ma=d[Oa]|0;a[Oa]=a[100552+(Ma<<1)+Ha|0]|0;Oa=(c[Ka>>2]|0)+(e[101200+((Ma^Ha)<<1)>>1]|0)|0;c[Ka>>2]=Oa;Ma=(e[101200+((d[76-(Pa&2)-Ha+(g+36)|0]^Pa>>>3&1)<<1)>>1]|0)+Oa|0;c[Ka>>2]=Ma;Oa=c[Na>>2]|0;Na=Oa&48;Pa=c[Qa>>2]|0;Qa=Pa&48;Ha=((Na|0)==0|(Oa|0)==-1)&1^1;if((Qa|0)==0){Sa=Ha}else{Sa=(Pa|0)==-1?Ha:Ha|2}Ha=f+19364|0;Pa=d[Sa+77+(g+36)|0]|0;if((c[Ha>>2]|0)==0){c[Ka>>2]=(e[101200+(Pa<<1)>>1]|0)+Ma;Ra=0;break}else{Oa=(e[101200+((Pa^1)<<1)>>1]|0)+Ma|0;c[Ka>>2]=Oa;Ma=(Na|0)==32?5:4;c[Ka>>2]=(e[101200+((d[((Qa|0)==32?Ma|2:Ma)+77+(g+36)|0]^c[Ha>>2]>>1)<<1)>>1]|0)+Oa;Ra=0;break}}}while(0);do{if((c[f+8696>>2]|0)!=0){Sa=c[i>>2]|0;if((Sa|0)==5){Ta=(c[f+19352>>2]|0)==50529027|0}else{Ta=d[17936+Sa|0]|0}if((Ta|0)==0){break}if((c[f+19360>>2]|0)==0){break}Sa=g+32|0;c[Sa>>2]=(c[Sa>>2]|0)+(e[101200+((d[(c[f+28760>>2]|0)+399+(g+36)|0]^c[f+19356>>2])<<1)>>1]|0)}}while(0);Ta=f+19360|0;do{if((c[Ta>>2]|0)==0){if((c[f+19364>>2]|0)!=0|Ra){break}return}}while(0);if(j>>>0<3>>>0){Ua=1}else{Ua=(j|0)==3|0}j=c[f+28816>>2]|0;Sa=c[f+28824>>2]|0;p=j-Sa|0;if((c[i>>2]|0)==2){Va=(b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]|0)==0&(j|0)>(Sa|0)?0:p}else{Va=p}do{if((c[f+28828>>2]|0)==0){Wa=0}else{p=c[f+18896>>2]|0;if((a[(c[f+18956>>2]|0)+p|0]|0)==2){Wa=1;break}Wa=(b[(c[f+18968>>2]|0)+(p<<1)>>1]&63)!=0|0}}while(0);if((Va|0)==0){Xa=Wa;Ya=c[g+32>>2]|0}else{p=Va<<1;Va=1-p|0;Sa=(Va|0)<0?p:Va;Va=Sa-1|0;p=g+32|0;j=(Va|0)>50&(Va|0)!=52?104-Sa|0:Va;Va=Wa;while(1){Wa=Va+60+(g+36)|0;Sa=d[Wa]|0;a[Wa]=a[100553+(Sa<<1)|0]|0;Wa=(c[p>>2]|0)+(e[101200+((Sa^1)<<1)>>1]|0)|0;c[p>>2]=Wa;Sa=(Va>>1)+2|0;i=j-1|0;if((i|0)==0){Xa=Sa;Ya=Wa;break}else{j=i;Va=Sa}}}Va=g+32|0;c[Va>>2]=(e[101200+(d[Xa+60+(g+36)|0]<<1)>>1]|0)+Ya;e:do{if(Ra){Ya=((c[f+28772>>2]|0)>>>8&1)+85+((c[f+28768>>2]|0)>>>8<<1&2)+(g+36)|0;Xa=d[Ya]|0;if((a[f+27984|0]|0)==0){a[Ya]=a[100552+(Xa<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+(Xa<<1)>>1]|0)}else{a[Ya]=a[100553+(Xa<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+((Xa^1)<<1)>>1]|0);TTb(f,g,0,f+15360|0)}if((c[Ta>>2]|0)==0){break}else{Za=0}do{Xa=d[19112+Za|0]|0;Ya=((a[Xa-1+(f+27984)|0]|0)!=0?90:89)+(((a[Xa-8+(f+27984)|0]|0)!=0)<<1)+(g+36)|0;j=d[Ya]|0;if((a[f+27984+Xa|0]|0)==0){a[Ya]=a[100552+(j<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+(j<<1)>>1]|0)}else{a[Ya]=a[100553+(j<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+((j^1)<<1)>>1]|0);TTb(f,g,1,f+17024+(Za<<5)+2|0)}Za=Za+1|0;}while((Za|0)<16)}else{if((c[f+19356>>2]|0)!=0){j=c[Ta>>2]|0;if((j|0)==0){break}else{_a=0;$a=j}while(1){j=d[98840+$a|0]|0;Ya=j+_a|0;Xa=$a>>j+1;STb(f,g,5,f+15488+(Ya<<7)|0);if((Xa|0)==0){break e}else{_a=Ya+1|0;$a=Xa}}}Xa=Ua<<7|127;Ya=c[Ta>>2]|0;if((Ya|0)==0){break}else{ab=0;bb=Ya}while(1){Ya=d[98840+bb|0]|0;j=Ya+ab|0;p=j<<2;Sa=0;do{i=p+Sa|0;Wa=d[19112+i|0]|0;Oa=((d[Wa-1+(f+27984)|0]&Xa|0)!=0?94:93)+(((d[Wa-8+(f+27984)|0]&Xa|0)!=0)<<1)+(g+36)|0;Ha=d[Oa]|0;if((a[f+27984+Wa|0]|0)==0){a[Oa]=a[100552+(Ha<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+(Ha<<1)>>1]|0)}else{a[Oa]=a[100553+(Ha<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+((Ha^1)<<1)>>1]|0);TTb(f,g,2,f+17024+(i<<5)|0)}Sa=Sa+1|0;}while((Sa|0)<4);Sa=bb>>Ya+1;if((Sa|0)==0){break}else{ab=j+1|0;bb=Sa}}}}while(0);bb=f+19364|0;if((c[bb>>2]|0)==0){return}ab=f+28772|0;Ta=c[ab>>2]|0;if((Ta|0)==-1){cb=Ua}else{cb=Ta>>>9&1}Ta=f+28768|0;$a=c[Ta>>2]|0;if(($a|0)==-1){db=Ua}else{db=$a>>>9&1}$a=(a[f+28024|0]|0)==0;_a=cb+97+(db<<1)+(g+36)|0;db=d[_a]|0;do{if((c[h>>2]|0)==2){if($a){a[_a]=a[100552+(db<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+(db<<1)>>1]|0)}else{a[_a]=a[100553+(db<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+((db^1)<<1)>>1]|0);LUb(c[f+18660>>2]|0,c[f+37788>>2]|0,g,f+15456|0)}cb=c[ab>>2]|0;if((cb|0)==-1){eb=Ua}else{eb=cb>>>10&1}cb=c[Ta>>2]|0;if((cb|0)==-1){fb=Ua}else{fb=cb>>>10&1}cb=eb+97+(fb<<1)+(g+36)|0;Za=d[cb]|0;if((a[f+28064|0]|0)==0){a[cb]=a[100552+(Za<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+(Za<<1)>>1]|0);break}else{a[cb]=a[100553+(Za<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+((Za^1)<<1)>>1]|0);LUb(c[f+18660>>2]|0,c[f+37788>>2]|0,g,f+15472|0);break}}else{if($a){a[_a]=a[100552+(db<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+(db<<1)>>1]|0)}else{a[_a]=a[100553+(db<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+((db^1)<<1)>>1]|0);TTb(f,g,3,f+15456|0)}Za=c[ab>>2]|0;if((Za|0)==-1){gb=Ua}else{gb=Za>>>10&1}Za=c[Ta>>2]|0;if((Za|0)==-1){hb=Ua}else{hb=Za>>>10&1}Za=gb+97+(hb<<1)+(g+36)|0;cb=d[Za]|0;if((a[f+28064|0]|0)==0){a[Za]=a[100552+(cb<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+(cb<<1)>>1]|0);break}else{a[Za]=a[100553+(cb<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+((cb^1)<<1)>>1]|0);TTb(f,g,3,f+15472|0);break}}}while(0);if((c[bb>>2]|0)!=2){return}bb=8<<c[f+18576>>2];hb=Ua<<7|127;Ua=16;do{gb=Ua+4|0;Ta=Ua;do{ab=d[19112+Ta|0]|0;db=(((d[ab-8+(f+27984)|0]&hb|0)!=0)<<1)+((d[ab-1+(f+27984)|0]&hb|0)!=0?102:101)+(g+36)|0;_a=d[db]|0;if((a[f+27984+ab|0]|0)==0){a[db]=a[100552+(_a<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+(_a<<1)>>1]|0)}else{a[db]=a[100553+(_a<<1)|0]|0;c[Va>>2]=(c[Va>>2]|0)+(e[101200+((_a^1)<<1)>>1]|0);TTb(f,g,4,f+17024+(Ta<<5)+2|0)}Ta=Ta+1|0;}while((Ta|0)<(gb|0));Ua=Ua+bb|0;}while((Ua|0)<48);return}function YUb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((e|0)==2){h=b+1520|0;i=(c[h>>2]|0)+(d[16464+(f+2+(d[95184+(c[b+19368>>2]|0)|0]|0)+(c[b+19364>>2]<<2)+((c[b+19360>>2]|0)==0?0:12))|0]|0)|0;c[h>>2]=i;j=i}else{i=(e|0)==1?4:1;e=b+1520|0;h=(c[e>>2]|0)+(d[f+16465|0]|0)|0;c[e>>2]=h;if((c[b+8696>>2]|0)==0){k=0;l=h}else{f=h+1|0;c[e>>2]=f;k=0;l=f}while(1){f=d[19112+k|0]|0;h=a[(a[f-1+(b+27936)|0]|0)+95137|0]|0;m=a[(a[f-8+(b+27936)|0]|0)+95137|0]|0;n=h<<24>>24<m<<24>>24?h:m;m=(((n<<24>>24<0?2:n<<24>>24)|0)==(a[(a[b+27936+f|0]|0)+95137|0]|0)?1:4)+l|0;c[e>>2]=m;f=k+i|0;if((f|0)<16){k=f;l=m}else{j=m;break}}}if((g|0)==0){return}c[b+1520>>2]=j+(d[(d[95352+(c[b+19372>>2]|0)|0]|0)+16465|0]|0);return}function ZUb(b,f,g,h,i,j,k,l,m){b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0;if(g>>>0<2>>>0){g=f+32|0;c[g>>2]=(c[g>>2]|0)+(e[101200+((d[f+36+h|0]|0)<<1)>>1]|0);return}g=d[95184+(c[b+19368>>2]|0)|0]|0;n=f+32|0;o=(e[101200+(((d[f+36+h|0]|0)^1)<<1)>>1]|0)+7+(c[n>>2]|0)|0;c[n>>2]=o;h=o+(e[101200+(((d[f+36+i|0]|0)^(c[b+19360>>2]|0)!=0)<<1)>>1]|0)|0;c[n>>2]=h;i=b+19364|0;b=f+36+j|0;j=d[b]|0;if((c[i>>2]|0)==0){p=(e[101200+(j<<1)>>1]|0)+h|0}else{a[b]=a[100553+(j<<1)|0]|0;b=(c[n>>2]|0)+(e[101200+((j^1)<<1)>>1]|0)|0;c[n>>2]=b;p=(e[101200+(((d[f+36+k|0]|0)^c[i>>2]>>1)<<1)>>1]|0)+b|0}c[n>>2]=p;p=g>>>1;b=f+36+l|0;l=d[b]|0;a[b]=a[100552+(l<<1)+p|0]|0;b=(c[n>>2]|0)+(e[101200+((l^p)<<1)>>1]|0)|0;c[n>>2]=b;c[n>>2]=(e[101200+(((d[f+36+m|0]|0)^g&1)<<1)>>1]|0)+b;return}function _Ub(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=d[19112+i|0]|0;i=j-1|0;k=j-8|0;if((a[f+28104+(h*40|0)+i|0]|0)>0){l=(a[f+28672+i|0]|0)==0|0}else{l=0}if((a[f+28104+(h*40|0)+k|0]|0)>0){m=(a[f+28672+k|0]|0)==0?l|2:l}else{m=l}l=a[f+28104+(h*40|0)+j|0]|0;j=m+54+(g+36)|0;h=d[j]|0;if(!(l<<24>>24>0)){n=j;o=h;p=g+32|0;q=100552+(o<<1)|0;r=a[q]|0;a[n]=r;s=101200+(o<<1)|0;t=b[s>>1]|0;u=t&65535;v=c[p>>2]|0;w=v+u|0;c[p>>2]=w;return}f=g+32|0;k=m;m=l<<24>>24;l=j;j=h;while(1){a[l]=a[100553+(j<<1)|0]|0;c[f>>2]=(c[f>>2]|0)+(e[101200+((j^1)<<1)>>1]|0);h=k>>2;i=m-1|0;x=h+58+(g+36)|0;y=d[x]|0;if((i|0)>0){k=h+4|0;m=i;l=x;j=y}else{n=x;o=y;p=f;break}}q=100552+(o<<1)|0;r=a[q]|0;a[n]=r;s=101200+(o<<1)|0;t=b[s>>1]|0;u=t&65535;v=c[p>>2]|0;w=v+u|0;c[p>>2]=w;return}function $Ub(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=d[19112+g|0]|0;g=(a[h-1+(b+28104)|0]|0)>0|0;i=(a[h-8+(b+28104)|0]|0)>0?g|2:g;g=a[b+28104+h|0]|0;h=i+54+(f+36)|0;b=d[h]|0;if(g<<24>>24>0){j=f+32|0;k=i;i=g<<24>>24;g=h;l=b;while(1){a[g]=a[100553+(l<<1)|0]|0;c[j>>2]=(c[j>>2]|0)+(e[101200+((l^1)<<1)>>1]|0);m=k>>2;n=i-1|0;o=m+58+(f+36)|0;p=d[o]|0;if((n|0)>0){k=m+4|0;i=n;g=o;l=p}else{q=o;r=p;s=j;break}}}else{q=h;r=b;s=f+32|0}a[q]=a[100552+(r<<1)|0]|0;c[s>>2]=(c[s>>2]|0)+(e[101200+(r<<1)>>1]|0);return}function aVb(a,b){a=a|0;b=b|0;sNb(a+13888|0,((c[a+3240>>2]|0)==0?11:24)+(c[a+28764>>2]|0)|0,b);return}function bVb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;k=i;i=i+128|0;l=k|0;m=f+18660|0;n=c[m>>2]|0;o=e[18864+(n<<5)+(h<<1)>>1]|0;p=e[97192+(n<<5)+(h<<1)>>1]|0;n=e[100176+(h<<1)>>1]|0;q=ve[c[f+37776+(h<<2)>>2]&4095](j)|0;f=a[99288+h|0]|0;h=f&255;do{if(f<<24>>24==63){r=c[m>>2]|0;s=-1;t=0;while(1){u=b[j+(t<<1)>>1]|0;if(u<<16>>16==0){sNb(g,(d[18736+(r<<6)+t|0]|0)+o|0,0);v=s}else{w=s+1|0;b[l+(w<<1)>>1]=u;sNb(g,(d[18736+(r<<6)+t|0]|0)+o|0,1);x=(d[97128+t|0]|0)+p|0;if((t|0)==(q|0)){y=5;break}sNb(g,x,0);v=w}u=t+1|0;if((u|0)==(h|0)){y=9;break}else{s=v;t=u}}if((y|0)==5){sNb(g,x,1);z=w;A=0;break}else if((y|0)==9){t=v+1|0;b[l+(t<<1)>>1]=b[j+(h<<1)>>1]|0;z=t;A=0;break}}else{t=-1;s=0;while(1){r=b[j+(s<<1)>>1]|0;if(r<<16>>16==0){sNb(g,s+o|0,0);B=t}else{C=t+1|0;b[l+(C<<1)>>1]=r;sNb(g,s+o|0,1);D=s+p|0;if((s|0)==(q|0)){y=12;break}sNb(g,D,0);B=C}r=s+1|0;if((r|0)==(h|0)){y=16;break}else{t=B;s=r}}if((y|0)==12){sNb(g,D,1);z=C;A=0;break}else if((y|0)==16){s=B+1|0;b[l+(s<<1)>>1]=b[j+(h<<1)>>1]|0;z=s;A=0;break}}}while(0);while(1){h=b[l+(z<<1)>>1]|0;j=h<<16>>16;B=h<<16>>16>-1?j:-j|0;h=j>>31;j=(d[1648656+A|0]|0)+n|0;if((B|0)>1){sNb(g,j,1);y=(d[1648608+A|0]|0)+n|0;C=(B|0)<15;D=C?B-2|0:13;if((D|0)>0){q=D;do{sNb(g,y,1);q=q-1|0;}while((q|0)>0)}if(C){sNb(g,y,0)}else{uNb(g,0,B-15|0)}E=1648632+A|0}else{sNb(g,j,0);E=1648624+A|0}q=d[E]|0;tNb(g,h);if((z|0)>0){z=z-1|0;A=q}else{break}}i=k;return}function cVb(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0;h=f+8632|0;i=f+19344|0;j=c[i>>2]|0;k=g+20|0;l=g+16|0;m=g+12|0;n=(c[k>>2]|0)-(c[l>>2]|0)+(c[m>>2]|0)<<3;o=g+8|0;p=c[o>>2]|0;q=(c[f+3260>>2]|0)==0;if((c[h>>2]|0)==3){do{if(!q){if((c[f+18612>>2]&1|0)!=0){r=a[(c[f+18956>>2]|0)+((c[f+18616>>2]|0)-(c[f+18580>>2]|0))|0]|0;if(!((r<<24>>24|0)==6|(r<<24>>24|0)==18)){break}}r=f+18948|0;s=(c[f+18608>>2]|0)!=0&c[r>>2];t=c[f+18936>>2]|0;do{if((t|0)>-1){if((e[(c[f+19272>>2]|0)+(t<<1)>>1]|0)!=(c[f+3244>>2]|0)){u=0;break}u=(a[(c[f+19276>>2]|0)+t|0]|0)!=0|0}else{u=0}}while(0);t=f+18660|0;sNb(g,u+(s|70)|0,c[t>>2]|0);c[r>>2]=c[t>>2]}}while(0);u=c[f+3240>>2]|0;a:do{if((u|0)==0){if((j|0)==4){sNb(g,14,0);t=c[f+19348>>2]|0;if((t|0)==16){sNb(g,15,0);sNb(g,16,0);if((c[f+24580>>2]|0)>1){hVb(f,g,0)}v=gVb(f,g,0,0,4)|0;re[c[25127]&1023](f+28536|0,v&65535);break}sNb(g,15,1);if((t|0)==14){sNb(g,17,1);if((c[f+24580>>2]|0)>1){hVb(f,g,0);hVb(f,g,8)}t=gVb(f,g,0,0,4)|0;re[c[25123]&1023](f+28536|0,t&65535);t=gVb(f,g,0,8,4)|0;re[c[25123]&1023](f+28568|0,t&65535);break}else{sNb(g,17,0);if((c[f+24580>>2]|0)>1){hVb(f,g,0);hVb(f,g,4)}t=gVb(f,g,0,0,2)|0;re[c[25125]&1023](f+28536|0,t&65535);t=gVb(f,g,0,4,2)|0;re[c[25125]&1023](f+28540|0,t&65535);break}}else if((j|0)==5){sNb(g,14,0);sNb(g,15,0);sNb(g,16,1);t=a[f+19352|0]|0;do{if(t<<24>>24==3){sNb(g,21,1)}else{sNb(g,21,0);if(t<<24>>24==1){sNb(g,22,0);break}else{sNb(g,22,1);sNb(g,23,t<<24>>24==2|0);break}}}while(0);t=a[f+19353|0]|0;do{if(t<<24>>24==3){sNb(g,21,1)}else{sNb(g,21,0);if(t<<24>>24==1){sNb(g,22,0);break}else{sNb(g,22,1);sNb(g,23,t<<24>>24==2|0);break}}}while(0);t=a[f+19354|0]|0;do{if(t<<24>>24==3){sNb(g,21,1)}else{sNb(g,21,0);if(t<<24>>24==1){sNb(g,22,0);break}else{sNb(g,22,1);sNb(g,23,t<<24>>24==2|0);break}}}while(0);t=a[f+19355|0]|0;do{if(t<<24>>24==3){sNb(g,21,1)}else{sNb(g,21,0);if(t<<24>>24==1){sNb(g,22,0);break}else{sNb(g,22,1);sNb(g,23,t<<24>>24==2|0);break}}}while(0);if((c[f+24580>>2]|0)>1){hVb(f,g,0);hVb(f,g,4);hVb(f,g,8);hVb(f,g,12);w=0}else{w=0}while(1){t=d[f+19352+w|0]|0;if((t|0)==3){r=w<<2;s=gVb(f,g,0,r,2)|0;re[c[25121]&1023](f+28512+((d[1901560+r|0]|0)+12+(d[1901352+r|0]<<3)<<1)|0,s&65535)}else if((t|0)==1){s=w<<2;r=gVb(f,g,0,s,2)|0;re[c[25119]&1023](f+28512+((d[1901560+s|0]|0)+12+(d[1901352+s|0]<<3)<<1)|0,r&65535);r=s|2;s=gVb(f,g,0,r,2)|0;re[c[25119]&1023](f+28512+((d[1901560+r|0]|0)+12+(d[1901352+r|0]<<3)<<1)|0,s&65535)}else if((t|0)==2){s=w<<2;r=gVb(f,g,0,s,1)|0;re[c[25120]&1023](f+28512+((d[1901560+s|0]|0)+12+(d[1901352+s|0]<<3)<<1)|0,r&65535);r=s|1;s=gVb(f,g,0,r,1)|0;re[c[25120]&1023](f+28512+((d[1901560+r|0]|0)+12+(d[1901352+r|0]<<3)<<1)|0,s&65535)}else if((t|0)==0){t=w<<2;s=gVb(f,g,0,t,1)|0;re[c[25118]&1023](f+28512+((d[1901560+t|0]|0)+12+(d[1901352+t|0]<<3)<<1)|0,s&65535);s=t|1;r=gVb(f,g,0,s,1)|0;re[c[25118]&1023](f+28512+((d[1901560+s|0]|0)+12+(d[1901352+s|0]<<3)<<1)|0,r&65535);r=t|2;s=gVb(f,g,0,r,1)|0;re[c[25118]&1023](f+28512+((d[1901560+r|0]|0)+12+(d[1901352+r|0]<<3)<<1)|0,s&65535);s=t|3;t=gVb(f,g,0,s,1)|0;re[c[25118]&1023](f+28512+((d[1901560+s|0]|0)+12+(d[1901352+s|0]<<3)<<1)|0,t&65535)}else{break}w=w+1|0;if((w|0)>=4){break a}}Cd(2385608,2573096,377,2649608)}else{sNb(g,14,1);eVb(f,g,j,17,18,19,19,20,20);if((j-2|0)>>>0<2>>>0){break}t=f+19356|0;if((c[f+8696>>2]|0)!=0){sNb(g,(c[f+28760>>2]|0)+399|0,c[t>>2]|0)}s=(c[t>>2]|0)!=0?4:1;t=0;do{r=d[19056+t|0]|0;v=a[(a[r-1+(f+27936)|0]|0)+95121|0]|0;x=a[(a[r-8+(f+27936)|0]|0)+95121|0]|0;y=v<<24>>24<x<<24>>24?v:x;x=y<<24>>24<0?2:y<<24>>24;y=a[(a[f+27936+r|0]|0)+95121|0]|0;if((x|0)==(y|0)){sNb(g,68,1)}else{sNb(g,68,0);r=(((y|0)>(x|0))<<31>>31)+y|0;sNb(g,69,r&1);sNb(g,69,r>>>1&1);sNb(g,69,r>>2)}t=t+s|0;}while((t|0)<16)}}else if((u|0)==1){t=c[f+18784>>2]|0;do{if((t&1|0)==0){z=0}else{s=c[f+18880>>2]|0;if((s|0)==18|(s|0)==7){z=0;break}z=1}}while(0);do{if((t&2|0)==0){A=z}else{s=c[f+18876>>2]|0;if((s|0)==18|(s|0)==7){A=z;break}A=z+1|0}}while(0);t=A+27|0;if((j|0)==7){sNb(g,t,0);break}sNb(g,t,1);if((j|0)!=17){if(!((j-8|0)>>>0<9>>>0)){sNb(g,30,1);sNb(g,31,1);sNb(g,32,1);sNb(g,32,0);sNb(g,32,1);eVb(f,g,j,32,33,34,34,35,35);if((j-2|0)>>>0<2>>>0){break}t=f+19356|0;if((c[f+8696>>2]|0)!=0){sNb(g,(c[f+28760>>2]|0)+399|0,c[t>>2]|0)}s=(c[t>>2]|0)!=0?4:1;t=0;while(1){r=d[19056+t|0]|0;y=a[(a[r-1+(f+27936)|0]|0)+95121|0]|0;x=a[(a[r-8+(f+27936)|0]|0)+95121|0]|0;v=y<<24>>24<x<<24>>24?y:x;x=v<<24>>24<0?2:v<<24>>24;v=a[(a[f+27936+r|0]|0)+95121|0]|0;if((x|0)==(v|0)){sNb(g,68,1)}else{sNb(g,68,0);r=(((v|0)>(x|0))<<31>>31)+v|0;sNb(g,69,r&1);sNb(g,69,r>>>1&1);sNb(g,69,r>>2)}t=t+s|0;if((t|0)>=16){break a}}}t=f+19348|0;s=d[101136+((j*3|0)-38+(c[t>>2]|0))|0]|0;r=s&1;sNb(g,30,r);sNb(g,32-r|0,s>>>1&1);r=s>>>2;do{if((r|0)!=1){sNb(g,32,r&1);sNb(g,32,s>>>3&1);sNb(g,32,s>>>4&1);v=s>>>5;if((v|0)==1){break}sNb(g,32,v&1)}}while(0);do{if((c[f+24580>>2]|0)>1){if((407727>>>(j>>>0)&1|0)==0){fVb(f,g,0,0)}if((93520>>>(j>>>0)&1|0)==0){break}s=c[t>>2]|0;if((s|0)==16){break}fVb(f,g,0,8>>>(((s|0)==15|0)>>>0))}}while(0);do{if((c[f+24584>>2]|0)>1){if(!((j-11|0)>>>0>5>>>0)){fVb(f,g,1,0)}if((112128>>>(j>>>0)&1|0)==0){B=0;C=104;break}s=c[t>>2]|0;if((s|0)==16){D=0;C=105;break}fVb(f,g,1,8>>>(((s|0)==15|0)>>>0));B=0;C=104}else{B=0;C=104}}while(0);b:while(1){do{if((C|0)==104){C=0;s=c[t>>2]|0;if((s|0)==16){D=B;C=105;continue b}r=(a[94840+(j<<2)+(B<<1)|0]|0)!=0;if((s|0)==14){if(r){s=gVb(f,g,B,0,4)|0;re[c[25123]&1023](f+28512+(B*80|0)+24|0,s&65535)}if((a[94840+(j<<2)+(B<<1)+1|0]|0)==0){E=B;break}s=gVb(f,g,B,8,4)|0;re[c[25123]&1023](f+28512+(B*80|0)+56|0,s&65535);E=B;break}else{if(r){r=gVb(f,g,B,0,2)|0;re[c[25125]&1023](f+28512+(B*80|0)+24|0,r&65535)}if((a[94840+(j<<2)+(B<<1)+1|0]|0)==0){E=B;break}r=gVb(f,g,B,4,2)|0;re[c[25125]&1023](f+28512+(B*80|0)+28|0,r&65535);E=B;break}}else if((C|0)==105){C=0;if((a[94840+(j<<2)+(D<<1)|0]|0)==0){E=D;break}r=gVb(f,g,D,0,4)|0;re[c[25127]&1023](f+28512+(D*80|0)+24|0,r&65535);E=D}}while(0);r=E+1|0;if((r|0)<2){B=r;C=104}else{break a}}}sNb(g,30,1);sNb(g,31,1);sNb(g,32,1);sNb(g,32,1);sNb(g,32,1);t=0;do{r=a[f+19352+t|0]|0;do{if(r<<24>>24==12){sNb(g,36,0)}else{sNb(g,36,1);if(r<<24>>24==11){sNb(g,37,1);sNb(g,38,0);sNb(g,39,0);sNb(g,39,0);break}else{sNb(g,37,0);sNb(g,39,r<<24>>24==7|0);break}}}while(0);t=t+1|0;}while((t|0)<4);t=f+19352|0;do{if((c[f+24580>>2]|0)>1){if((a[95256+(d[t]|0)|0]|0)!=0){fVb(f,g,0,0)}if((a[95256+(d[f+19353|0]|0)|0]|0)!=0){fVb(f,g,0,4)}if((a[95256+(d[f+19354|0]|0)|0]|0)!=0){fVb(f,g,0,8)}if((a[95256+(d[f+19355|0]|0)|0]|0)==0){break}fVb(f,g,0,12)}}while(0);do{if((c[f+24584>>2]|0)>1){if((a[95273+(d[t]|0)|0]|0)!=0){fVb(f,g,1,0)}if((a[95273+(d[f+19353|0]|0)|0]|0)!=0){fVb(f,g,1,4)}if((a[95273+(d[f+19354|0]|0)|0]|0)!=0){fVb(f,g,1,8)}if((a[95273+(d[f+19355|0]|0)|0]|0)==0){break}fVb(f,g,1,12)}}while(0);if((a[95256+(d[t]|0)|0]|0)!=0){r=gVb(f,g,0,0,2)|0;re[c[25121]&1023](f+28536|0,r&65535)}r=f+19353|0;if((a[95256+(d[r]|0)|0]|0)!=0){s=gVb(f,g,0,4,2)|0;re[c[25121]&1023](f+28540|0,s&65535)}s=f+19354|0;if((a[95256+(d[s]|0)|0]|0)!=0){v=gVb(f,g,0,8,2)|0;re[c[25121]&1023](f+28568|0,v&65535)}v=f+19355|0;if((a[95256+(d[v]|0)|0]|0)!=0){x=gVb(f,g,0,12,2)|0;re[c[25121]&1023](f+28572|0,x&65535)}if((a[95273+(d[t]|0)|0]|0)!=0){x=gVb(f,g,1,0,2)|0;re[c[25121]&1023](f+28616|0,x&65535)}if((a[95273+(d[r]|0)|0]|0)!=0){r=gVb(f,g,1,4,2)|0;re[c[25121]&1023](f+28620|0,r&65535)}if((a[95273+(d[s]|0)|0]|0)!=0){s=gVb(f,g,1,8,2)|0;re[c[25121]&1023](f+28648|0,s&65535)}if((a[95273+(d[v]|0)|0]|0)==0){break}v=gVb(f,g,1,12,2)|0;re[c[25121]&1023](f+28652|0,v&65535)}else{v=c[f+18784>>2]|0;if((v&1|0)==0){F=0}else{F=(c[f+18880>>2]|0)!=0|0}if((v&2|0)==0){G=F}else{G=((c[f+18876>>2]|0)!=0)+F|0}eVb(f,g,j,G+3|0,6,7,8,9,10);if((j-2|0)>>>0<2>>>0){break}v=f+19356|0;if((c[f+8696>>2]|0)!=0){sNb(g,(c[f+28760>>2]|0)+399|0,c[v>>2]|0)}s=(c[v>>2]|0)!=0?4:1;v=0;do{r=d[19056+v|0]|0;x=a[(a[r-1+(f+27936)|0]|0)+95121|0]|0;y=a[(a[r-8+(f+27936)|0]|0)+95121|0]|0;H=x<<24>>24<y<<24>>24?x:y;y=H<<24>>24<0?2:H<<24>>24;H=a[(a[f+27936+r|0]|0)+95121|0]|0;if((y|0)==(H|0)){sNb(g,68,1)}else{sNb(g,68,0);r=(((H|0)>(y|0))<<31>>31)+H|0;sNb(g,69,r&1);sNb(g,69,r>>>1&1);sNb(g,69,r>>2)}v=v+s|0;}while((v|0)<16)}}while(0);G=c[k>>2]|0;F=G;B=(F-(c[l>>2]|0)+(c[m>>2]|0)<<3)+(c[o>>2]|0)|0;E=f+30504|0;c[E>>2]=(c[E>>2]|0)-(n+p)+B;if((j|0)==3){E=F&3;F=G+(-E|0)|0;G=4-E<<3;E=f+24544|0;D=G;A=(je(c[F>>2]|0)|0)>>>(G>>>0);G=F;F=0;while(1){z=d[(c[E>>2]|0)+F|0]|0;if((D|0)>8){I=D-8|0;J=G;K=z|A<<8}else{u=8-D|0;c[G>>2]=je(z>>>(u>>>0)|A<<D|0)|0;I=32-u|0;J=G+4|0;K=z}z=F+1|0;if((z|0)<256){D=I;A=K;G=J;F=z}else{break}}F=f+24548|0;G=I;I=K;K=J;J=0;while(1){A=d[(c[F>>2]|0)+J|0]|0;if((G|0)>8){L=G-8|0;M=K;N=A|I<<8}else{D=8-G|0;c[K>>2]=je(A>>>(D>>>0)|I<<G|0)|0;L=32-D|0;M=K+4|0;N=A}A=J+1|0;if((A|0)<256){G=L;I=N;K=M;J=A}else{break}}J=f+24552|0;K=L;L=N;N=M;M=0;while(1){I=d[(c[J>>2]|0)+M|0]|0;if((K|0)>8){O=K-8|0;P=N;Q=I|L<<8}else{G=8-K|0;c[N>>2]=je(I>>>(G>>>0)|L<<K|0)|0;O=32-G|0;P=N+4|0;Q=I}I=M+1|0;if((I|0)<256){K=O;L=Q;N=P;M=I}else{break}}c[P>>2]=je(Q<<(O&31)|0)|0;c[k>>2]=P+(4-(O>>3));qNb(g);O=f+30508|0;c[O>>2]=(c[o>>2]|0)-B+(c[O>>2]|0)+((c[k>>2]|0)-(c[l>>2]|0)+(c[m>>2]|0)<<3);return}O=(j|0)==2;if(!O){P=c[f+19360>>2]|0;Q=c[f+28768>>2]|0;M=c[f+28772>>2]|0;N=P&1;sNb(g,76-(Q>>>1&2)-(M>>>1&1)|0,N);sNb(g,76-N-(Q>>>2&2)|0,P>>>1&1);Q=P>>>2&1;sNb(g,76-(P<<1&2)-(M>>>3&1)|0,Q);sNb(g,76-(P&2)-Q|0,P>>>3&1)}do{if((c[f+8696>>2]|0)!=0){P=c[i>>2]|0;if((P|0)==5){R=(c[f+19352>>2]|0)==50529027|0}else{R=d[17912+P|0]|0}if((R|0)==0){break}if((c[f+19360>>2]|0)==0){break}sNb(g,(c[f+28760>>2]|0)+399|0,c[f+19356>>2]|0)}}while(0);R=f+19360|0;c:do{if((c[R>>2]|0)!=0|O){P=j>>>0<3>>>0|0;Q=f+28816|0;M=c[Q>>2]|0;N=c[f+28824>>2]|0;L=M-N|0;do{if((c[i>>2]|0)==2){if(!((b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]|0)==0&(M|0)>(N|0))){S=L;break}c[Q>>2]=N;S=0}else{S=L}}while(0);do{if((c[f+28828>>2]|0)==0){T=0}else{L=c[f+18896>>2]|0;if((a[(c[f+18956>>2]|0)+L|0]|0)==2){T=1;break}T=(b[(c[f+18968>>2]|0)+(L<<1)>>1]&63)!=0|0}}while(0);if((S|0)==0){U=T}else{L=S<<1;N=1-L|0;Q=(N|0)<0?L:N;N=Q-1|0;if((N|0)>50&(N|0)!=52){V=104-Q|0;W=T}else{V=N;W=T}while(1){sNb(g,W+60|0,1);N=(W>>1)+2|0;Q=V-1|0;if((Q|0)==0){U=N;break}else{V=Q;W=N}}}sNb(g,U+60|0,0);if(O){N=f+28772|0;Q=f+28768|0;L=0;while(1){M=a[1624984+L|0]|0;K=L+48|0;J=c[N>>2]|0;if(M<<24>>24==3){if((J|0)==-1){X=1}else{X=J>>>((L+8|0)>>>0)&1}I=c[Q>>2]|0;if((I|0)==-1){Y=2}else{Y=I>>>((L+8|0)>>>0)<<1&2}Z=(Y|X)+97|0}else{I=L+8|0;Z=(e[109648+((M&255)<<1)>>1]|0)+(J>>>(I>>>0)&1)+((c[Q>>2]|0)>>>(I>>>0)<<1&2)|0}if((a[(d[19056+K|0]|0)+(f+27984)|0]|0)==0){sNb(g,Z,0)}else{sNb(g,Z,1);bVb(f,g,M&255,f+15360+(L<<5)|0)}if((c[R>>2]|0)!=0){M=L<<4;K=M+16|0;I=d[1624987+L|0]|0;J=e[109648+(I<<1)>>1]|0;G=M;do{M=d[19056+G|0]|0;F=((a[M-1+(f+27984)|0]|0)!=0)+J+(((a[M-8+(f+27984)|0]|0)!=0)<<1)|0;if((a[f+27984+M|0]|0)==0){sNb(g,F,0)}else{sNb(g,F,1);bVb(f,g,I,f+17024+(G<<5)+2|0)}G=G+1|0;}while((G|0)<(K|0))}L=L+1|0;if((L|0)>=3){break c}}}if((c[f+19356>>2]|0)==0){L=P<<7|127;Q=0;while(1){N=c[R>>2]|0;if((N|0)!=0){K=d[1624990+Q|0]|0;G=Q<<4;I=e[109648+(K<<1)>>1]|0;J=0;F=N;while(1){N=d[98824+F|0]|0;M=N+J|0;A=(M<<2)+G|0;D=0;do{E=A+D|0;z=d[19056+E|0]|0;u=((d[z-1+(f+27984)|0]&L|0)!=0)+I+(((d[z-8+(f+27984)|0]&L|0)!=0)<<1)|0;if((a[f+27984+z|0]|0)==0){sNb(g,u,0)}else{sNb(g,u,1);bVb(f,g,K,f+17024+(E<<5)|0)}D=D+1|0;}while((D|0)<4);D=F>>N+1;if((D|0)==0){break}else{J=M+1|0;F=D}}}Q=Q+1|0;if((Q|0)>=3){break c}}}Q=f+18784|0;L=c[Q>>2]|0;do{if((L&1|0)==0){_=0;$=0;aa=0;ba=0;ca=0;da=0;ea=0;fa=0;ga=0;ha=0;ia=0;ja=0}else{F=c[f+19268>>2]|0;if((a[F+(c[f+18900>>2]|0)|0]|0)==0){J=f+27995|0;K=a[J]|0;a[J]=-128;J=f+28003|0;I=a[J]|0;a[J]=-128;J=f+28035|0;G=a[J]|0;a[J]=-128;J=f+28043|0;D=a[J]|0;a[J]=-128;J=f+28075|0;A=a[J]|0;a[J]=-128;J=f+28083|0;E=a[J]|0;a[J]=-128;ka=E;la=K;ma=I;na=G;oa=D;pa=A}else{ka=0;la=0;ma=0;na=0;oa=0;pa=0}if((a[F+(c[f+18904>>2]|0)|0]|0)!=0){_=0;$=0;aa=0;ba=0;ca=0;da=0;ea=pa;fa=oa;ga=na;ha=ma;ia=la;ja=ka;break}F=f+28011|0;A=a[F]|0;a[F]=-128;F=f+28019|0;D=a[F]|0;a[F]=-128;F=f+28051|0;G=a[F]|0;a[F]=-128;F=f+28059|0;I=a[F]|0;a[F]=-128;F=f+28091|0;K=a[F]|0;a[F]=-128;F=f+28099|0;E=a[F]|0;a[F]=-128;_=E;$=K;aa=A;ba=D;ca=G;da=I;ea=pa;fa=oa;ga=na;ha=ma;ia=la;ja=ka}}while(0);do{if((L&2|0)==0){qa=0;ra=0;sa=0}else{if((a[(c[f+19268>>2]|0)+(c[f+18908>>2]|0)|0]|0)!=0){qa=0;ra=0;sa=0;break}I=f+27988|0;G=c[I>>2]|0;c[I>>2]=-2139062144;I=f+28028|0;D=c[I>>2]|0;c[I>>2]=-2139062144;I=f+28068|0;A=c[I>>2]|0;c[I>>2]=-2139062144;qa=A;ra=G;sa=D}}while(0);L=P<<7|127;D=0;do{G=c[R>>2]|0;if((G|0)!=0){A=d[1624999+D|0]|0;I=D<<4;K=e[109648+(A<<1)>>1]|0;E=D<<2;F=0;J=G;while(1){G=d[98824+J|0]|0;u=G+F|0;z=J>>G+1;G=d[19056+((u<<2)+I)|0]|0;w=((d[G-1+(f+27984)|0]&L|0)!=0)+K+(((d[G-8+(f+27984)|0]&L|0)!=0)<<1)|0;if((a[f+27984+G|0]|0)==0){sNb(g,w,0)}else{sNb(g,w,1);bVb(f,g,A,f+15488+(u+E<<7)|0)}if((z|0)==0){break}else{F=u+1|0;J=z}}}D=D+1|0;}while((D|0)<3);D=c[Q>>2]|0;do{if((D&1|0)!=0){L=c[f+19268>>2]|0;if((a[L+(c[f+18900>>2]|0)|0]|0)==0){a[f+27995|0]=ia;a[f+28003|0]=ha;a[f+28035|0]=ga;a[f+28043|0]=fa;a[f+28075|0]=ea;a[f+28083|0]=ja}if((a[L+(c[f+18904>>2]|0)|0]|0)!=0){break}a[f+28011|0]=aa;a[f+28019|0]=ba;a[f+28051|0]=ca;a[f+28059|0]=da;a[f+28091|0]=$;a[f+28099|0]=_}}while(0);if((D&2|0)==0){break}if((a[(c[f+19268>>2]|0)+(c[f+18908>>2]|0)|0]|0)!=0){break}c[f+27988>>2]=ra;c[f+28028>>2]=sa;c[f+28068>>2]=qa}}while(0);qa=f+30508|0;c[qa>>2]=(c[o>>2]|0)-B+(c[qa>>2]|0)+((c[k>>2]|0)-(c[l>>2]|0)+(c[m>>2]|0)<<3);return}do{if(!q){if((c[f+18612>>2]&1|0)!=0){qa=a[(c[f+18956>>2]|0)+((c[f+18616>>2]|0)-(c[f+18580>>2]|0))|0]|0;if(!((qa<<24>>24|0)==6|(qa<<24>>24|0)==18)){break}}qa=f+18948|0;B=(c[f+18608>>2]|0)!=0&c[qa>>2];sa=c[f+18936>>2]|0;do{if((sa|0)>-1){if((e[(c[f+19272>>2]|0)+(sa<<1)>>1]|0)!=(c[f+3244>>2]|0)){ta=0;break}ta=(a[(c[f+19276>>2]|0)+sa|0]|0)!=0|0}else{ta=0}}while(0);sa=f+18660|0;sNb(g,ta+(B|70)|0,c[sa>>2]|0);c[qa>>2]=c[sa>>2]}}while(0);ta=c[f+3240>>2]|0;d:do{if((ta|0)==0){if((j|0)==4){sNb(g,14,0);q=c[f+19348>>2]|0;if((q|0)==16){sNb(g,15,0);sNb(g,16,0);if((c[f+24580>>2]|0)>1){hVb(f,g,0)}sa=gVb(f,g,0,0,4)|0;re[c[25127]&1023](f+28536|0,sa&65535);break}sNb(g,15,1);if((q|0)==14){sNb(g,17,1);if((c[f+24580>>2]|0)>1){hVb(f,g,0);hVb(f,g,8)}q=gVb(f,g,0,0,4)|0;re[c[25123]&1023](f+28536|0,q&65535);q=gVb(f,g,0,8,4)|0;re[c[25123]&1023](f+28568|0,q&65535);break}else{sNb(g,17,0);if((c[f+24580>>2]|0)>1){hVb(f,g,0);hVb(f,g,4)}q=gVb(f,g,0,0,2)|0;re[c[25125]&1023](f+28536|0,q&65535);q=gVb(f,g,0,4,2)|0;re[c[25125]&1023](f+28540|0,q&65535);break}}else if((j|0)==5){sNb(g,14,0);sNb(g,15,0);sNb(g,16,1);q=a[f+19352|0]|0;do{if(q<<24>>24==3){sNb(g,21,1)}else{sNb(g,21,0);if(q<<24>>24==1){sNb(g,22,0);break}else{sNb(g,22,1);sNb(g,23,q<<24>>24==2|0);break}}}while(0);q=a[f+19353|0]|0;do{if(q<<24>>24==3){sNb(g,21,1)}else{sNb(g,21,0);if(q<<24>>24==1){sNb(g,22,0);break}else{sNb(g,22,1);sNb(g,23,q<<24>>24==2|0);break}}}while(0);q=a[f+19354|0]|0;do{if(q<<24>>24==3){sNb(g,21,1)}else{sNb(g,21,0);if(q<<24>>24==1){sNb(g,22,0);break}else{sNb(g,22,1);sNb(g,23,q<<24>>24==2|0);break}}}while(0);q=a[f+19355|0]|0;do{if(q<<24>>24==3){sNb(g,21,1)}else{sNb(g,21,0);if(q<<24>>24==1){sNb(g,22,0);break}else{sNb(g,22,1);sNb(g,23,q<<24>>24==2|0);break}}}while(0);if((c[f+24580>>2]|0)>1){hVb(f,g,0);hVb(f,g,4);hVb(f,g,8);hVb(f,g,12);ua=0}else{ua=0}while(1){q=d[f+19352+ua|0]|0;if((q|0)==3){qa=ua<<2;B=gVb(f,g,0,qa,2)|0;re[c[25121]&1023](f+28512+((d[1901560+qa|0]|0)+12+(d[1901352+qa|0]<<3)<<1)|0,B&65535)}else if((q|0)==1){B=ua<<2;qa=gVb(f,g,0,B,2)|0;re[c[25119]&1023](f+28512+((d[1901560+B|0]|0)+12+(d[1901352+B|0]<<3)<<1)|0,qa&65535);qa=B|2;B=gVb(f,g,0,qa,2)|0;re[c[25119]&1023](f+28512+((d[1901560+qa|0]|0)+12+(d[1901352+qa|0]<<3)<<1)|0,B&65535)}else if((q|0)==2){B=ua<<2;qa=gVb(f,g,0,B,1)|0;re[c[25120]&1023](f+28512+((d[1901560+B|0]|0)+12+(d[1901352+B|0]<<3)<<1)|0,qa&65535);qa=B|1;B=gVb(f,g,0,qa,1)|0;re[c[25120]&1023](f+28512+((d[1901560+qa|0]|0)+12+(d[1901352+qa|0]<<3)<<1)|0,B&65535)}else if((q|0)==0){q=ua<<2;B=gVb(f,g,0,q,1)|0;re[c[25118]&1023](f+28512+((d[1901560+q|0]|0)+12+(d[1901352+q|0]<<3)<<1)|0,B&65535);B=q|1;qa=gVb(f,g,0,B,1)|0;re[c[25118]&1023](f+28512+((d[1901560+B|0]|0)+12+(d[1901352+B|0]<<3)<<1)|0,qa&65535);qa=q|2;B=gVb(f,g,0,qa,1)|0;re[c[25118]&1023](f+28512+((d[1901560+qa|0]|0)+12+(d[1901352+qa|0]<<3)<<1)|0,B&65535);B=q|3;q=gVb(f,g,0,B,1)|0;re[c[25118]&1023](f+28512+((d[1901560+B|0]|0)+12+(d[1901352+B|0]<<3)<<1)|0,q&65535)}else{break}ua=ua+1|0;if((ua|0)>=4){break d}}Cd(2385608,2573096,377,2649608)}else{sNb(g,14,1);eVb(f,g,j,17,18,19,19,20,20);if((j|0)==3){break}else if((j|0)!=2){q=f+19356|0;if((c[f+8696>>2]|0)!=0){sNb(g,(c[f+28760>>2]|0)+399|0,c[q>>2]|0)}B=(c[q>>2]|0)!=0?4:1;q=0;do{qa=d[19056+q|0]|0;sa=a[(a[qa-1+(f+27936)|0]|0)+95121|0]|0;D=a[(a[qa-8+(f+27936)|0]|0)+95121|0]|0;ra=sa<<24>>24<D<<24>>24?sa:D;D=ra<<24>>24<0?2:ra<<24>>24;ra=a[(a[f+27936+qa|0]|0)+95121|0]|0;if((D|0)==(ra|0)){sNb(g,68,1)}else{sNb(g,68,0);qa=(((ra|0)>(D|0))<<31>>31)+ra|0;sNb(g,69,qa&1);sNb(g,69,qa>>>1&1);sNb(g,69,qa>>2)}q=q+B|0;}while((q|0)<16)}q=c[f+19372>>2]|0;B=c[f+18784>>2]|0;if((B&1|0)==0){va=0}else{va=(a[(c[f+18980>>2]|0)+(c[f+18900>>2]|0)|0]|0)!=0|0}if((B&2|0)==0){wa=va}else{wa=((a[(c[f+18980>>2]|0)+(c[f+18908>>2]|0)|0]|0)!=0)+va|0}B=(q-1|0)>>>0<3>>>0;sNb(g,wa+64|0,B&1);if(!B){break}B=(q-2|0)>>>0<2>>>0;sNb(g,67,B&1);if(!B){break}sNb(g,67,(q|0)==3|0);break}}else if((ta|0)==1){q=f+18784|0;B=c[q>>2]|0;do{if((B&1|0)==0){xa=0}else{qa=c[f+18880>>2]|0;if((qa|0)==18|(qa|0)==7){xa=0;break}xa=1}}while(0);do{if((B&2|0)==0){ya=xa}else{qa=c[f+18876>>2]|0;if((qa|0)==18|(qa|0)==7){ya=xa;break}ya=xa+1|0}}while(0);B=ya+27|0;if((j|0)==7){sNb(g,B,0);break}sNb(g,B,1);if((j|0)==17){sNb(g,30,1);sNb(g,31,1);sNb(g,32,1);sNb(g,32,1);sNb(g,32,1);B=0;do{qa=a[f+19352+B|0]|0;do{if(qa<<24>>24==12){sNb(g,36,0)}else{sNb(g,36,1);if(qa<<24>>24==11){sNb(g,37,1);sNb(g,38,0);sNb(g,39,0);sNb(g,39,0);break}else{sNb(g,37,0);sNb(g,39,qa<<24>>24==7|0);break}}}while(0);B=B+1|0;}while((B|0)<4);B=f+19352|0;do{if((c[f+24580>>2]|0)>1){if((a[95256+(d[B]|0)|0]|0)!=0){fVb(f,g,0,0)}if((a[95256+(d[f+19353|0]|0)|0]|0)!=0){fVb(f,g,0,4)}if((a[95256+(d[f+19354|0]|0)|0]|0)!=0){fVb(f,g,0,8)}if((a[95256+(d[f+19355|0]|0)|0]|0)==0){break}fVb(f,g,0,12)}}while(0);do{if((c[f+24584>>2]|0)>1){if((a[95273+(d[B]|0)|0]|0)!=0){fVb(f,g,1,0)}if((a[95273+(d[f+19353|0]|0)|0]|0)!=0){fVb(f,g,1,4)}if((a[95273+(d[f+19354|0]|0)|0]|0)!=0){fVb(f,g,1,8)}if((a[95273+(d[f+19355|0]|0)|0]|0)==0){break}fVb(f,g,1,12)}}while(0);if((a[95256+(d[B]|0)|0]|0)!=0){qa=gVb(f,g,0,0,2)|0;re[c[25121]&1023](f+28536|0,qa&65535)}qa=f+19353|0;if((a[95256+(d[qa]|0)|0]|0)!=0){ra=gVb(f,g,0,4,2)|0;re[c[25121]&1023](f+28540|0,ra&65535)}ra=f+19354|0;if((a[95256+(d[ra]|0)|0]|0)!=0){D=gVb(f,g,0,8,2)|0;re[c[25121]&1023](f+28568|0,D&65535)}D=f+19355|0;if((a[95256+(d[D]|0)|0]|0)!=0){sa=gVb(f,g,0,12,2)|0;re[c[25121]&1023](f+28572|0,sa&65535)}if((a[95273+(d[B]|0)|0]|0)!=0){sa=gVb(f,g,1,0,2)|0;re[c[25121]&1023](f+28616|0,sa&65535)}if((a[95273+(d[qa]|0)|0]|0)!=0){qa=gVb(f,g,1,4,2)|0;re[c[25121]&1023](f+28620|0,qa&65535)}if((a[95273+(d[ra]|0)|0]|0)!=0){ra=gVb(f,g,1,8,2)|0;re[c[25121]&1023](f+28648|0,ra&65535)}if((a[95273+(d[D]|0)|0]|0)==0){break}D=gVb(f,g,1,12,2)|0;re[c[25121]&1023](f+28652|0,D&65535);break}if(!((j-8|0)>>>0<9>>>0)){sNb(g,30,1);sNb(g,31,1);sNb(g,32,1);sNb(g,32,0);sNb(g,32,1);eVb(f,g,j,32,33,34,34,35,35);if((j|0)==3){break}else if((j|0)!=2){D=f+19356|0;if((c[f+8696>>2]|0)!=0){sNb(g,(c[f+28760>>2]|0)+399|0,c[D>>2]|0)}ra=(c[D>>2]|0)!=0?4:1;D=0;do{qa=d[19056+D|0]|0;sa=a[(a[qa-1+(f+27936)|0]|0)+95121|0]|0;_=a[(a[qa-8+(f+27936)|0]|0)+95121|0]|0;$=sa<<24>>24<_<<24>>24?sa:_;_=$<<24>>24<0?2:$<<24>>24;$=a[(a[f+27936+qa|0]|0)+95121|0]|0;if((_|0)==($|0)){sNb(g,68,1)}else{sNb(g,68,0);qa=((($|0)>(_|0))<<31>>31)+$|0;sNb(g,69,qa&1);sNb(g,69,qa>>>1&1);sNb(g,69,qa>>2)}D=D+ra|0;}while((D|0)<16)}D=c[f+19372>>2]|0;ra=c[q>>2]|0;if((ra&1|0)==0){za=0}else{za=(a[(c[f+18980>>2]|0)+(c[f+18900>>2]|0)|0]|0)!=0|0}if((ra&2|0)==0){Aa=za}else{Aa=((a[(c[f+18980>>2]|0)+(c[f+18908>>2]|0)|0]|0)!=0)+za|0}ra=(D-1|0)>>>0<3>>>0;sNb(g,Aa+64|0,ra&1);if(!ra){break}ra=(D-2|0)>>>0<2>>>0;sNb(g,67,ra&1);if(!ra){break}sNb(g,67,(D|0)==3|0);break}D=f+19348|0;ra=d[101136+((j*3|0)-38+(c[D>>2]|0))|0]|0;B=ra&1;sNb(g,30,B);sNb(g,32-B|0,ra>>>1&1);B=ra>>>2;do{if((B|0)!=1){sNb(g,32,B&1);sNb(g,32,ra>>>3&1);sNb(g,32,ra>>>4&1);qa=ra>>>5;if((qa|0)==1){break}sNb(g,32,qa&1)}}while(0);do{if((c[f+24580>>2]|0)>1){if((407727>>>(j>>>0)&1|0)==0){fVb(f,g,0,0)}if((93520>>>(j>>>0)&1|0)==0){break}ra=c[D>>2]|0;if((ra|0)==16){break}fVb(f,g,0,8>>>(((ra|0)==15|0)>>>0))}}while(0);do{if((c[f+24584>>2]|0)>1){if(!((j-11|0)>>>0>5>>>0)){fVb(f,g,1,0)}if((112128>>>(j>>>0)&1|0)==0){Ba=0;C=349;break}ra=c[D>>2]|0;if((ra|0)==16){Ca=0;C=350;break}fVb(f,g,1,8>>>(((ra|0)==15|0)>>>0));Ba=0;C=349}else{Ba=0;C=349}}while(0);e:while(1){do{if((C|0)==349){C=0;ra=c[D>>2]|0;if((ra|0)==16){Ca=Ba;C=350;continue e}B=(a[94840+(j<<2)+(Ba<<1)|0]|0)!=0;if((ra|0)==14){if(B){ra=gVb(f,g,Ba,0,4)|0;re[c[25123]&1023](f+28512+(Ba*80|0)+24|0,ra&65535)}if((a[94840+(j<<2)+(Ba<<1)+1|0]|0)==0){Da=Ba;break}ra=gVb(f,g,Ba,8,4)|0;re[c[25123]&1023](f+28512+(Ba*80|0)+56|0,ra&65535);Da=Ba;break}else{if(B){B=gVb(f,g,Ba,0,2)|0;re[c[25125]&1023](f+28512+(Ba*80|0)+24|0,B&65535)}if((a[94840+(j<<2)+(Ba<<1)+1|0]|0)==0){Da=Ba;break}B=gVb(f,g,Ba,4,2)|0;re[c[25125]&1023](f+28512+(Ba*80|0)+28|0,B&65535);Da=Ba;break}}else if((C|0)==350){C=0;if((a[94840+(j<<2)+(Ca<<1)|0]|0)==0){Da=Ca;break}B=gVb(f,g,Ca,0,4)|0;re[c[25127]&1023](f+28512+(Ca*80|0)+24|0,B&65535);Da=Ca}}while(0);B=Da+1|0;if((B|0)<2){Ba=B;C=349}else{break}}}else{D=f+18784|0;B=c[D>>2]|0;if((B&1|0)==0){Ea=0}else{Ea=(c[f+18880>>2]|0)!=0|0}if((B&2|0)==0){Fa=Ea}else{Fa=((c[f+18876>>2]|0)!=0)+Ea|0}eVb(f,g,j,Fa+3|0,6,7,8,9,10);if((j|0)==3){break}else if((j|0)!=2){B=f+19356|0;if((c[f+8696>>2]|0)!=0){sNb(g,(c[f+28760>>2]|0)+399|0,c[B>>2]|0)}ra=(c[B>>2]|0)!=0?4:1;B=0;do{q=d[19056+B|0]|0;qa=a[(a[q-1+(f+27936)|0]|0)+95121|0]|0;$=a[(a[q-8+(f+27936)|0]|0)+95121|0]|0;_=qa<<24>>24<$<<24>>24?qa:$;$=_<<24>>24<0?2:_<<24>>24;_=a[(a[f+27936+q|0]|0)+95121|0]|0;if(($|0)==(_|0)){sNb(g,68,1)}else{sNb(g,68,0);q=(((_|0)>($|0))<<31>>31)+_|0;sNb(g,69,q&1);sNb(g,69,q>>>1&1);sNb(g,69,q>>2)}B=B+ra|0;}while((B|0)<16)}B=c[f+19372>>2]|0;ra=c[D>>2]|0;if((ra&1|0)==0){Ga=0}else{Ga=(a[(c[f+18980>>2]|0)+(c[f+18900>>2]|0)|0]|0)!=0|0}if((ra&2|0)==0){Ha=Ga}else{Ha=((a[(c[f+18980>>2]|0)+(c[f+18908>>2]|0)|0]|0)!=0)+Ga|0}ra=(B-1|0)>>>0<3>>>0;sNb(g,Ha+64|0,ra&1);if(!ra){break}ra=(B-2|0)>>>0<2>>>0;sNb(g,67,ra&1);if(!ra){break}sNb(g,67,(B|0)==3|0)}}while(0);Ha=c[k>>2]|0;Ga=Ha;Fa=(Ga-(c[l>>2]|0)+(c[m>>2]|0)<<3)+(c[o>>2]|0)|0;Ea=f+30504|0;c[Ea>>2]=(c[Ea>>2]|0)-(n+p)+Fa;if((j|0)==3){p=Ga&3;Ga=Ha+(-p|0)|0;Ha=4-p<<3;p=f+24544|0;n=Ha;Ea=(je(c[Ga>>2]|0)|0)>>>(Ha>>>0);Ha=Ga;Ga=0;while(1){Ba=d[(c[p>>2]|0)+Ga|0]|0;if((n|0)>8){Ia=n-8|0;Ja=Ha;Ka=Ba|Ea<<8}else{Da=8-n|0;c[Ha>>2]=je(Ba>>>(Da>>>0)|Ea<<n|0)|0;Ia=32-Da|0;Ja=Ha+4|0;Ka=Ba}Ba=Ga+1|0;if((Ba|0)<256){n=Ia;Ea=Ka;Ha=Ja;Ga=Ba}else{break}}Ga=f+18576|0;Ha=c[Ga>>2]|0;if((16>>>(Ha>>>0)|0)>0){Ea=f+24548|0;n=Ia;p=Ka;Ba=Ja;Da=0;while(1){Ca=Da<<4;Aa=n;za=p;ya=Ba;xa=0;while(1){ta=d[(c[Ea>>2]|0)+(xa+Ca)|0]|0;if((Aa|0)>8){La=Aa-8|0;Ma=ya;Na=ta|za<<8}else{wa=8-Aa|0;c[ya>>2]=je(ta>>>(wa>>>0)|za<<Aa|0)|0;La=32-wa|0;Ma=ya+4|0;Na=ta}ta=xa+1|0;if((ta|0)<8){Aa=La;za=Na;ya=Ma;xa=ta}else{break}}xa=Da+1|0;ya=c[Ga>>2]|0;if((xa|0)<(16>>>(ya>>>0)|0)){n=La;p=Na;Ba=Ma;Da=xa}else{Oa=La;Pa=Na;Qa=Ma;Ra=ya;break}}}else{Oa=Ia;Pa=Ka;Qa=Ja;Ra=Ha}if((16>>>(Ra>>>0)|0)>0){Ra=f+24552|0;Ha=Oa;Ja=Pa;Ka=Qa;Ia=0;while(1){Ma=Ia<<4;Na=Ha;La=Ja;Da=Ka;Ba=0;while(1){p=d[(c[Ra>>2]|0)+(Ba+Ma)|0]|0;if((Na|0)>8){Sa=Na-8|0;Ta=Da;Ua=p|La<<8}else{n=8-Na|0;c[Da>>2]=je(p>>>(n>>>0)|La<<Na|0)|0;Sa=32-n|0;Ta=Da+4|0;Ua=p}p=Ba+1|0;if((p|0)<8){Na=Sa;La=Ua;Da=Ta;Ba=p}else{break}}Ba=Ia+1|0;if((Ba|0)<(16>>>((c[Ga>>2]|0)>>>0)|0)){Ha=Sa;Ja=Ua;Ka=Ta;Ia=Ba}else{Va=Ta;Wa=Ua;Xa=Sa;break}}}else{Va=Qa;Wa=Pa;Xa=Oa}c[Va>>2]=je(Wa<<(Xa&31)|0)|0;c[k>>2]=Va+(4-(Xa>>3));qNb(g);Xa=f+30508|0;c[Xa>>2]=(c[o>>2]|0)-Fa+(c[Xa>>2]|0)+((c[k>>2]|0)-(c[l>>2]|0)+(c[m>>2]|0)<<3);return}Xa=(j|0)==2;do{if(!Xa){Va=c[f+19360>>2]|0;Wa=f+28768|0;Oa=c[Wa>>2]|0;Pa=f+28772|0;Qa=c[Pa>>2]|0;Sa=Va&1;sNb(g,76-(Oa>>>1&2)-(Qa>>>1&1)|0,Sa);sNb(g,76-Sa-(Oa>>>2&2)|0,Va>>>1&1);Oa=Va>>>2&1;sNb(g,76-(Va<<1&2)-(Qa>>>3&1)|0,Oa);sNb(g,76-(Va&2)-Oa|0,Va>>>3&1);Va=c[Pa>>2]|0;Pa=Va&48;Oa=c[Wa>>2]|0;Wa=Oa&48;Qa=((Pa|0)==0|(Va|0)==-1)&1^1;if((Wa|0)==0){Ya=Qa}else{Ya=(Oa|0)==-1?Qa:Qa|2}Qa=f+19364|0;Oa=Ya+77|0;if((c[Qa>>2]|0)==0){sNb(g,Oa,0);break}else{sNb(g,Oa,1);Oa=(Pa|0)==32?5:4;sNb(g,((Wa|0)==32?Oa|2:Oa)+77|0,c[Qa>>2]>>1);break}}}while(0);do{if((c[f+8696>>2]|0)!=0){Ya=c[i>>2]|0;if((Ya|0)==5){Za=(c[f+19352>>2]|0)==50529027|0}else{Za=d[17912+Ya|0]|0}if((Za|0)==0){break}if((c[f+19360>>2]|0)==0){break}sNb(g,(c[f+28760>>2]|0)+399|0,c[f+19356>>2]|0)}}while(0);Za=f+19360|0;if((c[Za>>2]|0)==0){if((c[f+19364>>2]|0)!=0|Xa){C=448}}else{C=448}do{if((C|0)==448){Ya=j>>>0<3>>>0|0;Qa=f+28816|0;Oa=c[Qa>>2]|0;Wa=c[f+28824>>2]|0;Pa=Oa-Wa|0;do{if((c[i>>2]|0)==2){if(!((b[(c[f+18968>>2]|0)+(c[f+18616>>2]<<1)>>1]|0)==0&(Oa|0)>(Wa|0))){_a=Pa;break}c[Qa>>2]=Wa;_a=0}else{_a=Pa}}while(0);do{if((c[f+28828>>2]|0)==0){$a=0}else{Pa=c[f+18896>>2]|0;if((a[(c[f+18956>>2]|0)+Pa|0]|0)==2){$a=1;break}$a=(b[(c[f+18968>>2]|0)+(Pa<<1)>>1]&63)!=0|0}}while(0);if((_a|0)==0){ab=$a}else{Pa=_a<<1;Wa=1-Pa|0;Qa=(Wa|0)<0?Pa:Wa;Wa=Qa-1|0;if((Wa|0)>50&(Wa|0)!=52){bb=104-Qa|0;cb=$a}else{bb=Wa;cb=$a}while(1){sNb(g,cb+60|0,1);Wa=(cb>>1)+2|0;Qa=bb-1|0;if((Qa|0)==0){ab=Wa;break}else{bb=Qa;cb=Wa}}}sNb(g,ab+60|0,0);f:do{if(Xa){Wa=((c[f+28772>>2]|0)>>>8&1)+85+((c[f+28768>>2]|0)>>>8<<1&2)|0;if((a[f+27984|0]|0)==0){sNb(g,Wa,0)}else{sNb(g,Wa,1);bVb(f,g,0,f+15360|0)}if((c[Za>>2]|0)==0){break}else{db=0}do{Wa=d[19056+db|0]|0;Qa=((a[Wa-1+(f+27984)|0]|0)!=0?90:89)+(((a[Wa-8+(f+27984)|0]|0)!=0)<<1)|0;if((a[f+27984+Wa|0]|0)==0){sNb(g,Qa,0)}else{sNb(g,Qa,1);bVb(f,g,1,f+17024+(db<<5)+2|0)}db=db+1|0;}while((db|0)<16)}else{if((c[f+19356>>2]|0)!=0){Qa=c[Za>>2]|0;if((Qa|0)==0){break}else{eb=0;fb=Qa}while(1){Qa=d[98824+fb|0]|0;Wa=Qa+eb|0;Pa=fb>>Qa+1;bVb(f,g,5,f+15488+(Wa<<7)|0);if((Pa|0)==0){break f}else{eb=Wa+1|0;fb=Pa}}}Pa=Ya<<7|127;Wa=c[Za>>2]|0;if((Wa|0)==0){break}else{gb=0;hb=Wa}while(1){Wa=d[98824+hb|0]|0;Qa=Wa+gb|0;Oa=Qa<<2;Va=0;do{Sa=Oa+Va|0;Ua=d[19056+Sa|0]|0;Ta=((d[Ua-1+(f+27984)|0]&Pa|0)!=0?94:93)+(((d[Ua-8+(f+27984)|0]&Pa|0)!=0)<<1)|0;if((a[f+27984+Ua|0]|0)==0){sNb(g,Ta,0)}else{sNb(g,Ta,1);bVb(f,g,2,f+17024+(Sa<<5)|0)}Va=Va+1|0;}while((Va|0)<4);Va=hb>>Wa+1;if((Va|0)==0){break}else{gb=Qa+1|0;hb=Va}}}}while(0);Pa=f+19364|0;if((c[Pa>>2]|0)==0){break}Va=f+28772|0;Oa=c[Va>>2]|0;if((Oa|0)==-1){ib=Ya}else{ib=Oa>>>9&1}Oa=f+28768|0;M=c[Oa>>2]|0;if((M|0)==-1){jb=Ya}else{jb=M>>>9&1}M=ib+97+(jb<<1)|0;N=(a[f+28024|0]|0)==0;do{if((c[h>>2]|0)==2){if(N){sNb(g,M,0)}else{sNb(g,M,1);dVb(c[f+18660>>2]|0,c[f+37788>>2]|0,g,f+15456|0)}Sa=c[Va>>2]|0;if((Sa|0)==-1){kb=Ya}else{kb=Sa>>>10&1}Sa=c[Oa>>2]|0;if((Sa|0)==-1){lb=Ya}else{lb=Sa>>>10&1}Sa=kb+97+(lb<<1)|0;if((a[f+28064|0]|0)==0){sNb(g,Sa,0);break}else{sNb(g,Sa,1);dVb(c[f+18660>>2]|0,c[f+37788>>2]|0,g,f+15472|0);break}}else{if(N){sNb(g,M,0)}else{sNb(g,M,1);bVb(f,g,3,f+15456|0)}Sa=c[Va>>2]|0;if((Sa|0)==-1){mb=Ya}else{mb=Sa>>>10&1}Sa=c[Oa>>2]|0;if((Sa|0)==-1){nb=Ya}else{nb=Sa>>>10&1}Sa=mb+97+(nb<<1)|0;if((a[f+28064|0]|0)==0){sNb(g,Sa,0);break}else{sNb(g,Sa,1);bVb(f,g,3,f+15472|0);break}}}while(0);if((c[Pa>>2]|0)!=2){break}Oa=8<<c[f+18576>>2];Va=Ya<<7|127;M=16;do{N=M+4|0;Sa=M;do{Ta=d[19056+Sa|0]|0;Ua=(((d[Ta-8+(f+27984)|0]&Va|0)!=0)<<1)+((d[Ta-1+(f+27984)|0]&Va|0)!=0?102:101)|0;if((a[f+27984+Ta|0]|0)==0){sNb(g,Ua,0)}else{sNb(g,Ua,1);bVb(f,g,4,f+17024+(Sa<<5)+2|0)}Sa=Sa+1|0;}while((Sa|0)<(N|0));M=M+Oa|0;}while((M|0)<48)}}while(0);g=f+30508|0;c[g>>2]=(c[o>>2]|0)-Fa+(c[g>>2]|0)+((c[k>>2]|0)-(c[l>>2]|0)+(c[m>>2]|0)<<3);return}function dVb(a,c,f,g){a=a|0;c=c|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;i=i+128|0;j=h|0;k=e[18870+(a<<5)>>1]|0;l=e[97198+(a<<5)>>1]|0;a=e[50091]|0;m=ve[c&4095](g)|0;c=-1;n=0;while(1){o=b[g+(n<<1)>>1]|0;if(o<<16>>16==0){sNb(f,(d[100168+n|0]|0)+k|0,0);p=c}else{q=c+1|0;b[j+(q<<1)>>1]=o;o=d[100168+n|0]|0;sNb(f,o+k|0,1);r=o+l|0;if((n|0)==(m|0)){s=4;break}sNb(f,r,0);p=q}o=n+1|0;if((o|0)==7){s=8;break}else{c=p;n=o}}if((s|0)==4){sNb(f,r,1);t=q;u=0}else if((s|0)==8){s=p+1|0;b[j+(s<<1)>>1]=b[g+14>>1]|0;t=s;u=0}while(1){s=b[j+(t<<1)>>1]|0;g=s<<16>>16;p=s<<16>>16>-1?g:-g|0;s=g>>31;g=(d[1648656+u|0]|0)+a|0;if((p|0)>1){sNb(f,g,1);q=(d[1648592+u|0]|0)+a|0;r=(p|0)<15;n=r?p-2|0:13;if((n|0)>0){c=n;do{sNb(f,q,1);c=c-1|0;}while((c|0)>0)}if(r){sNb(f,q,0)}else{uNb(f,0,p-15|0)}v=1648632+u|0}else{sNb(f,g,0);v=1648624+u|0}c=d[v]|0;tNb(f,s);if((t|0)>0){t=t-1|0;u=c}else{break}}i=h;return}function eVb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;if(e>>>0<2>>>0){sNb(b,f,0);return}if((e|0)==3){sNb(b,f,1);wNb(a,b);return}e=d[95176+(c[a+19368>>2]|0)|0]|0;sNb(b,f,1);vNb(b);sNb(b,g,(c[a+19360>>2]|0)!=0|0);g=a+19364|0;if((c[g>>2]|0)==0){sNb(b,h,0)}else{sNb(b,h,1);sNb(b,i,c[g>>2]>>1)}sNb(b,j,e>>>1);sNb(b,k,e&1);return}function fVb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[19056+f|0]|0;f=g-1|0;h=g-8|0;if((a[b+28104+(e*40|0)+f|0]|0)>0){i=(a[b+28672+f|0]|0)==0|0}else{i=0}if((a[b+28104+(e*40|0)+h|0]|0)>0){j=(a[b+28672+h|0]|0)==0?i|2:i}else{j=i}i=a[b+28104+(e*40|0)+g|0]|0;g=j+54|0;if(!(i<<24>>24>0)){k=g;sNb(c,k,0);return}e=j;j=i<<24>>24;i=g;while(1){sNb(c,i,1);g=e>>2;b=j-1|0;h=g+58|0;if((b|0)>0){e=g+4|0;j=b;i=h}else{k=h;break}}sNb(c,k,0);return}function gVb(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+8|0;j=h|0;k=j|0;dQb(a,e,f,g,k);g=d[19056+f|0]|0;f=b[a+28192+(e*160|0)+(g<<2)>>1]|0;l=b[k>>1]|0;k=(f<<16>>16)-(l<<16>>16)|0;m=b[a+28192+(e*160|0)+(g<<2)+2>>1]|0;n=b[j+2>>1]|0;j=(m<<16>>16)-(n<<16>>16)|0;o=g-1|0;p=g-8|0;g=(d[a+28512+(e*80|0)+(p<<1)|0]|0)+(d[a+28512+(e*80|0)+(o<<1)|0]|0)|0;q=(d[a+28512+(e*80|0)+(p<<1)+1|0]|0)+(d[a+28512+(e*80|0)+(o<<1)+1|0]|0)|0;o=(((g|0)>2)+((g|0)>32)&65535)+((((q|0)>2)+((q|0)>32)&65535)<<8)&65535;q=o&255;if(f<<16>>16==l<<16>>16){sNb(c,q+40|0,0);r=0}else{l=(k|0)>-1?k:-k|0;sNb(c,q+40|0,1);if((l|0)<9){if((l|0)>1){q=1;do{sNb(c,(d[101128+(q-1)|0]|0)+40|0,1);q=q+1|0;}while((q|0)<(l|0))}sNb(c,(d[101128+(l-1)|0]|0)+40|0,0)}else{sNb(c,43,1);sNb(c,44,1);sNb(c,45,1);sNb(c,46,1);sNb(c,46,1);sNb(c,46,1);sNb(c,46,1);sNb(c,46,1);uNb(c,3,l-9|0)}tNb(c,k>>31);r=(l|0)<66?l:66}l=o>>>8;if(m<<16>>16==n<<16>>16){sNb(c,l+47|0,0);s=0;t=s+r|0;u=t&65535;i=h;return u|0}n=(j|0)>-1?j:-j|0;sNb(c,l+47|0,1);if((n|0)<9){if((n|0)>1){l=1;do{sNb(c,(d[101128+(l-1)|0]|0)+47|0,1);l=l+1|0;}while((l|0)<(n|0))}sNb(c,(d[101128+(n-1)|0]|0)+47|0,0)}else{sNb(c,50,1);sNb(c,51,1);sNb(c,52,1);sNb(c,53,1);sNb(c,53,1);sNb(c,53,1);sNb(c,53,1);sNb(c,53,1);uNb(c,3,n-9|0)}tNb(c,j>>31);s=(n|0)<66?n<<8:16896;t=s+r|0;u=t&65535;i=h;return u|0}function hVb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d[19056+e|0]|0;e=(a[f-1+(b+28104)|0]|0)>0|0;g=(a[f-8+(b+28104)|0]|0)>0?e|2:e;e=a[b+28104+f|0]|0;f=g+54|0;if(!(e<<24>>24>0)){h=f;sNb(c,h,0);return}b=g;g=e<<24>>24;e=f;while(1){sNb(c,e,1);f=b>>2;i=g-1|0;j=f+58|0;if((i|0)>0){b=f+4|0;g=i;e=j}else{h=j;break}}sNb(c,h,0);return}function iVb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0;e=b+19344|0;f=c[e>>2]|0;g=(c[b+8632>>2]|0)==3;h=g?3:1;i=g&1^1;j=b+1500|0;k=b+1504|0;l=c[k>>2]|0;m=b+1516|0;n=c[m>>2]|0;o=(l-(c[j>>2]|0)<<3)+(32-n)|0;do{if((c[b+3260>>2]|0)==0){p=n;q=l}else{if((c[b+18612>>2]&1|0)!=0){r=a[(c[b+18956>>2]|0)+((c[b+18616>>2]|0)-(c[b+18580>>2]|0))|0]|0;if(!((r<<24>>24|0)==6|(r<<24>>24|0)==18)){p=n;q=l;break}}r=b+18660|0;s=c[r>>2]|0;t=b+1512|0;u=c[t>>2]<<1|s;c[t>>2]=u;t=n-1|0;c[m>>2]=t;if((t|0)==0){c[l>>2]=je(u|0)|0;u=(c[k>>2]|0)+4|0;c[k>>2]=u;c[m>>2]=32;v=32;w=u;x=c[r>>2]|0}else{v=t;w=l;x=s}c[b+18948>>2]=x;p=v;q=w}}while(0);if((f|0)==3){w=c[j>>2]|0;v=(d[95456+(c[b+3240>>2]|0)|0]|0)+26|0;x=d[16208+v|0]|0;if((p|0)>(x|0)){l=b+1512|0;n=c[l>>2]<<x|v;c[l>>2]=n;y=p-x|0;z=w;A=q;B=n}else{n=x-p|0;x=b+1512|0;c[q>>2]=je(c[x>>2]<<p|v>>>(n>>>0)|0)|0;l=(c[k>>2]|0)+4|0;c[k>>2]=l;c[x>>2]=v;y=32-n|0;z=c[j>>2]|0;A=l;B=v}c[m>>2]=y;v=(A-z<<3)+(32-y)|0;z=b+30504|0;c[z>>2]=(c[z>>2]|0)-o+v;z=y&7;l=b+1512|0;if((y|0)>(z|0)){n=B<<z;c[l>>2]=n;C=y;D=n;E=A}else{c[A>>2]=je(B<<y|0)|0;B=(c[k>>2]|0)+4|0;c[k>>2]=B;c[l>>2]=0;C=y+32|0;D=0;E=B}B=C-z|0;c[m>>2]=B;c[E>>2]=je(D<<(B&31)|0)|0;B=(c[k>>2]|0)+(4-(c[m>>2]>>3))|0;c[k>>2]=B;c[m>>2]=32;D=0;E=32;z=B;while(1){B=b+24544+(D<<2)|0;C=0;y=E;A=z;while(1){n=d[(c[B>>2]|0)+C|0]|0;if((y|0)>8){x=c[l>>2]<<8|n;c[l>>2]=x;F=y-8|0;G=A;H=x}else{x=8-y|0;c[A>>2]=je(c[l>>2]<<y|n>>>(x>>>0)|0)|0;s=(c[k>>2]|0)+4|0;c[k>>2]=s;c[l>>2]=n;F=32-x|0;G=s;H=n}c[m>>2]=F;n=C+1|0;if((n|0)<256){C=n;y=F;A=G}else{break}}A=D+1|0;if((A|0)<(h|0)){D=A;E=F;z=G}else{break}}do{if(g){I=G}else{z=b+18576|0;E=c[z>>2]|0;if((16>>>(E>>>0)|0)>0){D=b+24548|0;A=0;y=G;C=F;B=H;while(1){n=A<<4;s=0;x=y;t=C;r=B;while(1){u=d[(c[D>>2]|0)+(s+n)|0]|0;if((t|0)>8){J=r<<8|u;c[l>>2]=J;K=t-8|0;L=x;M=J}else{J=8-t|0;c[x>>2]=je(r<<t|u>>>(J>>>0)|0)|0;N=(c[k>>2]|0)+4|0;c[k>>2]=N;c[l>>2]=u;K=32-J|0;L=N;M=u}c[m>>2]=K;u=s+1|0;if((u|0)<8){s=u;x=L;t=K;r=M}else{break}}r=A+1|0;t=c[z>>2]|0;if((r|0)<(16>>>(t>>>0)|0)){A=r;y=L;C=K;B=M}else{O=L;P=t;Q=K;R=M;break}}}else{O=G;P=E;Q=F;R=H}if((16>>>(P>>>0)|0)<=0){I=O;break}B=b+24552|0;C=0;y=O;A=Q;D=R;while(1){t=C<<4;r=0;x=y;s=A;n=D;while(1){u=d[(c[B>>2]|0)+(r+t)|0]|0;if((s|0)>8){N=n<<8|u;c[l>>2]=N;S=s-8|0;T=x;U=N}else{N=8-s|0;c[x>>2]=je(n<<s|u>>>(N>>>0)|0)|0;J=(c[k>>2]|0)+4|0;c[k>>2]=J;c[l>>2]=u;S=32-N|0;T=J;U=u}c[m>>2]=S;u=r+1|0;if((u|0)<8){r=u;x=T;s=S;n=U}else{break}}n=C+1|0;if((n|0)<(16>>>((c[z>>2]|0)>>>0)|0)){C=n;y=T;A=S;D=U}else{I=T;break}}}}while(0);T=b+1508|0;U=I;S=(c[T>>2]|0)-U|0;R=U&3;U=I+(-R|0)|0;c[j>>2]=U;c[k>>2]=U;c[T>>2]=I+S;S=4-R<<3;c[m>>2]=S;c[l>>2]=(je(c[U>>2]|0)|0)>>>(S>>>0);c[j>>2]=w;l=b+30508|0;c[l>>2]=32-v-S+(c[l>>2]|0)+(U-w<<3);return}w=c[b+3240>>2]|0;do{if((w|0)==0){if((f|0)==5){U=b+28116|0;l=b+28118|0;S=b+28132|0;v=b+28134|0;R=(p|0)>5;do{if((a[l]|a[U]|a[S]|a[v])<<24>>24==0){if(R){I=b+1512|0;T=c[I>>2]<<5|5;c[I>>2]=T;V=0;W=p-5|0;X=T;Y=q;break}else{T=5-p|0;I=b+1512|0;c[q>>2]=je(c[I>>2]<<p|5>>>(T>>>0)|0)|0;Q=(c[k>>2]|0)+4|0;c[k>>2]=Q;c[I>>2]=5;V=0;W=32-T|0;X=5;Y=Q;break}}else{if(R){Q=b+1512|0;T=c[Q>>2]<<5|4;c[Q>>2]=T;V=1;W=p-5|0;X=T;Y=q;break}else{T=5-p|0;Q=b+1512|0;c[q>>2]=je(c[Q>>2]<<p|4>>>(T>>>0)|0)|0;I=(c[k>>2]|0)+4|0;c[k>>2]=I;c[Q>>2]=4;V=1;W=32-T|0;X=4;Y=I;break}}}while(0);c[m>>2]=W;do{if((c[b+520>>2]&32|0)==0){if((W|0)>4){R=X<<4|15;c[b+1512>>2]=R;Z=R;_=W-4|0;$=Y;break}else{R=4-W|0;c[Y>>2]=je(15>>>(R>>>0)|X<<W|0)|0;I=(c[k>>2]|0)+4|0;c[k>>2]=I;c[b+1512>>2]=15;Z=15;_=32-R|0;$=I;break}}else{I=b+1512|0;R=(d[552744+(d[b+19352|0]|0)|0]|0)+1|0;T=d[16208+R|0]|0;if((W|0)>(T|0)){Q=X<<T|R;c[I>>2]=Q;aa=W-T|0;ba=Q;ca=Y}else{Q=T-W|0;c[Y>>2]=je(R>>>(Q>>>0)|X<<W|0)|0;T=(c[k>>2]|0)+4|0;c[k>>2]=T;c[I>>2]=R;aa=32-Q|0;ba=R;ca=T}c[m>>2]=aa;T=(d[552744+(d[b+19353|0]|0)|0]|0)+1|0;R=d[16208+T|0]|0;if((aa|0)>(R|0)){Q=ba<<R|T;c[I>>2]=Q;da=aa-R|0;ea=Q;fa=ca}else{Q=R-aa|0;c[ca>>2]=je(T>>>(Q>>>0)|ba<<aa|0)|0;R=(c[k>>2]|0)+4|0;c[k>>2]=R;c[I>>2]=T;da=32-Q|0;ea=T;fa=R}c[m>>2]=da;R=(d[552744+(d[b+19354|0]|0)|0]|0)+1|0;T=d[16208+R|0]|0;if((da|0)>(T|0)){Q=ea<<T|R;c[I>>2]=Q;ga=da-T|0;ha=Q;ia=fa}else{Q=T-da|0;c[fa>>2]=je(R>>>(Q>>>0)|ea<<da|0)|0;T=(c[k>>2]|0)+4|0;c[k>>2]=T;c[I>>2]=R;ga=32-Q|0;ha=R;ia=T}c[m>>2]=ga;T=(d[552744+(d[b+19355|0]|0)|0]|0)+1|0;R=d[16208+T|0]|0;if((ga|0)>(R|0)){Q=ha<<R|T;c[I>>2]=Q;Z=Q;_=ga-R|0;$=ia;break}else{Q=R-ga|0;c[ia>>2]=je(T>>>(Q>>>0)|ha<<ga|0)|0;R=(c[k>>2]|0)+4|0;c[k>>2]=R;c[I>>2]=T;Z=T;_=32-Q|0;$=R;break}}}while(0);c[m>>2]=_;do{if((V|0)==0){ja=0}else{R=b+24580|0;Q=a[U]|0;do{if((c[R>>2]|0)==2){T=(Q|Z<<1)^1;c[b+1512>>2]=T;I=_-1|0;c[m>>2]=I;if((I|0)!=0){ka=I;la=$;break}c[$>>2]=je(T|0)|0;T=(c[k>>2]|0)+4|0;c[k>>2]=T;c[m>>2]=32;ka=32;la=T}else{T=Q+1|0;I=d[16208+T|0]|0;if((_|0)>(I|0)){c[b+1512>>2]=Z<<I|T;ma=_-I|0;na=$}else{O=I-_|0;c[$>>2]=je(T>>>(O>>>0)|Z<<_|0)|0;I=(c[k>>2]|0)+4|0;c[k>>2]=I;c[b+1512>>2]=T;ma=32-O|0;na=I}c[m>>2]=ma;ka=ma;la=na}}while(0);Q=a[l]|0;do{if((c[R>>2]|0)==2){I=b+1512|0;O=(c[I>>2]<<1|Q)^1;c[I>>2]=O;I=ka-1|0;c[m>>2]=I;if((I|0)!=0){oa=I;pa=la;break}c[la>>2]=je(O|0)|0;O=(c[k>>2]|0)+4|0;c[k>>2]=O;c[m>>2]=32;oa=32;pa=O}else{O=Q+1|0;I=d[16208+O|0]|0;if((ka|0)>(I|0)){T=b+1512|0;c[T>>2]=c[T>>2]<<I|O;qa=ka-I|0;ra=la}else{T=I-ka|0;I=b+1512|0;c[la>>2]=je(c[I>>2]<<ka|O>>>(T>>>0)|0)|0;P=(c[k>>2]|0)+4|0;c[k>>2]=P;c[I>>2]=O;qa=32-T|0;ra=P}c[m>>2]=qa;oa=qa;pa=ra}}while(0);Q=a[S]|0;do{if((c[R>>2]|0)==2){P=b+1512|0;T=(c[P>>2]<<1|Q)^1;c[P>>2]=T;P=oa-1|0;c[m>>2]=P;if((P|0)!=0){sa=P;ta=pa;break}c[pa>>2]=je(T|0)|0;T=(c[k>>2]|0)+4|0;c[k>>2]=T;c[m>>2]=32;sa=32;ta=T}else{T=Q+1|0;P=d[16208+T|0]|0;if((oa|0)>(P|0)){O=b+1512|0;c[O>>2]=c[O>>2]<<P|T;ua=oa-P|0;va=pa}else{O=P-oa|0;P=b+1512|0;c[pa>>2]=je(c[P>>2]<<oa|T>>>(O>>>0)|0)|0;I=(c[k>>2]|0)+4|0;c[k>>2]=I;c[P>>2]=T;ua=32-O|0;va=I}c[m>>2]=ua;sa=ua;ta=va}}while(0);Q=a[v]|0;if((c[R>>2]|0)==2){I=b+1512|0;O=(c[I>>2]<<1|Q)^1;c[I>>2]=O;I=sa-1|0;c[m>>2]=I;if((I|0)!=0){ja=0;break}c[ta>>2]=je(O|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[m>>2]=32;ja=0;break}O=Q+1|0;Q=d[16208+O|0]|0;if((sa|0)>(Q|0)){I=b+1512|0;c[I>>2]=c[I>>2]<<Q|O;wa=sa-Q|0}else{I=Q-sa|0;Q=b+1512|0;c[ta>>2]=je(c[Q>>2]<<sa|O>>>(I>>>0)|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[Q>>2]=O;wa=32-I|0}c[m>>2]=wa;ja=0}}while(0);do{v=d[b+19352+ja|0]|0;if((v|0)==3){nVb(b,0,ja<<2,2)}else if((v|0)==1){S=ja<<2;nVb(b,0,S,2);nVb(b,0,S|2,2)}else if((v|0)==2){S=ja<<2;nVb(b,0,S,1);nVb(b,0,S|1,1)}else if((v|0)==0){v=ja<<2;nVb(b,0,v,1);nVb(b,0,v|1,1);nVb(b,0,v|2,1);nVb(b,0,v|3,1)}ja=ja+1|0;}while((ja|0)<4)}else if((f|0)==4){v=c[b+19348>>2]|0;if((v|0)==15){if((p|0)>3){S=b+1512|0;l=c[S>>2]<<3|3;c[S>>2]=l;xa=p-3|0;ya=l;za=q}else{l=3-p|0;S=b+1512|0;c[q>>2]=je(c[S>>2]<<p|3>>>(l>>>0)|0)|0;U=(c[k>>2]|0)+4|0;c[k>>2]=U;c[S>>2]=3;xa=32-l|0;ya=3;za=U}c[m>>2]=xa;U=b+24580|0;l=c[U>>2]|0;do{if((l|0)>1){S=a[b+28116|0]|0;do{if((l|0)==2){I=(S|ya<<1)^1;c[b+1512>>2]=I;O=xa-1|0;c[m>>2]=O;if((O|0)!=0){Aa=O;Ba=za;break}c[za>>2]=je(I|0)|0;I=(c[k>>2]|0)+4|0;c[k>>2]=I;c[m>>2]=32;Aa=32;Ba=I}else{I=S+1|0;O=d[16208+I|0]|0;if((xa|0)>(O|0)){c[b+1512>>2]=ya<<O|I;Ca=xa-O|0;Da=za}else{Q=O-xa|0;c[za>>2]=je(I>>>(Q>>>0)|ya<<xa|0)|0;O=(c[k>>2]|0)+4|0;c[k>>2]=O;c[b+1512>>2]=I;Ca=32-Q|0;Da=O}c[m>>2]=Ca;Aa=Ca;Ba=Da}}while(0);S=a[b+28118|0]|0;if((c[U>>2]|0)==2){R=b+1512|0;O=(c[R>>2]<<1|S)^1;c[R>>2]=O;R=Aa-1|0;c[m>>2]=R;if((R|0)!=0){break}c[Ba>>2]=je(O|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[m>>2]=32;break}O=S+1|0;S=d[16208+O|0]|0;if((Aa|0)>(S|0)){R=b+1512|0;c[R>>2]=c[R>>2]<<S|O;Ea=Aa-S|0}else{R=S-Aa|0;S=b+1512|0;c[Ba>>2]=je(c[S>>2]<<Aa|O>>>(R>>>0)|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[S>>2]=O;Ea=32-R|0}c[m>>2]=Ea}}while(0);nVb(b,0,0,2);nVb(b,0,4,2);break}else if((v|0)==14){if((p|0)>3){U=b+1512|0;l=c[U>>2]<<3|2;c[U>>2]=l;Fa=p-3|0;Ga=l;Ha=q}else{l=3-p|0;U=b+1512|0;c[q>>2]=je(c[U>>2]<<p|2>>>(l>>>0)|0)|0;R=(c[k>>2]|0)+4|0;c[k>>2]=R;c[U>>2]=2;Fa=32-l|0;Ga=2;Ha=R}c[m>>2]=Fa;R=b+24580|0;l=c[R>>2]|0;do{if((l|0)>1){U=a[b+28116|0]|0;do{if((l|0)==2){O=(U|Ga<<1)^1;c[b+1512>>2]=O;S=Fa-1|0;c[m>>2]=S;if((S|0)!=0){Ia=S;Ja=Ha;break}c[Ha>>2]=je(O|0)|0;O=(c[k>>2]|0)+4|0;c[k>>2]=O;c[m>>2]=32;Ia=32;Ja=O}else{O=U+1|0;S=d[16208+O|0]|0;if((Fa|0)>(S|0)){c[b+1512>>2]=Ga<<S|O;Ka=Fa-S|0;La=Ha}else{Q=S-Fa|0;c[Ha>>2]=je(O>>>(Q>>>0)|Ga<<Fa|0)|0;S=(c[k>>2]|0)+4|0;c[k>>2]=S;c[b+1512>>2]=O;Ka=32-Q|0;La=S}c[m>>2]=Ka;Ia=Ka;Ja=La}}while(0);U=a[b+28132|0]|0;if((c[R>>2]|0)==2){S=b+1512|0;Q=(c[S>>2]<<1|U)^1;c[S>>2]=Q;S=Ia-1|0;c[m>>2]=S;if((S|0)!=0){break}c[Ja>>2]=je(Q|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[m>>2]=32;break}Q=U+1|0;U=d[16208+Q|0]|0;if((Ia|0)>(U|0)){S=b+1512|0;c[S>>2]=c[S>>2]<<U|Q;Ma=Ia-U|0}else{S=U-Ia|0;U=b+1512|0;c[Ja>>2]=je(c[U>>2]<<Ia|Q>>>(S>>>0)|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[U>>2]=Q;Ma=32-S|0}c[m>>2]=Ma}}while(0);nVb(b,0,0,4);nVb(b,0,8,4);break}else if((v|0)==16){R=b+1512|0;l=c[R>>2]<<1|1;c[R>>2]=l;S=p-1|0;c[m>>2]=S;if((S|0)==0){c[q>>2]=je(l|0)|0;l=(c[k>>2]|0)+4|0;c[k>>2]=l;c[m>>2]=32;Na=32;Oa=l}else{Na=S;Oa=q}S=c[b+24580>>2]|0;do{if((S|0)>1){l=a[b+28116|0]|0;if((S|0)==2){Q=(c[R>>2]<<1|l)^1;c[R>>2]=Q;U=Na-1|0;c[m>>2]=U;if((U|0)!=0){break}c[Oa>>2]=je(Q|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[m>>2]=32;break}Q=l+1|0;l=d[16208+Q|0]|0;if((Na|0)>(l|0)){c[R>>2]=c[R>>2]<<l|Q;Pa=Na-l|0}else{U=l-Na|0;c[Oa>>2]=je(c[R>>2]<<Na|Q>>>(U>>>0)|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[R>>2]=Q;Pa=32-U|0}c[m>>2]=Pa}}while(0);nVb(b,0,0,4);break}else{break}}else{jVb(b,f,5,i);break}}else if((w|0)==1){if((f|0)==17){if((p|0)>9){R=b+1512|0;S=c[R>>2]<<9|23;c[R>>2]=S;Qa=p-9|0;Ra=S;Sa=q}else{S=9-p|0;R=b+1512|0;c[q>>2]=je(c[R>>2]<<p|23>>>(S>>>0)|0)|0;v=(c[k>>2]|0)+4|0;c[k>>2]=v;c[R>>2]=23;Qa=32-S|0;Ra=23;Sa=v}c[m>>2]=Qa;v=b+1512|0;S=b+19352|0;R=(d[552760+(d[S]|0)|0]|0)+1|0;U=d[16208+R|0]|0;if((Qa|0)>(U|0)){Q=Ra<<U|R;c[v>>2]=Q;Ta=Qa-U|0;Ua=Q;Va=Sa}else{Q=U-Qa|0;c[Sa>>2]=je(R>>>(Q>>>0)|Ra<<Qa|0)|0;U=(c[k>>2]|0)+4|0;c[k>>2]=U;c[v>>2]=R;Ta=32-Q|0;Ua=R;Va=U}c[m>>2]=Ta;U=b+19353|0;R=(d[552760+(d[U]|0)|0]|0)+1|0;Q=d[16208+R|0]|0;if((Ta|0)>(Q|0)){l=Ua<<Q|R;c[v>>2]=l;Wa=Ta-Q|0;Xa=l;Ya=Va}else{l=Q-Ta|0;c[Va>>2]=je(R>>>(l>>>0)|Ua<<Ta|0)|0;Q=(c[k>>2]|0)+4|0;c[k>>2]=Q;c[v>>2]=R;Wa=32-l|0;Xa=R;Ya=Q}c[m>>2]=Wa;Q=b+19354|0;R=(d[552760+(d[Q]|0)|0]|0)+1|0;l=d[16208+R|0]|0;if((Wa|0)>(l|0)){O=Xa<<l|R;c[v>>2]=O;Za=Wa-l|0;_a=O;$a=Ya}else{O=l-Wa|0;c[Ya>>2]=je(R>>>(O>>>0)|Xa<<Wa|0)|0;l=(c[k>>2]|0)+4|0;c[k>>2]=l;c[v>>2]=R;Za=32-O|0;_a=R;$a=l}c[m>>2]=Za;l=b+19355|0;R=(d[552760+(d[l]|0)|0]|0)+1|0;O=d[16208+R|0]|0;if((Za|0)>(O|0)){c[v>>2]=_a<<O|R;ab=Za-O|0;bb=$a}else{I=O-Za|0;c[$a>>2]=je(R>>>(I>>>0)|_a<<Za|0)|0;O=(c[k>>2]|0)+4|0;c[k>>2]=O;c[v>>2]=R;ab=32-I|0;bb=O}c[m>>2]=ab;O=b+24580|0;if((c[O>>2]|0)>1){I=0;R=ab;T=bb;while(1){do{if((a[95216+(d[b+19352+I|0]|0)|0]|0)==0){cb=R;db=T}else{P=a[(d[19e3+(I<<2)|0]|0)+(b+28104)|0]|0;if((c[O>>2]|0)==2){H=(c[v>>2]<<1|P)^1;c[v>>2]=H;F=R-1|0;c[m>>2]=F;if((F|0)!=0){cb=F;db=T;break}c[T>>2]=je(H|0)|0;H=(c[k>>2]|0)+4|0;c[k>>2]=H;c[m>>2]=32;cb=32;db=H;break}H=P+1|0;P=d[16208+H|0]|0;if((R|0)>(P|0)){c[v>>2]=c[v>>2]<<P|H;eb=R-P|0;fb=T}else{F=P-R|0;c[T>>2]=je(c[v>>2]<<R|H>>>(F>>>0)|0)|0;P=(c[k>>2]|0)+4|0;c[k>>2]=P;c[v>>2]=H;eb=32-F|0;fb=P}c[m>>2]=eb;cb=eb;db=fb}}while(0);P=I+1|0;if((P|0)<4){I=P;R=cb;T=db}else{gb=cb;hb=db;break}}}else{gb=ab;hb=bb}T=b+24584|0;if((c[T>>2]|0)>1){R=0;I=gb;O=hb;while(1){do{if((a[95233+(d[b+19352+R|0]|0)|0]|0)==0){ib=I;jb=O}else{P=a[(d[19e3+(R<<2)|0]|0)+(b+28144)|0]|0;if((c[T>>2]|0)==2){F=(c[v>>2]<<1|P)^1;c[v>>2]=F;H=I-1|0;c[m>>2]=H;if((H|0)!=0){ib=H;jb=O;break}c[O>>2]=je(F|0)|0;F=(c[k>>2]|0)+4|0;c[k>>2]=F;c[m>>2]=32;ib=32;jb=F;break}F=P+1|0;P=d[16208+F|0]|0;if((I|0)>(P|0)){c[v>>2]=c[v>>2]<<P|F;kb=I-P|0;lb=O}else{H=P-I|0;c[O>>2]=je(c[v>>2]<<I|F>>>(H>>>0)|0)|0;P=(c[k>>2]|0)+4|0;c[k>>2]=P;c[v>>2]=F;kb=32-H|0;lb=P}c[m>>2]=kb;ib=kb;jb=lb}}while(0);P=R+1|0;if((P|0)<4){R=P;I=ib;O=jb}else{break}}}if((a[95216+(d[S]|0)|0]|0)!=0){nVb(b,0,0,2)}if((a[95216+(d[U]|0)|0]|0)!=0){nVb(b,0,4,2)}if((a[95216+(d[Q]|0)|0]|0)!=0){nVb(b,0,8,2)}if((a[95216+(d[l]|0)|0]|0)!=0){nVb(b,0,12,2)}if((a[95233+(d[S]|0)|0]|0)!=0){nVb(b,1,0,2)}if((a[95233+(d[U]|0)|0]|0)!=0){nVb(b,1,4,2)}if((a[95233+(d[Q]|0)|0]|0)!=0){nVb(b,1,8,2)}if((a[95233+(d[l]|0)|0]|0)==0){break}nVb(b,1,12,2);break}O=f-8|0;if(!(O>>>0<9>>>0)){if((f|0)!=7){jVb(b,f,23,i);break}I=b+1512|0;R=c[I>>2]<<1|1;c[I>>2]=R;I=p-1|0;c[m>>2]=I;if((I|0)!=0){break}c[q>>2]=je(R|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[m>>2]=32;break}R=94760+(f<<2)|0;I=(c[b+24580>>2]|0)-1|0;v=(c[b+24584>>2]|0)-1|0;T=b+19348|0;P=c[T>>2]|0;H=(d[832920+((P-14|0)*9|0)+O|0]|0)+1|0;O=d[16208+H|0]|0;if((p|0)>(O|0)){F=b+1512|0;G=c[F>>2]<<O|H;c[F>>2]=G;mb=p-O|0;nb=P;ob=G;pb=q}else{G=O-p|0;O=b+1512|0;c[q>>2]=je(c[O>>2]<<p|H>>>(G>>>0)|0)|0;P=(c[k>>2]|0)+4|0;c[k>>2]=P;c[O>>2]=H;mb=32-G|0;nb=c[T>>2]|0;ob=H;pb=P}c[m>>2]=mb;P=(I|0)!=0;if((nb|0)==16){do{if(P){if((a[R|0]|0)==0){qb=mb;rb=pb;break}H=a[b+28116|0]|0;if((I|0)==1){G=(H|ob<<1)^1;c[b+1512>>2]=G;O=mb-1|0;c[m>>2]=O;if((O|0)!=0){qb=O;rb=pb;break}c[pb>>2]=je(G|0)|0;G=(c[k>>2]|0)+4|0;c[k>>2]=G;c[m>>2]=32;qb=32;rb=G;break}G=H+1|0;H=d[16208+G|0]|0;if((mb|0)>(H|0)){c[b+1512>>2]=ob<<H|G;sb=mb-H|0;tb=pb}else{O=H-mb|0;c[pb>>2]=je(G>>>(O>>>0)|ob<<mb|0)|0;H=(c[k>>2]|0)+4|0;c[k>>2]=H;c[b+1512>>2]=G;sb=32-O|0;tb=H}c[m>>2]=sb;qb=sb;rb=tb}else{qb=mb;rb=pb}}while(0);do{if((v|0)!=0){if(!((f-11|0)>>>0<6>>>0)){break}l=a[b+28156|0]|0;if((v|0)==1){Q=b+1512|0;U=(c[Q>>2]<<1|l)^1;c[Q>>2]=U;Q=qb-1|0;c[m>>2]=Q;if((Q|0)!=0){break}c[rb>>2]=je(U|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[m>>2]=32;break}U=l+1|0;l=d[16208+U|0]|0;if((qb|0)>(l|0)){Q=b+1512|0;c[Q>>2]=c[Q>>2]<<l|U;ub=qb-l|0}else{Q=l-qb|0;l=b+1512|0;c[rb>>2]=je(c[l>>2]<<qb|U>>>(Q>>>0)|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[l>>2]=U;ub=32-Q|0}c[m>>2]=ub}}while(0);if((a[R|0]|0)!=0){nVb(b,0,0,4)}if(!((f-11|0)>>>0<6>>>0)){break}nVb(b,1,0,4);break}do{if(P){do{if((a[R|0]|0)==0){vb=mb;wb=pb}else{Q=a[b+28116|0]|0;if((I|0)==1){U=(Q|ob<<1)^1;c[b+1512>>2]=U;l=mb-1|0;c[m>>2]=l;if((l|0)!=0){vb=l;wb=pb;break}c[pb>>2]=je(U|0)|0;U=(c[k>>2]|0)+4|0;c[k>>2]=U;c[m>>2]=32;vb=32;wb=U;break}U=Q+1|0;Q=d[16208+U|0]|0;if((mb|0)>(Q|0)){c[b+1512>>2]=ob<<Q|U;xb=mb-Q|0;yb=pb}else{l=Q-mb|0;c[pb>>2]=je(U>>>(l>>>0)|ob<<mb|0)|0;Q=(c[k>>2]|0)+4|0;c[k>>2]=Q;c[b+1512>>2]=U;xb=32-l|0;yb=Q}c[m>>2]=xb;vb=xb;wb=yb}}while(0);if((93520>>>(f>>>0)&1|0)==0){zb=vb;Ab=wb;break}Q=a[b+28134|0]|0;if((I|0)==1){l=b+1512|0;U=(c[l>>2]<<1|Q)^1;c[l>>2]=U;l=vb-1|0;c[m>>2]=l;if((l|0)!=0){zb=l;Ab=wb;break}c[wb>>2]=je(U|0)|0;U=(c[k>>2]|0)+4|0;c[k>>2]=U;c[m>>2]=32;zb=32;Ab=U;break}U=Q+1|0;Q=d[16208+U|0]|0;if((vb|0)>(Q|0)){l=b+1512|0;c[l>>2]=c[l>>2]<<Q|U;Bb=vb-Q|0;Cb=wb}else{l=Q-vb|0;Q=b+1512|0;c[wb>>2]=je(c[Q>>2]<<vb|U>>>(l>>>0)|0)|0;S=(c[k>>2]|0)+4|0;c[k>>2]=S;c[Q>>2]=U;Bb=32-l|0;Cb=S}c[m>>2]=Bb;zb=Bb;Ab=Cb}else{zb=mb;Ab=pb}}while(0);do{if((v|0)!=0){do{if((f-11|0)>>>0<6>>>0){I=a[b+28156|0]|0;if((v|0)==1){P=b+1512|0;S=(c[P>>2]<<1|I)^1;c[P>>2]=S;P=zb-1|0;c[m>>2]=P;if((P|0)!=0){Db=P;Eb=Ab;break}c[Ab>>2]=je(S|0)|0;S=(c[k>>2]|0)+4|0;c[k>>2]=S;c[m>>2]=32;Db=32;Eb=S;break}S=I+1|0;I=d[16208+S|0]|0;if((zb|0)>(I|0)){P=b+1512|0;c[P>>2]=c[P>>2]<<I|S;Fb=zb-I|0;Gb=Ab}else{P=I-zb|0;I=b+1512|0;c[Ab>>2]=je(c[I>>2]<<zb|S>>>(P>>>0)|0)|0;l=(c[k>>2]|0)+4|0;c[k>>2]=l;c[I>>2]=S;Fb=32-P|0;Gb=l}c[m>>2]=Fb;Db=Fb;Eb=Gb}else{Db=zb;Eb=Ab}}while(0);if((112128>>>(f>>>0)&1|0)==0){break}l=a[b+28174|0]|0;if((v|0)==1){P=b+1512|0;S=(c[P>>2]<<1|l)^1;c[P>>2]=S;P=Db-1|0;c[m>>2]=P;if((P|0)!=0){break}c[Eb>>2]=je(S|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[m>>2]=32;break}S=l+1|0;l=d[16208+S|0]|0;if((Db|0)>(l|0)){P=b+1512|0;c[P>>2]=c[P>>2]<<l|S;Hb=Db-l|0}else{P=l-Db|0;l=b+1512|0;c[Eb>>2]=je(c[l>>2]<<Db|S>>>(P>>>0)|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[l>>2]=S;Hb=32-P|0}c[m>>2]=Hb}}while(0);v=(a[R|0]|0)!=0;if((c[T>>2]|0)==14){if(v){nVb(b,0,0,4)}if((93520>>>(f>>>0)&1|0)!=0){nVb(b,0,8,4)}if(!((f-11|0)>>>0>5>>>0)){nVb(b,1,0,4)}if((112128>>>(f>>>0)&1|0)==0){break}nVb(b,1,8,4);break}else{if(v){nVb(b,0,0,2)}if((93520>>>(f>>>0)&1|0)!=0){nVb(b,0,4,2)}if(!((f-11|0)>>>0>5>>>0)){nVb(b,1,0,2)}if((112128>>>(f>>>0)&1|0)==0){break}nVb(b,1,4,2);break}}else{jVb(b,f,0,i)}}while(0);Hb=c[k>>2]|0;Db=c[m>>2]|0;Eb=(Hb-(c[j>>2]|0)<<3)+(32-Db)|0;Ab=b+30504|0;c[Ab>>2]=(c[Ab>>2]|0)-o+Eb;o=(f|0)==2;if(o){Ib=Db;Jb=Hb}else{Ab=(d[(c[b+19364>>2]<<4|c[b+19360>>2])+(1722048+(i*96|0)+((f>>>0<3>>>0|0)*48|0))|0]|0)+1|0;f=d[16208+Ab|0]|0;if((Db|0)>(f|0)){i=b+1512|0;c[i>>2]=c[i>>2]<<f|Ab;Kb=Db-f|0;Lb=Hb}else{i=f-Db|0;f=b+1512|0;c[Hb>>2]=je(c[f>>2]<<Db|Ab>>>(i>>>0)|0)|0;Db=(c[k>>2]|0)+4|0;c[k>>2]=Db;c[f>>2]=Ab;Kb=32-i|0;Lb=Db}c[m>>2]=Kb;Ib=Kb;Jb=Lb}do{if((c[b+8696>>2]|0)!=0){Lb=c[e>>2]|0;if((Lb|0)==5){Mb=(c[b+19352>>2]|0)==50529027|0}else{Mb=d[17888+Lb|0]|0}if((Mb|0)==0){break}if((c[b+19360>>2]|0)==0){break}Lb=b+1512|0;Kb=c[Lb>>2]<<1|c[b+19356>>2];c[Lb>>2]=Kb;Lb=Ib-1|0;c[m>>2]=Lb;if((Lb|0)!=0){break}c[Jb>>2]=je(Kb|0)|0;c[k>>2]=(c[k>>2]|0)+4;c[m>>2]=32}}while(0);do{if(o){kVb(b);Jb=b+1512|0;Ib=b+19360|0;Mb=0;do{e=Mb<<4;Kb=a[19e3+e|0]|0;Lb=Kb&255;Db=(d[Lb-8+(b+27984)|0]|0)+(d[Lb-1+(b+27984)|0]|0)|0;if((Db|0)<128){Nb=(Db+1|0)>>>1}else{Nb=Db}Db=d[1625056+(Nb&127)|0]|0;Lb=(d[Mb+19048|0]|0)+(b+27984)|0;if((a[Lb]|0)==0){i=d[100209+(Db<<1)|0]|0;Ab=d[100208+(Db<<1)|0]|0;f=c[m>>2]|0;if((f|0)>(i|0)){c[Jb>>2]=c[Jb>>2]<<i|Ab;Ob=f-i|0}else{Hb=i-f|0;i=je(c[Jb>>2]<<f|Ab>>>(Hb>>>0)|0)|0;c[c[k>>2]>>2]=i;c[k>>2]=(c[k>>2]|0)+4;c[Jb>>2]=Ab;Ob=32-Hb|0}c[m>>2]=Ob}else{a[Lb]=lVb(b,0,b+15360+(Mb<<5)|0,Db)|0}a:do{if((c[Ib>>2]|0)!=0){Db=e+16|0;Lb=e;Hb=Kb;while(1){Ab=Hb&255;i=(d[Ab-8+(b+27984)|0]|0)+(d[Ab-1+(b+27984)|0]|0)|0;if((i|0)<128){Pb=(i+1|0)>>>1}else{Pb=i}i=d[1625056+(Pb&127)|0]|0;f=b+27984+Ab|0;if((a[f]|0)==0){Ab=d[100209+(i<<1)|0]|0;zb=d[100208+(i<<1)|0]|0;Gb=c[m>>2]|0;if((Gb|0)>(Ab|0)){c[Jb>>2]=c[Jb>>2]<<Ab|zb;Qb=Gb-Ab|0}else{Fb=Ab-Gb|0;Ab=je(c[Jb>>2]<<Gb|zb>>>(Fb>>>0)|0)|0;c[c[k>>2]>>2]=Ab;c[k>>2]=(c[k>>2]|0)+4;c[Jb>>2]=zb;Qb=32-Fb|0}c[m>>2]=Qb}else{a[f]=lVb(b,1,b+17024+(Lb<<5)+2|0,i)|0}i=Lb+1|0;if((i|0)>=(Db|0)){break a}Lb=i;Hb=a[19e3+i|0]|0}}}while(0);Mb=Mb+1|0;}while((Mb|0)<(h|0));Rb=b+19364|0}else{Mb=b+19360|0;Jb=b+19364|0;if((c[Jb>>2]|c[Mb>>2]|0)==0){Rb=Jb;break}kVb(b);if((c[b+19356>>2]|0)!=0){Ib=b+37660|0;T=0;do{R=T<<4;Kb=T<<2;e=(d[19e3+R|0]|0)+(b+27984)|0;if((a[e]|0)!=0){ef[c[Ib>>2]&4095](b+17024+(R<<5)|0,b+15488+(Kb<<7)|0,e)}e=R|4;Hb=(d[19e3+e|0]|0)+(b+27984)|0;if((a[Hb]|0)!=0){ef[c[Ib>>2]&4095](b+17024+(e<<5)|0,b+15488+((Kb|1)<<7)|0,Hb)}Hb=R|8;e=(d[19e3+Hb|0]|0)+(b+27984)|0;if((a[e]|0)!=0){ef[c[Ib>>2]&4095](b+17024+(Hb<<5)|0,b+15488+((Kb|2)<<7)|0,e)}e=R|12;R=(d[19e3+e|0]|0)+(b+27984)|0;if((a[R]|0)!=0){ef[c[Ib>>2]&4095](b+17024+(e<<5)|0,b+15488+((Kb|3)<<7)|0,R)}T=T+1|0;}while((T|0)<(h|0))}T=b+1512|0;Ib=0;while(1){R=c[Mb>>2]|0;if((R|0)!=0){Kb=Ib<<4;e=0;Hb=R;while(1){R=d[98808+Hb|0]|0;Lb=R+e|0;Db=(Lb<<2)+Kb|0;i=0;do{f=Db+i|0;Fb=d[19e3+f|0]|0;zb=(d[Fb-8+(b+27984)|0]|0)+(d[Fb-1+(b+27984)|0]|0)|0;if((zb|0)<128){Sb=(zb+1|0)>>>1}else{Sb=zb}zb=d[1625056+(Sb&127)|0]|0;Ab=b+27984+Fb|0;if((a[Ab]|0)==0){Fb=d[100209+(zb<<1)|0]|0;Gb=d[100208+(zb<<1)|0]|0;pb=c[m>>2]|0;if((pb|0)>(Fb|0)){c[T>>2]=c[T>>2]<<Fb|Gb;Tb=pb-Fb|0}else{mb=Fb-pb|0;Fb=je(c[T>>2]<<pb|Gb>>>(mb>>>0)|0)|0;c[c[k>>2]>>2]=Fb;c[k>>2]=(c[k>>2]|0)+4;c[T>>2]=Gb;Tb=32-mb|0}c[m>>2]=Tb}else{a[Ab]=lVb(b,2,b+17024+(f<<5)|0,zb)|0}i=i+1|0;}while((i|0)<4);i=Hb>>R+1;if((i|0)==0){break}else{e=Lb+1|0;Hb=i}}}Hb=Ib+1|0;if((Hb|0)<(h|0)){Ib=Hb}else{Rb=Jb;break}}}}while(0);do{if((c[Rb>>2]|0)!=0){h=b+18576|0;Tb=5-(c[h>>2]|0)|0;Sb=b+28024|0;if((a[Sb]|0)==0){Qb=d[100209+(Tb<<1)|0]|0;Pb=d[100208+(Tb<<1)|0]|0;Ob=c[m>>2]|0;if((Ob|0)>(Qb|0)){Nb=b+1512|0;c[Nb>>2]=c[Nb>>2]<<Qb|Pb;Ub=Ob-Qb|0}else{Nb=Qb-Ob|0;Qb=b+1512|0;o=je(c[Qb>>2]<<Ob|Pb>>>(Nb>>>0)|0)|0;c[c[k>>2]>>2]=o;c[k>>2]=(c[k>>2]|0)+4;c[Qb>>2]=Pb;Ub=32-Nb|0}c[m>>2]=Ub}else{a[Sb]=lVb(b,3,b+15456|0,Tb)|0}Tb=5-(c[h>>2]|0)|0;Sb=b+28064|0;if((a[Sb]|0)==0){Nb=d[100209+(Tb<<1)|0]|0;Pb=d[100208+(Tb<<1)|0]|0;Qb=c[m>>2]|0;if((Qb|0)>(Nb|0)){o=b+1512|0;c[o>>2]=c[o>>2]<<Nb|Pb;Vb=Qb-Nb|0}else{o=Nb-Qb|0;Nb=b+1512|0;Ob=je(c[Nb>>2]<<Qb|Pb>>>(o>>>0)|0)|0;c[c[k>>2]>>2]=Ob;c[k>>2]=(c[k>>2]|0)+4;c[Nb>>2]=Pb;Vb=32-o|0}c[m>>2]=Vb}else{a[Sb]=lVb(b,3,b+15472|0,Tb)|0}if((c[Rb>>2]|0)!=2){break}Tb=8<<c[h>>2];h=b+1512|0;Sb=16;do{o=Sb+4|0;Pb=Sb;do{Nb=d[19e3+Pb|0]|0;Ob=(d[Nb-8+(b+27984)|0]|0)+(d[Nb-1+(b+27984)|0]|0)|0;if((Ob|0)<128){Wb=(Ob+1|0)>>>1}else{Wb=Ob}Ob=d[1625056+(Wb&127)|0]|0;Qb=b+27984+Nb|0;if((a[Qb]|0)==0){Nb=d[100209+(Ob<<1)|0]|0;Jb=d[100208+(Ob<<1)|0]|0;Ib=c[m>>2]|0;if((Ib|0)>(Nb|0)){c[h>>2]=c[h>>2]<<Nb|Jb;Xb=Ib-Nb|0}else{T=Nb-Ib|0;Nb=je(c[h>>2]<<Ib|Jb>>>(T>>>0)|0)|0;c[c[k>>2]>>2]=Nb;c[k>>2]=(c[k>>2]|0)+4;c[h>>2]=Jb;Xb=32-T|0}c[m>>2]=Xb}else{a[Qb]=lVb(b,4,b+17024+(Pb<<5)+2|0,Ob)|0}Pb=Pb+1|0;}while((Pb|0)<(o|0));Sb=Sb+Tb|0;}while((Sb|0)<48)}}while(0);Xb=b+30508|0;c[Xb>>2]=32-Eb-(c[m>>2]|0)+(c[Xb>>2]|0)+((c[k>>2]|0)-(c[j>>2]|0)<<3);return}function jVb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((e|0)==2){h=f+2+(d[95168+(c[b+19368>>2]|0)|0]|0)+(c[b+19364>>2]<<2)+((c[b+19360>>2]|0)==0?0:12)|0;i=d[16208+h|0]|0;j=b+1516|0;k=c[j>>2]|0;if((k|0)>(i|0)){l=b+1512|0;c[l>>2]=c[l>>2]<<i|h;m=k-i|0}else{l=i-k|0;i=b+1512|0;n=je(c[i>>2]<<k|h>>>(l>>>0)|0)|0;k=b+1504|0;c[c[k>>2]>>2]=n;c[k>>2]=(c[k>>2]|0)+4;c[i>>2]=h;m=32-l|0}c[j>>2]=m;o=m}else{m=(e|0)==1?4:1;e=f+1|0;f=d[16208+e|0]|0;j=b+1516|0;l=c[j>>2]|0;if((l|0)>(f|0)){h=b+1512|0;i=c[h>>2]<<f|e;c[h>>2]=i;p=l-f|0;q=i}else{i=f-l|0;f=b+1512|0;h=je(c[f>>2]<<l|e>>>(i>>>0)|0)|0;l=b+1504|0;c[c[l>>2]>>2]=h;c[l>>2]=(c[l>>2]|0)+4;c[f>>2]=e;p=32-i|0;q=e}c[j>>2]=p;do{if((c[b+8696>>2]|0)==0){r=p;s=b+1512|0}else{e=b+1512|0;i=q<<1|c[b+19356>>2];c[e>>2]=i;f=p-1|0;c[j>>2]=f;if((f|0)!=0){r=f;s=e;break}f=je(i|0)|0;i=b+1504|0;c[c[i>>2]>>2]=f;c[i>>2]=(c[i>>2]|0)+4;c[j>>2]=32;r=32;s=e}}while(0);p=b+1504|0;q=0;e=r;while(1){r=d[19e3+q|0]|0;i=a[(a[r-1+(b+27936)|0]|0)+95105|0]|0;f=a[(a[r-8+(b+27936)|0]|0)+95105|0]|0;l=i<<24>>24<f<<24>>24?i:f;f=l<<24>>24<0?2:l<<24>>24;l=a[(a[b+27936+r|0]|0)+95105|0]|0;do{if((f|0)==(l|0)){r=c[s>>2]<<1|1;c[s>>2]=r;i=e-1|0;c[j>>2]=i;if((i|0)!=0){t=i;break}i=je(r|0)|0;c[c[p>>2]>>2]=i;c[p>>2]=(c[p>>2]|0)+4;c[j>>2]=32;t=32}else{i=l-((l|0)>(f|0))|0;if((e|0)>4){c[s>>2]=c[s>>2]<<4|i;u=e-4|0}else{r=4-e|0;h=je(c[s>>2]<<e|i>>>(r>>>0)|0)|0;c[c[p>>2]>>2]=h;c[p>>2]=(c[p>>2]|0)+4;c[s>>2]=i;u=32-r|0}c[j>>2]=u;t=u}}while(0);f=q+m|0;if((f|0)<16){q=f;e=t}else{o=t;break}}}if((g|0)==0){return}g=(d[95344+(c[b+19372>>2]|0)|0]|0)+1|0;t=d[16208+g|0]|0;if((o|0)>(t|0)){e=b+1512|0;c[e>>2]=c[e>>2]<<t|g;v=o-t|0}else{e=t-o|0;t=b+1512|0;q=je(c[t>>2]<<o|g>>>(e>>>0)|0)|0;o=b+1504|0;c[c[o>>2]>>2]=q;c[o>>2]=(c[o>>2]|0)+4;c[t>>2]=g;v=32-e|0}c[b+1516>>2]=v;return}function kVb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+28816|0;f=c[e>>2]|0;g=c[b+28824>>2]|0;h=f-g|0;do{if((c[b+19344>>2]|0)==2){if((c[b+19364>>2]|c[b+19360>>2]|0)!=0){i=7;break}if((a[b+27984|0]|0)!=0){i=7;break}if((a[b+28024|0]|0)!=0){i=7;break}if(!((a[b+28064|0]|0)==0&(f|0)>(g|0))){i=7;break}c[e>>2]=g;j=0}else{i=7}}while(0);do{if((i|0)==7){if((f|0)==(g|0)){j=0;break}if((h|0)<-26){j=h+52|0;break}else{j=(h|0)>25?h-52|0:h;break}}}while(0);h=j<<1;j=1-h|0;g=(j|0)<0?h:j;j=(g|0)>255;h=(j?16:0)+(d[16208+(j?g>>8:g)|0]|0)|0;j=b+1516|0;f=c[j>>2]|0;if((f|0)>(h|0)){i=b+1512|0;c[i>>2]=c[i>>2]<<h|g;k=f-h|0;c[j>>2]=k;return}else{i=h-f|0;h=b+1512|0;e=je(c[h>>2]<<f|g>>>(i>>>0)|0)|0;f=b+1504|0;c[c[f>>2]>>2]=e;c[f>>2]=(c[f>>2]|0)+4;c[h>>2]=g;k=32-i|0;c[j>>2]=k;return}}function lVb(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;j=i;i=i+64|0;k=j|0;l=We[c[a+37840+(f<<2)>>2]&2047](g,k)|0;g=k+4|0;m=1-l+(c[k>>2]|0)|0;b[k+16+(l<<1)>>1]=2;b[k+16+(l+1<<1)>>1]=2;n=b[k+16>>1]|0;o=b[k+18>>1]|0;p=b[k+20>>1]|0;q=(o+1|1-o)>>31&2|(n+1|1-n)>>>31|(p+1|1-p)>>31&4;r=d[100352+q|0]|0;s=(o>>31&2|n>>31&4|p>>>31)>>>((3-r|0)>>>0);p=l-1|0;n=d[99400+(h<<7)+(p<<3)+(r<<1)+1|0]|0;o=d[99400+(h<<7)+(p<<3)+(r<<1)|0]|0;h=a+1516|0;t=c[h>>2]|0;if((t|0)>(n|0)){u=a+1512|0;v=c[u>>2]<<n|o;c[u>>2]=v;w=t-n|0;x=v}else{v=n-t|0;n=a+1512|0;u=je(c[n>>2]<<t|o>>>(v>>>0)|0)|0;t=a+1504|0;c[c[t>>2]>>2]=u;c[t>>2]=(c[t>>2]|0)+4;c[n>>2]=o;w=32-v|0;x=o}c[h>>2]=w;if((l|0)>10){y=(q|0)!=0|0}else{y=0}if((w|0)>(r|0)){o=x<<r|s;c[a+1512>>2]=o;z=w-r|0;A=o}else{o=r-w|0;v=je(x<<w|s>>>(o>>>0)|0)|0;w=a+1504|0;c[c[w>>2]>>2]=v;c[w>>2]=(c[w>>2]|0)+4;c[a+1512>>2]=s;z=32-o|0;A=s}c[h>>2]=z;do{if((r|0)<(l|0)){s=b[k+16+(r<<1)>>1]|0;o=s+64|0;w=s-((s>>31|1)&-((q|0)!=0|0))|0;if(o>>>0<128>>>0){s=w+64|0;v=d[3035176+(y<<9)+(s<<2)+2|0]|0;x=e[3035176+(y<<9)+(s<<2)>>1]|0;if((z|0)>(v|0)){c[a+1512>>2]=A<<v|x;B=z-v|0}else{s=v-z|0;v=je(A<<z|x>>>(s>>>0)|0)|0;n=a+1504|0;c[c[n>>2]>>2]=v;c[n>>2]=(c[n>>2]|0)+4;c[a+1512>>2]=x;B=32-s|0}c[h>>2]=B;C=d[3035176+(y<<9)+(o<<2)+3|0]|0}else{C=mVb(a,y,w)|0}w=r+1|0;if((w|0)>=(l|0)){break}o=a+1512|0;s=a+1504|0;x=C;n=w;while(1){w=b[k+16+(n<<1)>>1]|0;v=w+64|0;if(v>>>0<128>>>0){t=d[3035176+(x<<9)+(v<<2)+2|0]|0;u=e[3035176+(x<<9)+(v<<2)>>1]|0;D=c[h>>2]|0;if((D|0)>(t|0)){c[o>>2]=c[o>>2]<<t|u;E=D-t|0}else{F=t-D|0;t=je(c[o>>2]<<D|u>>>(F>>>0)|0)|0;c[c[s>>2]>>2]=t;c[s>>2]=(c[s>>2]|0)+4;c[o>>2]=u;E=32-F|0}c[h>>2]=E;G=d[3035176+(x<<9)+(v<<2)+3|0]|0}else{G=mVb(a,x,w)|0}w=n+1|0;if((w|0)<(l|0)){x=G;n=w}else{break}}}}while(0);do{if((f|0)==3){if((l|0)>=(8>>>((c[a+18576>>2]|0)>>>0)|0)){break}if((c[a+8632>>2]|0)==1){H=18144+(p<<3)+(m<<1)|0;I=18144+(p<<3)+(m<<1)+1|0}else{H=18032+(p<<4)+(m<<1)|0;I=18032+(p<<4)+(m<<1)+1|0}G=d[I]|0;E=d[H]|0;k=c[h>>2]|0;if((k|0)>(G|0)){C=a+1512|0;c[C>>2]=c[C>>2]<<G|E;J=k-G|0}else{C=G-k|0;G=a+1512|0;r=je(c[G>>2]<<k|E>>>(C>>>0)|0)|0;k=a+1504|0;c[c[k>>2]>>2]=r;c[k>>2]=(c[k>>2]|0)+4;c[G>>2]=E;J=32-C|0}c[h>>2]=J}else{if(!((l&255)>>>0<(d[100368+f|0]|0)>>>0)){break}C=d[18168+(p<<5)+(m<<1)+1|0]|0;E=d[18168+(p<<5)+(m<<1)|0]|0;G=c[h>>2]|0;if((G|0)>(C|0)){k=a+1512|0;c[k>>2]=c[k>>2]<<C|E;K=G-C|0}else{k=C-G|0;C=a+1512|0;r=je(c[C>>2]<<G|E>>>(k>>>0)|0)|0;G=a+1504|0;c[c[G>>2]>>2]=r;c[G>>2]=(c[G>>2]|0)+4;c[C>>2]=E;K=32-k|0}c[h>>2]=K}}while(0);K=c[2772392+(c[g>>2]<<2)>>2]|0;g=K&31;m=K>>5;K=c[h>>2]|0;if((K|0)>(g|0)){p=a+1512|0;c[p>>2]=c[p>>2]<<g|m;L=K-g|0;c[h>>2]=L;i=j;return l|0}else{p=g-K|0;g=a+1512|0;f=je(c[g>>2]<<K|m>>>(p>>>0)|0)|0;K=a+1504|0;c[c[K>>2]>>2]=f;c[K>>2]=(c[K>>2]|0)+4;c[g>>2]=m;L=32-p|0;c[h>>2]=L;i=j;return l|0}return 0}function mVb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=e>>31;g=(f^e)-f|0;e=(g<<1)-f-2|0;f=e>>d;if((f|0)<15){h=d+1+f|0;f=1<<d;i=(e&f-1)+f|0;f=a+1516|0;j=c[f>>2]|0;if((j|0)>(h|0)){k=a+1512|0;c[k>>2]=c[k>>2]<<h|i;l=j-h|0}else{k=h-j|0;h=a+1512|0;m=je(c[h>>2]<<j|i>>>(k>>>0)|0)|0;j=a+1504|0;c[c[j>>2]>>2]=m;c[j>>2]=(c[j>>2]|0)+4;c[h>>2]=i;l=32-k|0}c[f>>2]=l;n=(d|0)==0;o=n&1;p=o+d|0;q=100400+(p<<1)|0;r=b[q>>1]|0;s=r&65535;t=(g|0)>(s|0);u=t&1;v=u+p|0;return v|0}l=e-(15<<d)|0;e=(d|0)==0?l-15|0:l;do{if((e|0)>4095){if((c[a+8372>>2]|0)<=99){c[a+19396>>2]=1;w=e;x=15;break}if((e|0)>4096){y=15;z=e;A=4096}else{w=4096;x=15;break}while(1){l=z-A|0;f=y+1|0;k=1<<y-2;if((l|0)>(k|0)){y=f;z=l;A=k}else{w=l;x=f;break}}}else{w=e;x=15}}while(0);e=x+1|0;A=a+1516|0;z=c[A>>2]|0;if((z|0)>(e|0)){y=a+1512|0;f=c[y>>2]<<e|1;c[y>>2]=f;B=z-e|0;C=f}else{f=e-z|0;e=a+1512|0;y=je(c[e>>2]<<z|1>>>(f>>>0)|0)|0;z=a+1504|0;c[c[z>>2]>>2]=y;c[z>>2]=(c[z>>2]|0)+4;c[e>>2]=1;B=32-f|0;C=1}c[A>>2]=B;f=x-3|0;x=(1<<f)-1&w;if((B|0)>(f|0)){c[a+1512>>2]=C<<f|x;D=B-f|0}else{w=f-B|0;f=je(C<<B|x>>>(w>>>0)|0)|0;B=a+1504|0;c[c[B>>2]>>2]=f;c[B>>2]=(c[B>>2]|0)+4;c[a+1512>>2]=x;D=32-w|0}c[A>>2]=D;n=(d|0)==0;o=n&1;p=o+d|0;q=100400+(p<<1)|0;r=b[q>>1]|0;s=r&65535;t=(g|0)>(s|0);u=t&1;v=u+p|0;return v|0}function nVb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+8|0;j=h|0;k=j|0;dQb(a,e,f,g,k);g=d[19e3+f|0]|0;f=(b[a+28192+(e*160|0)+(g<<2)>>1]|0)-(b[k>>1]|0)<<1;k=1-f|0;l=(k|0)<0?f:k;k=(l|0)>255;f=(k?16:0)+(d[16208+(k?l>>8:l)|0]|0)|0;k=a+1516|0;m=c[k>>2]|0;if((m|0)>(f|0)){n=a+1512|0;o=c[n>>2]<<f|l;c[n>>2]=o;p=m-f|0;q=o}else{o=f-m|0;f=a+1512|0;n=je(c[f>>2]<<m|l>>>(o>>>0)|0)|0;m=a+1504|0;c[c[m>>2]>>2]=n;c[m>>2]=(c[m>>2]|0)+4;c[f>>2]=l;p=32-o|0;q=l}c[k>>2]=p;l=(b[a+28192+(e*160|0)+(g<<2)+2>>1]|0)-(b[j+2>>1]|0)<<1;j=1-l|0;g=(j|0)<0?l:j;j=(g|0)>255;l=(j?16:0)+(d[16208+(j?g>>8:g)|0]|0)|0;if((p|0)>(l|0)){c[a+1512>>2]=q<<l|g;r=p-l|0;c[k>>2]=r;i=h;return}else{j=l-p|0;l=je(q<<p|g>>>(j>>>0)|0)|0;p=a+1504|0;c[c[p>>2]>>2]=l;c[p>>2]=(c[p>>2]|0)+4;c[a+1512>>2]=g;r=32-j|0;c[k>>2]=r;i=h;return}}function oVb(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0;l=i;i=i+464|0;m=l+288|0;n=l+352|0;o=l+416|0;p=l+424|0;q=l+432|0;r=l+448|0;s=c[g>>2]|0;t=d[19504+(s<<1)|0]|0;u=d[19505+(s<<1)|0]|0;v=c[g+88>>2]|0;w=c[f+548>>2]|0;x=c[g+72>>2]|0;y=c[g+68>>2]|0;z=l+31&-32;A=f+18752|0;B=b[A>>1]|0;C=f+18754|0;D=b[C>>1]|0;E=f+18756|0;F=b[E>>1]|0;G=f+18758|0;H=b[G>>1]|0;I=-D&32767|-B<<16;J=F<<16|H&32767|32768;K=c[g+4>>2]|0;L=g+100|0;M=b[L>>1]|0;N=K+(-M<<1)|0;O=g+102|0;P=b[O>>1]|0;Q=K+(-P<<1)|0;R=f+18632|0;do{if((c[R>>2]|0)>2){S=B<<2;T=F<<2;if((M|0)<(S|0)){U=S}else{U=(M|0)>(T|0)?T:M}T=D<<2;S=H<<2;if((P|0)<(T|0)){V=T}else{V=(P|0)>(S|0)?S:P}S=V<<16|U&65535;T=U+2>>2;W=V+2>>2;c[o>>2]=16;X=f+37380|0;Y=g+20|0;Z=g+16|0;_=Ke[c[X>>2]&63](z,o,Y,v,U,V,t,u,c[Z>>2]|0)|0;$=f+36948+(s<<2)|0;aa=hf[c[$>>2]&1023](x,16,_,c[o>>2]|0)|0;_=(e[K+(U-M<<1)>>1]|0)+aa+(e[K+(V-P<<1)>>1]|0)|0;do{if((j|0)>0){aa=b[A>>1]<<2;ba=b[C>>1]<<2;da=b[E>>1]<<2;ea=b[G>>1]<<2;fa=aa&65535;ga=ba&65535;ha=0;ia=0;while(1){ja=c[h+(ha<<2)>>2]|0;ka=ja<<16>>16;la=b[h+(ha<<2)+2>>1]|0;if((ja|0)==0|(ja|0)==(S|0)){ma=ia}else{if((ka|0)<(aa|0)){na=fa}else{na=((ka|0)>(da|0)?da:ka)&65535}ka=ia+2|0;b[m+(ka<<2)>>1]=na;if((la|0)<(ba|0)){oa=ga}else{oa=((la|0)>(ea|0)?ea:la)&65535}b[m+(ka<<2)+2>>1]=oa;ma=ia+1|0}ka=ha+1|0;if((ka|0)<(j|0)){ha=ka;ia=ma}else{break}}if((ma|0)<=0){pa=_;qa=U;ra=V;break}c[m+4>>2]=S;ia=_<<4;ha=1;while(1){ea=ha+1|0;ga=b[m+(ea<<2)>>1]|0;ba=b[m+(ea<<2)+2>>1]|0;c[p>>2]=16;da=Ke[c[X>>2]&63](z,p,Y,v,ga,ba,t,u,c[Z>>2]|0)|0;fa=hf[c[$>>2]&1023](x,16,da,c[p>>2]|0)|0;da=((e[K+(ga-M<<1)>>1]|0)+fa+(e[K+(ba-P<<1)>>1]|0)<<4)+ha|0;sa=(da|0)<(ia|0)?da:ia;if((ea|0)>(ma|0)){break}else{ia=sa;ha=ea}}ha=(sa&15)+1|0;pa=sa>>4;qa=b[m+(ha<<2)>>1]|0;ra=b[m+(ha<<2)+2>>1]|0}else{pa=_;qa=U;ra=V}}while(0);Z=qa+2>>2;Y=ra+2>>2;X=qa&65535|ra<<16;if((X&196611|0)==0){ta=pa}else{ha=y+((ca(Y,v)|0)+Z)|0;ia=hf[c[$>>2]&1023](x,16,ha,v)|0;ha=(e[K+((Z<<2)-M<<1)>>1]|0)+ia+(e[K+((Y<<2)-P<<1)>>1]|0)|0;ta=(ha|0)<268435456?ha:268435456}if((S|0)==0){ha=(_|0)<(ta|0);ua=ha?0:Z;va=ha?0:Y;wa=ha?_:ta;xa=pa;ya=T;za=W;Aa=0;Ba=X;break}if((Z|Y|0)==0){ua=Z;va=Y;wa=ta;xa=pa;ya=T;za=W;Aa=S;Ba=X;break}ha=hf[c[$>>2]&1023](x,16,y,v)|0;ia=(e[N>>1]|0)+ha+(e[Q>>1]|0)|0;ha=(ia|0)<(ta|0);ua=ha?0:Z;va=ha?0:Y;wa=ha?ia:ta;xa=pa;ya=T;za=W;Aa=S;Ba=X}else{X=M+2>>2;if((X|0)<(B|0)){Ca=B}else{Ca=(X|0)>(F|0)?F:X}X=P+2>>2;if((X|0)<(D|0)){Da=D}else{Da=(X|0)>(H|0)?H:X}X=Da<<16|Ca&65535;ia=f+36948+(s<<2)|0;ha=y+((ca(Da,v)|0)+Ca)|0;Y=hf[c[ia>>2]&1023](x,16,ha,v)|0;do{if((j|0)>0){ha=0;Z=0;while(1){ea=(b[h+(ha<<2)>>1]|0)+2>>2;da=(b[h+(ha<<2)+2>>1]|0)+2>>2;ba=da<<16|ea&65535;if((ba|0)==0|(ba|0)==(X|0)){Ea=Z}else{ba=b[A>>1]|0;fa=b[E>>1]|0;if((ea|0)<(ba<<16>>16|0)){Fa=ba}else{Fa=((ea|0)>(fa|0)?fa:ea)&65535}ea=Z+2|0;b[m+(ea<<2)>>1]=Fa;fa=b[C>>1]|0;ba=b[G>>1]|0;if((da|0)<(fa<<16>>16|0)){Ga=fa}else{Ga=((da|0)>(ba|0)?ba:da)&65535}b[m+(ea<<2)+2>>1]=Ga;Ea=Z+1|0}ea=ha+1|0;if((ea|0)<(j|0)){ha=ea;Z=Ea}else{break}}if((Ea|0)<=0){Ha=Ca;Ia=Da;Ja=Y;break}c[m+4>>2]=X;Z=Y<<4;ha=1;while(1){ea=ha+1|0;da=b[m+(ea<<2)>>1]|0;ba=b[m+(ea<<2)+2>>1]|0;fa=y+((ca(ba,v)|0)+da)|0;ga=hf[c[ia>>2]&1023](x,16,fa,v)|0;fa=((e[K+((da<<2)-M<<1)>>1]|0)+ga+(e[K+((ba<<2)-P<<1)>>1]|0)<<4)+ha|0;Ka=(fa|0)<(Z|0)?fa:Z;if((ea|0)>(Ea|0)){break}else{Z=Ka;ha=ea}}ha=(Ka&15)+1|0;Ha=b[m+(ha<<2)>>1]|0;Ia=b[m+(ha<<2)+2>>1]|0;Ja=Ka>>4}else{Ha=Ca;Ia=Da;Ja=Y}}while(0);if((X|0)==0){ua=Ha;va=Ia;wa=Ja;xa=268435456;ya=Ca;za=Da;Aa=0;Ba=0;break}Y=hf[c[ia>>2]&1023](x,16,y,v)|0;S=(e[N>>1]|0)+Y+(e[Q>>1]|0)|0;Y=(S|0)<(Ja|0);ua=Y?0:Ha;va=Y?0:Ia;wa=Y?S:Ja;xa=268435456;ya=Ca;za=Da;Aa=X;Ba=0}}while(0);Da=f+18628|0;a:do{switch(c[Da>>2]|0){case 1:{La=w;Ma=ua;Na=va;Oa=wa;Pa=n|0;Qa=n+4|0;Ra=n+8|0;Sa=50;break};case 0:{Ca=f+37008+(s<<2)|0;Ja=n|0;Ia=-4-P|0;Ha=4-P|0;Ka=n+4|0;m=-4-M|0;Ea=n+8|0;Ga=4-M|0;G=n+12|0;C=ua;Fa=va;E=wa<<4;A=w;while(1){pa=C+(ca(Fa,v)|0)|0;Se[c[Ca>>2]&1023](x,y+(pa-v)|0,y+(pa+v)|0,y+(pa-1)|0,y+(pa+1)|0,v,Ja);pa=C<<2;ta=e[K+(pa-M<<1)>>1]|0;ra=Fa<<2;qa=(e[K+(Ia+ra<<1)>>1]|0)+ta+(c[Ja>>2]|0)|0;c[Ja>>2]=qa;V=(e[K+(Ha+ra<<1)>>1]|0)+ta+(c[Ka>>2]|0)|0;c[Ka>>2]=V;ta=e[K+(ra-P<<1)>>1]|0;ra=ta+(e[K+(m+pa<<1)>>1]|0)+(c[Ea>>2]|0)|0;c[Ea>>2]=ra;U=ta+(e[K+(Ga+pa<<1)>>1]|0)+(c[G>>2]|0)|0;c[G>>2]=U;pa=qa<<4|1;qa=(pa|0)<(E|0)?pa:E;pa=V<<4|3;V=(pa|0)<(qa|0)?pa:qa;qa=ra<<4|4;ra=(qa|0)<(V|0)?qa:V;V=U<<4|12;U=(V|0)<(ra|0)?V:ra;if((U&15|0)==0){Ta=C;Ua=Fa;Va=U;break}ra=C-(U<<28>>30)|0;V=Fa-(U<<30>>30)|0;qa=U&-16;U=A-1|0;if((U|0)==0){Ta=ra;Ua=V;Va=qa;break}pa=ra<<16|V&32767;if(((pa+I|J-pa)&-2147467264|0)==0){C=ra;Fa=V;E=qa;A=U}else{Ta=ra;Ua=V;Va=qa;break}}Wa=Ta;Xa=Ua;Ya=Va>>4;break};case 2:{A=ya+(ca(za,v)|0)|0;E=f+37008+(s<<2)|0;Fa=n|0;Se[c[E>>2]&1023](x,y+(A-v)|0,y+(A+v)|0,y+(A-1)|0,y+(A+1)|0,v,Fa);A=e[K+((ya<<2)-M<<1)>>1]|0;C=za-1|0;G=(e[K+((C<<2)-P<<1)>>1]|0)+A+(c[Fa>>2]|0)|0;c[Fa>>2]=G;Ga=za+1|0;Ea=n+4|0;m=(e[K+((Ga<<2)-P<<1)>>1]|0)+A+(c[Ea>>2]|0)|0;c[Ea>>2]=m;A=ya-1|0;Ka=e[K+((za<<2)-P<<1)>>1]|0;Ha=n+8|0;Ja=Ka+(e[K+((A<<2)-M<<1)>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=Ja;Ia=ya+1|0;Ca=n+12|0;X=Ka+(e[K+((Ia<<2)-M<<1)>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=X;Ka=(G|0)<(wa|0);ia=Ka?G:wa;G=(m|0)<(ia|0);qa=G?m:ia;ia=(Ja|0)<(qa|0);m=ia?Ja:qa;qa=(X|0)<(m|0);Ja=qa?X:m;m=qa?za:ia?za:G?Ga:Ka?C:va;C=qa?Ia:ia?A:G?ya:Ka?ya:ua;if((ya|za|0)==0){Za=C;_a=m;$a=Ja}else{Se[c[E>>2]&1023](x,y+(-v|0)|0,y+v|0,y-1|0,y+1|0,v,Fa);Ka=e[N>>1]|0;G=(e[K+(-4-P<<1)>>1]|0)+Ka+(c[Fa>>2]|0)|0;c[Fa>>2]=G;A=(e[K+(4-P<<1)>>1]|0)+Ka+(c[Ea>>2]|0)|0;c[Ea>>2]=A;Ka=e[Q>>1]|0;ia=Ka+(e[K+(-4-M<<1)>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=ia;Ia=Ka+(e[K+(4-M<<1)>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=Ia;Ka=(G|0)<(Ja|0);qa=Ka?G:Ja;Ja=(A|0)<(qa|0);G=Ja?A:qa;qa=(ia|0)<(G|0);A=qa?ia:G;G=(Ia|0)<(A|0);Za=G?1:qa?-1:Ja?0:Ka?0:C;_a=G?0:qa?0:Ja?1:Ka?-1:m;$a=G?Ia:A}if((s|0)==6){La=w;Ma=Za;Na=_a;Oa=$a;Pa=Fa;Qa=Ea;Ra=Ha;Sa=50;break a}do{if((Za|_a|0)==0){ab=_a;bb=Za;cb=3;Sa=63}else{if((Za-ya|_a-za|0)==0){ab=_a;bb=Za;cb=3;Sa=63;break}A=Za+(ca(_a,v)|0)|0;Se[c[E>>2]&1023](x,y+(A-v)|0,y+(A+v)|0,y+(A-1)|0,y+(A+1)|0,v,Fa);A=e[K+((Za<<2)-M<<1)>>1]|0;Ia=_a-1|0;G=(e[K+((Ia<<2)-P<<1)>>1]|0)+A+(c[Fa>>2]|0)|0;c[Fa>>2]=G;m=_a+1|0;Ka=(e[K+((m<<2)-P<<1)>>1]|0)+A+(c[Ea>>2]|0)|0;c[Ea>>2]=Ka;A=Za-1|0;Ja=e[K+((_a<<2)-P<<1)>>1]|0;qa=Ja+(e[K+((A<<2)-M<<1)>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=qa;C=Za+1|0;ia=Ja+(e[K+((C<<2)-M<<1)>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=ia;Ja=(G|0)<($a|0);Ga=Ja?G:$a;G=(Ka|0)<(Ga|0);X=G?Ka:Ga;Ga=(qa|0)<(X|0);Ka=Ga?qa:X;X=(ia|0)<(Ka|0);qa=X?ia:Ka;Ka=X?_a:Ga?_a:G?m:Ja?Ia:_a;Ia=X?C:Ga?A:Za;A=(qa|0)==($a|0);Ga=A?3:1;if(A){ab=Ka;bb=Ia;cb=Ga;Sa=63}else{db=Ia;eb=Ka;fb=qa;gb=Ga;hb=Ka;ib=Ia}}}while(0);do{if((Sa|0)==63){Ia=d[94544+s|0]|0;if(($a|0)>=(2e3>>>(Ia>>>0)|0)){db=bb;eb=ab;fb=$a;gb=cb;hb=ab;ib=bb;break}Ka=ca(ab,v)|0;Ga=Ka+bb|0;qa=v*-2|0;A=Ga-1|0;C=Ga+1|0;X=Ga-2|0;Se[c[E>>2]&1023](x,y+(Ga+qa)|0,y+(A-v)|0,y+(C-v)|0,y+X|0,v,Fa);Ja=K+((bb<<2)-M<<1)|0;m=ab-2|0;G=K+((m<<2)-P<<1)|0;ia=(e[G>>1]|0)+(e[Ja>>1]|0)+(c[Fa>>2]|0)|0;c[Fa>>2]=ia;V=bb-1|0;ra=K+((V<<2)-M<<1)|0;U=ab-1|0;pa=K+((U<<2)-P<<1)|0;ta=e[pa>>1]|0;sa=ta+(e[ra>>1]|0)+(c[Ea>>2]|0)|0;c[Ea>>2]=sa;ma=bb+1|0;p=K+((ma<<2)-M<<1)|0;u=ta+(e[p>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=u;ta=bb-2|0;t=K+((ta<<2)-M<<1)|0;z=K+((ab<<2)-P<<1)|0;oa=(e[z>>1]|0)+(e[t>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=oa;na=(ia|0)<($a|0);o=na?ia:$a;ia=(sa|0)<(o|0);S=ia?sa:o;o=(u|0)<(S|0);sa=o?u:S;S=(oa|0)<(sa|0);u=S?oa:sa;sa=Ga+2|0;oa=v<<1;Se[c[E>>2]&1023](x,y+sa|0,y+(A+v)|0,y+(C+v)|0,y+(Ga+oa)|0,v,Fa);Y=bb+2|0;W=K+((Y<<2)-M<<1)|0;T=(e[z>>1]|0)+(e[W>>1]|0)+(c[Fa>>2]|0)|0;c[Fa>>2]=T;$=ab+1|0;_=K+(($<<2)-P<<1)|0;ha=e[_>>1]|0;Z=ha+(e[ra>>1]|0)+(c[Ea>>2]|0)|0;c[Ea>>2]=Z;ea=ha+(e[p>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=ea;ha=ab+2|0;fa=K+((ha<<2)-P<<1)|0;ba=(e[fa>>1]|0)+(e[Ja>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=ba;ga=(T|0)<(u|0);da=ga?T:u;u=(Z|0)<(da|0);T=u?Z:da;da=(ea|0)<(T|0);Z=da?ea:T;T=(ba|0)<(Z|0);ea=T?ba:Z;Z=T?ha:da?$:u?$:ga?ab:S?ab:o?U:ia?U:na?m:ab;na=T?bb:da?ma:u?V:ga?Y:S?ta:o?ma:ia?V:bb;if((ea|0)==(wa|0)){if((wa|0)<(500>>>(Ia>>>0)|0)){Wa=na;Xa=Z;Ya=wa;break a}}if((ea|0)!=($a|0)){db=na;eb=Z;fb=ea;gb=cb;hb=ab;ib=bb;break}ea=w>>1|1;Ia=F-bb|0;ia=bb-B|0;do{if((ea|0)>(((Ia|0)<(ia|0)?Ia:ia)|0)){jb=na;kb=Z;lb=$a;mb=3}else{o=ea-2|0;if((o|0)<=3){jb=na;kb=Z;lb=$a;mb=3;break}S=ea-6&-4;ga=3;u=$a;da=Z;T=na;do{ba=ga+2|0;aa=-2-ga|0;Se[c[E>>2]&1023](x,y+(ga+Ga)|0,y+(Ga-ga)|0,y+(ba+Ga)|0,y+(aa+Ga)|0,v,Fa);ka=ga+bb|0;la=e[z>>1]|0;ja=la+(e[K+((ka<<2)-M<<1)>>1]|0)+(c[Fa>>2]|0)|0;c[Fa>>2]=ja;nb=bb-ga|0;ob=la+(e[K+((nb<<2)-M<<1)>>1]|0)+(c[Ea>>2]|0)|0;c[Ea>>2]=ob;pb=ba+bb|0;ba=la+(e[K+((pb<<2)-M<<1)>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=ba;qb=aa+bb|0;aa=la+(e[K+((qb<<2)-M<<1)>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=aa;la=(ja|0)<(u|0);rb=la?ja:u;ja=(ob|0)<(rb|0);sb=ja?ob:rb;rb=(ba|0)<(sb|0);ob=rb?ba:sb;sb=(aa|0)<(ob|0);u=sb?aa:ob;da=sb?ab:rb?ab:ja?ab:la?ab:da;T=sb?qb:rb?pb:ja?nb:la?ka:T;ga=ga+4|0;}while((ga|0)<(o|0));jb=T;kb=da;lb=u;mb=S+7|0}}while(0);if((mb|0)<(ea|0)){na=f+36948+(s<<2)|0;Z=mb;ia=lb;Ia=kb;o=jb;while(1){ga=Z+bb|0;if((ga|0)>(F|0)){tb=o;ub=Ia;vb=ia}else{ka=hf[c[na>>2]&1023](x,16,y+(ga+Ka)|0,v)|0;la=(e[K+((ga<<2)-M<<1)>>1]|0)+ka+(e[z>>1]|0)|0;ka=(la|0)<(ia|0);tb=ka?ga:o;ub=ka?ab:Ia;vb=ka?la:ia}la=bb-Z|0;if((la|0)<(B|0)){wb=tb;xb=ub;yb=vb}else{ka=hf[c[na>>2]&1023](x,16,y+(la+Ka)|0,v)|0;ga=(e[K+((la<<2)-M<<1)>>1]|0)+ka+(e[z>>1]|0)|0;ka=(ga|0)<(vb|0);wb=ka?la:tb;xb=ka?ab:ub;yb=ka?ga:vb}ga=Z+2|0;if((ga|0)<(ea|0)){Z=ga;ia=yb;Ia=xb;o=wb}else{zb=yb;Ab=xb;Bb=wb;break}}}else{zb=lb;Ab=kb;Bb=jb}o=H-ab|0;Ia=ab-D|0;do{if((ea|0)>(((o|0)<(Ia|0)?o:Ia)|0)){Cb=Bb;Db=Ab;Eb=zb;Fb=3}else{ia=ea-2|0;if((ia|0)<=3){Cb=Bb;Db=Ab;Eb=zb;Fb=3;break}Z=ea-6&-4;z=3;Ka=zb;na=Ab;ga=Bb;do{ka=ca(z,v)|0;la=z+2|0;nb=y+((ca(la,v)|0)+Ga)|0;ja=-2-z|0;pb=y+((ca(ja,v)|0)+Ga)|0;Se[c[E>>2]&1023](x,y+(ka+Ga)|0,y+(Ga-ka)|0,nb,pb,v,Fa);pb=e[Ja>>1]|0;nb=z+ab|0;ka=(e[K+((nb<<2)-P<<1)>>1]|0)+pb+(c[Fa>>2]|0)|0;c[Fa>>2]=ka;rb=ab-z|0;qb=(e[K+((rb<<2)-P<<1)>>1]|0)+pb+(c[Ea>>2]|0)|0;c[Ea>>2]=qb;sb=la+ab|0;la=(e[K+((sb<<2)-P<<1)>>1]|0)+pb+(c[Ha>>2]|0)|0;c[Ha>>2]=la;ob=ja+ab|0;ja=(e[K+((ob<<2)-P<<1)>>1]|0)+pb+(c[Ca>>2]|0)|0;c[Ca>>2]=ja;pb=(ka|0)<(Ka|0);aa=pb?ka:Ka;ka=(qb|0)<(aa|0);ba=ka?qb:aa;aa=(la|0)<(ba|0);qb=aa?la:ba;ba=(ja|0)<(qb|0);Ka=ba?ja:qb;na=ba?ob:aa?sb:ka?rb:pb?nb:na;ga=ba?bb:aa?bb:ka?bb:pb?bb:ga;z=z+4|0;}while((z|0)<(ia|0));Cb=ga;Db=na;Eb=Ka;Fb=Z+7|0}}while(0);if((Fb|0)<(ea|0)){Ga=f+36948+(s<<2)|0;Ia=Fb;o=Eb;ia=Db;z=Cb;while(1){S=Ia+ab|0;if((S|0)>(H|0)){Gb=z;Hb=ia;Ib=o}else{u=y+((ca(S,v)|0)+bb)|0;da=hf[c[Ga>>2]&1023](x,16,u,v)|0;u=(e[Ja>>1]|0)+da+(e[K+((S<<2)-P<<1)>>1]|0)|0;da=(u|0)<(o|0);Gb=da?bb:z;Hb=da?S:ia;Ib=da?u:o}u=ab-Ia|0;if((u|0)<(D|0)){Jb=Gb;Kb=Hb;Lb=Ib}else{da=y+((ca(u,v)|0)+bb)|0;S=hf[c[Ga>>2]&1023](x,16,da,v)|0;da=(e[Ja>>1]|0)+S+(e[K+((u<<2)-P<<1)>>1]|0)|0;S=(da|0)<(Ib|0);Jb=S?bb:Gb;Kb=S?u:Hb;Lb=S?da:Ib}da=Ia+2|0;if((da|0)<(ea|0)){Ia=da;o=Lb;ia=Kb;z=Jb}else{Mb=Lb;Nb=Kb;Ob=Jb;break}}}else{Mb=Eb;Nb=Db;Ob=Cb}Se[c[E>>2]&1023](x,y+(A+qa)|0,y+(C+qa)|0,y+(X-v)|0,y+(sa-v)|0,v,Fa);z=e[G>>1]|0;ia=z+(e[ra>>1]|0)+(c[Fa>>2]|0)|0;c[Fa>>2]=ia;o=z+(e[p>>1]|0)+(c[Ea>>2]|0)|0;c[Ea>>2]=o;z=e[pa>>1]|0;Ia=z+(e[t>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=Ia;Ja=z+(e[W>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=Ja;z=(ia|0)<(Mb|0);Ga=z?ia:Mb;ia=(o|0)<(Ga|0);da=ia?o:Ga;Ga=(Ia|0)<(da|0);o=Ga?Ia:da;da=(Ja|0)<(o|0);Ia=da?Ja:o;Se[c[E>>2]&1023](x,y+(X+v)|0,y+(sa+v)|0,y+(A+oa)|0,y+(C+oa)|0,v,Fa);o=e[_>>1]|0;Ja=o+(e[t>>1]|0)+(c[Fa>>2]|0)|0;c[Fa>>2]=Ja;S=o+(e[W>>1]|0)+(c[Ea>>2]|0)|0;c[Ea>>2]=S;o=e[fa>>1]|0;u=o+(e[ra>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=u;T=o+(e[p>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=T;o=(Ja|0)<(Ia|0);pb=o?Ja:Ia;Ia=(S|0)<(pb|0);Ja=Ia?S:pb;pb=(u|0)<(Ja|0);S=pb?u:Ja;Ja=(T|0)<(S|0);u=Ja?T:S;S=Ja?ha:pb?ha:Ia?$:o?$:da?U:Ga?U:ia?m:z?m:Nb;T=Ja?ma:pb?V:Ia?Y:o?ta:da?Y:Ga?ta:ia?ma:z?V:Ob;if((u|0)==($a|0)){Wa=T;Xa=S;Ya=$a;break a}db=T;eb=S;fb=u;gb=ea+2|0;hb=ab;ib=bb}}while(0);do{if((j|0)==1){if((s|0)==0){Pb=25;Qb=1;Sa=102;break}u=(b[L>>1]|0)-(b[h>>1]|0)|0;S=(b[O>>1]|0)-(b[h+2>>1]|0)|0;Pb=((S|0)>-1?S:-S|0)+((u|0)>-1?u:-u|0)|0;Qb=1;Sa=102}else if((j|0)==0){Rb=w}else{u=j-1|0;if((s|0)==0){Sb=0;Tb=u}else{S=(b[L>>1]|0)-(b[h>>1]|0)|0;T=(b[O>>1]|0)-(b[h+2>>1]|0)|0;Sb=((T|0)>-1?T:-T|0)+((S|0)>-1?S:-S|0)|0;Tb=j}if((u|0)>0){S=0;T=0;z=b[h>>1]|0;ia=b[h+2>>1]|0;while(1){Ga=T+1|0;da=b[h+(Ga<<2)>>1]|0;o=(z<<16>>16)-(da<<16>>16)|0;Ia=b[h+(Ga<<2)+2>>1]|0;pb=(ia<<16>>16)-(Ia<<16>>16)|0;Ja=((o|0)>-1?o:-o|0)+S+((pb|0)>-1?pb:-pb|0)|0;if((Ga|0)<(u|0)){S=Ja;T=Ga;z=da;ia=Ia}else{Ub=Ja;break}}}else{Ub=0}Pb=Ub+Sb|0;Qb=Tb;Sa=102}}while(0);if((Sa|0)==102){ia=d[94544+s|0]|0;do{if((fb|0)<(1e3>>>(ia>>>0)|0)){Vb=0}else{if((fb|0)<(2e3>>>(ia>>>0)|0)){Vb=1;break}Vb=(fb|0)<(4e3>>>(ia>>>0)|0)?2:3}}while(0);do{if((Pb|0)<(Qb*10|0|0)){Wb=0}else{if((Pb|0)<(Qb*20|0|0)){Wb=1;break}Wb=(Pb|0)<(Qb*40|0|0)?2:3}}while(0);Rb=(ca(d[94552+(Wb<<2)+Vb|0]|0,w)|0)>>2}ia=F-ib|0;z=ib-B|0;do{if((Rb|0)>(((ia|0)<(z|0)?ia:z)|0)){Xb=db;Yb=eb;Zb=fb;_b=gb}else{T=Rb-2|0;if((gb|0)>=(T|0)){Xb=db;Yb=eb;Zb=fb;_b=gb;break}S=(ca(hb,v)|0)+ib|0;u=K+((hb<<2)-P<<1)|0;ea=gb;V=fb;ma=eb;ta=db;while(1){Y=ea+2|0;m=-2-ea|0;Se[c[E>>2]&1023](x,y+(ea+S)|0,y+(S-ea)|0,y+(Y+S)|0,y+(m+S)|0,v,Fa);U=ea+ib|0;$=e[u>>1]|0;ha=$+(e[K+((U<<2)-M<<1)>>1]|0)+(c[Fa>>2]|0)|0;c[Fa>>2]=ha;p=ib-ea|0;ra=$+(e[K+((p<<2)-M<<1)>>1]|0)+(c[Ea>>2]|0)|0;c[Ea>>2]=ra;fa=Y+ib|0;Y=$+(e[K+((fa<<2)-M<<1)>>1]|0)+(c[Ha>>2]|0)|0;c[Ha>>2]=Y;W=m+ib|0;m=$+(e[K+((W<<2)-M<<1)>>1]|0)+(c[Ca>>2]|0)|0;c[Ca>>2]=m;$=(ha|0)<(V|0);t=$?ha:V;ha=(ra|0)<(t|0);_=ha?ra:t;t=(Y|0)<(_|0);ra=t?Y:_;_=(m|0)<(ra|0);Y=_?m:ra;ra=_?hb:t?hb:ha?hb:$?hb:ma;m=_?W:t?fa:ha?p:$?U:ta;U=ea+4|0;if((U|0)<(T|0)){ea=U;V=Y;ma=ra;ta=m}else{Xb=m;Yb=ra;Zb=Y;_b=U;break}}}}while(0);if((_b|0)<(Rb|0)){z=f+36948+(s<<2)|0;ia=ca(hb,v)|0;ta=K+((hb<<2)-P<<1)|0;ma=_b;V=Zb;ea=Yb;T=Xb;while(1){u=ma+ib|0;if((u|0)>(F|0)){$b=T;ac=ea;bc=V}else{S=hf[c[z>>2]&1023](x,16,y+(u+ia)|0,v)|0;U=(e[K+((u<<2)-M<<1)>>1]|0)+S+(e[ta>>1]|0)|0;S=(U|0)<(V|0);$b=S?u:T;ac=S?hb:ea;bc=S?U:V}U=ib-ma|0;if((U|0)<(B|0)){cc=$b;dc=ac;ec=bc}else{S=hf[c[z>>2]&1023](x,16,y+(U+ia)|0,v)|0;u=(e[K+((U<<2)-M<<1)>>1]|0)+S+(e[ta>>1]|0)|0;S=(u|0)<(bc|0);cc=S?U:$b;dc=S?hb:ac;ec=S?u:bc}u=ma+2|0;if((u|0)<(Rb|0)){ma=u;V=ec;ea=dc;T=cc}else{fc=ec;gc=dc;hc=cc;break}}}else{fc=Zb;gc=Yb;hc=Xb}T=Rb>>1;ea=H-hb|0;V=hb-D|0;do{if((T|0)>(((ea|0)<(V|0)?ea:V)|0)){ic=hc;jc=gc;kc=fc;lc=gb}else{ma=T-2|0;if((gb|0)>=(ma|0)){ic=hc;jc=gc;kc=fc;lc=gb;break}ta=(ca(hb,v)|0)+ib|0;ia=K+((ib<<2)-M<<1)|0;z=gb+(T-3-gb&-4)|0;u=gb;S=fc;U=gc;Y=hc;do{ra=ca(u,v)|0;m=u+2|0;$=y+((ca(m,v)|0)+ta)|0;p=-2-u|0;ha=y+((ca(p,v)|0)+ta)|0;Se[c[E>>2]&1023](x,y+(ra+ta)|0,y+(ta-ra)|0,$,ha,v,Fa);ha=e[ia>>1]|0;$=u+hb|0;ra=(e[K+(($<<2)-P<<1)>>1]|0)+ha+(c[Fa>>2]|0)|0;c[Fa>>2]=ra;fa=hb-u|0;t=(e[K+((fa<<2)-P<<1)>>1]|0)+ha+(c[Ea>>2]|0)|0;c[Ea>>2]=t;W=m+hb|0;m=(e[K+((W<<2)-P<<1)>>1]|0)+ha+(c[Ha>>2]|0)|0;c[Ha>>2]=m;_=p+hb|0;p=(e[K+((_<<2)-P<<1)>>1]|0)+ha+(c[Ca>>2]|0)|0;c[Ca>>2]=p;ha=(ra|0)<(S|0);oa=ha?ra:S;ra=(t|0)<(oa|0);C=ra?t:oa;oa=(m|0)<(C|0);t=oa?m:C;C=(p|0)<(t|0);S=C?p:t;U=C?_:oa?W:ra?fa:ha?$:U;Y=C?ib:oa?ib:ra?ib:ha?ib:Y;u=u+4|0;}while((u|0)<(ma|0));ic=Y;jc=U;kc=S;lc=z+4|0}}while(0);V=f+36948+(s<<2)|0;if((lc|0)<(T|0)){ea=K+((ib<<2)-M<<1)|0;ma=lc;u=kc;ia=jc;ta=ic;while(1){ha=ma+hb|0;if((ha|0)>(H|0)){mc=ta;nc=ia;oc=u}else{ra=y+((ca(ha,v)|0)+ib)|0;oa=hf[c[V>>2]&1023](x,16,ra,v)|0;ra=(e[ea>>1]|0)+oa+(e[K+((ha<<2)-P<<1)>>1]|0)|0;oa=(ra|0)<(u|0);mc=oa?ib:ta;nc=oa?ha:ia;oc=oa?ra:u}ra=hb-ma|0;if((ra|0)<(D|0)){pc=mc;qc=nc;rc=oc}else{oa=y+((ca(ra,v)|0)+ib)|0;ha=hf[c[V>>2]&1023](x,16,oa,v)|0;oa=(e[ea>>1]|0)+ha+(e[K+((ra<<2)-P<<1)>>1]|0)|0;ha=(oa|0)<(oc|0);pc=ha?ib:mc;qc=ha?ra:nc;rc=ha?oa:oc}oa=ma+2|0;if((oa|0)<(T|0)){ma=oa;u=rc;ia=qc;ta=pc}else{sc=rc;tc=qc;uc=pc;break}}}else{sc=kc;tc=jc;uc=ic}ta=(ca(hb,v)|0)+ib|0;ia=ta-2|0;u=v*-2|0;ma=v<<1;T=ta+2|0;Se[c[E>>2]&1023](x,y+(ia+u)|0,y+(ia+ma)|0,y+(T+u)|0,y+(T+ma)|0,v,Fa);ma=ib-2|0;T=e[K+((ma<<2)-M<<1)>>1]|0;u=hb-2|0;ia=e[K+((u<<2)-P<<1)>>1]|0;ta=ia+T+(c[Fa>>2]|0)|0;c[Fa>>2]=ta;ea=hb+2|0;oa=e[K+((ea<<2)-P<<1)>>1]|0;ha=oa+T+(c[Ea>>2]|0)|0;c[Ea>>2]=ha;T=ib+2|0;ra=e[K+((T<<2)-M<<1)>>1]|0;C=ia+ra+(c[Ha>>2]|0)|0;c[Ha>>2]=C;ia=oa+ra+(c[Ca>>2]|0)|0;c[Ca>>2]=ia;ra=(ta|0)<(sc|0);oa=ra?ta:sc;ta=(ha|0)<(oa|0);$=ta?ha:oa;oa=(C|0)<($|0);ha=oa?C:$;$=(ia|0)<(ha|0);C=$?ia:ha;ha=$?ea:oa?u:ta?ea:ra?u:tc;u=$?T:oa?T:ta?ma:ra?ma:uc;ma=(u<<2)-M|0;ra=K+(ma<<1)|0;ta=(ha<<2)-P|0;T=K+(ta<<1)|0;oa=F-u|0;$=u-B|0;ea=H-ha|0;ia=ha-D|0;fa=(ea|0)<(ia|0)?ea:ia;ia=($|0)<(fa|0)?$:fa;fa=Rb>>2;$=n+16|0;ea=n+32|0;W=n+48|0;_=n+20|0;t=n+24|0;p=n+28|0;m=n+36|0;A=n+40|0;sa=n+44|0;X=n+52|0;pa=n+56|0;G=n+60|0;if((oa|0)<(ia|0)){qa=u;Ja=ha;Ia=C;da=1;while(1){Ga=da<<2;do{if((Ga|0)>(oa|0)){pb=0;o=Ia;ka=Ja;aa=qa;while(1){ba=(ca(a[94568+(pb<<1)|0]|0,da)|0)+u|0;nb=(ca(a[94569+(pb<<1)|0]|0,da)|0)+ha|0;rb=nb&32767|ba<<16;if(((rb+I|J-rb)&-2147467264|0)==0){rb=y+((ca(nb,v)|0)+ba)|0;sb=hf[c[V>>2]&1023](x,16,rb,v)|0;rb=(e[K+((ba<<2)-M<<1)>>1]|0)+sb+(e[K+((nb<<2)-P<<1)>>1]|0)|0;sb=(rb|0)<(o|0);vc=sb?ba:aa;wc=sb?nb:ka;xc=sb?rb:o}else{vc=aa;wc=ka;xc=o}rb=pb+1|0;if((rb|0)<16){pb=rb;o=xc;ka=wc;aa=vc}else{yc=vc;zc=wc;Ac=xc;break}}}else{aa=(ca(ha-Ga|0,v)|0)+u|0;ka=ca(da,v)|0;o=da<<1;pb=ka-o|0;Z=ka+o|0;Se[c[E>>2]&1023](x,y+aa|0,y+(aa+(ka<<3))|0,y+(pb+aa)|0,y+(Z+aa)|0,v,Fa);o=ka<<1;Ka=aa+o|0;aa=Ka-Ga|0;na=Ka+Ga|0;Se[c[E>>2]&1023](x,y+aa|0,y+na|0,y+(aa+ka)|0,y+(na+ka)|0,v,$);na=Ka+o|0;Ka=na-Ga|0;aa=na+Ga|0;Se[c[E>>2]&1023](x,y+Ka|0,y+aa|0,y+(Ka+ka)|0,y+(aa+ka)|0,v,ea);ka=na+o|0;Se[c[E>>2]&1023](x,y+(ka-Ga)|0,y+(ka+Ga)|0,y+(pb+ka)|0,y+(Z+ka)|0,v,W);ka=e[ra>>1]|0;Z=da*-16|0;pb=(e[K+(Z+ta<<1)>>1]|0)+ka+(c[Fa>>2]|0)|0;c[Fa>>2]=pb;o=da<<4;na=(e[K+(o+ta<<1)>>1]|0)+ka+(c[Ea>>2]|0)|0;c[Ea>>2]=na;ka=da*-8|0;aa=e[K+(ka+ma<<1)>>1]|0;Ka=e[K+((da*-12|0)+ta<<1)>>1]|0;ga=Ka+aa+(c[Ha>>2]|0)|0;c[Ha>>2]=ga;rb=da<<3;sb=e[K+(rb+ma<<1)>>1]|0;nb=Ka+sb+(c[Ca>>2]|0)|0;c[Ca>>2]=nb;Ka=e[K+(Z+ma<<1)>>1]|0;Z=e[K+(ka+ta<<1)>>1]|0;ka=Z+Ka+(c[$>>2]|0)|0;c[$>>2]=ka;ba=e[K+(o+ma<<1)>>1]|0;o=Z+ba+(c[_>>2]|0)|0;c[_>>2]=o;Z=e[K+((da*-4|0)+ta<<1)>>1]|0;ob=Z+Ka+(c[t>>2]|0)|0;c[t>>2]=ob;qb=Z+ba+(c[p>>2]|0)|0;c[p>>2]=qb;Z=e[T>>1]|0;ja=Z+Ka+(c[ea>>2]|0)|0;c[ea>>2]=ja;la=Z+ba+(c[m>>2]|0)|0;c[m>>2]=la;Z=e[K+(Ga+ta<<1)>>1]|0;Bc=Z+Ka+(c[A>>2]|0)|0;c[A>>2]=Bc;Cc=Z+ba+(c[sa>>2]|0)|0;c[sa>>2]=Cc;Z=e[K+(rb+ta<<1)>>1]|0;rb=Z+Ka+(c[W>>2]|0)|0;c[W>>2]=rb;Ka=Z+ba+(c[X>>2]|0)|0;c[X>>2]=Ka;ba=e[K+((da*12|0)+ta<<1)>>1]|0;Z=ba+aa+(c[pa>>2]|0)|0;c[pa>>2]=Z;aa=ba+sb+(c[G>>2]|0)|0;c[G>>2]=aa;sb=(pb|0)<(Ia|0);ba=sb?pb:Ia;pb=(na|0)<(ba|0);Dc=pb?na:ba;ba=(ga|0)<(Dc|0);na=ba?ga:Dc;Dc=(nb|0)<(na|0);ga=Dc?nb:na;na=(ka|0)<(ga|0);nb=na?ka:ga;ga=(o|0)<(nb|0);ka=ga?o:nb;nb=(ob|0)<(ka|0);o=nb?ob:ka;ka=(qb|0)<(o|0);ob=ka?qb:o;o=(ja|0)<(ob|0);qb=o?ja:ob;ob=(la|0)<(qb|0);ja=ob?la:qb;qb=(Bc|0)<(ja|0);la=qb?Bc:ja;ja=(Cc|0)<(la|0);Bc=ja?Cc:la;la=(rb|0)<(Bc|0);Cc=la?rb:Bc;Bc=(Ka|0)<(Cc|0);rb=Bc?Ka:Cc;Cc=(Z|0)<(rb|0);Ka=Cc?Z:rb;rb=(aa|0)<(Ka|0);Z=rb?35:Cc?-29:Bc?66:la?-62:ja?65:qb?-63:ob?64:o?-64:ka?79:nb?-49:ga?78:na?-50:Dc?45:ba?-19:pb?4:sb?12:0;sb=rb?aa:Ka;if((Z|0)==0){yc=qa;zc=Ja;Ac=sb;break}yc=(ca(Z>>4,da)|0)+u|0;zc=(ca(Z<<28>>28,da)|0)+ha|0;Ac=sb}}while(0);Ga=da+1|0;if((Ga|0)>(fa|0)){Ec=Ac;Fc=zc;Gc=yc;break}else{qa=yc;Ja=zc;Ia=Ac;da=Ga}}}else{da=u;Ia=ha;Ja=C;qa=1;while(1){oa=qa<<2;do{if((oa|0)>(ia|0)){Ga=0;z=Ja;S=Ia;U=da;while(1){Y=(ca(a[94568+(Ga<<1)|0]|0,qa)|0)+u|0;sb=(ca(a[94569+(Ga<<1)|0]|0,qa)|0)+ha|0;Z=sb&32767|Y<<16;if(((Z+I|J-Z)&-2147467264|0)==0){Z=y+((ca(sb,v)|0)+Y)|0;Ka=hf[c[V>>2]&1023](x,16,Z,v)|0;Z=(e[K+((Y<<2)-M<<1)>>1]|0)+Ka+(e[K+((sb<<2)-P<<1)>>1]|0)|0;Ka=(Z|0)<(z|0);Hc=Ka?Y:U;Ic=Ka?sb:S;Jc=Ka?Z:z}else{Hc=U;Ic=S;Jc=z}Z=Ga+1|0;if((Z|0)<16){Ga=Z;z=Jc;S=Ic;U=Hc}else{Kc=Hc;Lc=Ic;Mc=Jc;break}}}else{U=(ca(ha-oa|0,v)|0)+u|0;S=ca(qa,v)|0;z=qa<<1;Ga=S-z|0;Z=S+z|0;Se[c[E>>2]&1023](x,y+U|0,y+(U+(S<<3))|0,y+(Ga+U)|0,y+(Z+U)|0,v,Fa);z=S<<1;Ka=U+z|0;U=Ka-oa|0;sb=Ka+oa|0;Se[c[E>>2]&1023](x,y+U|0,y+sb|0,y+(U+S)|0,y+(sb+S)|0,v,$);sb=Ka+z|0;Ka=sb-oa|0;U=sb+oa|0;Se[c[E>>2]&1023](x,y+Ka|0,y+U|0,y+(Ka+S)|0,y+(U+S)|0,v,ea);S=sb+z|0;Se[c[E>>2]&1023](x,y+(S-oa)|0,y+(S+oa)|0,y+(Ga+S)|0,y+(Z+S)|0,v,W);S=e[ra>>1]|0;Z=qa*-16|0;Ga=(e[K+(Z+ta<<1)>>1]|0)+S+(c[Fa>>2]|0)|0;c[Fa>>2]=Ga;z=qa<<4;sb=(e[K+(z+ta<<1)>>1]|0)+S+(c[Ea>>2]|0)|0;c[Ea>>2]=sb;S=qa*-8|0;U=e[K+(S+ma<<1)>>1]|0;Ka=e[K+((qa*-12|0)+ta<<1)>>1]|0;Y=Ka+U+(c[Ha>>2]|0)|0;c[Ha>>2]=Y;aa=qa<<3;rb=e[K+(aa+ma<<1)>>1]|0;pb=Ka+rb+(c[Ca>>2]|0)|0;c[Ca>>2]=pb;Ka=e[K+(Z+ma<<1)>>1]|0;Z=e[K+(S+ta<<1)>>1]|0;S=Z+Ka+(c[$>>2]|0)|0;c[$>>2]=S;ba=e[K+(z+ma<<1)>>1]|0;z=Z+ba+(c[_>>2]|0)|0;c[_>>2]=z;Z=e[K+((qa*-4|0)+ta<<1)>>1]|0;Dc=Z+Ka+(c[t>>2]|0)|0;c[t>>2]=Dc;na=Z+ba+(c[p>>2]|0)|0;c[p>>2]=na;Z=e[T>>1]|0;ga=Z+Ka+(c[ea>>2]|0)|0;c[ea>>2]=ga;nb=Z+ba+(c[m>>2]|0)|0;c[m>>2]=nb;Z=e[K+(oa+ta<<1)>>1]|0;ka=Z+Ka+(c[A>>2]|0)|0;c[A>>2]=ka;o=Z+ba+(c[sa>>2]|0)|0;c[sa>>2]=o;Z=e[K+(aa+ta<<1)>>1]|0;aa=Z+Ka+(c[W>>2]|0)|0;c[W>>2]=aa;Ka=Z+ba+(c[X>>2]|0)|0;c[X>>2]=Ka;ba=e[K+((qa*12|0)+ta<<1)>>1]|0;Z=ba+U+(c[pa>>2]|0)|0;c[pa>>2]=Z;U=ba+rb+(c[G>>2]|0)|0;c[G>>2]=U;rb=(Ga|0)<(Ja|0);ba=rb?Ga:Ja;Ga=(sb|0)<(ba|0);ob=Ga?sb:ba;ba=(Y|0)<(ob|0);sb=ba?Y:ob;ob=(pb|0)<(sb|0);Y=ob?pb:sb;sb=(S|0)<(Y|0);pb=sb?S:Y;Y=(z|0)<(pb|0);S=Y?z:pb;pb=(Dc|0)<(S|0);z=pb?Dc:S;S=(na|0)<(z|0);Dc=S?na:z;z=(ga|0)<(Dc|0);na=z?ga:Dc;Dc=(nb|0)<(na|0);ga=Dc?nb:na;na=(ka|0)<(ga|0);nb=na?ka:ga;ga=(o|0)<(nb|0);ka=ga?o:nb;nb=(aa|0)<(ka|0);o=nb?aa:ka;ka=(Ka|0)<(o|0);aa=ka?Ka:o;o=(Z|0)<(aa|0);Ka=o?Z:aa;aa=(U|0)<(Ka|0);Z=aa?35:o?-29:ka?66:nb?-62:ga?65:na?-63:Dc?64:z?-64:S?79:pb?-49:Y?78:sb?-50:ob?45:ba?-19:Ga?4:rb?12:0;rb=aa?U:Ka;if((Z|0)==0){Kc=da;Lc=Ia;Mc=rb;break}Kc=(ca(Z>>4,qa)|0)+u|0;Lc=(ca(Z<<28>>28,qa)|0)+ha|0;Mc=rb}}while(0);oa=qa+1|0;if((oa|0)>(fa|0)){Ec=Mc;Fc=Lc;Gc=Kc;break}else{da=Kc;Ia=Lc;Ja=Mc;qa=oa}}}if((Fc|0)>(H|0)|(Fc|0)<(D|0)|(Gc|0)>(F|0)|(Gc|0)<(B|0)){Wa=Gc;Xa=Fc;Ya=Ec}else{La=Rb;Ma=Gc;Na=Fc;Oa=Ec;Pa=Fa;Qa=Ea;Ra=Ha;Sa=50}break};case 3:case 4:{qa=ua-w|0;Ja=(qa|0)>(B|0)?qa:B;qa=va-w|0;Ia=(qa|0)>(D|0)?qa:D;qa=ua+w|0;da=va+w|0;fa=(da|0)<(H|0)?da:H;da=3-Ja+((qa|0)<(F|0)?qa:F)&-4;qa=c[g+84>>2]|0;ha=(s|0)<4?3:6;u=d[19504+(ha<<1)|0]|0;G=c[f+36456>>2]|0;pa=-(b[L>>1]|0)|0;ta=c[f+2096+(c[f+28816>>2]<<4)+((pa&3)<<2)>>2]|0;X=pa>>2;pa=u<<4;W=q|0;Se[c[f+37168+(ha<<2)>>2]&1023](3035048,x,x+u|0,x+pa|0,x+(pa+u)|0,16,W);if((ha-5|0)>>>0<4>>>0){Nc=qa+((ca((c[(c[f+15144>>2]|0)+180>>2]|0)+64|0,v)|0)<<1)|0}else{Nc=qa}if((s|0)==5|(s|0)==2|(s|0)==0){Oc=ca(u,v)|0}else{Oc=u}if((s|0)==5|(s|0)==2){c[q+4>>2]=c[q+8>>2]}if((c[Da>>2]|0)!=4){if((Ia|0)>(fa|0)){Wa=ua;Xa=va;Ya=wa;break a}u=f+37252+(s<<2)|0;qa=ta+(X+Ja<<1)|0;ha=f+36948+(s<<2)|0;pa=f+36980+(s<<2)|0;sa=n|0;A=n+4|0;m=n+8|0;ea=Ia;T=wa;p=va;t=ua;while(1){_=K+((ea<<2)-P<<1)|0;ma=e[_>>1]|0;do{if((T|0)>(ma|0)){$=T-ma|0;Ca=(ca(ea,v)|0)+Ja|0;ra=me[c[u>>2]&255](W,Nc+(Ca<<1)|0,Oc,qa,G,da,$)|0;E=ra-2|0;if((E|0)>0){V=0;ia=$;C=p;oa=t;while(1){rb=G+(V<<1)|0;Z=G+(V+1<<1)|0;Ka=G+(V+2<<1)|0;_e[c[pa>>2]&511](x,y+(Ca+(b[rb>>1]|0))|0,y+(Ca+(b[Z>>1]|0))|0,y+(Ca+(b[Ka>>1]|0))|0,v,sa);U=(b[rb>>1]|0)+Ja|0;rb=(c[sa>>2]|0)+(e[K+((U<<2)-M<<1)>>1]|0)|0;c[sa>>2]=rb;aa=(b[Z>>1]|0)+Ja|0;Z=(c[A>>2]|0)+(e[K+((aa<<2)-M<<1)>>1]|0)|0;c[A>>2]=Z;Ga=(b[Ka>>1]|0)+Ja|0;Ka=(c[m>>2]|0)+(e[K+((Ga<<2)-M<<1)>>1]|0)|0;c[m>>2]=Ka;ba=(rb|0)<(ia|0);ob=ba?rb:ia;rb=(Z|0)<(ob|0);sb=rb?Z:ob;ob=(Ka|0)<(sb|0);Z=ob?Ka:sb;sb=ob?ea:rb?ea:ba?ea:C;Ka=ob?Ga:rb?aa:ba?U:oa;U=V+3|0;if((U|0)<(E|0)){V=U;ia=Z;C=sb;oa=Ka}else{Pc=U;Qc=Z;Rc=sb;Sc=Ka;break}}}else{Pc=0;Qc=$;Rc=p;Sc=t}oa=Qc+ma|0;if((Pc|0)<(ra|0)){Tc=Pc;Uc=oa;Vc=Rc;Wc=Sc}else{Xc=Sc;Yc=Rc;Zc=oa;break}while(1){oa=G+(Tc<<1)|0;C=hf[c[ha>>2]&1023](x,16,y+(Ca+(b[oa>>1]|0))|0,v)|0;ia=(b[oa>>1]|0)+Ja|0;oa=(e[K+((ia<<2)-M<<1)>>1]|0)+C+(e[_>>1]|0)|0;C=(oa|0)<(Uc|0);V=C?oa:Uc;oa=C?ea:Vc;E=C?ia:Wc;ia=Tc+1|0;if((ia|0)<(ra|0)){Tc=ia;Uc=V;Vc=oa;Wc=E}else{Xc=E;Yc=oa;Zc=V;break}}}else{Xc=t;Yc=p;Zc=T}}while(0);_=ea+1|0;if((_|0)>(fa|0)){Wa=Xc;Xa=Yc;Ya=Zc;break a}else{ea=_;T=Zc;p=Yc;t=Xc}}}t=G+((da+31&-32|4)<<1)|0;if((w|0)<17){_c=10}else{_c=(w|0)<25?11:12}p=f+36744+(s<<2)|0;T=y+((ca(va,v)|0)+ua)|0;ea=hf[c[p>>2]&1023](x,16,T,v)|0;T=(e[K+((ua<<2)-M<<1)>>1]|0)+ea+(e[K+((va<<2)-P<<1)>>1]|0)|0;if((Ia|0)>(fa|0)){$c=0;ad=T}else{ea=f+37252+(s<<2)|0;ha=ta+(X+Ja<<1)|0;m=f+37140+(s<<2)|0;A=r|0;sa=0;pa=T;T=Ia;while(1){qa=e[K+((T<<2)-P<<1)>>1]|0;if((pa|0)>(qa|0)){u=pa-qa|0;Ha=ca(T,v)|0;Ea=Ha+Ja|0;Fa=me[c[ea>>2]&255](W,Nc+(Ea<<1)|0,Oc,ha,G,da,(u*17|0)>>4)|0;_=Fa-2|0;if((_|0)>0){ma=T&65535;ra=sa;Ca=u;$=0;while(1){V=G+($<<1)|0;oa=G+($+1<<1)|0;E=G+($+2<<1)|0;_e[c[m>>2]&511](x,y+((b[V>>1]|0)+Ea)|0,y+((b[oa>>1]|0)+Ea)|0,y+((b[E>>1]|0)+Ea)|0,v,A);ia=(e[ta+((b[V>>1]|0)+X<<1)>>1]|0)+(c[A>>2]|0)|0;if((ia|0)<((ca(Ca,_c)|0)>>3|0)){c[t+(ra<<3)>>2]=ia+qa;b[t+(ra<<3)+4>>1]=(e[V>>1]|0)+Ja;b[t+(ra<<3)+6>>1]=ma;bd=(ia|0)<(Ca|0)?ia:Ca;cd=ra+1|0}else{bd=Ca;cd=ra}ia=(e[ta+((b[oa>>1]|0)+X<<1)>>1]|0)+(c[r+4>>2]|0)|0;if((ia|0)<((ca(bd,_c)|0)>>3|0)){c[t+(cd<<3)>>2]=ia+qa;b[t+(cd<<3)+4>>1]=(e[oa>>1]|0)+Ja;b[t+(cd<<3)+6>>1]=ma;dd=(ia|0)<(bd|0)?ia:bd;ed=cd+1|0}else{dd=bd;ed=cd}ia=(e[ta+((b[E>>1]|0)+X<<1)>>1]|0)+(c[r+8>>2]|0)|0;if((ia|0)<((ca(dd,_c)|0)>>3|0)){c[t+(ed<<3)>>2]=ia+qa;b[t+(ed<<3)+4>>1]=(e[E>>1]|0)+Ja;b[t+(ed<<3)+6>>1]=ma;fd=(ia|0)<(dd|0)?ia:dd;gd=ed+1|0}else{fd=dd;gd=ed}ia=$+3|0;if((ia|0)<(_|0)){ra=gd;Ca=fd;$=ia}else{hd=gd;id=fd;jd=ia;break}}}else{hd=sa;id=u;jd=0}if((jd|0)<(Fa|0)){$=T&65535;Ca=hd;ra=id;_=jd;while(1){ma=G+(_<<1)|0;Ea=(b[ma>>1]|0)+Ja|0;ia=hf[c[p>>2]&1023](x,16,y+(Ea+Ha)|0,v)|0;E=(e[ta+((b[ma>>1]|0)+X<<1)>>1]|0)+ia|0;if((E|0)<((ca(ra,_c)|0)>>3|0)){c[t+(Ca<<3)>>2]=E+qa;b[t+(Ca<<3)+4>>1]=Ea;b[t+(Ca<<3)+6>>1]=$;kd=(E|0)<(ra|0)?E:ra;ld=Ca+1|0}else{kd=ra;ld=Ca}E=_+1|0;if((E|0)<(Fa|0)){Ca=ld;ra=kd;_=E}else{md=ld;nd=kd;break}}}else{md=hd;nd=id}od=nd+qa|0;pd=md}else{od=pa;pd=sa}_=T+1|0;if((_|0)>(fa|0)){$c=pd;ad=od;break}else{sa=pd;pa=od;T=_}}}T=w>>1;pa=(ca(ad,_c)|0)>>3;sa=T<<1;if(($c|0)>(sa|0)&(pa|0)>(ad|0)){fa=$c;X=pa;while(1){pa=X+ad>>1;ta=0;while(1){if((ta|0)>=(fa|0)){qd=ta;break}if((c[t+(ta<<3)>>2]|0)>(pa|0)){Sa=180;break}else{ta=ta+1|0}}if((Sa|0)==180){Sa=0;qa=~pa;p=ta;Ja=ta;while(1){G=c[t+(Ja<<3)>>2]|0;c[t+(p<<3)+4>>2]=c[t+(Ja<<3)+4>>2];c[t+(p<<3)>>2]=G;A=((G+qa|0)>>>31)+p|0;G=Ja+1|0;if((G|0)<(fa|0)){p=A;Ja=G}else{qd=A;break}}}if((qd|0)>(sa|0)&(pa|0)>(ad|0)){fa=qd;X=pa}else{rd=qd;break}}}else{rd=$c}if((rd|0)>(T|0)){X=rd;while(1){if((X|0)>1){fa=0;sa=1;while(1){Ja=(c[t+(sa<<3)>>2]|0)>(c[t+(fa<<3)>>2]|0)?sa:fa;p=sa+1|0;if((p|0)<(X|0)){fa=Ja;sa=p}else{sd=Ja;break}}}else{sd=0}sa=X-1|0;fa=t+(sa<<3)|0;pa=c[fa+4>>2]|0;Ja=t+(sd<<3)|0;c[Ja>>2]=c[fa>>2];c[Ja+4>>2]=pa;if((sa|0)>(T|0)){X=sa}else{td=T;break}}}else{td=rd}if((td|0)<=0){Wa=ua;Xa=va;Ya=wa;break a}T=f+36948+(s<<2)|0;X=0;sa=wa;pa=va;Ja=ua;while(1){fa=t+(X<<3)+6|0;p=ca(b[fa>>1]|0,v)|0;qa=t+(X<<3)+4|0;ta=hf[c[T>>2]&1023](x,16,y+(p+(b[qa>>1]|0))|0,v)|0;p=b[qa>>1]|0;qa=b[fa>>1]|0;fa=(e[K+((p<<2)-M<<1)>>1]|0)+ta+(e[K+((qa<<2)-P<<1)>>1]|0)|0;ta=(fa|0)<(sa|0);A=ta?fa:sa;fa=ta?qa:pa;qa=ta?p:Ja;p=X+1|0;if((p|0)<(td|0)){X=p;sa=A;pa=fa;Ja=qa}else{Wa=qa;Xa=fa;Ya=A;break}}break};default:{Wa=ua;Xa=va;Ya=wa}}}while(0);if((Sa|0)==50){Sa=Ma+(ca(Na,v)|0)|0;wa=f+36980+(s<<2)|0;va=Sa-1|0;ua=v<<1;td=Sa+1|0;_e[c[wa>>2]&511](x,y+(Sa-2)|0,y+(va+ua)|0,y+(td+ua)|0,v,Pa);ua=Ma<<2;rd=Na<<2;sd=K+(rd-P<<1)|0;c[Pa>>2]=(e[sd>>1]|0)+(e[K+(-8-M+ua<<1)>>1]|0)+(c[Pa>>2]|0);$c=-4-M|0;qd=K+($c+ua<<1)|0;ad=e[K+(8-P+rd<<1)>>1]|0;c[Qa>>2]=ad+(e[qd>>1]|0)+(c[Qa>>2]|0);_c=4-M|0;w=K+(_c+ua<<1)|0;c[Ra>>2]=ad+(e[w>>1]|0)+(c[Ra>>2]|0);ad=v*-2|0;od=n+16|0;_e[c[wa>>2]&511](x,y+(Sa+2)|0,y+(td+ad)|0,y+(va+ad)|0,v,od);ad=(e[sd>>1]|0)+(e[K+(8-M+ua<<1)>>1]|0)+(c[od>>2]|0)|0;c[od>>2]=ad;od=e[K+(-8-P+rd<<1)>>1]|0;rd=n+20|0;ua=od+(e[w>>1]|0)+(c[rd>>2]|0)|0;c[rd>>2]=ua;rd=n+24|0;w=od+(e[qd>>1]|0)+(c[rd>>2]|0)|0;c[rd>>2]=w;rd=Oa<<3;Oa=c[Pa>>2]<<3|2;qd=(Oa|0)<(rd|0)?Oa:rd;rd=c[Qa>>2]<<3|3;Oa=(rd|0)<(qd|0)?rd:qd;qd=c[Ra>>2]<<3|4;rd=(qd|0)<(Oa|0)?qd:Oa;Oa=ad<<3|5;ad=(Oa|0)<(rd|0)?Oa:rd;rd=ua<<3|6;ua=(rd|0)<(ad|0)?rd:ad;ad=w<<3|7;w=(ad|0)<(ua|0)?ad:ua;ua=w&7;b:do{if((ua|0)==0){ud=Ma;vd=Na;wd=w}else{ad=ua-1|0;rd=a[1142112+(ad<<1)|0]|0;Oa=(rd<<24>>24)+Ma|0;qd=a[1142113+(ad<<1)|0]|0;ad=(qd<<24>>24)+Na|0;od=(La>>1)-1|0;if((od|0)<=0){ud=Oa;vd=ad;wd=w;break}sd=ua-2|0;va=w;td=ad;ad=Oa;Oa=od;od=rd;rd=qd;while(1){qd=ad<<16|td&32767;if(((qd+I|J-qd)&-2147467264|0)!=0){ud=ad;vd=td;wd=va;break b}qd=ad+(ca(td,v)|0)|0;Sa=a[1142112+(sd<<1)|0]|0;pd=a[1142113+(sd<<1)|0]|0;md=y+(Sa+qd+(ca(pd,v)|0))|0;nd=od<<24>>24;id=rd<<24>>24;hd=y+(nd+qd+(ca(id,v)|0))|0;kd=sd+2|0;ld=a[1142112+(kd<<1)|0]|0;jd=a[1142113+(kd<<1)|0]|0;kd=y+(ld+qd+(ca(jd,v)|0))|0;_e[c[wa>>2]&511](x,md,hd,kd,v,Pa);kd=(e[K+((pd+td<<2)-P<<1)>>1]|0)+(e[K+((Sa+ad<<2)-M<<1)>>1]|0)+(c[Pa>>2]|0)|0;c[Pa>>2]=kd;Sa=(e[K+((id+td<<2)-P<<1)>>1]|0)+(e[K+((nd+ad<<2)-M<<1)>>1]|0)+(c[Qa>>2]|0)|0;c[Qa>>2]=Sa;nd=(e[K+((jd+td<<2)-P<<1)>>1]|0)+(e[K+((ld+ad<<2)-M<<1)>>1]|0)+(c[Ra>>2]|0)|0;c[Ra>>2]=nd;ld=va&-8;jd=kd<<3|1;kd=(jd|0)<(ld|0)?jd:ld;ld=Sa<<3|2;Sa=(ld|0)<(kd|0)?ld:kd;kd=nd<<3|3;nd=(kd|0)<(Sa|0)?kd:Sa;Sa=nd&3;if((Sa|0)==0){ud=ad;vd=td;wd=nd;break b}kd=d[830512+(sd-1+Sa)|0]|0;Sa=kd+1|0;ld=a[1142112+(Sa<<1)|0]|0;jd=(ld<<24>>24)+ad|0;id=a[1142113+(Sa<<1)|0]|0;Sa=(id<<24>>24)+td|0;pd=Oa-1|0;if((pd|0)>0){sd=kd;va=nd;td=Sa;ad=jd;Oa=pd;od=ld;rd=id}else{ud=jd;vd=Sa;wd=nd;break}}}}while(0);wa=wd>>>3<<4;wd=ud+(ca(vd,v)|0)|0;J=f+37008+(s<<2)|0;s=wd-1|0;I=wd+1|0;Se[c[J>>2]&1023](x,y+(wd-v)|0,y+(wd+v)|0,y+s|0,y+I|0,v,Pa);wd=ud<<2;w=e[K+(wd-M<<1)>>1]|0;ua=vd<<2;La=K+(-4-P+ua<<1)|0;Na=(e[La>>1]|0)+w+(c[Pa>>2]|0)|0;c[Pa>>2]=Na;Ma=K+(4-P+ua<<1)|0;rd=(e[Ma>>1]|0)+w+(c[Qa>>2]|0)|0;c[Qa>>2]=rd;w=K+($c+wd<<1)|0;$c=e[K+(ua-P<<1)>>1]|0;ua=$c+(e[w>>1]|0)+(c[Ra>>2]|0)|0;c[Ra>>2]=ua;od=K+(_c+wd<<1)|0;wd=n+12|0;n=$c+(e[od>>1]|0)+(c[wd>>2]|0)|0;c[wd>>2]=n;$c=Na<<4|1;Na=($c|0)<(wa|0)?$c:wa;wa=rd<<4|2;rd=(wa|0)<(Na|0)?wa:Na;Na=ua<<4|3;ua=(Na|0)<(rd|0)?Na:rd;rd=n<<4|4;n=(rd|0)<(ua|0)?rd:ua;Se[c[J>>2]&1023](x,y+(s-v)|0,y+(s+v)|0,y+(I-v)|0,y+(I+v)|0,v,Pa);v=e[w>>1]|0;w=e[La>>1]|0;La=w+v+(c[Pa>>2]|0)|0;c[Pa>>2]=La;Pa=e[Ma>>1]|0;Ma=Pa+v+(c[Qa>>2]|0)|0;c[Qa>>2]=Ma;Qa=e[od>>1]|0;od=w+Qa+(c[Ra>>2]|0)|0;c[Ra>>2]=od;Ra=Pa+Qa+(c[wd>>2]|0)|0;c[wd>>2]=Ra;wd=La<<4|5;La=(wd|0)<(n|0)?wd:n;n=Ma<<4|6;Ma=(n|0)<(La|0)?n:La;La=od<<4|7;od=(La|0)<(Ma|0)?La:Ma;Ma=Ra<<4|8;Ra=(Ma|0)<(od|0)?Ma:od;od=Ra&15;Wa=(a[558680+(od<<1)|0]|0)+ud|0;Xa=(a[558681+(od<<1)|0]|0)+vd|0;Ya=Ra>>4}Ra=Wa&65535|Xa<<16;vd=Ra<<2&-196612;if((c[R>>2]|0)<3){od=(e[K+((Xa<<2)-P<<1)>>1]|0)+(e[K+((Wa<<2)-M<<1)>>1]|0)|0;c[g+104>>2]=od;c[g+108>>2]=Ya+((Ra|0)==(Aa|0)?od:0);c[g+112>>2]=vd}else{od=(xa|0)<(Ya|0);c[g+112>>2]=od?Ba:vd;c[g+108>>2]=od?xa:Ya}Ya=c[R>>2]|0;if((Ya|0)<=1){i=l;return}pVb(f,g,d[552626+(Ya<<2)|0]|0,d[552627+(Ya<<2)|0]|0,k,0);i=l;return}function pVb(a,f,g,h,j,k){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;l=i;i=i+1256|0;m=l|0;n=l+1184|0;o=l+1200|0;p=l+1208|0;q=l+1216|0;r=l+1224|0;s=l+1232|0;t=l+1240|0;u=l+1248|0;v=c[f>>2]|0;w=d[19504+(v<<1)|0]|0;x=d[19505+(v<<1)|0]|0;y=c[f+4>>2]|0;z=b[f+100>>1]|0;A=b[f+102>>1]|0;do{if((c[a+18636>>2]|0)==0){B=0}else{if((v|0)<4){B=1;break}B=(c[a+8632>>2]|0)==3}}while(0);C=d[a+36448+v|0]|0;D=c[a+18576>>2]|0;if((c[a+18660>>2]&D&c[f+12>>2]|0)==0){E=0}else{E=(c[a+18612>>2]<<2&4)-2|0}F=m+31&-32;m=f+112|0;G=b[m>>1]|0;H=f+114|0;I=b[H>>1]|0;J=f+108|0;K=c[J>>2]|0;if((g|0)==0){L=G;M=I;N=K}else{do{if((c[a+18632>>2]|0)<3){O=(c[a+18708>>2]|0)+2|0;P=(c[a+18716>>2]|0)-2|0;if((z|0)<(O|0)){Q=O}else{Q=(z|0)>(P|0)?P:z}P=(c[a+18712>>2]|0)+2|0;O=(c[a+18720>>2]|0)-2|0;if((A|0)<(P|0)){R=P}else{R=(A|0)>(O|0)?O:A}if((R-I|Q-G|0)==0){S=G;T=I;U=K;break}c[o>>2]=16;O=Ke[c[a+37380>>2]&63](F,o,f+20|0,c[f+88>>2]|0,Q,R,w,x,c[f+16>>2]|0)|0;P=hf[c[a+36948+(v<<2)>>2]&1023](c[f+72>>2]|0,16,O,c[o>>2]|0)|0;O=(e[y+(Q-z<<1)>>1]|0)+P+(e[y+(R-A<<1)>>1]|0)|0;P=(O|0)<(K|0);S=P?Q:G;T=P?R:I;U=P?O:K}else{S=G;T=I;U=K}}while(0);K=U<<6;a:do{if((g|0)>0){U=a+37380|0;I=f+20|0;G=f+88|0;R=x+1|0;Q=f+16|0;o=F+32|0;O=w+4|0;P=a+37008+(v<<2)|0;V=f+72|0;W=n|0;X=2-A|0;Y=n+4|0;Z=n+8|0;_=2-z|0;$=n+12|0;aa=g;ba=K;ca=T;da=S;while(1){c[p>>2]=64;ea=ca-2|0;fa=Ke[c[U>>2]&63](F,p,I,c[G>>2]|0,da,ea,w,R,c[Q>>2]|0)|0;ga=da-2|0;ha=Ke[c[U>>2]&63](o,p,I,c[G>>2]|0,ga,ca,O,x,c[Q>>2]|0)|0;ia=c[p>>2]|0;Se[c[P>>2]&1023](c[V>>2]|0,fa,fa+ia|0,ha,ha+1|0,ia,W);ia=e[y+(da-z<<1)>>1]|0;ha=(e[y+(ea-A<<1)>>1]|0)+ia+(c[W>>2]|0)|0;c[W>>2]=ha;ea=(e[y+(X+ca<<1)>>1]|0)+ia+(c[Y>>2]|0)|0;c[Y>>2]=ea;ia=e[y+(ca-A<<1)>>1]|0;fa=ia+(e[y+(ga-z<<1)>>1]|0)+(c[Z>>2]|0)|0;c[Z>>2]=fa;ga=ia+(e[y+(_+da<<1)>>1]|0)+(c[$>>2]|0)|0;c[$>>2]=ga;ia=ha<<6|2;ha=(ia|0)<(ba|0)?ia:ba;ia=ea<<6|6;ea=(ia|0)<(ha|0)?ia:ha;ha=fa<<6|16;fa=(ha|0)<(ea|0)?ha:ea;ea=ga<<6|48;ga=(ea|0)<(fa|0)?ea:fa;if((ga&63|0)==0){ja=ga;ka=ca;la=da;break a}fa=da-(ga<<26>>29)|0;ea=ca-(ga<<29>>29)|0;ha=ga&-64;ga=aa-1|0;if((ga|0)>0){aa=ga;ba=ha;ca=ea;da=fa}else{ja=ha;ka=ea;la=fa;break}}}else{ja=K;ka=T;la=S}}while(0);L=la;M=ka;N=ja>>6}ja=(k|0)!=0;do{if(ja){ma=N}else{if(!((c[a+36916>>2]|0)!=(c[a+36948>>2]|0)|B)){ma=N;break}c[q>>2]=16;k=a+37380|0;ka=f+16|0;la=Ke[c[k>>2]&63](F,q,f+20|0,c[f+88>>2]|0,L,M,w,x,c[ka>>2]|0)|0;S=a+36916+(v<<2)|0;T=hf[c[S>>2]&1023](c[f+72>>2]|0,16,la,c[q>>2]|0)|0;la=(e[y+(L-z<<1)>>1]|0)+T+(e[y+(M-A<<1)>>1]|0)|0;do{if(B&(la|0)<268435456){if((c[a+8632>>2]|0)==3){c[q>>2]=16;T=Ke[c[k>>2]&63](F,q,f+36|0,c[f+92>>2]|0,L,M,w,x,(c[ka>>2]|0)+48|0)|0;K=(hf[c[S>>2]&1023](c[f+76>>2]|0,16,T,c[q>>2]|0)|0)+la|0;if((K|0)>=268435456){na=K;break}c[q>>2]=16;T=Ke[c[k>>2]&63](F,q,f+52|0,c[f+96>>2]|0,L,M,w,x,(c[ka>>2]|0)+96|0)|0;na=(hf[c[S>>2]&1023](c[f+80>>2]|0,16,T,c[q>>2]|0)|0)+K|0;break}K=F+8|0;T=x>>>(D>>>0);Te[c[a+37384>>2]&255](F,K,16,c[f+36>>2]|0,c[f+92>>2]|0,L,M+E<<1>>D,w>>>1,T);p=c[ka>>2]|0;g=c[p+92>>2]|0;if((g|0)!=0){_e[c[g+(w>>>3<<2)>>2]&511](F,16,F,16,p+48|0,T)}p=a+36884+(C<<2)|0;g=(hf[c[p>>2]&1023](c[f+76>>2]|0,16,F,16)|0)+la|0;if((g|0)>=268435456){na=g;break}da=c[ka>>2]|0;ca=c[da+140>>2]|0;if((ca|0)!=0){_e[c[ca+(w>>>3<<2)>>2]&511](K,16,K,16,da+96|0,T)}na=(hf[c[p>>2]&1023](c[f+80>>2]|0,16,K,16)|0)+g|0}else{na=la}}while(0);ma=(na|0)<268435456?na:268435456}}while(0);do{if((j|0)!=0){na=c[j>>2]|0;if(((ma*7|0)>>3|0)>(na|0)){c[J>>2]=ma;b[m>>1]=L;b[H>>1]=M;i=l;return}else{if((ma|0)>=(na|0)){break}c[j>>2]=ma;break}}}while(0);j=a+18712|0;b:do{if((c[a+18632>>2]|0)==1){if((M|0)<=(c[j>>2]|0)){oa=L;pa=M;qa=ma;break}if((M|0)>=(c[a+18720>>2]|0)){oa=L;pa=M;qa=ma;break}if((L|0)<=(c[a+18708>>2]|0)){oa=L;pa=M;qa=ma;break}if((L|0)>=(c[a+18716>>2]|0)){oa=L;pa=M;qa=ma;break}na=a+37376|0;q=f+20|0;N=f+88|0;la=M-1|0;ka=f+16|0;Te[c[na>>2]&255](F,64,q,c[N>>2]|0,L,la,w,x,c[ka>>2]|0);S=F+16|0;k=M+1|0;Te[c[na>>2]&255](S,64,q,c[N>>2]|0,L,k,w,x,c[ka>>2]|0);g=F+32|0;K=L-1|0;Te[c[na>>2]&255](g,64,q,c[N>>2]|0,K,M,w,x,c[ka>>2]|0);p=F+48|0;T=L+1|0;Te[c[na>>2]&255](p,64,q,c[N>>2]|0,T,M,w,x,c[ka>>2]|0);ka=n|0;Se[c[a+37008+(v<<2)>>2]&1023](c[f+72>>2]|0,F,S,g,p,64,ka);p=e[y+(L-z<<1)>>1]|0;g=(e[y+(la-A<<1)>>1]|0)+p+(c[ka>>2]|0)|0;c[ka>>2]=g;ka=n+4|0;la=(e[y+(k-A<<1)>>1]|0)+p+(c[ka>>2]|0)|0;c[ka>>2]=la;ka=e[y+(M-A<<1)>>1]|0;p=n+8|0;k=ka+(e[y+(K-z<<1)>>1]|0)+(c[p>>2]|0)|0;c[p>>2]=k;p=n+12|0;K=ka+(e[y+(T-z<<1)>>1]|0)+(c[p>>2]|0)|0;c[p>>2]=K;p=ma<<4;T=g<<4|1;g=(T|0)<(p|0)?T:p;p=la<<4|3;la=(p|0)<(g|0)?p:g;g=k<<4|4;k=(g|0)<(la|0)?g:la;la=K<<4|12;K=(la|0)<(k|0)?la:k;oa=L-(K<<28>>30)|0;pa=M-(K<<30>>30)|0;qa=K>>4}else{K=a+18720|0;k=a+18708|0;la=a+18716|0;g=ja^1;p=a+37380|0;T=f+20|0;ka=f+88|0;S=f+16|0;N=a+36916+(v<<2)|0;q=f+72|0;na=a+8632|0;da=f+36|0;ca=f+92|0;ba=f+76|0;aa=f+52|0;$=f+96|0;_=f+80|0;Z=a+37384|0;Y=F+8|0;X=w>>>1;W=x>>>(D>>>0);V=a+36884+(C<<2)|0;P=w>>>3;Q=L;O=M;G=ma;I=h;o=-1;while(1){if((I|0)<=0){oa=Q;pa=O;qa=G;break b}if((O|0)<=(c[j>>2]|0)){oa=Q;pa=O;qa=G;break b}if((O|0)>=(c[K>>2]|0)){oa=Q;pa=O;qa=G;break b}if((Q|0)<=(c[k>>2]|0)){oa=Q;pa=O;qa=G;break b}if((Q|0)>=(c[la>>2]|0)){oa=Q;pa=O;qa=G;break b}if((o|0)==1&g){ra=O;sa=G;ta=1}else{c[r>>2]=16;U=O-1|0;R=Ke[c[p>>2]&63](F,r,T,c[ka>>2]|0,Q,U,w,x,c[S>>2]|0)|0;fa=hf[c[N>>2]&1023](c[q>>2]|0,16,R,c[r>>2]|0)|0;R=(e[y+(Q-z<<1)>>1]|0)+fa+(e[y+(U-A<<1)>>1]|0)|0;do{if(B&(R|0)<(G|0)){if((c[na>>2]|0)==3){c[r>>2]=16;fa=Ke[c[p>>2]&63](F,r,da,c[ca>>2]|0,Q,U,w,x,(c[S>>2]|0)+48|0)|0;ea=(hf[c[N>>2]&1023](c[ba>>2]|0,16,fa,c[r>>2]|0)|0)+R|0;if((ea|0)>=(G|0)){ua=ea;break}c[r>>2]=16;fa=Ke[c[p>>2]&63](F,r,aa,c[$>>2]|0,Q,U,w,x,(c[S>>2]|0)+96|0)|0;ua=(hf[c[N>>2]&1023](c[_>>2]|0,16,fa,c[r>>2]|0)|0)+ea|0;break}Te[c[Z>>2]&255](F,Y,16,c[da>>2]|0,c[ca>>2]|0,Q,U+E<<1>>D,X,W);ea=c[S>>2]|0;fa=c[ea+92>>2]|0;if((fa|0)!=0){_e[c[fa+(P<<2)>>2]&511](F,16,F,16,ea+48|0,W)}ea=(hf[c[V>>2]&1023](c[ba>>2]|0,16,F,16)|0)+R|0;if((ea|0)>=(G|0)){ua=ea;break}fa=c[S>>2]|0;ha=c[fa+140>>2]|0;if((ha|0)!=0){_e[c[ha+(P<<2)>>2]&511](Y,16,Y,16,fa+96|0,W)}ua=(hf[c[V>>2]&1023](c[_>>2]|0,16,Y,16)|0)+ea|0}else{ua=R}}while(0);R=(ua|0)<(G|0);ra=R?U:O;sa=R?ua:G;ta=R?0:o}if((o|0)==0&g){va=ra;wa=sa;xa=ta}else{c[s>>2]=16;R=O+1|0;ea=Ke[c[p>>2]&63](F,s,T,c[ka>>2]|0,Q,R,w,x,c[S>>2]|0)|0;fa=hf[c[N>>2]&1023](c[q>>2]|0,16,ea,c[s>>2]|0)|0;ea=(e[y+(Q-z<<1)>>1]|0)+fa+(e[y+(R-A<<1)>>1]|0)|0;do{if(B&(ea|0)<(sa|0)){if((c[na>>2]|0)==3){c[s>>2]=16;fa=Ke[c[p>>2]&63](F,s,da,c[ca>>2]|0,Q,R,w,x,(c[S>>2]|0)+48|0)|0;ha=(hf[c[N>>2]&1023](c[ba>>2]|0,16,fa,c[s>>2]|0)|0)+ea|0;if((ha|0)>=(sa|0)){ya=ha;break}c[s>>2]=16;fa=Ke[c[p>>2]&63](F,s,aa,c[$>>2]|0,Q,R,w,x,(c[S>>2]|0)+96|0)|0;ya=(hf[c[N>>2]&1023](c[_>>2]|0,16,fa,c[s>>2]|0)|0)+ha|0;break}Te[c[Z>>2]&255](F,Y,16,c[da>>2]|0,c[ca>>2]|0,Q,R+E<<1>>D,X,W);ha=c[S>>2]|0;fa=c[ha+92>>2]|0;if((fa|0)!=0){_e[c[fa+(P<<2)>>2]&511](F,16,F,16,ha+48|0,W)}ha=(hf[c[V>>2]&1023](c[ba>>2]|0,16,F,16)|0)+ea|0;if((ha|0)>=(sa|0)){ya=ha;break}fa=c[S>>2]|0;ga=c[fa+140>>2]|0;if((ga|0)!=0){_e[c[ga+(P<<2)>>2]&511](Y,16,Y,16,fa+96|0,W)}ya=(hf[c[V>>2]&1023](c[_>>2]|0,16,Y,16)|0)+ha|0}else{ya=ea}}while(0);ea=(ya|0)<(sa|0);va=ea?R:ra;wa=ea?ya:sa;xa=ea?1:ta}if((o|0)==3&g){za=Q;Aa=va;Ba=wa;Ca=xa}else{c[t>>2]=16;ea=Q-1|0;U=Ke[c[p>>2]&63](F,t,T,c[ka>>2]|0,ea,O,w,x,c[S>>2]|0)|0;ha=hf[c[N>>2]&1023](c[q>>2]|0,16,U,c[t>>2]|0)|0;U=(e[y+(ea-z<<1)>>1]|0)+ha+(e[y+(O-A<<1)>>1]|0)|0;do{if(B&(U|0)<(wa|0)){if((c[na>>2]|0)==3){c[t>>2]=16;ha=Ke[c[p>>2]&63](F,t,da,c[ca>>2]|0,ea,O,w,x,(c[S>>2]|0)+48|0)|0;fa=(hf[c[N>>2]&1023](c[ba>>2]|0,16,ha,c[t>>2]|0)|0)+U|0;if((fa|0)>=(wa|0)){Da=fa;break}c[t>>2]=16;ha=Ke[c[p>>2]&63](F,t,aa,c[$>>2]|0,ea,O,w,x,(c[S>>2]|0)+96|0)|0;Da=(hf[c[N>>2]&1023](c[_>>2]|0,16,ha,c[t>>2]|0)|0)+fa|0;break}Te[c[Z>>2]&255](F,Y,16,c[da>>2]|0,c[ca>>2]|0,ea,O+E<<1>>D,X,W);fa=c[S>>2]|0;ha=c[fa+92>>2]|0;if((ha|0)!=0){_e[c[ha+(P<<2)>>2]&511](F,16,F,16,fa+48|0,W)}fa=(hf[c[V>>2]&1023](c[ba>>2]|0,16,F,16)|0)+U|0;if((fa|0)>=(wa|0)){Da=fa;break}ha=c[S>>2]|0;ga=c[ha+140>>2]|0;if((ga|0)!=0){_e[c[ga+(P<<2)>>2]&511](Y,16,Y,16,ha+96|0,W)}Da=(hf[c[V>>2]&1023](c[_>>2]|0,16,Y,16)|0)+fa|0}else{Da=U}}while(0);U=(Da|0)<(wa|0);za=U?ea:Q;Aa=U?O:va;Ba=U?Da:wa;Ca=U?2:xa}if((o|0)==2&g){Ea=za;Fa=Aa;Ga=Ba;Ha=Ca}else{c[u>>2]=16;U=Q+1|0;R=Ke[c[p>>2]&63](F,u,T,c[ka>>2]|0,U,O,w,x,c[S>>2]|0)|0;fa=hf[c[N>>2]&1023](c[q>>2]|0,16,R,c[u>>2]|0)|0;R=(e[y+(U-z<<1)>>1]|0)+fa+(e[y+(O-A<<1)>>1]|0)|0;do{if(B&(R|0)<(Ba|0)){if((c[na>>2]|0)==3){c[u>>2]=16;fa=Ke[c[p>>2]&63](F,u,da,c[ca>>2]|0,U,O,w,x,(c[S>>2]|0)+48|0)|0;ha=(hf[c[N>>2]&1023](c[ba>>2]|0,16,fa,c[u>>2]|0)|0)+R|0;if((ha|0)>=(Ba|0)){Ia=ha;break}c[u>>2]=16;fa=Ke[c[p>>2]&63](F,u,aa,c[$>>2]|0,U,O,w,x,(c[S>>2]|0)+96|0)|0;Ia=(hf[c[N>>2]&1023](c[_>>2]|0,16,fa,c[u>>2]|0)|0)+ha|0;break}Te[c[Z>>2]&255](F,Y,16,c[da>>2]|0,c[ca>>2]|0,U,O+E<<1>>D,X,W);ha=c[S>>2]|0;fa=c[ha+92>>2]|0;if((fa|0)!=0){_e[c[fa+(P<<2)>>2]&511](F,16,F,16,ha+48|0,W)}ha=(hf[c[V>>2]&1023](c[ba>>2]|0,16,F,16)|0)+R|0;if((ha|0)>=(Ba|0)){Ia=ha;break}fa=c[S>>2]|0;ga=c[fa+140>>2]|0;if((ga|0)!=0){_e[c[ga+(P<<2)>>2]&511](Y,16,Y,16,fa+96|0,W)}Ia=(hf[c[V>>2]&1023](c[_>>2]|0,16,Y,16)|0)+ha|0}else{Ia=R}}while(0);R=(Ia|0)<(Ba|0);Ea=R?U:za;Fa=R?O:Aa;Ga=R?Ia:Ba;Ha=R?3:Ca}if((Ea|0)==(Q|0)&(Fa|0)==(O|0)){oa=Q;pa=O;qa=Ga;break}else{Q=Ea;O=Fa;G=Ga;I=I-1|0;o=Ha}}}}while(0);c[J>>2]=qa;b[m>>1]=oa;b[H>>1]=pa;c[f+104>>2]=(e[y+(pa-A<<1)>>1]|0)+(e[y+(oa-z<<1)>>1]|0);i=l;return}function qVb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=c[a+18632>>2]|0;f=d[552624+(e<<2)|0]|0;g=d[552625+(e<<2)|0]|0;if((c[b>>2]|0)>=4){pVb(a,b,f,g,0,1);return}e=b+108|0;c[e>>2]=(c[e>>2]|0)-(c[b+8>>2]|0);pVb(a,b,f,g,0,1);return}function rVb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=c[a+18632>>2]|0;if((f-8|0)>>>0<4>>>0){g=2}else{g=d[552627+(f<<2)|0]|0}pVb(a,b,0,g,e,0);return}function sVb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;k=i;i=i+5616|0;l=k+4640|0;m=k+4856|0;n=c[g>>2]|0;o=d[19504+(n<<1)|0]|0;p=d[19505+(n<<1)|0]|0;q=k+31&-32;r=c[f+24568>>2]|0;s=g+112|0;t=b[s>>1]|0;u=g+114|0;v=b[u>>1]|0;w=h+112|0;x=b[w>>1]|0;y=h+114|0;z=b[y>>1]|0;A=k+5103&-32;B=(c[f+18712>>2]|0)+8|0;if((v|0)<(B|0)|(z|0)<(B|0)){i=k;return}B=(c[f+18720>>2]|0)-8|0;if((v|0)>(B|0)|(z|0)>(B|0)){i=k;return}B=(c[f+18708>>2]|0)+8|0;if((t|0)<(B|0)|(x|0)<(B|0)){i=k;return}B=(c[f+18716>>2]|0)-8|0;if((t|0)>(B|0)|(x|0)>(B|0)){i=k;return}B=c[g+4>>2]|0;C=b[g+100>>1]|0;D=b[g+102>>1]|0;E=c[h+4>>2]|0;F=b[h+100>>1]|0;G=b[h+102>>1]|0;re[c[f+37524>>2]&1023](A|0,512);H=f+37388+(n<<2)|0;I=f+36884+(n<<2)|0;n=g+72|0;J=f+37380|0;f=h+20|0;K=h+88|0;h=g+20|0;L=g+88|0;g=0;M=1;N=1;O=268435456;P=z;z=x;x=v;v=t;while(1){do{if((N|0)!=0){t=c[759690]|0;if((t|0)<9){Q=t}else{break}do{t=a[558680+(Q<<1)|0]|0;R=a[558681+(Q<<1)|0]|0;S=(t*3|0)+4+R|0;T=m+(S<<2)|0;c[T>>2]=o;c[l+(S<<2)>>2]=Ke[c[J>>2]&63](q+(S<<8)|0,T,h,c[L>>2]|0,t+v|0,R+x|0,o,p,2772248)|0;Q=Q+1|0;}while((Q|0)<9)}}while(0);do{if((M|0)!=0){R=c[759690]|0;if((R|0)<9){U=R}else{break}do{R=a[558680+(U<<1)|0]|0;t=a[558681+(U<<1)|0]|0;T=(R*3|0)+4+t|0;S=m+36+(T<<2)|0;c[S>>2]=o;c[l+36+(T<<2)>>2]=Ke[c[J>>2]&63](q+2304+(T<<8)|0,S,f,c[K>>2]|0,R+z|0,t+P|0,o,p,2772248)|0;U=U+1|0;}while((U|0)<9)}}while(0);t=(g|0)!=0;R=0;S=t&1;T=O;while(1){V=a[94600+(S<<2)|0]|0;W=V+v|0;X=a[94601+(S<<2)|0]|0;Y=X+x|0;Z=a[94602+(S<<2)|0]|0;_=Z+z|0;$=a[94603+(S<<2)|0]|0;aa=$+P|0;if(t){ba=(_&7)+(A+((W&7)<<6)+((Y&7)<<3))|0;ca=a[ba]|0;da=1<<(aa&7);if((ca&255&da|0)==0){ea=da;fa=ba;ga=ca;ha=16}else{ia=T;ja=R}}else{ca=(_&7)+(A+((W&7)<<6)+((Y&7)<<3))|0;ea=1<<(aa&7);fa=ca;ga=a[ca]|0;ha=16}if((ha|0)==16){ha=0;ca=(V*3|0)+4+X|0;X=(Z*3|0)+4+$|0;a[fa]=ga&255|ea;Se[c[H>>2]&1023](r,32,c[l+(ca<<2)>>2]|0,c[m+(ca<<2)>>2]|0,c[l+36+(X<<2)>>2]|0,c[m+36+(X<<2)>>2]|0,j);X=hf[c[I>>2]&1023](c[n>>2]|0,16,r,32)|0;ca=(e[B+(W-C<<1)>>1]|0)+X+(e[B+(Y-D<<1)>>1]|0)+(e[E+(_-F<<1)>>1]|0)+(e[E+(aa-G<<1)>>1]|0)|0;aa=(ca|0)<(T|0);ia=aa?ca:T;ja=aa?S:R}aa=S+1|0;if((aa|0)<33){R=ja;S=aa;T=ia}else{break}}if((ja|0)==0){ka=P&65535;la=z&65535;ma=x&65535;na=v&65535;break}T=94600+(ja<<2)|0;S=(a[T|0]|0)+v|0;R=(a[94601+(ja<<2)|0]|0)+x|0;t=94602+(ja<<2)|0;aa=(a[t]|0)+z|0;ca=(a[94603+(ja<<2)|0]|0)+P|0;_=g+1|0;if((_|0)<8){g=_;M=e[t>>1]|0;N=e[T>>1]|0;O=ia;P=ca;z=aa;x=R;v=S}else{ka=ca&65535;la=aa&65535;ma=R&65535;na=S&65535;break}}b[s>>1]=na;b[u>>1]=ma;b[w>>1]=la;b[y>>1]=ka;i=k;return}function tVb(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0;m=i;i=i+14896|0;n=m+13920|0;o=m+14136|0;p=f+19380|0;c[p>>2]=1;q=k&1;r=k>>1;s=q<<1|r<<4|12;t=g|0;u=c[t>>2]|0;v=d[19504+(u<<1)|0]|0;w=d[19505+(u<<1)|0]|0;x=m+31&-32;y=m+4671&-32;z=m+9311&-32;A=d[f+36448+u|0]|0;B=c[f+18576>>2]|0;C=(c[f+24568>>2]|0)+(q<<3|r<<8)|0;D=(8>>>((c[f+18572>>2]|0)>>>0)&-q)+(ca(r<<5,8>>>(B>>>0))|0)|0;r=(c[f+24572>>2]|0)+D|0;q=(c[f+24576>>2]|0)+D|0;D=c[f+18660>>2]|0;if((a[f+28104+s|0]&B&D|0)==0){E=0}else{E=(c[f+18612>>2]<<2&4)-2|0}if((a[f+28144+s|0]&B&D|0)==0){F=0}else{F=(c[f+18612>>2]<<2&4)-2|0}D=g+112|0;H=b[D>>1]|0;I=g+114|0;J=b[I>>1]|0;K=h+112|0;L=b[K>>1]|0;M=h+114|0;N=b[M>>1]|0;O=m+14383&-32;P=(c[f+18712>>2]|0)+8|0;if((J|0)<(P|0)|(N|0)<(P|0)){c[p>>2]=0;i=m;return}P=(c[f+18720>>2]|0)-8|0;if((J|0)>(P|0)|(N|0)>(P|0)){c[p>>2]=0;i=m;return}P=(c[f+18708>>2]|0)+8|0;if((H|0)<(P|0)|(L|0)<(P|0)){c[p>>2]=0;i=m;return}P=(c[f+18716>>2]|0)-8|0;if((H|0)>(P|0)|(L|0)>(P|0)){c[p>>2]=0;i=m;return}if((u|0)==0|(k|0)==0){Q=g+100|0;R=h+100|0;S=k<<2}else{P=k<<2;k=v>>>2;T=g+100|0;dQb(f,0,P,k,T);U=h+100|0;dQb(f,1,P,k,U);Q=T;R=U;S=P}P=c[g+4>>2]|0;U=b[Q>>1]|0;T=g+102|0;k=b[T>>1]|0;V=c[h+4>>2]|0;W=b[R>>1]|0;X=h+102|0;Y=b[X>>1]|0;re[c[f+37524>>2]&1023](O|0,512);Z=f+37388+(u<<2)|0;_=f+36884+(u<<2)|0;u=g+72|0;$=f+28192+(s<<2)|0;aa=f+28352+(s<<2)|0;ba=f+8632|0;da=f+37388+(A<<2)|0;A=f+37380|0;ea=h+20|0;fa=h+88|0;ga=h+36|0;ha=h+92|0;ia=h+52|0;ja=h+96|0;h=f+37384|0;ka=v>>>1;la=w>>>(B>>>0);ma=g+20|0;na=g+88|0;oa=g+36|0;pa=g+92|0;qa=g+52|0;ra=g+96|0;g=0;sa=268435456;ta=0;ua=1;va=1;wa=268435456;xa=N;N=L;L=J;J=H;while(1){do{if((va|0)!=0){H=c[759690]|0;if((H|0)<9){ya=H}else{break}do{H=a[558680+(ya<<1)|0]|0;za=a[558681+(ya<<1)|0]|0;Aa=(H*3|0)+4+za|0;Ba=H+J|0;H=za+L|0;za=o+(Aa<<2)|0;c[za>>2]=v;c[n+(Aa<<2)>>2]=Ke[c[A>>2]&63](x+(Aa<<8)|0,za,ma,c[na>>2]|0,Ba,H,v,w,2772248)|0;if((c[ba>>2]|0)==3){za=o+72+(Aa<<2)|0;c[za>>2]=v;c[n+72+(Aa<<2)>>2]=Ke[c[A>>2]&63](y+(Aa<<8)|0,za,oa,c[pa>>2]|0,Ba,H,v,w,2772248)|0;za=o+144+(Aa<<2)|0;c[za>>2]=v;c[n+144+(Aa<<2)>>2]=Ke[c[A>>2]&63](z+(Aa<<8)|0,za,qa,c[ra>>2]|0,Ba,H,v,w,2772248)|0}else{Te[c[h>>2]&255](y+(Aa<<8)|0,z+(Aa<<8)|0,8,c[oa>>2]|0,c[pa>>2]|0,Ba,H+E<<1>>B,ka,la)}ya=ya+1|0;}while((ya|0)<9)}}while(0);do{if((ua|0)!=0){H=c[759690]|0;if((H|0)<9){Ca=H}else{break}do{H=a[558680+(Ca<<1)|0]|0;Ba=a[558681+(Ca<<1)|0]|0;Aa=(H*3|0)+4+Ba|0;za=H+N|0;H=Ba+xa|0;Ba=o+36+(Aa<<2)|0;c[Ba>>2]=v;c[n+36+(Aa<<2)>>2]=Ke[c[A>>2]&63](x+2304+(Aa<<8)|0,Ba,ea,c[fa>>2]|0,za,H,v,w,2772248)|0;if((c[ba>>2]|0)==3){Ba=o+108+(Aa<<2)|0;c[Ba>>2]=v;c[n+108+(Aa<<2)>>2]=Ke[c[A>>2]&63](y+2304+(Aa<<8)|0,Ba,ga,c[ha>>2]|0,za,H,v,w,2772248)|0;Ba=o+180+(Aa<<2)|0;c[Ba>>2]=v;c[n+180+(Aa<<2)>>2]=Ke[c[A>>2]&63](z+2304+(Aa<<8)|0,Ba,ia,c[ja>>2]|0,za,H,v,w,2772248)|0}else{Te[c[h>>2]&255](y+2304+(Aa<<8)|0,z+2304+(Aa<<8)|0,8,c[ga>>2]|0,c[ha>>2]|0,za,H+F<<1>>B,ka,la)}Ca=Ca+1|0;}while((Ca|0)<9)}}while(0);H=(g|0)!=0;za=0;Aa=H&1;Ba=sa;Da=ta;Ea=wa;while(1){Fa=a[94600+(Aa<<2)|0]|0;Ga=Fa+J|0;Ha=a[94601+(Aa<<2)|0]|0;Ia=Ha+L|0;Ja=a[94602+(Aa<<2)|0]|0;Ka=Ja+N|0;La=a[94603+(Aa<<2)|0]|0;Ma=La+xa|0;if(H){Na=(Ka&7)+(O+((Ga&7)<<6)+((Ia&7)<<3))|0;Oa=a[Na]|0;Pa=1<<(Ma&7);if((Oa&255&Pa|0)==0){Qa=Pa;Ra=Na;Sa=Oa;Ta=29}else{Ua=Ea;Va=Ba;Wa=Da;Xa=za}}else{Oa=(Ka&7)+(O+((Ga&7)<<6)+((Ia&7)<<3))|0;Qa=1<<(Ma&7);Ra=Oa;Sa=a[Oa]|0;Ta=29}do{if((Ta|0)==29){Ta=0;Oa=(Fa*3|0)+4+Ha|0;Na=(Ja*3|0)+4+La|0;a[Ra]=Sa&255|Qa;Se[c[Z>>2]&1023](C,32,c[n+(Oa<<2)>>2]|0,c[o+(Oa<<2)>>2]|0,c[n+36+(Na<<2)>>2]|0,c[o+36+(Na<<2)>>2]|0,j);Pa=hf[c[_>>2]&1023](c[u>>2]|0,16,C,32)|0;Ya=(e[P+(Ga-U<<1)>>1]|0)+Pa+(e[P+(Ia-k<<1)>>1]|0)+(e[V+(Ka-W<<1)>>1]|0)+(e[V+(Ma-Y<<1)>>1]|0)|0;if((Ya|0)>=((Ea>>4)+Ea|0)){Ua=Ea;Va=Ba;Wa=Da;Xa=za;break}c[$>>2]=Ia<<16|Ga&65535;c[aa>>2]=Ma<<16|Ka&65535;if((c[ba>>2]|0)==3){Se[c[Z>>2]&1023](r,32,c[n+72+(Oa<<2)>>2]|0,c[o+72+(Oa<<2)>>2]|0,c[n+108+(Na<<2)>>2]|0,c[o+108+(Na<<2)>>2]|0,j);Se[c[Z>>2]&1023](q,32,c[n+144+(Oa<<2)>>2]|0,c[o+144+(Oa<<2)>>2]|0,c[n+180+(Na<<2)>>2]|0,c[o+180+(Na<<2)>>2]|0,j)}else{Se[c[da>>2]&1023](r,32,y+(Oa<<8)|0,8,y+2304+(Na<<8)|0,8,j);Se[c[da>>2]&1023](q,32,z+(Oa<<8)|0,8,z+2304+(Na<<8)|0,8,j)}Na=UTb(f,l,S,c[t>>2]|0)|0;Oa=G;Pa=Oa>>>0<Ba>>>0|Oa>>>0==Ba>>>0&Na>>>0<Da>>>0;Ua=(Ya|0)<(Ea|0)?Ya:Ea;Va=Pa?Oa:Ba;Wa=Pa?Na:Da;Xa=Pa?Aa:za}}while(0);Ka=Aa+1|0;if((Ka|0)<33){za=Xa;Aa=Ka;Ba=Va;Da=Wa;Ea=Ua}else{break}}if((Xa|0)==0){Za=xa;_a=N;$a=L;ab=J;break}Ea=94600+(Xa<<2)|0;Da=(a[Ea|0]|0)+J|0;Ba=(a[94601+(Xa<<2)|0]|0)+L|0;Aa=94602+(Xa<<2)|0;za=(a[Aa]|0)+N|0;H=(a[94603+(Xa<<2)|0]|0)+xa|0;Ka=g+1|0;if((Ka|0)<8){g=Ka;sa=Va;ta=Wa;ua=e[Aa>>1]|0;va=e[Ea>>1]|0;wa=Ua;xa=H;N=za;L=Ba;J=Da}else{Za=H;_a=za;$a=Ba;ab=Da;break}}J=(v>>>2)-3+(w>>>2<<1)|0;w=100512+(J<<2)|0;re[c[w>>2]&1023](f+28192+(s<<2)|0,$a<<16|ab&65535);v=ab-(b[Q>>1]|0)|0;Q=(v|0)>-1?v:-v|0;v=$a-(b[T>>1]|0)|0;T=(v|0)>-1?v:-v|0;v=100472+(J<<2)|0;re[c[v>>2]&1023](f+28512+(s<<1)|0,((T|0)<33?T<<8:8448)+((Q|0)<33?Q:33)&65535);re[c[w>>2]&1023](f+28352+(s<<2)|0,Za<<16|_a&65535);w=_a-(b[R>>1]|0)|0;R=(w|0)>-1?w:-w|0;w=Za-(b[X>>1]|0)|0;X=(w|0)>-1?w:-w|0;re[c[v>>2]&1023](f+28592+(s<<1)|0,((X|0)<33?X<<8:8448)+((R|0)<33?R:33)&65535);b[D>>1]=ab;b[I>>1]=$a;b[K>>1]=_a;b[M>>1]=Za;c[p>>2]=0;i=m;return}function uVb(f,g,h,i,j){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;k=f+28192+(j*160|0)+(d[18944+i|0]<<2)|0;l=g|0;m=c[l>>2]|0;n=d[19504+(m<<1)|0]|0;o=d[19505+(m<<1)|0]|0;p=c[f+18576>>2]|0;if((c[f+18660>>2]&p&c[g+12>>2]|0)==0){q=0}else{q=(c[f+18612>>2]<<2&4)-2|0}r=g+112|0;s=b[r>>1]|0;t=s<<16>>16;u=g+114|0;v=b[u>>1]|0;w=v<<16>>16;x=e[1901432+(i<<1)>>1]|0;y=(c[f+24568>>2]|0)+x|0;z=f+8632|0;if((c[z>>2]|0)==3){A=(c[f+24576>>2]|0)+x|0;B=(c[f+24572>>2]|0)+x|0}else{x=(ca(256>>>(p>>>0),i>>3)|0)+(i&4)|0;A=(c[f+24576>>2]|0)+x|0;B=(c[f+24572>>2]|0)+x|0}x=f+19380|0;c[x>>2]=1;if((c[l>>2]|0)==0|(i|0)==0){C=g+100|0}else{D=g+100|0;dQb(f,j,i,n>>>2,D);C=D}D=b[C>>1]|0;E=D<<16>>16;F=g+102|0;H=b[F>>1]|0;I=H<<16>>16;J=c[g+4>>2]|0;K=f+37376|0;L=g+20|0;M=g+88|0;N=g+16|0;Te[c[K>>2]&255](y,32,L,c[M>>2]|0,t,w,n,o,c[N>>2]|0);O=f+36884+(m<<2)|0;m=g+72|0;P=hf[c[O>>2]&1023](c[m>>2]|0,16,y,32)|0;Q=(e[J+(t-E<<1)>>1]|0)+P+(e[J+(w-I<<1)>>1]|0)|0;do{if((c[l>>2]|0)==0){P=c[g+108>>2]|0;R=(P|0)<0|0?-1:0;S=P}else{if(!(((Q>>4)+Q|0)>-1)){R=268435456;S=0;break}c[k>>2]=w<<16|t&65535;do{if((c[z>>2]|0)==3){Te[c[K>>2]&255](B,32,g+36|0,c[g+92>>2]|0,t,w,n,o,(c[N>>2]|0)+48|0);Te[c[K>>2]&255](A,32,g+52|0,c[g+96>>2]|0,t,w,n,o,(c[N>>2]|0)+96|0)}else{if((c[l>>2]|0)>=4){break}P=o>>>(p>>>0);Te[c[f+37384>>2]&255](B,A,32,c[g+36>>2]|0,c[g+92>>2]|0,t,w+q<<1>>p,n>>>1,P);T=c[N>>2]|0;U=c[T+92>>2]|0;if((U|0)==0){V=T}else{_e[c[U+(n>>>3<<2)>>2]&511](B,32,B,32,T+48|0,P);V=c[N>>2]|0}T=c[V+140>>2]|0;if((T|0)==0){break}_e[c[T+(n>>>3<<2)>>2]&511](A,32,A,32,V+96|0,P)}}while(0);P=UTb(f,h,i,c[l>>2]|0)|0;T=G;U=268435456;W=T>>>0<U>>>0|T>>>0==U>>>0&P>>>0<0>>>0;R=W?T:268435456;S=W?P:0}}while(0);do{if(s<<16>>16==D<<16>>16&v<<16>>16==H<<16>>16){X=R;Y=S;Z=t;_=w;$=E;aa=I;ba=Q}else{if((E|0)<(c[f+18708>>2]|0)){X=R;Y=S;Z=t;_=w;$=E;aa=I;ba=Q;break}if((E|0)>(c[f+18716>>2]|0)){X=R;Y=S;Z=t;_=w;$=E;aa=I;ba=Q;break}if((I|0)<(c[f+18712>>2]|0)){X=R;Y=S;Z=t;_=w;$=E;aa=I;ba=Q;break}if((I|0)>(c[f+18720>>2]|0)){X=R;Y=S;Z=t;_=w;$=E;aa=I;ba=Q;break}Te[c[K>>2]&255](y,32,L,c[M>>2]|0,E,I,n,o,c[N>>2]|0);V=hf[c[O>>2]&1023](c[m>>2]|0,16,y,32)|0;P=(e[J>>1]<<1)+V|0;V=(P|0)<(Q|0)?P:Q;if((P|0)>((V>>4)+V|0)){da=R;ea=S;fa=t;ga=w}else{c[k>>2]=I<<16|E&65535;do{if((c[z>>2]|0)==3){Te[c[K>>2]&255](B,32,g+36|0,c[g+92>>2]|0,E,I,n,o,(c[N>>2]|0)+48|0);Te[c[K>>2]&255](A,32,g+52|0,c[g+96>>2]|0,E,I,n,o,(c[N>>2]|0)+96|0)}else{if((c[l>>2]|0)>=4){break}P=o>>>(p>>>0);Te[c[f+37384>>2]&255](B,A,32,c[g+36>>2]|0,c[g+92>>2]|0,E,I+q<<1>>p,n>>>1,P);W=c[N>>2]|0;T=c[W+92>>2]|0;if((T|0)==0){ha=W}else{_e[c[T+(n>>>3<<2)>>2]&511](B,32,B,32,W+48|0,P);ha=c[N>>2]|0}W=c[ha+140>>2]|0;if((W|0)==0){break}_e[c[W+(n>>>3<<2)>>2]&511](A,32,A,32,ha+96|0,P)}}while(0);P=UTb(f,h,i,c[l>>2]|0)|0;W=G;T=W>>>0<R>>>0|W>>>0==R>>>0&P>>>0<S>>>0;da=T?W:R;ea=T?P:S;fa=T?E:t;ga=T?I:w}if(!((fa|0)==(E|0)&(ga|0)==(I|0))){X=da;Y=ea;Z=fa;_=ga;$=E;aa=I;ba=V;break}X=da;Y=ea;Z=E;_=I;$=b[r>>1]|0;aa=b[u>>1]|0;ba=V}}while(0);ea=f+18712|0;if((_|0)<((c[ea>>2]|0)+3|0)){c[x>>2]=0;return}da=f+18720|0;if((_|0)>((c[da>>2]|0)-3|0)){c[x>>2]=0;return}if((Z|0)<((c[f+18708>>2]|0)+3|0)){c[x>>2]=0;return}if((Z|0)>((c[f+18716>>2]|0)-3|0)){c[x>>2]=0;return}ga=k;k=g+36|0;fa=g+92|0;w=g+52|0;t=g+96|0;S=f+37384|0;R=_+q|0;ha=n>>>1;Q=o>>>(p>>>0);H=n>>>3;v=Z-E|0;D=_-I|0;s=-2;T=ba;ba=0;P=_;W=Z;U=X;X=Y;a:while(1){Y=T;ia=ba;while(1){ja=ia+1|0;ka=a[1142112+(ja<<1)|0]|0;la=ka+Z|0;ma=a[1142113+(ja<<1)|0]|0;if((la|0)==($|0)){if(((ma<<24>>24)+_|0)==(aa|0)){na=268435456;oa=Y}else{pa=44}}else{pa=44}if((pa|0)==44){pa=0;qa=ma<<24>>24;Te[c[K>>2]&255](y,32,L,c[M>>2]|0,la,qa+_|0,n,o,c[N>>2]|0);ra=hf[c[O>>2]&1023](c[m>>2]|0,16,y,32)|0;sa=(e[J+(v+ka<<1)>>1]|0)+ra+(e[J+(D+qa<<1)>>1]|0)|0;na=sa;oa=(sa|0)<(Y|0)?sa:Y}if((na|0)<=((oa>>4)+oa|0)){sa=ma<<24>>24;ta=sa+_|0;c[ga>>2]=ta<<16|la&65535;do{if((c[z>>2]|0)==3){Te[c[K>>2]&255](B,32,k,c[fa>>2]|0,la,ta,n,o,(c[N>>2]|0)+48|0);Te[c[K>>2]&255](A,32,w,c[t>>2]|0,la,ta,n,o,(c[N>>2]|0)+96|0)}else{if((c[l>>2]|0)>=4){break}Te[c[S>>2]&255](B,A,32,c[k>>2]|0,c[fa>>2]|0,la,R+sa<<1>>p,ha,Q);ma=c[N>>2]|0;qa=c[ma+92>>2]|0;if((qa|0)==0){ua=ma}else{_e[c[qa+(H<<2)>>2]&511](B,32,B,32,ma+48|0,Q);ua=c[N>>2]|0}ma=c[ua+140>>2]|0;if((ma|0)==0){break}_e[c[ma+(H<<2)>>2]&511](A,32,A,32,ua+96|0,Q)}}while(0);va=UTb(f,h,i,c[l>>2]|0)|0;wa=G;if(wa>>>0<U>>>0|wa>>>0==U>>>0&va>>>0<X>>>0){break}}if((ja|0)<6){Y=oa;ia=ja}else{xa=s;ya=P;za=W;Aa=U;Ba=X;break a}}if((ja|0)<6){s=ia;T=oa;ba=ja;P=ta;W=la;U=wa;X=va}else{xa=ia;ya=ta;za=la;Aa=wa;Ba=va;break}}b:do{if((xa|0)==-2){Ca=Aa;Da=Ba;Ea=za;Fa=ya;Ga=oa}else{va=Aa;wa=Ba;la=za;ta=ya;X=1;U=oa;W=xa;while(1){if((X|0)>=10){Ca=va;Da=wa;Ea=la;Fa=ta;Ga=U;break b}P=d[W+830513|0]|0;if((ta|0)<((c[ea>>2]|0)+3|0)){Ca=va;Da=wa;Ea=la;Fa=ta;Ga=U;break b}if((ta|0)>((c[da>>2]|0)-3|0)){Ca=va;Da=wa;Ea=la;Fa=ta;Ga=U;break b}ja=P-1|0;ba=ta+q|0;T=la-E|0;s=ta-I|0;ua=-2;R=U;_=ta;na=0;D=la;v=va;Z=wa;while(1){Y=na+P|0;V=a[1142112+(Y<<1)|0]|0;sa=V+la|0;ma=a[1142113+(Y<<1)|0]|0;if((sa|0)==($|0)){if(((ma<<24>>24)+ta|0)==(aa|0)){Ha=268435456;Ia=R}else{pa=63}}else{pa=63}if((pa|0)==63){pa=0;Y=ma<<24>>24;Te[c[K>>2]&255](y,32,L,c[M>>2]|0,sa,Y+ta|0,n,o,c[N>>2]|0);qa=hf[c[O>>2]&1023](c[m>>2]|0,16,y,32)|0;ra=(e[J+(T+V<<1)>>1]|0)+qa+(e[J+(s+Y<<1)>>1]|0)|0;Ha=ra;Ia=(ra|0)<(R|0)?ra:R}if((Ha|0)>((Ia>>4)+Ia|0)){Ja=v;Ka=Z;La=D;Ma=_;Na=ua}else{ra=ma<<24>>24;ma=ra+ta|0;c[ga>>2]=ma<<16|sa&65535;do{if((c[z>>2]|0)==3){Te[c[K>>2]&255](B,32,k,c[fa>>2]|0,sa,ma,n,o,(c[N>>2]|0)+48|0);Te[c[K>>2]&255](A,32,w,c[t>>2]|0,sa,ma,n,o,(c[N>>2]|0)+96|0)}else{if((c[l>>2]|0)>=4){break}Te[c[S>>2]&255](B,A,32,c[k>>2]|0,c[fa>>2]|0,sa,ba+ra<<1>>p,ha,Q);Y=c[N>>2]|0;qa=c[Y+92>>2]|0;if((qa|0)==0){Oa=Y}else{_e[c[qa+(H<<2)>>2]&511](B,32,B,32,Y+48|0,Q);Oa=c[N>>2]|0}Y=c[Oa+140>>2]|0;if((Y|0)==0){break}_e[c[Y+(H<<2)>>2]&511](A,32,A,32,Oa+96|0,Q)}}while(0);ra=UTb(f,h,i,c[l>>2]|0)|0;Y=G;qa=Y>>>0<v>>>0|Y>>>0==v>>>0&ra>>>0<Z>>>0;Ja=qa?Y:v;Ka=qa?ra:Z;La=qa?sa:D;Ma=qa?ma:_;Na=qa?ja+na|0:ua}qa=na+1|0;if((qa|0)<3){ua=Na;R=Ia;_=Ma;na=qa;D=La;v=Ja;Z=Ka}else{break}}if((Na|0)==-2){Ca=Ja;Da=Ka;Ea=La;Fa=Ma;Ga=Ia;break}else{va=Ja;wa=Ka;la=La;ta=Ma;X=X+1|0;U=Ia;W=Na}}}}while(0);Na=Fa+q|0;q=Ea-E|0;E=Fa-I|0;I=Ga;Ga=Fa;Ia=Ea;Ma=0;La=Ca;Ca=Da;c:while(1){Da=I;Ka=Ma;while(1){Pa=Ka+1|0;Ja=a[558680+(Pa<<1)|0]|0;Qa=Ja+Ea|0;Oa=a[558681+(Pa<<1)|0]|0;if((Qa|0)==($|0)){if(((Oa<<24>>24)+Fa|0)==(aa|0)){Ra=268435456;Sa=Da}else{pa=79}}else{pa=79}if((pa|0)==79){pa=0;Ha=Oa<<24>>24;Te[c[K>>2]&255](y,32,L,c[M>>2]|0,Qa,Ha+Fa|0,n,o,c[N>>2]|0);da=hf[c[O>>2]&1023](c[m>>2]|0,16,y,32)|0;ea=(e[J+(q+Ja<<1)>>1]|0)+da+(e[J+(E+Ha<<1)>>1]|0)|0;Ra=ea;Sa=(ea|0)<(Da|0)?ea:Da}if((Ra|0)<=((Sa>>4)+Sa|0)){ea=Oa<<24>>24;Ta=ea+Fa|0;c[ga>>2]=Ta<<16|Qa&65535;do{if((c[z>>2]|0)==3){Te[c[K>>2]&255](B,32,k,c[fa>>2]|0,Qa,Ta,n,o,(c[N>>2]|0)+48|0);Te[c[K>>2]&255](A,32,w,c[t>>2]|0,Qa,Ta,n,o,(c[N>>2]|0)+96|0)}else{if((c[l>>2]|0)>=4){break}Te[c[S>>2]&255](B,A,32,c[k>>2]|0,c[fa>>2]|0,Qa,Na+ea<<1>>p,ha,Q);Oa=c[N>>2]|0;Ha=c[Oa+92>>2]|0;if((Ha|0)==0){Ua=Oa}else{_e[c[Ha+(H<<2)>>2]&511](B,32,B,32,Oa+48|0,Q);Ua=c[N>>2]|0}Oa=c[Ua+140>>2]|0;if((Oa|0)==0){break}_e[c[Oa+(H<<2)>>2]&511](A,32,A,32,Ua+96|0,Q)}}while(0);Va=UTb(f,h,i,c[l>>2]|0)|0;Wa=G;if(Wa>>>0<La>>>0|Wa>>>0==La>>>0&Va>>>0<Ca>>>0){break}}if((Pa|0)<8){Da=Sa;Ka=Pa}else{Xa=Ga;Ya=Ia;Za=Ca;break c}}if((Pa|0)<8){I=Sa;Ga=Ta;Ia=Qa;Ma=Pa;La=Wa;Ca=Va}else{Xa=Ta;Ya=Qa;Za=Va;break}}c[g+108>>2]=Za;b[r>>1]=Ya;b[u>>1]=Xa;u=(d[1901544+i|0]|0)+12+(d[1901336+i|0]<<3)|0;i=(n>>>2)-3+(o>>>2<<1)|0;re[c[100512+(i<<2)>>2]&1023](f+28192+(j*160|0)+(u<<2)|0,Ya&65535|Xa<<16);o=Ya-(b[C>>1]|0)|0;C=(o|0)>-1?o:-o|0;o=Xa-(b[F>>1]|0)|0;F=(o|0)>-1?o:-o|0;re[c[100472+(i<<2)>>2]&1023](f+28512+(j*80|0)+(u<<1)|0,((F|0)<66?F<<8:16896)+((C|0)<66?C:66)&65535);c[x>>2]=0;return}function vVb(a){a=a|0;var b=0,d=0,e=0;ve[c[(c[a+38028>>2]|0)+56>>2]&4095](c[a+38040>>2]|0)|0;b=a+50352|0;if((c[b>>2]|0)>0){d=0}else{c[b>>2]=0;e=a+38060|0;c[e>>2]=0;return}do{nrc(c[a+38064+(d*12|0)+4>>2]|0,c[a+38064+(d*12|0)>>2]|0,c[a+38064+(d*12|0)+8>>2]|0)|0;d=d+1|0;}while((d|0)<(c[b>>2]|0));c[b>>2]=0;e=a+38060|0;c[e>>2]=0;return}function wVb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=f+48|0;o=f+56|0;p=f+64|0;c[g>>2]=e;e=d+8508|0;if((c[e>>2]|0)!=0){q=0;i=f;return q|0}c[e>>2]=1;e=a+38028|0;r=c[e>>2]|0;s=d+156|0;t=ca(c[d+180>>2]|0,c[s>>2]|0)|0;u=a+18560|0;v=a+18568|0;w=c[v>>2]|0;x=a+50456|0;a:do{if((c[x>>2]|0)==0){y=c[u>>2]|0;z=y<<3;A=a+18564|0;B=c[A>>2]|0;C=B<<3;D=j|0;c[D>>2]=4272;E=j+4|0;c[E>>2]=4316;F=r+20|0;G=a+38032|0;c[a+50416>>2]=Ke[c[F>>2]&63](c[G>>2]|0,1,0,j,z,C,0,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2382176,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}c[D>>2]=4277;c[E>>2]=4314;c[a+50400>>2]=Ke[c[F>>2]&63](c[G>>2]|0,1,0,j,z,C,0,0,h)|0;C=c[h>>2]|0;do{if((C|0)==0){c[D>>2]=4277;c[E>>2]=4314;c[a+50404>>2]=Ke[c[F>>2]&63](c[G>>2]|0,1,0,j,y<<2,B<<2,0,0,h)|0;z=c[h>>2]|0;if((z|0)!=0){J=z;break}c[D>>2]=4277;c[E>>2]=4314;c[a+50408>>2]=Ke[c[F>>2]&63](c[G>>2]|0,1,0,j,y<<1,B<<1,0,0,h)|0;z=c[h>>2]|0;if((z|0)!=0){J=z;break}c[D>>2]=4277;c[E>>2]=4314;c[a+50412>>2]=Ke[c[F>>2]&63](c[G>>2]|0,1,0,j,y,B,0,0,h)|0;z=c[h>>2]|0;if((z|0)!=0){J=z;break}z=r+8|0;H=w<<1;c[x>>2]=se[c[z>>2]&127](c[G>>2]|0,1,0,H,0,h)|0;K=c[h>>2]|0;if((K|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=K,I)|0);i=I;q=-1;i=f;return q|0}c[a+50472>>2]=se[c[z>>2]&127](c[G>>2]|0,1,0,H,0,h)|0;K=c[h>>2]|0;if((K|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=K,I)|0);i=I;q=-1;i=f;return q|0}c[a+50476>>2]=se[c[z>>2]&127](c[G>>2]|0,1,0,H,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}H=w<<2;c[a+50448>>2]=se[c[z>>2]&127](c[G>>2]|0,1,0,H,0,h)|0;K=c[h>>2]|0;if((K|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=K,I)|0);i=I;q=-1;i=f;return q|0}c[a+50452>>2]=se[c[z>>2]&127](c[G>>2]|0,1,0,H,0,h)|0;K=c[h>>2]|0;if((K|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=K,I)|0);i=I;q=-1;i=f;return q|0}c[a+50460>>2]=se[c[z>>2]&127](c[G>>2]|0,1,0,H,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}c[a+50480>>2]=se[c[z>>2]&127](c[G>>2]|0,2,0,16,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}c[a+50484>>2]=se[c[z>>2]&127](c[G>>2]|0,2,0,16,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}c[a+50432>>2]=se[c[z>>2]&127](c[G>>2]|0,2,0,c[A>>2]<<2,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}c[a+50436>>2]=se[c[z>>2]&127](c[G>>2]|0,2,0,c[A>>2]<<2,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}c[a+50384>>2]=se[c[z>>2]&127](c[G>>2]|0,4,0,t,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}c[a+50388>>2]=se[c[z>>2]&127](c[G>>2]|0,4,0,t,0,h)|0;z=c[h>>2]|0;if((z|0)==0){break a}c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=z,I)|0);i=I;q=-1;i=f;return q|0}else{J=C}}while(0);c[a+816>>2]=0;ILb(a,0,2382176,(I=i,i=i+8|0,c[I>>2]=J,I)|0);i=I;q=-1;i=f;return q|0}}while(0);J=d+12048|0;b:do{if((c[J>>2]|0)==0){x=c[u>>2]|0;j=x<<3;C=c[a+18564>>2]|0;G=C<<3;A=k|0;c[A>>2]=4272;B=k+4|0;c[B>>2]=4316;y=r+20|0;F=a+38032|0;c[d+12040>>2]=Ke[c[y>>2]&63](c[F>>2]|0,1,0,k,j,G,0,0,h)|0;E=c[h>>2]|0;if((E|0)!=0){c[a+816>>2]=0;ILb(a,0,2382176,(I=i,i=i+8|0,c[I>>2]=E,I)|0);i=I;q=-1;i=f;return q|0}c[A>>2]=4277;c[B>>2]=4314;c[d+12024>>2]=Ke[c[y>>2]&63](c[F>>2]|0,1,0,k,j,G,0,0,h)|0;G=c[h>>2]|0;do{if((G|0)==0){c[A>>2]=4277;c[B>>2]=4314;c[d+12028>>2]=Ke[c[y>>2]&63](c[F>>2]|0,1,0,k,x<<2,C<<2,0,0,h)|0;j=c[h>>2]|0;if((j|0)!=0){L=j;break}c[A>>2]=4277;c[B>>2]=4314;c[d+12032>>2]=Ke[c[y>>2]&63](c[F>>2]|0,1,0,k,x<<1,C<<1,0,0,h)|0;j=c[h>>2]|0;if((j|0)!=0){L=j;break}c[A>>2]=4277;c[B>>2]=4314;c[d+12036>>2]=Ke[c[y>>2]&63](c[F>>2]|0,1,0,k,x,C,0,0,h)|0;j=c[h>>2]|0;if((j|0)!=0){L=j;break}j=r+8|0;E=w<<1;c[d+12044>>2]=se[c[j>>2]&127](c[F>>2]|0,4,0,E,0,h)|0;D=c[h>>2]|0;if((D|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=D,I)|0);i=I;q=-1;i=f;return q|0}c[J>>2]=se[c[j>>2]&127](c[F>>2]|0,2,0,E,0,h)|0;D=c[h>>2]|0;if((D|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=D,I)|0);i=I;q=-1;i=f;return q|0}D=w<<2;z=a+112|0;H=ca((c[z>>2]|0)+1|0,D)|0;c[d+12052>>2]=se[c[j>>2]&127](c[F>>2]|0,1,0,H,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}H=ca((c[z>>2]|0)+1|0,D)|0;c[d+12056>>2]=se[c[j>>2]&127](c[F>>2]|0,1,0,H,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}H=ca((c[z>>2]|0)+1|0,E)|0;c[d+12060>>2]=se[c[j>>2]&127](c[F>>2]|0,1,0,H,0,h)|0;H=c[h>>2]|0;if((H|0)!=0){c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}H=ca((c[z>>2]|0)+1|0,E)|0;c[d+12064>>2]=se[c[j>>2]&127](c[F>>2]|0,1,0,H,0,h)|0;H=c[h>>2]|0;if((H|0)==0){break b}c[a+816>>2]=0;ILb(a,0,2572440,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}else{L=G}}while(0);c[a+816>>2]=0;ILb(a,0,2382176,(I=i,i=i+8|0,c[I>>2]=L,I)|0);i=I;q=-1;i=f;return q|0}}while(0);L=a+38060|0;w=c[L>>2]|0;if((w+t|0)>33554431){ve[c[(c[e>>2]|0)+56>>2]&4095](c[a+38040>>2]|0)|0;k=a+50352|0;if((c[k>>2]|0)>0){G=0;do{nrc(c[a+38064+(G*12|0)+4>>2]|0,c[a+38064+(G*12|0)>>2]|0,c[a+38064+(G*12|0)+8>>2]|0)|0;G=G+1|0;}while((G|0)<(c[k>>2]|0))}c[k>>2]=0;c[L>>2]=0;M=0}else{M=w}if((t|0)>=33554432){Cd(2164656,2138720,74,2649312);return 0}w=a+38056|0;k=(c[w>>2]|0)+M|0;c[L>>2]=M+t;nrc(k|0,c[d+204>>2]|0,t)|0;M=a+50360|0;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}G=r+52|0;F=a+38040|0;C=a+38048|0;x=Ke[c[G>>2]&63](c[F>>2]|0,c[a+50384+(c[C>>2]<<2)>>2]|0,0,0,t,k,0,0,0)|0;c[h>>2]=x;if((x|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2432448,(I=i,i=i+8|0,c[I>>2]=x,I)|0);i=I;q=-1;i=f;return q|0}do{if((c[a+684>>2]|0)==0){N=68}else{x=d+8520|0;if((c[x>>2]|0)==0){N=68;break}k=c[v>>2]<<1;t=c[L>>2]|0;if((t+k|0)>33554431){ve[c[(c[e>>2]|0)+56>>2]&4095](c[F>>2]|0)|0;y=a+50352|0;if((c[y>>2]|0)>0){B=0;do{nrc(c[a+38064+(B*12|0)+4>>2]|0,c[a+38064+(B*12|0)>>2]|0,c[a+38064+(B*12|0)+8>>2]|0)|0;B=B+1|0;}while((B|0)<(c[y>>2]|0))}c[y>>2]=0;c[L>>2]=0;O=0}else{O=t}if((k|0)>=33554432){Cd(2164656,2138720,74,2649312);return 0}B=(c[w>>2]|0)+O|0;c[L>>2]=O+k;nrc(B|0,c[x>>2]|0,k)|0;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}A=Ke[c[G>>2]&63](c[F>>2]|0,c[d+12044>>2]|0,0,0,k,B,0,0,0)|0;c[h>>2]=A;if((A|0)==0){break}c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2432448,(I=i,i=i+8|0,c[I>>2]=A,I)|0);i=I;q=-1;i=f;return q|0}}while(0);do{if((N|0)==68){b[m>>1]=256;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}G=r+112|0;O=a+50420|0;A=hf[c[G>>2]&1023](c[O>>2]|0,0,4,d+12044|0)|0;c[h>>2]=A;if((A|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=A,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}A=hf[c[G>>2]&1023](c[O>>2]|0,1,2,m)|0;c[h>>2]=A;if((A|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=A,I)|0);i=I;q=-1;i=f;return q|0}A=l|0;c[A>>2]=c[v>>2];if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}G=Ke[c[r+44>>2]&63](c[F>>2]|0,c[O>>2]|0,1,0,A,0,0,0,0)|0;c[h>>2]=G;if((G|0)==0){break}c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2286200,(I=i,i=i+8|0,c[I>>2]=G,I)|0);i=I;q=-1;i=f;return q|0}}while(0);c[n>>2]=c[s>>2];if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}s=r+112|0;m=a+50372|0;G=hf[c[s>>2]&1023](c[m>>2]|0,0,4,a+50384+(c[C>>2]<<2)|0)|0;c[h>>2]=G;if((G|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=G,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}G=d+12024|0;A=hf[c[s>>2]&1023](c[m>>2]|0,1,4,G)|0;c[h>>2]=A;if((A|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=A,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}A=hf[c[s>>2]&1023](c[m>>2]|0,2,4,d+12040|0)|0;c[h>>2]=A;if((A|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=A,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}A=hf[c[s>>2]&1023](c[m>>2]|0,3,4,n)|0;c[h>>2]=A;if((A|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=A,I)|0);i=I;q=-1;i=f;return q|0}A=u|0;n=l|0;c[n>>2]=c[A>>2]<<3;O=a+18564|0;B=l+4|0;c[B>>2]=c[O>>2]<<3;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}l=r+44|0;H=Ke[c[l>>2]&63](c[F>>2]|0,c[m>>2]|0,2,0,n,0,0,0,0)|0;c[h>>2]=H;if((H|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2286200,(I=i,i=i+8|0,c[I>>2]=H,I)|0);i=I;q=-1;i=f;return q|0}H=a+50376|0;m=a+50380|0;j=0;while(1){if((j|0)>=3){N=104;break}E=c[((j&1|0)==0?m:H)>>2]|0;if((c[M>>2]|0)!=0){q=-1;N=174;break}P=hf[c[s>>2]&1023](E,0,4,d+12024+(j<<2)|0)|0;c[h>>2]=P;if((P|0)!=0){N=96;break}if((c[M>>2]|0)!=0){q=-1;N=174;break}z=j+1|0;Q=hf[c[s>>2]&1023](E,1,4,d+12024+(z<<2)|0)|0;c[h>>2]=Q;if((Q|0)!=0){N=99;break}D=c[n>>2]|0;c[n>>2]=D>>>1;K=c[B>>2]|0;c[B>>2]=K>>>1;if(D>>>0<32>>>0|K>>>0<32>>>0){N=104;break}if((c[M>>2]|0)!=0){q=-1;N=174;break}R=Ke[c[l>>2]&63](c[F>>2]|0,E,2,0,n,0,0,0,0)|0;c[h>>2]=R;if((R|0)==0){j=z}else{N=103;break}}if((N|0)==96){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=P,I)|0);i=I;q=-1;i=f;return q|0}else if((N|0)==99){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=Q,I)|0);i=I;q=-1;i=f;return q|0}else if((N|0)==103){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2286200,(I=i,i=i+8|0,c[I>>2]=R,I)|0);i=I;q=-1;i=f;return q|0}else if((N|0)==104){c[n>>2]=(c[A>>2]|0)+31&-32;c[B>>2]=c[O>>2]<<3;A=o|0;c[A>>2]=32;R=o+4|0;c[R>>2]=8;c[p>>2]=(c[a+560>>2]|0)>7;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}o=a+50424|0;Q=hf[c[s>>2]&1023](c[o>>2]|0,0,4,G)|0;c[h>>2]=Q;if((Q|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=Q,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}Q=J;G=hf[c[s>>2]&1023](c[o>>2]|0,1,4,Q)|0;c[h>>2]=G;if((G|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=G,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}G=hf[c[s>>2]&1023](c[o>>2]|0,2,4,a+50480+(c[C>>2]<<2)|0)|0;c[h>>2]=G;if((G|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=G,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}G=hf[c[s>>2]&1023](c[o>>2]|0,3,4,g)|0;c[h>>2]=G;if((G|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=G,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}G=u;u=hf[c[s>>2]&1023](c[o>>2]|0,4,4,G)|0;c[h>>2]=u;if((u|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=u,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}u=hf[c[s>>2]&1023](c[o>>2]|0,5,4,p)|0;c[h>>2]=u;if((u|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=u,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}u=Ke[c[l>>2]&63](c[F>>2]|0,c[o>>2]|0,2,0,n,A,0,0,0)|0;c[h>>2]=u;if((u|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2286200,(I=i,i=i+8|0,c[I>>2]=u,I)|0);i=I;q=-1;i=f;return q|0}c[n>>2]=256;c[B>>2]=c[O>>2];c[A>>2]=256;c[R>>2]=1;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}R=a+50428|0;B=hf[c[s>>2]&1023](c[R>>2]|0,0,4,Q)|0;c[h>>2]=B;if((B|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=B,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}B=hf[c[s>>2]&1023](c[R>>2]|0,1,4,d+12044|0)|0;c[h>>2]=B;if((B|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=B,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}B=hf[c[s>>2]&1023](c[R>>2]|0,2,4,a+50432+(c[C>>2]<<2)|0)|0;c[h>>2]=B;if((B|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=B,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}B=hf[c[s>>2]&1023](c[R>>2]|0,3,4,a+50480+(c[C>>2]<<2)|0)|0;c[h>>2]=B;if((B|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=B,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}B=hf[c[s>>2]&1023](c[R>>2]|0,4,4,G)|0;c[h>>2]=B;if((B|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2347288,(I=i,i=i+8|0,c[I>>2]=B,I)|0);i=I;q=-1;i=f;return q|0}if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}B=Ke[c[l>>2]&63](c[F>>2]|0,c[R>>2]|0,2,0,n,A,0,0,0)|0;c[h>>2]=B;if((B|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2286200,(I=i,i=i+8|0,c[I>>2]=B,I)|0);i=I;q=-1;i=f;return q|0}B=a+50352|0;if((c[B>>2]|0)>1019){ve[c[(c[e>>2]|0)+56>>2]&4095](c[F>>2]|0)|0;if((c[B>>2]|0)>0){A=0;do{nrc(c[a+38064+(A*12|0)+4>>2]|0,c[a+38064+(A*12|0)>>2]|0,c[a+38064+(A*12|0)+8>>2]|0)|0;A=A+1|0;}while((A|0)<(c[B>>2]|0))}c[B>>2]=0;c[L>>2]=0;S=0}else{S=c[L>>2]|0}A=c[v>>2]<<1;if((S+A|0)>33554431){ve[c[(c[e>>2]|0)+56>>2]&4095](c[F>>2]|0)|0;if((c[B>>2]|0)>0){v=0;do{nrc(c[a+38064+(v*12|0)+4>>2]|0,c[a+38064+(v*12|0)>>2]|0,c[a+38064+(v*12|0)+8>>2]|0)|0;v=v+1|0;}while((v|0)<(c[B>>2]|0))}c[B>>2]=0;c[L>>2]=0;T=0}else{T=S}if((A|0)>=33554432){Cd(2164656,2138720,74,2649312);return 0}S=(c[w>>2]|0)+T|0;c[L>>2]=T+A;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}T=r+48|0;r=Ke[c[T>>2]&63](c[F>>2]|0,c[J>>2]|0,0,0,A,S,0,0,0)|0;c[h>>2]=r;if((r|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2236400,(I=i,i=i+8|0,c[I>>2]=r,I)|0);i=I;q=-1;i=f;return q|0}c[a+38064+((c[B>>2]|0)*12|0)+4>>2]=c[d+2940>>2];c[a+38064+((c[B>>2]|0)*12|0)>>2]=S;c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=A;c[B>>2]=(c[B>>2]|0)+1;A=c[O>>2]<<2;O=c[L>>2]|0;if((O+A|0)>33554431){ve[c[(c[e>>2]|0)+56>>2]&4095](c[F>>2]|0)|0;if((c[B>>2]|0)>0){S=0;do{nrc(c[a+38064+(S*12|0)+4>>2]|0,c[a+38064+(S*12|0)>>2]|0,c[a+38064+(S*12|0)+8>>2]|0)|0;S=S+1|0;}while((S|0)<(c[B>>2]|0))}c[B>>2]=0;c[L>>2]=0;U=0}else{U=O}if((A|0)>=33554432){Cd(2164656,2138720,74,2649312);return 0}O=(c[w>>2]|0)+U|0;c[L>>2]=U+A;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}U=Ke[c[T>>2]&63](c[F>>2]|0,c[a+50432+(c[C>>2]<<2)>>2]|0,0,0,A,O,0,0,0)|0;c[h>>2]=U;if((U|0)!=0){c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2236400,(I=i,i=i+8|0,c[I>>2]=U,I)|0);i=I;q=-1;i=f;return q|0}c[a+38064+((c[B>>2]|0)*12|0)+4>>2]=c[d+7188>>2];c[a+38064+((c[B>>2]|0)*12|0)>>2]=O;c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=A;c[B>>2]=(c[B>>2]|0)+1;A=c[L>>2]|0;if((A+16|0)>33554431){ve[c[(c[e>>2]|0)+56>>2]&4095](c[F>>2]|0)|0;if((c[B>>2]|0)>0){e=0;do{nrc(c[a+38064+(e*12|0)+4>>2]|0,c[a+38064+(e*12|0)>>2]|0,c[a+38064+(e*12|0)+8>>2]|0)|0;e=e+1|0;}while((e|0)<(c[B>>2]|0))}c[B>>2]=0;c[L>>2]=0;V=0}else{V=A}A=c[w>>2]|0;w=A+V|0;c[L>>2]=V+16;if((c[M>>2]|0)!=0){q=-1;i=f;return q|0}L=Ke[c[T>>2]&63](c[F>>2]|0,c[a+50480+(c[C>>2]<<2)>>2]|0,0,0,16,w,0,0,0)|0;c[h>>2]=L;if((L|0)==0){c[a+38064+((c[B>>2]|0)*12|0)+4>>2]=d+4520;c[a+38064+((c[B>>2]|0)*12|0)>>2]=w;c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=4;w=(c[B>>2]|0)+1|0;c[B>>2]=w;c[a+38064+(w*12|0)+4>>2]=d+5816;c[a+38064+((c[B>>2]|0)*12|0)>>2]=A+(V+4);c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=4;c[B>>2]=(c[B>>2]|0)+1;c[C>>2]=(c[C>>2]|0)==0;q=0;i=f;return q|0}else{c[a+816>>2]=0;c[M>>2]=1;ILb(a,0,2236400,(I=i,i=i+8|0,c[I>>2]=L,I)|0);i=I;q=-1;i=f;return q|0}}else if((N|0)==174){i=f;return q|0}return 0}function xVb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;j=i;i=i+48|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=o;q=i;i=i+4|0;i=i+7&-8;r=i;i=i+8|0;s=i;i=i+4|0;i=i+7&-8;t=i;i=i+4|0;i=i+7&-8;u=i;i=i+4|0;i=i+7&-8;v=i;i=i+8|0;w=i;i=i+8|0;x=i;i=i+4|0;i=i+7&-8;y=i;i=i+4|0;i=i+7&-8;z=i;i=i+4|0;i=i+7&-8;c[k>>2]=d;c[l>>2]=e;c[m>>2]=f;c[n>>2]=g;g=a+38028|0;f=c[g>>2]|0;A=c[b+(d<<2)>>2]|0;d=c[b+(e<<2)>>2]|0;do{if((h|0)==0){B=2}else{if((c[h+44>>2]|0)==0){B=2;break}e=a+18560|0;b=r|0;c[b>>2]=c[e>>2]<<3;C=a+18564|0;D=r+4|0;c[D>>2]=c[C>>2]<<3;E=a+50360|0;F=f+112|0;G=a+50396|0;H=h+40|0;I=h+36|0;J=h+32|0;K=f+44|0;L=a+38040|0;M=0;while(1){if((M|0)>=4){B=25;break}if((c[E>>2]|0)!=0){N=-1;B=190;break}O=hf[c[F>>2]&1023](c[G>>2]|0,0,4,d+12024+(M<<2)|0)|0;if((O|0)!=0){B=8;break}if((c[E>>2]|0)!=0){N=-1;B=190;break}P=hf[c[F>>2]&1023](c[G>>2]|0,1,4,a+50400+(M<<2)|0)|0;if((P|0)!=0){B=11;break}if((c[E>>2]|0)!=0){N=-1;B=190;break}Q=hf[c[F>>2]&1023](c[G>>2]|0,2,4,H)|0;if((Q|0)!=0){B=14;break}if((c[E>>2]|0)!=0){N=-1;B=190;break}R=hf[c[F>>2]&1023](c[G>>2]|0,3,4,I)|0;if((R|0)!=0){B=17;break}if((c[E>>2]|0)!=0){N=-1;B=190;break}S=hf[c[F>>2]&1023](c[G>>2]|0,4,4,J)|0;if((S|0)!=0){B=20;break}if((c[E>>2]|0)!=0){N=-1;B=190;break}T=Ke[c[K>>2]&63](c[L>>2]|0,c[G>>2]|0,2,0,b,0,0,0,0)|0;if((T|0)!=0){B=23;break}U=c[b>>2]|0;c[b>>2]=U>>>1;V=c[D>>2]|0;c[D>>2]=V>>>1;if(U>>>0<32>>>0|V>>>0<32>>>0){B=25;break}else{M=M+1|0}}if((B|0)==8){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=O,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==11){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=P,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==14){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Q,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==17){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=R,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==20){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=S,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==23){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2286200,(W=i,i=i+8|0,c[W>>2]=T,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==25){c[b>>2]=c[e>>2]<<3;c[D>>2]=c[C>>2]<<3;if((c[E>>2]|0)!=0){N=-1;i=j;return N|0}M=a+50392|0;G=hf[c[F>>2]&1023](c[M>>2]|0,0,4,d+12040|0)|0;if((G|0)!=0){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=G,W)|0);i=W;N=-1;i=j;return N|0}if((c[E>>2]|0)!=0){N=-1;i=j;return N|0}G=a+50416|0;V=hf[c[F>>2]&1023](c[M>>2]|0,1,4,G)|0;if((V|0)!=0){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=V,W)|0);i=W;N=-1;i=j;return N|0}if((c[E>>2]|0)!=0){N=-1;i=j;return N|0}V=hf[c[F>>2]&1023](c[M>>2]|0,2,4,H)|0;if((V|0)!=0){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=V,W)|0);i=W;N=-1;i=j;return N|0}if((c[E>>2]|0)!=0){N=-1;i=j;return N|0}V=hf[c[F>>2]&1023](c[M>>2]|0,3,4,I)|0;if((V|0)!=0){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=V,W)|0);i=W;N=-1;i=j;return N|0}if((c[E>>2]|0)!=0){N=-1;i=j;return N|0}V=hf[c[F>>2]&1023](c[M>>2]|0,4,4,J)|0;if((V|0)!=0){c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=V,W)|0);i=W;N=-1;i=j;return N|0}if((c[E>>2]|0)!=0){N=-1;i=j;return N|0}V=Ke[c[K>>2]&63](c[L>>2]|0,c[M>>2]|0,2,0,b,0,0,0,0)|0;if((V|0)==0){M=a+50400|0;c[p>>2]=c[M>>2];c[p+4>>2]=c[M+4>>2];c[p+8>>2]=c[M+8>>2];c[p+12>>2]=c[M+12>>2];X=G;Y=e;Z=C;_=E;$=F;aa=K;ba=L;break}c[a+816>>2]=0;c[E>>2]=1;ILb(a,0,2286200,(W=i,i=i+8|0,c[W>>2]=V,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==190){i=j;return N|0}}}while(0);if((B|0)==2){c[o>>2]=c[d+12024>>2];c[o+4>>2]=c[d+12028>>2];c[o+8>>2]=c[d+12032>>2];c[o+12>>2]=c[d+12036>>2];X=d+12040|0;Y=a+18560|0;Z=a+18564|0;_=a+50360|0;$=f+112|0;aa=f+44|0;ba=a+38040|0}c[q>>2]=c[X>>2];c[s>>2]=1;c[t>>2]=1;c[x>>2]=3;X=v|0;d=v+4|0;v=w|0;p=a+50440|0;T=a+38036|0;S=w+4|0;w=a+548|0;R=a+50456|0;Q=a+50460|0;P=u;O=n;n=y;h=x;r=z;V=s;G=t;M=3;U=1;da=0;ea=0;fa=0;a:while(1){ga=c[Y>>2]>>M;c[u>>2]=ga;c[X>>2]=ga;ha=c[Z>>2]>>M;c[d>>2]=ha;b:do{if(ga>>>0<2>>>0|ha>>>0<2>>>0){ia=fa;ja=ea;ka=da;la=U;ma=M}else{c[X>>2]=ga<<2;yVb(c[g>>2]|0,X,v,c[p>>2]|0,c[T>>2]|0);na=ca((c[v>>2]|0)>>>2,c[S>>2]|0)|0;oa=na<<3;pa=na<<4;c[y>>2]=c[w>>2]>>M;c[z>>2]=1;if((c[_>>2]|0)!=0){N=-1;B=190;break a}qa=hf[c[$>>2]&1023](c[p>>2]|0,0,4,A+12024+(M<<2)|0)|0;if((qa|0)!=0){B=48;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}ra=hf[c[$>>2]&1023](c[p>>2]|0,1,4,o+(M<<2)|0)|0;if((ra|0)!=0){B=51;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}sa=hf[c[$>>2]&1023](c[p>>2]|0,2,4,a+50448+(U<<2)|0)|0;if((sa|0)!=0){B=54;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}ta=hf[c[$>>2]&1023](c[p>>2]|0,3,4,a+50448+(((U|0)==0)<<2)|0)|0;if((ta|0)!=0){B=57;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}ua=hf[c[$>>2]&1023](c[p>>2]|0,4,4,R)|0;if((ua|0)!=0){B=60;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}va=hf[c[$>>2]&1023](c[p>>2]|0,5,4,Q)|0;if((va|0)!=0){B=63;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}wa=hf[c[$>>2]&1023](c[p>>2]|0,6,oa,0)|0;if((wa|0)!=0){B=66;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}xa=hf[c[$>>2]&1023](c[p>>2]|0,7,pa,0)|0;if((xa|0)!=0){B=69;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}ya=hf[c[$>>2]&1023](c[p>>2]|0,8,4,P)|0;if((ya|0)!=0){B=72;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}za=hf[c[$>>2]&1023](c[p>>2]|0,9,4,O)|0;if((za|0)!=0){B=75;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Aa=hf[c[$>>2]&1023](c[p>>2]|0,10,4,n)|0;if((Aa|0)!=0){B=78;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Ba=hf[c[$>>2]&1023](c[p>>2]|0,11,4,h)|0;if((Ba|0)!=0){B=81;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Ca=hf[c[$>>2]&1023](c[p>>2]|0,12,4,r)|0;if((Ca|0)!=0){B=84;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Da=hf[c[$>>2]&1023](c[p>>2]|0,13,4,V)|0;if((Da|0)!=0){B=87;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Ea=hf[c[$>>2]&1023](c[p>>2]|0,14,4,G)|0;if((Ea|0)==0){Fa=0;Ga=U}else{B=90;break a}while(1){Ha=c[x>>2]|0;if((Fa|0)>=(c[94440+(Ha<<2)>>2]|0)){ia=pa;ja=oa;ka=na;la=Ga;ma=Ha;break b}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Ia=Ke[c[aa>>2]&63](c[ba>>2]|0,c[p>>2]|0,2,0,X,v,0,0,0)|0;if((Ia|0)!=0){B=94;break a}c[z>>2]=0;c[s>>2]=0;if((c[x>>2]|0)>2){Ja=c[t>>2]^1}else{Ja=0}c[t>>2]=Ja;Ha=(Ga|0)!=0|0;Ka=Ha^1;if((c[_>>2]|0)!=0){N=-1;B=190;break a}La=hf[c[$>>2]&1023](c[p>>2]|0,2,4,a+50448+(Ka<<2)|0)|0;if((La|0)!=0){B=99;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Ma=hf[c[$>>2]&1023](c[p>>2]|0,3,4,a+50448+(Ha<<2)|0)|0;if((Ma|0)!=0){B=102;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Na=hf[c[$>>2]&1023](c[p>>2]|0,12,4,r)|0;if((Na|0)!=0){B=105;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Oa=hf[c[$>>2]&1023](c[p>>2]|0,13,4,V)|0;if((Oa|0)!=0){B=108;break a}if((c[_>>2]|0)!=0){N=-1;B=190;break a}Pa=hf[c[$>>2]&1023](c[p>>2]|0,14,4,G)|0;if((Pa|0)==0){Fa=Fa+1|0;Ga=Ka}else{B=111;break a}}}}while(0);ga=ma-1|0;c[x>>2]=ga;if((ma|0)>0){M=ga;U=la;da=ka;ea=ja;fa=ia}else{B=113;break}}if((B|0)==48){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=qa,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==51){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=ra,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==54){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=sa,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==57){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=ta,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==60){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=ua,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==63){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=va,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==66){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=wa,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==69){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=xa,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==72){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=ya,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==75){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=za,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==78){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Aa,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==81){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Ba,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==84){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Ca,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==87){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Da,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==90){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Ea,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==94){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2286200,(W=i,i=i+8|0,c[W>>2]=Ia,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==99){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=La,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==102){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Ma,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==105){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Na,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==108){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Oa,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==111){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Pa,W)|0);i=W;N=-1;i=j;return N|0}else if((B|0)==113){if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}Pa=a+50444|0;Oa=hf[c[$>>2]&1023](c[Pa>>2]|0,0,4,A+12024|0)|0;if((Oa|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Oa,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}Oa=hf[c[$>>2]&1023](c[Pa>>2]|0,1,4,q)|0;if((Oa|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=Oa,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}Oa=a+50448+(la<<2)|0;q=hf[c[$>>2]&1023](c[Pa>>2]|0,2,4,Oa)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,3,4,R)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,4,ja,0)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,5,ka<<6,0)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,6,ia,0)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}q=(c[_>>2]|0)!=0;do{if((c[m>>2]|0)==0){if(q){N=-1;i=j;return N|0}ia=hf[c[$>>2]&1023](c[Pa>>2]|0,7,4,A+12052|0)|0;if((ia|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=ia,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}ia=hf[c[$>>2]&1023](c[Pa>>2]|0,8,4,A+12060|0)|0;if((ia|0)==0){break}c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=ia,W)|0);i=W;N=-1;i=j;return N|0}else{if(q){N=-1;i=j;return N|0}ia=hf[c[$>>2]&1023](c[Pa>>2]|0,7,4,A+12056|0)|0;if((ia|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=ia,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}ia=hf[c[$>>2]&1023](c[Pa>>2]|0,8,4,A+12064|0)|0;if((ia|0)==0){break}c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=ia,W)|0);i=W;N=-1;i=j;return N|0}}while(0);if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,9,4,P)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,10,4,O)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,11,4,k)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,12,4,l)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=hf[c[$>>2]&1023](c[Pa>>2]|0,13,4,m)|0;if((q|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2347288,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}do{if((c[a+50356>>2]|0)!=0){if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}q=Ke[c[f+36>>2]&63](c[ba>>2]|0,c[Oa>>2]|0,c[a+50448+(((la|0)==0)<<2)>>2]|0,0,0,20,0,0,0)|0;if((q|0)==0){break}c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2196304,(W=i,i=i+8|0,c[W>>2]=q,W)|0);i=W;N=-1;i=j;return N|0}}while(0);if((c[_>>2]|0)!=0){N=-1;i=j;return N|0}la=Ke[c[aa>>2]&63](c[ba>>2]|0,c[Pa>>2]|0,2,0,X,v,0,0,0)|0;if((la|0)!=0){c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2286200,(W=i,i=i+8|0,c[W>>2]=la,W)|0);i=W;N=-1;i=j;return N|0}la=c[a+18568>>2]<<2;v=a+50352|0;X=c[v>>2]|0;if((X|0)>1022){ve[c[(c[g>>2]|0)+56>>2]&4095](c[ba>>2]|0)|0;if((c[v>>2]|0)>0){Pa=0;do{nrc(c[a+38064+(Pa*12|0)+4>>2]|0,c[a+38064+(Pa*12|0)>>2]|0,c[a+38064+(Pa*12|0)+8>>2]|0)|0;Pa=Pa+1|0;}while((Pa|0)<(c[v>>2]|0))}c[v>>2]=0;c[a+38060>>2]=0;Qa=0;Ra=0}else{Qa=X;Ra=c[a+38060>>2]|0}X=a+38060|0;if((Ra+la|0)>33554431){ve[c[(c[g>>2]|0)+56>>2]&4095](c[ba>>2]|0)|0;if((c[v>>2]|0)>0){g=0;do{nrc(c[a+38064+(g*12|0)+4>>2]|0,c[a+38064+(g*12|0)>>2]|0,c[a+38064+(g*12|0)+8>>2]|0)|0;g=g+1|0;}while((g|0)<(c[v>>2]|0))}c[v>>2]=0;c[X>>2]=0;Sa=0;Ta=0}else{Sa=Ra;Ta=Qa}if((la|0)>=33554432){Cd(2164656,2138720,74,2649312);return 0}Qa=(c[a+38056>>2]|0)+Sa|0;c[X>>2]=Sa+la;c[a+38064+(Ta*12|0)>>2]=Qa;c[a+38064+((c[v>>2]|0)*12|0)+8>>2]=la;Ta=(c[_>>2]|0)==0;do{if((c[m>>2]|0)==0){if(!Ta){N=-1;i=j;return N|0}Sa=ca((c[k>>2]|0)+~c[l>>2]|0,la)|0;X=Ke[c[f+48>>2]&63](c[ba>>2]|0,c[A+12052>>2]|0,0,Sa,la,Qa,0,0,0)|0;if((X|0)==0){c[a+38064+((c[v>>2]|0)*12|0)+4>>2]=c[A+2796+((c[k>>2]|0)-1-(c[l>>2]|0)<<2)>>2];break}c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2236400,(W=i,i=i+8|0,c[W>>2]=X,W)|0);i=W;N=-1;i=j;return N|0}else{if(!Ta){N=-1;i=j;return N|0}X=ca((c[l>>2]|0)+~c[k>>2]|0,la)|0;Sa=Ke[c[f+48>>2]&63](c[ba>>2]|0,c[A+12056>>2]|0,0,X,la,Qa,0,0,0)|0;if((Sa|0)==0){c[a+38064+((c[v>>2]|0)*12|0)+4>>2]=c[A+2864+((c[l>>2]|0)-1-(c[k>>2]|0)<<2)>>2];break}c[a+816>>2]=0;c[_>>2]=1;ILb(a,0,2236400,(W=i,i=i+8|0,c[W>>2]=Sa,W)|0);i=W;N=-1;i=j;return N|0}}while(0);c[v>>2]=(c[v>>2]|0)+1;N=0;i=j;return N|0}else if((B|0)==190){i=j;return N|0}return 0}function yVb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;c[h>>2]=256;c[j>>2]=64;c[k>>2]=6;l=a+72|0;se[c[l>>2]&127](e,f,4528,4,h,0)|0;se[c[l>>2]&127](e,f,4531,4,j,0)|0;Xe[c[a+68>>2]&511](f,4098,4,k,0)|0;f=c[j>>2]|0;c[d>>2]=f;j=d+4|0;c[j>>2]=8;a=b+4|0;if((c[a>>2]&7|0)==0){m=f;n=8}else{e=f;l=8;while(1){o=e<<1;c[d>>2]=o;p=l>>>1;c[j>>2]=p;if((c[a>>2]&p-1|0)==0){m=o;n=p;break}else{e=o;l=p}}}l=ca(n,m)|0;e=c[h>>2]|0;if(l>>>0>e>>>0){l=m;h=n;while(1){if(l>>>0<=f>>>0&h>>>0>1>>>0){n=h>>>1;c[j>>2]=n;q=l;r=n}else{n=l>>>1;c[d>>2]=n;q=n;r=h}if((ca(r,q)|0)>>>0>e>>>0){l=q;h=r}else{s=q;break}}}else{s=m}m=c[b>>2]|0;do{if(s>>>0>m>>>0){if((f+m|0)>>>0<s>>>0){t=s}else{u=s;break}while(1){q=t-f|0;c[d>>2]=q;if((f+(c[b>>2]|0)|0)>>>0<q>>>0){t=q}else{u=q;break}}}else{q=((s-1+m|0)>>>0)/(s>>>0)|0;c[b>>2]=q;u=ca(c[d>>2]|0,q)|0}}while(0);c[b>>2]=u;s=c[j>>2]|0;m=c[d>>2]|0;t=ca(((u>>>0)/(m>>>0)|0)<<1,((c[a>>2]|0)>>>0)/(s>>>0)|0)|0;u=c[k>>2]|0;a:do{if(t>>>0>u>>>0){v=m;w=s}else{k=s;q=m;while(1){r=k;while(1){if(q>>>0>f>>>0){break}if(!(r>>>0>1>>>0)){v=q;w=r;break a}h=r>>>1;c[j>>2]=h;if((ca((((c[b>>2]|0)>>>0)/(q>>>0)|0)<<1,((c[a>>2]|0)>>>0)/(h>>>0)|0)|0)>>>0>u>>>0){v=q;w=h;break a}else{r=h}}h=q>>>1;c[d>>2]=h;if((ca((((c[b>>2]|0)>>>0)/(h>>>0)|0)<<1,((c[a>>2]|0)>>>0)/(r>>>0)|0)|0)>>>0>u>>>0){v=h;w=r;break}else{k=r;q=h}}}}while(0);if(!((u|0)==6&(v|0)==64&(w|0)==4)){i=g;return}c[d>>2]=32;i=g;return}function zVb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=i;i=i+80|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;r=j+56|0;s=j+64|0;t=j+72|0;c[k>>2]=b;c[l>>2]=e;c[m>>2]=f;c[n>>2]=g;c[o>>2]=h;b=a+38028|0;u=c[b>>2]|0;v=c[d+(g<<2)>>2]|0;w=c[d+(e<<2)>>2]|0;e=c[d+(f<<2)>>2]|0;if((c[a+532>>2]|0)==0){x=32}else{x=64-(h>>2)|0}c[p>>2]=x;x=q|0;h=a+18560|0;d=c[h>>2]|0;c[x>>2]=d;y=a+18564|0;c[q+4>>2]=c[y>>2];if((g|0)<(f|0)){f=r|0;c[x>>2]=d<<2;yVb(u,x,f,c[a+50464>>2]|0,c[a+38036>>2]|0);d=ca((c[f>>2]|0)>>>2,c[r+4>>2]|0)|0;z=d<<6;A=d<<3;B=f}else{z=4;A=4;B=0}f=a+50360|0;if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}d=u+112|0;r=a+50464|0;g=hf[c[d>>2]&1023](c[r>>2]|0,0,4,v+12024|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=hf[c[d>>2]&1023](c[r>>2]|0,1,4,w+12040|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=hf[c[d>>2]&1023](c[r>>2]|0,2,4,e+12040|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=hf[c[d>>2]&1023](c[r>>2]|0,3,4,v+12052|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=hf[c[d>>2]&1023](c[r>>2]|0,4,4,v+12056|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=hf[c[d>>2]&1023](c[r>>2]|0,5,4,e+12052|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=hf[c[d>>2]&1023](c[r>>2]|0,6,4,v+12060|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=hf[c[d>>2]&1023](c[r>>2]|0,7,4,v+12064|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=hf[c[d>>2]&1023](c[r>>2]|0,8,4,v+12048|0)|0;if((g|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=g,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}g=a+38048|0;e=hf[c[d>>2]&1023](c[r>>2]|0,9,4,a+50472+(c[g>>2]<<2)|0)|0;if((e|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=e,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}e=hf[c[d>>2]&1023](c[r>>2]|0,10,4,a+50480+(c[g>>2]<<2)|0)|0;if((e|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=e,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}e=hf[c[d>>2]&1023](c[r>>2]|0,11,A,0)|0;if((e|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=e,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}e=hf[c[d>>2]&1023](c[r>>2]|0,12,z,0)|0;if((e|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=e,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}e=h;h=hf[c[d>>2]&1023](c[r>>2]|0,13,4,e)|0;if((h|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=h,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}h=hf[c[d>>2]&1023](c[r>>2]|0,14,4,p)|0;if((h|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=h,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}h=hf[c[d>>2]&1023](c[r>>2]|0,15,4,o)|0;if((h|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=h,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}h=n;o=hf[c[d>>2]&1023](c[r>>2]|0,16,4,h)|0;if((o|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=o,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}o=l;p=hf[c[d>>2]&1023](c[r>>2]|0,17,4,o)|0;if((p|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=p,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}p=m;z=hf[c[d>>2]&1023](c[r>>2]|0,18,4,p)|0;if((z|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=z,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}z=hf[c[d>>2]&1023](c[r>>2]|0,19,4,k)|0;if((z|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=z,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}z=u+44|0;k=a+38040|0;A=Ke[c[z>>2]&63](c[k>>2]|0,c[r>>2]|0,2,0,x,B,0,0,0)|0;if((A|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2286200,(D=i,i=i+8|0,c[D>>2]=A,D)|0);i=D;C=-1;i=j;return C|0}A=s|0;c[A>>2]=256;c[s+4>>2]=c[y>>2];c[t>>2]=256;c[t+4>>2]=1;if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}s=a+50468|0;B=hf[c[d>>2]&1023](c[s>>2]|0,0,4,a+50472+(c[g>>2]<<2)|0)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=hf[c[d>>2]&1023](c[s>>2]|0,1,4,v+12044|0)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=hf[c[d>>2]&1023](c[s>>2]|0,2,4,a+50432+(c[g>>2]<<2)|0)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=hf[c[d>>2]&1023](c[s>>2]|0,3,4,a+50480+(c[g>>2]<<2)|0)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=hf[c[d>>2]&1023](c[s>>2]|0,4,4,e)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=hf[c[d>>2]&1023](c[s>>2]|0,5,4,a+120|0)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=hf[c[d>>2]&1023](c[s>>2]|0,6,4,h)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=hf[c[d>>2]&1023](c[s>>2]|0,7,4,o)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=hf[c[d>>2]&1023](c[s>>2]|0,8,4,p)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2347288,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}B=Ke[c[z>>2]&63](c[k>>2]|0,c[s>>2]|0,2,0,A,t,0,0,0)|0;if((B|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2286200,(D=i,i=i+8|0,c[D>>2]=B,D)|0);i=D;C=-1;i=j;return C|0}B=a+50352|0;t=c[B>>2]|0;if((t|0)>1019){ve[c[(c[b>>2]|0)+56>>2]&4095](c[k>>2]|0)|0;if((c[B>>2]|0)>0){A=0;do{nrc(c[a+38064+(A*12|0)+4>>2]|0,c[a+38064+(A*12|0)>>2]|0,c[a+38064+(A*12|0)+8>>2]|0)|0;A=A+1|0;}while((A|0)<(c[B>>2]|0))}c[B>>2]=0;c[a+38060>>2]=0;E=0;F=0}else{E=t;F=c[a+38060>>2]|0}t=c[a+18568>>2]<<1;A=a+38060|0;if((F+t|0)>33554431){ve[c[(c[b>>2]|0)+56>>2]&4095](c[k>>2]|0)|0;if((c[B>>2]|0)>0){s=0;do{nrc(c[a+38064+(s*12|0)+4>>2]|0,c[a+38064+(s*12|0)>>2]|0,c[a+38064+(s*12|0)+8>>2]|0)|0;s=s+1|0;}while((s|0)<(c[B>>2]|0))}c[B>>2]=0;c[A>>2]=0;G=0;H=0}else{G=F;H=E}if((t|0)>=33554432){Cd(2164656,2138720,74,2649312);return 0}E=a+38056|0;F=(c[E>>2]|0)+G|0;c[A>>2]=G+t;c[a+38064+(H*12|0)>>2]=F;H=c[n>>2]|0;c[a+38064+((c[B>>2]|0)*12|0)+4>>2]=c[v+2940+((H-(c[l>>2]|0)|0)*72|0)+((c[m>>2]|0)-H<<2)>>2];c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=t;if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}H=u+48|0;u=Ke[c[H>>2]&63](c[k>>2]|0,c[a+50472+(c[g>>2]<<2)>>2]|0,0,0,t,F,0,0,0)|0;if((u|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2236400,(D=i,i=i+8|0,c[D>>2]=u,D)|0);i=D;C=-1;i=j;return C|0}u=(c[B>>2]|0)+1|0;c[B>>2]=u;F=c[y>>2]<<2;y=c[A>>2]|0;if((y+F|0)>33554431){ve[c[(c[b>>2]|0)+56>>2]&4095](c[k>>2]|0)|0;if((c[B>>2]|0)>0){t=0;do{nrc(c[a+38064+(t*12|0)+4>>2]|0,c[a+38064+(t*12|0)>>2]|0,c[a+38064+(t*12|0)+8>>2]|0)|0;t=t+1|0;}while((t|0)<(c[B>>2]|0))}c[B>>2]=0;c[A>>2]=0;I=0;J=0}else{I=y;J=u}if((F|0)>=33554432){Cd(2164656,2138720,74,2649312);return 0}u=(c[E>>2]|0)+I|0;c[A>>2]=I+F;c[a+38064+(J*12|0)>>2]=u;J=c[n>>2]|0;c[a+38064+((c[B>>2]|0)*12|0)+4>>2]=c[v+7188+((J-(c[l>>2]|0)|0)*72|0)+((c[m>>2]|0)-J<<2)>>2];c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=F;if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}J=Ke[c[H>>2]&63](c[k>>2]|0,c[a+50432+(c[g>>2]<<2)>>2]|0,0,0,F,u,0,0,0)|0;if((J|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2236400,(D=i,i=i+8|0,c[D>>2]=J,D)|0);i=D;C=-1;i=j;return C|0}c[B>>2]=(c[B>>2]|0)+1;J=c[A>>2]|0;if((J+16|0)>33554431){ve[c[(c[b>>2]|0)+56>>2]&4095](c[k>>2]|0)|0;if((c[B>>2]|0)>0){b=0;do{nrc(c[a+38064+(b*12|0)+4>>2]|0,c[a+38064+(b*12|0)>>2]|0,c[a+38064+(b*12|0)+8>>2]|0)|0;b=b+1|0;}while((b|0)<(c[B>>2]|0))}c[B>>2]=0;c[A>>2]=0;K=0}else{K=J}J=c[E>>2]|0;E=J+K|0;c[A>>2]=K+16;if((c[f>>2]|0)!=0){C=-1;i=j;return C|0}A=Ke[c[H>>2]&63](c[k>>2]|0,c[a+50480+(c[g>>2]<<2)>>2]|0,0,0,16,E,0,0,0)|0;if((A|0)!=0){c[a+816>>2]=0;c[f>>2]=1;ILb(a,0,2236400,(D=i,i=i+8|0,c[D>>2]=A,D)|0);i=D;C=-1;i=j;return C|0}c[g>>2]=(c[g>>2]|0)==0;c[a+38064+((c[B>>2]|0)*12|0)>>2]=E;E=c[m>>2]|0;m=c[n>>2]|0;n=E-m|0;g=m-(c[l>>2]|0)|0;c[a+38064+((c[B>>2]|0)*12|0)+4>>2]=v+4520+(g*72|0)+(n<<2);c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=4;l=(c[B>>2]|0)+1|0;c[B>>2]=l;c[a+38064+(l*12|0)>>2]=J+(K+4);c[a+38064+((c[B>>2]|0)*12|0)+4>>2]=v+5816+(g*72|0)+(n<<2);c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=4;n=(c[B>>2]|0)+1|0;c[B>>2]=n;if((m|0)!=(E|0)){C=0;i=j;return C|0}c[a+38064+(n*12|0)>>2]=J+(K+8);c[a+38064+((c[B>>2]|0)*12|0)+4>>2]=v+7116+(g<<2);c[a+38064+((c[B>>2]|0)*12|0)+8>>2]=4;c[B>>2]=(c[B>>2]|0)+1;C=0;i=j;return C|0}function AVb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[a+816>>2]|0)==0){return}g=(e|0)<0;if(!g){h=0;do{wVb(a,c[d+(h<<2)>>2]|0,f)|0;h=h+1|0;}while((h|0)<=(e|0))}h=a+38028|0;i=a+38040|0;ve[c[(c[h>>2]|0)+56>>2]&4095](c[i>>2]|0)|0;j=a+50352|0;if((c[j>>2]|0)>0){k=0;do{nrc(c[a+38064+(k*12|0)+4>>2]|0,c[a+38064+(k*12|0)>>2]|0,c[a+38064+(k*12|0)+8>>2]|0)|0;k=k+1|0;}while((k|0)<(c[j>>2]|0))}c[j>>2]=0;k=a+38060|0;c[k>>2]=0;if((c[a+116>>2]|0)!=2){return}l=a+112|0;m=c[l>>2]|0;if((m|0)==0){return}if(!g){g=a+528|0;n=0;o=m;while(1){if((o|0)>1){m=d+(n<<2)|0;p=1;while(1){q=n-p|0;do{if((q|0)>-1){r=p-1|0;s=c[m>>2]|0;t=c[s+2796+(r<<2)>>2]|0;if((b[t>>1]|0)!=32767){break}if((c[g>>2]|0)==0){u=2772248;v=t}else{pUb(a,s,c[d+(q<<2)>>2]|0,1);s=c[m>>2]|0;u=s+400|0;v=c[s+2796+(r<<2)>>2]|0}b[v>>1]=0;xVb(a,d,n,q,0,f,u)|0}}while(0);q=p+n|0;do{if((q|0)<=(e|0)){r=c[(c[m>>2]|0)+2864+(p-1<<2)>>2]|0;if((b[r>>1]|0)!=32767){break}b[r>>1]=0;xVb(a,d,n,q,1,f,0)|0}}while(0);q=p+1|0;r=c[l>>2]|0;if((q|0)<(r|0)){p=q}else{w=r;break}}}else{w=o}p=n+1|0;if((p|0)>(e|0)){break}else{n=p;o=w}}}ve[c[(c[h>>2]|0)+56>>2]&4095](c[i>>2]|0)|0;if((c[j>>2]|0)>0){i=0;do{nrc(c[a+38064+(i*12|0)+4>>2]|0,c[a+38064+(i*12|0)>>2]|0,c[a+38064+(i*12|0)+8>>2]|0)|0;i=i+1|0;}while((i|0)<(c[j>>2]|0))}c[j>>2]=0;c[k>>2]=0;return}function BVb(a){a=a|0;return}function CVb(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;i=g-h|0;j=h-f|0;k=d+(h<<2)|0;l=c[k>>2]|0;m=l+4520+(j*72|0)+(i<<2)|0;if((c[m>>2]|0)>-1){n=0;return n|0}o=(h|0)==(f|0);p=(h|0)==(g|0);if(o&p){n=0;return n|0}c[m>>2]=0;if(o){q=0}else{q=(b[c[l+2796+(j-1<<2)>>2]>>1]|0)==32767}if(p){r=0}else{r=(b[c[l+2864+(i-1<<2)>>2]>>1]|0)==32767}if(q){if((c[a+528>>2]|0)!=0&p){pUb(a,l,c[d+(f<<2)>>2]|0,1);o=c[k>>2]|0;s=o+400|0;t=o}else{s=2772248;t=l}b[c[t+2796+(j-1<<2)>>2]>>1]=0;u=s;v=t}else{u=2772248;v=l}if(r){b[c[v+2864+(i-1<<2)>>2]>>1]=0}if(p){c[v+7116+(j<<2)>>2]=0}if((g|0)==(f|0)){w=128}else{p=g-f|0;w=((j<<8)+(p>>1)|0)/(p|0)|0}c[v+4520+(j*72|0)+(i<<2)>>2]=0;c[v+5816+(j*72|0)+(i<<2)>>2]=0;wVb(a,v,e)|0;if(q){wVb(a,c[d+(f<<2)>>2]|0,e)|0;xVb(a,d,h,f,0,e,u)|0}if(r){wVb(a,c[d+(g<<2)>>2]|0,e)|0;xVb(a,d,h,g,1,e,0)|0}zVb(a,e,d,f,g,h,w)|0;n=1;return n|0}function DVb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a;a=b;b=0;SYb();if((c[e+24>>2]|0)==0){f=Rqc(1,9928)|0;if((f|0)==0){g=2;h=g;i=d;return h|0}c[e+24>>2]=f;c[c[e+24>>2]>>2]=208;c[(c[e+24>>2]|0)+4>>2]=c[e+4>>2];c[(c[e+24>>2]|0)+8>>2]=f;c[(c[e+24>>2]|0)+16>>2]=c[e+16>>2];if((c[e+20>>2]|0)!=0){nrc((c[(c[e+24>>2]|0)+8>>2]|0)+208|0,c[e+20>>2]|0,268)|0;c[e+20>>2]=(c[(c[e+24>>2]|0)+8>>2]|0)+208}j=(c[(c[e+24>>2]|0)+8>>2]|0)+208|0;k=0;while(1){if((c[1489200+(k*56|0)>>2]|0)!=0){l=(c[1489200+(k*56|0)>>2]|0)!=(c[j>>2]|0)}else{l=0}if(!l){break}k=k+1|0}nrc(f+476|0,1489204+(k*56|0)|0,52)|0;c[f+476>>2]=f+1072;c[f+968>>2]=((((ca(c[f+220>>2]|0,c[f+224>>2]|0)|0)*3|0)>>>0)/2|0)<<1;if((c[f+968>>2]|0)>>>0<32768>>>0){c[f+968>>2]=32768}c[f+964>>2]=Pqc(c[f+968>>2]|0)|0;if((c[f+964>>2]|0)==0){g=2;h=g;i=d;return h|0}if((a|0)!=0){c[(c[e+24>>2]|0)+200>>2]=c[a>>2]}else{c[(c[e+24>>2]|0)+200>>2]=1}b=KVb(f,f+208|0,f+476|0,0)|0;if((b|0)==0){LVb((c[(c[e+24>>2]|0)+8>>2]|0)+528|0,(c[(c[e+24>>2]|0)+8>>2]|0)+208|0,(c[(c[e+24>>2]|0)+8>>2]|0)+476|0,a)|0;a=vZb((c[(c[e+24>>2]|0)+8>>2]|0)+528|0)|0;if((a|0)!=0){c[(c[(c[e+24>>2]|0)+8>>2]|0)+960>>2]=a}else{b=2}}}g=b;h=g;i=d;return h|0}function EVb(a){a=a|0;var b=0,d=0;b=i;d=a;Qqc(c[d+964>>2]|0);wZb(d+960|0);Qqc(d);i=b;return 0}function FVb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=i;i=i+288|0;k=j|0;l=j+8|0;m=j+16|0;n=j+112|0;o=j+120|0;p=j+128|0;q=j+136|0;r=j+144|0;s=j+152|0;t=a;a=b;c[k>>2]=d;c[k+4>>2]=e;e=f;f=g;g=0;if((c[t+284>>2]|0)==0){u=g;v=u;i=j;return v|0}if((a|0)!=0){g=MVb(t,a)|0}if((g|0)==0){g=KVb(t,t+208|0,t+476|0,1)|0}NVb(t,e,h);c[t+1072>>2]=0;c[t+1076>>2]=64;if((f&4194304|0)!=0){if((f&524288|0)==0){w=9}}else{w=9}do{if((w|0)==9){if((f&8388608|0)!=0){if((f&16777216|0)!=0){break}}if((f&2293760|0)!=0){h=7;if((f&65536|0)!=0){h=h^1}if((f&131072|0)!=0){h=h^2}if((f&2097152|0)!=0){h=h^4}AZb(c[t+960>>2]|0,h)|0}if((f&30146560|0)!=0){h=7;if((f&262144|0)!=0){h=h^1}if((f&4194304|0)!=0){h=h^2}if((f&8388608|0)!=0){h=h^4}BZb(c[t+960>>2]|0,h)|0}if((f&1048576|0)!=0){EZb(c[t+960>>2]|0,0)|0}do{if((c[t+328>>2]|0)==1){if((c[t+332>>2]|0)!=(c[t+336>>2]|0)){break}h=t+9920|0;d=(c[h>>2]|0)+1|0;c[h>>2]=d;if(d>>>0>(c[t+332>>2]|0)>>>0){f=f|1;c[t+9920>>2]=1}}}while(0);do{if((g|0)==0){if((c[t+960>>2]|0)==0){break}d=0;if((c[t+16>>2]&65536|0)!=0){c[(c[t+960>>2]|0)+149712>>2]=1}if((c[t+16>>2]&131072|0)!=0){c[(c[t+960>>2]|0)+149732>>2]=1}c[l>>2]=(f&1|0)!=0?1:0;h=Erc(c[k>>2]|0,c[k+4>>2]|0,1e7,0)|0;b=c[t+228>>2]|0;x=Erc(h,G,b,(b|0)<0|0?-1:0)|0;b=c[t+232>>2]|0;h=Crc(x,G,b,(b|0)<0|0?-1:0)|0;c[n>>2]=h;c[n+4>>2]=G;h=wrc(c[k>>2]|0,c[k+4>>2]|0,e,0)|0;b=Erc(h,G,1e7,0)|0;h=c[t+228>>2]|0;x=Erc(b,G,h,(h|0)<0|0?-1:0)|0;h=c[t+232>>2]|0;b=Crc(x,G,h,(h|0)<0|0?-1:0)|0;c[o>>2]=b;c[o+4>>2]=G;if((a|0)!=0){g=OVb(a,m)|0;if((JZb(c[t+960>>2]|0,c[t+1056>>2]|c[l>>2],m,c[n>>2]|0,c[n+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0)!=0){g=PVb(t,(c[t+960>>2]|0)+105664|0)|0}c[t+1056>>2]=0}b=c[t+964>>2]|0;h=c[t+968>>2]|0;x=(c[t+964>>2]|0)+h|0;c[l>>2]=0;while(1){if(!(h>>>0>=(((c[t+968>>2]|0)>>>0)/2|0)>>>0)){break}d=KZb(c[t+960>>2]|0,l,p,b,x,n,o,((a|0)!=0^1)&1)|0;if((d|0)==7){w=48;break}if((d|0)==-1){w=50;break}if((c[p>>2]|0)!=0){y=c[t+960>>2]|0;z=c[t+228>>2]|0;A=Erc(1e6,0,z,(z|0)<0|0?-1:0)|0;z=Crc(A,G,2,0)|0;A=xrc(z,G,1,0)|0;c[q>>2]=A;c[q+4>>2]=G;A=xrc(c[o>>2]|0,c[o+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0)|0;c[r>>2]=A;c[r+4>>2]=G;c[s>>2]=0;A=c[t+232>>2]|0;z=Erc(c[n>>2]|0,c[n+4>>2]|0,A,(A|0)<0|0?-1:0)|0;A=wrc(z,G,c[q>>2]|0,c[q+4>>2]|0)|0;z=c[t+228>>2]|0;B=Crc(A,G,z,(z|0)<0|0?-1:0)|0;z=Crc(B,G,1e7,0)|0;B=s+16|0;c[B>>2]=z;c[B+4>>2]=G;B=c[t+232>>2]|0;z=Erc(c[r>>2]|0,c[r+4>>2]|0,B,(B|0)<0|0?-1:0)|0;B=wrc(z,G,c[q>>2]|0,c[q+4>>2]|0)|0;z=c[t+228>>2]|0;A=Crc(B,G,z,(z|0)<0|0?-1:0)|0;z=Crc(A,G,1e7,0)|0;c[s+24>>2]=z;c[s+28>>2]=c[l>>2]<<16;if((c[l>>2]&1|0)!=0){z=s+28|0;c[z>>2]=c[z>>2]|1}if((c[y+107980>>2]|0)==0){z=s+28|0;c[z>>2]=c[z>>2]|4;z=y+131616|0;A=c[t+232>>2]|0;B=Erc(c[z>>2]|0,c[z+4>>2]|0,A,(A|0)<0|0?-1:0)|0;A=wrc(B,G,c[q>>2]|0,c[q+4>>2]|0)|0;B=c[t+228>>2]|0;z=Crc(A,G,B,(B|0)<0|0?-1:0)|0;B=Crc(z,G,1e7,0)|0;z=wrc(B,G,1,0)|0;B=s+16|0;c[B>>2]=z;c[B+4>>2]=G;c[s+24>>2]=0}if((c[y+149752>>2]|0)!=0){B=s+28|0;c[B>>2]=c[B>>2]|2}if((c[y+149732>>2]|0)!=0){B=(1<<c[y+113708>>2])+1|0;z=s+28|0;c[z>>2]=c[z>>2]|8;z=0;while(1){if((z|0)>=(B|0)){break}c[s+8>>2]=b;b=b+(c[y+142664+(z<<2)>>2]|0)|0;h=h-(c[y+142664+(z<<2)>>2]|0)|0;c[s+12>>2]=c[y+142664+(z<<2)>>2];c[s+32>>2]=z;if((z|0)==(B-1|0)){A=s+28|0;c[A>>2]=c[A>>2]&-9}qYb(t+1072|0,s)|0;z=z+1|0}}else{c[s+8>>2]=b;c[s+12>>2]=c[p>>2];c[s+32>>2]=-1;qYb(t+1072|0,s)|0;b=b+(c[p>>2]|0)|0;h=h-(c[p>>2]|0)|0}}}if((w|0)==48){u=7;v=u;i=j;return v|0}}}while(0);u=g;v=u;i=j;return v|0}}while(0);c[t+12>>2]=2283904;u=8;v=u;i=j;return v|0}function GVb(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=rYb(a+1072|0,b)|0;i=c;return d|0}function HVb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;if((c[a+12>>2]|0)!=(c[e+220>>2]|0)){f=3}else{if((c[a+16>>2]|0)!=(c[e+224>>2]|0)){f=3}}do{if((f|0)==3){if(!((c[a+36>>2]|0)>>>0>1>>>0)){if((c[a+32>>2]|0)==0){break}}c[e+12>>2]=2572136;g=8;h=g;i=d;return h|0}}while(0);if((c[a+36>>2]|0)>>>0>(c[e+244>>2]|0)>>>0){c[e+12>>2]=2432288;g=8;h=g;i=d;return h|0}f=KVb(e,a,e+476|0,0)|0;if((f|0)==0){nrc(e+208|0,a|0,268)|0;LVb(e+528|0,e+208|0,e+476|0,0)|0;oZb(c[e+960>>2]|0,e+528|0)}g=f;h=g;i=d;return h|0}function IVb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+128|0;d=b|0;e=b+96|0;f=a;mrc(e|0,0,28)|0;if((c[f+1060>>2]|0)!=0){c[e>>2]=c[f+1060>>2];c[e+4>>2]=c[f+1064>>2];c[e+8>>2]=c[f+1068>>2]}if(0==(TZb(c[f+960>>2]|0,d,e)|0)){c[f+1032>>2]=12;c[f+1e3>>2]=c[d+52>>2];c[f+1004>>2]=c[d+56>>2];c[f+1008>>2]=c[d+60>>2];c[f+972>>2]=258;c[f+992>>2]=1;c[f+996>>2]=1;c[f+984>>2]=c[d>>2];c[f+988>>2]=c[d+4>>2];c[f+1016>>2]=c[d+16>>2];c[f+1020>>2]=c[d+36>>2];c[f+1024>>2]=c[d+36>>2];c[f+976>>2]=c[d>>2];c[f+980>>2]=c[d+4>>2];g=f+972|0;h=g;i=b;return h|0}else{g=0;h=g;i=b;return h|0}return 0}function JVb(a,b){a=a|0;b=b|0;i=i;return 0}function KVb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0;f=i;g=a;a=b;b=d;d=e;if((c[a+12>>2]|0)==1){j=4}else{if((c[a+12>>2]|0)>>>0>1>>>0){j=4}}do{if((j|0)==4){if(!((c[a+12>>2]|0)>>>0<=16383>>>0)){break}if((c[a+16>>2]|0)==1){j=11}else{if((c[a+16>>2]|0)>>>0>1>>>0){j=11}}do{if((j|0)==11){if(!((c[a+16>>2]|0)>>>0<=16383>>>0)){break}if((c[a+24>>2]|0)==1){j=18}else{if((c[a+24>>2]|0)>1){j=18}}do{if((j|0)==18){if((c[a+24>>2]|0)>1e9){break}if((c[a+20>>2]|0)==1){j=25}else{if((c[a+20>>2]|0)>1){j=25}}do{if((j|0)==25){if((c[a+20>>2]|0)>(c[a+24>>2]|0)){break}if(!((c[a+8>>2]|0)>>>0<=3>>>0)){c[g+12>>2]=2164608;k=8;l=k;i=f;return l|0}if(!((c[a+84>>2]|0)>>>0<=63>>>0)){c[g+12>>2]=2138656;k=8;l=k;i=f;return l|0}if(!((c[a+80>>2]|0)>>>0<=(c[a+84>>2]|0)>>>0)){c[g+12>>2]=2115336;k=8;l=k;i=f;return l|0}if(!((c[a+4>>2]|0)>>>0<=64>>>0)){c[g+12>>2]=2633336;k=8;l=k;i=f;return l|0}if(!((c[a+36>>2]|0)>>>0<=25>>>0)){c[g+12>>2]=2609632;k=8;l=k;i=f;return l|0}if((c[a+64>>2]|0)==0){j=57}else{if((c[a+64>>2]|0)>>>0>0>>>0){j=57}}do{if((j|0)==57){if(!((c[a+64>>2]|0)>>>0<=3>>>0)){break}if(!((c[a+88>>2]|0)>>>0<=1e3>>>0)){c[g+12>>2]=2562568;k=8;l=k;i=f;return l|0}if(!((c[a+92>>2]|0)>>>0<=1e3>>>0)){c[g+12>>2]=2544984;k=8;l=k;i=f;return l|0}if(!((c[a+108>>2]|0)>>>0<=100>>>0)){c[g+12>>2]=2527224;k=8;l=k;i=f;return l|0}if((c[a+120>>2]|0)==0){j=79}else{if((c[a+120>>2]|0)>>>0>0>>>0){j=79}}do{if((j|0)==79){if(!((c[a+120>>2]|0)>>>0<=1>>>0)){break}if((((c[a+44>>2]|0)!=0^1^1)&1|0)!=(c[a+44>>2]|0)){c[g+12>>2]=2498688;k=8;l=k;i=f;return l|0}if(!((c[a+40>>2]|0)>>>0<=100>>>0)){c[g+12>>2]=2486472;k=8;l=k;i=f;return l|0}if(!((c[a+56>>2]|0)>>>0<=100>>>0)){c[g+12>>2]=2474784;k=8;l=k;i=f;return l|0}if(!((c[a+60>>2]|0)>>>0<=100>>>0)){c[g+12>>2]=2466120;k=8;l=k;i=f;return l|0}if((c[a+32>>2]|0)==0){j=106}else{if((c[a+32>>2]|0)>>>0>0>>>0){j=106}}do{if((j|0)==106){if(!((c[a+32>>2]|0)>>>0<=2>>>0)){break}do{if((c[a+120>>2]|0)!=0){if((c[a+124>>2]|0)==(c[a+128>>2]|0)){break}if(!((c[a+124>>2]|0)>>>0>0>>>0)){break}c[g+12>>2]=2438424;k=8;l=k;i=f;return l|0}}while(0);if((((c[b+8>>2]|0)!=0^1^1)&1|0)!=(c[b+8>>2]|0)){c[g+12>>2]=2427704;k=8;l=k;i=f;return l|0}if((c[b+4>>2]|0)==-16){j=123}else{if((c[b+4>>2]|0)>-16){j=123}}do{if((j|0)==123){if((c[b+4>>2]|0)>16){break}if(!((c[b+12>>2]|0)>>>0<=6>>>0)){c[g+12>>2]=2408480;k=8;l=k;i=f;return l|0}if((c[b+24>>2]|0)==0){j=135}else{if((c[b+24>>2]|0)>>>0>0>>>0){j=135}}do{if((j|0)==135){if(!((c[b+24>>2]|0)>>>0<=3>>>0)){break}if(!((c[b+16>>2]|0)>>>0<=7>>>0)){c[g+12>>2]=2394064;k=8;l=k;i=f;return l|0}if((c[b+28>>2]|0)==0){j=147}else{if((c[b+28>>2]|0)>>>0>0>>>0){j=147}}do{if((j|0)==147){if(!((c[b+28>>2]|0)>>>0<=15>>>0)){break}if(!((c[b+32>>2]|0)>>>0<=6>>>0)){c[g+12>>2]=2380112;k=8;l=k;i=f;return l|0}if((c[b+36>>2]|0)==1){j=159}else{if((c[b+36>>2]|0)>>>0>1>>>0){j=159}}do{if((j|0)==159){if(!((c[b+36>>2]|0)>>>0<=3>>>0)){break}if((c[b+44>>2]|0)==0){j=166}else{if((c[b+44>>2]|0)>>>0>0>>>0){j=166}}do{if((j|0)==166){if(!((c[b+44>>2]|0)>>>0<=63>>>0)){break}a:do{if((d|0)!=0){if((c[a+64>>2]|0)!=2){if((c[a+64>>2]|0)!=3){break}}if((c[b+44>>2]|0)==(c[a+80>>2]|0)){j=176}else{if((c[b+44>>2]|0)>>>0>(c[a+80>>2]|0)>>>0){j=176}}do{if((j|0)==176){if(!((c[b+44>>2]|0)>>>0<=(c[a+84>>2]|0)>>>0)){break}break a}}while(0);c[g+12>>2]=2351144;k=8;l=k;i=f;return l|0}}while(0);do{if((c[a+32>>2]|0)==2){e=144;m=((c[a+72>>2]|0)>>>0)/(e>>>0)|0;if((c[a+68>>2]|0)==0){c[g+12>>2]=2343808;k=8;l=k;i=f;return l|0}if((((c[a+72>>2]|0)>>>0)%(e>>>0)|0|0)!=0){c[g+12>>2]=2337776;k=8;l=k;i=f;return l|0}if((c[a+72>>2]|0)>>>0<e<<1>>>0){c[g+12>>2]=2332272;k=8;l=k;i=f;return l|0}if((~~(+h[(c[a+68>>2]|0)+(ca(m-1|0,e)|0)+136>>3]+.5)|0)==(m-1|0)){break}c[g+12>>2]=2326640;k=8;l=k;i=f;return l|0}}while(0);if((c[a+156>>2]|0)==1){j=198}else{if((c[a+156>>2]|0)>>>0>1>>>0){j=198}}do{if((j|0)==198){if(!((c[a+156>>2]|0)>>>0<=5>>>0)){break}b:do{if((c[a+156>>2]|0)>>>0>1>>>0){if(!((c[a+200>>2]|0)>>>0<=16>>>0)){c[g+12>>2]=2315992;k=8;l=k;i=f;return l|0}m=1;while(1){if(!(m>>>0<(c[a+156>>2]|0)>>>0)){break}if((c[a+160+(m<<2)>>2]|0)>>>0<=(c[a+160+(m-1<<2)>>2]|0)>>>0){j=211;break}m=m+1|0}if((j|0)==211){c[g+12>>2]=2311488;k=8;l=k;i=f;return l|0}if((c[a+180+((c[a+156>>2]|0)-1<<2)>>2]|0)==1){j=218}else{if((c[a+180+((c[a+156>>2]|0)-1<<2)>>2]|0)>>>0>1>>>0){j=218}}do{if((j|0)==218){if(!((c[a+180+((c[a+156>>2]|0)-1<<2)>>2]|0)>>>0<=1>>>0)){break}m=(c[a+156>>2]|0)-2|0;while(1){if(!(m>>>0>0>>>0)){break}if((c[a+180+(m-1<<2)>>2]|0)!=(c[a+180+(m<<2)>>2]<<1|0)){j=225;break}m=m-1|0}if((j|0)==225){c[g+12>>2]=2300888;k=8;l=k;i=f;return l|0}if((c[a+204+(m<<2)>>2]|0)>>>0<=((c[a+156>>2]|0)-1|0)>>>0){break b}c[g+12>>2]=2289544;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2306888;k=8;l=k;i=f;return l|0}}while(0);k=0;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2320856;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2366392;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2373920;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2387192;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2401032;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2417440;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2455696;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2512120;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2582888;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2196224;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2236328;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2286120;k=8;l=k;i=f;return l|0}}while(0);c[g+12>>2]=2347192;k=8;l=k;i=f;return l|0}function LVb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;e=i;f=b;b=i;i=i+268|0;i=i+7&-8;nrc(b,f,268)|0;f=d;d=i;i=i+52|0;i=i+7&-8;nrc(d,f,52)|0;f=a;c[f+188>>2]=c[b+4>>2];c[f>>2]=c[b+8>>2];c[f+4>>2]=c[b+12>>2];c[f+8>>2]=c[b+16>>2];a=f+12|0;g=b+20|0;c[a>>2]=c[g>>2];c[a+4>>2]=c[g+4>>2];c[f+200>>2]=c[b+28>>2];g=c[b+32>>2]|0;if((g|0)==1){c[f+40>>2]=3}else if((g|0)==0){c[f+40>>2]=2}else if((g|0)==2){c[f+40>>2]=5}do{if((c[b+32>>2]|0)==1){h=7}else{if((c[b+32>>2]|0)==0){h=7;break}c[f+52>>2]=(c[b+36>>2]|0)>>>0>0>>>0;c[f+56>>2]=c[b+36>>2]}}while(0);if((h|0)==7){c[f+52>>2]=0;c[f+56>>2]=0}c[f+148>>2]=(c[b+40>>2]|0)>>>0>0>>>0;c[f+152>>2]=c[b+40>>2];c[f+136>>2]=c[b+44>>2];c[f+144>>2]=c[b+56>>2];c[f+140>>2]=c[b+60>>2];if((c[b+64>>2]|0)==0){c[f+60>>2]=0}else{if((c[b+64>>2]|0)==1){c[f+60>>2]=1}else{if((c[b+64>>2]|0)==2){c[f+60>>2]=2}else{if((c[b+64>>2]|0)==3){c[f+60>>2]=3}}}}c[f+20>>2]=c[b+76>>2];c[f+36>>2]=c[d+48>>2];c[f+128>>2]=c[b+80>>2];c[f+124>>2]=c[b+84>>2];c[f+132>>2]=c[d+44>>2];c[f+120>>2]=-1;c[f+64>>2]=c[b+88>>2];c[f+68>>2]=c[b+92>>2];h=f+112|0;c[h>>2]=c[b+96>>2];c[h+4>>2]=0;h=f+96|0;c[h>>2]=c[b+100>>2];c[h+4>>2]=0;h=f+104|0;c[h>>2]=c[b+104>>2];c[h+4>>2]=0;h=f+88|0;c[h>>2]=c[b+96>>2];c[h+4>>2]=0;h=f+72|0;c[h>>2]=c[b+100>>2];c[h+4>>2]=0;h=f+80|0;c[h>>2]=c[b+104>>2];c[h+4>>2]=0;c[f+156>>2]=c[b+108>>2];c[f+160>>2]=c[b+112>>2];c[f+164>>2]=c[b+116>>2];if((c[b+120>>2]|0)==1){j=(c[b+124>>2]|0)!=(c[b+128>>2]|0)}else{j=0}c[f+44>>2]=j&1;c[f+48>>2]=c[b+128>>2];c[f+232>>2]=c[b+156>>2];c[f+364>>2]=c[b+200>>2];if(!((c[f+232>>2]|0)>>>0>1>>>0)){k=d+4|0;l=c[k>>2]|0;m=f;n=m+32|0;c[n>>2]=l;o=d+20|0;p=c[o>>2]|0;q=f;r=q+196|0;c[r>>2]=p;s=d+8|0;t=c[s>>2]|0;u=f;v=u+168|0;c[v>>2]=t;w=d+12|0;x=c[w>>2]|0;y=f;z=y+24|0;c[z>>2]=x;A=d+16|0;B=c[A>>2]|0;C=f;D=C+28|0;c[D>>2]=B;E=d+24|0;F=c[E>>2]|0;G=f;H=G+192|0;c[H>>2]=F;I=f;J=I+216|0;K=b+68|0;L=J;M=K;c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];N=d|0;O=c[N>>2]|0;P=f;Q=P+224|0;c[Q>>2]=O;R=d+28|0;S=c[R>>2]|0;T=f;U=T+204|0;c[U>>2]=S;V=d+32|0;W=c[V>>2]|0;X=f;Y=X+208|0;c[Y>>2]=W;Z=d+36|0;_=c[Z>>2]|0;$=f;aa=$+212|0;c[aa>>2]=_;ba=d+40|0;ca=c[ba>>2]|0;da=f;ea=da+228|0;c[ea>>2]=ca;i=e;return 0}j=f+236|0;h=b+160|0;c[j>>2]=c[h>>2];c[j+4>>2]=c[h+4>>2];c[j+8>>2]=c[h+8>>2];c[j+12>>2]=c[h+12>>2];c[j+16>>2]=c[h+16>>2];h=f+300|0;j=b+180|0;c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];c[h+16>>2]=c[j+16>>2];nrc(f+368|0,b+204|0,64)|0;k=d+4|0;l=c[k>>2]|0;m=f;n=m+32|0;c[n>>2]=l;o=d+20|0;p=c[o>>2]|0;q=f;r=q+196|0;c[r>>2]=p;s=d+8|0;t=c[s>>2]|0;u=f;v=u+168|0;c[v>>2]=t;w=d+12|0;x=c[w>>2]|0;y=f;z=y+24|0;c[z>>2]=x;A=d+16|0;B=c[A>>2]|0;C=f;D=C+28|0;c[D>>2]=B;E=d+24|0;F=c[E>>2]|0;G=f;H=G+192|0;c[H>>2]=F;I=f;J=I+216|0;K=b+68|0;L=J;M=K;c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];N=d|0;O=c[N>>2]|0;P=f;Q=P+224|0;c[Q>>2]=O;R=d+28|0;S=c[R>>2]|0;T=f;U=T+204|0;c[U>>2]=S;V=d+32|0;W=c[V>>2]|0;X=f;Y=X+208|0;c[Y>>2]=W;Z=d+36|0;_=c[Z>>2]|0;$=f;aa=$+212|0;c[aa>>2]=_;ba=d+40|0;ca=c[ba>>2]|0;da=f;ea=da+228|0;c[ea>>2]=ca;i=e;return 0}function MVb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;b=c[a>>2]|0;if(!((b|0)==769|(b|0)==258|(b|0)==260|(b|0)==771)){c[e+12>>2]=2280040;f=8;g=f;i=d;return g|0}do{if((c[a+12>>2]|0)==(c[e+220>>2]|0)){if((c[a+16>>2]|0)!=(c[e+224>>2]|0)){break}f=0;g=f;i=d;return g|0}}while(0);c[e+12>>2]=2275864;f=8;g=f;i=d;return g|0}function NVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=a;a=d;d=2;if((a|0)!=0){h=Erc(b,0,1e6,0)|0;b=c[g+228>>2]|0;j=Erc(h,G,b,(b|0)<0|0?-1:0)|0;b=c[g+232>>2]|0;h=Frc(j,G,b,(b|0)<0|0?-1:0)|0;c[f>>2]=h;c[f+4>>2]=G;h=0;b=c[f+4>>2]|0;d=h>>>0>b>>>0|h>>>0==b>>>0&a>>>0>(c[f>>2]|0)>>>0?1:0}if((c[g+240>>2]|0)==1){d=3}else{if((c[g+240>>2]|0)==2){d=(d|0)==2?5:4}}if((c[g+568>>2]|0)==(d|0)){i=e;return}c[g+568>>2]=d;oZb(c[g+960>>2]|0,g+528|0);i=e;return}function OVb(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[a+52>>2]=c[d+28>>2];c[a+56>>2]=c[d+32>>2];c[a+60>>2]=c[d+36>>2];c[a+8>>2]=c[d+12>>2];c[a+12>>2]=c[d+16>>2];c[a>>2]=c[d+12>>2];c[a+4>>2]=c[d+16>>2];c[a+20>>2]=((c[a>>2]|0)+1|0)/2|0;c[a+24>>2]=((c[a+4>>2]|0)+1|0)/2|0;c[a+16>>2]=c[d+44>>2];c[a+36>>2]=c[d+48>>2];c[a+76>>2]=(((c[d+44>>2]|0)-(c[d+4>>2]|0)|0)>>>0)/2|0;i=i;return 0}function PVb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=b;b=c[e>>2]|0;f=b;if((b|0)==0){g=f;i=d;return g|0}if((c[e+4>>2]|0)!=0){h=e+8|0}else{h=0}c[a+12>>2]=h;g=f;i=d;return g|0}function QVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+96|0;e=b|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)!=0){f=d;OVb(f+4|0,e)|0;DZb(c[a+960>>2]|0,c[f>>2]|0,e)|0;g=0;h=g;i=b;return h|0}else{g=8;h=g;i=b;return h|0}return 0}function RVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+96|0;e=b|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)!=0){f=d;OVb(f+4|0,e)|0;CZb(c[a+960>>2]|0,c[f>>2]|0,e)|0;g=0;h=g;i=b;return h|0}else{g=8;h=g;i=b;return h|0}return 0}function SVb(a,b,c){a=a|0;b=b|0;c=c|0;i=i;return 4}function TVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;EZb(c[a+960>>2]|0,(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0))|0;i=b;return 0}function UVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;BZb(c[a+960>>2]|0,(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0))|0;i=b;return 0}function VVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;AZb(c[a+960>>2]|0,(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0))|0;i=b;return 0}function WVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=d;d=(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0);if((d|0)==0){f=8;g=f;i=b;return g|0}e=d;if((UZb(c[a+960>>2]|0,c[e>>2]|0,c[e+4>>2]|0,c[e+8>>2]|0,e+12|0,e+28|0,e+44|0)|0)!=0){f=8;g=f;i=b;return g|0}else{f=0;g=f;i=b;return g|0}return 0}function XVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=d;d=(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0);if((d|0)==0){f=8;g=f;i=b;return g|0}e=d;if((ZZb(c[a+960>>2]|0,c[e>>2]|0,c[e+4>>2]|0,c[e+8>>2]|0)|0)!=0){f=8;g=f;i=b;return g|0}else{f=0;g=f;i=b;return g|0}return 0}function YVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;e=b|0;f=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);if((d|0)==0){g=8;h=g;i=b;return h|0}a=e;j=d;c[a>>2]=c[j>>2];c[a+4>>2]=c[j+4>>2];if((_Zb(c[f+960>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0)!=0){g=8;h=g;i=b;return h|0}else{e=f+1056|0;c[e>>2]=c[e>>2]|1;g=0;h=g;i=b;return h|0}return 0}function ZVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+56|0;f=e|0;g=a;a=d;d=0;nrc(f|0,g+476|0,52)|0;switch(b|0){case 26:{c[f+48>>2]=mWb(a)|0;break};case 24:{c[f+40>>2]=kWb(a)|0;break};case 15:{c[f+12>>2]=dWb(a)|0;break};case 16:{c[f+16>>2]=eWb(a)|0;break};case 14:{c[f+8>>2]=cWb(a)|0;break};case 22:{c[f+32>>2]=iWb(a)|0;break};case 17:{c[f+20>>2]=fWb(a)|0;break};case 13:{c[f+4>>2]=bWb(a)|0;break};case 21:{c[f+28>>2]=hWb(a)|0;break};case 25:{c[f+44>>2]=lWb(a)|0;break};case 18:{c[f+24>>2]=gWb(a)|0;break};case 23:{c[f+36>>2]=jWb(a)|0;break};default:{}}d=KVb(g,g+208|0,f,0)|0;if((d|0)!=0){h=d;i=e;return h|0}nrc(g+476|0,f|0,52)|0;LVb(g+528|0,g+208|0,g+476|0,0)|0;oZb(c[g+960>>2]|0,g+528|0);h=d;i=e;return h|0}function _Vb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);if((d|0)==0){g=8;h=g;i=e;return h|0}a=b;if((a|0)==20){b=mZb(a_b(c[f+960>>2]|0)|0)|0;c[(aWb(d)|0)>>2]=b}else if((a|0)==19){a=a_b(c[f+960>>2]|0)|0;c[($Vb(d)|0)>>2]=a}g=0;h=g;i=e;return h|0}function $Vb(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;i=b;return c[d>>2]|0}function aWb(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;i=b;return c[d>>2]|0}function bWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function cWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function dWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function eWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function fWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function gWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function hWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function iWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function jWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function kWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function lWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function mWb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function nWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+96|0;e=b|0;f=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);do{if((d|0)!=0){if((c[f+352>>2]|0)!=0){break}a=d;HWb(a+4|0,e)|0;g=XYb(c[f+356>>2]|0,c[a>>2]|0,e)|0;h=g;i=b;return h|0}}while(0);g=8;h=g;i=b;return h|0}function oWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+96|0;e=b|0;f=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);do{if((d|0)!=0){if((c[f+352>>2]|0)!=0){break}a=d;HWb(a+4|0,e)|0;g=VYb(c[f+356>>2]|0,c[a>>2]|0,e)|0;h=g;i=b;return h|0}}while(0);g=8;h=g;i=b;return h|0}function pWb(a,b,c){a=a|0;b=b|0;c=c|0;i=i;return 4}function qWb(a,b,c){a=a|0;b=b|0;c=c|0;i=i;return 4}function rWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);do{if((d|0)!=0){if((c[e+352>>2]|0)!=0){break}a=c[e+356>>2]|0;c[d>>2]=(c[a+8948>>2]<<2)+(c[a+8944>>2]<<1)+(c[a+8940>>2]|0);f=0;g=f;i=b;return g|0}}while(0);f=8;g=f;i=b;return g|0}function sWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=d;d=(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0);e=c[a+356>>2]|0;do{if((d|0)!=0){if((e|0)==0){break}c[d>>2]=c[(c[e+4996>>2]|0)+84>>2];f=0;g=f;i=b;return g|0}}while(0);f=8;g=f;i=b;return g|0}function tWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;b=i;e=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);do{if((d|0)!=0){if((c[e+352>>2]|0)!=0){break}a=(c[e+356>>2]|0)+3184|0;f=(cZb(a,3)|0)!=0;g=(cZb(a,2)|0)!=0;h=(cZb(a,1)|0)!=0;c[d>>2]=(f?4:0)|(g?2:0)|(h?1:0);j=0;k=j;i=b;return k|0}}while(0);j=8;k=j;i=b;return k|0}function uWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);if((d|0)!=0){c[e+256>>2]=c[d>>2];c[e+260>>2]=c[d+4>>2];i=b;return 0}else{c[e+256>>2]=0;c[e+260>>2]=0;i=b;return 0}return 0}function vWb(a,b){a=a|0;b=b|0;var d=0,e=0;b=i;d=a;a=0;SYb();if((c[d+24>>2]|0)==0){GWb(d);c[(c[(c[d+24>>2]|0)+8>>2]|0)+492>>2]=0;c[(c[(c[d+24>>2]|0)+8>>2]|0)+488>>2]=c[(c[(c[d+24>>2]|0)+8>>2]|0)+16>>2]&262144}c[(c[(c[d+24>>2]|0)+8>>2]|0)+352>>2]=c[(c[(c[d+24>>2]|0)+8>>2]|0)+16>>2]&524288;c[(c[(c[d+24>>2]|0)+8>>2]|0)+352>>2]=0;if((c[(c[(c[d+24>>2]|0)+8>>2]|0)+352>>2]|0)==0){e=a;i=b;return e|0}do{if((c[(c[(c[d+24>>2]|0)+8>>2]|0)+16>>2]&131072|0)==0){if((c[(c[(c[d+24>>2]|0)+8>>2]|0)+16>>2]&262144|0)!=0){break}e=a;i=b;return e|0}}while(0);a=8;e=a;i=b;return e|0}function wWb(a){a=a|0;var b=0,c=0;b=i;c=a;fZb(c+352|0)|0;FYb(c);i=b;return 0}function xWb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=DWb(a,b,c,0,0)|0;i=d;return e|0}function yWb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=b;if((c[e>>2]|0)>>>0>=16>>>0){f=16}else{f=16}nrc(e|0,a+220|0,f)|0;c[e>>2]=f;i=d;return 0}function zWb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+32|0;h=1;j=0;k=i;i=i+168|0;c[k>>2]=0;while(1)switch(h|0){case 1:l=g|0;m=g+8|0;n=a;o=b;p=d;q=e;r=f;c[l>>2]=0;s=0;v=db(214,n|0,o|0,p|0,l|0)|0;if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;if((v|0)<=0){h=2;break}else{h=3;break};case 2:w=c[l>>2]|0;h=33;break;case 3:x=c[n+224>>2]|0;y=c[n+228>>2]|0;v=Ta(176,c[n+496>>2]|0,c[n+532>>2]|0,n+220|0,c[n+256>>2]|0,c[n+260>>2]|0)|0;if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;c[l>>2]=v;if((c[l>>2]|0)==5){h=4;break}else{h=6;break};case 4:if((c[n+232>>2]|0)!=0){h=6;break}else{h=5;break};case 5:c[l>>2]=0;h=6;break;case 6:if((c[n+236>>2]|0)!=0){h=9;break}else{h=7;break};case 7:if((c[n+232>>2]|0)!=0){h=9;break}else{h=8;break};case 8:c[l>>2]=5;h=9;break;case 9:if((c[n+228>>2]|0)!=(y|0)){h=11;break}else{h=10;break};case 10:if((c[n+224>>2]|0)!=(x|0)){h=11;break}else{h=12;break};case 11:s=1;h=12;break;case 12:if((c[l>>2]|0)!=0){h=18;break}else{h=13;break};case 13:if((c[n+236>>2]|0)!=0){h=18;break}else{h=14;break};case 14:c[m>>2]=c[n+224>>2];c[m+4>>2]=c[n+228>>2];c[m+8>>2]=9;c[m+12>>2]=0;c[m+16>>2]=c[n+208>>2];c[m+20>>2]=c[n+16>>2]&131072;if((c[n+240>>2]|0)!=0){h=17;break}else{h=15;break};case 15:if((c[n+16>>2]&65536|0)!=0){h=16;break}else{h=17;break};case 16:c[n+244>>2]=1027;c[n+248>>2]=4;c[n+252>>2]=0;h=17;break;case 17:v=Sa(878,n+352|0,m|0)|0;if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;c[l>>2]=v;c[(c[n+356>>2]|0)+11644>>2]=c[n+256>>2];c[(c[n+356>>2]|0)+11648>>2]=c[n+260>>2];c[n+236>>2]=1;h=18;break;case 18:if((c[l>>2]|0)!=0){h=32;break}else{h=19;break};case 19:z=c[n+356>>2]|0;if((s|0)!=0){h=20;break}else{h=29;break};case 20:A=z+3184|0;B=z|0;c[A+1792>>2]=c[n+224>>2];c[A+1796>>2]=c[n+228>>2];C=trc(z+3276|0,h,k)|0;h=34;break;case 34:if((C|0)!=0){h=21;break}else{h=22;break};case 21:c[z+3272>>2]=0;w=-1;h=33;break;case 22:c[z+3272>>2]=1;if((c[A+1792>>2]|0)<=0){h=23;break}else{h=24;break};case 23:c[A+1792>>2]=x;hb(452,A|0,7,2571344,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;i=D;h=24;break;case 24:if((c[A+1796>>2]|0)<=0){h=25;break}else{h=26;break};case 25:c[A+1796>>2]=y;hb(452,A|0,7,2431968,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;i=D;h=26;break;case 26:v=Aa(422,A|0,c[A+1792>>2]|0,c[A+1796>>2]|0)|0;if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;if((v|0)!=0){h=27;break}else{h=28;break};case 27:hb(452,A|0,2,2346792,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;i=D;h=28;break;case 28:nrc(B+2848|0,A+1816+((c[A+2204>>2]|0)*92|0)|0,92)|0;nrc(B+2940|0,A+1816+((c[A+2200>>2]|0)*92|0)|0,92)|0;ma(484,z|0);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;c[z+3272>>2]=0;c[z+5368>>2]=0;h=29;break;case 29:nrc(z+11524|0,n+488|0,80)|0;c[n+484>>2]=q;v=r;E=Ta(266,z|0,p|0,o|0,v|0,((v|0)<0|0?-1:0)|0)|0;if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;if((E|0)!=0){h=30;break}else{h=31;break};case 30:E=Sa(644,n|0,z+3184|0)|0;if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;c[l>>2]=E;h=31;break;case 31:c[n+492>>2]=0;h=32;break;case 32:w=c[l>>2]|0;h=33;break;case 33:i=g;return w|0;case-1:if((j|0)==20){C=u;h=34}t=u=0;break}return 0}function AWb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+144|0;e=d|0;f=d+96|0;g=d+104|0;h=d+112|0;j=a;a=b;b=0;if((c[a>>2]|0)!=0){k=b;i=d;return k|0}if((c[j+356>>2]|0)==0){k=b;i=d;return k|0}c[f>>2]=0;c[f+4>>2]=0;c[g>>2]=0;c[g+4>>2]=0;mrc(h|0,0,28)|0;if((c[j+16>>2]&65536|0)!=0){c[h>>2]=c[j+244>>2];c[h+4>>2]=c[j+248>>2];c[h+8>>2]=c[j+252>>2]}if(0==(bZb(c[j+356>>2]|0,e,f,g,h)|0)){BWb(j+264|0,e,c[j+484>>2]|0);b=j+264|0;c[a>>2]=b}k=b;i=d;return k|0}function BWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a;a=b;c[e>>2]=258;c[e+4>>2]=c[a+16>>2];c[e+8>>2]=(c[a+4>>2]|0)+79&-16;c[e+12>>2]=c[a>>2];c[e+16>>2]=c[a+4>>2];c[e+20>>2]=1;c[e+24>>2]=1;c[e+28>>2]=c[a+52>>2];c[e+32>>2]=c[a+56>>2];c[e+36>>2]=c[a+60>>2];c[e+40>>2]=0;c[e+44>>2]=c[a+16>>2];c[e+48>>2]=c[a+36>>2];c[e+52>>2]=c[a+36>>2];c[e+56>>2]=c[a+16>>2];c[e+60>>2]=12;c[e+64>>2]=d;c[e+68>>2]=c[a+68>>2];c[e+72>>2]=0;c[e+76>>2]=0;i=i;return}function CWb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;b=d;d=e;c[d>>2]=0;if((c[g+492>>2]|0)==0){mrc(g+496|0,0,36)|0;mrc(g+532|0,0,36)|0}do{if((c[g+488>>2]|0)!=0){if((a|0)==0){if((b|0)==0){break}}c[g+496+(c[g+492>>2]<<2)>>2]=a;c[g+532+(c[g+492>>2]<<2)>>2]=b;e=g+492|0;c[e>>2]=(c[e>>2]|0)+1;if((c[g+492>>2]|0)>>>0>9>>>0){c[g+492>>2]=0;c[d>>2]=8;h=-1;j=h;i=f;return j|0}else{h=0;j=h;i=f;return j|0}}}while(0);if((c[g+488>>2]|0)==0){c[g+496>>2]=a;c[g+532>>2]=b;c[g+492>>2]=1}h=1;j=h;i=f;return j|0}function DWb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=i;i=i+16|0;k=j|0;l=b;b=e;e=f;f=g;g=h;h=0;if((l+b|0)>>>0<=l>>>0){h=8;m=h;i=j;return m|0}n=l;if((f|0)!=0){if(b>>>0>10>>>0){o=10}else{o=b}mf[f&2047](g,l,k|0,o);n=k|0}c[e+12>>2]=0;do{if(b>>>0>=10>>>0){if((a[n|0]&1|0)!=0){p=17;break}c[e+12>>2]=1;do{if((d[n+3|0]|0|0)!=157){p=13}else{if((d[n+4|0]|0|0)!=1){p=13;break}if((d[n+5|0]|0|0)!=42){p=13}}}while(0);if((p|0)==13){h=5}c[e+4>>2]=(d[n+6|0]|0|(d[n+7|0]|0)<<8)&16383;c[e+8>>2]=(d[n+8|0]|0|(d[n+9|0]|0)<<8)&16383;if((c[e+8>>2]|c[e+4>>2]|0)==0){h=5}}else{p=17}}while(0);if((p|0)==17){h=5}m=h;i=j;return m|0}function EWb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function FWb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=b;b=c[e>>2]|0;f=b;if((b|0)==0){g=f;i=d;return g|0}if((c[e+4>>2]|0)!=0){h=e+8|0}else{h=0}c[a+12>>2]=h;g=f;i=d;return g|0}function GWb(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;c[d+24>>2]=BYb(8,568)|0;mrc(c[d+24>>2]|0,0,568)|0;c[c[d+24>>2]>>2]=208;c[(c[d+24>>2]|0)+4>>2]=c[d+4>>2];c[(c[d+24>>2]|0)+8>>2]=c[d+24>>2];c[(c[(c[d+24>>2]|0)+8>>2]|0)+220>>2]=16;c[(c[(c[d+24>>2]|0)+8>>2]|0)+256>>2]=0;c[(c[(c[d+24>>2]|0)+8>>2]|0)+260>>2]=0;c[(c[d+24>>2]|0)+16>>2]=c[d+16>>2];if((c[d+20>>2]|0)==0){i=b;return}a=(c[(c[d+24>>2]|0)+8>>2]|0)+208|0;e=c[d+20>>2]|0;c[a>>2]=c[e>>2];c[a+4>>2]=c[e+4>>2];c[a+8>>2]=c[e+8>>2];c[d+20>>2]=(c[(c[d+24>>2]|0)+8>>2]|0)+208;i=b;return}function HWb(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[a+52>>2]=c[d+28>>2];c[a+56>>2]=c[d+32>>2];c[a+60>>2]=c[d+36>>2];c[a+8>>2]=c[d+12>>2];c[a+12>>2]=c[d+16>>2];c[a>>2]=c[d+12>>2];c[a+4>>2]=c[d+16>>2];c[a+20>>2]=(c[a>>2]|0)/2|0;c[a+24>>2]=(c[a+4>>2]|0)/2|0;c[a+16>>2]=c[d+44>>2];c[a+36>>2]=c[d+48>>2];c[a+76>>2]=(((c[d+44>>2]|0)-(c[d+12>>2]|0)|0)>>>0)/2|0;i=i;return 0}function IWb(a,b){a=a|0;b=b|0;var c=0;b=i;c=DXb(a)|0;i=b;return c|0}function JWb(a){a=a|0;var b=0,d=0;b=i;d=a;Qqc(c[d+844>>2]|0);n1b(c[d+840>>2]|0);Qqc(d);i=b;return 0}function KWb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;i=i+288|0;k=j|0;l=j+8|0;m=j+16|0;n=j+112|0;o=j+120|0;p=j+128|0;q=j+136|0;r=j+144|0;s=j+152|0;t=a;a=b;c[k>>2]=d;c[k+4>>2]=e;e=f;f=g;g=0;if((a|0)!=0){g=RWb(t,a)|0}SWb(t,e,h);c[t+1e3>>2]=0;c[t+1004>>2]=64;if((f&4194304|0)!=0){if((f&524288|0)==0){u=5}}else{u=5}do{if((u|0)==5){if((f&8388608|0)!=0){if((f&16777216|0)!=0){break}}if((f&2293760|0)!=0){h=7;if((f&65536|0)!=0){h=h^1}if((f&131072|0)!=0){h=h^2}if((f&2097152|0)!=0){h=h^4}w1b(c[t+840>>2]|0,h)|0}if((f&30146560|0)!=0){h=7;if((f&262144|0)!=0){h=h^1}if((f&4194304|0)!=0){h=h^2}if((f&8388608|0)!=0){h=h^4}x1b(c[t+840>>2]|0,h)}if((f&1048576|0)!=0){C1b(c[t+840>>2]|0,0)|0}do{if((c[t+328>>2]|0)==1){if((c[t+332>>2]|0)!=(c[t+336>>2]|0)){break}h=t+9848|0;d=(c[h>>2]|0)+1|0;c[h>>2]=d;if(d>>>0>(c[t+332>>2]|0)>>>0){f=f|1;c[t+9848>>2]=1}}}while(0);do{if((g|0)==0){if((c[t+840>>2]|0)==0){break}if((c[t+16>>2]&65536|0)!=0){c[(c[t+840>>2]|0)+2050752>>2]=1}c[l>>2]=(f&1|0)!=0?1:0;d=Erc(c[k>>2]|0,c[k+4>>2]|0,1e7,0)|0;h=c[t+228>>2]|0;b=Erc(d,G,h,(h|0)<0|0?-1:0)|0;h=c[t+232>>2]|0;d=Crc(b,G,h,(h|0)<0|0?-1:0)|0;c[n>>2]=d;c[n+4>>2]=G;d=wrc(c[k>>2]|0,c[k+4>>2]|0,e,0)|0;h=Erc(d,G,1e7,0)|0;d=c[t+228>>2]|0;b=Erc(h,G,d,(d|0)<0|0?-1:0)|0;d=c[t+232>>2]|0;h=Crc(b,G,d,(d|0)<0|0?-1:0)|0;c[o>>2]=h;c[o+4>>2]=G;if((a|0)!=0){g=TWb(a,m)|0;if((G1b(c[t+840>>2]|0,c[l>>2]|0,m,c[n>>2]|0,c[n+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0)!=0){g=UWb(t,(c[t+840>>2]|0)+1434592|0)|0}}h=c[t+844>>2]|0;d=c[t+848>>2]|0;c[l>>2]=0;do{if((c[t+852>>2]|0)!=0){orc(h|0,c[t+852>>2]|0,c[t+856>>2]|0)|0;c[t+852>>2]=h;h=h+(c[t+856>>2]|0)|0;d=d-(c[t+856>>2]|0)|0;if(!(d>>>0<(((c[t+848>>2]|0)>>>0)/2|0)>>>0)){break}c[t+12>>2]=2239072;v=1;w=v;i=j;return w|0}}while(0);while(1){if(d>>>0>=(((c[t+848>>2]|0)>>>0)/2|0)>>>0){x=-1!=(M1b(c[t+840>>2]|0,l,p,h,n,o,((a|0)!=0^1)&1)|0)}else{x=0}if(!x){break}if((c[p>>2]|0)!=0){b=c[t+840>>2]|0;if((c[b+1444704>>2]|0)==0){if((c[t+852>>2]|0)==0){c[t+852>>2]=h}y=t+856|0;c[y>>2]=(c[y>>2]|0)+(c[p>>2]|0);y=c[p>>2]|0;z=t+860|0;A=c[z>>2]|0;c[z>>2]=A+1;c[t+864+(A<<2)>>2]=y;y=t+896|0;c[y>>2]=c[y>>2]|c[p>>2];h=h+(c[p>>2]|0)|0;d=d-(c[p>>2]|0)|0;continue}y=c[t+228>>2]|0;A=Erc(1e6,0,y,(y|0)<0|0?-1:0)|0;y=Crc(A,G,2,0)|0;A=xrc(y,G,1,0)|0;c[q>>2]=A;c[q+4>>2]=G;A=xrc(c[o>>2]|0,c[o+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0)|0;c[r>>2]=A;c[r+4>>2]=G;c[s>>2]=0;A=c[t+232>>2]|0;y=Erc(c[n>>2]|0,c[n+4>>2]|0,A,(A|0)<0|0?-1:0)|0;A=wrc(y,G,c[q>>2]|0,c[q+4>>2]|0)|0;y=c[t+228>>2]|0;z=Crc(A,G,y,(y|0)<0|0?-1:0)|0;y=Crc(z,G,1e7,0)|0;z=s+16|0;c[z>>2]=y;c[z+4>>2]=G;z=c[t+232>>2]|0;y=Erc(c[r>>2]|0,c[r+4>>2]|0,z,(z|0)<0|0?-1:0)|0;z=wrc(y,G,c[q>>2]|0,c[q+4>>2]|0)|0;y=c[t+228>>2]|0;A=Crc(z,G,y,(y|0)<0|0?-1:0)|0;y=Crc(A,G,1e7,0)|0;c[s+24>>2]=y;c[s+28>>2]=c[l>>2]<<16;if((c[l>>2]&1|0)!=0){y=s+28|0;c[y>>2]=c[y>>2]|1}if((c[b+1444704>>2]|0)==0){y=s+28|0;c[y>>2]=c[y>>2]|4;y=b+2017104|0;A=c[t+232>>2]|0;z=Erc(c[y>>2]|0,c[y+4>>2]|0,A,(A|0)<0|0?-1:0)|0;A=wrc(z,G,c[q>>2]|0,c[q+4>>2]|0)|0;z=c[t+228>>2]|0;y=Crc(A,G,z,(z|0)<0|0?-1:0)|0;z=Crc(y,G,1e7,0)|0;y=wrc(z,G,1,0)|0;z=s+16|0;c[z>>2]=y;c[z+4>>2]=G;c[s+24>>2]=0}if((c[b+2050768>>2]|0)!=0){b=s+28|0;c[b>>2]=c[b>>2]|2}if((c[t+852>>2]|0)!=0){b=c[p>>2]|0;z=t+860|0;y=c[z>>2]|0;c[z>>2]=y+1;c[t+864+(y<<2)>>2]=b;b=t+896|0;c[b>>2]=c[b>>2]|c[p>>2];b=t+856|0;c[b>>2]=(c[b>>2]|0)+(c[p>>2]|0);b=VWb(t)|0;c[p>>2]=(c[p>>2]|0)+b;c[s+8>>2]=c[t+852>>2];c[s+12>>2]=c[t+856>>2];c[t+852>>2]=0;c[t+856>>2]=0;c[t+860>>2]=0;c[t+896>>2]=0}else{c[s+8>>2]=h;c[s+12>>2]=c[p>>2]}c[s+32>>2]=-1;qYb(t+1e3|0,s)|0;h=h+(c[p>>2]|0)|0;d=d-(c[p>>2]|0)|0}}}}while(0);v=g;w=v;i=j;return w|0}}while(0);c[t+12>>2]=2249432;v=8;w=v;i=j;return w|0}function LWb(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=rYb(a+1e3|0,b)|0;i=c;return d|0}function MWb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;do{if((c[a+12>>2]|0)==(c[e+220>>2]|0)){if((c[a+16>>2]|0)!=(c[e+224>>2]|0)){break}if((c[a+36>>2]|0)>>>0>(c[e+244>>2]|0)>>>0){c[e+12>>2]=2431872;f=8;g=f;i=d;return g|0}b=PWb(e,a,e+476|0)|0;if((b|0)==0){nrc(e+208|0,a|0,268)|0;QWb(e+552|0,e+208|0,e+476|0)|0;i1b(c[e+840>>2]|0,e+552|0)}f=b;g=f;i=d;return g|0}}while(0);c[e+12>>2]=2571192;f=8;g=f;i=d;return g|0}function NWb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+112|0;d=b|0;e=b+96|0;f=a;mrc(e|0,0,12)|0;if((c[f+984>>2]|0)!=0){c[e>>2]=c[f+984>>2];c[e+4>>2]=c[f+988>>2];c[e+8>>2]=c[f+992>>2]}if((V1b(c[f+840>>2]|0,d,e)|0)==0){OWb(f+900|0,d,0);g=f+900|0;h=g;i=b;return h|0}else{g=0;h=g;i=b;return h|0}return 0}function OWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=d;d=12;if((c[a+24>>2]|0)==(c[a+4>>2]|0)){if((c[a+20>>2]|0)==(c[a>>2]|0)){c[f>>2]=262;d=24}else{c[f>>2]=261;d=16}}else{c[f>>2]=258}c[f+4>>2]=c[a+16>>2];c[f+8>>2]=(c[a+4>>2]|0)+327&-8;c[f+12>>2]=c[a+8>>2];c[f+16>>2]=c[a+12>>2];c[f+20>>2]=(c[a+20>>2]|0)<(c[a>>2]|0);c[f+24>>2]=(c[a+24>>2]|0)<(c[a+4>>2]|0);c[f+28>>2]=c[a+52>>2];c[f+32>>2]=c[a+56>>2];c[f+36>>2]=c[a+60>>2];c[f+40>>2]=c[a+64>>2];c[f+44>>2]=c[a+16>>2];c[f+48>>2]=c[a+36>>2];c[f+52>>2]=c[a+36>>2];c[f+56>>2]=c[a+48>>2];c[f+60>>2]=d;c[f+64>>2]=b;c[f+68>>2]=c[a+68>>2];c[f+72>>2]=0;c[f+76>>2]=0;i=e;return}function PWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+24|0;f=e|0;g=a;a=b;b=d;if((c[a+12>>2]|0)==1){j=4}else{if((c[a+12>>2]|0)>>>0>1>>>0){j=4}}do{if((j|0)==4){if(!((c[a+12>>2]|0)>>>0<=65535>>>0)){break}if((c[a+16>>2]|0)==1){j=11}else{if((c[a+16>>2]|0)>>>0>1>>>0){j=11}}do{if((j|0)==11){if(!((c[a+16>>2]|0)>>>0<=65535>>>0)){break}if((c[a+24>>2]|0)==1){j=18}else{if((c[a+24>>2]|0)>1){j=18}}do{if((j|0)==18){if((c[a+24>>2]|0)>1e9){break}if((c[a+20>>2]|0)==1){j=25}else{if((c[a+20>>2]|0)>1){j=25}}do{if((j|0)==25){if((c[a+20>>2]|0)>(c[a+24>>2]|0)){break}if(!((c[a+8>>2]|0)>>>0<=3>>>0)){c[g+12>>2]=2164480;k=8;l=k;i=e;return l|0}if(!((c[a+84>>2]|0)>>>0<=63>>>0)){c[g+12>>2]=2138560;k=8;l=k;i=e;return l|0}if(!((c[a+80>>2]|0)>>>0<=(c[a+84>>2]|0)>>>0)){c[g+12>>2]=2115112;k=8;l=k;i=e;return l|0}if((((c[b+56>>2]|0)!=0^1^1)&1|0)!=(c[b+56>>2]|0)){c[g+12>>2]=2633144;k=8;l=k;i=e;return l|0}if((c[b+64>>2]|0)==0){j=52}else{if((c[b+64>>2]|0)>>>0>0>>>0){j=52}}do{if((j|0)==52){if(!((c[b+64>>2]|0)>>>0<=3>>>0)){break}if((c[b+68>>2]|0)==0){j=59}else{if((c[b+68>>2]|0)>>>0>0>>>0){j=59}}do{if((j|0)==59){if(!((c[b+68>>2]|0)>>>0<=1>>>0)){break}if(!((c[a+4>>2]|0)>>>0<=64>>>0)){c[g+12>>2]=2562432;k=8;l=k;i=e;return l|0}if(!((c[a+36>>2]|0)>>>0<=25>>>0)){c[g+12>>2]=2544848;k=8;l=k;i=e;return l|0}if((c[a+64>>2]|0)==0){j=76}else{if((c[a+64>>2]|0)>>>0>0>>>0){j=76}}do{if((j|0)==76){if(!((c[a+64>>2]|0)>>>0<=3>>>0)){break}if(!((c[a+88>>2]|0)>>>0<=1e3>>>0)){c[g+12>>2]=2512016;k=8;l=k;i=e;return l|0}if(!((c[a+92>>2]|0)>>>0<=1e3>>>0)){c[g+12>>2]=2497816;k=8;l=k;i=e;return l|0}if(!((c[a+108>>2]|0)>>>0<=100>>>0)){c[g+12>>2]=2486368;k=8;l=k;i=e;return l|0}if((c[a+120>>2]|0)==0){j=98}else{if((c[a+120>>2]|0)>>>0>0>>>0){j=98}}do{if((j|0)==98){if(!((c[a+120>>2]|0)>>>0<=1>>>0)){break}if((((c[a+44>>2]|0)!=0^1^1)&1|0)!=(c[a+44>>2]|0)){c[g+12>>2]=2466032;k=8;l=k;i=e;return l|0}if(!((c[a+40>>2]|0)>>>0<=100>>>0)){c[g+12>>2]=2455552;k=8;l=k;i=e;return l|0}if(!((c[a+56>>2]|0)>>>0<=100>>>0)){c[g+12>>2]=2438296;k=8;l=k;i=e;return l|0}if(!((c[a+60>>2]|0)>>>0<=100>>>0)){c[g+12>>2]=2427560;k=8;l=k;i=e;return l|0}if((c[a+32>>2]|0)==0){j=125}else{if((c[a+32>>2]|0)>>>0>0>>>0){j=125}}do{if((j|0)==125){if(!((c[a+32>>2]|0)>>>0<=2>>>0)){break}a:do{if((c[a+44>>2]|0)==1){if((c[a+48>>2]|0)==1){j=133}else{if((c[a+48>>2]|0)>>>0>1>>>0){j=133}}do{if((j|0)==133){if(!((c[a+48>>2]|0)>>>0<=(c[a+12>>2]|0)>>>0)){break}if((c[a+52>>2]|0)==1){j=140}else{if((c[a+52>>2]|0)>>>0>1>>>0){j=140}}do{if((j|0)==140){if(!((c[a+52>>2]|0)>>>0<=(c[a+16>>2]|0)>>>0)){break}break a}}while(0);c[g+12>>2]=2400960;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2408424;k=8;l=k;i=e;return l|0}}while(0);if((c[a+132>>2]|0)==1){j=148}else{if((c[a+132>>2]|0)>>>0>1>>>0){j=148}}do{if((j|0)==148){if(!((c[a+132>>2]|0)>>>0<=5>>>0)){break}if((c[a+156>>2]|0)==1){j=155}else{if((c[a+156>>2]|0)>>>0>1>>>0){j=155}}do{if((j|0)==155){if(!((c[a+156>>2]|0)>>>0<=5>>>0)){break}b:do{if((c[a+156>>2]|0)>>>0>1>>>0){d=1;while(1){if(!(d>>>0<(c[a+156>>2]|0)>>>0)){break}if((c[a+160+(d<<2)>>2]|0)>>>0<(c[a+160+(d-1<<2)>>2]|0)>>>0){j=163;break}d=d+1|0}if((j|0)==163){c[g+12>>2]=2380056;k=8;l=k;i=e;return l|0}if((c[a+180+((c[a+156>>2]|0)-1<<2)>>2]|0)==1){j=170}else{if((c[a+180+((c[a+156>>2]|0)-1<<2)>>2]|0)>>>0>1>>>0){j=170}}do{if((j|0)==170){if(!((c[a+180+((c[a+156>>2]|0)-1<<2)>>2]|0)>>>0<=1>>>0)){break}d=(c[a+156>>2]|0)-2|0;while(1){if(!(d>>>0>0>>>0)){j=181;break}if((c[a+180+(d-1<<2)>>2]|0)!=(c[a+180+(d<<2)>>2]<<1|0)){break}d=d-1|0}if((j|0)==181){break b}c[g+12>>2]=2366080;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2373808;k=8;l=k;i=e;return l|0}}while(0);do{if((c[a+120>>2]|0)!=0){if((c[a+124>>2]|0)==(c[a+128>>2]|0)){break}if(!((c[a+124>>2]|0)>>>0>0>>>0)){break}c[g+12>>2]=2351e3;k=8;l=k;i=e;return l|0}}while(0);if((((c[b+8>>2]|0)!=0^1^1)&1|0)!=(c[b+8>>2]|0)){c[g+12>>2]=2343728;k=8;l=k;i=e;return l|0}if((c[b+4>>2]|0)==-16){j=195}else{if((c[b+4>>2]|0)>-16){j=195}}do{if((j|0)==195){if((c[b+4>>2]|0)>16){break}if(!((c[b+12>>2]|0)>>>0<=6>>>0)){c[g+12>>2]=2332224;k=8;l=k;i=e;return l|0}if((c[b+24>>2]|0)==0){j=207}else{if((c[b+24>>2]|0)>>>0>0>>>0){j=207}}do{if((j|0)==207){if(!((c[b+24>>2]|0)>>>0<=6>>>0)){break}if((c[b+28>>2]|0)==0){j=214}else{if((c[b+28>>2]|0)>>>0>0>>>0){j=214}}do{if((j|0)==214){if(!((c[b+28>>2]|0)>>>0<=2>>>0)){break}if(!((c[b+16>>2]|0)>>>0<=7>>>0)){c[g+12>>2]=2315944;k=8;l=k;i=e;return l|0}if((c[b+32>>2]|0)==0){j=226}else{if((c[b+32>>2]|0)>>>0>0>>>0){j=226}}do{if((j|0)==226){if(!((c[b+32>>2]|0)>>>0<=15>>>0)){break}if(!((c[b+36>>2]|0)>>>0<=6>>>0)){c[g+12>>2]=2306832;k=8;l=k;i=e;return l|0}if((c[b+40>>2]|0)==1){j=238}else{if((c[b+40>>2]|0)>>>0>1>>>0){j=238}}do{if((j|0)==238){if(!((c[b+40>>2]|0)>>>0<=3>>>0)){break}if((c[b+48>>2]|0)==0){j=245}else{if((c[b+48>>2]|0)>>>0>0>>>0){j=245}}do{if((j|0)==245){if(!((c[b+48>>2]|0)>>>0<=63>>>0)){break}if((c[b+44>>2]|0)==1){c[g+12>>2]=2283840;k=8;l=k;i=e;return l|0}if((c[a+32>>2]|0)==2){d=160;m=((c[a+72>>2]|0)>>>0)/(d>>>0)|0;if((c[a+68>>2]|0)==0){c[g+12>>2]=2279992;k=8;l=k;i=e;return l|0}if((((c[a+72>>2]|0)>>>0)%(d>>>0)|0|0)!=0){c[g+12>>2]=2275800;k=8;l=k;i=e;return l|0}do{if((c[a+132>>2]|0)>>>0>1>>>0){mrc(f|0,0,20)|0;n=c[a+68>>2]|0;o=0;while(1){if((o|0)>=(m|0)){break}p=c[n+(o*160|0)+152>>2]|0;do{if((p|0)>=0){if((p|0)>=(c[a+132>>2]|0)){break}q=f+(p<<2)|0;c[q>>2]=(c[q>>2]|0)+1}}while(0);o=o+1|0}o=0;while(1){if((o|0)>=(c[a+132>>2]|0)){j=278;break}if((c[f+(o<<2)>>2]|0)>>>0<2>>>0){j=270;break}n=(c[a+68>>2]|0)+(m*160|0)+((-(c[a+132>>2]|0)|0)*160|0)+(o*160|0)|0;p=c[n+152>>2]|0;if(p>>>0>=(c[a+132>>2]|0)>>>0){j=274;break}if((~~(+h[n+144>>3]+.5)|0)!=((c[f+(p<<2)>>2]|0)-1|0)){j=274;break}o=o+1|0}if((j|0)==270){c[g+12>>2]=2271200;k=8;l=k;i=e;return l|0}else if((j|0)==274){c[g+12>>2]=2266536;k=8;l=k;i=e;return l|0}else if((j|0)==278){break}}else{if((c[a+72>>2]|0)>>>0<d<<1>>>0){c[g+12>>2]=2263024;k=8;l=k;i=e;return l|0}n=(c[a+68>>2]|0)+(m*160|0)-160|0;if((~~(+h[n+144>>3]+.5)|0)==(m-1|0)){break}c[g+12>>2]=2266536;k=8;l=k;i=e;return l|0}}while(0)}do{if((c[a+8>>2]|0)>>>0<=1>>>0){if(!((c[b+72>>2]|0)>>>0>0>>>0)){break}c[g+12>>2]=2259056;k=8;l=k;i=e;return l|0}}while(0);do{if((c[a+8>>2]|0)>>>0>1>>>0){if((c[b+72>>2]|0)!=0){break}c[g+12>>2]=2254728;k=8;l=k;i=e;return l|0}}while(0);k=0;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2289488;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2300792;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2311432;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2320784;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2326592;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2337728;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2387120;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2393960;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2417344;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2474664;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2527104;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2582672;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2609464;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2196032;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2236120;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2285976;k=8;l=k;i=e;return l|0}}while(0);c[g+12>>2]=2346712;k=8;l=k;i=e;return l|0}function QWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0;e=i;f=a;a=b;b=d;c[f>>2]=c[a+8>>2];c[f+8>>2]=c[a+12>>2];c[f+12>>2]=c[a+16>>2];c[f+4>>2]=c[b+72>>2];h[f+16>>3]=+(c[a+24>>2]|0)/+(c[a+20>>2]|0);if(+h[f+16>>3]>180.0){h[f+16>>3]=30.0}d=c[a+32>>2]|0;if((d|0)==0){c[f+48>>2]=1}else if((d|0)==1){c[f+48>>2]=3}else if((d|0)==2){c[f+48>>2]=5}if((c[a+32>>2]|0)==1){g=0}else{g=c[a+36>>2]|0}c[f+60>>2]=g;c[f+64>>2]=0;if((c[a+64>>2]|0)==2){c[f+64>>2]=2}else{if((c[a+64>>2]|0)==3){c[f+64>>2]=3}else{if((c[a+64>>2]|0)==1){c[f+64>>2]=1}}}g=f+24|0;c[g>>2]=c[a+76>>2];c[g+4>>2]=0;c[f+44>>2]=c[b+52>>2];c[f+116>>2]=L2b(c[a+80>>2]|0)|0;c[f+112>>2]=L2b(c[a+84>>2]|0)|0;c[f+120>>2]=L2b(c[b+48>>2]|0)|0;c[f+108>>2]=-1;c[f+68>>2]=c[a+88>>2];c[f+72>>2]=c[a+92>>2];c[f+132>>2]=c[a+44>>2];c[f+136>>2]=c[a+48>>2];c[f+140>>2]=c[a+52>>2];g=f+96|0;c[g>>2]=c[a+96>>2];c[g+4>>2]=0;g=f+80|0;c[g>>2]=c[a+100>>2];c[g+4>>2]=0;g=f+88|0;c[g>>2]=c[a+104>>2];c[g+4>>2]=0;c[f+104>>2]=c[a+40>>2];c[f+148>>2]=c[a+108>>2];c[f+152>>2]=c[a+112>>2];c[f+156>>2]=c[a+116>>2];if((c[a+120>>2]|0)==1){j=(c[a+124>>2]|0)!=(c[a+128>>2]|0)}else{j=0}c[f+52>>2]=j&1;c[f+56>>2]=c[a+128>>2];c[f+40>>2]=c[b+4>>2];c[f+236>>2]=c[b+20>>2];c[f+228>>2]=c[b+8>>2];c[f+32>>2]=c[b+12>>2];c[f+36>>2]=c[b+16>>2];j=f+268|0;g=a+68|0;c[j>>2]=c[g>>2];c[j+4>>2]=c[g+4>>2];c[f+276>>2]=c[b>>2];c[f+248>>2]=c[b+32>>2];c[f+252>>2]=c[b+36>>2];c[f+256>>2]=c[b+40>>2];c[f+280>>2]=c[b+44>>2];c[f+260>>2]=c[b+24>>2];c[f+264>>2]=c[b+28>>2];c[f+124>>2]=c[b+56>>2];c[f+240>>2]=c[a+28>>2];c[f+244>>2]=c[b+60>>2];c[f+128>>2]=c[b+64>>2];c[f+144>>2]=c[b+68>>2];c[f+160>>2]=c[a+132>>2];if((c[f+160>>2]|0)>1){b=f+168|0;g=a+136|0;c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];c[b+8>>2]=c[g+8>>2];c[b+12>>2]=c[g+12>>2];c[b+16>>2]=c[g+16>>2]}else{if((c[f+160>>2]|0)==1){c[f+168>>2]=c[f+24>>2]}}c[f+164>>2]=c[a+156>>2];if((c[f+164>>2]|0)>1){g=f+188|0;b=a+160|0;c[g>>2]=c[b>>2];c[g+4>>2]=c[b+4>>2];c[g+8>>2]=c[b+8>>2];c[g+12>>2]=c[b+12>>2];c[g+16>>2]=c[b+16>>2];b=f+208|0;g=a+180|0;c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];c[b+8>>2]=c[g+8>>2];c[b+12>>2]=c[g+12>>2];c[b+16>>2]=c[g+16>>2];i=e;return 0}if((c[f+164>>2]|0)==1){c[f+188>>2]=c[f+24>>2];c[f+208>>2]=1}i=e;return 0}function RWb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;b=c[a>>2]|0;if(!((b|0)==769|(b|0)==258|(b|0)==261|(b|0)==262)){c[e+12>>2]=2222176;f=8;g=f;i=d;return g|0}do{if((c[a+12>>2]|0)==(c[e+220>>2]|0)){if((c[a+16>>2]|0)!=(c[e+224>>2]|0)){break}f=0;g=f;i=d;return g|0}}while(0);c[e+12>>2]=2218472;f=8;g=f;i=d;return g|0}function SWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=a;a=d;d=2;if((a|0)!=0){h=Erc(b,0,1e6,0)|0;b=c[g+228>>2]|0;j=Erc(h,G,b,(b|0)<0|0?-1:0)|0;b=c[g+232>>2]|0;h=Frc(j,G,b,(b|0)<0|0?-1:0)|0;c[f>>2]=h;c[f+4>>2]=G;h=0;b=c[f+4>>2]|0;d=h>>>0>b>>>0|h>>>0==b>>>0&a>>>0>(c[f>>2]|0)>>>0?1:6}if((c[g+240>>2]|0)==1){d=3}else{if((c[g+240>>2]|0)==2){d=(d|0)==2?5:4}}if((c[g+600>>2]|0)==(d|0)){i=e;return}c[g+600>>2]=d;i1b(c[g+840>>2]|0,g+552|0);i=e;return}function TWb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=a;a=b;c[a+52>>2]=c[e+28>>2];c[a+56>>2]=c[e+32>>2];c[a+60>>2]=c[e+36>>2];c[a+64>>2]=c[e+40>>2];c[a+8>>2]=c[e+12>>2];c[a+12>>2]=c[e+16>>2];c[a>>2]=c[e+12>>2];c[a+4>>2]=c[e+16>>2];if((c[e+20>>2]|0)==1){f=((c[a>>2]|0)+1|0)/2|0}else{f=c[a>>2]|0}c[a+20>>2]=f;if((c[e+24>>2]|0)==1){g=((c[a+4>>2]|0)+1|0)/2|0}else{g=c[a+4>>2]|0}c[a+24>>2]=g;if((c[a+64>>2]|0)!=0){h=c[e+12>>2]|0}else{h=0}c[a+40>>2]=h;if((c[a+64>>2]|0)!=0){j=c[e+16>>2]|0}else{j=0}c[a+44>>2]=j;c[a+16>>2]=c[e+44>>2];c[a+36>>2]=c[e+48>>2];if((c[a+64>>2]|0)!=0){k=c[e+56>>2]|0;l=a;m=l+48|0;c[m>>2]=k;n=e;o=n+44|0;p=o|0;q=c[p>>2]|0;r=e;s=r+4|0;t=c[s>>2]|0;u=q-t|0;v=(u>>>0)/2|0;w=a;x=w+76|0;c[x>>2]=v;i=d;return 0}else{k=0;l=a;m=l+48|0;c[m>>2]=k;n=e;o=n+44|0;p=o|0;q=c[p>>2]|0;r=e;s=r+4|0;t=c[s>>2]|0;u=q-t|0;v=(u>>>0)/2|0;w=a;x=w+76|0;c[x>>2]=v;i=d;return 0}return 0}function UWb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=b;b=c[e>>2]|0;if((b|0)==0){f=b;i=d;return f|0}if((c[e+4>>2]|0)!=0){g=e+8|0}else{g=0}c[a+12>>2]=g;f=b;i=d;return f|0}function VWb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=b;b=-64;if((c[e+860>>2]|0)!=0){}else{Cd(2234280,2230840,637,2649688);return 0}if((c[e+860>>2]|0)<=8){}else{Cd(2226928,2230840,638,2649688);return 0}b=(b&255|(c[e+860>>2]|0)-1)&255;f=0;g=255;while(1){if((f|0)>=4){break}if((c[e+896>>2]|0)>>>0<g>>>0){h=8;break}g=g<<8;g=g|255;f=f+1|0}b=(b&255|f<<3)&255;g=(ca(f+1|0,c[e+860>>2]|0)|0)+2|0;if(!(((c[e+856>>2]|0)+g|0)>>>0<(c[e+848>>2]|0)>>>0)){j=g;i=d;return j|0}h=(c[e+852>>2]|0)+(c[e+856>>2]|0)|0;k=h;h=k+1|0;a[k]=b;k=0;while(1){if((k|0)>=(c[e+860>>2]|0)){break}l=c[e+864+(k<<2)>>2]|0;m=0;while(1){if((m|0)>(f|0)){break}n=h;h=n+1|0;a[n]=l&255;l=l>>>8;m=m+1|0}k=k+1|0}k=h;h=k+1|0;a[k]=b;b=e+856|0;c[b>>2]=(c[b>>2]|0)+g;j=g;i=d;return j|0}function WWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+96|0;e=b|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)!=0){TWb(d+4|0,e)|0;f=c[a+840>>2]|0;y1b(f,CXb(c[d>>2]|0)|0,e)|0;g=0;h=g;i=b;return h|0}else{g=8;h=g;i=b;return h|0}return 0}function XWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;C1b(c[a+840>>2]|0,(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0))|0;i=b;return 0}function YWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;x1b(c[a+840>>2]|0,(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0));i=b;return 0}function ZWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;w1b(c[a+840>>2]|0,(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0))|0;i=b;return 0}function _Wb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+96|0;e=b|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)!=0){TWb(d+4|0,e)|0;f=c[a+840>>2]|0;B1b(f,CXb(c[d>>2]|0)|0,e)|0;g=0;h=g;i=b;return h|0}else{g=8;h=g;i=b;return h|0}return 0}function $Wb(a,b,c){a=a|0;b=b|0;c=c|0;i=i;return 4}function aXb(a,b,c){a=a|0;b=b|0;c=c|0;i=i;return 8}function bXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=d;d=(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0);if((d|0)==0){f=8;g=f;i=b;return g|0}if((W1b(c[a+840>>2]|0,c[d>>2]|0,c[d+4>>2]|0,c[d+8>>2]|0)|0)!=0){f=8;g=f;i=b;return g|0}else{f=0;g=f;i=b;return g|0}return 0}function cXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=d;d=(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0);if((d|0)!=0){e=(X1b(c[a+840>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0)==0;f=e?0:8;g=f;i=b;return g|0}else{f=8;g=f;i=b;return g|0}return 0}function dXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+80|0;f=e|0;g=a;a=d;d=0;nrc(f|0,g+476|0,76)|0;switch(b|0){case 24:{c[f+44>>2]=vXb(a)|0;break};case 21:{c[f+32>>2]=sXb(a)|0;break};case 30:{c[f+60>>2]=zXb(a)|0;break};case 14:{c[f+8>>2]=mXb(a)|0;break};case 27:{c[f+56>>2]=yXb(a)|0;break};case 26:{c[f+52>>2]=xXb(a)|0;break};case 28:{c[f+24>>2]=qXb(a)|0;break};case 31:{c[f+64>>2]=AXb(a)|0;break};case 32:{c[f+68>>2]=BXb(a)|0;break};case 25:{c[f+48>>2]=wXb(a)|0;break};case 15:{c[f+12>>2]=nXb(a)|0;break};case 13:{c[f+4>>2]=lXb(a)|0;break};case 22:{c[f+36>>2]=tXb(a)|0;break};case 29:{c[f+28>>2]=rXb(a)|0;break};case 17:{c[f+20>>2]=pXb(a)|0;break};case 16:{c[f+16>>2]=oXb(a)|0;break};case 23:{c[f+40>>2]=uXb(a)|0;break};default:{}}d=PWb(g,g+208|0,f)|0;if((d|0)!=0){h=d;i=e;return h|0}nrc(g+476|0,f|0,76)|0;QWb(g+552|0,g+208|0,g+476|0)|0;i1b(c[g+840>>2]|0,g+552|0);h=d;i=e;return h|0}function eXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);a=e+208|0;Y1b(c[e+840>>2]|0,d);a:do{if((d|0)==1){do{if((c[a+64>>2]|0)!=1){if((c[a+32>>2]|0)==1){break}if((c[a+32>>2]|0)!=2){break a}}}while(0);if(!((c[a+132>>2]|0)>>>0>1>>>0)){break}if(!((c[a+156>>2]|0)>>>0>1>>>0)){break}f=8;g=f;i=b;return g|0}}while(0);f=0;g=f;i=b;return g|0}function fXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;e=a;a=c[e+840>>2]|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)==0){g=8;h=g;i=b;return h|0}c[a+2050808>>2]=c[d+8>>2];c[a+2050812>>2]=c[d+12>>2];c[a+1472132>>2]=c[d+32>>2];c[a+1472136>>2]=c[d+36>>2];c[a+1472140>>2]=c[d+40>>2];if((N1b(c[e+840>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0)!=0){g=8;h=g;i=b;return h|0}else{c[e+292>>2]=c[d+20>>2];c[e+288>>2]=c[d+24>>2];QWb(e+552|0,e+208|0,e+476|0)|0;i1b(c[e+840>>2]|0,e+552|0);g=0;h=g;i=b;return h|0}return 0}function gXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);a=(c[e+840>>2]|0)+2050808|0;c[a>>2]=c[d>>2];c[a+4>>2]=c[d+4>>2];do{if((c[a+4>>2]|0)>=0){if((c[a+4>>2]|0)>=(c[e+364>>2]|0)){break}do{if((c[a>>2]|0)>=0){if((c[a>>2]|0)>=(c[e+340>>2]|0)){break}f=0;g=f;i=b;return g|0}}while(0);f=8;g=f;i=b;return g|0}}while(0);f=8;g=f;i=b;return g|0}function hXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);if((d|0)==0){g=8;h=g;i=e;return h|0}a=b;if((a|0)==19){b=$1b(c[f+840>>2]|0)|0;c[(jXb(d)|0)>>2]=b}else if((a|0)==20){a=M2b($1b(c[f+840>>2]|0)|0)|0;c[(kXb(d)|0)>>2]=a}g=0;h=g;i=e;return h|0}function iXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+8|0;e=b|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)!=0){A1b(c[a+840>>2]|0,c[d>>2]|0,e)|0;OWb(d+4|0,c[e>>2]|0,0);g=0;h=g;i=b;return h|0}else{g=8;h=g;i=b;return h|0}return 0}function jXb(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;i=b;return c[d>>2]|0}function kXb(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;i=b;return c[d>>2]|0}function lXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function mXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function nXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function oXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function pXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function qXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function rXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function sXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function tXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function uXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function vXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function wXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function xXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function yXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function zXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function AXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function BXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(x=c[d+4>>2]|0,c[d+4>>2]=x+8,c[(c[d>>2]|0)+x>>2]|0);i=b;return a|0}function CXb(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;if((c|0)==4){d=4}else if((c|0)==1){d=1}else if((c|0)==2){d=2}else{Cd(2215624,2230840,104,2651400);return 0}i=b;return d|0}function DXb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a;a=0;if((c[d+24>>2]|0)==0){e=Rqc(1,9856)|0;if((e|0)==0){f=2;g=f;i=b;return g|0}c[d+24>>2]=e;c[c[d+24>>2]>>2]=208;c[(c[d+24>>2]|0)+4>>2]=c[d+4>>2];c[(c[d+24>>2]|0)+8>>2]=e;c[(c[d+24>>2]|0)+16>>2]=c[d+16>>2];c[(c[d+24>>2]|0)+200>>2]=1;if((c[d+20>>2]|0)!=0){nrc((c[(c[d+24>>2]|0)+8>>2]|0)+208|0,c[d+20>>2]|0,268)|0;c[d+20>>2]=(c[(c[d+24>>2]|0)+8>>2]|0)+208}h=(c[(c[d+24>>2]|0)+8>>2]|0)+208|0;j=0;while(1){if((c[1489120+(j*80|0)>>2]|0)!=0){k=(c[1489120+(j*80|0)>>2]|0)!=(c[h>>2]|0)}else{k=0}if(!k){break}j=j+1|0}nrc(e+476|0,1489124+(j*80|0)|0,76)|0;c[e+476>>2]=e+1e3;c[e+848>>2]=((((ca(c[e+220>>2]|0,c[e+224>>2]|0)|0)*3|0)>>>0)/2|0)<<3;if((c[e+848>>2]|0)>>>0<4096>>>0){c[e+848>>2]=4096}c[e+844>>2]=Pqc(c[e+848>>2]|0)|0;if((c[e+844>>2]|0)==0){f=2;g=f;i=b;return g|0}d1b();a=PWb(e,e+208|0,e+476|0)|0;if((a|0)==0){QWb((c[(c[d+24>>2]|0)+8>>2]|0)+552|0,(c[(c[d+24>>2]|0)+8>>2]|0)+208|0,(c[(c[d+24>>2]|0)+8>>2]|0)+476|0)|0;e=m1b((c[(c[d+24>>2]|0)+8>>2]|0)+552|0)|0;if((e|0)==0){a=2}else{c[(c[(c[d+24>>2]|0)+8>>2]|0)+840>>2]=e}}}f=a;g=f;i=b;return g|0}function EXb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;b=i;d=a;if((c[d+24>>2]|0)==0){a=BYb(32,368)|0;if((a|0)==0){e=2;f=e;i=b;return f|0}mrc(a|0,0,368)|0;c[d+24>>2]=a;c[c[d+24>>2]>>2]=208;c[(c[d+24>>2]|0)+4>>2]=c[d+4>>2];c[(c[d+24>>2]|0)+8>>2]=a;c[(c[(c[d+24>>2]|0)+8>>2]|0)+220>>2]=16;c[(c[d+24>>2]|0)+16>>2]=c[d+16>>2];if((c[d+20>>2]|0)!=0){a=(c[(c[d+24>>2]|0)+8>>2]|0)+208|0;g=c[d+20>>2]|0;c[a>>2]=c[g>>2];c[a+4>>2]=c[g+4>>2];c[a+8>>2]=c[g+8>>2];c[d+20>>2]=(c[(c[d+24>>2]|0)+8>>2]|0)+208}}e=0;f=e;i=b;return f|0}function FXb(a){a=a|0;var b=0,d=0;b=i;d=a;if((c[d+240>>2]|0)!=0){F0b(c[d+240>>2]|0);c[d+240>>2]=0}FYb(d);i=b;return 0}function GXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+24|0;f=e|0;g=a;a=b;b=d;if(a>>>0<=8>>>0){h=5;j=h;i=e;return j|0}if((g+a|0)>>>0<=g>>>0){h=8;j=h;i=e;return j|0}c[b+12>>2]=0;c[b+8>>2]=0;c[b+4>>2]=0;c[f>>2]=g;c[f+4>>2]=g+a;c[f+8>>2]=0;c[f+12>>2]=0;c[f+16>>2]=0;a=X0b(f,2)|0;g=W0b(f)|0;W0b(f)|0;if((a|0)!=2){h=5;j=h;i=e;return j|0}if((g|0)>1){h=5;j=h;i=e;return j|0}if((W0b(f)|0)!=0){h=0;j=h;i=e;return j|0}c[b+12>>2]=((W0b(f)|0)!=0^1)&1;a:do{if((c[b+12>>2]|0)!=0){a=f+8|0;c[a>>2]=(c[a>>2]|0)+1;a=f+8|0;c[a>>2]=(c[a>>2]|0)+1;do{if((X0b(f,8)|0)==73){if((X0b(f,8)|0)!=131){break}if((X0b(f,8)|0)!=66){break}do{if((X0b(f,3)|0)!=7){a=f+8|0;c[a>>2]=(c[a>>2]|0)+1;if((g|0)==1){a=f+8|0;c[a>>2]=(c[a>>2]|0)+2;a=f+8|0;c[a>>2]=(c[a>>2]|0)+1}}else{if((g|0)==1){a=f+8|0;c[a>>2]=(c[a>>2]|0)+1;break}else{h=5;j=h;i=e;return j|0}}}while(0);c[b+4>>2]=(X0b(f,16)|0)+1;c[b+8>>2]=(X0b(f,16)|0)+1;break a}}while(0);h=5;j=h;i=e;return j|0}}while(0);h=0;j=h;i=e;return j|0}function HXb(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=b;b=(c[e>>2]|0)>>>0>=16>>>0?16:16;nrc(e|0,a+220|0,b)|0;c[e>>2]=b;i=d;return 0}function IXb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+48|0;k=j|0;l=j+8|0;m=j+40|0;n=b;b=e;e=f;f=g;g=h;c[k>>2]=b;h=b+e|0;o=0;p=0;do{if((b|0)!=0){if((e|0)==0){break}LXb(b,e,l|0,m);a:do{b:do{if((e|0)!=0){if((a[c[k>>2]|0]&224|0)!=192){q=13;break}r=a[c[k>>2]|0]|0;s=(ca(((r&255)>>3&3)+1|0,(r&7)+1|0)|0)+2|0;do{if(e>>>0>=s>>>0){if((d[(c[k>>2]|0)+(s-1)|0]|0|0)!=(r&255|0)){break}c[k>>2]=(c[k>>2]|0)+s;e=e-s|0;if(!((c[k>>2]|0)>>>0<h>>>0)){q=11;break a}break b}}while(0);q=13}else{q=13}}while(0);if((q|0)==13){q=0;if((c[m>>2]|0)!=0){s=c[l+(p<<2)>>2]|0;if(e>>>0<s>>>0){q=15;break}e=s;p=p+1|0}s=g;o=MXb(n,k,e,f,s,(s|0)<0|0?-1:0)|0;if((c[k>>2]|0)>>>0>=b>>>0){}else{Cd(2431704,2346504,376,2652984);return 0}if((c[k>>2]|0)>>>0<=h>>>0){}else{Cd(2285872,2346504,377,2652984);return 0}if((o|0)!=0){q=22;break}while(1){if((c[k>>2]|0)>>>0<h>>>0){t=(d[c[k>>2]|0]|0|0)==0}else{t=0}if(!t){break}c[k>>2]=(c[k>>2]|0)+1}e=h-(c[k>>2]|0)|0}}while((c[k>>2]|0)>>>0<h>>>0);if((q|0)!=11)if((q|0)==15){c[n+12>>2]=2570416;u=7;v=u;i=j;return v|0}u=o;v=u;i=j;return v|0}}while(0);u=8;v=u;i=j;return v|0}function JXb(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=b;b=0;if((c[e+348>>2]|0)!=0){if((c[a>>2]|0)==0){b=e+260|0;c[a>>2]=b}}c[e+348>>2]=0;i=d;return b|0}function KXb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;b=d;d=e;do{if((a|0)!=0){if((b|0)==0){break}if((c[g+240>>2]|0)==0){c[g+360>>2]=a;c[g+364>>2]=b;c[g+356>>2]=d;h=0;j=h;i=f;return j|0}h=1;j=h;i=f;return j|0}}while(0);h=8;j=h;i=f;return j|0}function LXb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=b;b=e;e=f;f=g;if((b|0)!=0){}else{Cd(2195960,2346504,303,2651776)}g=a[j+(b-1)|0]|0;c[f>>2]=0;if((g&224|0)!=192){i=h;return}k=(g&7)+1|0;l=((g&255)>>3&3)+1|0;m=(ca(l,k)|0)+2|0;do{if(b>>>0>=m>>>0){if((d[j+(b-m)|0]|0|0)!=(g&255|0)){break}n=j+(b-m+1)|0;o=0;while(1){if(!(o>>>0<k>>>0)){break}p=0;q=0;while(1){if(!(q>>>0<l>>>0)){break}r=n;n=r+1|0;p=p|(d[r]|0)<<(q<<3);q=q+1|0}c[e+(o<<2)>>2]=p;o=o+1|0}c[f>>2]=k}}while(0);i=h;return}function MXb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+136|0;j=h|0;k=h+8|0;l=h+104|0;m=h+112|0;n=h+120|0;o=a;a=b;b=d;d=e;c[j>>2]=f;c[j+4>>2]=g;mrc(k|0,0,92)|0;c[l>>2]=0;c[l+4>>2]=0;c[m>>2]=0;c[m+4>>2]=0;mrc(n|0,0,12)|0;g=0;c[o+348>>2]=0;do{if((c[o+228>>2]|0)==0){f=Ee[c[(c[o+4>>2]|0)+32>>2]&511](c[a>>2]|0,b,o+220|0)|0;if((f|0)==0){break}p=f;q=p;i=h;return q|0}}while(0);do{if((c[o+236>>2]|0)==0){NXb(o);if((c[o+240>>2]|0)!=0){c[o+236>>2]=1;break}p=1;q=p;i=h;return q|0}}while(0);g=(c[o+240>>2]|0)+50480|0;if((L0b(c[o+240>>2]|0,b,a,c[j>>2]|0,c[j+4>>2]|0)|0)!=0){p=OXb(o,g|0)|0;q=p;i=h;return q|0}if((c[o+16>>2]&65536|0)!=0){PXb(o,n)}if((N0b(c[o+240>>2]|0,k,l,m,n)|0)!=0){p=OXb(o,g|0)|0;q=p;i=h;return q|0}else{QXb(o+260|0,k,d);c[o+340>>2]=c[g+8488+((c[g+10008>>2]|0)*108|0)+12>>2];c[o+348>>2]=1;p=0;q=p;i=h;return q|0}return 0}function NXb(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=a;c[d>>2]=c[e+224>>2];c[d+4>>2]=c[e+228>>2];c[d+8>>2]=9;c[d+12>>2]=c[e+208>>2];c[d+16>>2]=c[e+352>>2];c[e+240>>2]=E0b(d)|0;if((c[e+240>>2]|0)==0){i=b;return}D0b();do{if((c[e+244>>2]|0)==0){if((c[e+16>>2]&65536|0)==0){break}RXb(e+248|0)}}while(0);SXb(e);i=b;return}function OXb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;if((c[a>>2]|0)!=0){if((c[a+4>>2]|0)!=0){f=a+8|0}else{f=0}c[e+12>>2]=f}i=d;return c[a>>2]|0}function PXb(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[a>>2]=c[d+248>>2];c[a+4>>2]=c[d+252>>2];c[a+8>>2]=c[d+256>>2];i=i;return}function QXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=d;d=12;if((c[a+24>>2]|0)==(c[a+4>>2]|0)){if((c[a+20>>2]|0)==(c[a>>2]|0)){c[f>>2]=262;d=24}else{c[f>>2]=261;d=16}}else{c[f>>2]=258}c[f+4>>2]=c[a+16>>2];c[f+8>>2]=(c[a+4>>2]|0)+327&-8;c[f+12>>2]=c[a+8>>2];c[f+16>>2]=c[a+12>>2];c[f+20>>2]=(c[a+20>>2]|0)<(c[a>>2]|0);c[f+24>>2]=(c[a+24>>2]|0)<(c[a+4>>2]|0);c[f+28>>2]=c[a+52>>2];c[f+32>>2]=c[a+56>>2];c[f+36>>2]=c[a+60>>2];c[f+40>>2]=c[a+64>>2];c[f+44>>2]=c[a+16>>2];c[f+48>>2]=c[a+36>>2];c[f+52>>2]=c[a+36>>2];c[f+56>>2]=c[a+48>>2];c[f+60>>2]=d;c[f+64>>2]=b;c[f+68>>2]=c[a+68>>2];c[f+72>>2]=0;c[f+76>>2]=0;i=e;return}function RXb(a){a=a|0;var b=0;b=a;c[b>>2]=3;c[b+4>>2]=4;c[b+8>>2]=0;i=i;return}function SXb(a){a=a|0;var b=0,d=0;b=i;d=a;a=(c[d+240>>2]|0)+50480|0;c[a+10008>>2]=-1;do{if((c[d+360>>2]|0)!=0){if((c[d+364>>2]|0)==0){break}c[a+36984>>2]=c[d+360>>2];c[a+36988>>2]=c[d+364>>2];c[a+36980>>2]=c[d+356>>2];i=b;return}}while(0);c[a+36984>>2]=382;c[a+36988>>2]=704;if((z0b(a+36992|0)|0)!=0){TXb(a|0,2,2235968,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d}c[a+36980>>2]=a+36992;i=b;return}function TXb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function UXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+96|0;e=b|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)!=0){f=d;bYb(f+4|0,e)|0;g=G0b(c[a+240>>2]|0,c[f>>2]|0,e)|0;h=g;i=b;return h|0}else{g=8;h=g;i=b;return h|0}return 0}function VXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+96|0;e=b|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)!=0){f=d;bYb(f+4|0,e)|0;g=J0b((c[a+240>>2]|0)+50480|0,c[f>>2]|0,e)|0;h=g;i=b;return h|0}else{g=8;h=g;i=b;return h|0}return 0}function WXb(a,b,c){a=a|0;b=b|0;c=c|0;i=i;return 4}function XXb(a,b,c){a=a|0;b=b|0;c=c|0;i=i;return 4}function YXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=d;c[a+352>>2]=(x=c[e+4>>2]|0,c[e+4>>2]=x+8,c[(c[e>>2]|0)+x>>2]|0);i=b;return 0}function ZXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);if((d|0)==0){f=8;g=f;i=b;return g|0}if((c[e+240>>2]|0)==0){f=1;g=f;i=b;return g|0}c[d>>2]=c[(c[e+240>>2]|0)+87524>>2];f=0;g=f;i=b;return g|0}function _Xb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);if((d|0)==0){f=8;g=f;i=b;return g|0}if((c[e+240>>2]|0)==0){f=1;g=f;i=b;return g|0}c[d>>2]=c[(c[(c[e+240>>2]|0)+58964>>2]|0)+84>>2];f=0;g=f;i=b;return g|0}function $Xb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+8|0;e=b|0;f=d;d=(x=c[f+4>>2]|0,c[f+4>>2]=x+8,c[(c[f>>2]|0)+x>>2]|0);if((d|0)!=0){K0b(c[a+240>>2]|0,c[d>>2]|0,e)|0;QXb(d+4|0,c[e>>2]|0,0);g=0;h=g;i=b;return h|0}else{g=8;h=g;i=b;return h|0}return 0}function aYb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;e=a;a=d;d=(x=c[a+4>>2]|0,c[a+4>>2]=x+8,c[(c[a>>2]|0)+x>>2]|0);if((d|0)==0){f=8;g=f;i=b;return g|0}if((c[e+240>>2]|0)==0){f=1;g=f;i=b;return g|0}a=(c[e+240>>2]|0)+50480|0;c[d>>2]=c[a+8460>>2];c[d+4>>2]=c[a+8464>>2];f=0;g=f;i=b;return g|0}function bYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=a;a=b;c[a+52>>2]=c[e+28>>2];c[a+56>>2]=c[e+32>>2];c[a+60>>2]=c[e+36>>2];c[a+64>>2]=c[e+40>>2];c[a+8>>2]=c[e+12>>2];c[a+12>>2]=c[e+16>>2];c[a>>2]=c[e+12>>2];c[a+4>>2]=c[e+16>>2];if((c[e+20>>2]|0)==1){f=((c[a>>2]|0)+1|0)/2|0}else{f=c[a>>2]|0}c[a+20>>2]=f;if((c[e+24>>2]|0)==1){g=((c[a+4>>2]|0)+1|0)/2|0}else{g=c[a+4>>2]|0}c[a+24>>2]=g;if((c[a+64>>2]|0)!=0){h=c[e+12>>2]|0}else{h=0}c[a+40>>2]=h;if((c[a+64>>2]|0)!=0){j=c[e+16>>2]|0}else{j=0}c[a+44>>2]=j;c[a+16>>2]=c[e+44>>2];c[a+36>>2]=c[e+48>>2];if((c[a+64>>2]|0)!=0){k=c[e+56>>2]|0;l=a;m=l+48|0;c[m>>2]=k;n=e;o=n+44|0;p=o|0;q=c[p>>2]|0;r=e;s=r+4|0;t=c[s>>2]|0;u=q-t|0;v=(u>>>0)/2|0;w=a;x=w+76|0;c[x>>2]=v;i=d;return 0}else{k=0;l=a;m=l+48|0;c[m>>2]=k;n=e;o=n+44|0;p=o|0;q=c[p>>2]|0;r=e;s=r+4|0;t=c[s>>2]|0;u=q-t|0;v=(u>>>0)/2|0;w=a;x=w+76|0;c[x>>2]=v;i=d;return 0}return 0}function cYb(){return 66304}function dYb(){return 2371432}function eYb(a){a=a|0;var b=0;switch(a|0){case 0:{b=2346376;break};case 1:{b=2285800;break};case 5:{b=2138408;break};case 4:{b=2164296;break};case 8:{b=2609208;break};case 9:{b=2582456;break};case 3:{b=2195904;break};case 7:{b=2632992;break};case 2:{b=2235872;break};case 6:{b=2114912;break};default:{b=2562184}}i=i;return b|0}function fYb(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;if((d|0)!=0){e=eYb(c[d+8>>2]|0)|0;i=b;return e|0}else{e=eYb(8)|0;i=b;return e|0}return 0}function gYb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;do{if((d|0)!=0){if((c[d+8>>2]|0)==0){break}if((c[d+24>>2]|0)!=0){e=c[(c[d+24>>2]|0)+12>>2]|0}else{e=c[d+12>>2]|0}f=e;g=f;i=b;return g|0}}while(0);f=0;g=f;i=b;return g|0}function hYb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;if((d|0)!=0){do{if((c[d+4>>2]|0)!=0){if((c[d+24>>2]|0)==0){e=5;break}if((c[(c[d+24>>2]|0)+8>>2]|0)!=0){ve[c[(c[d+4>>2]|0)+16>>2]&4095](c[(c[d+24>>2]|0)+8>>2]|0)|0}c[d+4>>2]=0;c[d>>2]=0;c[d+24>>2]=0;f=0}else{e=5}}while(0);if((e|0)==5){f=1}}else{f=8}if((d|0)!=0){e=f;c[d+8>>2]=e;g=e;i=b;return g|0}else{g=f;i=b;return g|0}return 0}function iYb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e|0;g=a;a=b;do{if((g|0)!=0){if((a|0)==0){h=3;break}do{if((c[g+4>>2]|0)!=0){if((c[g+24>>2]|0)==0){h=7;break}if((c[(c[g+4>>2]|0)+20>>2]|0)==0){h=7;break}j=1;b=c[(c[g+4>>2]|0)+20>>2]|0;while(1){if((b|0)!=0){k=(c[b+4>>2]|0)!=0}else{k=0}if(!k){break}if((c[b>>2]|0)==0){h=14;break}if((c[b>>2]|0)==(a|0)){h=14;break}b=b+8|0}if((h|0)==14){l=f|0;c[l>>2]=d;c[l+4>>2]=0;j=Ee[c[b+4>>2]&511](c[(c[g+24>>2]|0)+8>>2]|0,a,f|0)|0;}}else{h=7}}while(0);if((h|0)==7){j=1}}else{h=3}}while(0);if((h|0)==3){j=8}if((g|0)!=0){h=j;c[g+8>>2]=h;m=h;i=e;return m|0}else{m=j;i=e;return m|0}return 0}function jYb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=a;a=b;b=d;d=e;if((f|0)!=7){j=3}else{do{if((h|0)!=0){if((a|0)==0){k=5;break}if((c[a+4>>2]|0)!=5){j=3}else{do{if((d&1|0)!=0){if((c[a+8>>2]&4|0)!=0){k=11;break}j=4}else{k=11}}while(0);if((k|0)==11){do{if((d&65536|0)!=0){if((c[a+8>>2]&262144|0)!=0){k=14;break}j=4}else{k=14}}while(0);if((k|0)==14){do{if((d&131072|0)!=0){if((c[a+8>>2]&524288|0)!=0){k=17;break}j=4}else{k=17}}while(0);if((k|0)==17){do{if((d&262144|0)!=0){if((c[a+8>>2]&1048576|0)!=0){k=20;break}j=4}else{k=20}}while(0);if((k|0)==20){if((c[a+8>>2]&1|0)!=0){mrc(h|0,0,28)|0;c[h+4>>2]=a;c[h>>2]=c[a>>2];c[h+24>>2]=0;c[h+16>>2]=d;c[h+20>>2]=b;j=0;if((d&1|0)==0){j=We[c[(c[h+4>>2]|0)+12>>2]&2047](h,0)|0;if((j|0)!=0){if((c[h+24>>2]|0)!=0){l=c[(c[h+24>>2]|0)+12>>2]|0}else{l=0}c[h+12>>2]=l;hYb(h)|0}if((c[h+24>>2]|0)!=0){c[(c[h+24>>2]|0)+4>>2]=c[h+4>>2]}}}else{j=4}}}}}}}else{k=5}}while(0);if((k|0)==5){j=8}}if((h|0)!=0){k=j;c[h+8>>2]=k;m=k;i=g;return m|0}else{m=j;i=g;return m|0}return 0}function kYb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=a;a=b;b=d;d=e;e=f;do{if((h|0)!=0){if((a|0)==0){if((b|0)!=0){j=4;break}}do{if((c[h+4>>2]|0)!=0){if((c[h+24>>2]|0)==0){j=7;break}k=Xe[c[(c[h+4>>2]|0)+40>>2]&511](c[(c[h+24>>2]|0)+8>>2]|0,a,b,d,e)|0}else{j=7}}while(0);if((j|0)==7){k=1}}else{j=4}}while(0);if((j|0)==4){k=8}if((h|0)!=0){j=k;c[h+8>>2]=j;l=j;i=g;return l|0}else{l=k;i=g;return l|0}return 0}function lYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;do{if((e|0)!=0){if((a|0)==0){break}if((c[e+4>>2]|0)==0){break}if((c[e+24>>2]|0)==0){break}f=We[c[(c[e+4>>2]|0)+44>>2]&2047](c[(c[e+24>>2]|0)+8>>2]|0,a)|0;g=f;i=d;return g|0}}while(0);f=0;g=f;i=d;return g|0}function mYb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=a;a=b;b=d;d=e;if((f|0)!=7){j=3}else{do{if((h|0)!=0){if((a|0)==0){k=6;break}if((b|0)==0){k=6;break}if((c[a+4>>2]|0)!=5){j=3}else{if((c[a+8>>2]&2|0)!=0){do{if((d&1|0)!=0){if((c[a+8>>2]&4|0)!=0){k=14;break}j=4}else{k=14}}while(0);if((k|0)==14){do{if((d&65536|0)!=0){if((c[a+8>>2]&65536|0)!=0){k=17;break}j=4}else{k=17}}while(0);if((k|0)==17){do{if((d&131072|0)!=0){if((c[a+8>>2]&131072|0)!=0){k=20;break}j=4}else{k=20}}while(0);if((k|0)==20){c[h+4>>2]=a;c[h>>2]=c[a>>2];c[h+24>>2]=0;c[h+16>>2]=d;c[h+20>>2]=b;j=We[c[(c[h+4>>2]|0)+12>>2]&2047](h,0)|0;if((j|0)!=0){if((c[h+24>>2]|0)!=0){l=c[(c[h+24>>2]|0)+12>>2]|0}else{l=0}c[h+12>>2]=l;hYb(h)|0}if((c[h+24>>2]|0)!=0){c[(c[h+24>>2]|0)+4>>2]=c[h+4>>2]}}}}}else{j=4}}}else{k=6}}while(0);if((k|0)==6){j=8}}if((h|0)!=0){k=j;c[h+8>>2]=k;m=k;i=g;return m|0}else{m=j;i=g;return m|0}return 0}function nYb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a;a=b;b=d;do{if((f|0)!=0){if((a|0)==0){break}if(b>>>0>2147483647>>>0){break}if((c[f+8>>2]&2|0)!=0){g=8;d=c[f+52>>2]|0;while(1){if((c[d>>2]|0)<0){break}if((c[d>>2]|0)==(b|0)){h=10;break}d=d+272|0}if((h|0)==10){nrc(a|0,d+4|0,268)|0;c[a>>2]=b;g=0}}else{g=4}j=g;i=e;return j|0}}while(0);g=8;j=g;i=e;return j|0}function oYb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0;j=i;i=i+8|0;k=j|0;l=a;a=b;c[k>>2]=d;c[k+4>>2]=e;e=f;f=g;g=h;h=0;do{if((l|0)!=0){if((a|0)!=0){if((e|0)==0){m=4;break}}do{if((c[l+4>>2]|0)!=0){if((c[l+24>>2]|0)==0){m=7;break}if((c[(c[l+4>>2]|0)+8>>2]&2|0)!=0){d=c[(c[l+24>>2]|0)+200>>2]|0;tYb();if((d|0)==1){h=me[c[(c[l+4>>2]|0)+56>>2]&255](c[(c[l+24>>2]|0)+8>>2]|0,a,c[k>>2]|0,c[k+4>>2]|0,e,f,g)|0}else{l=l+((d-1|0)*28|0)|0;if((a|0)!=0){a=a+((d-1|0)*84|0)|0}b=d-1|0;while(1){if((b|0)<0){break}d=me[c[(c[l+4>>2]|0)+56>>2]&255](c[(c[l+24>>2]|0)+8>>2]|0,a,c[k>>2]|0,c[k+4>>2]|0,e,f,g)|0;h=d;if((d|0)!=0){m=17;break}l=l-28|0;if((a|0)!=0){a=a-84|0}b=b-1|0}l=l+28|0}sYb()}else{h=4}}else{m=7}}while(0);if((m|0)==7){h=1}}else{m=4}}while(0);if((m|0)==4){h=8}if((l|0)!=0){m=h;c[l+8>>2]=m;n=m;i=j;return n|0}else{n=h;i=j;return n|0}return 0}function pYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=0;if((e|0)!=0){if((a|0)!=0){do{if((c[e+4>>2]|0)!=0){if((c[e+24>>2]|0)==0){f=6;break}if((c[(c[e+4>>2]|0)+8>>2]&2|0)!=0){b=We[c[(c[e+4>>2]|0)+60>>2]&2047](c[(c[e+24>>2]|0)+8>>2]|0,a)|0}else{c[e+8>>2]=4}}else{f=6}}while(0);if((f|0)==6){c[e+8>>2]=1}}else{c[e+8>>2]=8}}if((b|0)==0){g=b;i=d;return g|0}if((c[b>>2]|0)!=0){g=b;i=d;return g|0}f=c[e+24>>2]|0;e=c[f+44>>2]|0;do{if((e|0)!=0){if((c[b+8>>2]|0)==(e|0)){break}if(!(((c[b+12>>2]|0)+(c[f+52>>2]|0)+(c[f+56>>2]|0)|0)>>>0<=(c[f+48>>2]|0)>>>0)){break}a=f+64|0;nrc(e+(c[f+52>>2]|0)|0,c[b+8>>2]|0,c[b+12>>2]|0)|0;nrc(a|0,b|0,136)|0;c[a+8>>2]=e;h=a+12|0;c[h>>2]=(c[h>>2]|0)+((c[f+52>>2]|0)+(c[f+56>>2]|0));b=a}}while(0);if((e|0)==(c[b+8>>2]|0)){c[f+44>>2]=e+(c[b+12>>2]|0);e=f+48|0;c[e>>2]=(c[e>>2]|0)-(c[b+12>>2]|0)}g=b;i=d;return g|0}function qYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;if((c[e>>2]|0)>>>0<(c[e+4>>2]|0)>>>0){a=e|0;f=c[a>>2]|0;c[a>>2]=f+1;nrc(e+8+(f*136|0)|0,b|0,136)|0;g=0;h=g;i=d;return h|0}else{g=1;h=g;i=d;return h|0}return 0}function rYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;if((c[a>>2]|0)==0){c[a>>2]=e+8}b=c[a>>2]|0;if(((b-(e+8)|0)/136|0)>>>0<(c[e>>2]|0)>>>0){c[a>>2]=b+136;f=b;i=d;return f|0}else{b=0;f=b;i=d;return f|0}return 0}function sYb(){return}function tYb(){return}function uYb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=i;k=a;a=b;b=d;d=e;e=f;f=g;g=h;if((e|0)==0){e=1}a:do{if((e&e-1|0)==0){if((f|0)==0){f=1}if((f&f-1|0)!=0){break}switch(a|0){case 258:case 769:case 260:case 771:{l=12;break};case 2:case 9:case 10:case 11:{l=32;break};case 1:case 8:{l=24;break};case 3:case 12:case 4:case 13:case 5:case 6:case 7:{l=16;break};default:{l=16}}h=a;if((h|0)==258|(h|0)==769|(h|0)==260|(h|0)==771){m=1}else{m=0}h=a;if((h|0)==258|(h|0)==769|(h|0)==260|(h|0)==771){n=1}else{n=0}h=(1<<m)-1|0;o=b+h&~h;h=(1<<n)-1|0;p=d+h&~h;if((a&256|0)!=0){q=o}else{q=((ca(l,o)|0)>>>0)/8|0}h=q;h=h+f-1&~(f-1);do{if((k|0)!=0){mrc(k|0,0,84)|0}else{k=Rqc(1,84)|0;if((k|0)!=0){c[k+76>>2]=1;break}else{break a}}}while(0);c[k+68>>2]=g;if((g|0)==0){if((a&256|0)!=0){r=((ca(ca(p,h)|0,l)|0)>>>0)/8|0}else{r=ca(p,h)|0}c[k+68>>2]=zYb(e,r)|0;c[k+72>>2]=1}if((c[k+68>>2]|0)==0){break}c[k>>2]=a;c[k+4>>2]=o;c[k+8>>2]=p;c[k+20>>2]=m;c[k+24>>2]=n;c[k+60>>2]=l;s=h;c[k+56>>2]=s;c[k+44>>2]=s;s=h>>>(m>>>0);c[k+52>>2]=s;c[k+48>>2]=s;if((wYb(k,0,0,b,d)|0)!=0){break}t=k;u=t;i=j;return u|0}}while(0);xYb(k);t=0;u=t;i=j;return u|0}function vYb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=uYb(a,b,c,d,1,e,f)|0;i=g;return h|0}function wYb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=b;b=d;d=e;e=f;do{if((a+d|0)>>>0<=(c[h+4>>2]|0)>>>0){if(!((b+e|0)>>>0<=(c[h+8>>2]|0)>>>0)){break}c[h+12>>2]=d;c[h+16>>2]=e;if((c[h>>2]&256|0)!=0){f=c[h+68>>2]|0;if((c[h>>2]&1024|0)!=0){c[h+40>>2]=f+a+(ca(b,c[h+56>>2]|0)|0);f=f+(ca(c[h+8>>2]|0,c[h+56>>2]|0)|0)|0}c[h+28>>2]=f+a+(ca(b,c[h+44>>2]|0)|0);f=f+(ca(c[h+8>>2]|0,c[h+44>>2]|0)|0)|0;if((c[h>>2]&512|0)!=0){c[h+36>>2]=f+(a>>>((c[h+20>>2]|0)>>>0))+(ca(b>>>((c[h+24>>2]|0)>>>0),c[h+52>>2]|0)|0);f=f+(ca((c[h+8>>2]|0)>>>((c[h+24>>2]|0)>>>0),c[h+52>>2]|0)|0)|0;c[h+32>>2]=f+(a>>>((c[h+20>>2]|0)>>>0))+(ca(b>>>((c[h+24>>2]|0)>>>0),c[h+48>>2]|0)|0)}else{c[h+32>>2]=f+(a>>>((c[h+20>>2]|0)>>>0))+(ca(b>>>((c[h+24>>2]|0)>>>0),c[h+48>>2]|0)|0);f=f+(ca((c[h+8>>2]|0)>>>((c[h+24>>2]|0)>>>0),c[h+48>>2]|0)|0)|0;c[h+36>>2]=f+(a>>>((c[h+20>>2]|0)>>>0))+(ca(b>>>((c[h+24>>2]|0)>>>0),c[h+52>>2]|0)|0)}}else{f=(c[h+68>>2]|0)+(((ca(a,c[h+60>>2]|0)|0)>>>0)/8|0)|0;c[h+28>>2]=f+(ca(b,c[h+44>>2]|0)|0)}j=0;k=j;i=g;return k|0}}while(0);j=-1;k=j;i=g;return k|0}function xYb(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)==0){i=b;return}do{if((c[d+68>>2]|0)!=0){if((c[d+72>>2]|0)==0){break}yYb(c[d+68>>2]|0)}}while(0);if((c[d+76>>2]|0)!=0){Qqc(d)}i=b;return}function yYb(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)==0){i=b;return}Qqc(c[d-4>>2]|0);i=b;return}function zYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=0;f=Pqc(b+e-1+4|0)|0;if((f|0)==0){g=a;i=d;return g|0}a=f+4+(e-1)&-e;c[a-4>>2]=f;g=a;i=d;return g|0}function AYb(){return c[428276]|0}function BYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=0;f=Pqc(b+e-1+4|0)|0;if((f|0)==0){g=a;i=d;return g|0}a=f+4+(e-1)&-e;c[a-4>>2]=f;g=a;i=d;return g|0}function CYb(a){a=a|0;var b=0,c=0;b=i;c=BYb(8,a)|0;i=b;return c|0}function DYb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;b=BYb(8,ca(d,a)|0)|0;if((b|0)==0){e=b;i=c;return e|0}mrc(b|0,0,ca(d,a)|0)|0;e=b;i=c;return e|0}function EYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=0;f=8;if((e|0)==0){b=CYb(a)|0;g=b;i=d;return g|0}if((a|0)!=0){h=c[e-4>>2]|0;e=0;b=Sqc(h,a+f+4|0)|0;if((b|0)!=0){h=b;b=b+4+(f-1)&-f;c[b-4>>2]=h}}else{FYb(e)}g=b;i=d;return g|0}function FYb(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)==0){i=b;return}Qqc(c[d-4>>2]|0);i=b;return}function GYb(a){a=a|0;var b=0,d=0;b=i;d=a;a=0;while(1){if((a|0)>=4){break}H7b(d+1816+(a*92|0)|0)|0;a=a+1|0}H7b(d+2216|0)|0;FYb(c[d+5796>>2]|0);FYb(c[d+2380>>2]|0);c[d+5796>>2]=0;c[d+2380>>2]=0;i=b;return}function HYb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a;a=b;b=d;GYb(f);if((a&15|0)!=0){a=a+(16-(a&15))|0}if((b&15|0)!=0){b=b+(16-(b&15))|0}d=0;while(1){if((d|0)>=4){g=11;break}c[f+2184+(d<<2)>>2]=0;c[f+1816+(d*92|0)+88>>2]=0;if((J7b(f+1816+(d*92|0)|0,a,b,32)|0)<0){g=8;break}d=d+1|0}do{if((g|0)!=8)if((g|0)==11){c[f+2200>>2]=0;c[f+2204>>2]=1;c[f+2208>>2]=2;c[f+2212>>2]=3;c[f+2184>>2]=1;c[f+2188>>2]=1;c[f+2192>>2]=1;c[f+2196>>2]=1;if((J7b(f+2216|0,a,16,32)|0)<0){break}c[f+2328>>2]=b>>4;c[f+2332>>2]=a>>4;c[f+2324>>2]=ca(c[f+2328>>2]|0,c[f+2332>>2]|0)|0;c[f+2336>>2]=(c[f+2332>>2]|0)+1;c[f+2380>>2]=DYb(ca((c[f+2332>>2]|0)+1|0,(c[f+2328>>2]|0)+1|0)|0,76)|0;if((c[f+2380>>2]|0)==0){break}c[f+2384>>2]=(c[f+2380>>2]|0)+((c[f+2336>>2]|0)*76|0)+76;c[f+5796>>2]=DYb((c[f+2332>>2]|0)*9|0,1)|0;if((c[f+5796>>2]|0)==0){break}h=0;j=h;i=e;return j|0}}while(0);GYb(f);h=1;j=h;i=e;return j|0}function IYb(a){a=a|0;var b=0,d=0;b=i;d=a;a=c[d+8040>>2]|0;if((a|0)==0){c[d+2344>>2]=0;c[d+2392>>2]=0;c[d+2348>>2]=0;c[d+2352>>2]=0;i=b;return}else if((a|0)==1){c[d+2344>>2]=0;c[d+2392>>2]=1;c[d+2348>>2]=1;c[d+2352>>2]=0;i=b;return}else if((a|0)==2){c[d+2344>>2]=1;c[d+2392>>2]=0;c[d+2348>>2]=1;c[d+2352>>2]=0;i=b;return}else if((a|0)==3){c[d+2344>>2]=1;c[d+2392>>2]=1;c[d+2348>>2]=1;c[d+2352>>2]=1;i=b;return}else{c[d+2344>>2]=0;c[d+2392>>2]=0;c[d+2348>>2]=0;c[d+2352>>2]=0;i=b;return}}function JYb(a){a=a|0;var b=0,d=0;b=i;d=a;PYb(d);MYb(d);NYb(d+6922|0);c[d+2340>>2]=1;c[d+2344>>2]=0;c[d+2392>>2]=0;c[d+2348>>2]=0;c[d+2352>>2]=0;c[d+8044>>2]=0;c[d+1808>>2]=0;mrc(d+5780|0,0,16)|0;c[d+5768>>2]=0;c[d+5772>>2]=0;i=b;return}function KYb(a){a=a|0;var b=0;b=i;GYb(a);i=b;return}function LYb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a;a=b;b=(c[e>>2]|0)==0|0;f=(c[a>>2]|0)==0|0;g=(c[e>>2]|0)==(c[a>>2]|0)|0;do{if((g|0)!=0){if((b|0)==0){h=4;break}j=4}else{h=4}}while(0);do{if((h|0)==4){if((g|0)!=0){j=3;break}if((f|0)!=0){j=2;break}if((b|0)!=0){j=1;break}else{j=0;break}}}while(0);i=d;return j|0}function MYb(b){b=b|0;var c=0;c=b;b=c+6931|0;a[b]=a[236136]|0;a[b+1|0]=a[236137]|0;a[b+2|0]=a[236138]|0;a[b+3|0]=a[236139]|0;b=c+6935|0;a[b]=a[236192]|0;a[b+1|0]=a[236193]|0;a[b+2|0]=a[236194]|0;b=c+6938|0;a[b]=a[553024]|0;a[b+1|0]=a[553025]|0;a[b+2|0]=a[553026]|0;i=i;return}function NYb(a){a=a|0;var b=0;b=i;nrc(a|0,246728,9)|0;i=b;return}function OYb(){return}function PYb(a){a=a|0;i=i;return}function QYb(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=0;while(1){if((a|0)>=4){break}e=0;while(1){if((e|0)>=4){break}c[d+2144+(((a<<2)+e|0)*28|0)+8>>2]=d+(a<<2<<4)+(e<<2);e=e+1|0}a=a+1|0}a=0;while(1){if((a|0)>=2){break}e=0;while(1){if((e|0)>=2){break}c[d+2144+(((a<<1)+16+e|0)*28|0)+8>>2]=d+256+(a<<2<<3)+(e<<2);e=e+1|0}a=a+1|0}a=0;while(1){if((a|0)>=2){break}e=0;while(1){if((e|0)>=2){break}c[d+2144+(((a<<1)+20+e|0)*28|0)+8>>2]=d+320+(a<<2<<3)+(e<<2);e=e+1|0}a=a+1|0}a=0;while(1){if((a|0)>=25){break}c[d+2144+(a*28|0)>>2]=d+384+(a<<4<<1);c[d+2144+(a*28|0)+4>>2]=d+1184+(a<<4<<1);c[d+2144+(a*28|0)+20>>2]=d+1984+a;a=a+1|0}i=b;return}function RYb(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=0;while(1){if((a|0)>=16){break}c[d+2144+(a*28|0)+16>>2]=(ca(a>>2<<2,c[d+2956>>2]|0)|0)+((a&3)<<2);a=a+1|0}a=16;while(1){if((a|0)>=20){break}e=(ca(a-16>>1<<2,c[d+2976>>2]|0)|0)+((a&1)<<2)|0;c[d+2144+(a*28|0)+16>>2]=e;c[d+2144+((a+4|0)*28|0)+16>>2]=e;a=a+1|0}i=b;return}function SYb(){U7b();TYb(14);return}function TYb(a){a=a|0;var b=0;b=i;if((c[1366892]|0)!=0){i=b;return}ff[a&15]();c[1366892]=1;i=b;return}function UYb(){return}function VYb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a;a=b;b=d;d=f+3184|0;if((a|0)==1){g=c[d+2204>>2]|0}else{do{if((a|0)==2){g=c[d+2208>>2]|0}else{if((a|0)==4){g=c[d+2212>>2]|0;break}else{WYb(f+3184|0,1,2360456,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=c[f+3184>>2]|0;k=j;i=e;return k|0}}}while(0)}do{if((c[d+1816+(g*92|0)+4>>2]|0)!=(c[b+4>>2]|0)){l=14}else{if((c[d+1816+(g*92|0)>>2]|0)!=(c[b>>2]|0)){l=14;break}if((c[d+1816+(g*92|0)+24>>2]|0)!=(c[b+24>>2]|0)){l=14;break}if((c[d+1816+(g*92|0)+20>>2]|0)!=(c[b+20>>2]|0)){l=14;break}S7b(d+1816+(g*92|0)|0,b)}}while(0);if((l|0)==14){WYb(f+3184|0,1,2567304,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}j=c[f+3184>>2]|0;k=j;i=e;return k|0}function WYb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function XYb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=a;a=b;b=d;d=f+3184|0;g=0;if((a|0)==1){g=d+2204|0}else{do{if((a|0)==2){g=d+2208|0}else{if((a|0)==4){g=d+2212|0;break}else{WYb(f+3184|0,1,2360456,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=c[f+3184>>2]|0;k=j;i=e;return k|0}}}while(0)}do{if((c[d+1816+((c[g>>2]|0)*92|0)+4>>2]|0)!=(c[b+4>>2]|0)){l=14}else{if((c[d+1816+((c[g>>2]|0)*92|0)>>2]|0)!=(c[b>>2]|0)){l=14;break}if((c[d+1816+((c[g>>2]|0)*92|0)+24>>2]|0)!=(c[b+24>>2]|0)){l=14;break}if((c[d+1816+((c[g>>2]|0)*92|0)+20>>2]|0)!=(c[b+20>>2]|0)){l=14;break}a=YYb(d)|0;m=d+2184+(a<<2)|0;c[m>>2]=(c[m>>2]|0)-1;ZYb(d+2184|0,g,a);S7b(b,d+1816+((c[g>>2]|0)*92|0)|0)}}while(0);if((l|0)==14){WYb(f+3184|0,1,2567304,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}j=c[f+3184>>2]|0;k=j;i=e;return k|0}function YYb(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=0;while(1){if((a|0)>=4){break}if((c[d+2184+(a<<2)>>2]|0)==0){e=4;break}a=a+1|0}if((a|0)<4){}else{Cd(2430160,2345208,194,2652496);return 0}c[d+2184+(a<<2)>>2]=1;i=b;return a|0}function ZYb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a;a=b;b=d;if((c[e+(c[a>>2]<<2)>>2]|0)>0){d=e+(c[a>>2]<<2)|0;c[d>>2]=(c[d>>2]|0)-1}c[a>>2]=b;a=e+(b<<2)|0;c[a>>2]=(c[a>>2]|0)+1;i=i;return}function _Yb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a;do{if((c[d+11628>>2]|0)==0){if(!((c[d+11528>>2]|0)>>>0<=1>>>0)){break}if((c[d+11568>>2]|0)!=0){break}a=d+3184|0;if((c[a+2184+(c[a+2204>>2]<<2)>>2]|0)>1){e=c[a+2204>>2]|0;f=a+2184+(e<<2)|0;c[f>>2]=(c[f>>2]|0)-1;c[a+2204>>2]=YYb(a)|0;S7b(a+1816+(e*92|0)|0,a+1816+((c[a+2204>>2]|0)*92|0)|0)}c[a+1816+((c[a+2204>>2]|0)*92|0)+84>>2]=1;c[a+2316>>2]=0;g=0;h=g;i=b;return h|0}}while(0);g=1;h=g;i=b;return h|0}function $Yb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+8|0;b=1;g=0;h=i;i=i+168|0;c[h>>2]=0;while(1)switch(b|0){case 1:j=d|0;k=a;c[j>>2]=e;c[j+4>>2]=f;l=k+3184|0;m=-1;c[k+3184>>2]=0;n=ra(2786,k|0)|0;if((t|0)!=0&(u|0)!=0){g=urc(c[t>>2]|0,h)|0;if((g|0)>0){b=-1;break}else return 0}t=u=0;m=n;if((m|0)<=0){b=2;break}else{b=3;break};case 2:o=m;b=17;break;case 3:n=ra(720,l|0)|0;if((t|0)!=0&(u|0)!=0){g=urc(c[t>>2]|0,h)|0;if((g|0)>0){b=-1;break}else return 0}t=u=0;c[l+2200>>2]=n;c[k+3168>>2]=l+1816+((c[l+2200>>2]|0)*92|0);c[k+3172>>2]=l+1816+((c[l+2204>>2]|0)*92|0);c[k+3176>>2]=l+1816+((c[l+2208>>2]|0)*92|0);c[k+3180>>2]=l+1816+((c[l+2212>>2]|0)*92|0);p=trc(k+3276|0,b,h)|0;b=18;break;case 18:if((p|0)!=0){b=4;break}else{b=7;break};case 4:c[l+1816+((c[l+2204>>2]|0)*92|0)+84>>2]=1;if((c[l+2184+(c[l+2200>>2]<<2)>>2]|0)>0){b=5;break}else{b=6;break};case 5:n=l+2184+(c[l+2200>>2]<<2)|0;c[n>>2]=(c[n>>2]|0)-1;b=6;break;case 6:b=16;break;case 7:c[k+3272>>2]=1;n=ra(2300,k|0)|0;if((t|0)!=0&(u|0)!=0){g=urc(c[t>>2]|0,h)|0;if((g|0)>0){b=-1;break}else return 0}t=u=0;m=n;if((m|0)<0){b=8;break}else{b=11;break};case 8:if((c[l+2184+(c[l+2200>>2]<<2)>>2]|0)>0){b=9;break}else{b=10;break};case 9:n=l+2184+(c[l+2200>>2]<<2)|0;c[n>>2]=(c[n>>2]|0)-1;b=10;break;case 10:c[k+3184>>2]=1;b=16;break;case 11:n=ra(796,l|0)|0;if((t|0)!=0&(u|0)!=0){g=urc(c[t>>2]|0,h)|0;if((g|0)>0){b=-1;break}else return 0}t=u=0;if((n|0)!=0){b=12;break}else{b=13;break};case 12:c[k+3184>>2]=1;b=16;break;case 13:bb(12);if((t|0)!=0&(u|0)!=0){g=urc(c[t>>2]|0,h)|0;if((g|0)>0){b=-1;break}else return 0}t=u=0;if((c[l+2316>>2]|0)!=0){b=14;break}else{b=15;break};case 14:n=l+8036|0;c[n>>2]=(c[n>>2]|0)+1;c[l+2388>>2]=c[l+2384>>2];b=15;break;case 15:c[k+11616>>2]=0;n=c[j+4>>2]|0;q=k+11608|0;c[q>>2]=c[j>>2];c[q+4>>2]=n;b=16;break;case 16:c[k+3272>>2]=0;o=m;b=17;break;case 17:i=d;return o|0;case-1:if((g|0)==3){p=u;b=18}t=u=0;break}return 0}function aZb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a;a=0;if((c[d+5772>>2]|0)!=0){e=0;if((c[d+5772>>2]|0)==1){e=c[d+2204>>2]|0}else{if((c[d+5772>>2]|0)==2){e=c[d+2208>>2]|0}else{a=-1}}ZYb(d+2184|0,d+2212|0,e)}if((c[d+5768>>2]|0)!=0){e=0;if((c[d+5768>>2]|0)==1){e=c[d+2204>>2]|0}else{if((c[d+5768>>2]|0)==2){e=c[d+2212>>2]|0}else{a=-1}}ZYb(d+2184|0,d+2208|0,e)}if((c[d+5760>>2]|0)!=0){ZYb(d+2184|0,d+2208|0,c[d+2200>>2]|0)}if((c[d+5764>>2]|0)!=0){ZYb(d+2184|0,d+2212|0,c[d+2200>>2]|0)}if((c[d+5756>>2]|0)!=0){ZYb(d+2184|0,d+2204|0,c[d+2200>>2]|0);c[d+1812>>2]=d+1816+((c[d+2204>>2]|0)*92|0);f=d;g=f+2200|0;h=c[g>>2]|0;j=d;k=j+2184|0;l=k+(h<<2)|0;m=c[l>>2]|0;n=m-1|0;c[l>>2]=n;o=a;i=b;return o|0}else{c[d+1812>>2]=d+1816+((c[d+2200>>2]|0)*92|0);f=d;g=f+2200|0;h=c[g>>2]|0;j=d;k=j+2184|0;l=k+(h<<2)|0;m=c[l>>2]|0;n=m-1|0;c[l>>2]=n;o=a;i=b;return o|0}return 0}function bZb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=a;a=b;b=-1;if((c[g+11616>>2]|0)==1){h=b;j=h;i=f;return j|0}if((c[g+5500>>2]|0)==0){h=b;j=h;i=f;return j|0}c[g+11616>>2]=1;k=g+11608|0;l=c[k+4>>2]|0;m=d;c[m>>2]=c[k>>2];c[m+4>>2]=l;l=e;c[l>>2]=0;c[l+4>>2]=0;if((c[g+4996>>2]|0)!=0){nrc(a|0,c[g+4996>>2]|0,92)|0;c[a>>2]=c[g+4976>>2];c[a+4>>2]=c[g+4980>>2];c[a+24>>2]=(c[g+4980>>2]|0)/2|0;b=0}else{b=-1}OYb();h=b;j=h;i=f;return j|0}function cZb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a;a=b;b=c[f+2384>>2]|0;g=0;a:while(1){if((g|0)>=(c[f+2328>>2]|0)){h=11;break}j=0;while(1){if((j|0)>=(c[f+2332>>2]|0)){break}if((d[b+2|0]|0|0)==(a|0)){h=6;break a}j=j+1|0;b=b+76|0}b=b+76|0;g=g+1|0}if((h|0)==6){k=1;l=k;i=e;return l|0}else if((h|0)==11){k=0;l=k;i=e;return l|0}return 0}function dZb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;do{if((c[e>>2]|0)==0){c[e+4>>2]=eZb(b)|0;if((c[e+4>>2]|0)!=0){break}f=1;g=f;i=d;return g|0}}while(0);f=0;g=f;i=d;return g|0}function eZb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;b=1;d=0;e=i;i=i+168|0;c[e>>2]=0;while(1)switch(b|0){case 1:f=Sa(110,32,11664)|0;if((t|0)!=0&(u|0)!=0){d=urc(c[t>>2]|0,e)|0;if((d|0)>0){b=-1;break}else return 0}t=u=0;g=f;if((g|0)!=0){b=3;break}else{b=2;break};case 2:h=0;b=6;break;case 3:mrc(g|0,0,11664)|0;j=trc(g+3276|0,b,e)|0;b=7;break;case 7:if((j|0)!=0){b=4;break}else{b=5;break};case 4:c[g+3272>>2]=0;ma(204,g|0);if((t|0)!=0&(u|0)!=0){d=urc(c[t>>2]|0,e)|0;if((d|0)>0){b=-1;break}else return 0}t=u=0;h=0;b=6;break;case 5:c[g+3272>>2]=1;ma(114,g+3184|0);if((t|0)!=0&(u|0)!=0){d=urc(c[t>>2]|0,e)|0;if((d|0)>0){b=-1;break}else return 0}t=u=0;c[g+11220>>2]=0;c[g+11616>>2]=1;ma(32,g|0);if((t|0)!=0&(u|0)!=0){d=urc(c[t>>2]|0,e)|0;if((d|0)>0){b=-1;break}else return 0}t=u=0;ma(332,g+3184|0);if((t|0)!=0&(u|0)!=0){d=urc(c[t>>2]|0,e)|0;if((d|0)>0){b=-1;break}else return 0}t=u=0;c[g+3272>>2]=0;c[g+11624>>2]=0;c[g+11628>>2]=0;c[g+11632>>2]=0;c[g+11636>>2]=0;ma(72,g|0);if((t|0)!=0&(u|0)!=0){d=urc(c[t>>2]|0,e)|0;if((d|0)>0){b=-1;break}else return 0}t=u=0;h=g;b=6;break;case 6:i=a;return h|0;case-1:if((d|0)==3){j=u;b=7}t=u=0;break}return 0}function fZb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;do{if((c[d>>2]|0)==0){a=c[d+4>>2]|0;if((a|0)!=0){gZb(a);break}e=1;f=e;i=b;return f|0}}while(0);e=0;f=e;i=b;return f|0}function gZb(a){a=a|0;var b=0,c=0;b=i;c=a;KYb(c+3184|0);FYb(c);i=b;return}function hZb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a;a=d+142452|0;e=c[d+142360>>2]|0;f=c[d+142356>>2]|0;g=d+105664|0;h=c[a+8>>2]|0;j=0;while(1){if((j|0)>=20){break}c[d+114756+(j<<2)>>2]=0;j=j+1|0}c[d+101440>>2]=0;c[a>>2]=1;c[a+4>>2]=1;c[a+8>>2]=1;c[a+12>>2]=1;c[a+16>>2]=1;c[a+20>>2]=1;c[a+32>>2]=1;c[a+28>>2]=1;c[a+24>>2]=1;c[a+124>>2]=1;c[a+128>>2]=0;c[a+132>>2]=1;c[a+120>>2]=0;c[a+116>>2]=8;c[a+136>>2]=1;j=0;while(1){if((j|0)>=20){break}c[a+36+(j<<2)>>2]=0;j=j+1|0}k=1;if((c[d+142448>>2]&1|0)!=0){k=k+1|0}if((c[d+142448>>2]&2|0)!=0){k=k+1|0}if((c[d+142448>>2]&4|0)!=0){k=k+1|0}if((e|0)==0){f=0}else{if((e|0)==2){f=f+7|0}else{if((f|0)>5){f=5}f=f+1|0}}c[a+40>>2]=0;c[a+48>>2]=0;c[a+44>>2]=0;c[a+36>>2]=0;l=iZb(f,309632)|0;c[a+72>>2]=l;c[a+68>>2]=l;c[a+64>>2]=l;c[a+56>>2]=l;c[a+60>>2]=l;c[a+52>>2]=l;l=iZb(f,309672)|0;c[a+80>>2]=l;c[a+76>>2]=l;c[a+112>>2]=iZb(f,31e4)|0;c[a+84>>2]=iZb(f,309720)|0;c[a+88>>2]=iZb(f,309976)|0;l=iZb(f,309920)|0;c[a+96>>2]=l;c[a+92>>2]=l;c[a+100>>2]=iZb(f,309848)|0;l=iZb(f,309776)|0;c[a+108>>2]=l;c[a+104>>2]=l;c[d+114760>>2]=0;c[d+114804>>2]=0;c[d+114768>>2]=0;c[d+114764>>2]=0;c[d+114756>>2]=0;l=iZb(f,828992)|0;c[d+114784>>2]=l;c[d+114776>>2]=l;c[d+114780>>2]=l;c[d+114772>>2]=l;l=iZb(f,829240)|0;c[d+114792>>2]=l;c[d+114788>>2]=l;l=iZb(f,829024)|0;c[d+114832>>2]=l;c[d+114800>>2]=l;c[d+114796>>2]=l;c[d+114808>>2]=iZb(f,829208)|0;l=iZb(f,829152)|0;c[d+114816>>2]=l;c[d+114812>>2]=l;c[d+114820>>2]=iZb(f,829112)|0;l=iZb(f,829064)|0;c[d+114828>>2]=l;c[d+114824>>2]=l;f=c[d+142356>>2]|0;l=e;if((l|0)==2){c[a+124>>2]=0;c[a+20>>2]=0;c[a+16>>2]=1;c[a+24>>2]=1;c[a+4>>2]=1;if((f|0)>0){c[a+8>>2]=0;c[a+12>>2]=0;c[a+128>>2]=1;c[a+132>>2]=0;c[a+120>>2]=1}if((f|0)>2){c[a+16>>2]=0}if((f|0)>3){c[a>>2]=0;c[a+16>>2]=1}if((f|0)>4){c[a+16>>2]=0;c[a+4>>2]=2;c[a+24>>2]=0}if((f|0)>6){e=0;m=c[g+2324>>2]|0;n=2e3;if((c[d+114252>>2]|0)>2e3){n=c[d+114252>>2]|0}n=n>>7;j=0;while(1){if((j|0)>=(n|0)){break}e=e+(c[d+101544+(j<<2)>>2]|0)|0;j=j+1|0}n=e;e=0;while(1){if((j|0)>=1024){break}e=e+(c[d+101544+(j<<2)>>2]|0)|0;if((e*10|0)>>>0>=(ca((c[d+142356>>2]|0)-6|0,m-n|0)|0)>>>0){o=52;break}j=j+1|0}j=j-1|0;n=j<<7;if((n|0)<2e3){n=2e3}if((k|0)>1){c[a+88>>2]=n;c[a+44>>2]=n>>1;c[a+48>>2]=n>>1}if((k|0)>2){c[a+92>>2]=n<<1;c[a+56>>2]=n;c[a+68>>2]=n}if((k|0)>3){c[a+96>>2]=n<<1;c[a+64>>2]=n;c[a+72>>2]=n}c[a+136>>2]=0}if((f|0)>8){c[a+32>>2]=0}if((c[g+8040>>2]|0)==0){c[g+2392>>2]=0;if((f|0)>=14){c[g+2392>>2]=1}}else{c[g+2392>>2]=1}if((f|0)>=15){c[a+28>>2]=0}mrc(d+101544|0,0,4096)|0}else if((l|0)==1|(l|0)==3){if((f|0)>0){c[a+124>>2]=0;c[a+128>>2]=1;c[a+132>>2]=0;c[a+120>>2]=1}if((f|0)>2){c[a+8>>2]=0;c[a+12>>2]=0;c[a+20>>2]=2}if((f|0)>3){c[a+16>>2]=1;c[a+20>>2]=0;c[a>>2]=0}if((f|0)>4){c[a+16>>2]=0}}else if((l|0)==0){c[a+120>>2]=0;c[a+116>>2]=8}if((c[d+142380>>2]|0)==1){c[a+8>>2]=0;c[a+124>>2]=0;c[a+12>>2]=0}if((c[d+142456>>2]|0)==1){Gdc(d+73728|0,c[g+1816+((c[g+2204>>2]|0)*92|0)+16>>2]|0)}else{if((c[d+142456>>2]|0)==0){Fdc(d+73728|0,c[g+1816+((c[g+2204>>2]|0)*92|0)+16>>2]|0)}}if((c[d+142464>>2]|0)!=0){c[d+105644>>2]=350;c[d+105640>>2]=940}else{c[d+105644>>2]=350;c[d+105640>>2]=940}c[d+105648>>2]=2428;if((c[d+142460>>2]|0)!=0){c[d+105652>>2]=260;c[d+105656>>2]=366}else{c[d+105652>>2]=186;c[d+105656>>2]=822}if((c[d+142460>>2]|0)!=(h|0)){U_b(d)}if((c[d+142476>>2]|0)==1){c[d+142772>>2]=8}else{if((c[d+142484>>2]|0)!=0){c[d+142772>>2]=4}else{if((c[d+142480>>2]|0)!=0){c[d+142772>>2]=6}else{c[d+142772>>2]=2}}}do{if((c[d+142576>>2]|0)==1){if((c[d+142380>>2]|0)==1){o=101;break}c[d+80196>>2]=1}else{o=101}}while(0);if((o|0)==101){c[d+80196>>2]=0}if((c[d+108016>>2]|0)==0){i=b;return}c[d+142772>>2]=2;i=b;return}function iZb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;do{b=a;a=b+4|0;f=c[b>>2]|0;b=a;a=b+4|0;}while((e|0)>=(c[b>>2]|0));i=d;return f|0}function jZb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=d+105664|0;e=c[a+1792>>2]|0;f=c[a+1796>>2]|0;if((HYb(a,e,f)|0)!=0){kZb(d+105664|0,2,2358104,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}if((lZb(d)|0)!=0){kZb(d+105664|0,2,2566424,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}if((e&15|0)!=0){e=e+(16-(e&15))|0}if((f&15|0)!=0){f=f+(16-(f&15))|0}if((J7b(d+114636|0,e,f,32)|0)!=0){kZb(d+105664|0,2,2429792,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}if((J7b(d+114512|0,e,f,32)|0)!=0){kZb(d+105664|0,2,2345024,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}FYb(c[d+114728>>2]|0);c[d+114728>>2]=DYb(((ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0)*24|0)<<4,8)|0;if((c[d+114728>>2]|0)==0){kZb(d+105664|0,2,2284616,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}c[d+142592>>2]=0;FYb(c[d+149724>>2]|0);c[d+149724>>2]=DYb(1,ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0)|0;if((c[d+149724>>2]|0)==0){kZb(d+105664|0,2,2235080,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}c[d+149728>>2]=ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0;FYb(c[d+149720>>2]|0);c[d+149720>>2]=DYb(4,ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0)|0;if((c[d+149720>>2]|0)==0){kZb(d+105664|0,2,2195352,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}FYb(c[d+149736>>2]|0);c[d+149736>>2]=DYb(ca((c[a+2328>>2]|0)+2|0,(c[a+2332>>2]|0)+2|0)|0,4)|0;if((c[d+149736>>2]|0)==0){kZb(d+105664|0,2,2163912,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}FYb(c[d+149740>>2]|0);c[d+149740>>2]=DYb(ca((c[a+2328>>2]|0)+2|0,(c[a+2332>>2]|0)+2|0)|0,4)|0;if((c[d+149740>>2]|0)==0){kZb(d+105664|0,2,2137928,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}FYb(c[d+149744>>2]|0);c[d+149744>>2]=DYb(ca((c[a+2328>>2]|0)+2|0,(c[a+2332>>2]|0)+2|0)|0,4)|0;if((c[d+149744>>2]|0)==0){kZb(d+105664|0,2,2114600,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}FYb(c[d+142600>>2]|0);c[d+142600>>2]=DYb(ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0,1)|0;if((c[d+142600>>2]|0)==0){kZb(d+105664|0,2,2632688,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}c[d+142644>>2]=0;FYb(c[d+142628>>2]|0);c[d+142628>>2]=DYb(ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0,1)|0;if((c[d+142628>>2]|0)==0){kZb(d+105664|0,2,2608816,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}mrc(c[d+142628>>2]|0,1,ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0)|0;FYb(c[d+142660>>2]|0);c[d+142660>>2]=CYb(c[a+2328>>2]<<3)|0;if((c[d+142660>>2]|0)==0){kZb(d+105664|0,2,2582168,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}i=b;return}function kZb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function lZb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;FYb(c[d+80056>>2]|0);c[d+80056>>2]=DYb(ca((c[d+107996>>2]|0)+1|0,(c[d+107992>>2]|0)+1|0)|0,132)|0;if((c[d+80056>>2]|0)!=0){c[d+80052>>2]=(c[d+80056>>2]|0)+((c[d+108e3>>2]|0)*132|0)+132;e=0;f=e;i=b;return f|0}else{e=1;f=e;i=b;return f|0}return 0}function mZb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=0;while(1){if((a|0)>=64){e=7;break}if((c[695984+(a<<2)>>2]|0)>=(d|0)){e=4;break}a=a+1|0}if((e|0)==4){f=a;g=f;i=b;return g|0}else if((e|0)==7){f=63;g=f;i=b;return g|0}return 0}function nZb(a,b){a=a|0;b=+b;var d=0,e=0,f=0.0;d=i;e=a;f=b;if(f<.1){f=30.0}h[e+131672>>3]=f;h[e+131608>>3]=f;c[e+131588>>2]=~~(+((c[e+114076>>2]|0)>>>0>>>0)/+h[e+131608>>3]);c[e+131592>>2]=c[e+131588>>2];c[e+131596>>2]=(ca(c[e+131592>>2]|0,c[e+114216>>2]|0)|0)/100|0;c[e+131548>>2]=~~(+h[e+131608>>3]/2.0)+2;if((c[e+131548>>2]|0)<12){c[e+131548>>2]=12}c[e+147416>>2]=(c[e+114740>>2]|0)>>>1;do{if((c[e+114224>>2]|0)!=0){if((c[e+114112>>2]|0)==0){break}if((c[e+131548>>2]|0)>((c[e+114112>>2]|0)-1|0)){c[e+131548>>2]=(c[e+114112>>2]|0)-1}if((c[e+147416>>2]|0)>((c[e+114112>>2]|0)-1|0)){c[e+147416>>2]=(c[e+114112>>2]|0)-1}}}while(0);if((c[e+131548>>2]|0)<=(c[e+147416>>2]|0)){i=d;return}c[e+131548>>2]=c[e+147416>>2];i=d;return}function oZb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;j=d+24|0;k=a;a=b;b=k+105664|0;if((k|0)==0){i=d;return}if((a|0)==0){i=d;return}if((c[b+8040>>2]|0)!=(c[a>>2]|0)){c[b+8040>>2]=c[a>>2];IYb(b)}l=c[k+114060>>2]|0;m=c[k+114064>>2]|0;n=c[k+114288>>2]|0;nrc(k+114056|0,a|0,432)|0;switch(c[k+114096>>2]|0){case 0:{c[k+142380>>2]=0;c[k+142360>>2]=2;if((c[k+114088>>2]|0)<-16){c[k+114088>>2]=-16}if((c[k+114088>>2]|0)>16){c[k+114088>>2]=16}break};case 4:{c[k+142380>>2]=2;c[k+142360>>2]=1;if((c[k+114088>>2]|0)<-5){c[k+114088>>2]=-5}if((c[k+114088>>2]|0)>5){c[k+114088>>2]=5}break};case 1:{c[k+142380>>2]=0;c[k+142360>>2]=1;if((c[k+114088>>2]|0)<-5){c[k+114088>>2]=-5}if((c[k+114088>>2]|0)>5){c[k+114088>>2]=5}break};case 2:{c[k+142380>>2]=0;c[k+142360>>2]=0;break};case 3:{c[k+142380>>2]=1;c[k+142360>>2]=1;break};case 5:{c[k+142380>>2]=2;c[k+142360>>2]=0;break};default:{}}if((c[k+142380>>2]|0)==0){c[k+142372>>2]=1}c[k+114180>>2]=c[695984+(c[a+124>>2]<<2)>>2];c[k+114184>>2]=c[695984+(c[a+128>>2]<<2)>>2];c[k+114188>>2]=c[695984+(c[k+114188>>2]<<2)>>2];if((c[a+120>>2]|0)>=0){if((c[a+124>>2]|0)<0){c[k+114176>>2]=c[173996]}else{c[k+114176>>2]=c[695984+(c[a+124>>2]<<2)>>2]}if((c[a+176>>2]|0)<0){c[k+114232>>2]=c[173996]}else{c[k+114232>>2]=c[695984+(c[a+176>>2]<<2)>>2]}if((c[a+180>>2]|0)<0){c[k+114236>>2]=c[173996]}else{c[k+114236>>2]=c[695984+(c[a+180>>2]<<2)>>2]}if((c[a+184>>2]|0)<0){c[k+114240>>2]=c[173996]}else{c[k+114240>>2]=c[695984+(c[a+184>>2]<<2)>>2]}}if((c[k+114228>>2]|0)!=0){o=c[k+114228>>2]|0}else{o=7}c[k+131552>>2]=o;c[k+142448>>2]=7;c[b+5760>>2]=0;c[b+5756>>2]=1;c[b+5776>>2]=1;do{if((c[k+114248>>2]|0)>=0){if((c[k+114248>>2]|0)>3){break}c[b+8044>>2]=c[k+114248>>2]}}while(0);pZb(k);o=0;while(1){if((o|0)>=4){break}c[k+142612+(o<<2)>>2]=c[k+114252>>2];o=o+1|0}if((c[k+114176>>2]|0)>127){c[k+114176>>2]=127}if((c[k+114116>>2]|0)==0){o=k+114128|0;c[o>>2]=6e4;c[o+4>>2]=0;o=k+114136|0;c[o>>2]=6e4;c[o+4>>2]=0;o=k+114144|0;c[o>>2]=24e4;c[o+4>>2]=0;o=k+114152|0;c[o>>2]=6e4;c[o+4>>2]=0;o=k+114160|0;c[o>>2]=6e4;c[o+4>>2]=0;o=k+114168|0;c[o>>2]=24e4;c[o+4>>2]=0}o=k+114076|0;c[o>>2]=(c[o>>2]|0)*1e3|0;o=qZb(c[k+114128>>2]|0,c[k+114076>>2]|0,1e3)|0;p=k+114128|0;c[p>>2]=o;c[p+4>>2]=(o|0)<0|0?-1:0;o=k+114136|0;if((c[o>>2]|0)==0&(c[o+4>>2]|0)==0){o=k+114136|0;c[o>>2]=((c[k+114076>>2]|0)>>>0)/8|0;c[o+4>>2]=0}else{o=qZb(c[k+114136>>2]|0,c[k+114076>>2]|0,1e3)|0;p=k+114136|0;c[p>>2]=o;c[p+4>>2]=(o|0)<0|0?-1:0}o=k+114144|0;if((c[o>>2]|0)==0&(c[o+4>>2]|0)==0){o=k+114144|0;c[o>>2]=((c[k+114076>>2]|0)>>>0)/8|0;c[o+4>>2]=0}else{o=qZb(c[k+114144>>2]|0,c[k+114076>>2]|0,1e3)|0;p=k+114144|0;c[p>>2]=o;c[p+4>>2]=(o|0)<0|0?-1:0}o=k+131696|0;p=c[o+4>>2]|0;q=k+114144|0;r=c[q+4>>2]|0;if((p|0)>(r|0)|(p|0)==(r|0)&(c[o>>2]|0)>>>0>(c[q>>2]|0)>>>0){q=k+114144|0;o=c[q+4>>2]|0;r=k+131696|0;c[r>>2]=c[q>>2];c[r+4>>2]=o;o=k+131696|0;r=c[o+4>>2]|0;q=k+131688|0;c[q>>2]=c[o>>2];c[q+4>>2]=r}nZb(k,+h[k+131672>>3]);c[k+131732>>2]=c[k+114180>>2];c[k+131740>>2]=c[k+114184>>2];if((c[k+131736>>2]|0)>(c[k+114180>>2]|0)){c[k+131736>>2]=c[k+114180>>2]}else{if((c[k+131736>>2]|0)<(c[k+114184>>2]|0)){c[k+131736>>2]=c[k+114184>>2]}}if((c[k+131744>>2]|0)<(c[k+114184>>2]|0)){c[k+131744>>2]=c[k+114184>>2]}else{if((c[k+131744>>2]|0)>(c[k+114180>>2]|0)){c[k+131744>>2]=c[k+114180>>2]}}r=k+114136|0;q=c[r+4>>2]|0;o=0;c[k+131664>>2]=((q|0)>(o|0)|(q|0)==(o|0)&(c[r>>2]|0)>>>0>0>>>0)&1;c[k+131748>>2]=c[k+114188>>2];if((c[k+114204>>2]|0)!=0){s=(c[k+131664>>2]|0)!=0}else{s=0}c[k+131752>>2]=s&1;c[k+142332>>2]=c[k+114076>>2];if((c[k+114288>>2]|0)!=(n|0)){c[k+142656>>2]=0;rZb(k,a,n)}c[b+1792>>2]=c[k+114060>>2];c[b+1796>>2]=c[k+114064>>2];if((c[k+114084>>2]|0)>7){c[k+114084>>2]=7}c[b+5752>>2]=c[k+114084>>2];if((c[b+1800>>2]|0)!=0){t=82}else{if((c[b+1804>>2]|0)!=0){t=82}}if((t|0)==82){c[e>>2]=c[e>>2];c[f>>2]=c[f>>2];c[g>>2]=c[g>>2];c[j>>2]=c[j>>2];sZb(c[b+1800>>2]|0,e,f);sZb(c[b+1804>>2]|0,g,j);n=(c[f>>2]|0)-1+(ca(c[k+114060>>2]|0,c[e>>2]|0)|0)|0;c[b+1792>>2]=(n|0)/(c[f>>2]|0)|0;f=(c[j>>2]|0)-1+(ca(c[k+114064>>2]|0,c[g>>2]|0)|0)|0;c[b+1796>>2]=(f|0)/(c[j>>2]|0)|0}if((l|0)!=(c[k+114060>>2]|0)){t=85}else{if((m|0)!=(c[k+114064>>2]|0)){t=85}}if((t|0)==85){c[k+149748>>2]=1}do{if(((c[b+1792>>2]|0)+15&-16|0)!=(c[b+1816+((c[b+2204>>2]|0)*92|0)>>2]|0)){t=89}else{if(((c[b+1796>>2]|0)+15&-16|0)!=(c[b+1816+((c[b+2204>>2]|0)*92|0)+4>>2]|0)){t=89;break}if((c[b+1816+((c[b+2204>>2]|0)*92|0)>>2]|0)==0){t=89}}}while(0);if((t|0)==89){tZb(k);uZb(k);jZb(k)}if((c[k+114176>>2]|0)>=0){c[k+131488>>2]=c[k+114176>>2];c[k+131492>>2]=c[k+114176>>2]}c[k+142356>>2]=c[k+114088>>2];if((c[k+114112>>2]|0)==0){c[k+114108>>2]=0}else{if((c[k+114112>>2]|0)>25){c[k+114112>>2]=25}}c[k+114496>>2]=0;c[k+114620>>2]=0;if((c[k+114080>>2]|0)==0){i=d;return}if((c[k+150192>>2]|0)==0){Fbc(k+149756|0,(c[k+114060>>2]|0)+15&-16,(c[k+114064>>2]|0)+15&-16)|0}i=d;return}function pZb(b){b=b|0;var c=0,d=0;c=i;d=b;if((a[d+79972|0]|0)!=0){a[d+79973|0]=1;a[d+79974|0]=1}else{a[d+79973|0]=0;a[d+79974|0]=0}a[d+79987|0]=0;a[d+79988|0]=0;mrc(d+79993|0,0,4)|0;mrc(d+80001|0,0,4)|0;mrc(d+79989|0,0,4)|0;mrc(d+79997|0,0,4)|0;m_b(d);i=c;return}function qZb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b;c[f>>2]=j;c[f+4>>2]=(j|0)<0|0?-1:0;j=d;c[g>>2]=j;c[g+4>>2]=(j|0)<0|0?-1:0;j=a;c[h>>2]=j;c[h+4>>2]=(j|0)<0|0?-1:0;j=Erc(c[h>>2]|0,c[h+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=Crc(j,G,c[g>>2]|0,c[g+4>>2]|0)|0;i=e;return f|0}function rZb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0.0,j=0,k=0,l=0,m=0,n=0;e=i;f=a;a=b;b=d;g=0.0;d=c[f+114288>>2]|0;if((b|0)==1){c[f+150216>>2]=0;RZb(f)}j=0;while(1){if((j|0)>=(d|0)){break}k=f+150224+(j*200|0)|0;if((j|0)>=(b|0)){l_b(f,a,j,g)}l=f+114152|0;m=Erc(c[l>>2]|0,c[l+4>>2]|0,c[f+114292+(j<<2)>>2]|0,0)|0;l=k+72|0;c[l>>2]=m;c[l+4>>2]=G;l=k+72|0;m=c[l+4>>2]|0;n=k+80|0;c[n>>2]=c[l>>2];c[n+4>>2]=m;if((d|0)==1){c[k+8>>2]=c[f+114076>>2];m=f+114152|0;n=c[k+8>>2]|0;l=Erc(c[m>>2]|0,c[m+4>>2]|0,n,(n|0)<0|0?-1:0)|0;n=Crc(l,G,1e3,0)|0;l=k+72|0;c[l>>2]=n;c[l+4>>2]=G;l=k+72|0;n=c[l+4>>2]|0;m=k+80|0;c[m>>2]=c[l>>2];c[m+4>>2]=n;MZb(f,0)}g=+h[f+131608>>3]/+((c[f+114356+(j<<2)>>2]|0)>>>0>>>0);j=j+1|0}i=e;return}function sZb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=b;b=d;d=a;if((d|0)==3){c[f>>2]=1;c[b>>2]=2;i=e;return}else if((d|0)==1){c[f>>2]=4;c[b>>2]=5;i=e;return}else if((d|0)==0){c[f>>2]=1;c[b>>2]=1;i=e;return}else if((d|0)==2){c[f>>2]=3;c[b>>2]=5;i=e;return}else{c[f>>2]=1;c[b>>2]=1;Cd(2400792,2393808,91,2653504)}}function tZb(a){a=a|0;var b=0,d=0;b=i;d=a;H7b(d+147472|0)|0;xdc(c[d+114488>>2]|0);i=b;return}function uZb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;a=(c[d+114060>>2]|0)+15&-16;e=(c[d+114064>>2]|0)+15&-16;c[d+114488>>2]=ydc(c[d+114060>>2]|0,c[d+114064>>2]|0,c[d+114112>>2]|0)|0;if((c[d+114488>>2]|0)==0){kZb(d+105664|0,2,2417176,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}if((J7b(d+147472|0,a,e,32)|0)==0){i=b;return}kZb(d+105664|0,2,2408240,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=b;return}function vZb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+8|0;d=1;e=0;f=i;i=i+168|0;c[f>>2]=0;while(1)switch(d|0){case 1:g=b|0;j=a;k=Sa(110,32,181008)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[g>>2]=k;if((c[g>>2]|0)!=0){d=3;break}else{d=2;break};case 2:l=0;d=32;break;case 3:m=(c[g>>2]|0)+105664|0;mrc(c[g>>2]|0,0,181008)|0;n=trc(m+92|0,d,f)|0;d=33;break;case 33:if((n|0)!=0){d=4;break}else{d=5;break};case 4:c[(c[g>>2]|0)+105752>>2]=0;ma(404,g|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;l=0;d=32;break;case 5:c[(c[g>>2]|0)+105752>>2]=1;d=6;break;case 6:k=Sa(314,8,65)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[(c[g>>2]|0)+80076>>2]=k;if((c[(c[g>>2]|0)+80076>>2]|0)!=0){d=8;break}else{d=7;break};case 7:hb(416,(c[g>>2]|0)+105664|0,2,2561880,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=o;d=8;break;case 8:d=9;break;case 9:ma(114,(c[g>>2]|0)+105664|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;na(4,c[g>>2]|0,j|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;nrc((c[g>>2]|0)+143e3|0,235616,512)|0;c[(c[g>>2]|0)+113700>>2]=0;c[(c[g>>2]|0)+142656>>2]=0;c[(c[g>>2]|0)+131540>>2]=0;c[(c[g>>2]|0)+131544>>2]=0;c[(c[g>>2]|0)+131524>>2]=0;c[(c[g>>2]|0)+131532>>2]=0;c[(c[g>>2]|0)+131536>>2]=0;c[(c[g>>2]|0)+142388>>2]=128;c[(c[g>>2]|0)+142392>>2]=128;c[(c[g>>2]|0)+142384>>2]=63;c[(c[g>>2]|0)+142424>>2]=1;c[(c[g>>2]|0)+142428>>2]=1;c[(c[g>>2]|0)+142432>>2]=1;c[(c[g>>2]|0)+142436>>2]=1;c[(c[g>>2]|0)+111456>>2]=1;c[(c[g>>2]|0)+147412>>2]=0;c[(c[g>>2]|0)+131552>>2]=7;c[(c[g>>2]|0)+114624>>2]=0;c[(c[g>>2]|0)+114628>>2]=0;c[(c[g>>2]|0)+114632>>2]=0;c[(c[g>>2]|0)+142632>>2]=0;c[(c[g>>2]|0)+142636>>2]=c[(c[g>>2]|0)+114256>>2];k=(ca(c[(c[g>>2]|0)+107992>>2]|0,c[(c[g>>2]|0)+107996>>2]|0)|0)/5|0;c[(c[g>>2]|0)+142640>>2]=k;c[(c[g>>2]|0)+142644>>2]=0;c[(c[g>>2]|0)+142648>>2]=32;if((c[(c[g>>2]|0)+142636>>2]|0)!=0){d=10;break}else{d=15;break};case 10:d=11;break;case 11:k=Sa(314,ca(c[(c[g>>2]|0)+107992>>2]|0,c[(c[g>>2]|0)+107996>>2]|0)|0,1)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[(c[g>>2]|0)+142652>>2]=k;if((c[(c[g>>2]|0)+142652>>2]|0)!=0){d=13;break}else{d=12;break};case 12:hb(416,(c[g>>2]|0)+105664|0,2,2544336,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=o;d=13;break;case 13:d=14;break;case 14:d=16;break;case 15:c[(c[g>>2]|0)+142652>>2]=0;d=16;break;case 16:c[(c[g>>2]|0)+149716>>2]=368640;c[(c[g>>2]|0)+114736>>2]=8;c[(c[g>>2]|0)+114740>>2]=c[(c[g>>2]|0)+114104>>2];c[(c[g>>2]|0)+114744>>2]=0;c[(c[g>>2]|0)+114748>>2]=0;c[(c[g>>2]|0)+114612>>2]=0;c[(c[g>>2]|0)+114616>>2]=0;c[(c[g>>2]|0)+111428>>2]=0;c[(c[g>>2]|0)+149712>>2]=0;k=(c[g>>2]|0)+131632|0;c[k>>2]=2147483647;c[k+4>>2]=0;c[(c[g>>2]|0)+131524>>2]=0;k=(c[g>>2]|0)+131560|0;c[k>>2]=1;c[k+4>>2]=0;c[(c[g>>2]|0)+131640>>2]=c[(c[g>>2]|0)+114180>>2];c[(c[g>>2]|0)+131644>>2]=0;c[(c[g>>2]|0)+131648>>2]=0;k=(c[g>>2]|0)+131656|0;c[k>>2]=0;c[k+4>>2]=0;c[(c[g>>2]|0)+131756>>2]=0;h[(c[g>>2]|0)+131496>>3]=1.0;h[(c[g>>2]|0)+131504>>3]=1.0;h[(c[g>>2]|0)+131512>>3]=1.0;h[(c[g>>2]|0)+147464>>3]=1.0;p=0;d=17;break;case 17:if((p|0)<5){d=18;break}else{d=20;break};case 18:c[(c[g>>2]|0)+131568+(p<<2)>>2]=~~+h[(c[g>>2]|0)+131608>>3];d=19;break;case 19:p=p+1|0;d=17;break;case 20:c[(c[g>>2]|0)+142336>>2]=c[j+224>>2];if((c[(c[g>>2]|0)+142380>>2]|0)==1){d=21;break}else{d=22;break};case 21:ma(222,c[g>>2]|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;d=25;break;case 22:if((c[(c[g>>2]|0)+142380>>2]|0)==2){d=23;break}else{d=24;break};case 23:k=144;q=((c[j+220>>2]|0)>>>0)/(k>>>0)|0;c[(c[g>>2]|0)+147176>>2]=c[j+216>>2];c[(c[g>>2]|0)+147168>>2]=c[(c[g>>2]|0)+147176>>2];r=(c[(c[g>>2]|0)+147168>>2]|0)+(ca(q-1|0,k)|0)|0;c[(c[g>>2]|0)+147172>>2]=r;ma(178,c[g>>2]|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;d=24;break;case 24:d=25;break;case 25:if((c[(c[g>>2]|0)+142360>>2]|0)==2){d=26;break}else{d=27;break};case 26:c[(c[g>>2]|0)+142348>>2]=0;c[(c[g>>2]|0)+142352>>2]=0;d=27;break;case 27:ma(448,c[g>>2]|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;p=0;d=28;break;case 28:if((p|0)<20){d=29;break}else{d=31;break};case 29:c[(c[g>>2]|0)+101280+(p<<2)>>2]=128;d=30;break;case 30:p=p+1|0;d=28;break;case 31:c[(c[g>>2]|0)+142932>>2]=282;c[(c[g>>2]|0)+142936>>2]=210;c[(c[g>>2]|0)+142940>>2]=154;c[(c[g>>2]|0)+142944>>2]=168;c[(c[g>>2]|0)+142948>>2]=218;c[(c[g>>2]|0)+142952>>2]=194;c[(c[g>>2]|0)+142956>>2]=588;c[(c[g>>2]|0)+142960>>2]=206;c[(c[g>>2]|0)+142964>>2]=490;c[(c[g>>2]|0)+142788>>2]=12;c[(c[g>>2]|0)+142792>>2]=70;c[(c[g>>2]|0)+142796>>2]=38;c[(c[g>>2]|0)+142800>>2]=0;c[(c[g>>2]|0)+142804>>2]=0;c[(c[g>>2]|0)+142808>>2]=0;c[(c[g>>2]|0)+142812>>2]=422;c[(c[g>>2]|0)+142816>>2]=58;c[(c[g>>2]|0)+142820>>2]=334;c[(c[g>>2]|0)+142824>>2]=184;c[(c[g>>2]|0)+142828>>2]=140;c[(c[g>>2]|0)+142832>>2]=12;c[(c[g>>2]|0)+142836>>2]=0;c[(c[g>>2]|0)+142840>>2]=0;c[(c[g>>2]|0)+142844>>2]=0;c[(c[g>>2]|0)+142848>>2]=274;c[(c[g>>2]|0)+142852>>2]=26;c[(c[g>>2]|0)+142856>>2]=480;c[(c[g>>2]|0)+142860>>2]=292;c[(c[g>>2]|0)+142864>>2]=38;c[(c[g>>2]|0)+142868>>2]=124;c[(c[g>>2]|0)+142872>>2]=0;c[(c[g>>2]|0)+142876>>2]=0;c[(c[g>>2]|0)+142880>>2]=0;c[(c[g>>2]|0)+142884>>2]=692;c[(c[g>>2]|0)+142888>>2]=256;c[(c[g>>2]|0)+142892>>2]=110;c[(c[g>>2]|0)+142896>>2]=236;c[(c[g>>2]|0)+142900>>2]=92;c[(c[g>>2]|0)+142904>>2]=8;c[(c[g>>2]|0)+142908>>2]=0;c[(c[g>>2]|0)+142912>>2]=0;c[(c[g>>2]|0)+142916>>2]=0;c[(c[g>>2]|0)+142920>>2]=626;c[(c[g>>2]|0)+142924>>2]=102;c[(c[g>>2]|0)+142928>>2]=262;c[(c[g>>2]|0)+142776>>2]=4;c[(c[g>>2]|0)+142784>>2]=2;c[(c[g>>2]|0)+142780>>2]=10;c[(c[g>>2]|0)+101544>>2]=c[(c[g>>2]|0)+107988>>2];ma(444,c[g>>2]|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;ma(332,m|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[(c[g>>2]|0)+105752>>2]=0;c[(c[g>>2]|0)+80124>>2]=(c[g>>2]|0)+155800;c[(c[g>>2]|0)+80128>>2]=(c[g>>2]|0)+163992;c[(c[g>>2]|0)+80132>>2]=(c[g>>2]|0)+169112;c[(c[g>>2]|0)+80136>>2]=(c[g>>2]|0)+171160;ma(74,(c[g>>2]|0)+80132|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[(c[g>>2]|0)+80140>>2]=(c[g>>2]|0)+172184;c[(c[g>>2]|0)+80144>>2]=(c[g>>2]|0)+172264;c[(c[g>>2]|0)+80148>>2]=(c[g>>2]|0)+172344;c[(c[g>>2]|0)+80152>>2]=(c[g>>2]|0)+176344;c[(c[g>>2]|0)+80156>>2]=(c[g>>2]|0)+176400;ma(262,(c[g>>2]|0)+73728|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;ma(72,(c[g>>2]|0)+76880|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;l=c[g>>2]|0;d=32;break;case 32:i=b;return l|0;case-1:if((e|0)==3){n=u;d=33}t=u=0;break}return 0}function wZb(a){a=a|0;var b=0,d=0;b=i;d=a;a=c[d>>2]|0;if((a|0)==0){i=b;return}do{if((a|0)!=0){if(!((c[a+113700>>2]|0)>>>0>0>>>0)){break}if((c[a+142380>>2]|0)==2){_cc(a)}}}while(0);Gbc(a+149756|0);zZb(a);FYb(c[a+80076>>2]|0);FYb(c[a+114728>>2]|0);FYb(c[a+142652>>2]|0);KYb(a+105664|0);FYb(a);c[d>>2]=0;i=b;return}function xZb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0.0;d=i;e=a;a=b;b=e+105664|0;nrc(e+114056|0,a|0,432)|0;c[e+142364>>2]=1;c[e+142368>>2]=1;c[b+8040>>2]=c[a>>2];IYb(b);h[e+131672>>3]=+(c[a+16>>2]|0)/+(c[a+12>>2]|0);if(+h[e+131672>>3]>180.0){h[e+131672>>3]=30.0}h[e+131680>>3]=+h[e+131672>>3];oZb(e,a);c[e+131736>>2]=c[e+114180>>2];c[e+131744>>2]=c[e+114184>>2];c[e+131652>>2]=c[e+114180>>2];b=e+114128|0;f=c[b+4>>2]|0;g=e+131688|0;c[g>>2]=c[b>>2];c[g+4>>2]=f;f=e+114128|0;g=c[f+4>>2]|0;b=e+131696|0;c[b>>2]=c[f>>2];c[b+4>>2]=g;c[e+131704>>2]=c[e+131592>>2];c[e+131708>>2]=c[e+131592>>2];c[e+131712>>2]=c[e+131592>>2];c[e+131716>>2]=c[e+131592>>2];g=e+131720|0;c[g>>2]=0;c[g+4>>2]=0;c[e+131728>>2]=0;if((c[e+114288>>2]|0)>>>0>1>>>0){j=0.0;g=0;while(1){if(!(g>>>0<(c[e+114288>>2]|0)>>>0)){break}l_b(e,a,g,j);j=+h[e+131608>>3]/+((c[e+114356+(g<<2)>>2]|0)>>>0>>>0);g=g+1|0}}c[e+147664>>2]=0;g=1;while(1){if((g|0)>=512){break}c[e+147664+(g<<2)>>2]=524288/(g|0)|0;g=g+1|0}i=d;return}function yZb(a){a=a|0;var b=0,d=0,e=0.0,f=0;b=i;d=a;a=1;c[c[d>>2]>>2]=300;c[c[d+4>>2]>>2]=300;do{e=(+aa(+(a<<3|0))/.6931471824645996+.6)*2.0*256.0;c[(c[d>>2]|0)+(a<<2)>>2]=~~e;c[(c[d+4>>2]|0)+(a<<2)>>2]=~~e;c[(c[d>>2]|0)+(-a<<2)>>2]=~~e;c[(c[d+4>>2]|0)+(-a<<2)>>2]=~~e;f=a+1|0;a=f;}while((f|0)<=255);i=b;return}function zZb(a){a=a|0;var b=0,d=0;b=i;d=a;FYb(c[d+142660>>2]|0);c[d+142660>>2]=0;FYb(c[d+149736>>2]|0);c[d+149736>>2]=0;FYb(c[d+149740>>2]|0);c[d+149740>>2]=0;FYb(c[d+149744>>2]|0);c[d+149744>>2]=0;FYb(c[d+142600>>2]|0);c[d+142600>>2]=0;FYb(c[d+142628>>2]|0);c[d+142628>>2]=0;GYb(d+105664|0);H7b(d+114636|0)|0;H7b(d+114512|0)|0;tZb(d);FYb(c[d+114728>>2]|0);c[d+114728>>2]=0;FYb(c[d+149724>>2]|0);c[d+149724>>2]=0;FYb(c[d+149720>>2]|0);c[d+149720>>2]=0;FYb(c[d+80056>>2]|0);c[d+80056>>2]=0;i=b;return}function AZb(a,b){a=a|0;b=b|0;var d=0,e=0;d=b;if((d|0)>7){e=-1}else{c[a+142448>>2]=d;e=0}i=i;return e|0}function BZb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;if((a|0)>7){f=-1;g=f;i=d;return g|0}c[e+111424>>2]=0;c[e+111428>>2]=0;c[e+111420>>2]=0;if((a&1|0)!=0){c[e+111420>>2]=1}if((a&2|0)!=0){c[e+111424>>2]=1}if((a&4|0)!=0){c[e+111428>>2]=1}f=0;g=f;i=d;return g|0}function CZb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=b;b=d;d=a+105664|0;if((f|0)==1){g=c[d+2204>>2]|0}else{do{if((f|0)==2){g=c[d+2208>>2]|0}else{if((f|0)==4){g=c[d+2212>>2]|0;break}else{h=-1;j=h;i=e;return j|0}}}while(0)}S7b(d+1816+(g*92|0)|0,b);h=0;j=h;i=e;return j|0}function DZb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=b;b=d;d=a+105664|0;if((f|0)==1){g=c[d+2204>>2]|0}else{do{if((f|0)==2){g=c[d+2208>>2]|0}else{if((f|0)==4){g=c[d+2212>>2]|0;break}else{h=-1;j=h;i=e;return j|0}}}while(0)}S7b(b,d+1816+(g*92|0)|0);h=0;j=h;i=e;return j|0}function EZb(a,b){a=a|0;b=b|0;c[a+111440>>2]=b;i=i;return 0}function FZb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+16|0;e=d|0;f=a;a=b;b=c[a+2312>>2]|0;if((c[a+2344>>2]|0)!=0){c[a+5744>>2]=0}else{OYb();GZb(e);if((c[f+142468>>2]|0)==0){H_b(c[f+114504>>2]|0,f)}else{M_b(c[f+114504>>2]|0,f)}if((c[a+5744>>2]|0)>0){L_b(f,c[a+5744>>2]|0)}HZb(e);g=IZb(e)|0;e=f+142984|0;h=wrc(c[e>>2]|0,c[e+4>>2]|0,g,G)|0;c[e>>2]=h;c[e+4>>2]=G}if((c[a+5744>>2]|0)<=0){j=a;k=j+1812|0;l=c[k>>2]|0;N7b(l);i=d;return}m8b(a,f+76880|0,b);j=a;k=j+1812|0;l=c[k>>2]|0;N7b(l);i=d;return}function GZb(a){a=a|0;var b=0;b=i;jd(a|0,0)|0;i=b;return}function HZb(a){a=a|0;var b=0;b=i;jd(a+8|0,0)|0;i=b;return}function IZb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;e=a;c[d>>2]=(c[e+8>>2]|0)-(c[e>>2]|0);a=(c[e+12>>2]|0)-(c[e+4>>2]|0)|0;c[d+4>>2]=a;if((a|0)<0){a=d+4|0;c[a>>2]=(c[a>>2]|0)+1e6;a=d|0;e=c[a>>2]|0;c[a>>2]=e-1;f=(e|0)!=0}else{f=0}f=((c[d>>2]|0)*1e6|0)+(c[d+4>>2]|0)|0;i=b;return(G=(f|0)<0|0?-1:0,f)|0}function JZb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=i;i=i+32|0;k=j|0;l=j+8|0;m=j+16|0;n=a;a=b;b=d;c[k>>2]=e;c[k+4>>2]=f;c[l>>2]=g;c[l+4>>2]=h;h=0;GZb(m);if((c[b>>2]|0)!=(c[n+114060>>2]|0)){o=3}else{if((c[b+4>>2]|0)!=(c[n+114064>>2]|0)){o=3}}if((o|0)==3){if((c[n+114112>>2]|0)<2){}else{Cd(2526744,2511648,4855,2650888);return 0}tZb(n);uZb(n)}if((c[n+142632>>2]|0)!=0){p=c[n+142628>>2]|0}else{p=0}if((zdc(c[n+114488>>2]|0,b,c[k>>2]|0,c[k+4>>2]|0,c[l>>2]|0,c[l+4>>2]|0,a,p)|0)!=0){h=-1}HZb(m);p=IZb(m)|0;m=n+142968|0;n=wrc(c[m>>2]|0,c[m+4>>2]|0,p,G)|0;c[m>>2]=n;c[m+4>>2]=G;i=j;return h|0}function KZb(a,b,d,e,f,g,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0.0,R=0.0,S=0,T=0,U=0,V=0;l=i;i=i+64|0;m=1;n=0;o=i;i=i+168|0;c[o>>2]=0;while(1)switch(m|0){case 1:p=l|0;q=l+16|0;r=l+32|0;s=l+48|0;v=l+56|0;w=a;x=b;y=d;z=e;A=f;B=g;C=j;D=k;E=0;if((w|0)!=0){m=3;break}else{m=2;break};case 2:F=-1;m=111;break;case 3:H=w+105664|0;I=trc(w+105756|0,m,o)|0;m=112;break;case 112:if((I|0)!=0){m=4;break}else{m=5;break};case 4:c[w+105752>>2]=0;F=7;m=111;break;case 5:c[w+105752>>2]=1;ma(454,r|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;c[w+114492>>2]=0;if((c[w+114256>>2]|0)==0){m=6;break}else{m=13;break};case 6:if((c[w+114224>>2]|0)!=0){m=7;break}else{m=13;break};case 7:if((c[w+114612>>2]|0)!=0){m=8;break}else{m=13;break};case 8:J=Aa(46,c[w+114488>>2]|0,c[w+131524>>2]|0,1)|0;if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;c[w+114492>>2]=J;if((J|0)!=0){m=9;break}else{m=12;break};case 9:c[w+114496>>2]=c[w+114492>>2];if((c[w+114260>>2]|0)>0){m=10;break}else{m=11;break};case 10:na(620,w|0,c[w+131524>>2]|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;E=w+147472|0;m=11;break;case 11:c[w+114608>>2]=c[w+131524>>2];c[H+5764>>2]=1;c[H+5760>>2]=0;c[H+5756>>2]=0;c[H+2316>>2]=0;c[w+114612>>2]=0;c[w+114620>>2]=0;m=12;break;case 12:m=13;break;case 13:if((c[w+114492>>2]|0)!=0){m=26;break}else{m=14;break};case 14:if((c[w+142380>>2]|0)==1){m=15;break}else{m=19;break};case 15:if((c[H+8036>>2]|0)>>>0>0>>>0){m=16;break}else{m=19;break};case 16:J=Aa(46,c[w+114488>>2]|0,1,-1|0)|0;if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;c[w+114500>>2]=J;if((J|0)==0){m=17;break}else{m=18;break};case 17:F=-1;m=111;break;case 18:m=19;break;case 19:J=Sa(860,c[w+114488>>2]|0,D|0)|0;if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;c[w+114492>>2]=J;if((J|0)!=0){m=20;break}else{m=25;break};case 20:c[H+2316>>2]=1;if((c[w+114496>>2]|0)!=0){m=21;break}else{K=0;m=22;break};case 21:K=(c[w+114492>>2]|0)==(c[w+114496>>2]|0);m=22;break;case 22:c[w+114620>>2]=K&1;if((c[w+114620>>2]|0)!=0){m=23;break}else{m=24;break};case 23:c[w+114496>>2]=0;m=24;break;case 24:m=25;break;case 25:m=26;break;case 26:if((c[w+114492>>2]|0)!=0){m=27;break}else{m=34;break};case 27:if((E|0)!=0){m=28;break}else{m=29;break};case 28:L=E;m=30;break;case 29:L=c[w+114492>>2]|0;m=30;break;case 30:c[w+114504>>2]=L;c[w+114508>>2]=c[w+114504>>2];J=(c[w+114492>>2]|0)+96|0;M=c[J+4>>2]|0;N=B;c[N>>2]=c[J>>2];c[N+4>>2]=M;M=(c[w+114492>>2]|0)+104|0;N=c[M+4>>2]|0;J=C;c[J>>2]=c[M>>2];c[J+4>>2]=N;c[x>>2]=c[(c[w+114492>>2]|0)+112>>2];if((c[w+142380>>2]|0)==1){m=31;break}else{m=33;break};case 31:if((c[H+8036>>2]|0)>>>0>0>>>0){m=32;break}else{m=33;break};case 32:c[w+114604>>2]=c[w+114500>>2];m=33;break;case 33:m=39;break;case 34:c[y>>2]=0;if((D|0)!=0){m=35;break}else{m=38;break};case 35:if((c[w+142380>>2]|0)==1){m=36;break}else{m=38;break};case 36:if((c[w+147328>>2]|0)!=0){m=38;break}else{m=37;break};case 37:ma(398,w|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;c[w+147328>>2]=1;m=38;break;case 38:F=-1;m=111;break;case 39:N=(c[w+114492>>2]|0)+96|0;J=c[N+4>>2]|0;M=w+131632|0;O=c[M+4>>2]|0;if((J|0)<(O|0)|(J|0)==(O|0)&(c[N>>2]|0)>>>0<(c[M>>2]|0)>>>0){m=40;break}else{m=41;break};case 40:M=(c[w+114492>>2]|0)+96|0;N=c[M+4>>2]|0;O=w+131632|0;c[O>>2]=c[M>>2];c[O+4>>2]=N;N=(c[w+114492>>2]|0)+96|0;O=c[N+4>>2]|0;M=w+131624|0;c[M>>2]=c[N>>2];c[M+4>>2]=O;m=41;break;case 41:if((c[H+2316>>2]|0)!=0){m=42;break}else{m=64;break};case 42:P=0;O=(c[w+114492>>2]|0)+96|0;M=w+131632|0;if((c[O>>2]|0)==(c[M>>2]|0)&(c[O+4>>2]|0)==(c[M+4>>2]|0)){m=43;break}else{m=44;break};case 43:M=(c[w+114492>>2]|0)+104|0;O=(c[w+114492>>2]|0)+96|0;N=xrc(c[M>>2]|0,c[M+4>>2]|0,c[O>>2]|0,c[O+4>>2]|0)|0;c[s>>2]=N;c[s+4>>2]=G;P=1;m=47;break;case 44:N=(c[w+114492>>2]|0)+104|0;O=w+131624|0;M=xrc(c[N>>2]|0,c[N+4>>2]|0,c[O>>2]|0,c[O+4>>2]|0)|0;c[s>>2]=M;c[s+4>>2]=G;M=w+131624|0;O=w+131616|0;N=xrc(c[M>>2]|0,c[M+4>>2]|0,c[O>>2]|0,c[O+4>>2]|0)|0;c[v>>2]=N;c[v+4>>2]=G;if((c[v>>2]|0)!=0|(c[v+4>>2]|0)!=0){m=45;break}else{m=46;break};case 45:N=xrc(c[s>>2]|0,c[s+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;O=Erc(N,G,10,0)|0;N=Crc(O,G,c[v>>2]|0,c[v+4>>2]|0)|0;P=N;m=46;break;case 46:m=47;break;case 47:if((c[s>>2]|0)!=0|(c[s+4>>2]|0)!=0){m=48;break}else{m=63;break};case 48:if((P|0)!=0){m=49;break}else{m=50;break};case 49:h[w+131680>>3]=1.0e7/(+((c[s>>2]|0)>>>0)+ +(c[s+4>>2]|0)*4294967296.0);m=53;break;case 50:N=(c[w+114492>>2]|0)+104|0;O=w+131632|0;M=xrc(c[N>>2]|0,c[N+4>>2]|0,c[O>>2]|0,c[O+4>>2]|0)|0;Q=+(M>>>0)+ +(G|0)*4294967296.0;if(Q>1.0e7){m=51;break}else{m=52;break};case 51:Q=1.0e7;m=52;break;case 52:R=1.0e7/+h[w+131680>>3];R=R*(Q-R+(+((c[s>>2]|0)>>>0)+ +(c[s+4>>2]|0)*4294967296.0));R=R/Q;h[w+131680>>3]=1.0e7/R;m=53;break;case 53:if((c[w+114288>>2]|0)>>>0>1>>>0){m=54;break}else{m=61;break};case 54:if((c[w+114288>>2]|0)>>>0<=5>>>0){m=56;break}else{m=55;break};case 55:hb(736,2497504,2511648,5078,2650936);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;return 0;m=56;break;case 56:S=0;m=57;break;case 57:if(S>>>0<(c[w+114288>>2]|0)>>>0){m=58;break}else{m=60;break};case 58:h[w+150224+(S*200|0)>>3]=+h[w+131680>>3]/+((c[w+114356+(S<<2)>>2]|0)>>>0>>>0);m=59;break;case 59:S=S+1|0;m=57;break;case 60:m=62;break;case 61:ka(2,w|0,+(+h[w+131680>>3]));if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;m=62;break;case 62:m=63;break;case 63:M=(c[w+114492>>2]|0)+96|0;O=c[M+4>>2]|0;N=w+131616|0;c[N>>2]=c[M>>2];c[N+4>>2]=O;O=(c[w+114492>>2]|0)+104|0;N=c[O+4>>2]|0;M=w+131624|0;c[M>>2]=c[O>>2];c[M+4>>2]=N;m=64;break;case 64:if((c[w+114288>>2]|0)>>>0>1>>>0){m=65;break}else{m=66;break};case 65:ma(50,w|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;N=c[w+114424+((((c[w+142656>>2]|0)>>>0)%((c[w+114420>>2]|0)>>>0)|0)<<2)>>2]|0;na(388,w|0,N|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;ka(2,w|0,+(+h[w+150224+(N*200|0)>>3]));if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;m=66;break;case 66:if((c[w+142360>>2]|0)==2){m=67;break}else{m=68;break};case 67:ma(454,p|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;ma(454,q|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;m=68;break;case 68:c[w+142596>>2]=((c[w+142592>>2]|0)*100|0|0)/(c[H+2324>>2]|0)|0;c[y>>2]=0;bb(12);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;c[H+2312>>2]=1;c[H+2320>>2]=c[x>>2];T=0;m=69;break;case 69:if((T|0)<4){m=70;break}else{m=74;break};case 70:if((c[H+1816+(T*92|0)+88>>2]|0)!=0){m=72;break}else{m=71;break};case 71:c[H+2200>>2]=T;m=74;break;case 72:m=73;break;case 73:T=T+1|0;m=69;break;case 74:if((T|0)<4){m=76;break}else{m=75;break};case 75:hb(736,2486200,2511648,5173,2650936);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;return 0;m=76;break;case 76:if((c[w+142380>>2]|0)==1){m=77;break}else{m=78;break};case 77:hb(330,w|0,y|0,z|0,x|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;m=82;break;case 78:if((c[w+142380>>2]|0)==2){m=79;break}else{m=80;break};case 79:la(66,w|0,y|0,z|0,A|0,x|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;m=81;break;case 80:la(354,w|0,y|0,z|0,A|0,x|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;m=81;break;case 81:m=82;break;case 82:if((c[w+142360>>2]|0)==2){m=83;break}else{m=94;break};case 83:ma(194,p|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;ma(194,q|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;N=ra(1262,q|0)|0;if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;U=N;V=~~(+(U>>>0>>>0)/2.0);if((c[H+2312>>2]|0)!=0){m=84;break}else{m=88;break};case 84:if((c[w+142348>>2]|0)==0){m=85;break}else{m=86;break};case 85:c[w+142348>>2]=U;m=87;break;case 86:c[w+142348>>2]=(((c[w+142348>>2]|0)*7|0)+U|0)>>>3;m=87;break;case 87:m=88;break;case 88:if((V|0)!=0){m=89;break}else{m=93;break};case 89:if((c[w+142352>>2]|0)==0){m=90;break}else{m=91;break};case 90:c[w+142352>>2]=V;m=92;break;case 91:c[w+142352>>2]=(((c[w+142352>>2]|0)*7|0)+V|0)>>>3;m=92;break;case 92:m=93;break;case 93:m=94;break;case 94:if((c[H+5776>>2]|0)==0){m=95;break}else{m=96;break};case 95:nrc(H+6922|0,H+5809|0,1113)|0;m=96;break;case 96:if((c[H+5764>>2]|0)!=0){m=97;break}else{m=98;break};case 97:nrc(w+144625|0,H+6922|0,1113)|0;m=98;break;case 98:if((c[H+5760>>2]|0)!=0){m=99;break}else{m=100;break};case 99:nrc(w+145738|0,H+6922|0,1113)|0;m=100;break;case 100:if((c[H+5756>>2]|0)!=0){m=101;break}else{m=102;break};case 101:nrc(w+143512|0,H+6922|0,1113)|0;m=102;break;case 102:if((c[y>>2]|0)>>>0>0>>>0){m=103;break}else{m=104;break};case 103:N=ra(1066,w|0)|0;if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;c[w+149752>>2]=((N|0)!=0^1)&1;c[H+5776>>2]=1;c[H+5764>>2]=0;c[H+5760>>2]=0;c[H+5756>>2]=1;c[H+2312>>2]=1;m=104;break;case 104:if((c[w+114288>>2]|0)>>>0>1>>>0){m=105;break}else{m=106;break};case 105:ma(356,w|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;m=106;break;case 106:ma(194,r|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;N=ra(1262,r|0)|0;if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;M=w+142976|0;O=wrc(c[M>>2]|0,c[M+4>>2]|0,N,G)|0;c[M>>2]=O;c[M+4>>2]=G;if((c[w+149712>>2]|0)!=0){m=107;break}else{m=110;break};case 107:if((c[w+142380>>2]|0)!=1){m=108;break}else{m=110;break};case 108:if((c[H+2316>>2]|0)!=0){m=109;break}else{m=110;break};case 109:ma(246,w|0);if((t|0)!=0&(u|0)!=0){n=urc(c[t>>2]|0,o)|0;if((n|0)>0){m=-1;break}else return 0}t=u=0;m=110;break;case 110:c[w+105752>>2]=0;F=0;m=111;break;case 111:i=l;return F|0;case-1:if((n|0)==3){I=u;m=112}t=u=0;break}return 0}function LZb(a){a=a|0;var b=0,d=0,e=0.0,f=0,g=0,j=0,k=0;b=i;d=a;a=d+114056|0;if(!((c[a+232>>2]|0)>>>0>1>>>0)){i=b;return}e=0.0;if((c[a+232>>2]|0)>>>0<=5>>>0){}else{Cd(2427320,2511648,1404,2651096)}f=0;while(1){if(!(f>>>0<(c[a+232>>2]|0)>>>0)){break}g=d+150224+(f*200|0)|0;h[g>>3]=+h[d+131680>>3]/+((c[a+300+(f<<2)>>2]|0)>>>0>>>0);c[g+8>>2]=(c[a+236+(f<<2)>>2]|0)*1e3|0;j=qZb(c[a+96>>2]|0,c[g+8>>2]|0,1e3)|0;k=g+16|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0;j=a+80|0;if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){j=(c[g+8>>2]|0)/8|0;k=g+24|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0}else{j=qZb(c[a+104>>2]|0,c[g+8>>2]|0,1e3)|0;k=g+24|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0}j=a+88|0;if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){j=(c[g+8>>2]|0)/8|0;k=g+32|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0}else{j=qZb(c[a+112>>2]|0,c[g+8>>2]|0,1e3)|0;k=g+32|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0}if(f>>>0>0>>>0){c[g+64>>2]=~~(+((((c[a+236+(f<<2)>>2]|0)-(c[a+236+(f-1<<2)>>2]|0)|0)*1e3|0)>>>0>>>0)/(+h[g>>3]-e))}e=+h[g>>3];f=f+1|0}i=b;return}function MZb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a;a=b;b=d+150224+(a*200|0)|0;c[d+150216>>2]=a;c[d+142332>>2]=c[b+8>>2];c[d+114076>>2]=c[b+8>>2];a=b+16|0;e=c[a+4>>2]|0;f=d+114128|0;c[f>>2]=c[a>>2];c[f+4>>2]=e;e=b+24|0;f=c[e+4>>2]|0;a=d+114136|0;c[a>>2]=c[e>>2];c[a+4>>2]=f;f=b+32|0;a=c[f+4>>2]|0;e=d+114144|0;c[e>>2]=c[f>>2];c[e+4>>2]=a;a=b+40|0;e=c[a+4>>2]|0;f=d+114152|0;c[f>>2]=c[a>>2];c[f+4>>2]=e;e=b+48|0;f=c[e+4>>2]|0;a=d+114160|0;c[a>>2]=c[e>>2];c[a+4>>2]=f;f=b+56|0;a=c[f+4>>2]|0;e=d+114168|0;c[e>>2]=c[f>>2];c[e+4>>2]=a;a=b+72|0;e=c[a+4>>2]|0;f=d+131688|0;c[f>>2]=c[a>>2];c[f+4>>2]=e;e=b+80|0;f=c[e+4>>2]|0;a=d+131696|0;c[a>>2]=c[e>>2];c[a+4>>2]=f;f=b+88|0;a=c[f+4>>2]|0;e=d+131720|0;c[e>>2]=c[f>>2];c[e+4>>2]=a;c[d+131736>>2]=c[b+104>>2];c[d+131744>>2]=c[b+112>>2];c[d+131640>>2]=c[b+116>>2];c[d+131644>>2]=c[b+120>>2];c[d+131648>>2]=c[b+124>>2];c[d+131652>>2]=c[b+128>>2];h[d+131496>>3]=+h[b+136>>3];h[d+131504>>3]=+h[b+144>>3];h[d+131512>>3]=+h[b+152>>3];c[d+101540>>2]=c[b+160>>2];c[d+131600>>2]=c[b+164>>2];a=b+168|0;e=c[a+4>>2]|0;f=d+131656|0;c[f>>2]=c[a>>2];c[f+4>>2]=e;c[d+111408>>2]=c[b+176>>2];c[d+142444>>2]=c[b+180>>2];e=d+101264|0;d=b+184|0;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];i=i;return}function NZb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=i;c=a;Z_b(c,26);Rcc(c);i=d;return}function OZb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,j=0,k=0.0,l=0.0;g=i;j=a;a=b;if((c[j+111428>>2]|0)==0){$cc(j)}PZb(j,a,d,e,f);f=j+147336|0;e=xrc(c[f>>2]|0,c[f+4>>2]|0,c[a>>2]<<3,0)|0;c[f>>2]=e;c[f+4>>2]=G;if((c[j+111428>>2]|0)!=0){i=g;return}k=+((((ca(c[j+114076>>2]|0,c[j+114216>>2]|0)|0)>>>0)/100|0)>>>0>>>0);l=k/+h[j+131672>>3];f=(F=+l,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);e=j+147336|0;j=wrc(c[e>>2]|0,c[e+4>>2]|0,~~+l>>>0,f)|0;c[e>>2]=j;c[e+4>>2]=G;i=g;return}



function x1a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0,$i=0,aj=0,bj=0,cj=0,dj=0,ej=0,fj=0,gj=0,hj=0,ij=0,jj=0,kj=0,lj=0,mj=0,nj=0,oj=0,pj=0,qj=0,rj=0,sj=0,tj=0,uj=0,vj=0,wj=0,xj=0,yj=0,zj=0,Aj=0,Bj=0,Cj=0,Dj=0,Ej=0,Fj=0,Gj=0,Hj=0,Ij=0,Jj=0,Kj=0,Lj=0,Mj=0,Nj=0,Oj=0,Pj=0,Qj=0,Rj=0,Sj=0;k=i;i=i+304|0;l=k|0;m=k+16|0;n=k+144|0;o=c[f+60>>2]|0;p=o;q=o+8|0;r=q;s=g;TYa(r,c[j+24>>2]|0,c[j+28>>2]|0);UYa(r,214748364,248);j=o+2540|0;c[(c[j>>2]|0)+88>>2]=1;g=o+12|0;t=c[g>>2]|0;u=t>>1;v=t-u|0;c[g>>2]=v;t=q;q=c[t>>2]|0;if((q|0)<(v|0)){if((v|0)<256){c[g>>2]=v<<8;w=q<<8;c[t>>2]=w;x=o+540|0;z=c[x>>2]|0;if(z>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[z]|w}c[x>>2]=z+1}z=o+7348|0;c[z>>2]=0;if((c[o+7352>>2]|0)==0){A=13}else{B=z;A=12}}else{z=q-v|0;c[t>>2]=z;c[g>>2]=u;if((u|0)<256){c[g>>2]=u<<8;u=z<<8;c[t>>2]=u;z=o+540|0;v=c[z>>2]|0;if(v>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[v]|u}c[z>>2]=v+1}v=o+7348|0;c[v>>2]=1;B=v;A=12}a:do{if((A|0)==12){utb(p);c[o+7536>>2]=0;c[o+7512>>2]=0;c[o+7520>>2]=0;c[o+7492>>2]=0;c[o+7360>>2]=0;if((c[B>>2]|0)==0){A=13;break}v=o+3092|0;z=c[g>>2]|0;u=d[v]|0;q=(ca(u,z)|0)>>8;x=z-q|0;c[g>>2]=x;z=c[t>>2]|0;b:do{if((z|0)<(x|0)){a[v]=a[r+16+u|0]|0;if((x|0)<256){w=x<<8;c[g>>2]=w;C=z<<8;c[t>>2]=C;D=o+540|0;E=c[D>>2]|0;if(E>>>0<(c[o+544>>2]|0)>>>0){F=d[E]|C;c[t>>2]=F;G=F}else{G=C}c[D>>2]=E+1;H=w;I=G}else{H=x;I=z}w=o+3093|0;E=a[w]|0;D=(ca(E&255,H)|0)>>8;C=H-D|0;c[g>>2]=C;if((I|0)<(C|0)){J=0;K=w;L=E}else{E=o+540|0;F=o+544|0;M=1;N=w;w=D;D=C;C=I;while(1){c[t>>2]=C-D;a[N]=a[(d[N]|0)+(r+272)|0]|0;c[g>>2]=w;if((w|0)<256){O=w<<8;c[g>>2]=O;P=c[t>>2]<<8;c[t>>2]=P;Q=c[E>>2]|0;if(Q>>>0<(c[F>>2]|0)>>>0){R=d[Q]|P;c[t>>2]=R;S=R}else{S=P}c[E>>2]=Q+1;T=O;U=S}else{T=w;U=c[t>>2]|0}V=o+((M|0)>9?3102:M+3093|0)|0;O=(ca(d[V]|0,T)|0)>>8;Q=T-O|0;c[g>>2]=Q;if((U|0)<(Q|0)){break}else{M=M+1|0;N=V;w=O;D=Q;C=U}}J=M;K=V;L=a[V]|0}a[K]=a[(L&255)+(r+16)|0]|0;C=c[g>>2]|0;if((C|0)<256){D=C<<8;c[g>>2]=D;w=c[t>>2]<<8;c[t>>2]=w;N=o+540|0;E=c[N>>2]|0;if(E>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[E]|w}c[N>>2]=E+1;W=D}else{W=C}do{if((J|0)>0){C=o+540|0;D=o+544|0;E=2;N=J;w=W;while(1){F=N-1|0;Q=o+((F|0)>9?3123:N+3113|0)|0;O=(ca(d[Q]|0,w)|0)>>8;P=w-O|0;c[g>>2]=P;R=c[t>>2]|0;do{if((R|0)<(P|0)){a[Q]=a[(d[Q]|0)+(r+16)|0]|0;X=c[g>>2]|0;if((X|0)>=256){Y=0;Z=X;break}_=X<<8;c[g>>2]=_;X=c[t>>2]<<8;c[t>>2]=X;$=c[C>>2]|0;if($>>>0<(c[D>>2]|0)>>>0){c[t>>2]=d[$]|X}c[C>>2]=$+1;Y=0;Z=_}else{c[t>>2]=R-P;a[Q]=a[(d[Q]|0)+(r+272)|0]|0;c[g>>2]=O;if((O|0)>=256){Y=1;Z=O;break}_=O<<8;c[g>>2]=_;$=c[t>>2]<<8;c[t>>2]=$;X=c[C>>2]|0;if(X>>>0<(c[D>>2]|0)>>>0){c[t>>2]=d[X]|$}c[C>>2]=X+1;Y=1;Z=_}}while(0);aa=Y|E;if((F|0)<=0){break}E=aa<<1;N=F;w=Z}if((aa|0)!=0){ba=aa;break}da=Z;ea=a[v]|0;fa=c[t>>2]|0;break b}else{ba=1}}while(0);KIb(c[o+4>>2]|0,16,2243128,(ga=i,i=i+8|0,c[ga>>2]=ba,ga)|0);i=ga;ha=-1;i=k;return ha|0}else{M=z-x|0;c[t>>2]=M;w=a[r+272+u|0]|0;a[v]=w;c[g>>2]=q;if((q|0)>=256){da=q;ea=w;fa=M;break}N=q<<8;c[g>>2]=N;E=M<<8;c[t>>2]=E;M=o+540|0;C=c[M>>2]|0;if(C>>>0<(c[o+544>>2]|0)>>>0){D=d[C]|E;c[t>>2]=D;ia=D}else{ia=E}c[M>>2]=C+1;da=N;ea=w;fa=ia}}while(0);c[o+7356>>2]=0;q=ea&255;u=(ca(q,da)|0)>>8;x=da-u|0;c[g>>2]=x;do{if((fa|0)<(x|0)){z=a[r+16+q|0]|0;a[v]=z;if((x|0)>=256){ja=0;ka=x;la=z;ma=fa;break}w=x<<8;c[g>>2]=w;N=fa<<8;c[t>>2]=N;C=o+540|0;M=c[C>>2]|0;if(M>>>0<(c[o+544>>2]|0)>>>0){E=d[M]|N;c[t>>2]=E;na=E}else{na=N}c[C>>2]=M+1;ja=0;ka=w;la=z;ma=na}else{z=fa-x|0;c[t>>2]=z;w=a[r+272+q|0]|0;a[v]=w;c[g>>2]=u;if((u|0)>=256){ja=1;ka=u;la=w;ma=z;break}M=u<<8;c[g>>2]=M;C=z<<8;c[t>>2]=C;z=o+540|0;N=c[z>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){E=d[N]|C;c[t>>2]=E;oa=E}else{oa=C}c[z>>2]=N+1;ja=1;ka=M;la=w;ma=oa}}while(0);c[o+7352>>2]=ja;u=la&255;q=(ca(u,ka)|0)>>8;x=ka-q|0;c[g>>2]=x;c:do{if((ma|0)<(x|0)){a[v]=a[r+16+u|0]|0;if((x|0)<256){w=x<<8;c[g>>2]=w;M=ma<<8;c[t>>2]=M;N=o+540|0;z=c[N>>2]|0;if(z>>>0<(c[o+544>>2]|0)>>>0){C=d[z]|M;c[t>>2]=C;pa=C}else{pa=M}c[N>>2]=z+1;qa=w;ra=pa}else{qa=x;ra=ma}w=o+3093|0;z=a[w]|0;N=(ca(z&255,qa)|0)>>8;M=qa-N|0;c[g>>2]=M;if((ra|0)<(M|0)){sa=0;ta=w;ua=z}else{z=o+540|0;C=o+544|0;E=1;D=w;w=N;N=M;M=ra;while(1){c[t>>2]=M-N;a[D]=a[(d[D]|0)+(r+272)|0]|0;c[g>>2]=w;if((w|0)<256){O=w<<8;c[g>>2]=O;Q=c[t>>2]<<8;c[t>>2]=Q;P=c[z>>2]|0;if(P>>>0<(c[C>>2]|0)>>>0){R=d[P]|Q;c[t>>2]=R;va=R}else{va=Q}c[z>>2]=P+1;wa=O;xa=va}else{wa=w;xa=c[t>>2]|0}ya=o+((E|0)>9?3102:E+3093|0)|0;O=(ca(d[ya]|0,wa)|0)>>8;P=wa-O|0;c[g>>2]=P;if((xa|0)<(P|0)){break}else{E=E+1|0;D=ya;w=O;N=P;M=xa}}sa=E;ta=ya;ua=a[ya]|0}a[ta]=a[(ua&255)+(r+16)|0]|0;M=c[g>>2]|0;if((M|0)<256){N=M<<8;c[g>>2]=N;w=c[t>>2]<<8;c[t>>2]=w;D=o+540|0;z=c[D>>2]|0;if(z>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[z]|w}c[D>>2]=z+1;za=N}else{za=M}if((sa|0)<=0){Aa=1;Ba=za;break}M=o+540|0;N=o+544|0;z=2;D=sa;w=za;while(1){C=D-1|0;P=o+((C|0)>9?3123:D+3113|0)|0;O=(ca(d[P]|0,w)|0)>>8;Q=w-O|0;c[g>>2]=Q;R=c[t>>2]|0;do{if((R|0)<(Q|0)){a[P]=a[(d[P]|0)+(r+16)|0]|0;_=c[g>>2]|0;if((_|0)>=256){Ca=0;Da=_;break}X=_<<8;c[g>>2]=X;_=c[t>>2]<<8;c[t>>2]=_;$=c[M>>2]|0;if($>>>0<(c[N>>2]|0)>>>0){c[t>>2]=d[$]|_}c[M>>2]=$+1;Ca=0;Da=X}else{c[t>>2]=R-Q;a[P]=a[(d[P]|0)+(r+272)|0]|0;c[g>>2]=O;if((O|0)>=256){Ca=1;Da=O;break}X=O<<8;c[g>>2]=X;$=c[t>>2]<<8;c[t>>2]=$;_=c[M>>2]|0;if(_>>>0<(c[N>>2]|0)>>>0){c[t>>2]=d[_]|$}c[M>>2]=_+1;Ca=1;Da=X}}while(0);O=Ca|z;if((C|0)<=0){Aa=O;Ba=Da;break c}z=O<<1;D=C;w=Da}}else{w=ma-x|0;c[t>>2]=w;a[v]=a[r+272+u|0]|0;c[g>>2]=q;if((q|0)>=256){Aa=0;Ba=q;break}D=q<<8;c[g>>2]=D;z=w<<8;c[t>>2]=z;w=o+540|0;M=c[w>>2]|0;if(M>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[M]|z}c[w>>2]=M+1;Aa=0;Ba=D}}while(0);c[o+7368>>2]=Aa;q=d[v]|0;u=(ca(q,Ba)|0)>>8;x=Ba-u|0;c[g>>2]=x;D=c[t>>2]|0;d:do{if((D|0)<(x|0)){a[v]=a[r+16+q|0]|0;if((x|0)<256){M=x<<8;c[g>>2]=M;w=D<<8;c[t>>2]=w;z=o+540|0;N=c[z>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){E=d[N]|w;c[t>>2]=E;Ea=E}else{Ea=w}c[z>>2]=N+1;Fa=M;Ga=Ea}else{Fa=x;Ga=D}M=o+3093|0;N=a[M]|0;z=(ca(N&255,Fa)|0)>>8;w=Fa-z|0;c[g>>2]=w;if((Ga|0)<(w|0)){Ha=0;Ia=M;Ja=N}else{N=o+540|0;E=o+544|0;O=1;P=M;M=z;z=w;w=Ga;while(1){c[t>>2]=w-z;a[P]=a[(d[P]|0)+(r+272)|0]|0;c[g>>2]=M;if((M|0)<256){Q=M<<8;c[g>>2]=Q;R=c[t>>2]<<8;c[t>>2]=R;X=c[N>>2]|0;if(X>>>0<(c[E>>2]|0)>>>0){_=d[X]|R;c[t>>2]=_;Ka=_}else{Ka=R}c[N>>2]=X+1;La=Q;Ma=Ka}else{La=M;Ma=c[t>>2]|0}Na=o+((O|0)>9?3102:O+3093|0)|0;Q=(ca(d[Na]|0,La)|0)>>8;X=La-Q|0;c[g>>2]=X;if((Ma|0)<(X|0)){break}else{O=O+1|0;P=Na;M=Q;z=X;w=Ma}}Ha=O;Ia=Na;Ja=a[Na]|0}a[Ia]=a[(Ja&255)+(r+16)|0]|0;w=c[g>>2]|0;if((w|0)<256){z=w<<8;c[g>>2]=z;M=c[t>>2]<<8;c[t>>2]=M;P=o+540|0;N=c[P>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[N]|M}c[P>>2]=N+1;Oa=z}else{Oa=w}if((Ha|0)<=0){Pa=1;Qa=Oa;break}w=o+540|0;z=o+544|0;N=2;P=Ha;M=Oa;while(1){E=P-1|0;X=o+((E|0)>9?3123:P+3113|0)|0;Q=(ca(d[X]|0,M)|0)>>8;R=M-Q|0;c[g>>2]=R;_=c[t>>2]|0;do{if((_|0)<(R|0)){a[X]=a[(d[X]|0)+(r+16)|0]|0;$=c[g>>2]|0;if(($|0)>=256){Ra=0;Sa=$;break}Ta=$<<8;c[g>>2]=Ta;$=c[t>>2]<<8;c[t>>2]=$;Ua=c[w>>2]|0;if(Ua>>>0<(c[z>>2]|0)>>>0){c[t>>2]=d[Ua]|$}c[w>>2]=Ua+1;Ra=0;Sa=Ta}else{c[t>>2]=_-R;a[X]=a[(d[X]|0)+(r+272)|0]|0;c[g>>2]=Q;if((Q|0)>=256){Ra=1;Sa=Q;break}Ta=Q<<8;c[g>>2]=Ta;Ua=c[t>>2]<<8;c[t>>2]=Ua;$=c[w>>2]|0;if($>>>0<(c[z>>2]|0)>>>0){c[t>>2]=d[$]|Ua}c[w>>2]=$+1;Ra=1;Sa=Ta}}while(0);Q=Ra|N;if((E|0)<=0){Pa=Q;Qa=Sa;break d}N=Q<<1;P=E;M=Sa}}else{M=D-x|0;c[t>>2]=M;a[v]=a[r+272+q|0]|0;c[g>>2]=u;if((u|0)>=256){Pa=0;Qa=u;break}P=u<<8;c[g>>2]=P;N=M<<8;c[t>>2]=N;M=o+540|0;w=c[M>>2]|0;if(w>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[w]|N}c[M>>2]=w+1;Pa=0;Qa=P}}while(0);c[o+7380>>2]=Pa;u=d[v]|0;q=(ca(u,Qa)|0)>>8;x=Qa-q|0;c[g>>2]=x;D=c[t>>2]|0;do{if((D|0)<(x|0)){a[v]=a[r+16+u|0]|0;if((x|0)<256){P=x<<8;c[g>>2]=P;w=D<<8;c[t>>2]=w;M=o+540|0;N=c[M>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){z=d[N]|w;c[t>>2]=z;Va=z}else{Va=w}c[M>>2]=N+1;Wa=P;Xa=Va}else{Wa=x;Xa=D}P=o+3093|0;N=a[P]|0;M=(ca(N&255,Wa)|0)>>8;w=Wa-M|0;c[g>>2]=w;if((Xa|0)<(w|0)){Ya=0;Za=P;_a=N}else{N=o+540|0;z=o+544|0;O=1;Q=P;X=M;M=w;w=Xa;while(1){c[t>>2]=w-M;a[Q]=a[(d[Q]|0)+(r+272)|0]|0;c[g>>2]=X;if((X|0)<256){R=X<<8;c[g>>2]=R;_=c[t>>2]<<8;c[t>>2]=_;C=c[N>>2]|0;if(C>>>0<(c[z>>2]|0)>>>0){Ta=d[C]|_;c[t>>2]=Ta;$a=Ta}else{$a=_}c[N>>2]=C+1;ab=R;bb=$a}else{ab=X;bb=c[t>>2]|0}cb=o+((O|0)>9?3102:O+3093|0)|0;R=(ca(d[cb]|0,ab)|0)>>8;C=ab-R|0;c[g>>2]=C;if((bb|0)<(C|0)){break}else{O=O+1|0;Q=cb;X=R;M=C;w=bb}}Ya=O;Za=cb;_a=a[cb]|0}a[Za]=a[(_a&255)+(r+16)|0]|0;w=c[g>>2]|0;if((w|0)<256){M=w<<8;c[g>>2]=M;X=c[t>>2]<<8;c[t>>2]=X;Q=o+540|0;N=c[Q>>2]|0;if(N>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[N]|X}c[Q>>2]=N+1;db=M}else{db=w}if((Ya|0)>0){w=o+540|0;M=o+544|0;N=2;Q=Ya;X=db;while(1){z=Q-1|0;C=o+((z|0)>9?3123:Q+3113|0)|0;R=(ca(d[C]|0,X)|0)>>8;_=X-R|0;c[g>>2]=_;Ta=c[t>>2]|0;do{if((Ta|0)<(_|0)){a[C]=a[(d[C]|0)+(r+16)|0]|0;$=c[g>>2]|0;if(($|0)>=256){eb=0;fb=$;break}Ua=$<<8;c[g>>2]=Ua;$=c[t>>2]<<8;c[t>>2]=$;gb=c[w>>2]|0;if(gb>>>0<(c[M>>2]|0)>>>0){c[t>>2]=d[gb]|$}c[w>>2]=gb+1;eb=0;fb=Ua}else{c[t>>2]=Ta-_;a[C]=a[(d[C]|0)+(r+272)|0]|0;c[g>>2]=R;if((R|0)>=256){eb=1;fb=R;break}Ua=R<<8;c[g>>2]=Ua;gb=c[t>>2]<<8;c[t>>2]=gb;$=c[w>>2]|0;if($>>>0<(c[M>>2]|0)>>>0){c[t>>2]=d[$]|gb}c[w>>2]=$+1;eb=1;fb=Ua}}while(0);hb=eb|N;if((z|0)<=0){break}N=hb<<1;Q=z;X=fb}if((hb-1|0)>>>0<8>>>0){ib=hb;jb=fb}else{kb=hb;break}}else{ib=1;jb=db}X=o+7372|0;c[X>>2]=ib;Q=d[v]|0;N=(ca(Q,jb)|0)>>8;w=jb-N|0;c[g>>2]=w;M=c[t>>2]|0;e:do{if((M|0)<(w|0)){a[v]=a[r+16+Q|0]|0;if((w|0)<256){O=w<<8;c[g>>2]=O;R=M<<8;c[t>>2]=R;C=o+540|0;_=c[C>>2]|0;if(_>>>0<(c[o+544>>2]|0)>>>0){Ta=d[_]|R;c[t>>2]=Ta;lb=Ta}else{lb=R}c[C>>2]=_+1;mb=O;nb=lb}else{mb=w;nb=M}O=a[P]|0;_=(ca(O&255,mb)|0)>>8;C=mb-_|0;c[g>>2]=C;if((nb|0)<(C|0)){ob=0;pb=P;qb=O}else{O=o+540|0;R=o+544|0;Ta=1;E=P;Ua=_;_=C;C=nb;while(1){c[t>>2]=C-_;a[E]=a[(d[E]|0)+(r+272)|0]|0;c[g>>2]=Ua;if((Ua|0)<256){$=Ua<<8;c[g>>2]=$;gb=c[t>>2]<<8;c[t>>2]=gb;rb=c[O>>2]|0;if(rb>>>0<(c[R>>2]|0)>>>0){sb=d[rb]|gb;c[t>>2]=sb;tb=sb}else{tb=gb}c[O>>2]=rb+1;ub=$;vb=tb}else{ub=Ua;vb=c[t>>2]|0}wb=o+((Ta|0)>9?3102:Ta+3093|0)|0;$=(ca(d[wb]|0,ub)|0)>>8;rb=ub-$|0;c[g>>2]=rb;if((vb|0)<(rb|0)){break}else{Ta=Ta+1|0;E=wb;Ua=$;_=rb;C=vb}}ob=Ta;pb=wb;qb=a[wb]|0}a[pb]=a[(qb&255)+(r+16)|0]|0;C=c[g>>2]|0;if((C|0)<256){_=C<<8;c[g>>2]=_;Ua=c[t>>2]<<8;c[t>>2]=Ua;E=o+540|0;O=c[E>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[O]|Ua}c[E>>2]=O+1;xb=_}else{xb=C}do{if((ob|0)>0){C=o+540|0;_=o+544|0;O=2;E=ob;Ua=xb;while(1){R=E-1|0;z=o+((R|0)>9?3123:E+3113|0)|0;rb=(ca(d[z]|0,Ua)|0)>>8;$=Ua-rb|0;c[g>>2]=$;gb=c[t>>2]|0;do{if((gb|0)<($|0)){a[z]=a[(d[z]|0)+(r+16)|0]|0;sb=c[g>>2]|0;if((sb|0)>=256){yb=0;zb=sb;break}Ab=sb<<8;c[g>>2]=Ab;sb=c[t>>2]<<8;c[t>>2]=sb;Bb=c[C>>2]|0;if(Bb>>>0<(c[_>>2]|0)>>>0){c[t>>2]=d[Bb]|sb}c[C>>2]=Bb+1;yb=0;zb=Ab}else{c[t>>2]=gb-$;a[z]=a[(d[z]|0)+(r+272)|0]|0;c[g>>2]=rb;if((rb|0)>=256){yb=1;zb=rb;break}Ab=rb<<8;c[g>>2]=Ab;Bb=c[t>>2]<<8;c[t>>2]=Bb;sb=c[C>>2]|0;if(sb>>>0<(c[_>>2]|0)>>>0){c[t>>2]=d[sb]|Bb}c[C>>2]=sb+1;yb=1;zb=Ab}}while(0);Cb=yb|O;if((R|0)<=0){break}O=Cb<<1;E=R;Ua=zb}c[o+7476>>2]=Cb;if((Cb|0)==1){Db=zb;break}else if((Cb|0)==0){Eb=zb;Fb=a[v]|0;Gb=c[t>>2]|0;A=208;break e}KIb(o,16,2142880,(ga=i,i=i+1|0,i=i+7&-8,c[ga>>2]=0,ga)|0);i=ga;c[o+7484>>2]=1;c[o+7480>>2]=1;c[(c[o+4>>2]|0)+140>>2]=0;ha=-1;i=k;return ha|0}else{c[o+7476>>2]=1;Db=xb}}while(0);c[(c[o+4>>2]|0)+140>>2]=8;c[o+7544>>2]=1;Hb=Db}else{Ta=M-w|0;c[t>>2]=Ta;Ua=a[r+272+Q|0]|0;a[v]=Ua;c[g>>2]=N;if((N|0)<256){E=N<<8;c[g>>2]=E;O=Ta<<8;c[t>>2]=O;C=o+540|0;_=c[C>>2]|0;if(_>>>0<(c[o+544>>2]|0)>>>0){F=d[_]|O;c[t>>2]=F;Ib=F}else{Ib=O}c[C>>2]=_+1;Jb=E;Kb=Ib}else{Jb=N;Kb=Ta}c[o+7476>>2]=0;Eb=Jb;Fb=Ua;Gb=Kb;A=208}}while(0);if((A|0)==208){N=Fb&255;Q=(ca(N,Eb)|0)>>8;w=Eb-Q|0;c[g>>2]=w;f:do{if((Gb|0)<(w|0)){a[v]=a[r+16+N|0]|0;if((w|0)<256){M=w<<8;c[g>>2]=M;Ua=Gb<<8;c[t>>2]=Ua;Ta=o+540|0;E=c[Ta>>2]|0;if(E>>>0<(c[o+544>>2]|0)>>>0){_=d[E]|Ua;c[t>>2]=_;Lb=_}else{Lb=Ua}c[Ta>>2]=E+1;Mb=M;Nb=Lb}else{Mb=w;Nb=Gb}M=a[P]|0;E=(ca(M&255,Mb)|0)>>8;Ta=Mb-E|0;c[g>>2]=Ta;if((Nb|0)<(Ta|0)){Ob=0;Pb=P;Qb=M}else{M=o+540|0;Ua=o+544|0;_=1;C=P;O=E;E=Ta;Ta=Nb;while(1){c[t>>2]=Ta-E;a[C]=a[(d[C]|0)+(r+272)|0]|0;c[g>>2]=O;if((O|0)<256){F=O<<8;c[g>>2]=F;rb=c[t>>2]<<8;c[t>>2]=rb;z=c[M>>2]|0;if(z>>>0<(c[Ua>>2]|0)>>>0){$=d[z]|rb;c[t>>2]=$;Rb=$}else{Rb=rb}c[M>>2]=z+1;Sb=F;Tb=Rb}else{Sb=O;Tb=c[t>>2]|0}Ub=o+((_|0)>9?3102:_+3093|0)|0;F=(ca(d[Ub]|0,Sb)|0)>>8;z=Sb-F|0;c[g>>2]=z;if((Tb|0)<(z|0)){break}else{_=_+1|0;C=Ub;O=F;E=z;Ta=Tb}}Ob=_;Pb=Ub;Qb=a[Ub]|0}a[Pb]=a[(Qb&255)+(r+16)|0]|0;Ta=c[g>>2]|0;if((Ta|0)<256){E=Ta<<8;c[g>>2]=E;O=c[t>>2]<<8;c[t>>2]=O;C=o+540|0;M=c[C>>2]|0;if(M>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[M]|O}c[C>>2]=M+1;Vb=E}else{Vb=Ta}if((Ob|0)<=0){Wb=1;Xb=Vb;break}Ta=o+540|0;E=o+544|0;M=2;C=Ob;O=Vb;while(1){Ua=C-1|0;z=o+((Ua|0)>9?3123:C+3113|0)|0;F=(ca(d[z]|0,O)|0)>>8;rb=O-F|0;c[g>>2]=rb;$=c[t>>2]|0;do{if(($|0)<(rb|0)){a[z]=a[(d[z]|0)+(r+16)|0]|0;gb=c[g>>2]|0;if((gb|0)>=256){Yb=0;Zb=gb;break}Ab=gb<<8;c[g>>2]=Ab;gb=c[t>>2]<<8;c[t>>2]=gb;sb=c[Ta>>2]|0;if(sb>>>0<(c[E>>2]|0)>>>0){c[t>>2]=d[sb]|gb}c[Ta>>2]=sb+1;Yb=0;Zb=Ab}else{c[t>>2]=$-rb;a[z]=a[(d[z]|0)+(r+272)|0]|0;c[g>>2]=F;if((F|0)>=256){Yb=1;Zb=F;break}Ab=F<<8;c[g>>2]=Ab;sb=c[t>>2]<<8;c[t>>2]=sb;gb=c[Ta>>2]|0;if(gb>>>0<(c[E>>2]|0)>>>0){c[t>>2]=d[gb]|sb}c[Ta>>2]=gb+1;Yb=1;Zb=Ab}}while(0);F=Yb|M;if((Ua|0)<=0){Wb=F;Xb=Zb;break f}M=F<<1;C=Ua;O=Zb}}else{O=Gb-w|0;c[t>>2]=O;a[v]=a[r+272+N|0]|0;c[g>>2]=Q;if((Q|0)>=256){Wb=0;Xb=Q;break}C=Q<<8;c[g>>2]=C;M=O<<8;c[t>>2]=M;O=o+540|0;Ta=c[O>>2]|0;if(Ta>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Ta]|M}c[O>>2]=Ta+1;Wb=0;Xb=C}}while(0);Q=o+7480|0;c[Q>>2]=Wb;N=d[v]|0;w=(ca(N,Xb)|0)>>8;C=Xb-w|0;c[g>>2]=C;Ta=c[t>>2]|0;do{if((Ta|0)<(C|0)){a[v]=a[r+16+N|0]|0;if((C|0)<256){O=C<<8;c[g>>2]=O;M=Ta<<8;c[t>>2]=M;E=o+540|0;_=c[E>>2]|0;if(_>>>0<(c[o+544>>2]|0)>>>0){F=d[_]|M;c[t>>2]=F;_b=F}else{_b=M}c[E>>2]=_+1;$b=O;ac=_b}else{$b=C;ac=Ta}O=a[P]|0;_=(ca(O&255,$b)|0)>>8;E=$b-_|0;c[g>>2]=E;if((ac|0)<(E|0)){bc=0;cc=P;dc=O}else{O=o+540|0;M=o+544|0;F=1;z=P;rb=_;_=E;E=ac;while(1){c[t>>2]=E-_;a[z]=a[(d[z]|0)+(r+272)|0]|0;c[g>>2]=rb;if((rb|0)<256){$=rb<<8;c[g>>2]=$;Ab=c[t>>2]<<8;c[t>>2]=Ab;gb=c[O>>2]|0;if(gb>>>0<(c[M>>2]|0)>>>0){sb=d[gb]|Ab;c[t>>2]=sb;ec=sb}else{ec=Ab}c[O>>2]=gb+1;fc=$;gc=ec}else{fc=rb;gc=c[t>>2]|0}hc=o+((F|0)>9?3102:F+3093|0)|0;$=(ca(d[hc]|0,fc)|0)>>8;gb=fc-$|0;c[g>>2]=gb;if((gc|0)<(gb|0)){break}else{F=F+1|0;z=hc;rb=$;_=gb;E=gc}}bc=F;cc=hc;dc=a[hc]|0}a[cc]=a[(dc&255)+(r+16)|0]|0;E=c[g>>2]|0;if((E|0)<256){_=E<<8;c[g>>2]=_;rb=c[t>>2]<<8;c[t>>2]=rb;z=o+540|0;O=c[z>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[O]|rb}c[z>>2]=O+1;ic=_}else{ic=E}g:do{if((bc|0)>0){E=o+540|0;_=o+544|0;O=2;z=bc;rb=ic;while(1){M=z-1|0;gb=o+((M|0)>9?3123:z+3113|0)|0;$=(ca(d[gb]|0,rb)|0)>>8;Ab=rb-$|0;c[g>>2]=Ab;sb=c[t>>2]|0;do{if((sb|0)<(Ab|0)){a[gb]=a[(d[gb]|0)+(r+16)|0]|0;Bb=c[g>>2]|0;if((Bb|0)>=256){jc=0;kc=Bb;break}lc=Bb<<8;c[g>>2]=lc;Bb=c[t>>2]<<8;c[t>>2]=Bb;mc=c[E>>2]|0;if(mc>>>0<(c[_>>2]|0)>>>0){c[t>>2]=d[mc]|Bb}c[E>>2]=mc+1;jc=0;kc=lc}else{c[t>>2]=sb-Ab;a[gb]=a[(d[gb]|0)+(r+272)|0]|0;c[g>>2]=$;if(($|0)>=256){jc=1;kc=$;break}lc=$<<8;c[g>>2]=lc;mc=c[t>>2]<<8;c[t>>2]=mc;Bb=c[E>>2]|0;if(Bb>>>0<(c[_>>2]|0)>>>0){c[t>>2]=d[Bb]|mc}c[E>>2]=Bb+1;jc=1;kc=lc}}while(0);$=jc|O;if((M|0)<=0){nc=$;oc=kc;break g}O=$<<1;z=M;rb=kc}}else{nc=1;oc=ic}}while(0);F=o+7484|0;c[F>>2]=nc;rb=c[Q>>2]|0;if(!((rb|0)==1&(nc|0)==1)){pc=nc;qc=F;rc=rb;sc=oc;A=281;break}c[(c[o+4>>2]|0)+140>>2]=0;tc=oc}else{rb=Ta-C|0;c[t>>2]=rb;a[v]=a[r+272+N|0]|0;c[g>>2]=w;if((w|0)<256){F=w<<8;c[g>>2]=F;z=rb<<8;c[t>>2]=z;rb=o+540|0;O=c[rb>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[O]|z}c[rb>>2]=O+1;uc=F}else{uc=w}F=o+7484|0;c[F>>2]=0;pc=0;qc=F;rc=Wb;sc=uc;A=281}}while(0);do{if((A|0)==281){if((pc|rc|0)==0){c[(c[o+4>>2]|0)+140>>2]=5;tc=sc;break}if((rc|0)==2&(pc|0)==2){c[(c[o+4>>2]|0)+140>>2]=6;tc=sc;break}KIb(o,16,2169960,(ga=i,i=i+16|0,c[ga>>2]=rc,c[ga+8>>2]=pc,ga)|0);i=ga;c[qc>>2]=1;c[Q>>2]=1;c[(c[o+4>>2]|0)+140>>2]=0;ha=-1;i=k;return ha|0}}while(0);c[o+7544>>2]=3;Hb=tc}Q=d[v]|0;w=(ca(Q,Hb)|0)>>8;N=Hb-w|0;c[g>>2]=N;C=c[t>>2]|0;do{if((C|0)<(N|0)){Ta=a[r+16+Q|0]|0;a[v]=Ta;if((N|0)>=256){vc=0;wc=N;xc=Ta;yc=C;break}F=N<<8;c[g>>2]=F;O=C<<8;c[t>>2]=O;rb=o+540|0;z=c[rb>>2]|0;if(z>>>0<(c[o+544>>2]|0)>>>0){E=d[z]|O;c[t>>2]=E;zc=E}else{zc=O}c[rb>>2]=z+1;vc=0;wc=F;xc=Ta;yc=zc}else{Ta=C-N|0;c[t>>2]=Ta;F=a[r+272+Q|0]|0;a[v]=F;c[g>>2]=w;if((w|0)>=256){vc=1;wc=w;xc=F;yc=Ta;break}z=w<<8;c[g>>2]=z;rb=Ta<<8;c[t>>2]=rb;Ta=o+540|0;O=c[Ta>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){E=d[O]|rb;c[t>>2]=E;Ac=E}else{Ac=rb}c[Ta>>2]=O+1;vc=1;wc=z;xc=F;yc=Ac}}while(0);c[o+7488>>2]=vc;w=xc&255;Q=(ca(w,wc)|0)>>8;N=wc-Q|0;c[g>>2]=N;do{if((yc|0)<(N|0)){a[v]=a[r+16+w|0]|0;if((N|0)<256){C=N<<8;c[g>>2]=C;F=yc<<8;c[t>>2]=F;z=o+540|0;O=c[z>>2]|0;if(O>>>0<(c[o+544>>2]|0)>>>0){Ta=d[O]|F;c[t>>2]=Ta;Bc=Ta}else{Bc=F}c[z>>2]=O+1;Cc=C;Dc=Bc}else{Cc=N;Dc=yc}C=a[P]|0;O=(ca(C&255,Cc)|0)>>8;z=Cc-O|0;c[g>>2]=z;if((Dc|0)<(z|0)){Ec=0;Fc=P;Gc=C}else{C=o+540|0;F=o+544|0;Ta=1;rb=P;E=O;O=z;z=Dc;while(1){c[t>>2]=z-O;a[rb]=a[(d[rb]|0)+(r+272)|0]|0;c[g>>2]=E;if((E|0)<256){_=E<<8;c[g>>2]=_;Ua=c[t>>2]<<8;c[t>>2]=Ua;$=c[C>>2]|0;if($>>>0<(c[F>>2]|0)>>>0){gb=d[$]|Ua;c[t>>2]=gb;Hc=gb}else{Hc=Ua}c[C>>2]=$+1;Ic=_;Jc=Hc}else{Ic=E;Jc=c[t>>2]|0}Kc=o+((Ta|0)>9?3102:Ta+3093|0)|0;_=(ca(d[Kc]|0,Ic)|0)>>8;$=Ic-_|0;c[g>>2]=$;if((Jc|0)<($|0)){break}else{Ta=Ta+1|0;rb=Kc;E=_;O=$;z=Jc}}Ec=Ta;Fc=Kc;Gc=a[Kc]|0}a[Fc]=a[(Gc&255)+(r+16)|0]|0;z=c[g>>2]|0;if((z|0)<256){O=z<<8;c[g>>2]=O;E=c[t>>2]<<8;c[t>>2]=E;rb=o+540|0;C=c[rb>>2]|0;if(C>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[C]|E}c[rb>>2]=C+1;Lc=O}else{Lc=z}if((Ec|0)<=0){Mc=2;break}z=o+540|0;O=o+544|0;C=2;rb=Ec;E=Lc;while(1){F=rb-1|0;$=o+((F|0)>9?3123:rb+3113|0)|0;_=(ca(d[$]|0,E)|0)>>8;Ua=E-_|0;c[g>>2]=Ua;gb=c[t>>2]|0;do{if((gb|0)<(Ua|0)){a[$]=a[(d[$]|0)+(r+16)|0]|0;Ab=c[g>>2]|0;if((Ab|0)>=256){Nc=0;Oc=Ab;break}sb=Ab<<8;c[g>>2]=sb;Ab=c[t>>2]<<8;c[t>>2]=Ab;R=c[z>>2]|0;if(R>>>0<(c[O>>2]|0)>>>0){c[t>>2]=d[R]|Ab}c[z>>2]=R+1;Nc=0;Oc=sb}else{c[t>>2]=gb-Ua;a[$]=a[(d[$]|0)+(r+272)|0]|0;c[g>>2]=_;if((_|0)>=256){Nc=1;Oc=_;break}sb=_<<8;c[g>>2]=sb;R=c[t>>2]<<8;c[t>>2]=R;Ab=c[z>>2]|0;if(Ab>>>0<(c[O>>2]|0)>>>0){c[t>>2]=d[Ab]|R}c[z>>2]=Ab+1;Nc=1;Oc=sb}}while(0);Pc=Nc|C;if((F|0)<=0){break}C=Pc<<1;rb=F;E=Oc}if(Pc>>>0<8>>>0){Mc=Pc+1|0;break}KIb(c[o+4>>2]|0,16,2119320,(ga=i,i=i+8|0,c[ga>>2]=Pc,ga)|0);i=ga;ha=-1;i=k;return ha|0}else{E=yc-N|0;c[t>>2]=E;a[v]=a[r+272+w|0]|0;c[g>>2]=Q;if((Q|0)>=256){Mc=1;break}c[g>>2]=Q<<8;rb=E<<8;c[t>>2]=rb;E=o+540|0;C=c[E>>2]|0;if(C>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[C]|rb}c[E>>2]=C+1;Mc=1}}while(0);c[o+7384>>2]=Mc;Q=o+7544|0;w=c[Q>>2]|0;if((w|0)>0){N=o+540|0;C=o+544|0;E=0;rb=c[X>>2]|0;z=w;while(1){h:do{if((rb|0)>0){if((E|0)==2){w=0;while(1){O=(w|0)!=0|0;do{c[p+1073612+(w*66624|0)+(O*16656|0)+16>>2]=c[p+540584+(w*66624|0)+(O*16656|0)+16>>2];O=O+1|0;}while((O|0)<4);O=c[X>>2]|0;M=w+1|0;if((M|0)<(O|0)){w=M}else{Qc=O;Rc=z;break h}}}else{Sc=0}do{w=p+7548+(E*533028|0)+8+(Sc*66624|0)+16672|0;F=p+7548+(E*533028|0)+8+(Sc*66624|0)+33328|0;O=(Sc|0)!=0|0;while(1){if((O|0)==2){c[F>>2]=c[w>>2];O=3;continue}M=c[g>>2]|0;Ta=d[v]|0;_=(ca(Ta,M)|0)>>8;$=M-_|0;c[g>>2]=$;M=c[t>>2]|0;do{if((M|0)<($|0)){a[v]=a[r+16+Ta|0]|0;if(($|0)<256){Ua=$<<8;c[g>>2]=Ua;gb=M<<8;c[t>>2]=gb;sb=c[N>>2]|0;if(sb>>>0<(c[C>>2]|0)>>>0){Ab=d[sb]|gb;c[t>>2]=Ab;Tc=Ab}else{Tc=gb}c[N>>2]=sb+1;Uc=Ua;Vc=Tc}else{Uc=$;Vc=M}Ua=a[P]|0;sb=(ca(Ua&255,Uc)|0)>>8;gb=Uc-sb|0;c[g>>2]=gb;if((Vc|0)<(gb|0)){Wc=0;Xc=P;Yc=Ua}else{Ua=1;Ab=P;R=sb;sb=gb;gb=Vc;while(1){c[t>>2]=gb-sb;a[Ab]=a[(d[Ab]|0)+(r+272)|0]|0;c[g>>2]=R;if((R|0)<256){lc=R<<8;c[g>>2]=lc;Bb=c[t>>2]<<8;c[t>>2]=Bb;mc=c[N>>2]|0;if(mc>>>0<(c[C>>2]|0)>>>0){Zc=d[mc]|Bb;c[t>>2]=Zc;_c=Zc}else{_c=Bb}c[N>>2]=mc+1;$c=lc;ad=_c}else{$c=R;ad=c[t>>2]|0}lc=Ua+1|0;bd=((Ua|0)>9?10:lc)+(p+3092)|0;mc=(ca(d[bd]|0,$c)|0)>>8;Bb=$c-mc|0;c[g>>2]=Bb;if((ad|0)<(Bb|0)){break}else{Ua=lc;Ab=bd;R=mc;sb=Bb;gb=ad}}Wc=Ua;Xc=bd;Yc=a[bd]|0}a[Xc]=a[(Yc&255)+(r+16)|0]|0;gb=c[g>>2]|0;if((gb|0)<256){sb=gb<<8;c[g>>2]=sb;R=c[t>>2]<<8;c[t>>2]=R;Ab=c[N>>2]|0;if(Ab>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[Ab]|R}c[N>>2]=Ab+1;cd=sb}else{cd=gb}i:do{if((Wc|0)>0){gb=2;sb=Wc;Ab=cd;while(1){R=sb-1|0;Bb=((R|0)>9?31:sb+21|0)+(p+3092)|0;mc=(ca(d[Bb]|0,Ab)|0)>>8;lc=Ab-mc|0;c[g>>2]=lc;Zc=c[t>>2]|0;do{if((Zc|0)<(lc|0)){a[Bb]=a[(d[Bb]|0)+(r+16)|0]|0;dd=c[g>>2]|0;if((dd|0)>=256){ed=0;fd=dd;break}gd=dd<<8;c[g>>2]=gd;dd=c[t>>2]<<8;c[t>>2]=dd;hd=c[N>>2]|0;if(hd>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[hd]|dd}c[N>>2]=hd+1;ed=0;fd=gd}else{c[t>>2]=Zc-lc;a[Bb]=a[(d[Bb]|0)+(r+272)|0]|0;c[g>>2]=mc;if((mc|0)>=256){ed=1;fd=mc;break}gd=mc<<8;c[g>>2]=gd;hd=c[t>>2]<<8;c[t>>2]=hd;dd=c[N>>2]|0;if(dd>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[dd]|hd}c[N>>2]=dd+1;ed=1;fd=gd}}while(0);mc=ed|gb;if((R|0)<=0){id=mc;jd=fd;break i}gb=mc<<1;sb=R;Ab=fd}}else{id=1;jd=cd}}while(0);Ua=((Wc|0)>10?21:Wc+11|0)+(p+3092)|0;Ab=(ca(d[Ua]|0,jd)|0)>>8;sb=jd-Ab|0;c[g>>2]=sb;gb=c[t>>2]|0;do{if((gb|0)<(sb|0)){a[Ua]=a[(d[Ua]|0)+(p+24)|0]|0;mc=c[g>>2]|0;if((mc|0)>=256){kd=0;break}c[g>>2]=mc<<8;mc=c[t>>2]<<8;c[t>>2]=mc;Bb=c[N>>2]|0;if(Bb>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[Bb]|mc}c[N>>2]=Bb+1;kd=0}else{c[t>>2]=gb-sb;a[Ua]=a[(d[Ua]|0)+(p+280)|0]|0;c[g>>2]=Ab;if((Ab|0)>=256){kd=1;break}c[g>>2]=Ab<<8;Bb=c[t>>2]<<8;c[t>>2]=Bb;mc=c[N>>2]|0;if(mc>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[mc]|Bb}c[N>>2]=mc+1;kd=1}}while(0);ld=(id^-kd)+kd|0}else{Ab=M-$|0;c[t>>2]=Ab;a[v]=a[r+272+Ta|0]|0;c[g>>2]=_;if((_|0)>=256){ld=0;break}c[g>>2]=_<<8;Ua=Ab<<8;c[t>>2]=Ua;Ab=c[N>>2]|0;if(Ab>>>0<(c[C>>2]|0)>>>0){c[t>>2]=d[Ab]|Ua}c[N>>2]=Ab+1;ld=0}}while(0);c[p+7548+(E*533028|0)+8+(Sc*66624|0)+(O*16656|0)+16>>2]=ld;O=O+1|0;if((O|0)>=4){break}}md=c[X>>2]|0;Sc=Sc+1|0;}while((Sc|0)<(md|0));Qc=md;Rc=c[Q>>2]|0}else{Qc=rb;Rc=z}}while(0);O=E+1|0;if((O|0)<(Rc|0)){E=O;rb=Qc;z=Rc}else{break}}}if((c[B>>2]|0)==0){nd=v;A=393;break a}else{break a}}else{z=D-x|0;c[t>>2]=z;a[v]=a[r+272+u|0]|0;c[g>>2]=q;if((q|0)>=256){kb=0;break}c[g>>2]=q<<8;rb=z<<8;c[t>>2]=rb;z=o+540|0;E=c[z>>2]|0;if(E>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[E]|rb}c[z>>2]=E+1;kb=0}}while(0);KIb(c[o+4>>2]|0,16,2201752,(ga=i,i=i+8|0,c[ga>>2]=kb,ga)|0);i=ga;ha=-1;i=k;return ha|0}}while(0);if((A|0)==13){nd=o+3092|0;A=393}j:do{if((A|0)==393){kb=c[g>>2]|0;r=d[nd]|0;B=(ca(r,kb)|0)>>8;Rc=kb-B|0;c[g>>2]=Rc;kb=c[t>>2]|0;do{if((kb|0)<(Rc|0)){Qc=a[p+24+r|0]|0;a[nd]=Qc;if((Rc|0)>=256){od=Rc;pd=Qc;qd=kb;break}md=Rc<<8;c[g>>2]=md;Sc=kb<<8;c[t>>2]=Sc;ld=o+540|0;kd=c[ld>>2]|0;if(kd>>>0<(c[o+544>>2]|0)>>>0){id=d[kd]|Sc;c[t>>2]=id;rd=id}else{rd=Sc}c[ld>>2]=kd+1;od=md;pd=Qc;qd=rd}else{Qc=kb-Rc|0;c[t>>2]=Qc;md=a[p+280+r|0]|0;a[nd]=md;c[g>>2]=B;if((B|0)<256){kd=B<<8;c[g>>2]=kd;ld=Qc<<8;c[t>>2]=ld;Sc=o+540|0;id=c[Sc>>2]|0;if(id>>>0<(c[o+544>>2]|0)>>>0){jd=d[id]|ld;c[t>>2]=jd;sd=jd}else{sd=ld}c[Sc>>2]=id+1;td=kd;ud=sd}else{td=B;ud=Qc}Qc=o+7544|0;k:do{if((c[Qc>>2]|0)>0){kd=o+540|0;id=o+544|0;Sc=o+3093|0;ld=0;jd=td;Wc=md;cd=ud;while(1){fd=Wc&255;ed=(ca(fd,jd)|0)>>8;Yc=jd-ed|0;c[g>>2]=Yc;do{if((cd|0)<(Yc|0)){a[nd]=a[p+24+fd|0]|0;if((Yc|0)>=256){vd=0;break}c[g>>2]=Yc<<8;Xc=cd<<8;c[t>>2]=Xc;bd=c[kd>>2]|0;if(bd>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[bd]|Xc}c[kd>>2]=bd+1;vd=0}else{bd=cd-Yc|0;c[t>>2]=bd;a[nd]=a[p+280+fd|0]|0;c[g>>2]=ed;if((ed|0)>=256){vd=1;break}c[g>>2]=ed<<8;Xc=bd<<8;c[t>>2]=Xc;bd=c[kd>>2]|0;if(bd>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[bd]|Xc}c[kd>>2]=bd+1;vd=1}}while(0);c[p+7548+(ld*533028|0)+533008>>2]=vd;ed=c[g>>2]|0;fd=d[nd]|0;Yc=(ca(fd,ed)|0)>>8;bd=ed-Yc|0;c[g>>2]=bd;ed=c[t>>2]|0;do{if((ed|0)<(bd|0)){a[nd]=a[p+24+fd|0]|0;if((bd|0)<256){Xc=bd<<8;c[g>>2]=Xc;ad=ed<<8;c[t>>2]=ad;$c=c[kd>>2]|0;if($c>>>0<(c[id>>2]|0)>>>0){_c=d[$c]|ad;c[t>>2]=_c;wd=_c}else{wd=ad}c[kd>>2]=$c+1;xd=Xc;yd=wd}else{xd=bd;yd=ed}Xc=a[Sc]|0;$c=(ca(Xc&255,xd)|0)>>8;ad=xd-$c|0;c[g>>2]=ad;if((yd|0)<(ad|0)){zd=0;Ad=Sc;Bd=Xc}else{Xc=1;_c=Sc;Vc=$c;$c=ad;ad=yd;while(1){c[t>>2]=ad-$c;a[_c]=a[(d[_c]|0)+(p+280)|0]|0;c[g>>2]=Vc;if((Vc|0)<256){Uc=Vc<<8;c[g>>2]=Uc;Tc=c[t>>2]<<8;c[t>>2]=Tc;Mc=c[kd>>2]|0;if(Mc>>>0<(c[id>>2]|0)>>>0){yc=d[Mc]|Tc;c[t>>2]=yc;Cd=yc}else{Cd=Tc}c[kd>>2]=Mc+1;Dd=Uc;Ed=Cd}else{Dd=Vc;Ed=c[t>>2]|0}Uc=Xc+1|0;Fd=((Xc|0)>9?10:Uc)+(p+3092)|0;Mc=(ca(d[Fd]|0,Dd)|0)>>8;Tc=Dd-Mc|0;c[g>>2]=Tc;if((Ed|0)<(Tc|0)){break}else{Xc=Uc;_c=Fd;Vc=Mc;$c=Tc;ad=Ed}}zd=Xc;Ad=Fd;Bd=a[Fd]|0}a[Ad]=a[(Bd&255)+(p+24)|0]|0;ad=c[g>>2]|0;if((ad|0)<256){$c=ad<<8;c[g>>2]=$c;Vc=c[t>>2]<<8;c[t>>2]=Vc;_c=c[kd>>2]|0;if(_c>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[_c]|Vc}c[kd>>2]=_c+1;Gd=$c}else{Gd=ad}if((zd|0)>0){Hd=2;Id=zd;Jd=Gd}else{Kd=4;break}while(1){ad=Id-1|0;$c=((ad|0)>9?31:Id+21|0)+(p+3092)|0;_c=(ca(d[$c]|0,Jd)|0)>>8;Vc=Jd-_c|0;c[g>>2]=Vc;Tc=c[t>>2]|0;do{if((Tc|0)<(Vc|0)){a[$c]=a[(d[$c]|0)+(p+24)|0]|0;Mc=c[g>>2]|0;if((Mc|0)>=256){Ld=0;Md=Mc;break}Uc=Mc<<8;c[g>>2]=Uc;Mc=c[t>>2]<<8;c[t>>2]=Mc;yc=c[kd>>2]|0;if(yc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[yc]|Mc}c[kd>>2]=yc+1;Ld=0;Md=Uc}else{c[t>>2]=Tc-Vc;a[$c]=a[(d[$c]|0)+(p+280)|0]|0;c[g>>2]=_c;if((_c|0)>=256){Ld=1;Md=_c;break}Uc=_c<<8;c[g>>2]=Uc;yc=c[t>>2]<<8;c[t>>2]=yc;Mc=c[kd>>2]|0;if(Mc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[Mc]|yc}c[kd>>2]=Mc+1;Ld=1;Md=Uc}}while(0);Nd=(Ld|Hd)<<1;if((ad|0)>0){Hd=Nd;Id=ad;Jd=Md}else{break}}Kd=Nd+2|0}else{Xc=ed-bd|0;c[t>>2]=Xc;a[nd]=a[p+280+fd|0]|0;c[g>>2]=Yc;if((Yc|0)>=256){Kd=2;break}c[g>>2]=Yc<<8;_c=Xc<<8;c[t>>2]=_c;Xc=c[kd>>2]|0;if(Xc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[Xc]|_c}c[kd>>2]=Xc+1;Kd=2}}while(0);if(Kd>>>0>8>>>0|(Kd|0)==0){ha=-1;break}c[p+7548+(ld*533028|0)+533e3>>2]=Kd;if((Kd|1)>>>0<3>>>0){Od=0}else{Yc=(Kd|0)/2|0;fd=0;while(1){bd=c[g>>2]|0;ed=d[nd]|0;Xc=(ca(ed,bd)|0)>>8;_c=bd-Xc|0;c[g>>2]=_c;bd=c[t>>2]|0;l:do{if((bd|0)<(_c|0)){a[nd]=a[p+24+ed|0]|0;if((_c|0)<256){$c=_c<<8;c[g>>2]=$c;Vc=bd<<8;c[t>>2]=Vc;Tc=c[kd>>2]|0;if(Tc>>>0<(c[id>>2]|0)>>>0){Uc=d[Tc]|Vc;c[t>>2]=Uc;Pd=Uc}else{Pd=Vc}c[kd>>2]=Tc+1;Qd=$c;Rd=Pd}else{Qd=_c;Rd=bd}$c=a[Sc]|0;Tc=(ca($c&255,Qd)|0)>>8;Vc=Qd-Tc|0;c[g>>2]=Vc;if((Rd|0)<(Vc|0)){Sd=0;Td=Sc;Ud=$c}else{$c=1;Uc=Sc;Mc=Tc;Tc=Vc;Vc=Rd;while(1){c[t>>2]=Vc-Tc;a[Uc]=a[(d[Uc]|0)+(p+280)|0]|0;c[g>>2]=Mc;if((Mc|0)<256){yc=Mc<<8;c[g>>2]=yc;Pc=c[t>>2]<<8;c[t>>2]=Pc;Oc=c[kd>>2]|0;if(Oc>>>0<(c[id>>2]|0)>>>0){Nc=d[Oc]|Pc;c[t>>2]=Nc;Vd=Nc}else{Vd=Pc}c[kd>>2]=Oc+1;Wd=yc;Xd=Vd}else{Wd=Mc;Xd=c[t>>2]|0}yc=$c+1|0;Yd=(($c|0)>9?10:yc)+(p+3092)|0;Oc=(ca(d[Yd]|0,Wd)|0)>>8;Pc=Wd-Oc|0;c[g>>2]=Pc;if((Xd|0)<(Pc|0)){break}else{$c=yc;Uc=Yd;Mc=Oc;Tc=Pc;Vc=Xd}}Sd=$c;Td=Yd;Ud=a[Yd]|0}a[Td]=a[(Ud&255)+(p+24)|0]|0;Vc=c[g>>2]|0;if((Vc|0)<256){Tc=Vc<<8;c[g>>2]=Tc;Mc=c[t>>2]<<8;c[t>>2]=Mc;Uc=c[kd>>2]|0;if(Uc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[Uc]|Mc}c[kd>>2]=Uc+1;Zd=Tc}else{Zd=Vc}if((Sd|0)>0){_d=2;$d=Sd;ae=Zd}else{be=1;break}while(1){Vc=$d-1|0;Tc=((Vc|0)>9?31:$d+21|0)+(p+3092)|0;Uc=(ca(d[Tc]|0,ae)|0)>>8;Mc=ae-Uc|0;c[g>>2]=Mc;ad=c[t>>2]|0;do{if((ad|0)<(Mc|0)){a[Tc]=a[(d[Tc]|0)+(p+24)|0]|0;Pc=c[g>>2]|0;if((Pc|0)>=256){ce=0;de=Pc;break}Oc=Pc<<8;c[g>>2]=Oc;Pc=c[t>>2]<<8;c[t>>2]=Pc;yc=c[kd>>2]|0;if(yc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[yc]|Pc}c[kd>>2]=yc+1;ce=0;de=Oc}else{c[t>>2]=ad-Mc;a[Tc]=a[(d[Tc]|0)+(p+280)|0]|0;c[g>>2]=Uc;if((Uc|0)>=256){ce=1;de=Uc;break}Oc=Uc<<8;c[g>>2]=Oc;yc=c[t>>2]<<8;c[t>>2]=yc;Pc=c[kd>>2]|0;if(Pc>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[Pc]|yc}c[kd>>2]=Pc+1;ce=1;de=Oc}}while(0);Uc=ce|_d;if((Vc|0)<=0){be=Uc;break l}_d=Uc<<1;$d=Vc;ae=de}}else{$c=bd-_c|0;c[t>>2]=$c;a[nd]=a[p+280+ed|0]|0;c[g>>2]=Xc;if((Xc|0)>=256){be=0;break}c[g>>2]=Xc<<8;Uc=$c<<8;c[t>>2]=Uc;$c=c[kd>>2]|0;if($c>>>0<(c[id>>2]|0)>>>0){c[t>>2]=d[$c]|Uc}c[kd>>2]=$c+1;be=0}}while(0);Xc=(ca(be,1-(Yc<<1&2)|0)|0)&255;a[p+7548+(ld*533028|0)+533004+Yc|0]=Xc;ed=(Xc<<24>>24)+fd|0;Xc=Yc-1|0;if((Xc|0)==0){Od=ed;break}else{Yc=Xc;fd=ed}}}a[p+7548+(ld*533028|0)+533004|0]=32-Od;fd=ld+1|0;Yc=c[Qc>>2]|0;ed=c[g>>2]|0;Xc=a[nd]|0;_c=c[t>>2]|0;if((fd|0)<(((Yc|0)>2?2:Yc)|0)){ld=fd;jd=ed;Wc=Xc;cd=_c}else{ee=ed;fe=Xc;ge=_c;break k}}i=k;return ha|0}else{ee=td;fe=md;ge=ud}}while(0);c[o+1606612>>2]=c[o+1073584>>2];c[o+1606604>>2]=c[o+1073576>>2];md=o+1073580|0;Qc=o+1606608|0;y=d[md]|d[md+1|0]<<8|d[md+2|0]<<16|d[md+3|0]<<24|0;a[Qc]=y;y=y>>8;a[Qc+1|0]=y;y=y>>8;a[Qc+2|0]=y;y=y>>8;a[Qc+3|0]=y;od=ee;pd=fe;qd=ge}}while(0);B=pd&255;r=(ca(B,od)|0)>>8;Rc=od-r|0;c[g>>2]=Rc;if((qd|0)<(Rc|0)){a[nd]=a[p+24+B|0]|0;if((Rc|0)>=256){break}c[g>>2]=Rc<<8;kb=qd<<8;c[t>>2]=kb;Qc=o+540|0;md=c[Qc>>2]|0;if(md>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[md]|kb}c[Qc>>2]=md+1;break}md=qd-Rc|0;c[t>>2]=md;Rc=a[p+280+B|0]|0;a[nd]=Rc;c[g>>2]=r;if((r|0)<256){B=r<<8;c[g>>2]=B;Qc=md<<8;c[t>>2]=Qc;kb=o+540|0;cd=c[kb>>2]|0;if(cd>>>0<(c[o+544>>2]|0)>>>0){Wc=d[cd]|Qc;c[t>>2]=Wc;he=Wc}else{he=Qc}c[kb>>2]=cd+1;ie=B;je=he}else{ie=r;je=md}md=Rc&255;Rc=(ca(ie,md)|0)>>8;r=ie-Rc|0;c[g>>2]=r;do{if((je|0)<(r|0)){a[nd]=a[p+24+md|0]|0;if((r|0)<256){B=r<<8;c[g>>2]=B;cd=je<<8;c[t>>2]=cd;kb=o+540|0;Qc=c[kb>>2]|0;if(Qc>>>0<(c[o+544>>2]|0)>>>0){Wc=d[Qc]|cd;c[t>>2]=Wc;ke=Wc}else{ke=cd}c[kb>>2]=Qc+1;le=B;me=ke}else{le=r;me=je}B=o+3093|0;Qc=a[B]|0;kb=(ca(Qc&255,le)|0)>>8;cd=le-kb|0;c[g>>2]=cd;if((me|0)<(cd|0)){ne=0;oe=B;pe=Qc}else{Qc=o+540|0;Wc=o+544|0;jd=1;ld=B;kd=kb;kb=cd;cd=me;while(1){c[t>>2]=cd-kb;a[ld]=a[(d[ld]|0)+(p+280)|0]|0;c[g>>2]=kd;if((kd|0)<256){id=kd<<8;c[g>>2]=id;Sc=c[t>>2]<<8;c[t>>2]=Sc;_c=c[Qc>>2]|0;if(_c>>>0<(c[Wc>>2]|0)>>>0){Xc=d[_c]|Sc;c[t>>2]=Xc;qe=Xc}else{qe=Sc}c[Qc>>2]=_c+1;re=id;se=qe}else{re=kd;se=c[t>>2]|0}id=jd+1|0;te=((jd|0)>9?10:id)+(p+3092)|0;_c=(ca(d[te]|0,re)|0)>>8;Sc=re-_c|0;c[g>>2]=Sc;if((se|0)<(Sc|0)){break}else{jd=id;ld=te;kd=_c;kb=Sc;cd=se}}ne=jd;oe=te;pe=a[te]|0}a[oe]=a[(pe&255)+(p+24)|0]|0;cd=c[g>>2]|0;if((cd|0)<256){kb=cd<<8;c[g>>2]=kb;kd=c[t>>2]<<8;c[t>>2]=kd;ld=o+540|0;Qc=c[ld>>2]|0;if(Qc>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Qc]|kd}c[ld>>2]=Qc+1;ue=kb}else{ue=cd}if((ne|0)>0){cd=o+540|0;kb=o+544|0;Qc=2;ld=ne;kd=ue;while(1){Wc=ld-1|0;Sc=((Wc|0)>9?31:ld+21|0)+(p+3092)|0;_c=(ca(d[Sc]|0,kd)|0)>>8;id=kd-_c|0;c[g>>2]=id;Xc=c[t>>2]|0;do{if((Xc|0)<(id|0)){a[Sc]=a[(d[Sc]|0)+(p+24)|0]|0;ed=c[g>>2]|0;if((ed|0)>=256){ve=0;xe=ed;break}fd=ed<<8;c[g>>2]=fd;ed=c[t>>2]<<8;c[t>>2]=ed;Yc=c[cd>>2]|0;if(Yc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Yc]|ed}c[cd>>2]=Yc+1;ve=0;xe=fd}else{c[t>>2]=Xc-id;a[Sc]=a[(d[Sc]|0)+(p+280)|0]|0;c[g>>2]=_c;if((_c|0)>=256){ve=1;xe=_c;break}fd=_c<<8;c[g>>2]=fd;Yc=c[t>>2]<<8;c[t>>2]=Yc;ed=c[cd>>2]|0;if(ed>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[ed]|Yc}c[cd>>2]=ed+1;ve=1;xe=fd}}while(0);ye=ve|Qc;if((Wc|0)<=0){break}Qc=ye<<1;ld=Wc;kd=xe}if((ye-1|0)>>>0<8>>>0){ze=ye}else{Ae=ye;break}}else{ze=1}kd=o+7372|0;c[kd>>2]=ze;ld=o+7544|0;Qc=c[ld>>2]|0;if((Qc|0)<=0){break j}cd=o+540|0;kb=o+544|0;jd=0;_c=ze;Sc=Qc;while(1){m:do{if((_c|0)>0){if((jd|0)==2){Qc=0;while(1){id=(Qc|0)!=0|0;do{c[p+1073612+(Qc*66624|0)+(id*16656|0)+16>>2]=c[p+540584+(Qc*66624|0)+(id*16656|0)+16>>2];id=id+1|0;}while((id|0)<4);id=c[kd>>2]|0;Xc=Qc+1|0;if((Xc|0)<(id|0)){Qc=Xc}else{Be=id;Ce=Sc;break m}}}else{De=0}do{Qc=p+7548+(jd*533028|0)+8+(De*66624|0)+16672|0;id=p+7548+(jd*533028|0)+8+(De*66624|0)+33328|0;Xc=(De|0)!=0|0;while(1){if((Xc|0)==2){c[id>>2]=c[Qc>>2];Xc=3;continue}fd=c[g>>2]|0;ed=d[nd]|0;Yc=(ca(ed,fd)|0)>>8;bd=fd-Yc|0;c[g>>2]=bd;fd=c[t>>2]|0;do{if((fd|0)<(bd|0)){a[nd]=a[p+24+ed|0]|0;if((bd|0)<256){$c=bd<<8;c[g>>2]=$c;Uc=fd<<8;c[t>>2]=Uc;Tc=c[cd>>2]|0;if(Tc>>>0<(c[kb>>2]|0)>>>0){Mc=d[Tc]|Uc;c[t>>2]=Mc;Ee=Mc}else{Ee=Uc}c[cd>>2]=Tc+1;Fe=$c;Ge=Ee}else{Fe=bd;Ge=fd}$c=a[B]|0;Tc=(ca($c&255,Fe)|0)>>8;Uc=Fe-Tc|0;c[g>>2]=Uc;if((Ge|0)<(Uc|0)){He=0;Ie=B;Je=$c}else{$c=1;Mc=B;ad=Tc;Tc=Uc;Uc=Ge;while(1){c[t>>2]=Uc-Tc;a[Mc]=a[(d[Mc]|0)+(p+280)|0]|0;c[g>>2]=ad;if((ad|0)<256){Oc=ad<<8;c[g>>2]=Oc;Pc=c[t>>2]<<8;c[t>>2]=Pc;yc=c[cd>>2]|0;if(yc>>>0<(c[kb>>2]|0)>>>0){Nc=d[yc]|Pc;c[t>>2]=Nc;Ke=Nc}else{Ke=Pc}c[cd>>2]=yc+1;Le=Oc;Me=Ke}else{Le=ad;Me=c[t>>2]|0}Oc=$c+1|0;Ne=(($c|0)>9?10:Oc)+(p+3092)|0;yc=(ca(d[Ne]|0,Le)|0)>>8;Pc=Le-yc|0;c[g>>2]=Pc;if((Me|0)<(Pc|0)){break}else{$c=Oc;Mc=Ne;ad=yc;Tc=Pc;Uc=Me}}He=$c;Ie=Ne;Je=a[Ne]|0}a[Ie]=a[(Je&255)+(p+24)|0]|0;Uc=c[g>>2]|0;if((Uc|0)<256){Tc=Uc<<8;c[g>>2]=Tc;ad=c[t>>2]<<8;c[t>>2]=ad;Mc=c[cd>>2]|0;if(Mc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Mc]|ad}c[cd>>2]=Mc+1;Oe=Tc}else{Oe=Uc}n:do{if((He|0)>0){Uc=2;Tc=He;Mc=Oe;while(1){ad=Tc-1|0;Vc=((ad|0)>9?31:Tc+21|0)+(p+3092)|0;Pc=(ca(d[Vc]|0,Mc)|0)>>8;yc=Mc-Pc|0;c[g>>2]=yc;Oc=c[t>>2]|0;do{if((Oc|0)<(yc|0)){a[Vc]=a[(d[Vc]|0)+(p+24)|0]|0;Nc=c[g>>2]|0;if((Nc|0)>=256){Pe=0;Qe=Nc;break}Lc=Nc<<8;c[g>>2]=Lc;Nc=c[t>>2]<<8;c[t>>2]=Nc;Ec=c[cd>>2]|0;if(Ec>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Ec]|Nc}c[cd>>2]=Ec+1;Pe=0;Qe=Lc}else{c[t>>2]=Oc-yc;a[Vc]=a[(d[Vc]|0)+(p+280)|0]|0;c[g>>2]=Pc;if((Pc|0)>=256){Pe=1;Qe=Pc;break}Lc=Pc<<8;c[g>>2]=Lc;Ec=c[t>>2]<<8;c[t>>2]=Ec;Nc=c[cd>>2]|0;if(Nc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Nc]|Ec}c[cd>>2]=Nc+1;Pe=1;Qe=Lc}}while(0);Pc=Pe|Uc;if((ad|0)<=0){Re=Pc;Se=Qe;break n}Uc=Pc<<1;Tc=ad;Mc=Qe}}else{Re=1;Se=Oe}}while(0);$c=((He|0)>10?21:He+11|0)+(p+3092)|0;Mc=(ca(d[$c]|0,Se)|0)>>8;Tc=Se-Mc|0;c[g>>2]=Tc;Uc=c[t>>2]|0;do{if((Uc|0)<(Tc|0)){a[$c]=a[(d[$c]|0)+(p+24)|0]|0;Pc=c[g>>2]|0;if((Pc|0)>=256){Te=0;break}c[g>>2]=Pc<<8;Pc=c[t>>2]<<8;c[t>>2]=Pc;Vc=c[cd>>2]|0;if(Vc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Vc]|Pc}c[cd>>2]=Vc+1;Te=0}else{c[t>>2]=Uc-Tc;a[$c]=a[(d[$c]|0)+(p+280)|0]|0;c[g>>2]=Mc;if((Mc|0)>=256){Te=1;break}c[g>>2]=Mc<<8;Vc=c[t>>2]<<8;c[t>>2]=Vc;Pc=c[cd>>2]|0;if(Pc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Pc]|Vc}c[cd>>2]=Pc+1;Te=1}}while(0);Ue=(Re^-Te)+Te|0}else{Mc=fd-bd|0;c[t>>2]=Mc;a[nd]=a[p+280+ed|0]|0;c[g>>2]=Yc;if((Yc|0)>=256){Ue=0;break}c[g>>2]=Yc<<8;$c=Mc<<8;c[t>>2]=$c;Mc=c[cd>>2]|0;if(Mc>>>0<(c[kb>>2]|0)>>>0){c[t>>2]=d[Mc]|$c}c[cd>>2]=Mc+1;Ue=0}}while(0);c[p+7548+(jd*533028|0)+8+(De*66624|0)+(Xc*16656|0)+16>>2]=Ue;Xc=Xc+1|0;if((Xc|0)>=4){break}}Ve=c[kd>>2]|0;De=De+1|0;}while((De|0)<(Ve|0));Be=Ve;Ce=c[ld>>2]|0}else{Be=_c;Ce=Sc}}while(0);Wc=jd+1|0;if((Wc|0)<(Ce|0)){jd=Wc;_c=Be;Sc=Ce}else{break j}}}else{Sc=je-r|0;c[t>>2]=Sc;a[nd]=a[p+280+md|0]|0;c[g>>2]=Rc;if((Rc|0)>=256){Ae=0;break}c[g>>2]=Rc<<8;_c=Sc<<8;c[t>>2]=_c;Sc=o+540|0;jd=c[Sc>>2]|0;if(jd>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[jd]|_c}c[Sc>>2]=jd+1;Ae=0}}while(0);KIb(c[o+4>>2]|0,16,2201752,(ga=i,i=i+8|0,c[ga>>2]=Ae,ga)|0);i=ga;ha=-1;i=k;return ha|0}}while(0);Ae=o+3092|0;nd=c[g>>2]|0;je=d[Ae]|0;Ce=(ca(je,nd)|0)>>8;Be=nd-Ce|0;c[g>>2]=Be;nd=c[t>>2]|0;do{if((nd|0)<(Be|0)){a[Ae]=a[p+24+je|0]|0;if((Be|0)<256){Ve=Be<<8;c[g>>2]=Ve;De=nd<<8;c[t>>2]=De;Ue=o+540|0;Te=c[Ue>>2]|0;if(Te>>>0<(c[o+544>>2]|0)>>>0){Re=d[Te]|De;c[t>>2]=Re;We=Re}else{We=De}c[Ue>>2]=Te+1;Xe=Ve;Ye=We}else{Xe=Be;Ye=nd}Ve=o+3093|0;Te=a[Ve]|0;Ue=(ca(Te&255,Xe)|0)>>8;De=Xe-Ue|0;c[g>>2]=De;if((Ye|0)<(De|0)){Ze=0;_e=Ve;$e=Te}else{Te=o+540|0;Re=o+544|0;Se=1;He=Ve;Ve=Ue;Ue=De;De=Ye;while(1){c[t>>2]=De-Ue;a[He]=a[(d[He]|0)+(p+280)|0]|0;c[g>>2]=Ve;if((Ve|0)<256){Oe=Ve<<8;c[g>>2]=Oe;Qe=c[t>>2]<<8;c[t>>2]=Qe;Pe=c[Te>>2]|0;if(Pe>>>0<(c[Re>>2]|0)>>>0){Je=d[Pe]|Qe;c[t>>2]=Je;af=Je}else{af=Qe}c[Te>>2]=Pe+1;bf=Oe;cf=af}else{bf=Ve;cf=c[t>>2]|0}Oe=Se+1|0;df=((Se|0)>9?10:Oe)+(p+3092)|0;Pe=(ca(d[df]|0,bf)|0)>>8;Qe=bf-Pe|0;c[g>>2]=Qe;if((cf|0)<(Qe|0)){break}else{Se=Oe;He=df;Ve=Pe;Ue=Qe;De=cf}}Ze=Se;_e=df;$e=a[df]|0}a[_e]=a[($e&255)+(p+24)|0]|0;De=c[g>>2]|0;if((De|0)<256){Ue=De<<8;c[g>>2]=Ue;Ve=c[t>>2]<<8;c[t>>2]=Ve;He=o+540|0;Te=c[He>>2]|0;if(Te>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Te]|Ve}c[He>>2]=Te+1;ef=Ue}else{ef=De}o:do{if((Ze|0)>0){De=o+540|0;Ue=o+544|0;Te=2;He=Ze;Ve=ef;while(1){Re=He-1|0;Qe=((Re|0)>9?31:He+21|0)+(p+3092)|0;Pe=(ca(d[Qe]|0,Ve)|0)>>8;Oe=Ve-Pe|0;c[g>>2]=Oe;Je=c[t>>2]|0;do{if((Je|0)<(Oe|0)){a[Qe]=a[(d[Qe]|0)+(p+24)|0]|0;Ie=c[g>>2]|0;if((Ie|0)>=256){ff=0;gf=Ie;break}Ne=Ie<<8;c[g>>2]=Ne;Ie=c[t>>2]<<8;c[t>>2]=Ie;Me=c[De>>2]|0;if(Me>>>0<(c[Ue>>2]|0)>>>0){c[t>>2]=d[Me]|Ie}c[De>>2]=Me+1;ff=0;gf=Ne}else{c[t>>2]=Je-Oe;a[Qe]=a[(d[Qe]|0)+(p+280)|0]|0;c[g>>2]=Pe;if((Pe|0)>=256){ff=1;gf=Pe;break}Ne=Pe<<8;c[g>>2]=Ne;Me=c[t>>2]<<8;c[t>>2]=Me;Ie=c[De>>2]|0;if(Ie>>>0<(c[Ue>>2]|0)>>>0){c[t>>2]=d[Ie]|Me}c[De>>2]=Ie+1;ff=1;gf=Ne}}while(0);Pe=ff|Te;if((Re|0)<=0){hf=Pe;jf=gf;break o}Te=Pe<<1;He=Re;Ve=gf}}else{hf=1;jf=ef}}while(0);Se=((Ze|0)>10?21:Ze+11|0)+(p+3092)|0;Ve=(ca(d[Se]|0,jf)|0)>>8;He=jf-Ve|0;c[g>>2]=He;Te=c[t>>2]|0;do{if((Te|0)<(He|0)){a[Se]=a[(d[Se]|0)+(p+24)|0]|0;De=c[g>>2]|0;if((De|0)>=256){kf=0;lf=De;break}Ue=De<<8;c[g>>2]=Ue;De=c[t>>2]<<8;c[t>>2]=De;Pe=o+540|0;Qe=c[Pe>>2]|0;if(Qe>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Qe]|De}c[Pe>>2]=Qe+1;kf=0;lf=Ue}else{c[t>>2]=Te-He;a[Se]=a[(d[Se]|0)+(p+280)|0]|0;c[g>>2]=Ve;if((Ve|0)>=256){kf=1;lf=Ve;break}Ue=Ve<<8;c[g>>2]=Ue;Qe=c[t>>2]<<8;c[t>>2]=Qe;Pe=o+540|0;De=c[Pe>>2]|0;if(De>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[De]|Qe}c[Pe>>2]=De+1;kf=1;lf=Ue}}while(0);mf=(hf^-kf)+kf|0;nf=lf}else{Ve=nd-Be|0;c[t>>2]=Ve;a[Ae]=a[p+280+je|0]|0;c[g>>2]=Ce;if((Ce|0)>=256){mf=0;nf=Ce;break}Se=Ce<<8;c[g>>2]=Se;He=Ve<<8;c[t>>2]=He;Ve=o+540|0;Te=c[Ve>>2]|0;if(Te>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Te]|He}c[Ve>>2]=Te+1;mf=0;nf=Se}}while(0);Ce=o+7360|0;je=(c[Ce>>2]|0)+mf|0;c[Ce>>2]=je;mf=o+4|0;Be=c[mf>>2]|0;if(je>>>0>1>>>0){KIb(Be,16,2637584,(ga=i,i=i+8|0,c[ga>>2]=je,ga)|0);i=ga;ha=-1;i=k;return ha|0}je=o+7480|0;nd=c[Be+120>>2]>>c[je>>2];lf=o+7484|0;kf=c[Be+124>>2]>>c[lf>>2];hf=o+7372|0;jf=c[hf>>2]|0;if((((nd|0)>(kf|0)?kf:nd)>>jf-1|0)<2){KIb(Be,16,2614304,(ga=i,i=i+8|0,c[ga>>2]=jf,ga)|0);i=ga;ha=-1;i=k;return ha|0}jf=d[Ae]|0;Be=(ca(jf,nf)|0)>>8;nd=nf-Be|0;c[g>>2]=nd;nf=c[t>>2]|0;do{if((nf|0)<(nd|0)){a[Ae]=a[p+24+jf|0]|0;if((nd|0)<256){kf=nd<<8;c[g>>2]=kf;Ze=nf<<8;c[t>>2]=Ze;ef=o+540|0;gf=c[ef>>2]|0;if(gf>>>0<(c[o+544>>2]|0)>>>0){ff=d[gf]|Ze;c[t>>2]=ff;of=ff}else{of=Ze}c[ef>>2]=gf+1;pf=kf;qf=of}else{pf=nd;qf=nf}kf=o+3093|0;gf=a[kf]|0;ef=(ca(gf&255,pf)|0)>>8;Ze=pf-ef|0;c[g>>2]=Ze;if((qf|0)<(Ze|0)){rf=0;sf=kf;tf=gf}else{gf=o+540|0;ff=o+544|0;$e=1;_e=kf;kf=ef;ef=Ze;Ze=qf;while(1){c[t>>2]=Ze-ef;a[_e]=a[(d[_e]|0)+(p+280)|0]|0;c[g>>2]=kf;if((kf|0)<256){df=kf<<8;c[g>>2]=df;cf=c[t>>2]<<8;c[t>>2]=cf;bf=c[gf>>2]|0;if(bf>>>0<(c[ff>>2]|0)>>>0){af=d[bf]|cf;c[t>>2]=af;uf=af}else{uf=cf}c[gf>>2]=bf+1;vf=df;wf=uf}else{vf=kf;wf=c[t>>2]|0}df=$e+1|0;xf=(($e|0)>9?10:df)+(p+3092)|0;bf=(ca(d[xf]|0,vf)|0)>>8;cf=vf-bf|0;c[g>>2]=cf;if((wf|0)<(cf|0)){break}else{$e=df;_e=xf;kf=bf;ef=cf;Ze=wf}}rf=$e;sf=xf;tf=a[xf]|0}a[sf]=a[(tf&255)+(p+24)|0]|0;Ze=c[g>>2]|0;if((Ze|0)<256){ef=Ze<<8;c[g>>2]=ef;kf=c[t>>2]<<8;c[t>>2]=kf;_e=o+540|0;gf=c[_e>>2]|0;if(gf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[gf]|kf}c[_e>>2]=gf+1;yf=ef}else{yf=Ze}p:do{if((rf|0)>0){Ze=o+540|0;ef=o+544|0;gf=2;_e=rf;kf=yf;while(1){ff=_e-1|0;cf=((ff|0)>9?31:_e+21|0)+(p+3092)|0;bf=(ca(d[cf]|0,kf)|0)>>8;df=kf-bf|0;c[g>>2]=df;af=c[t>>2]|0;do{if((af|0)<(df|0)){a[cf]=a[(d[cf]|0)+(p+24)|0]|0;Ye=c[g>>2]|0;if((Ye|0)>=256){zf=0;Af=Ye;break}Xe=Ye<<8;c[g>>2]=Xe;Ye=c[t>>2]<<8;c[t>>2]=Ye;We=c[Ze>>2]|0;if(We>>>0<(c[ef>>2]|0)>>>0){c[t>>2]=d[We]|Ye}c[Ze>>2]=We+1;zf=0;Af=Xe}else{c[t>>2]=af-df;a[cf]=a[(d[cf]|0)+(p+280)|0]|0;c[g>>2]=bf;if((bf|0)>=256){zf=1;Af=bf;break}Xe=bf<<8;c[g>>2]=Xe;We=c[t>>2]<<8;c[t>>2]=We;Ye=c[Ze>>2]|0;if(Ye>>>0<(c[ef>>2]|0)>>>0){c[t>>2]=d[Ye]|We}c[Ze>>2]=Ye+1;zf=1;Af=Xe}}while(0);bf=zf|gf;if((ff|0)<=0){Bf=bf;Cf=Af;break p}gf=bf<<1;_e=ff;kf=Af}}else{Bf=1;Cf=yf}}while(0);$e=((rf|0)>10?21:rf+11|0)+(p+3092)|0;kf=(ca(d[$e]|0,Cf)|0)>>8;_e=Cf-kf|0;c[g>>2]=_e;gf=c[t>>2]|0;do{if((gf|0)<(_e|0)){a[$e]=a[(d[$e]|0)+(p+24)|0]|0;Ze=c[g>>2]|0;if((Ze|0)>=256){Df=0;Ef=Ze;break}ef=Ze<<8;c[g>>2]=ef;Ze=c[t>>2]<<8;c[t>>2]=Ze;bf=o+540|0;cf=c[bf>>2]|0;if(cf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[cf]|Ze}c[bf>>2]=cf+1;Df=0;Ef=ef}else{c[t>>2]=gf-_e;a[$e]=a[(d[$e]|0)+(p+280)|0]|0;c[g>>2]=kf;if((kf|0)>=256){Df=1;Ef=kf;break}ef=kf<<8;c[g>>2]=ef;cf=c[t>>2]<<8;c[t>>2]=cf;bf=o+540|0;Ze=c[bf>>2]|0;if(Ze>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Ze]|cf}c[bf>>2]=Ze+1;Df=1;Ef=ef}}while(0);Ff=(Bf^-Df)+Df|0;Gf=Ef;Hf=a[Ae]|0;If=c[t>>2]|0}else{kf=nf-nd|0;c[t>>2]=kf;$e=a[p+280+jf|0]|0;a[Ae]=$e;c[g>>2]=Be;if((Be|0)>=256){Ff=0;Gf=Be;Hf=$e;If=kf;break}_e=Be<<8;c[g>>2]=_e;gf=kf<<8;c[t>>2]=gf;kf=o+540|0;ef=c[kf>>2]|0;if(ef>>>0<(c[o+544>>2]|0)>>>0){Ze=d[ef]|gf;c[t>>2]=Ze;Jf=Ze}else{Jf=gf}c[kf>>2]=ef+1;Ff=0;Gf=_e;Hf=$e;If=Jf}}while(0);Jf=o+7492|0;c[Jf>>2]=(c[Jf>>2]|0)+Ff;Ff=Hf&255;Hf=(ca(Ff,Gf)|0)>>8;Be=Gf-Hf|0;c[g>>2]=Be;do{if((If|0)<(Be|0)){a[Ae]=a[p+24+Ff|0]|0;if((Be|0)<256){Gf=Be<<8;c[g>>2]=Gf;jf=If<<8;c[t>>2]=jf;nd=o+540|0;nf=c[nd>>2]|0;if(nf>>>0<(c[o+544>>2]|0)>>>0){Ef=d[nf]|jf;c[t>>2]=Ef;Kf=Ef}else{Kf=jf}c[nd>>2]=nf+1;Lf=Gf;Mf=Kf}else{Lf=Be;Mf=If}Gf=o+3093|0;nf=a[Gf]|0;nd=(ca(nf&255,Lf)|0)>>8;jf=Lf-nd|0;c[g>>2]=jf;if((Mf|0)<(jf|0)){Nf=0;Of=Gf;Pf=nf}else{nf=o+540|0;Ef=o+544|0;Df=1;Bf=Gf;Gf=nd;nd=jf;jf=Mf;while(1){c[t>>2]=jf-nd;a[Bf]=a[(d[Bf]|0)+(p+280)|0]|0;c[g>>2]=Gf;if((Gf|0)<256){Cf=Gf<<8;c[g>>2]=Cf;rf=c[t>>2]<<8;c[t>>2]=rf;yf=c[nf>>2]|0;if(yf>>>0<(c[Ef>>2]|0)>>>0){Af=d[yf]|rf;c[t>>2]=Af;Qf=Af}else{Qf=rf}c[nf>>2]=yf+1;Rf=Cf;Sf=Qf}else{Rf=Gf;Sf=c[t>>2]|0}Cf=Df+1|0;Tf=((Df|0)>9?10:Cf)+(p+3092)|0;yf=(ca(d[Tf]|0,Rf)|0)>>8;rf=Rf-yf|0;c[g>>2]=rf;if((Sf|0)<(rf|0)){break}else{Df=Cf;Bf=Tf;Gf=yf;nd=rf;jf=Sf}}Nf=Df;Of=Tf;Pf=a[Tf]|0}a[Of]=a[(Pf&255)+(p+24)|0]|0;jf=c[g>>2]|0;if((jf|0)<256){nd=jf<<8;c[g>>2]=nd;Gf=c[t>>2]<<8;c[t>>2]=Gf;Bf=o+540|0;nf=c[Bf>>2]|0;if(nf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[nf]|Gf}c[Bf>>2]=nf+1;Uf=nd}else{Uf=jf}q:do{if((Nf|0)>0){jf=o+540|0;nd=o+544|0;nf=2;Bf=Nf;Gf=Uf;while(1){Ef=Bf-1|0;rf=((Ef|0)>9?31:Bf+21|0)+(p+3092)|0;yf=(ca(d[rf]|0,Gf)|0)>>8;Cf=Gf-yf|0;c[g>>2]=Cf;Af=c[t>>2]|0;do{if((Af|0)<(Cf|0)){a[rf]=a[(d[rf]|0)+(p+24)|0]|0;zf=c[g>>2]|0;if((zf|0)>=256){Vf=0;Wf=zf;break}tf=zf<<8;c[g>>2]=tf;zf=c[t>>2]<<8;c[t>>2]=zf;sf=c[jf>>2]|0;if(sf>>>0<(c[nd>>2]|0)>>>0){c[t>>2]=d[sf]|zf}c[jf>>2]=sf+1;Vf=0;Wf=tf}else{c[t>>2]=Af-Cf;a[rf]=a[(d[rf]|0)+(p+280)|0]|0;c[g>>2]=yf;if((yf|0)>=256){Vf=1;Wf=yf;break}tf=yf<<8;c[g>>2]=tf;sf=c[t>>2]<<8;c[t>>2]=sf;zf=c[jf>>2]|0;if(zf>>>0<(c[nd>>2]|0)>>>0){c[t>>2]=d[zf]|sf}c[jf>>2]=zf+1;Vf=1;Wf=tf}}while(0);yf=Vf|nf;if((Ef|0)<=0){Xf=yf;Yf=Wf;break q}nf=yf<<1;Bf=Ef;Gf=Wf}}else{Xf=1;Yf=Uf}}while(0);Df=((Nf|0)>10?21:Nf+11|0)+(p+3092)|0;Gf=(ca(d[Df]|0,Yf)|0)>>8;Bf=Yf-Gf|0;c[g>>2]=Bf;nf=c[t>>2]|0;do{if((nf|0)<(Bf|0)){a[Df]=a[(d[Df]|0)+(p+24)|0]|0;jf=c[g>>2]|0;if((jf|0)>=256){Zf=0;_f=jf;break}nd=jf<<8;c[g>>2]=nd;jf=c[t>>2]<<8;c[t>>2]=jf;yf=o+540|0;rf=c[yf>>2]|0;if(rf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[rf]|jf}c[yf>>2]=rf+1;Zf=0;_f=nd}else{c[t>>2]=nf-Bf;a[Df]=a[(d[Df]|0)+(p+280)|0]|0;c[g>>2]=Gf;if((Gf|0)>=256){Zf=1;_f=Gf;break}nd=Gf<<8;c[g>>2]=nd;rf=c[t>>2]<<8;c[t>>2]=rf;yf=o+540|0;jf=c[yf>>2]|0;if(jf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[jf]|rf}c[yf>>2]=jf+1;Zf=1;_f=nd}}while(0);$f=(Xf^-Zf)+Zf|0;ag=_f;bg=a[Ae]|0;cg=c[t>>2]|0}else{Gf=If-Be|0;c[t>>2]=Gf;Df=a[p+280+Ff|0]|0;a[Ae]=Df;c[g>>2]=Hf;if((Hf|0)>=256){$f=0;ag=Hf;bg=Df;cg=Gf;break}Bf=Hf<<8;c[g>>2]=Bf;nf=Gf<<8;c[t>>2]=nf;Gf=o+540|0;nd=c[Gf>>2]|0;if(nd>>>0<(c[o+544>>2]|0)>>>0){jf=d[nd]|nf;c[t>>2]=jf;dg=jf}else{dg=nf}c[Gf>>2]=nd+1;$f=0;ag=Bf;bg=Df;cg=dg}}while(0);dg=o+7512|0;c[dg>>2]=(c[dg>>2]|0)+$f;$f=bg&255;bg=(ca($f,ag)|0)>>8;dg=ag-bg|0;c[g>>2]=dg;do{if((cg|0)<(dg|0)){a[Ae]=a[p+24+$f|0]|0;if((dg|0)<256){ag=dg<<8;c[g>>2]=ag;Hf=cg<<8;c[t>>2]=Hf;Ff=o+540|0;Be=c[Ff>>2]|0;if(Be>>>0<(c[o+544>>2]|0)>>>0){If=d[Be]|Hf;c[t>>2]=If;eg=If}else{eg=Hf}c[Ff>>2]=Be+1;fg=ag;gg=eg}else{fg=dg;gg=cg}ag=o+3093|0;Be=a[ag]|0;Ff=(ca(Be&255,fg)|0)>>8;Hf=fg-Ff|0;c[g>>2]=Hf;if((gg|0)<(Hf|0)){hg=0;ig=ag;jg=Be}else{Be=o+540|0;If=o+544|0;_f=1;Zf=ag;ag=Ff;Ff=Hf;Hf=gg;while(1){c[t>>2]=Hf-Ff;a[Zf]=a[(d[Zf]|0)+(p+280)|0]|0;c[g>>2]=ag;if((ag|0)<256){Xf=ag<<8;c[g>>2]=Xf;Yf=c[t>>2]<<8;c[t>>2]=Yf;Nf=c[Be>>2]|0;if(Nf>>>0<(c[If>>2]|0)>>>0){Uf=d[Nf]|Yf;c[t>>2]=Uf;kg=Uf}else{kg=Yf}c[Be>>2]=Nf+1;lg=Xf;mg=kg}else{lg=ag;mg=c[t>>2]|0}Xf=_f+1|0;ng=((_f|0)>9?10:Xf)+(p+3092)|0;Nf=(ca(d[ng]|0,lg)|0)>>8;Yf=lg-Nf|0;c[g>>2]=Yf;if((mg|0)<(Yf|0)){break}else{_f=Xf;Zf=ng;ag=Nf;Ff=Yf;Hf=mg}}hg=_f;ig=ng;jg=a[ng]|0}a[ig]=a[(jg&255)+(p+24)|0]|0;Hf=c[g>>2]|0;if((Hf|0)<256){Ff=Hf<<8;c[g>>2]=Ff;ag=c[t>>2]<<8;c[t>>2]=ag;Zf=o+540|0;Be=c[Zf>>2]|0;if(Be>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Be]|ag}c[Zf>>2]=Be+1;og=Ff}else{og=Hf}r:do{if((hg|0)>0){Hf=o+540|0;Ff=o+544|0;Be=2;Zf=hg;ag=og;while(1){If=Zf-1|0;Yf=((If|0)>9?31:Zf+21|0)+(p+3092)|0;Nf=(ca(d[Yf]|0,ag)|0)>>8;Xf=ag-Nf|0;c[g>>2]=Xf;Uf=c[t>>2]|0;do{if((Uf|0)<(Xf|0)){a[Yf]=a[(d[Yf]|0)+(p+24)|0]|0;Wf=c[g>>2]|0;if((Wf|0)>=256){pg=0;qg=Wf;break}Vf=Wf<<8;c[g>>2]=Vf;Wf=c[t>>2]<<8;c[t>>2]=Wf;Pf=c[Hf>>2]|0;if(Pf>>>0<(c[Ff>>2]|0)>>>0){c[t>>2]=d[Pf]|Wf}c[Hf>>2]=Pf+1;pg=0;qg=Vf}else{c[t>>2]=Uf-Xf;a[Yf]=a[(d[Yf]|0)+(p+280)|0]|0;c[g>>2]=Nf;if((Nf|0)>=256){pg=1;qg=Nf;break}Vf=Nf<<8;c[g>>2]=Vf;Pf=c[t>>2]<<8;c[t>>2]=Pf;Wf=c[Hf>>2]|0;if(Wf>>>0<(c[Ff>>2]|0)>>>0){c[t>>2]=d[Wf]|Pf}c[Hf>>2]=Wf+1;pg=1;qg=Vf}}while(0);Nf=pg|Be;if((If|0)<=0){rg=Nf;sg=qg;break r}Be=Nf<<1;Zf=If;ag=qg}}else{rg=1;sg=og}}while(0);_f=((hg|0)>10?21:hg+11|0)+(p+3092)|0;ag=(ca(d[_f]|0,sg)|0)>>8;Zf=sg-ag|0;c[g>>2]=Zf;Be=c[t>>2]|0;do{if((Be|0)<(Zf|0)){a[_f]=a[(d[_f]|0)+(p+24)|0]|0;Hf=c[g>>2]|0;if((Hf|0)>=256){tg=0;ug=Hf;break}Ff=Hf<<8;c[g>>2]=Ff;Hf=c[t>>2]<<8;c[t>>2]=Hf;Nf=o+540|0;Yf=c[Nf>>2]|0;if(Yf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Yf]|Hf}c[Nf>>2]=Yf+1;tg=0;ug=Ff}else{c[t>>2]=Be-Zf;a[_f]=a[(d[_f]|0)+(p+280)|0]|0;c[g>>2]=ag;if((ag|0)>=256){tg=1;ug=ag;break}Ff=ag<<8;c[g>>2]=Ff;Yf=c[t>>2]<<8;c[t>>2]=Yf;Nf=o+540|0;Hf=c[Nf>>2]|0;if(Hf>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[Hf]|Yf}c[Nf>>2]=Hf+1;tg=1;ug=Ff}}while(0);vg=(rg^-tg)+tg|0;wg=ug;xg=a[Ae]|0;yg=c[t>>2]|0}else{ag=cg-dg|0;c[t>>2]=ag;_f=a[p+280+$f|0]|0;a[Ae]=_f;c[g>>2]=bg;if((bg|0)>=256){vg=0;wg=bg;xg=_f;yg=ag;break}Zf=bg<<8;c[g>>2]=Zf;Be=ag<<8;c[t>>2]=Be;ag=o+540|0;Ff=c[ag>>2]|0;if(Ff>>>0<(c[o+544>>2]|0)>>>0){Hf=d[Ff]|Be;c[t>>2]=Hf;zg=Hf}else{zg=Be}c[ag>>2]=Ff+1;vg=0;wg=Zf;xg=_f;yg=zg}}while(0);zg=o+7520|0;c[zg>>2]=(c[zg>>2]|0)+vg;vg=xg&255;xg=(ca(vg,wg)|0)>>8;bg=wg-xg|0;c[g>>2]=bg;do{if((yg|0)<(bg|0)){a[Ae]=a[p+24+vg|0]|0;if((bg|0)<256){wg=bg<<8;c[g>>2]=wg;$f=yg<<8;c[t>>2]=$f;dg=o+540|0;cg=c[dg>>2]|0;if(cg>>>0<(c[o+544>>2]|0)>>>0){ug=d[cg]|$f;c[t>>2]=ug;Ag=ug}else{Ag=$f}c[dg>>2]=cg+1;Bg=wg;Cg=Ag}else{Bg=bg;Cg=yg}wg=o+3093|0;cg=a[wg]|0;dg=(ca(cg&255,Bg)|0)>>8;$f=Bg-dg|0;c[g>>2]=$f;if((Cg|0)<($f|0)){Dg=0;Eg=wg;Fg=cg}else{cg=o+540|0;ug=o+544|0;tg=1;rg=wg;wg=dg;dg=$f;$f=Cg;while(1){c[t>>2]=$f-dg;a[rg]=a[(d[rg]|0)+(p+280)|0]|0;c[g>>2]=wg;if((wg|0)<256){sg=wg<<8;c[g>>2]=sg;hg=c[t>>2]<<8;c[t>>2]=hg;og=c[cg>>2]|0;if(og>>>0<(c[ug>>2]|0)>>>0){qg=d[og]|hg;c[t>>2]=qg;Gg=qg}else{Gg=hg}c[cg>>2]=og+1;Hg=sg;Ig=Gg}else{Hg=wg;Ig=c[t>>2]|0}sg=tg+1|0;Jg=((tg|0)>9?10:sg)+(p+3092)|0;og=(ca(d[Jg]|0,Hg)|0)>>8;hg=Hg-og|0;c[g>>2]=hg;if((Ig|0)<(hg|0)){break}else{tg=sg;rg=Jg;wg=og;dg=hg;$f=Ig}}Dg=tg;Eg=Jg;Fg=a[Jg]|0}a[Eg]=a[(Fg&255)+(p+24)|0]|0;$f=c[g>>2]|0;if(($f|0)<256){dg=$f<<8;c[g>>2]=dg;wg=c[t>>2]<<8;c[t>>2]=wg;rg=o+540|0;cg=c[rg>>2]|0;if(cg>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[cg]|wg}c[rg>>2]=cg+1;Kg=dg}else{Kg=$f}s:do{if((Dg|0)>0){$f=o+540|0;dg=o+544|0;cg=2;rg=Dg;wg=Kg;while(1){ug=rg-1|0;hg=((ug|0)>9?31:rg+21|0)+(p+3092)|0;og=(ca(d[hg]|0,wg)|0)>>8;sg=wg-og|0;c[g>>2]=sg;qg=c[t>>2]|0;do{if((qg|0)<(sg|0)){a[hg]=a[(d[hg]|0)+(p+24)|0]|0;pg=c[g>>2]|0;if((pg|0)>=256){Lg=0;Mg=pg;break}jg=pg<<8;c[g>>2]=jg;pg=c[t>>2]<<8;c[t>>2]=pg;ig=c[$f>>2]|0;if(ig>>>0<(c[dg>>2]|0)>>>0){c[t>>2]=d[ig]|pg}c[$f>>2]=ig+1;Lg=0;Mg=jg}else{c[t>>2]=qg-sg;a[hg]=a[(d[hg]|0)+(p+280)|0]|0;c[g>>2]=og;if((og|0)>=256){Lg=1;Mg=og;break}jg=og<<8;c[g>>2]=jg;ig=c[t>>2]<<8;c[t>>2]=ig;pg=c[$f>>2]|0;if(pg>>>0<(c[dg>>2]|0)>>>0){c[t>>2]=d[pg]|ig}c[$f>>2]=pg+1;Lg=1;Mg=jg}}while(0);og=Lg|cg;if((ug|0)<=0){Ng=og;Og=Mg;break s}cg=og<<1;rg=ug;wg=Mg}}else{Ng=1;Og=Kg}}while(0);tg=((Dg|0)>10?21:Dg+11|0)+(p+3092)|0;wg=(ca(d[tg]|0,Og)|0)>>8;rg=Og-wg|0;c[g>>2]=rg;cg=c[t>>2]|0;do{if((cg|0)<(rg|0)){a[tg]=a[(d[tg]|0)+(p+24)|0]|0;$f=c[g>>2]|0;if(($f|0)>=256){Pg=0;break}c[g>>2]=$f<<8;$f=c[t>>2]<<8;c[t>>2]=$f;dg=o+540|0;og=c[dg>>2]|0;if(og>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[og]|$f}c[dg>>2]=og+1;Pg=0}else{c[t>>2]=cg-rg;a[tg]=a[(d[tg]|0)+(p+280)|0]|0;c[g>>2]=wg;if((wg|0)>=256){Pg=1;break}c[g>>2]=wg<<8;og=c[t>>2]<<8;c[t>>2]=og;dg=o+540|0;$f=c[dg>>2]|0;if($f>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[$f]|og}c[dg>>2]=$f+1;Pg=1}}while(0);Qg=(Ng^-Pg)+Pg|0}else{wg=yg-bg|0;c[t>>2]=wg;a[Ae]=a[p+280+vg|0]|0;c[g>>2]=xg;if((xg|0)>=256){Qg=0;break}c[g>>2]=xg<<8;tg=wg<<8;c[t>>2]=tg;wg=o+540|0;rg=c[wg>>2]|0;if(rg>>>0<(c[o+544>>2]|0)>>>0){c[t>>2]=d[rg]|tg}c[wg>>2]=rg+1;Qg=0}}while(0);xg=o+7536|0;vg=(c[xg>>2]|0)+Qg|0;c[xg>>2]=vg;if(vg>>>0>1>>>0){KIb(c[mf>>2]|0,16,2587448,(ga=i,i=i+8|0,c[ga>>2]=vg,ga)|0);i=ga;c[xg>>2]=0;ha=-1;i=k;return ha|0}vg=Htb(f)|0;if((vg|0)<0){ha=vg;i=k;return ha|0}vg=o+2143764|0;Qg=vg;d1a(Qg);Ae=o+7548|0;bg=Ae;yg=o+7464|0;Pg=$0a(Qg,c[o+7552>>2]|0,(16>>>((c[xg>>2]|0)>>>0))+1+((c[hf>>2]|0)*11|0)|0,c[Ae>>2]|0,c[yg>>2]|0)|0;if((Pg|0)<0){ha=Pg;i=k;return ha|0}Pg=o+7544|0;if((c[Pg>>2]|0)>0){Ae=0;do{do{if((c[bg+(Ae*533028|0)+533008>>2]|0)==0){Rg=0}else{if((c[bg+(Ae*533028|0)+533e3>>2]|0)!=6){Rg=0;break}if((a[bg+(Ae*533028|0)+533004|0]|0)!=40){Rg=0;break}if(!((a[bg+(Ae*533028|0)+533005|0]|0)==-10)){Rg=0;break}Rg=(a[bg+(Ae*533028|0)+533006|0]|0)==2|0}}while(0);c[bg+(Ae*533028|0)+533012>>2]=Rg;Ae=Ae+1|0;}while((Ae|0)<(c[Pg>>2]|0))}vtb(p)|0;if((Jtb(p)|0)<0){ha=-1;i=k;return ha|0}if((c[f+688>>2]&1|0)!=0){Ae=c[Jf>>2]|0;KIb(f,16,2446376,(ga=i,i=i+16|0,c[ga>>2]=c[o+7348>>2],c[ga+8>>2]=Ae,ga)|0);i=ga}Ae=o+7528|0;Rg=c[Ae>>2]|0;Ng=o+7532|0;Og=c[Ng>>2]|0;t:do{if((Og|0)>0){Dg=0;u:while(1){Kg=0;while(1){if((Kg|0)>=(Rg|0)){break}Mg=A1a(p,0,Kg,Dg)|0;if((Mg|0)<0){ha=Mg;break u}else{Kg=Kg+1|0}}Dg=Dg+1|0;if((Dg|0)>=(Og|0)){break t}}i=k;return ha|0}}while(0);if((c[Pg>>2]|0)>0){Og=o+7456|0;Rg=o+7348|0;Dg=o+2139660|0;Kg=o+2158472|0;Mg=o+3088|0;Lg=n|0;n=l|0;Fg=l+4|0;Eg=l+8|0;Jg=l+12|0;l=o+2528|0;Ig=vg;vg=o+2520|0;Hg=o+7468|0;Gg=m|0;Cg=o+540|0;Bg=o+544|0;Ag=0;do{rg=c[bg+(Ag*533028|0)>>2]|0;wg=bg+(Ag*533028|0)+4|0;tg=c[wg>>2]|0;do{if((c[(c[mf>>2]|0)+688>>2]&2048|0)!=0){mrc(c[Og>>2]|0,0,ca(rg<<2,tg)|0)|0;cg=c[yg>>2]|0;$f=c[Ng>>2]|0;dg=c[xg>>2]|0;og=$f<<dg;v:do{if((og|0)>=0){hg=(Ag|0)==0;sg=p+7548+(Ag*533028|0)|0;qg=p+7548+(Ag*533028|0)+4|0;If=0;jg=dg;pg=$f;while(1){ig=c[Ae>>2]|0;ng=ig<<jg;mg=pg<<jg;lg=16>>>(jg>>>0);if(hg){Sg=lg<<1;Tg=lg;Ug=lg;Vg=jg}else{kg=c[je>>2]|0;Sg=lg<<1>>kg;Tg=lg>>c[lf>>2];Ug=lg>>kg;Vg=kg+jg|0}kg=c[1335352+(Vg<<2)>>2]|0;lg=c[j>>2]|0;gg=c[lg+32+(Ag<<2)>>2]|0;fg=c[lg+(Ag<<2)>>2]|0;lg=c[sg>>2]|0;eg=c[qg>>2]|0;w:do{if((c[Rg>>2]|0)==0){if((c[(c[mf>>2]|0)+688>>2]&512|0)!=0){A=848;break}if((ng|0)<0){break}_f=(Ug|0)/2|0;Zf=(ca(Tg,If)|0)-((Tg|0)/2|0)|0;Ff=If-1|0;ag=(gg|0)>111?16:gg<<4;Be=(Ff|0)<0;Hf=(Zf|0)<0;Nf=ca(Zf,-Sg|0)|0;Yf=Zf+Tg|0;Xf=ag*3|0;Uf=Xf+ag|0;Ef=Sg>>1;Vf=Uf+ag|0;Wf=0;Pf=ig;Of=jg;Tf=pg;while(1){Sf=(ca(Wf,Ug)|0)-_f|0;Rf=Wf-1|0;Qf=Pf<<Of;Mf=ca(Qf,Ff)|0;Lf=Mf+Rf|0;Kf=c[Dg>>2]|0;Df=Kf+(Lf*10|0)|0;Bf=Kf+((Mf+Wf|0)*10|0)|0;Mf=Lf+Qf|0;Lf=Kf+(Mf*10|0)|0;nd=Kf+((Mf+1|0)*10|0)|0;Mf=c[Kg>>2]|0;if((Rf|0)<0){Wg=nd;Xg=nd;Yg=Bf;Zg=Bf}else{Rf=(Wf|0)<(Qf|0);Wg=Rf?nd:Lf;Xg=Lf;Yg=Rf?Bf:Df;Zg=Df}if(Be){_g=Wg;$g=Xg;ah=Wg;bh=Xg}else{Df=(Tf<<Of|0)>(If|0);_g=Df?Wg:Yg;$g=Df?Xg:Zg;ah=Yg;bh=Zg}if((Sf|0)<0){ch=kg+(-Sf|0)|0;dh=0;eh=Sf+Ug|0}else{ch=kg;dh=Sf;eh=Ug}Sf=(dh+eh|0)>(lg|0)?lg-dh|0:eh;if(Hf){fh=ch+Nf|0;gh=0;hh=Yf}else{fh=ch;gh=Zf;hh=Tg}Df=(gh+hh|0)>(eg|0)?eg-gh|0:hh;do{if(!((Sf|0)<1|(Df|0)<1)){Bf=(ca(gh,gg)|0)+dh|0;Rf=Mf+Xf|0;Lf=Mf+Uf|0;wtb(p,Rf,Mf,gg,dh,gh,Sf,Df,bh,Ag,lg,eg);nd=bh+8|0;Qf=a[nd]|0;Kf=ah+8|0;Gf=a[Kf]|0;do{if((Qf&1)==0){A=869}else{if((Gf&1)==0){A=869;break}ih=(d[bh+6|0]|0)-(d[ah+6|0]|0)|(d[bh+5|0]|0)-(d[ah+5|0]|0)|(d[bh+7|0]|0)-(d[ah+7|0]|0)}}while(0);if((A|0)==869){A=0;ih=(b[bh>>1]|0)-(b[ah>>1]|0)|(Gf^Qf)&1|(b[bh+2>>1]|0)-(b[ah+2>>1]|0)|(d[bh+4|0]|0)-(d[ah+4|0]|0)}if((ih|0)==0){jh=Lf;kh=Rf;lh=Qf}else{wtb(p,Lf,Mf,gg,dh,gh,Sf,Df,ah,Ag,lg,eg);jh=Mf+Vf|0;kh=Lf;lh=a[nd]|0}nf=$g+8|0;jf=a[nf]|0;do{if((lh&1)==0){A=875}else{if((jf&1)==0){A=875;break}mh=(d[bh+6|0]|0)-(d[$g+6|0]|0)|(d[bh+5|0]|0)-(d[$g+5|0]|0)|(d[bh+7|0]|0)-(d[$g+7|0]|0)}}while(0);if((A|0)==875){A=0;mh=(b[bh>>1]|0)-(b[$g>>1]|0)|(jf^lh)&1|(b[bh+2>>1]|0)-(b[$g+2>>1]|0)|(d[bh+4|0]|0)-(d[$g+4|0]|0)}do{if((mh|0)==0){nh=jh;oh=Rf;ph=lh}else{Lf=a[Kf]|0;do{if((Lf&1)==0){A=880}else{if((jf&1)==0){A=880;break}qh=(d[ah+6|0]|0)-(d[$g+6|0]|0)|(d[ah+5|0]|0)-(d[$g+5|0]|0)|(d[ah+7|0]|0)-(d[$g+7|0]|0)}}while(0);if((A|0)==880){A=0;qh=(b[ah>>1]|0)-(b[$g>>1]|0)|(Lf^jf)&1|(b[ah+2>>1]|0)-(b[$g+2>>1]|0)|(d[ah+4|0]|0)-(d[$g+4|0]|0)}if((qh|0)==0){nh=jh;oh=kh;ph=lh;break}wtb(p,jh,Mf,gg,dh,gh,Sf,Df,$g,Ag,lg,eg);nh=jh+ag|0;oh=jh;ph=a[nd]|0}}while(0);nd=a[_g+8|0]|0;do{if((ph&1)==0){A=886}else{if((nd&1)==0){A=886;break}rh=(d[bh+6|0]|0)-(d[_g+6|0]|0)|(d[bh+5|0]|0)-(d[_g+5|0]|0)|(d[bh+7|0]|0)-(d[_g+7|0]|0)}}while(0);if((A|0)==886){A=0;rh=(b[bh>>1]|0)-(b[_g>>1]|0)|(nd^ph)&1|(b[bh+2>>1]|0)-(b[_g+2>>1]|0)|(d[bh+4|0]|0)-(d[_g+4|0]|0)}do{if((rh|0)==0){sh=Rf}else{jf=a[Kf]|0;do{if((jf&1)==0){A=891}else{if((nd&1)==0){A=891;break}th=(d[ah+6|0]|0)-(d[_g+6|0]|0)|(d[ah+5|0]|0)-(d[_g+5|0]|0)|(d[ah+7|0]|0)-(d[_g+7|0]|0)}}while(0);if((A|0)==891){A=0;th=(b[ah>>1]|0)-(b[_g>>1]|0)|(jf^nd)&1|(b[ah+2>>1]|0)-(b[_g+2>>1]|0)|(d[ah+4|0]|0)-(d[_g+4|0]|0)}if((th|0)==0){sh=kh;break}Lf=a[nf]|0;do{if((Lf&1)==0){A=896}else{if((nd&1)==0){A=896;break}uh=(d[$g+6|0]|0)-(d[_g+6|0]|0)|(d[$g+5|0]|0)-(d[_g+5|0]|0)|(d[$g+7|0]|0)-(d[_g+7|0]|0)}}while(0);if((A|0)==896){A=0;uh=(b[$g>>1]|0)-(b[_g>>1]|0)|(Lf^nd)&1|(b[$g+2>>1]|0)-(b[_g+2>>1]|0)|(d[$g+4|0]|0)-(d[_g+4|0]|0)}if((uh|0)==0){sh=oh;break}wtb(p,nh,Mf,gg,dh,gh,Sf,Df,_g,Ag,lg,eg);sh=nh}}while(0);if((Df|0)<=0){break}nd=(Sf|0)>0;nf=0;do{Kf=ca(nf,Sg)|0;Rf=Kf+Ef|0;jf=ca(nf+Ef|0,Sg)|0;Qf=jf+Ef|0;if(nd){Gf=ca(nf,gg)|0;yf=(ca(nf+gh|0,lg)|0)+dh|0;rf=0;do{Cf=rf+Gf|0;Af=((ca(d[fh+(rf+Kf)|0]|0,d[sh+Cf|0]|0)|0)+(ca(d[fh+(Rf+rf)|0]|0,d[oh+Cf|0]|0)|0)+(ca(d[fh+(rf+jf)|0]|0,d[kh+Cf|0]|0)|0)+(ca(d[fh+(Qf+rf)|0]|0,d[Mf+(Cf+Xf)|0]|0)|0)|0)>>>4;ff=(b[cg+(yf+rf<<1)>>1]|0)+8+Af|0;Af=ff>>4;if(Af>>>0>255>>>0){vh=(ff>>31^255)&255}else{vh=Af&255}a[fg+(Bf+Cf)|0]=vh;rf=rf+1|0;}while((rf|0)<(Sf|0))}nf=nf+1|0;}while((nf|0)<(Df|0))}}while(0);Df=Wf+1|0;if((Df|0)>(ng|0)){break w}Wf=Df;Pf=c[Ae>>2]|0;Of=c[xg>>2]|0;Tf=c[Ng>>2]|0}}else{A=848}}while(0);do{if((A|0)==848){A=0;if((mg|0)==(If|0)){break}ng=ca(Tg,If)|0;kg=ca(Tg,If+1|0)|0;ig=(eg|0)>(kg|0)?kg:eg;if((ng|0)>=(ig|0)){break}kg=(lg|0)>0;Tf=ng;do{if(kg){ng=ca(Tf,lg)|0;Of=ca(Tf,gg)|0;Pf=0;do{Wf=(b[cg+(Pf+ng<<1)>>1]|0)+2056|0;Xf=Wf>>4;if(Xf>>>0>255>>>0){wh=(Wf>>31^255)&255}else{wh=Xf&255}a[fg+(Pf+Of)|0]=wh;Pf=Pf+1|0;}while((Pf|0)<(lg|0))}Tf=Tf+1|0;}while((Tf|0)<(ig|0))}}while(0);lg=If+1|0;if((lg|0)>(og|0)){break v}If=lg;jg=c[xg>>2]|0;pg=c[Ng>>2]|0}}}while(0);if((tg|0)<=0){break}og=(rg|0)>0;cg=0;do{if(og){$f=0;do{dg=c[j>>2]|0;pg=(ca(c[dg+32+(Ag<<2)>>2]|0,cg)|0)+$f|0;jg=c[Mg>>2]|0;If=(ca(c[jg+32+(Ag<<2)>>2]|0,cg)|0)+$f|0;a[(c[jg+(Ag<<2)>>2]|0)+If|0]=a[(c[dg+(Ag<<2)>>2]|0)+pg|0]|0;$f=$f+1|0;}while(($f|0)<(rg|0))}cg=cg+1|0;}while((cg|0)<(tg|0))}}while(0);cg=c[hf>>2]|0;if((cg|0)>0){og=0;while(1){$f=(og|0)!=0|0;do{pg=c[bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+44>>2]|0;dg=c[bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+8>>2]|0;If=c[bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+12>>2]|0;jg=c[bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+40>>2]|0;if((pg|0)==0){xh=0}else{xh=c[pg+40>>2]|0}qg=0;sg=1;hg=0;ug=c[g>>2]|0;while(1){yh=qg+4+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+1008)|0;lg=(ca(d[yh]|0,ug)|0)>>8;fg=ug-lg|0;c[g>>2]=fg;gg=c[t>>2]|0;if((gg|0)<(fg|0)){A=923;break}c[t>>2]=gg-fg;a[yh]=a[(d[yh]|0)+(p+280)|0]|0;c[g>>2]=lg;if((lg|0)<256){fg=lg<<8;c[g>>2]=fg;gg=c[t>>2]<<8;c[t>>2]=gg;eg=c[Cg>>2]|0;if(eg>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[eg]|gg}c[Cg>>2]=eg+1;zh=fg}else{zh=lg}lg=sg+hg|0;fg=qg+1|0;if((fg|0)>=28){Ah=lg;Bh=fg;Ch=zh;A=933;break}qg=fg;sg=sg<<1;hg=lg;ug=zh}if((A|0)==923){A=0;a[yh]=a[(d[yh]|0)+(p+24)|0]|0;ug=c[g>>2]|0;if((ug|0)<256){sg=ug<<8;c[g>>2]=sg;lg=c[t>>2]<<8;c[t>>2]=lg;fg=c[Cg>>2]|0;if(fg>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[fg]|lg}c[Cg>>2]=fg+1;Dh=sg}else{Dh=ug}if((qg|0)>0){Ah=hg;Bh=qg;Ch=Dh;A=933}else{Eh=hg;Fh=Dh}}if((A|0)==933){while(1){A=0;ug=Bh-1|0;sg=32-Bh+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+1008)|0;fg=(ca(d[sg]|0,Ch)|0)>>8;lg=Ch-fg|0;c[g>>2]=lg;eg=c[t>>2]|0;do{if((eg|0)<(lg|0)){a[sg]=a[(d[sg]|0)+(p+24)|0]|0;gg=c[g>>2]|0;if((gg|0)>=256){Gh=0;Hh=gg;break}mg=gg<<8;c[g>>2]=mg;gg=c[t>>2]<<8;c[t>>2]=gg;ig=c[Cg>>2]|0;if(ig>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[ig]|gg}c[Cg>>2]=ig+1;Gh=0;Hh=mg}else{c[t>>2]=eg-lg;a[sg]=a[(d[sg]|0)+(p+280)|0]|0;c[g>>2]=fg;if((fg|0)>=256){Gh=1;Hh=fg;break}mg=fg<<8;c[g>>2]=mg;ig=c[t>>2]<<8;c[t>>2]=ig;gg=c[Cg>>2]|0;if(gg>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[gg]|ig}c[Cg>>2]=gg+1;Gh=1;Hh=mg}}while(0);fg=(Gh<<ug)+Ah|0;if((ug|0)>0){Ah=fg;Bh=ug;Ch=Hh;A=933}else{Eh=fg;Fh=Hh;break}}}hg=Eh-1|0;do{if((Eh|0)>0){qg=3;fg=8;sg=0;lg=Fh;while(1){Ih=qg+4+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+80)|0;eg=(ca(d[Ih]|0,lg)|0)>>8;mg=lg-eg|0;c[g>>2]=mg;gg=c[t>>2]|0;if((gg|0)<(mg|0)){A=946;break}c[t>>2]=gg-mg;a[Ih]=a[(d[Ih]|0)+(p+280)|0]|0;c[g>>2]=eg;if((eg|0)<256){mg=eg<<8;c[g>>2]=mg;gg=c[t>>2]<<8;c[t>>2]=gg;ig=c[Cg>>2]|0;if(ig>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[ig]|gg}c[Cg>>2]=ig+1;Jh=mg}else{Jh=eg}eg=fg+sg|0;mg=qg+1|0;if((mg|0)>=28){Kh=eg;Lh=mg;Mh=Jh;break}qg=mg;fg=fg<<1;sg=eg;lg=Jh}if((A|0)==946){A=0;a[Ih]=a[(d[Ih]|0)+(p+24)|0]|0;lg=c[g>>2]|0;if((lg|0)<256){fg=lg<<8;c[g>>2]=fg;ug=c[t>>2]<<8;c[t>>2]=ug;eg=c[Cg>>2]|0;if(eg>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[eg]|ug}c[Cg>>2]=eg+1;Nh=fg}else{Nh=lg}if((qg|0)>0){Kh=sg;Lh=qg;Mh=Nh}else{Oh=sg;Ph=Nh;break}}while(1){lg=Lh-1|0;fg=32-Lh+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+80)|0;eg=(ca(d[fg]|0,Mh)|0)>>8;ug=Mh-eg|0;c[g>>2]=ug;mg=c[t>>2]|0;do{if((mg|0)<(ug|0)){a[fg]=a[(d[fg]|0)+(p+24)|0]|0;ig=c[g>>2]|0;if((ig|0)>=256){Qh=0;Rh=ig;break}gg=ig<<8;c[g>>2]=gg;ig=c[t>>2]<<8;c[t>>2]=ig;Tf=c[Cg>>2]|0;if(Tf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Tf]|ig}c[Cg>>2]=Tf+1;Qh=0;Rh=gg}else{c[t>>2]=mg-ug;a[fg]=a[(d[fg]|0)+(p+280)|0]|0;c[g>>2]=eg;if((eg|0)>=256){Qh=1;Rh=eg;break}gg=eg<<8;c[g>>2]=gg;Tf=c[t>>2]<<8;c[t>>2]=Tf;ig=c[Cg>>2]|0;if(ig>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[ig]|Tf}c[Cg>>2]=ig+1;Qh=1;Rh=gg}}while(0);eg=(Qh<<lg)+Kh|0;if((lg|0)>0){Kh=eg;Lh=lg;Mh=Rh}else{Oh=eg;Ph=Rh;break}}}else{Oh=2147483647;Ph=Fh}}while(0);if((If|0)>0){sg=(dg|0)>0;qg=dg+1&65535;eg=pg+8|0;fg=bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+68|0;ug=bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+112|0;mg=Oh;gg=hg;ig=jg;Tf=0;kg=xh;Pf=xh;Of=0;ng=Ph;while(1){Xf=(Of|0)!=0;do{if(Xf){if((b[Tf>>1]|0)!=0){Sh=0;break}Sh=e[Tf+2>>1]|0}else{Sh=0}}while(0);if(sg){Wf=mg;Ef=gg;ag=ig;Vf=Tf;Uf=kg;Zf=0;Yf=0;Nf=Sh;Hf=0;Be=ng;while(1){do{if(Xf){Ff=(b[Vf>>1]|0)>(Hf|0)?Vf:Vf+4|0;if((b[Ff>>1]|0)!=(Hf+1|0)){Th=0;Uh=Ff;break}Th=e[Ff+2>>1]|0;Uh=Ff}else{Th=Nf;Uh=Vf}}while(0);do{if((Uf|0)==0){Vh=0;Wh=0}else{lg=Hf>>1;Ff=(lg|0)>(b[Uf>>1]|0)?Uf+4|0:Uf;if((lg|0)!=(b[Ff>>1]|0)){Vh=0;Wh=Ff;break}Vh=e[Ff+2>>1]|0;Wh=Ff}}while(0);do{if((Yf|Nf|Zf|Th|Vh|0)==0){if((Wf|0)!=0){Ff=Wf-1|0;if(Xf){lg=(b[Uh>>1]|0)-Hf-2|0;Xh=(Ff|0)>(lg|0)?lg:Ff}else{lg=dg-Hf-1|0;Xh=(Ff|0)>(lg|0)?lg:Ff}if((Wh|0)==0){Yh=Xh}else{lg=(b[Wh>>1]<<1)-Hf-1|0;Yh=(Xh|0)>(lg|0)?lg:Xh}Zh=Yh+Hf|0;_h=0;$h=ag;ai=Ef;bi=Ff-Yh|0;ci=Be;break}Ff=Ef-1|0;do{if((Ef|0)>0){lg=3;_f=8;Df=0;Sf=Be;while(1){di=lg+4+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+80)|0;Mf=(ca(d[di]|0,Sf)|0)>>8;nf=Sf-Mf|0;c[g>>2]=nf;Bf=c[t>>2]|0;if((Bf|0)<(nf|0)){A=1029;break}c[t>>2]=Bf-nf;a[di]=a[(d[di]|0)+(p+280)|0]|0;c[g>>2]=Mf;if((Mf|0)<256){nf=Mf<<8;c[g>>2]=nf;Bf=c[t>>2]<<8;c[t>>2]=Bf;nd=c[Cg>>2]|0;if(nd>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[nd]|Bf}c[Cg>>2]=nd+1;ei=nf}else{ei=Mf}Mf=_f+Df|0;nf=lg+1|0;if((nf|0)>=28){fi=Mf;gi=nf;hi=ei;break}lg=nf;_f=_f<<1;Df=Mf;Sf=ei}if((A|0)==1029){A=0;a[di]=a[(d[di]|0)+(p+24)|0]|0;Sf=c[g>>2]|0;if((Sf|0)<256){_f=Sf<<8;c[g>>2]=_f;Mf=c[t>>2]<<8;c[t>>2]=Mf;nf=c[Cg>>2]|0;if(nf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[nf]|Mf}c[Cg>>2]=nf+1;ii=_f}else{ii=Sf}if((lg|0)>0){fi=Df;gi=lg;hi=ii}else{ji=Df;ki=ii;break}}while(1){Sf=gi-1|0;_f=32-gi+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+80)|0;nf=(ca(d[_f]|0,hi)|0)>>8;Mf=hi-nf|0;c[g>>2]=Mf;nd=c[t>>2]|0;do{if((nd|0)<(Mf|0)){a[_f]=a[(d[_f]|0)+(p+24)|0]|0;Bf=c[g>>2]|0;if((Bf|0)>=256){li=0;mi=Bf;break}rf=Bf<<8;c[g>>2]=rf;Bf=c[t>>2]<<8;c[t>>2]=Bf;yf=c[Cg>>2]|0;if(yf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[yf]|Bf}c[Cg>>2]=yf+1;li=0;mi=rf}else{c[t>>2]=nd-Mf;a[_f]=a[(d[_f]|0)+(p+280)|0]|0;c[g>>2]=nf;if((nf|0)>=256){li=1;mi=nf;break}rf=nf<<8;c[g>>2]=rf;yf=c[t>>2]<<8;c[t>>2]=yf;Bf=c[Cg>>2]|0;if(Bf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Bf]|yf}c[Cg>>2]=Bf+1;li=1;mi=rf}}while(0);nf=(li<<Sf)+fi|0;if((Sf|0)>0){fi=nf;gi=Sf;hi=mi}else{ji=nf;ki=mi;break}}}else{ji=2147483647;ki=Be}}while(0);Df=(ca(d[ug]|0,ki)|0)>>8;lg=ki-Df|0;c[g>>2]=lg;nf=c[t>>2]|0;x:do{if((nf|0)<(lg|0)){ni=0;oi=-4;pi=ug;A=1051}else{_f=0;Mf=1;nd=-4;rf=ug;Bf=Df;yf=lg;Qf=nf;while(1){c[t>>2]=Qf-yf;a[rf]=a[(d[rf]|0)+(p+280)|0]|0;c[g>>2]=Bf;if((Bf|0)<256){jf=Bf<<8;c[g>>2]=jf;Rf=c[t>>2]<<8;c[t>>2]=Rf;Kf=c[Cg>>2]|0;if(Kf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Kf]|Rf}c[Cg>>2]=Kf+1;qi=jf}else{qi=Bf}jf=Mf+_f|0;Kf=nd+1|0;if((Kf|0)>=28){ri=jf;si=Kf;ti=qi;A=1061;break x}Rf=nd+5+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+112)|0;Gf=(ca(d[Rf]|0,qi)|0)>>8;Lf=qi-Gf|0;c[g>>2]=Lf;Cf=c[t>>2]|0;if((Cf|0)<(Lf|0)){ni=jf;oi=Kf;pi=Rf;A=1051;break}else{_f=jf;Mf=Mf<<((Kf|0)>0);nd=Kf;rf=Rf;Bf=Gf;yf=Lf;Qf=Cf}}}}while(0);if((A|0)==1051){A=0;a[pi]=a[(d[pi]|0)+(p+24)|0]|0;nf=c[g>>2]|0;if((nf|0)<256){lg=nf<<8;c[g>>2]=lg;Df=c[t>>2]<<8;c[t>>2]=Df;Qf=c[Cg>>2]|0;if(Qf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Qf]|Df}c[Cg>>2]=Qf+1;ui=lg}else{ui=nf}if((oi|0)>0){ri=ni;si=oi;ti=ui;A=1061}else{vi=ni;wi=ui}}if((A|0)==1061){while(1){A=0;nf=si-1|0;lg=32-si+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+112)|0;Qf=(ca(d[lg]|0,ti)|0)>>8;Df=ti-Qf|0;c[g>>2]=Df;yf=c[t>>2]|0;do{if((yf|0)<(Df|0)){a[lg]=a[(d[lg]|0)+(p+24)|0]|0;Bf=c[g>>2]|0;if((Bf|0)>=256){xi=0;yi=Bf;break}rf=Bf<<8;c[g>>2]=rf;Bf=c[t>>2]<<8;c[t>>2]=Bf;nd=c[Cg>>2]|0;if(nd>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[nd]|Bf}c[Cg>>2]=nd+1;xi=0;yi=rf}else{c[t>>2]=yf-Df;a[lg]=a[(d[lg]|0)+(p+280)|0]|0;c[g>>2]=Qf;if((Qf|0)>=256){xi=1;yi=Qf;break}rf=Qf<<8;c[g>>2]=rf;nd=c[t>>2]<<8;c[t>>2]=nd;Bf=c[Cg>>2]|0;if(Bf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Bf]|nd}c[Cg>>2]=Bf+1;xi=1;yi=rf}}while(0);Qf=(xi<<nf)+ri|0;if((nf|0)>0){ri=Qf;si=nf;ti=yi;A=1061}else{vi=Qf;wi=yi;break}}}Qf=(vi<<1)+2|0;lg=(ca(d[fg]|0,wi)|0)>>8;Df=wi-lg|0;c[g>>2]=Df;yf=c[t>>2]|0;do{if((yf|0)<(Df|0)){a[fg]=a[(d[fg]|0)+(p+24)|0]|0;rf=c[g>>2]|0;if((rf|0)>=256){zi=0;Ai=rf;break}Bf=rf<<8;c[g>>2]=Bf;rf=c[t>>2]<<8;c[t>>2]=rf;nd=c[Cg>>2]|0;if(nd>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[nd]|rf}c[Cg>>2]=nd+1;zi=0;Ai=Bf}else{c[t>>2]=yf-Df;a[fg]=a[(d[fg]|0)+(p+280)|0]|0;c[g>>2]=lg;if((lg|0)>=256){zi=1;Ai=lg;break}Bf=lg<<8;c[g>>2]=Bf;nd=c[t>>2]<<8;c[t>>2]=nd;rf=c[Cg>>2]|0;if(rf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[rf]|nd}c[Cg>>2]=rf+1;zi=1;Ai=Bf}}while(0);lg=zi|Qf;b[ag>>1]=Hf;b[ag+2>>1]=lg;Zh=Hf;_h=lg;$h=ag+4|0;ai=Ff;bi=ji;ci=Ai}else{lg=(Yf>>1)+(Nf&-2)+((Zf>>1)*3|0)+(Th>>1)+(Vh>>>1)|0;Df=lg>>>0>65535>>>0;yf=Df?lg>>>16:lg;lg=Df?16:0;if((yf&65280|0)==0){Bi=lg;Ci=yf}else{Bi=lg|8;Ci=yf>>>8}yf=(d[1359664+Ci|0]|0)+Bi|0;lg=bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48+yf|0;Df=(ca(d[lg]|0,Be)|0)>>8;Bf=Be-Df|0;c[g>>2]=Bf;rf=c[t>>2]|0;if((rf|0)<(Bf|0)){a[lg]=a[(d[lg]|0)+(p+24)|0]|0;nd=c[g>>2]|0;if((nd|0)>=256){Zh=Hf;_h=0;$h=ag;ai=Ef;bi=Wf;ci=nd;break}Mf=nd<<8;c[g>>2]=Mf;nd=c[t>>2]<<8;c[t>>2]=nd;_f=c[Cg>>2]|0;if(_f>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[_f]|nd}c[Cg>>2]=_f+1;Zh=Hf;_h=0;$h=ag;ai=Ef;bi=Wf;ci=Mf;break}c[t>>2]=rf-Bf;a[lg]=a[(d[lg]|0)+(p+280)|0]|0;c[g>>2]=Df;if((Df|0)<256){lg=Df<<8;c[g>>2]=lg;Bf=c[t>>2]<<8;c[t>>2]=Bf;rf=c[Cg>>2]|0;if(rf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[rf]|Bf}c[Cg>>2]=rf+1;Di=lg}else{Di=Df}Df=yf+2|0;lg=yf-4|0;y:do{if((lg|0)<28){rf=bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48+(Df<<5)+yf|0;Bf=(ca(d[rf]|0,Di)|0)>>8;Mf=Di-Bf|0;c[g>>2]=Mf;_f=c[t>>2]|0;if((_f|0)<(Mf|0)){Ei=0;Fi=lg;Gi=rf}else{nd=0;Cf=(lg|0)>-1?1<<lg:1;Lf=lg;Gf=rf;rf=Bf;Bf=Mf;Mf=_f;while(1){c[t>>2]=Mf-Bf;a[Gf]=a[(d[Gf]|0)+(p+280)|0]|0;c[g>>2]=rf;if((rf|0)<256){_f=rf<<8;c[g>>2]=_f;Rf=c[t>>2]<<8;c[t>>2]=Rf;Kf=c[Cg>>2]|0;if(Kf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Kf]|Rf}c[Cg>>2]=Kf+1;Hi=_f}else{Hi=rf}_f=Cf+nd|0;Kf=Lf+1|0;if((Kf|0)>=28){Ii=_f;Ji=Kf;Ki=Hi;A=1005;break y}Rf=Lf+5+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48+(Df<<5))|0;jf=(ca(d[Rf]|0,Hi)|0)>>8;Af=Hi-jf|0;c[g>>2]=Af;ff=c[t>>2]|0;if((ff|0)<(Af|0)){Ei=_f;Fi=Kf;Gi=Rf;break}else{nd=_f;Cf=Cf<<((Kf|0)>0);Lf=Kf;Gf=Rf;rf=jf;Bf=Af;Mf=ff}}}a[Gi]=a[(d[Gi]|0)+(p+24)|0]|0;Mf=c[g>>2]|0;if((Mf|0)<256){Bf=Mf<<8;c[g>>2]=Bf;rf=c[t>>2]<<8;c[t>>2]=rf;Gf=c[Cg>>2]|0;if(Gf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Gf]|rf}c[Cg>>2]=Gf+1;Li=Bf}else{Li=Mf}if((Fi|0)>0){Ii=Ei;Ji=Fi;Ki=Li;A=1005}else{Mi=Ei;Ni=Li}}else{Ii=0;Ji=lg;Ki=Di;A=1005}}while(0);if((A|0)==1005){while(1){A=0;lg=Ji-1|0;yf=32-Ji+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48+(Df<<5))|0;Ff=(ca(d[yf]|0,Ki)|0)>>8;Qf=Ki-Ff|0;c[g>>2]=Qf;Mf=c[t>>2]|0;do{if((Mf|0)<(Qf|0)){a[yf]=a[(d[yf]|0)+(p+24)|0]|0;Bf=c[g>>2]|0;if((Bf|0)>=256){Oi=0;Pi=Bf;break}Gf=Bf<<8;c[g>>2]=Gf;Bf=c[t>>2]<<8;c[t>>2]=Bf;rf=c[Cg>>2]|0;if(rf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[rf]|Bf}c[Cg>>2]=rf+1;Oi=0;Pi=Gf}else{c[t>>2]=Mf-Qf;a[yf]=a[(d[yf]|0)+(p+280)|0]|0;c[g>>2]=Ff;if((Ff|0)>=256){Oi=1;Pi=Ff;break}Gf=Ff<<8;c[g>>2]=Gf;rf=c[t>>2]<<8;c[t>>2]=rf;Bf=c[Cg>>2]|0;if(Bf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Bf]|rf}c[Cg>>2]=Bf+1;Oi=1;Pi=Gf}}while(0);Ff=(Oi<<lg)+Ii|0;if((lg|0)>0){Ii=Ff;Ji=lg;Ki=Pi;A=1005}else{Mi=Ff;Ni=Pi;break}}}Df=(Mi<<1)+2|0;Ff=(a[1319992+(Zf&255)|0]|0)+20+((a[1319992+(Nf&255)|0]|0)*3|0)+(bg+(Ag*533028|0)+8+(og*66624|0)+($f*16656|0)+48)|0;yf=(ca(d[Ff]|0,Ni)|0)>>8;Qf=Ni-yf|0;c[g>>2]=Qf;Mf=c[t>>2]|0;do{if((Mf|0)<(Qf|0)){a[Ff]=a[(d[Ff]|0)+(p+24)|0]|0;Gf=c[g>>2]|0;if((Gf|0)>=256){Qi=0;Ri=Gf;break}Bf=Gf<<8;c[g>>2]=Bf;Gf=c[t>>2]<<8;c[t>>2]=Gf;rf=c[Cg>>2]|0;if(rf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[rf]|Gf}c[Cg>>2]=rf+1;Qi=0;Ri=Bf}else{c[t>>2]=Mf-Qf;a[Ff]=a[(d[Ff]|0)+(p+280)|0]|0;c[g>>2]=yf;if((yf|0)>=256){Qi=1;Ri=yf;break}Bf=yf<<8;c[g>>2]=Bf;rf=c[t>>2]<<8;c[t>>2]=rf;Gf=c[Cg>>2]|0;if(Gf>>>0<(c[Bg>>2]|0)>>>0){c[t>>2]=d[Gf]|rf}c[Cg>>2]=Gf+1;Qi=1;Ri=Bf}}while(0);yf=Qi|Df;b[ag>>1]=Hf;b[ag+2>>1]=yf;Zh=Hf;_h=yf;$h=ag+4|0;ai=Ef;bi=Wf;ci=Ri}}while(0);yf=Zh+1|0;if((yf|0)<(dg|0)){Wf=bi;Ef=ai;ag=$h;Vf=Uh;Uf=Wh;Zf=_h;Yf=Nf;Nf=Th;Hf=yf;Be=ci}else{Si=bi;Ti=ai;Ui=$h;Vi=Wh;Wi=ci;break}}}else{Si=mg;Ti=gg;Ui=ig;Vi=kg;Wi=ng}Be=Ui+4|0;b[Ui>>1]=qg;do{if((Vi|0)==0){Xi=Pf;Yi=0}else{if((Of&1|0)==0){Xi=Pf;Yi=Pf;break}Hf=(c[eg>>2]|0)+1|0;Nf=Vi;while(1){Yf=Nf+4|0;if((b[Nf>>1]|0)==(Hf|0)){Xi=Yf;Yi=Yf;break}else{Nf=Yf}}}}while(0);Nf=Of+1|0;if((Nf|0)<(If|0)){mg=Si;gg=Ti;Tf=ig;ig=Be;kg=Yi;Pf=Xi;Of=Nf;ng=Wi}else{Zi=Be;_i=qg;break}}}else{Zi=jg;_i=dg+1&65535}b[Zi>>1]=_i;$f=$f+1|0;}while(($f|0)<4);$f=og+1|0;qg=c[hf>>2]|0;if(($f|0)<(qg|0)){og=$f}else{$i=qg;break}}}else{$i=cg}og=c[xg>>2]|0;qg=c[Ng>>2]<<og;$f=16>>>(og>>>0);og=(Ag|0)==0;if(og){aj=$f}else{aj=$f>>c[lf>>2]}h1a(Lg,Qg,rg,tg,1,c[Ce>>2]|0,$i);if((qg|0)>=0){$f=aj>>1;ng=p+7548+(Ag*533028|0)|0;Of=p+7548+(Ag*533028|0)+4|0;Pf=(rg|0)>0;kg=bg+(Ag*533028|0)+8|0;ig=bg+(Ag*533028|0)+16|0;Tf=bg+(Ag*533028|0)+44|0;gg=bg+(Ag*533028|0)+40|0;mg=bg+(Ag*533028|0)+36|0;If=bg+(Ag*533028|0)+24|0;eg=0;fg=0;ug=0;while(1){sg=ca(ug,aj)|0;hg=ug+1|0;pg=ca(hg,aj)|0;do{if((c[Rg>>2]|0)==0){if((c[(c[mf>>2]|0)+688>>2]&512|0)!=0){bj=pg;cj=sg;break}Nf=sg-$f|0;bj=pg-$f|0;cj=(Nf|0)<0?0:Nf}else{bj=pg;cj=sg}}while(0);Nf=c[hf>>2]|0;if((Nf|0)>0){Hf=(ug|0)==0;Yf=0;Zf=0;while(1){Uf=Zf+3|0;Vf=Zf+1|0;ag=(Yf|0)!=0|0;do{Ef=bg+(Ag*533028|0)+8+(Yf*66624|0)+(ag*16656|0)|0;if(Hf){dj=0}else{Wf=c[hf>>2]|0;dj=Uf+Wf+(sg>>Wf-Yf)|0}Wf=c[hf>>2]|0;Xf=Uf+Wf+(pg>>Wf-Yf)|0;do{if((c[Rg>>2]|0)==0){if((c[(c[mf>>2]|0)+688>>2]&512|0)!=0){ej=Xf;fj=dj;break}yf=aj>>Vf+Wf;Ff=dj-yf|0;Qf=Xf-yf|0;ej=(Qf|0)<0?0:Qf;fj=(Ff|0)<0?0:Ff}else{ej=Xf;fj=dj}}while(0);Xf=c[bg+(Ag*533028|0)+8+(Yf*66624|0)+(ag*16656|0)+12>>2]|0;Wf=(Xf|0)>(fj|0)?fj:Xf;Be=(Xf|0)>(ej|0)?ej:Xf;do{if((Wf|0)!=(Be|0)){if((ag|0)!=0){z1a(p,Ef,Qg,Wf,Be,m+(Yf<<4)+(ag<<2)|0);break}Ff=Be+1|0;Qf=(Xf|0)>(Ff|0)?Ff:Xf;Ff=(Wf|0)!=0?Wf+1|0:0;yf=(Xf|0)>(Ff|0)?Ff:Xf;z1a(p,kg,Qg,yf,Qf,Gg);Ff=c[ig>>2]|0;if((yf|0)==0){gj=0;hj=0}else{Mf=ca(c[Tf>>2]|0,yf-1|0)|0;Bf=Mf+(c[gg>>2]|0)|0;Mf=c[(c[Ig>>2]|0)+(Bf<<2)>>2]|0;if((Mf|0)==0){ij=a1a(Qg,Bf)|0}else{ij=Mf}gj=ij+(c[mg>>2]<<1)|0;hj=yf}if((hj|0)<(Qf|0)){yf=(Ff|0)>0;Mf=hj;Bf=gj;while(1){Gf=ca(c[Tf>>2]|0,Mf)|0;rf=Gf+(c[gg>>2]|0)|0;Gf=c[(c[Ig>>2]|0)+(rf<<2)>>2]|0;if((Gf|0)==0){jj=a1a(Qg,rf)|0}else{jj=Gf}Gf=c[mg>>2]|0;rf=jj+(Gf<<1)|0;if(yf){Lf=(Mf|0)==0;Cf=0;do{do{if((Cf|0)==0){if(Lf){break}b[rf>>1]=(b[rf>>1]|0)+(b[Bf>>1]|0)}else{nd=Cf-1|0;nf=b[jj+(nd+Gf<<1)>>1]|0;ff=nf<<16>>16;if(Lf){Af=jj+(Cf+Gf<<1)|0;b[Af>>1]=(b[Af>>1]|0)+nf;break}Af=b[Bf+(Cf<<1)>>1]|0;jf=Af<<16>>16;Rf=jf+ff-(b[Bf+(nd<<1)>>1]|0)|0;do{if(nf<<16>>16>Af<<16>>16){if((Rf|0)<=(jf|0)){kj=jf;break}kj=(Rf|0)>(ff|0)?ff:Rf}else{if((jf|0)<=(Rf|0)){kj=jf;break}kj=(Rf|0)>(ff|0)?Rf:ff}}while(0);ff=jj+(Cf+Gf<<1)|0;b[ff>>1]=(e[ff>>1]|0)+kj}}while(0);Cf=Cf+1|0;}while((Cf|0)<(Ff|0))}Cf=Mf+1|0;if((Cf|0)<(Qf|0)){Mf=Cf;Bf=rf}else{break}}}Bf=c[ig>>2]|0;Mf=c[Jf>>2]|0;Qf=(c[If>>2]|0)+Mf|0;if((Qf|0)<0){lj=0}else{lj=(Qf|0)>512?512:Qf}Qf=d[6549120+(lj&31)|0]<<(lj>>5);Ff=(ca(Qf,c[zg>>2]|0)|0)>>3;if(!((Mf|0)!=-128&(Wf|0)<(Be|0))){break}Mf=(Bf|0)>0;yf=Wf;do{Cf=ca(c[Tf>>2]|0,yf)|0;Gf=Cf+(c[gg>>2]|0)|0;Cf=c[(c[Ig>>2]|0)+(Gf<<2)>>2]|0;if((Cf|0)==0){mj=a1a(Qg,Gf)|0}else{mj=Cf}Cf=c[mg>>2]|0;if(Mf){Gf=0;do{Lf=mj+(Gf+Cf<<1)|0;Df=b[Lf>>1]|0;lg=Df<<16>>16;do{if(Df<<16>>16<0){b[Lf>>1]=-((Ff-(ca(lg,Qf)|0)|0)>>>11)}else{if(!(Df<<16>>16>0)){break}b[Lf>>1]=((ca(lg,Qf)|0)+Ff|0)>>>11}}while(0);Gf=Gf+1|0;}while((Gf|0)<(Bf|0))}yf=yf+1|0;}while((yf|0)<(Be|0))}}while(0);ag=ag+1|0;}while((ag|0)<4);ag=Yf+1|0;Vf=~Yf;Uf=c[hf>>2]|0;if((ag|0)<(Uf|0)){Yf=ag;Zf=Vf}else{nj=Uf;break}}}else{nj=Nf}z:do{if((fg|0)<(bj|0)){Zf=fg;Yf=nj;while(1){i1a(vg,Lg,Qg,c[Hg>>2]|0,rg,tg,1,c[Ce>>2]|0,Yf,Zf);pg=Zf+4|0;if((pg|0)>=(bj|0)){oj=pg;break z}Zf=pg;Yf=c[hf>>2]|0}}else{oj=fg}}while(0);do{if((c[Jf>>2]|0)==-128){if(!((eg|0)<(bj|0)&(eg|0)<(tg|0))){pj=eg;break}Nf=eg-bj|0;Yf=eg-tg|0;Zf=Nf>>>0>Yf>>>0?Nf:Yf;Yf=eg;do{Nf=c[(c[Ig>>2]|0)+(Yf<<2)>>2]|0;if((Nf|0)==0){qj=a1a(Qg,Yf)|0}else{qj=Nf}if(Pf){Nf=0;do{pg=qj+(Nf<<1)|0;b[pg>>1]=b[pg>>1]<<4;Nf=Nf+1|0;}while((Nf|0)<(rg|0))}Yf=Yf+1|0;}while((Yf|0)<(bj|0)&(Yf|0)<(tg|0));pj=eg-Zf|0}else{pj=eg}}while(0);Yf=c[Ae>>2]|0;Nf=c[xg>>2]|0;pg=Yf<<Nf;sg=c[Ng>>2]|0;Hf=sg<<Nf;Uf=16>>>(Nf>>>0);if(og){rj=Uf<<1;sj=Uf;tj=Uf;uj=Nf}else{Vf=c[je>>2]|0;rj=Uf<<1>>Vf;sj=Uf>>c[lf>>2];tj=Uf>>Vf;uj=Vf+Nf|0}Vf=c[1335352+(uj<<2)>>2]|0;Uf=c[j>>2]|0;ag=c[Uf+32+(Ag<<2)>>2]|0;dg=c[Uf+(Ag<<2)>>2]|0;Uf=c[ng>>2]|0;jg=c[Of>>2]|0;A:do{if((c[Rg>>2]|0)==0){if((c[(c[mf>>2]|0)+688>>2]&512|0)!=0){A=1171;break}if((pg|0)<0){break}Be=(tj|0)/2|0;Wf=(ca(sj,ug)|0)-((sj|0)/2|0)|0;Xf=ug-1|0;Ef=(ag|0)>111?16:ag<<4;yf=(Xf|0)<0;Bf=(Wf|0)<0;Ff=ca(Wf,-rj|0)|0;Qf=Wf+sj|0;Mf=Ef*3|0;Gf=Mf+Ef|0;Cf=Gf+Ef|0;rf=0;lg=Yf;Lf=Nf;Df=sg;while(1){ff=(ca(rf,tj)|0)-Be|0;Rf=rf-1|0;jf=lg<<Lf;Af=ca(jf,Xf)|0;nf=Af+Rf|0;Sf=c[Dg>>2]|0;nd=Sf+(nf*10|0)|0;Kf=Sf+((Af+rf|0)*10|0)|0;Af=nf+jf|0;nf=Sf+(Af*10|0)|0;_f=Sf+((Af+1|0)*10|0)|0;Af=c[Kg>>2]|0;if((Rf|0)<0){vj=_f;wj=_f;xj=Kf;yj=Kf}else{Rf=(rf|0)<(jf|0);vj=Rf?_f:nf;wj=nf;xj=Rf?Kf:nd;yj=nd}if(yf){zj=vj;Aj=wj;Bj=vj;Cj=wj}else{nd=(Df<<Lf|0)>(ug|0);zj=nd?vj:xj;Aj=nd?wj:yj;Bj=xj;Cj=yj}if((ff|0)<0){Dj=Vf+(-ff|0)|0;Ej=0;Fj=ff+tj|0}else{Dj=Vf;Ej=ff;Fj=tj}ff=(Ej+Fj|0)>(Uf|0)?Uf-Ej|0:Fj;if(Bf){Gj=Dj+Ff|0;Hj=0;Ij=Qf}else{Gj=Dj;Hj=Wf;Ij=sj}nd=(Hj+Ij|0)>(jg|0)?jg-Hj|0:Ij;if(!((ff|0)<1|(nd|0)<1)){Kf=dg+((ca(Hj,ag)|0)+Ej)|0;Rf=Af+Mf|0;c[n>>2]=Rf;nf=Af+Gf|0;wtb(p,Rf,Af,ag,Ej,Hj,ff,nd,Cj,Ag,Uf,jg);_f=Cj+8|0;jf=a[_f]|0;Sf=Bj+8|0;tf=a[Sf]|0;do{if((jf&1)==0){A=1192}else{if((tf&1)==0){A=1192;break}Jj=(d[Cj+6|0]|0)-(d[Bj+6|0]|0)|(d[Cj+5|0]|0)-(d[Bj+5|0]|0)|(d[Cj+7|0]|0)-(d[Bj+7|0]|0)}}while(0);if((A|0)==1192){A=0;Jj=(b[Cj>>1]|0)-(b[Bj>>1]|0)|(tf^jf)&1|(b[Cj+2>>1]|0)-(b[Bj+2>>1]|0)|(d[Cj+4|0]|0)-(d[Bj+4|0]|0)}if((Jj|0)==0){c[Fg>>2]=Rf;Kj=nf}else{c[Fg>>2]=nf;wtb(p,nf,Af,ag,Ej,Hj,ff,nd,Bj,Ag,Uf,jg);Kj=Af+Cf|0}zf=a[_f]|0;sf=Aj+8|0;xf=a[sf]|0;do{if((zf&1)==0){A=1199}else{if((xf&1)==0){A=1199;break}Lj=(d[Cj+6|0]|0)-(d[Aj+6|0]|0)|(d[Cj+5|0]|0)-(d[Aj+5|0]|0)|(d[Cj+7|0]|0)-(d[Aj+7|0]|0)}}while(0);if((A|0)==1199){A=0;Lj=(b[Cj>>1]|0)-(b[Aj>>1]|0)|(xf^zf)&1|(b[Cj+2>>1]|0)-(b[Aj+2>>1]|0)|(d[Cj+4|0]|0)-(d[Aj+4|0]|0)}do{if((Lj|0)==0){c[Eg>>2]=c[n>>2];Mj=Kj}else{nf=a[Sf]|0;do{if((nf&1)==0){A=1205}else{if((xf&1)==0){A=1205;break}Nj=(d[Bj+6|0]|0)-(d[Aj+6|0]|0)|(d[Bj+5|0]|0)-(d[Aj+5|0]|0)|(d[Bj+7|0]|0)-(d[Aj+7|0]|0)}}while(0);if((A|0)==1205){A=0;Nj=(b[Bj>>1]|0)-(b[Aj>>1]|0)|(nf^xf)&1|(b[Bj+2>>1]|0)-(b[Aj+2>>1]|0)|(d[Bj+4|0]|0)-(d[Aj+4|0]|0)}if((Nj|0)==0){c[Eg>>2]=c[Fg>>2];Mj=Kj;break}else{c[Eg>>2]=Kj;wtb(p,Kj,Af,ag,Ej,Hj,ff,nd,Aj,Ag,Uf,jg);Mj=Kj+Ef|0;break}}}while(0);xf=a[_f]|0;zf=a[zj+8|0]|0;do{if((xf&1)==0){A=1212}else{if((zf&1)==0){A=1212;break}Oj=(d[Cj+6|0]|0)-(d[zj+6|0]|0)|(d[Cj+5|0]|0)-(d[zj+5|0]|0)|(d[Cj+7|0]|0)-(d[zj+7|0]|0)}}while(0);if((A|0)==1212){A=0;Oj=(b[Cj>>1]|0)-(b[zj>>1]|0)|(zf^xf)&1|(b[Cj+2>>1]|0)-(b[zj+2>>1]|0)|(d[Cj+4|0]|0)-(d[zj+4|0]|0)}do{if((Oj|0)==0){c[Jg>>2]=c[n>>2]}else{_f=a[Sf]|0;do{if((_f&1)==0){A=1218}else{if((zf&1)==0){A=1218;break}Pj=(d[Bj+6|0]|0)-(d[zj+6|0]|0)|(d[Bj+5|0]|0)-(d[zj+5|0]|0)|(d[Bj+7|0]|0)-(d[zj+7|0]|0)}}while(0);if((A|0)==1218){A=0;Pj=(b[Bj>>1]|0)-(b[zj>>1]|0)|(_f^zf)&1|(b[Bj+2>>1]|0)-(b[zj+2>>1]|0)|(d[Bj+4|0]|0)-(d[zj+4|0]|0)}if((Pj|0)==0){c[Jg>>2]=c[Fg>>2];break}nf=a[sf]|0;do{if((nf&1)==0){A=1224}else{if((zf&1)==0){A=1224;break}Qj=(d[Aj+6|0]|0)-(d[zj+6|0]|0)|(d[Aj+5|0]|0)-(d[zj+5|0]|0)|(d[Aj+7|0]|0)-(d[zj+7|0]|0)}}while(0);if((A|0)==1224){A=0;Qj=(b[Aj>>1]|0)-(b[zj>>1]|0)|(nf^zf)&1|(b[Aj+2>>1]|0)-(b[zj+2>>1]|0)|(d[Aj+4|0]|0)-(d[zj+4|0]|0)}if((Qj|0)==0){c[Jg>>2]=c[Eg>>2];break}else{c[Jg>>2]=Mj;wtb(p,Mj,Af,ag,Ej,Hj,ff,nd,zj,Ag,Uf,jg);break}}}while(0);we[c[l>>2]&127](Gj,rj,n,ff,nd,Ej,Hj,ag,Qg,1,Kf)}Af=rf+1|0;if((Af|0)>(pg|0)){break A}rf=Af;lg=c[Ae>>2]|0;Lf=c[xg>>2]|0;Df=c[Ng>>2]|0}}else{A=1171}}while(0);do{if((A|0)==1171){A=0;if((Hf|0)==(ug|0)){break}pg=ca(sj,ug)|0;Vf=ca(sj,hg)|0;sg=(jg|0)>(Vf|0)?Vf:jg;if((pg|0)>=(sg|0)){break}Vf=(Uf|0)>0;Nf=pg;do{pg=c[(c[Ig>>2]|0)+(Nf<<2)>>2]|0;if(Vf){Yf=ca(Nf,ag)|0;Df=0;do{Lf=(b[pg+(Df<<1)>>1]|0)+2056|0;lg=Lf>>4;if(lg>>>0>255>>>0){Rj=(Lf>>31^255)&255}else{Rj=lg&255}a[dg+(Df+Yf)|0]=Rj;Df=Df+1|0;}while((Df|0)<(Uf|0))}Nf=Nf+1|0;}while((Nf|0)<(sg|0))}}while(0);Uf=c[wg>>2]|0;dg=(Uf|0)>(cj|0)?cj:Uf;ag=(Uf|0)>(bj|0)?bj:Uf;if((dg|0)<(ag|0)){Uf=dg;while(1){dg=Uf+1|0;b1a(Qg,Uf);if((dg|0)<(ag|0)){Uf=dg}else{break}}}if((hg|0)>(qg|0)){break}else{eg=pj;fg=oj;ug=hg}}}c1a(Qg);Ag=Ag+1|0;}while((Ag|0)<(c[Pg>>2]|0))}Itb(f);if((c[(c[mf>>2]|0)+688>>2]&2048|0)==0){Sj=YHb(s,c[j>>2]|0)|0}else{Sj=YHb(s,c[o+3088>>2]|0)|0}if((Sj|0)<0){ha=Sj;i=k;return ha|0}c[h>>2]=1;h=c[o+540>>2]|0;Sj=c[o+536>>2]|0;o=h-Sj|0;if((h|0)!=(Sj|0)){ha=o;i=k;return ha|0}KIb(c[mf>>2]|0,16,2357152,(ga=i,i=i+1|0,i=i+7&-8,c[ga>>2]=0,ga)|0);i=ga;ha=o;i=k;return ha|0}function y1a(a){a=a|0;var b=0;b=c[a+60>>2]|0;d1a(b+2143764|0);Ktb(b);return 0}function z1a(a,f,g,h,i,j){a=a|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;k=f+8|0;l=c[k>>2]|0;m=c[a+7492>>2]|0;n=(c[f+16>>2]|0)+m|0;if((n|0)<0){o=0}else{o=(n|0)>512?512:n}n=d[6549120+(o&31)|0]<<(o>>5);if((c[f+24>>2]|0)==(c[a+7464>>2]|0)){p=5}else{o=(ca(c[a+7520>>2]|0,n)|0)>>3;if((m|0)==-128){p=5}else{q=n;r=o}}if((p|0)==5){q=2048;r=0}if((h|0)==0){s=0;t=0}else{s=h;t=c[j>>2]|0}if((s|0)>=(i|0)){u=t;c[j>>2]=u;return}h=f+36|0;p=f+32|0;o=g|0;n=f+28|0;m=f+40|0;f=t;t=s;while(1){s=ca(c[h>>2]|0,t)|0;a=s+(c[p>>2]|0)|0;s=c[(c[o>>2]|0)+(a<<2)>>2]|0;if((s|0)==0){v=a1a(g,a)|0}else{v=s}s=c[n>>2]|0;mrc(v+(s<<1)|0,0,c[k>>2]<<1|0)|0;a=c[m>>2]|0;w=b[a+(f<<2)>>1]|0;x=f+1|0;if((w|0)<(l|0)){y=f;z=w;w=x;while(1){A=e[a+(y<<2)+2>>1]|0;B=A&1;b[v+(z+s<<1)>>1]=(((ca(A>>>1,q)|0)+r|0)>>>11^-B)+B;B=b[a+(w<<2)>>1]|0;A=w+1|0;if((B|0)<(l|0)){y=w;z=B;w=A}else{C=A;break}}}else{C=x}w=t+1|0;if((w|0)<(i|0)){f=C;t=w}else{u=C;break}}c[j>>2]=u;return}function A1a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=e+7528|0;n=e+7536|0;o=c[n>>2]|0;p=c[m>>2]<<o;q=o-f|0;r=(ca(p,h)|0)+g<<q;s=g+1<<q;t=(g|0)!=0;if(t){u=(c[e+2139660>>2]|0)+((r-1|0)*10|0)|0}else{u=778088}do{if((h|0)==0){v=u;w=778088;x=u}else{y=r-p|0;z=c[e+2139660>>2]|0;A=z+(y*10|0)|0;if(t){B=z+((y-1|0)*10|0)|0}else{B=u}if((s|0)>=(p|0)){v=B;w=A;x=B;break}if(!((g&1|0)==0|(f|0)==0)){v=B;w=A;x=B;break}v=z+(((1<<q)-p+r|0)*10|0)|0;w=A;x=B}}while(0);B=d[u+9|0]|0;s=d[w+9|0]|0;t=d[x+9|0]|0;x=d[v+9|0]|0;if((c[e+7348>>2]|0)!=0){A=1<<q;q=f&255;if((A|0)<=0){C=0;i=j;return C|0}z=e+2139660|0;y=0;while(1){D=(ca(y,p)|0)+r|0;E=0;do{F=D+E|0;G=c[z>>2]|0;mrc(G+(F*10|0)|0,0,5)|0;a[G+(F*10|0)+5|0]=-128;a[G+(F*10|0)+6|0]=-128;a[G+(F*10|0)+7|0]=-128;a[G+(F*10|0)+8|0]=1;a[G+(F*10|0)+9|0]=q;E=E+1|0;}while((E|0)<(A|0));E=y+1|0;if((E|0)<(A|0)){y=E}else{C=0;break}}i=j;return C|0}do{if((o|0)==(f|0)){H=25}else{y=t+4+x+(s+B<<1)+(e+3124)|0;A=e+12|0;q=c[A>>2]|0;z=(ca(d[y]|0,q)|0)>>8;r=q-z|0;c[A>>2]=r;q=e+8|0;p=c[q>>2]|0;if((p|0)>=(r|0)){c[q>>2]=p-r;a[y]=a[(d[y]|0)+(e+280)|0]|0;c[A>>2]=z;if((z|0)>=256){H=25;break}c[A>>2]=z<<8;z=c[q>>2]<<8;c[q>>2]=z;r=e+540|0;p=c[r>>2]|0;if(p>>>0<(c[e+544>>2]|0)>>>0){c[q>>2]=d[p]|z}c[r>>2]=p+1;H=25;break}a[y]=a[(d[y]|0)+(e+24)|0]|0;y=c[A>>2]|0;if((y|0)<256){c[A>>2]=y<<8;y=c[q>>2]<<8;c[q>>2]=y;A=e+540|0;p=c[A>>2]|0;if(p>>>0<(c[e+544>>2]|0)>>>0){c[q>>2]=d[p]|y}c[A>>2]=p+1}p=f+1|0;A=g<<1;y=h<<1;q=A1a(e,p,A,y)|0;if((q|0)<0){C=q;i=j;return C|0}q=A|1;r=A1a(e,p,q,y)|0;if((r|0)<0){C=r;i=j;return C|0}r=y|1;y=A1a(e,p,A,r)|0;if((y|0)<0){C=y;i=j;return C|0}y=A1a(e,p,q,r)|0;if((y|0)<0){C=y}else{break}i=j;return C|0}}while(0);do{if((H|0)==25){B=a[u+5|0]|0;s=B&255;x=a[u+6|0]|0;t=x&255;o=a[u+7|0]|0;y=o&255;r=d[u+4|0]|0;q=r<<1;p=q&256;A=d[w+4|0]|0;z=A<<1;E=z&256;D=(d[1359664+((E|0)==0?z:A>>>7)|0]|0)+(d[1359664+((p|0)==0?q:r>>>7)|0]|0)|0;r=(b[u>>1]|0)-(b[w>>1]|0)|0;q=(r|0)>-1?r:-r|0;r=q<<1;A=r>>>0>65535>>>0;z=A?q>>>15&65535:r;r=A?16:0;if((z&65280|0)==0){I=r;J=z}else{I=r|8;J=z>>>8}z=(d[1359664+J|0]|0)+I|0;r=(b[u+2>>1]|0)-(b[w+2>>1]|0)|0;A=(r|0)>-1?r:-r|0;r=A<<1;q=r>>>0>65535>>>0;F=q?A>>>15&65535:r;r=q?16:0;if((F&65280|0)==0){K=r;L=F}else{K=r|8;L=F>>>8}F=(d[1359664+L|0]|0)+K|0;r=(d[u+8|0]|0)+1+(d[w+8|0]|0)+(e+3124)|0;q=e+12|0;A=c[q>>2]|0;G=(ca(d[r]|0,A)|0)>>8;M=A-G|0;c[q>>2]=M;A=e+8|0;N=c[A>>2]|0;do{if((N|0)<(M|0)){a[r]=a[(d[r]|0)+(e+24)|0]|0;O=c[q>>2]|0;if((O|0)<256){P=O<<8;c[q>>2]=P;Q=c[A>>2]<<8;c[A>>2]=Q;R=e+540|0;S=c[R>>2]|0;if(S>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[S]|Q}c[R>>2]=S+1;T=P}else{T=O}O=e+7388|0;a:do{if((c[O>>2]|0)>1){P=((D<<5)+p&-32)+E|0;S=P+1152|0;R=e+3124+S|0;Q=(ca(d[R]|0,T)|0)>>8;U=T-Q|0;c[q>>2]=U;V=c[A>>2]|0;if((V|0)>=(U|0)){c[A>>2]=V-U;a[R]=a[(d[R]|0)+(e+280)|0]|0;c[q>>2]=Q;if((Q|0)>=256){W=0;break}c[q>>2]=Q<<8;Q=c[A>>2]<<8;c[A>>2]=Q;U=e+540|0;V=c[U>>2]|0;if(V>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[V]|Q}c[U>>2]=V+1;W=0;break}a[R]=a[(d[R]|0)+(e+24)|0]|0;R=c[q>>2]|0;if((R|0)<256){V=R<<8;c[q>>2]=V;U=c[A>>2]<<8;c[A>>2]=U;Q=e+540|0;X=c[Q>>2]|0;if(X>>>0<(c[e+544>>2]|0)>>>0){Y=d[X]|U;c[A>>2]=Y;Z=Y}else{Z=U}c[Q>>2]=X+1;_=V;$=Z}else{_=R;$=c[A>>2]|0}R=P+1153+(e+3124)|0;P=(ca(d[R]|0,_)|0)>>8;V=_-P|0;c[q>>2]=V;if(($|0)<(V|0)){aa=0;ba=R}else{X=e+540|0;Q=e+544|0;U=1;Y=R;R=P;P=V;V=$;while(1){c[A>>2]=V-P;a[Y]=a[(d[Y]|0)+(e+280)|0]|0;c[q>>2]=R;if((R|0)<256){da=R<<8;c[q>>2]=da;ea=c[A>>2]<<8;c[A>>2]=ea;fa=c[X>>2]|0;if(fa>>>0<(c[Q>>2]|0)>>>0){ga=d[fa]|ea;c[A>>2]=ga;ha=ga}else{ha=ea}c[X>>2]=fa+1;ia=da;ja=ha}else{ia=R;ja=c[A>>2]|0}da=U+1|0;fa=((U|0)>9?10:da)+S+(e+3124)|0;ea=(ca(d[fa]|0,ia)|0)>>8;ga=ia-ea|0;c[q>>2]=ga;if((ja|0)<(ga|0)){aa=U;ba=fa;break}else{U=da;Y=fa;R=ea;P=ga;V=ja}}}a[ba]=a[(d[ba]|0)+(e+24)|0]|0;V=c[q>>2]|0;if((V|0)<256){P=V<<8;c[q>>2]=P;R=c[A>>2]<<8;c[A>>2]=R;Y=e+540|0;U=c[Y>>2]|0;if(U>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[U]|R}c[Y>>2]=U+1;ka=P}else{ka=V}if((aa|0)<=0){W=1;break}V=e+540|0;P=e+544|0;U=2;Y=aa;R=ka;while(1){X=Y-1|0;Q=((X|0)>9?31:Y+21|0)+S+(e+3124)|0;ga=(ca(d[Q]|0,R)|0)>>8;ea=R-ga|0;c[q>>2]=ea;fa=c[A>>2]|0;do{if((fa|0)<(ea|0)){a[Q]=a[(d[Q]|0)+(e+24)|0]|0;da=c[q>>2]|0;if((da|0)>=256){la=0;ma=da;break}na=da<<8;c[q>>2]=na;da=c[A>>2]<<8;c[A>>2]=da;oa=c[V>>2]|0;if(oa>>>0<(c[P>>2]|0)>>>0){c[A>>2]=d[oa]|da}c[V>>2]=oa+1;la=0;ma=na}else{c[A>>2]=fa-ea;a[Q]=a[(d[Q]|0)+(e+280)|0]|0;c[q>>2]=ga;if((ga|0)>=256){la=1;ma=ga;break}na=ga<<8;c[q>>2]=na;oa=c[A>>2]<<8;c[A>>2]=oa;da=c[V>>2]|0;if(da>>>0<(c[P>>2]|0)>>>0){c[A>>2]=d[da]|oa}c[V>>2]=da+1;la=1;ma=na}}while(0);ga=la|U;if((X|0)<=0){W=ga;break a}U=ga<<1;Y=X;R=ma}}else{W=0}}while(0);R=c[O>>2]|0;if((W|0)>=(R|0)){KIb(c[e+4>>2]|0,16,2294096,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;C=-1094995529;i=j;return C|0}B1a(R,k,l,W,u,w,v);R=((W|0)!=0)<<4;Y=z+R<<5;U=Y+128|0;V=e+3124+U|0;P=c[q>>2]|0;S=d[V]|0;ga=(ca(S,P)|0)>>8;Q=P-ga|0;c[q>>2]=Q;P=c[A>>2]|0;do{if((P|0)<(Q|0)){a[V]=a[e+24+S|0]|0;if((Q|0)<256){ea=Q<<8;c[q>>2]=ea;fa=P<<8;c[A>>2]=fa;na=e+540|0;da=c[na>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){oa=d[da]|fa;c[A>>2]=oa;pa=oa}else{pa=fa}c[na>>2]=da+1;qa=ea;ra=pa}else{qa=Q;ra=P}ea=Y+129+(e+3124)|0;da=a[ea]|0;na=(ca(da&255,qa)|0)>>8;fa=qa-na|0;c[q>>2]=fa;if((ra|0)<(fa|0)){sa=0;ta=ea;ua=da}else{da=e+540|0;oa=e+544|0;va=1;wa=ea;ea=na;na=fa;fa=ra;while(1){c[A>>2]=fa-na;a[wa]=a[(d[wa]|0)+(e+280)|0]|0;c[q>>2]=ea;if((ea|0)<256){xa=ea<<8;c[q>>2]=xa;ya=c[A>>2]<<8;c[A>>2]=ya;za=c[da>>2]|0;if(za>>>0<(c[oa>>2]|0)>>>0){Aa=d[za]|ya;c[A>>2]=Aa;Ba=Aa}else{Ba=ya}c[da>>2]=za+1;Ca=xa;Da=Ba}else{Ca=ea;Da=c[A>>2]|0}xa=va+1|0;Ea=((va|0)>9?10:xa)+U+(e+3124)|0;za=(ca(d[Ea]|0,Ca)|0)>>8;ya=Ca-za|0;c[q>>2]=ya;if((Da|0)<(ya|0)){break}else{va=xa;wa=Ea;ea=za;na=ya;fa=Da}}sa=va;ta=Ea;ua=a[Ea]|0}a[ta]=a[(ua&255)+(e+24)|0]|0;fa=c[q>>2]|0;if((fa|0)<256){na=fa<<8;c[q>>2]=na;ea=c[A>>2]<<8;c[A>>2]=ea;wa=e+540|0;da=c[wa>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[da]|ea}c[wa>>2]=da+1;Fa=na}else{Fa=fa}b:do{if((sa|0)>0){fa=e+540|0;na=e+544|0;da=2;wa=sa;ea=Fa;while(1){oa=wa-1|0;ya=((oa|0)>9?31:wa+21|0)+U+(e+3124)|0;za=(ca(d[ya]|0,ea)|0)>>8;xa=ea-za|0;c[q>>2]=xa;Aa=c[A>>2]|0;do{if((Aa|0)<(xa|0)){a[ya]=a[(d[ya]|0)+(e+24)|0]|0;Ga=c[q>>2]|0;if((Ga|0)>=256){Ha=0;Ia=Ga;break}Ja=Ga<<8;c[q>>2]=Ja;Ga=c[A>>2]<<8;c[A>>2]=Ga;Ka=c[fa>>2]|0;if(Ka>>>0<(c[na>>2]|0)>>>0){c[A>>2]=d[Ka]|Ga}c[fa>>2]=Ka+1;Ha=0;Ia=Ja}else{c[A>>2]=Aa-xa;a[ya]=a[(d[ya]|0)+(e+280)|0]|0;c[q>>2]=za;if((za|0)>=256){Ha=1;Ia=za;break}Ja=za<<8;c[q>>2]=Ja;Ka=c[A>>2]<<8;c[A>>2]=Ka;Ga=c[fa>>2]|0;if(Ga>>>0<(c[na>>2]|0)>>>0){c[A>>2]=d[Ga]|Ka}c[fa>>2]=Ga+1;Ha=1;Ia=Ja}}while(0);za=Ha|da;if((oa|0)<=0){La=za;Ma=Ia;break b}da=za<<1;wa=oa;ea=Ia}}else{La=1;Ma=Fa}}while(0);va=((sa|0)>10?21:sa+11|0)+U+(e+3124)|0;ea=(ca(d[va]|0,Ma)|0)>>8;wa=Ma-ea|0;c[q>>2]=wa;da=c[A>>2]|0;do{if((da|0)<(wa|0)){a[va]=a[(d[va]|0)+(e+24)|0]|0;fa=c[q>>2]|0;if((fa|0)>=256){Na=0;Oa=fa;break}na=fa<<8;c[q>>2]=na;fa=c[A>>2]<<8;c[A>>2]=fa;X=e+540|0;za=c[X>>2]|0;if(za>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[za]|fa}c[X>>2]=za+1;Na=0;Oa=na}else{c[A>>2]=da-wa;a[va]=a[(d[va]|0)+(e+280)|0]|0;c[q>>2]=ea;if((ea|0)>=256){Na=1;Oa=ea;break}na=ea<<8;c[q>>2]=na;za=c[A>>2]<<8;c[A>>2]=za;X=e+540|0;fa=c[X>>2]|0;if(fa>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[fa]|za}c[X>>2]=fa+1;Na=1;Oa=na}}while(0);Pa=(La^-Na)+Na|0;Qa=Oa;Ra=c[A>>2]|0}else{ea=P-Q|0;c[A>>2]=ea;a[V]=a[e+280+S|0]|0;c[q>>2]=ga;if((ga|0)>=256){Pa=0;Qa=ga;Ra=ea;break}va=ga<<8;c[q>>2]=va;wa=ea<<8;c[A>>2]=wa;ea=e+540|0;da=c[ea>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){na=d[da]|wa;c[A>>2]=na;Sa=na}else{Sa=wa}c[ea>>2]=da+1;Pa=0;Qa=va;Ra=Sa}}while(0);c[k>>2]=(c[k>>2]|0)+Pa;ga=F+R<<5;S=ga+128|0;V=e+3124+S|0;Q=d[V]|0;P=(ca(Q,Qa)|0)>>8;U=Qa-P|0;c[q>>2]=U;do{if((Ra|0)<(U|0)){a[V]=a[e+24+Q|0]|0;if((U|0)<256){Y=U<<8;c[q>>2]=Y;O=Ra<<8;c[A>>2]=O;va=e+540|0;da=c[va>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){ea=d[da]|O;c[A>>2]=ea;Ta=ea}else{Ta=O}c[va>>2]=da+1;Ua=Y;Va=Ta}else{Ua=U;Va=Ra}Y=ga+129+(e+3124)|0;da=a[Y]|0;va=(ca(da&255,Ua)|0)>>8;O=Ua-va|0;c[q>>2]=O;if((Va|0)<(O|0)){Wa=0;Xa=Y;Ya=da}else{da=e+540|0;ea=e+544|0;wa=1;na=Y;Y=va;va=O;O=Va;while(1){c[A>>2]=O-va;a[na]=a[(d[na]|0)+(e+280)|0]|0;c[q>>2]=Y;if((Y|0)<256){fa=Y<<8;c[q>>2]=fa;X=c[A>>2]<<8;c[A>>2]=X;za=c[da>>2]|0;if(za>>>0<(c[ea>>2]|0)>>>0){ya=d[za]|X;c[A>>2]=ya;Za=ya}else{Za=X}c[da>>2]=za+1;_a=fa;$a=Za}else{_a=Y;$a=c[A>>2]|0}fa=wa+1|0;ab=((wa|0)>9?10:fa)+S+(e+3124)|0;za=(ca(d[ab]|0,_a)|0)>>8;X=_a-za|0;c[q>>2]=X;if(($a|0)<(X|0)){break}else{wa=fa;na=ab;Y=za;va=X;O=$a}}Wa=wa;Xa=ab;Ya=a[ab]|0}a[Xa]=a[(Ya&255)+(e+24)|0]|0;O=c[q>>2]|0;if((O|0)<256){va=O<<8;c[q>>2]=va;Y=c[A>>2]<<8;c[A>>2]=Y;na=e+540|0;da=c[na>>2]|0;if(da>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[da]|Y}c[na>>2]=da+1;bb=va}else{bb=O}c:do{if((Wa|0)>0){O=e+540|0;va=e+544|0;da=2;na=Wa;Y=bb;while(1){ea=na-1|0;X=((ea|0)>9?31:na+21|0)+S+(e+3124)|0;za=(ca(d[X]|0,Y)|0)>>8;fa=Y-za|0;c[q>>2]=fa;ya=c[A>>2]|0;do{if((ya|0)<(fa|0)){a[X]=a[(d[X]|0)+(e+24)|0]|0;xa=c[q>>2]|0;if((xa|0)>=256){cb=0;db=xa;break}Aa=xa<<8;c[q>>2]=Aa;xa=c[A>>2]<<8;c[A>>2]=xa;Ja=c[O>>2]|0;if(Ja>>>0<(c[va>>2]|0)>>>0){c[A>>2]=d[Ja]|xa}c[O>>2]=Ja+1;cb=0;db=Aa}else{c[A>>2]=ya-fa;a[X]=a[(d[X]|0)+(e+280)|0]|0;c[q>>2]=za;if((za|0)>=256){cb=1;db=za;break}Aa=za<<8;c[q>>2]=Aa;Ja=c[A>>2]<<8;c[A>>2]=Ja;xa=c[O>>2]|0;if(xa>>>0<(c[va>>2]|0)>>>0){c[A>>2]=d[xa]|Ja}c[O>>2]=xa+1;cb=1;db=Aa}}while(0);za=cb|da;if((ea|0)<=0){eb=za;fb=db;break c}da=za<<1;na=ea;Y=db}}else{eb=1;fb=bb}}while(0);wa=((Wa|0)>10?21:Wa+11|0)+S+(e+3124)|0;Y=(ca(d[wa]|0,fb)|0)>>8;na=fb-Y|0;c[q>>2]=na;da=c[A>>2]|0;do{if((da|0)<(na|0)){a[wa]=a[(d[wa]|0)+(e+24)|0]|0;O=c[q>>2]|0;if((O|0)>=256){gb=0;break}c[q>>2]=O<<8;O=c[A>>2]<<8;c[A>>2]=O;va=e+540|0;za=c[va>>2]|0;if(za>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[za]|O}c[va>>2]=za+1;gb=0}else{c[A>>2]=da-na;a[wa]=a[(d[wa]|0)+(e+280)|0]|0;c[q>>2]=Y;if((Y|0)>=256){gb=1;break}c[q>>2]=Y<<8;za=c[A>>2]<<8;c[A>>2]=za;va=e+540|0;O=c[va>>2]|0;if(O>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[O]|za}c[va>>2]=O+1;gb=1}}while(0);hb=(eb^-gb)+gb|0}else{Y=Ra-U|0;c[A>>2]=Y;a[V]=a[e+280+Q|0]|0;c[q>>2]=P;if((P|0)>=256){hb=0;break}c[q>>2]=P<<8;wa=Y<<8;c[A>>2]=wa;Y=e+540|0;na=c[Y>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[na]|wa}c[Y>>2]=na+1;hb=0}}while(0);c[l>>2]=(c[l>>2]|0)+hb;ib=B;jb=W&255;kb=o;lb=x;mb=0}else{c[A>>2]=N-M;a[r]=a[(d[r]|0)+(e+280)|0]|0;c[q>>2]=G;if((G|0)<256){c[q>>2]=G<<8;P=c[A>>2]<<8;c[A>>2]=P;Q=e+540|0;V=c[Q>>2]|0;if(V>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[V]|P}c[Q>>2]=V+1}B1a(c[e+7388>>2]|0,k,l,0,u,w,v);V=e+3156|0;Q=c[q>>2]|0;P=d[V]|0;U=(ca(P,Q)|0)>>8;S=Q-U|0;c[q>>2]=S;Q=c[A>>2]|0;do{if((Q|0)<(S|0)){a[V]=a[e+24+P|0]|0;if((S|0)<256){ga=S<<8;c[q>>2]=ga;R=Q<<8;c[A>>2]=R;na=e+540|0;Y=c[na>>2]|0;if(Y>>>0<(c[e+544>>2]|0)>>>0){wa=d[Y]|R;c[A>>2]=wa;nb=wa}else{nb=R}c[na>>2]=Y+1;ob=ga;pb=nb}else{ob=S;pb=Q}ga=e+3157|0;Y=a[ga]|0;na=(ca(Y&255,ob)|0)>>8;R=ob-na|0;c[q>>2]=R;if((pb|0)<(R|0)){qb=0;rb=ga;sb=Y}else{Y=e+540|0;wa=e+544|0;da=1;O=ga;ga=na;na=R;R=pb;while(1){c[A>>2]=R-na;a[O]=a[(d[O]|0)+(e+280)|0]|0;c[q>>2]=ga;if((ga|0)<256){va=ga<<8;c[q>>2]=va;za=c[A>>2]<<8;c[A>>2]=za;X=c[Y>>2]|0;if(X>>>0<(c[wa>>2]|0)>>>0){fa=d[X]|za;c[A>>2]=fa;tb=fa}else{tb=za}c[Y>>2]=X+1;ub=va;vb=tb}else{ub=ga;vb=c[A>>2]|0}wb=((da|0)>9?42:da+33|0)+(e+3124)|0;va=(ca(d[wb]|0,ub)|0)>>8;X=ub-va|0;c[q>>2]=X;if((vb|0)<(X|0)){break}else{da=da+1|0;O=wb;ga=va;na=X;R=vb}}qb=da;rb=wb;sb=a[wb]|0}a[rb]=a[(sb&255)+(e+24)|0]|0;R=c[q>>2]|0;if((R|0)<256){na=R<<8;c[q>>2]=na;ga=c[A>>2]<<8;c[A>>2]=ga;O=e+540|0;Y=c[O>>2]|0;if(Y>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[Y]|ga}c[O>>2]=Y+1;xb=na}else{xb=R}d:do{if((qb|0)>0){R=e+540|0;na=e+544|0;Y=2;O=qb;ga=xb;while(1){wa=O-1|0;X=((wa|0)>9?63:O+53|0)+(e+3124)|0;va=(ca(d[X]|0,ga)|0)>>8;za=ga-va|0;c[q>>2]=za;fa=c[A>>2]|0;do{if((fa|0)<(za|0)){a[X]=a[(d[X]|0)+(e+24)|0]|0;ya=c[q>>2]|0;if((ya|0)>=256){yb=0;zb=ya;break}oa=ya<<8;c[q>>2]=oa;ya=c[A>>2]<<8;c[A>>2]=ya;Aa=c[R>>2]|0;if(Aa>>>0<(c[na>>2]|0)>>>0){c[A>>2]=d[Aa]|ya}c[R>>2]=Aa+1;yb=0;zb=oa}else{c[A>>2]=fa-za;a[X]=a[(d[X]|0)+(e+280)|0]|0;c[q>>2]=va;if((va|0)>=256){yb=1;zb=va;break}oa=va<<8;c[q>>2]=oa;Aa=c[A>>2]<<8;c[A>>2]=Aa;ya=c[R>>2]|0;if(ya>>>0<(c[na>>2]|0)>>>0){c[A>>2]=d[ya]|Aa}c[R>>2]=ya+1;yb=1;zb=oa}}while(0);va=yb|Y;if((wa|0)<=0){Ab=va;Bb=zb;break d}Y=va<<1;O=wa;ga=zb}}else{Ab=1;Bb=xb}}while(0);da=((qb|0)>10?53:qb+43|0)+(e+3124)|0;ga=(ca(d[da]|0,Bb)|0)>>8;O=Bb-ga|0;c[q>>2]=O;Y=c[A>>2]|0;do{if((Y|0)<(O|0)){a[da]=a[(d[da]|0)+(e+24)|0]|0;R=c[q>>2]|0;if((R|0)>=256){Cb=0;Db=R;break}na=R<<8;c[q>>2]=na;R=c[A>>2]<<8;c[A>>2]=R;va=e+540|0;X=c[va>>2]|0;if(X>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[X]|R}c[va>>2]=X+1;Cb=0;Db=na}else{c[A>>2]=Y-O;a[da]=a[(d[da]|0)+(e+280)|0]|0;c[q>>2]=ga;if((ga|0)>=256){Cb=1;Db=ga;break}na=ga<<8;c[q>>2]=na;X=c[A>>2]<<8;c[A>>2]=X;va=e+540|0;R=c[va>>2]|0;if(R>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[R]|X}c[va>>2]=R+1;Cb=1;Db=na}}while(0);Eb=(Ab^-Cb)+Cb|0;Fb=Db}else{ga=Q-S|0;c[A>>2]=ga;a[V]=a[e+280+P|0]|0;c[q>>2]=U;if((U|0)>=256){Eb=0;Fb=U;break}da=U<<8;c[q>>2]=da;O=ga<<8;c[A>>2]=O;ga=e+540|0;Y=c[ga>>2]|0;if(Y>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[Y]|O}c[ga>>2]=Y+1;Eb=0;Fb=da}}while(0);U=Eb+s&255;if((c[e+7544>>2]|0)<=2){ib=U;jb=0;kb=o;lb=x;mb=1;break}P=e+3188|0;V=d[P]|0;S=(ca(V,Fb)|0)>>8;Q=Fb-S|0;c[q>>2]=Q;da=c[A>>2]|0;do{if((da|0)<(Q|0)){a[P]=a[e+24+V|0]|0;if((Q|0)<256){Y=Q<<8;c[q>>2]=Y;ga=da<<8;c[A>>2]=ga;O=e+540|0;na=c[O>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){R=d[na]|ga;c[A>>2]=R;Gb=R}else{Gb=ga}c[O>>2]=na+1;Hb=Y;Ib=Gb}else{Hb=Q;Ib=da}Y=e+3189|0;na=a[Y]|0;O=(ca(na&255,Hb)|0)>>8;ga=Hb-O|0;c[q>>2]=ga;if((Ib|0)<(ga|0)){Jb=0;Kb=Y;Lb=na}else{na=e+540|0;R=e+544|0;va=1;X=Y;Y=O;O=ga;ga=Ib;while(1){c[A>>2]=ga-O;a[X]=a[(d[X]|0)+(e+280)|0]|0;c[q>>2]=Y;if((Y|0)<256){za=Y<<8;c[q>>2]=za;fa=c[A>>2]<<8;c[A>>2]=fa;ea=c[na>>2]|0;if(ea>>>0<(c[R>>2]|0)>>>0){oa=d[ea]|fa;c[A>>2]=oa;Mb=oa}else{Mb=fa}c[na>>2]=ea+1;Nb=za;Ob=Mb}else{Nb=Y;Ob=c[A>>2]|0}Pb=((va|0)>9?74:va+65|0)+(e+3124)|0;za=(ca(d[Pb]|0,Nb)|0)>>8;ea=Nb-za|0;c[q>>2]=ea;if((Ob|0)<(ea|0)){break}else{va=va+1|0;X=Pb;Y=za;O=ea;ga=Ob}}Jb=va;Kb=Pb;Lb=a[Pb]|0}a[Kb]=a[(Lb&255)+(e+24)|0]|0;ga=c[q>>2]|0;if((ga|0)<256){O=ga<<8;c[q>>2]=O;Y=c[A>>2]<<8;c[A>>2]=Y;X=e+540|0;na=c[X>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[na]|Y}c[X>>2]=na+1;Qb=O}else{Qb=ga}e:do{if((Jb|0)>0){ga=e+540|0;O=e+544|0;na=2;X=Jb;Y=Qb;while(1){R=X-1|0;ea=((R|0)>9?95:X+85|0)+(e+3124)|0;za=(ca(d[ea]|0,Y)|0)>>8;fa=Y-za|0;c[q>>2]=fa;oa=c[A>>2]|0;do{if((oa|0)<(fa|0)){a[ea]=a[(d[ea]|0)+(e+24)|0]|0;ya=c[q>>2]|0;if((ya|0)>=256){Rb=0;Sb=ya;break}Aa=ya<<8;c[q>>2]=Aa;ya=c[A>>2]<<8;c[A>>2]=ya;xa=c[ga>>2]|0;if(xa>>>0<(c[O>>2]|0)>>>0){c[A>>2]=d[xa]|ya}c[ga>>2]=xa+1;Rb=0;Sb=Aa}else{c[A>>2]=oa-fa;a[ea]=a[(d[ea]|0)+(e+280)|0]|0;c[q>>2]=za;if((za|0)>=256){Rb=1;Sb=za;break}Aa=za<<8;c[q>>2]=Aa;xa=c[A>>2]<<8;c[A>>2]=xa;ya=c[ga>>2]|0;if(ya>>>0<(c[O>>2]|0)>>>0){c[A>>2]=d[ya]|xa}c[ga>>2]=ya+1;Rb=1;Sb=Aa}}while(0);za=Rb|na;if((R|0)<=0){Tb=za;Ub=Sb;break e}na=za<<1;X=R;Y=Sb}}else{Tb=1;Ub=Qb}}while(0);va=((Jb|0)>10?85:Jb+75|0)+(e+3124)|0;Y=(ca(d[va]|0,Ub)|0)>>8;X=Ub-Y|0;c[q>>2]=X;na=c[A>>2]|0;do{if((na|0)<(X|0)){a[va]=a[(d[va]|0)+(e+24)|0]|0;ga=c[q>>2]|0;if((ga|0)>=256){Vb=0;Wb=ga;break}O=ga<<8;c[q>>2]=O;ga=c[A>>2]<<8;c[A>>2]=ga;za=e+540|0;ea=c[za>>2]|0;if(ea>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[ea]|ga}c[za>>2]=ea+1;Vb=0;Wb=O}else{c[A>>2]=na-X;a[va]=a[(d[va]|0)+(e+280)|0]|0;c[q>>2]=Y;if((Y|0)>=256){Vb=1;Wb=Y;break}O=Y<<8;c[q>>2]=O;ea=c[A>>2]<<8;c[A>>2]=ea;za=e+540|0;ga=c[za>>2]|0;if(ga>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[ga]|ea}c[za>>2]=ga+1;Vb=1;Wb=O}}while(0);Xb=(Tb^-Vb)+Vb|0;Yb=Wb;Zb=c[A>>2]|0}else{Y=da-Q|0;c[A>>2]=Y;a[P]=a[e+280+V|0]|0;c[q>>2]=S;if((S|0)>=256){Xb=0;Yb=S;Zb=Y;break}va=S<<8;c[q>>2]=va;X=Y<<8;c[A>>2]=X;Y=e+540|0;na=c[Y>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){O=d[na]|X;c[A>>2]=O;_b=O}else{_b=X}c[Y>>2]=na+1;Xb=0;Yb=va;Zb=_b}}while(0);S=Xb+t|0;V=e+3220|0;P=d[V]|0;Q=(ca(P,Yb)|0)>>8;da=Yb-Q|0;c[q>>2]=da;do{if((Zb|0)<(da|0)){a[V]=a[e+24+P|0]|0;if((da|0)<256){va=da<<8;c[q>>2]=va;na=Zb<<8;c[A>>2]=na;Y=e+540|0;X=c[Y>>2]|0;if(X>>>0<(c[e+544>>2]|0)>>>0){O=d[X]|na;c[A>>2]=O;$b=O}else{$b=na}c[Y>>2]=X+1;ac=va;bc=$b}else{ac=da;bc=Zb}va=e+3221|0;X=a[va]|0;Y=(ca(X&255,ac)|0)>>8;na=ac-Y|0;c[q>>2]=na;if((bc|0)<(na|0)){cc=0;dc=va;ec=X}else{X=e+540|0;O=e+544|0;ga=1;za=va;va=Y;Y=na;na=bc;while(1){c[A>>2]=na-Y;a[za]=a[(d[za]|0)+(e+280)|0]|0;c[q>>2]=va;if((va|0)<256){ea=va<<8;c[q>>2]=ea;fa=c[A>>2]<<8;c[A>>2]=fa;oa=c[X>>2]|0;if(oa>>>0<(c[O>>2]|0)>>>0){wa=d[oa]|fa;c[A>>2]=wa;fc=wa}else{fc=fa}c[X>>2]=oa+1;gc=ea;hc=fc}else{gc=va;hc=c[A>>2]|0}ic=((ga|0)>9?106:ga+97|0)+(e+3124)|0;ea=(ca(d[ic]|0,gc)|0)>>8;oa=gc-ea|0;c[q>>2]=oa;if((hc|0)<(oa|0)){break}else{ga=ga+1|0;za=ic;va=ea;Y=oa;na=hc}}cc=ga;dc=ic;ec=a[ic]|0}a[dc]=a[(ec&255)+(e+24)|0]|0;na=c[q>>2]|0;if((na|0)<256){Y=na<<8;c[q>>2]=Y;va=c[A>>2]<<8;c[A>>2]=va;za=e+540|0;X=c[za>>2]|0;if(X>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[X]|va}c[za>>2]=X+1;jc=Y}else{jc=na}f:do{if((cc|0)>0){na=e+540|0;Y=e+544|0;X=2;za=cc;va=jc;while(1){O=za-1|0;oa=((O|0)>9?127:za+117|0)+(e+3124)|0;ea=(ca(d[oa]|0,va)|0)>>8;fa=va-ea|0;c[q>>2]=fa;wa=c[A>>2]|0;do{if((wa|0)<(fa|0)){a[oa]=a[(d[oa]|0)+(e+24)|0]|0;Aa=c[q>>2]|0;if((Aa|0)>=256){kc=0;lc=Aa;break}ya=Aa<<8;c[q>>2]=ya;Aa=c[A>>2]<<8;c[A>>2]=Aa;xa=c[na>>2]|0;if(xa>>>0<(c[Y>>2]|0)>>>0){c[A>>2]=d[xa]|Aa}c[na>>2]=xa+1;kc=0;lc=ya}else{c[A>>2]=wa-fa;a[oa]=a[(d[oa]|0)+(e+280)|0]|0;c[q>>2]=ea;if((ea|0)>=256){kc=1;lc=ea;break}ya=ea<<8;c[q>>2]=ya;xa=c[A>>2]<<8;c[A>>2]=xa;Aa=c[na>>2]|0;if(Aa>>>0<(c[Y>>2]|0)>>>0){c[A>>2]=d[Aa]|xa}c[na>>2]=Aa+1;kc=1;lc=ya}}while(0);ea=kc|X;if((O|0)<=0){mc=ea;nc=lc;break f}X=ea<<1;za=O;va=lc}}else{mc=1;nc=jc}}while(0);ga=((cc|0)>10?117:cc+107|0)+(e+3124)|0;va=(ca(d[ga]|0,nc)|0)>>8;za=nc-va|0;c[q>>2]=za;X=c[A>>2]|0;do{if((X|0)<(za|0)){a[ga]=a[(d[ga]|0)+(e+24)|0]|0;na=c[q>>2]|0;if((na|0)>=256){oc=0;break}c[q>>2]=na<<8;na=c[A>>2]<<8;c[A>>2]=na;Y=e+540|0;ea=c[Y>>2]|0;if(ea>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[ea]|na}c[Y>>2]=ea+1;oc=0}else{c[A>>2]=X-za;a[ga]=a[(d[ga]|0)+(e+280)|0]|0;c[q>>2]=va;if((va|0)>=256){oc=1;break}c[q>>2]=va<<8;ea=c[A>>2]<<8;c[A>>2]=ea;Y=e+540|0;na=c[Y>>2]|0;if(na>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[na]|ea}c[Y>>2]=na+1;oc=1}}while(0);pc=(mc^-oc)+oc|0}else{va=Zb-da|0;c[A>>2]=va;a[V]=a[e+280+P|0]|0;c[q>>2]=Q;if((Q|0)>=256){pc=0;break}c[q>>2]=Q<<8;ga=va<<8;c[A>>2]=ga;va=e+540|0;za=c[va>>2]|0;if(za>>>0<(c[e+544>>2]|0)>>>0){c[A>>2]=d[za]|ga}c[va>>2]=za+1;pc=0}}while(0);ib=U;jb=0;kb=pc+y&255;lb=S&255;mb=1}}while(0);y=c[n>>2]|0;A=c[m>>2]<<y;q=y-f|0;y=(ca(A,h)|0)+g<<q;t=1<<q;q=c[k>>2]&65535;x=c[l>>2]&65535;o=f&255;if((t|0)<=0){break}s=e+2139660|0;G=0;do{r=(ca(G,A)|0)+y|0;M=0;do{N=r+M|0;B=c[s>>2]|0;b[B+(N*10|0)>>1]=q;b[B+(N*10|0)+2>>1]=x;a[B+(N*10|0)+4|0]=jb;a[B+(N*10|0)+5|0]=ib;a[B+(N*10|0)+6|0]=lb;a[B+(N*10|0)+7|0]=kb;a[B+(N*10|0)+8|0]=mb;a[B+(N*10|0)+9|0]=o;M=M+1|0;}while((M|0)<(t|0));G=G+1|0;}while((G|0)<(t|0))}}while(0);C=0;i=j;return C|0}function B1a(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=b[h>>1]|0;l=k<<16>>16;if((a|0)==1){a=b[i>>1]|0;m=a<<16>>16;n=b[j>>1]|0;o=n<<16>>16;do{if(k<<16>>16>a<<16>>16){if(!(n<<16>>16>a<<16>>16)){p=m;break}p=(o|0)>(l|0)?l:o}else{if(!(a<<16>>16>n<<16>>16)){p=m;break}p=(o|0)>(l|0)?o:l}}while(0);c[e>>2]=p;p=b[h+2>>1]|0;o=p<<16>>16;m=b[i+2>>1]|0;n=m<<16>>16;a=b[j+2>>1]|0;k=a<<16>>16;if(p<<16>>16>m<<16>>16){if(!(a<<16>>16>m<<16>>16)){q=n;c[f>>2]=q;return}q=(k|0)>(o|0)?o:k;c[f>>2]=q;return}else{if(!(m<<16>>16>a<<16>>16)){q=n;c[f>>2]=q;return}q=(k|0)>(o|0)?k:o;c[f>>2]=q;return}}else{o=h+4|0;k=(ca(c[6548856+(g<<5)+(d[o]<<2)>>2]|0,l)|0)+128>>8;l=i+4|0;n=(ca(c[6548856+(g<<5)+(d[l]<<2)>>2]|0,b[i>>1]|0)|0)+128>>8;a=j+4|0;m=(ca(c[6548856+(g<<5)+(d[a]<<2)>>2]|0,b[j>>1]|0)|0)+128>>8;do{if((k|0)>(n|0)){if((m|0)<=(n|0)){r=n;break}r=(m|0)>(k|0)?k:m}else{if((n|0)<=(m|0)){r=n;break}r=(m|0)>(k|0)?m:k}}while(0);c[e>>2]=r;r=(ca(c[6548856+(g<<5)+(d[o]<<2)>>2]|0,b[h+2>>1]|0)|0)+128>>8;h=(ca(c[6548856+(g<<5)+(d[l]<<2)>>2]|0,b[i+2>>1]|0)|0)+128>>8;i=(ca(c[6548856+(g<<5)+(d[a]<<2)>>2]|0,b[j+2>>1]|0)|0)+128>>8;if((r|0)>(h|0)){if((i|0)<=(h|0)){q=h;c[f>>2]=q;return}q=(i|0)>(r|0)?r:i;c[f>>2]=q;return}else{if((h|0)<=(i|0)){q=h;c[f>>2]=q;return}q=(i|0)>(r|0)?i:r;c[f>>2]=q;return}}}function C1a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=b+60|0;f=c[e>>2]|0;g=f;if((c[b+680>>2]|0)>-2){KIb(b,16,2587296,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1;i=d;return j|0}k=c[b+216>>2]|0;l=b+88|0;do{if((k|0)==0){if((c[l>>2]&2|0)==0){break}if((c[b+80>>2]|0)!=0){break}KIb(b,16,2566240,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1;i=d;return j|0}}while(0);c[f+7360>>2]=k;c[f+7512>>2]=((c[l>>2]|0)>>>3&2^2)+2;k=f+7536|0;c[k>>2]=(c[l>>2]|0)>>>2&1;c[f+540556>>2]=1;c[f+540548>>2]=6;a[f+540552|0]=40;a[f+540553|0]=-10;a[f+540554|0]=2;c[f+540560>>2]=1;c[f+1073584>>2]=1;c[f+1073576>>2]=6;a[f+1073580|0]=40;a[f+1073581|0]=-10;a[f+1073582|0]=2;c[f+1073588>>2]=1;c[f+1606612>>2]=1;c[f+1606604>>2]=6;a[f+1606608|0]=40;a[f+1606609|0]=-10;a[f+1606610|0]=2;c[f+1606616>>2]=1;m=ytb(b)|0;if((m|0)<0){Ktb(c[e>>2]|0);j=m;i=d;return j|0}vtb(g)|0;c[f+7356>>2]=0;g=f+2143800|0;c[f+2143804>>2]=b;c[f+2143860>>2]=c[l>>2];c[f+2143824>>2]=c[b+72>>2];m=pJb((c[b+120>>2]<<6)+4096|0)|0;e=f+2155992|0;c[e>>2]=m;c[f+2156008>>2]=m;m=f+2156016|0;c[m>>2]=pJb(256)|0;n=f+2156020|0;c[n>>2]=pJb(256)|0;o=pJb(12288)|0;c[f+2153752>>2]=o;if((c[e>>2]|0)==0){j=-12;i=d;return j|0}if((c[m>>2]|0)==0){j=-12;i=d;return j|0}if((c[n>>2]|0)==0|(o|0)==0){j=-12;i=d;return j|0}Bqb(g);o=c[b+364>>2]|0;if((o|0)>1){p=(o|0)>8?8:o}else{p=1}o=f+7384|0;c[o>>2]=p;p=c[l>>2]|0;do{if((p&512|0)==0){q=p}else{n=b+668|0;if((c[n>>2]|0)!=0){q=p;break}m=pJb(256)|0;c[n>>2]=m;if((m|0)==0){j=-12;i=d;return j|0}else{q=c[l>>2]|0;break}}}while(0);do{if((q&1026|0)==2){r=q}else{if((YYa(g)|0)<0){j=-1;i=d;return j|0}else{r=c[l>>2]|0;break}}}while(0);c[f+7508>>2]=(r&1026|0)==0;r=c[b+140>>2]|0;if((r|0)==5|(r|0)==0|(r|0)==6){c[f+7544>>2]=3;c[f+7476>>2]=0}else if((r|0)==8){c[f+7544>>2]=1;c[f+7476>>2]=1}else{KIb(b,16,2548128,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1;i=d;return j|0}vLa(r,f+7480|0,f+7484|0);r=f+548|0;h=f+4|0;h8(r,f+960|0,c[(c[h>>2]|0)+232>>2]|0);h8(r,f+984|0,c[(c[h>>2]|0)+236>>2]|0);r=UHb()|0;c[f+2536>>2]=r;if((r|0)==0){j=-12;i=d;return j|0}b=M4a(c[h>>2]|0,r,1)|0;if((b|0)<0){j=b;i=d;return j|0}if((c[(c[h>>2]|0)+144>>2]|0)!=50){j=0;i=d;return j|0}h=ca(c[f+7532>>2]|0,c[f+7528>>2]|0)|0;b=h<<(c[k>>2]<<1)<<2;k=f+7392|0;h=f+7424|0;f=0;while(1){if((f|0)>=(c[o>>2]|0)){j=0;s=31;break}r=k+(f<<2)|0;c[r>>2]=pJb(b)|0;l=pJb(b)|0;c[h+(f<<2)>>2]=l;if((c[r>>2]|0)==0|(l|0)==0){j=-12;s=31;break}else{f=f+1|0}}if((s|0)==31){i=d;return j|0}return 0}function D1a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0.0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0;k=i;i=i+4256|0;l=k|0;m=k+32|0;n=c[f+60>>2]|0;o=n;p=n+8|0;q=n+4|0;r=c[q>>2]|0;s=c[r+120>>2]|0;t=c[r+124>>2]|0;r=n+7528|0;u=n+7532|0;v=(ca((c[r>>2]|0)*768|0,c[u>>2]|0)|0)+16384|0;w=d5a(f,g,v,(v|0)<0|0?-1:0)|0;if((w|0)<0){x=w;i=k;return x|0}w=g+24|0;v=g+28|0;SYa(p,c[w>>2]|0,c[v>>2]|0);UYa(p,214748364,248);z=n+7544|0;if((c[z>>2]|0)>0){A=n+1752|0;B=n+2536|0;C=n+7480|0;D=n+7484|0;E=0;do{if((E|0)==0){F=0;H=0}else{F=c[D>>2]|0;H=c[C>>2]|0}I=t>>F;if((I|0)>0){J=h+32+(E<<2)|0;K=h+(E<<2)|0;L=s>>H;M=0;while(1){N=c[B>>2]|0;O=ca(c[N+32+(E<<2)>>2]|0,M)|0;P=ca(c[J>>2]|0,M)|0;nrc((c[N+(E<<2)>>2]|0)+O|0,(c[K>>2]|0)+P|0,L)|0;P=M+1|0;if((P|0)<(I|0)){M=P}else{Q=L;break}}}else{Q=s>>H}L=c[B>>2]|0;Se[c[A>>2]&1023](c[L+(E<<2)>>2]|0,c[L+32+(E<<2)>>2]|0,Q,I,16>>>(H>>>0),16>>>(F>>>0),3);E=E+1|0;}while((E|0)<(c[z>>2]|0))}c[n+2532>>2]=h;E=f+428|0;F=n+2143800|0;c[n+2143908>>2]=c[E>>2];H=f+88|0;do{if((c[H>>2]&1024|0)==0){Q=c[f+136>>2]|0;if((Q|0)==0){R=1}else{R=((c[E>>2]|0)%(Q|0)|0|0)==0}c[n+7348>>2]=R&1;Q=R?1:2;c[h+88>>2]=Q;c[n+2153792>>2]=Q}else{Q=c[(c[n+2157036>>2]|0)+((c[E>>2]|0)*80|0)+40>>2]|0;c[h+88>>2]=Q;c[n+2153792>>2]=Q;c[n+7348>>2]=(Q|0)==1;if((c[H>>2]&2|0)!=0){break}Q=~~+dZa(F,0);c[h+168>>2]=Q;if((Q|0)<0){x=-1}else{break}i=k;return x|0}}while(0);R=n+7508|0;do{if((c[R>>2]|0)!=0){if((c[E>>2]|0)!=0){break}c[h+168>>2]=236}}while(0);Q=h+168|0;A=c[Q>>2]|0;if((A|0)==0){T=c[n+7492>>2]|0}else{B=~~(+Lc(+(+lc(+(+(A|0)/118.0))*32.0))+244.0);c[n+7492>>2]=B;c[n+7500>>2]=((c[Q>>2]|0)*3|0|0)/2|0;T=B}B=n+7492|0;do{if((T|0)<0){U=26}else{if((c[Q>>2]|0)!=0){break}if((c[H>>2]&2|0)!=0){U=26}}}while(0);if((U|0)==26){c[B>>2]=-128;c[n+7500>>2]=0}Jtb(o)|0;T=n+2540|0;A=f+804|0;c[A>>2]=c[T>>2];C=n+2151424|0;c[n+2153656>>2]=C;D=n+2151560|0;L=c[D+4>>2]|0;M=n+2144752|0;K=M;J=n+2144888|0;c[J>>2]=c[D>>2];c[J+4>>2]=L;L=h+136|0;J=c[L+4>>2]|0;c[D>>2]=c[L>>2];c[D+4>>2]=J;J=h+88|0;do{if((c[J>>2]|0)==2){D=s+15>>4;L=c[T>>2]|0;P=c[L+32>>2]|0;O=L|0;if((c[O>>2]|0)==0){KIb(0,0,2446344,(V=i,i=i+24|0,c[V>>2]=2357112,c[V+8>>2]=2294072,c[V+16>>2]=1621,V)|0);i=V;Hd();return 0}N=c[n+2544>>2]|0;if((c[N>>2]|0)==0){KIb(0,0,2446344,(V=i,i=i+24|0,c[V>>2]=2243096,c[V+8>>2]=2294072,c[V+16>>2]=1622,V)|0);i=V;Hd();return 0}else{W=c[q>>2]|0;c[n+2143804>>2]=W;c[C>>2]=c[O>>2];c[M>>2]=c[N>>2];c[n+2149200>>2]=c[c[n+2536>>2]>>2];c[n+2153648>>2]=K;c[n+2151456>>2]=P;c[n+2149232>>2]=P;c[n+2144784>>2]=P;c[n+2143948>>2]=P;c[n+2143952>>2]=c[L+36>>2];c[n+2143808>>2]=s;c[n+2143812>>2]=t;c[n+2143916>>2]=D;c[n+2143920>>2]=t+15>>4;c[n+2143924>>2]=D+1;c[n+2143928>>2]=D<<1|1;c[n+2155356>>2]=1;c[n+2153792>>2]=2;c[n+2155532>>2]=c[W+144>>2];c[n+2156240>>2]=0;D=W+88|0;c[n+2143860>>2]=c[D>>2];c[n+2157724>>2]=(c[D>>2]|0)>>>4&1;c[n+2143828>>2]=2;c[n+2153848>>2]=1;D=c[n+7500>>2]|0;c[n+2153768>>2]=D;c[n+2153760>>2]=((D*139|0)+8192|0)>>>14;W=((ca(D,D)|0)+64|0)>>>7;c[n+2153772>>2]=W;c[n+7504>>2]=W;W=n+2153856|0;D=n+548|0;nrc(W|0,D|0,1244)|0;L=n+2155132|0;P=n+1792|0;nrc(L|0,P|0,208)|0;$qb(F)|0;nrc(P|0,L|0,208)|0;nrc(D|0,W|0,1244)|0;break}}}while(0);if((c[R>>2]|0)==0){X=n+3092|0;Y=l|0;Z=n+3124|0;_=m|0}else{K=l|0;l=n+3092|0;nrc(K|0,l|0,32)|0;M=m|0;m=n+3124|0;nrc(M|0,m|0,4224)|0;X=l;Y=K;Z=m;_=M}M=n+7372|0;m=n+7484|0;K=n+7480|0;l=n+2153792|0;C=n+7520|0;W=n+7376|0;D=n+540|0;L=n+536|0;P=n+2157496|0;N=n+7348|0;O=n+544|0;$=n+2157464|0;ba=n+7548|0;da=n+2143792|0;ea=n+7464|0;fa=n+7536|0;ga=n+2156240|0;ha=n+7456|0;ia=n+7460|0;ja=n+7360|0;ka=n+2153592|0;la=n+2153600|0;ma=n+7500|0;na=n+7468|0;oa=n+2139660|0;pa=n+2158472|0;qa=n+2143796|0;ra=n+7472|0;a:while(1){sa=c[K>>2]|0;ta=c[m>>2]|0;ua=5;while(1){if((s>>sa+ua|0)!=0){if((t>>ta+ua|0)!=0){break}}ua=ua-1|0}c[M>>2]=ua;if((ua|0)<1){U=42;break}ta=c[J>>2]|0;c[l>>2]=ta;c[C>>2]=(ta|0)==2?2:0;Htb(f)|0;ta=c[M>>2]|0;do{if((c[W>>2]|0)!=(ta|0)){sa=c[z>>2]|0;if((sa|0)>0){va=0;wa=ta;xa=sa}else{break}while(1){sa=c[ba+(va*533028|0)>>2]|0;I=c[ba+(va*533028|0)+4>>2]|0;if((wa|0)>0){ya=ca(sa<<1,I)|0;za=(I|0)<1|(sa|0)<1;Aa=0;do{Ba=(Aa|0)!=0|0;do{Ca=c[ba+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+24>>2]|0;mrc(c[ea>>2]|0,0,ya|0)|0;b[Ca+((ca(c[ba+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+4>>2]|0,(c[ba+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+12>>2]|0)/2|0)|0)+((c[ba+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+8>>2]|0)/2|0)<<1)>>1]=4096;j1a(c[ea>>2]|0,c[na>>2]|0,sa,I,sa,c[ja>>2]|0,c[M>>2]|0);if(za){Da=0.0}else{Ca=c[ea>>2]|0;Ea=0;Fa=0;Ga=0;while(1){Ha=ca(Ea,sa)|0;Ia=0;Ja=Fa;Ka=Ga;do{La=b[Ca+(Ia+Ha<<1)>>1]<<4;Ma=La;Na=(La|0)<0|0?-1:0;La=Erc(Ma,Na,Ma,Na)|0;Ka=wrc(La,G,Ka,Ja)|0;Ja=G;Ia=Ia+1|0;}while((Ia|0)<(sa|0));Ia=Ea+1|0;if((Ia|0)<(I|0)){Ea=Ia;Fa=Ja;Ga=Ka}else{break}}Da=+(Ka>>>0)+ +(Ja|0)*4294967296.0}c[ba+(va*533028|0)+8+(Aa*66624|0)+(Ba*16656|0)+16>>2]=~~(+aa(352256.0/+S(Da))/.02166084939249824+.5);Ba=Ba+1|0;}while((Ba|0)<4);Aa=Aa+1|0;Oa=c[M>>2]|0;}while((Aa|0)<(Oa|0));Pa=Oa;Qa=c[z>>2]|0}else{Pa=wa;Qa=xa}Aa=va+1|0;if((Aa|0)<(Qa|0)){va=Aa;wa=Pa;xa=Qa}else{break}}}}while(0);F1a(o);c[P>>2]=(c[D>>2]|0)-(c[L>>2]|0)<<3;ta=c[r>>2]|0;ua=c[u>>2]|0;do{if((c[(c[q>>2]|0)+144>>2]|0)==50){if((c[N>>2]|0)!=0){break}I1a(o)}}while(0);b:do{if((ua|0)>0){Aa=ta*768|0;I=(ta|0)>0;sa=0;while(1){if(((c[O>>2]|0)-(c[D>>2]|0)|0)<(Aa|0)){break}if(I){za=0;do{if((c[(c[q>>2]|0)+144>>2]|0)==50){J1a(o,0,za,sa)}else{K1a(o,0,za,sa)|0}za=za+1|0;}while((za|0)<(ta|0))}sa=sa+1|0;if((sa|0)>=(ua|0)){break b}}KIb(c[q>>2]|0,16,2142848,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}}while(0);c[$>>2]=((c[D>>2]|0)-(c[L>>2]|0)<<3)-(c[P>>2]|0);if((c[z>>2]|0)>0){Ra=0}else{U=522;break}c:while(1){ua=c[ba+(Ra*533028|0)>>2]|0;ta=c[ba+(Ra*533028|0)+4>>2]|0;d:do{if((c[da>>2]|0)==0){sa=c[h+(Ra<<2)>>2]|0;if((sa|0)!=0&(ta|0)>0){I=(ua|0)>0;Aa=h+32+(Ra<<2)|0;za=0;do{if(I){ya=ca(za,ua)|0;Ba=c[Aa>>2]|0;Ga=c[ea>>2]|0;Fa=0;do{b[Ga+(Fa+ya<<1)>>1]=d[sa+((ca(Ba,za)|0)+Fa)|0]<<4;Fa=Fa+1|0;}while((Fa|0)<(ua|0))}za=za+1|0;}while((za|0)<(ta|0))}za=c[ea>>2]|0;sa=c[u>>2]|0;Aa=c[fa>>2]|0;I=sa<<Aa;e:do{if((I|0)>=0){Fa=(Ra|0)==0;Ba=o+7548+(Ra*533028|0)|0;ya=o+7548+(Ra*533028|0)+4|0;Ga=0;Ea=Aa;Ca=sa;while(1){Ia=c[r>>2]|0;Ha=Ia<<Ea;La=Ca<<Ea;Na=16>>>(Ea>>>0);if(Fa){Sa=Na<<1;Ta=Na;Ua=Na;Va=Ea}else{Ma=c[K>>2]|0;Sa=Na<<1>>Ma;Ta=Na>>c[m>>2];Ua=Na>>Ma;Va=Ma+Ea|0}Ma=c[1335352+(Va<<2)>>2]|0;Na=c[(c[T>>2]|0)+32+(Ra<<2)>>2]|0;Wa=c[Ba>>2]|0;Xa=c[ya>>2]|0;f:do{if((c[N>>2]|0)==0){if((c[(c[q>>2]|0)+688>>2]&512|0)!=0){U=88;break}if((Ha|0)<0){break}Ya=(Ua|0)/2|0;Za=(ca(Ta,Ga)|0)-((Ta|0)/2|0)|0;_a=Ga-1|0;$a=(Na|0)>111?16:Na<<4;ab=(_a|0)<0;bb=(Za|0)<0;cb=ca(Za,-Sa|0)|0;db=Za+Ta|0;eb=$a*3|0;fb=eb+$a|0;gb=Sa>>1;hb=fb+$a|0;ib=0;jb=Ia;kb=Ea;lb=Ca;while(1){mb=(ca(ib,Ua)|0)-Ya|0;nb=ib-1|0;ob=jb<<kb;pb=ca(ob,_a)|0;qb=pb+nb|0;rb=c[oa>>2]|0;sb=rb+(qb*10|0)|0;tb=rb+((pb+ib|0)*10|0)|0;pb=qb+ob|0;qb=rb+(pb*10|0)|0;ub=rb+((pb+1|0)*10|0)|0;pb=c[pa>>2]|0;if((nb|0)<0){vb=ub;wb=ub;xb=tb;yb=tb}else{nb=(ib|0)<(ob|0);vb=nb?ub:qb;wb=qb;xb=nb?tb:sb;yb=sb}if(ab){zb=vb;Ab=wb;Bb=vb;Cb=wb}else{sb=(lb<<kb|0)>(Ga|0);zb=sb?vb:xb;Ab=sb?wb:yb;Bb=xb;Cb=yb}if((mb|0)<0){Db=Ma+(-mb|0)|0;Eb=0;Fb=mb+Ua|0}else{Db=Ma;Eb=mb;Fb=Ua}mb=(Eb+Fb|0)>(Wa|0)?Wa-Eb|0:Fb;if(bb){Gb=Db+cb|0;Hb=0;Ib=db}else{Gb=Db;Hb=Za;Ib=Ta}sb=(Hb+Ib|0)>(Xa|0)?Xa-Hb|0:Ib;do{if(!((mb|0)<1|(sb|0)<1)){tb=pb+eb|0;nb=pb+fb|0;wtb(o,tb,pb,Na,Eb,Hb,mb,sb,Cb,Ra,Wa,Xa);qb=Cb+8|0;ub=a[qb]|0;ob=Bb+8|0;rb=a[ob]|0;do{if((ub&1)==0){U=107}else{if((rb&1)==0){U=107;break}Jb=(d[Cb+6|0]|0)-(d[Bb+6|0]|0)|(d[Cb+5|0]|0)-(d[Bb+5|0]|0)|(d[Cb+7|0]|0)-(d[Bb+7|0]|0)}}while(0);if((U|0)==107){U=0;Jb=(b[Cb>>1]|0)-(b[Bb>>1]|0)|(rb^ub)&1|(b[Cb+2>>1]|0)-(b[Bb+2>>1]|0)|(d[Cb+4|0]|0)-(d[Bb+4|0]|0)}if((Jb|0)==0){Kb=nb;Lb=tb;Mb=ub}else{wtb(o,nb,pb,Na,Eb,Hb,mb,sb,Bb,Ra,Wa,Xa);Kb=pb+hb|0;Lb=nb;Mb=a[qb]|0}Nb=Ab+8|0;Ob=a[Nb]|0;do{if((Mb&1)==0){U=113}else{if((Ob&1)==0){U=113;break}Pb=(d[Cb+6|0]|0)-(d[Ab+6|0]|0)|(d[Cb+5|0]|0)-(d[Ab+5|0]|0)|(d[Cb+7|0]|0)-(d[Ab+7|0]|0)}}while(0);if((U|0)==113){U=0;Pb=(b[Cb>>1]|0)-(b[Ab>>1]|0)|(Ob^Mb)&1|(b[Cb+2>>1]|0)-(b[Ab+2>>1]|0)|(d[Cb+4|0]|0)-(d[Ab+4|0]|0)}do{if((Pb|0)==0){Qb=Kb;Rb=tb;Sb=Mb}else{nb=a[ob]|0;do{if((nb&1)==0){U=118}else{if((Ob&1)==0){U=118;break}Tb=(d[Bb+6|0]|0)-(d[Ab+6|0]|0)|(d[Bb+5|0]|0)-(d[Ab+5|0]|0)|(d[Bb+7|0]|0)-(d[Ab+7|0]|0)}}while(0);if((U|0)==118){U=0;Tb=(b[Bb>>1]|0)-(b[Ab>>1]|0)|(nb^Ob)&1|(b[Bb+2>>1]|0)-(b[Ab+2>>1]|0)|(d[Bb+4|0]|0)-(d[Ab+4|0]|0)}if((Tb|0)==0){Qb=Kb;Rb=Lb;Sb=Mb;break}wtb(o,Kb,pb,Na,Eb,Hb,mb,sb,Ab,Ra,Wa,Xa);Qb=Kb+$a|0;Rb=Kb;Sb=a[qb]|0}}while(0);qb=a[zb+8|0]|0;do{if((Sb&1)==0){U=124}else{if((qb&1)==0){U=124;break}Ub=(d[Cb+6|0]|0)-(d[zb+6|0]|0)|(d[Cb+5|0]|0)-(d[zb+5|0]|0)|(d[Cb+7|0]|0)-(d[zb+7|0]|0)}}while(0);if((U|0)==124){U=0;Ub=(b[Cb>>1]|0)-(b[zb>>1]|0)|(qb^Sb)&1|(b[Cb+2>>1]|0)-(b[zb+2>>1]|0)|(d[Cb+4|0]|0)-(d[zb+4|0]|0)}do{if((Ub|0)==0){Vb=tb}else{Ob=a[ob]|0;do{if((Ob&1)==0){U=129}else{if((qb&1)==0){U=129;break}Wb=(d[Bb+6|0]|0)-(d[zb+6|0]|0)|(d[Bb+5|0]|0)-(d[zb+5|0]|0)|(d[Bb+7|0]|0)-(d[zb+7|0]|0)}}while(0);if((U|0)==129){U=0;Wb=(b[Bb>>1]|0)-(b[zb>>1]|0)|(Ob^qb)&1|(b[Bb+2>>1]|0)-(b[zb+2>>1]|0)|(d[Bb+4|0]|0)-(d[zb+4|0]|0)}if((Wb|0)==0){Vb=Lb;break}nb=a[Nb]|0;do{if((nb&1)==0){U=134}else{if((qb&1)==0){U=134;break}Xb=(d[Ab+6|0]|0)-(d[zb+6|0]|0)|(d[Ab+5|0]|0)-(d[zb+5|0]|0)|(d[Ab+7|0]|0)-(d[zb+7|0]|0)}}while(0);if((U|0)==134){U=0;Xb=(b[Ab>>1]|0)-(b[zb>>1]|0)|(nb^qb)&1|(b[Ab+2>>1]|0)-(b[zb+2>>1]|0)|(d[Ab+4|0]|0)-(d[zb+4|0]|0)}if((Xb|0)==0){Vb=Rb;break}wtb(o,Qb,pb,Na,Eb,Hb,mb,sb,zb,Ra,Wa,Xa);Vb=Qb}}while(0);if((sb|0)<=0){break}qb=(mb|0)>0;Nb=0;do{ob=ca(Nb,Sa)|0;tb=ob+gb|0;Ob=ca(Nb+gb|0,Sa)|0;ub=Ob+gb|0;if(qb){rb=ca(Nb,Na)|0;Yb=(ca(Nb+Hb|0,Wa)|0)+Eb|0;Zb=0;do{_b=Zb+rb|0;$b=ca(d[Vb+_b|0]|0,d[Gb+(Zb+ob)|0]|0)|0;ac=(ca(d[Rb+_b|0]|0,d[Gb+(tb+Zb)|0]|0)|0)+$b|0;$b=ac+(ca(d[Lb+_b|0]|0,d[Gb+(Zb+Ob)|0]|0)|0)|0;ac=($b+(ca(d[pb+(_b+eb)|0]|0,d[Gb+(ub+Zb)|0]|0)|0)|0)>>>4;_b=za+(Yb+Zb<<1)|0;b[_b>>1]=(e[_b>>1]|0)-ac;Zb=Zb+1|0;}while((Zb|0)<(mb|0))}Nb=Nb+1|0;}while((Nb|0)<(sb|0))}}while(0);sb=ib+1|0;if((sb|0)>(Ha|0)){break f}ib=sb;jb=c[r>>2]|0;kb=c[fa>>2]|0;lb=c[u>>2]|0}}else{U=88}}while(0);do{if((U|0)==88){U=0;if((La|0)==(Ga|0)){break}Ha=ca(Ta,Ga)|0;Na=ca(Ta,Ga+1|0)|0;Ma=(Xa|0)>(Na|0)?Na:Xa;if((Ha|0)>=(Ma|0)){break}Na=(Wa|0)>0;Ia=Ha;do{if(Na){Ha=ca(Ia,Wa)|0;lb=0;do{kb=za+(lb+Ha<<1)|0;b[kb>>1]=(b[kb>>1]|0)-2048;lb=lb+1|0;}while((lb|0)<(Wa|0))}Ia=Ia+1|0;}while((Ia|0)<(Ma|0))}}while(0);Wa=Ga+1|0;if((Wa|0)>(I|0)){break e}Ga=Wa;Ea=c[fa>>2]|0;Ca=c[u>>2]|0}}}while(0);I=(Ra|0)==0;do{if(I){if((c[J>>2]|0)!=2){break}if((c[H>>2]&1024|0)!=0){break}if((c[ga>>2]|0)>(c[(c[q>>2]|0)+308>>2]|0)){break c}}}while(0);za=(ta|0)>0;do{if((c[B>>2]|0)==-128){if(!za){break}sa=(ua|0)>0;Aa=0;do{if(sa){Ca=ca(Aa,ua)|0;Ea=c[ea>>2]|0;Ga=c[ha>>2]|0;ya=0;do{Ba=ya+Ca|0;c[Ga+(Ba<<2)>>2]=(b[Ea+(Ba<<1)>>1]|0)+7>>4;ya=ya+1|0;}while((ya|0)<(ua|0))}Aa=Aa+1|0;}while((Aa|0)<(ta|0))}else{if(!za){break}Aa=(ua|0)>0;sa=0;do{if(Aa){ya=ca(sa,ua)|0;Ea=c[ea>>2]|0;Ga=c[ha>>2]|0;Ca=0;do{Ba=Ca+ya|0;c[Ga+(Ba<<2)>>2]=b[Ea+(Ba<<1)>>1]<<4;Ca=Ca+1|0;}while((Ca|0)<(ua|0))}sa=sa+1|0;}while((sa|0)<(ta|0))}}while(0);e1a(c[ha>>2]|0,c[ia>>2]|0,ua,ta,ua,c[ja>>2]|0,c[M>>2]|0);g:do{if(!((c[R>>2]|0)==0|I^1)){if((c[M>>2]|0)>0){za=0;sa=0;while(1){Aa=o+7556+(za*66624|0)+8|0;Ca=o+7556+(za*66624|0)+12|0;Ea=(za|0)!=0|0;Ga=sa;while(1){ya=c[o+7556+(za*66624|0)+(Ea*16656|0)+24>>2]|0;Ba=c[o+7556+(za*66624|0)+(Ea*16656|0)+8>>2]|0;Fa=c[o+7556+(za*66624|0)+(Ea*16656|0)+12>>2]|0;Wa=c[o+7556+(za*66624|0)+(Ea*16656|0)+4>>2]|0;Xa=(c[o+7556+(za*66624|0)+(Ea*16656|0)+16>>2]|0)+64|0;if((Xa|0)<0){bc=0}else{bc=(Xa|0)>512?512:Xa}Xa=65536/(d[6549120+(bc&31)|0]<<(bc>>5)|0)|0;La=(Fa|0)>0;if(La){Ma=(Ba|0)>0;Ia=o+7556+(za*66624|0)+(Ea*16656|0)+20|0;Na=0;do{if(Ma){lb=ca(Na,Wa)|0;Ha=c[Ia>>2]|0;kb=0;do{jb=kb+lb|0;b[ya+(jb<<1)>>1]=c[Ha+(jb<<2)>>2];kb=kb+1|0;}while((kb|0)<(Ba|0))}Na=Na+1|0;}while((Na|0)<(Fa|0))}if((Ea|0)==0){G1a(c[Aa>>2]|0,c[Ca>>2]|0,ya,Wa)}if(La){Na=(Ba|0)>0;Ia=Ga;Ma=0;while(1){if(Na){kb=ca(Ma,Wa)|0;Ha=Ia;lb=0;while(1){jb=b[ya+(lb+kb<<1)>>1]|0;ib=jb<<16>>16;eb=((ca(jb<<16>>16>-1?ib:-ib|0,Xa)|0)>>16)+Ha|0;ib=lb+1|0;if((ib|0)<(Ba|0)){Ha=eb;lb=ib}else{cc=eb;break}}}else{cc=Ia}lb=Ma+1|0;if((lb|0)<(Fa|0)){Ia=cc;Ma=lb}else{dc=cc;break}}}else{dc=Ga}Ma=Ea+1|0;if((Ma|0)<4){Ea=Ma;Ga=dc}else{break}}Ga=za+1|0;if((Ga|0)<(c[M>>2]|0)){za=Ga;sa=dc}else{break}}if(dc>>>0<2147483647>>>0){ec=dc}else{U=187;break a}}else{ec=0}sa=ec;za=0;Ga=Erc(sa,za,sa,za)|0;za=G;sa=Ga>>>16|za<<16|0;Ga=(za>>>16|0<<16)&0;if((c[J>>2]|0)==1){c[ka>>2]=sa;c[ka+4>>2]=Ga;c[la>>2]=0;c[la+4>>2]=0}else{c[la>>2]=sa;c[la+4>>2]=Ga;c[ka>>2]=0;c[ka+4>>2]=0}Ga=~~+dZa(F,1);c[Q>>2]=Ga;if((Ga|0)<0){x=-1;U=531;break a}c[ma>>2]=(Ga*3|0|0)/2|0;Ga=~~(+Lc(+(+lc(+(+(c[Q>>2]|0)/118.0))*32.0))+244.0);sa=Ga-(c[B>>2]|0)|0;c[B>>2]=Ga;if((sa|0)==0){break}else if((sa|0)==(-2147483648|0)){x=-1;U=531;break a}SYa(p,c[w>>2]|0,c[v>>2]|0);nrc(X|0,Y|0,32)|0;nrc(Z|0,_|0,4224)|0;F1a(o);sa=c[r>>2]|0;Ga=c[u>>2]|0;if((Ga|0)<=0){break}za=sa*768|0;Ea=(sa|0)>0;Ca=0;while(1){if(((c[O>>2]|0)-(c[D>>2]|0)|0)<(za|0)){break}if(Ea){Aa=0;do{J1a(o,0,Aa,Ca);Aa=Aa+1|0;}while((Aa|0)<(sa|0))}Ca=Ca+1|0;if((Ca|0)>=(Ga|0)){break g}}KIb(c[q>>2]|0,16,2142848,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V}}while(0);Ga=c[M>>2]|0;do{if((Ga|0)>0){Ca=0;do{sa=(Ca|0)!=0|0;while(1){Ea=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+24|0;za=c[Ea>>2]|0;Aa=c[ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+20>>2]|0;Ma=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+4|0;Ia=c[Ma>>2]|0;Fa=c[C>>2]|0;Ba=c[B>>2]|0;Xa=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+8|0;ya=c[Xa>>2]|0;Wa=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+12|0;Na=c[Wa>>2]|0;La=(c[ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+16>>2]|0)+Ba|0;if((La|0)<0){fc=0}else{fc=(La|0)>512?512:La}La=d[6549120+(fc&31)|0]<<(fc>>5)+4;h:do{if((Ba|0)==-128){if((Na|0)<=0){break}lb=(ya|0)>0;Ha=0;do{if(lb){kb=ca(Ha,Ia)|0;eb=0;do{ib=eb+kb|0;b[za+(ib<<1)>>1]=c[Aa+(ib<<2)>>2];eb=eb+1|0;}while((eb|0)<(ya|0))}Ha=Ha+1|0;}while((Ha|0)<(Na|0))}else{do{if((Fa|0)==0){Ha=(La*3|0)>>3;lb=(La-Ha>>11)-1|0;eb=lb<<1;if((Ha|0)==0){gc=lb;hc=eb;break}if((Na|0)<=0){break h}kb=(ya|0)>0;ib=0;while(1){if(kb){jb=ca(ib,Ia)|0;gb=0;do{$a=gb+jb|0;hb=c[Aa+($a<<2)>>2]|0;do{if((hb+lb|0)>>>0>eb>>>0){if((hb|0)>-1){b[za+($a<<1)>>1]=((hb<<11)+Ha|0)/(La|0)|0;break}else{b[za+($a<<1)>>1]=-(((hb*-2048|0)+Ha|0)/(La|0)|0);break}}else{b[za+($a<<1)>>1]=0}}while(0);gb=gb+1|0;}while((gb|0)<(ya|0))}ib=ib+1|0;if((ib|0)>=(Na|0)){break h}}}else{ib=(La>>11)-1|0;gc=ib;hc=ib<<1}}while(0);if((Na|0)<=0){break}ib=(ya|0)>0;Ha=0;do{if(ib){eb=ca(Ha,Ia)|0;lb=0;do{kb=lb+eb|0;gb=c[Aa+(kb<<2)>>2]|0;do{if((gb+gc|0)>>>0>hc>>>0){if((gb|0)>-1){b[za+(kb<<1)>>1]=(gb<<11|0)/(La|0)|0;break}else{b[za+(kb<<1)>>1]=-((-gb<<11|0)/(La|0)|0);break}}else{b[za+(kb<<1)>>1]=0}}while(0);lb=lb+1|0;}while((lb|0)<(ya|0))}Ha=Ha+1|0;}while((Ha|0)<(Na|0))}}while(0);La=(sa|0)==0;if(La){G1a(ya,Na,za,Ia)}i:do{if((c[qa>>2]|0)==0){Aa=c[Ea>>2]|0;Fa=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+44|0;Ba=c[Fa>>2]|0;if((Ba|0)==0){ic=0}else{ic=c[Ba+24>>2]|0}Ha=c[Ma>>2]|0;ib=c[Xa>>2]|0;lb=c[Wa>>2]|0;eb=c[ra>>2]|0;kb=(lb|0)>0;do{if(kb){gb=(ib|0)>0;jb=(ic|0)==0;$a=Ha<<1;hb=0;fb=0;Za=0;while(1){if(gb){db=ca(Za,Ha)|0;cb=(Za|0)==0;bb=Za>>1;ab=ca($a,bb)|0;_a=db-1|0;Ya=ca(Za-1|0,Ha)|0;sb=Ya-1|0;mb=hb;pb=fb;Nb=0;while(1){qb=b[Aa+(Nb+db<<1)>>1]|0;do{if(cb){jc=0;kc=0;mc=0}else{Zb=b[Aa+(Nb+Ya<<1)>>1]|0;if((Nb|0)==0){nc=0}else{nc=b[Aa+(sb+Nb<<1)>>1]|0}Yb=Nb+1|0;if((Yb|0)>=(ib|0)){jc=nc;kc=Zb;mc=0;break}jc=nc;kc=Zb;mc=b[Aa+(Yb+Ya<<1)>>1]|0}}while(0);if((Nb|0)==0){oc=0}else{oc=b[Aa+(_a+Nb<<1)>>1]|0}do{if(jb){pc=0}else{Yb=Nb>>1;if((Yb|0)>=(c[Ba+8>>2]|0)){pc=0;break}if((bb|0)>=(c[Ba+12>>2]|0)){pc=0;break}pc=b[ic+(Yb+ab<<1)>>1]|0}}while(0);do{if((kc|mc|jc|oc|pc|0)==0){if(qb<<16>>16==0){qc=pb+1|0;rc=mb;break}else{c[eb+(mb<<2)>>2]=pb;qc=0;rc=mb+1|0;break}}else{qc=pb;rc=mb}}while(0);qb=Nb+1|0;if((qb|0)<(ib|0)){mb=rc;pb=qc;Nb=qb}else{sc=rc;tc=qc;break}}}else{sc=hb;tc=fb}Nb=Za+1|0;if((Nb|0)<(lb|0)){hb=sc;fb=tc;Za=Nb}else{break}}c[eb+(sc<<2)>>2]=tc;Za=c[eb>>2]|0;fb=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+1012|0;if((sc|0)<1){uc=sc;vc=Za;wc=fb;U=265;break}else{xc=sc;yc=0;zc=1;Ac=fb}while(1){H1a(p,Ac,1);Bc=xc-zc|0;Cc=yc+1|0;Dc=(Cc|0)>0;fb=zc<<(Dc&1);Ec=yc+5+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+1008)|0;if((Bc|0)<(fb|0)){break}else{xc=Bc;yc=Cc;zc=fb;Ac=Ec}}H1a(p,Ec,0);if(Dc){Fc=Cc}else{Gc=sc;Hc=Za;break}while(1){fb=Fc-1|0;H1a(p,32-Fc+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+1008)|0,Bc>>>(fb>>>0)&1);if((fb|0)>0){Fc=fb}else{Gc=sc;Hc=Za;break}}}else{c[eb>>2]=0;uc=0;vc=0;wc=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+1012|0;U=265}}while(0);if((U|0)==265){U=0;H1a(p,wc,0);Gc=uc;Hc=vc}do{if((Gc|0)>0){Ba=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+87|0;if((Hc|0)<8){H1a(p,Ba,0);Ic=3;Jc=Hc}else{Za=Hc;fb=3;hb=8;jb=Ba;while(1){H1a(p,jb,1);Kc=Za-hb|0;Mc=fb+1|0;Nc=(Mc|0)>0;Ba=hb<<(Nc&1);Oc=fb+5+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+80)|0;if((Kc|0)<(Ba|0)){break}else{Za=Kc;fb=Mc;hb=Ba;jb=Oc}}H1a(p,Oc,0);if(Nc){Ic=Mc;Jc=Kc}else{break}}jb=Ic;while(1){hb=jb-1|0;H1a(p,32-jb+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+80)|0,Jc>>>(hb>>>0)&1);if((hb|0)>0){jb=hb}else{break}}}}while(0);if(!kb){Pc=Fa;break}jb=ib*40|0;hb=(ib|0)>0;fb=(ic|0)==0;Za=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+87|0;Ba=Ha<<1;$a=1;gb=Hc;Nb=0;while(1){if(((c[O>>2]|0)-(c[D>>2]|0)|0)<(jb|0)){break}if(hb){pb=ca(Nb,Ha)|0;mb=(Nb|0)==0;ab=Nb>>1;bb=ca(Ba,ab)|0;_a=pb-1|0;Ya=ca(Nb-1|0,Ha)|0;sb=Ya-1|0;cb=$a;db=gb;qb=0;while(1){Yb=b[Aa+(qb+pb<<1)>>1]|0;Zb=Yb<<16>>16;do{if(mb){Qc=0;Rc=0;Sc=0}else{ub=b[Aa+(qb+Ya<<1)>>1]|0;if((qb|0)==0){Tc=0}else{Tc=b[Aa+(sb+qb<<1)>>1]|0}Ob=qb+1|0;if((Ob|0)>=(ib|0)){Qc=0;Rc=ub;Sc=Tc;break}Qc=b[Aa+(Ob+Ya<<1)>>1]|0;Rc=ub;Sc=Tc}}while(0);if((qb|0)==0){Uc=0}else{Uc=b[Aa+(_a+qb<<1)>>1]|0}do{if(fb){Vc=0}else{ub=qb>>1;Ob=c[Fa>>2]|0;if((ub|0)>=(c[Ob+8>>2]|0)){Vc=0;break}if((ab|0)>=(c[Ob+12>>2]|0)){Vc=0;break}Vc=b[ic+(ub+bb<<1)>>1]|0}}while(0);do{if((Rc|Sc|Qc|Uc|Vc|0)==0){if((db|0)!=0){Wc=db-1|0;Xc=cb;break}ub=cb+1|0;Ob=c[eb+(cb<<2)>>2]|0;if((ub|0)>(Gc|0)){Wc=Ob;Xc=ub;break}if((Ob|0)<8){H1a(p,Za,0);Yc=3;Zc=Ob}else{tb=Ob;ob=3;rb=8;nb=Za;while(1){H1a(p,nb,1);_c=tb-rb|0;$c=ob+1|0;ad=($c|0)>0;ac=rb<<(ad&1);bd=ob+5+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+80)|0;if((_c|0)<(ac|0)){break}else{tb=_c;ob=$c;rb=ac;nb=bd}}H1a(p,bd,0);if(ad){Yc=$c;Zc=_c}else{Wc=Ob;Xc=ub;break}}nb=Yc;while(1){rb=nb-1|0;H1a(p,32-nb+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+80)|0,Zc>>>(rb>>>0)&1);if((rb|0)>0){nb=rb}else{Wc=Ob;Xc=ub;break}}}else{ub=(((Rc|0)>-1?Rc:-Rc|0)<<1)+((Sc|0)>-1?Sc:-Sc|0)+((Qc|0)>-1?Qc:-Qc|0)+(((Uc|0)>-1?Uc:-Uc|0)*3|0)+((Vc|0)>-1?Vc:-Vc|0)|0;Ob=ub>>>0>65535>>>0;nb=Ob?ub>>>16:ub;ub=Ob?16:0;if((nb&65280|0)==0){cd=ub;dd=nb}else{cd=ub|8;dd=nb>>>8}H1a(p,(d[1359664+dd|0]|0)+cd+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48)|0,Yb<<16>>16!=0|0);Wc=db;Xc=cb}}while(0);if(!(Yb<<16>>16==0)){nb=(Uc|0)>-1?Uc:-Uc|0;ub=((Rc|0)>-1?Rc:-Rc|0)<<1;Ob=ub+((Sc|0)>-1?Sc:-Sc|0)+((Qc|0)>-1?Qc:-Qc|0)+(nb*3|0)+((Vc|0)>-1?Vc:-Vc|0)|0;rb=Ob>>>0>65535>>>0;ob=rb?Ob>>>16:Ob;Ob=rb?16:0;if((ob&65280|0)==0){ed=Ob;fd=ob}else{ed=Ob|8;fd=ob>>>8}ob=(d[1359664+fd|0]|0)+ed|0;Ob=nb<<1;nb=Uc>>>31;rb=Rc>>>31;tb=ob+2|0;ac=(Yb<<16>>16>-1?Zb:-Zb|0)-1|0;_b=ob-4|0;$b=(_b|0)>-1?1<<_b:1;gd=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48+(tb<<5)+ob|0;if(($b|0)>(ac|0)){hd=ac;id=_b;jd=gd}else{ob=ac;ac=_b;_b=$b;$b=gd;while(1){H1a(p,$b,1);gd=ob-_b|0;kd=ac+1|0;ld=_b<<((kd|0)>0);md=ac+5+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48+(tb<<5))|0;if((gd|0)<(ld|0)){hd=gd;id=kd;jd=md;break}else{ob=gd;ac=kd;_b=ld;$b=md}}}H1a(p,jd,0);if((id|0)>0){$b=id;while(1){_b=$b-1|0;H1a(p,32-$b+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48+(tb<<5))|0,hd>>>(_b>>>0)&1);if((_b|0)>0){$b=_b}else{break}}}H1a(p,(a[1319992+(Ob&254|nb)|0]|0)+20+((a[1319992+(ub&254|rb)|0]|0)*3|0)+(ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+48)|0,(Yb&65535)>>>15&65535)}$b=qb+1|0;if(($b|0)<(ib|0)){cb=Xc;db=Wc;qb=$b}else{nd=Xc;od=Wc;break}}}else{nd=$a;od=gb}qb=Nb+1|0;if((qb|0)<(lb|0)){$a=nd;gb=od;Nb=qb}else{Pc=Fa;break i}}KIb(c[q>>2]|0,16,2142848,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V;Pc=Fa}else{Pc=ba+(Ra*533028|0)+8+(Ca*66624|0)+(sa*16656|0)+44|0}}while(0);Ia=c[Pc>>2]|0;if((Ia|0)!=0){if((c[Ia+4>>2]|0)!=(c[Ma>>2]<<1|0)){U=318;break a}}if(La){Ia=c[Ea>>2]|0;za=c[Ma>>2]|0;Na=c[Xa>>2]|0;ya=c[Wa>>2]|0;if((ya|0)<=0){sa=sa+1|0;continue}Nb=(Na|0)>0;gb=0;do{if(Nb){$a=ca(gb,za)|0;lb=(gb|0)==0;ib=0;do{Za=ib+$a|0;do{if((ib|0)==0){if(lb){break}eb=Ia+(Za<<1)|0;b[eb>>1]=(b[eb>>1]|0)+(b[Ia+(Za-za<<1)>>1]|0)}else{eb=Za-1|0;fb=b[Ia+(eb<<1)>>1]|0;Aa=fb<<16>>16;if(lb){Ha=Ia+(Za<<1)|0;b[Ha>>1]=(b[Ha>>1]|0)+fb;break}Ha=b[Ia+(Za-za<<1)>>1]|0;Ba=Ha<<16>>16;hb=Ba+Aa-(b[Ia+(eb-za<<1)>>1]|0)|0;do{if(fb<<16>>16>Ha<<16>>16){if((hb|0)<=(Ba|0)){pd=Ba;break}pd=(hb|0)>(Aa|0)?Aa:hb}else{if((Ba|0)<=(hb|0)){pd=Ba;break}pd=(hb|0)>(Aa|0)?hb:Aa}}while(0);Aa=Ia+(Za<<1)|0;b[Aa>>1]=(e[Aa>>1]|0)+pd}}while(0);ib=ib+1|0;}while((ib|0)<(Na|0))}gb=gb+1|0;}while((gb|0)<(ya|0))}sa=sa+1|0;if((sa|0)>=4){break}}Ca=Ca+1|0;qd=c[M>>2]|0;}while((Ca|0)<(qd|0));if((qd|0)<=0){rd=qd;break}Ca=c[B>>2]|0;sa=0;while(1){ya=(sa|0)!=0|0;do{gb=c[ba+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+24>>2]|0;Na=c[ba+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+4>>2]|0;Ia=c[ba+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+8>>2]|0;za=c[ba+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+12>>2]|0;Nb=Ca+(c[ba+(Ra*533028|0)+8+(sa*66624|0)+(ya*16656|0)+16>>2]|0)|0;if((Nb|0)<0){sd=0}else{sd=(Nb|0)>512?512:Nb}Nb=d[6549120+(sd&31)|0]<<(sd>>5);Wa=(ca(Nb,c[C>>2]|0)|0)>>3;if((Ca|0)!=-128&(za|0)>0){Xa=(Ia|0)>0;Ma=0;do{if(Xa){Ea=ca(Ma,Na)|0;La=0;do{ib=gb+(La+Ea<<1)|0;lb=b[ib>>1]|0;$a=lb<<16>>16;do{if(lb<<16>>16<0){b[ib>>1]=-((Wa-(ca($a,Nb)|0)|0)>>>11)}else{if(!(lb<<16>>16>0)){break}b[ib>>1]=((ca($a,Nb)|0)+Wa|0)>>>11}}while(0);La=La+1|0;}while((La|0)<(Ia|0))}Ma=Ma+1|0;}while((Ma|0)<(za|0))}ya=ya+1|0;}while((ya|0)<4);ya=sa+1|0;if((ya|0)<(qd|0)){sa=ya}else{rd=qd;break}}}else{rd=Ga}}while(0);j1a(c[ea>>2]|0,c[na>>2]|0,ua,ta,ua,c[ja>>2]|0,rd);if((c[B>>2]|0)==-128&(ta|0)>0){Ga=(ua|0)>0;sa=0;do{if(Ga){Ca=ca(sa,ua)|0;ya=c[ea>>2]|0;za=0;do{Ma=ya+(za+Ca<<1)|0;b[Ma>>1]=b[Ma>>1]<<4;za=za+1|0;}while((za|0)<(ua|0))}sa=sa+1|0;}while((sa|0)<(ta|0))}sa=c[ea>>2]|0;Ga=c[u>>2]|0;za=c[fa>>2]|0;Ca=Ga<<za;if((Ca|0)<0){break}ya=o+7548+(Ra*533028|0)|0;Ma=o+7548+(Ra*533028|0)+4|0;Ia=0;Wa=za;za=Ga;while(1){Ga=c[r>>2]|0;Nb=Ga<<Wa;gb=za<<Wa;Na=16>>>(Wa>>>0);if(I){td=Na<<1;ud=Na;vd=Na;wd=Wa}else{Xa=c[K>>2]|0;td=Na<<1>>Xa;ud=Na>>c[m>>2];vd=Na>>Xa;wd=Xa+Wa|0}Xa=c[1335352+(wd<<2)>>2]|0;Na=c[T>>2]|0;La=c[Na+32+(Ra<<2)>>2]|0;Ea=c[Na+(Ra<<2)>>2]|0;Na=c[ya>>2]|0;$a=c[Ma>>2]|0;j:do{if((c[N>>2]|0)==0){if((c[(c[q>>2]|0)+688>>2]&512|0)!=0){U=372;break}if((Nb|0)<0){break}ib=(vd|0)/2|0;lb=(ca(ud,Ia)|0)-((ud|0)/2|0)|0;Fa=Ia-1|0;Za=(La|0)>111?16:La<<4;Aa=(Fa|0)<0;hb=(lb|0)<0;Ba=ca(lb,-td|0)|0;Ha=lb+ud|0;fb=Za*3|0;Yb=fb+Za|0;rb=td>>1;ub=Yb+Za|0;nb=0;Ob=Ga;eb=Wa;jb=za;while(1){kb=(ca(nb,vd)|0)-ib|0;qb=nb-1|0;db=Ob<<eb;cb=ca(db,Fa)|0;bb=cb+qb|0;ab=c[oa>>2]|0;_a=ab+(bb*10|0)|0;Ya=ab+((cb+nb|0)*10|0)|0;cb=bb+db|0;bb=ab+(cb*10|0)|0;sb=ab+((cb+1|0)*10|0)|0;cb=c[pa>>2]|0;if((qb|0)<0){xd=sb;yd=sb;zd=Ya;Ad=Ya}else{qb=(nb|0)<(db|0);xd=qb?sb:bb;yd=bb;zd=qb?Ya:_a;Ad=_a}if(Aa){Bd=xd;Cd=yd;Dd=xd;Ed=yd}else{_a=(jb<<eb|0)>(Ia|0);Bd=_a?xd:zd;Cd=_a?yd:Ad;Dd=zd;Ed=Ad}if((kb|0)<0){Fd=Xa+(-kb|0)|0;Gd=0;Id=kb+vd|0}else{Fd=Xa;Gd=kb;Id=vd}kb=(Gd+Id|0)>(Na|0)?Na-Gd|0:Id;if(hb){Jd=Fd+Ba|0;Kd=0;Ld=Ha}else{Jd=Fd;Kd=lb;Ld=ud}_a=(Kd+Ld|0)>($a|0)?$a-Kd|0:Ld;do{if(!((kb|0)<1|(_a|0)<1)){Ya=(ca(Kd,La)|0)+Gd|0;qb=cb+fb|0;bb=cb+Yb|0;wtb(o,qb,cb,La,Gd,Kd,kb,_a,Ed,Ra,Na,$a);sb=Ed+8|0;db=a[sb]|0;ab=Dd+8|0;mb=a[ab]|0;do{if((db&1)==0){U=393}else{if((mb&1)==0){U=393;break}Md=(d[Ed+6|0]|0)-(d[Dd+6|0]|0)|(d[Ed+5|0]|0)-(d[Dd+5|0]|0)|(d[Ed+7|0]|0)-(d[Dd+7|0]|0)}}while(0);if((U|0)==393){U=0;Md=(b[Ed>>1]|0)-(b[Dd>>1]|0)|(mb^db)&1|(b[Ed+2>>1]|0)-(b[Dd+2>>1]|0)|(d[Ed+4|0]|0)-(d[Dd+4|0]|0)}if((Md|0)==0){Nd=bb;Od=qb;Pd=db}else{wtb(o,bb,cb,La,Gd,Kd,kb,_a,Dd,Ra,Na,$a);Nd=cb+ub|0;Od=bb;Pd=a[sb]|0}pb=Cd+8|0;$b=a[pb]|0;do{if((Pd&1)==0){U=399}else{if(($b&1)==0){U=399;break}Qd=(d[Ed+6|0]|0)-(d[Cd+6|0]|0)|(d[Ed+5|0]|0)-(d[Cd+5|0]|0)|(d[Ed+7|0]|0)-(d[Cd+7|0]|0)}}while(0);if((U|0)==399){U=0;Qd=(b[Ed>>1]|0)-(b[Cd>>1]|0)|($b^Pd)&1|(b[Ed+2>>1]|0)-(b[Cd+2>>1]|0)|(d[Ed+4|0]|0)-(d[Cd+4|0]|0)}do{if((Qd|0)==0){Rd=Nd;Sd=qb;Td=Pd}else{bb=a[ab]|0;do{if((bb&1)==0){U=404}else{if(($b&1)==0){U=404;break}Ud=(d[Dd+6|0]|0)-(d[Cd+6|0]|0)|(d[Dd+5|0]|0)-(d[Cd+5|0]|0)|(d[Dd+7|0]|0)-(d[Cd+7|0]|0)}}while(0);if((U|0)==404){U=0;Ud=(b[Dd>>1]|0)-(b[Cd>>1]|0)|(bb^$b)&1|(b[Dd+2>>1]|0)-(b[Cd+2>>1]|0)|(d[Dd+4|0]|0)-(d[Cd+4|0]|0)}if((Ud|0)==0){Rd=Nd;Sd=Od;Td=Pd;break}wtb(o,Nd,cb,La,Gd,Kd,kb,_a,Cd,Ra,Na,$a);Rd=Nd+Za|0;Sd=Nd;Td=a[sb]|0}}while(0);sb=a[Bd+8|0]|0;do{if((Td&1)==0){U=410}else{if((sb&1)==0){U=410;break}Vd=(d[Ed+6|0]|0)-(d[Bd+6|0]|0)|(d[Ed+5|0]|0)-(d[Bd+5|0]|0)|(d[Ed+7|0]|0)-(d[Bd+7|0]|0)}}while(0);if((U|0)==410){U=0;Vd=(b[Ed>>1]|0)-(b[Bd>>1]|0)|(sb^Td)&1|(b[Ed+2>>1]|0)-(b[Bd+2>>1]|0)|(d[Ed+4|0]|0)-(d[Bd+4|0]|0)}do{if((Vd|0)==0){Wd=qb}else{$b=a[ab]|0;do{if(($b&1)==0){U=415}else{if((sb&1)==0){U=415;break}Xd=(d[Dd+6|0]|0)-(d[Bd+6|0]|0)|(d[Dd+5|0]|0)-(d[Bd+5|0]|0)|(d[Dd+7|0]|0)-(d[Bd+7|0]|0)}}while(0);if((U|0)==415){U=0;Xd=(b[Dd>>1]|0)-(b[Bd>>1]|0)|($b^sb)&1|(b[Dd+2>>1]|0)-(b[Bd+2>>1]|0)|(d[Dd+4|0]|0)-(d[Bd+4|0]|0)}if((Xd|0)==0){Wd=Od;break}bb=a[pb]|0;do{if((bb&1)==0){U=420}else{if((sb&1)==0){U=420;break}Yd=(d[Cd+6|0]|0)-(d[Bd+6|0]|0)|(d[Cd+5|0]|0)-(d[Bd+5|0]|0)|(d[Cd+7|0]|0)-(d[Bd+7|0]|0)}}while(0);if((U|0)==420){U=0;Yd=(b[Cd>>1]|0)-(b[Bd>>1]|0)|(bb^sb)&1|(b[Cd+2>>1]|0)-(b[Bd+2>>1]|0)|(d[Cd+4|0]|0)-(d[Bd+4|0]|0)}if((Yd|0)==0){Wd=Sd;break}wtb(o,Rd,cb,La,Gd,Kd,kb,_a,Bd,Ra,Na,$a);Wd=Rd}}while(0);if((_a|0)<=0){break}sb=(kb|0)>0;pb=0;do{ab=ca(pb,td)|0;qb=ab+rb|0;$b=ca(pb+rb|0,td)|0;db=$b+rb|0;if(sb){mb=ca(pb,La)|0;tb=(ca(pb+Kd|0,Na)|0)+Gd|0;_b=0;do{ac=_b+mb|0;ob=ca(d[Wd+ac|0]|0,d[Jd+(_b+ab)|0]|0)|0;Zb=(ca(d[Sd+ac|0]|0,d[Jd+(qb+_b)|0]|0)|0)+ob|0;ob=Zb+(ca(d[Od+ac|0]|0,d[Jd+(_b+$b)|0]|0)|0)|0;Zb=(ob+(ca(d[cb+(ac+fb)|0]|0,d[Jd+(db+_b)|0]|0)|0)|0)>>>4;ob=(b[sa+(tb+_b<<1)>>1]|0)+8+Zb|0;Zb=ob>>4;if(Zb>>>0>255>>>0){Zd=(ob>>31^255)&255}else{Zd=Zb&255}a[Ea+(Ya+ac)|0]=Zd;_b=_b+1|0;}while((_b|0)<(kb|0))}pb=pb+1|0;}while((pb|0)<(_a|0))}}while(0);_a=nb+1|0;if((_a|0)>(Nb|0)){break j}nb=_a;Ob=c[r>>2]|0;eb=c[fa>>2]|0;jb=c[u>>2]|0}}else{U=372}}while(0);do{if((U|0)==372){U=0;if((gb|0)==(Ia|0)){break}Nb=ca(ud,Ia)|0;Xa=ca(ud,Ia+1|0)|0;Ga=($a|0)>(Xa|0)?Xa:$a;if((Nb|0)>=(Ga|0)){break}Xa=(Na|0)>0;jb=Nb;do{if(Xa){Nb=ca(jb,Na)|0;eb=ca(jb,La)|0;Ob=0;do{nb=(b[sa+(Ob+Nb<<1)>>1]|0)+2056|0;fb=nb>>4;if(fb>>>0>255>>>0){_d=(nb>>31^255)&255}else{_d=fb&255}a[Ea+(Ob+eb)|0]=_d;Ob=Ob+1|0;}while((Ob|0)<(Na|0))}jb=jb+1|0;}while((jb|0)<(Ga|0))}}while(0);Na=Ia+1|0;if((Na|0)>(Ca|0)){break d}Ia=Na;Wa=c[fa>>2]|0;za=c[u>>2]|0}}else{if((c[J>>2]|0)==1){if((ta|0)<=0){break}za=(ua|0)>0;Wa=h+32+(Ra<<2)|0;Ia=h+(Ra<<2)|0;Ca=0;while(1){if(za){sa=0;do{Ma=(ca(c[Wa>>2]|0,Ca)|0)+sa|0;ya=c[T>>2]|0;I=(ca(c[ya+32+(Ra<<2)>>2]|0,Ca)|0)+sa|0;a[(c[ya+(Ra<<2)>>2]|0)+I|0]=a[(c[Ia>>2]|0)+Ma|0]|0;sa=sa+1|0;}while((sa|0)<(ua|0))}Ca=Ca+1|0;if((Ca|0)>=(ta|0)){break d}}}mrc(c[ea>>2]|0,0,ca(ua<<1,ta)|0)|0;Ca=c[ea>>2]|0;Ia=c[u>>2]|0;Wa=c[fa>>2]|0;za=Ia<<Wa;if((za|0)<0){break}sa=(Ra|0)==0;Ma=o+7548+(Ra*533028|0)|0;I=o+7548+(Ra*533028|0)+4|0;ya=0;Na=Wa;Wa=Ia;while(1){Ia=c[r>>2]|0;Ea=Ia<<Na;La=Wa<<Na;$a=16>>>(Na>>>0);if(sa){$d=$a<<1;ae=$a;be=$a;ce=Na}else{gb=c[K>>2]|0;$d=$a<<1>>gb;ae=$a>>c[m>>2];be=$a>>gb;ce=gb+Na|0}gb=c[1335352+(ce<<2)>>2]|0;$a=c[T>>2]|0;Ga=c[$a+32+(Ra<<2)>>2]|0;jb=c[$a+(Ra<<2)>>2]|0;$a=c[Ma>>2]|0;Xa=c[I>>2]|0;k:do{if((c[N>>2]|0)==0){if((c[(c[q>>2]|0)+688>>2]&512|0)!=0){U=450;break}if((Ea|0)<0){break}Ob=(be|0)/2|0;eb=(ca(ae,ya)|0)-((ae|0)/2|0)|0;Nb=ya-1|0;fb=(Ga|0)>111?16:Ga<<4;nb=(Nb|0)<0;rb=(eb|0)<0;Za=ca(eb,-$d|0)|0;ub=eb+ae|0;Yb=fb*3|0;lb=Yb+fb|0;Ha=$d>>1;Ba=lb+fb|0;hb=0;Aa=Ia;Fa=Na;ib=Wa;while(1){_a=(ca(hb,be)|0)-Ob|0;kb=hb-1|0;cb=Aa<<Fa;pb=ca(cb,Nb)|0;Ya=pb+kb|0;sb=c[oa>>2]|0;_b=sb+(Ya*10|0)|0;tb=sb+((pb+hb|0)*10|0)|0;pb=Ya+cb|0;Ya=sb+(pb*10|0)|0;db=sb+((pb+1|0)*10|0)|0;pb=c[pa>>2]|0;if((kb|0)<0){de=db;ee=db;fe=tb;ge=tb}else{kb=(hb|0)<(cb|0);de=kb?db:Ya;ee=Ya;fe=kb?tb:_b;ge=_b}if(nb){he=de;ie=ee;je=de;ke=ee}else{_b=(ib<<Fa|0)>(ya|0);he=_b?de:fe;ie=_b?ee:ge;je=fe;ke=ge}if((_a|0)<0){le=gb+(-_a|0)|0;me=0;ne=_a+be|0}else{le=gb;me=_a;ne=be}_a=(me+ne|0)>($a|0)?$a-me|0:ne;if(rb){oe=le+Za|0;pe=0;qe=ub}else{oe=le;pe=eb;qe=ae}_b=(pe+qe|0)>(Xa|0)?Xa-pe|0:qe;do{if(!((_a|0)<1|(_b|0)<1)){tb=(ca(pe,Ga)|0)+me|0;kb=pb+Yb|0;Ya=pb+lb|0;wtb(o,kb,pb,Ga,me,pe,_a,_b,ke,Ra,$a,Xa);db=ke+8|0;cb=a[db]|0;sb=je+8|0;$b=a[sb]|0;do{if((cb&1)==0){U=471}else{if(($b&1)==0){U=471;break}re=(d[ke+6|0]|0)-(d[je+6|0]|0)|(d[ke+5|0]|0)-(d[je+5|0]|0)|(d[ke+7|0]|0)-(d[je+7|0]|0)}}while(0);if((U|0)==471){U=0;re=(b[ke>>1]|0)-(b[je>>1]|0)|($b^cb)&1|(b[ke+2>>1]|0)-(b[je+2>>1]|0)|(d[ke+4|0]|0)-(d[je+4|0]|0)}if((re|0)==0){se=Ya;te=kb;ue=cb}else{wtb(o,Ya,pb,Ga,me,pe,_a,_b,je,Ra,$a,Xa);se=pb+Ba|0;te=Ya;ue=a[db]|0}qb=ie+8|0;ab=a[qb]|0;do{if((ue&1)==0){U=477}else{if((ab&1)==0){U=477;break}ve=(d[ke+6|0]|0)-(d[ie+6|0]|0)|(d[ke+5|0]|0)-(d[ie+5|0]|0)|(d[ke+7|0]|0)-(d[ie+7|0]|0)}}while(0);if((U|0)==477){U=0;ve=(b[ke>>1]|0)-(b[ie>>1]|0)|(ab^ue)&1|(b[ke+2>>1]|0)-(b[ie+2>>1]|0)|(d[ke+4|0]|0)-(d[ie+4|0]|0)}do{if((ve|0)==0){we=se;xe=kb;ye=ue}else{Ya=a[sb]|0;do{if((Ya&1)==0){U=482}else{if((ab&1)==0){U=482;break}ze=(d[je+6|0]|0)-(d[ie+6|0]|0)|(d[je+5|0]|0)-(d[ie+5|0]|0)|(d[je+7|0]|0)-(d[ie+7|0]|0)}}while(0);if((U|0)==482){U=0;ze=(b[je>>1]|0)-(b[ie>>1]|0)|(Ya^ab)&1|(b[je+2>>1]|0)-(b[ie+2>>1]|0)|(d[je+4|0]|0)-(d[ie+4|0]|0)}if((ze|0)==0){we=se;xe=te;ye=ue;break}wtb(o,se,pb,Ga,me,pe,_a,_b,ie,Ra,$a,Xa);we=se+fb|0;xe=se;ye=a[db]|0}}while(0);db=a[he+8|0]|0;do{if((ye&1)==0){U=488}else{if((db&1)==0){U=488;break}Ae=(d[ke+6|0]|0)-(d[he+6|0]|0)|(d[ke+5|0]|0)-(d[he+5|0]|0)|(d[ke+7|0]|0)-(d[he+7|0]|0)}}while(0);if((U|0)==488){U=0;Ae=(b[ke>>1]|0)-(b[he>>1]|0)|(db^ye)&1|(b[ke+2>>1]|0)-(b[he+2>>1]|0)|(d[ke+4|0]|0)-(d[he+4|0]|0)}do{if((Ae|0)==0){Be=kb}else{ab=a[sb]|0;do{if((ab&1)==0){U=493}else{if((db&1)==0){U=493;break}Ce=(d[je+6|0]|0)-(d[he+6|0]|0)|(d[je+5|0]|0)-(d[he+5|0]|0)|(d[je+7|0]|0)-(d[he+7|0]|0)}}while(0);if((U|0)==493){U=0;Ce=(b[je>>1]|0)-(b[he>>1]|0)|(ab^db)&1|(b[je+2>>1]|0)-(b[he+2>>1]|0)|(d[je+4|0]|0)-(d[he+4|0]|0)}if((Ce|0)==0){Be=te;break}Ya=a[qb]|0;do{if((Ya&1)==0){U=498}else{if((db&1)==0){U=498;break}De=(d[ie+6|0]|0)-(d[he+6|0]|0)|(d[ie+5|0]|0)-(d[he+5|0]|0)|(d[ie+7|0]|0)-(d[he+7|0]|0)}}while(0);if((U|0)==498){U=0;De=(b[ie>>1]|0)-(b[he>>1]|0)|(Ya^db)&1|(b[ie+2>>1]|0)-(b[he+2>>1]|0)|(d[ie+4|0]|0)-(d[he+4|0]|0)}if((De|0)==0){Be=xe;break}wtb(o,we,pb,Ga,me,pe,_a,_b,he,Ra,$a,Xa);Be=we}}while(0);if((_b|0)<=0){break}db=(_a|0)>0;qb=0;do{sb=ca(qb,$d)|0;kb=sb+Ha|0;ab=ca(qb+Ha|0,$d)|0;cb=ab+Ha|0;if(db){$b=ca(qb,Ga)|0;mb=(ca(qb+pe|0,$a)|0)+me|0;bb=0;do{ac=bb+$b|0;Zb=ca(d[Be+ac|0]|0,d[oe+(bb+sb)|0]|0)|0;ob=(ca(d[xe+ac|0]|0,d[oe+(kb+bb)|0]|0)|0)+Zb|0;Zb=ob+(ca(d[te+ac|0]|0,d[oe+(bb+ab)|0]|0)|0)|0;ob=(Zb+(ca(d[pb+(ac+Yb)|0]|0,d[oe+(cb+bb)|0]|0)|0)|0)>>>4;Zb=(b[Ca+(mb+bb<<1)>>1]|0)+8+ob|0;ob=Zb>>4;if(ob>>>0>255>>>0){Ee=(Zb>>31^255)&255}else{Ee=ob&255}a[jb+(tb+ac)|0]=Ee;bb=bb+1|0;}while((bb|0)<(_a|0))}qb=qb+1|0;}while((qb|0)<(_b|0))}}while(0);_b=hb+1|0;if((_b|0)>(Ea|0)){break k}hb=_b;Aa=c[r>>2]|0;Fa=c[fa>>2]|0;ib=c[u>>2]|0}}else{U=450}}while(0);do{if((U|0)==450){U=0;if((La|0)==(ya|0)){break}Ea=ca(ae,ya)|0;gb=ca(ae,ya+1|0)|0;Ia=(Xa|0)>(gb|0)?gb:Xa;if((Ea|0)>=(Ia|0)){break}gb=($a|0)>0;ib=Ea;do{if(gb){Ea=ca(ib,$a)|0;Fa=ca(ib,Ga)|0;Aa=0;do{hb=(b[Ca+(Aa+Ea<<1)>>1]|0)+2056|0;Yb=hb>>4;if(Yb>>>0>255>>>0){Fe=(hb>>31^255)&255}else{Fe=Yb&255}a[jb+(Aa+Fa)|0]=Fe;Aa=Aa+1|0;}while((Aa|0)<($a|0))}ib=ib+1|0;}while((ib|0)<(Ia|0))}}while(0);$a=ya+1|0;if(($a|0)>(za|0)){break d}ya=$a;Na=c[fa>>2]|0;Wa=c[u>>2]|0}}}while(0);Wa=c[q>>2]|0;if((c[Wa+88>>2]&32768|0)!=0){Na=c[h+(Ra<<2)>>2]|0;if((Na|0)!=0&(ta|0)>0){ya=(ua|0)>0;za=h+32+(Ra<<2)|0;Ca=0;I=0;Ma=0;while(1){if(ya){sa=c[T>>2]|0;$a=ca(c[sa+32+(Ra<<2)>>2]|0,Ca)|0;jb=c[sa+(Ra<<2)>>2]|0;sa=ca(c[za>>2]|0,Ca)|0;Ga=0;Xa=I;La=Ma;while(1){Ia=(d[jb+($a+Ga)|0]|0)-(d[Na+(sa+Ga)|0]|0)|0;ib=wrc(ca(Ia,Ia)|0,0,La,Xa)|0;Ia=G;gb=Ga+1|0;if((gb|0)<(ua|0)){Ga=gb;Xa=Ia;La=ib}else{Ge=Ia;He=ib;break}}}else{Ge=I;He=Ma}La=Ca+1|0;if((La|0)<(ta|0)){Ca=La;I=Ge;Ma=He}else{Ie=Ge;Je=He;break}}}else{Ie=0;Je=0}Ma=Wa+720+(Ra<<3)|0;I=wrc(c[Ma>>2]|0,c[Ma+4>>2]|0,Je,Ie)|0;c[Ma>>2]=I;c[Ma+4>>2]=G;Ma=(c[T>>2]|0)+224+(Ra<<3)|0;c[Ma>>2]=Je;c[Ma+4>>2]=Ie}Ma=Ra+1|0;if((Ma|0)<(c[z>>2]|0)){Ra=Ma}else{U=522;break a}}SYa(p,c[w>>2]|0,c[v>>2]|0);UYa(p,214748364,248);c[J>>2]=1;c[N>>2]=1;c[(c[T>>2]|0)+84>>2]=1}if((U|0)==42){KIb(f,16,2201728,(V=i,i=i+1|0,i=i+7&-8,c[V>>2]=0,V)|0);i=V;x=-22;i=k;return x|0}else if((U|0)==187){KIb(0,0,2446344,(V=i,i=i+24|0,c[V>>2]=2119296,c[V+8>>2]=2294072,c[V+16>>2]=1505,V)|0);i=V;Hd();return 0}else if((U|0)==318){KIb(0,0,2446344,(V=i,i=i+24|0,c[V>>2]=2169904,c[V+8>>2]=2294072,c[V+16>>2]=1765,V)|0);i=V;Hd();return 0}else if((U|0)==522){if((c[N>>2]|0)==0){c[n+540572>>2]=c[n+540556>>2];c[n+540564>>2]=c[n+540548>>2];N=n+540552|0;V=n+540568|0;y=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[n+1073600>>2]=c[n+1073584>>2];c[n+1073592>>2]=c[n+1073576>>2];V=n+1073580|0;N=n+1073596|0;y=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y}c[n+7364>>2]=c[ja>>2];c[n+7496>>2]=c[B>>2];c[n+7524>>2]=c[C>>2];c[n+7516>>2]=c[n+7512>>2];c[n+7540>>2]=c[fa>>2];c[W>>2]=c[M>>2];Itb(f);M=c[T>>2]|0;c[M+160>>2]=c[E>>2];c[M+88>>2]=c[J>>2];c[M+168>>2]=c[Q>>2];M=(c[D>>2]|0)-(c[L>>2]|0)<<3;L=n+2157016|0;c[L>>2]=M;D=n+2157476|0;c[D>>2]=M-((c[$>>2]|0)+(c[P>>2]|0));J=c[E>>2]|0;c[n+2151584>>2]=J;c[n+2151588>>2]=J;c[n+2151592>>2]=c[Q>>2];Q=n+2157008|0;J=wrc(M,(M|0)<0|0?-1:0,c[Q>>2]|0,c[Q+4>>2]|0)|0;c[Q>>2]=J;c[Q+4>>2]=G;do{if((c[R>>2]|0)!=0){if(+dZa(F,0)<0.0){x=-1}else{break}i=k;return x|0}}while(0);if((c[H>>2]&512|0)!=0){XYa(F)}c[n+2153800>>2]=c[l>>2];c[f+664>>2]=c[L>>2];c[f+632>>2]=c[$>>2];c[f+660>>2]=c[P>>2];c[f+644>>2]=c[D>>2];c[v>>2]=VYa(p)|0;if((c[(c[A>>2]|0)+84>>2]|0)!=0){A=g+36|0;c[A>>2]=c[A>>2]|1}c[j>>2]=1;x=0;i=k;return x|0}else if((U|0)==531){i=k;return x|0}return 0}function E1a(a){a=a|0;var b=0;b=c[a+60>>2]|0;Ktb(b);aZa(b+2143800|0);VHb(b+2536|0);kJb(c[a+668>>2]|0);return 0}function F1a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0;d=i;i=i+32|0;e=d|0;mrc(e|0,-128|0,32)|0;f=b+8|0;g=b+7348|0;H1a(f,e,c[g>>2]|0);if((c[g>>2]|0)==0){if((c[b+7352>>2]|0)==0){h=4}else{h=3}}else{h=3}do{if((h|0)==3){utb(b);c[b+7540>>2]=0;c[b+7516>>2]=0;c[b+7524>>2]=0;c[b+7496>>2]=0;c[b+7364>>2]=0;c[b+540564>>2]=0;c[b+540572>>2]=0;e=b+540568|0;y=0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;c[b+1073592>>2]=0;c[b+1073600>>2]=0;e=b+1073596|0;y=0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;if((c[g>>2]|0)==0){h=4;break}e=b+3092|0;L1a(f,e,c[b+7356>>2]|0,0);H1a(f,e,c[b+7352>>2]|0);L1a(f,e,c[b+7368>>2]|0,0);L1a(f,e,c[b+7380>>2]|0,0);j=b+7372|0;L1a(f,e,c[j>>2]|0,0);L1a(f,e,c[b+7476>>2]|0,0);k=b+7544|0;if((c[k>>2]|0)>2){L1a(f,e,c[b+7480>>2]|0,0);L1a(f,e,c[b+7484>>2]|0,0)}H1a(f,e,c[b+7488>>2]|0);L1a(f,e,(c[b+7384>>2]|0)-1|0,0);l=c[k>>2]|0;if((l|0)>0){m=0;n=c[j>>2]|0;o=l;while(1){if((n|0)>0){p=0;do{q=(p|0)!=0|0;while(1){if((q|0)==2){q=3;continue}L1a(f,e,c[b+7548+(m*533028|0)+8+(p*66624|0)+(q*16656|0)+16>>2]|0,1);q=q+1|0;if((q|0)>=4){break}}p=p+1|0;r=c[j>>2]|0;}while((p|0)<(r|0));s=r;t=c[k>>2]|0}else{s=n;t=o}p=m+1|0;if((p|0)<(((t|0)>2?2:t)|0)){m=p;n=s;o=t}else{u=t;break}}}else{u=l}if((c[g>>2]|0)==0){v=u;h=17}}}while(0);if((h|0)==4){v=c[b+7544>>2]|0;h=17}do{if((h|0)==17){u=b+7544|0;do{if((v|0)>0){g=(v|0)>2?2:v;t=0;s=0;do{r=(c[b+7548+(s*533028|0)+533016>>2]|0)!=(c[b+7548+(s*533028|0)+533e3>>2]|0)|t|(c[b+7548+(s*533028|0)+533024>>2]|0)!=(c[b+7548+(s*533028|0)+533008>>2]|0);t=r|(grc(b+7548+(s*533028|0)+533020|0,b+7548+(s*533028|0)+533004|0,4)|0)!=0;s=s+1|0;}while((s|0)<(g|0));g=b+3092|0;H1a(f,g,t);if((t|0)==0){w=g;break}if((c[u>>2]|0)>0){x=0}else{w=g;break}while(1){H1a(f,g,c[b+7548+(x*533028|0)+533008>>2]|0);s=b+7548+(x*533028|0)+533e3|0;L1a(f,g,((c[s>>2]|0)/2|0)-1|0,0);r=c[s>>2]|0;if(!((r+1|0)>>>0<3>>>0)){s=(r|0)/2|0;do{r=a[b+7548+(x*533028|0)+533004+s|0]|0;o=r<<24>>24;L1a(f,g,r<<24>>24>-1?o:-o|0,0);s=s-1|0;}while((s|0)!=0)}s=x+1|0;o=c[u>>2]|0;if((s|0)<(((o|0)>2?2:o)|0)){x=s}else{w=g;break}}}else{g=b+3092|0;H1a(f,g,0);w=g}}while(0);l=b+7372|0;if((c[b+7376>>2]|0)==(c[l>>2]|0)){H1a(f,w,0);break}H1a(f,w,1);L1a(f,w,c[l>>2]|0,0);g=c[u>>2]|0;if((g|0)<=0){break}t=0;s=c[l>>2]|0;o=g;while(1){if((s|0)>0){g=0;do{r=(g|0)!=0|0;while(1){if((r|0)==2){r=3;continue}L1a(f,w,c[b+7548+(t*533028|0)+8+(g*66624|0)+(r*16656|0)+16>>2]|0,1);r=r+1|0;if((r|0)>=4){break}}g=g+1|0;z=c[l>>2]|0;}while((g|0)<(z|0));A=z;B=c[u>>2]|0}else{A=s;B=o}g=t+1|0;if((g|0)<(((B|0)>2?2:B)|0)){t=g;s=A;o=B}else{break}}}}while(0);B=b+3092|0;L1a(f,B,(c[b+7360>>2]|0)-(c[b+7364>>2]|0)|0,1);L1a(f,B,(c[b+7492>>2]|0)-(c[b+7496>>2]|0)|0,1);L1a(f,B,(c[b+7512>>2]|0)-(c[b+7516>>2]|0)|0,1);L1a(f,B,(c[b+7520>>2]|0)-(c[b+7524>>2]|0)|0,1);L1a(f,B,(c[b+7536>>2]|0)-(c[b+7540>>2]|0)|0,1);i=d;return}function G1a(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c|0)<=0){return}g=(a|0)>0;h=c;a:while(1){c=h-1|0;b:do{if(g){i=ca(c,f)|0;j=(c|0)==0;k=a;while(1){k=k-1|0;l=k+i|0;if((k|0)==0){break}m=l-1|0;n=b[d+(m<<1)>>1]|0;o=n<<16>>16;if(j){p=d+(l<<1)|0;b[p>>1]=(b[p>>1]|0)-n}else{p=b[d+(l-f<<1)>>1]|0;q=p<<16>>16;r=q+o-(b[d+(m-f<<1)>>1]|0)|0;do{if(n<<16>>16>p<<16>>16){if((r|0)<=(q|0)){s=q;break}s=(r|0)>(o|0)?o:r}else{if((q|0)<=(r|0)){s=q;break}s=(r|0)>(o|0)?r:o}}while(0);o=d+(l<<1)|0;b[o>>1]=(e[o>>1]|0)-s}if((k|0)<=0){break b}}if(j){t=18;break a}k=d+(l<<1)|0;b[k>>1]=(b[k>>1]|0)-(b[d+(l-f<<1)>>1]|0)}}while(0);if((c|0)>0){h=c}else{t=18;break}}if((t|0)==18){return}}function H1a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b+4|0;h=c[g>>2]|0;i=(ca(d[e]|0,h)|0)>>8;j=h-i|0;if((f|0)==0){c[g>>2]=j;k=(d[e]|0)+(b+16)|0}else{f=b|0;c[f>>2]=(c[f>>2]|0)+j;c[g>>2]=i;k=(d[e]|0)+(b+272)|0}a[e]=a[k]|0;if((c[g>>2]|0)>=256){return}k=b+12|0;e=b|0;i=b+532|0;j=b+8|0;b=c[k>>2]|0;f=c[e>>2]|0;while(1){do{if((b|0)<0){h=f>>8;c[k>>2]=h;l=h;m=f}else{if((f|0)<65281){h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=-1;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>8;c[k>>2]=n;l=n;m=h;break}if((f|0)<=65535){c[j>>2]=(c[j>>2]|0)+1;l=b;m=f;break}h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b+1;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=0;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>>8&255;c[k>>2]=n;l=n;m=h}}while(0);h=m<<8&65280;c[e>>2]=h;n=c[g>>2]<<8;c[g>>2]=n;if((n|0)<256){b=l;f=h}else{break}}return}function I1a(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Ye=0,Ze=0,_e=0,$e=0,af=0;g=i;i=i+6200|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;z=g+256|0;A=g+272|0;B=g+288|0;C=g+304|0;D=g+320|0;E=g+336|0;F=g+352|0;G=g+368|0;H=g+5152|0;I=g+5160|0;J=g+6184|0;K=g+928|0;L=f+7528|0;M=c[L>>2]|0;N=f+7536|0;O=c[N>>2]|0;P=M<<O;Q=f+7532|0;R=c[Q>>2]|0;S=R<<O;O=g+384|0;T=f+8|0;nrc(O|0,T|0,540)|0;U=f+3124|0;nrc(K|0,U|0,4224)|0;if((R|0)>0){V=0;W=M;M=R;while(1){if((W|0)>0){R=0;do{K1a(f,0,R,V)|0;R=R+1|0;X=c[L>>2]|0;}while((R|0)<(X|0));Y=X;Z=c[Q>>2]|0}else{Y=W;Z=M}R=V+1|0;if((R|0)<(Z|0)){V=R;W=Y;M=Z}else{break}}}nrc(T|0,O|0,540)|0;nrc(U|0,K|0,4224)|0;K=(S|0)>0;U=f+4|0;O=(P|0)>0;T=f+2139660|0;Z=f+2143760|0;M=f+2139664|0;Y=P-1|0;W=S-1|0;V=f+2536|0;X=f+2540|0;R=f+7548|0;_=f+7552|0;$=f+7544|0;aa=E;E=f+2153752|0;ba=f+2158472|0;da=f+2158476|0;ea=f+7500|0;fa=f+7504|0;ga=f+960|0;ha=f+2143800|0;ia=D;D=H|0;H=f+7388|0;ja=G|0;ka=q;q=G+4|0;la=G+8|0;ma=C;C=B;B=f+2139664|0;na=w;w=v;v=u;u=t;t=s;s=r;r=x;x=z;z=A;A=F;F=f+7480|0;oa=f+7484|0;pa=I|0;qa=P+1|0;ra=1-P|0;sa=~P;ta=0;while(1){if((ta|0)>=25){break}if(K){ua=(ta|0)==0;va=(ta|0)>0;wa=0;xa=0;while(1){a:do{if(O){ya=ca(xa,P)|0;za=(xa|0)!=0;Aa=xa+1|0;Ba=(Aa|0)<(S|0);Ca=za^1;Da=Ba^1;Ea=(xa|0)==0;Fa=(xa|0)==(W|0);Ga=wa;Ha=0;while(1){Ia=Ha;while(1){Ja=Ia+ya|0;Ka=c[T>>2]|0;La=Ka+(Ja*10|0)|0;if(za){Ma=Ka+((Ja-P|0)*10|0)|0}else{Ma=0}Na=(Ia|0)!=0;if(Na){Oa=Ka+((Ja-1|0)*10|0)|0}else{Oa=0}Pa=Ia+1|0;Qa=(Pa|0)<(P|0);if(Qa){Ra=Ka+((Ja+1|0)*10|0)|0}else{Ra=0}if(Ba){Sa=Ka+((Ja+P|0)*10|0)|0}else{Sa=0}Ta=Na^1;if(Ta|Ca){Ua=0}else{Ua=Ka+((Ja+sa|0)*10|0)|0}Na=Qa^1;if(Na|Ca){Va=0}else{Va=Ka+((ra+Ja|0)*10|0)|0}if(Ta|Da){Wa=0}else{Wa=Ka+((Y+Ja|0)*10|0)|0}if(Na|Da){Xa=0}else{Xa=Ka+((qa+Ja|0)*10|0)|0}Na=16>>>((c[N>>2]|0)>>>0);Ta=a[Ka+(Ja*10|0)+8|0]|0;if(ua){Ya=33}else{if((Ta&2)==0){Ya=33}}if((Ya|0)==33){Ya=0;Za=Ka+(Ja*10|0)+8|0;a[Za]=Ta|2;_a=La|0;$a=b[_a>>1]|0;ab=Ka+(Ja*10|0)+2|0;bb=b[ab>>1]|0;cb=Ka+(Ja*10|0)+4|0;db=a[cb]|0;eb=Ka+(Ja*10|0)+5|0;fb=a[eb]|0;gb=Ka+(Ja*10|0)+6|0;hb=a[gb]|0;ib=Ka+(Ja*10|0)+7|0;Ka=a[ib]|0;jb=c[Z>>2]|0;if((jb|0)==0){mrc(M|0,0,4096)|0}c[Z>>2]=jb+4194304;jb=Na<<1;kb=(jb|0)>0;if(kb){lb=c[1335352+(c[N>>2]<<2)>>2]|0;mb=0;do{nrc(I+(mb<<5)|0,lb+(ca(jb,mb)|0)|0,jb)|0;mb=mb+1|0;}while((mb|0)<(jb|0))}mb=(Ia|0)==0;if(mb&kb){lb=Na-1|0;nb=0;do{ob=I+(nb<<5)|0;mrc(ob|0,(a[I+(nb<<5)+lb|0]|0)+(a[ob]|0)&255|0,Na|0)|0;nb=nb+1|0;}while((nb|0)<(jb|0))}nb=(Ia|0)==(Y|0);if(nb&kb){lb=jb-1|0;ob=0;do{pb=I+(ob<<5)+Na|0;mrc(pb|0,(a[I+(ob<<5)+lb|0]|0)+(a[pb]|0)&255|0,Na|0)|0;ob=ob+1|0;}while((ob|0)<(jb|0))}do{if(Ea){if(kb){ob=Na-1|0;lb=0;do{pb=I+lb|0;a[pb]=(a[pb]|0)+(a[I+(ob<<5)+lb|0]|0);lb=lb+1|0;}while((lb|0)<(jb|0))}if((Na|0)>1){qb=1}else{break}do{nrc(I+(qb<<5)|0,pa|0,jb)|0;qb=qb+1|0;}while((qb|0)<(Na|0))}}while(0);do{if(Fa){lb=jb-1|0;if(kb){ob=0;do{pb=I+(lb<<5)+ob|0;a[pb]=(a[pb]|0)+(a[I+(Na<<5)+ob|0]|0);ob=ob+1|0;}while((ob|0)<(jb|0))}if((Na|0)>=(lb|0)){break}ob=I+(lb<<5)|0;pb=Na;do{nrc(I+(pb<<5)|0,ob|0,jb)|0;pb=pb+1|0;}while((pb|0)<(lb|0))}}while(0);do{if(mb|Ea|nb|Fa){jb=c[c[V>>2]>>2]|0;Na=c[X>>2]|0;kb=c[Na>>2]|0;lb=c[Na+32>>2]|0;Na=16>>>((c[N>>2]|0)>>>0);pb=(Na|0)/2|0;ob=(ca(Na,Ia)|0)-pb|0;rb=(ca(Na,xa)|0)-pb|0;pb=c[R>>2]|0;sb=c[_>>2]|0;tb=Na<<1;if((rb|0)<0){Na=rb;do{ub=(ca(Na,lb)|0)+ob|0;nrc(kb+ub|0,jb+ub|0,tb)|0;Na=Na+1|0;}while((Na|0)<0)}Na=rb+tb|0;if((sb|0)<(Na|0)){ub=sb;do{vb=(ca(ub,lb)|0)+ob|0;nrc(kb+vb|0,jb+vb|0,tb)|0;ub=ub+1|0;}while((ub|0)<(Na|0))}if((ob|0)<0&(tb|0)>0){ub=-ob|0;sb=rb;do{vb=(ca(sb,lb)|0)+ob|0;nrc(kb+vb|0,jb+vb|0,ub)|0;sb=sb+1|0;}while((sb|0)<(Na|0))}sb=ob+tb|0;if(!((sb|0)>(pb|0)&(tb|0)>0)){break}ub=sb-pb|0;sb=rb;do{vb=(ca(sb,lb)|0)+pb|0;nrc(kb+vb|0,jb+vb|0,ub)|0;sb=sb+1|0;}while((sb|0)<(Na|0))}}while(0);if((c[$>>2]|0)>0){nb=0;do{Na=c[N>>2]|0;sb=16>>>(Na>>>0);if((nb|0)==0){wb=sb<<1;xb=sb;yb=sb;zb=Na}else{ub=c[F>>2]|0;wb=sb<<1>>ub;xb=sb>>c[oa>>2];yb=sb>>ub;zb=ub+Na|0}ub=c[1335352+(zb<<2)>>2]|0;jb=c[(c[X>>2]|0)+32+(nb<<2)>>2]|0;kb=c[(c[V>>2]|0)+(nb<<2)>>2]|0;pb=c[E>>2]|0;lb=ca(ca(nb<<2,sb)|0,sb)|0;sb=c[f+7548+(nb*533028|0)>>2]|0;rb=c[f+7548+(nb*533028|0)+4>>2]|0;tb=(ca(c[L>>2]<<Na,xa)|0)+Ia|0;Na=c[T>>2]|0;ob=Na+(tb*10|0)|0;b[A>>1]=b[ob>>1]|0;b[A+2>>1]=b[ob+2>>1]|0;b[A+4>>1]=b[ob+4>>1]|0;b[A+6>>1]=b[ob+6>>1]|0;b[A+8>>1]=b[ob+8>>1]|0;vb=Na+(tb*10|0)+8|0;a[vb]=a[vb]|1;a[Na+(tb*10|0)+5+nb|0]=0;mrc(pb+(lb<<1)|0,0,ca(wb<<1,wb)|0)|0;tb=(yb|0)/2|0;Na=(xb|0)/2|0;vb=ca(wb,xb)|0;Ab=(jb|0)>111?16:jb<<4;Bb=-wb|0;Cb=tb-(ca(yb,Ia)|0)|0;Db=Na-(ca(xb,xa)|0)|0;Eb=Ab*3|0;Fb=Eb+Ab|0;Gb=wb>>1;Hb=Fb+Ab|0;Ib=0;Jb=0;Kb=0;while(1){Lb=Kb&1;Mb=Lb+Ia|0;Nb=Mb-1|0;Ob=Kb>>1;Pb=Ob+xa|0;Qb=Pb-1|0;Rb=(ca(Nb,yb)|0)+tb|0;Sb=(ca(Qb,xb)|0)+Na|0;Tb=(yb&-Lb)+lb+(ca(Ob,vb)|0)|0;Ob=c[N>>2]|0;Lb=c[L>>2]<<Ob;Ub=ca(Lb,Qb)|0;Vb=Ub+Nb|0;Wb=c[T>>2]|0;Xb=Wb+(Vb*10|0)|0;Yb=Wb+((Ub+Mb|0)*10|0)|0;Ub=Vb+Lb|0;Vb=Wb+(Ub*10|0)|0;Zb=Wb+((Ub+1|0)*10|0)|0;Ub=c[ba>>2]|0;if((Nb|0)<0){_b=Zb;$b=Zb;ac=Yb;bc=Yb}else{Nb=(Mb|0)<(Lb|0);_b=Nb?Zb:Vb;$b=Vb;ac=Nb?Yb:Xb;bc=Xb}if((Qb|0)<0){cc=_b;dc=$b;ec=_b;fc=$b}else{Qb=(Pb|0)<(c[Q>>2]<<Ob|0);cc=Qb?_b:ac;dc=Qb?$b:bc;ec=ac;fc=bc}Qb=(Rb|0)<0;if(Qb){gc=Tb-Rb|0;hc=ub+(-Rb|0)|0;ic=0;jc=Rb+yb|0}else{gc=Tb;hc=ub;ic=Rb;jc=yb}Tb=(ic+jc|0)>(sb|0)?sb-ic|0:jc;Ob=(Sb|0)<0;if(Ob){Pb=ca(Sb,Bb)|0;kc=gc+Pb|0;lc=hc+Pb|0;mc=0;nc=Sb+xb|0}else{kc=gc;lc=hc;mc=Sb;nc=xb}Pb=(mc+nc|0)>(rb|0)?rb-mc|0:nc;do{if(!((Tb|0)<1|(Pb|0)<1)){Xb=Ub+Eb|0;Yb=Ub+Fb|0;wtb(f,Xb,Ub,jb,ic,mc,Tb,Pb,fc,nb,sb,rb);Nb=fc+8|0;Vb=a[Nb]|0;Zb=ec+8|0;Lb=a[Zb]|0;do{if((Vb&1)==0){Ya=84}else{if((Lb&1)==0){Ya=84;break}oc=(d[fc+6|0]|0)-(d[ec+6|0]|0)|(d[fc+5|0]|0)-(d[ec+5|0]|0)|(d[fc+7|0]|0)-(d[ec+7|0]|0)}}while(0);if((Ya|0)==84){Ya=0;oc=(b[fc>>1]|0)-(b[ec>>1]|0)|(Lb^Vb)&1|(b[fc+2>>1]|0)-(b[ec+2>>1]|0)|(d[fc+4|0]|0)-(d[ec+4|0]|0)}if((oc|0)==0){pc=Yb;qc=Xb;rc=Vb}else{wtb(f,Yb,Ub,jb,ic,mc,Tb,Pb,ec,nb,sb,rb);pc=Ub+Hb|0;qc=Yb;rc=a[Nb]|0}Mb=dc+8|0;Wb=a[Mb]|0;do{if((rc&1)==0){Ya=90}else{if((Wb&1)==0){Ya=90;break}sc=(d[fc+6|0]|0)-(d[dc+6|0]|0)|(d[fc+5|0]|0)-(d[dc+5|0]|0)|(d[fc+7|0]|0)-(d[dc+7|0]|0)}}while(0);if((Ya|0)==90){Ya=0;sc=(b[fc>>1]|0)-(b[dc>>1]|0)|(Wb^rc)&1|(b[fc+2>>1]|0)-(b[dc+2>>1]|0)|(d[fc+4|0]|0)-(d[dc+4|0]|0)}do{if((sc|0)==0){tc=pc;uc=Xb;vc=rc}else{Yb=a[Zb]|0;do{if((Yb&1)==0){Ya=95}else{if((Wb&1)==0){Ya=95;break}wc=(d[ec+6|0]|0)-(d[dc+6|0]|0)|(d[ec+5|0]|0)-(d[dc+5|0]|0)|(d[ec+7|0]|0)-(d[dc+7|0]|0)}}while(0);if((Ya|0)==95){Ya=0;wc=(b[ec>>1]|0)-(b[dc>>1]|0)|(Yb^Wb)&1|(b[ec+2>>1]|0)-(b[dc+2>>1]|0)|(d[ec+4|0]|0)-(d[dc+4|0]|0)}if((wc|0)==0){tc=pc;uc=qc;vc=rc;break}wtb(f,pc,Ub,jb,ic,mc,Tb,Pb,dc,nb,sb,rb);tc=pc+Ab|0;uc=pc;vc=a[Nb]|0}}while(0);Nb=a[cc+8|0]|0;do{if((vc&1)==0){Ya=101}else{if((Nb&1)==0){Ya=101;break}xc=(d[fc+6|0]|0)-(d[cc+6|0]|0)|(d[fc+5|0]|0)-(d[cc+5|0]|0)|(d[fc+7|0]|0)-(d[cc+7|0]|0)}}while(0);if((Ya|0)==101){Ya=0;xc=(b[fc>>1]|0)-(b[cc>>1]|0)|(Nb^vc)&1|(b[fc+2>>1]|0)-(b[cc+2>>1]|0)|(d[fc+4|0]|0)-(d[cc+4|0]|0)}do{if((xc|0)==0){yc=Xb}else{Wb=a[Zb]|0;do{if((Wb&1)==0){Ya=106}else{if((Nb&1)==0){Ya=106;break}zc=(d[ec+6|0]|0)-(d[cc+6|0]|0)|(d[ec+5|0]|0)-(d[cc+5|0]|0)|(d[ec+7|0]|0)-(d[cc+7|0]|0)}}while(0);if((Ya|0)==106){Ya=0;zc=(b[ec>>1]|0)-(b[cc>>1]|0)|(Wb^Nb)&1|(b[ec+2>>1]|0)-(b[cc+2>>1]|0)|(d[ec+4|0]|0)-(d[cc+4|0]|0)}if((zc|0)==0){yc=qc;break}Yb=a[Mb]|0;do{if((Yb&1)==0){Ya=111}else{if((Nb&1)==0){Ya=111;break}Ac=(d[dc+6|0]|0)-(d[cc+6|0]|0)|(d[dc+5|0]|0)-(d[cc+5|0]|0)|(d[dc+7|0]|0)-(d[cc+7|0]|0)}}while(0);if((Ya|0)==111){Ya=0;Ac=(b[dc>>1]|0)-(b[cc>>1]|0)|(Yb^Nb)&1|(b[dc+2>>1]|0)-(b[cc+2>>1]|0)|(d[dc+4|0]|0)-(d[cc+4|0]|0)}if((Ac|0)==0){yc=uc;break}wtb(f,tc,Ub,jb,ic,mc,Tb,Pb,cc,nb,sb,rb);yc=tc}}while(0);if((Pb|0)>0&(Tb|0)>0){Bc=0}else{break}do{Nb=ca(Bc,wb)|0;Mb=Nb+Gb|0;Zb=ca(Bc+Gb|0,wb)|0;Xb=Zb+Gb|0;Wb=ca(Bc,jb)|0;Vb=Nb+kc|0;Lb=0;do{Cc=Lb+Wb|0;Dc=ca(d[yc+Cc|0]|0,d[lc+(Lb+Nb)|0]|0)|0;Ec=(ca(d[uc+Cc|0]|0,d[lc+(Mb+Lb)|0]|0)|0)+Dc|0;Dc=Ec+(ca(d[qc+Cc|0]|0,d[lc+(Lb+Zb)|0]|0)|0)|0;Ec=(Dc+(ca(d[Ub+(Cc+Eb)|0]|0,d[lc+(Xb+Lb)|0]|0)|0)|0)>>>4;Cc=pb+(Vb+Lb<<1)|0;b[Cc>>1]=(e[Cc>>1]|0)-Ec;Lb=Lb+1|0;}while((Lb|0)<(Tb|0));Bc=Bc+1|0;}while((Bc|0)<(Pb|0))}}while(0);Pb=(Sb|0)>0?Sb:0;Tb=Sb+xb|0;Ub=(rb|0)>(Tb|0)?Tb:rb;if((Pb|0)<(Ub|0)){Lb=(Rb|0)>0?Rb:0;Vb=Rb+yb|0;Xb=(sb|0)>(Vb|0)?Vb:sb;Zb=(Lb|0)<(Xb|0);Mb=(Tb|0)>(rb|0);Tb=(Vb|0)>(sb|0);Vb=Ib;Nb=Jb;Wb=Pb;while(1){if(Zb){Pb=Cb+(ca(Db+Wb|0,wb)|0)|0;Yb=ca(Wb,jb)|0;Ec=Vb;Cc=Nb;Dc=Lb;while(1){Fc=Pb+Dc|0;Gc=d[ub+Fc|0]|0;if(Ob){Hc=(d[ub+(Fc+vb)|0]|0)+Gc|0}else{Hc=Gc}if(Qb){Ic=(d[ub+(Fc+yb)|0]|0)+Hc|0}else{Ic=Hc}if(Mb){Jc=(d[ub+(Fc-vb)|0]|0)+Ic|0}else{Jc=Ic}if(Tb){Kc=(d[ub+(Fc-yb)|0]|0)+Jc|0}else{Kc=Jc}Gc=pb+(Fc+lb<<1)|0;Fc=8-(b[Gc>>1]|0)|0;b[Gc>>1]=Fc;Gc=(ca((d[kb+(Dc+Yb)|0]|0)-(Fc>>4)|0,Kc)|0)+Cc|0;Fc=(ca(Kc,Kc)|0)+Ec|0;Lc=Dc+1|0;if((Lc|0)<(Xb|0)){Ec=Fc;Cc=Gc;Dc=Lc}else{Mc=Fc;Nc=Gc;break}}}else{Mc=Vb;Nc=Nb}Dc=Wb+1|0;if((Dc|0)<(Ub|0)){Vb=Mc;Nb=Nc;Wb=Dc}else{Oc=Mc;Pc=Nc;break}}}else{Oc=Ib;Pc=Jb}Wb=Kb+1|0;if((Wb|0)<4){Ib=Oc;Jb=Pc;Kb=Wb}else{break}}b[ob>>1]=b[A>>1]|0;b[ob+2>>1]=b[A+2>>1]|0;b[ob+4>>1]=b[A+4>>1]|0;b[ob+6>>1]=b[A+6>>1]|0;b[ob+8>>1]=b[A+8>>1]|0;Kb=Pc<<8;Jb=Oc>>1;Ib=(((Kb|0)>0?Jb:-Jb|0)+Kb|0)/(Oc|0)|0;if((Ib|0)<0){Qc=0}else{Qc=(Ib|0)>255?255:Ib}c[G+(nb<<2)>>2]=Qc;nb=nb+1|0;}while((nb|0)<(c[$>>2]|0))}do{if(va){if((a[Za]&1)==0){Ya=169;break}nb=a[eb]|0;Ib=a[gb]|0;Kb=a[ib]|0;Jb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;kb=c[T>>2]|0;lb=kb+(Jb*10|0)|0;b[aa>>1]=b[lb>>1]|0;b[aa+2>>1]=b[lb+2>>1]|0;b[aa+4>>1]=b[lb+4>>1]|0;b[aa+6>>1]=b[lb+6>>1]|0;b[aa+8>>1]=b[lb+8>>1]|0;a[kb+(Jb*10|0)+5|0]=nb;a[kb+(Jb*10|0)+6|0]=Ib;a[kb+(Jb*10|0)+7|0]=Kb;Kb=kb+(Jb*10|0)+8|0;a[Kb]=a[Kb]|1;Kb=c[N>>2]|0;Jb=16>>>(Kb>>>0);kb=Jb<<1;Ib=c[X>>2]|0;nb=c[Ib+32>>2]|0;pb=c[Ib>>2]|0;Ib=c[c[V>>2]>>2]|0;ub=c[E>>2]|0;vb=c[ba>>2]|0;jb=c[L>>2]<<Kb;Db=c[Q>>2]<<Kb;Kb=c[R>>2]|0;Cb=c[_>>2]|0;sb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Rc=(sb*3|0)>>8;break};case 11:{Rc=sb>>5;break};case 12:{Rc=sb>>6;break};case 2:case 14:{Rc=sb>>6;break};case 6:case 4:case 1:case 10:{Rc=c[fa>>2]>>7;break};case 5:{Rc=1;break};default:{Rc=sb>>7}}sb=(Jb|0)/2|0;rb=(ca(Jb,Ia)|0)-sb|0;Eb=(ca(Jb,xa)|0)-sb|0;sb=(rb|0)>0?0:-rb|0;Gb=(Eb|0)>0?0:-Eb|0;Ab=Kb-rb|0;Hb=(kb|0)>(Ab|0)?Ab:kb;Ab=Cb-Eb|0;Fb=(kb|0)>(Ab|0)?Ab:kb;Ab=(ca(jb,xa)|0)+Ia|0;wtb(f,vb,c[da>>2]|0,nb,rb,Eb,kb,kb,(c[T>>2]|0)+(Ab*10|0)|0,0,Kb,Cb);if((Gb|0)<(Fb|0)){Cb=(sb|0)<(Hb|0);Kb=Gb;do{Ab=ca(Kb,kb)|0;Bb=ca(Kb,nb)|0;Na=(ca(Kb+Eb|0,nb)|0)+rb|0;if(Cb){tb=sb;do{Wb=((ca(d[I+(Kb<<5)+tb|0]|0,d[vb+(tb+Bb)|0]|0)|0)+8|0)>>>4;Nb=Wb+(b[ub+(tb+Ab<<1)>>1]|0)|0;Wb=Nb>>4;if(Wb>>>0>255>>>0){Sc=(Nb>>31^255)&255}else{Sc=Wb&255}a[pb+(Na+tb)|0]=Sc;tb=tb+1|0;}while((tb|0)<(Hb|0))}Kb=Kb+1|0;}while((Kb|0)<(Fb|0))}if(mb){Ya=154}else{if((jb-1|0)==(Ia|0)){Ya=154}}do{if((Ya|0)==154){Ya=0;if(!Ea){if((Db-1|0)!=(xa|0)){break}}Kb=mb?sb:Jb;ub=Ea?Jb:Fb;Cb=Ea?Gb:Jb;if((Cb|0)>=(ub|0)){break}ob=Kb+rb|0;tb=(mb?Jb:Hb)-Kb|0;Na=Cb;do{nrc(pb+(ob+(ca(Na+Eb|0,nb)|0))|0,vb+((ca(Na,nb)|0)+Kb)|0,tb)|0;Na=Na+1|0;}while((Na|0)<(ub|0))}}while(0);do{if((Jb|0)==16){vb=c[(c[U>>2]|0)+232>>2]|0;if((vb|0)==12){Hb=(ca(Eb,nb)|0)+rb|0;Tc=m1a(ha,Ib+Hb|0,pb+Hb|0,nb,32)|0;break}else if((vb|0)==11){vb=(ca(Eb,nb)|0)+rb|0;Tc=k1a(ha,Ib+vb|0,pb+vb|0,nb,32)|0;break}else{vb=ca(Eb,nb)|0;Hb=vb+rb|0;Gb=Xe[c[ga>>2]&511](ha,Ib+Hb|0,pb+Hb|0,nb,16)|0;Hb=rb+16|0;Fb=Hb+vb|0;vb=(Xe[c[ga>>2]&511](ha,Ib+Fb|0,pb+Fb|0,nb,16)|0)+Gb|0;Gb=ca(Eb+16|0,nb)|0;Fb=Gb+rb|0;sb=vb+(Xe[c[ga>>2]&511](ha,Ib+Fb|0,pb+Fb|0,nb,16)|0)|0;Fb=Gb+Hb|0;Tc=sb+(Xe[c[ga>>2]&511](ha,Ib+Fb|0,pb+Fb|0,nb,16)|0)|0;break}}else{Fb=(ca(Eb,nb)|0)+rb|0;Tc=Xe[c[ga>>2]&511](ha,Ib+Fb|0,pb+Fb|0,nb,kb)|0}}while(0);kb=O1a(f,Ia,xa,1)|0;nb=(O1a(f,Pa,xa,1)|0)+kb|0;kb=nb+(O1a(f,Ia-1|0,Aa,1)|0)|0;nb=kb+(O1a(f,Ia,Aa,1)|0)|0;if((jb-2|0)==(Ia|0)){Uc=(O1a(f,Pa,Aa,1)|0)+nb|0}else{Uc=nb}nb=(ca(Uc,Rc)|0)+Tc|0;if((nb|0)!=2147483647){Vc=nb;break}b[lb>>1]=b[aa>>1]|0;b[lb+2>>1]=b[aa+2>>1]|0;b[lb+4>>1]=b[aa+4>>1]|0;b[lb+6>>1]=b[aa+6>>1]|0;b[lb+8>>1]=b[aa+8>>1]|0;Vc=2147483647}else{Ya=169}}while(0);do{if((Ya|0)==169){Ya=0;nb=b[_a>>1]|0;kb=nb<<16>>16;pb=b[ab>>1]|0;Ib=pb<<16>>16;rb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Eb=c[T>>2]|0;Jb=Eb+(rb*10|0)|0;Fb=Jb;b[ia>>1]=b[Fb>>1]|0;b[ia+2>>1]=b[Fb+2>>1]|0;b[ia+4>>1]=b[Fb+4>>1]|0;b[ia+6>>1]=b[Fb+6>>1]|0;b[ia+8>>1]=b[Fb+8>>1]|0;sb=(Ib<<6)+(kb>>10)+(c[Z>>2]|0)+(d[Eb+(rb*10|0)+4|0]<<12)|0;Hb=f+2139664+(((Ib*31|0)+kb&1023)<<2)|0;if((c[Hb>>2]|0)==(sb|0)){Vc=2147483647;break}c[Hb>>2]=sb;b[Jb>>1]=nb;b[Eb+(rb*10|0)+2>>1]=pb;pb=Eb+(rb*10|0)+8|0;a[pb]=a[pb]&-2;pb=c[N>>2]|0;rb=16>>>(pb>>>0);Eb=rb<<1;nb=c[X>>2]|0;Jb=c[nb+32>>2]|0;sb=c[nb>>2]|0;nb=c[c[V>>2]>>2]|0;Hb=c[E>>2]|0;kb=c[ba>>2]|0;Ib=c[L>>2]<<pb;Gb=c[Q>>2]<<pb;pb=c[R>>2]|0;vb=c[_>>2]|0;Db=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 6:case 4:case 1:case 10:{Wc=c[fa>>2]>>7;break};case 3:{Wc=(Db*3|0)>>8;break};case 5:{Wc=1;break};case 2:case 14:{Wc=Db>>6;break};case 11:{Wc=Db>>5;break};case 12:{Wc=Db>>6;break};default:{Wc=Db>>7}}Db=(rb|0)/2|0;ub=(ca(rb,Ia)|0)-Db|0;Na=(ca(rb,xa)|0)-Db|0;Db=(ub|0)>0?0:-ub|0;tb=(Na|0)>0?0:-Na|0;Kb=pb-ub|0;ob=(Eb|0)>(Kb|0)?Kb:Eb;Kb=vb-Na|0;Cb=(Eb|0)>(Kb|0)?Kb:Eb;Kb=(ca(Ib,xa)|0)+Ia|0;wtb(f,kb,c[da>>2]|0,Jb,ub,Na,Eb,Eb,(c[T>>2]|0)+(Kb*10|0)|0,0,pb,vb);if((tb|0)<(Cb|0)){vb=(Db|0)<(ob|0);pb=tb;do{Kb=ca(pb,Eb)|0;Ab=ca(pb,Jb)|0;Bb=(ca(pb+Na|0,Jb)|0)+ub|0;if(vb){Wb=Db;do{Nb=((ca(d[I+(pb<<5)+Wb|0]|0,d[kb+(Wb+Ab)|0]|0)|0)+8|0)>>>4;Vb=Nb+(b[Hb+(Wb+Kb<<1)>>1]|0)|0;Nb=Vb>>4;if(Nb>>>0>255>>>0){Xc=(Vb>>31^255)&255}else{Xc=Nb&255}a[sb+(Bb+Wb)|0]=Xc;Wb=Wb+1|0;}while((Wb|0)<(ob|0))}pb=pb+1|0;}while((pb|0)<(Cb|0))}if(mb){Ya=186}else{if((Ib-1|0)==(Ia|0)){Ya=186}}do{if((Ya|0)==186){Ya=0;if(!Ea){if((Gb-1|0)!=(xa|0)){break}}pb=mb?Db:rb;Hb=Ea?rb:Cb;vb=Ea?tb:rb;if((vb|0)>=(Hb|0)){break}lb=pb+ub|0;jb=(mb?rb:ob)-pb|0;Wb=vb;do{nrc(sb+(lb+(ca(Wb+Na|0,Jb)|0))|0,kb+((ca(Wb,Jb)|0)+pb)|0,jb)|0;Wb=Wb+1|0;}while((Wb|0)<(Hb|0))}}while(0);do{if((rb|0)==16){kb=c[(c[U>>2]|0)+232>>2]|0;if((kb|0)==12){ob=(ca(Na,Jb)|0)+ub|0;Yc=m1a(ha,nb+ob|0,sb+ob|0,Jb,32)|0;break}else if((kb|0)==11){kb=(ca(Na,Jb)|0)+ub|0;Yc=k1a(ha,nb+kb|0,sb+kb|0,Jb,32)|0;break}else{kb=ca(Na,Jb)|0;ob=kb+ub|0;tb=Xe[c[ga>>2]&511](ha,nb+ob|0,sb+ob|0,Jb,16)|0;ob=ub+16|0;Cb=ob+kb|0;kb=(Xe[c[ga>>2]&511](ha,nb+Cb|0,sb+Cb|0,Jb,16)|0)+tb|0;tb=ca(Na+16|0,Jb)|0;Cb=tb+ub|0;Db=kb+(Xe[c[ga>>2]&511](ha,nb+Cb|0,sb+Cb|0,Jb,16)|0)|0;Cb=tb+ob|0;Yc=Db+(Xe[c[ga>>2]&511](ha,nb+Cb|0,sb+Cb|0,Jb,16)|0)|0;break}}else{Cb=(ca(Na,Jb)|0)+ub|0;Yc=Xe[c[ga>>2]&511](ha,nb+Cb|0,sb+Cb|0,Jb,Eb)|0}}while(0);Eb=O1a(f,Ia,xa,1)|0;Jb=(O1a(f,Pa,xa,1)|0)+Eb|0;Eb=Jb+(O1a(f,Ia-1|0,Aa,1)|0)|0;Jb=Eb+(O1a(f,Ia,Aa,1)|0)|0;if((Ib-2|0)==(Ia|0)){Zc=(O1a(f,Pa,Aa,1)|0)+Jb|0}else{Zc=Jb}Jb=(ca(Zc,Wc)|0)+Yc|0;if((Jb|0)!=2147483647){Vc=Jb;break}b[Fb>>1]=b[ia>>1]|0;b[Fb+2>>1]=b[ia+2>>1]|0;b[Fb+4>>1]=b[ia+4>>1]|0;b[Fb+6>>1]=b[ia+6>>1]|0;b[Fb+8>>1]=b[ia+8>>1]|0;Vc=2147483647}}while(0);Jb=La;Eb=e[Jb>>1]|e[Jb+2>>1]<<16;sb=a[cb]|0;a[D]=a[eb]|0;a[D+1|0]=a[eb+1|0]|0;a[D+2|0]=a[eb+2|0]|0;a[D+3|0]=a[eb+3|0]|0;a[D+4|0]=a[eb+4|0]|0;if((c[H>>2]|0)>0){nb=(Ma|0)==0;ub=(Oa|0)==0;Na=(Ra|0)==0;rb=(Sa|0)==0;Cb=Ja+P|0;Db=Ia-1|0;ob=Ja+1|0;tb=Ja-1|0;kb=Ja-P|0;Gb=Eb;Hb=sb;Wb=Vc;jb=0;while(1){pb=c[f+7392+(jb<<2)>>2]|0;do{if((c[(c[f+7424+(jb<<2)>>2]|0)+(Ja<<2)>>2]|0)>>>0>((c[(c[f+7424+((Hb&255)<<2)>>2]|0)+(Ja<<2)>>2]|0)*3|0)>>>1>>>0){_c=Wb;$c=Hb;ad=Gb}else{a[cb]=jb;lb=pb+(Ja<<2)|0;vb=b[lb>>1]|0;Bb=vb<<16>>16;Kb=pb+(Ja<<2)+2|0;Ab=b[Kb>>1]|0;Nb=Ab<<16>>16;Vb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Ub=c[T>>2]|0;Xb=Ub+(Vb*10|0)|0;Tb=Xb;b[ma>>1]=b[Tb>>1]|0;b[ma+2>>1]=b[Tb+2>>1]|0;b[ma+4>>1]=b[Tb+4>>1]|0;b[ma+6>>1]=b[Tb+6>>1]|0;b[ma+8>>1]=b[Tb+8>>1]|0;Mb=(Nb<<6)+(Bb>>10)+(c[Z>>2]|0)+(d[Ub+(Vb*10|0)+4|0]<<12)|0;Qb=f+2139664+(((Nb*31|0)+Bb&1023)<<2)|0;do{if((c[Qb>>2]|0)==(Mb|0)){bd=2147483647}else{c[Qb>>2]=Mb;b[Xb>>1]=vb;b[Ub+(Vb*10|0)+2>>1]=Ab;Bb=Ub+(Vb*10|0)+8|0;a[Bb]=a[Bb]&-2;Bb=c[N>>2]|0;Nb=16>>>(Bb>>>0);Ob=Nb<<1;Lb=c[X>>2]|0;Zb=c[Lb+32>>2]|0;Rb=c[Lb>>2]|0;Lb=c[c[V>>2]>>2]|0;Sb=c[E>>2]|0;Dc=c[ba>>2]|0;Cc=c[L>>2]<<Bb;Ec=c[Q>>2]<<Bb;Bb=c[R>>2]|0;Yb=c[_>>2]|0;Pb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 6:case 4:case 1:case 10:{cd=c[fa>>2]>>7;break};case 5:{cd=1;break};case 3:{cd=(Pb*3|0)>>8;break};case 11:{cd=Pb>>5;break};case 12:{cd=Pb>>6;break};case 2:case 14:{cd=Pb>>6;break};default:{cd=Pb>>7}}Pb=(Nb|0)/2|0;Gc=(ca(Nb,Ia)|0)-Pb|0;Fc=(ca(Nb,xa)|0)-Pb|0;Pb=(Gc|0)>0?0:-Gc|0;Lc=(Fc|0)>0?0:-Fc|0;dd=Bb-Gc|0;ed=(Ob|0)>(dd|0)?dd:Ob;dd=Yb-Fc|0;fd=(Ob|0)>(dd|0)?dd:Ob;dd=(ca(Cc,xa)|0)+Ia|0;wtb(f,Dc,c[da>>2]|0,Zb,Gc,Fc,Ob,Ob,(c[T>>2]|0)+(dd*10|0)|0,0,Bb,Yb);if((Lc|0)<(fd|0)){Yb=(Pb|0)<(ed|0);Bb=Lc;do{dd=ca(Bb,Ob)|0;gd=ca(Bb,Zb)|0;hd=(ca(Bb+Fc|0,Zb)|0)+Gc|0;if(Yb){id=Pb;do{jd=((ca(d[I+(Bb<<5)+id|0]|0,d[Dc+(id+gd)|0]|0)|0)+8|0)>>>4;kd=jd+(b[Sb+(id+dd<<1)>>1]|0)|0;jd=kd>>4;if(jd>>>0>255>>>0){ld=(kd>>31^255)&255}else{ld=jd&255}a[Rb+(hd+id)|0]=ld;id=id+1|0;}while((id|0)<(ed|0))}Bb=Bb+1|0;}while((Bb|0)<(fd|0))}if(mb){Ya=221}else{if((Cc-1|0)==(Ia|0)){Ya=221}}do{if((Ya|0)==221){Ya=0;if(!Ea){if((Ec-1|0)!=(xa|0)){break}}Bb=mb?Pb:Nb;Sb=Ea?Nb:fd;Yb=Ea?Lc:Nb;if((Yb|0)>=(Sb|0)){break}id=Bb+Gc|0;hd=(mb?Nb:ed)-Bb|0;dd=Yb;do{nrc(Rb+(id+(ca(dd+Fc|0,Zb)|0))|0,Dc+((ca(dd,Zb)|0)+Bb)|0,hd)|0;dd=dd+1|0;}while((dd|0)<(Sb|0))}}while(0);do{if((Nb|0)==16){Dc=c[(c[U>>2]|0)+232>>2]|0;if((Dc|0)==12){ed=(ca(Fc,Zb)|0)+Gc|0;md=m1a(ha,Lb+ed|0,Rb+ed|0,Zb,32)|0;break}else if((Dc|0)==11){Dc=(ca(Fc,Zb)|0)+Gc|0;md=k1a(ha,Lb+Dc|0,Rb+Dc|0,Zb,32)|0;break}else{Dc=ca(Fc,Zb)|0;ed=Dc+Gc|0;Lc=Xe[c[ga>>2]&511](ha,Lb+ed|0,Rb+ed|0,Zb,16)|0;ed=Gc+16|0;fd=ed+Dc|0;Dc=(Xe[c[ga>>2]&511](ha,Lb+fd|0,Rb+fd|0,Zb,16)|0)+Lc|0;Lc=ca(Fc+16|0,Zb)|0;fd=Lc+Gc|0;Pb=Dc+(Xe[c[ga>>2]&511](ha,Lb+fd|0,Rb+fd|0,Zb,16)|0)|0;fd=Lc+ed|0;md=Pb+(Xe[c[ga>>2]&511](ha,Lb+fd|0,Rb+fd|0,Zb,16)|0)|0;break}}else{fd=(ca(Fc,Zb)|0)+Gc|0;md=Xe[c[ga>>2]&511](ha,Lb+fd|0,Rb+fd|0,Zb,Ob)|0}}while(0);Ob=O1a(f,Ia,xa,1)|0;Zb=(O1a(f,Pa,xa,1)|0)+Ob|0;Ob=Zb+(O1a(f,Db,Aa,1)|0)|0;Zb=Ob+(O1a(f,Ia,Aa,1)|0)|0;if((Cc-2|0)==(Ia|0)){nd=(O1a(f,Pa,Aa,1)|0)+Zb|0}else{nd=Zb}Zb=(ca(nd,cd)|0)+md|0;if((Zb|0)!=2147483647){bd=Zb;break}b[Tb>>1]=b[ma>>1]|0;b[Tb+2>>1]=b[ma+2>>1]|0;b[Tb+4>>1]=b[ma+4>>1]|0;b[Tb+6>>1]=b[ma+6>>1]|0;b[Tb+8>>1]=b[ma+8>>1]|0;bd=2147483647}}while(0);Tb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Vb=c[T>>2]|0;Ub=Vb+(Tb*10|0)|0;Ab=Ub;b[C>>1]=b[Ab>>1]|0;b[C+2>>1]=b[Ab+2>>1]|0;b[C+4>>1]=b[Ab+4>>1]|0;b[C+6>>1]=b[Ab+6>>1]|0;b[C+8>>1]=b[Ab+8>>1]|0;vb=(d[Vb+(Tb*10|0)+4|0]<<12)+(c[Z>>2]|0)|0;do{if((c[B>>2]|0)==(vb|0)){od=bd}else{c[B>>2]=vb;b[Ub>>1]=0;b[Vb+(Tb*10|0)+2>>1]=0;Xb=Vb+(Tb*10|0)+8|0;a[Xb]=a[Xb]&-2;Xb=c[N>>2]|0;Mb=16>>>(Xb>>>0);Qb=Mb<<1;Zb=c[X>>2]|0;Ob=c[Zb+32>>2]|0;Rb=c[Zb>>2]|0;Zb=c[c[V>>2]>>2]|0;Lb=c[E>>2]|0;Gc=c[ba>>2]|0;Fc=c[L>>2]<<Xb;Nb=c[Q>>2]<<Xb;Xb=c[R>>2]|0;fd=c[_>>2]|0;Pb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 6:case 4:case 1:case 10:{pd=c[fa>>2]>>7;break};case 5:{pd=1;break};case 11:{pd=Pb>>5;break};case 12:{pd=Pb>>6;break};case 2:case 14:{pd=Pb>>6;break};case 3:{pd=(Pb*3|0)>>8;break};default:{pd=Pb>>7}}Pb=(Mb|0)/2|0;ed=(ca(Mb,Ia)|0)-Pb|0;Lc=(ca(Mb,xa)|0)-Pb|0;Pb=(ed|0)>0?0:-ed|0;Dc=(Lc|0)>0?0:-Lc|0;Ec=Xb-ed|0;Sb=(Qb|0)>(Ec|0)?Ec:Qb;Ec=fd-Lc|0;dd=(Qb|0)>(Ec|0)?Ec:Qb;Ec=(ca(Fc,xa)|0)+Ia|0;wtb(f,Gc,c[da>>2]|0,Ob,ed,Lc,Qb,Qb,(c[T>>2]|0)+(Ec*10|0)|0,0,Xb,fd);if((Dc|0)<(dd|0)){fd=(Pb|0)<(Sb|0);Xb=Dc;do{Ec=ca(Xb,Qb)|0;hd=ca(Xb,Ob)|0;Bb=(ca(Xb+Lc|0,Ob)|0)+ed|0;if(fd){id=Pb;do{Yb=((ca(d[I+(Xb<<5)+id|0]|0,d[Gc+(id+hd)|0]|0)|0)+8|0)>>>4;gd=Yb+(b[Lb+(id+Ec<<1)>>1]|0)|0;Yb=gd>>4;if(Yb>>>0>255>>>0){qd=(gd>>31^255)&255}else{qd=Yb&255}a[Rb+(Bb+id)|0]=qd;id=id+1|0;}while((id|0)<(Sb|0))}Xb=Xb+1|0;}while((Xb|0)<(dd|0))}if(mb){Ya=253}else{if((Fc-1|0)==(Ia|0)){Ya=253}}do{if((Ya|0)==253){Ya=0;if(!Ea){if((Nb-1|0)!=(xa|0)){break}}Xb=mb?Pb:Mb;Lb=Ea?Mb:dd;fd=Ea?Dc:Mb;if((fd|0)>=(Lb|0)){break}Cc=Xb+ed|0;id=(mb?Mb:Sb)-Xb|0;Bb=fd;do{nrc(Rb+(Cc+(ca(Bb+Lc|0,Ob)|0))|0,Gc+((ca(Bb,Ob)|0)+Xb)|0,id)|0;Bb=Bb+1|0;}while((Bb|0)<(Lb|0))}}while(0);do{if((Mb|0)==16){Gc=c[(c[U>>2]|0)+232>>2]|0;if((Gc|0)==11){Sb=(ca(Lc,Ob)|0)+ed|0;rd=k1a(ha,Zb+Sb|0,Rb+Sb|0,Ob,32)|0;break}else if((Gc|0)==12){Gc=(ca(Lc,Ob)|0)+ed|0;rd=m1a(ha,Zb+Gc|0,Rb+Gc|0,Ob,32)|0;break}else{Gc=ca(Lc,Ob)|0;Sb=Gc+ed|0;Dc=Xe[c[ga>>2]&511](ha,Zb+Sb|0,Rb+Sb|0,Ob,16)|0;Sb=ed+16|0;dd=Sb+Gc|0;Gc=(Xe[c[ga>>2]&511](ha,Zb+dd|0,Rb+dd|0,Ob,16)|0)+Dc|0;Dc=ca(Lc+16|0,Ob)|0;dd=Dc+ed|0;Pb=Gc+(Xe[c[ga>>2]&511](ha,Zb+dd|0,Rb+dd|0,Ob,16)|0)|0;dd=Dc+Sb|0;rd=Pb+(Xe[c[ga>>2]&511](ha,Zb+dd|0,Rb+dd|0,Ob,16)|0)|0;break}}else{dd=(ca(Lc,Ob)|0)+ed|0;rd=Xe[c[ga>>2]&511](ha,Zb+dd|0,Rb+dd|0,Ob,Qb)|0}}while(0);Qb=O1a(f,Ia,xa,1)|0;Ob=(O1a(f,Pa,xa,1)|0)+Qb|0;Qb=Ob+(O1a(f,Db,Aa,1)|0)|0;Ob=Qb+(O1a(f,Ia,Aa,1)|0)|0;if((Fc-2|0)==(Ia|0)){sd=(O1a(f,Pa,Aa,1)|0)+Ob|0}else{sd=Ob}Ob=(ca(sd,pd)|0)+rd|0;if((Ob|0)<(bd|0)){od=Ob;break}b[Ab>>1]=b[C>>1]|0;b[Ab+2>>1]=b[C+2>>1]|0;b[Ab+4>>1]=b[C+4>>1]|0;b[Ab+6>>1]=b[C+6>>1]|0;b[Ab+8>>1]=b[C+8>>1]|0;od=bd}}while(0);do{if(nb){td=od}else{Ab=b[pb+(kb<<2)>>1]|0;Tb=Ab<<16>>16;Vb=b[pb+(kb<<2)+2>>1]|0;Ub=Vb<<16>>16;vb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Ob=c[T>>2]|0;Qb=Ob+(vb*10|0)|0;Rb=Qb;b[z>>1]=b[Rb>>1]|0;b[z+2>>1]=b[Rb+2>>1]|0;b[z+4>>1]=b[Rb+4>>1]|0;b[z+6>>1]=b[Rb+6>>1]|0;b[z+8>>1]=b[Rb+8>>1]|0;Zb=(Ub<<6)+(Tb>>10)+(c[Z>>2]|0)+(d[Ob+(vb*10|0)+4|0]<<12)|0;ed=f+2139664+(((Ub*31|0)+Tb&1023)<<2)|0;if((c[ed>>2]|0)==(Zb|0)){td=od;break}c[ed>>2]=Zb;b[Qb>>1]=Ab;b[Ob+(vb*10|0)+2>>1]=Vb;Vb=Ob+(vb*10|0)+8|0;a[Vb]=a[Vb]&-2;Vb=c[N>>2]|0;vb=16>>>(Vb>>>0);Ob=vb<<1;Ab=c[X>>2]|0;Qb=c[Ab+32>>2]|0;Zb=c[Ab>>2]|0;Ab=c[c[V>>2]>>2]|0;ed=c[E>>2]|0;Tb=c[ba>>2]|0;Ub=c[L>>2]<<Vb;Lc=c[Q>>2]<<Vb;Vb=c[R>>2]|0;Mb=c[_>>2]|0;dd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 5:{ud=1;break};case 3:{ud=(dd*3|0)>>8;break};case 11:{ud=dd>>5;break};case 12:{ud=dd>>6;break};case 2:case 14:{ud=dd>>6;break};case 6:case 4:case 1:case 10:{ud=c[fa>>2]>>7;break};default:{ud=dd>>7}}dd=(vb|0)/2|0;Pb=(ca(vb,Ia)|0)-dd|0;Sb=(ca(vb,xa)|0)-dd|0;dd=(Pb|0)>0?0:-Pb|0;Dc=(Sb|0)>0?0:-Sb|0;Gc=Vb-Pb|0;Nb=(Ob|0)>(Gc|0)?Gc:Ob;Gc=Mb-Sb|0;Lb=(Ob|0)>(Gc|0)?Gc:Ob;Gc=(ca(Ub,xa)|0)+Ia|0;wtb(f,Tb,c[da>>2]|0,Qb,Pb,Sb,Ob,Ob,(c[T>>2]|0)+(Gc*10|0)|0,0,Vb,Mb);if((Dc|0)<(Lb|0)){Mb=(dd|0)<(Nb|0);Vb=Dc;do{Gc=ca(Vb,Ob)|0;Bb=ca(Vb,Qb)|0;id=(ca(Vb+Sb|0,Qb)|0)+Pb|0;if(Mb){Xb=dd;do{Cc=((ca(d[I+(Vb<<5)+Xb|0]|0,d[Tb+(Xb+Bb)|0]|0)|0)+8|0)>>>4;fd=Cc+(b[ed+(Xb+Gc<<1)>>1]|0)|0;Cc=fd>>4;if(Cc>>>0>255>>>0){vd=(fd>>31^255)&255}else{vd=Cc&255}a[Zb+(id+Xb)|0]=vd;Xb=Xb+1|0;}while((Xb|0)<(Nb|0))}Vb=Vb+1|0;}while((Vb|0)<(Lb|0))}if(mb){Ya=286}else{if((Ub-1|0)==(Ia|0)){Ya=286}}do{if((Ya|0)==286){Ya=0;if(!Ea){if((Lc-1|0)!=(xa|0)){break}}Vb=mb?dd:vb;ed=Ea?vb:Lb;Mb=Ea?Dc:vb;if((Mb|0)>=(ed|0)){break}Fc=Vb+Pb|0;Xb=(mb?vb:Nb)-Vb|0;id=Mb;do{nrc(Zb+(Fc+(ca(id+Sb|0,Qb)|0))|0,Tb+((ca(id,Qb)|0)+Vb)|0,Xb)|0;id=id+1|0;}while((id|0)<(ed|0))}}while(0);do{if((vb|0)==16){Tb=c[(c[U>>2]|0)+232>>2]|0;if((Tb|0)==12){Nb=(ca(Sb,Qb)|0)+Pb|0;wd=m1a(ha,Ab+Nb|0,Zb+Nb|0,Qb,32)|0;break}else if((Tb|0)==11){Tb=(ca(Sb,Qb)|0)+Pb|0;wd=k1a(ha,Ab+Tb|0,Zb+Tb|0,Qb,32)|0;break}else{Tb=ca(Sb,Qb)|0;Nb=Tb+Pb|0;Dc=Xe[c[ga>>2]&511](ha,Ab+Nb|0,Zb+Nb|0,Qb,16)|0;Nb=Pb+16|0;Lb=Nb+Tb|0;Tb=(Xe[c[ga>>2]&511](ha,Ab+Lb|0,Zb+Lb|0,Qb,16)|0)+Dc|0;Dc=ca(Sb+16|0,Qb)|0;Lb=Dc+Pb|0;dd=Tb+(Xe[c[ga>>2]&511](ha,Ab+Lb|0,Zb+Lb|0,Qb,16)|0)|0;Lb=Dc+Nb|0;wd=dd+(Xe[c[ga>>2]&511](ha,Ab+Lb|0,Zb+Lb|0,Qb,16)|0)|0;break}}else{Lb=(ca(Sb,Qb)|0)+Pb|0;wd=Xe[c[ga>>2]&511](ha,Ab+Lb|0,Zb+Lb|0,Qb,Ob)|0}}while(0);Ob=O1a(f,Ia,xa,1)|0;Qb=(O1a(f,Pa,xa,1)|0)+Ob|0;Ob=Qb+(O1a(f,Db,Aa,1)|0)|0;Qb=Ob+(O1a(f,Ia,Aa,1)|0)|0;if((Ub-2|0)==(Ia|0)){xd=(O1a(f,Pa,Aa,1)|0)+Qb|0}else{xd=Qb}Qb=(ca(xd,ud)|0)+wd|0;if((Qb|0)<(od|0)){td=Qb;break}b[Rb>>1]=b[z>>1]|0;b[Rb+2>>1]=b[z+2>>1]|0;b[Rb+4>>1]=b[z+4>>1]|0;b[Rb+6>>1]=b[z+6>>1]|0;b[Rb+8>>1]=b[z+8>>1]|0;td=od}}while(0);do{if(ub){yd=td}else{Qb=b[pb+(tb<<2)>>1]|0;Ob=Qb<<16>>16;Zb=b[pb+(tb<<2)+2>>1]|0;Ab=Zb<<16>>16;Pb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Sb=c[T>>2]|0;vb=Sb+(Pb*10|0)|0;Lb=vb;b[x>>1]=b[Lb>>1]|0;b[x+2>>1]=b[Lb+2>>1]|0;b[x+4>>1]=b[Lb+4>>1]|0;b[x+6>>1]=b[Lb+6>>1]|0;b[x+8>>1]=b[Lb+8>>1]|0;dd=(Ab<<6)+(Ob>>10)+(c[Z>>2]|0)+(d[Sb+(Pb*10|0)+4|0]<<12)|0;Nb=f+2139664+(((Ab*31|0)+Ob&1023)<<2)|0;if((c[Nb>>2]|0)==(dd|0)){yd=td;break}c[Nb>>2]=dd;b[vb>>1]=Qb;b[Sb+(Pb*10|0)+2>>1]=Zb;Zb=Sb+(Pb*10|0)+8|0;a[Zb]=a[Zb]&-2;Zb=c[N>>2]|0;Pb=16>>>(Zb>>>0);Sb=Pb<<1;Qb=c[X>>2]|0;vb=c[Qb+32>>2]|0;dd=c[Qb>>2]|0;Qb=c[c[V>>2]>>2]|0;Nb=c[E>>2]|0;Ob=c[ba>>2]|0;Ab=c[L>>2]<<Zb;Dc=c[Q>>2]<<Zb;Zb=c[R>>2]|0;Tb=c[_>>2]|0;Lc=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{zd=(Lc*3|0)>>8;break};case 2:case 14:{zd=Lc>>6;break};case 6:case 4:case 1:case 10:{zd=c[fa>>2]>>7;break};case 5:{zd=1;break};case 11:{zd=Lc>>5;break};case 12:{zd=Lc>>6;break};default:{zd=Lc>>7}}Lc=(Pb|0)/2|0;ed=(ca(Pb,Ia)|0)-Lc|0;id=(ca(Pb,xa)|0)-Lc|0;Lc=(ed|0)>0?0:-ed|0;Xb=(id|0)>0?0:-id|0;Vb=Zb-ed|0;Fc=(Sb|0)>(Vb|0)?Vb:Sb;Vb=Tb-id|0;Mb=(Sb|0)>(Vb|0)?Vb:Sb;Vb=(ca(Ab,xa)|0)+Ia|0;wtb(f,Ob,c[da>>2]|0,vb,ed,id,Sb,Sb,(c[T>>2]|0)+(Vb*10|0)|0,0,Zb,Tb);if((Xb|0)<(Mb|0)){Tb=(Lc|0)<(Fc|0);Zb=Xb;do{Vb=ca(Zb,Sb)|0;Gc=ca(Zb,vb)|0;Bb=(ca(Zb+id|0,vb)|0)+ed|0;if(Tb){Cc=Lc;do{fd=((ca(d[I+(Zb<<5)+Cc|0]|0,d[Ob+(Cc+Gc)|0]|0)|0)+8|0)>>>4;Ec=fd+(b[Nb+(Cc+Vb<<1)>>1]|0)|0;fd=Ec>>4;if(fd>>>0>255>>>0){Ad=(Ec>>31^255)&255}else{Ad=fd&255}a[dd+(Bb+Cc)|0]=Ad;Cc=Cc+1|0;}while((Cc|0)<(Fc|0))}Zb=Zb+1|0;}while((Zb|0)<(Mb|0))}if(mb){Ya=319}else{if((Ab-1|0)==(Ia|0)){Ya=319}}do{if((Ya|0)==319){Ya=0;if(!Ea){if((Dc-1|0)!=(xa|0)){break}}Zb=mb?Lc:Pb;Nb=Ea?Pb:Mb;Tb=Ea?Xb:Pb;if((Tb|0)>=(Nb|0)){break}Rb=Zb+ed|0;Ub=(mb?Pb:Fc)-Zb|0;Cc=Tb;do{nrc(dd+(Rb+(ca(Cc+id|0,vb)|0))|0,Ob+((ca(Cc,vb)|0)+Zb)|0,Ub)|0;Cc=Cc+1|0;}while((Cc|0)<(Nb|0))}}while(0);do{if((Pb|0)==16){Ob=c[(c[U>>2]|0)+232>>2]|0;if((Ob|0)==12){Fc=(ca(id,vb)|0)+ed|0;Bd=m1a(ha,Qb+Fc|0,dd+Fc|0,vb,32)|0;break}else if((Ob|0)==11){Ob=(ca(id,vb)|0)+ed|0;Bd=k1a(ha,Qb+Ob|0,dd+Ob|0,vb,32)|0;break}else{Ob=ca(id,vb)|0;Fc=Ob+ed|0;Xb=Xe[c[ga>>2]&511](ha,Qb+Fc|0,dd+Fc|0,vb,16)|0;Fc=ed+16|0;Mb=Fc+Ob|0;Ob=(Xe[c[ga>>2]&511](ha,Qb+Mb|0,dd+Mb|0,vb,16)|0)+Xb|0;Xb=ca(id+16|0,vb)|0;Mb=Xb+ed|0;Lc=Ob+(Xe[c[ga>>2]&511](ha,Qb+Mb|0,dd+Mb|0,vb,16)|0)|0;Mb=Xb+Fc|0;Bd=Lc+(Xe[c[ga>>2]&511](ha,Qb+Mb|0,dd+Mb|0,vb,16)|0)|0;break}}else{Mb=(ca(id,vb)|0)+ed|0;Bd=Xe[c[ga>>2]&511](ha,Qb+Mb|0,dd+Mb|0,vb,Sb)|0}}while(0);Sb=O1a(f,Ia,xa,1)|0;vb=(O1a(f,Pa,xa,1)|0)+Sb|0;Sb=vb+(O1a(f,Db,Aa,1)|0)|0;vb=Sb+(O1a(f,Ia,Aa,1)|0)|0;if((Ab-2|0)==(Ia|0)){Cd=(O1a(f,Pa,Aa,1)|0)+vb|0}else{Cd=vb}vb=(ca(Cd,zd)|0)+Bd|0;if((vb|0)<(td|0)){yd=vb;break}b[Lb>>1]=b[x>>1]|0;b[Lb+2>>1]=b[x+2>>1]|0;b[Lb+4>>1]=b[x+4>>1]|0;b[Lb+6>>1]=b[x+6>>1]|0;b[Lb+8>>1]=b[x+8>>1]|0;yd=td}}while(0);do{if(Na){Dd=yd}else{vb=b[pb+(ob<<2)>>1]|0;Sb=vb<<16>>16;dd=b[pb+(ob<<2)+2>>1]|0;Qb=dd<<16>>16;ed=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;id=c[T>>2]|0;Pb=id+(ed*10|0)|0;Mb=Pb;b[r>>1]=b[Mb>>1]|0;b[r+2>>1]=b[Mb+2>>1]|0;b[r+4>>1]=b[Mb+4>>1]|0;b[r+6>>1]=b[Mb+6>>1]|0;b[r+8>>1]=b[Mb+8>>1]|0;Lc=(Qb<<6)+(Sb>>10)+(c[Z>>2]|0)+(d[id+(ed*10|0)+4|0]<<12)|0;Fc=f+2139664+(((Qb*31|0)+Sb&1023)<<2)|0;if((c[Fc>>2]|0)==(Lc|0)){Dd=yd;break}c[Fc>>2]=Lc;b[Pb>>1]=vb;b[id+(ed*10|0)+2>>1]=dd;dd=id+(ed*10|0)+8|0;a[dd]=a[dd]&-2;dd=c[N>>2]|0;ed=16>>>(dd>>>0);id=ed<<1;vb=c[X>>2]|0;Pb=c[vb+32>>2]|0;Lc=c[vb>>2]|0;vb=c[c[V>>2]>>2]|0;Fc=c[E>>2]|0;Sb=c[ba>>2]|0;Qb=c[L>>2]<<dd;Xb=c[Q>>2]<<dd;dd=c[R>>2]|0;Ob=c[_>>2]|0;Dc=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Ed=(Dc*3|0)>>8;break};case 11:{Ed=Dc>>5;break};case 12:{Ed=Dc>>6;break};case 2:case 14:{Ed=Dc>>6;break};case 6:case 4:case 1:case 10:{Ed=c[fa>>2]>>7;break};case 5:{Ed=1;break};default:{Ed=Dc>>7}}Dc=(ed|0)/2|0;Nb=(ca(ed,Ia)|0)-Dc|0;Cc=(ca(ed,xa)|0)-Dc|0;Dc=(Nb|0)>0?0:-Nb|0;Ub=(Cc|0)>0?0:-Cc|0;Zb=dd-Nb|0;Rb=(id|0)>(Zb|0)?Zb:id;Zb=Ob-Cc|0;Tb=(id|0)>(Zb|0)?Zb:id;Zb=(ca(Qb,xa)|0)+Ia|0;wtb(f,Sb,c[da>>2]|0,Pb,Nb,Cc,id,id,(c[T>>2]|0)+(Zb*10|0)|0,0,dd,Ob);if((Ub|0)<(Tb|0)){Ob=(Dc|0)<(Rb|0);dd=Ub;do{Zb=ca(dd,id)|0;Bb=ca(dd,Pb)|0;Vb=(ca(dd+Cc|0,Pb)|0)+Nb|0;if(Ob){Gc=Dc;do{fd=((ca(d[I+(dd<<5)+Gc|0]|0,d[Sb+(Gc+Bb)|0]|0)|0)+8|0)>>>4;Ec=fd+(b[Fc+(Gc+Zb<<1)>>1]|0)|0;fd=Ec>>4;if(fd>>>0>255>>>0){Fd=(Ec>>31^255)&255}else{Fd=fd&255}a[Lc+(Vb+Gc)|0]=Fd;Gc=Gc+1|0;}while((Gc|0)<(Rb|0))}dd=dd+1|0;}while((dd|0)<(Tb|0))}if(mb){Ya=352}else{if((Qb-1|0)==(Ia|0)){Ya=352}}do{if((Ya|0)==352){Ya=0;if(!Ea){if((Xb-1|0)!=(xa|0)){break}}dd=mb?Dc:ed;Fc=Ea?ed:Tb;Ob=Ea?Ub:ed;if((Ob|0)>=(Fc|0)){break}Lb=dd+Nb|0;Ab=(mb?ed:Rb)-dd|0;Gc=Ob;do{nrc(Lc+(Lb+(ca(Gc+Cc|0,Pb)|0))|0,Sb+((ca(Gc,Pb)|0)+dd)|0,Ab)|0;Gc=Gc+1|0;}while((Gc|0)<(Fc|0))}}while(0);do{if((ed|0)==16){Sb=c[(c[U>>2]|0)+232>>2]|0;if((Sb|0)==12){Rb=(ca(Cc,Pb)|0)+Nb|0;Gd=m1a(ha,vb+Rb|0,Lc+Rb|0,Pb,32)|0;break}else if((Sb|0)==11){Sb=(ca(Cc,Pb)|0)+Nb|0;Gd=k1a(ha,vb+Sb|0,Lc+Sb|0,Pb,32)|0;break}else{Sb=ca(Cc,Pb)|0;Rb=Sb+Nb|0;Ub=Xe[c[ga>>2]&511](ha,vb+Rb|0,Lc+Rb|0,Pb,16)|0;Rb=Nb+16|0;Tb=Rb+Sb|0;Sb=(Xe[c[ga>>2]&511](ha,vb+Tb|0,Lc+Tb|0,Pb,16)|0)+Ub|0;Ub=ca(Cc+16|0,Pb)|0;Tb=Ub+Nb|0;Dc=Sb+(Xe[c[ga>>2]&511](ha,vb+Tb|0,Lc+Tb|0,Pb,16)|0)|0;Tb=Ub+Rb|0;Gd=Dc+(Xe[c[ga>>2]&511](ha,vb+Tb|0,Lc+Tb|0,Pb,16)|0)|0;break}}else{Tb=(ca(Cc,Pb)|0)+Nb|0;Gd=Xe[c[ga>>2]&511](ha,vb+Tb|0,Lc+Tb|0,Pb,id)|0}}while(0);id=O1a(f,Ia,xa,1)|0;Pb=(O1a(f,Pa,xa,1)|0)+id|0;id=Pb+(O1a(f,Db,Aa,1)|0)|0;Pb=id+(O1a(f,Ia,Aa,1)|0)|0;if((Qb-2|0)==(Ia|0)){Hd=(O1a(f,Pa,Aa,1)|0)+Pb|0}else{Hd=Pb}Pb=(ca(Hd,Ed)|0)+Gd|0;if((Pb|0)<(yd|0)){Dd=Pb;break}b[Mb>>1]=b[r>>1]|0;b[Mb+2>>1]=b[r+2>>1]|0;b[Mb+4>>1]=b[r+4>>1]|0;b[Mb+6>>1]=b[r+6>>1]|0;b[Mb+8>>1]=b[r+8>>1]|0;Dd=yd}}while(0);do{if(rb){Id=0;Jd=0;Kd=Dd}else{Pb=b[pb+(Cb<<2)>>1]|0;id=Pb<<16>>16;Lc=b[pb+(Cb<<2)+2>>1]|0;vb=Lc<<16>>16;Nb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Cc=c[T>>2]|0;ed=Cc+(Nb*10|0)|0;Tb=ed;b[na>>1]=b[Tb>>1]|0;b[na+2>>1]=b[Tb+2>>1]|0;b[na+4>>1]=b[Tb+4>>1]|0;b[na+6>>1]=b[Tb+6>>1]|0;b[na+8>>1]=b[Tb+8>>1]|0;Dc=(vb<<6)+(id>>10)+(c[Z>>2]|0)+(d[Cc+(Nb*10|0)+4|0]<<12)|0;Rb=f+2139664+(((vb*31|0)+id&1023)<<2)|0;if((c[Rb>>2]|0)==(Dc|0)){Id=0;Jd=0;Kd=Dd;break}c[Rb>>2]=Dc;b[ed>>1]=Pb;b[Cc+(Nb*10|0)+2>>1]=Lc;Lc=Cc+(Nb*10|0)+8|0;a[Lc]=a[Lc]&-2;Lc=c[N>>2]|0;Nb=16>>>(Lc>>>0);Cc=Nb<<1;Pb=c[X>>2]|0;ed=c[Pb+32>>2]|0;Dc=c[Pb>>2]|0;Pb=c[c[V>>2]>>2]|0;Rb=c[E>>2]|0;id=c[ba>>2]|0;vb=c[L>>2]<<Lc;Ub=c[Q>>2]<<Lc;Lc=c[R>>2]|0;Sb=c[_>>2]|0;Xb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 11:{Ld=Xb>>5;break};case 12:{Ld=Xb>>6;break};case 2:case 14:{Ld=Xb>>6;break};case 6:case 4:case 1:case 10:{Ld=c[fa>>2]>>7;break};case 5:{Ld=1;break};case 3:{Ld=(Xb*3|0)>>8;break};default:{Ld=Xb>>7}}Xb=(Nb|0)/2|0;Fc=(ca(Nb,Ia)|0)-Xb|0;Gc=(ca(Nb,xa)|0)-Xb|0;Xb=(Fc|0)>0?0:-Fc|0;Ab=(Gc|0)>0?0:-Gc|0;dd=Lc-Fc|0;Lb=(Cc|0)>(dd|0)?dd:Cc;dd=Sb-Gc|0;Ob=(Cc|0)>(dd|0)?dd:Cc;dd=(ca(vb,xa)|0)+Ia|0;wtb(f,id,c[da>>2]|0,ed,Fc,Gc,Cc,Cc,(c[T>>2]|0)+(dd*10|0)|0,0,Lc,Sb);if((Ab|0)<(Ob|0)){Sb=(Xb|0)<(Lb|0);Lc=Ab;do{dd=ca(Lc,Cc)|0;Vb=ca(Lc,ed)|0;Zb=(ca(Lc+Gc|0,ed)|0)+Fc|0;if(Sb){Bb=Xb;do{fd=((ca(d[I+(Lc<<5)+Bb|0]|0,d[id+(Bb+Vb)|0]|0)|0)+8|0)>>>4;Ec=fd+(b[Rb+(Bb+dd<<1)>>1]|0)|0;fd=Ec>>4;if(fd>>>0>255>>>0){Md=(Ec>>31^255)&255}else{Md=fd&255}a[Dc+(Zb+Bb)|0]=Md;Bb=Bb+1|0;}while((Bb|0)<(Lb|0))}Lc=Lc+1|0;}while((Lc|0)<(Ob|0))}if(mb){Ya=385}else{if((vb-1|0)==(Ia|0)){Ya=385}}do{if((Ya|0)==385){Ya=0;if(!Ea){if((Ub-1|0)!=(xa|0)){break}}Lc=mb?Xb:Nb;Rb=Ea?Nb:Ob;Sb=Ea?Ab:Nb;if((Sb|0)>=(Rb|0)){break}Mb=Lc+Fc|0;Qb=(mb?Nb:Lb)-Lc|0;Bb=Sb;do{nrc(Dc+(Mb+(ca(Bb+Gc|0,ed)|0))|0,id+((ca(Bb,ed)|0)+Lc)|0,Qb)|0;Bb=Bb+1|0;}while((Bb|0)<(Rb|0))}}while(0);do{if((Nb|0)==16){id=c[(c[U>>2]|0)+232>>2]|0;if((id|0)==12){Lb=(ca(Gc,ed)|0)+Fc|0;Nd=m1a(ha,Pb+Lb|0,Dc+Lb|0,ed,32)|0;break}else if((id|0)==11){id=(ca(Gc,ed)|0)+Fc|0;Nd=k1a(ha,Pb+id|0,Dc+id|0,ed,32)|0;break}else{id=ca(Gc,ed)|0;Lb=id+Fc|0;Ab=Xe[c[ga>>2]&511](ha,Pb+Lb|0,Dc+Lb|0,ed,16)|0;Lb=Fc+16|0;Ob=Lb+id|0;id=(Xe[c[ga>>2]&511](ha,Pb+Ob|0,Dc+Ob|0,ed,16)|0)+Ab|0;Ab=ca(Gc+16|0,ed)|0;Ob=Ab+Fc|0;Xb=id+(Xe[c[ga>>2]&511](ha,Pb+Ob|0,Dc+Ob|0,ed,16)|0)|0;Ob=Ab+Lb|0;Nd=Xb+(Xe[c[ga>>2]&511](ha,Pb+Ob|0,Dc+Ob|0,ed,16)|0)|0;break}}else{Ob=(ca(Gc,ed)|0)+Fc|0;Nd=Xe[c[ga>>2]&511](ha,Pb+Ob|0,Dc+Ob|0,ed,Cc)|0}}while(0);Cc=O1a(f,Ia,xa,1)|0;ed=(O1a(f,Pa,xa,1)|0)+Cc|0;Cc=ed+(O1a(f,Db,Aa,1)|0)|0;ed=Cc+(O1a(f,Ia,Aa,1)|0)|0;if((vb-2|0)==(Ia|0)){Od=(O1a(f,Pa,Aa,1)|0)+ed|0}else{Od=ed}ed=(ca(Od,Ld)|0)+Nd|0;if((ed|0)<(Dd|0)){Id=0;Jd=0;Kd=ed;break}b[Tb>>1]=b[na>>1]|0;b[Tb+2>>1]=b[na+2>>1]|0;b[Tb+4>>1]=b[na+4>>1]|0;b[Tb+6>>1]=b[na+6>>1]|0;b[Tb+8>>1]=b[na+8>>1]|0;Id=0;Jd=0;Kd=Dd}}while(0);b:while(1){ed=c[(c[U>>2]|0)+248>>2]|0;Cc=(ed|0)>1?ed:1;ed=Id;Dc=Jd;while(1){if((Dc|0)<(Cc|0)){break}if((ed|0)==0){Pd=0;Qd=0;Rd=Kd;break b}else{ed=0;Dc=0}}if((Dc|0)>0){Cc=Kd;Tb=0;vb=ed;while(1){Pb=Dc-Tb<<2;Fc=(b[_a>>1]|0)+Pb|0;Gc=Tb<<2;Nb=(b[ab>>1]|0)+Gc|0;Ob=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Xb=c[T>>2]|0;Lb=Xb+(Ob*10|0)|0;Ab=Lb;b[w>>1]=b[Ab>>1]|0;b[w+2>>1]=b[Ab+2>>1]|0;b[w+4>>1]=b[Ab+4>>1]|0;b[w+6>>1]=b[Ab+6>>1]|0;b[w+8>>1]=b[Ab+8>>1]|0;id=(Nb<<6)+(Fc>>10)+(c[Z>>2]|0)+(d[Xb+(Ob*10|0)+4|0]<<12)|0;Ub=f+2139664+(((Nb*31|0)+Fc&1023)<<2)|0;do{if((c[Ub>>2]|0)==(id|0)){Sd=0;Td=Cc}else{c[Ub>>2]=id;b[Lb>>1]=Fc;b[Xb+(Ob*10|0)+2>>1]=Nb;Rb=Xb+(Ob*10|0)+8|0;a[Rb]=a[Rb]&-2;Rb=c[N>>2]|0;Bb=16>>>(Rb>>>0);Qb=Bb<<1;Lc=c[X>>2]|0;Mb=c[Lc+32>>2]|0;Sb=c[Lc>>2]|0;Lc=c[c[V>>2]>>2]|0;Zb=c[E>>2]|0;dd=c[ba>>2]|0;Vb=c[L>>2]<<Rb;fd=c[Q>>2]<<Rb;Rb=c[R>>2]|0;Ec=c[_>>2]|0;hd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Ud=(hd*3|0)>>8;break};case 11:{Ud=hd>>5;break};case 12:{Ud=hd>>6;break};case 2:case 14:{Ud=hd>>6;break};case 6:case 4:case 1:case 10:{Ud=c[fa>>2]>>7;break};case 5:{Ud=1;break};default:{Ud=hd>>7}}hd=(Bb|0)/2|0;Yb=(ca(Bb,Ia)|0)-hd|0;gd=(ca(Bb,xa)|0)-hd|0;hd=(Yb|0)>0?0:-Yb|0;jd=(gd|0)>0?0:-gd|0;kd=Rb-Yb|0;Vd=(Qb|0)>(kd|0)?kd:Qb;kd=Ec-gd|0;Wd=(Qb|0)>(kd|0)?kd:Qb;kd=(ca(Vb,xa)|0)+Ia|0;wtb(f,dd,c[da>>2]|0,Mb,Yb,gd,Qb,Qb,(c[T>>2]|0)+(kd*10|0)|0,0,Rb,Ec);if((jd|0)<(Wd|0)){Ec=(hd|0)<(Vd|0);Rb=jd;do{kd=ca(Rb,Qb)|0;Xd=ca(Rb,Mb)|0;Yd=(ca(Rb+gd|0,Mb)|0)+Yb|0;if(Ec){Zd=hd;do{_d=((ca(d[I+(Rb<<5)+Zd|0]|0,d[dd+(Zd+Xd)|0]|0)|0)+8|0)>>>4;$d=_d+(b[Zb+(Zd+kd<<1)>>1]|0)|0;_d=$d>>4;if(_d>>>0>255>>>0){ae=($d>>31^255)&255}else{ae=_d&255}a[Sb+(Yd+Zd)|0]=ae;Zd=Zd+1|0;}while((Zd|0)<(Vd|0))}Rb=Rb+1|0;}while((Rb|0)<(Wd|0))}if(mb){Ya=420}else{if((Vb-1|0)==(Ia|0)){Ya=420}}do{if((Ya|0)==420){Ya=0;if(!Ea){if((fd-1|0)!=(xa|0)){break}}Rb=mb?hd:Bb;Zb=Ea?Bb:Wd;Ec=Ea?jd:Bb;if((Ec|0)>=(Zb|0)){break}Zd=Rb+Yb|0;Yd=(mb?Bb:Vd)-Rb|0;kd=Ec;do{nrc(Sb+(Zd+(ca(kd+gd|0,Mb)|0))|0,dd+((ca(kd,Mb)|0)+Rb)|0,Yd)|0;kd=kd+1|0;}while((kd|0)<(Zb|0))}}while(0);do{if((Bb|0)==16){dd=c[(c[U>>2]|0)+232>>2]|0;if((dd|0)==12){Vd=(ca(gd,Mb)|0)+Yb|0;be=m1a(ha,Lc+Vd|0,Sb+Vd|0,Mb,32)|0;break}else if((dd|0)==11){dd=(ca(gd,Mb)|0)+Yb|0;be=k1a(ha,Lc+dd|0,Sb+dd|0,Mb,32)|0;break}else{dd=ca(gd,Mb)|0;Vd=dd+Yb|0;jd=Xe[c[ga>>2]&511](ha,Lc+Vd|0,Sb+Vd|0,Mb,16)|0;Vd=Yb+16|0;Wd=Vd+dd|0;dd=(Xe[c[ga>>2]&511](ha,Lc+Wd|0,Sb+Wd|0,Mb,16)|0)+jd|0;jd=ca(gd+16|0,Mb)|0;Wd=jd+Yb|0;hd=dd+(Xe[c[ga>>2]&511](ha,Lc+Wd|0,Sb+Wd|0,Mb,16)|0)|0;Wd=jd+Vd|0;be=hd+(Xe[c[ga>>2]&511](ha,Lc+Wd|0,Sb+Wd|0,Mb,16)|0)|0;break}}else{Wd=(ca(gd,Mb)|0)+Yb|0;be=Xe[c[ga>>2]&511](ha,Lc+Wd|0,Sb+Wd|0,Mb,Qb)|0}}while(0);Qb=O1a(f,Ia,xa,1)|0;Mb=(O1a(f,Pa,xa,1)|0)+Qb|0;Qb=Mb+(O1a(f,Db,Aa,1)|0)|0;Mb=Qb+(O1a(f,Ia,Aa,1)|0)|0;if((Vb-2|0)==(Ia|0)){ce=(O1a(f,Pa,Aa,1)|0)+Mb|0}else{ce=Mb}Mb=(ca(ce,Ud)|0)+be|0;if((Mb|0)<(Cc|0)){Sd=1;Td=Mb;break}b[Ab>>1]=b[w>>1]|0;b[Ab+2>>1]=b[w+2>>1]|0;b[Ab+4>>1]=b[w+4>>1]|0;b[Ab+6>>1]=b[w+6>>1]|0;b[Ab+8>>1]=b[w+8>>1]|0;Sd=0;Td=Cc}}while(0);Ab=Sd|vb;Ob=(b[_a>>1]|0)-Pb|0;Xb=(b[ab>>1]|0)-Gc|0;Nb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Fc=c[T>>2]|0;Lb=Fc+(Nb*10|0)|0;id=Lb;b[v>>1]=b[id>>1]|0;b[v+2>>1]=b[id+2>>1]|0;b[v+4>>1]=b[id+4>>1]|0;b[v+6>>1]=b[id+6>>1]|0;b[v+8>>1]=b[id+8>>1]|0;Ub=(Xb<<6)+(Ob>>10)+(c[Z>>2]|0)+(d[Fc+(Nb*10|0)+4|0]<<12)|0;Mb=f+2139664+(((Xb*31|0)+Ob&1023)<<2)|0;do{if((c[Mb>>2]|0)==(Ub|0)){de=0;ee=Td}else{c[Mb>>2]=Ub;b[Lb>>1]=Ob;b[Fc+(Nb*10|0)+2>>1]=Xb;Qb=Fc+(Nb*10|0)+8|0;a[Qb]=a[Qb]&-2;Qb=c[N>>2]|0;Sb=16>>>(Qb>>>0);Lc=Sb<<1;Yb=c[X>>2]|0;gd=c[Yb+32>>2]|0;Bb=c[Yb>>2]|0;Yb=c[c[V>>2]>>2]|0;Wd=c[E>>2]|0;hd=c[ba>>2]|0;Vd=c[L>>2]<<Qb;jd=c[Q>>2]<<Qb;Qb=c[R>>2]|0;dd=c[_>>2]|0;fd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 5:{fe=1;break};case 3:{fe=(fd*3|0)>>8;break};case 11:{fe=fd>>5;break};case 12:{fe=fd>>6;break};case 2:case 14:{fe=fd>>6;break};case 6:case 4:case 1:case 10:{fe=c[fa>>2]>>7;break};default:{fe=fd>>7}}fd=(Sb|0)/2|0;Zb=(ca(Sb,Ia)|0)-fd|0;kd=(ca(Sb,xa)|0)-fd|0;fd=(Zb|0)>0?0:-Zb|0;Yd=(kd|0)>0?0:-kd|0;Rb=Qb-Zb|0;Zd=(Lc|0)>(Rb|0)?Rb:Lc;Rb=dd-kd|0;Ec=(Lc|0)>(Rb|0)?Rb:Lc;Rb=(ca(Vd,xa)|0)+Ia|0;wtb(f,hd,c[da>>2]|0,gd,Zb,kd,Lc,Lc,(c[T>>2]|0)+(Rb*10|0)|0,0,Qb,dd);if((Yd|0)<(Ec|0)){dd=(fd|0)<(Zd|0);Qb=Yd;do{Rb=ca(Qb,Lc)|0;Xd=ca(Qb,gd)|0;_d=(ca(Qb+kd|0,gd)|0)+Zb|0;if(dd){$d=fd;do{ge=((ca(d[I+(Qb<<5)+$d|0]|0,d[hd+($d+Xd)|0]|0)|0)+8|0)>>>4;he=ge+(b[Wd+($d+Rb<<1)>>1]|0)|0;ge=he>>4;if(ge>>>0>255>>>0){ie=(he>>31^255)&255}else{ie=ge&255}a[Bb+(_d+$d)|0]=ie;$d=$d+1|0;}while(($d|0)<(Zd|0))}Qb=Qb+1|0;}while((Qb|0)<(Ec|0))}if(mb){Ya=452}else{if((Vd-1|0)==(Ia|0)){Ya=452}}do{if((Ya|0)==452){Ya=0;if(!Ea){if((jd-1|0)!=(xa|0)){break}}Qb=mb?fd:Sb;Wd=Ea?Sb:Ec;dd=Ea?Yd:Sb;if((dd|0)>=(Wd|0)){break}Vb=Qb+Zb|0;$d=(mb?Sb:Zd)-Qb|0;_d=dd;do{nrc(Bb+(Vb+(ca(_d+kd|0,gd)|0))|0,hd+((ca(_d,gd)|0)+Qb)|0,$d)|0;_d=_d+1|0;}while((_d|0)<(Wd|0))}}while(0);do{if((Sb|0)==16){hd=c[(c[U>>2]|0)+232>>2]|0;if((hd|0)==12){Zd=(ca(kd,gd)|0)+Zb|0;je=m1a(ha,Yb+Zd|0,Bb+Zd|0,gd,32)|0;break}else if((hd|0)==11){hd=(ca(kd,gd)|0)+Zb|0;je=k1a(ha,Yb+hd|0,Bb+hd|0,gd,32)|0;break}else{hd=ca(kd,gd)|0;Zd=hd+Zb|0;Yd=Xe[c[ga>>2]&511](ha,Yb+Zd|0,Bb+Zd|0,gd,16)|0;Zd=Zb+16|0;Ec=Zd+hd|0;hd=(Xe[c[ga>>2]&511](ha,Yb+Ec|0,Bb+Ec|0,gd,16)|0)+Yd|0;Yd=ca(kd+16|0,gd)|0;Ec=Yd+Zb|0;fd=hd+(Xe[c[ga>>2]&511](ha,Yb+Ec|0,Bb+Ec|0,gd,16)|0)|0;Ec=Yd+Zd|0;je=fd+(Xe[c[ga>>2]&511](ha,Yb+Ec|0,Bb+Ec|0,gd,16)|0)|0;break}}else{Ec=(ca(kd,gd)|0)+Zb|0;je=Xe[c[ga>>2]&511](ha,Yb+Ec|0,Bb+Ec|0,gd,Lc)|0}}while(0);Lc=O1a(f,Ia,xa,1)|0;gd=(O1a(f,Pa,xa,1)|0)+Lc|0;Lc=gd+(O1a(f,Db,Aa,1)|0)|0;gd=Lc+(O1a(f,Ia,Aa,1)|0)|0;if((Vd-2|0)==(Ia|0)){ke=(O1a(f,Pa,Aa,1)|0)+gd|0}else{ke=gd}gd=(ca(ke,fe)|0)+je|0;if((gd|0)<(Td|0)){de=1;ee=gd;break}b[id>>1]=b[v>>1]|0;b[id+2>>1]=b[v+2>>1]|0;b[id+4>>1]=b[v+4>>1]|0;b[id+6>>1]=b[v+6>>1]|0;b[id+8>>1]=b[v+8>>1]|0;de=0;ee=Td}}while(0);id=Ab|de;Nb=(b[_a>>1]|0)+Pb|0;Fc=(b[ab>>1]|0)-Gc|0;Xb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Ob=c[T>>2]|0;Lb=Ob+(Xb*10|0)|0;Ub=Lb;b[u>>1]=b[Ub>>1]|0;b[u+2>>1]=b[Ub+2>>1]|0;b[u+4>>1]=b[Ub+4>>1]|0;b[u+6>>1]=b[Ub+6>>1]|0;b[u+8>>1]=b[Ub+8>>1]|0;Mb=(Fc<<6)+(Nb>>10)+(c[Z>>2]|0)+(d[Ob+(Xb*10|0)+4|0]<<12)|0;gd=f+2139664+(((Fc*31|0)+Nb&1023)<<2)|0;do{if((c[gd>>2]|0)==(Mb|0)){le=0;me=ee}else{c[gd>>2]=Mb;b[Lb>>1]=Nb;b[Ob+(Xb*10|0)+2>>1]=Fc;Lc=Ob+(Xb*10|0)+8|0;a[Lc]=a[Lc]&-2;Lc=c[N>>2]|0;Bb=16>>>(Lc>>>0);Yb=Bb<<1;Zb=c[X>>2]|0;kd=c[Zb+32>>2]|0;Sb=c[Zb>>2]|0;Zb=c[c[V>>2]>>2]|0;Ec=c[E>>2]|0;fd=c[ba>>2]|0;Zd=c[L>>2]<<Lc;Yd=c[Q>>2]<<Lc;Lc=c[R>>2]|0;hd=c[_>>2]|0;jd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{ne=(jd*3|0)>>8;break};case 11:{ne=jd>>5;break};case 12:{ne=jd>>6;break};case 2:case 14:{ne=jd>>6;break};case 6:case 4:case 1:case 10:{ne=c[fa>>2]>>7;break};case 5:{ne=1;break};default:{ne=jd>>7}}jd=(Bb|0)/2|0;Wd=(ca(Bb,Ia)|0)-jd|0;_d=(ca(Bb,xa)|0)-jd|0;jd=(Wd|0)>0?0:-Wd|0;$d=(_d|0)>0?0:-_d|0;Qb=Lc-Wd|0;Vb=(Yb|0)>(Qb|0)?Qb:Yb;Qb=hd-_d|0;dd=(Yb|0)>(Qb|0)?Qb:Yb;Qb=(ca(Zd,xa)|0)+Ia|0;wtb(f,fd,c[da>>2]|0,kd,Wd,_d,Yb,Yb,(c[T>>2]|0)+(Qb*10|0)|0,0,Lc,hd);if(($d|0)<(dd|0)){hd=(jd|0)<(Vb|0);Lc=$d;do{Qb=ca(Lc,Yb)|0;Rb=ca(Lc,kd)|0;Xd=(ca(Lc+_d|0,kd)|0)+Wd|0;if(hd){ge=jd;do{he=((ca(d[I+(Lc<<5)+ge|0]|0,d[fd+(ge+Rb)|0]|0)|0)+8|0)>>>4;oe=he+(b[Ec+(ge+Qb<<1)>>1]|0)|0;he=oe>>4;if(he>>>0>255>>>0){pe=(oe>>31^255)&255}else{pe=he&255}a[Sb+(Xd+ge)|0]=pe;ge=ge+1|0;}while((ge|0)<(Vb|0))}Lc=Lc+1|0;}while((Lc|0)<(dd|0))}if(mb){Ya=484}else{if((Zd-1|0)==(Ia|0)){Ya=484}}do{if((Ya|0)==484){Ya=0;if(!Ea){if((Yd-1|0)!=(xa|0)){break}}Lc=mb?jd:Bb;Ec=Ea?Bb:dd;hd=Ea?$d:Bb;if((hd|0)>=(Ec|0)){break}Vd=Lc+Wd|0;ge=(mb?Bb:Vb)-Lc|0;Xd=hd;do{nrc(Sb+(Vd+(ca(Xd+_d|0,kd)|0))|0,fd+((ca(Xd,kd)|0)+Lc)|0,ge)|0;Xd=Xd+1|0;}while((Xd|0)<(Ec|0))}}while(0);do{if((Bb|0)==16){fd=c[(c[U>>2]|0)+232>>2]|0;if((fd|0)==12){Vb=(ca(_d,kd)|0)+Wd|0;qe=m1a(ha,Zb+Vb|0,Sb+Vb|0,kd,32)|0;break}else if((fd|0)==11){fd=(ca(_d,kd)|0)+Wd|0;qe=k1a(ha,Zb+fd|0,Sb+fd|0,kd,32)|0;break}else{fd=ca(_d,kd)|0;Vb=fd+Wd|0;$d=Xe[c[ga>>2]&511](ha,Zb+Vb|0,Sb+Vb|0,kd,16)|0;Vb=Wd+16|0;dd=Vb+fd|0;fd=(Xe[c[ga>>2]&511](ha,Zb+dd|0,Sb+dd|0,kd,16)|0)+$d|0;$d=ca(_d+16|0,kd)|0;dd=$d+Wd|0;jd=fd+(Xe[c[ga>>2]&511](ha,Zb+dd|0,Sb+dd|0,kd,16)|0)|0;dd=$d+Vb|0;qe=jd+(Xe[c[ga>>2]&511](ha,Zb+dd|0,Sb+dd|0,kd,16)|0)|0;break}}else{dd=(ca(_d,kd)|0)+Wd|0;qe=Xe[c[ga>>2]&511](ha,Zb+dd|0,Sb+dd|0,kd,Yb)|0}}while(0);Yb=O1a(f,Ia,xa,1)|0;kd=(O1a(f,Pa,xa,1)|0)+Yb|0;Yb=kd+(O1a(f,Db,Aa,1)|0)|0;kd=Yb+(O1a(f,Ia,Aa,1)|0)|0;if((Zd-2|0)==(Ia|0)){re=(O1a(f,Pa,Aa,1)|0)+kd|0}else{re=kd}kd=(ca(re,ne)|0)+qe|0;if((kd|0)<(ee|0)){le=1;me=kd;break}b[Ub>>1]=b[u>>1]|0;b[Ub+2>>1]=b[u+2>>1]|0;b[Ub+4>>1]=b[u+4>>1]|0;b[Ub+6>>1]=b[u+6>>1]|0;b[Ub+8>>1]=b[u+8>>1]|0;le=0;me=ee}}while(0);Ub=id|le;Xb=(b[_a>>1]|0)-Pb|0;Ob=(b[ab>>1]|0)+Gc|0;Fc=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Nb=c[T>>2]|0;Lb=Nb+(Fc*10|0)|0;Mb=Lb;b[t>>1]=b[Mb>>1]|0;b[t+2>>1]=b[Mb+2>>1]|0;b[t+4>>1]=b[Mb+4>>1]|0;b[t+6>>1]=b[Mb+6>>1]|0;b[t+8>>1]=b[Mb+8>>1]|0;gd=(Ob<<6)+(Xb>>10)+(c[Z>>2]|0)+(d[Nb+(Fc*10|0)+4|0]<<12)|0;Ab=f+2139664+(((Ob*31|0)+Xb&1023)<<2)|0;do{if((c[Ab>>2]|0)==(gd|0)){se=0;te=me}else{c[Ab>>2]=gd;b[Lb>>1]=Xb;b[Nb+(Fc*10|0)+2>>1]=Ob;kd=Nb+(Fc*10|0)+8|0;a[kd]=a[kd]&-2;kd=c[N>>2]|0;Yb=16>>>(kd>>>0);Sb=Yb<<1;Zb=c[X>>2]|0;Wd=c[Zb+32>>2]|0;_d=c[Zb>>2]|0;Zb=c[c[V>>2]>>2]|0;Bb=c[E>>2]|0;dd=c[ba>>2]|0;jd=c[L>>2]<<kd;Vb=c[Q>>2]<<kd;kd=c[R>>2]|0;$d=c[_>>2]|0;fd=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{ue=(fd*3|0)>>8;break};case 11:{ue=fd>>5;break};case 12:{ue=fd>>6;break};case 2:case 14:{ue=fd>>6;break};case 6:case 4:case 1:case 10:{ue=c[fa>>2]>>7;break};case 5:{ue=1;break};default:{ue=fd>>7}}fd=(Yb|0)/2|0;Yd=(ca(Yb,Ia)|0)-fd|0;Ec=(ca(Yb,xa)|0)-fd|0;fd=(Yd|0)>0?0:-Yd|0;Xd=(Ec|0)>0?0:-Ec|0;ge=kd-Yd|0;Lc=(Sb|0)>(ge|0)?ge:Sb;ge=$d-Ec|0;Vd=(Sb|0)>(ge|0)?ge:Sb;ge=(ca(jd,xa)|0)+Ia|0;wtb(f,dd,c[da>>2]|0,Wd,Yd,Ec,Sb,Sb,(c[T>>2]|0)+(ge*10|0)|0,0,kd,$d);if((Xd|0)<(Vd|0)){$d=(fd|0)<(Lc|0);kd=Xd;do{ge=ca(kd,Sb)|0;hd=ca(kd,Wd)|0;Qb=(ca(kd+Ec|0,Wd)|0)+Yd|0;if($d){Rb=fd;do{he=((ca(d[I+(kd<<5)+Rb|0]|0,d[dd+(Rb+hd)|0]|0)|0)+8|0)>>>4;oe=he+(b[Bb+(Rb+ge<<1)>>1]|0)|0;he=oe>>4;if(he>>>0>255>>>0){ve=(oe>>31^255)&255}else{ve=he&255}a[_d+(Qb+Rb)|0]=ve;Rb=Rb+1|0;}while((Rb|0)<(Lc|0))}kd=kd+1|0;}while((kd|0)<(Vd|0))}if(mb){Ya=516}else{if((jd-1|0)==(Ia|0)){Ya=516}}do{if((Ya|0)==516){Ya=0;if(!Ea){if((Vb-1|0)!=(xa|0)){break}}kd=mb?fd:Yb;Bb=Ea?Yb:Vd;$d=Ea?Xd:Yb;if(($d|0)>=(Bb|0)){break}Zd=kd+Yd|0;Rb=(mb?Yb:Lc)-kd|0;Qb=$d;do{nrc(_d+(Zd+(ca(Qb+Ec|0,Wd)|0))|0,dd+((ca(Qb,Wd)|0)+kd)|0,Rb)|0;Qb=Qb+1|0;}while((Qb|0)<(Bb|0))}}while(0);do{if((Yb|0)==16){dd=c[(c[U>>2]|0)+232>>2]|0;if((dd|0)==12){Lc=(ca(Ec,Wd)|0)+Yd|0;we=m1a(ha,Zb+Lc|0,_d+Lc|0,Wd,32)|0;break}else if((dd|0)==11){dd=(ca(Ec,Wd)|0)+Yd|0;we=k1a(ha,Zb+dd|0,_d+dd|0,Wd,32)|0;break}else{dd=ca(Ec,Wd)|0;Lc=dd+Yd|0;Xd=Xe[c[ga>>2]&511](ha,Zb+Lc|0,_d+Lc|0,Wd,16)|0;Lc=Yd+16|0;Vd=Lc+dd|0;dd=(Xe[c[ga>>2]&511](ha,Zb+Vd|0,_d+Vd|0,Wd,16)|0)+Xd|0;Xd=ca(Ec+16|0,Wd)|0;Vd=Xd+Yd|0;fd=dd+(Xe[c[ga>>2]&511](ha,Zb+Vd|0,_d+Vd|0,Wd,16)|0)|0;Vd=Xd+Lc|0;we=fd+(Xe[c[ga>>2]&511](ha,Zb+Vd|0,_d+Vd|0,Wd,16)|0)|0;break}}else{Vd=(ca(Ec,Wd)|0)+Yd|0;we=Xe[c[ga>>2]&511](ha,Zb+Vd|0,_d+Vd|0,Wd,Sb)|0}}while(0);Sb=O1a(f,Ia,xa,1)|0;Wd=(O1a(f,Pa,xa,1)|0)+Sb|0;Sb=Wd+(O1a(f,Db,Aa,1)|0)|0;Wd=Sb+(O1a(f,Ia,Aa,1)|0)|0;if((jd-2|0)==(Ia|0)){xe=(O1a(f,Pa,Aa,1)|0)+Wd|0}else{xe=Wd}Wd=(ca(xe,ue)|0)+we|0;if((Wd|0)<(me|0)){se=1;te=Wd;break}b[Mb>>1]=b[t>>1]|0;b[Mb+2>>1]=b[t+2>>1]|0;b[Mb+4>>1]=b[t+4>>1]|0;b[Mb+6>>1]=b[t+6>>1]|0;b[Mb+8>>1]=b[t+8>>1]|0;se=0;te=me}}while(0);Mb=Ub|se;Fc=Tb+1|0;if((Fc|0)<(Dc|0)){Cc=te;Tb=Fc;vb=Mb}else{ye=te;ze=Mb;break}}}else{ye=Kd;ze=ed}Id=ze;Jd=Dc+1|0;Kd=ye}c:while(1){vb=Pd;Tb=Qd;while(1){if((Tb|0)<8){break}if((vb|0)==0){break c}else{vb=0;Tb=0}}Dc=(b[_a>>1]|0)+(c[1057816+(Tb<<3)>>2]|0)|0;ed=(b[ab>>1]|0)+(c[1057820+(Tb<<3)>>2]|0)|0;Cc=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Mb=c[T>>2]|0;Fc=Mb+(Cc*10|0)|0;Nb=Fc;b[s>>1]=b[Nb>>1]|0;b[s+2>>1]=b[Nb+2>>1]|0;b[s+4>>1]=b[Nb+4>>1]|0;b[s+6>>1]=b[Nb+6>>1]|0;b[s+8>>1]=b[Nb+8>>1]|0;Ob=(ed<<6)+(Dc>>10)+(c[Z>>2]|0)+(d[Mb+(Cc*10|0)+4|0]<<12)|0;Xb=f+2139664+(((ed*31|0)+Dc&1023)<<2)|0;do{if((c[Xb>>2]|0)==(Ob|0)){Ae=0;Be=Rd}else{c[Xb>>2]=Ob;b[Fc>>1]=Dc;b[Mb+(Cc*10|0)+2>>1]=ed;Lb=Mb+(Cc*10|0)+8|0;a[Lb]=a[Lb]&-2;Lb=c[N>>2]|0;gd=16>>>(Lb>>>0);Ab=gd<<1;Gc=c[X>>2]|0;Pb=c[Gc+32>>2]|0;id=c[Gc>>2]|0;Gc=c[c[V>>2]>>2]|0;Wd=c[E>>2]|0;Sb=c[ba>>2]|0;_d=c[L>>2]<<Lb;Zb=c[Q>>2]<<Lb;Lb=c[R>>2]|0;Yd=c[_>>2]|0;Ec=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Ce=(Ec*3|0)>>8;break};case 11:{Ce=Ec>>5;break};case 12:{Ce=Ec>>6;break};case 2:case 14:{Ce=Ec>>6;break};case 6:case 4:case 1:case 10:{Ce=c[fa>>2]>>7;break};case 5:{Ce=1;break};default:{Ce=Ec>>7}}Ec=(gd|0)/2|0;Yb=(ca(gd,Ia)|0)-Ec|0;Vd=(ca(gd,xa)|0)-Ec|0;Ec=(Yb|0)>0?0:-Yb|0;fd=(Vd|0)>0?0:-Vd|0;Lc=Lb-Yb|0;Xd=(Ab|0)>(Lc|0)?Lc:Ab;Lc=Yd-Vd|0;dd=(Ab|0)>(Lc|0)?Lc:Ab;Lc=(ca(_d,xa)|0)+Ia|0;wtb(f,Sb,c[da>>2]|0,Pb,Yb,Vd,Ab,Ab,(c[T>>2]|0)+(Lc*10|0)|0,0,Lb,Yd);if((fd|0)<(dd|0)){Yd=(Ec|0)<(Xd|0);Lb=fd;do{Lc=ca(Lb,Ab)|0;Vb=ca(Lb,Pb)|0;Bb=(ca(Lb+Vd|0,Pb)|0)+Yb|0;if(Yd){Qb=Ec;do{Rb=((ca(d[I+(Lb<<5)+Qb|0]|0,d[Sb+(Qb+Vb)|0]|0)|0)+8|0)>>>4;kd=Rb+(b[Wd+(Qb+Lc<<1)>>1]|0)|0;Rb=kd>>4;if(Rb>>>0>255>>>0){De=(kd>>31^255)&255}else{De=Rb&255}a[id+(Bb+Qb)|0]=De;Qb=Qb+1|0;}while((Qb|0)<(Xd|0))}Lb=Lb+1|0;}while((Lb|0)<(dd|0))}if(mb){Ya=553}else{if((_d-1|0)==(Ia|0)){Ya=553}}do{if((Ya|0)==553){Ya=0;if(!Ea){if((Zb-1|0)!=(xa|0)){break}}Lb=mb?Ec:gd;Wd=Ea?gd:dd;Yd=Ea?fd:gd;if((Yd|0)>=(Wd|0)){break}Ub=Lb+Yb|0;Qb=(mb?gd:Xd)-Lb|0;Bb=Yd;do{nrc(id+(Ub+(ca(Bb+Vd|0,Pb)|0))|0,Sb+((ca(Bb,Pb)|0)+Lb)|0,Qb)|0;Bb=Bb+1|0;}while((Bb|0)<(Wd|0))}}while(0);do{if((gd|0)==16){Sb=c[(c[U>>2]|0)+232>>2]|0;if((Sb|0)==12){Xd=(ca(Vd,Pb)|0)+Yb|0;Ee=m1a(ha,Gc+Xd|0,id+Xd|0,Pb,32)|0;break}else if((Sb|0)==11){Sb=(ca(Vd,Pb)|0)+Yb|0;Ee=k1a(ha,Gc+Sb|0,id+Sb|0,Pb,32)|0;break}else{Sb=ca(Vd,Pb)|0;Xd=Sb+Yb|0;fd=Xe[c[ga>>2]&511](ha,Gc+Xd|0,id+Xd|0,Pb,16)|0;Xd=Yb+16|0;dd=Xd+Sb|0;Sb=(Xe[c[ga>>2]&511](ha,Gc+dd|0,id+dd|0,Pb,16)|0)+fd|0;fd=ca(Vd+16|0,Pb)|0;dd=fd+Yb|0;Ec=Sb+(Xe[c[ga>>2]&511](ha,Gc+dd|0,id+dd|0,Pb,16)|0)|0;dd=fd+Xd|0;Ee=Ec+(Xe[c[ga>>2]&511](ha,Gc+dd|0,id+dd|0,Pb,16)|0)|0;break}}else{dd=(ca(Vd,Pb)|0)+Yb|0;Ee=Xe[c[ga>>2]&511](ha,Gc+dd|0,id+dd|0,Pb,Ab)|0}}while(0);Ab=O1a(f,Ia,xa,1)|0;Pb=(O1a(f,Pa,xa,1)|0)+Ab|0;Ab=Pb+(O1a(f,Db,Aa,1)|0)|0;Pb=Ab+(O1a(f,Ia,Aa,1)|0)|0;if((_d-2|0)==(Ia|0)){Fe=(O1a(f,Pa,Aa,1)|0)+Pb|0}else{Fe=Pb}Pb=(ca(Fe,Ce)|0)+Ee|0;if((Pb|0)<(Rd|0)){Ae=1;Be=Pb;break}b[Nb>>1]=b[s>>1]|0;b[Nb+2>>1]=b[s+2>>1]|0;b[Nb+4>>1]=b[s+4>>1]|0;b[Nb+6>>1]=b[s+6>>1]|0;b[Nb+8>>1]=b[s+8>>1]|0;Ae=0;Be=Rd}}while(0);Pd=Ae|vb;Qd=Tb+1|0;Rd=Be}b[lb>>1]=b[_a>>1]|0;b[Kb>>1]=b[ab>>1]|0;if((Wb|0)<=(Rd|0)){_c=Wb;$c=Hb;ad=Gb;break}Nb=e[Jb>>1]|e[Jb+2>>1]<<16;Cc=a[cb]|0;a[D]=a[eb]|0;a[D+1|0]=a[eb+1|0]|0;a[D+2|0]=a[eb+2|0]|0;a[D+3|0]=a[eb+3|0]|0;a[D+4|0]=a[eb+4|0]|0;_c=Rd;$c=Cc;ad=Nb}}while(0);pb=jb+1|0;if((pb|0)<(c[H>>2]|0)){Gb=ad;Hb=$c;Wb=_c;jb=pb}else{Ge=ad;He=$c;Ie=_c;break}}}else{Ge=Eb;He=sb;Ie=Vc}y=Ge;b[Jb>>1]=y;b[Jb+2>>1]=y>>16;a[cb]=He;a[eb]=a[D]|0;a[eb+1|0]=a[D+1|0]|0;a[eb+2|0]=a[D+2|0]|0;a[eb+3|0]=a[D+3|0]|0;a[eb+4|0]=a[D+4|0]|0;jb=(ca(c[L>>2]<<c[N>>2],xa)|0)+Ia|0;Wb=c[T>>2]|0;Hb=Wb+(jb*10|0)|0;b[ka>>1]=b[Hb>>1]|0;b[ka+2>>1]=b[Hb+2>>1]|0;b[ka+4>>1]=b[Hb+4>>1]|0;b[ka+6>>1]=b[Hb+6>>1]|0;b[ka+8>>1]=b[Hb+8>>1]|0;a[Wb+(jb*10|0)+5|0]=c[ja>>2];a[Wb+(jb*10|0)+6|0]=c[q>>2];a[Wb+(jb*10|0)+7|0]=c[la>>2];Gb=Wb+(jb*10|0)+8|0;a[Gb]=a[Gb]|1;Gb=c[N>>2]|0;jb=16>>>(Gb>>>0);Wb=jb<<1;Db=c[X>>2]|0;Cb=c[Db+32>>2]|0;rb=c[Db>>2]|0;Db=c[c[V>>2]>>2]|0;ob=c[E>>2]|0;Na=c[ba>>2]|0;tb=c[L>>2]<<Gb;ub=c[Q>>2]<<Gb;Gb=c[R>>2]|0;kb=c[_>>2]|0;nb=c[ea>>2]|0;switch(c[(c[U>>2]|0)+232>>2]&255|0){case 3:{Je=(nb*3|0)>>8;break};case 11:{Je=nb>>5;break};case 12:{Je=nb>>6;break};case 2:case 14:{Je=nb>>6;break};case 6:case 4:case 1:case 10:{Je=c[fa>>2]>>7;break};case 5:{Je=1;break};default:{Je=nb>>7}}nb=(jb|0)/2|0;Ja=(ca(jb,Ia)|0)-nb|0;La=(ca(jb,xa)|0)-nb|0;nb=(Ja|0)>0?0:-Ja|0;pb=(La|0)>0?0:-La|0;Fb=Gb-Ja|0;Ib=(Wb|0)>(Fb|0)?Fb:Wb;Fb=kb-La|0;Nb=(Wb|0)>(Fb|0)?Fb:Wb;Fb=(ca(tb,xa)|0)+Ia|0;wtb(f,Na,c[da>>2]|0,Cb,Ja,La,Wb,Wb,(c[T>>2]|0)+(Fb*10|0)|0,0,Gb,kb);if((pb|0)<(Nb|0)){kb=(nb|0)<(Ib|0);Gb=pb;do{Fb=ca(Gb,Wb)|0;Cc=ca(Gb,Cb)|0;Mb=(ca(Gb+La|0,Cb)|0)+Ja|0;if(kb){ed=nb;do{Dc=((ca(d[I+(Gb<<5)+ed|0]|0,d[Na+(ed+Cc)|0]|0)|0)+8|0)>>>4;Fc=Dc+(b[ob+(ed+Fb<<1)>>1]|0)|0;Dc=Fc>>4;if(Dc>>>0>255>>>0){Ke=(Fc>>31^255)&255}else{Ke=Dc&255}a[rb+(Mb+ed)|0]=Ke;ed=ed+1|0;}while((ed|0)<(Ib|0))}Gb=Gb+1|0;}while((Gb|0)<(Nb|0))}if(mb){Ya=589}else{if((tb-1|0)==(Ia|0)){Ya=589}}do{if((Ya|0)==589){Ya=0;if(!Ea){if((ub-1|0)!=(xa|0)){break}}Gb=mb?nb:jb;ob=Ea?jb:Nb;kb=Ea?pb:jb;if((kb|0)>=(ob|0)){break}Jb=Gb+Ja|0;sb=(mb?jb:Ib)-Gb|0;Eb=kb;do{nrc(rb+(Jb+(ca(Eb+La|0,Cb)|0))|0,Na+((ca(Eb,Cb)|0)+Gb)|0,sb)|0;Eb=Eb+1|0;}while((Eb|0)<(ob|0))}}while(0);do{if((jb|0)==16){Na=c[(c[U>>2]|0)+232>>2]|0;if((Na|0)==12){Ib=(ca(La,Cb)|0)+Ja|0;Le=m1a(ha,Db+Ib|0,rb+Ib|0,Cb,32)|0;break}else if((Na|0)==11){Na=(ca(La,Cb)|0)+Ja|0;Le=k1a(ha,Db+Na|0,rb+Na|0,Cb,32)|0;break}else{Na=ca(La,Cb)|0;Ib=Na+Ja|0;mb=Xe[c[ga>>2]&511](ha,Db+Ib|0,rb+Ib|0,Cb,16)|0;Ib=Ja+16|0;pb=Ib+Na|0;Na=(Xe[c[ga>>2]&511](ha,Db+pb|0,rb+pb|0,Cb,16)|0)+mb|0;mb=ca(La+16|0,Cb)|0;pb=mb+Ja|0;Nb=Na+(Xe[c[ga>>2]&511](ha,Db+pb|0,rb+pb|0,Cb,16)|0)|0;pb=mb+Ib|0;Le=Nb+(Xe[c[ga>>2]&511](ha,Db+pb|0,rb+pb|0,Cb,16)|0)|0;break}}else{pb=(ca(La,Cb)|0)+Ja|0;Le=Xe[c[ga>>2]&511](ha,Db+pb|0,rb+pb|0,Cb,Wb)|0}}while(0);Wb=O1a(f,Ia,xa,1)|0;Cb=(O1a(f,Pa,xa,1)|0)+Wb|0;Wb=Cb+(O1a(f,Ia-1|0,Aa,1)|0)|0;Cb=Wb+(O1a(f,Ia,Aa,1)|0)|0;if((tb-2|0)==(Ia|0)){Me=(O1a(f,Pa,Aa,1)|0)+Cb|0}else{Me=Cb}if(((ca(Me,Je)|0)+Le|0)>=(Ie|0)){b[Hb>>1]=b[ka>>1]|0;b[Hb+2>>1]=b[ka+2>>1]|0;b[Hb+4>>1]=b[ka+4>>1]|0;b[Hb+6>>1]=b[ka+6>>1]|0;b[Hb+8>>1]=b[ka+8>>1]|0}Cb=a[Za]|0;do{if((Cb&1)==0){Ya=607}else{if((Ta&1)==0){Ya=607;break}Ne=(d[gb]|0)-(hb&255)|(d[eb]|0)-(fb&255)|(d[ib]|0)-(Ka&255)}}while(0);if((Ya|0)==607){Ya=0;Ne=(b[_a>>1]|0)-($a<<16>>16)|(Cb^Ta)&1|(b[ab>>1]|0)-(bb<<16>>16)|(d[cb]|0)-(db&255)}if((Ne|0)!=0){break}}if(Qa){Ia=Pa}else{Oe=Ga;Pe=Aa;break a}}if((Ma|0)!=0){Ia=Ma+8|0;a[Ia]=a[Ia]&-3}if((Oa|0)!=0){Ia=Oa+8|0;a[Ia]=a[Ia]&-3}if((Ra|0)!=0){Ia=Ra+8|0;a[Ia]=a[Ia]&-3}if((Sa|0)!=0){Ia=Sa+8|0;a[Ia]=a[Ia]&-3}if((Ua|0)!=0){Ia=Ua+8|0;a[Ia]=a[Ia]&-3}if((Va|0)!=0){Ia=Va+8|0;a[Ia]=a[Ia]&-3}if((Wa|0)!=0){Ia=Wa+8|0;a[Ia]=a[Ia]&-3}if((Xa|0)!=0){Ia=Xa+8|0;a[Ia]=a[Ia]&-3}Ia=Ga+1|0;if(Qa){Ga=Ia;Ha=Pa}else{Oe=Ia;Pe=Aa;break}}}else{Oe=wa;Pe=xa+1|0}}while(0);if((Pe|0)<(S|0)){wa=Oe;xa=Pe}else{Qe=Oe;break}}}else{Qe=0}KIb(c[U>>2]|0,16,2637560,(Re=i,i=i+16|0,c[Re>>2]=ta,c[Re+8>>2]=Qe,Re)|0);i=Re;if((Qe|0)==0){break}else{ta=ta+1|0}}if((c[N>>2]|0)!=1){i=g;return}if(K){K=J|0;ta=J+4|0;Qe=J+8|0;Oe=J+12|0;Pe=m;m=n;n=o;o=p;p=h;h=j;j=k;k=l;l=0;Pa=0;while(1){if(O){Qa=ca(l,P)|0;Xa=Pa;Wa=0;while(1){Va=Wa+Qa|0;Ua=c[T>>2]|0;Sa=Ua+(Va*10|0)|0;c[K>>2]=Sa;Ra=Va|1;Oa=Ua+(Ra*10|0)|0;c[ta>>2]=Oa;Ma=Va+P|0;Ne=Ua+(Ma*10|0)|0;c[Qe>>2]=Ne;ka=Va+qa|0;Ie=Ua+(ka*10|0)|0;c[Oe>>2]=Ie;Le=a[Ua+(Va*10|0)+8|0]|0;Je=(Le&1)==0;Me=a[Ua+(Ra*10|0)+8|0]|0;do{if(Je){Ya=636}else{if((Me&1)==0){Ya=636;break}Se=(d[Ua+(Va*10|0)+6|0]|0)-(d[Ua+(Ra*10|0)+6|0]|0)|(d[Ua+(Va*10|0)+5|0]|0)-(d[Ua+(Ra*10|0)+5|0]|0)|(d[Ua+(Va*10|0)+7|0]|0)-(d[Ua+(Ra*10|0)+7|0]|0)}}while(0);if((Ya|0)==636){Ya=0;Se=(b[Sa>>1]|0)-(b[Oa>>1]|0)|(Me^Le)&1|(b[Ua+(Va*10|0)+2>>1]|0)-(b[Ua+(Ra*10|0)+2>>1]|0)|(d[Ua+(Va*10|0)+4|0]|0)-(d[Ua+(Ra*10|0)+4|0]|0)}do{if((Se|0)==0){ha=a[Ua+(Ma*10|0)+8|0]|0;do{if(Je){Ya=641}else{if((ha&1)==0){Ya=641;break}Te=(d[Ua+(Va*10|0)+6|0]|0)-(d[Ua+(Ma*10|0)+6|0]|0)|(d[Ua+(Va*10|0)+5|0]|0)-(d[Ua+(Ma*10|0)+5|0]|0)|(d[Ua+(Va*10|0)+7|0]|0)-(d[Ua+(Ma*10|0)+7|0]|0)}}while(0);if((Ya|0)==641){Ya=0;Te=(b[Sa>>1]|0)-(b[Ne>>1]|0)|(ha^Le)&1|(b[Ua+(Va*10|0)+2>>1]|0)-(b[Ua+(Ma*10|0)+2>>1]|0)|(d[Ua+(Va*10|0)+4|0]|0)-(d[Ua+(Ma*10|0)+4|0]|0)}if((Te|0)!=0){Ya=648;break}ga=a[Ua+(ka*10|0)+8|0]|0;do{if(Je){Ya=646}else{if((ga&1)==0){Ya=646;break}Ue=(d[Ua+(Va*10|0)+6|0]|0)-(d[Ua+(ka*10|0)+6|0]|0)|(d[Ua+(Va*10|0)+5|0]|0)-(d[Ua+(ka*10|0)+5|0]|0)|(d[Ua+(Va*10|0)+7|0]|0)-(d[Ua+(ka*10|0)+7|0]|0)}}while(0);if((Ya|0)==646){Ya=0;Ue=(b[Sa>>1]|0)-(b[Ie>>1]|0)|(ga^Le)&1|(b[Ua+(Va*10|0)+2>>1]|0)-(b[Ua+(ka*10|0)+2>>1]|0)|(d[Ua+(Va*10|0)+4|0]|0)-(d[Ua+(ka*10|0)+4|0]|0)}if((Ue|0)==0){Ve=Xa}else{Ya=648}}else{Ya=648}}while(0);if((Ya|0)==648){Ya=0;Le=c[Z>>2]|0;if((Le|0)==0){mrc(M|0,0,4096)|0}c[Z>>2]=Le+4194304;Le=N1a(f,Wa,l)|0;Je=(b[Sa>>1]|0)+2+(b[Oa>>1]|0)+(b[Ne>>1]|0)+(b[Ie>>1]|0)|0;Me=Je>>2;ha=(b[Ua+(Va*10|0)+2>>1]|0)+2+(b[Ua+(Ra*10|0)+2>>1]|0)+(b[Ua+(Ma*10|0)+2>>1]|0)+(b[Ua+(ka*10|0)+2>>1]|0)>>2;Ke=c[L>>2]<<c[N>>2];I=(ca(Ke,l)|0)+Wa|0;da=c[T>>2]|0;fa=da+(I*10|0)|0;ea=fa;b[Pe>>1]=b[ea>>1]|0;b[Pe+2>>1]=b[ea+2>>1]|0;b[Pe+4>>1]=b[ea+4>>1]|0;b[Pe+6>>1]=b[ea+6>>1]|0;b[Pe+8>>1]=b[ea+8>>1]|0;_=da+((I|1)*10|0)|0;b[m>>1]=b[_>>1]|0;b[m+2>>1]=b[_+2>>1]|0;b[m+4>>1]=b[_+4>>1]|0;b[m+6>>1]=b[_+6>>1]|0;b[m+8>>1]=b[_+8>>1]|0;R=da+((I+Ke|0)*10|0)|0;b[n>>1]=b[R>>1]|0;b[n+2>>1]=b[R+2>>1]|0;b[n+4>>1]=b[R+4>>1]|0;b[n+6>>1]=b[R+6>>1]|0;b[n+8>>1]=b[R+8>>1]|0;Q=da+((Ke+1+I|0)*10|0)|0;b[o>>1]=b[Q>>1]|0;b[o+2>>1]=b[Q+2>>1]|0;b[o+4>>1]=b[Q+4>>1]|0;b[o+6>>1]=b[Q+6>>1]|0;b[o+8>>1]=b[Q+8>>1]|0;Ke=da+(I*10|0)+4|0;ba=(ha<<6)+(Je>>12)+(c[Z>>2]|0)+(d[Ke]<<12)|0;Je=f+2139664+(((ha*31|0)+Me&1023)<<2)|0;do{if((c[Je>>2]|0)==(ba|0)){We=Le;Ye=1;Ze=Sa}else{c[Je>>2]=ba;b[fa>>1]=Me;b[da+(I*10|0)+2>>1]=ha;a[Ke]=0;E=da+(I*10|0)+8|0;a[E]=a[E]&-2;b[Q>>1]=b[ea>>1]|0;b[Q+2>>1]=b[ea+2>>1]|0;b[Q+4>>1]=b[ea+4>>1]|0;b[Q+6>>1]=b[ea+6>>1]|0;b[Q+8>>1]=b[ea+8>>1]|0;orc(R|0,ea|0,10)|0;b[_>>1]=b[R>>1]|0;b[_+2>>1]=b[R+2>>1]|0;b[_+4>>1]=b[R+4>>1]|0;b[_+6>>1]=b[R+6>>1]|0;b[_+8>>1]=b[R+8>>1]|0;E=N1a(f,Wa,l)|0;if((E|0)<(Le|0)){We=E;Ye=1;Ze=Sa;break}b[ea>>1]=b[Pe>>1]|0;b[ea+2>>1]=b[Pe+2>>1]|0;b[ea+4>>1]=b[Pe+4>>1]|0;b[ea+6>>1]=b[Pe+6>>1]|0;b[ea+8>>1]=b[Pe+8>>1]|0;b[_>>1]=b[m>>1]|0;b[_+2>>1]=b[m+2>>1]|0;b[_+4>>1]=b[m+4>>1]|0;b[_+6>>1]=b[m+6>>1]|0;b[_+8>>1]=b[m+8>>1]|0;b[R>>1]=b[n>>1]|0;b[R+2>>1]=b[n+2>>1]|0;b[R+4>>1]=b[n+4>>1]|0;b[R+6>>1]=b[n+6>>1]|0;b[R+8>>1]=b[n+8>>1]|0;b[Q>>1]=b[o>>1]|0;b[Q+2>>1]=b[o+2>>1]|0;b[Q+4>>1]=b[o+4>>1]|0;b[Q+6>>1]=b[o+6>>1]|0;b[Q+8>>1]=b[o+8>>1]|0;We=Le;Ye=1;Ze=Sa}}while(0);while(1){do{if((a[Ze+8|0]&1)==0){Sa=b[Ze>>1]|0;Q=Sa<<16>>16;R=b[Ze+2>>1]|0;_=R<<16>>16;ea=a[Ze+4|0]|0;I=c[L>>2]<<c[N>>2];da=(ca(I,l)|0)+Wa|0;Ke=c[T>>2]|0;ha=Ke+(da*10|0)|0;Me=ha;b[p>>1]=b[Me>>1]|0;b[p+2>>1]=b[Me+2>>1]|0;b[p+4>>1]=b[Me+4>>1]|0;b[p+6>>1]=b[Me+6>>1]|0;b[p+8>>1]=b[Me+8>>1]|0;fa=Ke+((da|1)*10|0)|0;b[h>>1]=b[fa>>1]|0;b[h+2>>1]=b[fa+2>>1]|0;b[h+4>>1]=b[fa+4>>1]|0;b[h+6>>1]=b[fa+6>>1]|0;b[h+8>>1]=b[fa+8>>1]|0;ba=Ke+((da+I|0)*10|0)|0;b[j>>1]=b[ba>>1]|0;b[j+2>>1]=b[ba+2>>1]|0;b[j+4>>1]=b[ba+4>>1]|0;b[j+6>>1]=b[ba+6>>1]|0;b[j+8>>1]=b[ba+8>>1]|0;Je=Ke+((I+1+da|0)*10|0)|0;b[k>>1]=b[Je>>1]|0;b[k+2>>1]=b[Je+2>>1]|0;b[k+4>>1]=b[Je+4>>1]|0;b[k+6>>1]=b[Je+6>>1]|0;b[k+8>>1]=b[Je+8>>1]|0;I=Ke+(da*10|0)+4|0;ka=(_<<6)+(Q>>10)+(c[Z>>2]|0)+(d[I]<<12)|0;Ua=f+2139664+(((_*31|0)+Q&1023)<<2)|0;if((c[Ua>>2]|0)==(ka|0)){_e=We;break}c[Ua>>2]=ka;b[ha>>1]=Sa;b[Ke+(da*10|0)+2>>1]=R;a[I]=ea;ea=Ke+(da*10|0)+8|0;a[ea]=a[ea]&-2;b[Je>>1]=b[Me>>1]|0;b[Je+2>>1]=b[Me+2>>1]|0;b[Je+4>>1]=b[Me+4>>1]|0;b[Je+6>>1]=b[Me+6>>1]|0;b[Je+8>>1]=b[Me+8>>1]|0;orc(ba|0,Me|0,10)|0;b[fa>>1]=b[ba>>1]|0;b[fa+2>>1]=b[ba+2>>1]|0;b[fa+4>>1]=b[ba+4>>1]|0;b[fa+6>>1]=b[ba+6>>1]|0;b[fa+8>>1]=b[ba+8>>1]|0;ea=N1a(f,Wa,l)|0;if((ea|0)<(We|0)){_e=ea;break}b[Me>>1]=b[p>>1]|0;b[Me+2>>1]=b[p+2>>1]|0;b[Me+4>>1]=b[p+4>>1]|0;b[Me+6>>1]=b[p+6>>1]|0;b[Me+8>>1]=b[p+8>>1]|0;b[fa>>1]=b[h>>1]|0;b[fa+2>>1]=b[h+2>>1]|0;b[fa+4>>1]=b[h+4>>1]|0;b[fa+6>>1]=b[h+6>>1]|0;b[fa+8>>1]=b[h+8>>1]|0;b[ba>>1]=b[j>>1]|0;b[ba+2>>1]=b[j+2>>1]|0;b[ba+4>>1]=b[j+4>>1]|0;b[ba+6>>1]=b[j+6>>1]|0;b[ba+8>>1]=b[j+8>>1]|0;b[Je>>1]=b[k>>1]|0;b[Je+2>>1]=b[k+2>>1]|0;b[Je+4>>1]=b[k+4>>1]|0;b[Je+6>>1]=b[k+6>>1]|0;b[Je+8>>1]=b[k+8>>1]|0;_e=We}else{_e=We}}while(0);if((Ye|0)>=4){break}ga=c[J+(Ye<<2)>>2]|0;We=_e;Ye=Ye+1|0;Ze=ga}Ve=((Le|0)!=(_e|0))+Xa|0}ga=Wa+2|0;if((ga|0)<(P|0)){Xa=Ve;Wa=ga}else{$e=Ve;break}}}else{$e=Pa}Wa=l+2|0;if((Wa|0)<(S|0)){l=Wa;Pa=$e}else{af=$e;break}}}else{af=0}KIb(c[U>>2]|0,16,2614280,(Re=i,i=i+8|0,c[Re>>2]=af<<2,Re)|0);i=Re;i=g;return}function J1a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=e+7528|0;n=e+7536|0;o=c[n>>2]|0;p=c[m>>2]<<o;q=o-f|0;r=(ca(p,h)|0)+g<<q;s=g+1<<q;t=e+2139660|0;u=c[t>>2]|0;v=u+(r*10|0)|0;w=(g|0)!=0;if(w){x=u+((r-1|0)*10|0)|0}else{x=778072}do{if((h|0)==0){y=x;z=778072;A=x}else{B=r-p|0;C=u+(B*10|0)|0;if(w){D=u+((B-1|0)*10|0)|0}else{D=x}if((s|0)>=(p|0)){y=D;z=C;A=D;break}if(!((g&1|0)==0|(f|0)==0)){y=D;z=C;A=D;break}y=u+(((1<<q)-p+r|0)*10|0)|0;z=C;A=D}}while(0);D=a[x+5|0]|0;s=D&255;w=a[x+6|0]|0;C=w&255;B=a[x+7|0]|0;E=B&255;F=d[x+4|0]|0;G=F<<1;H=G&256;I=d[z+4|0]|0;J=I<<1;K=J&256;L=(d[1359664+((K|0)==0?J:I>>>7)|0]|0)+(d[1359664+((H|0)==0?G:F>>>7)|0]|0)|0;F=(b[x>>1]|0)-(b[z>>1]|0)|0;G=(F|0)>-1?F:-F|0;F=G<<1;I=F>>>0>65535>>>0;J=I?G>>>15&65535:F;F=I?16:0;if((J&65280|0)==0){M=F;N=J}else{M=F|8;N=J>>>8}J=u+(r*10|0)+4|0;F=a[J]|0;I=(F<<24>>24!=0)<<4;G=(d[1359664+N|0]|0)+M+I|0;M=(b[x+2>>1]|0)-(b[z+2>>1]|0)|0;N=(M|0)>-1?M:-M|0;M=N<<1;O=M>>>0>65535>>>0;P=O?N>>>15&65535:M;M=O?16:0;if((P&65280|0)==0){Q=M;R=P}else{Q=M|8;R=P>>>8}P=Q+I+(d[1359664+R|0]|0)|0;R=(d[y+9|0]|0)+(d[A+9|0]|0)+((d[z+9|0]|0)+(d[x+9|0]|0)<<1)|0;if((c[e+7348>>2]|0)!=0){A=1<<q;q=f&255;if((A|0)>0){S=0}else{i=j;return}do{I=(ca(S,p)|0)+r|0;Q=0;do{M=I+Q|0;O=c[t>>2]|0;mrc(O+(M*10|0)|0,0,5)|0;a[O+(M*10|0)+5|0]=D;a[O+(M*10|0)+6|0]=w;a[O+(M*10|0)+7|0]=B;a[O+(M*10|0)+8|0]=1;a[O+(M*10|0)+9|0]=q;Q=Q+1|0;}while((Q|0)<(A|0));S=S+1|0;}while((S|0)<(A|0));i=j;return}a:do{if((o|0)==(f|0)){T=u+(r*10|0)+8|0}else{A=r+1|0;S=u+(r*10|0)+8|0;q=a[S]|0;Q=(q&1)==0;I=a[u+(A*10|0)+8|0]|0;do{if(Q){U=23}else{if((I&1)==0){U=23;break}V=(d[u+(r*10|0)+6|0]|0)-(d[u+(A*10|0)+6|0]|0)|(d[u+(r*10|0)+5|0]|0)-(d[u+(A*10|0)+5|0]|0)|(d[u+(r*10|0)+7|0]|0)-(d[u+(A*10|0)+7|0]|0)}}while(0);if((U|0)==23){V=(b[v>>1]|0)-(b[u+(A*10|0)>>1]|0)|(I^q)&1|(b[u+(r*10|0)+2>>1]|0)-(b[u+(A*10|0)+2>>1]|0)|(F&255)-(d[u+(A*10|0)+4|0]|0)}do{if((V|0)==0){M=r+p|0;O=a[u+(M*10|0)+8|0]|0;do{if(Q){U=28}else{if((O&1)==0){U=28;break}W=(d[u+(r*10|0)+6|0]|0)-(d[u+(M*10|0)+6|0]|0)|(d[u+(r*10|0)+5|0]|0)-(d[u+(M*10|0)+5|0]|0)|(d[u+(r*10|0)+7|0]|0)-(d[u+(M*10|0)+7|0]|0)}}while(0);if((U|0)==28){W=(b[v>>1]|0)-(b[u+(M*10|0)>>1]|0)|(O^q)&1|(b[u+(r*10|0)+2>>1]|0)-(b[u+(M*10|0)+2>>1]|0)|(F&255)-(d[u+(M*10|0)+4|0]|0)}if((W|0)!=0){break}N=M+1|0;X=a[u+(N*10|0)+8|0]|0;do{if(Q){U=33}else{if((X&1)==0){U=33;break}Y=(d[u+(r*10|0)+6|0]|0)-(d[u+(N*10|0)+6|0]|0)|(d[u+(r*10|0)+5|0]|0)-(d[u+(N*10|0)+5|0]|0)|(d[u+(r*10|0)+7|0]|0)-(d[u+(N*10|0)+7|0]|0)}}while(0);if((U|0)==33){Y=(b[v>>1]|0)-(b[u+(N*10|0)>>1]|0)|(X^q)&1|(b[u+(r*10|0)+2>>1]|0)-(b[u+(N*10|0)+2>>1]|0)|(F&255)-(d[u+(N*10|0)+4|0]|0)}if((Y|0)!=0){break}H1a(e+8|0,R+4+(e+3124)|0,1);T=S;break a}}while(0);H1a(e+8|0,R+4+(e+3124)|0,0);S=f+1|0;q=g<<1;Q=h<<1;J1a(e,S,q,Q);A=q|1;J1a(e,S,A,Q);I=Q|1;J1a(e,S,q,I);J1a(e,S,A,I);i=j;return}}while(0);if((a[T]&1)==0){T=e+7388|0;M1a(c[T>>2]|0,k,l,d[J]|0,x,z,y);R=e+8|0;H1a(R,(a[x+8|0]&1)+1+(a[z+8|0]&1)+(e+3124)|0,0);if((c[T>>2]|0)>1){L1a(R,(((L<<5)+H&-32)+K+1152&-32)+(e+3124)|0,d[J]|0,0)}K=v|0;L1a(R,(G<<5)+128+(e+3124)|0,(b[K>>1]|0)-(c[k>>2]|0)|0,1);G=u+(r*10|0)+2|0;L1a(R,(P<<5)+128+(e+3124)|0,(b[G>>1]|0)-(c[l>>2]|0)|0,1);P=b[K>>1]|0;K=b[G>>1]|0;G=a[J]|0;J=c[n>>2]|0;R=c[m>>2]<<J;v=J-f|0;J=(ca(R,h)|0)+g<<v;H=1<<v;v=f&255;if((H|0)>0){Z=0}else{i=j;return}do{L=(ca(Z,R)|0)+J|0;T=0;do{Y=L+T|0;F=c[t>>2]|0;b[F+(Y*10|0)>>1]=P;b[F+(Y*10|0)+2>>1]=K;a[F+(Y*10|0)+4|0]=G;a[F+(Y*10|0)+5|0]=D;a[F+(Y*10|0)+6|0]=w;a[F+(Y*10|0)+7|0]=B;a[F+(Y*10|0)+8|0]=0;a[F+(Y*10|0)+9|0]=v;T=T+1|0;}while((T|0)<(H|0));Z=Z+1|0;}while((Z|0)<(H|0));i=j;return}M1a(c[e+7388>>2]|0,k,l,0,x,z,y);y=e+8|0;H1a(y,(a[x+8|0]&1)+1+(a[z+8|0]&1)+(e+3124)|0,1);z=u+(r*10|0)+5|0;L1a(y,e+3156|0,(d[z]|0)-s|0,1);if((c[e+7544>>2]|0)>2){s=u+(r*10|0)+6|0;L1a(y,e+3188|0,(d[s]|0)-C|0,1);C=u+(r*10|0)+7|0;L1a(y,e+3220|0,(d[C]|0)-E|0,1);_=s;$=C}else{_=u+(r*10|0)+6|0;$=u+(r*10|0)+7|0}r=a[z]|0;z=a[_]|0;_=a[$]|0;$=c[n>>2]|0;n=c[m>>2]<<$;m=$-f|0;$=(ca(n,h)|0)+g<<m;g=1<<m;m=c[k>>2]&65535;k=c[l>>2]&65535;l=f&255;if((g|0)>0){aa=0}else{i=j;return}do{f=(ca(aa,n)|0)+$|0;h=0;do{u=f+h|0;C=c[t>>2]|0;b[C+(u*10|0)>>1]=m;b[C+(u*10|0)+2>>1]=k;a[C+(u*10|0)+4|0]=0;a[C+(u*10|0)+5|0]=r;a[C+(u*10|0)+6|0]=z;a[C+(u*10|0)+7|0]=_;a[C+(u*10|0)+8|0]=1;a[C+(u*10|0)+9|0]=l;h=h+1|0;}while((h|0)<(g|0));aa=aa+1|0;}while((aa|0)<(g|0));i=j;return}function K1a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0;j=i;i=i+11712|0;k=j|0;l=j+1024|0;m=j+2048|0;n=j+6272|0;o=j+10496|0;p=j+11040|0;q=j+11584|0;r=j+11592|0;s=j+11600|0;t=j+11680|0;u=j+11696|0;v=j+11704|0;w=e+8|0;x=e+540|0;y=c[x>>2]|0;z=e+536|0;A=c[z>>2]|0;B=e+7528|0;C=e+7536|0;D=c[C>>2]|0;E=c[B>>2]<<D;F=c[e+7532>>2]<<D;H=D-f|0;I=(ca(E,h)|0)+g<<H;J=4-f|0;K=1<<J;L=(g|0)!=0;if(L){M=(c[e+2139660>>2]|0)+((I-1|0)*10|0)|0}else{M=778072}N=(h|0)!=0;if(N){O=(c[e+2139660>>2]|0)+((I-E|0)*10|0)|0}else{O=778072}P=(g+1<<H|0)<(E|0);if(P){Q=(c[e+2139660>>2]|0)+((I+1|0)*10|0)|0}else{Q=778072}if((h+1<<H|0)<(F|0)){R=(c[e+2139660>>2]|0)+((I+E|0)*10|0)|0}else{R=778072}S=N^1;if(S|L^1){T=M}else{T=(c[e+2139660>>2]|0)+((I+~E|0)*10|0)|0}do{if(S|P^1){U=T}else{if(!((g&1|0)==0|(f|0)==0)){U=T;break}U=(c[e+2139660>>2]|0)+(((1<<H)-E+I|0)*10|0)|0}}while(0);P=a[M+5|0]|0;S=P&255;L=a[M+6|0]|0;V=L&255;W=a[M+7|0]|0;X=W&255;Y=c[e+2540>>2]|0;Z=c[Y+32>>2]|0;_=c[Y+36>>2]|0;Y=c[e+2536>>2]|0;$=(c[Y>>2]|0)+((ca(Z,h)|0)+g<<J)|0;aa=g<<J;ba=e+7480|0;da=(ca(_,h)|0)<<J;ea=e+7484|0;fa=(da>>c[ea>>2])+(aa>>c[ba>>2])|0;da=(c[Y+4>>2]|0)+fa|0;ga=(c[Y+8>>2]|0)+fa|0;fa=((c[(c[e+4>>2]|0)+88>>2]|0)>>>4&1)+1|0;Y=e+2143800|0;ha=d[M+4|0]|0;ia=ha<<1;ja=ia&256;ka=d[O+4|0]|0;la=ka<<1;ma=la&256;na=(d[1359664+((ma|0)==0?la:ka>>>7)|0]|0)+(d[1359664+((ja|0)==0?ia:ha>>>7)|0]|0)|0;ha=b[M>>1]|0;ia=b[O>>1]|0;ka=ha-ia|0;la=(ka|0)>-1?ka:-ka|0;ka=la<<1;oa=ka>>>0>65535>>>0;pa=oa?la>>>15&65535:ka;ka=oa?16:0;if((pa&65280|0)==0){qa=ka;ra=pa}else{qa=ka|8;ra=pa>>>8}pa=(d[1359664+ra|0]|0)+qa|0;qa=b[M+2>>1]|0;ra=b[O+2>>1]|0;ka=qa-ra|0;oa=(ka|0)>-1?ka:-ka|0;ka=oa<<1;la=ka>>>0>65535>>>0;sa=la?oa>>>15&65535:ka;ka=la?16:0;if((sa&65280|0)==0){ta=ka;ua=sa}else{ta=ka|8;ua=sa>>>8}sa=(d[1359664+ua|0]|0)+ta|0;ta=(d[U+9|0]|0)+(d[T+9|0]|0)+((d[O+9|0]|0)+(d[M+9|0]|0)<<1)|0;if((c[e+7348>>2]|0)!=0){T=1<<H;H=f&255;if((T|0)<=0){va=0;i=j;return va|0}ua=e+2139660|0;ka=0;while(1){la=(ca(ka,E)|0)+I|0;oa=0;do{wa=la+oa|0;xa=c[ua>>2]|0;mrc(xa+(wa*10|0)|0,0,5)|0;a[xa+(wa*10|0)+5|0]=P;a[xa+(wa*10|0)+6|0]=L;a[xa+(wa*10|0)+7|0]=W;a[xa+(wa*10|0)+8|0]=1;a[xa+(wa*10|0)+9|0]=H;oa=oa+1|0;}while((oa|0)<(T|0));oa=ka+1|0;if((oa|0)<(T|0)){ka=oa}else{va=0;break}}i=j;return va|0}ka=s+8|0;c[ka>>2]=ha;T=s+12|0;c[T>>2]=qa;H=s+16|0;c[H>>2]=ia;ua=s+20|0;c[ua>>2]=ra;oa=b[U>>1]|0;la=s+24|0;c[la>>2]=oa;wa=b[U+2>>1]|0;xa=s+28|0;c[xa>>2]=wa;ya=e+2139660|0;za=c[ya>>2]|0;Aa=t|0;b[t>>1]=b[za+(I*10|0)>>1]|0;b[t+2>>1]=b[za+(I*10|0)+2>>1]|0;b[t+4>>1]=b[Q>>1]|0;b[t+6>>1]=b[Q+2>>1]|0;b[t+8>>1]=b[R>>1]|0;b[t+10>>1]=b[R+2>>1]|0;c[e+2143924>>2]=2;c[e+2156280>>2]=0;c[e+2156276>>2]=0;c[e+2155924>>2]=0;R=c[e+7500>>2]|0;t=e+7504|0;Q=c[t>>2]|0;za=e+2155920|0;Ba=c[za>>2]|0;switch(c[Ba+232>>2]&255|0){case 11:{Ca=R>>5;break};case 2:case 14:{Ca=R>>6;break};case 3:{Ca=(R*3|0)>>8;break};case 12:{Ca=R>>6;break};case 6:case 4:case 1:case 10:{Ca=Q>>7;break};case 5:{Ca=1;break};default:{Ca=R>>7}}Da=e+2156032|0;c[Da>>2]=Ca;switch(c[Ba+236>>2]&255|0){case 3:{Ea=(R*3|0)>>8;break};case 11:{Ea=R>>5;break};case 12:{Ea=R>>6;break};case 2:case 14:{Ea=R>>6;break};case 6:case 4:case 1:case 10:{Ea=Q>>7;break};case 5:{Ea=1;break};default:{Ea=R>>7}}c[e+2156036>>2]=Ea;switch(c[Ba+240>>2]&255|0){case 3:{Fa=(R*3|0)>>8;break};case 11:{Fa=R>>5;break};case 12:{Fa=R>>6;break};case 2:case 14:{Fa=R>>6;break};case 6:case 4:case 1:case 10:{Fa=Q>>7;break};case 5:{Fa=1;break};default:{Fa=R>>7}}c[e+2156040>>2]=Fa;c[e+2155356>>2]=1;c[e+2156264>>2]=(c[e+2156260>>2]|0)+12289;Fa=(-g<<J)-13|0;c[e+2156064>>2]=Fa;c[e+2156072>>2]=(-h<<J)-13;R=4-D|0;D=(~g<<J)+13+(E<<R)|0;c[e+2156068>>2]=D;E=(~h<<J)+13+(F<<R)|0;c[e+2156076>>2]=E;R=D<<fa;if((ha|0)>(R|0)){c[ka>>2]=R;Ga=R}else{Ga=ha}ha=E<<fa;if((qa|0)>(ha|0)){c[T>>2]=ha;Ha=ha}else{Ha=qa}if((ia|0)>(R|0)){c[H>>2]=R;Ia=R}else{Ia=ia}if((ra|0)>(ha|0)){c[ua>>2]=ha;Ja=ha}else{Ja=ra}ra=Fa<<fa;if((oa|0)<(ra|0)){c[la>>2]=ra;Ka=ra}else{Ka=oa}if((Ka|0)>(R|0)){c[la>>2]=R;La=R}else{La=Ka}if((wa|0)>(ha|0)){c[xa>>2]=ha;Ma=ha}else{Ma=wa}do{if((Ga|0)>(Ia|0)){if((La|0)<=(Ia|0)){Na=Ia;break}Na=(La|0)>(Ga|0)?Ga:La}else{if((Ia|0)<=(La|0)){Na=Ia;break}Na=(La|0)>(Ga|0)?La:Ga}}while(0);c[s+32>>2]=Na;do{if((Ha|0)>(Ja|0)){if((Ma|0)<=(Ja|0)){Oa=Ja;break}Oa=(Ma|0)>(Ha|0)?Ha:Ma}else{if((Ja|0)<=(Ma|0)){Oa=Ja;break}Oa=(Ma|0)>(Ha|0)?Ma:Ha}}while(0);c[s+36>>2]=Oa;Ma=e+2156080|0;if(N){c[Ma>>2]=Na;c[e+2156084>>2]=Oa}else{c[Ma>>2]=Ga;c[e+2156084>>2]=Ha}Ha=e+7388|0;if((c[Ha>>2]|0)>0){Ga=h<<J;Ma=e+2156216|0;Oa=e+2156220|0;Na=e+2156088|0;N=e+2156152|0;Ja=e+2156092|0;La=e+2156156|0;Ia=e+2156096|0;wa=e+2156160|0;ha=s|0;s=65536>>>(fa>>>0);fa=e+2156268|0;xa=0;Ka=0;R=0;la=0;oa=2147483647;ra=Ba;while(1){Ba=c[e+2544+(R<<2)>>2]|0;Fa=(ca(c[Ma>>2]|0,Ga)|0)+aa|0;ua=(ca(c[Oa>>2]|0,Ga)|0)+aa|0;ia=ua>>c[(c[ra+60>>2]|0)+7480>>2];c[Na>>2]=$;c[N>>2]=(c[Ba>>2]|0)+Fa;c[Ja>>2]=da;c[La>>2]=(c[Ba+4>>2]|0)+ia;c[Ia>>2]=ga;c[wa>>2]=(c[Ba+8>>2]|0)+ia;ia=_qb(Y,u,v,ha,0,0,Aa,s,f,K)|0;gf[c[fa>>2]&63](Y,u,v,ia,0,0,f,K)|0;ia=Yqb(Y,c[u>>2]|0,c[v>>2]|0,0,0,f,K,0)|0;Ba=R<<1;Fa=Ba>>>0>65535>>>0;ua=Fa?R>>>15&65535:Ba;Ba=Fa?16:0;if((ua&65280|0)==0){Pa=Ba;Qa=ua}else{Pa=Ba|8;Qa=ua>>>8}ua=(ca(c[Da>>2]<<1,(d[1359664+Qa|0]|0)+Pa|0)|0)+ia|0;ia=c[e+7392+(R<<2)>>2]|0;if((ia|0)!=0){b[ia+(I<<2)>>1]=c[u>>2];b[ia+(I<<2)+2>>1]=c[v>>2];c[(c[e+7424+(R<<2)>>2]|0)+(I<<2)>>2]=ua}if((oa|0)>(ua|0)){Ra=ua;Sa=R;Ta=c[u>>2]|0;Ua=c[v>>2]|0}else{Ra=oa;Sa=la;Ta=Ka;Ua=xa}ua=R+1|0;if((ua|0)>=(c[Ha>>2]|0)){break}xa=Ua;Ka=Ta;R=ua;la=Sa;oa=Ra;ra=c[za>>2]|0}Va=Ua;Wa=Ta;Xa=Sa;Ya=Ra;Za=c[x>>2]|0;_a=c[z>>2]|0}else{Va=0;Wa=0;Xa=0;Ya=2147483647;Za=y;_a=A}Ra=Za-_a|0;_a=c[e+12>>2]|0;Za=_a>>>0>65535>>>0;Sa=Za?_a>>>16:_a;_a=Za?16:0;if((Sa&65280|0)==0){$a=_a;ab=Sa}else{$a=_a|8;ab=Sa>>>8}Sa=(Ra<<3)+((d[1359664+ab|0]|0)+($a-(Ra+(c[e+16>>2]|0)+((c[e+20>>2]|0)>>>31^1)<<3)))|0;Ra=o;$a=w;nrc(Ra|0,$a|0,540)|0;ab=k|0;k=o+532|0;c[k>>2]=ab;_a=o+528|0;c[_a>>2]=ab;Za=m|0;Ta=e+3124|0;nrc(Za|0,Ta|0,4224)|0;if((c[C>>2]|0)!=(f|0)){H1a(o,m+(ta+4)|0,1)}Ua=M+8|0;za=O+8|0;H1a(o,m+((d[Ua]|0)+1+(d[za]|0))|0,0);ra=c[Ha>>2]|0;if((ra|0)>1){L1a(o,m+(((na<<5)+ja&-32)+ma+1152&-32)|0,Xa,0);bb=c[Ha>>2]|0}else{bb=ra}M1a(bb,q,r,Xa,M,O,U);bb=((Xa|0)!=0)<<4;L1a(o,m+((pa+bb<<5)+128)|0,Wa-(c[q>>2]|0)|0,1);L1a(o,m+((sa+bb<<5)+128)|0,Va-(c[r>>2]|0)|0,1);bb=(c[k>>2]|0)-(c[_a>>2]|0)|0;_a=c[o+4>>2]|0;k=_a>>>0>65535>>>0;sa=k?_a>>>16:_a;_a=k?16:0;if((sa&65280|0)==0){cb=_a;db=sa}else{cb=_a|8;db=sa>>>8}sa=((ca((bb+(c[o+8>>2]|0)+((c[o+12>>2]|0)>>>31^1)<<3)+Sa-cb-(d[1359664+db|0]|0)|0,c[t>>2]|0)|0)>>7)+Ya|0;Ya=K<<J;if((K|0)>0){J=$;db=0;cb=0;while(1){o=J;_a=db;k=0;while(1){eb=(d[o]|0)+_a|0;m=k+1|0;if((m|0)<(K|0)){o=o+1|0;_a=eb;k=m}else{break}}k=cb+1|0;if((k|0)<(K|0)){J=J+Z|0;db=eb;cb=k}else{break}}cb=((Ya|0)/2|0)+eb|0;db=0;J=0;k=$;while(1){$=db;_a=0;o=k;while(1){fb=(c[6219288+((d[o]|256)<<2)>>2]|0)+$|0;m=_a+1|0;if((m|0)<(K|0)){$=fb;_a=m;o=o+1|0}else{break}}o=J+1|0;if((o|0)<(K|0)){db=fb;J=o;k=k+Z|0}else{gb=fb;hb=eb;ib=cb;break}}}else{gb=0;hb=0;ib=(Ya|0)/2|0}cb=(ib|0)/(Ya|0)|0;ib=gb-(ca(cb<<1,hb)|0)+(ca(ca(cb,Ya)|0,cb)|0)|0;hb=e+7544|0;if((c[hb>>2]|0)>2){gb=c[ba>>2]|0;ba=c[ea>>2]|0;ea=Ya>>ba+gb;Ya=K>>gb;gb=K>>ba;ba=(gb|0)>0&(Ya|0)>0;do{if(ba){K=da;eb=0;fb=0;while(1){Z=K;k=eb;J=0;while(1){jb=(d[Z]|0)+k|0;db=J+1|0;if((db|0)<(Ya|0)){Z=Z+1|0;k=jb;J=db}else{break}}J=fb+1|0;if((J|0)<(gb|0)){K=K+_|0;eb=jb;fb=J}else{break}}fb=(ea|0)/2|0;eb=(fb+jb|0)/(ea|0)|0;if(ba){kb=ga;lb=0;mb=0}else{nb=0;ob=fb;pb=eb;break}while(1){K=kb;J=lb;k=0;while(1){qb=(d[K]|0)+J|0;Z=k+1|0;if((Z|0)<(Ya|0)){K=K+1|0;J=qb;k=Z}else{break}}k=mb+1|0;if((k|0)<(gb|0)){kb=kb+_|0;lb=qb;mb=k}else{nb=qb;ob=fb;pb=eb;break}}}else{eb=(ea|0)/2|0;nb=0;ob=eb;pb=(eb|0)/(ea|0)|0}}while(0);rb=(nb+ob|0)/(ea|0)|0;sb=pb}else{rb=0;sb=0}pb=p;nrc(pb|0,$a|0,540)|0;ea=l|0;l=p+532|0;c[l>>2]=ea;ob=p+528|0;c[ob>>2]=ea;nb=n|0;nrc(nb|0,Ta|0,4224)|0;if((c[C>>2]|0)!=(f|0)){H1a(p,n+(ta+4)|0,1)}H1a(p,n+((d[Ua]|0)+1+(d[za]|0))|0,1);L1a(p,n+32|0,cb-S|0,1);if((c[hb>>2]|0)>2){L1a(p,n+64|0,sb-V|0,1);L1a(p,n+96|0,rb-X|0,1)}X=(c[l>>2]|0)-(c[ob>>2]|0)|0;ob=c[p+4>>2]|0;l=ob>>>0>65535>>>0;n=l?ob>>>16:ob;ob=l?16:0;if((n&65280|0)==0){tb=ob;ub=n}else{tb=ob|8;ub=n>>>8}n=ib+((ca((X+(c[p+8>>2]|0)+((c[p+12>>2]|0)>>>31^1)<<3)+Sa-tb-(d[1359664+ub|0]|0)|0,c[t>>2]|0)|0)>>7)|0;do{if((f|0)==0){ub=n>>8;tb=sa>>8;if(!((tb|0)<65|(tb|0)<(ub|0))){Sa=e+2156240|0;c[Sa>>2]=(c[Sa>>2]|0)+(c[e+2153760>>2]|0);break}if(tb>>>0<255>>>0){vb=(d[tb+1303321|0]|0)-1>>4}else{do{if(tb>>>0<4096>>>0){wb=(d[1303320+(tb>>>4)|0]|0)>>>2}else{if(tb>>>0<16384>>>0){wb=(d[1303320+(tb>>>6)|0]|0)>>>1;break}if(tb>>>0<65536>>>0){wb=d[1303320+(tb>>>8)|0]|0;break}else{Sa=tb>>>16;p=(Sa&65280|0)==0;ib=((d[1359664+(p?Sa:tb>>>24)|0]|0)+(p?0:8)|0)>>>1;p=tb>>>((ib+2|0)>>>0);Sa=d[1303320+(p>>>((ib+8|0)>>>0))|0]|0;Erc(p,0,c[1367848+(Sa<<2)>>2]|0,0)|0;wb=G+(Sa<<ib)|0;break}}}while(0);vb=wb-((ca(wb,wb)|0)>>>0>tb>>>0)|0}if(ub>>>0<255>>>0){xb=(d[ub+1303321|0]|0)-1>>4}else{do{if(ub>>>0<4096>>>0){yb=(d[1303320+(ub>>>4)|0]|0)>>>2}else{if(ub>>>0<16384>>>0){yb=(d[1303320+(ub>>>6)|0]|0)>>>1;break}if(ub>>>0<65536>>>0){yb=d[1303320+(ub>>>8)|0]|0;break}else{ib=ub>>>16;Sa=(ib&65280|0)==0;p=((d[1359664+(Sa?ib:ub>>>24)|0]|0)+(Sa?0:8)|0)>>>1;Sa=ub>>>((p+2|0)>>>0);ib=d[1303320+(Sa>>>((p+8|0)>>>0))|0]|0;Erc(Sa,0,c[1367848+(ib<<2)>>2]|0,0)|0;yb=G+(ib<<p)|0;break}}}while(0);xb=yb-((ca(yb,yb)|0)>>>0>ub>>>0)|0}tb=e+2156240|0;c[tb>>2]=vb-xb+(c[tb>>2]|0)}}while(0);do{if((c[C>>2]|0)!=(f|0)){H1a(w,ta+4+(e+3124)|0,0);xb=f+1|0;vb=g<<1;yb=h<<1;wb=K1a(e,xb,vb,yb)|0;tb=vb|1;p=(K1a(e,xb,tb,yb)|0)+wb|0;wb=yb|1;yb=p+(K1a(e,xb,vb,wb)|0)|0;vb=yb+(K1a(e,xb,tb,wb)|0)|0;wb=vb+(c[t>>2]>>7)|0;if((wb|0)<(sa|0)&(wb|0)<(n|0)){va=wb}else{break}i=j;return va|0}}while(0);if((n|0)<(sa|0)){M1a(c[Ha>>2]|0,q,r,0,M,O,U);nrc(y|0,ea|0,X)|0;nrc($a|0,pb|0,540)|0;c[z>>2]=A;c[x>>2]=y+X;X=c[C>>2]|0;pb=c[B>>2]<<X;ea=X-f|0;X=(ca(pb,h)|0)+g<<ea;U=1<<ea;ea=cb&255;cb=sb&255;sb=rb&255;rb=c[q>>2]&65535;q=c[r>>2]&65535;r=f&255;if((U|0)>0){O=0;do{M=(ca(O,pb)|0)+X|0;Ha=0;do{t=M+Ha|0;e=c[ya>>2]|0;b[e+(t*10|0)>>1]=rb;b[e+(t*10|0)+2>>1]=q;a[e+(t*10|0)+4|0]=0;a[e+(t*10|0)+5|0]=ea;a[e+(t*10|0)+6|0]=cb;a[e+(t*10|0)+7|0]=sb;a[e+(t*10|0)+8|0]=1;a[e+(t*10|0)+9|0]=r;Ha=Ha+1|0;}while((Ha|0)<(U|0));O=O+1|0;}while((O|0)<(U|0))}nrc(Ta|0,nb|0,4224)|0;va=n;i=j;return va|0}else{nrc(y|0,ab|0,bb)|0;nrc($a|0,Ra|0,540)|0;c[z>>2]=A;c[x>>2]=y+bb;bb=c[C>>2]|0;C=c[B>>2]<<bb;B=bb-f|0;bb=(ca(C,h)|0)+g<<B;g=1<<B;B=Wa&65535;Wa=Va&65535;Va=Xa&255;Xa=f&255;if((g|0)>0){f=0;do{h=(ca(f,C)|0)+bb|0;y=0;do{x=h+y|0;A=c[ya>>2]|0;b[A+(x*10|0)>>1]=B;b[A+(x*10|0)+2>>1]=Wa;a[A+(x*10|0)+4|0]=Va;a[A+(x*10|0)+5|0]=P;a[A+(x*10|0)+6|0]=L;a[A+(x*10|0)+7|0]=W;a[A+(x*10|0)+8|0]=0;a[A+(x*10|0)+9|0]=Xa;y=y+1|0;}while((y|0)<(g|0));f=f+1|0;}while((f|0)<(g|0))}nrc(Ta|0,Za|0,4224)|0;va=sa;i=j;return va|0}return 0}function L1a(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c|0)==0){H1a(a,b,1);return}f=(c|0)>-1?c:-c|0;g=f>>>0>65535>>>0;h=g?f>>>16:f;i=g?16:0;if((h&65280|0)==0){j=i;k=h}else{j=i|8;k=h>>>8}h=(d[1359664+k|0]|0)+j|0;j=(h|0)>10?10:h;H1a(a,b,0);if((j|0)>0){k=(h|0)<10;i=0;do{i=i+1|0;H1a(a,b+i|0,1);}while((i|0)<(j|0));l=k?h:10}else{l=0}if((l|0)<(h|0)){k=b+10|0;i=l;while(1){H1a(a,k,1);g=i+1|0;if((g|0)<(h|0)){i=g}else{m=h;break}}}else{m=l}H1a(a,b+((m|0)>9?10:m+1|0)|0,0);m=h-1|0;if((m|0)<(j|0)){n=m}else{h=b+31|0;l=m;while(1){H1a(a,h,f>>>(l>>>0)&1);m=l-1|0;if((m|0)<(j|0)){n=m;break}else{l=m}}}if((n|0)>-1){l=n;while(1){H1a(a,b+(l+22)|0,f>>>(l>>>0)&1);if((l|0)>0){l=l-1|0}else{break}}}if((e|0)==0){return}H1a(a,b+(j+11)|0,c>>>31);return}function M1a(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=b[h>>1]|0;l=k<<16>>16;if((a|0)==1){a=b[i>>1]|0;m=a<<16>>16;n=b[j>>1]|0;o=n<<16>>16;do{if(k<<16>>16>a<<16>>16){if(!(n<<16>>16>a<<16>>16)){p=m;break}p=(o|0)>(l|0)?l:o}else{if(!(a<<16>>16>n<<16>>16)){p=m;break}p=(o|0)>(l|0)?o:l}}while(0);c[e>>2]=p;p=b[h+2>>1]|0;o=p<<16>>16;m=b[i+2>>1]|0;n=m<<16>>16;a=b[j+2>>1]|0;k=a<<16>>16;if(p<<16>>16>m<<16>>16){if(!(a<<16>>16>m<<16>>16)){q=n;c[f>>2]=q;return}q=(k|0)>(o|0)?o:k;c[f>>2]=q;return}else{if(!(m<<16>>16>a<<16>>16)){q=n;c[f>>2]=q;return}q=(k|0)>(o|0)?k:o;c[f>>2]=q;return}}else{o=h+4|0;k=(ca(c[6548856+(g<<5)+(d[o]<<2)>>2]|0,l)|0)+128>>8;l=i+4|0;n=(ca(c[6548856+(g<<5)+(d[l]<<2)>>2]|0,b[i>>1]|0)|0)+128>>8;a=j+4|0;m=(ca(c[6548856+(g<<5)+(d[a]<<2)>>2]|0,b[j>>1]|0)|0)+128>>8;do{if((k|0)>(n|0)){if((m|0)<=(n|0)){r=n;break}r=(m|0)>(k|0)?k:m}else{if((n|0)<=(m|0)){r=n;break}r=(m|0)>(k|0)?m:k}}while(0);c[e>>2]=r;r=(ca(c[6548856+(g<<5)+(d[o]<<2)>>2]|0,b[h+2>>1]|0)|0)+128>>8;h=(ca(c[6548856+(g<<5)+(d[l]<<2)>>2]|0,b[i+2>>1]|0)|0)+128>>8;i=(ca(c[6548856+(g<<5)+(d[a]<<2)>>2]|0,b[j+2>>1]|0)|0)+128>>8;if((r|0)>(h|0)){if((i|0)<=(h|0)){q=h;c[f>>2]=q;return}q=(i|0)>(r|0)?r:i;c[f>>2]=q;return}else{if((h|0)<=(i|0)){q=h;c[f>>2]=q;return}q=(i|0)>(r|0)?i:r;c[f>>2]=q;return}}}function N1a(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;h=e+7536|0;i=c[h>>2]|0;j=16>>>(i>>>0);k=c[1335352+(i<<2)>>2]|0;l=j<<1;m=c[e+2540>>2]|0;n=c[m+32>>2]|0;o=c[m>>2]|0;m=c[c[e+2536>>2]>>2]|0;p=e+7528|0;q=c[p>>2]|0;r=q<<i;s=c[e+7548>>2]|0;t=c[e+7552>>2]|0;u=c[e+7500>>2]|0;switch(c[(c[e+4>>2]|0)+232>>2]&255|0){case 3:{v=(u*3|0)>>8;break};case 6:case 4:case 1:case 10:{v=c[e+7504>>2]>>7;break};case 2:case 14:{v=u>>6;break};case 5:{v=1;break};case 11:{v=u>>5;break};case 12:{v=u>>6;break};default:{v=u>>7}}u=(j|0)/2|0;w=e+7532|0;x=e+2139660|0;y=(n|0)>111?16:n<<4;z=e+2158472|0;A=-l|0;B=y*3|0;C=B+y|0;D=C+y|0;E=e+960+(((j|0)==8)<<2)|0;F=e+2143800|0;G=0;H=0;I=q;q=i;while(1){i=((H|0)%3|0)+f|0;J=i-1|0;K=((H|0)/3|0)+g|0;L=K-1|0;M=(ca(J,j)|0)+u|0;N=(ca(L,j)|0)+u|0;O=I<<q;P=ca(O,L)|0;Q=P+J|0;R=c[x>>2]|0;S=R+(Q*10|0)|0;T=R+((P+i|0)*10|0)|0;P=Q+O|0;Q=R+(P*10|0)|0;U=R+((P+1|0)*10|0)|0;P=c[z>>2]|0;if((J|0)<0){V=U;W=U;X=T;Y=T}else{J=(i|0)<(O|0);V=J?U:Q;W=Q;X=J?T:S;Y=S}if((L|0)<0){Z=V;_=W;$=V;aa=W}else{L=(K|0)<(c[w>>2]<<q|0);Z=L?V:X;_=L?W:Y;$=X;aa=Y}L=(M|0)<0;if(L){ba=k+(-M|0)|0;da=0;ea=M+j|0}else{ba=k;da=M;ea=j}K=(da+ea|0)>(s|0)?s-da|0:ea;S=(N|0)<0;if(S){fa=ba+(ca(N,A)|0)|0;ga=0;ha=N+j|0}else{fa=ba;ga=N;ha=j}T=(ga+ha|0)>(t|0)?t-ga|0:ha;do{if(!((K|0)<1|(T|0)<1)){J=(ca(ga,n)|0)+da|0;Q=P+B|0;U=P+C|0;wtb(e,Q,P,n,da,ga,K,T,aa,0,s,t);O=aa+8|0;i=a[O]|0;R=$+8|0;ia=a[R]|0;do{if((i&1)==0){ja=21}else{if((ia&1)==0){ja=21;break}ka=(d[aa+6|0]|0)-(d[$+6|0]|0)|(d[aa+5|0]|0)-(d[$+5|0]|0)|(d[aa+7|0]|0)-(d[$+7|0]|0)}}while(0);if((ja|0)==21){ja=0;ka=(b[aa>>1]|0)-(b[$>>1]|0)|(ia^i)&1|(b[aa+2>>1]|0)-(b[$+2>>1]|0)|(d[aa+4|0]|0)-(d[$+4|0]|0)}if((ka|0)==0){la=U;ma=Q;na=i}else{wtb(e,U,P,n,da,ga,K,T,$,0,s,t);la=P+D|0;ma=U;na=a[O]|0}oa=_+8|0;pa=a[oa]|0;do{if((na&1)==0){ja=27}else{if((pa&1)==0){ja=27;break}qa=(d[aa+6|0]|0)-(d[_+6|0]|0)|(d[aa+5|0]|0)-(d[_+5|0]|0)|(d[aa+7|0]|0)-(d[_+7|0]|0)}}while(0);if((ja|0)==27){ja=0;qa=(b[aa>>1]|0)-(b[_>>1]|0)|(pa^na)&1|(b[aa+2>>1]|0)-(b[_+2>>1]|0)|(d[aa+4|0]|0)-(d[_+4|0]|0)}do{if((qa|0)==0){ra=la;sa=Q;ta=na}else{U=a[R]|0;do{if((U&1)==0){ja=32}else{if((pa&1)==0){ja=32;break}ua=(d[$+6|0]|0)-(d[_+6|0]|0)|(d[$+5|0]|0)-(d[_+5|0]|0)|(d[$+7|0]|0)-(d[_+7|0]|0)}}while(0);if((ja|0)==32){ja=0;ua=(b[$>>1]|0)-(b[_>>1]|0)|(U^pa)&1|(b[$+2>>1]|0)-(b[_+2>>1]|0)|(d[$+4|0]|0)-(d[_+4|0]|0)}if((ua|0)==0){ra=la;sa=ma;ta=na;break}wtb(e,la,P,n,da,ga,K,T,_,0,s,t);ra=la+y|0;sa=la;ta=a[O]|0}}while(0);O=a[Z+8|0]|0;do{if((ta&1)==0){ja=38}else{if((O&1)==0){ja=38;break}va=(d[aa+6|0]|0)-(d[Z+6|0]|0)|(d[aa+5|0]|0)-(d[Z+5|0]|0)|(d[aa+7|0]|0)-(d[Z+7|0]|0)}}while(0);if((ja|0)==38){ja=0;va=(b[aa>>1]|0)-(b[Z>>1]|0)|(O^ta)&1|(b[aa+2>>1]|0)-(b[Z+2>>1]|0)|(d[aa+4|0]|0)-(d[Z+4|0]|0)}do{if((va|0)==0){wa=Q}else{pa=a[R]|0;do{if((pa&1)==0){ja=43}else{if((O&1)==0){ja=43;break}xa=(d[$+6|0]|0)-(d[Z+6|0]|0)|(d[$+5|0]|0)-(d[Z+5|0]|0)|(d[$+7|0]|0)-(d[Z+7|0]|0)}}while(0);if((ja|0)==43){ja=0;xa=(b[$>>1]|0)-(b[Z>>1]|0)|(pa^O)&1|(b[$+2>>1]|0)-(b[Z+2>>1]|0)|(d[$+4|0]|0)-(d[Z+4|0]|0)}if((xa|0)==0){wa=ma;break}U=a[oa]|0;do{if((U&1)==0){ja=48}else{if((O&1)==0){ja=48;break}ya=(d[_+6|0]|0)-(d[Z+6|0]|0)|(d[_+5|0]|0)-(d[Z+5|0]|0)|(d[_+7|0]|0)-(d[Z+7|0]|0)}}while(0);if((ja|0)==48){ja=0;ya=(b[_>>1]|0)-(b[Z>>1]|0)|(U^O)&1|(b[_+2>>1]|0)-(b[Z+2>>1]|0)|(d[_+4|0]|0)-(d[Z+4|0]|0)}if((ya|0)==0){wa=sa;break}wtb(e,ra,P,n,da,ga,K,T,Z,0,s,t);wa=ra}}while(0);if((T|0)<=0){break}O=(K|0)>0;oa=0;do{R=ca(oa,l)|0;Q=R+j|0;pa=ca(oa+j|0,l)|0;i=pa+j|0;if(O){ia=ca(oa,n)|0;za=0;do{Aa=za+ia|0;Ba=ca(d[wa+Aa|0]|0,d[fa+(za+R)|0]|0)|0;Ca=(ca(d[sa+Aa|0]|0,d[fa+(Q+za)|0]|0)|0)+Ba|0;Ba=Ca+(ca(d[ma+Aa|0]|0,d[fa+(za+pa)|0]|0)|0)|0;Ca=(Ba+(ca(d[P+(Aa+B)|0]|0,d[fa+(i+za)|0]|0)|0)|0)>>>4;Ba=(b[6033320+(za+da<<1)>>1]|0)+8+Ca|0;Ca=Ba>>4;if(Ca>>>0>255>>>0){Da=(Ba>>31^255)&255}else{Da=Ca&255}a[o+(J+Aa)|0]=Da;za=za+1|0;}while((za|0)<(K|0))}oa=oa+1|0;}while((oa|0)<(T|0))}}while(0);if(S){T=N;do{K=(ca(T,n)|0)+M|0;nrc(o+K|0,m+K|0,j)|0;T=T+1|0;}while((T|0)<0)}T=N+j|0;if((t|0)<(T|0)){S=t;do{K=(ca(S,n)|0)+M|0;nrc(o+K|0,m+K|0,j)|0;S=S+1|0;}while((S|0)<(T|0))}if(L&(j|0)>0){S=-M|0;K=N;do{P=(ca(K,n)|0)+M|0;nrc(o+P|0,m+P|0,S)|0;K=K+1|0;}while((K|0)<(T|0))}K=M+j|0;if((K|0)>(s|0)&(j|0)>0){S=K-s|0;K=N;do{L=(ca(K,n)|0)+s|0;nrc(o+L|0,m+L|0,S)|0;K=K+1|0;}while((K|0)<(T|0))}T=(ca(N,n)|0)+M|0;Ea=(Xe[c[E>>2]&511](F,m+T|0,o+T|0,n,j)|0)+G|0;T=H+1|0;if((T|0)>=9){break}G=Ea;H=T;I=c[p>>2]|0;q=c[h>>2]|0}h=(ca(r,g)|0)+f|0;q=c[x>>2]|0;x=q+(h*10|0)|0;p=h+1|0;I=a[q+(h*10|0)+8|0]|0;H=(I&1)==0;G=a[q+(p*10|0)+8|0]|0;do{if(H){ja=74}else{if((G&1)==0){ja=74;break}Fa=(d[q+(h*10|0)+6|0]|0)-(d[q+(p*10|0)+6|0]|0)|(d[q+(h*10|0)+5|0]|0)-(d[q+(p*10|0)+5|0]|0)|(d[q+(h*10|0)+7|0]|0)-(d[q+(p*10|0)+7|0]|0)}}while(0);if((ja|0)==74){Fa=(b[x>>1]|0)-(b[q+(p*10|0)>>1]|0)|(G^I)&1|(b[q+(h*10|0)+2>>1]|0)-(b[q+(p*10|0)+2>>1]|0)|(d[q+(h*10|0)+4|0]|0)-(d[q+(p*10|0)+4|0]|0)}do{if((Fa|0)==0){p=h+r|0;G=a[q+(p*10|0)+8|0]|0;do{if(H){ja=79}else{if((G&1)==0){ja=79;break}Ga=(d[q+(h*10|0)+6|0]|0)-(d[q+(p*10|0)+6|0]|0)|(d[q+(h*10|0)+5|0]|0)-(d[q+(p*10|0)+5|0]|0)|(d[q+(h*10|0)+7|0]|0)-(d[q+(p*10|0)+7|0]|0)}}while(0);if((ja|0)==79){Ga=(b[x>>1]|0)-(b[q+(p*10|0)>>1]|0)|(G^I)&1|(b[q+(h*10|0)+2>>1]|0)-(b[q+(p*10|0)+2>>1]|0)|(d[q+(h*10|0)+4|0]|0)-(d[q+(p*10|0)+4|0]|0)}if((Ga|0)!=0){Ha=0;Ia=0;break}M=p+1|0;N=a[q+(M*10|0)+8|0]|0;do{if(H){ja=84}else{if((N&1)==0){ja=84;break}Ja=(d[q+(h*10|0)+6|0]|0)-(d[q+(M*10|0)+6|0]|0)|(d[q+(h*10|0)+5|0]|0)-(d[q+(M*10|0)+5|0]|0)|(d[q+(h*10|0)+7|0]|0)-(d[q+(M*10|0)+7|0]|0)}}while(0);if((ja|0)==84){Ja=(b[x>>1]|0)-(b[q+(M*10|0)>>1]|0)|(N^I)&1|(b[q+(h*10|0)+2>>1]|0)-(b[q+(M*10|0)+2>>1]|0)|(d[q+(h*10|0)+4|0]|0)-(d[q+(M*10|0)+4|0]|0)}if((Ja|0)!=0){Ha=0;Ia=0;break}Ha=O1a(e,f,g,2)|0;Ia=4}else{Ha=0;Ia=0}}while(0);do{Ha=(O1a(e,(c[1149104+(Ia<<3)>>2]|0)+f|0,(c[1149108+(Ia<<3)>>2]|0)+g|0,1)|0)+Ha|0;Ia=Ia+1|0;}while((Ia|0)<9);return(ca(Ha,v)|0)+Ea|0}function O1a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=c[e+7536>>2]|0;n=c[e+7528>>2]<<m;o=c[e+7532>>2]<<m;m=(ca(n,g)|0)+f|0;p=c[e+2139660>>2]|0;q=(f|0)!=0;if(q){r=p+((m-1|0)*10|0)|0}else{r=778072}do{if((g|0)==0){s=r;t=778072}else{u=m-n|0;v=p+(u*10|0)|0;if(q){w=p+((u-1|0)*10|0)|0}else{w=r}if((h+f|0)>=(n|0)){s=w;t=v;break}s=p+((h-n+m|0)*10|0)|0;t=v}}while(0);if(!((f|0)>-1&(n|0)>(f|0)&(o|0)>(g|0))){x=0;i=j;return x|0}if((a[p+(m*10|0)+8|0]&1)==0){g=p+(m*10|0)+4|0;M1a(c[e+7388>>2]|0,k,l,d[g]|0,r,t,s);s=(c[k>>2]|0)-(b[p+(m*10|0)>>1]|0)|0;c[k>>2]=s;k=(c[l>>2]|0)-(b[p+(m*10|0)+2>>1]|0)|0;c[l>>2]=k;l=(s|0)>-1?s:-s|0;s=l<<1;t=s>>>0>65535>>>0;e=t?l>>>15&65535:s;s=t?16:0;if((e&65280|0)==0){y=s;z=e}else{y=s|8;z=e>>>8}e=(k|0)>-1?k:-k|0;k=e<<1;s=k>>>0>65535>>>0;t=s?e>>>15&65535:k;k=s?16:0;if((t&65280|0)==0){A=k;B=t}else{A=k|8;B=t>>>8}t=d[g]|0;g=t<<1;k=g&256;x=y+1+(d[1359664+z|0]|0)+A+(d[1359664+B|0]|0)+(d[1359664+((k|0)==0?g:t>>>7)|0]|0)+(k>>>5)<<1;i=j;return x|0}k=(d[r+5|0]|0)-(d[p+(m*10|0)+5|0]|0)|0;t=(k|0)>-1?k:-k|0;k=t<<1;g=k>>>0>65535>>>0;B=g?t>>>15&65535:k;k=g?16:0;if((B&65280|0)==0){C=k;D=B}else{C=k|8;D=B>>>8}B=(d[r+6|0]|0)-(d[p+(m*10|0)+6|0]|0)|0;k=(B|0)>-1?B:-B|0;B=k<<1;g=B>>>0>65535>>>0;t=g?k>>>15&65535:B;B=g?16:0;if((t&65280|0)==0){E=B;F=t}else{E=B|8;F=t>>>8}t=(d[r+7|0]|0)-(d[p+(m*10|0)+7|0]|0)|0;m=(t|0)>-1?t:-t|0;t=m<<1;p=t>>>0>65535>>>0;r=p?m>>>15&65535:t;t=p?16:0;if((r&65280|0)==0){G=t;H=r}else{G=t|8;H=r>>>8}x=((d[1359664+D|0]|0)+C+E+(d[1359664+F|0]|0)+G+(d[1359664+H|0]|0)<<1)+3|0;i=j;return x|0}function P1a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;e=c[a+60>>2]|0;f=e+32|0;c[f>>2]=c[a+416>>2];g=e+36|0;c[g>>2]=c[a+412>>2];h=c[a+96>>2]|0;if((h|0)==0){KIb(a,16,2142816,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}l=c[a+100>>2]|0;m=l>>>0>268435455>>>0?-8:l<<3;l=m>>>0>2147483639>>>0;n=l?0:h;h=l?8:m+8|0;m=n;l=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>6&3;m=h>>>0>2>>>0?2:h;o=e;c[o>>2]=l;do{if(l>>>0>1>>>0){p=n+(m>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&2)>>>24;p=m+8|0;r=h>>>0>p>>>0?p:h;c[o>>2]=q;p=n+(r>>>3)|0;s=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>24;p=r+8|0;r=h>>>0>p>>>0?p:h;p=e+4|0;c[p>>2]=s;if((q|0)!=2){break}q=n+(r>>>3)|0;s=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>30;q=r+2|0;r=h>>>0>q>>>0?q:h;c[f>>2]=s;q=n+(r>>>3)|0;t=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>28;q=r+4|0;r=h>>>0>q>>>0?q:h;q=c[612032+(t<<2)>>2]|0;c[g>>2]=q;t=a;KIb(t,32,2637528,(j=i,i=i+16|0,c[j>>2]=s,c[j+8>>2]=q,j)|0);i=j;q=c[f>>2]|0;if((q|0)>2){KIb(t,16,2243016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}s=((r|0)<(h|0))+r|0;u=(d[n+(r>>>3)|0]|0)<<(r&7)>>>7&1;r=e+8|0;c[r>>2]=u;if((u|0)==0){v=s+3|0;w=h>>>0>v>>>0?v:h}else{w=s}s=n+(w>>>3)|0;v=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7)>>>30;s=w+2|0;x=h>>>0>s>>>0?s:h;s=e+12|0;c[s>>2]=v;do{if((v|0)==3){y=q}else{if((q|0)==2){y=2;break}KIb(t,16,2614248,(j=i,i=i+8|0,c[j>>2]=v,j)|0);i=j;k=-1094995529;i=b;return k|0}}while(0);q=n+(x>>>3)|0;z=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(x&7)>>>30;q=x+2|0;A=h>>>0>q>>>0?q:h;q=e+20|0;c[q>>2]=z;if((z|0)==0){KIb(t,16,2587264,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}B=n+(A>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(A&7)>>>27;B=A+5|0;A=h>>>0>B>>>0?B:h;B=(C<<5)+32|0;C=e+16|0;c[C>>2]=B;if(((d[n+(A>>>3)|0]|0)&128>>>((A&7)>>>0)|0)==0){D=z;E=y;F=u;H=v;I=B}else{KIb(t,32,2566216,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;D=c[q>>2]|0;E=c[f>>2]|0;F=c[r>>2]|0;H=c[s>>2]|0;I=c[C>>2]|0}q=c[g>>2]|0;B=q;z=D*44100|0;A=Crc(B<<11|0>>>21,((q|0)<0|0?-1:0)<<11|B>>>21,z,(z|0)<0|0?-1:0)|0;z=A;A=e+40|0;c[A>>2]=z;B=ca(ca(E,z)|0,D)|0;q=e+44|0;c[q>>2]=B;J=c[p>>2]|0;KIb(t,32,2169824,(j=i,i=i+64|0,c[j>>2]=c[o>>2],c[j+8>>2]=J,c[j+16>>2]=F,c[j+24>>2]=H,c[j+32>>2]=I,c[j+40>>2]=z,c[j+48>>2]=B,c[j+56>>2]=D,j)|0);i=j;B=qJb(c[C>>2]|0,4)|0;c[e+48>>2]=B;z=c[C>>2]|0;if((z|0)>0){J=0;while(1){K=J+1|0;if(K>>>0<255>>>0){L=(d[J+1303322|0]|0)-1>>4}else{do{if(K>>>0<4096>>>0){M=(d[1303320+(K>>>4)|0]|0)>>>2}else{if(K>>>0<16384>>>0){M=(d[1303320+(K>>>6)|0]|0)>>>1;break}if(K>>>0<65536>>>0){M=d[1303320+(K>>>8)|0]|0;break}else{N=K>>>16;O=(N&65280|0)==0;P=((d[1359664+(O?N:K>>>24)|0]|0)+(O?0:8)|0)>>>1;O=K>>>((P+2|0)>>>0);N=d[1303320+(O>>>((P+8|0)>>>0))|0]|0;Erc(O,0,c[1367848+(N<<2)>>2]|0,0)|0;M=G+(N<<P)|0;break}}}while(0);L=M-((ca(M,M)|0)>>>0>K>>>0)|0}c[B+(J<<2)>>2]=L;P=c[C>>2]|0;if((K|0)<(P|0)){J=K}else{Q=P;break}}}else{Q=z}c[e+80>>2]=qJb(Q,4)|0;J=e+84|0;B=0;while(1){R=c[f>>2]|0;if((B|0)>=(R|0)){break}t=qJb(c[C>>2]|0,4)|0;c[J+(B<<2)>>2]=t;if((t|0)==0){k=-12;S=37;break}else{B=B+1|0}}if((S|0)==37){i=b;return k|0}B=e+56|0;J=0;C=R;while(1){if((J|0)>=(C|0)){break}z=qJb(c[A>>2]|0,4)|0;c[B+(J<<2)>>2]=z;if((z|0)==0){k=-12;S=37;break}J=J+1|0;C=c[f>>2]|0}if((S|0)==37){i=b;return k|0}c[e+52>>2]=qJb(c[q>>2]|0,4)|0;c[a+420>>2]=1;k=0;i=b;return k|0}}while(0);KIb(a,16,2119248,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}function Q1a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;j=i;i=i+576|0;k=j|0;l=j+544|0;m=c[h+24>>2]|0;n=c[h+28>>2]|0;h=c[e+60>>2]|0;if((n|0)==0){o=0;i=j;return o|0}p=h+44|0;c[f+76>>2]=(c[p>>2]|0)/(c[e+416>>2]|0)|0;q=M4a(e,f,0)|0;if((q|0)<0){o=q;i=j;return o|0}q=c[f>>2]|0;f=l|0;mrc(f|0,-128|0,32)|0;TYa(k,m,n);UYa(k,214748364,248);m=h+80|0;e=c[m>>2]|0;r=h+16|0;s=c[r>>2]|0;do{if((s|0)>0){t=k+4|0;u=k|0;v=k+532|0;w=k+536|0;x=l+1|0;y=0;z=128;while(1){A=c[t>>2]|0;B=(ca(z,A)|0)>>8;C=A-B|0;c[t>>2]=C;A=c[u>>2]|0;do{if((A|0)<(C|0)){a[f]=a[k+16+z|0]|0;if((C|0)<256){D=C<<8;c[t>>2]=D;E=A<<8;c[u>>2]=E;F=c[v>>2]|0;if(F>>>0<(c[w>>2]|0)>>>0){G=d[F]|0|E;c[u>>2]=G;H=G}else{H=E}c[v>>2]=F+1;I=D;J=H}else{I=C;J=A}D=a[x]|0;F=(ca(D&255,I)|0)>>8;E=I-F|0;c[t>>2]=E;if((J|0)<(E|0)){K=0;L=x;M=D;N=J}else{G=1;O=x;P=F;F=E;E=J;Q=D;while(1){D=E-F|0;c[u>>2]=D;a[O]=a[(Q&255)+(k+272)|0]|0;c[t>>2]=P;if((P|0)<256){R=P<<8;c[t>>2]=R;S=D<<8;c[u>>2]=S;T=c[v>>2]|0;if(T>>>0<(c[w>>2]|0)>>>0){U=d[T]|0|S;c[u>>2]=U;V=U}else{V=S}c[v>>2]=T+1;W=R;X=V}else{W=P;X=D}D=G+1|0;R=l+((G|0)>9?10:D)|0;T=a[R]|0;S=(ca(T&255,W)|0)>>8;U=W-S|0;c[t>>2]=U;if((X|0)<(U|0)){K=G;L=R;M=T;N=X;break}else{G=D;O=R;P=S;F=U;E=X;Q=T}}}a[L]=a[(M&255)+(k+16)|0]|0;Q=c[t>>2]|0;if((Q|0)<256){E=Q<<8;c[t>>2]=E;F=N<<8;c[u>>2]=F;P=c[v>>2]|0;if(P>>>0<(c[w>>2]|0)>>>0){O=d[P]|0|F;c[u>>2]=O;Y=O}else{Y=F}c[v>>2]=P+1;Z=E;_=Y}else{Z=Q;_=N}if((K|0)>0){Q=1;E=K;P=Z;F=_;while(1){O=E-1|0;G=l+((O|0)>9?31:E+21|0)|0;T=d[G]|0;U=(ca(T,P)|0)>>8;S=P-U|0;c[t>>2]=S;do{if((F|0)<(S|0)){a[G]=a[k+16+T|0]|0;if((S|0)>=256){$=0;aa=S;ba=F;break}R=S<<8;c[t>>2]=R;D=F<<8;c[u>>2]=D;da=c[v>>2]|0;if(da>>>0<(c[w>>2]|0)>>>0){ea=d[da]|0|D;c[u>>2]=ea;fa=ea}else{fa=D}c[v>>2]=da+1;$=0;aa=R;ba=fa}else{R=F-S|0;c[u>>2]=R;a[G]=a[k+272+T|0]|0;c[t>>2]=U;if((U|0)>=256){$=1;aa=U;ba=R;break}da=U<<8;c[t>>2]=da;D=R<<8;c[u>>2]=D;R=c[v>>2]|0;if(R>>>0<(c[w>>2]|0)>>>0){ea=d[R]|0|D;c[u>>2]=ea;ga=ea}else{ga=D}c[v>>2]=R+1;$=1;aa=da;ba=ga}}while(0);U=$|Q<<1;if((O|0)>0){Q=U;E=O;P=aa;F=ba}else{ha=U;ia=aa;ja=ba;break}}}else{ha=1;ia=Z;ja=_}F=l+((K|0)>10?21:K+11|0)|0;P=d[F]|0;E=(ca(P,ia)|0)>>8;Q=ia-E|0;c[t>>2]=Q;do{if((ja|0)<(Q|0)){a[F]=a[k+16+P|0]|0;if((Q|0)>=256){ka=0;break}c[t>>2]=Q<<8;U=ja<<8;c[u>>2]=U;T=c[v>>2]|0;if(T>>>0<(c[w>>2]|0)>>>0){c[u>>2]=d[T]|0|U}c[v>>2]=T+1;ka=0}else{T=ja-Q|0;c[u>>2]=T;a[F]=a[k+272+P|0]|0;c[t>>2]=E;if((E|0)>=256){ka=1;break}c[t>>2]=E<<8;U=T<<8;c[u>>2]=U;T=c[v>>2]|0;if(T>>>0<(c[w>>2]|0)>>>0){c[u>>2]=d[T]|0|U}c[v>>2]=T+1;ka=1}}while(0);la=(ha^-ka)+ka|0}else{E=A-C|0;c[u>>2]=E;a[f]=a[k+272+z|0]|0;c[t>>2]=B;if((B|0)>=256){la=0;break}c[t>>2]=B<<8;P=E<<8;c[u>>2]=P;E=c[v>>2]|0;if(E>>>0<(c[w>>2]|0)>>>0){c[u>>2]=d[E]|0|P}c[v>>2]=E+1;la=0}}while(0);c[e+(y<<2)>>2]=la;B=y+1|0;if((B|0)>=(s|0)){break}y=B;z=d[f]|0}if((c[r>>2]|0)<=0){break}z=c[h+48>>2]|0;y=c[m>>2]|0;v=0;do{u=y+(v<<2)|0;c[u>>2]=ca(c[u>>2]|0,c[z+(v<<2)>>2]|0)|0;v=v+1|0;}while((v|0)<(c[r>>2]|0))}}while(0);s=h+8|0;do{if((c[s>>2]|0)==0){la=k+4|0;e=c[la>>2]|0;ka=d[f]|0;ha=(ca(ka,e)|0)>>8;ja=e-ha|0;c[la>>2]=ja;e=k|0;ia=c[e>>2]|0;if((ia|0)>=(ja|0)){K=ia-ja|0;c[e>>2]=K;a[f]=a[k+272+ka|0]|0;c[la>>2]=ha;if((ha|0)>=256){ma=0;break}c[la>>2]=ha<<8;ha=K<<8;c[e>>2]=ha;K=k+532|0;_=c[K>>2]|0;if(_>>>0<(c[k+536>>2]|0)>>>0){c[e>>2]=d[_]|0|ha}c[K>>2]=_+1;ma=0;break}a[f]=a[k+16+ka|0]|0;if((ja|0)<256){ka=ja<<8;c[la>>2]=ka;_=ia<<8;c[e>>2]=_;K=k+532|0;ha=c[K>>2]|0;if(ha>>>0<(c[k+536>>2]|0)>>>0){Z=d[ha]|0|_;c[e>>2]=Z;na=Z}else{na=_}c[K>>2]=ha+1;oa=ka;pa=na}else{oa=ja;pa=ia}ia=l+1|0;ja=a[ia]|0;ka=(ca(ja&255,oa)|0)>>8;ha=oa-ka|0;c[la>>2]=ha;if((pa|0)<(ha|0)){qa=0;ra=ia;sa=ja;ta=pa}else{K=k+532|0;_=k+536|0;Z=1;ba=ia;ia=ka;ka=ha;ha=pa;aa=ja;while(1){ja=ha-ka|0;c[e>>2]=ja;a[ba]=a[(aa&255)+(k+272)|0]|0;c[la>>2]=ia;if((ia|0)<256){$=ia<<8;c[la>>2]=$;ga=ja<<8;c[e>>2]=ga;fa=c[K>>2]|0;if(fa>>>0<(c[_>>2]|0)>>>0){N=d[fa]|0|ga;c[e>>2]=N;ua=N}else{ua=ga}c[K>>2]=fa+1;va=$;wa=ua}else{va=ia;wa=ja}ja=Z+1|0;$=l+((Z|0)>9?10:ja)|0;fa=a[$]|0;ga=(ca(fa&255,va)|0)>>8;N=va-ga|0;c[la>>2]=N;if((wa|0)<(N|0)){qa=Z;ra=$;sa=fa;ta=wa;break}else{Z=ja;ba=$;ia=ga;ka=N;ha=wa;aa=fa}}}a[ra]=a[(sa&255)+(k+16)|0]|0;aa=c[la>>2]|0;if((aa|0)<256){ha=aa<<8;c[la>>2]=ha;ka=ta<<8;c[e>>2]=ka;ia=k+532|0;ba=c[ia>>2]|0;if(ba>>>0<(c[k+536>>2]|0)>>>0){Z=d[ba]|0|ka;c[e>>2]=Z;xa=Z}else{xa=ka}c[ia>>2]=ba+1;ya=ha;za=xa}else{ya=aa;za=ta}if((qa|0)<=0){ma=16;break}aa=k+532|0;ha=k+536|0;ba=1;ia=qa;ka=ya;Z=za;while(1){K=ia-1|0;_=l+((K|0)>9?31:ia+21|0)|0;fa=d[_]|0;N=(ca(fa,ka)|0)>>8;ga=ka-N|0;c[la>>2]=ga;do{if((Z|0)<(ga|0)){a[_]=a[k+16+fa|0]|0;if((ga|0)>=256){Aa=0;Ba=ga;Ca=Z;break}$=ga<<8;c[la>>2]=$;ja=Z<<8;c[e>>2]=ja;Y=c[aa>>2]|0;if(Y>>>0<(c[ha>>2]|0)>>>0){M=d[Y]|0|ja;c[e>>2]=M;Da=M}else{Da=ja}c[aa>>2]=Y+1;Aa=0;Ba=$;Ca=Da}else{$=Z-ga|0;c[e>>2]=$;a[_]=a[k+272+fa|0]|0;c[la>>2]=N;if((N|0)>=256){Aa=1;Ba=N;Ca=$;break}Y=N<<8;c[la>>2]=Y;ja=$<<8;c[e>>2]=ja;$=c[aa>>2]|0;if($>>>0<(c[ha>>2]|0)>>>0){M=d[$]|0|ja;c[e>>2]=M;Ea=M}else{Ea=ja}c[aa>>2]=$+1;Aa=1;Ba=Y;Ca=Ea}}while(0);Fa=Aa|ba<<1;if((K|0)>0){ba=Fa;ia=K;ka=Ba;Z=Ca}else{break}}ma=Fa<<4}else{ma=1}}while(0);Fa=h+32|0;if((c[Fa>>2]|0)>0){Ca=h+84|0;Ba=h+56|0;Aa=h+40|0;Ea=k+4|0;Da=k|0;za=k+532|0;ya=k+536|0;qa=l+1|0;ta=h+52|0;xa=h+20|0;sa=0;ra=c[r>>2]|0;while(1){wa=c[m>>2]|0;va=Ca+(sa<<2)|0;ua=c[va>>2]|0;pa=ra-2|0;if((pa|0)>-1){oa=pa;while(1){pa=oa+1|0;if((pa|0)<(ra|0)){na=0;Z=c[ua+(oa<<2)>>2]|0;ka=pa;while(1){pa=c[wa+(na<<2)>>2]|0;ia=ua+(ka<<2)|0;ba=c[ia>>2]|0;aa=ca(ba,pa)|0;e=ca(pa,Z)|0;c[ia>>2]=(e>>>31)+ba+(e>>10);e=ka+1|0;if((e|0)<(ra|0)){na=na+1|0;Z=(aa>>>31)+Z+(aa>>10)|0;ka=e}else{break}}}if((oa|0)>0){oa=oa-1|0}else{break}}}oa=Ba+(sa<<2)|0;ua=c[oa>>2]|0;wa=c[Aa>>2]|0;a:do{if((wa|0)>0){ka=0;do{Z=c[Ea>>2]|0;na=d[f]|0;K=(ca(na,Z)|0)>>8;e=Z-K|0;c[Ea>>2]=e;Z=c[Da>>2]|0;do{if((Z|0)<(e|0)){a[f]=a[k+16+na|0]|0;if((e|0)<256){aa=e<<8;c[Ea>>2]=aa;ba=Z<<8;c[Da>>2]=ba;ia=c[za>>2]|0;if(ia>>>0<(c[ya>>2]|0)>>>0){pa=d[ia]|0|ba;c[Da>>2]=pa;Ga=pa}else{Ga=ba}c[za>>2]=ia+1;Ha=aa;Ia=Ga}else{Ha=e;Ia=Z}aa=a[qa]|0;ia=(ca(aa&255,Ha)|0)>>8;ba=Ha-ia|0;c[Ea>>2]=ba;if((Ia|0)<(ba|0)){Ja=0;Ka=qa;La=aa;Ma=Ia}else{pa=1;ha=qa;la=ia;ia=ba;ba=Ia;N=aa;while(1){aa=ba-ia|0;c[Da>>2]=aa;a[ha]=a[(N&255)+(k+272)|0]|0;c[Ea>>2]=la;if((la|0)<256){fa=la<<8;c[Ea>>2]=fa;_=aa<<8;c[Da>>2]=_;ga=c[za>>2]|0;if(ga>>>0<(c[ya>>2]|0)>>>0){Y=d[ga]|0|_;c[Da>>2]=Y;Na=Y}else{Na=_}c[za>>2]=ga+1;Oa=fa;Pa=Na}else{Oa=la;Pa=aa}aa=pa+1|0;fa=l+((pa|0)>9?10:aa)|0;ga=a[fa]|0;_=(ca(ga&255,Oa)|0)>>8;Y=Oa-_|0;c[Ea>>2]=Y;if((Pa|0)<(Y|0)){Ja=pa;Ka=fa;La=ga;Ma=Pa;break}else{pa=aa;ha=fa;la=_;ia=Y;ba=Pa;N=ga}}}a[Ka]=a[(La&255)+(k+16)|0]|0;N=c[Ea>>2]|0;if((N|0)<256){ba=N<<8;c[Ea>>2]=ba;ia=Ma<<8;c[Da>>2]=ia;la=c[za>>2]|0;if(la>>>0<(c[ya>>2]|0)>>>0){ha=d[la]|0|ia;c[Da>>2]=ha;Qa=ha}else{Qa=ia}c[za>>2]=la+1;Ra=ba;Sa=Qa}else{Ra=N;Sa=Ma}if((Ja|0)>0){N=1;ba=Ja;la=Ra;ia=Sa;while(1){ha=ba-1|0;pa=l+((ha|0)>9?31:ba+21|0)|0;O=d[pa]|0;ga=(ca(O,la)|0)>>8;Y=la-ga|0;c[Ea>>2]=Y;do{if((ia|0)<(Y|0)){a[pa]=a[k+16+O|0]|0;if((Y|0)>=256){Ta=0;Ua=Y;Va=ia;break}_=Y<<8;c[Ea>>2]=_;fa=ia<<8;c[Da>>2]=fa;aa=c[za>>2]|0;if(aa>>>0<(c[ya>>2]|0)>>>0){$=d[aa]|0|fa;c[Da>>2]=$;Wa=$}else{Wa=fa}c[za>>2]=aa+1;Ta=0;Ua=_;Va=Wa}else{_=ia-Y|0;c[Da>>2]=_;a[pa]=a[k+272+O|0]|0;c[Ea>>2]=ga;if((ga|0)>=256){Ta=1;Ua=ga;Va=_;break}aa=ga<<8;c[Ea>>2]=aa;fa=_<<8;c[Da>>2]=fa;_=c[za>>2]|0;if(_>>>0<(c[ya>>2]|0)>>>0){$=d[_]|0|fa;c[Da>>2]=$;Xa=$}else{Xa=fa}c[za>>2]=_+1;Ta=1;Ua=aa;Va=Xa}}while(0);ga=Ta|N<<1;if((ha|0)>0){N=ga;ba=ha;la=Ua;ia=Va}else{Ya=ga;Za=Ua;_a=Va;break}}}else{Ya=1;Za=Ra;_a=Sa}ia=l+((Ja|0)>10?21:Ja+11|0)|0;la=d[ia]|0;ba=(ca(la,Za)|0)>>8;N=Za-ba|0;c[Ea>>2]=N;do{if((_a|0)<(N|0)){a[ia]=a[k+16+la|0]|0;if((N|0)>=256){$a=0;break}c[Ea>>2]=N<<8;ga=_a<<8;c[Da>>2]=ga;O=c[za>>2]|0;if(O>>>0<(c[ya>>2]|0)>>>0){c[Da>>2]=d[O]|0|ga}c[za>>2]=O+1;$a=0}else{O=_a-N|0;c[Da>>2]=O;a[ia]=a[k+272+la|0]|0;c[Ea>>2]=ba;if((ba|0)>=256){$a=1;break}c[Ea>>2]=ba<<8;ga=O<<8;c[Da>>2]=ga;O=c[za>>2]|0;if(O>>>0<(c[ya>>2]|0)>>>0){c[Da>>2]=d[O]|0|ga}c[za>>2]=O+1;$a=1}}while(0);ab=(Ya^-$a)+$a|0}else{ba=Z-e|0;c[Da>>2]=ba;a[f]=a[k+272+na|0]|0;c[Ea>>2]=K;if((K|0)>=256){ab=0;break}c[Ea>>2]=K<<8;la=ba<<8;c[Da>>2]=la;ba=c[za>>2]|0;if(ba>>>0<(c[ya>>2]|0)>>>0){c[Da>>2]=d[ba]|0|la}c[za>>2]=ba+1;ab=0}}while(0);c[ua+(ka<<2)>>2]=ab;ka=ka+1|0;}while((ka|0)<(wa|0));if((c[Aa>>2]|0)<=0){break}ka=c[m>>2]|0;K=c[va>>2]|0;na=0;e=sa;while(1){Z=c[r>>2]|0;if(((c[xa>>2]|0)-1|0)>0){ba=0;la=e;ia=Z;while(1){N=ia-1|0;O=ca(c[K+(N<<2)>>2]|0,c[ka+(N<<2)>>2]|0)|0;N=(O>>31)-(O>>10)|0;O=ia-2|0;if((O|0)>-1){ga=ka+(O<<2)|0;pa=K+(O<<2)|0;Y=N;aa=O;while(1){O=c[ga>>2]|0;_=c[pa>>2]|0;fa=ca(_,O)|0;$=(fa>>31)+Y-(fa>>10)|0;fa=ca($,O)|0;c[pa+4>>2]=(fa>>>31)+_+(fa>>10);if((aa|0)>0){ga=ga-4|0;pa=pa-4|0;Y=$;aa=aa-1|0}else{bb=$;break}}}else{bb=N}aa=(bb|0)>1048576?1048576:bb;Y=(aa|0)<-1048576?-1048576:aa;c[K>>2]=Y;c[(c[ta>>2]|0)+(la<<2)>>2]=Y;Y=(c[Fa>>2]|0)+la|0;aa=ba+1|0;pa=c[r>>2]|0;if((aa|0)<((c[xa>>2]|0)-1|0)){ba=aa;la=Y;ia=pa}else{cb=Y;db=pa;break}}}else{cb=e;db=Z}ia=ca(c[(c[oa>>2]|0)+(na<<2)>>2]|0,ma)|0;la=db-1|0;ba=ca(c[K+(la<<2)>>2]|0,c[ka+(la<<2)>>2]|0)|0;la=(ba>>31)+ia-(ba>>10)|0;ba=db-2|0;if((ba|0)>-1){ia=ka+(ba<<2)|0;pa=K+(ba<<2)|0;Y=la;aa=ba;while(1){ba=c[ia>>2]|0;ga=c[pa>>2]|0;$=ca(ga,ba)|0;fa=($>>31)+Y-($>>10)|0;$=ca(fa,ba)|0;c[pa+4>>2]=($>>>31)+ga+($>>10);if((aa|0)>0){ia=ia-4|0;pa=pa-4|0;Y=fa;aa=aa-1|0}else{eb=fa;break}}}else{eb=la}aa=(eb|0)>1048576?1048576:eb;Y=(aa|0)<-1048576?-1048576:aa;c[K>>2]=Y;c[(c[ta>>2]|0)+(cb<<2)>>2]=Y;Y=na+1|0;if((Y|0)>=(c[Aa>>2]|0)){break a}na=Y;e=(c[Fa>>2]|0)+cb|0}}}while(0);oa=c[r>>2]|0;if((oa|0)>0){wa=c[va>>2]|0;ua=c[ta>>2]|0;e=0;while(1){na=c[Fa>>2]|0;c[wa+(e<<2)>>2]=c[ua+((c[p>>2]|0)+sa-na-(ca(na,e)|0)<<2)>>2];na=e+1|0;K=c[r>>2]|0;if((na|0)<(K|0)){e=na}else{fb=K;break}}}else{fb=oa}e=sa+1|0;if((e|0)<(c[Fa>>2]|0)){sa=e;ra=fb}else{break}}}fb=c[h+12>>2]|0;do{if((fb|0)==0){if((c[p>>2]|0)<=0){break}ra=c[h+52>>2]|0;sa=0;do{r=ra+(sa<<2)|0;ta=c[r>>2]|0;cb=ra+(sa+1<<2)|0;Aa=(ta+1>>1)+(c[cb>>2]|0)|0;c[cb>>2]=Aa;c[r>>2]=ta-Aa;sa=(c[Fa>>2]|0)+sa|0;}while((sa|0)<(c[p>>2]|0))}else if((fb|0)==2){if((c[p>>2]|0)<=0){break}sa=c[h+52>>2]|0;ra=0;do{oa=sa+(ra<<2)|0;c[oa>>2]=(c[oa>>2]|0)+(c[sa+(ra+1<<2)>>2]|0);ra=(c[Fa>>2]|0)+ra|0;}while((ra|0)<(c[p>>2]|0))}else if((fb|0)==1){if((c[p>>2]|0)<=0){break}ra=c[h+52>>2]|0;sa=0;do{oa=ra+(sa+1<<2)|0;c[oa>>2]=(c[oa>>2]|0)+(c[ra+(sa<<2)>>2]|0);sa=(c[Fa>>2]|0)+sa|0;}while((sa|0)<(c[p>>2]|0))}}while(0);Fa=c[p>>2]|0;do{if((c[s>>2]|0)==0){if((Fa|0)<=0){break}fb=c[h+52>>2]|0;sa=0;while(1){ra=fb+(sa<<2)|0;c[ra>>2]=(c[ra>>2]|0)+8>>4;ra=sa+1|0;oa=c[p>>2]|0;if((ra|0)<(oa|0)){sa=ra}else{gb=oa;hb=162;break}}}else{gb=Fa;hb=162}}while(0);do{if((hb|0)==162){if((gb|0)<=0){break}Fa=c[h+52>>2]|0;p=0;do{s=c[Fa+(p<<2)>>2]|0;if((s+32768|0)>>>0>65535>>>0){ib=(s>>31^32767)&65535}else{ib=s&65535}b[q+(p<<1)>>1]=ib;p=p+1|0;}while((p|0)<(gb|0))}}while(0);c[g>>2]=1;o=n;i=j;return o|0}function R1a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;mJb(b+52|0);mJb(b+48|0);mJb(b+80|0);a=b+32|0;if((c[a>>2]|0)<=0){return 0}d=b+84|0;e=b+56|0;b=0;do{mJb(d+(b<<2)|0);mJb(e+(b<<2)|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function S1a(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;f=c[b+60>>2]|0;g=f;c[g>>2]=2;j=b+416|0;k=c[j>>2]|0;if((k|0)>2){KIb(b,16,2243016,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=e;return m|0}n=f+12|0;c[n>>2]=(k|0)==2?0:3;if((c[(c[b+12>>2]|0)+12>>2]|0)==1397706316){c[f+8>>2]=1;c[f+16>>2]=32;c[f+20>>2]=1;h[f+24>>3]=0.0;o=32}else{c[f+16>>2]=128;c[f+20>>2]=2;h[f+24>>3]=1.0;o=128}k=f+16|0;p=qJb(o,4)|0;c[f+48>>2]=p;o=c[k>>2]|0;if((o|0)>0){q=0;while(1){r=q+1|0;if(r>>>0<255>>>0){s=(d[q+1303322|0]|0)-1>>4}else{do{if(r>>>0<4096>>>0){t=(d[1303320+(r>>>4)|0]|0)>>>2}else{if(r>>>0<16384>>>0){t=(d[1303320+(r>>>6)|0]|0)>>>1;break}if(r>>>0<65536>>>0){t=d[1303320+(r>>>8)|0]|0;break}else{u=r>>>16;v=(u&65280|0)==0;w=((d[1359664+(v?u:r>>>24)|0]|0)+(v?0:8)|0)>>>1;v=r>>>((w+2|0)>>>0);u=d[1303320+(v>>>((w+8|0)>>>0))|0]|0;Erc(v,0,c[1367848+(u<<2)>>2]|0,0)|0;t=G+(u<<w)|0;break}}}while(0);s=t-((ca(t,t)|0)>>>0>r>>>0)|0}c[p+(q<<2)>>2]=s;w=c[k>>2]|0;if((r|0)<(w|0)){q=r}else{x=w;break}}}else{x=o}o=c[j>>2]|0;j=f+32|0;c[j>>2]=o;q=c[b+412>>2]|0;s=f+36|0;c[s>>2]=q;p=q;t=f+20|0;w=c[t>>2]|0;u=w*44100|0;v=Crc(p<<11|0>>>21,((q|0)<0|0?-1:0)<<11|p>>>21,u,(u|0)<0|0?-1:0)|0;u=v;v=f+40|0;c[v>>2]=u;p=f+44|0;c[p>>2]=ca(ca(o,u)|0,w)|0;w=ca(o,x)|0;x=f+68|0;c[x>>2]=w;o=qJb(w,4)|0;c[f+64>>2]=o;if((o|0)==0){m=-12;i=e;return m|0}o=qJb(c[k>>2]|0,4)|0;c[f+80>>2]=o;if((o|0)==0){m=-12;i=e;return m|0}o=f+56|0;w=0;while(1){if((w|0)>=(c[j>>2]|0)){break}u=qJb(c[v>>2]|0,4)|0;c[o+(w<<2)>>2]=u;if((u|0)==0){m=-12;z=62;break}else{w=w+1|0}}if((z|0)==62){i=e;return m|0}c[f+52>>2]=qJb(c[p>>2]|0,4)|0;z=(c[x>>2]<<1)+(c[p>>2]|0)|0;c[f+76>>2]=z;x=qJb(z,4)|0;c[f+72>>2]=x;if((x|0)==0){m=-12;i=e;return m|0}x=pJb(16)|0;c[b+96>>2]=x;if((x|0)==0){m=-12;i=e;return m|0}z=c[g>>2]|0;w=z;if((z|0)>0){if((z|0)>1){o=c[f+4>>2]|(z<<8|z)<<8;w=o;A=8;B=o<<2}else{A=24;B=4}o=B|c[j>>2];w=o;j=c[s>>2]|0;if((j|0)==24e3){C=6}else if((j|0)==8e3){C=8}else if((j|0)==11025){C=2}else if((j|0)==96e3){C=3}else if((j|0)==32e3){C=5}else if((j|0)==16e3){C=7}else if((j|0)==22050){C=1}else if((j|0)==44100){C=0}else if((j|0)==48e3){C=4}else{C=-22}j=o<<4|C;w=j;C=f+8|0;D=A;E=C;F=C;H=j}else{j=f+8|0;D=30;E=j;F=j;H=z}z=H<<1|c[F>>2];F=D-1|0;w=z;if((c[E>>2]|0)==0){if((F|0)>3){I=D-4|0;J=z<<3|4;K=x}else{H=x;y=je(4>>>((4-D|0)>>>0)|z<<F|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;I=D+28|0;J=4;K=x+4|0}w=J;L=I;M=K;N=J}else{L=F;M=x;N=z}z=c[n>>2]|0;if((L|0)>2){O=L-2|0;P=N<<2|z;Q=M}else{F=M;y=je(N<<L|z>>>((2-L|0)>>>0)|0)|0;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;O=L+30|0;P=z;Q=M+4|0}w=P;M=c[t>>2]|0;if((O|0)>2){R=O-2|0;S=M|P<<2;T=Q}else{z=Q;y=je(M>>>((2-O|0)>>>0)|P<<O|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;R=O+30|0;S=M;T=Q+4|0}w=S;Q=(c[k>>2]>>5)-1|0;if((R|0)>5){U=R-5|0;V=Q|S<<5;W=T}else{M=T;y=je(Q>>>((5-R|0)>>>0)|S<<R|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;U=R+27|0;V=Q;W=T+4|0}w=V;if((U|0)>1){X=U-1|0;Y=V<<1;Z=W}else{T=W;y=je(V<<U|0)|0;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;X=U+31|0;Y=0;Z=W+4|0}w=Y;if((X|0)<32){W=Y<<X;w=W;Y=((31-X|0)>>>3)+1|0;U=W>>>24&255;W=X;X=Z;while(1){a[X]=U;T=w;w=T<<8;V=W+8|0;if((V|0)<32){U=T>>>16&255;W=V;X=X+1|0}else{break}}_=Z+Y|0}else{_=Z}w=0;c[b+100>>2]=(_-x<<3|0)/8|0;x=c[f+4>>2]|0;f=c[E>>2]|0;E=c[n>>2]|0;n=c[k>>2]|0;k=c[v>>2]|0;_=c[p>>2]|0;p=c[t>>2]|0;KIb(b,32,2169824,(l=i,i=i+64|0,c[l>>2]=c[g>>2],c[l+8>>2]=x,c[l+16>>2]=f,c[l+24>>2]=E,c[l+32>>2]=n,c[l+40>>2]=k,c[l+48>>2]=_,c[l+56>>2]=p,l)|0);i=l;c[b+424>>2]=ca(c[t>>2]|0,c[v>>2]|0)|0;m=0;i=e;return m|0}function T1a(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0.0,K=0,L=0.0,M=0.0,N=0.0,O=0,P=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;j=i;i=i+576|0;k=j|0;l=j+544|0;m=c[a+60>>2]|0;n=c[f>>2]|0;f=m+44|0;o=((c[f>>2]|0)*5|0)+1e3|0;p=d5a(a,e,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=j;return q|0}p=e+28|0;SYa(k,c[e+24>>2]|0,c[p>>2]|0);UYa(k,214748364,248);e=l|0;mrc(e|0,-128|0,32)|0;o=c[f>>2]|0;if((o|0)>0){a=c[m+52>>2]|0;r=0;while(1){c[a+(r<<2)>>2]=b[n+(r<<1)>>1]|0;s=r+1|0;t=c[f>>2]|0;if((s|0)<(t|0)){r=s}else{u=t;break}}}else{u=o}o=m+8|0;if((c[o>>2]|0)==0&(u|0)>0){r=c[m+52>>2]|0;n=0;while(1){a=r+(n<<2)|0;c[a>>2]=c[a>>2]<<4;a=n+1|0;t=c[f>>2]|0;if((a|0)<(t|0)){n=a}else{v=t;break}}}else{v=u}u=c[m+12>>2]|0;do{if((u|0)==2){if((v|0)<=0){break}n=c[m+52>>2]|0;r=m+32|0;t=0;do{a=n+(t<<2)|0;c[a>>2]=(c[a>>2]|0)-(c[n+(t+1<<2)>>2]|0);t=(c[r>>2]|0)+t|0;}while((t|0)<(c[f>>2]|0))}else if((u|0)==1){if((v|0)<=0){break}t=c[m+52>>2]|0;r=m+32|0;n=0;do{a=t+(n+1<<2)|0;c[a>>2]=(c[a>>2]|0)-(c[t+(n<<2)>>2]|0);n=(c[r>>2]|0)+n|0;}while((n|0)<(c[f>>2]|0))}else if((u|0)==0){if((v|0)<=0){break}n=c[m+52>>2]|0;r=m+32|0;t=0;do{a=n+(t+1<<2)|0;s=c[a>>2]|0;w=n+(t<<2)|0;x=(c[w>>2]|0)+s|0;c[w>>2]=x;c[a>>2]=s-(x+1>>1);t=(c[r>>2]|0)+t|0;}while((t|0)<(c[f>>2]|0))}}while(0);v=m+72|0;u=m+76|0;mrc(c[v>>2]|0,0,c[u>>2]<<2|0)|0;t=m+68|0;r=c[t>>2]|0;if((r|0)>0){n=c[m+64>>2]|0;x=c[v>>2]|0;s=0;while(1){a=s+1|0;c[x+(s<<2)>>2]=c[n+(s<<2)>>2];w=c[t>>2]|0;if((a|0)<(w|0)){s=a}else{y=a;z=w;break}}}else{y=0;z=r}if((c[f>>2]|0)>0){r=c[m+52>>2]|0;s=c[v>>2]|0;n=y;x=0;while(1){A=n+1|0;c[s+(n<<2)>>2]=c[r+(x<<2)>>2];w=x+1|0;if((w|0)<(c[f>>2]|0)){n=A;x=w}else{break}}B=A;C=c[t>>2]|0}else{B=y;C=z}do{if((C|0)>0){z=c[v>>2]|0;y=B;A=0;while(1){c[z+(y<<2)>>2]=0;x=A+1|0;D=c[t>>2]|0;if((x|0)<(D|0)){y=y+1|0;A=x}else{break}}if((D|0)<=0){break}A=c[m+52>>2]|0;y=c[m+64>>2]|0;z=0;x=D;do{c[y+(z<<2)>>2]=c[A+(z-x+(c[f>>2]|0)<<2)>>2];z=z+1|0;x=c[t>>2]|0;}while((z|0)<(x|0))}}while(0);f=c[v>>2]|0;D=c[u>>2]|0;u=m+80|0;B=c[u>>2]|0;C=m+16|0;x=c[C>>2]|0;z=m+32|0;A=c[z>>2]|0;y=c[m+48>>2]|0;n=qJb(D,4)|0;r=n;nrc(n|0,f|0,D<<2)|0;if((x|0)>0){s=0;while(1){w=s+1|0;a=ca(w,A)|0;E=f+(a<<2)|0;F=D-a|0;a=(F|0)>0;do{if(a){G=0.0;H=E;I=r;J=0.0;K=F;while(1){L=+(c[I>>2]|0);M=J+L*L;N=G+ +(c[H>>2]|0)*L;O=K-1|0;if((O|0)>0){G=N;H=H+4|0;I=I+4|0;J=M;K=O}else{break}}if(M==0.0){P=36;break}K=c[y+(s<<2)>>2]|0;T=~~+Q((-0.0-N)/M*1024.0/+(K|0)+.5);U=K}else{P=36}}while(0);if((P|0)==36){P=0;T=0;U=c[y+(s<<2)>>2]|0}K=1024/(U|0)|0;I=(T|0)>(K|0)?K:T;H=(K|0)<(-I|0)?-K|0:I;c[B+(s<<2)>>2]=H;I=ca(H,c[y+(s<<2)>>2]|0)|0;if(a){H=E;K=r;O=F;while(1){V=c[H>>2]|0;W=c[K>>2]|0;X=ca(W,I)|0;c[H>>2]=(X>>>31)+V+(X>>10);X=ca(V,I)|0;c[K>>2]=(X>>>31)+W+(X>>10);X=O-1|0;if((X|0)>0){H=H+4|0;K=K+4|0;O=X}else{break}}}if((w|0)<(x|0)){s=w}else{break}}}kJb(n);V1a(k,e,c[u>>2]|0,c[C>>2]|0);C=c[z>>2]|0;if((C|0)>0){u=m+40|0;n=m+20|0;s=m+56|0;x=0;r=c[u>>2]|0;y=C;while(1){if((r|0)>0){B=s+(x<<2)|0;T=(c[t>>2]|0)+x|0;U=0;while(1){D=c[n>>2]|0;if((D|0)>0){f=c[v>>2]|0;A=c[z>>2]|0;O=ca(A,(D|0)>1?D:1)|0;K=0;H=T;I=0;while(1){Y=(c[f+(H<<2)>>2]|0)+I|0;F=K+1|0;if((F|0)<(D|0)){K=F;H=A+H|0;I=Y}else{break}}Z=T+O|0;_=Y}else{Z=T;_=0}c[(c[B>>2]|0)+(U<<2)>>2]=_;I=U+1|0;$=c[u>>2]|0;if((I|0)<($|0)){T=Z;U=I}else{break}}aa=$;ba=c[z>>2]|0}else{aa=r;ba=y}U=x+1|0;if((U|0)<(ba|0)){x=U;r=aa;y=ba}else{da=ba;break}}}else{da=C}if((c[o>>2]|0)==0){C=c[m+40>>2]|0;a:do{if((da|0)>0){ba=m+56|0;if((C|0)>0){ea=0;fa=0.0;ga=0.0}else{y=0;while(1){aa=y+1|0;if((aa|0)<(da|0)){y=aa}else{ha=0.0;ia=0.0;break a}}}while(1){y=c[ba+(ea<<2)>>2]|0;aa=0;M=fa;N=ga;do{J=+(c[y+(aa<<2)>>2]|0);N=N+J*J;M=M+ +R(+J);aa=aa+1|0;}while((aa|0)<(C|0));aa=ea+1|0;if((aa|0)<(da|0)){ea=aa;fa=M;ga=N}else{ha=M;ia=N;break}}}else{ha=0.0;ia=0.0}}while(0);ga=+(ca(C,da)|0);fa=+S(ia/ga);ia=ha*1.4142135623730951/ga;if(fa>ia){ja=fa+(fa-ia)*3.0}else{ja=fa}C=~~(ja*+h[m+24>>3]*.6*.0625);do{if((C|0)<1){ka=1;P=62}else{ea=(C|0)>65534?65534:C;if((ea|0)!=0){ka=ea;P=62;break}W1a(k,e,1);la=0}}while(0);b:do{if((P|0)==62){C=(ka|0)>-1?ka:-ka|0;ea=C>>>0>65535>>>0;ba=ea?C>>>16:C;aa=ea?16:0;if((ba&65280|0)==0){ma=aa;na=ba}else{ma=aa|8;na=ba>>>8}ba=(d[1359664+na|0]|0)+ma|0;W1a(k,e,0);if((ba|0)>=10){aa=0;while(1){ea=aa+1|0;W1a(k,l+((aa|0)>9?10:ea)|0,1);if((ea|0)<(ba|0)){aa=ea}else{break}}W1a(k,l+10|0,0);aa=ba;while(1){ea=aa-1|0;W1a(k,l+((ea|0)>9?31:aa+21|0)|0,C>>>(ea>>>0)&1);if((ea|0)>0){aa=ea}else{la=ka;break b}}}aa=l+1|0;if((ba|0)>0){oa=0;pa=aa}else{W1a(k,aa,0);la=ka;break}while(1){W1a(k,pa,1);aa=oa+1|0;ea=l+(oa+2)|0;if((aa|0)<(ba|0)){oa=aa;pa=ea}else{break}}W1a(k,l+(ba+1)|0,0);ea=ba;while(1){aa=ea-1|0;W1a(k,l+(ea+21)|0,C>>>(aa>>>0)&1);if((aa|0)>0){ea=aa}else{la=ka;break}}}}while(0);qa=la<<4;ra=c[z>>2]|0}else{qa=0;ra=da}if((ra|0)>0){ra=m+56|0;da=m+40|0;m=qa>>1;la=-m|0;ka=0;do{l=c[da>>2]|0;if((c[o>>2]|0)==0&(l|0)>0){pa=c[ra+(ka<<2)>>2]|0;oa=0;while(1){ma=pa+(oa<<2)|0;na=c[ma>>2]|0;c[ma>>2]=(((na|0)>0?m:la)+na|0)/(qa|0)|0;na=oa+1|0;ma=c[da>>2]|0;if((na|0)<(ma|0)){oa=na}else{sa=ma;break}}}else{sa=l}V1a(k,e,c[ra+(ka<<2)>>2]|0,sa);ka=ka+1|0;}while((ka|0)<(c[z>>2]|0))}c[p>>2]=VYa(k)|0;c[g>>2]=1;q=0;i=j;return q|0}function U1a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b+32|0;if((c[a>>2]|0)>0){d=b+56|0;e=0;do{mJb(d+(e<<2)|0);e=e+1|0;}while((e|0)<(c[a>>2]|0))}mJb(b+80|0);mJb(b+64|0);mJb(b+48|0);mJb(b+72|0);mJb(b+52|0);return 0}function V1a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((f|0)<=0){return}g=b+1|0;h=b+10|0;i=b+21|0;j=0;do{k=c[e+(j<<2)>>2]|0;do{if((k|0)==0){W1a(a,b,1)}else{l=(k|0)>-1?k:-k|0;m=l>>>0>65535>>>0;n=m?l>>>16:l;o=m?16:0;if((n&65280|0)==0){p=o;q=n}else{p=o|8;q=n>>>8}n=(d[1359664+q|0]|0)+p|0;W1a(a,b,0);if((n|0)>=10){o=0;while(1){m=o+1|0;W1a(a,b+((o|0)>9?10:m)|0,1);if((m|0)<(n|0)){o=m}else{break}}W1a(a,h,0);o=n;while(1){m=o-1|0;W1a(a,b+((m|0)>9?31:o+21|0)|0,l>>>(m>>>0)&1);if((m|0)>0){o=m}else{break}}W1a(a,i,k>>>31);break}if((n|0)>0){o=0;m=g;while(1){W1a(a,m,1);r=o+1|0;s=b+(o+2)|0;if((r|0)<(n|0)){o=r;m=s}else{break}}W1a(a,b+(n+1)|0,0);m=n;while(1){o=m-1|0;W1a(a,b+(m+21)|0,l>>>(o>>>0)&1);if((o|0)>0){m=o}else{break}}}else{W1a(a,g,0)}W1a(a,b+(n+11)|0,k>>>31)}}while(0);j=j+1|0;}while((j|0)<(f|0));return}function W1a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b+4|0;h=c[g>>2]|0;i=(ca(d[e]|0,h)|0)>>8;j=h-i|0;if((f|0)==0){c[g>>2]=j;k=(d[e]|0)+(b+16)|0}else{f=b|0;c[f>>2]=(c[f>>2]|0)+j;c[g>>2]=i;k=(d[e]|0)+(b+272)|0}a[e]=a[k]|0;if((c[g>>2]|0)>=256){return}k=b+12|0;e=b|0;i=b+532|0;j=b+8|0;b=c[k>>2]|0;f=c[e>>2]|0;while(1){do{if((b|0)<0){h=f>>8;c[k>>2]=h;l=h;m=f}else{if((f|0)<65281){h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=-1;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>8;c[k>>2]=n;l=n;m=h;break}if((f|0)<=65535){c[j>>2]=(c[j>>2]|0)+1;l=b;m=f;break}h=c[i>>2]|0;c[i>>2]=h+1;a[h]=b+1;if((c[j>>2]|0)!=0){do{h=c[i>>2]|0;c[i>>2]=h+1;a[h]=0;h=(c[j>>2]|0)-1|0;c[j>>2]=h;}while((h|0)!=0)}h=c[e>>2]|0;n=h>>>8&255;c[k>>2]=n;l=n;m=h}}while(0);h=m<<8&65280;c[e>>2]=h;n=c[g>>2]<<8;c[g>>2]=n;if((n|0)<256){b=l;f=h}else{break}}return}function X1a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+80|0;h=g|0;j=c[f+24>>2]|0;k=f+28|0;f=c[k>>2]|0;if((c[b+120>>2]|0)==0){l=-1;i=g;return l|0}if((c[b+124>>2]|0)==0){l=-1;i=g;return l|0}m=pJb(f+1024|0)|0;if((m|0)==0){l=-1;i=g;return l|0}a[m]=-1;a[m+1|0]=-40;nrc(m+2|0,562224,70)|0;nrc(m+7|0,560264,64)|0;nrc(m+72|0,560328,64)|0;nrc(m+136|0,562360,420)|0;nrc(m+556|0,562200,19)|0;n=m+561|0;y=he(c[b+132>>2]&65535|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;n=m+563|0;y=he(c[b+128>>2]&65535|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;nrc(m+575|0,562184,14)|0;do{if((c[b+48>>2]|0)==108){n=f-2|0;o=f+1022|0;if(!((n|0)>2&(o|0)>589)){p=589;break}q=-433-f|0;r=4-f|0;s=q>>>0>r>>>0?q:r;r=2;q=589;while(1){t=q+1|0;a[m+q|0]=a[j+r|0]|0;u=r+1|0;if((u|0)<(n|0)&(t|0)<(o|0)){r=u;q=t}else{break}}p=589-s|0}else{q=f+1021|0;if((f|0)>14&(q|0)>589){v=14;w=589}else{p=589;break}while(1){r=j+v|0;o=w+1|0;a[m+w|0]=a[r]|0;if((a[r]|0)==-1){a[m+o|0]=0;x=w+2|0}else{x=o}o=v+1|0;if((o|0)<(f|0)&(x|0)<(q|0)){v=o;w=x}else{p=x;break}}}}while(0);a[m+p|0]=-1;a[m+(p+1)|0]=-39;J1(h);c[h+24>>2]=m;c[h+28>>2]=p+2;p=nQa(b,d,e,h)|0;kJb(m);if((p|0)<0){l=p;i=g;return l|0}l=c[k>>2]|0;i=g;return l|0}function Y1a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;h=i;i=i+10640|0;j=h|0;k=h+8|0;l=h+264|0;m=h+272|0;n=h+8464|0;o=h+8472|0;p=h+8480|0;q=h+8488|0;r=h+8496|0;s=h+8504|0;t=h+8512|0;u=h+8520|0;v=h+8528|0;w=h+8536|0;x=h+8544|0;y=h+8552|0;z=h+8560|0;A=h+8568|0;B=h+10616|0;C=h+10624|0;D=h+10632|0;E=e;c[w>>2]=-1;c[x>>2]=-1;c[y>>2]=-1;c[z>>2]=-1;F=c[g+24>>2]|0;H=g+28|0;I=c[H>>2]|0;J=F+I|0;K=V1(g,73,B)|0;if((K|0)!=0&(c[B>>2]|0)==16){B=K;c[w>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24;B=K+4|0;c[x>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24;B=K+8|0;c[y>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24;B=K+12|0;c[z>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24}B=c[H>>2]|0;if((B|0)<1){L=B;i=h;return L|0}a:do{if((I|0)>0){B=b+12|0;K=A|0;M=A+2048|0;N=k|0;O=h+136|0;P=m|0;Q=m+128|0;R=m+256|0;S=m+384|0;T=M;U=j|0;V=b;W=j+1|0;X=j+2|0;Y=k+1|0;Z=A+2045|0;_=g+8|0;$=b+104|0;aa=C|0;ba=C+4|0;ca=g+48|0;da=D|0;ea=D+4|0;fa=F;while(1){if((a[fa]|0)==0){break a}if((c[(c[B>>2]|0)+12>>2]|0)==94216){ga=0;ha=fa;while(1){if((ga|0)>=2){ia=0;break}ja=Bd(ha|0,2375024,(ka=i,i=i+96|0,c[ka>>2]=o,c[ka+8>>2]=p,c[ka+16>>2]=q,c[ka+24>>2]=u,c[ka+32>>2]=r,c[ka+40>>2]=s,c[ka+48>>2]=t,c[ka+56>>2]=v,c[ka+64>>2]=w,c[ka+72>>2]=y,c[ka+80>>2]=x,c[ka+88>>2]=z,ka)|0)|0;i=ka;la=mc(ha|0,2368224)|0;ma=ha+(((a[ha+la|0]|0)!=0)+la)|0;if((ja|0)>7){na=10;break}else{ga=ga+1|0;ha=ma}}if((na|0)==10){na=0;c[u>>2]=((((((c[o>>2]|0)*60|0)+(c[p>>2]|0)|0)*60|0)+(c[q>>2]|0)|0)*100|0)+((c[u>>2]|0)/10|0);c[v>>2]=((((((c[r>>2]|0)*60|0)+(c[s>>2]|0)|0)*60|0)+(c[t>>2]|0)|0)*100|0)+((c[v>>2]|0)/10|0);ia=ma}if((ia|0)==0){break a}else{oa=ia}}else{ha=c[_>>2]|0;ga=c[_+4>>2]|0;c[aa>>2]=1;c[ba>>2]=100;ja=XIb(ha,ga,$,C)|0;c[u>>2]=ja;ja=c[ca>>2]|0;ga=wrc(ja,(ja|0)<0|0?-1:0,c[_>>2]|0,c[_+4>>2]|0)|0;c[da>>2]=1;c[ea>>2]=100;ja=XIb(ga,G,$,D)|0;c[v>>2]=ja;oa=fa}ja=c[w>>2]|0;ga=c[x>>2]|0;ha=c[y>>2]|0;la=c[z>>2]|0;a[P]=0;a[Q]=a[2294048]|0;a[Q+1|0]=a[2294049]|0;a[Q+2|0]=a[2294050]|0;a[Q+3|0]=a[2294051]|0;a[Q+4|0]=a[2294052]|0;a[Q+5|0]=a[2294053]|0;a[R]=a[2243008]|0;a[R+1|0]=a[2243009]|0;a[R+2|0]=a[2243010]|0;a[R+3|0]=a[2243011]|0;a[R+4|0]=a[2243012]|0;a[S]=a[2201680]|0;a[S+1|0]=a[2201681]|0;a[S+2|0]=a[2201682]|0;a[S+3|0]=a[2201683]|0;a[S+4|0]=a[2201684]|0;a[S+5|0]=a[2201685]|0;if((ga|ja|0)>-1){do{if((la|ha|0)>-1){if((ha|0)==(ja|0)&(la|0)==(ga|0)){na=17;break}Rb(K|0,2048,2169792,(ka=i,i=i+32|0,c[ka>>2]=ja,c[ka+8>>2]=ga,c[ka+16>>2]=ha,c[ka+24>>2]=la,ka)|0)|0;i=ka}else{na=17}}while(0);if((na|0)==17){na=0;Rb(K|0,2048,2142792,(ka=i,i=i+16|0,c[ka>>2]=ja,c[ka+8>>2]=ga,ka)|0)|0;i=ka}la=lrc(K|0)|0;ha=A+la|0;if((la|0)<2048){pa=oa;qa=ha;ra=1;sa=1;ta=0;na=19}else{ua=oa;va=ha}}else{pa=oa;qa=K;ra=1;sa=1;ta=0;na=19}b:do{if((na|0)==19){while(1){na=0;ha=a[pa]|0;if(ha<<24>>24==0){ua=pa;va=qa;break b}c:do{switch(ha<<24>>24|0){case 60:{la=(a[pa+1|0]|0)==47;wa=la&1;c[l>>2]=0;xa=Bd(pa+(la?2:1)|0,2566200,(ka=i,i=i+16|0,c[ka>>2]=N,c[ka+8>>2]=l,ka)|0)|0;i=ka;if(!((xa|0)>0&(c[l>>2]|0)>0)){na=76;break c}xa=_b(N|0,32)|0;if((xa|0)==0){ya=0}else{a[xa]=0;ya=xa+1|0}if(!(ra>>>0<16>>>0&(la^1))){if(!(la&(ra|0)>0)){na=76;break c}if((irc(m+(ra-1<<9)|0,N)|0)!=0){na=76;break c}}xa=c[l>>2]|0;za=pa+(xa+wa)|0;if(!la){mrc(m+(ra<<9)|0,0,512)|0}d:do{if((irc(N,2548120)|0)==0){if(la){Aa=ra-1|0;Ba=ra-2|0;e:do{if((a[m+(Aa<<9)+384|0]|0)==0){Ca=qa}else{Da=Ba;while(1){if(!((Da|0)>-1)){Ca=qa;break e}Ea=m+(Da<<9)+384|0;if((a[Ea]|0)==0){Da=Da-1|0}else{break}}Rb(qa|0,T-qa|0,2530192,(ka=i,i=i+8|0,c[ka>>2]=Ea,ka)|0)|0;i=ka;if(!(qa>>>0<M>>>0)){Ca=qa;break}Ca=qa+(lrc(qa|0)|0)|0}}while(0);f:do{if((a[m+(Aa<<9)+256|0]|0)==0){Fa=Ca}else{Da=Ba;while(1){if(!((Da|0)>-1)){Fa=Ca;break f}Ga=m+(Da<<9)+256|0;if((a[Ga]|0)==0){Da=Da-1|0}else{break}}Rb(Ca|0,T-Ca|0,2530192,(ka=i,i=i+8|0,c[ka>>2]=Ga,ka)|0)|0;i=ka;if(!(Ca>>>0<M>>>0)){Fa=Ca;break}Fa=Ca+(lrc(Ca|0)|0)|0}}while(0);if((a[m+(Aa<<9)+128|0]|0)==0){Ha=0;Ia=Fa;break}else{Ja=Ba}while(1){if(!((Ja|0)>-1)){Ha=0;Ia=Fa;break d}Ka=m+(Ja<<9)+128|0;if((a[Ka]|0)==0){Ja=Ja-1|0}else{break}}Rb(Fa|0,T-Fa|0,2530192,(ka=i,i=i+8|0,c[ka>>2]=Ka,ka)|0)|0;i=ka;if(!(Fa>>>0<M>>>0)){Ha=0;Ia=Fa;break}Ha=0;Ia=Fa+(lrc(Fa|0)|0)|0;break}Ba=m+(ra<<9)+128|0;if((ya|0)!=0){Aa=m+(ra<<9)+256|0;Da=m+(ra<<9)+384|0;La=ya;do{do{if((krc(La,2514968,5)|0)==0){Ma=La+((a[La+5|0]|0)==34?6:5)|0;Na=Bd(Ma|0,2501088,(ka=i,i=i+8|0,c[ka>>2]=n,ka)|0)|0;i=ka;if((Na|0)!=1){Oa=Ma;break}Rb(Ba|0,128,2488360,(ka=i,i=i+8|0,c[ka>>2]=c[n>>2],ka)|0)|0;i=ka;Oa=Ma}else{if((krc(La,2477408,6)|0)!=0){if((krc(La,2458328,5)|0)!=0){Oa=La;break}Ma=(a[La+5|0]|0)==34?6:5;Na=La+Ma|0;Pa=mc(Na|0,((a[La+(Ma-1)|0]|0)==34?2441360:2429664)|0)|0;c[l>>2]=Pa;Qa=Pa+1|0;CFb(O,Na,Qa>>>0<128>>>0?Qa:128)|0;Qa=La+((c[l>>2]|0)+Ma)|0;Rb(Da|0,128,2419192,(ka=i,i=i+8|0,c[ka>>2]=O,ka)|0)|0;i=ka;Oa=Qa;break}Qa=La+((a[La+6|0]|0)==34|6)|0;if((dKb(U,Qa,mc(Qa|0,2381584)|0,V)|0)<0){Ra=-1}else{Ra=d[W]<<8|d[U]|d[X]<<16}Rb(Aa|0,128,2467904,(ka=i,i=i+8|0,c[ka>>2]=Ra,ka)|0)|0;i=ka;Oa=Qa}}while(0);Qa=_b(Oa|0,32)|0;La=(Qa|0)==0?0:Qa+1|0;}while((La|0)!=0)}do{if((a[Ba]|0)==0){Sa=qa}else{Rb(qa|0,T-qa|0,2530192,(ka=i,i=i+8|0,c[ka>>2]=Ba,ka)|0)|0;i=ka;if(!(qa>>>0<M>>>0)){Sa=qa;break}Sa=qa+(lrc(qa|0)|0)|0}}while(0);Ba=m+(ra<<9)+256|0;do{if((a[Ba]|0)==0){Ta=Sa}else{Rb(Sa|0,T-Sa|0,2530192,(ka=i,i=i+8|0,c[ka>>2]=Ba,ka)|0)|0;i=ka;if(!(Sa>>>0<M>>>0)){Ta=Sa;break}Ta=Sa+(lrc(Sa|0)|0)|0}}while(0);Ba=m+(ra<<9)+384|0;if((a[Ba]|0)==0){Ha=0;Ia=Ta;break}Rb(Ta|0,T-Ta|0,2530192,(ka=i,i=i+8|0,c[ka>>2]=Ba,ka)|0)|0;i=ka;if(!(Ta>>>0<M>>>0)){Ha=0;Ia=Ta;break}Ha=0;Ia=Ta+(lrc(Ta|0)|0)|0}else{do{if((a[Y]|0)==0){if((ud(N|0,2410184)|0)!=1){break}Rb(qa|0,T-qa|0,2402512,(ka=i,i=i+16|0,c[ka>>2]=a[N]|0,c[ka+8>>2]=wa^1,ka)|0)|0;i=ka;Ha=0;Ia=qa+(lrc(qa|0)|0)|0;break d}}while(0);Rb(O|0,128,2395656,(ka=i,i=i+8|0,c[ka>>2]=N,ka)|0)|0;i=ka;Ha=1;Ia=qa}}while(0);if(la){Ua=0;Va=ta;Wa=sa;Xa=ra-1|0;Ya=Ia;Za=za;break c}do{if((Ha|0)!=0){if((Db(za|0,O|0)|0)!=0){break}wa=pa+(xa-(c[l>>2]|0))|0;a[Ia]=a[wa]|0;Ua=0;Va=ta;Wa=sa;Xa=ra;Ya=Ia+1|0;Za=wa;break c}}while(0);CFb(m+(ra<<9)|0,N,128)|0;Ua=0;Va=ta;Wa=sa;Xa=ra+1|0;Ya=Ia;Za=za;break};case 13:{Ua=0;Va=ta;Wa=sa;Xa=ra;Ya=qa;Za=pa;break};case 10:{if((sa|0)==0){_a=qa}else{Ua=1;Va=ta;Wa=sa;Xa=ra;Ya=qa;Za=pa;break c}while(1){xa=_a-1|0;if((a[xa]|0)==32){_a=xa}else{break}}Rb(_a|0,T-_a|0,2119240,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0)|0;i=ka;if(!(_a>>>0<M>>>0)){Ua=0;Va=ta;Wa=1;Xa=ra;Ya=_a;Za=pa;break c}Ua=0;Va=ta;Wa=1;Xa=ra;Ya=_a+(lrc(_a|0)|0)|0;Za=pa;break};case 32:{if((sa|0)!=0){Ua=0;Va=ta;Wa=sa;Xa=ra;Ya=qa;Za=pa;break c}a[qa]=ha;Ua=0;Va=ta;Wa=0;Xa=ra;Ya=qa+1|0;Za=pa;break};case 123:{c[l>>2]=0;za=Bd(pa|0,2637512,(ka=i,i=i+8|0,c[ka>>2]=l,ka)|0)|0;i=ka;if((za|0)>-1){$a=(c[l>>2]|0)>0|0}else{$a=0}za=$a+ta|0;if((za|0)==1){na=31}else{c[l>>2]=0;xa=Bd(pa|0,2614232,(ka=i,i=i+8|0,c[ka>>2]=l,ka)|0)|0;i=ka;la=c[l>>2]|0;if((xa|0)>-1&(la|0)>0){ab=la}else{na=31}}do{if((na|0)==31){na=0;c[l>>2]=0;la=Bd(pa|0,2587232,(ka=i,i=i+8|0,c[ka>>2]=l,ka)|0)|0;i=ka;xa=c[l>>2]|0;if((la|0)>-1&(xa|0)>0){ab=xa;break}a[qa]=a[pa]|0;Ua=0;Va=za;Wa=sa;Xa=ra;Ya=qa+1|0;Za=pa;break c}}while(0);Ua=0;Va=za;Wa=sa;Xa=ra;Ya=qa;Za=pa+(ab-1)|0;break};default:{na=76}}}while(0);if((na|0)==76){na=0;a[qa]=a[pa]|0;Ua=0;Va=ta;Wa=sa;Xa=ra;Ya=qa+1|0;Za=pa}ha=a[Za]|0;if((ha<<24>>24|0)==32|(ha<<24>>24|0)==13|(ha<<24>>24|0)==10){bb=Wa}else{bb=0}ha=Za+1|0;if(Ya>>>0<M>>>0&(Ua|0)==0){pa=ha;qa=Ya;ra=Xa;sa=bb;ta=Va;na=19}else{ua=ha;va=Ya;break b}}}}while(0);ga=va>>>0>Z>>>0?Z:va;while(1){ja=ga-2|0;if((krc(ja,2119240,2)|0)==0){ga=ja}else{cb=ga;break}}while(1){ga=cb-1|0;if((a[ga]|0)==32){cb=ga}else{break}}Rb(cb|0,T-cb|0,2388432,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0)|0;i=ka;ga=c[u>>2]|0;fmb(E,K,ga,(c[v>>2]|0)-ga|0,0)|0;if(ua>>>0<J>>>0){fa=ua}else{break}}}}while(0);c[f>>2]=(c[e+12>>2]|0)!=0;L=c[H>>2]|0;i=h;return L|0}function Z1a(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b>>2]=a;d=b+4|0;c[d>>2]=hmb(c[a+860>>2]|0)|0;SFb(b+8|0,0,-1);return((c[d>>2]|0)!=0?0:-1094995529)|0}function _1a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+8|0;g=f|0;h=c[a+60>>2]|0;j=h;k=h+8|0;ZFb(k);l=e+12|0;a:do{if((c[l>>2]|0)==0){m=h+12|0}else{n=e+16|0;o=h+4|0;p=a+12|0;q=h+1036|0;r=h+12|0;s=h+1032|0;t=h+1108|0;u=0;while(1){v=c[(c[n>>2]|0)+(u<<2)>>2]|0;if((c[v+84>>2]|0)!=3){break}w=kmb(c[o>>2]|0,c[v+92>>2]|0,0,g)|0;b:do{if((w|0)!=0){v=w;do{x=c[g>>2]|0;c[g>>2]=x-1;if((x|0)==0){break b}if((c[(c[p>>2]|0)+12>>2]|0)==94216){x=(c[v+4>>2]|0)*10|0;y=(c[v+8>>2]|0)*10|0;z=(x|0)/36e5|0;A=(ca(z,-36e5)|0)+x|0;x=(A|0)/6e4|0;B=A+(x*-6e4|0)|0;A=(B|0)/1e3|0;C=(y|0)/36e5|0;D=(ca(C,-36e5)|0)+y|0;y=(D|0)/6e4|0;E=D+(y*-6e4|0)|0;D=(E|0)/1e3|0;F=(c[q>>2]|0)+1|0;c[q>>2]=F;a2a(j,2242952,(G=i,i=i+72|0,c[G>>2]=F,c[G+8>>2]=z,c[G+16>>2]=x,c[G+24>>2]=A,c[G+32>>2]=B+(A*-1e3|0),c[G+40>>2]=C,c[G+48>>2]=y,c[G+56>>2]=D,c[G+64>>2]=E+(D*-1e3|0),G)|0);i=G;c[s>>2]=(c[r>>2]|0)-2}c[t>>2]=0;b2a(j,c[v+12>>2]|0);mmb(558632,h,c[v+16>>2]|0)|0;v=v+20|0;}while((v|0)!=0)}}while(0);w=u+1|0;if(w>>>0<(c[l>>2]|0)>>>0){u=w}else{m=r;break a}}KIb(a,16,2294008,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-38;i=f;return H|0}}while(0);l=c[m>>2]|0;if(!(l>>>0<(c[h+16>>2]|0)>>>0)){H=-12;i=f;return H|0}if((l|0)==0){H=0;i=f;return H|0}if(l>>>0>d>>>0){KIb(a,16,2201640,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-1;i=f;return H|0}else{nrc(b|0,c[k>>2]|0,l)|0;H=c[m>>2]|0;i=f;return H|0}return 0}function $1a(a){a=a|0;var b=0;b=c[a+60>>2]|0;jmb(c[b+4>>2]|0);_Fb(b+8|0,0)|0;return 0}function a2a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;VFb(a+8|0,b,f|0);i=e;return}function b2a(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=nmb(c[b+4>>2]|0,d)|0;if((f|0)==0){i=e;return}d=c[f+12>>2]|0;g=d&16777215;h=f+4|0;j=c[h>>2]|0;if((j|0)==0){k=4}else{if((irc(j,2477400)|0)==0){k=4}else{k=5}}if((k|0)==4){if(!((c[f+8>>2]|0)==16&(g|0)==16777215)){k=5}}do{if((k|0)==5){a2a(b,2467896,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=c[h>>2]|0;do{if((j|0)!=0){if((irc(j,2477400)|0)==0){break}a2a(b,2458304,(l=i,i=i+8|0,c[l>>2]=j,l)|0);i=l}}while(0);j=c[f+8>>2]|0;if((j|0)!=16){a2a(b,2441344,(l=i,i=i+8|0,c[l>>2]=j,l)|0);i=l}if((g|0)!=16777215){a2a(b,2429648,(l=i,i=i+8|0,c[l>>2]=d>>>16&255|d&65280|d<<16&16711680,l)|0);i=l}a2a(b,2419168,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;j=b+1104|0;m=c[j>>2]|0;if((m|0)>63){break}c[j>>2]=m+1;a[b+1040+m|0]=102}}while(0);do{if((c[f+20>>2]|0)!=0){a2a(b,2410176,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;d=b+1104|0;g=c[d>>2]|0;if((g|0)>63){break}c[d>>2]=g+1;a[b+1040+g|0]=98}}while(0);do{if((c[f+24>>2]|0)!=0){a2a(b,2402504,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;g=b+1104|0;d=c[g>>2]|0;if((d|0)>63){break}c[g>>2]=d+1;a[b+1040+d|0]=105}}while(0);do{if((c[f+28>>2]|0)!=0){a2a(b,2395648,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;d=b+1104|0;g=c[d>>2]|0;if((g|0)>63){break}c[d>>2]=g+1;a[b+1040+g|0]=117}}while(0);g=c[f+32>>2]|0;if((g|0)==2){i=e;return}a2a(b,2566192,(l=i,i=i+8|0,c[l>>2]=g,l)|0);i=l;c[b+1108>>2]=1;i=e;return}function c2a(a,b,c){a=a|0;b=b|0;c=c|0;XFb(a+8|0,b,c);return}function d2a(a,b){a=a|0;b=b|0;b=i;a2a(a,2488352,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return}function e2a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a;m2a(f,b,d);if((d|0)!=0){i=e;return}a2a(f,2501080,(f=i,i=i+8|0,c[f>>2]=b<<24>>24,f)|0);i=f;i=e;return}function f2a(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;if(e>>>0>1>>>0){i=f;return}e=b;g=(d|0)==-1;h=b+1104|0;j=c[h>>2]|0;do{if(g){k=j;while(1){l=k-1|0;if((k|0)<=0){break}if((a[e+1040+l|0]|0)==102){break}else{k=l}}if((l|0)<0|(j|0)==(l|0)){m=12;break}else{n=j}while(1){if((n|0)<1){o=0}else{k=n-1|0;c[h>>2]=k;o=a[e+1040+k|0]|0}a2a(e,2119232,(p=i,i=i+16|0,c[p>>2]=o<<24>>24,c[p+8>>2]=o<<24>>24==102?2637504:10230744,p)|0);i=p;k=c[h>>2]|0;if((k|0)==(l|0)){m=12;break}else{n=k}}}else{if((j|0)>63){KIb(c[b>>2]|0,16,2142768,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;break}else{c[h>>2]=j+1;a[e+1040+j|0]=102;m=12;break}}}while(0);do{if((m|0)==12){if(!g){break}i=f;return}}while(0);a2a(e,2514944,(p=i,i=i+8|0,c[p>>2]=d>>>16&255|d&65280|d<<16&16711680,p)|0);i=p;i=f;return}function g2a(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b;g=(d|0)!=0;h=b+1104|0;j=c[h>>2]|0;do{if(g){if((j|0)>63){KIb(c[b>>2]|0,16,2142768,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;break}else{c[h>>2]=j+1;a[f+1040+j|0]=102;l=11;break}}else{m=j;while(1){n=m-1|0;if((m|0)<=0){break}if((a[f+1040+n|0]|0)==102){break}else{m=n}}if((n|0)<0|(j|0)==(n|0)){l=11;break}else{o=j}while(1){if((o|0)<1){p=0}else{m=o-1|0;c[h>>2]=m;p=a[f+1040+m|0]|0}a2a(f,2119232,(k=i,i=i+16|0,c[k>>2]=p<<24>>24,c[k+8>>2]=p<<24>>24==102?2637504:10230744,k)|0);i=k;m=c[h>>2]|0;if((m|0)==(n|0)){l=11;break}else{o=m}}}}while(0);do{if((l|0)==11){if(g){break}i=e;return}}while(0);a2a(f,2530168,(k=i,i=i+8|0,c[k>>2]=d,k)|0);i=k;i=e;return}function h2a(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b;g=(d|0)>-1;h=b+1104|0;j=c[h>>2]|0;do{if(g){if((j|0)>63){KIb(c[b>>2]|0,16,2142768,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;break}else{c[h>>2]=j+1;a[f+1040+j|0]=102;l=11;break}}else{m=j;while(1){n=m-1|0;if((m|0)<=0){break}if((a[f+1040+n|0]|0)==102){break}else{m=n}}if((n|0)<0|(j|0)==(n|0)){l=11;break}else{o=j}while(1){if((o|0)<1){p=0}else{m=o-1|0;c[h>>2]=m;p=a[f+1040+m|0]|0}a2a(f,2119232,(k=i,i=i+16|0,c[k>>2]=p<<24>>24,c[k+8>>2]=p<<24>>24==102?2637504:10230744,k)|0);i=k;m=c[h>>2]|0;if((m|0)==(n|0)){l=11;break}else{o=m}}}}while(0);do{if((l|0)==11){if(g){break}i=e;return}}while(0);a2a(f,2548096,(k=i,i=i+8|0,c[k>>2]=d,k)|0);i=k;i=e;return}function i2a(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a+1108|0;if(!((c[e>>2]|0)==0&(b|0)>-1)){i=d;return}a2a(a,2566192,(a=i,i=i+8|0,c[a>>2]=b,a)|0);i=a;c[e>>2]=1;i=d;return}function j2a(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=b;g=b+1104|0;b=c[g>>2]|0;if((b|0)==0){b2a(f,d);i=e;return}else{h=b}do{if((h|0)<1){j=0}else{b=h-1|0;c[g>>2]=b;j=a[f+1040+b|0]|0}a2a(f,2119232,(b=i,i=i+16|0,c[b>>2]=j<<24>>24,c[b+8>>2]=j<<24>>24==102?2637504:10230744,b)|0);i=b;h=c[g>>2]|0;}while((h|0)!=0);b2a(f,d);i=e;return}function k2a(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;h=i;i=i+48|0;g=h+40|0;if((c[(c[(c[a>>2]|0)+12>>2]|0)+12>>2]|0)!=94216){i=h;return}j=h|0;k=Rb(j|0,32,2587192,(l=i,i=i+32|0,c[l>>2]=b,c[l+8>>2]=e,c[l+16>>2]=d,c[l+24>>2]=f,l)|0)|0;i=l;l=a+8|0;YFb(l,k,h+32|0,g);if((c[g>>2]|0)>>>0<k>>>0){m=a+12|0}else{g=l;l=c[g>>2]|0;f=a+1032|0;d=c[f>>2]|0;e=a+12|0;orc(l+(d+k)|0,l+d|0,1-d+(c[e>>2]|0)|0)|0;nrc((c[g>>2]|0)+(c[f>>2]|0)|0,j|0,k)|0;m=e}c[m>>2]=(c[m>>2]|0)+k;i=h;return}function l2a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=b;f=b+1104|0;g=c[f>>2]|0;if((g|0)!=0){h=g;do{if((h|0)<1){j=0}else{g=h-1|0;c[f>>2]=g;j=a[e+1040+g|0]|0}a2a(e,2119232,(k=i,i=i+16|0,c[k>>2]=j<<24>>24,c[k+8>>2]=j<<24>>24==102?2637504:10230744,k)|0);i=k;h=c[f>>2]|0;}while((h|0)!=0)}if((c[(c[(c[b>>2]|0)+12>>2]|0)+12>>2]|0)!=94216){i=d;return}a2a(e,2169784,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;i=d;return}function m2a(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;if((e|0)==0){e=b+1104|0;g=c[e>>2]|0;if((g|0)>63){KIb(c[b>>2]|0,16,2142768,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;i=f;return}else{c[e>>2]=g+1;a[b+1040+g|0]=d;i=f;return}}g=c[b+1104>>2]|0;do{if(d<<24>>24==0){j=0}else{e=g;while(1){k=e-1|0;if((e|0)<=0){break}if((a[b+1040+k|0]|0)==d<<24>>24){break}else{e=k}}if((k|0)>=0){j=k;break}i=f;return}}while(0);k=b+1104|0;if((g|0)==(j|0)){i=f;return}else{l=g}do{if((l|0)<1){m=0}else{g=l-1|0;c[k>>2]=g;m=a[b+1040+g|0]|0}a2a(b,2119232,(h=i,i=i+16|0,c[h>>2]=m<<24>>24,c[h+8>>2]=m<<24>>24==102?2637504:10230744,h)|0);i=h;l=c[k>>2]|0;}while((l|0)!=(j|0));i=f;return}function n2a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1032|0;h=g+8|0;j=d;k=c[f+24>>2]|0;do{if((k|0)==0){SFb(h,0,-1);l=f+28|0}else{m=Bd(k|0,2446256,(n=i,i=i+8|0,c[n>>2]=g,n)|0)|0;i=n;if((m|0)==1){KIb(b,16,2356928,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}SFb(h,0,-1);m=f+28|0;if((c[m>>2]|0)<=0){l=m;break}p=a[k]|0;if(!(p<<24>>24==0)){q=k;r=p;while(1){if((krc(q,2294e3,4)|0)==0){UFb(h,2242944,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;s=q+4|0}else{do{if((r<<24>>24|0)==10){if((a[q+1|0]|0)==0){break}UFb(h,2242944,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}else if((r<<24>>24|0)!=13){WFb(h,r,1)}}while(0);s=q+1|0}p=a[s]|0;if(p<<24>>24==0){break}else{q=s;r=p}}}UFb(h,2201632,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;fmb(j,c[h>>2]|0,c[f+8>>2]|0,c[f+48>>2]|0,0)|0;l=m}}while(0);c[e>>2]=(c[d+12>>2]|0)!=0;_Fb(h,0)|0;o=c[l>>2]|0;i=g;return o|0}function o2a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;i=i+8|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=k+l|0;if((l|0)<32){m=-1094995529;i=h;return m|0}l=k;if(!((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)==-1788172711)){KIb(b,16,2446192,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}l=k+4|0;o=je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;l=k+8|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=je(p|0)|0;q=k+12|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=je(r|0)|0;s=k+20|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=je(t|0)|0;u=k+24|0;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=je(v|0)|0;w=k+28|0;x=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=je(x|0)|0;if((t|0)==-65536){QIb(b,2356880,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1163346256;i=h;return m|0}if(s>>>0>5>>>0){KIb(b,16,2293968,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}if((v|0)==33554432){QIb(b,2242920,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1163346256;i=h;return m|0}if(u>>>0>2>>>0){KIb(b,16,2201608,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}if((s-4|0)>>>0<2>>>0){KIb(b,16,2169752,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1;i=h;return m|0}switch(q|0){case 32:{c[b+140>>2]=(t|0)==50331648?295:297;break};case 4:{c[b+140>>2]=(x|0)!=0?11:-1;break};case 24:{c[b+140>>2]=(t|0)==50331648?2:3;break};case 1:{c[b+140>>2]=(x|0)!=0?11:9;break};case 8:{c[b+140>>2]=(x|0)!=0?11:8;break};default:{KIb(b,16,2142752,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}}s=H4a(b,o,l)|0;if((s|0)<0){m=s;i=h;return m|0}s=M4a(b,e,0)|0;if((s|0)<0){m=s;i=h;return m|0}c[e+88>>2]=1;s=g;if((s-(k+32)|0)>>>0<w>>>0){m=-1094995529;i=h;return m|0}u=(x|0)==0;do{if(q>>>0<9>>>0|u){if(u){y=k+(w+32)|0;z=q>>>0<8>>>0;A=36;break}v=(w>>>0)/3|0;if(((w>>>0)%3|0|0)!=0|w>>>0>768>>>0){KIb(b,24,2637472,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}if(!(w>>>0>2>>>0)){A=33;break}B=v+32|0;C=(v<<1)+32|0;D=0;E=c[e+4>>2]|0;while(1){c[E>>2]=(d[k+(D+32)|0]|0)<<16|(d[k+(B+D)|0]|0)<<8|(d[k+(C+D)|0]|0)|-16777216;F=D+1|0;if(F>>>0<v>>>0){D=F;E=E+4|0}else{A=33;break}}}else{KIb(b,24,2119168,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;A=33}}while(0);do{if((A|0)==33){n=k+(w+32)|0;u=q>>>0<8>>>0;if(!((x|0)!=0&u)){y=n;z=u;A=36;break}u=o+15|0;E=hJb(ca(l,u)|0)|0;if((E|0)==0){m=-12;i=h;return m|0}else{G=ca(q,u>>>3)|0;H=E;I=E;J=n;K=1;break}}}while(0);if((A|0)==36){G=c[e+32>>2]|0;H=0;I=c[e>>2]|0;J=y;K=z}z=((ca(q,o)|0)+7|0)>>>3;y=(z&1)+z|0;a:do{if((t|0)==33554432){A=ca(G,l)|0;x=I+A|0;if((A|0)!=0&J>>>0<g>>>0){L=0;M=I;N=J}else{O=J;break}while(1){if((s-N|0)<1){m=-1094995529;break}A=N+1|0;w=a[N]|0;do{if(w<<24>>24==-128){n=N+2|0;E=a[A]|0;u=(E&255)+1|0;if(E<<24>>24==0){P=u;Q=-128;R=n;break}P=u;Q=a[n]|0;R=N+3|0}else{P=1;Q=w;R=A}}while(0);A=P;w=M;n=L;b:while(1){u=A;S=n;while(1){T=u-1|0;if((u|0)==0){break b}if(S>>>0<z>>>0){a[w+S|0]=Q}E=S+1|0;if(E>>>0<y>>>0){u=T;S=E}else{break}}u=w+G|0;if((u|0)==(x|0)){O=R;break a}else{A=T;w=u;n=0}}if((w|0)!=(x|0)&R>>>0<g>>>0){L=S;M=w;N=R}else{O=R;break a}}i=h;return m|0}else{if((p|0)==0){O=J;break}else{U=0;V=I;W=J}while(1){if((s-W|0)>>>0<z>>>0){O=W;break a}nrc(V|0,W|0,z)|0;x=W+y|0;n=U+1|0;if(n>>>0<l>>>0){U=n;V=V+G|0;W=x}else{O=x;break}}}}while(0);if((c[b+140>>2]|0)==11&K){c[j>>2]=H;if((p|0)!=0){p=ca(q,(o+7|0)>>>3)|0;K=(p|0)==0;b=(r|0)==16777216;r=e+32|0;W=ca(q,(o+15|0)>>>3)|0;o=0;q=c[e>>2]|0;e=H;while(1){if(!K){if(b){H=0;do{G=e+H|0;V=H<<3;a[q+V|0]=(d[G]|0)>>>7;a[q+(V|1)|0]=(d[G]|0)>>>6&1;a[q+(V|2)|0]=(d[G]|0)>>>5&1;a[q+(V|3)|0]=(d[G]|0)>>>4&1;a[q+(V|4)|0]=(d[G]|0)>>>3&1;a[q+(V|5)|0]=(d[G]|0)>>>2&1;a[q+(V|6)|0]=(d[G]|0)>>>1&1;a[q+(V|7)|0]=a[G]&1;H=H+1|0;}while(H>>>0<p>>>0)}else{H=0;do{G=e+H|0;V=H<<1;a[q+V|0]=(d[G]|0)>>>4;a[q+(V|1)|0]=a[G]&15;H=H+1|0;}while(H>>>0<p>>>0)}}H=o+1|0;if(H>>>0<l>>>0){o=H;q=q+(c[r>>2]|0)|0;e=e+W|0}else{break}}}mJb(j)}c[f>>2]=1;m=O-k|0;i=h;return m|0}function p2a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+60>>2]|0;e=c[a+568>>2]|0;if((e|0)==3){c[d+24>>2]=2;f=2}else if((e|0)==2){c[d+24>>2]=1;f=1}else{KIb(a,16,2242896,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;g=-22;i=b;return g|0}e=d+28|0;c[e>>2]=0;h=d+32|0;c[h>>2]=0;j=c[a+140>>2]|0;if((j|0)==8){k=0;l=8}else if((j|0)==9){c[d+16>>2]=1;m=1;n=0}else if((j|0)==3){c[d+16>>2]=24;m=24;n=0}else if((j|0)==11){c[e>>2]=1;c[h>>2]=768;k=768;l=8}else{g=-558323010;i=b;return g|0}if((l|0)==8){c[d+16>>2]=8;m=8;n=k}k=ca((ca(m,c[a+120>>2]|0)|0)+15>>3&-2,c[a+124>>2]|0)|0;c[d+20>>2]=k;c[d+36>>2]=n+32+(ca(k,(f|0)==2?2:1)|0);g=0;i=b;return g|0}function q2a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=i;h=b+60|0;j=c[h>>2]|0;k=c[j+36>>2]|0;l=d5a(b,d,k,(k|0)<0|0?-1:0)|0;if((l|0)<0){m=l;i=g;return m|0}l=d+24|0;k=c[l>>2]|0;n=d+28|0;o=c[n>>2]|0;if(!((o|0)>-1)){KIb(0,0,2446160,(p=i,i=i+24|0,c[p>>2]=2356864,c[p+8>>2]=2293944,c[p+16>>2]=145,p)|0);i=p;Hd();return 0}p=j;c[p>>2]=k;q=j+8|0;c[q>>2]=k;c[j+4>>2]=k+o;c[j+12>>2]=0;o=c[h>>2]|0;k=o;r=c[k>>2]|0;y=-1788172711;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[k>>2]|0)+4|0;c[k>>2]=r;s=b+120|0;t=r;y=je(c[s>>2]|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[k>>2]|0)+4|0;c[k>>2]=t;r=b+124|0;b=t;y=je(c[r>>2]|0)|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=(c[k>>2]|0)+4|0;c[k>>2]=b;t=b;y=je(c[o+16>>2]|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[k>>2]|0)+4|0;c[k>>2]=t;b=t;y=je(c[o+20>>2]|0)|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=(c[k>>2]|0)+4|0;c[k>>2]=b;t=b;y=je(c[o+24>>2]|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[k>>2]|0)+4|0;c[k>>2]=t;b=t;y=je(c[o+28>>2]|0)|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=(c[k>>2]|0)+4|0;c[k>>2]=b;t=b;y=je(c[o+32>>2]|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;k=c[e>>2]|0;t=c[e+4>>2]|0;o=c[e+32>>2]|0;e=c[h>>2]|0;h=e+32|0;b=c[h>>2]|0;do{if((b|0)!=0){u=(b|0)/3|0;v=e;w=c[v>>2]|0;x=e+12|0;do{if((c[x>>2]|0)==0){z=c[e+4>>2]|0;A=z-w|0;B=A>>>0>u>>>0?u:A;if((B|0)!=(u|0)){c[x>>2]=1;A=w+B|0;c[v>>2]=A;C=A;break}A=w+u|0;c[v>>2]=A;B=z-A|0;z=B>>>0>u>>>0?u:B;if((z|0)!=(u|0)){c[x>>2]=1}c[v>>2]=w+(z+u);C=A}else{C=w}}while(0);if((b|0)>2){D=w;E=C;F=0}else{break}while(1){x=c[t+(F<<2)>>2]|0;a[D]=x>>>16;a[E]=x>>>8;a[c[v>>2]|0]=x;c[v>>2]=(c[v>>2]|0)+1;x=F+1|0;if((x|0)<(u|0)){D=D+1|0;E=E+1|0;F=x}else{break}}}}while(0);F=(ca(c[s>>2]|0,c[e+16>>2]|0)|0)+7>>3;s=F&1;E=s+F|0;D=c[r>>2]|0;a:do{if((c[e+24>>2]|0)==2){if((D|0)<1){G=c[e>>2]|0}else{t=F-1|0;if((F|0)<1){H=k+t|0}else{H=k}C=e;b=0;u=0;v=k;w=a[H]|0;x=D;while(1){A=u+1|0;if((A|0)<(E|0)){I=v;J=A;K=b}else{I=v+o|0;J=0;K=b+1|0}if((K|0)<(x|0)){L=a[I+((J|0)<(F|0)?J:t)|0]|0}else{L=0}A=w&255;b:do{if(L<<24>>24==w<<24>>24){z=K;B=J;M=I;N=1;while(1){if((z|0)>=(x|0)){O=z;P=B;Q=M;R=w;S=N;break b}T=B+1|0;U=N+1|0;if((T|0)<(E|0)){V=M;W=T;X=z}else{V=M+o|0;W=0;X=z+1|0}if((X|0)<(x|0)){Y=a[V+((W|0)<(F|0)?W:t)|0]|0}else{Y=0}if(Y<<24>>24==w<<24>>24&(U|0)<256){z=X;B=W;M=V;N=U}else{O=X;P=W;Q=V;R=Y;S=U;break}}}else{O=K;P=J;Q=I;R=L;S=1}}while(0);do{if((S|0)>2|w<<24>>24==-128){a[c[C>>2]|0]=-128;N=(c[C>>2]|0)+1|0;c[C>>2]=N;a[N]=S+255;N=(c[C>>2]|0)+1|0;c[C>>2]=N;if((S|0)<=1){Z=N;break}a[N]=w;N=(c[C>>2]|0)+1|0;c[C>>2]=N;Z=N}else{if((S|0)==1){a[c[C>>2]|0]=w;N=(c[C>>2]|0)+1|0;c[C>>2]=N;Z=N;break}else{N=he((A<<8|A)&65535|0)|0;M=c[C>>2]|0;y=N;a[M]=y;y=y>>8;a[M+1|0]=y;M=(c[C>>2]|0)+2|0;c[C>>2]=M;Z=M;break}}}while(0);A=c[r>>2]|0;if((O|0)<(A|0)){b=O;u=P;v=Q;w=R;x=A}else{G=Z;break}}}c[e+20>>2]=G-32-(c[e+8>>2]|0)-(c[h>>2]|0)}else{if((D|0)<=0){break}x=e+12|0;w=e+4|0;v=e;if((s|0)==0){u=1;b=k;C=D;while(1){if((c[x>>2]|0)==0){t=c[v>>2]|0;A=(c[w>>2]|0)-t|0;M=A>>>0>F>>>0?F:A;if((M|0)!=(F|0)){c[x>>2]=1}nrc(t|0,b|0,M)|0;c[v>>2]=(c[v>>2]|0)+M;_=c[r>>2]|0}else{_=C}if((u|0)>=(_|0)){break a}u=u+1|0;b=b+o|0;C=_}}else{$=1;aa=k}while(1){if((c[x>>2]|0)==0){C=c[v>>2]|0;b=(c[w>>2]|0)-C|0;u=b>>>0>F>>>0?F:b;if((u|0)!=(F|0)){c[x>>2]=1}nrc(C|0,aa|0,u)|0;C=(c[v>>2]|0)+u|0;c[v>>2]=C;ba=C}else{ba=c[v>>2]|0}a[ba]=0;c[v>>2]=(c[v>>2]|0)+1;if(($|0)>=(c[r>>2]|0)){break a}$=$+1|0;aa=aa+o|0}}}while(0);if((c[j+24>>2]|0)==2){o=je(c[j+20>>2]|0)|0;j=(c[l>>2]|0)+16|0;y=o;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y}c[f>>2]=1;f=d+36|0;c[f>>2]=c[f>>2]|1;c[n>>2]=(c[p>>2]|0)-(c[q>>2]|0);m=0;i=g;return m|0}function r2a(a){a=a|0;VHb(a+804|0);return 0}function s2a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;e=UHb()|0;c[b+228>>2]=e;if((e|0)==0){f=-12;return f|0}c[b+232>>2]=(c[a+120>>2]|0)+3&-4;c[b+236>>2]=(c[a+124>>2]|0)+3&-4;c[a+140>>2]=6;YJa(b,c[a+88>>2]|0);c[1273371]=5093456;c[1273373]=6;$2(5093480,2,4,1301745,2,1,1301744,2,1,0,0,0,4)|0;c[1270877]=5092752;c[1270879]=176;$2(5083504,7,33,1339809,2,1,1339808,2,1,0,0,0,4)|0;a=0;b=0;while(1){c[5083532+(a*20|0)>>2]=5092080+(b<<2);e=d[551872+a|0]|0;c[5083540+(a*20|0)>>2]=e;g=e+b|0;$2(5083528+(a*20|0)|0,3,8,1298193+(a<<4)|0,2,1,1298192+(a<<4)|0,2,1,0,0,0,4)|0;c[5083676+(a*20|0)>>2]=5092080+(g<<2);e=d[551878+a|0]|0;c[5083684+(a*20|0)>>2]=e;$2(5083672+(a*20|0)|0,3,8,1299337+(a<<4)|0,2,1,1299336+(a<<4)|0,2,1,0,0,0,4)|0;h=a+1|0;if((h|0)<6){a=h;b=e+g|0}else{break}}c[1270913]=5089552;c[1270915]=632;$2(5083648,8,256,1298290,4,2,1298288,4,2,0,0,0,4)|0;c[1270949]=5083816;c[1270951]=1434;$2(5083792,9,512,1299434,4,2,1299432,4,2,0,0,0,4)|0;f=0;return f|0}function t2a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;k=i;i=i+304|0;l=k|0;m=k+256|0;n=k+264|0;o=k+280|0;p=k+288|0;q=c[j+24>>2]|0;r=c[j+28>>2]|0;j=f+60|0;s=c[j>>2]|0;t=g;u=s+208|0;v=u;w=r>>>0>268435455>>>0?-8:r<<3;x=w>>>0>2147483639>>>0|(q|0)==0;y=x?0:q;z=x?0:w;w=u;c[w>>2]=y;c[s+220>>2]=z;u=z+8|0;x=s+224|0;c[x>>2]=u;c[s+212>>2]=y+(z>>3);z=s+216|0;c[z>>2]=0;A=y;y=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)>>>10;c[z>>2]=u>>>0>22>>>0?22:u;c[s+240>>2]=y;if((y&4194191|0)!=0|(y&96|0)==0){B=-1094995529;i=k;return B|0}do{if((y|0)!=32){u=q+4|0;if((r|0)<36){B=-1094995529;i=k;return B|0}else{A=c[u>>2]|0;c[u>>2]=(A<<16|A>>>16)^c[q+32>>2];A=q+8|0;u=c[A>>2]|0;c[A>>2]=(u<<16|u>>>16)^c[q+28>>2];u=q+12|0;A=c[u>>2]|0;c[u>>2]=(A<<16|A>>>16)^c[q+24>>2];A=q+16|0;u=c[A>>2]|0;c[A>>2]=(u<<16|u>>>16)^c[q+20>>2];break}}}while(0);q=l|0;y=c[j>>2]|0;j=y+232|0;u=c[j>>2]|0;A=y+236|0;C=c[A>>2]|0;D=y+216|0;E=y+224|0;F=c[E>>2]|0;G=(c[D>>2]|0)+8|0;H=F>>>0>G>>>0?G:F;c[D>>2]=H;G=y+244|0;c[G>>2]=0;I=y+208|0;J=c[I>>2]|0;K=J+(H>>>3)|0;L=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(H&7)>>>30;K=H+2|0;H=F>>>0>K>>>0?K:F;c[D>>2]=H;do{if((L|0)==0){c[g+88>>2]=1;K=y+240|0;M=c[K>>2]|0;if((M|0)==80|(M|0)==96){N=J+(H>>>3)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(H&7)>>>16;N=H+16|0;c[D>>2]=F>>>0>N>>>0?N:F;Ltb(J,c[y+220>>2]>>3,O)|0;P=c[K>>2]|0}else{P=M}if((P^16|0)>79){M=c[D>>2]|0;K=c[E>>2]|0;O=(c[I>>2]|0)+(M>>>3)|0;N=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(M&7)>>>24;O=M+8|0;c[D>>2]=K>>>0>O>>>0?O:K;a[q]=N;if((N|0)!=0){K=N;N=1;do{O=a[553064+K|0]|0;M=c[D>>2]|0;Q=c[E>>2]|0;R=(c[I>>2]|0)+(M>>>3)|0;K=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(M&7)>>>24;R=M+8|0;c[D>>2]=Q>>>0>R>>>0?R:Q;a[l+N|0]=K^O&255;N=N+1|0;}while((N|0)<=(d[q]|0))}KIb(f,32,2242872,(S=i,i=i+8|0,c[S>>2]=q,S)|0);i=S}N=c[E>>2]|0;K=(c[D>>2]|0)+2|0;O=(N>>>0>K>>>0?K:N)+2|0;K=(N>>>0>O>>>0?O:N)+1|0;O=N>>>0>K>>>0?K:N;c[D>>2]=O;K=c[I>>2]|0;Q=K+(O>>>3)|0;R=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>29;Q=O+3|0;O=N>>>0>Q>>>0?Q:N;c[D>>2]=O;if((R|0)!=7){T=e[1301506+(R<<2)>>1]|0;U=e[1301504+(R<<2)>>1]|0;V=O;W=K;X=N;break}R=K+(O>>>3)|0;Q=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>20;R=O+12|0;O=N>>>0>R>>>0?R:N;c[D>>2]=O;R=K+(O>>>3)|0;M=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>20;R=O+12|0;O=N>>>0>R>>>0?R:N;c[D>>2]=O;if((Q|0)==0|(M|0)==0){B=-1094995529}else{T=M;U=Q;V=O;W=K;X=N;break}i=k;return B|0}else if((L|0)==2){c[G>>2]=1;Y=8}else if((L|0)==1){Y=8}else{KIb(f,16,2293920,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;B=-1094995529;i=k;return B|0}}while(0);if((Y|0)==8){c[g+88>>2]=2;T=C;U=u;V=H;W=J;X=F}F=d[W+(V>>>3)|0]|0;J=((V|0)<(X|0))+V|0;c[D>>2]=J;do{if((F&128>>>((V&7)>>>0)|0)==0){Z=J}else{H=J+1|0;u=(X>>>0>H>>>0?H:X)+1|0;H=X>>>0>u>>>0?u:X;c[D>>2]=H;u=W+(H>>>3)|0;C=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=H+2|0;L=X>>>0>u>>>0?u:X;c[D>>2]=L;if((C&-1073741824>>>((H&7)>>>0)|0)==0){Z=L;break}else{B=-1094995529}i=k;return B|0}}while(0);J=d[W+(Z>>>3)|0]|0;V=((Z|0)<(X|0))+Z|0;c[D>>2]=V;a:do{if((J&128>>>((Z&7)>>>0)|0)!=0){F=V+1|0;L=(X>>>0>F>>>0?F:X)+4|0;F=(X>>>0>L>>>0?L:X)+1|0;L=(X>>>0>F>>>0?F:X)+2|0;F=X>>>0>L>>>0?L:X;c[D>>2]=F;L=c[y+220>>2]|0;if((L-F|0)<1){B=-1094995529;i=k;return B|0}else{_=F}while(1){F=d[W+(_>>>3)|0]|0;H=((_|0)<(X|0))+_|0;c[D>>2]=H;if((F&128>>>((_&7)>>>0)|0)==0){break a}F=H+8|0;H=X>>>0>F>>>0?F:X;c[D>>2]=H;if((L-H|0)<1){B=-1094995529;break}else{_=H}}i=k;return B|0}}while(0);c[j>>2]=U;c[A>>2]=T;T=s+232|0;A=s+236|0;U=H4a(f,c[T>>2]|0,c[A>>2]|0)|0;if((U|0)<0){B=U;i=k;return B|0}U=c[f+856>>2]|0;j=(c[s+244>>2]|0)==0;do{if((U|0)>7){if(!j){B=r;i=k;return B|0}if((U|0)<=31){$=1;break}if((c[g+88>>2]|0)!=1|(U|0)>47){B=r}else{$=1;break}i=k;return B|0}else{$=j&1}}while(0);j=s+244|0;U=M4a(f,t,$)|0;if((U|0)<0){B=U;i=k;return B|0}U=hJb(((((c[T>>2]|0)+15&-16|0)/8|0)<<3)+24|0)|0;$=U;if((U|0)==0){B=-12;i=k;return B|0}_=g+32|0;D=g;X=g+88|0;g=s+228|0;W=U+4|0;y=U;V=s;s=p|0;Z=p+8|0;J=p+4|0;p=o|0;L=o+4|0;H=n|0;F=n+8|0;C=n+4|0;u=n+12|0;G=f+88|0;I=0;b:while(1){E=c[_+(I<<2)>>2]|0;if((I|0)==0){q=c[T>>2]|0;l=c[A>>2]|0;aa=l;ba=q;da=q;ea=l}else{if((c[G>>2]&8192|0)!=0){Y=92;break}l=c[T>>2]|0;q=c[A>>2]|0;aa=(q|0)/4|0;ba=(l|0)/4|0;da=l;ea=q}q=aa+15&-16;l=ba+15&-16;P=c[D+(I<<2)>>2]|0;do{if((c[X>>2]|0)==1){if((q|0)<=0){break}N=E<<4;K=0;O=P;while(1){Q=0;while(1){if((Q|0)>=(l|0)){break}fa=w2a(v,O+Q|0,E)|0;if((fa|0)==0){Q=Q+16|0}else{Y=43;break b}}Q=K+16|0;if((Q|0)<(q|0)){K=Q;O=O+N|0}else{break}}}else{N=c[g>>2]|0;O=c[N+(I<<2)>>2]|0;if((O|0)==0){Y=48;break b}if((c[N+68>>2]|0)!=(da|0)){Y=48;break b}if((c[N+72>>2]|0)!=(ea|0)){Y=48;break b}mrc(U|0,0,(((l|0)/8|0)<<3)+24|0)|0;if((q|0)<=0){break}N=(l|0)>0;K=E<<4;Q=E<<1;M=Q+E|0;R=M+E|0;ga=R+E|0;ha=ga+E|0;ia=ha+E|0;ja=ia+E|0;ka=ja+E|0;la=ka+E|0;ma=la+E|0;na=ma+E|0;oa=na+E|0;pa=oa+E|0;qa=pa+E|0;ra=(E<<3)-8|0;sa=0;ta=P;while(1){if(N){ua=ca(sa,E)|0;va=(sa|0)==0;wa=sa*-2|0;xa=q-sa<<1;ya=xa-32|0;za=xa-16|0;xa=0;do{Aa=ta+xa|0;Ba=c[1273371]|0;Ca=c[z>>2]|0;Da=c[x>>2]|0;Ea=c[w>>2]|0;Fa=Ea+(Ca>>>3)|0;Ga=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ca&7)>>>30;Fa=b[Ba+(Ga<<2)>>1]|0;Ha=b[Ba+(Ga<<2)+2>>1]|0;Ga=Ha<<16>>16;if(Ha<<16>>16<0){Ha=Ca+2|0;Ia=Da>>>0>Ha>>>0?Ha:Da;Ha=Ea+(Ia>>>3)|0;Ea=((je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ia&7)>>>((Ga+32|0)>>>0))+Fa|0;Ja=b[Ba+(Ea<<2)+2>>1]|0;Ka=b[Ba+(Ea<<2)>>1]|0;La=Ia}else{Ja=Ga;Ka=Fa;La=Ca}Ca=Ja+La|0;c[z>>2]=Da>>>0>Ca>>>0?Ca:Da;do{if((Ka|0)==3|(Ka|0)==0){Da=(xa|0)/8|0;Ca=Da+3|0;c[$+(Ca<<3)+4>>2]=0;c[$+(Ca<<3)>>2]=0;Ca=Da+2|0;c[$+(Ca<<3)+4>>2]=0;c[$+(Ca<<3)>>2]=0;c[W>>2]=0;c[y>>2]=0;if((Ka|0)==0){Ca=xa+ua|0;nrc(Aa|0,O+Ca|0,16)|0;Da=Ca+E|0;nrc(ta+(xa+E)|0,O+Da|0,16)|0;Ca=Da+E|0;nrc(ta+(xa+Q)|0,O+Ca|0,16)|0;Da=Ca+E|0;nrc(ta+(xa+M)|0,O+Da|0,16)|0;Ca=Da+E|0;nrc(ta+(xa+R)|0,O+Ca|0,16)|0;Da=Ca+E|0;nrc(ta+(xa+ga)|0,O+Da|0,16)|0;Ca=Da+E|0;nrc(ta+(xa+ha)|0,O+Ca|0,16)|0;Da=Ca+E|0;nrc(ta+(xa+ia)|0,O+Da|0,16)|0;Ca=Da+E|0;nrc(ta+(xa+ja)|0,O+Ca|0,16)|0;Da=Ca+E|0;nrc(ta+(xa+ka)|0,O+Da|0,16)|0;Ca=Da+E|0;nrc(ta+(xa+la)|0,O+Ca|0,16)|0;Da=Ca+E|0;nrc(ta+(xa+ma)|0,O+Da|0,16)|0;Ca=Da+E|0;nrc(ta+(xa+na)|0,O+Ca|0,16)|0;Da=Ca+E|0;nrc(ta+(xa+oa)|0,O+Da|0,16)|0;Ca=Da+E|0;nrc(ta+(xa+pa)|0,O+Ca|0,16)|0;nrc(ta+(qa+xa)|0,O+(Ca+E)|0,16)|0;break}else if((Ka|0)==3){Ma=w2a(v,Aa,E)|0;Y=88;break}else if((Ka|0)==1){Y=58;break}else if((Ka|0)==2){Y=67;break}else{break}}else if((Ka|0)==1){Y=58}else if((Ka|0)==2){Y=67}}while(0);if((Y|0)==58){Y=0;c[s>>2]=$;if(va){c[Z>>2]=$;c[J>>2]=$}else{Ca=(xa|0)/8|0;c[J>>2]=$+(Ca+2<<3);c[Z>>2]=$+(Ca+4<<3)}Ca=y2a(v,o,s)|0;if((Ca|0)!=0){Na=Ca;break b}Ca=c[p>>2]|0;Da=(xa|0)/8|0;Fa=Da+3|0;c[$+(Fa<<3)>>2]=Ca;Ga=Da+2|0;c[$+(Ga<<3)>>2]=Ca;c[y>>2]=Ca;Da=c[L>>2]|0;c[$+(Fa<<3)+4>>2]=Da;c[$+(Ga<<3)+4>>2]=Da;c[W>>2]=Da;Ga=xa*-2|0;Fa=(l-xa<<1)-32|0;if((Ca|0)<(Ga|0)){Oa=Ga}else{Oa=(Ca|0)>(Fa|0)?Fa:Ca}c[p>>2]=Oa;if((Da|0)<(wa|0)){Pa=wa}else{Pa=(Da|0)>(ya|0)?ya:Da}c[L>>2]=Pa;Da=O+((Oa>>1)+xa+(ca((Pa>>1)+sa|0,E)|0))|0;mf[c[V+((Pa<<1&2|Oa&1)<<2)>>2]&2047](Aa,Da,E,16);Ma=x2a(v,Aa,E)|0;Y=88}else if((Y|0)==67){Y=0;c[H>>2]=$;if(va){c[F>>2]=$;c[C>>2]=$}else{Da=(xa|0)/8|0;c[C>>2]=$+(Da+2<<3);c[F>>2]=$+(Da+4<<3)}Da=y2a(v,m,H)|0;if((Da|0)!=0){Na=Da;break b}c[H>>2]=m;if(va){c[F>>2]=m;Qa=m}else{Qa=$+(((xa|0)/8|0)+3<<3)|0}c[C>>2]=Qa;Da=y2a(v,$,H)|0;if((Da|0)!=0){Na=Da;break b}c[C>>2]=$;Da=(xa|0)/8|0;c[F>>2]=$+(Da+1<<3);Ca=$+(Da+2<<3)|0;Fa=y2a(v,Ca,H)|0;if((Fa|0)!=0){Na=Fa;break b}c[F>>2]=Ca;Ca=$+(Da+3<<3)|0;c[u>>2]=Ca;Da=y2a(v,Ca,H)|0;if((Da|0)!=0){Na=Da;break b}Da=xa*-2|0;Ca=(l-xa<<1)-16|0;Fa=0;Ga=Aa;while(1){Ia=c[n+(Fa<<2)>>2]|0;Ea=Fa&1;Ba=(c[Ia>>2]|0)+(Ea<<4)|0;Ha=(c[Ia+4>>2]|0)+(Fa>>1<<4)|0;if((Ba|0)<(Da|0)){Ra=Da}else{Ra=(Ba|0)>(Ca|0)?Ca:Ba}if((Ha|0)<(wa|0)){Sa=wa}else{Sa=(Ha|0)>(za|0)?za:Ha}Ha=O+((Ra>>1)+xa+(ca((Sa>>1)+sa|0,E)|0))|0;mf[c[V+16+((Sa<<1&2|Ra&1)<<2)>>2]&2047](Ga,Ha,E,8);if((Ea|0)==0){Ta=Ga+8|0}else{Ta=Ga+ra|0}Ea=Fa+1|0;if((Ea|0)<4){Fa=Ea;Ga=Ta}else{break}}Ma=x2a(v,Aa,E)|0;Y=88}if((Y|0)==88){Y=0;if((Ma|0)!=0){Na=Ma;break b}}xa=xa+16|0;}while((xa|0)<(l|0))}c[W>>2]=0;c[y>>2]=0;xa=sa+16|0;if((xa|0)<(q|0)){sa=xa;ta=ta+K|0}else{break}}}}while(0);q=I+1|0;if((q|0)<3){I=q}else{Y=92;break}}do{if((Y|0)==43){KIb(f,16,2446112,(S=i,i=i+8|0,c[S>>2]=fa,S)|0);i=S;Na=fa}else if((Y|0)==48){KIb(f,16,2356832,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;Na=-1094995529}else if((Y|0)==92){if((c[j>>2]|0)==0){WHb(c[g>>2]|0);I=YHb(c[g>>2]|0,t)|0;if((I|0)<0){Na=I;break}}c[h>>2]=1;Na=r}}while(0);kJb(U);B=Na;i=k;return B|0}function u2a(a){a=a|0;VHb((c[a+60>>2]|0)+228|0);return 0}function v2a(a){a=a|0;WHb(c[(c[a+60>>2]|0)+228>>2]|0);return}function w2a(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=i;i=i+280|0;h=g|0;j=g+256|0;c[h>>2]=e;e=a+8|0;k=a+16|0;l=a|0;a=(f|0)/4|0;m=0;n=1;o=1;p=5;a:while(1){b:do{if((p|0)==0){q=0;r=n;s=m;t=o}else{u=m;v=n;w=o;x=p;while(1){if((u|0)==(v|0)){y=x-1|0;if((y|0)==0){q=0;r=w;s=v;t=w;break b}else{z=y;A=w}}else{z=x;A=v}y=c[e>>2]|0;B=d[(c[l>>2]|0)+(y>>>3)|0]|0;c[e>>2]=((y|0)<(c[k>>2]|0))+y;if((B&128>>>((y&7)>>>0)|0)==0){q=z;r=A;s=u;t=w;break b}y=h+(u<<2)|0;c[h+(w<<2)>>2]=c[y>>2];B=w+2|0;c[h+(w+1<<2)>>2]=(c[y>>2]|0)+(((z&1|0)!=0?f:1)<<(z>>>1)+1);y=u+1|0;if((z|0)==0){q=0;r=A;s=y;t=B;break}else{u=y;v=A;w=B;x=z}}}}while(0);x=c[h+(s<<2)>>2]|0;w=1<<((q+4|0)>>>1);v=1<<((q+3|0)>>>1);u=c[5083532+(q*20|0)>>2]|0;B=c[e>>2]|0;y=c[k>>2]|0;C=c[l>>2]|0;D=C+(B>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7)>>>29;D=b[u+(E<<2)>>1]|0;F=b[u+(E<<2)+2>>1]|0;E=F<<16>>16;do{if(F<<16>>16<0){G=B+3|0;H=y>>>0>G>>>0?G:y;G=C+(H>>>3)|0;I=((je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>((E+32|0)>>>0))+D|0;G=b[u+(I<<2)>>1]|0;J=b[u+(I<<2)+2>>1]|0;I=J<<16>>16;if(!(J<<16>>16<0)){K=I;L=G;M=H;break}J=H-E|0;H=y>>>0>J>>>0?J:y;J=C+(H>>>3)|0;N=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>((I+32|0)>>>0))+G|0;K=b[u+(N<<2)+2>>1]|0;L=b[u+(N<<2)>>1]|0;M=H}else{K=E;L=D;M=B}}while(0);B=K+M|0;D=y>>>0>B>>>0?B:y;c[e>>2]=D;B=L-1|0;c:do{if((L|0)==0){E=0;do{mrc(x+((ca(a,E)|0)<<2)|0,0,w|0)|0;E=E+1|0;}while(E>>>0<v>>>0)}else{E=(B|0)>0;if(E&q>>>0>3>>>0){O=-1094995529;P=38;break a}u=c[1270913]|0;F=C+(D>>>3)|0;H=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>24;F=b[u+(H<<2)>>1]|0;N=b[u+(H<<2)+2>>1]|0;H=N<<16>>16;do{if(N<<16>>16<0){G=D+8|0;I=y>>>0>G>>>0?G:y;G=C+(I>>>3)|0;J=((je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(I&7)>>>((H+32|0)>>>0))+F|0;G=b[u+(J<<2)>>1]|0;Q=b[u+(J<<2)+2>>1]|0;J=Q<<16>>16;if(!(Q<<16>>16<0)){R=J;S=G;T=I;break}Q=I-H|0;I=y>>>0>Q>>>0?Q:y;Q=C+(I>>>3)|0;U=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(I&7)>>>((J+32|0)>>>0))+G|0;R=b[u+(U<<2)+2>>1]|0;S=b[u+(U<<2)>>1]|0;T=I}else{R=H;S=F;T=D}}while(0);F=R+T|0;H=y>>>0>F>>>0?F:y;c[e>>2]=H;if((B|0)==0){F=S&255;u=0;while(1){mrc(x+((ca(a,u)|0)<<2)|0,F|0,w|0)|0;u=u+1|0;if(!(u>>>0<v>>>0)){break c}}}u=c[1299312+(q<<2)>>2]|0;if(E){F=B<<2;N=C+(H>>>3)|0;I=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(H&7)>>>((32-F|0)>>>0);N=H+F|0;c[e>>2]=y>>>0>N>>>0?N:y;N=q+1|0;F=0;do{c[j+(F<<2)>>2]=(I>>>(((B-F<<2)-4|0)>>>0)&15|F<<4)<<N;F=F+1|0;}while((F|0)<(B|0))}F=(S-(B<<7)|0)*65537|0;N=w>>>2;I=(N|0)==0;H=u;U=0;G=x;while(1){if(I){V=H}else{if(E){J=H;Q=0;while(1){W=0;X=F;Y=F;do{Z=c[J+(c[j+(W<<2)>>2]<<2)>>2]^-2139062144;X=(Z>>>8&16711935)+X|0;Y=(Z&16711935)+Y|0;W=W+1|0;}while((W|0)<(B|0));if((X&-16711936|0)==0){_=X}else{_=(X>>>15&65537|256)+16711679&16711935&(((-2130738945-X|0)>>>15&65537|256)+16711679|X+32512)}if((Y&-16711936|0)==0){$=Y}else{$=(Y>>>15&65537|256)+16711679&16711935&(((-2130738945-Y|0)>>>15&65537|256)+16711679|Y+32512)}c[G+(Q<<2)>>2]=$|_<<8;W=Q+1|0;if(W>>>0<N>>>0){J=J+4|0;Q=W}else{break}}}else{Q=0;do{if((F&-16711936|0)==0){aa=F;ba=F}else{aa=(F>>>15&65537|256)+16711679&16711935&(((-2130738945-F|0)>>>15&65537|256)+16711679|F+32512);ba=(F>>>15&65537|256)+16711679&16711935&(((-2130738945-F|0)>>>15&65537|256)+16711679|F+32512)}c[G+(Q<<2)>>2]=aa|ba<<8;Q=Q+1|0;}while(Q>>>0<N>>>0)}V=H+(N<<2)|0}Q=U+1|0;if(Q>>>0<v>>>0){H=V;U=Q;G=G+(a<<2)|0}else{break}}}}while(0);v=s+1|0;if((v|0)<(t|0)){m=v;n=r;o=t;p=q}else{O=0;P=38;break}}if((P|0)==38){i=g;return O|0}return 0}function x2a(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;g=i;i=i+280|0;h=g|0;j=g+256|0;c[h>>2]=e;e=a+8|0;k=a|0;l=a+16|0;a=(f|0)/4|0;m=0;n=1;o=1;p=5;a:while(1){b:do{if((p|0)>0){q=m;r=n;s=o;t=p;while(1){if((q|0)==(r|0)){u=t-1|0;if((u|0)==0){v=0;w=s;x=r;y=s;break b}else{z=u;A=s}}else{z=t;A=r}u=c[e>>2]|0;B=d[(c[k>>2]|0)+(u>>>3)|0]|0;c[e>>2]=((u|0)<(c[l>>2]|0))+u;if((B&128>>>((u&7)>>>0)|0)==0){v=z;w=A;x=q;y=s;break b}u=h+(q<<2)|0;c[h+(s<<2)>>2]=c[u>>2];B=s+2|0;c[h+(s+1<<2)>>2]=(c[u>>2]|0)+(((z&1|0)!=0?f:1)<<(z>>1)+1);u=q+1|0;if((z|0)>0){q=u;r=A;s=B;t=z}else{v=z;w=A;x=u;y=B;break}}}else{v=p;w=n;x=m;y=o}}while(0);t=c[h+(x<<2)>>2]|0;s=1<<((v+4|0)/2|0);r=1<<((v+3|0)/2|0);q=c[5083676+(v*20|0)>>2]|0;B=c[e>>2]|0;u=c[l>>2]|0;C=c[k>>2]|0;D=C+(B>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7)>>>29;D=b[q+(E<<2)>>1]|0;F=b[q+(E<<2)+2>>1]|0;E=F<<16>>16;if(F<<16>>16<0){F=B+3|0;G=u>>>0>F>>>0?F:u;F=C+(G>>>3)|0;H=((je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(G&7)>>>((E+32|0)>>>0))+D|0;I=b[q+(H<<2)+2>>1]|0;J=b[q+(H<<2)>>1]|0;K=G}else{I=E;J=D;K=B}B=I+K|0;D=u>>>0>B>>>0?B:u;c[e>>2]=D;B=J-1|0;do{if((J|0)!=0){E=(B|0)>0;if(E&(v|0)>3){L=-1094995529;M=36;break a}G=c[1270949]|0;H=C+(D>>>3)|0;q=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(D&7)>>>23;H=b[G+(q<<2)>>1]|0;F=b[G+(q<<2)+2>>1]|0;q=F<<16>>16;do{if(F<<16>>16<0){N=D+9|0;O=u>>>0>N>>>0?N:u;N=C+(O>>>3)|0;P=((je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(O&7)>>>((q+32|0)>>>0))+H|0;N=b[G+(P<<2)>>1]|0;Q=b[G+(P<<2)+2>>1]|0;P=Q<<16>>16;if(!(Q<<16>>16<0)){R=P;S=N;T=O;break}Q=O-q|0;O=u>>>0>Q>>>0?Q:u;Q=C+(O>>>3)|0;U=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(O&7)>>>((P+32|0)>>>0))+N|0;R=b[G+(U<<2)+2>>1]|0;S=b[G+(U<<2)>>1]|0;T=O}else{R=q;S=H;T=D}}while(0);H=R+T|0;q=u>>>0>H>>>0?H:u;c[e>>2]=q;H=c[1301480+(v<<2)>>2]|0;if(E){G=B<<2;F=C+(q>>>3)|0;O=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(q&7)>>>((32-G|0)>>>0);F=q+G|0;c[e>>2]=u>>>0>F>>>0?F:u;F=v+1|0;G=0;do{c[j+(G<<2)>>2]=(O>>>(((B-G<<2)-4|0)>>>0)&15|G<<4)<<F;G=G+1|0;}while((G|0)<(B|0))}G=(-256-(B<<7)+S|0)*65537|0;if((r|0)<=0){break}F=(s|0)/4|0;O=(s|0)>3;q=(F|0)>1?F:1;U=H;N=0;P=t;while(1){if(O){if(E){Q=U;V=0;while(1){W=P+(V<<2)|0;X=c[W>>2]|0;Y=0;Z=(X>>>8&16711935)+G|0;_=(X&16711935)+G|0;do{X=c[Q+(c[j+(Y<<2)>>2]<<2)>>2]^-2139062144;Z=(X>>>8&16711935)+Z|0;_=(X&16711935)+_|0;Y=Y+1|0;}while((Y|0)<(B|0));if((Z&-16711936|0)==0){$=Z}else{$=(Z>>>15&65537|256)+16711679&16711935&(((-2130738945-Z|0)>>>15&65537|256)+16711679|Z+32512)}if((_&-16711936|0)==0){aa=_}else{aa=(_>>>15&65537|256)+16711679&16711935&(((-2130738945-_|0)>>>15&65537|256)+16711679|_+32512)}c[W>>2]=aa|$<<8;Y=V+1|0;if((Y|0)<(F|0)){Q=Q+4|0;V=Y}else{break}}}else{V=0;do{Q=P+(V<<2)|0;Y=c[Q>>2]|0;X=(Y>>>8&16711935)+G|0;ba=(Y&16711935)+G|0;if((X&-16711936|0)==0){ca=X}else{ca=(X>>>15&65537|256)+16711679&16711935&(((-2130738945-X|0)>>>15&65537|256)+16711679|X+32512)}if((ba&-16711936|0)==0){da=ba}else{da=(ba>>>15&65537|256)+16711679&16711935&(((-2130738945-ba|0)>>>15&65537|256)+16711679|ba+32512)}c[Q>>2]=da|ca<<8;V=V+1|0;}while((V|0)<(F|0))}ea=U+(q<<2)|0}else{ea=U}V=N+1|0;if((V|0)<(r|0)){U=ea;N=V;P=P+(a<<2)|0}else{break}}}}while(0);r=x+1|0;if((r|0)<(y|0)){m=r;n=w;o=y;p=v}else{L=0;M=36;break}}if((M|0)==36){i=g;return L|0}return 0}function y2a(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=a+8|0;h=a+16|0;i=f+4|0;j=f+8|0;k=e+4|0;l=e|0;e=c[1270877]|0;m=c[a>>2]|0;a=0;while(1){n=c[g>>2]|0;o=c[h>>2]|0;p=m+(n>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(n&7)>>>25;p=b[e+(q<<2)>>1]|0;r=b[e+(q<<2)+2>>1]|0;q=r<<16>>16;if(r<<16>>16<0){r=n+7|0;s=o>>>0>r>>>0?r:o;r=m+(s>>>3)|0;t=((je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((q+32|0)>>>0))+p|0;u=b[e+(t<<2)+2>>1]|0;v=b[e+(t<<2)>>1]|0;w=s}else{u=q;v=p;w=n}n=u+w|0;p=o>>>0>n>>>0?n:o;c[g>>2]=p;if((v|0)<0){x=-1094995529;y=21;break}if((v|0)==0){z=0}else{n=d[m+(p>>>3)|0]|0;c[g>>2]=((p|0)<(o|0))+p;z=(n&128>>>((p&7)>>>0)|0)==0?v:-v|0}p=c[f>>2]|0;if((a|0)==1){n=c[p+4>>2]|0;o=c[(c[i>>2]|0)+4>>2]|0;q=c[(c[j>>2]|0)+4>>2]|0;do{if((n|0)>(o|0)){if((q|0)<=(o|0)){A=o;break}A=(q|0)>(n|0)?n:q}else{if((o|0)<=(q|0)){A=o;break}A=(q|0)>(n|0)?q:n}}while(0);c[k>>2]=A+z<<26>>26}else{n=c[p>>2]|0;q=c[c[i>>2]>>2]|0;o=c[c[j>>2]>>2]|0;do{if((n|0)>(q|0)){if((o|0)<=(q|0)){B=q;break}B=(o|0)>(n|0)?n:o}else{if((q|0)<=(o|0)){B=q;break}B=(o|0)>(n|0)?o:n}}while(0);c[l>>2]=B+z<<26>>26}n=a+1|0;if((n|0)<2){a=n}else{x=0;y=21;break}}if((y|0)==21){return x|0}return 0}function z2a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[a+60>>2]|0;l8(b+14676|0,a);YJa(b+15920|0,c[a+88>>2]|0);d=a+804|0;c[d>>2]=UHb()|0;e=b+16128|0;c[e>>2]=UHb()|0;f=UHb()|0;c[b+16132>>2]=f;do{if((c[d>>2]|0)!=0){if((c[e>>2]|0)==0|(f|0)==0){break}g=a+120|0;h=c[g>>2]|0;c[b+16324>>2]=h;i=c[a+124>>2]|0;c[b+16328>>2]=i;j=b+16332|0;c[j>>2]=(h+15|0)/16|0;k=b+16336|0;c[k>>2]=(i+15|0)/16|0;c[b+16340>>2]=(((h|0)/4|0)+15|0)/16|0;c[b+16344>>2]=(((i|0)/4|0)+15|0)/16|0;c[b+14672>>2]=a;c[b+4>>2]=a;c[b+14172>>2]=3;i=pJb((c[g>>2]<<6)+4096|0)|0;c[b+12192>>2]=i;c[b+12208>>2]=i;c[b+12216>>2]=pJb(256)|0;c[b+12220>>2]=pJb(256)|0;c[b+16348>>2]=pJb(ca(c[k>>2]<<1,(c[j>>2]|0)+1|0)|0)|0;c[b+16352>>2]=pJb(ca(c[k>>2]<<2,(c[j>>2]|0)+1|0)|0)|0;Bqb(b);l=0;return l|0}}while(0);B2a(a)|0;l=-12;return l|0}function A2a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0;j=i;i=i+4136|0;k=j|0;l=j+4032|0;m=j+4104|0;n=j+4120|0;o=j+4128|0;p=c[e+60>>2]|0;q=p;r=c[e+804>>2]|0;s=(ca((c[p+16332>>2]|0)*9e3|0,c[p+16336>>2]|0)|0)+16384|0;t=d5a(e,f,s,(s|0)<0|0?-1:0)|0;if((t|0)<0){u=t;i=j;return u|0}if((c[e+140>>2]|0)!=6){KIb(e,16,2356800,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1;i=j;return u|0}t=p+16128|0;s=c[t>>2]|0;do{if((c[s>>2]|0)==0){w=M4a(e,s,0)|0;if((w|0)<0){u=w;i=j;return u|0}w=p+16132|0;x=M4a(e,c[w>>2]|0,0)|0;if((x|0)<0){u=x;i=j;return u|0}else{c[p+16392>>2]=hJb(c[(c[t>>2]|0)+32>>2]<<5)|0;z=c[t>>2]|0;A=w;break}}else{z=s;A=p+16132|0}}while(0);s=c[A>>2]|0;c[A>>2]=z;c[t>>2]=s;s=p+16136|0;z=f+28|0;w=c[z>>2]|0;x=(w|0)<0;B=x?0:c[f+24>>2]|0;C=x?0:w;c[p+16156>>2]=C<<3;w=p+16144|0;c[w>>2]=B;x=p+16152|0;c[x>>2]=B+C;C=p+16148|0;c[C>>2]=B;D=p+16140|0;c[D>>2]=32;E=s;c[E>>2]=0;F=c[e+136>>2]|0;if((F|0)==0){H=1}else{H=((c[e+428>>2]|0)%(F|0)|0|0)!=0?2:1}F=r+88|0;c[F>>2]=H;e=(H|0)==1;c[r+84>>2]=e&1;c[r+168>>2]=c[g+168>>2];r=c[E>>2]|0;I=c[D>>2]|0;if((I|0)>22){J=I-22|0;K=r<<22|32;L=B}else{M=B;y=je(32>>>((22-I|0)>>>0)|r<<I|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;M=(c[C>>2]|0)+4|0;c[C>>2]=M;J=I+10|0;K=32;L=M}c[E>>2]=K;c[D>>2]=J;if((J|0)>8){N=J-8|0;O=K<<8;P=L}else{M=L;y=je(K<<J|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;M=(c[C>>2]|0)+4|0;c[C>>2]=M;N=J+24|0;O=0;P=M}c[E>>2]=O;c[D>>2]=N;M=H-1|0;if((N|0)>2){Q=N-2|0;R=O<<2|M;S=P}else{H=P;y=je(M>>>((2-N|0)>>>0)|O<<N|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=(c[C>>2]|0)+4|0;c[C>>2]=H;Q=N+30|0;R=M;S=H}c[E>>2]=R;c[D>>2]=Q;do{if(e){if((Q|0)>5){T=Q-5|0;U=R<<5|2}else{H=S;y=je(2>>>((5-Q|0)>>>0)|R<<Q|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;T=Q+27|0;U=2}c[E>>2]=U;c[D>>2]=T;H=p+16324|0;M=p+16328|0;N=D5a(1301504,7,c[H>>2]|0,c[M>>2]|0)|0;O=c[E>>2]|0;P=c[D>>2]|0;if((P|0)>3){V=P-3|0;W=O<<3|N}else{J=je(N>>>((3-P|0)>>>0)|O<<P|0)|0;O=c[C>>2]|0;y=J;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;V=P+29|0;W=N}c[E>>2]=W;c[D>>2]=V;if((N|0)!=7){X=V;Y=W;break}N=c[H>>2]|0;if((V|0)>12){Z=V-12|0;_=N|W<<12}else{H=je(N>>>((12-V|0)>>>0)|W<<V|0)|0;P=c[C>>2]|0;y=H;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;Z=V+20|0;_=N}c[E>>2]=_;c[D>>2]=Z;N=c[M>>2]|0;if((Z|0)>12){$=Z-12|0;aa=N|_<<12}else{M=je(N>>>((12-Z|0)>>>0)|_<<Z|0)|0;P=c[C>>2]|0;y=M;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;$=Z+20|0;aa=N}c[E>>2]=aa;c[D>>2]=$;X=$;Y=aa}else{X=Q;Y=R}}while(0);if((X|0)>2){ba=X-2|0;da=Y<<2}else{R=je(Y<<X|0)|0;Y=c[C>>2]|0;y=R;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;ba=X+30|0;da=0}c[E>>2]=da;c[D>>2]=ba;ba=p+16324|0;da=p+16328|0;X=k|0;Y=m;R=p+14672|0;Q=p+16392|0;aa=p;$=p+4|0;Z=p+7624|0;_=p+9856|0;V=p+952|0;W=V;T=p+9848|0;U=V;V=p+7656|0;S=p+5432|0;e=p+984|0;N=p+148|0;P=p+8|0;M=p+12|0;H=p+116|0;O=p+120|0;J=p+124|0;K=p+128|0;L=p+11556|0;I=p+9992|0;r=p+11732|0;B=p+12440|0;ea=p+60|0;fa=p+9968|0;ga=p+9960|0;ha=p+9972|0;ia=p+16348|0;ja=p+12492|0;ka=p+16352|0;la=p+9216|0;ma=p+9192|0;na=p+9200|0;oa=p+9160|0;pa=p+9148|0;qa=p+11636|0;ra=p+10056|0;sa=p+14676|0;ta=p+12260|0;ua=p+14084|0;va=p+5400|0;wa=p+12480|0;xa=p+12476|0;ya=p+12496|0;za=p+12500|0;Aa=p+12504|0;Ba=p+12508|0;Ca=p+12512|0;Da=p+12516|0;Ea=p+12544|0;Fa=p+12548|0;Ga=p+12552|0;Ha=s;s=p+16300|0;Ia=a[1301747]|0;Ja=d[1301746]|0;Ka=s;La=p+16304|0;Ma=p+784|0;Na=p+16308|0;Oa=p+16312|0;Pa=m+4|0;Qa=m|0;Ra=p+14752|0;Sa=m+8|0;Ta=d[1301745]|0;Ua=p+15920|0;Va=d[1301744]|0;Wa=32-Ta|0;Xa=32-(Ia&255)|0;Ya=p+16384|0;Za=a[1301751]|0;_a=Za&255;$a=d[1301750]|0;ab=32-_a|0;bb=l+48|0;cb=p+16200|0;db=p+16188|0;eb=k+224|0;fb=p+16196|0;gb=p+16192|0;hb=p+16184|0;ib=p+16180|0;jb=k+224|0;kb=p+16224|0;lb=p+16212|0;mb=k+448|0;nb=p+16220|0;ob=p+16216|0;pb=p+16208|0;qb=p+16204|0;rb=k+448|0;sb=p+16248|0;tb=p+16236|0;ub=k+672|0;vb=p+16244|0;wb=p+16240|0;xb=p+16232|0;yb=p+16228|0;zb=k+672|0;Ab=p+16272|0;Bb=p+16260|0;Cb=k+896|0;Db=p+16268|0;Eb=p+16264|0;Fb=p+16256|0;Gb=p+16252|0;Hb=k+896|0;Ib=p+16296|0;Jb=p+16284|0;Kb=k+1120|0;Lb=p+16292|0;Mb=p+16288|0;Nb=p+16280|0;Ob=p+16276|0;Pb=k+1120|0;Qb=p+16320|0;Rb=k+1344|0;Sb=p+16316|0;p=(Za&255)>>>0<32>>>0;Za=Pb;Tb=k+1124|0;Ub=ab+32|0;Vb=k+1344|0;Wb=k+1568|0;Xb=k+1568|0;Yb=k+1792|0;Zb=k+1792|0;_b=k+2016|0;$b=k+2016|0;ac=k+2240|0;bc=k+2240|0;cc=k+2464|0;dc=k+2464|0;ec=k+2688|0;fc=(Ia&255)>>>0<32>>>0;Ia=dc;gc=k+2468|0;hc=Xa+32|0;ic=0;a:do{jc=c[g+(ic<<2)>>2]|0;kc=c[(c[A>>2]|0)+(ic<<2)>>2]|0;lc=c[t>>2]|0;mc=c[lc+(ic<<2)>>2]|0;nc=(ic|0)!=0?4:1;oc=(c[ba>>2]|0)/(nc|0)|0;pc=(c[da>>2]|0)/(nc|0)|0;nc=c[g+32+(ic<<2)>>2]|0;qc=c[lc+32+(ic<<2)>>2]|0;lc=c[R>>2]|0;rc=c[lc+804>>2]|0;sc=c[Q>>2]|0;tc=rc+168|0;uc=c[tc>>2]|0;vc=qc<<4;wc=(ca(uc,uc)|0)>>>14;uc=(oc+15|0)/16|0;xc=(pc+15|0)/16|0;yc=rc+88|0;if((c[yc>>2]|0)==2){c[$>>2]=lc;c[_>>2]=Z;c[T>>2]=W;c[U>>2]=kc;c[V>>2]=qc;c[S>>2]=qc;c[e>>2]=qc;c[N>>2]=qc;c[P>>2]=oc;c[M>>2]=pc;c[H>>2]=uc;c[O>>2]=xc;rc=uc+1|0;c[J>>2]=rc;zc=uc<<1|1;c[K>>2]=zc;c[L>>2]=1;c[I>>2]=2;c[r>>2]=c[lc+144>>2];c[B>>2]=0;c[ea>>2]=c[lc+88>>2];lc=c[tc>>2]|0;c[fa>>2]=lc;c[ga>>2]=((lc*139|0)+8192|0)>>>14;c[ha>>2]=((ca(lc,lc)|0)+64|0)>>>7;lc=q+16356+(ic<<2)|0;if((c[lc>>2]|0)==0){c[lc>>2]=pJb((ca(xc<<3,zc)|0)+8|0)|0;zc=q+16368+(ic<<2)|0;c[zc>>2]=pJb((ca(c[J>>2]|0,(xc<<2)+8|0)|0)+4|0)|0;Ac=c[J>>2]|0;Bc=zc}else{Ac=rc;Bc=q+16368+(ic<<2)|0}c[ja>>2]=c[ia>>2];rc=c[ka>>2]|0;c[la>>2]=rc;zc=rc;c[ma>>2]=zc;c[na>>2]=zc;c[oa>>2]=rc;c[pa>>2]=(c[lc>>2]|0)+8;c[qa>>2]=(c[Bc>>2]|0)+(Ac+1<<2);nrc(ra|0,sa|0,1244)|0;$qb(aa)|0;c[ta>>2]=c[(c[R>>2]|0)+248>>2];c[ua>>2]=1;if((pc|0)>0){lc=uc<<4;rc=(lc|0)>(oc|0);zc=vc-1|0;tc=(oc|0)>0;Cc=xc<<4;Dc=0;do{Ec=Dc<<4;c[va>>2]=sc+(vc-(ca(Ec,qc)|0));c[wa>>2]=Dc;Fc=0;while(1){Gc=Fc+Ec|0;if((Gc|0)>=(pc|0)){Hc=52;break}Ic=ca(Fc,qc)|0;nrc(sc+(Ic+vc)|0,jc+(ca(Gc,nc)|0)|0,oc)|0;if(rc){Gc=oc;do{Jc=Gc+Ic|0;a[sc+(Jc+vc)|0]=a[sc+(zc+Jc)|0]|0;Gc=Gc+1|0;}while((Gc|0)<(lc|0))}Gc=Fc+1|0;if((Gc|0)<16){Fc=Gc}else{break}}b:do{if((Hc|0)==52){Hc=0;if((Fc|0)<16){Kc=Fc}else{break}do{if((Kc+Ec|0)>=(Cc|0)){break b}nrc(sc+((ca(Kc,qc)|0)+vc)|0,sc+((ca(Kc-1|0,qc)|0)+vc)|0,lc)|0;Kc=Kc+1|0;}while((Kc|0)<16)}}while(0);if(tc){Ec=0;do{c[xa>>2]=Ec;NTa(aa);Fc=8>>>((c[(c[$>>2]|0)+800>>2]|0)>>>0);c[ya>>2]=(c[ya>>2]|0)+2;c[za>>2]=(c[za>>2]|0)+2;c[Aa>>2]=(c[Aa>>2]|0)+2;c[Ba>>2]=(c[Ba>>2]|0)+2;c[Ca>>2]=(c[Ca>>2]|0)+1;c[Da>>2]=(c[Da>>2]|0)+1;c[Ea>>2]=(c[Ea>>2]|0)+(Fc<<1);c[Fa>>2]=(c[Fa>>2]|0)+Fc;c[Ga>>2]=(c[Ga>>2]|0)+Fc;grb(aa,Ec,Dc);Ec=Ec+1|0;}while((Ec|0)<(uc|0))}c[ua>>2]=0;Dc=Dc+1|0;}while((Dc|0)<(xc|0))}prb(aa);qrb(aa,0,0,c[qa>>2]|0,c[L>>2]|0,2,0)}c[ua>>2]=1;if((pc|0)>0){Dc=uc<<4;tc=(Dc|0)>(oc|0);lc=vc-1|0;Cc=(oc|0)>0;zc=ca(Ta,wc)|0;rc=ca(_a,wc)|0;Ec=xc<<4;Fc=0;do{Gc=Fc<<4;c:do{if(tc){Ic=0;do{Jc=Ic+Gc|0;if((Jc|0)>=(pc|0)){Lc=Ic;Hc=68;break c}Mc=ca(Ic,qc)|0;nrc(sc+(Mc+vc)|0,jc+(ca(Jc,nc)|0)|0,oc)|0;Jc=oc;do{Nc=Jc+Mc|0;a[sc+(Nc+vc)|0]=a[sc+(lc+Nc)|0]|0;Jc=Jc+1|0;}while((Jc|0)<(Dc|0));Ic=Ic+1|0;}while((Ic|0)<16)}else{Ic=0;do{Jc=Ic+Gc|0;if((Jc|0)>=(pc|0)){Lc=Ic;Hc=68;break c}nrc(sc+((ca(Ic,qc)|0)+vc)|0,jc+(ca(Jc,nc)|0)|0,oc)|0;Ic=Ic+1|0;}while((Ic|0)<16)}}while(0);d:do{if((Hc|0)==68){Hc=0;if((Lc|0)<16){Oc=Lc}else{break}do{if((Oc+Gc|0)>=(Ec|0)){break d}nrc(sc+((ca(Oc,qc)|0)+vc)|0,sc+((ca(Oc-1|0,qc)|0)+vc)|0,Dc)|0;Oc=Oc+1|0;}while((Oc|0)<16)}}while(0);c[wa>>2]=Fc;if(Cc){Gc=ca(Fc,vc)|0;Ic=0;do{Jc=Ic<<4;Mc=Jc+Gc|0;Nc=mc+Mc|0;Pc=kc+Mc|0;mrc(Y|0,0,16)|0;Qc=c[Q>>2]|0;Rc=c[w>>2]|0;if(((c[x>>2]|0)-Rc-(32-(c[D>>2]|0)+((c[C>>2]|0)-Rc<<3)>>3)|0)<3e3){Hc=74;break a}c[xa>>2]=Ic;NTa(aa);Rc=8>>>((c[(c[$>>2]|0)+800>>2]|0)>>>0);c[ya>>2]=(c[ya>>2]|0)+2;c[za>>2]=(c[za>>2]|0)+2;c[Aa>>2]=(c[Aa>>2]|0)+2;c[Ba>>2]=(c[Ba>>2]|0)+2;c[Ca>>2]=(c[Ca>>2]|0)+1;c[Da>>2]=(c[Da>>2]|0)+1;c[Ea>>2]=(c[Ea>>2]|0)+(Rc<<1);c[Fa>>2]=(c[Fa>>2]|0)+Rc;c[Ga>>2]=(c[Ga>>2]|0)+Rc;Rc=c[yc>>2]|0;do{if((Rc|0)==1){Hc=77}else{Sc=(ca(c[J>>2]|0,Fc)|0)+Ic|0;if(!((b[(c[ja>>2]|0)+(Sc<<1)>>1]&1)==0)){Hc=77;break}c[Qa>>2]=2147483647;Tc=Rc;Uc=2147483647}}while(0);if((Hc|0)==77){Hc=0;c[cb>>2]=1792;c[db>>2]=X;c[fb>>2]=eb;c[gb>>2]=X;c[hb>>2]=32;c[ib>>2]=0;c[kb>>2]=1792;c[lb>>2]=jb;c[nb>>2]=mb;c[ob>>2]=jb;c[pb>>2]=32;c[qb>>2]=0;c[sb>>2]=1792;c[tb>>2]=rb;c[vb>>2]=ub;c[wb>>2]=rb;c[xb>>2]=32;c[yb>>2]=0;c[Ab>>2]=1792;c[Bb>>2]=zb;c[Db>>2]=Cb;c[Eb>>2]=zb;c[Fb>>2]=32;c[Gb>>2]=0;c[Ib>>2]=1792;c[Jb>>2]=Hb;c[Lb>>2]=Kb;c[Mb>>2]=Hb;c[Nb>>2]=32;c[Ob>>2]=0;c[Qb>>2]=1792;c[Na>>2]=Pb;c[Sb>>2]=Rb;c[Oa>>2]=Pb;c[La>>2]=32;c[Ka>>2]=0;if((Rc|0)==2){if(p){Vc=ab}else{y=-1;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;c[Oa>>2]=Tb;Vc=Ub}c[Ka>>2]=$a;c[La>>2]=Vc;c[Qa>>2]=rc;Wc=rc}else{Wc=0}Sc=(C2a(q,sc+(Jc+vc)|0,0,Qc,qc,5,64,wc,1)|0)+Wc|0;c[Qa>>2]=Sc;Xc=0;do{Yc=q+16180+(Xc*24|0)+4|0;Zc=c[Yc>>2]|0;_c=q+16180+(Xc*24|0)+12|0;$c=c[_c>>2]|0;c[l+(Xc<<2)>>2]=32-Zc+($c-(c[q+16180+(Xc*24|0)+8>>2]|0)<<3);ad=q+16180+(Xc*24|0)|0;do{if((Zc|0)<32){bd=c[ad>>2]<<Zc;c[ad>>2]=bd;c[_c>>2]=$c+1;a[$c]=bd>>>24;bd=c[ad>>2]|0;c[ad>>2]=bd<<8;cd=(c[Yc>>2]|0)+8|0;c[Yc>>2]=cd;if((cd|0)>=32){break}cd=bd>>>16&255;while(1){bd=c[_c>>2]|0;c[_c>>2]=bd+1;a[bd]=cd;bd=c[ad>>2]|0;c[ad>>2]=bd<<8;dd=(c[Yc>>2]|0)+8|0;c[Yc>>2]=dd;if((dd|0)<32){cd=bd>>>16&255}else{break}}}}while(0);c[Yc>>2]=32;c[ad>>2]=0;Xc=Xc+1|0;}while((Xc|0)<6);Tc=c[yc>>2]|0;Uc=Sc}e:do{if((Tc|0)==2){Xc=Rga(aa,0,0,n,o)|0;Rc=(ca(c[J>>2]|0,Fc)|0)+Ic|0;do{if((b[(c[ja>>2]|0)+(Rc<<1)>>1]&2)==0){ed=0;fd=Uc;gd=Xc+2|0}else{c[cb>>2]=1792;c[db>>2]=Vb;c[fb>>2]=Wb;c[gb>>2]=Vb;c[hb>>2]=32;c[ib>>2]=0;c[kb>>2]=1792;c[lb>>2]=Xb;c[nb>>2]=Yb;c[ob>>2]=Xb;c[pb>>2]=32;c[qb>>2]=0;c[sb>>2]=1792;c[tb>>2]=Zb;c[vb>>2]=_b;c[wb>>2]=Zb;c[xb>>2]=32;c[yb>>2]=0;c[Ab>>2]=1792;c[Bb>>2]=$b;c[Db>>2]=ac;c[Eb>>2]=$b;c[Fb>>2]=32;c[Gb>>2]=0;c[Ib>>2]=1792;c[Jb>>2]=bc;c[Lb>>2]=cc;c[Mb>>2]=bc;c[Nb>>2]=32;c[Ob>>2]=0;c[Qb>>2]=1792;c[Na>>2]=dc;c[Sb>>2]=ec;c[Oa>>2]=dc;c[La>>2]=32;c[Ka>>2]=0;if(fc){hd=Xa}else{y=-1;a[Ia]=y;y=y>>8;a[Ia+1|0]=y;y=y>>8;a[Ia+2|0]=y;y=y>>8;a[Ia+3|0]=y;c[Oa>>2]=gc;hd=hc}c[Ka>>2]=Ja;c[La>>2]=hd;c[Ma>>2]=c[s>>2];c[Ma+4>>2]=c[s+4>>2];c[Ma+8>>2]=c[s+8>>2];c[Ma+12>>2]=c[s+12>>2];c[Ma+16>>2]=c[s+16>>2];c[Ma+20>>2]=c[s+20>>2];_c=b[Xc>>1]|0;$c=_c<<16>>16;Zc=Xc+2|0;cd=b[Zc>>1]|0;bd=cd<<16>>16;Aqb(aa,$c-(c[n>>2]|0)|0,1);Aqb(aa,bd-(c[o>>2]|0)|0,1);c[s>>2]=c[Ma>>2];c[s+4>>2]=c[Ma+4>>2];c[s+8>>2]=c[Ma+8>>2];c[s+12>>2]=c[Ma+12>>2];c[s+16>>2]=c[Ma+16>>2];c[s+20>>2]=c[Ma+20>>2];dd=ca(32-(c[La>>2]|0)+((c[Oa>>2]|0)-(c[Na>>2]|0)<<3)|0,wc)|0;id=Qc+16|0;jd=kc+(($c>>1)+Mc+(ca(bd>>1,qc)|0))|0;mf[c[q+15920+((bd<<1&2|$c&1)<<2)>>2]&2047](id,jd,qc,16);jd=sc+(Jc+vc)|0;$c=dd+(C2a(q,jd,id,Nc,qc,5,64,wc,0)|0)|0;c[Pa>>2]=$c;id=($c|0)<=(Uc|0);$c=id&1;dd=(Xe[c[Ra>>2]&511](0,jd,Pc,qc,16)|0)+zc|0;c[Sa>>2]=dd;jd=c[m+($c<<2)>>2]|0;if((dd|0)<(jd|0)&_c<<16>>16==0&cd<<16>>16==0){mf[c[Ua>>2]&2047](Nc,Pc,qc,16);mrc(bb|0,0,24)|0;cd=c[E>>2]|0;_c=c[D>>2]|0;if((_c|0)>(Ta|0)){kd=_c-Ta|0;ld=cd<<Ta|Va}else{bd=je(Va>>>((Ta-_c|0)>>>0)|cd<<_c|0)|0;cd=c[C>>2]|0;y=bd;a[cd]=y;y=y>>8;a[cd+1|0]=y;y=y>>8;a[cd+2|0]=y;y=y>>8;a[cd+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;kd=Wa+_c|0;ld=Va}c[E>>2]=ld;c[D>>2]=kd;ed=2;fd=dd;gd=Zc;break}if(id){md=0}else{ed=$c;fd=jd;gd=Zc;break}while(1){Zc=q+16180+(md*24|0)+4|0;id=c[Zc>>2]|0;dd=q+16180+(md*24|0)+12|0;_c=c[dd>>2]|0;c[l+24+(md<<2)>>2]=32-id+(_c-(c[q+16180+(md*24|0)+8>>2]|0)<<3);cd=q+16180+(md*24|0)|0;do{if((id|0)<32){bd=c[cd>>2]<<id;c[cd>>2]=bd;c[dd>>2]=_c+1;a[_c]=bd>>>24;bd=c[cd>>2]|0;c[cd>>2]=bd<<8;nd=(c[Zc>>2]|0)+8|0;c[Zc>>2]=nd;if((nd|0)>=32){break}nd=bd>>>16&255;while(1){bd=c[dd>>2]|0;c[dd>>2]=bd+1;a[bd]=nd;bd=c[cd>>2]|0;c[cd>>2]=bd<<8;od=(c[Zc>>2]|0)+8|0;c[Zc>>2]=od;if((od|0)<32){nd=bd>>>16&255}else{break}}}}while(0);c[Zc>>2]=32;c[cd>>2]=0;dd=md+1|0;if((dd|0)<6){md=dd}else{pd=$c;qd=jd;break e}}}}while(0);Rc=c[K>>2]<<1;b[Xc+(Rc+3<<1)>>1]=0;b[Xc+(Rc+2<<1)>>1]=0;b[Xc+((Rc|1)<<1)>>1]=0;b[Xc+(Rc<<1)>>1]=0;b[Xc+6>>1]=0;b[Xc+4>>1]=0;b[gd>>1]=0;b[Xc>>1]=0;pd=ed;qd=fd}else{pd=0;qd=Uc}}while(0);Pc=wrc(c[Ya>>2]|0,c[Ya+4>>2]|0,qd,(qd|0)<0|0?-1:0)|0;c[Ya>>2]=Pc;c[Ya+4>>2]=G;_2(Ha,k+(pd*1344|0)+1120|0,c[l+(pd*24|0)+20>>2]|0);_2(Ha,k+(pd*1344|0)+896|0,c[l+(pd*24|0)+16>>2]|0);_2(Ha,k+(pd*1344|0)+672|0,c[l+(pd*24|0)+12>>2]|0);_2(Ha,k+(pd*1344|0)+448|0,c[l+(pd*24|0)+8>>2]|0);_2(Ha,k+(pd*1344|0)+224|0,c[l+(pd*24|0)+4>>2]|0);_2(Ha,k+(pd*1344|0)|0,c[l+(pd*24|0)>>2]|0);if((pd|0)==0){mf[c[Ua>>2]&2047](Nc,Qc,qc,16)}Ic=Ic+1|0;}while((Ic|0)<(uc|0))}c[ua>>2]=0;Fc=Fc+1|0;}while((Fc|0)<(xc|0))}ic=ic+1|0;}while((ic|0)<3);if((Hc|0)==74){KIb(c[R>>2]|0,16,2293888,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1;i=j;return u|0}v=c[D>>2]|0;R=c[w>>2]|0;Hc=c[C>>2]|0;if((32-v+(Hc-R<<3)&31|0)==0){rd=v;sd=R;td=Hc}else{ic=c[E>>2]|0;ua=v;v=R;R=Hc;while(1){if((ua|0)>1){ud=ua-1|0;vd=ic<<1;wd=v;xd=R}else{Hc=R;y=je(ic<<ua|0)|0;a[Hc]=y;y=y>>8;a[Hc+1|0]=y;y=y>>8;a[Hc+2|0]=y;y=y>>8;a[Hc+3|0]=y;Hc=(c[C>>2]|0)+4|0;c[C>>2]=Hc;ud=ua+31|0;vd=0;wd=c[w>>2]|0;xd=Hc}c[E>>2]=vd;c[D>>2]=ud;if((32-ud+(xd-wd<<3)&31|0)==0){rd=ud;sd=wd;td=xd;break}else{ic=vd;ua=ud;v=wd;R=xd}}}if((rd|0)<32){xd=c[E>>2]<<rd;c[E>>2]=xd;rd=xd>>>24&255;xd=td;while(1){c[C>>2]=xd+1;a[xd]=rd;R=c[E>>2]|0;c[E>>2]=R<<8;wd=(c[D>>2]|0)+8|0;c[D>>2]=wd;if((wd|0)>=32){break}rd=R>>>16&255;xd=c[C>>2]|0}yd=c[w>>2]|0;zd=c[C>>2]|0}else{yd=sd;zd=td}c[D>>2]=32;c[E>>2]=0;c[z>>2]=(zd-yd<<3|0)/8|0;if((c[F>>2]|0)==1){F=f+36|0;c[F>>2]=c[F>>2]|1}c[h>>2]=1;u=0;i=j;return u|0}function B2a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0.0;b=i;d=c[a+60>>2]|0;e=d+16384|0;f=ca(c[a+124>>2]|0,c[a+120>>2]|0)|0;g=(+((c[e>>2]|0)>>>0)+ +(c[e+4>>2]|0)*4294967296.0)/+(ca(f,c[a+428>>2]|0)|0);KIb(a,48,2446104,(f=i,i=i+8|0,h[f>>3]=g,f)|0);i=f;mJb(d+12192|0);mJb(d+12216|0);mJb(d+12220|0);mJb(d+16348|0);mJb(d+16352|0);mJb(d+16392|0);mJb(d+16356|0);mJb(d+16368|0);mJb(d+16360|0);mJb(d+16372|0);mJb(d+16364|0);mJb(d+16376|0);VHb(d+16128|0);VHb(d+16132|0);VHb(a+804|0);i=b;return 0}function C2a(f,g,h,j,k,l,m,n,o){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;p=i;i=i+3752|0;q=p|0;r=p+24|0;s=p+3608|0;t=2<<(l+2>>1);u=2<<(l+1>>1);v=ca(t,u)|0;w=(o|0)!=0;do{if(w){x=c[1299312+(l<<2)>>2]|0;if((u|0)>0&(t|0)>0){z=0;A=0;B=0}else{C=0;D=1298192;E=1298288;F=x;H=528064;I=0;break}while(1){J=ca(A,k)|0;K=ca(A,t)|0;L=z;M=0;N=B;do{O=a[g+(M+J)|0]|0;P=O&255;b[r+(M+K<<1)>>1]=O&255;L=(ca(P,P)|0)+L|0;N=N+P|0;M=M+1|0;}while((M|0)<(t|0));M=A+1|0;if((M|0)<(u|0)){z=L;A=M;B=N}else{C=L;D=1298192;E=1298288;F=x;H=528064;I=N;break}}}else{x=c[1301480+(l<<2)>>2]|0;if((u|0)>0&(t|0)>0){Q=0;R=0;S=0}else{C=0;D=1299336;E=1300456;F=x;H=539968;I=0;break}while(1){M=ca(R,k)|0;K=ca(R,t)|0;J=Q;P=0;O=S;do{T=P+M|0;U=(d[g+T|0]|0)-(d[h+T|0]|0)|0;b[r+(P+K<<1)>>1]=U;J=(ca(U,U)|0)+J|0;O=U+O|0;P=P+1|0;}while((P|0)<(t|0));P=R+1|0;if((P|0)<(u|0)){Q=J;R=P;S=O}else{C=J;D=1299336;E=1300456;F=x;H=539968;I=O;break}}}}while(0);S=l+3|0;R=C-((ca(I,I)|0)>>>(S>>>0))|0;C=v>>1;Q=I+C>>S;a:do{if((l|0)<4){B=f+15208|0;A=S;z=w?0:-256;x=(v|0)>0;P=0;K=R;M=Q;N=1;L=I;while(1){U=N-1|0;T=U<<4;V=r+(U<<9)|0;W=q+(U<<2)|0;X=2147483647;Y=-999;Z=-999;_=0;while(1){$=_+T|0;aa=a[H+(l*96|0)+$|0]|0;ba=F+(ca($,v)|0)|0;$=L-aa|0;da=Ee[c[B>>2]&511](ba,V,v)|0;ba=$;ea=($|0)<0|0?-1:0;fa=Erc(ba,ea,ba,ea)|0;ea=zrc(fa|0,G|0,A|0)|0;fa=xrc(da,0,ea,G)|0;ea=fa;if((ea|0)<(X|0)){fa=$+C>>S;if((fa|0)<(z|0)){ga=z}else{ga=(fa|0)>255?255:fa}c[W>>2]=_;ha=ga;ia=aa;ja=ea}else{ha=Z;ia=Y;ja=X}ea=_+1|0;if((ea|0)<16){X=ja;Y=ia;Z=ha;_=ea}else{break}}if((ha|0)==-999){break}if(x){_=ca((c[W>>2]|0)+T|0,v)|0;Z=0;do{b[r+(N<<9)+(Z<<1)>>1]=(b[r+(U<<9)+(Z<<1)>>1]|0)-(a[F+(_+Z)|0]|0);Z=Z+1|0;}while((Z|0)<(v|0))}Z=N+1|0;_=(ca((d[D+(l<<4)+(Z<<1)+1|0]|0)+(N<<2|1)+(e[E+(ha<<2)+2>>1]|0)|0,n)|0)+ja|0;U=(_|0)<(K|0);T=U?N:P;W=U?_:K;_=U?ha:M;if((Z|0)<7){P=T;K=W;M=_;N=Z;L=L-ia|0}else{ka=_;la=W;ma=T;break a}}KIb(0,0,2242840,(L=i,i=i+24|0,c[L>>2]=2201568,c[L+8>>2]=2169720,c[L+16>>2]=189,L)|0);i=L;Hd();return 0}else{ka=Q;la=R;ma=0}}while(0);do{if((la|0)<=(m|0)|(l|0)==0){na=0;oa=la;pa=32}else{if((l&1|0)==0){qa=t}else{qa=ca(u,k)|0}R=(qa|0)/2|0;Q=l-1|0;ia=(l|0)>0;if(ia){ha=Q;while(1){ja=s+(ha*24|0)|0;v=f+16180+(ha*24|0)|0;c[ja>>2]=c[v>>2];c[ja+4>>2]=c[v+4>>2];c[ja+8>>2]=c[v+8>>2];c[ja+12>>2]=c[v+12>>2];c[ja+16>>2]=c[v+16>>2];c[ja+20>>2]=c[v+20>>2];if((ha|0)>0){ha=ha-1|0}else{break}}}ha=m>>1;v=C2a(f,g,h,j,k,Q,ha,n,o)|0;ja=v+n+(C2a(f,g+R|0,h+R|0,j+R|0,k,Q,ha,n,o)|0)|0;if((ja|0)<(la|0)){na=1;oa=ja;pa=32;break}if(ia){ra=Q}else{sa=la;break}while(1){ja=f+16180+(ra*24|0)|0;ha=s+(ra*24|0)|0;c[ja>>2]=c[ha>>2];c[ja+4>>2]=c[ha+4>>2];c[ja+8>>2]=c[ha+8>>2];c[ja+12>>2]=c[ha+12>>2];c[ja+16>>2]=c[ha+16>>2];c[ja+20>>2]=c[ha+20>>2];if((ra|0)>0){ra=ra-1|0}else{na=0;oa=la;pa=32;break}}}}while(0);do{if((pa|0)==32){if((l|0)>0){la=f+16180+(l*24|0)|0;ra=c[la>>2]|0;s=f+16180+(l*24|0)+4|0;o=c[s>>2]|0;if((o|0)>1){ta=o-1|0;ua=ra<<1|na}else{n=je(na>>>((1-o|0)>>>0)|ra<<o|0)|0;ra=f+16180+(l*24|0)+12|0;h=c[ra>>2]|0;y=n;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[ra>>2]=(c[ra>>2]|0)+4;ta=o+31|0;ua=na}c[la>>2]=ua;c[s>>2]=ta}if((na|0)==0){sa=oa;break}else{va=oa}i=p;return va|0}}while(0);oa=ma+1|0;na=d[D+(l<<4)+(oa<<1)+1|0]|0;ta=d[D+(l<<4)+(oa<<1)|0]|0;oa=f+16180+(l*24|0)|0;D=c[oa>>2]|0;ua=f+16180+(l*24|0)+4|0;pa=c[ua>>2]|0;if((pa|0)>(na|0)){wa=pa-na|0;xa=D<<na|ta}else{s=je(ta>>>((na-pa|0)>>>0)|D<<pa|0)|0;D=f+16180+(l*24|0)+12|0;la=c[D>>2]|0;y=s;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;wa=32-na+pa|0;xa=ta}c[oa>>2]=xa;c[ua>>2]=wa;ta=e[E+(ka<<2)+2>>1]|0;pa=e[E+(ka<<2)>>1]|0;if((wa|0)>(ta|0)){ya=wa;za=xa<<ta|pa}else{E=je(pa>>>((ta-wa|0)>>>0)|xa<<wa|0)|0;xa=f+16180+(l*24|0)+12|0;na=c[xa>>2]|0;y=E;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[xa>>2]=(c[xa>>2]|0)+4;ya=wa+32|0;za=pa}pa=ya-ta|0;c[oa>>2]=za;c[ua>>2]=pa;if((ma|0)>0){ta=f+16180+(l*24|0)+12|0;l=0;f=za;za=pa;while(1){pa=c[q+(l<<2)>>2]|0;if((za|0)>4){Aa=za-4|0;Ba=f<<4|pa}else{ya=je(pa>>>((4-za|0)>>>0)|f<<za|0)|0;wa=c[ta>>2]|0;y=ya;a[wa]=y;y=y>>8;a[wa+1|0]=y;y=y>>8;a[wa+2|0]=y;y=y>>8;a[wa+3|0]=y;c[ta>>2]=(c[ta>>2]|0)+4;Aa=za+28|0;Ba=pa}c[oa>>2]=Ba;c[ua>>2]=Aa;pa=l+1|0;if((pa|0)<(ma|0)){l=pa;f=Ba;za=Aa}else{break}}}if((u|0)>0&(t|0)>0){Ca=0}else{va=sa;i=p;return va|0}while(1){Aa=ca(Ca,k)|0;za=ca(Ca,t)|0;Ba=0;do{f=Ba+Aa|0;a[j+f|0]=(d[g+f|0]|0)+ka-(e[r+(ma<<9)+(Ba+za<<1)>>1]|0);Ba=Ba+1|0;}while((Ba|0)<(t|0));Ba=Ca+1|0;if((Ba|0)<(u|0)){Ca=Ba}else{va=sa;break}}i=p;return va|0}function D2a(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+64|0;h=g|0;j=c[527856+(f<<2)>>2]|0;f=0;while(1){k=f<<2;l=b[e+(k<<1)>>1]|0;m=k|2;n=b[e+(m<<1)>>1]|0;o=(n+l|0)*13|0;p=(l-n|0)*13|0;n=k|1;l=b[e+(n<<1)>>1]|0;q=k|3;r=b[e+(q<<1)>>1]|0;s=(r*-17|0)+(l*7|0)|0;t=(r*7|0)+(l*17|0)|0;c[h+(k<<2)>>2]=t+o;c[h+(n<<2)>>2]=s+p;c[h+(m<<2)>>2]=p-s;c[h+(q<<2)>>2]=o-t;t=f+1|0;if((t|0)<4){f=t}else{u=0;break}}do{f=d[1298080+u|0]|0;e=c[h+(u<<2)>>2]|0;t=c[h+(u+8<<2)>>2]|0;o=(t+e|0)*13|0;q=(e-t|0)*13|0;t=c[h+(u+4<<2)>>2]|0;e=c[h+(u+12<<2)>>2]|0;s=(e*-17|0)+(t*7|0)|0;p=(e*7|0)+(t*17|0)|0;b[a+(f<<1)>>1]=(ca(p+o|0,j)|0)+524288>>20;b[a+(f+32<<1)>>1]=(ca(s+q|0,j)|0)+524288>>20;b[a+(f+128<<1)>>1]=(ca(q-s|0,j)|0)+524288>>20;b[a+(f+160<<1)>>1]=(ca(o-p|0,j)|0)+524288>>20;u=u+1|0;}while((u|0)<4);i=g;return}function E2a(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=c[527856+(h<<2)>>2]|0;if((i|0)==0){k=524288}else if((i|0)==1){l=(b[f>>1]|0)*1538|0;m=4}else{l=(ca(b[f>>1]>>3,j)|0)/2|0;m=4}if((m|0)==4){b[f>>1]=0;k=(l*169|0)+524288|0}l=0;do{m=l<<2;i=f+(m<<1)|0;h=b[i>>1]|0;n=f+((m|2)<<1)|0;o=b[n>>1]|0;p=(o+h|0)*13|0;q=(h-o|0)*13|0;o=f+((m|1)<<1)|0;h=b[o>>1]|0;r=f+((m|3)<<1)|0;m=b[r>>1]|0;s=(m*-17|0)+(h*7|0)|0;t=(m*7|0)+(h*17|0)|0;b[i>>1]=t+p;b[o>>1]=s+q;b[n>>1]=q-s;b[r>>1]=p-t;l=l+1|0;}while((l|0)<4);l=g<<1;t=g*3|0;p=0;do{r=b[f+(p<<1)>>1]|0;s=b[f+(p+8<<1)>>1]|0;q=(s+r|0)*13|0;n=(r-s|0)*13|0;s=b[f+(p+4<<1)>>1]|0;r=b[f+(p+12<<1)>>1]|0;o=(r*-17|0)+(s*7|0)|0;i=(r*7|0)+(s*17|0)|0;s=e+p|0;r=((ca(i+q|0,j)|0)+k>>20)+(d[s]|0)|0;if(r>>>0>255>>>0){u=-r>>31&255}else{u=r&255}a[s]=u;s=e+(p+g)|0;r=(d[s]|0)+((ca(o+n|0,j)|0)+k>>20)|0;if(r>>>0>255>>>0){v=-r>>31&255}else{v=r&255}a[s]=v;s=e+(p+l)|0;r=(d[s]|0)+((ca(n-o|0,j)|0)+k>>20)|0;if(r>>>0>255>>>0){w=-r>>31&255}else{w=r&255}a[s]=w;s=e+(p+t)|0;r=(d[s]|0)+((ca(q-i|0,j)|0)+k>>20)|0;if(r>>>0>255>>>0){x=-r>>31&255}else{x=r&255}a[s]=x;p=p+1|0;}while((p|0)<4);mrc(f|0,0,32)|0;return}function F2a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;e=i;i=i+8|0;f=e|0;g=c[b+60>>2]|0;h=g;j=g+572928|0;c[j>>2]=pJb(2224)|0;k=g+572936|0;c[k>>2]=pJb(2224)|0;l=pJb(2224)|0;c[g+572932>>2]=l;a:do{if((l|0)==0){m=-12}else{if((c[k>>2]|0)==0){m=-12;break}if((c[j>>2]|0)==0){m=-12;break}n=kha(b)|0;if((n|0)<0){m=n;break}n=b+88|0;YJa(g+572720|0,c[n>>2]|0);c[g+4816>>2]=c[n>>2];c[g+427416>>2]=1;c[g+6136>>2]=1;c[g+177100>>2]=3;c[b+140>>2]=c[c[(c[b+12>>2]|0)+24>>2]>>2];c[g+4760>>2]=4;c[g+4756>>2]=4;c[g+4788>>2]=1;c[g+4784>>2]=1;n=g+572940|0;c[n>>2]=1;o=g+572944|0;c[o>>2]=1;p=g+572948|0;c[p>>2]=0;q=c[b+96>>2]|0;r=c[b+100>>2]|0;s=q+r|0;b:do{if((q|0)!=0&(r|0)>8){t=q;u=0;while(1){if((grc(t,2458288,4)|0)==0){break}if((u+9|0)<(r|0)){t=t+1|0;u=u+1|0}else{break b}}u=t+4|0;v=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;if(v>>>0>(s-8-t|0)>>>0){m=-1094995529;break a}u=t+8|0;w=v<<3;x=w>>>0>2147483639>>>0|(u|0)==0;y=x?0:u;u=x?0:w;w=u+8|0;x=y;z=w>>>0>3>>>0?3:w;switch((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>5&7|0){case 0:{c[b+120>>2]=160;c[b+124>>2]=120;A=z;break};case 4:{c[b+120>>2]=704;c[b+124>>2]=576;A=z;break};case 2:{c[b+120>>2]=176;c[b+124>>2]=144;A=z;break};case 7:{x=y+(z>>>3)|0;B=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&3)>>>20;x=z+12|0;C=w>>>0>x>>>0?x:w;c[b+120>>2]=B;B=y+(C>>>3)|0;x=C+12|0;c[b+124>>2]=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>20;A=w>>>0>x>>>0?x:w;break};case 3:{c[b+120>>2]=352;c[b+124>>2]=288;A=z;break};case 5:{c[b+120>>2]=240;c[b+124>>2]=180;A=z;break};case 1:{c[b+120>>2]=128;c[b+124>>2]=96;A=z;break};case 6:{c[b+120>>2]=320;c[b+124>>2]=240;A=z;break};default:{A=z}}z=((A|0)<(w|0))+A|0;c[n>>2]=(d[y+(A>>>3)|0]|0)<<(A&7)>>>7&1;c[o>>2]=(d[y+(z>>>3)|0]|0)<<(z&7)>>>7&1;x=z+1+((z|0)<(w|0))|0;z=(w>>>0>x>>>0?x:w)+1|0;x=(w>>>0>z>>>0?z:w)+1|0;z=(w>>>0>x>>>0?x:w)+1|0;x=w>>>0>z>>>0?z:w;z=(d[y+(x>>>3)|0]|0)<<(x&7)>>>7&1;c[g+4808>>2]=z;C=x+1+((x|0)<(w|0))|0;x=w>>>0>C>>>0?C:w;if((u-x|0)<1){m=-1094995529;break a}else{D=x}while(1){E=((D|0)<(w|0))+D|0;if(((d[y+(D>>>3)|0]|0)&128>>>((D&7)>>>0)|0)==0){break}x=E+8|0;C=w>>>0>x>>>0?x:w;if((u-C|0)<1){m=-1094995529;break a}else{D=C}}u=((E|0)<(w|0))+E|0;c[p>>2]=(d[y+(E>>>3)|0]|0)<<(E&7)>>>7&1;c[b+176>>2]=z^1;if((c[p>>2]|0)==0){break}C=y+(u>>>3)|0;x=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(u&7);if((x&-1434451968|0)==0){C=1;B=u;F=x;while(1){G=F>>>24;H=a[1369728+G|0]|0;I=H&255;J=((H&255)>>>0>8>>>0?8:I)+B|0;K=w>>>0>J>>>0;L=K?J:w;if(!(H<<24>>24==9)){M=25;break}H=d[1369984+G|0]|0|C<<4;if(!(H>>>0<134217728>>>0)){N=H;break}J=y+(L>>>3)|0;O=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7);if(K){C=H;B=L;F=O}else{N=H;break}}if((M|0)==25){N=d[1369984+G|0]|0|C<<(I-1>>1)}P=N-1|0;Q=L}else{F=x>>>24;B=(d[1369728+F|0]|0)+u|0;P=d[1369216+F|0]|0;Q=w>>>0>B>>>0?B:w}B=y+(Q>>>3)|0;F=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(Q&7);if((F&-1434451968|0)==0){B=1;z=Q;H=F;while(1){R=H>>>24;O=a[1369728+R|0]|0;S=O&255;K=((O&255)>>>0>8>>>0?8:S)+z|0;J=w>>>0>K>>>0;T=J?K:w;if(!(O<<24>>24==9)){M=32;break}O=d[1369984+R|0]|0|B<<4;if(!(O>>>0<134217728>>>0)){U=O;break}K=y+(T>>>3)|0;V=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(T&7);if(J){B=O;z=T;H=V}else{U=O;break}}if((M|0)==32){U=d[1369984+R|0]|0|B<<(S-1>>1)}W=U-1|0;X=T}else{H=F>>>24;z=(d[1369728+H|0]|0)+Q|0;W=d[1369216+H|0]|0;X=w>>>0>z>>>0?z:w}z=y+(X>>>3)|0;H=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(X&7);if((H&-1434451968|0)==0){z=1;u=X;x=H;while(1){Y=x>>>24;C=a[1369728+Y|0]|0;Z=C&255;O=((C&255)>>>0>8>>>0?8:Z)+u|0;V=w>>>0>O>>>0;_=V?O:w;if(!(C<<24>>24==9)){M=39;break}C=d[1369984+Y|0]|0|z<<4;if(!(C>>>0<134217728>>>0)){$=C;break}O=y+(_>>>3)|0;J=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(_&7);if(V){z=C;u=_;x=J}else{$=C;break}}if((M|0)==39){$=d[1369984+Y|0]|0|z<<(Z-1>>1)}aa=$-1|0;ba=_}else{x=H>>>24;u=(d[1369728+x|0]|0)+X|0;aa=d[1369216+x|0]|0;ba=w>>>0>u>>>0?u:w}u=y+(ba>>>3)|0;x=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(ba&7)>>>24;u=ba+8|0;F=w>>>0>u>>>0?u:w;u=y+(F>>>3)|0;B=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(F&7)>>>30;u=F+2|0;F=w>>>0>u>>>0?u:w;u=y+(F>>>3)|0;C=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(F&7);if((C&-1434451968|0)==0){u=1;J=F;V=C;while(1){da=V>>>24;O=a[1369728+da|0]|0;ea=O&255;K=((O&255)>>>0>8>>>0?8:ea)+J|0;fa=w>>>0>K>>>0;ga=fa?K:w;if(!(O<<24>>24==9)){M=46;break}O=d[1369984+da|0]|0|u<<4;if(!(O>>>0<134217728>>>0)){ha=O;break}K=y+(ga>>>3)|0;ia=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(ga&7);if(fa){u=O;J=ga;V=ia}else{ha=O;break}}if((M|0)==46){ha=d[1369984+da|0]|0|u<<(ea-1>>1)}ja=ha-1|0;ka=ga}else{V=C>>>24;J=(d[1369728+V|0]|0)+F|0;ja=d[1369216+V|0]|0;ka=w>>>0>J>>>0?J:w}J=ca(P<<2,W)|0;c[f>>2]=J;V=ka+7>>3;if((W|0)==0){m=-1;break a}y=P;H=0<<2|y>>>30;z=0;if(H>>>0>z>>>0|H>>>0==z>>>0&(y<<2|0>>>30)>>>0>(4294967295/(W>>>0)|0)>>>0){m=-1;break a}y=hJb(J)|0;J=b;KIb(J,48,2441312,(la=i,i=i+16|0,c[la>>2]=P,c[la+8>>2]=W,la)|0);i=la;KIb(J,48,2429584,(la=i,i=i+40|0,c[la>>2]=aa,c[la+8>>2]=x,c[la+16>>2]=B,c[la+24>>2]=ja,c[la+32>>2]=V,la)|0);i=la;if((Aqc(y,f,t+(V+8)|0,v-V|0)|0)==0){V=(Ltb(y,c[f>>2]|0,0)|0)&65535;z=V<<16|V;c[g+572956>>2]=z;KIb(J,48,2410152,(la=i,i=i+8|0,c[la>>2]=z,la)|0);i=la;kJb(y);break}else{KIb(J,16,2419128,(la=i,i=i+1|0,i=i+7&-8,c[la>>2]=0,la)|0);i=la;kJb(y);m=-1;break a}}}while(0);p=c[b+120>>2]|0;c[g+4768>>2]=p;o=c[b+124>>2]|0;c[g+4772>>2]=o;n=(p+15|0)/16|0;c[g+427400>>2]=n;p=(o+15|0)/16|0;c[g+427396>>2]=p;c[g+427404>>2]=n+1;c[g+427408>>2]=ca(p,n)|0;c[g+6108>>2]=n<<2;c[g+572976>>2]=n<<4;c[g+572980>>2]=p<<4;p=fha(h)|0;if((p|0)<0){KIb(b,16,2402472,(la=i,i=i+1|0,i=i+7&-8,c[la>>2]=0,la)|0);i=la;m=p;break}else{ma=0;i=e;return ma|0}}}while(0);H2a(b)|0;ma=m;i=e;return ma|0}function G2a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0;h=i;j=c[b+60>>2]|0;k=j;l=j;m=c[g+28>>2]|0;if((m|0)==0){n=c[j+572932>>2]|0;if((c[n>>2]|0)==0){o=0;i=h;return o|0}if((c[j+4808>>2]|0)!=0){o=0;i=h;return o|0}p=j+572984|0;if((c[p>>2]|0)!=0){o=0;i=h;return o|0}q=YHb(e,n|0)|0;if((q|0)<0){o=q;i=h;return o|0}c[p>>2]=1;c[f>>2]=1;o=0;i=h;return o|0}p=j+427412|0;c[p>>2]=0;q=j+427380|0;c[q>>2]=0;n=j+427376|0;c[n>>2]=0;do{if((c[j+572956>>2]|0)==0){r=g+24|0}else{s=j+572960|0;t=s;A4a(s,j+572964|0,m);s=c[t>>2]|0;if((s|0)==0){o=-12;i=h;return o|0}else{nrc(s|0,c[g+24>>2]|0,m)|0;r=t;break}}}while(0);g=c[r>>2]|0;r=j+1088|0;t=m<<3;s=t>>>0>2147483639>>>0|(g|0)==0;u=s?0:g;g=s?0:t;s=r;c[s>>2]=u;v=j+1100|0;c[v>>2]=g;w=j+1104|0;c[w>>2]=g+8;c[j+1092>>2]=u+(g>>3);g=j+1096|0;c[g>>2]=0;if((I2a(b)|0)!=0){o=-1;i=h;return o|0}u=c[j+177076>>2]|0;x=j+572392|0;c[x>>2]=u;if((u|0)!=3){u=j+572936|0;z=c[u>>2]|0;A=j+572932|0;c[u>>2]=c[A>>2];c[A>>2]=z}z=j+572928|0;WHb(c[z>>2]|0);A=c[z>>2]|0;c[A+88>>2]=c[x>>2];c[A+84>>2]=(c[x>>2]|0)==1;u=J2a(b,A)|0;if((u|0)<0){o=u;i=h;return o|0}c[j+2524>>2]=c[z>>2];u=j+2528|0;A=u;WHb(A);B=c[z>>2]|0;nrc(u|0,B|0,2224)|0;u=YHb(A,B|0)|0;if((u|0)<0){o=u;i=h;return o|0}B=j+4776|0;A=j+5716|0;C=0;do{D=(d[602048+C|0]|0)-12|0;E=D<<2&28;F=D>>3;c[A+(C<<2)>>2]=E+(ca(c[B>>2]<<2,F)|0);c[A+(C+48<<2)>>2]=E+(ca(c[B>>2]<<3,F)|0);C=C+1|0;}while((C|0)<16);C=j+4780|0;B=0;do{F=(d[602048+B|0]|0)-12|0;E=F<<2&28;D=F>>3;F=E+(ca(c[C>>2]<<2,D)|0)|0;c[A+(B+32<<2)>>2]=F;c[A+(B+16<<2)>>2]=F;F=E+(ca(c[C>>2]<<3,D)|0)|0;c[A+(B+80<<2)>>2]=F;c[A+(B+64<<2)>>2]=F;B=B+1|0;}while((B|0)<16);B=c[x>>2]|0;do{if((B|0)==1){G=u}else{A=j+572936|0;do{if((c[c[A>>2]>>2]|0)==0){KIb(b,16,2446040,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;WHb(c[A>>2]|0);C=J2a(b,c[A>>2]|0)|0;if((C|0)<0){o=C;i=h;return o|0}else{F=c[A>>2]|0;D=b+124|0;mrc(c[F>>2]|0,0,ca(c[F+32>>2]|0,c[D>>2]|0)|0)|0;F=c[A>>2]|0;mrc(c[F+4>>2]|0,-128|0,ca(c[F+36>>2]|0,(c[D>>2]|0)/2|0)|0)|0;F=c[A>>2]|0;mrc(c[F+8>>2]|0,-128|0,ca(c[F+40>>2]|0,(c[D>>2]|0)/2|0)|0)|0;I=C;J=c[x>>2]|0;break}}else{I=u;J=B}}while(0);if((J|0)!=3){G=I;break}A=j+572932|0;if((c[c[A>>2]>>2]|0)!=0){G=I;break}KIb(b,16,2446040,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;WHb(c[A>>2]|0);C=J2a(b,c[A>>2]|0)|0;if((C|0)<0){o=C;i=h;return o|0}else{D=c[A>>2]|0;F=b+124|0;mrc(c[D>>2]|0,0,ca(c[D+32>>2]|0,c[F>>2]|0)|0)|0;D=c[A>>2]|0;mrc(c[D+4>>2]|0,-128|0,ca(c[D+36>>2]|0,(c[F>>2]|0)/2|0)|0)|0;D=c[A>>2]|0;mrc(c[D+8>>2]|0,-128|0,ca(c[D+40>>2]|0,(c[F>>2]|0)/2|0)|0)|0;G=C;break}}}while(0);if((c[b+688>>2]&1|0)!=0){I=c[j>>2]|0;J=(BLb(c[x>>2]|0)|0)<<24>>24;B=c[j+572940>>2]|0;u=c[j+572944>>2]|0;C=c[j+572968>>2]|0;F=c[j+4792>>2]|0;D=c[j+177068>>2]|0;KIb(I,48,2356744,(H=i,i=i+48|0,c[H>>2]=J,c[H+8>>2]=B,c[H+16>>2]=u,c[H+24>>2]=C,c[H+32>>2]=F,c[H+40>>2]=D,H)|0);i=H}D=c[b+856>>2]|0;do{if((D|0)>7){F=c[x>>2]|0;if((F|0)==3){o=0;i=h;return o|0}if((D|0)<=31){break}if((F|0)!=1|(D|0)>47){o=0}else{break}i=h;return o|0}}while(0);D=j+572972|0;F=(c[x>>2]|0)==3;do{if((c[D>>2]|0)==0){if(!F){K=41;break}C=(c[j+177068>>2]|0)-(c[j+428676>>2]|0)|0;u=(C|0)<0?C+256|0:C;c[j+428668>>2]=u;if((u|0)!=0){if((u|0)<(c[j+428672>>2]|0)){break}}KIb(c[j>>2]|0,16,2293856,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;o=-1;i=h;return o|0}else{if(F){o=0;i=h;return o|0}else{c[D>>2]=0;K=41;break}}}while(0);do{if((K|0)==41){D=j+428656|0;F=c[D>>2]|0;c[j+428676>>2]=F;u=c[j+177068>>2]|0;c[D>>2]=u;D=u-F|0;F=j+428672|0;c[F>>2]=D;if((D|0)>=0){break}c[F>>2]=D+256}}while(0);mrc(j+5643|0,1,5)|0;a[j+5648|0]=-2;mrc(j+5651|0,1,5)|0;a[j+5656|0]=-2;mrc(j+5659|0,1,5)|0;a[j+5664|0]=-2;mrc(j+5667|0,1,5)|0;mrc(j+5683|0,1,5)|0;a[j+5688|0]=-2;mrc(j+5691|0,1,5)|0;a[j+5696|0]=-2;mrc(j+5699|0,1,5)|0;a[j+5704|0]=-2;mrc(j+5707|0,1,5)|0;c[q>>2]=0;D=j+427396|0;F=c[D>>2]|0;a:do{if((F|0)>0){u=j+427400|0;C=j+572936|0;B=j+177100|0;J=j+4808|0;I=j+427404|0;A=j+6108|0;E=j+5164|0;L=j+5172|0;M=j+5168|0;N=j+572932|0;O=j+4052|0;P=j+4056|0;Q=j+4928|0;R=j+6104|0;S=j+5192|0;T=j+4792|0;U=j+424272|0;V=U;W=r;X=j+426564|0;Y=j+4064|0;Z=j+4832|0;_=j+572968|0;$=j+572944|0;aa=j+572940|0;ba=j+4836|0;da=j;ea=j+4888|0;fa=j+4899|0;ga=j+4907|0;ha=j+4915|0;ia=j+4923|0;ja=j+4892|0;ka=j+4893|0;la=j+4894|0;ma=j+4895|0;na=j+4924|0;oa=j+4919|0;pa=j+4911|0;qa=j+4903|0;ra=j+4900|0;sa=j+4908|0;ta=j+4916|0;ua=j+572952|0;va=0;b:while(1){c[n>>2]=0;if((c[u>>2]|0)>0){wa=0;xa=va;while(1){c[p>>2]=(ca(c[I>>2]|0,xa)|0)+wa;ya=c[g>>2]|0;do{if((ya+7|0)<(c[v>>2]|0)){za=ya}else{Aa=ya&7;if((Aa|0)!=0){Ba=(c[s>>2]|0)+(ya>>>3)|0;if(((je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<Aa>>>((32-(-ya&7)|0)>>>0)|0)!=0){za=ya;break}}Aa=c[ua>>2]|0;Ba=c[w>>2]|0;c[g>>2]=Ba>>>0>Aa>>>0?Aa:Ba;c[v>>2]=t;if((I2a(b)|0)!=0){o=-1;K=212;break b}za=c[g>>2]|0}}while(0);ya=c[w>>2]|0;Ba=c[s>>2]|0;Aa=Ba+(za>>>3)|0;Ca=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(za&7);if((Ca&-1434451968|0)==0){Aa=1;Da=za;Ea=Ca;while(1){Fa=Ea>>>24;Ga=a[1369728+Fa|0]|0;Ha=Ga&255;Ia=((Ga&255)>>>0>8>>>0?8:Ha)+Da|0;Ja=ya>>>0>Ia>>>0;Ka=Ja?Ia:ya;if(!(Ga<<24>>24==9)){K=53;break}Ga=d[1369984+Fa|0]|Aa<<4;if(!(Ga>>>0<134217728>>>0)){La=Ga;break}Ia=Ba+(Ka>>>3)|0;Ma=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ka&7);if(Ja){Aa=Ga;Da=Ka;Ea=Ma}else{La=Ga;break}}if((K|0)==53){K=0;La=d[1369984+Fa|0]|Aa<<(Ha-1>>1)}c[g>>2]=Ka;Na=La-1|0;Oa=Ka}else{Ea=Ca>>>24;Da=(d[1369728+Ea|0]|0)+za|0;Ga=ya>>>0>Da>>>0?Da:ya;c[g>>2]=Ga;Na=d[1369216+Ea|0]|0;Oa=Ga}Ga=c[x>>2]|0;if((Ga|0)==3){Pa=Na>>>0>3>>>0?Na+4|0:Na}else if((Ga|0)==1){Pa=Na+8|0}else{Pa=Na}if(Pa>>>0>33>>>0){break b}Ea=c[p>>2]|0;Da=c[n>>2]|0;Ma=c[q>>2]|0;Ja=(ca(Ma<<2,c[A>>2]|0)|0)+(Da<<2)|0;c[E>>2]=(Ma|0)==0?13311:65535;c[L>>2]=(Da|0)==0?24415:65535;c[M>>2]=65535;Ia=(Pa|0)==0;c:do{if(Ia){do{if((Ga|0)!=2){Qa=c[(c[(c[N>>2]|0)+1536>>2]|0)+(Ea<<2)>>2]|0;if((Qa|0)==-1){break}Ra=Qa>>>0>6>>>0?6:Qa;if((L2a(k,Ra,4,0,0)|0)<0){break b}if((L2a(k,Ra,4,1,1)|0)<0){break b}else{Sa=8;Ta=0;K=132;break c}}}while(0);K2a(k,Da<<4,Ma<<4,16,16,0,0,0,0,0,0);Ra=c[x>>2]|0;if((Ra|0)!=3){Ua=2048;Va=0;Wa=Ra;K=128;break}K2a(k,c[n>>2]<<4,c[q>>2]<<4,16,16,0,0,0,0,1,1);Xa=2048;Ya=0;K=127}else{if(!(Pa>>>0<8>>>0)){Ra=(Pa|0)==8;if(!((Pa|0)==33|(Pa|0)==8)){Qa=Pa-8|0;Za=d[1077770+(Qa<<2)|0]|0;_a=dha(l,Za>>>1^1^-(Za&1)&3,0)|0;c[ba>>2]=_a;if((_a|0)<0){KIb(c[da>>2]|0,16,2637432,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;if((c[ba>>2]|0)==0){break}else{break b}}else{Xa=2;Ya=d[1077771+(Qa<<2)|0]|0;K=127;break}}mrc(ea|0,-1|0,40)|0;if(Ra){do{if((Da|0)>0){Qa=(c[R>>2]|0)+(Ea-1<<2)|0;_a=c[Q>>2]|0;Za=a[_a+((c[Qa>>2]|0)+6)|0]|0;a[fa]=Za;a[ga]=a[_a+((c[Qa>>2]|0)+5)|0]|0;a[ha]=a[_a+((c[Qa>>2]|0)+4)|0]|0;a[ia]=a[_a+((c[Qa>>2]|0)+3)|0]|0;if(!(Za<<24>>24==-1)){break}c[L>>2]=24415}}while(0);do{if((Ma|0)>0){Za=(c[R>>2]|0)+(Ea-(c[I>>2]|0)<<2)|0;Qa=c[Q>>2]|0;_a=a[Qa+(c[Za>>2]|0)|0]|0;a[ja]=_a;a[ka]=a[Qa+((c[Za>>2]|0)+1)|0]|0;a[la]=a[Qa+((c[Za>>2]|0)+2)|0]|0;a[ma]=a[Qa+((c[Za>>2]|0)+3)|0]|0;if(!(_a<<24>>24==-1)){$a=0;break}c[E>>2]=13311;$a=0}else{$a=0}}while(0);while(1){if(($a|0)>=16){break}_a=c[g>>2]|0;Za=c[w>>2]|0;Qa=c[s>>2]|0;ab=Qa+(_a>>>3)|0;bb=(je(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(_a&7);if((bb&-1434451968|0)==0){ab=1;cb=_a;db=bb;while(1){eb=db>>>24;fb=a[1369728+eb|0]|0;gb=fb&255;hb=((fb&255)>>>0>8>>>0?8:gb)+cb|0;ib=Za>>>0>hb>>>0;jb=ib?hb:Za;if(!(fb<<24>>24==9)){K=112;break}fb=d[1369984+eb|0]|ab<<4;if(!(fb>>>0<134217728>>>0)){kb=fb;break}hb=Qa+(jb>>>3)|0;lb=(je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(jb&7);if(ib){ab=fb;cb=jb;db=lb}else{kb=fb;break}}if((K|0)==112){K=0;kb=d[1369984+eb|0]|ab<<(gb-1>>1)}c[g>>2]=jb;mb=kb-1|0}else{db=bb>>>24;cb=(d[1369728+db|0]|0)+_a|0;c[g>>2]=Za>>>0>cb>>>0?cb:Za;mb=d[1369216+db|0]|0}if(mb>>>0>24>>>0){K=117;break b}db=d[602048+$a|0]|0;cb=a[(d[527800+(mb<<1)|0]|0)+(527616+(((a[db-8+(k+4888)|0]|0)+1|0)*30|0)+(((a[db-1+(k+4888)|0]|0)+1|0)*5|0))|0]|0;a[k+4888+db|0]=cb;Qa=a[(d[527801+(mb<<1)|0]|0)+(527616+(((a[db-7+(k+4888)|0]|0)+1|0)*30|0)+(((cb<<24>>24)+1|0)*5|0))|0]|0;a[db+1+(k+4888)|0]=Qa;if(cb<<24>>24==-1|Qa<<24>>24==-1){K=119;break b}else{$a=$a+2|0}}nb=c[p>>2]|0;ob=c[na>>2]|0}else{y=33686018;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;y=33686018;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;y=33686018;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;y=33686018;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;nb=Ea;ob=33686018}Qa=c[Q>>2]|0;cb=c[(c[R>>2]|0)+(nb<<2)>>2]|0;c[Qa+cb>>2]=ob;a[Qa+(cb+4)|0]=a[oa]|0;a[Qa+(cb+5)|0]=a[pa]|0;a[Qa+(cb+6)|0]=a[qa]|0;if(Ra){cha(l)|0;c[E>>2]=(c[q>>2]|0)==0?13311:65535;pb=(c[n>>2]|0)==0?24415:65535}else{y=185273099;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;y=185273099;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;y=185273099;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;y=185273099;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[E>>2]=13311;pb=24415}c[L>>2]=pb;Xa=1;Ya=0;K=127;break}cb=c[$>>2]|0;Qa=c[aa>>2]|0;if((cb|0)==0){qb=Oa;K=71}else{db=d[Ba+(Oa>>>3)|0]<<(Oa&7);fb=((Oa|0)<(ya|0))+Oa|0;c[g>>2]=fb;if((Qa|0)==(db>>>7&1^1|0)){rb=3}else{qb=fb;K=71}}do{if((K|0)==71){K=0;if((Qa|0)!=0){fb=d[Ba+(qb>>>3)|0]<<(qb&7);c[g>>2]=((qb|0)<(ya|0))+qb;if((cb|0)==(fb>>>7&1^1|0)){rb=2;break}}rb=1}}while(0);cb=Ea-1|0;Qa=Ja-1|0;Ra=Ja+4|0;fb=0;db=Ga;while(1){if((fb|0)>=2){sb=db;break}do{if((c[n>>2]|0)>0){if((a[(c[Q>>2]|0)+((c[(c[R>>2]|0)+(cb<<2)>>2]|0)+6)|0]|0)==-1){K=77;break}lb=k+4052+(fb<<2)|0;c[k+5312+(fb*160|0)+44>>2]=c[(c[lb>>2]|0)+(Qa<<2)>>2];ib=c[A>>2]|0;c[k+5312+(fb*160|0)+76>>2]=c[(c[lb>>2]|0)+(ib+Qa<<2)>>2];c[k+5312+(fb*160|0)+108>>2]=c[(c[lb>>2]|0)+((ib<<1)+Qa<<2)>>2];c[k+5312+(fb*160|0)+140>>2]=c[(c[lb>>2]|0)+((ib*3|0)+Qa<<2)>>2]}else{K=77}}while(0);if((K|0)==77){K=0;c[k+5312+(fb*160|0)+44>>2]=0;c[k+5312+(fb*160|0)+76>>2]=0;c[k+5312+(fb*160|0)+108>>2]=0;c[k+5312+(fb*160|0)+140>>2]=0}do{if((c[q>>2]|0)>0){Za=k+4052+(fb<<2)|0;nrc(k+5312+(fb*160|0)+16|0,(c[Za>>2]|0)+(Ja-(c[A>>2]|0)<<2)|0,16)|0;_a=c[R>>2]|0;mrc(k+5632+(fb*40|0)+4|0,((a[(c[Q>>2]|0)+(c[_a+(Ea-(c[I>>2]|0)<<2)>>2]|0)|0]|0)==-1?-2:1)|0,4)|0;if((c[n>>2]|0)<((c[u>>2]|0)-1|0)){c[k+5312+(fb*160|0)+32>>2]=c[(c[Za>>2]|0)+(Ra-(c[A>>2]|0)<<2)>>2];bb=Ea-(c[I>>2]|0)|0;ab=c[Q>>2]|0;if((a[ab+((c[_a+(bb+1<<2)>>2]|0)+6)|0]|0)==-1){tb=-2}else{tb=(a[ab+(c[_a+(bb<<2)>>2]|0)|0]|0)==-1?-2:1}a[k+5632+(fb*40|0)+8|0]=tb}else{a[k+5632+(fb*40|0)+8|0]=-2}if((c[n>>2]|0)>0){c[k+5312+(fb*160|0)+12>>2]=c[(c[Za>>2]|0)+(Qa-(c[A>>2]|0)<<2)>>2];a[k+5632+(fb*40|0)+3|0]=(a[(c[Q>>2]|0)+((c[(c[R>>2]|0)+(cb-(c[I>>2]|0)<<2)>>2]|0)+3)|0]|0)==-1?-2:1;break}else{a[k+5632+(fb*40|0)+3|0]=-2;break}}else{Za=k+5632+(fb*40|0)+3|0;bb=Za|0;y=-16843010;a[bb]=y;y=y>>8;a[bb+1|0]=y;y=y>>8;a[bb+2|0]=y;y=y>>8;a[bb+3|0]=y;bb=Za+4|0;y=-16843010;a[bb]=y;y=y>>8;a[bb+1|0]=y;y=y>>8;a[bb+2|0]=y;y=y>>8;a[bb+3|0]=y}}while(0);bb=c[x>>2]|0;if((bb|0)==3){fb=fb+1|0;db=3}else{sb=bb;break}}if((sb|0)==2){if((L2a(k,Pa-1|0,rb,0,0)|0)<0){break b}else{Sa=8;Ta=0;K=132;break}}do{if((Pa|0)==2){mrc((c[O>>2]|0)+(Ja<<2)|0,0,16)|0;mrc((c[O>>2]|0)+((c[A>>2]|0)+Ja<<2)|0,0,16)|0;mrc((c[O>>2]|0)+((c[A>>2]<<1)+Ja<<2)|0,0,16)|0;mrc((c[O>>2]|0)+(((c[A>>2]|0)*3|0)+Ja<<2)|0,0,16)|0}else{if((L2a(k,0,rb,0,0)|0)<0){break b}if((Pa|0)!=1){break}mrc((c[P>>2]|0)+(Ja<<2)|0,0,16)|0;mrc((c[P>>2]|0)+((c[A>>2]|0)+Ja<<2)|0,0,16)|0;mrc((c[P>>2]|0)+((c[A>>2]<<1)+Ja<<2)|0,0,16)|0;mrc((c[P>>2]|0)+(((c[A>>2]|0)*3|0)+Ja<<2)|0,0,16)|0;Sa=8;Ta=0;K=132;break c}}while(0);if((L2a(k,0,rb,1,(Pa|0)==3|0)|0)<0){break b}else{Sa=8;Ta=0;K=132}}}while(0);if((K|0)==127){K=0;Ua=Xa;Va=Ya;Wa=c[x>>2]|0;K=128}if((K|0)==128){K=0;do{if((Wa|0)!=1){mrc((c[O>>2]|0)+(Ja<<2)|0,0,16)|0;mrc((c[O>>2]|0)+((c[A>>2]|0)+Ja<<2)|0,0,16)|0;mrc((c[O>>2]|0)+((c[A>>2]<<1)+Ja<<2)|0,0,16)|0;mrc((c[O>>2]|0)+(((c[A>>2]|0)*3|0)+Ja<<2)|0,0,16)|0;if((c[x>>2]|0)!=3){break}mrc((c[P>>2]|0)+(Ja<<2)|0,0,16)|0;mrc((c[P>>2]|0)+((c[A>>2]|0)+Ja<<2)|0,0,16)|0;mrc((c[P>>2]|0)+((c[A>>2]<<1)+Ja<<2)|0,0,16)|0;mrc((c[P>>2]|0)+(((c[A>>2]|0)*3|0)+Ja<<2)|0,0,16)|0}}while(0);Ja=Ua&1;if((Ja|0)==0){Sa=Ua;Ta=Va;K=132}else{ub=Ua;vb=Va;wb=Ja;K=133}}if((K|0)==132){K=0;Ja=(c[Q>>2]|0)+(c[(c[R>>2]|0)+(Ea<<2)>>2]|0)|0;Ga=Ja|0;y=33686018;a[Ga]=y;y=y>>8;a[Ga+1|0]=y;y=y>>8;a[Ga+2|0]=y;y=y>>8;a[Ga+3|0]=y;Ga=Ja+4|0;y=33686018;a[Ga]=y;y=y>>8;a[Ga+1|0]=y;y=y>>8;a[Ga+2|0]=y;y=y>>8;a[Ga+3|0]=y;ub=Sa;vb=Ta;wb=0;K=133}do{if((K|0)==133){K=0;Ga=(ub&2048|0)!=0;if(Ga){if((c[x>>2]|0)==3){K=135}}else{K=135}if((K|0)==135){K=0;mrc(S|0,0,112)|0}Ja=ub&2;ya=(Ja|0)!=0;do{if(ya){xb=vb;K=151}else{if(Ga){Ba=c[x>>2]|0;if((Ba|0)==3){K=139}else{yb=vb;zb=Ba}}else{K=139}if((K|0)==139){K=0;Ba=c[g>>2]|0;Ma=c[w>>2]|0;Da=c[s>>2]|0;Ca=Da+(Ba>>>3)|0;Aa=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(Ba&7);if((Aa&-1434451968|0)==0){Ca=1;db=Ba;fb=Aa;while(1){Ab=fb>>>24;cb=a[1369728+Ab|0]|0;Bb=cb&255;Qa=((cb&255)>>>0>8>>>0?8:Bb)+db|0;Ra=Ma>>>0>Qa>>>0;Cb=Ra?Qa:Ma;if(!(cb<<24>>24==9)){K=142;break}cb=d[1369984+Ab|0]|Ca<<4;if(!(cb>>>0<134217728>>>0)){Db=cb;break}Qa=Da+(Cb>>>3)|0;bb=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Cb&7);if(Ra){Ca=cb;db=Cb;fb=bb}else{Db=cb;break}}if((K|0)==142){K=0;Db=d[1369984+Ab|0]|Ca<<(Bb-1>>1)}c[g>>2]=Cb;Eb=Db-1|0}else{fb=Aa>>>24;db=(d[1369728+fb|0]|0)+Ba|0;c[g>>2]=Ma>>>0>db>>>0?db:Ma;Eb=d[1369216+fb|0]|0}if(Eb>>>0>47>>>0){K=147;break b}yb=d[((ub&3|0)==0?1147328:1147216)+Eb|0]|0;zb=c[x>>2]|0}if((zb|0)==1){Fb=yb;break}if((c[_>>2]|0)==0|(yb|0)==0){Fb=yb}else{xb=yb;K=151}}}while(0);if((K|0)==151){K=0;Ga=c[g>>2]|0;fb=c[w>>2]|0;db=c[s>>2]|0;Da=db+(Ga>>>3)|0;cb=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Ga&7);do{if((cb&-1434451968|0)==0){Da=Ga+8|0;bb=fb>>>0>Da>>>0?Da:fb;Da=db+(bb>>>3)|0;Ra=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(bb&7)>>>8|cb;Da=Ra|1;if((Ra&-1431655766|0)==0){Gb=-2147483648;break}if((Da|0)>-1){Ra=Da;Qa=31;while(1){Za=Qa-1|0;_a=(Ra>>>30|Ra<<2)-(Ra<<Qa>>>(Za>>>0))|0;if((_a|0)>-1){Ra=_a;Qa=Za}else{Hb=_a;Ib=Za;break}}}else{Hb=Da;Ib=31}Qa=bb+55-(Ib<<1)|0;c[g>>2]=fb>>>0>Qa>>>0?Qa:fb;Gb=((Hb<<Ib>>>(Ib>>>0))-1^-(Hb&1))+1>>1}else{Qa=cb>>>24;Ra=(d[1369728+Qa|0]|0)+Ga|0;c[g>>2]=fb>>>0>Ra>>>0?Ra:fb;Gb=a[1369472+Qa|0]|0}}while(0);Jb=(c[T>>2]|0)+Gb|0;c[T>>2]=Jb;if(Jb>>>0>31>>>0){K=158;break b}else{Fb=xb}}if(ya){mrc(U|0,0,32)|0;if((M2a(W,V,0,1)|0)!=0){K=161;break b}}d:do{if((Fb|0)==0){Kb=0}else{fb=Ja>>>1;Ga=(c[T>>2]|0)<24?wb+1|0:1;cb=0;do{e:do{if((1<<cb&Fb|0)!=0){db=cb<<2;Qa=db&8|cb<<1&2;Ra=0;while(1){if((Ra|0)>=4){break e}if(ya){Lb=Qa|Ra&1|Ra<<1&4}else{Lb=Ra+db|0}a[(d[602048+Lb|0]|0)+(k+5184)|0]=1;if((M2a(W,k+421200+(Lb<<4<<1)|0,fb,Ga)|0)==0){Ra=Ra+1|0}else{K=171;break b}}}}while(0);cb=cb+1|0;}while((cb|0)<4);if((Fb&48|0)==0){Kb=Fb;break}else{Mb=1}while(1){if((Mb|0)>=3){break}if((M2a(W,k+421200+(Mb<<8<<1)|0,0,3)|0)==0){Mb=Mb+1|0}else{K=176;break b}}if((Fb&32|0)==0){Kb=Fb;break}else{Nb=0}while(1){if((Nb|0)>=4){Ob=0;break}cb=Nb+16|0;a[(d[602048+cb|0]|0)+(k+5184)|0]=1;if((M2a(W,k+421200+(cb<<4<<1)|0,1,1)|0)==0){Nb=Nb+1|0}else{K=180;break b}}while(1){if((Ob|0)>=4){Kb=Fb;break d}cb=Ob+32|0;a[(d[602048+cb|0]|0)+(k+5184)|0]=1;if((M2a(W,k+421200+(cb<<4<<1)|0,1,1)|0)==0){Ob=Ob+1|0}else{K=180;break b}}}}while(0);c[X>>2]=Kb;c[(c[Y>>2]|0)+(Ea<<2)>>2]=ub;if((ub&3|0)==0){break}c[Z>>2]=dha(l,0,1)|0}}while(0);if(Ia){if((c[X>>2]|0)!=0){K=189}}else{K=189}if((K|0)==189){K=0;mha(l)}Ea=c[x>>2]|0;do{if((Ea|0)!=3){if((c[J>>2]|0)!=0){break}ya=(ca(c[I>>2]|0,c[q>>2]|0)|0)+(c[n>>2]|0)|0;c[(c[Y>>2]|0)+(ya<<2)>>2]=(Ea|0)==2&Pa>>>0<8>>>0?Pa-1|0:-1}}while(0);Ea=(c[n>>2]|0)+1|0;c[n>>2]=Ea;Ia=c[q>>2]|0;if((Ea|0)<(c[u>>2]|0)){wa=Ea;xa=Ia}else{Pb=Ia;break}}}else{Pb=va}xa=c[C>>2]|0;LTa(b,c[z>>2]|0,(c[xa>>2]|0)==0?0:xa,Pb<<4,16,c[B>>2]|0,0,c[J>>2]|0);xa=(c[q>>2]|0)+1|0;c[q>>2]=xa;wa=c[D>>2]|0;if((xa|0)<(wa|0)){va=xa}else{Qb=xa;Rb=wa;break a}}if((K|0)==117){KIb(c[da>>2]|0,16,2142728,(H=i,i=i+8|0,c[H>>2]=mb,H)|0);i=H}else if((K|0)==119){KIb(c[da>>2]|0,16,2119144,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==147){KIb(c[da>>2]|0,16,2614200,(H=i,i=i+8|0,c[H>>2]=Eb,H)|0);i=H}else if((K|0)==158){KIb(c[da>>2]|0,16,2587160,(H=i,i=i+8|0,c[H>>2]=Jb,H)|0);i=H}else if((K|0)==161){KIb(c[da>>2]|0,16,2566152,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==171){KIb(c[da>>2]|0,16,2548064,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==176){KIb(c[da>>2]|0,16,2530128,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==180){KIb(c[da>>2]|0,16,2514904,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}else if((K|0)==212){i=h;return o|0}va=c[q>>2]|0;KIb(c[da>>2]|0,16,2242808,(H=i,i=i+16|0,c[H>>2]=c[n>>2],c[H+8>>2]=va,H)|0);i=H;o=-1;i=h;return o|0}else{Qb=0;Rb=F}}while(0);F=t-(c[g>>2]|0)|0;g=c[n>>2]|0;if((Qb|0)==(Rb|0)){if((g|0)!=(c[j+427400>>2]|0)){K=197}}else{K=197}if((K|0)==197){KIb(b,32,2201520,(H=i,i=i+32|0,c[H>>2]=c[b+428>>2],c[H+8>>2]=Qb,c[H+16>>2]=g,c[H+24>>2]=F,H)|0);i=H}if((F|0)<0){KIb(b,16,2169696,(H=i,i=i+16|0,c[H>>2]=c[b+428>>2],c[H+8>>2]=F,H)|0);i=H;o=-1;i=h;return o|0}do{if((c[x>>2]|0)==3){K=202}else{if((c[j+4808>>2]|0)!=0){K=202;break}H=c[j+572936>>2]|0;if((c[H>>2]|0)==0){Sb=G;break}Sb=YHb(e,H|0)|0}}while(0);if((K|0)==202){Sb=YHb(e,c[z>>2]|0)|0}if((Sb|0)<0){o=Sb;i=h;return o|0}if((c[c[j+572936>>2]>>2]|0)==0){if((c[j+4808>>2]|0)!=0){K=208}}else{K=208}if((K|0)==208){c[f>>2]=1}if((c[x>>2]|0)==3){WHb(c[z>>2]|0);o=m;i=h;return o|0}else{x=j+572932|0;j=c[x>>2]|0;c[x>>2]=c[z>>2];c[z>>2]=j;o=m;i=h;return o|0}return 0}function H2a(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;a=b+572928|0;d=c[a>>2]|0;fGb(d+1516|0);fGb(d+1548|0);fGb(d+1520|0);fGb(d+1552|0);fGb(d+1532|0);WHb(d|0);d=b+572932|0;e=c[d>>2]|0;fGb(e+1516|0);fGb(e+1548|0);fGb(e+1520|0);fGb(e+1552|0);fGb(e+1532|0);WHb(e|0);e=b+572936|0;f=c[e>>2]|0;fGb(f+1516|0);fGb(f+1548|0);fGb(f+1520|0);fGb(f+1552|0);fGb(f+1532|0);WHb(f|0);mJb(a);mJb(d);mJb(e);WHb(b+2528|0);lha(b);mJb(b+572960|0);c[b+572964>>2]=0;mJb(b+572684|0);return 0}function I2a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;f=c[b+60>>2]|0;g=c[f+427412>>2]|0;h=f+1096|0;j=c[h>>2]|0;k=f+1104|0;l=c[k>>2]|0;m=f+1088|0;n=c[m>>2]|0;o=n+(j>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(j&7);o=p>>>24;q=j+8|0;j=l>>>0>q>>>0?q:l;c[h>>2]=j;q=o&159;if((q-1|0)>>>0>1>>>0|(o&96|0)==0){KIb(b,16,2488312,(r=i,i=i+8|0,c[r>>2]=o,r)|0);i=r;s=-1;i=e;return s|0}o=p>>>29&3;p=o<<3;t=n+(j>>>3)|0;u=j+p+((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(j&7)>>>((32-p|0)>>>0)<<3)|0;c[f+572952>>2]=u;p=f+1100|0;if((u|0)>(c[p>>2]|0)){KIb(b,16,2477368,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1;i=e;return s|0}b=o-1|0;c[p>>2]=u-(b<<3);u=j+8|0;j=l>>>0>u>>>0?u:l;c[h>>2]=j;l=c[f+572956>>2]|0;if((l|0)!=0){u=n+((j>>3)+1)|0;y=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24)^l;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y}if((o|0)!=0){o=c[m>>2]|0;orc(o+(c[h>>2]>>3)|0,o+(c[p>>2]>>3)|0,b|0)|0}b=c[h>>2]|0;o=c[k>>2]|0;k=o-b|0;if((b|0)<0){v=-b|0}else{v=(k|0)<0?k:0}k=v+b|0;c[h>>2]=k;b=c[m>>2]|0;m=b+(k>>>3)|0;v=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(k&7);if((v&-1434451968|0)==0){m=1;u=k;l=v;while(1){w=l>>>24;j=a[1369728+w|0]|0;x=j&255;n=((j&255)>>>0>8>>>0?8:x)+u|0;t=o>>>0>n>>>0;z=t?n:o;if(!(j<<24>>24==9)){A=15;break}j=d[1369984+w|0]|0|m<<4;if(!(j>>>0<134217728>>>0)){B=j;break}n=b+(z>>>3)|0;C=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(z&7);if(t){m=j;u=z;l=C}else{B=j;break}}if((A|0)==15){B=d[1369984+w|0]|0|m<<(x-1>>1)}c[h>>2]=z;D=B-1|0;E=z}else{z=v>>>24;v=(d[1369728+z|0]|0)+k|0;k=o>>>0>v>>>0?v:o;c[h>>2]=k;D=d[1369216+z|0]|0;E=k}if(D>>>0>2>>>0){KIb(c[f>>2]|0,16,2467872,(r=i,i=i+8|0,c[r>>2]=D,r)|0);i=r;s=-1;i=e;return s|0}c[f+177076>>2]=d[1147176+D|0]|0;if((q|0)==2){q=c[f+427408>>2]|0;if((q|0)<64){F=6}else{D=q-1|0;q=D>>>0>65535>>>0;r=q?D>>>16:D;D=q?16:0;if((r&65280|0)==0){G=D;H=r}else{G=D|8;H=r>>>8}F=G+1+(d[1359664+H|0]|0)|0}H=b+(E>>>3)|0;G=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>((32-F|0)>>>0);H=E+F|0;F=o>>>0>H>>>0?H:o;c[h>>2]=F;H=ca(c[f+427400>>2]|0,c[f+427380>>2]|0)|0;c[f+427392>>2]=G-(c[f+427376>>2]|0)-H;I=F}else{F=E+1|0;E=o>>>0>F>>>0?F:o;c[h>>2]=E;c[f+427392>>2]=0;I=E}E=b+(I>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(I&7)>>>24;E=I+8|0;I=o>>>0>E>>>0?E:o;c[h>>2]=I;c[f+177068>>2]=F;F=b+(I>>>3)|0;E=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>27;F=I+5|0;I=o>>>0>F>>>0?F:o;c[h>>2]=I;c[f+4792>>2]=E;c[f+572968>>2]=(d[b+(I>>>3)|0]|0)<<(I&7)>>>7&1;E=((I|0)<(o|0))+I+1|0;I=o>>>0>E>>>0?E:o;c[h>>2]=I;if((c[f+572948>>2]|0)==0){J=I}else{E=I+1|0;I=o>>>0>E>>>0?E:o;c[h>>2]=I;J=I}I=J+1|0;J=(o>>>0>I>>>0?I:o)+2|0;I=o>>>0>J>>>0?J:o;c[h>>2]=I;J=c[p>>2]|0;if((J-I|0)<1){s=-1094995529;i=e;return s|0}else{K=I}while(1){I=d[b+(K>>>3)|0]|0;p=((K|0)<(o|0))+K|0;c[h>>2]=p;if((I&128>>>((K&7)>>>0)|0)==0){break}I=p+8|0;p=o>>>0>I>>>0?I:o;c[h>>2]=p;if((J-p|0)<1){s=-1094995529;A=38;break}else{K=p}}if((A|0)==38){i=e;return s|0}A=f+427376|0;if((c[A>>2]|0)>0){K=f+4928|0;J=f+6104|0;h=(c[K>>2]|0)+((c[(c[J>>2]|0)+(g-1<<2)>>2]|0)+3)|0;y=-1;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=c[A>>2]|0;mrc((c[K>>2]|0)+(c[(c[J>>2]|0)+(g-h<<2)>>2]|0)|0,-1|0,h<<3|0)|0}if((c[f+427380>>2]|0)<=0){s=0;i=e;return s|0}h=f+4928|0;J=f+427404|0;K=f+6104|0;mrc((c[h>>2]|0)+(c[(c[K>>2]|0)+(g-(c[J>>2]|0)<<2)>>2]|0)|0,-1|0,(c[f+427400>>2]|0)-(c[A>>2]|0)<<3|0)|0;if((c[A>>2]|0)<=0){s=0;i=e;return s|0}a[(c[h>>2]|0)+((c[(c[K>>2]|0)+(g-1-(c[J>>2]|0)<<2)>>2]|0)+3)|0]=-1;s=0;i=e;return s|0}function J2a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[a+60>>2]|0;e=d+427404|0;f=c[e>>2]|0;g=c[d+427396>>2]|0;h=ca(g<<4,c[d+427400>>2]<<2|1)|0;i=b+1516|0;a:do{if((c[i>>2]|0)==0){j=dGb(f+1+(ca(g+1|0,f)|0)<<2)|0;k=b+1532|0;c[k>>2]=j;if((j|0)==0){l=-12;return l|0}c[b+1536>>2]=(c[j+4>>2]|0)+((c[e>>2]<<1|1)<<2);j=h+16|0;m=ca(f<<2,g)|0;c[i>>2]=dGb(j)|0;n=dGb(m)|0;o=b+1548|0;c[o>>2]=n;p=c[i>>2]|0;do{if(!((p|0)==0|(n|0)==0)){c[b+1524>>2]=(c[p+4>>2]|0)+16;c[b+1556>>2]=c[n+4>>2];q=b+1520|0;c[q>>2]=dGb(j)|0;r=dGb(m)|0;c[b+1552>>2]=r;s=c[q>>2]|0;if((s|0)==0|(r|0)==0){break}c[b+1528>>2]=(c[s+4>>2]|0)+16;c[b+1560>>2]=c[r+4>>2];t=5;break a}}while(0);u=-12;v=b|0;w=o;x=k}else{t=5}}while(0);do{if((t|0)==5){g=(c[d+572392>>2]|0)!=3|0;c[b+2192>>2]=g;f=b|0;h=M4a(a,f,g)|0;if((h|0)<0){u=h;v=f;w=b+1548|0;x=b+1532|0;break}f=d+572684|0;h=b+32|0;do{if((c[f>>2]|0)==0){g=pJb((c[h>>2]|0)*17|0)|0;c[f>>2]=g;if((g|0)==0){l=-12}else{break}return l|0}}while(0);c[d+4776>>2]=c[h>>2];c[d+4780>>2]=c[b+36>>2];l=0;return l|0}}while(0);fGb(i);fGb(w);fGb(b+1520|0);fGb(b+1552|0);fGb(x);WHb(v);l=u;return l|0}function K2a(a,b,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;m=c[((k|0)==0?a+572936|0:a+572932|0)>>2]|0;k=2-(e>>3)|0;n=g+b|0;g=h+d|0;h=c[a+572976>>2]|0;do{if((n|0)<0){if((n|0)<-16){o=-16;p=7}else{p=6}}else{if(!((n|0)>=(h+~e|0)|(g|0)<0)){q=c[a+572980>>2]|0;if((g|0)<(q+~f|0)){r=0;s=n;t=g;u=q;break}}p=6}}while(0);if((p|0)==6){q=h-e+15|0;o=(n|0)>(q|0)?q:n;p=7}do{if((p|0)==7){n=c[a+572980>>2]|0;q=n-f+15|0;if((g|0)<-16){r=1;s=o;t=-16;u=n;break}r=1;s=o;t=(g|0)>(q|0)?q:g;u=n}}while(0);g=a+4776|0;o=c[g>>2]|0;p=(c[a+2528>>2]|0)+((ca(o,d)|0)+b)|0;n=(c[m>>2]|0)+((ca(o,t)|0)+s)|0;if(r){q=a+572684|0;Ve[c[a+4>>2]&127](c[q>>2]|0,n,o,o,e+1|0,f+1|0,s,t,h,u);v=c[q>>2]|0}else{v=n}n=(j|0)!=0;j=(l|0)!=0;if(n){pe[c[(j?a+1688|0:a+1644|0)+(i<<2)>>2]&1023](p,v,c[g>>2]|0,e,f)}else{mf[c[(j?a+572784|0:a+572720|0)+(k<<4)+(i<<2)>>2]&2047](p,v,c[g>>2]|0,f)}if((c[a+4816>>2]&8192|0)!=0){return}g=((s|0)<(b|0))+s>>1;s=((t|0)<(d|0))+t>>1;t=e>>1;e=f>>1;f=b>>1;b=d>>1;d=a+4780|0;v=a+4|0;p=a+572684|0;l=t+1|0;q=e+1|0;u=a+572976|0;h=a+572980|0;o=(j?a+1688|0:a+1644|0)+(i<<2)|0;w=(j?a+572784|0:a+572720|0)+(k+1<<4)+(i<<2)|0;i=c[d>>2]|0;k=(c[a+2532>>2]|0)+((ca(i,b)|0)+f)|0;j=(c[m+4>>2]|0)+((ca(i,s)|0)+g)|0;if(r){Ve[c[v>>2]&127](c[p>>2]|0,j,i,i,l,q,g,s,c[u>>2]>>1,c[h>>2]>>1);r=c[p>>2]|0;if(n){pe[c[o>>2]&1023](k,r,c[d>>2]|0,t,e);x=c[d>>2]|0;y=(c[a+2536>>2]|0)+((ca(x,b)|0)+f)|0;z=(c[m+8>>2]|0)+((ca(x,s)|0)+g)|0;Ve[c[v>>2]&127](c[p>>2]|0,z,x,x,l,q,g,s,c[u>>2]>>1,c[h>>2]>>1);pe[c[o>>2]&1023](y,c[p>>2]|0,c[d>>2]|0,t,e);return}else{mf[c[w>>2]&2047](k,r,c[d>>2]|0,e);r=c[d>>2]|0;y=(c[a+2536>>2]|0)+((ca(r,b)|0)+f)|0;x=(c[m+8>>2]|0)+((ca(r,s)|0)+g)|0;Ve[c[v>>2]&127](c[p>>2]|0,x,r,r,l,q,g,s,c[u>>2]>>1,c[h>>2]>>1);mf[c[w>>2]&2047](y,c[p>>2]|0,c[d>>2]|0,e);return}}else{if(n){pe[c[o>>2]&1023](k,j,i,t,e);n=c[d>>2]|0;p=(c[a+2536>>2]|0)+((ca(n,b)|0)+f)|0;y=(c[m+8>>2]|0)+((ca(n,s)|0)+g)|0;pe[c[o>>2]&1023](p,y,n,t,e);return}else{mf[c[w>>2]&2047](k,j,i,e);i=c[d>>2]|0;d=(c[a+2536>>2]|0)+((ca(i,b)|0)+f)|0;f=(c[m+8>>2]|0)+((ca(i,s)|0)+g)|0;mf[c[w>>2]&2047](d,f,i,e);return}}}function L2a(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;k=i;if((f&5|0)==4){l=4}else{l=16>>>((f&1)>>>0)}m=16>>>((((f+1|0)>>>0)/3|0)>>>0);f=(g|0)==4;n=f?-96:0;o=(((c[e+572976>>2]|0)-l|0)*6|0)-n|0;p=(((c[e+572980>>2]|0)-m|0)*6|0)-n|0;q=e+427376|0;r=e+427380|0;s=e+6108|0;t=(g|0)!=4;u=l>>2;v=e+177088|0;w=e+5632+(h*40|0)+11|0;x=e+2524|0;y=e+5312+(h*160|0)+40|0;z=y|0;A=y;y=e+177092|0;B=e+4872|0;C=e+4852|0;D=e+427404|0;E=12288<<(h<<1);F=e+6100|0;G=e+5312+(h*160|0)+42|0;H=(m|0)==8;I=(l|0)==8;J=(l|0)==4|(m|0)==4;K=e+4052+(h<<2)|0;L=m>>2;M=u<<2;N=(L|0)==1;O=(L|0)==2;L=e+1096|0;P=e+1104|0;Q=e+1088|0;R=e+572932|0;S=(h|0)==0;T=e+428668|0;U=e+428672|0;V=0;a:while(1){W=V>>2;X=V>>>1&2|V&8;Y=H&(V|0)<8;Z=0;do{_=c[q>>2]|0;$=Z>>2;aa=c[r>>2]|0;ba=c[s>>2]|0;da=(_<<2)+$+(ca((aa<<2)+W|0,ba)|0)|0;ea=(_<<4)+Z|0;_=(aa<<4)+V|0;fa=X|$&1|Z>>>1&4;do{if(t){$=a[602048+fa|0]|0;ga=$&255;ha=ga-8|0;ia=a[e+5632+(h*40|0)+ha|0]|0;ja=ga-1|0;ka=a[e+5632+(h*40|0)+ja|0]|0;la=e+5312+(h*160|0)+(ja<<2)|0;ma=e+5312+(h*160|0)+(ha<<2)|0;na=ha+u|0;oa=a[e+5632+(h*40|0)+na|0]|0;pa=oa<<24>>24;qa=oa<<24>>24==-2;do{if((c[v>>2]|0)!=0&qa&($&255)>>>0>19>>>0&(ga&7|0)==4){if((a[w]|0)==-2){ra=15;break}oa=c[x>>2]|0;sa=c[oa+1536>>2]|0;c[A>>2]=0;ta=(c[B>>2]&128|0)==0;if((c[y>>2]|0)==0){if(ta){ra=15;break}ua=c[D>>2]|0;va=ua+(c[C>>2]|0)|0;wa=(aa<<1&2)+(ga>>>5)|0;if((c[sa+((ca(wa>>>2,ua)|0)+va<<2)>>2]&E|0)==0){xa=-1;ya=z;break}ua=(c[(c[F>>2]|0)+(va<<2)>>2]|0)+3+(ca(ba,wa)|0)|0;za=c[oa+1524+(h<<2)>>2]|0;b[z>>1]=b[za+(ua<<2)>>1]|0;b[G>>1]=b[za+(ua<<2)+2>>1]<<1;xa=a[(c[oa+1556+(h<<2)>>2]|0)+((wa&2147483646)+(va<<2|1))|0]>>1;ya=z;break}else{if(!ta){ra=15;break}ta=c[e+4852+((($&255)>>>0>35>>>0)<<2)>>2]|0;va=ga>>>2;if((c[sa+(ta<<2)>>2]&E|0)==0){xa=-1;ya=z;break}sa=(c[(c[F>>2]|0)+(ta<<2)>>2]|0)+3+(ca(ba,va&3)|0)|0;wa=c[oa+1524+(h<<2)>>2]|0;b[z>>1]=b[wa+(sa<<2)>>1]|0;b[G>>1]=(b[wa+(sa<<2)+2>>1]|0)/2|0;xa=a[(c[oa+1556+(h<<2)>>2]|0)+(va&2|ta<<2|1)|0]<<1;ya=z;break}}else{ra=15}}while(0);do{if((ra|0)==15){ra=0;if(qa){$=ga-9|0;xa=a[e+5632+(h*40|0)+$|0]|0;ya=e+5312+(h*160|0)+($<<2)|0;break}else{xa=pa;ya=e+5312+(h*160|0)+(na<<2)|0;break}}}while(0);na=ia<<24>>24==1;pa=ka<<24>>24==1;ga=(pa&1)+(na&1)+((xa|0)==1)|0;if((ga|0)>1){qa=b[la>>1]|0;$=qa<<16>>16;ta=b[ma>>1]|0;va=ta<<16>>16;oa=b[ya>>1]|0;sa=oa<<16>>16;do{if(qa<<16>>16>ta<<16>>16){if(!(oa<<16>>16>ta<<16>>16)){Aa=va;break}Aa=(sa|0)>($|0)?$:sa}else{if(!(ta<<16>>16>oa<<16>>16)){Aa=va;break}Aa=(sa|0)>($|0)?sa:$}}while(0);$=b[e+5312+(h*160|0)+(ja<<2)+2>>1]|0;sa=$<<16>>16;va=b[e+5312+(h*160|0)+(ha<<2)+2>>1]|0;oa=va<<16>>16;ta=b[ya+2>>1]|0;qa=ta<<16>>16;if($<<16>>16>va<<16>>16){if(!(ta<<16>>16>va<<16>>16)){Ba=oa;Ca=Aa;break}Ba=(qa|0)>(sa|0)?sa:qa;Ca=Aa;break}else{if(!(va<<16>>16>ta<<16>>16)){Ba=oa;Ca=Aa;break}Ba=(qa|0)>(sa|0)?qa:sa;Ca=Aa;break}}if((ga|0)==1){if(pa){Ba=b[e+5312+(h*160|0)+(ja<<2)+2>>1]|0;Ca=b[la>>1]|0;break}if(na){Ba=b[e+5312+(h*160|0)+(ha<<2)+2>>1]|0;Ca=b[ma>>1]|0;break}else{Ba=b[ya+2>>1]|0;Ca=b[ya>>1]|0;break}}sa=b[la>>1]|0;qa=sa<<16>>16;if(!((xa|0)!=-2|ia<<24>>24!=-2|ka<<24>>24==-2)){Ba=b[e+5312+(h*160|0)+(ja<<2)+2>>1]|0;Ca=qa;break}oa=b[ma>>1]|0;ta=oa<<16>>16;va=b[ya>>1]|0;$=va<<16>>16;do{if(sa<<16>>16>oa<<16>>16){if(!(va<<16>>16>oa<<16>>16)){Da=ta;break}Da=($|0)>(qa|0)?qa:$}else{if(!(oa<<16>>16>va<<16>>16)){Da=ta;break}Da=($|0)>(qa|0)?$:qa}}while(0);qa=b[e+5312+(h*160|0)+(ja<<2)+2>>1]|0;$=qa<<16>>16;ta=b[e+5312+(h*160|0)+(ha<<2)+2>>1]|0;va=ta<<16>>16;oa=b[ya+2>>1]|0;sa=oa<<16>>16;if(qa<<16>>16>ta<<16>>16){if(!(oa<<16>>16>ta<<16>>16)){Ba=va;Ca=Da;break}Ba=(sa|0)>($|0)?$:sa;Ca=Da;break}else{if(!(ta<<16>>16>oa<<16>>16)){Ba=va;Ca=Da;break}Ba=(sa|0)>($|0)?sa:$;Ca=Da;break}}else{$=c[(c[R>>2]|0)+1524>>2]|0;sa=b[$+(da<<2)>>1]<<1;va=b[$+(da<<2)+2>>1]<<1;$=c[T>>2]|0;if(S){oa=ca(sa,$)|0;ta=c[U>>2]|0;Ba=((ca(va,$)|0)/(ta|0)|0)+1>>1;Ca=((oa|0)/(ta|0)|0)+1>>1;break}else{ta=c[U>>2]|0;oa=$-ta|0;Ba=((ca(oa,va)|0)/(ta|0)|0)+1>>1;Ca=((ca(oa,sa)|0)/(ta|0)|0)+1>>1;break}}}while(0);ba=ea*6|0;aa=n-ba|0;ta=o-ba|0;if((Ca|0)<(aa|0)){Ea=aa}else{Ea=(Ca|0)>(ta|0)?ta:Ca}ta=_*6|0;aa=n-ta|0;ba=p-ta|0;if((Ba|0)<(aa|0)){Fa=aa}else{Fa=(Ba|0)>(ba|0)?ba:Ba}do{if(f){Ga=0;Ha=0;ra=71}else{ba=c[L>>2]|0;aa=c[P>>2]|0;ta=c[Q>>2]|0;sa=ta+(ba>>>3)|0;oa=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ba&7);do{if((oa&-1434451968|0)==0){sa=ba+8|0;va=aa>>>0>sa>>>0?sa:aa;sa=ta+(va>>>3)|0;$=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(va&7)>>>8|oa;sa=$|1;if(($&-1431655766|0)==0){Ia=-2147483648;Ja=ba;break}if((sa|0)>-1){$=sa;qa=31;while(1){ma=qa-1|0;ka=($>>>30|$<<2)-($<<qa>>>(ma>>>0))|0;if((ka|0)>-1){$=ka;qa=ma}else{Ka=ka;La=ma;break}}}else{Ka=sa;La=31}qa=va+55-(La<<1)|0;$=aa>>>0>qa>>>0?qa:aa;c[L>>2]=$;Ia=((Ka<<La>>>(La>>>0))-1^-(Ka&1))+1>>1;Ja=$}else{$=oa>>>24;qa=(d[1369728+$|0]|0)+ba|0;ma=aa>>>0>qa>>>0?qa:aa;c[L>>2]=ma;Ia=a[1369472+$|0]|0;Ja=ma}}while(0);ba=ta+(Ja>>>3)|0;oa=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(Ja&7);if((oa&-1434451968|0)==0){ba=Ja+8|0;ha=aa>>>0>ba>>>0?ba:aa;ba=ta+(ha>>>3)|0;ja=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(ha&7)>>>8|oa;ba=ja|1;if((ja&-1431655766|0)==0){break a}if((ba|0)>-1){ja=ba;ma=31;while(1){$=ma-1|0;qa=(ja>>>30|ja<<2)-(ja<<ma>>>($>>>0))|0;if((qa|0)>-1){ja=qa;ma=$}else{Ma=qa;Na=$;break}}}else{Ma=ba;Na=31}ma=ha+55-(Na<<1)|0;c[L>>2]=aa>>>0>ma>>>0?ma:aa;Oa=((Ma<<Na>>>(Na>>>0))-1^-(Ma&1))+1>>1}else{ma=oa>>>24;ja=(d[1369728+ma|0]|0)+Ja|0;c[L>>2]=aa>>>0>ja>>>0?ja:aa;Oa=a[1369472+ma|0]|0}if((Ia|0)==-2147483648){break a}if((g|0)==3){ma=Oa+(Ea+1>>1)|0;ja=Ia+(Fa+1>>1)|0;ta=(((ma+12288|0)>>>0)/3|0)-4096|0;$=(((ja+12288|0)>>>0)/3|0)-4096|0;K2a(e,ea,_,l,m,ta,$,(ta*-3|0)+ma+(($*-3|0)+ja<<2)|0,1,h,j);Pa=ja<<1;Qa=ma<<1;break}else if((g|0)==4|(g|0)==2){Ga=Ia;Ha=Oa;ra=71;break}else{ma=Oa-4096+(((Ea+24579|0)>>>0)/6|0)|0;ja=Ia-4096+(((Fa+24579|0)>>>0)/6|0)|0;K2a(e,ea,_,l,m,ma,ja,0,0,h,j);Pa=ja*6|0;Qa=ma*6|0;break}}}while(0);if((ra|0)==71){ra=0;ma=Ha-4096+(((Ea+12289|0)>>>0)/3|0)|0;ja=Ga-4096+(((Fa+12289|0)>>>0)/3|0)|0;K2a(e,ea,_,l,m,ma>>1,ja>>1,ja<<1&2|ma&1,0,h,j);Pa=ja*3|0;Qa=ma*3|0}ma=Pa<<16|Qa&65535;do{if(t){do{if(Y){ja=d[602048+fa|0]|0;c[e+5312+(h*160|0)+(ja+8<<2)>>2]=ma;if(!(I&(Z|0)<8)){break}c[e+5312+(h*160|0)+(ja+9<<2)>>2]=ma}}while(0);if(I&(Z|0)<8){c[e+5312+(h*160|0)+((d[602048+fa|0]|0)+1<<2)>>2]=ma}if(!J){break}c[e+5312+(h*160|0)+(d[602048+fa|0]<<2)>>2]=ma}}while(0);fa=c[K>>2]|0;_=fa+(da<<2)|0;ea=_;aa=c[s>>2]|0;oa=aa<<2;do{if((M|0)==16){c[_>>2]=ma;c[fa+(da<<2)+4>>2]=ma;c[fa+(da<<2)+8>>2]=ma;c[fa+(da<<2)+12>>2]=ma;c[ea+oa>>2]=ma;c[ea+(oa+4)>>2]=ma;c[ea+(oa+8)>>2]=ma;c[ea+(oa+12)>>2]=ma;if(O){break}ha=aa<<3;c[ea+ha>>2]=ma;c[ea+(ha|4)>>2]=ma;c[ea+(ha+8)>>2]=ma;c[ea+(ha+12)>>2]=ma;ha=aa*12|0;c[ea+ha>>2]=ma;c[ea+(ha+4)>>2]=ma;c[ea+(ha+8)>>2]=ma;c[ea+(ha+12)>>2]=ma}else if((M|0)==4){c[_>>2]=ma;if(N){break}c[ea+oa>>2]=ma;if(O){break}c[fa+(da<<2)+(oa<<1)>>2]=ma;c[fa+(da<<2)+((aa*6|0)<<1)>>2]=ma}else if((M|0)==8){c[_>>2]=ma;c[fa+(da<<2)+4>>2]=ma;if(N){break}c[ea+oa>>2]=ma;c[ea+(oa+4)>>2]=ma;if(O){break}ha=aa<<3;c[ea+ha>>2]=ma;c[ea+(ha|4)>>2]=ma;ha=aa*12|0;c[ea+ha>>2]=ma;c[ea+(ha+4)>>2]=ma}}while(0);Z=Z+l|0;}while((Z|0)<16);Z=V+m|0;if((Z|0)<16){V=Z}else{Ra=0;ra=92;break}}if((ra|0)==92){i=k;return Ra|0}KIb(c[e>>2]|0,16,2501064,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;Ra=-1;i=k;return Ra|0}function M2a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=(h*3|0)>>2;j=c[527984+(h<<2)>>2]|0;k=e+8|0;l=e+16|0;m=e|0;e=(h|0)==3;n=(i|0)==0;o=(h|0)==2;h=g;g=16>>>(i>>>0);a:while(1){if((h|0)>=16){p=0;q=31;break}r=c[l>>2]|0;s=c[m>>2]|0;t=h;u=c[k>>2]|0;while(1){v=s+(u>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(u&7);if((w&-1434451968|0)==0){v=1;x=u;y=w;while(1){z=y>>>24;A=a[1369728+z|0]|0;B=A&255;C=((A&255)>>>0>8>>>0?8:B)+x|0;D=r>>>0>C>>>0;E=D?C:r;if(!(A<<24>>24==9)){q=7;break}A=d[1369984+z|0]|0|v<<4;if(!(A>>>0<134217728>>>0)){F=A;break}C=s+(E>>>3)|0;G=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7);if(D){v=A;x=E;y=G}else{F=A;break}}if((q|0)==7){q=0;F=d[1369984+z|0]|0|v<<(B-1>>1)}c[k>>2]=E;H=F-1|0;I=E}else{y=w>>>24;x=(d[1369728+y|0]|0)+u|0;A=r>>>0>x>>>0?x:r;c[k>>2]=A;H=d[1369216+y|0]|0;I=A}if((H|0)==0){break}if((H|0)<0){p=-1;q=31;break a}A=(H&1)-1|0;y=H+1|0;x=y>>>1;do{if(e){if(y>>>0<6>>>0){J=0;K=x;break}if(y>>>0<8>>>0){J=1;K=1;break}G=x&3;J=G;K=((x+9|0)>>>2)-G|0}else{if(y>>>0<32>>>0){J=d[528e3+(i<<5)+(x<<1)|0]|0;K=d[528e3+(i<<5)+(x<<1)+1|0]|0;break}if(n){G=x&15;D=y>>>5;do{if((G|0)==0){L=4}else{if(G>>>0<3>>>0){L=2;break}L=G>>>0<10>>>0|0}}while(0);J=G;K=L+D|0;break}else{C=x&7;M=y>>>4;do{if((C|0)==0){N=8}else{if(C>>>0<2>>>0){N=2;break}N=(C>>>0>4>>>0)<<31>>31}}while(0);J=C;K=N+M|0;break}}}while(0);y=J+t|0;if((y|0)>=(g|0)){p=-1;q=31;break a}b[f+((d[j+y|0]|0)<<1)>>1]=(K^A)-A;t=y+1|0;u=I}if(o){h=g;g=g+8|0}else{p=0;q=31;break}}if((q|0)==31){return p|0}return 0}function N2a(a){a=a|0;c[a>>2]=2;return}function O2a(a,b,d,e,f,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0,U=0.0;k=c[d>>2]|0;ef[c[a+44>>2]&4095](a,b+(k<<2)|0,i);i=c[d>>2]|0;a=512-i|0;l=k-497|0;m=k-512|0;n=k-481|0;o=k+15|0;p=k+31|0;if((a|0)>0){q=0;r=0}else{s=0;t=0;while(1){u=e+(s<<2)|0;v=s+16|0;w=e+(v<<2)|0;x=l+t|0;y=m+v|0;z=n+t|0;A=0;B=+g[u>>2];C=+g[w>>2];D=0.0;E=0.0;do{F=A+s|0;B=B+ +g[f+(F<<2)>>2]*(-0.0- +g[b+(x+A<<2)>>2]);C=C+ +g[f+(F+16<<2)>>2]*+g[b+(m+F<<2)>>2];D=D+ +g[f+(F+32<<2)>>2]*+g[b+(y+A<<2)>>2];E=E+ +g[f+(F+48<<2)>>2]*+g[b+(z+A<<2)>>2];A=A+64|0;}while((A|0)<512);g[h+(s<<2)>>2]=B*j;g[h+(v<<2)>>2]=C*j;g[u>>2]=D;g[w>>2]=E;A=s+1|0;z=~s;if((A|0)<16){s=A;t=z}else{break}}G=i+480|0;H=G&511;c[d>>2]=H;return}while(1){t=e+(q<<2)|0;s=q+16|0;z=e+(s<<2)|0;A=o+r|0;y=s+k|0;x=p+r|0;F=0;I=+g[t>>2];J=+g[z>>2];K=0.0;L=0.0;do{M=F+q|0;I=I+ +g[f+(M<<2)>>2]*(-0.0- +g[b+(A+F<<2)>>2]);J=J+ +g[f+(M+16<<2)>>2]*+g[b+(M+k<<2)>>2];K=K+ +g[f+(M+32<<2)>>2]*+g[b+(y+F<<2)>>2];L=L+ +g[f+(M+48<<2)>>2]*+g[b+(x+F<<2)>>2];F=F+64|0;}while((F|0)<(a|0));if((F|0)<512){x=l+r|0;y=m+s|0;A=n+r|0;w=F;E=I;D=J;C=K;B=L;while(1){u=w+q|0;N=E+ +g[f+(u<<2)>>2]*(-0.0- +g[b+(x+w<<2)>>2]);O=D+ +g[f+(u+16<<2)>>2]*+g[b+(m+u<<2)>>2];P=C+ +g[f+(u+32<<2)>>2]*+g[b+(y+w<<2)>>2];Q=B+ +g[f+(u+48<<2)>>2]*+g[b+(A+w<<2)>>2];u=w+64|0;if((u|0)<512){w=u;E=N;D=O;C=P;B=Q}else{R=N;S=O;T=P;U=Q;break}}}else{R=I;S=J;T=K;U=L}g[h+(q<<2)>>2]=R*j;g[h+(s<<2)>>2]=S*j;g[t>>2]=T;g[z>>2]=U;w=q+1|0;A=~q;if((w|0)<16){q=w;r=A}else{break}}G=i+480|0;H=G&511;c[d>>2]=H;return}function P2a(a,b){a=a|0;b=b|0;var c=0,e=0,f=0;if(b>>>0<4>>>0){c=-1094995529;return c|0}e=b-3|0;f=(d[a+(b-2)|0]|0)<<8|(d[a+e|0]|0)<<16|(d[a+(b-1)|0]|0);b=(f|0)==(EGb(DGb(12)|0,13501623,a,e)|0);c=b?0:-1094995529;return c|0}function Q2a(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=a+8|0;g=c[f>>2]|0;h=a+16|0;i=c[h>>2]|0;j=c[a>>2]|0;a=j+(g>>>3)|0;k=g+6|0;c[b+4>>2]=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>((g&7)>>>0)&63;g=(i>>>0>k>>>0?k:i)+4|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=j+(k>>>3)|0;a=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&15;g=k+4|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=j+(k>>>3)|0;l=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&65535;g=k+16|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=j+(k>>>3)|0;m=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0);g=k+16|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=j+(k>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&7;g=k+3|0;k=i>>>0>g>>>0?g:i;c[f>>2]=k;g=b+48|0;c[g>>2]=m<<16|l;c[g+4>>2]=n;n=j+(k>>>3)|0;g=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((k&7)>>>0)&7;n=k+3|0;c[f>>2]=i>>>0>n>>>0?n:i;c[b+8>>2]=g;g=c[f>>2]|0;i=c[h>>2]|0;n=j+(g>>>3)|0;k=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((g&7)>>>0)&262143;n=g+18|0;c[f>>2]=i>>>0>n>>>0?n:i;i=b+12|0;c[i>>2]=k+6e3;k=c[f>>2]|0;n=c[h>>2]|0;g=j+(k>>>3)|0;l=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&31;g=k+5|0;c[f>>2]=n>>>0>g>>>0?g:n;c[b+20>>2]=l+8;l=c[f>>2]|0;n=c[h>>2]|0;g=j+(l>>>3)|0;k=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((l&7)>>>0)&15;g=l+4|0;c[f>>2]=n>>>0>g>>>0?g:n;n=b+16|0;c[n>>2]=k+1;k=c[f>>2]|0;g=d[j+(k>>>3)|0]|0;l=c[h>>2]|0;h=((k|0)<(l|0))+k|0;c[f>>2]=h;do{if((g&1<<(k&7)|0)==0){o=0;p=0}else{m=h+5|0;q=l>>>0>m>>>0?m:l;c[f>>2]=q;m=d[j+(q>>>3)|0]|0;r=((q|0)<(l|0))+q|0;c[f>>2]=r;if((1<<(q&7)&m|0)==0){o=0;p=0;break}if((c[n>>2]|0)>0){s=0;t=0;u=0;v=r}else{o=0;p=0;break}while(1){r=j+(v>>>3)|0;m=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((v&7)>>>0)&63;r=v+6|0;q=l>>>0>r>>>0?r:l;c[f>>2]=q;if(m>>>0<19>>>0){r=312504+(m<<3)|0;w=c[r+4>>2]|t;x=c[r>>2]|u}else{w=t;x=u}r=s+1|0;if((r|0)<(c[n>>2]|0)){s=r;t=w;u=x;v=q}else{o=w;p=x;break}}}}while(0);x=b+40|0;c[x>>2]=p;c[x+4>>2]=o;o=c[i>>2]|0;do{if(a>>>0<4>>>0){y=16384;z=(ca(e[1210480+(a<<1)>>1]|0,o)|0)>>5}else{if(a>>>0<10>>>0){y=o>>2;z=e[1210480+(a<<1)>>1]|0;break}else{A=-1094995529;B=b+28|0;c[B>>2]=A;return}}}while(0);A=(z|0)<1|(z|0)>(y|0)?-1094995529:z;B=b+28|0;c[B>>2]=A;return}function R2a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;h=b+8|0;j=c[h>>2]|0;k=b+16|0;l=c[k>>2]|0;m=b|0;n=c[m>>2]|0;o=n+(j>>>3)|0;p=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((j&7)>>>0)&65535;o=j+16|0;j=l>>>0>o>>>0?o:l;c[h>>2]=j;if((p|0)!=41215){KIb(a,f+16|0,2472608,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;q=-1094995529;i=g;return q|0}f=n+(j>>>3)|0;a=(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)>>>((j&7)>>>0)&7;f=j+3|0;c[h>>2]=l>>>0>f>>>0?f:l;l=e|0;c[l>>2]=a;a=c[h>>2]|0;f=c[k>>2]|0;j=n+(a>>>3)|0;p=(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)>>>((a&7)>>>0)&2097151;j=a+21|0;c[h>>2]=f>>>0>j>>>0?j:f;c[e+24>>2]=p;p=c[l>>2]|0;if((p&1|0)==0){c[e+32>>2]=0;r=p}else{p=c[h>>2]|0;f=c[k>>2]|0;j=n+(p>>>3)|0;n=(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)>>>((p&7)>>>0)&16383;j=p+14|0;c[h>>2]=f>>>0>j>>>0?j:f;c[e+32>>2]=n+1;n=c[k>>2]|0;f=(c[h>>2]|0)+2|0;c[h>>2]=n>>>0>f>>>0?f:n;r=c[l>>2]|0}do{if((r&2|0)!=0){Q2a(b,e);n=c[h>>2]|0;f=c[k>>2]|0;j=(c[m>>2]|0)+(n>>>3)|0;p=n+6|0;a=f>>>0>p>>>0?p:f;if(((d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24)&63<<(n&7)|0)==0){s=a}else{n=a+25|0;s=f>>>0>n>>>0?n:f}c[h>>2]=s;n=-s&7;if((n|0)==0){break}a=n+s|0;c[h>>2]=f>>>0>a>>>0?a:f}}while(0);if((c[l>>2]&4|0)!=0){q=-1094995529;i=g;return q|0}l=c[k>>2]|0;k=(c[h>>2]|0)+24|0;c[h>>2]=l>>>0>k>>>0?k:l;q=0;i=g;return q|0}function S2a(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+168|0;k=j|0;l=j+8|0;m=j+16|0;n=j+96|0;o=j+104|0;p=j+112|0;c[k>>2]=g;c[l>>2]=h;q=c[b>>2]|0;r=q;s=(h|0)!=0?37:8;if((c[b+176>>2]&1|0)!=0){t=h>>>0>2147483639>>>0|(g|0)==0;u=t?0:g;g=t?0:h;c[m>>2]=u;c[m+12>>2]=g;c[m+16>>2]=g+8;c[m+4>>2]=u+(g+7>>3);c[m+8>>2]=0;if((R2a(d,m,j+40|0,127)|0)==0){g=c[q+72>>2]|0;if((g|0)==0){v=c[q+68>>2]|0}else{v=g}c[b+304>>2]=v}c[e>>2]=c[k>>2];v=c[l>>2]|0;c[f>>2]=v;w=v;i=j;return w|0}v=q+96|0;g=q+4|0;u=q;t=m|0;x=m+12|0;y=m+16|0;z=m+4|0;A=m+8|0;B=q+20|0;C=q+40|0;D=C;E=q+72|0;F=q+68|0;G=b+304|0;H=C;C=b+224|0;b=0;I=h;a:while(1){h=c[v>>2]|0;do{if((I|0)==0){J=c[g>>2]|0;if((h+s|0)>(J|0)){K=b;L=-100;break a}else{M=b;N=h;O=J;P=0}}else{J=c[g>>2]|0;if((h+37|0)<=(J|0)){M=b;N=h;O=J;P=I;break}c[n>>2]=(I|0)<74?I:74;c[o>>2]=c[k>>2];if(!((IWa(r,-100,o,n)|0)==-1)){w=-12;Q=33;break a}J=c[n>>2]|0;c[k>>2]=(c[k>>2]|0)+J;R=(c[l>>2]|0)-J|0;c[l>>2]=R;M=J+b|0;N=c[v>>2]|0;O=c[g>>2]|0;P=R}}while(0);if((N+s|0)>(O|0)){b=M;I=P;continue}else{S=N;T=O}do{h=c[u>>2]|0;R=h+S|0;do{if((a[R]|0)==-1){if(!((a[h+(S+1)|0]|0)==-96)){break}J=T-S<<3;U=J>>>0>2147483639>>>0;V=U?0:R;W=U?0:J;c[t>>2]=V;c[x>>2]=W;c[y>>2]=W+8;c[z>>2]=V+(W>>3);c[A>>2]=0;if((R2a(d,m,(c[B>>2]|0)==0?D:p,127)|0)!=0){break}if((P2a((c[u>>2]|0)+(c[v>>2]|0)|0,(c[A>>2]|0)/8|0)|0)!=0){break}if((c[B>>2]|0)!=0){Q=23;break a}c[B>>2]=1;W=c[E>>2]|0;if((W|0)==0){X=c[F>>2]|0}else{X=W}c[G>>2]=X;c[C>>2]=(c[H>>2]|0)>>>1&1}}while(0);S=(c[v>>2]|0)+1|0;c[v>>2]=S;T=c[g>>2]|0;}while((S+s|0)<=(T|0));b=M;I=c[l>>2]|0}if((Q|0)==23){c[B>>2]=0;B=(c[v>>2]|0)-(c[g>>2]|0)|0;c[v>>2]=0;K=M;L=B}else if((Q|0)==33){i=j;return w|0}if((K|0)==0){Q=27}else{if((c[l>>2]|0)==0&(L|0)==-100){Y=0}else{Q=27}}do{if((Q|0)==27){if((IWa(r,L,k,l)|0)<0){Y=c[l>>2]|0;break}if((L|0)==-100){Z=-100}else{B=K+L|0;c[q+24>>2]=(B|0)>0?0:-B|0;Z=B}c[e>>2]=c[k>>2];c[f>>2]=c[l>>2];w=Z;i=j;return w|0}}while(0);c[e>>2]=0;c[f>>2]=0;w=Y+K|0;i=j;return w|0}function T2a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a+60|0;e=c[d>>2]|0;l8(e+4|0,a);c[e>>2]=a;e=a+796|0;c[e>>2]=c[a+792>>2];f=c[d>>2]|0;d=a+412|0;g=c[d>>2]|0;h=3-((g|0)/11025|0)|0;c[f+1324>>2]=((g+511>>9)+3&-4)<<((h|0)<0?0:h);c[f+1968>>2]=((c[d>>2]|0)+511>>9<<1)+6&-8;d=c[e>>2]|0;if((d|0)==8){c[a+420>>2]=5;j=0;i=b;return j|0}else if((d|0)==16){c[a+420>>2]=6;j=0;i=b;return j|0}else if((d|0)==24){c[a+420>>2]=7;j=0;i=b;return j|0}else{KIb(a,16,2637368,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;j=-1094995529;i=b;return j|0}return 0}function U2a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;j=i;i=i+16|0;k=j|0;l=e+60|0;m=c[l>>2]|0;n=m;c[k>>2]=f;c[k+4>>2]=0;c[k+8>>2]=0;o=m+1304|0;p=h+28|0;q=c[p>>2]|0;if((q|0)<8){r=-1094995529;i=j;return r|0}s=h+24|0;h=c[s>>2]|0;t=q>>>0>268435455>>>0?-8:q<<3;q=t>>>0>2147483639>>>0|(h|0)==0;u=q?0:h;h=q?0:t;t=o;c[t>>2]=u;v=m+1316|0;c[v>>2]=h;w=m+1320|0;c[w>>2]=h+8;c[m+1308>>2]=u+(h>>3);h=m+1312|0;c[h>>2]=0;if(q){r=q?-1094995529:0;i=j;return r|0}q=R2a(e,o,m+1248|0,0)|0;if((q|0)<0){r=q;i=j;return r|0}q=e+696|0;do{if((c[q>>2]&131073|0)==0){x=0}else{o=(c[h>>2]|0)/8|0;if((P2a(c[s>>2]|0,o)|0)==0){x=o;break}KIb(e,16,2445960,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;if((c[q>>2]&8|0)==0){x=o;break}else{r=-1094995529}i=j;return r|0}}while(0);o=m+1252|0;u=c[o>>2]|0;if(!((u|0)==2|(u|0)==4)){KIb(e,16,2356688,(y=i,i=i+8|0,c[y>>2]=u,y)|0);i=y;r=-1163346256;i=j;return r|0}z=c[m+1256>>2]|0;if((z|0)!=0){KIb(e,16,2293824,(y=i,i=i+8|0,c[y>>2]=z,y)|0);i=y;r=-1094995529;i=j;return r|0}z=c[m+1264>>2]|0;do{if((u|0)==2){if((z|0)<=2){break}KIb(e,16,2242776,(y=i,i=i+8|0,c[y>>2]=z,y)|0);i=y;r=-1094995529;i=j;return r|0}else{if((z|0)<=6){break}KIb(e,16,2201480,(y=i,i=i+8|0,c[y>>2]=z,y)|0);i=y;r=-1094995529;i=j;return r|0}}while(0);z=m+1264|0;u=m+1276|0;if((c[u>>2]|0)<1){KIb(e,16,2169656,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;r=-1094995529;i=j;return r|0}A=c[m+1268>>2]|0;B=e+796|0;c[B>>2]=A;if((A|0)==24){c[e+420>>2]=7}else if((A|0)==16){c[e+420>>2]=6}else if((A|0)==8){c[e+420>>2]=5}else{KIb(e,16,2637368,(y=i,i=i+8|0,c[y>>2]=A,y)|0);i=y;r=-1094995529;i=j;return r|0}A=c[m+1260>>2]|0;C=e+412|0;if((A|0)!=(c[C>>2]|0)){c[C>>2]=A;D=c[l>>2]|0;l=3-((A|0)/11025|0)|0;c[D+1324>>2]=((A+511>>9)+3&-4)<<((l|0)<0?0:l);c[D+1968>>2]=((c[C>>2]|0)+511>>9<<1)+6&-8}C=m+1288|0;D=c[C>>2]|0;l=c[C+4>>2]|0;if(!((D|0)==0&(l|0)==0)){C=e+448|0;c[C>>2]=D;c[C+4>>2]=l}l=e+416|0;c[l>>2]=c[z>>2];z=c[m+1280>>2]|0;if((z|0)==0){E=c[u>>2]|0}else{E=z}z=m+1328|0;c[z>>2]=E;c[f+76>>2]=E;E=J5a(e,k,0)|0;if((E|0)<0){r=E;i=j;return r|0}K5a(e);E=c[l>>2]|0;do{if((c[B>>2]|0)<17){k=m+1332|0;xJb(k,m+1336|0,SKb(0,E,c[z>>2]|0,7,0)|0);u=c[k>>2]|0;if((u|0)==0){r=-12;i=j;return r|0}k=TKb(m+1340|0,0,u,c[l>>2]|0,c[z>>2]|0,7,0)|0;if((k|0)<0){r=k}else{break}i=j;return r|0}else{if((E|0)<=0){break}k=f+64|0;u=m+1340|0;C=0;do{c[u+(C<<2)>>2]=c[(c[k>>2]|0)+(C<<2)>>2];C=C+1|0;}while((C|0)<(E|0))}}while(0);E=c[z>>2]|0;a:do{if((E|0)<16){C=c[l>>2]|0;if((C|0)<=0){break}k=m+1340|0;u=0;D=E;A=C;while(1){C=c[k+(u<<2)>>2]|0;if((D|0)>0){F=c[t>>2]|0;G=0;do{H=c[B>>2]|0;I=c[h>>2]|0;J=c[w>>2]|0;K=F+(I>>>3)|0;L=32-H|0;M=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((I&7)>>>0)<<L>>L;L=I+H|0;c[h>>2]=J>>>0>L>>>0?L:J;c[C+(G<<2)>>2]=M;G=G+1|0;N=c[z>>2]|0;}while((G|0)<(N|0));O=N;P=c[l>>2]|0}else{O=D;P=A}G=u+1|0;if((G|0)<(P|0)){u=G;D=O;A=P}else{break}}}else{A=c[o>>2]|0;b:do{if((A|0)==2){D=0;while(1){Q=c[l>>2]|0;if((D|0)>=(Q|0)){break}u=W2a(n,D)|0;if((u|0)!=0){r=u;R=115;break}D=D+1|0}if((R|0)==115){i=j;return r|0}if((Q|0)!=2){break}D=c[h>>2]|0;u=c[w>>2]|0;k=c[t>>2]|0;G=k+(D>>>3)|0;C=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((D&7)>>>0)&1;G=D+1|0;D=u>>>0>G>>>0?G:u;c[h>>2]=D;G=C+1|0;c[m+1948>>2]=G;if(G>>>0>1>>>0){G=k+(D>>>3)|0;C=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((D&7)>>>0);G=D+6|0;F=u>>>0>G>>>0?G:u;c[h>>2]=F;b[m+1954>>1]=C&63;S=F}else{S=D}D=k+(S>>>3)|0;k=(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)>>>((S&7)>>>0);D=S+3|0;c[h>>2]=u>>>0>D>>>0?D:u;a[m+1972|0]=k&7;k=X2a(n,0,1,(c[z>>2]|0)-1|0)|0;if((k|0)==0){break}else{r=k}i=j;return r|0}else if((A|0)==4){k=c[h>>2]|0;u=c[t>>2]|0;D=d[u+(k>>>3)|0]|0;F=c[w>>2]|0;C=((k|0)<(F|0))+k|0;c[h>>2]=C;c:do{if((D&1<<(k&7)|0)==0){G=c[l>>2]|0;if((G|0)<=0){break a}M=m+1973|0;J=0;while(1){a[M+(J<<2)|0]=0;a[M+(J<<2)+2|0]=J;L=J+1|0;if((L|0)<(G|0)){J=L}else{T=G;break}}}else{G=u+(C>>>3)|0;J=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((C&7)>>>0)&15;G=C+4|0;M=F>>>0>G>>>0?G:F;c[h>>2]=M;G=J+1|0;if((G|0)>(c[l>>2]|0)){r=-1094995529;i=j;return r|0}J=m+1973|0;L=0;H=0;I=M;M=F;K=u;d:while(1){U=K+(I>>>3)|0;V=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((I&7)>>>0)&15;U=I+4|0;W=M>>>0>U>>>0?U:M;c[h>>2]=W;if((V|0)>=(c[l>>2]|0)){r=-1094995529;R=115;break}U=1<<V;if((U&L|0)!=0){r=-1094995529;R=115;break}X=(d[K+(W>>>3)|0]|0)>>>((W&7)>>>0);c[h>>2]=((W|0)<(M|0))+W;W=X&1;a[J+(H<<2)|0]=W;do{if(W<<24>>24==0){Y=L}else{X=c[h>>2]|0;Z=c[w>>2]|0;_=(c[t>>2]|0)+(X>>>3)|0;$=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((X&7)>>>0);_=X+2|0;c[h>>2]=Z>>>0>_>>>0?_:Z;Z=J+(H<<2)+1|0;a[Z]=$&3;$=c[h>>2]|0;_=c[w>>2]|0;X=(c[t>>2]|0)+($>>>3)|0;aa=(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)>>>(($&7)>>>0);X=$+4|0;c[h>>2]=_>>>0>X>>>0?X:_;_=aa&15;a[J+(H<<2)+3|0]=_;aa=_&255;if((a[Z]|0)!=1){if((1<<aa&L|0)==0){r=-1094995529;R=115;break d}else{Y=L;break}}if((V|0)==(aa|0)){r=-1094995529;R=115;break d}Z=1<<aa;if((Z&L|0)!=0){r=-1094995529;R=115;break d}Y=Z|L}}while(0);a[J+(H<<2)+2|0]=V;W=H+1|0;if((W|0)>=(G|0)){T=G;break c}L=Y|U;H=W;I=c[h>>2]|0;M=c[w>>2]|0;K=c[t>>2]|0}if((R|0)==115){i=j;return r|0}}}while(0);if((T|0)<=0){break}u=m+1973|0;F=m+1972|0;C=0;e:while(1){k=u+(C<<2)|0;do{if((a[k]|0)!=0){if((a[u+(C<<2)+1|0]|0)!=1){break}D=W2a(n,a[u+(C<<2)+3|0]|0)|0;if((D|0)!=0){r=D;R=115;break e}}}while(0);D=u+(C<<2)+2|0;K=W2a(n,a[D]|0)|0;if((K|0)!=0){r=K;R=115;break}if((a[k]|0)!=0){a[F]=a[832480+(a[u+(C<<2)+1|0]|0)|0]|0;K=X2a(n,a[u+(C<<2)+3|0]|0,a[D]|0,(c[z>>2]|0)-1|0)|0;if((K|0)!=0){r=K;R=115;break}}C=C+1|0;if((C|0)>=(T|0)){break b}}if((R|0)==115){i=j;return r|0}}}while(0);if((c[l>>2]|0)<=0){break}A=m+1340|0;C=0;do{u=c[A+(C<<2)>>2]|0;F=a[m+(C+1404)|0]|0;if(!(F<<24>>24==0)){Y2a(u,F<<24>>24,c[z>>2]|0)}F=m+(C+1420)|0;K=a[F]|0;f:do{if(K<<24>>24>0){if((c[z>>2]|0)>0){ba=0;ca=K}else{break}while(1){D=u+(ba<<2)|0;c[D>>2]=c[D>>2]<<(ca<<24>>24);D=ba+1|0;if((D|0)>=(c[z>>2]|0)){break f}ba=D;ca=a[F]|0}}}while(0);C=C+1|0;}while((C|0)<(c[l>>2]|0))}}while(0);ca=c[h>>2]|0;ba=-ca&7;R=c[w>>2]|0;if((ba|0)==0){da=ca}else{w=ba+ca|0;ca=R>>>0>w>>>0?w:R;c[h>>2]=ca;da=ca}ca=da+24|0;da=R>>>0>ca>>>0?ca:R;c[h>>2]=da;R=(c[v>>2]|0)-da|0;do{if((R|0)<0){KIb(e,48,2142712,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}else{if((R|0)<=0){break}KIb(e,48,2119128,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}}while(0);do{if((c[q>>2]&131073|0)!=0){if((P2a((c[s>>2]|0)+x|0,((c[h>>2]|0)/8|0)-x|0)|0)==0){break}KIb(e,16,2445960,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;if((c[q>>2]&8|0)==0){break}else{r=-1094995529}i=j;return r|0}}while(0);q=c[e+420>>2]|0;do{if((q|0)==6){e=c[l>>2]|0;if((e|0)<=0){break}y=c[f+64>>2]|0;x=m+1340|0;h=c[z>>2]|0;if((h|0)>0){ea=0}else{break}do{s=c[y+(ea<<2)>>2]|0;R=c[x+(ea<<2)>>2]|0;da=0;do{b[s+(da<<1)>>1]=c[R+(da<<2)>>2];da=da+1|0;}while((da|0)<(h|0));ea=ea+1|0;}while((ea|0)<(e|0))}else if((q|0)==5){e=c[l>>2]|0;if((e|0)<=0){break}h=f+64|0;x=m+1340|0;y=0;da=c[z>>2]|0;R=e;while(1){e=c[(c[h>>2]|0)+(y<<2)>>2]|0;s=c[x+(y<<2)>>2]|0;if((da|0)>0){v=0;do{a[e+v|0]=(c[s+(v<<2)>>2]|0)+128;v=v+1|0;fa=c[z>>2]|0;}while((v|0)<(fa|0));ga=fa;ha=c[l>>2]|0}else{ga=da;ha=R}v=y+1|0;if((v|0)<(ha|0)){y=v;da=ga;R=ha}else{break}}}else if((q|0)==7){R=c[l>>2]|0;if((R|0)<=0){break}da=c[f+64>>2]|0;y=0;x=c[z>>2]|0;h=R;while(1){R=c[da+(y<<2)>>2]|0;if((x|0)>0){v=0;do{s=R+(v<<2)|0;c[s>>2]=c[s>>2]<<8;v=v+1|0;ia=c[z>>2]|0;}while((v|0)<(ia|0));ja=ia;ka=c[l>>2]|0}else{ja=x;ka=h}v=y+1|0;if((v|0)<(ka|0)){y=v;x=ja;h=ka}else{break}}}}while(0);c[g>>2]=1;r=c[p>>2]|0;i=j;return r|0}function V2a(a){a=a|0;mJb((c[a+60>>2]|0)+1332|0);return 0}function W2a(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;h=i;i=i+1024|0;j=h|0;k=c[f>>2]|0;l=c[f+1340+(g<<2)>>2]|0;m=(c[f+1328>>2]|0)-1|0;n=f+1312|0;o=c[n>>2]|0;p=f+1304|0;q=c[p>>2]|0;r=d[q+(o>>>3)|0]|0;s=f+1320|0;t=c[s>>2]|0;u=((o|0)<(t|0))+o|0;c[n>>2]=u;if((r&1<<(o&7)|0)==0){v=0}else{o=q+(u>>>3)|0;q=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((u&7)>>>0)&15;o=u+4|0;c[n>>2]=t>>>0>o>>>0?o:t;v=q+1&255}a[f+1420+g|0]=v;q=v<<24>>24;v=c[k+796>>2]|0;if((q|0)>=(v|0)){w=-1094995529;i=h;return w|0}k=v-q|0;q=c[n>>2]|0;v=c[s>>2]|0;t=c[p>>2]|0;o=t+(q>>>3)|0;u=32-k|0;r=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((q&7)>>>0)<<u>>u;u=q+k|0;c[n>>2]=v>>>0>u>>>0?u:v;v=l+4|0;c[l>>2]=r;r=c[n>>2]|0;l=c[s>>2]|0;u=t+(r>>>3)|0;t=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((r&7)>>>0);u=r+2|0;c[n>>2]=l>>>0>u>>>0?u:l;a[f+1404+g|0]=t&3;t=c[n>>2]|0;g=c[s>>2]|0;l=c[p>>2]|0;u=l+(t>>>3)|0;r=(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)>>>((t&7)>>>0)&7;u=t+3|0;t=g>>>0>u>>>0?u:g;c[n>>2]=t;u=r+1|0;k=f+1948|0;c[k>>2]=u;q=m&65535;do{if(u>>>0>1>>>0){if(((c[f+1316>>2]|0)-t|0)<((u*6|0)-6|0)){w=-1094995529;i=h;return w|0}a:do{if((r|0)==0){x=m;y=0}else{o=f+1968|0;z=m;A=0;B=0;C=t;D=g;E=l;while(1){F=E+(C>>>3)|0;G=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((C&7)>>>0)&63;F=C+6|0;c[n>>2]=D>>>0>F>>>0?F:D;F=(ca(G-B|0,c[o>>2]|0)|0)&65535;b[f+1952+(A<<1)>>1]=F;if(F<<16>>16<1){w=-1094995529;break}H=z-(F<<16>>16)|0;F=A+1|0;if((F|0)>=((c[k>>2]|0)-1|0)){x=H;y=F;break a}z=H;A=F;B=G;C=c[n>>2]|0;D=c[s>>2]|0;E=c[p>>2]|0}i=h;return w|0}}while(0);if((x|0)<1){w=-1094995529}else{I=y;J=x&65535;break}i=h;return w|0}else{I=0;J=q}}while(0);b[f+1952+(I<<1)>>1]=J;if((c[k>>2]|0)<=0){w=0;i=h;return w|0}J=f+1436|0;I=f+1438|0;q=f+1440|0;x=f+1442|0;y=j|0;l=f+1228|0;g=f+2176|0;t=f+2688|0;m=0;r=v;v=0;b:while(1){u=f+1952+(m<<1)|0;E=b[u>>1]|0;D=E<<16>>16;C=c[n>>2]|0;B=c[p>>2]|0;A=d[B+(C>>>3)|0]|0;z=c[s>>2]|0;o=((C|0)<(z|0))+C|0;c[n>>2]=o;c:do{if((A&1<<(C&7)|0)==0){G=Z2a(f,r,D)|0;if((G|0)<0){w=G;K=71;break b}}else{G=B+(o>>>3)|0;F=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((o&7)>>>0)&15;G=o+4|0;H=z>>>0>G>>>0?G:z;c[n>>2]=H;G=e[699856+(F<<1)>>1]|0;do{if((v|0)>0){L=d[B+(H>>>3)|0]|0;M=((H|0)<(z|0))+H|0;c[n>>2]=M;if((L&1<<(H&7)|0)==0){N=M;K=19;break}if((G|0)>(v|0)){w=-1094995529;K=71;break b}if(E<<16>>16<0){w=-1094995529;K=71;break b}else{O=r+(-G<<2)|0;P=G+D|0}}else{N=H;K=19}}while(0);do{if((K|0)==19){K=0;if((G|0)>(D|0)){w=-1094995529;K=71;break b}H=B+(N>>>3)|0;M=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((N&7)>>>0)&3;H=N+2|0;c[n>>2]=z>>>0>H>>>0?H:z;if((M|0)==3){w=-1094995529;K=71;break b}H=Z2a(f,r,G)|0;if((H|0)<0){w=H;K=71;break b}if((M|0)==0){O=r;P=D;break}Y2a(r,M,G);O=r;P=D}}while(0);M=c[n>>2]|0;H=c[p>>2]|0;L=d[H+(M>>>3)|0]|0;Q=c[s>>2]|0;R=((M|0)<(Q|0))+M|0;c[n>>2]=R;if((L&1<<(M&7)|0)==0){S=0;T=R}else{M=H+(R>>>3)|0;L=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((R&7)>>>0)&15;M=R+4|0;R=Q>>>0>M>>>0?M:Q;c[n>>2]=R;S=L+1|0;T=R}R=(d[H+(T>>>3)|0]|0)>>>((T&7)>>>0);L=((T|0)<(Q|0))+T|0;c[n>>2]=L;M=R&1;R=M|6;U=d[H+(L>>>3)|0]|0;V=((L|0)<(Q|0))+L|0;c[n>>2]=V;if((1<<(L&7)&U|0)==0){W=10;X=V}else{U=H+(V>>>3)|0;L=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((V&7)>>>0)&7;U=V+3|0;V=Q>>>0>U>>>0?U:Q;c[n>>2]=V;U=9-L|0;if(U>>>0<3>>>0){w=-1094995529;K=71;break b}else{W=U;X=V}}V=H+(X>>>3)|0;U=(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((X&7)>>>0)<<22>>22;V=X+10|0;L=Q>>>0>V>>>0?V:Q;c[n>>2]=L;V=U&65535;b[J>>1]=V;U=H+(L>>>3)|0;Y=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((L&7)>>>0)<<22>>22;U=L+10|0;L=Q>>>0>U>>>0?U:Q;c[n>>2]=L;b[I>>1]=Y;Y=H+(L>>>3)|0;U=32-R|0;Z=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((L&7)>>>0)<<U>>U;Y=L+R|0;L=Q>>>0>Y>>>0?Y:Q;c[n>>2]=L;Y=4-M|0;b[q>>1]=Z<<Y;Z=H+(L>>>3)|0;M=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((L&7)>>>0)<<U>>U;U=L+R|0;L=Q>>>0>U>>>0?U:Q;c[n>>2]=L;b[x>>1]=M<<Y;if((F|0)==15|(F|0)==0){_=V}else{V=(d[H+(L>>>3)|0]|0)>>>((L&7)>>>0);M=((L|0)<(Q|0))+L|0;c[n>>2]=M;L=R-(V&1)|0;V=0;R=4;U=M;M=Q;Q=H;while(1){if((R&3|0)==0){H=Q+(U>>>3)|0;Z=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((U&7)>>>0)&3;H=U+2|0;$=M>>>0>H>>>0?H:M;c[n>>2]=$;aa=L-Z|0;ba=$}else{aa=V;ba=U}$=Q+(ba>>>3)|0;Z=32-aa|0;H=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((ba&7)>>>0)<<Z>>Z;Z=aa+ba|0;c[n>>2]=M>>>0>Z>>>0?Z:M;b[f+1436+(R<<1)>>1]=H<<Y;H=R+1|0;if((H|0)>=(G|0)){break}V=aa;R=H;U=c[n>>2]|0;M=c[s>>2]|0;Q=c[p>>2]|0}_=b[J>>1]|0}Q=_<<16>>16<<6;c[y>>2]=Q;d:do{if((F|0)==15){da=1}else{M=1;U=Q;R=Q;while(1){V=M+1|0;Y=(V|0)/2|0;L=b[f+1436+(M<<1)>>1]|0;H=R+((ca(U,L)|0)+256>>9)|0;c[j+(M-1<<2)>>2]=((ca(R,L)|0)+256>>9)+U;c[y>>2]=H;if((V|0)>3){H=y;Z=1;$=j+(M-2<<2)|0;while(1){ea=H+4|0;fa=c[$>>2]|0;ga=Z+1|0;ha=c[ea>>2]|0;ia=ha+((ca(fa,L)|0)+256>>9)|0;c[$>>2]=((ca(ha,L)|0)+256>>9)+fa;c[ea>>2]=ia;if((ga|0)<(Y|0)){H=ea;Z=ga;$=$-4|0}else{break}}}$=L<<6;c[j+(M<<2)>>2]=$;if((V|0)>=(G|0)){da=0;break d}M=V;U=$;R=c[y>>2]|0}}}while(0);Q=15-W|0;F=1<<32-Q;R=1<<Q-1;U=G>>>1;if((U|0)!=0){M=0;$=G;do{$=$-1|0;b[f+2176+($<<1)>>1]=F-((c[j+(M<<2)>>2]|0)+R>>Q);b[f+2176+(M<<1)>>1]=F-((c[j+($<<2)>>2]|0)+R>>Q);M=M+1|0;}while((M|0)<(U|0))}U=P-G|0;M=Z2a(f,O+(G<<2)|0,U)|0;if((M|0)<0){w=M;K=71;break b}if(da){ja=O}else{M=G>>>0>1>>>0;Q=0;R=O;while(1){b[f+2688+(Q<<1)>>1]=c[R>>2]>>S;$=Q+1|0;if(($|0)<(G|0)){Q=$;R=R+4|0}else{break}}ja=O+((M?G:1)<<2)|0}R=544-G|0;if((U|0)<=0){break}Q=1<<W-1;$=G&65520;F=($|0)==0;Z=f+2688+(R<<1)|0;H=G<<1;Y=G-545|0;ga=$>>>0<G>>>0;ea=U;ia=ja;while(1){fa=(R|0)>(ea|0)?ea:R;if((fa|0)>0){ha=~ea;ka=(Y|0)<(ha|0)?ha:Y;e:do{if(F){ha=0;la=ia;while(1){if(da){ma=Q}else{na=0;oa=Q;while(1){pa=na+ha|0;qa=ca(b[f+2176+((na|3)<<1)>>1]|0,b[f+2688+(pa+3<<1)>>1]|0)|0;ra=ca(b[f+2176+((na|2)<<1)>>1]|0,b[f+2688+(pa+2<<1)>>1]|0)|0;sa=ca(b[f+2176+((na|1)<<1)>>1]|0,b[f+2688+(pa+1<<1)>>1]|0)|0;ta=qa+oa+ra+sa+(ca(b[f+2176+(na<<1)>>1]|0,b[f+2688+(pa<<1)>>1]|0)|0)|0;pa=na+4|0;if((pa|0)<(G|0)){na=pa;oa=ta}else{ma=ta;break}}}oa=ma>>W;if((oa|0)<-8192){ua=-8192}else{ua=(oa|0)>8191?8191:oa}oa=(ua<<S)-(c[la>>2]|0)|0;c[la>>2]=oa;b[f+2688+(ha+G<<1)>>1]=oa>>S;oa=ha+1|0;if((oa|0)<(fa|0)){ha=oa;la=la+4|0}else{break}}}else{if(ga){va=0;wa=ia}else{la=0;ha=ia;while(1){V=(Ee[c[l>>2]&511](f+2688+(la<<1)|0,g,$)|0)+Q>>W;if((V|0)<-8192){xa=-8192}else{xa=(V|0)>8191?8191:V}V=(xa<<S)-(c[ha>>2]|0)|0;c[ha>>2]=V;b[f+2688+(la+G<<1)>>1]=V>>S;V=la+1|0;if((V|0)<(fa|0)){la=V;ha=ha+4|0}else{break e}}}while(1){ha=$;la=(Ee[c[l>>2]&511](f+2688+(va<<1)|0,g,$)|0)+Q|0;do{V=ha+va|0;L=ca(b[f+2176+((ha|3)<<1)>>1]|0,b[f+2688+(V+3<<1)>>1]|0)|0;oa=ca(b[f+2176+((ha|2)<<1)>>1]|0,b[f+2688+(V+2<<1)>>1]|0)|0;na=ca(b[f+2176+((ha|1)<<1)>>1]|0,b[f+2688+(V+1<<1)>>1]|0)|0;la=L+la+oa+na+(ca(b[f+2176+(ha<<1)>>1]|0,b[f+2688+(V<<1)>>1]|0)|0)|0;ha=ha+4|0;}while((ha|0)<(G|0));ha=la>>W;if((ha|0)<-8192){ya=-8192}else{ya=(ha|0)>8191?8191:ha}ha=(ya<<S)-(c[wa>>2]|0)|0;c[wa>>2]=ha;b[f+2688+(va+G<<1)>>1]=ha>>S;ha=va+1|0;if((ha|0)<(fa|0)){va=ha;wa=wa+4|0}else{break}}}}while(0);za=ia+(~ka<<2)|0}else{za=ia}ha=ea-fa|0;if((ha|0)<=0){break c}nrc(t|0,Z|0,H)|0;ea=ha;ia=za}}}while(0);D=b[u>>1]|0;z=m+1|0;if((z|0)<(c[k>>2]|0)){m=z;r=r+(D<<2)|0;v=D}else{w=0;K=71;break}}if((K|0)==71){i=h;return w|0}return 0}function X2a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=e+1304|0;j=c[e+1340+(f<<2)>>2]|0;f=j+4|0;k=c[e+1340+(g<<2)>>2]|0;g=k+4|0;switch(a[e+1972|0]|0){case 6:{l=g;m=f;break};case 3:{if((h|0)>0){n=0}else{o=0;return o|0}while(1){p=n+1|0;q=j+(p<<2)|0;r=k+(p<<2)|0;s=c[r>>2]|0;t=(c[q>>2]|0)-(s>>1)|0;c[q>>2]=t;c[r>>2]=t+s;if((p|0)<(h|0)){n=p}else{o=0;break}}return o|0};case 7:{l=f;m=g;break};case 2:{if((h|0)>0){u=0}else{o=0;return o|0}while(1){n=u+1|0;p=j+(n<<2)|0;c[p>>2]=(c[k+(n<<2)>>2]|0)-(c[p>>2]|0);if((n|0)<(h|0)){u=n}else{o=0;break}}return o|0};case 4:{v=g;w=f;x=9;break};case 1:{if((h|0)>0){y=0}else{o=0;return o|0}while(1){u=y+1|0;n=k+(u<<2)|0;c[n>>2]=(c[n>>2]|0)+(c[j+(u<<2)>>2]|0);if((u|0)<(h|0)){y=u}else{o=0;break}}return o|0};case 5:{v=f;w=g;x=9;break};default:{o=0;return o|0}}if((x|0)==9){x=e+1312|0;g=c[x>>2]|0;f=c[i>>2]|0;y=d[f+(g>>>3)|0]|0;j=c[e+1320>>2]|0;k=((g|0)<(j|0))+g|0;c[x>>2]=k;if((y&1<<(g&7)|0)==0){z=0;A=k}else{g=f+(k>>>3)|0;y=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((k&7)>>>0)&15;g=k+4|0;k=j>>>0>g>>>0?g:j;c[x>>2]=k;z=y+1|0;A=k}k=f+(A>>>3)|0;f=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((A&7)>>>0)<<22>>22;k=A+10|0;c[x>>2]=j>>>0>k>>>0?k:j;if((h|0)>0){B=0}else{o=0;return o|0}while(1){j=v+(B<<2)|0;c[j>>2]=((ca(c[w+(B<<2)>>2]>>z,f)|0)+128>>8<<z)-(c[j>>2]|0);j=B+1|0;if((j|0)<(h|0)){B=j}else{o=0;break}}return o|0}if((h|0)<256){o=-1094995529;return o|0}B=e+1312|0;z=c[B>>2]|0;f=i|0;i=c[f>>2]|0;w=d[i+(z>>>3)|0]|0;v=e+1320|0;j=c[v>>2]|0;k=((z|0)<(j|0))+z|0;c[B>>2]=k;if((w&1<<(z&7)|0)==0){C=0;D=k}else{z=i+(k>>>3)|0;w=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((k&7)>>>0)&15;z=k+4|0;k=j>>>0>z>>>0?z:j;c[B>>2]=k;C=w+1|0;D=k}k=(d[i+(D>>>3)|0]|0)>>>((D&7)>>>0);w=((D|0)<(j|0))+D|0;c[B>>2]=w;D=8<<(k&1);k=w&7;z=d[i+(w>>>3)|0]|0;x=((w|0)<(j|0))+w|0;c[B>>2]=x;w=x&7;A=d[i+(x>>>3)|0]|0;c[B>>2]=((x|0)<(j|0))+x;x=(D|0)>0;if(x){j=0;i=0;while(1){y=c[B>>2]|0;g=c[v>>2]|0;u=c[f>>2]|0;if((i&3|0)==0){n=u+(y>>>3)|0;p=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((y&7)>>>0)&7;n=y+3|0;s=g>>>0>n>>>0?n:g;c[B>>2]=s;E=14-p|0;F=s}else{E=j;F=y}y=u+(F>>>3)|0;u=32-E|0;s=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((F&7)>>>0)<<u>>u;u=F+E|0;c[B>>2]=g>>>0>u>>>0?u:g;b[e+2176+(i<<1)>>1]=s;s=i+1|0;if((s|0)<(D|0)){j=E;i=s}else{break}}}i=(D|0)/2|0;E=h+1-D|0;if((1<<k&z|0)!=0&(D|0)>1){z=0;do{k=l+(z<<2)|0;c[k>>2]=(c[m+(z<<2)>>2]|0)+(c[k>>2]|0);z=z+1|0;}while((z|0)<(i|0))}do{if((1<<w&A|0)!=0){z=i+E|0;if((z|0)<(h|0)){G=z}else{break}do{z=l+(G<<2)|0;c[z>>2]=(c[m+(G<<2)>>2]|0)+(c[z>>2]|0);G=G+1|0;}while((G|0)<(h|0))}}while(0);if(x){x=0;h=m;while(1){b[e+2688+(x<<1)>>1]=c[h>>2]>>C;G=x+1|0;if((G|0)<(D|0)){x=G;h=h+4|0}else{break}}H=m+(D<<2)|0}else{H=m}m=544-D|0;if((E|0)<=0){o=0;return o|0}h=e+2688|0;x=D<<1;G=(D|0)==16;A=e+1228|0;w=e+2176|0;z=e+2190|0;k=e+2188|0;j=e+2186|0;B=e+2184|0;F=e+2182|0;f=e+2180|0;v=e+2178|0;s=D-545|0;g=E;E=H;H=l+(i<<2)|0;while(1){i=(g|0)>(m|0)?m:g;l=(i|0)>0;do{if(l){u=~g;y=(s|0)<(u|0)?u:s;u=0;p=E;while(1){b[e+2688+(u+D<<1)>>1]=c[p>>2]>>C;n=u+1|0;if((n|0)<(i|0)){u=n;p=p+4|0}else{break}}p=E+(~y<<2)|0;if(!l){I=H;J=p;break}u=~g;n=(s|0)<(u|0)?u:s;u=0;t=H;while(1){if(G){K=Ee[c[A>>2]&511](e+2688+(u<<1)|0,w,16)|0}else{r=ca(b[z>>1]|0,b[e+2688+(u+7<<1)>>1]|0)|0;q=(ca(b[k>>1]|0,b[e+2688+(u+6<<1)>>1]|0)|0)+r|0;r=q+(ca(b[j>>1]|0,b[e+2688+(u+5<<1)>>1]|0)|0)|0;q=r+(ca(b[B>>1]|0,b[e+2688+(u+4<<1)>>1]|0)|0)|0;r=q+(ca(b[F>>1]|0,b[e+2688+(u+3<<1)>>1]|0)|0)|0;q=r+(ca(b[f>>1]|0,b[e+2688+(u+2<<1)>>1]|0)|0)|0;r=q+(ca(b[v>>1]|0,b[e+2688+(u+1<<1)>>1]|0)|0)|0;K=r+(ca(b[w>>1]|0,b[e+2688+(u<<1)>>1]|0)|0)|0}r=K+512>>10;if((r|0)<-8192){L=-8192}else{L=(r|0)>8191?8191:r}c[t>>2]=(L<<C)-(c[t>>2]|0);r=u+1|0;if((r|0)<(i|0)){u=r;t=t+4|0}else{break}}I=H+(~n<<2)|0;J=p}else{I=H;J=E}}while(0);nrc(h|0,e+2688+(i<<1)|0,x)|0;l=g-i|0;if((l|0)>0){g=l;E=J;H=I}else{o=0;break}}return o|0}function Y2a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((d|0)<2){return}if((b|0)==1){e=a+4|0;f=c[a>>2]|0;g=d-1|0;h=g>>1;if((h|0)>0){i=h<<1|1;j=f;k=0;l=e;while(1){m=(c[l>>2]|0)+j|0;c[l>>2]=m;n=l+4|0;o=(c[n>>2]|0)+m|0;c[n>>2]=o;n=k+1|0;if((n|0)<(h|0)){j=o;k=n;l=l+8|0}else{break}}p=o;q=a+(i<<2)|0}else{p=f;q=e}if((g&1|0)==0){return}c[q>>2]=(c[q>>2]|0)+p;return}else if((b|0)==3){p=a+4|0;q=c[p>>2]|0;g=(c[a>>2]|0)+q|0;c[p>>2]=g;if((d|0)<=2){return}p=c[a+8>>2]|0;e=p+q|0;q=d-3|0;if((q|0)<=0){return}f=0;i=a+12|0;o=p;p=e;l=e+g|0;while(1){g=(c[i>>2]|0)+o|0;e=g+p|0;k=e+l|0;c[i>>2]=k;j=f+1|0;if((j|0)<(q|0)){f=j;i=i+4|0;o=g;p=e;l=k}else{break}}return}else if((b|0)==2){b=a+4|0;l=c[b>>2]|0;p=(c[a>>2]|0)+l|0;c[b>>2]=p;if((d|0)<=2){return}b=a+8|0;o=d-2>>1;if((o|0)>0){i=(o<<1)+2|0;f=p;q=l;k=0;e=a;g=b;while(1){j=(c[g>>2]|0)+q|0;h=j+f|0;c[g>>2]=h;n=e+12|0;r=(c[n>>2]|0)+j|0;s=r+h|0;c[n>>2]=s;n=k+1|0;if((n|0)<(o|0)){f=s;q=r;k=n;e=g;g=g+8|0}else{break}}t=s;u=r;v=a+(i<<2)|0}else{t=p;u=l;v=b}if((d&1|0)==0){return}c[v>>2]=u+t+(c[v>>2]|0);return}else{return}}function Z2a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[b+1328>>2]|0)<(f|0)){g=-1094995529;return g|0}h=b+1312|0;i=c[h>>2]|0;j=b+1304|0;k=c[j>>2]|0;l=d[k+(i>>>3)|0]|0;m=b+1320|0;n=c[m>>2]|0;o=((i|0)<(n|0))+i|0;c[h>>2]=o;a:do{if((l&1<<(i&7)|0)==0){p=k+(o>>>3)|0;q=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((o&7)>>>0);p=o+6|0;c[h>>2]=n>>>0>p>>>0?p:n;p=_2a(b,q&63,e,f)|0;if((p|0)<0){g=p}else{break}return g|0}else{p=b+1324|0;q=c[p>>2]|0;r=(f|0)/(q|0)|0;s=f-(ca(r,q)|0)|0;t=(s|0)<((q|0)/2|0|0);u=(t&1^1)+r|0;r=(t?q:0)+s|0;if((u-2|0)>>>0>126>>>0){g=-1094995529;return g|0}s=k+(o>>>3)|0;q=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((o&7)>>>0)&63;s=o+6|0;c[h>>2]=n>>>0>s>>>0?s:n;a[b+2037|0]=q;b:do{if((u|0)>1){s=1;t=q;while(1){v=0;while(1){if((v|0)>=6){break}w=c[h>>2]|0;x=d[(c[j>>2]|0)+(w>>>3)|0]|0;c[h>>2]=((w|0)<(c[m>>2]|0))+w;if((x&1<<(w&7)|0)==0){v=v+1|0}else{break}}switch(v|0){case 6:{w=c[h>>2]|0;x=c[m>>2]|0;y=(c[j>>2]|0)+(w>>>3)|0;z=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((w&7)>>>0)&63;y=w+6|0;c[h>>2]=x>>>0>y>>>0?y:x;A=z;break};case 1:{A=t-1|0;break};case 2:{A=t+1|0;break};case 5:case 4:case 3:{z=c[h>>2]|0;x=(d[(c[j>>2]|0)+(z>>>3)|0]|0)>>>((z&7)>>>0);c[h>>2]=((z|0)<(c[m>>2]|0))+z;z=x&1;A=z+t+(v-1^-z)|0;break};default:{A=t}}a[b+2037+s|0]=A;z=s+1|0;if((z|0)<(u|0)){s=z;t=A}else{break b}}}}while(0);if((u|0)<=0){break}q=u-1|0;t=0;s=e;while(1){z=a[b+2037+t|0]|0;x=0;y=t;while(1){if((y|0)<(q|0)){B=c[p>>2]|0}else{B=r}C=B+x|0;w=y+1|0;if((w|0)==(u|0)){D=u;break}if((a[b+2037+w|0]|0)==z<<24>>24){x=C;y=w}else{D=w;break}}y=_2a(b,z,s,C)|0;if((y|0)<0){g=y;break}if((D|0)>=(u|0)){break a}t=D;s=s+(C<<2)|0}return g|0}}while(0);g=0;return g|0}function _2a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;if(b<<24>>24==0){mrc(e|0,0,f<<2|0)|0;g=0;return g|0}if((b&255)>>>0>50>>>0){g=-1094995529;return g|0}h=b<<24>>24;b=h-1|0;i=c[2176+(b*20|0)>>2]|0;j=c[2180+(b*20|0)>>2]|0;k=c[2184+(b*20|0)>>2]|0;l=c[2188+(b*20|0)>>2]|0;m=c[2192+(b*20|0)>>2]|0;if((f|0)<=0){g=0;return g|0}b=(h-49|0)>>>0>1>>>0;h=a+1312|0;n=a+1320|0;o=32-i|0;p=1<<i;q=i-16|0;r=48-i|0;s=c[a+1304>>2]|0;a=0;a:while(1){t=c[h>>2]|0;u=c[n>>2]|0;v=s+(t>>>3)|0;w=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((t&7)>>>0);if(b){v=t+i|0;x=u>>>0>v>>>0?v:u;c[h>>2]=x;y=w<<o>>>(o>>>0);z=x}else{x=t+16|0;t=u>>>0>x>>>0?x:u;c[h>>2]=t;x=s+(t>>>3)|0;v=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((t&7)>>>0)<<r>>>(r>>>0);x=q+t|0;t=u>>>0>x>>>0?x:u;c[h>>2]=t;y=v<<16|w&65535;z=t}b:do{if((y|0)<(j|0)){A=y}else{t=d[s+(z>>>3)|0]|0;w=((z|0)<(u|0))+z|0;c[h>>2]=w;if((t&1<<(z&7)|0)==0){A=y;break}t=y|p;if((t|0)<(l|0)){A=t-j|0;break}else{B=0;C=w}while(1){if((B|0)>=9){D=14;break}w=d[s+(C>>>3)|0]|0;v=((C|0)<(u|0))+C|0;c[h>>2]=v;if((w&1<<(C&7)|0)==0){B=B+1|0;C=v}else{break}}do{if((D|0)==14){D=0;if((B|0)!=9){break}v=s+(C>>>3)|0;w=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((C&7)>>>0)&7;v=C+3|0;x=u>>>0>v>>>0?v:u;c[h>>2]=x;do{if((w|0)==7){v=s+(x>>>3)|0;E=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((x&7)>>>0)&31;v=x+5|0;F=u>>>0>v>>>0?v:u;c[h>>2]=F;v=E+7|0;if(v>>>0>29>>>0){g=-1094995529;D=26;break a}G=s+(F>>>3)|0;H=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((F&7)>>>0);if(v>>>0<26>>>0){I=F;J=v;K=H;D=19;break}v=F+16|0;F=u>>>0>v>>>0?v:u;c[h>>2]=F;v=s+(F>>>3)|0;G=41-E|0;L=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((F&7)>>>0)<<G>>>(G>>>0);G=E-9+F|0;c[h>>2]=u>>>0>G>>>0?G:u;M=L<<16|H&65535;D=21}else if((w|0)==0){N=t}else{H=s+(x>>>3)|0;I=x;J=w;K=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((x&7)>>>0);D=19}}while(0);if((D|0)==19){D=0;x=32-J|0;w=I+J|0;c[h>>2]=u>>>0>w>>>0?w:u;M=K<<x>>>(x>>>0);D=21}if((D|0)==21){D=0;N=(ca(M+1|0,k)|0)+t|0}A=N+m|0;break b}}while(0);A=t-j+(ca(B,k)|0)|0}}while(0);c[e+(a<<2)>>2]=A>>1^-(A&1);u=a+1|0;if((u|0)<(f|0)){a=u}else{g=0;D=26;break}}if((D|0)==26){return g|0}return 0}function $2a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;j=i;i=i+8|0;k=j|0;l=c[e+60>>2]|0;m=f;n=c[h+24>>2]|0;o=h+28|0;h=c[o>>2]|0;if(!((h|0)>-1)){KIb(0,0,2614120,(p=i,i=i+24|0,c[p>>2]=2587144,c[p+8>>2]=2566128,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}q=l;c[q>>2]=n;c[l+8>>2]=n;r=n+h|0;s=l+4|0;c[s>>2]=r;l=r;if((h|0)<1){t=0;u=n}else{h=n+1|0;c[q>>2]=h;t=d[n]|0;u=h}if((l-u|0)<1){v=0;w=u}else{h=u+1|0;c[q>>2]=h;v=d[u]|0;w=h}if((l-w|0)<1){x=0;y=w}else{h=w+1|0;c[q>>2]=h;x=d[w]|0;y=h}if((l-y|0)<2){z=0;A=y}else{h=y+2|0;c[q>>2]=h;w=y;z=(d[w]|d[w+1|0]<<8)<<16>>16&65535;A=h}if((l-A|0)<2){B=0;C=A}else{h=A+2|0;c[q>>2]=h;w=A;B=(d[w]|d[w+1|0]<<8)<<16>>16&65535;C=h}if((l-C|0)<1){D=0;E=C}else{h=C+1|0;c[q>>2]=h;D=d[C]|0;E=h}h=l-E|0;C=h>>>0>4>>>0?4:h;h=E+C|0;c[q>>2]=h;if((l-h|0)<2){F=0;G=h}else{w=E+(C+2)|0;c[q>>2]=w;C=h;F=(d[C]|d[C+1|0]<<8)<<16>>16&65535;G=w}if((l-G|0)<2){H=0;I=G}else{w=G+2|0;c[q>>2]=w;C=G;H=(d[C]|d[C+1|0]<<8)<<16>>16&65535;I=w}if((l-I|0)<1){J=0;K=I}else{w=I+1|0;c[q>>2]=w;J=d[I]|0;K=w}w=l-K|0;if(!(w>>>0>t>>>0)){KIb(e,16,2445928,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}if((w|0)<1){M=0;N=K}else{w=K+1|0;c[q>>2]=w;M=d[K]|0;N=w}do{if((v|0)==0){if((B|z|D|0)==0){O=z;P=B;Q=D;R=r;S=N;break}KIb(e,24,2356632,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;O=0;P=0;Q=0;R=c[s>>2]|0;S=c[q>>2]|0}else{O=z;P=B;Q=D;R=r;S=N}}while(0);N=R-S|0;c[q>>2]=S+(N>>>0>t>>>0?t:N);switch(J|0){case 15:case 16:{c[e+140>>2]=46;break};case 32:{c[e+140>>2]=30;break};case 24:{c[e+140>>2]=3;break};case 8:{c[e+140>>2]=(x&247|0)==3?8:11;break};default:{KIb(e,16,2293792,(p=i,i=i+8|0,c[p>>2]=J,p)|0);i=p;L=-1094995529;i=j;return L|0}}N=(P|0)!=0;do{if(N){if((O+P|0)<=256){break}KIb(e,16,2242728,(p=i,i=i+16|0,c[p>>2]=P,c[p+8>>2]=O,p)|0);i=p;L=-1094995529;i=j;return L|0}}while(0);t=H4a(e,F,H)|0;if((t|0)<0){L=t;i=j;return L|0}t=M4a(e,m,0)|0;if((t|0)<0){L=t;i=j;return L|0}c[f+88>>2]=1;t=f;m=c[t>>2]|0;S=f+32|0;R=c[S>>2]|0;if((M&32|0)==0){T=m+(ca(R,H-1|0)|0)|0;U=-R|0}else{T=m;U=R}if((M&64|0)==0){V=(M&128|0)!=0?4:1}else{V=2}do{if(N){if((Q|0)==16|(Q|0)==15){W=2}else if((Q|0)==32){W=4}else if((Q|0)==24){W=3}else{KIb(e,16,2201432,(p=i,i=i+8|0,c[p>>2]=Q,p)|0);i=p;L=-1094995529;i=j;return L|0}R=ca(W,P)|0;if((c[e+140>>2]|0)!=11){m=c[q>>2]|0;r=(c[s>>2]|0)-m|0;c[q>>2]=m+(r>>>0>R>>>0?R:r);break}r=(c[f+4>>2]|0)+(O<<2)|0;m=c[q>>2]|0;if(((c[s>>2]|0)-m|0)>>>0<R>>>0){KIb(e,16,2169616,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}do{if((W|0)==3){if((P|0)>0){X=r;Y=0;Z=m}else{break}while(1){R=Z+3|0;c[q>>2]=R;c[X>>2]=(d[Z+2|0]|0)<<16|(d[Z+1|0]|0)<<8|(d[Z]|0)|-16777216;D=Y+1|0;if((D|0)<(P|0)){X=X+4|0;Y=D;Z=R}else{break}}}else if((W|0)==2){if((P|0)>0){_=r;$=0;aa=m}else{break}while(1){R=aa+2|0;c[q>>2]=R;D=aa;B=(d[D]|d[D+1|0]<<8)<<16>>16&65535;D=B<<9&16252928|B<<6&63488|B<<3&248;c[_>>2]=D|D>>>5&460551|-16777216;D=$+1|0;if((D|0)<(P|0)){_=_+4|0;$=D;aa=R}else{break}}}else if((W|0)==4){if((P|0)>0){ba=r;da=0;ea=m}else{break}while(1){R=ea+4|0;c[q>>2]=R;D=ea;c[ba>>2]=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24;D=da+1|0;if((D|0)<(P|0)){ba=ba+4|0;da=D;ea=R}else{break}}}}while(0);c[f+304>>2]=1}}while(0);a:do{if((x&247|0)==0){mrc(c[t>>2]|0,0,ca(c[S>>2]|0,H)|0)|0}else{if((x&8|0)==0){f=ca((J+1|0)>>>3,F)|0;ea=c[q>>2]|0;da=c[s>>2]|0;if((da-ea|0)>>>0<(ca(f,H)|0)>>>0){KIb(e,16,2142672,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}ba=ca(V,U)|0;P=V-1|0;W=T;aa=0;$=ea;ea=da;while(1){da=ea-$|0;_=da>>>0>f>>>0?f:da;nrc(W|0,$|0,_)|0;da=(c[q>>2]|0)+_|0;c[q>>2]=da;_=aa+V|0;if((_|0)<(H|0)){fa=W+ba|0;ga=_}else{Z=_+1&P;if(!((Z|0)!=0&(Z|0)<(H|0))){break a}fa=T+(ca(Z,U)|0)|0;ga=Z}if((fa|0)==0){break a}W=fa;aa=ga;$=da;ea=c[s>>2]|0}}ea=k|0;$=(J+1|0)>>>3;if((T|0)==0){break}aa=ca(V,U)|0;W=V-1|0;P=~F;ba=0;f=0;da=T;Z=T;b:while(1){_=c[q>>2]|0;Y=c[s>>2]|0;if((Y|0)==(_|0)){ha=67;break}X=_+1|0;c[q>>2]=X;O=d[_]|0;Q=(O&127)+1|0;c:do{if((O&128|0)==0){N=Z;m=da;r=Q;R=f;D=ba;B=X;z=Y;while(1){v=F-R|0;w=(r|0)>(v|0)?v:r;v=ca(w,$)|0;K=z-B|0;l=K>>>0>v>>>0?v:K;nrc(N|0,B|0,l)|0;K=(c[q>>2]|0)+l|0;c[q>>2]=K;l=r-w|0;I=N+v|0;v=w+R|0;do{if((v|0)==(F|0)){w=D+V|0;if((w|0)<(H|0)){C=m+aa|0;ia=C;ja=C;ka=0;la=w;break}C=w+1&W;if(!((C|0)!=0&(C|0)<(H|0))){ma=l;break b}w=T+(ca(C,U)|0)|0;ia=w;ja=w;ka=0;la=C}else{ia=I;ja=m;ka=v;la=D}}while(0);if(!((ia|0)!=0&(l|0)>0)){na=ia;oa=ja;pa=l;qa=ka;ra=la;break c}N=ia;m=ja;r=l;R=ka;D=la;B=K;z=c[s>>2]|0}}else{z=Y-X|0;B=z>>>0>$>>>0?$:z;nrc(ea|0,X|0,B)|0;c[q>>2]=_+(B+1);B=Z;z=da;D=Q;R=f;r=ba;while(1){m=F-R|0;N=(D|0)>(m|0)?m:D;m=~D;v=R+P|0;I=~((v|0)<(m|0)?m:v);v=N;m=B;while(1){nrc(m|0,ea|0,$)|0;C=v-1|0;if((C|0)==0){break}else{v=C;m=m+$|0}}m=D-N|0;v=N+R|0;K=B+(ca($,I)|0)|0;do{if((v|0)==(F|0)){l=r+V|0;if((l|0)<(H|0)){C=z+aa|0;sa=C;ta=C;ua=0;va=l;break}C=l+1&W;if(!((C|0)!=0&(C|0)<(H|0))){ma=m;break b}l=T+(ca(C,U)|0)|0;sa=l;ta=l;ua=0;va=C}else{sa=K;ta=z;ua=v;va=r}}while(0);if((sa|0)!=0&(m|0)>0){B=sa;z=ta;D=m;R=ua;r=va}else{na=sa;oa=ta;pa=m;qa=ua;ra=va;break}}}}while(0);if((na|0)==0){ma=pa;break}else{ba=ra;f=qa;da=oa;Z=na}}if((ha|0)==67){KIb(e,16,2119088,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}if((ma|0)==0){break}KIb(e,16,2637336,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;L=-1094995529;i=j;return L|0}}while(0);if(!((M&16|0)==0|(H|0)==0)){M=F>>>1;p=(M|0)==0;e=F-1|0;ma=F*3|0;F=0;do{ha=ca(c[S>>2]|0,F)|0;na=c[t>>2]|0;oa=na+ha|0;if(!p){qa=oa;ra=ha-3|0;pa=ha-2|0;va=ha+1|0;ua=ha-1|0;ta=ha+2|0;sa=oa;oa=e+ha|0;if((J|0)==32){U=0;T=0;while(1){V=qa+(e+T<<2)|0;q=c[V>>2]|0;s=qa+(U<<2)|0;c[V>>2]=c[s>>2];c[s>>2]=q;q=U+1|0;s=~U;if((q|0)<(M|0)){U=q;T=s}else{break}}}else if((J|0)==24){T=0;do{U=T*3|0;qa=ma-U|0;s=na+(ra+qa)|0;q=a[s]|0;V=na+(U+ha)|0;a[s]=a[V]|0;a[V]=q;q=na+(pa+qa)|0;V=a[q]|0;s=na+(va+U)|0;a[q]=a[s]|0;a[s]=V;V=na+(ua+qa)|0;qa=a[V]|0;s=na+(ta+U)|0;a[V]=a[s]|0;a[s]=qa;T=T+1|0;}while((T|0)<(M|0))}else{T=0;ta=0;while(1){if((J|0)==16){ua=sa+(e+ta<<1)|0;va=b[ua>>1]|0;pa=sa+(T<<1)|0;b[ua>>1]=b[pa>>1]|0;b[pa>>1]=va}else if((J|0)==8){va=na+(oa+ta)|0;pa=a[va]|0;ua=na+(T+ha)|0;a[va]=a[ua]|0;a[ua]=pa}pa=T+1|0;ua=~T;if((pa|0)<(M|0)){T=pa;ta=ua}else{break}}}}F=F+1|0;}while((F|0)<(H|0))}c[g>>2]=1;L=c[o>>2]|0;i=j;return L|0}function a3a(a){a=a|0;c[a+140>>2]=56;c[a+796>>2]=14;return 0}function b3a(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;h=c[f+24>>2]|0;j=a+120|0;k=f+28|0;f=a+124|0;l=(c[j>>2]|0)+3&65532;if((c[k>>2]|0)<(ca(c[f>>2]<<2,l)|0)){KIb(a,16,2445896,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=g;return n|0}m=M4a(a,d,0)|0;if((m|0)<0){n=m;i=g;return n|0}c[d+84>>2]=1;c[d+88>>2]=1;m=c[f>>2]|0;do{if((m|0)>0){f=c[j>>2]>>1;a=c[d+32>>2]>>1;o=c[d+36>>2]>>1;p=c[d+40>>2]>>1;q=l<<1;if((f|0)>0){r=c[d>>2]|0;s=c[d+4>>2]|0;t=c[d+8>>2]|0;u=h;v=0}else{break}while(1){w=0;do{x=w<<2;y=b[u+(x<<1)>>1]|0;b[s+(w<<1)>>1]=y<<2|(y&65535)>>>14;y=b[u+((x|1)<<1)>>1]|0;z=w<<1;b[r+(z<<1)>>1]=y<<2|(y&65535)>>>14;y=b[u+((x|2)<<1)>>1]|0;b[t+(w<<1)>>1]=y<<2|(y&65535)>>>14;y=b[u+((x|3)<<1)>>1]|0;b[r+((z|1)<<1)>>1]=y<<2|(y&65535)>>>14;w=w+1|0;}while((w|0)<(f|0));w=v+1|0;if((w|0)<(m|0)){r=r+(a<<1)|0;s=s+(o<<1)|0;t=t+(p<<1)|0;u=u+(q<<1)|0;v=w}else{break}}}}while(0);c[e>>2]=1;n=c[k>>2]|0;i=g;return n|0}function c3a(a){a=a|0;var b=0,d=0;b=UHb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+84>>2]=1;c[b+88>>2]=1;d=0;return d|0}function d3a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;j=b+120|0;k=c[j>>2]|0;do{if((k|0)<=65535){l=b+124|0;m=c[l>>2]|0;if((m|0)>65535){break}n=b+140|0;o=c2(c[n>>2]|0,k,m)|0;m=o+45|0;p=d5a(b,e,m,(m|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=h;return q|0}p=e+24|0;mrc(c[p>>2]|0,0,12)|0;m=(c[p>>2]|0)+12|0;y=c[j>>2]&65535;a[m]=y;y=y>>8;a[m+1|0]=y;m=(c[p>>2]|0)+14|0;y=c[l>>2]&65535;a[m]=y;y=y>>8;a[m+1|0]=y;a[(c[p>>2]|0)+17|0]=(c[n>>2]|0)==30?40:32;m=c[p>>2]|0;r=m+18|0;s=b+792|0;c[s>>2]=oKb(qKb(c[n>>2]|0)|0)|0;t=c[n>>2]|0;switch(t|0){case 30:{a[(c[p>>2]|0)+2|0]=2;a[(c[p>>2]|0)+16|0]=32;u=r;break};case 11:{n=f+4|0;v=0;while(1){if((v|0)>=256){w=24;break}x=(c[n>>2]|0)+(v<<2)|0;if(((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24)&-16777216|0)==-16777216){v=v+1|0}else{w=32;break}}a[(c[p>>2]|0)+1|0]=1;a[(c[p>>2]|0)+2|0]=1;a[(c[p>>2]|0)+6|0]=1;a[(c[p>>2]|0)+7|0]=w;a[(c[p>>2]|0)+16|0]=8;if((w|0)==32){v=0;do{x=v<<2;z=(c[p>>2]|0)+(x+18)|0;y=c[(c[n>>2]|0)+x>>2]|0;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;v=v+1|0;}while((v|0)<256)}else{v=0;do{z=v<<2;x=v*3|0;a[(c[p>>2]|0)+(x+18)|0]=c[(c[n>>2]|0)+z>>2];a[(c[p>>2]|0)+(x+19)|0]=(c[(c[n>>2]|0)+z>>2]|0)>>>8;a[(c[p>>2]|0)+(x+20)|0]=(c[(c[n>>2]|0)+z>>2]|0)>>>16;v=v+1|0;}while((v|0)<256)}u=m+(w<<5|18)|0;break};case 46:{a[(c[p>>2]|0)+2|0]=2;a[(c[p>>2]|0)+16|0]=16;c[s>>2]=16;u=r;break};case 8:{a[(c[p>>2]|0)+2|0]=3;c[s>>2]=40;a[(c[p>>2]|0)+16|0]=8;u=r;break};case 3:{a[(c[p>>2]|0)+2|0]=2;a[(c[p>>2]|0)+16|0]=24;u=r;break};default:{v=mKb(t)|0;KIb(b,16,2356592,(A=i,i=i+8|0,c[A>>2]=v,A)|0);i=A;q=-22;i=h;return q|0}}v=(d[(c[p>>2]|0)+16|0]|0)>>>3;a:do{if((c[b+568>>2]|0)==2){B=25}else{n=c[j>>2]|0;z=c[l>>2]|0;if((z|0)>0){x=f|0;C=f+32|0;D=o;E=0;F=u;while(1){G=$rb(F,D,(c[x>>2]|0)+(ca(c[C>>2]|0,E)|0)|0,v,n,127,0,-1,0)|0;if((G|0)==-1){B=25;break a}H=F+G|0;I=E+1|0;if((I|0)<(z|0)){D=D-G|0;E=I;F=H}else{J=H;break}}}else{J=u}F=J-u|0;if(!((F|0)>-1)){B=25;break}E=(c[p>>2]|0)+2|0;a[E]=a[E]|8;K=F}}while(0);if((B|0)==25){o=c[l>>2]|0;t=ca(c[j>>2]|0,v)|0;if((o|0)>0){r=f+32|0;s=0;m=u;F=c[f>>2]|0;while(1){nrc(m|0,F|0,t)|0;E=s+1|0;if((E|0)<(o|0)){s=E;m=m+t|0;F=F+(c[r>>2]|0)|0}else{break}}L=u+(ca(t,o)|0)|0}else{L=u}K=L-u|0}nrc(u+K|0,2293760,26)|0;c[e+28>>2]=u+(K+26)-(c[p>>2]|0);r=e+36|0;c[r>>2]=c[r>>2]|1;c[g>>2]=1;q=0;i=h;return q|0}}while(0);KIb(b,16,2445848,(A=i,i=i+1|0,i=i+7&-8,c[A>>2]=0,A)|0);i=A;q=-22;i=h;return q|0}function e3a(a){a=a|0;VHb(a+804|0);return 0}function f3a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1040|0;h=g|0;j=g+1024|0;k=g+1032|0;l=d;m=c[f+24>>2]|0;n=c[b+60>>2]|0;o=f+8|0;p=c[o>>2]|0;q=c[o+4>>2]|0;o=b+104|0;c[j>>2]=1;c[j+4>>2]=100;b=XIb(p,q,o,j)|0;j=b;b=c[f+48>>2]|0;if((b|0)==-1){r=-1}else{c[k>>2]=1;c[k+4>>2]=100;q=XIb(b,(b|0)<0|0?-1:0,o,k)|0;r=q}SFb(h,0,-1);q=f+28|0;do{if((m|0)!=0){f=c[q>>2]|0;if((f|0)<=0){break}if((a[m]|0)==0){break}gmb(h,m,f,c[n+4>>2]|0,c[n+8>>2]|0);if((c[h+4>>2]|0)>>>0<(c[h+8>>2]|0)>>>0){fmb(l,c[h>>2]|0,j,r,0)|0;break}_Fb(h,0)|0;s=-12;i=g;return s|0}}while(0);c[e>>2]=(c[d+12>>2]|0)!=0;_Fb(h,0)|0;s=c[q>>2]|0;i=g;return s|0}function g3a(a){a=a|0;c[(c[a+60>>2]|0)+4>>2]=2587136;return dmb(a)|0}function h3a(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;a=UHb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function i3a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;h=i;i=i+64|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=(c[b+60>>2]|0)+4|0;m=N4a(b,c[g>>2]|0)|0;if((m|0)<0){n=m;i=h;return n|0}m=k+l|0;b=k+1|0;o=d[k]|0;if((o&1|0)==0){p=b}else{q=c[g>>2]|0;r=c[q+4>>2]|0;if((m-b|0)<768){n=-1094995529;i=h;return n|0}else{s=0;t=b}while(1){b=a[t]|0;u=a[t+1|0]|0;v=a[t+2|0]|0;c[r+(s<<2)>>2]=((b<<2|(b&255)>>>4)&255)<<16|((u<<2|(u&255)>>>4)&255)<<8|(v<<2|(v&255)>>>4)&255|-16777216;v=s+1|0;if((v|0)<256){s=v;t=t+3|0}else{break}}c[q+304>>2]=1;p=k+769|0}a:do{if((o&2|0)!=0){k=m;if((k-p|0)<128){n=-1094995529;i=h;return n|0}q=(p|0)==0?8:1032;t=j;s=j|0;r=j;v=j+8|0;u=j+16|0;b=j+24|0;w=j+32|0;x=j+40|0;z=j+48|0;A=j+56|0;B=0;C=0;D=p+128|0;b:while(1){E=D;F=0;G=B;while(1){if((F|0)>=256){break}H=c[g>>2]|0;I=(ca(c[H+32>>2]|0,C)|0)+F|0;J=c[H>>2]|0;H=J+I|0;K=p+(G>>>3)|0;L=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)>>>((G&7)>>>0)&3;K=G+2|0;M=q>>>0>K>>>0?K:q;c:do{if((L|0)==1){if((k-E|0)<1){n=-1094995529;N=31;break b}K=E+1|0;O=a[E]|0;P=O&255;if((P&128|0)!=0){Q=P&3;if((Q|0)==1){R=k3a(K,m,t)|0;S=H;T=c[s+4>>2]|0;U=S|0;y=c[s>>2]|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=S+4|0;y=T;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=c[(c[g>>2]|0)+32>>2]|0;T=J+(U+I)|0;S=c[v+4>>2]|0;V=T|0;y=c[v>>2]|0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=T+4|0;y=S;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=(c[(c[g>>2]|0)+32>>2]|0)+U|0;U=J+(V+I)|0;S=c[u+4>>2]|0;T=U|0;y=c[u>>2]|0;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=U+4|0;y=S;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=(c[(c[g>>2]|0)+32>>2]|0)+V|0;V=J+(T+I)|0;S=c[b+4>>2]|0;U=V|0;y=c[b>>2]|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=V+4|0;y=S;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=(c[(c[g>>2]|0)+32>>2]|0)+T|0;T=J+(U+I)|0;S=c[w+4>>2]|0;V=T|0;y=c[w>>2]|0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=T+4|0;y=S;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=(c[(c[g>>2]|0)+32>>2]|0)+U+I|0;U=J+V|0;S=c[x+4>>2]|0;T=U|0;y=c[x>>2]|0;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=U+4|0;y=S;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=V+(c[(c[g>>2]|0)+32>>2]|0)|0;V=J+T|0;S=c[z+4>>2]|0;U=V|0;y=c[z>>2]|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=V+4|0;y=S;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=J+((c[(c[g>>2]|0)+32>>2]|0)+T)|0;T=c[A+4>>2]|0;S=U|0;y=c[A>>2]|0;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;S=U+4|0;y=T;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;W=R;break}else if((Q|0)!=2){W=K;break}Q=k3a(K,m,t)|0;R=H;S=0;while(1){T=S<<3;a[R]=a[r+T|0]|0;a[R+(c[(c[g>>2]|0)+32>>2]|0)|0]=a[r+(T|1)|0]|0;a[R+(c[(c[g>>2]|0)+32>>2]<<1)|0]=a[r+(T|2)|0]|0;a[R+((c[(c[g>>2]|0)+32>>2]|0)*3|0)|0]=a[r+(T|3)|0]|0;a[R+(c[(c[g>>2]|0)+32>>2]<<2)|0]=a[r+(T|4)|0]|0;a[R+((c[(c[g>>2]|0)+32>>2]|0)*5|0)|0]=a[r+(T|5)|0]|0;a[R+((c[(c[g>>2]|0)+32>>2]|0)*6|0)|0]=a[r+(T|6)|0]|0;a[R+((c[(c[g>>2]|0)+32>>2]|0)*7|0)|0]=a[r+(T|7)|0]|0;T=S+1|0;if((T|0)<8){R=R+1|0;S=T}else{W=Q;break c}}}if(O<<24>>24==0){n=-1094995529;N=31;break b}Q=d[1359664+(P-1)|0]|0;S=Q+1|0;R=S<<3;if((k-K|0)<(R+P|0)){n=-1094995529;N=31;break b}T=P+1|0;U=E+T|0;V=S<<6;X=V>>>0>2147483639>>>0|(U|0)==0;Y=X?0:U;U=X?8:V|8;V=31-Q|0;Q=0;X=H;Z=0;while(1){_=Y+(Q>>>3)|0;$=Q+S|0;aa=U>>>0>$>>>0?$:U;a[X]=a[E+(((d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((Q&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;_=Y+(aa>>>3)|0;$=aa+S|0;ba=U>>>0>$>>>0?$:U;a[X+1|0]=a[E+(((d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((aa&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;aa=Y+(ba>>>3)|0;_=ba+S|0;$=U>>>0>_>>>0?_:U;a[X+2|0]=a[E+(((d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((ba&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;ba=Y+($>>>3)|0;aa=$+S|0;_=U>>>0>aa>>>0?aa:U;a[X+3|0]=a[E+(((d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)>>>(($&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;$=Y+(_>>>3)|0;ba=_+S|0;aa=U>>>0>ba>>>0?ba:U;a[X+4|0]=a[E+(((d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((_&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;_=Y+(aa>>>3)|0;$=aa+S|0;ba=U>>>0>$>>>0?$:U;a[X+5|0]=a[E+(((d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((aa&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;aa=Y+(ba>>>3)|0;_=ba+S|0;$=U>>>0>_>>>0?_:U;a[X+6|0]=a[E+(((d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((ba&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;ba=Y+($>>>3)|0;aa=$+S|0;a[X+7|0]=a[E+(((d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)>>>(($&7)>>>0)<<V>>>(V>>>0))+1)|0]|0;$=Z+1|0;if(($|0)<8){Q=U>>>0>aa>>>0?aa:U;X=X+(c[(c[g>>2]|0)+32>>2]|0)|0;Z=$}else{break}}W=E+(R+T)|0}else if((L|0)==2){if((k-E|0)<64){n=-1094995529;N=31;break b}Z=E;X=H;U=Z|0;Q=Z+4|0;Z=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=X|0;y=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=X+4|0;y=Z;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=c[(c[g>>2]|0)+32>>2]|0;Z=E+8|0;X=J+(Q+I)|0;U=Z|0;V=Z+4|0;Z=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;V=X|0;y=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=X+4|0;y=Z;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=(c[(c[g>>2]|0)+32>>2]|0)+Q|0;Q=E+16|0;Z=J+(V+I)|0;X=Q|0;U=Q+4|0;Q=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;U=Z|0;y=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=Z+4|0;y=Q;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;U=(c[(c[g>>2]|0)+32>>2]|0)+V|0;V=E+24|0;Q=J+(U+I)|0;Z=V|0;X=V+4|0;V=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;X=Q|0;y=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=Q+4|0;y=V;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=(c[(c[g>>2]|0)+32>>2]|0)+U|0;U=E+32|0;V=J+(X+I)|0;Q=U|0;Z=U+4|0;U=d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0;Z=V|0;y=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;Z=V+4|0;y=U;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;Z=(c[(c[g>>2]|0)+32>>2]|0)+X+I|0;X=E+40|0;U=J+Z|0;V=X|0;Q=X+4|0;X=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=U|0;y=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=U+4|0;y=X;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=Z+(c[(c[g>>2]|0)+32>>2]|0)|0;Z=E+48|0;X=J+Q|0;U=Z|0;V=Z+4|0;Z=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;V=X|0;y=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=X+4|0;y=Z;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=E+56|0;Z=J+((c[(c[g>>2]|0)+32>>2]|0)+Q)|0;Q=V|0;X=V+4|0;V=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0;X=Z|0;y=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=Z+4|0;y=V;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;W=E+64|0}else if((L|0)==3){X=E;while(1){if((k-X|0)<2){n=-1094995529;N=31;break b}V=d[X]|0;Z=ca(V>>>3&7,c[(c[g>>2]|0)+32>>2]|0)|0;Q=X+2|0;a[J+(Z+(V&7|I))|0]=a[X+1|0]|0;if((V&128|0)==0){X=Q}else{W=Q;break}}}else{W=E}}while(0);if((W|0)==0){n=-1094995529;N=31;break b}else{E=W;F=F+8|0;G=M}}F=C+8|0;if((F|0)<128){B=G;C=F;D=E}else{break a}}if((N|0)==31){i=h;return n|0}}}while(0);N=YHb(e,c[g>>2]|0)|0;if((N|0)<0){n=N;i=h;return n|0}c[f>>2]=1;n=l;i=h;return n|0}function j3a(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function k3a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+256|0;h=g|0;j=e;e=j-b<<3;k=e>>>0>2147483639>>>0|(b|0)==0;l=k?0:b;m=k?0:e;e=m+8|0;k=0;n=0;o=0;do{if((m-k|0)<4){p=0;q=11;break}r=l+(k>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((k&7)>>>0)<<28;r=s>>28;t=k+4|0;k=e>>>0>t>>>0?t:e;c[h+(n<<2)>>2]=r;o=((s|0)>-268435456?r:-r|0)+o|0;n=n+1|0;}while((n|0)<64&(o|0)<64);if((q|0)==11){i=g;return p|0}o=b+((k+7|0)/8|0)|0;k=f;f=64;b=0;while(1){n=c[h+(b<<2)>>2]|0;if((n|0)<0){e=-n|0;if((j-o|0)<1){p=0;q=11;break}mrc(k|0,a[o]|0,((f|0)<(e|0)?f:e)|0)|0;u=e;v=o+1|0}else{if((j-o|0)<(n|0)){p=0;q=11;break}nrc(k|0,o|0,(n|0)>(f|0)?f:n)|0;u=n;v=o+n|0}n=f-u|0;e=b+1|0;if((e|0)<64&(n|0)>0){o=v;k=k+u|0;f=n;b=e}else{p=v;q=11;break}}if((q|0)==11){i=g;return p|0}return 0}function l3a(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+16>>2]=0;c[b+20>>2]=0;c[b>>2]=a;FPa(b+1120|0);Epb();return 0}function m3a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0.0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Cc=0,Dc=0,Ec=0;j=i;i=i+176|0;k=j|0;l=j+56|0;m=j+64|0;n=j+72|0;o=j+80|0;p=j+88|0;q=j+96|0;r=j+104|0;s=j+112|0;t=j+128|0;u=j+136|0;v=j+144|0;w=j+160|0;x=c[b+60>>2]|0;z=x;A=e;B=s|0;c[B>>2]=A;c[s+4>>2]=0;c[s+8>>2]=0;C=x+4|0;D=C;E=g+24|0;F=c[E>>2]|0;G=g+28|0;g=c[G>>2]|0;if(!((g|0)>-1)){KIb(0,0,2211352,(H=i,i=i+24|0,c[H>>2]=2208256,c[H+8>>2]=2199528,c[H+16>>2]=135,H)|0);i=H;Hd();return 0}I=C;c[I>>2]=F;C=x+12|0;c[C>>2]=F;J=x+8|0;c[J>>2]=F+g;g=B3a(D,u,t)|0;if((g|0)!=0){KIb(b,16,2445816,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=g;i=j;return K|0}g=c[t>>2]|0;do{if(!(g>>>0>4294967280>>>0)){if((c[G>>2]|0)>>>0<(g+14|0)>>>0){break}F=x+1060|0;c[F>>2]=c[u>>2];L=x+24|0;c[L>>2]=1;M=x+28|0;c[M>>2]=1;N=x+1068|0;c[N>>2]=0;O=x+1064|0;c[O>>2]=1;P=x+1084|0;c[P>>2]=0;Q=x+1132|0;R=c[Q>>2]|0;S=x+1136|0;T=S;if((R|0)>0){U=0;V=R;while(1){R=(c[T>>2]|0)+(U*20|0)+16|0;if((c[R>>2]|0)==0){W=V}else{mJb(R);W=c[Q>>2]|0}R=U+1|0;if((R|0)<(W|0)){U=R;V=W}else{break}}}mJb(S);c[Q>>2]=0;V=x+1116|0;c[V>>2]=0;U=x+1104|0;c[U>>2]=0;R=c[t>>2]|0;X=c[C>>2]|0;Y=(c[J>>2]|0)-X|0;if((R|0)<0){Z=0}else{Z=(Y|0)<(R|0)?Y:R}c[I>>2]=X+Z;X=r3a(D,c[u>>2]|0)|0;if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<(X*12|0)>>>0){K=-1094995529;i=j;return K|0}R=r;Y=x;_=x+16|0;$=x+20|0;aa=x+1080|0;ba=x+1076|0;da=x+1092|0;ea=x+1112|0;fa=x+1088|0;ga=x+1100|0;ha=x+1108|0;ia=x+1096|0;ja=x+1056|0;ka=x+1072|0;la=m;ma=l;na=0;while(1){if((na|0)>=(X|0)){break}a:do{if((C3a(D,c[F>>2]|0,n,o,p,q)|0)<0){oa=211}else{pa=(c[I>>2]|0)-(c[C>>2]|0)|0;do{if((c[p>>2]|0)==1){qa=c[o>>2]|0;if((qa|0)==2){ra=0;break}else if((qa|0)==1|(qa|0)==3|(qa|0)==4){ra=u3a(D,qa,c[F>>2]|0)|0;break}else{ra=-1;break}}else{ra=0}}while(0);qa=c[n>>2]|0;if((qa|0)==285){if((o3a(c[p>>2]|0,c[o>>2]|0,2250976,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==34736){sa=c[p>>2]|0;if(sa>>>0>268435454>>>0){ta=-1094995529;break}ua=sa<<3;if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<ua>>>0){ta=-1094995529;break}sa=hJb(ua)|0;c[r>>2]=sa;if((sa|0)==0){KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}if((c[p>>2]|0)!=0){sa=0;do{va=+t3a(D,c[F>>2]|0);h[(c[r>>2]|0)+(sa<<3)>>3]=va;sa=sa+1|0;}while(sa>>>0<(c[p>>2]|0)>>>0)}b:do{if((c[Q>>2]|0)>0){sa=0;c:while(1){ua=c[T>>2]|0;d:do{if((c[ua+(sa*20|0)+4>>2]|0)==34736){wa=c[ua+(sa*20|0)+8>>2]|0;do{if((wa|0)!=0){xa=c[ua+(sa*20|0)+12>>2]|0;if((xa+wa|0)>>>0>(c[p>>2]|0)>>>0){break}ya=c[r>>2]|0;if(wa>>>0>82595523>>>0){break c}za=hJb(wa*26|0|1)|0;if((za|0)==0){break c}a[za]=0;if((wa|0)>0){Aa=za;Ba=0;while(1){Ca=Rb(Aa|0,26,2222936,(H=i,i=i+16|0,h[H>>3]=+h[ya+(Ba+xa<<3)>>3],c[H+8>>2]=2291272,H)|0)|0;i=H;if(Ca>>>0>25>>>0){oa=169;break c}Da=Ba+1|0;if((Da|0)<(wa|0)){Aa=Aa+Ca|0;Ba=Da}else{break}}}a[za+((lrc(za|0)|0)-2)|0]=0;c[(c[T>>2]|0)+(sa*20|0)+16>>2]=za;break d}}while(0);KIb(c[Y>>2]|0,24,2302464,(H=i,i=i+8|0,c[H>>2]=c[ua+(sa*20|0)>>2],H)|0);i=H}}while(0);sa=sa+1|0;if((sa|0)>=(c[Q>>2]|0)){break b}}if((oa|0)==169){oa=0;kJb(za)}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;mJb(R);ta=-12;break a}}while(0);mJb(R);oa=211;break}else if((qa|0)==257){c[$>>2]=ra;oa=211;break}else if((qa|0)==277){if((c[p>>2]|0)!=1){KIb(c[Y>>2]|0,16,2410088,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ta=-1094995529;break}if(ra>>>0>4>>>0){KIb(c[Y>>2]|0,16,2402432,(H=i,i=i+8|0,c[H>>2]=ra,H)|0);i=H;ta=-1094995529;break}if((c[M>>2]|0)==1){c[L>>2]=ca(c[L>>2]|0,ra)|0}c[M>>2]=ra;oa=211;break}else if((qa|0)==320){sa=c[p>>2]|0;if(sa>>>0>770>>>0){ta=-1094995529;break}ua=d[301496+(c[o>>2]|0)|0]|0;if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<(ca(ua*3|0,(sa>>>0)/3|0)|0)>>>0){ta=-1094995529;break}wa=(ua<<3)-8|0;do{if(sa>>>0>2>>>0){ua=0;do{Ba=z+32+(ua<<2)|0;c[Ba>>2]=-16777216;Aa=(u3a(D,c[o>>2]|0,c[F>>2]|0)|0)>>>(wa>>>0)<<16;c[Ba>>2]=Aa|c[Ba>>2];ua=ua+1|0;Ea=c[p>>2]|0;}while(ua>>>0<((Ea>>>0)/3|0)>>>0);if(Ea>>>0>2>>>0){Fa=0}else{break}do{ua=(u3a(D,c[o>>2]|0,c[F>>2]|0)|0)>>>(wa>>>0)<<8;Ba=z+32+(Fa<<2)|0;c[Ba>>2]=ua|c[Ba>>2];Fa=Fa+1|0;Ga=c[p>>2]|0;}while(Fa>>>0<((Ga>>>0)/3|0)>>>0);if(Ga>>>0>2>>>0){Ha=0}else{break}do{Ba=(u3a(D,c[o>>2]|0,c[F>>2]|0)|0)>>>(wa>>>0);ua=z+32+(Ha<<2)|0;c[ua>>2]=Ba|c[ua>>2];Ha=Ha+1|0;}while(Ha>>>0<(((c[p>>2]|0)>>>0)/3|0)>>>0)}}while(0);c[ja>>2]=1;oa=211;break}else if((qa|0)==33922){if((o3a(c[p>>2]|0,c[o>>2]|0,2327872,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==279){wa=c[p>>2]|0;if((wa|0)==1){c[U>>2]=0;c[ha>>2]=ra;c[fa>>2]=1;Ia=0}else{c[U>>2]=pa;Ia=pa}c[fa>>2]=wa;c[ia>>2]=c[o>>2];if((Ia|0)<=((c[J>>2]|0)-(c[C>>2]|0)|0)){oa=211;break}KIb(c[Y>>2]|0,16,2374976,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ta=-1094995529;break}else if((qa|0)==34735){if((o3a(1,c[o>>2]|0,2322104,0,z,A)|0)<0){KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}if((o3a(2,c[o>>2]|0,2316976,2312480,z,A)|0)<0){KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}wa=r3a(D,c[F>>2]|0)|0;c[Q>>2]=wa;sa=((c[p>>2]|0)>>>2)-1|0;if(wa>>>0>sa>>>0){c[Q>>2]=sa;KIb(c[Y>>2]|0,24,2307848,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;Ja=c[Q>>2]|0}else{Ja=wa}if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<Ja<<3>>>0){c[Q>>2]=0;ta=-1;break}wa=pJb(Ja*20|0)|0;c[T>>2]=wa;if((wa|0)==0){KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[Q>>2]=0;oa=211;break}if((c[Q>>2]|0)>0){Ka=0}else{oa=211;break}while(1){wa=r3a(D,c[F>>2]|0)|0;c[(c[T>>2]|0)+(Ka*20|0)>>2]=wa;wa=r3a(D,c[F>>2]|0)|0;c[(c[T>>2]|0)+(Ka*20|0)+4>>2]=wa;wa=r3a(D,c[F>>2]|0)|0;sa=c[T>>2]|0;c[sa+(Ka*20|0)+8>>2]=wa;if((c[sa+(Ka*20|0)+4>>2]|0)==0){wa=c[sa+(Ka*20|0)>>2]|0;sa=r3a(D,c[F>>2]|0)|0;e:do{if((sa|0)==0){La=rJb(2219304)|0}else if((sa|0)==32767){La=rJb(2216312)|0}else{f:do{switch(wa|0){case 2051:{if((sa|0)<=8900){break f}ua=sa-8901|0;if(!(ua>>>0<11>>>0)){break f}La=rJb(c[1289128+(ua<<2)>>2]|0)|0;break e;break};case 3072:{c[m>>2]=sa;ua=Bc(la|0,1281304,978,8,352)|0;if((ua|0)==0){Ma=0}else{Ma=c[ua+4>>2]|0}ua=rJb(Ma)|0;if((ua|0)!=0){La=ua;break e}break};case 3074:{c[l>>2]=sa;ua=Bc(ma|0,1278728,298,8,352)|0;if((ua|0)==0){Na=0}else{Na=c[ua+4>>2]|0}ua=rJb(Na)|0;if((ua|0)!=0){La=ua;break e}break};case 2050:{do{if((sa|0)>6200){ua=sa-6201|0;if(!(ua>>>0<120>>>0)){break}La=rJb(c[1289544+(ua<<2)>>2]|0)|0;break e}else{if((sa|0)<=6e3){break f}}}while(0);ua=sa-6001|0;if(!(ua>>>0<35>>>0)){break f}La=rJb(c[1289400+(ua<<2)>>2]|0)|0;break e;break};case 1024:{if((sa|0)<=0){break f}ua=sa-1|0;if(!(ua>>>0<3>>>0)){break f}La=rJb(c[1289272+(ua<<2)>>2]|0)|0;break e;break};case 2052:case 3076:case 4099:{if((sa|0)<=9e3){break f}ua=sa-9001|0;if(!(ua>>>0<15>>>0)){break f}La=rJb(c[1289200+(ua<<2)>>2]|0)|0;break e;break};case 2054:case 2060:{if((sa|0)<=9100){break f}ua=sa-9101|0;if(!(ua>>>0<8>>>0)){break f}La=rJb(c[1291192+(ua<<2)>>2]|0)|0;break e;break};case 2048:{do{if((sa|0)>4200){ua=sa-4201|0;if(!(ua>>>0<133>>>0)){break}La=rJb(c[1290168+(ua<<2)>>2]|0)|0;break e}else{if((sa|0)<=4e3){break f}}}while(0);ua=sa-4001|0;if(!(ua>>>0<35>>>0)){break f}La=rJb(c[1290024+(ua<<2)>>2]|0)|0;break e;break};case 2056:{if((sa|0)<=7e3){break f}ua=sa-7001|0;if(!(ua>>>0<35>>>0)){break f}La=rJb(c[1290808+(ua<<2)>>2]|0)|0;break e;break};case 4096:{if((sa|0)<=5e3){break f}ua=sa-5001|0;if(ua>>>0<32>>>0){La=rJb(c[1278600+(ua<<2)>>2]|0)|0;break e}if((sa|0)<=5100){break f}ua=sa-5101|0;if(!(ua>>>0<6>>>0)){break f}La=rJb(c[1289176+(ua<<2)>>2]|0)|0;break e;break};case 3075:{if((sa|0)<=0){break f}ua=sa-1|0;if(!(ua>>>0<27>>>0)){break f}La=rJb(c[1291056+(ua<<2)>>2]|0)|0;break e;break};case 1025:{if((sa|0)<=0){break f}ua=sa-1|0;if(!(ua>>>0<2>>>0)){break f}La=rJb(c[1289264+(ua<<2)>>2]|0)|0;break e;break};default:{}}}while(0);ua=hJb(14)|0;if((ua|0)==0){La=0;break}Rb(ua|0,14,2213680,(H=i,i=i+8|0,c[H>>2]=sa,H)|0)|0;i=H;La=ua}}while(0);c[(c[T>>2]|0)+(Ka*20|0)+16>>2]=La}else{sa=r3a(D,c[F>>2]|0)|0;c[(c[T>>2]|0)+(Ka*20|0)+12>>2]=sa}sa=Ka+1|0;if((sa|0)<(c[Q>>2]|0)){Ka=sa}else{oa=211;break}}}else if((qa|0)==270){if((o3a(c[p>>2]|0,c[o>>2]|0,2263904,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==278){if((c[o>>2]|0)==4&(ra|0)==-1){Oa=c[$>>2]|0}else{Oa=ra}if((Oa|0)==0){KIb(c[Y>>2]|0,16,2381544,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ta=-1094995529;break}else{c[da>>2]=Oa;oa=211;break}}else if((qa|0)==297){if((o3a(c[p>>2]|0,c[o>>2]|0,2240568,2235032,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==315){if((o3a(c[p>>2]|0,c[o>>2]|0,2284592,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==34737){sa=(c[I>>2]|0)-(c[C>>2]|0)|0;if((c[Q>>2]|0)>0){Pa=0}else{oa=211;break}g:while(1){wa=c[T>>2]|0;h:do{if((c[wa+(Pa*20|0)+4>>2]|0)==34737){ua=c[wa+(Pa*20|0)+8>>2]|0;do{if((ua|0)!=0){Ba=c[wa+(Pa*20|0)+12>>2]|0;if((Ba+ua|0)>>>0>(c[p>>2]|0)>>>0){break}Aa=Ba+sa|0;Ba=c[C>>2]|0;xa=c[J>>2]|0;ya=xa-Ba|0;if((Aa|0)<0){Qa=0}else{Qa=(ya|0)<(Aa|0)?ya:Aa}Aa=Ba+Qa|0;c[I>>2]=Aa;if((xa-Aa|0)>>>0<ua>>>0){ta=-1094995529;break a}Aa=hJb(ua)|0;if((Aa|0)==0){break g}xa=c[T>>2]|0;Ba=xa+(Pa*20|0)+8|0;ya=c[Ba>>2]|0;Da=c[I>>2]|0;nrc(Aa|0,Da|0,ya)|0;c[I>>2]=Da+ya;a[Aa+((c[Ba>>2]|0)-1)|0]=0;c[xa+(Pa*20|0)+16>>2]=Aa;break h}}while(0);KIb(c[Y>>2]|0,24,2302464,(H=i,i=i+8|0,c[H>>2]=c[wa+(Pa*20|0)>>2],H)|0);i=H}}while(0);wa=Pa+1|0;if((wa|0)<(c[Q>>2]|0)){Pa=wa}else{oa=211;break a}}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ta=-12;break}else if((qa|0)==259){c[O>>2]=ra;c[aa>>2]=0;if((ra|0)==3|(ra|0)==4){c[ba>>2]=0;oa=211;break}else if((ra|0)==6|(ra|0)==7){RIb(c[Y>>2]|0,2395624,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ta=-1163346256;break}else if((ra|0)==1|(ra|0)==32773|(ra|0)==5|(ra|0)==2|(ra|0)==32946|(ra|0)==8){oa=211;break}else{KIb(c[Y>>2]|0,16,2388400,(H=i,i=i+8|0,c[H>>2]=ra,H)|0);i=H;ta=-1094995529;break}}else if((qa|0)==33550){if((o3a(c[p>>2]|0,c[o>>2]|0,2338856,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==316){if((o3a(c[p>>2]|0,c[o>>2]|0,2267432,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==284){c[ka>>2]=(ra|0)==2;oa=211;break}else if((qa|0)==273){sa=c[p>>2]|0;if((sa|0)==1){c[V>>2]=0;c[ea>>2]=ra;c[fa>>2]=1;c[da>>2]=c[$>>2];Ra=0}else{c[V>>2]=pa;c[fa>>2]=sa;Ra=pa}c[ga>>2]=c[o>>2];if((Ra|0)<=((c[J>>2]|0)-(c[C>>2]|0)|0)){oa=211;break}KIb(c[Y>>2]|0,16,2374976,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ta=-1094995529;break}else if((qa|0)==266){if((ra|0)==0|ra>>>0>2>>>0){KIb(c[Y>>2]|0,16,2344968,(H=i,i=i+8|0,c[H>>2]=ra,H)|0);i=H;Sa=1}else{Sa=ra}c[P>>2]=Sa-1;oa=211;break}else if((qa|0)==293){if((c[O>>2]|0)!=4){oa=211;break}c[ba>>2]=ra;oa=211;break}else if((qa|0)==317){c[aa>>2]=ra;oa=211;break}else if((qa|0)==262){if((ra|0)==0){c[N>>2]=1;oa=211;break}else if((ra|0)==1){c[N>>2]=0;oa=211;break}else if((ra|0)==2|(ra|0)==3){oa=211;break}else{KIb(c[Y>>2]|0,16,2353360,(H=i,i=i+8|0,c[H>>2]=ra,H)|0);i=H;ta=-1094995529;break}}else if((qa|0)==292){if((c[O>>2]|0)!=3){oa=211;break}c[ba>>2]=ra;oa=211;break}else if((qa|0)==272){if((o3a(c[p>>2]|0,c[o>>2]|0,2255616,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==325|(qa|0)==323|(qa|0)==324|(qa|0)==322){KIb(c[Y>>2]|0,16,2368144,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;ta=-1163346256;break}else if((qa|0)==33432){if((o3a(c[p>>2]|0,c[o>>2]|0,2280824,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==306){if((o3a(c[p>>2]|0,c[o>>2]|0,2276584,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==269){if((o3a(c[p>>2]|0,c[o>>2]|0,2272200,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==271){if((o3a(c[p>>2]|0,c[o>>2]|0,2259952,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==258){sa=c[p>>2]|0;c[M>>2]=sa;if(sa>>>0>4>>>0){KIb(c[Y>>2]|0,16,2419072,(H=i,i=i+16|0,c[H>>2]=c[L>>2],c[H+8>>2]=sa,H)|0);i=H;ta=-1094995529;break}if((sa|0)==1){c[L>>2]=ra;oa=211;break}wa=c[o>>2]|0;if(!((wa|0)==1|(wa|0)==3|(wa|0)==4)){c[L>>2]=-1;oa=211;break}c[L>>2]=0;if(((c[J>>2]|0)-(c[I>>2]|0)|0)>>>0<(ca(d[301496+wa|0]|0,sa)|0)>>>0){ta=-1094995529;break}if((sa|0)==0){oa=211;break}sa=u3a(D,wa,c[F>>2]|0)|0;c[L>>2]=(c[L>>2]|0)+sa;if((c[p>>2]|0)>>>0>1>>>0){Ta=1}else{oa=211;break}while(1){sa=Ta+1|0;wa=u3a(D,c[o>>2]|0,c[F>>2]|0)|0;c[L>>2]=(c[L>>2]|0)+wa;if(sa>>>0<(c[p>>2]|0)>>>0){Ta=sa}else{oa=211;break}}}else if((qa|0)==305){if((o3a(c[p>>2]|0,c[o>>2]|0,2231488,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else if((qa|0)==256){c[_>>2]=ra;oa=211;break}else if((qa|0)==33920){if((o3a(c[p>>2]|0,c[o>>2]|0,2333312,0,z,A)|0)>=0){oa=211;break}KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;oa=211;break}else{pa=c[Y>>2]|0;if((c[pa+696>>2]&8|0)==0){oa=211;break}KIb(pa,16,2227632,(H=i,i=i+16|0,c[H>>2]=qa,c[H+8>>2]=qa,H)|0);i=H;ta=-1094995529;break}}}while(0);if((oa|0)==211){oa=0;pa=c[q>>2]|0;sa=c[C>>2]|0;wa=(c[J>>2]|0)-sa|0;if((pa|0)<0){Ua=0}else{Ua=(wa|0)<(pa|0)?wa:pa}c[I>>2]=sa+Ua;ta=0}if((ta|0)<0){K=ta;oa=474;break}else{na=na+1|0}}if((oa|0)==474){i=j;return K|0}i:do{if((c[Q>>2]|0)>0){na=b;ma=0;j:while(1){la=c[T>>2]|0;R=c[la+(ma*20|0)>>2]|0;X=(R|0)>4095;do{if(X){S=R-4096|0;if(!(S>>>0<4>>>0)){oa=219;break}Va=1278568+(S<<3)|0;oa=227}else{if((R|0)>3071){oa=219;break}if((R|0)>2047){oa=222;break}if((R|0)>1023){oa=225}else{oa=228}}}while(0);do{if((oa|0)==219){oa=0;qa=R-3072|0;if(!(qa>>>0<24>>>0)){oa=222;break}Va=1281112+(qa<<3)|0;oa=227}}while(0);do{if((oa|0)==222){oa=0;qa=R-2048|0;if(!(qa>>>0<14>>>0)){oa=225;break}Va=1289288+(qa<<3)|0;oa=227}}while(0);do{if((oa|0)==225){oa=0;qa=R-1024|0;if(!(qa>>>0<3>>>0)){oa=228;break}Va=1291168+(qa<<3)|0;oa=227}}while(0);do{if((oa|0)==227){oa=0;Wa=c[Va>>2]|0;if((Wa|0)==0){oa=228;break}do{if(X){qa=R-4096|0;if(!(qa>>>0<4>>>0)){oa=233;break}Xa=c[1278572+(qa<<3)>>2]|0}else{if((R|0)>3071){oa=233;break}if((R|0)>2047){oa=236;break}if((R|0)>1023){oa=239}else{Xa=-1094995529}}}while(0);do{if((oa|0)==233){oa=0;qa=R-3072|0;if(!(qa>>>0<24>>>0)){oa=236;break}Xa=c[1281116+(qa<<3)>>2]|0}}while(0);do{if((oa|0)==236){oa=0;qa=R-2048|0;if(!(qa>>>0<14>>>0)){oa=239;break}Xa=c[1289292+(qa<<3)>>2]|0}}while(0);do{if((oa|0)==239){oa=0;qa=R-1024|0;if(!(qa>>>0<3>>>0)){Xa=-1094995529;break}Xa=c[1291172+(qa<<3)>>2]|0}}while(0);if((Xa|0)==(c[la+(ma*20|0)+4>>2]|0)){qa=QHb(A)|0;Ya=MGb(qa,Wa,c[(c[T>>2]|0)+(ma*20|0)+16>>2]|0,0)|0;if((Ya|0)<0){break j}else{break}}else{KIb(na,24,2242672,(H=i,i=i+8|0,c[H>>2]=R,H)|0);i=H;break}}}while(0);if((oa|0)==228){oa=0;KIb(na,24,2293712,(H=i,i=i+8|0,c[H>>2]=R,H)|0);i=H}ma=ma+1|0;if((ma|0)>=(c[Q>>2]|0)){break i}}KIb(na,16,2201376,(H=i,i=i+8|0,c[H>>2]=Wa,H)|0);i=H;K=Ya;i=j;return K|0}}while(0);do{if((c[V>>2]|0)==0){if((c[ea>>2]|0)!=0){break}KIb(b,16,2169568,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=-1094995529;i=j;return K|0}}while(0);Q=c[L>>2]|0;T=c[M>>2]|0;k:do{switch((Q*10|0)+((c[ka>>2]|0)*1e3|0)+T|0){case 21:case 41:case 81:{oa=252;break};case 1243:{ma=c[Y>>2]|0;c[ma+140>>2]=82;Za=ma;break};case 1324:{ma=c[Y>>2]|0;c[ma+140>>2]=317;Za=ma;break};case 1483:{ma=c[Y>>2]|0;c[ma+140>>2]=(c[F>>2]|0)!=0?88:87;Za=ma;break};case 1644:{ma=c[Y>>2]|0;c[ma+140>>2]=(c[F>>2]|0)!=0?319:318;Za=ma;break};case 11:{if((c[ja>>2]|0)!=0){oa=252;break k}ma=c[Y>>2]|0;c[ma+140>>2]=10;Za=ma;break};case 243:{ma=c[Y>>2]|0;c[ma+140>>2]=2;Za=ma;break};case 161:{ma=c[Y>>2]|0;c[ma+140>>2]=(c[F>>2]|0)!=0?32:31;Za=ma;break};case 162:{ma=c[Y>>2]|0;c[ma+140>>2]=66;Za=ma;break};case 324:{ma=c[Y>>2]|0;c[ma+140>>2]=28;Za=ma;break};case 483:{ma=c[Y>>2]|0;c[ma+140>>2]=(c[F>>2]|0)!=0?42:41;Za=ma;break};case 644:{ma=c[Y>>2]|0;c[ma+140>>2]=(c[F>>2]|0)!=0?292:291;Za=ma;break};default:{KIb(c[Y>>2]|0,16,2429528,(H=i,i=i+16|0,c[H>>2]=Q,c[H+8>>2]=T,H)|0);i=H;K=-1094995529;i=j;return K|0}}}while(0);if((oa|0)==252){T=c[Y>>2]|0;c[T+140>>2]=11;Za=T}T=c[_>>2]|0;Q=c[$>>2]|0;if((T|0)==(c[Za+120>>2]|0)){if((Q|0)==(c[Za+124>>2]|0)){_a=Za}else{oa=266}}else{oa=266}do{if((oa|0)==266){ma=H4a(Za,T,Q)|0;if((ma|0)<0){K=ma;i=j;return K|0}else{_a=c[Y>>2]|0;break}}}while(0);Q=J5a(_a,s,0)|0;if((Q|0)<0){K=Q;i=j;return K|0}do{if((c[(c[Y>>2]|0)+140>>2]|0)==11){Q=c[(c[B>>2]|0)+4>>2]|0;if((c[ja>>2]|0)!=0){nrc(Q|0,x+32|0,1024)|0;break}T=Q;Q=1<<c[L>>2];if((Q|0)>0){$a=0;ab=Q}else{break}do{c[T+($a<<2)>>2]=(($a*255|0|0)/(ab-1|0)|0)*65793|0|-16777216;$a=$a+1|0;ab=1<<c[L>>2];}while(($a|0)<(ab|0))}}while(0);do{if((c[fa>>2]|0)==1){if((c[ha>>2]|0)!=0){break}KIb(b,24,2142616,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;c[ha>>2]=(c[G>>2]|0)-(c[ea>>2]|0)}}while(0);fa=c[U>>2]|0;do{if((fa|0)!=0){ja=c[G>>2]|0;if(!(fa>>>0<ja>>>0)){K=-1094995529;i=j;return K|0}T=c[E>>2]|0;na=T+fa|0;if((ja-fa|0)>-1){c[v>>2]=na;c[v+8>>2]=na;c[v+4>>2]=T+ja;break}else{KIb(0,0,2211352,(H=i,i=i+24|0,c[H>>2]=2208256,c[H+8>>2]=2199528,c[H+16>>2]=135,H)|0);i=H;Hd();return 0}}}while(0);fa=c[V>>2]|0;do{if((fa|0)!=0){ja=c[G>>2]|0;if(!(fa>>>0<ja>>>0)){K=-1094995529;i=j;return K|0}T=c[E>>2]|0;na=T+fa|0;if((ja-fa|0)>-1){c[w>>2]=na;c[w+8>>2]=na;c[w+4>>2]=T+ja;break}else{KIb(0,0,2211352,(H=i,i=i+24|0,c[H>>2]=2208256,c[H+8>>2]=2199528,c[H+16>>2]=135,H)|0);i=H;Hd();return 0}}}while(0);fa=c[da>>2]|0;if((fa|0)<1){KIb(b,16,2119056,(H=i,i=i+8|0,c[H>>2]=fa,H)|0);i=H;K=-1094995529;i=j;return K|0}if((c[ka>>2]|0)==0){bb=1;oa=291}else{fa=c[M>>2]|0;if((fa|0)>0){bb=fa;oa=291}else{cb=fa;oa=471}}do{if((oa|0)==291){fa=e+32|0;ja=e;T=x+1120|0;na=k;Q=k|0;ma=k+4|0;la=k+12|0;X=k+16|0;qa=k+20|0;S=x+1124|0;sa=S;pa=x+1128|0;wa=b+696|0;ua=0;l:while(1){Aa=fa+(ua<<2)|0;xa=c[Aa>>2]|0;Ba=ja+(ua<<2)|0;m:do{if((c[$>>2]|0)>0){ya=c[Ba>>2]|0;Da=0;n:while(1){if((c[U>>2]|0)==0){db=c[ha>>2]|0}else{db=u3a(v,c[ia>>2]|0,c[F>>2]|0)|0}if((c[V>>2]|0)==0){eb=c[ea>>2]|0}else{eb=u3a(w,c[ga>>2]|0,c[F>>2]|0)|0}Ca=c[G>>2]|0;if(eb>>>0>Ca>>>0|db>>>0>(Ca-eb|0)>>>0){oa=301;break l}Ca=c[E>>2]|0;fb=Ca+eb|0;gb=c[da>>2]|0;hb=(c[$>>2]|0)-Da|0;ib=(gb|0)>(hb|0)?hb:gb;gb=((ca(c[L>>2]|0,c[_>>2]|0)|0)+7|0)>>>3;if((c[ka>>2]|0)==0){jb=gb}else{jb=(gb>>>0)/((c[M>>2]|0)>>>0)|0}if((db|0)<1){kb=-1094995529;break}gb=c[O>>2]|0;if((gb|0)==32946|(gb|0)==8){lb=ca(jb,ib)|0;mb=hJb(lb)|0;if((mb|0)==0){kb=-12;break}do{if((c[P>>2]|0)==0){nb=fb}else{A4a(S,pa,db);hb=c[sa>>2]|0;if((hb|0)==0){oa=312;break n}if((db|0)<=0){nb=hb;break}a[hb]=a[1316536+(d[fb]|0)|0]|0;if((db|0)>1){hb=1;do{a[(c[sa>>2]|0)+hb|0]=a[1316536+(d[Ca+(hb+eb)|0]|0)|0]|0;hb=hb+1|0;}while((hb|0)<(db|0))}nb=c[sa>>2]|0}}while(0);mrc(na|0,0,56)|0;c[Q>>2]=nb;c[ma>>2]=db;c[la>>2]=mb;c[X>>2]=lb;ob=_pc(k,2458248,56)|0;if((ob|0)!=0){oa=315;break}hb=$pc(k,2)|0;cqc(k)|0;pb=(hb|0)==1?0:hb;if((pb|0)!=0){qb=c[qa>>2]|0;rb=pb;oa=319;break}o:do{if((ib|0)>0){pb=(jb|0)>0;hb=mb;sb=ya;tb=1;while(1){ub=c[L>>2]|0;do{if(ub>>>0<8>>>0){if((c[(c[Y>>2]|0)+140>>2]|0)!=11){oa=330;break}if((ub|0)==4){if(pb){vb=jb}else{break}do{vb=vb-1|0;wb=a[hb+vb|0]|0;xb=vb<<1;a[sb+(xb|1)|0]=wb&15;a[sb+xb|0]=(wb&255)>>>4;}while((vb|0)>0)}else if((ub|0)==2){if(pb){yb=jb}else{break}do{yb=yb-1|0;wb=a[hb+yb|0]|0;xb=yb<<2;a[sb+(xb|3)|0]=wb&3;a[sb+(xb|2)|0]=(wb&255)>>>2&3;a[sb+(xb|1)|0]=(wb&255)>>>4&3;a[sb+xb|0]=(wb&255)>>>6;}while((yb|0)>0)}else if((ub|0)==1){if(pb){zb=jb}else{break}do{zb=zb-1|0;wb=a[hb+zb|0]|0;xb=zb<<3;a[sb+(xb|7)|0]=wb&1;a[sb+(xb|6)|0]=(wb&255)>>>1&1;a[sb+(xb|5)|0]=(wb&255)>>>2&1;a[sb+(xb|4)|0]=(wb&255)>>>3&1;a[sb+(xb|3)|0]=(wb&255)>>>4&1;a[sb+(xb|2)|0]=(wb&255)>>>5&1;a[sb+(xb|1)|0]=(wb&255)>>>6&1;a[sb+xb|0]=(wb&255)>>>7;}while((zb|0)>0)}else{nrc(sb|0,hb|0,jb)|0;break}}else{oa=330}}while(0);if((oa|0)==330){oa=0;nrc(sb|0,hb|0,jb)|0}if((tb|0)>=(ib|0)){break o}hb=hb+jb|0;sb=sb+xa|0;tb=tb+1|0}}}while(0);kJb(mb)}else if((gb|0)==5){do{if((c[P>>2]|0)==0){Ab=fb;oa=340}else{A4a(S,pa,db);tb=c[sa>>2]|0;if((tb|0)==0){kb=-12;break n}if((db|0)<=0){Bb=tb;break}a[tb]=a[1316536+(d[fb]|0)|0]|0;if((db|0)>1){tb=1;do{a[(c[sa>>2]|0)+tb|0]=a[1316536+(d[Ca+(tb+eb)|0]|0)|0]|0;tb=tb+1|0;}while((tb|0)<(db|0))}Ab=c[sa>>2]|0;oa=340}}while(0);do{if((oa|0)==340){oa=0;if((db|0)<=1){Bb=Ab;break}if((a[Ab]|0)!=0){Bb=Ab;break}if((a[Ab+1|0]&1)==0){Bb=Ab;break}KIb(c[Y>>2]|0,16,2614024,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;Bb=Ab}}while(0);Cb=HPa(c[T>>2]|0,8,Bb,db,1)|0;if((Cb|0)<0){oa=346;break}Db=Bb;Eb=c[O>>2]|0;oa=347}else{Db=fb;Eb=gb;oa=347}do{if((oa|0)==347){oa=0;if((Eb-2|0)>>>0<3>>>0){Fb=hJb(db+16|0)|0;if((Fb|0)==0){oa=351;break n}Ca=c[ba>>2]|0;if((Ca&2|0)!=0){oa=353;break n}do{if((c[P>>2]|0)==0){nrc(Fb|0,Db|0,db)|0}else{if((db|0)>0){Gb=0}else{break}do{a[Fb+Gb|0]=a[1316536+(d[Db+Gb|0]|0)|0]|0;Gb=Gb+1|0;}while((Gb|0)<(db|0))}}while(0);mrc(Fb+db|0,0,16)|0;tb=Fpb(c[Y>>2]|0,Fb,db,ya,ib,xa,c[O>>2]|0,Ca)|0;sb=c[L>>2]|0;p:do{if(sb>>>0<8>>>0){if(!((c[(c[Y>>2]|0)+140>>2]|0)==11&(ib|0)>0)){break}hb=(jb|0)>0;pb=ya;ub=1;wb=sb;while(1){do{if((wb|0)==4){if(hb){Hb=jb}else{break}do{Hb=Hb-1|0;xb=pb+Hb|0;Ib=Hb<<1;a[pb+(Ib|1)|0]=a[xb]&15;a[pb+Ib|0]=(d[xb]|0)>>>4;}while((Hb|0)>0)}else if((wb|0)==2){if(hb){Jb=jb}else{break}do{Jb=Jb-1|0;xb=pb+Jb|0;Ib=Jb<<2;a[pb+(Ib|3)|0]=a[xb]&3;a[pb+(Ib|2)|0]=(d[xb]|0)>>>2&3;a[pb+(Ib|1)|0]=(d[xb]|0)>>>4&3;a[pb+Ib|0]=(d[xb]|0)>>>6;}while((Jb|0)>0)}else if((wb|0)==1){if(hb){Kb=jb}else{break}do{Kb=Kb-1|0;xb=pb+Kb|0;Ib=Kb<<3;a[pb+(Ib|7)|0]=a[xb]&1;a[pb+(Ib|6)|0]=(d[xb]|0)>>>1&1;a[pb+(Ib|5)|0]=(d[xb]|0)>>>2&1;a[pb+(Ib|4)|0]=(d[xb]|0)>>>3&1;a[pb+(Ib|3)|0]=(d[xb]|0)>>>4&1;a[pb+(Ib|2)|0]=(d[xb]|0)>>>5&1;a[pb+(Ib|1)|0]=(d[xb]|0)>>>6&1;a[pb+Ib|0]=(d[xb]|0)>>>7;}while((Kb|0)>0)}}while(0);if((ub|0)>=(ib|0)){break p}pb=pb+xa|0;ub=ub+1|0;wb=c[L>>2]|0}}}while(0);kJb(Fb);if((tb|0)<0){kb=tb;break n}else{break}}if((ib|0)<=0){break}sb=Db;Ca=Db+db|0;wb=(jb|0)>0;ub=wb^1;pb=Db;hb=ya;xb=0;while(1){Ib=pb;if((Ib-sb|0)>(db|0)){oa=371;break n}Lb=c[O>>2]|0;do{if((Lb|0)==32773){if(wb){Mb=pb;Nb=0}else{Ob=pb;break}while(1){if((Ca-Mb|0)<2){oa=388;break n}Pb=Mb+1|0;Qb=a[Mb]|0;if((c[P>>2]|0)==0){Sb=Qb}else{Sb=a[1316536+(Qb&255)|0]|0}Qb=Sb<<24>>24;do{if(Sb<<24>>24>-1){Tb=Qb+1|0;Ub=Tb+Nb|0;if((Ub|0)>(jb|0)){oa=394;break n}if((Ca-Pb|0)<(Tb|0)){oa=394;break n}Vb=c[L>>2]&-((c[(c[Y>>2]|0)+140>>2]|0)==11|0);do{if((Vb|0)==4){if((Tb|0)>0){Wb=Qb}else{break}while(1){Xb=Mb+(Wb+1)|0;Yb=Wb+Nb<<1;a[hb+(Yb|1)|0]=a[Xb]&15;a[hb+Yb|0]=(d[Xb]|0)>>>4;if((Wb|0)>0){Wb=Wb-1|0}else{break}}}else if((Vb|0)==2){if((Tb|0)>0){Zb=Qb}else{break}while(1){Xb=Mb+(Zb+1)|0;Yb=Zb+Nb<<2;a[hb+(Yb|3)|0]=a[Xb]&3;a[hb+(Yb|2)|0]=(d[Xb]|0)>>>2&3;a[hb+(Yb|1)|0]=(d[Xb]|0)>>>4&3;a[hb+Yb|0]=(d[Xb]|0)>>>6;if((Zb|0)>0){Zb=Zb-1|0}else{break}}}else if((Vb|0)==1){if((Tb|0)>0){_b=Qb}else{break}while(1){Xb=Mb+(_b+1)|0;Yb=_b+Nb<<3;a[hb+(Yb|7)|0]=a[Xb]&1;a[hb+(Yb|6)|0]=(d[Xb]|0)>>>1&1;a[hb+(Yb|5)|0]=(d[Xb]|0)>>>2&1;a[hb+(Yb|4)|0]=(d[Xb]|0)>>>3&1;a[hb+(Yb|3)|0]=(d[Xb]|0)>>>4&1;a[hb+(Yb|2)|0]=(d[Xb]|0)>>>5&1;a[hb+(Yb|1)|0]=(d[Xb]|0)>>>6&1;a[hb+Yb|0]=(d[Xb]|0)>>>7;if((_b|0)>0){_b=_b-1|0}else{break}}}else{nrc(hb+Nb|0,Pb|0,Tb)|0}}while(0);$b=Ub;ac=Mb+(Qb+2)|0}else{if(Sb<<24>>24==-128){$b=Nb;ac=Pb;break}Tb=1-Qb|0;Vb=Tb+Nb|0;if((Vb|0)>(jb|0)){oa=407;break n}Xb=Mb+2|0;Yb=a[Pb]|0;bc=c[L>>2]&-((c[(c[Y>>2]|0)+140>>2]|0)==11|0);if((bc|0)==4){if((Tb|0)<=0){$b=Vb;ac=Xb;break}cc=Yb&15;dc=(Yb&255)>>>4;ec=Tb;while(1){fc=ec-1|0;gc=fc+Nb<<1;a[hb+(gc|1)|0]=cc;a[hb+gc|0]=dc;if((fc|0)>0){ec=fc}else{$b=Vb;ac=Xb;break}}}else if((bc|0)==2){if((Tb|0)<=0){$b=Vb;ac=Xb;break}ec=Yb&3;dc=(Yb&255)>>>2&3;cc=(Yb&255)>>>4&3;Ub=(Yb&255)>>>6;fc=Tb;while(1){gc=fc-1|0;hc=gc+Nb<<2;a[hb+(hc|3)|0]=ec;a[hb+(hc|2)|0]=dc;a[hb+(hc|1)|0]=cc;a[hb+hc|0]=Ub;if((gc|0)>0){fc=gc}else{$b=Vb;ac=Xb;break}}}else if((bc|0)==1){if((Tb|0)<=0){$b=Vb;ac=Xb;break}fc=Yb&1;Ub=(Yb&255)>>>1&1;cc=(Yb&255)>>>2&1;dc=(Yb&255)>>>3&1;ec=(Yb&255)>>>4&1;gc=(Yb&255)>>>5&1;hc=(Yb&255)>>>6&1;ic=(Yb&255)>>>7;jc=Tb;while(1){kc=jc-1|0;lc=kc+Nb<<3;a[hb+(lc|7)|0]=fc;a[hb+(lc|6)|0]=Ub;a[hb+(lc|5)|0]=cc;a[hb+(lc|4)|0]=dc;a[hb+(lc|3)|0]=ec;a[hb+(lc|2)|0]=gc;a[hb+(lc|1)|0]=hc;a[hb+lc|0]=ic;if((kc|0)>0){jc=kc}else{$b=Vb;ac=Xb;break}}}else{mrc(hb+Nb|0,Yb|0,Tb|0)|0;$b=Vb;ac=Xb;break}}}while(0);if(($b|0)<(jb|0)){Mb=ac;Nb=$b}else{break}}if((c[P>>2]|0)==0|ub){Ob=ac;break}else{mc=0}while(1){Pb=hb+mc|0;a[Pb]=a[1316536+(d[Pb]|0)|0]|0;Pb=mc+1|0;if((Pb|0)<(jb|0)){mc=Pb}else{Ob=ac;break}}}else if((Lb|0)==1){if((Ca-Ib|0)<(jb|0)){kb=-1094995529;break n}do{if((c[P>>2]|0)==0){Pb=c[L>>2]&-((c[(c[Y>>2]|0)+140>>2]|0)==11|0);if((Pb|0)==1){if(wb){nc=jb}else{break}do{nc=nc-1|0;Qb=pb+nc|0;jc=nc<<3;a[hb+(jc|7)|0]=a[Qb]&1;a[hb+(jc|6)|0]=(d[Qb]|0)>>>1&1;a[hb+(jc|5)|0]=(d[Qb]|0)>>>2&1;a[hb+(jc|4)|0]=(d[Qb]|0)>>>3&1;a[hb+(jc|3)|0]=(d[Qb]|0)>>>4&1;a[hb+(jc|2)|0]=(d[Qb]|0)>>>5&1;a[hb+(jc|1)|0]=(d[Qb]|0)>>>6&1;a[hb+jc|0]=(d[Qb]|0)>>>7;}while((nc|0)>0)}else if((Pb|0)==4){if(wb){oc=jb}else{break}do{oc=oc-1|0;Qb=pb+oc|0;jc=oc<<1;a[hb+(jc|1)|0]=a[Qb]&15;a[hb+jc|0]=(d[Qb]|0)>>>4;}while((oc|0)>0)}else if((Pb|0)==2){if(wb){pc=jb}else{break}do{pc=pc-1|0;Qb=pb+pc|0;jc=pc<<2;a[hb+(jc|3)|0]=a[Qb]&3;a[hb+(jc|2)|0]=(d[Qb]|0)>>>2&3;a[hb+(jc|1)|0]=(d[Qb]|0)>>>4&3;a[hb+jc|0]=(d[Qb]|0)>>>6;}while((pc|0)>0)}else{nrc(hb|0,pb|0,jb)|0;break}}else{if(wb){qc=0}else{break}do{a[hb+qc|0]=a[1316536+(d[pb+qc|0]|0)|0]|0;qc=qc+1|0;}while((qc|0)<(jb|0))}}while(0);Ob=pb+jb|0}else if((Lb|0)==5){rc=IPa(c[T>>2]|0,hb,jb)|0;if((rc|0)<(jb|0)){oa=422;break n}Pb=c[L>>2]|0;if(!(Pb>>>0<8>>>0)){Ob=pb;break}if((c[(c[Y>>2]|0)+140>>2]|0)!=11){Ob=pb;break}if((Pb|0)==4){if(wb){sc=jb}else{Ob=pb;break}while(1){Qb=sc-1|0;jc=hb+Qb|0;ic=Qb<<1;a[hb+(ic|1)|0]=a[jc]&15;a[hb+ic|0]=(d[jc]|0)>>>4;if((Qb|0)>0){sc=Qb}else{Ob=pb;break}}}else if((Pb|0)==2){if(wb){tc=jb}else{Ob=pb;break}while(1){Qb=tc-1|0;jc=hb+Qb|0;ic=Qb<<2;a[hb+(ic|3)|0]=a[jc]&3;a[hb+(ic|2)|0]=(d[jc]|0)>>>2&3;a[hb+(ic|1)|0]=(d[jc]|0)>>>4&3;a[hb+ic|0]=(d[jc]|0)>>>6;if((Qb|0)>0){tc=Qb}else{Ob=pb;break}}}else if((Pb|0)==1){if(wb){uc=jb}else{Ob=pb;break}while(1){Qb=uc-1|0;jc=hb+Qb|0;ic=Qb<<3;a[hb+(ic|7)|0]=a[jc]&1;a[hb+(ic|6)|0]=(d[jc]|0)>>>1&1;a[hb+(ic|5)|0]=(d[jc]|0)>>>2&1;a[hb+(ic|4)|0]=(d[jc]|0)>>>3&1;a[hb+(ic|3)|0]=(d[jc]|0)>>>4&1;a[hb+(ic|2)|0]=(d[jc]|0)>>>5&1;a[hb+(ic|1)|0]=(d[jc]|0)>>>6&1;a[hb+ic|0]=(d[jc]|0)>>>7;if((Qb|0)>0){uc=Qb}else{Ob=pb;break}}}else{Ob=pb;break}}else{Ob=pb}}while(0);Lb=xb+1|0;if((Lb|0)<(ib|0)){pb=Ob;hb=hb+xa|0;xb=Lb}else{break}}}}while(0);ib=c[da>>2]|0;gb=ib+Da|0;if((gb|0)>=(c[$>>2]|0)){break m}ya=ya+(ca(ib,xa)|0)|0;Da=gb}if((oa|0)==312){oa=0;kJb(mb);kb=-12}else if((oa|0)==315){oa=0;KIb(0,16,2441288,(H=i,i=i+8|0,c[H>>2]=ob,H)|0);i=H;qb=lb;rb=ob;oa=319}else if((oa|0)==346){oa=0;KIb(c[Y>>2]|0,16,2587104,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=Cb}else if((oa|0)==351){oa=0;KIb(c[Y>>2]|0,16,2488272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-12}else if((oa|0)==353){oa=0;QIb(c[Y>>2]|0,2477344,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kJb(Fb);kb=-1163346256}else if((oa|0)==371){oa=0;KIb(c[Y>>2]|0,16,2566080,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-1094995529}else if((oa|0)==388){oa=0;KIb(c[Y>>2]|0,16,2548016,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-1094995529}else if((oa|0)==394){oa=0;KIb(c[Y>>2]|0,16,2530096,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-1094995529}else if((oa|0)==407){oa=0;KIb(c[Y>>2]|0,16,2514880,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;kb=-1094995529}else if((oa|0)==422){oa=0;KIb(c[Y>>2]|0,16,2501032,(H=i,i=i+16|0,c[H>>2]=rc,c[H+8>>2]=jb,H)|0);i=H;kb=-1094995529}if((oa|0)==319){oa=0;KIb(c[Y>>2]|0,16,2467816,(H=i,i=i+24|0,c[H>>2]=qb,c[H+8>>2]=lb,c[H+16>>2]=rb,H)|0);i=H;kJb(mb);kb=-1313558101}if((c[wa>>2]&8|0)!=0){K=kb;oa=474;break l}}}while(0);q:do{if((c[aa>>2]|0)==2){R=c[Ba>>2]|0;Da=(c[L>>2]|0)>>>3;if((c[ka>>2]|0)==0){vc=Da}else{ya=(Da>>>0)/((c[M>>2]|0)>>>0)|0;vc=ya>>>0>1>>>0?ya:1}ya=ca(c[_>>2]|0,vc)|0;switch(c[(c[Y>>2]|0)+140>>2]|0){case 42:case 292:case 88:case 319:{Da=c[$>>2]|0;if((Da|0)<=0){break q}gb=vc>>>0<ya>>>0;ib=R;fb=0;xb=Da;while(1){if(gb){Da=vc;do{hb=ib+Da|0;pb=ib+(Da-vc)|0;y=((d[pb]|d[pb+1|0]<<8)<<16>>16)+((d[hb]|d[hb+1|0]<<8)<<16>>16)&65535;a[hb]=y;y=y>>8;a[hb+1|0]=y;Da=Da+2|0;}while(Da>>>0<ya>>>0);wc=c[$>>2]|0}else{wc=xb}Da=fb+1|0;if((Da|0)<(wc|0)){ib=ib+xa|0;fb=Da;xb=wc}else{break}}break};case 41:case 291:case 87:case 318:{xb=c[$>>2]|0;if((xb|0)<=0){break q}if(vc>>>0<ya>>>0){xc=R;yc=0}else{fb=0;while(1){fb=fb+1|0;if((fb|0)>=(xb|0)){break q}}}while(1){xb=vc;do{fb=xc+xb|0;ib=he((d[fb]|d[fb+1|0]<<8)<<16>>16|0)|0;gb=xc+(xb-vc)|0;y=he((he((d[gb]|d[gb+1|0]<<8)<<16>>16|0)|0)+ib&65535|0)|0;a[fb]=y;y=y>>8;a[fb+1|0]=y;xb=xb+2|0;}while(xb>>>0<ya>>>0);xb=yc+1|0;if((xb|0)<(c[$>>2]|0)){xc=xc+xa|0;yc=xb}else{break}}break};default:{xb=c[$>>2]|0;if((xb|0)<=0){break q}fb=vc>>>0<ya>>>0;ib=R;gb=0;Da=xb;while(1){if(fb){xb=vc;do{hb=ib+xb|0;a[hb]=(a[hb]|0)+(a[ib+(xb-vc)|0]|0);xb=xb+1|0;}while(xb>>>0<ya>>>0);zc=c[$>>2]|0}else{zc=Da}xb=gb+1|0;if((xb|0)<(zc|0)){ib=ib+xa|0;gb=xb;Da=zc}else{break}}}}}}while(0);do{if((c[N>>2]|0)!=0){xa=c[$>>2]|0;if((xa|0)<=0){break}Da=c[Ba>>2]|0;gb=0;ib=c[Aa>>2]|0;ya=xa;while(1){if((ib|0)>0){xa=0;do{if((c[(c[Y>>2]|0)+140>>2]|0)==11){Ac=(1<<c[L>>2])-1|0}else{Ac=255}fb=Da+xa|0;a[fb]=Ac-(d[fb]|0);xa=xa+1|0;Cc=c[Aa>>2]|0;}while((xa|0)<(Cc|0));Dc=Cc;Ec=c[$>>2]|0}else{Dc=ib;Ec=ya}xa=gb+1|0;if((xa|0)<(Ec|0)){Da=Da+Dc|0;gb=xa;ib=Dc;ya=Ec}else{break}}}}while(0);Aa=ua+1|0;if((Aa|0)<(bb|0)){ua=Aa}else{oa=469;break}}if((oa|0)==301){KIb(b,16,2637272,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=-1094995529;i=j;return K|0}else if((oa|0)==469){if((c[ka>>2]|0)==0){break}cb=c[M>>2]|0;oa=471;break}else if((oa|0)==474){i=j;return K|0}}}while(0);do{if((oa|0)==471){if(!(cb>>>0>2>>>0)){break}M=e+8|0;ka=c[M>>2]|0;$=e;c[M>>2]=c[$>>2];M=e+40|0;L=c[M>>2]|0;Y=e+32|0;c[M>>2]=c[Y>>2];M=e+4|0;N=c[M>>2]|0;c[M>>2]=ka;c[$>>2]=N;N=e+36|0;$=c[N>>2]|0;c[N>>2]=L;c[Y>>2]=$}}while(0);c[f>>2]=1;K=c[G>>2]|0;i=j;return K|0}}while(0);KIb(b,16,2356520,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;K=-1094995529;i=j;return K|0}function n3a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+60>>2]|0;a=b+1132|0;d=c[a>>2]|0;e=b+1136|0;f=e;if((d|0)>0){g=0;h=d;while(1){d=(c[f>>2]|0)+(g*20|0)+16|0;if((c[d>>2]|0)==0){i=h}else{mJb(d);i=c[a>>2]|0}d=g+1|0;if((d|0)<(i|0)){g=d;h=i}else{break}}}mJb(e);c[a>>2]=0;GPa(b+1120|0);mJb(b+1124|0);return 0}function o3a(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;if((b|0)==2){h=c[f+1060>>2]|0;i=A3a(a,d,f+4|0,h,QHb(g)|0)|0;return i|0}else if((b|0)==3){h=c[f+1060>>2]|0;i=y3a(a,d,e,f+4|0,h,QHb(g)|0)|0;return i|0}else if((b|0)==12){b=c[f+1060>>2]|0;i=x3a(a,d,e,f+4|0,b,QHb(g)|0)|0;return i|0}else{i=-1094995529;return i|0}return 0}function p3a(a,b){a=a|0;b=b|0;return(c[a>>2]|0)-(c[b>>2]|0)|0}function q3a(a){a=a|0;var b=0,c=0,d=0,f=0;b=0;while(1){if(!(b>>>0<3>>>0)){c=0;d=4;break}f=b+1|0;if((e[1076392+(b<<1)>>1]|0|0)==(a|0)){c=f;d=4;break}else{b=f}}if((d|0)==4){return c|0}return 0}function r3a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a|0;f=c[e>>2]|0;g=((c[a+4>>2]|0)-f|0)<2;if((b|0)==0){if(g){h=0;return h|0}c[e>>2]=f+2;b=f;h=(he((d[b]|d[b+1|0]<<8)<<16>>16|0)|0)&65535;return h|0}else{if(g){h=0;return h|0}c[e>>2]=f+2;e=f;h=(d[e]|d[e+1|0]<<8)<<16>>16&65535;return h|0}return 0}function s3a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a|0;f=c[e>>2]|0;g=((c[a+4>>2]|0)-f|0)<4;if((b|0)==0){if(g){h=0;return h|0}c[e>>2]=f+4;b=f;h=je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0;return h|0}else{if(g){h=0;return h|0}c[e>>2]=f+4;e=f;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;return h|0}return 0}function t3a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,i=0,j=0,l=0.0,m=0;e=a|0;f=c[e>>2]|0;g=((c[a+4>>2]|0)-f|0)<8;if((b|0)==0){if(g){i=0;j=0;l=(c[k>>2]=j,c[k+4>>2]=i,+h[k>>3]);return+l}c[e>>2]=f+8;b=f;a=b|0;m=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=b+4|0;b=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;a=je(m|0)|0;i=a|0;j=je(b|0)|0;l=(c[k>>2]=j,c[k+4>>2]=i,+h[k>>3]);return+l}else{if(g){i=0;j=0;l=(c[k>>2]=j,c[k+4>>2]=i,+h[k>>3]);return+l}c[e>>2]=f+8;e=f;f=e|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;i=e;j=g;l=(c[k>>2]=j,c[k+4>>2]=i,+h[k>>3]);return+l}return 0.0}function u3a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((b|0)==1){f=a|0;g=c[f>>2]|0;if(((c[a+4>>2]|0)-g|0)<1){h=0;return h|0}c[f>>2]=g+1;h=d[g]|0;return h|0}else if((b|0)==4){g=a|0;f=c[g>>2]|0;i=((c[a+4>>2]|0)-f|0)<4;if((e|0)==0){if(i){h=0;return h|0}c[g>>2]=f+4;j=f;h=je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;return h|0}else{if(i){h=0;return h|0}c[g>>2]=f+4;g=f;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;return h|0}}else if((b|0)==3){b=a|0;g=c[b>>2]|0;f=((c[a+4>>2]|0)-g|0)<2;if((e|0)==0){if(f){h=0;return h|0}c[b>>2]=g+2;e=g;h=(he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;return h|0}else{if(f){h=0;return h|0}c[b>>2]=g+2;b=g;h=(d[b]|d[b+1|0]<<8)<<16>>16&65535;return h|0}}else{h=-1;return h|0}return 0}function v3a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=i;i=i+1032|0;k=j|0;l=j+1024|0;if(a>>>0>268435454>>>0|(a|0)<1){m=-1094995529;i=j;return m|0}n=f|0;o=f+4|0;if(((c[o>>2]|0)-(c[n>>2]|0)|0)>>>0<a<<3>>>0){m=-1094995529;i=j;return m|0}SFb(k,a*10|0,-1);if((a|0)>0){f=(e|0)==0;p=(a|0)>4?2119048:10230088;if((g|0)==0){g=0;do{q=c[n>>2]|0;r=c[o>>2]|0;if((r-q|0)<4){s=0;t=q}else{u=q+4|0;c[n>>2]=u;v=q;s=je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;t=u}if((r-t|0)<4){w=0}else{c[n>>2]=t+4;r=t;w=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0}r=(g|0)!=0;if(f){x=(g&3|0)==0|r^1?p:2142608}else{x=r?e:10230088}UFb(k,2471680,(y=i,i=i+24|0,c[y>>2]=x,c[y+8>>2]=s,c[y+16>>2]=w,y)|0);i=y;g=g+1|0;}while((g|0)<(a|0))}else{g=0;do{w=c[n>>2]|0;s=c[o>>2]|0;if((s-w|0)<4){z=0;A=w}else{x=w+4|0;c[n>>2]=x;t=w;z=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;A=x}if((s-A|0)<4){B=0}else{c[n>>2]=A+4;s=A;B=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0}s=(g|0)!=0;if(f){C=(g&3|0)==0|s^1?p:2142608}else{C=s?e:10230088}UFb(k,2471680,(y=i,i=i+24|0,c[y>>2]=C,c[y+8>>2]=z,c[y+16>>2]=B,y)|0);i=y;g=g+1|0;}while((g|0)<(a|0))}}a=_Fb(k,l)|0;if((a|0)!=0){m=a;i=j;return m|0}a=c[l>>2]|0;if((a|0)==0){m=-12;i=j;return m|0}MGb(h,b,a,8)|0;m=0;i=j;return m|0}function w3a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+1032|0;k=j|0;l=j+1024|0;if(a>>>0>536870910>>>0|(a|0)<1){m=-1094995529;i=j;return m|0}n=f|0;o=f+4|0;if(((c[o>>2]|0)-(c[n>>2]|0)|0)>>>0<a<<2>>>0){m=-1094995529;i=j;return m|0}SFb(k,a*10|0,-1);if((a|0)>0){f=(a|0)>8?2119048:10230088;p=(g|0)==0;if((e|0)==0){g=0;do{q=(g&7|0)==0|(g|0)==0?f:2142608;r=c[n>>2]|0;s=((c[o>>2]|0)-r|0)<4;do{if(p){if(s){t=0;break}c[n>>2]=r+4;u=r;t=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0}else{if(s){t=0;break}c[n>>2]=r+4;u=r;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0}}while(0);UFb(k,2594528,(v=i,i=i+16|0,c[v>>2]=q,c[v+8>>2]=t,v)|0);i=v;g=g+1|0;}while((g|0)<(a|0))}else{g=0;do{t=(g|0)!=0?e:10230088;f=c[n>>2]|0;r=((c[o>>2]|0)-f|0)<4;do{if(p){if(r){w=0;break}c[n>>2]=f+4;s=f;w=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0}else{if(r){w=0;break}c[n>>2]=f+4;s=f;w=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0}}while(0);UFb(k,2594528,(v=i,i=i+16|0,c[v>>2]=t,c[v+8>>2]=w,v)|0);i=v;g=g+1|0;}while((g|0)<(a|0))}}a=_Fb(k,l)|0;if((a|0)!=0){m=a;i=j;return m|0}a=c[l>>2]|0;if((a|0)==0){m=-12;i=j;return m|0}MGb(h,b,a,8)|0;m=0;i=j;return m|0}function x3a(a,b,e,f,g,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0;l=i;i=i+1032|0;m=l|0;n=l+1024|0;if(a>>>0>268435454>>>0|(a|0)<1){o=-1094995529;i=l;return o|0}p=f|0;q=f+4|0;if(((c[q>>2]|0)-(c[p>>2]|0)|0)>>>0<a<<3>>>0){o=-1094995529;i=l;return o|0}SFb(m,a*10|0,a*100|0);if((a|0)>0){f=(e|0)==0;r=(a|0)>4?2119048:10230088;s=(g|0)==0;g=0;do{t=(g|0)!=0;if(f){u=(g&3|0)==0|t^1?r:2142608}else{u=t?e:10230088}t=c[p>>2]|0;v=((c[q>>2]|0)-t|0)<8;do{if(s){if(v){w=0;x=0;break}c[p>>2]=t+8;y=t;z=y|0;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=y+4|0;y=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=je(A|0)|0;w=z|0;x=je(y|0)|0}else{if(v){w=0;x=0;break}c[p>>2]=t+8;y=t;z=y|0;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=y+4|0;y=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;w=y;x=A}}while(0);B=(c[k>>2]=x,c[k+4>>2]=w,+h[k>>3]);UFb(m,2445760,(t=i,i=i+16|0,c[t>>2]=u,h[t+8>>3]=B,t)|0);i=t;g=g+1|0;}while((g|0)<(a|0))}a=_Fb(m,n)|0;if((a|0)!=0){o=a;i=l;return o|0}a=c[n>>2]|0;if((a|0)==0){o=-12;i=l;return o|0}MGb(j,b,a,8)|0;o=0;i=l;return o|0}function y3a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+1032|0;k=j|0;l=j+1024|0;if(a>>>0>1073741822>>>0|(a|0)<1){m=-1094995529;i=j;return m|0}n=f|0;o=f+4|0;if(((c[o>>2]|0)-(c[n>>2]|0)|0)>>>0<a<<1>>>0){m=-1094995529;i=j;return m|0}SFb(k,a*10|0,-1);if((a|0)>0){f=(e|0)==0;p=(a|0)>8?2119048:10230088;q=(g|0)==0;g=0;do{r=(g|0)!=0;if(f){s=(g&7|0)==0|r^1?p:2142608}else{s=r?e:10230088}r=c[n>>2]|0;t=((c[o>>2]|0)-r|0)<2;do{if(q){if(t){u=0;break}c[n>>2]=r+2;v=r;u=(he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535}else{if(t){u=0;break}c[n>>2]=r+2;v=r;u=(d[v]|d[v+1|0]<<8)<<16>>16&65535}}while(0);UFb(k,2356480,(r=i,i=i+16|0,c[r>>2]=s,c[r+8>>2]=u,r)|0);i=r;g=g+1|0;}while((g|0)<(a|0))}a=_Fb(k,l)|0;if((a|0)!=0){m=a;i=j;return m|0}a=c[l>>2]|0;if((a|0)==0){m=-12;i=j;return m|0}MGb(h,b,a,8)|0;m=0;i=j;return m|0}function z3a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+1032|0;j=g|0;k=g+1024|0;if(a>>>0>2147483646>>>0|(a|0)<0){l=-1094995529;i=g;return l|0}m=f|0;n=f+4|0;if(((c[n>>2]|0)-(c[m>>2]|0)|0)>>>0<a>>>0){l=-1094995529;i=g;return l|0}SFb(j,a*10|0,-1);if((a|0)>0){f=(e|0)==0;o=(a|0)>16?2119048:10230088;p=0;do{q=(p|0)!=0;if(f){r=(p&15|0)==0|q^1?o:2142608}else{r=q?e:10230088}q=c[m>>2]|0;if(((c[n>>2]|0)-q|0)<1){s=0}else{c[m>>2]=q+1;s=d[q]|0}UFb(j,2293672,(q=i,i=i+16|0,c[q>>2]=r,c[q+8>>2]=s,q)|0);i=q;p=p+1|0;}while((p|0)<(a|0))}a=_Fb(j,k)|0;if((a|0)!=0){l=a;i=g;return l|0}a=c[k>>2]|0;if((a|0)==0){l=-12;i=g;return l|0}MGb(h,b,a,8)|0;l=0;i=g;return l|0}function A3a(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;f=e|0;if(((c[e+4>>2]|0)-(c[f>>2]|0)|0)>>>0<b>>>0|(b|0)<0){h=-1094995529;return h|0}e=hJb(b+1|0)|0;if((e|0)==0){h=-12;return h|0}i=c[f>>2]|0;nrc(e|0,i|0,b)|0;c[f>>2]=i+b;a[e+b|0]=0;MGb(g,d,e,8)|0;h=0;return h|0}function B3a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a|0;g=c[f>>2]|0;h=a+4|0;if(((c[h>>2]|0)-g|0)>>>0<8>>>0){i=-1094995529;return i|0}c[f>>2]=g+2;a=g;g=(d[a]|d[a+1|0]<<8)<<16>>16;c[b>>2]=g&65535;do{if(g<<16>>16==18761){j=1}else{if(g<<16>>16==19789){j=0;break}else{i=-1094995529}return i|0}}while(0);c[b>>2]=j;b=(j|0)==0;j=c[f>>2]|0;g=c[h>>2]|0;h=(g-j|0)<2;do{if(b){if(h){i=-1094995529;return i|0}else{a=j+2|0;c[f>>2]=a;k=j;l=he((d[k]|d[k+1|0]<<8)<<16>>16|0)|0;m=a;break}}else{if(h){i=-1094995529;return i|0}else{a=j+2|0;c[f>>2]=a;k=j;l=(d[k]|d[k+1|0]<<8)<<16>>16;m=a;break}}}while(0);if(!(l<<16>>16==42)){i=-1094995529;return i|0}l=(g-m|0)<4;do{if(b){if(l){n=0;break}c[f>>2]=m+4;g=m;n=je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0}else{if(l){n=0;break}c[f>>2]=m+4;g=m;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0}}while(0);c[e>>2]=n;i=0;return i|0}function C3a(a,b,f,g,h,i){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=(b|0)==0;b=a|0;k=c[b>>2]|0;l=c[a+4>>2]|0;m=(l-k|0)<2;do{if(j){if(m){n=0;o=k}else{p=k+2|0;c[b>>2]=p;q=k;n=(he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;o=p}c[f>>2]=n;if((l-o|0)<2){r=0;s=o}else{p=o+2|0;c[b>>2]=p;q=o;r=(he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535;s=p}c[g>>2]=r;if((l-s|0)<4){t=0;u=s;break}p=s+4|0;c[b>>2]=p;q=s;t=je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0;u=p}else{if(m){v=0;w=k}else{p=k+2|0;c[b>>2]=p;q=k;v=(d[q]|d[q+1|0]<<8)<<16>>16&65535;w=p}c[f>>2]=v;if((l-w|0)<2){x=0;y=w}else{p=w+2|0;c[b>>2]=p;q=w;x=(d[q]|d[q+1|0]<<8)<<16>>16&65535;y=p}c[g>>2]=x;if((l-y|0)<4){t=0;u=y;break}p=y+4|0;c[b>>2]=p;q=y;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;u=p}}while(0);c[h>>2]=t;t=c[f>>2]|0;f=0;while(1){if(!(f>>>0<3>>>0)){z=0;break}y=f+1|0;if((e[1076392+(f<<1)>>1]|0|0)==(t|0)){z=y;break}else{f=y}}f=c[g>>2]|0;t=c[a+8>>2]|0;a=u;y=t;c[i>>2]=a+4-y;if(!(f>>>0<14>>>0&(f|0)!=0)){A=-1094995529;return A|0}do{if((z|0)==0){f=c[h>>2]|0;if(f>>>0>4>>>0){break}i=c[g>>2]|0;if((ca(d[301480+i|0]|0,f)|0)>>>0<5>>>0|(i|0)==2){A=0}else{break}return A|0}}while(0);g=(l-a|0)<4;do{if(j){if(g){B=26;break}c[b>>2]=u+4;a=u;C=je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0;B=27}else{if(g){B=26;break}c[b>>2]=u+4;a=u;C=d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0;B=27}}while(0);if((B|0)==26){D=0;B=28}else if((B|0)==27){if((C|0)<0){E=0}else{D=C;B=28}}if((B|0)==28){B=l-y|0;E=(B|0)<(D|0)?B:D}c[b>>2]=t+E;A=0;return A|0}function D3a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=UHb()|0;c[a+804>>2]=d;if((d|0)==0){e=-12;return e|0}c[d+88>>2]=1;c[d+84>>2]=1;c[b+4>>2]=a;e=0;return e|0}function E3a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;k=i;i=i+1704|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+40|0;r=k+48|0;s=k+56|0;t=k+64|0;u=k+72|0;v=k+80|0;w=k+88|0;x=k+96|0;z=k+104|0;A=k+112|0;B=k+120|0;C=k+1656|0;D=f+140|0;E=qKb(c[D>>2]|0)|0;F=c[f+60>>2]|0;H=F;c[w>>2]=c[F+472>>2];c[w+4>>2]=1;I=f+120|0;J=F+8|0;c[J>>2]=c[I>>2];K=f+124|0;L=F+12|0;c[L>>2]=c[K>>2];M=F+464|0;N=M;b[N>>1]=1;O=F+466|0;b[O>>1]=1;P=oKb(E)|0;Q=F+16|0;c[Q>>2]=P;R=f+792|0;c[R>>2]=P;P=F+24|0;c[P>>2]=d[E+4|0]|0;S=c[D>>2]|0;switch(S|0){case 32:case 10:{T=0;U=6;break};case 9:{c[F+28>>2]=0;V=0;W=0;break};case 0:case 4:case 33:case 5:case 6:case 7:{tKb(S,z,A)|0;c[F+28>>2]=6;b[N>>1]=1<<c[z>>2];b[O>>1]=1<<c[A>>2];V=0;W=1;break};case 66:{U=5;break};case 292:case 28:{X=1;U=3;break};case 11:{c[F+28>>2]=3;V=0;W=0;break};case 42:case 2:{X=0;U=3;break};case 8:{c[R>>2]=40;U=5;break};default:{KIb(c[F+4>>2]|0,16,2445440,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;Z=-1;i=k;return Z|0}}if((U|0)==3){c[F+28>>2]=2;V=X;W=0}else if((U|0)==5){T=(S|0)==66|0;U=6}if((U|0)==6){c[F+28>>2]=1;V=T;W=0}T=c[P>>2]|0;if((T|0)>0){S=0;do{b[x+(S<<1)>>1]=((e[E+8+(S<<1)>>1]|0)>>>11&15)+1;S=S+1|0;}while((S|0)<(T|0))}T=F+20|0;S=c[T>>2]|0;if((S|0)==32946|(S|0)==8|(S|0)==5){S=c[L>>2]|0;c[F+60>>2]=S;_=S;$=S;aa=c[Q>>2]|0}else{S=c[Q>>2]|0;E=8192/((((ca(S,c[J>>2]|0)|0)>>>3)+1|0)>>>0)|0;X=E>>>0>1>>>0?E:1;c[F+60>>2]=X;_=X;$=c[L>>2]|0;aa=S}S=F+60|0;X=e[O>>1]|0;E=ca(((_-1|0)/(X|0)|0)+1|0,X)|0;c[S>>2]=E;X=(($-1|0)/(E|0)|0)+1|0;E=d5a(f,g,(ca((ca(c[I>>2]<<1,aa)|0)+4|0,c[K>>2]|0)|0)+16384|0,0)|0;if((E|0)<0){Z=E;i=k;return Z|0}K=g+24|0;aa=c[K>>2]|0;c[v>>2]=aa;I=F+456|0;c[I>>2]=aa;$=F+452|0;c[$>>2]=v;_=g+28|0;R=c[_>>2]|0;A=F+460|0;c[A>>2]=R;z=(R|0)<0|0?-1:0;ba=c[v>>2]|0;da=ba-aa|0;ea=wrc(da,(da|0)<0|0?-1:0,8,0)|0;da=G;a:do{if(z>>>0<da>>>0|z>>>0==da>>>0&R>>>0<ea>>>0){c[v>>2]=aa+(R+1);KIb(c[F+4>>2]|0,16,2637048,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=E}else{ga=ba;y=18761;a[ga]=y;y=y>>8;a[ga+1|0]=y;ga=(c[v>>2]|0)+2|0;c[v>>2]=ga;ha=ga;y=42;a[ha]=y;y=y>>8;a[ha+1|0]=y;ha=(c[v>>2]|0)+2|0;c[v>>2]=ha;ga=ha;y=0;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;ha=F+36|0;ia=ha;ja=X<<2;B4a(ha,F+40|0,ja);ha=F+44|0;ka=ha;B4a(ha,F+48|0,ja);if((c[ia>>2]|0)==0){fa=-12;break}if((c[ka>>2]|0)==0){fa=-12;break}ja=e[N>>1]|0;ha=((ca(ca(ca(c[Q>>2]|0,ja)|0,(((c[J>>2]|0)-1|0)/(ja|0)|0)+1|0)|0,e[O>>1]|0)|0)+7|0)>>>3;ja=(W|0)!=0;do{if(ja){la=F+52|0;A4a(la,F+56|0,ha);if((c[la>>2]|0)!=0){break}KIb(c[F+4>>2]|0,16,2356200,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=-12;break a}}while(0);la=c[T>>2]|0;do{if((la|0)==32946|(la|0)==8){ma=hJb(ca(c[S>>2]|0,ha)|0)|0;if((ma|0)==0){fa=-12;break a}na=c[v>>2]|0;c[c[ka>>2]>>2]=na-(c[K>>2]|0);b:do{if((c[S>>2]|0)>0){oa=F+52|0;pa=h|0;qa=h+32|0;if(ja){ra=0;sa=0}else{ta=0;ua=0;while(1){va=ma+(ca(ua,ha)|0)|0;nrc(va|0,(c[pa>>2]|0)+(ca(c[qa>>2]|0,ua)|0)|0,ha)|0;va=ta+ha|0;wa=ua+1|0;if((wa|0)<(c[S>>2]|0)){ta=va;ua=wa}else{xa=va;ya=na;break b}}}do{G3a(H,h,c[oa>>2]|0,sa);nrc(ma+ra|0,c[oa>>2]|0,ha)|0;ra=ra+ha|0;sa=sa+(e[O>>1]|0)|0;}while((sa|0)<(c[S>>2]|0));xa=ra;ya=c[v>>2]|0}else{xa=0;ya=na}}while(0);na=H3a(H,ma,ya,xa,c[T>>2]|0)|0;kJb(ma);if((na|0)<0){KIb(c[F+4>>2]|0,16,2293480,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=na;break a}else{oa=(c[v>>2]|0)+na|0;c[v>>2]=oa;c[c[ia>>2]>>2]=oa-(c[K>>2]|0)-(c[c[ka>>2]>>2]|0);za=na;break}}else if((la|0)==5){na=hJb(c[339864]|0)|0;c[F+468>>2]=na;if((na|0)==0){fa=-12;break a}else{U=35}}else{U=35}}while(0);do{if((U|0)==35){c:do{if((c[L>>2]|0)>0){la=F+468|0;na=F+52|0;oa=h|0;ua=h+32|0;d:do{if(ja){ta=0;while(1){qa=c[S>>2]|0;if((c[(c[ia>>2]|0)+(((ta|0)/(qa|0)|0)<<2)>>2]|0)==0){if((c[T>>2]|0)==5){JPa(c[la>>2]|0,c[v>>2]|0,(c[A>>2]|0)-(c[c[$>>2]>>2]|0)+(c[I>>2]|0)|0,12,1,602);Aa=c[S>>2]|0}else{Aa=qa}c[(c[ka>>2]|0)+(((ta|0)/(Aa|0)|0)<<2)>>2]=(c[v>>2]|0)-(c[K>>2]|0)}G3a(H,h,c[na>>2]|0,ta);qa=H3a(H,c[na>>2]|0,c[v>>2]|0,ha,c[T>>2]|0)|0;pa=e[O>>1]|0;va=ta-1+pa|0;if((qa|0)<0){Ba=qa;break d}wa=(c[ia>>2]|0)+(((va|0)/(c[S>>2]|0)|0)<<2)|0;c[wa>>2]=(c[wa>>2]|0)+qa;c[v>>2]=(c[v>>2]|0)+qa;do{if((c[T>>2]|0)==5){if((va|0)!=((c[L>>2]|0)-1|0)){wa=c[S>>2]|0;if(((va|0)%(wa|0)|0|0)!=(wa-1|0)){Ca=qa;break}}wa=LPa(c[la>>2]|0,346)|0;Da=(c[ia>>2]|0)+(((va|0)/(c[S>>2]|0)|0)<<2)|0;c[Da>>2]=(c[Da>>2]|0)+wa;c[v>>2]=(c[v>>2]|0)+wa;Ca=wa}else{Ca=qa}}while(0);qa=ta+pa|0;if((qa|0)<(c[L>>2]|0)){ta=qa}else{Ea=Ca;break c}}}else{ta=0;while(1){qa=c[S>>2]|0;if((c[(c[ia>>2]|0)+(((ta|0)/(qa|0)|0)<<2)>>2]|0)==0){if((c[T>>2]|0)==5){JPa(c[la>>2]|0,c[v>>2]|0,(c[A>>2]|0)-(c[c[$>>2]>>2]|0)+(c[I>>2]|0)|0,12,1,602);Fa=c[S>>2]|0}else{Fa=qa}c[(c[ka>>2]|0)+(((ta|0)/(Fa|0)|0)<<2)>>2]=(c[v>>2]|0)-(c[K>>2]|0)}qa=(c[oa>>2]|0)+(ca(c[ua>>2]|0,ta)|0)|0;va=H3a(H,qa,c[v>>2]|0,ha,c[T>>2]|0)|0;if((va|0)<0){Ba=va;break d}qa=(c[ia>>2]|0)+(((ta|0)/(c[S>>2]|0)|0)<<2)|0;c[qa>>2]=(c[qa>>2]|0)+va;c[v>>2]=(c[v>>2]|0)+va;do{if((c[T>>2]|0)==5){if((ta|0)!=((c[L>>2]|0)-1|0)){qa=c[S>>2]|0;if(((ta|0)%(qa|0)|0|0)!=(qa-1|0)){Ga=va;break}}qa=LPa(c[la>>2]|0,346)|0;wa=(c[ia>>2]|0)+(((ta|0)/(c[S>>2]|0)|0)<<2)|0;c[wa>>2]=(c[wa>>2]|0)+qa;c[v>>2]=(c[v>>2]|0)+qa;Ga=qa}else{Ga=va}}while(0);va=ta+1|0;if((va|0)<(c[L>>2]|0)){ta=va}else{Ea=Ga;break c}}}}while(0);KIb(c[F+4>>2]|0,16,2293480,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=Ba;break a}else{Ea=E}}while(0);if((c[T>>2]|0)!=5){za=Ea;break}kJb(c[F+468>>2]|0);za=Ea}}while(0);ha=F+448|0;c[ha>>2]=0;c[t>>2]=0;K3a(H,254,4,1,t);c[s>>2]=c[J>>2];K3a(H,256,4,1,s);c[r>>2]=c[L>>2];K3a(H,257,4,1,r);ma=c[P>>2]|0;if((ma|0)!=0){K3a(H,258,3,ma,x)}b[q>>1]=c[T>>2];K3a(H,259,3,1,q);b[p>>1]=c[F+28>>2];K3a(H,262,3,1,p);K3a(H,273,4,X,c[ka>>2]|0);ma=c[P>>2]|0;if((ma|0)!=0){b[o>>1]=ma;K3a(H,277,3,1,o)}c[n>>2]=c[S>>2];K3a(H,278,4,1,n);K3a(H,279,4,X,c[ia>>2]|0);ma=w;K3a(H,282,5,1,ma);K3a(H,283,5,1,ma);b[m>>1]=2;K3a(H,296,3,1,m);if((c[f+88>>2]&8388608|0)==0){K3a(H,305,2,14,2242416)}if((c[D>>2]|0)==11){ma=c[h+4>>2]|0;la=0;do{ua=c[ma+(la<<2)>>2]|0;b[B+(la<<1)>>1]=(ua>>>16&255)*257|0;b[B+(la+256<<1)>>1]=(ua>>>8&255)*257|0;b[B+(la+512<<1)>>1]=(ua&255)*257|0;la=la+1|0;}while((la|0)<256);K3a(H,320,3,768,B)}if((V|0)!=0){b[l>>1]=2;K3a(H,338,3,1,l)}if(ja){la=C;nrc(la|0,1512696,48)|0;K3a(H,530,3,2,M);if((c[f+400>>2]|0)==3){b[u>>1]=2;K3a(H,531,3,1,u)}K3a(H,532,5,6,la)}y=(c[v>>2]|0)-(c[K>>2]|0)|0;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;la=c[ha>>2]|0;ma=(la*12|0)+6|0;ia=c[A>>2]|0;ka=(ia|0)<0|0?-1:0;ua=c[$>>2]|0;oa=c[I>>2]|0;na=(c[ua>>2]|0)-oa|0;ta=wrc(na,(na|0)<0|0?-1:0,ma,(ma|0)<0|0?-1:0)|0;ma=G;if(ka>>>0<ma>>>0|ka>>>0==ma>>>0&ia>>>0<ta>>>0){c[ua>>2]=oa+(ia+1);KIb(c[F+4>>2]|0,16,2637048,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;fa=-22;break}else{ia=c[v>>2]|0;y=la&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=(c[v>>2]|0)+2|0;c[v>>2]=ia;la=(c[ha>>2]|0)*12|0;nrc(ia|0,F+64|0,la)|0;ia=(c[v>>2]|0)+la|0;c[v>>2]=ia;la=ia;y=0;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;la=(c[v>>2]|0)+4|0;c[v>>2]=la;c[_>>2]=la-(c[K>>2]|0);la=g+36|0;c[la>>2]=c[la>>2]|1;c[j>>2]=1;fa=za;break}}}while(0);Z=(fa|0)<0?fa:0;i=k;return Z|0}function F3a(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(a+804|0);mJb(b+36|0);mJb(b+44|0);mJb(b+52|0);return 0}function G3a(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=d+8|0;j=c[i>>2]|0;k=d+464|0;l=e[k>>1]|0;m=((j-1|0)/(l|0)|0)+1|0;n=d+466|0;o=b[n>>1]|0;p=o&65535;q=(h|0)/(p|0)|0;r=f+32|0;s=ca(c[f+36>>2]|0,q)|0;t=(c[f+4>>2]|0)+s|0;s=ca(c[f+40>>2]|0,q)|0;q=(c[f+8>>2]|0)+s|0;do{if(((j|0)%(l|0)|0|0)==0){if(((c[d+12>>2]|0)%(p|0)|0|0)!=0){break}if((m|0)<=0){return}s=r|0;u=f|0;v=0;w=g;x=t;y=q;z=o;while(1){if(z<<16>>16==0){A=w}else{B=0;C=w;D=b[k>>1]|0;E=z;while(1){if(D<<16>>16==0){F=C;G=0;H=E}else{I=B+h|0;J=0;K=C;L=D&65535;while(1){M=(ca(L,v)|0)+J+(ca(c[s>>2]|0,I)|0)|0;N=K+1|0;a[K]=a[(c[u>>2]|0)+M|0]|0;M=J+1|0;O=b[k>>1]|0;P=O&65535;if((M|0)<(P|0)){J=M;K=N;L=P}else{break}}F=N;G=O;H=b[n>>1]|0}L=B+1|0;if((L|0)<(H&65535|0)){B=L;C=F;D=G;E=H}else{A=F;break}}}a[A]=a[x]|0;a[A+1|0]=a[y]|0;E=v+1|0;if((E|0)>=(m|0)){break}v=E;w=A+2|0;x=x+1|0;y=y+1|0;z=b[n>>1]|0}return}}while(0);if((m|0)<=0){return}A=d+12|0;d=r|0;r=f|0;f=0;F=g;g=t;t=q;q=o;while(1){if(q<<16>>16==0){Q=F}else{o=0;H=F;G=b[k>>1]|0;O=q;while(1){if(G<<16>>16==0){R=H;S=0;T=O}else{N=o+h|0;p=0;l=H;j=G&65535;while(1){z=(c[A>>2]|0)-1|0;y=ca((N|0)>(z|0)?z:N,c[d>>2]|0)|0;z=(ca(j,f)|0)+p|0;x=(c[i>>2]|0)-1|0;U=l+1|0;a[l]=a[(c[r>>2]|0)+(((z|0)>(x|0)?x:z)+y)|0]|0;y=p+1|0;V=b[k>>1]|0;z=V&65535;if((y|0)<(z|0)){p=y;l=U;j=z}else{break}}R=U;S=V;T=b[n>>1]|0}j=o+1|0;if((j|0)<(T&65535|0)){o=j;H=R;G=S;O=T}else{Q=R;break}}}a[Q]=a[g]|0;a[Q+1|0]=a[t]|0;O=f+1|0;if((O|0)>=(m|0)){break}f=O;F=Q+2|0;g=g+1|0;t=t+1|0;q=b[n>>1]|0}return}function H3a(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+8|0;h=g|0;if((f|0)==32773){j=$rb(d,(c[a+460>>2]|0)-(c[c[a+452>>2]>>2]|0)+(c[a+456>>2]|0)|0,b,1,e,2,255,-1,0)|0;i=g;return j|0}else if((f|0)==5){j=KPa(c[a+468>>2]|0,b,e)|0;i=g;return j|0}else if((f|0)==1){k=c[a+460>>2]|0;l=(k|0)<0|0?-1:0;m=c[a+452>>2]|0;n=c[a+456>>2]|0;o=(c[m>>2]|0)-n|0;p=wrc(o,(o|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;o=G;if(l>>>0<o>>>0|l>>>0==o>>>0&k>>>0<p>>>0){c[m>>2]=n+(k+1);KIb(c[a+4>>2]|0,16,2637048,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-1;i=g;return j|0}else{nrc(d|0,b|0,e)|0;j=e;i=g;return j|0}}else if((f|0)==32946|(f|0)==8){c[h>>2]=(c[a+460>>2]|0)-(c[c[a+452>>2]>>2]|0)+(c[a+456>>2]|0);if((Cpc(d,h,b,e)|0)==0){j=c[h>>2]|0;i=g;return j|0}else{KIb(c[a+4>>2]|0,16,2118904,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-1;i=g;return j|0}}else{j=-1;i=g;return j|0}return 0}function I3a(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b|0;g=c[f>>2]|0;h=b+4|0;i=c[h>>2]|0;if((i|0)>(d|0)){j=i-d|0;k=g<<d|e;c[f>>2]=k;c[h>>2]=j;return}else{l=je(e>>>((d-i|0)>>>0)|g<<i|0)|0;g=b+12|0;b=c[g>>2]|0;y=l;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;j=32-d+i|0;k=e;c[f>>2]=k;c[h>>2]=j;return}}function J3a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=b+4|0;e=c[d>>2]|0;f=b|0;if((e|0)>=32){g=f;c[d>>2]=32;c[g>>2]=0;return}h=c[f>>2]<<e;c[f>>2]=h;f=b|0;e=b+12|0;b=h>>>24&255;while(1){h=c[e>>2]|0;c[e>>2]=h+1;a[h]=b;h=c[f>>2]|0;c[f>>2]=h<<8;i=(c[d>>2]|0)+8|0;c[d>>2]=i;if((i|0)<32){b=h>>>16&255}else{g=f;break}}c[d>>2]=32;c[g>>2]=0;return}function K3a(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;k=b+448|0;l=c[k>>2]|0;m=l*12|0;if((l|0)>=32){KIb(0,0,2201144,(n=i,i=i+24|0,c[n>>2]=2169384,c[n+8>>2]=2142440,c[n+16>>2]=131,n)|0);i=n;Hd()}l=b+64+m|0;y=e&65535;a[l]=y;y=y>>8;a[l+1|0]=y;l=m|2;m=b+64+l|0;y=f&65535;a[m]=y;y=y>>8;a[m+1|0]=y;m=l+2+(b+64)|0;y=g;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=l+6+(b+64)|0;l=g;e=(g|0)<0|0?-1:0;o=Erc(d[301448+f|0]|0,0,l,e)|0;p=G;q=0;if((p|0)<(q|0)|(p|0)==(q|0)&o>>>0<5>>>0){o=ca(d[301464+f|0]|0,g)|0;if((o|0)>0){r=0;s=m}else{t=c[k>>2]|0;u=t+1|0;c[k>>2]=u;i=j;return}while(1){a[s]=a[h+r|0]|0;q=r+1|0;if((q|0)<(o|0)){r=q;s=s+1|0}else{break}}t=c[k>>2]|0;u=t+1|0;c[k>>2]=u;i=j;return}s=b+452|0;r=b+456|0;o=m;y=(c[c[s>>2]>>2]|0)-(c[r>>2]|0)|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=a[301464+f|0]|0;f=Erc(o&255,0,l,e)|0;e=c[b+460>>2]|0;l=(e|0)<0|0?-1:0;m=c[s>>2]|0;q=c[r>>2]|0;r=(c[m>>2]|0)-q|0;p=wrc(r,(r|0)<0|0?-1:0,f,G)|0;f=G;if(l>>>0<f>>>0|l>>>0==f>>>0&e>>>0<p>>>0){c[m>>2]=q+(e+1);KIb(c[b+4>>2]|0,16,2637048,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;v=c[s>>2]|0}else{v=m}m=ca(o&255,g)|0;if((m|0)>0){w=0}else{t=c[k>>2]|0;u=t+1|0;c[k>>2]=u;i=j;return}do{g=a[h+w|0]|0;o=c[v>>2]|0;c[v>>2]=o+1;a[o]=g;w=w+1|0;}while((w|0)<(m|0));t=c[k>>2]|0;u=t+1|0;c[k>>2]=u;i=j;return}function L3a(a){a=a|0;c[a+140>>2]=11;return 0}function M3a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=c[f+24>>2]|0;j=c[a+120>>2]>>3;k=c[a+124>>2]>>3;l=M4a(a,b,0)|0;if((l|0)<0){m=l;i=g;return m|0}l=f+28|0;if((c[l>>2]|0)>>>0<(ca(j<<1,k)|0)>>>0){KIb(a,16,2445376,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;c[e>>2]=0;m=-1094995529;i=g;return m|0}c[b+88>>2]=1;c[b+84>>2]=1;a=c[b>>2]|0;c[b+304>>2]=1;f=b+4|0;nrc(c[f>>2]|0,1412488,64)|0;mrc((c[f>>2]|0)+64|0,0,960)|0;do{if((k|0)!=0){f=b+32|0;if((j|0)==0){break}n=j<<1;o=0;p=a;q=h;while(1){r=0;s=q;while(1){t=d[s+1|0]|0;T3(p+(r<<3)|0,c[f>>2]|0,1965880,8,d[s]|0,t&15,t>>>4);t=r+1|0;if(!(t>>>0<j>>>0)){break}r=t;s=s+2|0}s=o+1|0;if(s>>>0<k>>>0){o=s;p=p+(c[f>>2]<<3)|0;q=q+n|0}else{break}}}}while(0);c[e>>2]=1;m=c[l>>2]|0;i=g;return m|0}function N3a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=b;c[d>>2]=a;a=UHb()|0;c[b+4>>2]=a;if((a|0)==0){e=-12;return e|0}a=b+16524|0;xJb(a,b+16528|0,c[(c[d>>2]|0)+120>>2]<<2);e=(c[a>>2]|0)==0?-12:0;return e|0}function O3a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0;k=i;i=i+128|0;l=k|0;m=c[j+24>>2]|0;n=c[j+28>>2]|0;j=c[f+60>>2]|0;o=j;p=j+8|0;c[p>>2]=m;q=j+12|0;c[q>>2]=n;r=l|0;mrc(r|0,0,128)|0;s=a[m]|0;if((s&255)>>>0<16>>>0){KIb(c[j>>2]|0,16,2293440,(t=i,i=i+8|0,c[t>>2]=s&255,t)|0);i=t;u=-1094995529;i=k;return u|0}v=s<<3&120|(s&255)>>>5;s=v&255;if((s+1|0)>(n|0)){KIb(c[j>>2]|0,16,2242384,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=k;return u|0}do{if((v&255)>>>0>1>>>0){w=1;x=a[m+1|0]|0;while(1){y=w+1|0;z=a[m+y|0]|0;a[l+(w-1)|0]=z^x;if((y|0)<(s|0)){w=y;x=z}else{break}}x=a[r]|0;w=a[l+1|0]|0;z=a[l+2|0]|0;y=l+3|0;A=(d[y]|d[y+1|0]<<8)<<16>>16;y=l+5|0;B=a[l+10|0]|0;C=(d[y]|d[y+1|0]<<8)<<16>>16&65535;y=d[l+11|0]|0;if(!((d[l+9|0]|0)>>>0>1>>>0)){D=B;E=C;F=A;G=z;H=w;I=x;J=14;break}if((B&255)>>>0>3>>>0){KIb(c[j>>2]|0,16,2201112,(t=i,i=i+8|0,c[t>>2]=B&255,t)|0);i=t;u=-1094995529;i=k;return u|0}K=j+32|0;if(!((B-2&255)>>>0<2>>>0)){c[K>>2]=16;L=x;M=w;N=z;O=A;P=C;Q=B;R=16;break}S=(y&8|0)==0?y|16:y;c[K>>2]=S;if((S&32|0)==0){L=x;M=w;N=z;O=A;P=C;Q=B;R=S;break}QIb(c[j>>2]|0,2169360,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1163346256;i=k;return u|0}else{D=0;E=0;F=0;G=0;H=0;I=0;J=14}}while(0);if((J|0)==14){c[j+32>>2]=16;L=I;M=H;N=G;O=F;P=E;Q=D;R=16}D=j+32|0;E=j+44|0;c[E>>2]=P;F=j+48|0;c[F>>2]=O&65535;do{if((Q&255)>>>0<2>>>0){if(!(P>>>0<213>>>0&(O&65535)>>>0>175>>>0)){break}c[D>>2]=R|4;QIb(c[j>>2]|0,2142416,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}}while(0);R=L&255;if((L&255)>>>0>16>>>0){KIb(c[j>>2]|0,16,2118872,(t=i,i=i+8|0,c[t>>2]=R,t)|0);i=t;u=-1094995529;i=k;return u|0}L=M&255;O=j+16516|0;P=c[O>>2]|0;if((L|0)==(P|0)){if(!((N&255|0)==(c[j+16520>>2]|0)|(M&255)>>>0>3>>>0)){J=24}}else{if(!((M&255)>>>0>3>>>0)){J=24}}if((J|0)==24){M=j+16452|0;nrc(M|0,c[1232+(L<<2)>>2]|0,16)|0;nrc(j+16468|0,c[1720880+(L<<2)>>2]|0,16)|0;nrc(j+16484|0,c[1480984+(L<<2)>>2]|0,16)|0;nrc(j+16500|0,c[1481040+(L<<2)>>2]|0,16)|0;G=M;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16454|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16456|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16458|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16460|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16462|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16464|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0;G=j+16466|0;b[G>>1]=((b[G>>1]&-2)<<16>>16|0)/2|0}do{if((R&1|0)==0|Q<<24>>24==0){G=N&255;if(N<<24>>24!=0&(N&255)>>>0<4>>>0){T=c[316896+(G-1<<2)>>2]|0;break}KIb(c[j>>2]|0,16,2637016,(t=i,i=i+8|0,c[t>>2]=G,t)|0);i=t;u=-1094995529;i=k;return u|0}else{T=734136}}while(0);Q=87040>>>(R>>>0)&1;G=(Q|0)==0;M=(Q<<4^16)+30|0;H=c[E>>2]>>Q;c[E>>2]=H;I=j;l=c[I>>2]|0;do{if((H|0)==(c[l+120>>2]|0)){if((c[F>>2]|0)!=(c[l+124>>2]|0)){J=32;break}if((M|0)==(c[l+140>>2]|0)){U=l;V=H;W=P}else{J=32}}else{J=32}}while(0);do{if((J|0)==32){WHb(c[j+4>>2]|0);P=c[I>>2]|0;c[P+224>>2]=1<<Q;c[P+228>>2]=1;P=c[I>>2]|0;c[P+140>>2]=M;H=H4a(P,c[E>>2]|0,c[F>>2]|0)|0;if((H|0)<0){u=H;i=k;return u|0}H=j+16524|0;xJb(H,j+16528|0,c[(c[I>>2]|0)+120>>2]<<2);if((c[H>>2]|0)==0){u=-12;i=k;return u|0}else{H=c[I>>2]|0;U=H;V=c[H+120>>2]|0;W=c[O>>2]|0;break}}}while(0);F=j+20|0;c[F>>2]=(V>>2-Q)+7>>3;if((L|0)==(W|0)){if((N&255|0)!=(c[j+16520>>2]|0)){J=37}}else{J=37}a:do{if((J|0)==37){if(!G){W=0;Q=T;while(1){V=(d[Q]|0)>>>1;E=Q+1|0;if((V|0)==0){X=0;Y=E}else{M=0;H=E;while(1){E=d[H]|0;P=E>>>4;l=E&15;E=M+W|0;c[o+52+(E<<2)>>2]=((b[o+16452+(l<<1)>>1]|0)*65792|0)+(b[o+16452+(P<<1)>>1]|0)<<1;c[o+4148+(E<<2)>>2]=(e[o+16468+(P<<1)>>1]<<16)+(b[o+16468+(l<<1)>>1]|0)<<1;c[o+8244+(E<<2)>>2]=((b[o+16484+(l<<1)>>1]|0)*65792|0)+(b[o+16484+(P<<1)>>1]|0)<<1;c[o+12340+(E<<2)>>2]=(e[o+16500+(P<<1)>>1]<<16)+(b[o+16500+(l<<1)>>1]|0)<<1;l=M+1|0;if((l|0)<(V|0)){M=l;H=H+1|0}else{break}}H=V>>>0>1>>>0?V:1;X=H;Y=Q+(H+1)|0}H=W-1+X|0;M=o+52+(H<<2)|0;c[M>>2]=c[M>>2]|1;M=o+4148+(H<<2)|0;c[M>>2]=c[M>>2]|1;M=o+8244+(H<<2)|0;c[M>>2]=c[M>>2]|1;M=o+12340+(H<<2)|0;c[M>>2]=c[M>>2]|1;M=W+4|0;if((M|0)<1024){W=M;Q=Y}else{break a}}}if((c[U+140>>2]|0)==46){Q=0;W=T;while(1){M=(d[W]|0)>>>1;H=W+1|0;if((M|0)==0){Z=0;_=H}else{l=0;P=H;while(1){H=d[P]|0;E=H>>>4;r=H&15;H=l+Q|0;c[o+52+(H<<2)>>2]=(ca(b[o+16452+(r<<1)>>1]|0,69271552)|0)+((b[o+16452+(E<<1)>>1]|0)*1057|0)<<1;c[o+4148+(H<<2)>>2]=((b[o+16468+(E<<1)>>1]<<10)+(b[o+16468+(r<<1)>>1]|0)|0)*131074|0;r=l+1|0;if((r|0)<(M|0)){l=r;P=P+1|0}else{break}}P=M>>>0>1>>>0?M:1;Z=P;_=W+(P+1)|0}P=Q-1+Z|0;l=o+52+(P<<2)|0;c[l>>2]=c[l>>2]|1;l=o+4148+(P<<2)|0;c[l>>2]=c[l>>2]|1;l=Q+4|0;if((l|0)<1024){Q=l;W=_}else{break}}}else{W=0;Q=T;while(1){l=(d[Q]|0)>>>1;P=Q+1|0;if((l|0)==0){$=0;aa=P}else{V=0;r=P;while(1){P=d[r]|0;E=P>>>4;H=P&15;P=V+W|0;c[o+52+(P<<2)>>2]=(ca(b[o+16452+(H<<1)>>1]|0,138477568)|0)+((b[o+16452+(E<<1)>>1]|0)*2113|0)<<1;c[o+4148+(P<<2)>>2]=((b[o+16468+(E<<1)>>1]<<11)+(b[o+16468+(H<<1)>>1]|0)|0)*131074|0;H=V+1|0;if((H|0)<(l|0)){V=H;r=r+1|0}else{break}}r=l>>>0>1>>>0?l:1;$=r;aa=Q+(r+1)|0}r=W-1+$|0;V=o+52+(r<<2)|0;c[V>>2]=c[V>>2]|1;V=o+4148+(r<<2)|0;c[V>>2]=c[V>>2]|1;V=W+4|0;if((V|0)<1024){W=V;Q=aa}else{break}}}}}while(0);aa=c[p>>2]|0;p=aa+s|0;$=j+16|0;c[$>>2]=p;T=c[D>>2]|0;_=T&16;if((_|0)==0){Z=c[I>>2]|0;U=aa+((ca(c[Z+124>>2]>>2,c[F>>2]|0)|0)+s)|0;c[j+24>>2]=U;ba=U;da=Z}else{c[j+24>>2]=p;ba=p;da=c[I>>2]|0}p=j+28|0;c[p>>2]=aa-ba+(c[q>>2]|0);c[O>>2]=L;O=N&255;c[j+16520>>2]=O;N=j+16436|0;c[N>>2]=R;q=c[1638412+(R<<4)>>2]|0;ba=j+16444|0;c[ba>>2]=q;aa=c[1638416+(R<<4)>>2]|0;c[j+16448>>2]=aa;Z=c[1638420+(R<<4)>>2]|0;U=j+16440|0;c[U>>2]=Z;if((c[da+688>>2]&1|0)!=0){KIb(da,32,2613712,(t=i,i=i+80|0,c[t>>2]=L,c[t+8>>2]=O,c[t+16>>2]=R,c[t+24>>2]=q,c[t+32>>2]=aa,c[t+40>>2]=Z,c[t+48>>2]=(_|0)!=0?2586848:10230656,c[t+56>>2]=(T&8|0)!=0?2547832:10230656,c[t+64>>2]=(T&32|0)!=0?2529952:10230656,c[t+72>>2]=(T&4|0)!=0?2514712:10230656,t)|0);i=t}T=j+4|0;_=N4a(f,c[T>>2]|0)|0;if((_|0)<0){u=_;i=k;return u|0}_=c[N>>2]|0;b:do{if((87040>>>(_>>>0)&1|0)==0){if((87550>>>(_>>>0)&1|0)==0){break}N=c[c[T>>2]>>2]|0;f=c[D>>2]&16;Z=c[$>>2]|0;aa=j+16524|0;mrc(c[aa>>2]|0,0,c[(c[I>>2]|0)+120>>2]<<2|0)|0;q=c[I>>2]|0;if((c[p>>2]|0)<1){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}R=q+124|0;if((c[R>>2]|0)<=0){break}O=c[j+24>>2]|0;L=(f|0)!=0;f=q+120|0;da=N;N=0;s=Z;Z=1;Y=d[O]<<2;X=O;G=O;Q=O;W=O;V=O;r=O;c:while(1){M=c[f>>2]|0;if((M|0)>0){H=N&3;E=M;M=0;P=c[aa>>2]|0;m=da;v=a[s]|0;S=1;B=1;C=Z;A=Y;z=X;w=G;x=Q;K=W;y=V;ea=r;while(1){do{if(L){J=345}else{if((v&S)<<24>>24==0){J=345;break}fa=P+4|0;c[P>>2]=c[m>>2];ga=c[m+4>>2]|0;ha=ga-(c[fa>>2]|0)|0;c[fa>>2]=ga;ia=ha;ja=P+8|0;ka=m+8|0;la=C;ma=A;na=z;oa=w;pa=x;qa=K;ra=y;sa=ea;J=608}}while(0);if((J|0)==345){J=0;do{if((H|0)==0){ha=c[o+4148+(A<<2)>>2]|0;ga=(ha>>>1)+M|0;fa=(ha&1|0)!=0;if((c[ba>>2]|0)!=2){do{if(fa){ha=c[p>>2]|0;if((C|0)>=(ha|0)){J=406;break c}ta=C+1|0;ua=a[K+C|0]|0;if(!(ua<<24>>24==0)){va=(ua&255)<<2;wa=ta;xa=ga;ya=K;za=K;Aa=K;break}if((ta|0)>=(ha|0)){J=409;break c}ua=C+2|0;Ba=d[K+ta|0]<<2;ta=c[o+4148+(Ba<<2)>>2]|0;Ca=((ta>>>1)*5|0)+ga|0;if((ta&1|0)==0){va=Ba|1;wa=ua;xa=Ca;ya=K;za=K;Aa=K;break}if((ua|0)>=(ha|0)){J=412;break c}va=d[K+ua|0]<<2;wa=C+3|0;xa=Ca;ya=K;za=K;Aa=K}else{if((A|0)>1022){J=416;break c}va=A+1|0;wa=C;xa=ga;ya=z;za=w;Aa=x}}while(0);Ca=c[o+52+(va<<2)>>2]|0;ua=(Ca>>>1)+xa|0;do{if((Ca&1|0)==0){if((va|0)>1022){J=430;break c}Da=va+1|0;Ea=wa;Fa=ua;Ga=ya;Ha=za;Ia=Aa;Ja=K}else{ha=c[p>>2]|0;if((wa|0)>=(ha|0)){J=420;break c}Ba=wa+1|0;ta=a[y+wa|0]|0;if(!(ta<<24>>24==0)){Da=(ta&255)<<2;Ea=Ba;Fa=ua;Ga=y;Ha=y;Ia=y;Ja=y;break}if((Ba|0)>=(ha|0)){J=423;break c}ta=wa+2|0;Ka=d[y+Ba|0]<<2;Ba=c[o+52+(Ka<<2)>>2]|0;La=((Ba>>>1)*5|0)+ua|0;if((Ba&1|0)==0){Da=Ka|1;Ea=ta;Fa=La;Ga=y;Ha=y;Ia=y;Ja=y;break}if((ta|0)>=(ha|0)){J=426;break c}Da=d[y+ta|0]<<2;Ea=wa+3|0;Fa=La;Ga=y;Ha=y;Ia=y;Ja=y}}while(0);ua=(c[P>>2]|0)+Fa|0;c[m>>2]=ua;Ca=m+4|0;La=P+4|0;c[P>>2]=ua;ua=c[o+52+(Da<<2)>>2]|0;ta=(ua>>>1)+Fa|0;do{if((ua&1|0)==0){if((Da|0)>1022){J=444;break c}Ma=Da+1|0;Na=Ea;Oa=ta;Pa=Ga;Qa=Ha;Ra=Ia}else{ha=c[p>>2]|0;if((Ea|0)>=(ha|0)){J=434;break c}Ka=Ea+1|0;Ba=a[Ja+Ea|0]|0;if(!(Ba<<24>>24==0)){Ma=(Ba&255)<<2;Na=Ka;Oa=ta;Pa=Ja;Qa=Ja;Ra=Ja;break}if((Ka|0)>=(ha|0)){J=437;break c}Ba=Ea+2|0;Sa=d[Ja+Ka|0]<<2;Ka=c[o+52+(Sa<<2)>>2]|0;Ta=((Ka>>>1)*5|0)+ta|0;if((Ka&1|0)==0){Ma=Sa|1;Na=Ba;Oa=Ta;Pa=Ja;Qa=Ja;Ra=Ja;break}if((Ba|0)>=(ha|0)){J=440;break c}Ma=d[Ja+Ba|0]<<2;Na=Ea+3|0;Oa=Ta;Pa=Ja;Qa=Ja;Ra=Ja}}while(0);ta=(c[La>>2]|0)+Oa|0;c[Ca>>2]=ta;c[La>>2]=ta;Ua=Ma;Va=Na;Wa=m+8|0;Xa=P+8|0;Ya=Oa;Za=Pa;_a=Qa;$a=Ra;ab=Ja;bb=y;cb=ea;break}do{if(fa){ta=c[p>>2]|0;if((C|0)>=(ta|0)){J=349;break c}ua=C+1|0;Ta=a[z+C|0]|0;if(!(Ta<<24>>24==0)){db=(Ta&255)<<2;eb=ua;fb=ga;break}if((ua|0)>=(ta|0)){J=352;break c}Ta=C+2|0;Ba=d[z+ua|0]<<2;ua=c[o+4148+(Ba<<2)>>2]|0;ha=((ua>>>1)*5|0)+ga|0;if((ua&1|0)==0){db=Ba|1;eb=Ta;fb=ha;break}if((Ta|0)>=(ta|0)){J=355;break c}db=d[z+Ta|0]<<2;eb=C+3|0;fb=ha}else{if((A|0)>1022){J=359;break c}db=A+1|0;eb=C;fb=ga}}while(0);ga=c[o+52+(db<<2)>>2]|0;fa=(ga>>>1)+fb|0;do{if((ga&1|0)==0){if((db|0)>1022){J=373;break c}gb=db+1|0;hb=eb;ib=fa;jb=z;kb=w}else{La=c[p>>2]|0;if((eb|0)>=(La|0)){J=363;break c}Ca=eb+1|0;ha=a[x+eb|0]|0;if(!(ha<<24>>24==0)){gb=(ha&255)<<2;hb=Ca;ib=fa;jb=x;kb=x;break}if((Ca|0)>=(La|0)){J=366;break c}ha=eb+2|0;Ta=d[x+Ca|0]<<2;Ca=c[o+52+(Ta<<2)>>2]|0;ta=((Ca>>>1)*5|0)+fa|0;if((Ca&1|0)==0){gb=Ta|1;hb=ha;ib=ta;jb=x;kb=x;break}if((ha|0)>=(La|0)){J=369;break c}gb=d[x+ha|0]<<2;hb=eb+3|0;ib=ta;jb=x;kb=x}}while(0);fa=(c[P>>2]|0)+ib|0;c[m>>2]=fa;ga=m+4|0;ta=P+4|0;c[P>>2]=fa;fa=c[o+4148+(gb<<2)>>2]|0;ha=(fa>>>1)+ib|0;do{if((fa&1|0)==0){if((gb|0)>1022){J=387;break c}lb=gb+1|0;mb=hb;nb=ha;ob=jb}else{La=c[p>>2]|0;if((hb|0)>=(La|0)){J=377;break c}Ta=hb+1|0;Ca=a[kb+hb|0]|0;if(!(Ca<<24>>24==0)){lb=(Ca&255)<<2;mb=Ta;nb=ha;ob=kb;break}if((Ta|0)>=(La|0)){J=380;break c}Ca=hb+2|0;Ba=d[kb+Ta|0]<<2;Ta=c[o+4148+(Ba<<2)>>2]|0;ua=((Ta>>>1)*5|0)+ha|0;if((Ta&1|0)==0){lb=Ba|1;mb=Ca;nb=ua;ob=kb;break}if((Ca|0)>=(La|0)){J=383;break c}lb=d[kb+Ca|0]<<2;mb=hb+3|0;nb=ua;ob=kb}}while(0);ha=c[o+52+(lb<<2)>>2]|0;fa=(ha>>>1)+nb|0;do{if((ha&1|0)==0){if((lb|0)>1022){J=401;break c}pb=lb+1|0;qb=mb;rb=fa}else{ua=c[p>>2]|0;if((mb|0)>=(ua|0)){J=391;break c}Ca=mb+1|0;La=a[ob+mb|0]|0;if(!(La<<24>>24==0)){pb=(La&255)<<2;qb=Ca;rb=fa;break}if((Ca|0)>=(ua|0)){J=394;break c}La=mb+2|0;Ba=d[ob+Ca|0]<<2;Ca=c[o+52+(Ba<<2)>>2]|0;Ta=((Ca>>>1)*5|0)+fa|0;if((Ca&1|0)==0){pb=Ba|1;qb=La;rb=Ta;break}if((La|0)>=(ua|0)){J=397;break c}pb=d[ob+La|0]<<2;qb=mb+3|0;rb=Ta}}while(0);fa=(c[ta>>2]|0)+rb|0;c[ga>>2]=fa;c[ta>>2]=fa;Ua=pb;Va=qb;Wa=m+8|0;Xa=P+8|0;Ya=rb;Za=ob;_a=kb;$a=x;ab=K;bb=y;cb=ea}else if((H|0)==1|(H|0)==3){fa=c[o+52+(A<<2)>>2]|0;ha=(fa>>>1)+M|0;do{if((fa&1|0)==0){if((A|0)>1022){J=459;break c}sb=A+1|0;tb=C;ub=ha;vb=z;wb=w;xb=x;yb=K;zb=y;Ab=ea}else{Ta=c[p>>2]|0;if((C|0)>=(Ta|0)){J=449;break c}La=C+1|0;ua=a[O+C|0]|0;if(!(ua<<24>>24==0)){sb=(ua&255)<<2;tb=La;ub=ha;vb=O;wb=O;xb=O;yb=O;zb=O;Ab=O;break}if((La|0)>=(Ta|0)){J=452;break c}ua=C+2|0;Ba=d[O+La|0]<<2;La=c[o+52+(Ba<<2)>>2]|0;Ca=((La>>>1)*5|0)+ha|0;if((La&1|0)==0){sb=Ba|1;tb=ua;ub=Ca;vb=O;wb=O;xb=O;yb=O;zb=O;Ab=O;break}if((ua|0)>=(Ta|0)){J=455;break c}sb=d[O+ua|0]<<2;tb=C+3|0;ub=Ca;vb=O;wb=O;xb=O;yb=O;zb=O;Ab=O}}while(0);ha=(c[P>>2]|0)+ub|0;c[m>>2]=ha;fa=m+4|0;ta=P+4|0;c[P>>2]=ha;ha=c[o+52+(sb<<2)>>2]|0;ga=(ha>>>1)+ub|0;do{if((ha&1|0)==0){if((sb|0)>1022){J=473;break c}Bb=sb+1|0;Cb=tb;Db=ga;Eb=vb;Fb=wb;Gb=xb;Hb=yb;Ib=zb}else{Ca=c[p>>2]|0;if((tb|0)>=(Ca|0)){J=463;break c}ua=tb+1|0;Ta=a[Ab+tb|0]|0;if(!(Ta<<24>>24==0)){Bb=(Ta&255)<<2;Cb=ua;Db=ga;Eb=Ab;Fb=Ab;Gb=Ab;Hb=Ab;Ib=Ab;break}if((ua|0)>=(Ca|0)){J=466;break c}Ta=tb+2|0;Ba=d[Ab+ua|0]<<2;ua=c[o+52+(Ba<<2)>>2]|0;La=((ua>>>1)*5|0)+ga|0;if((ua&1|0)==0){Bb=Ba|1;Cb=Ta;Db=La;Eb=Ab;Fb=Ab;Gb=Ab;Hb=Ab;Ib=Ab;break}if((Ta|0)>=(Ca|0)){J=469;break c}Bb=d[Ab+Ta|0]<<2;Cb=tb+3|0;Db=La;Eb=Ab;Fb=Ab;Gb=Ab;Hb=Ab;Ib=Ab}}while(0);ga=(c[ta>>2]|0)+Db|0;c[fa>>2]=ga;c[ta>>2]=ga;Ua=Bb;Va=Cb;Wa=m+8|0;Xa=P+8|0;Ya=Db;Za=Eb;_a=Fb;$a=Gb;ab=Hb;bb=Ib;cb=Ab}else if((H|0)==2){ga=c[U>>2]|0;if((ga|0)==0){ha=c[o+4148+(A<<2)>>2]|0;La=(ha>>>1)+M|0;do{if((ha&1|0)==0){if((A|0)>1022){J=489;break c}Jb=A+1|0;Kb=C;Lb=La;Mb=z;Nb=w;Ob=x;Pb=K;Qb=y;Rb=ea}else{Ta=c[p>>2]|0;if((C|0)>=(Ta|0)){J=479;break c}Ca=C+1|0;Ba=a[O+C|0]|0;if(!(Ba<<24>>24==0)){Jb=(Ba&255)<<2;Kb=Ca;Lb=La;Mb=O;Nb=O;Ob=O;Pb=O;Qb=O;Rb=O;break}if((Ca|0)>=(Ta|0)){J=482;break c}Ba=C+2|0;ua=d[O+Ca|0]<<2;Ca=c[o+4148+(ua<<2)>>2]|0;Sa=((Ca>>>1)*5|0)+La|0;if((Ca&1|0)==0){Jb=ua|1;Kb=Ba;Lb=Sa;Mb=O;Nb=O;Ob=O;Pb=O;Qb=O;Rb=O;break}if((Ba|0)>=(Ta|0)){J=485;break c}Jb=d[O+Ba|0]<<2;Kb=C+3|0;Lb=Sa;Mb=O;Nb=O;Ob=O;Pb=O;Qb=O;Rb=O}}while(0);La=c[o+52+(Jb<<2)>>2]|0;ha=(La>>>1)+Lb|0;do{if((La&1|0)==0){if((Jb|0)>1022){J=503;break c}Sb=Jb+1|0;Tb=Kb;Ub=ha;Vb=Mb;Wb=Nb;Xb=Ob;Yb=Pb;Zb=Qb;_b=Rb}else{ta=c[p>>2]|0;if((Kb|0)>=(ta|0)){J=493;break c}fa=Kb+1|0;Sa=a[O+Kb|0]|0;if(!(Sa<<24>>24==0)){Sb=(Sa&255)<<2;Tb=fa;Ub=ha;Vb=O;Wb=O;Xb=O;Yb=O;Zb=O;_b=O;break}if((fa|0)>=(ta|0)){J=496;break c}Sa=Kb+2|0;Ba=d[O+fa|0]<<2;fa=c[o+52+(Ba<<2)>>2]|0;Ta=((fa>>>1)*5|0)+ha|0;if((fa&1|0)==0){Sb=Ba|1;Tb=Sa;Ub=Ta;Vb=O;Wb=O;Xb=O;Yb=O;Zb=O;_b=O;break}if((Sa|0)>=(ta|0)){J=499;break c}Sb=d[O+Sa|0]<<2;Tb=Kb+3|0;Ub=Ta;Vb=O;Wb=O;Xb=O;Yb=O;Zb=O;_b=O}}while(0);ha=(c[P>>2]|0)+Ub|0;c[m>>2]=ha;La=m+4|0;Ta=P+4|0;c[P>>2]=ha;ha=c[o+4148+(Sb<<2)>>2]|0;Sa=(ha>>>1)+Ub|0;do{if((ha&1|0)==0){if((Sb|0)>1022){J=517;break c}$b=Sb+1|0;ac=Tb;bc=Sa;cc=Vb;dc=Wb;ec=Xb;fc=Yb;gc=Zb;hc=_b}else{ta=c[p>>2]|0;if((Tb|0)>=(ta|0)){J=507;break c}Ba=Tb+1|0;fa=a[O+Tb|0]|0;if(!(fa<<24>>24==0)){$b=(fa&255)<<2;ac=Ba;bc=Sa;cc=O;dc=O;ec=O;fc=O;gc=O;hc=O;break}if((Ba|0)>=(ta|0)){J=510;break c}fa=Tb+2|0;ua=d[O+Ba|0]<<2;Ba=c[o+4148+(ua<<2)>>2]|0;Ca=((Ba>>>1)*5|0)+Sa|0;if((Ba&1|0)==0){$b=ua|1;ac=fa;bc=Ca;cc=O;dc=O;ec=O;fc=O;gc=O;hc=O;break}if((fa|0)>=(ta|0)){J=513;break c}$b=d[O+fa|0]<<2;ac=Tb+3|0;bc=Ca;cc=O;dc=O;ec=O;fc=O;gc=O;hc=O}}while(0);Sa=c[o+52+($b<<2)>>2]|0;ha=(Sa>>>1)+bc|0;do{if((Sa&1|0)==0){if(($b|0)>1022){J=531;break c}ic=$b+1|0;jc=ac;kc=ha;lc=cc;mc=dc;nc=ec;oc=fc;pc=gc;qc=hc}else{Ca=c[p>>2]|0;if((ac|0)>=(Ca|0)){J=521;break c}fa=ac+1|0;ta=a[O+ac|0]|0;if(!(ta<<24>>24==0)){ic=(ta&255)<<2;jc=fa;kc=ha;lc=O;mc=O;nc=O;oc=O;pc=O;qc=O;break}if((fa|0)>=(Ca|0)){J=524;break c}ta=ac+2|0;ua=d[O+fa|0]<<2;fa=c[o+52+(ua<<2)>>2]|0;Ba=((fa>>>1)*5|0)+ha|0;if((fa&1|0)==0){ic=ua|1;jc=ta;kc=Ba;lc=O;mc=O;nc=O;oc=O;pc=O;qc=O;break}if((ta|0)>=(Ca|0)){J=527;break c}ic=d[O+ta|0]<<2;jc=ac+3|0;kc=Ba;lc=O;mc=O;nc=O;oc=O;pc=O;qc=O}}while(0);ha=(c[Ta>>2]|0)+kc|0;c[La>>2]=ha;c[Ta>>2]=ha;Ua=ic;Va=jc;Wa=m+8|0;Xa=P+8|0;Ya=kc;Za=lc;_a=mc;$a=nc;ab=oc;bb=pc;cb=qc;break}else if((ga|0)==2){ha=c[o+4148+(A<<2)>>2]|0;Sa=(ha>>>1)+M|0;do{if((ha&1|0)==0){if((A|0)>1022){J=546;break c}rc=A+1|0;sc=C;tc=Sa;uc=z;vc=w;wc=x;xc=K;yc=y;zc=ea}else{Ba=c[p>>2]|0;if((C|0)>=(Ba|0)){J=536;break c}ta=C+1|0;Ca=a[O+C|0]|0;if(!(Ca<<24>>24==0)){rc=(Ca&255)<<2;sc=ta;tc=Sa;uc=O;vc=O;wc=O;xc=O;yc=O;zc=O;break}if((ta|0)>=(Ba|0)){J=539;break c}Ca=C+2|0;ua=d[O+ta|0]<<2;ta=c[o+4148+(ua<<2)>>2]|0;fa=((ta>>>1)*5|0)+Sa|0;if((ta&1|0)==0){rc=ua|1;sc=Ca;tc=fa;uc=O;vc=O;wc=O;xc=O;yc=O;zc=O;break}if((Ca|0)>=(Ba|0)){J=542;break c}rc=d[O+Ca|0]<<2;sc=C+3|0;tc=fa;uc=O;vc=O;wc=O;xc=O;yc=O;zc=O}}while(0);Sa=c[o+52+(rc<<2)>>2]|0;ha=(Sa>>>1)+tc|0;do{if((Sa&1|0)==0){if((rc|0)>1022){J=560;break c}Ac=rc+1|0;Bc=sc;Cc=ha;Dc=uc;Ec=vc;Fc=wc;Gc=xc;Hc=yc;Ic=zc}else{ga=c[p>>2]|0;if((sc|0)>=(ga|0)){J=550;break c}Ta=sc+1|0;La=a[O+sc|0]|0;if(!(La<<24>>24==0)){Ac=(La&255)<<2;Bc=Ta;Cc=ha;Dc=O;Ec=O;Fc=O;Gc=O;Hc=O;Ic=O;break}if((Ta|0)>=(ga|0)){J=553;break c}La=sc+2|0;fa=d[O+Ta|0]<<2;Ta=c[o+52+(fa<<2)>>2]|0;Ca=((Ta>>>1)*5|0)+ha|0;if((Ta&1|0)==0){Ac=fa|1;Bc=La;Cc=Ca;Dc=O;Ec=O;Fc=O;Gc=O;Hc=O;Ic=O;break}if((La|0)>=(ga|0)){J=556;break c}Ac=d[O+La|0]<<2;Bc=sc+3|0;Cc=Ca;Dc=O;Ec=O;Fc=O;Gc=O;Hc=O;Ic=O}}while(0);ha=(c[P>>2]|0)+Cc|0;c[m>>2]=ha;Sa=m+4|0;Ca=P+4|0;c[P>>2]=ha;ha=c[o+52+(Ac<<2)>>2]|0;La=(ha>>>1)+Cc|0;do{if((ha&1|0)==0){if((Ac|0)>1022){J=574;break c}Jc=Ac+1|0;Kc=Bc;Lc=La;Mc=Dc;Nc=Ec;Oc=Fc;Pc=Gc;Qc=Hc;Rc=Ic}else{ga=c[p>>2]|0;if((Bc|0)>=(ga|0)){J=564;break c}fa=Bc+1|0;Ta=a[O+Bc|0]|0;if(!(Ta<<24>>24==0)){Jc=(Ta&255)<<2;Kc=fa;Lc=La;Mc=O;Nc=O;Oc=O;Pc=O;Qc=O;Rc=O;break}if((fa|0)>=(ga|0)){J=567;break c}Ta=Bc+2|0;Ba=d[O+fa|0]<<2;fa=c[o+52+(Ba<<2)>>2]|0;ua=((fa>>>1)*5|0)+La|0;if((fa&1|0)==0){Jc=Ba|1;Kc=Ta;Lc=ua;Mc=O;Nc=O;Oc=O;Pc=O;Qc=O;Rc=O;break}if((Ta|0)>=(ga|0)){J=570;break c}Jc=d[O+Ta|0]<<2;Kc=Bc+3|0;Lc=ua;Mc=O;Nc=O;Oc=O;Pc=O;Qc=O;Rc=O}}while(0);La=(c[Ca>>2]|0)+Lc|0;c[Sa>>2]=La;c[Ca>>2]=La;Ua=Jc;Va=Kc;Wa=m+8|0;Xa=P+8|0;Ya=Lc;Za=Mc;_a=Nc;$a=Oc;ab=Pc;bb=Qc;cb=Rc;break}else{La=c[o+52+(A<<2)>>2]|0;ha=(La>>>1)+M|0;do{if((La&1|0)==0){if((A|0)>1022){J=589;break c}Sc=A+1|0;Tc=C;Uc=ha;Vc=z;Wc=w;Xc=x;Yc=K;Zc=y;_c=ea}else{ua=c[p>>2]|0;if((C|0)>=(ua|0)){J=579;break c}Ta=C+1|0;ga=a[O+C|0]|0;if(!(ga<<24>>24==0)){Sc=(ga&255)<<2;Tc=Ta;Uc=ha;Vc=O;Wc=O;Xc=O;Yc=O;Zc=O;_c=O;break}if((Ta|0)>=(ua|0)){J=582;break c}ga=C+2|0;Ba=d[O+Ta|0]<<2;Ta=c[o+52+(Ba<<2)>>2]|0;fa=((Ta>>>1)*5|0)+ha|0;if((Ta&1|0)==0){Sc=Ba|1;Tc=ga;Uc=fa;Vc=O;Wc=O;Xc=O;Yc=O;Zc=O;_c=O;break}if((ga|0)>=(ua|0)){J=585;break c}Sc=d[O+ga|0]<<2;Tc=C+3|0;Uc=fa;Vc=O;Wc=O;Xc=O;Yc=O;Zc=O;_c=O}}while(0);ha=(c[P>>2]|0)+Uc|0;c[m>>2]=ha;La=m+4|0;Ca=P+4|0;c[P>>2]=ha;ha=c[o+52+(Sc<<2)>>2]|0;Sa=(ha>>>1)+Uc|0;do{if((ha&1|0)==0){if((Sc|0)>1022){J=603;break c}$c=Sc+1|0;ad=Tc;bd=Sa;cd=Vc;dd=Wc;ed=Xc;fd=Yc;gd=Zc;hd=_c}else{fa=c[p>>2]|0;if((Tc|0)>=(fa|0)){J=593;break c}ga=Tc+1|0;ua=a[O+Tc|0]|0;if(!(ua<<24>>24==0)){$c=(ua&255)<<2;ad=ga;bd=Sa;cd=O;dd=O;ed=O;fd=O;gd=O;hd=O;break}if((ga|0)>=(fa|0)){J=596;break c}ua=Tc+2|0;Ba=d[O+ga|0]<<2;ga=c[o+52+(Ba<<2)>>2]|0;Ta=((ga>>>1)*5|0)+Sa|0;if((ga&1|0)==0){$c=Ba|1;ad=ua;bd=Ta;cd=O;dd=O;ed=O;fd=O;gd=O;hd=O;break}if((ua|0)>=(fa|0)){J=599;break c}$c=d[O+ua|0]<<2;ad=Tc+3|0;bd=Ta;cd=O;dd=O;ed=O;fd=O;gd=O;hd=O}}while(0);Sa=(c[Ca>>2]|0)+bd|0;c[La>>2]=Sa;c[Ca>>2]=Sa;Ua=$c;Va=ad;Wa=m+8|0;Xa=P+8|0;Ya=bd;Za=cd;_a=dd;$a=ed;ab=fd;bb=gd;cb=hd;break}}else{Ua=A;Va=C;Wa=m;Xa=P;Ya=M;Za=z;_a=w;$a=x;ab=K;bb=y;cb=ea}}while(0);if(L){id=B;jd=S;kd=v;ld=Ya;md=Xa;nd=Wa;od=Va;pd=Ua;qd=Za;rd=_a;sd=$a;td=ab;ud=bb;vd=cb}else{ia=Ya;ja=Xa;ka=Wa;la=Va;ma=Ua;na=Za;oa=_a;pa=$a;qa=ab;ra=bb;sa=cb;J=608}}do{if((J|0)==608){J=0;Sa=S<<1;if(!(Sa<<24>>24==0)){id=B;jd=Sa;kd=v;ld=ia;md=ja;nd=ka;od=la;pd=ma;qd=na;rd=oa;sd=pa;td=qa;ud=ra;vd=sa;break}id=B+1|0;jd=1;kd=a[s+B|0]|0;ld=ia;md=ja;nd=ka;od=la;pd=ma;qd=na;rd=oa;sd=pa;td=qa;ud=ra;vd=sa}}while(0);Sa=E-4|0;if((Sa|0)>0){E=Sa;M=ld;P=md;m=nd;v=kd;S=jd;B=id;C=od;A=pd;z=qd;w=rd;x=sd;K=td;y=ud;ea=vd}else{wd=od;xd=pd;yd=qd;zd=rd;Ad=sd;Bd=td;Cd=ud;Dd=vd;break}}}else{wd=Z;xd=Y;yd=X;zd=G;Ad=Q;Bd=W;Cd=V;Dd=r}ea=N+1|0;if((ea&3|0)==0){Ed=s+(c[F>>2]|0)|0}else{Ed=s}if((ea|0)>=(c[R>>2]|0)){break b}da=da+(c[(c[T>>2]|0)+32>>2]|0)|0;N=ea;s=Ed;Z=wd;Y=xd;X=yd;G=zd;Q=Ad;W=Bd;V=Cd;r=Dd}if((J|0)==349){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==352){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==355){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==359){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==363){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==366){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==369){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==373){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==377){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==380){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==383){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==387){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==391){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==394){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==397){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==401){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==406){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==409){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==412){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==416){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==420){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==423){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==426){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==430){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==434){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==437){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==440){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==444){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==449){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==452){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==455){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==459){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==463){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==466){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==469){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==473){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==479){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==482){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==485){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==489){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==493){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==496){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==499){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==503){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==507){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==510){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==513){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==517){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==521){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==524){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==527){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==531){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==536){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==539){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==542){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==546){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==550){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==553){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==556){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==560){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==564){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==567){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==570){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==574){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==579){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==582){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==585){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==589){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==593){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==596){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==599){KIb(q,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==603){KIb(q,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}}else{r=c[c[T>>2]>>2]|0;V=c[D>>2]&16;W=c[$>>2]|0;Q=j+16524|0;mrc(c[Q>>2]|0,0,c[(c[I>>2]|0)+120>>2]<<2|0)|0;G=c[I>>2]|0;if((c[p>>2]|0)<1){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}X=G+124|0;if((c[X>>2]|0)<=0){break}Y=c[j+24>>2]|0;Z=(V|0)!=0;V=G+120|0;s=r;r=0;N=W;W=1;da=d[Y]<<2;R=Y;L=Y;O=Y;aa=Y;f=Y;ea=Y;d:while(1){y=c[V>>2]|0;if((y|0)>0){K=r&3;x=y;y=0;w=c[Q>>2]|0;z=s;A=a[N]|0;C=1;B=1;S=W;v=da;m=R;P=L;M=O;E=aa;H=f;l=ea;while(1){do{if(Z){J=66}else{if((A&C)<<24>>24==0){J=66;break}Sa=w+4|0;c[w>>2]=c[z>>2];ha=c[z+4>>2]|0;Ta=ha-(c[Sa>>2]|0)|0;c[Sa>>2]=ha;Fd=Ta;Gd=w+8|0;Hd=z+8|0;Id=S;Jd=v;Kd=m;Ld=P;Md=M;Nd=E;Od=H;Pd=l;J=329}}while(0);if((J|0)==66){J=0;do{if((K|0)==1|(K|0)==3){Ta=c[o+52+(v<<2)>>2]|0;ha=(Ta>>>1)+y|0;do{if((Ta&1|0)==0){if((v|0)>1022){J=180;break d}Qd=v+1|0;Rd=S;Sd=ha;Td=m;Ud=P;Vd=M;Wd=E;Xd=H;Yd=l}else{Sa=c[p>>2]|0;if((S|0)>=(Sa|0)){J=170;break d}ua=S+1|0;fa=a[Y+S|0]|0;if(!(fa<<24>>24==0)){Qd=(fa&255)<<2;Rd=ua;Sd=ha;Td=Y;Ud=Y;Vd=Y;Wd=Y;Xd=Y;Yd=Y;break}if((ua|0)>=(Sa|0)){J=173;break d}fa=S+2|0;Ba=d[Y+ua|0]<<2;ua=c[o+8244+(Ba<<2)>>2]|0;ga=(ua>>>1)+ha|0;if((ua&1|0)==0){Qd=Ba|1;Rd=fa;Sd=ga;Td=Y;Ud=Y;Vd=Y;Wd=Y;Xd=Y;Yd=Y;break}if((fa|0)>=(Sa|0)){J=176;break d}Qd=d[Y+fa|0]<<2;Rd=S+3|0;Sd=ga;Td=Y;Ud=Y;Vd=Y;Wd=Y;Xd=Y;Yd=Y}}while(0);ha=(c[w>>2]|0)+Sd|0;c[z>>2]=ha;Ta=z+4|0;Ca=w+4|0;c[w>>2]=ha;ha=c[o+52+(Qd<<2)>>2]|0;La=(ha>>>1)+Sd|0;do{if((ha&1|0)==0){if((Qd|0)>1022){J=194;break d}Zd=Qd+1|0;_d=Rd;$d=La;ae=Td;be=Ud;ce=Vd;de=Wd;ee=Xd}else{ga=c[p>>2]|0;if((Rd|0)>=(ga|0)){J=184;break d}fa=Rd+1|0;Sa=a[Yd+Rd|0]|0;if(!(Sa<<24>>24==0)){Zd=(Sa&255)<<2;_d=fa;$d=La;ae=Yd;be=Yd;ce=Yd;de=Yd;ee=Yd;break}if((fa|0)>=(ga|0)){J=187;break d}Sa=Rd+2|0;Ba=d[Yd+fa|0]<<2;fa=c[o+8244+(Ba<<2)>>2]|0;ua=(fa>>>1)+La|0;if((fa&1|0)==0){Zd=Ba|1;_d=Sa;$d=ua;ae=Yd;be=Yd;ce=Yd;de=Yd;ee=Yd;break}if((Sa|0)>=(ga|0)){J=190;break d}Zd=d[Yd+Sa|0]<<2;_d=Rd+3|0;$d=ua;ae=Yd;be=Yd;ce=Yd;de=Yd;ee=Yd}}while(0);La=(c[Ca>>2]|0)+$d|0;c[Ta>>2]=La;c[Ca>>2]=La;fe=Zd;ge=_d;he=z+8|0;ie=w+8|0;je=$d;ke=ae;le=be;me=ce;ne=de;oe=ee;pe=Yd}else if((K|0)==0){La=c[o+4148+(v<<2)>>2]|0;ha=(La>>>1)+y|0;ua=(La&1|0)!=0;if((c[ba>>2]|0)!=2){do{if(ua){La=c[p>>2]|0;if((S|0)>=(La|0)){J=127;break d}Sa=S+1|0;ga=a[E+S|0]|0;if(!(ga<<24>>24==0)){qe=(ga&255)<<2;re=Sa;se=ha;te=E;ue=E;ve=E;break}if((Sa|0)>=(La|0)){J=130;break d}ga=S+2|0;Ba=d[E+Sa|0]<<2;Sa=c[o+12340+(Ba<<2)>>2]|0;fa=(Sa>>>1)+ha|0;if((Sa&1|0)==0){qe=Ba|1;re=ga;se=fa;te=E;ue=E;ve=E;break}if((ga|0)>=(La|0)){J=133;break d}qe=d[E+ga|0]<<2;re=S+3|0;se=fa;te=E;ue=E;ve=E}else{if((v|0)>1022){J=137;break d}qe=v+1|0;re=S;se=ha;te=m;ue=P;ve=M}}while(0);Ca=c[o+52+(qe<<2)>>2]|0;Ta=(Ca>>>1)+se|0;do{if((Ca&1|0)==0){if((qe|0)>1022){J=151;break d}we=qe+1|0;xe=re;ye=Ta;ze=te;Ae=ue;Be=ve;Ce=E}else{fa=c[p>>2]|0;if((re|0)>=(fa|0)){J=141;break d}ga=re+1|0;La=a[H+re|0]|0;if(!(La<<24>>24==0)){we=(La&255)<<2;xe=ga;ye=Ta;ze=H;Ae=H;Be=H;Ce=H;break}if((ga|0)>=(fa|0)){J=144;break d}La=re+2|0;Ba=d[H+ga|0]<<2;ga=c[o+8244+(Ba<<2)>>2]|0;Sa=(ga>>>1)+Ta|0;if((ga&1|0)==0){we=Ba|1;xe=La;ye=Sa;ze=H;Ae=H;Be=H;Ce=H;break}if((La|0)>=(fa|0)){J=147;break d}we=d[H+La|0]<<2;xe=re+3|0;ye=Sa;ze=H;Ae=H;Be=H;Ce=H}}while(0);Ta=(c[w>>2]|0)+ye|0;c[z>>2]=Ta;Ca=z+4|0;Sa=w+4|0;c[w>>2]=Ta;Ta=c[o+52+(we<<2)>>2]|0;La=(Ta>>>1)+ye|0;do{if((Ta&1|0)==0){if((we|0)>1022){J=165;break d}De=we+1|0;Ee=xe;Fe=La;Ge=ze;He=Ae;Ie=Be}else{fa=c[p>>2]|0;if((xe|0)>=(fa|0)){J=155;break d}Ba=xe+1|0;ga=a[Ce+xe|0]|0;if(!(ga<<24>>24==0)){De=(ga&255)<<2;Ee=Ba;Fe=La;Ge=Ce;He=Ce;Ie=Ce;break}if((Ba|0)>=(fa|0)){J=158;break d}ga=xe+2|0;ta=d[Ce+Ba|0]<<2;Ba=c[o+8244+(ta<<2)>>2]|0;Ka=(Ba>>>1)+La|0;if((Ba&1|0)==0){De=ta|1;Ee=ga;Fe=Ka;Ge=Ce;He=Ce;Ie=Ce;break}if((ga|0)>=(fa|0)){J=161;break d}De=d[Ce+ga|0]<<2;Ee=xe+3|0;Fe=Ka;Ge=Ce;He=Ce;Ie=Ce}}while(0);La=(c[Sa>>2]|0)+Fe|0;c[Ca>>2]=La;c[Sa>>2]=La;fe=De;ge=Ee;he=z+8|0;ie=w+8|0;je=Fe;ke=Ge;le=He;me=Ie;ne=Ce;oe=H;pe=l;break}do{if(ua){La=c[p>>2]|0;if((S|0)>=(La|0)){J=70;break d}Ta=S+1|0;Ka=a[m+S|0]|0;if(!(Ka<<24>>24==0)){Je=(Ka&255)<<2;Ke=Ta;Le=ha;break}if((Ta|0)>=(La|0)){J=73;break d}Ka=S+2|0;ga=d[m+Ta|0]<<2;Ta=c[o+12340+(ga<<2)>>2]|0;fa=(Ta>>>1)+ha|0;if((Ta&1|0)==0){Je=ga|1;Ke=Ka;Le=fa;break}if((Ka|0)>=(La|0)){J=76;break d}Je=d[m+Ka|0]<<2;Ke=S+3|0;Le=fa}else{if((v|0)>1022){J=80;break d}Je=v+1|0;Ke=S;Le=ha}}while(0);ha=c[o+52+(Je<<2)>>2]|0;ua=(ha>>>1)+Le|0;do{if((ha&1|0)==0){if((Je|0)>1022){J=94;break d}Me=Je+1|0;Ne=Ke;Oe=ua;Pe=m;Qe=P}else{Sa=c[p>>2]|0;if((Ke|0)>=(Sa|0)){J=84;break d}Ca=Ke+1|0;fa=a[M+Ke|0]|0;if(!(fa<<24>>24==0)){Me=(fa&255)<<2;Ne=Ca;Oe=ua;Pe=M;Qe=M;break}if((Ca|0)>=(Sa|0)){J=87;break d}fa=Ke+2|0;Ka=d[M+Ca|0]<<2;Ca=c[o+8244+(Ka<<2)>>2]|0;La=(Ca>>>1)+ua|0;if((Ca&1|0)==0){Me=Ka|1;Ne=fa;Oe=La;Pe=M;Qe=M;break}if((fa|0)>=(Sa|0)){J=90;break d}Me=d[M+fa|0]<<2;Ne=Ke+3|0;Oe=La;Pe=M;Qe=M}}while(0);ua=(c[w>>2]|0)+Oe|0;c[z>>2]=ua;ha=z+4|0;La=w+4|0;c[w>>2]=ua;ua=c[o+4148+(Me<<2)>>2]|0;fa=(ua>>>1)+Oe|0;do{if((ua&1|0)==0){if((Me|0)>1022){J=108;break d}Re=Me+1|0;Se=Ne;Te=fa;Ue=Pe}else{Sa=c[p>>2]|0;if((Ne|0)>=(Sa|0)){J=98;break d}Ka=Ne+1|0;Ca=a[Qe+Ne|0]|0;if(!(Ca<<24>>24==0)){Re=(Ca&255)<<2;Se=Ka;Te=fa;Ue=Qe;break}if((Ka|0)>=(Sa|0)){J=101;break d}Ca=Ne+2|0;ga=d[Qe+Ka|0]<<2;Ka=c[o+12340+(ga<<2)>>2]|0;Ta=(Ka>>>1)+fa|0;if((Ka&1|0)==0){Re=ga|1;Se=Ca;Te=Ta;Ue=Qe;break}if((Ca|0)>=(Sa|0)){J=104;break d}Re=d[Qe+Ca|0]<<2;Se=Ne+3|0;Te=Ta;Ue=Qe}}while(0);fa=c[o+52+(Re<<2)>>2]|0;ua=(fa>>>1)+Te|0;do{if((fa&1|0)==0){if((Re|0)>1022){J=122;break d}Ve=Re+1|0;We=Se;Xe=ua}else{Ta=c[p>>2]|0;if((Se|0)>=(Ta|0)){J=112;break d}Ca=Se+1|0;Sa=a[Ue+Se|0]|0;if(!(Sa<<24>>24==0)){Ve=(Sa&255)<<2;We=Ca;Xe=ua;break}if((Ca|0)>=(Ta|0)){J=115;break d}Sa=Se+2|0;ga=d[Ue+Ca|0]<<2;Ca=c[o+8244+(ga<<2)>>2]|0;Ka=(Ca>>>1)+ua|0;if((Ca&1|0)==0){Ve=ga|1;We=Sa;Xe=Ka;break}if((Sa|0)>=(Ta|0)){J=118;break d}Ve=d[Ue+Sa|0]<<2;We=Se+3|0;Xe=Ka}}while(0);ua=(c[La>>2]|0)+Xe|0;c[ha>>2]=ua;c[La>>2]=ua;fe=Ve;ge=We;he=z+8|0;ie=w+8|0;je=Xe;ke=Ue;le=Qe;me=M;ne=E;oe=H;pe=l}else if((K|0)==2){ua=c[U>>2]|0;if((ua|0)==0){fa=c[o+4148+(v<<2)>>2]|0;Ka=(fa>>>1)+y|0;do{if((fa&1|0)==0){if((v|0)>1022){J=210;break d}Ye=v+1|0;Ze=S;_e=Ka;$e=m;af=P;bf=M;cf=E;df=H;ef=l}else{Sa=c[p>>2]|0;if((S|0)>=(Sa|0)){J=200;break d}Ta=S+1|0;ga=a[Y+S|0]|0;if(!(ga<<24>>24==0)){Ye=(ga&255)<<2;Ze=Ta;_e=Ka;$e=Y;af=Y;bf=Y;cf=Y;df=Y;ef=Y;break}if((Ta|0)>=(Sa|0)){J=203;break d}ga=S+2|0;Ca=d[Y+Ta|0]<<2;Ta=c[o+12340+(Ca<<2)>>2]|0;ta=(Ta>>>1)+Ka|0;if((Ta&1|0)==0){Ye=Ca|1;Ze=ga;_e=ta;$e=Y;af=Y;bf=Y;cf=Y;df=Y;ef=Y;break}if((ga|0)>=(Sa|0)){J=206;break d}Ye=d[Y+ga|0]<<2;Ze=S+3|0;_e=ta;$e=Y;af=Y;bf=Y;cf=Y;df=Y;ef=Y}}while(0);Ka=c[o+52+(Ye<<2)>>2]|0;fa=(Ka>>>1)+_e|0;do{if((Ka&1|0)==0){if((Ye|0)>1022){J=224;break d}ff=Ye+1|0;gf=Ze;hf=fa;jf=$e;kf=af;lf=bf;mf=cf;nf=df;of=ef}else{La=c[p>>2]|0;if((Ze|0)>=(La|0)){J=214;break d}ha=Ze+1|0;ta=a[Y+Ze|0]|0;if(!(ta<<24>>24==0)){ff=(ta&255)<<2;gf=ha;hf=fa;jf=Y;kf=Y;lf=Y;mf=Y;nf=Y;of=Y;break}if((ha|0)>=(La|0)){J=217;break d}ta=Ze+2|0;ga=d[Y+ha|0]<<2;ha=c[o+8244+(ga<<2)>>2]|0;Sa=(ha>>>1)+fa|0;if((ha&1|0)==0){ff=ga|1;gf=ta;hf=Sa;jf=Y;kf=Y;lf=Y;mf=Y;nf=Y;of=Y;break}if((ta|0)>=(La|0)){J=220;break d}ff=d[Y+ta|0]<<2;gf=Ze+3|0;hf=Sa;jf=Y;kf=Y;lf=Y;mf=Y;nf=Y;of=Y}}while(0);fa=(c[w>>2]|0)+hf|0;c[z>>2]=fa;Ka=z+4|0;Sa=w+4|0;c[w>>2]=fa;fa=c[o+4148+(ff<<2)>>2]|0;ta=(fa>>>1)+hf|0;do{if((fa&1|0)==0){if((ff|0)>1022){J=238;break d}pf=ff+1|0;qf=gf;rf=ta;sf=jf;tf=kf;uf=lf;vf=mf;wf=nf;xf=of}else{La=c[p>>2]|0;if((gf|0)>=(La|0)){J=228;break d}ga=gf+1|0;ha=a[Y+gf|0]|0;if(!(ha<<24>>24==0)){pf=(ha&255)<<2;qf=ga;rf=ta;sf=Y;tf=Y;uf=Y;vf=Y;wf=Y;xf=Y;break}if((ga|0)>=(La|0)){J=231;break d}ha=gf+2|0;Ca=d[Y+ga|0]<<2;ga=c[o+12340+(Ca<<2)>>2]|0;Ta=(ga>>>1)+ta|0;if((ga&1|0)==0){pf=Ca|1;qf=ha;rf=Ta;sf=Y;tf=Y;uf=Y;vf=Y;wf=Y;xf=Y;break}if((ha|0)>=(La|0)){J=234;break d}pf=d[Y+ha|0]<<2;qf=gf+3|0;rf=Ta;sf=Y;tf=Y;uf=Y;vf=Y;wf=Y;xf=Y}}while(0);ta=c[o+52+(pf<<2)>>2]|0;fa=(ta>>>1)+rf|0;do{if((ta&1|0)==0){if((pf|0)>1022){J=252;break d}yf=pf+1|0;zf=qf;Af=fa;Bf=sf;Cf=tf;Df=uf;Ef=vf;Ff=wf;Gf=xf}else{Ta=c[p>>2]|0;if((qf|0)>=(Ta|0)){J=242;break d}ha=qf+1|0;La=a[Y+qf|0]|0;if(!(La<<24>>24==0)){yf=(La&255)<<2;zf=ha;Af=fa;Bf=Y;Cf=Y;Df=Y;Ef=Y;Ff=Y;Gf=Y;break}if((ha|0)>=(Ta|0)){J=245;break d}La=qf+2|0;Ca=d[Y+ha|0]<<2;ha=c[o+8244+(Ca<<2)>>2]|0;ga=(ha>>>1)+fa|0;if((ha&1|0)==0){yf=Ca|1;zf=La;Af=ga;Bf=Y;Cf=Y;Df=Y;Ef=Y;Ff=Y;Gf=Y;break}if((La|0)>=(Ta|0)){J=248;break d}yf=d[Y+La|0]<<2;zf=qf+3|0;Af=ga;Bf=Y;Cf=Y;Df=Y;Ef=Y;Ff=Y;Gf=Y}}while(0);fa=(c[Sa>>2]|0)+Af|0;c[Ka>>2]=fa;c[Sa>>2]=fa;fe=yf;ge=zf;he=z+8|0;ie=w+8|0;je=Af;ke=Bf;le=Cf;me=Df;ne=Ef;oe=Ff;pe=Gf;break}else if((ua|0)==2){fa=c[o+4148+(v<<2)>>2]|0;ta=(fa>>>1)+y|0;do{if((fa&1|0)==0){if((v|0)>1022){J=267;break d}Hf=v+1|0;If=S;Jf=ta;Kf=m;Lf=P;Mf=M;Nf=E;Of=H;Pf=l}else{ga=c[p>>2]|0;if((S|0)>=(ga|0)){J=257;break d}La=S+1|0;Ta=a[Y+S|0]|0;if(!(Ta<<24>>24==0)){Hf=(Ta&255)<<2;If=La;Jf=ta;Kf=Y;Lf=Y;Mf=Y;Nf=Y;Of=Y;Pf=Y;break}if((La|0)>=(ga|0)){J=260;break d}Ta=S+2|0;Ca=d[Y+La|0]<<2;La=c[o+12340+(Ca<<2)>>2]|0;ha=(La>>>1)+ta|0;if((La&1|0)==0){Hf=Ca|1;If=Ta;Jf=ha;Kf=Y;Lf=Y;Mf=Y;Nf=Y;Of=Y;Pf=Y;break}if((Ta|0)>=(ga|0)){J=263;break d}Hf=d[Y+Ta|0]<<2;If=S+3|0;Jf=ha;Kf=Y;Lf=Y;Mf=Y;Nf=Y;Of=Y;Pf=Y}}while(0);ta=c[o+52+(Hf<<2)>>2]|0;fa=(ta>>>1)+Jf|0;do{if((ta&1|0)==0){if((Hf|0)>1022){J=281;break d}Qf=Hf+1|0;Rf=If;Sf=fa;Tf=Kf;Uf=Lf;Vf=Mf;Wf=Nf;Xf=Of;Yf=Pf}else{ua=c[p>>2]|0;if((If|0)>=(ua|0)){J=271;break d}Sa=If+1|0;Ka=a[Y+If|0]|0;if(!(Ka<<24>>24==0)){Qf=(Ka&255)<<2;Rf=Sa;Sf=fa;Tf=Y;Uf=Y;Vf=Y;Wf=Y;Xf=Y;Yf=Y;break}if((Sa|0)>=(ua|0)){J=274;break d}Ka=If+2|0;ha=d[Y+Sa|0]<<2;Sa=c[o+8244+(ha<<2)>>2]|0;Ta=(Sa>>>1)+fa|0;if((Sa&1|0)==0){Qf=ha|1;Rf=Ka;Sf=Ta;Tf=Y;Uf=Y;Vf=Y;Wf=Y;Xf=Y;Yf=Y;break}if((Ka|0)>=(ua|0)){J=277;break d}Qf=d[Y+Ka|0]<<2;Rf=If+3|0;Sf=Ta;Tf=Y;Uf=Y;Vf=Y;Wf=Y;Xf=Y;Yf=Y}}while(0);fa=(c[w>>2]|0)+Sf|0;c[z>>2]=fa;ta=z+4|0;Ta=w+4|0;c[w>>2]=fa;fa=c[o+52+(Qf<<2)>>2]|0;Ka=(fa>>>1)+Sf|0;do{if((fa&1|0)==0){if((Qf|0)>1022){J=295;break d}Zf=Qf+1|0;_f=Rf;$f=Ka;ag=Tf;bg=Uf;cg=Vf;dg=Wf;eg=Xf;fg=Yf}else{ua=c[p>>2]|0;if((Rf|0)>=(ua|0)){J=285;break d}ha=Rf+1|0;Sa=a[Y+Rf|0]|0;if(!(Sa<<24>>24==0)){Zf=(Sa&255)<<2;_f=ha;$f=Ka;ag=Y;bg=Y;cg=Y;dg=Y;eg=Y;fg=Y;break}if((ha|0)>=(ua|0)){J=288;break d}Sa=Rf+2|0;ga=d[Y+ha|0]<<2;ha=c[o+8244+(ga<<2)>>2]|0;Ca=(ha>>>1)+Ka|0;if((ha&1|0)==0){Zf=ga|1;_f=Sa;$f=Ca;ag=Y;bg=Y;cg=Y;dg=Y;eg=Y;fg=Y;break}if((Sa|0)>=(ua|0)){J=291;break d}Zf=d[Y+Sa|0]<<2;_f=Rf+3|0;$f=Ca;ag=Y;bg=Y;cg=Y;dg=Y;eg=Y;fg=Y}}while(0);Ka=(c[Ta>>2]|0)+$f|0;c[ta>>2]=Ka;c[Ta>>2]=Ka;fe=Zf;ge=_f;he=z+8|0;ie=w+8|0;je=$f;ke=ag;le=bg;me=cg;ne=dg;oe=eg;pe=fg;break}else{Ka=c[o+52+(v<<2)>>2]|0;fa=(Ka>>>1)+y|0;do{if((Ka&1|0)==0){if((v|0)>1022){J=310;break d}gg=v+1|0;hg=S;ig=fa;jg=m;kg=P;lg=M;mg=E;ng=H;og=l}else{Ca=c[p>>2]|0;if((S|0)>=(Ca|0)){J=300;break d}Sa=S+1|0;ua=a[Y+S|0]|0;if(!(ua<<24>>24==0)){gg=(ua&255)<<2;hg=Sa;ig=fa;jg=Y;kg=Y;lg=Y;mg=Y;ng=Y;og=Y;break}if((Sa|0)>=(Ca|0)){J=303;break d}ua=S+2|0;ga=d[Y+Sa|0]<<2;Sa=c[o+8244+(ga<<2)>>2]|0;ha=(Sa>>>1)+fa|0;if((Sa&1|0)==0){gg=ga|1;hg=ua;ig=ha;jg=Y;kg=Y;lg=Y;mg=Y;ng=Y;og=Y;break}if((ua|0)>=(Ca|0)){J=306;break d}gg=d[Y+ua|0]<<2;hg=S+3|0;ig=ha;jg=Y;kg=Y;lg=Y;mg=Y;ng=Y;og=Y}}while(0);fa=(c[w>>2]|0)+ig|0;c[z>>2]=fa;Ka=z+4|0;Ta=w+4|0;c[w>>2]=fa;fa=c[o+52+(gg<<2)>>2]|0;ta=(fa>>>1)+ig|0;do{if((fa&1|0)==0){if((gg|0)>1022){J=324;break d}pg=gg+1|0;qg=hg;rg=ta;sg=jg;tg=kg;ug=lg;vg=mg;wg=ng;xg=og}else{ha=c[p>>2]|0;if((hg|0)>=(ha|0)){J=314;break d}ua=hg+1|0;Ca=a[Y+hg|0]|0;if(!(Ca<<24>>24==0)){pg=(Ca&255)<<2;qg=ua;rg=ta;sg=Y;tg=Y;ug=Y;vg=Y;wg=Y;xg=Y;break}if((ua|0)>=(ha|0)){J=317;break d}Ca=hg+2|0;ga=d[Y+ua|0]<<2;ua=c[o+8244+(ga<<2)>>2]|0;Sa=(ua>>>1)+ta|0;if((ua&1|0)==0){pg=ga|1;qg=Ca;rg=Sa;sg=Y;tg=Y;ug=Y;vg=Y;wg=Y;xg=Y;break}if((Ca|0)>=(ha|0)){J=320;break d}pg=d[Y+Ca|0]<<2;qg=hg+3|0;rg=Sa;sg=Y;tg=Y;ug=Y;vg=Y;wg=Y;xg=Y}}while(0);ta=(c[Ta>>2]|0)+rg|0;c[Ka>>2]=ta;c[Ta>>2]=ta;fe=pg;ge=qg;he=z+8|0;ie=w+8|0;je=rg;ke=sg;le=tg;me=ug;ne=vg;oe=wg;pe=xg;break}}else{fe=v;ge=S;he=z;ie=w;je=y;ke=m;le=P;me=M;ne=E;oe=H;pe=l}}while(0);if(Z){yg=B;zg=C;Ag=A;Bg=je;Cg=ie;Dg=he;Eg=ge;Fg=fe;Gg=ke;Hg=le;Ig=me;Jg=ne;Kg=oe;Lg=pe}else{Fd=je;Gd=ie;Hd=he;Id=ge;Jd=fe;Kd=ke;Ld=le;Md=me;Nd=ne;Od=oe;Pd=pe;J=329}}do{if((J|0)==329){J=0;ta=C<<1;if(!(ta<<24>>24==0)){yg=B;zg=ta;Ag=A;Bg=Fd;Cg=Gd;Dg=Hd;Eg=Id;Fg=Jd;Gg=Kd;Hg=Ld;Ig=Md;Jg=Nd;Kg=Od;Lg=Pd;break}yg=B+1|0;zg=1;Ag=a[N+B|0]|0;Bg=Fd;Cg=Gd;Dg=Hd;Eg=Id;Fg=Jd;Gg=Kd;Hg=Ld;Ig=Md;Jg=Nd;Kg=Od;Lg=Pd}}while(0);ta=x-2|0;if((ta|0)>0){x=ta;y=Bg;w=Cg;z=Dg;A=Ag;C=zg;B=yg;S=Eg;v=Fg;m=Gg;P=Hg;M=Ig;E=Jg;H=Kg;l=Lg}else{Mg=Eg;Ng=Fg;Og=Gg;Pg=Hg;Qg=Ig;Rg=Jg;Sg=Kg;Tg=Lg;break}}}else{Mg=W;Ng=da;Og=R;Pg=L;Qg=O;Rg=aa;Sg=f;Tg=ea}l=r+1|0;if((l&3|0)==0){Ug=N+(c[F>>2]|0)|0}else{Ug=N}if((l|0)>=(c[X>>2]|0)){break b}s=s+(c[(c[T>>2]|0)+32>>2]|0)|0;r=l;N=Ug;W=Mg;da=Ng;R=Og;L=Pg;O=Qg;aa=Rg;f=Sg;ea=Tg}if((J|0)==70){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==73){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==76){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==80){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==84){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==87){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==90){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==94){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==98){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==101){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==104){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==108){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==112){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==115){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==118){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==122){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==127){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==130){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==133){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==137){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==141){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==144){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==147){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==151){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==155){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==158){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==161){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==165){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==170){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==173){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==176){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==180){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==184){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==187){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==190){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==194){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==200){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==203){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==206){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==210){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==214){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==217){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==220){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==224){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==228){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==231){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==234){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==238){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==242){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==245){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==248){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==252){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==257){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==260){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==263){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==267){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==271){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==274){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==277){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==281){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==285){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==288){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==291){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==295){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==300){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==303){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==306){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==310){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==314){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==317){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==320){KIb(G,32,2445328,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else if((J|0)==324){KIb(G,16,2356136,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}}}while(0);t=YHb(g,c[T>>2]|0)|0;if((t|0)<0){u=t;i=k;return u|0}c[h>>2]=1;u=n;i=k;return u|0}function P3a(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+16524|0);return 0}function Q3a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;d=c[a+60>>2]|0;e=c[a+120>>2]|0;f=c[a+124>>2]|0;do{if((e&3|0)==0){if((f&3|0)!=0){break}c[d>>2]=a;c[a+140>>2]=3;g=UHb()|0;h=d+4|0;c[h>>2]=g;if((g|0)==0){j=-12;i=b;return j|0}l8(d+28|0,a);g=e>>2;if(g>>>0<134217727>>>0){k=g<<4;g=d+3188|0;l=g;c[l>>2]=hJb(k)|0;m=hJb(k)|0;n=g;o=l}else{l=d+3188|0;g=l;c[g>>2]=0;m=0;n=l;o=g}g=d+3192|0;l=g;c[l>>2]=m;c[d+1280>>2]=0;c[d+1308>>2]=0;c[d+1284>>2]=0;c[d+1312>>2]=0;c[d+1288>>2]=0;c[d+1316>>2]=0;c[d+1292>>2]=0;c[d+1320>>2]=0;c[d+1296>>2]=0;c[d+1324>>2]=0;c[d+1300>>2]=0;c[d+1328>>2]=0;c[d+1304>>2]=0;c[d+1332>>2]=0;k=e+8|0;p=ca(f+8|0,k)|0;q=d+3196|0;r=q;c[r>>2]=qJb(p,4)|0;s=d+3208|0;t=s;c[t>>2]=qJb(p,4)|0;p=d+3244|0;c[p>>2]=k;k=e+9>>1;u=ca(f+9>>1,k)|0;v=d+3200|0;w=v;c[w>>2]=qJb(u,4)|0;x=d+3204|0;y=x;c[y>>2]=qJb(u,4)|0;z=d+3212|0;A=z;c[A>>2]=qJb(u,4)|0;B=qJb(u,4)|0;u=B;C=d+3216|0;c[C>>2]=u;c[d+3248>>2]=k;c[d+3252>>2]=0;D=c[r>>2]|0;do{if((D|0)!=0){r=c[t>>2]|0;if((r|0)==0){break}E=c[w>>2]|0;if((E|0)==0){break}F=c[y>>2]|0;if((F|0)==0){break}G=c[A>>2]|0;if((G|0)==0|(B|0)==0){break}if((c[o>>2]|0)==0){break}if((c[l>>2]|0)==0){break}H=(c[p>>2]<<2)+4|0;c[d+3220>>2]=D+(H<<2);c[d+3232>>2]=r+(H<<2);H=(k<<1)+2|0;c[d+3224>>2]=E+(H<<2);c[d+3236>>2]=G+(H<<2);c[d+3228>>2]=F+(H<<2);c[d+3240>>2]=u+(H<<2);j=0;i=b;return j|0}}while(0);mJb(q);mJb(s);mJb(v);mJb(z);mJb(x);mJb(C);mJb(n);mJb(g);VHb(h);j=-12;i=b;return j|0}}while(0);KIb(a,16,2409952,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-22;i=b;return j|0}function R3a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0;j=i;i=i+136|0;k=j|0;l=j+64|0;m=j+104|0;n=c[e+60>>2]|0;o=n;p=c[h+24>>2]|0;q=c[h+28>>2]|0;h=q&-4;r=n+4|0;s=c[r>>2]|0;t=n+1272|0;u=t;A4a(t,n+1276|0,h);if((c[u>>2]|0)==0){KIb(e,16,2445288,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-12;i=j;return w|0}t=N4a(e,s)|0;if((t|0)<0){w=t;i=j;return w|0}ef[c[n+1124>>2]&4095](c[u>>2]|0,p,q>>2);q=c[u>>2]|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;if((p|0)==256){q=n;QIb(c[q>>2]|0,2429408,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;x=q}else if((p|0)==257){x=n}else{KIb(c[n>>2]|0,16,2418944,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v;w=-1094995529;i=j;return w|0}p=n+8|0;q=n+20|0;t=n+24|0;y=n+12|0;z=n+16|0;A=l|0;B=l+4|0;C=l+8|0;D=l+12|0;E=l+16|0;F=l+20|0;G=l+24|0;H=l+28|0;I=l+32|0;J=m+24|0;K=m+4|0;L=m|0;M=m+20|0;N=m+28|0;m=0;O=40;a:while(1){if((O|0)>=(h|0)){P=10;break}Q=c[u>>2]|0;R=Q+O|0;S=307664+(m<<2)|0;T=c[S>>2]|0;U=h-O|0;if((U|0)<4){P=12;break}V=Q+h|0;W=R;X=Q+(O+4)|0;Y=R;R=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;Y=je(R|0)|0;Z=(Y<<2)+4|0;if((R|0)==0){_=4}else{if(Y>>>0>536870909>>>0|(Z|0)>(U|0)){P=15;break}do{if((U-4|0)<4){$=X;aa=0}else{Y=Q+(O+8)|0;R=X;ba=je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0;if((ba&1|0)==0){$=Y;aa=ba;break}if((U-8|0)<4){$=Y;aa=ba;break}R=Q+(O+12)|0;da=Y;Y=d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0;da=je(Y|0)|0;if((Y|0)==128){if((U-12|0)<4){$=R;aa=ba;break}Y=R;ea=je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0;fa=Q+(O+16)|0}else{ea=da;fa=R}if((ea|0)<=0){$=fa;aa=ba;break}R=fa;da=R-W|0;if((Z|0)<=(da|0)){ga=-1094995529;ha=T;break a}Y=Q+(da+O)|0;ia=Z-da<<3;da=ia>>>0>2147483639>>>0|(Y|0)==0;ja=da?0:Y;Y=da?0:ia;c[p>>2]=ja;c[q>>2]=Y;ia=Y+8|0;c[t>>2]=ia;c[y>>2]=ja+(Y>>3);c[z>>2]=0;Y=ja;da=je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0;ka=da>>>23;Y=ia>>>0>9>>>0?9:ia;c[z>>2]=Y;la=ja+(Y>>>3)|0;ma=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(Y&1);na=ma>>>27;la=Y+5|0;Y=ia>>>0>la>>>0?la:ia;c[z>>2]=Y;if((ka-1|0)>>>0>63>>>0){P=44;break a}la=na-1|0;if(la>>>0>31>>>0){P=44;break a}if((ka|0)==0){oa=0;P=38}else{pa=1<<la;la=1<<na;qa=32-na|0;ra=na-16|0;sa=48-na|0;ta=da>>>0>16777215>>>0;do{if((na|0)==0){mrc(n+((T<<8)+1364)|0,0,(ta?ka<<2:4)|0)|0;ua=ta?ka:1}else{if(ma>>>0<3489660928>>>0){da=0;va=Y;wa=ia;xa=ja;while(1){ya=xa+(va>>>3)|0;za=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(va&7)>>>(qa>>>0);ya=va+na|0;c[z>>2]=wa>>>0>ya>>>0?ya:wa;if((za&pa|0)==0){c[o+1364+(T<<8)+(da<<2)>>2]=za}else{c[o+1364+(T<<8)+(da<<2)>>2]=za-la}za=da+1|0;if((za|0)>=(ka|0)){break}da=za;va=c[z>>2]|0;wa=c[t>>2]|0;xa=c[p>>2]|0}ua=ta?ka:1;break}else{xa=0;wa=Y;va=ia;da=ja;while(1){za=da+(wa>>>3)|0;ya=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(wa&7)>>>16;za=wa+16|0;Aa=va>>>0>za>>>0?za:va;c[z>>2]=Aa;za=da+(Aa>>>3)|0;Ba=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Aa&7)>>>(sa>>>0);za=Aa+ra|0;c[z>>2]=va>>>0>za>>>0?za:va;za=Ba|ya<<ra;if((za&pa|0)==0){c[o+1364+(T<<8)+(xa<<2)>>2]=za}else{c[o+1364+(T<<8)+(xa<<2)>>2]=za-la}za=xa+1|0;if((za|0)>=(ka|0)){break}xa=za;wa=c[z>>2]|0;va=c[t>>2]|0;da=c[p>>2]|0}ua=ta?ka:1;break}}}while(0);if((ua|0)<64){oa=ua;P=38}}if((P|0)==38){P=0;ta=oa<<2;mrc(n+((T<<8)+1364+ta)|0,0,256-ta|0)|0}ta=(c[z>>2]|0)+31>>5<<2;la=V-R|0;$=fa+(la>>>0>ta>>>0?ta:la)|0;aa=ba}}while(0);do{if((V-$|0)<4){Ca=$;P=49}else{U=$+4|0;X=$;if((d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)!=128){Ca=U;P=49;break}X=V-U|0;Da=$+(X>>>0>8>>>0?12:X+4|0)|0}}while(0);if((P|0)==49){P=0;X=V-Ca|0;Da=Ca+(X>>>0>4>>>0?4:X)|0}X=Da;U=X-W|0;if((Z|0)<=(U|0)){ga=-1094995529;ha=T;break}la=Q+(U+O)|0;ta=Z-U<<3;U=ta>>>0>2147483639>>>0|(la|0)==0;pa=U?0:la;la=U?0:ta;c[p>>2]=pa;c[q>>2]=la;ta=la+8|0;c[t>>2]=ta;c[y>>2]=pa+(la>>3);c[z>>2]=0;la=pa;Ea=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>3&31;la=ta>>>0>5>>>0?5:ta;c[z>>2]=la;c[A>>2]=Ea;U=pa+(la>>>3)|0;ra=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(la&5);Fa=ra>>>27;U=la+5|0;la=ta>>>0>U>>>0?U:ta;c[z>>2]=la;c[B>>2]=Fa;U=pa+(la>>>3)|0;sa=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(la&7)>>>27;U=la+5|0;la=ta>>>0>U>>>0?U:ta;c[z>>2]=la;c[C>>2]=sa;sa=pa+(la>>>3)|0;Ga=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(la&7)>>>15;sa=la+17|0;c[z>>2]=ta>>>0>sa>>>0?sa:ta;c[D>>2]=Ga;c[E>>2]=0;if((Ea-1|0)>>>0>31>>>0|ra>>>0>3489660927>>>0){P=52;break}if((Ga-1|0)>>>0>65535>>>0){P=54;break}if((Fa|0)==0){c[B>>2]=1}ra=(Ga+1|0)>>>1;c[F>>2]=ra;ta=qJb(ra,4)|0;c[G>>2]=ta;sa=qJb(ra,4)|0;c[H>>2]=sa;la=qJb(ra,4)|0;c[I>>2]=la;do{if((ta|0)==0){Ha=-12}else{if((sa|0)==0|(la|0)==0){Ha=-12;break}ra=U3a(o,0,0,l)|0;pa=c[E>>2]|0;U=c[F>>2]|0;if((pa|0)!=(U|0)){KIb(c[x>>2]|0,16,2529912,(v=i,i=i+16|0,c[v>>2]=pa,c[v+8>>2]=U,v)|0);i=v;Ha=-1094995529;break}if(!((ra|0)>-1)){Ha=ra;break}ra=$2(L,c[B>>2]|0,pa,c[I>>2]|0,4,4,c[H>>2]|0,4,4,0,0,0,0)|0;if((ra|0)<0){KIb(c[x>>2]|0,16,2514688,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;Ha=ra;break}c[M>>2]=c[B>>2];pa=c[F>>2]|0;c[N>>2]=pa;if(!(pa>>>0<536870911>>>0)){c[J>>2]=0;Ha=-12;break}U=hJb(pa<<2)|0;pa=U;c[J>>2]=pa;if((U|0)==0){Ha=-12;break}U=c[N>>2]|0;if((U|0)<=0){Ha=ra;break}ja=c[G>>2]|0;ia=0;while(1){c[pa+(ia<<2)>>2]=c[ja+(ia<<2)>>2];Y=ia+1|0;if((Y|0)<(U|0)){ia=Y}else{Ha=ra;break}}}}while(0);kJb(c[G>>2]|0);kJb(c[H>>2]|0);kJb(c[I>>2]|0);if((Ha|0)<0){ga=Ha;ha=T;break}la=(c[z>>2]|0)+31>>5<<2;sa=V-X|0;ta=sa>>>0>la>>>0?la:sa;sa=Da+ta|0;Ia=aa>>1;if(Ia>>>0>16777215>>>0){P=72;break}Ja=o+1280+(T<<2)|0;Ka=oJb(Ja,Ia,4)|0;La=o+1308+(T<<2)|0;if((Ka|0)<0){P=75;break}c[La>>2]=Ia;b:do{if((V-sa|0)<4){P=77}else{la=sa;if((je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<=0){P=77;break}la=Da+(ta+4)-W|0;if((Z|0)<=(la|0)){ga=-1094995529;ha=T;break a}ra=Q+(la+O)|0;ia=Z-la<<3;la=ia>>>0>2147483639>>>0|(ra|0)==0;U=la?0:ra;ra=la?0:ia;c[p>>2]=U;c[q>>2]=ra;c[t>>2]=ra+8;c[y>>2]=U+(ra>>3);c[z>>2]=0;ra=(m|0)!=6;Ma=0;while(1){if((Ma|0)>=(Ia|0)){break b}ia=c[z>>2]|0;if(((c[q>>2]|0)-ia|0)<1){P=86;break a}la=c[K>>2]|0;ja=c[M>>2]|0;pa=c[J>>2]|0;ba=c[t>>2]|0;R=U+(ia>>>3)|0;Y=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(ia&7)>>>((32-ja|0)>>>0);ja=b[la+(Y<<2)>>1]|0;R=(b[la+(Y<<2)+2>>1]|0)+ia|0;c[z>>2]=ba>>>0>R>>>0?R:ba;if(ja<<16>>16<0){P=88;break a}ba=c[pa+(ja<<16>>16<<2)>>2]|0;c[(c[Ja>>2]|0)+(Ma<<2)>>2]=ba;if(ra&(ba|0)>63){Na=ba;P=91;break a}if((ba|0)<0){Na=ba;P=91;break a}else{Ma=Ma+1|0}}}}while(0);c:do{if((P|0)==77){P=0;if((Ia|0)<=0){break}Q=c[J>>2]|0;W=c[Ja>>2]|0;if((m|0)==6){ta=0;while(1){c[W+(ta<<2)>>2]=c[Q>>2];ta=ta+1|0;if((ta|0)>=(Ia|0)){break c}}}else{Oa=0}while(1){Pa=c[Q>>2]|0;c[W+(Oa<<2)>>2]=Pa;if((Pa|0)>63){P=92;break a}ta=Oa+1|0;if((ta|0)<(Ia|0)){Oa=ta}else{break}}}}while(0);kJb(c[J>>2]|0);if((c[K>>2]|0)!=0){c3(L)}if((Z|0)<0){ga=Z;ha=T;break}else{_=Z}}W=m+1|0;if((W|0)<7){m=W;O=_+O|0}else{P=99;break}}do{if((P|0)==10){KIb(e,16,2356104,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=j;return w|0}else if((P|0)==12){KIb(c[x>>2]|0,16,2118840,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==15){KIb(c[x>>2]|0,16,2636992,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==44){KIb(c[x>>2]|0,16,2477176,(v=i,i=i+16|0,c[v>>2]=ka,c[v+8>>2]=na,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==52){KIb(c[x>>2]|0,16,2565816,(v=i,i=i+16|0,c[v>>2]=Ea,c[v+8>>2]=Fa,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==54){KIb(c[x>>2]|0,16,2547784,(v=i,i=i+8|0,c[v>>2]=Ga,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==72){KIb(c[x>>2]|0,16,2613680,(v=i,i=i+8|0,c[v>>2]=Ia,v)|0);i=v;kJb(c[J>>2]|0);if((c[K>>2]|0)==0){ga=-1094995529;ha=T;break}c3(L);ga=-1094995529;ha=T}else if((P|0)==75){c[La>>2]=0;ga=Ka;ha=T}else if((P|0)==86){KIb(c[x>>2]|0,16,2613680,(v=i,i=i+8|0,c[v>>2]=Ia,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==88){c[(c[Ja>>2]|0)+(Ma<<2)>>2]=-1;Na=-1;P=91}else if((P|0)==92){KIb(c[x>>2]|0,16,2586800,(v=i,i=i+24|0,c[v>>2]=Pa,c[v+8>>2]=T,c[v+16>>2]=Oa,v)|0);i=v;ga=-1094995529;ha=T}else if((P|0)==99){O=c[x>>2]|0;_=c[O+120>>2]|0;m=c[O+124>>2]|0;z=m>>2;t=n+1336|0;M=t;mrc(t|0,0,28)|0;t=_>>2;q=_>>1;y=n+1332|0;p=c[y>>2]|0;Da=ca(z,t)|0;do{if((p|0)<(Da|0)){KIb(O,16,2293408,(v=i,i=i+16|0,c[v>>2]=p,c[v+8>>2]=Da,v)|0);i=v;Qa=-1094995529}else{aa=n+3188|0;Ha=t<<4;mrc(c[aa>>2]|0,0,Ha|0)|0;I=n+3192|0;mrc(c[I>>2]|0,0,Ha|0)|0;if((z|0)>0){Ha=n+3156|0;H=(t|0)>0;G=n+1360|0;N=n+1304|0;F=k;B=n+3244|0;E=n+3248|0;l=n+3252|0;D=n+3232|0;C=n+3220|0;A=n+3240|0;Ca=n+3228|0;$=n+3236|0;fa=n+3224|0;oa=n+1340|0;ua=n+1312|0;ea=n+1284|0;u=k|0;W=k+12|0;Q=k+8|0;ta=k+4|0;sa=n+3172|0;V=n+3176|0;X=n+3180|0;ra=n+3184|0;U=n+1344|0;ba=n+1316|0;ja=n+1288|0;pa=n+1348|0;R=n+1320|0;ia=n+1292|0;Y=k+32|0;la=k+40|0;qa=Ha;ma=n+3160|0;da=n+3164|0;va=n+3168|0;wa=n+1352|0;xa=n+1324|0;za=n+1296|0;ya=n+1356|0;Ba=n+1328|0;Aa=n+1300|0;Ra=n+1308|0;Sa=n+1280|0;Ta=k+16|0;Ua=k+20|0;Va=k+24|0;Wa=k+28|0;Xa=1;Ya=0;while(1){mrc(Ha|0,0,32)|0;if(H){Za=Ya<<2;_a=Ya<<1;$a=_a|1;ab=-4-Za|0;bb=Za|3;cb=Xa;db=0;while(1){eb=c[G>>2]|0;fb=c[y>>2]|0;d:do{if((eb|0)<(fb|0)){c[G>>2]=eb+1;gb=c[(c[N>>2]|0)+(eb<<2)>>2]|0;switch(gb|0){case 3:{hb=c[B>>2]|0;ib=c[E>>2]|0;jb=(c[l>>2]|0)==0;kb=db<<2;lb=(c[(jb?C:D)>>2]|0)+((ca(hb,Za)|0)+kb<<2)|0;mb=c[(jb?Ca:A)>>2]|0;nb=(ca(ib,_a)|0)+(db<<1)|0;ob=c[(jb?fa:$)>>2]|0;jb=c[aa>>2]|0;pb=jb+(kb<<2)|0;qb=c[I>>2]|0;rb=qb+(kb<<2)|0;sb=(db|0)>0;mrc(F|0,0,16)|0;if(sb){tb=c[qb+(kb-3<<2)>>2]|0}else{tb=0}ub=c[sa>>2]|0;vb=c[V>>2]|0;wb=vb+ub|0;xb=wb>>1;yb=kb|1;zb=qb+(yb<<2)|0;Ab=tb-ub-vb+(c[zb>>2]|0)>>1;c[V>>2]=wb-xb;c[sa>>2]=xb;c[rb>>2]=Ab;xb=Ab+(c[sa>>2]|0)|0;c[rb>>2]=xb;c[ob+(nb<<2)>>2]=xb;xb=(c[zb>>2]|0)+(c[sa>>2]|0)|0;c[zb>>2]=xb;Ab=nb|1;c[ob+(Ab<<2)>>2]=xb;xb=nb+ib|0;wb=(c[rb>>2]|0)+(c[V>>2]|0)|0;c[rb>>2]=wb;c[ob+(xb<<2)>>2]=wb;wb=(c[zb>>2]|0)+(c[V>>2]|0)|0;c[zb>>2]=wb;zb=ib+1+nb|0;c[ob+(zb<<2)>>2]=wb;wb=kb|2;ob=qb+(wb<<2)|0;mrc(F|0,0,16)|0;if(sb){Bb=c[qb+(wb-3<<2)>>2]|0}else{Bb=0}ib=c[X>>2]|0;rb=c[ra>>2]|0;vb=rb+ib|0;ub=vb>>1;Cb=kb|3;Db=qb+(Cb<<2)|0;qb=Bb-ib-rb+(c[Db>>2]|0)>>1;c[ra>>2]=vb-ub;c[X>>2]=ub;c[ob>>2]=qb;ub=qb+(c[X>>2]|0)|0;c[ob>>2]=ub;c[mb+(nb<<2)>>2]=ub;ub=(c[Db>>2]|0)+(c[X>>2]|0)|0;c[Db>>2]=ub;c[mb+(Ab<<2)>>2]=ub;ub=(c[ob>>2]|0)+(c[ra>>2]|0)|0;c[ob>>2]=ub;c[mb+(xb<<2)>>2]=ub;ub=(c[Db>>2]|0)+(c[ra>>2]|0)|0;c[Db>>2]=ub;c[mb+(zb<<2)>>2]=ub;mrc(F|0,0,64)|0;ub=(c[ma>>2]|0)+(c[qa>>2]|0)+(c[da>>2]|0)+(c[va>>2]|0)|0;if(sb){Eb=(c[jb+(kb-1<<2)>>2]|0)-ub|0}else{Eb=0}kb=c[jb+(Cb<<2)>>2]|0;Cb=kb-Eb|0;sb=Cb>>2;c[pb>>2]=sb+Eb;c[jb+(yb<<2)>>2]=(Cb>>1)+Eb;c[jb+(wb<<2)>>2]=kb-sb;sb=ub>>2;c[qa>>2]=sb;kb=Eb+(ub>>1)|0;c[ma>>2]=kb-(Eb+sb);c[da>>2]=ub-sb+Eb-kb;c[va>>2]=sb;T3a(o,lb,hb,u,pb);Fb=cb;break d;break};case 5:{pb=c[B>>2]|0;hb=c[E>>2]|0;lb=(c[l>>2]|0)==0;sb=c[(lb?C:D)>>2]|0;kb=db<<2;ub=(ca(pb,Za)|0)+kb|0;wb=c[(lb?Ca:A)>>2]|0;jb=db<<1;Cb=(ca(hb,_a)|0)+jb|0;yb=c[(lb?fa:$)>>2]|0;zb=c[aa>>2]|0;mb=c[I>>2]|0;Db=c[(lb?D:C)>>2]|0;xb=c[(lb?A:Ca)>>2]|0;ob=c[(lb?$:fa)>>2]|0;lb=(ca(hb,$a)|0)+jb|0;c[yb+(Cb<<2)>>2]=c[ob+(Cb<<2)>>2];c[wb+(Cb<<2)>>2]=c[xb+(Cb<<2)>>2];jb=Cb|1;c[yb+(jb<<2)>>2]=c[ob+(jb<<2)>>2];c[wb+(jb<<2)>>2]=c[xb+(jb<<2)>>2];jb=Cb+hb|0;c[yb+(jb<<2)>>2]=c[ob+(jb<<2)>>2];c[wb+(jb<<2)>>2]=c[xb+(jb<<2)>>2];Cb=jb+1|0;c[yb+(Cb<<2)>>2]=c[ob+(Cb<<2)>>2];c[wb+(Cb<<2)>>2]=c[xb+(Cb<<2)>>2];Cb=Db+(ub<<2)|0;xb=hb<<1;ob=-xb|1;jb=ob+hb+lb|0;hb=yb+(jb<<2)|0;Ab=kb|1;nb=mb+(Ab<<2)|0;c[sa>>2]=(c[hb>>2]|0)-(c[nb>>2]|0);qb=lb+xb+ob|0;ob=yb+(qb<<2)|0;c[V>>2]=(c[ob>>2]|0)-(c[hb>>2]|0);c[mb+(kb<<2)>>2]=c[yb+(lb<<2)>>2];c[nb>>2]=c[ob>>2];ob=wb+(jb<<2)|0;jb=kb|2;nb=kb|3;yb=mb+(nb<<2)|0;c[X>>2]=(c[ob>>2]|0)-(c[yb>>2]|0);hb=wb+(qb<<2)|0;c[ra>>2]=(c[hb>>2]|0)-(c[ob>>2]|0);c[mb+(jb<<2)>>2]=c[wb+(lb<<2)>>2];c[yb>>2]=c[hb>>2];hb=ub|3;yb=Db+(hb<<2)|0;lb=zb+(nb<<2)|0;c[qa>>2]=(c[yb>>2]|0)-(c[lb>>2]|0);nb=Db+(pb+3+ub<<2)|0;c[ma>>2]=(c[nb>>2]|0)-(c[yb>>2]|0);wb=Db+((pb<<1)+3+ub<<2)|0;c[da>>2]=(c[wb>>2]|0)-(c[nb>>2]|0);c[va>>2]=(c[Db+((pb*3|0)+3+ub<<2)>>2]|0)-(c[wb>>2]|0);c[sb+(ub<<2)>>2]=c[Cb>>2];wb=zb+(kb<<2)|0;c[wb>>2]=c[Cb>>2];Cb=ub|1;kb=Db+(Cb<<2)|0;c[sb+(Cb<<2)>>2]=c[kb>>2];Cb=zb+(Ab<<2)|0;c[Cb>>2]=c[kb>>2];kb=ub|2;Ab=Db+(kb<<2)|0;c[sb+(kb<<2)>>2]=c[Ab>>2];kb=zb+(jb<<2)|0;c[kb>>2]=c[Ab>>2];c[sb+(hb<<2)>>2]=c[yb>>2];c[lb>>2]=c[yb>>2];yb=ub+pb|0;ub=Db+(yb<<2)|0;c[sb+(yb<<2)>>2]=c[ub>>2];c[wb>>2]=c[ub>>2];ub=yb+1|0;hb=Db+(ub<<2)|0;c[sb+(ub<<2)>>2]=c[hb>>2];c[Cb>>2]=c[hb>>2];hb=yb+2|0;ub=Db+(hb<<2)|0;c[sb+(hb<<2)>>2]=c[ub>>2];c[kb>>2]=c[ub>>2];ub=yb+3|0;hb=Db+(ub<<2)|0;c[sb+(ub<<2)>>2]=c[hb>>2];c[lb>>2]=c[hb>>2];hb=yb+pb|0;yb=Db+(hb<<2)|0;c[sb+(hb<<2)>>2]=c[yb>>2];c[wb>>2]=c[yb>>2];yb=hb+1|0;ub=Db+(yb<<2)|0;c[sb+(yb<<2)>>2]=c[ub>>2];c[Cb>>2]=c[ub>>2];ub=hb+2|0;yb=Db+(ub<<2)|0;c[sb+(ub<<2)>>2]=c[yb>>2];c[kb>>2]=c[yb>>2];yb=hb+3|0;ub=Db+(yb<<2)|0;c[sb+(yb<<2)>>2]=c[ub>>2];c[lb>>2]=c[ub>>2];ub=hb+pb|0;pb=Db+(ub<<2)|0;c[sb+(ub<<2)>>2]=c[pb>>2];c[wb>>2]=c[pb>>2];pb=ub+1|0;wb=Db+(pb<<2)|0;c[sb+(pb<<2)>>2]=c[wb>>2];c[Cb>>2]=c[wb>>2];wb=ub+2|0;Cb=Db+(wb<<2)|0;c[sb+(wb<<2)>>2]=c[Cb>>2];c[kb>>2]=c[Cb>>2];Cb=ub+3|0;ub=Db+(Cb<<2)|0;c[sb+(Cb<<2)>>2]=c[ub>>2];c[lb>>2]=c[ub>>2];Fb=0;break d;break};case 6:{ub=c[B>>2]|0;lb=c[E>>2]|0;Cb=(c[l>>2]|0)==0;sb=c[(Cb?C:D)>>2]|0;Db=db<<2;kb=(ca(ub,Za)|0)+Db|0;wb=sb+(kb<<2)|0;pb=c[(Cb?Ca:A)>>2]|0;hb=db<<1;yb=(ca(lb,_a)|0)+hb|0;Ab=pb+(yb<<2)|0;jb=c[(Cb?fa:$)>>2]|0;zb=jb+(yb<<2)|0;nb=c[aa>>2]|0;mb=c[I>>2]|0;ob=mb+(Db<<2)|0;qb=c[(Cb?D:C)>>2]|0;xb=c[(Cb?A:Ca)>>2]|0;vb=c[(Cb?$:fa)>>2]|0;Cb=c[ya>>2]|0;rb=c[Ba>>2]|0;do{if((Cb|0)<(rb|0)){ib=(c[Aa>>2]|0)+(Cb<<2)|0;Gb=c[ib>>2]|0;if((Gb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=Gb,v)|0);i=v;Hb=0;break}else{c[ya>>2]=Cb+1;Hb=c[o+2644+(c[ib>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=5,c[v+8>>2]=Cb,c[v+16>>2]=rb,v)|0);i=v;Hb=0}}while(0);rb=c[ya>>2]|0;Cb=c[Ba>>2]|0;do{if((rb|0)<(Cb|0)){ib=(c[Aa>>2]|0)+(rb<<2)|0;Gb=c[ib>>2]|0;if((Gb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=Gb,v)|0);i=v;Ib=0;break}else{c[ya>>2]=rb+1;Ib=c[o+2644+(c[ib>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=5,c[v+8>>2]=rb,c[v+16>>2]=Cb,v)|0);i=v;Ib=0}}while(0);Cb=-4-Db|0;rb=c[x>>2]|0;ib=c[rb+120>>2]|0;Gb=ib-Db|0;if((Hb|0)<(Cb|0)){Jb=Cb}else{Jb=(Hb|0)>(Gb|0)?Gb:Hb}Gb=c[rb+124>>2]|0;Cb=Gb-Za|0;if((Ib|0)<(ab|0)){Kb=ab}else{Kb=(Ib|0)>(Cb|0)?Cb:Ib}Cb=Jb+Db|0;do{if((Cb|0)>=0){Lb=Kb+Za|0;if((Lb|0)<0){break}if((Cb+4|0)>(ib|0)){break}if((Lb+4|0)>(Gb|0)){break}Lb=Jb+kb+(ca(Kb,ub)|0)|0;Mb=(Jb>>1)+yb+(ca(Kb>>1,lb)|0)|0;Nb=(ca(lb,$a)|0)+hb|0;c[zb>>2]=c[vb+(Mb<<2)>>2];c[Ab>>2]=c[xb+(Mb<<2)>>2];Ob=Mb+1|0;Pb=yb|1;c[jb+(Pb<<2)>>2]=c[vb+(Ob<<2)>>2];c[pb+(Pb<<2)>>2]=c[xb+(Ob<<2)>>2];Ob=yb+lb|0;Pb=Mb+lb|0;c[jb+(Ob<<2)>>2]=c[vb+(Pb<<2)>>2];c[pb+(Ob<<2)>>2]=c[xb+(Pb<<2)>>2];Mb=Pb+1|0;Pb=Ob+1|0;c[jb+(Pb<<2)>>2]=c[vb+(Mb<<2)>>2];c[pb+(Pb<<2)>>2]=c[xb+(Mb<<2)>>2];Mb=lb<<1;Pb=-Mb|1;Ob=Pb+lb+Nb|0;Qb=jb+(Ob<<2)|0;Rb=Db|1;Sb=mb+(Rb<<2)|0;c[sa>>2]=(c[Qb>>2]|0)-(c[Sb>>2]|0);Tb=Nb+Mb+Pb|0;Pb=jb+(Tb<<2)|0;c[V>>2]=(c[Pb>>2]|0)-(c[Qb>>2]|0);c[ob>>2]=c[jb+(Nb<<2)>>2];c[Sb>>2]=c[Pb>>2];Pb=pb+(Ob<<2)|0;Ob=Db|2;Sb=Db|3;Qb=mb+(Sb<<2)|0;c[X>>2]=(c[Pb>>2]|0)-(c[Qb>>2]|0);Mb=pb+(Tb<<2)|0;c[ra>>2]=(c[Mb>>2]|0)-(c[Pb>>2]|0);c[mb+(Ob<<2)>>2]=c[pb+(Nb<<2)>>2];c[Qb>>2]=c[Mb>>2];Mb=(ca(ub,bb)|0)+Db|0;c[wb>>2]=c[qb+(Lb<<2)>>2];c[sb+((kb|1)<<2)>>2]=c[qb+(Lb+1<<2)>>2];c[sb+((kb|2)<<2)>>2]=c[qb+(Lb+2<<2)>>2];c[sb+((kb|3)<<2)>>2]=c[qb+(Lb+3<<2)>>2];Qb=kb+ub|0;Nb=Lb+ub|0;c[sb+(Qb<<2)>>2]=c[qb+(Nb<<2)>>2];c[sb+(Qb+1<<2)>>2]=c[qb+(Nb+1<<2)>>2];c[sb+(Qb+2<<2)>>2]=c[qb+(Nb+2<<2)>>2];c[sb+(Qb+3<<2)>>2]=c[qb+(Nb+3<<2)>>2];Lb=Qb+ub|0;Qb=Nb+ub|0;c[sb+(Lb<<2)>>2]=c[qb+(Qb<<2)>>2];c[sb+(Lb+1<<2)>>2]=c[qb+(Qb+1<<2)>>2];c[sb+(Lb+2<<2)>>2]=c[qb+(Qb+2<<2)>>2];c[sb+(Lb+3<<2)>>2]=c[qb+(Qb+3<<2)>>2];Nb=Lb+ub|0;Lb=Qb+ub|0;c[sb+(Nb<<2)>>2]=c[qb+(Lb<<2)>>2];c[sb+(Nb+1<<2)>>2]=c[qb+(Lb+1<<2)>>2];c[sb+(Nb+2<<2)>>2]=c[qb+(Lb+2<<2)>>2];c[sb+(Nb+3<<2)>>2]=c[qb+(Lb+3<<2)>>2];Lb=ub<<2;Nb=-Lb|3;Qb=sb+(Nb+ub+Mb<<2)|0;Pb=nb+(Sb<<2)|0;c[qa>>2]=(c[Qb>>2]|0)-(c[Pb>>2]|0);Sb=ub<<1;Tb=sb+(Mb+Sb+Nb<<2)|0;c[ma>>2]=(c[Tb>>2]|0)-(c[Qb>>2]|0);Qb=ub+3|0;Nb=sb+(Qb+Sb-Lb+Mb<<2)|0;c[da>>2]=(c[Nb>>2]|0)-(c[Tb>>2]|0);Tb=ub*3|0;c[va>>2]=(c[sb+(Qb+Tb-Lb+Mb<<2)>>2]|0)-(c[Nb>>2]|0);Nb=Tb-Lb|0;c[nb+(Db<<2)>>2]=c[sb+(Nb+ub+Mb<<2)>>2];c[nb+(Rb<<2)>>2]=c[sb+(ub+1+Nb+Mb<<2)>>2];c[nb+(Ob<<2)>>2]=c[sb+(ub+2+Nb+Mb<<2)>>2];c[Pb>>2]=c[sb+(Nb+Qb+Mb<<2)>>2];Fb=0;break d}}while(0);KIb(rb,16,2201080,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;Fb=0;break d;break};case 4:{sb=c[B>>2]|0;ub=c[E>>2]|0;nb=(c[l>>2]|0)==0;Db=c[(nb?C:D)>>2]|0;qb=c[(nb?Ca:A)>>2]|0;kb=db<<1;wb=(ca(ub,_a)|0)+kb|0;pb=c[(nb?fa:$)>>2]|0;mb=c[aa>>2]|0;jb=c[I>>2]|0;ob=c[(nb?D:C)>>2]|0;lb=(c[(nb?A:Ca)>>2]|0)+(wb<<2)|0;xb=(c[(nb?$:fa)>>2]|0)+(wb<<2)|0;nb=pb+(wb<<2)|0;vb=qb+(wb<<2)|0;wb=0;while(1){yb=c[xb>>2]|0;Ab=c[wa>>2]|0;zb=c[xa>>2]|0;do{if((Ab|0)<(zb|0)){hb=(c[za>>2]|0)+(Ab<<2)|0;Gb=c[hb>>2]|0;if((Gb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=Gb,v)|0);i=v;Ub=0;break}else{c[wa>>2]=Ab+1;Ub=c[o+2388+(c[hb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=Ab,c[v+16>>2]=zb,v)|0);i=v;Ub=0}}while(0);c[nb>>2]=Ub+yb;zb=c[lb>>2]|0;Ab=c[wa>>2]|0;hb=c[xa>>2]|0;do{if((Ab|0)<(hb|0)){Gb=(c[za>>2]|0)+(Ab<<2)|0;ib=c[Gb>>2]|0;if((ib|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=ib,v)|0);i=v;Vb=0;break}else{c[wa>>2]=Ab+1;Vb=c[o+2388+(c[Gb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=Ab,c[v+16>>2]=hb,v)|0);i=v;Vb=0}}while(0);c[vb>>2]=Vb+zb;hb=c[xb+4>>2]|0;Ab=c[wa>>2]|0;yb=c[xa>>2]|0;do{if((Ab|0)<(yb|0)){Gb=(c[za>>2]|0)+(Ab<<2)|0;ib=c[Gb>>2]|0;if((ib|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=ib,v)|0);i=v;Wb=0;break}else{c[wa>>2]=Ab+1;Wb=c[o+2388+(c[Gb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=Ab,c[v+16>>2]=yb,v)|0);i=v;Wb=0}}while(0);c[nb+4>>2]=Wb+hb;yb=c[lb+4>>2]|0;Ab=c[wa>>2]|0;zb=c[xa>>2]|0;do{if((Ab|0)<(zb|0)){Gb=(c[za>>2]|0)+(Ab<<2)|0;ib=c[Gb>>2]|0;if((ib|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=ib,v)|0);i=v;Xb=0;break}else{c[wa>>2]=Ab+1;Xb=c[o+2388+(c[Gb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=Ab,c[v+16>>2]=zb,v)|0);i=v;Xb=0}}while(0);c[vb+4>>2]=Xb+yb;zb=wb+1|0;if((zb|0)<2){lb=lb+(ub<<2)|0;xb=xb+(ub<<2)|0;nb=nb+(ub<<2)|0;vb=vb+(ub<<2)|0;wb=zb}else{break}}wb=db<<2;vb=(ca(sb,Za)|0)+wb|0;nb=(ca(ub,$a)|0)+kb|0;xb=ub<<1;lb=-xb|1;rb=lb+ub+nb|0;zb=pb+(rb<<2)|0;Ab=jb+((wb|1)<<2)|0;c[sa>>2]=(c[zb>>2]|0)-(c[Ab>>2]|0);hb=nb+xb+lb|0;lb=pb+(hb<<2)|0;c[V>>2]=(c[lb>>2]|0)-(c[zb>>2]|0);c[jb+(wb<<2)>>2]=c[pb+(nb<<2)>>2];c[Ab>>2]=c[lb>>2];lb=qb+(rb<<2)|0;rb=wb|3;Ab=jb+(rb<<2)|0;c[X>>2]=(c[lb>>2]|0)-(c[Ab>>2]|0);zb=qb+(hb<<2)|0;c[ra>>2]=(c[zb>>2]|0)-(c[lb>>2]|0);c[jb+((wb|2)<<2)>>2]=c[qb+(nb<<2)>>2];c[Ab>>2]=c[zb>>2];zb=ob+((vb|3)<<2)|0;Ab=mb+(rb<<2)|0;c[qa>>2]=(c[zb>>2]|0)-(c[Ab>>2]|0);rb=ob+(sb+3+vb<<2)|0;c[ma>>2]=(c[rb>>2]|0)-(c[zb>>2]|0);zb=ob+((sb<<1)+3+vb<<2)|0;c[da>>2]=(c[zb>>2]|0)-(c[rb>>2]|0);c[va>>2]=(c[ob+((sb*3|0)+3+vb<<2)>>2]|0)-(c[zb>>2]|0);zb=Db+(vb<<2)|0;rb=ob+(vb<<2)|0;vb=0;while(1){nb=c[Ab>>2]|0;lb=0;do{hb=c[rb+(lb<<2)>>2]|0;xb=c[wa>>2]|0;Gb=c[xa>>2]|0;do{if((xb|0)<(Gb|0)){ib=(c[za>>2]|0)+(xb<<2)|0;Cb=c[ib>>2]|0;if((Cb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=Cb,v)|0);i=v;Yb=0;break}else{c[wa>>2]=xb+1;Yb=c[o+2388+(c[ib>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=4,c[v+8>>2]=xb,c[v+16>>2]=Gb,v)|0);i=v;Yb=0}}while(0);Gb=Yb+hb|0;c[zb+(lb<<2)>>2]=Gb;c[mb+(lb+wb<<2)>>2]=Gb;lb=lb+1|0;}while((lb|0)<4);c[o+3156+(vb<<2)>>2]=(c[Ab>>2]|0)-nb;lb=vb+1|0;if((lb|0)<4){zb=zb+(sb<<2)|0;rb=rb+(sb<<2)|0;vb=lb}else{Fb=0;break}}break};case 0:{P=109;break d;break};case 1:{vb=c[B>>2]|0;sb=c[E>>2]|0;rb=(c[l>>2]|0)==0;zb=db<<2;Ab=(c[(rb?C:D)>>2]|0)+((ca(vb,Za)|0)+zb<<2)|0;wb=c[(rb?Ca:A)>>2]|0;mb=(ca(sb,_a)|0)+(db<<1)|0;ob=wb+(mb<<2)|0;Db=c[(rb?fa:$)>>2]|0;rb=Db+(mb<<2)|0;qb=(c[aa>>2]|0)+(zb<<2)|0;jb=c[I>>2]|0;pb=jb+(zb<<2)|0;ub=c[oa>>2]|0;kb=c[ua>>2]|0;do{if((ub|0)<(kb|0)){lb=(c[ea>>2]|0)+(ub<<2)|0;yb=c[lb>>2]|0;if((yb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=yb,v)|0);i=v;Zb=0;break}else{c[oa>>2]=ub+1;Zb=c[o+1620+(c[lb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=1,c[v+8>>2]=ub,c[v+16>>2]=kb,v)|0);i=v;Zb=0}}while(0);c[u>>2]=Zb;c[W>>2]=0;c[Q>>2]=0;c[ta>>2]=0;kb=(db|0)>0;if(kb){_b=c[jb+(zb-3<<2)>>2]|0}else{_b=0}ub=c[sa>>2]|0;lb=c[V>>2]|0;yb=lb+ub|0;Gb=yb>>1;xb=jb+((zb|1)<<2)|0;ib=_b-ub-lb+(c[xb>>2]|0)>>1;c[V>>2]=yb-Gb;c[sa>>2]=Gb;c[pb>>2]=ib;ib=(c[sa>>2]|0)+Zb|0;c[sa>>2]=ib;Gb=(c[pb>>2]|0)+ib|0;c[pb>>2]=Gb;c[rb>>2]=Gb;Gb=(c[xb>>2]|0)+(c[sa>>2]|0)|0;c[xb>>2]=Gb;ib=mb|1;c[Db+(ib<<2)>>2]=Gb;Gb=mb+sb|0;yb=(c[pb>>2]|0)+(c[V>>2]|0)|0;c[pb>>2]=yb;c[Db+(Gb<<2)>>2]=yb;yb=(c[xb>>2]|0)+(c[V>>2]|0)|0;c[xb>>2]=yb;xb=sb+1+mb|0;c[Db+(xb<<2)>>2]=yb;yb=c[oa>>2]|0;lb=c[ua>>2]|0;do{if((yb|0)<(lb|0)){ub=(c[ea>>2]|0)+(yb<<2)|0;Cb=c[ub>>2]|0;if((Cb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=Cb,v)|0);i=v;$b=0;break}else{c[oa>>2]=yb+1;$b=c[o+1620+(c[ub>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=1,c[v+8>>2]=yb,c[v+16>>2]=lb,v)|0);i=v;$b=0}}while(0);c[u>>2]=$b;c[W>>2]=0;c[Q>>2]=0;c[ta>>2]=0;lb=zb|2;yb=jb+(lb<<2)|0;if(kb){ac=c[jb+(lb-3<<2)>>2]|0}else{ac=0}lb=c[X>>2]|0;Db=c[ra>>2]|0;mb=Db+lb|0;sb=mb>>1;pb=jb+((zb|3)<<2)|0;rb=ac-lb-Db+(c[pb>>2]|0)>>1;c[ra>>2]=mb-sb;c[X>>2]=sb;c[yb>>2]=rb;rb=(c[X>>2]|0)+$b|0;c[X>>2]=rb;sb=(c[yb>>2]|0)+rb|0;c[yb>>2]=sb;c[ob>>2]=sb;sb=(c[pb>>2]|0)+(c[X>>2]|0)|0;c[pb>>2]=sb;c[wb+(ib<<2)>>2]=sb;sb=(c[yb>>2]|0)+(c[ra>>2]|0)|0;c[yb>>2]=sb;c[wb+(Gb<<2)>>2]=sb;sb=(c[pb>>2]|0)+(c[ra>>2]|0)|0;c[pb>>2]=sb;c[wb+(xb<<2)>>2]=sb;sb=0;do{pb=c[U>>2]|0;yb=c[ba>>2]|0;do{if((pb|0)<(yb|0)){rb=(c[ja>>2]|0)+(pb<<2)|0;mb=c[rb>>2]|0;if((mb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=mb,v)|0);i=v;bc=0;break}else{c[U>>2]=pb+1;bc=c[o+1876+(c[rb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=2,c[v+8>>2]=pb,c[v+16>>2]=yb,v)|0);i=v;bc=0}}while(0);c[k+(sb<<2)>>2]=bc;sb=sb+1|0;}while((sb|0)<16);T3a(o,Ab,vb,u,qb);Fb=cb;break d;break};case 2:{sb=c[B>>2]|0;xb=c[E>>2]|0;wb=(c[l>>2]|0)==0;Gb=db<<2;ib=(c[(wb?C:D)>>2]|0)+((ca(sb,Za)|0)+Gb<<2)|0;ob=c[(wb?Ca:A)>>2]|0;zb=(ca(xb,_a)|0)+(db<<1)|0;jb=ob+(zb<<2)|0;kb=c[(wb?fa:$)>>2]|0;wb=kb+(zb<<2)|0;yb=c[aa>>2]|0;pb=yb+(Gb<<2)|0;nb=c[I>>2]|0;rb=nb+(Gb<<2)|0;mb=c[oa>>2]|0;Db=c[ua>>2]|0;do{if((mb|0)<(Db|0)){lb=(c[ea>>2]|0)+(mb<<2)|0;ub=c[lb>>2]|0;if((ub|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=ub,v)|0);i=v;cc=0;break}else{c[oa>>2]=mb+1;cc=c[o+1620+(c[lb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=1,c[v+8>>2]=mb,c[v+16>>2]=Db,v)|0);i=v;cc=0}}while(0);c[u>>2]=cc;c[W>>2]=0;c[Q>>2]=0;c[ta>>2]=0;Db=(db|0)>0;if(Db){dc=c[nb+(Gb-3<<2)>>2]|0}else{dc=0}mb=c[sa>>2]|0;qb=c[V>>2]|0;vb=qb+mb|0;Ab=vb>>1;lb=Gb|1;ub=nb+(lb<<2)|0;Cb=dc-mb-qb+(c[ub>>2]|0)>>1;c[V>>2]=vb-Ab;c[sa>>2]=Ab;c[rb>>2]=Cb;Cb=(c[sa>>2]|0)+cc|0;c[sa>>2]=Cb;Ab=(c[rb>>2]|0)+Cb|0;c[rb>>2]=Ab;c[wb>>2]=Ab;Ab=(c[ub>>2]|0)+(c[sa>>2]|0)|0;c[ub>>2]=Ab;Cb=zb|1;c[kb+(Cb<<2)>>2]=Ab;Ab=zb+xb|0;vb=(c[rb>>2]|0)+(c[V>>2]|0)|0;c[rb>>2]=vb;c[kb+(Ab<<2)>>2]=vb;vb=(c[ub>>2]|0)+(c[V>>2]|0)|0;c[ub>>2]=vb;ub=xb+1+zb|0;c[kb+(ub<<2)>>2]=vb;vb=c[oa>>2]|0;qb=c[ua>>2]|0;do{if((vb|0)<(qb|0)){mb=(c[ea>>2]|0)+(vb<<2)|0;Mb=c[mb>>2]|0;if((Mb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=Mb,v)|0);i=v;ec=0;break}else{c[oa>>2]=vb+1;ec=c[o+1620+(c[mb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=1,c[v+8>>2]=vb,c[v+16>>2]=qb,v)|0);i=v;ec=0}}while(0);c[u>>2]=ec;c[W>>2]=0;c[Q>>2]=0;c[ta>>2]=0;qb=Gb|2;vb=nb+(qb<<2)|0;if(Db){fc=c[nb+(qb-3<<2)>>2]|0}else{fc=0}kb=c[X>>2]|0;zb=c[ra>>2]|0;xb=zb+kb|0;rb=xb>>1;wb=Gb|3;mb=nb+(wb<<2)|0;Mb=fc-kb-zb+(c[mb>>2]|0)>>1;c[ra>>2]=xb-rb;c[X>>2]=rb;c[vb>>2]=Mb;Mb=(c[X>>2]|0)+ec|0;c[X>>2]=Mb;rb=(c[vb>>2]|0)+Mb|0;c[vb>>2]=rb;c[jb>>2]=rb;rb=(c[mb>>2]|0)+(c[X>>2]|0)|0;c[mb>>2]=rb;c[ob+(Cb<<2)>>2]=rb;rb=(c[vb>>2]|0)+(c[ra>>2]|0)|0;c[vb>>2]=rb;c[ob+(Ab<<2)>>2]=rb;rb=(c[mb>>2]|0)+(c[ra>>2]|0)|0;c[mb>>2]=rb;c[ob+(ub<<2)>>2]=rb;mrc(F|0,0,64)|0;rb=c[pa>>2]|0;mb=c[R>>2]|0;do{if((rb|0)<(mb|0)){vb=(c[ia>>2]|0)+(rb<<2)|0;Mb=c[vb>>2]|0;if((Mb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=Mb,v)|0);i=v;gc=0;break}else{c[pa>>2]=rb+1;gc=c[o+2132+(c[vb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=3,c[v+8>>2]=rb,c[v+16>>2]=mb,v)|0);i=v;gc=0}}while(0);c[u>>2]=gc;mb=c[pa>>2]|0;rb=c[R>>2]|0;do{if((mb|0)<(rb|0)){ub=(c[ia>>2]|0)+(mb<<2)|0;ob=c[ub>>2]|0;if((ob|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=ob,v)|0);i=v;hc=0;break}else{c[pa>>2]=mb+1;hc=c[o+2132+(c[ub>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=3,c[v+8>>2]=mb,c[v+16>>2]=rb,v)|0);i=v;hc=0}}while(0);c[Q>>2]=hc;rb=c[pa>>2]|0;mb=c[R>>2]|0;do{if((rb|0)<(mb|0)){ub=(c[ia>>2]|0)+(rb<<2)|0;ob=c[ub>>2]|0;if((ob|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=ob,v)|0);i=v;ic=0;break}else{c[pa>>2]=rb+1;ic=c[o+2132+(c[ub>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=3,c[v+8>>2]=rb,c[v+16>>2]=mb,v)|0);i=v;ic=0}}while(0);c[Y>>2]=ic;mb=c[pa>>2]|0;rb=c[R>>2]|0;do{if((mb|0)<(rb|0)){ub=(c[ia>>2]|0)+(mb<<2)|0;ob=c[ub>>2]|0;if((ob|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=ob,v)|0);i=v;jc=0;break}else{c[pa>>2]=mb+1;jc=c[o+2132+(c[ub>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=3,c[v+8>>2]=mb,c[v+16>>2]=rb,v)|0);i=v;jc=0}}while(0);c[la>>2]=jc;if(Db){rb=c[yb+(lb<<2)>>2]|0;kc=(c[yb+(Gb-1<<2)>>2]|0)-(c[qa>>2]|0)-(c[ma>>2]|0)-(c[da>>2]|0)-(c[va>>2]|0)+rb|0;lc=rb}else{rb=c[yb+(lb<<2)>>2]|0;kc=rb-(c[qa>>2]|0)-(c[ma>>2]|0)-(c[da>>2]|0)-(c[va>>2]|0)|0;lc=rb}c[pb>>2]=kc>>1;c[yb+(qb<<2)>>2]=(c[yb+(wb<<2)>>2]|0)+lc>>1;rb=(c[ma>>2]|0)+(c[qa>>2]|0)|0;mb=rb>>1;c[qa>>2]=mb;c[ma>>2]=rb-mb;mb=(c[va>>2]|0)+(c[da>>2]|0)|0;rb=mb>>1;c[da>>2]=rb;c[va>>2]=mb-rb;T3a(o,ib,sb,u,pb);Fb=cb;break d;break};default:{KIb(c[x>>2]|0,16,2242312,(v=i,i=i+8|0,c[v>>2]=gb,v)|0);i=v;Fb=cb;break d}}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=6,c[v+8>>2]=eb,c[v+16>>2]=fb,v)|0);i=v;P=109}}while(0);if((P|0)==109){P=0;fb=c[B>>2]|0;eb=c[E>>2]|0;rb=(c[l>>2]|0)==0;mb=c[(rb?C:D)>>2]|0;ub=c[(rb?Ca:A)>>2]|0;ob=c[(rb?fa:$)>>2]|0;rb=c[aa>>2]|0;Ab=c[I>>2]|0;Cb=0;do{jb=c[M>>2]|0;nb=c[Ra>>2]|0;do{if((jb|0)<(nb|0)){vb=(c[Sa>>2]|0)+(jb<<2)|0;Mb=c[vb>>2]|0;if((Mb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=Mb,v)|0);i=v;mc=0;break}else{c[M>>2]=jb+1;mc=c[o+1364+(c[vb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=0,c[v+8>>2]=jb,c[v+16>>2]=nb,v)|0);i=v;mc=0}}while(0);c[k+(Cb<<2)>>2]=mc;nb=c[M>>2]|0;jb=c[Ra>>2]|0;do{if((nb|0)<(jb|0)){gb=(c[Sa>>2]|0)+(nb<<2)|0;pb=c[gb>>2]|0;if((pb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=pb,v)|0);i=v;nc=0;break}else{c[M>>2]=nb+1;nc=c[o+1364+(c[gb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=0,c[v+8>>2]=nb,c[v+16>>2]=jb,v)|0);i=v;nc=0}}while(0);c[k+(Cb+4<<2)>>2]=nc;Cb=Cb+1|0;}while((Cb|0)<4);Cb=db<<2;jb=(ca(eb,_a)|0)+(db<<1)|0;nb=Ab+(Cb<<2)|0;gb=(c[sa>>2]|0)+(c[u>>2]|0)|0;c[sa>>2]=gb;pb=(c[nb>>2]|0)+gb|0;c[nb>>2]=pb;c[ob+(jb<<2)>>2]=pb;pb=(c[sa>>2]|0)+(c[ta>>2]|0)|0;c[sa>>2]=pb;gb=Ab+((Cb|1)<<2)|0;sb=(c[gb>>2]|0)+pb|0;c[gb>>2]=sb;pb=jb|1;c[ob+(pb<<2)>>2]=sb;sb=jb+eb|0;ib=(c[V>>2]|0)+(c[Q>>2]|0)|0;c[V>>2]=ib;wb=(c[nb>>2]|0)+ib|0;c[nb>>2]=wb;c[ob+(sb<<2)>>2]=wb;wb=(c[V>>2]|0)+(c[W>>2]|0)|0;c[V>>2]=wb;nb=(c[gb>>2]|0)+wb|0;c[gb>>2]=nb;gb=eb+1+jb|0;c[ob+(gb<<2)>>2]=nb;nb=Ab+((Cb|2)<<2)|0;wb=(c[X>>2]|0)+(c[Ta>>2]|0)|0;c[X>>2]=wb;ib=(c[nb>>2]|0)+wb|0;c[nb>>2]=ib;c[ub+(jb<<2)>>2]=ib;ib=(c[X>>2]|0)+(c[Ua>>2]|0)|0;c[X>>2]=ib;jb=Ab+((Cb|3)<<2)|0;wb=(c[jb>>2]|0)+ib|0;c[jb>>2]=wb;c[ub+(pb<<2)>>2]=wb;wb=(c[ra>>2]|0)+(c[Va>>2]|0)|0;c[ra>>2]=wb;pb=(c[nb>>2]|0)+wb|0;c[nb>>2]=pb;c[ub+(sb<<2)>>2]=pb;pb=(c[ra>>2]|0)+(c[Wa>>2]|0)|0;c[ra>>2]=pb;sb=(c[jb>>2]|0)+pb|0;c[jb>>2]=sb;c[ub+(gb<<2)>>2]=sb;sb=0;do{gb=c[U>>2]|0;jb=c[ba>>2]|0;do{if((gb|0)<(jb|0)){pb=(c[ja>>2]|0)+(gb<<2)|0;nb=c[pb>>2]|0;if((nb|0)>63){KIb(c[x>>2]|0,16,2142392,(v=i,i=i+8|0,c[v>>2]=nb,v)|0);i=v;oc=0;break}else{c[U>>2]=gb+1;oc=c[o+1876+(c[pb>>2]<<2)>>2]|0;break}}else{KIb(c[x>>2]|0,16,2169304,(v=i,i=i+24|0,c[v>>2]=2,c[v+8>>2]=gb,c[v+16>>2]=jb,v)|0);i=v;oc=0}}while(0);c[k+(sb<<2)>>2]=oc;sb=sb+1|0;}while((sb|0)<16);T3a(o,mb+((ca(fb,Za)|0)+Cb<<2)|0,fb,u,rb+(Cb<<2)|0);Fb=cb}sb=db+1|0;if((sb|0)<(t|0)){cb=Fb;db=sb}else{pc=Fb;break}}}else{pc=Xa}db=Ya+1|0;if((db|0)<(z|0)){Xa=pc;Ya=db}else{qc=pc;rc=l;break}}}else{qc=1;rc=n+3252|0}l=(c[rc>>2]|0)==0;if((m|0)<=0){Qa=qc;break}Ya=(_|0)>0;Xa=_-1|0;u=_+1|0;U=_+2|0;ja=_+3|0;ba=n+3244|0;ra=s+32|0;Wa=m-1|0;Va=q-1|0;X=q+1|0;Ua=n+3248|0;Ta=c[(l?n+3220|0:n+3232|0)>>2]|0;V=c[(l?n+3224|0:n+3236|0)>>2]|0;W=c[(l?n+3228|0:n+3240|0)>>2]|0;l=c[s>>2]|0;Q=0;while(1){if(Ya){sa=0;do{ta=c[Ta+(sa<<2)>>2]|0;Sa=sa>>1;Ra=c[V+(Sa<<2)>>2]|0;I=(c[W+(Sa<<2)>>2]|0)+ta|0;if(I>>>0>255>>>0){sc=-I>>31&255}else{sc=I&255}I=sa*3|0;a[l+I|0]=sc;if(ta>>>0>255>>>0){tc=-ta>>31&255}else{tc=ta&255}a[l+(I+1)|0]=tc;Sa=Ra+ta|0;if(Sa>>>0>255>>>0){uc=-Sa>>31&255}else{uc=Sa&255}a[l+(I+2)|0]=uc;sa=sa+1|0;}while((sa|0)<(_|0))}sa=c[Ta>>2]|0;c[Ta-4>>2]=sa;c[Ta-8>>2]=sa;c[Ta-12>>2]=sa;I=Ta-16|0;c[I>>2]=sa;sa=c[Ta+(Xa<<2)>>2]|0;c[Ta+(_<<2)>>2]=sa;c[Ta+(u<<2)>>2]=sa;c[Ta+(U<<2)>>2]=sa;c[Ta+(ja<<2)>>2]=sa;do{if((Q|0)==0){sa=c[ba>>2]|0;Sa=I;nrc(Ta+(-4-sa<<2)|0,Sa|0,sa)|0;sa=c[ba>>2]|0;nrc(Ta+(-4-(sa<<1)<<2)|0,Sa|0,sa)|0;sa=c[ba>>2]|0;nrc(Ta+((sa*-3|0)-4<<2)|0,Sa|0,sa)|0;sa=c[ba>>2]|0;nrc(Ta+(-4-(sa<<2)<<2)|0,Sa|0,sa)|0;vc=W;wc=V;xc=Ta+(c[ba>>2]<<2)|0}else{sa=(Q|0)==(Wa|0);if(sa){Sa=c[ba>>2]|0;ta=I;nrc(Ta+(Sa-4<<2)|0,ta|0,Sa)|0;Sa=c[ba>>2]|0;nrc(Ta+((Sa<<1)-4<<2)|0,ta|0,Sa)|0;Sa=c[ba>>2]|0;nrc(Ta+((Sa*3|0)-4<<2)|0,ta|0,Sa)|0;Sa=c[ba>>2]|0;nrc(Ta+((Sa<<2)-4<<2)|0,ta|0,Sa)|0}Sa=Ta+(c[ba>>2]<<2)|0;if((Q&1|0)==0){vc=W;wc=V;xc=Sa;break}ta=c[V>>2]|0;c[V-4>>2]=ta;Ra=V-8|0;c[Ra>>2]=ta;ta=c[W>>2]|0;c[W-4>>2]=ta;aa=W-8|0;c[aa>>2]=ta;ta=c[V+(Va<<2)>>2]|0;c[V+(q<<2)>>2]=ta;c[V+(X<<2)>>2]=ta;ta=c[W+(Va<<2)>>2]|0;c[W+(q<<2)>>2]=ta;c[W+(X<<2)>>2]=ta;do{if((Q|0)==1){ta=c[Ua>>2]|0;$=Ra;nrc(V+(-2-ta<<2)|0,$|0,ta)|0;ta=c[Ua>>2]|0;fa=aa;nrc(W+(-2-ta<<2)|0,fa|0,ta)|0;ta=c[Ua>>2]|0;nrc(V+(-2-(ta<<1)<<2)|0,$|0,ta)|0;ta=c[Ua>>2]|0;nrc(W+(-2-(ta<<1)<<2)|0,fa|0,ta)|0}else{if(!sa){break}ta=c[Ua>>2]|0;fa=Ra;nrc(V+(ta-2<<2)|0,fa|0,ta)|0;ta=c[Ua>>2]|0;$=aa;nrc(W+(ta-2<<2)|0,$|0,ta)|0;ta=c[Ua>>2]|0;nrc(V+((ta<<1)-2<<2)|0,fa|0,ta)|0;ta=c[Ua>>2]|0;nrc(W+((ta<<1)-2<<2)|0,$|0,ta)|0}}while(0);aa=c[Ua>>2]|0;vc=W+(aa<<2)|0;wc=V+(aa<<2)|0;xc=Sa}}while(0);I=Q+1|0;if((I|0)<(m|0)){Ta=xc;V=wc;W=vc;l=l+(c[ra>>2]|0)|0;Q=I}else{Qa=qc;break}}}}while(0);c[s+84>>2]=Qa;c[s+88>>2]=(Qa|0)==0?2:1;m=n+3252|0;c[m>>2]=(c[m>>2]|0)==0;c[g>>2]=1;m=YHb(f,c[r>>2]|0)|0;w=(m|0)<0?m:h;i=j;return w|0}}while(0);if((P|0)==91){KIb(c[x>>2]|0,16,2586800,(v=i,i=i+24|0,c[v>>2]=Na,c[v+8>>2]=T,c[v+16>>2]=Ma,v)|0);i=v;ga=-1094995529;ha=c[S>>2]|0}mrc(c[n+1280+(ha<<2)>>2]|0,0,c[n+1308+(ha<<2)>>2]<<2|0)|0;w=ga;i=j;return w|0}function S3a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;kJb(c[b+3188>>2]|0);kJb(c[b+3192>>2]|0);kJb(c[b+1280>>2]|0);kJb(c[b+1284>>2]|0);kJb(c[b+1288>>2]|0);kJb(c[b+1292>>2]|0);kJb(c[b+1296>>2]|0);kJb(c[b+1300>>2]|0);kJb(c[b+1304>>2]|0);if((c[b+3220>>2]|0)==0){d=b+1272|0;mJb(d);e=b+1276|0;f=e;c[f>>2]=0;g=b+4|0;h=g;VHb(h);return 0}kJb(c[b+3196>>2]|0);kJb(c[b+3200>>2]|0);kJb(c[b+3204>>2]|0);kJb(c[b+3208>>2]|0);kJb(c[b+3212>>2]|0);kJb(c[b+3216>>2]|0);d=b+1272|0;mJb(d);e=b+1276|0;f=e;c[f>>2]=0;g=b+4|0;h=g;VHb(h);return 0}function T3a(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=b;b=0;while(1){h=a+3156+(b<<2)|0;i=b<<2;j=(c[e+(i<<2)>>2]|0)+(c[h>>2]|0)|0;k=(c[f>>2]|0)+j|0;c[f>>2]=k;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}c[g>>2]=l&255;k=(c[e+((i|1)<<2)>>2]|0)+j|0;j=f+4|0;m=(c[j>>2]|0)+k|0;c[j>>2]=m;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}c[g+4>>2]=n&255;m=(c[e+((i|2)<<2)>>2]|0)+k|0;k=f+8|0;j=(c[k>>2]|0)+m|0;c[k>>2]=j;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}c[g+8>>2]=o&255;j=(c[e+((i|3)<<2)>>2]|0)+m|0;m=f+12|0;i=(c[m>>2]|0)+j|0;c[m>>2]=i;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}c[g+12>>2]=p&255;c[h>>2]=j;j=b+1|0;if((j|0)<4){g=g+(d<<2)|0;b=j}else{break}}return}function U3a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=c[f+4>>2]|0;if((h|0)<(e|0)){KIb(c[a>>2]|0,16,2500848,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;k=-1094995529;i=g;return k|0}h=a+16|0;l=c[h>>2]|0;m=c[a+8>>2]|0;n=d[m+(l>>>3)|0]|0;o=c[a+24>>2]|0;p=((l|0)<(o|0))+l|0;c[h>>2]=p;if((n&128>>>((l&7)>>>0)|0)!=0){l=b<<1;n=e+1|0;q=U3a(a,l,n,f)|0;if((q|0)<0){k=q;i=g;return k|0}else{q=U3a(a,l|1,n,f)|0;i=g;return((q|0)<0?q:0)|0}}q=(e|0)==0?1:e;e=f+16|0;if((c[e>>2]|0)>=(c[f+20>>2]|0)){KIb(c[a>>2]|0,48,2488136,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=g;return k|0}j=c[f>>2]|0;do{if((j|0)==0){r=0}else{a=m+(p>>>3)|0;n=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(p&7);if((j|0)<26){a=j+p|0;c[h>>2]=o>>>0>a>>>0?a:o;r=n>>>((32-j|0)>>>0);break}else{a=p+16|0;l=o>>>0>a>>>0?a:o;c[h>>2]=l;a=j-16|0;s=m+(l>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(l&7)>>>((48-j|0)>>>0);s=l+a|0;c[h>>2]=o>>>0>s>>>0?s:o;r=t|n>>>16<<a;break}}}while(0);c[(c[f+24>>2]|0)+(c[e>>2]<<2)>>2]=r;c[(c[f+28>>2]|0)+(c[e>>2]<<2)>>2]=b;c[(c[f+32>>2]|0)+(c[e>>2]<<2)>>2]=q;c[e>>2]=(c[e>>2]|0)+1;k=0;i=g;return k|0}function V3a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+416>>2]|0;if((d|0)==1){e=c[a+60>>2]|0;f=a+448|0;c[f>>2]=4;c[f+4>>2]=0;c[a+420>>2]=1;l8(e,a);g=0;i=b;return g|0}else{QIb(a,2356080,(a=i,i=i+8|0,c[a>>2]=d,a)|0);i=a;g=-1163346256;i=b;return g|0}return 0}function W3a(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0;h=i;i=i+448|0;j=h|0;k=h+416|0;l=h+432|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[a+60>>2]|0;o=g;p=(n|0)/32|0;if(!((n+31|0)>>>0>62>>>0)){KIb(a,16,2445224,(q=i,i=i+8|0,c[q>>2]=n,q)|0);i=q;r=-1;i=h;return r|0}c[e+76>>2]=p*240|0;q=M4a(a,e,0)|0;if((q|0)<0){r=q;i=h;return r|0}q=c[e>>2]|0;mrc(q|0,0,p*480|0|0)|0;if((n|0)>31){e=g+1096|0;a=g+1248|0;s=a;t=(a|0)==0?8:264;a=g+1294|0;u=g+1292|0;v=t>>>0>9>>>0?9:t;w=g+1290|0;x=(v>>>3)+(o+1248)|0;y=v&1;z=v|4;v=t>>>0>z>>>0?z:t;z=g+1288|0;A=(v>>>3)+(o+1248)|0;B=v&5;C=v+4|0;v=t>>>0>C>>>0?C:t;C=g+1286|0;D=(v>>>3)+(o+1248)|0;E=v&7;F=v+4|0;v=t>>>0>F>>>0?F:t;F=g+1284|0;G=(v>>>3)+(o+1248)|0;H=v&7;I=v+5|0;v=t>>>0>I>>>0?I:t;I=g+1282|0;J=(v>>>3)+(o+1248)|0;K=v&7;L=v+5|0;v=t>>>0>L>>>0?L:t;L=g+1280|0;M=(v>>>3)+(o+1248)|0;N=v&7;O=((v|0)<(t|0))+v|0;v=g+1368|0;P=(O>>>3)+(o+1248)|0;Q=O&7;R=O+4|0;O=t>>>0>R>>>0?R:t;R=g+1296|0;S=(O>>>3)+(o+1248)|0;T=O&7;U=O+7|0;O=t>>>0>U>>>0?U:t;U=g+1316|0;V=(O>>>3)+(o+1248)|0;W=O&7;X=O+7|0;O=t>>>0>X>>>0?X:t;X=g+1312|0;Y=(O>>>3)+(o+1248)|0;Z=O&7;_=O+7|0;O=t>>>0>_>>>0?_:t;_=g+1308|0;$=(O>>>3)+(o+1248)|0;aa=O&7;ba=O+7|0;O=t>>>0>ba>>>0?ba:t;ba=g+1304|0;da=(O>>>3)+(o+1248)|0;ea=O&7;fa=O+4|0;O=t>>>0>fa>>>0?fa:t;fa=g+1300|0;ga=(O>>>3)+(o+1248)|0;ha=O&7;ia=O+14|0;O=t>>>0>ia>>>0?ia:t;ia=g+1356|0;ja=(O>>>3)+(o+1248)|0;ka=O&7;la=O+14|0;O=t>>>0>la>>>0?la:t;la=g+1352|0;ma=(O>>>3)+(o+1248)|0;na=O&7;oa=O+4|0;O=t>>>0>oa>>>0?oa:t;oa=(O>>>3)+(o+1248)|0;pa=O&7;qa=O+14|0;O=t>>>0>qa>>>0?qa:t;qa=g+1364|0;ra=(O>>>3)+(o+1248)|0;sa=O&7;ta=O+14|0;O=t>>>0>ta>>>0?ta:t;ta=g+1360|0;ua=(O>>>3)+(o+1248)|0;va=O&7;wa=((O|0)<(t|0))+O|0;O=(wa>>>3)+(o+1248)|0;xa=wa&7;ya=wa+16|0;wa=t>>>0>ya>>>0?ya:t;ya=(wa>>>3)+(o+1248)|0;za=wa&7;Aa=wa+11|0;wa=t>>>0>Aa>>>0?Aa:t;Aa=g+1336|0;Ba=(wa>>>3)+(o+1248)|0;Ca=wa&7;Da=wa+4|0;wa=t>>>0>Da>>>0?Da:t;Da=g+1320|0;Ea=(wa>>>3)+(o+1248)|0;Fa=wa&7;Ga=((wa|0)<(t|0))+wa|0;wa=(Ga>>>3)+(o+1248)|0;Ha=Ga&7;Ia=Ga+16|0;Ga=t>>>0>Ia>>>0?Ia:t;Ia=(Ga>>>3)+(o+1248)|0;Ja=Ga&7;Ka=Ga+11|0;Ga=t>>>0>Ka>>>0?Ka:t;Ka=g+1340|0;La=(Ga>>>3)+(o+1248)|0;Ma=Ga&7;Na=Ga+4|0;Ga=t>>>0>Na>>>0?Na:t;Na=g+1324|0;Oa=(Ga>>>3)+(o+1248)|0;Pa=Ga&7;Qa=((Ga|0)<(t|0))+Ga|0;Ga=(Qa>>>3)+(o+1248)|0;Ra=Qa&7;Sa=Qa+16|0;Qa=t>>>0>Sa>>>0?Sa:t;Sa=(Qa>>>3)+(o+1248)|0;Ta=Qa&7;Ua=Qa+11|0;Qa=t>>>0>Ua>>>0?Ua:t;Ua=g+1344|0;Va=(Qa>>>3)+(o+1248)|0;Wa=Qa&7;Xa=Qa+4|0;Qa=t>>>0>Xa>>>0?Xa:t;Xa=g+1328|0;Ya=(Qa>>>3)+(o+1248)|0;Za=Qa&7;_a=((Qa|0)<(t|0))+Qa|0;Qa=(_a>>>3)+(o+1248)|0;$a=_a&7;ab=_a+16|0;_a=t>>>0>ab>>>0?ab:t;ab=(_a>>>3)+(o+1248)|0;bb=_a&7;cb=_a+11|0;_a=t>>>0>cb>>>0?cb:t;t=g+1348|0;cb=(_a>>>3)+(o+1248)|0;db=_a&7;_a=g+1332|0;eb=l;fb=g+2036|0;gb=fb;hb=g+2038|0;ib=g+2040|0;jb=g+2042|0;kb=g+2044|0;lb=g+2046|0;mb=g+2048|0;nb=g+2050|0;ob=g+2052|0;pb=g+1956|0;qb=g+2176|0;rb=g+2192|0;sb=g+1960|0;tb=g+2178|0;ub=g+2194|0;vb=g+1964|0;wb=g+2180|0;xb=g+2196|0;yb=g+1968|0;zb=g+2182|0;Ab=g+2198|0;Bb=g+1972|0;Cb=g+2184|0;Db=g+2200|0;Eb=g+1976|0;Fb=g+2186|0;Gb=g+2202|0;Hb=g+1980|0;Ib=g+2188|0;Jb=g+2204|0;Kb=g+1984|0;Lb=g+2190|0;Mb=g+2206|0;Nb=g+2208|0;Ob=g+2224|0;Pb=g+2210|0;Qb=g+2226|0;Rb=g+2212|0;Sb=g+2228|0;Tb=g+2214|0;Ub=g+2230|0;Vb=g+2216|0;Wb=g+2232|0;Xb=g+2218|0;Yb=g+2234|0;Zb=g+2220|0;_b=g+2236|0;$b=g+2222|0;ac=g+2238|0;bc=g+2056|0;cc=k+12|0;dc=k+10|0;ec=k+8|0;fc=k+6|0;gc=k+4|0;hc=k+2|0;ic=k|0;k=g+1372|0;jc=g+1612|0;kc=g+1988|0;lc=g+2e3|0;mc=g+1990|0;nc=g+1992|0;oc=g+1994|0;pc=g+1996|0;qc=g+1998|0;rc=g+2002|0;sc=g+2004|0;tc=g+2016|0;uc=g+2006|0;vc=g+2008|0;wc=g+2010|0;xc=g+2012|0;yc=g+2014|0;zc=g+2018|0;Ac=g+2020|0;Bc=g+2022|0;Cc=g+2024|0;Dc=g+2026|0;Ec=g+2028|0;Fc=g+2030|0;Gc=g+2032|0;Hc=g+2034|0;g=0;Ic=q;q=m;while(1){ef[c[e>>2]&4095](s,q,8);m=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;b[a>>1]=b[303432+((m>>>5&7)<<1)>>1]|0;b[u>>1]=b[303448+((m>>>2&7)<<1)>>1]|0;b[w>>1]=b[303464+(((je(m|0)|0)>>>23&7)<<1)>>1]|0;b[z>>1]=b[303480+((je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<y>>>28<<1)>>1]|0;b[C>>1]=b[303512+((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<B>>>28<<1)>>1]|0;b[F>>1]=b[303544+((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<E>>>28<<1)>>1]|0;b[I>>1]=b[303576+((je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<H>>>27<<1)>>1]|0;b[L>>1]=b[303640+((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<K>>>27<<1)>>1]|0;c[v>>2]=d[M]<<N>>>7&1;m=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<Q>>>28<<4;c[R>>2]=m;c[U>>2]=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<T>>>25;c[X>>2]=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<W>>>25;c[_>>2]=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<Z>>>25;c[ba>>2]=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<aa>>>25;Jc=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<ea>>>28;c[fa>>2]=Jc;c[ia>>2]=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<ha>>>18;c[la>>2]=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<ka>>>18;c[fa>>2]=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<na>>>28<<4|Jc;c[qa>>2]=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<pa>>>18;c[ta>>2]=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<sa>>>18;Jc=d[ua]<<va>>>7&1|m;c[R>>2]=Jc;m=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<xa>>>16;c[Aa>>2]=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<za>>>21|m<<11;c[Da>>2]=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<Ca>>>28;m=d[Ea]<<Fa>>>7<<1&2|Jc;c[R>>2]=m;Jc=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<Ha>>>16;c[Ka>>2]=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<Ja>>>21|Jc<<11;c[Na>>2]=(je(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0)|0)<<Ma>>>28;Jc=d[Oa]<<Pa>>>7<<2&4|m;c[R>>2]=Jc;m=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<Ra>>>16;c[Ua>>2]=(je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<Ta>>>21|m<<11;c[Xa>>2]=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<Wa>>>28;c[R>>2]=d[Ya]<<Za>>>7<<3&8|Jc;Jc=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<$a>>>16;c[t>>2]=(je(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<bb>>>21|Jc<<11;c[_a>>2]=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<db>>>28;Jc=0;do{if((Jc|0)>0){nrc(eb|0,fb|0,Jc<<1)|0;m=Jc-1|0;Kc=o+1280+(Jc<<1)|0;Lc=0;while(1){Mc=ca(b[Kc>>1]|0,b[l+(m-Lc<<1)>>1]|0)|0;Nc=o+2036+(Lc<<1)|0;b[Nc>>1]=(Mc+16384+(b[Nc>>1]<<15)|0)>>>15;Nc=Lc+1|0;if((Nc|0)<(Jc|0)){Lc=Nc}else{Oc=Kc;break}}}else{Oc=o+1280+(Jc<<1)|0}b[o+2036+(Jc<<1)>>1]=(8-(b[Oc>>1]|0)|0)>>>3;Jc=Jc+1|0;}while((Jc|0)<8);Jc=q+32|0;Kc=((b[gb>>1]|0)*32571|0)>>>15&65535;b[gb>>1]=Kc;Lc=((b[hb>>1]|0)*32376|0)>>>15&65535;b[hb>>1]=Lc;m=((b[ib>>1]|0)*32182|0)>>>15&65535;b[ib>>1]=m;Nc=((b[jb>>1]|0)*31989|0)>>>15&65535;b[jb>>1]=Nc;Mc=((b[kb>>1]|0)*31797|0)>>>15&65535;b[kb>>1]=Mc;Pc=((b[lb>>1]|0)*31606|0)>>>15&65535;b[lb>>1]=Pc;Qc=((b[mb>>1]|0)*31416|0)>>>15&65535;b[mb>>1]=Qc;Rc=((b[nb>>1]|0)*31228|0)>>>15&65535;b[nb>>1]=Rc;c[ob>>2]=b[L>>1]|0;if((c[v>>2]|0)==0){Sc=c[pb>>2]&65535;b[qb>>1]=Sc;b[rb>>1]=Sc;Sc=c[sb>>2]&65535;b[tb>>1]=Sc;b[ub>>1]=Sc;Sc=c[vb>>2]&65535;b[wb>>1]=Sc;b[xb>>1]=Sc;Sc=c[yb>>2]&65535;b[zb>>1]=Sc;b[Ab>>1]=Sc;Sc=c[Bb>>2]&65535;b[Cb>>1]=Sc;b[Db>>1]=Sc;Sc=c[Eb>>2]&65535;b[Fb>>1]=Sc;b[Gb>>1]=Sc;Sc=c[Hb>>2]&65535;b[Ib>>1]=Sc;b[Jb>>1]=Sc;Sc=c[Kb>>2]&65535;b[Lb>>1]=Sc;b[Mb>>1]=Sc;Tc=Kc;Uc=Lc;Vc=m;Wc=Nc;Xc=Mc;Yc=Pc;Zc=Qc;_c=Rc}else{Rc=0;do{Qc=b[o+2036+(Rc<<1)>>1]|0;Pc=o+1956+(Rc<<2)|0;b[o+2176+(Rc<<1)>>1]=(((c[Pc>>2]|0)*10923|0)+16384+(Qc*21846|0)|0)>>>15;b[o+2176+(Rc+8<<1)>>1]=((Qc*10923|0)+16384+((c[Pc>>2]|0)*21846|0)|0)>>>15;Rc=Rc+1|0;}while((Rc|0)<8);Tc=b[gb>>1]|0;Uc=b[hb>>1]|0;Vc=b[ib>>1]|0;Wc=b[jb>>1]|0;Xc=b[kb>>1]|0;Yc=b[lb>>1]|0;Zc=b[mb>>1]|0;_c=b[nb>>1]|0}b[Nb>>1]=Tc;b[Ob>>1]=Tc;b[Pb>>1]=Uc;b[Qb>>1]=Uc;b[Rb>>1]=Vc;b[Sb>>1]=Vc;b[Tb>>1]=Wc;b[Ub>>1]=Wc;b[Vb>>1]=Xc;b[Wb>>1]=Xc;b[Xb>>1]=Yc;b[Yb>>1]=Yc;b[Zb>>1]=Zc;b[_b>>1]=Zc;b[$b>>1]=_c;b[ac>>1]=_c;Rc=0;Pc=Ic;while(1){Qc=c[o+1304+(Rc<<2)>>2]|0;if((Qc|0)==127){mrc(bc|0,0,120)|0}else{Mc=0;do{b[j+(Mc<<1)>>1]=c[o+1372+(Mc<<2)>>2];Mc=Mc+1|0;}while((Mc|0)<146);Mc=((Qc|0)/25|0)+18+(c[o+1296+(Rc>>1<<2)>>2]|0)|0;if((Mc|0)<0){$c=0}else{$c=(Mc|0)>145?145:Mc}Mc=((Qc|0)%25|0)<<1;Nc=b[303328+(Mc<<1)>>1]|0;m=b[303328+((Mc|1)<<1)>>1]|0;Mc=0;Lc=j+(145-$c<<1)|0;do{Kc=ca(b[Lc>>1]|0,Nc)|0;Lc=Lc+2|0;Sc=(Kc+8192+(ca(b[Lc>>1]|0,m)|0)|0)>>>14&65535;b[o+2056+(Mc<<1)>>1]=Sc;b[j+(Mc+146<<1)>>1]=Sc;Mc=Mc+1|0;}while((Mc|0)<60)}mrc(Pc|0,0,120)|0;Mc=o+1352+(Rc<<2)|0;m=c[o+1320+(Rc<<2)>>2]<<2;Lc=c[Mc>>2]|0;b[cc>>1]=b[303200+((Lc&3|m)<<1)>>1]|0;b[dc>>1]=b[303200+((Lc>>>2&3|m)<<1)>>1]|0;b[ec>>1]=b[303200+((Lc>>>4&3|m)<<1)>>1]|0;b[fc>>1]=b[303200+((Lc>>>6&3|m)<<1)>>1]|0;b[gc>>1]=b[303200+((Lc>>>8&3|m)<<1)>>1]|0;b[hc>>1]=b[303200+((Lc>>>10&3|m)<<1)>>1]|0;b[ic>>1]=b[303200+((Lc>>>12&3|m)<<1)>>1]|0;c[Mc>>2]=Lc>>14;Lc=c[o+1336+(Rc<<2)>>2]|0;Mc=0;m=3;Nc=303020;Qc=ic;Sc=Lc>>15;while(1){Kc=b[Nc>>1]|0;if((Sc|0)<(Kc|0)){b[Pc+(Mc<<1)>>1]=b[Qc>>1]|0;ad=Sc;bd=Qc+2|0;cd=Nc+62|0;dd=m-1|0}else{ad=Sc-Kc|0;bd=Qc;cd=Nc+2|0;dd=m}Kc=Mc+1|0;if((Kc|0)<30&(dd|0)>0){Mc=Kc;m=dd;Nc=cd;Qc=bd;Sc=ad}else{break}}Sc=30;Qc=4;Nc=302960;m=bd;Mc=Lc&32767;while(1){Kc=b[Nc>>1]|0;if((Mc|0)<(Kc|0)){b[Pc+(Sc<<1)>>1]=b[m>>1]|0;ed=Mc;fd=m+2|0;gd=Nc+62|0;hd=Qc-1|0}else{ed=Mc-Kc|0;fd=m;gd=Nc+2|0;hd=Qc}Kc=Sc+1|0;if((Kc|0)<60&(hd|0)>0){Sc=Kc;Qc=hd;Nc=gd;m=fd;Mc=ed}else{break}}orc(k|0,jc|0,344)|0;Mc=0;do{m=Pc+(Mc<<1)|0;Nc=b[m>>1]|0;Qc=o+2056+(Mc<<1)|0;Sc=b[Qc>>1]|0;c[o+1372+(Mc+86<<2)>>2]=Sc+(Nc<<16>>16)-(Sc>>3);b[m>>1]=(b[Qc>>1]|0)+Nc;Mc=Mc+1|0;}while((Mc|0)<60);Mc=Rc<<3;Nc=o+2176+(Mc<<1)|0;Qc=o+2176+((Mc|1)<<1)|0;m=o+2176+((Mc|2)<<1)|0;Sc=o+2176+((Mc|3)<<1)|0;Lc=o+2176+((Mc|4)<<1)|0;Kc=o+2176+((Mc|5)<<1)|0;id=o+2176+((Mc|6)<<1)|0;jd=o+2176+((Mc|7)<<1)|0;Mc=0;kd=b[kc>>1]|0;ld=b[mc>>1]|0;md=b[nc>>1]|0;nd=b[oc>>1]|0;od=b[pc>>1]|0;pd=b[qc>>1]|0;qd=b[lc>>1]|0;rd=b[rc>>1]|0;do{sd=ca(b[Nc>>1]|0,kd<<16>>16)|0;td=ca(b[Qc>>1]|0,ld<<16>>16)|0;ud=ca(b[m>>1]|0,md<<16>>16)|0;vd=ca(b[Sc>>1]|0,nd<<16>>16)|0;wd=ca(b[Lc>>1]|0,od<<16>>16)|0;xd=ca(b[Kc>>1]|0,pd<<16>>16)|0;yd=ca(b[id>>1]|0,qd<<16>>16)|0;zd=ca(b[jd>>1]|0,rd<<16>>16)|0;Ad=Pc+(Mc<<1)|0;Bd=sd+2048+td+ud+vd+wd+xd+yd+zd+(b[Ad>>1]<<12)>>12;if((Bd|0)<-32766){Cd=-32766}else{Cd=(Bd|0)>32766?32766:Bd&65535}b[Ad>>1]=Cd;rd=b[lc>>1]|0;b[rc>>1]=rd;qd=b[qc>>1]|0;b[lc>>1]=qd;pd=b[pc>>1]|0;b[qc>>1]=pd;od=b[oc>>1]|0;b[pc>>1]=od;nd=b[nc>>1]|0;b[oc>>1]=nd;md=b[mc>>1]|0;b[nc>>1]=md;ld=b[kc>>1]|0;b[mc>>1]=ld;kd=b[Ad>>1]|0;b[kc>>1]=kd;Mc=Mc+1|0;}while((Mc|0)<60);Mc=((b[Nc>>1]|0)*18022|0)>>15;kd=((b[Qc>>1]|0)*9912|0)>>15;ld=((b[m>>1]|0)*5452|0)>>15;md=((b[Sc>>1]|0)*2998|0)>>15;nd=((b[Lc>>1]|0)*1649|0)>>15;od=((b[Kc>>1]|0)*907|0)>>15;pd=((b[id>>1]|0)*499|0)>>15;qd=((b[jd>>1]|0)*274|0)>>15;rd=0;do{Ad=b[sc>>1]|0;Bd=b[uc>>1]|0;zd=ca(Bd<<16>>16,kd)|0;yd=b[vc>>1]|0;xd=ca(yd<<16>>16,ld)|0;wd=b[wc>>1]|0;vd=ca(wd<<16>>16,md)|0;ud=b[xc>>1]|0;td=ca(ud<<16>>16,nd)|0;sd=b[yc>>1]|0;Dd=ca(sd<<16>>16,od)|0;Ed=b[tc>>1]|0;Fd=ca(Ed<<16>>16,pd)|0;Gd=ca(b[zc>>1]|0,qd)|0;b[zc>>1]=Ed;b[tc>>1]=sd;b[yc>>1]=ud;b[xc>>1]=wd;b[wc>>1]=yd;b[vc>>1]=Bd;b[uc>>1]=Ad;Bd=ca(Ad<<16>>16,Mc)|0;Ad=Pc+(rd<<1)|0;b[sc>>1]=b[Ad>>1]|0;b[Ad>>1]=((b[Ad>>1]<<12)-(zd+Bd+xd+vd+td+Dd+Fd+Gd)|0)>>>12;rd=rd+1|0;}while((rd|0)<60);rd=((b[Nc>>1]|0)*24576|0)>>15;Mc=((b[Qc>>1]|0)*18432|0)>>15;qd=((b[m>>1]|0)*13824|0)>>15;pd=((b[Sc>>1]|0)*10368|0)>>15;od=((b[Lc>>1]|0)*7776|0)>>15;nd=((b[Kc>>1]|0)*5832|0)>>15;md=((b[id>>1]|0)*4374|0)>>15;ld=((b[jd>>1]|0)*3281|0)>>15;kd=c[ob>>2]|0;Gd=kd-(kd>>2)|0;kd=0;do{Fd=Pc+(kd<<1)|0;Dd=b[Fd>>1]<<12;td=b[Ac>>1]|0;vd=td<<16>>16;xd=ca(vd,rd)|0;Bd=b[Bc>>1]|0;zd=ca(Bd<<16>>16,Mc)|0;Ad=b[Cc>>1]|0;yd=ca(Ad<<16>>16,qd)|0;wd=b[Dc>>1]|0;ud=ca(wd<<16>>16,pd)|0;sd=b[Ec>>1]|0;Ed=ca(sd<<16>>16,od)|0;Hd=b[Fc>>1]|0;Id=ca(Hd<<16>>16,nd)|0;Jd=b[Gc>>1]|0;Kd=ca(Jd<<16>>16,md)|0;Ld=ca(b[Hc>>1]|0,ld)|0;b[Hc>>1]=Jd;b[Gc>>1]=Hd;b[Fc>>1]=sd;b[Ec>>1]=wd;b[Dc>>1]=Ad;b[Cc>>1]=Bd;b[Bc>>1]=td;td=xd+Dd+zd+yd+ud+Ed+Id+Kd+Ld|0;Ld=td+2048>>12;if((Ld|0)<-32766){Md=-32766}else{Md=(Ld|0)>32766?32766:Ld&65535}b[Ac>>1]=Md;Ld=((ca(Gd,vd)|0)>>4)+td|0;td=Ld+2048-(Ld>>3)>>12;if((td|0)<-32766){Nd=-32766}else{Nd=(td|0)>32766?32766:td&65535}b[Fd>>1]=Nd;kd=kd+1|0;}while((kd|0)<60);kd=Rc+1|0;if((kd|0)<4){Rc=kd;Pc=Pc+120|0}else{break}}c[pb>>2]=b[gb>>1]|0;c[sb>>2]=b[hb>>1]|0;c[vb>>2]=b[ib>>1]|0;c[yb>>2]=b[jb>>1]|0;c[Bb>>2]=b[kb>>1]|0;c[Eb>>2]=b[lb>>1]|0;c[Hb>>2]=b[mb>>1]|0;c[Kb>>2]=b[nb>>1]|0;Pc=g+1|0;if((Pc|0)<(p|0)){g=Pc;Ic=Ic+480|0;q=Jc}else{break}}}c[f>>2]=1;r=n;i=h;return r|0}function X3a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;e=a+124|0;c[d+32>>2]=c[e>>2];f=d+36|0;g=f;mrc(f|0,0,56)|0;f=c[a+792>>2]|0;if((f|0)==16){c[a+140>>2]=46}else if((f|0)==32){c[a+140>>2]=30}else if((f|0)==24){c[a+140>>2]=3}else if((f|0)==8){c[a+140>>2]=11}else{KIb(a,16,2169224,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;j=-1163346256;i=b;return j|0}c[d+8>>2]=f;k=c[a+120>>2]|0;l=(k*3|0)+2+((ca(k,f)|0)+7>>3)|0;f=(ca(l,c[e>>2]|0)|0)+2|0;c[d+12>>2]=f;do{if((f|0)!=0){e=hJb(f)|0;c[d+16>>2]=e;if((e|0)!=0){break}KIb(a,16,2142344,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-12;i=b;return j|0}}while(0);c[d+68>>2]=0;c[d+72>>2]=0;c[d+76>>2]=0;f=_pc(g,2118792,56)|0;if((f|0)==0){c[d+4>>2]=UHb()|0;j=0;i=b;return j|0}else{KIb(a,16,2636960,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;j=-1313558101;i=b;return j|0}return 0}function Y3a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=c[e+24>>2]|0;h=c[e+28>>2]|0;j=c[a+60>>2]|0;k=c[j+4>>2]|0;l=N4a(a,k)|0;if((l|0)<0){m=l;i=f;return m|0}l=j+36|0;n=l;o=Xpc(n)|0;if((o|0)!=0){KIb(a,16,2445192,(p=i,i=i+8|0,c[p>>2]=o,p)|0);i=p;m=-1313558101;i=f;return m|0}c[l>>2]=g;c[j+40>>2]=h;g=j+16|0;c[j+48>>2]=c[g>>2];l=j+12|0;o=j+52|0;c[o>>2]=c[l>>2];q=$pc(n,4)|0;if((q|0)==0|(q|0)==1){r=6}else if((q|0)!=(-3|0)){KIb(a,16,2356056,(p=i,i=i+8|0,c[p>>2]=q,p)|0);i=p;m=-1313558101;i=f;return m|0}do{if((r|0)==6){q=j+20|0;n=c[g>>2]|0;s=(c[l>>2]|0)-(c[o>>2]|0)|0;if((s|0)>-1){c[q>>2]=n;c[j+28>>2]=n;c[j+24>>2]=n+s;YUa(a,k,c[j+8>>2]|0,q)|0;break}else{KIb(0,0,2293368,(p=i,i=i+24|0,c[p>>2]=2242296,c[p+8>>2]=2201056,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}}}while(0);if((c[(c[j>>2]|0)+140>>2]|0)==11){p=V1(e,0,0)|0;if((p|0)==0){t=j+92|0}else{c[k+304>>2]=1;e=j+92|0;nrc(e|0,p|0,1024)|0;t=e}nrc(c[k+4>>2]|0,t|0,1024)|0}t=YHb(b,k)|0;if((t|0)<0){m=t;i=f;return m|0}c[d>>2]=1;m=h;i=f;return m|0}function Z3a(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+16|0);VHb(b+4|0);cqc(b+36|0)|0;return 0}function _3a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a+60|0;e=c[d>>2]|0;f=e;c[e>>2]=a;c[a+140>>2]=5;g=$2(e+72|0,9,47,302688,1,1,302592,2,2,302496,2,2,2)|0;a:do{if((g|0)==0){h=0;while(1){if((h|0)>=13){break a}j=$2(f+92+(h*20|0)|0,9,16,302288+(h<<4)|0,1,1,301872+(h<<5)|0,2,2,301856,1,1,2)|0;if((j|0)!=0){k=4;break}l=$2(f+352+(h*20|0)|0,9,c[302792+(h<<2)>>2]|0,c[302904+(h<<2)>>2]|0,1,1,c[302848+(h<<2)>>2]|0,2,2,c[302736+(h<<2)>>2]|0,2,2,2)|0;if((l|0)==0){h=h+1|0}else{k=6;break}}if((k|0)==4){b4a(f);m=j;k=7;break}else if((k|0)==6){b4a(f);m=l;k=7;break}}else{m=g;k=7}}while(0);do{if((k|0)==7){if((m|0)>=0){break}KIb(a,16,2547760,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=m;i=b;return o|0}}while(0);m=(c[a+120>>2]|0)+15>>4;c[e+8>>2]=m;k=(c[a+124>>2]|0)+7>>3;c[e+12>>2]=k;g=hJb(ca(k,m)|0)|0;c[e+16>>2]=g;if((g|0)==0){KIb(a,16,2529872,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;b4a(f);o=-12;i=b;return o|0}f=UHb()|0;c[e+4>>2]=f;if((f|0)!=0){o=0;i=b;return o|0}f=c[d>>2]|0;VHb(f+4|0);mJb(f+16|0);b4a(f);o=-12;i=b;return o|0}function $3a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;k=i;i=i+64|0;l=k|0;m=c[j+24>>2]|0;n=c[j+28>>2]|0;j=c[f+60>>2]|0;o=j;p=j+8|0;q=j+12|0;r=ca(c[q>>2]|0,c[p>>2]|0)|0;if(!((n|0)>-1)){KIb(0,0,2613608,(s=i,i=i+24|0,c[s>>2]=2586744,c[s+8>>2]=2565792,c[s+16>>2]=135,s)|0);i=s;Hd();return 0}t=m+n|0;u=m;do{if((n|0)<1){v=m;w=0}else{x=a[m]|0;y=x&255;if(!((x&255)>>>0>1>>>0)){v=m+1|0;w=y;break}KIb(f,16,2445160,(s=i,i=i+8|0,c[s>>2]=y,s)|0);i=s;z=-1094995529;i=k;return z|0}}while(0);y=j+4|0;x=N4a(f,c[y>>2]|0)|0;if((x|0)<0){z=x;i=k;return z|0}if((w|0)==0){c[h>>2]=1;w=YHb(g,c[y>>2]|0)|0;z=(w|0)<0?w:n;i=k;return z|0}w=t-v|0;if(w>>>0<4>>>0){KIb(f,16,2356032,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;z=-1094995529;i=k;return z|0}if((w|0)<1){A=0;B=v}else{A=d[v]|0;B=v+1|0}c[j+20>>2]=A;if((t-B|0)<1){C=0;D=B}else{C=d[B]|0;D=B+1|0}c[j+24>>2]=C;B=A-2|0;if(B>>>0>12>>>0|C>>>0<2>>>0|C>>>0>14>>>0){KIb(f,16,2293336,(s=i,i=i+16|0,c[s>>2]=A,c[s+8>>2]=C,s)|0);i=s;z=-1094995529;i=k;return z|0}c[j+28>>2]=e[301776+(B*6|0)>>1]|0;A=C-2|0;c[j+40>>2]=e[301776+(A*6|0)>>1]|0;c[j+32>>2]=e[301778+(B*6|0)>>1]|0;c[j+44>>2]=e[301778+(A*6|0)>>1]|0;c[j+36>>2]=e[301780+(B*6|0)>>1]|0;c[j+48>>2]=e[301780+(A*6|0)>>1]|0;A=t-D|0;B=A>>>0>1>>>0?1:A;A=D+B|0;a:do{if((t-A|0)<4){E=A;F=0}else{C=D+(B+4)|0;v=A;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if(w>>>0>(t-C|0)>>>0){KIb(f,16,2242256,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;z=-1094995529;i=k;return z|0}if((w|0)==0){E=C;F=0;break}v=j+16|0;x=C;C=0;G=0;while(1){if((t-x|0)<1){H=0;I=x}else{H=d[x]|0;I=x+1|0}J=H&63;K=J+G|0;if((K|0)>(r|0)){break}mrc((c[v>>2]|0)+G|0,H>>>6&255|0,J|0)|0;J=C+1|0;if(J>>>0<w>>>0){x=I;C=J;G=K}else{E=I;F=K;break a}}KIb(f,16,2201024,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;z=-1094995529;i=k;return z|0}}while(0);if((F|0)<(r|0)){KIb(f,16,2169184,(s=i,i=i+16|0,c[s>>2]=F,c[s+8>>2]=r,s)|0);i=s;z=-1094995529;i=k;return z|0}r=c[q>>2]|0;b:do{if((r|0)>0){F=j+16|0;I=j+52|0;H=j+64|0;A=j+68|0;B=j+56|0;D=j+60|0;G=j+612|0;C=j+616|0;x=j+76|0;w=E;v=0;K=r;c:while(1){J=t-w|0;do{if((J|0)<1){L=w;M=37}else{N=a[w]|0;if((N&1)==0){if((J|0)<4){L=w;M=37;break}O=w;P=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>1;Q=w+4|0}else{P=(N&255)-1|0;Q=w+1|0}if((P|0)==0){L=Q;M=37}else{R=Q;S=P}}}while(0);d:do{if((M|0)==37){M=0;J=c[p>>2]|0;N=ca(J,v)|0;O=0;while(1){if((O|0)>=(J|0)){R=L;S=0;break d}if(((a[(c[F>>2]|0)+(O+N)|0]|0)-1&255)>>>0<2>>>0){M=40;break c}else{O=O+1|0}}}}while(0);O=R;T=t-O|0;if(T>>>0<S>>>0){M=42;break}N=m+(O-u)|0;O=S>>>0>268435455>>>0?-8:S<<3;J=O>>>0>2147483639>>>0|(N|0)==0;U=J?0:N;N=J?0:O;c[I>>2]=U;c[H>>2]=N;c[A>>2]=N+8;c[B>>2]=U+(N>>3);c[D>>2]=0;if(J){M=80;break}J=c[p>>2]|0;if((J|0)>0){N=v<<3;U=0;O=J;while(1){J=(ca(O,v)|0)+U|0;V=a[(c[F>>2]|0)+J|0]|0;if((V<<24>>24|0)==3|(V<<24>>24|0)==0){W=O}else{J=U<<4;X=(V&255)-1|0;V=o+20+(X<<2)|0;Y=0;do{Z=c[y>>2]|0;_=c[Z+32+(Y<<2)>>2]|0;$=(ca(N,_)|0)+J|0;aa=(c[V>>2]|0)-2|0;ba=c[Z+(Y<<2)>>2]|0;Z=ba+$|0;da=c[D>>2]|0;ea=c[I>>2]|0;fa=d[ea+(da>>>3)|0]|0;ga=c[A>>2]|0;ha=((da|0)<(ga|0))+da|0;c[D>>2]=ha;do{if((fa&1<<(da&7)|0)==0){ia=o+92+(aa*20|0)+4|0;ja=o+352+(aa*20|0)+4|0;ka=_<<2;la=Z;ma=0;na=0;while(1){oa=ma;pa=0;do{do{if((pa|na|0)==0){qa=c[D>>2]|0;ra=c[A>>2]|0;sa=c[I>>2]|0;ta=sa+(qa>>>3)|0;ua=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((qa&7)>>>0)&255;ta=qa+8|0;qa=ra>>>0>ta>>>0?ta:ra;c[D>>2]=qa;va=ua;wa=qa;xa=ra;ya=sa}else{sa=c[x>>2]|0;ra=c[D>>2]|0;qa=c[A>>2]|0;ua=c[I>>2]|0;ta=ua+(ra>>>3)|0;za=(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)>>>((ra&7)>>>0)&511;ta=b[sa+(za<<2)>>1]|0;Aa=b[sa+(za<<2)+2>>1]|0;za=Aa<<16>>16;if(Aa<<16>>16<0){Aa=ra+9|0;Ba=qa>>>0>Aa>>>0?Aa:qa;Aa=ua+(Ba>>>3)|0;Ca=za+32|0;Da=((d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)>>>((Ba&7)>>>0)<<Ca>>>(Ca>>>0))+ta|0;Ea=b[sa+(Da<<2)+2>>1]|0;Fa=b[sa+(Da<<2)>>1]|0;Ga=Ba}else{Ea=za;Fa=ta;Ga=ra}ra=Ea+Ga|0;ta=qa>>>0>ra>>>0?ra:qa;c[D>>2]=ta;if((Fa|0)==(-1|0)){M=80;break c}else if((Fa|0)!=256){va=Fa;wa=ta;xa=qa;ya=ua;break}ra=ua+(ta>>>3)|0;za=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)>>>((ta&7)>>>0)&255;ra=ta+8|0;ta=qa>>>0>ra>>>0?ra:qa;c[D>>2]=ta;va=za;wa=ta;xa=qa;ya=ua}}while(0);oa=va+oa&255;c[G>>2]=oa;ua=c[ia>>2]|0;qa=ya+(wa>>>3)|0;ta=(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)>>>((wa&7)>>>0)&511;qa=b[ua+(ta<<2)>>1]|0;za=qa<<16>>16;ra=(b[ua+(ta<<2)+2>>1]|0)+wa|0;ta=xa>>>0>ra>>>0?ra:xa;c[D>>2]=ta;if(qa<<16>>16==-1){M=80;break c}mrc(C|0,0,60)|0;e:do{if(qa<<16>>16>0){ra=1;ua=1;Ba=ta;Da=xa;sa=ya;while(1){Ca=c[ja>>2]|0;Aa=sa+(Ba>>>3)|0;Ha=(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)>>>((Ba&7)>>>0)&511;Aa=b[Ca+(Ha<<2)>>1]|0;Ia=b[Ca+(Ha<<2)+2>>1]|0;Ha=Ia<<16>>16;if(Ia<<16>>16<0){Ia=Ba+9|0;Ja=Da>>>0>Ia>>>0?Ia:Da;Ia=sa+(Ja>>>3)|0;Ka=Ha+32|0;La=((d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)>>>((Ja&7)>>>0)<<Ka>>>(Ka>>>0))+Aa|0;Ma=b[Ca+(La<<2)+2>>1]|0;Na=b[Ca+(La<<2)>>1]|0;Oa=Ja}else{Ma=Ha;Na=Aa;Oa=Ba}Aa=Ma+Oa|0;Ha=Da>>>0>Aa>>>0?Aa:Da;c[D>>2]=Ha;if((Na|0)==(-1|0)){M=80;break c}else if((Na|0)==4096){Aa=sa+(Ha>>>3)|0;Ja=(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)>>>((Ha&7)>>>0)&4095;Aa=Ha+12|0;c[D>>2]=Da>>>0>Aa>>>0?Aa:Da;Pa=Ja}else{Pa=Na}Ja=(Pa&15)+ra|0;if((Ja|0)>15){M=80;break c}c[o+612+(d[301760+Ja|0]<<2)>>2]=Pa>>>4<<24>>24;if((ua|0)>=(za|0)){Qa=0;break e}ra=Ja+1|0;ua=ua+1|0;Ba=c[D>>2]|0;Da=c[A>>2]|0;sa=c[I>>2]|0}}else{Qa=0}}while(0);do{za=Qa&1;ta=c[o+28+(X*12|0)+(za<<2)>>2]|0;qa=(ca(ta,c[o+612+(Qa<<2)>>2]|0)|0)+128>>8;sa=Qa+4|0;Da=c[o+28+(X*12|0)+(za+1<<2)>>2]|0;za=(ca(Da,c[o+612+(sa<<2)>>2]|0)|0)+128>>8;Ba=Qa+8|0;ua=(ca(c[o+612+(Ba<<2)>>2]|0,ta)|0)+128>>8;ta=Qa+12|0;ra=(ca(c[o+612+(ta<<2)>>2]|0,Da)|0)+128>>8;Da=ra<<1;c[l+(Qa<<2)>>2]=((za+qa+ua|0)*5|0)+Da;Ja=qa-ua|0;Aa=za<<1;c[l+(sa<<2)>>2]=((Ja-ra|0)*5|0)+Aa;c[l+(Ba<<2)>>2]=((Ja+ra|0)*5|0)-Aa;c[l+(ta<<2)>>2]=((qa-za+ua|0)*5|0)-Da;Qa=Qa+1|0;}while((Qa|0)<4);Da=0;ua=la+(pa<<2)|0;while(1){za=Da<<2;qa=l+(za<<2)|0;ta=l+((za|1)<<2)|0;Aa=l+((za|2)<<2)|0;ra=l+((za|3)<<2)|0;a[ua]=((c[ra>>2]<<1)+32+(((c[ta>>2]|0)+(c[qa>>2]|0)+(c[Aa>>2]|0)|0)*5|0)|0)>>>6;a[ua+1|0]=((c[ta>>2]<<1)+32+(((c[qa>>2]|0)-(c[Aa>>2]|0)-(c[ra>>2]|0)|0)*5|0)|0)>>>6;a[ua+2|0]=(32-(c[ta>>2]<<1)+(((c[qa>>2]|0)-(c[Aa>>2]|0)+(c[ra>>2]|0)|0)*5|0)|0)>>>6;a[ua+3|0]=(32-(c[ra>>2]<<1)+(((c[qa>>2]|0)-(c[ta>>2]|0)+(c[Aa>>2]|0)|0)*5|0)|0)>>>6;Aa=Da+1|0;if((Aa|0)<4){Da=Aa;ua=ua+_|0}else{break}}pa=pa+1|0;}while((pa|0)<4);pa=na+1|0;if((pa|0)<2){la=la+ka|0;ma=oa;na=pa}else{break}}}else{na=d[ea+(ha>>>3)|0]|0;ma=((ha|0)<(ga|0))+ha|0;c[D>>2]=ma;if((na&1<<(ha&7)|0)!=0){na=ea+(ma>>>3)|0;ka=(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)>>>((ma&7)>>>0);na=ma+8|0;c[D>>2]=ga>>>0>na>>>0?na:ga;na=ka&255;mrc(Z|0,na|0,16)|0;ka=$+_|0;mrc(ba+ka|0,na|0,16)|0;la=_<<1;mrc(ba+($+la)|0,na|0,16)|0;ja=la+_|0;mrc(ba+($+ja)|0,na|0,16)|0;la=ja+_|0;mrc(ba+(la+$)|0,na|0,16)|0;ja=la+_|0;mrc(ba+(ja+$)|0,na|0,16)|0;la=ja+_|0;mrc(ba+(la+$)|0,na|0,16)|0;mrc(ba+(la+ka)|0,na|0,16)|0;break}if(((c[H>>2]|0)-ma|0)<1024){M=80;break c}else{Ra=Z;Sa=0}while(1){ma=0;do{na=c[D>>2]|0;ka=c[A>>2]|0;la=(c[I>>2]|0)+(na>>>3)|0;ja=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((na&7)>>>0);la=na+8|0;c[D>>2]=ka>>>0>la>>>0?la:ka;a[Ra+ma|0]=ja;ma=ma+1|0;}while((ma|0)<16);ma=Sa+1|0;if((ma|0)<8){Ra=Ra+_|0;Sa=ma}else{break}}}}while(0);Y=Y+1|0;}while((Y|0)<3);W=c[p>>2]|0}Y=U+1|0;if((Y|0)<(W|0)){U=Y;O=W}else{break}}Ta=c[q>>2]|0}else{Ta=K}O=v+1|0;if((O|0)<(Ta|0)){w=R+(T>>>0>S>>>0?S:T)|0;v=O;K=Ta}else{break b}}if((M|0)==40){KIb(f,16,2142312,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;z=-1094995529;i=k;return z|0}else if((M|0)==42){KIb(f,16,2118760,(s=i,i=i+16|0,c[s>>2]=S,c[s+8>>2]=T,s)|0);i=s;z=-1094995529;i=k;return z|0}else if((M|0)==80){KIb(f,16,2636928,(s=i,i=i+8|0,c[s>>2]=v,s)|0);i=s;z=-1094995529;i=k;return z|0}}}while(0);c[h>>2]=1;h=YHb(g,c[y>>2]|0)|0;z=(h|0)<0?h:n;i=k;return z|0}function a4a(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+16|0);b4a(b);return 0}function b4a(a){a=a|0;c3(a+72|0);c3(a+92|0);c3(a+352|0);c3(a+112|0);c3(a+372|0);c3(a+132|0);c3(a+392|0);c3(a+152|0);c3(a+412|0);c3(a+172|0);c3(a+432|0);c3(a+192|0);c3(a+452|0);c3(a+212|0);c3(a+472|0);c3(a+232|0);c3(a+492|0);c3(a+252|0);c3(a+512|0);c3(a+272|0);c3(a+532|0);c3(a+292|0);c3(a+552|0);c3(a+312|0);c3(a+572|0);c3(a+332|0);c3(a+592|0);return}function c4a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=b+60|0;g=c[f>>2]|0;c[g+4>>2]=b;h=b+100|0;if((c[h>>2]|0)<22){j=-1094995529;i=e;return j|0}c[g+8>>2]=DGb(4)|0;k=c[b+96>>2]|0;l=c[h>>2]|0;h=l>>>0>268435455>>>0?-8:l<<3;l=h>>>0>2147483639>>>0|(k|0)==0;m=l?0:k;k=l?8:h+8|0;h=m;l=m+(k>>>0>16>>>0?2:k>>>3)|0;if(((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)<<16|(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24)&65535|0)!=826365012){KIb(b,16,2565712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}h=(k|0)<32?k:32;l=m+(h>>>3)|0;o=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)&65535;l=h+16|0;h=k>>>0>l>>>0?l:k;l=g+12|0;c[l>>2]=o;if(o>>>0>2>>>0){KIb(b,16,2293320,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}if((o|0)==2){o=c[g+48>>2]|0;if((o|0)==0){KIb(b,16,2242184,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-22;i=e;return j|0}p=lrc(o|0)|0;q=o+p|0;if((p|0)>0){p=-1;r=-1;s=o;do{o=(0<<24|0>>>8)^r;t=((d[s]|0)<<24|0>>>8)^p;u=(t>>31|((t|0)<0|0?-1:0)<<1)&-1444268397^(o<<1|0>>>31);v=(((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1)&1123082731^(t<<1|o>>>31);o=(v>>31|((v|0)<0|0?-1:0)<<1)&-1444268397^(u<<1|0>>>31);t=(((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1)&1123082731^(v<<1|u>>>31);u=(t>>31|((t|0)<0|0?-1:0)<<1)&-1444268397^(o<<1|0>>>31);v=(((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1)&1123082731^(t<<1|o>>>31);o=(v>>31|((v|0)<0|0?-1:0)<<1)&-1444268397^(u<<1|0>>>31);t=(((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1)&1123082731^(v<<1|u>>>31);u=(t>>31|((t|0)<0|0?-1:0)<<1)&-1444268397^(o<<1|0>>>31);v=(((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1)&1123082731^(t<<1|o>>>31);o=(v>>31|((v|0)<0|0?-1:0)<<1)&-1444268397^(u<<1|0>>>31);t=(((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1)&1123082731^(v<<1|u>>>31);u=(t>>31|((t|0)<0|0?-1:0)<<1)&-1444268397^(o<<1|0>>>31);v=(((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1)&1123082731^(t<<1|o>>>31);r=(v>>31|((v|0)<0|0?-1:0)<<1)&-1444268397^(u<<1|0>>>31);p=(((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1)&1123082731^(v<<1|u>>>31);s=s+1|0;}while(s>>>0<q>>>0);w=~p;x=~r}else{w=0;x=0}r=g+40|0;p=r|0;y=x;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=w;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y}p=m+(h>>>3)|0;w=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((h&7)>>>0)&65535;p=h+16|0;h=k>>>0>p>>>0?p:k;p=g+16|0;c[p>>2]=w;r=b+416|0;c[r>>2]=w;w=(c[p>>2]|0)-2|0;if(w>>>0<7>>>0){x=301704+(w<<3)|0;w=c[x+4>>2]|0;q=b+448|0;c[q>>2]=c[x>>2];c[q+4>>2]=w}w=m+(h>>>3)|0;q=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((h&7)>>>0)&65535;w=h+16|0;h=k>>>0>w>>>0?w:k;c[b+796>>2]=q;w=g+20|0;c[w>>2]=(q+7|0)>>>3;q=m+(h>>>3)|0;x=h+16|0;s=k>>>0>x>>>0?x:k;x=m+(s>>>3)|0;u=s+16|0;v=k>>>0>u>>>0?u:k;u=b+412|0;c[u>>2]=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((s&7)>>>0)<<16|(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((h&7)>>>0)&65535;h=m+(v>>>3)|0;q=v+16|0;s=k>>>0>q>>>0?q:k;k=m+(s>>>3)|0;m=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((s&7)>>>0)<<16|(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>((v&7)>>>0)&65535;v=g+24|0;c[v>>2]=m;if((c[p>>2]|0)==0){KIb(b,16,2200992,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}h=c[u>>2]|0;if((h|0)==0){KIb(b,16,2169160,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}s=c[w>>2]|0;if((s|0)==1){c[b+420>>2]=0}else if((s|0)==3){c[b+420>>2]=2}else if((s|0)==2){c[b+420>>2]=1}else{KIb(b,16,2142272,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}if(h>>>0>8388607>>>0){KIb(b,16,2118736,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-22;i=e;return j|0}s=(h<<8|0)/245|0;h=g+28|0;c[h>>2]=s;w=(m>>>0)%(s>>>0)|0;k=g+32|0;c[k>>2]=w;q=b;x=c[r>>2]|0;o=c[b+792>>2]|0;t=c[u>>2]|0;u=c[b+432>>2]|0;KIb(q,48,2636872,(n=i,i=i+40|0,c[n>>2]=c[l>>2],c[n+8>>2]=x,c[n+16>>2]=o,c[n+24>>2]=t,c[n+32>>2]=u,n)|0);i=n;u=c[h>>2]|0;t=c[k>>2]|0;KIb(q,48,2613552,(n=i,i=i+32|0,c[n>>2]=c[v>>2],c[n+8>>2]=u,c[n+16>>2]=t,c[n+24>>2]=((m>>>0)/(s>>>0)|0)+((w|0)!=0),n)|0);i=n;if(!((c[h>>2]|0)>>>0<(4294967295/(c[p>>2]<<2>>>0)|0)>>>0)){KIb(q,16,2586720,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;j=-1094995529;i=e;return j|0}h4a(g+56|0);g=c[f>>2]|0;do{if((c[g+20>>2]|0)<3){f=pJb(ca(c[g+28>>2]<<2,c[g+16>>2]|0)|0)|0;c[g+36>>2]=f;if((f|0)==0){j=-12}else{break}i=e;return j|0}else{c[g+36>>2]=0}}while(0);f=hJb((c[r>>2]|0)*224|0)|0;c[g+52>>2]=f;if((f|0)!=0){j=0;i=e;return j|0}mJb(g+36|0);j=-12;i=e;return j|0}function d4a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;j=i;i=i+16|0;k=j|0;c[k>>2]=f;c[k+4>>2]=0;c[k+8>>2]=0;l=h+24|0;m=c[l>>2]|0;n=h+28|0;h=c[n>>2]|0;o=c[e+60>>2]|0;p=c[o+28>>2]|0;q=e+696|0;do{if((c[q>>2]&1|0)==0){r=m;s=h}else{if((h|0)<4){t=-1094995529;i=j;return t|0}u=h-4|0;v=m+u|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if((w|0)==(~(EGb(c[o+8>>2]|0,-1,m,u)|0)|0)){r=m;s=h;break}KIb(c[o+4>>2]|0,16,2445144,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;if((c[q>>2]&8|0)==0){r=c[l>>2]|0;s=c[n>>2]|0;break}else{t=-1094995529;i=j;return t|0}}}while(0);n=s>>>0>268435455>>>0?-8:s<<3;s=n>>>0>2147483639>>>0|(r|0)==0;l=s?0:r;r=s?0:n;n=r+8|0;if(s){t=s?-1094995529:0;i=j;return t|0}s=f+76|0;c[s>>2]=p;q=J5a(e,k,0)|0;if((q|0)<0){t=q;i=j;return t|0}q=o+20|0;if((c[q>>2]|0)==3){c[o+36>>2]=c[f>>2]}k=o+16|0;e=c[k>>2]|0;if((e|0)>0){m=o+52|0;u=o+12|0;w=0;while(1){v=c[m>>2]|0;c[v+(w*224|0)>>2]=0;g4a(v+(w*224|0)+4|0,d[1277152+((c[q>>2]|0)-1)|0]|0);if((c[u>>2]|0)==2){c[v+(w*224|0)+16>>2]=a[o+40|0]|0;c[v+(w*224|0)+20>>2]=a[o+41|0]|0;c[v+(w*224|0)+24>>2]=a[o+42|0]|0;c[v+(w*224|0)+28>>2]=a[o+43|0]|0;c[v+(w*224|0)+32>>2]=a[o+44|0]|0;c[v+(w*224|0)+36>>2]=a[o+45|0]|0;c[v+(w*224|0)+40>>2]=a[o+46|0]|0;c[v+(w*224|0)+44>>2]=a[o+47|0]|0}f4a((c[m>>2]|0)+(w*224|0)+208|0,10,10);v=w+1|0;x=c[k>>2]|0;if((v|0)<(x|0)){w=v}else{y=x;break}}}else{y=e}e=o+36|0;a:do{if((ca(y,p)|0)>0){w=o+52|0;m=c[319246]|0;u=o+56|0;x=o+32|0;v=r-32|0;z=0;A=c[e>>2]|0;B=0;C=0;b:while(1){D=c[w>>2]|0;E=D+(B*224|0)|0;F=D+(B*224|0)+208|0;H=r-z|0;I=0;J=z;while(1){if((I|0)>=(H|0)){K=J;break}L=((J|0)<(n|0))+J|0;if((d[l+(J>>>3)|0]&1<<(J&7)|0)==0){K=L;break}else{I=I+1|0;J=L}}if((I|0)==0){M=F|0;N=0;O=0}else{M=D+(B*224|0)+212|0;N=1;O=I-1|0}J=c[M>>2]|0;if((r-K|0)>>>0<J>>>0){break a}if((J|0)==0){P=O;Q=K}else{if(J>>>0>25>>>0){break a}H=l+(K>>>3)|0;L=32-J|0;R=J+K|0;P=((d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((K&7)>>>0)<<L>>>(L>>>0))+(O<<J)|0;Q=n>>>0>R>>>0?R:n}if((N|0)==1){R=D+(B*224|0)+220|0;J=c[R>>2]|0;L=P-(J>>>4)+J|0;c[R>>2]=L;R=D+(B*224|0)+212|0;J=c[R>>2]|0;do{if((J|0)==0){S=32}else{if(!(L>>>0<(c[m+(J<<2)>>2]|0)>>>0)){S=32;break}c[R>>2]=J-1}}while(0);do{if((S|0)==32){S=0;I=J+1|0;if(!(L>>>0>(c[m+(I<<2)>>2]|0)>>>0)){break}c[R>>2]=I}}while(0);R=c[F>>2]|0;T=(c[1276992+(R<<2)>>2]|0)+P|0;U=R}else{T=P;U=c[F>>2]|0}R=D+(B*224|0)+216|0;L=c[R>>2]|0;J=T-(L>>>4)+L|0;c[R>>2]=J;R=F|0;do{if((U|0)==0){S=38}else{if(!(J>>>0<(c[m+(U<<2)>>2]|0)>>>0)){S=38;break}c[R>>2]=U-1}}while(0);do{if((S|0)==38){S=0;F=U+1|0;if(!(J>>>0>(c[m+(F<<2)>>2]|0)>>>0)){break}c[R>>2]=F}}while(0);c[A>>2]=((T&1)-1^T>>1)+1;Se[c[u>>2]&1023](D+(B*224|0)+16|0,D+(B*224|0)+80|0,D+(B*224|0)+144|0,D+(B*224|0)+12|0,A,c[D+(B*224|0)+4>>2]|0,c[D+(B*224|0)+8>>2]|0);R=c[q>>2]|0;if((R|0)==2|(R|0)==3){J=c[E>>2]|0;F=Erc(J,(J|0)<0|0?-1:0,31,0)|0;J=(F>>>5|G<<27)+(c[A>>2]|0)|0;c[A>>2]=J;V=J}else if((R|0)==4){J=(c[A>>2]|0)+(c[E>>2]|0)|0;c[A>>2]=J;V=J}else if((R|0)==1){R=c[E>>2]|0;J=Erc(R,(R|0)<0|0?-1:0,15,0)|0;R=(J>>>4|G<<28)+(c[A>>2]|0)|0;c[A>>2]=R;V=R}else{V=c[A>>2]|0}c[E>>2]=V;R=c[k>>2]|0;do{if((B|0)<(R-1|0)){W=C;X=B+1|0;Y=R}else{c:do{if((R|0)>1){J=A-4|0;F=c[J>>2]|0;c[A>>2]=(c[A>>2]|0)+((F|0)/2|0);L=c[k>>2]|0;if((-L|0)<-1){Z=J;_=F}else{$=L;break}while(1){c[Z>>2]=(c[Z+4>>2]|0)-_;L=Z-4|0;F=c[k>>2]|0;if(!(L>>>0>(A+(-F<<2)|0)>>>0)){$=F;break c}Z=L;_=c[L>>2]|0}}else{$=R}}while(0);aa=C+1|0;if((aa|0)!=(c[x>>2]|0)){W=aa;X=0;Y=$;break}if((v-Q|0)>>>0<8>>>0){break b}else{W=aa;X=0;Y=$}}}while(0);R=A+4|0;if(R>>>0<((c[e>>2]|0)+((ca(Y,p)|0)<<2)|0)>>>0){z=Q;A=R;B=X;C=W}else{ba=p;da=Q;S=55;break a}}c[s>>2]=aa;ba=aa;da=Q;S=55}else{ba=p;da=0;S=55}}while(0);do{if((S|0)==55){p=-da&7;if((p|0)==0){ea=da}else{Q=p+da|0;ea=n>>>0>Q>>>0?Q:n}if((r-ea|0)<32){break}Q=c[q>>2]|0;do{if((Q|0)==3){if((ca(c[k>>2]|0,ba)|0)>0){p=0;aa=c[f>>2]|0;while(1){c[aa>>2]=c[aa>>2]<<8;s=p+1|0;if((s|0)<(ca(c[k>>2]|0,ba)|0)){p=s;aa=aa+4|0}else{break}}}c[e>>2]=0}else if((Q|0)==1){if((ca(c[k>>2]|0,ba)|0)<=0){break}aa=c[e>>2]|0;p=c[f>>2]|0;while(1){a[p]=(c[aa>>2]|0)+128;s=aa+4|0;if(s>>>0<((c[e>>2]|0)+((ca(c[k>>2]|0,ba)|0)<<2)|0)>>>0){aa=s;p=p+1|0}else{break}}}else if((Q|0)==2){p=ca(c[k>>2]|0,ba)|0;if((p|0)<=0){break}aa=c[e>>2]|0;s=aa+(p<<2)|0;p=aa;aa=c[f>>2]|0;while(1){b[aa>>1]=c[p>>2];W=p+4|0;if(W>>>0<s>>>0){p=W;aa=aa+2|0}else{break}}}}while(0);c[g>>2]=1;t=h;i=j;return t|0}}while(0);if((c[q>>2]|0)!=3){t=-1094995529;i=j;return t|0}c[e>>2]=0;t=-1094995529;i=j;return t|0}function e4a(a){a=a|0;var b=0;b=c[a+60>>2]|0;a=b+36|0;if((c[b+20>>2]|0)<3){kJb(c[a>>2]|0)}c[a>>2]=0;mJb(b+52|0);return 0}function f4a(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=b;c[a+4>>2]=d;c[a+8>>2]=c[1276992+(b+4<<2)>>2];c[a+12>>2]=c[1276992+(d+4<<2)>>2];return}function g4a(a,b){a=a|0;b=b|0;mrc(a|0,0,204)|0;c[a>>2]=b;c[a+4>>2]=c[1276992+(b-1<<2)>>2];return}function h4a(a){a=a|0;c[a>>2]=272;return}function i4a(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=c[e>>2]|0;do{if((i|0)<0){j=(c[a>>2]|0)-(c[b>>2]|0)|0;c[a>>2]=j;k=b+4|0;l=a+4|0;m=(c[l>>2]|0)-(c[k>>2]|0)|0;c[l>>2]=m;l=b+8|0;n=a+8|0;o=(c[n>>2]|0)-(c[l>>2]|0)|0;c[n>>2]=o;n=b+12|0;p=a+12|0;q=(c[p>>2]|0)-(c[n>>2]|0)|0;c[p>>2]=q;p=b+16|0;r=a+16|0;s=(c[r>>2]|0)-(c[p>>2]|0)|0;c[r>>2]=s;r=b+20|0;t=a+20|0;u=(c[t>>2]|0)-(c[r>>2]|0)|0;c[t>>2]=u;t=b+24|0;v=a+24|0;w=(c[v>>2]|0)-(c[t>>2]|0)|0;c[v>>2]=w;v=b+28|0;x=a+28|0;y=(c[x>>2]|0)-(c[v>>2]|0)|0;c[x>>2]=y;z=j;A=m;B=o;C=q;D=s;E=u;F=w;G=y;H=k;I=l;J=n;K=p;L=r;M=t;N=v}else{if((i|0)>0){v=(c[a>>2]|0)+(c[b>>2]|0)|0;c[a>>2]=v;t=b+4|0;r=a+4|0;p=(c[r>>2]|0)+(c[t>>2]|0)|0;c[r>>2]=p;r=b+8|0;n=a+8|0;l=(c[n>>2]|0)+(c[r>>2]|0)|0;c[n>>2]=l;n=b+12|0;k=a+12|0;y=(c[k>>2]|0)+(c[n>>2]|0)|0;c[k>>2]=y;k=b+16|0;w=a+16|0;u=(c[w>>2]|0)+(c[k>>2]|0)|0;c[w>>2]=u;w=b+20|0;s=a+20|0;q=(c[s>>2]|0)+(c[w>>2]|0)|0;c[s>>2]=q;s=b+24|0;o=a+24|0;m=(c[o>>2]|0)+(c[s>>2]|0)|0;c[o>>2]=m;o=b+28|0;j=a+28|0;x=(c[j>>2]|0)+(c[o>>2]|0)|0;c[j>>2]=x;z=v;A=p;B=l;C=y;D=u;E=q;F=m;G=x;H=t;I=r;J=n;K=k;L=w;M=s;N=o;break}else{z=c[a>>2]|0;A=c[a+4>>2]|0;B=c[a+8>>2]|0;C=c[a+12>>2]|0;D=c[a+16>>2]|0;E=c[a+20>>2]|0;F=c[a+24>>2]|0;G=c[a+28>>2]|0;H=b+4|0;I=b+8|0;J=b+12|0;K=b+16|0;L=b+20|0;M=b+24|0;N=b+28|0;break}}}while(0);a=ca(z,c[d>>2]|0)|0;z=d+4|0;i=ca(A,c[z>>2]|0)|0;A=d+8|0;o=ca(B,c[A>>2]|0)|0;B=d+12|0;s=ca(C,c[B>>2]|0)|0;C=d+16|0;w=ca(D,c[C>>2]|0)|0;D=d+20|0;k=ca(E,c[D>>2]|0)|0;E=d+24|0;n=ca(F,c[E>>2]|0)|0;F=d+28|0;r=a+h+i+o+s+w+k+n+(ca(G,c[F>>2]|0)|0)|0;c[b>>2]=c[H>>2];c[H>>2]=c[I>>2];c[I>>2]=c[J>>2];c[J>>2]=c[K>>2];c[d>>2]=c[z>>2];c[z>>2]=c[A>>2];c[A>>2]=c[B>>2];A=c[C>>2]|0;c[B>>2]=A;c[K>>2]=A>>30|1;c[L>>2]=c[D>>2]>>30&-4|2;c[M>>2]=c[E>>2]>>30&-4|2;c[N>>2]=c[F>>2]>>30&-8|4;c[e>>2]=c[f>>2];c[f>>2]=(c[f>>2]|0)+(r>>g);g=c[D>>2]|0;c[C>>2]=-g;r=c[E>>2]|0;c[D>>2]=-r;e=(c[f>>2]|0)-(c[F>>2]|0)|0;c[E>>2]=e;c[F>>2]=c[f>>2];f=e-r|0;c[D>>2]=f;c[C>>2]=f-g;return}function j4a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;c[d>>2]=DGb(4)|0;e=c[a+420>>2]|0;if((e|0)==0){c[a+796>>2]=8;f=1}else if((e|0)==2){g=a+796|0;if((c[g>>2]|0)>24){KIb(a,24,2445112,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}c[g>>2]=24;f=3}else if((e|0)==1){c[a+796>>2]=16;f=2}else{f=c[a+796>>2]>>3}c[d+4>>2]=f;c[a+424>>2]=(c[a+412>>2]<<8|0)/245|0;f=hJb((c[a+416>>2]|0)*224|0)|0;c[d+8>>2]=f;i=b;return((f|0)==0?-12:0)|0}function k4a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0;j=i;i=i+8|0;k=j|0;l=c[e+60>>2]|0;m=g+76|0;n=e+416|0;o=ca(c[m>>2]<<1,c[n>>2]|0)|0;p=l+4|0;q=ca(o,c[p>>2]|0)|0;o=d5a(e,f,q,(q|0)<0|0?-1:0)|0;if((o|0)<0){r=o;i=j;return r|0}o=f+24|0;q=f+28|0;s=(c[q>>2]|0)<0?0:c[o>>2]|0;t=c[n>>2]|0;if((t|0)>0){u=l+8|0;v=0;while(1){w=c[u>>2]|0;c[w+(v*224|0)>>2]=0;g4a(w+(v*224|0)+4|0,d[1277152+((c[p>>2]|0)-1)|0]|0);f4a((c[u>>2]|0)+(v*224|0)+208|0,10,10);w=v+1|0;x=c[n>>2]|0;if((w|0)<(x|0)){v=w}else{z=x;break}}}else{z=t}do{if((ca(z,c[m>>2]|0)|0)>0){t=l+8|0;v=e+420|0;u=g|0;x=c[319246]|0;w=s;A=32;B=0;C=0;D=0;E=0;F=z;while(1){H=c[t>>2]|0;I=H+(D*224|0)|0;J=E+1|0;K=c[v>>2]|0;L=(K|0)==0;do{if(L){M=c[u>>2]|0;N=(d[M+E|0]|0)-128|0;O=M}else{M=c[u>>2]|0;if((K|0)==1){N=b[M+(E<<1)>>1]|0;O=M;break}else{N=c[M+(E<<2)>>2]>>8;O=M;break}}}while(0);do{if((F|0)>1){if((D|0)>=(F-1|0)){P=C;Q=N-((C|0)/2|0)|0;break}do{if(L){R=(d[O+J|0]|0)-128|0}else{if((K|0)==1){R=b[O+(J<<1)>>1]|0;break}else{R=c[O+(J<<2)>>2]>>8;break}}}while(0);M=R-N|0;P=M;Q=M}else{P=C;Q=N}}while(0);K=c[p>>2]|0;if((K|0)==2|(K|0)==3){L=I|0;M=c[L>>2]|0;S=Erc(M,(M|0)<0|0?-1:0,31,0)|0;T=Q-(S>>>5|G<<27)|0;U=L}else if((K|0)==1){K=I|0;L=c[K>>2]|0;S=Erc(L,(L|0)<0|0?-1:0,15,0)|0;T=Q-(S>>>4|G<<28)|0;U=K}else{T=Q;U=I|0}c[U>>2]=Q;K=H+(D*224|0)+144|0;S=H+(D*224|0)+16|0;L=H+(D*224|0)+80|0;M=c[H+(D*224|0)+8>>2]|0;V=H+(D*224|0)+12|0;W=c[V>>2]|0;do{if((W|0)<0){X=(c[S>>2]|0)-(c[L>>2]|0)|0;c[S>>2]=X;Y=c[H+(D*224|0)+84>>2]|0;Z=H+(D*224|0)+20|0;_=(c[Z>>2]|0)-Y|0;c[Z>>2]=_;Z=c[H+(D*224|0)+88>>2]|0;$=H+(D*224|0)+24|0;aa=(c[$>>2]|0)-Z|0;c[$>>2]=aa;$=c[H+(D*224|0)+92>>2]|0;ba=H+(D*224|0)+28|0;da=(c[ba>>2]|0)-$|0;c[ba>>2]=da;ba=c[H+(D*224|0)+96>>2]|0;ea=H+(D*224|0)+32|0;fa=(c[ea>>2]|0)-ba|0;c[ea>>2]=fa;ea=H+(D*224|0)+100|0;ga=H+(D*224|0)+36|0;ha=(c[ga>>2]|0)-(c[ea>>2]|0)|0;c[ga>>2]=ha;ga=H+(D*224|0)+104|0;ia=H+(D*224|0)+40|0;ja=(c[ia>>2]|0)-(c[ga>>2]|0)|0;c[ia>>2]=ja;ia=H+(D*224|0)+108|0;ka=H+(D*224|0)+44|0;la=(c[ka>>2]|0)-(c[ia>>2]|0)|0;c[ka>>2]=la;ma=X;na=_;oa=aa;pa=da;qa=fa;ra=ha;sa=ja;ta=la;ua=Y;va=Z;wa=$;xa=ba;ya=ea;za=ga;Aa=ia}else{if((W|0)>0){ia=(c[S>>2]|0)+(c[L>>2]|0)|0;c[S>>2]=ia;ga=c[H+(D*224|0)+84>>2]|0;ea=H+(D*224|0)+20|0;ba=(c[ea>>2]|0)+ga|0;c[ea>>2]=ba;ea=c[H+(D*224|0)+88>>2]|0;$=H+(D*224|0)+24|0;Z=(c[$>>2]|0)+ea|0;c[$>>2]=Z;$=c[H+(D*224|0)+92>>2]|0;Y=H+(D*224|0)+28|0;la=(c[Y>>2]|0)+$|0;c[Y>>2]=la;Y=c[H+(D*224|0)+96>>2]|0;ja=H+(D*224|0)+32|0;ha=(c[ja>>2]|0)+Y|0;c[ja>>2]=ha;ja=H+(D*224|0)+100|0;fa=H+(D*224|0)+36|0;da=(c[fa>>2]|0)+(c[ja>>2]|0)|0;c[fa>>2]=da;fa=H+(D*224|0)+104|0;aa=H+(D*224|0)+40|0;_=(c[aa>>2]|0)+(c[fa>>2]|0)|0;c[aa>>2]=_;aa=H+(D*224|0)+108|0;X=H+(D*224|0)+44|0;ka=(c[X>>2]|0)+(c[aa>>2]|0)|0;c[X>>2]=ka;ma=ia;na=ba;oa=Z;pa=la;qa=ha;ra=da;sa=_;ta=ka;ua=ga;va=ea;wa=$;xa=Y;ya=ja;za=fa;Aa=aa;break}else{ma=c[S>>2]|0;na=c[H+(D*224|0)+20>>2]|0;oa=c[H+(D*224|0)+24>>2]|0;pa=c[H+(D*224|0)+28>>2]|0;qa=c[H+(D*224|0)+32>>2]|0;ra=c[H+(D*224|0)+36>>2]|0;sa=c[H+(D*224|0)+40>>2]|0;ta=c[H+(D*224|0)+44>>2]|0;ua=c[H+(D*224|0)+84>>2]|0;va=c[H+(D*224|0)+88>>2]|0;wa=c[H+(D*224|0)+92>>2]|0;xa=c[H+(D*224|0)+96>>2]|0;ya=H+(D*224|0)+100|0;za=H+(D*224|0)+104|0;Aa=H+(D*224|0)+108|0;break}}}while(0);S=ca(c[K>>2]|0,ma)|0;W=H+(D*224|0)+148|0;I=c[W>>2]|0;aa=ca(I,na)|0;fa=H+(D*224|0)+152|0;ja=c[fa>>2]|0;Y=ca(ja,oa)|0;$=H+(D*224|0)+156|0;ea=c[$>>2]|0;ga=ca(ea,pa)|0;ka=H+(D*224|0)+160|0;_=c[ka>>2]|0;da=ca(_,qa)|0;ha=H+(D*224|0)+164|0;la=c[ha>>2]|0;Z=ca(la,ra)|0;ba=H+(D*224|0)+168|0;ia=c[ba>>2]|0;X=ca(ia,sa)|0;Ba=H+(D*224|0)+172|0;Ca=c[Ba>>2]|0;Da=S+M+aa+Y+ga+da+Z+X+(ca(Ca,ta)|0)|0;c[L>>2]=ua;c[H+(D*224|0)+84>>2]=va;c[H+(D*224|0)+88>>2]=wa;c[H+(D*224|0)+92>>2]=xa;c[K>>2]=I;c[W>>2]=ja;c[fa>>2]=ea;c[$>>2]=_;c[H+(D*224|0)+96>>2]=_>>30|1;c[ya>>2]=la>>30&-4|2;c[za>>2]=ia>>30&-4|2;c[Aa>>2]=Ca>>30&-8|4;_=T-Ca|0;c[ba>>2]=_;c[Ba>>2]=T;Ba=_-ia|0;c[ha>>2]=Ba;c[ka>>2]=Ba-la;la=T-(Da>>c[H+(D*224|0)+4>>2])|0;c[V>>2]=la;if((la|0)>0){Ea=(la<<1)-1|0}else{Ea=-la<<1}la=H+(D*224|0)+208|0;Da=c[la>>2]|0;Ba=H+(D*224|0)+216|0;ka=c[Ba>>2]|0;ha=Ea-(ka>>>4)+ka|0;c[Ba>>2]=ha;do{if((Da|0)==0){Fa=36}else{if(!(ha>>>0<(c[x+(Da<<2)>>2]|0)>>>0)){Fa=36;break}c[la>>2]=Da-1}}while(0);do{if((Fa|0)==36){Fa=0;V=Da+1|0;if(!(ha>>>0>(c[x+(V<<2)>>2]|0)>>>0)){break}c[la>>2]=V}}while(0);la=c[1276992+(Da<<2)>>2]|0;a:do{if(Ea>>>0<la>>>0){Ga=Ea;Ha=Da;Ia=B;Ja=A;Ka=w}else{ha=Ea-la|0;V=H+(D*224|0)+212|0;K=c[V>>2]|0;L=H+(D*224|0)+220|0;M=c[L>>2]|0;Ba=ha-(M>>>4)+M|0;c[L>>2]=Ba;do{if((K|0)==0){Fa=42}else{if(!(Ba>>>0<(c[x+(K<<2)>>2]|0)>>>0)){Fa=42;break}c[V>>2]=K-1}}while(0);do{if((Fa|0)==42){Fa=0;L=K+1|0;if(!(Ba>>>0>(c[x+(L<<2)>>2]|0)>>>0)){break}c[V>>2]=L}}while(0);V=(ha>>>(K>>>0))+1|0;Ba=B;L=A;M=w;while(1){if(!(V>>>0>31>>>0)){break}ka=2147483647<<32-L|Ba;if((L|0)>31){La=L;Ma=ka;Na=M}else{ia=M;y=ka;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;La=L+32|0;Ma=2147483647>>>(L>>>0);Na=M+4|0}ia=La-31|0;ka=V-31|0;if((ka|0)==0){Ga=ha;Ha=K;Ia=Ma;Ja=ia;Ka=Na;break a}else{V=ka;Ba=Ma;L=ia;M=Na}}ia=(1<<V)-1|0;ka=ia<<32-L|Ba;if((L|0)>(V|0)){Oa=L;Pa=ka;Qa=M}else{_=M;y=ka;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;Oa=L+32|0;Pa=(L|0)==32?0:ia>>>(L>>>0);Qa=M+4|0}Ga=ha;Ha=K;Ia=Pa;Ja=Oa-V|0;Ka=Qa}}while(0);if((Ja|0)>1){Ra=Ja;Sa=Ia;Ta=Ka}else{H=Ka;y=Ia;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;Ra=Ja+32|0;Sa=0;Ta=Ka+4|0}H=Ra-1|0;if((Ha|0)==0){Ua=Sa;Va=H;Wa=Ta}else{la=(c[1276992+(Ha<<2)>>2]|0)-1&Ga;Da=la<<33-Ra|Sa;if((H|0)>(Ha|0)){Xa=H;Ya=Da;Za=Ta}else{ia=Ta;y=Da;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;Xa=Ra+31|0;Ya=(H|0)==32?0:la>>>(H>>>0);Za=Ta+4|0}Ua=Ya;Va=Xa-Ha|0;Wa=Za}H=c[n>>2]|0;if((J|0)>=(ca(H,c[m>>2]|0)|0)){break}w=Wa;A=Va;B=Ua;C=P;D=(D|0)<(H-1|0)?D+1|0:0;E=J;F=H}if((Va|0)>=32){_a=Wa;break}F=((31-Va|0)>>>3)+1|0;E=Ua&255;D=Ua;C=Va;B=Wa;while(1){a[B]=E;A=D>>>8;w=C+8|0;if((w|0)<32){E=A&255;D=A;C=w;B=B+1|0}else{break}}_a=Wa+F|0}else{_a=s}}while(0);Wa=_a-s<<3>>3;s=_a;y=~(EGb(c[l>>2]|0,-1,c[o>>2]|0,Wa)|0);a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=g+136|0;g=c[s+4>>2]|0;o=f+8|0;c[o>>2]=c[s>>2];c[o+4>>2]=g;c[q>>2]=Wa+4;Wa=c[m>>2]|0;c[k>>2]=1;c[k+4>>2]=c[e+412>>2];m=XIb(Wa,(Wa|0)<0|0?-1:0,k,e+104|0)|0;c[f+48>>2]=m;c[h>>2]=1;r=0;i=j;return r|0}function l4a(a){a=a|0;mJb((c[a+60>>2]|0)+8|0);return 0}function m4a(b,f,h,j){b=b|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0.0,ra=0.0,sa=0,ta=0,ua=0.0,va=0,wa=0,xa=0.0,ya=0.0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0.0,Va=0.0,Wa=0.0,Xa=0,Ya=0,Za=0,_a=0.0,$a=0.0,ab=0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0.0,gb=0.0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0;k=i;i=i+2152|0;l=k|0;m=k+16|0;n=k+24|0;o=k+152|0;p=k+2072|0;q=c[j+24>>2]|0;r=c[j+28>>2]|0;j=c[b+60>>2]|0;s=j;t=j+232|0;u=c[t>>2]|0;v=j+34208|0;do{if((c[v>>2]|0)>1){c[f+76>>2]=ca(e[u+96>>1]|0,c[j+34232>>2]|0)|0;w=M4a(b,f,0)|0;if((w|0)<0){x=w;i=k;return x|0}else{y=c[f+64>>2]|0;break}}else{y=0}}while(0);f=b+432|0;if((r|0)<(c[f>>2]|0)){KIb(b,16,2463656,(w=i,i=i+8|0,c[w>>2]=r,w)|0);i=w;x=-22;i=k;return x|0}w=hf[c[j+36876>>2]&1023](b,s,q,r)|0;if((w|0)<0){x=w;i=k;return x|0}w=j+34236|0;c[w>>2]=0;q=j+34232|0;if((c[q>>2]|0)>0){b=j+34188|0;z=j+34240|0;A=j;B=j+34184|0;C=o|0;D=j+36884|0;E=p|0;F=m|0;G=m+1|0;H=m+2|0;I=m+3|0;J=j+34224|0;K=j+34212|0;L=j+4|0;M=j+36880|0;N=u+96|0;u=j+34196|0;O=j+34200|0;P=j+34192|0;Q=l|0;S=l+4|0;T=l+8|0;V=j+20|0;W=(y|0)==0;X=y+4|0;Y=j+32|0;j=0;do{Z=c[b>>2]|0;_=c[z+(j*1316|0)+4>>2]|0;aa=c[t>>2]|0;ba=c[(c[A>>2]|0)+416>>2]|0;da=aa+(_<<5)|0;ea=a[da]|0;fa=ea&255;ga=aa+96|0;ha=((e[ga>>1]|0)>>>0)/(fa>>>0)|0;p4a(s,s+34240+(j*1316|0)+8|0,Z,_,c[aa+(_<<5)+20>>2]|0,c[aa+(_<<5)+24>>2]|0,d[aa+(_<<5)+28|0]|0);ia=c[w>>2]|0;ja=a[(c[t>>2]|0)+(_<<5)|0]|0;ka=ja&255;la=(_|0)==2;ma=c[(c[A>>2]|0)+416>>2]|0;na=(ma|0)>0;do{if(la){if(na){oa=0}else{pa=24;break}while(1){qa=(+(d[s+34240+(ia*1316|0)+1092+oa|0]|0)*50.98039245605469+25.490196228027344)/13.0e3;if(qa<-1.0){ra=-1.0}else{ra=qa>1.0?1.0:qa}g[n+(oa<<2)>>2]=(ra>0.0?13.0e3:-13.0e3)*(+$(+R(+ra)*4.61512051684126)+-1.0)/100.0*.0001220703125;sa=oa+1|0;if((sa|0)<(ma|0)){oa=sa}else{pa=23;break}}}else{if(!na){break}if(ja<<24>>24==0){pa=23;break}else{ta=0}while(1){qa=(+(d[s+34240+(ia*1316|0)+1092+ta|0]|0)*50.98039245605469+25.490196228027344)/13.0e3;if(qa<-1.0){ua=-1.0}else{ua=qa>1.0?1.0:qa}qa=(ua>0.0?13.0e3:-13.0e3)*(+$(+R(+ua)*4.61512051684126)+-1.0)/100.0*1.1920928955078125e-7;sa=ca(ta,ka)|0;va=0;do{wa=va+sa|0;xa=(+(d[s+34240+(ia*1316|0)+1094+wa|0]|0)*145.16128540039062+72.58064270019531)/4500.0;if(xa<-1.0){ya=-1.0}else{ya=xa>1.0?1.0:xa}g[n+(wa<<2)>>2]=qa*((ya>0.0?4500.0:-4500.0)*(+$(+R(+ya)*4.61512051684126)+-1.0)/100.0);va=va+1|0;}while((va|0)<(ka|0));va=ta+1|0;if((va|0)<(ma|0)){ta=va}else{pa=23;break}}}}while(0);if((pa|0)==23){pa=0;if(la){pa=24}}if((pa|0)==24){pa=0;ma=c[B>>2]|0;ka=(ma-1+(ca(d[aa+114|0]|0,ba)|0)|0)/(ma|0)|0;ma=c[aa+108>>2]|0;p4a(s,s+34240+(j*1316|0)+1032|0,C,3,ma,ma+(ka<<6<<1)|0,ka)}if((ba|0)>0){ka=ea<<24>>24==0;ma=aa+114|0;ia=0;do{ja=ca(e[ga>>1]|0,ia)|0;na=Z+(ja<<2)|0;if(!ka){va=ca(ia,fa)|0;sa=0;do{Re[c[M>>2]&7](s,s+34240+(j*1316|0)+1126+(ia<<6)+(sa<<2)|0,d[s+34240+(j*1316|0)+1254+(ia<<4)+sa|0]|0,ia,c[J>>2]|0,+g[n+(sa+va<<2)>>2],_);wa=Z+((ca(sa,ha)|0)+ja<<2)|0;mf[c[L>>2]&2047](wa,wa,c[J>>2]|0,ha);sa=sa+1|0;}while((sa|0)<(fa|0))}if(la){sa=o+((ca(d[ma]|0,ia)|0)<<2)|0;pe[c[D>>2]&1023](s,c[s+34240+(j*1316|0)+1300+(ia<<2)>>2]|0,c[s+34240+(j*1316|0)+1308+(ia<<2)>>2]|0,sa,na)}sa=d[s+34240+(j*1316|0)+1286+ia|0]|0;ja=d[s+34240+(j*1316|0)+1296+ia|0]|0;va=c[t>>2]|0;wa=c[va+100>>2]|0;za=va+98|0;Aa=a[za]|0;Ba=Aa&255;Ca=Ba<<d[va+105|0];Da=Ba<<d[va+106|0];a[F]=-2;Ba=va+107|0;va=a[Ba]|0;Ea=va<<24>>24==4?-2:1;a[G]=Ea;a[H]=Ea;a[I]=0;a:do{if(va<<24>>24==0){Fa=Aa}else{Ea=0;Ga=0;Ha=va&255;Ia=va;Ja=Aa;Ka=-2;while(1){La=Ga+1|0;Ma=((ca(La,Ja&255)|0)+Ka|0)/(Ha|0)|0;if((Ea|0)<(Ma|0)){Na=d[s+34240+(j*1316|0)+1288+(ia<<2)+Ga|0]|0;Oa=Ea;Pa=Ja;while(1){Qa=Pa&255;qa=+g[wa+((ca(Qa,sa)|0)+Oa<<2)>>2];g[p+(Oa<<2)>>2]=qa+ +g[wa+(Oa+Ca+(ca(Qa,Na)|0)<<2)>>2];Qa=Oa+1|0;if((Qa|0)>=(Ma|0)){break}Oa=Qa;Pa=a[za]|0}Ra=Ma;Sa=a[Ba]|0;Ta=a[za]|0}else{Ra=Ea;Sa=Ia;Ta=Ja}Pa=Sa&255;if((La|0)>=(Pa|0)){Fa=Ta;break a}Ea=Ra;Ga=La;Ha=Pa;Ia=Sa;Ja=Ta;Ka=a[m+La|0]|0}}}while(0);Ba=Fa&255;if((Fa&255)>>>0>1>>>0){sa=1;qa=+g[E>>2];while(1){Aa=p+(sa<<2)|0;xa=+g[Aa>>2];if(xa-qa<9999999747378752.0e-20){Ua=(qa+xa)*.5;g[p+(sa-1<<2)>>2]=Ua+-4999999873689376.0e-20;Va=Ua+4999999873689376.0e-20;g[Aa>>2]=Va;Wa=Va}else{Wa=xa}Aa=sa+1|0;if((Aa|0)<(Ba|0)){sa=Aa;qa=Wa}else{break}}Xa=a[za]|0}else{Xa=Fa}do{if(Xa<<24>>24==0){Ya=0}else{sa=Da+Ca|0;Ba=0;Aa=Xa&255;do{qa=+g[wa+(sa+Ba+(ca(Aa,ja)|0)<<2)>>2];va=s+240+(ia*80|0)+(Ba<<2)|0;xa=qa*+g[va>>2];Ka=p+(Ba<<2)|0;Va=+g[Ka>>2];g[va>>2]=Va;g[Ka>>2]=xa+(1.0-qa)*Va;Ba=Ba+1|0;Za=a[za]|0;Aa=Za&255;}while((Ba|0)<(Aa|0));if(!((Za&255)>>>0>1>>>0)){Ya=Za;break}Ba=1;Va=+g[E>>2];while(1){sa=p+(Ba<<2)|0;qa=+g[sa>>2];if(qa-Va<9999999747378752.0e-20){xa=(Va+qa)*.5;g[p+(Ba-1<<2)>>2]=xa+-4999999873689376.0e-20;Ua=xa+4999999873689376.0e-20;g[sa>>2]=Ua;_a=Ua}else{_a=qa}sa=Ba+1|0;if((sa|0)<(Aa|0)){Ba=sa;Va=_a}else{break}}Ba=a[za]|0;Aa=Ba&255;if(!((Ba&255)>>>0>1>>>0)){Ya=Ba;break}Ba=1;Va=+g[E>>2];while(1){sa=p+(Ba<<2)|0;qa=+g[sa>>2];if(qa-Va<9500000305706635.0e-20){Ua=(Va+qa)*.5;g[p+(Ba-1<<2)>>2]=Ua+-47500001528533176.0e-21;xa=Ua+47500001528533176.0e-21;g[sa>>2]=xa;$a=xa}else{$a=qa}sa=Ba+1|0;if((sa|0)<(Aa|0)){Ba=sa;Va=$a}else{break}}Ya=a[za]|0}}while(0);DPa(E,Ya&255);za=c[J>>2]|0;ja=c[t>>2]|0;wa=e[ja+96>>1]|0;Ca=(wa>>>0)/((d[ja+(_<<5)|0]|0)>>>0)|0;Da=ja+98|0;if((a[Da]|0)==0){ab=0}else{Ba=0;while(1){Aa=p+(Ba<<2)|0;g[Aa>>2]=+U(+g[Aa>>2])*2.0;Aa=Ba+1|0;sa=a[Da]|0;if((Aa|0)<(sa&255|0)){Ba=Aa}else{ab=sa;break}}}b:do{if((_|0)==2){Ba=Ca>>>1;q4a(s,2,za,E,Ba,8,0);sa=za+(Ba<<2)|0;q4a(s,2,sa,E,Ba,16,1);Va=+g[za+(Ba-8<<2)>>2];qa=(+g[sa>>2]-Va)/9.0;xa=Va+qa;g[za+(Ba-7<<2)>>2]=xa;Va=qa+xa;g[za+(Ba-6<<2)>>2]=Va;xa=qa+Va;g[za+(Ba-5<<2)>>2]=xa;Va=qa+xa;g[za+(Ba-4<<2)>>2]=Va;xa=qa+Va;g[za+(Ba-3<<2)>>2]=xa;Va=qa+xa;g[za+(Ba-2<<2)>>2]=Va;xa=qa+Va;g[za+(Ba-1<<2)>>2]=xa;g[sa>>2]=qa+xa;xa=+g[za+(Ca-16<<2)>>2];g[za+(Ca-15<<2)>>2]=xa;g[za+(Ca-14<<2)>>2]=xa;g[za+(Ca-13<<2)>>2]=xa;g[za+(Ca-12<<2)>>2]=xa;g[za+(Ca-11<<2)>>2]=xa;g[za+(Ca-10<<2)>>2]=xa;g[za+(Ca-9<<2)>>2]=xa;g[za+(Ca-8<<2)>>2]=xa;g[za+(Ca-7<<2)>>2]=xa;g[za+(Ca-6<<2)>>2]=xa;g[za+(Ca-5<<2)>>2]=xa;g[za+(Ca-4<<2)>>2]=xa;g[za+(Ca-3<<2)>>2]=xa;g[za+(Ca-2<<2)>>2]=xa;g[za+(Ca-1<<2)>>2]=xa}else if((_|0)==1){sa=Ca>>>1;q4a(s,1,za,E,sa,2,0);Ba=za+(sa<<2)|0;q4a(s,1,Ba,E,sa,4,1);xa=+g[za+(sa-2<<2)>>2];qa=(+g[Ba>>2]-xa)/3.0;Va=xa+qa;g[za+(sa-1<<2)>>2]=Va;g[Ba>>2]=qa+Va;Va=+g[za+(Ca-4<<2)>>2];g[za+(Ca-3<<2)>>2]=Va;g[za+(Ca-2<<2)>>2]=Va;g[za+(Ca-1<<2)>>2]=Va}else if((_|0)==0){Ba=(wa>>>0)/((d[ja|0]|0)>>>0)|0;sa=Ba>>>1;if((sa|0)==0){break}Aa=Ba-1|0;Ba=c[K>>2]|0;Ka=0;va=ab;while(1){Va=+g[Ba+(Ka<<2)>>2];Ja=va&255;qa=Va*2.0;if((va&255)>>>0>1>>>0){xa=.5;Ua=.5;Ia=0;Ha=1;while(1){bb=Ua*(+g[p+(Ia<<2)>>2]-qa)*(+g[p+((Ia|2)<<2)>>2]-qa);cb=xa*(+g[p+(Ha<<2)>>2]-qa)*(+g[p+((Ia|3)<<2)>>2]-qa);Ga=Ia+4|0;Ea=Ga|1;if((Ea|0)<(Ja|0)){xa=cb;Ua=bb;Ia=Ga;Ha=Ea}else{db=cb;eb=bb;break}}}else{db=.5;eb=.5}g[za+(Ka<<2)>>2]=.5/(eb*(qa+2.0)*eb+db*(2.0-qa)*db);Ha=a[Da]|0;Ia=Ha&255;Ua=Va*-2.0;if((Ha&255)>>>0>1>>>0){xa=.5;bb=.5;Ha=0;Ja=1;while(1){cb=bb*(+g[p+(Ha<<2)>>2]-Ua)*(+g[p+((Ha|2)<<2)>>2]-Ua);fb=xa*(+g[p+(Ja<<2)>>2]-Ua)*(+g[p+((Ha|3)<<2)>>2]-Ua);La=Ha+4|0;Ma=La|1;if((Ma|0)<(Ia|0)){xa=fb;bb=cb;Ha=La;Ja=Ma}else{gb=fb;hb=cb;break}}}else{gb=.5;hb=.5}g[za+(Aa-Ka<<2)>>2]=.5/(hb*(Ua+2.0)*hb+gb*(2.0-Ua)*gb);Ja=Ka+1|0;if((Ja|0)>=(sa|0)){break b}Ka=Ja;va=a[Da]|0}}}while(0);do{if((a[da]|0)!=0){mf[c[L>>2]&2047](na,na,c[J>>2]|0,ha);if((d[da]|0)>>>0>1>>>0){ib=na;jb=1}else{break}do{ib=ib+(ha<<2)|0;jb=jb+1|0;mf[c[L>>2]&2047](ib,ib,c[J>>2]|0,ha);}while((jb|0)<(d[da]|0))}}while(0);ia=ia+1|0;}while((ia|0)<(ba|0))}ba=c[w>>2]|0;ia=c[z+(ba*1316|0)+4>>2]|0;da=c[z+(ba*1316|0)>>2]|0;ha=ca(e[N>>1]|0,ba)|0;ba=c[t>>2]|0;_=c[u>>2]|0;ma=c[O>>2]|0;la=_+(ma<<2)|0;c:do{if((c[(c[A>>2]|0)+416>>2]|0)>0){fa=ba+96|0;Z=s+40+(ia<<6)|0;ka=l+(d[109944+da|0]<<2)|0;ga=(ia|0)==1;aa=(da|0)==4;ea=s+40+(ia<<6)+44|0;na=ga?8:da;Da=(da|0)==7;za=0;ja=ba;while(1){wa=c[b>>2]|0;Ca=e[fa>>1]|0;va=ca(Ca,za)|0;Ka=e[ja+96>>1]|0;sa=ja+(ia<<5)|0;Aa=a[sa]|0;Ba=Aa&255;Ja=(Ka>>>0)/(Ba>>>0)|0;Ha=c[J>>2]|0;Ia=c[P>>2]|0;c[Q>>2]=(Ka>>>0)/((d[ja+64|0]|0)>>>0)|0;c[S>>2]=(Ka>>>0)/((d[ja+32|0]|0)>>>0)|0;c[T>>2]=(Ka>>>0)/(d[ja|0]<<1>>>0)|0;Ma=c[ka>>2]|0;if(!(Aa<<24>>24==0)){Aa=za<<1;La=Ja>>>1;Ea=0;Ga=Ia+((ca(Ka,Aa)|0)<<2)|0;Ia=_+((ca(Ca,Aa)|0)+ma+((Ka-Ja|0)/2|0)<<2)|0;Aa=Ba;while(1){if((Ea|0)==0&aa){kb=4}else{kb=(Ea|0)==(Aa-1|0)&Da?7:na}Ba=c[l+(d[109944+kb|0]<<2)>>2]|0;Ca=ca(Ea,Ja)|0;Pa=Ha+(Ca<<2)|0;ef[c[ea>>2]&4095](Z,Pa,wa+(Ca+va<<2)|0);Oa=Ja-Ba|0;Na=(Oa|0)/2|0;Qa=Ba>>>0>65535>>>0;lb=Qa?Ba>>>16:Ba;mb=Qa?16:0;if((lb&65280|0)==0){nb=mb;ob=lb}else{nb=mb|8;ob=lb>>>8}lb=(Ba|0)/2|0;pe[c[V>>2]&1023](Ga,Ia+(Na<<2)|0,Pa,c[1305896+((d[1359664+ob|0]|0)+nb<<2)>>2]|0,lb);nrc(Ga+(Ba<<2)|0,Ha+(lb+Ca<<2)|0,Ja-lb<<2)|0;lb=Ea+1|0;Pa=d[sa]|0;if((lb|0)<(Pa|0)){Ea=lb;Ga=Ga+((ga?Na:Oa)+Ba<<2)|0;Ia=Ha+(Ca+La<<2)|0;Aa=Pa}else{break}}}c[s+34200+(za<<2)>>2]=(Ma+Ka|0)/2|0;Aa=za+1|0;if((Aa|0)>=(c[(c[A>>2]|0)+416>>2]|0)){break c}za=Aa;ja=c[t>>2]|0}}}while(0);do{if(!W){ia=c[O>>2]|0;da=ba+96|0;ja=(e[da>>1]|0)-ia|0;za=c[y>>2]|0;ga=za+(ha<<2)|0;Z=ja<<2;nrc(ga|0,la|0,Z)|0;ea=ja+ha|0;ja=ia<<2;nrc(za+(ea<<2)|0,c[P>>2]|0,ja)|0;if((c[(c[A>>2]|0)+416>>2]|0)!=2){break}za=c[X>>2]|0;ia=za+(ha<<2)|0;nrc(ia|0,_+((e[da>>1]<<1)+ma<<2)|0,Z)|0;nrc(za+(ea<<2)|0,(c[P>>2]|0)+(e[da>>1]<<1<<2)|0,ja)|0;ef[c[Y>>2]&4095](ga,ia,e[da>>1]|0)}}while(0);ma=c[u>>2]|0;c[u>>2]=c[P>>2];c[P>>2]=ma;j=(c[w>>2]|0)+1|0;c[w>>2]=j;}while((j|0)<(c[q>>2]|0))}q=c[v>>2]|0;if((q|0)<2){c[v>>2]=q+1;c[h>>2]=0;x=r;i=k;return x|0}else{c[h>>2]=1;h=c[f>>2]|0;x=(r|0)==(h+1|0)?r:h;i=k;return x|0}return 0}function n4a(a){a=a|0;var b=0;b=c[a+60>>2]|0;PPa(b+40|0);kJb(c[b+34212>>2]|0);PPa(b+104|0);kJb(c[b+34216>>2]|0);PPa(b+168|0);kJb(c[b+34220>>2]|0);kJb(c[b+34192>>2]|0);kJb(c[b+34188>>2]|0);kJb(c[b+34196>>2]|0);kJb(c[b+34224>>2]|0);return 0}function o4a(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;h=i;i=i+16|0;j=h|0;k=f+60|0;l=c[k>>2]|0;m=l;n=l;c[n>>2]=f;c[f+420>>2]=8;o=f+432|0;p=c[o>>2]|0;do{if((p|0)==0){q=l+34228|0;r=(c[q>>2]|0)+7>>3;c[o>>2]=r;s=r;t=c[q>>2]|0}else{q=p<<3;r=c[l+34228>>2]|0;if((q|0)>=(r|0)){s=p;t=r;break}KIb(f,16,2593232,(u=i,i=i+16|0,c[u>>2]=q,c[u+8>>2]=r,u)|0);i=u;v=-1094995529;i=h;return v|0}}while(0);p=(s<<3|0)/(t|0)|0;c[l+34232>>2]=p;if((p|0)>2){KIb(f,16,2445072,(u=i,i=i+8|0,c[u>>2]=p,u)|0);i=u;v=-1094995529;i=h;return v|0}qHb(l+4|0,c[f+88>>2]&8388608);p=l+232|0;t=c[p>>2]|0;s=t+96|0;o=e[s>>1]|0;r=t|0;q=(o>>>0)/((d[r]|0)>>>0)|0;w=t+32|0;x=(o>>>0)/((d[w]|0)>>>0)|0;o=c[(c[n>>2]|0)+416>>2]|0;y=(o|0)==1?2.0:1.0;z=0;while(1){if((z|0)>=3){A=10;break}B=c[p>>2]|0;C=((e[B+96>>1]|0)>>>0)/((d[B+(z<<5)|0]|0)>>>0)|0;B=(C&65280|0)==0;D=OPa(m+40+(z<<6)|0,(d[1359664+(B?C:C>>>8)|0]|0)+1+(B?0:8)|0,1,+S(y/+(C|0))*-30517578125.0e-15)|0;if((D|0)==0){z=z+1|0}else{E=D;break}}a:do{if((A|0)==10){z=hJb(e[s>>1]<<2)|0;D=l+34224|0;c[D>>2]=z;C=b[s>>1]|0;do{if((z|0)==0){if(C<<16>>16==0){F=0;break}KIb(c[n>>2]|0,16,2293288,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12;break a}else{F=C&65535}}while(0);C=o<<3;z=hJb(ca(F,C)|0)|0;c[l+34188>>2]=z;B=e[s>>1]|0;do{if((z|0)==0){if(((ca(o<<1,B)|0)&1073741822|0)==0){break}KIb(c[n>>2]|0,16,2293288,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12;break a}}while(0);z=hJb(ca(B,C)|0)|0;c[l+34192>>2]=z;G=e[s>>1]|0;do{if((z|0)==0){if(((ca(o<<1,G)|0)&1073741822|0)==0){break}KIb(c[n>>2]|0,16,2293288,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12;break a}}while(0);z=hJb(ca(G,C)|0)|0;c[l+34196>>2]=z;B=e[s>>1]|0;do{if((z|0)==0){if(((ca(o<<1,B)|0)&1073741822|0)==0){break}KIb(c[n>>2]|0,16,2293288,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12;break a}}while(0);z=(B<<2>>>0)/((d[r]|0)>>>0)|0;y=6.283185307179586/+(z|0);C=z>>>2;G=hJb(C<<2)|0;H=G;c[l+34212>>2]=H;do{if((G|0)!=0|(C|0)==0){I=z>>>3;J=0;do{g[H+(J<<2)>>2]=+U(y*+(J<<1|1|0));J=J+1|0;}while((J|0)<=(I|0));if(z>>>0>15>>>0){J=1;do{g[H+(C-J<<2)>>2]=+g[H+(J<<2)>>2];J=J+1|0;}while((J|0)<(I|0))}I=(e[s>>1]<<2>>>0)/((d[w]|0)>>>0)|0;K=6.283185307179586/+(I|0);J=I>>>2;L=hJb(J<<2)|0;M=L;c[l+34216>>2]=M;if(!((L|0)!=0|(J|0)==0)){break}L=I>>>3;N=0;do{g[M+(N<<2)>>2]=+U(K*+(N<<1|1|0));N=N+1|0;}while((N|0)<=(L|0));if(I>>>0>15>>>0){N=1;do{g[M+(J-N<<2)>>2]=+g[M+(N<<2)>>2];N=N+1|0;}while((N|0)<(L|0))}L=(e[s>>1]<<2>>>0)/((d[t+64|0]|0)>>>0)|0;K=6.283185307179586/+(L|0);N=L>>>2;M=hJb(N<<2)|0;J=M;c[l+34220>>2]=J;if(!((M|0)!=0|(N|0)==0)){break}M=L>>>3;I=0;do{g[J+(I<<2)>>2]=+U(K*+(I<<1|1|0));I=I+1|0;}while((I|0)<=(M|0));if(L>>>0>15>>>0){I=1;do{g[J+(N-I<<2)>>2]=+g[J+(I<<2)>>2];I=I+1|0;}while((I|0)<(M|0))}M=(x&65280|0)==0;H0a((d[1359664+(M?x:x>>>8)|0]|0)+(M?0:8)|0);M=q>>>1;I=(M&32512|0)==0;H0a((d[1359664+(I?M:q>>>9)|0]|0)+(I?0:8)|0);I=e[s>>1]|0;M=(I&65280|0)==0;H0a((M?0:8)+(d[1359664+(M?I:I>>>8)|0]|0)|0);I=c[p>>2]|0;M=c[n>>2]|0;J=c[M+416>>2]|0;N=I+96|0;L=(d[I+105|0]|0)+(d[I+104|0]|0)+(ca(d[I+106|0]|0,d[I+107|0]|0)|0)|0;O=I+113|0;P=ca(d[I+17|0]|0,d[I+16|0]|0)|0;Q=ca(d[I+49|0]|0,d[I+48|0]|0)|0;R=(ca(e[N>>1]|0,c[M+72>>2]|0)|0)/(c[M+412>>2]|0)|0;M=(ca(L,J)|0)+(J<<3|4)|0;L=(ca((d[I+115|0]|0)+1+(d[O]|0)+(d[I+112|0]|0)+(ca(d[I+81|0]|0,d[I+80|0]|0)|0)|0,J)|0)+M|0;T=j+8|0;c[T>>2]=L;c[j>>2]=(ca(ca(P+6|0,J)|0,d[I|0]|0)|0)+M;P=(ca(ca(Q+6|0,J)|0,d[I+32|0]|0)|0)+M|0;M=j+4|0;c[M>>2]=P;do{if((c[l+36872>>2]|0)==1){if((c[l+236>>2]|0)!=0){break}c[M>>2]=P+2;c[T>>2]=L+2}}while(0);L=I+114|0;T=0;while(1){if((T|0)==3){P=ca(d[O]|0,J)|0;V=P;W=d[L]|0}else{V=R-(c[j+(T<<2)>>2]|0)|0;W=e[N>>1]|0}P=ca(W,J)|0;M=(V+13|0)/14|0;Q=m+34172+(T<<2)|0;c[Q>>2]=M;X=(V-1+M|0)/(M|0)|0;Y=(V|0)/(M|0)|0;Z=M+V-(ca(X,M)|0)|0;a[m+34140+(T<<1)|0]=(X+1|0)/2|0;a[m+34148+(T<<1)|0]=(X|0)/2|0;a[m+34140+(T<<1)+1|0]=(Y+1|0)/2|0;a[m+34148+(T<<1)+1|0]=(Y|0)/2|0;c[m+34156+(T<<2)>>2]=Z;Z=c[Q>>2]|0;Q=(P-1+Z|0)/(Z|0)|0;Y=Z+P-(ca(Q,Z)|0)|0;a[m+34128+(T<<1)|0]=Q;a[m+34128+(T<<1)+1|0]=(P|0)/(Z|0)|0;a[m+34136+T|0]=Y;Y=T+1|0;if((Y|0)<4){T=Y}else{_=0;break}}do{T=c[p>>2]|0;J=c[D>>2]|0;N=c[(c[n>>2]|0)+416>>2]|0;if((_|0)==3){$=d[T+114|0]|0;aa=N}else{R=d[T+(_<<5)|0]|0;L=ca(R,N)|0;$=((e[T+96>>1]|0)>>>0)/(R>>>0)|0;aa=L}L=c[m+34172+(_<<2)>>2]|0;R=m+34128+(_<<1)|0;T=m+34136+_|0;N=a[R]|0;if(!(N<<24>>24==0)){O=(aa|0)==1;I=(L|0)>0;Y=ca($,aa)|0;Z=(_|0)==2;P=m+34128+(_<<1)+1|0;Q=(L&1|0)==0;X=0;M=N;while(1){do{if(O){ba=0}else{if(Z){if(((L|0)%(aa|0)|0|0)!=0){ba=0;break}ba=(X|0)==(d[P]|0)?0:X;break}if(!Q){ba=0;break}N=(X|0)==(d[P]|0);if(N){ba=N?0:X;break}ba=ca(X,X)|0}}while(0);N=ca(X,L)|0;if(I){da=0;do{ea=da+N|0;if((ea|0)>=(Y|0)){break}b[J+(ea<<1)>>1]=((da+ba|0)%(L|0)|0)+N;da=da+1|0;}while((da|0)<(L|0));fa=a[R]|0}else{fa=M}da=X+1|0;if((da|0)<(fa&255|0)){X=da;M=fa}else{break}}}M=d[T]|0;if((L|0)>0){X=0;R=0;while(1){Y=((X|0)>=(M|0))+(m+34128+(_<<1))|0;if((a[Y]|0)==0){ga=R}else{I=0;P=R;while(1){Q=P+1|0;b[m+1360+(_<<13)+(P<<1)>>1]=b[J+((ca(I,L)|0)+X<<1)>>1]|0;Z=I+1|0;if((Z|0)<(d[Y]|0)){I=Z;P=Q}else{ga=Q;break}}}P=X+1|0;if((P|0)<(L|0)){X=P;R=ga}else{break}}}R=ca($,aa)|0;if((R|0)>0){X=0;do{L=m+1360+(_<<13)+(X<<1)|0;J=b[L>>1]|0;b[L>>1]=(ca((J|0)%(aa|0)|0,$)|0)+((J|0)/(aa|0)|0);X=X+1|0;}while((X|0)<(R|0))}_=_+1|0;}while(_>>>0<4>>>0);g[l+400>>2]=.10000000149011612;g[l+404>>2]=.10000000149011612;g[l+408>>2]=.10000000149011612;v=0;i=h;return v|0}}while(0);KIb(c[n>>2]|0,16,2293288,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;E=-12}}while(0);KIb(f,16,2356e3,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;u=c[k>>2]|0;PPa(u+40|0);kJb(c[u+34212>>2]|0);PPa(u+104|0);kJb(c[u+34216>>2]|0);PPa(u+168|0);kJb(c[u+34220>>2]|0);kJb(c[u+34192>>2]|0);kJb(c[u+34188>>2]|0);kJb(c[u+34196>>2]|0);kJb(c[u+34224>>2]|0);v=E;i=h;return v|0}function p4a(e,f,h,i,j,k,l){e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0;m=c[e+34172+(i<<2)>>2]|0;if((m|0)<=0){return}n=e+34136+i|0;o=c[e+34156+(i<<2)>>2]|0;p=0;q=0;r=f;while(1){f=a[((p|0)>=(d[n]|0))+(e+34128+(i<<1))|0]|0;s=f&255;t=(p|0)>=(o|0)|0;u=d[r]|0;if((a[e+34140+(i<<1)+t|0]|0)==7){v=(u>>>5&2^2)-1|0;w=u&63}else{v=1;w=u}u=r+2|0;x=d[r+1|0]|0;if((a[e+34148+(i<<1)+t|0]|0)==7){y=(x>>>5&2^2)-1|0;z=x&63}else{y=1;z=x}x=ca(w,l)|0;t=ca(z,l)|0;if(!(f<<24>>24==0)){f=0;do{A=ca(b[j+(f+x<<1)>>1]|0,v)|0;B=+((ca(b[k+(f+t<<1)>>1]|0,y)|0)+A|0);g[h+(b[e+1360+(i<<13)+(f+q<<1)>>1]<<2)>>2]=B;f=f+1|0;}while((f|0)<(s|0))}f=p+1|0;if((f|0)>=(m|0)){break}p=f;q=s+q|0;r=u}return}function q4a(b,d,e,f,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0.0,n=0,o=0,p=0.0,q=0.0,r=0,s=0.0,t=0.0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0,K=0,L=0,M=0.0,N=0.0,O=0,P=0,Q=0.0,R=0.0;k=c[b+232>>2]|0;l=c[b+34212+(d<<2)>>2]|0;if((h|0)>0){d=k+98|0;if((j|0)==0){b=0;do{m=+g[l+(b<<2)>>2]*2.0;n=a[d]|0;o=n&255;if((n&255)>>>0>1>>>0){p=.5;q=.5;n=0;r=1;while(1){s=q*(+g[f+(n<<2)>>2]-m)*(+g[f+((n|2)<<2)>>2]-m);t=p*(+g[f+(r<<2)>>2]-m)*(+g[f+((n|3)<<2)>>2]-m);u=n+4|0;v=u|1;if((v|0)<(o|0)){p=t;q=s;n=u;r=v}else{w=t;x=s;break}}}else{w=.5;x=.5}g[e+(b<<2)>>2]=.5/(x*(m+2.0)*x+w*(2.0-m)*w);b=b+i|0;}while((b|0)<(h|0))}else{b=0;do{w=+g[l+(~b+h<<2)>>2]*-2.0;r=a[d]|0;n=r&255;if((r&255)>>>0>1>>>0){x=.5;q=.5;r=0;o=1;while(1){p=q*(+g[f+(r<<2)>>2]-w)*(+g[f+((r|2)<<2)>>2]-w);s=x*(+g[f+(o<<2)>>2]-w)*(+g[f+((r|3)<<2)>>2]-w);v=r+4|0;u=v|1;if((u|0)<(n|0)){x=s;q=p;r=v;o=u}else{y=s;z=p;break}}}else{y=.5;z=.5}g[e+(b<<2)>>2]=.5/(z*(w+2.0)*z+y*(2.0-w)*y);b=b+i|0;}while((b|0)<(h|0))}}b=i<<1;d=h-b|0;if((d|0)<(i|0)){A=i-1|0;B=+(i|0)}else{o=(i|0)/2|0;r=(j|0)==0;j=k+98|0;k=o-1|0;y=+(o|0);n=(k|0)>0;u=1-i|0;v=i-1|0;z=+(i|0);C=(v|0)>0;D=i;while(1){E=D+i|0;q=+g[e+(E<<2)>>2];F=e+(D-i<<2)|0;x=+g[F>>2];G=e+(D<<2)|0;m=+g[G>>2];do{if(q+x<=m*1.95&q<x){H=D-o|0;if(r){I=+g[l+(H<<2)>>2]}else{I=-0.0- +g[l+(~H+h<<2)>>2]}J=a[j]|0;K=J&255;p=I*2.0;if((J&255)>>>0>1>>>0){s=.5;t=.5;J=0;L=1;while(1){M=t*(+g[f+(J<<2)>>2]-p)*(+g[f+((J|2)<<2)>>2]-p);N=s*(+g[f+(L<<2)>>2]-p)*(+g[f+((J|3)<<2)>>2]-p);O=J+4|0;P=O|1;if((P|0)<(K|0)){s=N;t=M;J=O;L=P}else{Q=N;R=M;break}}}else{Q=.5;R=.5}t=.5/(R*(p+2.0)*R+Q*(2.0-p)*Q);L=e+(H<<2)|0;g[L>>2]=t;s=+g[F>>2];M=(t-s)/y;if(!n){break}J=u+D|0;K=0;t=s;do{t=M+t;g[e+(J+K<<2)>>2]=t;K=K+1|0;}while((K|0)<(k|0));t=+g[L>>2];M=(+g[G>>2]-t)/y;if(!n){break}K=D+1-o|0;J=0;p=t;do{p=M+p;g[e+(K+J<<2)>>2]=p;J=J+1|0;}while((J|0)<(k|0))}else{p=(m-x)/z;if(!C){break}J=u+D|0;K=0;M=x;do{M=p+M;g[e+(J+K<<2)>>2]=M;K=K+1|0;}while((K|0)<(v|0))}}while(0);if((E|0)>(d|0)){A=v;B=z;break}else{D=E}}}z=+g[e+(d<<2)>>2];y=(+g[e+(h-i<<2)>>2]-z)/B;if((A|0)<=0){return}i=h+1-b|0;b=0;B=z;do{B=y+B;g[e+(i+b<<2)>>2]=B;b=b+1|0;}while((b|0)<(A|0));return}function r4a(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;f=c[a+60>>2]|0;g=c[a+96>>2]|0;do{if((g|0)!=0){if((c[a+100>>2]|0)<12){break}h=g;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=je(j|0)|0;k=h+1|0;c[a+416>>2]=k;l=g+4|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)*1e3|0;c[a+72>>2]=m;l=g+8|0;n=je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;if((n-8|0)>>>0>36>>>0){KIb(a,16,2355968,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}if((n|0)==22){c[a+412>>2]=22050;q=22050}else if((n|0)==11){c[a+412>>2]=11025;q=11025}else if((n|0)==44){c[a+412>>2]=44100;q=44100}else{l=n*1e3|0;c[a+412>>2]=l;q=l}if(h>>>0>1>>>0){KIb(a,16,2293248,(o=i,i=i+8|0,c[o>>2]=k,o)|0);i=o;p=-1;i=b;return p|0}h=(j|0)==0;j=a+448|0;c[j>>2]=h?4:3;c[j+4>>2]=h?0:0;h=(m|0)/(k*1e3|0|0)|0;if((h-8|0)>>>0>40>>>0){KIb(a,16,2242144,(o=i,i=i+8|0,c[o>>2]=h,o)|0);i=o;p=-1094995529;i=b;return p|0}k=h+(n<<8)|0;if((k|0)==2826){c[f+232>>2]=830072;r=830072}else if((k|0)==5656){c[f+232>>2]=829712;r=829712}else if((k|0)==11312){c[f+232>>2]=829296;r=829296}else if((k|0)==5664){c[f+232>>2]=829592;r=829592}else if((k|0)==5652){c[f+232>>2]=829832;r=829832}else if((k|0)==11304){c[f+232>>2]=829416;r=829416}else if((k|0)==4112){c[f+232>>2]=829952;r=829952}else if((k|0)==2824){c[f+232>>2]=830192;r=830192}else if((k|0)==2056){c[f+232>>2]=830312;r=830312}else{KIb(a,16,2200928,(o=i,i=i+16|0,c[o>>2]=n,c[o+8>>2]=n,o)|0);i=o;p=-1;i=b;return p|0}c[f+36872>>2]=0;c[f+36876>>2]=746;c[f+36880>>2]=2;c[f+36884>>2]=204;n=((ca(e[r+96>>1]|0,m)|0)/(q|0)|0)+8|0;c[f+34228>>2]=n;c[f+236>>2]=0;m=c[a+432>>2]|0;do{if((m|0)!=0){if(((m<<3|0)/(n|0)|0|0)<=1){break}KIb(a,16,2169104,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}}while(0);p=o4a(a)|0;i=b;return p|0}}while(0);KIb(a,16,2445032,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=b;return p|0}function s4a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;j=c[e+232>>2]|0;k=c[(c[e>>2]|0)+416>>2]|0;l=g<<3;g=l>>>0>2147483639>>>0|(f|0)==0;m=g?0:f;f=g?8:l+8|0;l=m;g=((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)&255)+(f>>>0>8>>>0?8:f)|0;l=f>>>0>g>>>0?g:f;g=m+(l>>>3)|0;n=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(l&7);g=n>>>28;o=l+4|0;l=f>>>0>o>>>0?o:f;c[e+34240>>2]=g;if(n>>>0>2415919103>>>0){KIb(b,16,2142232,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;p=-1094995529;i=h;return p|0}b=c[1276760+(g<<2)>>2]|0;g=e+34244|0;c[g>>2]=b;n=a[j+(b<<5)|0]|0;o=n&255;q=e+34172+(b<<2)|0;if((c[q>>2]|0)>0){r=e+34156+(b<<2)|0;s=0;t=e+34248|0;u=l;while(1){v=(s|0)>=(c[r>>2]|0)|0;w=d[e+34140+(b<<1)+v|0]|0;x=m+(u>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>((32-w|0)>>>0);x=w+u|0;w=f>>>0>x>>>0?x:f;a[t]=y;y=d[e+34148+(b<<1)+v|0]|0;v=m+(w>>>3)|0;x=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(w&7)>>>((32-y|0)>>>0);v=w+y|0;y=f>>>0>v>>>0?v:f;a[t+1|0]=x;x=s+1|0;if((x|0)<(c[q>>2]|0)){s=x;t=t+2|0;u=y}else{z=y;break}}}else{z=l}l=(k|0)>0;do{if(l){u=n<<24>>24==0;t=z;s=0;while(1){if(u){A=t}else{q=t;b=0;r=c[g>>2]|0;while(1){if((a[j+(r<<5)+16|0]|0)==0){B=q;C=r}else{y=q;x=0;v=r;while(1){w=d[j+(v<<5)+17|0]|0;D=m+(y>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(y&7)>>>((32-w|0)>>>0);D=w+y|0;w=f>>>0>D>>>0?D:f;a[e+35366+(s<<6)+(b<<2)+x|0]=E;E=x+1|0;D=c[g>>2]|0;if((E|0)<(d[j+(D<<5)+16|0]|0)){y=w;x=E;v=D}else{B=w;C=D;break}}}v=b+1|0;if((v|0)<(o|0)){q=B;b=v;r=C}else{A=B;break}}}r=s+1|0;if((r|0)<(k|0)){t=A;s=r}else{break}}if(n<<24>>24==0|l^1){F=A;break}else{G=A;H=0}while(1){s=G;t=0;while(1){I=((s|0)<(f|0))+s|0;a[e+35494+(H<<4)+t|0]=d[m+(s>>>3)|0]<<(s&7)>>>7&1;u=t+1|0;if((u|0)<(o|0)){s=I;t=u}else{break}}t=H+1|0;if((t|0)<(k|0)){G=I;H=t}else{F=I;break}}}else{F=z}}while(0);a:do{if((c[g>>2]|0)==2){if(l){J=F;K=0}else{L=F;break}while(1){z=m+(J>>>3)|0;I=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(J&7)>>>24;z=J+8|0;H=f>>>0>z>>>0?z:f;a[e+35332+K|0]=I;I=K+1|0;if((I|0)<(k|0)){J=H;K=I}else{M=H;N=25;break}}}else{if(!l){L=F;break}if(n<<24>>24==0){H=F;I=0;while(1){z=m+(H>>>3)|0;G=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(H&7)>>>24;z=H+8|0;A=f>>>0>z>>>0?z:f;a[e+35332+I|0]=G;G=I+1|0;if((G|0)<(k|0)){H=A;I=G}else{M=A;N=25;break a}}}else{O=F;P=0}while(1){I=m+(O>>>3)|0;H=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(O&7)>>>24;I=O+8|0;a[e+35332+P|0]=H;H=ca(P,o)|0;A=f>>>0>I>>>0?I:f;I=0;do{G=m+(A>>>3)|0;z=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(A&7)>>>27;G=A+5|0;A=f>>>0>G>>>0?G:f;a[I+H+(e+35334)|0]=z;I=I+1|0;}while((I|0)<(o|0));I=P+1|0;if((I|0)<(k|0)){O=A;P=I}else{M=A;N=25;break}}}}while(0);do{if((N|0)==25){if(!l){L=M;break}P=j+104|0;O=j+105|0;o=j+107|0;F=j+106|0;n=M;K=0;while(1){J=d[P]|0;I=m+(n>>>3)|0;H=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(n&7)>>>((32-J|0)>>>0);I=J+n|0;J=f>>>0>I>>>0?I:f;a[e+35536+K|0]=H;H=d[O]|0;I=m+(J>>>3)|0;z=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(J&7)>>>((32-H|0)>>>0);I=J+H|0;H=f>>>0>I>>>0?I:f;a[e+35526+K|0]=z;if((a[o]|0)==0){Q=H}else{z=H;H=0;while(1){I=d[F]|0;J=m+(z>>>3)|0;G=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(z&7)>>>((32-I|0)>>>0);J=I+z|0;I=f>>>0>J>>>0?J:f;a[e+35528+(K<<2)+H|0]=G;G=H+1|0;if((G|0)<(d[o]|0)){z=I;H=G}else{Q=I;break}}}H=K+1|0;if((H|0)<(k|0)){n=Q;K=H}else{L=Q;break}}}}while(0);do{if((c[g>>2]|0)==2){Q=e+34184|0;if((c[Q>>2]|0)>0){M=e+34168|0;N=0;K=e+35272|0;n=L;while(1){o=(N|0)>=(c[M>>2]|0)|0;F=d[e+34146+o|0]|0;O=m+(n>>>3)|0;P=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(n&7)>>>((32-F|0)>>>0);O=F+n|0;F=f>>>0>O>>>0?O:f;a[K]=P;P=d[e+34154+o|0]|0;o=m+(F>>>3)|0;O=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(F&7)>>>((32-P|0)>>>0);o=F+P|0;P=f>>>0>o>>>0?o:f;a[K+1|0]=O;O=N+1|0;if((O|0)<(c[Q>>2]|0)){N=O;K=K+2|0;n=P}else{R=P;break}}}else{R=L}if(!l){S=R;break}n=j+112|0;K=j+115|0;N=R;Q=0;while(1){M=d[n]|0;P=m+(N>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(N&7)>>>((32-M|0)>>>0);P=M+N|0;M=f>>>0>P>>>0?P:f;c[e+35540+(Q<<2)>>2]=O;O=d[K]|0;P=m+(M>>>3)|0;o=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7)>>>((32-O|0)>>>0);P=M+O|0;O=f>>>0>P>>>0?P:f;c[e+35548+(Q<<2)>>2]=o;o=Q+1|0;if((o|0)<(k|0)){N=O;Q=o}else{S=O;break}}}else{S=L}}while(0);p=(S+7|0)/8|0;i=h;return p|0}function t4a(e,f,h,j,k,l,m){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=+l;m=m|0;var n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0.0,G=0,H=0,I=0,J=0,K=0,L=0;n=i;i=i+16|0;o=n|0;p=c[e+232>>2]|0;g[o>>2]=.4000000059604645;g[o+4>>2]=.3499999940395355;g[o+8>>2]=.2800000011920929;q=+g[o+(m<<2)>>2];o=a[p+(m<<5)+16|0]|0;r=o&255;s=(d[p+(m<<5)+8|0]|0)/(o&255)|0;t=s&255;if(s<<24>>24==0){i=n;return}s=o<<24>>24==0;o=p+(m<<5)+12|0;u=(h|0)==0;h=p+(m<<5)+4|0;v=1.0-q;p=r>>>0>1>>>0?r:1;w=0;x=0;y=k;while(1){if(s){z=x;A=y}else{k=c[o>>2]|0;if(u){B=0;C=x;D=y;while(1){E=+(b[k+((ca(d[f+B|0]|0,t)|0)+w<<1)>>1]|0)*.000244140625;F=E+1.0;g[e+400+(m*320|0)+(j*160|0)+(C<<2)>>2]=E;E=(F<-1.0?1.0:F)*l;G=b[(c[h>>2]|0)+(C<<1)>>1]|0;H=G&65535;if(!(G<<16>>16==0)){G=D;I=H;while(1){J=I-1|0;g[G>>2]=E;if((J|0)==0){break}else{G=G+4|0;I=J}}}I=D+(H<<2)|0;G=B+1|0;if((G|0)<(r|0)){B=G;C=C+1|0;D=I}else{K=I;break}}}else{D=0;C=x;B=y;while(1){E=+(b[k+((ca(d[f+D|0]|0,t)|0)+w<<1)>>1]|0)*.000244140625;I=e+400+(m*320|0)+(j*160|0)+(C<<2)|0;F=v*E+q*+g[I>>2]+1.0;g[I>>2]=E;E=(F<-1.0?1.0:F)*l;I=b[(c[h>>2]|0)+(C<<1)>>1]|0;G=I&65535;if(!(I<<16>>16==0)){I=B;J=G;while(1){L=J-1|0;g[I>>2]=E;if((L|0)==0){break}else{I=I+4|0;J=L}}}J=B+(G<<2)|0;I=D+1|0;if((I|0)<(r|0)){D=I;C=C+1|0;B=J}else{K=J;break}}}z=p+x|0;A=K}B=w+1|0;if((B|0)<(t|0)){w=B;x=z;y=A}else{break}}i=n;return}function u4a(b,f,h,i,j){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;k=c[b+232>>2]|0;l=c[b>>2]|0;b=c[l+412>>2]|0;m=(b|0)/1e3|0;n=e[k+96>>1]|0;o=n*80|0;p=m>>1;q=-p|0;r=(((o|0)!=0?p:q)+o|0)/(m|0)|0;o=n*480|0;s=25.0e3/+((1<<(d[k+115|0]|0))-1|0);t=(+(h|0)*s+s*.5)/25.0e3;if(t<-1.0){u=-1.0}else{u=t>1.0?1.0:t}t=(u>0.0?25.0e3:-25.0e3)*(+$(+R(+u)*5.303304908059076)+-1.0)/200.0*.0001220703125;h=ca(((((o|0)!=0?p:q)+o|0)/(m|0)|0)-r|0,f)|0;f=(1<<(d[k+112|0]|0))-1|0;m=f>>1;o=((((h|0)>0?m:-m|0)+h|0)/(f|0)|0)+r|0;do{if((b-22e3|0)>>>0<1e3>>>0){if(((c[l+72>>2]|0)/((c[l+416>>2]|0)*1e3|0|0)|0|0)!=32){v=6;break}r=ca(e[k+116>>1]|0,o+800|0)|0;f=n*400|0;h=f>>>1;w=(((r|0)>0?h:-h|0)+r|0)/(f|0)|0}else{v=6}}while(0);if((v|0)==6){w=(ca(e[k+116>>1]|0,o)|0)/(n*400|0|0)|0}n=a[k+114|0]|0;k=n&255;l=i+(k<<2)|0;b=(w|0)/2|0;if((w|0)>1){f=(b|0)>1;r=0;h=i;while(1){m=j+(r<<2)|0;g[m>>2]=+g[m>>2]+t*+g[h>>2];m=r+1|0;if((m|0)<(b|0)){r=m;h=h+4|0}else{break}}x=i+((f?b:1)<<2)|0}else{x=i}i=w>>1;b=((n<<24>>24!=0?i:-i|0)+k|0)/(w|0)|0;k=(w|0)/-2|0;i=(w+1|0)/2|0;w=(k|0)<(i|0);n=i-k|0;f=x;x=1;while(1){h=(x|0)<(b|0);r=(ca(x,o)|0)+200|0;do{if(((r|0)%400|0|0)==0){if(((x|0)%5|0|0)!=0){v=14;break}m=(r|0)/400|0;q=(x|0)/5|0;p=c[316752+(q<<3)>>2]|0;y=m-1|0;z=(y<<1|0)/(p|0)|0;A=z>>>0>65535>>>0;B=A?z>>>16:z;z=A?16:0;if((B&65280|0)==0){C=z;D=B}else{C=z|8;D=B>>>8}E=m-(d[(c[316756+(q<<3)>>2]|0)+((ca((d[1359664+D|0]|0)+C|0,p)|0)+((y|0)%(p|0)|0))|0]|0)|0}else{v=14}}while(0);if((v|0)==14){v=0;E=(r|0)/400|0}if(!h){break}if(w){p=k;y=f;while(1){q=j+(p+E<<2)|0;g[q>>2]=+g[q>>2]+t*+g[y>>2];q=p+1|0;if((q|0)<(i|0)){p=q;y=y+4|0}else{break}}F=f+(n<<2)|0}else{F=f}f=F;x=x+1|0}if(w&f>>>0<l>>>0){G=k;H=f}else{return}while(1){f=H+4|0;k=j+(G+E<<2)|0;g[k>>2]=+g[k>>2]+t*+g[H>>2];k=G+1|0;if((k|0)<(i|0)&f>>>0<l>>>0){G=k;H=f}else{break}}return}function v4a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=i;i=i+16|0;j=h|0;k=e;l=c[g+24>>2]|0;m=g+28|0;g=c[m>>2]|0;if(!((g|0)>-1)){KIb(0,0,2242112,(n=i,i=i+24|0,c[n>>2]=2200912,c[n+8>>2]=2169080,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}o=j|0;c[o>>2]=l;c[j+8>>2]=l;p=l+g|0;q=j+4|0;c[q>>2]=p;r=p;if((g|0)<4){s=0;t=l}else{g=l+4|0;c[o>>2]=g;u=l;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;t=g}g=r-t|0;u=g>>>0>72>>>0?72:g;g=t+u|0;c[o>>2]=g;if((r-g|0)<4){v=0;w=g}else{l=t+(u+4)|0;c[o>>2]=l;u=g;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;w=l}if((r-w|0)<2){x=0;y=w}else{l=w+2|0;c[o>>2]=l;u=w;x=(d[u]|d[u+1|0]<<8)<<16>>16&65535;y=l}if((r-y|0)<2){z=0;A=y}else{l=y+2|0;c[o>>2]=l;u=y;z=(d[u]|d[u+1|0]<<8)<<16>>16&65535;A=l}if((r-A|0)<1){B=0;C=A}else{l=A+1|0;c[o>>2]=l;B=d[A]|0;C=l}l=r-C|0;A=l>>>0>2>>>0?2:l;l=C+A|0;c[o>>2]=l;if((r-l|0)<1){D=0;E=l}else{u=C+(A+1)|0;c[o>>2]=u;D=a[l]&1;E=u}if((s-8|0)>>>0>1>>>0){KIb(b,16,2444992,(n=i,i=i+8|0,c[n>>2]=s,n)|0);i=n;F=-1163346256;i=h;return F|0}s=(B|0)==8;do{if(s){c[b+140>>2]=11}else{if((B|0)==32|(B|0)==16){c[b+140>>2]=30;break}KIb(b,16,2355920,(n=i,i=i+8|0,c[n>>2]=B,n)|0);i=n;F=-1163346256;i=h;return F|0}}while(0);u=H4a(b,x,z)|0;if((u|0)<0){F=u;i=h;return F|0}u=M4a(b,k,0)|0;if((u|0)<0){F=u;i=h;return F|0}c[e+88>>2]=1;u=c[e>>2]|0;k=c[e+32>>2]|0;a:do{if(s){l=c[e+4>>2]|0;A=0;C=E;while(1){if((r-C|0)<4){G=0;H=C}else{y=C+4|0;c[o>>2]=y;w=C;G=je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;H=y}c[l+(A<<2)>>2]=G>>>8|G<<24;y=A+1|0;if(y>>>0<256>>>0){A=y;C=H}else{break}}C=r-H|0;if(C>>>0<(ca(z,x)|0)>>>0){F=-1094995529;i=h;return F|0}A=H+(C>>>0>4>>>0?4:C)|0;c[o>>2]=A;if((z|0)==0){break}else{I=1;J=u;K=A;L=p}while(1){A=L-K|0;C=A>>>0>x>>>0?x:A;nrc(J|0,K|0,C)|0;A=(c[o>>2]|0)+C|0;c[o>>2]=A;if(!(I>>>0<z>>>0)){break a}I=I+1|0;J=J+k|0;K=A;L=c[q>>2]|0}}else{do{if((B|0)==16){A=r-E|0;C=E+(A>>>0>4>>>0?4:A)|0;c[o>>2]=C;if((v|0)==0){if((D|0)==0){break}}else if((v|0)==861165636){if((r-C|0)>>>0<(ca(x>>>2<<4,z>>>2)|0)>>>0){F=-1094995529;i=h;return F|0}else{dtb(j,u,x,z,k);break a}}else if((v|0)!=827611204){break}if((r-C|0)>>>0<(ca(x>>>2<<3,z>>>2)|0)>>>0){F=-1094995529;i=h;return F|0}else{btb(j,u,x,z,k);break a}}else if((B|0)==32){if(!((v-21|0)>>>0<2>>>0)){break}C=x<<2;if((r-E|0)>>>0<(ca(C,z)|0)>>>0){F=-1094995529;i=h;return F|0}if((z|0)==0){break a}else{M=1;N=u;O=E;P=p}while(1){A=P-O|0;l=A>>>0>C>>>0?C:A;nrc(N|0,O|0,l)|0;A=(c[o>>2]|0)+l|0;c[o>>2]=A;if(!(M>>>0<z>>>0)){break a}M=M+1|0;N=N+k|0;O=A;P=c[q>>2]|0}}else{break a}}while(0);KIb(b,16,2293216,(n=i,i=i+8|0,c[n>>2]=v,n)|0);i=n;F=-1163346256;i=h;return F|0}}while(0);c[f>>2]=1;F=c[m>>2]|0;i=h;return F|0}function w4a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;d=c[a+120>>2]|0;c[b+4>>2]=d;e=c[a+124>>2]|0;c[b+8>>2]=e;c[b+12>>2]=ca((e|0)/8|0,(d|0)/8|0)|0;c[a+140>>2]=6;c[b+20>>2]=284712;a=UHb()|0;c[b+16>>2]=a;return((a|0)==0?-12:0)|0}function x4a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;h=i;i=i+40|0;j=h|0;k=h+16|0;l=h+24|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;o=g+16|0;p=N4a(b,c[o>>2]|0)|0;if((p|0)<0){q=p;i=h;return q|0}if(!((n|0)>-1)){KIb(0,0,2242080,(r=i,i=i+24|0,c[r>>2]=2200896,c[r+8>>2]=2169056,c[r+16>>2]=135,r)|0);i=r;Hd();return 0}p=g+24|0;c[p>>2]=m;c[g+32>>2]=m;s=g+28|0;c[s>>2]=m+n;m=g+12|0;t=g+8|0;u=b;b=g+4|0;v=k|0;w=k+1|0;x=k+2|0;y=k+3|0;k=g+20|0;g=j|0;z=j+1|0;A=j+2|0;B=j+3|0;C=j+4|0;D=j+5|0;E=j+6|0;F=j+7|0;G=j+8|0;H=j+9|0;I=j+10|0;J=j+11|0;K=j+12|0;L=j+13|0;M=j+14|0;N=j+15|0;O=l|0;P=l+1|0;Q=l+2|0;R=l+3|0;S=l+4|0;T=l+5|0;U=l+6|0;V=l+7|0;W=l+8|0;X=l+9|0;Y=l+10|0;Z=l+11|0;_=l+12|0;$=l+13|0;aa=l+14|0;ba=l+15|0;da=0;ea=0;fa=0;ga=0;ha=0;ia=0;a:while(1){ja=c[m>>2]|0;if((fa|0)>=(ja|0)){ka=61;break}if((ea|0)>=(c[t>>2]|0)){ka=61;break}la=c[p>>2]|0;ma=c[s>>2]|0;if((ma|0)==(la|0)){ka=62;break}na=la+1|0;c[p>>2]=na;oa=a[la]|0;pa=oa&255;if((pa&248|0)==112){switch(pa|0){case 112:{if((ma-na|0)<1){da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=0;continue a}c[p>>2]=la+2;qa=a[na]|0;ra=qa&255;if(!((qa&255)>>>0>1>>>0)){da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=ra;continue a}KIb(u,32,2444944,(r=i,i=i+8|0,c[r>>2]=ra,r)|0);i=r;da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=ra;continue a;break};case 116:{if((ma-na|0)<1){sa=0}else{c[p>>2]=la+2;sa=d[na]|0}ra=sa+fa|0;if((ra|0)>=(ja|0)){da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=ia;continue a}ja=(sa<<3)+da|0;qa=c[b>>2]|0;if((ja|0)<(qa|0)){da=ja;ea=ea;fa=ra;ga=ga;ha=ha;ia=ia;continue a}else{ta=ja;ua=ea}while(1){ja=ta-qa|0;va=ua+8|0;if((ja|0)<(qa|0)){da=ja;ea=va;fa=ra;ga=ga;ha=ha;ia=ia;continue a}else{ta=ja;ua=va}}break};case 114:{da=da;ea=ea;fa=fa;ga=ga^1;ha=ha;ia=ia;continue a;break};case 113:{da=da;ea=ea;fa=fa;ga=ga;ha=1;ia=ia;continue a;break};case 115:{ka=61;break a;break};default:{KIb(u,32,2355888,(r=i,i=i+8|0,c[r>>2]=pa,r)|0);i=r;da=da;ea=ea;fa=fa;ga=ga;ha=ha;ia=ia;continue a}}}do{if((ha|ga|0)==0){if(oa<<24>>24==0){wa=0;xa=1;ya=ha;break}if((ma-na|0)<1){wa=0;xa=1;ya=ha;break}c[p>>2]=la+2;wa=d[na]|0;xa=1;ya=ha}else{wa=0;xa=0;ya=0}}while(0);na=(ia|0)==0;la=0;ma=0;oa=wa;while(1){ra=la<<1;qa=pa>>>((6-ra|0)>>>0)&3;do{if((qa|0)==0){za=oa;Aa=ma}else{do{if(xa){Ba=oa}else{va=c[p>>2]|0;if(((c[s>>2]|0)-va|0)<1){Ba=0;break}c[p>>2]=va+1;Ba=d[va]|0}}while(0);va=(c[1901608+(ra<<2)>>2]|0)+da|0;ja=(c[1901608+((ra|1)<<2)>>2]|0)+ea|0;b:do{if((qa|0)==3){Ca=c[p>>2]|0;Da=(c[s>>2]|0)-Ca|0;if(!na){if(Da>>>0<12>>>0){ka=62;break a}Ea=Ca+3|0;c[p>>2]=Ea;Fa=a[Ca]|0;Ga=(d[Ca+1|0]|0)<<8;Ha=a[Ca+2|0]|0;Ia=(Fa&255)>>>2;a[O]=Ia;a[P]=(Ga|(Fa&255)<<16)>>>12&63;a[Q]=(Ga|Ha&255)>>>6&63;a[R]=Ha&63;Ha=Ca+6|0;c[p>>2]=Ha;Ga=a[Ea]|0;Ea=(d[Ca+4|0]|0)<<8;Fa=a[Ca+5|0]|0;a[S]=(Ga&255)>>>2;a[T]=(Ea|(Ga&255)<<16)>>>12&63;a[U]=(Ea|Fa&255)>>>6&63;a[V]=Fa&63;Fa=Ca+9|0;c[p>>2]=Fa;Ea=a[Ha]|0;Ha=(d[Ca+7|0]|0)<<8;Ga=a[Ca+8|0]|0;a[W]=(Ea&255)>>>2;a[X]=(Ha|(Ea&255)<<16)>>>12&63;a[Y]=(Ha|Ga&255)>>>6&63;a[Z]=Ga&63;c[p>>2]=Ca+12;Ga=a[Fa]|0;Fa=(d[Ca+10|0]|0)<<8;Ha=a[Ca+11|0]|0;a[_]=(Ga&255)>>>2;a[$]=(Fa|(Ga&255)<<16)>>>12&63;a[aa]=(Fa|Ha&255)>>>6&63;a[ba]=Ha&63;Ha=c[o>>2]|0;Fa=Ha+32|0;Ga=(c[Ha>>2]|0)+((ca(c[Fa>>2]|0,ja)|0)+va)|0;Ea=(va|0)/4|0;Ja=(ja|0)/4|0;Ka=(c[Ha+4>>2]|0)+((ca(c[Ha+36>>2]|0,Ja)|0)+Ea)|0;La=(c[Ha+8>>2]|0)+((ca(c[Ha+40>>2]|0,Ja)|0)+Ea)|0;a[Ka]=a[301096+(Ba>>4)|0]|0;a[La]=a[301096+(Ba&15)|0]|0;La=Ga;Ga=0;Ka=Ia;while(1){Ia=Ga&3;a[La+Ia|0]=a[284648+(Ka&255)|0]|0;if((Ia|0)==3){Ma=La+(c[Fa>>2]|0)|0}else{Ma=La}Ia=Ga+1|0;if((Ia|0)>=16){Na=ma;ka=57;break b}La=Ma;Ga=Ia;Ka=a[l+Ia|0]|0}}if(Da>>>0<4>>>0){ka=62;break a}Ka=Ca+1|0;c[p>>2]=Ka;Ga=d[Ca]|0;if((Ga&128|0)!=0){La=Ga>>>4&7;c[p>>2]=Ca+2;Fa=a[Ka]|0;a[v]=(Fa&255|Ga<<8)>>>6&63;a[w]=Fa&63;Fa=c[p>>2]|0;c[p>>2]=Fa+1;a[x]=a[Fa]&63;Fa=c[p>>2]|0;c[p>>2]=Fa+1;a[y]=a[Fa]&63;z4a(c[o>>2]|0,va,ja,v,Ba,La);Na=La;ka=57;break}La=Ca+2|0;c[p>>2]=La;Fa=d[Ka]|0;c[p>>2]=Ca+3;a[v]=a[La]&63;La=c[p>>2]|0;c[p>>2]=La+1;Ka=a[La]&63;a[w]=Ka;La=c[o>>2]|0;Ia=a[v]|0;a[g]=Ia;a[z]=(Ga&64|0)==0?Ia:Ka;a[A]=(Ga&32|0)==0?Ia:Ka;a[B]=(Ga&16|0)==0?Ia:Ka;a[C]=(Ga&8|0)==0?Ia:Ka;a[D]=(Ga&4|0)==0?Ia:Ka;a[E]=(Ga&2|0)==0?Ia:Ka;a[F]=(Ga&1|0)==0?Ia:Ka;a[G]=(Fa&128|0)==0?Ia:Ka;a[H]=(Fa&64|0)==0?Ia:Ka;a[I]=(Fa&32|0)==0?Ia:Ka;a[J]=(Fa&16|0)==0?Ia:Ka;a[K]=(Fa&8|0)==0?Ia:Ka;a[L]=(Fa&4|0)==0?Ia:Ka;a[M]=(Fa&2|0)==0?Ia:Ka;a[N]=(Fa&1|0)==0?Ia:Ka;Ka=La+32|0;Fa=(c[La>>2]|0)+((ca(c[Ka>>2]|0,ja)|0)+va)|0;Ga=(va|0)/4|0;Ea=(ja|0)/4|0;Ja=(c[La+4>>2]|0)+((ca(c[La+36>>2]|0,Ea)|0)+Ga)|0;Ha=(c[La+8>>2]|0)+((ca(c[La+40>>2]|0,Ea)|0)+Ga)|0;a[Ja]=a[301096+(Ba>>4)|0]|0;a[Ha]=a[301096+(Ba&15)|0]|0;Ha=Fa;Fa=0;Ja=Ia;while(1){Ia=Fa&3;a[Ha+Ia|0]=a[284648+(Ja&255)|0]|0;if((Ia|0)==3){Oa=Ha+(c[Ka>>2]|0)|0}else{Oa=Ha}Ia=Fa+1|0;if((Ia|0)>=16){Na=ma;ka=57;break b}Ha=Oa;Fa=Ia;Ja=a[j+Ia|0]|0}}else if((qa|0)==1){Ja=c[p>>2]|0;if(((c[s>>2]|0)-Ja|0)<1){Pa=0}else{c[p>>2]=Ja+1;Pa=d[Ja]|0}Ja=Pa>>>6;Fa=c[2018744+(Ja<<2)>>2]|0;Ha=Pa&63;a[v]=Ha;a[w]=Ha;if((Ja|0)==0){a[x]=Ha;a[y]=Ha;Na=Fa;ka=57;break}else{Ja=Ha+1&255;Ha=(Ja&255)>>>0>63>>>0?63:Ja;a[x]=Ha;a[y]=Ha;Na=Fa;ka=57;break}}else if((qa|0)==2){Fa=c[p>>2]|0;Ha=(c[s>>2]|0)-Fa|0;if(na){if((Ha|0)<2){Qa=0}else{c[p>>2]=Fa+2;Ja=Fa;Qa=(he((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)&65535}Ja=Qa<<2&16380;a[v]=a[(c[k>>2]|0)+Ja|0]|0;a[w]=a[(c[k>>2]|0)+(Ja|1)|0]|0;a[x]=a[(c[k>>2]|0)+(Ja|2)|0]|0;a[y]=a[(c[k>>2]|0)+(Ja|3)|0]|0;Na=Qa>>>12;ka=57;break}else{if((Ha|0)<3){Ra=0;Sa=0;Ta=0;Ua=0}else{c[p>>2]=Fa+3;Ha=a[Fa]|0;Ja=(d[Fa+1|0]|0)<<8;Ka=a[Fa+2|0]|0;Ra=(Ha&255)>>>2;Sa=(Ja|(Ha&255)<<16)>>>12&63;Ta=(Ja|Ka&255)>>>6&63;Ua=Ka&63}a[v]=Ra;a[w]=Sa;a[x]=Ta;a[y]=Ua;Na=16;ka=57;break}}else{Va=ma}}while(0);if((ka|0)==57){ka=0;if((qa|0)==3){za=Ba;Aa=Na;break}else{Va=Na}}z4a(c[o>>2]|0,va,ja,v,Ba,Va);za=Ba;Aa=Va}}while(0);qa=la+1|0;if((qa|0)<4){la=qa;ma=Aa;oa=za}else{break}}oa=da+8|0;ma=(oa|0)<(c[b>>2]|0);da=ma?oa:0;ea=ma?ea:ea+8|0;fa=fa+1|0;ga=ga;ha=ya;ia=ia}if((ka|0)==61){c[f>>2]=1;f=YHb(e,c[o>>2]|0)|0;q=(f|0)<0?f:n;i=h;return q|0}else if((ka|0)==62){KIb(u,16,2293192,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;q=-1094995529;i=h;return q|0}return 0}function y4a(a){a=a|0;VHb((c[a+60>>2]|0)+16|0);return 0}function z4a(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;i=i+16|0;l=k|0;if((j&8|0)==0){m=j}else{n=a[g]|0;o=g+3|0;a[g]=a[o]|0;a[o]=n;n=g+1|0;o=a[n]|0;p=g+2|0;a[n]=a[p]|0;a[p]=o;m=j&7}switch(m|0){case 5:{m=a[g+3|0]|0;a[l|0]=m;a[l+1|0]=m;a[l+2|0]=m;j=a[g+2|0]|0;a[l+3|0]=j;a[l+4|0]=m;a[l+5|0]=j;a[l+6|0]=j;m=a[g+1|0]|0;a[l+7|0]=m;a[l+8|0]=j;a[l+9|0]=m;a[l+10|0]=m;j=a[g]|0;a[l+11|0]=j;a[l+12|0]=m;a[l+13|0]=j;a[l+14|0]=j;a[l+15|0]=j;break};case 4:{mrc(l|0,a[g+3|0]|0,4)|0;mrc(l+4|0,a[g+2|0]|0,4)|0;mrc(l+8|0,a[g+1|0]|0,4)|0;mrc(l+12|0,a[g]|0,4)|0;break};case 6:{j=a[g+3|0]|0;a[l|0]=j;a[l+1|0]=j;m=a[g+2|0]|0;a[l+2|0]=m;a[l+3|0]=m;a[l+4|0]=j;a[l+5|0]=m;j=a[g+1|0]|0;a[l+6|0]=j;a[l+7|0]=j;a[l+8|0]=m;a[l+9|0]=m;a[l+10|0]=j;m=a[g]|0;a[l+11|0]=m;a[l+12|0]=j;a[l+13|0]=j;a[l+14|0]=m;a[l+15|0]=m;break};case 0:{m=a[g]|0;a[l|0]=m;j=a[g+1|0]|0;a[l+1|0]=j;o=a[g+2|0]|0;a[l+2|0]=o;p=a[g+3|0]|0;a[l+3|0]=p;a[l+4|0]=m;a[l+5|0]=j;a[l+6|0]=o;a[l+7|0]=p;a[l+8|0]=m;a[l+9|0]=j;a[l+10|0]=o;a[l+11|0]=p;a[l+12|0]=m;a[l+13|0]=j;a[l+14|0]=o;a[l+15|0]=p;break};case 1:{p=a[g+1|0]|0;a[l|0]=p;o=a[g+2|0]|0;a[l+1|0]=o;j=a[g+3|0]|0;a[l+2|0]=j;a[l+3|0]=j;m=a[g]|0;a[l+4|0]=m;a[l+5|0]=p;a[l+6|0]=o;a[l+7|0]=j;a[l+8|0]=m;a[l+9|0]=p;a[l+10|0]=o;a[l+11|0]=j;a[l+12|0]=m;a[l+13|0]=m;a[l+14|0]=p;a[l+15|0]=o;break};case 7:{o=a[g+3|0]|0;a[l|0]=o;a[l+1|0]=o;p=a[g+2|0]|0;a[l+2|0]=p;m=a[g+1|0]|0;a[l+3|0]=m;a[l+4|0]=o;a[l+5|0]=p;a[l+6|0]=m;j=a[g]|0;a[l+7|0]=j;a[l+8|0]=o;a[l+9|0]=p;a[l+10|0]=m;a[l+11|0]=j;a[l+12|0]=p;a[l+13|0]=m;a[l+14|0]=j;a[l+15|0]=j;break};case 3:{j=a[g+2|0]|0;a[l|0]=j;m=a[g+3|0]|0;a[l+1|0]=m;a[l+2|0]=m;a[l+3|0]=m;p=a[g+1|0]|0;a[l+4|0]=p;a[l+5|0]=j;a[l+6|0]=j;a[l+7|0]=m;m=a[g]|0;a[l+8|0]=m;a[l+9|0]=p;a[l+10|0]=p;a[l+11|0]=j;a[l+12|0]=m;a[l+13|0]=m;a[l+14|0]=m;a[l+15|0]=p;break};case 2:{p=a[g+1|0]|0;a[l|0]=p;m=a[g+2|0]|0;a[l+1|0]=m;j=a[g+3|0]|0;a[l+2|0]=j;a[l+3|0]=j;a[l+4|0]=p;a[l+5|0]=m;a[l+6|0]=m;a[l+7|0]=j;j=a[g]|0;a[l+8|0]=j;a[l+9|0]=p;a[l+10|0]=p;a[l+11|0]=m;a[l+12|0]=j;a[l+13|0]=j;a[l+14|0]=p;a[l+15|0]=m;break};default:{m=a[g]|0;a[l|0]=m;a[l+1|0]=m;p=a[g+1|0]|0;a[l+2|0]=p;a[l+3|0]=p;a[l+4|0]=m;a[l+5|0]=m;a[l+6|0]=p;a[l+7|0]=p;p=a[g+2|0]|0;a[l+8|0]=p;a[l+9|0]=p;m=a[g+3|0]|0;a[l+10|0]=m;a[l+11|0]=m;a[l+12|0]=p;a[l+13|0]=p;a[l+14|0]=m;a[l+15|0]=m}}m=b+32|0;p=(c[b>>2]|0)+((ca(c[m>>2]|0,f)|0)+e)|0;g=(e|0)/4|0;e=(f|0)/4|0;f=(c[b+4>>2]|0)+((ca(c[b+36>>2]|0,e)|0)+g)|0;j=(c[b+8>>2]|0)+((ca(c[b+40>>2]|0,e)|0)+g)|0;a[f]=a[301096+(h>>4)|0]|0;a[j]=a[301096+(h&15)|0]|0;h=p;p=0;while(1){j=p&3;a[h+j|0]=a[284648+(d[l+p|0]|0)|0]|0;if((j|0)==3){q=h+(c[m>>2]|0)|0}else{q=h}j=p+1|0;if((j|0)<16){h=q;p=j}else{break}}i=k;return}function A4a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=a;if(d>>>0>4294967279>>>0){mJb(a);c[b>>2]=0;return}a=d+16|0;if((c[b>>2]|0)>>>0>a>>>0){mrc((c[e>>2]|0)+d|0,0,16)|0;return}else{d=((a*17|0)>>>4)+32|0;f=d>>>0>a>>>0?d:a;kJb(c[e>>2]|0);a=pJb(f)|0;c[e>>2]=a;c[b>>2]=(a|0)==0?0:f;return}}function B4a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=a;if(d>>>0>4294967279>>>0){mJb(a);c[b>>2]=0;return}a=d+16|0;if((c[b>>2]|0)>>>0>a>>>0){mrc(c[e>>2]|0,0,a|0)|0;return}else{d=((a*17|0)>>>4)+32|0;f=d>>>0>a>>>0?d:a;kJb(c[e>>2]|0);a=pJb(f)|0;c[e>>2]=a;c[b>>2]=(a|0)==0?0:f;return}}function C4a(a){a=a|0;return c[((a|0)==0?6041848:a+56|0)>>2]|0}function D4a(a){a=a|0;var b=0;do{if((a|0)==0){b=0}else{if((c[a+80>>2]|0)!=0){b=1;break}b=(c[a+84>>2]|0)!=0|0}}while(0);return b|0}function E4a(a){a=a|0;var b=0;if((a|0)==0){b=0;return b|0}b=(c[a+88>>2]|0)!=0|0;return b|0}function F4a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;if(!(a[1998144]|0)){a[1998144]=1;j8()}d=c[253248]|0;e=b+56|0;c[e>>2]=0;f=b;g=d;while(1){d=c[g>>2]|0;if((d|0)==0){h=g;if(((E=c[h>>2]|0,(c[h>>2]|0)==0?(c[h>>2]=f)|0:0,E)|0)==0){break}i=c[g>>2]|0}else{i=d}g=i+56|0}c[253248]=e;e=c[b+72>>2]|0;if((e|0)==0){return}qe[e&1023](b);return}function G4a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;g=(tIb(b,d,0,f)|0)<0;h=g?0:d;j=g?0:b;c[a+128>>2]=j;c[a+132>>2]=h;k=c[a+800>>2]|0;c[a+120>>2]=-(-j>>k);c[a+124>>2]=-(-h>>k);if(!g){i=e;return}KIb(f,24,2463344,(f=i,i=i+16|0,c[f>>2]=b,c[f+8>>2]=d,f)|0);i=f;i=e;return}function H4a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=tIb(b,d,0,a)|0;f=(e|0)<0;g=f?0:d;d=f?0:b;c[a+128>>2]=d;c[a+132>>2]=g;b=c[a+800>>2]|0;c[a+120>>2]=-(-d>>b);c[a+124>>2]=-(-g>>b);return e|0}function I4a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=fIb(a,3)|0;do{if((d|0)==0){e=dIb(a,3,4)|0;if((e|0)==0){f=-12}else{g=e;break}return f|0}else{g=d}}while(0);c[c[g+4>>2]>>2]=b;f=0;return f|0}function J4a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=qKb(c[e+80>>2]|0)|0;if((a[h+7|0]&16)==0){KIb(0,0,2593072,(j=i,i=i+24|0,c[j>>2]=2444920,c[j+8>>2]=2355864,c[j+16>>2]=706,j)|0);i=j;Hd()}j=h+4|0;k=a[j]|0;if(k<<24>>24==0){i=g;return}l=e+68|0;m=h+5|0;n=e+72|0;o=h+6|0;p=h+8|0;h=0;q=k;while(1){k=c[e+(h<<2)>>2]|0;r=c[l>>2]|0;if((h-1|0)>>>0<2>>>0){s=-(-(c[n>>2]|0)>>(d[o]|0))|0;t=-(-r>>(d[m]|0))|0}else{s=c[n>>2]|0;t=r}if((s|0)>0){r=e+32+(h<<2)|0;u=f+(h<<2)|0;a:do{if((t|0)>0){v=k;w=1;while(1){x=c[u>>2]|0;if((b[p>>1]&16384)>>>0>14336>>>0){y=x&65535;z=v;A=0;do{b[z+(A<<1)>>1]=y;A=A+1|0;}while((A|0)<(t|0))}else{mrc(v|0,x&255|0,t|0)|0}if((w|0)>=(s|0)){break a}v=v+(c[r>>2]|0)|0;w=w+1|0}}else{w=k;v=1;while(1){if(!((b[p>>1]&16384)>>>0>14336>>>0)){mrc(w|0,c[u>>2]&255|0,t|0)|0}if((v|0)>=(s|0)){break a}w=w+(c[r>>2]|0)|0;v=v+1|0}}}while(0);B=a[j]|0}else{B=q}r=h+1|0;if((r|0)<(B&255|0)){h=r;q=B}else{break}}i=g;return}function K4a(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;d=i;i=i+96|0;f=d|0;g=d+8|0;h=d+16|0;j=d+80|0;k=a+64|0;l=c[(c[k>>2]|0)+24>>2]|0;m=a+8|0;n=c[m>>2]|0;a:do{if((n|0)==0){mrc(j|0,0,16)|0;o=b+68|0;p=c[o>>2]|0;q=b+72|0;r=c[q>>2]|0;s=l+16|0;t=b+80|0;do{if((c[s>>2]|0)==(c[t>>2]|0)){if((c[l+20>>2]|0)!=(p|0)){break}if((c[l+24>>2]|0)==(r|0)){break a}}}while(0);u=l+28|0;v=a+140|0;w=c[v>>2]|0;b:do{switch(w|0){case 7:case 320:case 18:{x=8;y=32;break};case 3:{z=((c[a+48>>2]|0)-54|0)>>>0<2>>>0?4:1;x=z;y=z;break};case 46:{z=(c[a+48>>2]|0)==43?4:1;x=z;y=z;break};case 2:{z=(c[a+48>>2]|0)==44?4:1;x=z;y=z;break};case 6:{z=(c[a+48>>2]|0)==23?64:1;x=z;y=z;break};case 0:case 1:case 17:case 4:case 33:case 5:case 317:case 82:case 8:case 31:case 32:case 12:case 13:case 34:case 14:case 35:case 300:case 299:case 70:case 69:case 72:case 71:case 302:case 301:case 304:case 303:case 54:case 55:case 92:case 91:case 98:case 97:case 104:case 103:case 80:case 79:case 74:case 73:case 306:case 305:case 308:case 307:case 56:case 57:case 94:case 93:case 100:case 99:case 106:case 105:case 76:case 75:case 78:case 77:case 310:case 309:case 312:case 311:case 58:case 59:case 96:case 95:case 102:case 101:case 108:case 107:case 84:case 83:case 86:case 85:case 314:case 313:case 316:case 315:{x=32;y=16;break};case 11:case 19:case 22:{z=c[a+48>>2]|0;if(!((z|0)==50|(z|0)==44)){x=1;y=1;break b}x=4;y=4;break};default:{x=1;y=1}}}while(0);z=c[a+48>>2]|0;if((z-137|0)>>>0<2>>>0){A=y>>>0>8>>>0?y:8}else{A=y}B=p-1+A&-A;C=r-1+x&-x;if((z|0)==28){D=18}else{if((c[a+800>>2]|0)==0){E=C}else{D=18}}if((D|0)==18){E=C+2|0}c[u>>2]=8;C=l+32|0;c[C>>2]=8;z=l+36|0;c[z>>2]=8;F=l+40|0;c[F>>2]=8;if((c[a+88>>2]&16384|0)==0){G=E+32|0;H=B+32|0}else{G=E;H=B}B=h+32|0;I=h+36|0;J=h+40|0;K=h+44|0;L=H;M=w;while(1){pIb(B,M,L)|0;if(((c[I>>2]|0)%(c[C>>2]|0)|0|((c[B>>2]|0)%(c[u>>2]|0)|0)|((c[J>>2]|0)%(c[z>>2]|0)|0)|((c[K>>2]|0)%(c[F>>2]|0)|0)|0)==0){break}L=(L&-L)+L|0;M=c[v>>2]|0}M=h|0;L=qIb(M,c[v>>2]|0,G,0,B)|0;if((L|0)<0){N=-1;i=d;return N|0}F=c[h+4>>2]|0;z=c[M>>2]|0;do{if((F|0)==0){O=0;P=j|0;Q=z}else{M=F;u=z;C=j|0;c[C>>2]=M-u;w=c[h+8>>2]|0;if((w|0)==0){O=1;P=C;Q=u;break}r=w;c[j+4>>2]=r-M;M=c[h+12>>2]|0;if((M|0)==0){O=2;P=C;Q=u;break}c[j+8>>2]=M-r;O=3;P=C;Q=u}}while(0);c[j+(O<<2)>>2]=Q+L-(c[h+(O<<2)>>2]|0);z=l|0;lGb(z);c[l+60>>2]=c[B>>2];F=c[P>>2]|0;if((F|0)!=0){v=kGb(F+23|0,792)|0;c[z>>2]=v;if((v|0)==0){R=-12;D=39;break}}v=l+4|0;lGb(v);c[l+64>>2]=c[I>>2];z=c[j+4>>2]|0;if((z|0)!=0){F=kGb(z+23|0,792)|0;c[v>>2]=F;if((F|0)==0){R=-12;D=39;break}}F=l+8|0;lGb(F);c[l+68>>2]=c[J>>2];v=c[j+8>>2]|0;if((v|0)!=0){z=kGb(v+23|0,792)|0;c[F>>2]=z;if((z|0)==0){R=-12;D=39;break}}z=l+12|0;lGb(z);c[l+72>>2]=c[K>>2];F=c[j+12>>2]|0;if((F|0)!=0){v=kGb(F+23|0,792)|0;c[z>>2]=v;if((v|0)==0){R=-12;D=39;break}}c[s>>2]=c[t>>2];c[l+20>>2]=c[o>>2];c[l+24>>2]=c[q>>2]}else if((n|0)==1){v=GHb(b)|0;z=b+80|0;F=(RKb(c[z>>2]|0)|0)!=0;u=F?v:1;F=l+16|0;do{if((c[F>>2]|0)==(c[z>>2]|0)){if((c[l+76>>2]|0)!=(u|0)){break}if((c[l+80>>2]|0)!=(v|0)){break}if((c[b+76>>2]|0)==(c[l+84>>2]|0)){break a}}}while(0);q=l|0;lGb(q);o=l+60|0;t=b+76|0;s=SKb(o,v,c[t>>2]|0,c[z>>2]|0,0)|0;if((s|0)<0){R=s;D=39;break}s=kGb(c[o>>2]|0,0)|0;c[q>>2]=s;if((s|0)==0){R=-12;D=39;break}c[F>>2]=c[z>>2];c[l+76>>2]=u;c[l+80>>2]=v;c[l+84>>2]=c[t>>2]}else{KIb(0,0,2593072,(S=i,i=i+24|0,c[S>>2]=2118728,c[S+8>>2]=2355864,c[S+16>>2]=590,S)|0);i=S;Hd();return 0}}while(0);if((D|0)==39){lGb(l|0);lGb(l+4|0);lGb(l+8|0);lGb(l+12|0);c[l+16>>2]=-1;c[l+84>>2]=0;c[l+80>>2]=0;c[l+76>>2]=0;c[l+24>>2]=0;c[l+20>>2]=0;N=R;i=d;return N|0}c[b+288>>2]=1;R=c[m>>2]|0;if((R|0)==1){m=c[(c[k>>2]|0)+24>>2]|0;l=c[m+76>>2]|0;c[b+32>>2]=c[m+60>>2];do{if((l|0)>8){n=b+64|0;c[n>>2]=pJb(l<<2)|0;j=l-8|0;c[b+396>>2]=j;P=pJb(j<<2)|0;j=b+392|0;c[j>>2]=P;if(!((c[n>>2]|0)==0|(P|0)==0)){T=8;D=73;break}mJb(n);mJb(j);N=-12;i=d;return N|0}else{c[b+64>>2]=b;if((c[b+396>>2]|0)==0){if((l|0)>0){T=l;D=73;break}else{break}}else{KIb(0,0,2593072,(S=i,i=i+24|0,c[S>>2]=2625720,c[S+8>>2]=2355864,c[S+16>>2]=622,S)|0);i=S;Hd();return 0}}}while(0);c:do{if((D|0)==73){l=m|0;j=b+64|0;n=0;while(1){P=mGb(c[l>>2]|0)|0;c[b+360+(n<<2)>>2]=P;if((P|0)==0){break}O=c[P+4>>2]|0;c[b+(n<<2)>>2]=O;c[(c[j>>2]|0)+(n<<2)>>2]=O;O=n+1|0;if((O|0)<(T|0)){n=O}else{D=75;break}}d:do{if((D|0)==75){n=b+396|0;if((c[b+396>>2]|0)<=0){break c}j=m|0;l=b+392|0;v=b+64|0;u=0;while(1){z=mGb(c[j>>2]|0)|0;c[(c[l>>2]|0)+(u<<2)>>2]=z;z=c[(c[l>>2]|0)+(u<<2)>>2]|0;if((z|0)==0){break d}c[(c[v>>2]|0)+(u+8<<2)>>2]=c[z+4>>2];u=u+1|0;if((u|0)>=(c[n>>2]|0)){break c}}}}while(0);WHb(b);N=-12;i=d;return N|0}}while(0);if((c[a+688>>2]&32768|0)==0){N=0;i=d;return N|0}KIb(a,48,2624536,(S=i,i=i+8|0,c[S>>2]=b,S)|0);i=S;N=0;i=d;return N|0}else if((R|0)==0){R=c[(c[k>>2]|0)+24>>2]|0;k=qKb(c[b+80>>2]|0)|0;m=b|0;if((c[m>>2]|0)!=0){KIb(a,16,2622976,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;N=-1;i=d;return N|0}T=(e[k+8>>1]|0)>>>2&7;mrc(b|0,0,32)|0;c[b+64>>2]=m;m=a+140|0;tKb(c[m>>2]|0,f,g)|0;k=R+8|0;n=a+88|0;u=(T<<4)+16|0;T=0;while(1){v=c[R+(T<<2)>>2]|0;if((v|0)==0){U=T;D=61;break}l=(T|0)==0;j=l?0:c[f>>2]|0;z=l?0:c[g>>2]|0;F=(c[k>>2]|0)!=0;if(F|l^1){V=F}else{V=(c[m>>2]|0)==8}F=b+32+(T<<2)|0;c[F>>2]=c[R+60+(T<<2)>>2];l=mGb(v)|0;c[b+360+(T<<2)>>2]=l;if((l|0)==0){D=67;break}v=c[l+4>>2]|0;if((c[n>>2]&16384|0)!=0|V^1){c[b+(T<<2)>>2]=v}else{l=c[R+28+(T<<2)>>2]|0;c[b+(T<<2)>>2]=v+((u>>j)-1+l+(c[F>>2]<<4>>z)&-l)}W=T+1|0;if((W|0)<4){T=W}else{D=53;break}}if((D|0)==53){if((W|0)<8){U=W;D=61}}else if((D|0)==67){WHb(b);N=-12;i=d;return N|0}if((D|0)==61){while(1){D=0;c[b+(U<<2)>>2]=0;c[b+32+(U<<2)>>2]=0;W=U+1|0;if((W|0)<8){U=W;D=61}else{break}}}D=c[b+4>>2]|0;do{if((D|0)!=0){if((c[b+8>>2]|0)!=0){break}rIb(D,c[m>>2]|0)|0}}while(0);if((c[a+688>>2]&32768|0)==0){N=0;i=d;return N|0}KIb(a,48,2621440,(S=i,i=i+8|0,c[S>>2]=b,S)|0);i=S;N=0;i=d;return N|0}else{N=-1;i=d;return N|0}return 0}function L4a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a+64|0;f=c[(c[e>>2]|0)+32>>2]|0;if((f|0)==0){g=b+144|0;c[g>>2]=0;c[g+4>>2]=-2147483648;EHb(b,-1,-1);CHb(b,0,0);LHb(b,-1)}else{g=f+8|0;h=c[g+4>>2]|0;j=b+144|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;h=f+64|0;EHb(b,c[h>>2]|0,c[h+4>>2]|0);h=c[(c[(c[e>>2]|0)+32>>2]|0)+48>>2]|0;CHb(b,h,(h|0)<0|0?-1:0);LHb(b,c[(c[(c[e>>2]|0)+32>>2]|0)+28>>2]|0)}e=a+704|0;h=c[e+4>>2]|0;f=b+320|0;c[f>>2]=c[e>>2];c[f+4>>2]=h;h=c[(c[a+12>>2]|0)+8>>2]|0;if((h|0)==0){c[b+80>>2]=c[a+140>>2];f=b+124|0;if((c[f>>2]|0)==0){e=a+224|0;j=f;f=c[e+4>>2]|0;c[j>>2]=c[e>>2];c[j+4>>2]=f}if((MHb(b)|0)==2){NHb(b,c[a+392>>2]|0)}if((OHb(b)|0)!=0){k=0;i=d;return k|0}PHb(b,c[a+396>>2]|0);k=0;i=d;return k|0}else if((h|0)==1){h=b+344|0;if((c[h>>2]|0)==0){c[h>>2]=c[a+412>>2]}h=b+80|0;if((c[h>>2]|0)<0){c[h>>2]=c[a+420>>2]}h=b+352|0;do{if((c[h>>2]|0)==0&(c[h+4>>2]|0)==0){f=a+448|0;j=c[f>>2]|0;e=c[f+4>>2]|0;if((j|0)==0&(e|0)==0){g=c[a+416>>2]|0;if(!(g>>>0>63>>>0)){l=g;break}KIb(a,16,2242056,(m=i,i=i+8|0,c[m>>2]=g,m)|0);i=m;k=-38;i=d;return k|0}g=rGb(j,e)|0;if((g|0)==(c[a+416>>2]|0)){e=c[f+4>>2]|0;c[h>>2]=c[f>>2];c[h+4>>2]=e;l=g;break}KIb(a,16,2293152,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;k=-22;i=d;return k|0}else{l=c[a+416>>2]|0}}while(0);HHb(b,l);k=0;i=d;return k|0}else{k=0;i=d;return k|0}return 0}function M4a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=h;l=b+8|0;a:do{if((c[l>>2]|0)==0){m=b+120|0;n=b+124|0;o=b;do{if((tIb(c[m>>2]|0,c[n>>2]|0,0,o)|0)>=0){if((c[b+140>>2]|0)<0){break}if((c[l>>2]|0)!=0){p=1;q=9;break a}r=e+68|0;s=e+72|0;if((c[r>>2]|0)>=1){if((c[s>>2]|0)>=1){p=1;q=9;break a}}t=c[m>>2]|0;u=b+800|0;v=-(-(c[b+128>>2]|0)>>c[u>>2])|0;c[r>>2]=(t|0)>(v|0)?t:v;v=c[n>>2]|0;t=-(-(c[b+132>>2]|0)>>c[u>>2])|0;c[s>>2]=(v|0)>(t|0)?v:t;p=0;q=9;break a}}while(0);KIb(o,16,2627128,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-22}else{p=1;q=9}}while(0);b:do{if((q|0)==9){n=L4a(b,e)|0;if((n|0)<0){x=n;break}n=c[b+472>>2]|0;if((n|0)==0){m=Ee[c[b+484>>2]&511](b,e,f)|0;if((c[l>>2]|p|0)==0){c[e+68>>2]=c[b+120>>2];c[e+72>>2]=c[b+124>>2]}if((m|0)<0){x=m;break}else{y=m}i=g;return y|0}c[h>>2]=0;c[j>>2]=0;if((f&1|0)!=0){c[e+172>>2]=1}m=We[n&2047](b,e)|0;if((m|0)<0){x=m;break}c:do{if((c[e+360>>2]|0)==0){m=pJb(2456)|0;c[h>>2]=m;d:do{if((m|0)==0){z=-12}else{nrc(m|0,b|0,960)|0;nrc(m+960|0,e|0,472)|0;n=aGb(0,0,10,m,0)|0;c[j>>2]=n;if((n|0)==0){z=-12;break}n=e+80|0;t=c[n>>2]|0;e:do{if((c[l>>2]|0)==0){v=qKb(t)|0;s=uKb(c[n>>2]|0)|0;if((v|0)==0){z=-22;break d}u=(a[v+7|0]&8)==0?s:1;if((u|0)<1){z=-22;break d}s=v+6|0;v=e+72|0;r=0;while(1){if((r|0)>=(u|0)){break e}if((r-1|0)>>>0<2>>>0){A=d[s]|0}else{A=0}B=c[v>>2]|0;C=c[e+32+(r<<2)>>2]|0;D=eGb(c[j>>2]|0)|0;if((D|0)==0){z=-12;break d}E=ca(B>>A,C)|0;C=aGb(c[e+(r<<2)>>2]|0,E,546,D,0)|0;c[e+360+(r<<2)>>2]=C;if((C|0)==0){break}else{r=r+1|0}}WHb(e);z=-12;break d}else{do{if((RKb(t)|0)==0){F=1}else{r=c[b+416>>2]|0;if(!(r>>>0>8>>>0)){F=r;break}v=r-8|0;c[e+396>>2]=v;r=hJb(v<<2)|0;c[e+392>>2]=r;if((r|0)==0){z=-12;break d}else{F=8}}}while(0);r=e+64|0;v=e+32|0;s=0;while(1){if(!(s>>>0<F>>>0)){break}u=eGb(c[j>>2]|0)|0;if((u|0)==0){z=-12;break d}C=aGb(c[(c[r>>2]|0)+(s<<2)>>2]|0,c[v>>2]|0,546,u,0)|0;c[e+360+(s<<2)>>2]=C;if((C|0)==0){q=35;break}else{s=s+1|0}}if((q|0)==35){WHb(e);z=-12;break d}s=e+396|0;C=e+392|0;u=0;while(1){if((u|0)>=(c[s>>2]|0)){break e}D=eGb(c[j>>2]|0)|0;if((D|0)==0){z=-12;break d}E=aGb(c[(c[r>>2]|0)+(u+8<<2)>>2]|0,c[v>>2]|0,546,D,0)|0;c[(c[C>>2]|0)+(u<<2)>>2]=E;if((c[(c[C>>2]|0)+(u<<2)>>2]|0)==0){break}else{u=u+1|0}}WHb(e);z=-12;break d}}while(0);fGb(j);break c}}while(0);re[c[b+476>>2]&1023](b,e);mJb(k);fGb(j);x=z;break b}}while(0);c[e+68>>2]=c[b+120>>2];c[e+72>>2]=c[b+124>>2];y=0;i=g;return y|0}}while(0);KIb(b,16,2200872,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;y=x;i=g;return y|0}function N4a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+8|0;e=d|0;if((c[a+8>>2]|0)!=0){KIb(0,0,2593072,(f=i,i=i+24|0,c[f>>2]=2630520,c[f+8>>2]=2355864,c[f+16>>2]=991,f)|0);i=f;Hd();return 0}g=b|0;a:do{if((c[g>>2]|0)!=0){h=c[b+68>>2]|0;j=a+120|0;k=c[b+72>>2]|0;l=a+124|0;do{if((h|0)==(c[j>>2]|0)){if((k|0)!=(c[l>>2]|0)){break}if((c[b+80>>2]|0)==(c[a+140>>2]|0)){break a}}}while(0);m=mKb(c[b+80>>2]|0)|0;n=c[j>>2]|0;o=c[l>>2]|0;p=mKb(c[a+140>>2]|0)|0;KIb(a,24,2628528,(f=i,i=i+48|0,c[f>>2]=h,c[f+8>>2]=k,c[f+16>>2]=m,c[f+24>>2]=n,c[f+32>>2]=o,c[f+40>>2]=p,f)|0);i=f;WHb(b)}}while(0);L4a(a,b)|0;do{if((c[g>>2]|0)==0){p=M4a(a,b,1)|0;if((p|0)<0){q=p;break}else{r=p}i=d;return r|0}else{if((bIb(b)|0)!=0){p=c[(c[a+64>>2]|0)+32>>2]|0;if((p|0)==0){s=-2147483648;t=0}else{o=p+8|0;s=c[o+4>>2]|0;t=c[o>>2]|0}o=b+144|0;c[o>>2]=t;c[o+4>>2]=s;o=a+704|0;p=c[o+4>>2]|0;n=b+320|0;c[n>>2]=c[o>>2];c[n+4>>2]=p;r=0;i=d;return r|0}p=UHb()|0;c[e>>2]=p;if((p|0)==0){q=-12;break}aIb(p,b);n=M4a(a,b,1)|0;if((n|0)<0){VHb(e);q=n;break}_Hb(b,p)|0;VHb(e);r=0;i=d;return r|0}}while(0);KIb(a,16,2169032,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;r=q;i=d;return r|0}function O4a(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;if((f|0)<=0){return 0}if((e|0)==0){h=0;do{i=d+(ca(h,g)|0)|0;We[b&2047](a,i)|0;h=h+1|0;}while((h|0)<(f|0));return 0}else{h=0;do{i=d+(ca(h,g)|0)|0;c[e+(h<<2)>>2]=We[b&2047](a,i)|0;h=h+1|0;}while((h|0)<(f|0));return 0}return 0}function P4a(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((f|0)<=0){return 0}if((e|0)==0){g=0;do{hf[b&1023](a,d,g,0)|0;g=g+1|0;}while((g|0)<(f|0));return 0}else{g=0;do{c[e+(g<<2)>>2]=hf[b&1023](a,d,g,0)|0;g=g+1|0;}while((g|0)<(f|0));return 0}return 0}function Q4a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a;while(1){a=c[d>>2]|0;if(!((a|0)>-1)){e=-1;f=4;break}if((c[d+4>>2]|0)==(b|0)){e=a;f=4;break}else{d=d+8|0}}if((f|0)==4){return e|0}return 0}function R4a(b,d){b=b|0;d=d|0;var e=0,f=0;b=d;while(1){d=c[b>>2]|0;if((d|0)==-1){e=-1;f=5;break}if((a[(qKb(d)|0)+7|0]&8)==0){break}else{b=b+4|0}}if((f|0)==5){return e|0}e=c[b>>2]|0;return e|0}function S4a(a){a=a|0;mrc(a|0,0,472)|0;WHb(a);return}function T4a(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=b;b=i;i=i+8|0;c[b>>2]=c[e>>2];c[b+4>>2]=c[e+4>>2];e=b;b=a+888|0;a=c[e+4>>2]|0;c[b>>2]=c[e>>2];c[b+4>>2]=a;i=d;return}function U4a(a){a=a|0;return c[a+896>>2]|0}function V4a(a,b){a=a|0;b=b|0;c[a+896>>2]=b;return}function W4a(a){a=a|0;return c[a+800>>2]|0}function X4a(a,b){a=a|0;b=b|0;c[a+948>>2]=b;return}function Y4a(a,b){a=a|0;b=b|0;c[a+952>>2]=b;return}function Z4a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if((c[2194908]|0)==0){KIb(0,0,2593072,(f=i,i=i+24|0,c[f>>2]=2107744,c[f+8>>2]=2355864,c[f+16>>2]=3333,f)|0);i=f;Hd();return 0}c[2194908]=0;c[2244128]=(c[2244128]|0)-1;f=c[1448084]|0;if((f|0)==0){g=_4a(a,b,d)|0;h=$4a(a)|0;i=e;return g|0}We[f&2047](9800216,2)|0;g=_4a(a,b,d)|0;h=$4a(a)|0;i=e;return g|0}function _4a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;f=i;i=i+1800|0;g=f|0;h=f+8|0;j=f+136|0;k=f+264|0;l=f+776|0;m=f+1288|0;c[g>>2]=0;n=a+64|0;if((c[n>>2]|0)!=0){o=0;i=f;return o|0}p=a+12|0;q=c[p>>2]|0;r=(q|0)==0;do{if((b|0)==0){if(!r){s=q;break}KIb(a,16,2636832,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;o=-22;i=f;return o|0}else{if(r|(q|0)==(b|0)){s=b;break}u=c[b>>2]|0;KIb(a,16,2613456,(t=i,i=i+16|0,c[t>>2]=c[q>>2],c[t+8>>2]=u,t)|0);i=t;o=-22;i=f;return o|0}}while(0);if((c[a+100>>2]|0)>>>0>268435439>>>0){o=-22;i=f;return o|0}q=(e|0)!=0;if(q){PGb(g,c[e>>2]|0,0)}b=$4a(a)|0;if((b|0)<0){o=b;i=f;return o|0}b=pJb(56)|0;c[n>>2]=b;a:do{if((b|0)==0){v=-12}else{r=pJb(88)|0;c[(c[n>>2]|0)+24>>2]=r;b:do{if((c[(c[n>>2]|0)+24>>2]|0)==0){w=-12}else{r=UHb()|0;c[(c[n>>2]|0)+20>>2]=r;if((c[(c[n>>2]|0)+20>>2]|0)==0){w=-12;break}r=c[s+52>>2]|0;u=a+60|0;do{if((r|0)>0){do{if((c[u>>2]|0)==0){x=pJb(r)|0;c[u>>2]=x;if((x|0)==0){v=-12;break a}y=s+44|0;z=c[y>>2]|0;if((z|0)==0){A=y;break}c[x>>2]=z;SJb(x);A=y}else{A=s+44|0}}while(0);if((c[A>>2]|0)==0){break}y=XJb(c[u>>2]|0,g)|0;if((y|0)<0){w=y;break b}}else{c[u>>2]=0}}while(0);u=a;r=XJb(u,g)|0;if((r|0)<0){w=r;break}y=a+128|0;x=c[y>>2]|0;c:do{if((x|0)==0){B=0;C=30}else{z=a+132|0;D=c[z>>2]|0;if((D|0)==0){B=x;C=30;break}E=c[a+120>>2]|0;do{if((E|0)!=0){if((c[a+124>>2]|0)==0){break}F=c[a+48>>2]|0;if((F|0)==28|(F|0)==93){G=x;H=E;break c}}}while(0);E=tIb(x,D,0,u)|0;F=(E|0)<0;I=F?0:D;J=F?0:x;c[y>>2]=J;c[z>>2]=I;F=c[a+800>>2]|0;K=-(-J>>F)|0;c[a+120>>2]=K;c[a+124>>2]=-(-I>>F);L=E;M=J;N=K;C=33}}while(0);do{if((C|0)==30){x=a+120|0;K=c[x>>2]|0;if((K|0)==0){L=r;M=B;N=0;C=33;break}J=a+124|0;E=c[J>>2]|0;if((E|0)==0){L=r;M=B;N=K;C=33;break}F=tIb(K,E,0,u)|0;I=(F|0)<0;O=I?0:E;E=I?0:K;c[y>>2]=E;c[a+132>>2]=O;K=c[a+800>>2]|0;I=-(-E>>K)|0;c[x>>2]=I;c[J>>2]=-(-O>>K);L=F;M=E;N=I;C=33}}while(0);if((C|0)==33){if((L|0)<0){w=L;break}else{G=M;H=N}}r=c[a+132>>2]|0;do{if((G|r|0)==0){if((H|0)!=0){P=0;C=37;break}if((c[a+124>>2]|0)!=0){P=0;C=37}}else{P=r;C=37}}while(0);do{if((C|0)==37){r=a+132|0;I=a+120|0;if((tIb(G,P,0,u)|0)<0){Q=a+124|0}else{E=a+124|0;if((tIb(c[I>>2]|0,c[E>>2]|0,0,u)|0)<0){Q=E}else{break}}KIb(u,24,2586680,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;tIb(0,0,0,u)|0;c[y>>2]=0;c[r>>2]=0;c[I>>2]=0;c[Q>>2]=0}}while(0);y=(s|0)==0;do{if(!y){if((c[s+88>>2]|0)==0){break}mJb(a+860|0)}}while(0);I=a+416|0;if((c[I>>2]|0)>>>0>63>>>0){w=-22;break}c[p>>2]=s;r=a+8|0;E=c[r>>2]|0;do{if((E|0)==-1){C=48}else{if((E|0)==(c[s+8>>2]|0)){C=48;break}R=E;S=c[a+48>>2]|0}}while(0);do{if((C|0)==48){F=a+48|0;K=c[F>>2]|0;if((K|0)!=0){R=E;S=K;break}K=c[s+8>>2]|0;c[r>>2]=K;O=c[s+12>>2]|0;c[F>>2]=O;R=K;S=O}}while(0);E=a+48|0;O=s+12|0;do{if((S|0)==(c[O>>2]|0)){if(!((R|0)==(c[s+8>>2]|0)|(R|0)==4)){break}c[a+428>>2]=0;K=a+896|0;c[K>>2]=u4(S)|0;do{if((c[(c[p>>2]|0)+16>>2]&512|0)!=0){if(!((c[a+680>>2]|0)>-2)){break}d:do{if(y){F=c[s>>2]|0;KIb(u,16,2514544,(t=i,i=i+24|0,c[t>>2]=2529808,c[t+8>>2]=F,c[t+16>>2]=-2,t)|0);i=t;T=c[O>>2]|0;U=2529808;C=77}else{if((c[s+80>>2]|0)==0){V=(c[s+84>>2]|0)!=0?2547688:2529808}else{V=2547688}F=c[s>>2]|0;KIb(u,16,2514544,(t=i,i=i+24|0,c[t>>2]=V,c[t+8>>2]=F,c[t+16>>2]=-2,t)|0);i=t;if((c[s+80>>2]|0)==0){F=c[O>>2]|0;if((c[s+84>>2]|0)==0){T=F;U=V;C=77;break}else{W=F}}else{W=c[O>>2]|0}F=c[1510462]|0;if((W|0)==173){X=1464156752}else if((W|0)==175){X=1211250229}else if((W|0)==86079){X=1950507339}else if((W|0)==65564){X=407917392}else if((W|0)==65565){X=542135120}else if((W|0)==86077){X=1330664787}else if((W|0)==171){X=1160852272}else if((W|0)==172){X=4665933}else{X=W}if((F|0)==0){Y=0;Z=V;break}else{_=F;$=0}while(1){if((c[_+80>>2]|0)==0){if((c[_+84>>2]|0)==0){aa=$}else{C=74}}else{C=74}do{if((C|0)==74){C=0;if((c[_+12>>2]|0)!=(X|0)){aa=$;break}if((c[_+16>>2]&512|0)!=0&($|0)==0){aa=_}else{Y=_;Z=V;break d}}}while(0);F=c[_+56>>2]|0;if((F|0)==0){Y=aa;Z=V;break}else{_=F;$=aa}}}}while(0);e:do{if((C|0)==77){F=c[1510462]|0;if((T|0)==171){ba=1160852272}else if((T|0)==172){ba=4665933}else if((T|0)==173){ba=1464156752}else if((T|0)==175){ba=1211250229}else if((T|0)==86077){ba=1330664787}else if((T|0)==86079){ba=1950507339}else if((T|0)==65564){ba=407917392}else if((T|0)==65565){ba=542135120}else{ba=T}if((F|0)==0){Y=0;Z=U;break}else{da=F;ea=0}while(1){do{if((c[da+88>>2]|0)==0){fa=ea}else{if((c[da+12>>2]|0)!=(ba|0)){fa=ea;break}if((c[da+16>>2]&512|0)!=0&(ea|0)==0){fa=da}else{Y=da;Z=U;break e}}}while(0);F=c[da+56>>2]|0;if((F|0)==0){Y=fa;Z=U;break}else{da=F;ea=fa}}}}while(0);if((c[Y+16>>2]&512|0)!=0){w=-733130664;break b}F=c[Y>>2]|0;KIb(u,16,2500744,(t=i,i=i+16|0,c[t>>2]=Z,c[t+8>>2]=F,t)|0);i=t;w=-733130664;break b}}while(0);do{if((c[r>>2]|0)==1){z=a+104|0;D=a+108|0;if((c[z>>2]|0)!=0){if((c[D>>2]|0)!=0){break}}c[z>>2]=1;c[D>>2]=c[a+412>>2]}}while(0);KIb(u,24,2488056,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;if((c[s+16>>2]&32768|0)==0){c[a+808>>2]=1}D=c[p>>2]|0;z=d[D+40|0]|0;F=c[a+800>>2]|0;if((z|0)<(F|0)|(F|0)<0){KIb(u,16,2477072,(t=i,i=i+8|0,c[t>>2]=z,t)|0);i=t;w=-22;break b}do{if((D|0)!=0){if((c[D+80>>2]|0)==0){if((c[D+84>>2]|0)==0){break}}z=c[D+32>>2]|0;do{if((z|0)==0){ga=D}else{F=c[z>>2]|0;f:do{if((F|0)==-1){ha=0;ia=D;ja=z}else{J=a+420|0;x=0;ka=F;la=D;ma=z;while(1){na=c[J>>2]|0;if((na|0)==(ka|0)){ha=x;ia=la;ja=ma;break f}if((c[I>>2]|0)==1){oa=OKb(na)|0;na=(oa|0)==(OKb(c[(c[(c[p>>2]|0)+32>>2]|0)+(x<<2)>>2]|0)|0);pa=c[p>>2]|0;qa=c[pa+32>>2]|0;if(na){break}else{ra=pa;sa=qa}}else{ra=la;sa=ma}na=x+1|0;oa=c[sa+(na<<2)>>2]|0;if((oa|0)==-1){ha=na;ia=ra;ja=sa;break f}else{x=na;ka=oa;la=ra;ma=sa}}c[J>>2]=c[qa+(x<<2)>>2];ha=x;ia=pa;ja=qa}}while(0);if(!((c[ja+(ha<<2)>>2]|0)==-1)){ga=ia;break}F=h|0;ma=a+420|0;Rb(F|0,128,2467704,(t=i,i=i+8|0,c[t>>2]=c[ma>>2],t)|0)|0;i=t;la=LKb(c[ma>>2]|0)|0;KIb(u,16,2457904,(t=i,i=i+8|0,c[t>>2]=(la|0)!=0?la:F,t)|0);i=t;w=-22;break b}}while(0);z=c[ga+24>>2]|0;g:do{if((z|0)!=0){F=a+140|0;la=0;while(1){ma=c[z+(la<<2)>>2]|0;if((ma|0)==-1){break}if((c[F>>2]|0)==(ma|0)){break g}else{la=la+1|0}}la=c[E>>2]|0;if((la|0)==8|(la|0)==10){if((c[a+680>>2]|0)<0){break}}la=j|0;Rb(la|0,128,2467704,(t=i,i=i+8|0,c[t>>2]=c[F>>2],t)|0)|0;i=t;ma=mKb(c[F>>2]|0)|0;KIb(u,16,2441016,(t=i,i=i+8|0,c[t>>2]=(ma|0)!=0?ma:la,t)|0);i=t;w=-22;break b}}while(0);z=c[ga+28>>2]|0;h:do{if((z|0)!=0){la=a+412|0;ma=0;while(1){ka=c[z+(ma<<2)>>2]|0;ta=c[la>>2]|0;if((ka|0)==0){break}if((ta|0)==(ka|0)){break h}else{ma=ma+1|0}}KIb(u,16,2429320,(t=i,i=i+8|0,c[t>>2]=ta,t)|0);i=t;w=-22;break b}}while(0);z=c[ga+36>>2]|0;ma=a+448|0;i:do{if((z|0)!=0){la=c[ma>>2]|0;F=c[ma+4>>2]|0;if((la|0)==0&(F|0)==0){KIb(u,24,2418904,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}else{ua=0}while(1){ka=z+(ua<<3)|0;oa=c[ka>>2]|0;na=c[ka+4>>2]|0;if((oa|0)==0&(na|0)==0){break}if((la|0)==(oa|0)&(F|0)==(na|0)){break i}else{ua=ua+1|0}}na=k|0;sGb(na,512,-1,la,F);KIb(u,16,2409904,(t=i,i=i+8|0,c[t>>2]=na,t)|0);i=t;w=-22;break b}}while(0);z=c[ma>>2]|0;na=c[ma+4>>2]|0;do{if(!((z|0)==0&(na|0)==0)){oa=(c[I>>2]|0)==0;ka=rGb(z,na)|0;if(oa){c[I>>2]=ka;break}if((ka|0)==(c[I>>2]|0)){break}oa=l|0;sGb(oa,512,-1,c[ma>>2]|0,c[ma+4>>2]|0);va=c[I>>2]|0;KIb(u,16,2402128,(t=i,i=i+24|0,c[t>>2]=oa,c[t+8>>2]=ka,c[t+16>>2]=va,t)|0);i=t;w=-22;break b}}while(0);ma=c[r>>2]|0;do{if((ma|0)==0){if((c[E>>2]|0)==62){C=143;break}if((c[a+120>>2]|0)>=1){if((c[a+124>>2]|0)>=1){C=142;break}}KIb(u,16,2395368,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;w=-22;break b}else{C=142}}while(0);if((C|0)==142){if(ma>>>0<2>>>0){C=143}}do{if((C|0)==143){na=c[a+72>>2]|0;if(!((na-1|0)>>>0<999>>>0)){break}KIb(u,24,2388232,(t=i,i=i+16|0,c[t>>2]=na,c[t+8>>2]=na,t)|0);i=t}}while(0);ma=a+564|0;if((c[ma>>2]|0)!=0){break}c[ma>>2]=((c[a+524>>2]|0)*3|0|0)/4|0}}while(0);D=a+928|0;mrc(a+904|0,0,16)|0;c[D>>2]=0;c[D+4>>2]=-2147483648;D=a+920|0;c[D>>2]=0;c[D+4>>2]=-2147483648;D=c[p>>2]|0;ma=c[D+76>>2]|0;do{if((ma|0)==0){wa=D}else{if((c[a+816>>2]&1|0)!=0){if((c[(c[n>>2]|0)+44>>2]|0)==0){wa=D;break}}na=ve[ma&4095](a)|0;if((na|0)<0){w=na;break b}wa=c[p>>2]|0}}while(0);if((wa|0)==0){v=0;break a}if((c[wa+88>>2]|0)==0){v=0;break a}ma=a+72|0;if((c[ma>>2]|0)==0){j:do{if((c[r>>2]|0)==1){D=c[E>>2]|0;k:do{switch(D|0){case 69649:{xa=2;break};case 69648:{xa=3;break};case 69647:case 69633:case 69632:case 69645:case 69638:{xa=4;break};default:{if((D|0)==65552|(D|0)==65549|(D|0)==65548|(D|0)==407917392|(D|0)==65551|(D|0)==65550){xa=24;break k}else if((D|0)==65545|(D|0)==65544|(D|0)==542135120|(D|0)==65547|(D|0)==65546|(D|0)==65556|(D|0)==65557){xa=32;break k}else if((D|0)==65558|(D|0)==65559){xa=64;break k}else if((D|0)==86071|(D|0)==86072|(D|0)==69644|(D|0)==69661|(D|0)==69655|(D|0)==1330333984|(D|0)==69636|(D|0)==69660|(D|0)==69646){xa=4;break k}else if((D|0)==65543|(D|0)==65542|(D|0)==65540|(D|0)==65563|(D|0)==65541|(D|0)==65553){xa=8;break k}else if((D|0)==65537|(D|0)==1347637264|(D|0)==65536|(D|0)==65554|(D|0)==65539|(D|0)==65538){xa=16;break k}else{ya=0;break j}}}}while(0);ya=ca(ca(c[a+412>>2]|0,xa)|0,c[I>>2]|0)|0}else{ya=0}}while(0);c[ma>>2]=ya}D=a+448|0;na=c[D>>2]|0;z=c[D+4>>2]|0;do{if((na|0)==0&(z|0)==0){C=172}else{va=rGb(na,z)|0;ka=c[I>>2]|0;if((ka|0)==0){c[I>>2]=va;za=va;break}if((va|0)==(ka|0)){C=172;break}ka=m|0;sGb(ka,512,-1,c[D>>2]|0,c[D+4>>2]|0);oa=c[I>>2]|0;KIb(u,24,2381304,(t=i,i=i+24|0,c[t>>2]=ka,c[t+8>>2]=va,c[t+16>>2]=oa,t)|0);i=t;c[D>>2]=0;c[D+4>>2]=0;C=172}}while(0);if((C|0)==172){za=c[I>>2]|0}if((za|0)<0|za>>>0>63>>>0){w=-22;break b}D=a+936|0;z=c[D>>2]|0;if((z|0)==0){v=0;break a}if((c[r>>2]|0)!=3){KIb(u,16,2374864,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;w=-22;break b}na=c[K>>2]|0;if((c[na+16>>2]&65536|0)!=0){KIb(u,24,2367912,(t=i,i=i+8|0,c[t>>2]=c[na+8>>2],t)|0);i=t;c[a+940>>2]=-1;v=0;break a}na=a+940|0;ma=c[na>>2]|0;if((ma|0)==0){c[na>>2]=1}else if((ma|0)!=1){v=0;break a}ma=Fqc(2353184,z)|0;if((ma|0)==-1){KIb(u,16,2344848,(t=i,i=i+8|0,c[t>>2]=c[D>>2],t)|0);i=t;w=-(c[(pd()|0)>>2]|0)|0;break b}else{Hqc(ma)|0;v=0;break a}}}while(0);KIb(u,16,2565680,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;w=-22}}while(0);OGb(g);mJb(a+60|0);r=c[n>>2]|0;if((r|0)!=0){VHb(r+20|0);mJb((c[n>>2]|0)+24|0)}mJb(n);c[p>>2]=0;v=w}}while(0);if((c[2194908]|0)==0){KIb(0,0,2593072,(t=i,i=i+24|0,c[t>>2]=2107744,c[t+8>>2]=2355864,c[t+16>>2]=3333,t)|0);i=t;Hd();return 0}c[2194908]=0;c[2244128]=(c[2244128]|0)-1;t=c[1448084]|0;if((t|0)!=0){We[t&2047](9800216,2)|0}if(!q){o=v;i=f;return o|0}OGb(e);c[e>>2]=c[g>>2];o=v;i=f;return o|0}function $4a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[1448084]|0;do{if((d|0)!=0){if((We[d&2047](9800216,1)|0)==0){break}else{e=-1}i=b;return e|0}}while(0);c[2244128]=(c[2244128]|0)+1;if((c[2244128]|0)==1){if((c[2194908]|0)!=0){KIb(0,0,2593072,(f=i,i=i+24|0,c[f>>2]=2109312,c[f+8>>2]=2355864,c[f+16>>2]=3326,f)|0);i=f;Hd();return 0}c[2194908]=1;e=0;i=b;return e|0}d=a;KIb(d,16,2112808,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;if((c[1448084]|0)==0){KIb(d,16,2110872,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}c[2194908]=1;if((c[2194908]|0)==0){KIb(0,0,2593072,(f=i,i=i+24|0,c[f>>2]=2107744,c[f+8>>2]=2355864,c[f+16>>2]=3333,f)|0);i=f;Hd();return 0}c[2194908]=0;c[2244128]=(c[2244128]|0)-1;f=c[1448084]|0;if((f|0)==0){e=-22;i=b;return e|0}We[f&2047](9800216,2)|0;e=-22;i=b;return e|0}function a5a(a){a=a|0;return(c[a+64>>2]|0)!=0|0}function b5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[1510462]|0;if((a|0)==171){d=1160852272}else if((a|0)==173){d=1464156752}else if((a|0)==86077){d=1330664787}else if((a|0)==86079){d=1950507339}else if((a|0)==172){d=4665933}else if((a|0)==65564){d=407917392}else if((a|0)==65565){d=542135120}else if((a|0)==175){d=1211250229}else{d=a}if((b|0)==0){e=0;return e|0}else{f=b;g=0}a:while(1){if((c[f+80>>2]|0)==0){if((c[f+84>>2]|0)==0){h=g}else{i=13}}else{i=13}do{if((i|0)==13){i=0;if((c[f+12>>2]|0)!=(d|0)){h=g;break}if((c[f+16>>2]&512|0)!=0&(g|0)==0){h=f}else{e=f;i=16;break a}}}while(0);b=c[f+56>>2]|0;if((b|0)==0){e=h;i=16;break}else{f=b;g=h}}if((i|0)==16){return e|0}return 0}function c5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[1510462]|0;if((a|0)==171){d=1160852272}else if((a|0)==65565){d=542135120}else if((a|0)==173){d=1464156752}else if((a|0)==86077){d=1330664787}else if((a|0)==175){d=1211250229}else if((a|0)==65564){d=407917392}else if((a|0)==86079){d=1950507339}else if((a|0)==172){d=4665933}else{d=a}if((b|0)==0){e=0;return e|0}else{f=b;g=0}a:while(1){do{if((c[f+88>>2]|0)==0){h=g}else{if((c[f+12>>2]|0)!=(d|0)){h=g;break}if((c[f+16>>2]&512|0)!=0&(g|0)==0){h=f}else{e=f;i=15;break a}}}while(0);b=c[f+56>>2]|0;if((b|0)==0){e=h;i=15;break}else{f=b;g=h}}if((i|0)==15){return e|0}return 0}function d5a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=b+28|0;h=c[g>>2]|0;if((h|0)<0){KIb(a,16,2338776,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;k=-22;i=f;return k|0}l=0;if(e>>>0>l>>>0|e>>>0==l>>>0&d>>>0>2147483631>>>0){KIb(a,16,2333104,(j=i,i=i+24|0,c[j>>2]=d,c[j+8>>2]=e,c[j+16>>2]=2147483631,j)|0);i=j;k=-22;i=f;return k|0}l=b+24|0;m=c[l>>2]|0;a:do{if((a|0)==0){n=h;o=m}else{p=c[a+64>>2]|0;do{if((m|0)!=0){if((m|0)==(c[p+36>>2]|0)){KIb(0,0,2593072,(j=i,i=i+24|0,c[j>>2]=2327712,c[j+8>>2]=2355864,c[j+16>>2]=1542,j)|0);i=j;Hd();return 0}else{q=(h|0)<0|0?-1:0;if((q|0)<(e|0)|(q|0)==(e|0)&h>>>0<d>>>0){break}else{n=h;o=m;break a}}}}while(0);q=a+64|0;r=p+36|0;s=p+40|0;t=d;do{if(t>>>0>4294967279>>>0){mJb(r);c[s>>2]=0}else{u=t+16|0;if((c[s>>2]|0)>>>0>u>>>0){mrc((c[r>>2]|0)+t|0,0,16)|0;break}else{v=((u*17|0)>>>4)+32|0;w=v>>>0>u>>>0?v:u;kJb(c[r>>2]|0);u=pJb(w)|0;c[r>>2]=u;c[s>>2]=(u|0)==0?0:w;break}}}while(0);s=c[(c[q>>2]|0)+36>>2]|0;c[l>>2]=s;r=c[(c[q>>2]|0)+40>>2]|0;c[g>>2]=r;c[b+52>>2]=0;n=r;o=s}}while(0);if((o|0)==0){o=K1(b,d)|0;if((o|0)>=0){k=o;i=f;return k|0}KIb(a,16,2316904,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0);i=j;k=o;i=f;return k|0}o=b|0;l=b+52|0;m=(n|0)<0|0?-1:0;if((m|0)<(e|0)|(m|0)==(e|0)&n>>>0<d>>>0){KIb(a,16,2322e3,(j=i,i=i+24|0,c[j>>2]=n,c[j+8>>2]=d,c[j+16>>2]=e,j)|0);i=j;k=-22;i=f;return k|0}else{j=c[l>>2]|0;e=c[o>>2]|0;J1(b);c[l>>2]=j;c[o>>2]=e;c[g>>2]=d;k=0;i=f;return k|0}return 0}function e5a(a,b){a=a|0;b=b|0;return d5a(0,a,b,(b|0)<0|0?-1:0)|0}function f5a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;c[j>>2]=0;k=b|0;l=c[k>>2]|0;m=b+24|0;n=c[m>>2]|0;o=b+28|0;p=c[o>>2]|0;q=b+52|0;r=c[q>>2]|0;s=(n|0)!=0;t=s&1^1;c[e>>2]=0;u=a+12|0;v=c[u>>2]|0;w=c[v+16>>2]|0;x=(d|0)==0;if((w&32|0)==0&x){P1(b);J1(b);y=0;i=f;return y|0}a:do{if(x){z=0;A=0;B=v;C=26}else{do{if((c[d+64>>2]|0)==0){do{if((RKb(c[a+420>>2]|0)|0)!=0){if((c[a+416>>2]|0)<=8){break}KIb(a,16,2312296,(D=i,i=i+8|0,c[D>>2]=8,D)|0);i=D;y=-22;i=f;return y|0}}while(0);KIb(a,24,2307768,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=UHb()|0;if((E|0)==0){y=-12;i=f;return y|0}else{F=E;nrc(F|0,d|0,472)|0;c[E+64>>2]=E;G=c[u>>2]|0;H=E;I=F;J=G;K=c[G+16>>2]|0;break}}else{H=d;I=0;J=v;K=w}}while(0);if((K&64|0)!=0){if((c[H+76>>2]|0)<=(c[a+424>>2]|0)){z=H;A=I;B=J;C=26;break}KIb(a,16,2302200,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;L=-22;M=I;break}if((K&65536|0)!=0){z=H;A=I;B=J;C=26;break}G=H+76|0;F=c[G>>2]|0;E=a+424|0;N=c[E>>2]|0;b:do{if((F|0)<(N|0)){O=a+64|0;if((c[(c[O>>2]|0)+16>>2]|0)!=0){P=H;Q=F;R=N;break}S=UHb()|0;c[h>>2]=S;if((S|0)==0){L=-12;M=I;break a}c[S+80>>2]=c[H+80>>2];T=H+352|0;U=c[T+4>>2]|0;V=S+352|0;c[V>>2]=c[T>>2];c[V+4>>2]=U;HHb(S,GHb(H)|0);c[S+76>>2]=c[E>>2];U=XHb(S,32)|0;do{if((U|0)<0){W=U}else{V=ZHb(S,H)|0;if((V|0)<0){W=V;break}V=a+416|0;T=a+420|0;X=XKb(c[(c[h>>2]|0)+64>>2]|0,c[H+64>>2]|0,0,0,c[G>>2]|0,c[V>>2]|0,c[T>>2]|0)|0;if((X|0)<0){W=X;break}X=c[h>>2]|0;Y=c[G>>2]|0;Z=VKb(c[X+64>>2]|0,Y,(c[X+76>>2]|0)-Y|0,c[V>>2]|0,c[T>>2]|0)|0;if((Z|0)<0){W=Z;break}Z=c[h>>2]|0;c[j>>2]=Z;c[(c[O>>2]|0)+16>>2]=1;P=Z;Q=c[Z+76>>2]|0;R=c[E>>2]|0;break b}}while(0);VHb(h);L=W;M=I;break a}else{P=H;Q=F;R=N}}while(0);if((Q|0)==(R|0)){z=P;A=I;B=c[u>>2]|0;C=26;break}else{KIb(a,16,2291096,(D=i,i=i+16|0,c[D>>2]=Q,c[D+8>>2]=R,D)|0);i=D;L=-22;M=I;break}}}while(0);c:do{if((C|0)==26){I=hf[c[B+84>>2]&1023](a,b,z,e)|0;do{if((I|0)==0){if((c[e>>2]|0)==0){c[o>>2]=0;break}R=b+8|0;do{if((c[(c[u>>2]|0)+16>>2]&32|0)==0){if((c[R>>2]|0)==0&(c[R+4>>2]|0)==(-2147483648|0)){Q=z+136|0;P=c[Q+4>>2]|0;c[R>>2]=c[Q>>2];c[R+4>>2]=P}P=b+48|0;if((c[P>>2]|0)!=0){break}Q=c[z+76>>2]|0;c[g>>2]=1;c[g+4>>2]=c[a+412>>2];H=XIb(Q,(Q|0)<0|0?-1:0,g,a+104|0)|0;c[P>>2]=H}}while(0);H=c[R+4>>2]|0;P=b+16|0;c[P>>2]=c[R>>2];c[P+4>>2]=H}}while(0);H=c[m>>2]|0;do{if((H|0)==0){_=t;$=I}else{if((H|0)!=(c[(c[a+64>>2]|0)+36>>2]|0)){_=t;$=I;break}if(!s){P=(Q1(b)|0)<0;_=0;$=P?-12:I;break}P=c[o>>2]|0;if((p|0)<(P|0)){KIb(a,16,2284504,(D=i,i=i+8|0,c[D>>2]=P,D)|0);i=D;c[o>>2]=p;aa=-1}else{nrc(n|0,H|0,P)|0;aa=I}c[k>>2]=l;c[m>>2]=n;c[q>>2]=r;_=0;$=aa}}while(0);if(($|0)==0){do{if((_|0)==0){ba=0}else{if((c[m>>2]|0)==0){ba=0;break}I=jGb(k,(c[o>>2]|0)+16|0)|0;if(!((I|0)>-1)){ba=I;break}c[m>>2]=c[(c[k>>2]|0)+4>>2];ba=I}}while(0);I=a+428|0;c[I>>2]=(c[I>>2]|0)+1;ca=ba}else{ca=$}do{if((ca|0)>=0){if((c[e>>2]|0)==0){break}I=b+36|0;c[I>>2]=c[I>>2]|1;L=ca;M=A;break c}}while(0);P1(b);J1(b);L=ca;M=A}}while(0);VHb(j);kJb(M);y=L;i=f;return y|0}function g5a(a){a=a|0;var b=0;a:do{switch(a|0){case 69648:{b=3;break};case 69649:{b=2;break};case 69647:case 69633:case 69632:case 69645:case 69638:{b=4;break};default:{if((a|0)==65543|(a|0)==65542|(a|0)==65540|(a|0)==65563|(a|0)==65541|(a|0)==65553){b=8;break a}else if((a|0)==65545|(a|0)==65544|(a|0)==542135120|(a|0)==65547|(a|0)==65546|(a|0)==65556|(a|0)==65557){b=32;break a}else if((a|0)==65558|(a|0)==65559){b=64;break a}else if((a|0)==86071|(a|0)==86072|(a|0)==69644|(a|0)==69661|(a|0)==69655|(a|0)==1330333984|(a|0)==69636|(a|0)==69660|(a|0)==69646){b=4;break a}else if((a|0)==65552|(a|0)==65549|(a|0)==65548|(a|0)==407917392|(a|0)==65551|(a|0)==65550){b=24;break a}else if((a|0)==65537|(a|0)==1347637264|(a|0)==65536|(a|0)==65554|(a|0)==65539|(a|0)==65538){b=16;break a}else{b=0;break a}}}}while(0);return b|0}function h5a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+88|0;g=f|0;h=f+80|0;c[h>>2]=0;if((d|0)<16384){KIb(a,16,2276504,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=f;return k|0}J1(g);c[g+24>>2]=b;b=g+28|0;c[b>>2]=d;d=i5a(a,g,e,h)|0;e=(d|0)!=0;do{if(!(e|(c[h>>2]|0)==0)){j=c[a+804>>2]|0;if((j|0)==0){break}l=g+8|0;m=c[l+4>>2]|0;n=j+136|0;c[n>>2]=c[l>>2];c[n+4>>2]=m;c[j+84>>2]=c[g+36>>2]&1}}while(0);a=g+44|0;if((c[a>>2]|0)>0){h=g+40|0;g=0;do{kJb(c[(c[h>>2]|0)+(g*12|0)>>2]|0);g=g+1|0;}while((g|0)<(c[a>>2]|0));mJb(h);c[a>>2]=0}k=e?d:c[b>>2]|0;i=f;return k|0}function i5a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;h=d|0;j=c[h>>2]|0;k=d+24|0;l=c[k>>2]|0;m=d+28|0;n=c[m>>2]|0;o=d+52|0;p=c[o>>2]|0;q=(l|0)!=0;r=q&1^1;c[f>>2]=0;do{if((c[b+88>>2]&512|0)!=0){s=c[b+668>>2]|0;if((s|0)==0){break}a[s]=0}}while(0);s=b+12|0;if((c[(c[s>>2]|0)+16>>2]&32|0)==0&(e|0)==0){P1(d);J1(d);c[m>>2]=0;t=0;i=g;return t|0}u=b;if((tIb(c[b+120>>2]|0,c[b+124>>2]|0,0,u)|0)!=0){t=-22;i=g;return t|0}v=c[(c[s>>2]|0)+84>>2]|0;if((v|0)==0){KIb(0,0,2593072,(w=i,i=i+24|0,c[w>>2]=2272128,c[w+8>>2]=2355864,c[w+16>>2]=1903,w)|0);i=w;Hd();return 0}x=hf[v&1023](b,d,e,f)|0;if((x|0)>=1){KIb(0,0,2593072,(w=i,i=i+24|0,c[w>>2]=2267312,c[w+8>>2]=2355864,c[w+16>>2]=1906,w)|0);i=w;Hd();return 0}v=c[k>>2]|0;do{if((v|0)==0){y=r;z=x}else{if((v|0)!=(c[(c[b+64>>2]|0)+36>>2]|0)){y=r;z=x;break}if(!q){A=(Q1(d)|0)<0;y=0;z=A?-12:x;break}A=c[m>>2]|0;if((n|0)<(A|0)){KIb(u,16,2284504,(w=i,i=i+8|0,c[w>>2]=A,w)|0);i=w;c[m>>2]=n;B=-1}else{nrc(l|0,v|0,A)|0;B=x}c[h>>2]=j;c[k>>2]=l;c[o>>2]=p;y=0;z=B}}while(0);if((z|0)==0){do{if((c[f>>2]|0)==0){c[m>>2]=0}else{if((c[(c[s>>2]|0)+16>>2]&32|0)!=0){break}B=e+136|0;p=c[B>>2]|0;o=c[B+4>>2]|0;B=d+16|0;c[B>>2]=p;c[B+4>>2]=o;B=d+8|0;c[B>>2]=p;c[B+4>>2]=o}}while(0);do{if((y|0)==0){C=0}else{if((c[k>>2]|0)==0){C=0;break}e=jGb(h,(c[m>>2]|0)+16|0)|0;if(!((e|0)>-1)){C=e;break}c[k>>2]=c[(c[h>>2]|0)+4>>2];C=e}}while(0);h=b+428|0;c[h>>2]=(c[h>>2]|0)+1;D=C}else{D=z}do{if((D|0)>=0){if((c[f>>2]|0)==0){break}W1(d)|0;t=D;i=g;return t|0}}while(0);P1(d);t=D;i=g;return t|0}function j5a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;if((c[e+4>>2]|0)==0){g=hf[c[(c[a+12>>2]|0)+80>>2]&1023](a,b,d,e)|0;e=a+428|0;c[e>>2]=(c[e>>2]|0)+1;h=g;i=f;return h|0}else{KIb(a,16,2263800,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;h=-1;i=f;return h|0}return 0}function k5a(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+88|0;g=f|0;h=f+8|0;j=a+64|0;k=c[j>>2]|0;nrc(h|0,e|0,80)|0;l=a+12|0;m=c[l>>2]|0;if((m|0)==0){n=-22;i=f;return n|0}if((c[m+8>>2]|0)!=0){KIb(a,16,2259856,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-22;i=f;return n|0}c[d>>2]=0;m=c[a+128>>2]|0;p=c[a+132>>2]|0;do{if((m|p|0)!=0){if((tIb(m,p,0,a)|0)==0){break}else{n=-22}i=f;return n|0}}while(0);WHb(b);do{if((c[(c[l>>2]|0)+16>>2]&32|0)==0){if((c[e+28>>2]|0)!=0){q=9;break}if((c[a+816>>2]&1|0)==0){r=0}else{q=9}}else{q=9}}while(0);do{if((q|0)==9){p=X1(h)|0;m=l5a(a,h)|0;if((m|0)<0){KIb(a,16,2255512,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;if((c[a+696>>2]&8|0)==0){q=11}else{s=m}}else{q=11}if((q|0)==11){c[(c[j>>2]|0)+32>>2]=h;m=hf[c[(c[l>>2]|0)+88>>2]&1023](a,b,d,h)|0;t=e+16|0;u=c[t+4>>2]|0;v=b+152|0;c[v>>2]=c[t>>2];c[v+4>>2]=u;if((c[a+176>>2]|0)==0){u=e+64|0;EHb(b,c[u>>2]|0,c[u+4>>2]|0)}do{if((c[(c[l>>2]|0)+16>>2]&2|0)==0){u=b+124|0;if((c[u>>2]|0)==0){v=a+224|0;t=u;u=c[v+4>>2]|0;c[t>>2]=c[v>>2];c[t+4>>2]=u}u=b+68|0;if((c[u>>2]|0)==0){c[u>>2]=c[a+120>>2]}u=b+72|0;if((c[u>>2]|0)==0){c[u>>2]=c[a+124>>2]}u=b+80|0;if(!((c[u>>2]|0)==-1)){break}c[u>>2]=c[a+140>>2]}}while(0);u=QHb(b)|0;t=V1(c[(c[j>>2]|0)+32>>2]|0,72,g)|0;Z1(t,c[g>>2]|0,u)|0;s=m}c[(c[j>>2]|0)+32>>2]=0;do{if((p|0)==0){w=s}else{T1(h);if((s|0)!=(c[h+28>>2]|0)){w=s;break}w=c[e+28>>2]|0}}while(0);if((c[d>>2]|0)==0){WHb(b);r=w;break}do{if((c[a+488>>2]|0)==0){p=m5a(k,b)|0;if((p|0)<0){n=p}else{break}i=f;return n|0}}while(0);p=a+428|0;c[p>>2]=(c[p>>2]|0)+1;p=b+144|0;m=c[p>>2]|0;u=c[p+4>>2]|0;p=b+152|0;t=c[p>>2]|0;v=c[p+4>>2]|0;p=(t|0)!=0|(v|0)!=(-2147483648|0);do{if(p){x=a+928|0;y=c[x+4>>2]|0;z=a+912|0;A=wrc((y|0)>=(v|0)&((y|0)>(v|0)|(c[x>>2]|0)>>>0>=t>>>0)&1,0,c[z>>2]|0,c[z+4>>2]|0)|0;c[z>>2]=A;c[z+4>>2]=G;c[x>>2]=t;c[x+4>>2]=v;q=33}else{if((m|0)==0&(u|0)==(-2147483648|0)){B=1;break}x=a+928|0;c[x>>2]=m;c[x+4>>2]=u;q=33}}while(0);do{if((q|0)==33){if(!((m|0)==0&(u|0)==(-2147483648|0))){x=a+920|0;z=c[x+4>>2]|0;A=a+904|0;y=wrc((z|0)>=(u|0)&((z|0)>(u|0)|(c[x>>2]|0)>>>0>=m>>>0)&1,0,c[A>>2]|0,c[A+4>>2]|0)|0;c[A>>2]=y;c[A+4>>2]=G;c[x>>2]=m;c[x+4>>2]=u;B=0;break}if(!p){B=1;break}x=a+920|0;c[x>>2]=t;c[x+4>>2]=v;B=1}}while(0);x=a+904|0;A=c[x+4>>2]|0;y=a+912|0;z=c[y+4>>2]|0;C=p&((A|0)>(z|0)|(A|0)==(z|0)&(c[x>>2]|0)>>>0>(c[y>>2]|0)>>>0)|B;AHb(b,C?t:m,C?v:u);r=w}}while(0);w=c[b+64>>2]|0;if((w|0)==0|(w|0)==(b|0)){n=r;i=f;return n|0}else{KIb(0,0,2593072,(o=i,i=i+24|0,c[o>>2]=2250752,c[o+8>>2]=2355864,c[o+16>>2]=2200,o)|0);i=o;Hd();return 0}return 0}function l5a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+8|0;f=e|0;c[f>>2]=0;g=V1(b,2,f)|0;if((g|0)==0){h=0;i=e;return h|0}if((c[(c[a+12>>2]|0)+16>>2]&16384|0)==0){KIb(a,16,2635536,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-22;i=e;return h|0}b=c[f>>2]|0;a:do{if((b|0)>=4){k=g+4|0;l=g;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b-4|0;c[f>>2]=l;if((m&1|0)==0){n=k;o=l}else{if((l|0)<4){break}l=k;c[a+416>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b-8|0;c[f>>2]=l;n=g+8|0;o=l}if((m&2|0)==0){p=n;q=o}else{if((o|0)<8){break}l=n;k=l|0;r=l+4|0;l=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=a+448|0;c[r>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[r+4>>2]=l;l=o-8|0;c[f>>2]=l;p=n+8|0;q=l}if((m&4|0)==0){s=p;t=q}else{if((q|0)<4){break}l=p;c[a+412>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=q-4|0;c[f>>2]=l;s=p+4|0;t=l}do{if((m&8|0)!=0){if((t|0)<8){break a}l=s;r=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+120|0;c[l>>2]=r;k=s+4|0;u=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+124|0;c[k>>2]=u;c[f>>2]=t-8;v=tIb(r,u,0,a)|0;w=(v|0)<0;x=w?0:u;u=w?0:r;c[a+128>>2]=u;c[a+132>>2]=x;r=c[a+800>>2]|0;c[l>>2]=-(-u>>r);c[k>>2]=-(-x>>r);if(w){h=v}else{break}i=e;return h|0}}while(0);h=0;i=e;return h|0}}while(0);KIb(a,16,2632600,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;h=-1094995529;i=e;return h|0}function m5a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+20|0;WHb(c[d>>2]|0);aIb(c[d>>2]|0,b);a=ZHb(b,c[d>>2]|0)|0;if((a|0)<0){e=a;return e|0}nrc(b|0,c[d>>2]|0,32)|0;nrc(b+32|0,(c[d>>2]|0)+32|0,32)|0;a=c[d>>2]|0;do{if((c[a+64>>2]|0)==(a|0)){c[b+64>>2]=b;f=c[d>>2]|0}else{g=(GHb(a)|0)<<2;if((g|0)==0){WHb(b);e=-558323010;return e|0}h=hJb(g)|0;c[b+64>>2]=h;if((h|0)!=0){i=c[d>>2]|0;nrc(h|0,c[i+64>>2]|0,g)|0;f=i;break}WHb(b);e=-12;return e|0}}while(0);c[b+80>>2]=c[f+80>>2];c[b+68>>2]=c[f+68>>2];c[b+72>>2]=c[f+72>>2];d=f+352|0;a=c[d+4>>2]|0;i=b+352|0;c[i>>2]=c[d>>2];c[i+4>>2]=a;c[b+76>>2]=c[f+76>>2];HHb(b,GHb(f)|0);e=0;return e|0}function n5a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;i=i+112|0;h=g|0;j=g+8|0;k=g+16|0;l=g+96|0;m=g+104|0;n=a+64|0;o=c[n>>2]|0;c[e>>2]=0;do{if((c[f+24>>2]|0)==0){if((c[f+28>>2]|0)==0){break}KIb(a,16,2227552,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=g;return q|0}}while(0);r=a+12|0;s=c[r>>2]|0;if((s|0)==0){q=-22;i=g;return q|0}if((c[s+8>>2]|0)!=1){KIb(a,16,2222848,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-22;i=g;return q|0}WHb(b);do{if((c[(c[r>>2]|0)+16>>2]&32|0)==0){if((c[f+28>>2]|0)!=0){t=10;break}if((c[a+816>>2]&1|0)==0){u=0}else{t=10}}else{t=10}}while(0);a:do{if((t|0)==10){nrc(k|0,f|0,80)|0;s=X1(k)|0;v=l5a(a,k)|0;if((v|0)<0){KIb(a,16,2255512,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;if((c[a+696>>2]&8|0)==0){t=12}else{w=v}}else{t=12}do{if((t|0)==12){c[(c[n>>2]|0)+32>>2]=k;v=hf[c[(c[r>>2]|0)+88>>2]&1023](a,b,e,k)|0;x=f+16|0;y=c[x+4>>2]|0;z=b+152|0;c[z>>2]=c[x>>2];c[z+4>>2]=y;do{if((v|0)>-1){if((c[e>>2]|0)==0){break}y=QHb(b)|0;x=V1(c[(c[n>>2]|0)+32>>2]|0,72,h)|0;Z1(x,c[h>>2]|0,y)|0;y=a+428|0;c[y>>2]=(c[y>>2]|0)+1;y=b+144|0;x=c[y>>2]|0;A=c[y+4>>2]|0;y=c[z>>2]|0;B=c[z+4>>2]|0;C=(y|0)!=0|(B|0)!=(-2147483648|0);do{if(C){D=a+928|0;E=c[D+4>>2]|0;F=a+912|0;H=wrc((E|0)>=(B|0)&((E|0)>(B|0)|(c[D>>2]|0)>>>0>=y>>>0)&1,0,c[F>>2]|0,c[F+4>>2]|0)|0;c[F>>2]=H;c[F+4>>2]=G;c[D>>2]=y;c[D+4>>2]=B;t=18}else{if((x|0)==0&(A|0)==(-2147483648|0)){I=1;break}D=a+928|0;c[D>>2]=x;c[D+4>>2]=A;t=18}}while(0);do{if((t|0)==18){if(!((x|0)==0&(A|0)==(-2147483648|0))){D=a+920|0;F=c[D+4>>2]|0;H=a+904|0;E=wrc((F|0)>=(A|0)&((F|0)>(A|0)|(c[D>>2]|0)>>>0>=x>>>0)&1,0,c[H>>2]|0,c[H+4>>2]|0)|0;c[H>>2]=E;c[H+4>>2]=G;c[D>>2]=x;c[D+4>>2]=A;I=0;break}if(!C){I=1;break}D=a+920|0;c[D>>2]=y;c[D+4>>2]=B;I=1}}while(0);D=a+904|0;H=c[D+4>>2]|0;E=a+912|0;F=c[E+4>>2]|0;J=C&((H|0)>(F|0)|(H|0)==(F|0)&(c[D>>2]|0)>>>0>(c[E>>2]|0)>>>0)|I;AHb(b,J?y:x,J?B:A);J=b+80|0;if((c[J>>2]|0)==-1){c[J>>2]=c[a+420>>2]}J=b+352|0;if((c[J>>2]|0)==0&(c[J+4>>2]|0)==0){E=a+448|0;D=c[E+4>>2]|0;c[J>>2]=c[E>>2];c[J+4>>2]=D}if((GHb(b)|0)==0){HHb(b,c[a+416>>2]|0)}D=b+344|0;if((c[D>>2]|0)!=0){break}c[D>>2]=c[a+412>>2]}}while(0);D=V1(c[(c[n>>2]|0)+32>>2]|0,70,j)|0;if((D|0)!=0&(c[j>>2]|0)>9){J=D;E=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;c[(c[n>>2]|0)+48>>2]=E;KIb(a,48,2219192,(p=i,i=i+8|0,c[p>>2]=E,p)|0);i=p;E=D+4|0;K=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0}else{K=0}E=(c[n>>2]|0)+48|0;D=c[E>>2]|0;do{if((D|0)!=0){if((c[e>>2]|0)==0){break}J=b+76|0;F=c[J>>2]|0;if((F|0)<=(D|0)){c[e>>2]=0;H=(c[E>>2]|0)-(c[J>>2]|0)|0;c[E>>2]=H;KIb(a,48,2216208,(p=i,i=i+8|0,c[p>>2]=H,p)|0);i=p;break}H=c[b+64>>2]|0;XKb(H,H,0,D,F-D|0,c[a+416>>2]|0,c[b+80>>2]|0)|0;F=a+888|0;do{if((c[F>>2]|0)==0){t=44}else{H=c[a+412>>2]|0;if((H|0)==0){t=44;break}L=c[(c[n>>2]|0)+48>>2]|0;c[l>>2]=1;c[l+4>>2]=H;H=XIb(L,(L|0)<0|0?-1:0,l,F)|0;L=G;M=b+144|0;N=c[M>>2]|0;O=c[M+4>>2]|0;if(!((N|0)==0&(O|0)==(-2147483648|0))){P=wrc(N,O,H,L)|0;c[M>>2]=P;c[M+4>>2]=G}M=c[z>>2]|0;P=c[z+4>>2]|0;if(!((M|0)==0&(P|0)==(-2147483648|0))){O=wrc(M,P,H,L)|0;c[z>>2]=O;c[z+4>>2]=G}O=BHb(b)|0;P=G;if((P|0)<(L|0)|(P|0)==(L|0)&O>>>0<H>>>0){break}O=BHb(b)|0;P=xrc(O,G,H,L)|0;CHb(b,P,G)}}while(0);if((t|0)==44){KIb(a,24,2213544,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}F=c[J>>2]|0;KIb(a,48,2211256,(p=i,i=i+16|0,c[p>>2]=c[(c[n>>2]|0)+48>>2],c[p+8>>2]=F,p)|0);i=p;F=(c[n>>2]|0)+48|0;c[J>>2]=(c[J>>2]|0)-(c[F>>2]|0);c[F>>2]=0}}while(0);if((K|0)==0){w=v;break}z=b+76|0;D=c[z>>2]|0;if(K>>>0>D>>>0){w=v;break}if((c[e>>2]|0)==0){w=v;break}if((K|0)==(D|0)){c[e>>2]=0;w=v;break}E=a+888|0;do{if((c[E>>2]|0)==0){t=55}else{F=c[a+412>>2]|0;if((F|0)==0){t=55;break}c[m>>2]=1;c[m+4>>2]=F;F=XIb(D-K|0,0,m,E)|0;A=G;B=BHb(b)|0;x=G;if((x|0)<(A|0)|(x|0)==(A|0)&B>>>0<F>>>0){break}B=BHb(b)|0;x=xrc(B,G,F,A)|0;CHb(b,x,G)}}while(0);if((t|0)==55){KIb(a,24,2208112,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}E=c[z>>2]|0;KIb(a,48,2199352,(p=i,i=i+16|0,c[p>>2]=K,c[p+8>>2]=E,p)|0);i=p;c[z>>2]=(c[z>>2]|0)-K;w=v}}while(0);c[(c[n>>2]|0)+32>>2]=0;do{if((s|0)==0){Q=w}else{T1(k);if((w|0)!=(c[k+28>>2]|0)){Q=w;break}Q=c[f+28>>2]|0}}while(0);do{if((Q|0)>-1){if((c[e>>2]|0)==0){break}if((c[a+488>>2]|0)!=0){u=Q;break a}s=m5a(o,b)|0;if((s|0)<0){q=s}else{u=Q;break a}i=g;return q|0}}while(0);WHb(b);u=Q}}while(0);q=u;i=g;return q|0}function o5a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;i=i+280|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+112|0;q=j+192|0;r=j+272|0;do{if((c[h+24>>2]|0)==0){if((c[h+28>>2]|0)==0){break}KIb(e,16,2227552,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-22;i=j;return t|0}}while(0);u=e+12|0;v=c[u>>2]|0;if((v|0)==0){t=-22;i=j;return t|0}if((c[v+8>>2]|0)!=3){KIb(e,16,2195224,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-22;i=j;return t|0}c[g>>2]=0;v=f;mrc(v|0,0,24)|0;w=f+24|0;c[w>>2]=0;c[w+4>>2]=-2147483648;do{if((c[(c[u>>2]|0)+16>>2]&32|0)==0){if((c[h+28>>2]|0)==0){t=0}else{break}i=j;return t|0}}while(0);x=q;nrc(x|0,h|0,80)|0;y=(X1(q)|0)!=0;if(y){z=c[q+28>>2]|0;A=(c[h+28>>2]|0)-z|0;mrc((c[q+24>>2]|0)+z|0,0,((A|0)>16?16:A)|0)|0}nrc(p|0,x|0,80)|0;do{if((c[e+940>>2]|0)==1){x=q+28|0;if((c[x>>2]|0)==0){B=0;break}A=e+936|0;z=Fqc(2353184,c[A>>2]|0)|0;if((z|0)==-1){KIb(0,0,2593072,(s=i,i=i+24|0,c[s>>2]=2104880,c[s+8>>2]=2355864,c[s+16>>2]=2411,s)|0);i=s;Hd();return 0}C=q+24|0;c[k>>2]=c[C>>2];D=c[x>>2]|0;c[m>>2]=D;a:do{if(D>>>0>536870894>>>0){KIb(e,16,2644160,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;E=-12}else{x=K1(o,D<<2)|0;if((x|0)<0){E=x;break}c[p>>2]=c[o>>2];F=c[o+24>>2]|0;H=p+24|0;c[H>>2]=F;I=c[o+28>>2]|0;J=p+28|0;c[J>>2]=I;c[l>>2]=F;c[n>>2]=I;do{if(!((Iqc(z,k,m,l,n)|0)==-1)){if((Iqc(z,0,0,l,n)|0)==-1){break}I=c[n>>2]|0;F=c[J>>2]|0;if(!(I>>>0<F>>>0)){break}if((c[m>>2]|0)!=0){break}K=F-I|0;c[J>>2]=K;mrc((c[H>>2]|0)+K|0,0,I|0)|0;E=x;break a}}while(0);x=c[A>>2]|0;KIb(e,16,2641440,(s=i,i=i+16|0,c[s>>2]=c[C>>2],c[s+8>>2]=x,s)|0);i=s;P1(o);E=-(c[(pd()|0)>>2]|0)|0}}while(0);Hqc(z)|0;B=E}else{B=0}}while(0);if((B|0)<0){c[g>>2]=0;L=B}else{B=e+64|0;c[(c[B>>2]|0)+32>>2]=p;E=e+888|0;do{if((c[e+892>>2]|0)!=0){o=h+8|0;m=c[o>>2]|0;n=c[o+4>>2]|0;if((m|0)==0&(n|0)==(-2147483648|0)){break}c[r>>2]=1;c[r+4>>2]=1e6;o=XIb(m,n,E,r)|0;c[w>>2]=o;c[w+4>>2]=G}}while(0);w=hf[c[(c[u>>2]|0)+88>>2]&1023](e,v,g,p)|0;v=f+12|0;u=c[v>>2]|0;b:do{if((u|0)!=0){r=f+8|0;if((c[r>>2]|0)==0){o=c[h+48>>2]|0;do{if((o|0)==0){M=u}else{if((c[E>>2]|0)==0){M=u;break}n=XIb(o,(o|0)<0|0?-1:0,E,1998152)|0;c[r>>2]=n;M=c[v>>2]|0}}while(0);if((M|0)==0){break}else{N=M}}else{N=u}r=c[f+16>>2]|0;o=0;c:while(1){z=c[(c[r+(o<<2)>>2]|0)+92>>2]|0;d:do{if((z|0)!=0){n=z;while(1){m=a[n]|0;if(m<<24>>24==0){break d}l=m&255;k=l>>>1&64;if((l&192|0)==128|(m&255)>>>0>253>>>0){break c}m=n+1|0;if((k&l|0)==0){O=l;P=k;Q=m}else{C=l;l=k;k=m;while(1){m=(d[k]|0)-128|0;if(m>>>0>63>>>0){break c}A=m+(C<<6)|0;m=l<<5;D=k+1|0;if((A&m|0)==0){O=A;P=m;Q=D;break}else{C=A;l=m;k=D}}}k=(P<<1)-1&O;l=Q-n|0;do{if((l|0)==1){R=0}else{if((l|0)==2){R=128;break}R=1<<(l*5|0)-4}}while(0);if(k>>>0<R>>>0|k>>>0>1114111>>>0|(k|0)==65534|(k-55296|0)>>>0<2048>>>0){break c}else{n=Q}}}}while(0);o=o+1|0;if(!(o>>>0<N>>>0)){break b}}KIb(e,16,2192736,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;p5a(f);t=-1094995529;i=j;return t|0}}while(0);if((c[q+24>>2]|0)!=(c[p+24>>2]|0)){c[p+40>>2]=0;c[p+44>>2]=0;P1(p)}p=c[(c[e+896>>2]|0)+16>>2]|0;do{if((p&65536|0)==0){if((p&131072|0)==0){break}b[f>>1]=1}else{b[f>>1]=0}}while(0);c[(c[B>>2]|0)+32>>2]=0;L=w}do{if(y){T1(q);if((L|0)!=(c[q+28>>2]|0)){S=L;break}S=c[h+28>>2]|0}else{S=L}}while(0);if((c[g>>2]|0)==0){t=S;i=j;return t|0}g=e+428|0;c[g>>2]=(c[g>>2]|0)+1;t=S;i=j;return t|0}function p5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+12|0;d=a+16|0;if((c[b>>2]|0)==0){e=d;mJb(e);f=a;mrc(f|0,0,32)|0;return}else{g=0}do{mJb((c[(c[d>>2]|0)+(g<<2)>>2]|0)+20|0);mJb((c[(c[d>>2]|0)+(g<<2)>>2]|0)+24|0);mJb((c[(c[d>>2]|0)+(g<<2)>>2]|0)+28|0);mJb((c[(c[d>>2]|0)+(g<<2)>>2]|0)+32|0);mJb((c[(c[d>>2]|0)+(g<<2)>>2]|0)+88|0);mJb((c[(c[d>>2]|0)+(g<<2)>>2]|0)+92|0);mJb((c[d>>2]|0)+(g<<2)|0);g=g+1|0;}while(g>>>0<(c[b>>2]|0)>>>0);e=d;mJb(e);f=a;mrc(f|0,0,32)|0;return}function q5a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[2194908]|0)==0){KIb(0,0,2593072,(d=i,i=i+24|0,c[d>>2]=2107744,c[d+8>>2]=2355864,c[d+16>>2]=3333,d)|0);i=d;Hd();return 0}c[2194908]=0;c[2244128]=(c[2244128]|0)-1;d=c[1448084]|0;if((d|0)==0){e=r5a(a)|0;f=$4a(0)|0;i=b;return e|0}We[d&2047](9800216,2)|0;e=r5a(a)|0;f=$4a(0)|0;i=b;return e|0}function r5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;if((a|0)==0){d=0;i=b;return d|0}e=$4a(a)|0;if((e|0)<0){d=e;i=b;return d|0}e=a+64|0;f=c[e>>2]|0;if((f|0)!=0){g=c[f+24>>2]|0;h=c[a+12>>2]|0;do{if((h|0)==0){j=f}else{k=c[h+92>>2]|0;if((k|0)==0){j=f;break}ve[k&4095](a)|0;j=c[e>>2]|0}}while(0);c[a+804>>2]=0;c[j+40>>2]=0;mJb(j+36|0);VHb((c[e>>2]|0)+20|0);lGb(g|0);lGb(g+4|0);lGb(g+8|0);lGb(g+12|0);mJb((c[e>>2]|0)+24|0);mJb(e)}e=a+60|0;g=c[e>>2]|0;j=a+12|0;do{if((g|0)!=0){f=c[j>>2]|0;if((f|0)==0){break}if((c[f+44>>2]|0)==0){break}WJb(g)}}while(0);WJb(a);mJb(e);e=c[j>>2]|0;do{if((e|0)!=0){if((c[e+80>>2]|0)==0){if((c[e+84>>2]|0)==0){break}}mJb(a+96|0)}}while(0);c[j>>2]=0;c[a+816>>2]=0;if((c[2194908]|0)==0){KIb(0,0,2593072,(a=i,i=i+24|0,c[a>>2]=2107744,c[a+8>>2]=2355864,c[a+16>>2]=3333,a)|0);i=a;Hd();return 0}c[2194908]=0;c[2244128]=(c[2244128]|0)-1;a=c[1448084]|0;if((a|0)==0){d=0;i=b;return d|0}We[a&2047](9800216,2)|0;d=0;i=b;return d|0}function s5a(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){b=0;return b|0}d=c[1510462]|0;if((d|0)==0){b=0;return b|0}else{e=d}while(1){if((c[e+80>>2]|0)==0){if((c[e+84>>2]|0)!=0){f=5}}else{f=5}if((f|0)==5){f=0;if((irc(a,c[e>>2]|0)|0)==0){b=e;f=7;break}}d=c[e+56>>2]|0;if((d|0)==0){b=0;f=7;break}else{e=d}}if((f|0)==7){return b|0}return 0}function t5a(a){a=a|0;var b=0,d=0,e=0,f=0;if((a|0)==0){b=0;return b|0}d=c[1510462]|0;if((d|0)==0){b=0;return b|0}else{e=d}while(1){if((c[e+88>>2]|0)!=0){if((irc(a,c[e>>2]|0)|0)==0){b=e;f=6;break}}d=c[e+56>>2]|0;if((d|0)==0){b=0;f=6;break}else{e=d}}if((f|0)==6){return b|0}return 0}function u5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;if((a|0)==0){d=2190208;i=b;return d|0}e=u4(a)|0;if((e|0)!=0){d=c[e+8>>2]|0;i=b;return d|0}KIb(0,24,2187672,(e=i,i=i+8|0,c[e>>2]=a,e)|0);i=e;e=c[1510462]|0;if((a|0)==172){f=4665933}else if((a|0)==175){f=1211250229}else if((a|0)==86079){f=1950507339}else if((a|0)==171){f=1160852272}else if((a|0)==173){f=1464156752}else if((a|0)==86077){f=1330664787}else if((a|0)==65565){f=542135120}else if((a|0)==65564){f=407917392}else{f=a}g=(e|0)==0;do{if(!g){h=e;j=0;a:while(1){do{if((c[h+88>>2]|0)==0){k=j}else{if((c[h+12>>2]|0)!=(f|0)){k=j;break}if((c[h+16>>2]&512|0)!=0&(j|0)==0){k=h}else{l=h;break a}}}while(0);m=c[h+56>>2]|0;if((m|0)==0){l=k;break}else{h=m;j=k}}if((l|0)==0){break}d=c[l>>2]|0;i=b;return d|0}}while(0);if((a|0)==175){n=1211250229}else if((a|0)==65565){n=542135120}else if((a|0)==173){n=1464156752}else if((a|0)==171){n=1160852272}else if((a|0)==86077){n=1330664787}else if((a|0)==172){n=4665933}else if((a|0)==86079){n=1950507339}else if((a|0)==65564){n=407917392}else{n=a}if(g){d=2185136;i=b;return d|0}else{o=e;p=0}b:while(1){if((c[o+80>>2]|0)==0){if((c[o+84>>2]|0)==0){q=p}else{r=32}}else{r=32}do{if((r|0)==32){r=0;if((c[o+12>>2]|0)!=(n|0)){q=p;break}if((c[o+16>>2]&512|0)!=0&(p|0)==0){q=o}else{s=o;break b}}}while(0);e=c[o+56>>2]|0;if((e|0)==0){s=q;break}else{o=e;p=q}}if((s|0)==0){d=2185136;i=b;return d|0}d=c[s>>2]|0;i=b;return d|0}function v5a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=d&255;do{if((f-48|0)>>>0<10>>>0|(f-97|0)>>>0<26>>>0|(f-65|0)>>>0<26>>>0){g=2182888}else{if((f|0)==46|(f|0)==45|(f|0)==32){g=2182888;break}g=(f|0)==95?2182888:2180856}}while(0);h=Rb(a|0,b|0,g|0,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;f=a+h|0;j=h>>>0<b>>>0?b-h|0:0;b=d>>>8&255;do{if((b-48|0)>>>0<10>>>0|(b-97|0)>>>0<26>>>0|(b-65|0)>>>0<26>>>0){k=2182888}else{if((b|0)==46|(b|0)==45|(b|0)==32){k=2182888;break}k=(b|0)==95?2182888:2180856}}while(0);l=Rb(f|0,j|0,k|0,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;b=h+l|0;k=a+b|0;f=j>>>0>l>>>0?j-l|0:0;j=l+h|0;h=d>>>16&255;do{if((h-48|0)>>>0<10>>>0|(h-97|0)>>>0<26>>>0|(h-65|0)>>>0<26>>>0){m=2182888}else{if((h|0)==46|(h|0)==45|(h|0)==32){m=2182888;break}m=(h|0)==95?2182888:2180856}}while(0);l=Rb(k|0,f|0,m|0,(g=i,i=i+8|0,c[g>>2]=h,g)|0)|0;i=g;h=a+(b+l)|0;b=f>>>0>l>>>0?f-l|0:0;f=l+j|0;j=d>>>24;if((j-48|0)>>>0<10>>>0|(j-97|0)>>>0<26>>>0|(j-65|0)>>>0<26>>>0){n=2182888;o=Rb(h|0,b|0,n|0,(g=i,i=i+8|0,c[g>>2]=j,g)|0)|0;i=g;p=o+f|0;i=e;return p|0}if((j|0)==46|(j|0)==45|(j|0)==32){n=2182888;o=Rb(h|0,b|0,n|0,(g=i,i=i+8|0,c[g>>2]=j,g)|0)|0;i=g;p=o+f|0;i=e;return p|0}n=(j|0)==95?2182888:2180856;o=Rb(h|0,b|0,n|0,(g=i,i=i+8|0,c[g>>2]=j,g)|0)|0;i=g;p=o+f|0;i=e;return p|0}function w5a(b,d,f,g){b=b|0;d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+296|0;j=h|0;k=h+8|0;l=h+40|0;if((b|0)==0|(d|0)<1){i=h;return}m=f+8|0;n=ALb(c[m>>2]|0)|0;o=f+48|0;p=u5a(c[o>>2]|0)|0;q=c[f+840>>2]|0;r=f+12|0;a:do{if((q|0)==-99){s=0}else{t=c[r>>2]|0;if((t|0)==0){u=c[o>>2]|0;v=c[1510462]|0;b:do{if((g|0)==0){if((u|0)==65565){w=542135120}else if((u|0)==175){w=1211250229}else if((u|0)==86079){w=1950507339}else if((u|0)==86077){w=1330664787}else if((u|0)==65564){w=407917392}else if((u|0)==173){w=1464156752}else if((u|0)==171){w=1160852272}else if((u|0)==172){w=4665933}else{w=u}if((v|0)==0){s=0;break a}else{x=v;y=0}while(1){do{if((c[x+88>>2]|0)==0){z=y}else{if((c[x+12>>2]|0)!=(w|0)){z=y;break}if((c[x+16>>2]&512|0)!=0&(y|0)==0){z=x}else{A=x;break b}}}while(0);B=c[x+56>>2]|0;if((B|0)==0){A=z;break}else{x=B;y=z}}}else{if((u|0)==172){C=4665933}else if((u|0)==65564){C=407917392}else if((u|0)==175){C=1211250229}else if((u|0)==65565){C=542135120}else if((u|0)==86077){C=1330664787}else if((u|0)==171){C=1160852272}else if((u|0)==86079){C=1950507339}else if((u|0)==173){C=1464156752}else{C=u}if((v|0)==0){s=0;break a}else{D=v;E=0}while(1){if((c[D+80>>2]|0)==0){if((c[D+84>>2]|0)==0){F=E}else{G=17}}else{G=17}do{if((G|0)==17){G=0;if((c[D+12>>2]|0)!=(C|0)){F=E;break}if((c[D+16>>2]&512|0)!=0&(E|0)==0){F=D}else{A=D;break b}}}while(0);B=c[D+56>>2]|0;if((B|0)==0){A=F;break}else{D=B;E=F}}}}while(0);if((A|0)==0){s=0;break}else{H=A}}else{H=t}v=c[H+48>>2]|0;if((v|0)==0){s=0;break}else{I=v}while(1){v=c[I>>2]|0;if((v|0)==-99){s=0;break a}if((v|0)==(q|0)){break}else{I=I+8|0}}s=c[I+4>>2]|0}}while(0);Rb(b|0,d|0,2178536,(I=i,i=i+16|0,c[I>>2]=(n|0)!=0?n:2175680,c[I+8>>2]=p,I)|0)|0;i=I;a[b]=a[b]^32;n=c[r>>2]|0;do{if((n|0)!=0){r=c[n>>2]|0;if((irc(r,p)|0)==0){break}q=lrc(b|0)|0;Rb(b+q|0,d-q|0,2167752,(I=i,i=i+8|0,c[I>>2]=r,I)|0)|0;i=I}}while(0);if((s|0)!=0){p=lrc(b|0)|0;Rb(b+p|0,d-p|0,2167752,(I=i,i=i+8|0,c[I>>2]=s,I)|0)|0;i=I}s=f+52|0;p=c[s>>2]|0;if((p|0)!=0){n=k|0;v5a(n,32,p)|0;p=lrc(b|0)|0;k=c[s>>2]|0;Rb(b+p|0,d-p|0,2163840,(I=i,i=i+16|0,c[I>>2]=n,c[I+8>>2]=k,I)|0)|0;i=I}k=c[m>>2]|0;do{if((k|0)==2){if((MIb()|0)<=47){G=73;break}n=c[f+104>>2]|0;p=c[f+108>>2]|0;s=TIb(n,(n|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;r=s;if((r|0)==0){G=73;break}s=lrc(b|0)|0;Rb(b+s|0,d-s|0,2141080,(I=i,i=i+16|0,c[I>>2]=(n|0)/(r|0)|0,c[I+8>>2]=(p|0)/(r|0)|0,I)|0)|0;i=I;G=73}else if((k|0)==1){r=c[f+412>>2]|0;if((r|0)!=0){p=lrc(b|0)|0;Rb(b+p|0,d-p|0,2136296,(I=i,i=i+8|0,c[I>>2]=r,I)|0)|0;i=I}DFb(b,2134312,d)|0;r=lrc(b|0)|0;p=f+448|0;sGb(b+r|0,d-r|0,c[f+416>>2]|0,c[p>>2]|0,c[p+4>>2]|0);p=c[f+420>>2]|0;if((p|0)==-1){G=73;break}r=lrc(b|0)|0;n=LKb(p)|0;Rb(b+r|0,d-r|0,2161712,(I=i,i=i+8|0,c[I>>2]=n,I)|0)|0;i=I;G=73}else if((k|0)==0){n=f+140|0;r=c[n>>2]|0;do{if(!((r|0)==-1)){p=l|0;mrc(p|0,0,256)|0;a[p]=40;s=lrc(b|0)|0;q=mKb(r)|0;Rb(b+s|0,d-s|0,2161712,(I=i,i=i+8|0,c[I>>2]=q,I)|0)|0;i=I;q=f+796|0;s=c[q>>2]|0;do{if((s|0)!=0){if((s|0)>((e[(qKb(c[n>>2]|0)|0)+8>>1]|0)>>>11&15|0)){break}EFb(p,256,2159712,(I=i,i=i+8|0,c[I>>2]=c[q>>2],I)|0)|0;i=I}}while(0);q=c[f+396>>2]|0;if((q|0)!=0){EFb(p,256,(q|0)==1?2157800:2156096,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}q=THb(c[f+392>>2]|0)|0;if((q|0)!=0){EFb(p,256,2154448,(I=i,i=i+8|0,c[I>>2]=q,I)|0)|0;i=I}q=lrc(p|0)|0;if(!(q>>>0>1>>>0)){break}a[l+(q-2)|0]=0;EFb(b,d,2152576,(I=i,i=i+8|0,c[I>>2]=p,I)|0)|0;i=I}}while(0);n=f+120|0;r=c[n>>2]|0;do{if((r|0)!=0){q=lrc(b|0)|0;s=f+124|0;H=c[s>>2]|0;Rb(b+q|0,d-q|0,2150288,(I=i,i=i+16|0,c[I>>2]=r,c[I+8>>2]=H,I)|0)|0;i=I;H=f+224|0;q=c[H>>2]|0;if((q|0)!=0){A=j|0;F=j+4|0;E=ca(c[n>>2]|0,q)|0;q=f+228|0;D=ca(c[q>>2]|0,c[s>>2]|0)|0;xKb(A,F,E,(E|0)<0|0?-1:0,D,(D|0)<0|0?-1:0,1048576,0)|0;D=lrc(b|0)|0;E=c[q>>2]|0;q=c[A>>2]|0;A=c[F>>2]|0;Rb(b+D|0,d-D|0,2147952,(I=i,i=i+32|0,c[I>>2]=c[H>>2],c[I+8>>2]=E,c[I+16>>2]=q,c[I+24>>2]=A,I)|0)|0;i=I}if((MIb()|0)<=47){break}A=c[f+104>>2]|0;q=c[f+108>>2]|0;E=TIb(A,(A|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;H=E;E=lrc(b|0)|0;Rb(b+E|0,d-E|0,2141080,(I=i,i=i+16|0,c[I>>2]=(A|0)/(H|0)|0,c[I+8>>2]=(q|0)/(H|0)|0,I)|0)|0;i=I}}while(0);if((g|0)==0){break}n=lrc(b|0)|0;r=c[f+504>>2]|0;Rb(b+n|0,d-n|0,2137872,(I=i,i=i+16|0,c[I>>2]=c[f+500>>2],c[I+8>>2]=r,I)|0)|0;i=I;G=73}else if((k|0)==3){r=c[f+120>>2]|0;if((r|0)==0){G=73;break}n=lrc(b|0)|0;H=c[f+124>>2]|0;Rb(b+n|0,d-n|0,2150288,(I=i,i=i+16|0,c[I>>2]=r,c[I+8>>2]=H,I)|0)|0;i=I;G=73}else{i=h;return}}while(0);do{if((G|0)==73){if((g|0)==0){break}k=f+88|0;j=c[k>>2]|0;if((j&512|0)==0){J=j}else{j=lrc(b|0)|0;Rb(b+j|0,d-j|0,2132440,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I;J=c[k>>2]|0}if((J&1024|0)==0){break}k=lrc(b|0)|0;Rb(b+k|0,d-k|0,2130928,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0)|0;i=I}}while(0);c:do{switch(c[m>>2]|0){case 0:case 2:case 3:case 4:{K=c[f+72>>2]|0;G=91;break};case 1:{J=c[o>>2]|0;d:do{switch(J|0){case 69649:{L=2;break};case 69648:{L=3;break};case 69647:case 69633:case 69632:case 69645:case 69638:{L=4;break};default:{if((J|0)==65558|(J|0)==65559){L=64;break d}else if((J|0)==86071|(J|0)==86072|(J|0)==69644|(J|0)==69661|(J|0)==69655|(J|0)==1330333984|(J|0)==69636|(J|0)==69660|(J|0)==69646){L=4;break d}else if((J|0)==65543|(J|0)==65542|(J|0)==65540|(J|0)==65563|(J|0)==65541|(J|0)==65553){L=8;break d}else if((J|0)==65537|(J|0)==1347637264|(J|0)==65536|(J|0)==65554|(J|0)==65539|(J|0)==65538){L=16;break d}else if((J|0)==65552|(J|0)==65549|(J|0)==65548|(J|0)==407917392|(J|0)==65551|(J|0)==65550){L=24;break d}else if((J|0)==65545|(J|0)==65544|(J|0)==542135120|(J|0)==65547|(J|0)==65546|(J|0)==65556|(J|0)==65557){L=32;break d}else{K=c[f+72>>2]|0;G=91;break c}}}}while(0);K=ca(ca(c[f+412>>2]|0,L)|0,c[f+416>>2]|0)|0;G=91;break};default:{}}}while(0);do{if((G|0)==91){if((K|0)==0){break}L=lrc(b|0)|0;Rb(b+L|0,d-L|0,2129488,(I=i,i=i+8|0,c[I>>2]=(K|0)/1e3|0,I)|0)|0;i=I;i=h;return}}while(0);K=c[f+540>>2]|0;if((K|0)<=0){i=h;return}f=lrc(b|0)|0;Rb(b+f|0,d-f|0,2127960,(I=i,i=i+8|0,c[I>>2]=(K|0)/1e3|0,I)|0)|0;i=I;i=h;return}function x5a(){return 3617894}function y5a(){return 2126032}function z5a(a){a=a|0;var b=0;b=c[(c[a+12>>2]|0)+96>>2]|0;if((b|0)!=0){qe[b&1023](a)}b=a+928|0;c[b>>2]=0;c[b+4>>2]=-2147483648;b=a+920|0;c[b>>2]=0;c[b+4>>2]=-2147483648;if((c[a+488>>2]|0)!=0){return}WHb(c[(c[a+64>>2]|0)+20>>2]|0);return}function A5a(a){a=a|0;var b=0;if((a|0)==65537|(a|0)==1347637264|(a|0)==65536|(a|0)==65554|(a|0)==65539|(a|0)==65538){b=16}else if((a|0)==65545|(a|0)==65544|(a|0)==542135120|(a|0)==65547|(a|0)==65546|(a|0)==65556|(a|0)==65557){b=32}else if((a|0)==65552|(a|0)==65549|(a|0)==65548|(a|0)==407917392|(a|0)==65551|(a|0)==65550){b=24}else if((a|0)==65543|(a|0)==65542|(a|0)==65540|(a|0)==65563|(a|0)==65541|(a|0)==65553){b=8}else if((a|0)==86071|(a|0)==86072|(a|0)==69644|(a|0)==69661|(a|0)==69655|(a|0)==1330333984|(a|0)==69636|(a|0)==69660|(a|0)==69646){b=4}else if((a|0)==65558|(a|0)==65559){b=64}else{b=0}return b|0}function B5a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[a+48>>2]|0;e=c[a+412>>2]|0;f=c[a+416>>2]|0;g=c[a+432>>2]|0;h=c[a+52>>2]|0;if((d|0)==86071|(d|0)==86072|(d|0)==69644|(d|0)==69661|(d|0)==69655|(d|0)==1330333984|(d|0)==69636|(d|0)==69660|(d|0)==69646){i=4}else if((d|0)==65545|(d|0)==65544|(d|0)==542135120|(d|0)==65547|(d|0)==65546|(d|0)==65556|(d|0)==65557){i=32}else if((d|0)==65552|(d|0)==65549|(d|0)==65548|(d|0)==407917392|(d|0)==65551|(d|0)==65550){i=24}else if((d|0)==65537|(d|0)==1347637264|(d|0)==65536|(d|0)==65554|(d|0)==65539|(d|0)==65538){i=16}else if((d|0)==65543|(d|0)==65542|(d|0)==65540|(d|0)==65563|(d|0)==65541|(d|0)==65553){i=8}else if((d|0)==65558|(d|0)==65559){i=64}else{i=0}j=(f|0)>0;k=(b|0)>0;a:do{if((i|0)!=0&j&k&(f|0)<32768){l=b;m=ca(i,f)|0;n=Crc(l<<3|0>>>29,((b|0)<0|0?-1:0)<<3|l>>>29,m,(m|0)<0|0?-1:0)|0;o=n}else{n=c[a+792>>2]|0;if((d|0)==86016|(d|0)==86044){o=1152;break}else if((d|0)==86059){o=384;break}else if((d|0)==69632){o=64;break}else if((d|0)==86063){o=512;break}else if((d|0)==69657){o=128;break}else if((d|0)==86047){o=1024;break}else if((d|0)==86019){o=1536;break}else if((d|0)==73728|(d|0)==1936029283|(d|0)==86034|(d|0)==86040|(d|0)==77825){o=160;break}else if((d|0)==69641){o=32;break}else if((d|0)==73729|(d|0)==86046){o=320;break}else{do{if((e|0)>0){if((d|0)==86038){o=(e<<8|0)/245|0;break a}if(!(j&(d|0)==86065)){break}o=(480<<((e|0)/22050|0)|0)/(f|0)|0;break a}}while(0);m=(g|0)>0;do{if(m){if((d|0)==86076){if((g|0)==38){o=160;break a}else if((g|0)!=50){break}o=240;break a}else if((d|0)!=86058){break}if((g|0)==29){o=288;break a}else if((g|0)==19){o=144;break a}else if((g|0)==37){o=480;break a}else if((g|0)==20){o=160;break a}else{break}}}while(0);if(!k){o=0;break}if((d|0)==86037){o=((b|0)/32|0)*240|0;break}else if((d|0)==86069){o=((b|0)/24|0)*240|0;break}else if((d|0)==77824){o=((b|0)/20|0)*160|0;break}else if((d|0)==86050){o=((b|0)/64|0)<<8;break}else{l=(n|0)>0;if(l&(d|0)==69643){o=(b<<3|0)/(n|0)|0;break}if(!j){o=0;break}if((d|0)==81922){o=(b-(f<<1)|0)/(f|0)|0;break}else if((d|0)==65561){o=((b|0)/(f*5|0|0)|0)<<1;break}else if((d|0)==86075|(d|0)==86043){o=(b<<2|0)/(f|0)|0;break}else if((d|0)==1095123744){o=((b|0)/(f*9|0|0)|0)<<4;break}else if((d|0)==69639|(d|0)==69659){o=(b-(f<<2)<<1|0)/(f|0)|0;break}else if((d|0)==69637){o=((b<<1)-8|0)/(f|0)|0;break}else if((d|0)==86025){o=(b*3|0|0)/(f|0)|0;break}else if((d|0)==1146374944){o=((b|0)/(f<<4|0)|0)*28|0;break}else if((d|0)==86026){o=(b*6|0|0)/(f|0)|0;break}else if((d|0)==81921){o=(b-6-f|0)/(f|0)|0;break}else if((d|0)==81920){o=(b-8|0)/(f|0)|0;break}else if((d|0)==69651){o=((b<<1)-16|0)/(f|0)|0;break}else if((d|0)==69640){o=(((b|0)/128|0)*224|0|0)/(f|0)|0;break}else{if((h|0)!=0&(d|0)==81923){if((h|0)==3){o=(b|0)/(f|0)|0;break}else{o=(b<<1|0)/(f|0)|0;break}}do{if(m){p=(b|0)/(g|0)|0;if((d|0)==69633){if((n-2|0)>>>0>3>>>0){o=0;break a}o=ca(((g-(f<<2)|0)/(ca(n,f)|0)|0)<<3|1,p)|0;break a}else if((d|0)==69635){o=ca(((g-(f<<2)<<1|0)/(f|0)|0)+1|0,p)|0;break a}else if((d|0)==1380008992){o=ca((g-(f<<2)<<1|0)/(f|0)|0,p)|0;break a}else if((d|0)==69634){o=ca(((((g<<1)-32|0)/3|0)<<2|0)/(f|0)|0,p)|0;break a}else if((d|0)==69638){o=ca(((g+(f*-7|0)<<1|0)/(f|0)|0)+2|0,p)|0;break a}else{break}}}while(0);if(!l){o=0;break}if((d|0)==65562){o=(((b|0)/((n+4|0)/4|0|0)|0)<<1|0)/(f|0)|0;break}else if((d|0)==65560){if((n|0)<4){o=0;break}o=(b|0)/((ca(n,f+1&-2)|0)/8|0|0)|0;break}else if((d|0)==65555){if((n|0)<4){o=0;break}o=((b|0)/(ca((n<<1|0)/8|0,f)|0)|0)<<1;break}else{o=0;break}}}}}}while(0);return o|0}function C5a(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c&255;if(c>>>0>254>>>0){e=b;f=c;c=1;while(1){g=e+1|0;a[e]=-1;h=f-255|0;i=c+1|0;if(h>>>0>254>>>0){e=g;f=h;c=i}else{break}}j=g;k=h&255;l=i}else{j=b;k=d;l=1}a[j]=k;return l|0}function D5a(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0;if((b|0)>0){f=0}else{g=0;return g|0}while(1){if((e[a+(f<<2)>>1]|0|0)==(c|0)){if((e[a+(f<<2)+2>>1]|0|0)==(d|0)){g=f;h=5;break}}i=f+1|0;if((i|0)<(b|0)){f=i}else{g=i;h=5;break}}if((h|0)==5){return g|0}return 0}function E5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[(c[a+12>>2]|0)+12>>2]|0;d=c[a+140>>2]|0;a=c[1510456]|0;if((a|0)==0){e=0;return e|0}else{f=a}while(1){if((c[f+8>>2]|0)==(b|0)){if((c[f+12>>2]|0)==(d|0)){e=f;g=5;break}}a=c[((f|0)==0?6041824:f+20|0)>>2]|0;if((a|0)==0){e=0;g=5;break}else{f=a}}if((g|0)==5){return e|0}return 0}function F5a(a){a=a|0;var b=0,c=0,d=0,e=0;b=a&255;c=a>>>8&255;d=a>>>16&255;e=a>>>24;return((e-97|0)>>>0<26>>>0?e^32:e)<<24|((b-97|0)>>>0<26>>>0?b^32:b)|((c-97|0)>>>0<26>>>0?c^32:c)<<8|((d-97|0)>>>0<26>>>0?d^32:d)<<16|0}function G5a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;c[a+4>>2]=c[b+4>>2];d=a|0;e=YHb(c[d>>2]|0,c[b>>2]|0)|0;if((e|0)<0){f=e;return f|0}e=c[b+8>>2]|0;if((e|0)==0){f=0;return f|0}b=eGb(e)|0;c[a+8>>2]=b;if((b|0)!=0){f=0;return f|0}WHb(c[d>>2]|0);f=-12;return f|0}function H5a(a,b){a=a|0;b=b|0;WHb(c[b>>2]|0);return}function I5a(a,b){a=a|0;b=b|0;return We[c[a+152>>2]&2047](a,b)|0}function J5a(a,b,d){a=a|0;b=b|0;d=d|0;c[b+4>>2]=a;return M4a(a,c[b>>2]|0,d)|0}function K5a(a){a=a|0;return}function L5a(a,b,c){a=a|0;b=b|0;c=c|0;return}function M5a(a,b,c){a=a|0;b=b|0;c=c|0;return}function N5a(a){a=a|0;return 1}function O5a(a,b){a=a|0;b=b|0;return 0}function P5a(a){a=a|0;return}function Q5a(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return}function R5a(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return}function S5a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[1510462]|0;if((a|0)==86077){d=1330664787}else if((a|0)==171){d=1160852272}else if((a|0)==65565){d=542135120}else if((a|0)==172){d=4665933}else if((a|0)==175){d=1211250229}else if((a|0)==173){d=1464156752}else if((a|0)==86079){d=1950507339}else if((a|0)==65564){d=407917392}else{d=a}e=(b|0)==0;if(e){f=16}else{g=b;h=0;a:while(1){do{if((c[g+88>>2]|0)==0){i=h}else{if((c[g+12>>2]|0)!=(d|0)){i=h;break}if((c[g+16>>2]&512|0)!=0&(h|0)==0){i=g}else{j=g;break a}}}while(0);k=c[g+56>>2]|0;if((k|0)==0){j=i;break}else{g=k;h=i}}if((j|0)==0){f=16}else{l=j}}do{if((f|0)==16){if((a|0)==86079){m=1950507339}else if((a|0)==65565){m=542135120}else if((a|0)==172){m=4665933}else if((a|0)==65564){m=407917392}else if((a|0)==173){m=1464156752}else if((a|0)==175){m=1211250229}else if((a|0)==171){m=1160852272}else if((a|0)==86077){m=1330664787}else{m=a}if(!e){j=b;i=0;b:while(1){if((c[j+80>>2]|0)==0){if((c[j+84>>2]|0)==0){n=i}else{f=28}}else{f=28}do{if((f|0)==28){f=0;if((c[j+12>>2]|0)!=(m|0)){n=i;break}if((c[j+16>>2]&512|0)!=0&(i|0)==0){n=j}else{o=j;break b}}}while(0);h=c[j+56>>2]|0;if((h|0)==0){o=n;break}else{j=h;i=n}}if((o|0)!=0){l=o;break}}if((a|0)==0){p=-1;return p|0}if(a>>>0<65536>>>0){p=0;return p|0}if(a>>>0<94208>>>0){p=1;return p|0}p=a>>>0<98304>>>0?3:-1;return p|0}}while(0);p=c[l+8>>2]|0;return p|0}function T5a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=_Fb(b,e)|0;if((f|0)<0){g=f;i=d;return g|0}c[a+96>>2]=c[e>>2];c[a+100>>2]=c[b+4>>2];g=0;i=d;return g|0}function U5a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;if(b>>>0>e>>>0){KIb(0,0,2593072,(h=i,i=i+24|0,c[h>>2]=2106440,c[h+8>>2]=2355864,c[h+16>>2]=3491,h)|0);i=h;Hd();return 0}if(b>>>0<e>>>0){j=0;k=b}else{l=e;i=g;return l|0}while(1){if((j|0)>=3){break}b=c[f>>2]<<8;h=k+1|0;c[f>>2]=d[k]|b;if((b|0)==256|(h|0)==(e|0)){l=h;m=14;break}else{j=j+1|0;k=h}}if((m|0)==14){i=g;return l|0}a:do{if(k>>>0<e>>>0){m=k;while(1){j=a[m-1|0]|0;h=j&255;do{if((j&255)>>>0>1>>>0){n=m+3|0}else{if((a[m-2|0]|0)==0){b=m+1|0;if((d[m-3|0]|h-1|0)==0){o=b;break a}else{n=b;break}}else{n=m+2|0;break}}}while(0);if(n>>>0<e>>>0){m=n}else{o=n;break}}}else{o=k}}while(0);k=o>>>0>e>>>0?e:o;o=k-4|0;c[f>>2]=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;l=k;i=g;return l|0}function V5a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;e=c[a+476>>2]|0;if((e|0)==0){f=d;mJb(f);i=b;return}re[e&1023](a,a+960|0);f=d;mJb(f);i=b;return}function W5a(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=a;fGb(d);i=b;return}function X5a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;l8(e+4|0,a);f=c[a+100>>2]|0;g=a;if((f|0)<16){KIb(g,16,2514456,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;j=-1094995529;i=b;return j|0}f=a+96|0;k=c[f>>2]|0;l=d[k+2|0]|0;m=d[k+1|0]|0;n=d[k]|0;KIb(g,48,2500680,(h=i,i=i+32|0,c[h>>2]=d[k+3|0]|0,c[h+8>>2]=l,c[h+16>>2]=m,c[h+24>>2]=n,h)|0);i=h;n=(c[f>>2]|0)+4|0;m=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;KIb(g,48,2487992,(h=i,i=i+8|0,c[h>>2]=m,h)|0);i=h;m=c[f>>2]|0;f=m+8|0;n=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[e+1248>>2]=n;f=m+12|0;m=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=e+1252|0;c[f>>2]=m;if((n|0)==4){o=m}else{QIb(g,2477048,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;o=c[f>>2]|0}KIb(g,48,2467672,(h=i,i=i+8|0,c[h>>2]=o,h)|0);i=h;o=c[f>>2]|0;c[e+1264>>2]=(o>>>24)+1;c[e+1268>>2]=o&1;c[e+1272>>2]=o&2048;c[e+1304>>2]=0;o=c[a+52>>2]|0;if((o|0)==1196575829){c[e+1260>>2]=3;c[a+140>>2]=2;j=0;i=b;return j|0}else if((o|0)==1095912533){c[e+1260>>2]=4;c[a+140>>2]=28;j=0;i=b;return j|0}else if((o|0)==843598933){c[e+1260>>2]=3;c[a+140>>2]=4;c[a+392>>2]=1;j=0;i=b;return j|0}else if((o|0)==811158613){c[e+1260>>2]=3;c[a+140>>2]=0;c[a+392>>2]=5;j=0;i=b;return j|0}else if((o|0)==844713045){c[e+1260>>2]=3;c[a+140>>2]=4;c[a+392>>2]=5;j=0;i=b;return j|0}else if((o|0)==810044501){c[e+1260>>2]=3;c[a+140>>2]=0;c[a+392>>2]=1;j=0;i=b;return j|0}else{KIb(g,16,2457768,(h=i,i=i+8|0,c[h>>2]=o,h)|0);i=h;j=-1094995529;i=b;return j|0}return 0}function Y5a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;i=i+40|0;j=h|0;k=h+24|0;l=c[g+24>>2]|0;m=c[g+28>>2]|0;g=c[b+60>>2]|0;n=g;o=k|0;c[o>>2]=e;c[k+4>>2]=0;c[k+8>>2]=0;e=J5a(b,k,0)|0;if((e|0)<0){p=e;i=h;return p|0}if(!((m|0)>-1)){KIb(0,0,2565600,(q=i,i=i+24|0,c[q>>2]=2547568,c[q+8>>2]=2529744,c[q+16>>2]=135,q)|0);i=q;Hd();return 0}e=g+1260|0;k=c[e>>2]|0;r=l+m|0;a:do{if((k|0)>0){s=c[g+1264>>2]|0;t=l;u=0;v=0;b:while(1){c[j+(u<<2)>>2]=t;if((r-t|0)>>>0<((s<<2)+256|0)>>>0){w=7;break}x=t+256|0;if((s|0)>0){y=x;z=0;A=v;B=0;while(1){C=y+4|0;D=y;E=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=E-B|0;if((D|E|0)<0){w=11;break b}if((r-C|0)>>>0<E>>>0){w=11;break b}F=(A|0)>(D|0)?A:D;D=z+1|0;if((D|0)<(s|0)){y=C;z=D;A=F;B=E}else{G=C;H=F;I=E;break}}}else{G=x;H=v;I=0}B=G+I|0;A=u+1|0;if((A|0)<(k|0)){t=B;u=A;v=H}else{J=B;K=H;break a}}if((w|0)==7){KIb(b,16,2444520,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-1094995529;i=h;return p|0}else if((w|0)==11){KIb(b,16,2355616,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-1094995529;i=h;return p|0}}else{J=l;K=0}}while(0);c[j+(k<<2)>>2]=J;if((r-J|0)>>>0<(c[g+1248>>2]|0)>>>0){KIb(b,16,2292976,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-1094995529;i=h;return p|0}r=J;J=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+1256|0;c[r>>2]=J;k=b;KIb(k,48,2241960,(q=i,i=i+8|0,c[q>>2]=J,q)|0);i=q;J=(c[r>>2]|0)>>>8&3;r=g+1276|0;c[r>>2]=J;if((J|0)==2){QIb(k,2200808,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-1163346256;i=h;return p|0}J=g+1284|0;xJb(J,g+1304|0,K+16|0);if((c[J>>2]|0)==0){KIb(k,16,2168944,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=-12;i=h;return p|0}q=c[(c[g>>2]|0)+140>>2]|0;c:do{if((q|0)==0){k=b+120|0;J=b+124|0;K=g+1272|0;l=g+1264|0;w=0;while(1){H=c[o>>2]|0;I=(w|0)!=0|0;G=_5a(n,w,c[H+(w<<2)>>2]|0,1,c[H+32+(w<<2)>>2]|0,c[k>>2]>>I,c[J>>2]>>I,c[j+(w<<2)>>2]|0,(c[r>>2]|0)==1|0)|0;if((G|0)!=0){p=G;break}do{if((c[r>>2]|0)==3){G=c[o>>2]|0;H=c[G+(w<<2)>>2]|0;v=c[G+32+(w<<2)>>2]|0;G=c[k>>2]>>I;u=c[J>>2]>>I;t=c[l>>2]|0;s=I^1;if((c[K>>2]|0)==0){$5a(H,1,v,G,u,t,s);break}else{a6a(H,1,v,G,u,t,s);break}}}while(0);w=w+1|0;if((w|0)>=3){break c}}i=h;return p|0}else if((q|0)==2|(q|0)==28){w=c[e>>2]|0;K=c[o>>2]|0;l=c[K>>2]|0;d:do{if((w|0)>0){J=b+120|0;k=b+124|0;I=g+1272|0;x=g+1264|0;s=0;t=w;u=K;G=l;while(1){v=c[1275832+(s<<2)>>2]|0;H=_5a(n,s,G+v|0,t,c[u+32>>2]|0,c[J>>2]|0,c[k>>2]|0,c[j+(s<<2)>>2]|0,(c[r>>2]|0)==1|0)|0;if((H|0)!=0){p=H;break}do{if((c[r>>2]|0)==3){H=c[o>>2]|0;B=(c[H>>2]|0)+v|0;A=c[e>>2]|0;z=c[H+32>>2]|0;H=c[J>>2]|0;y=c[k>>2]|0;E=c[x>>2]|0;if((c[I>>2]|0)==0){$5a(B,A,z,H,y,E,0);break}else{a6a(B,A,z,H,y,E,0);break}}}while(0);v=s+1|0;E=c[e>>2]|0;y=c[o>>2]|0;H=c[y>>2]|0;if((v|0)<(E|0)){s=v;t=E;u=y;G=H}else{L=E;M=y;N=H;O=k;break d}}i=h;return p|0}else{L=w;M=K;N=l;O=b+124|0}}while(0);l=c[M+32>>2]|0;K=c[O>>2]|0;if((K|0)<=0){break}w=ca(c[b+120>>2]|0,L)|0;k=(w|0)>0;G=0;u=N;while(1){if(k){t=0;do{s=u+t|0;I=a[u+(t+1)|0]|0;x=u+(t+2)|0;J=a[x]|0;a[s]=I+(a[s]|0)&255^-128;a[x]=J+I&255^-128;t=t+L|0;}while((t|0)<(w|0))}t=G+1|0;if((t|0)<(K|0)){G=t;u=u+l|0}else{break}}}else if((q|0)==4){l=b+120|0;u=b+124|0;G=g+1272|0;K=g+1264|0;w=0;while(1){k=c[o>>2]|0;t=(w|0)!=0|0;I=_5a(n,w,c[k+(w<<2)>>2]|0,1,c[k+32+(w<<2)>>2]|0,c[l>>2]>>t,c[u>>2]|0,c[j+(w<<2)>>2]|0,(c[r>>2]|0)==1|0)|0;if((I|0)!=0){p=I;break}do{if((c[r>>2]|0)==3){I=c[o>>2]|0;k=c[I+(w<<2)>>2]|0;J=c[I+32+(w<<2)>>2]|0;I=c[l>>2]>>t;x=c[u>>2]|0;s=c[K>>2]|0;if((c[G>>2]|0)==0){$5a(k,1,J,I,x,s,0);break}else{a6a(k,1,J,I,x,s,0);break}}}while(0);w=w+1|0;if((w|0)>=3){break c}}i=h;return p|0}}while(0);r=c[o>>2]|0;c[r+84>>2]=1;c[r+88>>2]=1;c[r+296>>2]=(c[g+1272>>2]|0)!=0;c[f>>2]=1;p=m;i=h;return p|0}function Z5a(a){a=a|0;mJb((c[a+60>>2]|0)+1284|0);return 0}function _5a(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;o=i;i=i+3608|0;p=o|0;q=o+2048|0;r=o+3072|0;s=o+3328|0;t=o+3584|0;if((f|0)==0){u=~((c[(c[e>>2]|0)+140>>2]|0)==0)}else{u=-1}f=p|0;v=q;w=r|0;x=s|0;y=m;z=0;while(1){a[p+(z<<3)|0]=z;a[p+(z<<3)+1|0]=a[y]|0;A=z+1|0;if((A|0)<256){y=y+1|0;z=A}else{break}}cd(f|0,256,8,1028);z=a[p+1|0]|0;do{if(z<<24>>24==0){B=1;C=d[f]|0}else{if((z&255)>>>0>32>>>0){B=0;C=-1;break}else{D=255}while(1){E=a[p+(D<<3)+1|0]|0;if(E<<24>>24!=-1|(D|0)==0){break}else{D=D-1|0}}y=E&255;do{if((D|0)>-1){c[q+(D<<2)>>2]=1>>>((32-y|0)>>>0);a[r+D|0]=E;a[s+D|0]=a[p+(D<<3)|0]|0;if((D|0)>0){F=1;G=y;H=D}else{break}do{H=H-1|0;F=(-2147483648>>>((G-1|0)>>>0))+F|0;A=a[p+(H<<3)+1|0]|0;G=A&255;c[q+(H<<2)>>2]=F>>>((32-G|0)>>>0);a[r+H|0]=A;a[s+H|0]=a[p+(H<<3)|0]|0;}while((H|0)>0)}}while(0);B=($2(t,(E&255)>>>0>10>>>0?10:y,D+1|0,w,1,1,v,4,4,x,1,1,0)|0)==0;C=-1}}while(0);if(!B){KIb(c[e>>2]|0,16,2142144,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-1094995529;i=o;return J|0}B=e+1264|0;x=c[B>>2]|0;v=(x|0)>0;if((C|0)>-1){if(!v){J=0;i=o;return J|0}w=ca(k,h)|0;D=(n|0)==0;E=C&255;H=0;p=0;s=x;while(1){r=H+1|0;G=((ca(r,l)|0)/(s|0)|0)&u;F=g+(ca(p,j)|0)|0;if((p|0)>=(G|0)|(w|0)<1){K=s}else{if(D){q=p;z=F;while(1){f=0;do{a[z+f|0]=E;f=f+h|0;}while((f|0)<(w|0));f=q+1|0;if((f|0)<(G|0)){q=f;z=z+j|0}else{break}}}else{z=128;q=p;y=F;while(1){f=z;A=0;do{f=f+C|0;a[y+A|0]=f;A=A+h|0;}while((A|0)<(w|0));A=q+1|0;if((A|0)<(G|0)){z=f;q=A;y=y+j|0}else{break}}}K=c[B>>2]|0}if((r|0)<(K|0)){H=r;p=G;s=K}else{J=0;break}}i=o;return J|0}a:do{if(v){K=e+1284|0;s=e+1100|0;p=e|0;H=ca(k,h)|0;w=(H|0)>0;C=t+4|0;E=t|0;D=(n|0)==0;y=0;q=0;z=x;b:while(1){F=y+1|0;A=((ca(F,l)|0)/(z|0)|0)&u;L=g+(ca(q,j)|0)|0;M=y<<2;if((y|0)==0){N=0}else{O=m+(M+252)|0;N=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0}O=m+(M+256)|0;M=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=M-N|0;if((M|0)==(N|0)){P=33;break}nrc(c[K>>2]|0,m+(N+256+(z<<2))|0,O)|0;mrc((c[K>>2]|0)+O|0,0,16)|0;M=c[K>>2]|0;ef[c[s>>2]&4095](M,M,O+3>>2);M=c[K>>2]|0;Q=O<<3;O=Q>>>0>2147483639>>>0|(M|0)==0;R=O?0:M;M=O?0:Q;Q=M+8|0;if((q|0)<(A|0)){O=0;S=128;T=q;U=L;while(1){if(w){L=O;V=S;W=0;while(1){if((M-L|0)<1){P=37;break b}X=c[C>>2]|0;Y=c[E>>2]|0;Z=R+(L>>>3)|0;_=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(L&7)>>>((32-Y|0)>>>0);Z=b[X+(_<<2)>>1]|0;$=b[X+(_<<2)+2>>1]|0;_=$<<16>>16;do{if($<<16>>16<0){aa=Y+L|0;ba=Q>>>0>aa>>>0?aa:Q;aa=R+(ba>>>3)|0;da=((je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ba&7)>>>((_+32|0)>>>0))+Z|0;aa=b[X+(da<<2)>>1]|0;ea=b[X+(da<<2)+2>>1]|0;da=ea<<16>>16;if(!(ea<<16>>16<0)){fa=da;ga=aa;ha=ba;break}ea=ba-_|0;ba=Q>>>0>ea>>>0?ea:Q;ea=R+(ba>>>3)|0;ia=((je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ba&7)>>>((da+32|0)>>>0))+aa|0;fa=b[X+(ia<<2)+2>>1]|0;ga=b[X+(ia<<2)>>1]|0;ha=ba}else{fa=_;ga=Z;ha=L}}while(0);Z=fa+ha|0;_=Q>>>0>Z>>>0?Z:Q;if((ga|0)<0){P=42;break b}if(D){ja=V;ka=ga&255}else{Z=ga+V|0;ja=Z;ka=Z&255}a[U+W|0]=ka;Z=W+h|0;if((Z|0)<(H|0)){L=_;V=ja;W=Z}else{la=_;ma=ja;break}}}else{la=O;ma=S}W=T+1|0;if((W|0)<(A|0)){O=la;S=ma;T=W;U=U+j|0}else{na=la;break}}}else{na=0}U=M-na|0;if((U|0)>32){KIb(c[p>>2]|0,24,2586584,(I=i,i=i+8|0,c[I>>2]=U,I)|0);i=I}U=c[B>>2]|0;if((F|0)<(U|0)){y=F;q=A;z=U}else{break a}}if((P|0)==33){KIb(c[p>>2]|0,16,2118616,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}else if((P|0)==37){KIb(c[p>>2]|0,16,2636744,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}else if((P|0)==42){KIb(c[p>>2]|0,16,2613280,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}c3(t);J=-1094995529;i=o;return J|0}}while(0);c3(t);J=0;i=o;return J|0}function $5a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=~i;if((h|0)<=0){return}i=ca(f,c)|0;f=(i|0)>(c|0);k=0;do{l=((ca(k,g)|0)/(h|0)|0)&j;k=k+1|0;m=(((ca(k,g)|0)/(h|0)|0)&j)-l|0;n=ca(l,e)|0;l=b+n|0;o=a[l]^-128;a[l]=o;if(f){p=o;o=c;do{q=b+(o+n)|0;p=(a[q]|0)+p&255;a[q]=p;o=o+c|0;}while((o|0)<(i|0))}o=n+e|0;p=b+o|0;do{if((m|0)!=1){q=a[l]|0;r=q&255;s=(a[p]|0)+q&255;a[p]=s;q=s&255;if(f){t=s;s=r;u=c;v=q;while(1){w=a[b+(u+n)|0]|0;x=w&255;y=v-s+x&255;do{if((t&255)>>>0>(w&255)>>>0){if(!(y>>>0>x>>>0)){z=x;break}z=y>>>0>v>>>0?v:y}else{if(!(x>>>0>y>>>0)){z=x;break}z=y>>>0>v>>>0?y:v}}while(0);y=b+(u+o)|0;w=(d[y]|0)+z|0;A=w&255;a[y]=A;y=u+c|0;B=w&255;if((y|0)<(i|0)){t=A;s=x;u=y;v=B}else{C=x;D=B;break}}}else{C=r;D=q}if((m|0)<=2){break}v=(i|0)>0;u=D;s=C;t=b+(o+e)|0;B=2;while(1){if(v){y=u;A=s;w=0;while(1){E=d[t+(w-e)|0]|0;F=y-A+E&255;do{if((y|0)>(E|0)){if(!(F>>>0>E>>>0)){G=E;break}G=(F|0)>(y|0)?y:F}else{if(!(E>>>0>F>>>0)){G=E;break}G=(F|0)>(y|0)?F:y}}while(0);F=t+w|0;H=(d[F]|0)+G|0;a[F]=H;F=H&255;H=w+c|0;if((H|0)<(i|0)){y=F;A=E;w=H}else{I=F;J=E;break}}}else{I=u;J=s}w=B+1|0;if((w|0)<(m|0)){u=I;s=J;t=t+e|0;B=w}else{break}}}}while(0);}while((k|0)<(h|0));return}function a6a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=(i|0)!=0?-4:-2;i=e<<1;if((h|0)<=0){return}k=ca(f,c)|0;f=(k|0)>(c|0);l=0;do{m=((ca(l,g)|0)/(h|0)|0)&j;l=l+1|0;n=(((ca(l,g)|0)/(h|0)|0)&j)-m|0;o=n>>1;p=ca(m,e)|0;m=b+p|0;q=a[m]^-128;a[m]=q;if(f){r=q;s=c;while(1){t=b+(s+p)|0;u=(a[t]|0)+r&255;a[t]=u;t=s+c|0;if((t|0)<(k|0)){r=u;s=t}else{v=u;break}}}else{v=q}s=(k|0)>0;if(s){r=p+e|0;u=v;t=0;do{w=b+(r+t)|0;u=(a[w]|0)+u&255;a[w]=u;t=t+c|0;}while((t|0)<(k|0))}t=p+i|0;u=b+t|0;do{if((o|0)!=1){r=a[m]|0;q=r&255;w=(a[u]|0)+r&255;a[u]=w;r=w&255;if(f){x=w;w=q;y=c;z=r;while(1){A=a[b+(y+p)|0]|0;B=A&255;C=z-w+B&255;do{if((x&255)>>>0>(A&255)>>>0){if(!(C>>>0>B>>>0)){D=B;break}D=C>>>0>z>>>0?z:C}else{if(!(B>>>0>C>>>0)){D=B;break}D=C>>>0>z>>>0?C:z}}while(0);C=b+(y+t)|0;A=(d[C]|0)+D|0;E=A&255;a[C]=E;C=y+c|0;F=A&255;if((C|0)<(k|0)){x=E;w=B;y=C;z=F}else{G=B;H=F;break}}}else{G=q;H=r}if(s){z=t-e|0;y=t+e|0;w=H;x=G;F=0;while(1){C=d[b+(z+F)|0]|0;E=w-x+C&255;do{if(w>>>0>C>>>0){if(!(E>>>0>C>>>0)){I=C;break}I=E>>>0>w>>>0?w:E}else{if(!(C>>>0>E>>>0)){I=C;break}I=E>>>0>w>>>0?E:w}}while(0);E=b+(y+F)|0;B=(d[E]|0)+I|0;a[E]=B;E=B&255;B=F+c|0;if((B|0)<(k|0)){w=E;x=C;F=B}else{J=E;K=C;break}}}else{J=H;K=G}if((n|0)<=4){break}F=J;x=K;w=b+(t+i)|0;y=2;while(1){do{if(s){z=F;r=x;q=0;while(1){L=d[w+(q-i)|0]|0;E=z-r+L&255;do{if((z|0)>(L|0)){if(!(E>>>0>L>>>0)){M=L;break}M=(E|0)>(z|0)?z:E}else{if(!(L>>>0>E>>>0)){M=L;break}M=(E|0)>(z|0)?E:z}}while(0);E=w+q|0;B=(d[E]|0)+M|0;a[E]=B;N=B&255;B=q+c|0;if((B|0)<(k|0)){z=N;r=L;q=B}else{break}}if(s){O=N;P=L;Q=0}else{R=N;S=L;break}while(1){q=d[w+(Q-e)|0]|0;r=O-P+q&255;do{if(O>>>0>q>>>0){if(!(r>>>0>q>>>0)){T=q;break}T=r>>>0>O>>>0?O:r}else{if(!(q>>>0>r>>>0)){T=q;break}T=r>>>0>O>>>0?r:O}}while(0);r=w+(Q+e)|0;z=(d[r]|0)+T|0;a[r]=z;r=z&255;z=Q+c|0;if((z|0)<(k|0)){O=r;P=q;Q=z}else{R=r;S=q;break}}}else{R=F;S=x}}while(0);C=y+1|0;if((C|0)<(o|0)){F=R;x=S;w=w+i|0;y=C}else{break}}}}while(0);}while((l|0)<(h|0));return}function b6a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=b+60|0;g=c[f>>2]|0;c[g>>2]=b;h=g+1248|0;c[h>>2]=4;j=b+120|0;k=g+1280|0;c[k>>2]=(c[j>>2]|0)+31&-32;l=b+140|0;m=c[l>>2]|0;a:do{if((m|0)==2){c[g+1260>>2]=3;c[b+52>>2]=1196575829;n=402718720}else if((m|0)==4){if((c[j>>2]&1|0)==0){c[g+1260>>2]=3;c[b+52>>2]=(c[b+392>>2]|0)==1?843598933:844713045;n=844715353;break}KIb(b,16,2636704,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=e;return p|0}else if((m|0)==0){do{if((c[j>>2]&1|0)==0){if((c[b+124>>2]&1|0)!=0){break}c[g+1260>>2]=3;c[b+52>>2]=(c[b+392>>2]|0)==1?810044501:811158613;n=842094169;break a}}while(0);KIb(b,16,2118560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=e;return p|0}else if((m|0)==28){c[g+1260>>2]=4;c[b+52>>2]=1095912533;n=402784256}else{KIb(b,16,2292936,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;p=-1094995529;i=e;return p|0}}while(0);l8(g+4|0,b);m=c[b+216>>2]|0;if(m>>>0>4>>>0){KIb(b,24,2613224,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;p=-1414549496;i=e;return p|0}if((m|0)==1){KIb(b,16,2586536,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1414549496;i=e;return p|0}j=c[1275848+(m<<2)>>2]|0;c[g+1276>>2]=j;if((j|0)==2){KIb(b,16,2565560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1414549496;i=e;return p|0}j=b+404|0;m=c[j>>2]|0;if(m>>>0>256>>>0){KIb(b,16,2547488,(o=i,i=i+8|0,c[o>>2]=m,o)|0);i=o;p=-22;i=e;return p|0}m=b+124|0;q=c[m>>2]|0;r=q>>(d[(qKb(c[l>>2]|0)|0)+6|0]|0);l=c[j>>2]|0;if((l|0)>(r|0)){KIb(b,16,2529672,(o=i,i=i+16|0,c[o>>2]=l,c[o+8>>2]=r,o)|0);i=o;p=-22;i=e;return p|0}l=UHb()|0;q=b+804|0;c[q>>2]=l;if((l|0)==0){KIb(b,16,2514424,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;l=c[f>>2]|0;mJb(q);mJb(l+1284|0);mJb(l+1288|0);mJb(l+1292|0);mJb(l+1296|0);mJb(l+1300|0);p=-12;i=e;return p|0}c[b+100>>2]=16;l=pJb(32)|0;s=b+96|0;c[s>>2]=l;if((l|0)==0){KIb(b,16,2500648,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;l=c[f>>2]|0;mJb(q);mJb(l+1284|0);mJb(l+1288|0);mJb(l+1292|0);mJb(l+1296|0);mJb(l+1300|0);p=-12;i=e;return p|0}l=g+1260|0;t=g+1288|0;u=0;while(1){if((u|0)>=(c[l>>2]|0)){break}v=hJb((ca((c[m>>2]|0)+2|0,c[k>>2]|0)|0)+16|0)|0;c[t+(u<<2)>>2]=v;if((v|0)==0){w=29;break}else{u=u+1|0}}if((w|0)==29){KIb(b,16,2487952,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;o=c[f>>2]|0;mJb(q);mJb(o+1284|0);mJb(o+1288|0);mJb(o+1292|0);mJb(o+1296|0);mJb(o+1300|0);p=-12;i=e;return p|0}o=c[s>>2]|0;y=16777456;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=(c[s>>2]|0)+4|0;y=n;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=(c[s>>2]|0)+8|0;y=c[h>>2]|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=c[j>>2]|0;do{if((o|0)==0){j=(r|0)/120|0;h=g+1264|0;c[h>>2]=j;if(!((r+119|0)>>>0>238>>>0)){c[h>>2]=1;x=1;break}if((r|0)<=30839){x=j;break}c[h>>2]=256;x=256}else{c[g+1264>>2]=o;x=o}}while(0);c[g+1268>>2]=1;o=(x<<24)-16777216|1;c[g+1252>>2]=o;g=(c[s>>2]|0)+12|0;y=o;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;p=0;i=e;return p|0}function c6a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+16|0;j=h|0;k=c[b+60>>2]|0;l=c[b+120>>2]|0;m=c[b+124>>2]|0;n=ca(m,l)|0;o=k+1260|0;p=(ca(n+256+(c[k+1264>>2]<<2)|0,c[o>>2]|0)|0)+4|0;q=d5a(b,e,p,(p|0)<0|0?-1:0)|0;if((q|0)<0){r=q;i=h;return r|0}q=c[e+24>>2]|0;p=e+28|0;s=c[p>>2]|0;if(!((s|0)>-1)){KIb(0,0,2200744,(t=i,i=i+24|0,c[t>>2]=2168896,c[t+8>>2]=2142048,c[t+16>>2]=145,t)|0);i=t;Hd();return 0}u=j|0;c[u>>2]=q;v=j+8|0;c[v>>2]=q;w=j+4|0;c[w>>2]=q+s;s=j+12|0;c[s>>2]=0;q=k+1284|0;A4a(q,k+1304|0,n+4|0);if((c[q>>2]|0)==0){KIb(b,16,2444424,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;r=-12;i=h;return r|0}q=b+140|0;n=c[q>>2]|0;if((n|0)==28|(n|0)==2){x=k+1288|0;z=c[k+1280>>2]|0;A=c[f>>2]|0;B=c[o>>2]|0;C=c[f+32>>2]|0;D=z<<1;if((m|0)>0){E=z-l|0;z=ca(B,l)|0;F=(z|0)>0;G=k+1292|0;H=k+1296|0;I=k+1300|0;if((B|0)==3){J=A;K=0;L=D;while(1){if(F){M=0;N=L;while(1){O=a[J+(M+1)|0]|0;a[(c[x>>2]|0)+N|0]=O;P=(O&255)+128|0;a[(c[G>>2]|0)+N|0]=(d[J+(M+2)|0]|0)-P;a[(c[H>>2]|0)+N|0]=(d[J+M|0]|0)-P;P=N+1|0;O=M+3|0;if((O|0)<(z|0)){M=O;N=P}else{Q=P;break}}}else{Q=L}N=K+1|0;if((N|0)<(m|0)){J=J+C|0;K=N;L=Q+E|0}else{break}}}else{Q=A;A=0;L=D;while(1){if(F){D=0;K=L;while(1){J=a[Q+(D+1)|0]|0;a[(c[x>>2]|0)+K|0]=J;N=(J&255)+128|0;a[(c[G>>2]|0)+K|0]=(d[Q+(D+2)|0]|0)-N;a[(c[H>>2]|0)+K|0]=(d[Q+D|0]|0)-N;a[(c[I>>2]|0)+K|0]=a[Q+(D+3)|0]|0;N=K+1|0;J=D+B|0;if((J|0)<(z|0)){D=J;K=N}else{R=N;break}}}else{R=L}K=A+1|0;if((K|0)<(m|0)){Q=Q+C|0;A=K;L=R+E|0}else{break}}}}S=c[q>>2]|0}else{S=n}a:do{if((S|0)==0){n=k+1288|0;q=0;while(1){if((q|0)>=(c[o>>2]|0)){break a}E=(q|0)!=0|0;T=e6a(b,c[f+(q<<2)>>2]|0,c[n>>2]|0,c[f+32+(q<<2)>>2]|0,l>>E,m>>E,j)|0;if((T|0)!=0){break}q=q+1|0}KIb(b,16,2355560,(t=i,i=i+8|0,c[t>>2]=q,t)|0);i=t;r=T;i=h;return r|0}else if((S|0)==4){n=k+1288|0;E=0;while(1){if((E|0)>=(c[o>>2]|0)){break a}U=e6a(b,c[f+(E<<2)>>2]|0,c[n>>2]|0,c[f+32+(E<<2)>>2]|0,l>>((E|0)!=0),m,j)|0;if((U|0)!=0){break}E=E+1|0}KIb(b,16,2355560,(t=i,i=i+8|0,c[t>>2]=E,t)|0);i=t;r=U;i=h;return r|0}else if((S|0)==2|(S|0)==28){n=k+1288|0;q=k+1280|0;R=0;while(1){if((R|0)>=(c[o>>2]|0)){break a}L=c[n+(R<<2)>>2]|0;A=c[q>>2]|0;V=e6a(b,L+(A<<1)|0,L,A,l,m,j)|0;if((V|0)!=0){break}R=R+1|0}KIb(b,16,2355560,(t=i,i=i+8|0,c[t>>2]=R,t)|0);i=t;r=V;i=h;return r|0}else{KIb(b,16,2292936,(t=i,i=i+8|0,c[t>>2]=S,t)|0);i=t;r=-1094995529;i=h;return r|0}}while(0);t=c[k+1276>>2]<<8;do{if((c[s>>2]|0)==0){k=c[u>>2]|0;if(((c[w>>2]|0)-k|0)<=3){W=k;X=37;break}S=k;y=t;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;S=(c[u>>2]|0)+4|0;c[u>>2]=S;Y=S}else{W=c[u>>2]|0;X=37}}while(0);if((X|0)==37){c[s>>2]=1;Y=W}W=c[b+804>>2]|0;c[W+84>>2]=1;c[W+88>>2]=1;c[p>>2]=Y-(c[v>>2]|0);v=e+36|0;c[v>>2]=c[v>>2]|1;c[g>>2]=1;r=0;i=h;return r|0}function d6a(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(a+804|0);mJb(b+1284|0);mJb(b+1288|0);mJb(b+1292|0);mJb(b+1296|0);mJb(b+1300|0);return 0}function e6a(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;l=i;i=i+4368|0;m=l|0;n=l+8|0;o=l+16|0;p=l+272|0;q=l+2320|0;r=c[b+60>>2]|0;mrc(p|0,0,2048)|0;s=c[r+1276>>2]|0;do{if((s|0)==3){t=r+1264|0;u=c[t>>2]|0;if((u|0)<=0){break}v=(h|0)>0;w=r+1084|0;x=0;z=0;A=u;while(1){u=x+1|0;B=(ca(u,j)|0)/(A|0)|0;C=ca(z,g)|0;D=e+C|0;E=ca(z,h)|0;F=f+E|0;H=B-z|0;if(v){I=F;J=0;K=-128;while(1){L=e+(J+C)|0;a[I]=(a[L]|0)-K;M=J+1|0;if((M|0)<(h|0)){I=I+1|0;J=M;K=a[L]|0}else{break}}N=f+(E+h)|0}else{N=F}do{if((H|0)!=1){c[n>>2]=0;c[m>>2]=0;if((H|0)>1){O=N;P=1;Q=D}else{break}while(1){K=Q+g|0;_e[c[w>>2]&511](O,Q,K,h,m,n);J=P+1|0;if((J|0)<(H|0)){O=O+h|0;P=J;Q=K}else{break}}}}while(0);H=c[t>>2]|0;if((u|0)<(H|0)){x=u;z=B;A=H}else{break}}}else if((s|0)==0){A=r+1264|0;z=c[A>>2]|0;if((z|0)>0){R=0;S=0;T=z}else{break}while(1){z=R+1|0;x=(ca(z,j)|0)/(T|0)|0;uIb(f+(ca(S,h)|0)|0,h,e+(ca(S,g)|0)|0,g,h,x-S|0);t=c[A>>2]|0;if((z|0)<(t|0)){R=z;S=x;T=t}else{break}}}else if((s|0)==1){A=r+1264|0;t=c[A>>2]|0;if((t|0)<=0){break}x=(h|0)>0;z=0;w=0;v=t;while(1){t=z+1|0;H=(ca(t,j)|0)/(v|0)|0;D=H-w|0;if((D|0)>0&x){F=f+(ca(w,h)|0)|0;E=e+(ca(w,g)|0)|0;K=0;J=-128;while(1){I=F;C=0;L=J;while(1){M=E+C|0;a[I]=(a[M]|0)-L;U=a[M]|0;M=C+1|0;if((M|0)<(h|0)){I=I+1|0;C=M;L=U}else{break}}L=K+1|0;if((L|0)<(D|0)){F=F+h|0;E=E+g|0;K=L;J=U}else{break}}V=c[A>>2]|0}else{V=v}if((t|0)<(V|0)){z=t;w=H;v=V}else{break}}}else{KIb(b,16,2241896,(v=i,i=i+8|0,c[v>>2]=s,v)|0);i=v;W=-1414549496;i=l;return W|0}}while(0);s=p|0;b=(h|0)>0;if((j|0)>0&b){V=f;U=0;while(1){g=0;do{e=p+((d[V+g|0]|0)<<3)|0;T=wrc(c[e>>2]|0,c[e+4>>2]|0,1,0)|0;c[e>>2]=T;c[e+4>>2]=G;g=g+1|0;}while((g|0)<(h|0));g=U+1|0;if((g|0)<(j|0)){V=V+h|0;U=g}else{X=0;break}}}else{X=0}while(1){if((X|0)>=256){break}U=p+(X<<3)|0;Y=c[U>>2]|0;Z=c[U+4>>2]|0;if((Y|0)==0&(Z|0)==0){X=X+1|0}else{_=29;break}}do{if((_|0)==29){p=Erc(j,(j|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;if(!((Y|0)==(p|0)&(Z|0)==(G|0))){break}p=k+12|0;U=k+4|0;V=k|0;g=0;do{e=(c[p>>2]|0)==0;a:do{if((g|0)==(X|0)){do{if(e){T=c[V>>2]|0;if(((c[U>>2]|0)-T|0)<=0){break}a[T]=0;c[V>>2]=(c[V>>2]|0)+1;break a}}while(0);c[p>>2]=1}else{do{if(e){T=c[V>>2]|0;if(((c[U>>2]|0)-T|0)<=0){break}a[T]=-1;c[V>>2]=(c[V>>2]|0)+1;break a}}while(0);c[p>>2]=1}}while(0);g=g+1|0;}while((g|0)<256);g=r+1264|0;if((c[g>>2]|0)>0){$=1}else{W=0;i=l;return W|0}while(1){do{if((c[p>>2]|0)==0){e=c[V>>2]|0;if(((c[U>>2]|0)-e|0)<=3){_=45;break}H=e;y=0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[V>>2]=(c[V>>2]|0)+4}else{_=45}}while(0);if((_|0)==45){_=0;c[p>>2]=1}if(($|0)>=(c[g>>2]|0)){W=0;break}$=$+1|0}i=l;return W|0}}while(0);$=PKa(o|0,s,256)|0;if(($|0)<0){W=$;i=l;return W|0}$=k+12|0;s=k+4|0;X=k|0;Z=0;do{Y=o+Z|0;g=a[Y]|0;do{if((c[$>>2]|0)==0){p=c[X>>2]|0;if(((c[s>>2]|0)-p|0)<=0){_=53;break}a[p]=g;c[X>>2]=(c[X>>2]|0)+1;aa=a[Y]|0}else{_=53}}while(0);if((_|0)==53){_=0;c[$>>2]=1;aa=g}a[q+(Z<<3)+1|0]=aa;a[q+(Z<<3)|0]=Z;Z=Z+1|0;}while((Z|0)<256);Z=q|0;cd(Z|0,256,8,1028);aa=255;while(1){ba=a[q+(aa<<3)+1|0]|0;if(ba<<24>>24!=-1|(aa|0)==0){break}else{aa=aa-1|0}}do{if((aa|0)>-1){o=ba&255;c[q+(aa<<3)+4>>2]=1>>>((32-o|0)>>>0);if((aa|0)>0){da=1;ea=o;fa=aa}else{break}do{fa=fa-1|0;da=(-2147483648>>>((ea-1|0)>>>0))+da|0;ea=d[q+(fa<<3)+1|0]|0;c[q+(fa<<3)+4>>2]=da>>>((32-ea|0)>>>0);}while((fa|0)>0)}}while(0);cd(Z|0,256,8,278);Z=r+1264|0;fa=c[Z>>2]|0;if((fa|0)>0){ea=r+1284|0;da=((ca(j,h)|0)+4|0)<0;aa=r+1100|0;r=k+8|0;ba=0;g=0;o=0;Y=fa;while(1){fa=g+1|0;p=(ca(fa,j)|0)/(Y|0)|0;V=p-o|0;U=da?0:c[ea>>2]|0;if((V|0)>0){H=U;e=32;t=f+(ca(o,h)|0)|0;T=0;S=0;while(1){if(b){R=H;Q=e;P=0;O=S;while(1){n=d[t+P|0]|0;m=d[q+(n<<3)+1|0]|0;N=c[q+(n<<3)+4>>2]|0;if((Q|0)>(m|0)){ga=Q;ha=O<<m|N;ia=R}else{n=R;y=je(N>>>((m-Q|0)>>>0)|O<<Q|0)|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;ga=Q+32|0;ha=N;ia=R+4|0}N=ga-m|0;m=P+1|0;if((m|0)<(h|0)){R=ia;Q=N;P=m;O=ha}else{ja=ia;ka=N;la=ha;break}}}else{ja=H;ka=e;la=S}O=T+1|0;if((O|0)<(V|0)){H=ja;e=ka;t=t+h|0;T=O;S=la}else{ma=ja;na=ka;oa=la;break}}}else{ma=U;na=32;oa=0}S=U;T=32-na+(ma-S<<3)&31;do{if((T|0)==0){pa=na;qa=ma;ra=oa}else{t=32-T|0;if((na|0)>(t|0)){pa=na-t|0;qa=ma;ra=oa<<t;break}else{t=ma;y=je(oa<<na|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;pa=T+na|0;qa=ma+4|0;ra=0;break}}}while(0);T=32-pa+(qa-S<<3)|0;if((pa|0)<32){U=ra<<pa;t=U>>>24&255;e=pa;H=qa;V=U;while(1){a[H]=t;U=e+8|0;if((U|0)<32){t=V>>>16&255;e=U;H=H+1|0;V=V<<8}else{break}}}V=T>>3;H=V+ba|0;e=c[ea>>2]|0;ef[c[aa>>2]&4095](e,e,V>>>2);do{if((c[$>>2]|0)==0){e=c[X>>2]|0;if(((c[s>>2]|0)-e|0)<=3){sa=e;_=82;break}t=e;y=H;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[X>>2]|0)+4|0;c[X>>2]=t;ta=t}else{sa=c[X>>2]|0;_=82}}while(0);if((_|0)==82){_=0;c[$>>2]=1;ta=sa}T=ba-4+((c[Z>>2]|0)-g<<2)|0;c[$>>2]=0;t=c[s>>2]|0;e=t;S=ta;U=e-S|0;O=(U|0)<(T|0);if(O){c[$>>2]=1;ua=1}else{ua=0}P=(c[r>>2]|0)-S|0;if((P|0)>(T|0)){va=P}else{va=O?U:T}T=ta+va|0;c[X>>2]=T;U=c[ea>>2]|0;if((ua|0)==0){O=e-T|0;e=O>>>0>V>>>0?V:O;if((e|0)!=(V|0)){c[$>>2]=1}nrc(T|0,U|0,e)|0;U=(c[X>>2]|0)+e|0;c[X>>2]=U;wa=c[s>>2]|0;xa=U}else{wa=t;xa=T}T=4-H+(g-(c[Z>>2]|0)<<2)|0;t=xa;U=wa-t|0;e=(U|0)<(T|0);if(e){ya=1}else{ya=0}c[$>>2]=ya;O=(c[r>>2]|0)-t|0;if((O|0)>(T|0)){za=O}else{za=e?U:T}T=xa+za|0;c[X>>2]=T;U=c[Z>>2]|0;if((fa|0)<(U|0)){ba=H;g=fa;o=p;Y=U}else{Aa=H;Ba=wa;Ca=T;break}}}else{Aa=0;Ba=c[s>>2]|0;Ca=c[X>>2]|0}s=Ca;wa=Ba-s|0;Ba=(wa|0)<(Aa|0);if(Ba){Da=1}else{Da=0}c[$>>2]=Da;Da=(c[k+8>>2]|0)-s|0;if((Da|0)>(Aa|0)){Ea=Da}else{Ea=Ba?wa:Aa}c[X>>2]=Ca+Ea;W=0;i=l;return W|0}function f6a(a,b){a=a|0;b=b|0;return(d[a]|0)-(d[b]|0)|0}function g6a(a){a=a|0;var b=0,d=0,e=0;b=i;if((c[a+120>>2]&1|0)==0){d=c[a+60>>2]|0;c[a+140>>2]=74;c[a+796>>2]=10;c[d+16>>2]=124;e=0;i=b;return e|0}else{KIb(a,16,2292848,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1094995529;i=b;return e|0}return 0}function h6a(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=i;h=c[a+60>>2]|0;j=d;k=c[f+24>>2]|0;l=c[h+4>>2]|0;if((l|0)==0){m=(c[a+120>>2]|0)+47|0;n=(m-((m|0)%48|0)<<3|0)/3|0}else{n=l}l=f+28|0;f=c[l>>2]|0;m=a+124|0;o=c[m>>2]|0;if((f|0)<(ca(o,n)|0)){p=(c[a+120>>2]|0)+23|0;if((ca((p-((p|0)%24|0)<<3|0)/3|0,o)|0)!=(f|0)){KIb(a,16,2355432,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=g;return r|0}p=h+12|0;if((c[p>>2]|0)==0){KIb(a,24,2444304,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}c[p>>2]=1;s=(f|0)/(o|0)|0}else{s=n}if((k&15|0)==0){t=(s&15|0)==0|0}else{t=0}n=h+8|0;if((t|0)!=(c[n>>2]|0)){c[n>>2]=t}t=M4a(a,j,0)|0;if((t|0)<0){r=t;i=g;return r|0}t=c[d>>2]|0;j=c[d+4>>2]|0;n=c[d+8>>2]|0;c[d+88>>2]=1;c[d+84>>2]=1;if((c[m>>2]|0)>0){o=a+120|0;f=h+16|0;h=d+32|0;p=d+36|0;q=d+40|0;u=0;v=k;k=t;t=j;j=n;n=c[o>>2]|0;while(1){w=v;x=n-((n|0)%6|0)|0;pe[c[f>>2]&1023](w,k,t,j,x);y=k+(x<<1)|0;z=x>>1;A=t+(z<<1)|0;B=j+(z<<1)|0;C=(x<<1|0)/3|0;D=c[o>>2]|0;do{if((x|0)<(D-1|0)){E=c[w+(C<<2)>>2]|0;F=z+1|0;G=t+(F<<1)|0;b[A>>1]=E&1023;b[y>>1]=E>>>10&1023;H=j+(F<<1)|0;b[B>>1]=E>>>20&1023;E=c[w+(C+1<<2)>>2]|0;F=k+(x+2<<1)|0;b[k+(x+1<<1)>>1]=E&1023;if((x|0)>=(D-3|0)){I=H;J=G;K=F;break}L=z+2|0;b[G>>1]=E>>>10&1023;b[F>>1]=E>>>20&1023;E=c[w+(C+2<<2)>>2]|0;b[H>>1]=E&1023;b[k+(x+3<<1)>>1]=E>>>10&1023;I=j+(L<<1)|0;J=t+(L<<1)|0;K=k+(x+4<<1)|0}else{I=B;J=A;K=y}}while(0);y=(D|0)/2|0;A=u+1|0;if((A|0)<(c[m>>2]|0)){u=A;v=v+s|0;k=K+(((c[h>>2]|0)/2|0)-D<<1)|0;t=J+(((c[p>>2]|0)/2|0)-y<<1)|0;j=I+(((c[q>>2]|0)/2|0)-y<<1)|0;n=D}else{break}}}n=c[a+408>>2]|0;do{if(n>>>0>1>>>0){c[d+296>>2]=1;if(!((n|0)==2|(n|0)==4)){break}c[d+300>>2]=1}}while(0);c[e>>2]=1;r=c[l>>2]|0;i=g;return r|0}function i6a(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=g-5|0;if((h|0)>0){i=e;j=f;k=d;l=a;m=0}else{return}while(1){a=c[l>>2]|0;b[i>>1]=a&1023;b[k>>1]=a>>>10&1023;b[j>>1]=a>>>20&1023;a=c[l+4>>2]|0;b[k+2>>1]=a&1023;b[i+2>>1]=a>>>10&1023;b[k+4>>1]=a>>>20&1023;a=c[l+8>>2]|0;b[j+2>>1]=a&1023;b[k+6>>1]=a>>>10&1023;b[i+4>>1]=a>>>20&1023;a=c[l+12>>2]|0;b[k+8>>1]=a&1023;b[j+4>>1]=a>>>10&1023;b[k+10>>1]=a>>>20&1023;a=m+6|0;if((a|0)<(h|0)){i=i+6|0;j=j+6|0;k=k+12|0;l=l+16|0;m=a}else{break}}return}function j6a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[a+120>>2]&1|0)!=0){KIb(a,16,2241816,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-22;i=b;return e|0}f=c[a+796>>2]|0;if((f|0)!=10){KIb(a,24,2200672,(d=i,i=i+8|0,c[d>>2]=f,d)|0);i=d}d=UHb()|0;c[a+804>>2]=d;if((d|0)==0){e=-12;i=b;return e|0}c[d+88>>2]=1;e=0;i=b;return e|0}function k6a(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;h=i;j=d+120|0;k=c[j>>2]|0;l=k+47|0;m=(l-((l|0)%48|0)<<3|0)/3|0;l=m-((((k<<3)+11|0)/12|0)<<2)|0;k=c[f>>2]|0;n=c[f+4>>2]|0;o=c[f+8>>2]|0;p=d+124|0;q=ca(c[p>>2]|0,m)|0;m=d5a(d,e,q,(q|0)<0|0?-1:0)|0;if((m|0)<0){r=m;i=h;return r|0}m=c[e+24>>2]|0;q=c[e+28>>2]|0;if(!((q|0)>-1)){KIb(0,0,2444256,(d=i,i=i+24|0,c[d>>2]=2355400,c[d+8>>2]=2292816,c[d+16>>2]=145,d)|0);i=d;Hd();return 0}if((c[p>>2]|0)>0){d=m+q|0;q=f+32|0;s=f+36|0;t=f+40|0;f=0;u=m;m=0;v=k;k=n;n=o;o=c[j>>2]|0;while(1){if((o-5|0)>0){w=u;x=0;z=v;A=k;B=n;while(1){C=b[A>>1]|0;D=C&65535;if((C&65535)>>>0<4>>>0){E=4}else{E=D>>>0>1019>>>0?1019:D}D=b[z>>1]|0;if((D&65535)>>>0<4>>>0){F=4096}else{F=(D&65535)>>>0>1019>>>0?1043456:(D&65535)<<10}D=b[B>>1]|0;if((D&65535)>>>0<4>>>0){G=4194304}else{G=(D&65535)>>>0>1019>>>0?1068498944:(D&65535)<<20}D=w;y=F|E|G;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;D=b[z+2>>1]|0;C=D&65535;if((D&65535)>>>0<4>>>0){H=4}else{H=C>>>0>1019>>>0?1019:C}C=b[A+2>>1]|0;if((C&65535)>>>0<4>>>0){I=4096}else{I=(C&65535)>>>0>1019>>>0?1043456:(C&65535)<<10}C=b[z+4>>1]|0;if((C&65535)>>>0<4>>>0){J=4194304}else{J=(C&65535)>>>0>1019>>>0?1068498944:(C&65535)<<20}C=w+4|0;y=I|H|J;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=b[B+2>>1]|0;D=C&65535;if((C&65535)>>>0<4>>>0){K=4}else{K=D>>>0>1019>>>0?1019:D}D=b[z+6>>1]|0;if((D&65535)>>>0<4>>>0){L=4096}else{L=(D&65535)>>>0>1019>>>0?1043456:(D&65535)<<10}D=A+6|0;C=b[A+4>>1]|0;if((C&65535)>>>0<4>>>0){M=4194304}else{M=(C&65535)>>>0>1019>>>0?1068498944:(C&65535)<<20}C=w+8|0;y=L|K|M;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=b[z+8>>1]|0;N=C&65535;if((C&65535)>>>0<4>>>0){O=4}else{O=N>>>0>1019>>>0?1019:N}N=B+6|0;C=b[B+4>>1]|0;if((C&65535)>>>0<4>>>0){P=4096}else{P=(C&65535)>>>0>1019>>>0?1043456:(C&65535)<<10}C=z+12|0;Q=b[z+10>>1]|0;if((Q&65535)>>>0<4>>>0){R=4194304}else{R=(Q&65535)>>>0>1019>>>0?1068498944:(Q&65535)<<20}Q=w+12|0;y=P|O|R;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=w+16|0;S=x+6|0;T=c[j>>2]|0;if((S|0)<(T-5|0)){w=Q;x=S;z=C;A=D;B=N}else{U=Q;V=S;W=C;X=D;Y=N;Z=T;break}}}else{U=u;V=0;W=v;X=k;Y=n;Z=o}do{if((V|0)<(Z-1|0)){B=X+2|0;A=b[X>>1]|0;z=A&65535;if((A&65535)>>>0<4>>>0){_=4}else{_=z>>>0>1019>>>0?1019:z}z=b[W>>1]|0;if((z&65535)>>>0<4>>>0){$=4096}else{$=(z&65535)>>>0>1019>>>0?1043456:(z&65535)<<10}z=Y+2|0;A=b[Y>>1]|0;if((A&65535)>>>0<4>>>0){aa=4194304}else{aa=(A&65535)>>>0>1019>>>0?1068498944:(A&65535)<<20}A=U;y=$|_|aa;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;A=U+4|0;x=W+4|0;w=b[W+2>>1]|0;T=w&65535;if((w&65535)>>>0<4>>>0){ba=4}else{ba=T>>>0>1019>>>0?1019:T}T=c[j>>2]|0;if((V|0)==(T-2|0)){w=A;y=ba;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;da=U+8|0;ea=c[j>>2]|0}else{da=A;ea=T}if((V|0)>=(ea-3|0)){fa=z;ga=B;ha=x;ia=da;break}T=b[B>>1]|0;if((T&65535)>>>0<4>>>0){ja=4096}else{ja=(T&65535)>>>0>1019>>>0?1043456:(T&65535)<<10}T=b[x>>1]|0;if((T&65535)>>>0<4>>>0){ka=4194304}else{ka=(T&65535)>>>0>1019>>>0?1068498944:(T&65535)<<20}T=da;y=ja|ba|ka;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;T=b[z>>1]|0;z=T&65535;if((T&65535)>>>0<4>>>0){la=4}else{la=z>>>0>1019>>>0?1019:z}z=b[W+6>>1]|0;if((z&65535)>>>0<4>>>0){ma=4096}else{ma=(z&65535)>>>0>1019>>>0?1043456:(z&65535)<<10}z=da+4|0;y=ma|la;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;fa=Y+4|0;ga=X+4|0;ha=W+8|0;ia=da+8|0}else{fa=Y;ga=X;ha=W;ia=U}}while(0);if((f|0)==0){z=d-ia|0;T=z>>>0>l>>>0?l:z;mrc(ia|0,0,T|0)|0;na=ia+T|0;oa=(T|0)!=(l|0)|0}else{na=ia;oa=f}T=c[j>>2]|0;z=(T|0)/2|0;x=m+1|0;if((x|0)<(c[p>>2]|0)){f=oa;u=na;m=x;v=ha+(((c[q>>2]|0)/2|0)-T<<1)|0;k=ga+(((c[s>>2]|0)/2|0)-z<<1)|0;n=fa+(((c[t>>2]|0)/2|0)-z<<1)|0;o=T}else{break}}}o=e+36|0;c[o>>2]=c[o>>2]|1;c[g>>2]=1;r=0;i=h;return r|0}function l6a(a){a=a|0;mJb(a+804|0);return 0}function m6a(a){a=a|0;var b=0,d=0;b=i;if((c[a+120>>2]&1|0)==0){c[a+140>>2]=56;c[a+796>>2]=10;d=0;i=b;return d|0}else{KIb(a,16,2292792,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;d=-22;i=b;return d|0}return 0}function n6a(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;h=c[f+24>>2]|0;j=c[a+120>>2]|0;k=f+28|0;f=c[k>>2]|0;l=a+124|0;m=(ca(j<<3,c[l>>2]|0)|0)/3|0;if((f|0)<(m|0)){KIb(a,16,2444232,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}if((f|0)>(m|0)){QIb(a,2355376,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}n=M4a(a,d,0)|0;if((n|0)<0){o=n;i=g;return o|0}n=c[d>>2]|0;a=c[d+4>>2]|0;m=c[d+8>>2]|0;c[d+88>>2]=1;c[d+84>>2]=1;f=d+32|0;p=2-j|0;q=d+36|0;r=(j|0)/-2|0;s=d+40|0;d=r+1|0;t=n+(j<<1)|0;j=m;m=a;a=n;n=0;u=h;while(1){h=je(c[u>>2]|0)|0;b[m>>1]=h>>>16&65535&-64;b[a>>1]=h>>>6&65535&-64;b[j>>1]=h<<4&65535&-64;h=u+8|0;v=je(c[u+4>>2]|0)|0;w=a+4|0;b[a+2>>1]=v>>>16&65535&-64;if(w>>>0<t>>>0){x=t;y=j+2|0;z=m+2|0;A=w;B=n}else{w=(c[f>>2]|0)/2|0;C=n+1|0;if((C|0)<(c[l>>2]|0)){x=a+(w+2<<1)|0;y=j+(d+((c[s>>2]|0)/2|0)<<1)|0;z=m+(((c[q>>2]|0)/2|0)+1+r<<1)|0;A=a+(p+w<<1)|0;B=C}else{break}}b[z>>1]=v>>>6&65535&-64;b[A>>1]=v<<4&65535&-64;v=u+12|0;C=je(c[h>>2]|0)|0;b[y>>1]=C>>>16&65535&-64;h=A+4|0;b[A+2>>1]=C>>>6&65535&-64;if(h>>>0<x>>>0){D=x;E=y+2|0;F=z+2|0;G=h;H=B}else{h=(c[f>>2]|0)/2|0;w=B+1|0;if((w|0)<(c[l>>2]|0)){D=A+(h+2<<1)|0;E=y+(d+((c[s>>2]|0)/2|0)<<1)|0;F=z+(((c[q>>2]|0)/2|0)+1+r<<1)|0;G=A+(p+h<<1)|0;H=w}else{break}}b[F>>1]=C<<4&65535&-64;C=u+16|0;w=je(c[v>>2]|0)|0;b[G>>1]=w>>>16&65535&-64;b[E>>1]=w>>>6&65535&-64;v=G+4|0;b[G+2>>1]=w<<4&65535&-64;if(v>>>0<D>>>0){t=D;j=E+2|0;m=F+2|0;a=v;n=H;u=C;continue}v=(c[f>>2]|0)/2|0;w=H+1|0;if((w|0)<(c[l>>2]|0)){t=G+(v+2<<1)|0;j=E+(d+((c[s>>2]|0)/2|0)<<1)|0;m=F+(((c[q>>2]|0)/2|0)+1+r<<1)|0;a=G+(p+v<<1)|0;n=w;u=C}else{break}}c[e>>2]=1;o=c[k>>2]|0;i=g;return o|0}function o6a(a){a=a|0;var b=0;b=i;c[a+140>>2]=5;if((c[a+120>>2]&1|0)==0){i=b;return 0}KIb(a,24,2355336,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function p6a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=b+124|0;k=b+120|0;if((c[j>>2]|0)<(ca((c[f>>2]|0)*3|0,c[k>>2]|0)|0)){KIb(b,16,2444200,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=g;return m|0}l=M4a(b,d,0)|0;if((l|0)<0){m=l;i=g;return m|0}c[d+84>>2]=1;c[d+88>>2]=1;l=c[f>>2]|0;if((l|0)>0){b=d+32|0;n=d+36|0;o=d+40|0;p=h;h=c[d>>2]|0;q=c[d+4>>2]|0;r=c[d+8>>2]|0;d=0;s=c[k>>2]|0;t=l;while(1){if((s|0)>0){l=p;u=0;while(1){a[r+u|0]=a[l]|0;a[h+u|0]=a[l+1|0]|0;v=l+3|0;a[q+u|0]=a[l+2|0]|0;w=u+1|0;x=c[k>>2]|0;if((w|0)<(x|0)){l=v;u=w}else{break}}y=v;z=x;A=c[f>>2]|0}else{y=p;z=s;A=t}u=d+1|0;if((u|0)<(A|0)){p=y;h=h+(c[b>>2]|0)|0;q=q+(c[n>>2]|0)|0;r=r+(c[o>>2]|0)|0;d=u;s=z;t=A}else{break}}}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function q6a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[a+120>>2]&1|0)!=0){KIb(a,16,2444144,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-1094995529;i=b;return e|0}f=UHb()|0;c[a+804>>2]=f;if((f|0)!=0){e=0;i=b;return e|0}KIb(a,16,2355296,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-12;i=b;return e|0}function r6a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=b+120|0;h=b+124|0;i=ca((c[g>>2]|0)*3|0,c[h>>2]|0)|0;j=d5a(b,d,i,(i|0)<0|0?-1:0)|0;if((j|0)<0){k=j;return k|0}j=c[d+24>>2]|0;i=c[b+804>>2]|0;c[i+84>>2]=1;c[i+88>>2]=1;i=c[h>>2]|0;if((i|0)>0){b=e+32|0;l=e+36|0;m=e+40|0;n=j;j=c[e>>2]|0;o=c[e+4>>2]|0;p=c[e+8>>2]|0;e=0;q=c[g>>2]|0;r=i;while(1){if((q|0)>0){i=n;s=0;while(1){a[i]=a[p+s|0]|0;a[i+1|0]=a[j+s|0]|0;t=i+3|0;a[i+2|0]=a[o+s|0]|0;u=s+1|0;v=c[g>>2]|0;if((u|0)<(v|0)){i=t;s=u}else{break}}w=t;x=v;y=c[h>>2]|0}else{w=n;x=q;y=r}s=e+1|0;if((s|0)<(y|0)){n=w;j=j+(c[b>>2]|0)|0;o=o+(c[l>>2]|0)|0;p=p+(c[m>>2]|0)|0;e=s;q=x;r=y}else{break}}}y=d+36|0;c[y>>2]=c[y>>2]|1;c[f>>2]=1;k=0;return k|0}function s6a(a){a=a|0;mJb(a+804|0);return 0}function t6a(a){a=a|0;c[a+140>>2]=299;return 0}function u6a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=b+124|0;k=b+120|0;if((c[j>>2]|0)<(ca(c[f>>2]<<2,c[k>>2]|0)|0)){KIb(b,16,2292744,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=g;return m|0}l=M4a(b,d,0)|0;if((l|0)<0){m=l;i=g;return m|0}c[d+84>>2]=1;c[d+88>>2]=1;l=c[f>>2]|0;if((l|0)>0){n=d+32|0;o=d+36|0;p=d+40|0;q=d+44|0;r=b+48|0;b=h;h=c[d>>2]|0;s=c[d+4>>2]|0;t=c[d+8>>2]|0;u=c[d+12>>2]|0;d=0;v=c[k>>2]|0;w=l;while(1){if((v|0)>0){l=b;x=0;do{y=l+1|0;z=a[l]|0;if((c[r>>2]|0)==1096373590){a[t+x|0]=z;a[s+x|0]=a[y]|0;a[h+x|0]=a[l+2|0]|0;a[u+x|0]=a[l+3|0]|0}else{a[s+x|0]=z;a[h+x|0]=a[y]|0;a[t+x|0]=a[l+2|0]|0;a[u+x|0]=a[l+3|0]|0}l=l+4|0;x=x+1|0;A=c[k>>2]|0;}while((x|0)<(A|0));B=l;C=A;D=c[f>>2]|0}else{B=b;C=v;D=w}x=d+1|0;if((x|0)<(D|0)){b=B;h=h+(c[n>>2]|0)|0;s=s+(c[o>>2]|0)|0;t=t+(c[p>>2]|0)|0;u=u+(c[q>>2]|0)|0;d=x;v=C;w=D}else{break}}}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function v6a(a){a=a|0;var b=0,d=0,e=0;b=i;d=UHb()|0;c[a+804>>2]=d;if((d|0)!=0){e=0;i=b;return e|0}KIb(a,16,2241752,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-12;i=b;return e|0}function w6a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=b+120|0;h=b+124|0;i=ca(c[g>>2]<<2,c[h>>2]|0)|0;j=d5a(b,d,i,(i|0)<0|0?-1:0)|0;if((j|0)<0){k=j;return k|0}j=c[d+24>>2]|0;i=c[b+804>>2]|0;c[i+84>>2]=1;c[i+88>>2]=1;i=c[h>>2]|0;if((i|0)>0){l=e+32|0;m=e+36|0;n=e+40|0;o=e+44|0;p=b+48|0;b=j;j=c[e>>2]|0;q=c[e+4>>2]|0;r=c[e+8>>2]|0;s=c[e+12>>2]|0;e=0;t=c[g>>2]|0;u=i;while(1){if((t|0)>0){i=b;v=0;do{if((c[p>>2]|0)==1096373590){a[i]=a[r+v|0]|0;a[i+1|0]=a[q+v|0]|0;a[i+2|0]=a[j+v|0]|0;a[i+3|0]=a[s+v|0]|0}else{a[i]=a[q+v|0]|0;a[i+1|0]=a[j+v|0]|0;a[i+2|0]=a[r+v|0]|0;a[i+3|0]=a[s+v|0]|0}i=i+4|0;v=v+1|0;w=c[g>>2]|0;}while((v|0)<(w|0));x=i;y=w;z=c[h>>2]|0}else{x=b;y=t;z=u}v=e+1|0;if((v|0)<(z|0)){b=x;j=j+(c[l>>2]|0)|0;q=q+(c[m>>2]|0)|0;r=r+(c[n>>2]|0)|0;s=s+(c[o>>2]|0)|0;e=v;t=y;u=z}else{break}}}z=d+36|0;c[z>>2]=c[z>>2]|1;c[f>>2]=1;k=0;return k|0}function x6a(a){a=a|0;mJb(a+804|0);return 0}function y6a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;c[a+140>>2]=78;c[a+796>>2]=10;if((c[a+120>>2]&1|0)==0){d=0;i=b;return d|0}e=a;if((c[a+696>>2]&8|0)==0){KIb(e,24,2292664,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;d=0;i=b;return d|0}else{KIb(e,16,2355160,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;d=-1094995529;i=b;return d|0}return 0}function z6a(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;j=c[g+24>>2]|0;k=g+28|0;g=a+124|0;l=a+120|0;if((c[k>>2]|0)<(ca(c[g>>2]<<2,c[l>>2]|0)|0)){KIb(a,16,2443888,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=h;return n|0}m=M4a(a,e,0)|0;if((m|0)<0){n=m;i=h;return n|0}c[e+84>>2]=1;c[e+88>>2]=1;m=c[g>>2]|0;if((m|0)>0){g=e+32|0;a=e+36|0;o=e+40|0;p=c[l>>2]|0;l=c[e>>2]|0;q=c[e+4>>2]|0;r=c[e+8>>2]|0;e=j;j=0;while(1){if((p|0)>0){s=e;t=0;while(1){u=s;v=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;b[q+(t<<1)>>1]=v>>>2&1023;b[l+(t<<1)>>1]=v>>>12&1023;b[r+(t<<1)>>1]=v>>>22;v=s+4|0;u=t+1|0;if((u|0)<(p|0)){s=v;t=u}else{w=v;break}}}else{w=e}t=j+1|0;if((t|0)<(m|0)){l=l+(c[g>>2]>>1<<1)|0;q=q+(c[a>>2]>>1<<1)|0;r=r+(c[o>>2]>>1<<1)|0;e=w;j=t}else{break}}}c[f>>2]=1;n=c[k>>2]|0;i=h;return n|0}function A6a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[a+120>>2]&1|0)!=0){KIb(a,16,2443848,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-1094995529;i=b;return e|0}f=UHb()|0;c[a+804>>2]=f;if((f|0)!=0){e=0;i=b;return e|0}KIb(a,16,2355128,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-12;i=b;return e|0}function B6a(b,d,f,g){b=b|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;h=b+120|0;i=b+124|0;j=ca(c[h>>2]<<2,c[i>>2]|0)|0;k=d5a(b,d,j,(j|0)<0|0?-1:0)|0;if((k|0)<0){l=k;return l|0}k=c[d+24>>2]|0;j=c[b+804>>2]|0;c[j+84>>2]=1;c[j+88>>2]=1;j=c[i>>2]|0;if((j|0)>0){b=f+32|0;m=f+36|0;n=f+40|0;o=c[f>>2]|0;p=c[f+4>>2]|0;q=c[f+8>>2]|0;f=k;k=0;r=c[h>>2]|0;s=j;while(1){if((r|0)>0){j=f;t=0;do{u=j;y=(e[o+(t<<1)>>1]|0)<<12|(e[p+(t<<1)>>1]|0)<<2|(e[q+(t<<1)>>1]|0)<<22;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;j=j+4|0;t=t+1|0;v=c[h>>2]|0;}while((t|0)<(v|0));w=j;x=v;z=c[i>>2]|0}else{w=f;x=r;z=s}t=k+1|0;if((t|0)<(z|0)){o=o+(c[b>>2]>>1<<1)|0;p=p+(c[m>>2]>>1<<1)|0;q=q+(c[n>>2]>>1<<1)|0;f=w;k=t;r=x;s=z}else{break}}}z=d+36|0;c[z>>2]=c[z>>2]|1;c[g>>2]=1;l=0;return l|0}function C6a(a){a=a|0;mJb(a+804|0);return 0}function D6a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;d=a+120|0;e=a+124|0;c[b+4>>2]=pJb(ca(c[e>>2]|0,c[d>>2]|0)|0)|0;c[b+8>>2]=pJb(ca(c[e>>2]|0,c[d>>2]|0)|0)|0;return 0}function E6a(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0;j=i;k=c[b+60>>2]|0;l=k;m=c[h+24>>2]|0;n=h+28|0;h=c[n>>2]|0;if(!((h|0)>-1)){KIb(0,0,2168800,(o=i,i=i+24|0,c[o>>2]=2142016,c[o+8>>2]=2118512,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}p=k+1036|0;c[p>>2]=m;c[k+1044>>2]=m;q=k+1040|0;c[q>>2]=m+h;h=M4a(b,f,0)|0;if((h|0)<0){r=h;i=j;return r|0}h=c[q>>2]|0;m=c[p>>2]|0;s=h;a:do{if((s-m|0)<2){t=0}else{u=m+2|0;c[p>>2]=u;v=m;w=(d[v]|d[v+1|0]<<8)<<16>>16&65535;if((w&1|0)==0){x=0;z=u}else{if((s-u|0)<2){A=0;B=u}else{v=m+4|0;c[p>>2]=v;C=u;A=(d[C]|d[C+1|0]<<8)<<16>>16<<16>>16;B=v}if((s-B|0)<2){D=0;E=B}else{v=B+2|0;c[p>>2]=v;C=B;D=(d[C]|d[C+1|0]<<8)<<16>>16<<16>>16;E=v}x=(ca(c[b+120>>2]|0,D)|0)+A|0;z=E}b:do{if((w&8|0)==0){F=h;G=z}else{do{if((s-z|0)>=4){v=z+4|0;c[p>>2]=v;C=z;u=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;if(u>>>0>(4-v+s|0)>>>0|u>>>0<4>>>0){break}C=k;H=c[C>>2]|0;I=c[H+120>>2]|0;J=c[k+8>>2]|0;K=c[H+124>>2]|0;H=J+(ca(K,I)|0)|0;L=I>>2;M=ca(K>>2,L)|0;c:do{if((M|0)>0){K=I*3|0;N=K+4|0;O=I<<1;P=O+4|0;Q=I+4|0;R=I+1|0;S=I+2|0;T=I+3|0;U=O|1;V=O+2|0;W=O+3|0;X=K+1|0;Y=K+2|0;Z=K+3|0;_=v;$=0;aa=0;ba=0;da=c[k+4>>2]|0;ea=J+x|0;d:while(1){do{if((ba&3|0)==0){if((s-_|0)<1){fa=_;ga=0;ha=21;break}ia=d[_]|0;ja=_+1|0;ha=20}else{ia=aa;ja=_;ha=20}}while(0);e:do{if((ha|0)==20){ha=0;ka=ia&192;if((ka|0)==128){if((s-ja|0)<1){la=0;ma=ja}else{la=a[ja]|0;ma=ja+1|0}mrc(da|0,la|0,4)|0;mrc(da+I|0,la|0,4)|0;mrc(da+O|0,la|0,4)|0;mrc(da+K|0,la|0,4)|0;na=ma;oa=ia;break}else if((ka|0)==64){do{if((s-ja|0)<1){pa=ja}else{qa=ja+1|0;ra=a[ja]|0;sa=ra&255;if(ra<<24>>24==0){pa=qa;break}ra=(ca(sa>>>4<<28>>28,I)|0)+(sa<<28>>28)|0;sa=ea+ra|0;do{if(sa>>>0<J>>>0){ha=33}else{if((ea+(ra+4)|0)>>>0>H>>>0){ha=33;break}ta=sa;ua=da;y=d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y}}while(0);if((ha|0)==33){ha=0;sa=da;y=0;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y}sa=ra+I|0;ua=ea+sa|0;do{if(ua>>>0<J>>>0){va=da+I|0;ha=73}else{ta=da+I|0;if((ea+(sa+4)|0)>>>0>H>>>0){va=ta;ha=73;break}wa=ua;xa=ta;y=d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y}}while(0);if((ha|0)==73){ha=0;ua=va;y=0;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y}ua=ra+O|0;sa=ea+ua|0;do{if(sa>>>0<J>>>0){ya=da+O|0;ha=78}else{xa=da+O|0;if((ea+(ua+4)|0)>>>0>H>>>0){ya=xa;ha=78;break}wa=sa;ta=xa;y=d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y}}while(0);if((ha|0)==78){ha=0;sa=ya;y=0;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y}sa=ra+K|0;ua=ea+sa|0;do{if(ua>>>0<J>>>0){za=da+K|0}else{ta=da+K|0;if((ea+(sa+4)|0)>>>0>H>>>0){za=ta;break}wa=ua;xa=ta;y=d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;na=qa;oa=ia;break e}}while(0);ua=za;y=0;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y;na=qa;oa=ia;break e}}while(0);if((s-pa|0)>>>0<16>>>0){ha=29;break d}ua=pa;sa=da;y=d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;sa=pa+4|0;ua=s-sa|0;ra=ua>>>0>4>>>0?4:ua;nrc(da+I|0,sa|0,ra)|0;sa=ra+4|0;ra=pa+sa|0;ua=s-ra|0;xa=ua>>>0>4>>>0?4:ua;nrc(da+O|0,ra|0,xa)|0;ra=xa+sa|0;sa=pa+ra|0;xa=s-sa|0;ua=xa>>>0>4>>>0?4:xa;nrc(da+K|0,sa|0,ua)|0;na=pa+(ua+ra)|0;oa=ia;break}else if((ka|0)==192){do{if((s-ja|0)<1){Aa=ja;Ba=1632}else{ra=ja+1|0;ua=d[ja]|0;sa=ua>>>6;xa=e[280976+((ua&63)<<1)>>1]|0;if((sa|0)==1){Ca=~xa}else if((sa|0)==2){Ca=xa}else if((sa|0)==3){ha=54;break d}else if((sa|0)==0){Aa=ra;Ba=xa;break}else{na=ra;oa=ia;break e}if((s-ra|0)<1){Da=0;Ea=ra}else{Da=a[ra]|0;Ea=ja+2|0}ra=0;xa=Ca;while(1){sa=ca(ra,I)|0;do{if((xa&1|0)==0){ha=52}else{ua=ea+sa|0;if(!(ua>>>0>=J>>>0&ua>>>0<H>>>0)){ha=52;break}a[da+sa|0]=a[ua]|0}}while(0);if((ha|0)==52){ha=0;a[da+sa|0]=Da}ua=sa+1|0;do{if((xa&2|0)==0){ha=60}else{wa=ea+ua|0;if(!(wa>>>0>=J>>>0&wa>>>0<H>>>0)){ha=60;break}a[da+ua|0]=a[wa]|0}}while(0);if((ha|0)==60){ha=0;a[da+ua|0]=Da}wa=sa+2|0;do{if((xa&4|0)==0){ha=64}else{ta=ea+wa|0;if(!(ta>>>0>=J>>>0&ta>>>0<H>>>0)){ha=64;break}a[da+wa|0]=a[ta]|0}}while(0);if((ha|0)==64){ha=0;a[da+wa|0]=Da}ua=sa+3|0;do{if((xa&8|0)==0){ha=68}else{ta=ea+ua|0;if(!(ta>>>0>=J>>>0&ta>>>0<H>>>0)){ha=68;break}a[da+ua|0]=a[ta]|0}}while(0);if((ha|0)==68){ha=0;a[da+ua|0]=Da}sa=ra+1|0;if((sa|0)<4){ra=sa;xa=xa>>4}else{na=Ea;oa=ia;break e}}}}while(0);if((s-Aa|0)<1){Fa=0;Ga=Aa}else{Fa=a[Aa]|0;Ga=Aa+1|0}if((s-Ga|0)<1){Ha=0;Ia=Ga}else{Ha=a[Ga]|0;Ia=Ga+1|0}a[da]=(Ba&1|0)!=0?Ha:Fa;a[da+1|0]=(Ba&2|0)!=0?Ha:Fa;a[da+2|0]=(Ba&4|0)!=0?Ha:Fa;a[da+3|0]=(Ba&8|0)!=0?Ha:Fa;a[da+I|0]=(Ba&16|0)!=0?Ha:Fa;a[da+R|0]=(Ba&32|0)!=0?Ha:Fa;a[da+S|0]=(Ba&64|0)!=0?Ha:Fa;a[da+T|0]=(Ba&128|0)!=0?Ha:Fa;a[da+O|0]=(Ba&256|0)!=0?Ha:Fa;a[da+U|0]=(Ba&512|0)!=0?Ha:Fa;a[da+V|0]=(Ba&1024|0)!=0?Ha:Fa;a[da+W|0]=(Ba&2048|0)!=0?Ha:Fa;a[da+K|0]=(Ba&4096|0)!=0?Ha:Fa;a[da+X|0]=(Ba&8192|0)!=0?Ha:Fa;a[da+Y|0]=(Ba&16384|0)!=0?Ha:Fa;a[da+Z|0]=(Ba&32768|0)!=0?Ha:Fa;na=Ia;oa=ia;break}else if((ka|0)==0){fa=ja;ga=ia;ha=21;break}else{na=ja;oa=ia;break}}}while(0);f:do{if((ha|0)==21){ha=0;if(ea>>>0<J>>>0|(ea+4|0)>>>0>H>>>0){xa=da;y=0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y}else{xa=ea;ra=da;y=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y}ra=ea+I|0;do{if(ra>>>0<J>>>0){Ja=da+I|0;ha=87}else{xa=da+I|0;if((ea+Q|0)>>>0>H>>>0){Ja=xa;ha=87;break}qa=ra;sa=xa;y=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y}}while(0);if((ha|0)==87){ha=0;ra=Ja;y=0;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y}ra=ea+O|0;do{if(ra>>>0<J>>>0){Ka=da+O|0;ha=92}else{ka=da+O|0;if((ea+P|0)>>>0>H>>>0){Ka=ka;ha=92;break}sa=ra;qa=ka;y=d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y}}while(0);if((ha|0)==92){ha=0;ra=Ka;y=0;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y}ra=ea+K|0;do{if(ra>>>0<J>>>0){La=da+K|0}else{qa=da+K|0;if((ea+N|0)>>>0>H>>>0){La=qa;break}sa=ra;ka=qa;y=d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0;a[ka]=y;y=y>>8;a[ka+1|0]=y;y=y>>8;a[ka+2|0]=y;y=y>>8;a[ka+3|0]=y;na=fa;oa=ga;break f}}while(0);ra=La;y=0;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;na=fa;oa=ga}}while(0);ra=$+1|0;if((ra|0)==(L|0)){Ma=ea+N|0;Na=da+N|0;Oa=0}else{Ma=ea+4|0;Na=da+4|0;Oa=ra}ra=ba+1|0;if((ra|0)<(M|0)){_=na;$=Oa;aa=oa<<2;ba=ra;da=Na;ea=Ma}else{break c}}if((ha|0)==29){KIb(c[C>>2]|0,16,2241720,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((ha|0)==54){KIb(c[C>>2]|0,16,2200600,(o=i,i=i+8|0,c[o>>2]=ba,o)|0);i=o;break}}}while(0);C=u-4|0;M=c[q>>2]|0;L=c[p>>2]|0;H=M-L|0;J=L+(H>>>0>C>>>0?C:H)|0;c[p>>2]=J;F=M;G=J;break b}}while(0);KIb(b,16,2443824,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;r=-1;i=j;return r|0}}while(0);J=w&16;if((J|0)==0){t=0;break}M=F;if((M-G|0)<4){Pa=0;Qa=G}else{H=G+4|0;c[p>>2]=H;C=G;Pa=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;Qa=H}if((M-Qa|0)<1){Ra=0;Sa=Qa}else{H=Qa+1|0;c[p>>2]=H;Ra=d[Qa]|0;Sa=H}if((M-Sa|0)<1){Ta=255;Ua=Sa}else{M=Sa+1|0;c[p>>2]=M;Ta=(d[Sa]|0)+255&255;Ua=M}M=Ta+Ra|0;if((M|0)>255){KIb(c[k>>2]|0,16,2355088,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=J;break}if(((Ta*3|0)+2|0)>(Pa|0)){KIb(c[k>>2]|0,16,2292624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=J;break}else{Va=Ra;Wa=F;Xa=Ua}while(1){if((Wa-Xa|0)<3){Ya=-16777216}else{c[p>>2]=Xa+3;Ya=(d[Xa]|0)<<16|(d[Xa+1|0]|0)<<8|(d[Xa+2|0]|0)|-16777216}c[l+12+(Va<<2)>>2]=Ya;H=Va+1|0;if((H|0)>(M|0)){t=J;break a}Va=H;Wa=c[q>>2]|0;Xa=c[p>>2]|0}}}while(0);nrc(c[f+4>>2]|0,k+12|0,1024)|0;c[f+304>>2]=t;t=k+4|0;p=b+124|0;if((c[p>>2]|0)>0){Xa=b+120|0;b=f+32|0;q=0;Wa=c[t>>2]|0;Va=c[f>>2]|0;f=c[Xa>>2]|0;while(1){nrc(Va|0,Wa|0,f)|0;Ya=c[Xa>>2]|0;l=q+1|0;if((l|0)<(c[p>>2]|0)){q=l;Wa=Wa+Ya|0;Va=Va+(c[b>>2]|0)|0;f=Ya}else{break}}}f=k+8|0;k=c[f>>2]|0;c[f>>2]=c[t>>2];c[t>>2]=k;c[g>>2]=1;r=c[n>>2]|0;i=j;return r|0}function F6a(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+4|0);mJb(b+8|0);return 0}function G6a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a+60|0;e=c[d>>2]|0;c[e>>2]=a;l8(e+4|0,a);c[a+140>>2]=0;c[a+796>>2]=8;f=c2(0,c[a+120>>2]|0,c[a+124>>2]|0)|0;c[e+1248>>2]=f;g=hJb(f)|0;c[e+1252>>2]=g;if((g|0)!=0){h=0;i=b;return h|0}KIb(a,16,2241680,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;mJb((c[d>>2]|0)+1252|0);h=-12;i=b;return h|0}function H6a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;i=i+24|0;j=h|0;k=c[b+60>>2]|0;l=k;m=e;n=c[g+24>>2]|0;o=b+120|0;p=(c[o>>2]|0)/2|0;q=b+124|0;r=(c[q>>2]|0)/2|0;s=g+28|0;g=c[s>>2]|0;if((g|0)<4|(g-4|0)>268435455){KIb(b,16,2443800,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}g=M4a(b,m,0)|0;if((g|0)<0){u=g;i=h;return u|0}c[e+84>>2]=1;c[e+88>>2]=1;e=n;g=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;if((g|0)!=1){KIb(b,24,2355056,(t=i,i=i+8|0,c[t>>2]=g,t)|0);i=t}g=n+4|0;n=(c[s>>2]<<3)-32|0;e=n>>>0>2147483639>>>0|(g|0)==0;v=e?0:g;g=e?0:n;c[j>>2]=v;c[j+12>>2]=g;n=g+8|0;c[j+16>>2]=n;c[j+4>>2]=v+(g>>3);e=j+8|0;c[e>>2]=0;w=k+1248|0;a:do{if((c[w>>2]|0)>0){x=k+1252|0;y=0;z=0;A=0;while(1){B=v+(A>>>3)|0;C=(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)>>>((A&7)>>>0)&255;if((C|0)==0){B=A+8|0;D=n>>>0>B>>>0?B:n;B=d[v+(D>>>3)|0]|0;E=((D|0)<(n|0))+D|0;c[e>>2]=E;if((1<<(D&7)&B|0)==0){break a}a[(c[x>>2]|0)+y|0]=8;F=E}else{E=a[280720+C|0]|0;C=A+1+(E&255)|0;B=n>>>0>C>>>0?C:n;c[e>>2]=B;a[(c[x>>2]|0)+y|0]=E;F=B}B=(d[(c[x>>2]|0)+y|0]|0)+z|0;E=y+1|0;if((E|0)<(c[w>>2]|0)){y=E;z=B;A=F}else{G=B;H=F;I=13;break}}}else{G=0;H=0;I=13}}while(0);do{if((I|0)==13){if((g-H|0)<(G|0)){break}J6a(l,m,j,0,0,c[o>>2]|0,c[q>>2]|0);if((c[(c[k>>2]|0)+88>>2]&8192|0)==0){F=ca(c[q>>2]|0,c[o>>2]|0)|0;J6a(l,m,j,1,F,p,r);J6a(l,m,j,2,F+(ca(r,p)|0)|0,p,r)}c[f>>2]=1;u=c[s>>2]|0;i=h;return u|0}}while(0);KIb(b,16,2292608,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}function I6a(a){a=a|0;mJb((c[a+60>>2]|0)+1252|0);return 0}function J6a(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;l=i;i=i+16|0;m=l|0;n=l+8|0;o=c[e+(g<<2)>>2]|0;p=(c[b+1252>>2]|0)+h|0;h=c[e+32+(g<<2)>>2]|0;if((k|0)<=0){i=l;return}g=(j|0)>1;e=-h|0;q=b+1088|0;b=f+8|0;r=f+16|0;s=f|0;if((j|0)>0){t=p;u=0;v=o}else{f=p;p=0;w=o;while(1){do{if((p|0)==0){o=a[f]|0;a[w]=o;if(g){x=1;y=o}else{break}do{y=y+(a[f+x|0]|0)&255;a[w+x|0]=y;x=x+1|0;}while((x|0)<(j|0))}else{c[m>>2]=0;o=w+e|0;c[n>>2]=d[o]|0;_e[c[q>>2]&511](w,o,f,j,m,n)}}while(0);o=p+1|0;if((o|0)<(k|0)){f=f+j|0;p=o;w=w+h|0}else{break}}i=l;return}while(1){w=0;do{p=t+w|0;f=a[p]|0;if(!(f<<24>>24==0)){x=f&255;f=c[b>>2]|0;y=c[r>>2]|0;o=(c[s>>2]|0)+(f>>>3)|0;z=32-x|0;A=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((f&7)>>>0)<<z>>>(z>>>0);z=f+x|0;c[b>>2]=y>>>0>z>>>0?z:y;y=(1<<x)-1+A|0;a[p]=y>>>1^-(y&1)}w=w+1|0;}while((w|0)<(j|0));do{if((u|0)==0){w=a[t]|0;a[v]=w;if(g){B=1;C=w}else{break}do{C=C+(a[t+B|0]|0)&255;a[v+B|0]=C;B=B+1|0;}while((B|0)<(j|0))}else{c[m>>2]=0;w=v+e|0;c[n>>2]=d[w]|0;_e[c[q>>2]&511](v,w,t,j,m,n)}}while(0);w=u+1|0;if((w|0)<(k|0)){t=t+j|0;u=w;v=v+h|0}else{break}}i=l;return}function K6a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=i;g=a;h=e|0;j=c[h>>2]|0;k=e+8|0;l=c[k>>2]|0;m=e+16|0;e=c[m>>2]|0;n=j+(l>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(l&7)&-65536;n=l+16|0;l=e>>>0>n>>>0?n:e;e=j+(l>>>3)|0;j=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(l&7)>>>16|o;KIb(g,48,2456272,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;j=c[k>>2]|0;l=c[m>>2]|0;e=(c[h>>2]|0)+(j>>>3)|0;n=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(j&7)>>>30;e=j+2|0;c[k>>2]=l>>>0>e>>>0?e:l;l=b+15660|0;c[l>>2]=n;if((n|0)==2){KIb(g,24,2591104,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=c[l>>2]|0}else{p=n}if((p|0)==3){c[b+15996>>2]=1267576;c[b+16e3>>2]=1267608;c[b+15608>>2]=1;p=c[k>>2]|0;n=c[m>>2]|0;e=c[h>>2]|0;j=e+(p>>>3)|0;q=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(p&7);j=q>>>29;r=p+3|0;c[k>>2]=n>>>0>r>>>0?r:n;n=b+15616|0;c[n>>2]=j;if(q>>>0>2684354559>>>0){KIb(c[b+4>>2]|0,16,2333080,(o=i,i=i+8|0,c[o>>2]=j,o)|0);i=o;s=c[h>>2]|0}else{s=e}e=c[k>>2]|0;j=c[m>>2]|0;q=s+(e>>>3)|0;r=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(e&7)>>>30;q=e+2|0;c[k>>2]=j>>>0>q>>>0?q:j;j=b+15620|0;c[j>>2]=r;if((r|0)!=1){KIb(c[b+4>>2]|0,16,2327672,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}r=c[k>>2]|0;q=c[m>>2]|0;e=s+(r>>>3)|0;p=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(r&7)>>>29;e=r+3|0;c[k>>2]=q>>>0>e>>>0?e:q;q=b+15664|0;c[q>>2]=p;p=c[k>>2]|0;e=c[m>>2]|0;r=s+(p>>>3)|0;u=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(p&7)>>>27;r=p+5|0;c[k>>2]=e>>>0>r>>>0?r:e;e=b+15668|0;c[e>>2]=u;u=c[k>>2]|0;r=(d[s+(u>>>3)|0]|0)<<(u&7)>>>7;c[k>>2]=((u|0)<(c[m>>2]|0))+u;c[b+15624>>2]=r&1;r=c[k>>2]|0;u=c[m>>2]|0;p=s+(r>>>3)|0;v=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>20;p=r+12|0;c[k>>2]=u>>>0>p>>>0?p:u;c[b+15672>>2]=(v<<1)+2;v=c[k>>2]|0;u=c[m>>2]|0;p=s+(v>>>3)|0;r=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(v&7)>>>20;p=v+12|0;c[k>>2]=u>>>0>p>>>0?p:u;c[b+15676>>2]=(r<<1)+2;r=c[k>>2]|0;u=(d[s+(r>>>3)|0]|0)<<(r&7)>>>7;c[k>>2]=((r|0)<(c[m>>2]|0))+r;r=b+15628|0;c[r>>2]=u&1;u=c[k>>2]|0;p=(d[s+(u>>>3)|0]|0)<<(u&7)>>>7;c[k>>2]=((u|0)<(c[m>>2]|0))+u;u=b+15632|0;c[u>>2]=p&1;p=c[k>>2]|0;v=(d[s+(p>>>3)|0]|0)<<(p&7)>>>7;c[k>>2]=((p|0)<(c[m>>2]|0))+p;p=b+15636|0;c[p>>2]=v&1;v=c[k>>2]|0;w=(d[s+(v>>>3)|0]|0)<<(v&7)>>>7;c[k>>2]=((v|0)<(c[m>>2]|0))+v;v=b+15704|0;c[v>>2]=w&1;w=c[m>>2]|0;s=(c[k>>2]|0)+1|0;c[k>>2]=w>>>0>s>>>0?s:w;w=b+4|0;s=c[q>>2]|0;q=c[e>>2]|0;e=c[b+13836>>2]|0;x=c[j>>2]|0;j=c[r>>2]|0;y=c[u>>2]|0;u=c[p>>2]|0;p=c[v>>2]|0;KIb(c[w>>2]|0,48,2321840,(o=i,i=i+72|0,c[o>>2]=c[n>>2],c[o+8>>2]=s,c[o+16>>2]=q,c[o+24>>2]=e,c[o+32>>2]=x,c[o+40>>2]=j,c[o+48>>2]=y,c[o+56>>2]=u,c[o+64>>2]=p,o)|0);i=o;p=c[k>>2]|0;u=c[h>>2]|0;y=(d[u+(p>>>3)|0]|0)<<(p&7)>>>7;c[k>>2]=((p|0)<(c[m>>2]|0))+p;p=y&1;c[b+15656>>2]=p;y=c[w>>2]|0;if((p|0)!=0){KIb(y,16,2316808,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}c[y+156>>2]=7;c[b+68>>2]=7;p=c[k>>2]|0;j=d[u+(p>>>3)|0]|0;x=c[m>>2]|0;e=((p|0)<(x|0))+p|0;c[k>>2]=e;do{if((j&128>>>((p&7)>>>0)|0)==0){z=e;A=u;B=x}else{KIb(y,48,2312272,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;q=c[k>>2]|0;s=c[m>>2]|0;n=c[h>>2]|0;v=n+(q>>>3)|0;C=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(q&7)>>>18;v=q+14|0;q=s>>>0>v>>>0?v:s;c[k>>2]=q;v=C+1|0;C=n+(q>>>3)|0;n=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(q&7)>>>18;C=q+14|0;c[k>>2]=s>>>0>C>>>0?C:s;s=n+1|0;KIb(c[w>>2]|0,48,2307736,(o=i,i=i+16|0,c[o>>2]=v,c[o+8>>2]=s,o)|0);i=o;n=c[k>>2]|0;C=c[h>>2]|0;q=d[C+(n>>>3)|0]|0;D=c[m>>2]|0;E=((n|0)<(D|0))+n|0;c[k>>2]=E;do{if((q&128>>>((n&7)>>>0)|0)==0){F=16}else{G=C+(E>>>3)|0;H=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7);G=H>>>28;I=E+4|0;J=D>>>0>I>>>0?I:D;c[k>>2]=J;if((G|0)!=0&H>>>0<3758096384>>>0){H=1262592+(G<<3)|0;I=(c[w>>2]|0)+224|0;K=c[H+4>>2]|0;c[I>>2]=c[H>>2];c[I+4>>2]=K;break}if((G|0)!=15){F=16;break}G=C+(J>>>3)|0;K=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>>24;G=J+8|0;J=D>>>0>G>>>0?G:D;c[k>>2]=J;G=C+(J>>>3)|0;I=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>>24;G=J+8|0;c[k>>2]=D>>>0>G>>>0?G:D;G=c[w>>2]|0;c[G+224>>2]=K+1;c[G+228>>2]=I+1}}while(0);if((F|0)==16){D=c[w>>2]|0;C=ca(c[D+124>>2]|0,v)|0;E=ca(c[D+120>>2]|0,s)|0;xKb(D+224|0,D+228|0,C,(C|0)<0|0?-1:0,E,(E|0)<0|0?-1:0,1073741824,0)|0}E=c[w>>2]|0;C=c[E+228>>2]|0;KIb(E,48,2302112,(o=i,i=i+16|0,c[o>>2]=c[E+224>>2],c[o+8>>2]=C,o)|0);i=o;C=c[k>>2]|0;E=c[h>>2]|0;D=d[E+(C>>>3)|0]|0;n=c[m>>2]|0;q=((C|0)<(n|0))+C|0;c[k>>2]=q;do{if((D&128>>>((C&7)>>>0)|0)!=0){I=d[E+(q>>>3)|0]|0;G=((q|0)<(n|0))+q|0;c[k>>2]=G;do{if((I&128>>>((q&7)>>>0)|0)==0){K=E+(G>>>3)|0;J=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(G&7)>>>24;K=G+8|0;H=n>>>0>K>>>0?K:n;c[k>>2]=H;K=E+(H>>>3)|0;L=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;K=H+4|0;c[k>>2]=n>>>0>K>>>0?K:n;K=J-1|0;if(!(K>>>0<7>>>0)){break}J=((je(L|0)|0)<<(H&7)>>>28)-1|0;if(!(J>>>0<2>>>0)){break}H=c[w>>2]|0;c[H+104>>2]=c[1266096+(J<<2)>>2];c[H+108>>2]=(c[1266064+(K<<2)>>2]|0)*1e3|0}else{K=c[w>>2]|0;c[K+104>>2]=32;H=c[k>>2]|0;J=c[m>>2]|0;L=E+(H>>>3)|0;M=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(H&7)>>>16;L=H+16|0;c[k>>2]=J>>>0>L>>>0?L:J;c[K+108>>2]=M+1}}while(0);if((c[r>>2]|0)==0){break}G=c[w>>2]|0;I=G+108|0;c[I>>2]=c[I>>2]<<1;c[G+112>>2]=2}}while(0);n=c[k>>2]|0;q=d[E+(n>>>3)|0]|0;C=c[m>>2]|0;D=((n|0)<(C|0))+n|0;c[k>>2]=D;if((q&128>>>((n&7)>>>0)|0)==0){z=D;A=E;B=C;break}n=E+(D>>>3)|0;q=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(D&7)>>>24;n=D+8|0;D=C>>>0>n>>>0?n:C;c[k>>2]=D;n=c[w>>2]|0;c[n+384>>2]=q;q=E+(D>>>3)|0;s=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(D&7)>>>24;q=D+8|0;D=C>>>0>q>>>0?q:C;c[k>>2]=D;c[n+388>>2]=s;s=E+(D>>>3)|0;q=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(D&7)>>>24;s=D+8|0;D=C>>>0>s>>>0?s:C;c[k>>2]=D;c[n+392>>2]=q;c[n+396>>2]=1;z=D;A=E;B=C}}while(0);w=(d[A+(z>>>3)|0]|0)<<(z&7)>>>7;c[k>>2]=((z|0)<(B|0))+z;z=w&1;c[b+15652>>2]=z;if((z|0)==0){t=0;i=f;return t|0}z=c[k>>2]|0;w=c[m>>2]|0;B=A+(z>>>3)|0;A=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7)>>>27;B=z+5|0;c[k>>2]=w>>>0>B>>>0?B:w;w=b+19244|0;c[w>>2]=A;A=c[m>>2]|0;B=(c[k>>2]|0)+4|0;z=(A>>>0>B>>>0?B:A)+4|0;B=A>>>0>z>>>0?z:A;c[k>>2]=B;if((c[w>>2]|0)>0){N=0;O=B}else{t=0;i=f;return t|0}while(1){B=O+16|0;z=(A>>>0>B>>>0?B:A)+16|0;B=A>>>0>z>>>0?z:A;c[k>>2]=B;z=N+1|0;if((z|0)<(c[w>>2]|0)){N=z;O=B}else{t=0;break}}i=f;return t|0}c[b+15620>>2]=1;c[b+15996>>2]=1246232;c[b+16e3>>2]=1246168;O=c[k>>2]|0;N=c[h>>2]|0;w=(d[N+(O>>>3)|0]|0)<<(O&7)>>>7;c[k>>2]=((O|0)<(c[m>>2]|0))+O;O=b+15584|0;c[O>>2]=w&1;w=c[k>>2]|0;A=(d[N+(w>>>3)|0]|0)<<(w&7)>>>7;c[k>>2]=((w|0)<(c[m>>2]|0))+w;w=b+15580|0;c[w>>2]=A&1;if((c[O>>2]|0)!=0){KIb(g,16,2443744,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}O=c[k>>2]|0;A=c[m>>2]|0;B=N+(O>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(O&7)>>>29;B=O+3|0;c[k>>2]=A>>>0>B>>>0?B:A;A=b+15664|0;c[A>>2]=z;z=c[k>>2]|0;B=c[m>>2]|0;O=N+(z>>>3)|0;r=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(z&7)>>>27;O=z+5|0;c[k>>2]=B>>>0>O>>>0?O:B;B=b+15668|0;c[B>>2]=r;r=c[k>>2]|0;O=(d[N+(r>>>3)|0]|0)<<(r&7)>>>7;c[k>>2]=((r|0)<(c[m>>2]|0))+r;r=O&1;O=b+13836|0;c[O>>2]=r;do{if((r|0)!=0){if((c[l>>2]|0)!=0){break}KIb(g,16,2354984,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);r=b+4|0;if((c[(c[r>>2]|0)+848>>2]|0)>47){c[O>>2]=0}N=c[k>>2]|0;z=c[h>>2]|0;y=(d[z+(N>>>3)|0]|0)<<(N&7)>>>7;c[k>>2]=((N|0)<(c[m>>2]|0))+N;N=b+15588|0;c[N>>2]=y&1;y=c[k>>2]|0;x=(d[z+(y>>>3)|0]|0)<<(y&7)>>>7;c[k>>2]=((y|0)<(c[m>>2]|0))+y;y=b+15592|0;c[y>>2]=x&1;x=c[k>>2]|0;u=(d[z+(x>>>3)|0]|0)<<(x&7)>>>7;c[k>>2]=((x|0)<(c[m>>2]|0))+x;x=u&1;u=b+15596|0;c[u>>2]=x;if((x|0)==0){c[b+15332>>2]=386;c[b+15336>>2]=1788;c[b+15340>>2]=2060;c[b+15344>>2]=652;c[b+15348>>2]=240;c[b+15352>>2]=1788;c[b+15356>>2]=2060;c[b+15360>>2]=652;P=c[h>>2]|0}else{P=z}z=c[k>>2]|0;x=(d[P+(z>>>3)|0]|0)<<(z&7)>>>7;c[k>>2]=((z|0)<(c[m>>2]|0))+z;z=x&1;x=b+15680|0;c[x>>2]=z;if((z|c[l>>2]|0)==0){KIb(g,16,2292560,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}z=c[k>>2]|0;e=(d[P+(z>>>3)|0]|0)<<(z&7)>>>7;c[k>>2]=((z|0)<(c[m>>2]|0))+z;z=e&1;e=b+15684|0;c[e>>2]=z;if(!((c[l>>2]|0)!=0|(z|0)==0)){KIb(g,16,2241624,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}z=c[k>>2]|0;p=c[m>>2]|0;j=P+(z>>>3)|0;C=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(z&7)>>>30;j=z+2|0;c[k>>2]=p>>>0>j>>>0?j:p;p=b+15688|0;c[p>>2]=C;C=c[k>>2]|0;j=(d[P+(C>>>3)|0]|0)<<(C&7)>>>7;c[k>>2]=((C|0)<(c[m>>2]|0))+C;C=b+15692|0;c[C>>2]=j&1;j=c[k>>2]|0;z=(d[P+(j>>>3)|0]|0)<<(j&7)>>>7;c[k>>2]=((j|0)<(c[m>>2]|0))+j;j=z&1;c[b+15600>>2]=j;if((j|0)!=0){KIb(g,16,2200544,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}j=c[k>>2]|0;z=(d[P+(j>>>3)|0]|0)<<(j&7)>>>7;c[k>>2]=((j|0)<(c[m>>2]|0))+j;j=b+15696|0;c[j>>2]=z&1;z=c[k>>2]|0;D=(d[P+(z>>>3)|0]|0)<<(z&7)>>>7;c[k>>2]=((z|0)<(c[m>>2]|0))+z;z=b+19616|0;c[z>>2]=D&1;D=c[k>>2]|0;n=(d[P+(D>>>3)|0]|0)<<(D&7)>>>7;c[k>>2]=((D|0)<(c[m>>2]|0))+D;D=n&1;n=b+15604|0;c[n>>2]=D;do{if((D|0)==0){Q=P}else{if((c[l>>2]|0)!=0){Q=P;break}KIb(g,32,2168744,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;Q=c[h>>2]|0}}while(0);P=c[k>>2]|0;D=c[m>>2]|0;q=Q+(P>>>3)|0;s=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(P&7)>>>29;q=P+3|0;c[k>>2]=D>>>0>q>>>0?q:D;D=a+156|0;c[D>>2]=s;c[b+68>>2]=s;s=c[k>>2]|0;a=c[m>>2]|0;q=Q+(s>>>3)|0;P=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(s&7)>>>30;q=s+2|0;c[k>>2]=a>>>0>q>>>0?q:a;a=b+15700|0;c[a>>2]=P;P=c[k>>2]|0;q=(d[Q+(P>>>3)|0]|0)<<(P&7)>>>7;c[k>>2]=((P|0)<(c[m>>2]|0))+P;c[b+15704>>2]=q&1;q=c[k>>2]|0;do{if((c[w>>2]|0)==0){P=(d[Q+(q>>>3)|0]|0)<<(q&7)>>>7;c[k>>2]=((q|0)<(c[m>>2]|0))+q;s=P&1;c[b+15608>>2]=s;if((s|0)==0){F=53}}else{s=c[m>>2]|0;P=Q+(q>>>3)|0;v=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(q&7)>>>21;P=q+11|0;G=s>>>0>P>>>0?P:s;c[k>>2]=G;P=Q+(G>>>3)|0;I=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(G&7)>>>21;P=G+11|0;c[k>>2]=s>>>0>P>>>0?P:s;G4a(c[r>>2]|0,v,I);I=c[m>>2]|0;v=(c[k>>2]|0)+5|0;s=I>>>0>v>>>0?v:I;c[k>>2]=s;v=c[h>>2]|0;P=(d[v+(s>>>3)|0]|0)<<(s&7)>>>7;c[k>>2]=((s|0)<(I|0))+s;c[N>>2]=P&1;P=c[k>>2]|0;s=d[v+(P>>>3)|0]|0;v=c[m>>2]|0;I=((P|0)<(v|0))+P|0;c[k>>2]=I;if((s&128>>>((P&7)>>>0)|0)==0){P=I+3|0;c[k>>2]=v>>>0>P>>>0?P:v;c[b+15608>>2]=0;F=53;break}KIb(g,16,2141968,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;t=-1;i=f;return t|0}}while(0);if((F|0)==53){KIb(g,16,2118416,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}if((c[u>>2]|0)==0){u=c[m>>2]|0;m=(c[k>>2]|0)+16|0;c[k>>2]=u>>>0>m>>>0?m:u}u=c[A>>2]|0;A=c[B>>2]|0;B=c[O>>2]|0;O=c[y>>2]|0;y=c[x>>2]|0;x=c[e>>2]|0;e=c[n>>2]|0;n=c[C>>2]|0;C=c[j>>2]|0;j=c[z>>2]|0;z=c[p>>2]|0;p=c[a>>2]|0;a=c[D>>2]|0;KIb(g,48,2636440,(o=i,i=i+112|0,c[o>>2]=c[l>>2],c[o+8>>2]=u,c[o+16>>2]=A,c[o+24>>2]=B,c[o+32>>2]=O,c[o+40>>2]=y,c[o+48>>2]=x,c[o+56>>2]=e,c[o+64>>2]=n,c[o+72>>2]=C,c[o+80>>2]=j,c[o+88>>2]=z,c[o+96>>2]=p,c[o+104>>2]=a,o)|0);i=o;t=0;i=f;return t|0}function L6a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=i;h=b;j=f|0;k=c[j>>2]|0;l=f+8|0;m=c[l>>2]|0;n=f+16|0;f=c[n>>2]|0;o=k+(m>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(m&7)&-65536;o=m+16|0;m=f>>>0>o>>>0?o:f;f=k+(m>>>3)|0;k=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(m&7)>>>16|p;KIb(h,48,2613128,(p=i,i=i+8|0,c[p>>2]=k,p)|0);i=p;k=c[l>>2]|0;m=(d[(c[j>>2]|0)+(k>>>3)|0]|0)<<(k&7)>>>7;c[l>>2]=((k|0)<(c[n>>2]|0))+k;k=e+19605|0;a[k]=m&1;m=c[l>>2]|0;f=(d[(c[j>>2]|0)+(m>>>3)|0]|0)<<(m&7)>>>7;c[l>>2]=((m|0)<(c[n>>2]|0))+m;m=e+19606|0;a[m]=f&1;f=c[l>>2]|0;o=c[j>>2]|0;q=(d[o+(f>>>3)|0]|0)<<(f&7)>>>7;c[l>>2]=((f|0)<(c[n>>2]|0))+f;f=e+15640|0;c[f>>2]=q&1;q=c[l>>2]|0;r=(d[o+(q>>>3)|0]|0)<<(q&7)>>>7;c[l>>2]=((q|0)<(c[n>>2]|0))+q;q=e+15644|0;c[q>>2]=r&1;r=c[l>>2]|0;s=(d[o+(r>>>3)|0]|0)<<(r&7)>>>7;c[l>>2]=((r|0)<(c[n>>2]|0))+r;r=e+13836|0;c[r>>2]=s&1;if((c[(c[e+4>>2]|0)+848>>2]|0)>47){c[r>>2]=0}s=c[l>>2]|0;t=(d[o+(s>>>3)|0]|0)<<(s&7)>>>7;c[l>>2]=((s|0)<(c[n>>2]|0))+s;s=e+15680|0;c[s>>2]=t&1;t=c[l>>2]|0;u=(d[o+(t>>>3)|0]|0)<<(t&7)>>>7;c[l>>2]=((t|0)<(c[n>>2]|0))+t;t=e+15684|0;c[t>>2]=u&1;u=c[l>>2]|0;v=c[n>>2]|0;w=o+(u>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>30;w=u+2|0;c[l>>2]=v>>>0>w>>>0?w:v;v=e+15688|0;c[v>>2]=x;x=c[l>>2]|0;w=(d[o+(x>>>3)|0]|0)<<(x&7)>>>7;c[l>>2]=((x|0)<(c[n>>2]|0))+x;x=e+15692|0;c[x>>2]=w&1;w=c[l>>2]|0;u=(d[o+(w>>>3)|0]|0)<<(w&7)>>>7;c[l>>2]=((w|0)<(c[n>>2]|0))+w;w=e+15696|0;c[w>>2]=u&1;u=c[l>>2]|0;y=c[n>>2]|0;z=o+(u>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(u&7)>>>30;z=u+2|0;c[l>>2]=y>>>0>z>>>0?z:y;y=e+15700|0;c[y>>2]=A;do{if((c[e+15652>>2]|0)!=0){A=e+19244|0;if((c[A>>2]|0)<=0){break}z=c[n>>2]|0;u=0;B=c[l>>2]|0;do{C=B+8|0;B=z>>>0>C>>>0?C:z;c[l>>2]=B;u=u+1|0;}while((u|0)<(c[A>>2]|0))}}while(0);A=c[l>>2]|0;u=d[o+(A>>>3)|0]|0;B=c[n>>2]|0;z=((A|0)<(B|0))+A|0;c[l>>2]=z;if((u&128>>>((A&7)>>>0)|0)==0){D=c[e+15676>>2]|0;E=c[e+15672>>2]|0}else{A=o+(z>>>3)|0;u=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7)>>>20;A=z+12|0;z=B>>>0>A>>>0?A:B;c[l>>2]=z;A=o+(z>>>3)|0;o=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7)>>>20;A=z+12|0;c[l>>2]=B>>>0>A>>>0?A:B;D=(o<<1)+2|0;E=(u<<1)+2|0}G4a(b,E,D);if((c[t>>2]|0)==0){F=c[j>>2]|0}else{D=c[l>>2]|0;E=c[j>>2]|0;b=(d[E+(D>>>3)|0]|0)<<(D&7)>>>7;c[l>>2]=((D|0)<(c[n>>2]|0))+D;c[e+15648>>2]=b&1;F=E}E=c[l>>2]|0;b=(d[F+(E>>>3)|0]|0)<<(E&7)>>>7;c[l>>2]=((E|0)<(c[n>>2]|0))+E;E=b&1;a[e+19284|0]=E;if(!(E<<24>>24==0)){KIb(h,16,2586360,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;E=c[l>>2]|0;b=c[n>>2]|0;F=(c[j>>2]|0)+(E>>>3)|0;D=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>29;F=E+3|0;c[l>>2]=b>>>0>F>>>0?F:b;a[e+19286|0]=D}D=c[l>>2]|0;b=(d[(c[j>>2]|0)+(D>>>3)|0]|0)<<(D&7)>>>7;c[l>>2]=((D|0)<(c[n>>2]|0))+D;D=b&1;a[e+19285|0]=D;if(D<<24>>24==0){G=a[k]|0;H=G&255;I=a[m]|0;J=I&255;K=c[f>>2]|0;L=c[q>>2]|0;M=c[r>>2]|0;N=c[s>>2]|0;O=c[t>>2]|0;P=c[v>>2]|0;Q=c[x>>2]|0;R=c[w>>2]|0;S=c[y>>2]|0;KIb(h,48,2547280,(p=i,i=i+88|0,c[p>>2]=H,c[p+8>>2]=J,c[p+16>>2]=K,c[p+24>>2]=L,c[p+32>>2]=M,c[p+40>>2]=N,c[p+48>>2]=O,c[p+56>>2]=P,c[p+64>>2]=Q,c[p+72>>2]=R,c[p+80>>2]=S,p)|0);i=p;i=g;return 0}KIb(h,16,2565480,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;D=c[l>>2]|0;b=c[n>>2]|0;n=(c[j>>2]|0)+(D>>>3)|0;j=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(D&7)>>>29;n=D+3|0;c[l>>2]=b>>>0>n>>>0?n:b;a[e+19287|0]=j;G=a[k]|0;H=G&255;I=a[m]|0;J=I&255;K=c[f>>2]|0;L=c[q>>2]|0;M=c[r>>2]|0;N=c[s>>2]|0;O=c[t>>2]|0;P=c[v>>2]|0;Q=c[x>>2]|0;R=c[w>>2]|0;S=c[y>>2]|0;KIb(h,48,2547280,(p=i,i=i+88|0,c[p>>2]=H,c[p+8>>2]=J,c[p+16>>2]=K,c[p+24>>2]=L,c[p+32>>2]=M,c[p+40>>2]=N,c[p+48>>2]=O,c[p+56>>2]=P,c[p+64>>2]=Q,c[p+72>>2]=R,c[p+80>>2]=S,p)|0);i=p;i=g;return 0}function M6a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=i;i=i+1024|0;h=g|0;j=g+512|0;c[e+19428>>2]=0;c[e+19224>>2]=0;if((c[e+15704>>2]|0)!=0){k=f+8|0;l=c[k>>2]|0;m=d[(c[f>>2]|0)+(l>>>3)|0]<<(l&7)>>>7;c[k>>2]=((l|0)<(c[f+16>>2]|0))+l;a[e+19221|0]=m&1}m=e+4|0;l=c[m>>2]|0;if((c[l+12>>2]|0)==0){n=-1;i=g;return n|0}k=f+8|0;o=c[k>>2]|0;p=f+16|0;q=c[p>>2]|0;if((c[l+48>>2]|0)==168){r=(c[f>>2]|0)+(o>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(o&7);r=o+2|0;c[k>>2]=q>>>0>r>>>0?r:q;r=(s&-1073741824|0)==1073741824;s=r&1;c[e+15592>>2]=s;c[e+15604>>2]=s;a[e+16073|0]=r&1;t=s}else{s=o+2|0;c[k>>2]=q>>>0>s>>>0?s:q;t=c[e+15604>>2]|0}q=e+19220|0;a[q]=0;if((t|0)==0){u=f|0}else{t=c[k>>2]|0;s=f|0;f=d[(c[s>>2]|0)+(t>>>3)|0]<<(t&7)>>>7;c[k>>2]=((t|0)<(c[p>>2]|0))+t;a[q]=f&1;u=s}s=c[k>>2]|0;f=c[u>>2]|0;q=d[f+(s>>>3)|0]<<(s&7)>>>7;c[k>>2]=((s|0)<(c[p>>2]|0))+s;s=q&1;q=e+9992|0;c[q>>2]=s;a:do{if((c[l+156>>2]|0)==0){t=s+1|0;c[q>>2]=t;o=e+19548|0;c[o>>2]=0;if((t|0)==3){v=o;w=18}else{x=t;y=o;w=23}}else{do{if((s|0)==0){o=c[k>>2]|0;t=d[f+(o>>>3)|0]|0;c[k>>2]=((o|0)<(c[p>>2]|0))+o;if((t&128>>>((o&7)>>>0)|0)==0){c[q>>2]=3;o=e+19548|0;c[o>>2]=0;v=o;w=18;break a}else{z=1;A=1;break}}else{z=2;A=2}}while(0);c[q>>2]=A;o=e+19548|0;c[o>>2]=0;x=z;y=o;w=23}}while(0);do{if((w|0)==18){z=c[1552043]|0;A=c[k>>2]|0;s=c[p>>2]|0;o=f+(A>>>3)|0;t=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(A&7)>>>25;o=b[z+(t<<2)>>1]|0;r=(b[z+(t<<2)+2>>1]|0)+A|0;c[k>>2]=s>>>0>r>>>0?r:s;if(o<<16>>16==21|o<<16>>16<0){KIb(l,16,2338744,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;n=-1094995529;i=g;return n|0}a[e+19604|0]=o;s=b[1267424+((o&255)<<1)>>1]|0;b[e+16070>>1]=s;if(s<<16>>16==0){c[q>>2]=7;C=v;w=24;break}else{x=c[q>>2]|0;y=v;w=23;break}}}while(0);if((w|0)==23){if((x|0)==1|(x|0)==7){C=y;w=24}else{D=y}}if((w|0)==24){y=c[p>>2]|0;x=(c[k>>2]|0)+7|0;c[k>>2]=y>>>0>x>>>0?x:y;D=C}if((c[e+19612>>2]|0)!=0){n=0;i=g;return n|0}C=c[q>>2]|0;if((C|0)==2){w=28}else if((C|0)==1|(C|0)==7){c[e+19216>>2]=1;if((C|0)==2){w=28}}if((w|0)==28){C=e+19216|0;c[C>>2]=c[C>>2]^1}C=c[k>>2]|0;y=c[p>>2]|0;x=(c[u>>2]|0)+(C>>>3)|0;v=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(C&7);x=v>>>27;l=C+5|0;c[k>>2]=y>>>0>l>>>0?l:y;if((x|0)==0){n=-1;i=g;return n|0}y=e+15700|0;l=c[y>>2]|0;if((l|0)==0){a[e+15728|0]=a[1262496+x|0]|0;E=v>>>0<1207959552>>>0}else{a[e+15728|0]=a[1262528+x|0]|0;E=(l|0)!=2}C=e+16081|0;a[C]=E&1;c[e+16040>>2]=x;if(v>>>0<1207959552>>>0){v=c[k>>2]|0;x=d[(c[u>>2]|0)+(v>>>3)|0]<<(v&7)>>>7;c[k>>2]=((v|0)<(c[p>>2]|0))+v;a[e+16072|0]=x&1;F=c[y>>2]|0}else{a[e+16072|0]=0;F=l}if((F|0)==1){F=c[k>>2]|0;l=d[(c[u>>2]|0)+(F>>>3)|0]<<(F&7)>>>7;c[k>>2]=((F|0)<(c[p>>2]|0))+F;a[C]=l&1}a[e+16004|0]=0;if((c[e+15684>>2]|0)==1){l=0;while(1){if((l|0)>=3){break}C=c[k>>2]|0;F=d[(c[u>>2]|0)+(C>>>3)|0]|0;c[k>>2]=((C|0)<(c[p>>2]|0))+C;if((F&128>>>((C&7)>>>0)|0)==0){break}else{l=l+1|0}}C=l&255;a[e+16080|0]=C;G=C}else{G=a[e+16080|0]|0}C=G&255;G=C+9+(C>>>1)|0;c[e+15712>>2]=G;c[e+15716>>2]=C+8;c[e+15720>>2]=1<<G-1;c[e+15724>>2]=1<<C+7;do{if((c[e+15592>>2]|0)!=0){if((c[q>>2]|0)==3){break}C=c[k>>2]|0;G=c[p>>2]|0;l=(c[u>>2]|0)+(C>>>3)|0;F=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(C&7)>>>30;l=C+2|0;c[k>>2]=G>>>0>l>>>0?l:G;a[e+16073|0]=F}}while(0);do{if((c[e+15588>>2]|0)==0){w=49}else{F=c[q>>2]|0;if(!((F|0)==1|(F|0)==7)){w=49;break}F=c[k>>2]|0;G=d[(c[u>>2]|0)+(F>>>3)|0]<<(F&7)>>>7;c[k>>2]=((F|0)<(c[p>>2]|0))+F;c[e+19552>>2]=G&1}}while(0);if((w|0)==49){c[e+19552>>2]=0}if((c[e+19492>>2]|0)!=0){G=h|0;h=j|0;j=c[q>>2]|0;if((j|0)==7|(j|0)==3){c[e+19204>>2]=e+19212}else{F=e+19200|0;l=c[F>>2]|0;C=e+19208|0;c[F>>2]=c[C>>2];c[C>>2]=l;c[e+19204>>2]=C}if((j|0)==7|(j|0)==3){C=e+17144|0;c[e+19192>>2]=C;H=C}else{C=e+16120|0;nrc(G|0,C|0,512)|0;l=e+18168|0;F=l|0;nrc(C|0,F|0,512)|0;nrc(F|0,G|0,512)|0;G=l|0;c[e+19192>>2]=G;H=G}if((j|0)==7|(j|0)==3){c[e+19196>>2]=e+17656}else{j=e+16632|0;nrc(h|0,j|0,512)|0;G=e+18680|0;l=G|0;nrc(j|0,l|0,512)|0;nrc(l|0,h|0,512)|0;c[e+19196>>2]=G}G=e+19192|0;h=e+19196|0;l=0;j=H;while(1){H=l&255;a[j+l|0]=H;a[(c[h>>2]|0)+l|0]=H;H=l+1|0;if((H|0)>=256){I=0;break}l=H;j=c[G>>2]|0}do{j=I&255;a[(c[G>>2]|0)+256+I|0]=j;a[(c[h>>2]|0)+256+I|0]=j;I=I+1|0;}while((I|0)<256);c[c[e+19204>>2]>>2]=0;}I=c[q>>2]|0;do{if((I|0)==2){h=a[e+15728|0]|0;do{if((h&255)>>>0<5>>>0){c[e+16088>>2]=0}else{G=e+16088|0;if((h&255)>>>0<13>>>0){c[G>>2]=1;break}else{c[G>>2]=2;break}}}while(0);G=(h&255)>>>0<13>>>0|0;j=0;while(1){if((j|0)>=4){break}l=c[k>>2]|0;H=d[(c[u>>2]|0)+(l>>>3)|0]|0;c[k>>2]=((l|0)<(c[p>>2]|0))+l;if((H&128>>>((l&7)>>>0)|0)==0){j=j+1|0}else{break}}h=a[1262936+(G*5|0)+j|0]|0;l=e+15708|0;a[l]=h;if(h<<24>>24==4){H=0;while(1){if((H|0)>=3){break}F=c[k>>2]|0;C=d[(c[u>>2]|0)+(F>>>3)|0]|0;c[k>>2]=((F|0)<(c[p>>2]|0))+F;if((C&128>>>((F&7)>>>0)|0)==0){H=H+1|0}else{break}}a[e+15709|0]=a[1262928+(G<<2)+H|0]|0;j=c[k>>2]|0;F=c[p>>2]|0;C=(c[u>>2]|0)+(j>>>3)|0;y=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(j&7)>>>26;C=j+6|0;c[k>>2]=F>>>0>C>>>0?C:F;F=e+16068|0;a[F]=y;y=c[k>>2]|0;C=c[p>>2]|0;j=(c[u>>2]|0)+(y>>>3)|0;x=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(y&7)>>>26;j=y+6|0;c[k>>2]=C>>>0>j>>>0?j:C;C=x&255;j=e+16069|0;a[j]=C;c[e+19200>>2]=1;y=a[F]|0;do{if(y<<24>>24==0){v=x<<7^16320;if(!((C&255)>>>0>31>>>0)){J=-64;K=v;break}J=-64;K=v+8192|0}else{v=(y&255)+32|0;E=x<<6;if(!((C&255)>>>0>31>>>0)){J=v;K=E;break}J=v;K=E|-4096}}while(0);C=K+32|0;x=0;do{y=e+16120+x|0;H=e+16632+x|0;G=d[H]|0;E=C+(ca(d[y]|0,J)|0)>>6;if(E>>>0>255>>>0){L=-E>>31&255}else{L=E&255}a[y]=L;y=(ca(G-128|0,J)|0)+8224>>6;if(y>>>0>255>>>0){M=-y>>31&255}else{M=y&255}a[H]=M;x=x+1|0;}while((x|0)<256);x=a[F]|0;do{if(x<<24>>24==0){C=a[j]|0;H=255-((C&255)<<1)<<6;if(!((C&255)>>>0>31>>>0)){N=H;O=-64;break}N=H+8192|0;O=-64}else{H=(x&255)+32|0;C=a[j]|0;y=(C&255)<<6;if(!((C&255)>>>0>31>>>0)){N=y;O=H;break}N=y-4096|0;O=H}}while(0);j=N+32|0;x=0;do{F=e+16376+x|0;H=e+16888+x|0;y=d[H]|0;C=j+(ca(d[F]|0,O)|0)>>6;if(C>>>0>255>>>0){P=-C>>31&255}else{P=C&255}a[F]=P;F=(ca(y-128|0,O)|0)+8224>>6;if(F>>>0>255>>>0){Q=-F>>31&255}else{Q=F&255}a[H]=Q;x=x+1|0;}while((x|0)<256);R=a[l]|0}else{R=h}x=e+13924|0;c[e+19476>>2]=c[x>>2];do{if((R<<24>>24|0)==2|(R<<24>>24|0)==0){c[x>>2]=0;w=106}else if((R<<24>>24|0)==4){j=a[e+15709|0]|0;if((j<<24>>24|0)==2|(j<<24>>24|0)==0){c[x>>2]=0;w=108;break}else{c[x>>2]=1;w=106;break}}else{c[x>>2]=1;w=106}}while(0);do{if((w|0)==106){if((R<<24>>24|0)==4){w=108;break}else if((R<<24>>24|0)!=0){S=1;w=109;break}c[e+14116>>2]=0;w=113}}while(0);if((w|0)==108){S=(a[e+15709|0]|0)!=0|0;w=109}do{if((w|0)==109){c[e+14116>>2]=S;if((R<<24>>24|0)==4){if((a[e+15709|0]|0)!=3){w=113;break}}else if((R<<24>>24|0)!=3){w=113;break}x=N6a(c[e+16092>>2]|0,e+16104|0,e)|0;if((x|0)<0){n=-1;i=g;return n|0}else{KIb(c[m>>2]|0,48,2529584,(B=i,i=i+16|0,c[B>>2]=x>>1,c[B+8>>2]=x&1,B)|0);i=B;break}}}while(0);if((w|0)==113){c[e+16104>>2]=0;mrc(c[e+16092>>2]|0,0,ca(c[e+120>>2]|0,c[e+124>>2]|0)|0)|0}x=N6a(c[e+9928>>2]|0,e+16116|0,e)|0;if((x|0)<0){n=-1;i=g;return n|0}KIb(c[m>>2]|0,48,2514336,(B=i,i=i+16|0,c[B>>2]=x>>1,c[B+8>>2]=x&1,B)|0);i=B;x=c[k>>2]|0;h=c[p>>2]|0;l=c[u>>2]|0;j=l+(x>>>3)|0;H=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(x&7)>>>30;j=x+2|0;c[k>>2]=h>>>0>j>>>0?j:h;c[e+14060>>2]=H;H=c[k>>2]|0;h=c[p>>2]|0;j=l+(H>>>3)|0;l=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(H&7)>>>30;j=H+2|0;c[k>>2]=h>>>0>j>>>0?j:h;c[e+16084>>2]=6208088+(l*20|0);if((c[e+15688>>2]|0)!=0){KIb(c[m>>2]|0,48,2500608,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;O6a(e)}l=e+16016|0;c[l>>2]=0;if((c[e+15692>>2]|0)==0){a[e+16020|0]=1;c[l>>2]=0;break}h=c[k>>2]|0;j=d[(c[u>>2]|0)+(h>>>3)|0]<<(h&7)>>>7;c[k>>2]=((h|0)<(c[p>>2]|0))+h;h=j&1;a[e+16020|0]=h;if(h<<24>>24==0){break}h=c[k>>2]|0;j=c[p>>2]|0;H=(c[u>>2]|0)+(h>>>3)|0;x=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(h&7)>>>30;H=h+2|0;c[k>>2]=j>>>0>H>>>0?H:j;c[l>>2]=c[1262224+(x<<2)>>2]}else if((I|0)==3){x=a[e+15728|0]|0;do{if((x&255)>>>0<5>>>0){c[e+16088>>2]=0}else{l=e+16088|0;if((x&255)>>>0<13>>>0){c[l>>2]=1;break}else{c[l>>2]=2;break}}}while(0);x=c[k>>2]|0;l=d[(c[u>>2]|0)+(x>>>3)|0]<<(x&7);c[k>>2]=((x|0)<(c[p>>2]|0))+x;x=l>>>7&1;a[e+15708|0]=x;l=e+13924|0;c[e+19476>>2]=c[l>>2];j=x&255;c[l>>2]=j;c[e+14116>>2]=j;j=N6a(c[e+16096>>2]|0,e+16108|0,e)|0;if((j|0)<0){n=-1;i=g;return n|0}KIb(c[m>>2]|0,48,2487872,(B=i,i=i+16|0,c[B>>2]=j>>1,c[B+8>>2]=j&1,B)|0);i=B;j=N6a(c[e+9928>>2]|0,e+16116|0,e)|0;if((j|0)<0){n=-1;i=g;return n|0}KIb(c[m>>2]|0,48,2514336,(B=i,i=i+16|0,c[B>>2]=j>>1,c[B+8>>2]=j&1,B)|0);i=B;j=c[k>>2]|0;l=c[p>>2]|0;x=c[u>>2]|0;H=x+(j>>>3)|0;h=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(j&7)>>>30;H=j+2|0;c[k>>2]=l>>>0>H>>>0?H:l;c[e+14060>>2]=h;h=c[k>>2]|0;l=c[p>>2]|0;H=x+(h>>>3)|0;x=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(h&7)>>>30;H=h+2|0;c[k>>2]=l>>>0>H>>>0?H:l;c[e+16084>>2]=6208088+(x*20|0);if((c[e+15688>>2]|0)!=0){KIb(c[m>>2]|0,48,2500608,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;O6a(e)}x=e+16016|0;c[x>>2]=0;if((c[e+15692>>2]|0)==0){a[e+16020|0]=1;c[x>>2]=0;break}l=c[k>>2]|0;H=d[(c[u>>2]|0)+(l>>>3)|0]<<(l&7)>>>7;c[k>>2]=((l|0)<(c[p>>2]|0))+l;l=H&1;a[e+16020|0]=l;if(l<<24>>24==0){break}l=c[k>>2]|0;H=c[p>>2]|0;h=(c[u>>2]|0)+(l>>>3)|0;j=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(l&7)>>>30;h=l+2|0;c[k>>2]=H>>>0>h>>>0?h:H;c[x>>2]=c[1262224+(j<<2)>>2]}}while(0);if((c[e+19552>>2]|0)==0){B=c[k>>2]|0;m=c[u>>2]|0;u=d[m+(B>>>3)|0]|0;I=c[p>>2]|0;w=((B|0)<(I|0))+B|0;c[k>>2]=w;if((u&128>>>((B&7)>>>0)|0)==0){T=0}else{B=d[m+(w>>>3)|0]<<(w&7)>>>7;c[k>>2]=((w|0)<(I|0))+w;T=(B&1)+1|0}c[e+16008>>2]=T;T=c[q>>2]|0;if((T|0)==1|(T|0)==7){T=c[k>>2]|0;B=d[m+(T>>>3)|0]|0;w=c[p>>2]|0;I=((T|0)<(w|0))+T|0;c[k>>2]=I;if((B&128>>>((T&7)>>>0)|0)==0){U=0}else{T=d[m+(I>>>3)|0]<<(I&7)>>>7;c[k>>2]=((I|0)<(w|0))+I;U=(T&1)+1|0}c[e+16012>>2]=U}U=c[k>>2]|0;T=d[m+(U>>>3)|0]<<(U&7)>>>7;c[k>>2]=((U|0)<(c[p>>2]|0))+U;c[e+14072>>2]=T&1}if((c[q>>2]|0)!=7){n=0;i=g;return n|0}c[q>>2]=3;c[D>>2]=1;n=0;i=g;return n|0}function N6a(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;h=i;j=g+14120|0;k=c[g+116>>2]|0;l=c[g+120>>2]>>c[g+19428>>2];m=c[g+124>>2]|0;n=g+14128|0;o=c[n>>2]|0;p=j|0;q=c[p>>2]|0;r=d[q+(o>>>3)|0]<<(o&7)>>>7;s=g+14136|0;t=c[s>>2]|0;u=((o|0)<(t|0))+o|0;c[n>>2]=u;o=r&1;r=c[1551897]|0;v=q+(u>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(u&7)>>>28;v=b[r+(w<<2)>>1]|0;x=(b[r+(w<<2)+2>>1]|0)+u|0;c[n>>2]=t>>>0>x>>>0?x:t;c[f>>2]=0;a:do{switch(v|0){case 4:case 3:{t=(k|0)%3|0;do{if(((l|0)%3|0|0)==0){if((t|0)==0){y=0;break}x=(l|0)>0;u=k&1;b:do{if(x){w=(u|0)<(k|0);r=m*3|0;z=m<<1;A=e;B=0;c:while(1){if(w){C=u;do{D=c[1518745]|0;E=c[n>>2]|0;F=c[s>>2]|0;G=c[p>>2]|0;H=G+(E>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>23;H=b[D+(I<<2)>>1]|0;J=b[D+(I<<2)+2>>1]|0;I=J<<16>>16;if(J<<16>>16<0){J=E+9|0;K=F>>>0>J>>>0?J:F;J=G+(K>>>3)|0;G=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(K&7)>>>((I+32|0)>>>0))+H|0;L=b[D+(G<<2)+2>>1]|0;M=b[D+(G<<2)>>1]|0;N=K}else{L=I;M=H;N=E}E=L+N|0;c[n>>2]=F>>>0>E>>>0?E:F;if((M|0)<0){break c}a[A+C|0]=M&1;F=C+1|0;a[A+F|0]=M>>>1&1;a[A+(C+m)|0]=M>>>2&1;a[A+(F+m)|0]=M>>>3&1;a[A+(C+z)|0]=M>>>4&1;a[A+(F+z)|0]=M>>>5&1;C=C+2|0;}while((C|0)<(k|0))}C=B+3|0;if((C|0)<(l|0)){A=A+r|0;B=C}else{break b}}KIb(c[g+4>>2]|0,48,2344760,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;P=-1;i=h;return P|0}}while(0);if((u|0)==0){Q=46;break a}if(!x){B=c[n>>2]|0;c[n>>2]=((B|0)<(c[s>>2]|0))+B;Q=46;break a}B=c[n>>2]|0;r=c[p>>2]|0;A=d[r+(B>>>3)|0]|0;z=c[s>>2]|0;w=((B|0)<(z|0))+B|0;c[n>>2]=w;if((A&128>>>((B&7)>>>0)|0)==0){B=0;while(1){a[e+(ca(B,m)|0)|0]=0;A=B+1|0;if((A|0)<(l|0)){B=A}else{Q=46;break a}}}else{R=0;S=w;T=r;U=z}while(1){B=d[T+(S>>>3)|0]<<(S&7)>>>7;c[n>>2]=((S|0)<(U|0))+S;a[e+(ca(R,m)|0)|0]=B&1;B=R+1|0;if((B|0)>=(l|0)){Q=46;break a}R=B;S=c[n>>2]|0;T=c[p>>2]|0;U=c[s>>2]|0}}else{y=t}}while(0);t=l&1;d:do{if((t|0)<(l|0)){z=(y|0)<(k|0);r=m<<1;w=e+(m&-t)|0;B=t;e:while(1){if(z){x=y;do{u=c[1518745]|0;A=c[n>>2]|0;C=c[s>>2]|0;F=c[p>>2]|0;E=F+(A>>>3)|0;H=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(A&7)>>>23;E=b[u+(H<<2)>>1]|0;I=b[u+(H<<2)+2>>1]|0;H=I<<16>>16;if(I<<16>>16<0){I=A+9|0;K=C>>>0>I>>>0?I:C;I=F+(K>>>3)|0;F=((je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(K&7)>>>((H+32|0)>>>0))+E|0;V=b[u+(F<<2)+2>>1]|0;W=b[u+(F<<2)>>1]|0;X=K}else{V=H;W=E;X=A}A=V+X|0;c[n>>2]=C>>>0>A>>>0?A:C;if((W|0)<0){break e}a[w+x|0]=W&1;C=x+1|0;a[w+C|0]=W>>>1&1;A=x+2|0;a[w+A|0]=W>>>2&1;a[w+(x+m)|0]=W>>>3&1;a[w+(C+m)|0]=W>>>4&1;a[w+(A+m)|0]=W>>>5&1;x=x+3|0;}while((x|0)<(k|0))}x=B+2|0;if((x|0)<(l|0)){w=w+r|0;B=x}else{break d}}KIb(c[g+4>>2]|0,48,2344760,(O=i,i=i+1|0,i=i+7&-8,c[O>>2]=0,O)|0);i=O;P=-1;i=h;return P|0}}while(0);if((y|0)!=0){R6a(e,y,l,m,j)}if((t|0)==0){Q=46;break a}S6a(e+y|0,k-y|0,1,m,j);Q=46;break};case 5:{S6a(e,k,l,m,j);Q=58;break};case 0:{c[f>>2]=1;P=o;i=h;return P|0};case 2:case 1:{B=ca(l,k)|0;do{if((B&1|0)==0){Y=0;Z=e;_=0}else{r=c[n>>2]|0;w=d[q+(r>>>3)|0]<<(r&7)>>>7;c[n>>2]=((r|0)<(c[s>>2]|0))+r;a[e]=w&1;if((k|0)!=1){Y=1;Z=e+1|0;_=1;break}Y=1;Z=e+m|0;_=0}}while(0);if((Y|0)>=(B|0)){Q=46;break a}t=1-k+m|0;w=_;r=Z;z=Y;while(1){x=c[1518751]|0;A=c[n>>2]|0;C=c[s>>2]|0;E=(c[p>>2]|0)+(A>>>3)|0;H=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(A&7)>>>29;E=b[x+(H<<2)>>1]|0;K=(b[x+(H<<2)+2>>1]|0)+A|0;c[n>>2]=C>>>0>K>>>0?K:C;a[r]=E&1;C=w+1|0;if((C|0)==(k|0)){$=r+t|0;aa=0}else{$=r+1|0;aa=C}a[$]=(E&65535)>>>1;E=aa+1|0;if((E|0)==(k|0)){ba=$+t|0;da=0}else{ba=$+1|0;da=E}E=z+2|0;if((E|0)<(B|0)){w=da;r=ba;z=E}else{Q=46;break}}break};case 6:{R6a(e,k,l,m,j);Q=58;break};default:{Q=58}}}while(0);f:do{if((Q|0)==46){if(!((v|0)==4|(v|0)==2)){Q=58;break}j=(d[e]^o)&255;a[e]=j;ba=(k|0)>1;if(ba){da=1;$=j;do{j=e+da|0;$=a[j]^$;a[j]=$;da=da+1|0;}while((da|0)<(k|0))}if((l|0)<=1){break}da=m-1|0;$=e;j=2;while(1){aa=$+m|0;a[aa]=a[aa]^a[$];if(ba){n=1;do{p=a[$+(da+n)|0]|0;s=$+(n+m)|0;Y=a[s]|0;if(p<<24>>24==(a[$+n|0]|0)){ea=Y^p}else{ea=(Y&255^o)&255}a[s]=ea;n=n+1|0;}while((n|0)<(k|0))}if((j|0)>=(l|0)){break f}$=aa;j=j+1|0}}}while(0);do{if((Q|0)==58){if((o|0)==0){break}k=ca(m,l)|0;if((k|0)>0){fa=0}else{break}do{ea=e+fa|0;a[ea]=(a[ea]|0)==0|0;fa=fa+1|0;}while((fa|0)<(k|0))}}while(0);P=v<<1|o;i=h;return P|0}function O6a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b+14120|0;f=b+14128|0;g=c[f>>2]|0;if((c[b+15688>>2]|0)==2){h=c[b+14136>>2]|0;i=c[e>>2]|0;j=i+(g>>>3)|0;k=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(g&7)>>>29;j=g+3|0;l=h>>>0>j>>>0?j:h;c[f>>2]=l;if((k|0)==7){j=i+(l>>>3)|0;i=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(l&7)>>>27;j=l+5|0;c[f>>2]=h>>>0>j>>>0?j:h;a[b+15729|0]=i;return}else{a[b+15729|0]=k+1+(d[b+15728|0]|0);return}}k=c[e>>2]|0;e=d[k+(g>>>3)|0]<<(g&7)>>>7;i=c[b+14136>>2]|0;h=((g|0)<(i|0))+g|0;c[f>>2]=h;g=e&1;a[b+16004|0]=g;if(g<<24>>24==0){return}g=k+(h>>>3)|0;e=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(h&7)>>>30;g=h+2|0;h=i>>>0>g>>>0?g:i;c[f>>2]=h;g=e&255;a[b+16005|0]=g;do{if((e|0)==2|(e|0)==1){j=k+(h>>>3)|0;l=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(h&7)>>>30;j=h+2|0;m=i>>>0>j>>>0?j:i;c[f>>2]=m;a[b+16006|0]=l;n=m}else if((e|0)==3){m=d[k+(h>>>3)|0]<<(h&7)>>>7;l=((h|0)<(i|0))+h|0;c[f>>2]=l;j=m&1;a[b+16007|0]=j;if(!(j<<24>>24==0)){n=l;break}a[b+16072|0]=0;n=l}else{n=h}}while(0);if((a[b+16007|0]|0)==0&g<<24>>24==3){return}g=k+(n>>>3)|0;h=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(n&7)>>>29;g=n+3|0;n=i>>>0>g>>>0?g:i;c[f>>2]=n;if((h|0)==7){g=k+(n>>>3)|0;k=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(n&7)>>>27;g=n+5|0;c[f>>2]=i>>>0>g>>>0?g:i;a[b+15729|0]=k;return}else{a[b+15729|0]=h+1+(d[b+15728|0]|0);return}}function P6a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;g=i;i=i+1024|0;h=g|0;j=g+512|0;k=e+19444|0;c[k>>2]=0;l=e+19544|0;c[l>>2]=0;m=e+19436|0;if((c[m>>2]|0)==0){n=7}else{if((c[e+19224>>2]|0)!=2){o=-1;i=g;return o|0}if((c[e+19428>>2]|0)!=1){o=-1;i=g;return o|0}p=c[e+19432>>2]|0;if((p&4|0)==0){q=(p&1)+1|0}else{q=p<<2&4|3}c[e+9992>>2]=q;c[(c[e+9856>>2]|0)+88>>2]=q;if((c[e+19496>>2]|0)!=0){n=7}}do{if((n|0)==7){q=e+15632|0;if((c[q>>2]|0)==0){r=0;s=0}else{p=f+8|0;t=c[p>>2]|0;u=c[f>>2]|0;v=d[u+(t>>>3)|0]|0;w=c[f+16>>2]|0;x=((t|0)<(w|0))+t|0;c[p>>2]=x;if((v&128>>>((t&7)>>>0)|0)==0){y=0}else{t=d[u+(x>>>3)|0]<<(x&7)>>>7;c[p>>2]=((x|0)<(w|0))+x;y=(t&1)+1|0}r=(y|0)==2|0;s=y}t=e+19428|0;do{if((c[e+19492>>2]|0)==0){if((c[t>>2]|0)==(r|0)){break}else{o=-1094995529}i=g;return o|0}}while(0);c[t>>2]=r;x=e+19224|0;c[x>>2]=s;w=e+120|0;p=c[w>>2]|0;u=(c[e+12>>2]|0)+15>>4;do{if((p|0)!=(u|0)){if((p|0)==(u+1&-2|0)){break}KIb(0,0,2476896,(z=i,i=i+24|0,c[z>>2]=2467512,c[z+8>>2]=2457712,c[z+16>>2]=883,z)|0);i=z;Hd();return 0}}while(0);a:do{if((r|0)==0){c[w>>2]=u;p=f+8|0;v=f|0;A=f+16|0;B=0;while(1){if((B|0)>=4){break}C=c[p>>2]|0;D=d[(c[v>>2]|0)+(C>>>3)|0]|0;c[p>>2]=((C|0)<(c[A>>2]|0))+C;if((D&128>>>((C&7)>>>0)|0)==0){break}else{B=B+1|0}}switch(B|0){case 0:{c[e+9992>>2]=2;break a;break};case 2:{c[e+9992>>2]=1;break a;break};case 3:{c[e+9992>>2]=7;break a;break};case 1:{c[e+9992>>2]=3;break a;break};case 4:{c[e+9992>>2]=2;c[l>>2]=1;break a;break};default:{break a}}}else{c[w>>2]=u+1&-2;A=f+8|0;p=c[A>>2]|0;v=c[f+16>>2]|0;C=(c[f>>2]|0)+(p>>>3)|0;D=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(p&7);C=D>>>29;E=p+3|0;c[A>>2]=v>>>0>E>>>0?E:v;c[e+19432>>2]=C;v=e+9992|0;c[v>>2]=(D>>>30&1)+1;if((C&4|0)==0){break}c[v>>2]=C<<1&4|3}}while(0);if((c[e+15636>>2]|0)!=0){u=f+8|0;w=c[f+16>>2]|0;C=(c[u>>2]|0)+8|0;c[u>>2]=w>>>0>C>>>0?C:w}b:do{if((c[e+15628>>2]|0)==0){a[e+19231|0]=1}else{do{if((c[q>>2]|0)!=0){if((c[e+15656>>2]|0)!=0){break}w=f+8|0;C=c[w>>2]|0;u=f|0;v=d[(c[u>>2]|0)+(C>>>3)|0]<<(C&7)>>>7;D=f+16|0;c[w>>2]=((C|0)<(c[D>>2]|0))+C;a[e+19231|0]=v&1;v=c[w>>2]|0;C=d[(c[u>>2]|0)+(v>>>3)|0]<<(v&7)>>>7;c[w>>2]=((v|0)<(c[D>>2]|0))+v;a[e+19232|0]=C&1;break b}}while(0);B=f+8|0;C=c[B>>2]|0;v=c[f+16>>2]|0;D=(c[f>>2]|0)+(C>>>3)|0;w=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>>30;D=C+2|0;c[B>>2]=v>>>0>D>>>0?D:v;a[e+19230|0]=w}}while(0);if((c[e+15640>>2]|0)!=0){RIb(c[e+4>>2]|0,2440952,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}if((c[l>>2]|0)!=0){o=0;i=g;return o|0}w=f+8|0;v=c[w>>2]|0;D=f|0;B=c[D>>2]|0;C=d[B+(v>>>3)|0]<<(v&7)>>>7;u=f+16|0;c[w>>2]=((v|0)<(c[u>>2]|0))+v;c[e+19216>>2]=C&1;if((c[q>>2]|0)!=0){C=c[w>>2]|0;v=d[B+(C>>>3)|0]<<(C&7)>>>7;c[w>>2]=((C|0)<(c[u>>2]|0))+C;a[e+19242|0]=v&1}v=c[1552043]|0;if((v|0)==0){o=0;i=g;return o|0}if((c[t>>2]|0)==0){if((c[x>>2]|0)!=0){break}if((c[e+15704>>2]|0)!=0){C=c[w>>2]|0;B=d[(c[D>>2]|0)+(C>>>3)|0]<<(C&7)>>>7;c[w>>2]=((C|0)<(c[u>>2]|0))+C;a[e+19221|0]=B&1}B=e+9992|0;if((c[B>>2]|0)!=3){break}C=c[1552043]|0;E=c[w>>2]|0;A=c[u>>2]|0;p=(c[D>>2]|0)+(E>>>3)|0;F=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(E&7)>>>25;p=b[C+(F<<2)>>1]|0;G=(b[C+(F<<2)+2>>1]|0)+E|0;c[w>>2]=A>>>0>G>>>0?G:A;if(p<<16>>16==21|p<<16>>16<0){KIb(c[e+4>>2]|0,16,2338744,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=g;return o|0}else{a[e+19604|0]=p;A=b[1267424+((p&255)<<1)>>1]|0;b[e+16070>>1]=A;if(!(A<<16>>16==0)){break}c[B>>2]=7;break}}do{if((c[e+15644>>2]|0)==0){c[e+19440>>2]=0;H=e+9992|0}else{B=e+9992|0;A=c[B>>2]|0;if((A|0)==3|(A|0)==7){H=B;break}A=c[w>>2]|0;p=c[u>>2]|0;G=c[D>>2]|0;E=G+(A>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(A&7)>>>30;E=A+2|0;c[w>>2]=p>>>0>E>>>0?E:p;p=e+19440|0;c[p>>2]=F;if((F|0)==3){I=0}else{H=B;break}while(1){if((I|0)>=16){break}F=c[w>>2]|0;E=d[G+(F>>>3)|0]|0;c[w>>2]=((F|0)<(c[u>>2]|0))+F;if((E&128>>>((F&7)>>>0)|0)==0){break}else{I=I+1|0}}c[p>>2]=(c[p>>2]|0)+I;H=B}}while(0);x=c[H>>2]|0;if(!((x|0)==3|(x|0)==7)){break}x=c[w>>2]|0;t=c[u>>2]|0;q=(c[D>>2]|0)+(x>>>3)|0;G=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(x&7)>>>25;q=b[v+(G<<2)>>1]|0;F=(b[v+(G<<2)+2>>1]|0)+x|0;c[w>>2]=t>>>0>F>>>0?F:t;if(q<<16>>16==21|q<<16>>16<0){KIb(c[e+4>>2]|0,16,2338744,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=g;return o|0}else{a[e+19604|0]=q;t=b[1267424+((q&255)<<1)>>1]|0;b[e+16070>>1]=t;q=c[e+19440>>2]|0;F=(ca(t<<16>>16,q)|0)>>8;c[e+19484>>2]=F;t=q-F-1|0;F=e+19488|0;c[F>>2]=t;if((t|0)>=0){break}c[F>>2]=0;break}}}while(0);H=e+19428|0;if((c[H>>2]|0)!=0){c[e+19456>>2]=(d[e+19231|0]|0)==(c[m>>2]|0)}I=f+8|0;l=c[I>>2]|0;r=f+16|0;s=c[r>>2]|0;y=f|0;f=(c[y>>2]|0)+(l>>>3)|0;F=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7);f=F>>>27;t=l+5|0;c[I>>2]=s>>>0>t>>>0?t:s;if((f|0)==0){o=-1;i=g;return o|0}s=e+16040|0;c[s>>2]=f;t=e+15700|0;l=c[t>>2]|0;if((l|0)==0){a[e+15728|0]=a[1262496+f|0]|0;J=F>>>0<1207959552>>>0}else{a[e+15728|0]=a[1262528+f|0]|0;J=(l|0)!=2}q=e+16081|0;a[q]=J&1;c[s>>2]=f;if(F>>>0<1207959552>>>0){F=c[I>>2]|0;f=d[(c[y>>2]|0)+(F>>>3)|0]<<(F&7)>>>7;c[I>>2]=((F|0)<(c[r>>2]|0))+F;a[e+16072|0]=f&1;K=c[t>>2]|0}else{a[e+16072|0]=0;K=l}if((K|0)==1){K=c[I>>2]|0;l=d[(c[y>>2]|0)+(K>>>3)|0]<<(K&7)>>>7;c[I>>2]=((K|0)<(c[r>>2]|0))+K;a[q]=l&1}if((c[e+15624>>2]|0)!=0){l=c[I>>2]|0;q=c[r>>2]|0;K=(c[y>>2]|0)+(l>>>3)|0;t=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(l&7)>>>30;K=l+2|0;c[I>>2]=q>>>0>K>>>0?K:q;a[e+19243|0]=t}if((c[e+19612>>2]|0)!=0){o=0;i=g;return o|0}if((c[e+19492>>2]|0)==0){L=e+9992|0}else{t=h|0;h=j|0;j=e+9992|0;q=c[j>>2]|0;if((q|0)==7|(q|0)==3){c[e+19204>>2]=e+19212}else{K=e+19200|0;l=c[K>>2]|0;f=e+19208|0;c[K>>2]=c[f>>2];c[f>>2]=l;c[e+19204>>2]=f}if((q|0)==7|(q|0)==3){f=e+17144|0;c[e+19192>>2]=f;M=f}else{f=e+16120|0;nrc(t|0,f|0,512)|0;l=e+18168|0;K=l|0;nrc(f|0,K|0,512)|0;nrc(K|0,t|0,512)|0;t=l|0;c[e+19192>>2]=t;M=t}if((q|0)==7|(q|0)==3){c[e+19196>>2]=e+17656}else{q=e+16632|0;nrc(h|0,q|0,512)|0;t=e+18680|0;l=t|0;nrc(q|0,l|0,512)|0;nrc(l|0,h|0,512)|0;c[e+19196>>2]=t}t=e+19192|0;h=e+19196|0;l=0;q=M;while(1){M=l&255;a[q+l|0]=M;a[(c[h>>2]|0)+l|0]=M;M=l+1|0;if((M|0)>=256){N=0;break}l=M;q=c[t>>2]|0}do{q=N&255;a[(c[t>>2]|0)+256+N|0]=q;a[(c[h>>2]|0)+256+N|0]=q;N=N+1|0;}while((N|0)<256);c[c[e+19204>>2]>>2]=0;L=j}j=c[L>>2]|0;do{if((j|0)==2){do{if((c[H>>2]|0)!=0){N=c[I>>2]|0;h=c[y>>2]|0;t=d[h+(N>>>3)|0]<<(N&7)>>>7;c[I>>2]=((N|0)<(c[r>>2]|0))+N;N=t&1;c[k>>2]=N;if((N|0)!=0){break}N=c[I>>2]|0;t=d[h+(N>>>3)|0]<<(N&7)>>>7;c[I>>2]=((N|0)<(c[r>>2]|0))+N;N=t&1;c[e+19448>>2]=N;c[e+19460>>2]=N^(c[e+19456>>2]|0)==0}}while(0);if((c[e+15684>>2]|0)==0){a[e+16080|0]=0}else{w=0;while(1){if((w|0)>=3){break}v=c[I>>2]|0;D=d[(c[y>>2]|0)+(v>>>3)|0]|0;c[I>>2]=((v|0)<(c[r>>2]|0))+v;if((D&128>>>((v&7)>>>0)|0)==0){break}else{w=w+1|0}}a[e+16080|0]=w}do{if((c[e+15632>>2]|0)!=0){if((c[e+15648>>2]|0)==0){a[e+19288|0]=0}else{v=0;while(1){if((v|0)>=3){break}D=c[I>>2]|0;u=d[(c[y>>2]|0)+(D>>>3)|0]|0;c[I>>2]=((D|0)<(c[r>>2]|0))+D;if((u&128>>>((D&7)>>>0)|0)==0){break}else{v=v+1|0}}a[e+19288|0]=v}if((c[e+19224>>2]|0)!=1){break}B=c[I>>2]|0;p=c[y>>2]|0;D=d[p+(B>>>3)|0]<<(B&7)>>>7;c[I>>2]=((B|0)<(c[r>>2]|0))+B;B=e+19292|0;c[B>>2]=D&1;D=c[I>>2]|0;u=d[p+(D>>>3)|0]<<(D&7)>>>7;c[I>>2]=((D|0)<(c[r>>2]|0))+D;D=u&1;c[e+19296>>2]=D;if((D|0)!=0){D=c[I>>2]|0;u=c[r>>2]|0;N=p+(D>>>3)|0;p=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(D&7)>>>26;N=D+6|0;c[I>>2]=u>>>0>N>>>0?N:u;u=e+16068|0;a[u]=p;p=c[I>>2]|0;N=c[r>>2]|0;D=(c[y>>2]|0)+(p>>>3)|0;t=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(p&7);D=t>>>26;h=p+6|0;c[I>>2]=N>>>0>h>>>0?h:N;N=e+16069|0;a[N]=D;h=a[u]|0;do{if(h<<24>>24==0){p=D<<7^16320;if((t|0)>=0){O=-64;P=p;break}O=-64;P=p+8192|0}else{p=(h&255)+32|0;q=D<<6;if((t|0)>=0){O=p;P=q;break}O=p;P=q|-4096}}while(0);t=P+32|0;D=0;do{h=e+16120+D|0;v=e+16632+D|0;q=d[v]|0;p=t+(ca(d[h]|0,O)|0)>>6;if(p>>>0>255>>>0){Q=-p>>31&255}else{Q=p&255}a[h]=Q;h=(ca(q-128|0,O)|0)+8224>>6;if(h>>>0>255>>>0){R=-h>>31&255}else{R=h&255}a[v]=R;D=D+1|0;}while((D|0)<256);D=a[u]|0;do{if(D<<24>>24==0){t=a[N]|0;v=255-((t&255)<<1)<<6;if(!((t&255)>>>0>31>>>0)){S=-64;T=v;break}S=-64;T=v+8192|0}else{v=(D&255)+32|0;t=a[N]|0;h=(t&255)<<6;if(!((t&255)>>>0>31>>>0)){S=v;T=h;break}S=v;T=h-4096|0}}while(0);N=T+32|0;D=0;do{u=e+16376+D|0;h=e+16888+D|0;v=d[h]|0;t=N+(ca(d[u]|0,S)|0)>>6;if(t>>>0>255>>>0){U=-t>>31&255}else{U=t&255}a[u]=U;u=(ca(v-128|0,S)|0)+8224>>6;if(u>>>0>255>>>0){V=-u>>31&255}else{V=u&255}a[h]=V;D=D+1|0;}while((D|0)<256);c[e+19200>>2]=1}D=N6a(c[e+9928>>2]|0,e+16116|0,e)|0;KIb(c[e+4>>2]|0,48,2402040,(z=i,i=i+16|0,c[z>>2]=D>>1,c[z+8>>2]=D&1,z)|0);i=z;D=c[I>>2]|0;N=c[r>>2]|0;h=(c[y>>2]|0)+(D>>>3)|0;u=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(D&7)>>>30;h=D+2|0;D=N>>>0>h>>>0?h:N;c[I>>2]=D;if((c[B>>2]|0)==0){c[e+19304>>2]=6075104+(u*20|0)}else{c[e+19304>>2]=6075184+(u*20|0)}u=(c[y>>2]|0)+(D>>>3)|0;h=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(D&7)>>>30;u=D+2|0;D=N>>>0>u>>>0?u:N;c[I>>2]=D;c[e+19308>>2]=6208672+(h*20|0);h=(c[y>>2]|0)+(D>>>3)|0;u=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(D&7)>>>29;h=D+3|0;D=N>>>0>h>>>0?h:N;c[I>>2]=D;c[e+16084>>2]=6207928+(u*20|0);u=(c[y>>2]|0)+(D>>>3)|0;h=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(D&7)>>>30;u=D+2|0;D=N>>>0>u>>>0?u:N;c[I>>2]=D;c[e+19312>>2]=6208592+(h*20|0);if((c[B>>2]|0)==0){break}h=(c[y>>2]|0)+(D>>>3)|0;u=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(D&7)>>>30;h=D+2|0;c[I>>2]=N>>>0>h>>>0?h:N;c[e+19316>>2]=6208352+(u*20|0)}}while(0);w=d[e+16080|0]|0;u=w+9+(w>>>1)|0;c[e+15712>>2]=u;c[e+15716>>2]=w+8;c[e+15720>>2]=1<<u-1;c[e+15724>>2]=1<<w+7;w=e+15728|0;u=a[w]|0;do{if((u&255)>>>0<5>>>0){c[e+16088>>2]=0}else{N=e+16088|0;if((u&255)>>>0<13>>>0){c[N>>2]=1;break}else{c[N>>2]=2;break}}}while(0);u=e+19224|0;do{if((c[u>>2]|0)==1){W=c[e+13924>>2]|0;X=e+19476|0;Y=e+14116|0;n=261}else{N=0;while(1){if((N|0)>=4){break}h=c[I>>2]|0;D=d[(c[y>>2]|0)+(h>>>3)|0]|0;c[I>>2]=((h|0)<(c[r>>2]|0))+h;if((D&128>>>((h&7)>>>0)|0)==0){N=N+1|0}else{break}}B=(d[w]|0)>>>0<13>>>0|0;h=a[1262936+(B*5|0)+N|0]|0;D=e+15708|0;a[D]=h;if(h<<24>>24==4){v=0;while(1){if((v|0)>=3){break}t=c[I>>2]|0;q=d[(c[y>>2]|0)+(t>>>3)|0]|0;c[I>>2]=((t|0)<(c[r>>2]|0))+t;if((q&128>>>((t&7)>>>0)|0)==0){v=v+1|0}else{break}}a[e+15709|0]=a[1262928+(B<<2)+v|0]|0;if((c[H>>2]|0)==0){c[e+19452>>2]=3;Z=3}else{N=c[I>>2]|0;t=c[y>>2]|0;q=d[t+(N>>>3)|0]|0;p=c[r>>2]|0;l=((N|0)<(p|0))+N|0;c[I>>2]=l;if((q&128>>>((N&7)>>>0)|0)==0){N=d[t+(l>>>3)|0]<<(l&7)>>>7;c[I>>2]=((l|0)<(p|0))+l;_=2-(N&1)^3}else{_=3}c[e+19452>>2]=_;Z=_}N=e+16068|0;a[N]=32;l=e+19300|0;a[l]=32;p=e+16069|0;a[p]=0;t=e+19301|0;a[t]=0;if((Z&1|0)==0){$=Z;aa=0}else{q=c[I>>2]|0;M=c[r>>2]|0;K=(c[y>>2]|0)+(q>>>3)|0;f=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(q&7)>>>26;K=q+6|0;c[I>>2]=M>>>0>K>>>0?K:M;a[N]=f;f=c[I>>2]|0;M=c[r>>2]|0;K=(c[y>>2]|0)+(f>>>3)|0;q=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(f&7)>>>26;K=f+6|0;c[I>>2]=M>>>0>K>>>0?K:M;M=q&255;a[p]=M;$=c[e+19452>>2]|0;aa=M}M=(c[H>>2]|0)==0;do{if(($&2|0)==0){if(M){n=172}else{n=174}}else{if(M){n=172;break}q=c[I>>2]|0;K=c[r>>2]|0;f=(c[y>>2]|0)+(q>>>3)|0;F=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(q&7)>>>26;f=q+6|0;c[I>>2]=K>>>0>f>>>0?f:K;a[l]=F;F=c[I>>2]|0;K=c[r>>2]|0;f=(c[y>>2]|0)+(F>>>3)|0;q=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(F&7)>>>26;f=F+6|0;c[I>>2]=K>>>0>f>>>0?f:K;K=c[H>>2]|0;a[t]=q;if((K|0)==0){n=221}else{n=174}}}while(0);do{if((n|0)==172){a[l]=a[N]|0;a[t]=aa;n=221}else if((n|0)==174){if((c[m>>2]|0)==0){n=221;break}M=e+19456|0;if((c[M>>2]|0)==0){v=a[l]|0;do{if(v<<24>>24==0){B=a[t]|0;K=255-((B&255)<<1)<<6;if(!((B&255)>>>0>31>>>0)){ba=K;da=-64;break}ba=K+8192|0;da=-64}else{K=(v&255)+32|0;B=a[t]|0;q=(B&255)<<6;if(!((B&255)>>>0>31>>>0)){ba=q;da=K;break}ba=q-4096|0;da=K}}while(0);v=ba+32|0;K=e+19192|0;q=e+19196|0;B=0;do{f=v+(ca(B,da)|0)>>6;if(f>>>0>255>>>0){ea=-f>>31&255}else{ea=f&255}a[(c[K>>2]|0)+((c[M>>2]^1)<<8)+B|0]=ea;f=(ca(B-128|0,da)|0)+8224>>6;if(f>>>0>255>>>0){fa=-f>>31&255}else{fa=f&255}a[(c[q>>2]|0)+((c[M>>2]^1)<<8)+B|0]=fa;B=B+1|0;}while((B|0)<256);B=a[N]|0;do{if(B<<24>>24==0){q=a[p]|0;K=255-((q&255)<<1)<<6;if(!((q&255)>>>0>31>>>0)){ga=K;ha=-64;break}ga=K+8192|0;ha=-64}else{K=(B&255)+32|0;q=a[p]|0;v=(q&255)<<6;if(!((q&255)>>>0>31>>>0)){ga=v;ha=K;break}ga=v-4096|0;ha=K}}while(0);B=ga+32|0;K=0;do{v=c[M>>2]|0;q=e+16120+(v<<8)+K|0;f=d[e+16632+(v<<8)+K|0]|0;v=B+(ca(d[q]|0,ha)|0)>>6;if(v>>>0>255>>>0){ia=-v>>31&255}else{ia=v&255}a[q]=ia;q=(ca(f-128|0,ha)|0)+8224>>6;if(q>>>0>255>>>0){ja=-q>>31&255}else{ja=q&255}a[e+16632+(c[M>>2]<<8)+K|0]=ja;K=K+1|0;}while((K|0)<256)}else{K=a[N]|0;do{if(K<<24>>24==0){B=a[p]|0;q=255-((B&255)<<1)<<6;if(!((B&255)>>>0>31>>>0)){ka=q;la=-64;break}ka=q+8192|0;la=-64}else{q=(K&255)+32|0;B=a[p]|0;f=(B&255)<<6;if(!((B&255)>>>0>31>>>0)){ka=f;la=q;break}ka=f-4096|0;la=q}}while(0);K=ka+32|0;q=e+19192|0;f=e+19196|0;B=0;do{v=K+(ca(B,la)|0)>>6;if(v>>>0>255>>>0){ma=-v>>31&255}else{ma=v&255}a[(c[q>>2]|0)+((c[M>>2]^1)<<8)+B|0]=ma;v=(ca(B-128|0,la)|0)+8224>>6;if(v>>>0>255>>>0){na=-v>>31&255}else{na=v&255}a[(c[f>>2]|0)+((c[M>>2]^1)<<8)+B|0]=na;B=B+1|0;}while((B|0)<256);B=a[l]|0;do{if(B<<24>>24==0){f=a[t]|0;q=255-((f&255)<<1)<<6;if(!((f&255)>>>0>31>>>0)){oa=q;pa=-64;break}oa=q+8192|0;pa=-64}else{q=(B&255)+32|0;f=a[t]|0;K=(f&255)<<6;if(!((f&255)>>>0>31>>>0)){oa=K;pa=q;break}oa=K-4096|0;pa=q}}while(0);B=oa+32|0;q=0;do{K=c[M>>2]|0;f=e+16120+(K<<8)+q|0;v=d[e+16632+(K<<8)+q|0]|0;K=B+(ca(d[f]|0,pa)|0)>>6;if(K>>>0>255>>>0){qa=-K>>31&255}else{qa=K&255}a[f]=qa;f=(ca(v-128|0,pa)|0)+8224>>6;if(f>>>0>255>>>0){ra=-f>>31&255}else{ra=f&255}a[e+16632+(c[M>>2]<<8)+q|0]=ra;q=q+1|0;}while((q|0)<256)}c[c[e+19204>>2]>>2]=1;c[e+19208>>2]=1}}while(0);if((n|0)==221){q=a[N]|0;do{if(q<<24>>24==0){M=a[p]|0;B=255-((M&255)<<1)<<6;if(!((M&255)>>>0>31>>>0)){sa=B;ta=-64;break}sa=B+8192|0;ta=-64}else{B=(q&255)+32|0;M=a[p]|0;f=(M&255)<<6;if(!((M&255)>>>0>31>>>0)){sa=f;ta=B;break}sa=f-4096|0;ta=B}}while(0);p=sa+32|0;q=0;do{N=e+16120+q|0;B=e+16632+q|0;f=d[B]|0;M=p+(ca(d[N]|0,ta)|0)>>6;if(M>>>0>255>>>0){ua=-M>>31&255}else{ua=M&255}a[N]=ua;N=(ca(f-128|0,ta)|0)+8224>>6;if(N>>>0>255>>>0){va=-N>>31&255}else{va=N&255}a[B]=va;q=q+1|0;}while((q|0)<256);q=a[l]|0;do{if(q<<24>>24==0){p=a[t]|0;B=255-((p&255)<<1)<<6;if(!((p&255)>>>0>31>>>0)){wa=B;xa=-64;break}wa=B+8192|0;xa=-64}else{B=(q&255)+32|0;p=a[t]|0;N=(p&255)<<6;if(!((p&255)>>>0>31>>>0)){wa=N;xa=B;break}wa=N-4096|0;xa=B}}while(0);t=wa+32|0;q=0;do{l=e+16376+q|0;B=e+16888+q|0;N=d[B]|0;p=t+(ca(d[l]|0,xa)|0)>>6;if(p>>>0>255>>>0){ya=-p>>31&255}else{ya=p&255}a[l]=ya;l=(ca(N-128|0,xa)|0)+8224>>6;if(l>>>0>255>>>0){za=-l>>31&255}else{za=l&255}a[B]=za;q=q+1|0;}while((q|0)<256)}c[e+19200>>2]=1;Aa=a[D]|0}else{Aa=h}q=e+13924|0;t=e+19476|0;c[t>>2]=c[q>>2];do{if((Aa<<24>>24|0)==2|(Aa<<24>>24|0)==0){c[q>>2]=0;Ba=0;n=250}else if((Aa<<24>>24|0)==4){B=a[e+15709|0]|0;if((B<<24>>24|0)==2|(B<<24>>24|0)==0){c[q>>2]=0;Ca=0;n=252;break}else{c[q>>2]=1;Ba=1;n=250;break}}else{c[q>>2]=1;Ba=1;n=250}}while(0);do{if((n|0)==250){if(Aa<<24>>24==0){Da=0;Ea=Ba;break}if(Aa<<24>>24==4){Ca=Ba;n=252}else{Da=1;Ea=Ba}}}while(0);if((n|0)==252){Da=(a[e+15709|0]|0)!=0|0;Ea=Ca}q=e+14116|0;c[q>>2]=Da;h=c[u>>2]|0;if((h|0)==1){W=Ea;X=t;Y=q;n=261;break}else if((h|0)!=0){h=c[I>>2]|0;q=c[r>>2]|0;B=c[y>>2]|0;l=B+(h>>>3)|0;N=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>29;l=h+3|0;h=q>>>0>l>>>0?l:q;c[I>>2]=h;l=c[k>>2]|0;p=B+(h>>>3)|0;B=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(h&7)>>>((30-l|0)>>>0);p=h+2+l|0;l=q>>>0>p>>>0?p:q;c[I>>2]=l;if((c[k>>2]|0)==0){c[e+19308>>2]=6208672+(B*20|0)}else{c[e+19308>>2]=6208432+(B*20|0)}B=(c[y>>2]|0)+(l>>>3)|0;p=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(l&7)>>>29;B=l+3|0;l=q>>>0>B>>>0?B:q;c[I>>2]=l;c[e+16084>>2]=6207928+(p*20|0);p=a[D]|0;if((p<<24>>24|0)==4){if((a[e+15709|0]|0)==3){n=267}else{n=268}}else if((p<<24>>24|0)==3){n=267}else{n=268}if((n|0)==267){p=(c[y>>2]|0)+(l>>>3)|0;B=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(l&7)>>>30;p=l+2|0;c[I>>2]=q>>>0>p>>>0?p:q;c[e+19316>>2]=6208352+(B*20|0);c[e+19304>>2]=6207608+(N*20|0);break}else if((n|0)==268){c[e+19304>>2]=6207768+(N*20|0);break}}if((Aa<<24>>24|0)==4){if((a[e+15709|0]|0)==3){n=256}else{n=258}}else if((Aa<<24>>24|0)==3){n=256}else{n=258}do{if((n|0)==256){N=N6a(c[e+16092>>2]|0,e+16104|0,e)|0;if((N|0)<0){o=-1;i=g;return o|0}else{KIb(c[e+4>>2]|0,48,2529584,(z=i,i=i+16|0,c[z>>2]=N>>1,c[z+8>>2]=N&1,z)|0);i=z;break}}else if((n|0)==258){c[e+16104>>2]=0;mrc(c[e+16092>>2]|0,0,ca(c[e+120>>2]|0,c[e+124>>2]|0)|0)|0}}while(0);D=N6a(c[e+9928>>2]|0,e+16116|0,e)|0;if((D|0)<0){o=-1;i=g;return o|0}else{KIb(c[e+4>>2]|0,48,2514336,(z=i,i=i+16|0,c[z>>2]=D>>1,c[z+8>>2]=D&1,z)|0);i=z;D=c[I>>2]|0;t=c[r>>2]|0;N=c[y>>2]|0;B=N+(D>>>3)|0;q=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(D&7)>>>30;B=D+2|0;c[I>>2]=t>>>0>B>>>0?B:t;c[e+14060>>2]=q;q=c[I>>2]|0;t=c[r>>2]|0;B=N+(q>>>3)|0;N=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(q&7)>>>30;B=q+2|0;c[I>>2]=t>>>0>B>>>0?B:t;c[e+16084>>2]=6208088+(N*20|0);break}}}while(0);if((n|0)==261){c[X>>2]=W;c[e+13924>>2]=1;c[Y>>2]=1}if((c[e+15688>>2]|0)!=0){KIb(c[e+4>>2]|0,48,2500608,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;O6a(e)}w=e+16016|0;c[w>>2]=0;if((c[e+15692>>2]|0)==0){a[e+16020|0]=1;c[w>>2]=0;Fa=u;break}N=c[I>>2]|0;t=d[(c[y>>2]|0)+(N>>>3)|0]<<(N&7)>>>7;c[I>>2]=((N|0)<(c[r>>2]|0))+N;N=t&1;a[e+16020|0]=N;if(N<<24>>24==0){Fa=u;break}N=c[I>>2]|0;t=c[r>>2]|0;B=(c[y>>2]|0)+(N>>>3)|0;q=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(N&7)>>>30;B=N+2|0;c[I>>2]=t>>>0>B>>>0?B:t;c[w>>2]=c[1262224+(q<<2)>>2];Fa=u}else if((j|0)==1|(j|0)==7){q=e+19224|0;do{if((c[q>>2]|0)==1){w=N6a(c[e+19324>>2]|0,e+19328|0,e)|0;if((w|0)<0){o=-1;i=g;return o|0}else{KIb(c[e+4>>2]|0,48,2429240,(z=i,i=i+16|0,c[z>>2]=w>>1,c[z+8>>2]=w&1,z)|0);i=z;break}}}while(0);u=N6a(c[e+19252>>2]|0,e+19256|0,e)|0;if((u|0)<0){o=-1;i=g;return o|0}w=e+4|0;KIb(c[w>>2]|0,48,2418768,(z=i,i=i+16|0,c[z>>2]=u>>1,c[z+8>>2]=u&1,z)|0);i=z;u=e+19268|0;a[u]=0;if((c[e+15696>>2]|0)==0){Fa=q;break}if(!((d[e+15728|0]|0)>>>0<9>>>0)){Fa=q;break}t=c[I>>2]|0;B=c[y>>2]|0;N=d[B+(t>>>3)|0]|0;D=c[r>>2]|0;p=((t|0)<(D|0))+t|0;c[I>>2]=p;if((N&128>>>((t&7)>>>0)|0)==0){a[u]=0;Fa=q;break}t=d[B+(p>>>3)|0]<<(p&7)>>>7;c[I>>2]=((p|0)<(D|0))+p;p=(t&1)+1|0;a[u]=p;if((p&255|0)!=2){Fa=q;break}p=N6a(c[e+19260>>2]|0,e+19264|0,e)|0;if((p|0)<0){o=-1;i=g;return o|0}else{KIb(c[w>>2]|0,48,2409808,(z=i,i=i+16|0,c[z>>2]=p>>1,c[z+8>>2]=p&1,z)|0);i=z;Fa=q;break}}else if((j|0)==3){p=e+19224|0;w=(c[p>>2]|0)==1;do{if(w){u=c[1552043]|0;t=c[I>>2]|0;D=c[r>>2]|0;B=(c[y>>2]|0)+(t>>>3)|0;N=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>25;B=b[u+(N<<2)>>1]|0;l=(b[u+(N<<2)+2>>1]|0)+t|0;c[I>>2]=D>>>0>l>>>0?l:D;if(B<<16>>16==21|B<<16>>16<0){KIb(c[e+4>>2]|0,16,2338744,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1094995529;i=g;return o|0}else{a[e+19604|0]=B;D=b[1267424+((B&255)<<1)>>1]|0;b[e+16070>>1]=D;if(D<<16>>16==0){o=-1}else{break}i=g;return o|0}}}while(0);if((c[e+15684>>2]|0)==0){a[e+16080|0]=0;Ga=0}else{q=0;while(1){if((q|0)>=3){break}D=c[I>>2]|0;B=d[(c[y>>2]|0)+(D>>>3)|0]|0;c[I>>2]=((D|0)<(c[r>>2]|0))+D;if((B&128>>>((D&7)>>>0)|0)==0){break}else{q=q+1|0}}a[e+16080|0]=q;Ga=q&255}D=Ga+9+(Ga>>>1)|0;c[e+15712>>2]=D;c[e+15716>>2]=Ga+8;c[e+15720>>2]=1<<D-1;c[e+15724>>2]=1<<Ga+7;D=e+15728|0;B=a[D]|0;do{if((B&255)>>>0<5>>>0){c[e+16088>>2]=0}else{l=e+16088|0;if((B&255)>>>0<13>>>0){c[l>>2]=1;break}else{c[l>>2]=2;break}}}while(0);do{if((c[H>>2]|0)==0){if(!w){B=c[I>>2]|0;q=d[(c[y>>2]|0)+(B>>>3)|0]<<(B&7);c[I>>2]=((B|0)<(c[r>>2]|0))+B;B=q>>>7&1;a[e+15708|0]=B;q=e+13924|0;c[e+19476>>2]=c[q>>2];l=B&255;c[q>>2]=l;c[e+14116>>2]=l;l=N6a(c[e+16096>>2]|0,e+16108|0,e)|0;if((l|0)<0){o=-1;i=g;return o|0}q=e+4|0;KIb(c[q>>2]|0,48,2487872,(z=i,i=i+16|0,c[z>>2]=l>>1,c[z+8>>2]=l&1,z)|0);i=z;l=N6a(c[e+9928>>2]|0,e+16116|0,e)|0;if((l|0)<0){o=-1;i=g;return o|0}else{KIb(c[q>>2]|0,48,2514336,(z=i,i=i+16|0,c[z>>2]=l>>1,c[z+8>>2]=l&1,z)|0);i=z;l=c[I>>2]|0;q=c[r>>2]|0;B=c[y>>2]|0;t=B+(l>>>3)|0;N=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(l&7)>>>30;t=l+2|0;c[I>>2]=q>>>0>t>>>0?t:q;c[e+14060>>2]=N;N=c[I>>2]|0;q=c[r>>2]|0;t=B+(N>>>3)|0;B=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(N&7)>>>30;t=N+2|0;c[I>>2]=q>>>0>t>>>0?t:q;c[e+16084>>2]=6208088+(B*20|0);break}}if((c[e+15648>>2]|0)!=0){B=0;while(1){if((B|0)>=3){break}q=c[I>>2]|0;t=d[(c[y>>2]|0)+(q>>>3)|0]|0;c[I>>2]=((q|0)<(c[r>>2]|0))+q;if((t&128>>>((q&7)>>>0)|0)==0){break}else{B=B+1|0}}a[e+19288|0]=B}q=c[I>>2]|0;t=d[(c[y>>2]|0)+(q>>>3)|0]|0;c[I>>2]=((q|0)<(c[r>>2]|0))+q;if((t&128>>>((q&7)>>>0)|0)!=0){KIb(c[e+4>>2]|0,24,2381168,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}c[e+19296>>2]=0;a[e+15708|0]=1;c[e+19292>>2]=0;q=e+13924|0;c[e+19476>>2]=c[q>>2];c[q>>2]=1;c[e+14116>>2]=1;q=N6a(c[e+16096>>2]|0,e+16108|0,e)|0;if((q|0)<0){o=-1;i=g;return o|0}t=e+4|0;KIb(c[t>>2]|0,48,2487872,(z=i,i=i+16|0,c[z>>2]=q>>1,c[z+8>>2]=q&1,z)|0);i=z;q=N6a(c[e+9928>>2]|0,e+16116|0,e)|0;if((q|0)<0){o=-1;i=g;return o|0}else{KIb(c[t>>2]|0,48,2514336,(z=i,i=i+16|0,c[z>>2]=q>>1,c[z+8>>2]=q&1,z)|0);i=z;q=c[I>>2]|0;t=c[r>>2]|0;N=(c[y>>2]|0)+(q>>>3)|0;l=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(q&7)>>>30;N=q+2|0;q=t>>>0>N>>>0?N:t;c[I>>2]=q;c[e+19304>>2]=6075104+(l*20|0);l=(c[y>>2]|0)+(q>>>3)|0;N=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(q&7)>>>30;l=q+2|0;q=t>>>0>l>>>0?l:t;c[I>>2]=q;c[e+19308>>2]=6208672+(N*20|0);N=(c[y>>2]|0)+(q>>>3)|0;l=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(q&7)>>>29;N=q+3|0;q=t>>>0>N>>>0?N:t;c[I>>2]=q;c[e+16084>>2]=6207928+(l*20|0);l=(c[y>>2]|0)+(q>>>3)|0;N=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(q&7)>>>30;l=q+2|0;q=t>>>0>l>>>0?l:t;c[I>>2]=q;c[e+19312>>2]=6208592+(N*20|0);N=(c[y>>2]|0)+(q>>>3)|0;l=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(q&7)>>>30;N=q+2|0;c[I>>2]=t>>>0>N>>>0?N:t;c[e+19316>>2]=6208352+(l*20|0);break}}else{l=e+4|0;KIb(c[l>>2]|0,48,2395288,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;if((c[e+15648>>2]|0)==0){Ha=0}else{t=0;while(1){if((t|0)>=3){break}N=c[I>>2]|0;q=d[(c[y>>2]|0)+(N>>>3)|0]|0;c[I>>2]=((N|0)<(c[r>>2]|0))+N;if((q&128>>>((N&7)>>>0)|0)==0){break}else{t=t+1|0}}a[e+19288|0]=t;Ha=0}while(1){if((Ha|0)>=3){break}B=c[I>>2]|0;N=d[(c[y>>2]|0)+(B>>>3)|0]|0;c[I>>2]=((B|0)<(c[r>>2]|0))+B;if((N&128>>>((B&7)>>>0)|0)==0){Ha=Ha+1|0}else{break}}t=a[1262928+(((d[D]|0)>>>0<13>>>0)<<2)+Ha|0]|0;B=e+15708|0;a[B]=t;N=e+13924|0;c[e+19476>>2]=c[N>>2];if(t<<24>>24==1){c[N>>2]=1;n=299}else{c[N>>2]=t<<24>>24==3;if(t<<24>>24==0){Ia=0}else{n=299}}if((n|0)==299){Ia=t<<24>>24!=2|0}c[e+14116>>2]=Ia;t=N6a(c[e+16100>>2]|0,e+16112|0,e)|0;if((t|0)<0){o=-1;i=g;return o|0}KIb(c[l>>2]|0,48,2388136,(z=i,i=i+16|0,c[z>>2]=t>>1,c[z+8>>2]=t&1,z)|0);i=z;t=c[I>>2]|0;N=c[r>>2]|0;q=(c[y>>2]|0)+(t>>>3)|0;u=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(t&7)>>>29;q=t+3|0;t=N>>>0>q>>>0?q:N;c[I>>2]=t;if((a[B]|0)==3){c[e+19304>>2]=6207608+(u*20|0)}else{c[e+19304>>2]=6207768+(u*20|0)}u=(c[y>>2]|0)+(t>>>3)|0;q=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>>29;u=t+3|0;t=N>>>0>u>>>0?u:N;c[I>>2]=t;c[e+19308>>2]=6208432+(q*20|0);q=(c[y>>2]|0)+(t>>>3)|0;u=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(t&7)>>>29;q=t+3|0;t=N>>>0>q>>>0?q:N;c[I>>2]=t;c[e+16084>>2]=6207928+(u*20|0);if((a[B]|0)==3){B=(c[y>>2]|0)+(t>>>3)|0;u=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>30;B=t+2|0;c[I>>2]=N>>>0>B>>>0?B:N;c[e+19316>>2]=6208352+(u*20|0)}c[k>>2]=1}}while(0);if((c[e+15688>>2]|0)!=0){KIb(c[e+4>>2]|0,48,2500608,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;O6a(e)}D=e+16016|0;c[D>>2]=0;if((c[e+15692>>2]|0)==0){a[e+16020|0]=1;c[D>>2]=0;Fa=p;break}w=c[I>>2]|0;u=d[(c[y>>2]|0)+(w>>>3)|0]<<(w&7)>>>7;c[I>>2]=((w|0)<(c[r>>2]|0))+w;w=u&1;a[e+16020|0]=w;if(w<<24>>24==0){Fa=p;break}w=c[I>>2]|0;u=c[r>>2]|0;N=(c[y>>2]|0)+(w>>>3)|0;B=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(w&7)>>>30;N=w+2|0;c[I>>2]=u>>>0>N>>>0?N:u;c[D>>2]=c[1262224+(B<<2)>>2];Fa=p}else{Fa=e+19224|0}}while(0);do{if((c[Fa>>2]|0)!=0){if((c[e+13924>>2]|0)!=0){break}k=e+15720|0;c[k>>2]=c[k>>2]<<1;k=e+15724|0;c[k>>2]=c[k>>2]<<1}}while(0);Fa=c[I>>2]|0;k=c[y>>2]|0;y=d[k+(Fa>>>3)|0]|0;Ia=c[r>>2]|0;n=((Fa|0)<(Ia|0))+Fa|0;c[I>>2]=n;if((y&128>>>((Fa&7)>>>0)|0)==0){Ja=0}else{Fa=d[k+(n>>>3)|0]<<(n&7)>>>7;c[I>>2]=((n|0)<(Ia|0))+n;Ja=(Fa&1)+1|0}c[e+16008>>2]=Ja;Ja=c[L>>2]|0;if((Ja|0)==1|(Ja|0)==7){Ja=c[I>>2]|0;Fa=d[k+(Ja>>>3)|0]|0;n=c[r>>2]|0;Ia=((Ja|0)<(n|0))+Ja|0;c[I>>2]=Ia;if((Fa&128>>>((Ja&7)>>>0)|0)==0){Ka=0}else{Ja=d[k+(Ia>>>3)|0]<<(Ia&7)>>>7;c[I>>2]=((Ia|0)<(n|0))+Ia;Ka=(Ja&1)+1|0}c[e+16012>>2]=Ka}Ka=c[I>>2]|0;Ja=d[k+(Ka>>>3)|0]<<(Ka&7)>>>7;c[I>>2]=((Ka|0)<(c[r>>2]|0))+Ka;c[e+14072>>2]=Ja&1;Ja=c[L>>2]|0;if(!((Ja|0)==1|(Ja|0)==7)){c[e+19548>>2]=0;o=0;i=g;return o|0}if((c[e+15688>>2]|0)==0){La=Ja}else{KIb(c[e+4>>2]|0,48,2500608,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;O6a(e);La=c[L>>2]|0}z=e+19548|0;c[z>>2]=0;if((La|0)!=7){o=0;i=g;return o|0}c[L>>2]=3;c[z>>2]=1;o=0;i=g;return o|0}function Q6a(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[b+19276>>2]=0;c[b+19272>>2]=0;if(a[1264304]|0){d=b+15728|0;a[d]=-1;f=b+16080|0;a[f]=0;return 0}c[1552043]=6207072;c[1552045]=128;$2(6208168,7,23,1267496,1,1,1267472,1,1,0,0,0,4)|0;c[1518751]=6207040;c[1518753]=8;$2(6075e3,3,4,1262920,1,1,1262912,1,1,0,0,0,4)|0;c[1518745]=6204816;c[1518747]=556;$2(6074976,9,64,1262848,1,1,1262720,2,2,0,0,0,4)|0;c[1551897]=6204752;c[1551899]=16;$2(6207584,4,7,1264320,1,1,1264312,1,1,0,0,0,4)|0;g=0;while(1){h=g*3|0;i=e[256328+(h<<1)>>1]|0;c[6074788+(g*20|0)>>2]=6075264+(i<<2);j=e[256328+(h+1<<1)>>1]|0;c[6074796+(g*20|0)>>2]=j-i;$2(6074784+(g*20|0)|0,9,16,1262176+(g<<4)|0,1,1,1262080+(g<<5)|0,2,2,0,0,0,4)|0;c[6074852+(g*20|0)>>2]=6075264+(j<<2);i=e[256328+(h+2<<1)>>1]|0;c[6074860+(g*20|0)>>2]=i-j;$2(6074848+(g*20|0)|0,5,8,1262360+(g<<3)|0,1,1,1262336+(g<<3)|0,1,1,0,0,0,4)|0;c[6074916+(g*20|0)>>2]=6075264+(i<<2);c[6074924+(g*20|0)>>2]=(e[256328+(h+3<<1)>>1]|0)-i;$2(6074912+(g*20|0)|0,6,15,1262432+(g*15|0)|0,1,1,1262384+(g*15|0)|0,1,1,0,0,0,4)|0;i=g+1|0;if((i|0)<3){g=i}else{k=0;break}}while(1){g=k*3|0;i=e[256328+(g+9<<1)>>1]|0;c[6208356+(k*20|0)>>2]=6075264+(i<<2);h=e[256328+(g+10<<1)>>1]|0;c[6208364+(k*20|0)>>2]=h-i;$2(6208352+(k*20|0)|0,6,16,1267880+(k<<4)|0,1,1,1267816+(k<<4)|0,1,1,0,0,0,4)|0;c[6208092+(k*20|0)>>2]=6075264+(h<<2);i=e[256328+(g+11<<1)>>1]|0;c[6208100+(k*20|0)>>2]=i-h;$2(6208088+(k*20|0)|0,9,64,1267168+(k<<6)|0,1,1,1266656+(k<<7)|0,2,2,0,0,0,4)|0;c[6075028+(k*20|0)>>2]=6075264+(i<<2);c[6075036+(k*20|0)>>2]=(e[256328+(g+12<<1)>>1]|0)-i;$2(6075024+(k*20|0)|0,9,73,1263536+(k*73|0)|0,1,1,1262952+(k*146|0)|0,2,2,0,0,0,4)|0;i=k+1|0;if((i|0)<4){k=i}else{l=0;break}}while(1){k=l<<1;i=e[256328+(k+21<<1)>>1]|0;c[6208196+(l*20|0)>>2]=6075264+(i<<2);g=e[256328+(k+22<<1)>>1]|0;c[6208204+(l*20|0)>>2]=g-i;$2(6208192+(l*20|0)|0,9,c[1267784+(l<<2)>>2]|0,268820+(l*1488|0)|0,8,4,268816+(l*1488|0)|0,8,4,0,0,0,4)|0;c[6208436+(l*20|0)>>2]=6075264+(g<<2);c[6208444+(l*20|0)>>2]=(e[256328+(k+23<<1)>>1]|0)-g;$2(6208432+(l*20|0)|0,9,126,1271976+(l*126|0)|0,1,1,1267944+(l*504|0)|0,4,4,0,0,0,4)|0;g=l+1|0;if((g|0)<8){l=g}else{m=0;break}}do{l=m*3|0;g=e[256328+(l+37<<1)>>1]|0;c[6075188+(m*20|0)>>2]=6075264+(g<<2);k=e[256328+(l+38<<1)>>1]|0;c[6075196+(m*20|0)>>2]=k-g;$2(6075184+(m*20|0)|0,9,15,1264240+(m*15|0)|0,1,1,1264120+(m*30|0)|0,2,2,0,0,0,4)|0;c[6075108+(m*20|0)>>2]=6075264+(k<<2);g=e[256328+(l+39<<1)>>1]|0;c[6075116+(m*20|0)>>2]=g-k;$2(6075104+(m*20|0)|0,6,9,1264080+(m*9|0)|0,1,1,1264040+(m*9|0)|0,1,1,0,0,0,4)|0;c[6208676+(m*20|0)>>2]=6075264+(g<<2);c[6208684+(m*20|0)>>2]=(e[256328+(l+40<<1)>>1]|0)-g;$2(6208672+(m*20|0)|0,9,72,1274168+(m*72|0)|0,1,1,1273016+(m*288|0)|0,4,4,0,0,0,4)|0;m=m+1|0;}while((m|0)<4);c[1552149]=6185632;c[1552151]=8;$2(6208592,3,4,1273e3,1,1,1272984,1,1,0,0,0,4)|0;c[1552154]=6185664;c[1552156]=8;$2(6208612,3,4,1273004,1,1,1272988,1,1,0,0,0,4)|0;c[1552159]=6185696;c[1552161]=8;$2(6208632,3,4,1273008,1,1,1272992,1,1,0,0,0,4)|0;c[1552164]=6185728;c[1552166]=8;$2(6208652,3,4,1273012,1,1,1272996,1,1,0,0,0,4)|0;m=0;do{g=m*3|0;l=e[256328+(g+53<<1)>>1]|0;c[6207932+(m*20|0)>>2]=6075264+(l<<2);k=e[256328+(g+54<<1)>>1]|0;c[6207940+(m*20|0)>>2]=k-l;$2(6207928+(m*20|0)|0,9,63,1265560+(m*63|0)|0,1,1,1264552+(m*126|0)|0,2,2,0,0,0,4)|0;c[6207612+(m*20|0)>>2]=6075264+(k<<2);l=e[256328+(g+55<<1)>>1]|0;c[6207620+(m*20|0)>>2]=l-k;$2(6207608+(m*20|0)|0,5,8,1264392+(m<<3)|0,1,1,1264328+(m<<3)|0,1,1,0,0,0,4)|0;c[6207772+(m*20|0)>>2]=6075264+(l<<2);c[6207780+(m*20|0)>>2]=(e[256328+(g+56<<1)>>1]|0)-l;$2(6207768+(m*20|0)|0,5,6,1264504+(m*6|0)|0,1,1,1264456+(m*6|0)|0,1,1,0,0,0,4)|0;m=m+1|0;}while((m|0)<8);a[1264304]=1;d=b+15728|0;a[d]=-1;f=b+16080|0;a[f]=0;return 0}function R6a(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((e|0)<=0){return}i=h+8|0;j=h|0;k=h+16|0;if((f|0)>0){l=b;m=1}else{b=1;while(1){h=c[i>>2]|0;c[i>>2]=((h|0)<(c[k>>2]|0))+h;if((b|0)>=(e|0)){break}b=b+1|0}return}while(1){b=c[i>>2]|0;h=c[j>>2]|0;n=d[h+(b>>>3)|0]|0;o=c[k>>2]|0;p=((b|0)<(o|0))+b|0;c[i>>2]=p;a:do{if((n&128>>>((b&7)>>>0)|0)==0){q=0;do{a[l+(ca(q,g)|0)|0]=0;q=q+1|0;}while((q|0)<(f|0))}else{q=0;r=p;s=h;t=o;while(1){u=(d[s+(r>>>3)|0]|0)<<(r&7)>>>7;c[i>>2]=((r|0)<(t|0))+r;a[l+(ca(q,g)|0)|0]=u&1;u=q+1|0;if((u|0)>=(f|0)){break a}q=u;r=c[i>>2]|0;s=c[j>>2]|0;t=c[k>>2]|0}}}while(0);if((m|0)>=(e|0)){break}l=l+1|0;m=m+1|0}return}function S6a(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((f|0)<=0){return}i=h+8|0;j=h|0;k=h+16|0;if((e|0)>0){l=b;m=1}else{h=b;b=1;while(1){n=c[i>>2]|0;o=d[(c[j>>2]|0)+(n>>>3)|0]|0;c[i>>2]=((n|0)<(c[k>>2]|0))+n;if((o&128>>>((n&7)>>>0)|0)==0){mrc(h|0,0,e|0)|0}if((b|0)>=(f|0)){break}h=h+g|0;b=b+1|0}return}while(1){b=c[i>>2]|0;h=c[j>>2]|0;n=d[h+(b>>>3)|0]|0;o=c[k>>2]|0;p=((b|0)<(o|0))+b|0;c[i>>2]=p;a:do{if((n&128>>>((b&7)>>>0)|0)==0){mrc(l|0,0,e|0)|0}else{q=0;r=p;s=h;t=o;while(1){u=(d[s+(r>>>3)|0]|0)<<(r&7)>>>7;c[i>>2]=((r|0)<(t|0))+r;a[l+q|0]=u&1;u=q+1|0;if((u|0)>=(e|0)){break a}q=u;r=c[i>>2]|0;s=c[j>>2]|0;t=c[k>>2]|0}}}while(0);if((m|0)>=(f|0)){break}l=l+g|0;m=m+1|0}return}function T6a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;c[b+14100>>2]=0;if((c[b+19552>>2]|0)!=0){e=d[b+15728|0]|0;aqb(b+14672|0,(e<<1)+(d[b+16072|0]|0)|0,e&-((a[b+16081|0]|0)==0|0))|0;return}c[b+19564>>2]=0;c[b+19568>>2]=-1;c[b+19572>>2]=1;c[b+19576>>2]=2;e=b+9992|0;f=c[e>>2]|0;if((f|0)==2){if((c[b+19544>>2]|0)==0){W6a(b);return}g=b|0;h=b+952|0;if((c[h>>2]|0)==0){return}i=b+808|0;j=b+812|0;ypb(b+14424|0,0,c[i>>2]|0,(c[b+116>>2]|0)-1|0,(c[j>>2]|0)-1|0,112);k=b+14084|0;c[k>>2]=1;l=c[i>>2]|0;i=b+12480|0;c[i>>2]=l;if((l|0)<(c[j>>2]|0)){l=b+12476|0;m=b+19428|0;n=b+4|0;o=b+12496|0;p=b+12500|0;q=b+12504|0;r=b+12508|0;s=b+12512|0;t=b+12516|0;u=b+12544|0;v=b+12548|0;w=b+12552|0;x=b+148|0;y=b+956|0;z=b+152|0;A=b+960|0;B=b+19436|0;C=b+19231|0;D=b+9856|0;do{c[l>>2]=0;NTa(g);do{if((c[m>>2]|0)!=0){if((c[B>>2]|0)!=(d[C]|0)){break}E=c[D>>2]|0;c[u>>2]=(c[u>>2]|0)+(c[E+32>>2]|0);c[v>>2]=(c[v>>2]|0)+(c[E+36>>2]|0);c[w>>2]=(c[w>>2]|0)+(c[E+40>>2]|0)}}while(0);E=8>>>((c[(c[n>>2]|0)+800>>2]|0)>>>0);c[o>>2]=(c[o>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+2;c[r>>2]=(c[r>>2]|0)+2;c[s>>2]=(c[s>>2]|0)+1;c[t>>2]=(c[t>>2]|0)+1;F=(c[u>>2]|0)+(E<<1)|0;c[u>>2]=F;c[v>>2]=(c[v>>2]|0)+E;c[w>>2]=(c[w>>2]|0)+E;E=c[x>>2]|0;nrc(F|0,(c[h>>2]|0)+(ca(c[i>>2]<<4,E)|0)|0,E<<4)|0;E=c[z>>2]|0;nrc(c[v>>2]|0,(c[y>>2]|0)+(ca(c[i>>2]<<3,E)|0)|0,E<<3)|0;E=c[z>>2]|0;nrc(c[w>>2]|0,(c[A>>2]|0)+(ca(c[i>>2]<<3,E)|0)|0,E<<3)|0;MTa(g,c[i>>2]<<4,16);c[k>>2]=0;E=(c[i>>2]|0)+1|0;c[i>>2]=E;}while((E|0)<(c[j>>2]|0))}c[e>>2]=2;return}else if((f|0)==3){if((c[b+19548>>2]|0)==0){X6a(b);return}if((c[b+15660>>2]|0)==3){U6a(b);return}else{V6a(b);return}}else if((f|0)==1){if((c[b+15660>>2]|0)==3){U6a(b);return}else{V6a(b);return}}else{return}}function U6a(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0;g=i;i=i+40|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=f|0;o=f+15728|0;p=d[o]|0;q=c[f+16012>>2]|0;if((q|0)==0){c[f+16032>>2]=(c[f+16040>>2]|0)<9?6:2}else if((q|0)==2){c[f+16032>>2]=4}else if((q|0)==1){c[f+16032>>2]=0}q=c[f+16008>>2]|0;if((q|0)==2){c[f+16036>>2]=5}else if((q|0)==0){c[f+16036>>2]=(c[f+16040>>2]|0)<9?7:3}else if((q|0)==1){c[f+16036>>2]=1}q=f+12480|0;r=f+12476|0;c[r>>2]=0;c[f+12488>>2]=1;s=f+14084|0;c[s>>2]=1;t=f+808|0;u=c[t>>2]|0;c[q>>2]=u;if((u|0)==0){v=0;w=f+19428|0;x=f+12496|0;y=f+128|0;z=f+9904|0}else{c[r>>2]=0;NTa(n);u=f+19428|0;do{if((c[u>>2]|0)!=0){if((c[f+19436>>2]|0)!=(d[f+19231|0]|0)){break}A=c[f+9856>>2]|0;B=f+12544|0;c[B>>2]=(c[B>>2]|0)+(c[A+32>>2]|0);B=f+12548|0;c[B>>2]=(c[B>>2]|0)+(c[A+36>>2]|0);B=f+12552|0;c[B>>2]=(c[B>>2]|0)+(c[A+40>>2]|0)}}while(0);A=f+12496|0;B=f+128|0;C=c[B>>2]|0;D=f+9904|0;mrc((c[D>>2]|0)+((c[A>>2]|0)-C)|0,0,C+1|0)|0;v=c[q>>2]|0;w=u;x=A;y=B;z=D}D=f+812|0;B=f+116|0;A=f+13836|0;u=f+19564|0;C=f+19556|0;E=f+4|0;F=f+12500|0;G=f+12504|0;H=f+12508|0;I=f+12512|0;J=f+12516|0;K=f+12544|0;L=f+12548|0;M=f+12552|0;N=f+10096|0;O=f+124|0;P=f+19472|0;Q=f+9160|0;R=f+19468|0;S=f+9152|0;T=f+19328|0;U=f+14128|0;V=f+14136|0;W=f+14120|0;X=f+19256|0;Y=f+19252|0;Z=f+176|0;_=f+19268|0;$=f+19264|0;aa=f+19260|0;ba=f+16004|0;da=f+9136|0;ea=f+9888|0;fa=f+168|0;ga=f+9892|0;ha=f+172|0;ia=f+16044|0;ja=f+16048|0;ka=f+16032|0;la=f+16036|0;ma=f+14072|0;na=f+60|0;oa=f+15332|0;pa=f+9912|0;qa=f+16072|0;ra=f+15992|0;sa=f+16081|0;ta=f+15988|0;ua=f+19224|0;va=f+19332|0;wa=f+15794|0;xa=f+15858|0;ya=f+15922|0;za=f+15576|0;Aa=f+15376|0;Ba=f+15372|0;Ca=f+19576|0;Da=f+19568|0;Ea=f+19572|0;Fa=f+16005|0;Ga=f+16007|0;Ha=f+15729|0;Ia=f+16006|0;Ja=f+120|0;Ka=f+19324|0;La=f+19436|0;Ma=f+19231|0;Na=f+9856|0;Oa=p;p=v;a:while(1){v=(p|0)<(c[D>>2]|0);c[r>>2]=0;NTa(n);do{if((c[w>>2]|0)!=0){if((c[La>>2]|0)!=(d[Ma]|0)){break}Pa=c[Na>>2]|0;c[K>>2]=(c[K>>2]|0)+(c[Pa+32>>2]|0);c[L>>2]=(c[L>>2]|0)+(c[Pa+36>>2]|0);c[M>>2]=(c[M>>2]|0)+(c[Pa+40>>2]|0)}}while(0);Qa=c[B>>2]|0;Ra=(c[r>>2]|0)<(Qa|0);if(!v){break}if(Ra){Pa=Oa;while(1){Sa=c[u>>2]|0;Ta=c[C>>2]|0;Ua=8>>>((c[(c[E>>2]|0)+800>>2]|0)>>>0);c[x>>2]=(c[x>>2]|0)+2;c[F>>2]=(c[F>>2]|0)+2;c[G>>2]=(c[G>>2]|0)+2;c[H>>2]=(c[H>>2]|0)+2;c[I>>2]=(c[I>>2]|0)+1;c[J>>2]=(c[J>>2]|0)+1;c[K>>2]=(c[K>>2]|0)+(Ua<<1);c[L>>2]=(c[L>>2]|0)+Ua;c[M>>2]=(c[M>>2]|0)+Ua;qe[c[N>>2]&1023](Ta+(Sa*768|0)|0);Ua=(ca(c[O>>2]|0,c[q>>2]|0)|0)+(c[r>>2]|0)|0;c[(c[Q>>2]|0)+(Ua+(c[P>>2]|0)<<2)>>2]=1;Va=(c[R>>2]|0)+(c[x>>2]|0)|0;Wa=c[S>>2]|0;b[Wa+(Va<<2)>>1]=0;b[Wa+(Va<<2)+2>>1]=0;if((c[T>>2]|0)!=0){Va=c[U>>2]|0;Wa=d[(c[W>>2]|0)+(Va>>>3)|0]<<(Va&7)>>>7;c[U>>2]=((Va|0)<(c[V>>2]|0))+Va;a[(c[Ka>>2]|0)+Ua|0]=Wa&1}Wa=c[1825693]|0;Va=c[U>>2]|0;Xa=c[V>>2]|0;Ya=c[W>>2]|0;Za=Ya+(Va>>>3)|0;_a=(je(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Va&7)>>>23;Za=b[Wa+(_a<<2)>>1]|0;$a=b[Wa+(_a<<2)+2>>1]|0;_a=$a<<16>>16;if($a<<16>>16<0){$a=Va+9|0;ab=Xa>>>0>$a>>>0?$a:Xa;$a=Ya+(ab>>>3)|0;bb=((je(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(ab&7)>>>((_a+32|0)>>>0))+Za|0;cb=b[Wa+(bb<<2)+2>>1]|0;db=b[Wa+(bb<<2)>>1]|0;eb=ab}else{cb=_a;db=Za;eb=Va}Va=cb+eb|0;Za=Xa>>>0>Va>>>0?Va:Xa;c[U>>2]=Za;if((c[X>>2]|0)==0){fb=Za;gb=d[(c[Y>>2]|0)+Ua|0]|0}else{Va=d[Ya+(Za>>>3)|0]<<(Za&7)>>>7;_a=((Za|0)<(Xa|0))+Za|0;c[U>>2]=_a;fb=_a;gb=Va&1}c[Z>>2]=gb;do{if((a[_]|0)==2){if((c[$>>2]|0)==0){break}Va=d[Ya+(fb>>>3)|0]<<(fb&7)>>>7;c[U>>2]=((fb|0)<(Xa|0))+fb;a[(c[aa>>2]|0)+Ua|0]=Va&1}}while(0);do{if((a[ba]|0)==0){hb=Pa}else{Xa=a[Fa]|0;do{if(Xa<<24>>24==3){Ya=c[U>>2]|0;if((a[Ga]|0)!=0){Va=d[(c[W>>2]|0)+(Ya>>>3)|0]|0;c[U>>2]=((Ya|0)<(c[V>>2]|0))+Ya;ib=d[(Va&128>>>((Ya&7)>>>0)|0)==0?o:Ha]|0;jb=39;break}Va=c[V>>2]|0;_a=c[W>>2]|0;Za=_a+(Ya>>>3)|0;ab=(je(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Ya&7)>>>29;Za=Ya+3|0;Ya=Va>>>0>Za>>>0?Za:Va;c[U>>2]=Ya;if((ab|0)==7){Za=_a+(Ya>>>3)|0;_a=(je(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Ya&7)>>>27;Za=Ya+5|0;c[U>>2]=Va>>>0>Za>>>0?Za:Va;ib=_a;jb=39;break}else{kb=(d[o]|0)+ab|0;break}}else{ib=Pa;jb=39}}while(0);do{if((jb|0)==39){jb=0;if((Xa<<24>>24|0)==1){lb=(3<<d[Ia]|0)%15|0;jb=42}else if((Xa<<24>>24|0)==0){mb=15;jb=43}else if((Xa<<24>>24|0)==2){lb=1<<d[Ia];jb=42}else{kb=ib;break}if((jb|0)==42){jb=0;if((lb&1|0)==0){nb=ib;ob=lb}else{mb=lb;jb=43}}do{if((jb|0)==43){jb=0;if((c[r>>2]|0)!=0){nb=ib;ob=mb;break}nb=d[Ha]|0;ob=mb}}while(0);do{if((ob&2|0)==0){pb=nb}else{if((c[s>>2]|0)==0){pb=nb;break}pb=d[Ha]|0}}while(0);do{if((ob&4|0)==0){qb=pb}else{if((c[r>>2]|0)!=((c[B>>2]|0)-1|0)){qb=pb;break}qb=d[Ha]|0}}while(0);if((ob&8|0)==0){kb=qb;break}if((c[q>>2]|0)!=((c[Ja>>2]|0)-1|0)){kb=qb;break}kb=d[Ha]|0}}while(0);if(!((kb|0)==0|(kb|0)>31)){hb=kb;break}KIb(c[E>>2]|0,16,2267264,(rb=i,i=i+8|0,c[rb>>2]=kb,rb)|0);i=rb;hb=1}}while(0);a[(c[da>>2]|0)+Ua|0]=hb;c[fa>>2]=d[(c[ea>>2]|0)+hb|0]|0;c[ha>>2]=d[(c[ga>>2]|0)+hb|0]|0;Xa=hb<<1;ab=-hb|0;_a=(hb|0)==1;Va=(hb|0)==2;Za=db;Ya=0;do{bb=5-Ya|0;Wa=Za>>>(bb>>>0)&1;$a=(Ya|0)<4;if($a){sb=c[f+12496+(Ya<<2)>>2]|0;tb=c[y>>2]|0;ub=sb-1|0;vb=c[z>>2]|0;wb=a[vb+(sb-tb)|0]|0;if((a[vb+(ub-tb)|0]|0)==wb<<24>>24){xb=a[vb+ub|0]|0}else{xb=wb}wb=xb&255^Wa;a[vb+sb|0]=wb;yb=wb}else{yb=Wa}Za=yb<<bb|Za;bb=(Ya|0)==2;if((c[s>>2]|0)==0|bb){zb=1}else{zb=(Ya|0)==3|0}c[ia>>2]=zb;Wa=c[r>>2]|0;wb=(Ya|0)==1;if((Wa|0)!=0|wb){Ab=1}else{Ab=(Ya|0)==3|0}c[ja>>2]=Ab;sb=Ta+(Sa*768|0)+(Ya<<7)|0;vb=c[($a?ka:la)>>2]|0;c[h>>2]=0;c[j>>2]=0;ub=c[Z>>2]|0;tb=(ca(c[O>>2]|0,c[q>>2]|0)|0)+Wa|0;Wa=c[ma>>2]|0;if($a){Bb=c[7302796+(Wa*20|0)>>2]|0;Cb=c[U>>2]|0;Db=c[V>>2]|0;Eb=c[W>>2]|0;Fb=Eb+(Cb>>>3)|0;Gb=(je(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(Cb&7)>>>23;Fb=b[Bb+(Gb<<2)>>1]|0;Hb=b[Bb+(Gb<<2)+2>>1]|0;Gb=Hb<<16>>16;do{if(Hb<<16>>16<0){Ib=Cb+9|0;Jb=Db>>>0>Ib>>>0?Ib:Db;Ib=Eb+(Jb>>>3)|0;Kb=((je(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)|0)<<(Jb&7)>>>((Gb+32|0)>>>0))+Fb|0;Ib=b[Bb+(Kb<<2)>>1]|0;Lb=b[Bb+(Kb<<2)+2>>1]|0;Kb=Lb<<16>>16;if(!(Lb<<16>>16<0)){Mb=Kb;Nb=Ib;Ob=Jb;break}Lb=Jb-Gb|0;Jb=Db>>>0>Lb>>>0?Lb:Db;Lb=Eb+(Jb>>>3)|0;Pb=((je(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(Jb&7)>>>((Kb+32|0)>>>0))+Ib|0;Mb=b[Bb+(Pb<<2)+2>>1]|0;Nb=b[Bb+(Pb<<2)>>1]|0;Ob=Jb}else{Mb=Gb;Nb=Fb;Ob=Cb}}while(0);Cb=Mb+Ob|0;Qb=Nb;Rb=Db;Sb=Eb;Tb=Db>>>0>Cb>>>0?Cb:Db}else{Cb=c[7302836+(Wa*20|0)>>2]|0;Fb=c[U>>2]|0;Gb=c[V>>2]|0;Bb=c[W>>2]|0;Hb=Bb+(Fb>>>3)|0;Jb=(je(d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0)|0)<<(Fb&7)>>>23;Hb=b[Cb+(Jb<<2)>>1]|0;Pb=b[Cb+(Jb<<2)+2>>1]|0;Jb=Pb<<16>>16;do{if(Pb<<16>>16<0){Ib=Fb+9|0;Kb=Gb>>>0>Ib>>>0?Ib:Gb;Ib=Bb+(Kb>>>3)|0;Lb=((je(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)|0)<<(Kb&7)>>>((Jb+32|0)>>>0))+Hb|0;Ib=b[Cb+(Lb<<2)>>1]|0;Ub=b[Cb+(Lb<<2)+2>>1]|0;Lb=Ub<<16>>16;if(!(Ub<<16>>16<0)){Vb=Lb;Wb=Ib;Xb=Kb;break}Ub=Kb-Jb|0;Kb=Gb>>>0>Ub>>>0?Ub:Gb;Ub=Bb+(Kb>>>3)|0;Yb=((je(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Kb&7)>>>((Lb+32|0)>>>0))+Ib|0;Vb=b[Cb+(Yb<<2)+2>>1]|0;Wb=b[Cb+(Yb<<2)>>1]|0;Xb=Kb}else{Vb=Jb;Wb=Hb;Xb=Fb}}while(0);Fb=Vb+Xb|0;Qb=Wb;Rb=Gb;Sb=Bb;Tb=Gb>>>0>Fb>>>0?Fb:Gb}c[U>>2]=Tb;b:do{if((Qb|0)<0){KIb(c[E>>2]|0,16,2263752,(rb=i,i=i+1|0,i=i+7&-8,c[rb>>2]=0,rb)|0);i=rb}else{do{if((Qb|0)==0){Zb=0}else if((Qb|0)==119){Fb=Sb+(Tb>>>3)|0;Hb=(je(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(Tb&7);if(_a){Fb=Tb+10|0;Jb=Rb>>>0>Fb>>>0?Fb:Rb;c[U>>2]=Jb;_b=Hb>>>22;$b=Jb;jb=86;break}if(Va){Jb=Tb+9|0;Fb=Rb>>>0>Jb>>>0?Jb:Rb;c[U>>2]=Fb;_b=Hb>>>23;$b=Fb;jb=86;break}else{Fb=Tb+8|0;Jb=Rb>>>0>Fb>>>0?Fb:Rb;c[U>>2]=Jb;_b=Hb>>>24;$b=Jb;jb=86;break}}else{if(_a){Jb=Sb+(Tb>>>3)|0;Hb=(je(d[Jb]|d[Jb+1|0]<<8|d[Jb+2|0]<<16|d[Jb+3|0]<<24|0)|0)<<(Tb&7)>>>30;Jb=Tb+2|0;Fb=Rb>>>0>Jb>>>0?Jb:Rb;c[U>>2]=Fb;_b=(Hb|Qb<<2)-3|0;$b=Fb;jb=86;break}if(!Va){_b=Qb;$b=Tb;jb=86;break}Fb=d[Sb+(Tb>>>3)|0]<<(Tb&7)>>>7;Hb=((Tb|0)<(Rb|0))+Tb|0;c[U>>2]=Hb;_b=(Fb&1|Qb<<1)-1|0;$b=Hb;jb=86}}while(0);do{if((jb|0)==86){jb=0;Hb=d[Sb+($b>>>3)|0]|0;c[U>>2]=(($b|0)<(Rb|0))+$b;if((Hb&128>>>(($b&7)>>>0)|0)==0){Zb=_b;break}Zb=-_b|0}}while(0);Hb=(j7a(n,Ya,zb,Ab,j,h)|0)+Zb|0;b[c[j>>2]>>1]=Hb;b[sb>>1]=ca(c[($a?fa:ha)>>2]|0,Hb)|0;Hb=(Ab|zb|0)==0?0:ub;Fb=c[pa>>2]|0;Jb=c[f+12496+(Ya<<2)>>2]<<4;Cb=Fb+(Jb<<1)|0;if((d[o]|0)==(hb|0)){ac=d[qa]|0}else{ac=0}Pb=ac+Xa|0;Wa=c[h>>2]|0;Db=(Wa|0)==0;if(Db){bc=Jb-(c[f+12520+(Ya<<2)>>2]<<4)|0}else{bc=Jb-16|0}Eb=Fb+(bc<<1)|0;Kb=c[da>>2]|0;Yb=a[Kb+tb|0]|0;if(Db|(Ab|0)==0|(tb|0)==0){cc=0}else{cc=a[Kb+(tb-1)|0]|0}Ib=(Wa|0)!=0;do{if(Ib|(zb|0)==0){dc=cc}else{Lb=c[O>>2]|0;if((tb|0)<(Lb|0)){dc=cc;break}dc=a[Kb+(tb-Lb)|0]|0}}while(0);Kb=(Ya|0)==3?Yb:Db&bb?Yb:Ib&wb?Yb:dc;c:do{if((yb|0)==0){Lb=Cb;mrc(Lb|0,0,32)|0;Ub=(Hb|0)!=0;do{if(Db){if(!Ub){ec=1;break c}nrc(Fb+((Jb|8)<<1)|0,Fb+(bc+8<<1)|0,16)|0;if((Kb|0)==0|(Yb|0)==(Kb|0)){break}fc=d[o]|0;if((Yb|0)==(fc|0)){gc=d[qa]|0}else{gc=0}hc=gc+(Yb<<1)|0;if((Kb|0)==(fc|0)){ic=d[qa]|0}else{ic=0}if((hc-1|0)<1){break b}fc=Fb+((Jb|9)<<1)|0;jc=ca(c[1266216+(hc-2<<2)>>2]|0,(Kb<<1)-1+ic|0)|0;b[fc>>1]=(ca(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|10)<<1)|0;b[fc>>1]=(ca(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|11)<<1)|0;b[fc>>1]=(ca(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|12)<<1)|0;b[fc>>1]=(ca(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|13)<<1)|0;b[fc>>1]=(ca(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|14)<<1)|0;b[fc>>1]=(ca(jc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|15)<<1)|0;b[fc>>1]=(ca(jc,b[fc>>1]|0)|0)+131072>>18;jb=143}else{if(!Ub){ec=1;break c}nrc(Lb|0,Eb|0,16)|0;if((Kb|0)==0|(Yb|0)==(Kb|0)){break}fc=d[o]|0;if((Yb|0)==(fc|0)){kc=d[qa]|0}else{kc=0}jc=kc+(Yb<<1)|0;if((Kb|0)==(fc|0)){lc=d[qa]|0}else{lc=0}if((jc-1|0)<1){break b}fc=Fb+((Jb|1)<<1)|0;hc=ca(c[1266216+(jc-2<<2)>>2]|0,(Kb<<1)-1+lc|0)|0;b[fc>>1]=(ca(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|2)<<1)|0;b[fc>>1]=(ca(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|3)<<1)|0;b[fc>>1]=(ca(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|4)<<1)|0;b[fc>>1]=(ca(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|5)<<1)|0;b[fc>>1]=(ca(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|6)<<1)|0;b[fc>>1]=(ca(hc,b[fc>>1]|0)|0)+131072>>18;fc=Fb+((Jb|7)<<1)|0;b[fc>>1]=(ca(hc,b[fc>>1]|0)|0)+131072>>18;jb=143}}while(0);if((jb|0)==143){jb=0;if(!Ub){ec=1;break}}if(Db){Lb=Jb|8;fc=c[ra>>2]|0;hc=1;while(1){jc=ca(b[Fb+(hc+Lb<<1)>>1]|0,Pb)|0;mc=jc&65535;nc=Ta+(Sa*768|0)+(Ya<<7)+(hc<<fc<<1)|0;b[nc>>1]=mc;if(!((a[sa]|0)!=0|mc<<16>>16==0)){b[nc>>1]=(mc<<16>>16<0?ab:hb)+jc}jc=hc+1|0;if((jc|0)<8){hc=jc}else{ec=63;break}}}else{hc=c[ta>>2]|0;fc=1;while(1){Lb=ca(b[Fb+(fc+Jb<<1)>>1]|0,Pb)|0;Ub=Lb&65535;jc=Ta+(Sa*768|0)+(Ya<<7)+(fc<<hc<<1)|0;b[jc>>1]=Ub;if(!((a[sa]|0)!=0|Ub<<16>>16==0)){b[jc>>1]=(Ub<<16>>16<0?ab:hb)+Lb}Lb=fc+1|0;if((Lb|0)<8){fc=Lb}else{ec=63;break}}}}else{c[k>>2]=0;do{if((c[Z>>2]|0)==0){oc=(c[ua>>2]|0)==1?va:wa}else{if((Hb|0)==0){if((c[ua>>2]|0)==1){oc=va;break}}oc=Db?xa:ya}}while(0);fc=1;while(1){i7a(f,k,l,m,vb);hc=(c[l>>2]|0)+fc|0;if((hc|0)>63){pc=hc;break}Lb=hc+1|0;b[Ta+(Sa*768|0)+(Ya<<7)+(d[oc+hc|0]<<1)>>1]=c[m>>2];if((c[k>>2]|0)==0){fc=Lb}else{pc=Lb;break}}fc=(Hb|0)!=0;do{if(fc){if((Kb|0)==0|(Yb|0)==(Kb|0)){if((Wa|0)==0){Lb=c[ra>>2]|0;hc=Ta+(Sa*768|0)+(Ya<<7)+(1<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+9<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(2<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+10<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(3<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+11<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(4<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+12<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(5<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+13<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(6<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+14<<1)>>1]|0);hc=Ta+(Sa*768|0)+(Ya<<7)+(7<<Lb<<1)|0;b[hc>>1]=(b[hc>>1]|0)+(b[Fb+(bc+15<<1)>>1]|0);break}else{hc=c[ta>>2]|0;Lb=Ta+(Sa*768|0)+(Ya<<7)+(1<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+1<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(2<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+2<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(3<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+3<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(4<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+4<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(5<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+5<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(6<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+6<<1)>>1]|0);Lb=Ta+(Sa*768|0)+(Ya<<7)+(7<<hc<<1)|0;b[Lb>>1]=(b[Lb>>1]|0)+(b[Fb+(bc+7<<1)>>1]|0);break}}Lb=d[o]|0;if((Yb|0)==(Lb|0)){qc=d[qa]|0}else{qc=0}hc=qc+(Yb<<1)|0;if((Kb|0)==(Lb|0)){rc=d[qa]|0}else{rc=0}Lb=(Kb<<1)-1+rc|0;if((hc-1|0)<1){break b}Ub=c[1266216+(hc-2<<2)>>2]|0;if((Wa|0)==0){hc=c[ra>>2]|0;jc=ca(Ub,Lb)|0;mc=(ca(jc,b[Fb+(bc+9<<1)>>1]|0)|0)+131072>>18;nc=Ta+(Sa*768|0)+(Ya<<7)+(1<<hc<<1)|0;b[nc>>1]=mc+(e[nc>>1]|0);nc=(ca(jc,b[Fb+(bc+10<<1)>>1]|0)|0)+131072>>18;mc=Ta+(Sa*768|0)+(Ya<<7)+(2<<hc<<1)|0;b[mc>>1]=nc+(e[mc>>1]|0);mc=(ca(jc,b[Fb+(bc+11<<1)>>1]|0)|0)+131072>>18;nc=Ta+(Sa*768|0)+(Ya<<7)+(3<<hc<<1)|0;b[nc>>1]=mc+(e[nc>>1]|0);nc=(ca(jc,b[Fb+(bc+12<<1)>>1]|0)|0)+131072>>18;mc=Ta+(Sa*768|0)+(Ya<<7)+(4<<hc<<1)|0;b[mc>>1]=nc+(e[mc>>1]|0);mc=(ca(jc,b[Fb+(bc+13<<1)>>1]|0)|0)+131072>>18;nc=Ta+(Sa*768|0)+(Ya<<7)+(5<<hc<<1)|0;b[nc>>1]=mc+(e[nc>>1]|0);nc=(ca(jc,b[Fb+(bc+14<<1)>>1]|0)|0)+131072>>18;mc=Ta+(Sa*768|0)+(Ya<<7)+(6<<hc<<1)|0;b[mc>>1]=nc+(e[mc>>1]|0);mc=(ca(jc,b[Fb+(bc+15<<1)>>1]|0)|0)+131072>>18;jc=Ta+(Sa*768|0)+(Ya<<7)+(7<<hc<<1)|0;b[jc>>1]=mc+(e[jc>>1]|0);break}else{jc=c[ta>>2]|0;mc=ca(Ub,Lb)|0;Lb=(ca(mc,b[Fb+(bc+1<<1)>>1]|0)|0)+131072>>18;Ub=Ta+(Sa*768|0)+(Ya<<7)+(1<<jc<<1)|0;b[Ub>>1]=Lb+(e[Ub>>1]|0);Ub=(ca(mc,b[Fb+(bc+2<<1)>>1]|0)|0)+131072>>18;Lb=Ta+(Sa*768|0)+(Ya<<7)+(2<<jc<<1)|0;b[Lb>>1]=Ub+(e[Lb>>1]|0);Lb=(ca(mc,b[Fb+(bc+3<<1)>>1]|0)|0)+131072>>18;Ub=Ta+(Sa*768|0)+(Ya<<7)+(3<<jc<<1)|0;b[Ub>>1]=Lb+(e[Ub>>1]|0);Ub=(ca(mc,b[Fb+(bc+4<<1)>>1]|0)|0)+131072>>18;Lb=Ta+(Sa*768|0)+(Ya<<7)+(4<<jc<<1)|0;b[Lb>>1]=Ub+(e[Lb>>1]|0);Lb=(ca(mc,b[Fb+(bc+5<<1)>>1]|0)|0)+131072>>18;Ub=Ta+(Sa*768|0)+(Ya<<7)+(5<<jc<<1)|0;b[Ub>>1]=Lb+(e[Ub>>1]|0);Ub=(ca(mc,b[Fb+(bc+6<<1)>>1]|0)|0)+131072>>18;Lb=Ta+(Sa*768|0)+(Ya<<7)+(6<<jc<<1)|0;b[Lb>>1]=Ub+(e[Lb>>1]|0);Lb=(ca(mc,b[Fb+(bc+7<<1)>>1]|0)|0)+131072>>18;mc=Ta+(Sa*768|0)+(Ya<<7)+(7<<jc<<1)|0;b[mc>>1]=Lb+(e[mc>>1]|0);break}}}while(0);mc=c[ta>>2]|0;Lb=c[ra>>2]|0;b[Fb+((Jb|1)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(1<<mc<<1)>>1]|0;b[Fb+((Jb|9)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(1<<Lb<<1)>>1]|0;b[Fb+((Jb|2)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(2<<mc<<1)>>1]|0;b[Fb+((Jb|10)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(2<<Lb<<1)>>1]|0;b[Fb+((Jb|3)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(3<<mc<<1)>>1]|0;b[Fb+((Jb|11)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(3<<Lb<<1)>>1]|0;b[Fb+((Jb|4)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(4<<mc<<1)>>1]|0;b[Fb+((Jb|12)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(4<<Lb<<1)>>1]|0;b[Fb+((Jb|5)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(5<<mc<<1)>>1]|0;b[Fb+((Jb|13)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(5<<Lb<<1)>>1]|0;b[Fb+((Jb|6)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(6<<mc<<1)>>1]|0;b[Fb+((Jb|14)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(6<<Lb<<1)>>1]|0;b[Fb+((Jb|7)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(7<<mc<<1)>>1]|0;b[Fb+((Jb|15)<<1)>>1]=b[Ta+(Sa*768|0)+(Ya<<7)+(7<<Lb<<1)>>1]|0;Lb=1;do{mc=Ta+(Sa*768|0)+(Ya<<7)+(Lb<<1)|0;jc=b[mc>>1]|0;do{if(!(jc<<16>>16==0)){Ub=ca(jc<<16>>16,Pb)|0;hc=Ub&65535;b[mc>>1]=hc;if((a[sa]|0)!=0){break}b[mc>>1]=(hc<<16>>16<0?ab:hb)+Ub}}while(0);Lb=Lb+1|0;}while((Lb|0)<64);ec=fc?63:pc}}while(0);c[f+180+(Ya<<2)>>2]=ec}}while(0);if((Ya|0)>3){if((c[na>>2]&8192|0)==0){jb=156}}else{jb=156}if((jb|0)==156){jb=0;qe[c[oa>>2]&1023](sb)}Ya=Ya+1|0;}while((Ya|0)<6);Ya=a[_]|0;do{if(!(Ya<<24>>24==0)){ab=c[r>>2]|0;Sa=(ca(c[O>>2]|0,c[q>>2]|0)|0)+ab|0;Ta=Ya<<24>>24==1;do{if(Ta){jb=162}else{if((d[o]|0)>>>0>8>>>0){jb=162;break}if((a[(c[aa>>2]|0)+Sa|0]|0)==0){sc=ab}else{jb=162}}}while(0);do{if((jb|0)==162){jb=0;d:do{if((ab|0)!=0){do{if(!Ta){if((d[o]|0)>>>0>8>>>0){break}if((a[(c[aa>>2]|0)+(Sa-1)|0]|0)==0){break d}}}while(0);fc=c[C>>2]|0;re[c[Aa>>2]&1023](fc+((c[Da>>2]|0)*768|0)+128|0,fc+((c[u>>2]|0)*768|0)|0);fc=c[C>>2]|0;re[c[Aa>>2]&1023](fc+((c[Da>>2]|0)*768|0)+384|0,fc+((c[u>>2]|0)*768|0)+256|0);if((c[na>>2]&8192|0)!=0){break}fc=c[C>>2]|0;re[c[Aa>>2]&1023](fc+((c[Da>>2]|0)*768|0)+512|0,fc+((c[u>>2]|0)*768|0)+512|0);fc=c[C>>2]|0;re[c[Aa>>2]&1023](fc+((c[Da>>2]|0)*768|0)+640|0,fc+((c[u>>2]|0)*768|0)+640|0)}}while(0);fc=c[u>>2]|0;sb=c[C>>2]|0;re[c[Aa>>2]&1023](sb+(fc*768|0)|0,sb+(fc*768|0)+128|0);fc=c[u>>2]|0;sb=c[C>>2]|0;re[c[Aa>>2]&1023](sb+(fc*768|0)+256|0,sb+(fc*768|0)+384|0);fc=c[r>>2]|0;if((fc|0)!=((c[B>>2]|0)-1|0)){sc=fc;break}e:do{if((c[s>>2]|0)==0){do{if((a[_]|0)!=1){if((d[o]|0)>>>0>8>>>0){break}if((a[(c[aa>>2]|0)+(Sa-(c[O>>2]|0))|0]|0)==0){break e}}}while(0);fc=c[C>>2]|0;re[c[Ba>>2]&1023](fc+((c[Ca>>2]|0)*768|0)+256|0,fc+((c[u>>2]|0)*768|0)|0);fc=c[C>>2]|0;re[c[Ba>>2]&1023](fc+((c[Ca>>2]|0)*768|0)+384|0,fc+((c[u>>2]|0)*768|0)+128|0);if((c[na>>2]&8192|0)!=0){break}fc=c[C>>2]|0;re[c[Ba>>2]&1023](fc+((c[Ca>>2]|0)*768|0)+512|0,fc+((c[u>>2]|0)*768|0)+512|0);fc=c[C>>2]|0;re[c[Ba>>2]&1023](fc+((c[Ca>>2]|0)*768|0)+640|0,fc+((c[u>>2]|0)*768|0)+640|0)}}while(0);fc=c[u>>2]|0;sb=c[C>>2]|0;re[c[Ba>>2]&1023](sb+(fc*768|0)|0,sb+(fc*768|0)+256|0);fc=c[u>>2]|0;sb=c[C>>2]|0;re[c[Ba>>2]&1023](sb+(fc*768|0)+128|0,sb+(fc*768|0)+384|0);sc=c[r>>2]|0}}while(0);if((sc|0)==0){break}Ta=(a[_]|0)==1;if(!Ta){if((a[(c[aa>>2]|0)+(Sa-1)|0]|0)==0){break}}f:do{if((c[s>>2]|0)==0){do{if(!Ta){if((d[o]|0)>>>0>8>>>0){break}if((a[(c[aa>>2]|0)+(Sa-1-(c[O>>2]|0))|0]|0)==0){break f}}}while(0);ab=c[C>>2]|0;re[c[Ba>>2]&1023](ab+((c[Ea>>2]|0)*768|0)+256|0,ab+((c[Da>>2]|0)*768|0)|0);ab=c[C>>2]|0;re[c[Ba>>2]&1023](ab+((c[Ea>>2]|0)*768|0)+384|0,ab+((c[Da>>2]|0)*768|0)+128|0);if((c[na>>2]&8192|0)!=0){break}ab=c[C>>2]|0;re[c[Ba>>2]&1023](ab+((c[Ea>>2]|0)*768|0)+512|0,ab+((c[Da>>2]|0)*768|0)+512|0);ab=c[C>>2]|0;re[c[Ba>>2]&1023](ab+((c[Ea>>2]|0)*768|0)+640|0,ab+((c[Da>>2]|0)*768|0)+640|0)}}while(0);Sa=c[Da>>2]|0;Ta=c[C>>2]|0;re[c[Ba>>2]&1023](Ta+(Sa*768|0)|0,Ta+(Sa*768|0)+256|0);Sa=c[Da>>2]|0;Ta=c[C>>2]|0;re[c[Ba>>2]&1023](Ta+(Sa*768|0)+128|0,Ta+(Sa*768|0)+384|0)}}while(0);t7a(f);if((c[A>>2]|0)!=0){u7a(f,d[o]|0)}if((c[U>>2]|0)>(c[za>>2]|0)){jb=189;break a}Ya=(c[r>>2]|0)+1|0;c[r>>2]=Ya;if((Ya|0)<(c[B>>2]|0)){Pa=hb}else{tc=hb;break}}}else{tc=Oa}Pa=c[q>>2]|0;do{if((c[A>>2]|0)==0){MTa(n,Pa<<4,16)}else{if((Pa|0)==0){break}MTa(n,(Pa<<4)-16|0,16)}}while(0);c[s>>2]=0;Pa=(c[q>>2]|0)+1|0;c[q>>2]=Pa;Oa=tc;p=Pa}if((jb|0)==189){ypb(f+14424|0,0,c[t>>2]|0,c[r>>2]|0,c[q>>2]|0,14);q=c[za>>2]|0;KIb(c[E>>2]|0,16,2227512,(rb=i,i=i+16|0,c[rb>>2]=c[U>>2],c[rb+8>>2]=q,rb)|0);i=rb;i=g;return}if(Ra){while(1){Ra=8>>>((c[(c[E>>2]|0)+800>>2]|0)>>>0);c[x>>2]=(c[x>>2]|0)+2;c[F>>2]=(c[F>>2]|0)+2;c[G>>2]=(c[G>>2]|0)+2;c[H>>2]=(c[H>>2]|0)+2;c[I>>2]=(c[I>>2]|0)+1;c[J>>2]=(c[J>>2]|0)+1;c[K>>2]=(c[K>>2]|0)+(Ra<<1);c[L>>2]=(c[L>>2]|0)+Ra;c[M>>2]=(c[M>>2]|0)+Ra;t7a(f);if((c[A>>2]|0)!=0){u7a(f,d[o]|0)}Ra=(c[r>>2]|0)+1|0;c[r>>2]=Ra;rb=c[B>>2]|0;if((Ra|0)>=(rb|0)){uc=rb;break}}}else{uc=Qa}if((c[A>>2]|0)==0){vc=uc}else{MTa(n,(c[D>>2]<<4)-16|0,16);vc=c[B>>2]|0}B=c[w>>2]|0;ypb(f+14424|0,0,c[t>>2]<<B,vc-1|0,(c[D>>2]<<B)-1|0,112);i=g;return}function V6a(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0;g=i;i=i+48|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=f|0;n=c[f+16012>>2]|0;if((n|0)==2){c[f+16032>>2]=4}else if((n|0)==1){c[f+16032>>2]=0}else if((n|0)==0){c[f+16032>>2]=(c[f+16040>>2]|0)<9?6:2}n=c[f+16008>>2]|0;if((n|0)==1){c[f+16036>>2]=1}else if((n|0)==2){c[f+16036>>2]=5}else if((n|0)==0){c[f+16036>>2]=(c[f+16040>>2]|0)<9?7:3}n=f+15728|0;o=d[n]|0;p=f+168|0;c[p>>2]=d[(c[f+9888>>2]|0)+o|0]|0;q=f+172|0;c[q>>2]=d[(c[f+9892>>2]|0)+o|0]|0;o=f+12480|0;r=f+12476|0;c[r>>2]=0;c[f+12488>>2]=1;s=f+14084|0;c[s>>2]=1;c[o>>2]=0;t=f+812|0;u=c[t>>2]|0;a:do{if((u|0)>0){v=f+19428|0;w=f+19436|0;x=f+19231|0;y=f+9856|0;z=f+12544|0;A=f+12548|0;B=f+12552|0;C=f+19608|0;D=f+13836|0;E=f+4|0;F=f+12496|0;G=f+12500|0;H=f+12504|0;I=f+12508|0;J=f+12512|0;K=f+12516|0;L=l|0;M=l+4|0;N=f+148|0;O=l+8|0;P=l+12|0;Q=l+16|0;R=l+20|0;S=f+10096|0;T=f+14340|0;U=f+116|0;V=f+9160|0;W=f+9136|0;X=f+9152|0;Y=f+14128|0;Z=f+14136|0;_=f+14120|0;$=f+176|0;aa=f+128|0;ba=f+9904|0;da=f+16032|0;ea=f+16036|0;fa=f+14072|0;ga=f+60|0;ha=f+15332|0;ia=f+15696|0;ja=f+19220|0;ka=f+10068|0;la=f+152|0;ma=f+10064|0;na=f+9876|0;oa=f+16072|0;pa=f+9912|0;qa=f+15992|0;ra=f+16081|0;sa=f+15988|0;ta=f+15794|0;ua=f+15858|0;va=f+15922|0;wa=f+15368|0;xa=f+15364|0;ya=f+15576|0;b:while(1){c[r>>2]=0;NTa(m);do{if((c[v>>2]|0)!=0){if((c[w>>2]|0)!=(d[x]|0)){break}za=c[y>>2]|0;c[z>>2]=(c[z>>2]|0)+(c[za+32>>2]|0);c[A>>2]=(c[A>>2]|0)+(c[za+36>>2]|0);c[B>>2]=(c[B>>2]|0)+(c[za+40>>2]|0)}}while(0);if((c[r>>2]|0)<(c[C>>2]|0)){do{za=8>>>((c[(c[E>>2]|0)+800>>2]|0)>>>0);c[F>>2]=(c[F>>2]|0)+2;c[G>>2]=(c[G>>2]|0)+2;c[H>>2]=(c[H>>2]|0)+2;c[I>>2]=(c[I>>2]|0)+2;c[J>>2]=(c[J>>2]|0)+1;c[K>>2]=(c[K>>2]|0)+1;Aa=za<<1;Ba=c[z>>2]|0;Ca=Ba+Aa|0;c[z>>2]=Ca;Da=(c[A>>2]|0)+za|0;c[A>>2]=Da;Ea=(c[B>>2]|0)+za|0;c[B>>2]=Ea;c[L>>2]=Ca;c[M>>2]=Ba+(Aa+8);Ca=c[N>>2]<<3;c[O>>2]=Ba+(Aa+Ca);c[P>>2]=Ba+(Aa+(Ca+8));c[Q>>2]=Da;c[R>>2]=Ea;qe[c[S>>2]&1023](c[T>>2]|0);Ea=(ca(c[U>>2]|0,c[o>>2]|0)|0)+(c[r>>2]|0)|0;c[(c[V>>2]|0)+(Ea<<2)>>2]=1;a[(c[W>>2]|0)+Ea|0]=a[n]|0;Ea=c[F>>2]|0;Da=c[X>>2]|0;b[Da+(Ea<<2)>>1]=0;b[Da+(Ea<<2)+2>>1]=0;Ea=c[1825693]|0;Da=c[Y>>2]|0;Ca=c[Z>>2]|0;Aa=c[_>>2]|0;Ba=Aa+(Da>>>3)|0;za=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Da&7)>>>23;Ba=b[Ea+(za<<2)>>1]|0;Fa=b[Ea+(za<<2)+2>>1]|0;za=Fa<<16>>16;if(Fa<<16>>16<0){Fa=Da+9|0;Ga=Ca>>>0>Fa>>>0?Fa:Ca;Fa=Aa+(Ga>>>3)|0;Ha=((je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ga&7)>>>((za+32|0)>>>0))+Ba|0;Ia=b[Ea+(Ha<<2)+2>>1]|0;Ja=b[Ea+(Ha<<2)>>1]|0;Ka=Ga}else{Ia=za;Ja=Ba;Ka=Da}Da=Ia+Ka|0;Ba=Ca>>>0>Da>>>0?Da:Ca;c[Y>>2]=Ba;Da=d[Aa+(Ba>>>3)|0]<<(Ba&7)>>>7;c[Y>>2]=((Ba|0)<(Ca|0))+Ba;c[$>>2]=Da&1;Da=Ja;Ba=0;do{Ca=5-Ba|0;Aa=Da>>>(Ca>>>0)&1;za=(Ba|0)<4;if(za){Ga=c[f+12496+(Ba<<2)>>2]|0;Ha=c[aa>>2]|0;Ea=Ga-1|0;Fa=c[ba>>2]|0;La=a[Fa+(Ga-Ha)|0]|0;if((a[Fa+(Ea-Ha)|0]|0)==La<<24>>24){Ma=a[Fa+Ea|0]|0}else{Ma=La}La=Ma&255^Aa;a[Fa+Ga|0]=La;Na=La}else{Na=Aa}Da=Na<<Ca|Da;Ca=c[T>>2]|0;Aa=Ca+(Ba<<7)|0;La=c[(za?da:ea)>>2]|0;Ga=c[fa>>2]|0;if(za){Fa=c[7302796+(Ga*20|0)>>2]|0;Ea=c[Y>>2]|0;Ha=c[Z>>2]|0;Oa=c[_>>2]|0;Pa=Oa+(Ea>>>3)|0;Qa=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Ea&7)>>>23;Pa=b[Fa+(Qa<<2)>>1]|0;Ra=b[Fa+(Qa<<2)+2>>1]|0;Qa=Ra<<16>>16;do{if(Ra<<16>>16<0){Sa=Ea+9|0;Ta=Ha>>>0>Sa>>>0?Sa:Ha;Sa=Oa+(Ta>>>3)|0;Ua=((je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ta&7)>>>((Qa+32|0)>>>0))+Pa|0;Sa=b[Fa+(Ua<<2)>>1]|0;Va=b[Fa+(Ua<<2)+2>>1]|0;Ua=Va<<16>>16;if(!(Va<<16>>16<0)){Wa=Ua;Xa=Sa;Ya=Ta;break}Va=Ta-Qa|0;Ta=Ha>>>0>Va>>>0?Va:Ha;Va=Oa+(Ta>>>3)|0;Za=((je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)>>>((Ua+32|0)>>>0))+Sa|0;Wa=b[Fa+(Za<<2)+2>>1]|0;Xa=b[Fa+(Za<<2)>>1]|0;Ya=Ta}else{Wa=Qa;Xa=Pa;Ya=Ea}}while(0);Ea=Wa+Ya|0;_a=Xa;$a=Ha;ab=Oa;bb=Ha>>>0>Ea>>>0?Ea:Ha}else{Ea=c[7302836+(Ga*20|0)>>2]|0;Pa=c[Y>>2]|0;Qa=c[Z>>2]|0;Fa=c[_>>2]|0;Ra=Fa+(Pa>>>3)|0;Ta=(je(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Pa&7)>>>23;Ra=b[Ea+(Ta<<2)>>1]|0;Za=b[Ea+(Ta<<2)+2>>1]|0;Ta=Za<<16>>16;do{if(Za<<16>>16<0){Sa=Pa+9|0;Ua=Qa>>>0>Sa>>>0?Sa:Qa;Sa=Fa+(Ua>>>3)|0;Va=((je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ua&7)>>>((Ta+32|0)>>>0))+Ra|0;Sa=b[Ea+(Va<<2)>>1]|0;cb=b[Ea+(Va<<2)+2>>1]|0;Va=cb<<16>>16;if(!(cb<<16>>16<0)){db=Va;eb=Sa;fb=Ua;break}cb=Ua-Ta|0;Ua=Qa>>>0>cb>>>0?cb:Qa;cb=Fa+(Ua>>>3)|0;gb=((je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Ua&7)>>>((Va+32|0)>>>0))+Sa|0;db=b[Ea+(gb<<2)+2>>1]|0;eb=b[Ea+(gb<<2)>>1]|0;fb=Ua}else{db=Ta;eb=Ra;fb=Pa}}while(0);Pa=db+fb|0;_a=eb;$a=Qa;ab=Fa;bb=Qa>>>0>Pa>>>0?Pa:Qa}c[Y>>2]=bb;if((_a|0)<0){KIb(c[E>>2]|0,16,2263752,(hb=i,i=i+1|0,i=i+7&-8,c[hb>>2]=0,hb)|0);i=hb}else{do{if((_a|0)==0){ib=0;jb=a[n]|0}else{Pa=a[n]|0;Ra=Pa<<24>>24==1;do{if((_a|0)==119){if(Ra){Ta=ab+(bb>>>3)|0;Ea=(je(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(bb&7)>>>22;Ta=bb+10|0;Za=$a>>>0>Ta>>>0?Ta:$a;c[Y>>2]=Za;kb=Ea;lb=Za;break}Za=ab+(bb>>>3)|0;Ea=(je(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(bb&7);if(Pa<<24>>24==2){Za=bb+9|0;Ta=$a>>>0>Za>>>0?Za:$a;c[Y>>2]=Ta;kb=Ea>>>23;lb=Ta;break}else{Ta=bb+8|0;Za=$a>>>0>Ta>>>0?Ta:$a;c[Y>>2]=Za;kb=Ea>>>24;lb=Za;break}}else{if(Ra){Za=ab+(bb>>>3)|0;Ea=(je(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(bb&7)>>>30;Za=bb+2|0;Ta=$a>>>0>Za>>>0?Za:$a;c[Y>>2]=Ta;kb=(Ea|_a<<2)-3|0;lb=Ta;break}if(!(Pa<<24>>24==2)){kb=_a;lb=bb;break}Ta=d[ab+(bb>>>3)|0]<<(bb&7)>>>7;Ea=((bb|0)<($a|0))+bb|0;c[Y>>2]=Ea;kb=(Ta&1|_a<<1)-1|0;lb=Ea}}while(0);Ra=d[ab+(lb>>>3)|0]|0;c[Y>>2]=((lb|0)<($a|0))+lb;if((Ra&128>>>((lb&7)>>>0)|0)==0){ib=kb;jb=Pa;break}ib=-kb|0;jb=Pa}}while(0);Qa=za?p:q;Fa=c[Qa>>2]|0;Ra=f+12520+(Ba<<2)|0;Ea=c[Ra>>2]|0;Ta=c[na>>2]|0;Za=f+12496+(Ba<<2)|0;Ga=c[Za>>2]|0;Ha=Ta+(Ga<<1)|0;Oa=b[Ta+(Ga-1<<1)>>1]|0;Ua=b[Ta+(Ga+~Ea<<1)>>1]|0;gb=b[Ta+(Ga-Ea<<1)>>1]|0;Ea=(c[s>>2]|0)==0;do{if((jb&255)>>>0<9>>>0|(c[ia>>2]|0)==0){do{if(Ea){mb=gb;nb=Ua}else{if(!((Ba-2|0)>>>0>1>>>0)){mb=gb;nb=Ua;break}Ga=e[267976+(Fa<<1)>>1]|0;mb=Ga;nb=Ga}}while(0);if((c[r>>2]|0)!=0){ob=mb;pb=nb;qb=Oa;break}if((Ba|0)==3|(Ba|0)==1){ob=mb;pb=nb;qb=Oa;break}Pa=e[267976+(Fa<<1)>>1]|0;ob=mb;pb=Pa;qb=Pa}else{if(Ea){rb=gb;sb=Ua}else{Pa=(Ba-2|0)>>>0>1>>>0;rb=Pa?0:gb;sb=Pa?0:Ua}if((c[r>>2]|0)!=0){ob=rb;pb=sb;qb=Oa;break}if((Ba|0)==3|(Ba|0)==1){ob=rb;pb=sb;qb=Oa;break}ob=rb;pb=0;qb=0}}while(0);Oa=ob-pb|0;Ua=pb-qb|0;gb=(((Oa|0)>-1?Oa:-Oa|0)|0)>(((Ua|0)>-1?Ua:-Ua|0)|0);Ua=(gb?ob:qb)+ib|0;b[Ha>>1]=Ua;b[Aa>>1]=ca(Ua,c[Qa>>2]|0)|0;do{if((Na|0)==0){Ua=c[pa>>2]|0;Oa=c[Za>>2]<<4;Ea=(d[n]<<1)+(d[oa]|0)|0;Fa=Ua+(Oa<<1)|0;mrc(Fa|0,0,32)|0;if(gb){za=Oa-(c[Ra>>2]<<4)|0;if((c[$>>2]|0)==0){tb=0;break}nrc(Ua+((Oa|8)<<1)|0,Ua+((za|8)<<1)|0,16)|0;ub=Ua+(za<<1)|0}else{za=Ua+(Oa-16<<1)|0;if((c[$>>2]|0)==0){tb=0;break}nrc(Fa|0,za|0,16)|0;ub=za}if((c[$>>2]|0)==0){tb=0;break}if(gb){za=c[qa>>2]|0;Fa=1;while(1){Oa=ca(b[ub+(Fa+8<<1)>>1]|0,Ea)|0;Ua=Oa&65535;Pa=Ca+(Ba<<7)+(Fa<<za<<1)|0;b[Pa>>1]=Ua;if(!((a[ra]|0)!=0|Ua<<16>>16==0)){Ga=d[n]|0;b[Pa>>1]=(Ua<<16>>16<0?-Ga|0:Ga)+Oa}Oa=Fa+1|0;if((Oa|0)<8){Fa=Oa}else{tb=63;break}}}else{Fa=c[sa>>2]|0;za=1;while(1){Oa=ca(b[ub+(za<<1)>>1]|0,Ea)|0;Ga=Oa&65535;Ua=Ca+(Ba<<7)+(za<<Fa<<1)|0;b[Ua>>1]=Ga;if(!((a[ra]|0)!=0|Ga<<16>>16==0)){Pa=d[n]|0;b[Ua>>1]=(Ga<<16>>16<0?-Pa|0:Pa)+Oa}Oa=za+1|0;if((Oa|0)<8){za=Oa}else{tb=63;break}}}}else{c[h>>2]=0;za=(d[n]<<1)+(d[oa]|0)&65535;Fa=(c[$>>2]|0)==0;Ea=c[pa>>2]|0;Oa=c[Za>>2]<<4;if(gb){vb=Fa?ta:ua;wb=1;xb=Oa-(c[Ra>>2]<<4)|0}else{vb=Fa?ta:va;wb=0;xb=Oa-16|0}Fa=1;while(1){i7a(f,h,j,k,La);Pa=(c[j>>2]|0)+Fa|0;if((Pa|0)>63){yb=Pa;break}Ga=Pa+1|0;b[Ca+(Ba<<7)+(d[vb+Pa|0]<<1)>>1]=c[k>>2];if((c[h>>2]|0)==0){Fa=Ga}else{yb=Ga;break}}Fa=(c[$>>2]|0)==0;do{if(!Fa){if(wb){Ga=c[qa>>2]|0;Pa=Ca+(Ba<<7)+(1<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+9<<1)>>1]|0);Pa=Ca+(Ba<<7)+(2<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+10<<1)>>1]|0);Pa=Ca+(Ba<<7)+(3<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+11<<1)>>1]|0);Pa=Ca+(Ba<<7)+(4<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+12<<1)>>1]|0);Pa=Ca+(Ba<<7)+(5<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+13<<1)>>1]|0);Pa=Ca+(Ba<<7)+(6<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+14<<1)>>1]|0);Pa=Ca+(Ba<<7)+(7<<Ga<<1)|0;b[Pa>>1]=(b[Pa>>1]|0)+(b[Ea+(xb+15<<1)>>1]|0);break}else{Pa=c[sa>>2]|0;Ga=Ca+(Ba<<7)+(1<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+1<<1)>>1]|0);Ga=Ca+(Ba<<7)+(2<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+2<<1)>>1]|0);Ga=Ca+(Ba<<7)+(3<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+3<<1)>>1]|0);Ga=Ca+(Ba<<7)+(4<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+4<<1)>>1]|0);Ga=Ca+(Ba<<7)+(5<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+5<<1)>>1]|0);Ga=Ca+(Ba<<7)+(6<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+6<<1)>>1]|0);Ga=Ca+(Ba<<7)+(7<<Pa<<1)|0;b[Ga>>1]=(b[Ga>>1]|0)+(b[Ea+(xb+7<<1)>>1]|0);break}}}while(0);Ga=c[sa>>2]|0;Pa=c[qa>>2]|0;b[Ea+((Oa|1)<<1)>>1]=b[Ca+(Ba<<7)+(1<<Ga<<1)>>1]|0;b[Ea+((Oa|9)<<1)>>1]=b[Ca+(Ba<<7)+(1<<Pa<<1)>>1]|0;b[Ea+((Oa|2)<<1)>>1]=b[Ca+(Ba<<7)+(2<<Ga<<1)>>1]|0;b[Ea+((Oa|10)<<1)>>1]=b[Ca+(Ba<<7)+(2<<Pa<<1)>>1]|0;b[Ea+((Oa|3)<<1)>>1]=b[Ca+(Ba<<7)+(3<<Ga<<1)>>1]|0;b[Ea+((Oa|11)<<1)>>1]=b[Ca+(Ba<<7)+(3<<Pa<<1)>>1]|0;b[Ea+((Oa|4)<<1)>>1]=b[Ca+(Ba<<7)+(4<<Ga<<1)>>1]|0;b[Ea+((Oa|12)<<1)>>1]=b[Ca+(Ba<<7)+(4<<Pa<<1)>>1]|0;b[Ea+((Oa|5)<<1)>>1]=b[Ca+(Ba<<7)+(5<<Ga<<1)>>1]|0;b[Ea+((Oa|13)<<1)>>1]=b[Ca+(Ba<<7)+(5<<Pa<<1)>>1]|0;b[Ea+((Oa|6)<<1)>>1]=b[Ca+(Ba<<7)+(6<<Ga<<1)>>1]|0;b[Ea+((Oa|14)<<1)>>1]=b[Ca+(Ba<<7)+(6<<Pa<<1)>>1]|0;b[Ea+((Oa|7)<<1)>>1]=b[Ca+(Ba<<7)+(7<<Ga<<1)>>1]|0;b[Ea+((Oa|15)<<1)>>1]=b[Ca+(Ba<<7)+(7<<Pa<<1)>>1]|0;Pa=1;do{Ga=Ca+(Ba<<7)+(Pa<<1)|0;Ua=b[Ga>>1]|0;do{if(!(Ua<<16>>16==0)){Ta=ca(Ua,za)|0;b[Ga>>1]=Ta;if((a[ra]|0)!=0){break}Sa=d[n]|0;b[Ga>>1]=(Ta<<16>>16<0?-Sa|0:Sa)+(Ta&65535)}}while(0);Pa=Pa+1|0;}while((Pa|0)<64);tb=Fa?yb:63}}while(0);c[f+180+(Ba<<2)>>2]=tb}if((Ba|0)>3){if((c[ga>>2]&8192|0)==0){zb=95}}else{zb=95}c:do{if((zb|0)==95){zb=0;qe[c[ha>>2]&1023]((c[T>>2]|0)+(Ba<<7)|0);do{if((d[n]|0)>>>0>8>>>0){if((c[ia>>2]|0)==0){break}Ca=c[T>>2]|0;if((a[ja]|0)!=0){La=0;do{Ra=Ca+(Ba<<7)+(La<<1)|0;b[Ra>>1]=b[Ra>>1]<<1;La=La+1|0;}while((La|0)<64)}ef[c[ka>>2]&4095](Ca+(Ba<<7)|0,c[l+(Ba<<2)>>2]|0,c[((Ba&4|0)==0?N:la)>>2]|0);break c}}while(0);Fa=c[T>>2]|0;if((a[ja]|0)!=0){La=0;do{Ra=Fa+(Ba<<7)+(La<<1)|0;b[Ra>>1]=(b[Ra>>1]<<1)-128;La=La+1|0;}while((La|0)<64)}ef[c[ma>>2]&4095](Fa+(Ba<<7)|0,c[l+(Ba<<2)>>2]|0,c[((Ba&4|0)==0?N:la)>>2]|0)}}while(0);Ba=Ba+1|0;}while((Ba|0)<6);do{if((d[n]|0)>>>0>8>>>0){if((c[ia>>2]|0)==0){break}do{if((c[r>>2]|0)!=0){re[c[wa>>2]&1023](c[z>>2]|0,c[N>>2]|0);Ba=c[N>>2]|0;re[c[wa>>2]&1023]((c[z>>2]|0)+(Ba<<3)|0,Ba);if((c[ga>>2]&8192|0)!=0){break}re[c[wa>>2]&1023](c[A>>2]|0,c[la>>2]|0);re[c[wa>>2]&1023](c[B>>2]|0,c[la>>2]|0)}}while(0);re[c[wa>>2]&1023]((c[z>>2]|0)+8|0,c[N>>2]|0);Ba=c[N>>2]|0;re[c[wa>>2]&1023]((c[z>>2]|0)+((Ba<<3)+8)|0,Ba);do{if((c[s>>2]|0)==0){re[c[xa>>2]&1023](c[z>>2]|0,c[N>>2]|0);re[c[xa>>2]&1023]((c[z>>2]|0)+8|0,c[N>>2]|0);if((c[ga>>2]&8192|0)!=0){break}re[c[xa>>2]&1023](c[A>>2]|0,c[la>>2]|0);re[c[xa>>2]&1023](c[B>>2]|0,c[la>>2]|0)}}while(0);Ba=c[N>>2]|0;re[c[xa>>2]&1023]((c[z>>2]|0)+(Ba<<3)|0,Ba);Ba=c[N>>2]|0;re[c[xa>>2]&1023]((c[z>>2]|0)+((Ba<<3)+8)|0,Ba)}}while(0);if((c[D>>2]|0)!=0){e7a(f,d[n]|0)}if((c[Y>>2]|0)>(c[ya>>2]|0)){break b}Ba=(c[r>>2]|0)+1|0;c[r>>2]=Ba;}while((Ba|0)<(c[C>>2]|0))}Ba=c[o>>2]|0;do{if((c[D>>2]|0)==0){MTa(m,Ba<<4,16)}else{if((Ba|0)==0){break}MTa(m,(Ba<<4)-16|0,16)}}while(0);c[s>>2]=0;Ba=(c[o>>2]|0)+1|0;c[o>>2]=Ba;Da=c[t>>2]|0;if((Ba|0)>=(Da|0)){Ab=Da;Bb=D;break a}}ypb(f+14424|0,0,0,c[r>>2]|0,c[o>>2]|0,14);D=c[ya>>2]|0;KIb(c[E>>2]|0,16,2227512,(hb=i,i=i+16|0,c[hb>>2]=c[Y>>2],c[hb+8>>2]=D,hb)|0);i=hb;i=g;return}else{Ab=u;Bb=f+13836|0}}while(0);if((c[Bb>>2]|0)!=0){MTa(m,(Ab<<4)-16|0,16)}ypb(f+14424|0,0,0,(c[f+116>>2]|0)-1|0,(c[f+120>>2]|0)-1|0,112);i=g;return}function W6a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+32|0;k=f+56|0;l=f+64|0;m=e|0;n=c[e+16008>>2]|0;if((n|0)==0){c[e+16032>>2]=(c[e+16040>>2]|0)<9?6:2;c[e+16036>>2]=(c[e+16040>>2]|0)<9?7:3}else if((n|0)==1){c[e+16032>>2]=0;c[e+16036>>2]=1}else if((n|0)==2){c[e+16032>>2]=4;c[e+16036>>2]=5}do{if((c[e+13836>>2]|0)==0){o=0}else{if((c[(c[e+4>>2]|0)+848>>2]|0)>31){o=0;break}o=(c[e+19224>>2]|0)==0}}while(0);n=e+14084|0;c[n>>2]=1;p=e+19580|0;q=e+124|0;mrc(c[p>>2]|0,0,c[q>>2]<<3|0)|0;r=e+808|0;s=c[r>>2]|0;t=e+12480|0;c[t>>2]=s;u=e+812|0;v=c[u>>2]|0;a:do{if((s|0)<(v|0)){w=e+12476|0;x=e+19428|0;y=e+19436|0;z=e+19231|0;A=e+9856|0;B=e+12544|0;C=e+12548|0;D=e+12552|0;E=e+116|0;F=e+19584|0;G=e+16024|0;H=e+16028|0;I=e+19588|0;J=e+19592|0;K=e+19596|0;L=e+19600|0;M=e+4|0;N=e+12496|0;O=e+12500|0;P=e+12504|0;Q=e+12508|0;R=e+12512|0;S=e+12516|0;T=e+19224|0;U=e+16016|0;V=e+15728|0;W=e+16104|0;X=e+16092|0;Y=e+16116|0;Z=e+9928|0;_=e+12488|0;$=e+16056|0;aa=e+9876|0;ba=e+9160|0;da=e+9136|0;ea=e+15720|0;fa=e+15724|0;ga=e+14060|0;ha=e+14128|0;ia=e+14136|0;ja=e+14120|0;ka=e+13924|0;la=e+16004|0;ma=e+176|0;na=e+16005|0;oa=e+16007|0;pa=e+15729|0;qa=e+16006|0;ra=e+120|0;sa=e+16020|0;ta=e+16088|0;ua=e+14340|0;va=e+152|0;wa=e+148|0;xa=e+60|0;ya=e+16048|0;za=e+16044|0;Aa=e+16036|0;Ba=e+16032|0;Ca=e+15332|0;Da=e+19220|0;Ea=e+10068|0;Fa=e+15696|0;Ga=e+15364|0;Ha=e+15368|0;Ia=e+16084|0;Ja=e+15712|0;Ka=e+15716|0;La=e+9152|0;Ma=o^1;Na=e+15576|0;Oa=e+19304|0;Pa=e+14120|0;Qa=e+19468|0;Ra=e+19472|0;Sa=e+9888|0;Ta=e+168|0;Ua=e+9892|0;Va=e+172|0;Wa=e+19252|0;Xa=e+19444|0;Ya=e+19288|0;Za=e+19308|0;_a=e+19316|0;$a=e+19321|0;ab=e+19292|0;bb=e+19324|0;cb=e+19320|0;db=e+19312|0;eb=e+19400|0;b:while(1){c[w>>2]=0;NTa(m);do{if((c[x>>2]|0)!=0){if((c[y>>2]|0)!=(d[z]|0)){break}fb=c[A>>2]|0;c[B>>2]=(c[B>>2]|0)+(c[fb+32>>2]|0);c[C>>2]=(c[C>>2]|0)+(c[fb+36>>2]|0);c[D>>2]=(c[D>>2]|0)+(c[fb+40>>2]|0)}}while(0);fb=c[w>>2]|0;if((fb|0)<(c[E>>2]|0)){gb=fb;while(1){fb=8>>>((c[(c[M>>2]|0)+800>>2]|0)>>>0);hb=(c[N>>2]|0)+2|0;c[N>>2]=hb;c[O>>2]=(c[O>>2]|0)+2;c[P>>2]=(c[P>>2]|0)+2;c[Q>>2]=(c[Q>>2]|0)+2;c[R>>2]=(c[R>>2]|0)+1;c[S>>2]=(c[S>>2]|0)+1;c[B>>2]=(c[B>>2]|0)+(fb<<1);c[C>>2]=(c[C>>2]|0)+fb;c[D>>2]=(c[D>>2]|0)+fb;fb=c[T>>2]|0;do{if((fb|0)==2){ib=(ca(c[q>>2]|0,c[t>>2]|0)|0)+gb|0;jb=c[U>>2]|0;c[l>>2]=0;kb=d[V]|0;lb=c[(c[Oa>>2]|0)+4>>2]|0;mb=c[ha>>2]|0;nb=c[ia>>2]|0;ob=c[Pa>>2]|0;pb=ob+(mb>>>3)|0;qb=(je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(mb&7)>>>27;pb=b[lb+(qb<<2)>>1]|0;rb=b[lb+(qb<<2)+2>>1]|0;qb=rb<<16>>16;if(rb<<16>>16<0){rb=mb+5|0;sb=nb>>>0>rb>>>0?rb:nb;rb=ob+(sb>>>3)|0;ob=((je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(sb&7)>>>((qb+32|0)>>>0))+pb|0;tb=b[lb+(ob<<2)+2>>1]|0;ub=b[lb+(ob<<2)>>1]|0;vb=sb}else{tb=qb;ub=pb;vb=mb}mb=tb+vb|0;c[ha>>2]=nb>>>0>mb>>>0?mb:nb;nb=(c[J>>2]|0)+gb|0;if((ub|0)<2){a[nb]=1;c[_>>2]=1;mb=(c[Qa>>2]|0)+(c[N>>2]|0)|0;pb=c[La>>2]|0;b[pb+(mb<<2)>>1]=0;b[pb+(mb<<2)+2>>1]=0;c[(c[ba>>2]|0)+((c[Ra>>2]|0)+ib<<2)>>2]=1;do{if((a[la]|0)==0){wb=kb}else{mb=a[na]|0;do{if(mb<<24>>24==3){pb=c[ha>>2]|0;if((a[oa]|0)!=0){qb=d[(c[Pa>>2]|0)+(pb>>>3)|0]|0;c[ha>>2]=((pb|0)<(c[ia>>2]|0))+pb;xb=d[(qb&128>>>((pb&7)>>>0)|0)==0?V:pa]|0;break}qb=c[ia>>2]|0;sb=c[Pa>>2]|0;ob=sb+(pb>>>3)|0;lb=(je(d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0)|0)<<(pb&7)>>>29;ob=pb+3|0;pb=qb>>>0>ob>>>0?ob:qb;c[ha>>2]=pb;if((lb|0)==7){ob=sb+(pb>>>3)|0;sb=(je(d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0)|0)<<(pb&7)>>>27;ob=pb+5|0;c[ha>>2]=qb>>>0>ob>>>0?ob:qb;yb=sb;zb=25;break}else{xb=(d[V]|0)+lb|0;break}}else{yb=kb;zb=25}}while(0);do{if((zb|0)==25){zb=0;if((mb<<24>>24|0)==2){Ab=1<<d[qa];zb=28}else if((mb<<24>>24|0)==1){Ab=(3<<d[qa]|0)%15|0;zb=28}else if((mb<<24>>24|0)==0){Bb=15;zb=29}else{xb=yb;break}if((zb|0)==28){zb=0;if((Ab&1|0)==0){Cb=yb;Db=Ab}else{Bb=Ab;zb=29}}do{if((zb|0)==29){zb=0;if((c[w>>2]|0)!=0){Cb=yb;Db=Bb;break}Cb=d[pa]|0;Db=Bb}}while(0);do{if((Db&2|0)==0){Eb=Cb}else{if((c[n>>2]|0)==0){Eb=Cb;break}Eb=d[pa]|0}}while(0);do{if((Db&4|0)==0){Fb=Eb}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){Fb=Eb;break}Fb=d[pa]|0}}while(0);if((Db&8|0)==0){xb=Fb;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){xb=Fb;break}xb=d[pa]|0}}while(0);if(!((xb|0)==0|(xb|0)>31)){wb=xb;break}KIb(c[M>>2]|0,16,2267264,(Gb=i,i=i+8|0,c[Gb>>2]=xb,Gb)|0);i=Gb;wb=1}}while(0);a[(c[da>>2]|0)+ib|0]=wb;c[Ta>>2]=d[(c[Sa>>2]|0)+wb|0]|0;c[Va>>2]=d[(c[Ua>>2]|0)+wb|0]|0;mb=c[ha>>2]|0;lb=d[(c[Pa>>2]|0)+(mb>>>3)|0]<<(mb&7)>>>7;c[ha>>2]=((mb|0)<(c[ia>>2]|0))+mb;mb=lb&1;a[(c[Wa>>2]|0)+ib|0]=mb;c[ma>>2]=mb;if((ub&1|0)==0){Hb=0}else{mb=c[(c[Ia>>2]|0)+4>>2]|0;lb=c[ha>>2]|0;sb=c[ia>>2]|0;qb=c[Pa>>2]|0;ob=qb+(lb>>>3)|0;pb=(je(d[ob]|d[ob+1|0]<<8|d[ob+2|0]<<16|d[ob+3|0]<<24|0)|0)<<(lb&7)>>>23;ob=b[mb+(pb<<2)>>1]|0;rb=b[mb+(pb<<2)+2>>1]|0;pb=rb<<16>>16;if(rb<<16>>16<0){rb=lb+9|0;Ib=sb>>>0>rb>>>0?rb:sb;rb=qb+(Ib>>>3)|0;qb=((je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(Ib&7)>>>((pb+32|0)>>>0))+ob|0;Jb=b[mb+(qb<<2)+2>>1]|0;Kb=b[mb+(qb<<2)>>1]|0;Lb=Ib}else{Jb=pb;Kb=ob;Lb=lb}lb=Jb+Lb|0;c[ha>>2]=sb>>>0>lb>>>0?lb:sb;Hb=Kb+1|0}sb=0;lb=0;do{ob=e+12496+(lb<<2)|0;pb=c[ob>>2]|0;b[(c[aa>>2]|0)+(pb<<1)>>1]=0;a[(c[$>>2]|0)+pb|0]=1;sb=(lb>>2)+sb|0;pb=Hb>>>((5-lb|0)>>>0)&1;c[ya>>2]=0;c[za>>2]=0;if((lb-2|0)>>>0<2>>>0){zb=49}else{if((c[n>>2]|0)==0){zb=49}}if((zb|0)==49){zb=0;c[za>>2]=d[(c[$>>2]|0)+((c[ob>>2]|0)-(c[e+12520+(lb<<2)>>2]|0))|0]|0}if((lb|0)==3|(lb|0)==1){zb=52}else{if((c[w>>2]|0)!=0){zb=52}}if((zb|0)==52){zb=0;c[ya>>2]=d[(c[$>>2]|0)+((c[ob>>2]|0)-1)|0]|0}ob=(lb&4|0)!=0;g7a(e,(c[ua>>2]|0)+(lb<<7)|0,lb,pb,wb,c[(ob?Aa:Ba)>>2]|0);if((lb|0)>3){if((c[xa>>2]&8192|0)==0){zb=55}}else{zb=55}if((zb|0)==55){zb=0;qe[c[Ca>>2]&1023]((c[ua>>2]|0)+(lb<<7)|0);if(ob){Mb=0}else{Mb=(ca(c[wa>>2]|0,lb<<2&8)|0)+(lb<<3&8)|0}ef[c[Ea>>2]&4095]((c[ua>>2]|0)+(lb<<7)|0,(c[e+12544+(sb<<2)>>2]|0)+Mb|0,c[(ob?va:wa)>>2]|0)}lb=lb+1|0;}while((lb|0)<6)}else{a[nb]=0;c[_>>2]=0;c[(c[ba>>2]|0)+((c[Ra>>2]|0)+ib<<2)>>2]=8;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;if((ub|0)<6){do{if((ub&1|0)==0){Nb=0;Ob=0;Pb=0}else{lb=c[Xa>>2]|0;sb=(lb|0)==0;ob=sb?71:125;pb=d[Ya]|0;if((pb|0)==1){Qb=1;Rb=0}else if((pb|0)==2){Qb=0;Rb=1}else if((pb|0)==3){Qb=1;Rb=1}else{Qb=0;Rb=0}pb=c[(c[Za>>2]|0)+4>>2]|0;Ib=c[ha>>2]|0;qb=c[ia>>2]|0;mb=c[Pa>>2]|0;rb=mb+(Ib>>>3)|0;Sb=(je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(Ib&7)>>>23;rb=b[pb+(Sb<<2)>>1]|0;Tb=b[pb+(Sb<<2)+2>>1]|0;Sb=Tb<<16>>16;do{if(Tb<<16>>16<0){Ub=Ib+9|0;Vb=qb>>>0>Ub>>>0?Ub:qb;Ub=mb+(Vb>>>3)|0;Wb=((je(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Vb&7)>>>((Sb+32|0)>>>0))+rb|0;Ub=b[pb+(Wb<<2)>>1]|0;Xb=b[pb+(Wb<<2)+2>>1]|0;Wb=Xb<<16>>16;if(!(Xb<<16>>16<0)){Yb=Wb;Zb=Ub;_b=Vb;break}Xb=Vb-Sb|0;Vb=qb>>>0>Xb>>>0?Xb:qb;Xb=mb+(Vb>>>3)|0;$b=((je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Vb&7)>>>((Wb+32|0)>>>0))+Ub|0;Yb=b[pb+($b<<2)+2>>1]|0;Zb=b[pb+($b<<2)>>1]|0;_b=Vb}else{Yb=Sb;Zb=rb;_b=Ib}}while(0);Ib=Yb+_b|0;rb=qb>>>0>Ib>>>0?Ib:qb;c[ha>>2]=rb;if((Zb|0)==(ob|0)){Ib=c[Ja>>2]|0;Sb=mb+(rb>>>3)|0;pb=(je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(rb&7)>>>((32-Ib|0)>>>0);Sb=Ib+rb|0;Ib=qb>>>0>Sb>>>0?Sb:qb;c[ha>>2]=Ib;Sb=c[Ka>>2]|0;Tb=mb+(Ib>>>3)|0;Vb=(je(d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0)|0)<<(Ib&7)>>>((32-Sb|0)>>>0);Tb=Ib+Sb|0;c[ha>>2]=qb>>>0>Tb>>>0?Tb:qb;if(sb){Nb=0;Ob=Vb;Pb=pb;break}Tb=Vb&1;Nb=Tb;Ob=Tb+Vb>>1;Pb=pb;break}if((Zb|0)>=(ob|0)){zb=72;break b}pb=Zb+1|0;Vb=(pb|0)%9|0;if((Vb|0)==0){ac=0;bc=rb}else{Tb=Vb+Qb|0;Sb=mb+(rb>>>3)|0;Ib=(je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(rb&7)>>>((32-Tb|0)>>>0);Sb=Tb+rb|0;rb=qb>>>0>Sb>>>0?Sb:qb;c[ha>>2]=rb;Sb=Ib&1;ac=((Ib>>1)+(c[((Qb|0)==0?774784:774744)+(Vb<<2)>>2]|0)^-Sb)+Sb|0;bc=rb}rb=(pb|0)/9|0;if((rb|0)>(lb|0)){pb=rb+(Rb<<lb)>>lb;Sb=mb+(bc>>>3)|0;Vb=(je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(bc&7)>>>((32-pb|0)>>>0);Sb=pb+bc|0;c[ha>>2]=qb>>>0>Sb>>>0?Sb:qb;Sb=Vb&1;cc=((Vb>>1)+(c[((Rb|0)==0?774784:774744)+(rb>>lb<<2)>>2]|0)^-Sb)+Sb|0}else{cc=0}Nb=sb?0:rb&1;Ob=cc;Pb=ac}}while(0);r7a(e,0,Pb,Ob,1,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,Nb,0);k7a(e,0);dc=ub>>>1&1^1}else{nb=c[(c[_a>>2]|0)+4>>2]|0;rb=c[ha>>2]|0;Sb=c[ia>>2]|0;Vb=(c[Pa>>2]|0)+(rb>>>3)|0;pb=(je(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(rb&7)>>>26;Vb=b[nb+(pb<<2)>>1]|0;Ib=(b[nb+(pb<<2)+2>>1]|0)+rb|0;c[ha>>2]=Sb>>>0>Ib>>>0?Ib:Sb;a[$a]=Vb;Vb=0;c:while(1){do{if((Vb|0)<4){do{if((d[$a]&1<<3-Vb|0)==0){ec=0;fc=0;gc=0}else{Sb=c[Xa>>2]|0;Ib=(Sb|0)==0;rb=Ib?71:125;pb=d[Ya]|0;if((pb|0)==1){hc=1;ic=0}else if((pb|0)==2){hc=0;ic=1}else if((pb|0)==3){hc=1;ic=1}else{hc=0;ic=0}pb=c[(c[Za>>2]|0)+4>>2]|0;nb=c[ha>>2]|0;Tb=c[ia>>2]|0;$b=c[Pa>>2]|0;Ub=$b+(nb>>>3)|0;Wb=(je(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(nb&7)>>>23;Ub=b[pb+(Wb<<2)>>1]|0;Xb=b[pb+(Wb<<2)+2>>1]|0;Wb=Xb<<16>>16;do{if(Xb<<16>>16<0){jc=nb+9|0;kc=Tb>>>0>jc>>>0?jc:Tb;jc=$b+(kc>>>3)|0;lc=((je(d[jc]|d[jc+1|0]<<8|d[jc+2|0]<<16|d[jc+3|0]<<24|0)|0)<<(kc&7)>>>((Wb+32|0)>>>0))+Ub|0;jc=b[pb+(lc<<2)>>1]|0;mc=b[pb+(lc<<2)+2>>1]|0;lc=mc<<16>>16;if(!(mc<<16>>16<0)){nc=lc;oc=jc;pc=kc;break}mc=kc-Wb|0;kc=Tb>>>0>mc>>>0?mc:Tb;mc=$b+(kc>>>3)|0;qc=((je(d[mc]|d[mc+1|0]<<8|d[mc+2|0]<<16|d[mc+3|0]<<24|0)|0)<<(kc&7)>>>((lc+32|0)>>>0))+jc|0;nc=b[pb+(qc<<2)+2>>1]|0;oc=b[pb+(qc<<2)>>1]|0;pc=kc}else{nc=Wb;oc=Ub;pc=nb}}while(0);nb=nc+pc|0;Ub=Tb>>>0>nb>>>0?nb:Tb;c[ha>>2]=Ub;if((oc|0)==(rb|0)){nb=c[Ja>>2]|0;Wb=$b+(Ub>>>3)|0;pb=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Ub&7)>>>((32-nb|0)>>>0);Wb=nb+Ub|0;nb=Tb>>>0>Wb>>>0?Wb:Tb;c[ha>>2]=nb;Wb=c[Ka>>2]|0;Xb=$b+(nb>>>3)|0;kc=(je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(nb&7)>>>((32-Wb|0)>>>0);Xb=nb+Wb|0;c[ha>>2]=Tb>>>0>Xb>>>0?Xb:Tb;if(Ib){ec=0;fc=kc;gc=pb;break}Xb=kc&1;ec=Xb;fc=Xb+kc>>1;gc=pb;break}if((oc|0)>=(rb|0)){zb=93;break b}pb=oc+1|0;kc=(pb|0)%9|0;if((kc|0)==0){rc=0;sc=Ub}else{Xb=kc+hc|0;Wb=$b+(Ub>>>3)|0;nb=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Ub&7)>>>((32-Xb|0)>>>0);Wb=Xb+Ub|0;Ub=Tb>>>0>Wb>>>0?Wb:Tb;c[ha>>2]=Ub;Wb=nb&1;rc=((nb>>1)+(c[((hc|0)==0?774784:774744)+(kc<<2)>>2]|0)^-Wb)+Wb|0;sc=Ub}Ub=(pb|0)/9|0;if((Ub|0)>(Sb|0)){pb=Ub+(ic<<Sb)>>Sb;Wb=$b+(sc>>>3)|0;kc=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(sc&7)>>>((32-pb|0)>>>0);Wb=pb+sc|0;c[ha>>2]=Tb>>>0>Wb>>>0?Wb:Tb;Wb=kc&1;tc=((kc>>1)+(c[((ic|0)==0?774784:774744)+(Ub>>Sb<<2)>>2]|0)^-Wb)+Wb|0}else{tc=0}ec=Ib?0:Ub&1;fc=tc;gc=rc}}while(0);r7a(e,Vb,gc,fc,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,ec,0);m7a(e,Vb,0,0)}else{if((Vb|0)!=4){break}q7a(e,0);Vb=5;continue c}}while(0);Vb=Vb+1|0;if((Vb|0)>=6){break}}dc=ub&1}do{if((dc|0)==0){uc=kb;vc=0;wc=1}else{Vb=c[(c[Ia>>2]|0)+4>>2]|0;sb=c[ha>>2]|0;lb=c[ia>>2]|0;qb=c[Pa>>2]|0;mb=qb+(sb>>>3)|0;ob=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(sb&7)>>>23;mb=b[Vb+(ob<<2)>>1]|0;Ub=b[Vb+(ob<<2)+2>>1]|0;ob=Ub<<16>>16;if(Ub<<16>>16<0){Ub=sb+9|0;Wb=lb>>>0>Ub>>>0?Ub:lb;Ub=qb+(Wb>>>3)|0;kc=((je(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Wb&7)>>>((ob+32|0)>>>0))+mb|0;xc=b[Vb+(kc<<2)+2>>1]|0;yc=b[Vb+(kc<<2)>>1]|0;zc=Wb}else{xc=ob;yc=mb;zc=sb}sb=xc+zc|0;mb=lb>>>0>sb>>>0?sb:lb;c[ha>>2]=mb;sb=yc+1|0;if((sb|0)==0){uc=kb;vc=0;wc=1;break}if((a[la]|0)==0){uc=kb;vc=sb;wc=0;break}ob=a[na]|0;do{if(ob<<24>>24==3){Wb=qb+(mb>>>3)|0;if((a[oa]|0)!=0){kc=d[Wb]|0;c[ha>>2]=((mb|0)<(lb|0))+mb;Ac=d[(kc&128>>>((mb&7)>>>0)|0)==0?V:pa]|0;break}kc=Wb;Wb=(je(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(mb&7)>>>29;kc=mb+3|0;Vb=lb>>>0>kc>>>0?kc:lb;c[ha>>2]=Vb;if((Wb|0)==7){kc=qb+(Vb>>>3)|0;Ub=(je(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(Vb&7)>>>27;kc=Vb+5|0;c[ha>>2]=lb>>>0>kc>>>0?kc:lb;Bc=Ub;zb=115;break}else{Ac=(d[V]|0)+Wb|0;break}}else{Bc=kb;zb=115}}while(0);do{if((zb|0)==115){zb=0;if((ob<<24>>24|0)==2){Cc=1<<d[qa];zb=118}else if((ob<<24>>24|0)==1){Cc=(3<<d[qa]|0)%15|0;zb=118}else if((ob<<24>>24|0)==0){Dc=15;zb=119}else{Ac=Bc;break}if((zb|0)==118){zb=0;if((Cc&1|0)==0){Ec=Bc;Fc=Cc}else{Dc=Cc;zb=119}}do{if((zb|0)==119){zb=0;if((c[w>>2]|0)!=0){Ec=Bc;Fc=Dc;break}Ec=d[pa]|0;Fc=Dc}}while(0);do{if((Fc&2|0)==0){Gc=Ec}else{if((c[n>>2]|0)==0){Gc=Ec;break}Gc=d[pa]|0}}while(0);do{if((Fc&4|0)==0){Hc=Gc}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){Hc=Gc;break}Hc=d[pa]|0}}while(0);if((Fc&8|0)==0){Ac=Hc;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){Ac=Hc;break}Ac=d[pa]|0}}while(0);if(!((Ac|0)==0|(Ac|0)>31)){uc=Ac;vc=sb;wc=0;break}KIb(c[M>>2]|0,16,2267264,(Gb=i,i=i+8|0,c[Gb>>2]=Ac,Gb)|0);i=Gb;uc=1;vc=sb;wc=0}}while(0);a[(c[da>>2]|0)+ib|0]=uc;if((a[sa]|0)!=0|wc){Ic=jb;Jc=1;Kc=0;Lc=0}else{kb=c[6074788+((c[ta>>2]|0)*20|0)>>2]|0;ob=c[ha>>2]|0;lb=c[ia>>2]|0;qb=c[Pa>>2]|0;mb=qb+(ob>>>3)|0;Wb=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(ob&7)>>>23;mb=b[kb+(Wb<<2)>>1]|0;Ub=b[kb+(Wb<<2)+2>>1]|0;Wb=Ub<<16>>16;if(Ub<<16>>16<0){Ub=ob+9|0;kc=lb>>>0>Ub>>>0?Ub:lb;Ub=qb+(kc>>>3)|0;qb=((je(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(kc&7)>>>((Wb+32|0)>>>0))+mb|0;Mc=b[kb+(qb<<2)+2>>1]|0;Nc=b[kb+(qb<<2)>>1]|0;Oc=kc}else{Mc=Wb;Nc=mb;Oc=ob}ob=Mc+Oc|0;c[ha>>2]=lb>>>0>ob>>>0?ob:lb;Ic=Nc;Jc=1;Kc=0;Lc=0}while(1){b[(c[aa>>2]|0)+(c[e+12496+(Lc<<2)>>2]<<1)>>1]=0;lb=(Lc>>2)+Kc|0;ob=(Lc&4|0)!=0;if(ob){Pc=0}else{Pc=(ca(c[wa>>2]|0,Lc<<2&8)|0)+(Lc<<3&8)|0}if((1<<5-Lc&vc|0)==0){Qc=Jc;Rc=Ic}else{if(ob){Sc=(c[xa>>2]|0)>>>13&1}else{Sc=0}h7a(e,(c[ua>>2]|0)+(Lc<<7)|0,Lc,uc,Ic,Jc,(c[e+12544+(lb<<2)>>2]|0)+Pc|0,c[(ob?va:wa)>>2]|0,Sc,l)|0;Qc=0;Rc=(a[sa]|0)==0&(Ic|0)<8?-1:Ic}ob=Lc+1|0;if((ob|0)<6){Ic=Rc;Jc=Qc;Kc=lb;Lc=ob}else{break}}}if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){break}orc(c[I>>2]|0,c[J>>2]|0,c[q>>2]|0)|0}else if((fb|0)==1){jb=(ca(c[q>>2]|0,c[t>>2]|0)|0)+gb|0;ib=c[U>>2]|0;c[k>>2]=0;ob=d[V]|0;if((c[Y>>2]|0)==0){Tc=d[(c[Z>>2]|0)+jb|0]|0}else{lb=c[ha>>2]|0;mb=d[(c[ja>>2]|0)+(lb>>>3)|0]<<(lb&7)>>>7;c[ha>>2]=((lb|0)<(c[ia>>2]|0))+lb;Tc=mb&1}d:do{if((Tc|0)==0){mb=c[ab>>2]|0;lb=c[(c[Oa>>2]|0)+4>>2]|0;Wb=c[ha>>2]|0;kc=c[ia>>2]|0;qb=c[ja>>2]|0;kb=qb+(Wb>>>3)|0;Ub=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Wb&7);if((mb|0)==0){kb=Ub>>>26;Vb=b[lb+(kb<<2)>>1]|0;pb=b[lb+(kb<<2)+2>>1]|0;kb=pb<<16>>16;if(pb<<16>>16<0){pb=Wb+6|0;nb=kc>>>0>pb>>>0?pb:kc;pb=qb+(nb>>>3)|0;Xb=((je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(nb&7)>>>((kb+32|0)>>>0))+Vb|0;Uc=b[lb+(Xb<<2)+2>>1]|0;Vc=b[lb+(Xb<<2)>>1]|0;Wc=nb}else{Uc=kb;Vc=Vb;Wc=Wb}Vb=Uc+Wc|0;Xc=Vc;Yc=kc>>>0>Vb>>>0?Vb:kc}else{Vb=Ub>>>23;Ub=b[lb+(Vb<<2)>>1]|0;kb=b[lb+(Vb<<2)+2>>1]|0;Vb=kb<<16>>16;if(kb<<16>>16<0){kb=Wb+9|0;nb=kc>>>0>kb>>>0?kb:kc;kb=qb+(nb>>>3)|0;qb=((je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(nb&7)>>>((Vb+32|0)>>>0))+Ub|0;Zc=b[lb+(qb<<2)+2>>1]|0;_c=b[lb+(qb<<2)>>1]|0;$c=nb}else{Zc=Vb;_c=Ub;$c=Wb}Wb=Zc+$c|0;Xc=_c;Yc=kc>>>0>Wb>>>0?Wb:kc}c[ha>>2]=Yc;kc=d[1263920+(mb*60|0)+(Xc<<2)|0]|0;if((kc|0)==4){a[(c[eb>>2]|0)+hb|0]=0;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=0;ad=0;bd=1}else if((kc|0)==3){a[(c[eb>>2]|0)+hb|0]=1;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=1;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=1;ad=0;bd=1}else if((kc|0)==1){a[(c[eb>>2]|0)+hb|0]=1;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=1;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=1;ad=1;bd=0}else if((kc|0)==0){a[(c[eb>>2]|0)+hb|0]=0;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=0;ad=0;bd=0}else{ad=0;bd=0}kc=c[ab>>2]|0;mb=a[1263920+(kc*60|0)+(Xc<<2)|0]|0;if(mb<<24>>24==5){Wb=c[La>>2]|0;Ub=c[N>>2]|0;b[Wb+(Ub<<2)>>1]=0;b[Wb+(Ub<<2)+2>>1]=0;Ub=c[O>>2]|0;b[Wb+(Ub<<2)>>1]=0;b[Wb+(Ub<<2)+2>>1]=0;Ub=c[P>>2]|0;b[Wb+(Ub<<2)>>1]=0;b[Wb+(Ub<<2)+2>>1]=0;Ub=c[Q>>2]|0;b[Wb+(Ub<<2)>>1]=0;b[Wb+(Ub<<2)+2>>1]=0;c[(c[ba>>2]|0)+(jb<<2)>>2]=1;a[(c[J>>2]|0)+(c[w>>2]|0)|0]=1;c[_>>2]=1;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=1;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=1;Ub=c[ha>>2]|0;Wb=d[(c[ja>>2]|0)+(Ub>>>3)|0]<<(Ub&7)>>>7;c[ha>>2]=((Ub|0)<(c[ia>>2]|0))+Ub;Ub=Wb&1;a[(c[bb>>2]|0)+jb|0]=Ub;Wb=c[ha>>2]|0;Vb=c[ja>>2]|0;nb=d[Vb+(Wb>>>3)|0]|0;qb=c[ia>>2]|0;lb=((Wb|0)<(qb|0))+Wb|0;c[ha>>2]=lb;if((nb&128>>>((Wb&7)>>>0)|0)==0){cd=0;dd=lb}else{Wb=c[(c[Ia>>2]|0)+4>>2]|0;nb=Vb+(lb>>>3)|0;kb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(lb&7)>>>23;nb=b[Wb+(kb<<2)>>1]|0;Xb=b[Wb+(kb<<2)+2>>1]|0;kb=Xb<<16>>16;if(Xb<<16>>16<0){Xb=lb+9|0;pb=qb>>>0>Xb>>>0?Xb:qb;Xb=Vb+(pb>>>3)|0;qc=((je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(pb&7)>>>((kb+32|0)>>>0))+nb|0;ed=b[Wb+(qc<<2)+2>>1]|0;fd=b[Wb+(qc<<2)>>1]|0;gd=pb}else{ed=kb;fd=nb;gd=lb}lb=ed+gd|0;nb=qb>>>0>lb>>>0?lb:qb;c[ha>>2]=nb;cd=fd+1|0;dd=nb}nb=d[Vb+(dd>>>3)|0]<<(dd&7)>>>7;c[ha>>2]=((dd|0)<(qb|0))+dd;qb=nb&1;a[(c[Wa>>2]|0)+jb|0]=qb;c[ma>>2]=qb;do{if((a[la]|0)==0){hd=ob}else{qb=a[na]|0;do{if(qb<<24>>24==3){nb=c[ha>>2]|0;if((a[oa]|0)!=0){Vb=d[(c[ja>>2]|0)+(nb>>>3)|0]|0;c[ha>>2]=((nb|0)<(c[ia>>2]|0))+nb;id=d[(Vb&128>>>((nb&7)>>>0)|0)==0?V:pa]|0;break}Vb=c[ia>>2]|0;lb=c[ja>>2]|0;kb=lb+(nb>>>3)|0;pb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(nb&7)>>>29;kb=nb+3|0;nb=Vb>>>0>kb>>>0?kb:Vb;c[ha>>2]=nb;if((pb|0)==7){kb=lb+(nb>>>3)|0;lb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(nb&7)>>>27;kb=nb+5|0;c[ha>>2]=Vb>>>0>kb>>>0?kb:Vb;jd=lb;zb=173;break}else{id=(d[V]|0)+pb|0;break}}else{jd=ob;zb=173}}while(0);do{if((zb|0)==173){zb=0;if((qb<<24>>24|0)==2){kd=1<<d[qa];zb=176}else if((qb<<24>>24|0)==1){kd=(3<<d[qa]|0)%15|0;zb=176}else if((qb<<24>>24|0)==0){ld=15;zb=177}else{id=jd;break}if((zb|0)==176){zb=0;if((kd&1|0)==0){md=jd;nd=kd}else{ld=kd;zb=177}}do{if((zb|0)==177){zb=0;if((c[w>>2]|0)!=0){md=jd;nd=ld;break}md=d[pa]|0;nd=ld}}while(0);do{if((nd&2|0)==0){od=md}else{if((c[n>>2]|0)==0){od=md;break}od=d[pa]|0}}while(0);do{if((nd&4|0)==0){pd=od}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){pd=od;break}pd=d[pa]|0}}while(0);if((nd&8|0)==0){id=pd;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){id=pd;break}id=d[pa]|0}}while(0);if(!((id|0)==0|(id|0)>31)){hd=id;break}KIb(c[M>>2]|0,16,2267264,(Gb=i,i=i+8|0,c[Gb>>2]=id,Gb)|0);i=Gb;hd=1}}while(0);a[(c[da>>2]|0)+jb|0]=hd;c[Ta>>2]=d[(c[Sa>>2]|0)+hd|0]|0;c[Va>>2]=d[(c[Ua>>2]|0)+hd|0]|0;sb=(Ub|0)==0;qb=0;Ib=0;while(1){Sb=e+12496+(Ib<<2)|0;Tb=c[Sb>>2]|0;b[(c[aa>>2]|0)+(Tb<<1)>>1]=0;qb=(Ib>>2)+qb|0;$b=cd>>>((5-Ib|0)>>>0)&1;a[(c[$>>2]|0)+Tb|0]=c[_>>2];c[ya>>2]=0;c[za>>2]=0;if((Ib-2|0)>>>0<2>>>0){zb=193}else{if((c[n>>2]|0)==0){zb=193}}if((zb|0)==193){zb=0;c[za>>2]=d[(c[$>>2]|0)+((c[Sb>>2]|0)-(c[e+12520+(Ib<<2)>>2]|0))|0]|0}if((Ib|0)==3|(Ib|0)==1){zb=196}else{if((c[w>>2]|0)!=0){zb=196}}if((zb|0)==196){zb=0;c[ya>>2]=d[(c[$>>2]|0)+((c[Sb>>2]|0)-1)|0]|0}g7a(e,(c[ua>>2]|0)+(Ib<<7)|0,Ib,$b,hd,c[((Ib&4|0)==0?Ba:Aa)>>2]|0);if((Ib|0)>3){if((c[xa>>2]&8192|0)==0){zb=199}}else{zb=199}if((zb|0)==199){zb=0;qe[c[Ca>>2]&1023]((c[ua>>2]|0)+(Ib<<7)|0);if((Ib|0)<4){$b=c[wa>>2]|0;Sb=Ib&2;qd=$b<<Ub;rd=(ca($b,sb?Sb<<2:Sb>>>1)|0)+(Ib<<3&8)|0}else{qd=c[va>>2]|0;rd=0}ef[c[Ea>>2]&4095]((c[ua>>2]|0)+(Ib<<7)|0,(c[e+12544+(qb<<2)>>2]|0)+rd|0,qd)}Ib=Ib+1|0;if((Ib|0)>=6){break d}}}if((a[1263920+(kc*60|0)+(Xc<<2)+3|0]|0)==0){sd=0}else{Ib=c[(c[Ia>>2]|0)+4>>2]|0;qb=c[ha>>2]|0;sb=c[ia>>2]|0;Ub=c[ja>>2]|0;Sb=Ub+(qb>>>3)|0;$b=(je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(qb&7)>>>23;Sb=b[Ib+($b<<2)>>1]|0;Tb=b[Ib+($b<<2)+2>>1]|0;$b=Tb<<16>>16;if(Tb<<16>>16<0){Tb=qb+9|0;rb=sb>>>0>Tb>>>0?Tb:sb;Tb=Ub+(rb>>>3)|0;Ub=((je(d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0)|0)<<(rb&7)>>>(($b+32|0)>>>0))+Sb|0;td=b[Ib+(Ub<<2)+2>>1]|0;ud=b[Ib+(Ub<<2)>>1]|0;vd=rb}else{td=$b;ud=Sb;vd=qb}qb=td+vd|0;c[ha>>2]=sb>>>0>qb>>>0?qb:sb;sd=ud+1|0}if((mb<<24>>24|0)==1){sb=c[(c[db>>2]|0)+4>>2]|0;qb=c[ha>>2]|0;Sb=c[ia>>2]|0;$b=(c[ja>>2]|0)+(qb>>>3)|0;rb=(je(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(qb&7)>>>29;$b=b[sb+(rb<<2)>>1]|0;Ub=(b[sb+(rb<<2)+2>>1]|0)+qb|0;c[ha>>2]=Sb>>>0>Ub>>>0?Ub:Sb;a[cb]=$b}else if((mb<<24>>24|0)==4|(mb<<24>>24|0)==3){$b=c[(c[_a>>2]|0)+4>>2]|0;Sb=c[ha>>2]|0;Ub=c[ia>>2]|0;qb=(c[ja>>2]|0)+(Sb>>>3)|0;rb=(je(d[qb]|d[qb+1|0]<<8|d[qb+2|0]<<16|d[qb+3|0]<<24|0)|0)<<(Sb&7)>>>26;qb=b[$b+(rb<<2)>>1]|0;sb=(b[$b+(rb<<2)+2>>1]|0)+Sb|0;c[ha>>2]=Ub>>>0>sb>>>0?sb:Ub;a[$a]=qb}a[(c[J>>2]|0)+(c[w>>2]|0)|0]=0;c[_>>2]=0;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;qb=a[1263920+((c[ab>>2]|0)*60|0)+(Xc<<2)+1|0]|0;a[(c[bb>>2]|0)+jb|0]=qb;Ub=qb&255;do{if((bd|0)==0){if((ad|0)==0){do{if((a[1263920+((c[ab>>2]|0)*60|0)+(Xc<<2)+2|0]|0)==0){wd=0;xd=0}else{sb=c[Xa>>2]|0;Sb=(sb|0)==0;rb=Sb?71:125;$b=d[Ya]|0;if(($b|0)==1){yd=1;zd=0}else if(($b|0)==2){yd=0;zd=1}else if(($b|0)==3){yd=1;zd=1}else{yd=0;zd=0}$b=c[(c[Za>>2]|0)+4>>2]|0;Ib=c[ha>>2]|0;Tb=c[ia>>2]|0;pb=c[Pa>>2]|0;lb=pb+(Ib>>>3)|0;Vb=(je(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(Ib&7)>>>23;lb=b[$b+(Vb<<2)>>1]|0;kb=b[$b+(Vb<<2)+2>>1]|0;Vb=kb<<16>>16;do{if(kb<<16>>16<0){nb=Ib+9|0;qc=Tb>>>0>nb>>>0?nb:Tb;nb=pb+(qc>>>3)|0;Wb=((je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(qc&7)>>>((Vb+32|0)>>>0))+lb|0;nb=b[$b+(Wb<<2)>>1]|0;Xb=b[$b+(Wb<<2)+2>>1]|0;Wb=Xb<<16>>16;if(!(Xb<<16>>16<0)){Ad=Wb;Bd=nb;Cd=qc;break}Xb=qc-Vb|0;qc=Tb>>>0>Xb>>>0?Xb:Tb;Xb=pb+(qc>>>3)|0;jc=((je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(qc&7)>>>((Wb+32|0)>>>0))+nb|0;Ad=b[$b+(jc<<2)+2>>1]|0;Bd=b[$b+(jc<<2)>>1]|0;Cd=qc}else{Ad=Vb;Bd=lb;Cd=Ib}}while(0);Ib=Ad+Cd|0;lb=Tb>>>0>Ib>>>0?Ib:Tb;c[ha>>2]=lb;if((Bd|0)==(rb|0)){Ib=c[Ja>>2]|0;Vb=pb+(lb>>>3)|0;$b=(je(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(lb&7)>>>((32-Ib|0)>>>0);Vb=Ib+lb|0;Ib=Tb>>>0>Vb>>>0?Vb:Tb;c[ha>>2]=Ib;Vb=c[Ka>>2]|0;kb=pb+(Ib>>>3)|0;qc=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Ib&7)>>>((32-Vb|0)>>>0);kb=Ib+Vb|0;c[ha>>2]=Tb>>>0>kb>>>0?kb:Tb;if(Sb){wd=qc;xd=$b;break}wd=(qc&1)+qc>>1;xd=$b;break}if((Bd|0)>=(rb|0)){zb=283;break b}$b=Bd+1|0;qc=($b|0)%9|0;if((qc|0)==0){Dd=0;Ed=lb}else{kb=qc+yd|0;Vb=pb+(lb>>>3)|0;Ib=(je(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(lb&7)>>>((32-kb|0)>>>0);Vb=kb+lb|0;lb=Tb>>>0>Vb>>>0?Vb:Tb;c[ha>>2]=lb;Vb=Ib&1;Dd=((Ib>>1)+(c[((yd|0)==0?774784:774744)+(qc<<2)>>2]|0)^-Vb)+Vb|0;Ed=lb}lb=($b|0)/9|0;if((lb|0)<=(sb|0)){wd=0;xd=Dd;break}$b=lb+(zd<<sb)>>sb;Vb=pb+(Ed>>>3)|0;qc=(je(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(Ed&7)>>>((32-$b|0)>>>0);Vb=$b+Ed|0;c[ha>>2]=Tb>>>0>Vb>>>0?Vb:Tb;Vb=qc&1;wd=((qc>>1)+(c[((zd|0)==0?774784:774744)+(lb>>sb<<2)>>2]|0)^-Vb)+Vb|0;xd=Dd}}while(0);o7a(e,0,xd,wd,1,c[ea>>2]|0,c[fa>>2]|0,0);k7a(e,0);break}Vb=d[cb]|0;do{if((Vb&2|0)==0){Fd=0;Gd=0}else{lb=c[Xa>>2]|0;qc=(lb|0)==0;$b=qc?71:125;Ib=d[Ya]|0;if((Ib|0)==1){Id=1;Jd=0}else if((Ib|0)==2){Id=0;Jd=1}else if((Ib|0)==3){Id=1;Jd=1}else{Id=0;Jd=0}Ib=c[(c[Za>>2]|0)+4>>2]|0;kb=c[ha>>2]|0;jc=c[ia>>2]|0;nb=c[Pa>>2]|0;Wb=nb+(kb>>>3)|0;Xb=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(kb&7)>>>23;Wb=b[Ib+(Xb<<2)>>1]|0;lc=b[Ib+(Xb<<2)+2>>1]|0;Xb=lc<<16>>16;do{if(lc<<16>>16<0){mc=kb+9|0;Kd=jc>>>0>mc>>>0?mc:jc;mc=nb+(Kd>>>3)|0;Ld=((je(d[mc]|d[mc+1|0]<<8|d[mc+2|0]<<16|d[mc+3|0]<<24|0)|0)<<(Kd&7)>>>((Xb+32|0)>>>0))+Wb|0;mc=b[Ib+(Ld<<2)>>1]|0;Md=b[Ib+(Ld<<2)+2>>1]|0;Ld=Md<<16>>16;if(!(Md<<16>>16<0)){Nd=Ld;Od=mc;Pd=Kd;break}Md=Kd-Xb|0;Kd=jc>>>0>Md>>>0?Md:jc;Md=nb+(Kd>>>3)|0;Qd=((je(d[Md]|d[Md+1|0]<<8|d[Md+2|0]<<16|d[Md+3|0]<<24|0)|0)<<(Kd&7)>>>((Ld+32|0)>>>0))+mc|0;Nd=b[Ib+(Qd<<2)+2>>1]|0;Od=b[Ib+(Qd<<2)>>1]|0;Pd=Kd}else{Nd=Xb;Od=Wb;Pd=kb}}while(0);kb=Nd+Pd|0;Wb=jc>>>0>kb>>>0?kb:jc;c[ha>>2]=Wb;if((Od|0)==($b|0)){kb=c[Ja>>2]|0;Xb=nb+(Wb>>>3)|0;Ib=(je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-kb|0)>>>0);Xb=kb+Wb|0;kb=jc>>>0>Xb>>>0?Xb:jc;c[ha>>2]=kb;Xb=c[Ka>>2]|0;lc=nb+(kb>>>3)|0;sb=(je(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(kb&7)>>>((32-Xb|0)>>>0);lc=kb+Xb|0;c[ha>>2]=jc>>>0>lc>>>0?lc:jc;if(qc){Fd=sb;Gd=Ib;break}Fd=(sb&1)+sb>>1;Gd=Ib;break}if((Od|0)>=($b|0)){zb=248;break b}Ib=Od+1|0;sb=(Ib|0)%9|0;if((sb|0)==0){Rd=0;Sd=Wb}else{lc=sb+Id|0;Xb=nb+(Wb>>>3)|0;kb=(je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-lc|0)>>>0);Xb=lc+Wb|0;Wb=jc>>>0>Xb>>>0?Xb:jc;c[ha>>2]=Wb;Xb=kb&1;Rd=((kb>>1)+(c[((Id|0)==0?774784:774744)+(sb<<2)>>2]|0)^-Xb)+Xb|0;Sd=Wb}Wb=(Ib|0)/9|0;if((Wb|0)<=(lb|0)){Fd=0;Gd=Rd;break}Ib=Wb+(Jd<<lb)>>lb;Xb=nb+(Sd>>>3)|0;sb=(je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(Sd&7)>>>((32-Ib|0)>>>0);Xb=Ib+Sd|0;c[ha>>2]=jc>>>0>Xb>>>0?Xb:jc;Xb=sb&1;Fd=((sb>>1)+(c[((Jd|0)==0?774784:774744)+(Wb>>lb<<2)>>2]|0)^-Xb)+Xb|0;Gd=Rd}}while(0);o7a(e,0,Gd,Fd,2,c[ea>>2]|0,c[fa>>2]|0,0);m7a(e,0,0,0);m7a(e,1,0,0);do{if((Vb&1|0)==0){Td=0;Ud=0}else{Xb=c[Xa>>2]|0;Wb=(Xb|0)==0;sb=Wb?71:125;Ib=d[Ya]|0;if((Ib|0)==1){Vd=1;Wd=0}else if((Ib|0)==2){Vd=0;Wd=1}else if((Ib|0)==3){Vd=1;Wd=1}else{Vd=0;Wd=0}Ib=c[(c[Za>>2]|0)+4>>2]|0;kb=c[ha>>2]|0;lc=c[ia>>2]|0;Tb=c[Pa>>2]|0;pb=Tb+(kb>>>3)|0;rb=(je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(kb&7)>>>23;pb=b[Ib+(rb<<2)>>1]|0;Sb=b[Ib+(rb<<2)+2>>1]|0;rb=Sb<<16>>16;do{if(Sb<<16>>16<0){Kd=kb+9|0;Qd=lc>>>0>Kd>>>0?Kd:lc;Kd=Tb+(Qd>>>3)|0;mc=((je(d[Kd]|d[Kd+1|0]<<8|d[Kd+2|0]<<16|d[Kd+3|0]<<24|0)|0)<<(Qd&7)>>>((rb+32|0)>>>0))+pb|0;Kd=b[Ib+(mc<<2)>>1]|0;Ld=b[Ib+(mc<<2)+2>>1]|0;mc=Ld<<16>>16;if(!(Ld<<16>>16<0)){Xd=mc;Yd=Kd;Zd=Qd;break}Ld=Qd-rb|0;Qd=lc>>>0>Ld>>>0?Ld:lc;Ld=Tb+(Qd>>>3)|0;Md=((je(d[Ld]|d[Ld+1|0]<<8|d[Ld+2|0]<<16|d[Ld+3|0]<<24|0)|0)<<(Qd&7)>>>((mc+32|0)>>>0))+Kd|0;Xd=b[Ib+(Md<<2)+2>>1]|0;Yd=b[Ib+(Md<<2)>>1]|0;Zd=Qd}else{Xd=rb;Yd=pb;Zd=kb}}while(0);kb=Xd+Zd|0;pb=lc>>>0>kb>>>0?kb:lc;c[ha>>2]=pb;if((Yd|0)==(sb|0)){kb=c[Ja>>2]|0;rb=Tb+(pb>>>3)|0;Ib=(je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(pb&7)>>>((32-kb|0)>>>0);rb=kb+pb|0;kb=lc>>>0>rb>>>0?rb:lc;c[ha>>2]=kb;rb=c[Ka>>2]|0;Sb=Tb+(kb>>>3)|0;lb=(je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(kb&7)>>>((32-rb|0)>>>0);Sb=kb+rb|0;c[ha>>2]=lc>>>0>Sb>>>0?Sb:lc;if(Wb){Td=lb;Ud=Ib;break}Td=(lb&1)+lb>>1;Ud=Ib;break}if((Yd|0)>=(sb|0)){zb=265;break b}Ib=Yd+1|0;lb=(Ib|0)%9|0;if((lb|0)==0){_d=0;$d=pb}else{Sb=lb+Vd|0;rb=Tb+(pb>>>3)|0;kb=(je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(pb&7)>>>((32-Sb|0)>>>0);rb=Sb+pb|0;pb=lc>>>0>rb>>>0?rb:lc;c[ha>>2]=pb;rb=kb&1;_d=((kb>>1)+(c[((Vd|0)==0?774784:774744)+(lb<<2)>>2]|0)^-rb)+rb|0;$d=pb}pb=(Ib|0)/9|0;if((pb|0)<=(Xb|0)){Td=0;Ud=_d;break}Ib=pb+(Wd<<Xb)>>Xb;rb=Tb+($d>>>3)|0;lb=(je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<($d&7)>>>((32-Ib|0)>>>0);rb=Ib+$d|0;c[ha>>2]=lc>>>0>rb>>>0?rb:lc;rb=lb&1;Td=((lb>>1)+(c[((Wd|0)==0?774784:774744)+(pb>>Xb<<2)>>2]|0)^-rb)+rb|0;Ud=_d}}while(0);o7a(e,2,Ud,Td,2,c[ea>>2]|0,c[fa>>2]|0,0);m7a(e,2,0,0);m7a(e,3,0,0);n7a(e,0,0,0)}else{Vb=d[$a]|0;rb=0;e:while(1){do{if((rb|0)<4){do{if((1<<3-rb&Vb|0)==0){ae=0;be=0}else{pb=c[Xa>>2]|0;lb=(pb|0)==0;Ib=lb?71:125;kb=d[Ya]|0;if((kb|0)==1){ce=1;de=0}else if((kb|0)==2){ce=0;de=1}else if((kb|0)==3){ce=1;de=1}else{ce=0;de=0}kb=c[(c[Za>>2]|0)+4>>2]|0;Sb=c[ha>>2]|0;jc=c[ia>>2]|0;nb=c[Pa>>2]|0;$b=nb+(Sb>>>3)|0;qc=(je(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(Sb&7)>>>23;$b=b[kb+(qc<<2)>>1]|0;Qd=b[kb+(qc<<2)+2>>1]|0;qc=Qd<<16>>16;do{if(Qd<<16>>16<0){Md=Sb+9|0;Kd=jc>>>0>Md>>>0?Md:jc;Md=nb+(Kd>>>3)|0;mc=((je(d[Md]|d[Md+1|0]<<8|d[Md+2|0]<<16|d[Md+3|0]<<24|0)|0)<<(Kd&7)>>>((qc+32|0)>>>0))+$b|0;Md=b[kb+(mc<<2)>>1]|0;Ld=b[kb+(mc<<2)+2>>1]|0;mc=Ld<<16>>16;if(!(Ld<<16>>16<0)){ee=mc;fe=Md;ge=Kd;break}Ld=Kd-qc|0;Kd=jc>>>0>Ld>>>0?Ld:jc;Ld=nb+(Kd>>>3)|0;he=((je(d[Ld]|d[Ld+1|0]<<8|d[Ld+2|0]<<16|d[Ld+3|0]<<24|0)|0)<<(Kd&7)>>>((mc+32|0)>>>0))+Md|0;ee=b[kb+(he<<2)+2>>1]|0;fe=b[kb+(he<<2)>>1]|0;ge=Kd}else{ee=qc;fe=$b;ge=Sb}}while(0);Sb=ee+ge|0;$b=jc>>>0>Sb>>>0?Sb:jc;c[ha>>2]=$b;if((fe|0)==(Ib|0)){Sb=c[Ja>>2]|0;qc=nb+($b>>>3)|0;kb=(je(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<($b&7)>>>((32-Sb|0)>>>0);qc=Sb+$b|0;Sb=jc>>>0>qc>>>0?qc:jc;c[ha>>2]=Sb;qc=c[Ka>>2]|0;Qd=nb+(Sb>>>3)|0;Kd=(je(d[Qd]|d[Qd+1|0]<<8|d[Qd+2|0]<<16|d[Qd+3|0]<<24|0)|0)<<(Sb&7)>>>((32-qc|0)>>>0);Qd=Sb+qc|0;c[ha>>2]=jc>>>0>Qd>>>0?Qd:jc;if(lb){ae=Kd;be=kb;break}ae=(Kd&1)+Kd>>1;be=kb;break}if((fe|0)>=(Ib|0)){zb=226;break b}kb=fe+1|0;Kd=(kb|0)%9|0;if((Kd|0)==0){ie=0;ke=$b}else{Qd=Kd+ce|0;qc=nb+($b>>>3)|0;Sb=(je(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<($b&7)>>>((32-Qd|0)>>>0);qc=Qd+$b|0;$b=jc>>>0>qc>>>0?qc:jc;c[ha>>2]=$b;qc=Sb&1;ie=((Sb>>1)+(c[((ce|0)==0?774784:774744)+(Kd<<2)>>2]|0)^-qc)+qc|0;ke=$b}$b=(kb|0)/9|0;if(($b|0)<=(pb|0)){ae=0;be=ie;break}kb=$b+(de<<pb)>>pb;qc=nb+(ke>>>3)|0;Kd=(je(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<(ke&7)>>>((32-kb|0)>>>0);qc=kb+ke|0;c[ha>>2]=jc>>>0>qc>>>0?qc:jc;qc=Kd&1;ae=((Kd>>1)+(c[((de|0)==0?774784:774744)+($b>>pb<<2)>>2]|0)^-qc)+qc|0;be=ie}}while(0);o7a(e,rb,be,ae,0,c[ea>>2]|0,c[fa>>2]|0,0);m7a(e,rb,0,0)}else{if((rb|0)!=4){break}n7a(e,0,0,0);rb=5;continue e}}while(0);rb=rb+1|0;if((rb|0)>=6){break}}}}while(0);mb=(sd|0)!=0;do{if(mb){if((a[la]|0)==0){le=ob;break}kc=a[na]|0;do{if(kc<<24>>24==3){rb=c[ha>>2]|0;if((a[oa]|0)!=0){Vb=d[(c[ja>>2]|0)+(rb>>>3)|0]|0;c[ha>>2]=((rb|0)<(c[ia>>2]|0))+rb;me=d[(Vb&128>>>((rb&7)>>>0)|0)==0?V:pa]|0;break}Vb=c[ia>>2]|0;Xb=c[ja>>2]|0;lc=Xb+(rb>>>3)|0;Tb=(je(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(rb&7)>>>29;lc=rb+3|0;rb=Vb>>>0>lc>>>0?lc:Vb;c[ha>>2]=rb;if((Tb|0)==7){lc=Xb+(rb>>>3)|0;Xb=(je(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(rb&7)>>>27;lc=rb+5|0;c[ha>>2]=Vb>>>0>lc>>>0?lc:Vb;ne=Xb;zb=297;break}else{me=(d[V]|0)+Tb|0;break}}else{ne=ob;zb=297}}while(0);do{if((zb|0)==297){zb=0;if((kc<<24>>24|0)==2){oe=1<<d[qa];zb=300}else if((kc<<24>>24|0)==1){oe=(3<<d[qa]|0)%15|0;zb=300}else if((kc<<24>>24|0)==0){pe=15;zb=301}else{me=ne;break}if((zb|0)==300){zb=0;if((oe&1|0)==0){se=ne;te=oe}else{pe=oe;zb=301}}do{if((zb|0)==301){zb=0;if((c[w>>2]|0)!=0){se=ne;te=pe;break}se=d[pa]|0;te=pe}}while(0);do{if((te&2|0)==0){ue=se}else{if((c[n>>2]|0)==0){ue=se;break}ue=d[pa]|0}}while(0);do{if((te&4|0)==0){ve=ue}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){ve=ue;break}ve=d[pa]|0}}while(0);if((te&8|0)==0){me=ve;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){me=ve;break}me=d[pa]|0}}while(0);if(!((me|0)==0|(me|0)>31)){le=me;break}KIb(c[M>>2]|0,16,2267264,(Gb=i,i=i+8|0,c[Gb>>2]=me,Gb)|0);i=Gb;le=1}else{le=ob}}while(0);a[(c[da>>2]|0)+jb|0]=le;if((a[sa]|0)!=0|mb^1){we=ib}else{kc=c[6074788+((c[ta>>2]|0)*20|0)>>2]|0;Tb=c[ha>>2]|0;Xb=c[ia>>2]|0;Vb=c[ja>>2]|0;lc=Vb+(Tb>>>3)|0;rb=(je(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(Tb&7)>>>23;lc=b[kc+(rb<<2)>>1]|0;sb=b[kc+(rb<<2)+2>>1]|0;rb=sb<<16>>16;if(sb<<16>>16<0){sb=Tb+9|0;Wb=Xb>>>0>sb>>>0?sb:Xb;sb=Vb+(Wb>>>3)|0;Vb=((je(d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)|0)<<(Wb&7)>>>((rb+32|0)>>>0))+lc|0;xe=b[kc+(Vb<<2)+2>>1]|0;ye=b[kc+(Vb<<2)>>1]|0;ze=Wb}else{xe=rb;ye=lc;ze=Tb}Tb=xe+ze|0;c[ha>>2]=Xb>>>0>Tb>>>0?Tb:Xb;we=ye}Xb=qb<<24>>24==0;Tb=we;lc=1;rb=0;Wb=0;while(1){b[(c[aa>>2]|0)+(c[e+12496+(Wb<<2)>>2]<<1)>>1]=0;Vb=(Wb>>2)+rb|0;kc=5-Wb|0;sb=(Wb&4|0)!=0;do{if(Xb){if(sb){Ae=0;break}Ae=(ca(c[wa>>2]|0,Wb<<2&8)|0)+(Wb<<3&8)|0}else{if(sb){Ae=0;break}Ae=(c[wa>>2]&-((Wb|0)>1|0))+(Wb<<3&8)|0}}while(0);if((1<<kc&sd|0)==0){Be=lc;Ce=Tb}else{if(sb){De=(c[xa>>2]|0)>>>13&1;Ee=c[va>>2]|0}else{De=0;Ee=c[wa>>2]<<Ub}h7a(e,(c[ua>>2]|0)+(Wb<<7)|0,Wb,le,Tb,lc,(c[e+12544+(Vb<<2)>>2]|0)+Ae|0,Ee,De,k)|0;Be=0;Ce=(a[sa]|0)==0&(Tb|0)<8?-1:Tb}qc=Wb+1|0;if((qc|0)<6){Tb=Ce;lc=Be;rb=Vb;Wb=qc}else{break}}}else{a[(c[J>>2]|0)+gb|0]=0;c[_>>2]=0;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[N>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[O>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[P>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[Q>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[R>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[S>>2]<<1)>>1]=0;c[(c[ba>>2]|0)+(jb<<2)>>2]=2048;a[(c[da>>2]|0)+jb|0]=0;a[(c[eb>>2]|0)+(c[N>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[O>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[eb>>2]|0)+(c[Q>>2]|0)|0]=0;o7a(e,0,0,0,1,c[ea>>2]|0,c[fa>>2]|0,0);k7a(e,0)}}while(0);if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){break}orc(c[I>>2]|0,c[J>>2]|0,c[q>>2]|0)|0}else{jb=(ca(c[q>>2]|0,c[t>>2]|0)|0)+gb|0;ib=c[U>>2]|0;c[g>>2]=0;ob=d[V]|0;if((c[W>>2]|0)==0){Fe=d[(c[X>>2]|0)+jb|0]|0}else{Wb=c[ha>>2]|0;rb=d[(c[ja>>2]|0)+(Wb>>>3)|0]<<(Wb&7)>>>7;c[ha>>2]=((Wb|0)<(c[ia>>2]|0))+Wb;Fe=rb&1}if((c[Y>>2]|0)==0){Ge=d[(c[Z>>2]|0)+jb|0]|0}else{rb=c[ha>>2]|0;Wb=d[(c[ja>>2]|0)+(rb>>>3)|0]<<(rb&7)>>>7;c[ha>>2]=((rb|0)<(c[ia>>2]|0))+rb;Ge=Wb&1}Wb=(Ge|0)!=0;do{if((Fe|0)==0){if(Wb){c[_>>2]=0;a[(c[$>>2]|0)+hb|0]=0;b[(c[aa>>2]|0)+(c[N>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[O>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[P>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[Q>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[R>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[S>>2]<<1)>>1]=0;c[(c[ba>>2]|0)+(jb<<2)>>2]=2048;a[(c[da>>2]|0)+jb|0]=0;r7a(e,0,0,0,1,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);k7a(e,0);He=0;Ie=0;break}rb=c[6075028+((c[ga>>2]|0)*20|0)>>2]|0;lc=c[ha>>2]|0;Tb=c[ia>>2]|0;Ub=c[ja>>2]|0;Xb=Ub+(lc>>>3)|0;qb=(je(d[Xb]|d[Xb+1|0]<<8|d[Xb+2|0]<<16|d[Xb+3|0]<<24|0)|0)<<(lc&7)>>>23;Xb=b[rb+(qb<<2)>>1]|0;mb=b[rb+(qb<<2)+2>>1]|0;qb=mb<<16>>16;if(mb<<16>>16<0){mb=lc+9|0;qc=Tb>>>0>mb>>>0?mb:Tb;mb=Ub+(qc>>>3)|0;$b=((je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(qc&7)>>>((qb+32|0)>>>0))+Xb|0;Je=b[rb+($b<<2)+2>>1]|0;Ke=b[rb+($b<<2)>>1]|0;Le=qc}else{Je=qb;Ke=Xb;Le=lc}lc=Je+Le|0;Xb=Tb>>>0>lc>>>0?lc:Tb;c[ha>>2]=Xb;lc=Ke+1|0;qb=(lc|0)>36;qc=qb?Ke-36|0:lc;c[_>>2]=0;if((qc|0)==35){lc=c[ka>>2]|0;$b=(c[Ja>>2]|0)-1+lc|0;rb=Ub+(Xb>>>3)|0;mb=(je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(Xb&7)>>>((32-$b|0)>>>0);rb=$b+Xb|0;$b=Tb>>>0>rb>>>0?rb:Tb;c[ha>>2]=$b;rb=lc-1+(c[Ka>>2]|0)|0;lc=Ub+($b>>>3)|0;Kd=(je(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<($b&7)>>>((32-rb|0)>>>0);lc=rb+$b|0;c[ha>>2]=Tb>>>0>lc>>>0?lc:Tb;Me=mb;Ne=Kd;Oe=8}else if((qc|0)==36){c[_>>2]=1;Kd=c[La>>2]|0;b[Kd+(hb<<2)>>1]=0;b[Kd+(hb<<2)+2>>1]=0;Me=0;Ne=0;Oe=1}else if((qc|0)==0){Me=0;Ne=0;Oe=8}else{Kd=(qc|0)%6|0;mb=(c[ka>>2]|0)==0;lc=(c[564656+(Kd<<2)>>2]|0)-(mb&(Kd|0)==5&1)|0;if((lc|0)>0){$b=Ub+(Xb>>>3)|0;rb=(je(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(Xb&7)>>>((32-lc|0)>>>0);$b=lc+Xb|0;lc=Tb>>>0>$b>>>0?$b:Tb;c[ha>>2]=lc;Pe=rb;Qe=lc}else{Pe=0;Qe=Xb}Xb=Pe&1;lc=((Pe>>1)+(c[774720+(Kd<<2)>>2]|0)^-Xb)+Xb|0;Xb=(qc|0)/6|0;if(mb){if((qc-30|0)>>>0<6>>>0){Re=1}else{zb=349}}else{zb=349}if((zb|0)==349){zb=0;Re=0}qc=(c[564656+(Xb<<2)>>2]|0)-Re|0;if((qc|0)>0){mb=Ub+(Qe>>>3)|0;Ub=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(Qe&7)>>>((32-qc|0)>>>0);mb=qc+Qe|0;c[ha>>2]=Tb>>>0>mb>>>0?mb:Tb;Se=Ub}else{Se=0}Ub=Se&1;Me=lc;Ne=((Se>>1)+(c[774720+(Xb<<2)>>2]|0)^-Ub)+Ub|0;Oe=8}c[(c[ba>>2]|0)+(jb<<2)>>2]=Oe;r7a(e,0,Me,Ne,1,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);Ub=c[_>>2]|0;Xb=qb^1;do{if((Ub|0)!=0&Xb){do{if((a[la]|0)==0){Te=ob}else{lc=a[na]|0;do{if(lc<<24>>24==3){Tb=c[ha>>2]|0;if((a[oa]|0)!=0){mb=d[(c[ja>>2]|0)+(Tb>>>3)|0]|0;c[ha>>2]=((Tb|0)<(c[ia>>2]|0))+Tb;Ue=d[(mb&128>>>((Tb&7)>>>0)|0)==0?V:pa]|0;break}mb=c[ia>>2]|0;qc=c[ja>>2]|0;Kd=qc+(Tb>>>3)|0;rb=(je(d[Kd]|d[Kd+1|0]<<8|d[Kd+2|0]<<16|d[Kd+3|0]<<24|0)|0)<<(Tb&7)>>>29;Kd=Tb+3|0;Tb=mb>>>0>Kd>>>0?Kd:mb;c[ha>>2]=Tb;if((rb|0)==7){Kd=qc+(Tb>>>3)|0;qc=(je(d[Kd]|d[Kd+1|0]<<8|d[Kd+2|0]<<16|d[Kd+3|0]<<24|0)|0)<<(Tb&7)>>>27;Kd=Tb+5|0;c[ha>>2]=mb>>>0>Kd>>>0?Kd:mb;Ve=qc;zb=362;break}else{Ue=(d[V]|0)+rb|0;break}}else{Ve=ob;zb=362}}while(0);do{if((zb|0)==362){zb=0;if((lc<<24>>24|0)==2){We=1<<d[qa];zb=365}else if((lc<<24>>24|0)==1){We=(3<<d[qa]|0)%15|0;zb=365}else if((lc<<24>>24|0)==0){Xe=15;zb=366}else{Ue=Ve;break}if((zb|0)==365){zb=0;if((We&1|0)==0){Ye=Ve;Ze=We}else{Xe=We;zb=366}}do{if((zb|0)==366){zb=0;if((c[w>>2]|0)!=0){Ye=Ve;Ze=Xe;break}Ye=d[pa]|0;Ze=Xe}}while(0);do{if((Ze&2|0)==0){_e=Ye}else{if((c[n>>2]|0)==0){_e=Ye;break}_e=d[pa]|0}}while(0);do{if((Ze&4|0)==0){$e=_e}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){$e=_e;break}$e=d[pa]|0}}while(0);if((Ze&8|0)==0){Ue=$e;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){Ue=$e;break}Ue=d[pa]|0}}while(0);if(!((Ue|0)==0|(Ue|0)>31)){Te=Ue;break}KIb(c[M>>2]|0,16,2267264,(Gb=i,i=i+8|0,c[Gb>>2]=Ue,Gb)|0);i=Gb;Te=1}}while(0);Vb=c[ha>>2]|0;sb=d[(c[ja>>2]|0)+(Vb>>>3)|0]<<(Vb&7)>>>7;c[ha>>2]=((Vb|0)<(c[ia>>2]|0))+Vb;c[ma>>2]=sb&1;af=Te;bf=0}else{if(!qb){af=d[V]|0;bf=0;break}sb=c[ha>>2]|0;if((Ub|0)==0){cf=sb;df=c[ia>>2]|0;ff=c[ja>>2]|0}else{Vb=c[ja>>2]|0;kc=d[Vb+(sb>>>3)|0]<<(sb&7)>>>7;lc=c[ia>>2]|0;rb=((sb|0)<(lc|0))+sb|0;c[ha>>2]=rb;c[ma>>2]=kc&1;cf=rb;df=lc;ff=Vb}Vb=c[(c[Ia>>2]|0)+4>>2]|0;lc=ff+(cf>>>3)|0;rb=(je(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(cf&7)>>>23;lc=b[Vb+(rb<<2)>>1]|0;kc=b[Vb+(rb<<2)+2>>1]|0;rb=kc<<16>>16;if(kc<<16>>16<0){kc=cf+9|0;sb=df>>>0>kc>>>0?kc:df;kc=ff+(sb>>>3)|0;qc=((je(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(sb&7)>>>((rb+32|0)>>>0))+lc|0;gf=b[Vb+(qc<<2)+2>>1]|0;hf=b[Vb+(qc<<2)>>1]|0;jf=sb}else{gf=rb;hf=lc;jf=cf}lc=gf+jf|0;rb=df>>>0>lc>>>0?lc:df;c[ha>>2]=rb;if((a[la]|0)==0){af=ob;bf=hf;break}lc=a[na]|0;do{if(lc<<24>>24==3){sb=ff+(rb>>>3)|0;if((a[oa]|0)!=0){qc=d[sb]|0;c[ha>>2]=((rb|0)<(df|0))+rb;kf=d[(qc&128>>>((rb&7)>>>0)|0)==0?V:pa]|0;break}qc=sb;sb=(je(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<(rb&7)>>>29;qc=rb+3|0;Vb=df>>>0>qc>>>0?qc:df;c[ha>>2]=Vb;if((sb|0)==7){qc=ff+(Vb>>>3)|0;kc=(je(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<(Vb&7)>>>27;qc=Vb+5|0;c[ha>>2]=df>>>0>qc>>>0?qc:df;lf=kc;zb=393;break}else{kf=(d[V]|0)+sb|0;break}}else{lf=ob;zb=393}}while(0);do{if((zb|0)==393){zb=0;if((lc<<24>>24|0)==2){mf=1<<d[qa];zb=396}else if((lc<<24>>24|0)==1){mf=(3<<d[qa]|0)%15|0;zb=396}else if((lc<<24>>24|0)==0){nf=15;zb=397}else{kf=lf;break}if((zb|0)==396){zb=0;if((mf&1|0)==0){of=lf;pf=mf}else{nf=mf;zb=397}}do{if((zb|0)==397){zb=0;if((c[w>>2]|0)!=0){of=lf;pf=nf;break}of=d[pa]|0;pf=nf}}while(0);do{if((pf&2|0)==0){qf=of}else{if((c[n>>2]|0)==0){qf=of;break}qf=d[pa]|0}}while(0);do{if((pf&4|0)==0){rf=qf}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){rf=qf;break}rf=d[pa]|0}}while(0);if((pf&8|0)==0){kf=rf;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){kf=rf;break}kf=d[pa]|0}}while(0);if(!((kf|0)==0|(kf|0)>31)){af=kf;bf=hf;break}KIb(c[M>>2]|0,16,2267264,(Gb=i,i=i+8|0,c[Gb>>2]=kf,Gb)|0);i=Gb;af=1;bf=hf}}while(0);a[(c[da>>2]|0)+jb|0]=af;Ub=c[_>>2]|0;do{if((a[sa]|0)==0){if((Ub|0)!=0|Xb){zb=416;break}qb=c[6074788+((c[ta>>2]|0)*20|0)>>2]|0;lc=c[ha>>2]|0;rb=c[ia>>2]|0;sb=c[ja>>2]|0;kc=sb+(lc>>>3)|0;qc=(je(d[kc]|d[kc+1|0]<<8|d[kc+2|0]<<16|d[kc+3|0]<<24|0)|0)<<(lc&7)>>>23;kc=b[qb+(qc<<2)>>1]|0;Vb=b[qb+(qc<<2)+2>>1]|0;qc=Vb<<16>>16;if(Vb<<16>>16<0){Vb=lc+9|0;mb=rb>>>0>Vb>>>0?Vb:rb;Vb=sb+(mb>>>3)|0;sb=((je(d[Vb]|d[Vb+1|0]<<8|d[Vb+2|0]<<16|d[Vb+3|0]<<24|0)|0)<<(mb&7)>>>((qc+32|0)>>>0))+kc|0;sf=b[qb+(sb<<2)+2>>1]|0;tf=b[qb+(sb<<2)>>1]|0;uf=mb}else{sf=qc;tf=kc;uf=lc}lc=sf+uf|0;c[ha>>2]=rb>>>0>lc>>>0?lc:rb;vf=tf;zb=417}else{zb=416}}while(0);if((zb|0)==416){zb=0;if((Ub|0)==0){vf=ib;zb=417}else{wf=0;xf=ib;yf=1;zf=0;Af=0;Bf=0}}if((zb|0)==417){zb=0;k7a(e,0);wf=0;xf=vf;yf=1;zf=0;Af=0;Bf=0}while(1){Xb=e+12496+(wf<<2)|0;rb=c[Xb>>2]|0;b[(c[aa>>2]|0)+(rb<<1)>>1]=0;lc=(wf>>2)+zf|0;kc=bf>>>((5-wf|0)>>>0)&1;qc=(wf&4|0)!=0;if(qc){Cf=0}else{Cf=(ca(c[wa>>2]|0,wf<<2&8)|0)+(wf<<3&8)|0}a[(c[$>>2]|0)+rb|0]=c[_>>2];do{if((c[_>>2]|0)==0){if((kc|0)==0){Df=Bf;Ef=Af;Ff=yf;Gf=xf;break}if(qc){Hf=(c[xa>>2]|0)>>>13&1}else{Hf=0}rb=(h7a(e,(c[ua>>2]|0)+(wf<<7)|0,wf,af,xf,yf,(c[e+12544+(lc<<2)>>2]|0)+Cf|0,c[(qc?va:wa)>>2]|0,Hf,g)|0)<<(wf<<2)|Af;Df=Bf;Ef=rb;Ff=0;Gf=(a[sa]|0)==0&(xf|0)<8?-1:xf}else{c[ya>>2]=0;c[za>>2]=0;if((wf-2|0)>>>0<2>>>0){zb=423}else{if((c[n>>2]|0)==0){zb=423}}if((zb|0)==423){zb=0;c[za>>2]=d[(c[$>>2]|0)+((c[Xb>>2]|0)-(c[e+12520+(wf<<2)>>2]|0))|0]|0}if((wf|0)==3|(wf|0)==1){zb=426}else{if((c[w>>2]|0)!=0){zb=426}}if((zb|0)==426){zb=0;c[ya>>2]=d[(c[$>>2]|0)+((c[Xb>>2]|0)-1)|0]|0}g7a(e,(c[ua>>2]|0)+(wf<<7)|0,wf,kc,af,c[(qc?Aa:Ba)>>2]|0);if((wf|0)>3){if((c[xa>>2]&8192|0)!=0){Df=Bf;Ef=Af;Ff=yf;Gf=xf;break}}qe[c[Ca>>2]&1023]((c[ua>>2]|0)+(wf<<7)|0);rb=c[ua>>2]|0;if((a[Da]|0)!=0){mb=0;do{sb=rb+(wf<<7)+(mb<<1)|0;b[sb>>1]=b[sb>>1]<<1;mb=mb+1|0;}while((mb|0)<64)}mb=e+12544+(lc<<2)|0;sb=qc?va:wa;ef[c[Ea>>2]&4095](rb+(wf<<7)|0,(c[mb>>2]|0)+Cf|0,c[sb>>2]|0);do{if((d[V]|0)>>>0>8>>>0){if((c[Fa>>2]|0)==0){break}if((c[ya>>2]|0)!=0){re[c[Ha>>2]&1023]((c[mb>>2]|0)+Cf|0,c[sb>>2]|0)}if((c[za>>2]|0)==0){break}re[c[Ga>>2]&1023]((c[mb>>2]|0)+Cf|0,c[sb>>2]|0)}}while(0);Df=1<<wf|Bf;Ef=15<<(wf<<2)|Af;Ff=yf;Gf=xf}}while(0);qc=wf+1|0;if((qc|0)<6){wf=qc;xf=Gf;yf=Ff;zf=lc;Af=Ef;Bf=Df}else{break}}He=Df&255;Ie=Ef}else{if(Wb){c[_>>2]=0;a[(c[da>>2]|0)+jb|0]=0;a[(c[$>>2]|0)+(c[N>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[N>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[O>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[O>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[P>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[P>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[Q>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[Q>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[R>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[R>>2]<<1)>>1]=0;a[(c[$>>2]|0)+(c[S>>2]|0)|0]=0;b[(c[aa>>2]|0)+(c[S>>2]<<1)>>1]=0;r7a(e,0,0,0,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);m7a(e,0,0,0);r7a(e,1,0,0,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);m7a(e,1,0,0);r7a(e,2,0,0,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);m7a(e,2,0,0);r7a(e,3,0,0,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);m7a(e,3,0,0);q7a(e,0);a[(c[da>>2]|0)+jb|0]=0;He=0;Ie=0;break}Ub=c[(c[Ia>>2]|0)+4>>2]|0;qc=c[ha>>2]|0;kc=c[ia>>2]|0;Xb=c[ja>>2]|0;sb=Xb+(qc>>>3)|0;mb=(je(d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)|0)<<(qc&7)>>>23;sb=b[Ub+(mb<<2)>>1]|0;rb=b[Ub+(mb<<2)+2>>1]|0;mb=rb<<16>>16;if(rb<<16>>16<0){rb=qc+9|0;qb=kc>>>0>rb>>>0?rb:kc;rb=Xb+(qb>>>3)|0;Xb=((je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(qb&7)>>>((mb+32|0)>>>0))+sb|0;If=b[Ub+(Xb<<2)+2>>1]|0;Jf=b[Ub+(Xb<<2)>>1]|0;Kf=qb}else{If=mb;Jf=sb;Kf=qc}qc=If+Kf|0;c[ha>>2]=kc>>>0>qc>>>0?qc:kc;kc=0;qc=0;sb=0;mb=hb;while(1){qb=Jf>>>((5-kc|0)>>>0)&1;Xb=e+12496+(kc<<2)|0;b[(c[aa>>2]|0)+(mb<<1)>>1]=0;c[_>>2]=0;if((kc|0)<4){c[_>>2]=0;do{if((qb|0)==0){Lf=0;Mf=0;Nf=0;Of=0}else{Ub=c[6075028+((c[ga>>2]|0)*20|0)>>2]|0;rb=c[ha>>2]|0;Vb=c[ia>>2]|0;Kd=c[ja>>2]|0;Tb=Kd+(rb>>>3)|0;$b=(je(d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0)|0)<<(rb&7)>>>23;Tb=b[Ub+($b<<2)>>1]|0;kb=b[Ub+($b<<2)+2>>1]|0;$b=kb<<16>>16;if(kb<<16>>16<0){kb=rb+9|0;Sb=Vb>>>0>kb>>>0?kb:Vb;kb=Kd+(Sb>>>3)|0;Qd=((je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Sb&7)>>>(($b+32|0)>>>0))+Tb|0;Pf=b[Ub+(Qd<<2)+2>>1]|0;Qf=b[Ub+(Qd<<2)>>1]|0;Rf=Sb}else{Pf=$b;Qf=Tb;Rf=rb}rb=Pf+Rf|0;Tb=Vb>>>0>rb>>>0?rb:Vb;c[ha>>2]=Tb;rb=Qf+1|0;$b=(rb|0)>36;Sb=$b&1;Qd=$b?Qf-36|0:rb;c[_>>2]=0;if((Qd|0)==35){rb=c[ka>>2]|0;$b=(c[Ja>>2]|0)-1+rb|0;Ub=Kd+(Tb>>>3)|0;kb=(je(d[Ub]|d[Ub+1|0]<<8|d[Ub+2|0]<<16|d[Ub+3|0]<<24|0)|0)<<(Tb&7)>>>((32-$b|0)>>>0);Ub=$b+Tb|0;$b=Vb>>>0>Ub>>>0?Ub:Vb;c[ha>>2]=$b;Ub=rb-1+(c[Ka>>2]|0)|0;rb=Kd+($b>>>3)|0;he=(je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<($b&7)>>>((32-Ub|0)>>>0);rb=Ub+$b|0;c[ha>>2]=Vb>>>0>rb>>>0?rb:Vb;Lf=qb;Mf=he;Nf=kb;Of=Sb;break}else if((Qd|0)==36){c[_>>2]=1;Lf=qb;Mf=0;Nf=0;Of=Sb;break}else if((Qd|0)==0){Lf=qb;Mf=0;Nf=0;Of=Sb;break}else{kb=(Qd|0)%6|0;he=(c[ka>>2]|0)==0;rb=(c[564656+(kb<<2)>>2]|0)-(he&(kb|0)==5&1)|0;if((rb|0)>0){$b=Kd+(Tb>>>3)|0;Ub=(je(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)|0)<<(Tb&7)>>>((32-rb|0)>>>0);$b=rb+Tb|0;rb=Vb>>>0>$b>>>0?$b:Vb;c[ha>>2]=rb;Sf=Ub;Tf=rb}else{Sf=0;Tf=Tb}Tb=Sf&1;rb=((Sf>>1)+(c[774720+(kb<<2)>>2]|0)^-Tb)+Tb|0;Tb=(Qd|0)/6|0;if(he){if((Qd-30|0)>>>0<6>>>0){Uf=1}else{zb=459}}else{zb=459}if((zb|0)==459){zb=0;Uf=0}Qd=(c[564656+(Tb<<2)>>2]|0)-Uf|0;if((Qd|0)>0){he=Kd+(Tf>>>3)|0;Kd=(je(d[he]|d[he+1|0]<<8|d[he+2|0]<<16|d[he+3|0]<<24|0)|0)<<(Tf&7)>>>((32-Qd|0)>>>0);he=Qd+Tf|0;c[ha>>2]=Vb>>>0>he>>>0?he:Vb;Vf=Kd}else{Vf=0}Kd=Vf&1;Lf=Vf;Mf=((Vf>>1)+(c[774720+(Tb<<2)>>2]|0)^-Kd)+Kd|0;Nf=rb;Of=Sb;break}}}while(0);r7a(e,kc,Nf,Mf,0,c[ea>>2]|0,c[fa>>2]|0,c[$>>2]|0,0,0);lc=c[_>>2]|0;if((lc|0)==0){m7a(e,kc,0,0);Wf=c[_>>2]|0}else{Wf=lc}c[h+(kc<<2)>>2]=Wf;c[j+(kc<<2)>>2]=Of;Xf=Wf+qc|0;Yf=Lf}else{Xf=qc;Yf=qb}if((kc&4|0)!=0){c[h+(kc<<2)>>2]=(Xf|0)>2;c[j+(kc<<2)>>2]=Yf}if((kc|0)==4){q7a(e,0)}lc=c[h+(kc<<2)>>2]|0;a[(c[$>>2]|0)+(c[Xb>>2]|0)|0]=lc;if((sb|0)==0){Zf=c[j+(kc<<2)>>2]&(lc|0)==0}else{Zf=sb}lc=kc+1|0;if((lc|0)>=6){break}kc=lc;qc=Xf;sb=Zf;mb=c[e+12496+(lc<<2)>>2]|0}mb=(Zf|0)==0;if((Zf|Xf|0)==0){He=0;Ie=0;break}do{if((a[la]|0)==0){_f=ob}else{sb=a[na]|0;do{if(sb<<24>>24==3){qc=c[ha>>2]|0;if((a[oa]|0)!=0){kc=d[(c[ja>>2]|0)+(qc>>>3)|0]|0;c[ha>>2]=((qc|0)<(c[ia>>2]|0))+qc;$f=d[(kc&128>>>((qc&7)>>>0)|0)==0?V:pa]|0;break}kc=c[ia>>2]|0;lc=c[ja>>2]|0;Sb=lc+(qc>>>3)|0;rb=(je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(qc&7)>>>29;Sb=qc+3|0;qc=kc>>>0>Sb>>>0?Sb:kc;c[ha>>2]=qc;if((rb|0)==7){Sb=lc+(qc>>>3)|0;lc=(je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(qc&7)>>>27;Sb=qc+5|0;c[ha>>2]=kc>>>0>Sb>>>0?Sb:kc;ag=lc;zb=482;break}else{$f=(d[V]|0)+rb|0;break}}else{ag=ob;zb=482}}while(0);do{if((zb|0)==482){zb=0;if((sb<<24>>24|0)==2){bg=1<<d[qa];zb=485}else if((sb<<24>>24|0)==1){bg=(3<<d[qa]|0)%15|0;zb=485}else if((sb<<24>>24|0)==0){cg=15;zb=486}else{$f=ag;break}if((zb|0)==485){zb=0;if((bg&1|0)==0){dg=ag;eg=bg}else{cg=bg;zb=486}}do{if((zb|0)==486){zb=0;if((c[w>>2]|0)!=0){dg=ag;eg=cg;break}dg=d[pa]|0;eg=cg}}while(0);do{if((eg&2|0)==0){fg=dg}else{if((c[n>>2]|0)==0){fg=dg;break}fg=d[pa]|0}}while(0);do{if((eg&4|0)==0){gg=fg}else{if((c[w>>2]|0)!=((c[E>>2]|0)-1|0)){gg=fg;break}gg=d[pa]|0}}while(0);if((eg&8|0)==0){$f=gg;break}if((c[t>>2]|0)!=((c[ra>>2]|0)-1|0)){$f=gg;break}$f=d[pa]|0}}while(0);if(!(($f|0)==0|($f|0)>31)){_f=$f;break}KIb(c[M>>2]|0,16,2267264,(Gb=i,i=i+8|0,c[Gb>>2]=$f,Gb)|0);i=Gb;_f=1}}while(0);a[(c[da>>2]|0)+jb|0]=_f;sb=0;f:while(1){do{if((c[h+(sb<<2)>>2]|0)!=0){if((c[n>>2]|0)==0){zb=503}else{if((sb-2|0)>>>0<2>>>0){zb=503}}if((zb|0)==503){zb=0;if((a[(c[$>>2]|0)+((c[e+12496+(sb<<2)>>2]|0)-(c[e+12520+(sb<<2)>>2]|0))|0]|0)!=0){zb=508;break f}}if((c[w>>2]|0)==0){if(!((sb|0)==3|(sb|0)==1)){break}}if((a[(c[$>>2]|0)+((c[e+12496+(sb<<2)>>2]|0)-1)|0]|0)!=0){zb=508;break f}}}while(0);Xb=sb+1|0;if((Xb|0)<6){sb=Xb}else{hg=0;break}}if((zb|0)==508){zb=0;sb=c[ha>>2]|0;Xb=d[(c[ja>>2]|0)+(sb>>>3)|0]<<(sb&7)>>>7;c[ha>>2]=((sb|0)<(c[ia>>2]|0))+sb;hg=Xb&1}c[ma>>2]=hg;if((a[sa]|0)!=0|mb){ig=0;jg=ib;kg=1;lg=0;mg=0;ng=0}else{Xb=c[6074788+((c[ta>>2]|0)*20|0)>>2]|0;sb=c[ha>>2]|0;qb=c[ia>>2]|0;rb=c[ja>>2]|0;lc=rb+(sb>>>3)|0;kc=(je(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(sb&7)>>>23;lc=b[Xb+(kc<<2)>>1]|0;Sb=b[Xb+(kc<<2)+2>>1]|0;kc=Sb<<16>>16;if(Sb<<16>>16<0){Sb=sb+9|0;qc=qb>>>0>Sb>>>0?Sb:qb;Sb=rb+(qc>>>3)|0;rb=((je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(qc&7)>>>((kc+32|0)>>>0))+lc|0;og=b[Xb+(rb<<2)+2>>1]|0;pg=b[Xb+(rb<<2)>>1]|0;qg=qc}else{og=kc;pg=lc;qg=sb}sb=og+qg|0;c[ha>>2]=qb>>>0>sb>>>0?sb:qb;ig=0;jg=pg;kg=1;lg=0;mg=0;ng=0}while(1){qb=(ig>>2)+lg|0;sb=(ig&4|0)!=0;if(sb){rg=0}else{rg=(ca(c[wa>>2]|0,ig<<2&8)|0)+(ig<<3&8)|0}lc=c[h+(ig<<2)>>2]|0;c[_>>2]=lc;do{if((lc|0)==0){if((c[j+(ig<<2)>>2]|0)==0){sg=ng;tg=mg;ug=kg;vg=jg;break}if(sb){wg=(c[xa>>2]|0)>>>13&1}else{wg=0}kc=(h7a(e,(c[ua>>2]|0)+(ig<<7)|0,ig,_f,jg,kg,(c[e+12544+(qb<<2)>>2]|0)+rg|0,c[(sb?va:wa)>>2]|0,wg,g)|0)<<(ig<<2)|mg;sg=ng;tg=kc;ug=0;vg=(a[sa]|0)==0&(jg|0)<8?-1:jg}else{c[ya>>2]=0;c[za>>2]=0;if((ig-2|0)>>>0<2>>>0){zb=518}else{if((c[n>>2]|0)==0){zb=518}}if((zb|0)==518){zb=0;c[za>>2]=d[(c[$>>2]|0)+((c[e+12496+(ig<<2)>>2]|0)-(c[e+12520+(ig<<2)>>2]|0))|0]|0}if((ig|0)==3|(ig|0)==1){zb=521}else{if((c[w>>2]|0)!=0){zb=521}}if((zb|0)==521){zb=0;c[ya>>2]=d[(c[$>>2]|0)+((c[e+12496+(ig<<2)>>2]|0)-1)|0]|0}g7a(e,(c[ua>>2]|0)+(ig<<7)|0,ig,c[j+(ig<<2)>>2]|0,_f,c[(sb?Aa:Ba)>>2]|0);if((ig|0)>3){if((c[xa>>2]&8192|0)!=0){sg=ng;tg=mg;ug=kg;vg=jg;break}}qe[c[Ca>>2]&1023]((c[ua>>2]|0)+(ig<<7)|0);kc=c[ua>>2]|0;if((a[Da]|0)!=0){qc=0;do{rb=kc+(ig<<7)+(qc<<1)|0;b[rb>>1]=b[rb>>1]<<1;qc=qc+1|0;}while((qc|0)<64)}qc=e+12544+(qb<<2)|0;rb=sb?va:wa;ef[c[Ea>>2]&4095](kc+(ig<<7)|0,(c[qc>>2]|0)+rg|0,c[rb>>2]|0);do{if((d[V]|0)>>>0>8>>>0){if((c[Fa>>2]|0)==0){break}if((c[ya>>2]|0)!=0){re[c[Ha>>2]&1023]((c[qc>>2]|0)+rg|0,c[rb>>2]|0)}if((c[za>>2]|0)==0){break}re[c[Ga>>2]&1023]((c[qc>>2]|0)+rg|0,c[rb>>2]|0)}}while(0);sg=1<<ig|ng;tg=15<<(ig<<2)|mg;ug=kg;vg=jg}}while(0);sb=ig+1|0;if((sb|0)<6){ig=sb;jg=vg;kg=ug;lg=qb;mg=tg;ng=sg}else{break}}He=sg&255;Ie=tg}}while(0);c[(c[F>>2]|0)+(c[w>>2]<<2)>>2]=Ie;c[(c[H>>2]|0)+(c[w>>2]<<2)>>2]=c[g>>2];a[(c[J>>2]|0)+(c[w>>2]|0)|0]=He}}while(0);if(!((c[t>>2]|0)==(c[r>>2]|0)|Ma)){s7a(e)}hb=c[ha>>2]|0;if((hb|0)>(c[Na>>2]|0)|(hb|0)<0){zb=545;break b}gb=(c[w>>2]|0)+1|0;c[w>>2]=gb;if((gb|0)>=(c[E>>2]|0)){break}}}orc(c[p>>2]|0,c[F>>2]|0,c[q>>2]<<2|0)|0;orc(c[G>>2]|0,c[H>>2]|0,c[q>>2]<<2|0)|0;orc(c[I>>2]|0,c[J>>2]|0,c[q>>2]|0)|0;orc(c[K>>2]|0,c[L>>2]|0,c[q>>2]<<2|0)|0;gb=c[t>>2]|0;if((gb|0)==(c[r>>2]|0)){xg=gb}else{MTa(m,(gb<<4)-16|0,16);xg=c[t>>2]|0}c[n>>2]=0;gb=xg+1|0;c[t>>2]=gb;hb=c[u>>2]|0;if((gb|0)>=(hb|0)){yg=hb;break a}}if((zb|0)==72){KIb(0,0,2565376,(Gb=i,i=i+24|0,c[Gb>>2]=2240232,c[Gb+8>>2]=2529528,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Hd()}else if((zb|0)==93){KIb(0,0,2565376,(Gb=i,i=i+24|0,c[Gb>>2]=2240232,c[Gb+8>>2]=2529528,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Hd()}else if((zb|0)==226){KIb(0,0,2565376,(Gb=i,i=i+24|0,c[Gb>>2]=2240232,c[Gb+8>>2]=2529528,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Hd()}else if((zb|0)==248){KIb(0,0,2565376,(Gb=i,i=i+24|0,c[Gb>>2]=2240232,c[Gb+8>>2]=2529528,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Hd()}else if((zb|0)==265){KIb(0,0,2565376,(Gb=i,i=i+24|0,c[Gb>>2]=2240232,c[Gb+8>>2]=2529528,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Hd()}else if((zb|0)==283){KIb(0,0,2565376,(Gb=i,i=i+24|0,c[Gb>>2]=2240232,c[Gb+8>>2]=2529528,c[Gb+16>>2]=1214,Gb)|0);i=Gb;Hd()}else if((zb|0)==545){ypb(e+14424|0,0,c[r>>2]|0,c[w>>2]|0,c[t>>2]|0,14);L=c[Na>>2]|0;K=c[w>>2]|0;J=c[t>>2]|0;KIb(c[M>>2]|0,16,2272072,(Gb=i,i=i+32|0,c[Gb>>2]=c[ha>>2],c[Gb+8>>2]=L,c[Gb+16>>2]=K,c[Gb+24>>2]=J,Gb)|0);i=Gb;i=f;return}}else{yg=v}}while(0);if(o){o=e+12476|0;c[o>>2]=0;NTa(m);do{if((c[e+19428>>2]|0)!=0){if((c[e+19436>>2]|0)!=(d[e+19231|0]|0)){break}v=c[e+9856>>2]|0;Gb=e+12544|0;c[Gb>>2]=(c[Gb>>2]|0)+(c[v+32>>2]|0);Gb=e+12548|0;c[Gb>>2]=(c[Gb>>2]|0)+(c[v+36>>2]|0);Gb=e+12552|0;c[Gb>>2]=(c[Gb>>2]|0)+(c[v+40>>2]|0)}}while(0);v=e+116|0;if((c[o>>2]|0)<(c[v>>2]|0)){Gb=e+4|0;t=e+12496|0;zb=e+12500|0;xg=e+12504|0;n=e+12508|0;q=e+12512|0;p=e+12516|0;He=e+12544|0;g=e+12548|0;Ie=e+12552|0;do{tg=8>>>((c[(c[Gb>>2]|0)+800>>2]|0)>>>0);c[t>>2]=(c[t>>2]|0)+2;c[zb>>2]=(c[zb>>2]|0)+2;c[xg>>2]=(c[xg>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+1;c[p>>2]=(c[p>>2]|0)+1;c[He>>2]=(c[He>>2]|0)+(tg<<1);c[g>>2]=(c[g>>2]|0)+tg;c[Ie>>2]=(c[Ie>>2]|0)+tg;s7a(e);tg=(c[o>>2]|0)+1|0;c[o>>2]=tg;}while((tg|0)<(c[v>>2]|0))}zg=c[u>>2]|0}else{zg=yg}yg=c[r>>2]|0;if((zg|0)<(yg|0)){Ag=yg;Bg=zg}else{MTa(m,(zg<<4)-16|0,16);Ag=c[r>>2]|0;Bg=c[u>>2]|0}u=c[e+19428>>2]|0;ypb(e+14424|0,0,Ag<<u,(c[e+116>>2]|0)-1|0,(Bg<<u)-1|0,112);i=f;return}function X6a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,re=0,se=0,te=0,ue=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=e|0;l=c[e+16008>>2]|0;if((l|0)==0){c[e+16032>>2]=(c[e+16040>>2]|0)<9?6:2;c[e+16036>>2]=(c[e+16040>>2]|0)<9?7:3}else if((l|0)==1){c[e+16032>>2]=0;c[e+16036>>2]=1}else if((l|0)==2){c[e+16032>>2]=4;c[e+16036>>2]=5}l=e+14084|0;c[l>>2]=1;m=e+808|0;n=c[m>>2]|0;o=e+12480|0;c[o>>2]=n;p=e+812|0;q=c[p>>2]|0;a:do{if((n|0)<(q|0)){r=e+12476|0;s=e+19428|0;t=e+19436|0;u=e+19231|0;v=e+9856|0;w=e+12544|0;x=e+12548|0;y=e+12552|0;z=e+116|0;A=e+13836|0;B=e+4|0;C=e+12496|0;D=e+12500|0;E=e+12504|0;F=e+12508|0;G=e+12512|0;H=e+12516|0;I=e+19224|0;J=e+124|0;K=e+16016|0;L=e+15728|0;M=e+12488|0;N=e+16108|0;O=e+16096|0;P=e+16116|0;Q=e+9928|0;R=h+4|0;S=h|0;T=g+4|0;U=g|0;V=e+16056|0;W=e+9876|0;X=e+9136|0;Y=e+16084|0;Z=e+14128|0;_=e+14136|0;$=e+14120|0;aa=e+16004|0;ba=e+16020|0;da=e+16088|0;ea=e+16005|0;fa=e+16007|0;ga=e+15729|0;ha=e+16006|0;ia=e+120|0;ja=e+14340|0;ka=e+152|0;la=e+148|0;ma=e+60|0;na=e+16048|0;oa=e+16044|0;pa=e+16036|0;qa=e+16032|0;ra=e+15332|0;sa=e+19220|0;ta=e+10068|0;ua=e+176|0;va=e+14060|0;wa=e+13924|0;xa=e+15712|0;ya=e+15716|0;za=e+16070|0;Aa=e+15576|0;Ba=e+19304|0;Ca=e+14120|0;Da=e+19592|0;Ea=e+9152|0;Fa=e+19472|0;Ga=e+9160|0;Ha=e+9888|0;Ia=e+168|0;Ja=e+9892|0;Ka=e+172|0;La=e+19252|0;Ma=e+16112|0;Na=e+16100|0;Oa=j+4|0;Pa=j|0;Qa=e+19480|0;Ra=e+9852|0;Sa=e+19444|0;Ta=e+19288|0;Ua=e+19308|0;Va=e+19316|0;Wa=e+19321|0;b:while(1){c[r>>2]=0;NTa(k);do{if((c[s>>2]|0)!=0){if((c[t>>2]|0)!=(d[u]|0)){break}Xa=c[v>>2]|0;c[w>>2]=(c[w>>2]|0)+(c[Xa+32>>2]|0);c[x>>2]=(c[x>>2]|0)+(c[Xa+36>>2]|0);c[y>>2]=(c[y>>2]|0)+(c[Xa+40>>2]|0)}}while(0);Xa=c[r>>2]|0;if((Xa|0)<(c[z>>2]|0)){Ya=Xa;while(1){Xa=8>>>((c[(c[B>>2]|0)+800>>2]|0)>>>0);Za=(c[C>>2]|0)+2|0;c[C>>2]=Za;c[D>>2]=(c[D>>2]|0)+2;c[E>>2]=(c[E>>2]|0)+2;c[F>>2]=(c[F>>2]|0)+2;c[G>>2]=(c[G>>2]|0)+1;c[H>>2]=(c[H>>2]|0)+1;c[w>>2]=(c[w>>2]|0)+(Xa<<1);c[x>>2]=(c[x>>2]|0)+Xa;c[y>>2]=(c[y>>2]|0)+Xa;Xa=c[I>>2]|0;c:do{if((Xa|0)==2){_a=(ca(c[J>>2]|0,c[o>>2]|0)|0)+Ya|0;$a=c[K>>2]|0;ab=d[L]|0;c[M>>2]=0;bb=c[(c[Ba>>2]|0)+4>>2]|0;cb=c[Z>>2]|0;db=c[_>>2]|0;eb=c[Ca>>2]|0;fb=eb+(cb>>>3)|0;gb=(je(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(cb&7)>>>27;fb=b[bb+(gb<<2)>>1]|0;hb=b[bb+(gb<<2)+2>>1]|0;gb=hb<<16>>16;if(hb<<16>>16<0){hb=cb+5|0;ib=db>>>0>hb>>>0?hb:db;hb=eb+(ib>>>3)|0;eb=((je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(ib&7)>>>((gb+32|0)>>>0))+fb|0;jb=b[bb+(eb<<2)+2>>1]|0;kb=b[bb+(eb<<2)>>1]|0;lb=ib}else{jb=gb;kb=fb;lb=cb}cb=jb+lb|0;c[Z>>2]=db>>>0>cb>>>0?cb:db;db=(c[Da>>2]|0)+Ya|0;if((kb|0)<2){a[db]=1;c[M>>2]=1;cb=c[C>>2]|0;fb=c[Ea>>2]|0;b[fb+(cb<<2)>>1]=0;b[fb+(cb<<2)+2>>1]=0;c[(c[Ga>>2]|0)+((c[Fa>>2]|0)+_a<<2)>>2]=1;do{if((a[aa]|0)==0){mb=ab}else{cb=a[ea]|0;do{if(cb<<24>>24==3){fb=c[Z>>2]|0;if((a[fa]|0)!=0){gb=d[(c[Ca>>2]|0)+(fb>>>3)|0]|0;c[Z>>2]=((fb|0)<(c[_>>2]|0))+fb;nb=d[(gb&128>>>((fb&7)>>>0)|0)==0?L:ga]|0;break}gb=c[_>>2]|0;ib=c[Ca>>2]|0;eb=ib+(fb>>>3)|0;bb=(je(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(fb&7)>>>29;eb=fb+3|0;fb=gb>>>0>eb>>>0?eb:gb;c[Z>>2]=fb;if((bb|0)==7){eb=ib+(fb>>>3)|0;ib=(je(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(fb&7)>>>27;eb=fb+5|0;c[Z>>2]=gb>>>0>eb>>>0?eb:gb;ob=ib;pb=23;break}else{nb=(d[L]|0)+bb|0;break}}else{ob=ab;pb=23}}while(0);do{if((pb|0)==23){pb=0;if((cb<<24>>24|0)==2){qb=1<<d[ha];pb=26}else if((cb<<24>>24|0)==1){qb=(3<<d[ha]|0)%15|0;pb=26}else if((cb<<24>>24|0)==0){rb=15;pb=27}else{nb=ob;break}if((pb|0)==26){pb=0;if((qb&1|0)==0){sb=ob;tb=qb}else{rb=qb;pb=27}}do{if((pb|0)==27){pb=0;if((c[r>>2]|0)!=0){sb=ob;tb=rb;break}sb=d[ga]|0;tb=rb}}while(0);do{if((tb&2|0)==0){ub=sb}else{if((c[l>>2]|0)==0){ub=sb;break}ub=d[ga]|0}}while(0);do{if((tb&4|0)==0){vb=ub}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){vb=ub;break}vb=d[ga]|0}}while(0);if((tb&8|0)==0){nb=vb;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){nb=vb;break}nb=d[ga]|0}}while(0);if(!((nb|0)==0|(nb|0)>31)){mb=nb;break}KIb(c[B>>2]|0,16,2267264,(wb=i,i=i+8|0,c[wb>>2]=nb,wb)|0);i=wb;mb=1}}while(0);a[(c[X>>2]|0)+_a|0]=mb;c[Ia>>2]=d[(c[Ha>>2]|0)+mb|0]|0;c[Ka>>2]=d[(c[Ja>>2]|0)+mb|0]|0;cb=c[Z>>2]|0;bb=d[(c[Ca>>2]|0)+(cb>>>3)|0]<<(cb&7)>>>7;c[Z>>2]=((cb|0)<(c[_>>2]|0))+cb;cb=bb&1;a[(c[La>>2]|0)+_a|0]=cb;c[ua>>2]=cb;if((kb&1|0)==0){xb=0}else{cb=c[(c[Y>>2]|0)+4>>2]|0;bb=c[Z>>2]|0;ib=c[_>>2]|0;gb=c[Ca>>2]|0;eb=gb+(bb>>>3)|0;fb=(je(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(bb&7)>>>23;eb=b[cb+(fb<<2)>>1]|0;hb=b[cb+(fb<<2)+2>>1]|0;fb=hb<<16>>16;if(hb<<16>>16<0){hb=bb+9|0;yb=ib>>>0>hb>>>0?hb:ib;hb=gb+(yb>>>3)|0;gb=((je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(yb&7)>>>((fb+32|0)>>>0))+eb|0;zb=b[cb+(gb<<2)+2>>1]|0;Ab=b[cb+(gb<<2)>>1]|0;Bb=yb}else{zb=fb;Ab=eb;Bb=bb}bb=zb+Bb|0;c[Z>>2]=ib>>>0>bb>>>0?bb:ib;xb=Ab+1|0}ib=0;bb=0;while(1){eb=e+12496+(bb<<2)|0;fb=c[eb>>2]|0;b[(c[W>>2]|0)+(fb<<1)>>1]=0;ib=(bb>>2)+ib|0;yb=xb>>>((5-bb|0)>>>0)&1;a[(c[V>>2]|0)+fb|0]=c[M>>2];c[na>>2]=0;c[oa>>2]=0;if((bb-2|0)>>>0<2>>>0){pb=47}else{if((c[l>>2]|0)==0){pb=47}}if((pb|0)==47){pb=0;c[oa>>2]=d[(c[V>>2]|0)+((c[eb>>2]|0)-(c[e+12520+(bb<<2)>>2]|0))|0]|0}if((bb|0)==3|(bb|0)==1){pb=50}else{if((c[r>>2]|0)!=0){pb=50}}if((pb|0)==50){pb=0;c[na>>2]=d[(c[V>>2]|0)+((c[eb>>2]|0)-1)|0]|0}eb=(bb&4|0)!=0;g7a(e,(c[ja>>2]|0)+(bb<<7)|0,bb,yb,mb,c[(eb?pa:qa)>>2]|0);if((bb|0)>3){if((c[ma>>2]&8192|0)==0){pb=53}}else{pb=53}if((pb|0)==53){pb=0;qe[c[ra>>2]&1023]((c[ja>>2]|0)+(bb<<7)|0);if((a[sa]|0)!=0){yb=c[ja>>2]|0;fb=0;do{gb=yb+(bb<<7)+(fb<<1)|0;b[gb>>1]=b[gb>>1]<<1;fb=fb+1|0;}while((fb|0)<64)}if(eb){Cb=0}else{Cb=(ca(c[la>>2]|0,bb<<2&8)|0)+(bb<<3&8)|0}ef[c[ta>>2]&4095]((c[ja>>2]|0)+(bb<<7)|0,(c[e+12544+(ib<<2)>>2]|0)+Cb|0,c[(eb?ka:la)>>2]|0)}bb=bb+1|0;if((bb|0)>=6){break c}}}a[db]=0;c[M>>2]=0;c[(c[Ga>>2]|0)+((c[Fa>>2]|0)+_a<<2)>>2]=8;a[(c[V>>2]|0)+(c[C>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[D>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[E>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[F>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[G>>2]|0)|0]=0;a[(c[V>>2]|0)+(c[H>>2]|0)|0]=0;if((c[Ma>>2]|0)==0){Db=a[(c[Na>>2]|0)+_a|0]|0}else{bb=c[Z>>2]|0;ib=d[(c[Ca>>2]|0)+(bb>>>3)|0]<<(bb&7)>>>7;c[Z>>2]=((bb|0)<(c[_>>2]|0))+bb;bb=ib&1;a[(c[Na>>2]|0)+_a|0]=bb;Db=bb}if((kb|0)<6){c[R>>2]=0;c[S>>2]=0;c[T>>2]=0;c[U>>2]=0;c[Oa>>2]=0;c[Pa>>2]=0;do{if(Db<<24>>24==0){bb=c[Z>>2]|0;ib=c[Ca>>2]|0;fb=d[ib+(bb>>>3)|0]|0;yb=c[_>>2]|0;gb=((bb|0)<(yb|0))+bb|0;c[Z>>2]=gb;if((fb&128>>>((bb&7)>>>0)|0)==0){Eb=0;Fb=0;pb=69;break}bb=d[ib+(gb>>>3)|0]<<(gb&7)>>>7;fb=((gb|0)<(yb|0))+gb|0;c[Z>>2]=fb;gb=bb&1;bb=gb+1|0;if((gb|0)==0){c[Qa>>2]=3}else if((gb|0)==1){gb=d[ib+(fb>>>3)|0]<<(fb&7)>>>7;c[Z>>2]=((fb|0)<(yb|0))+fb;Eb=gb&1;Fb=2;pb=69;break}else{c[Qa>>2]=bb;if((bb|0)!=3){Gb=bb;Hb=0;pb=71;break}}c[S>>2]=0;c[U>>2]=0;c[Pa>>2]=0;c[R>>2]=0;c[T>>2]=0;if((c[(c[Ra>>2]|0)+2164>>2]|0)==0){KIb(c[B>>2]|0,16,2231312,(wb=i,i=i+1|0,i=i+7&-8,c[wb>>2]=0,wb)|0);i=wb;break c}else{p7a(e,0,U,S,1,Pa);k7a(e,0);l7a(e);break}}else{Eb=0;Fb=1;pb=69}}while(0);if((pb|0)==69){pb=0;c[Qa>>2]=Fb;Gb=Fb;Hb=Eb;pb=71}do{if((pb|0)==71){pb=0;do{if((kb&1|0)!=0){db=(Gb|0)==0|0;bb=g+(db<<2)|0;gb=h+(db<<2)|0;fb=j+(db<<2)|0;db=c[Sa>>2]|0;yb=(db|0)==0;ib=yb?71:125;cb=d[Ta]|0;if((cb|0)==1){Ib=1;Jb=0}else if((cb|0)==2){Ib=0;Jb=1}else if((cb|0)==3){Ib=1;Jb=1}else{Ib=0;Jb=0}cb=c[(c[Ua>>2]|0)+4>>2]|0;hb=c[Z>>2]|0;Kb=c[_>>2]|0;Lb=c[Ca>>2]|0;Mb=Lb+(hb>>>3)|0;Nb=(je(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(hb&7)>>>23;Mb=b[cb+(Nb<<2)>>1]|0;Ob=b[cb+(Nb<<2)+2>>1]|0;Nb=Ob<<16>>16;do{if(Ob<<16>>16<0){Pb=hb+9|0;Qb=Kb>>>0>Pb>>>0?Pb:Kb;Pb=Lb+(Qb>>>3)|0;Rb=((je(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(Qb&7)>>>((Nb+32|0)>>>0))+Mb|0;Pb=b[cb+(Rb<<2)>>1]|0;Sb=b[cb+(Rb<<2)+2>>1]|0;Rb=Sb<<16>>16;if(!(Sb<<16>>16<0)){Tb=Rb;Ub=Pb;Vb=Qb;break}Sb=Qb-Nb|0;Qb=Kb>>>0>Sb>>>0?Sb:Kb;Sb=Lb+(Qb>>>3)|0;Wb=((je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(Qb&7)>>>((Rb+32|0)>>>0))+Pb|0;Tb=b[cb+(Wb<<2)+2>>1]|0;Ub=b[cb+(Wb<<2)>>1]|0;Vb=Qb}else{Tb=Nb;Ub=Mb;Vb=hb}}while(0);hb=Tb+Vb|0;Mb=Kb>>>0>hb>>>0?hb:Kb;c[Z>>2]=Mb;if((Ub|0)==(ib|0)){hb=c[xa>>2]|0;Nb=Lb+(Mb>>>3)|0;cb=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Mb&7)>>>((32-hb|0)>>>0);Nb=hb+Mb|0;hb=Kb>>>0>Nb>>>0?Nb:Kb;c[Z>>2]=hb;c[bb>>2]=cb;cb=c[ya>>2]|0;Nb=Lb+(hb>>>3)|0;Ob=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(hb&7)>>>((32-cb|0)>>>0);Nb=hb+cb|0;c[Z>>2]=Kb>>>0>Nb>>>0?Nb:Kb;c[gb>>2]=Ob;if(yb){break}Nb=Ob&1;c[fb>>2]=Nb;c[gb>>2]=Nb+Ob>>1;break}if((Ub|0)>=(ib|0)){pb=83;break b}Ob=Ub+1|0;Nb=(Ob|0)%9|0;if((Nb|0)==0){Xb=0;Yb=Mb}else{cb=Nb+Ib|0;hb=Lb+(Mb>>>3)|0;Qb=(je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(Mb&7)>>>((32-cb|0)>>>0);hb=cb+Mb|0;Mb=Kb>>>0>hb>>>0?hb:Kb;c[Z>>2]=Mb;hb=Qb&1;Xb=((Qb>>1)+(c[((Ib|0)==0?774784:774744)+(Nb<<2)>>2]|0)^-hb)+hb|0;Yb=Mb}c[bb>>2]=Xb;Mb=(Ob|0)/9|0;if((Mb|0)>(db|0)){Ob=Mb+(Jb<<db)>>db;hb=Lb+(Yb>>>3)|0;Nb=(je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(Yb&7)>>>((32-Ob|0)>>>0);hb=Ob+Yb|0;c[Z>>2]=Kb>>>0>hb>>>0?hb:Kb;hb=Nb&1;Zb=((Nb>>1)+(c[((Jb|0)==0?774784:774744)+(Mb>>db<<2)>>2]|0)^-hb)+hb|0}else{Zb=0}c[gb>>2]=Zb;if(yb){break}c[fb>>2]=Mb&1}}while(0);do{if((Hb|0)!=0){eb=c[Sa>>2]|0;Mb=(eb|0)==0;hb=Mb?71:125;Nb=d[Ta]|0;if((Nb|0)==1){_b=1;$b=0}else if((Nb|0)==2){_b=0;$b=1}else if((Nb|0)==3){_b=1;$b=1}else{_b=0;$b=0}Nb=c[(c[Ua>>2]|0)+4>>2]|0;Ob=c[Z>>2]|0;Qb=c[_>>2]|0;cb=c[Ca>>2]|0;Wb=cb+(Ob>>>3)|0;Pb=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Ob&7)>>>23;Wb=b[Nb+(Pb<<2)>>1]|0;Rb=b[Nb+(Pb<<2)+2>>1]|0;Pb=Rb<<16>>16;do{if(Rb<<16>>16<0){Sb=Ob+9|0;ac=Qb>>>0>Sb>>>0?Sb:Qb;Sb=cb+(ac>>>3)|0;bc=((je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(ac&7)>>>((Pb+32|0)>>>0))+Wb|0;Sb=b[Nb+(bc<<2)>>1]|0;cc=b[Nb+(bc<<2)+2>>1]|0;bc=cc<<16>>16;if(!(cc<<16>>16<0)){dc=bc;ec=Sb;fc=ac;break}cc=ac-Pb|0;ac=Qb>>>0>cc>>>0?cc:Qb;cc=cb+(ac>>>3)|0;gc=((je(d[cc]|d[cc+1|0]<<8|d[cc+2|0]<<16|d[cc+3|0]<<24|0)|0)<<(ac&7)>>>((bc+32|0)>>>0))+Sb|0;dc=b[Nb+(gc<<2)+2>>1]|0;ec=b[Nb+(gc<<2)>>1]|0;fc=ac}else{dc=Pb;ec=Wb;fc=Ob}}while(0);Ob=dc+fc|0;Wb=Qb>>>0>Ob>>>0?Ob:Qb;c[Z>>2]=Wb;if((ec|0)==(hb|0)){Ob=c[xa>>2]|0;Pb=cb+(Wb>>>3)|0;Nb=(je(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-Ob|0)>>>0);Pb=Ob+Wb|0;Ob=Qb>>>0>Pb>>>0?Pb:Qb;c[Z>>2]=Ob;c[T>>2]=Nb;Nb=c[ya>>2]|0;Pb=cb+(Ob>>>3)|0;Rb=(je(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(Ob&7)>>>((32-Nb|0)>>>0);Pb=Ob+Nb|0;c[Z>>2]=Qb>>>0>Pb>>>0?Pb:Qb;c[R>>2]=Rb;if(Mb){break}Pb=Rb&1;c[Oa>>2]=Pb;c[R>>2]=Pb+Rb>>1;break}if((ec|0)>=(hb|0)){pb=102;break b}Rb=ec+1|0;Pb=(Rb|0)%9|0;if((Pb|0)==0){hc=0;ic=Wb}else{Nb=Pb+_b|0;Ob=cb+(Wb>>>3)|0;fb=(je(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Wb&7)>>>((32-Nb|0)>>>0);Ob=Nb+Wb|0;Wb=Qb>>>0>Ob>>>0?Ob:Qb;c[Z>>2]=Wb;Ob=fb&1;hc=((fb>>1)+(c[((_b|0)==0?774784:774744)+(Pb<<2)>>2]|0)^-Ob)+Ob|0;ic=Wb}c[T>>2]=hc;Wb=(Rb|0)/9|0;if((Wb|0)>(eb|0)){Rb=Wb+($b<<eb)>>eb;Ob=cb+(ic>>>3)|0;Pb=(je(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(ic&7)>>>((32-Rb|0)>>>0);Ob=Rb+ic|0;c[Z>>2]=Qb>>>0>Ob>>>0?Ob:Qb;Ob=Pb&1;jc=((Pb>>1)+(c[(($b|0)==0?774784:774744)+(Wb>>eb<<2)>>2]|0)^-Ob)+Ob|0}else{jc=0}c[R>>2]=jc;if(Mb){break}c[Oa>>2]=Wb&1}}while(0);p7a(e,0,U,S,1,Pa);if((Gb|0)==2){k7a(e,0);l7a(e);break}else{k7a(e,(Gb|0)==0|0);break}}}while(0);kc=kb>>>1&1^1}else{Wb=Db<<24>>24!=0|0;c[Qa>>2]=Wb;Ob=c[(c[Va>>2]|0)+4>>2]|0;Pb=c[Z>>2]|0;Rb=c[_>>2]|0;fb=(c[Ca>>2]|0)+(Pb>>>3)|0;Nb=(je(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(Pb&7)>>>26;fb=b[Ob+(Nb<<2)>>1]|0;yb=(b[Ob+(Nb<<2)+2>>1]|0)+Pb|0;c[Z>>2]=Rb>>>0>yb>>>0?yb:Rb;a[Wa]=fb;fb=Wb^1;Wb=g+(fb<<2)|0;Rb=h+(fb<<2)|0;yb=j+(fb<<2)|0;Pb=0;d:while(1){do{if((Pb|0)<4){c[Pa>>2]=0;c[S>>2]=0;c[U>>2]=0;c[Oa>>2]=0;c[R>>2]=0;c[T>>2]=0;do{if((d[Wa]&1<<3-Pb|0)!=0){Nb=c[Sa>>2]|0;Ob=(Nb|0)==0;gb=Ob?71:125;db=d[Ta]|0;if((db|0)==1){lc=1;mc=0}else if((db|0)==2){lc=0;mc=1}else if((db|0)==3){lc=1;mc=1}else{lc=0;mc=0}db=c[(c[Ua>>2]|0)+4>>2]|0;Kb=c[Z>>2]|0;Lb=c[_>>2]|0;bb=c[Ca>>2]|0;ib=bb+(Kb>>>3)|0;ac=(je(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(Kb&7)>>>23;ib=b[db+(ac<<2)>>1]|0;gc=b[db+(ac<<2)+2>>1]|0;ac=gc<<16>>16;do{if(gc<<16>>16<0){Sb=Kb+9|0;bc=Lb>>>0>Sb>>>0?Sb:Lb;Sb=bb+(bc>>>3)|0;cc=((je(d[Sb]|d[Sb+1|0]<<8|d[Sb+2|0]<<16|d[Sb+3|0]<<24|0)|0)<<(bc&7)>>>((ac+32|0)>>>0))+ib|0;Sb=b[db+(cc<<2)>>1]|0;nc=b[db+(cc<<2)+2>>1]|0;cc=nc<<16>>16;if(!(nc<<16>>16<0)){oc=cc;pc=Sb;qc=bc;break}nc=bc-ac|0;bc=Lb>>>0>nc>>>0?nc:Lb;nc=bb+(bc>>>3)|0;rc=((je(d[nc]|d[nc+1|0]<<8|d[nc+2|0]<<16|d[nc+3|0]<<24|0)|0)<<(bc&7)>>>((cc+32|0)>>>0))+Sb|0;oc=b[db+(rc<<2)+2>>1]|0;pc=b[db+(rc<<2)>>1]|0;qc=bc}else{oc=ac;pc=ib;qc=Kb}}while(0);Kb=oc+qc|0;ib=Lb>>>0>Kb>>>0?Kb:Lb;c[Z>>2]=ib;if((pc|0)==(gb|0)){Kb=c[xa>>2]|0;ac=bb+(ib>>>3)|0;db=(je(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(ib&7)>>>((32-Kb|0)>>>0);ac=Kb+ib|0;Kb=Lb>>>0>ac>>>0?ac:Lb;c[Z>>2]=Kb;c[Wb>>2]=db;db=c[ya>>2]|0;ac=bb+(Kb>>>3)|0;gc=(je(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(Kb&7)>>>((32-db|0)>>>0);ac=Kb+db|0;c[Z>>2]=Lb>>>0>ac>>>0?ac:Lb;c[Rb>>2]=gc;if(Ob){break}ac=gc&1;c[yb>>2]=ac;c[Rb>>2]=ac+gc>>1;break}if((pc|0)>=(gb|0)){pb=130;break b}gc=pc+1|0;ac=(gc|0)%9|0;if((ac|0)==0){sc=0;tc=ib}else{db=ac+lc|0;Kb=bb+(ib>>>3)|0;bc=(je(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(ib&7)>>>((32-db|0)>>>0);Kb=db+ib|0;ib=Lb>>>0>Kb>>>0?Kb:Lb;c[Z>>2]=ib;Kb=bc&1;sc=((bc>>1)+(c[((lc|0)==0?774784:774744)+(ac<<2)>>2]|0)^-Kb)+Kb|0;tc=ib}c[Wb>>2]=sc;ib=(gc|0)/9|0;if((ib|0)>(Nb|0)){gc=ib+(mc<<Nb)>>Nb;Kb=bb+(tc>>>3)|0;ac=(je(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(tc&7)>>>((32-gc|0)>>>0);Kb=gc+tc|0;c[Z>>2]=Lb>>>0>Kb>>>0?Kb:Lb;Kb=ac&1;uc=((ac>>1)+(c[((mc|0)==0?774784:774744)+(ib>>Nb<<2)>>2]|0)^-Kb)+Kb|0}else{uc=0}c[Rb>>2]=uc;if(Ob){break}c[yb>>2]=ib&1}}while(0);p7a(e,Pb,U,S,0,Pa);m7a(e,Pb,fb,0)}else{if((Pb|0)!=4){break}q7a(e,fb);Pb=5;continue d}}while(0);Pb=Pb+1|0;if((Pb|0)>=6){break}}kc=kb&1}do{if((kc|0)==0){vc=ab;wc=0;xc=1}else{Pb=c[(c[Y>>2]|0)+4>>2]|0;fb=c[Z>>2]|0;yb=c[_>>2]|0;Rb=c[Ca>>2]|0;Wb=Rb+(fb>>>3)|0;Mb=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(fb&7)>>>23;Wb=b[Pb+(Mb<<2)>>1]|0;eb=b[Pb+(Mb<<2)+2>>1]|0;Mb=eb<<16>>16;if(eb<<16>>16<0){eb=fb+9|0;Qb=yb>>>0>eb>>>0?eb:yb;eb=Rb+(Qb>>>3)|0;cb=((je(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(Qb&7)>>>((Mb+32|0)>>>0))+Wb|0;yc=b[Pb+(cb<<2)+2>>1]|0;zc=b[Pb+(cb<<2)>>1]|0;Ac=Qb}else{yc=Mb;zc=Wb;Ac=fb}fb=yc+Ac|0;Wb=yb>>>0>fb>>>0?fb:yb;c[Z>>2]=Wb;fb=zc+1|0;if((fb|0)==0){vc=ab;wc=0;xc=1;break}if((a[aa]|0)==0){vc=ab;wc=fb;xc=0;break}Mb=a[ea]|0;do{if(Mb<<24>>24==3){Qb=Rb+(Wb>>>3)|0;if((a[fa]|0)!=0){cb=d[Qb]|0;c[Z>>2]=((Wb|0)<(yb|0))+Wb;Bc=d[(cb&128>>>((Wb&7)>>>0)|0)==0?L:ga]|0;break}cb=Qb;Qb=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Wb&7)>>>29;cb=Wb+3|0;Pb=yb>>>0>cb>>>0?cb:yb;c[Z>>2]=Pb;if((Qb|0)==7){cb=Rb+(Pb>>>3)|0;eb=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Pb&7)>>>27;cb=Pb+5|0;c[Z>>2]=yb>>>0>cb>>>0?cb:yb;Cc=eb;pb=153;break}else{Bc=(d[L]|0)+Qb|0;break}}else{Cc=ab;pb=153}}while(0);do{if((pb|0)==153){pb=0;if((Mb<<24>>24|0)==2){Dc=1<<d[ha];pb=156}else if((Mb<<24>>24|0)==1){Dc=(3<<d[ha]|0)%15|0;pb=156}else if((Mb<<24>>24|0)==0){Ec=15;pb=157}else{Bc=Cc;break}if((pb|0)==156){pb=0;if((Dc&1|0)==0){Fc=Cc;Gc=Dc}else{Ec=Dc;pb=157}}do{if((pb|0)==157){pb=0;if((c[r>>2]|0)!=0){Fc=Cc;Gc=Ec;break}Fc=d[ga]|0;Gc=Ec}}while(0);do{if((Gc&2|0)==0){Hc=Fc}else{if((c[l>>2]|0)==0){Hc=Fc;break}Hc=d[ga]|0}}while(0);do{if((Gc&4|0)==0){Ic=Hc}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){Ic=Hc;break}Ic=d[ga]|0}}while(0);if((Gc&8|0)==0){Bc=Ic;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){Bc=Ic;break}Bc=d[ga]|0}}while(0);if(!((Bc|0)==0|(Bc|0)>31)){vc=Bc;wc=fb;xc=0;break}KIb(c[B>>2]|0,16,2267264,(wb=i,i=i+8|0,c[wb>>2]=Bc,wb)|0);i=wb;vc=1;wc=fb;xc=0}}while(0);a[(c[X>>2]|0)+_a|0]=vc;if((a[ba]|0)!=0|xc){Jc=$a;Kc=1;Lc=0;Mc=0}else{ab=c[6074788+((c[da>>2]|0)*20|0)>>2]|0;Mb=c[Z>>2]|0;yb=c[_>>2]|0;Rb=c[Ca>>2]|0;Wb=Rb+(Mb>>>3)|0;Qb=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Mb&7)>>>23;Wb=b[ab+(Qb<<2)>>1]|0;eb=b[ab+(Qb<<2)+2>>1]|0;Qb=eb<<16>>16;if(eb<<16>>16<0){eb=Mb+9|0;cb=yb>>>0>eb>>>0?eb:yb;eb=Rb+(cb>>>3)|0;Rb=((je(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(cb&7)>>>((Qb+32|0)>>>0))+Wb|0;Nc=b[ab+(Rb<<2)+2>>1]|0;Oc=b[ab+(Rb<<2)>>1]|0;Pc=cb}else{Nc=Qb;Oc=Wb;Pc=Mb}Mb=Nc+Pc|0;c[Z>>2]=yb>>>0>Mb>>>0?Mb:yb;Jc=Oc;Kc=1;Lc=0;Mc=0}while(1){b[(c[W>>2]|0)+(c[e+12496+(Mc<<2)>>2]<<1)>>1]=0;yb=(Mc>>2)+Lc|0;Mb=(Mc&4|0)!=0;if(Mb){Qc=0}else{Qc=(ca(c[la>>2]|0,Mc<<2&8)|0)+(Mc<<3&8)|0}if((1<<5-Mc&wc|0)==0){Rc=Kc;Sc=Jc}else{if(Mb){Tc=(c[ma>>2]|0)>>>13&1}else{Tc=0}h7a(e,(c[ja>>2]|0)+(Mc<<7)|0,Mc,vc,Jc,Kc,(c[e+12544+(yb<<2)>>2]|0)+Qc|0,c[(Mb?ka:la)>>2]|0,Tc,0)|0;Rc=0;Sc=(a[ba]|0)==0&(Jc|0)<8?-1:Jc}Mb=Mc+1|0;if((Mb|0)<6){Jc=Sc;Kc=Rc;Lc=yb;Mc=Mb}else{break}}}else if((Xa|0)==1){d7a(e)}else{$a=(ca(c[J>>2]|0,c[o>>2]|0)|0)+Ya|0;_a=c[K>>2]|0;Mb=d[L]|0;c[M>>2]=0;if((c[N>>2]|0)==0){Uc=d[(c[O>>2]|0)+$a|0]|0}else{yb=c[Z>>2]|0;Wb=d[(c[$>>2]|0)+(yb>>>3)|0]<<(yb&7)>>>7;c[Z>>2]=((yb|0)<(c[_>>2]|0))+yb;Uc=Wb&1}if((c[P>>2]|0)==0){Vc=d[(c[Q>>2]|0)+$a|0]|0}else{Wb=c[Z>>2]|0;yb=d[(c[$>>2]|0)+(Wb>>>3)|0]<<(Wb&7)>>>7;c[Z>>2]=((Wb|0)<(c[_>>2]|0))+Wb;Vc=yb&1}c[R>>2]=0;c[S>>2]=0;c[T>>2]=0;c[U>>2]=0;a[(c[V>>2]|0)+Za|0]=0;b[(c[W>>2]|0)+(c[C>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[D>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[D>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[E>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[E>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[F>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[F>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[G>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[G>>2]<<1)>>1]=0;a[(c[V>>2]|0)+(c[H>>2]|0)|0]=0;b[(c[W>>2]|0)+(c[H>>2]<<1)>>1]=0;a[(c[X>>2]|0)+$a|0]=0;yb=(Uc|0)!=0;do{if(yb){Wc=0;Xc=0}else{if((Vc|0)==0){Wb=c[6075028+((c[va>>2]|0)*20|0)>>2]|0;Qb=c[Z>>2]|0;cb=c[_>>2]|0;Rb=c[$>>2]|0;ab=Rb+(Qb>>>3)|0;eb=(je(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(Qb&7)>>>23;ab=b[Wb+(eb<<2)>>1]|0;Pb=b[Wb+(eb<<2)+2>>1]|0;eb=Pb<<16>>16;if(Pb<<16>>16<0){Pb=Qb+9|0;hb=cb>>>0>Pb>>>0?Pb:cb;Pb=Rb+(hb>>>3)|0;ib=((je(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(hb&7)>>>((eb+32|0)>>>0))+ab|0;Yc=b[Wb+(ib<<2)+2>>1]|0;Zc=b[Wb+(ib<<2)>>1]|0;_c=hb}else{Yc=eb;Zc=ab;_c=Qb}Qb=Yc+_c|0;ab=cb>>>0>Qb>>>0?Qb:cb;c[Z>>2]=ab;Qb=Zc+1|0;eb=(Qb|0)>36;hb=eb&1;ib=eb?Zc-36|0:Qb;c[M>>2]=0;if((ib|0)==0){c[S>>2]=0;c[U>>2]=0;$c=0;ad=0;bd=ab}else if((ib|0)==35){Qb=c[wa>>2]|0;eb=(c[xa>>2]|0)-1+Qb|0;Wb=Rb+(ab>>>3)|0;Pb=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(ab&7)>>>((32-eb|0)>>>0);Wb=eb+ab|0;eb=cb>>>0>Wb>>>0?Wb:cb;c[Z>>2]=eb;c[U>>2]=Pb;Wb=Qb-1+(c[ya>>2]|0)|0;Qb=Rb+(eb>>>3)|0;Kb=(je(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(eb&7)>>>((32-Wb|0)>>>0);Qb=eb+Wb|0;Wb=cb>>>0>Qb>>>0?Qb:cb;c[Z>>2]=Wb;c[S>>2]=Kb;$c=Pb;ad=Kb;bd=Wb}else if((ib|0)==36){c[U>>2]=0;c[S>>2]=0;c[M>>2]=1;c[T>>2]=0;c[R>>2]=0;Wc=0;Xc=hb;break}else{Wb=(ib|0)%6|0;Kb=(c[wa>>2]|0)==0;Pb=(c[564656+(Wb<<2)>>2]|0)-(Kb&(Wb|0)==5&1)|0;if((Pb|0)>0){Qb=Rb+(ab>>>3)|0;eb=(je(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(ab&7)>>>((32-Pb|0)>>>0);Qb=Pb+ab|0;Pb=cb>>>0>Qb>>>0?Qb:cb;c[Z>>2]=Pb;cd=eb;dd=Pb}else{cd=0;dd=ab}ab=cd&1;Pb=((cd>>1)+(c[774720+(Wb<<2)>>2]|0)^-ab)+ab|0;c[U>>2]=Pb;ab=(ib|0)/6|0;if(Kb){if((ib-30|0)>>>0<6>>>0){ed=1}else{pb=200}}else{pb=200}if((pb|0)==200){pb=0;ed=0}ib=(c[564656+(ab<<2)>>2]|0)-ed|0;if((ib|0)>0){Kb=Rb+(dd>>>3)|0;Wb=(je(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(dd&7)>>>((32-ib|0)>>>0);Kb=ib+dd|0;ib=cb>>>0>Kb>>>0?Kb:cb;c[Z>>2]=ib;fd=Wb;gd=ib}else{fd=0;gd=dd}ib=fd&1;Wb=((fd>>1)+(c[774720+(ab<<2)>>2]|0)^-ib)+ib|0;c[S>>2]=Wb;$c=Pb;ad=Wb;bd=gd}c[T>>2]=$c;c[R>>2]=ad;hd=hb;id=bd;jd=Rb;kd=cb}else{hd=0;id=c[Z>>2]|0;jd=c[$>>2]|0;kd=c[_>>2]|0}cb=d[jd+(id>>>3)|0]|0;Rb=((id|0)<(kd|0))+id|0;c[Z>>2]=Rb;if((cb&128>>>((id&7)>>>0)|0)==0){Wc=(b[za>>1]|0)<128|0;Xc=hd;break}cb=d[jd+(Rb>>>3)|0]<<(Rb&7)>>>7;c[Z>>2]=((Rb|0)<(kd|0))+Rb;Rb=cb&1;if((Rb|0)==0){Wc=(b[za>>1]|0)>127|0;Xc=hd;break}else if((Rb|0)==1){c[S>>2]=0;c[U>>2]=0;Wc=2;Xc=hd;break}else{Wc=Rb+1|0;Xc=hd;break}}}while(0);a[(c[V>>2]|0)+(c[C>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[D>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[E>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[F>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[G>>2]|0)|0]=c[M>>2];a[(c[V>>2]|0)+(c[H>>2]|0)|0]=c[M>>2];if((Vc|0)!=0){Rb=yb?2:Wc;f7a(e,U,S,Uc,Rb);if((Uc|0)!=0){k7a(e,0);l7a(e);break}if((Rb|0)==2){k7a(e,0);l7a(e);break}else{k7a(e,(Rb|0)==0|0);break}}do{if(yb){Rb=c[(c[Y>>2]|0)+4>>2]|0;cb=c[Z>>2]|0;hb=c[_>>2]|0;Wb=c[$>>2]|0;Pb=Wb+(cb>>>3)|0;ib=(je(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(cb&7)>>>23;Pb=b[Rb+(ib<<2)>>1]|0;ab=b[Rb+(ib<<2)+2>>1]|0;ib=ab<<16>>16;if(ab<<16>>16<0){ab=cb+9|0;Kb=hb>>>0>ab>>>0?ab:hb;ab=Wb+(Kb>>>3)|0;eb=((je(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(Kb&7)>>>((ib+32|0)>>>0))+Pb|0;ld=b[Rb+(eb<<2)+2>>1]|0;md=b[Rb+(eb<<2)>>1]|0;nd=Kb}else{ld=ib;md=Pb;nd=cb}cb=ld+nd|0;Pb=hb>>>0>cb>>>0?cb:hb;c[Z>>2]=Pb;do{if((a[aa]|0)==0){od=Mb}else{cb=a[ea]|0;do{if(cb<<24>>24==3){ib=Wb+(Pb>>>3)|0;if((a[fa]|0)!=0){Kb=d[ib]|0;c[Z>>2]=((Pb|0)<(hb|0))+Pb;pd=d[(Kb&128>>>((Pb&7)>>>0)|0)==0?L:ga]|0;break}Kb=ib;ib=(je(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(Pb&7)>>>29;Kb=Pb+3|0;eb=hb>>>0>Kb>>>0?Kb:hb;c[Z>>2]=eb;if((ib|0)==7){Kb=Wb+(eb>>>3)|0;Rb=(je(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(eb&7)>>>27;Kb=eb+5|0;c[Z>>2]=hb>>>0>Kb>>>0?Kb:hb;qd=Rb;pb=228;break}else{pd=(d[L]|0)+ib|0;break}}else{qd=Mb;pb=228}}while(0);do{if((pb|0)==228){pb=0;if((cb<<24>>24|0)==2){rd=1<<d[ha];pb=231}else if((cb<<24>>24|0)==1){rd=(3<<d[ha]|0)%15|0;pb=231}else if((cb<<24>>24|0)==0){sd=15;pb=232}else{pd=qd;break}if((pb|0)==231){pb=0;if((rd&1|0)==0){td=qd;ud=rd}else{sd=rd;pb=232}}do{if((pb|0)==232){pb=0;if((c[r>>2]|0)!=0){td=qd;ud=sd;break}td=d[ga]|0;ud=sd}}while(0);do{if((ud&2|0)==0){vd=td}else{if((c[l>>2]|0)==0){vd=td;break}vd=d[ga]|0}}while(0);do{if((ud&4|0)==0){wd=vd}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){wd=vd;break}wd=d[ga]|0}}while(0);if((ud&8|0)==0){pd=wd;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){pd=wd;break}pd=d[ga]|0}}while(0);if(!((pd|0)==0|(pd|0)>31)){od=pd;break}KIb(c[B>>2]|0,16,2267264,(wb=i,i=i+8|0,c[wb>>2]=pd,wb)|0);i=wb;od=1}}while(0);c[M>>2]=0;a[(c[X>>2]|0)+$a|0]=od;if((a[ba]|0)==0){hb=c[6074788+((c[da>>2]|0)*20|0)>>2]|0;Wb=c[Z>>2]|0;Pb=c[_>>2]|0;fb=c[$>>2]|0;cb=fb+(Wb>>>3)|0;Ob=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Wb&7)>>>23;cb=b[hb+(Ob<<2)>>1]|0;Nb=b[hb+(Ob<<2)+2>>1]|0;Ob=Nb<<16>>16;if(Nb<<16>>16<0){Nb=Wb+9|0;Lb=Pb>>>0>Nb>>>0?Nb:Pb;Nb=fb+(Lb>>>3)|0;fb=((je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Lb&7)>>>((Ob+32|0)>>>0))+cb|0;xd=b[hb+(fb<<2)+2>>1]|0;yd=b[hb+(fb<<2)>>1]|0;zd=Lb}else{xd=Ob;yd=cb;zd=Wb}Wb=xd+zd|0;c[Z>>2]=Pb>>>0>Wb>>>0?Wb:Pb;Ad=yd}else{Ad=_a}c[R>>2]=0;c[T>>2]=0;c[S>>2]=0;c[U>>2]=0;f7a(e,U,S,Uc,Wc);k7a(e,0);l7a(e);Bd=Ad;Cd=od;Dd=md}else{if((Xc|0)==0){if((c[M>>2]|0)==0){f7a(e,U,S,0,Wc);if((Wc|0)==2){k7a(e,0);l7a(e);break c}else{k7a(e,(Wc|0)==0|0);break c}}do{if((a[aa]|0)==0){Ed=Mb}else{Pb=a[ea]|0;do{if(Pb<<24>>24==3){Wb=c[Z>>2]|0;if((a[fa]|0)!=0){cb=d[(c[$>>2]|0)+(Wb>>>3)|0]|0;c[Z>>2]=((Wb|0)<(c[_>>2]|0))+Wb;Fd=d[(cb&128>>>((Wb&7)>>>0)|0)==0?L:ga]|0;break}cb=c[_>>2]|0;Ob=c[$>>2]|0;Lb=Ob+(Wb>>>3)|0;fb=(je(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(Wb&7)>>>29;Lb=Wb+3|0;Wb=cb>>>0>Lb>>>0?Lb:cb;c[Z>>2]=Wb;if((fb|0)==7){Lb=Ob+(Wb>>>3)|0;Ob=(je(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(Wb&7)>>>27;Lb=Wb+5|0;c[Z>>2]=cb>>>0>Lb>>>0?Lb:cb;Gd=Ob;pb=262;break}else{Fd=(d[L]|0)+fb|0;break}}else{Gd=Mb;pb=262}}while(0);do{if((pb|0)==262){pb=0;if((Pb<<24>>24|0)==2){Id=1<<d[ha];pb=265}else if((Pb<<24>>24|0)==1){Id=(3<<d[ha]|0)%15|0;pb=265}else if((Pb<<24>>24|0)==0){Jd=15;pb=266}else{Fd=Gd;break}if((pb|0)==265){pb=0;if((Id&1|0)==0){Kd=Gd;Ld=Id}else{Jd=Id;pb=266}}do{if((pb|0)==266){pb=0;if((c[r>>2]|0)!=0){Kd=Gd;Ld=Jd;break}Kd=d[ga]|0;Ld=Jd}}while(0);do{if((Ld&2|0)==0){Md=Kd}else{if((c[l>>2]|0)==0){Md=Kd;break}Md=d[ga]|0}}while(0);do{if((Ld&4|0)==0){Nd=Md}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){Nd=Md;break}Nd=d[ga]|0}}while(0);if((Ld&8|0)==0){Fd=Nd;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){Fd=Nd;break}Fd=d[ga]|0}}while(0);if(!((Fd|0)==0|(Fd|0)>31)){Ed=Fd;break}KIb(c[B>>2]|0,16,2267264,(wb=i,i=i+8|0,c[wb>>2]=Fd,wb)|0);i=wb;Ed=1}}while(0);a[(c[X>>2]|0)+$a|0]=Ed;Pb=c[Z>>2]|0;fb=d[(c[$>>2]|0)+(Pb>>>3)|0]<<(Pb&7)>>>7;c[Z>>2]=((Pb|0)<(c[_>>2]|0))+Pb;c[ua>>2]=fb&1;f7a(e,U,S,0,Wc);Bd=_a;Cd=Ed;Dd=0;break}fb=(Wc|0)==2;do{if(fb){Pb=c[6075028+((c[va>>2]|0)*20|0)>>2]|0;Ob=c[Z>>2]|0;cb=c[_>>2]|0;Lb=c[$>>2]|0;Wb=Lb+(Ob>>>3)|0;hb=(je(d[Wb]|d[Wb+1|0]<<8|d[Wb+2|0]<<16|d[Wb+3|0]<<24|0)|0)<<(Ob&7)>>>23;Wb=b[Pb+(hb<<2)>>1]|0;Nb=b[Pb+(hb<<2)+2>>1]|0;hb=Nb<<16>>16;if(Nb<<16>>16<0){Nb=Ob+9|0;bb=cb>>>0>Nb>>>0?Nb:cb;Nb=Lb+(bb>>>3)|0;gb=((je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(bb&7)>>>((hb+32|0)>>>0))+Wb|0;Od=b[Pb+(gb<<2)+2>>1]|0;Pd=b[Pb+(gb<<2)>>1]|0;Qd=bb}else{Od=hb;Pd=Wb;Qd=Ob}Ob=Od+Qd|0;Wb=cb>>>0>Ob>>>0?Ob:cb;c[Z>>2]=Wb;Ob=Pd+1|0;hb=(Ob|0)>36;bb=hb&1;gb=hb?Pd-36|0:Ob;c[M>>2]=0;if((gb|0)==0){c[S>>2]=0;c[U>>2]=0}else if((gb|0)==35){Ob=c[wa>>2]|0;Pb=(c[xa>>2]|0)-1+Ob|0;Nb=Lb+(Wb>>>3)|0;ib=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-Pb|0)>>>0);Nb=Pb+Wb|0;Pb=cb>>>0>Nb>>>0?Nb:cb;c[Z>>2]=Pb;c[U>>2]=ib;ib=Ob-1+(c[ya>>2]|0)|0;Ob=Lb+(Pb>>>3)|0;Nb=(je(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Pb&7)>>>((32-ib|0)>>>0);Ob=Pb+ib|0;c[Z>>2]=cb>>>0>Ob>>>0?Ob:cb;c[S>>2]=Nb}else if((gb|0)==36){c[U>>2]=0;c[S>>2]=0;c[M>>2]=1}else{Nb=(gb|0)%6|0;Ob=(c[wa>>2]|0)==0;ib=(c[564656+(Nb<<2)>>2]|0)-(Ob&(Nb|0)==5&1)|0;if((ib|0)>0){Pb=Lb+(Wb>>>3)|0;Rb=(je(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0)<<(Wb&7)>>>((32-ib|0)>>>0);Pb=ib+Wb|0;ib=cb>>>0>Pb>>>0?Pb:cb;c[Z>>2]=ib;Rd=Rb;Sd=ib}else{Rd=0;Sd=Wb}Wb=Rd&1;c[U>>2]=((Rd>>1)+(c[774720+(Nb<<2)>>2]|0)^-Wb)+Wb;Wb=(gb|0)/6|0;if(Ob){if((gb-30|0)>>>0<6>>>0){Td=1}else{pb=291}}else{pb=291}if((pb|0)==291){pb=0;Td=0}gb=(c[564656+(Wb<<2)>>2]|0)-Td|0;if((gb|0)>0){Ob=Lb+(Sd>>>3)|0;Lb=(je(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Sd&7)>>>((32-gb|0)>>>0);Ob=gb+Sd|0;c[Z>>2]=cb>>>0>Ob>>>0?Ob:cb;Ud=Lb}else{Ud=0}Lb=Ud&1;c[S>>2]=((Ud>>1)+(c[774720+(Wb<<2)>>2]|0)^-Lb)+Lb}if(hb){Vd=bb;break}f7a(e,U,S,0,2);k7a(e,0);l7a(e);break c}else{Vd=Xc}}while(0);f7a(e,U,S,0,Wc);do{if((c[M>>2]|0)==0){if(fb){k7a(e,0);l7a(e)}else{k7a(e,(Wc|0)==0|0)}if((c[M>>2]|0)!=0){pb=303;break}Wd=c[Z>>2]|0;Xd=c[_>>2]|0;Yd=c[$>>2]|0}else{pb=303}}while(0);if((pb|0)==303){pb=0;fb=c[Z>>2]|0;bb=c[$>>2]|0;hb=d[bb+(fb>>>3)|0]<<(fb&7)>>>7;Lb=c[_>>2]|0;Wb=((fb|0)<(Lb|0))+fb|0;c[Z>>2]=Wb;c[ua>>2]=hb&1;Wd=Wb;Xd=Lb;Yd=bb}bb=c[(c[Y>>2]|0)+4>>2]|0;Lb=Yd+(Wd>>>3)|0;Wb=(je(d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)|0)<<(Wd&7)>>>23;Lb=b[bb+(Wb<<2)>>1]|0;hb=b[bb+(Wb<<2)+2>>1]|0;Wb=hb<<16>>16;if(hb<<16>>16<0){hb=Wd+9|0;fb=Xd>>>0>hb>>>0?hb:Xd;hb=Yd+(fb>>>3)|0;cb=((je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(fb&7)>>>((Wb+32|0)>>>0))+Lb|0;Zd=b[bb+(cb<<2)+2>>1]|0;_d=b[bb+(cb<<2)>>1]|0;$d=fb}else{Zd=Wb;_d=Lb;$d=Wd}Lb=Zd+$d|0;Wb=Xd>>>0>Lb>>>0?Lb:Xd;c[Z>>2]=Wb;do{if((a[aa]|0)==0){ae=Mb}else{Lb=a[ea]|0;do{if(Lb<<24>>24==3){fb=Yd+(Wb>>>3)|0;if((a[fa]|0)!=0){cb=d[fb]|0;c[Z>>2]=((Wb|0)<(Xd|0))+Wb;be=d[(cb&128>>>((Wb&7)>>>0)|0)==0?L:ga]|0;break}cb=fb;fb=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Wb&7)>>>29;cb=Wb+3|0;bb=Xd>>>0>cb>>>0?cb:Xd;c[Z>>2]=bb;if((fb|0)==7){cb=Yd+(bb>>>3)|0;hb=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(bb&7)>>>27;cb=bb+5|0;c[Z>>2]=Xd>>>0>cb>>>0?cb:Xd;ce=hb;pb=313;break}else{be=(d[L]|0)+fb|0;break}}else{ce=Mb;pb=313}}while(0);do{if((pb|0)==313){pb=0;if((Lb<<24>>24|0)==2){de=1<<d[ha];pb=316}else if((Lb<<24>>24|0)==1){de=(3<<d[ha]|0)%15|0;pb=316}else if((Lb<<24>>24|0)==0){ee=15;pb=317}else{be=ce;break}if((pb|0)==316){pb=0;if((de&1|0)==0){fe=ce;ge=de}else{ee=de;pb=317}}do{if((pb|0)==317){pb=0;if((c[r>>2]|0)!=0){fe=ce;ge=ee;break}fe=d[ga]|0;ge=ee}}while(0);do{if((ge&2|0)==0){he=fe}else{if((c[l>>2]|0)==0){he=fe;break}he=d[ga]|0}}while(0);do{if((ge&4|0)==0){ie=he}else{if((c[r>>2]|0)!=((c[z>>2]|0)-1|0)){ie=he;break}ie=d[ga]|0}}while(0);if((ge&8|0)==0){be=ie;break}if((c[o>>2]|0)!=((c[ia>>2]|0)-1|0)){be=ie;break}be=d[ga]|0}}while(0);if(!((be|0)==0|(be|0)>31)){ae=be;break}KIb(c[B>>2]|0,16,2267264,(wb=i,i=i+8|0,c[wb>>2]=be,wb)|0);i=wb;ae=1}}while(0);a[(c[X>>2]|0)+$a|0]=ae;if((a[ba]|0)!=0){Bd=_a;Cd=ae;Dd=_d;break}if((c[M>>2]|0)!=0|(Vd|0)==0){Bd=_a;Cd=ae;Dd=_d;break}Wb=c[6074788+((c[da>>2]|0)*20|0)>>2]|0;Lb=c[Z>>2]|0;fb=c[_>>2]|0;hb=c[$>>2]|0;cb=hb+(Lb>>>3)|0;bb=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(Lb&7)>>>23;cb=b[Wb+(bb<<2)>>1]|0;Ob=b[Wb+(bb<<2)+2>>1]|0;bb=Ob<<16>>16;if(Ob<<16>>16<0){Ob=Lb+9|0;gb=fb>>>0>Ob>>>0?Ob:fb;Ob=hb+(gb>>>3)|0;hb=((je(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(gb&7)>>>((bb+32|0)>>>0))+cb|0;ke=b[Wb+(hb<<2)+2>>1]|0;le=b[Wb+(hb<<2)>>1]|0;me=gb}else{ke=bb;le=cb;me=Lb}Lb=ke+me|0;c[Z>>2]=fb>>>0>Lb>>>0?Lb:fb;Bd=le;Cd=ae;Dd=_d}}while(0);_a=Bd;$a=1;Mb=0;yb=0;while(1){fb=e+12496+(yb<<2)|0;Lb=c[fb>>2]|0;b[(c[W>>2]|0)+(Lb<<1)>>1]=0;cb=(yb>>2)+Mb|0;bb=Dd>>>((5-yb|0)>>>0)&1;gb=(yb&4|0)!=0;if(gb){ne=0}else{ne=(ca(c[la>>2]|0,yb<<2&8)|0)+(yb<<3&8)|0}a[(c[V>>2]|0)+Lb|0]=c[M>>2];do{if((c[M>>2]|0)==0){if((bb|0)==0){oe=$a;pe=_a;break}if(gb){re=(c[ma>>2]|0)>>>13&1}else{re=0}h7a(e,(c[ja>>2]|0)+(yb<<7)|0,yb,Cd,_a,$a,(c[e+12544+(cb<<2)>>2]|0)+ne|0,c[(gb?ka:la)>>2]|0,re,0)|0;oe=0;pe=(a[ba]|0)==0&(_a|0)<8?-1:_a}else{c[na>>2]=0;c[oa>>2]=0;if((yb-2|0)>>>0<2>>>0){pb=341}else{if((c[l>>2]|0)==0){pb=341}}if((pb|0)==341){pb=0;c[oa>>2]=d[(c[V>>2]|0)+((c[fb>>2]|0)-(c[e+12520+(yb<<2)>>2]|0))|0]|0}if((yb|0)==3|(yb|0)==1){pb=344}else{if((c[r>>2]|0)!=0){pb=344}}if((pb|0)==344){pb=0;c[na>>2]=d[(c[V>>2]|0)+((c[fb>>2]|0)-1)|0]|0}g7a(e,(c[ja>>2]|0)+(yb<<7)|0,yb,bb,Cd,c[(gb?pa:qa)>>2]|0);if((yb|0)>3){if((c[ma>>2]&8192|0)!=0){oe=$a;pe=_a;break}}qe[c[ra>>2]&1023]((c[ja>>2]|0)+(yb<<7)|0);Lb=c[ja>>2]|0;if((a[sa]|0)!=0){hb=0;do{Wb=Lb+(yb<<7)+(hb<<1)|0;b[Wb>>1]=b[Wb>>1]<<1;hb=hb+1|0;}while((hb|0)<64)}ef[c[ta>>2]&4095](Lb+(yb<<7)|0,(c[e+12544+(cb<<2)>>2]|0)+ne|0,c[(gb?ka:la)>>2]|0);oe=$a;pe=_a}}while(0);gb=yb+1|0;if((gb|0)<6){_a=pe;$a=oe;Mb=cb;yb=gb}else{break}}}}while(0);Za=c[Z>>2]|0;if((Za|0)>(c[Aa>>2]|0)|(Za|0)<0){pb=356;break b}if((c[A>>2]|0)!=0){e7a(e,d[L]|0)}Ya=(c[r>>2]|0)+1|0;c[r>>2]=Ya;if((Ya|0)>=(c[z>>2]|0)){break}}}Ya=c[o>>2]|0;do{if((c[A>>2]|0)==0){MTa(k,Ya<<4,16)}else{if((Ya|0)==0){break}MTa(k,(Ya<<4)-16|0,16)}}while(0);c[l>>2]=0;Ya=(c[o>>2]|0)+1|0;c[o>>2]=Ya;Za=c[p>>2]|0;if((Ya|0)>=(Za|0)){se=Za;te=A;break a}}if((pb|0)==83){KIb(0,0,2565376,(wb=i,i=i+24|0,c[wb>>2]=2240232,c[wb+8>>2]=2529528,c[wb+16>>2]=1214,wb)|0);i=wb;Hd()}else if((pb|0)==102){KIb(0,0,2565376,(wb=i,i=i+24|0,c[wb>>2]=2240232,c[wb+8>>2]=2529528,c[wb+16>>2]=1214,wb)|0);i=wb;Hd()}else if((pb|0)==130){KIb(0,0,2565376,(wb=i,i=i+24|0,c[wb>>2]=2240232,c[wb+8>>2]=2529528,c[wb+16>>2]=1214,wb)|0);i=wb;Hd()}else if((pb|0)==356){ypb(e+14424|0,0,c[m>>2]|0,c[r>>2]|0,c[o>>2]|0,14);A=c[Aa>>2]|0;z=c[r>>2]|0;L=c[o>>2]|0;KIb(c[B>>2]|0,16,2272072,(wb=i,i=i+32|0,c[wb>>2]=c[Z>>2],c[wb+8>>2]=A,c[wb+16>>2]=z,c[wb+24>>2]=L,wb)|0);i=wb;i=f;return}}else{se=q;te=e+13836|0}}while(0);if((c[te>>2]|0)==0){ue=se}else{MTa(k,(se<<4)-16|0,16);ue=c[p>>2]|0}p=c[e+19428>>2]|0;ypb(e+14424|0,0,c[m>>2]<<p,(c[e+116>>2]|0)-1|0,(ue<<p)-1|0,112);i=f;return}function Y6a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=(c[a+120>>2]|0)+1|0;d=b&-2;e=a+124|0;f=a+16092|0;c[f>>2]=hJb(ca(d,c[e>>2]|0)|0)|0;g=a+16096|0;c[g>>2]=hJb(ca(c[e>>2]|0,d)|0)|0;c[a+16100>>2]=hJb(ca(c[e>>2]|0,d)|0)|0;c[a+19324>>2]=pJb(ca(c[e>>2]|0,d)|0)|0;h=a+19252|0;c[h>>2]=hJb(ca(c[e>>2]|0,d)|0)|0;i=a+19260|0;c[i>>2]=hJb(ca(c[e>>2]|0,d)|0)|0;j=(c[a+116>>2]|0)+2|0;c[a+19560>>2]=j;k=a+19556|0;c[k>>2]=hJb(j*768|0)|0;j=hJb(c[e>>2]<<3)|0;l=a+19580|0;c[l>>2]=j;m=c[e>>2]|0;c[a+19584>>2]=j+(m<<2);j=hJb(m<<3)|0;m=a+16024|0;c[m>>2]=j;n=c[e>>2]|0;c[a+16028>>2]=j+(n<<2);j=pJb(n<<1)|0;n=a+19588|0;c[n>>2]=j;o=c[e>>2]|0;c[a+19592>>2]=j+o;j=pJb(o<<3)|0;o=a+19596|0;c[o>>2]=j;p=c[e>>2]|0;c[a+19600>>2]=j+(p<<2);j=a+128|0;q=d<<1|1;d=b|1;b=d<<1;r=hJb((ca(b,p)|0)+(ca(c[j>>2]|0,q)|0)|0)|0;p=a+16052|0;c[p>>2]=r;s=c[j>>2]|0;c[a+16056>>2]=r+(s+1);t=ca(s,q)|0;s=c[e>>2]|0;u=s+1+t|0;c[a+16060>>2]=r+u;c[a+16064>>2]=r+(u+(ca(s,d)|0));d=pJb((ca(b,s)|0)+t|0)|0;c[a+19396>>2]=d;t=c[j>>2]|0;c[a+19400>>2]=d+(t+1);d=ca(t,q)|0;t=pJb((ca(b,c[e>>2]|0)|0)+d<<1)|0;c[a+19404>>2]=t;d=c[j>>2]|0;s=d+1|0;c[a+19408>>2]=t+s;u=ca(d,q)|0;d=ca(b,c[e>>2]|0)|0;c[a+19412>>2]=t+(u+s+d);s=pJb(d+u<<1)|0;c[a+19416>>2]=s;u=c[j>>2]|0;j=u+1|0;c[a+19420>>2]=s+j;d=ca(u,q)|0;c[a+19424>>2]=s+(d+j+(ca(b,c[e>>2]|0)|0));_pb(a+14672|0,a|0);a:do{if(((c[(c[a+4>>2]|0)+48>>2]|0)-152|0)>>>0<2>>>0){e=a+19512|0;b=0;while(1){if((b|0)>=4){break a}j=hJb(c[e>>2]|0)|0;c[a+19528+(b>>1<<3)+((b&1)<<2)>>2]=j;if((j|0)==0){v=-12;break}else{b=b+1|0}}return v|0}}while(0);do{if((c[f>>2]|0)!=0){if((c[g>>2]|0)==0){break}if((c[h>>2]|0)==0){break}if((c[i>>2]|0)==0){break}if((c[k>>2]|0)==0){break}if((c[l>>2]|0)==0){break}if((c[m>>2]|0)==0){break}if((c[n>>2]|0)==0){break}if((c[o>>2]|0)==0){break}if((c[p>>2]|0)==0){break}else{v=0}return v|0}}while(0);mJb(f);mJb(g);mJb(h);mJb(i);mJb(k);mJb(l);mJb(m);mJb(n);mJb(o);mJb(p);v=-12;return v|0}function Z6a(b){b=b|0;var d=0,e=0;d=0;do{e=a[1246600+d|0]|0;a[b+15730+d|0]=e<<3&56|(e&255)>>>3;e=a[1246664+d|0]|0;a[b+15794+d|0]=e<<3&56|(e&255)>>>3;e=a[1246728+d|0]|0;a[b+15858+d|0]=e<<3&56|(e&255)>>>3;e=a[1246792+d|0]|0;a[b+15922+d|0]=e<<3&56|(e&255)>>>3;e=a[1267640+d|0]|0;a[b+19332+d|0]=e<<3&56|(e&255)>>>3;d=d+1|0;}while((d|0)<64);c[b+15988>>2]=0;c[b+15992>>2]=3;return}function _6a(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+19508|0);mJb(b+19528|0);mJb(b+19532|0);mJb(b+19536|0);mJb(b+19540|0);mJb(b+19272|0);mJb(b+19276|0);xTa(b);mJb(b+16092|0);mJb(b+16096|0);mJb(b+16100|0);mJb(b+19324|0);mJb(b+19252|0);mJb(b+19260|0);mJb(b+16052|0);mJb(b+19396|0);mJb(b+19404|0);mJb(b+19416|0);mJb(b+19556|0);mJb(b+19580|0);mJb(b+16024|0);mJb(b+19588|0);mJb(b+19596|0);$pb(b+14672|0);return 0}function $6a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+24|0;f=e|0;g=c[b+60>>2]|0;h=g;j=b+120|0;k=g+19512|0;c[k>>2]=c[j>>2];l=b+124|0;m=g+19516|0;c[m>>2]=c[l>>2];n=b+100|0;if((c[n>>2]|0)==0){o=-1;i=e;return o|0}p=b+96|0;if((c[p>>2]|0)==0){o=-1;i=e;return o|0}if((c[b+88>>2]&8192|0)==0){c[b+140>>2]=We[c[b+152>>2]&2047](b,c[(c[b+12>>2]|0)+24>>2]|0)|0}else{c[b+140>>2]=8}c[b+712>>2]=E5a(b)|0;c[g+4>>2]=b;q=Q6a(h)|0;if((q|0)<0){o=q;i=e;return o|0}q=EUa(b)|0;if((q|0)<0){o=q;i=e;return o|0}q=Y6a(h)|0;if((q|0)<0){o=q;i=e;return o|0}_6a(b)|0;Mia(g+15300|0,8);v7a(g+15332|0);q=b+48|0;r=c[q>>2]|0;do{if((r|0)==72|(r|0)==152){s=c[p>>2]|0;t=c[n>>2]<<3;u=t>>>0>2147483639>>>0|(s|0)==0;v=u?0:s;s=u?0:t;t=f|0;c[t>>2]=v;c[f+12>>2]=s;u=f+16|0;c[u>>2]=s+8;c[f+4>>2]=v+(s>>3);s=f+8|0;c[s>>2]=0;v=K6a(b,h,f)|0;if((v|0)<0){o=v;i=e;return o|0}v=c[n>>2]<<3;w=c[s>>2]|0;x=v-w|0;if((x|0)>0){y=c[u>>2]|0;u=(c[t>>2]|0)+(w>>>3)|0;t=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(w&7)>>>((32-x|0)>>>0);c[s>>2]=y>>>0>v>>>0?v:y;KIb(b,32,2321792,(z=i,i=i+16|0,c[z>>2]=x,c[z+8>>2]=t,z)|0);i=z;break}if((x|0)>=0){break}KIb(b,32,2316768,(z=i,i=i+8|0,c[z>>2]=-x,z)|0);i=z}else{x=c[p>>2]|0;t=c[n>>2]|0;y=x+t|0;if((t|0)<16){KIb(b,16,2312224,(z=i,i=i+8|0,c[z>>2]=t,z)|0);i=z;o=-1;i=e;return o|0}v=pJb(t+16|0)|0;t=y;s=-1;w=x;while(1){if(!(w>>>0<y>>>0)){A=y;break}x=s<<8;if((x|0)==256){B=20;break}else{s=d[w]|x;w=w+1|0}}if((B|0)==20){A=w-3|0}s=(v|0)==0;x=f|0;u=f+12|0;C=f+16|0;D=f+4|0;E=f+8|0;F=0;G=0;H=A;a:while(1){I=F;J=H;b:while(1){if(J>>>0<y>>>0){K=J}else{B=45;break a}while(1){L=K+4|0;c:do{if((t-L|0)<4){M=y}else{N=-1;O=L;while(1){if(!(O>>>0<y>>>0)){M=y;break c}P=N<<8;if((P|0)==256){break}else{N=d[O]|P;O=O+1|0}}M=O-3|0}}while(0);N=M-K|0;P=N-4|0;if((P|0)>=1){if((P|0)<4){Q=L;R=v;S=0;while(1){a[R]=a[Q]|0;T=S+1|0;if((T|0)<(P|0)){Q=Q+1|0;R=R+1|0;S=T}else{U=P;break}}}else{S=N-5|0;R=L;Q=0;T=0;while(1){V=a[R]|0;do{if(V<<24>>24==3&(T|0)>1){if((a[R-1|0]|0)!=0){B=37;break}if(!((a[R-2|0]|0)==0&(T|0)<(S|0))){B=37;break}W=R+1|0;X=a[W]|0;if(!((X&255)>>>0<4>>>0)){B=37;break}a[v+Q|0]=X;Y=T+1|0;Z=W}else{B=37}}while(0);if((B|0)==37){B=0;a[v+Q|0]=V;Y=T;Z=R}O=Q+1|0;W=Y+1|0;if((W|0)<(P|0)){R=Z+1|0;Q=O;T=W}else{U=O;break}}}T=U<<3;Q=T>>>0>2147483639>>>0|s;R=Q?0:v;P=Q?0:T;c[x>>2]=R;c[u>>2]=P;c[C>>2]=P+8;c[D>>2]=R+(P>>3);c[E>>2]=0;P=K;R=je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;if((R|0)==271){break b}else if((R|0)==270){break}}if(M>>>0<y>>>0){K=M}else{B=45;break a}}_=L6a(b,h,f)|0;if((_|0)<0){B=44;break a}else{I=1;J=M}}$=K6a(b,h,f)|0;if(($|0)<0){B=42;break}else{F=I;G=1;H=M}}if((B|0)==42){kJb(v);o=$;i=e;return o|0}else if((B|0)==44){kJb(v);o=_;i=e;return o|0}else if((B|0)==45){kJb(v);if(!((G|0)==0|(I|0)==0)){c[g+15580>>2]=(c[q>>2]|0)==153;break}KIb(b,16,2307704,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1;i=e;return o|0}}}while(0);I=UHb()|0;c[g+19508>>2]=I;if((I|0)==0){o=-12;i=e;return o|0}I=g+15660|0;c[b+840>>2]=c[I>>2];if((c[I>>2]|0)==3){c[b+844>>2]=c[g+15616>>2]}c[b+176>>2]=(c[b+156>>2]|0)!=0;_=b+128|0;c[g+116>>2]=(c[_>>2]|0)+15>>4;$=b+132|0;c[g+120>>2]=(c[$>>2]|0)+15>>4;do{if((c[I>>2]|0)==3){aa=0;B=53}else{if((c[g+15596>>2]|0)!=0){aa=0;B=53;break}nrc(g+15730|0,1246600,256)|0;c[g+15988>>2]=3;c[g+15992>>2]=0}}while(0);if((B|0)==53){while(1){B=0;I=a[1246600+aa|0]|0;a[h+15730+aa|0]=I<<3&56|(I&255)>>>3;I=a[1246664+aa|0]|0;a[h+15794+aa|0]=I<<3&56|(I&255)>>>3;I=a[1246728+aa|0]|0;a[h+15858+aa|0]=I<<3&56|(I&255)>>>3;I=a[1246792+aa|0]|0;a[h+15922+aa|0]=I<<3&56|(I&255)>>>3;I=a[1267640+aa|0]|0;a[h+19332+aa|0]=I<<3&56|(I&255)>>>3;I=aa+1|0;if((I|0)<64){aa=I;B=53}else{break}}c[g+15988>>2]=0;c[g+15992>>2]=3}if(!(((c[q>>2]|0)-152|0)>>>0<2>>>0)){o=0;i=e;return o|0}q=g+19520|0;c[q>>2]=c[_>>2];B=g+19524|0;c[B>>2]=c[$>>2];g=c[k>>2]|0;c[j>>2]=g;c[_>>2]=g;g=c[m>>2]|0;c[l>>2]=g;c[$>>2]=g;g=c[q>>2]|0;if((g|0)>16384){o=-1;i=e;return o|0}q=c[B>>2]|0;if((q|0)>16384){o=-1;i=e;return o|0}if((c[k>>2]|0)>16384){o=-1;i=e;return o|0}if((c[m>>2]|0)>16384){o=-1;i=e;return o|0}do{if((g&1|0)==0){if((q&1|0)==0){o=0}else{break}i=e;return o|0}}while(0);QIb(b,2302048,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;o=-1163346256;i=e;return o|0}function a7a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0;h=i;i=i+248|0;j=h|0;k=h+16|0;l=h+32|0;m=h+40|0;n=h+48|0;o=h+56|0;p=h+64|0;q=h+72|0;r=c[g+24>>2]|0;s=c[g+28>>2]|0;g=c[b+60>>2]|0;t=g;u=g;v=e;e=g+19436|0;c[e>>2]=0;w=g+60|0;if((c[w>>2]&524288|0)!=0){c[g+13944>>2]=1}if((s|0)==4){x=r;if((d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)==167837696){y=5}}else if((s|0)==0){y=5}if((y|0)==5){if((c[g+13944>>2]|0)!=0){z=s;i=h;return z|0}x=g+9852|0;A=c[x>>2]|0;if((A|0)==0){z=s;i=h;return z|0}B=YHb(v,A|0)|0;if((B|0)<0){z=B;i=h;return z|0}c[x>>2]=0;c[f>>2]=1;z=s;i=h;return z|0}x=g+4|0;do{if((c[(c[(c[x>>2]|0)+12>>2]|0)+16>>2]&128|0)!=0){B=b+140|0;if((c[g+15660>>2]|0)<3){c[B>>2]=39;break}else{c[B>>2]=40;break}}}while(0);B=b+48|0;A=c[B>>2]|0;a:do{if((A|0)==71|(A|0)==153){C=s+16|0;D=pJb(C)|0;if((D|0)==0){z=-12;i=h;return z|0}E=r;F=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=F&255;b:do{if(((je(F|0)|0)&-256|0)==256){G=r+s|0;if((s|0)<=0){H=0;I=r;J=0;K=-1;L=0;M=0;break}N=G;O=b+712|0;P=g+120|0;Q=g+14120|0;R=Q;S=Q;Q=g+14132|0;T=g+14136|0;U=g+14124|0;V=g+14128|0;W=0;X=0;Y=r;Z=-1;_=0;$=r;aa=0;while(1){ba=Y+4|0;c:do{if((N-ba|0)<4){da=G}else{ea=-1;fa=ba;while(1){if(!(fa>>>0<G>>>0)){da=G;break c}ga=ea<<8;if((ga|0)==256){break}else{ea=d[fa]|ga;fa=fa+1|0}}da=fa-3|0}}while(0);ea=da-Y|0;ga=ea-4|0;d:do{if((ga|0)<1){ha=aa;ia=$;ja=_;ka=Z;la=X;ma=W}else{na=Y;oa=je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0;if((oa|0)==269){if((c[O>>2]|0)==0){if((c[(c[(c[x>>2]|0)+12>>2]|0)+16>>2]&128|0)==0){pa=$}else{y=27}}else{y=27}if((y|0)==27){y=0;pa=Y}if((ga|0)<4){if((ga|0)>0){qa=ba;ra=D;sa=0}else{ha=aa;ia=pa;ja=_;ka=Z;la=ga;ma=W;break}while(1){a[ra]=a[qa]|0;na=sa+1|0;if((na|0)<(ga|0)){qa=qa+1|0;ra=ra+1|0;sa=na}else{ha=aa;ia=pa;ja=_;ka=Z;la=ga;ma=W;break d}}}fa=ea-5|0;na=ba;ta=0;ua=0;while(1){va=a[na]|0;do{if(va<<24>>24==3&(ua|0)>1){if((a[na-1|0]|0)!=0){y=37;break}if(!((a[na-2|0]|0)==0&(ua|0)<(fa|0))){y=37;break}wa=na+1|0;xa=a[wa]|0;if(!((xa&255)>>>0<4>>>0)){y=37;break}a[D+ta|0]=xa;ya=ua+1|0;za=wa}else{y=37}}while(0);if((y|0)==37){y=0;a[D+ta|0]=va;ya=ua;za=na}wa=ta+1|0;xa=ya+1|0;if((xa|0)<(ga|0)){na=za+1|0;ta=wa;ua=xa}else{ha=aa;ia=pa;ja=_;ka=Z;la=wa;ma=W;break}}}else if((oa|0)==268){if((c[O>>2]|0)==0){if((c[(c[(c[x>>2]|0)+12>>2]|0)+16>>2]&128|0)==0){Aa=_}else{y=41}}else{y=41}if((y|0)==41){y=0;Aa=Y}ua=aa+1|0;ta=iJb(W,ua*28|0)|0;na=ta;if((ta|0)==0){Ba=aa;Ca=D;Da=W;y=342;break a}ta=pJb(C)|0;fa=na+(aa*28|0)|0;c[fa>>2]=ta;if((ta|0)==0){Ba=aa;Ca=D;Da=na;y=342;break a}do{if((ga|0)<4){if((ga|0)>0){Ea=ba;Fa=ta;Ga=0}else{Ha=ga;break}while(1){a[Fa]=a[Ea]|0;wa=Ga+1|0;if((wa|0)<(ga|0)){Ea=Ea+1|0;Fa=Fa+1|0;Ga=wa}else{Ha=ga;break}}}else{va=ea-5|0;wa=ba;xa=0;Ia=0;while(1){Ja=a[wa]|0;do{if(Ja<<24>>24==3&(Ia|0)>1){if((a[wa-1|0]|0)!=0){y=53;break}if(!((a[wa-2|0]|0)==0&(Ia|0)<(va|0))){y=53;break}Ka=wa+1|0;La=a[Ka]|0;if(!((La&255)>>>0<4>>>0)){y=53;break}a[ta+xa|0]=La;Ma=Ia+1|0;Na=Ka}else{y=53}}while(0);if((y|0)==53){y=0;a[ta+xa|0]=Ja;Ma=Ia;Na=wa}Ka=xa+1|0;La=Ma+1|0;if((La|0)<(ga|0)){wa=Na+1|0;xa=Ka;Ia=La}else{Ha=Ka;break}}}}while(0);ta=c[fa>>2]|0;Ia=Ha<<3;xa=Ia>>>0>2147483639>>>0|(ta|0)==0;wa=xa?0:ta;ta=xa?0:Ia;c[na+(aa*28|0)+4>>2]=wa;c[na+(aa*28|0)+16>>2]=ta;c[na+(aa*28|0)+20>>2]=ta+8;c[na+(aa*28|0)+8>>2]=wa+(ta>>3);c[na+(aa*28|0)+12>>2]=0;c[na+(aa*28|0)+24>>2]=(c[P>>2]|0)+1>>1;ha=ua;ia=$;ja=Aa;ka=aa-1|0;la=X;ma=na;break}else if((oa|0)==270){do{if((ga|0)<4){if((ga|0)>0){Oa=ba;Pa=D;Qa=0}else{Ra=ga;break}while(1){a[Pa]=a[Oa]|0;ta=Qa+1|0;if((ta|0)<(ga|0)){Oa=Oa+1|0;Pa=Pa+1|0;Qa=ta}else{Ra=ga;break}}}else{ta=ea-5|0;wa=ba;Ia=0;xa=0;while(1){va=a[wa]|0;do{if(va<<24>>24==3&(xa|0)>1){if((a[wa-1|0]|0)!=0){y=65;break}if(!((a[wa-2|0]|0)==0&(xa|0)<(ta|0))){y=65;break}Ka=wa+1|0;La=a[Ka]|0;if(!((La&255)>>>0<4>>>0)){y=65;break}a[D+Ia|0]=La;Sa=xa+1|0;Ta=Ka}else{y=65}}while(0);if((y|0)==65){y=0;a[D+Ia|0]=va;Sa=xa;Ta=wa}Ja=Ia+1|0;Ka=Sa+1|0;if((Ka|0)<(ga|0)){wa=Ta+1|0;Ia=Ja;xa=Ka}else{Ra=Ja;break}}}}while(0);na=Ra<<3;ua=na>>>0>2147483639>>>0;fa=ua?0:D;xa=ua?0:na;c[S>>2]=fa;c[Q>>2]=xa;c[T>>2]=xa+8;c[U>>2]=fa+(xa>>3);c[V>>2]=0;L6a(b,t,R)|0;ha=aa;ia=$;ja=_;ka=Z;la=Ra;ma=W;break}else if((oa|0)==267){xa=aa+1|0;fa=iJb(W,xa*28|0)|0;na=fa;if((fa|0)==0){Ba=aa;Ca=D;Da=W;y=342;break a}fa=pJb(C)|0;ua=na+(aa*28|0)|0;c[ua>>2]=fa;if((fa|0)==0){Ba=aa;Ca=D;Da=na;y=342;break a}do{if((ga|0)<4){if((ga|0)>0){Ua=ba;Va=fa;Wa=0}else{Xa=ga;break}while(1){a[Va]=a[Ua]|0;Ia=Wa+1|0;if((Ia|0)<(ga|0)){Ua=Ua+1|0;Va=Va+1|0;Wa=Ia}else{Xa=ga;break}}}else{Ia=ea-5|0;wa=ba;ta=0;Ja=0;while(1){Ka=a[wa]|0;do{if(Ka<<24>>24==3&(Ja|0)>1){if((a[wa-1|0]|0)!=0){y=79;break}if(!((a[wa-2|0]|0)==0&(Ja|0)<(Ia|0))){y=79;break}La=wa+1|0;Ya=a[La]|0;if(!((Ya&255)>>>0<4>>>0)){y=79;break}a[fa+ta|0]=Ya;Za=Ja+1|0;_a=La}else{y=79}}while(0);if((y|0)==79){y=0;a[fa+ta|0]=Ka;Za=Ja;_a=wa}va=ta+1|0;La=Za+1|0;if((La|0)<(ga|0)){wa=_a+1|0;ta=va;Ja=La}else{Xa=va;break}}}}while(0);fa=c[ua>>2]|0;oa=Xa<<3;Ja=oa>>>0>2147483639>>>0|(fa|0)==0;ta=Ja?0:fa;fa=Ja?0:oa;c[na+(aa*28|0)+4>>2]=ta;c[na+(aa*28|0)+16>>2]=fa;oa=fa+8|0;c[na+(aa*28|0)+20>>2]=oa;c[na+(aa*28|0)+8>>2]=ta+(fa>>3);fa=na+(aa*28|0)+12|0;c[fa>>2]=0;Ja=ta;ta=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)>>>23;c[fa>>2]=oa>>>0>9>>>0?9:oa;c[na+(aa*28|0)+24>>2]=ta;ha=xa;ia=$;ja=_;ka=Z;la=X;ma=na;break}else{ha=aa;ia=$;ja=_;ka=Z;la=X;ma=W;break}}}while(0);if(da>>>0<G>>>0){W=ma;X=la;Y=da;Z=ka;_=ja;$=ia;aa=ha}else{H=ha;I=ia;J=ja;K=ka;L=la;M=ma;break}}}else{do{if((c[g+15632>>2]|0)!=0){if(!((E&-64)<<24>>24==-64)){break}aa=r+s|0;$=aa;_=r;e:do{if((s|0)<4){y=89}else{Z=-1;Y=r;while(1){if(!(Y>>>0<aa>>>0)){y=89;break e}X=Z<<8;$a=Y+1|0;if((X|0)==256){break}else{Z=d[Y]|X;Y=$a}}Z=Y-3|0;if((Z|0)==(aa|0)){y=89;break}na=Z;if((d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)!=201392128){y=89;break}if((c[b+712>>2]|0)==0){if((c[(c[(c[x>>2]|0)+12>>2]|0)+16>>2]&128|0)==0){ab=0}else{y=92}}else{y=92}if((y|0)==92){ab=Z}na=iJb(0,28)|0;xa=na;if((na|0)==0){bb=0;break}ua=pJb(C)|0;X=na;c[X>>2]=ua;if((ua|0)==0){bb=xa;break}W=Z;Z=$-W|0;G=Z-4|0;do{if((G|0)<4){if((G|0)>0){cb=$a;db=ua;eb=0}else{fb=G;break}while(1){a[db]=a[cb]|0;R=eb+1|0;if((R|0)<(G|0)){cb=cb+1|0;db=db+1|0;eb=R}else{fb=G;break}}}else{R=Z-5|0;V=$a;U=0;T=0;while(1){Q=a[V]|0;do{if(Q<<24>>24==3&(T|0)>1){if((a[V-1|0]|0)!=0){y=104;break}if(!((a[V-2|0]|0)==0&(T|0)<(R|0))){y=104;break}S=V+1|0;P=a[S]|0;if(!((P&255)>>>0<4>>>0)){y=104;break}a[ua+U|0]=P;gb=T+1|0;hb=S}else{y=104}}while(0);if((y|0)==104){y=0;a[ua+U|0]=Q;gb=T;hb=V}Ka=U+1|0;S=gb+1|0;if((S|0)<(G|0)){V=hb+1|0;U=Ka;T=S}else{fb=Ka;break}}}}while(0);G=c[X>>2]|0;ua=fb<<3;Z=ua>>>0>2147483639>>>0|(G|0)==0;Y=Z?0:G;G=Z?0:ua;c[na+4>>2]=Y;c[na+16>>2]=G;c[na+20>>2]=G+8;c[na+8>>2]=Y+(G>>3);c[na+12>>2]=0;c[na+24>>2]=(c[g+120>>2]|0)+1>>1;G=W-_|0;if((G|0)<4){if((G|0)>0){ib=r;jb=D;kb=0}else{H=1;I=r;J=ab;K=-1;L=G;M=xa;break b}while(1){a[jb]=a[ib]|0;Y=kb+1|0;if((Y|0)<(G|0)){ib=ib+1|0;jb=jb+1|0;kb=Y}else{H=1;I=r;J=ab;K=-1;L=G;M=xa;break b}}}W=G-1|0;na=r;X=0;Y=0;while(1){ua=a[na]|0;do{if(ua<<24>>24==3&(Y|0)>1){if((a[na-1|0]|0)!=0){y=115;break}if(!((a[na-2|0]|0)==0&(Y|0)<(W|0))){y=115;break}Z=na+1|0;T=a[Z]|0;if(!((T&255)>>>0<4>>>0)){y=115;break}a[D+X|0]=T;lb=Y+1|0;mb=Z}else{y=115}}while(0);if((y|0)==115){y=0;a[D+X|0]=ua;lb=Y;mb=na}Z=X+1|0;T=lb+1|0;if((T|0)<(G|0)){na=mb+1|0;X=Z;Y=T}else{H=1;I=r;J=ab;K=-1;L=Z;M=xa;break b}}}}while(0);if((y|0)==89){KIb(b,16,2141936,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;bb=0}kJb(D);ob=bb;break a}}while(0);if((s|0)<4){if((s|0)>0){pb=r;qb=D;rb=1;sb=E}else{H=0;I=r;J=0;K=-1;L=s;M=0;break}while(1){_=pb+1|0;a[qb]=sb;if((rb|0)>=(s|0)){H=0;I=r;J=0;K=-1;L=s;M=0;break b}pb=_;qb=qb+1|0;rb=rb+1|0;sb=a[_]|0}}_=s-1|0;$=r;aa=0;xa=0;Y=E;while(1){do{if(Y<<24>>24==3&(xa|0)>1){if((a[$-1|0]|0)!=0){y=127;break}if(!((a[$-2|0]|0)==0&(xa|0)<(_|0))){y=127;break}X=$+1|0;na=a[X]|0;if(!((na&255)>>>0<4>>>0)){y=127;break}a[D+aa|0]=na;tb=xa+1|0;ub=X}else{y=127}}while(0);if((y|0)==127){y=0;a[D+aa|0]=Y;tb=xa;ub=$}X=aa+1|0;na=tb+1|0;G=ub+1|0;if((na|0)>=(s|0)){H=0;I=r;J=0;K=-1;L=X;M=0;break b}$=G;aa=X;xa=na;Y=a[G]|0}}}while(0);E=L<<3;C=E>>>0>2147483639>>>0;F=C?0:D;Y=C?0:E;c[g+14120>>2]=F;c[g+14132>>2]=Y;E=Y+8|0;c[g+14136>>2]=E;c[g+14124>>2]=F+(Y>>3);c[g+14128>>2]=0;vb=H;wb=D;xb=I;yb=J;zb=K;Ab=M;Bb=F;Cb=E;y=132}else{E=s<<3;F=E>>>0>2147483639>>>0|(r|0)==0;Y=F?0:r;C=F?0:E;c[g+14120>>2]=Y;c[g+14132>>2]=C;E=C+8|0;c[g+14136>>2]=E;c[g+14124>>2]=Y+(C>>3);c[g+14128>>2]=0;vb=0;wb=0;xb=r;yb=0;zb=-1;Ab=0;Bb=Y;Cb=E;y=132}}while(0);f:do{if((y|0)==132){M=g+15580|0;do{if((c[M>>2]|0)==0){y=137}else{K=g+14128|0;J=d[Bb]|0;I=(Cb|0)>0|0;c[K>>2]=I;H=J>>>7;c[g+19500>>2]=H^1;J=d[Bb]<<I>>>7;c[K>>2]=((I|0)<(Cb|0))+I;c[g+19504>>2]=J&1;if(!(((c[B>>2]|0)-152|0)>>>0<2>>>0)){y=137;break}if((H|0)==1){Db=b+856|0;y=240;break}else{H=c[g+19520>>2]|0;c[b+128>>2]=H;c[b+120>>2]=H;H=c[g+19524>>2]|0;c[b+132>>2]=H;c[b+124>>2]=H;y=137;break}}}while(0);g:do{if((y|0)==137){D=g+96|0;H=c[D>>2]|0;do{if((H|0)==0){y=143}else{if((c[g+8>>2]|0)==(c[b+128>>2]|0)){if((c[g+12>>2]|0)==(c[b+132>>2]|0)){Eb=H}else{y=140}}else{y=140}if((y|0)==140){_6a(b)|0;Eb=c[D>>2]|0}if((Eb|0)==0){y=143;break}Fb=c[g+15660>>2]|0;y=152}}while(0);do{if((y|0)==143){if((EUa(b)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((Y6a(t)|0)<0){xTa(u);Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((c[b+176>>2]|0)==0){Gb=1}else{Gb=(c[M>>2]|0)!=0|0}c[g+13944>>2]=Gb;D=c[g+15660>>2]|0;if((D|0)!=3){Fb=D;y=152;break}D=c[b+128>>2]|0;if((D|0)<2){Ba=vb;Ca=wb;Da=Ab;y=342;break f}H=b+132|0;if((c[H>>2]|0)<2){Ba=vb;Ca=wb;Da=Ab;y=342;break f}c[g+136>>2]=D;c[g+140>>2]=c[H>>2];H=g+19496|0;c[H>>2]=0;D=g+19492|0;c[D>>2]=1;J=g+14120|0;Hb=H;Ib=D;Jb=J;Kb=J;y=154}}while(0);do{if((y|0)==152){J=g+19496|0;c[J>>2]=0;D=g+19492|0;c[D>>2]=1;H=g+14120|0;I=H;if((Fb|0)>=3){Hb=J;Ib=D;Jb=H;Kb=I;y=154;break}if((M6a(t,I)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}else{Lb=J;Mb=D;Nb=H;Ob=I}}}while(0);if((y|0)==154){if((P6a(t,Kb)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}else{Lb=Hb;Mb=Ib;Nb=Jb;Ob=Kb}}c[Mb>>2]=0;if((c[b+688>>2]&1|0)!=0){I=c[x>>2]|0;H=(BLb(c[g+9992>>2]|0)|0)<<24>>24;KIb(I,48,2118400,(nb=i,i=i+8|0,c[nb>>2]=H,nb)|0);i=nb}do{if(((c[B>>2]|0)-152|0)>>>0<2>>>0){if((c[g+9992>>2]|0)==1){break}KIb(c[x>>2]|0,16,2636336,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Ba=vb;Ca=wb;Da=Ab;y=342;break f}}while(0);H=g+120|0;I=g+19428|0;if((c[H>>2]>>c[I>>2]|0)==0){KIb(c[x>>2]|0,16,2613032,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Ba=vb;Ca=wb;Da=Ab;y=342;break f}D=g+9992|0;J=c[D>>2]|0;c[g+7712>>2]=J;K=(J|0)==1;c[g+7708>>2]=K&1;L=g+9848|0;if((c[L>>2]|0)==0){if((J|0)==3){Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((c[g+10008>>2]|0)!=0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}}ub=b+856|0;tb=c[ub>>2]|0;do{if((tb|0)>7){if((J|0)==3){break g}if((tb|0)<=31){break}if((tb|0)>47|K^1){break g}}}while(0);K=g+13736|0;if((c[K>>2]|0)!=0){if((J|0)==3){break}c[K>>2]=0}if((DTa(u,b)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}K=g+9856|0;tb=c[K>>2]|0;c[tb+2164>>2]=c[I>>2];c[tb+296>>2]=(c[g+19224>>2]|0)!=0;sb=g+19231|0;c[tb+300>>2]=d[sb]|0;rb=tb+292|0;c[rb>>2]=0;do{if((a[g+19232|0]|0)==0){tb=a[g+19230|0]|0;if(tb<<24>>24==0){break}c[rb>>2]=(tb&255)<<1}else{c[rb>>2]=1}}while(0);c[g+12452>>2]=g+10680;c[g+12456>>2]=g+10808;rb=b+712|0;J=c[rb>>2]|0;do{if((J|0)==0){STa(u);c[g+15576>>2]=s<<3;c[g+19608>>2]=c[g+116>>2];tb=c[I>>2]|0;if((tb|0)!=0){qb=g+7656|0;c[qb>>2]=c[qb>>2]<<1;qb=g+7660|0;c[qb>>2]=c[qb>>2]<<1;qb=g+7664|0;c[qb>>2]=c[qb>>2]<<1;qb=g+148|0;c[qb>>2]=c[qb>>2]<<1;qb=g+152|0;c[qb>>2]=c[qb>>2]<<1}qb=c[H>>2]>>tb;if((qb|0)<=0){KIb(0,0,2565376,(nb=i,i=i+24|0,c[nb>>2]=2547240,c[nb+8>>2]=2529528,c[nb+16>>2]=6106,nb)|0);i=nb;Hd();return 0}do{if((vb|0)<0){Pb=tb}else{pb=g+128|0;bb=g+19468|0;ab=g+124|0;mb=g+19472|0;lb=g+808|0;kb=(qb|0)>-1;jb=g+812|0;ib=g+19544|0;fb=g+16084|0;hb=zb+1|0;gb=g+14128|0;$a=Nb;eb=g+14136|0;db=b+696|0;cb=zb+2|0;ma=0;la=0;h:while(1){do{if((ma|0)>0){ka=c[Ab+((ma-1|0)*28|0)+24>>2]|0;if((ka|0)<(qb|0)){y=203;break}if((c[I>>2]|0)<1){KIb(c[x>>2]|0,16,2514240,(nb=i,i=i+24|0,c[nb>>2]=ma,c[nb+8>>2]=ka,c[nb+16>>2]=qb,nb)|0);i=nb;Qb=la;break}c[e>>2]=1;ka=c[H>>2]|0;if((ka&1|0)!=0){y=201;break h}c[bb>>2]=ca(c[pb>>2]|0,ka&-2)|0;Rb=(ca(ka,c[ab>>2]|0)|0)>>1;y=204}else{y=203}}while(0);if((y|0)==203){y=0;c[e>>2]=0;c[bb>>2]=0;Rb=0;y=204}i:do{if((y|0)==204){y=0;c[mb>>2]=Rb;ua=(ma|0)==0;do{if(ua){y=211}else{c[Lb>>2]=0;if((c[I>>2]|0)!=0&(ma|0)==(cb|0)){ka=P6a(t,Ob)|0;if((ka|0)>=0){Sb=ka;y=213;break}KIb(c[x>>2]|0,16,2487816,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;if((c[db>>2]&8|0)==0){Qb=ka;break i}else{Ba=vb;Ca=wb;Da=Ab;y=342;break f}}ka=c[gb>>2]|0;ja=d[(c[$a>>2]|0)+(ka>>>3)|0]|0;c[gb>>2]=((ka|0)<(c[eb>>2]|0))+ka;if((ja&128>>>((ka&7)>>>0)|0)==0){y=211;break}c[Lb>>2]=1;ka=P6a(t,Ob)|0;if((ka|0)>=0){Tb=ka;y=212;break}KIb(c[x>>2]|0,16,2476816,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;if((c[db>>2]&8|0)==0){Qb=ka;break i}else{Ba=vb;Ca=wb;Da=Ab;y=342;break f}}}while(0);if((y|0)==211){y=0;if((la|0)<0){Qb=la;break}else{Tb=la;y=212}}if((y|0)==212){y=0;if(ua){Ub=0;Vb=Tb}else{Sb=Tb;y=213}}if((y|0)==213){y=0;Q=(c[Ab+((ma-1|0)*28|0)+24>>2]|0)%(qb|0)|0;Ub=(Q|0)<0?0:Q;Vb=Sb}c[lb>>2]=Ub;do{if((c[I>>2]|0)==0){y=216}else{if((c[e>>2]|0)!=0){y=216;break}if((ma|0)>=(vb|0)){KIb(c[x>>2]|0,16,2467448,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Qb=Vb;break i}if(!((ma|0)>(hb|0)&kb)){Wb=qb;break}Wb=(c[Ab+(ma*28|0)+24>>2]|0)%(qb|0)|0}}while(0);do{if((y|0)==216){y=0;if(!((ma|0)!=(vb|0)&kb)){Wb=qb;break}Wb=(c[Ab+(ma*28|0)+24>>2]|0)%(qb|0)|0}}while(0);c[jb>>2]=Wb;if((Wb|0)<=(Ub|0)){KIb(c[x>>2]|0,16,2457648,(nb=i,i=i+16|0,c[nb>>2]=Wb,c[nb+8>>2]=Ub,nb)|0);i=nb;Qb=Vb;break}do{if((c[ib>>2]|0)==0){if((c[D>>2]|0)==1){break}if((c[fb>>2]|0)!=0){break}KIb(c[x>>2]|0,16,2440920,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Qb=Vb;break i}}while(0);T6a(t);if((ma|0)==(vb|0)){Qb=Vb;break}ua=Ab+(ma*28|0)+4|0;c[Nb>>2]=c[ua>>2];c[Nb+4>>2]=c[ua+4>>2];c[Nb+8>>2]=c[ua+8>>2];c[Nb+12>>2]=c[ua+12>>2];c[Nb+16>>2]=c[ua+16>>2];Qb=Vb}}while(0);ua=ma+1|0;if((ua|0)>(vb|0)){y=231;break}else{ma=ua;la=Qb}}if((y|0)==201){KIb(0,0,2565376,(nb=i,i=i+24|0,c[nb>>2]=2500576,c[nb+8>>2]=2529528,c[nb+16>>2]=6117,nb)|0);i=nb;Hd();return 0}else if((y|0)==231){Pb=c[I>>2]|0;break}}}while(0);qb=(Pb|0)==0;do{if(!qb){c[e>>2]=0;tb=g+7656|0;c[tb>>2]=c[tb>>2]>>1;tb=g+7660|0;c[tb>>2]=c[tb>>2]>>1;tb=g+7664|0;c[tb>>2]=c[tb>>2]>>1;tb=g+148|0;c[tb>>2]=c[tb>>2]>>1;tb=g+152|0;c[tb>>2]=c[tb>>2]>>1;tb=c[D>>2]|0;if((tb|0)==7|(tb|0)==3){break}tb=g+19408|0;la=c[tb>>2]|0;ma=g+19420|0;c[tb>>2]=c[ma>>2];c[ma>>2]=la;la=g+19412|0;ma=c[la>>2]|0;tb=g+19424|0;c[la>>2]=c[tb>>2];c[tb>>2]=ma}}while(0);ma=g+14424|0;if((c[g+14460>>2]|0)!=0){if((c[D>>2]|0)==3){Ba=vb;Ca=wb;Da=Ab;y=342;break f}}if(!qb){break}zpb(ma)}else{if((c[I>>2]|0)==0|(yb|0)==0){c[g+14172>>2]=3;ma=r+s-xb|0;if((Ee[c[J+24>>2]&511](b,xb,ma)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((Ee[c[(c[rb>>2]|0)+28>>2]&511](b,xb,ma)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((ve[c[(c[rb>>2]|0)+32>>2]&4095](b)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}else{break}}ma=g+14172|0;c[ma>>2]=2-(d[sb]|0);tb=yb;la=tb-xb|0;if((Ee[c[J+24>>2]&511](b,xb,la)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((Ee[c[(c[rb>>2]|0)+28>>2]&511](b,xb,la)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((ve[c[(c[rb>>2]|0)+32>>2]&4095](b)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}la=Ab+((zb+1|0)*28|0)+4|0;c[Nb>>2]=c[la>>2];c[Nb+4>>2]=c[la+4>>2];c[Nb+8>>2]=c[la+8>>2];c[Nb+12>>2]=c[la+12>>2];c[Nb+16>>2]=c[la+16>>2];c[ma>>2]=(d[sb]|0)+1;c[e>>2]=1;c[Lb>>2]=0;if((P6a(t,Ob)|0)<0){KIb(b,16,2586248,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Ba=vb;Ca=wb;Da=Ab;y=342;break f}c[(c[K>>2]|0)+88>>2]=c[D>>2];ma=r+s-tb|0;if((Ee[c[(c[rb>>2]|0)+24>>2]&511](b,yb,ma)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((Ee[c[(c[rb>>2]|0)+28>>2]&511](b,yb,ma)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((ve[c[(c[rb>>2]|0)+32>>2]&4095](b)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}}}while(0);ETa(u);if(((c[B>>2]|0)-152|0)>>>0<2>>>0){Db=ub;y=240;break}do{if((c[D>>2]|0)!=3){if((c[g+13944>>2]|0)!=0){break}rb=c[L>>2]|0;if((rb|0)==0){break g}if((YHb(v,rb|0)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}HTa(u,c[L>>2]|0,v);c[f>>2]=1;break g}}while(0);if((YHb(v,c[K>>2]|0)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}HTa(u,c[K>>2]|0,v);c[f>>2]=1}}while(0);do{if((y|0)==240){M=g+19512|0;L=c[M>>2]|0;c[b+128>>2]=L;c[b+120>>2]=L;L=g+19516|0;D=c[L>>2]|0;c[b+132>>2]=D;c[b+124>>2]=D;if((c[Db>>2]|0)>7){break}D=g+14120|0;ub=D;rb=c[x>>2]|0;mrc(q|0,0,172)|0;sb=g+19504|0;if((c[sb>>2]|0)>=0){J=rb;I=0;do{H=q+(I*28|0)|0;c7a(ub,H);ma=q+(I*28|0)+4|0;tb=q+(I*28|0)+12|0;if((c[ma>>2]|0)==0){if((c[tb>>2]|0)!=0){y=245}}else{y=245}if((y|0)==245){y=0;QIb(J,2409752,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb}KIb(J,48,(I|0)!=0?2402016:2395256,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;la=c[H>>2]|0;KIb(J,48,2388096,(nb=i,i=i+16|0,c[nb>>2]=(la|0)/65536|0,c[nb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,nb)|0);i=nb;la=c[ma>>2]|0;KIb(J,48,2388096,(nb=i,i=i+16|0,c[nb>>2]=(la|0)/65536|0,c[nb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,nb)|0);i=nb;la=c[q+(I*28|0)+8>>2]|0;KIb(J,48,2388096,(nb=i,i=i+16|0,c[nb>>2]=(la|0)/65536|0,c[nb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,nb)|0);i=nb;la=c[tb>>2]|0;KIb(J,48,2388096,(nb=i,i=i+16|0,c[nb>>2]=(la|0)/65536|0,c[nb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,nb)|0);i=nb;la=c[q+(I*28|0)+16>>2]|0;KIb(J,48,2388096,(nb=i,i=i+16|0,c[nb>>2]=(la|0)/65536|0,c[nb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,nb)|0);i=nb;la=c[q+(I*28|0)+20>>2]|0;KIb(J,48,2388096,(nb=i,i=i+16|0,c[nb>>2]=(la|0)/65536|0,c[nb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,nb)|0);i=nb;la=c[q+(I*28|0)+24>>2]|0;KIb(J,48,2388096,(nb=i,i=i+16|0,c[nb>>2]=(la|0)/65536|0,c[nb+8>>2]=((((la|0)>-1?la:-la|0)&65535)*1e3|0)>>>16,nb)|0);i=nb;KIb(J,48,2381152,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;I=I+1|0;}while((I|0)<=(c[sb>>2]|0))}I=g+14128|0;J=g+14136|0;K=c[J>>2]|0;la=(c[I>>2]|0)+2|0;tb=K>>>0>la>>>0?la:K;c[I>>2]=tb;la=D;ma=c[la>>2]|0;H=ma+(tb>>>3)|0;fb=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(tb&7)>>>16;H=tb+16|0;tb=K>>>0>H>>>0?H:K;c[I>>2]=tb;H=ma+(tb>>>3)|0;ib=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(tb&7)>>>18;H=tb+14|0;tb=K>>>0>H>>>0?H:K;c[I>>2]=tb;H=ib|fb<<14;fb=q+56|0;c[fb>>2]=H;do{if((H|0)==0){Xb=ma;Yb=tb;Zb=K}else{ib=ma+(tb>>>3)|0;jb=(je(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(tb&7)>>>28;ib=tb+4|0;kb=K>>>0>ib>>>0?ib:K;c[I>>2]=kb;ib=q+64|0;c[ib>>2]=jb;if((jb|0)==7){c7a(ub,q+72|0)}else if((jb|0)==14){c7a(ub,q+72|0);c7a(ub,q+100|0)}else if((jb|0)!=0){jb=0;hb=kb;do{kb=ma+(hb>>>3)|0;lb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(hb&7)>>>16;kb=hb+16|0;db=K>>>0>kb>>>0?kb:K;c[I>>2]=db;kb=ma+(db>>>3)|0;eb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(db&7)>>>18;kb=db+14|0;hb=K>>>0>kb>>>0?kb:K;c[I>>2]=hb;c[q+72+(jb<<2)>>2]=((eb|lb<<14)<<1)-1073741824;jb=jb+1|0;}while((jb|0)<(c[ib>>2]|0))}jb=c[fb>>2]|0;if((jb|0)==13){if((c[q+72>>2]|0)!=(c[q+24>>2]|0)){y=254}}else{y=254}if((y|0)==254){hb=rb;KIb(hb,48,2374808,(nb=i,i=i+8|0,c[nb>>2]=jb,nb)|0);i=nb;if((c[ib>>2]|0)>0){jb=0;do{qb=c[q+72+(jb<<2)>>2]|0;KIb(hb,48,2367640,(nb=i,i=i+16|0,c[nb>>2]=(qb|0)/65536|0,c[nb+8>>2]=((((qb|0)>-1?qb:-qb|0)&65535)*1e3|0)>>>16,nb)|0);i=nb;jb=jb+1|0;}while((jb|0)<(c[ib>>2]|0))}KIb(hb,48,2381152,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb}ib=c[I>>2]|0;jb=c[J>>2]|0;qb=c[la>>2]|0;lb=qb+(ib>>>3)|0;eb=(je(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(ib&7);lb=eb>>>16;kb=ib+16|0;ib=jb>>>0>kb>>>0?kb:jb;c[I>>2]=ib;kb=q+68|0;c[kb>>2]=lb;if(eb>>>0>720895>>>0){KIb(rb,16,2353064,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((lb|0)==0){Xb=qb;Yb=ib;Zb=jb;break}jb=rb;KIb(jb,48,2344704,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;if((c[kb>>2]|0)>0){ib=0;do{qb=c[I>>2]|0;lb=c[J>>2]|0;eb=c[la>>2]|0;db=eb+(qb>>>3)|0;gb=(je(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(qb&7)>>>16;db=qb+16|0;qb=lb>>>0>db>>>0?db:lb;c[I>>2]=qb;db=eb+(qb>>>3)|0;eb=(je(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(qb&7)>>>18;db=qb+14|0;c[I>>2]=lb>>>0>db>>>0?db:lb;lb=(eb|gb<<14)<<1;gb=lb-1073741824|0;c[q+132+(ib<<2)>>2]=gb;KIb(jb,48,2367640,(nb=i,i=i+16|0,c[nb>>2]=(gb|0)/65536|0,c[nb+8>>2]=((((gb|0)>-1?gb:1073741824-lb|0)&65534)*1e3|0)>>>16,nb)|0);i=nb;ib=ib+1|0;}while((ib|0)<(c[kb>>2]|0))}KIb(jb,48,2381152,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Xb=c[la>>2]|0;Yb=c[I>>2]|0;Zb=c[J>>2]|0}}while(0);J=d[Xb+(Yb>>>3)|0]<<(Yb&7)>>>7;la=((Yb|0)<(Zb|0))+Yb|0;c[I>>2]=la;fb=J&1;c[q+60>>2]=fb;if((fb|0)==0){_b=la}else{KIb(rb,48,2338680,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;_b=c[I>>2]|0}la=c[g+14132>>2]|0;if((_b|0)>=(((c[rb+48>>2]|0)==152?64:0)+la|0)){KIb(rb,16,2333048,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Ba=vb;Ca=wb;Da=Ab;y=342;break f}if((_b|0)<(la-8|0)){KIb(rb,24,2327640,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb}if((c[g+7624>>2]|0)==0){KIb(rb,16,2429208,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;Ba=vb;Ca=wb;Da=Ab;y=342;break f}do{if((c[sb>>2]|0)!=0){if((c[g+9848>>2]|0)!=0){if((c[g+952>>2]|0)!=0){break}}KIb(rb,24,2418728,(nb=i,i=i+1|0,i=i+7&-8,c[nb>>2]=0,nb)|0);i=nb;c[sb>>2]=0}}while(0);I=g+19508|0;WHb(c[I>>2]|0);if((M4a(rb,c[I>>2]|0,0)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}la=j;c[la>>2]=c[67012];c[la+4>>2]=c[67013];c[la+8>>2]=c[67014];c[la+12>>2]=c[67015];la=c[sb>>2]|0;if((la|0)>=0){fb=c[g+19520>>2]<<16;J=fb-65536|0;K=c[g+19524>>2]<<16;ma=K-65536|0;ub=c[L>>2]|0;tb=c[M>>2]|0;H=fb-(tb<<16)|0;D=0;do{kb=c[q+(D*28|0)+8>>2]|0;if((kb|0)<0){$b=0}else{$b=(kb|0)>(J|0)?J:kb}c[l+(D<<2)>>2]=$b;kb=c[q+(D*28|0)>>2]|0;ib=m+(D<<2)|0;c[ib>>2]=kb;if((kb|0)==65536){if((H|0)!=($b|0)){y=283}}else{if((kb|0)<0){ac=0;y=284}else{y=283}}if((y|0)==283){y=0;hb=(fb+~$b|0)/(tb|0)|0;ac=(kb|0)>(hb|0)?hb:kb;y=284}if((y|0)==284){y=0;c[ib>>2]=ac}ib=c[q+(D*28|0)+20>>2]|0;if((ib|0)<0){bc=0}else{bc=(ib|0)>(ma|0)?ma:ib}c[n+(D<<2)>>2]=bc;ib=c[q+(D*28|0)+16>>2]|0;kb=(K-bc|0)/(ub|0)|0;if((ib|0)<0){cc=0}else{cc=(ib|0)>(kb|0)?kb:ib}c[o+(D<<2)>>2]=cc;D=D+1|0;}while((D|0)<=(la|0))}la=c[q+52>>2]|0;if((la|0)<0){dc=0}else{dc=(la|0)>65535?65535:la}la=p|0;D=g+15560|0;ub=k|0;K=k+4|0;ma=p+4|0;tb=g+15572|0;fb=k+8|0;H=k+12|0;J=g+15564|0;rb=g+15568|0;ib=65535-dc|0;kb=g+19524|0;hb=g+15556|0;lb=0;gb=c[L>>2]|0;eb=0;db=0;while(1){qb=(lb|0)!=0;$a=qb&1;cb=c[M>>2]>>$a;if((gb>>$a|0)>0){mb=t+7624+(lb<<2)|0;bb=t+7656+(lb<<2)|0;ab=t+952+(lb<<2)|0;pb=t+984+(lb<<2)|0;ua=0;Q=eb;ka=db;while(1){ja=c[I>>2]|0;ia=(c[ja+(lb<<2)>>2]|0)+(ca(c[ja+32+(lb<<2)>>2]|0,ua)|0)|0;ja=c[sb>>2]|0;do{if((ja|0)<0){if((Q|0)==0){ec=ka;y=319}else{fc=Q;gc=ka;y=317}}else{ha=0;da=ja;while(1){Xa=c[mb>>2]|0;_a=c[bb>>2]|0;Za=(ca(c[o+(ha<<2)>>2]|0,ua)|0)+(c[n+(ha<<2)>>2]|0)|0;Wa=Za>>16;Va=Za&65535;c[p+(ha<<2)>>2]=Va;if((ha|0)==0){hc=Xa;ic=_a}else{hc=c[ab>>2]|0;ic=c[pb>>2]|0}_a=Wa+1|0;Xa=(c[kb>>2]>>$a)-1|0;Za=ca((_a|0)>(Xa|0)?Xa:_a,ic)|0;Xa=c[l+(ha<<2)>>2]|0;do{if((Xa&65535|0)==0){if((c[m+(ha<<2)>>2]|0)!=65536){y=303;break}Ua=Xa>>16;c[k+(ha<<3)>>2]=hc+(Ua+(ca(ic,Wa)|0));if((Va|0)==0){jc=da;break}c[k+(ha<<3)+4>>2]=hc+(Za+Ua);jc=da}else{y=303}}while(0);if((y|0)==303){y=0;Ua=j+(ha<<3)|0;Ra=c[Ua>>2]|0;do{if((Ra|0)!=(Wa|0)){Ta=j+(ha<<3)+4|0;if((c[Ta>>2]|0)==(Wa|0)){Sa=t+19528+(ha<<3)+4|0;Qa=c[Sa>>2]|0;Pa=t+19528+(ha<<3)|0;c[Sa>>2]=c[Pa>>2];c[Pa>>2]=Qa;c[Ta>>2]=Ra;c[Ua>>2]=Wa;break}else{Ta=hc+(ca(ic,Wa)|0)|0;pe[c[hb>>2]&1023](c[t+19528+(ha<<3)>>2]|0,Ta,Xa,c[m+(ha<<2)>>2]|0,cb);c[Ua>>2]=Wa;break}}}while(0);do{if((Va|0)!=0){Wa=j+(ha<<3)+4|0;if((c[Wa>>2]|0)==(_a|0)){break}pe[c[hb>>2]&1023](c[t+19528+(ha<<3)+4>>2]|0,hc+Za|0,Xa,c[m+(ha<<2)>>2]|0,cb);c[Wa>>2]=_a}}while(0);c[k+(ha<<3)>>2]=c[t+19528+(ha<<3)>>2];c[k+(ha<<3)+4>>2]=c[t+19528+(ha<<3)+4>>2];jc=c[sb>>2]|0}_a=ha+1|0;if((_a|0)>(jc|0)){break}else{ha=_a;da=jc}}da=c[la>>2]|0;ha=(da|0)!=0;if((jc|0)!=0){if(ha){fc=da;gc=da;y=317;break}else{y=321;break}}if(ha){pe[c[D>>2]&1023](ia,c[ub>>2]|0,c[K>>2]|0,da,cb);kc=da;lc=da;break}else{nrc(ia|0,c[ub>>2]|0,cb)|0;kc=0;lc=0;break}}}while(0);do{if((y|0)==317){y=0;ja=c[ma>>2]|0;if((ja|0)==0){ec=gc;y=319;break}Te[c[tb>>2]&255](ia,c[ub>>2]|0,c[K>>2]|0,fc,c[fb>>2]|0,c[H>>2]|0,ja,dc,cb);kc=fc;lc=gc}}while(0);do{if((y|0)==319){y=0;if((ec|0)==0){y=321;break}Se[c[rb>>2]&1023](ia,c[ub>>2]|0,c[K>>2]|0,ec,c[fb>>2]|0,dc,cb);kc=ec;lc=ec}}while(0);do{if((y|0)==321){y=0;ja=c[ma>>2]|0;if((ja|0)==0){pe[c[J>>2]&1023](ia,c[ub>>2]|0,c[fb>>2]|0,dc,cb);kc=0;lc=0;break}else{Se[c[rb>>2]&1023](ia,c[fb>>2]|0,c[H>>2]|0,ja,c[ub>>2]|0,ib,cb);kc=0;lc=0;break}}}while(0);ia=ua+1|0;ja=c[L>>2]|0;if((ia|0)<(ja>>$a|0)){ua=ia;Q=kc;ka=lc}else{mc=ja;nc=kc;oc=lc;break}}}else{mc=gb;nc=eb;oc=db}do{if(!qb){ka=c[sb>>2]|0;if((ka|0)<0){break}else{pc=0}do{Q=l+(pc<<2)|0;c[Q>>2]=c[Q>>2]>>1;Q=n+(pc<<2)|0;c[Q>>2]=c[Q>>2]>>1;pc=pc+1|0;}while((pc|0)<=(ka|0))}}while(0);qb=lb+1|0;if((qb|0)<((c[w>>2]|0)>>>12&2^3|0)){lb=qb;gb=mc;eb=nc;db=oc}else{break}}if((YHb(v,c[I>>2]|0)|0)<0){Ba=vb;Ca=wb;Da=Ab;y=342;break f}c[f>>2]=1}}while(0);kJb(wb);if((vb|0)>0){db=0;do{kJb(c[Ab+(db*28|0)>>2]|0);db=db+1|0;}while((db|0)<(vb|0))}kJb(Ab);z=s;i=h;return z|0}}while(0);do{if((y|0)==342){kJb(Ca);if((Ba|0)>0){qc=0}else{ob=Da;break}while(1){kJb(c[Da+(qc*28|0)>>2]|0);s=qc+1|0;if((s|0)<(Ba|0)){qc=s}else{ob=Da;break}}}}while(0);kJb(ob);z=-1;i=h;return z|0}function b7a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a+60>>2]|0;a=b+7624|0;d=a;if((c[a>>2]|0)==0){return}a=b+60|0;e=b+19524|0;f=b+7656|0;b=0;g=c[e>>2]|0;while(1){h=(b|0)!=0;i=h&1;if((g>>i|0)>0){j=d+(b<<2)|0;k=f+(b<<2)|0;l=h?-128:0;h=0;while(1){m=c[k>>2]|0;mrc((c[j>>2]|0)+(ca(m,h)|0)|0,l|0,m|0)|0;m=h+1|0;n=c[e>>2]|0;if((m|0)<(n>>i|0)){h=m}else{o=n;break}}}else{o=g}h=b+1|0;if((h|0)<((c[a>>2]|0)>>>12&2^3|0)){b=h;g=o}else{break}}return}function c7a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b+12|0;c[e>>2]=0;f=b+4|0;c[f>>2]=0;g=a+8|0;h=c[g>>2]|0;i=a+16|0;j=c[i>>2]|0;k=c[a>>2]|0;a=k+(h>>>3)|0;l=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(h&7)>>>30;a=h+2|0;h=j>>>0>a>>>0?a:j;c[g>>2]=h;if((l|0)==0){c[b>>2]=65536;a=c[g>>2]|0;m=c[i>>2]|0;n=k+(a>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(a&7)>>>16;n=a+16|0;a=m>>>0>n>>>0?n:m;c[g>>2]=a;n=k+(a>>>3)|0;p=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(a&7)>>>18;n=a+14|0;c[g>>2]=m>>>0>n>>>0?n:m;c[b+8>>2]=((p|o<<14)<<1)-1073741824;c[b+16>>2]=65536}else if((l|0)==1){o=k+(h>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(h&7)>>>16;o=h+16|0;m=j>>>0>o>>>0?o:j;c[g>>2]=m;o=k+(m>>>3)|0;n=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(m&7)>>>18;o=m+14|0;c[g>>2]=j>>>0>o>>>0?o:j;o=((n|p<<14)<<1)-1073741824|0;c[b+16>>2]=o;c[b>>2]=o;o=c[g>>2]|0;p=c[i>>2]|0;n=k+(o>>>3)|0;m=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(o&7)>>>16;n=o+16|0;o=p>>>0>n>>>0?n:p;c[g>>2]=o;n=k+(o>>>3)|0;a=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(o&7)>>>18;n=o+14|0;c[g>>2]=p>>>0>n>>>0?n:p;c[b+8>>2]=((a|m<<14)<<1)-1073741824}else if((l|0)==2){m=k+(h>>>3)|0;a=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7)>>>16;m=h+16|0;p=j>>>0>m>>>0?m:j;c[g>>2]=p;m=k+(p>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>18;m=p+14|0;c[g>>2]=j>>>0>m>>>0?m:j;c[b>>2]=((n|a<<14)<<1)-1073741824;a=c[g>>2]|0;n=c[i>>2]|0;m=k+(a>>>3)|0;p=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(a&7)>>>16;m=a+16|0;a=n>>>0>m>>>0?m:n;c[g>>2]=a;m=k+(a>>>3)|0;o=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(a&7)>>>18;m=a+14|0;c[g>>2]=n>>>0>m>>>0?m:n;c[b+8>>2]=((o|p<<14)<<1)-1073741824;p=c[g>>2]|0;o=c[i>>2]|0;n=k+(p>>>3)|0;m=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(p&7)>>>16;n=p+16|0;p=o>>>0>n>>>0?n:o;c[g>>2]=p;n=k+(p>>>3)|0;a=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(p&7)>>>18;n=p+14|0;c[g>>2]=o>>>0>n>>>0?n:o;c[b+16>>2]=((a|m<<14)<<1)-1073741824}else if((l|0)==3){l=k+(h>>>3)|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>16;l=h+16|0;h=j>>>0>l>>>0?l:j;c[g>>2]=h;l=k+(h>>>3)|0;a=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)>>>18;l=h+14|0;c[g>>2]=j>>>0>l>>>0?l:j;c[b>>2]=((a|m<<14)<<1)-1073741824;m=c[g>>2]|0;a=c[i>>2]|0;j=k+(m>>>3)|0;l=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(m&7)>>>16;j=m+16|0;m=a>>>0>j>>>0?j:a;c[g>>2]=m;j=k+(m>>>3)|0;h=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(m&7)>>>18;j=m+14|0;c[g>>2]=a>>>0>j>>>0?j:a;c[f>>2]=((h|l<<14)<<1)-1073741824;l=c[g>>2]|0;h=c[i>>2]|0;f=k+(l>>>3)|0;a=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7)>>>16;f=l+16|0;l=h>>>0>f>>>0?f:h;c[g>>2]=l;f=k+(l>>>3)|0;j=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7)>>>18;f=l+14|0;c[g>>2]=h>>>0>f>>>0?f:h;c[b+8>>2]=((j|a<<14)<<1)-1073741824;a=c[g>>2]|0;j=c[i>>2]|0;h=k+(a>>>3)|0;f=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(a&7)>>>16;h=a+16|0;a=j>>>0>h>>>0?h:j;c[g>>2]=a;h=k+(a>>>3)|0;l=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(a&7)>>>18;h=a+14|0;c[g>>2]=j>>>0>h>>>0?h:j;c[e>>2]=((l|f<<14)<<1)-1073741824;f=c[g>>2]|0;l=c[i>>2]|0;e=k+(f>>>3)|0;j=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(f&7)>>>16;e=f+16|0;f=l>>>0>e>>>0?e:l;c[g>>2]=f;e=k+(f>>>3)|0;h=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(f&7)>>>18;e=f+14|0;c[g>>2]=l>>>0>e>>>0?e:l;c[b+16>>2]=((h|j<<14)<<1)-1073741824}j=c[g>>2]|0;h=c[i>>2]|0;l=k+(j>>>3)|0;e=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(j&7)>>>16;l=j+16|0;j=h>>>0>l>>>0?l:h;c[g>>2]=j;l=k+(j>>>3)|0;f=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(j&7)>>>18;l=j+14|0;c[g>>2]=h>>>0>l>>>0?l:h;c[b+20>>2]=((f|e<<14)<<1)-1073741824;e=c[g>>2]|0;f=d[k+(e>>>3)|0]|0;h=c[i>>2]|0;i=((e|0)<(h|0))+e|0;c[g>>2]=i;if((f&128>>>((e&7)>>>0)|0)==0){c[b+24>>2]=65536;return}else{e=k+(i>>>3)|0;f=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(i&7)>>>16;e=i+16|0;i=h>>>0>e>>>0?e:h;c[g>>2]=i;e=k+(i>>>3)|0;k=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(i&7)>>>18;e=i+14|0;c[g>>2]=h>>>0>e>>>0?e:h;c[b+24>>2]=((k|f<<14)<<1)-1073741824;return}}function d7a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0;f=i;i=i+8|0;g=f|0;h=e+14120|0;j=e+12476|0;k=e+12480|0;l=e+124|0;m=(ca(c[l>>2]|0,c[k>>2]|0)|0)+(c[j>>2]|0)|0;n=c[e+16016>>2]|0;c[g>>2]=0;o=e+15728|0;p=d[o]|0;q=e+12488|0;c[q>>2]=0;if((c[e+16116>>2]|0)==0){r=d[(c[e+9928>>2]|0)+m|0]|0}else{s=e+14128|0;t=c[s>>2]|0;u=d[(c[h>>2]|0)+(t>>>3)|0]<<(t&7)>>>7;c[s>>2]=((t|0)<(c[e+14136>>2]|0))+t;r=u&1}u=(r|0)!=0;do{if(u){v=0;w=0}else{r=c[(c[e+19304>>2]|0)+4>>2]|0;t=e+14128|0;s=c[t>>2]|0;x=c[e+14136>>2]|0;y=c[h>>2]|0;z=y+(s>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(s&7)>>>26;z=b[r+(A<<2)>>1]|0;B=b[r+(A<<2)+2>>1]|0;A=B<<16>>16;if(B<<16>>16<0){B=s+6|0;C=x>>>0>B>>>0?B:x;B=y+(C>>>3)|0;y=((je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>((A+32|0)>>>0))+z|0;D=b[r+(y<<2)+2>>1]|0;E=b[r+(y<<2)>>1]|0;F=C}else{D=A;E=z;F=s}s=D+F|0;c[t>>2]=x>>>0>s>>>0?s:x;x=e+19400|0;s=(c[x>>2]|0)+(c[e+12496>>2]|0)|0;if((a[1263920+(E<<2)|0]|0)==1){a[s]=1;a[(c[x>>2]|0)+(c[e+12500>>2]|0)|0]=1;a[(c[x>>2]|0)+(c[e+12504>>2]|0)|0]=1;a[(c[x>>2]|0)+(c[e+12508>>2]|0)|0]=1;v=E;w=1;break}else{a[s]=0;a[(c[x>>2]|0)+(c[e+12500>>2]|0)|0]=0;a[(c[x>>2]|0)+(c[e+12504>>2]|0)|0]=0;a[(c[x>>2]|0)+(c[e+12508>>2]|0)|0]=0;v=E;w=0;break}}}while(0);if((c[e+16108>>2]|0)==0){G=d[(c[e+16096>>2]|0)+m|0]|0}else{E=e+14128|0;F=c[E>>2]|0;D=d[(c[h>>2]|0)+(F>>>3)|0]<<(F&7)>>>7;c[E>>2]=((F|0)<(c[e+14136>>2]|0))+F;G=D&1}D=(G|0)!=0;do{if(D){if((c[(c[e+9852>>2]|0)+2164>>2]|0)!=0){KIb(c[e+4>>2]|0,24,2250600,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H}G=c[e+12496>>2]|0;F=c[e+4704>>2]|0;E=F+(G<<2)|0;x=e+16070|0;s=(c[e+13924>>2]|0)==0;t=ca(b[x>>1]|0,b[E>>1]|0)|0;if(s){I=t+255>>9<<1&65535}else{I=(t+128|0)>>>8&65535}t=c[e+9148>>2]|0;b[t+(G<<2)>>1]=I;c[e+11744>>2]=I<<16>>16;z=F+(G<<2)+2|0;A=ca(b[x>>1]|0,b[z>>1]|0)|0;if(s){J=A+255>>9<<1&65535}else{J=(A+128|0)>>>8&65535}b[t+(G<<2)+2>>1]=J;c[e+11748>>2]=J<<16>>16;A=ca((b[x>>1]|0)-256|0,b[E>>1]|0)|0;if(s){K=A+255>>9<<1&65535}else{K=(A+128|0)>>>8&65535}A=c[e+9152>>2]|0;b[A+(G<<2)>>1]=K;c[e+11776>>2]=K<<16>>16;E=ca((b[x>>1]|0)-256|0,b[z>>1]|0)|0;if(s){L=E+255>>9<<1&65535}else{L=(E+128|0)>>>8&65535}b[A+(G<<2)+2>>1]=L;c[e+11780>>2]=L<<16>>16;if((w|0)==0){G=c[e+12500>>2]|0;b[t+(G<<2)>>1]=I;E=I<<16>>16;c[e+11752>>2]=E;b[t+(G<<2)+2>>1]=J;z=J<<16>>16;c[e+11756>>2]=z;b[A+(G<<2)>>1]=K;C=K<<16>>16;c[e+11784>>2]=C;b[A+(G<<2)+2>>1]=L;G=L<<16>>16;c[e+11788>>2]=G;y=c[e+12504>>2]|0;b[t+(y<<2)>>1]=I;c[e+11760>>2]=E;b[t+(y<<2)+2>>1]=J;c[e+11764>>2]=z;b[A+(y<<2)>>1]=K;c[e+11792>>2]=C;b[A+(y<<2)+2>>1]=L;c[e+11796>>2]=G;y=c[e+12508>>2]|0;b[t+(y<<2)>>1]=I;c[e+11768>>2]=E;b[t+(y<<2)+2>>1]=J;c[e+11772>>2]=z;b[A+(y<<2)>>1]=K;c[e+11800>>2]=C;b[A+(y<<2)+2>>1]=L;c[e+11804>>2]=G;break}G=c[e+12504>>2]|0;y=F+(G<<2)|0;C=ca(b[x>>1]|0,b[y>>1]|0)|0;if(s){M=C+255>>9<<1&65535}else{M=(C+128|0)>>>8&65535}b[t+(G<<2)>>1]=M;c[e+11760>>2]=M<<16>>16;C=F+(G<<2)+2|0;F=ca(b[x>>1]|0,b[C>>1]|0)|0;if(s){N=F+255>>9<<1&65535}else{N=(F+128|0)>>>8&65535}b[t+(G<<2)+2>>1]=N;c[e+11764>>2]=N<<16>>16;F=ca((b[x>>1]|0)-256|0,b[y>>1]|0)|0;if(s){O=F+255>>9<<1&65535}else{O=(F+128|0)>>>8&65535}b[A+(G<<2)>>1]=O;c[e+11792>>2]=O<<16>>16;F=ca((b[x>>1]|0)-256|0,b[C>>1]|0)|0;if(s){P=F+255>>9<<1&65535}else{P=(F+128|0)>>>8&65535}b[A+(G<<2)+2>>1]=P;c[e+11796>>2]=P<<16>>16;G=c[e+12500>>2]|0;b[t+(G<<2)>>1]=I;c[e+11752>>2]=I<<16>>16;b[t+(G<<2)+2>>1]=J;c[e+11756>>2]=J<<16>>16;b[A+(G<<2)>>1]=K;c[e+11784>>2]=K<<16>>16;b[A+(G<<2)+2>>1]=L;c[e+11788>>2]=L<<16>>16;G=c[e+12508>>2]|0;b[t+(G<<2)>>1]=M;c[e+11768>>2]=M<<16>>16;b[t+(G<<2)+2>>1]=N;c[e+11772>>2]=N<<16>>16;b[A+(G<<2)>>1]=O;c[e+11800>>2]=O<<16>>16;b[A+(G<<2)+2>>1]=P;c[e+11804>>2]=P<<16>>16}}while(0);a:do{if((a[1263920+(v<<2)|0]|0)==5){P=e+12496|0;O=c[P>>2]|0;N=c[e+9148>>2]|0;b[N+(O<<2)>>1]=0;c[e+11744>>2]=0;b[N+(O<<2)+2>>1]=0;c[e+11748>>2]=0;M=c[e+9152>>2]|0;b[M+(O<<2)>>1]=0;c[e+11776>>2]=0;b[M+(O<<2)+2>>1]=0;c[e+11780>>2]=0;O=e+12500|0;L=c[O>>2]|0;b[N+(L<<2)>>1]=0;c[e+11752>>2]=0;b[N+(L<<2)+2>>1]=0;c[e+11756>>2]=0;b[M+(L<<2)>>1]=0;c[e+11784>>2]=0;b[M+(L<<2)+2>>1]=0;c[e+11788>>2]=0;L=e+12504|0;K=c[L>>2]|0;b[N+(K<<2)>>1]=0;c[e+11760>>2]=0;b[N+(K<<2)+2>>1]=0;c[e+11764>>2]=0;b[M+(K<<2)>>1]=0;c[e+11792>>2]=0;b[M+(K<<2)+2>>1]=0;c[e+11796>>2]=0;K=e+12508|0;J=c[K>>2]|0;b[N+(J<<2)>>1]=0;c[e+11768>>2]=0;b[N+(J<<2)+2>>1]=0;c[e+11772>>2]=0;b[M+(J<<2)>>1]=0;c[e+11800>>2]=0;b[M+(J<<2)+2>>1]=0;c[e+11804>>2]=0;c[(c[e+9160>>2]|0)+(m<<2)>>2]=1;a[(c[e+19592>>2]|0)+(c[j>>2]|0)|0]=1;c[q>>2]=1;J=e+16056|0;a[(c[J>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[O>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[L>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[K>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[e+12512>>2]|0)|0]=1;a[(c[J>>2]|0)+(c[e+12516>>2]|0)|0]=1;K=e+14128|0;L=c[K>>2]|0;O=h|0;P=d[(c[O>>2]|0)+(L>>>3)|0]<<(L&7)>>>7;M=e+14136|0;c[K>>2]=((L|0)<(c[M>>2]|0))+L;L=P&1;a[(c[e+19324>>2]|0)+m|0]=L;P=c[K>>2]|0;N=c[O>>2]|0;I=d[N+(P>>>3)|0]|0;G=c[M>>2]|0;A=((P|0)<(G|0))+P|0;c[K>>2]=A;if((I&128>>>((P&7)>>>0)|0)==0){Q=0;R=A}else{P=c[(c[e+16084>>2]|0)+4>>2]|0;I=N+(A>>>3)|0;t=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(A&7)>>>23;I=b[P+(t<<2)>>1]|0;F=b[P+(t<<2)+2>>1]|0;t=F<<16>>16;if(F<<16>>16<0){F=A+9|0;s=G>>>0>F>>>0?F:G;F=N+(s>>>3)|0;C=((je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(s&7)>>>((t+32|0)>>>0))+I|0;S=b[P+(C<<2)+2>>1]|0;T=b[P+(C<<2)>>1]|0;U=s}else{S=t;T=I;U=A}A=S+U|0;I=G>>>0>A>>>0?A:G;c[K>>2]=I;Q=T+1|0;R=I}I=d[N+(R>>>3)|0]<<(R&7)>>>7;c[K>>2]=((R|0)<(G|0))+R;G=I&1;a[(c[e+19252>>2]|0)+m|0]=G;c[e+176>>2]=G;do{if((a[e+16004|0]|0)==0){V=p}else{G=a[e+16005|0]|0;do{if(G<<24>>24==3){I=c[K>>2]|0;if((a[e+16007|0]|0)!=0){N=d[(c[O>>2]|0)+(I>>>3)|0]|0;c[K>>2]=((I|0)<(c[M>>2]|0))+I;W=d[(N&128>>>((I&7)>>>0)|0)==0?o:e+15729|0]|0;X=55;break}N=c[M>>2]|0;A=c[O>>2]|0;t=A+(I>>>3)|0;s=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(I&7)>>>29;t=I+3|0;I=N>>>0>t>>>0?t:N;c[K>>2]=I;if((s|0)==7){t=A+(I>>>3)|0;A=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(I&7)>>>27;t=I+5|0;c[K>>2]=N>>>0>t>>>0?t:N;W=A;X=55;break}else{Y=(d[o]|0)+s|0;break}}else{W=p;X=55}}while(0);do{if((X|0)==55){if((G<<24>>24|0)==2){Z=1<<d[e+16006|0];X=58}else if((G<<24>>24|0)==1){Z=(3<<d[e+16006|0]|0)%15|0;X=58}else if((G<<24>>24|0)==0){_=15;X=59}else{Y=W;break}if((X|0)==58){if((Z&1|0)==0){$=W;aa=Z}else{_=Z;X=59}}do{if((X|0)==59){if((c[j>>2]|0)!=0){$=W;aa=_;break}$=d[e+15729|0]|0;aa=_}}while(0);do{if((aa&2|0)==0){ba=$}else{if((c[e+14084>>2]|0)==0){ba=$;break}ba=d[e+15729|0]|0}}while(0);do{if((aa&4|0)==0){da=ba}else{if((c[j>>2]|0)!=((c[e+116>>2]|0)-1|0)){da=ba;break}da=d[e+15729|0]|0}}while(0);if((aa&8|0)==0){Y=da;break}if((c[k>>2]|0)!=((c[e+120>>2]|0)-1|0)){Y=da;break}Y=d[e+15729|0]|0}}while(0);if(!((Y|0)==0|(Y|0)>31)){V=Y;break}KIb(c[e+4>>2]|0,16,2267264,(H=i,i=i+8|0,c[H>>2]=Y,H)|0);i=H;V=1}}while(0);a[(c[e+9136>>2]|0)+m|0]=V;c[e+168>>2]=d[(c[e+9888>>2]|0)+V|0]|0;c[e+172>>2]=d[(c[e+9892>>2]|0)+V|0]|0;K=e+9876|0;O=e+16048|0;M=e+16044|0;G=e+14340|0;s=e+16036|0;A=e+16032|0;N=e+60|0;t=e+15332|0;I=e+148|0;C=(L|0)==0;P=e+10068|0;F=e+152|0;x=e+14084|0;y=0;z=0;while(1){E=e+12496+(z<<2)|0;r=c[E>>2]|0;b[(c[K>>2]|0)+(r<<1)>>1]=0;B=(z>>2)+y|0;ea=Q>>>((5-z|0)>>>0)&1;a[(c[J>>2]|0)+r|0]=c[q>>2];c[O>>2]=0;c[M>>2]=0;if((z-2|0)>>>0<2>>>0){X=75}else{if((c[x>>2]|0)==0){X=75}}if((X|0)==75){X=0;c[M>>2]=d[(c[J>>2]|0)+((c[E>>2]|0)-(c[e+12520+(z<<2)>>2]|0))|0]|0}if((z|0)==3|(z|0)==1){X=78}else{if((c[j>>2]|0)!=0){X=78}}if((X|0)==78){X=0;c[O>>2]=d[(c[J>>2]|0)+((c[E>>2]|0)-1)|0]|0}g7a(e,(c[G>>2]|0)+(z<<7)|0,z,ea,V,c[((z&4|0)==0?A:s)>>2]|0);if((z|0)>3){if((c[N>>2]&8192|0)==0){X=81}}else{X=81}if((X|0)==81){X=0;qe[c[t>>2]&1023]((c[G>>2]|0)+(z<<7)|0);if((z|0)<4){ea=c[I>>2]|0;E=z&2;fa=ea<<L;ga=(ca(ea,C?E<<2:E>>>1)|0)+(z<<3&8)|0}else{fa=c[F>>2]|0;ga=0}ef[c[P>>2]&4095]((c[G>>2]|0)+(z<<7)|0,(c[e+12544+(B<<2)>>2]|0)+ga|0,fa)}E=z+1|0;if((E|0)<6){y=B;z=E}else{ha=0;break}}}else{a[(c[e+19592>>2]|0)+(c[j>>2]|0)|0]=0;c[q>>2]=0;b:do{if(D){ia=0;ja=0}else{z=e+14128|0;y=c[z>>2]|0;G=c[h>>2]|0;P=d[G+(y>>>3)|0]|0;F=c[e+14136>>2]|0;C=((y|0)<(F|0))+y|0;c[z>>2]=C;do{if((P&128>>>((y&7)>>>0)|0)==0){ka=(b[e+16070>>1]|0)<128|0;la=C}else{L=d[G+(C>>>3)|0]<<(C&7)>>>7;I=((C|0)<(F|0))+C|0;c[z>>2]=I;t=L&1;L=t+1|0;if((t|0)==1){ia=2;ja=0;break b}else if((t|0)!=0){ka=L;la=I;break}ka=(b[e+16070>>1]|0)>127|0;la=I}}while(0);if((w|0)==0|(ka|0)==2){ia=ka;ja=0;break}C=d[G+(la>>>3)|0]<<(la&7)>>>7;c[z>>2]=((la|0)<(F|0))+la;ia=ka;ja=C&1}}while(0);if(u){C=e+16056|0;y=e+9876|0;P=e+12496|0;a[(c[C>>2]|0)+(c[P>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[P>>2]<<1)>>1]=0;I=e+12500|0;a[(c[C>>2]|0)+(c[I>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[I>>2]<<1)>>1]=0;L=e+12504|0;a[(c[C>>2]|0)+(c[L>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[L>>2]<<1)>>1]=0;t=e+12508|0;a[(c[C>>2]|0)+(c[t>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[t>>2]<<1)>>1]=0;N=e+12512|0;a[(c[C>>2]|0)+(c[N>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[N>>2]<<1)>>1]=0;N=e+12516|0;a[(c[C>>2]|0)+(c[N>>2]|0)|0]=0;b[(c[y>>2]|0)+(c[N>>2]<<1)>>1]=0;c[(c[e+9160>>2]|0)+(m<<2)>>2]=2048;a[(c[e+9136>>2]|0)+m|0]=0;N=e+19400|0;a[(c[N>>2]|0)+(c[P>>2]|0)|0]=0;a[(c[N>>2]|0)+(c[I>>2]|0)|0]=0;a[(c[N>>2]|0)+(c[L>>2]|0)|0]=0;a[(c[N>>2]|0)+(c[t>>2]|0)|0]=0;do{if(D){k7a(e,0)}else{if((ia|0)==2){y=e+15720|0;C=e+15724|0;o7a(e,0,0,0,1,c[y>>2]|0,c[C>>2]|0,0);o7a(e,0,0,0,1,c[y>>2]|0,c[C>>2]|0,1);k7a(e,0);break}C=(ia|0)==0|0;y=e+15720|0;s=e+15724|0;o7a(e,0,0,0,1,c[y>>2]|0,c[s>>2]|0,C);if((ja|0)==0){a[(c[N>>2]|0)+(c[P>>2]|0)|0]=1;a[(c[N>>2]|0)+(c[I>>2]|0)|0]=1;a[(c[N>>2]|0)+(c[L>>2]|0)|0]=1;a[(c[N>>2]|0)+(c[t>>2]|0)|0]=1;A=C^1;o7a(e,0,0,0,2,c[y>>2]|0,c[s>>2]|0,A);s=e+9148+(A<<2)|0;y=c[s>>2]|0;J=b[y+(c[P>>2]<<2)>>1]|0;O=c[L>>2]|0;b[y+(O<<2)>>1]=J;y=J<<16>>16;c[e+11744+(A<<5)>>2]=y;c[e+11744+(A<<5)+16>>2]=y;y=c[s>>2]|0;J=b[y+(c[P>>2]<<2)+2>>1]|0;b[y+(O<<2)+2>>1]=J;O=J<<16>>16;c[e+11744+(A<<5)+4>>2]=O;c[e+11744+(A<<5)+20>>2]=O;O=c[I>>2]|0;J=c[s>>2]|0;y=b[J+(O<<2)>>1]|0;M=c[t>>2]|0;b[J+(M<<2)>>1]=y;J=y<<16>>16;c[e+11744+(A<<5)+8>>2]=J;c[e+11744+(A<<5)+24>>2]=J;J=c[s>>2]|0;s=b[J+(O<<2)+2>>1]|0;b[J+(M<<2)+2>>1]=s;M=s<<16>>16;c[e+11744+(A<<5)+12>>2]=M;c[e+11744+(A<<5)+28>>2]=M}else{M=C^1;A=e+9148+(C<<2)|0;s=e+9148+(M<<2)|0;J=c[A>>2]|0;O=b[J+(c[P>>2]<<2)>>1]|0;y=c[L>>2]|0;b[J+(y<<2)>>1]=O;J=O<<16>>16;c[e+11744+(C<<5)>>2]=J;c[e+11744+(C<<5)+16>>2]=J;J=c[P>>2]|0;O=c[A>>2]|0;x=b[O+(J<<2)+2>>1]|0;b[O+(y<<2)+2>>1]=x;O=x<<16>>16;c[e+11744+(C<<5)+4>>2]=O;c[e+11744+(C<<5)+20>>2]=O;O=c[s>>2]|0;x=b[O+(y<<2)>>1]|0;b[O+(J<<2)>>1]=x;J=x<<16>>16;c[e+11744+(M<<5)>>2]=J;c[e+11744+(M<<5)+16>>2]=J;J=c[s>>2]|0;x=b[J+(y<<2)+2>>1]|0;b[J+(c[P>>2]<<2)+2>>1]=x;J=x<<16>>16;c[e+11744+(M<<5)+4>>2]=J;c[e+11744+(M<<5)+20>>2]=J;J=c[I>>2]|0;x=c[A>>2]|0;y=b[x+(J<<2)>>1]|0;O=c[t>>2]|0;b[x+(O<<2)>>1]=y;x=y<<16>>16;c[e+11744+(C<<5)+8>>2]=x;c[e+11744+(C<<5)+24>>2]=x;x=c[A>>2]|0;A=b[x+(J<<2)+2>>1]|0;b[x+(O<<2)+2>>1]=A;O=A<<16>>16;c[e+11744+(C<<5)+12>>2]=O;c[e+11744+(C<<5)+28>>2]=O;O=c[t>>2]|0;A=c[s>>2]|0;x=b[A+(O<<2)>>1]|0;b[A+(J<<2)>>1]=x;A=x<<16>>16;c[e+11744+(M<<5)+8>>2]=A;c[e+11744+(M<<5)+24>>2]=A;A=c[s>>2]|0;s=b[A+(O<<2)+2>>1]|0;b[A+(J<<2)+2>>1]=s;J=s<<16>>16;c[e+11744+(M<<5)+12>>2]=J;c[e+11744+(M<<5)+28>>2]=J}k7a(e,C);ha=0;break a}}while(0);l7a(e);ha=0;break}if((a[1263923+(v<<2)|0]|0)==0){ma=0}else{t=c[(c[e+16084>>2]|0)+4>>2]|0;I=e+14128|0;P=c[I>>2]|0;L=c[e+14136>>2]|0;N=c[h>>2]|0;C=N+(P>>>3)|0;J=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(P&7)>>>23;C=b[t+(J<<2)>>1]|0;M=b[t+(J<<2)+2>>1]|0;J=M<<16>>16;if(M<<16>>16<0){M=P+9|0;s=L>>>0>M>>>0?M:L;M=N+(s>>>3)|0;N=((je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(s&7)>>>((J+32|0)>>>0))+C|0;na=b[t+(N<<2)+2>>1]|0;oa=b[t+(N<<2)>>1]|0;pa=s}else{na=J;oa=C;pa=P}P=na+pa|0;c[I>>2]=L>>>0>P>>>0?P:L;ma=oa+1|0}do{if(!D){L=(ia|0)!=2;P=(w|0)==0;if(!(L|P)){I=c[(c[e+19316>>2]|0)+4>>2]|0;C=e+14128|0;J=c[C>>2]|0;s=c[e+14136>>2]|0;N=(c[h>>2]|0)+(J>>>3)|0;t=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(J&7)>>>26;N=b[I+(t<<2)>>1]|0;M=(b[I+(t<<2)+2>>1]|0)+J|0;c[C>>2]=s>>>0>M>>>0?M:s;a[e+19321|0]=N;break}if(L&P){break}P=c[(c[e+19312>>2]|0)+4>>2]|0;L=e+14128|0;N=c[L>>2]|0;s=c[e+14136>>2]|0;M=(c[h>>2]|0)+(N>>>3)|0;C=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(N&7)>>>29;M=b[P+(C<<2)>>1]|0;J=(b[P+(C<<2)+2>>1]|0)+N|0;c[L>>2]=s>>>0>J>>>0?J:s;a[e+19320|0]=M}}while(0);M=e+16056|0;s=e+12496|0;a[(c[M>>2]|0)+(c[s>>2]|0)|0]=0;J=e+12500|0;a[(c[M>>2]|0)+(c[J>>2]|0)|0]=0;L=e+12504|0;a[(c[M>>2]|0)+(c[L>>2]|0)|0]=0;N=e+12508|0;a[(c[M>>2]|0)+(c[N>>2]|0)|0]=0;a[(c[M>>2]|0)+(c[e+12512>>2]|0)|0]=0;a[(c[M>>2]|0)+(c[e+12516>>2]|0)|0]=0;M=a[1263921+(v<<2)|0]|0;a[(c[e+19324>>2]|0)+m|0]=M;C=M&255;P=(w|0)!=0;do{if(D){if(P){m7a(e,0,0,0);m7a(e,0,1,1);m7a(e,1,0,0);m7a(e,1,1,1);m7a(e,2,0,0);m7a(e,2,1,1);m7a(e,3,0,0);m7a(e,3,1,1);n7a(e,0,0,0);n7a(e,1,1,1);break}else{k7a(e,0);l7a(e);break}}else{t=(ia|0)==2;if(P&t){I=d[e+19321|0]|0;A=e+15720|0;O=e+15724|0;x=e+19444|0;y=e+19288|0;K=e+19308|0;E=e+14128|0;B=e+14136|0;ea=e+14120|0;r=e+15712|0;qa=e+15716|0;ra=0;c:while(1){if((ra|0)==1){sa=1}else{sa=(ra|0)==3|0}do{if((1<<3-ra&I|0)==0){ta=0;ua=0}else{va=c[x>>2]|0;wa=(va|0)==0;xa=wa?71:125;ya=d[y]|0;if((ya|0)==1){za=1;Aa=0}else if((ya|0)==2){za=0;Aa=1}else if((ya|0)==3){za=1;Aa=1}else{za=0;Aa=0}ya=c[(c[K>>2]|0)+4>>2]|0;Ba=c[E>>2]|0;Ca=c[B>>2]|0;Da=c[ea>>2]|0;Ea=Da+(Ba>>>3)|0;Fa=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ba&7)>>>23;Ea=b[ya+(Fa<<2)>>1]|0;Ga=b[ya+(Fa<<2)+2>>1]|0;Fa=Ga<<16>>16;do{if(Ga<<16>>16<0){Ha=Ba+9|0;Ia=Ca>>>0>Ha>>>0?Ha:Ca;Ha=Da+(Ia>>>3)|0;Ja=((je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ia&7)>>>((Fa+32|0)>>>0))+Ea|0;Ha=b[ya+(Ja<<2)>>1]|0;Ka=b[ya+(Ja<<2)+2>>1]|0;Ja=Ka<<16>>16;if(!(Ka<<16>>16<0)){La=Ja;Ma=Ha;Na=Ia;break}Ka=Ia-Fa|0;Ia=Ca>>>0>Ka>>>0?Ka:Ca;Ka=Da+(Ia>>>3)|0;Oa=((je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ia&7)>>>((Ja+32|0)>>>0))+Ha|0;La=b[ya+(Oa<<2)+2>>1]|0;Ma=b[ya+(Oa<<2)>>1]|0;Na=Ia}else{La=Fa;Ma=Ea;Na=Ba}}while(0);Ba=La+Na|0;Ea=Ca>>>0>Ba>>>0?Ba:Ca;c[E>>2]=Ea;if((Ma|0)==(xa|0)){Ba=c[r>>2]|0;Fa=Da+(Ea>>>3)|0;ya=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ea&7)>>>((32-Ba|0)>>>0);Fa=Ba+Ea|0;Ba=Ca>>>0>Fa>>>0?Fa:Ca;c[E>>2]=Ba;Fa=c[qa>>2]|0;Ga=Da+(Ba>>>3)|0;Ia=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ba&7)>>>((32-Fa|0)>>>0);Ga=Ba+Fa|0;c[E>>2]=Ca>>>0>Ga>>>0?Ga:Ca;if(wa){ta=Ia;ua=ya;break}ta=(Ia&1)+Ia>>1;ua=ya;break}if((Ma|0)>=(xa|0)){X=124;break c}ya=Ma+1|0;Ia=(ya|0)%9|0;if((Ia|0)==0){Pa=0;Qa=Ea}else{Ga=Ia+za|0;Fa=Da+(Ea>>>3)|0;Ba=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ea&7)>>>((32-Ga|0)>>>0);Fa=Ga+Ea|0;Ea=Ca>>>0>Fa>>>0?Fa:Ca;c[E>>2]=Ea;Fa=Ba&1;Pa=((Ba>>1)+(c[((za|0)==0?774784:774744)+(Ia<<2)>>2]|0)^-Fa)+Fa|0;Qa=Ea}Ea=(ya|0)/9|0;if((Ea|0)<=(va|0)){ta=0;ua=Pa;break}ya=(Aa<<va)+Ea>>va;Fa=Da+(Qa>>>3)|0;Ia=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Qa&7)>>>((32-ya|0)>>>0);Fa=Qa+ya|0;c[E>>2]=Ca>>>0>Fa>>>0?Fa:Ca;Fa=Ia&1;ta=((Ia>>1)+(c[((Aa|0)==0?774784:774744)+(Ea>>va<<2)>>2]|0)^-Fa)+Fa|0;ua=Pa}}while(0);Fa=(ra|0)>1?2:0;o7a(e,Fa,ua,ta,2,c[A>>2]|0,c[O>>2]|0,sa);m7a(e,Fa,sa,sa);m7a(e,Fa|1,sa,sa);Fa=ra+1|0;if((Fa|0)<4){ra=Fa}else{X=130;break}}if((X|0)==124){KIb(0,0,2565376,(H=i,i=i+24|0,c[H>>2]=2240232,c[H+8>>2]=2529528,c[H+16>>2]=1214,H)|0);i=H;Hd()}else if((X|0)==130){n7a(e,0,0,0);n7a(e,1,1,1);break}}if(t){ra=d[e+19320|0]|0;do{if((ra&2|0)==0){Ra=0;Sa=0}else{O=c[e+19444>>2]|0;A=(O|0)==0;E=A?71:125;qa=d[e+19288|0]|0;if((qa|0)==1){Ta=1;Ua=0}else if((qa|0)==2){Ta=0;Ua=1}else if((qa|0)==3){Ta=1;Ua=1}else{Ta=0;Ua=0}qa=c[(c[e+19308>>2]|0)+4>>2]|0;r=e+14128|0;ea=c[r>>2]|0;B=c[e+14136>>2]|0;K=c[e+14120>>2]|0;y=K+(ea>>>3)|0;x=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(ea&7)>>>23;y=b[qa+(x<<2)>>1]|0;I=b[qa+(x<<2)+2>>1]|0;x=I<<16>>16;do{if(I<<16>>16<0){F=ea+9|0;z=B>>>0>F>>>0?F:B;F=K+(z>>>3)|0;G=((je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(z&7)>>>((x+32|0)>>>0))+y|0;F=b[qa+(G<<2)>>1]|0;Fa=b[qa+(G<<2)+2>>1]|0;G=Fa<<16>>16;if(!(Fa<<16>>16<0)){Va=G;Wa=F;Xa=z;break}Fa=z-x|0;z=B>>>0>Fa>>>0?Fa:B;Fa=K+(z>>>3)|0;Ea=((je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(z&7)>>>((G+32|0)>>>0))+F|0;Va=b[qa+(Ea<<2)+2>>1]|0;Wa=b[qa+(Ea<<2)>>1]|0;Xa=z}else{Va=x;Wa=y;Xa=ea}}while(0);ea=Va+Xa|0;y=B>>>0>ea>>>0?ea:B;c[r>>2]=y;if((Wa|0)==(E|0)){ea=c[e+15712>>2]|0;x=K+(y>>>3)|0;qa=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7)>>>((32-ea|0)>>>0);x=ea+y|0;ea=B>>>0>x>>>0?x:B;c[r>>2]=ea;x=c[e+15716>>2]|0;I=K+(ea>>>3)|0;z=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(ea&7)>>>((32-x|0)>>>0);I=ea+x|0;c[r>>2]=B>>>0>I>>>0?I:B;if(A){Ra=z;Sa=qa;break}Ra=(z&1)+z>>1;Sa=qa;break}if((Wa|0)>=(E|0)){KIb(0,0,2565376,(H=i,i=i+24|0,c[H>>2]=2240232,c[H+8>>2]=2529528,c[H+16>>2]=1214,H)|0);i=H;Hd()}qa=Wa+1|0;z=(qa|0)%9|0;if((z|0)==0){Ya=0;Za=y}else{I=z+Ta|0;x=K+(y>>>3)|0;ea=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(y&7)>>>((32-I|0)>>>0);x=I+y|0;y=B>>>0>x>>>0?x:B;c[r>>2]=y;x=ea&1;Ya=((ea>>1)+(c[((Ta|0)==0?774784:774744)+(z<<2)>>2]|0)^-x)+x|0;Za=y}y=(qa|0)/9|0;if((y|0)<=(O|0)){Ra=0;Sa=Ya;break}qa=(Ua<<O)+y>>O;x=K+(Za>>>3)|0;z=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(Za&7)>>>((32-qa|0)>>>0);x=Za+qa|0;c[r>>2]=B>>>0>x>>>0?x:B;x=z&1;Ra=((z>>1)+(c[((Ua|0)==0?774784:774744)+(y>>O<<2)>>2]|0)^-x)+x|0;Sa=Ya}}while(0);t=e+15720|0;x=e+15724|0;o7a(e,0,Sa,Ra,1,c[t>>2]|0,c[x>>2]|0,0);k7a(e,0);do{if((ra&1|0)==0){_a=0;$a=0}else{y=c[e+19444>>2]|0;z=(y|0)==0;qa=z?71:125;ea=d[e+19288|0]|0;if((ea|0)==1){ab=1;bb=0}else if((ea|0)==2){ab=0;bb=1}else if((ea|0)==3){ab=1;bb=1}else{ab=0;bb=0}ea=c[(c[e+19308>>2]|0)+4>>2]|0;I=e+14128|0;Ea=c[I>>2]|0;F=c[e+14136>>2]|0;G=c[e+14120>>2]|0;Fa=G+(Ea>>>3)|0;Ia=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ea&7)>>>23;Fa=b[ea+(Ia<<2)>>1]|0;ya=b[ea+(Ia<<2)+2>>1]|0;Ia=ya<<16>>16;do{if(ya<<16>>16<0){Ba=Ea+9|0;Ga=F>>>0>Ba>>>0?Ba:F;Ba=G+(Ga>>>3)|0;Oa=((je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ga&7)>>>((Ia+32|0)>>>0))+Fa|0;Ba=b[ea+(Oa<<2)>>1]|0;Ha=b[ea+(Oa<<2)+2>>1]|0;Oa=Ha<<16>>16;if(!(Ha<<16>>16<0)){cb=Oa;db=Ba;eb=Ga;break}Ha=Ga-Ia|0;Ga=F>>>0>Ha>>>0?Ha:F;Ha=G+(Ga>>>3)|0;Ja=((je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ga&7)>>>((Oa+32|0)>>>0))+Ba|0;cb=b[ea+(Ja<<2)+2>>1]|0;db=b[ea+(Ja<<2)>>1]|0;eb=Ga}else{cb=Ia;db=Fa;eb=Ea}}while(0);Ea=cb+eb|0;Fa=F>>>0>Ea>>>0?Ea:F;c[I>>2]=Fa;if((db|0)==(qa|0)){Ea=c[e+15712>>2]|0;Ia=G+(Fa>>>3)|0;ea=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Fa&7)>>>((32-Ea|0)>>>0);Ia=Ea+Fa|0;Ea=F>>>0>Ia>>>0?Ia:F;c[I>>2]=Ea;Ia=c[e+15716>>2]|0;ya=G+(Ea>>>3)|0;O=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(Ea&7)>>>((32-Ia|0)>>>0);ya=Ea+Ia|0;c[I>>2]=F>>>0>ya>>>0?ya:F;if(z){_a=O;$a=ea;break}_a=(O&1)+O>>1;$a=ea;break}if((db|0)>=(qa|0)){KIb(0,0,2565376,(H=i,i=i+24|0,c[H>>2]=2240232,c[H+8>>2]=2529528,c[H+16>>2]=1214,H)|0);i=H;Hd()}ea=db+1|0;O=(ea|0)%9|0;if((O|0)==0){fb=0;gb=Fa}else{ya=O+ab|0;Ia=G+(Fa>>>3)|0;Ea=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Fa&7)>>>((32-ya|0)>>>0);Ia=ya+Fa|0;Fa=F>>>0>Ia>>>0?Ia:F;c[I>>2]=Fa;Ia=Ea&1;fb=((Ea>>1)+(c[((ab|0)==0?774784:774744)+(O<<2)>>2]|0)^-Ia)+Ia|0;gb=Fa}Fa=(ea|0)/9|0;if((Fa|0)<=(y|0)){_a=0;$a=fb;break}ea=(bb<<y)+Fa>>y;Ia=G+(gb>>>3)|0;O=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(gb&7)>>>((32-ea|0)>>>0);Ia=gb+ea|0;c[I>>2]=F>>>0>Ia>>>0?Ia:F;Ia=O&1;_a=((O>>1)+(c[((bb|0)==0?774784:774744)+(Fa>>y<<2)>>2]|0)^-Ia)+Ia|0;$a=fb}}while(0);o7a(e,0,$a,_a,1,c[t>>2]|0,c[x>>2]|0,1);l7a(e);break}ra=(ia|0)==0;Ia=ra&1;if(!P){do{if((a[1263922+(v<<2)|0]|0)==0){hb=0;ib=0}else{Fa=c[e+19444>>2]|0;O=(Fa|0)==0;ea=O?71:125;Ea=d[e+19288|0]|0;if((Ea|0)==1){jb=1;kb=0}else if((Ea|0)==2){jb=0;kb=1}else if((Ea|0)==3){jb=1;kb=1}else{jb=0;kb=0}Ea=c[(c[e+19308>>2]|0)+4>>2]|0;ya=e+14128|0;B=c[ya>>2]|0;r=c[e+14136>>2]|0;K=c[e+14120>>2]|0;E=K+(B>>>3)|0;A=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(B&7)>>>23;E=b[Ea+(A<<2)>>1]|0;Ga=b[Ea+(A<<2)+2>>1]|0;A=Ga<<16>>16;do{if(Ga<<16>>16<0){Ja=B+9|0;Ba=r>>>0>Ja>>>0?Ja:r;Ja=K+(Ba>>>3)|0;Oa=((je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(Ba&7)>>>((A+32|0)>>>0))+E|0;Ja=b[Ea+(Oa<<2)>>1]|0;Ha=b[Ea+(Oa<<2)+2>>1]|0;Oa=Ha<<16>>16;if(!(Ha<<16>>16<0)){lb=Oa;mb=Ja;nb=Ba;break}Ha=Ba-A|0;Ba=r>>>0>Ha>>>0?Ha:r;Ha=K+(Ba>>>3)|0;Ka=((je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ba&7)>>>((Oa+32|0)>>>0))+Ja|0;lb=b[Ea+(Ka<<2)+2>>1]|0;mb=b[Ea+(Ka<<2)>>1]|0;nb=Ba}else{lb=A;mb=E;nb=B}}while(0);B=lb+nb|0;E=r>>>0>B>>>0?B:r;c[ya>>2]=E;if((mb|0)==(ea|0)){B=c[e+15712>>2]|0;A=K+(E>>>3)|0;Ea=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(E&7)>>>((32-B|0)>>>0);A=B+E|0;B=r>>>0>A>>>0?A:r;c[ya>>2]=B;A=c[e+15716>>2]|0;Ga=K+(B>>>3)|0;y=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(B&7)>>>((32-A|0)>>>0);Ga=B+A|0;c[ya>>2]=r>>>0>Ga>>>0?Ga:r;if(O){hb=y;ib=Ea;break}hb=(y&1)+y>>1;ib=Ea;break}if((mb|0)>=(ea|0)){KIb(0,0,2565376,(H=i,i=i+24|0,c[H>>2]=2240232,c[H+8>>2]=2529528,c[H+16>>2]=1214,H)|0);i=H;Hd()}Ea=mb+1|0;y=(Ea|0)%9|0;if((y|0)==0){ob=0;pb=E}else{Ga=y+jb|0;A=K+(E>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(E&7)>>>((32-Ga|0)>>>0);A=Ga+E|0;E=r>>>0>A>>>0?A:r;c[ya>>2]=E;A=B&1;ob=((B>>1)+(c[((jb|0)==0?774784:774744)+(y<<2)>>2]|0)^-A)+A|0;pb=E}E=(Ea|0)/9|0;if((E|0)<=(Fa|0)){hb=0;ib=ob;break}Ea=(kb<<Fa)+E>>Fa;A=K+(pb>>>3)|0;y=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(pb&7)>>>((32-Ea|0)>>>0);A=pb+Ea|0;c[ya>>2]=r>>>0>A>>>0?A:r;A=y&1;hb=((y>>1)+(c[((kb|0)==0?774784:774744)+(E>>Fa<<2)>>2]|0)^-A)+A|0;ib=ob}}while(0);x=e+15720|0;t=e+15724|0;o7a(e,0,ib,hb,1,c[x>>2]|0,c[t>>2]|0,Ia);A=e+19400|0;a[(c[A>>2]|0)+(c[s>>2]|0)|0]=1;a[(c[A>>2]|0)+(c[J>>2]|0)|0]=1;a[(c[A>>2]|0)+(c[L>>2]|0)|0]=1;a[(c[A>>2]|0)+(c[N>>2]|0)|0]=1;A=Ia^1;o7a(e,0,0,0,2,c[x>>2]|0,c[t>>2]|0,A);t=e+9148+(A<<2)|0;x=c[t>>2]|0;E=b[x+(c[s>>2]<<2)>>1]|0;y=c[L>>2]|0;b[x+(y<<2)>>1]=E;x=E<<16>>16;c[e+11744+(A<<5)>>2]=x;c[e+11744+(A<<5)+16>>2]=x;x=c[t>>2]|0;E=b[x+(c[s>>2]<<2)+2>>1]|0;b[x+(y<<2)+2>>1]=E;y=E<<16>>16;c[e+11744+(A<<5)+4>>2]=y;c[e+11744+(A<<5)+20>>2]=y;y=c[J>>2]|0;E=c[t>>2]|0;x=b[E+(y<<2)>>1]|0;Ea=c[N>>2]|0;b[E+(Ea<<2)>>1]=x;E=x<<16>>16;c[e+11744+(A<<5)+8>>2]=E;c[e+11744+(A<<5)+24>>2]=E;E=c[t>>2]|0;t=b[E+(y<<2)+2>>1]|0;b[E+(Ea<<2)+2>>1]=t;Ea=t<<16>>16;c[e+11744+(A<<5)+12>>2]=Ea;c[e+11744+(A<<5)+28>>2]=Ea;k7a(e,Ia);break}Ea=(ja|0)!=0;A=(ra^Ea)&1;t=d[e+19320|0]|0;do{if((t&2|0)==0){qb=0;rb=0}else{E=c[e+19444>>2]|0;y=(E|0)==0;x=y?71:125;B=d[e+19288|0]|0;if((B|0)==1){sb=1;tb=0}else if((B|0)==2){sb=0;tb=1}else if((B|0)==3){sb=1;tb=1}else{sb=0;tb=0}B=c[(c[e+19308>>2]|0)+4>>2]|0;Ga=e+14128|0;F=c[Ga>>2]|0;I=c[e+14136>>2]|0;G=c[e+14120>>2]|0;qa=G+(F>>>3)|0;z=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(F&7)>>>23;qa=b[B+(z<<2)>>1]|0;Ba=b[B+(z<<2)+2>>1]|0;z=Ba<<16>>16;do{if(Ba<<16>>16<0){Ka=F+9|0;Ja=I>>>0>Ka>>>0?Ka:I;Ka=G+(Ja>>>3)|0;Oa=((je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(Ja&7)>>>((z+32|0)>>>0))+qa|0;Ka=b[B+(Oa<<2)>>1]|0;Ha=b[B+(Oa<<2)+2>>1]|0;Oa=Ha<<16>>16;if(!(Ha<<16>>16<0)){ub=Oa;vb=Ka;wb=Ja;break}Ha=Ja-z|0;Ja=I>>>0>Ha>>>0?Ha:I;Ha=G+(Ja>>>3)|0;xb=((je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ja&7)>>>((Oa+32|0)>>>0))+Ka|0;ub=b[B+(xb<<2)+2>>1]|0;vb=b[B+(xb<<2)>>1]|0;wb=Ja}else{ub=z;vb=qa;wb=F}}while(0);F=ub+wb|0;qa=I>>>0>F>>>0?F:I;c[Ga>>2]=qa;if((vb|0)==(x|0)){F=c[e+15712>>2]|0;z=G+(qa>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(qa&7)>>>((32-F|0)>>>0);z=F+qa|0;F=I>>>0>z>>>0?z:I;c[Ga>>2]=F;z=c[e+15716>>2]|0;Ba=G+(F>>>3)|0;Fa=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(F&7)>>>((32-z|0)>>>0);Ba=F+z|0;c[Ga>>2]=I>>>0>Ba>>>0?Ba:I;if(y){qb=Fa;rb=B;break}qb=(Fa&1)+Fa>>1;rb=B;break}if((vb|0)>=(x|0)){KIb(0,0,2565376,(H=i,i=i+24|0,c[H>>2]=2240232,c[H+8>>2]=2529528,c[H+16>>2]=1214,H)|0);i=H;Hd()}B=vb+1|0;Fa=(B|0)%9|0;if((Fa|0)==0){yb=0;zb=qa}else{Ba=Fa+sb|0;z=G+(qa>>>3)|0;F=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(qa&7)>>>((32-Ba|0)>>>0);z=Ba+qa|0;qa=I>>>0>z>>>0?z:I;c[Ga>>2]=qa;z=F&1;yb=((F>>1)+(c[((sb|0)==0?774784:774744)+(Fa<<2)>>2]|0)^-z)+z|0;zb=qa}qa=(B|0)/9|0;if((qa|0)<=(E|0)){qb=0;rb=yb;break}B=(tb<<E)+qa>>E;z=G+(zb>>>3)|0;Fa=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(zb&7)>>>((32-B|0)>>>0);z=zb+B|0;c[Ga>>2]=I>>>0>z>>>0?z:I;z=Fa&1;qb=((Fa>>1)+(c[((tb|0)==0?774784:774744)+(qa>>E<<2)>>2]|0)^-z)+z|0;rb=yb}}while(0);ra=e+15720|0;z=e+15724|0;o7a(e,0,rb,qb,2,c[ra>>2]|0,c[z>>2]|0,Ia);do{if((t&1|0)==0){Ab=0;Bb=0}else{qa=c[e+19444>>2]|0;Fa=(qa|0)==0;B=Fa?71:125;F=d[e+19288|0]|0;if((F|0)==1){Cb=1;Db=0}else if((F|0)==2){Cb=0;Db=1}else if((F|0)==3){Cb=1;Db=1}else{Cb=0;Db=0}F=c[(c[e+19308>>2]|0)+4>>2]|0;Ba=e+14128|0;r=c[Ba>>2]|0;ya=c[e+14136>>2]|0;K=c[e+14120>>2]|0;ea=K+(r>>>3)|0;O=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(r&7)>>>23;ea=b[F+(O<<2)>>1]|0;Ja=b[F+(O<<2)+2>>1]|0;O=Ja<<16>>16;do{if(Ja<<16>>16<0){xb=r+9|0;Ka=ya>>>0>xb>>>0?xb:ya;xb=K+(Ka>>>3)|0;Oa=((je(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(Ka&7)>>>((O+32|0)>>>0))+ea|0;xb=b[F+(Oa<<2)>>1]|0;Ha=b[F+(Oa<<2)+2>>1]|0;Oa=Ha<<16>>16;if(!(Ha<<16>>16<0)){Eb=Oa;Fb=xb;Gb=Ka;break}Ha=Ka-O|0;Ka=ya>>>0>Ha>>>0?Ha:ya;Ha=K+(Ka>>>3)|0;Hb=((je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(Ka&7)>>>((Oa+32|0)>>>0))+xb|0;Eb=b[F+(Hb<<2)+2>>1]|0;Fb=b[F+(Hb<<2)>>1]|0;Gb=Ka}else{Eb=O;Fb=ea;Gb=r}}while(0);r=Eb+Gb|0;ea=ya>>>0>r>>>0?r:ya;c[Ba>>2]=ea;if((Fb|0)==(B|0)){r=c[e+15712>>2]|0;O=K+(ea>>>3)|0;F=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(ea&7)>>>((32-r|0)>>>0);O=r+ea|0;r=ya>>>0>O>>>0?O:ya;c[Ba>>2]=r;O=c[e+15716>>2]|0;Ja=K+(r>>>3)|0;E=(je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0)<<(r&7)>>>((32-O|0)>>>0);Ja=r+O|0;c[Ba>>2]=ya>>>0>Ja>>>0?Ja:ya;if(Fa){Ab=E;Bb=F;break}Ab=(E&1)+E>>1;Bb=F;break}if((Fb|0)>=(B|0)){KIb(0,0,2565376,(H=i,i=i+24|0,c[H>>2]=2240232,c[H+8>>2]=2529528,c[H+16>>2]=1214,H)|0);i=H;Hd()}F=Fb+1|0;E=(F|0)%9|0;if((E|0)==0){Ib=0;Jb=ea}else{Ja=E+Cb|0;O=K+(ea>>>3)|0;r=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(ea&7)>>>((32-Ja|0)>>>0);O=Ja+ea|0;ea=ya>>>0>O>>>0?O:ya;c[Ba>>2]=ea;O=r&1;Ib=((r>>1)+(c[((Cb|0)==0?774784:774744)+(E<<2)>>2]|0)^-O)+O|0;Jb=ea}ea=(F|0)/9|0;if((ea|0)<=(qa|0)){Ab=0;Bb=Ib;break}F=(Db<<qa)+ea>>qa;O=K+(Jb>>>3)|0;E=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(Jb&7)>>>((32-F|0)>>>0);O=Jb+F|0;c[Ba>>2]=ya>>>0>O>>>0?O:ya;O=E&1;Ab=((E>>1)+(c[((Db|0)==0?774784:774744)+(ea>>qa<<2)>>2]|0)^-O)+O|0;Bb=Ib}}while(0);o7a(e,2,Bb,Ab,2,c[ra>>2]|0,c[z>>2]|0,A);if(Ea){t=e+9148+(Ia<<2)|0;O=e+9148+(A<<2)|0;ea=c[t>>2]|0;E=b[ea+(c[s>>2]<<2)>>1]|0;F=c[L>>2]|0;b[ea+(F<<2)>>1]=E;ea=E<<16>>16;c[e+11744+(Ia<<5)>>2]=ea;c[e+11744+(Ia<<5)+16>>2]=ea;ea=c[s>>2]|0;E=c[t>>2]|0;r=b[E+(ea<<2)+2>>1]|0;b[E+(F<<2)+2>>1]=r;E=r<<16>>16;c[e+11744+(Ia<<5)+4>>2]=E;c[e+11744+(Ia<<5)+20>>2]=E;E=c[O>>2]|0;r=b[E+(F<<2)>>1]|0;b[E+(ea<<2)>>1]=r;ea=r<<16>>16;c[e+11744+(A<<5)>>2]=ea;c[e+11744+(A<<5)+16>>2]=ea;ea=c[O>>2]|0;r=b[ea+(F<<2)+2>>1]|0;b[ea+(c[s>>2]<<2)+2>>1]=r;ea=r<<16>>16;c[e+11744+(A<<5)+4>>2]=ea;c[e+11744+(A<<5)+20>>2]=ea;ea=c[J>>2]|0;r=c[t>>2]|0;F=b[r+(ea<<2)>>1]|0;E=c[N>>2]|0;b[r+(E<<2)>>1]=F;r=F<<16>>16;c[e+11744+(Ia<<5)+8>>2]=r;c[e+11744+(Ia<<5)+24>>2]=r;r=c[t>>2]|0;t=b[r+(ea<<2)+2>>1]|0;b[r+(E<<2)+2>>1]=t;E=t<<16>>16;c[e+11744+(Ia<<5)+12>>2]=E;c[e+11744+(Ia<<5)+28>>2]=E;E=c[N>>2]|0;t=c[O>>2]|0;r=b[t+(E<<2)>>1]|0;b[t+(ea<<2)>>1]=r;t=r<<16>>16;c[e+11744+(A<<5)+8>>2]=t;c[e+11744+(A<<5)+24>>2]=t;t=c[O>>2]|0;O=b[t+(E<<2)+2>>1]|0;b[t+(ea<<2)+2>>1]=O;ea=O<<16>>16;c[e+11744+(A<<5)+12>>2]=ea;c[e+11744+(A<<5)+28>>2]=ea}else{ea=Ia^1;o7a(e,0,0,0,2,c[ra>>2]|0,c[z>>2]|0,ea);o7a(e,2,0,0,2,c[ra>>2]|0,c[z>>2]|0,ea)}m7a(e,0,Ia,0);m7a(e,1,Ia,0);m7a(e,2,A,0);m7a(e,3,A,0);n7a(e,Ia,A,0)}}while(0);N=(ma|0)!=0;do{if(N){if((a[e+16004|0]|0)==0){Kb=p;break}J=a[e+16005|0]|0;do{if(J<<24>>24==3){s=e+14128|0;L=c[s>>2]|0;if((a[e+16007|0]|0)!=0){P=d[(c[h>>2]|0)+(L>>>3)|0]|0;c[s>>2]=((L|0)<(c[e+14136>>2]|0))+L;Lb=d[(P&128>>>((L&7)>>>0)|0)==0?o:e+15729|0]|0;X=232;break}P=c[e+14136>>2]|0;ea=c[h>>2]|0;O=ea+(L>>>3)|0;t=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>29;O=L+3|0;L=P>>>0>O>>>0?O:P;c[s>>2]=L;if((t|0)==7){O=ea+(L>>>3)|0;ea=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>27;O=L+5|0;c[s>>2]=P>>>0>O>>>0?O:P;Lb=ea;X=232;break}else{Mb=(d[o]|0)+t|0;break}}else{Lb=p;X=232}}while(0);do{if((X|0)==232){if((J<<24>>24|0)==2){Nb=1<<d[e+16006|0];X=235}else if((J<<24>>24|0)==1){Nb=(3<<d[e+16006|0]|0)%15|0;X=235}else if((J<<24>>24|0)==0){Ob=15;X=236}else{Mb=Lb;break}if((X|0)==235){if((Nb&1|0)==0){Pb=Lb;Qb=Nb}else{Ob=Nb;X=236}}do{if((X|0)==236){if((c[j>>2]|0)!=0){Pb=Lb;Qb=Ob;break}Pb=d[e+15729|0]|0;Qb=Ob}}while(0);do{if((Qb&2|0)==0){Rb=Pb}else{if((c[e+14084>>2]|0)==0){Rb=Pb;break}Rb=d[e+15729|0]|0}}while(0);do{if((Qb&4|0)==0){Sb=Rb}else{if((c[j>>2]|0)!=((c[e+116>>2]|0)-1|0)){Sb=Rb;break}Sb=d[e+15729|0]|0}}while(0);if((Qb&8|0)==0){Mb=Sb;break}if((c[k>>2]|0)!=((c[e+120>>2]|0)-1|0)){Mb=Sb;break}Mb=d[e+15729|0]|0}}while(0);if(!((Mb|0)==0|(Mb|0)>31)){Kb=Mb;break}KIb(c[e+4>>2]|0,16,2267264,(H=i,i=i+8|0,c[H>>2]=Mb,H)|0);i=H;Kb=1}else{Kb=p}}while(0);a[(c[e+9136>>2]|0)+m|0]=Kb;J=e+16020|0;if((a[J]|0)!=0|N^1){Tb=n}else{qa=c[6074788+((c[e+16088>>2]|0)*20|0)>>2]|0;ya=e+14128|0;Ba=c[ya>>2]|0;K=c[e+14136>>2]|0;B=c[h>>2]|0;Fa=B+(Ba>>>3)|0;A=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ba&7)>>>23;Fa=b[qa+(A<<2)>>1]|0;Ia=b[qa+(A<<2)+2>>1]|0;A=Ia<<16>>16;if(Ia<<16>>16<0){Ia=Ba+9|0;z=K>>>0>Ia>>>0?Ia:K;Ia=B+(z>>>3)|0;B=((je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(z&7)>>>((A+32|0)>>>0))+Fa|0;Ub=b[qa+(B<<2)+2>>1]|0;Vb=b[qa+(B<<2)>>1]|0;Wb=z}else{Ub=A;Vb=Fa;Wb=Ba}Ba=Ub+Wb|0;c[ya>>2]=K>>>0>Ba>>>0?Ba:K;Tb=Vb}K=e+9876|0;Ba=M<<24>>24==0;ya=e+148|0;Fa=e+14340|0;A=e+152|0;z=e+60|0;B=Tb;qa=1;Ia=0;ra=0;Ea=0;while(1){b[(c[K>>2]|0)+(c[e+12496+(Ea<<2)>>2]<<1)>>1]=0;t=(Ea>>2)+Ia|0;ea=5-Ea|0;P=(Ea&4|0)!=0;do{if(Ba){if(P){Xb=0;break}Xb=(ca(c[ya>>2]|0,Ea<<2&8)|0)+(Ea<<3&8)|0}else{if(P){Xb=0;break}Xb=(c[ya>>2]&-((Ea|0)>1|0))+(Ea<<3&8)|0}}while(0);if((1<<ea&ma|0)==0){Yb=ra;Zb=qa;_b=B}else{if(P){$b=(c[z>>2]|0)>>>13&1;ac=c[A>>2]|0}else{$b=0;ac=c[ya>>2]<<C}O=(h7a(e,(c[Fa>>2]|0)+(Ea<<7)|0,Ea,Kb,B,qa,(c[e+12544+(t<<2)>>2]|0)+Xb|0,ac,$b,g)|0)<<(Ea<<2)|ra;Yb=O;Zb=0;_b=(a[J]|0)==0&(B|0)<8?-1:B}O=Ea+1|0;if((O|0)<6){B=_b;qa=Zb;Ia=t;ra=Yb;Ea=O}else{ha=Yb;break}}}}while(0);Yb=c[j>>2]|0;if((Yb|0)!=((c[e+116>>2]|0)-1|0)){bc=Yb;cc=e+19584|0;dc=c[cc>>2]|0;ec=dc+(bc<<2)|0;c[ec>>2]=ha;fc=c[g>>2]|0;gc=c[j>>2]|0;hc=e+16028|0;ic=c[hc>>2]|0;jc=ic+(gc<<2)|0;c[jc>>2]=fc;i=f;return}orc(c[e+19588>>2]|0,c[e+19592>>2]|0,c[l>>2]|0)|0;bc=c[j>>2]|0;cc=e+19584|0;dc=c[cc>>2]|0;ec=dc+(bc<<2)|0;c[ec>>2]=ha;fc=c[g>>2]|0;gc=c[j>>2]|0;hc=e+16028|0;ic=c[hc>>2]|0;jc=ic+(gc<<2)|0;c[jc>>2]=fc;i=f;return}function e7a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a+15396|0;do{if((c[a+14084>>2]|0)==0){e=a+12544|0;f=a+148|0;ef[c[d>>2]&4095](c[e>>2]|0,c[f>>2]|0,b);g=a+12476|0;h=a+15400|0;if((c[g>>2]|0)!=0){i=c[f>>2]|0;ef[c[h>>2]&4095]((c[e>>2]|0)+(-(i<<4)|0)|0,i,b)}i=c[f>>2]|0;ef[c[h>>2]&4095]((c[e>>2]|0)+(-(i<<4)|8)|0,i,b);i=a+15388|0;h=a+152|0;j=a+15392|0;k=a+12548|0;ef[c[i>>2]&4095](c[k>>2]|0,c[h>>2]|0,b);if((c[g>>2]|0)!=0){l=c[h>>2]|0;ef[c[j>>2]&4095]((c[k>>2]|0)+(-(l<<3)|0)|0,l,b)}l=a+12552|0;ef[c[i>>2]&4095](c[l>>2]|0,c[h>>2]|0,b);if((c[g>>2]|0)==0){m=e;n=f;break}g=c[h>>2]|0;ef[c[j>>2]&4095]((c[l>>2]|0)+(-(g<<3)|0)|0,g,b);m=e;n=f}else{m=a+12544|0;n=a+148|0}}while(0);f=c[n>>2]|0;ef[c[d>>2]&4095]((c[m>>2]|0)+(f<<3)|0,f,b);if((c[a+12480>>2]|0)!=((c[a+812>>2]|0)-1|0)){return}f=a+15400|0;if((c[a+12476>>2]|0)!=0){ef[c[f>>2]&4095](c[m>>2]|0,c[n>>2]|0,b);d=a+15392|0;e=a+152|0;ef[c[d>>2]&4095](c[a+12548>>2]|0,c[e>>2]|0,b);ef[c[d>>2]&4095](c[a+12552>>2]|0,c[e>>2]|0,b)}ef[c[f>>2]&4095]((c[m>>2]|0)+8|0,c[n>>2]|0,b);return}function f7a(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;h=i;if((c[a+19428>>2]|0)!=0){KIb(0,0,2565376,(j=i,i=i+24|0,c[j>>2]=2255472,c[j+8>>2]=2529528,c[j+16>>2]=2116,j)|0);i=j;Hd()}k=c[a+15720>>2]|0;l=c[a+15724>>2]|0;m=a+13924|0;c[d>>2]=c[d>>2]<<1-(c[m>>2]|0);c[e>>2]=c[e>>2]<<1-(c[m>>2]|0);n=d+4|0;c[n>>2]=c[n>>2]<<1-(c[m>>2]|0);o=e+4|0;c[o>>2]=c[o>>2]<<1-(c[m>>2]|0);p=c[a+128>>2]|0;q=c[a+12496>>2]|0;if((c[a+12488>>2]|0)!=0){r=c[a+9152>>2]|0;b[r+(q<<2)+2>>1]=0;b[r+(q<<2)>>1]=0;r=c[a+9148>>2]|0;b[r+(q<<2)+2>>1]=0;b[r+(q<<2)>>1]=0;i=h;return}r=(f|0)!=0;do{if(r){if((c[(c[a+9852>>2]|0)+2164>>2]|0)==0){break}KIb(c[a+4>>2]|0,24,2250600,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}}while(0);j=c[a+4704>>2]|0;f=b[j+(q<<2)>>1]|0;s=b[a+16070>>1]|0;t=ca(s,f)|0;if((c[m>>2]|0)==0){m=t+255>>9<<1;u=a+11744|0;c[u>>2]=m;v=b[j+(q<<2)+2>>1]|0;w=(ca(s,v)|0)+255>>9<<1;x=a+11748|0;c[x>>2]=w;y=s-256|0;z=(ca(y,f)|0)+255>>9<<1;A=a+11776|0;c[A>>2]=z;B=(ca(y,v)|0)+255>>9<<1;C=x;D=w;E=m;F=u;G=z;H=A}else{A=t+128>>8;t=a+11744|0;c[t>>2]=A;z=b[j+(q<<2)+2>>1]|0;j=(ca(s,z)|0)+128>>8;u=a+11748|0;c[u>>2]=j;m=s-256|0;s=(ca(m,f)|0)+128>>8;f=a+11776|0;c[f>>2]=s;B=(ca(m,z)|0)+128>>8;C=u;D=j;E=A;F=t;G=s;H=f}f=a+11780|0;c[f>>2]=B;s=c[a+12476>>2]|0;t=s<<6;A=-60-t|0;j=c[a+116>>2]|0;u=j<<6;z=-4-t+u|0;if((E|0)<(A|0)){I=A}else{I=(E|0)>(z|0)?z:E}c[F>>2]=I;E=c[a+12480>>2]|0;t=E<<6;m=-60-t|0;w=c[a+120>>2]|0;x=w<<6;v=-4-t+x|0;if((D|0)<(m|0)){J=m}else{J=(D|0)>(v|0)?v:D}c[C>>2]=J;if((G|0)<(A|0)){K=A}else{K=(G|0)>(z|0)?z:G}c[H>>2]=K;if((B|0)<(m|0)){L=m}else{L=(B|0)>(v|0)?v:B}c[f>>2]=L;if(r){r=c[a+9148>>2]|0;b[r+(q<<2)>>1]=I;b[r+(q<<2)+2>>1]=J;r=c[a+9152>>2]|0;b[r+(q<<2)>>1]=K;b[r+(q<<2)+2>>1]=L;i=h;return}r=J&65535;J=I&65535;if((g-1|0)>>>0<2>>>0){I=q-2|0;B=c[a+9148>>2]|0;v=B+(I<<2)|0;G=q-(p<<1)|0;z=((s|0)==(j-1|0)?-2:2)+G|0;A=B+(z<<2)|0;D=(s|0)==0;if(D){b[B+(I<<2)+2>>1]=0;b[v>>1]=0}do{if((c[a+14084>>2]|0)==0){y=b[B+(G<<2)>>1]|0;M=y<<16>>16;if((j|0)==1){N=b[B+(G<<2)+2>>1]|0;O=M;P=s;break}Q=b[A>>1]|0;R=Q<<16>>16;S=b[v>>1]|0;T=S<<16>>16;do{if(y<<16>>16>Q<<16>>16){if(!(S<<16>>16>Q<<16>>16)){U=R;break}U=(T|0)>(M|0)?M:T}else{if(!(Q<<16>>16>S<<16>>16)){U=R;break}U=(T|0)>(M|0)?T:M}}while(0);M=b[B+(G<<2)+2>>1]|0;T=M<<16>>16;R=b[B+(z<<2)+2>>1]|0;S=R<<16>>16;Q=b[B+(I<<2)+2>>1]|0;y=Q<<16>>16;if(M<<16>>16>R<<16>>16){if(!(Q<<16>>16>R<<16>>16)){N=S;O=U;P=s;break}N=(y|0)>(T|0)?T:y;O=U;P=s;break}else{if(!(R<<16>>16>Q<<16>>16)){N=S;O=U;P=s;break}N=(y|0)>(T|0)?y:T;O=U;P=s;break}}else{if(D){N=0;O=0;P=0;break}N=b[B+(I<<2)+2>>1]|0;O=b[v>>1]|0;P=s}}while(0);if((c[a+15660>>2]|0)<3){v=P<<5;I=E<<5;B=(j<<5)-4|0;D=(w<<5)-4|0;U=(v+O|0)<-28?-28-v|0:O;z=(I+N|0)<-28?-28-I|0:N;V=(z+I|0)>(D|0)?D-I|0:z;W=(U+v|0)>(B|0)?B-v|0:U}else{U=P<<6;P=u-4|0;v=x-4|0;B=(U+O|0)<-60?-60-U|0:O;O=(t+N|0)<-60?m:N;V=(O+t|0)>(v|0)?v-t|0:O;W=(B+U|0)>(P|0)?P-U|0:B}B=(W+k+(c[d>>2]|0)&(k<<1)-1)-k|0;c[F>>2]=B;F=(V+l+(c[e>>2]|0)&(l<<1)-1)-l|0;c[C>>2]=F;X=B&65535;Y=F&65535}else{X=J;Y=r}if((g|0)==2|(g|0)==0){g=q-2|0;r=c[a+9152>>2]|0;J=r+(g<<2)|0;F=q-(p<<1)|0;p=((s|0)==(j-1|0)?-2:2)+F|0;B=r+(p<<2)|0;C=(s|0)==0;if(C){b[r+(g<<2)+2>>1]=0;b[J>>1]=0}do{if((c[a+14084>>2]|0)==0){e=b[r+(F<<2)>>1]|0;V=e<<16>>16;if((j|0)==1){Z=b[r+(F<<2)+2>>1]|0;_=V;$=s;break}d=b[B>>1]|0;W=d<<16>>16;U=b[J>>1]|0;P=U<<16>>16;do{if(e<<16>>16>d<<16>>16){if(!(U<<16>>16>d<<16>>16)){aa=W;break}aa=(P|0)>(V|0)?V:P}else{if(!(d<<16>>16>U<<16>>16)){aa=W;break}aa=(P|0)>(V|0)?P:V}}while(0);V=b[r+(F<<2)+2>>1]|0;P=V<<16>>16;W=b[r+(p<<2)+2>>1]|0;U=W<<16>>16;d=b[r+(g<<2)+2>>1]|0;e=d<<16>>16;if(V<<16>>16>W<<16>>16){if(!(d<<16>>16>W<<16>>16)){Z=U;_=aa;$=s;break}Z=(e|0)>(P|0)?P:e;_=aa;$=s;break}else{if(!(W<<16>>16>d<<16>>16)){Z=U;_=aa;$=s;break}Z=(e|0)>(P|0)?e:P;_=aa;$=s;break}}else{if(C){Z=0;_=0;$=0;break}Z=b[r+(g<<2)+2>>1]|0;_=b[J>>1]|0;$=s}}while(0);if((c[a+15660>>2]|0)<3){s=$<<5;J=E<<5;E=(j<<5)-4|0;j=(w<<5)-4|0;w=(s+_|0)<-28?-28-s|0:_;g=(J+Z|0)<-28?-28-J|0:Z;ba=(g+J|0)>(j|0)?j-J|0:g;da=(w+s|0)>(E|0)?E-s|0:w}else{w=$<<6;$=u-4|0;u=x-4|0;x=(w+_|0)<-60?-60-w|0:_;_=(t+Z|0)<-60?m:Z;ba=(_+t|0)>(u|0)?u-t|0:_;da=(x+w|0)>($|0)?$-w|0:x}x=(da+k+(c[n>>2]|0)&(k<<1)-1)-k|0;c[H>>2]=x;H=(ba+l+(c[o>>2]|0)&(l<<1)-1)-l|0;c[f>>2]=H;ea=r;fa=x&65535;ga=H&65535}else{ea=c[a+9152>>2]|0;fa=K&65535;ga=L&65535}L=c[a+9148>>2]|0;b[L+(q<<2)>>1]=X;b[L+(q<<2)+2>>1]=Y;b[ea+(q<<2)>>1]=fa;b[ea+(q<<2)+2>>1]=ga;i=h;return}function g7a(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;m=i;i=i+40|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;r=m+32|0;s=f|0;t=f+14120|0;c[n>>2]=0;c[o>>2]=0;u=f+124|0;v=(ca(c[u>>2]|0,c[f+12480>>2]|0)|0)+(c[f+12476>>2]|0)|0;w=c[f+16044>>2]|0;x=c[f+16048>>2]|0;y=c[f+176>>2]|0;qe[c[f+10092>>2]&1023](g);if((k|0)<1){z=0}else{z=(k|0)>31?31:k}k=f+168|0;c[k>>2]=d[(c[f+9888>>2]|0)+z|0]|0;A=f+172|0;c[A>>2]=d[(c[f+9892>>2]|0)+z|0]|0;B=(h|0)<4;C=c[f+14072>>2]|0;if(B){D=c[7302796+(C*20|0)>>2]|0;E=f+14128|0;F=c[E>>2]|0;G=c[f+14136>>2]|0;H=c[t>>2]|0;I=H+(F>>>3)|0;J=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(F&7)>>>23;I=b[D+(J<<2)>>1]|0;K=b[D+(J<<2)+2>>1]|0;J=K<<16>>16;do{if(K<<16>>16<0){L=F+9|0;M=G>>>0>L>>>0?L:G;L=H+(M>>>3)|0;N=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>((J+32|0)>>>0))+I|0;L=b[D+(N<<2)>>1]|0;O=b[D+(N<<2)+2>>1]|0;N=O<<16>>16;if(!(O<<16>>16<0)){P=N;Q=L;R=M;break}O=M-J|0;M=G>>>0>O>>>0?O:G;O=H+(M>>>3)|0;S=((je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(M&7)>>>((N+32|0)>>>0))+L|0;P=b[D+(S<<2)+2>>1]|0;Q=b[D+(S<<2)>>1]|0;R=M}else{P=J;Q=I;R=F}}while(0);F=P+R|0;R=G>>>0>F>>>0?F:G;c[E>>2]=R;T=Q;U=R;V=G;W=H}else{H=c[7302836+(C*20|0)>>2]|0;C=f+14128|0;G=c[C>>2]|0;R=c[f+14136>>2]|0;Q=c[t>>2]|0;t=Q+(G>>>3)|0;E=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(G&7)>>>23;t=b[H+(E<<2)>>1]|0;F=b[H+(E<<2)+2>>1]|0;E=F<<16>>16;do{if(F<<16>>16<0){P=G+9|0;I=R>>>0>P>>>0?P:R;P=Q+(I>>>3)|0;J=((je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(I&7)>>>((E+32|0)>>>0))+t|0;P=b[H+(J<<2)>>1]|0;D=b[H+(J<<2)+2>>1]|0;J=D<<16>>16;if(!(D<<16>>16<0)){X=J;Y=P;Z=I;break}D=I-E|0;I=R>>>0>D>>>0?D:R;D=Q+(I>>>3)|0;K=((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(I&7)>>>((J+32|0)>>>0))+P|0;X=b[H+(K<<2)+2>>1]|0;Y=b[H+(K<<2)>>1]|0;Z=I}else{X=E;Y=t;Z=G}}while(0);G=X+Z|0;Z=R>>>0>G>>>0?G:R;c[C>>2]=Z;T=Y;U=Z;V=R;W=Q}if((T|0)<0){KIb(c[f+4>>2]|0,16,2263752,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;i=m;return}do{if((T|0)==0){_=0}else{Q=(z|0)==1;do{if((T|0)==119){if(Q){R=f+14128|0;Z=W+(U>>>3)|0;Y=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(U&7)>>>22;Z=U+10|0;C=V>>>0>Z>>>0?Z:V;c[R>>2]=C;$=Y;aa=C;ba=R;break}R=f+14128|0;C=W+(U>>>3)|0;Y=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(U&7);if((z|0)==2){C=U+9|0;Z=V>>>0>C>>>0?C:V;c[R>>2]=Z;$=Y>>>23;aa=Z;ba=R;break}else{Z=U+8|0;C=V>>>0>Z>>>0?Z:V;c[R>>2]=C;$=Y>>>24;aa=C;ba=R;break}}else{if(Q){R=f+14128|0;C=W+(U>>>3)|0;Y=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(U&7)>>>30;C=U+2|0;Z=V>>>0>C>>>0?C:V;c[R>>2]=Z;$=(Y|T<<2)-3|0;aa=Z;ba=R;break}if((z|0)==2){R=f+14128|0;Z=d[W+(U>>>3)|0]<<(U&7)>>>7;Y=((U|0)<(V|0))+U|0;c[R>>2]=Y;$=(Z&1|T<<1)-1|0;aa=Y;ba=R;break}else{$=T;aa=U;ba=f+14128|0;break}}}while(0);Q=d[W+(aa>>>3)|0]|0;c[ba>>2]=((aa|0)<(V|0))+aa;if((Q&128>>>((aa&7)>>>0)|0)==0){_=$;break}_=-$|0}}while(0);$=(j7a(s,h,w,x,o,n)|0)+_|0;b[c[o>>2]>>1]=$;b[g>>1]=ca(c[(B?k:A)>>2]|0,$)|0;$=(w|0)!=0;if(!$){c[n>>2]=1}w=(x|0)!=0;if(!w){c[n>>2]=0}if($){da=y}else{da=w?y:0}y=c[f+9912>>2]|0;x=c[f+12496+(h<<2)>>2]<<4;A=y+(x<<1)|0;k=f+16072|0;B=(d[k]|0)+(z<<1)|0;o=c[n>>2]|0;n=(o|0)==0;if(n){ea=x-(c[f+12520+(h<<2)>>2]<<4)|0}else{ea=x-16|0}_=y+(ea<<1)|0;s=c[f+9136>>2]|0;aa=a[s+v|0]|0;if(n|w^1|(v|0)==0){fa=0}else{fa=a[s+(v-1)|0]|0}w=(o|0)!=0;do{if(w|$^1){ga=fa}else{o=c[u>>2]|0;if((v|0)<(o|0)){ga=fa;break}ga=a[s+(v-o)|0]|0}}while(0);v=(h|0)==3?aa:n&(h|0)==2?aa:w&(h|0)==1?aa:ga;a:do{if((j|0)==0){ga=A;mrc(ga|0,0,32)|0;w=(da|0)!=0;do{if(n){if(!w){ha=1;break a}nrc(y+((x|8)<<1)|0,y+(ea+8<<1)|0,16)|0;if((v|0)==0|(aa|0)==(v|0)){break}s=d[f+15728|0]|0;if((aa|0)==(s|0)){ia=d[k]|0}else{ia=0}fa=ia+(aa<<1)|0;if((v|0)==(s|0)){ja=d[k]|0}else{ja=0}s=(v<<1)-1+ja|0;if((fa-1|0)<1){i=m;return}else{u=c[1266216+(fa-2<<2)>>2]|0;fa=y+((x|9)<<1)|0;b[fa>>1]=(ca(ca(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|10)<<1)|0;b[fa>>1]=(ca(ca(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|11)<<1)|0;b[fa>>1]=(ca(ca(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|12)<<1)|0;b[fa>>1]=(ca(ca(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|13)<<1)|0;b[fa>>1]=(ca(ca(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|14)<<1)|0;b[fa>>1]=(ca(ca(b[fa>>1]|0,s)|0,u)|0)+131072>>18;fa=y+((x|15)<<1)|0;b[fa>>1]=(ca(ca(b[fa>>1]|0,s)|0,u)|0)+131072>>18;ka=99;break}}else{if(!w){ha=1;break a}nrc(ga|0,_|0,16)|0;if((v|0)==0|(aa|0)==(v|0)){break}u=d[f+15728|0]|0;if((aa|0)==(u|0)){la=d[k]|0}else{la=0}s=la+(aa<<1)|0;if((v|0)==(u|0)){ma=d[k]|0}else{ma=0}u=(v<<1)-1+ma|0;if((s-1|0)<1){i=m;return}else{fa=c[1266216+(s-2<<2)>>2]|0;s=y+((x|1)<<1)|0;b[s>>1]=(ca(ca(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|2)<<1)|0;b[s>>1]=(ca(ca(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|3)<<1)|0;b[s>>1]=(ca(ca(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|4)<<1)|0;b[s>>1]=(ca(ca(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|5)<<1)|0;b[s>>1]=(ca(ca(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|6)<<1)|0;b[s>>1]=(ca(ca(b[s>>1]|0,u)|0,fa)|0)+131072>>18;s=y+((x|7)<<1)|0;b[s>>1]=(ca(ca(b[s>>1]|0,u)|0,fa)|0)+131072>>18;ka=99;break}}}while(0);if((ka|0)==99){if(!w){ha=1;break}}if(n){ga=x|8;fa=c[f+15992>>2]|0;u=f+16081|0;s=-z|0;$=1;while(1){o=ca(b[y+(ga+$<<1)>>1]|0,B)|0;V=o&65535;ba=g+($<<fa<<1)|0;b[ba>>1]=V;if(!((a[u]|0)!=0|V<<16>>16==0)){b[ba>>1]=(V<<16>>16<0?s:z)+o}o=$+1|0;if((o|0)<8){$=o}else{ha=63;break}}}else{$=c[f+15988>>2]|0;s=f+16081|0;u=-z|0;fa=1;while(1){ga=ca(b[y+(fa+x<<1)>>1]|0,B)|0;w=ga&65535;o=g+(fa<<$<<1)|0;b[o>>1]=w;if(!((a[s]|0)!=0|w<<16>>16==0)){b[o>>1]=(w<<16>>16<0?u:z)+ga}ga=fa+1|0;if((ga|0)<8){fa=ga}else{ha=63;break}}}}else{c[p>>2]=0;fa=f+19224|0;b:do{if((da|0)==0){if(n){u=1;while(1){i7a(f,p,q,r,l);s=(c[q>>2]|0)+u|0;if((s|0)>63){na=s;break b}$=c[r>>2]&65535;ga=s+1|0;if((c[fa>>2]|0)==0){b[g+(d[f+15730+s|0]<<1)>>1]=$}else{b[g+(d[f+19332+s|0]<<1)>>1]=$}if((c[p>>2]|0)==0){u=ga}else{na=ga;break}}}else{u=1;while(1){i7a(f,p,q,r,l);ga=(c[q>>2]|0)+u|0;if((ga|0)>63){na=ga;break b}$=c[r>>2]&65535;s=ga+1|0;if((c[fa>>2]|0)==0){b[g+(d[f+15730+ga|0]<<1)>>1]=$}else{b[g+(d[f+19332+ga|0]<<1)>>1]=$}if((c[p>>2]|0)==0){u=s}else{na=s;break}}}}else{u=1;while(1){i7a(f,p,q,r,l);s=(c[q>>2]|0)+u|0;if((s|0)>63){na=s;break b}$=c[fa>>2]|0;do{if(($|0)==1){ga=c[r>>2]&65535;w=s+1|0;if(n){b[g+(d[f+15858+s|0]<<1)>>1]=ga;oa=w;break}else{b[g+(d[f+15922+s|0]<<1)>>1]=ga;oa=w;break}}else if(($|0)==0){b[g+(d[f+15730+s|0]<<1)>>1]=c[r>>2];oa=s+1|0}else{b[g+(d[f+19332+s|0]<<1)>>1]=c[r>>2];oa=s+1|0}}while(0);if((c[p>>2]|0)==0){u=oa}else{na=oa;break}}}}while(0);fa=(da|0)!=0;do{if(fa){if((v|0)==0|(aa|0)==(v|0)){if(n){u=c[f+15992>>2]|0;s=g+(1<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+9<<1)>>1]|0);s=g+(2<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+10<<1)>>1]|0);s=g+(3<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+11<<1)>>1]|0);s=g+(4<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+12<<1)>>1]|0);s=g+(5<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+13<<1)>>1]|0);s=g+(6<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+14<<1)>>1]|0);s=g+(7<<u<<1)|0;b[s>>1]=(b[s>>1]|0)+(b[y+(ea+15<<1)>>1]|0);break}else{s=c[f+15988>>2]|0;u=g+(1<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+1<<1)>>1]|0);u=g+(2<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+2<<1)>>1]|0);u=g+(3<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+3<<1)>>1]|0);u=g+(4<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+4<<1)>>1]|0);u=g+(5<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+5<<1)>>1]|0);u=g+(6<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+6<<1)>>1]|0);u=g+(7<<s<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[y+(ea+7<<1)>>1]|0);break}}u=d[f+15728|0]|0;if((aa|0)==(u|0)){pa=d[k]|0}else{pa=0}s=pa+(aa<<1)|0;if((v|0)==(u|0)){qa=d[k]|0}else{qa=0}u=(v<<1)-1+qa|0;if((s-1|0)<1){i=m;return}$=c[1266216+(s-2<<2)>>2]|0;if(n){s=c[f+15992>>2]|0;w=(ca(ca(b[y+(ea+9<<1)>>1]|0,u)|0,$)|0)+131072>>18;ga=g+(1<<s<<1)|0;b[ga>>1]=w+(e[ga>>1]|0);ga=(ca(ca(b[y+(ea+10<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(2<<s<<1)|0;b[w>>1]=ga+(e[w>>1]|0);w=(ca(ca(b[y+(ea+11<<1)>>1]|0,u)|0,$)|0)+131072>>18;ga=g+(3<<s<<1)|0;b[ga>>1]=w+(e[ga>>1]|0);ga=(ca(ca(b[y+(ea+12<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(4<<s<<1)|0;b[w>>1]=ga+(e[w>>1]|0);w=(ca(ca(b[y+(ea+13<<1)>>1]|0,u)|0,$)|0)+131072>>18;ga=g+(5<<s<<1)|0;b[ga>>1]=w+(e[ga>>1]|0);ga=(ca(ca(b[y+(ea+14<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(6<<s<<1)|0;b[w>>1]=ga+(e[w>>1]|0);w=(ca(ca(b[y+(ea+15<<1)>>1]|0,u)|0,$)|0)+131072>>18;ga=g+(7<<s<<1)|0;b[ga>>1]=w+(e[ga>>1]|0);break}else{ga=c[f+15988>>2]|0;w=(ca(ca(b[y+(ea+1<<1)>>1]|0,u)|0,$)|0)+131072>>18;s=g+(1<<ga<<1)|0;b[s>>1]=w+(e[s>>1]|0);s=(ca(ca(b[y+(ea+2<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(2<<ga<<1)|0;b[w>>1]=s+(e[w>>1]|0);w=(ca(ca(b[y+(ea+3<<1)>>1]|0,u)|0,$)|0)+131072>>18;s=g+(3<<ga<<1)|0;b[s>>1]=w+(e[s>>1]|0);s=(ca(ca(b[y+(ea+4<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(4<<ga<<1)|0;b[w>>1]=s+(e[w>>1]|0);w=(ca(ca(b[y+(ea+5<<1)>>1]|0,u)|0,$)|0)+131072>>18;s=g+(5<<ga<<1)|0;b[s>>1]=w+(e[s>>1]|0);s=(ca(ca(b[y+(ea+6<<1)>>1]|0,u)|0,$)|0)+131072>>18;w=g+(6<<ga<<1)|0;b[w>>1]=s+(e[w>>1]|0);w=(ca(ca(b[y+(ea+7<<1)>>1]|0,u)|0,$)|0)+131072>>18;$=g+(7<<ga<<1)|0;b[$>>1]=w+(e[$>>1]|0);break}}}while(0);$=c[f+15988>>2]|0;w=c[f+15992>>2]|0;b[y+((x|1)<<1)>>1]=b[g+(1<<$<<1)>>1]|0;b[y+((x|9)<<1)>>1]=b[g+(1<<w<<1)>>1]|0;b[y+((x|2)<<1)>>1]=b[g+(2<<$<<1)>>1]|0;b[y+((x|10)<<1)>>1]=b[g+(2<<w<<1)>>1]|0;b[y+((x|3)<<1)>>1]=b[g+(3<<$<<1)>>1]|0;b[y+((x|11)<<1)>>1]=b[g+(3<<w<<1)>>1]|0;b[y+((x|4)<<1)>>1]=b[g+(4<<$<<1)>>1]|0;b[y+((x|12)<<1)>>1]=b[g+(4<<w<<1)>>1]|0;b[y+((x|5)<<1)>>1]=b[g+(5<<$<<1)>>1]|0;b[y+((x|13)<<1)>>1]=b[g+(5<<w<<1)>>1]|0;b[y+((x|6)<<1)>>1]=b[g+(6<<$<<1)>>1]|0;b[y+((x|14)<<1)>>1]=b[g+(6<<w<<1)>>1]|0;b[y+((x|7)<<1)>>1]=b[g+(7<<$<<1)>>1]|0;b[y+((x|15)<<1)>>1]=b[g+(7<<w<<1)>>1]|0;w=f+16081|0;$=-z|0;ga=1;do{u=g+(ga<<1)|0;s=b[u>>1]|0;do{if(!(s<<16>>16==0)){o=ca(s<<16>>16,B)|0;V=o&65535;b[u>>1]=V;if((a[w]|0)!=0){break}b[u>>1]=(V<<16>>16<0?$:z)+o}}while(0);ga=ga+1|0;}while((ga|0)<64);ha=fa?63:na}}while(0);c[f+180+(h<<2)>>2]=ha;i=m;return}function h7a(e,f,g,h,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;p=i;i=i+24|0;q=p|0;r=p+8|0;s=p+16|0;t=e+14120|0;qe[c[e+10092>>2]&1023](f);u=(j|0)==-1;if(u){v=c[e+16088>>2]|0;w=c[6074852+(v*20|0)>>2]|0;x=e+14128|0;y=c[x>>2]|0;z=c[e+14136>>2]|0;A=(c[t>>2]|0)+(y>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7)>>>27;A=b[w+(B<<2)>>1]|0;C=(b[w+(B<<2)+2>>1]|0)+y|0;c[x>>2]=z>>>0>C>>>0?C:z;D=c[1262240+(v<<5)+(A<<2)>>2]|0}else{D=j&7}a:do{if((D|0)==0){E=0;F=0}else if((D|0)==7){A=c[6074916+((c[e+16088>>2]|0)*20|0)>>2]|0;v=e+14128|0;z=c[v>>2]|0;C=c[e+14136>>2]|0;x=(c[t>>2]|0)+(z>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(z&7)>>>26;x=b[A+(y<<2)>>1]|0;B=(b[A+(y<<2)+2>>1]|0)+z|0;c[v>>2]=C>>>0>B>>>0?B:C;E=7;F=-2-x|0}else{do{if((a[e+16020|0]|0)==0){if((k|0)==0&((u|(j&8|0)==0)^1)){break}if((c[e+15608>>2]|k|0)!=0){E=D;F=0;break a}}}while(0);x=e+14128|0;C=c[x>>2]|0;B=c[t>>2]|0;v=d[B+(C>>>3)|0]|0;z=c[e+14136>>2]|0;y=((C|0)<(z|0))+C|0;c[x>>2]=y;if((v&128>>>((C&7)>>>0)|0)==0){G=0}else{C=d[B+(y>>>3)|0]<<(y&7)>>>7;c[x>>2]=((y|0)<(z|0))+y;G=(C&1)+1|0}C=(D-1|0)>>>0<2>>>0?3:D;E=(C-4|0)>>>0<2>>>0?6:C;F=(G|0)==0?0:G^3}}while(0);if((d[e+15728|0]|0)==(h|0)){H=d[e+16072|0]|0}else{H=0}G=H+(h<<1)|0;b:do{if((E-1|0)>>>0<2>>>0){I=2-((E|0)==2)|0;J=41}else{do{if((E-4|0)>>>0<2>>>0){K=2-((E|0)==5)|0}else{if((E|0)==0){c[q>>2]=0;H=e+16036|0;D=e+19224|0;t=e+16081|0;k=-h|0;j=0;while(1){i7a(e,q,r,s,c[H>>2]|0);u=(c[r>>2]|0)+j|0;if((u|0)>63){L=u;break}C=u+1|0;if((c[D>>2]|0)==0){M=e+15730+u|0}else{M=e+19332+u|0}u=ca(c[s>>2]|0,G)|0;y=u&65535;z=f+(d[M]<<1)|0;b[z>>1]=y;if((a[t]|0)==0){b[z>>1]=(y<<16>>16<0?k:h)+u}if((c[q>>2]|0)==0){j=C}else{L=C;break}}if((n|0)!=0){N=15;O=0;break b}if((L|0)==1){ef[c[e+15348>>2]&4095](l,m,f);N=15;O=0;break b}else{qe[c[e+15332>>2]&1023](f);ef[c[e+10072>>2]&4095](f,l,m);N=15;O=0;break b}}else if((E|0)==7){j=F&15;k=e+16036|0;t=e+15360|0;D=m<<1;H=e+15344|0;C=e+19224|0;u=e+16081|0;y=-h|0;z=0;do{x=1<<3-z&F;c[q>>2]=x;B=z<<2&4;v=z&2;A=B|v<<4;c:do{if((x|0)==0){w=0;while(1){i7a(e,q,r,s,c[k>>2]|0);P=(c[r>>2]|0)+w|0;if((P|0)>15){Q=P;break c}R=P+1|0;S=ca(c[s>>2]|0,G)|0;T=S&65535;U=f+((d[((c[C>>2]|0)==0?1262480:1267768)+P|0]|0)+A<<1)|0;b[U>>1]=T;if((a[u]|0)==0){b[U>>1]=(T<<16>>16<0?y:h)+S}if((c[q>>2]|0)==0){w=R}else{Q=R;break}}}else{Q=0}}while(0);do{if((x|n|0)==0){if((Q|0)==1){w=l+(B+(ca(D,v)|0))|0;ef[c[t>>2]&4095](w,m,f+(A<<1)|0);break}else{w=l+(B+(ca(D,v)|0))|0;ef[c[H>>2]&4095](w,m,f+(A<<1)|0);break}}}while(0);z=z+1|0;}while((z|0)<4);N=j^15;O=7;break b}else if((E|0)==3){I=F;J=41;break b}else if((E|0)==6){K=F;break}else{N=0;O=E;break b}}}while(0);z=(K*5|0)&15;H=e+16036|0;D=e+15356|0;t=e+15340|0;y=e+19224|0;u=e+16e3|0;C=e+16081|0;k=-h|0;A=K&2;c[q>>2]=A;d:do{if((A|0)==0){v=0;while(1){i7a(e,q,r,s,c[H>>2]|0);B=(c[r>>2]|0)+v|0;if((B|0)>31){V=B;break d}x=B+1|0;if((c[y>>2]|0)==0){W=(c[u>>2]|0)+B|0}else{W=1267736+B|0}B=ca(c[s>>2]|0,G)|0;w=B&65535;R=f+(d[W]<<1)|0;b[R>>1]=w;if((a[C]|0)==0){b[R>>1]=(w<<16>>16<0?k:h)+B}if((c[q>>2]|0)==0){v=x}else{V=x;break}}}else{V=0}}while(0);do{if((A|n|0)==0){if((V|0)==1){ef[c[D>>2]&4095](l,m,f);break}else{ef[c[t>>2]&4095](l,m,f);break}}}while(0);A=K&1;c[q>>2]=A;e:do{if((A|0)==0){v=0;while(1){i7a(e,q,r,s,c[H>>2]|0);j=(c[r>>2]|0)+v|0;if((j|0)>31){X=j;break e}x=j+1|0;if((c[y>>2]|0)==0){Y=(c[u>>2]|0)+j|0}else{Y=1267736+j|0}j=ca(c[s>>2]|0,G)|0;B=j&65535;w=f+((d[Y]|0)+4<<1)|0;b[w>>1]=B;if((a[C]|0)==0){b[w>>1]=(B<<16>>16<0?k:h)+j}if((c[q>>2]|0)==0){v=x}else{X=x;break}}}else{X=0}}while(0);do{if((A|n|0)==0){if((X|0)==1){ef[c[D>>2]&4095](l+4|0,m,f+8|0);break}else{ef[c[t>>2]&4095](l+4|0,m,f+8|0);break}}}while(0);N=z^15;O=6}}while(0);if((J|0)==41){J=((I&2)*6|0)&12|-(I&1)&3;X=e+16036|0;Y=e+15352|0;K=m<<2;V=e+15336|0;W=e+19224|0;E=e+15996|0;F=e+16081|0;Q=-h|0;L=0;do{M=1<<1-L&I;c[q>>2]=M;t=L<<5;f:do{if((M|0)==0){D=0;while(1){i7a(e,q,r,s,c[X>>2]|0);A=(c[r>>2]|0)+D|0;if((A|0)>31){Z=A;break f}k=A+1|0;if((c[W>>2]|0)==0){_=(c[E>>2]|0)+A|0}else{_=1267704+A|0}A=ca(c[s>>2]|0,G)|0;C=A&65535;u=f+((d[_]|0)+t<<1)|0;b[u>>1]=C;if((a[F]|0)==0){b[u>>1]=(C<<16>>16<0?Q:h)+A}if((c[q>>2]|0)==0){D=k}else{Z=k;break}}}else{Z=0}}while(0);do{if((M|n|0)==0){if((Z|0)==1){z=l+(ca(K,L)|0)|0;ef[c[Y>>2]&4095](z,m,f+(t<<1)|0);break}else{z=l+(ca(K,L)|0)|0;ef[c[V>>2]&4095](z,m,f+(t<<1)|0);break}}}while(0);L=L+1|0;}while((L|0)<2);N=J^15;O=3}if((o|0)==0){i=p;return N|0}c[o>>2]=c[o>>2]|O<<(g<<2);i=p;return N|0}function i7a(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=c[6208196+(i*20|0)>>2]|0;k=e+14128|0;l=c[k>>2]|0;m=c[e+14136>>2]|0;n=c[e+14120>>2]|0;o=n+(l>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>23;o=b[j+(p<<2)>>1]|0;q=b[j+(p<<2)+2>>1]|0;p=q<<16>>16;do{if(q<<16>>16<0){r=l+9|0;s=m>>>0>r>>>0?r:m;r=n+(s>>>3)|0;t=((je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((p+32|0)>>>0))+o|0;r=b[j+(t<<2)>>1]|0;u=b[j+(t<<2)+2>>1]|0;t=u<<16>>16;if(!(u<<16>>16<0)){v=t;w=r;x=s;break}u=s-p|0;s=m>>>0>u>>>0?u:m;u=n+(s>>>3)|0;y=((je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(s&7)>>>((t+32|0)>>>0))+r|0;v=b[j+(y<<2)+2>>1]|0;w=b[j+(y<<2)>>1]|0;x=s}else{v=p;w=o;x=l}}while(0);l=v+x|0;x=m>>>0>l>>>0?l:m;c[k>>2]=x;if((w|0)!=((c[1267784+(i<<2)>>2]|0)-1|0)){l=d[265016+(i*370|0)+(w<<1)|0]|0;v=d[265016+(i*370|0)+(w<<1)+1|0]|0;if((w|0)<(c[264984+(i<<2)>>2]|0)){z=((c[e+14132>>2]|0)-x|0)>>>31}else{z=1}w=d[n+(x>>>3)|0]|0;c[k>>2]=((x|0)<(m|0))+x;A=z;B=(w&128>>>((x&7)>>>0)|0)==0?v:-v|0;C=l;c[f>>2]=A;c[g>>2]=C;c[h>>2]=B;return}l=d[n+(x>>>3)|0]|0;v=((x|0)<(m|0))+x|0;c[k>>2]=v;do{if((l&128>>>((x&7)>>>0)|0)==0){w=d[n+(v>>>3)|0]<<(v&7)>>>7;z=((v|0)<(m|0))+v|0;c[k>>2]=z;o=w&1;if((o|0)!=0){D=2-o|0;E=z;break}o=d[n+(z>>>3)|0]<<(z&7)>>>7;w=((z|0)<(m|0))+z|0;c[k>>2]=w;z=o&1;o=e+14100|0;p=c[o>>2]|0;if((p|0)==0){do{if((d[e+15728|0]|0)>>>0<8>>>0){F=26}else{if((a[e+16004|0]|0)==0){G=0;H=w}else{F=26;break}while(1){if((G|0)>=6){I=H;break}q=d[n+(H>>>3)|0]|0;s=((H|0)<(m|0))+H|0;c[k>>2]=s;if((q&128>>>((H&7)>>>0)|0)==0){G=G+1|0;H=s}else{I=s;break}}s=G+2|0;c[o>>2]=s;J=I;K=s}}while(0);do{if((F|0)==26){s=n+(w>>>3)|0;q=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7)>>>29;s=w+3|0;y=m>>>0>s>>>0?s:m;c[k>>2]=y;c[o>>2]=q;if((q|0)!=0){J=y;K=q;break}q=n+(y>>>3)|0;s=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(y&7)>>>30;q=y+2|0;y=m>>>0>q>>>0?q:m;c[k>>2]=y;q=s|8;c[o>>2]=q;J=y;K=q}}while(0);o=n+(J>>>3)|0;q=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(J&7)>>>30;o=J+2|0;y=m>>>0>o>>>0?o:m;c[k>>2]=y;o=q+3|0;c[e+14104>>2]=o;L=y;M=K;N=o}else{L=w;M=p;N=c[e+14104>>2]|0}o=n+(L>>>3)|0;y=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(L&7)>>>((32-N|0)>>>0);o=L+N|0;q=m>>>0>o>>>0?o:m;c[k>>2]=q;o=d[n+(q>>>3)|0]|0;s=((q|0)<(m|0))+q|0;c[k>>2]=s;r=n+(s>>>3)|0;t=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>((32-M|0)>>>0);r=s+M|0;c[k>>2]=m>>>0>r>>>0?r:m;A=z;B=(o&128>>>((q&7)>>>0)|0)==0?t:-t|0;C=y;c[f>>2]=A;c[g>>2]=C;c[h>>2]=B;return}else{D=0;E=v}}while(0);v=n+(E>>>3)|0;M=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(E&7)>>>23;v=b[j+(M<<2)>>1]|0;N=b[j+(M<<2)+2>>1]|0;M=N<<16>>16;do{if(N<<16>>16<0){L=E+9|0;e=m>>>0>L>>>0?L:m;L=n+(e>>>3)|0;K=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(e&7)>>>((M+32|0)>>>0))+v|0;L=b[j+(K<<2)>>1]|0;J=b[j+(K<<2)+2>>1]|0;K=J<<16>>16;if(!(J<<16>>16<0)){O=K;P=L;Q=e;break}J=e-M|0;e=m>>>0>J>>>0?J:m;J=n+(e>>>3)|0;F=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(e&7)>>>((K+32|0)>>>0))+L|0;O=b[j+(F<<2)+2>>1]|0;P=b[j+(F<<2)>>1]|0;Q=e}else{O=M;P=v;Q=E}}while(0);E=O+Q|0;Q=m>>>0>E>>>0?E:m;c[k>>2]=Q;E=d[265016+(i*370|0)+(P<<1)|0]|0;O=d[265016+(i*370|0)+(P<<1)+1|0]|0;v=(P|0)>=(c[264984+(i<<2)>>2]|0);P=v&1;do{if((D|0)==0){if(v){R=(d[264632+(i*44|0)+E|0]|0)+O|0;S=E;break}else{R=(d[268568+(i*31|0)+E|0]|0)+O|0;S=E;break}}else{if(v){R=O;S=E+1+(d[264552+(i*10|0)+O|0]|0)|0;break}else{R=O;S=E+1+(d[268112+(i*57|0)+O|0]|0)|0;break}}}while(0);O=d[n+(Q>>>3)|0]|0;c[k>>2]=((Q|0)<(m|0))+Q;if((O&128>>>((Q&7)>>>0)|0)==0){A=P;B=R;C=S;c[f>>2]=A;c[g>>2]=C;c[h>>2]=B;return}A=P;B=-R|0;C=S;c[f>>2]=A;c[g>>2]=C;c[h>>2]=B;return}function j7a(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=c[e+124>>2]|0;l=(ca(k,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;m=c[e+12520+(f<<2)>>2]|0;n=c[e+9876>>2]|0;o=c[e+12496+(f<<2)>>2]|0;p=n+(o<<1)|0;q=b[n+(o-1<<1)>>1]|0;r=b[n+(o+~m<<1)>>1]|0;s=b[n+(o-m<<1)>>1]|0;m=c[e+9136>>2]|0;o=a[m+l|0]|0;n=c[e+9888>>2]|0;e=(d[n+(o<<24>>24)|0]|0)-1|0;if((e|0)<0){t=0;return t|0}u=(h|0)!=0;do{if(u){if((f|0)==3|(f|0)==1){v=q;break}h=a[m+(l-1)|0]|0;if(h<<24>>24==0|h<<24>>24==o<<24>>24){v=q;break}w=ca(d[n+(h<<24>>24)|0]|0,q)|0;v=(ca(w,c[1266216+(e<<2)>>2]|0)|0)+131072>>18}else{v=q}}while(0);do{if((g|0)==0){c[j>>2]=1;x=u?v:0}else{do{if((f-2|0)>>>0>1>>>0){q=a[m+(l-k)|0]|0;if(q<<24>>24==0|q<<24>>24==o<<24>>24){y=s;break}w=ca(d[n+(q<<24>>24)|0]|0,s)|0;y=(ca(w,c[1266216+(e<<2)>>2]|0)|0)+131072>>18}else{y=s}}while(0);do{if((f|0)==3|u^1){z=13}else{w=a[m+(l+(((f|0)!=1)<<31>>31)-((f|0)==2?0:k))|0]|0;if(w<<24>>24==0|w<<24>>24==o<<24>>24){z=13;break}q=ca(d[n+(w<<24>>24)|0]|0,r)|0;w=(ca(q,c[1266216+(e<<2)>>2]|0)|0)+131072>>18;if(u){A=w}else{z=17}}}while(0);if((z|0)==13){if(u){A=r}else{z=17}}if((z|0)==17){c[j>>2]=0;x=y;break}w=y-A|0;q=A-v|0;if((((w|0)>-1?w:-w|0)|0)>(((q|0)>-1?q:-q|0)|0)){c[j>>2]=0;x=y;break}else{c[j>>2]=1;x=v;break}}}while(0);c[i>>2]=p;t=x;return t|0}function k7a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;g=i;h=e+19428|0;j=c[h>>2]|0;k=c[e+140>>2]>>j;l=(j|0)==0;do{if(l){m=4}else{if((c[e+19460+(f<<2)>>2]|0)!=1){break}if((c[e+19456>>2]|0)==1){m=4}}}while(0);do{if((m|0)==4){if((c[e+952>>2]|0)!=0){break}i=g;return}}while(0);j=c[e+11744+(f<<5)>>2]|0;n=c[e+11744+(f<<5)+4>>2]|0;if((c[e+9992>>2]|0)==2){o=j&65535;p=c[e+19468>>2]|0;q=c[e+9152>>2]|0;r=n&65535;s=p+(c[e+12496>>2]|0)|0;b[q+(s<<2)>>1]=o;b[q+(s<<2)+2>>1]=r;s=p+(c[e+12500>>2]|0)|0;b[q+(s<<2)>>1]=o;b[q+(s<<2)+2>>1]=r;s=p+(c[e+12504>>2]|0)|0;b[q+(s<<2)>>1]=o;b[q+(s<<2)+2>>1]=r;s=p+(c[e+12508>>2]|0)|0;b[q+(s<<2)>>1]=o;b[q+(s<<2)+2>>1]=r}r=j&3;s=((r|0)==3)+j>>1;q=((n&3|0)==3)+n>>1;o=c[e+12476>>2]|0;p=c[e+19600>>2]|0;b[p+(o<<2)>>1]=s;b[p+(o<<2)+2>>1]=q;do{if(l){t=q;u=n}else{p=c[e+19456>>2]|0;if((p|0)==(c[e+19460+(f<<2)>>2]|0)){t=q;u=n;break}v=p<<2;t=q-2+v|0;u=n-2+v|0}}while(0);do{if((c[e+15680>>2]|0)==0){w=t;x=s}else{if((c[e+19224>>2]|0)==1){w=t;x=s;break}n=s&1;q=t&1;w=((t|0)<0?q:-q|0)+t|0;x=((s|0)<0?n:-n|0)+s|0}}while(0);a:do{if((f|0)==0){do{if(!l){if((c[e+19456>>2]|0)==(c[e+19460>>2]|0)){break}if((c[e+19436>>2]|0)==0){break}y=e+7624|0;z=e+7628|0;A=e+7632|0;B=c[e+19204>>2]|0;C=c[e+19196>>2]|0;D=c[e+19192>>2]|0;break a}}while(0);y=e+952|0;z=e+956|0;A=e+960|0;B=e+19200|0;C=e+16632|0;D=e+16120|0}else{y=e+3176|0;z=e+3180|0;A=e+3184|0;B=e+19208|0;C=e+18680|0;D=e+18168|0}}while(0);s=c[y>>2]|0;y=c[z>>2]|0;z=c[A>>2]|0;A=c[B>>2]|0;if((s|0)==0|(y|0)==0){KIb(c[e+4>>2]|0,16,2259808,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;i=g;return}B=(o<<4)+(j>>2)|0;t=c[e+12480>>2]|0;n=(t<<4)+(u>>2)|0;q=(o<<3)+(x>>2)|0;o=(t<<3)+(w>>2)|0;if((c[e+15660>>2]|0)==3){t=c[e+4>>2]|0;v=c[t+128>>2]|0;if((B|0)<-17){E=-17}else{E=(B|0)>(v|0)?v:B}p=c[t+132>>2]|0;t=p+1|0;if((n|0)<-18){F=-18}else{F=(n|0)>(t|0)?t:n}t=v>>1;if((q|0)<-8){G=-8}else{G=(q|0)>(t|0)?t:q}H=G;I=F;J=E;K=p>>1}else{p=c[e+116>>2]|0;E=p<<4;if((B|0)<-16){L=-16}else{L=(B|0)>(E|0)?E:B}B=c[e+120>>2]|0;E=B<<4;if((n|0)<-16){M=-16}else{M=(n|0)>(E|0)?E:n}n=p<<3;if((q|0)<-8){N=-8}else{N=(q|0)>(n|0)?n:q}H=N;I=M;J=L;K=B<<3}if((o|0)<-8){O=-8}else{O=(o|0)>(K|0)?K:o}o=e+148|0;K=c[o>>2]|0;B=(ca(K,I)|0)+J|0;L=s+B|0;M=e+152|0;N=(ca(c[M>>2]|0,O)|0)+H|0;q=y+N|0;n=z+N|0;do{if(l){P=L;Q=q;R=n}else{if((c[e+19460+(f<<2)>>2]|0)==0){P=L;Q=q;R=n;break}p=c[e+9856>>2]|0;P=s+((c[p+32>>2]|0)+B)|0;Q=y+((c[p+36>>2]|0)+N)|0;R=z+((c[p+40>>2]|0)+N)|0}}while(0);N=e+60|0;if((c[N>>2]&8192|0)==0){S=Q;T=R}else{R=(c[e+9944>>2]|0)+(K*18|0)|0;S=R;T=R}R=e+19220|0;Q=(A|0)==0;A=c[e+136>>2]|0;do{if((a[R]|0)==0&Q){if((A|0)<22|(k|0)<22){m=48;break}z=c[e+14116>>2]|0;if((J-z|0)>>>0>(-16-r+A+(z*-3|0)|0)>>>0){m=48;break}if((I-1|0)>>>0>(k-19-(u&3)|0)>>>0){m=48}else{U=P;V=S;W=T;X=z;Y=K}}else{m=48}}while(0);if((m|0)==48){m=e+9944|0;z=c[m>>2]|0;y=K*19|0;B=z+y|0;s=e+14116|0;n=c[s>>2]|0;q=P+(ca(n,~K)|0)|0;P=e+11540|0;L=(n<<1)+17|0;l=e+136|0;Ve[c[P>>2]&127](z,q,K,K,L,L,J-n|0,I-n|0,A,k);A=c[m>>2]|0;m=c[M>>2]|0;n=k>>1;Ve[c[P>>2]&127](B,S,m,m,9,9,H,O,c[l>>2]>>1,n);m=z+(y+16)|0;y=c[M>>2]|0;Ve[c[P>>2]&127](m,T,y,y,9,9,H,O,c[l>>2]>>1,n);if((a[R]|0)!=0){R=c[s>>2]|0;if(((R<<1)+17|0)>0){n=0;l=A;H=R;while(1){if(((H<<1)+17|0)>0){R=0;while(1){y=l+R|0;a[y]=(((d[y]|0)+384|0)>>>1)+128;y=R+1|0;T=c[s>>2]|0;if((y|0)<((T<<1)+17|0)){R=y}else{Z=T;break}}}else{Z=H}R=n+1|0;if((R|0)<((Z<<1)+17|0)){n=R;l=l+(c[o>>2]|0)|0;H=Z}else{_=0;$=B;aa=m;break}}}else{_=0;$=B;aa=m}while(1){Z=0;do{H=$+Z|0;a[H]=(((d[H]|0)+384|0)>>>1)+128;H=aa+Z|0;a[H]=(((d[H]|0)+384|0)>>>1)+128;Z=Z+1|0;}while((Z|0)<9);Z=c[M>>2]|0;H=_+1|0;if((H|0)<9){_=H;$=$+Z|0;aa=aa+Z|0}else{break}}}b:do{if(!Q){aa=c[s>>2]|0;$=e+19460+(f<<2)|0;c:do{if(((aa<<1)+17|0)>0){_=0;Z=A;H=aa;while(1){if((c[h>>2]|0)==0){ba=_+I-H&1}else{ba=c[$>>2]|0}if(((H<<1)+17|0)>0){l=0;while(1){n=Z+l|0;a[n]=a[(d[n]|0)+(D+(ba<<8))|0]|0;n=l+1|0;R=c[s>>2]|0;if((n|0)<((R<<1)+17|0)){l=n}else{da=R;break}}}else{da=H}l=_+1|0;if((l|0)>=((da<<1)+17|0)){break c}_=l;Z=Z+(c[o>>2]|0)|0;H=da}}}while(0);aa=0;H=B;Z=m;while(1){if((c[h>>2]|0)==0){ea=aa+O&1}else{ea=c[$>>2]|0}a[H]=a[(d[H]|0)+(C+(ea<<8))|0]|0;a[Z]=a[(d[Z]|0)+(C+(ea<<8))|0]|0;_=H+1|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+1|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+2|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+2|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+3|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+3|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+4|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+4|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+5|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+5|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+6|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+6|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+7|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+7|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=H+8|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=Z+8|0;a[_]=a[(d[_]|0)+(C+(ea<<8))|0]|0;_=c[M>>2]|0;l=aa+1|0;if((l|0)>=9){break b}aa=l;H=H+_|0;Z=Z+_|0}}}while(0);ea=c[s>>2]|0;s=c[o>>2]|0;U=A+(ca(s+1|0,ea)|0)|0;V=B;W=m;X=ea;Y=s}do{if((X|0)==0){s=u&2|j>>>1&1;if((c[e+19216>>2]|0)==0){mf[c[e+11332+(s<<2)>>2]&2047](c[e+12544>>2]|0,U,Y,16);break}else{mf[c[e+11460+(s<<2)>>2]&2047](c[e+12544>>2]|0,U,Y,16);break}}else{s=e+15404+((u<<2&12|r)<<2)|0;ea=e+12544|0;m=e+19216|0;mf[c[s>>2]&2047](c[ea>>2]|0,U,Y,c[m>>2]|0);mf[c[s>>2]&2047]((c[ea>>2]|0)+8|0,U+8|0,c[o>>2]|0,c[m>>2]|0);B=c[o>>2]|0;A=B<<3;mf[c[s>>2]&2047]((c[ea>>2]|0)+A|0,U+A|0,B,c[m>>2]|0);B=c[o>>2]|0;mf[c[s>>2]&2047]((c[ea>>2]|0)+((B<<3)+8)|0,U+(A+8)|0,B,c[m>>2]|0)}}while(0);if((c[N>>2]&8192|0)!=0){i=g;return}N=x<<1&6;x=w<<1&6;if((c[e+19216>>2]|0)==0){w=e+15300|0;_e[c[w>>2]&511](c[e+12548>>2]|0,V,c[M>>2]|0,8,N,x);_e[c[w>>2]&511](c[e+12552>>2]|0,W,c[M>>2]|0,8,N,x);i=g;return}else{w=e+15532|0;_e[c[w>>2]&511](c[e+12548>>2]|0,V,c[M>>2]|0,8,N,x);_e[c[w>>2]&511](c[e+12552>>2]|0,W,c[M>>2]|0,8,N,x);i=g;return}}function l7a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=b+19428|0;f=c[e>>2]|0;g=c[b+140>>2]>>f;h=c[b+19208>>2]|0;i=(f|0)==0;do{if(i){if((c[b+3176>>2]|0)!=0){break}return}}while(0);f=c[b+11776>>2]|0;j=c[b+11780>>2]|0;k=f&3;l=((k|0)==3)+f>>1;m=((j&3|0)==3)+j>>1;if(i){n=j;o=m}else{p=c[b+19456>>2]|0;if((p|0)==(c[b+19464>>2]|0)){q=j;r=p<<2}else{s=p<<2;q=j-2+s|0;r=s}n=q;o=m-2+r|0}if((c[b+15680>>2]|0)==0){t=l;u=o}else{r=l&1;m=o&1;t=((l|0)<0?-r|0:r)+l|0;u=((o|0)<0?-m|0:m)+o|0}o=c[b+3176>>2]|0;m=c[b+3180>>2]|0;l=c[b+3184>>2]|0;r=c[b+12476>>2]|0;q=(r<<4)+(f>>2)|0;s=c[b+12480>>2]|0;j=(s<<4)+(n>>2)|0;p=(r<<3)+(t>>2)|0;r=(s<<3)+(u>>2)|0;if((c[b+15660>>2]|0)==3){s=c[b+4>>2]|0;v=c[s+128>>2]|0;if((q|0)<-17){w=-17}else{w=(q|0)>(v|0)?v:q}x=c[s+132>>2]|0;s=x+1|0;if((j|0)<-18){y=-18}else{y=(j|0)>(s|0)?s:j}s=v>>1;if((p|0)<-8){z=-8}else{z=(p|0)>(s|0)?s:p}A=w;B=y;C=z;D=x>>1}else{x=c[b+116>>2]|0;z=x<<4;if((q|0)<-16){E=-16}else{E=(q|0)>(z|0)?z:q}q=c[b+120>>2]|0;z=q<<4;if((j|0)<-16){F=-16}else{F=(j|0)>(z|0)?z:j}j=x<<3;if((p|0)<-8){G=-8}else{G=(p|0)>(j|0)?j:p}A=E;B=F;C=G;D=q<<3}if((r|0)<-8){H=-8}else{H=(r|0)>(D|0)?D:r}r=b+148|0;D=c[r>>2]|0;q=(ca(D,B)|0)+A|0;G=o+q|0;F=b+152|0;E=(ca(c[F>>2]|0,H)|0)+C|0;p=m+E|0;j=l+E|0;do{if(i){I=G;J=p;K=j}else{if((c[b+19464>>2]|0)==0){I=G;J=p;K=j;break}x=c[b+9856>>2]|0;I=o+((c[x+32>>2]|0)+q)|0;J=m+((c[x+36>>2]|0)+E)|0;K=l+((c[x+40>>2]|0)+E)|0}}while(0);E=b+60|0;if((c[E>>2]&8192|0)==0){L=J;M=K}else{K=(c[b+9944>>2]|0)+(D*18|0)|0;L=K;M=K}K=b+19220|0;J=c[b+136>>2]|0;do{if((a[K]|0)==0){if(!((g|0)>21&(J|0)>21&(h|0)==0)){N=37;break}if((A-1|0)>>>0>(-19-k+J|0)>>>0){N=37;break}if((B-1|0)>>>0>(g-19-(n&3)|0)>>>0){N=37;break}O=I;P=L;Q=M;R=D;S=c[b+14116>>2]|0}else{N=37}}while(0);if((N|0)==37){N=b+9944|0;l=c[N>>2]|0;m=D*19|0;q=l+m|0;o=b+14116|0;j=c[o>>2]|0;p=I+(ca(j,~D)|0)|0;I=b+11540|0;G=(j<<1)+17|0;i=b+136|0;Ve[c[I>>2]&127](l,p,D,D,G,G,A-j|0,B-j|0,J,g);J=c[N>>2]|0;N=c[F>>2]|0;j=g>>1;Ve[c[I>>2]&127](q,L,N,N,9,9,C,H,c[i>>2]>>1,j);N=l+(m+16)|0;m=c[F>>2]|0;Ve[c[I>>2]&127](N,M,m,m,9,9,C,H,c[i>>2]>>1,j);if((a[K]|0)!=0){K=c[o>>2]|0;if(((K<<1)+17|0)>0){j=0;i=J;C=K;while(1){if(((C<<1)+17|0)>0){K=0;while(1){m=i+K|0;a[m]=(((d[m]|0)+384|0)>>>1)+128;m=K+1|0;M=c[o>>2]|0;if((m|0)<((M<<1)+17|0)){K=m}else{T=M;break}}}else{T=C}K=j+1|0;if((K|0)<((T<<1)+17|0)){j=K;i=i+(c[r>>2]|0)|0;C=T}else{U=0;V=q;W=N;break}}}else{U=0;V=q;W=N}while(1){T=0;do{C=V+T|0;a[C]=(((d[C]|0)+384|0)>>>1)+128;C=W+T|0;a[C]=(((d[C]|0)+384|0)>>>1)+128;T=T+1|0;}while((T|0)<9);T=c[F>>2]|0;C=U+1|0;if((C|0)<9){U=C;V=V+T|0;W=W+T|0}else{break}}}a:do{if((h|0)!=0){W=c[o>>2]|0;V=b+19464|0;b:do{if(((W<<1)+17|0)>0){U=0;T=J;C=W;while(1){if((c[e>>2]|0)==0){X=U+B-C&1}else{X=c[V>>2]|0}if(((C<<1)+17|0)>0){i=0;while(1){j=T+i|0;a[j]=a[(d[j]|0)+(b+18168+(X<<8))|0]|0;j=i+1|0;K=c[o>>2]|0;if((j|0)<((K<<1)+17|0)){i=j}else{Y=K;break}}}else{Y=C}i=U+1|0;if((i|0)>=((Y<<1)+17|0)){break b}U=i;T=T+(c[r>>2]|0)|0;C=Y}}}while(0);W=0;C=q;T=N;while(1){if((c[e>>2]|0)==0){Z=W+H&1}else{Z=c[V>>2]|0}a[C]=a[(d[C]|0)+(b+18680+(Z<<8))|0]|0;a[T]=a[(d[T]|0)+(b+18680+(Z<<8))|0]|0;U=C+1|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+1|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+2|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+2|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+3|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+3|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+4|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+4|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+5|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+5|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+6|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+6|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+7|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+7|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=C+8|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=T+8|0;a[U]=a[(d[U]|0)+(b+18680+(Z<<8))|0]|0;U=c[F>>2]|0;i=W+1|0;if((i|0)>=9){break a}W=i;C=C+U|0;T=T+U|0}}}while(0);Z=c[o>>2]|0;o=c[r>>2]|0;O=J+(ca(o+1|0,Z)|0)|0;P=q;Q=N;R=o;S=Z}do{if((S|0)==0){Z=n&2|f>>>1&1;if((c[b+19216>>2]|0)==0){mf[c[b+11396+(Z<<2)>>2]&2047](c[b+12544>>2]|0,O,R,16);break}else{mf[c[b+11524+(Z<<2)>>2]&2047](c[b+12544>>2]|0,O,R,16);break}}else{Z=b+15468+((n<<2&12|k)<<2)|0;o=b+12544|0;N=b+19216|0;mf[c[Z>>2]&2047](c[o>>2]|0,O,R,c[N>>2]|0);mf[c[Z>>2]&2047]((c[o>>2]|0)+8|0,O+8|0,c[r>>2]|0,c[N>>2]|0);q=c[r>>2]|0;J=q<<3;mf[c[Z>>2]&2047]((c[o>>2]|0)+J|0,O+J|0,q,c[N>>2]|0);q=c[r>>2]|0;mf[c[Z>>2]&2047]((c[o>>2]|0)+((q<<3)+8)|0,O+(J+8)|0,q,c[N>>2]|0)}}while(0);if((c[E>>2]&8192|0)!=0){return}E=t<<1&6;t=u<<1&6;if((c[b+19216>>2]|0)==0){u=b+15316|0;_e[c[u>>2]&511](c[b+12548>>2]|0,P,c[F>>2]|0,8,E,t);_e[c[u>>2]&511](c[b+12552>>2]|0,Q,c[F>>2]|0,8,E,t);return}else{u=b+15544|0;_e[c[u>>2]&511](c[b+12548>>2]|0,P,c[F>>2]|0,8,E,t);_e[c[u>>2]&511](c[b+12552>>2]|0,Q,c[F>>2]|0,8,E,t);return}}function m7a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;j=i;i=i+64|0;k=j|0;l=e+19224|0;m=c[l>>2]|0;if((m|0)==1){n=d[(c[e+19400>>2]|0)+(c[e+12496+(f<<2)>>2]|0)|0]|0}else{n=0}o=e+19428|0;p=c[o>>2]|0;q=c[e+140>>2]>>p;r=(p|0)==0;do{if(r){s=6}else{if((c[e+19460+(g<<2)>>2]|0)!=1){break}if((c[e+19456>>2]|0)==1){s=6}}}while(0);do{if((s|0)==6){if((c[e+952>>2]|0)!=0){break}i=j;return}}while(0);p=c[e+11744+(g<<5)+(f<<3)>>2]|0;t=c[e+11744+(g<<5)+(f<<3)+4>>2]|0;a:do{if((g|0)==0){do{if(!r){if((c[e+19456>>2]|0)==(c[e+19460>>2]|0)){break}if((c[e+19436>>2]|0)==0){break}u=e+7624|0;v=c[e+19204>>2]|0;w=c[e+19192>>2]|0;break a}}while(0);u=e+952|0;v=e+19200|0;w=e+16120|0}else{u=e+3176|0;v=e+19208|0;w=e+18168|0}}while(0);x=c[u>>2]|0;u=c[v>>2]|0;if((x|0)==0){KIb(c[e+4>>2]|0,16,2259808,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;i=j;return}do{if(r){z=t}else{v=c[e+19456>>2]|0;if((v|0)==(c[e+19460+(g<<2)>>2]|0)){z=t;break}z=t-2+(v<<2)|0}}while(0);t=e+9992|0;if((f|0)!=3|(c[t>>2]|0)!=2|r){A=m}else{m=e+19468|0;r=c[m>>2]|0;v=c[e+19408>>2]|0;B=r+(c[e+12496>>2]|0)|0;C=d[v+B|0]|0;c[k+(C<<5)>>2]=c[e+11744>>2];c[k+(C<<5)+4>>2]=c[e+11748>>2];D=1-C|0;E=e+12500|0;F=a[v+(r+(c[E>>2]|0))|0]|0;G=F&255;H=F<<24>>24!=0?C:D;c[k+(G<<5)+(H<<3)>>2]=c[e+11752>>2];c[k+(G<<5)+(H<<3)+4>>2]=c[e+11756>>2];H=G+C|0;C=D+1-G|0;G=e+12504|0;D=a[v+(r+(c[G>>2]|0))|0]|0;F=D&255;I=D<<24>>24!=0?H:C;c[k+(F<<5)+(I<<3)>>2]=c[e+11760>>2];c[k+(F<<5)+(I<<3)+4>>2]=c[e+11764>>2];I=F+H|0;H=C+1-F|0;F=e+12508|0;C=a[v+(r+(c[F>>2]|0))|0]|0;r=C&255;v=C<<24>>24!=0?I:H;c[k+(r<<5)+(v<<3)>>2]=c[e+11768>>2];c[k+(r<<5)+(v<<3)+4>>2]=c[e+11772>>2];v=r+I|0;I=H+1-r|0;r=(v|0)>(I|0);H=r&1;C=r?v:I;do{if((C|0)==2){J=(((c[k+(H<<5)+12>>2]|0)+(c[k+(H<<5)+4>>2]|0)|0)/2|0)&65535;K=(((c[k+(H<<5)+8>>2]|0)+(c[k+(H<<5)>>2]|0)|0)/2|0)&65535}else if((C|0)==3){I=c[k+(H<<5)>>2]|0;v=c[k+(H<<5)+8>>2]|0;D=c[k+(H<<5)+16>>2]|0;do{if((I|0)>(v|0)){if((D|0)<=(v|0)){L=v&65535;break}L=((D|0)>(I|0)?I:D)&65535}else{if((v|0)<=(D|0)){L=v&65535;break}L=((D|0)>(I|0)?D:I)&65535}}while(0);I=c[k+(H<<5)+4>>2]|0;D=c[k+(H<<5)+12>>2]|0;v=c[k+(H<<5)+20>>2]|0;if((I|0)>(D|0)){if((v|0)<=(D|0)){J=D&65535;K=L;break}J=((v|0)>(I|0)?I:v)&65535;K=L;break}else{if((D|0)<=(v|0)){J=D&65535;K=L;break}J=((v|0)>(I|0)?v:I)&65535;K=L;break}}else if((C|0)==4){I=c[k+(H<<5)>>2]|0;v=c[k+(H<<5)+8>>2]|0;D=c[k+(H<<5)+16>>2]|0;M=c[k+(H<<5)+24>>2]|0;N=(D|0)<(M|0);do{if((I|0)<(v|0)){if(N){O=((v|0)>(M|0)?M:v)+((I|0)>(D|0)?I:D)|0;break}else{O=((I|0)>(M|0)?I:M)+((v|0)>(D|0)?D:v)|0;break}}else{if(N){O=((I|0)>(M|0)?M:I)+((v|0)>(D|0)?v:D)|0;break}else{O=((v|0)>(M|0)?v:M)+((I|0)>(D|0)?D:I)|0;break}}}while(0);I=(O|0)/2|0;D=c[k+(H<<5)+4>>2]|0;M=c[k+(H<<5)+12>>2]|0;v=c[k+(H<<5)+20>>2]|0;N=c[k+(H<<5)+28>>2]|0;P=(v|0)<(N|0);do{if((D|0)<(M|0)){if(P){Q=((M|0)>(N|0)?N:M)+((D|0)>(v|0)?D:v)|0;break}else{Q=((D|0)>(N|0)?D:N)+((M|0)>(v|0)?v:M)|0;break}}else{if(P){Q=((D|0)>(N|0)?N:D)+((M|0)>(v|0)?M:v)|0;break}else{Q=((M|0)>(N|0)?M:N)+((D|0)>(v|0)?v:D)|0;break}}}while(0);J=((Q|0)/2|0)&65535;K=I&65535}else{KIb(0,0,2565376,(y=i,i=i+24|0,c[y>>2]=2234960,c[y+8>>2]=2529528,c[y+16>>2]=624,y)|0);i=y;Hd()}}while(0);y=c[e+9152>>2]|0;b[y+(B<<2)>>1]=K;b[y+(B<<2)+2>>1]=J;J=r&1;r=e+19412|0;a[(c[r>>2]|0)+B|0]=J;a[(c[r>>2]|0)+((c[m>>2]|0)+(c[E>>2]|0))|0]=J;a[(c[r>>2]|0)+((c[m>>2]|0)+(c[G>>2]|0))|0]=J;a[(c[r>>2]|0)+((c[m>>2]|0)+(c[F>>2]|0))|0]=J;A=c[l>>2]|0}l=(A|0)==1;do{if(l){J=c[e+4>>2]|0;F=c[J+128>>2]|0;m=c[J+132>>2]>>1;if((c[t>>2]|0)==2){J=(c[e+19468>>2]|0)+(c[e+12496+(f<<2)>>2]|0)|0;r=c[e+9152>>2]|0;b[r+(J<<2)>>1]=p;b[r+(J<<2)+2>>1]=z}J=(c[e+12476>>2]<<4)+(p>>2)|0;r=(c[e+12480>>2]<<3)+(z>>3)|0;do{if((J|0)<-17){R=p-68-(J<<2)|0}else{if((J|0)<=(F|0)){R=p;break}R=p-(J-F<<2)|0}}while(0);do{if((r|0)<-18){S=z-144-(r<<3)|0}else{if((r|0)<=(m+1|0)){S=z;break}S=z+8-(r-m<<3)|0}}while(0);if((A|0)!=1|(n|0)==0){T=S;U=R;s=64;break}if((f|0)>1){V=c[e+148>>2]|0}else{V=0}W=V+(f<<3&8)|0;X=S;Y=R}else{T=z;U=p;s=64}}while(0);if((s|0)==64){W=(ca(f<<2&8,c[e+148>>2]|0)|0)+(f<<3&8)|0;X=T;Y=U}U=(c[e+12476>>2]<<4|f<<3&8)+(Y>>2)|0;T=(n|0)!=0;p=c[e+12480>>2]<<4;if(T){Z=(p|(f|0)>1)+(X>>2)|0}else{Z=(p|f<<2&8)+(X>>2)|0}do{if((c[e+15660>>2]|0)==3){f=c[e+4>>2]|0;p=c[f+128>>2]|0;if((U|0)<-17){_=-17}else{_=(U|0)>(p|0)?p:U}if(!l){p=(c[f+132>>2]|0)+1|0;if((Z|0)<-18){$=_;aa=-18;break}$=_;aa=(Z|0)>(p|0)?p:Z;break}p=c[f+132>>2]|0;if((Z&1|0)==0){if((Z|0)<-18){$=_;aa=-18;break}$=_;aa=(Z|0)>(p|0)?p:Z;break}else{f=p+1|0;if((Z|0)<-17){$=_;aa=-17;break}$=_;aa=(Z|0)>(f|0)?f:Z;break}}else{f=c[e+116>>2]<<4;if((U|0)<-16){ba=-16}else{ba=(U|0)>(f|0)?f:U}f=c[e+120>>2]<<4;if((Z|0)<-16){$=ba;aa=-16;break}$=ba;aa=(Z|0)>(f|0)?f:Z}}while(0);Z=e+148|0;ba=c[Z>>2]|0;U=(ca(ba,aa)|0)+$|0;_=x+U|0;do{if((c[o>>2]|0)==0){da=_}else{if((c[e+19460+(g<<2)>>2]|0)==0){da=_;break}da=x+((c[(c[e+9856>>2]|0)+32>>2]|0)+U)|0}}while(0);if(T){T=aa&1;ea=(((T|0)!=0&(aa|0)<4)<<31>>31)+aa|0;fa=q-1+T|0}else{ea=aa;fa=q}q=e+19220|0;aa=(u|0)==0;u=c[e+136>>2]|0;do{if((a[q]|0)==0&aa){if((u|0)<13|(fa|0)<23){s=92;break}T=c[e+14116>>2]|0;U=T<<1;if(($-T|0)>>>0>(-8-(Y&3)+u-U|0)>>>0){s=92;break}if((ea-(T<<n)|0)>>>0>(fa-(X&3)-(U+8<<n)|0)>>>0){s=92}else{ga=da;ha=T;ia=ba}}else{s=92}}while(0);if((s|0)==92){s=e+14116|0;T=c[s>>2]|0;U=da+(ca((ba<<n)+1|0,-T|0)|0)|0;da=e+9944|0;x=(T<<1)+9|0;Ve[c[e+11540>>2]&127](c[da>>2]|0,U,ba,ba,x,x<<n,$-T|0,ea-(T<<n)|0,u,fa);fa=c[da>>2]|0;do{if((a[q]|0)!=0){da=c[s>>2]|0;if(((da<<1)+9|0)>0){ja=0;ka=fa;la=da}else{break}while(1){if(((la<<1)+9|0)>0){da=0;while(1){u=ka+da|0;a[u]=(((d[u]|0)+384|0)>>>1)+128;u=da+1|0;T=c[s>>2]|0;if((u|0)<((T<<1)+9|0)){da=u}else{ma=T;break}}}else{ma=la}da=ja+1|0;if((da|0)<((ma<<1)+9|0)){ja=da;ka=ka+(c[Z>>2]<<n)|0;la=ma}else{break}}}}while(0);ma=c[s>>2]|0;b:do{if(aa){na=ma}else{if(((ma<<1)+9|0)<=0){na=ma;break}la=e+19460+(g<<2)|0;ka=0;ja=fa;q=ma;while(1){if((c[o>>2]|0)==0){oa=(ka<<n)+ea-(q<<n)&1}else{oa=c[la>>2]|0}if(((q<<1)+9|0)>0){da=0;while(1){T=ja+da|0;a[T]=a[(d[T]|0)+(w+(oa<<8))|0]|0;T=da+1|0;u=c[s>>2]|0;if((T|0)<((u<<1)+9|0)){da=T}else{pa=u;break}}}else{pa=q}da=ka+1|0;if((da|0)>=((pa<<1)+9|0)){na=pa;break b}ka=da;ja=ja+(c[Z>>2]<<n)|0;q=pa}}}while(0);pa=c[Z>>2]|0;ga=fa+(ca((pa<<n)+1|0,na)|0)|0;ha=na;ia=pa}if((ha|0)==0){ha=Y>>>1&1|X&2;if((c[e+19216>>2]|0)==0){mf[c[e+11348+(ha<<2)>>2]&2047]((c[e+12544>>2]|0)+W|0,ga,ia,8);i=j;return}else{mf[c[e+11476+(ha<<2)>>2]&2047]((c[e+12544>>2]|0)+W|0,ga,ia,8);i=j;return}}else{ha=X<<2&12|Y&3;if((h|0)==0){mf[c[e+15404+(ha<<2)>>2]&2047]((c[e+12544>>2]|0)+W|0,ga,ia<<n,c[e+19216>>2]|0);i=j;return}else{mf[c[e+15468+(ha<<2)>>2]&2047]((c[e+12544>>2]|0)+W|0,ga,ia<<n,c[e+19216>>2]|0);i=j;return}}}function n7a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=a[(c[b+19400>>2]|0)+(c[b+12496>>2]|0)|0]|0;m=l&255;n=l<<24>>24!=0;l=n?1:4;o=b+140|0;p=c[o>>2]>>1;if((c[b+60>>2]&8192|0)!=0){i=h;return}q=c[b+11744+(e<<5)>>2]|0;c[j>>2]=((q&3|0)==3)+q>>1;q=c[b+11744+(e<<5)+4>>2]|0;if(n){c[k>>2]=(c[264488+((q&15)<<2)>>2]|0)+(q>>4<<3)}else{c[k>>2]=((q&3|0)==3)+q>>1}q=c[b+11744+(e<<5)+8>>2]|0;c[j+4>>2]=((q&3|0)==3)+q>>1;q=c[b+11744+(e<<5)+12>>2]|0;if(n){c[k+4>>2]=(c[264488+((q&15)<<2)>>2]|0)+(q>>4<<3)}else{c[k+4>>2]=((q&3|0)==3)+q>>1}q=c[b+11744+(f<<5)+16>>2]|0;c[j+8>>2]=((q&3|0)==3)+q>>1;q=c[b+11744+(f<<5)+20>>2]|0;if(n){c[k+8>>2]=(c[264488+((q&15)<<2)>>2]|0)+(q>>4<<3)}else{c[k+8>>2]=((q&3|0)==3)+q>>1}q=c[b+11744+(f<<5)+24>>2]|0;c[j+12>>2]=((q&3|0)==3)+q>>1;q=c[b+11744+(f<<5)+28>>2]|0;if(n){c[k+12>>2]=(c[264488+((q&15)<<2)>>2]|0)+(q>>4<<3)}else{c[k+12>>2]=((q&3|0)==3)+q>>1}q=b+152|0;r=b+12476|0;s=b+12480|0;t=b+4|0;u=(e|0)==0;e=b+956|0;v=b+960|0;w=b+16632|0;x=b+19200|0;y=b+11540|0;z=b+9944|0;A=5<<m;B=b+136|0;C=(g|0)==0;g=b+19216|0;D=b+15536|0;E=b+12548|0;F=b+12552|0;G=b+15304|0;H=b+15548|0;I=b+15320|0;J=b+3180|0;K=b+3184|0;L=b+18680|0;M=b+19208|0;b=(f|0)==0;f=0;N=p;while(1){p=f<<2&4;O=(f&2|0)!=0;if(O){P=ca(c[q>>2]|0,l)|0}else{P=0}Q=P+p|0;R=j+(f<<2)|0;S=c[R>>2]|0;T=(c[r>>2]<<3|p)+(S>>2)|0;p=k+(f<<2)|0;U=c[p>>2]|0;V=(c[s>>2]<<3|(O?l:0))+(U>>2)|0;O=c[t>>2]|0;W=c[O+128>>2]>>1;if((T|0)<-8){X=-8}else{X=(T|0)>(W|0)?W:T}T=c[O+132>>2]>>1;if((V|0)<-8){Y=-8}else{Y=(V|0)>(T|0)?T:V}if((f|0)<2){if(u){Z=15}else{_=J;$=K;aa=L;ba=M}}else{if(b){Z=15}else{_=J;$=K;aa=L;ba=M}}if((Z|0)==15){Z=0;_=e;$=v;aa=w;ba=x}V=c[_>>2]|0;T=c[ba>>2]|0;if((V|0)==0){Z=34;break}O=c[q>>2]|0;W=(ca(O,Y)|0)+X|0;da=V+W|0;V=(c[$>>2]|0)+W|0;c[R>>2]=S<<1&6;c[p>>2]=U<<1&6;if(n){U=Y&1;if((U|0)==0){ea=(c[o>>2]>>1)-1|0}else{ea=N}fa=(((U|0)!=0&(Y|0)<2)<<31>>31)+Y|0;ga=ea}else{fa=Y;ga=N}U=(T|0)!=0;T=c[B>>2]|0;do{if(U|(T|0)<10|(ga|0)<(A|0)){Z=24}else{if(X>>>0>((T>>1)-5|0)>>>0){Z=24;break}if(fa>>>0>(ga-A|0)>>>0){Z=24}else{ha=da;ia=V}}}while(0);do{if((Z|0)==24){Z=0;Ve[c[y>>2]&127](c[z>>2]|0,da,O,O,5,A,X,fa,T>>1,ga);S=c[q>>2]|0;Ve[c[y>>2]&127]((c[z>>2]|0)+16|0,V,S,S,5,A,X,fa,c[B>>2]>>1,ga);S=c[z>>2]|0;W=S+16|0;if(U){ja=0;ka=S;la=W}else{ha=S;ia=W;break}while(1){ma=(ja<<m)+fa&1;a[ka]=a[(d[ka]|0)+(aa+(ma<<8))|0]|0;a[la]=a[(d[la]|0)+(aa+(ma<<8))|0]|0;na=ka+1|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=la+1|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=ka+2|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=la+2|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=ka+3|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=la+3|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=ka+4|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;na=la+4|0;a[na]=a[(d[na]|0)+(aa+(ma<<8))|0]|0;ma=c[q>>2]<<m;na=ja+1|0;if((na|0)<5){ja=na;ka=ka+ma|0;la=la+ma|0}else{ha=S;ia=W;break}}}}while(0);U=(c[g>>2]|0)!=0;do{if(C){if(U){V=c[R>>2]|0;T=c[p>>2]|0;_e[c[D>>2]&511]((c[E>>2]|0)+Q|0,ha,c[q>>2]<<m,4,V,T);_e[c[D>>2]&511]((c[F>>2]|0)+Q|0,ia,c[q>>2]<<m,4,V,T);break}else{T=c[R>>2]|0;V=c[p>>2]|0;_e[c[G>>2]&511]((c[E>>2]|0)+Q|0,ha,c[q>>2]<<m,4,T,V);_e[c[G>>2]&511]((c[F>>2]|0)+Q|0,ia,c[q>>2]<<m,4,T,V);break}}else{if(U){V=c[R>>2]|0;T=c[p>>2]|0;_e[c[H>>2]&511]((c[E>>2]|0)+Q|0,ha,c[q>>2]<<m,4,V,T);_e[c[H>>2]&511]((c[F>>2]|0)+Q|0,ia,c[q>>2]<<m,4,V,T);break}else{T=c[R>>2]|0;V=c[p>>2]|0;_e[c[I>>2]&511]((c[E>>2]|0)+Q|0,ha,c[q>>2]<<m,4,T,V);_e[c[I>>2]&511]((c[F>>2]|0)+Q|0,ia,c[q>>2]<<m,4,T,V);break}}}while(0);Q=f+1|0;if((Q|0)<4){f=Q;N=ga}else{Z=34;break}}if((Z|0)==34){i=h;return}}function o7a(d,e,f,g,h,i,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;l=c[d+128>>2]|0;m=c[d+12496+(e<<2)>>2]|0;if((c[d+12488>>2]|0)!=0){n=d+9148|0;o=c[n>>2]|0;b[o+(m<<2)>>1]=0;c[d+11744+(e<<3)>>2]=0;b[o+(m<<2)+2>>1]=0;c[d+11744+(e<<3)+4>>2]=0;o=c[d+9152>>2]|0;b[o+(m<<2)>>1]=0;b[o+(m<<2)+2>>1]=0;if((h|0)!=1){return}p=m+1|0;q=c[n>>2]|0;b[q+(p<<2)>>1]=0;b[q+(p<<2)+2>>1]=0;n=m+l|0;b[q+(n<<2)>>1]=0;b[q+(n<<2)+2>>1]=0;r=n+1|0;b[q+(r<<2)>>1]=0;b[q+(r<<2)+2>>1]=0;q=c[d+12476>>2]|0;s=c[d+19600>>2]|0;b[s+(q<<2)+2>>1]=0;b[s+(q<<2)>>1]=0;b[o+(p<<2)>>1]=0;b[o+(p<<2)+2>>1]=0;b[o+(n<<2)>>1]=0;b[o+(n<<2)+2>>1]=0;b[o+(r<<2)>>1]=0;b[o+(r<<2)+2>>1]=0;return}if((e|0)==0){t=1}else{t=(e|0)==1?1:-1}r=c[d+12476>>2]|0;if((r|0)==0){if((e|0)==3|(e|0)==1){u=8}else{v=0;w=0;x=0;y=0}}else{u=8}do{if((u|0)==8){o=c[d+19400>>2]|0;n=m-1|0;do{if((a[o+m|0]|0)==0){if((a[o+n|0]|0)==0){u=10;break}p=c[d+9148+(k<<2)>>2]|0;q=(ca(t,l)|0)+n|0;z=(b[p+(n<<2)+2>>1]|0)+1+(b[p+(q<<2)+2>>1]|0)>>1;A=(b[p+(n<<2)>>1]|0)+1+(b[p+(q<<2)>>1]|0)>>1}else{u=10}}while(0);if((u|0)==10){o=c[d+9148+(k<<2)>>2]|0;z=b[o+(n<<2)+2>>1]|0;A=b[o+(n<<2)>>1]|0}if((e&1|0)!=0){v=z;w=A;x=1;y=r;break}o=(a[(c[d+19592>>2]|0)+(r-1)|0]|0)==0;v=o?z:0;w=o?A:0;x=o&1;y=r}}while(0);do{if(e>>>0<2>>>0){u=16}else{if((a[(c[d+19400>>2]|0)+m|0]|0)!=0){u=16;break}r=c[d+12500>>2]|0;A=c[d+9148+(k<<2)>>2]|0;z=c[d+12496>>2]|0;B=1;C=1;D=b[A+(z<<2)>>1]|0;E=b[A+(z<<2)+2>>1]|0;F=b[A+(r<<2)>>1]|0;G=b[A+(r<<2)+2>>1]|0}}while(0);do{if((u|0)==16){if((c[d+14084>>2]|0)!=0){B=0;C=0;D=0;E=0;F=0;G=0;break}r=c[d+124>>2]|0;A=c[d+19592>>2]|0;do{if((a[A+(y-r)|0]|0)==0){z=e|2;t=c[d+12496+(z<<2)>>2]|0;o=l<<1;q=c[d+19400>>2]|0;p=(a[q+(t-o)|0]|0)==0;if(p){H=z;I=t}else{t=(a[q+m|0]|0)==0?z:e&3;H=t;I=c[d+12496+(t<<2)>>2]|0}t=I-o|0;z=c[d+9148+(k<<2)>>2]|0;s=b[z+(t<<2)>>1]|0;J=b[z+(t<<2)+2>>1]|0;if(p){K=1;L=s;M=J;break}if((a[q+m|0]|0)!=0){K=1;L=s;M=J;break}q=(c[d+12496+((H^2)<<2)>>2]|0)-o|0;K=1;L=s+1+(b[z+(q<<2)>>1]|0)>>1;M=J+1+(b[z+(q<<2)+2>>1]|0)>>1}else{K=0;L=0;M=0}}while(0);n=c[d+116>>2]|0;if((n|0)<=1){B=0;C=K;D=0;E=0;F=L;G=M;break}if((a[A+(y+1-r)|0]|0)!=0){B=0;C=K;D=0;E=0;F=L;G=M;break}q=c[d+12504>>2]|0;z=l<<1;J=c[d+19400>>2]|0;s=(a[J+(q-z+2)|0]|0)==0;if(s){N=0;O=q}else{q=(a[J+m|0]|0)==0?2:e&2;N=q^2;O=c[d+12496+(q<<2)>>2]|0}q=O-z+2|0;o=c[d+9148+(k<<2)>>2]|0;p=b[o+(q<<2)>>1]|0;t=b[o+(q<<2)+2>>1]|0;do{if(s){P=p;Q=t}else{if((a[J+m|0]|0)!=0){P=p;Q=t;break}q=(c[d+12496+(N<<2)>>2]|0)-z+2|0;P=p+1+(b[o+(q<<2)>>1]|0)>>1;Q=t+1+(b[o+(q<<2)+2>>1]|0)>>1}}while(0);if((y|0)!=(n-1|0)){B=1;C=K;D=P;E=Q;F=L;G=M;break}if((a[A+(y-1-r)|0]|0)!=0){B=0;C=K;D=P;E=Q;F=L;G=M;break}t=c[d+12508>>2]|0;p=(a[J+(t-z-2)|0]|0)==0;if(p){R=t}else{R=c[d+12496+(((a[J+m|0]|0)==0?3:e|1)<<2)>>2]|0}t=R-z-2|0;s=b[o+(t<<2)>>1]|0;q=b[o+(t<<2)+2>>1]|0;if(p){B=1;C=K;D=s;E=q;F=L;G=M;break}if((a[J+m|0]|0)!=0){B=1;C=K;D=s;E=q;F=L;G=M;break}p=(c[d+12500>>2]|0)-z-2|0;B=1;C=K;D=s+1+(b[o+(p<<2)>>1]|0)>>1;E=q+1+(b[o+(p<<2)+2>>1]|0)>>1;F=L;G=M}}while(0);M=C+x+B|0;do{if((y|0)==0){if((e|0)==3|(e|0)==1){S=v;T=w;break}S=0;T=0}else{S=v;T=w}}while(0);w=(a[(c[d+19400>>2]|0)+m|0]|0)==0;do{if((c[d+14084>>2]|0)==0){if(w){U=G;V=F;W=E;X=D;u=45}else{Y=G;Z=F;_=E;$=D;u=60}}else{if(!w){Y=0;Z=0;_=0;$=0;u=60;break}v=(e&2|0)==0;U=v?0:G;V=v?0:F;W=v?0:E;X=v?0:D;u=45}}while(0);do{if((u|0)==45){if((c[d+116>>2]|0)==1){aa=U;ba=V;break}if((M|0)<=1){if((M|0)==0){aa=0;ba=0;break}if((x|0)!=0){aa=S;ba=T;break}D=(C|0)==0;aa=D?W:U;ba=D?X:V;break}do{if((T|0)>(V|0)){if((X|0)<=(V|0)){da=V;break}da=(X|0)>(T|0)?T:X}else{if((V|0)<=(X|0)){da=V;break}da=(X|0)>(T|0)?X:T}}while(0);if((S|0)>(U|0)){if((W|0)<=(U|0)){aa=U;ba=da;break}aa=(W|0)>(S|0)?S:W;ba=da;break}else{if((U|0)<=(W|0)){aa=U;ba=da;break}aa=(W|0)>(S|0)?W:S;ba=da;break}}else if((u|0)==60){o=(x|0)!=0;if(o){ea=S>>>2&1}else{ea=0}z=(C|0)!=0;if(z){fa=Y>>>2&1}else{fa=0}if((B|0)==0){ga=0}else{ga=_>>>2&1}J=fa+ea+ga|0;r=M-J|0;if((M|0)==2){A=(ea|0)!=0;if((r|0)<(J|0)){n=A&o;aa=n?S:Y;ba=n?T:Z;break}if(!(A|o^1)){aa=S;ba=T;break}A=(fa|0)!=0|z^1;aa=A?_:Y;ba=A?$:Z;break}else if((M|0)==1){if(o){aa=S;ba=T;break}aa=z?Y:_;ba=z?Z:$;break}else if((M|0)==3){if(!((r|0)==3|(J|0)==3)){z=(ea|0)!=0;if((r|0)<(J|0)){aa=z?S:Y;ba=z?T:Z;break}else{aa=z?Y:S;ba=z?Z:T;break}}do{if((T|0)>(Z|0)){if(($|0)<=(Z|0)){ha=Z;break}ha=($|0)>(T|0)?T:$}else{if((Z|0)<=($|0)){ha=Z;break}ha=($|0)>(T|0)?$:T}}while(0);if((S|0)>(Y|0)){if((_|0)<=(Y|0)){aa=Y;ba=ha;break}aa=(_|0)>(S|0)?S:_;ba=ha;break}else{if((Y|0)<=(_|0)){aa=Y;ba=ha;break}aa=(_|0)>(S|0)?_:S;ba=ha;break}}else{aa=0;ba=0;break}}}while(0);ha=(i+f+ba&(i<<1)+65535)-i&65535;i=d+9148+(k<<2)|0;b[(c[i>>2]|0)+(m<<2)>>1]=ha;ba=ha<<16>>16;c[d+11744+(k<<5)+(e<<3)>>2]=ba;ha=(j+g+aa&(j<<1)+65535)-j&65535;b[(c[i>>2]|0)+(m<<2)+2>>1]=ha;j=ha<<16>>16;c[d+11744+(k<<5)+(e<<3)+4>>2]=j;if((h|0)==1){ha=c[i>>2]|0;aa=ha+(m<<2)|0;g=b[aa>>1]|0;f=m+1|0;b[ha+(f<<2)>>1]=g;S=ha+(m<<2)+2|0;_=b[S>>1]|0;b[ha+(f<<2)+2>>1]=_;f=m+l|0;b[ha+(f<<2)>>1]=g;b[ha+(f<<2)+2>>1]=_;_=f+1|0;b[ha+(_<<2)>>1]=b[aa>>1]|0;b[ha+(_<<2)+2>>1]=b[S>>1]|0;return}else if((h|0)==2){h=c[i>>2]|0;i=m+1|0;b[h+(i<<2)>>1]=b[h+(m<<2)>>1]|0;b[h+(i<<2)+2>>1]=b[h+(m<<2)+2>>1]|0;m=e+1|0;c[d+11744+(k<<5)+(m<<3)>>2]=ba;c[d+11744+(k<<5)+(m<<3)+4>>2]=j;return}else{return}}function p7a(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;k=c[e+19480>>2]|0;if((k|0)==2){l=e+15720|0;m=e+15724|0;n=e+16056|0;r7a(e,0,c[g>>2]|0,c[h>>2]|0,1,c[l>>2]|0,c[m>>2]|0,c[n>>2]|0,c[j>>2]|0,0);r7a(e,0,c[g+4>>2]|0,c[h+4>>2]|0,1,c[l>>2]|0,c[m>>2]|0,c[n>>2]|0,c[j+4>>2]|0,1);return}else if((k|0)==0){n=e+15720|0;m=e+15724|0;l=e+16056|0;r7a(e,f,c[g+4>>2]|0,c[h+4>>2]|0,i,c[n>>2]|0,c[m>>2]|0,c[l>>2]|0,c[j+4>>2]|0,1);if((f|0)!=3&(i|0)==0){return}r7a(e,0,c[g>>2]|0,c[h>>2]|0,1,c[n>>2]|0,c[m>>2]|0,c[l>>2]|0,0,0);return}else if((k|0)==3){k=ca(c[e+12480>>2]|0,c[e+124>>2]|0)|0;if((c[(c[e+4712>>2]|0)+((c[e+12476>>2]|0)+k+(c[e+19472>>2]|0)<<2)>>2]|0)==1){c[e+11748>>2]=0;c[e+11744>>2]=0;c[e+11780>>2]=0;c[e+11776>>2]=0;o=0;p=0;q=0;r=0;s=0;t=e+19468|0}else{k=e+19468|0;l=c[k>>2]|0;m=l+(c[e+12496>>2]|0)|0;n=c[e+4704>>2]|0;u=b[n+(m<<2)>>1]|0;v=b[e+16070>>1]|0;w=ca(v,u)|0;if((c[e+13924>>2]|0)==0){x=w+255>>9<<1;c[e+11744>>2]=x;y=b[n+(m<<2)+2>>1]|0;z=(ca(v,y)|0)+255>>9<<1;c[e+11748>>2]=z;A=v-256|0;B=(ca(A,u)|0)+255>>9<<1;c[e+11776>>2]=B;C=(ca(A,y)|0)+255>>9<<1;D=z&65535;E=x&65535;F=B&65535}else{B=w+128>>8;c[e+11744>>2]=B;w=b[n+(m<<2)+2>>1]|0;n=(ca(v,w)|0)+128>>8;c[e+11748>>2]=n;x=v-256|0;v=(ca(x,u)|0)+128>>8;c[e+11776>>2]=v;C=(ca(x,w)|0)+128>>8;D=n&65535;E=B&65535;F=v&65535}c[e+11780>>2]=C;v=c[e+19420>>2]|0;o=((d[v+((c[e+12500>>2]|0)+l)|0]|0)+(d[v+m|0]|0)+(d[v+((c[e+12504>>2]|0)+l)|0]|0)+(d[v+((c[e+12508>>2]|0)+l)|0]|0)|0)>2|0;p=E;q=D;r=F;s=C&65535;t=k}k=c[e+19456>>2]^o;c[e+19464>>2]=k;c[e+19460>>2]=k;k=e+11744|0;C=e+9148|0;F=e+11748|0;D=e+11776|0;E=e+9152|0;l=e+11780|0;v=o&255;o=e+19408|0;m=e+19412|0;B=0;n=p;p=q;q=r;r=s;while(1){s=e+12496+(B<<2)|0;w=(c[t>>2]|0)+(c[s>>2]|0)|0;x=c[C>>2]|0;b[x+(w<<2)>>1]=n;b[x+(w<<2)+2>>1]=p;x=c[E>>2]|0;b[x+(w<<2)>>1]=q;b[x+(w<<2)+2>>1]=r;a[(c[o>>2]|0)+w|0]=v;a[(c[m>>2]|0)+((c[t>>2]|0)+(c[s>>2]|0))|0]=v;s=B+1|0;if((s|0)>=4){break}B=s;n=c[k>>2]&65535;p=c[F>>2]&65535;q=c[D>>2]&65535;r=c[l>>2]&65535}return}else{l=e+15720|0;r=e+15724|0;D=e+16056|0;r7a(e,f,c[g>>2]|0,c[h>>2]|0,i,c[l>>2]|0,c[r>>2]|0,c[D>>2]|0,c[j>>2]|0,0);if((f|0)!=3&(i|0)==0){return}r7a(e,0,c[g+4>>2]|0,c[h+4>>2]|0,1,c[l>>2]|0,c[r>>2]|0,c[D>>2]|0,0,1);return}}function q7a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=c[e+19456>>2]|0;n=e+19428|0;o=c[n>>2]|0;p=c[e+140>>2]>>o;q=(o|0)==0;do{if(q){if((c[e+952>>2]|0)!=0){break}i=g;return}}while(0);if((c[e+60>>2]&8192|0)!=0){i=g;return}r=e+19468|0;s=e+19408+(f<<2)|0;t=c[e+11744+(f<<5)>>2]|0;c[h>>2]=t;u=c[e+11744+(f<<5)+4>>2]|0;c[j>>2]=u;v=c[e+12496>>2]|0;w=c[e+16056>>2]|0;x=a[w+v|0]|0;c[k>>2]=x&255;if(q){y=0}else{z=d[(c[s>>2]|0)+((c[r>>2]|0)+v)|0]|0;c[l>>2]=z;y=z}z=c[e+11744+(f<<5)+8>>2]|0;c[h+4>>2]=z;A=c[e+11744+(f<<5)+12>>2]|0;c[j+4>>2]=A;B=c[e+12500>>2]|0;C=a[w+B|0]|0;c[k+4>>2]=C&255;if(q){D=0}else{E=d[(c[s>>2]|0)+((c[r>>2]|0)+B)|0]|0;c[l+4>>2]=E;D=E}E=c[e+11744+(f<<5)+16>>2]|0;c[h+8>>2]=E;B=c[e+11744+(f<<5)+20>>2]|0;c[j+8>>2]=B;F=c[e+12504>>2]|0;G=a[w+F|0]|0;c[k+8>>2]=G&255;if(q){H=0}else{I=d[(c[s>>2]|0)+((c[r>>2]|0)+F)|0]|0;c[l+8>>2]=I;H=I}I=c[e+11744+(f<<5)+24>>2]|0;c[h+12>>2]=I;F=c[e+11744+(f<<5)+28>>2]|0;c[j+12>>2]=F;J=c[e+12508>>2]|0;K=a[w+J|0]|0;c[k+12>>2]=K&255;do{if(q){L=8}else{w=d[(c[s>>2]|0)+((c[r>>2]|0)+J)|0]|0;c[l+12>>2]=w;if((c[e+19444>>2]|0)==0){L=8;break}M=(D+y+H+w|0)>2;N=M&1;O=((w|0)!=(N|0))<<3|(y|0)!=(N|0)|((H|0)!=(N|0))<<2|((D|0)!=(N|0))<<1;do{if((O|0)==0){N=(E|0)<(I|0);do{if((t|0)<(z|0)){if(N){P=((z|0)>(I|0)?I:z)+((t|0)>(E|0)?t:E)|0;break}else{P=((t|0)>(I|0)?t:I)+((z|0)>(E|0)?E:z)|0;break}}else{if(N){P=((t|0)>(I|0)?I:t)+((z|0)>(E|0)?z:E)|0;break}else{P=((z|0)>(I|0)?z:I)+((t|0)>(E|0)?E:t)|0;break}}}while(0);N=(P|0)/2|0;w=(B|0)<(F|0);do{if((u|0)<(A|0)){if(w){Q=((A|0)>(F|0)?F:A)+((u|0)>(B|0)?u:B)|0;break}else{Q=((u|0)>(F|0)?u:F)+((A|0)>(B|0)?B:A)|0;break}}else{if(w){Q=((u|0)>(F|0)?F:u)+((A|0)>(B|0)?A:B)|0;break}else{Q=((A|0)>(F|0)?A:F)+((u|0)>(B|0)?B:u)|0;break}}}while(0);R=(Q|0)/2|0;S=N}else{if((278>>>(O>>>0)&1|0)==0){if((5736>>>(O>>>0)&1|0)==0){R=0;S=0;break}else{T=0}while(1){if((T|0)>=3){U=0;break}if((c[l+(T<<2)>>2]|0)==0){U=T;break}else{T=T+1|0}}N=U;while(1){w=N+1|0;if((w|0)>=4){V=0;break}if((c[l+(w<<2)>>2]|0)==0){V=w;break}else{N=w}}R=((c[j+(V<<2)>>2]|0)+(c[j+(U<<2)>>2]|0)|0)/2|0;S=((c[h+(V<<2)>>2]|0)+(c[h+(U<<2)>>2]|0)|0)/2|0;break}if((O|0)==8){do{if((t|0)>(z|0)){if((E|0)<=(z|0)){W=z;break}W=(E|0)>(t|0)?t:E}else{if((z|0)<=(E|0)){W=z;break}W=(E|0)>(t|0)?E:t}}while(0);if((u|0)>(A|0)){if((B|0)<=(A|0)){R=A;S=W;break}R=(B|0)>(u|0)?u:B;S=W;break}else{if((A|0)<=(B|0)){R=A;S=W;break}R=(B|0)>(u|0)?B:u;S=W;break}}else if((O|0)==2){do{if((t|0)>(E|0)){if((I|0)<=(E|0)){X=E;break}X=(I|0)>(t|0)?t:I}else{if((E|0)<=(I|0)){X=E;break}X=(I|0)>(t|0)?I:t}}while(0);if((u|0)>(B|0)){if((F|0)<=(B|0)){R=B;S=X;break}R=(F|0)>(u|0)?u:F;S=X;break}else{if((B|0)<=(F|0)){R=B;S=X;break}R=(F|0)>(u|0)?F:u;S=X;break}}else if((O|0)==1){do{if((z|0)>(E|0)){if((I|0)<=(E|0)){Y=E;break}Y=(I|0)>(z|0)?z:I}else{if((E|0)<=(I|0)){Y=E;break}Y=(I|0)>(z|0)?I:z}}while(0);if((A|0)>(B|0)){if((F|0)<=(B|0)){R=B;S=Y;break}R=(F|0)>(A|0)?A:F;S=Y;break}else{if((B|0)<=(F|0)){R=B;S=Y;break}R=(F|0)>(A|0)?F:A;S=Y;break}}else if((O|0)==4){do{if((t|0)>(z|0)){if((I|0)<=(z|0)){Z=z;break}Z=(I|0)>(t|0)?t:I}else{if((z|0)<=(I|0)){Z=z;break}Z=(I|0)>(t|0)?I:t}}while(0);if((u|0)>(A|0)){if((F|0)<=(A|0)){R=A;S=Z;break}R=(F|0)>(u|0)?u:F;S=Z;break}else{if((A|0)<=(F|0)){R=A;S=Z;break}R=(F|0)>(u|0)?F:u;S=Z;break}}else{R=0;S=0;break}}}while(0);if(!M){_=m;$=R;aa=S;break}_=(m|0)==0|0;$=R;aa=S}}while(0);if((L|0)==8){S=(G<<24>>24!=0)<<2|(K<<24>>24!=0)<<3|(C<<24>>24!=0)<<1|x<<24>>24!=0;do{if((S|0)==0){x=(E|0)<(I|0);do{if((t|0)<(z|0)){if(x){ba=((z|0)>(I|0)?I:z)+((t|0)>(E|0)?t:E)|0;break}else{ba=((t|0)>(I|0)?t:I)+((z|0)>(E|0)?E:z)|0;break}}else{if(x){ba=((t|0)>(I|0)?I:t)+((z|0)>(E|0)?z:E)|0;break}else{ba=((z|0)>(I|0)?z:I)+((t|0)>(E|0)?E:t)|0;break}}}while(0);x=(ba|0)/2|0;M=(B|0)<(F|0);do{if((u|0)<(A|0)){if(M){da=((A|0)>(F|0)?F:A)+((u|0)>(B|0)?u:B)|0;break}else{da=((u|0)>(F|0)?u:F)+((A|0)>(B|0)?B:A)|0;break}}else{if(M){da=((u|0)>(F|0)?F:u)+((A|0)>(B|0)?A:B)|0;break}else{da=((A|0)>(F|0)?A:F)+((u|0)>(B|0)?B:u)|0;break}}}while(0);ea=(da|0)/2|0;fa=x}else{if((278>>>(S>>>0)&1|0)==0){if((5736>>>(S>>>0)&1|0)==0){M=(c[r>>2]|0)+v|0;C=c[e+9152>>2]|0;b[C+(M<<2)>>1]=0;b[C+(M<<2)+2>>1]=0;M=c[e+12476>>2]|0;C=c[e+19600>>2]|0;b[C+(M<<2)+2>>1]=0;b[C+(M<<2)>>1]=0;i=g;return}else{ga=0}while(1){if((ga|0)>=3){ha=0;break}if((c[k+(ga<<2)>>2]|0)==0){ha=ga;break}else{ga=ga+1|0}}x=ha;while(1){M=x+1|0;if((M|0)>=4){ia=0;break}if((c[k+(M<<2)>>2]|0)==0){ia=M;break}else{x=M}}ea=((c[j+(ia<<2)>>2]|0)+(c[j+(ha<<2)>>2]|0)|0)/2|0;fa=((c[h+(ia<<2)>>2]|0)+(c[h+(ha<<2)>>2]|0)|0)/2|0;break}if((S|0)==1){do{if((z|0)>(E|0)){if((I|0)<=(E|0)){ja=E;break}ja=(I|0)>(z|0)?z:I}else{if((E|0)<=(I|0)){ja=E;break}ja=(I|0)>(z|0)?I:z}}while(0);if((A|0)>(B|0)){if((F|0)<=(B|0)){ea=B;fa=ja;break}ea=(F|0)>(A|0)?A:F;fa=ja;break}else{if((B|0)<=(F|0)){ea=B;fa=ja;break}ea=(F|0)>(A|0)?F:A;fa=ja;break}}else if((S|0)==2){do{if((t|0)>(E|0)){if((I|0)<=(E|0)){ka=E;break}ka=(I|0)>(t|0)?t:I}else{if((E|0)<=(I|0)){ka=E;break}ka=(I|0)>(t|0)?I:t}}while(0);if((u|0)>(B|0)){if((F|0)<=(B|0)){ea=B;fa=ka;break}ea=(F|0)>(u|0)?u:F;fa=ka;break}else{if((B|0)<=(F|0)){ea=B;fa=ka;break}ea=(F|0)>(u|0)?F:u;fa=ka;break}}else if((S|0)==4){do{if((t|0)>(z|0)){if((I|0)<=(z|0)){la=z;break}la=(I|0)>(t|0)?t:I}else{if((z|0)<=(I|0)){la=z;break}la=(I|0)>(t|0)?I:t}}while(0);if((u|0)>(A|0)){if((F|0)<=(A|0)){ea=A;fa=la;break}ea=(F|0)>(u|0)?u:F;fa=la;break}else{if((A|0)<=(F|0)){ea=A;fa=la;break}ea=(F|0)>(u|0)?F:u;fa=la;break}}else if((S|0)==8){do{if((t|0)>(z|0)){if((E|0)<=(z|0)){ma=z;break}ma=(E|0)>(t|0)?t:E}else{if((z|0)<=(E|0)){ma=z;break}ma=(E|0)>(t|0)?E:t}}while(0);if((u|0)>(A|0)){if((B|0)<=(A|0)){ea=A;fa=ma;break}ea=(B|0)>(u|0)?u:B;fa=ma;break}else{if((A|0)<=(B|0)){ea=A;fa=ma;break}ea=(B|0)>(u|0)?B:u;fa=ma;break}}else{ea=0;fa=0;break}}}while(0);_=c[e+19448>>2]|0;$=ea;aa=fa}do{if((o|0)!=0&(_|0)==1&(m|0)==1){if((c[e+952>>2]|0)!=0){break}i=g;return}}while(0);o=(c[r>>2]|0)+v|0;v=c[e+9152>>2]|0;b[v+(o<<2)>>1]=aa;b[v+(o<<2)+2>>1]=$;o=((aa&3|0)==3)+aa>>1;aa=(($&3|0)==3)+$>>1;$=c[e+12476>>2]|0;v=c[e+19600>>2]|0;b[v+($<<2)>>1]=o;b[v+($<<2)+2>>1]=aa;if((c[e+15680>>2]|0)==0){na=aa;oa=o}else{v=o&1;r=aa&1;na=((aa|0)<0?r:-r|0)+aa|0;oa=((o|0)<0?v:-v|0)+o|0}o=(m|0)==(_|0);if(o){pa=na}else{pa=(-(_<<2)|2)+na|0}na=($<<3)+(oa>>2)|0;$=(c[e+12480>>2]<<3)+(pa>>2)|0;if((c[e+15660>>2]|0)==3){m=c[e+4>>2]|0;v=c[m+128>>2]>>1;if((na|0)<-8){qa=-8}else{qa=(na|0)>(v|0)?v:na}ra=qa;sa=c[m+132>>2]>>1}else{m=c[e+116>>2]<<3;if((na|0)<-8){ta=-8}else{ta=(na|0)>(m|0)?m:na}ra=ta;sa=c[e+120>>2]<<3}if(($|0)<-8){ua=-8}else{ua=($|0)>(sa|0)?sa:$}a:do{if((f|0)==0){do{if(!(q|o)){if((c[e+19436>>2]|0)==0){break}va=e+7628|0;wa=c[e+19204>>2]|0;xa=c[e+19196>>2]|0;ya=e+7632|0;break a}}while(0);va=e+956|0;wa=e+19200|0;xa=e+16632|0;ya=e+960|0}else{va=e+3180|0;wa=e+19208|0;xa=e+18680|0;ya=e+3184|0}}while(0);o=c[va>>2]|0;va=c[wa>>2]|0;if((o|0)==0){KIb(c[e+4>>2]|0,16,2259808,(wa=i,i=i+1|0,i=i+7&-8,c[wa>>2]=0,wa)|0);i=wa;i=g;return}wa=e+152|0;f=c[wa>>2]|0;$=(ca(f,ua)|0)+ra|0;if(q|(_|0)==0){za=$;Aa=$}else{q=c[e+9856>>2]|0;za=(c[q+36>>2]|0)+$|0;Aa=(c[q+40>>2]|0)+$|0}$=o+za|0;za=(c[ya>>2]|0)+Aa|0;Aa=e+19220|0;ya=(va|0)==0;va=c[e+136>>2]|0;do{if((a[Aa]|0)==0&ya){if((va|0)<18|(p|0)<18){L=171;break}if(ra>>>0>((va>>1)-9|0)>>>0){L=171;break}if(ua>>>0>((p>>1)-9|0)>>>0){L=171}else{Ba=$;Ca=za}}else{L=171}}while(0);do{if((L|0)==171){o=e+11540|0;q=e+9944|0;sa=p>>1;Ve[c[o>>2]&127](c[q>>2]|0,$,f,f,9,9,ra,ua,va>>1,sa);ta=c[wa>>2]|0;Ve[c[o>>2]&127]((c[q>>2]|0)+16|0,za,ta,ta,9,9,ra,ua,c[e+136>>2]>>1,sa);sa=c[q>>2]|0;q=sa+16|0;if((a[Aa]|0)!=0){ta=0;o=sa;na=q;while(1){m=0;do{qa=o+m|0;a[qa]=(((d[qa]|0)+384|0)>>>1)+128;qa=na+m|0;a[qa]=(((d[qa]|0)+384|0)>>>1)+128;m=m+1|0;}while((m|0)<9);m=c[wa>>2]|0;qa=ta+1|0;if((qa|0)<9){ta=qa;o=o+m|0;na=na+m|0}else{break}}}if(ya){Ba=sa;Ca=q;break}else{Da=0;Ea=sa;Fa=q}while(1){if((c[n>>2]|0)==0){Ga=Da+ua&1}else{Ga=_}a[Ea]=a[(d[Ea]|0)+(xa+(Ga<<8))|0]|0;a[Fa]=a[(d[Fa]|0)+(xa+(Ga<<8))|0]|0;na=Ea+1|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+1|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+2|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+2|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+3|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+3|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+4|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+4|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+5|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+5|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+6|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+6|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+7|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+7|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Ea+8|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=Fa+8|0;a[na]=a[(d[na]|0)+(xa+(Ga<<8))|0]|0;na=c[wa>>2]|0;o=Da+1|0;if((o|0)<9){Da=o;Ea=Ea+na|0;Fa=Fa+na|0}else{Ba=sa;Ca=q;break}}}}while(0);Fa=oa<<1&6;oa=pa<<1&6;if((c[e+19216>>2]|0)==0){pa=e+15300|0;_e[c[pa>>2]&511](c[e+12548>>2]|0,Ba,c[wa>>2]|0,8,Fa,oa);_e[c[pa>>2]&511](c[e+12552>>2]|0,Ca,c[wa>>2]|0,8,Fa,oa);i=g;return}else{pa=e+15532|0;_e[c[pa>>2]&511](c[e+12548>>2]|0,Ba,c[wa>>2]|0,8,Fa,oa);_e[c[pa>>2]&511](c[e+12552>>2]|0,Ca,c[wa>>2]|0,8,Fa,oa);i=g;return}}function r7a(f,g,h,i,j,k,l,m,n,o){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0;p=a[f+15708|0]|0;if((p<<24>>24|0)==3){q=1}else if((p<<24>>24|0)==4){if((a[f+15709|0]|0)==3){q=1}else{r=3}}else{r=3}if((r|0)==3){q=0}p=1-(c[f+13924>>2]|0)|0;s=h<<p;h=i<<p;i=c[f+128>>2]|0;t=c[f+12496+(g<<2)>>2]|0;if((c[f+12488>>2]|0)!=0){u=f+19468|0;v=(c[u>>2]|0)+t|0;w=f+9148|0;x=c[w>>2]|0;b[x+(v<<2)>>1]=0;c[f+11744+(g<<3)>>2]=0;b[x+(v<<2)+2>>1]=0;c[f+11744+(g<<3)+4>>2]=0;v=c[u>>2]|0;u=v+t|0;x=c[f+9152>>2]|0;b[x+(u<<2)>>1]=0;b[x+(u<<2)+2>>1]=0;if((j|0)==0){return}u=v+(t+1)|0;y=c[w>>2]|0;b[y+(u<<2)>>1]=0;b[y+(u<<2)+2>>1]=0;w=t+i|0;z=v+w|0;b[y+(z<<2)>>1]=0;b[y+(z<<2)+2>>1]=0;A=v+(w+1)|0;b[y+(A<<2)>>1]=0;b[y+(A<<2)+2>>1]=0;y=c[f+12476>>2]|0;v=c[f+19600>>2]|0;b[v+(y<<2)+2>>1]=0;b[v+(y<<2)>>1]=0;b[x+(u<<2)>>1]=0;b[x+(u<<2)+2>>1]=0;b[x+(w<<2)>>1]=0;b[x+(z<<2)+2>>1]=0;b[x+(A<<2)>>1]=0;b[x+(A<<2)+2>>1]=0;return}A=t-1|0;x=f+19468|0;z=c[x>>2]|0;w=z+A|0;u=f+9148+(o<<2)|0;y=c[u>>2]|0;v=y+(w<<2)|0;B=t-i|0;C=z+B|0;D=y+(C<<2)|0;E=(j|0)!=0;do{if(E){j=(c[f+12476>>2]|0)==((c[f+116>>2]|0)-1|0);if((c[f+19428>>2]|0)==0|(q|0)==0){F=j?-1:2;break}else{F=j?-2:2;break}}else{if((g|0)==0){F=(c[f+12476>>2]|0)>0?-1:1;break}else if((g|0)==1){F=(c[f+12476>>2]|0)==((c[f+116>>2]|0)-1|0)?-1:1;break}else if((g|0)==2){F=1;break}else if((g|0)==3){F=-1;break}else{F=0;break}}}while(0);q=F+B|0;F=q+z|0;j=y+(F<<2)|0;G=(g|0)==2;H=(g|0)==3;I=(c[f+14084>>2]|0)==0|G|H;if(I){J=(c[f+116>>2]|0)>1}else{J=0}K=f+12476|0;L=(c[K>>2]|0)!=0;M=(g|0)==1;N=f+19428|0;O=(c[N>>2]|0)==0;do{if(O){P=L|M|H;Q=J;R=I;r=26}else{if(I){S=(a[m+B|0]|0)==0}else{S=0}if(J){T=(a[m+q|0]|0)==0}else{T=0}if(!L){if(!((g|0)==3|(g|0)==1)){P=0;Q=T;R=S;r=26;break}}U=(a[m+A|0]|0)==0;if(S){V=T;W=U;r=27}else{X=T;Y=U;r=28}}}while(0);if((r|0)==26){if(R){V=Q;W=P;r=27}else{X=Q;Y=P;r=28}}do{if((r|0)==27){P=c[f+19408+(o<<2)>>2]|0;Q=d[P+C|0]|0;R=1-Q|0;T=b[D>>1]|0;S=b[y+(C<<2)+2>>1]|0;if(V){Z=W;_=1;$=R;aa=Q;ba=S;da=T;ea=P;r=30}else{fa=R;ga=W;ha=1;ia=Q;ja=S;ka=T;r=31}}else if((r|0)==28){if(!X){fa=0;ga=Y;ha=0;ia=0;ja=0;ka=0;r=31;break}Z=Y;_=0;$=0;aa=0;ba=0;da=0;ea=c[f+19408+(o<<2)>>2]|0;r=30}}while(0);do{if((r|0)==30){Y=d[ea+F|0]|0;X=Y+aa|0;W=1-Y+$|0;V=b[j>>1]|0;C=b[y+(F<<2)+2>>1]|0;if(Z){la=da;ma=ba;na=aa;oa=_;pa=1;qa=W;ra=X;sa=Y;ta=C;ua=V;va=ea;r=33}else{wa=0;xa=0;ya=0;za=X;Aa=W;Ba=da;Ca=ba;Da=aa;Ea=_;Fa=1;Ga=0;Ha=Y;Ia=C;Ja=V}}else if((r|0)==31){if(!ga){wa=0;xa=0;ya=0;za=ia;Aa=fa;Ba=ka;Ca=ja;Da=ia;Ea=ha;Fa=0;Ga=0;Ha=0;Ia=0;Ja=0;break}la=ka;ma=ja;na=ia;oa=ha;pa=0;qa=fa;ra=ia;sa=0;ta=0;ua=0;va=c[f+19408+(o<<2)>>2]|0;r=33}}while(0);if((r|0)==33){ia=d[va+w|0]|0;wa=b[v>>1]|0;xa=b[y+(w<<2)+2>>1]|0;ya=ia;za=ia+ra|0;Aa=qa+1-ia|0;Ba=la;Ca=ma;Da=na;Ea=oa;Fa=pa;Ga=1;Ha=sa;Ia=ta;Ja=ua}do{if(O){r=136}else{if((c[f+19444>>2]|0)==0){Ka=1-(c[f+19448>>2]|0)|0}else{Ka=(Aa|0)>(za|0)?n:1-n|0}if((Ka|0)==0){r=136;break}if(Ea&(Da|0)==0){ua=Ba<<16>>16>>p;ta=(c[f+9992>>2]|0)==3;sa=c[f+19436>>2]|0;do{if(ta){if(!((sa|0)==0&(o|0)==1)){La=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=52;break}pa=c[f+19488>>2]|0;oa=(pa|0)>3?3:pa;pa=e[1267560+(oa<<1)>>1]|0;na=e[1267528+(oa<<1)>>1]|0;ma=e[1267536+(oa<<1)>>1]|0;la=(ua|0)>-1?ua:-ua|0;do{if((la|0)>255){Ma=ua}else{if((la|0)<(e[1267544+(oa<<1)>>1]|0)){Ma=(ca(na,ua)|0)>>8;break}ia=(ca(ma,ua)|0)>>8;if((ua|0)<0){Ma=ia-pa|0;break}else{Ma=ia+pa|0;break}}}while(0);pa=c[f+15720>>2]|0;ma=-pa|0;na=pa-1|0;if((Ma|0)<(ma|0)){Na=ma;break}Na=(Ma|0)>(na|0)?na:Ma}else{na=c[f+19440>>2]|0;La=(na|0)>3?3:na;r=52}}while(0);if((r|0)==52){Na=(ca(e[1266104+((sa^o)*56|0)+(La<<1)>>1]|0,ua)|0)>>8}na=Na<<p&65535;ma=Ca<<16>>16>>p;a:do{if(ta){if(!((sa|0)==0&(o|0)==1)){Oa=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=69;break}pa=c[f+19488>>2]|0;oa=(pa|0)>3?3:pa;pa=e[1267568+(oa<<1)>>1]|0;la=e[1267528+(oa<<1)>>1]|0;ia=e[1267536+(oa<<1)>>1]|0;qa=(ma|0)>-1?ma:-ma|0;do{if((qa|0)>63){Pa=ma}else{if((qa|0)<(e[1267552+(oa<<1)>>1]|0)){Pa=(ca(la,ma)|0)>>8;break}ra=(ca(ia,ma)|0)>>8;if((ma|0)<0){Pa=ra-pa|0;break}else{Pa=ra+pa|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19464>>2]|0)!=0){break}pa=c[f+15724>>2]|0;ia=((pa|0)/-2|0)+1|0;la=(pa|0)/2|0;if((Pa|0)<(ia|0)){Qa=ia;break a}Qa=(Pa|0)>(la|0)?la:Pa;break a}}while(0);la=c[f+15724>>2]|0;ia=(la|0)/-2|0;pa=((la|0)/2|0)-1|0;if((Pa|0)<(ia|0)){Qa=ia;break}Qa=(Pa|0)>(pa|0)?pa:Pa}else{pa=c[f+19440>>2]|0;Oa=(pa|0)>3?3:pa;r=69}}while(0);if((r|0)==69){Qa=(ca(e[1266104+((sa^o)*56|0)+(Oa<<1)>>1]|0,ma)|0)>>8}Ra=na;Sa=Qa<<p&65535}else{Ra=Ba;Sa=Ca}if(Fa&(Ha|0)==0){ta=Ja<<16>>16>>p;ua=(c[f+9992>>2]|0)==3;pa=c[f+19436>>2]|0;do{if(ua){if(!((pa|0)==0&(o|0)==1)){Ta=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=84;break}ia=c[f+19488>>2]|0;la=(ia|0)>3?3:ia;ia=e[1267560+(la<<1)>>1]|0;oa=e[1267528+(la<<1)>>1]|0;qa=e[1267536+(la<<1)>>1]|0;ra=(ta|0)>-1?ta:-ta|0;do{if((ra|0)>255){Ua=ta}else{if((ra|0)<(e[1267544+(la<<1)>>1]|0)){Ua=(ca(oa,ta)|0)>>8;break}w=(ca(qa,ta)|0)>>8;if((ta|0)<0){Ua=w-ia|0;break}else{Ua=w+ia|0;break}}}while(0);ia=c[f+15720>>2]|0;qa=-ia|0;oa=ia-1|0;if((Ua|0)<(qa|0)){Va=qa;break}Va=(Ua|0)>(oa|0)?oa:Ua}else{oa=c[f+19440>>2]|0;Ta=(oa|0)>3?3:oa;r=84}}while(0);if((r|0)==84){Va=(ca(e[1266104+((pa^o)*56|0)+(Ta<<1)>>1]|0,ta)|0)>>8}na=Va<<p&65535;ma=Ia<<16>>16>>p;b:do{if(ua){if(!((pa|0)==0&(o|0)==1)){Wa=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=101;break}sa=c[f+19488>>2]|0;oa=(sa|0)>3?3:sa;sa=e[1267568+(oa<<1)>>1]|0;qa=e[1267528+(oa<<1)>>1]|0;ia=e[1267536+(oa<<1)>>1]|0;la=(ma|0)>-1?ma:-ma|0;do{if((la|0)>63){Xa=ma}else{if((la|0)<(e[1267552+(oa<<1)>>1]|0)){Xa=(ca(qa,ma)|0)>>8;break}ra=(ca(ia,ma)|0)>>8;if((ma|0)<0){Xa=ra-sa|0;break}else{Xa=ra+sa|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19464>>2]|0)!=0){break}sa=c[f+15724>>2]|0;ia=((sa|0)/-2|0)+1|0;qa=(sa|0)/2|0;if((Xa|0)<(ia|0)){Ya=ia;break b}Ya=(Xa|0)>(qa|0)?qa:Xa;break b}}while(0);qa=c[f+15724>>2]|0;ia=(qa|0)/-2|0;sa=((qa|0)/2|0)-1|0;if((Xa|0)<(ia|0)){Ya=ia;break}Ya=(Xa|0)>(sa|0)?sa:Xa}else{sa=c[f+19440>>2]|0;Wa=(sa|0)>3?3:sa;r=101}}while(0);if((r|0)==101){Ya=(ca(e[1266104+((pa^o)*56|0)+(Wa<<1)>>1]|0,ma)|0)>>8}Za=na;_a=Ya<<p&65535}else{Za=Ja;_a=Ia}if(Ga&(ya|0)==0){ua=wa<<16>>16>>p;ta=(c[f+9992>>2]|0)==3;sa=c[f+19436>>2]|0;do{if(ta){if(!((sa|0)==0&(o|0)==1)){$a=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=116;break}ia=c[f+19488>>2]|0;qa=(ia|0)>3?3:ia;ia=e[1267560+(qa<<1)>>1]|0;oa=e[1267528+(qa<<1)>>1]|0;la=e[1267536+(qa<<1)>>1]|0;ra=(ua|0)>-1?ua:-ua|0;do{if((ra|0)>255){ab=ua}else{if((ra|0)<(e[1267544+(qa<<1)>>1]|0)){ab=(ca(oa,ua)|0)>>8;break}w=(ca(la,ua)|0)>>8;if((ua|0)<0){ab=w-ia|0;break}else{ab=w+ia|0;break}}}while(0);ia=c[f+15720>>2]|0;la=-ia|0;oa=ia-1|0;if((ab|0)<(la|0)){bb=la;break}bb=(ab|0)>(oa|0)?oa:ab}else{oa=c[f+19440>>2]|0;$a=(oa|0)>3?3:oa;r=116}}while(0);if((r|0)==116){bb=(ca(e[1266104+((sa^o)*56|0)+($a<<1)>>1]|0,ua)|0)>>8}na=bb<<p&65535;ma=xa<<16>>16>>p;c:do{if(ta){if(!((sa|0)==0&(o|0)==1)){cb=c[((o|0)==0?f+19484|0:f+19488|0)>>2]|0;r=133;break}pa=c[f+19488>>2]|0;oa=(pa|0)>3?3:pa;pa=e[1267568+(oa<<1)>>1]|0;la=e[1267528+(oa<<1)>>1]|0;ia=e[1267536+(oa<<1)>>1]|0;qa=(ma|0)>-1?ma:-ma|0;do{if((qa|0)>63){db=ma}else{if((qa|0)<(e[1267552+(oa<<1)>>1]|0)){db=(ca(la,ma)|0)>>8;break}ra=(ca(ia,ma)|0)>>8;if((ma|0)<0){db=ra-pa|0;break}else{db=ra+pa|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19464>>2]|0)!=0){break}pa=c[f+15724>>2]|0;ia=((pa|0)/-2|0)+1|0;la=(pa|0)/2|0;if((db|0)<(ia|0)){eb=ia;break c}eb=(db|0)>(la|0)?la:db;break c}}while(0);la=c[f+15724>>2]|0;ia=(la|0)/-2|0;pa=((la|0)/2|0)-1|0;if((db|0)<(ia|0)){eb=ia;break}eb=(db|0)>(pa|0)?pa:db}else{pa=c[f+19440>>2]|0;cb=(pa|0)>3?3:pa;r=133}}while(0);if((r|0)==133){eb=(ca(e[1266104+((sa^o)*56|0)+(cb<<1)>>1]|0,ma)|0)>>8}fb=na;gb=eb<<p&65535}else{fb=wa;gb=xa}a[(c[f+19408+(o<<2)>>2]|0)+(z+t)|0]=1;c[f+19460+(o<<2)>>2]=(c[f+19456>>2]|0)==0;hb=fb;ib=gb;jb=Za;kb=_a;lb=Ra;mb=Sa}}while(0);if((r|0)==136){if((Da|0)==0|Ea^1){nb=Ba;ob=Ca}else{Da=Ba<<16>>16>>p;Ba=(c[f+9992>>2]|0)==3;Sa=c[f+19436>>2]|0;do{if(Ba){Ra=(o|0)==0;_a=f+19488|0;if((Sa|0)!=0|Ra){pb=Ra?f+19484|0:_a;r=141;break}else{Ra=c[_a>>2]|0;qb=(ca(e[1267520+(((Ra|0)>3?3:Ra)<<1)>>1]|0,Da)|0)>>8<<p&65535;rb=Ca<<16>>16>>p;r=151;break}}else{pb=f+19440|0;r=141}}while(0);do{if((r|0)==141){Ra=Sa^o;_a=c[pb>>2]|0;Za=(_a|0)>3?3:_a;_a=e[1266112+(Ra*56|0)+(Za<<1)>>1]|0;gb=e[1266120+(Ra*56|0)+(Za<<1)>>1]|0;fb=e[1266144+(Ra*56|0)+(Za<<1)>>1]|0;eb=(Da|0)>-1?Da:-Da|0;do{if((eb|0)>255){sb=Da}else{if((eb|0)<(e[1266128+(Ra*56|0)+(Za<<1)>>1]|0)){sb=(ca(_a,Da)|0)>>8;break}cb=(ca(gb,Da)|0)>>8;if((Da|0)<0){sb=cb-fb|0;break}else{sb=cb+fb|0;break}}}while(0);fb=c[f+15720>>2]|0;gb=-fb|0;_a=fb-1|0;if((sb|0)<(gb|0)){tb=gb}else{tb=(sb|0)>(_a|0)?_a:sb}_a=tb<<p&65535;gb=Ca<<16>>16>>p;if(Ba){qb=_a;rb=gb;r=151;break}ub=f+19440|0;vb=_a;wb=gb;r=154}}while(0);do{if((r|0)==151){Ba=(o|0)==0;Ca=f+19488|0;if((Sa|0)!=0|Ba){ub=Ba?f+19484|0:Ca;vb=qb;wb=rb;r=154;break}else{Ba=c[Ca>>2]|0;xb=(ca(e[1267520+(((Ba|0)>3?3:Ba)<<1)>>1]|0,rb)|0)>>8;yb=qb;break}}}while(0);d:do{if((r|0)==154){qb=Sa^o;rb=c[ub>>2]|0;Ba=(rb|0)>3?3:rb;rb=e[1266112+(qb*56|0)+(Ba<<1)>>1]|0;Ca=e[1266120+(qb*56|0)+(Ba<<1)>>1]|0;tb=e[1266152+(qb*56|0)+(Ba<<1)>>1]|0;sb=(wb|0)>-1?wb:-wb|0;do{if((sb|0)>63){zb=wb}else{if((sb|0)<(e[1266136+(qb*56|0)+(Ba<<1)>>1]|0)){zb=(ca(rb,wb)|0)>>8;break}Da=(ca(Ca,wb)|0)>>8;if((wb|0)<0){zb=Da-tb|0;break}else{zb=Da+tb|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19460+(o<<2)>>2]|0)!=0){break}tb=c[f+15724>>2]|0;Ca=((tb|0)/-2|0)+1|0;rb=(tb|0)/2|0;if((zb|0)<(Ca|0)){xb=Ca;yb=vb;break d}xb=(zb|0)>(rb|0)?rb:zb;yb=vb;break d}}while(0);rb=c[f+15724>>2]|0;Ca=(rb|0)/-2|0;tb=((rb|0)/2|0)-1|0;if((zb|0)<(Ca|0)){xb=Ca;yb=vb;break}xb=(zb|0)>(tb|0)?tb:zb;yb=vb}}while(0);nb=yb;ob=xb<<p&65535}if((Ha|0)==0|Fa^1){Ab=Ja;Bb=Ia}else{Ha=Ja<<16>>16>>p;Ja=(c[f+9992>>2]|0)==3;xb=c[f+19436>>2]|0;do{if(Ja){yb=(o|0)==0;vb=f+19488|0;if((xb|0)!=0|yb){Cb=yb?f+19484|0:vb;r=173;break}else{yb=c[vb>>2]|0;Db=(ca(e[1267520+(((yb|0)>3?3:yb)<<1)>>1]|0,Ha)|0)>>8<<p&65535;Eb=Ia<<16>>16>>p;r=183;break}}else{Cb=f+19440|0;r=173}}while(0);do{if((r|0)==173){yb=xb^o;vb=c[Cb>>2]|0;zb=(vb|0)>3?3:vb;vb=e[1266112+(yb*56|0)+(zb<<1)>>1]|0;wb=e[1266120+(yb*56|0)+(zb<<1)>>1]|0;ub=e[1266144+(yb*56|0)+(zb<<1)>>1]|0;Sa=(Ha|0)>-1?Ha:-Ha|0;do{if((Sa|0)>255){Fb=Ha}else{if((Sa|0)<(e[1266128+(yb*56|0)+(zb<<1)>>1]|0)){Fb=(ca(vb,Ha)|0)>>8;break}tb=(ca(wb,Ha)|0)>>8;if((Ha|0)<0){Fb=tb-ub|0;break}else{Fb=tb+ub|0;break}}}while(0);ub=c[f+15720>>2]|0;wb=-ub|0;vb=ub-1|0;if((Fb|0)<(wb|0)){Gb=wb}else{Gb=(Fb|0)>(vb|0)?vb:Fb}vb=Gb<<p&65535;wb=Ia<<16>>16>>p;if(Ja){Db=vb;Eb=wb;r=183;break}Hb=f+19440|0;Ib=vb;Jb=wb;r=186}}while(0);do{if((r|0)==183){Ja=(o|0)==0;Ia=f+19488|0;if((xb|0)!=0|Ja){Hb=Ja?f+19484|0:Ia;Ib=Db;Jb=Eb;r=186;break}else{Ja=c[Ia>>2]|0;Kb=(ca(e[1267520+(((Ja|0)>3?3:Ja)<<1)>>1]|0,Eb)|0)>>8;Lb=Db;break}}}while(0);e:do{if((r|0)==186){Db=xb^o;Eb=c[Hb>>2]|0;Ja=(Eb|0)>3?3:Eb;Eb=e[1266112+(Db*56|0)+(Ja<<1)>>1]|0;Ia=e[1266120+(Db*56|0)+(Ja<<1)>>1]|0;Gb=e[1266152+(Db*56|0)+(Ja<<1)>>1]|0;Fb=(Jb|0)>-1?Jb:-Jb|0;do{if((Fb|0)>63){Mb=Jb}else{if((Fb|0)<(e[1266136+(Db*56|0)+(Ja<<1)>>1]|0)){Mb=(ca(Eb,Jb)|0)>>8;break}Ha=(ca(Ia,Jb)|0)>>8;if((Jb|0)<0){Mb=Ha-Gb|0;break}else{Mb=Ha+Gb|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19460+(o<<2)>>2]|0)!=0){break}Gb=c[f+15724>>2]|0;Ia=((Gb|0)/-2|0)+1|0;Eb=(Gb|0)/2|0;if((Mb|0)<(Ia|0)){Kb=Ia;Lb=Ib;break e}Kb=(Mb|0)>(Eb|0)?Eb:Mb;Lb=Ib;break e}}while(0);Eb=c[f+15724>>2]|0;Ia=(Eb|0)/-2|0;Gb=((Eb|0)/2|0)-1|0;if((Mb|0)<(Ia|0)){Kb=Ia;Lb=Ib;break}Kb=(Mb|0)>(Gb|0)?Gb:Mb;Lb=Ib}}while(0);Ab=Lb;Bb=Kb<<p&65535}if((ya|0)==0|Ga^1){Nb=wa;Ob=xa}else{ya=wa<<16>>16>>p;wa=(c[f+9992>>2]|0)==3;Kb=c[f+19436>>2]|0;do{if(wa){Lb=(o|0)==0;Ib=f+19488|0;if((Kb|0)!=0|Lb){Pb=Lb?f+19484|0:Ib;r=205;break}else{Lb=c[Ib>>2]|0;Qb=(ca(e[1267520+(((Lb|0)>3?3:Lb)<<1)>>1]|0,ya)|0)>>8<<p&65535;Rb=xa<<16>>16>>p;r=215;break}}else{Pb=f+19440|0;r=205}}while(0);do{if((r|0)==205){Lb=Kb^o;Ib=c[Pb>>2]|0;Mb=(Ib|0)>3?3:Ib;Ib=e[1266112+(Lb*56|0)+(Mb<<1)>>1]|0;Jb=e[1266120+(Lb*56|0)+(Mb<<1)>>1]|0;Hb=e[1266144+(Lb*56|0)+(Mb<<1)>>1]|0;xb=(ya|0)>-1?ya:-ya|0;do{if((xb|0)>255){Sb=ya}else{if((xb|0)<(e[1266128+(Lb*56|0)+(Mb<<1)>>1]|0)){Sb=(ca(Ib,ya)|0)>>8;break}Gb=(ca(Jb,ya)|0)>>8;if((ya|0)<0){Sb=Gb-Hb|0;break}else{Sb=Gb+Hb|0;break}}}while(0);Hb=c[f+15720>>2]|0;Jb=-Hb|0;Ib=Hb-1|0;if((Sb|0)<(Jb|0)){Tb=Jb}else{Tb=(Sb|0)>(Ib|0)?Ib:Sb}Ib=Tb<<p&65535;Jb=xa<<16>>16>>p;if(wa){Qb=Ib;Rb=Jb;r=215;break}Ub=f+19440|0;Vb=Ib;Wb=Jb;r=218}}while(0);do{if((r|0)==215){wa=(o|0)==0;xa=f+19488|0;if((Kb|0)!=0|wa){Ub=wa?f+19484|0:xa;Vb=Qb;Wb=Rb;r=218;break}else{wa=c[xa>>2]|0;Xb=(ca(e[1267520+(((wa|0)>3?3:wa)<<1)>>1]|0,Rb)|0)>>8;Yb=Qb;break}}}while(0);f:do{if((r|0)==218){Qb=Kb^o;Rb=c[Ub>>2]|0;wa=(Rb|0)>3?3:Rb;Rb=e[1266112+(Qb*56|0)+(wa<<1)>>1]|0;xa=e[1266120+(Qb*56|0)+(wa<<1)>>1]|0;Tb=e[1266152+(Qb*56|0)+(wa<<1)>>1]|0;Sb=(Wb|0)>-1?Wb:-Wb|0;do{if((Sb|0)>63){Zb=Wb}else{if((Sb|0)<(e[1266136+(Qb*56|0)+(wa<<1)>>1]|0)){Zb=(ca(Rb,Wb)|0)>>8;break}ya=(ca(xa,Wb)|0)>>8;if((Wb|0)<0){Zb=ya-Tb|0;break}else{Zb=ya+Tb|0;break}}}while(0);do{if((c[f+19456>>2]|0)!=0){if((c[f+19460+(o<<2)>>2]|0)!=0){break}Tb=c[f+15724>>2]|0;xa=((Tb|0)/-2|0)+1|0;Rb=(Tb|0)/2|0;if((Zb|0)<(xa|0)){Xb=xa;Yb=Vb;break f}Xb=(Zb|0)>(Rb|0)?Rb:Zb;Yb=Vb;break f}}while(0);Rb=c[f+15724>>2]|0;xa=(Rb|0)/-2|0;Tb=((Rb|0)/2|0)-1|0;if((Zb|0)<(xa|0)){Xb=xa;Yb=Vb;break}Xb=(Zb|0)>(Tb|0)?Tb:Zb;Yb=Vb}}while(0);Nb=Yb;Ob=Xb<<p&65535}a[(c[f+19408+(o<<2)>>2]|0)+(z+t)|0]=0;c[f+19460+(o<<2)>>2]=c[f+19456>>2];hb=Nb;ib=Ob;jb=Ab;kb=Bb;lb=nb;mb=ob}do{if(Ea){_b=lb<<16>>16;$b=mb<<16>>16}else{if(Ga){_b=hb<<16>>16;$b=ib<<16>>16;break}if(!Fa){_b=0;$b=0;break}_b=jb<<16>>16;$b=kb<<16>>16}}while(0);do{if((za+Aa|0)>1){Fa=lb<<16>>16;ob=jb<<16>>16;nb=hb<<16>>16;do{if(lb<<16>>16>jb<<16>>16){if(!(hb<<16>>16>jb<<16>>16)){ac=ob;break}ac=(nb|0)>(Fa|0)?Fa:nb}else{if(!(jb<<16>>16>hb<<16>>16)){ac=ob;break}ac=(nb|0)>(Fa|0)?nb:Fa}}while(0);Fa=mb<<16>>16;nb=kb<<16>>16;ob=ib<<16>>16;if(mb<<16>>16>kb<<16>>16){if(!(ib<<16>>16>kb<<16>>16)){bc=ac;cc=nb;break}bc=ac;cc=(ob|0)>(Fa|0)?Fa:ob;break}else{if(!(kb<<16>>16>ib<<16>>16)){bc=ac;cc=nb;break}bc=ac;cc=(ob|0)>(Fa|0)?ob:Fa;break}}else{bc=_b;cc=$b}}while(0);$b=(c[N>>2]|0)==0;if($b){if(M){dc=32}else{dc=H?32:0}M=dc|c[K>>2]<<6;if(G){ec=32}else{ec=H?32:0}H=ec|c[f+12480>>2]<<6;ec=(c[f+116>>2]<<6)-4|0;G=(c[f+120>>2]<<6)-4|0;K=M+bc|0;if(E){fc=(K|0)<-60?-60-M|0:bc;gc=(H+cc|0)<-60?-60-H|0:cc}else{fc=(K|0)<-28?-28-M|0:bc;gc=(H+cc|0)<-28?-28-H|0:cc}K=(fc+M|0)>(ec|0)?ec-M|0:fc;fc=(gc+H|0)>(G|0)?G-H|0:gc;if(Ea&Ga){hc=fc;ic=K;r=260}else{jc=K;kc=fc;r=274}}else{if((c[f+9992>>2]|0)==3|Ea^1|Ga^1){lc=cc;mc=bc;r=275}else{hc=cc;ic=bc;r=260}}do{if((r|0)==260){if((a[m+B|0]|0)==0){bc=ic-(lb<<16>>16)|0;cc=hc-(mb<<16>>16)|0;nc=((cc|0)>-1?cc:-cc|0)+((bc|0)>-1?bc:-bc|0)|0}else{nc=((hc|0)>-1?hc:-hc|0)+((ic|0)>-1?ic:-ic|0)|0}if((nc|0)>32){bc=f+14128|0;cc=c[bc>>2]|0;Ga=d[(c[f+14120>>2]|0)+(cc>>>3)|0]|0;c[bc>>2]=((cc|0)<(c[f+14136>>2]|0))+cc;if((Ga&128>>>((cc&7)>>>0)|0)==0){jc=hb<<16>>16;kc=ib<<16>>16;r=274;break}else{jc=lb<<16>>16;kc=mb<<16>>16;r=274;break}}if((a[m+A|0]|0)==0){cc=ic-(hb<<16>>16)|0;Ga=hc-(ib<<16>>16)|0;oc=((Ga|0)>-1?Ga:-Ga|0)+((cc|0)>-1?cc:-cc|0)|0}else{oc=((hc|0)>-1?hc:-hc|0)+((ic|0)>-1?ic:-ic|0)|0}if((oc|0)<=32){jc=ic;kc=hc;r=274;break}cc=f+14128|0;Ga=c[cc>>2]|0;bc=d[(c[f+14120>>2]|0)+(Ga>>>3)|0]|0;c[cc>>2]=((Ga|0)<(c[f+14136>>2]|0))+Ga;if((bc&128>>>((Ga&7)>>>0)|0)==0){jc=hb<<16>>16;kc=ib<<16>>16;r=274;break}else{jc=lb<<16>>16;kc=mb<<16>>16;r=274;break}}}while(0);if((r|0)==274){if($b){pc=0;qc=l;rc=kc;sc=jc}else{lc=kc;mc=jc;r=275}}do{if((r|0)==275){jc=l>>((c[f+19444>>2]|0)!=0);if((c[f+19456>>2]|0)==0){pc=0;qc=jc;rc=lc;sc=mc;break}pc=(c[f+19460+(o<<2)>>2]|0)==0|0;qc=jc;rc=lc;sc=mc}}while(0);mc=(s+k+sc&(k<<1)+65535)-k&65535;k=(c[x>>2]|0)+t|0;b[(c[u>>2]|0)+(k<<2)>>1]=mc;c[f+11744+(o<<5)+(g<<3)>>2]=mc<<16>>16;mc=pc-qc+(rc+h+qc-pc&(qc<<1)+65535)&65535;b[(c[u>>2]|0)+(k<<2)+2>>1]=mc;c[f+11744+(o<<5)+(g<<3)+4>>2]=mc<<16>>16;if(!E){return}E=c[x>>2]|0;mc=E+t|0;g=c[u>>2]|0;u=g+(mc<<2)|0;k=E+(t+1)|0;b[g+(k<<2)>>1]=b[u>>1]|0;qc=g+(mc<<2)+2|0;b[g+(k<<2)+2>>1]=b[qc>>1]|0;pc=t+i|0;i=E+pc|0;b[g+(i<<2)>>1]=b[u>>1]|0;b[g+(i<<2)+2>>1]=b[qc>>1]|0;i=pc+1|0;h=E+i|0;b[g+(h<<2)>>1]=b[u>>1]|0;b[g+(h<<2)+2>>1]=b[qc>>1]|0;qc=f+19408+(o<<2)|0;o=c[qc>>2]|0;a[o+k|0]=a[o+mc|0]|0;mc=c[x>>2]|0;o=c[qc>>2]|0;k=a[o+(mc+t)|0]|0;a[o+(mc+i)|0]=k;a[(c[qc>>2]|0)+((c[x>>2]|0)+pc)|0]=k;return}function s7a(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=a+12476|0;f=a+124|0;g=a+19584|0;h=a+19592|0;i=a+152|0;j=a+148|0;k=a+12480|0;l=a+812|0;m=a+19600|0;n=a+15380|0;o=a+15728|0;p=a+15388|0;q=a+128|0;r=a+9148|0;s=a+16028|0;t=a+12544|0;u=0;v=c[e>>2]|0;do{w=c[f>>2]|0;x=v-w|0;y=c[g>>2]|0;z=c[y+(x<<2)>>2]|0;A=u<<2;B=z>>A;C=c[h>>2]|0;D=d[C+x|0]|0;E=(u|0)>3;F=c[(E?i:j)>>2]|0;if(E){G=c[a+12544+(u-3<<2)>>2]|0}else{G=(c[t>>2]|0)+((ca(F,(A&8)-8|0)|0)+(u<<3&8))|0}H=(u|0)<2;a:do{if((c[k>>2]|0)!=(c[l>>2]|0)|H){if(E){I=w;J=(c[m>>2]|0)+(x<<2)|0;K=(c[y+(v<<2)>>2]|0)>>>(A>>>0);L=(d[C+v|0]|0)>>>(A>>>0)}else{if(H){M=A+8|0;N=D>>>(M>>>0);O=z>>M}else{M=A-8|0;N=(d[C+v|0]|0)>>>(M>>>0);O=(c[y+(v<<2)>>2]|0)>>>(M>>>0)}M=c[q>>2]|0;I=M;J=(c[r>>2]|0)+((c[a+12496+(u<<2)>>2]|0)-(M<<1)<<2)|0;K=O;L=N}do{if((L&1|0)==0){if((D&1<<A|0)!=0){break}if((b[J>>1]|0)!=(b[J+(I<<2)>>1]|0)){break}if((b[J+2>>1]|0)!=(b[J+(I<<2)+2>>1]|0)){break}M=(K>>>2|B)&3;if((M|0)==3){ef[c[p>>2]&4095](G,F,d[o]|0);break a}else if((M|0)==0){break a}P=c[n>>2]|0;if((M|0)==1){ef[P&4095](G+4|0,F,d[o]|0);break a}else{ef[P&4095](G,F,d[o]|0);break a}}}while(0);ef[c[p>>2]&4095](G,F,d[o]|0)}}while(0);D=F<<2;y=G+(-D|0)|0;C=c[(c[s>>2]|0)+((c[e>>2]|0)-(c[f>>2]|0)<<2)>>2]>>A&15;do{if((C|0)==7|(C|0)==3){z=(B>>>2|B)&3;if((z|0)==3){ef[c[p>>2]&4095](y,F,d[o]|0);break}else if((z|0)==0){break}H=c[n>>2]|0;if((z|0)==1){ef[H&4095](G+(4-D)|0,F,d[o]|0);break}else{ef[H&4095](y,F,d[o]|0);break}}}while(0);u=u+1|0;v=c[e>>2]|0}while((u|0)<6);if((v|0)==0){return}u=a+116|0;G=a+15384|0;n=a+15392|0;p=0;K=v;do{v=c[f>>2]|0;I=K-1-v|0;J=c[g>>2]|0;L=c[J+(I<<2)>>2]|0;N=p<<2;O=L>>N;l=c[h>>2]|0;k=d[l+I|0]|0;I=(p|0)>3;F=c[(I?i:j)>>2]|0;if(I){Q=(c[a+12544+(p-3<<2)>>2]|0)+(-(F<<3)|0)|0}else{Q=(c[t>>2]|0)+((p<<3&8)-8+(ca(F,N&8|-16)|0))|0}if((K|0)==(c[u>>2]|0)){if((p&5|0)==0){R=36}}else{R=36}b:do{if((R|0)==36){R=0;if(I){y=K-v|0;S=(c[m>>2]|0)+(y-1<<2)|0;T=(c[J+(y<<2)>>2]|0)>>>(N>>>0);U=(d[l+y|0]|0)>>>(N>>>0)}else{if((p&1|0)==0){y=N+4|0;V=k>>>(y>>>0);W=L>>y}else{y=K-v|0;D=N-4|0;V=(d[l+y|0]|0)>>>(D>>>0);W=(c[J+(y<<2)>>2]|0)>>>(D>>>0)}S=(c[r>>2]|0)+((c[a+12496+(p<<2)>>2]|0)-2-(c[q>>2]<<1)<<2)|0;T=W;U=V}do{if((k&1<<N|0)==0){if((U&1|0)!=0){break}if((b[S>>1]|0)!=(b[S+4>>1]|0)){break}if((b[S+2>>1]|0)!=(b[S+6>>1]|0)){break}D=(T>>>1|O)&5;if((D|0)==5){ef[c[n>>2]&4095](Q,F,d[o]|0);break b}else if((D|0)==0){break b}y=c[G>>2]|0;if((D|0)==1){ef[y&4095](Q+(F<<2)|0,F,d[o]|0);break b}else{ef[y&4095](Q,F,d[o]|0);break b}}}while(0);ef[c[n>>2]&4095](Q,F,d[o]|0)}}while(0);k=Q-4|0;do{if(((c[(c[s>>2]|0)+((c[e>>2]|0)-1-(c[f>>2]|0)<<2)>>2]>>N&15)-6|0)>>>0<2>>>0){J=(O>>>1|O)&5;if((J|0)==5){ef[c[n>>2]&4095](k,F,d[o]|0);break}else if((J|0)==0){break}l=c[G>>2]|0;if((J|0)==1){ef[l&4095](Q+((F<<2)-4)|0,F,d[o]|0);break}else{ef[l&4095](k,F,d[o]|0);break}}}while(0);p=p+1|0;K=c[e>>2]|0}while((p|0)<6);if((K|0)!=((c[u>>2]|0)-1|0)){return}p=K+1|0;c[e>>2]=p;K=8>>>((c[(c[a+4>>2]|0)+800>>2]|0)>>>0);Q=a+12496|0;c[Q>>2]=(c[Q>>2]|0)+2;Q=a+12500|0;c[Q>>2]=(c[Q>>2]|0)+2;Q=a+12504|0;c[Q>>2]=(c[Q>>2]|0)+2;Q=a+12508|0;c[Q>>2]=(c[Q>>2]|0)+2;Q=a+12512|0;c[Q>>2]=(c[Q>>2]|0)+1;Q=a+12516|0;c[Q>>2]=(c[Q>>2]|0)+1;c[t>>2]=(c[t>>2]|0)+(K<<1);Q=a+12548|0;c[Q>>2]=(c[Q>>2]|0)+K;Q=a+12552|0;c[Q>>2]=(c[Q>>2]|0)+K;K=0;Q=p;while(1){p=c[f>>2]|0;T=Q-1-p|0;S=c[g>>2]|0;U=c[S+(T<<2)>>2]|0;V=K<<2;W=U>>V;F=c[h>>2]|0;k=d[F+T|0]|0;T=(K|0)>3;O=c[(T?i:j)>>2]|0;if(T){X=(c[a+12544+(K-3<<2)>>2]|0)+(-(O<<3)|0)|0}else{X=(c[t>>2]|0)+((K<<3&8)-8+(ca(O,V&8|-16)|0))|0}if((Q|0)==(c[u>>2]|0)){if((K&5|0)==0){R=66}}else{R=66}c:do{if((R|0)==66){R=0;if(T){N=Q-p|0;Y=(c[m>>2]|0)+(N-1<<2)|0;Z=(c[S+(N<<2)>>2]|0)>>>(V>>>0);_=(d[F+N|0]|0)>>>(V>>>0)}else{if((K&1|0)==0){N=V+4|0;$=k>>>(N>>>0);aa=U>>N}else{N=Q-p|0;l=V-4|0;$=(d[F+N|0]|0)>>>(l>>>0);aa=(c[S+(N<<2)>>2]|0)>>>(l>>>0)}Y=(c[r>>2]|0)+((c[a+12496+(K<<2)>>2]|0)-2-(c[q>>2]<<1)<<2)|0;Z=aa;_=$}do{if((k&1<<V|0)==0){if((_&1|0)!=0){break}if((b[Y>>1]|0)!=(b[Y+4>>1]|0)){break}if((b[Y+2>>1]|0)!=(b[Y+6>>1]|0)){break}l=(Z>>>1|W)&5;if((l|0)==5){ef[c[n>>2]&4095](X,O,d[o]|0);break c}else if((l|0)==0){break c}N=c[G>>2]|0;if((l|0)==1){ef[N&4095](X+(O<<2)|0,O,d[o]|0);break c}else{ef[N&4095](X,O,d[o]|0);break c}}}while(0);ef[c[n>>2]&4095](X,O,d[o]|0)}}while(0);k=X-4|0;do{if(((c[(c[s>>2]|0)+((c[e>>2]|0)-1-(c[f>>2]|0)<<2)>>2]>>V&15)-6|0)>>>0<2>>>0){S=(W>>>1|W)&5;if((S|0)==5){ef[c[n>>2]&4095](k,O,d[o]|0);break}else if((S|0)==0){break}F=c[G>>2]|0;if((S|0)==1){ef[F&4095](X+((O<<2)-4)|0,O,d[o]|0);break}else{ef[F&4095](k,O,d[o]|0);break}}}while(0);O=K+1|0;if((O|0)>=6){break}K=O;Q=c[e>>2]|0}return}function t7a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;do{if((c[a+14084>>2]|0)==0){b=a+12476|0;e=c[b>>2]|0;if((e|0)==0){f=0;g=0}else{if((c[a+19224>>2]|0)==1){h=e-1+(ca((c[a+12480>>2]|0)-1|0,c[a+124>>2]|0)|0)|0;i=d[(c[a+19324>>2]|0)+h|0]|0}else{i=0}h=a+148|0;e=c[h>>2]|0;j=e<<i;k=16-i>>((i|0)==0);l=a+10068|0;m=a+19572|0;n=a+19556|0;o=a+12544|0;ef[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)|0,(c[o>>2]|0)+(-16-(e<<4))|0,j);ef[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+128|0,(c[o>>2]|0)+(-8-(c[h>>2]<<4))|0,j);e=(c[o>>2]|0)+(-16-(ca(c[h>>2]|0,k)|0))|0;ef[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+256|0,e,j);e=(c[o>>2]|0)+(-8-(ca(c[h>>2]|0,k)|0))|0;ef[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+384|0,e,j);j=a+152|0;e=c[j>>2]|0;ef[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+512|0,(c[a+12548>>2]|0)+(-8-(e<<3))|0,e);e=c[j>>2]|0;ef[c[l>>2]&4095]((c[n>>2]|0)+((c[m>>2]|0)*768|0)+640|0,(c[a+12552>>2]|0)+(-8-(e<<3))|0,e);f=i;g=c[b>>2]|0}if((g|0)!=((c[a+116>>2]|0)-1|0)){break}if((c[a+19224>>2]|0)==1){b=(ca((c[a+12480>>2]|0)-1|0,c[a+124>>2]|0)|0)+g|0;p=d[(c[a+19324>>2]|0)+b|0]|0}else{p=f}b=a+148|0;e=c[b>>2]|0;m=e<<p;n=(p|0)!=0?15:8;l=a+10068|0;j=a+19576|0;k=a+19556|0;h=a+12544|0;ef[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)|0,(c[h>>2]|0)+(-(e<<4)|0)|0,m);ef[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+128|0,(c[h>>2]|0)+(-(c[b>>2]<<4)|8)|0,m);e=(c[h>>2]|0)+(ca(c[b>>2]|0,-n|0)|0)|0;ef[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+256|0,e,m);e=(c[h>>2]|0)+(8-(ca(c[b>>2]|0,n)|0))|0;ef[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+384|0,e,m);m=a+152|0;e=c[m>>2]|0;ef[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+512|0,(c[a+12548>>2]|0)+(-(e<<3)|0)|0,e);e=c[m>>2]|0;ef[c[l>>2]&4095]((c[k>>2]|0)+((c[j>>2]|0)*768|0)+640|0,(c[a+12552>>2]|0)+(-(e<<3)|0)|0,e)}}while(0);p=a+19572|0;f=(c[p>>2]|0)+1|0;c[p>>2]=f;g=c[a+19560>>2]|0;if((f|0)<(g|0)){q=a+19576|0;r=c[q>>2]|0;s=r+1|0;t=(s|0)<(g|0);u=t?s:0;c[q>>2]=u;v=a+19568|0;w=c[v>>2]|0;x=w+1|0;y=(x|0)<(g|0);z=y?x:0;c[v>>2]=z;A=a+19564|0;B=c[A>>2]|0;C=B+1|0;D=(C|0)<(g|0);E=D?C:0;c[A>>2]=E;return}c[p>>2]=0;q=a+19576|0;r=c[q>>2]|0;s=r+1|0;t=(s|0)<(g|0);u=t?s:0;c[q>>2]=u;v=a+19568|0;w=c[v>>2]|0;x=w+1|0;y=(x|0)<(g|0);z=y?x:0;c[v>>2]=z;A=a+19564|0;B=c[A>>2]|0;C=B+1|0;D=(C|0)<(g|0);E=D?C:0;c[A>>2]=E;return}function u7a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((c[a+14084>>2]|0)!=0){return}d=a+12476|0;if((c[d>>2]|0)==0){e=0}else{f=a+15396|0;do{if((c[a+12480>>2]|0)<((c[a+808>>2]|0)+2|0)){g=a+12544|0;h=a+148|0}else{i=a+12544|0;j=a+148|0;k=c[j>>2]|0;ef[c[f>>2]&4095]((c[i>>2]|0)+(-16-(k<<4))|0,k,b);k=a+15400|0;if((c[d>>2]|0)>1){l=c[j>>2]|0;ef[c[k>>2]&4095]((c[i>>2]|0)+(-16-(l<<5))|0,l,b)}l=c[j>>2]|0;ef[c[k>>2]&4095]((c[i>>2]|0)+(-8-(l<<5))|0,l,b);l=a+15388|0;k=a+152|0;m=a+15392|0;n=a+12548|0;o=c[k>>2]|0;ef[c[l>>2]&4095]((c[n>>2]|0)+(-8-(o<<3))|0,o,b);if((c[d>>2]|0)>1){o=c[k>>2]|0;ef[c[m>>2]&4095]((c[n>>2]|0)+(-8-(o<<4))|0,o,b)}o=a+12552|0;n=c[k>>2]|0;ef[c[l>>2]&4095]((c[o>>2]|0)+(-8-(n<<3))|0,n,b);if((c[d>>2]|0)<=1){g=i;h=j;break}n=c[k>>2]|0;ef[c[m>>2]&4095]((c[o>>2]|0)+(-8-(n<<4))|0,n,b);g=i;h=j}}while(0);j=c[h>>2]|0;ef[c[f>>2]&4095]((c[g>>2]|0)+(-16-(j<<3))|0,j,b);e=c[d>>2]|0}j=a+116|0;g=a+12480|0;if((e|0)==((c[j>>2]|0)-1|0)){e=a+15396|0;do{if((c[g>>2]|0)<((c[a+808>>2]|0)+2|0)){p=a+12544|0;q=a+148|0}else{f=a+12544|0;h=a+148|0;i=c[h>>2]|0;ef[c[e>>2]&4095]((c[f>>2]|0)+(-(i<<4)|0)|0,i,b);i=a+15400|0;if((c[d>>2]|0)!=0){n=c[h>>2]|0;ef[c[i>>2]&4095]((c[f>>2]|0)+(-(n<<5)|0)|0,n,b)}n=c[h>>2]|0;ef[c[i>>2]&4095]((c[f>>2]|0)+(-(n<<5)|8)|0,n,b);n=a+15388|0;i=a+152|0;o=a+15392|0;m=a+12548|0;k=c[i>>2]|0;ef[c[n>>2]&4095]((c[m>>2]|0)+(-(k<<3)|0)|0,k,b);if((c[d>>2]|0)>1){k=c[i>>2]|0;ef[c[o>>2]&4095]((c[m>>2]|0)+(-(k<<4)|0)|0,k,b)}k=a+12552|0;m=c[i>>2]|0;ef[c[n>>2]&4095]((c[k>>2]|0)+(-(m<<3)|0)|0,m,b);if((c[d>>2]|0)<=1){p=f;q=h;break}m=c[i>>2]|0;ef[c[o>>2]&4095]((c[k>>2]|0)+(-(m<<4)|0)|0,m,b);p=f;q=h}}while(0);h=c[q>>2]|0;ef[c[e>>2]&4095]((c[p>>2]|0)+(-(h<<3)|0)|0,h,b)}if((c[g>>2]|0)!=(c[a+812>>2]|0)){return}g=c[d>>2]|0;do{if((g|0)==0){r=0}else{h=a+15400|0;if((g|0)>1){p=a+12544|0;e=a+148|0;q=c[e>>2]|0;ef[c[h>>2]&4095]((c[p>>2]|0)+(-16-(q<<4))|0,q,b);s=p;t=e}else{s=a+12544|0;t=a+148|0}e=c[t>>2]|0;ef[c[h>>2]&4095]((c[s>>2]|0)+(-8-(e<<4))|0,e,b);e=c[d>>2]|0;if((e|0)<=1){r=e;break}e=a+15392|0;h=a+152|0;p=c[h>>2]|0;ef[c[e>>2]&4095]((c[a+12548>>2]|0)+(-8-(p<<3))|0,p,b);p=c[h>>2]|0;ef[c[e>>2]&4095]((c[a+12552>>2]|0)+(-8-(p<<3))|0,p,b);r=c[d>>2]|0}}while(0);if((r|0)!=((c[j>>2]|0)-1|0)){return}j=a+15400|0;if((r|0)==0){u=a+12544|0;v=a+148|0}else{r=a+12544|0;s=a+148|0;t=c[s>>2]|0;ef[c[j>>2]&4095]((c[r>>2]|0)+(-(t<<4)|0)|0,t,b);u=r;v=s}s=c[v>>2]|0;ef[c[j>>2]&4095]((c[u>>2]|0)+(-(s<<4)|8)|0,s,b);if((c[d>>2]|0)==0){return}d=a+15392|0;s=a+152|0;u=c[s>>2]|0;ef[c[d>>2]&4095]((c[a+12548>>2]|0)+(-(u<<3)|0)|0,u,b);u=c[s>>2]|0;ef[c[d>>2]&4095]((c[a+12552>>2]|0)+(-(u<<3)|0)|0,u,b);return}function v7a(a){a=a|0;c[a>>2]=274;c[a+8>>2]=2320;c[a+4>>2]=1250;c[a+12>>2]=784;c[a+16>>2]=1368;c[a+24>>2]=1728;c[a+20>>2]=1274;c[a+28>>2]=1418;c[a+36>>2]=402;c[a+32>>2]=360;c[a+44>>2]=168;c[a+40>>2]=152;c[a+48>>2]=124;c[a+52>>2]=432;c[a+56>>2]=578;c[a+60>>2]=1668;c[a+64>>2]=2154;c[a+68>>2]=2130;c[a+72>>2]=524;c[a+76>>2]=266;c[a+80>>2]=840;c[a+84>>2]=1020;c[a+88>>2]=820;c[a+92>>2]=150;c[a+96>>2]=192;c[a+100>>2]=584;c[a+104>>2]=534;c[a+108>>2]=824;c[a+112>>2]=444;c[a+116>>2]=304;c[a+120>>2]=362;c[a+124>>2]=464;c[a+128>>2]=928;c[a+132>>2]=476;c[a+136>>2]=714;c[a+140>>2]=610;c[a+144>>2]=858;c[a+148>>2]=166;c[a+152>>2]=214;c[a+156>>2]=474;c[a+160>>2]=1002;c[a+164>>2]=580;c[a+168>>2]=882;c[a+172>>2]=902;c[a+176>>2]=86;c[a+180>>2]=952;c[a+184>>2]=762;c[a+188>>2]=726;c[a+192>>2]=204;c[a+196>>2]=814;c[a+200>>2]=316;c[a+212>>2]=110;c[a+204>>2]=128;c[a+216>>2]=64;c[a+224>>2]=116;c[a+228>>2]=336;c[a+232>>2]=358;c[a+236>>2]=304;c[a+240>>2]=156;return}function w7a(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=i;i=i+128|0;d=c|0;e=0;f=a;g=d;while(1){h=b[f>>1]|0;j=b[f+64>>1]|0;k=((j+h|0)*12|0)+4|0;l=((h-j|0)*12|0)+4|0;j=b[f+32>>1]|0;h=b[f+96>>1]|0;m=(h*6|0)+(j<<4)|0;n=(j*6|0)-(h<<4)|0;h=m+k|0;j=n+l|0;o=l-n|0;n=k-m|0;m=b[f+16>>1]|0;k=b[f+48>>1]|0;l=b[f+80>>1]|0;p=b[f+112>>1]|0;q=(k*15|0)+(m<<4)+(l*9|0)+(p<<2)|0;r=(m*15|0)-(k<<2)-(l<<4)+(p*-9|0)|0;s=(m*9|0)-(k<<4)+(l<<2)+(p*15|0)|0;t=(k*-9|0)+(m<<2)+(l*15|0)-(p<<4)|0;b[g>>1]=(q+h|0)>>>3;b[g+2>>1]=(r+j|0)>>>3;b[g+4>>1]=(s+o|0)>>>3;b[g+6>>1]=(t+n|0)>>>3;b[g+8>>1]=(n-t|0)>>>3;b[g+10>>1]=(o-s|0)>>>3;b[g+12>>1]=(j-r|0)>>>3;b[g+14>>1]=(h-q|0)>>>3;q=e+1|0;if((q|0)<8){e=q;f=f+2|0;g=g+16|0}else{u=0;v=d;w=a;break}}while(1){a=b[v>>1]|0;d=b[v+64>>1]|0;g=((d+a|0)*12|0)+64|0;f=((a-d|0)*12|0)+64|0;d=b[v+32>>1]|0;a=b[v+96>>1]|0;e=(a*6|0)+(d<<4)|0;q=(d*6|0)-(a<<4)|0;a=e+g|0;d=q+f|0;h=f-q|0;q=g-e|0;e=b[v+16>>1]|0;g=b[v+48>>1]|0;f=b[v+80>>1]|0;r=b[v+112>>1]|0;j=(g*15|0)+(e<<4)+(f*9|0)+(r<<2)|0;s=(e*15|0)-(g<<2)-(f<<4)+(r*-9|0)|0;o=(e*9|0)-(g<<4)+(f<<2)+(r*15|0)|0;t=(g*-9|0)+(e<<2)+(f*15|0)-(r<<4)|0;b[w>>1]=(j+a|0)>>>7;b[w+16>>1]=(s+d|0)>>>7;b[w+32>>1]=(o+h|0)>>>7;b[w+48>>1]=(t+q|0)>>>7;b[w+64>>1]=((q|1)-t|0)>>>7;b[w+80>>1]=((h|1)-o|0)>>>7;b[w+96>>1]=((d|1)-s|0)>>>7;b[w+112>>1]=((a|1)-j|0)>>>7;j=u+1|0;if((j|0)<8){u=j;v=v+2|0;w=w+2|0}else{break}}i=c;return}function x7a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=0;h=f;while(1){i=b[h>>1]|0;j=h+4|0;k=b[j>>1]|0;l=((k+i|0)*17|0)+4|0;m=((i-k|0)*17|0)+4|0;k=h+2|0;i=b[k>>1]|0;n=h+6|0;o=b[n>>1]|0;p=(o*10|0)+(i*22|0)|0;q=(o*22|0)+(i*-10|0)|0;b[h>>1]=(p+l|0)>>>3;b[k>>1]=(m-q|0)>>>3;b[j>>1]=(q+m|0)>>>3;b[n>>1]=(l-p|0)>>>3;p=g+1|0;if((p|0)<8){g=p;h=h+16|0}else{break}}h=e<<1;g=e*3|0;p=e<<2;l=e*5|0;n=e*6|0;m=e*7|0;q=0;j=c;c=f;while(1){f=b[c>>1]|0;k=b[c+64>>1]|0;i=((k+f|0)*12|0)+64|0;o=((f-k|0)*12|0)+64|0;k=b[c+32>>1]|0;f=b[c+96>>1]|0;r=(f*6|0)+(k<<4)|0;s=(k*6|0)-(f<<4)|0;f=r+i|0;k=s+o|0;t=o-s|0;s=i-r|0;r=b[c+16>>1]|0;i=b[c+48>>1]|0;o=b[c+80>>1]|0;u=b[c+112>>1]|0;v=(i*15|0)+(r<<4)+(o*9|0)+(u<<2)|0;w=(r*15|0)-(i<<2)-(o<<4)+(u*-9|0)|0;x=(r*9|0)-(i<<4)+(o<<2)+(u*15|0)|0;y=(i*-9|0)+(r<<2)+(o*15|0)-(u<<4)|0;u=(v+f>>7)+(d[j]|0)|0;if(u>>>0>255>>>0){z=-u>>31&255}else{z=u&255}a[j]=z;u=j+e|0;o=(d[u]|0)+(w+k>>7)|0;if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}a[u]=A;u=j+h|0;o=(d[u]|0)+(x+t>>7)|0;if(o>>>0>255>>>0){B=-o>>31&255}else{B=o&255}a[u]=B;u=j+g|0;o=(d[u]|0)+(y+s>>7)|0;if(o>>>0>255>>>0){C=-o>>31&255}else{C=o&255}a[u]=C;u=j+p|0;o=(d[u]|0)+((s|1)-y>>7)|0;if(o>>>0>255>>>0){D=-o>>31&255}else{D=o&255}a[u]=D;u=j+l|0;o=(d[u]|0)+((t|1)-x>>7)|0;if(o>>>0>255>>>0){E=-o>>31&255}else{E=o&255}a[u]=E;u=j+n|0;o=(d[u]|0)+((k|1)-w>>7)|0;if(o>>>0>255>>>0){F=-o>>31&255}else{F=o&255}a[u]=F;u=j+m|0;o=(d[u]|0)+((f|1)-v>>7)|0;if(o>>>0>255>>>0){G=-o>>31&255}else{G=o&255}a[u]=G;u=q+1|0;if((u|0)<4){q=u;j=j+1|0;c=c+2|0}else{break}}return}function y7a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=0;h=f;while(1){i=b[h>>1]|0;j=h+8|0;k=b[j>>1]|0;l=((k+i|0)*12|0)+4|0;m=((i-k|0)*12|0)+4|0;k=h+4|0;i=b[k>>1]|0;n=h+12|0;o=b[n>>1]|0;p=(o*6|0)+(i<<4)|0;q=(i*6|0)-(o<<4)|0;o=p+l|0;i=q+m|0;r=m-q|0;q=l-p|0;p=h+2|0;l=b[p>>1]|0;m=h+6|0;s=b[m>>1]|0;t=h+10|0;u=b[t>>1]|0;v=h+14|0;w=b[v>>1]|0;x=(s*15|0)+(l<<4)+(u*9|0)+(w<<2)|0;y=(l*15|0)-(s<<2)-(u<<4)+(w*-9|0)|0;z=(l*9|0)-(s<<4)+(u<<2)+(w*15|0)|0;A=(s*-9|0)+(l<<2)+(u*15|0)-(w<<4)|0;b[h>>1]=(x+o|0)>>>3;b[p>>1]=(y+i|0)>>>3;b[k>>1]=(z+r|0)>>>3;b[m>>1]=(A+q|0)>>>3;b[j>>1]=(q-A|0)>>>3;b[t>>1]=(r-z|0)>>>3;b[n>>1]=(i-y|0)>>>3;b[v>>1]=(o-x|0)>>>3;x=g+1|0;if((x|0)<4){g=x;h=h+16|0}else{break}}h=e<<1;g=e*3|0;x=0;o=c;c=f;while(1){f=b[c>>1]|0;v=b[c+32>>1]|0;y=((v+f|0)*17|0)+64|0;i=((f-v|0)*17|0)+64|0;v=b[c+16>>1]|0;f=b[c+48>>1]|0;n=(f*10|0)+(v*22|0)|0;z=(f*22|0)+(v*-10|0)|0;v=(n+y>>7)+(d[o]|0)|0;if(v>>>0>255>>>0){B=-v>>31&255}else{B=v&255}a[o]=B;v=o+e|0;f=(d[v]|0)+(i-z>>7)|0;if(f>>>0>255>>>0){C=-f>>31&255}else{C=f&255}a[v]=C;v=o+h|0;f=(d[v]|0)+(z+i>>7)|0;if(f>>>0>255>>>0){D=-f>>31&255}else{D=f&255}a[v]=D;v=o+g|0;f=(d[v]|0)+(y-n>>7)|0;if(f>>>0>255>>>0){E=-f>>31&255}else{E=f&255}a[v]=E;v=x+1|0;if((v|0)<8){x=v;o=o+1|0;c=c+2|0}else{break}}return}function z7a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=0;h=f;while(1){i=b[h>>1]|0;j=h+4|0;k=b[j>>1]|0;l=((k+i|0)*17|0)+4|0;m=((i-k|0)*17|0)+4|0;k=h+2|0;i=b[k>>1]|0;n=h+6|0;o=b[n>>1]|0;p=(o*10|0)+(i*22|0)|0;q=(o*22|0)+(i*-10|0)|0;b[h>>1]=(p+l|0)>>>3;b[k>>1]=(m-q|0)>>>3;b[j>>1]=(q+m|0)>>>3;b[n>>1]=(l-p|0)>>>3;p=g+1|0;if((p|0)<4){g=p;h=h+16|0}else{break}}h=e<<1;g=e*3|0;p=c;c=0;l=f;while(1){f=b[l>>1]|0;n=b[l+32>>1]|0;m=((n+f|0)*17|0)+64|0;q=((f-n|0)*17|0)+64|0;n=b[l+16>>1]|0;f=b[l+48>>1]|0;j=(f*10|0)+(n*22|0)|0;k=(f*22|0)+(n*-10|0)|0;n=(j+m>>7)+(d[p]|0)|0;if(n>>>0>255>>>0){r=-n>>31&255}else{r=n&255}a[p]=r;n=p+e|0;f=(d[n]|0)+(q-k>>7)|0;if(f>>>0>255>>>0){s=-f>>31&255}else{s=f&255}a[n]=s;n=p+h|0;f=(d[n]|0)+(k+q>>7)|0;if(f>>>0>255>>>0){t=-f>>31&255}else{t=f&255}a[n]=t;n=p+g|0;f=(d[n]|0)+(m-j>>7)|0;if(f>>>0>255>>>0){u=-f>>31&255}else{u=f&255}a[n]=u;n=c+1|0;if((n|0)<4){p=p+1|0;c=n;l=l+2|0}else{break}}return}function A7a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=((((b[f>>1]|0)*3|0)+1>>1)*3|0)+16>>5;f=c;c=0;while(1){h=(d[f]|0)+g|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[f]=i;h=f+1|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=f+2|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=f+3|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=f+4|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[h]=n;h=f+5|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[h]=o;h=f+6|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;h=f+7|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[h]=q;h=c+1|0;if((h|0)<8){f=f+e|0;c=h}else{break}}return}function B7a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=((((b[f>>1]|0)*17|0)+4>>3)*12|0)+64>>7;f=c;c=0;while(1){h=(d[f]|0)+g|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[f]=i;h=f+1|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=f+2|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=f+3|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=c+1|0;if((h|0)<8){f=f+e|0;c=h}else{break}}return}function C7a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=((((b[f>>1]|0)*3|0)+1>>1)*17|0)+64>>7;f=c;c=0;while(1){h=(d[f]|0)+g|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[f]=i;h=f+1|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=f+2|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=f+3|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=f+4|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[h]=n;h=f+5|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[h]=o;h=f+6|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;h=f+7|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[h]=q;h=c+1|0;if((h|0)<4){f=f+e|0;c=h}else{break}}return}function D7a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=((((b[f>>1]|0)*17|0)+4>>3)*17|0)+64>>7;f=c;c=0;while(1){h=(d[f]|0)+g|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[f]=i;h=f+1|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=f+2|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=f+3|0;j=(d[h]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=c+1|0;if((h|0)<4){f=f+e|0;c=h}else{break}}return}function E7a(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=0;f=b;b=1;while(1){g=f-2|0;h=d[g]|0;i=f-1|0;j=d[i]|0;k=d[f]|0;l=f+1|0;m=d[l]|0;n=h-m|0;o=b+3+n>>3;p=4-b+j-k+n>>3;a[g]=h-o;h=j-p|0;if(h>>>0>255>>>0){q=-h>>31&255}else{q=h&255}a[i]=q;i=p+k|0;if(i>>>0>255>>>0){r=-i>>31&255}else{r=i&255}a[f]=r;a[l]=o+m;m=e+1|0;if((m|0)<8){e=m;f=f+c|0;b=b^1}else{break}}return}function F7a(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=c*-2|0;f=-c|0;g=0;h=b;b=1;while(1){i=h+e|0;j=d[i]|0;k=h+f|0;l=d[k]|0;m=d[h]|0;n=h+c|0;o=d[n]|0;p=j-o|0;q=b+3+p>>3;r=4-b+l-m+p>>3;a[i]=j-q;j=l-r|0;if(j>>>0>255>>>0){s=-j>>31&255}else{s=j&255}a[k]=s;k=r+m|0;if(k>>>0>255>>>0){t=-k>>31&255}else{t=k&255}a[h]=t;a[n]=q+o;o=g+1|0;if((o|0)<8){g=o;h=h+1|0;b=b^1}else{break}}return}function G7a(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=0;e=c;c=a;a=4;f=3;while(1){g=c+12|0;h=b[g>>1]|0;i=c+14|0;j=b[i>>1]|0;k=b[e>>1]|0;l=e+2|0;m=b[l>>1]|0;n=h-m|0;o=j-k+n|0;b[g>>1]=((h<<3)+a-n|0)>>>3;b[i>>1]=((j<<3)+f-o|0)>>>3;b[e>>1]=((k<<3)+a+o|0)>>>3;b[l>>1]=(n+f+(m<<3)|0)>>>3;m=d+1|0;if((m|0)<8){d=m;e=e+16|0;c=c+16|0;a=7-a|0;f=7-f|0}else{break}}return}function H7a(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=0;e=c;c=a;a=4;f=3;while(1){g=c+96|0;h=b[g>>1]|0;i=c+112|0;j=b[i>>1]|0;k=b[e>>1]|0;l=e+16|0;m=b[l>>1]|0;n=h-m|0;o=j-k+n|0;b[g>>1]=((h<<3)+a-n|0)>>>3;b[i>>1]=((j<<3)+f-o|0)>>>3;b[e>>1]=((k<<3)+a+o|0)>>>3;b[l>>1]=(n+f+(m<<3)|0)>>>3;m=d+1|0;if((m|0)<8){d=m;e=e+2|0;c=c+2|0;a=7-a|0;f=7-f|0}else{break}}return}function I7a(a,b,c){a=a|0;b=b|0;c=c|0;B8a(a,1,b,4,c);return}function J7a(a,b,c){a=a|0;b=b|0;c=c|0;B8a(a,b,1,4,c);return}function K7a(a,b,c){a=a|0;b=b|0;c=c|0;B8a(a,1,b,8,c);return}function L7a(a,b,c){a=a|0;b=b|0;c=c|0;B8a(a,b,1,8,c);return}function M7a(a,b,c){a=a|0;b=b|0;c=c|0;B8a(a,1,b,16,c);return}function N7a(a,b,c){a=a|0;b=b|0;c=c|0;B8a(a,b,1,16,c);return}function O7a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(e+4)|0;c[a+(e+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=e<<1;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;e=b+g|0;c[a+h>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=b+(g+4)|0;c[a+(h+4)>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function P7a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=32-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=b+1|0;j=g+((d[f+(b-1)|0]|0)*-4|0)+((d[f+b|0]|0)*53|0)+((d[f+i|0]|0)*18|0)+((d[f+(b+2)|0]|0)*-3|0)>>6;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h+b|0]=k;if((i|0)<8){b=i}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function Q7a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=8-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=b+1|0;j=g-(d[f+(b-1)|0]|0)-(d[f+(b+2)|0]|0)+(((d[f+i|0]|0)+(d[f+b|0]|0)|0)*9|0)>>4;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h+b|0]=k;if((i|0)<8){b=i}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function R7a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=32-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=b+1|0;j=g+((d[f+(b-1)|0]|0)*-3|0)+((d[f+b|0]|0)*18|0)+((d[f+i|0]|0)*53|0)-((d[f+(b+2)|0]|0)<<2)>>6;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h+b|0]=k;if((i|0)<8){b=i}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function S7a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=e<<1;h=f+31|0;f=c;c=0;i=b;while(1){b=0;do{j=h+((d[f+(b-e)|0]|0)*-4|0)+((d[f+b|0]|0)*53|0)+((d[f+(b+e)|0]|0)*18|0)+((d[f+(b+g)|0]|0)*-3|0)>>6;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i+b|0]=k;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function T7a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-4|0)+((l<<16>>16)*53|0)+((k<<16>>16)*18|0)+((p<<16>>16)*-3|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function U7a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n-(m<<16>>16)-(p<<16>>16)+(((k<<16>>16)+(l<<16>>16)|0)*9|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function V7a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-3|0)+((l<<16>>16)*18|0)+((k<<16>>16)*53|0)-(p<<16>>16<<2)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function W7a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=e<<1;h=f+7|0;f=c;c=0;i=b;while(1){b=0;do{j=h-(d[f+(b-e)|0]|0)-(d[f+(b+g)|0]|0)+(((d[f+(b+e)|0]|0)+(d[f+b|0]|0)|0)*9|0)>>4;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i+b|0]=k;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function X7a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l-(d[m+(o-f)|0]|0)-(d[m+(o+k)|0]|0)+(((d[m+(o+f)|0]|0)+(d[m+o|0]|0)|0)*9|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-4|0)+((l<<16>>16)*53|0)+((k<<16>>16)*18|0)+((p<<16>>16)*-3|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function Y7a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=e-1|0;e=0;m=j|0;while(1){n=0;do{b[m+(n<<1)>>1]=(g-(d[l+(n-f)|0]|0)-(d[l+(n+k)|0]|0)+(((d[l+(n+f)|0]|0)+(d[l+n|0]|0)|0)*9|0)|0)>>>1;n=n+1|0;}while((n|0)<11);n=e+1|0;if((n|0)<8){l=l+f|0;e=n;m=m+22|0}else{break}}m=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;l=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){n=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=m-(l<<16>>16)-(p<<16>>16)+(((k<<16>>16)+(n<<16>>16)|0)*9|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;l=n;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function Z7a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l-(d[m+(o-f)|0]|0)-(d[m+(o+k)|0]|0)+(((d[m+(o+f)|0]|0)+(d[m+o|0]|0)|0)*9|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-3|0)+((l<<16>>16)*18|0)+((k<<16>>16)*53|0)-(p<<16>>16<<2)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function _7a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=e<<1;h=f+31|0;f=c;c=0;i=b;while(1){b=0;do{j=h+((d[f+(b-e)|0]|0)*-3|0)+((d[f+b|0]|0)*18|0)+((d[f+(b+e)|0]|0)*53|0)-((d[f+(b+g)|0]|0)<<2)>>6;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i+b|0]=k;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function $7a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-4|0)+((l<<16>>16)*53|0)+((k<<16>>16)*18|0)+((p<<16>>16)*-3|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function a8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n-(m<<16>>16)-(p<<16>>16)+(((k<<16>>16)+(l<<16>>16)|0)*9|0)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function b8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=b[c+(j<<1)>>1]|0;o=j+1|0;p=b[c+(j+2<<1)>>1]|0;q=n+((m<<16>>16)*-3|0)+((l<<16>>16)*18|0)+((k<<16>>16)*53|0)-(p<<16>>16<<2)>>7;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[e+j|0]=r;if((o|0)<8){j=o;m=l;k=p}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function c8a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=f;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[g>>2]=(j|h)-((j^h)>>>1&2139062143);h=b+4|0;j=c[h>>2]|0;g=f+4|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[h>>2]=(i|j)-((i^j)>>>1&2139062143);j=a+1|0;if((j|0)<8){f=f+e|0;b=b+e|0;a=j}else{break}}return}function d8a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=32-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=h+b|0;j=b+1|0;k=g+((d[f+(b-1)|0]|0)*-4|0)+((d[f+b|0]|0)*53|0)+((d[f+j|0]|0)*18|0)+((d[f+(b+2)|0]|0)*-3|0)>>6;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i]=((d[i]|0)+1+(l&255)|0)>>>1;if((j|0)<8){b=j}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function e8a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=8-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=h+b|0;j=b+1|0;k=g-(d[f+(b-1)|0]|0)-(d[f+(b+2)|0]|0)+(((d[f+j|0]|0)+(d[f+b|0]|0)|0)*9|0)>>4;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i]=((d[i]|0)+1+(l&255)|0)>>>1;if((j|0)<8){b=j}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function f8a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=32-f|0;f=c;c=0;h=b;while(1){b=0;while(1){i=h+b|0;j=b+1|0;k=g+((d[f+(b-1)|0]|0)*-3|0)+((d[f+b|0]|0)*18|0)+((d[f+j|0]|0)*53|0)-((d[f+(b+2)|0]|0)<<2)>>6;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[i]=((d[i]|0)+1+(l&255)|0)>>>1;if((j|0)<8){b=j}else{break}}b=c+1|0;if((b|0)<8){f=f+e|0;c=b;h=h+e|0}else{break}}return}function g8a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e<<1;h=f+31|0;f=c;c=0;i=b;while(1){b=0;do{j=i+b|0;k=h+((d[f+(b-e)|0]|0)*-4|0)+((d[f+b|0]|0)*53|0)+((d[f+(b+e)|0]|0)*18|0)+((d[f+(b+g)|0]|0)*-3|0)>>6;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=((d[j]|0)+1+(l&255)|0)>>>1;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function h8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-4|0)+((o<<16>>16)*53|0)+((k<<16>>16)*18|0)+((q<<16>>16)*-3|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function i8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n-(m<<16>>16)-(q<<16>>16)+(((k<<16>>16)+(o<<16>>16)|0)*9|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function j8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-4|0)+((d[m+o|0]|0)*53|0)+((d[m+(o+f)|0]|0)*18|0)+((d[m+(o+k)|0]|0)*-3|0)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-3|0)+((o<<16>>16)*18|0)+((k<<16>>16)*53|0)-(q<<16>>16<<2)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function k8a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e<<1;h=f+7|0;f=c;c=0;i=b;while(1){b=0;do{j=i+b|0;k=h-(d[f+(b-e)|0]|0)-(d[f+(b+g)|0]|0)+(((d[f+(b+e)|0]|0)+(d[f+b|0]|0)|0)*9|0)>>4;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=((d[j]|0)+1+(l&255)|0)>>>1;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function l8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l-(d[m+(o-f)|0]|0)-(d[m+(o+k)|0]|0)+(((d[m+(o+f)|0]|0)+(d[m+o|0]|0)|0)*9|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-4|0)+((o<<16>>16)*53|0)+((k<<16>>16)*18|0)+((q<<16>>16)*-3|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function m8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=e-1|0;e=0;m=j|0;while(1){n=0;do{b[m+(n<<1)>>1]=(g-(d[l+(n-f)|0]|0)-(d[l+(n+k)|0]|0)+(((d[l+(n+f)|0]|0)+(d[l+n|0]|0)|0)*9|0)|0)>>>1;n=n+1|0;}while((n|0)<11);n=e+1|0;if((n|0)<8){l=l+f|0;e=n;m=m+22|0}else{break}}m=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;l=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){n=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=m-(l<<16>>16)-(q<<16>>16)+(((k<<16>>16)+(o<<16>>16)|0)*9|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[n]=((d[n]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;l=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function n8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l-(d[m+(o-f)|0]|0)-(d[m+(o+k)|0]|0)+(((d[m+(o+f)|0]|0)+(d[m+o|0]|0)|0)*9|0)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-3|0)+((o<<16>>16)*18|0)+((k<<16>>16)*53|0)-(q<<16>>16<<2)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function o8a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e<<1;h=f+31|0;f=c;c=0;i=b;while(1){b=0;do{j=i+b|0;k=h+((d[f+(b-e)|0]|0)*-3|0)+((d[f+b|0]|0)*18|0)+((d[f+(b+e)|0]|0)*53|0)-((d[f+(b+g)|0]|0)<<2)>>6;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[j]=((d[j]|0)+1+(l&255)|0)>>>1;b=b+1|0;}while((b|0)<8);b=c+1|0;if((b|0)<8){f=f+e|0;c=b;i=i+e|0}else{break}}return}function p8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-4|0)+((o<<16>>16)*53|0)+((k<<16>>16)*18|0)+((q<<16>>16)*-3|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function q8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+3|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>3;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n-(m<<16>>16)-(q<<16>>16)+(((k<<16>>16)+(o<<16>>16)|0)*9|0)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function r8a(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+176|0;j=h|0;k=f<<1;l=g+15|0;m=e-1|0;e=0;n=j|0;while(1){o=0;do{b[n+(o<<1)>>1]=(l+((d[m+(o-f)|0]|0)*-3|0)+((d[m+o|0]|0)*18|0)+((d[m+(o+f)|0]|0)*53|0)-((d[m+(o+k)|0]|0)<<2)|0)>>>5;o=o+1|0;}while((o|0)<11);o=e+1|0;if((o|0)<8){m=m+f|0;e=o;n=n+22|0}else{break}}n=64-g|0;g=0;e=c;c=j+2|0;while(1){j=0;m=b[c-2>>1]|0;k=b[c+2>>1]|0;while(1){l=e+j|0;o=b[c+(j<<1)>>1]|0;p=j+1|0;q=b[c+(j+2<<1)>>1]|0;r=n+((m<<16>>16)*-3|0)+((o<<16>>16)*18|0)+((k<<16>>16)*53|0)-(q<<16>>16<<2)>>7;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[l]=((d[l]|0)+1+(s&255)|0)>>>1;if((p|0)<8){j=p;m=o;k=q}else{break}}k=g+1|0;if((k|0)<8){g=k;e=e+f|0;c=c+22|0}else{break}}i=h;return}function s8a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=e+5|0;p=e+6|0;q=e+7|0;r=e+8|0;s=c;c=b;b=0;while(1){t=ca(d[s]|0,k)|0;u=s+1|0;v=ca(d[u]|0,l)|0;w=s+e|0;x=ca(d[w]|0,j)|0;y=s+g|0;a[c]=(t+28+v+x+(ca(d[y]|0,i)|0)|0)>>>6;x=ca(d[u]|0,k)|0;u=s+2|0;v=ca(d[u]|0,l)|0;t=ca(d[y]|0,j)|0;y=s+h|0;a[c+1|0]=(x+28+v+t+(ca(d[y]|0,i)|0)|0)>>>6;t=ca(d[u]|0,k)|0;u=s+3|0;v=ca(d[u]|0,l)|0;x=ca(d[y]|0,j)|0;y=s+m|0;a[c+2|0]=(t+28+v+x+(ca(d[y]|0,i)|0)|0)>>>6;x=ca(d[u]|0,k)|0;u=s+4|0;v=ca(d[u]|0,l)|0;t=ca(d[y]|0,j)|0;y=s+n|0;a[c+3|0]=(x+28+v+t+(ca(d[y]|0,i)|0)|0)>>>6;t=ca(d[u]|0,k)|0;u=s+5|0;v=ca(d[u]|0,l)|0;x=ca(d[y]|0,j)|0;y=s+o|0;a[c+4|0]=(t+28+v+x+(ca(d[y]|0,i)|0)|0)>>>6;x=ca(d[u]|0,k)|0;u=s+6|0;v=ca(d[u]|0,l)|0;t=ca(d[y]|0,j)|0;y=s+p|0;a[c+5|0]=(x+28+v+t+(ca(d[y]|0,i)|0)|0)>>>6;t=ca(d[u]|0,k)|0;u=s+7|0;v=ca(d[u]|0,l)|0;x=ca(d[y]|0,j)|0;y=s+q|0;a[c+6|0]=(t+28+v+x+(ca(d[y]|0,i)|0)|0)>>>6;x=ca(d[u]|0,k)|0;u=ca(d[s+8|0]|0,l)|0;v=ca(d[y]|0,j)|0;a[c+7|0]=(x+28+u+v+(ca(d[s+r|0]|0,i)|0)|0)>>>6;v=b+1|0;if((v|0)<(f|0)){s=w;c=c+e|0;b=v}else{break}}return}function t8a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=e+5|0;p=e+6|0;q=e+7|0;r=e+8|0;s=c;c=b;b=0;while(1){t=ca(d[s]|0,k)|0;u=s+1|0;v=ca(d[u]|0,l)|0;w=s+e|0;x=ca(d[w]|0,j)|0;y=s+g|0;a[c]=((d[c]|0)+1+((t+28+v+x+(ca(d[y]|0,i)|0)|0)>>>6)|0)>>>1;x=c+1|0;v=ca(d[u]|0,k)|0;u=s+2|0;t=ca(d[u]|0,l)|0;z=ca(d[y]|0,j)|0;y=s+h|0;a[x]=((d[x]|0)+1+((v+28+t+z+(ca(d[y]|0,i)|0)|0)>>>6)|0)>>>1;z=c+2|0;t=ca(d[u]|0,k)|0;u=s+3|0;v=ca(d[u]|0,l)|0;x=ca(d[y]|0,j)|0;y=s+m|0;a[z]=((d[z]|0)+1+((t+28+v+x+(ca(d[y]|0,i)|0)|0)>>>6)|0)>>>1;x=c+3|0;v=ca(d[u]|0,k)|0;u=s+4|0;t=ca(d[u]|0,l)|0;z=ca(d[y]|0,j)|0;y=s+n|0;a[x]=((d[x]|0)+1+((v+28+t+z+(ca(d[y]|0,i)|0)|0)>>>6)|0)>>>1;z=c+4|0;t=ca(d[u]|0,k)|0;u=s+5|0;v=ca(d[u]|0,l)|0;x=ca(d[y]|0,j)|0;y=s+o|0;a[z]=((d[z]|0)+1+((t+28+v+x+(ca(d[y]|0,i)|0)|0)>>>6)|0)>>>1;x=c+5|0;v=ca(d[u]|0,k)|0;u=s+6|0;t=ca(d[u]|0,l)|0;z=ca(d[y]|0,j)|0;y=s+p|0;a[x]=((d[x]|0)+1+((v+28+t+z+(ca(d[y]|0,i)|0)|0)>>>6)|0)>>>1;z=c+6|0;t=ca(d[u]|0,k)|0;u=s+7|0;v=ca(d[u]|0,l)|0;x=ca(d[y]|0,j)|0;y=s+q|0;a[z]=((d[z]|0)+1+((t+28+v+x+(ca(d[y]|0,i)|0)|0)>>>6)|0)>>>1;x=c+7|0;v=ca(d[u]|0,k)|0;u=ca(d[s+8|0]|0,l)|0;t=ca(d[y]|0,j)|0;a[x]=((d[x]|0)+1+((v+28+u+t+(ca(d[s+r|0]|0,i)|0)|0)>>>6)|0)>>>1;t=b+1|0;if((t|0)<(f|0)){s=w;c=c+e|0;b=t}else{break}}return}function u8a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=c;c=b;b=0;while(1){p=ca(d[o]|0,k)|0;q=o+1|0;r=ca(d[q]|0,l)|0;s=o+e|0;t=ca(d[s]|0,j)|0;u=o+g|0;a[c]=(p+28+r+t+(ca(d[u]|0,i)|0)|0)>>>6;t=ca(d[q]|0,k)|0;q=o+2|0;r=ca(d[q]|0,l)|0;p=ca(d[u]|0,j)|0;u=o+h|0;a[c+1|0]=(t+28+r+p+(ca(d[u]|0,i)|0)|0)>>>6;p=ca(d[q]|0,k)|0;q=o+3|0;r=ca(d[q]|0,l)|0;t=ca(d[u]|0,j)|0;u=o+m|0;a[c+2|0]=(p+28+r+t+(ca(d[u]|0,i)|0)|0)>>>6;t=ca(d[q]|0,k)|0;q=ca(d[o+4|0]|0,l)|0;r=ca(d[u]|0,j)|0;a[c+3|0]=(t+28+q+r+(ca(d[o+n|0]|0,i)|0)|0)>>>6;r=b+1|0;if((r|0)<(f|0)){o=s;c=c+e|0;b=r}else{break}}return}function v8a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=c;c=b;b=0;while(1){p=ca(d[o]|0,k)|0;q=o+1|0;r=ca(d[q]|0,l)|0;s=o+e|0;t=ca(d[s]|0,j)|0;u=o+g|0;a[c]=((d[c]|0)+1+((p+28+r+t+(ca(d[u]|0,i)|0)|0)>>>6)|0)>>>1;t=c+1|0;r=ca(d[q]|0,k)|0;q=o+2|0;p=ca(d[q]|0,l)|0;v=ca(d[u]|0,j)|0;u=o+h|0;a[t]=((d[t]|0)+1+((r+28+p+v+(ca(d[u]|0,i)|0)|0)>>>6)|0)>>>1;v=c+2|0;p=ca(d[q]|0,k)|0;q=o+3|0;r=ca(d[q]|0,l)|0;t=ca(d[u]|0,j)|0;u=o+m|0;a[v]=((d[v]|0)+1+((p+28+r+t+(ca(d[u]|0,i)|0)|0)>>>6)|0)>>>1;t=c+3|0;r=ca(d[q]|0,k)|0;q=ca(d[o+4|0]|0,l)|0;p=ca(d[u]|0,j)|0;a[t]=((d[t]|0)+1+((r+28+q+p+(ca(d[o+n|0]|0,i)|0)|0)>>>6)|0)>>>1;p=b+1|0;if((p|0)<(f|0)){o=s;c=c+e|0;b=p}else{break}}return}function w8a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((g|0)==0){return}else{h=g;i=e;j=b}while(1){b=h-1|0;e=i>>16;g=d[c+e|0]|0;a[j]=((ca((d[c+(e+1)|0]|0)-g|0,i&65535)|0)>>>16)+g;if((b|0)==0){break}else{h=b;i=i+f|0;j=j+1|0}}return}function x8a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=e;i=c;j=b;k=g}while(1){g=k-1|0;b=d[i]|0;a[j]=((ca((d[h]|0)-b|0,f)|0)>>>16)+b;if((g|0)==0){break}else{h=h+1|0;i=i+1|0;j=j+1|0;k=g}}return}function y8a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((g|0)==0){return}else{h=e;i=c;j=b;k=g}while(1){g=k-1|0;b=d[i]|0;a[j]=((ca((d[h]|0)-b|0,f)|0)>>>16)+b;if((g|0)==0){break}else{h=h+1|0;i=i+1|0;j=j+1|0;k=g}}return}function z8a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;if((i|0)==0){return}else{j=g;k=e;l=c;m=b;n=i}while(1){i=n-1|0;b=d[l]|0;c=((ca((d[k]|0)-b|0,f)|0)>>16)+b|0;a[m]=((ca((d[j]|0)-c|0,h)|0)>>>16)+c;if((i|0)==0){break}else{j=j+1|0;k=k+1|0;l=l+1|0;m=m+1|0;n=i}}return}function A8a(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0;if((k|0)==0){return}else{l=h;m=g;n=e;o=c;p=b;q=k}while(1){k=q-1|0;b=d[o]|0;c=((ca((d[n]|0)-b|0,f)|0)>>16)+b|0;b=d[m]|0;a[p]=((ca(b-c+((ca((d[l]|0)-b|0,i)|0)>>16)|0,j)|0)>>>16)+c;if((k|0)==0){break}else{l=l+1|0;m=m+1|0;n=n+1|0;o=o+1|0;p=p+1|0;q=k}}return}function B8a(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;if((f|0)<=0){return}h=c<<1;i=e*-2|0;j=i+h|0;k=h+e|0;l=-e|0;m=h-e|0;n=e*-4|0;o=n+h|0;p=e*-3|0;q=p+h|0;r=e*3|0;s=r+h|0;t=e<<1;u=t+h|0;v=i+c|0;w=e+c|0;x=c-e|0;y=n+c|0;z=p+c|0;A=r+c|0;B=t+c|0;C=c*3|0;D=i+C|0;E=C+e|0;F=C-e|0;G=n+C|0;H=p+C|0;I=w*3|0;J=t+C|0;K=c<<2;L=0;M=b;while(1){b=M+h|0;N=d[M+j|0]|0;O=d[M+k|0]|0;P=M+m|0;Q=d[P]|0;R=d[b]|0;S=Q-R|0;T=(N-O<<1)+4+(S*-5|0)|0;U=T>>31;V=(T>>3^U)-U|0;do{if((V|0)<(g|0)){T=((d[M+o|0]|0)-Q<<1)+4+(((d[M+q|0]|0)-N|0)*-5|0)>>3;W=(T|0)>-1?T:-T|0;T=(R-(d[M+s|0]|0)<<1)+4+((O-(d[M+u|0]|0)|0)*-5|0)>>3;X=(T|0)>-1?T:-T|0;if(!((W|0)<(V|0)|(X|0)<(V|0))){break}T=S>>31;Y=(T^S)-T>>1;if((Y|0)==0){break}Z=(((W|0)>(X|0)?X:W)-V|0)*5|0;W=Z>>31;X=(W^Z)-W>>3;if((W^U|0)==(T|0)){W=(((X|0)>(Y|0)?Y:X)^T)-T|0;T=Q-W|0;if(T>>>0>255>>>0){_=-T>>31&255}else{_=T&255}a[P]=_;T=(d[b]|0)+W|0;if(T>>>0>255>>>0){$=-T>>31&255}else{$=T&255}a[b]=$}T=d[M+i|0]|0;W=d[M+e|0]|0;X=M+l|0;Y=d[X]|0;Z=d[M]|0;aa=Y-Z|0;ba=(T-W<<1)+4+(aa*-5|0)|0;ca=ba>>31;da=(ba>>3^ca)-ca|0;do{if((da|0)<(g|0)){ba=((d[M+n|0]|0)-Y<<1)+4+(((d[M+p|0]|0)-T|0)*-5|0)>>3;ea=(ba|0)>-1?ba:-ba|0;ba=(Z-(d[M+r|0]|0)<<1)+4+((W-(d[M+t|0]|0)|0)*-5|0)>>3;fa=(ba|0)>-1?ba:-ba|0;if(!((ea|0)<(da|0)|(fa|0)<(da|0))){break}ba=aa>>31;ga=(ba^aa)-ba>>1;if((ga|0)==0){break}ha=(((ea|0)>(fa|0)?fa:ea)-da|0)*5|0;ea=ha>>31;fa=(ea^ha)-ea>>3;if((ea^ca|0)!=(ba|0)){break}ea=(((fa|0)>(ga|0)?ga:fa)^ba)-ba|0;ba=Y-ea|0;if(ba>>>0>255>>>0){ia=-ba>>31&255}else{ia=ba&255}a[X]=ia;ba=(d[M]|0)+ea|0;if(ba>>>0>255>>>0){ja=-ba>>31&255}else{ja=ba&255}a[M]=ja}}while(0);X=M+c|0;Y=d[M+v|0]|0;ca=d[M+w|0]|0;da=M+x|0;aa=d[da]|0;W=d[X]|0;Z=aa-W|0;T=(Y-ca<<1)+4+(Z*-5|0)|0;ba=T>>31;ea=(T>>3^ba)-ba|0;do{if((ea|0)<(g|0)){T=((d[M+y|0]|0)-aa<<1)+4+(((d[M+z|0]|0)-Y|0)*-5|0)>>3;fa=(T|0)>-1?T:-T|0;T=(W-(d[M+A|0]|0)<<1)+4+((ca-(d[M+B|0]|0)|0)*-5|0)>>3;ga=(T|0)>-1?T:-T|0;if(!((fa|0)<(ea|0)|(ga|0)<(ea|0))){break}T=Z>>31;ha=(T^Z)-T>>1;if((ha|0)==0){break}ka=(((fa|0)>(ga|0)?ga:fa)-ea|0)*5|0;fa=ka>>31;ga=(fa^ka)-fa>>3;if((fa^ba|0)!=(T|0)){break}fa=(((ga|0)>(ha|0)?ha:ga)^T)-T|0;T=aa-fa|0;if(T>>>0>255>>>0){la=-T>>31&255}else{la=T&255}a[da]=la;T=(d[X]|0)+fa|0;if(T>>>0>255>>>0){ma=-T>>31&255}else{ma=T&255}a[X]=ma}}while(0);X=M+C|0;da=d[M+D|0]|0;aa=d[M+E|0]|0;ba=M+F|0;ea=d[ba]|0;Z=d[X]|0;ca=ea-Z|0;W=(da-aa<<1)+4+(ca*-5|0)|0;Y=W>>31;T=(W>>3^Y)-Y|0;if((T|0)>=(g|0)){break}W=((d[M+G|0]|0)-ea<<1)+4+(((d[M+H|0]|0)-da|0)*-5|0)>>3;da=(W|0)>-1?W:-W|0;W=(Z-(d[M+I|0]|0)<<1)+4+((aa-(d[M+J|0]|0)|0)*-5|0)>>3;aa=(W|0)>-1?W:-W|0;if(!((da|0)<(T|0)|(aa|0)<(T|0))){break}W=ca>>31;Z=(W^ca)-W>>1;if((Z|0)==0){break}ca=(((da|0)>(aa|0)?aa:da)-T|0)*5|0;T=ca>>31;da=(T^ca)-T>>3;if((T^Y|0)!=(W|0)){break}Y=(((da|0)>(Z|0)?Z:da)^W)-W|0;W=ea-Y|0;if(W>>>0>255>>>0){na=-W>>31&255}else{na=W&255}a[ba]=na;ba=(d[X]|0)+Y|0;if(ba>>>0>255>>>0){oa=-ba>>31&255}else{oa=ba&255}a[X]=oa}}while(0);b=L+4|0;if((b|0)<(f|0)){L=b;M=M+K|0}else{break}}return}function C8a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;c[a+140>>2]=6;d=c[a+120>>2]|0;e=c[a+124>>2]|0;do{if((d&7|0)==0){if((e&3|0)==0){f=0}else{break}i=b;return f|0}}while(0);QIb(a,2168600,(a=i,i=i+16|0,c[a>>2]=d,c[a+8>>2]=e,a)|0);i=a;f=-1094995529;i=b;return f|0}function D8a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=i;j=c[b+60>>2]|0;k=g+24|0;l=c[k>>2]|0;m=c[g+28>>2]|0;g=b+124|0;n=c[g>>2]|0;o=b+120|0;p=n+32+((ca(n*5|0,c[o>>2]|0)|0)/8|0)|0;if((m|0)<(p|0)){KIb(b,16,2442976,(q=i,i=i+16|0,c[q>>2]=m,c[q+8>>2]=p,q)|0);i=q;r=-22;i=h;return r|0}p=M4a(b,e,0)|0;if((p|0)<0){r=p;i=h;return r|0}c[e+88>>2]=1;c[e+84>>2]=1;p=j;c[j>>2]=d[l]|0;c[j+4>>2]=d[l+2|0]|0;c[j+8>>2]=d[l+4|0]|0;c[j+12>>2]=d[l+6|0]|0;c[j+16>>2]=d[l+8|0]|0;c[j+20>>2]=d[l+10|0]|0;c[j+24>>2]=d[l+12|0]|0;c[j+28>>2]=d[l+14|0]|0;c[j+32>>2]=d[l+16|0]|0;c[j+36>>2]=d[l+18|0]|0;c[j+40>>2]=d[l+20|0]|0;c[j+44>>2]=d[l+22|0]|0;c[j+48>>2]=d[l+24|0]|0;c[j+52>>2]=d[l+26|0]|0;c[j+56>>2]=d[l+28|0]|0;c[j+60>>2]=d[l+30|0]|0;b=l+32|0;a:do{if((c[g>>2]|0)>0){n=e+32|0;s=e;t=e+36|0;u=e+4|0;v=e+40|0;w=e+8|0;x=l+m|0;y=j+64|0;z=y;A=b;B=0;b:while(1){C=ca(c[n>>2]|0,B)|0;D=(c[s>>2]|0)+C|0;C=B&3;c:do{if((C|0)==0){E=B>>2;F=ca(c[t>>2]|0,E)|0;G=(c[u>>2]|0)+F|0;F=ca(c[v>>2]|0,E)|0;E=(c[w>>2]|0)+F|0;if((x-A|0)<((c[o>>2]|0)+4|0)){H=9;break b}F=A+4|0;I=d[A]|0;c[y>>2]=I;c[j+68>>2]=d[A+1|0]|0;c[j+72>>2]=d[A+2|0]|0;c[j+76>>2]=d[A+3|0]|0;if((c[o>>2]|0)<=0){J=F;break}K=F;F=0;L=I-(c[p+((a[A+6|0]&15)<<2)>>2]|0)|0;I=D;M=G;G=E;while(1){E=K+2|0;N=(c[p+((a[E]&15)<<2)>>2]|0)+L|0;a[I]=N;O=(c[p+((d[E]|0)>>>4<<2)>>2]|0)+N|0;a[I+1|0]=O;N=(c[p+((a[K]&15)<<2)>>2]|0)+O|0;a[I+2|0]=N;O=(c[p+((d[K]|0)>>>4<<2)>>2]|0)+N|0;a[I+3|0]=O;a[M]=a[K+3|0]|0;a[G]=a[K+1|0]|0;N=K+4|0;E=F+4|0;if((E|0)<(c[o>>2]|0)){K=N;F=E;L=O;I=I+4|0;M=M+1|0;G=G+1|0}else{J=N;break}}}else{G=c[o>>2]|0;if((x-A|0)<((G|0)/2|0|0)){H=13;break b}if((G|0)<=0){J=A;break}G=a[A+2|0]|0;M=A;I=8;L=(c[z+(C<<2)>>2]|0)-(c[p+((G&15)<<2)>>2]|0)|0;F=D;K=G;while(1){G=(c[p+((K&15)<<2)>>2]|0)+L|0;a[F]=G;N=(c[p+((d[M+2|0]|0)>>>4<<2)>>2]|0)+G|0;a[F+1|0]=N;G=M+3|0;O=(c[p+((a[G]&15)<<2)>>2]|0)+N|0;a[F+2|0]=O;N=(c[p+((d[G]|0)>>>4<<2)>>2]|0)+O|0;a[F+3|0]=N;O=(c[p+((a[M]&15)<<2)>>2]|0)+N|0;a[F+4|0]=O;N=(c[p+((d[M]|0)>>>4<<2)>>2]|0)+O|0;a[F+5|0]=N;O=M+1|0;G=(c[p+((a[O]&15)<<2)>>2]|0)+N|0;a[F+6|0]=G;N=(c[p+((d[O]|0)>>>4<<2)>>2]|0)+G|0;a[F+7|0]=N;G=M+4|0;if((I|0)>=(c[o>>2]|0)){J=G;break c}O=a[M+6|0]|0;M=G;I=I+8|0;L=N;F=F+8|0;K=O}}}while(0);D=B+1|0;if((D|0)<(c[g>>2]|0)){A=J;B=D}else{P=J;break a}}if((H|0)==9){KIb(0,0,2354544,(q=i,i=i+24|0,c[q>>2]=2292312,c[q+8>>2]=2241416,c[q+16>>2]=81,q)|0);i=q;Hd();return 0}else if((H|0)==13){KIb(0,0,2354544,(q=i,i=i+24|0,c[q>>2]=2200400,c[q+8>>2]=2241416,c[q+16>>2]=100,q)|0);i=q;Hd();return 0}}else{P=b}}while(0);c[f>>2]=1;r=P-(c[k>>2]|0)|0;i=h;return r|0}function E8a(b,c,d,e,f,g,h,i,j,k){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((j|0)==0|(k|0)==0){return}do{if((i|0)<(k|0)){if((i|0)>(-g|0)){l=c;m=i;break}n=1-g|0;l=c+(ca(n-i|0,e)|0)|0;m=n}else{n=k-1|0;l=c+(ca(n-i|0,e)|0)|0;m=n}}while(0);do{if((h|0)<(j|0)){if((h|0)>(-f|0)){o=l;p=h;break}i=1-f|0;o=l+(i-h)|0;p=i}else{i=j-1|0;o=l+(i-h)|0;p=i}}while(0);h=(m|0)>0;l=h?0:-m|0;i=(p|0)>0;c=i?0:-p|0;n=k-m|0;q=(n|0)<(g|0)?n:g;n=j-p|0;j=(n|0)<(f|0);r=j?n:f;n=r-c|0;s=o+(c+(ca(l,e)|0))|0;t=b+c|0;if((l|0)>0){u=(h?m:0)-m|0;v=(i?p:0)+(ca(u,d)|0)-p|0;w=0;x=t;while(1){nrc(x|0,s|0,n)|0;y=w+1|0;if((y|0)<(l|0)){w=y;x=x+d|0}else{break}}z=u;A=b+v|0}else{z=0;A=t}if((z|0)<(q|0)){t=m-1-k|0;k=~g;v=(t|0)>(k|0)?t:k;k=ca(~z-v|0,d)|0;t=(i?p:0)+(ca((h?m-1|0:-1)-m-z-v|0,e)|0)-p|0;p=z;m=s;h=A;while(1){nrc(h|0,m|0,n)|0;i=p+1|0;if((i|0)<(q|0)){p=i;m=m+e|0;h=h+d|0}else{break}}B=~v;C=o+t|0;D=A+k|0}else{B=z;C=s;D=A}A=C+(-e|0)|0;if((B|0)<(g|0)){e=ca(g-B|0,d)|0;C=B;B=D;while(1){nrc(B|0,A|0,n)|0;s=C+1|0;if((s|0)<(g|0)){C=s;B=B+d|0}else{break}}E=D+e|0}else{E=D}D=E+(-((ca(g,d)|0)+c|0)|0)|0;E=g-1|0;if((g|0)==0){return}g=r-1|0;if((c|0)<=0){if(j){F=D;G=E}else{return}while(1){e=F+g|0;B=r;do{a[F+B|0]=a[e]|0;B=B+1|0;}while((B|0)<(f|0));if((G|0)==0){break}else{F=F+d|0;G=G-1|0}}return}if(j){H=D;I=E}else{j=D;D=E;while(1){E=j+c|0;G=0;do{a[j+G|0]=a[E]|0;G=G+1|0;}while((G|0)<(c|0));if((D|0)==0){break}else{j=j+d|0;D=D-1|0}}return}while(1){D=H+c|0;j=0;do{a[H+j|0]=a[D]|0;j=j+1|0;}while((j|0)<(c|0));j=H+g|0;D=r;do{a[H+D|0]=a[j]|0;D=D+1|0;}while((D|0)<(f|0));if((I|0)==0){break}else{H=H+d|0;I=I-1|0}}return}function F8a(a,c,d,e,f,g,h,i,j,k){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((j|0)==0|(k|0)==0){return}do{if((i|0)<(k|0)){if((i|0)>(-g|0)){l=c;m=i;break}n=1-g|0;l=c+(ca(n-i|0,e)|0)|0;m=n}else{n=k-1|0;l=c+(ca(n-i|0,e)|0)|0;m=n}}while(0);do{if((h|0)<(j|0)){if((h|0)>(-f|0)){o=l;p=h;break}i=1-f|0;o=l+(i-h<<1)|0;p=i}else{i=j-1|0;o=l+(i-h<<1)|0;p=i}}while(0);h=(m|0)>0;l=h?0:-m|0;i=(p|0)>0;c=i?0:-p|0;n=k-m|0;q=(n|0)<(g|0)?n:g;n=j-p|0;j=(n|0)<(f|0);r=j?n:f;n=r-c|0;s=c<<1;t=o+(s+(ca(l,e)|0))|0;u=a+s|0;if((l|0)>0){v=n<<1;w=(h?m:0)-m|0;x=ca(w,d)|0;y=x+((i?p:0)-p<<1)|0;x=0;z=u;while(1){nrc(z|0,t|0,v)|0;A=x+1|0;if((A|0)<(l|0)){x=A;z=z+d|0}else{break}}B=w;C=a+y|0}else{B=0;C=u}if((B|0)<(q|0)){u=n<<1;y=m-1-k|0;k=~g;a=(y|0)>(k|0)?y:k;k=ca(~B-a|0,d)|0;y=ca((h?m-1|0:-1)-m-B-a|0,e)|0;m=y+((i?p:0)-p<<1)|0;p=B;i=t;y=C;while(1){nrc(y|0,i|0,u)|0;h=p+1|0;if((h|0)<(q|0)){p=h;i=i+e|0;y=y+d|0}else{break}}D=~a;E=o+m|0;F=C+k|0}else{D=B;E=t;F=C}C=E+(-e|0)|0;if((D|0)<(g|0)){e=n<<1;n=ca(g-D|0,d)|0;E=D;D=F;while(1){nrc(D|0,C|0,e)|0;t=E+1|0;if((t|0)<(g|0)){E=t;D=D+d|0}else{break}}G=F+n|0}else{G=F}F=G+(-((ca(g,d)|0)+s|0)|0)|0;s=g-1|0;if((g|0)==0){return}g=r-1|0;if((c|0)>0){H=F;I=s}else{G=F;F=s;while(1){s=G;if(j){n=s+(g<<1)|0;D=r;do{b[s+(D<<1)>>1]=b[n>>1]|0;D=D+1|0;}while((D|0)<(f|0))}if((F|0)==0){break}else{G=G+d|0;F=F-1|0}}return}while(1){F=H;G=F+(c<<1)|0;D=0;do{b[F+(D<<1)>>1]=b[G>>1]|0;D=D+1|0;}while((D|0)<(c|0));if(j){D=F+(g<<1)|0;G=r;do{b[F+(G<<1)>>1]=b[D>>1]|0;G=G+1|0;}while((G|0)<(f|0))}if((I|0)==0){break}else{H=H+d|0;I=I-1|0}}return}function G8a(a,b){a=a|0;b=b|0;c[a+4>>2]=878;c[a>>2]=(b|0)<9?56:72;return}function H8a(a,b,c){a=a|0;b=b|0;c=c|0;return}function I8a(d){d=d|0;var e=0,f=0,g=0,h=0;c[d+420>>2]=1;if(a[699888]|0){return 0}else{e=0}do{d=(e&32|0)==0;f=e;g=0;while(1){h=b[1437984+(g<<1)>>1]|0;b[5430488+(f<<1)>>1]=((e&1|0)==0?0:h>>>5)+(((e&2|0)==0?0:h>>>4)+(((e&4|0)==0?0:h>>>3)+(((e&8|0)==0?0:h>>2)+(((e&16|0)==0?0:h>>1)+(d?0:h)))));h=g+1|0;if(h>>>0<89>>>0){f=f+64|0;g=h}else{break}}e=e+1|0;}while((e|0)<64);a[699888]=1;return 0}function J8a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=g;o=j+28|0;p=c[o>>2]|0;if((p|0)<13){q=-1094995529;i=k;return q|0}r=c[j+24>>2]|0;j=p>>>0>268435455>>>0?-8:p<<3;s=j>>>0>2147483639>>>0|(r|0)==0;t=s?0:r;r=s?8:j+8|0;if(s){q=s?-1094995529:0;i=k;return q|0}s=t;j=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)&-65536;s=r>>>0>16>>>0?16:r;u=t+(s>>>3)|0;v=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)>>>16;u=s+16|0;s=r>>>0>u>>>0?u:r;u=v|j;if((u|0)==-1){j=-s|0;v=r-s|0;if((j|0)>32){w=j}else{w=(v|0)<32?v:32}v=w+s|0;w=t+(v>>>3)|0;j=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)&-65536;w=v+16|0;v=r>>>0>w>>>0?w:r;w=t+(v>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(v&7)>>>16;w=v+16|0;y=x|j;z=r>>>0>w>>>0?w:r}else{y=u;z=s}if(y>>>0>p<<1>>>0){q=-1094995529;i=k;return q|0}p=t+(z>>>3)|0;s=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(z&7)>>24;p=z+8|0;z=r>>>0>p>>>0?p:r;p=s>>>7;u=(p&1)+1|0;a[m|0]=p^s;c[f+416>>2]=u;s=(u|0)==2;p=f+448|0;c[p>>2]=s?3:4;c[p+4>>2]=s?0:0;s=t+(z>>>3)|0;p=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(z&7)>>>16;s=z+16|0;z=r>>>0>s>>>0?s:r;b[l>>1]=p;if(u>>>0>1>>>0){p=t+(z>>>3)|0;s=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(z&7)>>>24;p=z+8|0;w=r>>>0>p>>>0?p:r;a[m+1|0]=s;s=t+(w>>>3)|0;p=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(w&7)>>>16;s=w+16|0;b[l+2>>1]=p;A=r>>>0>s>>>0?s:r}else{A=z}c[g+76>>2]=y;z=M4a(f,n,0)|0;if((z|0)<0){q=z;i=k;return q|0}z=g;if((y|0)!=0){g=A;A=0;while(1){n=g;f=(c[z>>2]|0)+(A<<1)|0;s=a[m+A|0]|0;p=b[l+(A<<1)>>1]|0;w=0;while(1){if((s|0)<0){B=0}else{B=(s|0)>88?88:s}j=d[564560+B|0]|0;x=t+(n>>>3)|0;v=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(n&7)>>>((32-j|0)>>>0);x=j+n|0;C=r>>>0>x>>>0?x:r;x=j-1|0;D=1<<x;E=(v&D|0)==0;F=E?0:D;G=F^v;if((G|0)==(D-1|0)){D=t+(C>>>3)|0;H=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>16;D=C+16|0;I=H;J=r>>>0>D>>>0?D:r}else{D=G<<7-j|B<<6;if((D|0)<0){K=0}else{K=(D|0)>5785?5785:D}D=e[5430488+(K<<1)>>1]|0;if((v|0)==(F|0)){L=D}else{L=(b[1437984+(B<<1)>>1]>>x)+D|0}D=(E?L:-L|0)+p|0;if((D+32768|0)>>>0>65535>>>0){M=(D>>31^32767)&65535}else{M=D&65535}I=M<<16>>16;J=C}b[f>>1]=I;C=w+1|0;if(C>>>0<y>>>0){n=J;f=f+(u<<1)|0;s=(a[(c[557e3+(j-2<<2)>>2]|0)+G|0]|0)+B|0;p=I;w=C}else{break}}w=A+1|0;if((w|0)<(u|0)){g=J;A=w}else{break}}}c[h>>2]=1;q=c[o>>2]|0;i=k;return q|0}function K8a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b+60|0;g=c[f>>2]|0;c[g>>2]=b;c[b+140>>2]=11;if((c[b+100>>2]|0)!=816){KIb(b,16,2457616,(h=i,i=i+8|0,c[h>>2]=816,h)|0);i=h;j=-1094995529;i=e;return j|0}h=c[b+96>>2]|0;b=h+800|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[g+1044>>2]=k;do{if((k|0)!=0){b=hJb(k)|0;c[g+1040>>2]=b;if((b|0)==0){j=-12}else{break}i=e;return j|0}}while(0);k=g+16|0;b=0;l=0;while(1){m=(a[h+(b+29)|0]<<2&255)<<8|(a[h+(b+28)|0]<<2&255)<<16|a[h+(b+30)|0]<<2&255;c[k+(l<<2)>>2]=m|m>>>6&197379|-16777216;m=l+1|0;if((m|0)<256){b=b+3|0;l=m}else{break}}l=UHb()|0;c[g+4>>2]=l;if((l|0)!=0){j=0;i=e;return j|0}l=c[f>>2]|0;VHb(l+4|0);mJb(l+1040|0);c[l+1044>>2]=0;j=-12;i=e;return j|0}function L8a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0;h=i;i=i+4096|0;j=h|0;k=c[g+28>>2]|0;l=c[b+60>>2]|0;m=e;n=l+8|0;c[n>>2]=c[g+24>>2];g=l+12|0;c[g>>2]=k;if((k|0)<16){o=-1094995529;i=h;return o|0}p=M4a(b,m,1)|0;if((p|0)<0){o=p;i=h;return o|0}p=c[n>>2]|0;b=p+6|0;q=(d[b]|d[b+1|0]<<8)<<16>>16;b=q&65535;r=p+8|0;s=(d[r]|d[r+1|0]<<8)<<16>>16;r=s&65535;t=p+10|0;u=((d[t]|d[t+1|0]<<8)<<16>>16&65535)-b+1|0;t=p+12|0;v=((d[t]|d[t+1|0]<<8)<<16>>16&65535)-r+1|0;t=l;w=c[t>>2]|0;x=w+120|0;do{if((u|0)==(c[x>>2]|0)){if((v|0)!=(c[w+124>>2]|0)){break}if((s|q)<<16>>16==0){break}c[l+1048>>2]=b;c[l+1052>>2]=r}}while(0);q=c[l+1048>>2]|0;s=b-q|0;z=c[l+1052>>2]|0;A=r-z|0;do{if((s|u|0)>=0){B=c[x>>2]|0;if((s|0)>=(B|0)|(u|0)>(B|0)|(s+u|0)>(B|0)){break}do{if((A|v|0)>=0){C=c[w+124>>2]|0;if((A|0)>=(C|0)|(v|0)>(C|0)|(A+v|0)>(C|0)){break}D=l+4|0;E=c[c[D>>2]>>2]|0;do{if((E|0)==0){F=p}else{if((b|0)==(q|0)&(r|0)==(z|0)&(u|0)==(B|0)&(v|0)==(C|0)){F=p;break}nrc(c[e>>2]|0,E|0,ca(c[e+32>>2]|0,C)|0)|0;F=c[n>>2]|0}}while(0);C=F+16|0;E=c[g>>2]|0;if(!((E-16|0)>-1)){KIb(0,0,2168568,(G=i,i=i+24|0,c[G>>2]=2476792,c[G+8>>2]=2467424,c[G+16>>2]=135,G)|0);i=G;Hd();return 0}H=F+E|0;if((a[F+15|0]&2)==0){I=C;J=E}else{E=H;K=C;C=E-K|0;L=F+(C>>>0>2>>>0?18:C+16|0)|0;C=l+16|0;if(!((E-L|0)>>>0>767>>>0)){KIb(c[t>>2]|0,16,2514200,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;o=-1094995529;i=h;return o|0}M=K-1-E|0;E=783-M|0;K=L;L=0;while(1){N=d[K+1|0]<<10&64512|d[K]<<18|d[K+2|0]<<2&252;c[C+(L<<2)>>2]=N|N>>>6&197379|-16777216;N=L+1|0;if((N|0)<256){K=K+3|0;L=N}else{break}}I=F+(M>>>0>4294967293>>>0?E:786)|0;J=c[g>>2]|0}a:do{if((J|0)!=0){L=H;if((H|0)==(I|0)){o=-1094995529;i=h;return o|0}K=I+1|0;C=a[I]|0;do{if(C<<24>>24>-1){O=C;P=K;Q=H}else{N=c[l+1044>>2]|0;if((N|0)==0){KIb(c[t>>2]|0,16,2500496,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;o=-1094995529;i=h;return o|0}R=L-K|0;S=l+1040|0;T=c[S>>2]|0;if(!((R|0)>-1)){KIb(0,0,2168568,(G=i,i=i+24|0,c[G>>2]=2476792,c[G+8>>2]=2467424,c[G+16>>2]=135,G)|0);i=G;Hd();return 0}U=I+(R+1)|0;V=U;if((R|0)<4){W=0;X=K}else{R=K;W=d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0;X=I+5|0}mrc(j|0,32,4096)|0;R=V-X|0;if(R>>>0<4>>>0){o=-1094995529;i=h;return o|0}if((R|0)<4){Y=100;Z=4078;_=X}else{R=X;$=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)==1450709556;Y=$?18:100;Z=$?273:4078;_=$?X+4|0:X}b:do{if((W|0)==0|(U|0)==(_|0)){aa=T}else{$=T+N|0;R=_;ba=T;da=Z;ea=W;c:while(1){fa=R+1|0;ga=a[R]|0;if(ga<<24>>24==-1&ea>>>0>8>>>0){if(($-ba|0)<8){o=-1094995529;ha=118;break}if((V-fa|0)>>>0<8>>>0){o=-1094995529;ha=118;break}ia=a[fa]|0;a[ba]=ia;a[j+da|0]=ia;ia=a[R+2|0]|0;a[ba+1|0]=ia;a[j+(da+1&4095)|0]=ia;ia=a[R+3|0]|0;a[ba+2|0]=ia;a[j+(da+2&4095)|0]=ia;ia=a[R+4|0]|0;a[ba+3|0]=ia;a[j+(da+3&4095)|0]=ia;ia=a[R+5|0]|0;a[ba+4|0]=ia;a[j+(da+4&4095)|0]=ia;ia=a[R+6|0]|0;a[ba+5|0]=ia;a[j+(da+5&4095)|0]=ia;ia=a[R+7|0]|0;a[ba+6|0]=ia;a[j+(da+6&4095)|0]=ia;ia=a[R+8|0]|0;a[ba+7|0]=ia;a[j+(da+7&4095)|0]=ia;ja=ea-8|0;ka=da+8&4095;la=ba+8|0;ma=R+9|0}else{if((ea|0)==0){aa=ba;break b}else{na=fa;oa=ba;pa=da;qa=ea;ra=ga;sa=0}while(1){if((ra&1)==0){if((V-na|0)<1){ta=0;ua=na}else{ta=d[na]|0;ua=na+1|0}do{if((V-ua|0)<1){va=3;wa=ua;xa=ta}else{ga=d[ua]|0;fa=ga<<4&3840|ta;ia=ua+1|0;ya=(ga&15)+3|0;if((ya|0)!=(Y|0)){va=ya;wa=ia;xa=fa;break}if((V-ia|0)<1){va=18;wa=ia;xa=fa;break}va=(d[ia]|0)+18|0;wa=ua+2|0;xa=fa}}while(0);if(($-oa|0)>>>0<va>>>0){o=-1094995529;ha=118;break c}else{za=oa;Aa=pa;Ba=xa;Ca=0}while(1){fa=a[j+(Ba&4095)|0]|0;a[za]=fa;a[j+Aa|0]=fa;Da=Aa+1&4095;fa=Ca+1|0;if(fa>>>0<va>>>0){za=za+1|0;Aa=Da;Ba=Ba+1|0;Ca=fa}else{break}}Ea=qa-va|0;Fa=Da;Ga=oa+(va>>>0>1>>>0?va:1)|0;Ha=wa}else{if(($-oa|0)<1|(U|0)==(na|0)){o=-1094995529;ha=118;break c}fa=a[na]|0;a[oa]=fa;a[j+pa|0]=fa;Ea=qa-1|0;Fa=pa+1&4095;Ga=oa+1|0;Ha=na+1|0}fa=sa+1|0;if(fa>>>0>7>>>0|(Ea|0)==0){ja=Ea;ka=Fa;la=Ga;ma=Ha;break}else{na=Ha;oa=Ga;pa=Fa;qa=Ea;ra=(ra&255)>>>1;sa=fa}}}if((ja|0)==0|(U|0)==(ma|0)){aa=la;break b}else{R=ma;ba=la;da=ka;ea=ja}}if((ha|0)==118){i=h;return o|0}}}while(0);U=aa-T|0;if((U|0)<0){o=U;i=h;return o|0}else{V=c[S>>2]|0;O=C&127;P=V;Q=V+U|0;break}}}while(0);C=e+32|0;K=(ca(c[C>>2]|0,A)|0)+s|0;L=(c[e>>2]|0)+K|0;K=c[D>>2]|0;U=(ca(c[K+32>>2]|0,A)|0)+s|0;V=(c[K>>2]|0)+U|0;U=O&255;if((U|0)==1){if((v|0)<=0){break}K=Q;N=P;ea=V;da=L;ba=0;d:while(1){R=0;$=N;while(1){do{if((K-$|0)<1){Ia=$;Ja=0;ha=72}else{fa=$+1|0;ia=d[$]|0;if((ia&128|0)==0){Ia=fa;Ja=ia;ha=72;break}ya=ia&127;ia=ya+1|0;ga=ia+R|0;if((ga|0)>(u|0)){o=-1094995529;ha=118;break d}if((K-fa|0)>>>0<ia>>>0){o=-1094995529;ha=118;break d}nrc(da+R|0,fa|0,ia)|0;Ka=ga;La=$+(ya+2)|0}}while(0);if((ha|0)==72){ha=0;if((R+1+Ja|0)>(u|0)){o=-1094995529;ha=118;break d}if((c[c[D>>2]>>2]|0)==0){o=-1094995529;ha=118;break d}ya=Ja+1|0;nrc(da+R|0,ea+R|0,ya)|0;Ka=ya+R|0;La=Ia}if((Ka|0)<(u|0)){R=Ka;$=La}else{break}}if((Ka|0)>(u|0)){ha=77;break}$=ba+1|0;if(($|0)<(v|0)){N=La;ea=ea+(c[(c[D>>2]|0)+32>>2]|0)|0;da=da+(c[C>>2]|0)|0;ba=$}else{break a}}if((ha|0)==77){KIb(c[t>>2]|0,16,2487784,(G=i,i=i+16|0,c[G>>2]=Ka,c[G+8>>2]=u,G)|0);i=G;o=-1094995529;i=h;return o|0}else if((ha|0)==118){i=h;return o|0}}else if((U|0)==3){if((v|0)<=0){break}ba=Q;da=P;ea=V;N=L;K=0;e:while(1){$=N+u|0;R=0;S=da;while(1){f:do{if((ba-S|0)<1){Ma=S;Na=0;ha=109}else{T=S+1|0;ya=d[S]|0;if((ya&128|0)==0){Ma=T;Na=ya;ha=109;break}ga=(ya&127)+1|0;ia=ba-T|0;do{if((ia|0)>=1){if(!((a[T]|0)==-1)){break}fa=ga&255;Oa=S+2|0;Pa=N+R|0;Qa=Oa;Ra=ba-Qa|0;if(!((Ra|0)>-1)){ha=86;break e}Sa=S+(Ra+2)|0;do{if((ya&1|0)==0){if((Q|0)==(Oa|0)){Ta=0;break}a[Pa]=a[Oa]|0;Ua=N+(R+1)|0;Va=1;Wa=S+3|0;ha=90}else{Ua=Pa;Va=0;Wa=Oa;ha=90}}while(0);do{if((ha|0)==90){ha=0;Oa=Sa;Pa=Ua;Xa=Va;Ya=Wa;g:while(1){if((Sa|0)==(Ya|0)){Za=Sa;ha=106;break}_a=Ya+1|0;$a=a[Ya]|0;ab=$a&255;do{if((ab&128|0)==0){bb=ab<<1;cb=_a;if(($-Pa|0)<(bb|0)){ha=99;break g}db=Oa-cb|0;if(db>>>0<2>>>0){ha=99;break g}if((db|0)<2){eb=0;fb=_a}else{db=_a;eb=(d[db]|d[db+1|0]<<8)<<16>>16;fb=Ya+3|0}if($a<<24>>24==0){gb=Pa;hb=bb;ib=fb;break}else{jb=0;kb=Pa}while(1){db=kb;y=eb;a[db]=y;y=y>>8;a[db+1|0]=y;db=jb+1|0;if((db|0)<(ab|0)){jb=db;kb=kb+2|0}else{break}}gb=Pa+(($a&255)>>>0>1>>>0?bb:2)|0;hb=bb;ib=fb}else{db=ab<<1&254;lb=_a;if(($-Pa|0)<(db|0)){ha=95;break g}if((Oa-lb|0)>>>0<db>>>0){ha=95;break g}nrc(Pa|0,_a|0,db)|0;gb=Pa+db|0;hb=db;ib=Ya+(db|1)|0}}while(0);_a=hb+Xa|0;if((_a|0)<(fa|0)){Pa=gb;Xa=_a;Ya=ib}else{Za=ib;ha=106;break}}if((ha|0)==95){ha=0;Ta=lb-Qa|0;break}else if((ha|0)==99){ha=0;Ta=cb-Qa|0;break}else if((ha|0)==106){ha=0;Ta=Za-Qa|0;break}}}while(0);Qa=Ta&255;mb=fa;nb=S+((Ra>>>0>Qa>>>0?Qa:Ra)+2)|0;break f}}while(0);ya=ga&255;Qa=ia>>>0>ya>>>0?ya:ia;nrc(N+R|0,T|0,Qa)|0;mb=ya;nb=S+(Qa+1)|0}}while(0);if((ha|0)==109){ha=0;if((R+1+Na|0)>(u|0)){o=-1094995529;ha=118;break e}if((c[c[D>>2]>>2]|0)==0){o=-1094995529;ha=118;break e}Qa=Na+1|0;nrc(N+R|0,ea+R|0,Qa)|0;mb=Qa;nb=Ma}ob=mb+R|0;if((ob|0)<(u|0)){R=ob;S=nb}else{break}}if((ob|0)>(u|0)){ha=114;break}S=K+1|0;if((S|0)<(v|0)){da=nb;ea=ea+(c[(c[D>>2]|0)+32>>2]|0)|0;N=N+(c[C>>2]|0)|0;K=S}else{break a}}if((ha|0)==86){KIb(0,0,2168568,(G=i,i=i+24|0,c[G>>2]=2476792,c[G+8>>2]=2467424,c[G+16>>2]=135,G)|0);i=G;Hd();return 0}else if((ha|0)==114){KIb(c[t>>2]|0,16,2487784,(G=i,i=i+16|0,c[G>>2]=ob,c[G+8>>2]=u,G)|0);i=G;o=-1094995529;i=h;return o|0}else if((ha|0)==118){i=h;return o|0}}else if((U|0)==2){if((v|0)<=0){break}K=Q;N=P;ea=L;da=0;while(1){ba=K-N|0;V=ba>>>0>u>>>0?u:ba;nrc(ea|0,N|0,V)|0;ba=da+1|0;if((ba|0)<(v|0)){N=N+V|0;ea=ea+(c[C>>2]|0)|0;da=ba}else{break}}}else{break}}}while(0);nrc(c[e+4>>2]|0,l+16|0,1024)|0;WHb(c[D>>2]|0);H=YHb(c[D>>2]|0,m)|0;if((H|0)<0){o=H;i=h;return o|0}c[f>>2]=1;o=k;i=h;return o|0}}while(0);KIb(w,16,2529464,(G=i,i=i+16|0,c[G>>2]=s,c[G+8>>2]=u,G)|0);i=G;o=-1094995529;i=h;return o|0}}while(0);KIb(w,16,2547176,(G=i,i=i+16|0,c[G>>2]=s,c[G+8>>2]=u,G)|0);i=G;o=-1094995529;i=h;return o|0}function M8a(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+1040|0);c[b+1044>>2]=0;return 0}function N8a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+60>>2]|0;e=a+416|0;f=c[e>>2]|0;if((f-1|0)>>>0>1>>>0){KIb(a,16,2612896,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}j=a+432|0;k=c[j>>2]|0;do{if((k|0)>=1){if(((k|0)%(f|0)|0|0)!=0){break}l=(f|0)==1;m=a+448|0;c[m>>2]=l?4:3;c[m+4>>2]=l?0:0;l=a+792|0;m=(c[l>>2]|0)==16|0;c[a+420>>2]=m;n=QKb(m)|0;c[d>>2]=n;c[d+4>>2]=(c[e>>2]&-((n|0)==2|0))+(c[j>>2]|0);n=c[l>>2]|0;l=c[j>>2]|0;m=c[a+412>>2]|0;KIb(a,48,2565296,(g=i,i=i+32|0,c[g>>2]=c[e>>2],c[g+8>>2]=n,c[g+16>>2]=l,c[g+24>>2]=m,g)|0);i=g;h=0;i=b;return h|0}}while(0);KIb(a,16,2586152,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-22;i=b;return h|0}function O8a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+8|0;l=k|0;m=g;n=c[j+24>>2]|0;o=j+28|0;j=c[o>>2]|0;p=c[f+60>>2]|0;if((j|0)<16){KIb(f,24,2292280,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;c[h>>2]=0;r=j;i=k;return r|0}s=a[n+6|0]|0;if(s<<24>>24==0|(s&255)>>>0>3>>>0){KIb(f,16,2241392,(q=i,i=i+8|0,c[q>>2]=s&255,q)|0);i=q;r=-22;i=k;return r|0}t=n+16|0;u=j-16|0;do{if((s<<24>>24|0)==2){if((u|0)>=4){v=t;w=je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=w-(w>>>1&1431655765)|0;w=(v>>>2&858993459)+(v&858993459)|0;v=(w>>>4)+w&252645135;w=(v>>>8)+v|0;x=n+20|0;y=j-20|0;z=(w>>>16)+w&63;break}KIb(f,16,2200376,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-22;i=k;return r|0}else if((s<<24>>24|0)==3){x=t;y=0;z=1}else{x=t;y=u;z=0}}while(0);u=p+4|0;t=c[u>>2]|0;s=(y|0)/(t|0)|0;y=ca(s,t)|0;t=f+432|0;j=ca(s+z|0,c[t>>2]|0)|0;n=f+416|0;w=g+76|0;c[w>>2]=(j|0)/(c[n>>2]|0)|0;j=M4a(f,m,0)|0;if((j|0)<0){r=j;i=k;return r|0}j=c[g>>2]|0;g=j;do{if((z|0)==0){A=g;B=j}else{m=ca(c[t>>2]|0,z)|0;if((m|0)>(ca(c[n>>2]|0,c[w>>2]|0)|0)){KIb(0,0,2168568,(q=i,i=i+24|0,c[q>>2]=2141808,c[q+8>>2]=2118360,c[q+16>>2]=626,q)|0);i=q;Hd();return 0}if((c[p>>2]|0)==2){mrc(j|0,0,m<<1|0)|0;A=g+(m<<1)|0;B=j;break}else{mrc(j|0,-128|0,m|0)|0;A=g;B=j+m|0;break}}}while(0);do{if((s|0)>0){if(((c[n>>2]|0)>1&y|0)!=0){KIb(0,0,2168568,(q=i,i=i+24|0,c[q>>2]=2636264,c[q+8>>2]=2118360,c[q+16>>2]=640,q)|0);i=q;Hd();return 0}j=x+y|0;g=c[u>>2]|0;if((y|0)<(g|0)){break}w=p;z=B;m=A;f=x;v=g;while(1){if((c[w>>2]|0)==2){g=c[n>>2]|0;C=f+v|0;D=g-1|0;if((g|0)>0){E=0;F=f;G=m;while(1){H=F;I=(d[H]|d[H+1|0]<<8)<<16>>16;c[l+(E<<2)>>2]=I<<16>>16;b[G>>1]=I;I=E+1|0;if((I|0)<(g|0)){E=I;F=F+2|0;G=G+2|0}else{break}}J=f+(g<<1)|0;K=m+(g<<1)|0}else{J=f;K=m}if(J>>>0<C>>>0){G=0;F=J;E=K;while(1){I=F+1|0;H=d[F]|0;if((H&128|0)==0){L=l+(G<<2)|0;M=(c[L>>2]|0)+(e[254184+(H<<1)>>1]|0)|0;c[L>>2]=M;N=M}else{M=l+(G<<2)|0;L=(c[M>>2]|0)-(e[254184+((H&127)<<1)>>1]|0)|0;c[M>>2]=L;N=L}if((N+32768|0)>>>0>65535>>>0){O=(N>>31^32767)&65535}else{O=N&65535}c[l+(G<<2)>>2]=O<<16>>16;b[E>>1]=O;if(I>>>0<C>>>0){G=G^D;F=I;E=E+2|0}else{break}}}P=m+(c[t>>2]<<1)|0;Q=z;R=v}else{nrc(z|0,f|0,v)|0;P=m;Q=z+(c[t>>2]|0)|0;R=c[u>>2]|0}E=f+R|0;if((j-E|0)<(R|0)){break}else{z=Q;m=P;f=E;v=R}}}}while(0);c[h>>2]=1;r=c[o>>2]|0;i=k;return r|0}function P8a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;c[d+788>>2]=c[a+120>>2];c[d+792>>2]=c[a+124>>2];e=c[a+792>>2]|0;c[d+8>>2]=e;c[d+12>>2]=(e|0)/8|0;if((e|0)==8){c[a+140>>2]=11}else if((e|0)==32){c[a+140>>2]=30}else if((e|0)==16){c[a+140>>2]=46}else{KIb(a,16,2547144,(a=i,i=i+8|0,c[a>>2]=e,a)|0);i=a;f=-1094995529;i=b;return f|0}a=UHb()|0;c[d+4>>2]=a;f=(a|0)==0?-12:0;i=b;return f|0}



function _qb(a,f,h,j,k,l,m,n,o,p){a=a|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0;q=i;i=i+27720|0;r=c[(a+12244|0)>>2]|0;if((r|0)==0&(p|0)==16&(o|0)==0){s=q+8|0;c[(q+8|0)>>2]=0;c[(q+8|0)+4>>2]=0;t=c[a+124>>2]|0;u=(ca(c[(a+12480|0)>>2]|0,t)|0)+(c[(a+12476|0)>>2]|0)|0;v=c[(a+12220|0)>>2]|0;w=c[(a+12264|0)>>2]|0;y=c[(a+12272|0)>>2]|0;z=c[(a+12268|0)>>2]|0;A=c[(a+12276|0)>>2]|0;B=c[(a+12464|0)>>2]|0;C=c[(a+12280|0)>>2]|0;D=c[(a+12284|0)>>2]|0;G=c[(a+12216|0)>>2]|0;if((c[(a+12256|0)>>2]|0)==0){H=a+12232|0;I=a+10468|0}else{H=a+12228|0;I=a+10444|0}J=c[H>>2]|0;H=c[I>>2]|0;I=(c[(a+12224|0)>>2]|0)+4194304|0;c[(a+12224|0)>>2]=I;if((I|0)==0){c[(a+12224|0)>>2]=4194304;mrc(G|0,0,256)|0;K=c[(a+12224|0)>>2]|0}else{K=I}I=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,c[(a+12352+(l<<4)|0)>>2]|0,c[(a+12416|0)>>2]|0,16)|0;c[G>>2]=K;c[v>>2]=I;if((c[a+9992>>2]|0)==3){if((c[(a+12244|0)>>2]&4|0)==0){L=10}else{L=9}}else{L=9}if((L|0)==9){if((c[a+60>>2]&64|0)==0){M=I}else{L=10}}if((L|0)==10){M=(ca((d[B+D|0]|0)+(d[B+C|0]|0)|0,J)|0)+I|0}do{if((c[(a+14084|0)>>2]|0)==0){do{if((M|0)<(c[(c[a+4>>2]|0)+376>>2]|0)){if((c[j+12>>2]|c[j+8>>2]|c[j+16>>2]|c[j+20>>2]|c[j+24>>2]|c[j+28>>2]|0)!=0){break}c[f>>2]=0;c[h>>2]=0;c[a+12124>>2]=1;N=M;i=q;return N|0}}while(0);I=c[(j+36|0)>>2]|0;O=c[(j+32|0)>>2]|0;P=(O>>1)+K+(I>>1<<11)|0;do{if((c[(G+(((I>>1<<3)+(O>>1)&63)<<2)|0)>>2]|0)==(P|0)){Q=M;R=O;S=I;T=0;U=0}else{V=c[(a+12416|0)>>2]|0;W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V,I>>1)|0)+(O>>1))|0;X=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,W,V,16)|0;c[(G+(((I>>1<<3)+(O>>1)&63)<<2)|0)>>2]=P;c[v+(((I>>1<<3)+(O>>1)&63)<<2)>>2]=X;V=c[(j+32|0)>>2]|0;W=c[(j+36|0)>>2]|0;Y=(ca((d[B+((W>>1<<1)-D)|0]|0)+(d[B+((V>>1<<1)-C)|0]|0)|0,J)|0)+X|0;if((Y|0)>=(M|0)){Q=M;R=V;S=W;T=0;U=0;break}c[(q+8|0)>>2]=V>>1;c[s+4>>2]=W>>1;Q=Y;R=V;S=W;T=V>>1;U=W>>1}}while(0);O=R>>1;I=(S>>1)-1|0;P=(O|0)>(z|0)?z:O;O=(w|0)>(P|0)?w:P;P=(I|0)>(A|0)?A:I;I=(y|0)>(P|0)?y:P;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){Z=Q;_=T;$=U}else{W=c[(a+12416|0)>>2]|0;V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W,I)|0)+O)|0;Y=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,V,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=Y;W=(ca((d[B+((I<<1)-D)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+Y|0;if((W|0)>=(Q|0)){Z=Q;_=T;$=U;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;Z=W;_=O;$=I}}while(0);I=c[(j+32|0)>>2]>>1;O=(c[(j+36|0)>>2]>>1)+1|0;P=(I|0)>(z|0)?z:I;I=(w|0)>(P|0)?w:P;P=(O|0)>(A|0)?A:O;O=(y|0)>(P|0)?y:P;P=I+K+(O<<11)|0;do{if((c[(G+(((O<<3)+I&63)<<2)|0)>>2]|0)==(P|0)){aa=Z;ba=_;da=$}else{W=c[(a+12416|0)>>2]|0;Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W,O)|0)+I)|0;V=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Y,W,16)|0;c[(G+(((O<<3)+I&63)<<2)|0)>>2]=P;c[v+(((O<<3)+I&63)<<2)>>2]=V;W=(ca((d[B+((O<<1)-D)|0]|0)+(d[B+((I<<1)-C)|0]|0)|0,J)|0)+V|0;if((W|0)>=(Z|0)){aa=Z;ba=_;da=$;break}c[(q+8|0)>>2]=I;c[s+4>>2]=O;aa=W;ba=I;da=O}}while(0);O=(c[(j+32|0)>>2]>>1)-1|0;I=c[(j+36|0)>>2]>>1;P=(O|0)>(z|0)?z:O;O=(w|0)>(P|0)?w:P;P=(I|0)>(A|0)?A:I;I=(y|0)>(P|0)?y:P;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){ea=aa;fa=ba;ga=da}else{W=c[(a+12416|0)>>2]|0;V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W,I)|0)+O)|0;Y=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,V,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=Y;W=(ca((d[B+((I<<1)-D)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+Y|0;if((W|0)>=(aa|0)){ea=aa;fa=ba;ga=da;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;ea=W;fa=O;ga=I}}while(0);I=(c[(j+32|0)>>2]>>1)+1|0;O=c[(j+36|0)>>2]>>1;P=(I|0)>(z|0)?z:I;I=(w|0)>(P|0)?w:P;P=(O|0)>(A|0)?A:O;O=(y|0)>(P|0)?y:P;P=I+K+(O<<11)|0;do{if((c[(G+(((O<<3)+I&63)<<2)|0)>>2]|0)==(P|0)){ha=ea;ia=fa;ja=ga}else{W=c[(a+12416|0)>>2]|0;Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W,O)|0)+I)|0;V=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Y,W,16)|0;c[(G+(((O<<3)+I&63)<<2)|0)>>2]=P;c[v+(((O<<3)+I&63)<<2)>>2]=V;W=(ca((d[B+((O<<1)-D)|0]|0)+(d[B+((I<<1)-C)|0]|0)|0,J)|0)+V|0;if((W|0)>=(ea|0)){ha=ea;ia=fa;ja=ga;break}c[(q+8|0)>>2]=I;c[s+4>>2]=O;ha=W;ia=I;ja=O}}while(0);O=(ca(b[m+(u<<2)>>1]|0,n)|0)+32768>>16;I=(ca(b[m+(u<<2)+2>>1]|0,n)|0)+32768>>16;P=(O|0)>(z|0)?z:O;O=(w|0)>(P|0)?w:P;P=(I|0)>(A|0)?A:I;I=(y|0)>(P|0)?y:P;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){ka=ha;la=ia;ma=ja}else{W=c[(a+12416|0)>>2]|0;V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W,I)|0)+O)|0;Y=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,V,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=Y;W=(ca((d[B+((I<<1)-D)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+Y|0;if((W|0)>=(ha|0)){ka=ha;la=ia;ma=ja;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;ka=W;la=O;ma=I}}while(0);I=c[(j+12|0)>>2]>>1;O=c[(j+8|0)>>2]>>1;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){na=ka;oa=la;pa=ma}else{W=c[(a+12416|0)>>2]|0;Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W,I)|0)+O)|0;V=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Y,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=V;W=c[(j+8|0)>>2]>>1;Y=c[(j+12|0)>>2]>>1;X=(ca((d[B+((Y<<1)-D)|0]|0)+(d[B+((W<<1)-C)|0]|0)|0,J)|0)+V|0;if((X|0)>=(ka|0)){na=ka;oa=la;pa=ma;break}c[(q+8|0)>>2]=W;c[s+4>>2]=Y;na=X;oa=W;pa=Y}}while(0);O=c[(j+20|0)>>2]>>1;I=c[(j+16|0)>>2]>>1;P=I+K+(O<<11)|0;do{if((c[(G+(((O<<3)+I&63)<<2)|0)>>2]|0)==(P|0)){qa=na;ra=oa;sa=pa}else{Y=c[(a+12416|0)>>2]|0;W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y,O)|0)+I)|0;X=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,W,Y,16)|0;c[(G+(((O<<3)+I&63)<<2)|0)>>2]=P;c[v+(((O<<3)+I&63)<<2)>>2]=X;Y=c[(j+16|0)>>2]>>1;W=c[(j+20|0)>>2]>>1;V=(ca((d[B+((W<<1)-D)|0]|0)+(d[B+((Y<<1)-C)|0]|0)|0,J)|0)+X|0;if((V|0)>=(na|0)){qa=na;ra=oa;sa=pa;break}c[(q+8|0)>>2]=Y;c[s+4>>2]=W;qa=V;ra=Y;sa=W}}while(0);I=c[(j+28|0)>>2]>>1;O=c[(j+24|0)>>2]>>1;P=O+K+(I<<11)|0;if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){ta=qa;ua=ra;va=sa;break}W=c[(a+12416|0)>>2]|0;Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W,I)|0)+O)|0;V=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Y,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=V;O=c[(j+24|0)>>2]>>1;I=c[(j+28|0)>>2]>>1;P=(ca((d[B+((I<<1)-D)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+V|0;if((P|0)>=(qa|0)){ta=qa;ua=ra;va=sa;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;ta=P;ua=O;va=I}else{I=c[(j+12|0)>>2]>>1;O=c[(j+8|0)>>2]>>1;P=O+K+(I<<11)|0;do{if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){wa=M;xa=0;ya=0}else{V=c[(a+12416|0)>>2]|0;W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V,I)|0)+O)|0;Y=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,W,V,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=Y;V=c[(j+8|0)>>2]>>1;W=c[(j+12|0)>>2]>>1;X=(ca((d[B+((W<<1)-D)|0]|0)+(d[B+((V<<1)-C)|0]|0)|0,J)|0)+Y|0;if((X|0)>=(M|0)){wa=M;xa=0;ya=0;break}c[(q+8|0)>>2]=V;c[s+4>>2]=W;wa=X;xa=V;ya=W}}while(0);O=(ca(b[m+(u<<2)>>1]|0,n)|0)+32768>>16;I=(ca(b[m+(u<<2)+2>>1]|0,n)|0)+32768>>16;P=(O|0)>(z|0)?z:O;O=(w|0)>(P|0)?w:P;P=(I|0)>(A|0)?A:I;I=(y|0)>(P|0)?y:P;P=O+K+(I<<11)|0;if((c[(G+(((I<<3)+O&63)<<2)|0)>>2]|0)==(P|0)){ta=wa;ua=xa;va=ya;break}W=c[(a+12416|0)>>2]|0;V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W,I)|0)+O)|0;X=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,V,W,16)|0;c[(G+(((I<<3)+O&63)<<2)|0)>>2]=P;c[v+(((I<<3)+O&63)<<2)>>2]=X;P=(ca((d[B+((I<<1)-D)|0]|0)+(d[B+((O<<1)-C)|0]|0)|0,J)|0)+X|0;if((P|0)>=(wa|0)){ta=wa;ua=xa;va=ya;break}c[(q+8|0)>>2]=O;c[s+4>>2]=I;ta=P;ua=O;va=I}}while(0);do{if((ta|0)>1024){if((c[(a+12256|0)>>2]|0)==0){ya=(ca(b[m+((u+1|0)<<2)>>1]|0,n)|0)+32768>>16;xa=(ca(b[m+((u+1|0)<<2)+2>>1]|0,n)|0)+32768>>16;wa=(ya|0)>(z|0)?z:ya;ya=(w|0)>(wa|0)?w:wa;wa=(xa|0)>(A|0)?A:xa;xa=(y|0)>(wa|0)?y:wa;wa=ya+K+(xa<<11)|0;do{if((c[(G+(((xa<<3)+ya&63)<<2)|0)>>2]|0)==(wa|0)){za=ta;Aa=ua;Ba=va}else{M=c[(a+12416|0)>>2]|0;sa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(M,xa)|0)+ya)|0;ra=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,sa,M,16)|0;c[(G+(((xa<<3)+ya&63)<<2)|0)>>2]=wa;c[v+(((xa<<3)+ya&63)<<2)>>2]=ra;M=(ca((d[B+((xa<<1)-D)|0]|0)+(d[B+((ya<<1)-C)|0]|0)|0,J)|0)+ra|0;if((M|0)>=(ta|0)){za=ta;Aa=ua;Ba=va;break}c[(q+8|0)>>2]=ya;c[s+4>>2]=xa;za=M;Aa=ya;Ba=xa}}while(0);if(((c[(a+12480|0)>>2]|0)+1|0)>=(c[a+812>>2]|0)){Ca=za;Da=Aa;Ea=Ba;break}xa=(ca(b[m+((u+t|0)<<2)>>1]|0,n)|0)+32768>>16;ya=(ca(b[m+((u+t|0)<<2)+2>>1]|0,n)|0)+32768>>16;wa=(xa|0)>(z|0)?z:xa;xa=(w|0)>(wa|0)?w:wa;wa=(ya|0)>(A|0)?A:ya;ya=(y|0)>(wa|0)?y:wa;wa=xa+K+(ya<<11)|0;if((c[(G+(((ya<<3)+xa&63)<<2)|0)>>2]|0)==(wa|0)){Ca=za;Da=Aa;Ea=Ba;break}M=c[(a+12416|0)>>2]|0;ra=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(M,ya)|0)+xa)|0;sa=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,ra,M,16)|0;c[(G+(((ya<<3)+xa&63)<<2)|0)>>2]=wa;c[v+(((ya<<3)+xa&63)<<2)>>2]=sa;wa=(ca((d[B+((ya<<1)-D)|0]|0)+(d[B+((xa<<1)-C)|0]|0)|0,J)|0)+sa|0;if((wa|0)>=(za|0)){Ca=za;Da=Aa;Ea=Ba;break}c[(q+8|0)>>2]=xa;c[s+4>>2]=ya;Ca=wa;Da=xa;Ea=ya;break}else{ya=(ca(b[m+((u-1|0)<<2)>>1]|0,n)|0)+32768>>16;xa=(ca(b[m+((u-1|0)<<2)+2>>1]|0,n)|0)+32768>>16;wa=(ya|0)>(z|0)?z:ya;ya=(w|0)>(wa|0)?w:wa;wa=(xa|0)>(A|0)?A:xa;xa=(y|0)>(wa|0)?y:wa;wa=ya+K+(xa<<11)|0;do{if((c[(G+(((xa<<3)+ya&63)<<2)|0)>>2]|0)==(wa|0)){Fa=ta;Ga=ua;Ha=va}else{sa=c[(a+12416|0)>>2]|0;M=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(sa,xa)|0)+ya)|0;ra=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,M,sa,16)|0;c[(G+(((xa<<3)+ya&63)<<2)|0)>>2]=wa;c[v+(((xa<<3)+ya&63)<<2)>>2]=ra;sa=(ca((d[B+((xa<<1)-D)|0]|0)+(d[B+((ya<<1)-C)|0]|0)|0,J)|0)+ra|0;if((sa|0)>=(ta|0)){Fa=ta;Ga=ua;Ha=va;break}c[(q+8|0)>>2]=ya;c[s+4>>2]=xa;Fa=sa;Ga=ya;Ha=xa}}while(0);if((c[(a+14084|0)>>2]|0)!=0){Ca=Fa;Da=Ga;Ea=Ha;break}xa=(ca(b[m+((u-t|0)<<2)>>1]|0,n)|0)+32768>>16;ya=(ca(b[m+((u-t|0)<<2)+2>>1]|0,n)|0)+32768>>16;wa=(xa|0)>(z|0)?z:xa;xa=(w|0)>(wa|0)?w:wa;wa=(ya|0)>(A|0)?A:ya;ya=(y|0)>(wa|0)?y:wa;wa=xa+K+(ya<<11)|0;if((c[(G+(((ya<<3)+xa&63)<<2)|0)>>2]|0)==(wa|0)){Ca=Fa;Da=Ga;Ea=Ha;break}sa=c[(a+12416|0)>>2]|0;ra=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(sa,ya)|0)+xa)|0;M=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,ra,sa,16)|0;c[(G+(((ya<<3)+xa&63)<<2)|0)>>2]=wa;c[v+(((ya<<3)+xa&63)<<2)>>2]=M;wa=(ca((d[B+((ya<<1)-D)|0]|0)+(d[B+((xa<<1)-C)|0]|0)|0,J)|0)+M|0;if((wa|0)>=(Fa|0)){Ca=Fa;Da=Ga;Ea=Ha;break}c[(q+8|0)>>2]=xa;c[s+4>>2]=ya;Ca=wa;Da=xa;Ea=ya;break}}else{Ca=ta;Da=ua;Ea=va}}while(0);va=c[(c[a+12120>>2]|0)+252>>2]|0;do{if((va|0)==0){Ia=Ca;Ja=Da;Ka=Ea}else{ua=c[(a+12476|0)>>2]|0;ta=(ua-va|0|0)<0?0:ua-va|0;Ha=c[(a+12480|0)>>2]|0;Ga=(Ha-va|0|0)<0?0:Ha-va|0;Fa=c[a+116>>2]|0;u=(Fa|0)>(ua+(va+1|0)|0|0)?ua+(va+1|0)|0:Fa;Fa=c[a+120>>2]|0;ua=(Fa|0)>(Ha+(va+1|0)|0|0)?Ha+(va+1|0)|0:Fa;if((Ga|0)>=(ua|0)){Ia=Ca;Ja=Da;Ka=Ea;break}Fa=Ga;Ga=Ca;Ha=Da;Ba=Ea;while(1){Aa=Fa+1|0;a:do{if((ta|0)<(u|0)){za=ca(Aa,t)|0;ya=ta;xa=Ga;wa=Ha;M=Ba;while(1){sa=ya;b:while(1){La=sa+1|0;Ma=(ca(b[m+((La+za|0)<<2)>>1]|0,n)|0)+32768>>16;Na=(ca(b[m+((La+za|0)<<2)+2>>1]|0,n)|0)+32768>>16;do{if(!((Ma|0)>(z|0)|(Ma|0)<(w|0)|(Na|0)>(A|0)|(Na|0)<(y|0))){ra=Ma+K+(Na<<11)|0;if((c[(G+(((Na<<3)+Ma&63)<<2)|0)>>2]|0)==(ra|0)){break}qa=c[(a+12416|0)>>2]|0;pa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(qa,Na)|0)+Ma)|0;oa=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,pa,qa,16)|0;c[(G+(((Na<<3)+Ma&63)<<2)|0)>>2]=ra;c[v+(((Na<<3)+Ma&63)<<2)>>2]=oa;Oa=(ca((d[B+((Na<<1)-D)|0]|0)+(d[B+((Ma<<1)-C)|0]|0)|0,J)|0)+oa|0;if((Oa|0)<(xa|0)){break b}}}while(0);if((La|0)<(u|0)){sa=La}else{Pa=xa;Qa=wa;Ra=M;break a}}c[(q+8|0)>>2]=Ma;c[(s+4|0)>>2]=Na;if((La|0)<(u|0)){ya=La;xa=Oa;wa=Ma;M=Na}else{Pa=Oa;Qa=Ma;Ra=Na;break}}}else{Pa=Ga;Qa=Ha;Ra=Ba}}while(0);if((Aa|0)<(ua|0)){Fa=Aa;Ga=Pa;Ha=Qa;Ba=Ra}else{Ia=Pa;Ja=Qa;Ka=Ra;break}}}}while(0);Ra=q+8|0;Qa=c[(a+12260|0)>>2]|0;c:do{if((Qa|0)==-1){Pa=c[(a+12220|0)>>2]|0;Na=c[(a+12264|0)>>2]|0;Ma=c[(a+12272|0)>>2]|0;Oa=c[(a+12268|0)>>2]|0;La=c[(a+12276|0)>>2]|0;C=c[(a+12464|0)>>2]|0;B=c[(a+12280|0)>>2]|0;D=c[(a+12284|0)>>2]|0;v=c[(a+12216|0)>>2]|0;G=c[(a+12224|0)>>2]|0;H=c[a+10468>>2]|0;K=Ia;y=Ka;A=Ja;d:while(1){w=1;z=K;t=y;Ea=A;while(1){do{if((w-1&w|0)==0){Da=w+A|0;if((Da|0)>(Oa|0)){Sa=z;Ta=t;Ua=Ea;break}Ca=A-w|0;if((Ca|0)<(Na|0)){Sa=z;Ta=t;Ua=Ea;break}va=w+y|0;if((va|0)>(La|0)){Sa=z;Ta=t;Ua=Ea;break}Ba=y-w|0;if((Ba|0)<(Ma|0)){Sa=z;Ta=t;Ua=Ea;break}else{Va=0;Wa=z;Xa=t;Ya=Ea}while(1){Ha=va-Va|0;Ga=Va+A|0;do{if((c[(v+(((Ha<<3)+Ga&63)<<2)|0)>>2]|0)==(Ga+G+(Ha<<11)|0|0)){Za=Wa;_a=Xa;$a=Ya}else{Fa=c[(a+12416|0)>>2]|0;ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Fa,Ha)|0)+Ga)|0;u=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,ua,Fa,16)|0;c[(v+(((Ha<<3)+Ga&63)<<2)|0)>>2]=Ga+G+(Ha<<11)|0;c[Pa+(((Ha<<3)+Ga&63)<<2)>>2]=u;Fa=(ca((d[C+((Ha<<1)-D)|0]|0)+(d[C+((Ga<<1)-B)|0]|0)|0,J)|0)+u|0;if((Fa|0)>=(Wa|0)){Za=Wa;_a=Xa;$a=Ya;break}c[Ra>>2]=Ga;c[(Ra+4|0)>>2]=Ha;Za=Fa;_a=Ha;$a=Ga}}while(0);Ga=y-Va|0;Ha=Da-Va|0;do{if((c[(v+(((Ga<<3)+Ha&63)<<2)|0)>>2]|0)==(Ha+G+(Ga<<11)|0|0)){ab=Za;bb=_a;cb=$a}else{Fa=c[(a+12416|0)>>2]|0;u=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Fa,Ga)|0)+Ha)|0;ua=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,u,Fa,16)|0;c[(v+(((Ga<<3)+Ha&63)<<2)|0)>>2]=Ha+G+(Ga<<11)|0;c[Pa+(((Ga<<3)+Ha&63)<<2)>>2]=ua;Fa=(ca((d[C+((Ga<<1)-D)|0]|0)+(d[C+((Ha<<1)-B)|0]|0)|0,J)|0)+ua|0;if((Fa|0)>=(Za|0)){ab=Za;bb=_a;cb=$a;break}c[Ra>>2]=Ha;c[(Ra+4|0)>>2]=Ga;ab=Fa;bb=Ga;cb=Ha}}while(0);Ha=Va+Ba|0;Ga=A-Va|0;do{if((c[(v+(((Ha<<3)+Ga&63)<<2)|0)>>2]|0)==(Ga+G+(Ha<<11)|0|0)){db=ab;eb=bb;fb=cb}else{Fa=c[(a+12416|0)>>2]|0;ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Fa,Ha)|0)+Ga)|0;u=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,ua,Fa,16)|0;c[(v+(((Ha<<3)+Ga&63)<<2)|0)>>2]=Ga+G+(Ha<<11)|0;c[Pa+(((Ha<<3)+Ga&63)<<2)>>2]=u;Fa=(ca((d[C+((Ha<<1)-D)|0]|0)+(d[C+((Ga<<1)-B)|0]|0)|0,J)|0)+u|0;if((Fa|0)>=(ab|0)){db=ab;eb=bb;fb=cb;break}c[Ra>>2]=Ga;c[(Ra+4|0)>>2]=Ha;db=Fa;eb=Ha;fb=Ga}}while(0);Ga=Va+y|0;Ha=Va+Ca|0;do{if((c[(v+(((Ga<<3)+Ha&63)<<2)|0)>>2]|0)==(Ha+G+(Ga<<11)|0|0)){gb=db;hb=eb;ib=fb}else{Fa=c[(a+12416|0)>>2]|0;u=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Fa,Ga)|0)+Ha)|0;ua=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,u,Fa,16)|0;c[(v+(((Ga<<3)+Ha&63)<<2)|0)>>2]=Ha+G+(Ga<<11)|0;c[Pa+(((Ga<<3)+Ha&63)<<2)>>2]=ua;Fa=(ca((d[C+((Ga<<1)-D)|0]|0)+(d[C+((Ha<<1)-B)|0]|0)|0,J)|0)+ua|0;if((Fa|0)>=(db|0)){gb=db;hb=eb;ib=fb;break}c[Ra>>2]=Ha;c[(Ra+4|0)>>2]=Ga;gb=Fa;hb=Ga;ib=Ha}}while(0);Ha=Va+2|0;if((Ha|0)<(w|0)){Va=Ha;Wa=gb;Xa=hb;Ya=ib}else{break}}if((A|0)!=(ib|0)){K=gb;y=hb;A=ib;continue d}if((y|0)==(hb|0)){Sa=gb;Ta=y;Ua=A}else{K=gb;y=hb;A=A;continue d}}else{Sa=z;Ta=t;Ua=Ea}}while(0);Ca=w+1|0;if((Ca|0)<5){w=Ca;z=Sa;t=Ta;Ea=Ua}else{jb=Sa;break c}}}}else{if((Qa|0)<-1){jb=trb(a,Ra,k,l,J,0,16,0)|0;break}if((Qa|0)<2){A=c[(a+12220|0)>>2]|0;y=c[(a+12264|0)>>2]|0;K=c[(a+12272|0)>>2]|0;B=c[(a+12268|0)>>2]|0;C=c[(a+12276|0)>>2]|0;D=c[(a+12464|0)>>2]|0;Pa=c[(a+12280|0)>>2]|0;G=c[(a+12284|0)>>2]|0;v=c[(a+12216|0)>>2]|0;H=c[(a+12224|0)>>2]|0;Ma=c[a+10468>>2]|0;La=(Ka<<11)+Ja+H|0;Na=(Ka<<3)+Ja&63;if((c[(v+(Na<<2)|0)>>2]|0)==(La|0)){kb=Ia;lb=-1;mb=Ja;nb=Ka}else{Oa=c[(a+12416|0)>>2]|0;Ea=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Oa,Ka)|0)+Ja)|0;c[A+(Na<<2)>>2]=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Ea,Oa,16)|0;c[(v+(Na<<2)|0)>>2]=La;kb=Ia;lb=-1;mb=Ja;nb=Ka}while(1){La=(mb|0)>(y|0);Na=mb-1|0;Oa=mb+H|0;Ea=D+((mb<<1)-Pa)|0;t=(mb|0)<(B|0);z=mb+1|0;w=kb;Aa=lb;Ca=nb;while(1){do{if((Aa|0)!=2&La){Ba=(Ca<<11)+H+Na|0;Da=Na+(Ca<<3)&63;if((c[(v+(Da<<2)|0)>>2]|0)==(Ba|0)){ob=w;pb=-1;qb=mb;break}va=c[(a+12416|0)>>2]|0;Ha=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(va,Ca)|0)+Na)|0;Ga=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Ha,va,16)|0;c[(v+(Da<<2)|0)>>2]=Ba;c[A+(Da<<2)>>2]=Ga;Da=(ca((d[D+((Ca<<1)-G)|0]|0)+(d[D+((Na<<1)-Pa)|0]|0)|0,J)|0)+Ga|0;if((Da|0)>=(w|0)){ob=w;pb=-1;qb=mb;break}c[Ra>>2]=Na;c[(Ra+4|0)>>2]=Ca;ob=Da;pb=0;qb=Na}else{ob=w;pb=-1;qb=mb}}while(0);do{if((Aa|0)!=3&(Ca|0)>(K|0)){Da=Ca-1|0;Ga=(Da<<3)+mb&63;if((c[(v+(Ga<<2)|0)>>2]|0)==(Oa+(Da<<11)|0|0)){rb=ob;sb=pb;tb=qb;ub=Ca;break}Ba=c[(a+12416|0)>>2]|0;va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ba,Da)|0)+mb)|0;Ha=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,va,Ba,16)|0;c[(v+(Ga<<2)|0)>>2]=Oa+(Da<<11)|0;c[A+(Ga<<2)>>2]=Ha;Ga=(ca((d[D+((Da<<1)-G)|0]|0)+(d[Ea]|0)|0,J)|0)+Ha|0;if((Ga|0)>=(ob|0)){rb=ob;sb=pb;tb=qb;ub=Ca;break}c[Ra>>2]=mb;c[(Ra+4|0)>>2]=Da;rb=Ga;sb=1;tb=mb;ub=Da}else{rb=ob;sb=pb;tb=qb;ub=Ca}}while(0);do{if((Aa|0)!=0&t){Da=(Ca<<11)+H+z|0;Ga=z+(Ca<<3)&63;if((c[(v+(Ga<<2)|0)>>2]|0)==(Da|0)){vb=rb;wb=sb;xb=tb;yb=ub;break}Ha=c[(a+12416|0)>>2]|0;Ba=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ha,Ca)|0)+z)|0;va=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Ba,Ha,16)|0;c[(v+(Ga<<2)|0)>>2]=Da;c[A+(Ga<<2)>>2]=va;Ga=(ca((d[D+((Ca<<1)-G)|0]|0)+(d[D+((z<<1)-Pa)|0]|0)|0,J)|0)+va|0;if((Ga|0)>=(rb|0)){vb=rb;wb=sb;xb=tb;yb=ub;break}c[Ra>>2]=z;c[(Ra+4|0)>>2]=Ca;vb=Ga;wb=2;xb=z;yb=Ca}else{vb=rb;wb=sb;xb=tb;yb=ub}}while(0);if(!((Aa|0)!=1&(Ca|0)<(C|0))){break}Ga=Ca+1|0;va=(Ga<<3)+mb&63;if((c[(v+(va<<2)|0)>>2]|0)==(Oa+(Ga<<11)|0|0)){break}Da=c[(a+12416|0)>>2]|0;Ha=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Da,Ga)|0)+mb)|0;Ba=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Ha,Da,16)|0;c[(v+(va<<2)|0)>>2]=Oa+(Ga<<11)|0;c[A+(va<<2)>>2]=Ba;va=(ca((d[D+((Ga<<1)-G)|0]|0)+(d[Ea]|0)|0,J)|0)+Ba|0;if((va|0)>=(vb|0)){break}c[Ra>>2]=mb;c[(Ra+4|0)>>2]=Ga;w=va;Aa=3;Ca=Ga}if((wb|0)==-1){jb=vb;break c}else{kb=vb;lb=wb;mb=xb;nb=yb}}}if((Qa|0)>1024){jb=urb(a,Ra,Ia,k,l,J,0,16,0)|0;break}if((Qa|0)>768){G=c[(a+12220|0)>>2]|0;D=c[(a+12264|0)>>2]|0;A=c[(a+12272|0)>>2]|0;v=c[(a+12268|0)>>2]|0;Ma=c[(a+12276|0)>>2]|0;C=c[(a+12464|0)>>2]|0;Pa=c[(a+12280|0)>>2]|0;H=c[(a+12284|0)>>2]|0;K=c[(a+12216|0)>>2]|0;B=c[(a+12224|0)>>2]|0;y=c[a+10468>>2]|0;Ca=Ja-(Qa&254)+1|0;Aa=(Ca|0)>(D|0)?Ca:D;Ca=Ja-1+(Qa&254)|0;w=(Ca|0)>(v|0)?v:Ca;if((Aa|0)>(w|0)){zb=Ia;Ab=Ja;Bb=Ka}else{Ca=B+(Ka<<11)|0;Ea=Ka<<3;Oa=C+((Ka<<1)-H)|0;z=Aa;Aa=Ia;t=Ja;Na=Ka;while(1){La=Ca+z|0;Ga=z+Ea&63;do{if((c[(K+(Ga<<2)|0)>>2]|0)==(La|0)){Cb=Aa;Db=t;Eb=Na}else{va=c[(a+12416|0)>>2]|0;Ba=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(va,Ka)|0)+z)|0;Da=Xe[y&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Ba,va,16)|0;c[(K+(Ga<<2)|0)>>2]=La;c[G+(Ga<<2)>>2]=Da;va=(ca((d[Oa]|0)+(d[C+((z<<1)-Pa)|0]|0)|0,J)|0)+Da|0;if((va|0)>=(Aa|0)){Cb=Aa;Db=t;Eb=Na;break}c[Ra>>2]=z;c[(Ra+4|0)>>2]=Ka;Cb=va;Db=z;Eb=Ka}}while(0);Ga=z+2|0;if((Ga|0)>(w|0)){zb=Cb;Ab=Db;Bb=Eb;break}else{z=Ga;Aa=Cb;t=Db;Na=Eb}}}Na=Ka-((Qa&254)>>>1)+1|0;t=(Na|0)>(A|0)?Na:A;Na=Ka-1+((Qa&254)>>>1)|0;Aa=(Na|0)>(Ma|0)?Ma:Na;if((t|0)>(Aa|0)){Fb=zb;Gb=Ab;Hb=Bb}else{Na=B+Ja|0;z=C+((Ja<<1)-Pa)|0;w=t;t=zb;Oa=Ab;Ea=Bb;while(1){Ca=Na+(w<<11)|0;Ga=(w<<3)+Ja&63;do{if((c[(K+(Ga<<2)|0)>>2]|0)==(Ca|0)){Ib=t;Jb=Oa;Kb=Ea}else{La=c[(a+12416|0)>>2]|0;va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(La,w)|0)+Ja)|0;Da=Xe[y&511](a,c[(a+12288+(k<<4)|0)>>2]|0,va,La,16)|0;c[(K+(Ga<<2)|0)>>2]=Ca;c[G+(Ga<<2)>>2]=Da;La=(ca((d[C+((w<<1)-H)|0]|0)+(d[z]|0)|0,J)|0)+Da|0;if((La|0)>=(t|0)){Ib=t;Jb=Oa;Kb=Ea;break}c[Ra>>2]=Ja;c[(Ra+4|0)>>2]=w;Ib=La;Jb=Ja;Kb=w}}while(0);Ga=w+2|0;if((Ga|0)>(Aa|0)){Fb=Ib;Gb=Jb;Hb=Kb;break}else{w=Ga;t=Ib;Oa=Jb;Ea=Kb}}}Ea=Hb-2|0;Oa=(Ea|0)>(A|0)?Ea:A;Ea=Hb+2|0;t=(Ea|0)>(Ma|0)?Ma:Ea;if((Oa|0)>(t|0)){Lb=Fb}else{Ea=Gb-2|0;w=(Ea|0)>(D|0)?Ea:D;Ea=Gb+2|0;Aa=(Ea|0)>(v|0)?v:Ea;Ea=Oa;Oa=Fb;while(1){if((w|0)>(Aa|0)){Mb=Oa}else{z=(Ea<<11)+B|0;Na=Ea<<3;Ga=C+((Ea<<1)-H)|0;Ca=w;La=Oa;while(1){Da=z+Ca|0;va=Ca+Na&63;do{if((c[(K+(va<<2)|0)>>2]|0)==(Da|0)){Nb=La}else{Ba=c[(a+12416|0)>>2]|0;Ha=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ba,Ea)|0)+Ca)|0;Fa=Xe[y&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Ha,Ba,16)|0;c[(K+(va<<2)|0)>>2]=Da;c[G+(va<<2)>>2]=Fa;Ba=(ca((d[Ga]|0)+(d[C+((Ca<<1)-Pa)|0]|0)|0,J)|0)+Fa|0;if((Ba|0)>=(La|0)){Nb=La;break}c[Ra>>2]=Ca;c[(Ra+4|0)>>2]=Ea;Nb=Ba}}while(0);va=Ca+1|0;if((va|0)>(Aa|0)){Mb=Nb;break}else{Ca=va;La=Nb}}}La=Ea+1|0;if((La|0)>(t|0)){Lb=Mb;break}else{Ea=La;Oa=Mb}}}if(((Qa&254)>>>2|0)==0){Ob=Lb}else{Oa=1;Ea=Lb;while(1){t=0;Aa=Ea;while(1){w=(ca(c[284520+(t<<3)>>2]|0,Oa)|0)+Gb|0;La=(ca(c[284524+(t<<3)>>2]|0,Oa)|0)+Hb|0;Ca=(w|0)>(v|0)?v:w;w=(D|0)>(Ca|0)?D:Ca;Ca=(La|0)>(Ma|0)?Ma:La;La=(A|0)>(Ca|0)?A:Ca;do{if((c[(K+(((La<<3)+w&63)<<2)|0)>>2]|0)==(w+B+(La<<11)|0|0)){Pb=Aa}else{Ca=c[(a+12416|0)>>2]|0;Ga=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ca,La)|0)+w)|0;Na=Xe[y&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Ga,Ca,16)|0;c[(K+(((La<<3)+w&63)<<2)|0)>>2]=w+B+(La<<11)|0;c[G+(((La<<3)+w&63)<<2)>>2]=Na;Ca=(ca((d[C+((La<<1)-H)|0]|0)+(d[C+((w<<1)-Pa)|0]|0)|0,J)|0)+Na|0;if((Ca|0)>=(Aa|0)){Pb=Aa;break}c[Ra>>2]=w;c[(Ra+4|0)>>2]=La;Pb=Ca}}while(0);La=t+1|0;if((La|0)<16){t=La;Aa=Pb}else{break}}Aa=Oa+1|0;if((Aa|0)>((Qa&254)>>>2|0)){Ob=Pb;break}else{Oa=Aa;Ea=Pb}}}jb=vrb(a,Ra,Ob,k,l,J,0,16,0,2)|0;break}if((Qa|0)>512){jb=vrb(a,Ra,Ia,k,l,J,0,16,0,Qa&255)|0;break}Ea=c[(a+12220|0)>>2]|0;Oa=c[(a+12264|0)>>2]|0;Pa=c[(a+12272|0)>>2]|0;C=c[(a+12268|0)>>2]|0;H=c[(a+12276|0)>>2]|0;G=c[(a+12464|0)>>2]|0;B=c[(a+12280|0)>>2]|0;K=c[(a+12284|0)>>2]|0;y=c[(a+12216|0)>>2]|0;A=c[(a+12224|0)>>2]|0;if((Qa|0)>256){Ma=c[a+10468>>2]|0;if((Qa&255|0)==0){Qb=Ia;Rb=Ja;Sb=Ka;Tb=Ra+4|0}else{D=Qa&255;v=Ia;Aa=Ka;t=Ja;while(1){La=v;w=Aa;Ca=t;while(1){Na=0;Ga=La;z=w;va=Ca;while(1){Da=(ca(c[1017160+(Na<<3)>>2]|0,D)|0)+Ca|0;Ba=(ca(c[1017164+(Na<<3)>>2]|0,D)|0)+w|0;Fa=(Da|0)>(C|0)?C:Da;Da=(Oa|0)>(Fa|0)?Oa:Fa;Fa=(Ba|0)>(H|0)?H:Ba;Ba=(Pa|0)>(Fa|0)?Pa:Fa;do{if((c[(y+(((Ba<<3)+Da&63)<<2)|0)>>2]|0)==(Da+A+(Ba<<11)|0|0)){Ub=Ga;Vb=z;Wb=va}else{Fa=c[(a+12416|0)>>2]|0;Ha=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Fa,Ba)|0)+Da)|0;ua=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Ha,Fa,16)|0;c[(y+(((Ba<<3)+Da&63)<<2)|0)>>2]=Da+A+(Ba<<11)|0;c[Ea+(((Ba<<3)+Da&63)<<2)>>2]=ua;Fa=(ca((d[G+((Ba<<1)-K)|0]|0)+(d[G+((Da<<1)-B)|0]|0)|0,J)|0)+ua|0;if((Fa|0)>=(Ga|0)){Ub=Ga;Vb=z;Wb=va;break}c[Ra>>2]=Da;c[(Ra+4|0)>>2]=Ba;Ub=Fa;Vb=Ba;Wb=Da}}while(0);Da=Na+1|0;if((Da|0)<8){Na=Da;Ga=Ub;z=Vb;va=Wb}else{break}}if((Wb|0)==(Ca|0)&(Vb|0)==(w|0)){break}else{La=Ub;w=Vb;Ca=Wb}}La=(Qa+255&(Qa&255)|0)!=0?D-1|0:D>>1;if((La|0)==0){Qb=Ub;Rb=Ca;Sb=w;Tb=Ra+4|0;break}else{D=La;v=Ub;Aa=w;t=Ca}}}t=Rb+1|0;Aa=(t|0)>(C|0)?C:t;t=(Oa|0)>(Aa|0)?Oa:Aa;Aa=(Sb|0)>(H|0)?H:Sb;v=(Pa|0)>(Aa|0)?Pa:Aa;do{if((c[(y+((t+(v<<3)&63)<<2)|0)>>2]|0)==(((v<<11)+A|0)+t|0|0)){Xb=Qb}else{Aa=c[(a+12416|0)>>2]|0;D=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Aa,v)|0)+t)|0;La=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,D,Aa,16)|0;c[(y+((t+(v<<3)&63)<<2)|0)>>2]=((v<<11)+A|0)+t|0;c[Ea+((t+(v<<3)&63)<<2)>>2]=La;Aa=(ca((d[G+((v<<1)-K)|0]|0)+(d[G+((t<<1)-B)|0]|0)|0,J)|0)+La|0;if((Aa|0)>=(Qb|0)){Xb=Qb;break}c[Ra>>2]=t;c[Tb>>2]=v;Xb=Aa}}while(0);t=Sb+1|0;Aa=(Rb|0)>(C|0)?C:Rb;La=(Oa|0)>(Aa|0)?Oa:Aa;Aa=(t|0)>(H|0)?H:t;t=(Pa|0)>(Aa|0)?Pa:Aa;do{if((c[(y+(((t<<3)+La&63)<<2)|0)>>2]|0)==((La+A|0)+(t<<11)|0|0)){Yb=Xb}else{Aa=c[(a+12416|0)>>2]|0;D=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Aa,t)|0)+La)|0;va=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,D,Aa,16)|0;c[(y+(((t<<3)+La&63)<<2)|0)>>2]=(La+A|0)+(t<<11)|0;c[Ea+(((t<<3)+La&63)<<2)>>2]=va;Aa=(ca((d[G+((t<<1)-K)|0]|0)+(d[G+((La<<1)-B)|0]|0)|0,J)|0)+va|0;if((Aa|0)>=(Xb|0)){Yb=Xb;break}c[Ra>>2]=La;c[Tb>>2]=t;Yb=Aa}}while(0);t=Rb-1|0;Aa=(t|0)>(C|0)?C:t;t=(Oa|0)>(Aa|0)?Oa:Aa;do{if((c[(y+((t+(v<<3)&63)<<2)|0)>>2]|0)==(((v<<11)+A|0)+t|0|0)){Zb=Yb}else{Aa=c[(a+12416|0)>>2]|0;va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Aa,v)|0)+t)|0;D=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,va,Aa,16)|0;c[(y+((t+(v<<3)&63)<<2)|0)>>2]=((v<<11)+A|0)+t|0;c[Ea+((t+(v<<3)&63)<<2)>>2]=D;Aa=(ca((d[G+((v<<1)-K)|0]|0)+(d[G+((t<<1)-B)|0]|0)|0,J)|0)+D|0;if((Aa|0)>=(Yb|0)){Zb=Yb;break}c[Ra>>2]=t;c[Tb>>2]=v;Zb=Aa}}while(0);v=Sb-1|0;t=(v|0)>(H|0)?H:v;v=(Pa|0)>(t|0)?Pa:t;if((c[(y+(((v<<3)+La&63)<<2)|0)>>2]|0)==((La+A|0)+(v<<11)|0|0)){jb=Zb;break}t=c[(a+12416|0)>>2]|0;Aa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(t,v)|0)+La)|0;D=Xe[Ma&511](a,c[(a+12288+(k<<4)|0)>>2]|0,Aa,t,16)|0;c[(y+(((v<<3)+La&63)<<2)|0)>>2]=(La+A|0)+(v<<11)|0;c[Ea+(((v<<3)+La&63)<<2)>>2]=D;t=(ca((d[G+((v<<1)-K)|0]|0)+(d[G+((La<<1)-B)|0]|0)|0,J)|0)+D|0;if((t|0)>=(Zb|0)){jb=Zb;break}c[Ra>>2]=La;c[Tb>>2]=v;jb=t;break}t=c[a+10468>>2]|0;v=1;D=Ia;Aa=Ja;va=Ka;while(1){z=v+va|0;Ga=(z-H|0|0)<0?0:z-H|0;Na=C-Aa+1|0;Da=(v|0)>(Na|0)?Na:v;if((Ga|0)<(Da|0)){Na=Ga;Ga=D;Ba=va;Fa=Aa;while(1){ua=z-Na|0;Ha=Na+Aa|0;do{if((c[(y+(((ua<<3)+Ha&63)<<2)|0)>>2]|0)==(Ha+A+(ua<<11)|0|0)){_b=Ga;$b=Ba;ac=Fa}else{u=c[(a+12416|0)>>2]|0;ta=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(u,ua)|0)+Ha)|0;M=Xe[t&511](a,c[(a+12288+(k<<4)|0)>>2]|0,ta,u,16)|0;c[(y+(((ua<<3)+Ha&63)<<2)|0)>>2]=Ha+A+(ua<<11)|0;c[Ea+(((ua<<3)+Ha&63)<<2)>>2]=M;u=(ca((d[G+((ua<<1)-K)|0]|0)+(d[G+((Ha<<1)-B)|0]|0)|0,J)|0)+M|0;if((u|0)>=(Ga|0)){_b=Ga;$b=Ba;ac=Fa;break}c[Ra>>2]=Ha;c[(Ra+4|0)>>2]=ua;_b=u;$b=ua;ac=Ha}}while(0);Ha=Na+1|0;if((Ha|0)<(Da|0)){Na=Ha;Ga=_b;Ba=$b;Fa=ac}else{bc=_b;cc=$b;dc=ac;break}}}else{bc=D;cc=va;dc=Aa}Fa=v+Aa|0;Ba=(Fa-C|0|0)<0?0:Fa-C|0;Ga=va-Pa+1|0;Na=(v|0)>(Ga|0)?Ga:v;if((Ba|0)<(Na|0)){Ga=Ba;Ba=bc;Da=cc;z=dc;while(1){Ca=va-Ga|0;w=Fa-Ga|0;do{if((c[(y+(((Ca<<3)+w&63)<<2)|0)>>2]|0)==(w+A+(Ca<<11)|0|0)){ec=Ba;fc=Da;gc=z}else{Ha=c[(a+12416|0)>>2]|0;ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ha,Ca)|0)+w)|0;u=Xe[t&511](a,c[(a+12288+(k<<4)|0)>>2]|0,ua,Ha,16)|0;c[(y+(((Ca<<3)+w&63)<<2)|0)>>2]=w+A+(Ca<<11)|0;c[Ea+(((Ca<<3)+w&63)<<2)>>2]=u;Ha=(ca((d[G+((Ca<<1)-K)|0]|0)+(d[G+((w<<1)-B)|0]|0)|0,J)|0)+u|0;if((Ha|0)>=(Ba|0)){ec=Ba;fc=Da;gc=z;break}c[Ra>>2]=w;c[(Ra+4|0)>>2]=Ca;ec=Ha;fc=Ca;gc=w}}while(0);w=Ga+1|0;if((w|0)<(Na|0)){Ga=w;Ba=ec;Da=fc;z=gc}else{hc=ec;ic=fc;jc=gc;break}}}else{hc=bc;ic=cc;jc=dc}z=v-va+Pa|0;Da=(z|0)<0?0:z;z=Aa-Oa+1|0;Ba=(v|0)>(z|0)?z:v;if((Da|0)<(Ba|0)){z=va-v|0;Ga=Da;Da=hc;Na=ic;Fa=jc;while(1){w=Ga+z|0;Ca=Aa-Ga|0;do{if((c[(y+(((w<<3)+Ca&63)<<2)|0)>>2]|0)==(Ca+A+(w<<11)|0|0)){kc=Da;lc=Na;mc=Fa}else{Ha=c[(a+12416|0)>>2]|0;u=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ha,w)|0)+Ca)|0;ua=Xe[t&511](a,c[(a+12288+(k<<4)|0)>>2]|0,u,Ha,16)|0;c[(y+(((w<<3)+Ca&63)<<2)|0)>>2]=Ca+A+(w<<11)|0;c[Ea+(((w<<3)+Ca&63)<<2)>>2]=ua;Ha=(ca((d[G+((w<<1)-K)|0]|0)+(d[G+((Ca<<1)-B)|0]|0)|0,J)|0)+ua|0;if((Ha|0)>=(Da|0)){kc=Da;lc=Na;mc=Fa;break}c[Ra>>2]=Ca;c[(Ra+4|0)>>2]=w;kc=Ha;lc=w;mc=Ca}}while(0);Ca=Ga+1|0;if((Ca|0)<(Ba|0)){Ga=Ca;Da=kc;Na=lc;Fa=mc}else{nc=kc;oc=lc;pc=mc;break}}}else{nc=hc;oc=ic;pc=jc}Fa=v-Aa+Oa|0;Na=(Fa|0)<0?0:Fa;Fa=H-va+1|0;Da=(v|0)>(Fa|0)?Fa:v;if((Na|0)<(Da|0)){Fa=Aa-v|0;Ga=Na;Na=nc;Ba=oc;z=pc;while(1){Ca=Ga+va|0;w=Ga+Fa|0;do{if((c[(y+(((Ca<<3)+w&63)<<2)|0)>>2]|0)==(w+A+(Ca<<11)|0|0)){qc=Na;rc=Ba;sc=z}else{Ha=c[(a+12416|0)>>2]|0;ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ha,Ca)|0)+w)|0;u=Xe[t&511](a,c[(a+12288+(k<<4)|0)>>2]|0,ua,Ha,16)|0;c[(y+(((Ca<<3)+w&63)<<2)|0)>>2]=w+A+(Ca<<11)|0;c[Ea+(((Ca<<3)+w&63)<<2)>>2]=u;Ha=(ca((d[G+((Ca<<1)-K)|0]|0)+(d[G+((w<<1)-B)|0]|0)|0,J)|0)+u|0;if((Ha|0)>=(Na|0)){qc=Na;rc=Ba;sc=z;break}c[Ra>>2]=w;c[(Ra+4|0)>>2]=Ca;qc=Ha;rc=Ca;sc=w}}while(0);w=Ga+1|0;if((w|0)<(Da|0)){Ga=w;Na=qc;Ba=rc;z=sc}else{tc=qc;uc=rc;vc=sc;break}}}else{tc=nc;uc=oc;vc=pc}z=(Aa|0)==(vc|0)&(va|0)==(uc|0);Ba=z?v+1|0:1;if((Ba|0)>(c[(a+12260|0)>>2]|0)){jb=tc;break}else{v=Ba;D=tc;Aa=vc;va=z?va:uc}}}}while(0);c[f>>2]=c[Ra>>2];c[h>>2]=c[s+4>>2];N=jb;i=q;return N|0}jb=q|0;c[(q|0)>>2]=0;c[(q|0)+4>>2]=0;s=c[a+124>>2]|0;Ra=(ca(c[(a+12480|0)>>2]|0,s)|0)+(c[(a+12476|0)>>2]|0)|0;uc=c[(a+12220|0)>>2]|0;vc=c[(a+12264|0)>>2]|0;tc=c[(a+12272|0)>>2]|0;pc=c[(a+12268|0)>>2]|0;oc=c[(a+12276|0)>>2]|0;nc=c[(a+12464|0)>>2]|0;sc=c[(a+12280|0)>>2]|0;rc=c[(a+12284|0)>>2]|0;qc=c[(a+12216|0)>>2]|0;J=(r&1)+1|0;if((c[(a+12256|0)>>2]|0)==0){wc=a+12232|0;xc=a+10468+(o<<2)|0;yc=a+10468+(o+1<<2)|0}else{wc=a+12228|0;xc=a+10444+(o<<2)|0;yc=a+10444+(o+1<<2)|0}jc=c[wc>>2]|0;wc=c[xc>>2]|0;xc=c[yc>>2]|0;yc=(c[(a+12224|0)>>2]|0)+4194304|0;c[(a+12224|0)>>2]=yc;if((yc|0)==0){c[(a+12224|0)>>2]=4194304;mrc(qc|0,0,256)|0;zc=c[(a+12224|0)>>2]|0}else{zc=yc}do{if((r&4|0)==0){yc=c[a+12416>>2]|0;ic=c[a+12420>>2]|0;hc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,c[a+12352+(l<<4)>>2]|0,yc,p)|0;if((r&2|0)==0){Ac=hc;break}mc=c[a+12208>>2]|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)>>2]&2047](mc+(yc<<4)|0,c[a+12352+(l<<4)+4>>2]|0,ic,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)>>2]&2047](mc+(yc<<4|8)|0,c[a+12352+(l<<4)+8>>2]|0,ic,p>>1);lc=(Xe[xc&511](a,mc+(yc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ic,p>>1)|0)+hc|0;Ac=lc+(Xe[xc&511](a,mc+(yc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ic,p>>1)|0)|0}else{ic=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>0){Ac=536870912;break}if((c[(a+12268|0)>>2]<<J|0)<0){Ac=536870912;break}if((c[(a+12272|0)>>2]|0)>0){Ac=536870912;break}if((c[(a+12276|0)>>2]<<J|0)<0){Ac=536870912;break}yc=e[a+13872>>1]|0;mc=e[a+13874>>1]|0;lc=(r&1)<<1|1;do{if((c[a+11740>>2]|0)==1){hc=0;do{kc=c[a+12160+(hc<<3)>>2]|0;dc=c[a+12160+(hc<<3)+4>>2]|0;cc=((ca(c[a+12128+(hc<<3)>>2]|0,mc-yc|0)|0)/(yc|0)|0)+((hc&1)<<(r&1|4))|0;bc=hc>>1;gc=((ca(c[a+12128+(hc<<3)+4>>2]|0,mc-yc|0)|0)/(yc|0)|0)+(bc<<(r&1|4))|0;fc=(c[(a+12208|0)>>2]|0)+((ca(ic<<3,bc)|0)+(hc<<3&8))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(dc>>1,ic)|0)+(kc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((dc&lc)<<J)+(kc&lc)|0)<<2)>>2]&2047](fc,bc,ic,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(gc>>1,ic)|0)+(cc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((gc&lc)<<J)+(cc&lc)|0)<<2)>>2]&2047](fc,bc,ic,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(dc>>2,ic)|0)+(kc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((dc&lc)<<J)+(kc&lc)|0)<<2)>>2]&4095](fc,bc,ic);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(gc>>2,ic)|0)+(cc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((gc&lc)<<J)+(cc&lc)|0)<<2)>>2]&4095](fc,bc,ic)}hc=hc+1|0;}while((hc|0)<4)}else{hc=c[a+12160>>2]|0;bc=c[a+12164>>2]|0;fc=(ca(c[a+12128>>2]|0,mc-yc|0)|0)/(yc|0)|0;cc=(ca(c[a+12132>>2]|0,mc-yc|0)|0)/(yc|0)|0;if((r&1|0)==0){gc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,ic)|0)+(hc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,gc,ic,16);gc=(c[a+12352+(l<<4)+32>>2]|0)+((ca(cc>>1,ic)|0)+(fc>>1))|0;mf[c[(c[a+12448>>2]|0)+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,gc,ic,16);break}else{gc=(ca(bc>>2,ic)|0)+(hc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+gc|0,ic);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(gc+8|0)|0,ic);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ic<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(gc+(ic<<3))|0,ic);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&lc)<<J)+(hc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ic<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((gc+8|0)+(ic<<3))|0,ic);gc=(ca(cc>>2,ic)|0)+(fc>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+gc|0,ic);ef[c[(c[(a+12456|0)>>2]|0)+64+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(gc+8|0)|0,ic);ef[c[(c[(a+12456|0)>>2]|0)+64+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ic<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(gc+(ic<<3))|0,ic);ef[c[(c[(a+12456|0)>>2]|0)+64+((((cc&lc)<<J)+(fc&lc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ic<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((gc+8|0)+(ic<<3))|0,ic);break}}}while(0);Ac=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ic,16)|0}}while(0);c[qc>>2]=zc;c[uc>>2]=Ac;if((c[a+9992>>2]|0)==3){if((c[(a+12244|0)>>2]&4|0)==0){L=231}else{L=230}}else{L=230}if((L|0)==230){if((c[a+60>>2]&64|0)==0){Bc=Ac}else{L=231}}if((L|0)==231){Bc=(ca((d[nc+rc|0]|0)+(d[nc+sc|0]|0)|0,jc)|0)+Ac|0}do{Ac=1;if(Ac){Ac=0;if((c[(a+14084|0)>>2]|0)==0){L=ca(p,p)|0;do{if((Bc|0)<((ca(L,c[(c[a+4>>2]|0)+376>>2]|0)|0)>>8|0)){if((c[j+12>>2]|c[j+8>>2]|c[j+16>>2]|c[j+20>>2]|c[j+24>>2]|c[j+28>>2]|0)!=0){break}c[f>>2]=0;c[h>>2]=0;c[a+12124>>2]=1;N=Bc;i=q;return N|0}}while(0);L=c[(j+36|0)>>2]|0;ic=c[(j+32|0)>>2]|0;lc=(ic>>J)+zc+(L>>J<<11)|0;do{if((c[(qc+(((L>>J<<3)+(ic>>J)&63)<<2)|0)>>2]|0)==(lc|0)){Cc=Bc;Dc=ic;Ec=L;Fc=0;Gc=0}else{do{if((r&4|0)==0){yc=c[a+12416>>2]|0;mc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(yc,L>>J)|0)+(ic>>J))|0;fc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,yc,p)|0;if((r&2|0)==0){Hc=fc;break}gc=c[a+12208>>2]|0;cc=(ca(mc,L>>J>>1)|0)+(ic>>J>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L>>J<<1&2|ic>>J&1)<<2)>>2]&2047](gc+(yc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+cc|0,mc,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L>>J<<1&2|ic>>J&1)<<2)>>2]&2047](gc+(yc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+cc|0,mc,p>>1);cc=(Xe[xc&511](a,gc+(yc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,mc,p>>1)|0)+fc|0;Hc=cc+(Xe[xc&511](a,gc+(yc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,mc,p>>1)|0)|0}else{mc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic>>J|0)){Hc=536870912;break}if((ic>>J<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Hc=536870912;break}if((c[(a+12272|0)>>2]|0)>(L>>J|0)){Hc=536870912;break}if((L>>J<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Hc=536870912;break}yc=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;cc=(r&1)<<1|1;e:do{if((c[a+11740>>2]|0)==1){if((ic>>J<<J|0)==0){fc=0;while(1){hc=c[a+12160+(fc<<3)>>2]|0;bc=(c[a+12160+(fc<<3)+4>>2]|0)+(L>>J<<J)|0;kc=((ca(c[a+12128+(fc<<3)>>2]|0,gc-yc|0)|0)/(yc|0)|0)+((fc&1)<<(r&1|4))|0;dc=c[a+12128+(fc<<3)+4>>2]|0;if((L>>J<<J|0)==0){ec=fc>>1;Ic=((ca(dc,gc-yc|0)|0)/(yc|0)|0)+(ec<<(r&1|4))|0;Jc=ec}else{Ic=bc-dc|0;Jc=fc>>1}dc=((Ic&cc)<<J)+(kc&cc)|0;ec=(c[(a+12208|0)>>2]|0)+((ca(Jc,mc<<3)|0)+(fc<<3&8))|0;if((r&1|0)==0){ac=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,mc)|0)+(hc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&2047](ec,ac,mc,8);ac=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ic>>1,mc)|0)+(kc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(dc<<2)>>2]&2047](ec,ac,mc,8)}else{ac=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>2,mc)|0)+(hc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&4095](ec,ac,mc);ac=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ic>>2,mc)|0)+(kc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](ec,ac,mc)}fc=fc+1|0;if((fc|0)>=4){break e}}}if((L>>J<<J|0)==0){fc=0;do{ac=(c[a+12160+(fc<<3)>>2]|0)+(ic>>J<<J)|0;ec=c[a+12160+(fc<<3)+4>>2]|0;dc=ac-(c[a+12128+(fc<<3)>>2]|0)|0;kc=fc>>1;hc=((ca(c[a+12128+(fc<<3)+4>>2]|0,gc-yc|0)|0)/(yc|0)|0)+(kc<<(r&1|4))|0;bc=(c[(a+12208|0)>>2]|0)+((fc<<3&8)+(ca(kc,mc<<3)|0))|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ec>>1,mc)|0)+(ac>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ec&cc)<<J)+(ac&cc)|0)<<2)>>2]&2047](bc,kc,mc,8);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(hc>>1,mc)|0)+(dc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((hc&cc)<<J)+(dc&cc)|0)<<2)>>2]&2047](bc,kc,mc,8)}else{kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ec>>2,mc)|0)+(ac>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(ac&cc)|0)<<2)>>2]&4095](bc,kc,mc);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(hc>>2,mc)|0)+(dc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((hc&cc)<<J)+(dc&cc)|0)<<2)>>2]&4095](bc,kc,mc)}fc=fc+1|0;}while((fc|0)<4)}else{fc=0;do{kc=(c[a+12160+(fc<<3)>>2]|0)+(ic>>J<<J)|0;bc=(c[a+12160+(fc<<3)+4>>2]|0)+(L>>J<<J)|0;dc=kc-(c[a+12128+(fc<<3)>>2]|0)|0;hc=bc-(c[a+12128+(fc<<3)+4>>2]|0)|0;ac=(c[(a+12208|0)>>2]|0)+((fc<<3&8)+(ca(fc>>1,mc<<3)|0))|0;if((r&1|0)==0){ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,mc)|0)+(kc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&cc)<<J)+(kc&cc)|0)<<2)>>2]&2047](ac,ec,mc,8);ec=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(hc>>1,mc)|0)+(dc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((hc&cc)<<J)+(dc&cc)|0)<<2)>>2]&2047](ac,ec,mc,8)}else{ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>2,mc)|0)+(kc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&cc)<<J)+(kc&cc)|0)<<2)>>2]&4095](ac,ec,mc);ec=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(hc>>2,mc)|0)+(dc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((hc&cc)<<J)+(dc&cc)|0)<<2)>>2]&4095](ac,ec,mc)}fc=fc+1|0;}while((fc|0)<4)}}else{fc=(c[a+12160>>2]|0)+(ic>>J<<J)|0;ec=(c[a+12164>>2]|0)+(L>>J<<J)|0;ac=c[a+12128>>2]|0;if((ic>>J<<J|0)==0){Kc=(ca(ac,gc-yc|0)|0)/(yc|0)|0}else{Kc=fc-ac|0}ac=c[a+12132>>2]|0;if((L>>J<<J|0)==0){Lc=(ca(ac,gc-yc|0)|0)/(yc|0)|0}else{Lc=ec-ac|0}ac=((Lc&cc)<<J)+(Kc&cc)|0;if((r&1|0)==0){dc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ec>>1,mc)|0)+(fc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,dc,mc,16);dc=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Lc>>1,mc)|0)+(Kc>>1))|0;mf[c[(c[a+12448>>2]|0)+(ac<<2)>>2]&2047](c[(a+12208|0)>>2]|0,dc,mc,16);break}else{dc=(ca(ec>>2,mc)|0)+(fc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+dc|0,mc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(dc+8|0)|0,mc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(mc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(dc+(mc<<3))|0,mc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((ec&cc)<<J)+(fc&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((mc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((dc+8|0)+(mc<<3))|0,mc);dc=(ca(Lc>>2,mc)|0)+(Kc>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+dc|0,mc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(dc+8|0)|0,mc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(mc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(dc+(mc<<3))|0,mc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((mc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((dc+8|0)+(mc<<3))|0,mc);break}}}while(0);Hc=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,mc,16)|0}}while(0);c[(qc+(((L>>J<<3)+(ic>>J)&63)<<2)|0)>>2]=lc;c[uc+(((L>>J<<3)+(ic>>J)&63)<<2)>>2]=Hc;cc=c[(j+32|0)>>2]|0;yc=c[(j+36|0)>>2]|0;gc=(ca((d[nc+((yc>>J<<J)-rc)|0]|0)+(d[nc+((cc>>J<<J)-sc)|0]|0)|0,jc)|0)+Hc|0;if((gc|0)>=(Bc|0)){Cc=Bc;Dc=cc;Ec=yc;Fc=0;Gc=0;break}c[(q|0)>>2]=cc>>J;c[jb+4>>2]=yc>>J;Cc=gc;Dc=cc;Ec=yc;Fc=cc>>J;Gc=yc>>J}}while(0);ic=Dc>>J;L=(Ec>>J)-1|0;lc=(ic|0)>(pc|0)?pc:ic;ic=(vc|0)>(lc|0)?vc:lc;lc=(L|0)>(oc|0)?oc:L;L=(tc|0)>(lc|0)?tc:lc;lc=ic+zc+(L<<11)|0;do{if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){Mc=Cc;Nc=Fc;Oc=Gc}else{do{if((r&4|0)==0){yc=c[a+12416>>2]|0;cc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(yc,L)|0)+ic)|0;dc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,yc,p)|0;if((r&2|0)==0){Pc=dc;break}gc=c[a+12208>>2]|0;ac=(ca(cc,L>>1)|0)+(ic>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+(yc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ac|0,cc,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+(yc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ac|0,cc,p>>1);ac=(Xe[xc&511](a,gc+(yc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,cc,p>>1)|0)+dc|0;Pc=ac+(Xe[xc&511](a,gc+(yc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,cc,p>>1)|0)|0}else{cc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){Pc=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Pc=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Pc=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Pc=536870912;break}yc=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;ac=(r&1)<<1|1;f:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){dc=0;while(1){fc=c[a+12160+(dc<<3)>>2]|0;ec=(c[a+12160+(dc<<3)+4>>2]|0)+(L<<J)|0;hc=((ca(c[a+12128+(dc<<3)>>2]|0,gc-yc|0)|0)/(yc|0)|0)+((dc&1)<<(r&1|4))|0;kc=c[a+12128+(dc<<3)+4>>2]|0;if((L<<J|0)==0){bc=dc>>1;Qc=((ca(kc,gc-yc|0)|0)/(yc|0)|0)+(bc<<(r&1|4))|0;Rc=bc}else{Qc=ec-kc|0;Rc=dc>>1}kc=((Qc&ac)<<J)+(hc&ac)|0;bc=(c[(a+12208|0)>>2]|0)+((ca(Rc,cc<<3)|0)+(dc<<3&8))|0;if((r&1|0)==0){$b=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ec>>1,cc)|0)+(fc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ec&ac)<<J)+(fc&ac)|0)<<2)>>2]&2047](bc,$b,cc,8);$b=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Qc>>1,cc)|0)+(hc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(kc<<2)>>2]&2047](bc,$b,cc,8)}else{$b=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ec>>2,cc)|0)+(fc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ec&ac)<<J)+(fc&ac)|0)<<2)>>2]&4095](bc,$b,cc);$b=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Qc>>2,cc)|0)+(hc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095](bc,$b,cc)}dc=dc+1|0;if((dc|0)>=4){break f}}}if((L<<J|0)==0){dc=0;do{$b=(c[a+12160+(dc<<3)>>2]|0)+(ic<<J)|0;bc=c[a+12160+(dc<<3)+4>>2]|0;kc=$b-(c[a+12128+(dc<<3)>>2]|0)|0;hc=dc>>1;fc=((ca(c[a+12128+(dc<<3)+4>>2]|0,gc-yc|0)|0)/(yc|0)|0)+(hc<<(r&1|4))|0;ec=(c[(a+12208|0)>>2]|0)+((dc<<3&8)+(ca(hc,cc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,cc)|0)+($b>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&ac)<<J)+($b&ac)|0)<<2)>>2]&2047](ec,hc,cc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(fc>>1,cc)|0)+(kc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((fc&ac)<<J)+(kc&ac)|0)<<2)>>2]&2047](ec,hc,cc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>2,cc)|0)+($b>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+($b&ac)|0)<<2)>>2]&4095](ec,hc,cc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(fc>>2,cc)|0)+(kc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((fc&ac)<<J)+(kc&ac)|0)<<2)>>2]&4095](ec,hc,cc)}dc=dc+1|0;}while((dc|0)<4)}else{dc=0;do{hc=(c[a+12160+(dc<<3)>>2]|0)+(ic<<J)|0;ec=(c[a+12160+(dc<<3)+4>>2]|0)+(L<<J)|0;kc=hc-(c[a+12128+(dc<<3)>>2]|0)|0;fc=ec-(c[a+12128+(dc<<3)+4>>2]|0)|0;$b=(c[(a+12208|0)>>2]|0)+((dc<<3&8)+(ca(dc>>1,cc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ec>>1,cc)|0)+(hc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ec&ac)<<J)+(hc&ac)|0)<<2)>>2]&2047]($b,bc,cc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(fc>>1,cc)|0)+(kc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((fc&ac)<<J)+(kc&ac)|0)<<2)>>2]&2047]($b,bc,cc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ec>>2,cc)|0)+(hc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ec&ac)<<J)+(hc&ac)|0)<<2)>>2]&4095]($b,bc,cc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(fc>>2,cc)|0)+(kc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((fc&ac)<<J)+(kc&ac)|0)<<2)>>2]&4095]($b,bc,cc)}dc=dc+1|0;}while((dc|0)<4)}}else{dc=(c[a+12160>>2]|0)+(ic<<J)|0;bc=(c[a+12164>>2]|0)+(L<<J)|0;$b=c[a+12128>>2]|0;if((ic<<J|0)==0){Sc=(ca($b,gc-yc|0)|0)/(yc|0)|0}else{Sc=dc-$b|0}$b=c[a+12132>>2]|0;if((L<<J|0)==0){Tc=(ca($b,gc-yc|0)|0)/(yc|0)|0}else{Tc=bc-$b|0}$b=((Tc&ac)<<J)+(Sc&ac)|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,cc)|0)+(dc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,kc,cc,16);kc=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Tc>>1,cc)|0)+(Sc>>1))|0;mf[c[(c[a+12448>>2]|0)+($b<<2)>>2]&2047](c[(a+12208|0)>>2]|0,kc,cc,16);break}else{kc=(ca(bc>>2,cc)|0)+(dc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+kc|0,cc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kc+8|0)|0,cc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(cc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kc+(cc<<3))|0,cc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ac)<<J)+(dc&ac)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((cc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((kc+8|0)+(cc<<3))|0,cc);kc=(ca(Tc>>2,cc)|0)+(Sc>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+kc|0,cc);ef[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kc+8|0)|0,cc);ef[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(cc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kc+(cc<<3))|0,cc);ef[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((cc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((kc+8|0)+(cc<<3))|0,cc);break}}}while(0);Pc=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,cc,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=Pc;ac=(ca((d[nc+((L<<J)-rc)|0]|0)+(d[nc+((ic<<J)-sc)|0]|0)|0,jc)|0)+Pc|0;if((ac|0)>=(Cc|0)){Mc=Cc;Nc=Fc;Oc=Gc;break}c[(q|0)>>2]=ic;c[jb+4>>2]=L;Mc=ac;Nc=ic;Oc=L}}while(0);L=c[(j+32|0)>>2]>>J;ic=(c[(j+36|0)>>2]>>J)+1|0;lc=(L|0)>(pc|0)?pc:L;L=(vc|0)>(lc|0)?vc:lc;lc=(ic|0)>(oc|0)?oc:ic;ic=(tc|0)>(lc|0)?tc:lc;lc=L+zc+(ic<<11)|0;do{if((c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]|0)==(lc|0)){Uc=Mc;Vc=Nc;Wc=Oc}else{do{if((r&4|0)==0){ac=c[a+12416>>2]|0;yc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(ac,ic)|0)+L)|0;mc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,ac,p)|0;if((r&2|0)==0){Xc=mc;break}gc=c[a+12208>>2]|0;kc=(ca(yc,ic>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&2047](gc+(ac<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+kc|0,yc,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&2047](gc+(ac<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+kc|0,yc,p>>1);kc=(Xe[xc&511](a,gc+(ac<<4)|0,c[a+12288+(k<<4)+4>>2]|0,yc,p>>1)|0)+mc|0;Xc=kc+(Xe[xc&511](a,gc+(ac<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,yc,p>>1)|0)|0}else{yc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Xc=536870912;break}if((L<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Xc=536870912;break}if((c[(a+12272|0)>>2]|0)>(ic|0)){Xc=536870912;break}if((ic<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Xc=536870912;break}ac=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;kc=(r&1)<<1|1;g:do{if((c[a+11740>>2]|0)==1){if((L<<J|0)==0){mc=0;while(1){$b=c[a+12160+(mc<<3)>>2]|0;dc=(c[a+12160+(mc<<3)+4>>2]|0)+(ic<<J)|0;bc=((ca(c[a+12128+(mc<<3)>>2]|0,gc-ac|0)|0)/(ac|0)|0)+((mc&1)<<(r&1|4))|0;fc=c[a+12128+(mc<<3)+4>>2]|0;if((ic<<J|0)==0){hc=mc>>1;Yc=((ca(fc,gc-ac|0)|0)/(ac|0)|0)+(hc<<(r&1|4))|0;Zc=hc}else{Yc=dc-fc|0;Zc=mc>>1}fc=((Yc&kc)<<J)+(bc&kc)|0;hc=(c[(a+12208|0)>>2]|0)+((ca(Zc,yc<<3)|0)+(mc<<3&8))|0;if((r&1|0)==0){ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(dc>>1,yc)|0)+($b>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((dc&kc)<<J)+($b&kc)|0)<<2)>>2]&2047](hc,ec,yc,8);ec=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Yc>>1,yc)|0)+(bc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(fc<<2)>>2]&2047](hc,ec,yc,8)}else{ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(dc>>2,yc)|0)+($b>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((dc&kc)<<J)+($b&kc)|0)<<2)>>2]&4095](hc,ec,yc);ec=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Yc>>2,yc)|0)+(bc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(fc<<2)>>2]&4095](hc,ec,yc)}mc=mc+1|0;if((mc|0)>=4){break g}}}if((ic<<J|0)==0){mc=0;do{ec=(c[a+12160+(mc<<3)>>2]|0)+(L<<J)|0;hc=c[a+12160+(mc<<3)+4>>2]|0;fc=ec-(c[a+12128+(mc<<3)>>2]|0)|0;bc=mc>>1;$b=((ca(c[a+12128+(mc<<3)+4>>2]|0,gc-ac|0)|0)/(ac|0)|0)+(bc<<(r&1|4))|0;dc=(c[(a+12208|0)>>2]|0)+((mc<<3&8)+(ca(bc,yc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>1,yc)|0)+(ec>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((hc&kc)<<J)+(ec&kc)|0)<<2)>>2]&2047](dc,bc,yc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($b>>1,yc)|0)+(fc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(((($b&kc)<<J)+(fc&kc)|0)<<2)>>2]&2047](dc,bc,yc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>2,yc)|0)+(ec>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(ec&kc)|0)<<2)>>2]&4095](dc,bc,yc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($b>>2,yc)|0)+(fc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(((($b&kc)<<J)+(fc&kc)|0)<<2)>>2]&4095](dc,bc,yc)}mc=mc+1|0;}while((mc|0)<4)}else{mc=0;do{bc=(c[a+12160+(mc<<3)>>2]|0)+(L<<J)|0;dc=(c[a+12160+(mc<<3)+4>>2]|0)+(ic<<J)|0;fc=bc-(c[a+12128+(mc<<3)>>2]|0)|0;$b=dc-(c[a+12128+(mc<<3)+4>>2]|0)|0;ec=(c[(a+12208|0)>>2]|0)+((mc<<3&8)+(ca(mc>>1,yc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(dc>>1,yc)|0)+(bc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((dc&kc)<<J)+(bc&kc)|0)<<2)>>2]&2047](ec,hc,yc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($b>>1,yc)|0)+(fc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(((($b&kc)<<J)+(fc&kc)|0)<<2)>>2]&2047](ec,hc,yc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(dc>>2,yc)|0)+(bc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((dc&kc)<<J)+(bc&kc)|0)<<2)>>2]&4095](ec,hc,yc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($b>>2,yc)|0)+(fc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(((($b&kc)<<J)+(fc&kc)|0)<<2)>>2]&4095](ec,hc,yc)}mc=mc+1|0;}while((mc|0)<4)}}else{mc=(c[a+12160>>2]|0)+(L<<J)|0;hc=(c[a+12164>>2]|0)+(ic<<J)|0;ec=c[a+12128>>2]|0;if((L<<J|0)==0){_c=(ca(ec,gc-ac|0)|0)/(ac|0)|0}else{_c=mc-ec|0}ec=c[a+12132>>2]|0;if((ic<<J|0)==0){$c=(ca(ec,gc-ac|0)|0)/(ac|0)|0}else{$c=hc-ec|0}ec=(($c&kc)<<J)+(_c&kc)|0;if((r&1|0)==0){fc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>1,yc)|0)+(mc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,fc,yc,16);fc=(c[a+12352+(l<<4)+32>>2]|0)+((ca($c>>1,yc)|0)+(_c>>1))|0;mf[c[(c[a+12448>>2]|0)+(ec<<2)>>2]&2047](c[(a+12208|0)>>2]|0,fc,yc,16);break}else{fc=(ca(hc>>2,yc)|0)+(mc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+fc|0,yc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(fc+8|0)|0,yc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(yc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(fc+(yc<<3))|0,yc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&kc)<<J)+(mc&kc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((yc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((fc+8|0)+(yc<<3))|0,yc);fc=(ca($c>>2,yc)|0)+(_c>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+fc|0,yc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(fc+8|0)|0,yc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(yc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(fc+(yc<<3))|0,yc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((yc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((fc+8|0)+(yc<<3))|0,yc);break}}}while(0);Xc=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,yc,16)|0}}while(0);c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]=lc;c[uc+(((ic<<3)+L&63)<<2)>>2]=Xc;kc=(ca((d[nc+((ic<<J)-rc)|0]|0)+(d[nc+((L<<J)-sc)|0]|0)|0,jc)|0)+Xc|0;if((kc|0)>=(Mc|0)){Uc=Mc;Vc=Nc;Wc=Oc;break}c[(q|0)>>2]=L;c[jb+4>>2]=ic;Uc=kc;Vc=L;Wc=ic}}while(0);ic=(c[(j+32|0)>>2]>>J)-1|0;L=c[(j+36|0)>>2]>>J;lc=(ic|0)>(pc|0)?pc:ic;ic=(vc|0)>(lc|0)?vc:lc;lc=(L|0)>(oc|0)?oc:L;L=(tc|0)>(lc|0)?tc:lc;lc=ic+zc+(L<<11)|0;do{if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){ad=Uc;bd=Vc;cd=Wc}else{do{if((r&4|0)==0){kc=c[a+12416>>2]|0;ac=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(kc,L)|0)+ic)|0;cc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,kc,p)|0;if((r&2|0)==0){dd=cc;break}gc=c[a+12208>>2]|0;fc=(ca(ac,L>>1)|0)+(ic>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+(kc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+fc|0,ac,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+(kc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+fc|0,ac,p>>1);fc=(Xe[xc&511](a,gc+(kc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ac,p>>1)|0)+cc|0;dd=fc+(Xe[xc&511](a,gc+(kc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ac,p>>1)|0)|0}else{ac=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){dd=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){dd=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){dd=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){dd=536870912;break}kc=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;fc=(r&1)<<1|1;h:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){cc=0;while(1){ec=c[a+12160+(cc<<3)>>2]|0;mc=(c[a+12160+(cc<<3)+4>>2]|0)+(L<<J)|0;hc=((ca(c[a+12128+(cc<<3)>>2]|0,gc-kc|0)|0)/(kc|0)|0)+((cc&1)<<(r&1|4))|0;$b=c[a+12128+(cc<<3)+4>>2]|0;if((L<<J|0)==0){bc=cc>>1;ed=((ca($b,gc-kc|0)|0)/(kc|0)|0)+(bc<<(r&1|4))|0;fd=bc}else{ed=mc-$b|0;fd=cc>>1}$b=((ed&fc)<<J)+(hc&fc)|0;bc=(c[(a+12208|0)>>2]|0)+((ca(fd,ac<<3)|0)+(cc<<3&8))|0;if((r&1|0)==0){dc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mc>>1,ac)|0)+(ec>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((mc&fc)<<J)+(ec&fc)|0)<<2)>>2]&2047](bc,dc,ac,8);dc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ed>>1,ac)|0)+(hc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+($b<<2)>>2]&2047](bc,dc,ac,8)}else{dc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mc>>2,ac)|0)+(ec>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((mc&fc)<<J)+(ec&fc)|0)<<2)>>2]&4095](bc,dc,ac);dc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ed>>2,ac)|0)+(hc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+($b<<2)>>2]&4095](bc,dc,ac)}cc=cc+1|0;if((cc|0)>=4){break h}}}if((L<<J|0)==0){cc=0;do{dc=(c[a+12160+(cc<<3)>>2]|0)+(ic<<J)|0;bc=c[a+12160+(cc<<3)+4>>2]|0;$b=dc-(c[a+12128+(cc<<3)>>2]|0)|0;hc=cc>>1;ec=((ca(c[a+12128+(cc<<3)+4>>2]|0,gc-kc|0)|0)/(kc|0)|0)+(hc<<(r&1|4))|0;mc=(c[(a+12208|0)>>2]|0)+((cc<<3&8)+(ca(hc,ac<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,ac)|0)+(dc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&fc)<<J)+(dc&fc)|0)<<2)>>2]&2047](mc,hc,ac,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ec>>1,ac)|0)+($b>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ec&fc)<<J)+($b&fc)|0)<<2)>>2]&2047](mc,hc,ac,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>2,ac)|0)+(dc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(dc&fc)|0)<<2)>>2]&4095](mc,hc,ac);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ec>>2,ac)|0)+($b>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ec&fc)<<J)+($b&fc)|0)<<2)>>2]&4095](mc,hc,ac)}cc=cc+1|0;}while((cc|0)<4)}else{cc=0;do{hc=(c[a+12160+(cc<<3)>>2]|0)+(ic<<J)|0;mc=(c[a+12160+(cc<<3)+4>>2]|0)+(L<<J)|0;$b=hc-(c[a+12128+(cc<<3)>>2]|0)|0;ec=mc-(c[a+12128+(cc<<3)+4>>2]|0)|0;dc=(c[(a+12208|0)>>2]|0)+((cc<<3&8)+(ca(cc>>1,ac<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mc>>1,ac)|0)+(hc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((mc&fc)<<J)+(hc&fc)|0)<<2)>>2]&2047](dc,bc,ac,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ec>>1,ac)|0)+($b>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ec&fc)<<J)+($b&fc)|0)<<2)>>2]&2047](dc,bc,ac,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mc>>2,ac)|0)+(hc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((mc&fc)<<J)+(hc&fc)|0)<<2)>>2]&4095](dc,bc,ac);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ec>>2,ac)|0)+($b>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ec&fc)<<J)+($b&fc)|0)<<2)>>2]&4095](dc,bc,ac)}cc=cc+1|0;}while((cc|0)<4)}}else{cc=(c[a+12160>>2]|0)+(ic<<J)|0;bc=(c[a+12164>>2]|0)+(L<<J)|0;dc=c[a+12128>>2]|0;if((ic<<J|0)==0){gd=(ca(dc,gc-kc|0)|0)/(kc|0)|0}else{gd=cc-dc|0}dc=c[a+12132>>2]|0;if((L<<J|0)==0){hd=(ca(dc,gc-kc|0)|0)/(kc|0)|0}else{hd=bc-dc|0}dc=((hd&fc)<<J)+(gd&fc)|0;if((r&1|0)==0){$b=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,ac)|0)+(cc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,$b,ac,16);$b=(c[a+12352+(l<<4)+32>>2]|0)+((ca(hd>>1,ac)|0)+(gd>>1))|0;mf[c[(c[a+12448>>2]|0)+(dc<<2)>>2]&2047](c[(a+12208|0)>>2]|0,$b,ac,16);break}else{$b=(ca(bc>>2,ac)|0)+(cc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+$b|0,ac);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($b+8|0)|0,ac);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ac<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($b+(ac<<3))|0,ac);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&fc)<<J)+(cc&fc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ac<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(($b+8|0)+(ac<<3))|0,ac);$b=(ca(hd>>2,ac)|0)+(gd>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+$b|0,ac);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($b+8|0)|0,ac);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ac<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($b+(ac<<3))|0,ac);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ac<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(($b+8|0)+(ac<<3))|0,ac);break}}}while(0);dd=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ac,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=dd;fc=(ca((d[nc+((L<<J)-rc)|0]|0)+(d[nc+((ic<<J)-sc)|0]|0)|0,jc)|0)+dd|0;if((fc|0)>=(Uc|0)){ad=Uc;bd=Vc;cd=Wc;break}c[(q|0)>>2]=ic;c[jb+4>>2]=L;ad=fc;bd=ic;cd=L}}while(0);L=(c[(j+32|0)>>2]>>J)+1|0;ic=c[(j+36|0)>>2]>>J;lc=(L|0)>(pc|0)?pc:L;L=(vc|0)>(lc|0)?vc:lc;lc=(ic|0)>(oc|0)?oc:ic;ic=(tc|0)>(lc|0)?tc:lc;lc=L+zc+(ic<<11)|0;do{if((c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]|0)==(lc|0)){id=ad;jd=bd;kd=cd}else{do{if((r&4|0)==0){fc=c[a+12416>>2]|0;kc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(fc,ic)|0)+L)|0;yc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,fc,p)|0;if((r&2|0)==0){ld=yc;break}gc=c[a+12208>>2]|0;$b=(ca(kc,ic>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&2047](gc+(fc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+$b|0,kc,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&2047](gc+(fc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+$b|0,kc,p>>1);$b=(Xe[xc&511](a,gc+(fc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,kc,p>>1)|0)+yc|0;ld=$b+(Xe[xc&511](a,gc+(fc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,kc,p>>1)|0)|0}else{kc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){ld=536870912;break}if((L<<J|0)>(c[(a+12268|0)>>2]<<J|0)){ld=536870912;break}if((c[(a+12272|0)>>2]|0)>(ic|0)){ld=536870912;break}if((ic<<J|0)>(c[(a+12276|0)>>2]<<J|0)){ld=536870912;break}fc=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;$b=(r&1)<<1|1;i:do{if((c[a+11740>>2]|0)==1){if((L<<J|0)==0){yc=0;while(1){dc=c[a+12160+(yc<<3)>>2]|0;cc=(c[a+12160+(yc<<3)+4>>2]|0)+(ic<<J)|0;bc=((ca(c[a+12128+(yc<<3)>>2]|0,gc-fc|0)|0)/(fc|0)|0)+((yc&1)<<(r&1|4))|0;ec=c[a+12128+(yc<<3)+4>>2]|0;if((ic<<J|0)==0){hc=yc>>1;md=((ca(ec,gc-fc|0)|0)/(fc|0)|0)+(hc<<(r&1|4))|0;nd=hc}else{md=cc-ec|0;nd=yc>>1}ec=((md&$b)<<J)+(bc&$b)|0;hc=(c[(a+12208|0)>>2]|0)+((ca(nd,kc<<3)|0)+(yc<<3&8))|0;if((r&1|0)==0){mc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(cc>>1,kc)|0)+(dc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((cc&$b)<<J)+(dc&$b)|0)<<2)>>2]&2047](hc,mc,kc,8);mc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(md>>1,kc)|0)+(bc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(ec<<2)>>2]&2047](hc,mc,kc,8)}else{mc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(cc>>2,kc)|0)+(dc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((cc&$b)<<J)+(dc&$b)|0)<<2)>>2]&4095](hc,mc,kc);mc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(md>>2,kc)|0)+(bc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ec<<2)>>2]&4095](hc,mc,kc)}yc=yc+1|0;if((yc|0)>=4){break i}}}if((ic<<J|0)==0){yc=0;do{mc=(c[a+12160+(yc<<3)>>2]|0)+(L<<J)|0;hc=c[a+12160+(yc<<3)+4>>2]|0;ec=mc-(c[a+12128+(yc<<3)>>2]|0)|0;bc=yc>>1;dc=((ca(c[a+12128+(yc<<3)+4>>2]|0,gc-fc|0)|0)/(fc|0)|0)+(bc<<(r&1|4))|0;cc=(c[(a+12208|0)>>2]|0)+((yc<<3&8)+(ca(bc,kc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>1,kc)|0)+(mc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((hc&$b)<<J)+(mc&$b)|0)<<2)>>2]&2047](cc,bc,kc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(dc>>1,kc)|0)+(ec>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((dc&$b)<<J)+(ec&$b)|0)<<2)>>2]&2047](cc,bc,kc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>2,kc)|0)+(mc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(mc&$b)|0)<<2)>>2]&4095](cc,bc,kc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(dc>>2,kc)|0)+(ec>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((dc&$b)<<J)+(ec&$b)|0)<<2)>>2]&4095](cc,bc,kc)}yc=yc+1|0;}while((yc|0)<4)}else{yc=0;do{bc=(c[a+12160+(yc<<3)>>2]|0)+(L<<J)|0;cc=(c[a+12160+(yc<<3)+4>>2]|0)+(ic<<J)|0;ec=bc-(c[a+12128+(yc<<3)>>2]|0)|0;dc=cc-(c[a+12128+(yc<<3)+4>>2]|0)|0;mc=(c[(a+12208|0)>>2]|0)+((yc<<3&8)+(ca(yc>>1,kc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(cc>>1,kc)|0)+(bc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((cc&$b)<<J)+(bc&$b)|0)<<2)>>2]&2047](mc,hc,kc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(dc>>1,kc)|0)+(ec>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((dc&$b)<<J)+(ec&$b)|0)<<2)>>2]&2047](mc,hc,kc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(cc>>2,kc)|0)+(bc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((cc&$b)<<J)+(bc&$b)|0)<<2)>>2]&4095](mc,hc,kc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(dc>>2,kc)|0)+(ec>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((dc&$b)<<J)+(ec&$b)|0)<<2)>>2]&4095](mc,hc,kc)}yc=yc+1|0;}while((yc|0)<4)}}else{yc=(c[a+12160>>2]|0)+(L<<J)|0;hc=(c[a+12164>>2]|0)+(ic<<J)|0;mc=c[a+12128>>2]|0;if((L<<J|0)==0){od=(ca(mc,gc-fc|0)|0)/(fc|0)|0}else{od=yc-mc|0}mc=c[a+12132>>2]|0;if((ic<<J|0)==0){pd=(ca(mc,gc-fc|0)|0)/(fc|0)|0}else{pd=hc-mc|0}mc=((pd&$b)<<J)+(od&$b)|0;if((r&1|0)==0){ec=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>1,kc)|0)+(yc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ec,kc,16);ec=(c[a+12352+(l<<4)+32>>2]|0)+((ca(pd>>1,kc)|0)+(od>>1))|0;mf[c[(c[a+12448>>2]|0)+(mc<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ec,kc,16);break}else{ec=(ca(hc>>2,kc)|0)+(yc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ec|0,kc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ec+8|0)|0,kc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(kc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ec+(kc<<3))|0,kc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&$b)<<J)+(yc&$b)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((kc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ec+8|0)+(kc<<3))|0,kc);ec=(ca(pd>>2,kc)|0)+(od>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ec|0,kc);ef[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ec+8|0)|0,kc);ef[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(kc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ec+(kc<<3))|0,kc);ef[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((kc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ec+8|0)+(kc<<3))|0,kc);break}}}while(0);ld=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,kc,16)|0}}while(0);c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]=lc;c[uc+(((ic<<3)+L&63)<<2)>>2]=ld;$b=(ca((d[nc+((ic<<J)-rc)|0]|0)+(d[nc+((L<<J)-sc)|0]|0)|0,jc)|0)+ld|0;if(($b|0)>=(ad|0)){id=ad;jd=bd;kd=cd;break}c[(q|0)>>2]=L;c[jb+4>>2]=ic;id=$b;jd=L;kd=ic}}while(0);ic=(ca(b[m+(Ra<<2)>>1]|0,n)|0)+32768>>16;L=(ca(b[m+(Ra<<2)+2>>1]|0,n)|0)+32768>>16;lc=(ic|0)>(pc|0)?pc:ic;ic=(vc|0)>(lc|0)?vc:lc;lc=(L|0)>(oc|0)?oc:L;L=(tc|0)>(lc|0)?tc:lc;lc=ic+zc+(L<<11)|0;do{if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){qd=id;rd=jd;sd=kd}else{do{if((r&4|0)==0){$b=c[a+12416>>2]|0;fc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca($b,L)|0)+ic)|0;ac=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,$b,p)|0;if((r&2|0)==0){td=ac;break}gc=c[a+12208>>2]|0;ec=(ca(fc,L>>1)|0)+(ic>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+($b<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ec|0,fc,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+($b<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ec|0,fc,p>>1);ec=(Xe[xc&511](a,gc+($b<<4)|0,c[a+12288+(k<<4)+4>>2]|0,fc,p>>1)|0)+ac|0;td=ec+(Xe[xc&511](a,gc+($b<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,fc,p>>1)|0)|0}else{fc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){td=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){td=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){td=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){td=536870912;break}$b=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;ec=(r&1)<<1|1;j:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){ac=0;while(1){mc=c[a+12160+(ac<<3)>>2]|0;yc=(c[a+12160+(ac<<3)+4>>2]|0)+(L<<J)|0;hc=((ca(c[a+12128+(ac<<3)>>2]|0,gc-$b|0)|0)/($b|0)|0)+((ac&1)<<(r&1|4))|0;dc=c[a+12128+(ac<<3)+4>>2]|0;if((L<<J|0)==0){bc=ac>>1;ud=((ca(dc,gc-$b|0)|0)/($b|0)|0)+(bc<<(r&1|4))|0;vd=bc}else{ud=yc-dc|0;vd=ac>>1}dc=((ud&ec)<<J)+(hc&ec)|0;bc=(c[(a+12208|0)>>2]|0)+((ca(vd,fc<<3)|0)+(ac<<3&8))|0;if((r&1|0)==0){cc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(yc>>1,fc)|0)+(mc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((yc&ec)<<J)+(mc&ec)|0)<<2)>>2]&2047](bc,cc,fc,8);cc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ud>>1,fc)|0)+(hc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(dc<<2)>>2]&2047](bc,cc,fc,8)}else{cc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(yc>>2,fc)|0)+(mc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((yc&ec)<<J)+(mc&ec)|0)<<2)>>2]&4095](bc,cc,fc);cc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ud>>2,fc)|0)+(hc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](bc,cc,fc)}ac=ac+1|0;if((ac|0)>=4){break j}}}if((L<<J|0)==0){ac=0;do{cc=(c[a+12160+(ac<<3)>>2]|0)+(ic<<J)|0;bc=c[a+12160+(ac<<3)+4>>2]|0;dc=cc-(c[a+12128+(ac<<3)>>2]|0)|0;hc=ac>>1;mc=((ca(c[a+12128+(ac<<3)+4>>2]|0,gc-$b|0)|0)/($b|0)|0)+(hc<<(r&1|4))|0;yc=(c[(a+12208|0)>>2]|0)+((ac<<3&8)+(ca(hc,fc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,fc)|0)+(cc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&ec)<<J)+(cc&ec)|0)<<2)>>2]&2047](yc,hc,fc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(mc>>1,fc)|0)+(dc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((mc&ec)<<J)+(dc&ec)|0)<<2)>>2]&2047](yc,hc,fc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>2,fc)|0)+(cc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(cc&ec)|0)<<2)>>2]&4095](yc,hc,fc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(mc>>2,fc)|0)+(dc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((mc&ec)<<J)+(dc&ec)|0)<<2)>>2]&4095](yc,hc,fc)}ac=ac+1|0;}while((ac|0)<4)}else{ac=0;do{hc=(c[a+12160+(ac<<3)>>2]|0)+(ic<<J)|0;yc=(c[a+12160+(ac<<3)+4>>2]|0)+(L<<J)|0;dc=hc-(c[a+12128+(ac<<3)>>2]|0)|0;mc=yc-(c[a+12128+(ac<<3)+4>>2]|0)|0;cc=(c[(a+12208|0)>>2]|0)+((ac<<3&8)+(ca(ac>>1,fc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(yc>>1,fc)|0)+(hc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((yc&ec)<<J)+(hc&ec)|0)<<2)>>2]&2047](cc,bc,fc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(mc>>1,fc)|0)+(dc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((mc&ec)<<J)+(dc&ec)|0)<<2)>>2]&2047](cc,bc,fc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(yc>>2,fc)|0)+(hc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((yc&ec)<<J)+(hc&ec)|0)<<2)>>2]&4095](cc,bc,fc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(mc>>2,fc)|0)+(dc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((mc&ec)<<J)+(dc&ec)|0)<<2)>>2]&4095](cc,bc,fc)}ac=ac+1|0;}while((ac|0)<4)}}else{ac=(c[a+12160>>2]|0)+(ic<<J)|0;bc=(c[a+12164>>2]|0)+(L<<J)|0;cc=c[a+12128>>2]|0;if((ic<<J|0)==0){wd=(ca(cc,gc-$b|0)|0)/($b|0)|0}else{wd=ac-cc|0}cc=c[a+12132>>2]|0;if((L<<J|0)==0){xd=(ca(cc,gc-$b|0)|0)/($b|0)|0}else{xd=bc-cc|0}cc=((xd&ec)<<J)+(wd&ec)|0;if((r&1|0)==0){dc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,fc)|0)+(ac>>1))|0;mf[c[(c[a+12444>>2]|0)+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,dc,fc,16);dc=(c[a+12352+(l<<4)+32>>2]|0)+((ca(xd>>1,fc)|0)+(wd>>1))|0;mf[c[(c[a+12448>>2]|0)+(cc<<2)>>2]&2047](c[(a+12208|0)>>2]|0,dc,fc,16);break}else{dc=(ca(bc>>2,fc)|0)+(ac>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+dc|0,fc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(dc+8|0)|0,fc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(dc+(fc<<3))|0,fc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&ec)<<J)+(ac&ec)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((dc+8|0)+(fc<<3))|0,fc);dc=(ca(xd>>2,fc)|0)+(wd>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+dc|0,fc);ef[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(dc+8|0)|0,fc);ef[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(dc+(fc<<3))|0,fc);ef[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((dc+8|0)+(fc<<3))|0,fc);break}}}while(0);td=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,fc,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=td;ec=(ca((d[nc+((L<<J)-rc)|0]|0)+(d[nc+((ic<<J)-sc)|0]|0)|0,jc)|0)+td|0;if((ec|0)>=(id|0)){qd=id;rd=jd;sd=kd;break}c[(q|0)>>2]=ic;c[jb+4>>2]=L;qd=ec;rd=ic;sd=L}}while(0);L=c[(j+12|0)>>2]>>J;ic=c[(j+8|0)>>2]>>J;lc=ic+zc+(L<<11)|0;do{if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){yd=qd;zd=rd;Ad=sd}else{do{if((r&4|0)==0){ec=c[a+12416>>2]|0;$b=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(ec,L)|0)+ic)|0;kc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,ec,p)|0;if((r&2|0)==0){Bd=kc;break}gc=c[a+12208>>2]|0;dc=(ca($b,L>>1)|0)+(ic>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+(ec<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+dc|0,$b,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+(ec<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+dc|0,$b,p>>1);dc=(Xe[xc&511](a,gc+(ec<<4)|0,c[a+12288+(k<<4)+4>>2]|0,$b,p>>1)|0)+kc|0;Bd=dc+(Xe[xc&511](a,gc+(ec<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,$b,p>>1)|0)|0}else{$b=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){Bd=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Bd=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Bd=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Bd=536870912;break}ec=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;dc=(r&1)<<1|1;k:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){kc=0;while(1){cc=c[a+12160+(kc<<3)>>2]|0;ac=(c[a+12160+(kc<<3)+4>>2]|0)+(L<<J)|0;bc=((ca(c[a+12128+(kc<<3)>>2]|0,gc-ec|0)|0)/(ec|0)|0)+((kc&1)<<(r&1|4))|0;mc=c[a+12128+(kc<<3)+4>>2]|0;if((L<<J|0)==0){hc=kc>>1;Cd=((ca(mc,gc-ec|0)|0)/(ec|0)|0)+(hc<<(r&1|4))|0;Dd=hc}else{Cd=ac-mc|0;Dd=kc>>1}mc=((Cd&dc)<<J)+(bc&dc)|0;hc=(c[(a+12208|0)>>2]|0)+((ca(Dd,$b<<3)|0)+(kc<<3&8))|0;if((r&1|0)==0){yc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>1,$b)|0)+(cc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&dc)<<J)+(cc&dc)|0)<<2)>>2]&2047](hc,yc,$b,8);yc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Cd>>1,$b)|0)+(bc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(mc<<2)>>2]&2047](hc,yc,$b,8)}else{yc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>2,$b)|0)+(cc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ac&dc)<<J)+(cc&dc)|0)<<2)>>2]&4095](hc,yc,$b);yc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Cd>>2,$b)|0)+(bc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(mc<<2)>>2]&4095](hc,yc,$b)}kc=kc+1|0;if((kc|0)>=4){break k}}}if((L<<J|0)==0){kc=0;do{yc=(c[a+12160+(kc<<3)>>2]|0)+(ic<<J)|0;hc=c[a+12160+(kc<<3)+4>>2]|0;mc=yc-(c[a+12128+(kc<<3)>>2]|0)|0;bc=kc>>1;cc=((ca(c[a+12128+(kc<<3)+4>>2]|0,gc-ec|0)|0)/(ec|0)|0)+(bc<<(r&1|4))|0;ac=(c[(a+12208|0)>>2]|0)+((kc<<3&8)+(ca(bc,$b<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>1,$b)|0)+(yc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((hc&dc)<<J)+(yc&dc)|0)<<2)>>2]&2047](ac,bc,$b,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(cc>>1,$b)|0)+(mc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((cc&dc)<<J)+(mc&dc)|0)<<2)>>2]&2047](ac,bc,$b,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>2,$b)|0)+(yc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(yc&dc)|0)<<2)>>2]&4095](ac,bc,$b);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(cc>>2,$b)|0)+(mc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((cc&dc)<<J)+(mc&dc)|0)<<2)>>2]&4095](ac,bc,$b)}kc=kc+1|0;}while((kc|0)<4)}else{kc=0;do{bc=(c[a+12160+(kc<<3)>>2]|0)+(ic<<J)|0;ac=(c[a+12160+(kc<<3)+4>>2]|0)+(L<<J)|0;mc=bc-(c[a+12128+(kc<<3)>>2]|0)|0;cc=ac-(c[a+12128+(kc<<3)+4>>2]|0)|0;yc=(c[(a+12208|0)>>2]|0)+((kc<<3&8)+(ca(kc>>1,$b<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>1,$b)|0)+(bc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&dc)<<J)+(bc&dc)|0)<<2)>>2]&2047](yc,hc,$b,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(cc>>1,$b)|0)+(mc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((cc&dc)<<J)+(mc&dc)|0)<<2)>>2]&2047](yc,hc,$b,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>2,$b)|0)+(bc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ac&dc)<<J)+(bc&dc)|0)<<2)>>2]&4095](yc,hc,$b);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(cc>>2,$b)|0)+(mc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((cc&dc)<<J)+(mc&dc)|0)<<2)>>2]&4095](yc,hc,$b)}kc=kc+1|0;}while((kc|0)<4)}}else{kc=(c[a+12160>>2]|0)+(ic<<J)|0;hc=(c[a+12164>>2]|0)+(L<<J)|0;yc=c[a+12128>>2]|0;if((ic<<J|0)==0){Ed=(ca(yc,gc-ec|0)|0)/(ec|0)|0}else{Ed=kc-yc|0}yc=c[a+12132>>2]|0;if((L<<J|0)==0){Fd=(ca(yc,gc-ec|0)|0)/(ec|0)|0}else{Fd=hc-yc|0}yc=((Fd&dc)<<J)+(Ed&dc)|0;if((r&1|0)==0){mc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>1,$b)|0)+(kc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,mc,$b,16);mc=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Fd>>1,$b)|0)+(Ed>>1))|0;mf[c[(c[a+12448>>2]|0)+(yc<<2)>>2]&2047](c[(a+12208|0)>>2]|0,mc,$b,16);break}else{mc=(ca(hc>>2,$b)|0)+(kc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+mc|0,$b);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(mc+8|0)|0,$b);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+($b<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(mc+($b<<3))|0,$b);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&dc)<<J)+(kc&dc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(($b<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((mc+8|0)+($b<<3))|0,$b);mc=(ca(Fd>>2,$b)|0)+(Ed>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+mc|0,$b);ef[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(mc+8|0)|0,$b);ef[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+($b<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(mc+($b<<3))|0,$b);ef[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(($b<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((mc+8|0)+($b<<3))|0,$b);break}}}while(0);Bd=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,$b,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=Bd;dc=c[(j+8|0)>>2]>>J;ec=c[(j+12|0)>>2]>>J;gc=(ca((d[nc+((ec<<J)-rc)|0]|0)+(d[nc+((dc<<J)-sc)|0]|0)|0,jc)|0)+Bd|0;if((gc|0)>=(qd|0)){yd=qd;zd=rd;Ad=sd;break}c[(q|0)>>2]=dc;c[jb+4>>2]=ec;yd=gc;zd=dc;Ad=ec}}while(0);ic=c[(j+20|0)>>2]>>J;L=c[(j+16|0)>>2]>>J;lc=L+zc+(ic<<11)|0;do{if((c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]|0)==(lc|0)){Gd=yd;Hd=zd;Id=Ad}else{do{if((r&4|0)==0){ec=c[a+12416>>2]|0;dc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(ec,ic)|0)+L)|0;fc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,ec,p)|0;if((r&2|0)==0){Jd=fc;break}gc=c[a+12208>>2]|0;mc=(ca(dc,ic>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&2047](gc+(ec<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+mc|0,dc,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ic<<1&2|L&1)<<2)>>2]&2047](gc+(ec<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+mc|0,dc,p>>1);mc=(Xe[xc&511](a,gc+(ec<<4)|0,c[a+12288+(k<<4)+4>>2]|0,dc,p>>1)|0)+fc|0;Jd=mc+(Xe[xc&511](a,gc+(ec<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,dc,p>>1)|0)|0}else{dc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Jd=536870912;break}if((L<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Jd=536870912;break}if((c[(a+12272|0)>>2]|0)>(ic|0)){Jd=536870912;break}if((ic<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Jd=536870912;break}ec=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;mc=(r&1)<<1|1;l:do{if((c[a+11740>>2]|0)==1){if((L<<J|0)==0){fc=0;while(1){yc=c[a+12160+(fc<<3)>>2]|0;kc=(c[a+12160+(fc<<3)+4>>2]|0)+(ic<<J)|0;hc=((ca(c[a+12128+(fc<<3)>>2]|0,gc-ec|0)|0)/(ec|0)|0)+((fc&1)<<(r&1|4))|0;cc=c[a+12128+(fc<<3)+4>>2]|0;if((ic<<J|0)==0){bc=fc>>1;Kd=((ca(cc,gc-ec|0)|0)/(ec|0)|0)+(bc<<(r&1|4))|0;Ld=bc}else{Kd=kc-cc|0;Ld=fc>>1}cc=((Kd&mc)<<J)+(hc&mc)|0;bc=(c[(a+12208|0)>>2]|0)+((ca(Ld,dc<<3)|0)+(fc<<3&8))|0;if((r&1|0)==0){ac=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kc>>1,dc)|0)+(yc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((kc&mc)<<J)+(yc&mc)|0)<<2)>>2]&2047](bc,ac,dc,8);ac=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Kd>>1,dc)|0)+(hc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(cc<<2)>>2]&2047](bc,ac,dc,8)}else{ac=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kc>>2,dc)|0)+(yc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((kc&mc)<<J)+(yc&mc)|0)<<2)>>2]&4095](bc,ac,dc);ac=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Kd>>2,dc)|0)+(hc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(cc<<2)>>2]&4095](bc,ac,dc)}fc=fc+1|0;if((fc|0)>=4){break l}}}if((ic<<J|0)==0){fc=0;do{ac=(c[a+12160+(fc<<3)>>2]|0)+(L<<J)|0;bc=c[a+12160+(fc<<3)+4>>2]|0;cc=ac-(c[a+12128+(fc<<3)>>2]|0)|0;hc=fc>>1;yc=((ca(c[a+12128+(fc<<3)+4>>2]|0,gc-ec|0)|0)/(ec|0)|0)+(hc<<(r&1|4))|0;kc=(c[(a+12208|0)>>2]|0)+((fc<<3&8)+(ca(hc,dc<<3)|0))|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,dc)|0)+(ac>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((bc&mc)<<J)+(ac&mc)|0)<<2)>>2]&2047](kc,hc,dc,8);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(yc>>1,dc)|0)+(cc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((yc&mc)<<J)+(cc&mc)|0)<<2)>>2]&2047](kc,hc,dc,8)}else{hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>2,dc)|0)+(ac>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(ac&mc)|0)<<2)>>2]&4095](kc,hc,dc);hc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(yc>>2,dc)|0)+(cc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((yc&mc)<<J)+(cc&mc)|0)<<2)>>2]&4095](kc,hc,dc)}fc=fc+1|0;}while((fc|0)<4)}else{fc=0;do{hc=(c[a+12160+(fc<<3)>>2]|0)+(L<<J)|0;kc=(c[a+12160+(fc<<3)+4>>2]|0)+(ic<<J)|0;cc=hc-(c[a+12128+(fc<<3)>>2]|0)|0;yc=kc-(c[a+12128+(fc<<3)+4>>2]|0)|0;ac=(c[(a+12208|0)>>2]|0)+((fc<<3&8)+(ca(fc>>1,dc<<3)|0))|0;if((r&1|0)==0){bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kc>>1,dc)|0)+(hc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((kc&mc)<<J)+(hc&mc)|0)<<2)>>2]&2047](ac,bc,dc,8);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(yc>>1,dc)|0)+(cc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((yc&mc)<<J)+(cc&mc)|0)<<2)>>2]&2047](ac,bc,dc,8)}else{bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kc>>2,dc)|0)+(hc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((kc&mc)<<J)+(hc&mc)|0)<<2)>>2]&4095](ac,bc,dc);bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(yc>>2,dc)|0)+(cc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((yc&mc)<<J)+(cc&mc)|0)<<2)>>2]&4095](ac,bc,dc)}fc=fc+1|0;}while((fc|0)<4)}}else{fc=(c[a+12160>>2]|0)+(L<<J)|0;bc=(c[a+12164>>2]|0)+(ic<<J)|0;ac=c[a+12128>>2]|0;if((L<<J|0)==0){Md=(ca(ac,gc-ec|0)|0)/(ec|0)|0}else{Md=fc-ac|0}ac=c[a+12132>>2]|0;if((ic<<J|0)==0){Nd=(ca(ac,gc-ec|0)|0)/(ec|0)|0}else{Nd=bc-ac|0}ac=((Nd&mc)<<J)+(Md&mc)|0;if((r&1|0)==0){cc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(bc>>1,dc)|0)+(fc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,cc,dc,16);cc=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Nd>>1,dc)|0)+(Md>>1))|0;mf[c[(c[a+12448>>2]|0)+(ac<<2)>>2]&2047](c[(a+12208|0)>>2]|0,cc,dc,16);break}else{cc=(ca(bc>>2,dc)|0)+(fc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+cc|0,dc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(cc+8|0)|0,dc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(dc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(cc+(dc<<3))|0,dc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((bc&mc)<<J)+(fc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((dc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((cc+8|0)+(dc<<3))|0,dc);cc=(ca(Nd>>2,dc)|0)+(Md>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+cc|0,dc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(cc+8|0)|0,dc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(dc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(cc+(dc<<3))|0,dc);ef[c[(c[(a+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((dc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((cc+8|0)+(dc<<3))|0,dc);break}}}while(0);Jd=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,dc,16)|0}}while(0);c[(qc+(((ic<<3)+L&63)<<2)|0)>>2]=lc;c[uc+(((ic<<3)+L&63)<<2)>>2]=Jd;mc=c[(j+16|0)>>2]>>J;ec=c[(j+20|0)>>2]>>J;gc=(ca((d[nc+((ec<<J)-rc)|0]|0)+(d[nc+((mc<<J)-sc)|0]|0)|0,jc)|0)+Jd|0;if((gc|0)>=(yd|0)){Gd=yd;Hd=zd;Id=Ad;break}c[(q|0)>>2]=mc;c[jb+4>>2]=ec;Gd=gc;Hd=mc;Id=ec}}while(0);L=c[(j+28|0)>>2]>>J;ic=c[(j+24|0)>>2]>>J;lc=ic+zc+(L<<11)|0;if((c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]|0)==(lc|0)){Od=Gd;Pd=Hd;Qd=Id;break}do{if((r&4|0)==0){ec=c[a+12416>>2]|0;mc=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(ec,L)|0)+ic)|0;$b=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,ec,p)|0;if((r&2|0)==0){Rd=$b;break}gc=c[a+12208>>2]|0;cc=(ca(mc,L>>1)|0)+(ic>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+(ec<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+cc|0,mc,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|ic&1)<<2)>>2]&2047](gc+(ec<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+cc|0,mc,p>>1);cc=(Xe[xc&511](a,gc+(ec<<4)|0,c[a+12288+(k<<4)+4>>2]|0,mc,p>>1)|0)+$b|0;Rd=cc+(Xe[xc&511](a,gc+(ec<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,mc,p>>1)|0)|0}else{mc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(ic|0)){Rd=536870912;break}if((ic<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Rd=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Rd=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Rd=536870912;break}ec=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;cc=(r&1)<<1|1;m:do{if((c[a+11740>>2]|0)==1){if((ic<<J|0)==0){$b=0;while(1){ac=c[a+12160+($b<<3)>>2]|0;fc=(c[a+12160+($b<<3)+4>>2]|0)+(L<<J)|0;bc=((ca(c[a+12128+($b<<3)>>2]|0,gc-ec|0)|0)/(ec|0)|0)+(($b&1)<<(r&1|4))|0;yc=c[a+12128+($b<<3)+4>>2]|0;if((L<<J|0)==0){hc=$b>>1;Sd=((ca(yc,gc-ec|0)|0)/(ec|0)|0)+(hc<<(r&1|4))|0;Td=hc}else{Sd=fc-yc|0;Td=$b>>1}yc=((Sd&cc)<<J)+(bc&cc)|0;hc=(c[(a+12208|0)>>2]|0)+((ca(Td,mc<<3)|0)+($b<<3&8))|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(fc>>1,mc)|0)+(ac>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((fc&cc)<<J)+(ac&cc)|0)<<2)>>2]&2047](hc,kc,mc,8);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Sd>>1,mc)|0)+(bc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(yc<<2)>>2]&2047](hc,kc,mc,8)}else{kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(fc>>2,mc)|0)+(ac>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((fc&cc)<<J)+(ac&cc)|0)<<2)>>2]&4095](hc,kc,mc);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Sd>>2,mc)|0)+(bc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(yc<<2)>>2]&4095](hc,kc,mc)}$b=$b+1|0;if(($b|0)>=4){break m}}}if((L<<J|0)==0){$b=0;do{dc=(c[a+12160+($b<<3)>>2]|0)+(ic<<J)|0;kc=c[a+12160+($b<<3)+4>>2]|0;hc=dc-(c[a+12128+($b<<3)>>2]|0)|0;yc=$b>>1;bc=((ca(c[a+12128+($b<<3)+4>>2]|0,gc-ec|0)|0)/(ec|0)|0)+(yc<<(r&1|4))|0;ac=(c[(a+12208|0)>>2]|0)+(($b<<3&8)+(ca(yc,mc<<3)|0))|0;if((r&1|0)==0){yc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kc>>1,mc)|0)+(dc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((kc&cc)<<J)+(dc&cc)|0)<<2)>>2]&2047](ac,yc,mc,8);yc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(bc>>1,mc)|0)+(hc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&2047](ac,yc,mc,8)}else{yc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kc>>2,mc)|0)+(dc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+(dc&cc)|0)<<2)>>2]&4095](ac,yc,mc);yc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(bc>>2,mc)|0)+(hc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&4095](ac,yc,mc)}$b=$b+1|0;}while(($b|0)<4)}else{$b=0;do{yc=(c[a+12160+($b<<3)>>2]|0)+(ic<<J)|0;ac=(c[a+12160+($b<<3)+4>>2]|0)+(L<<J)|0;hc=yc-(c[a+12128+($b<<3)>>2]|0)|0;bc=ac-(c[a+12128+($b<<3)+4>>2]|0)|0;dc=(c[(a+12208|0)>>2]|0)+(($b<<3&8)+(ca($b>>1,mc<<3)|0))|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>1,mc)|0)+(yc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&cc)<<J)+(yc&cc)|0)<<2)>>2]&2047](dc,kc,mc,8);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(bc>>1,mc)|0)+(hc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&2047](dc,kc,mc,8)}else{kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>2,mc)|0)+(yc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ac&cc)<<J)+(yc&cc)|0)<<2)>>2]&4095](dc,kc,mc);kc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(bc>>2,mc)|0)+(hc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((bc&cc)<<J)+(hc&cc)|0)<<2)>>2]&4095](dc,kc,mc)}$b=$b+1|0;}while(($b|0)<4)}}else{$b=(c[a+12160>>2]|0)+(ic<<J)|0;kc=(c[a+12164>>2]|0)+(L<<J)|0;dc=c[a+12128>>2]|0;if((ic<<J|0)==0){Ud=(ca(dc,gc-ec|0)|0)/(ec|0)|0}else{Ud=$b-dc|0}dc=c[a+12132>>2]|0;if((L<<J|0)==0){Vd=(ca(dc,gc-ec|0)|0)/(ec|0)|0}else{Vd=kc-dc|0}dc=((Vd&cc)<<J)+(Ud&cc)|0;if((r&1|0)==0){hc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kc>>1,mc)|0)+($b>>1))|0;mf[c[(c[a+12444>>2]|0)+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,hc,mc,16);hc=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Vd>>1,mc)|0)+(Ud>>1))|0;mf[c[(c[a+12448>>2]|0)+(dc<<2)>>2]&2047](c[(a+12208|0)>>2]|0,hc,mc,16);break}else{hc=(ca(kc>>2,mc)|0)+($b>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+hc|0,mc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(hc+8|0)|0,mc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(mc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(hc+(mc<<3))|0,mc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((kc&cc)<<J)+($b&cc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((mc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((hc+8|0)+(mc<<3))|0,mc);hc=(ca(Vd>>2,mc)|0)+(Ud>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+hc|0,mc);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(hc+8|0)|0,mc);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(mc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(hc+(mc<<3))|0,mc);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((mc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((hc+8|0)+(mc<<3))|0,mc);break}}}while(0);Rd=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,mc,16)|0}}while(0);c[(qc+(((L<<3)+ic&63)<<2)|0)>>2]=lc;c[uc+(((L<<3)+ic&63)<<2)>>2]=Rd;cc=c[(j+24|0)>>2]>>J;ec=c[(j+28|0)>>2]>>J;gc=(ca((d[nc+((ec<<J)-rc)|0]|0)+(d[nc+((cc<<J)-sc)|0]|0)|0,jc)|0)+Rd|0;if((gc|0)>=(Gd|0)){Od=Gd;Pd=Hd;Qd=Id;break}c[(q|0)>>2]=cc;c[jb+4>>2]=ec;Od=gc;Pd=cc;Qd=ec}else{Ac=1}}if(Ac){Ac=0;if(1){ec=c[(j+12|0)>>2]>>J;cc=c[(j+8|0)>>2]>>J;gc=cc+zc+(ec<<11)|0;do{if((c[(qc+(((ec<<3)+cc&63)<<2)|0)>>2]|0)==(gc|0)){Wd=Bc;Xd=0;Yd=0}else{do{if((r&4|0)==0){hc=c[a+12416>>2]|0;dc=c[a+12420>>2]|0;$b=(c[a+12352+(l<<4)>>2]|0)+((ca(hc,ec)|0)+cc)|0;kc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,$b,hc,p)|0;if((r&2|0)==0){Zd=kc;break}$b=c[a+12208>>2]|0;bc=(ca(dc,ec>>1)|0)+(cc>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ec<<1&2|cc&1)<<2)>>2]&2047]($b+(hc<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+bc|0,dc,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ec<<1&2|cc&1)<<2)>>2]&2047]($b+(hc<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+bc|0,dc,p>>1);bc=(Xe[xc&511](a,$b+(hc<<4)|0,c[a+12288+(k<<4)+4>>2]|0,dc,p>>1)|0)+kc|0;Zd=bc+(Xe[xc&511](a,$b+(hc<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,dc,p>>1)|0)|0}else{dc=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(cc|0)){Zd=536870912;break}if((cc<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Zd=536870912;break}if((c[(a+12272|0)>>2]|0)>(ec|0)){Zd=536870912;break}if((ec<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Zd=536870912;break}hc=e[a+13872>>1]|0;$b=e[a+13874>>1]|0;bc=(r&1)<<1|1;n:do{if((c[a+11740>>2]|0)==1){if((cc<<J|0)==0){kc=0;while(1){yc=c[a+12160+(kc<<3)>>2]|0;ac=(c[a+12160+(kc<<3)+4>>2]|0)+(ec<<J)|0;fc=((ca(c[a+12128+(kc<<3)>>2]|0,$b-hc|0)|0)/(hc|0)|0)+((kc&1)<<(r&1|4))|0;_b=c[a+12128+(kc<<3)+4>>2]|0;if((ec<<J|0)==0){Ka=kc>>1;_d=((ca(_b,$b-hc|0)|0)/(hc|0)|0)+(Ka<<(r&1|4))|0;$d=Ka}else{_d=ac-_b|0;$d=kc>>1}_b=((_d&bc)<<J)+(fc&bc)|0;Ka=(c[(a+12208|0)>>2]|0)+((ca($d,dc<<3)|0)+(kc<<3&8))|0;if((r&1|0)==0){Ja=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>1,dc)|0)+(yc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&bc)<<J)+(yc&bc)|0)<<2)>>2]&2047](Ka,Ja,dc,8);Ja=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_d>>1,dc)|0)+(fc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(_b<<2)>>2]&2047](Ka,Ja,dc,8)}else{Ja=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>2,dc)|0)+(yc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ac&bc)<<J)+(yc&bc)|0)<<2)>>2]&4095](Ka,Ja,dc);Ja=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_d>>2,dc)|0)+(fc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(_b<<2)>>2]&4095](Ka,Ja,dc)}kc=kc+1|0;if((kc|0)>=4){break n}}}if((ec<<J|0)==0){kc=0;do{Ja=(c[a+12160+(kc<<3)>>2]|0)+(cc<<J)|0;Ka=c[a+12160+(kc<<3)+4>>2]|0;_b=Ja-(c[a+12128+(kc<<3)>>2]|0)|0;fc=kc>>1;yc=((ca(c[a+12128+(kc<<3)+4>>2]|0,$b-hc|0)|0)/(hc|0)|0)+(fc<<(r&1|4))|0;ac=(c[(a+12208|0)>>2]|0)+((kc<<3&8)+(ca(fc,dc<<3)|0))|0;if((r&1|0)==0){fc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ka>>1,dc)|0)+(Ja>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Ka&bc)<<J)+(Ja&bc)|0)<<2)>>2]&2047](ac,fc,dc,8);fc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(yc>>1,dc)|0)+(_b>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((yc&bc)<<J)+(_b&bc)|0)<<2)>>2]&2047](ac,fc,dc,8)}else{fc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ka>>2,dc)|0)+(Ja>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(Ja&bc)|0)<<2)>>2]&4095](ac,fc,dc);fc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(yc>>2,dc)|0)+(_b>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((yc&bc)<<J)+(_b&bc)|0)<<2)>>2]&4095](ac,fc,dc)}kc=kc+1|0;}while((kc|0)<4)}else{kc=0;do{fc=(c[a+12160+(kc<<3)>>2]|0)+(cc<<J)|0;ac=(c[a+12160+(kc<<3)+4>>2]|0)+(ec<<J)|0;_b=fc-(c[a+12128+(kc<<3)>>2]|0)|0;yc=ac-(c[a+12128+(kc<<3)+4>>2]|0)|0;Ja=(c[(a+12208|0)>>2]|0)+((kc<<3&8)+(ca(kc>>1,dc<<3)|0))|0;if((r&1|0)==0){Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>1,dc)|0)+(fc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ac&bc)<<J)+(fc&bc)|0)<<2)>>2]&2047](Ja,Ka,dc,8);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(yc>>1,dc)|0)+(_b>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((yc&bc)<<J)+(_b&bc)|0)<<2)>>2]&2047](Ja,Ka,dc,8)}else{Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ac>>2,dc)|0)+(fc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ac&bc)<<J)+(fc&bc)|0)<<2)>>2]&4095](Ja,Ka,dc);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(yc>>2,dc)|0)+(_b>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((yc&bc)<<J)+(_b&bc)|0)<<2)>>2]&4095](Ja,Ka,dc)}kc=kc+1|0;}while((kc|0)<4)}}else{kc=(c[a+12160>>2]|0)+(cc<<J)|0;Ka=(c[a+12164>>2]|0)+(ec<<J)|0;Ja=c[a+12128>>2]|0;if((cc<<J|0)==0){ae=(ca(Ja,$b-hc|0)|0)/(hc|0)|0}else{ae=kc-Ja|0}Ja=c[a+12132>>2]|0;if((ec<<J|0)==0){be=(ca(Ja,$b-hc|0)|0)/(hc|0)|0}else{be=Ka-Ja|0}Ja=((be&bc)<<J)+(ae&bc)|0;if((r&1|0)==0){_b=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ka>>1,dc)|0)+(kc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,_b,dc,16);_b=(c[a+12352+(l<<4)+32>>2]|0)+((ca(be>>1,dc)|0)+(ae>>1))|0;mf[c[(c[a+12448>>2]|0)+(Ja<<2)>>2]&2047](c[(a+12208|0)>>2]|0,_b,dc,16);break}else{_b=(ca(Ka>>2,dc)|0)+(kc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+_b|0,dc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_b+8|0)|0,dc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(dc<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_b+(dc<<3))|0,dc);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&bc)<<J)+(kc&bc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((dc<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((_b+8|0)+(dc<<3))|0,dc);_b=(ca(be>>2,dc)|0)+(ae>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+_b|0,dc);ef[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_b+8|0)|0,dc);ef[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(dc<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_b+(dc<<3))|0,dc);ef[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((dc<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((_b+8|0)+(dc<<3))|0,dc);break}}}while(0);Zd=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,dc,16)|0}}while(0);c[(qc+(((ec<<3)+cc&63)<<2)|0)>>2]=gc;c[uc+(((ec<<3)+cc&63)<<2)>>2]=Zd;mc=c[(j+8|0)>>2]>>J;bc=c[(j+12|0)>>2]>>J;hc=(ca((d[nc+((bc<<J)-rc)|0]|0)+(d[nc+((mc<<J)-sc)|0]|0)|0,jc)|0)+Zd|0;if((hc|0)>=(Bc|0)){Wd=Bc;Xd=0;Yd=0;break}c[(q|0)>>2]=mc;c[jb+4>>2]=bc;Wd=hc;Xd=mc;Yd=bc}}while(0);cc=(ca(b[m+(Ra<<2)>>1]|0,n)|0)+32768>>16;ec=(ca(b[m+(Ra<<2)+2>>1]|0,n)|0)+32768>>16;gc=(cc|0)>(pc|0)?pc:cc;cc=(vc|0)>(gc|0)?vc:gc;gc=(ec|0)>(oc|0)?oc:ec;ec=(tc|0)>(gc|0)?tc:gc;gc=cc+zc+(ec<<11)|0;if((c[(qc+(((ec<<3)+cc&63)<<2)|0)>>2]|0)==(gc|0)){Od=Wd;Pd=Xd;Qd=Yd;break}do{if((r&4|0)==0){ic=c[a+12416>>2]|0;L=c[a+12420>>2]|0;lc=(c[a+12352+(l<<4)>>2]|0)+((ca(ic,ec)|0)+cc)|0;bc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,lc,ic,p)|0;if((r&2|0)==0){ce=bc;break}lc=c[a+12208>>2]|0;mc=(ca(L,ec>>1)|0)+(cc>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ec<<1&2|cc&1)<<2)>>2]&2047](lc+(ic<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+mc|0,L,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((ec<<1&2|cc&1)<<2)>>2]&2047](lc+(ic<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+mc|0,L,p>>1);mc=(Xe[xc&511](a,lc+(ic<<4)|0,c[a+12288+(k<<4)+4>>2]|0,L,p>>1)|0)+bc|0;ce=mc+(Xe[xc&511](a,lc+(ic<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,L,p>>1)|0)|0}else{L=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(cc|0)){ce=536870912;break}if((cc<<J|0)>(c[(a+12268|0)>>2]<<J|0)){ce=536870912;break}if((c[(a+12272|0)>>2]|0)>(ec|0)){ce=536870912;break}if((ec<<J|0)>(c[(a+12276|0)>>2]<<J|0)){ce=536870912;break}ic=e[a+13872>>1]|0;lc=e[a+13874>>1]|0;mc=(r&1)<<1|1;o:do{if((c[a+11740>>2]|0)==1){if((cc<<J|0)==0){bc=0;while(1){hc=c[a+12160+(bc<<3)>>2]|0;$b=(c[a+12160+(bc<<3)+4>>2]|0)+(ec<<J)|0;_b=((ca(c[a+12128+(bc<<3)>>2]|0,lc-ic|0)|0)/(ic|0)|0)+((bc&1)<<(r&1|4))|0;Ja=c[a+12128+(bc<<3)+4>>2]|0;if((ec<<J|0)==0){kc=bc>>1;de=((ca(Ja,lc-ic|0)|0)/(ic|0)|0)+(kc<<(r&1|4))|0;ee=kc}else{de=$b-Ja|0;ee=bc>>1}Ja=((de&mc)<<J)+(_b&mc)|0;kc=(c[(a+12208|0)>>2]|0)+((ca(ee,L<<3)|0)+(bc<<3&8))|0;if((r&1|0)==0){Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($b>>1,L)|0)+(hc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+(((($b&mc)<<J)+(hc&mc)|0)<<2)>>2]&2047](kc,Ka,L,8);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(de>>1,L)|0)+(_b>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Ja<<2)>>2]&2047](kc,Ka,L,8)}else{Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($b>>2,L)|0)+(hc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+(((($b&mc)<<J)+(hc&mc)|0)<<2)>>2]&4095](kc,Ka,L);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(de>>2,L)|0)+(_b>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Ja<<2)>>2]&4095](kc,Ka,L)}bc=bc+1|0;if((bc|0)>=4){break o}}}if((ec<<J|0)==0){bc=0;do{dc=(c[a+12160+(bc<<3)>>2]|0)+(cc<<J)|0;Ka=c[a+12160+(bc<<3)+4>>2]|0;kc=dc-(c[a+12128+(bc<<3)>>2]|0)|0;Ja=bc>>1;_b=((ca(c[a+12128+(bc<<3)+4>>2]|0,lc-ic|0)|0)/(ic|0)|0)+(Ja<<(r&1|4))|0;hc=(c[(a+12208|0)>>2]|0)+((bc<<3&8)+(ca(Ja,L<<3)|0))|0;if((r&1|0)==0){Ja=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ka>>1,L)|0)+(dc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Ka&mc)<<J)+(dc&mc)|0)<<2)>>2]&2047](hc,Ja,L,8);Ja=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_b>>1,L)|0)+(kc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((_b&mc)<<J)+(kc&mc)|0)<<2)>>2]&2047](hc,Ja,L,8)}else{Ja=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ka>>2,L)|0)+(dc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(dc&mc)|0)<<2)>>2]&4095](hc,Ja,L);Ja=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_b>>2,L)|0)+(kc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((_b&mc)<<J)+(kc&mc)|0)<<2)>>2]&4095](hc,Ja,L)}bc=bc+1|0;}while((bc|0)<4)}else{bc=0;do{Ja=(c[a+12160+(bc<<3)>>2]|0)+(cc<<J)|0;hc=(c[a+12160+(bc<<3)+4>>2]|0)+(ec<<J)|0;kc=Ja-(c[a+12128+(bc<<3)>>2]|0)|0;_b=hc-(c[a+12128+(bc<<3)+4>>2]|0)|0;dc=(c[(a+12208|0)>>2]|0)+((bc<<3&8)+(ca(bc>>1,L<<3)|0))|0;if((r&1|0)==0){Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>1,L)|0)+(Ja>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((hc&mc)<<J)+(Ja&mc)|0)<<2)>>2]&2047](dc,Ka,L,8);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_b>>1,L)|0)+(kc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((_b&mc)<<J)+(kc&mc)|0)<<2)>>2]&2047](dc,Ka,L,8)}else{Ka=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hc>>2,L)|0)+(Ja>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hc&mc)<<J)+(Ja&mc)|0)<<2)>>2]&4095](dc,Ka,L);Ka=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_b>>2,L)|0)+(kc>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((_b&mc)<<J)+(kc&mc)|0)<<2)>>2]&4095](dc,Ka,L)}bc=bc+1|0;}while((bc|0)<4)}}else{bc=(c[a+12160>>2]|0)+(cc<<J)|0;Ka=(c[a+12164>>2]|0)+(ec<<J)|0;dc=c[a+12128>>2]|0;if((cc<<J|0)==0){fe=(ca(dc,lc-ic|0)|0)/(ic|0)|0}else{fe=bc-dc|0}dc=c[a+12132>>2]|0;if((ec<<J|0)==0){ge=(ca(dc,lc-ic|0)|0)/(ic|0)|0}else{ge=Ka-dc|0}dc=((ge&mc)<<J)+(fe&mc)|0;if((r&1|0)==0){kc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ka>>1,L)|0)+(bc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,kc,L,16);kc=(c[a+12352+(l<<4)+32>>2]|0)+((ca(ge>>1,L)|0)+(fe>>1))|0;mf[c[(c[a+12448>>2]|0)+(dc<<2)>>2]&2047](c[(a+12208|0)>>2]|0,kc,L,16);break}else{kc=(ca(Ka>>2,L)|0)+(bc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+kc|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kc+8|0)|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kc+(L<<3))|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ka&mc)<<J)+(bc&mc)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((kc+8|0)+(L<<3))|0,L);kc=(ca(ge>>2,L)|0)+(fe>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+kc|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kc+8|0)|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kc+(L<<3))|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(dc<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((kc+8|0)+(L<<3))|0,L);break}}}while(0);ce=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,L,16)|0}}while(0);c[(qc+(((ec<<3)+cc&63)<<2)|0)>>2]=gc;c[uc+(((ec<<3)+cc&63)<<2)>>2]=ce;mc=(ca((d[nc+((ec<<J)-rc)|0]|0)+(d[nc+((cc<<J)-sc)|0]|0)|0,jc)|0)+ce|0;if((mc|0)>=(Wd|0)){Od=Wd;Pd=Xd;Qd=Yd;break}c[(q|0)>>2]=cc;c[jb+4>>2]=ec;Od=mc;Pd=cc;Qd=ec}else{Ac=1}}}while(0);do{if((Od|0)>(ca(p<<2,p)|0)){if((c[(a+12256|0)>>2]|0)==0){Yd=(ca(b[m+((Ra+1|0)<<2)>>1]|0,n)|0)+32768>>16;Xd=(ca(b[m+((Ra+1|0)<<2)+2>>1]|0,n)|0)+32768>>16;Wd=(Yd|0)>(pc|0)?pc:Yd;Yd=(vc|0)>(Wd|0)?vc:Wd;Wd=(Xd|0)>(oc|0)?oc:Xd;Xd=(tc|0)>(Wd|0)?tc:Wd;Wd=Yd+zc+(Xd<<11)|0;do{if((c[(qc+(((Xd<<3)+Yd&63)<<2)|0)>>2]|0)==(Wd|0)){he=Od;ie=Pd;je=Qd}else{do{if((r&4|0)==0){ce=c[a+12416>>2]|0;fe=c[a+12420>>2]|0;ge=(c[a+12352+(l<<4)>>2]|0)+((ca(ce,Xd)|0)+Yd)|0;de=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,ge,ce,p)|0;if((r&2|0)==0){ke=de;break}ge=c[a+12208>>2]|0;ee=(ca(fe,Xd>>1)|0)+(Yd>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Xd<<1&2|Yd&1)<<2)>>2]&2047](ge+(ce<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ee|0,fe,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Xd<<1&2|Yd&1)<<2)>>2]&2047](ge+(ce<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ee|0,fe,p>>1);ee=(Xe[xc&511](a,ge+(ce<<4)|0,c[a+12288+(k<<4)+4>>2]|0,fe,p>>1)|0)+de|0;ke=ee+(Xe[xc&511](a,ge+(ce<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,fe,p>>1)|0)|0}else{fe=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Yd|0)){ke=536870912;break}if((Yd<<J|0)>(c[(a+12268|0)>>2]<<J|0)){ke=536870912;break}if((c[(a+12272|0)>>2]|0)>(Xd|0)){ke=536870912;break}if((Xd<<J|0)>(c[(a+12276|0)>>2]<<J|0)){ke=536870912;break}ce=e[a+13872>>1]|0;ge=e[a+13874>>1]|0;ee=(r&1)<<1|1;p:do{if((c[a+11740>>2]|0)==1){if((Yd<<J|0)==0){de=0;while(1){Bc=c[a+12160+(de<<3)>>2]|0;Zd=(c[a+12160+(de<<3)+4>>2]|0)+(Xd<<J)|0;j=((ca(c[a+12128+(de<<3)>>2]|0,ge-ce|0)|0)/(ce|0)|0)+((de&1)<<(r&1|4))|0;ae=c[a+12128+(de<<3)+4>>2]|0;if((Xd<<J|0)==0){be=de>>1;le=((ca(ae,ge-ce|0)|0)/(ce|0)|0)+(be<<(r&1|4))|0;me=be}else{le=Zd-ae|0;me=de>>1}ae=((le&ee)<<J)+(j&ee)|0;be=(c[(a+12208|0)>>2]|0)+((ca(me,fe<<3)|0)+(de<<3&8))|0;if((r&1|0)==0){_d=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Zd>>1,fe)|0)+(Bc>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Zd&ee)<<J)+(Bc&ee)|0)<<2)>>2]&2047](be,_d,fe,8);_d=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(le>>1,fe)|0)+(j>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(ae<<2)>>2]&2047](be,_d,fe,8)}else{_d=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Zd>>2,fe)|0)+(Bc>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Zd&ee)<<J)+(Bc&ee)|0)<<2)>>2]&4095](be,_d,fe);_d=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(le>>2,fe)|0)+(j>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ae<<2)>>2]&4095](be,_d,fe)}de=de+1|0;if((de|0)>=4){break p}}}if((Xd<<J|0)==0){de=0;do{_d=(c[a+12160+(de<<3)>>2]|0)+(Yd<<J)|0;be=c[a+12160+(de<<3)+4>>2]|0;ae=_d-(c[a+12128+(de<<3)>>2]|0)|0;j=de>>1;Bc=((ca(c[a+12128+(de<<3)+4>>2]|0,ge-ce|0)|0)/(ce|0)|0)+(j<<(r&1|4))|0;Zd=(c[(a+12208|0)>>2]|0)+((de<<3&8)+(ca(j,fe<<3)|0))|0;if((r&1|0)==0){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(be>>1,fe)|0)+(_d>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((be&ee)<<J)+(_d&ee)|0)<<2)>>2]&2047](Zd,j,fe,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Bc>>1,fe)|0)+(ae>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((Bc&ee)<<J)+(ae&ee)|0)<<2)>>2]&2047](Zd,j,fe,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(be>>2,fe)|0)+(_d>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(_d&ee)|0)<<2)>>2]&4095](Zd,j,fe);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Bc>>2,fe)|0)+(ae>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((Bc&ee)<<J)+(ae&ee)|0)<<2)>>2]&4095](Zd,j,fe)}de=de+1|0;}while((de|0)<4)}else{de=0;do{j=(c[a+12160+(de<<3)>>2]|0)+(Yd<<J)|0;Zd=(c[a+12160+(de<<3)+4>>2]|0)+(Xd<<J)|0;ae=j-(c[a+12128+(de<<3)>>2]|0)|0;Bc=Zd-(c[a+12128+(de<<3)+4>>2]|0)|0;_d=(c[(a+12208|0)>>2]|0)+((de<<3&8)+(ca(de>>1,fe<<3)|0))|0;if((r&1|0)==0){be=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Zd>>1,fe)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Zd&ee)<<J)+(j&ee)|0)<<2)>>2]&2047](_d,be,fe,8);be=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Bc>>1,fe)|0)+(ae>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((Bc&ee)<<J)+(ae&ee)|0)<<2)>>2]&2047](_d,be,fe,8)}else{be=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Zd>>2,fe)|0)+(j>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Zd&ee)<<J)+(j&ee)|0)<<2)>>2]&4095](_d,be,fe);be=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Bc>>2,fe)|0)+(ae>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((Bc&ee)<<J)+(ae&ee)|0)<<2)>>2]&4095](_d,be,fe)}de=de+1|0;}while((de|0)<4)}}else{de=(c[a+12160>>2]|0)+(Yd<<J)|0;be=(c[a+12164>>2]|0)+(Xd<<J)|0;_d=c[a+12128>>2]|0;if((Yd<<J|0)==0){ne=(ca(_d,ge-ce|0)|0)/(ce|0)|0}else{ne=de-_d|0}_d=c[a+12132>>2]|0;if((Xd<<J|0)==0){oe=(ca(_d,ge-ce|0)|0)/(ce|0)|0}else{oe=be-_d|0}_d=((oe&ee)<<J)+(ne&ee)|0;if((r&1|0)==0){ae=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(be>>1,fe)|0)+(de>>1))|0;mf[c[(c[a+12444>>2]|0)+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ae,fe,16);ae=(c[a+12352+(l<<4)+32>>2]|0)+((ca(oe>>1,fe)|0)+(ne>>1))|0;mf[c[(c[a+12448>>2]|0)+(_d<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ae,fe,16);break}else{ae=(ca(be>>2,fe)|0)+(de>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ae|0,fe);ef[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ae+8|0)|0,fe);ef[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fe<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ae+(fe<<3))|0,fe);ef[c[(c[(a+12452|0)>>2]|0)+64+((((be&ee)<<J)+(de&ee)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fe<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ae+8|0)+(fe<<3))|0,fe);ae=(ca(oe>>2,fe)|0)+(ne>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(_d<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ae|0,fe);ef[c[(c[(a+12456|0)>>2]|0)+64+(_d<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ae+8|0)|0,fe);ef[c[(c[(a+12456|0)>>2]|0)+64+(_d<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fe<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ae+(fe<<3))|0,fe);ef[c[(c[(a+12456|0)>>2]|0)+64+(_d<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fe<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ae+8|0)+(fe<<3))|0,fe);break}}}while(0);ke=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,fe,16)|0}}while(0);c[(qc+(((Xd<<3)+Yd&63)<<2)|0)>>2]=Wd;c[uc+(((Xd<<3)+Yd&63)<<2)>>2]=ke;L=(ca((d[nc+((Xd<<J)-rc)|0]|0)+(d[nc+((Yd<<J)-sc)|0]|0)|0,jc)|0)+ke|0;if((L|0)>=(Od|0)){he=Od;ie=Pd;je=Qd;break}c[(q|0)>>2]=Yd;c[jb+4>>2]=Xd;he=L;ie=Yd;je=Xd}}while(0);if(((c[(a+12480|0)>>2]|0)+1|0)>=(c[a+812>>2]|0)){pe=he;qe=ie;re=je;break}Xd=(ca(b[m+((Ra+s|0)<<2)>>1]|0,n)|0)+32768>>16;Yd=(ca(b[m+((Ra+s|0)<<2)+2>>1]|0,n)|0)+32768>>16;Wd=(Xd|0)>(pc|0)?pc:Xd;Xd=(vc|0)>(Wd|0)?vc:Wd;Wd=(Yd|0)>(oc|0)?oc:Yd;Yd=(tc|0)>(Wd|0)?tc:Wd;Wd=Xd+zc+(Yd<<11)|0;if((c[(qc+(((Yd<<3)+Xd&63)<<2)|0)>>2]|0)==(Wd|0)){pe=he;qe=ie;re=je;break}do{if((r&4|0)==0){Ac=c[a+12416>>2]|0;ec=c[a+12420>>2]|0;cc=(c[a+12352+(l<<4)>>2]|0)+((ca(Ac,Yd)|0)+Xd)|0;gc=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,cc,Ac,p)|0;if((r&2|0)==0){se=gc;break}cc=c[a+12208>>2]|0;L=(ca(ec,Yd>>1)|0)+(Xd>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Yd<<1&2|Xd&1)<<2)>>2]&2047](cc+(Ac<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+L|0,ec,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Yd<<1&2|Xd&1)<<2)>>2]&2047](cc+(Ac<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+L|0,ec,p>>1);L=(Xe[xc&511](a,cc+(Ac<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ec,p>>1)|0)+gc|0;se=L+(Xe[xc&511](a,cc+(Ac<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ec,p>>1)|0)|0}else{ec=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Xd|0)){se=536870912;break}if((Xd<<J|0)>(c[(a+12268|0)>>2]<<J|0)){se=536870912;break}if((c[(a+12272|0)>>2]|0)>(Yd|0)){se=536870912;break}if((Yd<<J|0)>(c[(a+12276|0)>>2]<<J|0)){se=536870912;break}Ac=e[a+13872>>1]|0;cc=e[a+13874>>1]|0;L=(r&1)<<1|1;q:do{if((c[a+11740>>2]|0)==1){if((Xd<<J|0)==0){gc=0;while(1){ee=c[a+12160+(gc<<3)>>2]|0;ce=(c[a+12160+(gc<<3)+4>>2]|0)+(Yd<<J)|0;ge=((ca(c[a+12128+(gc<<3)>>2]|0,cc-Ac|0)|0)/(Ac|0)|0)+((gc&1)<<(r&1|4))|0;ae=c[a+12128+(gc<<3)+4>>2]|0;if((Yd<<J|0)==0){_d=gc>>1;te=((ca(ae,cc-Ac|0)|0)/(Ac|0)|0)+(_d<<(r&1|4))|0;ue=_d}else{te=ce-ae|0;ue=gc>>1}ae=((te&L)<<J)+(ge&L)|0;_d=(c[(a+12208|0)>>2]|0)+((ca(ue,ec<<3)|0)+(gc<<3&8))|0;if((r&1|0)==0){de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ce>>1,ec)|0)+(ee>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ce&L)<<J)+(ee&L)|0)<<2)>>2]&2047](_d,de,ec,8);de=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(te>>1,ec)|0)+(ge>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(ae<<2)>>2]&2047](_d,de,ec,8)}else{de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ce>>2,ec)|0)+(ee>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ce&L)<<J)+(ee&L)|0)<<2)>>2]&4095](_d,de,ec);de=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(te>>2,ec)|0)+(ge>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ae<<2)>>2]&4095](_d,de,ec)}gc=gc+1|0;if((gc|0)>=4){break q}}}if((Yd<<J|0)==0){gc=0;do{fe=(c[a+12160+(gc<<3)>>2]|0)+(Xd<<J)|0;de=c[a+12160+(gc<<3)+4>>2]|0;_d=fe-(c[a+12128+(gc<<3)>>2]|0)|0;ae=gc>>1;ge=((ca(c[a+12128+(gc<<3)+4>>2]|0,cc-Ac|0)|0)/(Ac|0)|0)+(ae<<(r&1|4))|0;ee=(c[(a+12208|0)>>2]|0)+((gc<<3&8)+(ca(ae,ec<<3)|0))|0;if((r&1|0)==0){ae=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(de>>1,ec)|0)+(fe>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((de&L)<<J)+(fe&L)|0)<<2)>>2]&2047](ee,ae,ec,8);ae=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ge>>1,ec)|0)+(_d>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ge&L)<<J)+(_d&L)|0)<<2)>>2]&2047](ee,ae,ec,8)}else{ae=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(de>>2,ec)|0)+(fe>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(fe&L)|0)<<2)>>2]&4095](ee,ae,ec);ae=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ge>>2,ec)|0)+(_d>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ge&L)<<J)+(_d&L)|0)<<2)>>2]&4095](ee,ae,ec)}gc=gc+1|0;}while((gc|0)<4)}else{gc=0;do{ae=(c[a+12160+(gc<<3)>>2]|0)+(Xd<<J)|0;ee=(c[a+12160+(gc<<3)+4>>2]|0)+(Yd<<J)|0;_d=ae-(c[a+12128+(gc<<3)>>2]|0)|0;ge=ee-(c[a+12128+(gc<<3)+4>>2]|0)|0;fe=(c[(a+12208|0)>>2]|0)+((gc<<3&8)+(ca(gc>>1,ec<<3)|0))|0;if((r&1|0)==0){de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ee>>1,ec)|0)+(ae>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ee&L)<<J)+(ae&L)|0)<<2)>>2]&2047](fe,de,ec,8);de=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ge>>1,ec)|0)+(_d>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ge&L)<<J)+(_d&L)|0)<<2)>>2]&2047](fe,de,ec,8)}else{de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ee>>2,ec)|0)+(ae>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ee&L)<<J)+(ae&L)|0)<<2)>>2]&4095](fe,de,ec);de=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ge>>2,ec)|0)+(_d>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ge&L)<<J)+(_d&L)|0)<<2)>>2]&4095](fe,de,ec)}gc=gc+1|0;}while((gc|0)<4)}}else{gc=(c[a+12160>>2]|0)+(Xd<<J)|0;de=(c[a+12164>>2]|0)+(Yd<<J)|0;fe=c[a+12128>>2]|0;if((Xd<<J|0)==0){ve=(ca(fe,cc-Ac|0)|0)/(Ac|0)|0}else{ve=gc-fe|0}fe=c[a+12132>>2]|0;if((Yd<<J|0)==0){we=(ca(fe,cc-Ac|0)|0)/(Ac|0)|0}else{we=de-fe|0}fe=((we&L)<<J)+(ve&L)|0;if((r&1|0)==0){_d=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(de>>1,ec)|0)+(gc>>1))|0;mf[c[(c[a+12444>>2]|0)+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,_d,ec,16);_d=(c[a+12352+(l<<4)+32>>2]|0)+((ca(we>>1,ec)|0)+(ve>>1))|0;mf[c[(c[a+12448>>2]|0)+(fe<<2)>>2]&2047](c[(a+12208|0)>>2]|0,_d,ec,16);break}else{_d=(ca(de>>2,ec)|0)+(gc>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+_d|0,ec);ef[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_d+8|0)|0,ec);ef[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ec<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_d+(ec<<3))|0,ec);ef[c[(c[(a+12452|0)>>2]|0)+64+((((de&L)<<J)+(gc&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ec<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((_d+8|0)+(ec<<3))|0,ec);_d=(ca(we>>2,ec)|0)+(ve>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+_d|0,ec);ef[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_d+8|0)|0,ec);ef[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ec<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_d+(ec<<3))|0,ec);ef[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ec<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((_d+8|0)+(ec<<3))|0,ec);break}}}while(0);se=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ec,16)|0}}while(0);c[(qc+(((Yd<<3)+Xd&63)<<2)|0)>>2]=Wd;c[uc+(((Yd<<3)+Xd&63)<<2)>>2]=se;L=(ca((d[nc+((Yd<<J)-rc)|0]|0)+(d[nc+((Xd<<J)-sc)|0]|0)|0,jc)|0)+se|0;if((L|0)>=(he|0)){pe=he;qe=ie;re=je;break}c[(q|0)>>2]=Xd;c[jb+4>>2]=Yd;pe=L;qe=Xd;re=Yd;break}else{L=(ca(b[m+((Ra-1|0)<<2)>>1]|0,n)|0)+32768>>16;Ac=(ca(b[m+((Ra-1|0)<<2)+2>>1]|0,n)|0)+32768>>16;cc=(L|0)>(pc|0)?pc:L;L=(vc|0)>(cc|0)?vc:cc;cc=(Ac|0)>(oc|0)?oc:Ac;Ac=(tc|0)>(cc|0)?tc:cc;cc=L+zc+(Ac<<11)|0;do{if((c[(qc+(((Ac<<3)+L&63)<<2)|0)>>2]|0)==(cc|0)){xe=Od;ye=Pd;ze=Qd}else{do{if((r&4|0)==0){_d=c[a+12416>>2]|0;fe=c[a+12420>>2]|0;gc=(c[a+12352+(l<<4)>>2]|0)+((ca(_d,Ac)|0)+L)|0;de=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,gc,_d,p)|0;if((r&2|0)==0){Ae=de;break}gc=c[a+12208>>2]|0;ge=(ca(fe,Ac>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Ac<<1&2|L&1)<<2)>>2]&2047](gc+(_d<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ge|0,fe,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((Ac<<1&2|L&1)<<2)>>2]&2047](gc+(_d<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ge|0,fe,p>>1);ge=(Xe[xc&511](a,gc+(_d<<4)|0,c[a+12288+(k<<4)+4>>2]|0,fe,p>>1)|0)+de|0;Ae=ge+(Xe[xc&511](a,gc+(_d<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,fe,p>>1)|0)|0}else{fe=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Ae=536870912;break}if((L<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Ae=536870912;break}if((c[(a+12272|0)>>2]|0)>(Ac|0)){Ae=536870912;break}if((Ac<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Ae=536870912;break}_d=e[a+13872>>1]|0;gc=e[a+13874>>1]|0;ge=(r&1)<<1|1;r:do{if((c[a+11740>>2]|0)==1){if((L<<J|0)==0){de=0;while(1){ae=c[a+12160+(de<<3)>>2]|0;ee=(c[a+12160+(de<<3)+4>>2]|0)+(Ac<<J)|0;ce=((ca(c[a+12128+(de<<3)>>2]|0,gc-_d|0)|0)/(_d|0)|0)+((de&1)<<(r&1|4))|0;be=c[a+12128+(de<<3)+4>>2]|0;if((Ac<<J|0)==0){Bc=de>>1;Be=((ca(be,gc-_d|0)|0)/(_d|0)|0)+(Bc<<(r&1|4))|0;Ce=Bc}else{Be=ee-be|0;Ce=de>>1}be=((Be&ge)<<J)+(ce&ge)|0;Bc=(c[(a+12208|0)>>2]|0)+((ca(Ce,fe<<3)|0)+(de<<3&8))|0;if((r&1|0)==0){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ee>>1,fe)|0)+(ae>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ee&ge)<<J)+(ae&ge)|0)<<2)>>2]&2047](Bc,j,fe,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Be>>1,fe)|0)+(ce>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(be<<2)>>2]&2047](Bc,j,fe,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ee>>2,fe)|0)+(ae>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ee&ge)<<J)+(ae&ge)|0)<<2)>>2]&4095](Bc,j,fe);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Be>>2,fe)|0)+(ce>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(be<<2)>>2]&4095](Bc,j,fe)}de=de+1|0;if((de|0)>=4){break r}}}if((Ac<<J|0)==0){de=0;do{j=(c[a+12160+(de<<3)>>2]|0)+(L<<J)|0;Bc=c[a+12160+(de<<3)+4>>2]|0;be=j-(c[a+12128+(de<<3)>>2]|0)|0;ce=de>>1;ae=((ca(c[a+12128+(de<<3)+4>>2]|0,gc-_d|0)|0)/(_d|0)|0)+(ce<<(r&1|4))|0;ee=(c[(a+12208|0)>>2]|0)+((de<<3&8)+(ca(ce,fe<<3)|0))|0;if((r&1|0)==0){ce=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Bc>>1,fe)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Bc&ge)<<J)+(j&ge)|0)<<2)>>2]&2047](ee,ce,fe,8);ce=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ae>>1,fe)|0)+(be>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ae&ge)<<J)+(be&ge)|0)<<2)>>2]&2047](ee,ce,fe,8)}else{ce=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Bc>>2,fe)|0)+(j>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(j&ge)|0)<<2)>>2]&4095](ee,ce,fe);ce=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ae>>2,fe)|0)+(be>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ae&ge)<<J)+(be&ge)|0)<<2)>>2]&4095](ee,ce,fe)}de=de+1|0;}while((de|0)<4)}else{de=0;do{ce=(c[a+12160+(de<<3)>>2]|0)+(L<<J)|0;ee=(c[a+12160+(de<<3)+4>>2]|0)+(Ac<<J)|0;be=ce-(c[a+12128+(de<<3)>>2]|0)|0;ae=ee-(c[a+12128+(de<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((de<<3&8)+(ca(de>>1,fe<<3)|0))|0;if((r&1|0)==0){Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ee>>1,fe)|0)+(ce>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ee&ge)<<J)+(ce&ge)|0)<<2)>>2]&2047](j,Bc,fe,8);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ae>>1,fe)|0)+(be>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ae&ge)<<J)+(be&ge)|0)<<2)>>2]&2047](j,Bc,fe,8)}else{Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ee>>2,fe)|0)+(ce>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ee&ge)<<J)+(ce&ge)|0)<<2)>>2]&4095](j,Bc,fe);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ae>>2,fe)|0)+(be>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ae&ge)<<J)+(be&ge)|0)<<2)>>2]&4095](j,Bc,fe)}de=de+1|0;}while((de|0)<4)}}else{de=(c[a+12160>>2]|0)+(L<<J)|0;Bc=(c[a+12164>>2]|0)+(Ac<<J)|0;j=c[a+12128>>2]|0;if((L<<J|0)==0){De=(ca(j,gc-_d|0)|0)/(_d|0)|0}else{De=de-j|0}j=c[a+12132>>2]|0;if((Ac<<J|0)==0){Ee=(ca(j,gc-_d|0)|0)/(_d|0)|0}else{Ee=Bc-j|0}j=((Ee&ge)<<J)+(De&ge)|0;if((r&1|0)==0){be=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Bc>>1,fe)|0)+(de>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,be,fe,16);be=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Ee>>1,fe)|0)+(De>>1))|0;mf[c[(c[a+12448>>2]|0)+(j<<2)>>2]&2047](c[(a+12208|0)>>2]|0,be,fe,16);break}else{be=(ca(Bc>>2,fe)|0)+(de>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+be|0,fe);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(be+8|0)|0,fe);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fe<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(be+(fe<<3))|0,fe);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(de&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fe<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((be+8|0)+(fe<<3))|0,fe);be=(ca(Ee>>2,fe)|0)+(De>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+be|0,fe);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(be+8|0)|0,fe);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(fe<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(be+(fe<<3))|0,fe);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((fe<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((be+8|0)+(fe<<3))|0,fe);break}}}while(0);Ae=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,fe,16)|0}}while(0);c[(qc+(((Ac<<3)+L&63)<<2)|0)>>2]=cc;c[uc+(((Ac<<3)+L&63)<<2)>>2]=Ae;ec=(ca((d[nc+((Ac<<J)-rc)|0]|0)+(d[nc+((L<<J)-sc)|0]|0)|0,jc)|0)+Ae|0;if((ec|0)>=(Od|0)){xe=Od;ye=Pd;ze=Qd;break}c[(q|0)>>2]=L;c[jb+4>>2]=Ac;xe=ec;ye=L;ze=Ac}}while(0);if((c[(a+14084|0)>>2]|0)!=0){pe=xe;qe=ye;re=ze;break}Ac=(ca(b[m+((Ra-s|0)<<2)>>1]|0,n)|0)+32768>>16;L=(ca(b[m+((Ra-s|0)<<2)+2>>1]|0,n)|0)+32768>>16;cc=(Ac|0)>(pc|0)?pc:Ac;Ac=(vc|0)>(cc|0)?vc:cc;cc=(L|0)>(oc|0)?oc:L;L=(tc|0)>(cc|0)?tc:cc;cc=Ac+zc+(L<<11)|0;if((c[(qc+(((L<<3)+Ac&63)<<2)|0)>>2]|0)==(cc|0)){pe=xe;qe=ye;re=ze;break}do{if((r&4|0)==0){Yd=c[a+12416>>2]|0;Xd=c[a+12420>>2]|0;Wd=(c[a+12352+(l<<4)>>2]|0)+((ca(Yd,L)|0)+Ac)|0;ec=Xe[wc&511](a,c[a+12288+(k<<4)>>2]|0,Wd,Yd,p)|0;if((r&2|0)==0){Fe=ec;break}Wd=c[a+12208>>2]|0;ge=(ca(Xd,L>>1)|0)+(Ac>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|Ac&1)<<2)>>2]&2047](Wd+(Yd<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ge|0,Xd,p>>1);mf[c[(c[(a+12444|0)>>2]|0)+((o+1|0)<<4)+((L<<1&2|Ac&1)<<2)>>2]&2047](Wd+(Yd<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ge|0,Xd,p>>1);ge=(Xe[xc&511](a,Wd+(Yd<<4)|0,c[a+12288+(k<<4)+4>>2]|0,Xd,p>>1)|0)+ec|0;Fe=ge+(Xe[xc&511](a,Wd+(Yd<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,Xd,p>>1)|0)|0}else{Xd=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Ac|0)){Fe=536870912;break}if((Ac<<J|0)>(c[(a+12268|0)>>2]<<J|0)){Fe=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Fe=536870912;break}if((L<<J|0)>(c[(a+12276|0)>>2]<<J|0)){Fe=536870912;break}Yd=e[a+13872>>1]|0;Wd=e[a+13874>>1]|0;ge=(r&1)<<1|1;s:do{if((c[a+11740>>2]|0)==1){if((Ac<<J|0)==0){ec=0;while(1){_d=c[a+12160+(ec<<3)>>2]|0;gc=(c[a+12160+(ec<<3)+4>>2]|0)+(L<<J)|0;be=((ca(c[a+12128+(ec<<3)>>2]|0,Wd-Yd|0)|0)/(Yd|0)|0)+((ec&1)<<(r&1|4))|0;j=c[a+12128+(ec<<3)+4>>2]|0;if((L<<J|0)==0){de=ec>>1;Ge=((ca(j,Wd-Yd|0)|0)/(Yd|0)|0)+(de<<(r&1|4))|0;He=de}else{Ge=gc-j|0;He=ec>>1}j=((Ge&ge)<<J)+(be&ge)|0;de=(c[(a+12208|0)>>2]|0)+((ca(He,Xd<<3)|0)+(ec<<3&8))|0;if((r&1|0)==0){Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(gc>>1,Xd)|0)+(_d>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((gc&ge)<<J)+(_d&ge)|0)<<2)>>2]&2047](de,Bc,Xd,8);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ge>>1,Xd)|0)+(be>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(j<<2)>>2]&2047](de,Bc,Xd,8)}else{Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(gc>>2,Xd)|0)+(_d>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((gc&ge)<<J)+(_d&ge)|0)<<2)>>2]&4095](de,Bc,Xd);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ge>>2,Xd)|0)+(be>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](de,Bc,Xd)}ec=ec+1|0;if((ec|0)>=4){break s}}}if((L<<J|0)==0){ec=0;do{fe=(c[a+12160+(ec<<3)>>2]|0)+(Ac<<J)|0;Bc=c[a+12160+(ec<<3)+4>>2]|0;de=fe-(c[a+12128+(ec<<3)>>2]|0)|0;j=ec>>1;be=((ca(c[a+12128+(ec<<3)+4>>2]|0,Wd-Yd|0)|0)/(Yd|0)|0)+(j<<(r&1|4))|0;_d=(c[(a+12208|0)>>2]|0)+((ec<<3&8)+(ca(j,Xd<<3)|0))|0;if((r&1|0)==0){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Bc>>1,Xd)|0)+(fe>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Bc&ge)<<J)+(fe&ge)|0)<<2)>>2]&2047](_d,j,Xd,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(be>>1,Xd)|0)+(de>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((be&ge)<<J)+(de&ge)|0)<<2)>>2]&2047](_d,j,Xd,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Bc>>2,Xd)|0)+(fe>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(fe&ge)|0)<<2)>>2]&4095](_d,j,Xd);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(be>>2,Xd)|0)+(de>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((be&ge)<<J)+(de&ge)|0)<<2)>>2]&4095](_d,j,Xd)}ec=ec+1|0;}while((ec|0)<4)}else{ec=0;do{j=(c[a+12160+(ec<<3)>>2]|0)+(Ac<<J)|0;_d=(c[a+12160+(ec<<3)+4>>2]|0)+(L<<J)|0;de=j-(c[a+12128+(ec<<3)>>2]|0)|0;be=_d-(c[a+12128+(ec<<3)+4>>2]|0)|0;fe=(c[(a+12208|0)>>2]|0)+((ec<<3&8)+(ca(ec>>1,Xd<<3)|0))|0;if((r&1|0)==0){Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_d>>1,Xd)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((_d&ge)<<J)+(j&ge)|0)<<2)>>2]&2047](fe,Bc,Xd,8);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(be>>1,Xd)|0)+(de>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((be&ge)<<J)+(de&ge)|0)<<2)>>2]&2047](fe,Bc,Xd,8)}else{Bc=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_d>>2,Xd)|0)+(j>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_d&ge)<<J)+(j&ge)|0)<<2)>>2]&4095](fe,Bc,Xd);Bc=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(be>>2,Xd)|0)+(de>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((be&ge)<<J)+(de&ge)|0)<<2)>>2]&4095](fe,Bc,Xd)}ec=ec+1|0;}while((ec|0)<4)}}else{ec=(c[a+12160>>2]|0)+(Ac<<J)|0;Bc=(c[a+12164>>2]|0)+(L<<J)|0;fe=c[a+12128>>2]|0;if((Ac<<J|0)==0){Ie=(ca(fe,Wd-Yd|0)|0)/(Yd|0)|0}else{Ie=ec-fe|0}fe=c[a+12132>>2]|0;if((L<<J|0)==0){Je=(ca(fe,Wd-Yd|0)|0)/(Yd|0)|0}else{Je=Bc-fe|0}fe=((Je&ge)<<J)+(Ie&ge)|0;if((r&1|0)==0){de=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Bc>>1,Xd)|0)+(ec>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,de,Xd,16);de=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Je>>1,Xd)|0)+(Ie>>1))|0;mf[c[(c[a+12448>>2]|0)+(fe<<2)>>2]&2047](c[(a+12208|0)>>2]|0,de,Xd,16);break}else{de=(ca(Bc>>2,Xd)|0)+(ec>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+de|0,Xd);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(de+8|0)|0,Xd);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Xd<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(de+(Xd<<3))|0,Xd);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Bc&ge)<<J)+(ec&ge)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Xd<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((de+8|0)+(Xd<<3))|0,Xd);de=(ca(Je>>2,Xd)|0)+(Ie>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+de|0,Xd);ef[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(de+8|0)|0,Xd);ef[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Xd<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(de+(Xd<<3))|0,Xd);ef[c[(c[(a+12456|0)>>2]|0)+64+(fe<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Xd<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((de+8|0)+(Xd<<3))|0,Xd);break}}}while(0);Fe=Xe[wc&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,Xd,16)|0}}while(0);c[(qc+(((L<<3)+Ac&63)<<2)|0)>>2]=cc;c[uc+(((L<<3)+Ac&63)<<2)>>2]=Fe;ge=(ca((d[nc+((L<<J)-rc)|0]|0)+(d[nc+((Ac<<J)-sc)|0]|0)|0,jc)|0)+Fe|0;if((ge|0)>=(xe|0)){pe=xe;qe=ye;re=ze;break}c[(q|0)>>2]=Ac;c[jb+4>>2]=L;pe=ge;qe=Ac;re=L;break}}else{pe=Od;qe=Pd;re=Qd}}while(0);Qd=c[(c[a+12120>>2]|0)+252>>2]|0;c[q+24>>2]=a;c[q+32>>2]=f;c[q+40>>2]=h;c[q+56>>2]=k;c[q+64>>2]=l;c[q+72>>2]=m;c[q+80>>2]=n;c[q+88>>2]=o;c[q+96>>2]=p;c[q+104>>2]=r;c[q+5344>>2]=jb;c[q+5352>>2]=s;c[q+5368>>2]=uc;c[q+5376>>2]=vc;c[q+5384>>2]=tc;c[q+5392>>2]=pc;c[q+5400>>2]=oc;c[q+5408>>2]=nc;c[q+5416>>2]=sc;c[q+5424>>2]=rc;c[q+5432>>2]=qc;c[q+5440>>2]=J;c[q+5472>>2]=jc;c[q+5480>>2]=wc;c[q+5488>>2]=xc;c[q+5504>>2]=zc;c[q+13904>>2]=re;c[q+13912>>2]=qe;c[q+13920>>2]=pe;c[q+13928>>2]=Qd;c[q+27600>>2]=N;c[q+27640>>2]=0;c[q+27644>>2]=0;_ff_epzs_motion_search$0(q);N=c[q+27600>>2]|0;E=c[q+27640>>2]|0;x=c[q+27644>>2]|0;F=+g[q+27644>>2];c[q+27640>>2]=0;c[q+27644>>2]=0;if((E|0)==6){return x|0}return 0|0;return 0}function $qb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+4>>2]|0;e=c[d+248>>2]|0;f=(e|0)>-1?e:-e|0;g=c[d+264>>2]|0;h=(g|0)>-1?g:-g|0;j=(f&255)>>>0>(h&255)>>>0?f:h;if((((e|0)>(g|0)?g:e)|0)<-64){KIb(d,16,2425112,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}e=c[a+11732>>2]|0;do{if(!((e|0)==1|(e|0)==5|(e|0)==6)){if((c[d+48>>2]|0)==1397641047){break}KIb(d,16,2581120,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}}while(0);e=a+12120|0;c[e>>2]=d;do{if((j&255)>>>0>4>>>0){if((c[a+12416>>2]|0)!=0){m=d;break}KIb(d,32,2437184,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;m=c[e>>2]|0}else{m=d}}while(0);d=a+10056|0;h8(d,a+10444|0,c[m+260>>2]|0);h8(d,a+10468|0,c[(c[e>>2]|0)+232>>2]|0);h8(d,a+10492|0,c[(c[e>>2]|0)+236>>2]|0);h8(d,a+10516|0,c[(c[e>>2]|0)+240>>2]|0);d=c[e>>2]|0;e=d+232|0;m=d+88|0;c[a+12244>>2]=(c[m>>2]|0)>>>4&1|(c[e>>2]|0)>>>7&2;k=d+236|0;c[a+12248>>2]=(c[m>>2]|0)>>>4&1|(c[k>>2]|0)>>>7&2;j=d+240|0;c[a+12252>>2]=(c[m>>2]|0)>>>4&1|(c[j>>2]|0)>>>7&2;a:do{if((c[a+60>>2]&16|0)==0){m=c[k>>2]|0;if((m&256|0)!=0){c[a+12468>>2]=26;break}do{if((m|0)==0){if((c[e>>2]|0)!=0){break}if((c[j>>2]|0)!=0){break}c[a+12468>>2]=24;break a}}while(0);c[a+12468>>2]=26}else{c[a+12468>>2]=32;c[a+12456>>2]=a+10808;if((c[a+12472>>2]|0)==0){c[a+12452>>2]=a+10680;break}else{c[a+12452>>2]=a+10936;break}}}while(0);c[a+12448>>2]=a+11396;if((c[a+12472>>2]|0)==0){j=a+11332|0;c[a+12444>>2]=j;n=j}else{j=a+11460|0;c[a+12444>>2]=j;n=j}j=c[a+148>>2]|0;if((j|0)==0){m=c[a+116>>2]|0;c[a+12416>>2]=(m<<4)+32;c[a+12420>>2]=(m<<3)+16}else{c[a+12416>>2]=j;c[a+12420>>2]=c[a+152>>2]}j=c[a+48>>2]|0;if((j|0)==1397641047){l=0;i=b;return l|0}if((c[e>>2]&256|0)!=0){c[a+10476>>2]=202}do{if((c[k>>2]&256|0)!=0){e=a+10500|0;if((c[e>>2]|0)!=0){break}c[e>>2]=202}}while(0);k=a+12444|0;c[n+44>>2]=966;c[(c[k>>2]|0)+40>>2]=966;c[(c[k>>2]|0)+36>>2]=966;c[(c[k>>2]|0)+32>>2]=966;if((j|0)!=4){l=0;i=b;return l|0}c[a+12468>>2]=8;l=0;i=b;return l|0}function arb(a,b,f,g,h,j,k,l){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;m=i;i=i+96|0;n=m|0;o=m+32|0;p=c[b>>2]|0;q=c[f>>2]|0;r=c[a+12236>>2]|0;s=c[a+12120>>2]|0;t=c[s+268>>2]|0;u=c[a+12220>>2]|0;v=a+12264|0;w=c[v>>2]|0;x=a+12272|0;y=c[x>>2]|0;z=a+12268|0;A=c[z>>2]|0;B=a+12276|0;C=c[B>>2]|0;D=c[a+12464>>2]|0;E=c[a+12280>>2]|0;F=c[a+12284>>2]|0;H=c[a+12248>>2]|0;I=c[a+10468+(k<<2)>>2]|0;J=k+1|0;K=c[a+10468+(J<<2)>>2]|0;L=c[a+10492+(k<<2)>>2]|0;M=c[a+10492+(J<<2)>>2]|0;if((c[a+12124>>2]|0)!=0){c[b>>2]=0;N=g;O=0;c[f>>2]=O;i=m;return N|0}do{if((c[s+232>>2]|0)==(c[s+236>>2]|0)){P=g}else{Q=H&1;do{if((H&4|0)==0){R=c[a+12416>>2]|0;S=c[a+12420>>2]|0;T=a;U=(c[a+12352+(j<<4)>>2]|0)+((ca(R,q)|0)+p)|0;V=Xe[L&511](T,c[a+12288+(h<<4)>>2]|0,U,R,l)|0;if((H&2|0)==0){W=V;break}U=q<<1&2|p&1;X=c[a+12208>>2]|0;Y=R<<4;R=X+Y|0;Z=a+12444|0;_=(ca(S,q>>1)|0)+(p>>1)|0;$=l>>1;mf[c[(c[Z>>2]|0)+(J<<4)+(U<<2)>>2]&2047](R,(c[a+12352+(j<<4)+4>>2]|0)+_|0,S,$);aa=X+(Y|8)|0;mf[c[(c[Z>>2]|0)+(J<<4)+(U<<2)>>2]&2047](aa,(c[a+12352+(j<<4)+8>>2]|0)+_|0,S,$);_=(Xe[M&511](T,R,c[a+12288+(h<<4)+4>>2]|0,S,$)|0)+V|0;W=_+(Xe[M&511](T,aa,c[a+12288+(h<<4)+8>>2]|0,S,$)|0)|0}else{$=c[a+12416>>2]|0;S=Q+1|0;aa=p<<S;T=q<<S;_=a+12352+(j<<4)|0;V=a+12288+(h<<4)|0;if((w|0)>(p|0)){W=536870912;break}if((aa|0)>(A<<S|0)|(y|0)>(q|0)){W=536870912;break}if((T|0)>(C<<S|0)){W=536870912;break}R=e[a+13872>>1]|0;U=e[a+13874>>1]|0;Z=Q<<1|1;a:do{if((c[a+11740>>2]|0)==1){Y=U-R|0;X=Q|4;ba=(T|0)==0;da=a+12208|0;ea=$<<3;fa=(Q|0)==0;ga=a+12444|0;ha=a+12448|0;ia=a+12352+(j<<4)+32|0;ja=a+12452|0;ka=a+12456|0;if((aa|0)==0){la=0;while(1){ma=c[a+12160+(la<<3)>>2]|0;na=(c[a+12160+(la<<3)+4>>2]|0)+T|0;oa=((ca(c[a+12128+(la<<3)>>2]|0,Y)|0)/(R|0)|0)+((la&1)<<X)|0;pa=c[a+12128+(la<<3)+4>>2]|0;if(ba){qa=la>>1;ra=((ca(pa,Y)|0)/(R|0)|0)+(qa<<X)|0;sa=qa}else{ra=na-pa|0;sa=la>>1}pa=((na&Z)<<S)+(ma&Z)|0;qa=((ra&Z)<<S)+(oa&Z)|0;ta=(c[da>>2]|0)+((ca(sa,ea)|0)+(la<<3&8))|0;if(fa){ua=(c[_>>2]|0)+((ca(na>>1,$)|0)+(ma>>1))|0;mf[c[(c[ga>>2]|0)+16+(pa<<2)>>2]&2047](ta,ua,$,8);ua=(c[ia>>2]|0)+((ca(ra>>1,$)|0)+(oa>>1))|0;mf[c[(c[ha>>2]|0)+16+(qa<<2)>>2]&2047](ta,ua,$,8)}else{ua=(c[_>>2]|0)+((ca(na>>2,$)|0)+(ma>>2))|0;ef[c[(c[ja>>2]|0)+64+(pa<<2)>>2]&4095](ta,ua,$);ua=(c[ia>>2]|0)+((ca(ra>>2,$)|0)+(oa>>2))|0;ef[c[(c[ka>>2]|0)+64+(qa<<2)>>2]&4095](ta,ua,$)}la=la+1|0;if((la|0)>=4){break a}}}if(ba){la=0;do{ua=(c[a+12160+(la<<3)>>2]|0)+aa|0;ta=c[a+12160+(la<<3)+4>>2]|0;qa=ua-(c[a+12128+(la<<3)>>2]|0)|0;oa=la>>1;pa=((ca(c[a+12128+(la<<3)+4>>2]|0,Y)|0)/(R|0)|0)+(oa<<X)|0;ma=((ta&Z)<<S)+(ua&Z)|0;na=((pa&Z)<<S)+(qa&Z)|0;va=(c[da>>2]|0)+((la<<3&8)+(ca(oa,ea)|0))|0;if(fa){oa=(c[_>>2]|0)+((ca(ta>>1,$)|0)+(ua>>1))|0;mf[c[(c[ga>>2]|0)+16+(ma<<2)>>2]&2047](va,oa,$,8);oa=(c[ia>>2]|0)+((ca(pa>>1,$)|0)+(qa>>1))|0;mf[c[(c[ha>>2]|0)+16+(na<<2)>>2]&2047](va,oa,$,8)}else{oa=(c[_>>2]|0)+((ca(ta>>2,$)|0)+(ua>>2))|0;ef[c[(c[ja>>2]|0)+64+(ma<<2)>>2]&4095](va,oa,$);oa=(c[ia>>2]|0)+((ca(pa>>2,$)|0)+(qa>>2))|0;ef[c[(c[ka>>2]|0)+64+(na<<2)>>2]&4095](va,oa,$)}la=la+1|0;}while((la|0)<4)}else{la=0;do{X=(c[a+12160+(la<<3)>>2]|0)+aa|0;Y=(c[a+12160+(la<<3)+4>>2]|0)+T|0;ba=X-(c[a+12128+(la<<3)>>2]|0)|0;oa=Y-(c[a+12128+(la<<3)+4>>2]|0)|0;va=((Y&Z)<<S)+(X&Z)|0;na=((oa&Z)<<S)+(ba&Z)|0;qa=(c[da>>2]|0)+((la<<3&8)+(ca(la>>1,ea)|0))|0;if(fa){pa=(c[_>>2]|0)+((ca(Y>>1,$)|0)+(X>>1))|0;mf[c[(c[ga>>2]|0)+16+(va<<2)>>2]&2047](qa,pa,$,8);pa=(c[ia>>2]|0)+((ca(oa>>1,$)|0)+(ba>>1))|0;mf[c[(c[ha>>2]|0)+16+(na<<2)>>2]&2047](qa,pa,$,8)}else{pa=(c[_>>2]|0)+((ca(Y>>2,$)|0)+(X>>2))|0;ef[c[(c[ja>>2]|0)+64+(va<<2)>>2]&4095](qa,pa,$);pa=(c[ia>>2]|0)+((ca(oa>>2,$)|0)+(ba>>2))|0;ef[c[(c[ka>>2]|0)+64+(na<<2)>>2]&4095](qa,pa,$)}la=la+1|0;}while((la|0)<4)}}else{la=(c[a+12160>>2]|0)+aa|0;ka=(c[a+12164>>2]|0)+T|0;ia=c[a+12128>>2]|0;if((aa|0)==0){wa=(ca(ia,U-R|0)|0)/(R|0)|0}else{wa=la-ia|0}ia=c[a+12132>>2]|0;if((T|0)==0){xa=(ca(ia,U-R|0)|0)/(R|0)|0}else{xa=ka-ia|0}ia=((ka&Z)<<S)+(la&Z)|0;ja=((xa&Z)<<S)+(wa&Z)|0;if((Q|0)==0){ha=a+12208|0;ga=(c[_>>2]|0)+((ca(ka>>1,$)|0)+(la>>1))|0;mf[c[(c[a+12444>>2]|0)+(ia<<2)>>2]&2047](c[ha>>2]|0,ga,$,16);ga=(c[a+12352+(j<<4)+32>>2]|0)+((ca(xa>>1,$)|0)+(wa>>1))|0;mf[c[(c[a+12448>>2]|0)+(ja<<2)>>2]&2047](c[ha>>2]|0,ga,$,16);break}else{ga=a+12452|0;ha=a+12208|0;fa=(ca(ka>>2,$)|0)+(la>>2)|0;ef[c[(c[ga>>2]|0)+64+(ia<<2)>>2]&4095](c[ha>>2]|0,(c[_>>2]|0)+fa|0,$);la=fa+8|0;ef[c[(c[ga>>2]|0)+64+(ia<<2)>>2]&4095]((c[ha>>2]|0)+8|0,(c[_>>2]|0)+la|0,$);ka=$<<3;ef[c[(c[ga>>2]|0)+64+(ia<<2)>>2]&4095]((c[ha>>2]|0)+ka|0,(c[_>>2]|0)+(fa+ka)|0,$);fa=ka+8|0;ef[c[(c[ga>>2]|0)+64+(ia<<2)>>2]&4095]((c[ha>>2]|0)+fa|0,(c[_>>2]|0)+(la+ka)|0,$);la=a+12456|0;ia=a+12352+(j<<4)+32|0;ga=(ca(xa>>2,$)|0)+(wa>>2)|0;ef[c[(c[la>>2]|0)+64+(ja<<2)>>2]&4095](c[ha>>2]|0,(c[ia>>2]|0)+ga|0,$);ea=ga+8|0;ef[c[(c[la>>2]|0)+64+(ja<<2)>>2]&4095]((c[ha>>2]|0)+8|0,(c[ia>>2]|0)+ea|0,$);ef[c[(c[la>>2]|0)+64+(ja<<2)>>2]&4095]((c[ha>>2]|0)+ka|0,(c[ia>>2]|0)+(ga+ka)|0,$);ef[c[(c[la>>2]|0)+64+(ja<<2)>>2]&4095]((c[ha>>2]|0)+fa|0,(c[ia>>2]|0)+(ea+ka)|0,$);break}}}while(0);W=Xe[L&511](a,c[a+12208>>2]|0,c[V>>2]|0,$,16)|0}}while(0);if(!((q|p|0)!=0|(k|0)>0)){P=W;break}P=(ca((d[D+((q<<2)-F)|0]|0)+(d[D+((p<<2)-E)|0]|0)|0,r)|0)+W|0}}while(0);W=p<<2;if(!((p|0)>(w|0)&(p|0)<(A|0)&(q|0)>(y|0)&(q|0)<(C|0))){c[b>>2]=W;N=P;O=q<<2;c[f>>2]=O;i=m;return N|0}C=q<<2;y=(q<<3)+p|0;A=c[u+((y+56&63)<<2)>>2]|0;w=c[u+((y+63&63)<<2)>>2]|0;L=c[u+((y+1&63)<<2)>>2]|0;wa=c[u+((y+8&63)<<2)>>2]|0;xa=c[u+((y&63)<<2)>>2]|0;mrc(n|0,64,32)|0;if((c[a+12260>>2]|0)>1){ra=c[u+((y+55&63)<<2)>>2]|0;sa=c[u+((y+7&63)<<2)>>2]|0;M=c[u+((y+57&63)<<2)>>2]|0;g=c[u+((y+9&63)<<2)>>2]|0;y=ra-(A<<1)+M|0;u=M-ra|0;ra=A<<5;M=L+w-(xa<<1)|0;s=L-w|0;Q=xa<<5;_=sa-(wa<<1)+g|0;Z=g-sa|0;sa=wa<<5;g=-3;do{S=ca(g,g)|0;R=0;U=g<<2;T=U;aa=(U|0)<0|0?-1:0;U=g+C|0;ka=D+(U-F)|0;ea=-3;do{ia=ca(ea,ea)|0;fa=ea<<2;ha=(ca(fa,u)|0)+ra+(ca(ia,y)|0)|0;ja=ha;la=(ha|0)<0|0?-1:0;ha=(ca(fa,s)|0)+Q+(ca(ia,M)|0)|0;ga=ha;da=(ha|0)<0|0?-1:0;ha=(ca(fa,Z)|0)+sa+(ca(ia,_)|0)|0;ia=ha;fa=(ha|0)<0|0?-1:0;b:do{if(((ea|g)&3|0)!=0){ha=xrc(ia,fa,ja,la)|0;pa=G;qa=wrc(ia,fa,ja,la)|0;na=G;ba=wrc(ga<<5|0>>>27,da<<5|ga>>>27,512,0)|0;oa=G;va=Erc(ha,pa,T,aa)|0;pa=G;ha=xrc(qa,na,ga<<1|0>>>31,da<<1|ga>>>31)|0;na=G;qa=wrc(ba,oa,va,pa)|0;pa=G;va=Erc(ha,na,S,R)|0;na=wrc(qa,pa,va,G)|0;va=ea+W|0;pa=(ca((d[ka]|0)+(d[D+(va-E)|0]|0)|0,r)|0)+(na>>>10|G<<22)|0;na=0;while(1){if((na|0)>=8){break b}ya=n+(na<<2)|0;za=na+1|0;if((pa|0)<(c[ya>>2]|0)){break}else{na=za}}qa=7-na|0;orc(n+(za<<2)|0,ya|0,qa<<2|0)|0;ha=o+(na<<3)|0;orc(o+(za<<3)|0,ha|0,qa<<3|0)|0;c[ya>>2]=pa;c[ha>>2]=va;c[o+(na<<3)+4>>2]=U}}while(0);ea=ea+1|0;}while((ea|0)<4);g=g+1|0;}while((g|0)<4)}else{g=L-w<<2;ya=xa<<1;za=L+w-ya|0;w=wa-A<<2;L=wa+A|0;A=L-ya|0;ya=p-1|0;p=q-1|0;q=H&1;do{if((H&4|0)==0){wa=c[a+12416>>2]|0;_=c[a+12420>>2]|0;sa=a;Z=(c[a+12352+(j<<4)>>2]|0)+((ca(wa,p)|0)+ya)|0;M=Xe[I&511](sa,c[a+12288+(h<<4)>>2]|0,Z,wa,l)|0;if((H&2|0)==0){Aa=M;break}Z=p<<1&2|ya&1;Q=c[a+12208>>2]|0;s=wa<<4;wa=Q+s|0;y=a+12444|0;ra=(ca(_,p>>1)|0)+(ya>>1)|0;u=l>>1;mf[c[(c[y>>2]|0)+(J<<4)+(Z<<2)>>2]&2047](wa,(c[a+12352+(j<<4)+4>>2]|0)+ra|0,_,u);ea=Q+(s|8)|0;mf[c[(c[y>>2]|0)+(J<<4)+(Z<<2)>>2]&2047](ea,(c[a+12352+(j<<4)+8>>2]|0)+ra|0,_,u);ra=(Xe[K&511](sa,wa,c[a+12288+(h<<4)+4>>2]|0,_,u)|0)+M|0;Aa=ra+(Xe[K&511](sa,ea,c[a+12288+(h<<4)+8>>2]|0,_,u)|0)|0}else{u=c[a+12416>>2]|0;_=q+1|0;ea=ya<<_;sa=p<<_;ra=a+12352+(j<<4)|0;M=a+12288+(h<<4)|0;if((c[v>>2]|0)>(ya|0)){Aa=536870912;break}if((ea|0)>(c[z>>2]<<_|0)){Aa=536870912;break}if((c[x>>2]|0)>(p|0)){Aa=536870912;break}if((sa|0)>(c[B>>2]<<_|0)){Aa=536870912;break}wa=e[a+13872>>1]|0;Z=e[a+13874>>1]|0;y=q<<1|1;c:do{if((c[a+11740>>2]|0)==1){s=Z-wa|0;Q=q|4;U=(sa|0)==0;ka=a+12208|0;R=u<<3;S=(q|0)==0;aa=a+12444|0;T=a+12448|0;ga=a+12352+(j<<4)+32|0;da=a+12452|0;la=a+12456|0;if((ea|0)==0){ja=0;while(1){fa=c[a+12160+(ja<<3)>>2]|0;ia=(c[a+12160+(ja<<3)+4>>2]|0)+sa|0;$=((ca(c[a+12128+(ja<<3)>>2]|0,s)|0)/(wa|0)|0)+((ja&1)<<Q)|0;V=c[a+12128+(ja<<3)+4>>2]|0;if(U){ha=ja>>1;Ba=((ca(V,s)|0)/(wa|0)|0)+(ha<<Q)|0;Ca=ha}else{Ba=ia-V|0;Ca=ja>>1}V=((ia&y)<<_)+(fa&y)|0;ha=((Ba&y)<<_)+($&y)|0;qa=(c[ka>>2]|0)+((ca(Ca,R)|0)+(ja<<3&8))|0;if(S){oa=(c[ra>>2]|0)+((ca(ia>>1,u)|0)+(fa>>1))|0;mf[c[(c[aa>>2]|0)+16+(V<<2)>>2]&2047](qa,oa,u,8);oa=(c[ga>>2]|0)+((ca(Ba>>1,u)|0)+($>>1))|0;mf[c[(c[T>>2]|0)+16+(ha<<2)>>2]&2047](qa,oa,u,8)}else{oa=(c[ra>>2]|0)+((ca(ia>>2,u)|0)+(fa>>2))|0;ef[c[(c[da>>2]|0)+64+(V<<2)>>2]&4095](qa,oa,u);oa=(c[ga>>2]|0)+((ca(Ba>>2,u)|0)+($>>2))|0;ef[c[(c[la>>2]|0)+64+(ha<<2)>>2]&4095](qa,oa,u)}ja=ja+1|0;if((ja|0)>=4){break c}}}if(U){ja=0;do{oa=(c[a+12160+(ja<<3)>>2]|0)+ea|0;qa=c[a+12160+(ja<<3)+4>>2]|0;ha=oa-(c[a+12128+(ja<<3)>>2]|0)|0;$=ja>>1;V=((ca(c[a+12128+(ja<<3)+4>>2]|0,s)|0)/(wa|0)|0)+($<<Q)|0;fa=((qa&y)<<_)+(oa&y)|0;ia=((V&y)<<_)+(ha&y)|0;ba=(c[ka>>2]|0)+((ja<<3&8)+(ca($,R)|0))|0;if(S){$=(c[ra>>2]|0)+((ca(qa>>1,u)|0)+(oa>>1))|0;mf[c[(c[aa>>2]|0)+16+(fa<<2)>>2]&2047](ba,$,u,8);$=(c[ga>>2]|0)+((ca(V>>1,u)|0)+(ha>>1))|0;mf[c[(c[T>>2]|0)+16+(ia<<2)>>2]&2047](ba,$,u,8)}else{$=(c[ra>>2]|0)+((ca(qa>>2,u)|0)+(oa>>2))|0;ef[c[(c[da>>2]|0)+64+(fa<<2)>>2]&4095](ba,$,u);$=(c[ga>>2]|0)+((ca(V>>2,u)|0)+(ha>>2))|0;ef[c[(c[la>>2]|0)+64+(ia<<2)>>2]&4095](ba,$,u)}ja=ja+1|0;}while((ja|0)<4)}else{ja=0;do{Q=(c[a+12160+(ja<<3)>>2]|0)+ea|0;s=(c[a+12160+(ja<<3)+4>>2]|0)+sa|0;U=Q-(c[a+12128+(ja<<3)>>2]|0)|0;$=s-(c[a+12128+(ja<<3)+4>>2]|0)|0;ba=((s&y)<<_)+(Q&y)|0;ia=(($&y)<<_)+(U&y)|0;ha=(c[ka>>2]|0)+((ja<<3&8)+(ca(ja>>1,R)|0))|0;if(S){V=(c[ra>>2]|0)+((ca(s>>1,u)|0)+(Q>>1))|0;mf[c[(c[aa>>2]|0)+16+(ba<<2)>>2]&2047](ha,V,u,8);V=(c[ga>>2]|0)+((ca($>>1,u)|0)+(U>>1))|0;mf[c[(c[T>>2]|0)+16+(ia<<2)>>2]&2047](ha,V,u,8)}else{V=(c[ra>>2]|0)+((ca(s>>2,u)|0)+(Q>>2))|0;ef[c[(c[da>>2]|0)+64+(ba<<2)>>2]&4095](ha,V,u);V=(c[ga>>2]|0)+((ca($>>2,u)|0)+(U>>2))|0;ef[c[(c[la>>2]|0)+64+(ia<<2)>>2]&4095](ha,V,u)}ja=ja+1|0;}while((ja|0)<4)}}else{ja=(c[a+12160>>2]|0)+ea|0;la=(c[a+12164>>2]|0)+sa|0;ga=c[a+12128>>2]|0;if((ea|0)==0){Da=(ca(ga,Z-wa|0)|0)/(wa|0)|0}else{Da=ja-ga|0}ga=c[a+12132>>2]|0;if((sa|0)==0){Ea=(ca(ga,Z-wa|0)|0)/(wa|0)|0}else{Ea=la-ga|0}ga=((la&y)<<_)+(ja&y)|0;da=((Ea&y)<<_)+(Da&y)|0;if((q|0)==0){T=a+12208|0;aa=(c[ra>>2]|0)+((ca(la>>1,u)|0)+(ja>>1))|0;mf[c[(c[a+12444>>2]|0)+(ga<<2)>>2]&2047](c[T>>2]|0,aa,u,16);aa=(c[a+12352+(j<<4)+32>>2]|0)+((ca(Ea>>1,u)|0)+(Da>>1))|0;mf[c[(c[a+12448>>2]|0)+(da<<2)>>2]&2047](c[T>>2]|0,aa,u,16);break}else{aa=a+12452|0;T=a+12208|0;S=(ca(la>>2,u)|0)+(ja>>2)|0;ef[c[(c[aa>>2]|0)+64+(ga<<2)>>2]&4095](c[T>>2]|0,(c[ra>>2]|0)+S|0,u);ja=S+8|0;ef[c[(c[aa>>2]|0)+64+(ga<<2)>>2]&4095]((c[T>>2]|0)+8|0,(c[ra>>2]|0)+ja|0,u);la=u<<3;ef[c[(c[aa>>2]|0)+64+(ga<<2)>>2]&4095]((c[T>>2]|0)+la|0,(c[ra>>2]|0)+(S+la)|0,u);S=la+8|0;ef[c[(c[aa>>2]|0)+64+(ga<<2)>>2]&4095]((c[T>>2]|0)+S|0,(c[ra>>2]|0)+(ja+la)|0,u);ja=a+12456|0;ga=a+12352+(j<<4)+32|0;aa=(ca(Ea>>2,u)|0)+(Da>>2)|0;ef[c[(c[ja>>2]|0)+64+(da<<2)>>2]&4095](c[T>>2]|0,(c[ga>>2]|0)+aa|0,u);R=aa+8|0;ef[c[(c[ja>>2]|0)+64+(da<<2)>>2]&4095]((c[T>>2]|0)+8|0,(c[ga>>2]|0)+R|0,u);ef[c[(c[ja>>2]|0)+64+(da<<2)>>2]&4095]((c[T>>2]|0)+la|0,(c[ga>>2]|0)+(aa+la)|0,u);ef[c[(c[ja>>2]|0)+64+(da<<2)>>2]&4095]((c[T>>2]|0)+S|0,(c[ga>>2]|0)+(R+la)|0,u);break}}}while(0);Aa=Xe[I&511](a,c[a+12208>>2]|0,c[M>>2]|0,u,16)|0}}while(0);Da=((w+g|0)/4|0)-(L+za)+(Aa<<1)|0;Aa=-3;do{L=Aa+C|0;Ea=D+(L-F)|0;q=(ca(Aa,Da)|0)+g|0;Ba=ca((ca(Aa,A)|0)+w|0,Aa)|0;Ca=-3;do{d:do{if(((Ca|Aa)&3|0)!=0){p=ca(Ca,za)|0;ya=Ca+W|0;ra=Ba+(ca(q+p|0,Ca)|0)+((ca((d[Ea]|0)+(d[D+(ya-E)|0]|0)|0,r)|0)+xa<<5)|0;p=0;while(1){if((p|0)>=8){break d}Fa=n+(p<<2)|0;Ga=p+1|0;if((ra|0)<(c[Fa>>2]|0)){break}else{p=Ga}}na=7-p|0;orc(n+(Ga<<2)|0,Fa|0,na<<2|0)|0;va=o+(p<<3)|0;orc(o+(Ga<<3)|0,va|0,na<<3|0)|0;c[Fa>>2]=ra;c[va>>2]=ya;c[o+(p<<3)+4>>2]=L}}while(0);Ca=Ca+1|0;}while((Ca|0)<4);Aa=Aa+1|0;}while((Aa|0)<4)}if((t|0)>0){Aa=(H&4|0)==0;Fa=a+12416|0;Ga=a+12420|0;n=a+12352+(j<<4)|0;xa=a+12288+(h<<4)|0;za=a;w=(H&2|0)==0;H=a+12208|0;A=a+12444|0;g=a+12352+(j<<4)+4|0;Da=l>>1;Ca=a+12352+(j<<4)+8|0;L=a+12288+(h<<4)+4|0;Ea=a+12288+(h<<4)+8|0;h=a+12452|0;q=a+13872|0;Ba=a+13874|0;u=a+11740|0;M=a+12352+(j<<4)+32|0;j=a+12456|0;va=a+12160|0;na=a+12164|0;pa=a+12128|0;y=a+12132|0;_=0;wa=C;Z=W;sa=P;while(1){ea=c[o+(_<<3)>>2]|0;la=c[o+(_<<3)+4>>2]|0;R=ea>>2;ga=ea&3;S=R<<2|ga;T=la>>2;da=la&3;ja=T<<2|da;aa=c[Fa>>2]|0;e:do{if(Aa){ka=c[Ga>>2]|0;V=da<<2|ga;do{if((V|0)==0){ha=(c[n>>2]|0)+((ca(aa,T)|0)+R)|0;ia=Xe[I&511](za,c[xa>>2]|0,ha,aa,l)|0;if(w){Ha=ia;break e}Ia=T<<1&2|R&1;Ja=ia}else{ia=(c[n>>2]|0)+((ca(aa,T)|0)+R)|0;ef[c[(c[h>>2]|0)+(k<<6)+(V<<2)>>2]&4095](c[H>>2]|0,ia,aa);if(w){Ha=Xe[I&511](za,c[H>>2]|0,c[xa>>2]|0,aa,l)|0;break e}else{ia=(S|0)/2|0;ha=(ja|0)/2|0;Ia=(ha<<1|ha)&2|(ia>>>1|ia)&1;Ja=Xe[I&511](za,c[H>>2]|0,c[xa>>2]|0,aa,l)|0;break}}}while(0);V=c[H>>2]|0;ia=aa<<4;ha=V+ia|0;U=(ca(ka,la>>3)|0)+(ea>>3)|0;mf[c[(c[A>>2]|0)+(J<<4)+(Ia<<2)>>2]&2047](ha,(c[g>>2]|0)+U|0,ka,Da);$=V+(ia|8)|0;mf[c[(c[A>>2]|0)+(J<<4)+(Ia<<2)>>2]&2047]($,(c[Ca>>2]|0)+U|0,ka,Da);U=(Xe[K&511](za,ha,c[L>>2]|0,ka,Da)|0)+Ja|0;Ha=U+(Xe[K&511](za,$,c[Ea>>2]|0,ka,Da)|0)|0}else{if((c[v>>2]|0)>(R|0)){Ha=536870912;break}if((S|0)>(c[z>>2]<<2|0)){Ha=536870912;break}if((c[x>>2]|0)>(T|0)){Ha=536870912;break}if((ja|0)>(c[B>>2]<<2|0)){Ha=536870912;break}$=e[q>>1]|0;U=e[Ba>>1]|0;f:do{if((c[u>>2]|0)==1){ha=U-$|0;ia=(ja|0)==0;V=aa<<3;if((S|0)==0){Ka=0}else{if(ia){ba=0;while(1){Q=(c[a+12160+(ba<<3)>>2]|0)+S|0;s=c[a+12160+(ba<<3)+4>>2]|0;fa=Q-(c[a+12128+(ba<<3)>>2]|0)|0;oa=ba>>1;qa=((ca(c[a+12128+(ba<<3)+4>>2]|0,ha)|0)/($|0)|0)+(oa<<5)|0;X=(c[H>>2]|0)+((ba<<3&8)+(ca(oa,V)|0))|0;oa=(c[n>>2]|0)+((ca(s>>2,aa)|0)+(Q>>2))|0;ef[c[(c[h>>2]|0)+64+((s<<2&12|Q&3)<<2)>>2]&4095](X,oa,aa);oa=(c[M>>2]|0)+((ca(qa>>2,aa)|0)+(fa>>2))|0;ef[c[(c[j>>2]|0)+64+((qa<<2&12|fa&3)<<2)>>2]&4095](X,oa,aa);ba=ba+1|0;if((ba|0)>=4){break f}}}else{ba=0;while(1){p=(c[a+12160+(ba<<3)>>2]|0)+S|0;ya=(c[a+12160+(ba<<3)+4>>2]|0)+ja|0;ra=p-(c[a+12128+(ba<<3)>>2]|0)|0;oa=ya-(c[a+12128+(ba<<3)+4>>2]|0)|0;X=(c[H>>2]|0)+((ba<<3&8)+(ca(ba>>1,V)|0))|0;fa=(c[n>>2]|0)+((ca(ya>>2,aa)|0)+(p>>2))|0;ef[c[(c[h>>2]|0)+64+((ya<<2&12|p&3)<<2)>>2]&4095](X,fa,aa);fa=(c[M>>2]|0)+((ca(oa>>2,aa)|0)+(ra>>2))|0;ef[c[(c[j>>2]|0)+64+((oa<<2&12|ra&3)<<2)>>2]&4095](X,fa,aa);ba=ba+1|0;if((ba|0)>=4){break f}}}}do{ba=c[a+12160+(Ka<<3)>>2]|0;fa=(c[a+12160+(Ka<<3)+4>>2]|0)+ja|0;X=((ca(c[a+12128+(Ka<<3)>>2]|0,ha)|0)/($|0)|0)+(Ka<<5&32)|0;ra=c[a+12128+(Ka<<3)+4>>2]|0;if(ia){oa=Ka>>1;La=((ca(ra,ha)|0)/($|0)|0)+(oa<<5)|0;Ma=oa}else{La=fa-ra|0;Ma=Ka>>1}ra=(c[H>>2]|0)+((ca(Ma,V)|0)+(Ka<<3&8))|0;oa=(c[n>>2]|0)+((ca(fa>>2,aa)|0)+(ba>>2))|0;ef[c[(c[h>>2]|0)+64+((fa<<2&12|ba&3)<<2)>>2]&4095](ra,oa,aa);oa=(c[M>>2]|0)+((ca(La>>2,aa)|0)+(X>>2))|0;ef[c[(c[j>>2]|0)+64+((La<<2&12|X&3)<<2)>>2]&4095](ra,oa,aa);Ka=Ka+1|0;}while((Ka|0)<4)}else{V=(c[va>>2]|0)+S|0;ha=(c[na>>2]|0)+ja|0;ia=c[pa>>2]|0;if((S|0)==0){Na=(ca(ia,U-$|0)|0)/($|0)|0}else{Na=V-ia|0}ia=c[y>>2]|0;if((ja|0)==0){Oa=(ca(ia,U-$|0)|0)/($|0)|0}else{Oa=ha-ia|0}ia=ha<<2&12|V&3;oa=Oa<<2&12|Na&3;ra=(ca(ha>>2,aa)|0)+(V>>2)|0;ef[c[(c[h>>2]|0)+64+(ia<<2)>>2]&4095](c[H>>2]|0,(c[n>>2]|0)+ra|0,aa);V=ra+8|0;ef[c[(c[h>>2]|0)+64+(ia<<2)>>2]&4095]((c[H>>2]|0)+8|0,(c[n>>2]|0)+V|0,aa);ha=aa<<3;ef[c[(c[h>>2]|0)+64+(ia<<2)>>2]&4095]((c[H>>2]|0)+ha|0,(c[n>>2]|0)+(ra+ha)|0,aa);ra=ha+8|0;ef[c[(c[h>>2]|0)+64+(ia<<2)>>2]&4095]((c[H>>2]|0)+ra|0,(c[n>>2]|0)+(V+ha)|0,aa);V=(ca(Oa>>2,aa)|0)+(Na>>2)|0;ef[c[(c[j>>2]|0)+64+(oa<<2)>>2]&4095](c[H>>2]|0,(c[M>>2]|0)+V|0,aa);ia=V+8|0;ef[c[(c[j>>2]|0)+64+(oa<<2)>>2]&4095]((c[H>>2]|0)+8|0,(c[M>>2]|0)+ia|0,aa);ef[c[(c[j>>2]|0)+64+(oa<<2)>>2]&4095]((c[H>>2]|0)+ha|0,(c[M>>2]|0)+(V+ha)|0,aa);ef[c[(c[j>>2]|0)+64+(oa<<2)>>2]&4095]((c[H>>2]|0)+ra|0,(c[M>>2]|0)+(ia+ha)|0,aa)}}while(0);Ha=Xe[I&511](za,c[H>>2]|0,c[xa>>2]|0,aa,16)|0}}while(0);aa=(ca((d[D+(ja-F)|0]|0)+(d[D+(S-E)|0]|0)|0,r)|0)+Ha|0;T=(aa|0)<(sa|0);R=T?ja:wa;ea=T?S:Z;la=T?aa:sa;aa=_+1|0;if((aa|0)<(t|0)){_=aa;wa=R;Z=ea;sa=la}else{Pa=R;Qa=ea;Ra=la;break}}}else{Pa=C;Qa=W;Ra=P}c[b>>2]=Qa;N=Ra;O=Pa;c[f>>2]=O;i=m;return N|0}function brb(a,b,f,g,h,i,j,k){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;l=c[b>>2]|0;m=c[f>>2]|0;n=c[a+12236>>2]|0;o=l<<1;p=m<<1;q=c[a+12220>>2]|0;r=c[a+12264>>2]|0;s=c[a+12272>>2]|0;t=c[a+12268>>2]|0;u=c[a+12276>>2]|0;v=c[a+12464>>2]|0;w=c[a+12280>>2]|0;x=c[a+12284>>2]|0;y=c[a+12248>>2]|0;z=c[a+10492+(j<<2)>>2]|0;A=j+1|0;B=c[a+10492+(A<<2)>>2]|0;if((c[a+12124>>2]|0)!=0){C=g;D=0;E=0;c[b>>2]=E;c[f>>2]=D;return C|0}F=c[a+12120>>2]|0;do{if((c[F+232>>2]|0)==(c[F+236>>2]|0)){G=g}else{H=y&1;do{if((y&4|0)==0){I=c[a+12416>>2]|0;J=c[a+12420>>2]|0;K=a;L=(c[a+12352+(i<<4)>>2]|0)+((ca(I,m)|0)+l)|0;M=Xe[z&511](K,c[a+12288+(h<<4)>>2]|0,L,I,k)|0;if((y&2|0)==0){N=M;break}L=p&2|l&1;O=c[a+12208>>2]|0;P=I<<4;I=O+P|0;Q=a+12444|0;R=(ca(J,m>>1)|0)+(l>>1)|0;S=k>>1;mf[c[(c[Q>>2]|0)+(A<<4)+(L<<2)>>2]&2047](I,(c[a+12352+(i<<4)+4>>2]|0)+R|0,J,S);T=O+(P|8)|0;mf[c[(c[Q>>2]|0)+(A<<4)+(L<<2)>>2]&2047](T,(c[a+12352+(i<<4)+8>>2]|0)+R|0,J,S);R=(Xe[B&511](K,I,c[a+12288+(h<<4)+4>>2]|0,J,S)|0)+M|0;N=R+(Xe[B&511](K,T,c[a+12288+(h<<4)+8>>2]|0,J,S)|0)|0}else{S=c[a+12416>>2]|0;J=H+1|0;T=l<<J;K=m<<J;R=a+12352+(i<<4)|0;M=a+12288+(h<<4)|0;if((r|0)>(l|0)){N=536870912;break}if((T|0)>(t<<J|0)|(s|0)>(m|0)){N=536870912;break}if((K|0)>(u<<J|0)){N=536870912;break}I=e[a+13872>>1]|0;L=e[a+13874>>1]|0;Q=H<<1|1;a:do{if((c[a+11740>>2]|0)==1){P=L-I|0;O=H|4;U=(K|0)==0;V=a+12208|0;W=S<<3;X=(H|0)==0;Y=a+12444|0;Z=a+12448|0;_=a+12352+(i<<4)+32|0;$=a+12452|0;aa=a+12456|0;if((T|0)==0){ba=0;while(1){da=c[a+12160+(ba<<3)>>2]|0;ea=(c[a+12160+(ba<<3)+4>>2]|0)+K|0;fa=((ca(c[a+12128+(ba<<3)>>2]|0,P)|0)/(I|0)|0)+((ba&1)<<O)|0;ga=c[a+12128+(ba<<3)+4>>2]|0;if(U){ha=ba>>1;ia=((ca(ga,P)|0)/(I|0)|0)+(ha<<O)|0;ja=ha}else{ia=ea-ga|0;ja=ba>>1}ga=((ea&Q)<<J)+(da&Q)|0;ha=((ia&Q)<<J)+(fa&Q)|0;ka=(c[V>>2]|0)+((ca(ja,W)|0)+(ba<<3&8))|0;if(X){la=(c[R>>2]|0)+((ca(ea>>1,S)|0)+(da>>1))|0;mf[c[(c[Y>>2]|0)+16+(ga<<2)>>2]&2047](ka,la,S,8);la=(c[_>>2]|0)+((ca(ia>>1,S)|0)+(fa>>1))|0;mf[c[(c[Z>>2]|0)+16+(ha<<2)>>2]&2047](ka,la,S,8)}else{la=(c[R>>2]|0)+((ca(ea>>2,S)|0)+(da>>2))|0;ef[c[(c[$>>2]|0)+64+(ga<<2)>>2]&4095](ka,la,S);la=(c[_>>2]|0)+((ca(ia>>2,S)|0)+(fa>>2))|0;ef[c[(c[aa>>2]|0)+64+(ha<<2)>>2]&4095](ka,la,S)}ba=ba+1|0;if((ba|0)>=4){break a}}}if(U){ba=0;do{la=(c[a+12160+(ba<<3)>>2]|0)+T|0;ka=c[a+12160+(ba<<3)+4>>2]|0;ha=la-(c[a+12128+(ba<<3)>>2]|0)|0;fa=ba>>1;ga=((ca(c[a+12128+(ba<<3)+4>>2]|0,P)|0)/(I|0)|0)+(fa<<O)|0;da=((ka&Q)<<J)+(la&Q)|0;ea=((ga&Q)<<J)+(ha&Q)|0;ma=(c[V>>2]|0)+((ba<<3&8)+(ca(fa,W)|0))|0;if(X){fa=(c[R>>2]|0)+((ca(ka>>1,S)|0)+(la>>1))|0;mf[c[(c[Y>>2]|0)+16+(da<<2)>>2]&2047](ma,fa,S,8);fa=(c[_>>2]|0)+((ca(ga>>1,S)|0)+(ha>>1))|0;mf[c[(c[Z>>2]|0)+16+(ea<<2)>>2]&2047](ma,fa,S,8)}else{fa=(c[R>>2]|0)+((ca(ka>>2,S)|0)+(la>>2))|0;ef[c[(c[$>>2]|0)+64+(da<<2)>>2]&4095](ma,fa,S);fa=(c[_>>2]|0)+((ca(ga>>2,S)|0)+(ha>>2))|0;ef[c[(c[aa>>2]|0)+64+(ea<<2)>>2]&4095](ma,fa,S)}ba=ba+1|0;}while((ba|0)<4)}else{ba=0;do{O=(c[a+12160+(ba<<3)>>2]|0)+T|0;P=(c[a+12160+(ba<<3)+4>>2]|0)+K|0;U=O-(c[a+12128+(ba<<3)>>2]|0)|0;fa=P-(c[a+12128+(ba<<3)+4>>2]|0)|0;ma=((P&Q)<<J)+(O&Q)|0;ea=((fa&Q)<<J)+(U&Q)|0;ha=(c[V>>2]|0)+((ba<<3&8)+(ca(ba>>1,W)|0))|0;if(X){ga=(c[R>>2]|0)+((ca(P>>1,S)|0)+(O>>1))|0;mf[c[(c[Y>>2]|0)+16+(ma<<2)>>2]&2047](ha,ga,S,8);ga=(c[_>>2]|0)+((ca(fa>>1,S)|0)+(U>>1))|0;mf[c[(c[Z>>2]|0)+16+(ea<<2)>>2]&2047](ha,ga,S,8)}else{ga=(c[R>>2]|0)+((ca(P>>2,S)|0)+(O>>2))|0;ef[c[(c[$>>2]|0)+64+(ma<<2)>>2]&4095](ha,ga,S);ga=(c[_>>2]|0)+((ca(fa>>2,S)|0)+(U>>2))|0;ef[c[(c[aa>>2]|0)+64+(ea<<2)>>2]&4095](ha,ga,S)}ba=ba+1|0;}while((ba|0)<4)}}else{ba=(c[a+12160>>2]|0)+T|0;aa=(c[a+12164>>2]|0)+K|0;_=c[a+12128>>2]|0;if((T|0)==0){na=(ca(_,L-I|0)|0)/(I|0)|0}else{na=ba-_|0}_=c[a+12132>>2]|0;if((K|0)==0){oa=(ca(_,L-I|0)|0)/(I|0)|0}else{oa=aa-_|0}_=((aa&Q)<<J)+(ba&Q)|0;$=((oa&Q)<<J)+(na&Q)|0;if((H|0)==0){Z=a+12208|0;Y=(c[R>>2]|0)+((ca(aa>>1,S)|0)+(ba>>1))|0;mf[c[(c[a+12444>>2]|0)+(_<<2)>>2]&2047](c[Z>>2]|0,Y,S,16);Y=(c[a+12352+(i<<4)+32>>2]|0)+((ca(oa>>1,S)|0)+(na>>1))|0;mf[c[(c[a+12448>>2]|0)+($<<2)>>2]&2047](c[Z>>2]|0,Y,S,16);break}else{Y=a+12452|0;Z=a+12208|0;X=(ca(aa>>2,S)|0)+(ba>>2)|0;ef[c[(c[Y>>2]|0)+64+(_<<2)>>2]&4095](c[Z>>2]|0,(c[R>>2]|0)+X|0,S);ba=X+8|0;ef[c[(c[Y>>2]|0)+64+(_<<2)>>2]&4095]((c[Z>>2]|0)+8|0,(c[R>>2]|0)+ba|0,S);aa=S<<3;ef[c[(c[Y>>2]|0)+64+(_<<2)>>2]&4095]((c[Z>>2]|0)+aa|0,(c[R>>2]|0)+(X+aa)|0,S);X=aa+8|0;ef[c[(c[Y>>2]|0)+64+(_<<2)>>2]&4095]((c[Z>>2]|0)+X|0,(c[R>>2]|0)+(ba+aa)|0,S);ba=a+12456|0;_=a+12352+(i<<4)+32|0;Y=(ca(oa>>2,S)|0)+(na>>2)|0;ef[c[(c[ba>>2]|0)+64+($<<2)>>2]&4095](c[Z>>2]|0,(c[_>>2]|0)+Y|0,S);W=Y+8|0;ef[c[(c[ba>>2]|0)+64+($<<2)>>2]&4095]((c[Z>>2]|0)+8|0,(c[_>>2]|0)+W|0,S);ef[c[(c[ba>>2]|0)+64+($<<2)>>2]&4095]((c[Z>>2]|0)+aa|0,(c[_>>2]|0)+(Y+aa)|0,S);ef[c[(c[ba>>2]|0)+64+($<<2)>>2]&4095]((c[Z>>2]|0)+X|0,(c[_>>2]|0)+(W+aa)|0,S);break}}}while(0);N=Xe[z&511](a,c[a+12208>>2]|0,c[M>>2]|0,S,16)|0}}while(0);if(!((m|l|0)!=0|(j|0)>0)){G=N;break}G=(ca((d[v+(p-x)|0]|0)+(d[v+(o-w)|0]|0)|0,n)|0)+N|0}}while(0);if(!((l|0)>(r|0)&(l|0)<(t|0)&(m|0)>(s|0)&(m|0)<(u|0))){C=G;D=p;E=o;c[b>>2]=E;c[f>>2]=D;return C|0}u=(m<<3)+l|0;s=v+(o-w)|0;t=d[s]|0;r=c[a+12232>>2]|0;N=(ca((d[v+(p-2-x)|0]|0)+t|0,r)|0)+(c[q+((u+56&63)<<2)>>2]|0)|0;na=v+(p-x)|0;oa=d[na]|0;ia=(ca(oa+(d[v+(o-2-w)|0]|0)|0,r)|0)+(c[q+((u+63&63)<<2)>>2]|0)|0;ja=(ca((d[v+(o+2-w)|0]|0)+oa|0,r)|0)+(c[q+((u+1&63)<<2)>>2]|0)|0;oa=(ca((d[v+(p+2-x)|0]|0)+t|0,r)|0)+(c[q+((u+8&63)<<2)>>2]|0)|0;if((N|0)>(oa|0)){if((ia|0)>(ja|0)){if((ja+N|0)>(oa+ia|0)){u=l-1|0;q=u<<1|1;r=p|1;t=yrb(a,u,m,1,1,j,k,i,h,z,B,y)|0;u=v+(r-x)|0;A=(ca((d[u]|0)+(d[v+(q-w)|0]|0)|0,n)|0)+t|0;t=(A|0)<(G|0);g=o|1;pa=t?A:G;qa=t?q:o;ra=t?r:p;sa=g;ta=v+(g-w)|0;ua=r;va=u}else{u=o|1;r=m-1|0;g=r<<1|1;t=yrb(a,l,r,1,1,j,k,i,h,z,B,y)|0;r=v+(u-w)|0;q=(ca((d[v+(g-x)|0]|0)+(d[r]|0)|0,n)|0)+t|0;t=(q|0)<(G|0);A=p|1;pa=t?q:G;qa=t?u:o;ra=t?g:p;sa=u;ta=r;ua=A;va=v+(A-x)|0}A=yrb(a,l,m,1,0,j,k,i,h,z,B,y)|0;r=(ca((d[na]|0)+(d[ta]|0)|0,n)|0)+A|0;A=(r|0)<(pa|0);u=A?r:pa;pa=yrb(a,l,m,1,1,j,k,i,h,z,B,y)|0;r=(ca((d[va]|0)+(d[ta]|0)|0,n)|0)+pa|0;pa=(r|0)<(u|0);wa=pa?r:u;xa=pa?sa:A?sa:qa;ya=pa?ua:A?p:ra}else{if((ia+N|0)>(oa+ja|0)){ra=o|1;A=p|1;ua=yrb(a,l,m,1,1,j,k,i,h,z,B,y)|0;pa=v+(A-x)|0;qa=(ca((d[pa]|0)+(d[v+(ra-w)|0]|0)|0,n)|0)+ua|0;ua=(qa|0)<(G|0);sa=l-1|0;u=sa<<1|1;za=ua?qa:G;Aa=ua?ra:o;Ba=ua?A:p;Ca=sa;Da=u;Ea=v+(u-w)|0;Fa=A;Ga=pa}else{pa=l-1|0;A=pa<<1|1;u=m-1|0;sa=u<<1|1;ua=yrb(a,pa,u,1,1,j,k,i,h,z,B,y)|0;u=v+(A-w)|0;ra=(ca((d[v+(sa-x)|0]|0)+(d[u]|0)|0,n)|0)+ua|0;ua=(ra|0)<(G|0);qa=p|1;za=ua?ra:G;Aa=ua?A:o;Ba=ua?sa:p;Ca=pa;Da=A;Ea=u;Fa=qa;Ga=v+(qa-x)|0}qa=yrb(a,Ca,m,1,0,j,k,i,h,z,B,y)|0;u=(ca((d[na]|0)+(d[Ea]|0)|0,n)|0)+qa|0;qa=(u|0)<(za|0);A=qa?u:za;za=yrb(a,Ca,m,1,1,j,k,i,h,z,B,y)|0;Ca=(ca((d[Ga]|0)+(d[Ea]|0)|0,n)|0)+za|0;za=(Ca|0)<(A|0);wa=za?Ca:A;xa=za?Da:qa?Da:Aa;ya=za?Fa:qa?p:Ba}Ba=p|1;qa=yrb(a,l,m,0,1,j,k,i,h,z,B,y)|0;Fa=(ca((d[v+(Ba-x)|0]|0)+(d[s]|0)|0,n)|0)+qa|0;qa=(Fa|0)<(wa|0);C=qa?Fa:wa;D=qa?Ba:ya;E=qa?o:xa;c[b>>2]=E;c[f>>2]=D;return C|0}else{xa=m-1|0;qa=xa<<1|1;ya=yrb(a,l,xa,0,1,j,k,i,h,z,B,y)|0;Ba=v+(qa-x)|0;wa=(ca((d[Ba]|0)+(d[s]|0)|0,n)|0)+ya|0;ya=(wa|0)<(G|0);s=ya?qa:p;Fa=ya?wa:G;if((ia|0)>(ja|0)){G=o|1;wa=yrb(a,l,xa,1,1,j,k,i,h,z,B,y)|0;ya=v+(G-w)|0;za=(ca((d[Ba]|0)+(d[ya]|0)|0,n)|0)+wa|0;wa=(za|0)<(Fa|0);Aa=wa?qa:s;Da=wa?G:o;A=wa?za:Fa;if((ia+N|0)>(oa+ja|0)){za=p|1;wa=yrb(a,l,m,1,1,j,k,i,h,z,B,y)|0;Ca=(ca((d[v+(za-x)|0]|0)+(d[ya]|0)|0,n)|0)+wa|0;wa=(Ca|0)<(A|0);Ha=wa?Ca:A;Ia=wa?G:Da;Ja=wa?za:Aa}else{za=l-1|0;wa=za<<1|1;Ca=yrb(a,za,xa,1,1,j,k,i,h,z,B,y)|0;za=(ca((d[Ba]|0)+(d[v+(wa-w)|0]|0)|0,n)|0)+Ca|0;Ca=(za|0)<(A|0);Ha=Ca?za:A;Ia=Ca?wa:Da;Ja=Ca?qa:Aa}Aa=yrb(a,l,m,1,0,j,k,i,h,z,B,y)|0;Ca=(ca((d[na]|0)+(d[ya]|0)|0,n)|0)+Aa|0;Aa=(Ca|0)<(Ha|0);C=Aa?Ca:Ha;D=Aa?p:Ja;E=Aa?G:Ia;c[b>>2]=E;c[f>>2]=D;return C|0}else{Ia=l-1|0;G=Ia<<1|1;Aa=yrb(a,Ia,xa,1,1,j,k,i,h,z,B,y)|0;Ja=v+(G-w)|0;Ha=(ca((d[Ba]|0)+(d[Ja]|0)|0,n)|0)+Aa|0;Aa=(Ha|0)<(Fa|0);Ca=Aa?qa:s;s=Aa?G:o;ya=Aa?Ha:Fa;if((ja+N|0)>(oa+ia|0)){ia=p|1;oa=yrb(a,Ia,m,1,1,j,k,i,h,z,B,y)|0;N=(ca((d[v+(ia-x)|0]|0)+(d[Ja]|0)|0,n)|0)+oa|0;oa=(N|0)<(ya|0);Ka=oa?N:ya;La=oa?G:s;Ma=oa?ia:Ca}else{ia=o|1;o=yrb(a,l,xa,1,1,j,k,i,h,z,B,y)|0;xa=(ca((d[Ba]|0)+(d[v+(ia-w)|0]|0)|0,n)|0)+o|0;o=(xa|0)<(ya|0);Ka=o?xa:ya;La=o?ia:s;Ma=o?qa:Ca}Ca=yrb(a,Ia,m,1,0,j,k,i,h,z,B,y)|0;y=(ca((d[na]|0)+(d[Ja]|0)|0,n)|0)+Ca|0;Ca=(y|0)<(Ka|0);C=Ca?y:Ka;D=Ca?p:Ma;E=Ca?G:La;c[b>>2]=E;c[f>>2]=D;return C|0}}return 0}function crb(a,b,e,f,g,h,i,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;k=c[a+12236>>2]|0;l=c[a+12416>>2]|0;m=c[a+12220>>2]|0;n=c[a+12464>>2]|0;o=c[a+12280>>2]|0;p=c[a+12284>>2]|0;if((c[a+12124>>2]|0)!=0){q=f;r=0;s=0;c[b>>2]=s;c[e>>2]=r;return q|0}t=c[a+12288+(g<<4)>>2]|0;g=c[b>>2]|0;u=c[e>>2]|0;v=c[a+12352+(h<<4)>>2]|0;h=(ca(u,l)|0)+g|0;if(!((g|0)>(c[a+12264>>2]|0)&(g|0)<(c[a+12268>>2]|0)&(u|0)>(c[a+12272>>2]|0)&(u|0)<(c[a+12276>>2]|0))){q=f;r=u<<1;s=g<<1;c[b>>2]=s;c[e>>2]=r;return q|0}w=(u<<3)+g|0;x=c[m+((w+56&63)<<2)>>2]|0;y=c[m+((w+63&63)<<2)>>2]|0;z=c[m+((w+1&63)<<2)>>2]|0;A=c[m+((w+8&63)<<2)>>2]|0;w=g<<1;g=u<<1;u=w+o|0;o=g+p|0;p=h-l|0;m=v+p|0;do{if((x|0)>(A|0)){if((y|0)>(z|0)){B=a+11096+(i<<4)+12|0;C=c[B>>2]|0;if((z+x|0)>(A+y|0)){D=Xe[C&511](0,t,v+(h-1)|0,l,j)|0;E=n+(o+1)|0;F=(ca((d[E]|0)+(d[n+(u-1)|0]|0)|0,k)|0)+D|0;D=(F|0)<(f|0);G=D?F:f;H=D<<31>>31;I=D&1;J=n+(u+1)|0;K=E}else{E=Xe[C&511](0,t,m,l,j)|0;C=n+(u+1)|0;D=(ca((d[n+(o-1)|0]|0)+(d[C]|0)|0,k)|0)+E|0;E=(D|0)<(f|0);G=E?D:f;H=E&1;I=E<<31>>31;J=C;K=n+(o+1)|0}C=v+h|0;E=Xe[c[a+11096+(i<<4)+4>>2]&511](0,t,C,l,j)|0;D=(ca((d[n+o|0]|0)+(d[J]|0)|0,k)|0)+E|0;E=(D|0)<(G|0);F=E?D:G;D=Xe[c[B>>2]&511](0,t,C,l,j)|0;B=(ca((d[K]|0)+(d[J]|0)|0,k)|0)+D|0;D=(B|0)<(F|0);L=D?B:F;M=C;N=D?1:E?1:H;O=D?1:E?0:I}else{if((y+x|0)>(A+z|0)){E=v+h|0;D=Xe[c[a+11096+(i<<4)+12>>2]&511](0,t,E,l,j)|0;C=n+(o+1)|0;F=(ca((d[C]|0)+(d[n+(u+1)|0]|0)|0,k)|0)+D|0;D=(F|0)<(f|0);P=D?F:f;Q=E;R=D&1;S=n+(u-1)|0;T=C}else{C=Xe[c[a+11096+(i<<4)+12>>2]&511](0,t,v+(p-1)|0,l,j)|0;D=n+(u-1)|0;E=(ca((d[n+(o-1)|0]|0)+(d[D]|0)|0,k)|0)+C|0;C=(E|0)<(f|0);P=C?E:f;Q=v+h|0;R=C<<31>>31;S=D;T=n+(o+1)|0}D=Q-1|0;C=Xe[c[a+11096+(i<<4)+4>>2]&511](0,t,D,l,j)|0;E=(ca((d[n+o|0]|0)+(d[S]|0)|0,k)|0)+C|0;C=(E|0)<(P|0);F=C?E:P;E=Xe[c[a+11096+(i<<4)+12>>2]&511](0,t,D,l,j)|0;D=(ca((d[T]|0)+(d[S]|0)|0,k)|0)+E|0;E=(D|0)<(F|0);L=E?D:F;M=Q;N=E?-1:C?-1:R;O=E?1:C?0:R}C=Xe[c[a+11096+(i<<4)+8>>2]&511](0,t,M,l,j)|0;E=(ca((d[n+(o+1)|0]|0)+(d[n+u|0]|0)|0,k)|0)+C|0;C=(E|0)<(L|0);U=C?E:L;V=C?0:N;W=C?1:O}else{C=Xe[c[a+11096+(i<<4)+8>>2]&511](0,t,m,l,j)|0;E=n+(o-1)|0;F=(ca((d[E]|0)+(d[n+u|0]|0)|0,k)|0)+C|0;C=(F|0)<(f|0);D=C<<31>>31;B=C?F:f;F=a+11096+(i<<4)+12|0;C=c[F>>2]|0;if((y|0)>(z|0)){X=Xe[C&511](0,t,m,l,j)|0;Y=n+(u+1)|0;Z=(ca((d[E]|0)+(d[Y]|0)|0,k)|0)+X|0;X=(Z|0)<(B|0);_=X?-1:D;$=X&1;aa=X?Z:B;if((y+x|0)>(A+z|0)){Z=v+h|0;X=Xe[c[F>>2]&511](0,t,Z,l,j)|0;ba=(ca((d[n+(o+1)|0]|0)+(d[Y]|0)|0,k)|0)+X|0;X=(ba|0)<(aa|0);da=X?ba:aa;ea=Z;fa=X?1:$;ga=X?1:_}else{X=Xe[c[F>>2]&511](0,t,v+(p-1)|0,l,j)|0;Z=(ca((d[E]|0)+(d[n+(u-1)|0]|0)|0,k)|0)+X|0;X=(Z|0)<(aa|0);da=X?Z:aa;ea=v+h|0;fa=X?-1:$;ga=X?-1:_}_=Xe[c[a+11096+(i<<4)+4>>2]&511](0,t,ea,l,j)|0;X=(ca((d[n+o|0]|0)+(d[Y]|0)|0,k)|0)+_|0;_=(X|0)<(da|0);U=_?X:da;V=_?1:fa;W=_?0:ga;break}else{_=Xe[C&511](0,t,v+(p-1)|0,l,j)|0;C=n+(u-1)|0;X=(ca((d[E]|0)+(d[C]|0)|0,k)|0)+_|0;_=(X|0)<(B|0);Y=_?-1:D;D=_<<31>>31;$=_?X:B;B=c[F>>2]|0;if((z+x|0)>(A+y|0)){F=v+(h-1)|0;X=Xe[B&511](0,t,F,l,j)|0;_=(ca((d[n+(o+1)|0]|0)+(d[C]|0)|0,k)|0)+X|0;X=(_|0)<($|0);ha=X?_:$;ia=X?-1:D;ja=X?1:Y;ka=F}else{F=Xe[B&511](0,t,m,l,j)|0;B=(ca((d[E]|0)+(d[n+(u+1)|0]|0)|0,k)|0)+F|0;F=(B|0)<($|0);ha=F?B:$;ia=F?1:D;ja=F?-1:Y;ka=v+(h-1)|0}Y=Xe[c[a+11096+(i<<4)+4>>2]&511](0,t,ka,l,j)|0;F=(ca((d[n+o|0]|0)+(d[C]|0)|0,k)|0)+Y|0;Y=(F|0)<(ha|0);U=Y?F:ha;V=Y?-1:ia;W=Y?0:ja;break}}}while(0);q=U;r=W+g|0;s=V+w|0;c[b>>2]=s;c[e>>2]=r;return q|0}function drb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function erb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return}function frb(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[b>>2]=c[b>>2]<<1;c[d>>2]=c[d>>2]<<1;return e|0}function grb(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;h=i;i=i+96|0;j=h|0;k=h+8|0;l=h+16|0;m=c[e+13924>>2]|0;n=m+1|0;o=f<<4;p=g<<4;q=c[e+12416>>2]|0;r=(ca(q,p)|0)+o|0;s=c[e+12420>>2]|0;t=(ca(s,p)|0)+o>>1;u=e+12288|0;c[u>>2]=(c[e+5400>>2]|0)+r;v=e+12352|0;c[v>>2]=(c[e+952>>2]|0)+r;c[e+12292>>2]=(c[e+5404>>2]|0)+t;c[e+12356>>2]=(c[e+956>>2]|0)+t;c[e+12296>>2]=(c[e+5408>>2]|0)+t;c[e+12360>>2]=(c[e+960>>2]|0)+t;if(!(m>>>0<2>>>0)){KIb(0,0,2350336,(w=i,i=i+24|0,c[w>>2]=2288752,c[w+8>>2]=2238640,c[w+16>>2]=883,w)|0);i=w;Hd()}m=e+148|0;if((c[m>>2]|0)!=(q|0)){KIb(0,0,2350336,(w=i,i=i+24|0,c[w>>2]=2197856,c[w+8>>2]=2238640,c[w+16>>2]=884,w)|0);i=w;Hd()}if((c[e+152>>2]|0)!=(s|0)){KIb(0,0,2350336,(w=i,i=i+24|0,c[w>>2]=2166192,c[w+8>>2]=2238640,c[w+16>>2]=885,w)|0);i=w;Hd()}w=c[e+9968>>2]|0;s=e+9972|0;q=c[s>>2]|0;t=e+12120|0;r=c[t>>2]|0;switch(c[r+232>>2]&255|0){case 3:{x=(w*3|0)>>8;break};case 11:{x=w>>5;break};case 5:{x=1;break};case 6:case 4:case 1:case 10:{x=q>>7;break};case 2:case 14:{x=w>>6;break};case 12:{x=w>>6;break};default:{x=w>>7}}c[e+12232>>2]=x;switch(c[r+236>>2]&255|0){case 12:{y=w>>6;break};case 11:{y=w>>5;break};case 5:{y=1;break};case 2:case 14:{y=w>>6;break};case 3:{y=(w*3|0)>>8;break};case 6:case 4:case 1:case 10:{y=q>>7;break};default:{y=w>>7}}c[e+12236>>2]=y;switch(c[r+240>>2]&255|0){case 2:case 14:{z=w>>6;break};case 3:{z=(w*3|0)>>8;break};case 5:{z=1;break};case 12:{z=w>>6;break};case 6:case 4:case 1:case 10:{z=q>>7;break};case 11:{z=w>>5;break};default:{z=w>>7}}w=e+12240|0;c[w>>2]=z;c[e+12464>>2]=(c[e+12460>>2]|0)+((c[e+11556>>2]|0)*8193|0)+4096;hrb(e,o,p);p=e+12124|0;c[p>>2]=0;o=c[u>>2]|0;u=We[c[e+10100>>2]&2047](o,c[m>>2]|0)|0;z=(We[c[e+10104>>2]&2047](o,c[m>>2]|0)|0)-((ca(u,u)|0)>>>8)|0;q=z+500|0;r=u+128>>8;u=e+124|0;y=(ca(c[u>>2]|0,g)|0)+f|0;a[(c[e+9216>>2]|0)+y|0]=r;y=z+628>>8;x=(ca(c[u>>2]|0,g)|0)+f|0;b[(c[e+9192>>2]|0)+(x<<1)>>1]=y;x=e+12432|0;A=wrc(c[x>>2]|0,c[x+4>>2]|0,y,(y|0)<0|0?-1:0)|0;c[x>>2]=A;c[x+4>>2]=G;if(((c[e+11732>>2]|0)-5|0)>>>0<2>>>0){x=c[e+128>>2]|0;A=c[e+12496>>2]|0;y=A-1|0;B=c[e+9148>>2]|0;C=b[B+(y<<2)>>1]|0;D=l+8|0;c[D>>2]=C;E=b[B+(y<<2)+2>>1]|0;c[l+12>>2]=E;y=c[e+12268>>2]<<n;if((C|0)>(y|0)){c[D>>2]=y;F=y}else{F=C}do{if((c[e+14084>>2]|0)==0){C=A-x|0;y=b[B+(C<<2)>>1]|0;c[l+16>>2]=y;D=b[B+(C<<2)+2>>1]|0;H=l+20|0;c[H>>2]=D;I=C+2|0;C=b[B+(I<<2)>>1]|0;J=l+24|0;c[J>>2]=C;K=b[B+(I<<2)+2>>1]|0;I=l+28|0;c[I>>2]=K;L=c[e+12276>>2]<<n;if((D|0)>(L|0)){c[H>>2]=L;M=L}else{M=D}D=c[e+12264>>2]<<n;if((C|0)<(D|0)){c[J>>2]=D;N=D}else{N=C}if((K|0)>(L|0)){c[I>>2]=L;O=L}else{O=K}do{if((F|0)>(y|0)){if((N|0)<=(y|0)){P=y;break}P=(N|0)>(F|0)?F:N}else{if((y|0)<=(N|0)){P=y;break}P=(N|0)>(F|0)?N:F}}while(0);c[l+32>>2]=P;do{if((E|0)>(M|0)){if((O|0)<=(M|0)){Q=M;break}Q=(O|0)>(E|0)?E:O}else{if((M|0)<=(O|0)){Q=M;break}Q=(O|0)>(E|0)?O:E}}while(0);c[l+36>>2]=Q;y=e+12280|0;if((c[e+28>>2]|0)==2){c[y>>2]=P;c[e+12284>>2]=Q;break}else{c[y>>2]=F;c[e+12284>>2]=E;break}}else{c[e+12280>>2]=F;c[e+12284>>2]=E}}while(0);E=_qb(e,j,k,l|0,0,0,c[e+11636>>2]|0,65536>>>(n>>>0),0,16)|0;R=E;S=c[k>>2]|0;T=c[j>>2]|0}else{c[j>>2]=0;c[k>>2]=0;R=0;S=0;T=0}E=c[m>>2]|0;l=(c[v>>2]|0)+((ca(E,S)|0)+T)|0;v=Xe[c[e+10132>>2]&511](0,o,l,E,16)|0;E=v+128>>8;l=(ca(c[u>>2]|0,g)|0)+f|0;b[(c[e+9200>>2]|0)+(l<<1)>>1]=E;l=e+12424|0;F=wrc(c[l>>2]|0,c[l+4>>2]|0,E,(E|0)<0|0?-1:0)|0;c[l>>2]=F;c[l+4>>2]=G;if((c[(c[t>>2]|0)+296>>2]|0)>0){l=(c[s>>2]|0)>>>7;F=(l*100|0)+z|0;E=v>>>0>F>>>0?F:v;F=(l*20|0)+z|0;if(E>>>0<255>>>0){U=(d[E+1303321|0]|0)-1>>4}else{do{if(E>>>0<4096>>>0){V=(d[1303320+(E>>>4)|0]|0)>>>2}else{if(E>>>0<16384>>>0){V=(d[1303320+(E>>>6)|0]|0)>>>1;break}if(E>>>0<65536>>>0){V=d[1303320+(E>>>8)|0]|0;break}else{l=E>>>16;Q=(l&65280|0)==0;P=((d[1359664+(Q?l:E>>>24)|0]|0)+(Q?0:8)|0)>>>1;Q=E>>>((P+2|0)>>>0);l=d[1303320+(Q>>>((P+8|0)>>>0))|0]|0;Erc(Q,0,c[1367848+(l<<2)>>2]|0,0)|0;V=G+(l<<P)|0;break}}}while(0);U=V-((ca(V,V)|0)>>>0>E>>>0)|0}if(F>>>0<255>>>0){W=(d[F+1303321|0]|0)-1>>4}else{do{if(F>>>0<4096>>>0){X=(d[1303320+(F>>>4)|0]|0)>>>2}else{if(F>>>0<16384>>>0){X=(d[1303320+(F>>>6)|0]|0)>>>1;break}if(F>>>0<65536>>>0){X=d[1303320+(F>>>8)|0]|0;break}else{E=F>>>16;V=(E&65280|0)==0;P=((d[1359664+(V?E:F>>>24)|0]|0)+(V?0:8)|0)>>>1;V=F>>>((P+2|0)>>>0);E=d[1303320+(V>>>((P+8|0)>>>0))|0]|0;Erc(V,0,c[1367848+(E<<2)>>2]|0,0)|0;X=G+(E<<P)|0;break}}}while(0);W=X-((ca(X,X)|0)>>>0>F>>>0)|0}F=e+12440|0;c[F>>2]=U-W+(c[F>>2]|0);F=((v<<1)+51200|0)>(q|0)|0;do{if(((q<<1)+51200|0)>(v|0)){Y=77}else{if((c[e+9960>>2]|0)>24){Y=77;break}c[j>>2]=T<<n;c[k>>2]=S<<n;Z=F;_=c[e+60>>2]|0}}while(0);do{if((Y|0)==77){S=F|2;gf[c[e+12468>>2]&63](e,j,k,R,0,0,0,16)|0;T=c[e+60>>2]|0;if((T&64|0)==0){Z=S;_=T;break}if((c[j>>2]|0)==0){if((c[k>>2]|0)==0){Z=S;_=T;break}}Z=F|10;_=T}}while(0);F=e+60|0;do{if((_&4|0)==0){Y=85}else{if(!((c[p>>2]|0)==0&(q|0)>12800&(v|0)>2560)){Y=85;break}T=(irb(e,c[j>>2]|0,c[k>>2]|0,n)|0)==2147483647;S=c[j>>2]|0;W=c[k>>2]|0;U=(ca(c[u>>2]|0,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;X=c[e+11636>>2]|0;b[X+(U<<2)>>1]=S;b[X+(U<<2)+2>>1]=W;$=T?Z:Z|4;aa=S;ba=W}}while(0);if((Y|0)==85){Y=c[j>>2]|0;_=c[k>>2]|0;W=(ca(c[u>>2]|0,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;S=Y&65535;T=c[e+11636>>2]|0;b[T+(W<<2)>>1]=S;U=_&65535;b[T+(W<<2)+2>>1]=U;W=c[e+12496>>2]|0;T=c[e+9148>>2]|0;b[T+(W<<2)>>1]=S;b[T+(W<<2)+2>>1]=U;X=W+1|0;b[T+(X<<2)>>1]=S;b[T+(X<<2)+2>>1]=U;X=(c[e+128>>2]|0)+W|0;b[T+(X<<2)>>1]=S;b[T+(X<<2)+2>>1]=U;W=X+1|0;b[T+(W<<2)>>1]=S;b[T+(W<<2)+2>>1]=U;$=Z;aa=Y;ba=_}_=$&65535;if((c[F>>2]&536870912|0)==0){da=_;ea=c[u>>2]|0;fa=ca(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}if((c[p>>2]|0)!=0){da=_;ea=c[u>>2]|0;fa=ca(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}if((jrb(e,0,e+11660|0,e+11708|0,aa,ba)|0)==2147483647){da=_;ea=c[u>>2]|0;fa=ca(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}da=($|256)&65535;ea=c[u>>2]|0;fa=ca(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}$=gf[c[e+12468>>2]&63](e,j,k,R,0,0,0,16)|0;R=c[t>>2]|0;do{if((c[R+236>>2]|0)==(c[R+240>>2]|0)){ka=$}else{if((c[p>>2]|0)!=0){ka=$;break}ka=Zqb(e,c[j>>2]|0,c[k>>2]|0,0,0,0,16,1)|0}}while(0);$=e+60|0;R=c[$>>2]|0;do{if((R&4|0)==0){la=ka;ma=2;na=R}else{if(!((c[p>>2]|0)==0&(q|0)>12800&(v|0)>2560)){la=ka;ma=2;na=R;break}_=irb(e,c[j>>2]|0,c[k>>2]|0,n)|0;ba=(_|0)<(ka|0);la=ba?_:ka;ma=ba?4:2;na=c[$>>2]|0}}while(0);do{if((na&536870912|0)==0){oa=la;pa=ma}else{if((c[p>>2]|0)!=0){oa=la;pa=ma;break}$=jrb(e,0,e+11660|0,e+11708|0,c[j>>2]|0,c[k>>2]|0)|0;ka=($|0)<(la|0);oa=ka?$:la;pa=ka?256:ma}}while(0);ma=c[k>>2]|0;k=c[u>>2]|0;la=(ca(k,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;p=c[j>>2]&65535;j=c[e+11636>>2]|0;b[j+(la<<2)>>1]=p;na=ma&65535;b[j+(la<<2)+2>>1]=na;if((pa|0)!=4){la=c[e+12496>>2]|0;j=c[e+9148>>2]|0;b[j+(la<<2)>>1]=p;b[j+(la<<2)+2>>1]=na;ma=la+1|0;b[j+(ma<<2)>>1]=p;b[j+(ma<<2)+2>>1]=na;ma=(c[e+128>>2]|0)+la|0;b[j+(ma<<2)>>1]=p;b[j+(ma<<2)+2>>1]=na;la=ma+1|0;b[j+(la<<2)>>1]=p;b[j+(la<<2)+2>>1]=na}if((c[(c[t>>2]|0)+240>>2]&255|0)==1){qa=z;ra=k}else{k=ca(r,16843009)|0;r=c[e+12192>>2]|0;t=0;do{c[r+(ca(c[m>>2]|0,t)|0)>>2]=k;c[r+((ca(c[m>>2]|0,t)|0)+4)>>2]=k;c[r+((ca(c[m>>2]|0,t)|0)+8)>>2]=k;c[r+((ca(c[m>>2]|0,t)|0)+12)>>2]=k;t=t+1|0;}while((t|0)<16);t=Xe[c[e+10516>>2]&511](e,r,o,c[m>>2]|0,16)|0;qa=t;ra=c[u>>2]|0}t=(ca(ra,g)|0)+f|0;ra=(c[e+9160>>2]|0)+(t<<2)|0;if(((c[w>>2]<<4)+qa|0)<(oa|0)){c[ra>>2]=1;sa=1}else{c[ra>>2]=0;sa=pa&65535}pa=(c[s>>2]|0)>>>7;s=(pa*100|0)+z|0;ra=v>>>0>s>>>0?s:v;v=(pa*20|0)+z|0;if(ra>>>0<255>>>0){ta=(d[ra+1303321|0]|0)-1>>4}else{do{if(ra>>>0<4096>>>0){ua=(d[1303320+(ra>>>4)|0]|0)>>>2}else{if(ra>>>0<16384>>>0){ua=(d[1303320+(ra>>>6)|0]|0)>>>1;break}if(ra>>>0<65536>>>0){ua=d[1303320+(ra>>>8)|0]|0;break}else{z=ra>>>16;pa=(z&65280|0)==0;s=((d[1359664+(pa?z:ra>>>24)|0]|0)+(pa?0:8)|0)>>>1;pa=ra>>>((s+2|0)>>>0);z=d[1303320+(pa>>>((s+8|0)>>>0))|0]|0;Erc(pa,0,c[1367848+(z<<2)>>2]|0,0)|0;ua=G+(z<<s)|0;break}}}while(0);ta=ua-((ca(ua,ua)|0)>>>0>ra>>>0)|0}if(v>>>0<255>>>0){va=(d[v+1303321|0]|0)-1>>4}else{do{if(v>>>0<4096>>>0){wa=(d[1303320+(v>>>4)|0]|0)>>>2}else{if(v>>>0<16384>>>0){wa=(d[1303320+(v>>>6)|0]|0)>>>1;break}if(v>>>0<65536>>>0){wa=d[1303320+(v>>>8)|0]|0;break}else{ra=v>>>16;ua=(ra&65280|0)==0;s=((d[1359664+(ua?ra:v>>>24)|0]|0)+(ua?0:8)|0)>>>1;ua=v>>>((s+2|0)>>>0);ra=d[1303320+(ua>>>((s+8|0)>>>0))|0]|0;Erc(ua,0,c[1367848+(ra<<2)>>2]|0,0)|0;wa=G+(ra<<s)|0;break}}}while(0);va=wa-((ca(wa,wa)|0)>>>0>v>>>0)|0}v=e+12440|0;c[v>>2]=ta-va+(c[v>>2]|0);da=sa;ea=c[u>>2]|0;fa=ca(ea,g)|0;ga=fa+f|0;ha=e+12492|0;ia=c[ha>>2]|0;ja=ia+(ga<<1)|0;b[ja>>1]=da;i=h;return}function hrb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=-d|0;f=-b|0;g=(c[a+12244>>2]&1)+1|0;h=c[(c[a+12120>>2]|0)+276>>2]>>g;i=4096>>>(g>>>0);do{if((c[a+10048>>2]|0)==0){if((c[a+28>>2]|0)==1){g=(b|0)>15?-15:0;c[a+12264>>2]=g;j=(d|0)>15?-15:0;c[a+12272>>2]=j;k=((c[a+116>>2]<<4)-16|0)>(b|0)?15:0;c[a+12268>>2]=k;l=((c[a+120>>2]<<4)-16|0)>(d|0)?15:0;c[a+12276>>2]=l;m=g;n=k;o=j;p=l;break}else{c[a+12264>>2]=f;c[a+12272>>2]=e;l=-16-b+(c[a+116>>2]<<4)|0;c[a+12268>>2]=l;j=-16-d+(c[a+120>>2]<<4)|0;c[a+12276>>2]=j;m=f;n=l;o=e;p=j;break}}else{j=-16-b|0;c[a+12264>>2]=j;l=-16-d|0;c[a+12272>>2]=l;k=(c[a+8>>2]|0)-b|0;c[a+12268>>2]=k;g=(c[a+12>>2]|0)-d|0;c[a+12276>>2]=g;m=j;n=k;o=l;p=g}}while(0);d=(h|0)==0|(h|0)>(i|0)?i:h;if((d|0)==0){return}h=-d|0;c[a+12264>>2]=(m|0)>(h|0)?m:h;c[a+12268>>2]=(n|0)>(d|0)?d:n;c[a+12272>>2]=(o|0)>(h|0)?o:h;c[a+12276>>2]=(p|0)>(d|0)?d:p;return}function irb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;h=i;i=i+96|0;j=h|0;k=h+80|0;l=h+88|0;m=c[a+12416>>2]|0;n=c[a+12464>>2]|0;o=a+8|0;do{if((c[a+10048>>2]|0)==0){p=0}else{if((c[o>>2]&15|0)==0){p=0;break}p=(c[a+12>>2]&15|0)!=0}}while(0);q=c[a+12352>>2]|0;c[a+12368>>2]=q+8;r=m<<3;c[a+12384>>2]=q+r;s=r+8|0;c[a+12400>>2]=q+s;q=c[a+12288>>2]|0;c[a+12304>>2]=q+8;c[a+12320>>2]=q+r;c[a+12336>>2]=q+s;s=a+128|0;q=a+12476|0;r=a+12268|0;t=a+12480|0;u=a+12|0;v=a+12276|0;w=a+9148|0;x=j+8|0;y=j+12|0;z=a+14084|0;A=a+12280|0;B=a+12284|0;C=j+72|0;D=j+76|0;E=j|0;F=a+11636|0;G=65536>>>(g>>>0);H=a+12468|0;I=a+10492|0;J=a+10516|0;K=a+13924|0;L=a+12192|0;M=a+12472|0;N=a+12240|0;O=j+16|0;P=j+20|0;Q=j+24|0;R=j+28|0;S=a+12264|0;T=j+32|0;U=j+36|0;V=1;W=0;X=0;Y=0;Z=0;do{_=c[s>>2]|0;$=a+12496+(Z<<2)|0;aa=c[$>>2]|0;if(p){ba=(c[o>>2]|0)-(Z<<3&8)+((c[q>>2]|0)*-16|0)|0;c[r>>2]=ba;c[v>>2]=(c[u>>2]|0)-(Z>>1<<3)+((c[t>>2]|0)*-16|0);da=ba}else{da=c[r>>2]|0}ba=aa-1|0;ea=c[w>>2]|0;fa=b[ea+(ba<<2)>>1]|0;c[x>>2]=fa;ga=b[ea+(ba<<2)+2>>1]|0;c[y>>2]=ga;ba=da<<g;if((fa|0)>(ba|0)){c[x>>2]=ba;ha=ba}else{ha=fa}if((c[z>>2]|0)!=0&(Z|0)<2){ia=ga;ja=ha}else{fa=aa-_|0;_=b[ea+(fa<<2)>>1]|0;c[O>>2]=_;aa=b[ea+(fa<<2)+2>>1]|0;c[P>>2]=aa;ka=(c[1145792+(Z<<2)>>2]|0)+fa|0;fa=b[ea+(ka<<2)>>1]|0;c[Q>>2]=fa;la=b[ea+(ka<<2)+2>>1]|0;c[R>>2]=la;ka=c[v>>2]<<g;if((aa|0)>(ka|0)){c[P>>2]=ka;ma=ka}else{ma=aa}aa=c[S>>2]<<g;if((fa|0)<(aa|0)){c[Q>>2]=aa;na=aa}else{na=fa}if((na|0)>(ba|0)){c[Q>>2]=ba;oa=ba}else{oa=na}if((la|0)>(ka|0)){c[R>>2]=ka;pa=ka}else{pa=la}do{if((ha|0)>(_|0)){if((oa|0)<=(_|0)){qa=_;break}qa=(oa|0)>(ha|0)?ha:oa}else{if((_|0)<=(oa|0)){qa=_;break}qa=(oa|0)>(ha|0)?oa:ha}}while(0);c[T>>2]=qa;do{if((ga|0)>(ma|0)){if((pa|0)<=(ma|0)){ra=ma;break}ra=(pa|0)>(ga|0)?ga:pa}else{if((ma|0)<=(pa|0)){ra=ma;break}ra=(pa|0)>(ga|0)?pa:ga}}while(0);c[U>>2]=ra;ia=ra;ja=qa}c[A>>2]=ja;c[B>>2]=ia;c[C>>2]=e;c[D>>2]=f;do{if(p){_=c[v>>2]<<g;la=j|0;if((c[la>>2]|0)>(ba|0)){c[la>>2]=ba}la=j+4|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}if((ha|0)>(ba|0)){c[x>>2]=ba}if((ga|0)>(_|0)){c[y>>2]=_}if((c[O>>2]|0)>(ba|0)){c[O>>2]=ba}if((c[P>>2]|0)>(_|0)){c[P>>2]=_}if((c[Q>>2]|0)>(ba|0)){c[Q>>2]=ba}if((c[R>>2]|0)>(_|0)){c[R>>2]=_}if((c[T>>2]|0)>(ba|0)){c[T>>2]=ba}if((c[U>>2]|0)>(_|0)){c[U>>2]=_}la=j+40|0;if((c[la>>2]|0)>(ba|0)){c[la>>2]=ba}la=j+44|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}la=j+48|0;if((c[la>>2]|0)>(ba|0)){c[la>>2]=ba}la=j+52|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}la=j+56|0;if((c[la>>2]|0)>(ba|0)){c[la>>2]=ba}la=j+60|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}la=j+64|0;if((c[la>>2]|0)>(ba|0)){c[la>>2]=ba}la=j+68|0;if((c[la>>2]|0)>(_|0)){c[la>>2]=_}if((ba|0)<(e|0)){c[C>>2]=ba}if((_|0)>=(f|0)){break}c[D>>2]=_}}while(0);ba=xrb(a,k,l,E,Z,Z,c[F>>2]|0,G)|0;ga=gf[c[H>>2]&63](a,k,l,ba,Z,Z,1,8)|0;if((c[I>>2]|0)==(c[J>>2]|0)){sa=ga;ta=c[k>>2]|0}else{ga=(ca(Z>>1,m)|0)+(Z&1)<<3;ba=(c[L>>2]|0)+ga|0;ga=c[a+12352+(Z<<4)>>2]|0;_=c[k>>2]|0;do{if((c[K>>2]|0)==0){la=c[l>>2]|0;ka=ga+((ca(la>>1,m)|0)+(_>>1))|0;fa=la<<1&2|_&1;if((c[M>>2]|0)==0){mf[c[a+11348+(fa<<2)>>2]&2047](ba,ka,m,8);break}else{mf[c[a+11476+(fa<<2)>>2]&2047](ba,ka,m,8);break}}else{ka=c[l>>2]|0;fa=ga+((ca(ka>>2,m)|0)+(_>>2))|0;la=ka<<2&12|_&3;if((c[M>>2]|0)==0){ef[c[a+10744+(la<<2)>>2]&4095](ba,fa,m);break}else{ef[c[a+11e3+(la<<2)>>2]&4095](ba,fa,m);break}}}while(0);ba=c[k>>2]|0;sa=ca((d[n+((c[l>>2]|0)-ia)|0]|0)+(d[n+(ba-ja)|0]|0)|0,c[N>>2]|0)|0;ta=ba}Y=sa+Y|0;if((c[K>>2]|0)==0){ba=c[l>>2]|0;ua=ta;va=ba;wa=ba}else{ba=c[l>>2]|0;ua=(ta|0)/2|0;va=(ba|0)/2|0;wa=ba}X=ua+X|0;W=va+W|0;ba=c[$>>2]|0;_=c[w>>2]|0;b[_+(ba<<2)>>1]=ta;b[_+(ba<<2)+2>>1]=wa;V=(ta|0)==(e|0)&(wa|0)==(f|0)?V:0;Z=Z+1|0;}while((Z|0)<4);if((V|0)!=0){xa=2147483647;i=h;return xa|0}V=c[J>>2]|0;if((c[I>>2]|0)==(V|0)){ya=Y}else{I=(c[a+5400>>2]|0)+((ca(c[t>>2]|0,m)|0)+(c[q>>2]|0)<<4)|0;ya=(Xe[V&511](a,I,c[L>>2]|0,m,16)|0)+Y|0}Y=a+12120|0;m=c[Y>>2]|0;if((c[m+240>>2]&256|0)==0){za=ya;Aa=m}else{m=(d[1378480+(X&15)|0]|0)+(X>>3)|0;X=(d[1378480+(W&15)|0]|0)+(W>>3)|0;W=X<<1&2|m&1;I=a+152|0;V=c[I>>2]|0;J=(c[q>>2]<<3)+(m>>1)+(ca((c[t>>2]<<3)+(X>>1)|0,V)|0)|0;if((c[M>>2]|0)==0){M=a+11348+(W<<2)|0;mf[c[M>>2]&2047](c[L>>2]|0,(c[a+956>>2]|0)+J|0,V,8);mf[c[M>>2]&2047]((c[L>>2]|0)+8|0,(c[a+960>>2]|0)+J|0,c[I>>2]|0,8)}else{M=a+11476+(W<<2)|0;mf[c[M>>2]&2047](c[L>>2]|0,(c[a+956>>2]|0)+J|0,V,8);mf[c[M>>2]&2047]((c[L>>2]|0)+8|0,(c[a+960>>2]|0)+J|0,c[I>>2]|0,8)}J=a+10520|0;M=a;V=c[I>>2]|0;W=(c[a+5404>>2]|0)+((ca(V,c[t>>2]|0)|0)+(c[q>>2]|0)<<3)|0;X=(Xe[c[J>>2]&511](M,W,c[L>>2]|0,V,8)|0)+ya|0;ya=c[I>>2]|0;I=(c[a+5408>>2]|0)+((ca(ya,c[t>>2]|0)|0)+(c[q>>2]|0)<<3)|0;q=X+(Xe[c[J>>2]&511](M,I,(c[L>>2]|0)+8|0,ya,8)|0)|0;za=q;Aa=c[Y>>2]|0}c[A>>2]=e;c[B>>2]=f;if((c[Aa+240>>2]&255|0)==6){xa=za;i=h;return xa|0}xa=((c[N>>2]|0)*11|0)+za|0;i=h;return xa|0}function jrb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;l=i;i=i+96|0;m=l|0;n=l+80|0;o=l+88|0;p=c[e+12464>>2]|0;q=c[e+148>>2]|0;r=q<<1;s=c[e+124>>2]|0;t=(ca(c[e+12480>>2]|0,s)|0)+(c[e+12476>>2]|0)|0;u=e+12272|0;c[u>>2]=c[u>>2]>>1;v=e+12276|0;c[v>>2]=c[v>>2]>>1;w=e+12416|0;c[w>>2]=c[w>>2]<<1;x=e+12420|0;c[x>>2]=c[x>>2]<<1;y=f+1|0;c[e+12352+(y<<4)>>2]=(c[e+12352+(f<<4)>>2]|0)+q;c[e+12304>>2]=(c[e+12288>>2]|0)+q;if((c[e+12244>>2]&2|0)!=0){q=e+152|0;z=c[q>>2]|0;c[e+12352+(y<<4)+4>>2]=(c[e+12352+(f<<4)+4>>2]|0)+z;c[e+12352+(y<<4)+8>>2]=(c[e+12352+(f<<4)+8>>2]|0)+z;z=c[q>>2]|0;c[e+12308>>2]=(c[e+12292>>2]|0)+z;c[e+12312>>2]=(c[e+12296>>2]|0)+z}z=t-1|0;q=m+8|0;y=m+12|0;A=e+12268|0;B=e+12280|0;C=e+12284|0;D=e+14084|0;E=t-s|0;s=m+16|0;F=m+20|0;G=E+1|0;H=m+24|0;I=m+28|0;J=e+12264|0;K=m+32|0;L=m+36|0;M=m+72|0;N=(k|0)/2|0;O=m+76|0;P=m|0;m=e+12468|0;Q=e+10492|0;R=e+10516|0;S=e+12240|0;T=e+12472|0;U=e+12192|0;V=e;W=0;X=1;Y=0;do{Z=e+12288+(Y<<4)|0;_=0;$=2147483647;aa=-1;do{ba=c[g+(Y<<3)+(_<<2)>>2]|0;da=b[ba+(z<<2)>>1]|0;c[q>>2]=da;ea=b[ba+(z<<2)+2>>1]|0;c[y>>2]=ea;fa=c[A>>2]<<1;if((da|0)>(fa|0)){c[q>>2]=fa;ga=fa}else{ga=da}c[B>>2]=ga;c[C>>2]=ea;if((c[D>>2]|0)==0){da=b[ba+(E<<2)>>1]|0;c[s>>2]=da;ha=b[ba+(E<<2)+2>>1]|0;c[F>>2]=ha;ia=b[ba+(G<<2)>>1]|0;c[H>>2]=ia;ja=b[ba+(G<<2)+2>>1]|0;c[I>>2]=ja;ka=c[v>>2]<<1;if((ha|0)>(ka|0)){c[F>>2]=ka;la=ka}else{la=ha}ha=c[J>>2]<<1;if((ia|0)<(ha|0)){c[H>>2]=ha;ma=ha}else{ma=ia}if((ma|0)>(fa|0)){c[H>>2]=fa;na=fa}else{na=ma}if((ja|0)>(ka|0)){c[I>>2]=ka;oa=ka}else{oa=ja}do{if((ga|0)>(da|0)){if((na|0)<=(da|0)){pa=da;break}pa=(na|0)>(ga|0)?ga:na}else{if((da|0)<=(na|0)){pa=da;break}pa=(na|0)>(ga|0)?na:ga}}while(0);c[K>>2]=pa;do{if((ea|0)>(la|0)){if((oa|0)<=(la|0)){qa=la;break}qa=(oa|0)>(ea|0)?ea:oa}else{if((la|0)<=(oa|0)){qa=la;break}qa=(oa|0)>(ea|0)?oa:ea}}while(0);c[L>>2]=qa}c[M>>2]=j;c[O>>2]=N;ea=_+f|0;da=srb(e,n,o,P,Y,ea,ba)|0;ja=gf[c[m>>2]&63](e,n,o,da,Y,ea,0,8)|0;da=c[n>>2]|0;b[ba+(t<<2)>>1]=da;ka=c[o>>2]|0;b[ba+(t<<2)+2>>1]=ka;if((c[Q>>2]|0)==(c[R>>2]|0)){ra=(c[S>>2]|0)+ja|0}else{ja=(c[e+12352+(ea<<4)>>2]|0)+((ca(ka>>1,r)|0)+(da>>1))|0;ea=ka<<1&2|da&1;if((c[T>>2]|0)==0){mf[c[e+11332+(ea<<2)>>2]&2047](c[U>>2]|0,ja,r,8)}else{mf[c[e+11460+(ea<<2)>>2]&2047](c[U>>2]|0,ja,r,8)}ja=Xe[c[R>>2]&511](V,c[Z>>2]|0,c[U>>2]|0,r,8)|0;ra=(ca((d[p+((c[n>>2]|0)-(c[B>>2]|0))|0]|0)+1+(d[p+((c[o>>2]|0)-(c[C>>2]|0))|0]|0)|0,c[S>>2]|0)|0)+ja|0}ja=ra+((_|0)!=(Y|0))|0;ea=(ja|0)<($|0);$=ea?ja:$;aa=ea?_:aa;_=_+1|0;}while((_|0)<2);_=c[g+(Y<<3)+(aa<<2)>>2]|0;Z=b[_+(t<<2)+2>>1]|0;X=(aa|0)==(Y|0)?(Z<<16>>16<<1|0)==(k|0)?(Z&1)==0?(b[_+(t<<2)>>1]|0)==(j|0)?X:0:0:0:0;a[(c[h+(Y<<2)>>2]|0)+t|0]=aa;W=$+W|0;Y=Y+1|0;}while((Y|0)<2);c[u>>2]=c[u>>2]<<1;c[v>>2]=c[v>>2]<<1;c[w>>2]=c[w>>2]>>1;c[x>>2]=c[x>>2]>>1;if((X|0)!=0){sa=2147483647;i=l;return sa|0}if((c[(c[e+12120>>2]|0)+240>>2]&255|0)==6){sa=W;i=l;return sa|0}sa=((c[S>>2]|0)*11|0)+W|0;i=l;return sa|0}function krb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;i=i+96|0;g=f|0;h=f+8|0;j=f+16|0;k=c[a+13924>>2]|0;l=k+1|0;m=a+124|0;n=(ca(c[m>>2]|0,e)|0)+d|0;o=d<<4;d=e<<4;e=(ca(c[a+12416>>2]|0,d)|0)+o|0;p=(ca(c[a+12420>>2]|0,d)|0)+o>>1;c[a+12288>>2]=(c[a+5400>>2]|0)+e;c[a+12352>>2]=(c[a+952>>2]|0)+e;c[a+12292>>2]=(c[a+5404>>2]|0)+p;c[a+12356>>2]=(c[a+956>>2]|0)+p;c[a+12296>>2]=(c[a+5408>>2]|0)+p;c[a+12360>>2]=(c[a+960>>2]|0)+p;if(!(k>>>0<2>>>0)){KIb(0,0,2350336,(k=i,i=i+24|0,c[k>>2]=2288752,c[k+8>>2]=2238640,c[k+16>>2]=1082,k)|0);i=k;Hd();return 0}k=c[a+9968>>2]|0;switch(c[(c[a+12120>>2]|0)+260>>2]&255|0){case 2:case 14:{q=k>>6;break};case 3:{q=(k*3|0)>>8;break};case 12:{q=k>>6;break};case 11:{q=k>>5;break};case 5:{q=1;break};case 6:case 4:case 1:case 10:{q=c[a+9972>>2]>>7;break};default:{q=k>>7}}c[a+12228>>2]=q;c[a+12464>>2]=(c[a+12460>>2]|0)+((c[a+11556>>2]|0)*8193|0)+4096;hrb(a,o,d);c[a+12124>>2]=0;d=n+1|0;o=a+11636|0;q=c[o>>2]|0;k=b[q+(d<<2)>>1]|0;p=j+8|0;c[p>>2]=k;e=b[q+(d<<2)+2>>1]|0;c[j+12>>2]=e;d=c[a+12264>>2]<<l;if((k|0)<(d|0)){c[p>>2]=d;r=d}else{r=k}if((c[a+14084>>2]|0)!=0){c[a+12280>>2]=r;c[a+12284>>2]=e;mrc(j+16|0,0,24)|0;s=j|0;t=65536>>>(l>>>0);u=_qb(a,g,h,s,0,0,q,t,0,16)|0;v=c[g>>2]|0;w=v<<l;x=w&65535;y=c[o>>2]|0;z=y+(n<<2)|0;b[z>>1]=x;A=c[h>>2]|0;B=A<<l;C=B&65535;D=y+(n<<2)+2|0;b[D>>1]=C;i=f;return u|0}k=c[m>>2]|0;m=k+n|0;d=b[q+(m<<2)>>1]|0;c[j+16>>2]=d;p=b[q+(m<<2)+2>>1]|0;m=j+20|0;c[m>>2]=p;E=n-1+k|0;k=b[q+(E<<2)>>1]|0;F=j+24|0;c[F>>2]=k;G=b[q+(E<<2)+2>>1]|0;E=j+28|0;c[E>>2]=G;H=c[a+12272>>2]<<l;if((p|0)<(H|0)){c[m>>2]=H;I=H}else{I=p}p=c[a+12268>>2]<<l;if((k|0)>(p|0)){c[F>>2]=p;J=p}else{J=k}if((G|0)<(H|0)){c[E>>2]=H;K=H}else{K=G}do{if((r|0)>(d|0)){if((J|0)<=(d|0)){L=d;break}L=(J|0)>(r|0)?r:J}else{if((d|0)<=(J|0)){L=d;break}L=(J|0)>(r|0)?J:r}}while(0);c[j+32>>2]=L;do{if((e|0)>(I|0)){if((K|0)<=(I|0)){M=I;break}M=(K|0)>(e|0)?e:K}else{if((I|0)<=(K|0)){M=I;break}M=(K|0)>(e|0)?K:e}}while(0);c[j+36>>2]=M;c[a+12280>>2]=L;c[a+12284>>2]=M;s=j|0;t=65536>>>(l>>>0);u=_qb(a,g,h,s,0,0,q,t,0,16)|0;v=c[g>>2]|0;w=v<<l;x=w&65535;y=c[o>>2]|0;z=y+(n<<2)|0;b[z>>1]=x;A=c[h>>2]|0;B=A<<l;C=B&65535;D=y+(n<<2)+2|0;b[D>>1]=C;i=f;return u|0}function lrb(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0;h=i;i=i+256|0;j=h|0;k=c[e+12240>>2]|0;l=e+124|0;m=(ca(c[l>>2]|0,g)|0)+f|0;n=f<<4;o=g<<4;p=(ca(c[e+12416>>2]|0,o)|0)+n|0;q=(ca(c[e+12420>>2]|0,o)|0)+n>>1;c[e+12288>>2]=(c[e+5400>>2]|0)+p;c[e+12352>>2]=(c[e+952>>2]|0)+p;c[e+12292>>2]=(c[e+5404>>2]|0)+q;c[e+12356>>2]=(c[e+956>>2]|0)+q;c[e+12296>>2]=(c[e+5408>>2]|0)+q;c[e+12360>>2]=(c[e+960>>2]|0)+q;c[e+12384>>2]=(c[e+3176>>2]|0)+p;c[e+12388>>2]=(c[e+3180>>2]|0)+q;c[e+12392>>2]=(c[e+3184>>2]|0)+q;hrb(e,n,o);o=e+12124|0;c[o>>2]=0;n=e+48|0;do{if((c[n>>2]|0)==13){q=(a[(c[e+4720>>2]|0)+m|0]|0)==0;p=mrb(e,f,g)|0;if(q){r=p;break}q=((ca(p,p)|0)+32768|0)>>>16;p=e+12424|0;s=wrc(q,0,c[p>>2]|0,c[p+4>>2]|0)|0;c[p>>2]=s;c[p+4>>2]=G;p=(ca(c[l>>2]|0,g)|0)+f|0;b[(c[e+9200>>2]|0)+(p<<1)>>1]=q;b[(c[e+12492>>2]|0)+(p<<1)>>1]=4096;i=h;return}else{r=2147483647}}while(0);c[o>>2]=0;p=e+11640|0;q=e+11556|0;s=(nrb(e,f,g,c[p>>2]|0,0,c[q>>2]|0)|0)+(k*3|0)|0;c[o>>2]=0;t=e+11644|0;u=e+11560|0;v=(nrb(e,f,g,c[t>>2]|0,2,c[u>>2]|0)|0)+(k<<1)|0;c[o>>2]=0;w=(ca(c[l>>2]|0,g)|0)+f|0;x=w-1|0;y=e+11648|0;z=c[y>>2]|0;A=b[z+(x<<2)>>1]|0;B=b[z+(x<<2)+2>>1]|0;C=e+11652|0;D=c[C>>2]|0;E=b[D+(x<<2)>>1]|0;F=b[D+(x<<2)+2>>1]|0;x=c[p>>2]|0;H=b[x+(w<<2)>>1]|0;b[z+(w<<2)>>1]=H;I=H<<16>>16;J=b[x+(w<<2)+2>>1]|0;b[z+(w<<2)+2>>1]=J;z=J<<16>>16;x=c[t>>2]|0;K=b[x+(w<<2)>>1]|0;b[D+(w<<2)>>1]=K;L=K<<16>>16;M=b[x+(w<<2)+2>>1]|0;b[D+(w<<2)+2>>1]=M;D=M<<16>>16;x=(c[e+12248>>2]&1)+1|0;N=c[e+12264>>2]<<x;O=c[e+12272>>2]<<x;P=c[e+12268>>2]<<x;Q=c[e+12276>>2]<<x;x=(z*17|0)+I+(L*63|0)+(D*117|0)|0;mrc(j|0,0,256)|0;a[j+(x&255)|0]=1;R=rrb(e,I,z,L,D,A,B,E,F)|0;S=c[(c[e+4>>2]|0)+352>>2]|0;if((S|0)==0){T=R;U=H;V=J;W=K;X=M}else{M=d[1953120+S|0]|0;K=S>>>0>1>>>0;S=R;R=I;I=z;z=L;L=D;D=x;while(1){x=D+117|0;J=j+(x&255)|0;do{if((a[J]|0)==0){H=L+1|0;if((H|0)>(Q|0)){Y=S;Z=L;_=D;$=1;break}a[J]=1;aa=rrb(e,R,I,z,H,A,B,E,F)|0;ba=(aa|0)<(S|0);Y=ba?aa:S;Z=ba?H:L;_=ba?x:D;$=ba&1^1}else{Y=S;Z=L;_=D;$=1}}while(0);x=_-117|0;J=j+(x&255)|0;do{if((a[J]|0)==0){ba=Z-1|0;if((ba|0)<(O|0)){da=Y;ea=Z;fa=_;ga=$;break}a[J]=1;H=rrb(e,R,I,z,ba,A,B,E,F)|0;aa=(H|0)<(Y|0);da=aa?H:Y;ea=aa?ba:Z;fa=aa?x:_;ga=aa?0:$}else{da=Y;ea=Z;fa=_;ga=$}}while(0);x=fa+63|0;J=j+(x&255)|0;do{if((a[J]|0)==0){aa=z+1|0;if((aa|0)>(P|0)){ha=da;ia=z;ja=fa;ka=ga;break}a[J]=1;ba=rrb(e,R,I,aa,ea,A,B,E,F)|0;H=(ba|0)<(da|0);ha=H?ba:da;ia=H?aa:z;ja=H?x:fa;ka=H?0:ga}else{ha=da;ia=z;ja=fa;ka=ga}}while(0);x=ja-63|0;J=j+(x&255)|0;do{if((a[J]|0)==0){H=ia-1|0;if((H|0)<(N|0)){la=ha;ma=ia;na=ja;oa=ka;break}a[J]=1;aa=rrb(e,R,I,H,ea,A,B,E,F)|0;ba=(aa|0)<(ha|0);la=ba?aa:ha;ma=ba?H:ia;na=ba?x:ja;oa=ba?0:ka}else{la=ha;ma=ia;na=ja;oa=ka}}while(0);x=na+17|0;J=j+(x&255)|0;do{if((a[J]|0)==0){ba=I+1|0;if((ba|0)>(Q|0)){pa=la;qa=I;ra=na;sa=oa;break}a[J]=1;H=rrb(e,R,ba,ma,ea,A,B,E,F)|0;aa=(H|0)<(la|0);pa=aa?H:la;qa=aa?ba:I;ra=aa?x:na;sa=aa?0:oa}else{pa=la;qa=I;ra=na;sa=oa}}while(0);x=ra-17|0;J=j+(x&255)|0;do{if((a[J]|0)==0){aa=qa-1|0;if((aa|0)<(O|0)){ta=pa;ua=qa;va=ra;wa=sa;break}a[J]=1;ba=rrb(e,R,aa,ma,ea,A,B,E,F)|0;H=(ba|0)<(pa|0);ta=H?ba:pa;ua=H?aa:qa;va=H?x:ra;wa=H?0:sa}else{ta=pa;ua=qa;va=ra;wa=sa}}while(0);x=va+1|0;J=j+(x&255)|0;do{if((a[J]|0)==0){H=R+1|0;if((H|0)>(P|0)){xa=ta;ya=R;za=va;Aa=wa;break}a[J]=1;aa=rrb(e,H,ua,ma,ea,A,B,E,F)|0;ba=(aa|0)<(ta|0);xa=ba?aa:ta;ya=ba?H:R;za=ba?x:va;Aa=ba?0:wa}else{xa=ta;ya=R;za=va;Aa=wa}}while(0);x=za-1|0;J=j+(x&255)|0;do{if((a[J]|0)==0){ba=ya-1|0;if((ba|0)<(N|0)){Ba=xa;Ca=ya;Da=za;Ea=Aa;break}a[J]=1;H=rrb(e,ba,ua,ma,ea,A,B,E,F)|0;aa=(H|0)<(xa|0);Ba=aa?H:xa;Ca=aa?ba:ya;Da=aa?x:za;Ea=aa?0:Aa}else{Ba=xa;Ca=ya;Da=za;Ea=Aa}}while(0);if(K){x=0;J=8;aa=Ea;ba=Da;H=ea;Fa=ma;Ga=ua;Ha=Ca;Ia=Ba;while(1){Ja=(a[1952800+(J<<2)|0]|0)+Ha|0;Ka=(a[1952801+(J<<2)|0]|0)+Ga|0;La=(a[1952802+(J<<2)|0]|0)+Fa|0;Ma=(a[1952803+(J<<2)|0]|0)+H|0;do{if((x|0)<1){Na=(Ja|0)>(La|0);Oa=(Ka|0)>(Ma|0);if((P-(Na?Ja:La)|(Na?La:Ja)-N|(Oa?Ma:Ka)-O|Q-(Oa?Ka:Ma)|0)>=0){break}a[j+((d[1953128+J|0]|0)+ba&255)|0]=1}}while(0);Oa=(d[1953128+J|0]|0)+ba|0;Na=j+(Oa&255)|0;do{if((a[Na]|0)==0){a[Na]=1;Pa=rrb(e,Ja,Ka,La,Ma,A,B,E,F)|0;if((Pa|0)>=(Ia|0)){Qa=Ia;Ra=Ha;Sa=Ga;Ta=Fa;Ua=H;Va=ba;Wa=aa;Xa=x;break}Ya=x-1|0;if((Ya|0)>=1){Qa=Pa;Ra=Ja;Sa=Ka;Ta=La;Ua=Ma;Va=Oa;Wa=0;Xa=Ya;break}Ya=(Ja|0)>(La|0);Za=P-(Ya?Ja:La)|0;_a=(Ya?La:Ja)-N|0;Ya=(Za|0)>(_a|0)?_a:Za;Za=(Ka|0)>(Ma|0);_a=Q-(Za?Ka:Ma)|0;$a=(Za?Ma:Ka)-O|0;Za=(_a|0)>($a|0)?$a:_a;Qa=Pa;Ra=Ja;Sa=Ka;Ta=La;Ua=Ma;Va=Oa;Wa=0;Xa=(Ya|0)>(Za|0)?Za:Ya}else{Qa=Ia;Ra=Ha;Sa=Ga;Ta=Fa;Ua=H;Va=ba;Wa=aa;Xa=x}}while(0);Oa=J+1|0;if((Oa|0)<(M|0)){x=Xa;J=Oa;aa=Wa;ba=Va;H=Ua;Fa=Ta;Ga=Sa;Ha=Ra;Ia=Qa}else{ab=Wa;bb=Va;cb=Ua;db=Ta;eb=Sa;fb=Ra;gb=Qa;break}}}else{ab=Ea;bb=Da;cb=ea;db=ma;eb=ua;fb=Ca;gb=Ba}if((ab|0)==0){S=gb;R=fb;I=eb;z=db;L=cb;D=bb}else{break}}T=gb;U=fb&65535;V=eb&65535;W=db&65535;X=cb&65535}cb=c[y>>2]|0;b[cb+(w<<2)>>1]=U;b[cb+(w<<2)+2>>1]=V;V=c[C>>2]|0;b[V+(w<<2)>>1]=W;b[V+(w<<2)+2>>1]=X;X=T+k|0;k=e+60|0;if((c[k>>2]&536870912|0)==0){hb=2147483647;ib=2147483647}else{c[o>>2]=0;o=e+12460|0;T=e+12464|0;c[T>>2]=(c[o>>2]|0)+((c[q>>2]|0)*8193|0)+4096;q=c[p>>2]|0;p=jrb(e,0,e+11676|0,e+11716|0,b[q+(m<<2)>>1]|0,b[q+(m<<2)+2>>1]|0)|0;c[T>>2]=(c[o>>2]|0)+((c[u>>2]|0)*8193|0)+4096;u=c[t>>2]|0;hb=jrb(e,2,e+11692|0,e+11724|0,b[u+(m<<2)>>1]|0,b[u+(m<<2)+2>>1]|0)|0;ib=p}p=(r|0)>(s|0);u=p?s:r;s=(v|0)<(u|0);t=s?v:u;u=(X|0)<(t|0);v=u?X:t;t=(ib|0)<(v|0);X=t?ib:v;v=(hb|0)<(X|0);o=v?1024:t?512:u?128:s?64:p?32:16;p=v?hb:X;X=((ca(p,p)|0)+32768|0)>>>16;p=e+12424|0;v=wrc(X,0,c[p>>2]|0,c[p+4>>2]|0)|0;c[p>>2]=v;c[p+4>>2]=G;p=(ca(c[l>>2]|0,g)|0)+f|0;b[(c[e+9200>>2]|0)+(p<<1)>>1]=X;do{if((c[(c[e+12120>>2]|0)+296>>2]|0)>0){X=(ib|0)!=2147483647;f=X?752:240;g=(hb|0)!=2147483647;l=g?f|1024:f;if(X){jb=g?l|2048:f}else{jb=l}l=(r|0)>1048576?jb&-17:jb;f=l&65535;if((c[n>>2]|0)!=13){kb=f;break}if((l&16|0)==0){kb=f;break}if((c[k>>2]&64|0)==0){kb=f;break}if((c[(c[e+11656>>2]|0)+(m<<2)>>2]|0)==0){kb=f;break}kb=(l|4096)&65535}else{kb=o}}while(0);b[(c[e+12492>>2]|0)+(p<<1)>>1]=kb;i=h;return}function mrb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=i;i=i+96|0;h=g|0;j=g+80|0;k=g+88|0;l=c[a+124>>2]|0;m=(ca(l,f)|0)+d|0;n=c[a+13924>>2]|0;o=n+1|0;p=e[a+13872>>1]|0;q=e[a+13874>>1]|0;r=a+11656|0;s=c[r>>2]|0;c[a+12464>>2]=(c[a+12460>>2]|0)+12289;t=-32>>o;u=31>>>(o>>>0);v=a+11740|0;c[v>>2]=(c[(c[a+4712>>2]|0)+(m<<2)>>2]|0)>>>6&1;w=a+4700|0;x=n+4|0;y=d<<4;d=y|1;z=a+8|0;A=-15-y|0;B=f<<4;f=B|1;C=a+12|0;D=-15-B|0;E=u;F=t;G=u;u=t;t=0;while(1){if((t|0)>=4){H=E;I=F;J=G;K=u;break}L=c[a+12496+(t<<2)>>2]|0;M=c[w>>2]|0;N=b[M+(L<<2)>>1]|0;O=N<<16>>16;c[a+12128+(t<<3)>>2]=O;P=b[M+(L<<2)+2>>1]|0;L=P<<16>>16;c[a+12128+(t<<3)+4>>2]=L;M=((ca(O,q)|0)/(p|0)|0)+((t&1)<<x)|0;c[a+12160+(t<<3)>>2]=M;Q=((ca(L,q)|0)/(p|0)|0)+(t>>1<<x)|0;c[a+12160+(t<<3)+4>>2]=Q;R=N<<16>>16>0;N=M-O|0;O=(c[z>>2]|0)-d-((R?M:N)>>o)|0;S=(G|0)>(O|0)?O:G;O=A-((R?N:M)>>o)|0;M=(u|0)>(O|0)?u:O;O=P<<16>>16>0;P=Q-L|0;L=(c[C>>2]|0)-f-((O?Q:P)>>o)|0;N=(E|0)>(L|0)?L:E;L=D-((O?P:Q)>>o)|0;Q=(F|0)>(L|0)?F:L;if((c[v>>2]|0)==0){H=N;I=Q;J=S;K=M;break}else{E=N;F=Q;G=S;u=M;t=t+1|0}}if((J|0)<0|(K|0)>0|(H|0)<0|(I|0)>0){t=c[r>>2]|0;b[t+(m<<2)>>1]=0;b[t+(m<<2)+2>>1]=0;T=1073741824;i=g;return T|0}c[a+12264>>2]=K;c[a+12272>>2]=I;c[a+12268>>2]=J;c[a+12276>>2]=H;t=a+12244|0;c[t>>2]=c[t>>2]|4;r=a+12248|0;c[r>>2]=c[r>>2]|4;c[a+12280>>2]=0;c[a+12284>>2]=0;u=m-1|0;G=b[s+(u<<2)>>1]|0;F=K<<o;K=J<<o;if((G|0)<(F|0)){U=F}else{U=(G|0)>(K|0)?K:G}c[h+8>>2]=U;G=b[s+(u<<2)+2>>1]|0;u=I<<o;I=H<<o;if((G|0)<(u|0)){V=u}else{V=(G|0)>(I|0)?I:G}c[h+12>>2]=V;if((c[a+14084>>2]|0)==0){G=m-l|0;l=b[s+(G<<2)>>1]|0;if((l|0)<(F|0)){W=F}else{W=(l|0)>(K|0)?K:l}c[h+16>>2]=W;l=b[s+(G<<2)+2>>1]|0;if((l|0)<(u|0)){X=u}else{X=(l|0)>(I|0)?I:l}c[h+20>>2]=X;l=G+1|0;G=b[s+(l<<2)>>1]|0;if((G|0)<(F|0)){Y=F}else{Y=(G|0)>(K|0)?K:G}c[h+24>>2]=Y;G=b[s+(l<<2)+2>>1]|0;if((G|0)<(u|0)){Z=u}else{Z=(G|0)>(I|0)?I:G}c[h+28>>2]=Z;do{if((U|0)>(W|0)){if((Y|0)<=(W|0)){_=W;break}_=(Y|0)>(U|0)?U:Y}else{if((W|0)<=(Y|0)){_=W;break}_=(Y|0)>(U|0)?Y:U}}while(0);c[h+32>>2]=_;do{if((V|0)>(X|0)){if((Z|0)<=(X|0)){$=X;break}$=(Z|0)>(V|0)?V:Z}else{if((X|0)<=(Z|0)){$=X;break}$=(Z|0)>(V|0)?Z:V}}while(0);c[h+36>>2]=$}$=_qb(a,j,k,h|0,0,0,s,1<<15-n,0,16)|0;if((c[r>>2]&1|0)==0){aa=brb(a,j,k,$,0,0,0,16)|0}else{aa=arb(a,j,k,$,0,0,0,16)|0}$=c[a+12120>>2]|0;do{if((c[$+236>>2]|0)==(c[$+240>>2]|0)){ba=aa}else{if((c[a+12124>>2]|0)!=0){ba=aa;break}ba=Zqb(a,c[j>>2]|0,c[k>>2]|0,0,0,0,16,1)|0}}while(0);hrb(a,y,B);b[s+(m<<2)>>1]=c[j>>2];b[s+(m<<2)+2>>1]=c[k>>2];c[t>>2]=c[t>>2]&-5;c[r>>2]=c[r>>2]&-5;T=ba;i=g;return T|0}function nrb(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;k=i;i=i+96|0;l=k|0;m=k+8|0;n=k+16|0;o=(c[a+13924>>2]|0)+1|0;p=c[a+124>>2]|0;q=(ca(p,f)|0)+d|0;r=(c[a+12460>>2]|0)+(j*8193|0)+4096|0;j=c[a+9968>>2]|0;s=c[a+9972>>2]|0;t=a+12120|0;u=c[t>>2]|0;switch(c[u+232>>2]&255|0){case 6:case 4:case 1:case 10:{v=s>>7;break};case 2:case 14:{v=j>>6;break};case 11:{v=j>>5;break};case 5:{v=1;break};case 3:{v=(j*3|0)>>8;break};case 12:{v=j>>6;break};default:{v=j>>7}}c[a+12232>>2]=v;switch(c[u+236>>2]&255|0){case 5:{w=1;break};case 3:{w=(j*3|0)>>8;break};case 6:case 4:case 1:case 10:{w=s>>7;break};case 11:{w=j>>5;break};case 12:{w=j>>6;break};case 2:case 14:{w=j>>6;break};default:{w=j>>7}}c[a+12236>>2]=w;switch(c[u+240>>2]&255|0){case 2:case 14:{x=j>>6;break};case 11:{x=j>>5;break};case 5:{x=1;break};case 3:{x=(j*3|0)>>8;break};case 12:{x=j>>6;break};case 6:case 4:case 1:case 10:{x=s>>7;break};default:{x=j>>7}}c[a+12240>>2]=x;c[a+12464>>2]=r;hrb(a,d<<4,f<<4);if(((c[a+11732>>2]|0)-5|0)>>>0<2>>>0){f=q-1|0;d=b[g+(f<<2)>>1]|0;r=n+8|0;c[r>>2]=d;x=b[g+(f<<2)+2>>1]|0;c[n+12>>2]=x;f=c[a+12268>>2]<<o;if((d|0)>(f|0)){c[r>>2]=f;y=f}else{y=d}if((c[a+14084>>2]|0)==0){d=q-p|0;p=b[g+(d<<2)>>1]|0;c[n+16>>2]=p;f=b[g+(d<<2)+2>>1]|0;r=n+20|0;c[r>>2]=f;j=d+1|0;d=b[g+(j<<2)>>1]|0;s=n+24|0;c[s>>2]=d;u=b[g+(j<<2)+2>>1]|0;j=n+28|0;c[j>>2]=u;w=c[a+12276>>2]<<o;if((f|0)>(w|0)){c[r>>2]=w;z=w}else{z=f}f=c[a+12264>>2]<<o;if((d|0)<(f|0)){c[s>>2]=f;A=f}else{A=d}if((u|0)>(w|0)){c[j>>2]=w;B=w}else{B=u}do{if((y|0)>(p|0)){if((A|0)<=(p|0)){C=p;break}C=(A|0)>(y|0)?y:A}else{if((p|0)<=(A|0)){C=p;break}C=(A|0)>(y|0)?A:y}}while(0);c[n+32>>2]=C;do{if((x|0)>(z|0)){if((B|0)<=(z|0)){D=z;break}D=(B|0)>(x|0)?x:B}else{if((z|0)<=(B|0)){D=z;break}D=(B|0)>(x|0)?B:x}}while(0);c[n+36>>2]=D}c[a+12280>>2]=y;c[a+12284>>2]=x;x=e[a+13874>>1]|0;if((c[a+11640>>2]|0)==(g|0)){E=(x<<16|0)/(e[a+13872>>1]<<o|0)|0}else{y=e[a+13872>>1]|0;E=(x-y<<16|0)/(y<<o|0)|0}F=_qb(a,l,m,n|0,0,h,c[a+11636>>2]|0,E,0,16)|0}else{c[l>>2]=0;c[m>>2]=0;F=0}E=gf[c[a+12468>>2]&63](a,l,m,F,0,h,0,16)|0;F=c[t>>2]|0;if((c[F+236>>2]|0)==(c[F+240>>2]|0)){G=E;H=c[l>>2]|0;I=H&65535;J=g+(q<<2)|0;b[J>>1]=I;K=c[m>>2]|0;L=K&65535;M=g+(q<<2)+2|0;b[M>>1]=L;i=k;return G|0}if((c[a+12124>>2]|0)!=0){G=E;H=c[l>>2]|0;I=H&65535;J=g+(q<<2)|0;b[J>>1]=I;K=c[m>>2]|0;L=K&65535;M=g+(q<<2)+2|0;b[M>>1]=L;i=k;return G|0}G=Zqb(a,c[l>>2]|0,c[m>>2]|0,0,h,0,16,1)|0;H=c[l>>2]|0;I=H&65535;J=g+(q<<2)|0;b[J>>1]=I;K=c[m>>2]|0;L=K&65535;M=g+(q<<2)+2|0;b[M>>1]=L;i=k;return G|0}function orb(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;h=i;i=i+32|0;j=h|0;if((c[d+11732>>2]|0)<=4){k=1;i=h;return k|0}l=c[d+4>>2]|0;m=c[l+276>>2]|0;n=(m|0)==0?1073741823:m;m=c[d+11856>>2]|0;do{if((c[d+14092>>2]|0)==0){if((c[d+48>>2]|0)!=2){o=n;break}if(!((c[l+680>>2]|0)>-1)){o=n;break}o=(n|0)>256?256:n}else{o=(n|0)>16?16:n}}while(0);n=c[d+144>>2]|0;c[j>>2]=n<<3;l=n*7|0;p=j+4|0;c[p>>2]=l;q=n*6|0;r=j+8|0;c[r>>2]=q;s=n*5|0;t=j+12|0;c[t>>2]=s;u=n<<2;v=j+16|0;c[v>>2]=u;w=n*3|0;x=j+20|0;c[x>>2]=w;y=n<<1;z=j+24|0;c[z>>2]=y;A=j+28|0;c[A>>2]=n;B=c[d+120>>2]|0;if((B|0)>0){C=c[d+124>>2]|0;D=c[d+116>>2]|0;E=(D|0)>0;F=d+12492|0;G=-o|0;H=d+9992|0;I=d+9200|0;J=d+9192|0;d=0;do{if(E){K=ca(C,d)|0;L=c[F>>2]|0;M=0;N=K;while(1){do{if((e[L+(N<<1)>>1]&g|0)==0){O=22}else{K=b[f+(N<<2)>>1]|0;P=b[f+(N<<2)+2>>1]|0;Q=a[m+(K+4096)|0]|0;R=a[m+(P+4096)|0]|0;S=(Q&255)>>>0>(R&255)>>>0?Q:R;R=S&255;if((K|0)>=(o|0)){T=N;break}if((P|0)>=(o|0)|(K|0)<(G|0)|(P|0)<(G|0)){T=N;break}if(S<<24>>24==0){O=22;break}S=(c[H>>2]|0)==3;P=0;while(1){if(S){O=20}else{if((e[(c[I>>2]|0)+(N<<1)>>1]|0)>>>0<(e[(c[J>>2]|0)+(N<<1)>>1]|0)>>>0){O=20}}if((O|0)==20){O=0;K=j+(P<<2)|0;c[K>>2]=(c[K>>2]|0)-170}K=P+1|0;if((K|0)<(R|0)&(K|0)<8){P=K}else{O=22;break}}}}while(0);if((O|0)==22){O=0;T=N+1|0}P=M+1|0;if((P|0)<(D|0)){M=P;N=T}else{break}}}d=d+1|0;}while((d|0)<(B|0));U=c[p>>2]|0;V=c[r>>2]|0;W=c[t>>2]|0;X=c[v>>2]|0;Y=c[x>>2]|0;Z=c[z>>2]|0;_=c[A>>2]|0}else{U=l;V=q;W=s;X=u;Y=w;Z=y;_=n}n=(U|0)>-1e7;y=n?U:-1e7;U=(V|0)>(y|0);w=U?V:y;y=(W|0)>(w|0);V=y?W:w;w=(X|0)>(V|0);W=w?X:V;V=(Y|0)>(W|0);X=V?Y:W;W=(Z|0)>(X|0);k=(_|0)>((W?Z:X)|0)?7:W?6:V?5:w?4:y?3:U?2:n?1:-1;i=h;return k|0}function prb(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=i;e=c[a+11556>>2]|0;if((c[a+9992>>2]|0)!=2){KIb(0,0,2350336,(f=i,i=i+24|0,c[f>>2]=2139920,c[f+8>>2]=2238640,c[f+16>>2]=1676,f)|0);i=f;Hd()}if((c[a+28>>2]|0)==0){g=8}else{g=(c[a+14092>>2]|0)!=0?8:16}h=g<<e;do{if((h|0)>=17){if((c[a+14092>>2]|0)!=0){KIb(0,0,2350336,(f=i,i=i+24|0,c[f>>2]=2116488,c[f+8>>2]=2238640,c[f+16>>2]=1680,f)|0);i=f;Hd()}if((h|0)<257){break}if((c[a+48>>2]|0)!=2){break}if(!((c[(c[a+4>>2]|0)+680>>2]|0)>-1)){break}KIb(0,0,2350336,(f=i,i=i+24|0,c[f>>2]=2634336,c[f+8>>2]=2238640,c[f+16>>2]=1681,f)|0);i=f;Hd()}}while(0);f=c[(c[a+12120>>2]|0)+276>>2]|0;e=(f|0)!=0&(h|0)>(f|0)?f:h;if((c[a+60>>2]&4|0)==0){i=d;return}h=c[a+128>>2]|0;f=a+120|0;g=c[f>>2]|0;if((g|0)<=0){i=d;return}j=h<<1;k=a+124|0;l=a+116|0;m=a+12492|0;n=a+9148|0;o=-e|0;p=a+9160|0;a=0;q=c[l>>2]|0;r=g;while(1){if((q|0)>0){g=ca(c[k>>2]|0,a)|0;s=ca(j,a)|0;t=c[m>>2]|0;u=g;g=0;v=s;s=q;while(1){w=t+(u<<1)|0;x=b[w>>1]|0;if((x&4)==0){y=s}else{z=c[n>>2]|0;A=b[z+(v<<2)>>1]|0;B=b[z+(v<<2)+2>>1]|0;if((A|0)<(e|0)){if((B|0)>=(e|0)|(A|0)<(o|0)|(B|0)<(o|0)){C=20}else{D=x}}else{C=20}if((C|0)==20){C=0;B=x&-6|1;b[w>>1]=B;c[(c[p>>2]|0)+(u<<2)>>2]=1;D=B}B=v+1|0;x=b[z+(B<<2)>>1]|0;A=b[z+(B<<2)+2>>1]|0;if((x|0)<(e|0)){if((A|0)>=(e|0)|(x|0)<(o|0)|(A|0)<(o|0)){C=27}else{E=D}}else{C=27}if((C|0)==27){C=0;A=D&-6|1;b[w>>1]=A;c[(c[p>>2]|0)+(u<<2)>>2]=1;E=A}A=v+h|0;x=b[z+(A<<2)>>1]|0;F=b[z+(A<<2)+2>>1]|0;if((x|0)<(e|0)){if((F|0)>=(e|0)|(x|0)<(o|0)|(F|0)<(o|0)){C=30}else{G=E}}else{C=30}if((C|0)==30){C=0;F=E&-6|1;b[w>>1]=F;c[(c[p>>2]|0)+(u<<2)>>2]=1;G=F}F=B+h|0;B=b[z+(F<<2)>>1]|0;x=b[z+(F<<2)+2>>1]|0;if((B|0)<(e|0)){if((x|0)>=(e|0)|(B|0)<(o|0)|(x|0)<(o|0)){C=33}}else{C=33}if((C|0)==33){C=0;b[w>>1]=G&-6|1;c[(c[p>>2]|0)+(u<<2)>>2]=1}y=c[l>>2]|0}w=g+1|0;if((w|0)<(y|0)){u=u+1|0;g=w;v=v+2|0;s=y}else{break}}H=y;I=c[f>>2]|0}else{H=q;I=r}s=a+1|0;if((s|0)<(I|0)){a=s;q=H;r=I}else{break}}i=d;return}function qrb(a,f,g,h,i,j,k){a=a|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((c[a+28>>2]|0)==0){l=8}else{l=(c[a+14092>>2]|0)!=0?8:16}m=l<<i;i=c[(c[a+12120>>2]|0)+276>>2]|0;l=(i|0)!=0&(m|0)>(i|0)?i:m;m=l>>((f|0)!=0);i=c[a+120>>2]|0;if((i|0)<=0){return}n=a+124|0;o=a+12492|0;p=(f|0)==0;q=-l|0;r=(k|0)==0;k=j^65534;s=l-1|0;t=s&65535;u=m-1|0;v=u&65535;w=-m|0;x=w&65535;y=q&65535;z=c[a+116>>2]|0;a=0;do{if((z|0)>0){A=ca(c[n>>2]|0,a)|0;B=c[o>>2]|0;C=0;D=A;while(1){A=B+(D<<1)|0;E=e[A>>1]|0;do{if((E&j|0)!=0){if(!p){if((d[f+D|0]|0)!=(g|0)){break}}F=h+(D<<2)|0;G=b[F>>1]|0;H=(G|0)<(q|0);if(!((G|0)>=(l|0)|H)){I=b[h+(D<<2)+2>>1]|0;if(!((I|0)>=(m|0)|(I|0)<(w|0))){break}}if(r){b[A>>1]=E&k&65535|1;b[h+(D<<2)+2>>1]=0;b[F>>1]=0;break}do{if((G|0)>(s|0)){b[F>>1]=t}else{if(!H){break}b[F>>1]=y}}while(0);F=h+(D<<2)+2|0;H=b[F>>1]|0;if((H|0)>(u|0)){b[F>>1]=v;break}if((H|0)>=(w|0)){break}b[F>>1]=x}}while(0);E=C+1|0;if((E|0)<(z|0)){C=E;D=D+1|0}else{break}}}a=a+1|0;}while((a|0)<(i|0));return}function rrb(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=c[a+11556>>2]|0;m=c[a+12460>>2]|0;n=c[a+11560>>2]|0;o=c[a+12416>>2]|0;p=c[a+12192>>2]|0;q=a+12352|0;r=a+12384|0;if((c[a+13924>>2]|0)==0){s=(c[q>>2]|0)+((ca(o,e>>1)|0)+(b>>1))|0;mf[c[a+11332+((e<<1&2|b&1)<<2)>>2]&2047](p,s,o,16);s=(c[r>>2]|0)+((ca(o,g>>1)|0)+(f>>1))|0;mf[c[a+11396+((g<<1&2|f&1)<<2)>>2]&2047](p,s,o,16)}else{s=(c[q>>2]|0)+((ca(o,e>>2)|0)+(b>>2))|0;ef[c[a+10680+((e<<2&12|b&3)<<2)>>2]&4095](p,s,o);s=(c[r>>2]|0)+((ca(o,g>>2)|0)+(f>>2))|0;ef[c[a+10808+((g<<2&12|f&3)<<2)>>2]&4095](p,s,o)}s=ca((d[e+4096-i+(m+(l*8193|0))|0]|0)+(d[b+4096-h+(m+(l*8193|0))|0]|0)+(d[f+4096-j+(m+(n*8193|0))|0]|0)+(d[g+4096-k+(m+(n*8193|0))|0]|0)|0,c[a+12240>>2]|0)|0;return s+(Xe[c[a+10516>>2]&511](a,c[a+12288>>2]|0,p,o,16)|0)|0}function srb(a,f,h,j,k,l,m){a=a|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0;n=i;i=i+19208|0;o=n|0;c[(n|0)>>2]=0;c[(n|0)+4>>2]=0;p=c[a+12232>>2]|0;q=c[a+124>>2]|0;r=(ca(c[(a+12480|0)>>2]|0,q)|0)+(c[a+12476>>2]|0)|0;s=c[(a+12220|0)>>2]|0;t=c[(a+12264|0)>>2]|0;u=c[(a+12272|0)>>2]|0;v=c[(a+12268|0)>>2]|0;w=c[(a+12276|0)>>2]|0;y=c[(a+12464|0)>>2]|0;z=c[(a+12280|0)>>2]|0;A=c[(a+12284|0)>>2]|0;B=c[a+12244>>2]|0;C=c[(a+12216|0)>>2]|0;D=(B&1)+1|0;G=c[(a+10468|0)>>2]|0;H=c[(a+10472|0)>>2]|0;I=(c[(a+12224|0)>>2]|0)+4194304|0;c[(a+12224|0)>>2]=I;if((I|0)==0){c[(a+12224|0)>>2]=4194304;mrc(C|0,0,256)|0;J=c[(a+12224|0)>>2]|0}else{J=I}do{I=1;if(I){I=0;if((c[a+14084>>2]|0)==0){K=c[(j+76|0)>>2]>>D;L=c[(j+72|0)>>2]>>D;M=L+J+(K<<11)|0;do{if((c[(C+(((K<<3)+L&63)<<2)|0)>>2]|0)==(M|0)){N=1e6;O=0;P=0}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;R=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ca(Q,K)|0)+L)|0;T=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){U=T;break}S=c[a+12208>>2]|0;V=(ca(R,K>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&2047](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+V|0,R,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&2047](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+V|0,R,4);V=(Xe[H&511](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,R,4)|0)+T|0;U=V+(Xe[H&511](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,R,4)|0)|0}else{R=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){U=536870912;break}if((L<<D|0)>(c[(a+12268|0)>>2]<<D|0)){U=536870912;break}if((c[(a+12272|0)>>2]|0)>(K|0)){U=536870912;break}if((K<<D|0)>(c[(a+12276|0)>>2]<<D|0)){U=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;V=(B&1)<<1|1;a:do{if((c[a+11740>>2]|0)==1){if((L<<D|0)==0){T=0;while(1){W=c[a+12160+(T<<3)>>2]|0;X=(c[a+12160+(T<<3)+4>>2]|0)+(K<<D)|0;Y=((ca(c[a+12128+(T<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((T&1)<<(B&1|4))|0;Z=c[a+12128+(T<<3)+4>>2]|0;if((K<<D|0)==0){_=T>>1;$=((ca(Z,S-Q|0)|0)/(Q|0)|0)+(_<<(B&1|4))|0;aa=_}else{$=X-Z|0;aa=T>>1}Z=(($&V)<<D)+(Y&V)|0;_=(c[(a+12208|0)>>2]|0)+((ca(aa,R<<3)|0)+(T<<3&8))|0;if((B&1|0)==0){ba=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,R)|0)+(W>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((X&V)<<D)+(W&V)|0)<<2)>>2]&2047](_,ba,R,8);ba=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>1,R)|0)+(Y>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Z<<2)>>2]&2047](_,ba,R,8)}else{ba=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>2,R)|0)+(W>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&V)<<D)+(W&V)|0)<<2)>>2]&4095](_,ba,R);ba=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>2,R)|0)+(Y>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095](_,ba,R)}T=T+1|0;if((T|0)>=4){break a}}}if((K<<D|0)==0){T=0;do{ba=(c[a+12160+(T<<3)>>2]|0)+(L<<D)|0;_=c[a+12160+(T<<3)+4>>2]|0;Z=ba-(c[a+12128+(T<<3)>>2]|0)|0;Y=T>>1;W=((ca(c[a+12128+(T<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(Y<<(B&1|4))|0;X=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ca(Y,R<<3)|0))|0;if((B&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>1,R)|0)+(ba>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((_&V)<<D)+(ba&V)|0)<<2)>>2]&2047](X,Y,R,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>1,R)|0)+(Z>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((W&V)<<D)+(Z&V)|0)<<2)>>2]&2047](X,Y,R,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>2,R)|0)+(ba>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<D)+(ba&V)|0)<<2)>>2]&4095](X,Y,R);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>2,R)|0)+(Z>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((W&V)<<D)+(Z&V)|0)<<2)>>2]&4095](X,Y,R)}T=T+1|0;}while((T|0)<4)}else{T=0;do{Y=(c[a+12160+(T<<3)>>2]|0)+(L<<D)|0;X=(c[a+12160+(T<<3)+4>>2]|0)+(K<<D)|0;Z=Y-(c[a+12128+(T<<3)>>2]|0)|0;W=X-(c[a+12128+(T<<3)+4>>2]|0)|0;ba=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ca(T>>1,R<<3)|0))|0;if((B&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,R)|0)+(Y>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((X&V)<<D)+(Y&V)|0)<<2)>>2]&2047](ba,_,R,8);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>1,R)|0)+(Z>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((W&V)<<D)+(Z&V)|0)<<2)>>2]&2047](ba,_,R,8)}else{_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>2,R)|0)+(Y>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&V)<<D)+(Y&V)|0)<<2)>>2]&4095](ba,_,R);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>2,R)|0)+(Z>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((W&V)<<D)+(Z&V)|0)<<2)>>2]&4095](ba,_,R)}T=T+1|0;}while((T|0)<4)}}else{T=(c[a+12160>>2]|0)+(L<<D)|0;_=(c[a+12164>>2]|0)+(K<<D)|0;ba=c[a+12128>>2]|0;if((L<<D|0)==0){da=(ca(ba,S-Q|0)|0)/(Q|0)|0}else{da=T-ba|0}ba=c[a+12132>>2]|0;if((K<<D|0)==0){ea=(ca(ba,S-Q|0)|0)/(Q|0)|0}else{ea=_-ba|0}ba=((ea&V)<<D)+(da&V)|0;if((B&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>1,R)|0)+(T>>1))|0;mf[c[(c[a+12444>>2]|0)+((((_&V)<<D)+(T&V)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Z,R,16);Z=(c[a+12352+(l<<4)+32>>2]|0)+((ca(ea>>1,R)|0)+(da>>1))|0;mf[c[(c[a+12448>>2]|0)+(ba<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Z,R,16);break}else{Z=(ca(_>>2,R)|0)+(T>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<D)+(T&V)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Z|0,R);ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<D)+(T&V)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Z+8|0)|0,R);ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<D)+(T&V)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(R<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Z+(R<<3))|0,R);ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&V)<<D)+(T&V)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Z+8|0)+(R<<3))|0,R);Z=(ca(ea>>2,R)|0)+(da>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ba<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Z|0,R);ef[c[(c[(a+12456|0)>>2]|0)+64+(ba<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Z+8|0)|0,R);ef[c[(c[(a+12456|0)>>2]|0)+64+(ba<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(R<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Z+(R<<3))|0,R);ef[c[(c[(a+12456|0)>>2]|0)+64+(ba<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Z+8|0)+(R<<3))|0,R);break}}}while(0);U=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,R,16)|0}}while(0);c[(C+(((K<<3)+L&63)<<2)|0)>>2]=M;c[s+(((K<<3)+L&63)<<2)>>2]=U;V=c[(j+72|0)>>2]>>D;Q=c[(j+76|0)>>2]>>D;S=(ca((d[y+((Q<<D)-A)|0]|0)+(d[y+((V<<D)-z)|0]|0)|0,p)|0)+U|0;if((S|0)>=1e6){N=1e6;O=0;P=0;break}c[(n|0)>>2]=V;c[o+4>>2]=Q;N=S;O=V;P=Q}}while(0);L=c[(j+36|0)>>2]>>D;K=c[(j+32|0)>>2]>>D;M=K+J+(L<<11)|0;do{if((c[(C+(((L<<3)+K&63)<<2)|0)>>2]|0)==(M|0)){fa=N;ga=O;ha=P}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;V=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ca(Q,L)|0)+K)|0;Z=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){ia=Z;break}S=c[a+12208>>2]|0;ba=(ca(V,L>>1)|0)+(K>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((L<<1&2|K&1)<<2)>>2]&2047](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ba|0,V,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((L<<1&2|K&1)<<2)>>2]&2047](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ba|0,V,4);ba=(Xe[H&511](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,V,4)|0)+Z|0;ia=ba+(Xe[H&511](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,V,4)|0)|0}else{V=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(K|0)){ia=536870912;break}if((K<<D|0)>(c[(a+12268|0)>>2]<<D|0)){ia=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){ia=536870912;break}if((L<<D|0)>(c[(a+12276|0)>>2]<<D|0)){ia=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;ba=(B&1)<<1|1;b:do{if((c[a+11740>>2]|0)==1){if((K<<D|0)==0){Z=0;while(1){T=c[a+12160+(Z<<3)>>2]|0;_=(c[a+12160+(Z<<3)+4>>2]|0)+(L<<D)|0;W=((ca(c[a+12128+(Z<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((Z&1)<<(B&1|4))|0;Y=c[a+12128+(Z<<3)+4>>2]|0;if((L<<D|0)==0){X=Z>>1;ja=((ca(Y,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;ka=X}else{ja=_-Y|0;ka=Z>>1}Y=((ja&ba)<<D)+(W&ba)|0;X=(c[(a+12208|0)>>2]|0)+((ca(ka,V<<3)|0)+(Z<<3&8))|0;if((B&1|0)==0){la=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>1,V)|0)+(T>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((_&ba)<<D)+(T&ba)|0)<<2)>>2]&2047](X,la,V,8);la=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ja>>1,V)|0)+(W>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Y<<2)>>2]&2047](X,la,V,8)}else{la=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>2,V)|0)+(T>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&ba)<<D)+(T&ba)|0)<<2)>>2]&4095](X,la,V);la=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ja>>2,V)|0)+(W>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Y<<2)>>2]&4095](X,la,V)}Z=Z+1|0;if((Z|0)>=4){break b}}}if((L<<D|0)==0){Z=0;do{la=(c[a+12160+(Z<<3)>>2]|0)+(K<<D)|0;X=c[a+12160+(Z<<3)+4>>2]|0;Y=la-(c[a+12128+(Z<<3)>>2]|0)|0;W=Z>>1;T=((ca(c[a+12128+(Z<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(W<<(B&1|4))|0;_=(c[(a+12208|0)>>2]|0)+((Z<<3&8)+(ca(W,V<<3)|0))|0;if((B&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,V)|0)+(la>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((X&ba)<<D)+(la&ba)|0)<<2)>>2]&2047](_,W,V,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(T>>1,V)|0)+(Y>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((T&ba)<<D)+(Y&ba)|0)<<2)>>2]&2047](_,W,V,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>2,V)|0)+(la>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ba)<<D)+(la&ba)|0)<<2)>>2]&4095](_,W,V);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(T>>2,V)|0)+(Y>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((T&ba)<<D)+(Y&ba)|0)<<2)>>2]&4095](_,W,V)}Z=Z+1|0;}while((Z|0)<4)}else{Z=0;do{W=(c[a+12160+(Z<<3)>>2]|0)+(K<<D)|0;_=(c[a+12160+(Z<<3)+4>>2]|0)+(L<<D)|0;Y=W-(c[a+12128+(Z<<3)>>2]|0)|0;T=_-(c[a+12128+(Z<<3)+4>>2]|0)|0;la=(c[(a+12208|0)>>2]|0)+((Z<<3&8)+(ca(Z>>1,V<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>1,V)|0)+(W>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((_&ba)<<D)+(W&ba)|0)<<2)>>2]&2047](la,X,V,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(T>>1,V)|0)+(Y>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((T&ba)<<D)+(Y&ba)|0)<<2)>>2]&2047](la,X,V,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>2,V)|0)+(W>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&ba)<<D)+(W&ba)|0)<<2)>>2]&4095](la,X,V);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(T>>2,V)|0)+(Y>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((T&ba)<<D)+(Y&ba)|0)<<2)>>2]&4095](la,X,V)}Z=Z+1|0;}while((Z|0)<4)}}else{Z=(c[a+12160>>2]|0)+(K<<D)|0;X=(c[a+12164>>2]|0)+(L<<D)|0;la=c[a+12128>>2]|0;if((K<<D|0)==0){ma=(ca(la,S-Q|0)|0)/(Q|0)|0}else{ma=Z-la|0}la=c[a+12132>>2]|0;if((L<<D|0)==0){na=(ca(la,S-Q|0)|0)/(Q|0)|0}else{na=X-la|0}la=((na&ba)<<D)+(ma&ba)|0;if((B&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,V)|0)+(Z>>1))|0;mf[c[(c[a+12444>>2]|0)+((((X&ba)<<D)+(Z&ba)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Y,V,16);Y=(c[a+12352+(l<<4)+32>>2]|0)+((ca(na>>1,V)|0)+(ma>>1))|0;mf[c[(c[a+12448>>2]|0)+(la<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Y,V,16);break}else{Y=(ca(X>>2,V)|0)+(Z>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ba)<<D)+(Z&ba)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Y|0,V);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ba)<<D)+(Z&ba)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Y+8|0)|0,V);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ba)<<D)+(Z&ba)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(V<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Y+(V<<3))|0,V);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ba)<<D)+(Z&ba)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Y+8|0)+(V<<3))|0,V);Y=(ca(na>>2,V)|0)+(ma>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Y|0,V);ef[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Y+8|0)|0,V);ef[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(V<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Y+(V<<3))|0,V);ef[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Y+8|0)+(V<<3))|0,V);break}}}while(0);ia=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,V,16)|0}}while(0);c[(C+(((L<<3)+K&63)<<2)|0)>>2]=M;c[s+(((L<<3)+K&63)<<2)>>2]=ia;ba=c[(j+32|0)>>2]>>D;Q=c[(j+36|0)>>2]>>D;S=(ca((d[y+((Q<<D)-A)|0]|0)+(d[y+((ba<<D)-z)|0]|0)|0,p)|0)+ia|0;if((S|0)>=(N|0)){fa=N;ga=O;ha=P;break}c[(n|0)>>2]=ba;c[o+4>>2]=Q;fa=S;ga=ba;ha=Q}}while(0);K=c[(j+12|0)>>2]>>D;L=c[(j+8|0)>>2]>>D;M=L+J+(K<<11)|0;do{if((c[(C+(((K<<3)+L&63)<<2)|0)>>2]|0)==(M|0)){oa=fa;pa=ga;qa=ha}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;ba=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ca(Q,K)|0)+L)|0;R=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){ra=R;break}S=c[a+12208>>2]|0;Y=(ca(ba,K>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&2047](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+Y|0,ba,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&2047](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+Y|0,ba,4);Y=(Xe[H&511](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ba,4)|0)+R|0;ra=Y+(Xe[H&511](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ba,4)|0)|0}else{ba=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){ra=536870912;break}if((L<<D|0)>(c[(a+12268|0)>>2]<<D|0)){ra=536870912;break}if((c[(a+12272|0)>>2]|0)>(K|0)){ra=536870912;break}if((K<<D|0)>(c[(a+12276|0)>>2]<<D|0)){ra=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;Y=(B&1)<<1|1;c:do{if((c[a+11740>>2]|0)==1){if((L<<D|0)==0){R=0;while(1){la=c[a+12160+(R<<3)>>2]|0;Z=(c[a+12160+(R<<3)+4>>2]|0)+(K<<D)|0;X=((ca(c[a+12128+(R<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((R&1)<<(B&1|4))|0;T=c[a+12128+(R<<3)+4>>2]|0;if((K<<D|0)==0){W=R>>1;sa=((ca(T,S-Q|0)|0)/(Q|0)|0)+(W<<(B&1|4))|0;ta=W}else{sa=Z-T|0;ta=R>>1}T=((sa&Y)<<D)+(X&Y)|0;W=(c[(a+12208|0)>>2]|0)+((ca(ta,ba<<3)|0)+(R<<3&8))|0;if((B&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>1,ba)|0)+(la>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&Y)<<D)+(la&Y)|0)<<2)>>2]&2047](W,_,ba,8);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(sa>>1,ba)|0)+(X>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(T<<2)>>2]&2047](W,_,ba,8)}else{_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>2,ba)|0)+(la>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&Y)<<D)+(la&Y)|0)<<2)>>2]&4095](W,_,ba);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(sa>>2,ba)|0)+(X>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095](W,_,ba)}R=R+1|0;if((R|0)>=4){break c}}}if((K<<D|0)==0){R=0;do{_=(c[a+12160+(R<<3)>>2]|0)+(L<<D)|0;W=c[a+12160+(R<<3)+4>>2]|0;T=_-(c[a+12128+(R<<3)>>2]|0)|0;X=R>>1;la=((ca(c[a+12128+(R<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;Z=(c[(a+12208|0)>>2]|0)+((R<<3&8)+(ca(X,ba<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,ba)|0)+(_>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((W&Y)<<D)+(_&Y)|0)<<2)>>2]&2047](Z,X,ba,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(la>>1,ba)|0)+(T>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((la&Y)<<D)+(T&Y)|0)<<2)>>2]&2047](Z,X,ba,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>2,ba)|0)+(_>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<D)+(_&Y)|0)<<2)>>2]&4095](Z,X,ba);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(la>>2,ba)|0)+(T>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((la&Y)<<D)+(T&Y)|0)<<2)>>2]&4095](Z,X,ba)}R=R+1|0;}while((R|0)<4)}else{R=0;do{X=(c[a+12160+(R<<3)>>2]|0)+(L<<D)|0;Z=(c[a+12160+(R<<3)+4>>2]|0)+(K<<D)|0;T=X-(c[a+12128+(R<<3)>>2]|0)|0;la=Z-(c[a+12128+(R<<3)+4>>2]|0)|0;_=(c[(a+12208|0)>>2]|0)+((R<<3&8)+(ca(R>>1,ba<<3)|0))|0;if((B&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>1,ba)|0)+(X>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&Y)<<D)+(X&Y)|0)<<2)>>2]&2047](_,W,ba,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(la>>1,ba)|0)+(T>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((la&Y)<<D)+(T&Y)|0)<<2)>>2]&2047](_,W,ba,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>2,ba)|0)+(X>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&Y)<<D)+(X&Y)|0)<<2)>>2]&4095](_,W,ba);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(la>>2,ba)|0)+(T>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((la&Y)<<D)+(T&Y)|0)<<2)>>2]&4095](_,W,ba)}R=R+1|0;}while((R|0)<4)}}else{R=(c[a+12160>>2]|0)+(L<<D)|0;W=(c[a+12164>>2]|0)+(K<<D)|0;_=c[a+12128>>2]|0;if((L<<D|0)==0){ua=(ca(_,S-Q|0)|0)/(Q|0)|0}else{ua=R-_|0}_=c[a+12132>>2]|0;if((K<<D|0)==0){va=(ca(_,S-Q|0)|0)/(Q|0)|0}else{va=W-_|0}_=((va&Y)<<D)+(ua&Y)|0;if((B&1|0)==0){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,ba)|0)+(R>>1))|0;mf[c[(c[a+12444>>2]|0)+((((W&Y)<<D)+(R&Y)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,T,ba,16);T=(c[a+12352+(l<<4)+32>>2]|0)+((ca(va>>1,ba)|0)+(ua>>1))|0;mf[c[(c[a+12448>>2]|0)+(_<<2)>>2]&2047](c[(a+12208|0)>>2]|0,T,ba,16);break}else{T=(ca(W>>2,ba)|0)+(R>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<D)+(R&Y)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+T|0,ba);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<D)+(R&Y)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(T+8|0)|0,ba);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<D)+(R&Y)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ba<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(T+(ba<<3))|0,ba);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&Y)<<D)+(R&Y)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ba<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((T+8|0)+(ba<<3))|0,ba);T=(ca(va>>2,ba)|0)+(ua>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+T|0,ba);ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(T+8|0)|0,ba);ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ba<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(T+(ba<<3))|0,ba);ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ba<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((T+8|0)+(ba<<3))|0,ba);break}}}while(0);ra=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ba,16)|0}}while(0);c[(C+(((K<<3)+L&63)<<2)|0)>>2]=M;c[s+(((K<<3)+L&63)<<2)>>2]=ra;Y=c[(j+8|0)>>2]>>D;Q=c[(j+12|0)>>2]>>D;S=(ca((d[y+((Q<<D)-A)|0]|0)+(d[y+((Y<<D)-z)|0]|0)|0,p)|0)+ra|0;if((S|0)>=(fa|0)){oa=fa;pa=ga;qa=ha;break}c[(n|0)>>2]=Y;c[o+4>>2]=Q;oa=S;pa=Y;qa=Q}}while(0);L=c[(j+20|0)>>2]>>D;K=c[(j+16|0)>>2]>>D;M=K+J+(L<<11)|0;do{if((c[(C+(((L<<3)+K&63)<<2)|0)>>2]|0)==(M|0)){wa=oa;xa=pa;ya=qa}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;Y=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ca(Q,L)|0)+K)|0;V=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){za=V;break}S=c[a+12208>>2]|0;T=(ca(Y,L>>1)|0)+(K>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((L<<1&2|K&1)<<2)>>2]&2047](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+T|0,Y,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((L<<1&2|K&1)<<2)>>2]&2047](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+T|0,Y,4);T=(Xe[H&511](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,Y,4)|0)+V|0;za=T+(Xe[H&511](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,Y,4)|0)|0}else{Y=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(K|0)){za=536870912;break}if((K<<D|0)>(c[(a+12268|0)>>2]<<D|0)){za=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){za=536870912;break}if((L<<D|0)>(c[(a+12276|0)>>2]<<D|0)){za=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;T=(B&1)<<1|1;d:do{if((c[a+11740>>2]|0)==1){if((K<<D|0)==0){V=0;while(1){_=c[a+12160+(V<<3)>>2]|0;R=(c[a+12160+(V<<3)+4>>2]|0)+(L<<D)|0;W=((ca(c[a+12128+(V<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((V&1)<<(B&1|4))|0;la=c[a+12128+(V<<3)+4>>2]|0;if((L<<D|0)==0){X=V>>1;Aa=((ca(la,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;Ba=X}else{Aa=R-la|0;Ba=V>>1}la=((Aa&T)<<D)+(W&T)|0;X=(c[(a+12208|0)>>2]|0)+((ca(Ba,Y<<3)|0)+(V<<3&8))|0;if((B&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>1,Y)|0)+(_>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((R&T)<<D)+(_&T)|0)<<2)>>2]&2047](X,Z,Y,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Aa>>1,Y)|0)+(W>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(la<<2)>>2]&2047](X,Z,Y,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>2,Y)|0)+(_>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((R&T)<<D)+(_&T)|0)<<2)>>2]&4095](X,Z,Y);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Aa>>2,Y)|0)+(W>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](X,Z,Y)}V=V+1|0;if((V|0)>=4){break d}}}if((L<<D|0)==0){V=0;do{Z=(c[a+12160+(V<<3)>>2]|0)+(K<<D)|0;X=c[a+12160+(V<<3)+4>>2]|0;la=Z-(c[a+12128+(V<<3)>>2]|0)|0;W=V>>1;_=((ca(c[a+12128+(V<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(W<<(B&1|4))|0;R=(c[(a+12208|0)>>2]|0)+((V<<3&8)+(ca(W,Y<<3)|0))|0;if((B&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,Y)|0)+(Z>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((X&T)<<D)+(Z&T)|0)<<2)>>2]&2047](R,W,Y,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>1,Y)|0)+(la>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((_&T)<<D)+(la&T)|0)<<2)>>2]&2047](R,W,Y,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>2,Y)|0)+(Z>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<D)+(Z&T)|0)<<2)>>2]&4095](R,W,Y);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>2,Y)|0)+(la>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((_&T)<<D)+(la&T)|0)<<2)>>2]&4095](R,W,Y)}V=V+1|0;}while((V|0)<4)}else{V=0;do{W=(c[a+12160+(V<<3)>>2]|0)+(K<<D)|0;R=(c[a+12160+(V<<3)+4>>2]|0)+(L<<D)|0;la=W-(c[a+12128+(V<<3)>>2]|0)|0;_=R-(c[a+12128+(V<<3)+4>>2]|0)|0;Z=(c[(a+12208|0)>>2]|0)+((V<<3&8)+(ca(V>>1,Y<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>1,Y)|0)+(W>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((R&T)<<D)+(W&T)|0)<<2)>>2]&2047](Z,X,Y,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>1,Y)|0)+(la>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((_&T)<<D)+(la&T)|0)<<2)>>2]&2047](Z,X,Y,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>2,Y)|0)+(W>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((R&T)<<D)+(W&T)|0)<<2)>>2]&4095](Z,X,Y);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>2,Y)|0)+(la>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((_&T)<<D)+(la&T)|0)<<2)>>2]&4095](Z,X,Y)}V=V+1|0;}while((V|0)<4)}}else{V=(c[a+12160>>2]|0)+(K<<D)|0;X=(c[a+12164>>2]|0)+(L<<D)|0;Z=c[a+12128>>2]|0;if((K<<D|0)==0){Ca=(ca(Z,S-Q|0)|0)/(Q|0)|0}else{Ca=V-Z|0}Z=c[a+12132>>2]|0;if((L<<D|0)==0){Da=(ca(Z,S-Q|0)|0)/(Q|0)|0}else{Da=X-Z|0}Z=((Da&T)<<D)+(Ca&T)|0;if((B&1|0)==0){la=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,Y)|0)+(V>>1))|0;mf[c[(c[a+12444>>2]|0)+((((X&T)<<D)+(V&T)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,la,Y,16);la=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Da>>1,Y)|0)+(Ca>>1))|0;mf[c[(c[a+12448>>2]|0)+(Z<<2)>>2]&2047](c[(a+12208|0)>>2]|0,la,Y,16);break}else{la=(ca(X>>2,Y)|0)+(V>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<D)+(V&T)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+la|0,Y);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<D)+(V&T)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(la+8|0)|0,Y);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<D)+(V&T)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Y<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(la+(Y<<3))|0,Y);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&T)<<D)+(V&T)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Y<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((la+8|0)+(Y<<3))|0,Y);la=(ca(Da>>2,Y)|0)+(Ca>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+la|0,Y);ef[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(la+8|0)|0,Y);ef[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Y<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(la+(Y<<3))|0,Y);ef[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Y<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((la+8|0)+(Y<<3))|0,Y);break}}}while(0);za=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,Y,16)|0}}while(0);c[(C+(((L<<3)+K&63)<<2)|0)>>2]=M;c[s+(((L<<3)+K&63)<<2)>>2]=za;T=c[(j+16|0)>>2]>>D;Q=c[(j+20|0)>>2]>>D;S=(ca((d[y+((Q<<D)-A)|0]|0)+(d[y+((T<<D)-z)|0]|0)|0,p)|0)+za|0;if((S|0)>=(oa|0)){wa=oa;xa=pa;ya=qa;break}c[(n|0)>>2]=T;c[o+4>>2]=Q;wa=S;xa=T;ya=Q}}while(0);K=c[(j+28|0)>>2]>>D;L=c[(j+24|0)>>2]>>D;M=L+J+(K<<11)|0;do{if((c[(C+(((K<<3)+L&63)<<2)|0)>>2]|0)==(M|0)){Ea=wa;Fa=xa;Ga=ya}else{do{if((B&4|0)==0){Q=c[a+12416>>2]|0;T=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ca(Q,K)|0)+L)|0;ba=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){Ha=ba;break}S=c[a+12208>>2]|0;la=(ca(T,K>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&2047](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+la|0,T,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&2047](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+la|0,T,4);la=(Xe[H&511](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,T,4)|0)+ba|0;Ha=la+(Xe[H&511](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,T,4)|0)|0}else{T=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Ha=536870912;break}if((L<<D|0)>(c[(a+12268|0)>>2]<<D|0)){Ha=536870912;break}if((c[(a+12272|0)>>2]|0)>(K|0)){Ha=536870912;break}if((K<<D|0)>(c[(a+12276|0)>>2]<<D|0)){Ha=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;la=(B&1)<<1|1;e:do{if((c[a+11740>>2]|0)==1){if((L<<D|0)==0){ba=0;while(1){Z=c[a+12160+(ba<<3)>>2]|0;V=(c[a+12160+(ba<<3)+4>>2]|0)+(K<<D)|0;X=((ca(c[a+12128+(ba<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((ba&1)<<(B&1|4))|0;_=c[a+12128+(ba<<3)+4>>2]|0;if((K<<D|0)==0){W=ba>>1;Ia=((ca(_,S-Q|0)|0)/(Q|0)|0)+(W<<(B&1|4))|0;Ja=W}else{Ia=V-_|0;Ja=ba>>1}_=((Ia&la)<<D)+(X&la)|0;W=(c[(a+12208|0)>>2]|0)+((ca(Ja,T<<3)|0)+(ba<<3&8))|0;if((B&1|0)==0){R=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>1,T)|0)+(Z>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((V&la)<<D)+(Z&la)|0)<<2)>>2]&2047](W,R,T,8);R=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ia>>1,T)|0)+(X>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(_<<2)>>2]&2047](W,R,T,8)}else{R=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>2,T)|0)+(Z>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<D)+(Z&la)|0)<<2)>>2]&4095](W,R,T);R=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ia>>2,T)|0)+(X>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](W,R,T)}ba=ba+1|0;if((ba|0)>=4){break e}}}if((K<<D|0)==0){ba=0;do{R=(c[a+12160+(ba<<3)>>2]|0)+(L<<D)|0;W=c[a+12160+(ba<<3)+4>>2]|0;_=R-(c[a+12128+(ba<<3)>>2]|0)|0;X=ba>>1;Z=((ca(c[a+12128+(ba<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;V=(c[(a+12208|0)>>2]|0)+((ba<<3&8)+(ca(X,T<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,T)|0)+(R>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((W&la)<<D)+(R&la)|0)<<2)>>2]&2047](V,X,T,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Z>>1,T)|0)+(_>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((Z&la)<<D)+(_&la)|0)<<2)>>2]&2047](V,X,T,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>2,T)|0)+(R>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<D)+(R&la)|0)<<2)>>2]&4095](V,X,T);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Z>>2,T)|0)+(_>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((Z&la)<<D)+(_&la)|0)<<2)>>2]&4095](V,X,T)}ba=ba+1|0;}while((ba|0)<4)}else{ba=0;do{X=(c[a+12160+(ba<<3)>>2]|0)+(L<<D)|0;V=(c[a+12160+(ba<<3)+4>>2]|0)+(K<<D)|0;_=X-(c[a+12128+(ba<<3)>>2]|0)|0;Z=V-(c[a+12128+(ba<<3)+4>>2]|0)|0;R=(c[(a+12208|0)>>2]|0)+((ba<<3&8)+(ca(ba>>1,T<<3)|0))|0;if((B&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>1,T)|0)+(X>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((V&la)<<D)+(X&la)|0)<<2)>>2]&2047](R,W,T,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Z>>1,T)|0)+(_>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((Z&la)<<D)+(_&la)|0)<<2)>>2]&2047](R,W,T,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>2,T)|0)+(X>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<D)+(X&la)|0)<<2)>>2]&4095](R,W,T);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Z>>2,T)|0)+(_>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((Z&la)<<D)+(_&la)|0)<<2)>>2]&4095](R,W,T)}ba=ba+1|0;}while((ba|0)<4)}}else{ba=(c[a+12160>>2]|0)+(L<<D)|0;W=(c[a+12164>>2]|0)+(K<<D)|0;R=c[a+12128>>2]|0;if((L<<D|0)==0){Ka=(ca(R,S-Q|0)|0)/(Q|0)|0}else{Ka=ba-R|0}R=c[a+12132>>2]|0;if((K<<D|0)==0){La=(ca(R,S-Q|0)|0)/(Q|0)|0}else{La=W-R|0}R=((La&la)<<D)+(Ka&la)|0;if((B&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,T)|0)+(ba>>1))|0;mf[c[(c[a+12444>>2]|0)+((((W&la)<<D)+(ba&la)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,_,T,16);_=(c[a+12352+(l<<4)+32>>2]|0)+((ca(La>>1,T)|0)+(Ka>>1))|0;mf[c[(c[a+12448>>2]|0)+(R<<2)>>2]&2047](c[(a+12208|0)>>2]|0,_,T,16);break}else{_=(ca(W>>2,T)|0)+(ba>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<D)+(ba&la)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+_|0,T);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<D)+(ba&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_+8|0)|0,T);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<D)+(ba&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(T<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_+(T<<3))|0,T);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&la)<<D)+(ba&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((_+8|0)+(T<<3))|0,T);_=(ca(La>>2,T)|0)+(Ka>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(R<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+_|0,T);ef[c[(c[(a+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_+8|0)|0,T);ef[c[(c[(a+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(T<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_+(T<<3))|0,T);ef[c[(c[(a+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((_+8|0)+(T<<3))|0,T);break}}}while(0);Ha=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,T,16)|0}}while(0);c[(C+(((K<<3)+L&63)<<2)|0)>>2]=M;c[s+(((K<<3)+L&63)<<2)>>2]=Ha;la=c[(j+24|0)>>2]>>D;Q=c[(j+28|0)>>2]>>D;S=(ca((d[y+((Q<<D)-A)|0]|0)+(d[y+((la<<D)-z)|0]|0)|0,p)|0)+Ha|0;if((S|0)>=(wa|0)){Ea=wa;Fa=xa;Ga=ya;break}c[(n|0)>>2]=la;c[o+4>>2]=Q;Ea=S;Fa=la;Ga=Q}}while(0);L=(b[m+(r<<2)>>1]<<15)+32768>>16;K=(b[m+(r<<2)+2>>1]<<15)+32768>>16;M=(L|0)>(v|0)?v:L;L=(t|0)>(M|0)?t:M;M=(K|0)>(w|0)?w:K;K=(u|0)>(M|0)?u:M;M=L+J+(K<<11)|0;if((c[(C+(((K<<3)+L&63)<<2)|0)>>2]|0)==(M|0)){Ma=Ea;Na=Fa;Oa=Ga;break}do{if((B&4|0)==0){Q=c[a+12416>>2]|0;la=c[a+12420>>2]|0;S=(c[a+12352+(l<<4)>>2]|0)+((ca(Q,K)|0)+L)|0;Y=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,S,Q,8)|0;if((B&2|0)==0){Pa=Y;break}S=c[a+12208>>2]|0;_=(ca(la,K>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&2047](S+(Q<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+_|0,la,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((K<<1&2|L&1)<<2)>>2]&2047](S+(Q<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+_|0,la,4);_=(Xe[H&511](a,S+(Q<<4)|0,c[a+12288+(k<<4)+4>>2]|0,la,4)|0)+Y|0;Pa=_+(Xe[H&511](a,S+(Q<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,la,4)|0)|0}else{la=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Pa=536870912;break}if((L<<D|0)>(c[(a+12268|0)>>2]<<D|0)){Pa=536870912;break}if((c[(a+12272|0)>>2]|0)>(K|0)){Pa=536870912;break}if((K<<D|0)>(c[(a+12276|0)>>2]<<D|0)){Pa=536870912;break}Q=e[a+13872>>1]|0;S=e[a+13874>>1]|0;_=(B&1)<<1|1;f:do{if((c[a+11740>>2]|0)==1){if((L<<D|0)==0){Y=0;while(1){R=c[a+12160+(Y<<3)>>2]|0;ba=(c[a+12160+(Y<<3)+4>>2]|0)+(K<<D)|0;W=((ca(c[a+12128+(Y<<3)>>2]|0,S-Q|0)|0)/(Q|0)|0)+((Y&1)<<(B&1|4))|0;Z=c[a+12128+(Y<<3)+4>>2]|0;if((K<<D|0)==0){X=Y>>1;Qa=((ca(Z,S-Q|0)|0)/(Q|0)|0)+(X<<(B&1|4))|0;Ra=X}else{Qa=ba-Z|0;Ra=Y>>1}Z=((Qa&_)<<D)+(W&_)|0;X=(c[(a+12208|0)>>2]|0)+((ca(Ra,la<<3)|0)+(Y<<3&8))|0;if((B&1|0)==0){V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ba>>1,la)|0)+(R>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((ba&_)<<D)+(R&_)|0)<<2)>>2]&2047](X,V,la,8);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Qa>>1,la)|0)+(W>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Z<<2)>>2]&2047](X,V,la,8)}else{V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(ba>>2,la)|0)+(R>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((ba&_)<<D)+(R&_)|0)<<2)>>2]&4095](X,V,la);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Qa>>2,la)|0)+(W>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095](X,V,la)}Y=Y+1|0;if((Y|0)>=4){break f}}}if((K<<D|0)==0){Y=0;do{T=(c[a+12160+(Y<<3)>>2]|0)+(L<<D)|0;V=c[a+12160+(Y<<3)+4>>2]|0;X=T-(c[a+12128+(Y<<3)>>2]|0)|0;Z=Y>>1;W=((ca(c[a+12128+(Y<<3)+4>>2]|0,S-Q|0)|0)/(Q|0)|0)+(Z<<(B&1|4))|0;R=(c[(a+12208|0)>>2]|0)+((Y<<3&8)+(ca(Z,la<<3)|0))|0;if((B&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>1,la)|0)+(T>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((V&_)<<D)+(T&_)|0)<<2)>>2]&2047](R,Z,la,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>1,la)|0)+(X>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((W&_)<<D)+(X&_)|0)<<2)>>2]&2047](R,Z,la,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>2,la)|0)+(T>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<D)+(T&_)|0)<<2)>>2]&4095](R,Z,la);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>2,la)|0)+(X>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((W&_)<<D)+(X&_)|0)<<2)>>2]&4095](R,Z,la)}Y=Y+1|0;}while((Y|0)<4)}else{Y=0;do{Z=(c[a+12160+(Y<<3)>>2]|0)+(L<<D)|0;R=(c[a+12160+(Y<<3)+4>>2]|0)+(K<<D)|0;X=Z-(c[a+12128+(Y<<3)>>2]|0)|0;W=R-(c[a+12128+(Y<<3)+4>>2]|0)|0;T=(c[(a+12208|0)>>2]|0)+((Y<<3&8)+(ca(Y>>1,la<<3)|0))|0;if((B&1|0)==0){V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>1,la)|0)+(Z>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((R&_)<<D)+(Z&_)|0)<<2)>>2]&2047](T,V,la,8);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>1,la)|0)+(X>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((W&_)<<D)+(X&_)|0)<<2)>>2]&2047](T,V,la,8)}else{V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>2,la)|0)+(Z>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((R&_)<<D)+(Z&_)|0)<<2)>>2]&4095](T,V,la);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>2,la)|0)+(X>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((W&_)<<D)+(X&_)|0)<<2)>>2]&4095](T,V,la)}Y=Y+1|0;}while((Y|0)<4)}}else{Y=(c[a+12160>>2]|0)+(L<<D)|0;V=(c[a+12164>>2]|0)+(K<<D)|0;T=c[a+12128>>2]|0;if((L<<D|0)==0){Sa=(ca(T,S-Q|0)|0)/(Q|0)|0}else{Sa=Y-T|0}T=c[a+12132>>2]|0;if((K<<D|0)==0){Ta=(ca(T,S-Q|0)|0)/(Q|0)|0}else{Ta=V-T|0}T=((Ta&_)<<D)+(Sa&_)|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>1,la)|0)+(Y>>1))|0;mf[c[(c[a+12444>>2]|0)+((((V&_)<<D)+(Y&_)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,X,la,16);X=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Ta>>1,la)|0)+(Sa>>1))|0;mf[c[(c[a+12448>>2]|0)+(T<<2)>>2]&2047](c[(a+12208|0)>>2]|0,X,la,16);break}else{X=(ca(V>>2,la)|0)+(Y>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<D)+(Y&_)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+X|0,la);ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<D)+(Y&_)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(X+8|0)|0,la);ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<D)+(Y&_)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(la<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(X+(la<<3))|0,la);ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&_)<<D)+(Y&_)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((la<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((X+8|0)+(la<<3))|0,la);X=(ca(Ta>>2,la)|0)+(Sa>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+X|0,la);ef[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(X+8|0)|0,la);ef[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(la<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(X+(la<<3))|0,la);ef[c[(c[(a+12456|0)>>2]|0)+64+(T<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((la<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((X+8|0)+(la<<3))|0,la);break}}}while(0);Pa=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,la,16)|0}}while(0);c[(C+(((K<<3)+L&63)<<2)|0)>>2]=M;c[s+(((K<<3)+L&63)<<2)>>2]=Pa;_=(ca((d[y+((K<<D)-A)|0]|0)+(d[y+((L<<D)-z)|0]|0)|0,p)|0)+Pa|0;if((_|0)>=(Ea|0)){Ma=Ea;Na=Fa;Oa=Ga;break}c[(n|0)>>2]=L;c[o+4>>2]=K;Ma=_;Na=L;Oa=K}else{I=1}}if(I){I=0;if(1){_=c[(j+12|0)>>2]>>D;Q=c[(j+8|0)>>2]>>D;S=Q+J+(_<<11)|0;do{if((c[(C+(((_<<3)+Q&63)<<2)|0)>>2]|0)==(S|0)){Ua=1e6;Va=0;Wa=0}else{do{if((B&4|0)==0){X=c[a+12416>>2]|0;T=c[a+12420>>2]|0;Y=(c[a+12352+(l<<4)>>2]|0)+((ca(X,_)|0)+Q)|0;V=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,Y,X,8)|0;if((B&2|0)==0){Xa=V;break}Y=c[a+12208>>2]|0;W=(ca(T,_>>1)|0)+(Q>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&2047](Y+(X<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+W|0,T,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&2047](Y+(X<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+W|0,T,4);W=(Xe[H&511](a,Y+(X<<4)|0,c[a+12288+(k<<4)+4>>2]|0,T,4)|0)+V|0;Xa=W+(Xe[H&511](a,Y+(X<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,T,4)|0)|0}else{T=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Q|0)){Xa=536870912;break}if((Q<<D|0)>(c[(a+12268|0)>>2]<<D|0)){Xa=536870912;break}if((c[(a+12272|0)>>2]|0)>(_|0)){Xa=536870912;break}if((_<<D|0)>(c[(a+12276|0)>>2]<<D|0)){Xa=536870912;break}X=e[a+13872>>1]|0;Y=e[a+13874>>1]|0;W=(B&1)<<1|1;g:do{if((c[a+11740>>2]|0)==1){if((Q<<D|0)==0){V=0;while(1){Z=c[a+12160+(V<<3)>>2]|0;R=(c[a+12160+(V<<3)+4>>2]|0)+(_<<D)|0;ba=((ca(c[a+12128+(V<<3)>>2]|0,Y-X|0)|0)/(X|0)|0)+((V&1)<<(B&1|4))|0;Ya=c[a+12128+(V<<3)+4>>2]|0;if((_<<D|0)==0){Za=V>>1;_a=((ca(Ya,Y-X|0)|0)/(X|0)|0)+(Za<<(B&1|4))|0;$a=Za}else{_a=R-Ya|0;$a=V>>1}Ya=((_a&W)<<D)+(ba&W)|0;Za=(c[(a+12208|0)>>2]|0)+((ca($a,T<<3)|0)+(V<<3&8))|0;if((B&1|0)==0){ab=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>1,T)|0)+(Z>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((R&W)<<D)+(Z&W)|0)<<2)>>2]&2047](Za,ab,T,8);ab=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_a>>1,T)|0)+(ba>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Ya<<2)>>2]&2047](Za,ab,T,8)}else{ab=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>2,T)|0)+(Z>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((R&W)<<D)+(Z&W)|0)<<2)>>2]&4095](Za,ab,T);ab=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_a>>2,T)|0)+(ba>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095](Za,ab,T)}V=V+1|0;if((V|0)>=4){break g}}}if((_<<D|0)==0){V=0;do{ab=(c[a+12160+(V<<3)>>2]|0)+(Q<<D)|0;Za=c[a+12160+(V<<3)+4>>2]|0;Ya=ab-(c[a+12128+(V<<3)>>2]|0)|0;ba=V>>1;Z=((ca(c[a+12128+(V<<3)+4>>2]|0,Y-X|0)|0)/(X|0)|0)+(ba<<(B&1|4))|0;R=(c[(a+12208|0)>>2]|0)+((V<<3&8)+(ca(ba,T<<3)|0))|0;if((B&1|0)==0){ba=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Za>>1,T)|0)+(ab>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Za&W)<<D)+(ab&W)|0)<<2)>>2]&2047](R,ba,T,8);ba=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Z>>1,T)|0)+(Ya>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((Z&W)<<D)+(Ya&W)|0)<<2)>>2]&2047](R,ba,T,8)}else{ba=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Za>>2,T)|0)+(ab>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<D)+(ab&W)|0)<<2)>>2]&4095](R,ba,T);ba=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Z>>2,T)|0)+(Ya>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((Z&W)<<D)+(Ya&W)|0)<<2)>>2]&4095](R,ba,T)}V=V+1|0;}while((V|0)<4)}else{V=0;do{ba=(c[a+12160+(V<<3)>>2]|0)+(Q<<D)|0;R=(c[a+12160+(V<<3)+4>>2]|0)+(_<<D)|0;Ya=ba-(c[a+12128+(V<<3)>>2]|0)|0;Z=R-(c[a+12128+(V<<3)+4>>2]|0)|0;ab=(c[(a+12208|0)>>2]|0)+((V<<3&8)+(ca(V>>1,T<<3)|0))|0;if((B&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>1,T)|0)+(ba>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((R&W)<<D)+(ba&W)|0)<<2)>>2]&2047](ab,Za,T,8);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Z>>1,T)|0)+(Ya>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((Z&W)<<D)+(Ya&W)|0)<<2)>>2]&2047](ab,Za,T,8)}else{Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(R>>2,T)|0)+(ba>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((R&W)<<D)+(ba&W)|0)<<2)>>2]&4095](ab,Za,T);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Z>>2,T)|0)+(Ya>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((Z&W)<<D)+(Ya&W)|0)<<2)>>2]&4095](ab,Za,T)}V=V+1|0;}while((V|0)<4)}}else{V=(c[a+12160>>2]|0)+(Q<<D)|0;Za=(c[a+12164>>2]|0)+(_<<D)|0;ab=c[a+12128>>2]|0;if((Q<<D|0)==0){bb=(ca(ab,Y-X|0)|0)/(X|0)|0}else{bb=V-ab|0}ab=c[a+12132>>2]|0;if((_<<D|0)==0){cb=(ca(ab,Y-X|0)|0)/(X|0)|0}else{cb=Za-ab|0}ab=((cb&W)<<D)+(bb&W)|0;if((B&1|0)==0){Ya=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Za>>1,T)|0)+(V>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Za&W)<<D)+(V&W)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Ya,T,16);Ya=(c[a+12352+(l<<4)+32>>2]|0)+((ca(cb>>1,T)|0)+(bb>>1))|0;mf[c[(c[a+12448>>2]|0)+(ab<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Ya,T,16);break}else{Ya=(ca(Za>>2,T)|0)+(V>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<D)+(V&W)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Ya|0,T);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<D)+(V&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ya+8|0)|0,T);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<D)+(V&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(T<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ya+(T<<3))|0,T);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Za&W)<<D)+(V&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Ya+8|0)+(T<<3))|0,T);Ya=(ca(cb>>2,T)|0)+(bb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Ya|0,T);ef[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ya+8|0)|0,T);ef[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(T<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ya+(T<<3))|0,T);ef[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Ya+8|0)+(T<<3))|0,T);break}}}while(0);Xa=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,T,16)|0}}while(0);c[(C+(((_<<3)+Q&63)<<2)|0)>>2]=S;c[s+(((_<<3)+Q&63)<<2)>>2]=Xa;la=c[(j+8|0)>>2]>>D;W=c[(j+12|0)>>2]>>D;X=(ca((d[y+((W<<D)-A)|0]|0)+(d[y+((la<<D)-z)|0]|0)|0,p)|0)+Xa|0;if((X|0)>=1e6){Ua=1e6;Va=0;Wa=0;break}c[(n|0)>>2]=la;c[o+4>>2]=W;Ua=X;Va=la;Wa=W}}while(0);Q=(b[m+(r<<2)>>1]<<15)+32768>>16;_=(b[m+(r<<2)+2>>1]<<15)+32768>>16;S=(Q|0)>(v|0)?v:Q;Q=(t|0)>(S|0)?t:S;S=(_|0)>(w|0)?w:_;_=(u|0)>(S|0)?u:S;S=Q+J+(_<<11)|0;do{if((c[(C+(((_<<3)+Q&63)<<2)|0)>>2]|0)==(S|0)){db=Ua;eb=Va;fb=Wa}else{do{if((B&4|0)==0){K=c[a+12416>>2]|0;L=c[a+12420>>2]|0;M=(c[a+12352+(l<<4)>>2]|0)+((ca(K,_)|0)+Q)|0;W=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,M,K,8)|0;if((B&2|0)==0){gb=W;break}M=c[a+12208>>2]|0;la=(ca(L,_>>1)|0)+(Q>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&2047](M+(K<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+la|0,L,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&2047](M+(K<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+la|0,L,4);la=(Xe[H&511](a,M+(K<<4)|0,c[a+12288+(k<<4)+4>>2]|0,L,4)|0)+W|0;gb=la+(Xe[H&511](a,M+(K<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,L,4)|0)|0}else{L=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Q|0)){gb=536870912;break}if((Q<<D|0)>(c[(a+12268|0)>>2]<<D|0)){gb=536870912;break}if((c[(a+12272|0)>>2]|0)>(_|0)){gb=536870912;break}if((_<<D|0)>(c[(a+12276|0)>>2]<<D|0)){gb=536870912;break}K=e[a+13872>>1]|0;M=e[a+13874>>1]|0;la=(B&1)<<1|1;h:do{if((c[a+11740>>2]|0)==1){if((Q<<D|0)==0){W=0;while(1){X=c[a+12160+(W<<3)>>2]|0;Y=(c[a+12160+(W<<3)+4>>2]|0)+(_<<D)|0;Ya=((ca(c[a+12128+(W<<3)>>2]|0,M-K|0)|0)/(K|0)|0)+((W&1)<<(B&1|4))|0;ab=c[a+12128+(W<<3)+4>>2]|0;if((_<<D|0)==0){V=W>>1;hb=((ca(ab,M-K|0)|0)/(K|0)|0)+(V<<(B&1|4))|0;ib=V}else{hb=Y-ab|0;ib=W>>1}ab=((hb&la)<<D)+(Ya&la)|0;V=(c[(a+12208|0)>>2]|0)+((ca(ib,L<<3)|0)+(W<<3&8))|0;if((B&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,L)|0)+(X>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&la)<<D)+(X&la)|0)<<2)>>2]&2047](V,Za,L,8);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(hb>>1,L)|0)+(Ya>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(ab<<2)>>2]&2047](V,Za,L,8)}else{Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>2,L)|0)+(X>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&la)<<D)+(X&la)|0)<<2)>>2]&4095](V,Za,L);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(hb>>2,L)|0)+(Ya>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095](V,Za,L)}W=W+1|0;if((W|0)>=4){break h}}}if((_<<D|0)==0){W=0;do{Za=(c[a+12160+(W<<3)>>2]|0)+(Q<<D)|0;V=c[a+12160+(W<<3)+4>>2]|0;ab=Za-(c[a+12128+(W<<3)>>2]|0)|0;Ya=W>>1;X=((ca(c[a+12128+(W<<3)+4>>2]|0,M-K|0)|0)/(K|0)|0)+(Ya<<(B&1|4))|0;Y=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ca(Ya,L<<3)|0))|0;if((B&1|0)==0){Ya=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>1,L)|0)+(Za>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((V&la)<<D)+(Za&la)|0)<<2)>>2]&2047](Y,Ya,L,8);Ya=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>1,L)|0)+(ab>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((X&la)<<D)+(ab&la)|0)<<2)>>2]&2047](Y,Ya,L,8)}else{Ya=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>2,L)|0)+(Za>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<D)+(Za&la)|0)<<2)>>2]&4095](Y,Ya,L);Ya=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>2,L)|0)+(ab>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((X&la)<<D)+(ab&la)|0)<<2)>>2]&4095](Y,Ya,L)}W=W+1|0;}while((W|0)<4)}else{W=0;do{Ya=(c[a+12160+(W<<3)>>2]|0)+(Q<<D)|0;Y=(c[a+12160+(W<<3)+4>>2]|0)+(_<<D)|0;ab=Ya-(c[a+12128+(W<<3)>>2]|0)|0;X=Y-(c[a+12128+(W<<3)+4>>2]|0)|0;Za=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ca(W>>1,L<<3)|0))|0;if((B&1|0)==0){V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,L)|0)+(Ya>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&la)<<D)+(Ya&la)|0)<<2)>>2]&2047](Za,V,L,8);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>1,L)|0)+(ab>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((X&la)<<D)+(ab&la)|0)<<2)>>2]&2047](Za,V,L,8)}else{V=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>2,L)|0)+(Ya>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&la)<<D)+(Ya&la)|0)<<2)>>2]&4095](Za,V,L);V=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>2,L)|0)+(ab>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((X&la)<<D)+(ab&la)|0)<<2)>>2]&4095](Za,V,L)}W=W+1|0;}while((W|0)<4)}}else{W=(c[a+12160>>2]|0)+(Q<<D)|0;V=(c[a+12164>>2]|0)+(_<<D)|0;Za=c[a+12128>>2]|0;if((Q<<D|0)==0){jb=(ca(Za,M-K|0)|0)/(K|0)|0}else{jb=W-Za|0}Za=c[a+12132>>2]|0;if((_<<D|0)==0){kb=(ca(Za,M-K|0)|0)/(K|0)|0}else{kb=V-Za|0}Za=((kb&la)<<D)+(jb&la)|0;if((B&1|0)==0){ab=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(V>>1,L)|0)+(W>>1))|0;mf[c[(c[a+12444>>2]|0)+((((V&la)<<D)+(W&la)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ab,L,16);ab=(c[a+12352+(l<<4)+32>>2]|0)+((ca(kb>>1,L)|0)+(jb>>1))|0;mf[c[(c[a+12448>>2]|0)+(Za<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ab,L,16);break}else{ab=(ca(V>>2,L)|0)+(W>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<D)+(W&la)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ab|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<D)+(W&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ab+8|0)|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<D)+(W&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ab+(L<<3))|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((V&la)<<D)+(W&la)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ab+8|0)+(L<<3))|0,L);ab=(ca(kb>>2,L)|0)+(jb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ab|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ab+8|0)|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ab+(L<<3))|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ab+8|0)+(L<<3))|0,L);break}}}while(0);gb=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,L,16)|0}}while(0);c[(C+(((_<<3)+Q&63)<<2)|0)>>2]=S;c[s+(((_<<3)+Q&63)<<2)>>2]=gb;la=(ca((d[y+((_<<D)-A)|0]|0)+(d[y+((Q<<D)-z)|0]|0)|0,p)|0)+gb|0;if((la|0)>=(Ua|0)){db=Ua;eb=Va;fb=Wa;break}c[(n|0)>>2]=Q;c[o+4>>2]=_;db=la;eb=Q;fb=_}}while(0);_=c[(j+76|0)>>2]>>D;Q=c[(j+72|0)>>2]>>D;S=Q+J+(_<<11)|0;if((c[(C+(((_<<3)+Q&63)<<2)|0)>>2]|0)==(S|0)){Ma=db;Na=eb;Oa=fb;break}do{if((B&4|0)==0){la=c[a+12416>>2]|0;K=c[a+12420>>2]|0;M=(c[a+12352+(l<<4)>>2]|0)+((ca(la,_)|0)+Q)|0;T=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,M,la,8)|0;if((B&2|0)==0){lb=T;break}M=c[a+12208>>2]|0;ab=(ca(K,_>>1)|0)+(Q>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&2047](M+(la<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ab|0,K,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((_<<1&2|Q&1)<<2)>>2]&2047](M+(la<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ab|0,K,4);ab=(Xe[H&511](a,M+(la<<4)|0,c[a+12288+(k<<4)+4>>2]|0,K,4)|0)+T|0;lb=ab+(Xe[H&511](a,M+(la<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,K,4)|0)|0}else{K=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(Q|0)){lb=536870912;break}if((Q<<D|0)>(c[(a+12268|0)>>2]<<D|0)){lb=536870912;break}if((c[(a+12272|0)>>2]|0)>(_|0)){lb=536870912;break}if((_<<D|0)>(c[(a+12276|0)>>2]<<D|0)){lb=536870912;break}la=e[a+13872>>1]|0;M=e[a+13874>>1]|0;ab=(B&1)<<1|1;i:do{if((c[a+11740>>2]|0)==1){if((Q<<D|0)==0){T=0;while(1){Za=c[a+12160+(T<<3)>>2]|0;W=(c[a+12160+(T<<3)+4>>2]|0)+(_<<D)|0;V=((ca(c[a+12128+(T<<3)>>2]|0,M-la|0)|0)/(la|0)|0)+((T&1)<<(B&1|4))|0;X=c[a+12128+(T<<3)+4>>2]|0;if((_<<D|0)==0){Ya=T>>1;mb=((ca(X,M-la|0)|0)/(la|0)|0)+(Ya<<(B&1|4))|0;nb=Ya}else{mb=W-X|0;nb=T>>1}X=((mb&ab)<<D)+(V&ab)|0;Ya=(c[(a+12208|0)>>2]|0)+((ca(nb,K<<3)|0)+(T<<3&8))|0;if((B&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,K)|0)+(Za>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((W&ab)<<D)+(Za&ab)|0)<<2)>>2]&2047](Ya,Y,K,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(mb>>1,K)|0)+(V>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(X<<2)>>2]&2047](Ya,Y,K,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>2,K)|0)+(Za>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&ab)<<D)+(Za&ab)|0)<<2)>>2]&4095](Ya,Y,K);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(mb>>2,K)|0)+(V>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(X<<2)>>2]&4095](Ya,Y,K)}T=T+1|0;if((T|0)>=4){break i}}}if((_<<D|0)==0){T=0;do{L=(c[a+12160+(T<<3)>>2]|0)+(Q<<D)|0;Y=c[a+12160+(T<<3)+4>>2]|0;Ya=L-(c[a+12128+(T<<3)>>2]|0)|0;X=T>>1;V=((ca(c[a+12128+(T<<3)+4>>2]|0,M-la|0)|0)/(la|0)|0)+(X<<(B&1|4))|0;Za=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ca(X,K<<3)|0))|0;if((B&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,K)|0)+(L>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&ab)<<D)+(L&ab)|0)<<2)>>2]&2047](Za,X,K,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(V>>1,K)|0)+(Ya>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((V&ab)<<D)+(Ya&ab)|0)<<2)>>2]&2047](Za,X,K,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>2,K)|0)+(L>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<D)+(L&ab)|0)<<2)>>2]&4095](Za,X,K);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(V>>2,K)|0)+(Ya>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((V&ab)<<D)+(Ya&ab)|0)<<2)>>2]&4095](Za,X,K)}T=T+1|0;}while((T|0)<4)}else{T=0;do{X=(c[a+12160+(T<<3)>>2]|0)+(Q<<D)|0;Za=(c[a+12160+(T<<3)+4>>2]|0)+(_<<D)|0;Ya=X-(c[a+12128+(T<<3)>>2]|0)|0;V=Za-(c[a+12128+(T<<3)+4>>2]|0)|0;L=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ca(T>>1,K<<3)|0))|0;if((B&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Za>>1,K)|0)+(X>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Za&ab)<<D)+(X&ab)|0)<<2)>>2]&2047](L,Y,K,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(V>>1,K)|0)+(Ya>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((V&ab)<<D)+(Ya&ab)|0)<<2)>>2]&2047](L,Y,K,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Za>>2,K)|0)+(X>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Za&ab)<<D)+(X&ab)|0)<<2)>>2]&4095](L,Y,K);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(V>>2,K)|0)+(Ya>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((V&ab)<<D)+(Ya&ab)|0)<<2)>>2]&4095](L,Y,K)}T=T+1|0;}while((T|0)<4)}}else{T=(c[a+12160>>2]|0)+(Q<<D)|0;Y=(c[a+12164>>2]|0)+(_<<D)|0;L=c[a+12128>>2]|0;if((Q<<D|0)==0){ob=(ca(L,M-la|0)|0)/(la|0)|0}else{ob=T-L|0}L=c[a+12132>>2]|0;if((_<<D|0)==0){pb=(ca(L,M-la|0)|0)/(la|0)|0}else{pb=Y-L|0}L=((pb&ab)<<D)+(ob&ab)|0;if((B&1|0)==0){Ya=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,K)|0)+(T>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Y&ab)<<D)+(T&ab)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Ya,K,16);Ya=(c[a+12352+(l<<4)+32>>2]|0)+((ca(pb>>1,K)|0)+(ob>>1))|0;mf[c[(c[a+12448>>2]|0)+(L<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Ya,K,16);break}else{Ya=(ca(Y>>2,K)|0)+(T>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<D)+(T&ab)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Ya|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<D)+(T&ab)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ya+8|0)|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<D)+(T&ab)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ya+(K<<3))|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&ab)<<D)+(T&ab)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Ya+8|0)+(K<<3))|0,K);Ya=(ca(pb>>2,K)|0)+(ob>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(L<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Ya|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(L<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ya+8|0)|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(L<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ya+(K<<3))|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(L<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Ya+8|0)+(K<<3))|0,K);break}}}while(0);lb=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(C+(((_<<3)+Q&63)<<2)|0)>>2]=S;c[s+(((_<<3)+Q&63)<<2)>>2]=lb;ab=c[(j+72|0)>>2]>>D;la=c[(j+76|0)>>2]>>D;M=(ca((d[y+((la<<D)-A)|0]|0)+(d[y+((ab<<D)-z)|0]|0)|0,p)|0)+lb|0;if((M|0)>=(db|0)){Ma=db;Na=eb;Oa=fb;break}c[(n|0)>>2]=ab;c[o+4>>2]=la;Ma=M;Na=ab;Oa=la}else{I=1}}}while(0);do{if((Ma|0)>256){fb=(b[m+((r+1|0)<<2)>>1]<<15)+32768>>16;eb=(b[m+((r+1|0)<<2)+2>>1]<<15)+32768>>16;db=(fb|0)>(v|0)?v:fb;fb=(t|0)>(db|0)?t:db;db=(eb|0)>(w|0)?w:eb;eb=(u|0)>(db|0)?u:db;db=fb+J+(eb<<11)|0;do{if((c[(C+(((eb<<3)+fb&63)<<2)|0)>>2]|0)==(db|0)){qb=Ma;rb=Na;sb=Oa}else{do{if((B&4|0)==0){lb=c[a+12416>>2]|0;j=c[a+12420>>2]|0;ob=(c[a+12352+(l<<4)>>2]|0)+((ca(lb,eb)|0)+fb)|0;pb=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,ob,lb,8)|0;if((B&2|0)==0){tb=pb;break}ob=c[a+12208>>2]|0;mb=(ca(j,eb>>1)|0)+(fb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((eb<<1&2|fb&1)<<2)>>2]&2047](ob+(lb<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+mb|0,j,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((eb<<1&2|fb&1)<<2)>>2]&2047](ob+(lb<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+mb|0,j,4);mb=(Xe[H&511](a,ob+(lb<<4)|0,c[a+12288+(k<<4)+4>>2]|0,j,4)|0)+pb|0;tb=mb+(Xe[H&511](a,ob+(lb<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,j,4)|0)|0}else{j=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(fb|0)){tb=536870912;break}if((fb<<D|0)>(c[(a+12268|0)>>2]<<D|0)){tb=536870912;break}if((c[(a+12272|0)>>2]|0)>(eb|0)){tb=536870912;break}if((eb<<D|0)>(c[(a+12276|0)>>2]<<D|0)){tb=536870912;break}lb=e[a+13872>>1]|0;ob=e[a+13874>>1]|0;mb=(B&1)<<1|1;j:do{if((c[a+11740>>2]|0)==1){if((fb<<D|0)==0){pb=0;while(1){nb=c[a+12160+(pb<<3)>>2]|0;Wa=(c[a+12160+(pb<<3)+4>>2]|0)+(eb<<D)|0;Va=((ca(c[a+12128+(pb<<3)>>2]|0,ob-lb|0)|0)/(lb|0)|0)+((pb&1)<<(B&1|4))|0;Ua=c[a+12128+(pb<<3)+4>>2]|0;if((eb<<D|0)==0){gb=pb>>1;ub=((ca(Ua,ob-lb|0)|0)/(lb|0)|0)+(gb<<(B&1|4))|0;vb=gb}else{ub=Wa-Ua|0;vb=pb>>1}Ua=((ub&mb)<<D)+(Va&mb)|0;gb=(c[(a+12208|0)>>2]|0)+((ca(vb,j<<3)|0)+(pb<<3&8))|0;if((B&1|0)==0){jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Wa>>1,j)|0)+(nb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Wa&mb)<<D)+(nb&mb)|0)<<2)>>2]&2047](gb,jb,j,8);jb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ub>>1,j)|0)+(Va>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Ua<<2)>>2]&2047](gb,jb,j,8)}else{jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Wa>>2,j)|0)+(nb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Wa&mb)<<D)+(nb&mb)|0)<<2)>>2]&4095](gb,jb,j);jb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ub>>2,j)|0)+(Va>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Ua<<2)>>2]&4095](gb,jb,j)}pb=pb+1|0;if((pb|0)>=4){break j}}}if((eb<<D|0)==0){pb=0;do{jb=(c[a+12160+(pb<<3)>>2]|0)+(fb<<D)|0;gb=c[a+12160+(pb<<3)+4>>2]|0;Ua=jb-(c[a+12128+(pb<<3)>>2]|0)|0;Va=pb>>1;nb=((ca(c[a+12128+(pb<<3)+4>>2]|0,ob-lb|0)|0)/(lb|0)|0)+(Va<<(B&1|4))|0;Wa=(c[(a+12208|0)>>2]|0)+((pb<<3&8)+(ca(Va,j<<3)|0))|0;if((B&1|0)==0){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(gb>>1,j)|0)+(jb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((gb&mb)<<D)+(jb&mb)|0)<<2)>>2]&2047](Wa,Va,j,8);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(nb>>1,j)|0)+(Ua>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((nb&mb)<<D)+(Ua&mb)|0)<<2)>>2]&2047](Wa,Va,j,8)}else{Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(gb>>2,j)|0)+(jb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<D)+(jb&mb)|0)<<2)>>2]&4095](Wa,Va,j);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(nb>>2,j)|0)+(Ua>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((nb&mb)<<D)+(Ua&mb)|0)<<2)>>2]&4095](Wa,Va,j)}pb=pb+1|0;}while((pb|0)<4)}else{pb=0;do{Va=(c[a+12160+(pb<<3)>>2]|0)+(fb<<D)|0;Wa=(c[a+12160+(pb<<3)+4>>2]|0)+(eb<<D)|0;Ua=Va-(c[a+12128+(pb<<3)>>2]|0)|0;nb=Wa-(c[a+12128+(pb<<3)+4>>2]|0)|0;jb=(c[(a+12208|0)>>2]|0)+((pb<<3&8)+(ca(pb>>1,j<<3)|0))|0;if((B&1|0)==0){gb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Wa>>1,j)|0)+(Va>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Wa&mb)<<D)+(Va&mb)|0)<<2)>>2]&2047](jb,gb,j,8);gb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(nb>>1,j)|0)+(Ua>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((nb&mb)<<D)+(Ua&mb)|0)<<2)>>2]&2047](jb,gb,j,8)}else{gb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Wa>>2,j)|0)+(Va>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Wa&mb)<<D)+(Va&mb)|0)<<2)>>2]&4095](jb,gb,j);gb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(nb>>2,j)|0)+(Ua>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((nb&mb)<<D)+(Ua&mb)|0)<<2)>>2]&4095](jb,gb,j)}pb=pb+1|0;}while((pb|0)<4)}}else{pb=(c[a+12160>>2]|0)+(fb<<D)|0;gb=(c[a+12164>>2]|0)+(eb<<D)|0;jb=c[a+12128>>2]|0;if((fb<<D|0)==0){wb=(ca(jb,ob-lb|0)|0)/(lb|0)|0}else{wb=pb-jb|0}jb=c[a+12132>>2]|0;if((eb<<D|0)==0){xb=(ca(jb,ob-lb|0)|0)/(lb|0)|0}else{xb=gb-jb|0}jb=((xb&mb)<<D)+(wb&mb)|0;if((B&1|0)==0){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(gb>>1,j)|0)+(pb>>1))|0;mf[c[(c[a+12444>>2]|0)+((((gb&mb)<<D)+(pb&mb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Ua,j,16);Ua=(c[a+12352+(l<<4)+32>>2]|0)+((ca(xb>>1,j)|0)+(wb>>1))|0;mf[c[(c[a+12448>>2]|0)+(jb<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Ua,j,16);break}else{Ua=(ca(gb>>2,j)|0)+(pb>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<D)+(pb&mb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Ua|0,j);ef[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<D)+(pb&mb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ua+8|0)|0,j);ef[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<D)+(pb&mb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(j<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Ua+(j<<3))|0,j);ef[c[(c[(a+12452|0)>>2]|0)+64+((((gb&mb)<<D)+(pb&mb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((j<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Ua+8|0)+(j<<3))|0,j);Ua=(ca(xb>>2,j)|0)+(wb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Ua|0,j);ef[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ua+8|0)|0,j);ef[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(j<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Ua+(j<<3))|0,j);ef[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((j<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Ua+8|0)+(j<<3))|0,j);break}}}while(0);tb=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,j,16)|0}}while(0);c[(C+(((eb<<3)+fb&63)<<2)|0)>>2]=db;c[s+(((eb<<3)+fb&63)<<2)>>2]=tb;K=(ca((d[y+((eb<<D)-A)|0]|0)+(d[y+((fb<<D)-z)|0]|0)|0,p)|0)+tb|0;if((K|0)>=(Ma|0)){qb=Ma;rb=Na;sb=Oa;break}c[(n|0)>>2]=fb;c[o+4>>2]=eb;qb=K;rb=fb;sb=eb}}while(0);if(((c[(a+12480|0)>>2]|0)+1|0)>=(c[a+812>>2]|0)){yb=qb;zb=rb;Ab=sb;break}eb=(b[m+((r+q|0)<<2)>>1]<<15)+32768>>16;fb=(b[m+((r+q|0)<<2)+2>>1]<<15)+32768>>16;db=(eb|0)>(v|0)?v:eb;eb=(t|0)>(db|0)?t:db;db=(fb|0)>(w|0)?w:fb;fb=(u|0)>(db|0)?u:db;db=eb+J+(fb<<11)|0;if((c[(C+(((fb<<3)+eb&63)<<2)|0)>>2]|0)==(db|0)){yb=qb;zb=rb;Ab=sb;break}do{if((B&4|0)==0){I=c[a+12416>>2]|0;Q=c[a+12420>>2]|0;_=(c[a+12352+(l<<4)>>2]|0)+((ca(I,fb)|0)+eb)|0;S=Xe[G&511](a,c[a+12288+(k<<4)>>2]|0,_,I,8)|0;if((B&2|0)==0){Bb=S;break}_=c[a+12208>>2]|0;K=(ca(Q,fb>>1)|0)+(eb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((fb<<1&2|eb&1)<<2)>>2]&2047](_+(I<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+K|0,Q,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((fb<<1&2|eb&1)<<2)>>2]&2047](_+(I<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+K|0,Q,4);K=(Xe[H&511](a,_+(I<<4)|0,c[a+12288+(k<<4)+4>>2]|0,Q,4)|0)+S|0;Bb=K+(Xe[H&511](a,_+(I<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,Q,4)|0)|0}else{Q=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(eb|0)){Bb=536870912;break}if((eb<<D|0)>(c[(a+12268|0)>>2]<<D|0)){Bb=536870912;break}if((c[(a+12272|0)>>2]|0)>(fb|0)){Bb=536870912;break}if((fb<<D|0)>(c[(a+12276|0)>>2]<<D|0)){Bb=536870912;break}I=e[a+13872>>1]|0;_=e[a+13874>>1]|0;K=(B&1)<<1|1;k:do{if((c[a+11740>>2]|0)==1){if((eb<<D|0)==0){S=0;while(1){mb=c[a+12160+(S<<3)>>2]|0;lb=(c[a+12160+(S<<3)+4>>2]|0)+(fb<<D)|0;ob=((ca(c[a+12128+(S<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((S&1)<<(B&1|4))|0;Ua=c[a+12128+(S<<3)+4>>2]|0;if((fb<<D|0)==0){jb=S>>1;Cb=((ca(Ua,_-I|0)|0)/(I|0)|0)+(jb<<(B&1|4))|0;Db=jb}else{Cb=lb-Ua|0;Db=S>>1}Ua=((Cb&K)<<D)+(ob&K)|0;jb=(c[(a+12208|0)>>2]|0)+((ca(Db,Q<<3)|0)+(S<<3&8))|0;if((B&1|0)==0){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(lb>>1,Q)|0)+(mb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((lb&K)<<D)+(mb&K)|0)<<2)>>2]&2047](jb,pb,Q,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Cb>>1,Q)|0)+(ob>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Ua<<2)>>2]&2047](jb,pb,Q,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(lb>>2,Q)|0)+(mb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((lb&K)<<D)+(mb&K)|0)<<2)>>2]&4095](jb,pb,Q);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Cb>>2,Q)|0)+(ob>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Ua<<2)>>2]&4095](jb,pb,Q)}S=S+1|0;if((S|0)>=4){break k}}}if((fb<<D|0)==0){S=0;do{j=(c[a+12160+(S<<3)>>2]|0)+(eb<<D)|0;pb=c[a+12160+(S<<3)+4>>2]|0;jb=j-(c[a+12128+(S<<3)>>2]|0)|0;Ua=S>>1;ob=((ca(c[a+12128+(S<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(Ua<<(B&1|4))|0;mb=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ca(Ua,Q<<3)|0))|0;if((B&1|0)==0){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,Q)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&K)<<D)+(j&K)|0)<<2)>>2]&2047](mb,Ua,Q,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>1,Q)|0)+(jb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&K)<<D)+(jb&K)|0)<<2)>>2]&2047](mb,Ua,Q,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>2,Q)|0)+(j>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<D)+(j&K)|0)<<2)>>2]&4095](mb,Ua,Q);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>2,Q)|0)+(jb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ob&K)<<D)+(jb&K)|0)<<2)>>2]&4095](mb,Ua,Q)}S=S+1|0;}while((S|0)<4)}else{S=0;do{Ua=(c[a+12160+(S<<3)>>2]|0)+(eb<<D)|0;mb=(c[a+12160+(S<<3)+4>>2]|0)+(fb<<D)|0;jb=Ua-(c[a+12128+(S<<3)>>2]|0)|0;ob=mb-(c[a+12128+(S<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ca(S>>1,Q<<3)|0))|0;if((B&1|0)==0){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mb>>1,Q)|0)+(Ua>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((mb&K)<<D)+(Ua&K)|0)<<2)>>2]&2047](j,pb,Q,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>1,Q)|0)+(jb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&K)<<D)+(jb&K)|0)<<2)>>2]&2047](j,pb,Q,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mb>>2,Q)|0)+(Ua>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((mb&K)<<D)+(Ua&K)|0)<<2)>>2]&4095](j,pb,Q);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>2,Q)|0)+(jb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ob&K)<<D)+(jb&K)|0)<<2)>>2]&4095](j,pb,Q)}S=S+1|0;}while((S|0)<4)}}else{S=(c[a+12160>>2]|0)+(eb<<D)|0;pb=(c[a+12164>>2]|0)+(fb<<D)|0;j=c[a+12128>>2]|0;if((eb<<D|0)==0){Eb=(ca(j,_-I|0)|0)/(I|0)|0}else{Eb=S-j|0}j=c[a+12132>>2]|0;if((fb<<D|0)==0){Fb=(ca(j,_-I|0)|0)/(I|0)|0}else{Fb=pb-j|0}j=((Fb&K)<<D)+(Eb&K)|0;if((B&1|0)==0){jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,Q)|0)+(S>>1))|0;mf[c[(c[a+12444>>2]|0)+((((pb&K)<<D)+(S&K)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,jb,Q,16);jb=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Fb>>1,Q)|0)+(Eb>>1))|0;mf[c[(c[a+12448>>2]|0)+(j<<2)>>2]&2047](c[(a+12208|0)>>2]|0,jb,Q,16);break}else{jb=(ca(pb>>2,Q)|0)+(S>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<D)+(S&K)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+jb|0,Q);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<D)+(S&K)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+8|0)|0,Q);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<D)+(S&K)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Q<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+(Q<<3))|0,Q);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&K)<<D)+(S&K)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Q<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((jb+8|0)+(Q<<3))|0,Q);jb=(ca(Fb>>2,Q)|0)+(Eb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+jb|0,Q);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+8|0)|0,Q);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Q<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+(Q<<3))|0,Q);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Q<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((jb+8|0)+(Q<<3))|0,Q);break}}}while(0);Bb=Xe[G&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,Q,16)|0}}while(0);c[(C+(((fb<<3)+eb&63)<<2)|0)>>2]=db;c[s+(((fb<<3)+eb&63)<<2)>>2]=Bb;K=(ca((d[y+((fb<<D)-A)|0]|0)+(d[y+((eb<<D)-z)|0]|0)|0,p)|0)+Bb|0;if((K|0)>=(qb|0)){yb=qb;zb=rb;Ab=sb;break}c[(n|0)>>2]=eb;c[o+4>>2]=fb;yb=K;zb=eb;Ab=fb}else{yb=Ma;zb=Na;Ab=Oa}}while(0);Oa=n|0;Na=c[(a+12260|0)>>2]|0;if((Na|0)==-1){Ma=c[(a+12220|0)>>2]|0;sb=c[(a+12264|0)>>2]|0;rb=c[(a+12272|0)>>2]|0;qb=c[(a+12268|0)>>2]|0;Bb=c[(a+12276|0)>>2]|0;z=c[(a+12464|0)>>2]|0;y=c[(a+12280|0)>>2]|0;A=c[(a+12284|0)>>2]|0;s=c[(a+12216|0)>>2]|0;C=c[(a+12224|0)>>2]|0;G=c[(a+10468|0)>>2]|0;Eb=c[(a+10472|0)>>2]|0;Fb=(B&1)<<1|1;Cb=B&1|4;Db=(B&1|0)==0;H=yb;J=zb;u=Ab;w=zb;l:while(1){t=1;v=H;q=u;r=w;while(1){do{if((t-1&t|0)==0){m=t+J|0;if((m|0)>(qb|0)){Gb=v;Hb=q;Ib=r;break}tb=J-t|0;if((tb|0)<(sb|0)){Gb=v;Hb=q;Ib=r;break}wb=t+u|0;if((wb|0)>(Bb|0)){Gb=v;Hb=q;Ib=r;break}xb=u-t|0;if((xb|0)<(rb|0)){Gb=v;Hb=q;Ib=r;break}else{Jb=0;Kb=v;Lb=q;Mb=r}while(1){ub=wb-Jb|0;vb=Jb+J|0;do{if((c[(s+(((ub<<3)+vb&63)<<2)|0)>>2]|0)==(vb+C+(ub<<11)|0|0)){Nb=Kb;Ob=Lb;Pb=Mb}else{K=c[(a+12416|0)>>2]|0;do{if((B&4|0)==0){I=c[(a+12420|0)>>2]|0;_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(K,ub)|0)+vb)|0;jb=Xe[G&511](a,c[(a+12288+(k<<4)|0)>>2]|0,_,K,8)|0;if((B&2|0)==0){Qb=jb;break}_=c[(a+12208|0)>>2]|0;j=(ca(I,ub>>1)|0)+(vb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((ub<<1&2|vb&1)<<2)>>2]&2047](_+(K<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+j|0,I,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((ub<<1&2|vb&1)<<2)>>2]&2047](_+(K<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+j|0,I,4);j=(Xe[Eb&511](a,_+(K<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,I,4)|0)+jb|0;Qb=j+(Xe[Eb&511](a,_+(K<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,I,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(vb|0)){Qb=536870912;break}if((vb<<D|0)>(c[(a+12268|0)>>2]<<D|0)){Qb=536870912;break}if((c[(a+12272|0)>>2]|0)>(ub|0)){Qb=536870912;break}if((ub<<D|0)>(c[(a+12276|0)>>2]<<D|0)){Qb=536870912;break}I=e[(a+13872|0)>>1]|0;_=e[(a+13874|0)>>1]|0;m:do{if((c[(a+11740|0)>>2]|0)==1){if((vb<<D|0)==0){j=0;while(1){jb=c[a+12160+(j<<3)>>2]|0;S=(c[a+12160+(j<<3)+4>>2]|0)+(ub<<D)|0;pb=((ca(c[a+12128+(j<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((j&1)<<Cb)|0;ob=c[a+12128+(j<<3)+4>>2]|0;if((ub<<D|0)==0){Ua=j>>1;Rb=((ca(ob,_-I|0)|0)/(I|0)|0)+(Ua<<Cb)|0;Sb=Ua}else{Rb=S-ob|0;Sb=j>>1}ob=((Rb&Fb)<<D)+(pb&Fb)|0;Ua=(c[(a+12208|0)>>2]|0)+((ca(Sb,K<<3)|0)+(j<<3&8))|0;if(Db){mb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,K)|0)+(jb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&2047](Ua,mb,K,8);mb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Rb>>1,K)|0)+(pb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(ob<<2)>>2]&2047](Ua,mb,K,8)}else{mb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,K)|0)+(jb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&4095](Ua,mb,K);mb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Rb>>2,K)|0)+(pb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ob<<2)>>2]&4095](Ua,mb,K)}j=j+1|0;if((j|0)>=4){break m}}}if((ub<<D|0)==0){j=0;do{mb=(c[a+12160+(j<<3)>>2]|0)+(vb<<D)|0;Ua=c[a+12160+(j<<3)+4>>2]|0;ob=mb-(c[a+12128+(j<<3)>>2]|0)|0;pb=j>>1;jb=((ca(c[a+12128+(j<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(pb<<Cb)|0;S=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ca(pb,K<<3)|0))|0;if(Db){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ua>>1,K)|0)+(mb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Ua&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&2047](S,pb,K,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jb>>1,K)|0)+(ob>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((jb&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&2047](S,pb,K,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ua>>2,K)|0)+(mb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&4095](S,pb,K);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jb>>2,K)|0)+(ob>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((jb&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&4095](S,pb,K)}j=j+1|0;}while((j|0)<4)}else{j=0;do{pb=(c[a+12160+(j<<3)>>2]|0)+(vb<<D)|0;S=(c[a+12160+(j<<3)+4>>2]|0)+(ub<<D)|0;ob=pb-(c[a+12128+(j<<3)>>2]|0)|0;jb=S-(c[a+12128+(j<<3)+4>>2]|0)|0;mb=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ca(j>>1,K<<3)|0))|0;if(Db){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,K)|0)+(pb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&Fb)<<D)+(pb&Fb)|0)<<2)>>2]&2047](mb,Ua,K,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jb>>1,K)|0)+(ob>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((jb&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&2047](mb,Ua,K,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,K)|0)+(pb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&Fb)<<D)+(pb&Fb)|0)<<2)>>2]&4095](mb,Ua,K);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jb>>2,K)|0)+(ob>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((jb&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&4095](mb,Ua,K)}j=j+1|0;}while((j|0)<4)}}else{j=(c[(a+12160|0)>>2]|0)+(vb<<D)|0;Ua=(c[(a+12164|0)>>2]|0)+(ub<<D)|0;mb=c[(a+12128|0)>>2]|0;if((vb<<D|0)==0){Tb=(ca(mb,_-I|0)|0)/(I|0)|0}else{Tb=j-mb|0}mb=c[(a+12132|0)>>2]|0;if((ub<<D|0)==0){Ub=(ca(mb,_-I|0)|0)/(I|0)|0}else{Ub=Ua-mb|0}mb=((Ub&Fb)<<D)+(Tb&Fb)|0;if(Db){ob=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ua>>1,K)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+((((Ua&Fb)<<D)+(j&Fb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ob,K,16);ob=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ub>>1,K)|0)+(Tb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+(mb<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ob,K,16);break}else{ob=(ca(Ua>>2,K)|0)+(j>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ob|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ob+8|0)|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ob+(K<<3))|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ob+8|0)+(K<<3))|0,K);ob=(ca(Ub>>2,K)|0)+(Tb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ob|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ob+8|0)|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ob+(K<<3))|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ob+8|0)+(K<<3))|0,K);break}}}while(0);Qb=Xe[G&511](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(s+(((ub<<3)+vb&63)<<2)|0)>>2]=vb+C+(ub<<11)|0;c[Ma+(((ub<<3)+vb&63)<<2)>>2]=Qb;K=(ca((d[z+((ub<<D)-A)|0]|0)+(d[z+((vb<<D)-y)|0]|0)|0,p)|0)+Qb|0;if((K|0)>=(Kb|0)){Nb=Kb;Ob=Lb;Pb=Mb;break}c[Oa>>2]=vb;c[(Oa+4|0)>>2]=ub;Nb=K;Ob=ub;Pb=vb}}while(0);vb=u-Jb|0;ub=m-Jb|0;do{if((c[(s+(((vb<<3)+ub&63)<<2)|0)>>2]|0)==(ub+C+(vb<<11)|0|0)){Vb=Nb;Wb=Ob;Xb=Pb}else{K=c[(a+12416|0)>>2]|0;do{if((B&4|0)==0){I=c[(a+12420|0)>>2]|0;_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(K,vb)|0)+ub)|0;ob=Xe[G&511](a,c[(a+12288+(k<<4)|0)>>2]|0,_,K,8)|0;if((B&2|0)==0){Yb=ob;break}_=c[(a+12208|0)>>2]|0;mb=(ca(I,vb>>1)|0)+(ub>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((vb<<1&2|ub&1)<<2)>>2]&2047](_+(K<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+mb|0,I,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((vb<<1&2|ub&1)<<2)>>2]&2047](_+(K<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+mb|0,I,4);mb=(Xe[Eb&511](a,_+(K<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,I,4)|0)+ob|0;Yb=mb+(Xe[Eb&511](a,_+(K<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,I,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(ub|0)){Yb=536870912;break}if((ub<<D|0)>(c[(a+12268|0)>>2]<<D|0)){Yb=536870912;break}if((c[(a+12272|0)>>2]|0)>(vb|0)){Yb=536870912;break}if((vb<<D|0)>(c[(a+12276|0)>>2]<<D|0)){Yb=536870912;break}I=e[(a+13872|0)>>1]|0;_=e[(a+13874|0)>>1]|0;n:do{if((c[(a+11740|0)>>2]|0)==1){if((ub<<D|0)==0){mb=0;while(1){ob=c[a+12160+(mb<<3)>>2]|0;j=(c[a+12160+(mb<<3)+4>>2]|0)+(vb<<D)|0;Ua=((ca(c[a+12128+(mb<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((mb&1)<<Cb)|0;jb=c[a+12128+(mb<<3)+4>>2]|0;if((vb<<D|0)==0){pb=mb>>1;Zb=((ca(jb,_-I|0)|0)/(I|0)|0)+(pb<<Cb)|0;_b=pb}else{Zb=j-jb|0;_b=mb>>1}jb=((Zb&Fb)<<D)+(Ua&Fb)|0;pb=(c[(a+12208|0)>>2]|0)+((ca(_b,K<<3)|0)+(mb<<3&8))|0;if(Db){S=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>1,K)|0)+(ob>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&2047](pb,S,K,8);S=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Zb>>1,K)|0)+(Ua>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(jb<<2)>>2]&2047](pb,S,K,8)}else{S=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>2,K)|0)+(ob>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((j&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&4095](pb,S,K);S=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Zb>>2,K)|0)+(Ua>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095](pb,S,K)}mb=mb+1|0;if((mb|0)>=4){break n}}}if((vb<<D|0)==0){mb=0;do{S=(c[a+12160+(mb<<3)>>2]|0)+(ub<<D)|0;pb=c[a+12160+(mb<<3)+4>>2]|0;jb=S-(c[a+12128+(mb<<3)>>2]|0)|0;Ua=mb>>1;ob=((ca(c[a+12128+(mb<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(Ua<<Cb)|0;j=(c[(a+12208|0)>>2]|0)+((mb<<3&8)+(ca(Ua,K<<3)|0))|0;if(Db){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,K)|0)+(S>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&Fb)<<D)+(S&Fb)|0)<<2)>>2]&2047](j,Ua,K,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>1,K)|0)+(jb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&2047](j,Ua,K,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>2,K)|0)+(S>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(S&Fb)|0)<<2)>>2]&4095](j,Ua,K);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>2,K)|0)+(jb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ob&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&4095](j,Ua,K)}mb=mb+1|0;}while((mb|0)<4)}else{mb=0;do{Ua=(c[a+12160+(mb<<3)>>2]|0)+(ub<<D)|0;j=(c[a+12160+(mb<<3)+4>>2]|0)+(vb<<D)|0;jb=Ua-(c[a+12128+(mb<<3)>>2]|0)|0;ob=j-(c[a+12128+(mb<<3)+4>>2]|0)|0;S=(c[(a+12208|0)>>2]|0)+((mb<<3&8)+(ca(mb>>1,K<<3)|0))|0;if(Db){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>1,K)|0)+(Ua>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Fb)<<D)+(Ua&Fb)|0)<<2)>>2]&2047](S,pb,K,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>1,K)|0)+(jb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&2047](S,pb,K,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>2,K)|0)+(Ua>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((j&Fb)<<D)+(Ua&Fb)|0)<<2)>>2]&4095](S,pb,K);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>2,K)|0)+(jb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ob&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&4095](S,pb,K)}mb=mb+1|0;}while((mb|0)<4)}}else{mb=(c[(a+12160|0)>>2]|0)+(ub<<D)|0;pb=(c[(a+12164|0)>>2]|0)+(vb<<D)|0;S=c[(a+12128|0)>>2]|0;if((ub<<D|0)==0){$b=(ca(S,_-I|0)|0)/(I|0)|0}else{$b=mb-S|0}S=c[(a+12132|0)>>2]|0;if((vb<<D|0)==0){ac=(ca(S,_-I|0)|0)/(I|0)|0}else{ac=pb-S|0}S=((ac&Fb)<<D)+($b&Fb)|0;if(Db){jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,K)|0)+(mb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+((((pb&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,jb,K,16);jb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ac>>1,K)|0)+($b>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+(S<<2)>>2]&2047](c[(a+12208|0)>>2]|0,jb,K,16);break}else{jb=(ca(pb>>2,K)|0)+(mb>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+jb|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+8|0)|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+(K<<3))|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((jb+8|0)+(K<<3))|0,K);jb=(ca(ac>>2,K)|0)+($b>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+jb|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+8|0)|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+(K<<3))|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((jb+8|0)+(K<<3))|0,K);break}}}while(0);Yb=Xe[G&511](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(s+(((vb<<3)+ub&63)<<2)|0)>>2]=ub+C+(vb<<11)|0;c[Ma+(((vb<<3)+ub&63)<<2)>>2]=Yb;K=(ca((d[z+((vb<<D)-A)|0]|0)+(d[z+((ub<<D)-y)|0]|0)|0,p)|0)+Yb|0;if((K|0)>=(Nb|0)){Vb=Nb;Wb=Ob;Xb=Pb;break}c[Oa>>2]=ub;c[(Oa+4|0)>>2]=vb;Vb=K;Wb=vb;Xb=ub}}while(0);ub=Jb+xb|0;vb=J-Jb|0;do{if((c[(s+(((ub<<3)+vb&63)<<2)|0)>>2]|0)==(vb+C+(ub<<11)|0|0)){bc=Vb;cc=Wb;dc=Xb}else{K=c[(a+12416|0)>>2]|0;do{if((B&4|0)==0){I=c[(a+12420|0)>>2]|0;_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(K,ub)|0)+vb)|0;jb=Xe[G&511](a,c[(a+12288+(k<<4)|0)>>2]|0,_,K,8)|0;if((B&2|0)==0){ec=jb;break}_=c[(a+12208|0)>>2]|0;S=(ca(I,ub>>1)|0)+(vb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((ub<<1&2|vb&1)<<2)>>2]&2047](_+(K<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+S|0,I,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((ub<<1&2|vb&1)<<2)>>2]&2047](_+(K<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+S|0,I,4);S=(Xe[Eb&511](a,_+(K<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,I,4)|0)+jb|0;ec=S+(Xe[Eb&511](a,_+(K<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,I,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(vb|0)){ec=536870912;break}if((vb<<D|0)>(c[(a+12268|0)>>2]<<D|0)){ec=536870912;break}if((c[(a+12272|0)>>2]|0)>(ub|0)){ec=536870912;break}if((ub<<D|0)>(c[(a+12276|0)>>2]<<D|0)){ec=536870912;break}I=e[(a+13872|0)>>1]|0;_=e[(a+13874|0)>>1]|0;o:do{if((c[(a+11740|0)>>2]|0)==1){if((vb<<D|0)==0){S=0;while(1){jb=c[a+12160+(S<<3)>>2]|0;mb=(c[a+12160+(S<<3)+4>>2]|0)+(ub<<D)|0;pb=((ca(c[a+12128+(S<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((S&1)<<Cb)|0;ob=c[a+12128+(S<<3)+4>>2]|0;if((ub<<D|0)==0){Ua=S>>1;fc=((ca(ob,_-I|0)|0)/(I|0)|0)+(Ua<<Cb)|0;gc=Ua}else{fc=mb-ob|0;gc=S>>1}ob=((fc&Fb)<<D)+(pb&Fb)|0;Ua=(c[(a+12208|0)>>2]|0)+((ca(gc,K<<3)|0)+(S<<3&8))|0;if(Db){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mb>>1,K)|0)+(jb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((mb&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&2047](Ua,j,K,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(fc>>1,K)|0)+(pb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(ob<<2)>>2]&2047](Ua,j,K,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mb>>2,K)|0)+(jb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((mb&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&4095](Ua,j,K);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(fc>>2,K)|0)+(pb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ob<<2)>>2]&4095](Ua,j,K)}S=S+1|0;if((S|0)>=4){break o}}}if((ub<<D|0)==0){S=0;do{j=(c[a+12160+(S<<3)>>2]|0)+(vb<<D)|0;Ua=c[a+12160+(S<<3)+4>>2]|0;ob=j-(c[a+12128+(S<<3)>>2]|0)|0;pb=S>>1;jb=((ca(c[a+12128+(S<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(pb<<Cb)|0;mb=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ca(pb,K<<3)|0))|0;if(Db){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ua>>1,K)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Ua&Fb)<<D)+(j&Fb)|0)<<2)>>2]&2047](mb,pb,K,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jb>>1,K)|0)+(ob>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((jb&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&2047](mb,pb,K,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ua>>2,K)|0)+(j>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095](mb,pb,K);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jb>>2,K)|0)+(ob>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((jb&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&4095](mb,pb,K)}S=S+1|0;}while((S|0)<4)}else{S=0;do{pb=(c[a+12160+(S<<3)>>2]|0)+(vb<<D)|0;mb=(c[a+12160+(S<<3)+4>>2]|0)+(ub<<D)|0;ob=pb-(c[a+12128+(S<<3)>>2]|0)|0;jb=mb-(c[a+12128+(S<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ca(S>>1,K<<3)|0))|0;if(Db){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mb>>1,K)|0)+(pb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((mb&Fb)<<D)+(pb&Fb)|0)<<2)>>2]&2047](j,Ua,K,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jb>>1,K)|0)+(ob>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((jb&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&2047](j,Ua,K,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mb>>2,K)|0)+(pb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((mb&Fb)<<D)+(pb&Fb)|0)<<2)>>2]&4095](j,Ua,K);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jb>>2,K)|0)+(ob>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((jb&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&4095](j,Ua,K)}S=S+1|0;}while((S|0)<4)}}else{S=(c[(a+12160|0)>>2]|0)+(vb<<D)|0;Ua=(c[(a+12164|0)>>2]|0)+(ub<<D)|0;j=c[(a+12128|0)>>2]|0;if((vb<<D|0)==0){hc=(ca(j,_-I|0)|0)/(I|0)|0}else{hc=S-j|0}j=c[(a+12132|0)>>2]|0;if((ub<<D|0)==0){ic=(ca(j,_-I|0)|0)/(I|0)|0}else{ic=Ua-j|0}j=((ic&Fb)<<D)+(hc&Fb)|0;if(Db){ob=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Ua>>1,K)|0)+(S>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+((((Ua&Fb)<<D)+(S&Fb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ob,K,16);ob=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ic>>1,K)|0)+(hc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+(j<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ob,K,16);break}else{ob=(ca(Ua>>2,K)|0)+(S>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(S&Fb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ob|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(S&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ob+8|0)|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(S&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ob+(K<<3))|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Ua&Fb)<<D)+(S&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ob+8|0)+(K<<3))|0,K);ob=(ca(ic>>2,K)|0)+(hc>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ob|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ob+8|0)|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ob+(K<<3))|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ob+8|0)+(K<<3))|0,K);break}}}while(0);ec=Xe[G&511](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(s+(((ub<<3)+vb&63)<<2)|0)>>2]=vb+C+(ub<<11)|0;c[Ma+(((ub<<3)+vb&63)<<2)>>2]=ec;K=(ca((d[z+((ub<<D)-A)|0]|0)+(d[z+((vb<<D)-y)|0]|0)|0,p)|0)+ec|0;if((K|0)>=(Vb|0)){bc=Vb;cc=Wb;dc=Xb;break}c[Oa>>2]=vb;c[(Oa+4|0)>>2]=ub;bc=K;cc=ub;dc=vb}}while(0);vb=Jb+u|0;ub=Jb+tb|0;do{if((c[(s+(((vb<<3)+ub&63)<<2)|0)>>2]|0)==(ub+C+(vb<<11)|0|0)){jc=bc;kc=cc;lc=dc}else{K=c[(a+12416|0)>>2]|0;do{if((B&4|0)==0){I=c[(a+12420|0)>>2]|0;_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(K,vb)|0)+ub)|0;ob=Xe[G&511](a,c[(a+12288+(k<<4)|0)>>2]|0,_,K,8)|0;if((B&2|0)==0){mc=ob;break}_=c[(a+12208|0)>>2]|0;j=(ca(I,vb>>1)|0)+(ub>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((vb<<1&2|ub&1)<<2)>>2]&2047](_+(K<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+j|0,I,4);mf[c[(c[(a+12444|0)>>2]|0)+16+((vb<<1&2|ub&1)<<2)>>2]&2047](_+(K<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+j|0,I,4);j=(Xe[Eb&511](a,_+(K<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,I,4)|0)+ob|0;mc=j+(Xe[Eb&511](a,_+(K<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,I,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(ub|0)){mc=536870912;break}if((ub<<D|0)>(c[(a+12268|0)>>2]<<D|0)){mc=536870912;break}if((c[(a+12272|0)>>2]|0)>(vb|0)){mc=536870912;break}if((vb<<D|0)>(c[(a+12276|0)>>2]<<D|0)){mc=536870912;break}I=e[(a+13872|0)>>1]|0;_=e[(a+13874|0)>>1]|0;p:do{if((c[(a+11740|0)>>2]|0)==1){if((ub<<D|0)==0){j=0;while(1){ob=c[a+12160+(j<<3)>>2]|0;S=(c[a+12160+(j<<3)+4>>2]|0)+(vb<<D)|0;Ua=((ca(c[a+12128+(j<<3)>>2]|0,_-I|0)|0)/(I|0)|0)+((j&1)<<Cb)|0;jb=c[a+12128+(j<<3)+4>>2]|0;if((vb<<D|0)==0){pb=j>>1;nc=((ca(jb,_-I|0)|0)/(I|0)|0)+(pb<<Cb)|0;oc=pb}else{nc=S-jb|0;oc=j>>1}jb=((nc&Fb)<<D)+(Ua&Fb)|0;pb=(c[(a+12208|0)>>2]|0)+((ca(oc,K<<3)|0)+(j<<3&8))|0;if(Db){mb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,K)|0)+(ob>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&2047](pb,mb,K,8);mb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(nc>>1,K)|0)+(Ua>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(jb<<2)>>2]&2047](pb,mb,K,8)}else{mb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,K)|0)+(ob>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&Fb)<<D)+(ob&Fb)|0)<<2)>>2]&4095](pb,mb,K);mb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(nc>>2,K)|0)+(Ua>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(jb<<2)>>2]&4095](pb,mb,K)}j=j+1|0;if((j|0)>=4){break p}}}if((vb<<D|0)==0){j=0;do{mb=(c[a+12160+(j<<3)>>2]|0)+(ub<<D)|0;pb=c[a+12160+(j<<3)+4>>2]|0;jb=mb-(c[a+12128+(j<<3)>>2]|0)|0;Ua=j>>1;ob=((ca(c[a+12128+(j<<3)+4>>2]|0,_-I|0)|0)/(I|0)|0)+(Ua<<Cb)|0;S=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ca(Ua,K<<3)|0))|0;if(Db){Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,K)|0)+(mb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&2047](S,Ua,K,8);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>1,K)|0)+(jb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&2047](S,Ua,K,8)}else{Ua=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>2,K)|0)+(mb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(mb&Fb)|0)<<2)>>2]&4095](S,Ua,K);Ua=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>2,K)|0)+(jb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ob&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&4095](S,Ua,K)}j=j+1|0;}while((j|0)<4)}else{j=0;do{Ua=(c[a+12160+(j<<3)>>2]|0)+(ub<<D)|0;S=(c[a+12160+(j<<3)+4>>2]|0)+(vb<<D)|0;jb=Ua-(c[a+12128+(j<<3)>>2]|0)|0;ob=S-(c[a+12128+(j<<3)+4>>2]|0)|0;mb=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ca(j>>1,K<<3)|0))|0;if(Db){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,K)|0)+(Ua>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&Fb)<<D)+(Ua&Fb)|0)<<2)>>2]&2047](mb,pb,K,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>1,K)|0)+(jb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&2047](mb,pb,K,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,K)|0)+(Ua>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&Fb)<<D)+(Ua&Fb)|0)<<2)>>2]&4095](mb,pb,K);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>2,K)|0)+(jb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ob&Fb)<<D)+(jb&Fb)|0)<<2)>>2]&4095](mb,pb,K)}j=j+1|0;}while((j|0)<4)}}else{j=(c[(a+12160|0)>>2]|0)+(ub<<D)|0;pb=(c[(a+12164|0)>>2]|0)+(vb<<D)|0;mb=c[(a+12128|0)>>2]|0;if((ub<<D|0)==0){pc=(ca(mb,_-I|0)|0)/(I|0)|0}else{pc=j-mb|0}mb=c[(a+12132|0)>>2]|0;if((vb<<D|0)==0){qc=(ca(mb,_-I|0)|0)/(I|0)|0}else{qc=pb-mb|0}mb=((qc&Fb)<<D)+(pc&Fb)|0;if(Db){jb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,K)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+((((pb&Fb)<<D)+(j&Fb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,jb,K,16);jb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qc>>1,K)|0)+(pc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+(mb<<2)>>2]&2047](c[(a+12208|0)>>2]|0,jb,K,16);break}else{jb=(ca(pb>>2,K)|0)+(j>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+jb|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+8|0)|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(jb+(K<<3))|0,K);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Fb)<<D)+(j&Fb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((jb+8|0)+(K<<3))|0,K);jb=(ca(qc>>2,K)|0)+(pc>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+jb|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+8|0)|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(K<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(jb+(K<<3))|0,K);ef[c[(c[(a+12456|0)>>2]|0)+64+(mb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((jb+8|0)+(K<<3))|0,K);break}}}while(0);mc=Xe[G&511](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,K,16)|0}}while(0);c[(s+(((vb<<3)+ub&63)<<2)|0)>>2]=ub+C+(vb<<11)|0;c[Ma+(((vb<<3)+ub&63)<<2)>>2]=mc;K=(ca((d[z+((vb<<D)-A)|0]|0)+(d[z+((ub<<D)-y)|0]|0)|0,p)|0)+mc|0;if((K|0)>=(bc|0)){jc=bc;kc=cc;lc=dc;break}c[Oa>>2]=ub;c[(Oa+4|0)>>2]=vb;jc=K;kc=vb;lc=ub}}while(0);ub=Jb+2|0;if((ub|0)<(t|0)){Jb=ub;Kb=jc;Lb=kc;Mb=lc}else{break}}if((J|0)!=(lc|0)){H=jc;J=lc;u=kc;w=lc;continue l}if((u|0)==(kc|0)){Gb=jc;Hb=u;Ib=J}else{H=jc;J=J;u=kc;w=lc;continue l}}else{Gb=v;Hb=q;Ib=r}}while(0);Q=t+1|0;if((Q|0)<5){t=Q;v=Gb;q=Hb;r=Ib}else{rc=Gb;break l}}}sc=c[Oa>>2]|0;c[f>>2]=sc;tc=o+4|0;uc=c[tc>>2]|0;c[h>>2]=uc;i=n;return rc|0}if((Na|0)<-1){rc=trb(a,Oa,k,l,p,0,8,B)|0;sc=c[Oa>>2]|0;c[f>>2]=sc;tc=o+4|0;uc=c[tc>>2]|0;c[h>>2]=uc;i=n;return rc|0}c[n+16>>2]=a;c[n+24>>2]=f;c[n+32>>2]=h;c[n+48>>2]=k;c[n+56>>2]=l;c[n+72>>2]=o;c[n+80>>2]=p;c[n+168>>2]=B;c[n+184>>2]=D;c[n+6136>>2]=Ab;c[n+6144>>2]=zb;c[n+6152>>2]=yb;c[n+6160>>2]=Oa;c[n+6168>>2]=Na;c[n+19096>>2]=rc;c[n+19104>>2]=sc;c[n+19112>>2]=tc;c[n+19120>>2]=uc;c[n+19144>>2]=0;c[n+19148>>2]=0;_epzs_motion_search2$0(n);rc=c[n+19096>>2]|0;sc=c[n+19104>>2]|0;tc=c[n+19112>>2]|0;uc=c[n+19120>>2]|0;E=c[n+19144>>2]|0;x=c[n+19148>>2]|0;F=+g[n+19148>>2];c[n+19144>>2]=0;c[n+19148>>2]=0;if((E|0)==6){return x|0}return 0|0;return 0}function trb(a,b,f,g,h,j,k,l){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0;m=i;i=i+1024|0;n=m|0;o=c[a+12260>>2]|0;p=-o|0;q=c[a+12220>>2]|0;r=a+12264|0;s=c[r>>2]|0;t=a+12272|0;u=c[t>>2]|0;v=a+12268|0;w=c[v>>2]|0;x=a+12276|0;y=c[x>>2]|0;z=c[a+12464>>2]|0;A=c[a+12280>>2]|0;B=c[a+12284>>2]|0;C=c[a+12216>>2]|0;D=l&1;E=D+1|0;F=c[a+12224>>2]|0;G=c[a+10468+(j<<2)>>2]|0;H=j+1|0;j=c[a+10468+(H<<2)>>2]|0;I=0;J=0;while(1){K=(c[C+(J<<2)>>2]|0)+2098176|0;do{if((K&-4194304|0)==(F|0)){L=c[q+(J<<2)>>2]|0;M=n+(I<<4)|0;c[M>>2]=L;N=(K&2047)-1024|0;c[n+(I<<4)+4>>2]=N;O=(K>>>11&2047)-1024|0;c[n+(I<<4)+8>>2]=O;if((N|0)>(w|0)|(N|0)<(s|0)|(O|0)>(y|0)|(O|0)<(u|0)){P=I;break}c[n+(I<<4)+12>>2]=0;if((N|O|0)!=0){c[M>>2]=(ca((d[z+((O<<E)-B)|0]|0)+(d[z+((N<<E)-A)|0]|0)|0,h)|0)+L}P=I+1|0}else{P=I}}while(0);K=J+1|0;if((K|0)<64&(P|0)<64){I=P;J=K}else{break}}J=(o|0)>-1?o:p;cd(n|0,P|0,16,982);if((P|0)<(J|0)){p=P;do{c[n+(p<<4)>>2]=1073741824;c[n+(p<<4)+12>>2]=0;c[n+(p<<4)+8>>2]=0;c[n+(p<<4)+4>>2]=0;p=p+1|0;}while((p|0)<(J|0))}if((J|0)>0){p=(l&4|0)==0;P=a+12416|0;o=a+12420|0;I=a+12352+(g<<4)|0;K=a+12288+(f<<4)|0;L=a;N=(l&2|0)==0;O=a+12208|0;M=a+12444|0;Q=a+12352+(g<<4)+4|0;R=k>>1;S=a+12352+(g<<4)+8|0;T=a+12288+(f<<4)+4|0;U=a+12288+(f<<4)+8|0;V=n+(J-1<<4)|0;W=a+13872|0;X=a+13874|0;Y=D<<1|1;Z=a+11740|0;_=D|4;$=(D|0)==0;aa=a+12448|0;ba=a+12352+(g<<4)+32|0;da=a+12452|0;ea=a+12456|0;fa=a+12160|0;ga=a+12164|0;ha=a+12128|0;ia=a+12132|0;ja=0;do{ka=c[n+(ja<<4)+4>>2]|0;la=c[n+(ja<<4)+8>>2]|0;ma=n+(ja<<4)+12|0;a:do{if((c[ma>>2]|0)==0&(ka|0)<(w|0)&(ka|0)>(s|0)&(la|0)<(y|0)&(la|0)>(u|0)){na=la<<11;oa=ka-1|0;pa=oa+F+na|0;qa=la<<3;ra=qa+oa&63;sa=C+(ra<<2)|0;do{if((c[sa>>2]|0)!=(pa|0)){ta=c[P>>2]|0;do{if(p){ua=c[o>>2]|0;va=(c[I>>2]|0)+((ca(ta,la)|0)+oa)|0;wa=Xe[G&511](L,c[K>>2]|0,va,ta,k)|0;if(N){xa=wa;break}va=la<<1&2|oa&1;ya=c[O>>2]|0;za=ta<<4;Aa=ya+za|0;Ba=(ca(ua,la>>1)|0)+(oa>>1)|0;mf[c[(c[M>>2]|0)+(H<<4)+(va<<2)>>2]&2047](Aa,(c[Q>>2]|0)+Ba|0,ua,R);Ca=ya+(za|8)|0;mf[c[(c[M>>2]|0)+(H<<4)+(va<<2)>>2]&2047](Ca,(c[S>>2]|0)+Ba|0,ua,R);Ba=(Xe[j&511](L,Aa,c[T>>2]|0,ua,R)|0)+wa|0;xa=Ba+(Xe[j&511](L,Ca,c[U>>2]|0,ua,R)|0)|0}else{ua=oa<<E;Ca=la<<E;if((c[r>>2]|0)>(oa|0)){xa=536870912;break}if((ua|0)>(c[v>>2]<<E|0)){xa=536870912;break}if((c[t>>2]|0)>(la|0)){xa=536870912;break}if((Ca|0)>(c[x>>2]<<E|0)){xa=536870912;break}Ba=e[W>>1]|0;wa=e[X>>1]|0;b:do{if((c[Z>>2]|0)==1){Aa=wa-Ba|0;va=(Ca|0)==0;za=ta<<3;if((ua|0)==0){ya=0;while(1){Da=c[a+12160+(ya<<3)>>2]|0;Ea=(c[a+12160+(ya<<3)+4>>2]|0)+Ca|0;Fa=((ca(c[a+12128+(ya<<3)>>2]|0,Aa)|0)/(Ba|0)|0)+((ya&1)<<_)|0;Ga=c[a+12128+(ya<<3)+4>>2]|0;if(va){Ha=ya>>1;Ia=((ca(Ga,Aa)|0)/(Ba|0)|0)+(Ha<<_)|0;Ja=Ha}else{Ia=Ea-Ga|0;Ja=ya>>1}Ga=((Ea&Y)<<E)+(Da&Y)|0;Ha=((Ia&Y)<<E)+(Fa&Y)|0;Ka=(c[O>>2]|0)+((ca(Ja,za)|0)+(ya<<3&8))|0;if($){La=(c[I>>2]|0)+((ca(Ea>>1,ta)|0)+(Da>>1))|0;mf[c[(c[M>>2]|0)+16+(Ga<<2)>>2]&2047](Ka,La,ta,8);La=(c[ba>>2]|0)+((ca(Ia>>1,ta)|0)+(Fa>>1))|0;mf[c[(c[aa>>2]|0)+16+(Ha<<2)>>2]&2047](Ka,La,ta,8)}else{La=(c[I>>2]|0)+((ca(Ea>>2,ta)|0)+(Da>>2))|0;ef[c[(c[da>>2]|0)+64+(Ga<<2)>>2]&4095](Ka,La,ta);La=(c[ba>>2]|0)+((ca(Ia>>2,ta)|0)+(Fa>>2))|0;ef[c[(c[ea>>2]|0)+64+(Ha<<2)>>2]&4095](Ka,La,ta)}ya=ya+1|0;if((ya|0)>=4){break b}}}if(va){ya=0;do{La=(c[a+12160+(ya<<3)>>2]|0)+ua|0;Ka=c[a+12160+(ya<<3)+4>>2]|0;Ha=La-(c[a+12128+(ya<<3)>>2]|0)|0;Fa=ya>>1;Ga=((ca(c[a+12128+(ya<<3)+4>>2]|0,Aa)|0)/(Ba|0)|0)+(Fa<<_)|0;Da=((Ka&Y)<<E)+(La&Y)|0;Ea=((Ga&Y)<<E)+(Ha&Y)|0;Ma=(c[O>>2]|0)+((ya<<3&8)+(ca(Fa,za)|0))|0;if($){Fa=(c[I>>2]|0)+((ca(Ka>>1,ta)|0)+(La>>1))|0;mf[c[(c[M>>2]|0)+16+(Da<<2)>>2]&2047](Ma,Fa,ta,8);Fa=(c[ba>>2]|0)+((ca(Ga>>1,ta)|0)+(Ha>>1))|0;mf[c[(c[aa>>2]|0)+16+(Ea<<2)>>2]&2047](Ma,Fa,ta,8)}else{Fa=(c[I>>2]|0)+((ca(Ka>>2,ta)|0)+(La>>2))|0;ef[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095](Ma,Fa,ta);Fa=(c[ba>>2]|0)+((ca(Ga>>2,ta)|0)+(Ha>>2))|0;ef[c[(c[ea>>2]|0)+64+(Ea<<2)>>2]&4095](Ma,Fa,ta)}ya=ya+1|0;}while((ya|0)<4)}else{ya=0;do{Aa=(c[a+12160+(ya<<3)>>2]|0)+ua|0;va=(c[a+12160+(ya<<3)+4>>2]|0)+Ca|0;Fa=Aa-(c[a+12128+(ya<<3)>>2]|0)|0;Ma=va-(c[a+12128+(ya<<3)+4>>2]|0)|0;Ea=((va&Y)<<E)+(Aa&Y)|0;Ha=((Ma&Y)<<E)+(Fa&Y)|0;Ga=(c[O>>2]|0)+((ya<<3&8)+(ca(ya>>1,za)|0))|0;if($){Da=(c[I>>2]|0)+((ca(va>>1,ta)|0)+(Aa>>1))|0;mf[c[(c[M>>2]|0)+16+(Ea<<2)>>2]&2047](Ga,Da,ta,8);Da=(c[ba>>2]|0)+((ca(Ma>>1,ta)|0)+(Fa>>1))|0;mf[c[(c[aa>>2]|0)+16+(Ha<<2)>>2]&2047](Ga,Da,ta,8)}else{Da=(c[I>>2]|0)+((ca(va>>2,ta)|0)+(Aa>>2))|0;ef[c[(c[da>>2]|0)+64+(Ea<<2)>>2]&4095](Ga,Da,ta);Da=(c[ba>>2]|0)+((ca(Ma>>2,ta)|0)+(Fa>>2))|0;ef[c[(c[ea>>2]|0)+64+(Ha<<2)>>2]&4095](Ga,Da,ta)}ya=ya+1|0;}while((ya|0)<4)}}else{ya=(c[fa>>2]|0)+ua|0;za=(c[ga>>2]|0)+Ca|0;Da=c[ha>>2]|0;if((ua|0)==0){Na=(ca(Da,wa-Ba|0)|0)/(Ba|0)|0}else{Na=ya-Da|0}Da=c[ia>>2]|0;if((Ca|0)==0){Oa=(ca(Da,wa-Ba|0)|0)/(Ba|0)|0}else{Oa=za-Da|0}Da=((za&Y)<<E)+(ya&Y)|0;Ga=((Oa&Y)<<E)+(Na&Y)|0;if($){Ha=(c[I>>2]|0)+((ca(za>>1,ta)|0)+(ya>>1))|0;mf[c[(c[M>>2]|0)+(Da<<2)>>2]&2047](c[O>>2]|0,Ha,ta,16);Ha=(c[ba>>2]|0)+((ca(Oa>>1,ta)|0)+(Na>>1))|0;mf[c[(c[aa>>2]|0)+(Ga<<2)>>2]&2047](c[O>>2]|0,Ha,ta,16);break}else{Ha=(ca(za>>2,ta)|0)+(ya>>2)|0;ef[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095](c[O>>2]|0,(c[I>>2]|0)+Ha|0,ta);ya=Ha+8|0;ef[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[I>>2]|0)+ya|0,ta);za=ta<<3;ef[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095]((c[O>>2]|0)+za|0,(c[I>>2]|0)+(Ha+za)|0,ta);Ha=za+8|0;ef[c[(c[da>>2]|0)+64+(Da<<2)>>2]&4095]((c[O>>2]|0)+Ha|0,(c[I>>2]|0)+(ya+za)|0,ta);ya=(ca(Oa>>2,ta)|0)+(Na>>2)|0;ef[c[(c[ea>>2]|0)+64+(Ga<<2)>>2]&4095](c[O>>2]|0,(c[ba>>2]|0)+ya|0,ta);Da=ya+8|0;ef[c[(c[ea>>2]|0)+64+(Ga<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[ba>>2]|0)+Da|0,ta);ef[c[(c[ea>>2]|0)+64+(Ga<<2)>>2]&4095]((c[O>>2]|0)+za|0,(c[ba>>2]|0)+(ya+za)|0,ta);ef[c[(c[ea>>2]|0)+64+(Ga<<2)>>2]&4095]((c[O>>2]|0)+Ha|0,(c[ba>>2]|0)+(Da+za)|0,ta);break}}}while(0);xa=Xe[G&511](L,c[O>>2]|0,c[K>>2]|0,ta,16)|0}}while(0);c[sa>>2]=pa;c[q+(ra<<2)>>2]=xa;ta=(ca((d[z+((la<<E)-B)|0]|0)+(d[z+((oa<<E)-A)|0]|0)|0,h)|0)+xa|0;if((ta|0)<(c[V>>2]|0)){Pa=0}else{break}while(1){Qa=n+(Pa<<4)|0;Ra=Qa|0;Sa=Pa+1|0;if((ta|0)<(c[Ra>>2]|0)){break}else{Pa=Sa}}orc(n+(Sa<<4)|0,Qa|0,(J-Pa<<4)-16|0)|0;c[n+(Pa<<4)+12>>2]=0;c[Ra>>2]=ta;c[n+(Pa<<4)+4>>2]=oa;c[n+(Pa<<4)+8>>2]=la;Ta=-1;break a}}while(0);oa=ka+1|0;ra=oa+F+na|0;pa=qa+oa&63;sa=C+(pa<<2)|0;do{if((c[sa>>2]|0)!=(ra|0)){Ba=c[P>>2]|0;do{if(p){wa=c[o>>2]|0;Ca=(c[I>>2]|0)+((ca(Ba,la)|0)+oa)|0;ua=Xe[G&511](L,c[K>>2]|0,Ca,Ba,k)|0;if(N){Ua=ua;break}Ca=la<<1&2|oa&1;za=c[O>>2]|0;Da=Ba<<4;Ha=za+Da|0;Ga=(ca(wa,la>>1)|0)+(oa>>1)|0;mf[c[(c[M>>2]|0)+(H<<4)+(Ca<<2)>>2]&2047](Ha,(c[Q>>2]|0)+Ga|0,wa,R);ya=za+(Da|8)|0;mf[c[(c[M>>2]|0)+(H<<4)+(Ca<<2)>>2]&2047](ya,(c[S>>2]|0)+Ga|0,wa,R);Ga=(Xe[j&511](L,Ha,c[T>>2]|0,wa,R)|0)+ua|0;Ua=Ga+(Xe[j&511](L,ya,c[U>>2]|0,wa,R)|0)|0}else{wa=oa<<E;ya=la<<E;if((c[r>>2]|0)>(oa|0)){Ua=536870912;break}if((wa|0)>(c[v>>2]<<E|0)){Ua=536870912;break}if((c[t>>2]|0)>(la|0)){Ua=536870912;break}if((ya|0)>(c[x>>2]<<E|0)){Ua=536870912;break}Ga=e[W>>1]|0;ua=e[X>>1]|0;c:do{if((c[Z>>2]|0)==1){Ha=ua-Ga|0;Ca=(ya|0)==0;Da=Ba<<3;if((wa|0)==0){za=0;while(1){Fa=c[a+12160+(za<<3)>>2]|0;Ma=(c[a+12160+(za<<3)+4>>2]|0)+ya|0;Ea=((ca(c[a+12128+(za<<3)>>2]|0,Ha)|0)/(Ga|0)|0)+((za&1)<<_)|0;Aa=c[a+12128+(za<<3)+4>>2]|0;if(Ca){va=za>>1;Va=((ca(Aa,Ha)|0)/(Ga|0)|0)+(va<<_)|0;Wa=va}else{Va=Ma-Aa|0;Wa=za>>1}Aa=((Ma&Y)<<E)+(Fa&Y)|0;va=((Va&Y)<<E)+(Ea&Y)|0;La=(c[O>>2]|0)+((ca(Wa,Da)|0)+(za<<3&8))|0;if($){Ka=(c[I>>2]|0)+((ca(Ma>>1,Ba)|0)+(Fa>>1))|0;mf[c[(c[M>>2]|0)+16+(Aa<<2)>>2]&2047](La,Ka,Ba,8);Ka=(c[ba>>2]|0)+((ca(Va>>1,Ba)|0)+(Ea>>1))|0;mf[c[(c[aa>>2]|0)+16+(va<<2)>>2]&2047](La,Ka,Ba,8)}else{Ka=(c[I>>2]|0)+((ca(Ma>>2,Ba)|0)+(Fa>>2))|0;ef[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095](La,Ka,Ba);Ka=(c[ba>>2]|0)+((ca(Va>>2,Ba)|0)+(Ea>>2))|0;ef[c[(c[ea>>2]|0)+64+(va<<2)>>2]&4095](La,Ka,Ba)}za=za+1|0;if((za|0)>=4){break c}}}if(Ca){za=0;do{Ka=(c[a+12160+(za<<3)>>2]|0)+wa|0;La=c[a+12160+(za<<3)+4>>2]|0;va=Ka-(c[a+12128+(za<<3)>>2]|0)|0;Ea=za>>1;Aa=((ca(c[a+12128+(za<<3)+4>>2]|0,Ha)|0)/(Ga|0)|0)+(Ea<<_)|0;Fa=((La&Y)<<E)+(Ka&Y)|0;Ma=((Aa&Y)<<E)+(va&Y)|0;Xa=(c[O>>2]|0)+((za<<3&8)+(ca(Ea,Da)|0))|0;if($){Ea=(c[I>>2]|0)+((ca(La>>1,Ba)|0)+(Ka>>1))|0;mf[c[(c[M>>2]|0)+16+(Fa<<2)>>2]&2047](Xa,Ea,Ba,8);Ea=(c[ba>>2]|0)+((ca(Aa>>1,Ba)|0)+(va>>1))|0;mf[c[(c[aa>>2]|0)+16+(Ma<<2)>>2]&2047](Xa,Ea,Ba,8)}else{Ea=(c[I>>2]|0)+((ca(La>>2,Ba)|0)+(Ka>>2))|0;ef[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095](Xa,Ea,Ba);Ea=(c[ba>>2]|0)+((ca(Aa>>2,Ba)|0)+(va>>2))|0;ef[c[(c[ea>>2]|0)+64+(Ma<<2)>>2]&4095](Xa,Ea,Ba)}za=za+1|0;}while((za|0)<4)}else{za=0;do{Ha=(c[a+12160+(za<<3)>>2]|0)+wa|0;Ca=(c[a+12160+(za<<3)+4>>2]|0)+ya|0;Ea=Ha-(c[a+12128+(za<<3)>>2]|0)|0;Xa=Ca-(c[a+12128+(za<<3)+4>>2]|0)|0;Ma=((Ca&Y)<<E)+(Ha&Y)|0;va=((Xa&Y)<<E)+(Ea&Y)|0;Aa=(c[O>>2]|0)+((za<<3&8)+(ca(za>>1,Da)|0))|0;if($){Fa=(c[I>>2]|0)+((ca(Ca>>1,Ba)|0)+(Ha>>1))|0;mf[c[(c[M>>2]|0)+16+(Ma<<2)>>2]&2047](Aa,Fa,Ba,8);Fa=(c[ba>>2]|0)+((ca(Xa>>1,Ba)|0)+(Ea>>1))|0;mf[c[(c[aa>>2]|0)+16+(va<<2)>>2]&2047](Aa,Fa,Ba,8)}else{Fa=(c[I>>2]|0)+((ca(Ca>>2,Ba)|0)+(Ha>>2))|0;ef[c[(c[da>>2]|0)+64+(Ma<<2)>>2]&4095](Aa,Fa,Ba);Fa=(c[ba>>2]|0)+((ca(Xa>>2,Ba)|0)+(Ea>>2))|0;ef[c[(c[ea>>2]|0)+64+(va<<2)>>2]&4095](Aa,Fa,Ba)}za=za+1|0;}while((za|0)<4)}}else{za=(c[fa>>2]|0)+wa|0;Da=(c[ga>>2]|0)+ya|0;Fa=c[ha>>2]|0;if((wa|0)==0){Ya=(ca(Fa,ua-Ga|0)|0)/(Ga|0)|0}else{Ya=za-Fa|0}Fa=c[ia>>2]|0;if((ya|0)==0){Za=(ca(Fa,ua-Ga|0)|0)/(Ga|0)|0}else{Za=Da-Fa|0}Fa=((Da&Y)<<E)+(za&Y)|0;Aa=((Za&Y)<<E)+(Ya&Y)|0;if($){va=(c[I>>2]|0)+((ca(Da>>1,Ba)|0)+(za>>1))|0;mf[c[(c[M>>2]|0)+(Fa<<2)>>2]&2047](c[O>>2]|0,va,Ba,16);va=(c[ba>>2]|0)+((ca(Za>>1,Ba)|0)+(Ya>>1))|0;mf[c[(c[aa>>2]|0)+(Aa<<2)>>2]&2047](c[O>>2]|0,va,Ba,16);break}else{va=(ca(Da>>2,Ba)|0)+(za>>2)|0;ef[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095](c[O>>2]|0,(c[I>>2]|0)+va|0,Ba);za=va+8|0;ef[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[I>>2]|0)+za|0,Ba);Da=Ba<<3;ef[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095]((c[O>>2]|0)+Da|0,(c[I>>2]|0)+(va+Da)|0,Ba);va=Da+8|0;ef[c[(c[da>>2]|0)+64+(Fa<<2)>>2]&4095]((c[O>>2]|0)+va|0,(c[I>>2]|0)+(za+Da)|0,Ba);za=(ca(Za>>2,Ba)|0)+(Ya>>2)|0;ef[c[(c[ea>>2]|0)+64+(Aa<<2)>>2]&4095](c[O>>2]|0,(c[ba>>2]|0)+za|0,Ba);Fa=za+8|0;ef[c[(c[ea>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[ba>>2]|0)+Fa|0,Ba);ef[c[(c[ea>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+Da|0,(c[ba>>2]|0)+(za+Da)|0,Ba);ef[c[(c[ea>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+va|0,(c[ba>>2]|0)+(Fa+Da)|0,Ba);break}}}while(0);Ua=Xe[G&511](L,c[O>>2]|0,c[K>>2]|0,Ba,16)|0}}while(0);c[sa>>2]=ra;c[q+(pa<<2)>>2]=Ua;Ba=(ca((d[z+((la<<E)-B)|0]|0)+(d[z+((oa<<E)-A)|0]|0)|0,h)|0)+Ua|0;if((Ba|0)<(c[V>>2]|0)){_a=0}else{break}while(1){$a=n+(_a<<4)|0;ab=$a|0;bb=_a+1|0;if((Ba|0)<(c[ab>>2]|0)){break}else{_a=bb}}orc(n+(bb<<4)|0,$a|0,(J-_a<<4)-16|0)|0;c[n+(_a<<4)+12>>2]=0;c[ab>>2]=Ba;c[n+(_a<<4)+4>>2]=oa;c[n+(_a<<4)+8>>2]=la;Ta=-1;break a}}while(0);oa=la-1|0;pa=ka+F|0;ra=pa+(oa<<11)|0;sa=(oa<<3)+ka&63;qa=C+(sa<<2)|0;do{if((c[qa>>2]|0)!=(ra|0)){na=c[P>>2]|0;do{if(p){ta=c[o>>2]|0;Ga=(c[I>>2]|0)+((ca(na,oa)|0)+ka)|0;ua=Xe[G&511](L,c[K>>2]|0,Ga,na,k)|0;if(N){cb=ua;break}Ga=oa<<1&2|ka&1;ya=c[O>>2]|0;wa=na<<4;Da=ya+wa|0;Fa=(ca(ta,oa>>1)|0)+(ka>>1)|0;mf[c[(c[M>>2]|0)+(H<<4)+(Ga<<2)>>2]&2047](Da,(c[Q>>2]|0)+Fa|0,ta,R);va=ya+(wa|8)|0;mf[c[(c[M>>2]|0)+(H<<4)+(Ga<<2)>>2]&2047](va,(c[S>>2]|0)+Fa|0,ta,R);Fa=(Xe[j&511](L,Da,c[T>>2]|0,ta,R)|0)+ua|0;cb=Fa+(Xe[j&511](L,va,c[U>>2]|0,ta,R)|0)|0}else{ta=ka<<E;va=oa<<E;if((c[r>>2]|0)>(ka|0)){cb=536870912;break}if((ta|0)>(c[v>>2]<<E|0)){cb=536870912;break}if((c[t>>2]|0)>(oa|0)){cb=536870912;break}if((va|0)>(c[x>>2]<<E|0)){cb=536870912;break}Fa=e[W>>1]|0;ua=e[X>>1]|0;d:do{if((c[Z>>2]|0)==1){Da=ua-Fa|0;Ga=(va|0)==0;wa=na<<3;if((ta|0)==0){ya=0;while(1){Aa=c[a+12160+(ya<<3)>>2]|0;za=(c[a+12160+(ya<<3)+4>>2]|0)+va|0;Ea=((ca(c[a+12128+(ya<<3)>>2]|0,Da)|0)/(Fa|0)|0)+((ya&1)<<_)|0;Xa=c[a+12128+(ya<<3)+4>>2]|0;if(Ga){Ma=ya>>1;db=((ca(Xa,Da)|0)/(Fa|0)|0)+(Ma<<_)|0;eb=Ma}else{db=za-Xa|0;eb=ya>>1}Xa=((za&Y)<<E)+(Aa&Y)|0;Ma=((db&Y)<<E)+(Ea&Y)|0;Ha=(c[O>>2]|0)+((ca(eb,wa)|0)+(ya<<3&8))|0;if($){Ca=(c[I>>2]|0)+((ca(za>>1,na)|0)+(Aa>>1))|0;mf[c[(c[M>>2]|0)+16+(Xa<<2)>>2]&2047](Ha,Ca,na,8);Ca=(c[ba>>2]|0)+((ca(db>>1,na)|0)+(Ea>>1))|0;mf[c[(c[aa>>2]|0)+16+(Ma<<2)>>2]&2047](Ha,Ca,na,8)}else{Ca=(c[I>>2]|0)+((ca(za>>2,na)|0)+(Aa>>2))|0;ef[c[(c[da>>2]|0)+64+(Xa<<2)>>2]&4095](Ha,Ca,na);Ca=(c[ba>>2]|0)+((ca(db>>2,na)|0)+(Ea>>2))|0;ef[c[(c[ea>>2]|0)+64+(Ma<<2)>>2]&4095](Ha,Ca,na)}ya=ya+1|0;if((ya|0)>=4){break d}}}if(Ga){ya=0;do{Ca=(c[a+12160+(ya<<3)>>2]|0)+ta|0;Ha=c[a+12160+(ya<<3)+4>>2]|0;Ma=Ca-(c[a+12128+(ya<<3)>>2]|0)|0;Ea=ya>>1;Xa=((ca(c[a+12128+(ya<<3)+4>>2]|0,Da)|0)/(Fa|0)|0)+(Ea<<_)|0;Aa=((Ha&Y)<<E)+(Ca&Y)|0;za=((Xa&Y)<<E)+(Ma&Y)|0;Ka=(c[O>>2]|0)+((ya<<3&8)+(ca(Ea,wa)|0))|0;if($){Ea=(c[I>>2]|0)+((ca(Ha>>1,na)|0)+(Ca>>1))|0;mf[c[(c[M>>2]|0)+16+(Aa<<2)>>2]&2047](Ka,Ea,na,8);Ea=(c[ba>>2]|0)+((ca(Xa>>1,na)|0)+(Ma>>1))|0;mf[c[(c[aa>>2]|0)+16+(za<<2)>>2]&2047](Ka,Ea,na,8)}else{Ea=(c[I>>2]|0)+((ca(Ha>>2,na)|0)+(Ca>>2))|0;ef[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095](Ka,Ea,na);Ea=(c[ba>>2]|0)+((ca(Xa>>2,na)|0)+(Ma>>2))|0;ef[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095](Ka,Ea,na)}ya=ya+1|0;}while((ya|0)<4)}else{ya=0;do{Da=(c[a+12160+(ya<<3)>>2]|0)+ta|0;Ga=(c[a+12160+(ya<<3)+4>>2]|0)+va|0;Ea=Da-(c[a+12128+(ya<<3)>>2]|0)|0;Ka=Ga-(c[a+12128+(ya<<3)+4>>2]|0)|0;za=((Ga&Y)<<E)+(Da&Y)|0;Ma=((Ka&Y)<<E)+(Ea&Y)|0;Xa=(c[O>>2]|0)+((ya<<3&8)+(ca(ya>>1,wa)|0))|0;if($){Aa=(c[I>>2]|0)+((ca(Ga>>1,na)|0)+(Da>>1))|0;mf[c[(c[M>>2]|0)+16+(za<<2)>>2]&2047](Xa,Aa,na,8);Aa=(c[ba>>2]|0)+((ca(Ka>>1,na)|0)+(Ea>>1))|0;mf[c[(c[aa>>2]|0)+16+(Ma<<2)>>2]&2047](Xa,Aa,na,8)}else{Aa=(c[I>>2]|0)+((ca(Ga>>2,na)|0)+(Da>>2))|0;ef[c[(c[da>>2]|0)+64+(za<<2)>>2]&4095](Xa,Aa,na);Aa=(c[ba>>2]|0)+((ca(Ka>>2,na)|0)+(Ea>>2))|0;ef[c[(c[ea>>2]|0)+64+(Ma<<2)>>2]&4095](Xa,Aa,na)}ya=ya+1|0;}while((ya|0)<4)}}else{ya=(c[fa>>2]|0)+ta|0;wa=(c[ga>>2]|0)+va|0;Aa=c[ha>>2]|0;if((ta|0)==0){fb=(ca(Aa,ua-Fa|0)|0)/(Fa|0)|0}else{fb=ya-Aa|0}Aa=c[ia>>2]|0;if((va|0)==0){gb=(ca(Aa,ua-Fa|0)|0)/(Fa|0)|0}else{gb=wa-Aa|0}Aa=((wa&Y)<<E)+(ya&Y)|0;Xa=((gb&Y)<<E)+(fb&Y)|0;if($){Ma=(c[I>>2]|0)+((ca(wa>>1,na)|0)+(ya>>1))|0;mf[c[(c[M>>2]|0)+(Aa<<2)>>2]&2047](c[O>>2]|0,Ma,na,16);Ma=(c[ba>>2]|0)+((ca(gb>>1,na)|0)+(fb>>1))|0;mf[c[(c[aa>>2]|0)+(Xa<<2)>>2]&2047](c[O>>2]|0,Ma,na,16);break}else{Ma=(ca(wa>>2,na)|0)+(ya>>2)|0;ef[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095](c[O>>2]|0,(c[I>>2]|0)+Ma|0,na);ya=Ma+8|0;ef[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[I>>2]|0)+ya|0,na);wa=na<<3;ef[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+wa|0,(c[I>>2]|0)+(Ma+wa)|0,na);Ma=wa+8|0;ef[c[(c[da>>2]|0)+64+(Aa<<2)>>2]&4095]((c[O>>2]|0)+Ma|0,(c[I>>2]|0)+(ya+wa)|0,na);ya=(ca(gb>>2,na)|0)+(fb>>2)|0;ef[c[(c[ea>>2]|0)+64+(Xa<<2)>>2]&4095](c[O>>2]|0,(c[ba>>2]|0)+ya|0,na);Aa=ya+8|0;ef[c[(c[ea>>2]|0)+64+(Xa<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[ba>>2]|0)+Aa|0,na);ef[c[(c[ea>>2]|0)+64+(Xa<<2)>>2]&4095]((c[O>>2]|0)+wa|0,(c[ba>>2]|0)+(ya+wa)|0,na);ef[c[(c[ea>>2]|0)+64+(Xa<<2)>>2]&4095]((c[O>>2]|0)+Ma|0,(c[ba>>2]|0)+(Aa+wa)|0,na);break}}}while(0);cb=Xe[G&511](L,c[O>>2]|0,c[K>>2]|0,na,16)|0}}while(0);c[qa>>2]=ra;c[q+(sa<<2)>>2]=cb;na=(ca((d[z+((oa<<E)-B)|0]|0)+(d[z+((ka<<E)-A)|0]|0)|0,h)|0)+cb|0;if((na|0)<(c[V>>2]|0)){hb=0}else{break}while(1){ib=n+(hb<<4)|0;jb=ib|0;kb=hb+1|0;if((na|0)<(c[jb>>2]|0)){break}else{hb=kb}}orc(n+(kb<<4)|0,ib|0,(J-hb<<4)-16|0)|0;c[n+(hb<<4)+12>>2]=0;c[jb>>2]=na;c[n+(hb<<4)+4>>2]=ka;c[n+(hb<<4)+8>>2]=oa;Ta=-1;break a}}while(0);oa=la+1|0;sa=pa+(oa<<11)|0;ra=(oa<<3)+ka&63;qa=C+(ra<<2)|0;do{if((c[qa>>2]|0)!=(sa|0)){Ba=c[P>>2]|0;do{if(p){Fa=c[o>>2]|0;ua=(c[I>>2]|0)+((ca(Ba,oa)|0)+ka)|0;va=Xe[G&511](L,c[K>>2]|0,ua,Ba,k)|0;if(N){lb=va;break}ua=oa<<1&2|ka&1;ta=c[O>>2]|0;wa=Ba<<4;Aa=ta+wa|0;Ma=(ca(Fa,oa>>1)|0)+(ka>>1)|0;mf[c[(c[M>>2]|0)+(H<<4)+(ua<<2)>>2]&2047](Aa,(c[Q>>2]|0)+Ma|0,Fa,R);Xa=ta+(wa|8)|0;mf[c[(c[M>>2]|0)+(H<<4)+(ua<<2)>>2]&2047](Xa,(c[S>>2]|0)+Ma|0,Fa,R);Ma=(Xe[j&511](L,Aa,c[T>>2]|0,Fa,R)|0)+va|0;lb=Ma+(Xe[j&511](L,Xa,c[U>>2]|0,Fa,R)|0)|0}else{Fa=ka<<E;Xa=oa<<E;if((c[r>>2]|0)>(ka|0)){lb=536870912;break}if((Fa|0)>(c[v>>2]<<E|0)){lb=536870912;break}if((c[t>>2]|0)>(oa|0)){lb=536870912;break}if((Xa|0)>(c[x>>2]<<E|0)){lb=536870912;break}Ma=e[W>>1]|0;va=e[X>>1]|0;e:do{if((c[Z>>2]|0)==1){Aa=va-Ma|0;ua=(Xa|0)==0;wa=Ba<<3;if((Fa|0)==0){ta=0;while(1){ya=c[a+12160+(ta<<3)>>2]|0;Ea=(c[a+12160+(ta<<3)+4>>2]|0)+Xa|0;Ka=((ca(c[a+12128+(ta<<3)>>2]|0,Aa)|0)/(Ma|0)|0)+((ta&1)<<_)|0;za=c[a+12128+(ta<<3)+4>>2]|0;if(ua){Da=ta>>1;mb=((ca(za,Aa)|0)/(Ma|0)|0)+(Da<<_)|0;nb=Da}else{mb=Ea-za|0;nb=ta>>1}za=((Ea&Y)<<E)+(ya&Y)|0;Da=((mb&Y)<<E)+(Ka&Y)|0;Ga=(c[O>>2]|0)+((ca(nb,wa)|0)+(ta<<3&8))|0;if($){Ca=(c[I>>2]|0)+((ca(Ea>>1,Ba)|0)+(ya>>1))|0;mf[c[(c[M>>2]|0)+16+(za<<2)>>2]&2047](Ga,Ca,Ba,8);Ca=(c[ba>>2]|0)+((ca(mb>>1,Ba)|0)+(Ka>>1))|0;mf[c[(c[aa>>2]|0)+16+(Da<<2)>>2]&2047](Ga,Ca,Ba,8)}else{Ca=(c[I>>2]|0)+((ca(Ea>>2,Ba)|0)+(ya>>2))|0;ef[c[(c[da>>2]|0)+64+(za<<2)>>2]&4095](Ga,Ca,Ba);Ca=(c[ba>>2]|0)+((ca(mb>>2,Ba)|0)+(Ka>>2))|0;ef[c[(c[ea>>2]|0)+64+(Da<<2)>>2]&4095](Ga,Ca,Ba)}ta=ta+1|0;if((ta|0)>=4){break e}}}if(ua){ta=0;do{Ca=(c[a+12160+(ta<<3)>>2]|0)+Fa|0;Ga=c[a+12160+(ta<<3)+4>>2]|0;Da=Ca-(c[a+12128+(ta<<3)>>2]|0)|0;Ka=ta>>1;za=((ca(c[a+12128+(ta<<3)+4>>2]|0,Aa)|0)/(Ma|0)|0)+(Ka<<_)|0;ya=((Ga&Y)<<E)+(Ca&Y)|0;Ea=((za&Y)<<E)+(Da&Y)|0;Ha=(c[O>>2]|0)+((ta<<3&8)+(ca(Ka,wa)|0))|0;if($){Ka=(c[I>>2]|0)+((ca(Ga>>1,Ba)|0)+(Ca>>1))|0;mf[c[(c[M>>2]|0)+16+(ya<<2)>>2]&2047](Ha,Ka,Ba,8);Ka=(c[ba>>2]|0)+((ca(za>>1,Ba)|0)+(Da>>1))|0;mf[c[(c[aa>>2]|0)+16+(Ea<<2)>>2]&2047](Ha,Ka,Ba,8)}else{Ka=(c[I>>2]|0)+((ca(Ga>>2,Ba)|0)+(Ca>>2))|0;ef[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095](Ha,Ka,Ba);Ka=(c[ba>>2]|0)+((ca(za>>2,Ba)|0)+(Da>>2))|0;ef[c[(c[ea>>2]|0)+64+(Ea<<2)>>2]&4095](Ha,Ka,Ba)}ta=ta+1|0;}while((ta|0)<4)}else{ta=0;do{Aa=(c[a+12160+(ta<<3)>>2]|0)+Fa|0;ua=(c[a+12160+(ta<<3)+4>>2]|0)+Xa|0;Ka=Aa-(c[a+12128+(ta<<3)>>2]|0)|0;Ha=ua-(c[a+12128+(ta<<3)+4>>2]|0)|0;Ea=((ua&Y)<<E)+(Aa&Y)|0;Da=((Ha&Y)<<E)+(Ka&Y)|0;za=(c[O>>2]|0)+((ta<<3&8)+(ca(ta>>1,wa)|0))|0;if($){ya=(c[I>>2]|0)+((ca(ua>>1,Ba)|0)+(Aa>>1))|0;mf[c[(c[M>>2]|0)+16+(Ea<<2)>>2]&2047](za,ya,Ba,8);ya=(c[ba>>2]|0)+((ca(Ha>>1,Ba)|0)+(Ka>>1))|0;mf[c[(c[aa>>2]|0)+16+(Da<<2)>>2]&2047](za,ya,Ba,8)}else{ya=(c[I>>2]|0)+((ca(ua>>2,Ba)|0)+(Aa>>2))|0;ef[c[(c[da>>2]|0)+64+(Ea<<2)>>2]&4095](za,ya,Ba);ya=(c[ba>>2]|0)+((ca(Ha>>2,Ba)|0)+(Ka>>2))|0;ef[c[(c[ea>>2]|0)+64+(Da<<2)>>2]&4095](za,ya,Ba)}ta=ta+1|0;}while((ta|0)<4)}}else{ta=(c[fa>>2]|0)+Fa|0;wa=(c[ga>>2]|0)+Xa|0;ya=c[ha>>2]|0;if((Fa|0)==0){ob=(ca(ya,va-Ma|0)|0)/(Ma|0)|0}else{ob=ta-ya|0}ya=c[ia>>2]|0;if((Xa|0)==0){pb=(ca(ya,va-Ma|0)|0)/(Ma|0)|0}else{pb=wa-ya|0}ya=((wa&Y)<<E)+(ta&Y)|0;za=((pb&Y)<<E)+(ob&Y)|0;if($){Da=(c[I>>2]|0)+((ca(wa>>1,Ba)|0)+(ta>>1))|0;mf[c[(c[M>>2]|0)+(ya<<2)>>2]&2047](c[O>>2]|0,Da,Ba,16);Da=(c[ba>>2]|0)+((ca(pb>>1,Ba)|0)+(ob>>1))|0;mf[c[(c[aa>>2]|0)+(za<<2)>>2]&2047](c[O>>2]|0,Da,Ba,16);break}else{Da=(ca(wa>>2,Ba)|0)+(ta>>2)|0;ef[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095](c[O>>2]|0,(c[I>>2]|0)+Da|0,Ba);ta=Da+8|0;ef[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[I>>2]|0)+ta|0,Ba);wa=Ba<<3;ef[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095]((c[O>>2]|0)+wa|0,(c[I>>2]|0)+(Da+wa)|0,Ba);Da=wa+8|0;ef[c[(c[da>>2]|0)+64+(ya<<2)>>2]&4095]((c[O>>2]|0)+Da|0,(c[I>>2]|0)+(ta+wa)|0,Ba);ta=(ca(pb>>2,Ba)|0)+(ob>>2)|0;ef[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095](c[O>>2]|0,(c[ba>>2]|0)+ta|0,Ba);ya=ta+8|0;ef[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095]((c[O>>2]|0)+8|0,(c[ba>>2]|0)+ya|0,Ba);ef[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095]((c[O>>2]|0)+wa|0,(c[ba>>2]|0)+(ta+wa)|0,Ba);ef[c[(c[ea>>2]|0)+64+(za<<2)>>2]&4095]((c[O>>2]|0)+Da|0,(c[ba>>2]|0)+(ya+wa)|0,Ba);break}}}while(0);lb=Xe[G&511](L,c[O>>2]|0,c[K>>2]|0,Ba,16)|0}}while(0);c[qa>>2]=sa;c[q+(ra<<2)>>2]=lb;Ba=(ca((d[z+((oa<<E)-B)|0]|0)+(d[z+((ka<<E)-A)|0]|0)|0,h)|0)+lb|0;if((Ba|0)<(c[V>>2]|0)){qb=0}else{break}while(1){rb=n+(qb<<4)|0;sb=rb|0;tb=qb+1|0;if((Ba|0)<(c[sb>>2]|0)){break}else{qb=tb}}orc(n+(tb<<4)|0,rb|0,(J-qb<<4)-16|0)|0;c[n+(qb<<4)+12>>2]=0;c[sb>>2]=Ba;c[n+(qb<<4)+4>>2]=ka;c[n+(qb<<4)+8>>2]=oa;Ta=-1;break a}}while(0);c[ma>>2]=1;Ta=ja}else{Ta=ja}}while(0);ja=Ta+1|0;}while((ja|0)<(J|0))}J=c[n+4>>2]|0;c[b>>2]=J;ja=c[n+8>>2]|0;Ta=b+4|0;c[Ta>>2]=ja;qb=c[n>>2]|0;if(!((J|0)<(w|0)&(J|0)>(s|0)&(ja|0)<(y|0)&(ja|0)>(u|0))){ub=qb;i=m;return ub|0}u=J-1|0;y=(ja<<11)+F+u|0;s=u+(ja<<3)&63;w=C+(s<<2)|0;do{if((c[w>>2]|0)==(y|0)){vb=qb;wb=ja;xb=J}else{do{if((l&4|0)==0){n=c[a+12416>>2]|0;sb=c[a+12420>>2]|0;rb=a;tb=(c[a+12352+(g<<4)>>2]|0)+((ca(n,ja)|0)+u)|0;V=Xe[G&511](rb,c[a+12288+(f<<4)>>2]|0,tb,n,k)|0;if((l&2|0)==0){yb=V;break}tb=u&1|ja<<1&2;lb=c[a+12208>>2]|0;K=n<<4;n=lb+K|0;O=a+12444|0;L=(ca(sb,ja>>1)|0)+(u>>1)|0;ba=k>>1;mf[c[(c[O>>2]|0)+(H<<4)+(tb<<2)>>2]&2047](n,(c[a+12352+(g<<4)+4>>2]|0)+L|0,sb,ba);ea=lb+(K|8)|0;mf[c[(c[O>>2]|0)+(H<<4)+(tb<<2)>>2]&2047](ea,(c[a+12352+(g<<4)+8>>2]|0)+L|0,sb,ba);L=(Xe[j&511](rb,n,c[a+12288+(f<<4)+4>>2]|0,sb,ba)|0)+V|0;yb=L+(Xe[j&511](rb,ea,c[a+12288+(f<<4)+8>>2]|0,sb,ba)|0)|0}else{ba=c[a+12416>>2]|0;sb=u<<E;ea=ja<<E;rb=a+12352+(g<<4)|0;L=a+12288+(f<<4)|0;if((c[r>>2]|0)>(u|0)){yb=536870912;break}if((sb|0)>(c[v>>2]<<E|0)){yb=536870912;break}if((c[t>>2]|0)>(ja|0)){yb=536870912;break}if((ea|0)>(c[x>>2]<<E|0)){yb=536870912;break}V=e[a+13872>>1]|0;n=e[a+13874>>1]|0;tb=D<<1|1;f:do{if((c[a+11740>>2]|0)==1){O=n-V|0;K=D|4;lb=(ea|0)==0;ob=a+12208|0;pb=ba<<3;I=(D|0)==0;da=a+12444|0;aa=a+12448|0;M=a+12352+(g<<4)+32|0;$=a+12452|0;Y=a+12456|0;if((sb|0)==0){ia=0;while(1){ha=c[a+12160+(ia<<3)>>2]|0;ga=(c[a+12160+(ia<<3)+4>>2]|0)+ea|0;fa=((ca(c[a+12128+(ia<<3)>>2]|0,O)|0)/(V|0)|0)+((ia&1)<<K)|0;_=c[a+12128+(ia<<3)+4>>2]|0;if(lb){mb=ia>>1;zb=((ca(_,O)|0)/(V|0)|0)+(mb<<K)|0;Ab=mb}else{zb=ga-_|0;Ab=ia>>1}_=((ga&tb)<<E)+(ha&tb)|0;mb=((zb&tb)<<E)+(fa&tb)|0;nb=(c[ob>>2]|0)+((ca(Ab,pb)|0)+(ia<<3&8))|0;if(I){Z=(c[rb>>2]|0)+((ca(ga>>1,ba)|0)+(ha>>1))|0;mf[c[(c[da>>2]|0)+16+(_<<2)>>2]&2047](nb,Z,ba,8);Z=(c[M>>2]|0)+((ca(zb>>1,ba)|0)+(fa>>1))|0;mf[c[(c[aa>>2]|0)+16+(mb<<2)>>2]&2047](nb,Z,ba,8)}else{Z=(c[rb>>2]|0)+((ca(ga>>2,ba)|0)+(ha>>2))|0;ef[c[(c[$>>2]|0)+64+(_<<2)>>2]&4095](nb,Z,ba);Z=(c[M>>2]|0)+((ca(zb>>2,ba)|0)+(fa>>2))|0;ef[c[(c[Y>>2]|0)+64+(mb<<2)>>2]&4095](nb,Z,ba)}ia=ia+1|0;if((ia|0)>=4){break f}}}if(lb){ia=0;do{Ba=(c[a+12160+(ia<<3)>>2]|0)+sb|0;Z=c[a+12160+(ia<<3)+4>>2]|0;nb=Ba-(c[a+12128+(ia<<3)>>2]|0)|0;mb=ia>>1;fa=((ca(c[a+12128+(ia<<3)+4>>2]|0,O)|0)/(V|0)|0)+(mb<<K)|0;_=((Z&tb)<<E)+(Ba&tb)|0;ha=((fa&tb)<<E)+(nb&tb)|0;ga=(c[ob>>2]|0)+((ia<<3&8)+(ca(mb,pb)|0))|0;if(I){mb=(c[rb>>2]|0)+((ca(Z>>1,ba)|0)+(Ba>>1))|0;mf[c[(c[da>>2]|0)+16+(_<<2)>>2]&2047](ga,mb,ba,8);mb=(c[M>>2]|0)+((ca(fa>>1,ba)|0)+(nb>>1))|0;mf[c[(c[aa>>2]|0)+16+(ha<<2)>>2]&2047](ga,mb,ba,8)}else{mb=(c[rb>>2]|0)+((ca(Z>>2,ba)|0)+(Ba>>2))|0;ef[c[(c[$>>2]|0)+64+(_<<2)>>2]&4095](ga,mb,ba);mb=(c[M>>2]|0)+((ca(fa>>2,ba)|0)+(nb>>2))|0;ef[c[(c[Y>>2]|0)+64+(ha<<2)>>2]&4095](ga,mb,ba)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{K=(c[a+12160+(ia<<3)>>2]|0)+sb|0;O=(c[a+12160+(ia<<3)+4>>2]|0)+ea|0;lb=K-(c[a+12128+(ia<<3)>>2]|0)|0;mb=O-(c[a+12128+(ia<<3)+4>>2]|0)|0;ga=((O&tb)<<E)+(K&tb)|0;ha=((mb&tb)<<E)+(lb&tb)|0;nb=(c[ob>>2]|0)+((ia<<3&8)+(ca(ia>>1,pb)|0))|0;if(I){fa=(c[rb>>2]|0)+((ca(O>>1,ba)|0)+(K>>1))|0;mf[c[(c[da>>2]|0)+16+(ga<<2)>>2]&2047](nb,fa,ba,8);fa=(c[M>>2]|0)+((ca(mb>>1,ba)|0)+(lb>>1))|0;mf[c[(c[aa>>2]|0)+16+(ha<<2)>>2]&2047](nb,fa,ba,8)}else{fa=(c[rb>>2]|0)+((ca(O>>2,ba)|0)+(K>>2))|0;ef[c[(c[$>>2]|0)+64+(ga<<2)>>2]&4095](nb,fa,ba);fa=(c[M>>2]|0)+((ca(mb>>2,ba)|0)+(lb>>2))|0;ef[c[(c[Y>>2]|0)+64+(ha<<2)>>2]&4095](nb,fa,ba)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[a+12160>>2]|0)+sb|0;Y=(c[a+12164>>2]|0)+ea|0;M=c[a+12128>>2]|0;if((sb|0)==0){Bb=(ca(M,n-V|0)|0)/(V|0)|0}else{Bb=ia-M|0}M=c[a+12132>>2]|0;if((ea|0)==0){Cb=(ca(M,n-V|0)|0)/(V|0)|0}else{Cb=Y-M|0}M=((Y&tb)<<E)+(ia&tb)|0;$=((Cb&tb)<<E)+(Bb&tb)|0;if((D|0)==0){aa=a+12208|0;da=(c[rb>>2]|0)+((ca(Y>>1,ba)|0)+(ia>>1))|0;mf[c[(c[a+12444>>2]|0)+(M<<2)>>2]&2047](c[aa>>2]|0,da,ba,16);da=(c[a+12352+(g<<4)+32>>2]|0)+((ca(Cb>>1,ba)|0)+(Bb>>1))|0;mf[c[(c[a+12448>>2]|0)+($<<2)>>2]&2047](c[aa>>2]|0,da,ba,16);break}else{da=a+12452|0;aa=a+12208|0;I=(ca(Y>>2,ba)|0)+(ia>>2)|0;ef[c[(c[da>>2]|0)+64+(M<<2)>>2]&4095](c[aa>>2]|0,(c[rb>>2]|0)+I|0,ba);ia=I+8|0;ef[c[(c[da>>2]|0)+64+(M<<2)>>2]&4095]((c[aa>>2]|0)+8|0,(c[rb>>2]|0)+ia|0,ba);Y=ba<<3;ef[c[(c[da>>2]|0)+64+(M<<2)>>2]&4095]((c[aa>>2]|0)+Y|0,(c[rb>>2]|0)+(I+Y)|0,ba);I=Y+8|0;ef[c[(c[da>>2]|0)+64+(M<<2)>>2]&4095]((c[aa>>2]|0)+I|0,(c[rb>>2]|0)+(ia+Y)|0,ba);ia=a+12456|0;M=a+12352+(g<<4)+32|0;da=(ca(Cb>>2,ba)|0)+(Bb>>2)|0;ef[c[(c[ia>>2]|0)+64+($<<2)>>2]&4095](c[aa>>2]|0,(c[M>>2]|0)+da|0,ba);pb=da+8|0;ef[c[(c[ia>>2]|0)+64+($<<2)>>2]&4095]((c[aa>>2]|0)+8|0,(c[M>>2]|0)+pb|0,ba);ef[c[(c[ia>>2]|0)+64+($<<2)>>2]&4095]((c[aa>>2]|0)+Y|0,(c[M>>2]|0)+(da+Y)|0,ba);ef[c[(c[ia>>2]|0)+64+($<<2)>>2]&4095]((c[aa>>2]|0)+I|0,(c[M>>2]|0)+(pb+Y)|0,ba);break}}}while(0);yb=Xe[G&511](a,c[a+12208>>2]|0,c[L>>2]|0,ba,16)|0}}while(0);c[w>>2]=y;c[q+(s<<2)>>2]=yb;rb=c[b>>2]|0;tb=rb-1|0;V=c[Ta>>2]|0;n=(ca((d[z+((V<<E)-B)|0]|0)+(d[z+((tb<<E)-A)|0]|0)|0,h)|0)+yb|0;if((n|0)>=(qb|0)){vb=qb;wb=V;xb=rb;break}c[b>>2]=tb;vb=n;wb=V;xb=tb}}while(0);qb=xb+1|0;yb=(wb<<11)+F+qb|0;s=qb+(wb<<3)&63;y=C+(s<<2)|0;do{if((c[y>>2]|0)==(yb|0)){Db=vb;Eb=wb;Fb=xb}else{do{if((l&4|0)==0){w=c[a+12416>>2]|0;Bb=c[a+12420>>2]|0;Cb=a;zb=(c[a+12352+(g<<4)>>2]|0)+((ca(w,wb)|0)+qb)|0;Ab=Xe[G&511](Cb,c[a+12288+(f<<4)>>2]|0,zb,w,k)|0;if((l&2|0)==0){Gb=Ab;break}zb=qb&1|wb<<1&2;ja=c[a+12208>>2]|0;u=w<<4;w=ja+u|0;J=a+12444|0;tb=(ca(Bb,wb>>1)|0)+(qb>>1)|0;V=k>>1;mf[c[(c[J>>2]|0)+(H<<4)+(zb<<2)>>2]&2047](w,(c[a+12352+(g<<4)+4>>2]|0)+tb|0,Bb,V);n=ja+(u|8)|0;mf[c[(c[J>>2]|0)+(H<<4)+(zb<<2)>>2]&2047](n,(c[a+12352+(g<<4)+8>>2]|0)+tb|0,Bb,V);tb=(Xe[j&511](Cb,w,c[a+12288+(f<<4)+4>>2]|0,Bb,V)|0)+Ab|0;Gb=tb+(Xe[j&511](Cb,n,c[a+12288+(f<<4)+8>>2]|0,Bb,V)|0)|0}else{V=c[a+12416>>2]|0;Bb=qb<<E;n=wb<<E;Cb=a+12352+(g<<4)|0;tb=a+12288+(f<<4)|0;if((c[r>>2]|0)>(qb|0)){Gb=536870912;break}if((Bb|0)>(c[v>>2]<<E|0)){Gb=536870912;break}if((c[t>>2]|0)>(wb|0)){Gb=536870912;break}if((n|0)>(c[x>>2]<<E|0)){Gb=536870912;break}Ab=e[a+13872>>1]|0;w=e[a+13874>>1]|0;zb=D<<1|1;g:do{if((c[a+11740>>2]|0)==1){J=w-Ab|0;u=D|4;ja=(n|0)==0;rb=a+12208|0;ea=V<<3;sb=(D|0)==0;Y=a+12444|0;pb=a+12448|0;M=a+12352+(g<<4)+32|0;I=a+12452|0;aa=a+12456|0;if((Bb|0)==0){$=0;while(1){ia=c[a+12160+($<<3)>>2]|0;da=(c[a+12160+($<<3)+4>>2]|0)+n|0;ob=((ca(c[a+12128+($<<3)>>2]|0,J)|0)/(Ab|0)|0)+(($&1)<<u)|0;fa=c[a+12128+($<<3)+4>>2]|0;if(ja){nb=$>>1;Hb=((ca(fa,J)|0)/(Ab|0)|0)+(nb<<u)|0;Ib=nb}else{Hb=da-fa|0;Ib=$>>1}fa=((da&zb)<<E)+(ia&zb)|0;nb=((Hb&zb)<<E)+(ob&zb)|0;ha=(c[rb>>2]|0)+((ca(Ib,ea)|0)+($<<3&8))|0;if(sb){lb=(c[Cb>>2]|0)+((ca(da>>1,V)|0)+(ia>>1))|0;mf[c[(c[Y>>2]|0)+16+(fa<<2)>>2]&2047](ha,lb,V,8);lb=(c[M>>2]|0)+((ca(Hb>>1,V)|0)+(ob>>1))|0;mf[c[(c[pb>>2]|0)+16+(nb<<2)>>2]&2047](ha,lb,V,8)}else{lb=(c[Cb>>2]|0)+((ca(da>>2,V)|0)+(ia>>2))|0;ef[c[(c[I>>2]|0)+64+(fa<<2)>>2]&4095](ha,lb,V);lb=(c[M>>2]|0)+((ca(Hb>>2,V)|0)+(ob>>2))|0;ef[c[(c[aa>>2]|0)+64+(nb<<2)>>2]&4095](ha,lb,V)}$=$+1|0;if(($|0)>=4){break g}}}if(ja){$=0;do{lb=(c[a+12160+($<<3)>>2]|0)+Bb|0;ha=c[a+12160+($<<3)+4>>2]|0;nb=lb-(c[a+12128+($<<3)>>2]|0)|0;ob=$>>1;fa=((ca(c[a+12128+($<<3)+4>>2]|0,J)|0)/(Ab|0)|0)+(ob<<u)|0;ia=((ha&zb)<<E)+(lb&zb)|0;da=((fa&zb)<<E)+(nb&zb)|0;mb=(c[rb>>2]|0)+(($<<3&8)+(ca(ob,ea)|0))|0;if(sb){ob=(c[Cb>>2]|0)+((ca(ha>>1,V)|0)+(lb>>1))|0;mf[c[(c[Y>>2]|0)+16+(ia<<2)>>2]&2047](mb,ob,V,8);ob=(c[M>>2]|0)+((ca(fa>>1,V)|0)+(nb>>1))|0;mf[c[(c[pb>>2]|0)+16+(da<<2)>>2]&2047](mb,ob,V,8)}else{ob=(c[Cb>>2]|0)+((ca(ha>>2,V)|0)+(lb>>2))|0;ef[c[(c[I>>2]|0)+64+(ia<<2)>>2]&4095](mb,ob,V);ob=(c[M>>2]|0)+((ca(fa>>2,V)|0)+(nb>>2))|0;ef[c[(c[aa>>2]|0)+64+(da<<2)>>2]&4095](mb,ob,V)}$=$+1|0;}while(($|0)<4)}else{$=0;do{u=(c[a+12160+($<<3)>>2]|0)+Bb|0;J=(c[a+12160+($<<3)+4>>2]|0)+n|0;ja=u-(c[a+12128+($<<3)>>2]|0)|0;ob=J-(c[a+12128+($<<3)+4>>2]|0)|0;mb=((J&zb)<<E)+(u&zb)|0;da=((ob&zb)<<E)+(ja&zb)|0;nb=(c[rb>>2]|0)+(($<<3&8)+(ca($>>1,ea)|0))|0;if(sb){fa=(c[Cb>>2]|0)+((ca(J>>1,V)|0)+(u>>1))|0;mf[c[(c[Y>>2]|0)+16+(mb<<2)>>2]&2047](nb,fa,V,8);fa=(c[M>>2]|0)+((ca(ob>>1,V)|0)+(ja>>1))|0;mf[c[(c[pb>>2]|0)+16+(da<<2)>>2]&2047](nb,fa,V,8)}else{fa=(c[Cb>>2]|0)+((ca(J>>2,V)|0)+(u>>2))|0;ef[c[(c[I>>2]|0)+64+(mb<<2)>>2]&4095](nb,fa,V);fa=(c[M>>2]|0)+((ca(ob>>2,V)|0)+(ja>>2))|0;ef[c[(c[aa>>2]|0)+64+(da<<2)>>2]&4095](nb,fa,V)}$=$+1|0;}while(($|0)<4)}}else{$=(c[a+12160>>2]|0)+Bb|0;aa=(c[a+12164>>2]|0)+n|0;M=c[a+12128>>2]|0;if((Bb|0)==0){Jb=(ca(M,w-Ab|0)|0)/(Ab|0)|0}else{Jb=$-M|0}M=c[a+12132>>2]|0;if((n|0)==0){Kb=(ca(M,w-Ab|0)|0)/(Ab|0)|0}else{Kb=aa-M|0}M=((aa&zb)<<E)+($&zb)|0;I=((Kb&zb)<<E)+(Jb&zb)|0;if((D|0)==0){pb=a+12208|0;Y=(c[Cb>>2]|0)+((ca(aa>>1,V)|0)+($>>1))|0;mf[c[(c[a+12444>>2]|0)+(M<<2)>>2]&2047](c[pb>>2]|0,Y,V,16);Y=(c[a+12352+(g<<4)+32>>2]|0)+((ca(Kb>>1,V)|0)+(Jb>>1))|0;mf[c[(c[a+12448>>2]|0)+(I<<2)>>2]&2047](c[pb>>2]|0,Y,V,16);break}else{Y=a+12452|0;pb=a+12208|0;sb=(ca(aa>>2,V)|0)+($>>2)|0;ef[c[(c[Y>>2]|0)+64+(M<<2)>>2]&4095](c[pb>>2]|0,(c[Cb>>2]|0)+sb|0,V);$=sb+8|0;ef[c[(c[Y>>2]|0)+64+(M<<2)>>2]&4095]((c[pb>>2]|0)+8|0,(c[Cb>>2]|0)+$|0,V);aa=V<<3;ef[c[(c[Y>>2]|0)+64+(M<<2)>>2]&4095]((c[pb>>2]|0)+aa|0,(c[Cb>>2]|0)+(sb+aa)|0,V);sb=aa+8|0;ef[c[(c[Y>>2]|0)+64+(M<<2)>>2]&4095]((c[pb>>2]|0)+sb|0,(c[Cb>>2]|0)+($+aa)|0,V);$=a+12456|0;M=a+12352+(g<<4)+32|0;Y=(ca(Kb>>2,V)|0)+(Jb>>2)|0;ef[c[(c[$>>2]|0)+64+(I<<2)>>2]&4095](c[pb>>2]|0,(c[M>>2]|0)+Y|0,V);ea=Y+8|0;ef[c[(c[$>>2]|0)+64+(I<<2)>>2]&4095]((c[pb>>2]|0)+8|0,(c[M>>2]|0)+ea|0,V);ef[c[(c[$>>2]|0)+64+(I<<2)>>2]&4095]((c[pb>>2]|0)+aa|0,(c[M>>2]|0)+(Y+aa)|0,V);ef[c[(c[$>>2]|0)+64+(I<<2)>>2]&4095]((c[pb>>2]|0)+sb|0,(c[M>>2]|0)+(ea+aa)|0,V);break}}}while(0);Gb=Xe[G&511](a,c[a+12208>>2]|0,c[tb>>2]|0,V,16)|0}}while(0);c[y>>2]=yb;c[q+(s<<2)>>2]=Gb;Cb=c[b>>2]|0;zb=Cb+1|0;Ab=c[Ta>>2]|0;w=(ca((d[z+((Ab<<E)-B)|0]|0)+(d[z+((zb<<E)-A)|0]|0)|0,h)|0)+Gb|0;if((w|0)>=(vb|0)){Db=vb;Eb=Ab;Fb=Cb;break}c[b>>2]=zb;Db=w;Eb=Ab;Fb=zb}}while(0);vb=Eb-1|0;Gb=Fb+F+(vb<<11)|0;s=(vb<<3)+Fb&63;yb=C+(s<<2)|0;do{if((c[yb>>2]|0)==(Gb|0)){Lb=Db;Mb=Eb;Nb=Fb}else{do{if((l&4|0)==0){y=c[a+12416>>2]|0;Jb=c[a+12420>>2]|0;Kb=a;Hb=(c[a+12352+(g<<4)>>2]|0)+((ca(y,vb)|0)+Fb)|0;Ib=Xe[G&511](Kb,c[a+12288+(f<<4)>>2]|0,Hb,y,k)|0;if((l&2|0)==0){Ob=Ib;break}Hb=vb<<1&2|Fb&1;wb=c[a+12208>>2]|0;qb=y<<4;y=wb+qb|0;xb=a+12444|0;zb=(ca(Jb,vb>>1)|0)+(Fb>>1)|0;Ab=k>>1;mf[c[(c[xb>>2]|0)+(H<<4)+(Hb<<2)>>2]&2047](y,(c[a+12352+(g<<4)+4>>2]|0)+zb|0,Jb,Ab);w=wb+(qb|8)|0;mf[c[(c[xb>>2]|0)+(H<<4)+(Hb<<2)>>2]&2047](w,(c[a+12352+(g<<4)+8>>2]|0)+zb|0,Jb,Ab);zb=(Xe[j&511](Kb,y,c[a+12288+(f<<4)+4>>2]|0,Jb,Ab)|0)+Ib|0;Ob=zb+(Xe[j&511](Kb,w,c[a+12288+(f<<4)+8>>2]|0,Jb,Ab)|0)|0}else{Ab=c[a+12416>>2]|0;Jb=Fb<<E;w=vb<<E;Kb=a+12352+(g<<4)|0;zb=a+12288+(f<<4)|0;if((c[r>>2]|0)>(Fb|0)){Ob=536870912;break}if((Jb|0)>(c[v>>2]<<E|0)){Ob=536870912;break}if((c[t>>2]|0)>(vb|0)){Ob=536870912;break}if((w|0)>(c[x>>2]<<E|0)){Ob=536870912;break}Ib=e[a+13872>>1]|0;y=e[a+13874>>1]|0;Hb=D<<1|1;h:do{if((c[a+11740>>2]|0)==1){xb=y-Ib|0;qb=D|4;wb=(w|0)==0;Cb=a+12208|0;n=Ab<<3;Bb=(D|0)==0;ba=a+12444|0;L=a+12448|0;aa=a+12352+(g<<4)+32|0;ea=a+12452|0;M=a+12456|0;if((Jb|0)==0){sb=0;while(1){pb=c[a+12160+(sb<<3)>>2]|0;I=(c[a+12160+(sb<<3)+4>>2]|0)+w|0;$=((ca(c[a+12128+(sb<<3)>>2]|0,xb)|0)/(Ib|0)|0)+((sb&1)<<qb)|0;Y=c[a+12128+(sb<<3)+4>>2]|0;if(wb){rb=sb>>1;Pb=((ca(Y,xb)|0)/(Ib|0)|0)+(rb<<qb)|0;Qb=rb}else{Pb=I-Y|0;Qb=sb>>1}Y=((I&Hb)<<E)+(pb&Hb)|0;rb=((Pb&Hb)<<E)+($&Hb)|0;fa=(c[Cb>>2]|0)+((ca(Qb,n)|0)+(sb<<3&8))|0;if(Bb){nb=(c[Kb>>2]|0)+((ca(I>>1,Ab)|0)+(pb>>1))|0;mf[c[(c[ba>>2]|0)+16+(Y<<2)>>2]&2047](fa,nb,Ab,8);nb=(c[aa>>2]|0)+((ca(Pb>>1,Ab)|0)+($>>1))|0;mf[c[(c[L>>2]|0)+16+(rb<<2)>>2]&2047](fa,nb,Ab,8)}else{nb=(c[Kb>>2]|0)+((ca(I>>2,Ab)|0)+(pb>>2))|0;ef[c[(c[ea>>2]|0)+64+(Y<<2)>>2]&4095](fa,nb,Ab);nb=(c[aa>>2]|0)+((ca(Pb>>2,Ab)|0)+($>>2))|0;ef[c[(c[M>>2]|0)+64+(rb<<2)>>2]&4095](fa,nb,Ab)}sb=sb+1|0;if((sb|0)>=4){break h}}}if(wb){sb=0;do{nb=(c[a+12160+(sb<<3)>>2]|0)+Jb|0;fa=c[a+12160+(sb<<3)+4>>2]|0;rb=nb-(c[a+12128+(sb<<3)>>2]|0)|0;$=sb>>1;Y=((ca(c[a+12128+(sb<<3)+4>>2]|0,xb)|0)/(Ib|0)|0)+($<<qb)|0;pb=((fa&Hb)<<E)+(nb&Hb)|0;I=((Y&Hb)<<E)+(rb&Hb)|0;da=(c[Cb>>2]|0)+((sb<<3&8)+(ca($,n)|0))|0;if(Bb){$=(c[Kb>>2]|0)+((ca(fa>>1,Ab)|0)+(nb>>1))|0;mf[c[(c[ba>>2]|0)+16+(pb<<2)>>2]&2047](da,$,Ab,8);$=(c[aa>>2]|0)+((ca(Y>>1,Ab)|0)+(rb>>1))|0;mf[c[(c[L>>2]|0)+16+(I<<2)>>2]&2047](da,$,Ab,8)}else{$=(c[Kb>>2]|0)+((ca(fa>>2,Ab)|0)+(nb>>2))|0;ef[c[(c[ea>>2]|0)+64+(pb<<2)>>2]&4095](da,$,Ab);$=(c[aa>>2]|0)+((ca(Y>>2,Ab)|0)+(rb>>2))|0;ef[c[(c[M>>2]|0)+64+(I<<2)>>2]&4095](da,$,Ab)}sb=sb+1|0;}while((sb|0)<4)}else{sb=0;do{qb=(c[a+12160+(sb<<3)>>2]|0)+Jb|0;xb=(c[a+12160+(sb<<3)+4>>2]|0)+w|0;wb=qb-(c[a+12128+(sb<<3)>>2]|0)|0;$=xb-(c[a+12128+(sb<<3)+4>>2]|0)|0;da=((xb&Hb)<<E)+(qb&Hb)|0;I=(($&Hb)<<E)+(wb&Hb)|0;rb=(c[Cb>>2]|0)+((sb<<3&8)+(ca(sb>>1,n)|0))|0;if(Bb){Y=(c[Kb>>2]|0)+((ca(xb>>1,Ab)|0)+(qb>>1))|0;mf[c[(c[ba>>2]|0)+16+(da<<2)>>2]&2047](rb,Y,Ab,8);Y=(c[aa>>2]|0)+((ca($>>1,Ab)|0)+(wb>>1))|0;mf[c[(c[L>>2]|0)+16+(I<<2)>>2]&2047](rb,Y,Ab,8)}else{Y=(c[Kb>>2]|0)+((ca(xb>>2,Ab)|0)+(qb>>2))|0;ef[c[(c[ea>>2]|0)+64+(da<<2)>>2]&4095](rb,Y,Ab);Y=(c[aa>>2]|0)+((ca($>>2,Ab)|0)+(wb>>2))|0;ef[c[(c[M>>2]|0)+64+(I<<2)>>2]&4095](rb,Y,Ab)}sb=sb+1|0;}while((sb|0)<4)}}else{sb=(c[a+12160>>2]|0)+Jb|0;M=(c[a+12164>>2]|0)+w|0;aa=c[a+12128>>2]|0;if((Jb|0)==0){Rb=(ca(aa,y-Ib|0)|0)/(Ib|0)|0}else{Rb=sb-aa|0}aa=c[a+12132>>2]|0;if((w|0)==0){Sb=(ca(aa,y-Ib|0)|0)/(Ib|0)|0}else{Sb=M-aa|0}aa=((M&Hb)<<E)+(sb&Hb)|0;ea=((Sb&Hb)<<E)+(Rb&Hb)|0;if((D|0)==0){L=a+12208|0;ba=(c[Kb>>2]|0)+((ca(M>>1,Ab)|0)+(sb>>1))|0;mf[c[(c[a+12444>>2]|0)+(aa<<2)>>2]&2047](c[L>>2]|0,ba,Ab,16);ba=(c[a+12352+(g<<4)+32>>2]|0)+((ca(Sb>>1,Ab)|0)+(Rb>>1))|0;mf[c[(c[a+12448>>2]|0)+(ea<<2)>>2]&2047](c[L>>2]|0,ba,Ab,16);break}else{ba=a+12452|0;L=a+12208|0;Bb=(ca(M>>2,Ab)|0)+(sb>>2)|0;ef[c[(c[ba>>2]|0)+64+(aa<<2)>>2]&4095](c[L>>2]|0,(c[Kb>>2]|0)+Bb|0,Ab);sb=Bb+8|0;ef[c[(c[ba>>2]|0)+64+(aa<<2)>>2]&4095]((c[L>>2]|0)+8|0,(c[Kb>>2]|0)+sb|0,Ab);M=Ab<<3;ef[c[(c[ba>>2]|0)+64+(aa<<2)>>2]&4095]((c[L>>2]|0)+M|0,(c[Kb>>2]|0)+(Bb+M)|0,Ab);Bb=M+8|0;ef[c[(c[ba>>2]|0)+64+(aa<<2)>>2]&4095]((c[L>>2]|0)+Bb|0,(c[Kb>>2]|0)+(sb+M)|0,Ab);sb=a+12456|0;aa=a+12352+(g<<4)+32|0;ba=(ca(Sb>>2,Ab)|0)+(Rb>>2)|0;ef[c[(c[sb>>2]|0)+64+(ea<<2)>>2]&4095](c[L>>2]|0,(c[aa>>2]|0)+ba|0,Ab);n=ba+8|0;ef[c[(c[sb>>2]|0)+64+(ea<<2)>>2]&4095]((c[L>>2]|0)+8|0,(c[aa>>2]|0)+n|0,Ab);ef[c[(c[sb>>2]|0)+64+(ea<<2)>>2]&4095]((c[L>>2]|0)+M|0,(c[aa>>2]|0)+(ba+M)|0,Ab);ef[c[(c[sb>>2]|0)+64+(ea<<2)>>2]&4095]((c[L>>2]|0)+Bb|0,(c[aa>>2]|0)+(n+M)|0,Ab);break}}}while(0);Ob=Xe[G&511](a,c[a+12208>>2]|0,c[zb>>2]|0,Ab,16)|0}}while(0);c[yb>>2]=Gb;c[q+(s<<2)>>2]=Ob;Kb=c[b>>2]|0;Hb=c[Ta>>2]|0;Ib=Hb-1|0;y=(ca((d[z+((Ib<<E)-B)|0]|0)+(d[z+((Kb<<E)-A)|0]|0)|0,h)|0)+Ob|0;if((y|0)>=(Db|0)){Lb=Db;Mb=Hb;Nb=Kb;break}c[b>>2]=Kb;c[Ta>>2]=Ib;Lb=y;Mb=Ib;Nb=Kb}}while(0);Db=Mb+1|0;Mb=Nb+F+(Db<<11)|0;F=(Db<<3)+Nb&63;Ob=C+(F<<2)|0;if((c[Ob>>2]|0)==(Mb|0)){ub=Lb;i=m;return ub|0}do{if((l&4|0)==0){C=c[a+12416>>2]|0;s=c[a+12420>>2]|0;Gb=a;yb=(c[a+12352+(g<<4)>>2]|0)+((ca(C,Db)|0)+Nb)|0;Rb=Xe[G&511](Gb,c[a+12288+(f<<4)>>2]|0,yb,C,k)|0;if((l&2|0)==0){Tb=Rb;break}yb=Db<<1&2|Nb&1;Sb=c[a+12208>>2]|0;Pb=C<<4;C=Sb+Pb|0;Qb=a+12444|0;vb=(ca(s,Db>>1)|0)+(Nb>>1)|0;Fb=k>>1;mf[c[(c[Qb>>2]|0)+(H<<4)+(yb<<2)>>2]&2047](C,(c[a+12352+(g<<4)+4>>2]|0)+vb|0,s,Fb);Eb=Sb+(Pb|8)|0;mf[c[(c[Qb>>2]|0)+(H<<4)+(yb<<2)>>2]&2047](Eb,(c[a+12352+(g<<4)+8>>2]|0)+vb|0,s,Fb);vb=(Xe[j&511](Gb,C,c[a+12288+(f<<4)+4>>2]|0,s,Fb)|0)+Rb|0;Tb=vb+(Xe[j&511](Gb,Eb,c[a+12288+(f<<4)+8>>2]|0,s,Fb)|0)|0}else{Fb=c[a+12416>>2]|0;s=Nb<<E;Eb=Db<<E;Gb=a+12352+(g<<4)|0;vb=a+12288+(f<<4)|0;if((c[r>>2]|0)>(Nb|0)){Tb=536870912;break}if((s|0)>(c[v>>2]<<E|0)){Tb=536870912;break}if((c[t>>2]|0)>(Db|0)){Tb=536870912;break}if((Eb|0)>(c[x>>2]<<E|0)){Tb=536870912;break}Rb=e[a+13872>>1]|0;C=e[a+13874>>1]|0;yb=D<<1|1;i:do{if((c[a+11740>>2]|0)==1){Qb=C-Rb|0;Pb=D|4;Sb=(Eb|0)==0;Kb=a+12208|0;Ib=Fb<<3;y=(D|0)==0;Hb=a+12444|0;w=a+12448|0;Jb=a+12352+(g<<4)+32|0;V=a+12452|0;tb=a+12456|0;if((s|0)==0){M=0;while(1){n=c[a+12160+(M<<3)>>2]|0;aa=(c[a+12160+(M<<3)+4>>2]|0)+Eb|0;Bb=((ca(c[a+12128+(M<<3)>>2]|0,Qb)|0)/(Rb|0)|0)+((M&1)<<Pb)|0;L=c[a+12128+(M<<3)+4>>2]|0;if(Sb){ea=M>>1;Ub=((ca(L,Qb)|0)/(Rb|0)|0)+(ea<<Pb)|0;Vb=ea}else{Ub=aa-L|0;Vb=M>>1}L=((aa&yb)<<E)+(n&yb)|0;ea=((Ub&yb)<<E)+(Bb&yb)|0;sb=(c[Kb>>2]|0)+((ca(Vb,Ib)|0)+(M<<3&8))|0;if(y){ba=(c[Gb>>2]|0)+((ca(aa>>1,Fb)|0)+(n>>1))|0;mf[c[(c[Hb>>2]|0)+16+(L<<2)>>2]&2047](sb,ba,Fb,8);ba=(c[Jb>>2]|0)+((ca(Ub>>1,Fb)|0)+(Bb>>1))|0;mf[c[(c[w>>2]|0)+16+(ea<<2)>>2]&2047](sb,ba,Fb,8)}else{ba=(c[Gb>>2]|0)+((ca(aa>>2,Fb)|0)+(n>>2))|0;ef[c[(c[V>>2]|0)+64+(L<<2)>>2]&4095](sb,ba,Fb);ba=(c[Jb>>2]|0)+((ca(Ub>>2,Fb)|0)+(Bb>>2))|0;ef[c[(c[tb>>2]|0)+64+(ea<<2)>>2]&4095](sb,ba,Fb)}M=M+1|0;if((M|0)>=4){break i}}}if(Sb){M=0;do{Ab=(c[a+12160+(M<<3)>>2]|0)+s|0;zb=c[a+12160+(M<<3)+4>>2]|0;ba=Ab-(c[a+12128+(M<<3)>>2]|0)|0;sb=M>>1;ea=((ca(c[a+12128+(M<<3)+4>>2]|0,Qb)|0)/(Rb|0)|0)+(sb<<Pb)|0;Bb=((zb&yb)<<E)+(Ab&yb)|0;L=((ea&yb)<<E)+(ba&yb)|0;n=(c[Kb>>2]|0)+((M<<3&8)+(ca(sb,Ib)|0))|0;if(y){sb=(c[Gb>>2]|0)+((ca(zb>>1,Fb)|0)+(Ab>>1))|0;mf[c[(c[Hb>>2]|0)+16+(Bb<<2)>>2]&2047](n,sb,Fb,8);sb=(c[Jb>>2]|0)+((ca(ea>>1,Fb)|0)+(ba>>1))|0;mf[c[(c[w>>2]|0)+16+(L<<2)>>2]&2047](n,sb,Fb,8)}else{sb=(c[Gb>>2]|0)+((ca(zb>>2,Fb)|0)+(Ab>>2))|0;ef[c[(c[V>>2]|0)+64+(Bb<<2)>>2]&4095](n,sb,Fb);sb=(c[Jb>>2]|0)+((ca(ea>>2,Fb)|0)+(ba>>2))|0;ef[c[(c[tb>>2]|0)+64+(L<<2)>>2]&4095](n,sb,Fb)}M=M+1|0;}while((M|0)<4)}else{M=0;do{Pb=(c[a+12160+(M<<3)>>2]|0)+s|0;Qb=(c[a+12160+(M<<3)+4>>2]|0)+Eb|0;Sb=Pb-(c[a+12128+(M<<3)>>2]|0)|0;sb=Qb-(c[a+12128+(M<<3)+4>>2]|0)|0;n=((Qb&yb)<<E)+(Pb&yb)|0;L=((sb&yb)<<E)+(Sb&yb)|0;ba=(c[Kb>>2]|0)+((M<<3&8)+(ca(M>>1,Ib)|0))|0;if(y){ea=(c[Gb>>2]|0)+((ca(Qb>>1,Fb)|0)+(Pb>>1))|0;mf[c[(c[Hb>>2]|0)+16+(n<<2)>>2]&2047](ba,ea,Fb,8);ea=(c[Jb>>2]|0)+((ca(sb>>1,Fb)|0)+(Sb>>1))|0;mf[c[(c[w>>2]|0)+16+(L<<2)>>2]&2047](ba,ea,Fb,8)}else{ea=(c[Gb>>2]|0)+((ca(Qb>>2,Fb)|0)+(Pb>>2))|0;ef[c[(c[V>>2]|0)+64+(n<<2)>>2]&4095](ba,ea,Fb);ea=(c[Jb>>2]|0)+((ca(sb>>2,Fb)|0)+(Sb>>2))|0;ef[c[(c[tb>>2]|0)+64+(L<<2)>>2]&4095](ba,ea,Fb)}M=M+1|0;}while((M|0)<4)}}else{M=(c[a+12160>>2]|0)+s|0;tb=(c[a+12164>>2]|0)+Eb|0;Jb=c[a+12128>>2]|0;if((s|0)==0){Wb=(ca(Jb,C-Rb|0)|0)/(Rb|0)|0}else{Wb=M-Jb|0}Jb=c[a+12132>>2]|0;if((Eb|0)==0){Xb=(ca(Jb,C-Rb|0)|0)/(Rb|0)|0}else{Xb=tb-Jb|0}Jb=((tb&yb)<<E)+(M&yb)|0;V=((Xb&yb)<<E)+(Wb&yb)|0;if((D|0)==0){w=a+12208|0;Hb=(c[Gb>>2]|0)+((ca(tb>>1,Fb)|0)+(M>>1))|0;mf[c[(c[a+12444>>2]|0)+(Jb<<2)>>2]&2047](c[w>>2]|0,Hb,Fb,16);Hb=(c[a+12352+(g<<4)+32>>2]|0)+((ca(Xb>>1,Fb)|0)+(Wb>>1))|0;mf[c[(c[a+12448>>2]|0)+(V<<2)>>2]&2047](c[w>>2]|0,Hb,Fb,16);break}else{Hb=a+12452|0;w=a+12208|0;y=(ca(tb>>2,Fb)|0)+(M>>2)|0;ef[c[(c[Hb>>2]|0)+64+(Jb<<2)>>2]&4095](c[w>>2]|0,(c[Gb>>2]|0)+y|0,Fb);M=y+8|0;ef[c[(c[Hb>>2]|0)+64+(Jb<<2)>>2]&4095]((c[w>>2]|0)+8|0,(c[Gb>>2]|0)+M|0,Fb);tb=Fb<<3;ef[c[(c[Hb>>2]|0)+64+(Jb<<2)>>2]&4095]((c[w>>2]|0)+tb|0,(c[Gb>>2]|0)+(y+tb)|0,Fb);y=tb+8|0;ef[c[(c[Hb>>2]|0)+64+(Jb<<2)>>2]&4095]((c[w>>2]|0)+y|0,(c[Gb>>2]|0)+(M+tb)|0,Fb);M=a+12456|0;Jb=a+12352+(g<<4)+32|0;Hb=(ca(Xb>>2,Fb)|0)+(Wb>>2)|0;ef[c[(c[M>>2]|0)+64+(V<<2)>>2]&4095](c[w>>2]|0,(c[Jb>>2]|0)+Hb|0,Fb);Ib=Hb+8|0;ef[c[(c[M>>2]|0)+64+(V<<2)>>2]&4095]((c[w>>2]|0)+8|0,(c[Jb>>2]|0)+Ib|0,Fb);ef[c[(c[M>>2]|0)+64+(V<<2)>>2]&4095]((c[w>>2]|0)+tb|0,(c[Jb>>2]|0)+(Hb+tb)|0,Fb);ef[c[(c[M>>2]|0)+64+(V<<2)>>2]&4095]((c[w>>2]|0)+y|0,(c[Jb>>2]|0)+(Ib+tb)|0,Fb);break}}}while(0);Tb=Xe[G&511](a,c[a+12208>>2]|0,c[vb>>2]|0,Fb,16)|0}}while(0);c[Ob>>2]=Mb;c[q+(F<<2)>>2]=Tb;F=c[b>>2]|0;q=(c[Ta>>2]|0)+1|0;Mb=(ca((d[z+((q<<E)-B)|0]|0)+(d[z+((F<<E)-A)|0]|0)|0,h)|0)+Tb|0;if((Mb|0)>=(Lb|0)){ub=Lb;i=m;return ub|0}c[b>>2]=F;c[Ta>>2]=q;ub=Mb;i=m;return ub|0}function urb(a,b,f,g,h,i,j,k,l){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0;m=c[a+12220>>2]|0;n=a+12264|0;o=c[n>>2]|0;p=a+12272|0;q=c[p>>2]|0;r=a+12268|0;s=c[r>>2]|0;t=a+12276|0;u=c[t>>2]|0;v=c[a+12464>>2]|0;w=c[a+12280>>2]|0;x=c[a+12284>>2]|0;y=c[a+12216>>2]|0;z=l&1;A=z+1|0;B=c[a+12224>>2]|0;C=c[a+12260>>2]&255;D=c[a+10468+(j<<2)>>2]|0;E=j+1|0;j=c[a+10468+(E<<2)>>2]|0;F=-C|0;G=(q|0)<(F|0)?F:q;H=(C|0)>(u|0)?u:C;if((G|0)>(H|0)){I=f;J=b+4|0}else{K=(o|0)<(F|0)?F:o;F=(C|0)>(s|0)?s:C;C=(K|0)>(F|0);L=(l&4|0)==0;M=a+12416|0;N=a+12420|0;O=a+12352+(h<<4)|0;P=a+12288+(g<<4)|0;Q=a;R=(l&2|0)==0;S=a+12208|0;T=a+12444|0;U=a+12352+(h<<4)+4|0;V=k>>1;W=a+12352+(h<<4)+8|0;X=a+12288+(g<<4)+4|0;Y=a+12288+(g<<4)+8|0;Z=b+4|0;_=a+13872|0;$=a+13874|0;aa=z<<1|1;ba=a+11740|0;da=z|4;ea=(z|0)==0;fa=a+12448|0;ga=a+12352+(h<<4)+32|0;ha=a+12452|0;ia=a+12456|0;ja=a+12160|0;ka=a+12164|0;la=a+12128|0;ma=a+12132|0;na=G;G=f;while(1){if(C){oa=G}else{f=(na<<11)+B|0;pa=na<<3;qa=na<<1&2;ra=na>>1;sa=na<<A;ta=v+(sa-x)|0;ua=(sa|0)==0;va=K;wa=G;while(1){xa=f+va|0;ya=va+pa&63;za=y+(ya<<2)|0;do{if((c[za>>2]|0)==(xa|0)){Aa=wa}else{Ba=c[M>>2]|0;do{if(L){Ca=c[N>>2]|0;Da=(c[O>>2]|0)+((ca(Ba,na)|0)+va)|0;Ea=Xe[D&511](Q,c[P>>2]|0,Da,Ba,k)|0;if(R){Fa=Ea;break}Da=va&1|qa;Ga=c[S>>2]|0;Ha=Ba<<4;Ia=Ga+Ha|0;Ja=(ca(Ca,ra)|0)+(va>>1)|0;mf[c[(c[T>>2]|0)+(E<<4)+(Da<<2)>>2]&2047](Ia,(c[U>>2]|0)+Ja|0,Ca,V);Ka=Ga+(Ha|8)|0;mf[c[(c[T>>2]|0)+(E<<4)+(Da<<2)>>2]&2047](Ka,(c[W>>2]|0)+Ja|0,Ca,V);Ja=(Xe[j&511](Q,Ia,c[X>>2]|0,Ca,V)|0)+Ea|0;Fa=Ja+(Xe[j&511](Q,Ka,c[Y>>2]|0,Ca,V)|0)|0}else{Ca=va<<A;if((c[n>>2]|0)>(va|0)){Fa=536870912;break}if((Ca|0)>(c[r>>2]<<A|0)){Fa=536870912;break}if((c[p>>2]|0)>(na|0)){Fa=536870912;break}if((sa|0)>(c[t>>2]<<A|0)){Fa=536870912;break}Ka=e[_>>1]|0;Ja=e[$>>1]|0;a:do{if((c[ba>>2]|0)==1){Ea=Ja-Ka|0;Ia=Ba<<3;if((Ca|0)==0){Da=0;while(1){Ha=c[a+12160+(Da<<3)>>2]|0;Ga=(c[a+12160+(Da<<3)+4>>2]|0)+sa|0;La=((ca(c[a+12128+(Da<<3)>>2]|0,Ea)|0)/(Ka|0)|0)+((Da&1)<<da)|0;Ma=c[a+12128+(Da<<3)+4>>2]|0;if(ua){Na=Da>>1;Oa=((ca(Ma,Ea)|0)/(Ka|0)|0)+(Na<<da)|0;Pa=Na}else{Oa=Ga-Ma|0;Pa=Da>>1}Ma=((Ga&aa)<<A)+(Ha&aa)|0;Na=((Oa&aa)<<A)+(La&aa)|0;Qa=(c[S>>2]|0)+((ca(Pa,Ia)|0)+(Da<<3&8))|0;if(ea){Ra=(c[O>>2]|0)+((ca(Ga>>1,Ba)|0)+(Ha>>1))|0;mf[c[(c[T>>2]|0)+16+(Ma<<2)>>2]&2047](Qa,Ra,Ba,8);Ra=(c[ga>>2]|0)+((ca(Oa>>1,Ba)|0)+(La>>1))|0;mf[c[(c[fa>>2]|0)+16+(Na<<2)>>2]&2047](Qa,Ra,Ba,8)}else{Ra=(c[O>>2]|0)+((ca(Ga>>2,Ba)|0)+(Ha>>2))|0;ef[c[(c[ha>>2]|0)+64+(Ma<<2)>>2]&4095](Qa,Ra,Ba);Ra=(c[ga>>2]|0)+((ca(Oa>>2,Ba)|0)+(La>>2))|0;ef[c[(c[ia>>2]|0)+64+(Na<<2)>>2]&4095](Qa,Ra,Ba)}Da=Da+1|0;if((Da|0)>=4){break a}}}if(ua){Da=0;do{Ra=(c[a+12160+(Da<<3)>>2]|0)+Ca|0;Qa=c[a+12160+(Da<<3)+4>>2]|0;Na=Ra-(c[a+12128+(Da<<3)>>2]|0)|0;La=Da>>1;Ma=((ca(c[a+12128+(Da<<3)+4>>2]|0,Ea)|0)/(Ka|0)|0)+(La<<da)|0;Ha=((Qa&aa)<<A)+(Ra&aa)|0;Ga=((Ma&aa)<<A)+(Na&aa)|0;Sa=(c[S>>2]|0)+((Da<<3&8)+(ca(La,Ia)|0))|0;if(ea){La=(c[O>>2]|0)+((ca(Qa>>1,Ba)|0)+(Ra>>1))|0;mf[c[(c[T>>2]|0)+16+(Ha<<2)>>2]&2047](Sa,La,Ba,8);La=(c[ga>>2]|0)+((ca(Ma>>1,Ba)|0)+(Na>>1))|0;mf[c[(c[fa>>2]|0)+16+(Ga<<2)>>2]&2047](Sa,La,Ba,8)}else{La=(c[O>>2]|0)+((ca(Qa>>2,Ba)|0)+(Ra>>2))|0;ef[c[(c[ha>>2]|0)+64+(Ha<<2)>>2]&4095](Sa,La,Ba);La=(c[ga>>2]|0)+((ca(Ma>>2,Ba)|0)+(Na>>2))|0;ef[c[(c[ia>>2]|0)+64+(Ga<<2)>>2]&4095](Sa,La,Ba)}Da=Da+1|0;}while((Da|0)<4)}else{Da=0;do{Ea=(c[a+12160+(Da<<3)>>2]|0)+Ca|0;La=(c[a+12160+(Da<<3)+4>>2]|0)+sa|0;Sa=Ea-(c[a+12128+(Da<<3)>>2]|0)|0;Ga=La-(c[a+12128+(Da<<3)+4>>2]|0)|0;Na=((La&aa)<<A)+(Ea&aa)|0;Ma=((Ga&aa)<<A)+(Sa&aa)|0;Ha=(c[S>>2]|0)+((Da<<3&8)+(ca(Da>>1,Ia)|0))|0;if(ea){Ra=(c[O>>2]|0)+((ca(La>>1,Ba)|0)+(Ea>>1))|0;mf[c[(c[T>>2]|0)+16+(Na<<2)>>2]&2047](Ha,Ra,Ba,8);Ra=(c[ga>>2]|0)+((ca(Ga>>1,Ba)|0)+(Sa>>1))|0;mf[c[(c[fa>>2]|0)+16+(Ma<<2)>>2]&2047](Ha,Ra,Ba,8)}else{Ra=(c[O>>2]|0)+((ca(La>>2,Ba)|0)+(Ea>>2))|0;ef[c[(c[ha>>2]|0)+64+(Na<<2)>>2]&4095](Ha,Ra,Ba);Ra=(c[ga>>2]|0)+((ca(Ga>>2,Ba)|0)+(Sa>>2))|0;ef[c[(c[ia>>2]|0)+64+(Ma<<2)>>2]&4095](Ha,Ra,Ba)}Da=Da+1|0;}while((Da|0)<4)}}else{Da=(c[ja>>2]|0)+Ca|0;Ia=(c[ka>>2]|0)+sa|0;Ra=c[la>>2]|0;if((Ca|0)==0){Ta=(ca(Ra,Ja-Ka|0)|0)/(Ka|0)|0}else{Ta=Da-Ra|0}Ra=c[ma>>2]|0;if(ua){Ua=(ca(Ra,Ja-Ka|0)|0)/(Ka|0)|0}else{Ua=Ia-Ra|0}Ra=((Ia&aa)<<A)+(Da&aa)|0;Ha=((Ua&aa)<<A)+(Ta&aa)|0;if(ea){Ma=(c[O>>2]|0)+((ca(Ia>>1,Ba)|0)+(Da>>1))|0;mf[c[(c[T>>2]|0)+(Ra<<2)>>2]&2047](c[S>>2]|0,Ma,Ba,16);Ma=(c[ga>>2]|0)+((ca(Ua>>1,Ba)|0)+(Ta>>1))|0;mf[c[(c[fa>>2]|0)+(Ha<<2)>>2]&2047](c[S>>2]|0,Ma,Ba,16);break}else{Ma=(ca(Ia>>2,Ba)|0)+(Da>>2)|0;ef[c[(c[ha>>2]|0)+64+(Ra<<2)>>2]&4095](c[S>>2]|0,(c[O>>2]|0)+Ma|0,Ba);Da=Ma+8|0;ef[c[(c[ha>>2]|0)+64+(Ra<<2)>>2]&4095]((c[S>>2]|0)+8|0,(c[O>>2]|0)+Da|0,Ba);Ia=Ba<<3;ef[c[(c[ha>>2]|0)+64+(Ra<<2)>>2]&4095]((c[S>>2]|0)+Ia|0,(c[O>>2]|0)+(Ma+Ia)|0,Ba);Ma=Ia+8|0;ef[c[(c[ha>>2]|0)+64+(Ra<<2)>>2]&4095]((c[S>>2]|0)+Ma|0,(c[O>>2]|0)+(Da+Ia)|0,Ba);Da=(ca(Ua>>2,Ba)|0)+(Ta>>2)|0;ef[c[(c[ia>>2]|0)+64+(Ha<<2)>>2]&4095](c[S>>2]|0,(c[ga>>2]|0)+Da|0,Ba);Ra=Da+8|0;ef[c[(c[ia>>2]|0)+64+(Ha<<2)>>2]&4095]((c[S>>2]|0)+8|0,(c[ga>>2]|0)+Ra|0,Ba);ef[c[(c[ia>>2]|0)+64+(Ha<<2)>>2]&4095]((c[S>>2]|0)+Ia|0,(c[ga>>2]|0)+(Da+Ia)|0,Ba);ef[c[(c[ia>>2]|0)+64+(Ha<<2)>>2]&4095]((c[S>>2]|0)+Ma|0,(c[ga>>2]|0)+(Ra+Ia)|0,Ba);break}}}while(0);Fa=Xe[D&511](Q,c[S>>2]|0,c[P>>2]|0,Ba,16)|0}}while(0);c[za>>2]=xa;c[m+(ya<<2)>>2]=Fa;Ba=(ca((d[ta]|0)+(d[v+((va<<A)-w)|0]|0)|0,i)|0)+Fa|0;if((Ba|0)>=(wa|0)){Aa=wa;break}c[b>>2]=va;c[Z>>2]=na;Aa=Ba}}while(0);ya=va+1|0;if((ya|0)>(F|0)){oa=Aa;break}else{va=ya;wa=Aa}}}wa=na+1|0;if((wa|0)>(H|0)){I=oa;J=Z;break}else{na=wa;G=oa}}}oa=c[b>>2]|0;G=c[J>>2]|0;na=(oa|0)>(s|0)?s:oa;Z=(o|0)>(na|0)?o:na;na=(G|0)>(u|0)?u:G;H=(q|0)>(na|0)?q:na;na=H<<11;Aa=Z+B|0;F=Aa+na|0;Fa=H<<3;P=Fa+Z&63;S=y+(P<<2)|0;do{if((c[S>>2]|0)==(F|0)){Va=I;Wa=I}else{do{if((l&4|0)==0){Q=c[a+12416>>2]|0;ga=c[a+12420>>2]|0;ia=a;Ta=(c[a+12352+(h<<4)>>2]|0)+((ca(Q,H)|0)+Z)|0;Ua=Xe[D&511](ia,c[a+12288+(g<<4)>>2]|0,Ta,Q,k)|0;if((l&2|0)==0){Xa=Ua;break}Ta=H<<1&2|Z&1;O=c[a+12208>>2]|0;ha=Q<<4;Q=O+ha|0;fa=a+12444|0;T=(ca(ga,H>>1)|0)+(Z>>1)|0;ea=k>>1;mf[c[(c[fa>>2]|0)+(E<<4)+(Ta<<2)>>2]&2047](Q,(c[a+12352+(h<<4)+4>>2]|0)+T|0,ga,ea);aa=O+(ha|8)|0;mf[c[(c[fa>>2]|0)+(E<<4)+(Ta<<2)>>2]&2047](aa,(c[a+12352+(h<<4)+8>>2]|0)+T|0,ga,ea);T=(Xe[j&511](ia,Q,c[a+12288+(g<<4)+4>>2]|0,ga,ea)|0)+Ua|0;Xa=T+(Xe[j&511](ia,aa,c[a+12288+(g<<4)+8>>2]|0,ga,ea)|0)|0}else{ea=c[a+12416>>2]|0;ga=Z<<A;aa=H<<A;ia=a+12352+(h<<4)|0;T=a+12288+(g<<4)|0;if((c[n>>2]|0)>(Z|0)){Xa=536870912;break}if((ga|0)>(c[r>>2]<<A|0)){Xa=536870912;break}if((c[p>>2]|0)>(H|0)){Xa=536870912;break}if((aa|0)>(c[t>>2]<<A|0)){Xa=536870912;break}Ua=e[a+13872>>1]|0;Q=e[a+13874>>1]|0;Ta=z<<1|1;b:do{if((c[a+11740>>2]|0)==1){fa=Q-Ua|0;ha=z|4;O=(aa|0)==0;ma=a+12208|0;la=ea<<3;ka=(z|0)==0;ja=a+12444|0;da=a+12448|0;Oa=a+12352+(h<<4)+32|0;Pa=a+12452|0;ba=a+12456|0;if((ga|0)==0){$=0;while(1){_=c[a+12160+($<<3)>>2]|0;V=(c[a+12160+($<<3)+4>>2]|0)+aa|0;Y=((ca(c[a+12128+($<<3)>>2]|0,fa)|0)/(Ua|0)|0)+(($&1)<<ha)|0;X=c[a+12128+($<<3)+4>>2]|0;if(O){W=$>>1;Ya=((ca(X,fa)|0)/(Ua|0)|0)+(W<<ha)|0;Za=W}else{Ya=V-X|0;Za=$>>1}X=((V&Ta)<<A)+(_&Ta)|0;W=((Ya&Ta)<<A)+(Y&Ta)|0;U=(c[ma>>2]|0)+((ca(Za,la)|0)+($<<3&8))|0;if(ka){R=(c[ia>>2]|0)+((ca(V>>1,ea)|0)+(_>>1))|0;mf[c[(c[ja>>2]|0)+16+(X<<2)>>2]&2047](U,R,ea,8);R=(c[Oa>>2]|0)+((ca(Ya>>1,ea)|0)+(Y>>1))|0;mf[c[(c[da>>2]|0)+16+(W<<2)>>2]&2047](U,R,ea,8)}else{R=(c[ia>>2]|0)+((ca(V>>2,ea)|0)+(_>>2))|0;ef[c[(c[Pa>>2]|0)+64+(X<<2)>>2]&4095](U,R,ea);R=(c[Oa>>2]|0)+((ca(Ya>>2,ea)|0)+(Y>>2))|0;ef[c[(c[ba>>2]|0)+64+(W<<2)>>2]&4095](U,R,ea)}$=$+1|0;if(($|0)>=4){break b}}}if(O){$=0;do{R=(c[a+12160+($<<3)>>2]|0)+ga|0;U=c[a+12160+($<<3)+4>>2]|0;W=R-(c[a+12128+($<<3)>>2]|0)|0;Y=$>>1;X=((ca(c[a+12128+($<<3)+4>>2]|0,fa)|0)/(Ua|0)|0)+(Y<<ha)|0;_=((U&Ta)<<A)+(R&Ta)|0;V=((X&Ta)<<A)+(W&Ta)|0;N=(c[ma>>2]|0)+(($<<3&8)+(ca(Y,la)|0))|0;if(ka){Y=(c[ia>>2]|0)+((ca(U>>1,ea)|0)+(R>>1))|0;mf[c[(c[ja>>2]|0)+16+(_<<2)>>2]&2047](N,Y,ea,8);Y=(c[Oa>>2]|0)+((ca(X>>1,ea)|0)+(W>>1))|0;mf[c[(c[da>>2]|0)+16+(V<<2)>>2]&2047](N,Y,ea,8)}else{Y=(c[ia>>2]|0)+((ca(U>>2,ea)|0)+(R>>2))|0;ef[c[(c[Pa>>2]|0)+64+(_<<2)>>2]&4095](N,Y,ea);Y=(c[Oa>>2]|0)+((ca(X>>2,ea)|0)+(W>>2))|0;ef[c[(c[ba>>2]|0)+64+(V<<2)>>2]&4095](N,Y,ea)}$=$+1|0;}while(($|0)<4)}else{$=0;do{ha=(c[a+12160+($<<3)>>2]|0)+ga|0;fa=(c[a+12160+($<<3)+4>>2]|0)+aa|0;O=ha-(c[a+12128+($<<3)>>2]|0)|0;Y=fa-(c[a+12128+($<<3)+4>>2]|0)|0;N=((fa&Ta)<<A)+(ha&Ta)|0;V=((Y&Ta)<<A)+(O&Ta)|0;W=(c[ma>>2]|0)+(($<<3&8)+(ca($>>1,la)|0))|0;if(ka){X=(c[ia>>2]|0)+((ca(fa>>1,ea)|0)+(ha>>1))|0;mf[c[(c[ja>>2]|0)+16+(N<<2)>>2]&2047](W,X,ea,8);X=(c[Oa>>2]|0)+((ca(Y>>1,ea)|0)+(O>>1))|0;mf[c[(c[da>>2]|0)+16+(V<<2)>>2]&2047](W,X,ea,8)}else{X=(c[ia>>2]|0)+((ca(fa>>2,ea)|0)+(ha>>2))|0;ef[c[(c[Pa>>2]|0)+64+(N<<2)>>2]&4095](W,X,ea);X=(c[Oa>>2]|0)+((ca(Y>>2,ea)|0)+(O>>2))|0;ef[c[(c[ba>>2]|0)+64+(V<<2)>>2]&4095](W,X,ea)}$=$+1|0;}while(($|0)<4)}}else{$=(c[a+12160>>2]|0)+ga|0;ba=(c[a+12164>>2]|0)+aa|0;Oa=c[a+12128>>2]|0;if((ga|0)==0){_a=(ca(Oa,Q-Ua|0)|0)/(Ua|0)|0}else{_a=$-Oa|0}Oa=c[a+12132>>2]|0;if((aa|0)==0){$a=(ca(Oa,Q-Ua|0)|0)/(Ua|0)|0}else{$a=ba-Oa|0}Oa=((ba&Ta)<<A)+($&Ta)|0;Pa=(($a&Ta)<<A)+(_a&Ta)|0;if((z|0)==0){da=a+12208|0;ja=(c[ia>>2]|0)+((ca(ba>>1,ea)|0)+($>>1))|0;mf[c[(c[a+12444>>2]|0)+(Oa<<2)>>2]&2047](c[da>>2]|0,ja,ea,16);ja=(c[a+12352+(h<<4)+32>>2]|0)+((ca($a>>1,ea)|0)+(_a>>1))|0;mf[c[(c[a+12448>>2]|0)+(Pa<<2)>>2]&2047](c[da>>2]|0,ja,ea,16);break}else{ja=a+12452|0;da=a+12208|0;ka=(ca(ba>>2,ea)|0)+($>>2)|0;ef[c[(c[ja>>2]|0)+64+(Oa<<2)>>2]&4095](c[da>>2]|0,(c[ia>>2]|0)+ka|0,ea);$=ka+8|0;ef[c[(c[ja>>2]|0)+64+(Oa<<2)>>2]&4095]((c[da>>2]|0)+8|0,(c[ia>>2]|0)+$|0,ea);ba=ea<<3;ef[c[(c[ja>>2]|0)+64+(Oa<<2)>>2]&4095]((c[da>>2]|0)+ba|0,(c[ia>>2]|0)+(ka+ba)|0,ea);ka=ba+8|0;ef[c[(c[ja>>2]|0)+64+(Oa<<2)>>2]&4095]((c[da>>2]|0)+ka|0,(c[ia>>2]|0)+($+ba)|0,ea);$=a+12456|0;Oa=a+12352+(h<<4)+32|0;ja=(ca($a>>2,ea)|0)+(_a>>2)|0;ef[c[(c[$>>2]|0)+64+(Pa<<2)>>2]&4095](c[da>>2]|0,(c[Oa>>2]|0)+ja|0,ea);la=ja+8|0;ef[c[(c[$>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+8|0,(c[Oa>>2]|0)+la|0,ea);ef[c[(c[$>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+ba|0,(c[Oa>>2]|0)+(ja+ba)|0,ea);ef[c[(c[$>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+ka|0,(c[Oa>>2]|0)+(la+ba)|0,ea);break}}}while(0);Xa=Xe[D&511](a,c[a+12208>>2]|0,c[T>>2]|0,ea,16)|0}}while(0);c[S>>2]=F;c[m+(P<<2)>>2]=Xa;ia=(ca((d[v+((H<<A)-x)|0]|0)+(d[v+((Z<<A)-w)|0]|0)|0,i)|0)+Xa|0;if((ia|0)>=(I|0)){Va=I;Wa=ia;break}c[b>>2]=Z;c[J>>2]=H;Va=ia;Wa=ia}}while(0);I=oa+1|0;Xa=(I|0)>(s|0)?s:I;I=(o|0)>(Xa|0)?o:Xa;Xa=I+B+na|0;P=Fa+I&63;F=y+(P<<2)|0;do{if((c[F>>2]|0)==(Xa|0)){ab=Va;bb=Wa}else{do{if((l&4|0)==0){S=c[a+12416>>2]|0;_a=c[a+12420>>2]|0;$a=a;Ya=(c[a+12352+(h<<4)>>2]|0)+((ca(S,H)|0)+I)|0;Za=Xe[D&511]($a,c[a+12288+(g<<4)>>2]|0,Ya,S,k)|0;if((l&2|0)==0){cb=Za;break}Ya=H<<1&2|I&1;ia=c[a+12208>>2]|0;Ta=S<<4;S=ia+Ta|0;Ua=a+12444|0;Q=(ca(_a,H>>1)|0)+(I>>1)|0;aa=k>>1;mf[c[(c[Ua>>2]|0)+(E<<4)+(Ya<<2)>>2]&2047](S,(c[a+12352+(h<<4)+4>>2]|0)+Q|0,_a,aa);ga=ia+(Ta|8)|0;mf[c[(c[Ua>>2]|0)+(E<<4)+(Ya<<2)>>2]&2047](ga,(c[a+12352+(h<<4)+8>>2]|0)+Q|0,_a,aa);Q=(Xe[j&511]($a,S,c[a+12288+(g<<4)+4>>2]|0,_a,aa)|0)+Za|0;cb=Q+(Xe[j&511]($a,ga,c[a+12288+(g<<4)+8>>2]|0,_a,aa)|0)|0}else{aa=c[a+12416>>2]|0;_a=I<<A;ga=H<<A;$a=a+12352+(h<<4)|0;Q=a+12288+(g<<4)|0;if((c[n>>2]|0)>(I|0)){cb=536870912;break}if((_a|0)>(c[r>>2]<<A|0)){cb=536870912;break}if((c[p>>2]|0)>(H|0)){cb=536870912;break}if((ga|0)>(c[t>>2]<<A|0)){cb=536870912;break}Za=e[a+13872>>1]|0;S=e[a+13874>>1]|0;Ya=z<<1|1;c:do{if((c[a+11740>>2]|0)==1){Ua=S-Za|0;Ta=z|4;ia=(ga|0)==0;ba=a+12208|0;la=aa<<3;Oa=(z|0)==0;ka=a+12444|0;da=a+12448|0;Pa=a+12352+(h<<4)+32|0;$=a+12452|0;ja=a+12456|0;if((_a|0)==0){ma=0;while(1){X=c[a+12160+(ma<<3)>>2]|0;W=(c[a+12160+(ma<<3)+4>>2]|0)+ga|0;V=((ca(c[a+12128+(ma<<3)>>2]|0,Ua)|0)/(Za|0)|0)+((ma&1)<<Ta)|0;O=c[a+12128+(ma<<3)+4>>2]|0;if(ia){Y=ma>>1;db=((ca(O,Ua)|0)/(Za|0)|0)+(Y<<Ta)|0;eb=Y}else{db=W-O|0;eb=ma>>1}O=((W&Ya)<<A)+(X&Ya)|0;Y=((db&Ya)<<A)+(V&Ya)|0;N=(c[ba>>2]|0)+((ca(eb,la)|0)+(ma<<3&8))|0;if(Oa){ha=(c[$a>>2]|0)+((ca(W>>1,aa)|0)+(X>>1))|0;mf[c[(c[ka>>2]|0)+16+(O<<2)>>2]&2047](N,ha,aa,8);ha=(c[Pa>>2]|0)+((ca(db>>1,aa)|0)+(V>>1))|0;mf[c[(c[da>>2]|0)+16+(Y<<2)>>2]&2047](N,ha,aa,8)}else{ha=(c[$a>>2]|0)+((ca(W>>2,aa)|0)+(X>>2))|0;ef[c[(c[$>>2]|0)+64+(O<<2)>>2]&4095](N,ha,aa);ha=(c[Pa>>2]|0)+((ca(db>>2,aa)|0)+(V>>2))|0;ef[c[(c[ja>>2]|0)+64+(Y<<2)>>2]&4095](N,ha,aa)}ma=ma+1|0;if((ma|0)>=4){break c}}}if(ia){ma=0;do{ha=(c[a+12160+(ma<<3)>>2]|0)+_a|0;N=c[a+12160+(ma<<3)+4>>2]|0;Y=ha-(c[a+12128+(ma<<3)>>2]|0)|0;V=ma>>1;O=((ca(c[a+12128+(ma<<3)+4>>2]|0,Ua)|0)/(Za|0)|0)+(V<<Ta)|0;X=((N&Ya)<<A)+(ha&Ya)|0;W=((O&Ya)<<A)+(Y&Ya)|0;fa=(c[ba>>2]|0)+((ma<<3&8)+(ca(V,la)|0))|0;if(Oa){V=(c[$a>>2]|0)+((ca(N>>1,aa)|0)+(ha>>1))|0;mf[c[(c[ka>>2]|0)+16+(X<<2)>>2]&2047](fa,V,aa,8);V=(c[Pa>>2]|0)+((ca(O>>1,aa)|0)+(Y>>1))|0;mf[c[(c[da>>2]|0)+16+(W<<2)>>2]&2047](fa,V,aa,8)}else{V=(c[$a>>2]|0)+((ca(N>>2,aa)|0)+(ha>>2))|0;ef[c[(c[$>>2]|0)+64+(X<<2)>>2]&4095](fa,V,aa);V=(c[Pa>>2]|0)+((ca(O>>2,aa)|0)+(Y>>2))|0;ef[c[(c[ja>>2]|0)+64+(W<<2)>>2]&4095](fa,V,aa)}ma=ma+1|0;}while((ma|0)<4)}else{ma=0;do{Ta=(c[a+12160+(ma<<3)>>2]|0)+_a|0;Ua=(c[a+12160+(ma<<3)+4>>2]|0)+ga|0;ia=Ta-(c[a+12128+(ma<<3)>>2]|0)|0;V=Ua-(c[a+12128+(ma<<3)+4>>2]|0)|0;fa=((Ua&Ya)<<A)+(Ta&Ya)|0;W=((V&Ya)<<A)+(ia&Ya)|0;Y=(c[ba>>2]|0)+((ma<<3&8)+(ca(ma>>1,la)|0))|0;if(Oa){O=(c[$a>>2]|0)+((ca(Ua>>1,aa)|0)+(Ta>>1))|0;mf[c[(c[ka>>2]|0)+16+(fa<<2)>>2]&2047](Y,O,aa,8);O=(c[Pa>>2]|0)+((ca(V>>1,aa)|0)+(ia>>1))|0;mf[c[(c[da>>2]|0)+16+(W<<2)>>2]&2047](Y,O,aa,8)}else{O=(c[$a>>2]|0)+((ca(Ua>>2,aa)|0)+(Ta>>2))|0;ef[c[(c[$>>2]|0)+64+(fa<<2)>>2]&4095](Y,O,aa);O=(c[Pa>>2]|0)+((ca(V>>2,aa)|0)+(ia>>2))|0;ef[c[(c[ja>>2]|0)+64+(W<<2)>>2]&4095](Y,O,aa)}ma=ma+1|0;}while((ma|0)<4)}}else{ma=(c[a+12160>>2]|0)+_a|0;ja=(c[a+12164>>2]|0)+ga|0;Pa=c[a+12128>>2]|0;if((_a|0)==0){fb=(ca(Pa,S-Za|0)|0)/(Za|0)|0}else{fb=ma-Pa|0}Pa=c[a+12132>>2]|0;if((ga|0)==0){gb=(ca(Pa,S-Za|0)|0)/(Za|0)|0}else{gb=ja-Pa|0}Pa=((ja&Ya)<<A)+(ma&Ya)|0;$=((gb&Ya)<<A)+(fb&Ya)|0;if((z|0)==0){da=a+12208|0;ka=(c[$a>>2]|0)+((ca(ja>>1,aa)|0)+(ma>>1))|0;mf[c[(c[a+12444>>2]|0)+(Pa<<2)>>2]&2047](c[da>>2]|0,ka,aa,16);ka=(c[a+12352+(h<<4)+32>>2]|0)+((ca(gb>>1,aa)|0)+(fb>>1))|0;mf[c[(c[a+12448>>2]|0)+($<<2)>>2]&2047](c[da>>2]|0,ka,aa,16);break}else{ka=a+12452|0;da=a+12208|0;Oa=(ca(ja>>2,aa)|0)+(ma>>2)|0;ef[c[(c[ka>>2]|0)+64+(Pa<<2)>>2]&4095](c[da>>2]|0,(c[$a>>2]|0)+Oa|0,aa);ma=Oa+8|0;ef[c[(c[ka>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+8|0,(c[$a>>2]|0)+ma|0,aa);ja=aa<<3;ef[c[(c[ka>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+ja|0,(c[$a>>2]|0)+(Oa+ja)|0,aa);Oa=ja+8|0;ef[c[(c[ka>>2]|0)+64+(Pa<<2)>>2]&4095]((c[da>>2]|0)+Oa|0,(c[$a>>2]|0)+(ma+ja)|0,aa);ma=a+12456|0;Pa=a+12352+(h<<4)+32|0;ka=(ca(gb>>2,aa)|0)+(fb>>2)|0;ef[c[(c[ma>>2]|0)+64+($<<2)>>2]&4095](c[da>>2]|0,(c[Pa>>2]|0)+ka|0,aa);la=ka+8|0;ef[c[(c[ma>>2]|0)+64+($<<2)>>2]&4095]((c[da>>2]|0)+8|0,(c[Pa>>2]|0)+la|0,aa);ef[c[(c[ma>>2]|0)+64+($<<2)>>2]&4095]((c[da>>2]|0)+ja|0,(c[Pa>>2]|0)+(ka+ja)|0,aa);ef[c[(c[ma>>2]|0)+64+($<<2)>>2]&4095]((c[da>>2]|0)+Oa|0,(c[Pa>>2]|0)+(la+ja)|0,aa);break}}}while(0);cb=Xe[D&511](a,c[a+12208>>2]|0,c[Q>>2]|0,aa,16)|0}}while(0);c[F>>2]=Xa;c[m+(P<<2)>>2]=cb;$a=(ca((d[v+((H<<A)-x)|0]|0)+(d[v+((I<<A)-w)|0]|0)|0,i)|0)+cb|0;if(($a|0)>=(Va|0)){ab=Va;bb=$a;break}c[b>>2]=I;c[J>>2]=H;ab=$a;bb=$a}}while(0);I=G+1|0;Va=(I|0)>(u|0)?u:I;I=(q|0)>(Va|0)?q:Va;Va=Aa+(I<<11)|0;cb=(I<<3)+Z&63;P=y+(cb<<2)|0;do{if((c[P>>2]|0)==(Va|0)){hb=ab;ib=bb}else{do{if((l&4|0)==0){Xa=c[a+12416>>2]|0;F=c[a+12420>>2]|0;fb=a;gb=(c[a+12352+(h<<4)>>2]|0)+((ca(Xa,I)|0)+Z)|0;db=Xe[D&511](fb,c[a+12288+(g<<4)>>2]|0,gb,Xa,k)|0;if((l&2|0)==0){jb=db;break}gb=I<<1&2|Z&1;eb=c[a+12208>>2]|0;Wa=Xa<<4;Xa=eb+Wa|0;$a=a+12444|0;Ya=(ca(F,I>>1)|0)+(Z>>1)|0;Za=k>>1;mf[c[(c[$a>>2]|0)+(E<<4)+(gb<<2)>>2]&2047](Xa,(c[a+12352+(h<<4)+4>>2]|0)+Ya|0,F,Za);S=eb+(Wa|8)|0;mf[c[(c[$a>>2]|0)+(E<<4)+(gb<<2)>>2]&2047](S,(c[a+12352+(h<<4)+8>>2]|0)+Ya|0,F,Za);Ya=(Xe[j&511](fb,Xa,c[a+12288+(g<<4)+4>>2]|0,F,Za)|0)+db|0;jb=Ya+(Xe[j&511](fb,S,c[a+12288+(g<<4)+8>>2]|0,F,Za)|0)|0}else{Za=c[a+12416>>2]|0;F=Z<<A;S=I<<A;fb=a+12352+(h<<4)|0;Ya=a+12288+(g<<4)|0;if((c[n>>2]|0)>(Z|0)){jb=536870912;break}if((F|0)>(c[r>>2]<<A|0)){jb=536870912;break}if((c[p>>2]|0)>(I|0)){jb=536870912;break}if((S|0)>(c[t>>2]<<A|0)){jb=536870912;break}db=e[a+13872>>1]|0;Xa=e[a+13874>>1]|0;gb=z<<1|1;d:do{if((c[a+11740>>2]|0)==1){$a=Xa-db|0;Wa=z|4;eb=(S|0)==0;ga=a+12208|0;_a=Za<<3;ea=(z|0)==0;T=a+12444|0;ja=a+12448|0;la=a+12352+(h<<4)+32|0;Pa=a+12452|0;Oa=a+12456|0;if((F|0)==0){da=0;while(1){$=c[a+12160+(da<<3)>>2]|0;ma=(c[a+12160+(da<<3)+4>>2]|0)+S|0;ka=((ca(c[a+12128+(da<<3)>>2]|0,$a)|0)/(db|0)|0)+((da&1)<<Wa)|0;ba=c[a+12128+(da<<3)+4>>2]|0;if(eb){O=da>>1;kb=((ca(ba,$a)|0)/(db|0)|0)+(O<<Wa)|0;lb=O}else{kb=ma-ba|0;lb=da>>1}ba=((ma&gb)<<A)+($&gb)|0;O=((kb&gb)<<A)+(ka&gb)|0;Y=(c[ga>>2]|0)+((ca(lb,_a)|0)+(da<<3&8))|0;if(ea){W=(c[fb>>2]|0)+((ca(ma>>1,Za)|0)+($>>1))|0;mf[c[(c[T>>2]|0)+16+(ba<<2)>>2]&2047](Y,W,Za,8);W=(c[la>>2]|0)+((ca(kb>>1,Za)|0)+(ka>>1))|0;mf[c[(c[ja>>2]|0)+16+(O<<2)>>2]&2047](Y,W,Za,8)}else{W=(c[fb>>2]|0)+((ca(ma>>2,Za)|0)+($>>2))|0;ef[c[(c[Pa>>2]|0)+64+(ba<<2)>>2]&4095](Y,W,Za);W=(c[la>>2]|0)+((ca(kb>>2,Za)|0)+(ka>>2))|0;ef[c[(c[Oa>>2]|0)+64+(O<<2)>>2]&4095](Y,W,Za)}da=da+1|0;if((da|0)>=4){break d}}}if(eb){da=0;do{W=(c[a+12160+(da<<3)>>2]|0)+F|0;Y=c[a+12160+(da<<3)+4>>2]|0;O=W-(c[a+12128+(da<<3)>>2]|0)|0;ka=da>>1;ba=((ca(c[a+12128+(da<<3)+4>>2]|0,$a)|0)/(db|0)|0)+(ka<<Wa)|0;$=((Y&gb)<<A)+(W&gb)|0;ma=((ba&gb)<<A)+(O&gb)|0;ia=(c[ga>>2]|0)+((da<<3&8)+(ca(ka,_a)|0))|0;if(ea){ka=(c[fb>>2]|0)+((ca(Y>>1,Za)|0)+(W>>1))|0;mf[c[(c[T>>2]|0)+16+($<<2)>>2]&2047](ia,ka,Za,8);ka=(c[la>>2]|0)+((ca(ba>>1,Za)|0)+(O>>1))|0;mf[c[(c[ja>>2]|0)+16+(ma<<2)>>2]&2047](ia,ka,Za,8)}else{ka=(c[fb>>2]|0)+((ca(Y>>2,Za)|0)+(W>>2))|0;ef[c[(c[Pa>>2]|0)+64+($<<2)>>2]&4095](ia,ka,Za);ka=(c[la>>2]|0)+((ca(ba>>2,Za)|0)+(O>>2))|0;ef[c[(c[Oa>>2]|0)+64+(ma<<2)>>2]&4095](ia,ka,Za)}da=da+1|0;}while((da|0)<4)}else{da=0;do{Wa=(c[a+12160+(da<<3)>>2]|0)+F|0;$a=(c[a+12160+(da<<3)+4>>2]|0)+S|0;eb=Wa-(c[a+12128+(da<<3)>>2]|0)|0;ka=$a-(c[a+12128+(da<<3)+4>>2]|0)|0;ia=(($a&gb)<<A)+(Wa&gb)|0;ma=((ka&gb)<<A)+(eb&gb)|0;O=(c[ga>>2]|0)+((da<<3&8)+(ca(da>>1,_a)|0))|0;if(ea){ba=(c[fb>>2]|0)+((ca($a>>1,Za)|0)+(Wa>>1))|0;mf[c[(c[T>>2]|0)+16+(ia<<2)>>2]&2047](O,ba,Za,8);ba=(c[la>>2]|0)+((ca(ka>>1,Za)|0)+(eb>>1))|0;mf[c[(c[ja>>2]|0)+16+(ma<<2)>>2]&2047](O,ba,Za,8)}else{ba=(c[fb>>2]|0)+((ca($a>>2,Za)|0)+(Wa>>2))|0;ef[c[(c[Pa>>2]|0)+64+(ia<<2)>>2]&4095](O,ba,Za);ba=(c[la>>2]|0)+((ca(ka>>2,Za)|0)+(eb>>2))|0;ef[c[(c[Oa>>2]|0)+64+(ma<<2)>>2]&4095](O,ba,Za)}da=da+1|0;}while((da|0)<4)}}else{da=(c[a+12160>>2]|0)+F|0;Oa=(c[a+12164>>2]|0)+S|0;la=c[a+12128>>2]|0;if((F|0)==0){mb=(ca(la,Xa-db|0)|0)/(db|0)|0}else{mb=da-la|0}la=c[a+12132>>2]|0;if((S|0)==0){nb=(ca(la,Xa-db|0)|0)/(db|0)|0}else{nb=Oa-la|0}la=((Oa&gb)<<A)+(da&gb)|0;Pa=((nb&gb)<<A)+(mb&gb)|0;if((z|0)==0){ja=a+12208|0;T=(c[fb>>2]|0)+((ca(Oa>>1,Za)|0)+(da>>1))|0;mf[c[(c[a+12444>>2]|0)+(la<<2)>>2]&2047](c[ja>>2]|0,T,Za,16);T=(c[a+12352+(h<<4)+32>>2]|0)+((ca(nb>>1,Za)|0)+(mb>>1))|0;mf[c[(c[a+12448>>2]|0)+(Pa<<2)>>2]&2047](c[ja>>2]|0,T,Za,16);break}else{T=a+12452|0;ja=a+12208|0;ea=(ca(Oa>>2,Za)|0)+(da>>2)|0;ef[c[(c[T>>2]|0)+64+(la<<2)>>2]&4095](c[ja>>2]|0,(c[fb>>2]|0)+ea|0,Za);da=ea+8|0;ef[c[(c[T>>2]|0)+64+(la<<2)>>2]&4095]((c[ja>>2]|0)+8|0,(c[fb>>2]|0)+da|0,Za);Oa=Za<<3;ef[c[(c[T>>2]|0)+64+(la<<2)>>2]&4095]((c[ja>>2]|0)+Oa|0,(c[fb>>2]|0)+(ea+Oa)|0,Za);ea=Oa+8|0;ef[c[(c[T>>2]|0)+64+(la<<2)>>2]&4095]((c[ja>>2]|0)+ea|0,(c[fb>>2]|0)+(da+Oa)|0,Za);da=a+12456|0;la=a+12352+(h<<4)+32|0;T=(ca(nb>>2,Za)|0)+(mb>>2)|0;ef[c[(c[da>>2]|0)+64+(Pa<<2)>>2]&4095](c[ja>>2]|0,(c[la>>2]|0)+T|0,Za);_a=T+8|0;ef[c[(c[da>>2]|0)+64+(Pa<<2)>>2]&4095]((c[ja>>2]|0)+8|0,(c[la>>2]|0)+_a|0,Za);ef[c[(c[da>>2]|0)+64+(Pa<<2)>>2]&4095]((c[ja>>2]|0)+Oa|0,(c[la>>2]|0)+(T+Oa)|0,Za);ef[c[(c[da>>2]|0)+64+(Pa<<2)>>2]&4095]((c[ja>>2]|0)+ea|0,(c[la>>2]|0)+(_a+Oa)|0,Za);break}}}while(0);jb=Xe[D&511](a,c[a+12208>>2]|0,c[Ya>>2]|0,Za,16)|0}}while(0);c[P>>2]=Va;c[m+(cb<<2)>>2]=jb;fb=(ca((d[v+((I<<A)-x)|0]|0)+(d[v+((Z<<A)-w)|0]|0)|0,i)|0)+jb|0;if((fb|0)>=(ab|0)){hb=ab;ib=fb;break}c[b>>2]=Z;c[J>>2]=I;hb=fb;ib=fb}}while(0);I=oa-1|0;ab=(I|0)>(s|0)?s:I;I=(o|0)>(ab|0)?o:ab;ab=I+B+na|0;na=Fa+I&63;Fa=y+(na<<2)|0;do{if((c[Fa>>2]|0)==(ab|0)){ob=hb;pb=ib}else{do{if((l&4|0)==0){B=c[a+12416>>2]|0;o=c[a+12420>>2]|0;s=a;jb=(c[a+12352+(h<<4)>>2]|0)+((ca(B,H)|0)+I)|0;cb=Xe[D&511](s,c[a+12288+(g<<4)>>2]|0,jb,B,k)|0;if((l&2|0)==0){qb=cb;break}jb=H<<1&2|I&1;Va=c[a+12208>>2]|0;P=B<<4;B=Va+P|0;mb=a+12444|0;nb=(ca(o,H>>1)|0)+(I>>1)|0;kb=k>>1;mf[c[(c[mb>>2]|0)+(E<<4)+(jb<<2)>>2]&2047](B,(c[a+12352+(h<<4)+4>>2]|0)+nb|0,o,kb);lb=Va+(P|8)|0;mf[c[(c[mb>>2]|0)+(E<<4)+(jb<<2)>>2]&2047](lb,(c[a+12352+(h<<4)+8>>2]|0)+nb|0,o,kb);nb=(Xe[j&511](s,B,c[a+12288+(g<<4)+4>>2]|0,o,kb)|0)+cb|0;qb=nb+(Xe[j&511](s,lb,c[a+12288+(g<<4)+8>>2]|0,o,kb)|0)|0}else{kb=c[a+12416>>2]|0;o=I<<A;lb=H<<A;s=a+12352+(h<<4)|0;nb=a+12288+(g<<4)|0;if((c[n>>2]|0)>(I|0)){qb=536870912;break}if((o|0)>(c[r>>2]<<A|0)){qb=536870912;break}if((c[p>>2]|0)>(H|0)){qb=536870912;break}if((lb|0)>(c[t>>2]<<A|0)){qb=536870912;break}cb=e[a+13872>>1]|0;B=e[a+13874>>1]|0;jb=z<<1|1;e:do{if((c[a+11740>>2]|0)==1){mb=B-cb|0;P=z|4;Va=(lb|0)==0;bb=a+12208|0;fb=kb<<3;gb=(z|0)==0;db=a+12444|0;Xa=a+12448|0;S=a+12352+(h<<4)+32|0;F=a+12452|0;aa=a+12456|0;if((o|0)==0){Q=0;while(1){Oa=c[a+12160+(Q<<3)>>2]|0;_a=(c[a+12160+(Q<<3)+4>>2]|0)+lb|0;la=((ca(c[a+12128+(Q<<3)>>2]|0,mb)|0)/(cb|0)|0)+((Q&1)<<P)|0;ea=c[a+12128+(Q<<3)+4>>2]|0;if(Va){ja=Q>>1;rb=((ca(ea,mb)|0)/(cb|0)|0)+(ja<<P)|0;sb=ja}else{rb=_a-ea|0;sb=Q>>1}ea=((_a&jb)<<A)+(Oa&jb)|0;ja=((rb&jb)<<A)+(la&jb)|0;Pa=(c[bb>>2]|0)+((ca(sb,fb)|0)+(Q<<3&8))|0;if(gb){da=(c[s>>2]|0)+((ca(_a>>1,kb)|0)+(Oa>>1))|0;mf[c[(c[db>>2]|0)+16+(ea<<2)>>2]&2047](Pa,da,kb,8);da=(c[S>>2]|0)+((ca(rb>>1,kb)|0)+(la>>1))|0;mf[c[(c[Xa>>2]|0)+16+(ja<<2)>>2]&2047](Pa,da,kb,8)}else{da=(c[s>>2]|0)+((ca(_a>>2,kb)|0)+(Oa>>2))|0;ef[c[(c[F>>2]|0)+64+(ea<<2)>>2]&4095](Pa,da,kb);da=(c[S>>2]|0)+((ca(rb>>2,kb)|0)+(la>>2))|0;ef[c[(c[aa>>2]|0)+64+(ja<<2)>>2]&4095](Pa,da,kb)}Q=Q+1|0;if((Q|0)>=4){break e}}}if(Va){Q=0;do{da=(c[a+12160+(Q<<3)>>2]|0)+o|0;Pa=c[a+12160+(Q<<3)+4>>2]|0;ja=da-(c[a+12128+(Q<<3)>>2]|0)|0;la=Q>>1;ea=((ca(c[a+12128+(Q<<3)+4>>2]|0,mb)|0)/(cb|0)|0)+(la<<P)|0;Oa=((Pa&jb)<<A)+(da&jb)|0;_a=((ea&jb)<<A)+(ja&jb)|0;T=(c[bb>>2]|0)+((Q<<3&8)+(ca(la,fb)|0))|0;if(gb){la=(c[s>>2]|0)+((ca(Pa>>1,kb)|0)+(da>>1))|0;mf[c[(c[db>>2]|0)+16+(Oa<<2)>>2]&2047](T,la,kb,8);la=(c[S>>2]|0)+((ca(ea>>1,kb)|0)+(ja>>1))|0;mf[c[(c[Xa>>2]|0)+16+(_a<<2)>>2]&2047](T,la,kb,8)}else{la=(c[s>>2]|0)+((ca(Pa>>2,kb)|0)+(da>>2))|0;ef[c[(c[F>>2]|0)+64+(Oa<<2)>>2]&4095](T,la,kb);la=(c[S>>2]|0)+((ca(ea>>2,kb)|0)+(ja>>2))|0;ef[c[(c[aa>>2]|0)+64+(_a<<2)>>2]&4095](T,la,kb)}Q=Q+1|0;}while((Q|0)<4)}else{Q=0;do{P=(c[a+12160+(Q<<3)>>2]|0)+o|0;mb=(c[a+12160+(Q<<3)+4>>2]|0)+lb|0;Va=P-(c[a+12128+(Q<<3)>>2]|0)|0;la=mb-(c[a+12128+(Q<<3)+4>>2]|0)|0;T=((mb&jb)<<A)+(P&jb)|0;_a=((la&jb)<<A)+(Va&jb)|0;ja=(c[bb>>2]|0)+((Q<<3&8)+(ca(Q>>1,fb)|0))|0;if(gb){ea=(c[s>>2]|0)+((ca(mb>>1,kb)|0)+(P>>1))|0;mf[c[(c[db>>2]|0)+16+(T<<2)>>2]&2047](ja,ea,kb,8);ea=(c[S>>2]|0)+((ca(la>>1,kb)|0)+(Va>>1))|0;mf[c[(c[Xa>>2]|0)+16+(_a<<2)>>2]&2047](ja,ea,kb,8)}else{ea=(c[s>>2]|0)+((ca(mb>>2,kb)|0)+(P>>2))|0;ef[c[(c[F>>2]|0)+64+(T<<2)>>2]&4095](ja,ea,kb);ea=(c[S>>2]|0)+((ca(la>>2,kb)|0)+(Va>>2))|0;ef[c[(c[aa>>2]|0)+64+(_a<<2)>>2]&4095](ja,ea,kb)}Q=Q+1|0;}while((Q|0)<4)}}else{Q=(c[a+12160>>2]|0)+o|0;aa=(c[a+12164>>2]|0)+lb|0;S=c[a+12128>>2]|0;if((o|0)==0){tb=(ca(S,B-cb|0)|0)/(cb|0)|0}else{tb=Q-S|0}S=c[a+12132>>2]|0;if((lb|0)==0){ub=(ca(S,B-cb|0)|0)/(cb|0)|0}else{ub=aa-S|0}S=((aa&jb)<<A)+(Q&jb)|0;F=((ub&jb)<<A)+(tb&jb)|0;if((z|0)==0){Xa=a+12208|0;db=(c[s>>2]|0)+((ca(aa>>1,kb)|0)+(Q>>1))|0;mf[c[(c[a+12444>>2]|0)+(S<<2)>>2]&2047](c[Xa>>2]|0,db,kb,16);db=(c[a+12352+(h<<4)+32>>2]|0)+((ca(ub>>1,kb)|0)+(tb>>1))|0;mf[c[(c[a+12448>>2]|0)+(F<<2)>>2]&2047](c[Xa>>2]|0,db,kb,16);break}else{db=a+12452|0;Xa=a+12208|0;gb=(ca(aa>>2,kb)|0)+(Q>>2)|0;ef[c[(c[db>>2]|0)+64+(S<<2)>>2]&4095](c[Xa>>2]|0,(c[s>>2]|0)+gb|0,kb);Q=gb+8|0;ef[c[(c[db>>2]|0)+64+(S<<2)>>2]&4095]((c[Xa>>2]|0)+8|0,(c[s>>2]|0)+Q|0,kb);aa=kb<<3;ef[c[(c[db>>2]|0)+64+(S<<2)>>2]&4095]((c[Xa>>2]|0)+aa|0,(c[s>>2]|0)+(gb+aa)|0,kb);gb=aa+8|0;ef[c[(c[db>>2]|0)+64+(S<<2)>>2]&4095]((c[Xa>>2]|0)+gb|0,(c[s>>2]|0)+(Q+aa)|0,kb);Q=a+12456|0;S=a+12352+(h<<4)+32|0;db=(ca(ub>>2,kb)|0)+(tb>>2)|0;ef[c[(c[Q>>2]|0)+64+(F<<2)>>2]&4095](c[Xa>>2]|0,(c[S>>2]|0)+db|0,kb);fb=db+8|0;ef[c[(c[Q>>2]|0)+64+(F<<2)>>2]&4095]((c[Xa>>2]|0)+8|0,(c[S>>2]|0)+fb|0,kb);ef[c[(c[Q>>2]|0)+64+(F<<2)>>2]&4095]((c[Xa>>2]|0)+aa|0,(c[S>>2]|0)+(db+aa)|0,kb);ef[c[(c[Q>>2]|0)+64+(F<<2)>>2]&4095]((c[Xa>>2]|0)+gb|0,(c[S>>2]|0)+(fb+aa)|0,kb);break}}}while(0);qb=Xe[D&511](a,c[a+12208>>2]|0,c[nb>>2]|0,kb,16)|0}}while(0);c[Fa>>2]=ab;c[m+(na<<2)>>2]=qb;s=(ca((d[v+((H<<A)-x)|0]|0)+(d[v+((I<<A)-w)|0]|0)|0,i)|0)+qb|0;if((s|0)>=(hb|0)){ob=hb;pb=s;break}c[b>>2]=I;c[J>>2]=H;ob=s;pb=s}}while(0);H=G-1|0;I=(H|0)>(u|0)?u:H;H=(q|0)>(I|0)?q:I;I=Aa+(H<<11)|0;Aa=(H<<3)+Z&63;q=y+(Aa<<2)|0;if((c[q>>2]|0)==(I|0)){vb=pb;c[b>>2]=oa;c[J>>2]=G;return vb|0}do{if((l&4|0)==0){pb=c[a+12416>>2]|0;y=c[a+12420>>2]|0;u=a;hb=(c[a+12352+(h<<4)>>2]|0)+((ca(pb,H)|0)+Z)|0;qb=Xe[D&511](u,c[a+12288+(g<<4)>>2]|0,hb,pb,k)|0;if((l&2|0)==0){wb=qb;break}hb=H<<1&2|Z&1;na=c[a+12208>>2]|0;ab=pb<<4;pb=na+ab|0;Fa=a+12444|0;tb=(ca(y,H>>1)|0)+(Z>>1)|0;ub=k>>1;mf[c[(c[Fa>>2]|0)+(E<<4)+(hb<<2)>>2]&2047](pb,(c[a+12352+(h<<4)+4>>2]|0)+tb|0,y,ub);rb=na+(ab|8)|0;mf[c[(c[Fa>>2]|0)+(E<<4)+(hb<<2)>>2]&2047](rb,(c[a+12352+(h<<4)+8>>2]|0)+tb|0,y,ub);tb=(Xe[j&511](u,pb,c[a+12288+(g<<4)+4>>2]|0,y,ub)|0)+qb|0;wb=tb+(Xe[j&511](u,rb,c[a+12288+(g<<4)+8>>2]|0,y,ub)|0)|0}else{ub=c[a+12416>>2]|0;y=Z<<A;rb=H<<A;u=a+12352+(h<<4)|0;tb=a+12288+(g<<4)|0;if((c[n>>2]|0)>(Z|0)){wb=536870912;break}if((y|0)>(c[r>>2]<<A|0)){wb=536870912;break}if((c[p>>2]|0)>(H|0)){wb=536870912;break}if((rb|0)>(c[t>>2]<<A|0)){wb=536870912;break}qb=e[a+13872>>1]|0;pb=e[a+13874>>1]|0;hb=z<<1|1;f:do{if((c[a+11740>>2]|0)==1){Fa=pb-qb|0;ab=z|4;na=(rb|0)==0;sb=a+12208|0;ib=ub<<3;s=(z|0)==0;jb=a+12444|0;cb=a+12448|0;B=a+12352+(h<<4)+32|0;lb=a+12452|0;o=a+12456|0;if((y|0)==0){Za=0;while(1){Ya=c[a+12160+(Za<<3)>>2]|0;aa=(c[a+12160+(Za<<3)+4>>2]|0)+rb|0;fb=((ca(c[a+12128+(Za<<3)>>2]|0,Fa)|0)/(qb|0)|0)+((Za&1)<<ab)|0;S=c[a+12128+(Za<<3)+4>>2]|0;if(na){gb=Za>>1;xb=((ca(S,Fa)|0)/(qb|0)|0)+(gb<<ab)|0;yb=gb}else{xb=aa-S|0;yb=Za>>1}S=((aa&hb)<<A)+(Ya&hb)|0;gb=((xb&hb)<<A)+(fb&hb)|0;Xa=(c[sb>>2]|0)+((ca(yb,ib)|0)+(Za<<3&8))|0;if(s){F=(c[u>>2]|0)+((ca(aa>>1,ub)|0)+(Ya>>1))|0;mf[c[(c[jb>>2]|0)+16+(S<<2)>>2]&2047](Xa,F,ub,8);F=(c[B>>2]|0)+((ca(xb>>1,ub)|0)+(fb>>1))|0;mf[c[(c[cb>>2]|0)+16+(gb<<2)>>2]&2047](Xa,F,ub,8)}else{F=(c[u>>2]|0)+((ca(aa>>2,ub)|0)+(Ya>>2))|0;ef[c[(c[lb>>2]|0)+64+(S<<2)>>2]&4095](Xa,F,ub);F=(c[B>>2]|0)+((ca(xb>>2,ub)|0)+(fb>>2))|0;ef[c[(c[o>>2]|0)+64+(gb<<2)>>2]&4095](Xa,F,ub)}Za=Za+1|0;if((Za|0)>=4){break f}}}if(na){Za=0;do{kb=(c[a+12160+(Za<<3)>>2]|0)+y|0;nb=c[a+12160+(Za<<3)+4>>2]|0;F=kb-(c[a+12128+(Za<<3)>>2]|0)|0;Xa=Za>>1;gb=((ca(c[a+12128+(Za<<3)+4>>2]|0,Fa)|0)/(qb|0)|0)+(Xa<<ab)|0;fb=((nb&hb)<<A)+(kb&hb)|0;S=((gb&hb)<<A)+(F&hb)|0;Ya=(c[sb>>2]|0)+((Za<<3&8)+(ca(Xa,ib)|0))|0;if(s){Xa=(c[u>>2]|0)+((ca(nb>>1,ub)|0)+(kb>>1))|0;mf[c[(c[jb>>2]|0)+16+(fb<<2)>>2]&2047](Ya,Xa,ub,8);Xa=(c[B>>2]|0)+((ca(gb>>1,ub)|0)+(F>>1))|0;mf[c[(c[cb>>2]|0)+16+(S<<2)>>2]&2047](Ya,Xa,ub,8)}else{Xa=(c[u>>2]|0)+((ca(nb>>2,ub)|0)+(kb>>2))|0;ef[c[(c[lb>>2]|0)+64+(fb<<2)>>2]&4095](Ya,Xa,ub);Xa=(c[B>>2]|0)+((ca(gb>>2,ub)|0)+(F>>2))|0;ef[c[(c[o>>2]|0)+64+(S<<2)>>2]&4095](Ya,Xa,ub)}Za=Za+1|0;}while((Za|0)<4)}else{Za=0;do{ab=(c[a+12160+(Za<<3)>>2]|0)+y|0;Fa=(c[a+12160+(Za<<3)+4>>2]|0)+rb|0;na=ab-(c[a+12128+(Za<<3)>>2]|0)|0;Xa=Fa-(c[a+12128+(Za<<3)+4>>2]|0)|0;Ya=((Fa&hb)<<A)+(ab&hb)|0;S=((Xa&hb)<<A)+(na&hb)|0;F=(c[sb>>2]|0)+((Za<<3&8)+(ca(Za>>1,ib)|0))|0;if(s){gb=(c[u>>2]|0)+((ca(Fa>>1,ub)|0)+(ab>>1))|0;mf[c[(c[jb>>2]|0)+16+(Ya<<2)>>2]&2047](F,gb,ub,8);gb=(c[B>>2]|0)+((ca(Xa>>1,ub)|0)+(na>>1))|0;mf[c[(c[cb>>2]|0)+16+(S<<2)>>2]&2047](F,gb,ub,8)}else{gb=(c[u>>2]|0)+((ca(Fa>>2,ub)|0)+(ab>>2))|0;ef[c[(c[lb>>2]|0)+64+(Ya<<2)>>2]&4095](F,gb,ub);gb=(c[B>>2]|0)+((ca(Xa>>2,ub)|0)+(na>>2))|0;ef[c[(c[o>>2]|0)+64+(S<<2)>>2]&4095](F,gb,ub)}Za=Za+1|0;}while((Za|0)<4)}}else{Za=(c[a+12160>>2]|0)+y|0;o=(c[a+12164>>2]|0)+rb|0;B=c[a+12128>>2]|0;if((y|0)==0){zb=(ca(B,pb-qb|0)|0)/(qb|0)|0}else{zb=Za-B|0}B=c[a+12132>>2]|0;if((rb|0)==0){Ab=(ca(B,pb-qb|0)|0)/(qb|0)|0}else{Ab=o-B|0}B=((o&hb)<<A)+(Za&hb)|0;lb=((Ab&hb)<<A)+(zb&hb)|0;if((z|0)==0){cb=a+12208|0;jb=(c[u>>2]|0)+((ca(o>>1,ub)|0)+(Za>>1))|0;mf[c[(c[a+12444>>2]|0)+(B<<2)>>2]&2047](c[cb>>2]|0,jb,ub,16);jb=(c[a+12352+(h<<4)+32>>2]|0)+((ca(Ab>>1,ub)|0)+(zb>>1))|0;mf[c[(c[a+12448>>2]|0)+(lb<<2)>>2]&2047](c[cb>>2]|0,jb,ub,16);break}else{jb=a+12452|0;cb=a+12208|0;s=(ca(o>>2,ub)|0)+(Za>>2)|0;ef[c[(c[jb>>2]|0)+64+(B<<2)>>2]&4095](c[cb>>2]|0,(c[u>>2]|0)+s|0,ub);Za=s+8|0;ef[c[(c[jb>>2]|0)+64+(B<<2)>>2]&4095]((c[cb>>2]|0)+8|0,(c[u>>2]|0)+Za|0,ub);o=ub<<3;ef[c[(c[jb>>2]|0)+64+(B<<2)>>2]&4095]((c[cb>>2]|0)+o|0,(c[u>>2]|0)+(s+o)|0,ub);s=o+8|0;ef[c[(c[jb>>2]|0)+64+(B<<2)>>2]&4095]((c[cb>>2]|0)+s|0,(c[u>>2]|0)+(Za+o)|0,ub);Za=a+12456|0;B=a+12352+(h<<4)+32|0;jb=(ca(Ab>>2,ub)|0)+(zb>>2)|0;ef[c[(c[Za>>2]|0)+64+(lb<<2)>>2]&4095](c[cb>>2]|0,(c[B>>2]|0)+jb|0,ub);ib=jb+8|0;ef[c[(c[Za>>2]|0)+64+(lb<<2)>>2]&4095]((c[cb>>2]|0)+8|0,(c[B>>2]|0)+ib|0,ub);ef[c[(c[Za>>2]|0)+64+(lb<<2)>>2]&4095]((c[cb>>2]|0)+o|0,(c[B>>2]|0)+(jb+o)|0,ub);ef[c[(c[Za>>2]|0)+64+(lb<<2)>>2]&4095]((c[cb>>2]|0)+s|0,(c[B>>2]|0)+(ib+o)|0,ub);break}}}while(0);wb=Xe[D&511](a,c[a+12208>>2]|0,c[tb>>2]|0,ub,16)|0}}while(0);c[q>>2]=I;c[m+(Aa<<2)>>2]=wb;Aa=(ca((d[v+((H<<A)-x)|0]|0)+(d[v+((Z<<A)-w)|0]|0)|0,i)|0)+wb|0;if((Aa|0)>=(ob|0)){vb=Aa;c[b>>2]=oa;c[J>>2]=G;return vb|0}c[b>>2]=Z;c[J>>2]=H;vb=Aa;c[b>>2]=oa;c[J>>2]=G;return vb|0}function vrb(a,b,f,g,h,i,j,k,l,m){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0;n=c[a+12220>>2]|0;o=a+12264|0;p=c[o>>2]|0;q=a+12272|0;r=c[q>>2]|0;s=a+12268|0;t=c[s>>2]|0;u=a+12276|0;v=c[u>>2]|0;w=c[a+12464>>2]|0;x=c[a+12280>>2]|0;y=c[a+12284>>2]|0;z=c[a+12216>>2]|0;A=l&1;B=A+1|0;C=c[a+12224>>2]|0;D=c[a+10468+(j<<2)>>2]|0;E=j+1|0;j=c[a+10468+(E<<2)>>2]|0;if((m|0)==0){F=f;return F|0}G=b+4|0;H=(l&4|0)==0;I=a+12416|0;J=a+12420|0;K=a+12352+(h<<4)|0;L=a+12288+(g<<4)|0;M=a;N=(l&2|0)==0;l=a+12208|0;O=a+12444|0;P=a+12352+(h<<4)+4|0;Q=k>>1;R=a+12352+(h<<4)+8|0;S=a+12288+(g<<4)+4|0;T=a+12288+(g<<4)+8|0;g=a+13872|0;U=a+13874|0;V=A<<1|1;W=a+11740|0;X=A|4;Y=(A|0)==0;A=a+12448|0;Z=a+12352+(h<<4)+32|0;h=a+12452|0;_=a+12456|0;$=a+12160|0;aa=a+12164|0;ba=a+12128|0;da=a+12132|0;ea=(m-1&m|0)!=0;fa=m;m=f;f=c[b>>2]|0;while(1){ga=fa>>1;ha=(fa|0)>1;ia=-fa>>1;ja=m;ka=f;while(1){la=c[G>>2]|0;ma=ka-fa|0;na=(ma|0)>(t|0)?t:ma;ma=(p|0)>(na|0)?p:na;na=(la|0)>(v|0)?v:la;oa=(r|0)>(na|0)?r:na;na=oa<<11;pa=ma+C+na|0;qa=oa<<3;ra=qa+ma&63;sa=z+(ra<<2)|0;do{if((c[sa>>2]|0)==(pa|0)){ta=ja}else{ua=c[I>>2]|0;do{if(H){va=c[J>>2]|0;wa=(c[K>>2]|0)+((ca(ua,oa)|0)+ma)|0;xa=Xe[D&511](M,c[L>>2]|0,wa,ua,k)|0;if(N){ya=xa;break}wa=oa<<1&2|ma&1;za=c[l>>2]|0;Aa=ua<<4;Ba=za+Aa|0;Ca=(ca(va,oa>>1)|0)+(ma>>1)|0;mf[c[(c[O>>2]|0)+(E<<4)+(wa<<2)>>2]&2047](Ba,(c[P>>2]|0)+Ca|0,va,Q);Da=za+(Aa|8)|0;mf[c[(c[O>>2]|0)+(E<<4)+(wa<<2)>>2]&2047](Da,(c[R>>2]|0)+Ca|0,va,Q);Ca=(Xe[j&511](M,Ba,c[S>>2]|0,va,Q)|0)+xa|0;ya=Ca+(Xe[j&511](M,Da,c[T>>2]|0,va,Q)|0)|0}else{va=ma<<B;Da=oa<<B;if((c[o>>2]|0)>(ma|0)){ya=536870912;break}if((va|0)>(c[s>>2]<<B|0)){ya=536870912;break}if((c[q>>2]|0)>(oa|0)){ya=536870912;break}if((Da|0)>(c[u>>2]<<B|0)){ya=536870912;break}Ca=e[g>>1]|0;xa=e[U>>1]|0;a:do{if((c[W>>2]|0)==1){Ba=xa-Ca|0;wa=(Da|0)==0;Aa=ua<<3;if((va|0)==0){za=0;while(1){Ea=c[a+12160+(za<<3)>>2]|0;Fa=(c[a+12160+(za<<3)+4>>2]|0)+Da|0;Ga=((ca(c[a+12128+(za<<3)>>2]|0,Ba)|0)/(Ca|0)|0)+((za&1)<<X)|0;Ha=c[a+12128+(za<<3)+4>>2]|0;if(wa){Ia=za>>1;Ja=((ca(Ha,Ba)|0)/(Ca|0)|0)+(Ia<<X)|0;Ka=Ia}else{Ja=Fa-Ha|0;Ka=za>>1}Ha=((Fa&V)<<B)+(Ea&V)|0;Ia=((Ja&V)<<B)+(Ga&V)|0;La=(c[l>>2]|0)+((ca(Ka,Aa)|0)+(za<<3&8))|0;if(Y){Ma=(c[K>>2]|0)+((ca(Fa>>1,ua)|0)+(Ea>>1))|0;mf[c[(c[O>>2]|0)+16+(Ha<<2)>>2]&2047](La,Ma,ua,8);Ma=(c[Z>>2]|0)+((ca(Ja>>1,ua)|0)+(Ga>>1))|0;mf[c[(c[A>>2]|0)+16+(Ia<<2)>>2]&2047](La,Ma,ua,8)}else{Ma=(c[K>>2]|0)+((ca(Fa>>2,ua)|0)+(Ea>>2))|0;ef[c[(c[h>>2]|0)+64+(Ha<<2)>>2]&4095](La,Ma,ua);Ma=(c[Z>>2]|0)+((ca(Ja>>2,ua)|0)+(Ga>>2))|0;ef[c[(c[_>>2]|0)+64+(Ia<<2)>>2]&4095](La,Ma,ua)}za=za+1|0;if((za|0)>=4){break a}}}if(wa){za=0;do{Ma=(c[a+12160+(za<<3)>>2]|0)+va|0;La=c[a+12160+(za<<3)+4>>2]|0;Ia=Ma-(c[a+12128+(za<<3)>>2]|0)|0;Ga=za>>1;Ha=((ca(c[a+12128+(za<<3)+4>>2]|0,Ba)|0)/(Ca|0)|0)+(Ga<<X)|0;Ea=((La&V)<<B)+(Ma&V)|0;Fa=((Ha&V)<<B)+(Ia&V)|0;Na=(c[l>>2]|0)+((za<<3&8)+(ca(Ga,Aa)|0))|0;if(Y){Ga=(c[K>>2]|0)+((ca(La>>1,ua)|0)+(Ma>>1))|0;mf[c[(c[O>>2]|0)+16+(Ea<<2)>>2]&2047](Na,Ga,ua,8);Ga=(c[Z>>2]|0)+((ca(Ha>>1,ua)|0)+(Ia>>1))|0;mf[c[(c[A>>2]|0)+16+(Fa<<2)>>2]&2047](Na,Ga,ua,8)}else{Ga=(c[K>>2]|0)+((ca(La>>2,ua)|0)+(Ma>>2))|0;ef[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095](Na,Ga,ua);Ga=(c[Z>>2]|0)+((ca(Ha>>2,ua)|0)+(Ia>>2))|0;ef[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095](Na,Ga,ua)}za=za+1|0;}while((za|0)<4)}else{za=0;do{Ba=(c[a+12160+(za<<3)>>2]|0)+va|0;wa=(c[a+12160+(za<<3)+4>>2]|0)+Da|0;Ga=Ba-(c[a+12128+(za<<3)>>2]|0)|0;Na=wa-(c[a+12128+(za<<3)+4>>2]|0)|0;Fa=((wa&V)<<B)+(Ba&V)|0;Ia=((Na&V)<<B)+(Ga&V)|0;Ha=(c[l>>2]|0)+((za<<3&8)+(ca(za>>1,Aa)|0))|0;if(Y){Ea=(c[K>>2]|0)+((ca(wa>>1,ua)|0)+(Ba>>1))|0;mf[c[(c[O>>2]|0)+16+(Fa<<2)>>2]&2047](Ha,Ea,ua,8);Ea=(c[Z>>2]|0)+((ca(Na>>1,ua)|0)+(Ga>>1))|0;mf[c[(c[A>>2]|0)+16+(Ia<<2)>>2]&2047](Ha,Ea,ua,8)}else{Ea=(c[K>>2]|0)+((ca(wa>>2,ua)|0)+(Ba>>2))|0;ef[c[(c[h>>2]|0)+64+(Fa<<2)>>2]&4095](Ha,Ea,ua);Ea=(c[Z>>2]|0)+((ca(Na>>2,ua)|0)+(Ga>>2))|0;ef[c[(c[_>>2]|0)+64+(Ia<<2)>>2]&4095](Ha,Ea,ua)}za=za+1|0;}while((za|0)<4)}}else{za=(c[$>>2]|0)+va|0;Aa=(c[aa>>2]|0)+Da|0;Ea=c[ba>>2]|0;if((va|0)==0){Oa=(ca(Ea,xa-Ca|0)|0)/(Ca|0)|0}else{Oa=za-Ea|0}Ea=c[da>>2]|0;if((Da|0)==0){Pa=(ca(Ea,xa-Ca|0)|0)/(Ca|0)|0}else{Pa=Aa-Ea|0}Ea=((Aa&V)<<B)+(za&V)|0;Ha=((Pa&V)<<B)+(Oa&V)|0;if(Y){Ia=(c[K>>2]|0)+((ca(Aa>>1,ua)|0)+(za>>1))|0;mf[c[(c[O>>2]|0)+(Ea<<2)>>2]&2047](c[l>>2]|0,Ia,ua,16);Ia=(c[Z>>2]|0)+((ca(Pa>>1,ua)|0)+(Oa>>1))|0;mf[c[(c[A>>2]|0)+(Ha<<2)>>2]&2047](c[l>>2]|0,Ia,ua,16);break}else{Ia=(ca(Aa>>2,ua)|0)+(za>>2)|0;ef[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+Ia|0,ua);za=Ia+8|0;ef[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+za|0,ua);Aa=ua<<3;ef[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[K>>2]|0)+(Ia+Aa)|0,ua);Ia=Aa+8|0;ef[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+Ia|0,(c[K>>2]|0)+(za+Aa)|0,ua);za=(ca(Pa>>2,ua)|0)+(Oa>>2)|0;ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+za|0,ua);Ea=za+8|0;ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+Ea|0,ua);ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[Z>>2]|0)+(za+Aa)|0,ua);ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+Ia|0,(c[Z>>2]|0)+(Ea+Aa)|0,ua);break}}}while(0);ya=Xe[D&511](M,c[l>>2]|0,c[L>>2]|0,ua,16)|0}}while(0);c[sa>>2]=pa;c[n+(ra<<2)>>2]=ya;ua=(ca((d[w+((oa<<B)-y)|0]|0)+(d[w+((ma<<B)-x)|0]|0)|0,i)|0)+ya|0;if((ua|0)>=(ja|0)){ta=ja;break}c[b>>2]=ma;c[G>>2]=oa;ta=ua}}while(0);ma=ka+fa|0;ra=(ma|0)>(t|0)?t:ma;ma=(p|0)>(ra|0)?p:ra;ra=ma+C+na|0;pa=qa+ma&63;sa=z+(pa<<2)|0;do{if((c[sa>>2]|0)==(ra|0)){Qa=ta}else{ua=c[I>>2]|0;do{if(H){Ca=c[J>>2]|0;xa=(c[K>>2]|0)+((ca(ua,oa)|0)+ma)|0;Da=Xe[D&511](M,c[L>>2]|0,xa,ua,k)|0;if(N){Ra=Da;break}xa=oa<<1&2|ma&1;va=c[l>>2]|0;Aa=ua<<4;Ea=va+Aa|0;Ia=(ca(Ca,oa>>1)|0)+(ma>>1)|0;mf[c[(c[O>>2]|0)+(E<<4)+(xa<<2)>>2]&2047](Ea,(c[P>>2]|0)+Ia|0,Ca,Q);Ha=va+(Aa|8)|0;mf[c[(c[O>>2]|0)+(E<<4)+(xa<<2)>>2]&2047](Ha,(c[R>>2]|0)+Ia|0,Ca,Q);Ia=(Xe[j&511](M,Ea,c[S>>2]|0,Ca,Q)|0)+Da|0;Ra=Ia+(Xe[j&511](M,Ha,c[T>>2]|0,Ca,Q)|0)|0}else{Ca=ma<<B;Ha=oa<<B;if((c[o>>2]|0)>(ma|0)){Ra=536870912;break}if((Ca|0)>(c[s>>2]<<B|0)){Ra=536870912;break}if((c[q>>2]|0)>(oa|0)){Ra=536870912;break}if((Ha|0)>(c[u>>2]<<B|0)){Ra=536870912;break}Ia=e[g>>1]|0;Da=e[U>>1]|0;b:do{if((c[W>>2]|0)==1){Ea=Da-Ia|0;xa=(Ha|0)==0;Aa=ua<<3;if((Ca|0)==0){va=0;while(1){za=c[a+12160+(va<<3)>>2]|0;Ga=(c[a+12160+(va<<3)+4>>2]|0)+Ha|0;Na=((ca(c[a+12128+(va<<3)>>2]|0,Ea)|0)/(Ia|0)|0)+((va&1)<<X)|0;Fa=c[a+12128+(va<<3)+4>>2]|0;if(xa){Ba=va>>1;Sa=((ca(Fa,Ea)|0)/(Ia|0)|0)+(Ba<<X)|0;Ta=Ba}else{Sa=Ga-Fa|0;Ta=va>>1}Fa=((Ga&V)<<B)+(za&V)|0;Ba=((Sa&V)<<B)+(Na&V)|0;wa=(c[l>>2]|0)+((ca(Ta,Aa)|0)+(va<<3&8))|0;if(Y){Ma=(c[K>>2]|0)+((ca(Ga>>1,ua)|0)+(za>>1))|0;mf[c[(c[O>>2]|0)+16+(Fa<<2)>>2]&2047](wa,Ma,ua,8);Ma=(c[Z>>2]|0)+((ca(Sa>>1,ua)|0)+(Na>>1))|0;mf[c[(c[A>>2]|0)+16+(Ba<<2)>>2]&2047](wa,Ma,ua,8)}else{Ma=(c[K>>2]|0)+((ca(Ga>>2,ua)|0)+(za>>2))|0;ef[c[(c[h>>2]|0)+64+(Fa<<2)>>2]&4095](wa,Ma,ua);Ma=(c[Z>>2]|0)+((ca(Sa>>2,ua)|0)+(Na>>2))|0;ef[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095](wa,Ma,ua)}va=va+1|0;if((va|0)>=4){break b}}}if(xa){va=0;do{Ma=(c[a+12160+(va<<3)>>2]|0)+Ca|0;wa=c[a+12160+(va<<3)+4>>2]|0;Ba=Ma-(c[a+12128+(va<<3)>>2]|0)|0;Na=va>>1;Fa=((ca(c[a+12128+(va<<3)+4>>2]|0,Ea)|0)/(Ia|0)|0)+(Na<<X)|0;za=((wa&V)<<B)+(Ma&V)|0;Ga=((Fa&V)<<B)+(Ba&V)|0;La=(c[l>>2]|0)+((va<<3&8)+(ca(Na,Aa)|0))|0;if(Y){Na=(c[K>>2]|0)+((ca(wa>>1,ua)|0)+(Ma>>1))|0;mf[c[(c[O>>2]|0)+16+(za<<2)>>2]&2047](La,Na,ua,8);Na=(c[Z>>2]|0)+((ca(Fa>>1,ua)|0)+(Ba>>1))|0;mf[c[(c[A>>2]|0)+16+(Ga<<2)>>2]&2047](La,Na,ua,8)}else{Na=(c[K>>2]|0)+((ca(wa>>2,ua)|0)+(Ma>>2))|0;ef[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095](La,Na,ua);Na=(c[Z>>2]|0)+((ca(Fa>>2,ua)|0)+(Ba>>2))|0;ef[c[(c[_>>2]|0)+64+(Ga<<2)>>2]&4095](La,Na,ua)}va=va+1|0;}while((va|0)<4)}else{va=0;do{Ea=(c[a+12160+(va<<3)>>2]|0)+Ca|0;xa=(c[a+12160+(va<<3)+4>>2]|0)+Ha|0;Na=Ea-(c[a+12128+(va<<3)>>2]|0)|0;La=xa-(c[a+12128+(va<<3)+4>>2]|0)|0;Ga=((xa&V)<<B)+(Ea&V)|0;Ba=((La&V)<<B)+(Na&V)|0;Fa=(c[l>>2]|0)+((va<<3&8)+(ca(va>>1,Aa)|0))|0;if(Y){za=(c[K>>2]|0)+((ca(xa>>1,ua)|0)+(Ea>>1))|0;mf[c[(c[O>>2]|0)+16+(Ga<<2)>>2]&2047](Fa,za,ua,8);za=(c[Z>>2]|0)+((ca(La>>1,ua)|0)+(Na>>1))|0;mf[c[(c[A>>2]|0)+16+(Ba<<2)>>2]&2047](Fa,za,ua,8)}else{za=(c[K>>2]|0)+((ca(xa>>2,ua)|0)+(Ea>>2))|0;ef[c[(c[h>>2]|0)+64+(Ga<<2)>>2]&4095](Fa,za,ua);za=(c[Z>>2]|0)+((ca(La>>2,ua)|0)+(Na>>2))|0;ef[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095](Fa,za,ua)}va=va+1|0;}while((va|0)<4)}}else{va=(c[$>>2]|0)+Ca|0;Aa=(c[aa>>2]|0)+Ha|0;za=c[ba>>2]|0;if((Ca|0)==0){Ua=(ca(za,Da-Ia|0)|0)/(Ia|0)|0}else{Ua=va-za|0}za=c[da>>2]|0;if((Ha|0)==0){Va=(ca(za,Da-Ia|0)|0)/(Ia|0)|0}else{Va=Aa-za|0}za=((Aa&V)<<B)+(va&V)|0;Fa=((Va&V)<<B)+(Ua&V)|0;if(Y){Ba=(c[K>>2]|0)+((ca(Aa>>1,ua)|0)+(va>>1))|0;mf[c[(c[O>>2]|0)+(za<<2)>>2]&2047](c[l>>2]|0,Ba,ua,16);Ba=(c[Z>>2]|0)+((ca(Va>>1,ua)|0)+(Ua>>1))|0;mf[c[(c[A>>2]|0)+(Fa<<2)>>2]&2047](c[l>>2]|0,Ba,ua,16);break}else{Ba=(ca(Aa>>2,ua)|0)+(va>>2)|0;ef[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+Ba|0,ua);va=Ba+8|0;ef[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+va|0,ua);Aa=ua<<3;ef[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[K>>2]|0)+(Ba+Aa)|0,ua);Ba=Aa+8|0;ef[c[(c[h>>2]|0)+64+(za<<2)>>2]&4095]((c[l>>2]|0)+Ba|0,(c[K>>2]|0)+(va+Aa)|0,ua);va=(ca(Va>>2,ua)|0)+(Ua>>2)|0;ef[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+va|0,ua);za=va+8|0;ef[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+za|0,ua);ef[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[Z>>2]|0)+(va+Aa)|0,ua);ef[c[(c[_>>2]|0)+64+(Fa<<2)>>2]&4095]((c[l>>2]|0)+Ba|0,(c[Z>>2]|0)+(za+Aa)|0,ua);break}}}while(0);Ra=Xe[D&511](M,c[l>>2]|0,c[L>>2]|0,ua,16)|0}}while(0);c[sa>>2]=ra;c[n+(pa<<2)>>2]=Ra;ua=(ca((d[w+((oa<<B)-y)|0]|0)+(d[w+((ma<<B)-x)|0]|0)|0,i)|0)+Ra|0;if((ua|0)>=(ta|0)){Qa=ta;break}c[b>>2]=ma;c[G>>2]=oa;Qa=ua}}while(0);oa=ka+ga|0;ma=la+fa|0;pa=(oa|0)>(t|0)?t:oa;oa=(p|0)>(pa|0)?p:pa;pa=(ma|0)>(v|0)?v:ma;ma=(r|0)>(pa|0)?r:pa;pa=ma<<11;ra=oa+C|0;sa=ra+pa|0;qa=ma<<3;na=qa+oa&63;ua=z+(na<<2)|0;do{if((c[ua>>2]|0)==(sa|0)){Wa=Qa}else{Ia=c[I>>2]|0;do{if(H){Da=c[J>>2]|0;Ha=(c[K>>2]|0)+((ca(Ia,ma)|0)+oa)|0;Ca=Xe[D&511](M,c[L>>2]|0,Ha,Ia,k)|0;if(N){Xa=Ca;break}Ha=ma<<1&2|oa&1;Aa=c[l>>2]|0;za=Ia<<4;Ba=Aa+za|0;Fa=(ca(Da,ma>>1)|0)+(oa>>1)|0;mf[c[(c[O>>2]|0)+(E<<4)+(Ha<<2)>>2]&2047](Ba,(c[P>>2]|0)+Fa|0,Da,Q);va=Aa+(za|8)|0;mf[c[(c[O>>2]|0)+(E<<4)+(Ha<<2)>>2]&2047](va,(c[R>>2]|0)+Fa|0,Da,Q);Fa=(Xe[j&511](M,Ba,c[S>>2]|0,Da,Q)|0)+Ca|0;Xa=Fa+(Xe[j&511](M,va,c[T>>2]|0,Da,Q)|0)|0}else{Da=oa<<B;va=ma<<B;if((c[o>>2]|0)>(oa|0)){Xa=536870912;break}if((Da|0)>(c[s>>2]<<B|0)){Xa=536870912;break}if((c[q>>2]|0)>(ma|0)){Xa=536870912;break}if((va|0)>(c[u>>2]<<B|0)){Xa=536870912;break}Fa=e[g>>1]|0;Ca=e[U>>1]|0;c:do{if((c[W>>2]|0)==1){Ba=Ca-Fa|0;Ha=(va|0)==0;za=Ia<<3;if((Da|0)==0){Aa=0;while(1){Na=c[a+12160+(Aa<<3)>>2]|0;La=(c[a+12160+(Aa<<3)+4>>2]|0)+va|0;Ga=((ca(c[a+12128+(Aa<<3)>>2]|0,Ba)|0)/(Fa|0)|0)+((Aa&1)<<X)|0;Ea=c[a+12128+(Aa<<3)+4>>2]|0;if(Ha){xa=Aa>>1;Ya=((ca(Ea,Ba)|0)/(Fa|0)|0)+(xa<<X)|0;Za=xa}else{Ya=La-Ea|0;Za=Aa>>1}Ea=((La&V)<<B)+(Na&V)|0;xa=((Ya&V)<<B)+(Ga&V)|0;Ma=(c[l>>2]|0)+((ca(Za,za)|0)+(Aa<<3&8))|0;if(Y){wa=(c[K>>2]|0)+((ca(La>>1,Ia)|0)+(Na>>1))|0;mf[c[(c[O>>2]|0)+16+(Ea<<2)>>2]&2047](Ma,wa,Ia,8);wa=(c[Z>>2]|0)+((ca(Ya>>1,Ia)|0)+(Ga>>1))|0;mf[c[(c[A>>2]|0)+16+(xa<<2)>>2]&2047](Ma,wa,Ia,8)}else{wa=(c[K>>2]|0)+((ca(La>>2,Ia)|0)+(Na>>2))|0;ef[c[(c[h>>2]|0)+64+(Ea<<2)>>2]&4095](Ma,wa,Ia);wa=(c[Z>>2]|0)+((ca(Ya>>2,Ia)|0)+(Ga>>2))|0;ef[c[(c[_>>2]|0)+64+(xa<<2)>>2]&4095](Ma,wa,Ia)}Aa=Aa+1|0;if((Aa|0)>=4){break c}}}if(Ha){Aa=0;do{wa=(c[a+12160+(Aa<<3)>>2]|0)+Da|0;Ma=c[a+12160+(Aa<<3)+4>>2]|0;xa=wa-(c[a+12128+(Aa<<3)>>2]|0)|0;Ga=Aa>>1;Ea=((ca(c[a+12128+(Aa<<3)+4>>2]|0,Ba)|0)/(Fa|0)|0)+(Ga<<X)|0;Na=((Ma&V)<<B)+(wa&V)|0;La=((Ea&V)<<B)+(xa&V)|0;_a=(c[l>>2]|0)+((Aa<<3&8)+(ca(Ga,za)|0))|0;if(Y){Ga=(c[K>>2]|0)+((ca(Ma>>1,Ia)|0)+(wa>>1))|0;mf[c[(c[O>>2]|0)+16+(Na<<2)>>2]&2047](_a,Ga,Ia,8);Ga=(c[Z>>2]|0)+((ca(Ea>>1,Ia)|0)+(xa>>1))|0;mf[c[(c[A>>2]|0)+16+(La<<2)>>2]&2047](_a,Ga,Ia,8)}else{Ga=(c[K>>2]|0)+((ca(Ma>>2,Ia)|0)+(wa>>2))|0;ef[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095](_a,Ga,Ia);Ga=(c[Z>>2]|0)+((ca(Ea>>2,Ia)|0)+(xa>>2))|0;ef[c[(c[_>>2]|0)+64+(La<<2)>>2]&4095](_a,Ga,Ia)}Aa=Aa+1|0;}while((Aa|0)<4)}else{Aa=0;do{Ba=(c[a+12160+(Aa<<3)>>2]|0)+Da|0;Ha=(c[a+12160+(Aa<<3)+4>>2]|0)+va|0;Ga=Ba-(c[a+12128+(Aa<<3)>>2]|0)|0;_a=Ha-(c[a+12128+(Aa<<3)+4>>2]|0)|0;La=((Ha&V)<<B)+(Ba&V)|0;xa=((_a&V)<<B)+(Ga&V)|0;Ea=(c[l>>2]|0)+((Aa<<3&8)+(ca(Aa>>1,za)|0))|0;if(Y){Na=(c[K>>2]|0)+((ca(Ha>>1,Ia)|0)+(Ba>>1))|0;mf[c[(c[O>>2]|0)+16+(La<<2)>>2]&2047](Ea,Na,Ia,8);Na=(c[Z>>2]|0)+((ca(_a>>1,Ia)|0)+(Ga>>1))|0;mf[c[(c[A>>2]|0)+16+(xa<<2)>>2]&2047](Ea,Na,Ia,8)}else{Na=(c[K>>2]|0)+((ca(Ha>>2,Ia)|0)+(Ba>>2))|0;ef[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095](Ea,Na,Ia);Na=(c[Z>>2]|0)+((ca(_a>>2,Ia)|0)+(Ga>>2))|0;ef[c[(c[_>>2]|0)+64+(xa<<2)>>2]&4095](Ea,Na,Ia)}Aa=Aa+1|0;}while((Aa|0)<4)}}else{Aa=(c[$>>2]|0)+Da|0;za=(c[aa>>2]|0)+va|0;Na=c[ba>>2]|0;if((Da|0)==0){$a=(ca(Na,Ca-Fa|0)|0)/(Fa|0)|0}else{$a=Aa-Na|0}Na=c[da>>2]|0;if((va|0)==0){ab=(ca(Na,Ca-Fa|0)|0)/(Fa|0)|0}else{ab=za-Na|0}Na=((za&V)<<B)+(Aa&V)|0;Ea=((ab&V)<<B)+($a&V)|0;if(Y){xa=(c[K>>2]|0)+((ca(za>>1,Ia)|0)+(Aa>>1))|0;mf[c[(c[O>>2]|0)+(Na<<2)>>2]&2047](c[l>>2]|0,xa,Ia,16);xa=(c[Z>>2]|0)+((ca(ab>>1,Ia)|0)+($a>>1))|0;mf[c[(c[A>>2]|0)+(Ea<<2)>>2]&2047](c[l>>2]|0,xa,Ia,16);break}else{xa=(ca(za>>2,Ia)|0)+(Aa>>2)|0;ef[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+xa|0,Ia);Aa=xa+8|0;ef[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+Aa|0,Ia);za=Ia<<3;ef[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095]((c[l>>2]|0)+za|0,(c[K>>2]|0)+(xa+za)|0,Ia);xa=za+8|0;ef[c[(c[h>>2]|0)+64+(Na<<2)>>2]&4095]((c[l>>2]|0)+xa|0,(c[K>>2]|0)+(Aa+za)|0,Ia);Aa=(ca(ab>>2,Ia)|0)+($a>>2)|0;ef[c[(c[_>>2]|0)+64+(Ea<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+Aa|0,Ia);Na=Aa+8|0;ef[c[(c[_>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+Na|0,Ia);ef[c[(c[_>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+za|0,(c[Z>>2]|0)+(Aa+za)|0,Ia);ef[c[(c[_>>2]|0)+64+(Ea<<2)>>2]&4095]((c[l>>2]|0)+xa|0,(c[Z>>2]|0)+(Na+za)|0,Ia);break}}}while(0);Xa=Xe[D&511](M,c[l>>2]|0,c[L>>2]|0,Ia,16)|0}}while(0);c[ua>>2]=sa;c[n+(na<<2)>>2]=Xa;Ia=(ca((d[w+((ma<<B)-y)|0]|0)+(d[w+((oa<<B)-x)|0]|0)|0,i)|0)+Xa|0;if((Ia|0)>=(Qa|0)){Wa=Qa;break}c[b>>2]=oa;c[G>>2]=ma;Wa=Ia}}while(0);na=la-fa|0;sa=(na|0)>(v|0)?v:na;na=(r|0)>(sa|0)?r:sa;sa=na<<11;ua=ra+sa|0;Ia=na<<3;Fa=Ia+oa&63;Ca=z+(Fa<<2)|0;do{if((c[Ca>>2]|0)==(ua|0)){bb=Wa}else{va=c[I>>2]|0;do{if(H){Da=c[J>>2]|0;za=(c[K>>2]|0)+((ca(va,na)|0)+oa)|0;Na=Xe[D&511](M,c[L>>2]|0,za,va,k)|0;if(N){cb=Na;break}za=na<<1&2|oa&1;xa=c[l>>2]|0;Ea=va<<4;Aa=xa+Ea|0;Ga=(ca(Da,na>>1)|0)+(oa>>1)|0;mf[c[(c[O>>2]|0)+(E<<4)+(za<<2)>>2]&2047](Aa,(c[P>>2]|0)+Ga|0,Da,Q);_a=xa+(Ea|8)|0;mf[c[(c[O>>2]|0)+(E<<4)+(za<<2)>>2]&2047](_a,(c[R>>2]|0)+Ga|0,Da,Q);Ga=(Xe[j&511](M,Aa,c[S>>2]|0,Da,Q)|0)+Na|0;cb=Ga+(Xe[j&511](M,_a,c[T>>2]|0,Da,Q)|0)|0}else{Da=oa<<B;_a=na<<B;if((c[o>>2]|0)>(oa|0)){cb=536870912;break}if((Da|0)>(c[s>>2]<<B|0)){cb=536870912;break}if((c[q>>2]|0)>(na|0)){cb=536870912;break}if((_a|0)>(c[u>>2]<<B|0)){cb=536870912;break}Ga=e[g>>1]|0;Na=e[U>>1]|0;d:do{if((c[W>>2]|0)==1){Aa=Na-Ga|0;za=(_a|0)==0;Ea=va<<3;if((Da|0)==0){xa=0;while(1){La=c[a+12160+(xa<<3)>>2]|0;Ba=(c[a+12160+(xa<<3)+4>>2]|0)+_a|0;Ha=((ca(c[a+12128+(xa<<3)>>2]|0,Aa)|0)/(Ga|0)|0)+((xa&1)<<X)|0;wa=c[a+12128+(xa<<3)+4>>2]|0;if(za){Ma=xa>>1;db=((ca(wa,Aa)|0)/(Ga|0)|0)+(Ma<<X)|0;eb=Ma}else{db=Ba-wa|0;eb=xa>>1}wa=((Ba&V)<<B)+(La&V)|0;Ma=((db&V)<<B)+(Ha&V)|0;fb=(c[l>>2]|0)+((ca(eb,Ea)|0)+(xa<<3&8))|0;if(Y){gb=(c[K>>2]|0)+((ca(Ba>>1,va)|0)+(La>>1))|0;mf[c[(c[O>>2]|0)+16+(wa<<2)>>2]&2047](fb,gb,va,8);gb=(c[Z>>2]|0)+((ca(db>>1,va)|0)+(Ha>>1))|0;mf[c[(c[A>>2]|0)+16+(Ma<<2)>>2]&2047](fb,gb,va,8)}else{gb=(c[K>>2]|0)+((ca(Ba>>2,va)|0)+(La>>2))|0;ef[c[(c[h>>2]|0)+64+(wa<<2)>>2]&4095](fb,gb,va);gb=(c[Z>>2]|0)+((ca(db>>2,va)|0)+(Ha>>2))|0;ef[c[(c[_>>2]|0)+64+(Ma<<2)>>2]&4095](fb,gb,va)}xa=xa+1|0;if((xa|0)>=4){break d}}}if(za){xa=0;do{gb=(c[a+12160+(xa<<3)>>2]|0)+Da|0;fb=c[a+12160+(xa<<3)+4>>2]|0;Ma=gb-(c[a+12128+(xa<<3)>>2]|0)|0;Ha=xa>>1;wa=((ca(c[a+12128+(xa<<3)+4>>2]|0,Aa)|0)/(Ga|0)|0)+(Ha<<X)|0;La=((fb&V)<<B)+(gb&V)|0;Ba=((wa&V)<<B)+(Ma&V)|0;hb=(c[l>>2]|0)+((xa<<3&8)+(ca(Ha,Ea)|0))|0;if(Y){Ha=(c[K>>2]|0)+((ca(fb>>1,va)|0)+(gb>>1))|0;mf[c[(c[O>>2]|0)+16+(La<<2)>>2]&2047](hb,Ha,va,8);Ha=(c[Z>>2]|0)+((ca(wa>>1,va)|0)+(Ma>>1))|0;mf[c[(c[A>>2]|0)+16+(Ba<<2)>>2]&2047](hb,Ha,va,8)}else{Ha=(c[K>>2]|0)+((ca(fb>>2,va)|0)+(gb>>2))|0;ef[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095](hb,Ha,va);Ha=(c[Z>>2]|0)+((ca(wa>>2,va)|0)+(Ma>>2))|0;ef[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095](hb,Ha,va)}xa=xa+1|0;}while((xa|0)<4)}else{xa=0;do{Aa=(c[a+12160+(xa<<3)>>2]|0)+Da|0;za=(c[a+12160+(xa<<3)+4>>2]|0)+_a|0;Ha=Aa-(c[a+12128+(xa<<3)>>2]|0)|0;hb=za-(c[a+12128+(xa<<3)+4>>2]|0)|0;Ba=((za&V)<<B)+(Aa&V)|0;Ma=((hb&V)<<B)+(Ha&V)|0;wa=(c[l>>2]|0)+((xa<<3&8)+(ca(xa>>1,Ea)|0))|0;if(Y){La=(c[K>>2]|0)+((ca(za>>1,va)|0)+(Aa>>1))|0;mf[c[(c[O>>2]|0)+16+(Ba<<2)>>2]&2047](wa,La,va,8);La=(c[Z>>2]|0)+((ca(hb>>1,va)|0)+(Ha>>1))|0;mf[c[(c[A>>2]|0)+16+(Ma<<2)>>2]&2047](wa,La,va,8)}else{La=(c[K>>2]|0)+((ca(za>>2,va)|0)+(Aa>>2))|0;ef[c[(c[h>>2]|0)+64+(Ba<<2)>>2]&4095](wa,La,va);La=(c[Z>>2]|0)+((ca(hb>>2,va)|0)+(Ha>>2))|0;ef[c[(c[_>>2]|0)+64+(Ma<<2)>>2]&4095](wa,La,va)}xa=xa+1|0;}while((xa|0)<4)}}else{xa=(c[$>>2]|0)+Da|0;Ea=(c[aa>>2]|0)+_a|0;La=c[ba>>2]|0;if((Da|0)==0){ib=(ca(La,Na-Ga|0)|0)/(Ga|0)|0}else{ib=xa-La|0}La=c[da>>2]|0;if((_a|0)==0){jb=(ca(La,Na-Ga|0)|0)/(Ga|0)|0}else{jb=Ea-La|0}La=((Ea&V)<<B)+(xa&V)|0;wa=((jb&V)<<B)+(ib&V)|0;if(Y){Ma=(c[K>>2]|0)+((ca(Ea>>1,va)|0)+(xa>>1))|0;mf[c[(c[O>>2]|0)+(La<<2)>>2]&2047](c[l>>2]|0,Ma,va,16);Ma=(c[Z>>2]|0)+((ca(jb>>1,va)|0)+(ib>>1))|0;mf[c[(c[A>>2]|0)+(wa<<2)>>2]&2047](c[l>>2]|0,Ma,va,16);break}else{Ma=(ca(Ea>>2,va)|0)+(xa>>2)|0;ef[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+Ma|0,va);xa=Ma+8|0;ef[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+xa|0,va);Ea=va<<3;ef[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[K>>2]|0)+(Ma+Ea)|0,va);Ma=Ea+8|0;ef[c[(c[h>>2]|0)+64+(La<<2)>>2]&4095]((c[l>>2]|0)+Ma|0,(c[K>>2]|0)+(xa+Ea)|0,va);xa=(ca(jb>>2,va)|0)+(ib>>2)|0;ef[c[(c[_>>2]|0)+64+(wa<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+xa|0,va);La=xa+8|0;ef[c[(c[_>>2]|0)+64+(wa<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+La|0,va);ef[c[(c[_>>2]|0)+64+(wa<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[Z>>2]|0)+(xa+Ea)|0,va);ef[c[(c[_>>2]|0)+64+(wa<<2)>>2]&4095]((c[l>>2]|0)+Ma|0,(c[Z>>2]|0)+(La+Ea)|0,va);break}}}while(0);cb=Xe[D&511](M,c[l>>2]|0,c[L>>2]|0,va,16)|0}}while(0);c[Ca>>2]=ua;c[n+(Fa<<2)>>2]=cb;va=(ca((d[w+((na<<B)-y)|0]|0)+(d[w+((oa<<B)-x)|0]|0)|0,i)|0)+cb|0;if((va|0)>=(Wa|0)){bb=Wa;break}c[b>>2]=oa;c[G>>2]=na;bb=va}}while(0);do{if(ha){oa=ka+ia|0;Fa=(oa|0)>(t|0)?t:oa;oa=(p|0)>(Fa|0)?p:Fa;Fa=oa+C|0;ua=Fa+pa|0;Ca=qa+oa&63;ra=z+(Ca<<2)|0;do{if((c[ra>>2]|0)==(ua|0)){kb=bb}else{va=c[I>>2]|0;do{if(H){Ga=c[J>>2]|0;Na=(c[K>>2]|0)+((ca(va,ma)|0)+oa)|0;_a=Xe[D&511](M,c[L>>2]|0,Na,va,k)|0;if(N){lb=_a;break}Na=ma<<1&2|oa&1;Da=c[l>>2]|0;Ea=va<<4;La=Da+Ea|0;Ma=(ca(Ga,ma>>1)|0)+(oa>>1)|0;mf[c[(c[O>>2]|0)+(E<<4)+(Na<<2)>>2]&2047](La,(c[P>>2]|0)+Ma|0,Ga,Q);wa=Da+(Ea|8)|0;mf[c[(c[O>>2]|0)+(E<<4)+(Na<<2)>>2]&2047](wa,(c[R>>2]|0)+Ma|0,Ga,Q);Ma=(Xe[j&511](M,La,c[S>>2]|0,Ga,Q)|0)+_a|0;lb=Ma+(Xe[j&511](M,wa,c[T>>2]|0,Ga,Q)|0)|0}else{Ga=oa<<B;wa=ma<<B;if((c[o>>2]|0)>(oa|0)){lb=536870912;break}if((Ga|0)>(c[s>>2]<<B|0)){lb=536870912;break}if((c[q>>2]|0)>(ma|0)){lb=536870912;break}if((wa|0)>(c[u>>2]<<B|0)){lb=536870912;break}Ma=e[g>>1]|0;_a=e[U>>1]|0;e:do{if((c[W>>2]|0)==1){La=_a-Ma|0;Na=(wa|0)==0;Ea=va<<3;if((Ga|0)==0){Da=0;while(1){xa=c[a+12160+(Da<<3)>>2]|0;Ha=(c[a+12160+(Da<<3)+4>>2]|0)+wa|0;hb=((ca(c[a+12128+(Da<<3)>>2]|0,La)|0)/(Ma|0)|0)+((Da&1)<<X)|0;Ba=c[a+12128+(Da<<3)+4>>2]|0;if(Na){Aa=Da>>1;mb=((ca(Ba,La)|0)/(Ma|0)|0)+(Aa<<X)|0;nb=Aa}else{mb=Ha-Ba|0;nb=Da>>1}Ba=((Ha&V)<<B)+(xa&V)|0;Aa=((mb&V)<<B)+(hb&V)|0;za=(c[l>>2]|0)+((ca(nb,Ea)|0)+(Da<<3&8))|0;if(Y){gb=(c[K>>2]|0)+((ca(Ha>>1,va)|0)+(xa>>1))|0;mf[c[(c[O>>2]|0)+16+(Ba<<2)>>2]&2047](za,gb,va,8);gb=(c[Z>>2]|0)+((ca(mb>>1,va)|0)+(hb>>1))|0;mf[c[(c[A>>2]|0)+16+(Aa<<2)>>2]&2047](za,gb,va,8)}else{gb=(c[K>>2]|0)+((ca(Ha>>2,va)|0)+(xa>>2))|0;ef[c[(c[h>>2]|0)+64+(Ba<<2)>>2]&4095](za,gb,va);gb=(c[Z>>2]|0)+((ca(mb>>2,va)|0)+(hb>>2))|0;ef[c[(c[_>>2]|0)+64+(Aa<<2)>>2]&4095](za,gb,va)}Da=Da+1|0;if((Da|0)>=4){break e}}}if(Na){Da=0;do{gb=(c[a+12160+(Da<<3)>>2]|0)+Ga|0;za=c[a+12160+(Da<<3)+4>>2]|0;Aa=gb-(c[a+12128+(Da<<3)>>2]|0)|0;hb=Da>>1;Ba=((ca(c[a+12128+(Da<<3)+4>>2]|0,La)|0)/(Ma|0)|0)+(hb<<X)|0;xa=((za&V)<<B)+(gb&V)|0;Ha=((Ba&V)<<B)+(Aa&V)|0;fb=(c[l>>2]|0)+((Da<<3&8)+(ca(hb,Ea)|0))|0;if(Y){hb=(c[K>>2]|0)+((ca(za>>1,va)|0)+(gb>>1))|0;mf[c[(c[O>>2]|0)+16+(xa<<2)>>2]&2047](fb,hb,va,8);hb=(c[Z>>2]|0)+((ca(Ba>>1,va)|0)+(Aa>>1))|0;mf[c[(c[A>>2]|0)+16+(Ha<<2)>>2]&2047](fb,hb,va,8)}else{hb=(c[K>>2]|0)+((ca(za>>2,va)|0)+(gb>>2))|0;ef[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095](fb,hb,va);hb=(c[Z>>2]|0)+((ca(Ba>>2,va)|0)+(Aa>>2))|0;ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095](fb,hb,va)}Da=Da+1|0;}while((Da|0)<4)}else{Da=0;do{La=(c[a+12160+(Da<<3)>>2]|0)+Ga|0;Na=(c[a+12160+(Da<<3)+4>>2]|0)+wa|0;hb=La-(c[a+12128+(Da<<3)>>2]|0)|0;fb=Na-(c[a+12128+(Da<<3)+4>>2]|0)|0;Ha=((Na&V)<<B)+(La&V)|0;Aa=((fb&V)<<B)+(hb&V)|0;Ba=(c[l>>2]|0)+((Da<<3&8)+(ca(Da>>1,Ea)|0))|0;if(Y){xa=(c[K>>2]|0)+((ca(Na>>1,va)|0)+(La>>1))|0;mf[c[(c[O>>2]|0)+16+(Ha<<2)>>2]&2047](Ba,xa,va,8);xa=(c[Z>>2]|0)+((ca(fb>>1,va)|0)+(hb>>1))|0;mf[c[(c[A>>2]|0)+16+(Aa<<2)>>2]&2047](Ba,xa,va,8)}else{xa=(c[K>>2]|0)+((ca(Na>>2,va)|0)+(La>>2))|0;ef[c[(c[h>>2]|0)+64+(Ha<<2)>>2]&4095](Ba,xa,va);xa=(c[Z>>2]|0)+((ca(fb>>2,va)|0)+(hb>>2))|0;ef[c[(c[_>>2]|0)+64+(Aa<<2)>>2]&4095](Ba,xa,va)}Da=Da+1|0;}while((Da|0)<4)}}else{Da=(c[$>>2]|0)+Ga|0;Ea=(c[aa>>2]|0)+wa|0;xa=c[ba>>2]|0;if((Ga|0)==0){ob=(ca(xa,_a-Ma|0)|0)/(Ma|0)|0}else{ob=Da-xa|0}xa=c[da>>2]|0;if((wa|0)==0){pb=(ca(xa,_a-Ma|0)|0)/(Ma|0)|0}else{pb=Ea-xa|0}xa=((Ea&V)<<B)+(Da&V)|0;Ba=((pb&V)<<B)+(ob&V)|0;if(Y){Aa=(c[K>>2]|0)+((ca(Ea>>1,va)|0)+(Da>>1))|0;mf[c[(c[O>>2]|0)+(xa<<2)>>2]&2047](c[l>>2]|0,Aa,va,16);Aa=(c[Z>>2]|0)+((ca(pb>>1,va)|0)+(ob>>1))|0;mf[c[(c[A>>2]|0)+(Ba<<2)>>2]&2047](c[l>>2]|0,Aa,va,16);break}else{Aa=(ca(Ea>>2,va)|0)+(Da>>2)|0;ef[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+Aa|0,va);Da=Aa+8|0;ef[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+Da|0,va);Ea=va<<3;ef[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[K>>2]|0)+(Aa+Ea)|0,va);Aa=Ea+8|0;ef[c[(c[h>>2]|0)+64+(xa<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[K>>2]|0)+(Da+Ea)|0,va);Da=(ca(pb>>2,va)|0)+(ob>>2)|0;ef[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+Da|0,va);xa=Da+8|0;ef[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+xa|0,va);ef[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[Z>>2]|0)+(Da+Ea)|0,va);ef[c[(c[_>>2]|0)+64+(Ba<<2)>>2]&4095]((c[l>>2]|0)+Aa|0,(c[Z>>2]|0)+(xa+Ea)|0,va);break}}}while(0);lb=Xe[D&511](M,c[l>>2]|0,c[L>>2]|0,va,16)|0}}while(0);c[ra>>2]=ua;c[n+(Ca<<2)>>2]=lb;va=(ca((d[w+((ma<<B)-y)|0]|0)+(d[w+((oa<<B)-x)|0]|0)|0,i)|0)+lb|0;if((va|0)>=(bb|0)){kb=bb;break}c[b>>2]=oa;c[G>>2]=ma;kb=va}}while(0);Ca=Fa+sa|0;ua=Ia+oa&63;ra=z+(ua<<2)|0;if((c[ra>>2]|0)==(Ca|0)){qb=kb;break}va=c[I>>2]|0;do{if(H){Ma=c[J>>2]|0;_a=(c[K>>2]|0)+((ca(va,na)|0)+oa)|0;wa=Xe[D&511](M,c[L>>2]|0,_a,va,k)|0;if(N){rb=wa;break}_a=na<<1&2|oa&1;Ga=c[l>>2]|0;Ea=va<<4;xa=Ga+Ea|0;Aa=(ca(Ma,na>>1)|0)+(oa>>1)|0;mf[c[(c[O>>2]|0)+(E<<4)+(_a<<2)>>2]&2047](xa,(c[P>>2]|0)+Aa|0,Ma,Q);Ba=Ga+(Ea|8)|0;mf[c[(c[O>>2]|0)+(E<<4)+(_a<<2)>>2]&2047](Ba,(c[R>>2]|0)+Aa|0,Ma,Q);Aa=(Xe[j&511](M,xa,c[S>>2]|0,Ma,Q)|0)+wa|0;rb=Aa+(Xe[j&511](M,Ba,c[T>>2]|0,Ma,Q)|0)|0}else{Ma=oa<<B;Ba=na<<B;if((c[o>>2]|0)>(oa|0)){rb=536870912;break}if((Ma|0)>(c[s>>2]<<B|0)){rb=536870912;break}if((c[q>>2]|0)>(na|0)){rb=536870912;break}if((Ba|0)>(c[u>>2]<<B|0)){rb=536870912;break}Aa=e[g>>1]|0;wa=e[U>>1]|0;f:do{if((c[W>>2]|0)==1){xa=wa-Aa|0;_a=(Ba|0)==0;Ea=va<<3;if((Ma|0)==0){Ga=0;while(1){Da=c[a+12160+(Ga<<3)>>2]|0;hb=(c[a+12160+(Ga<<3)+4>>2]|0)+Ba|0;fb=((ca(c[a+12128+(Ga<<3)>>2]|0,xa)|0)/(Aa|0)|0)+((Ga&1)<<X)|0;Ha=c[a+12128+(Ga<<3)+4>>2]|0;if(_a){La=Ga>>1;sb=((ca(Ha,xa)|0)/(Aa|0)|0)+(La<<X)|0;tb=La}else{sb=hb-Ha|0;tb=Ga>>1}Ha=((hb&V)<<B)+(Da&V)|0;La=((sb&V)<<B)+(fb&V)|0;Na=(c[l>>2]|0)+((ca(tb,Ea)|0)+(Ga<<3&8))|0;if(Y){gb=(c[K>>2]|0)+((ca(hb>>1,va)|0)+(Da>>1))|0;mf[c[(c[O>>2]|0)+16+(Ha<<2)>>2]&2047](Na,gb,va,8);gb=(c[Z>>2]|0)+((ca(sb>>1,va)|0)+(fb>>1))|0;mf[c[(c[A>>2]|0)+16+(La<<2)>>2]&2047](Na,gb,va,8)}else{gb=(c[K>>2]|0)+((ca(hb>>2,va)|0)+(Da>>2))|0;ef[c[(c[h>>2]|0)+64+(Ha<<2)>>2]&4095](Na,gb,va);gb=(c[Z>>2]|0)+((ca(sb>>2,va)|0)+(fb>>2))|0;ef[c[(c[_>>2]|0)+64+(La<<2)>>2]&4095](Na,gb,va)}Ga=Ga+1|0;if((Ga|0)>=4){break f}}}if(_a){Ga=0;do{gb=(c[a+12160+(Ga<<3)>>2]|0)+Ma|0;Na=c[a+12160+(Ga<<3)+4>>2]|0;La=gb-(c[a+12128+(Ga<<3)>>2]|0)|0;fb=Ga>>1;Ha=((ca(c[a+12128+(Ga<<3)+4>>2]|0,xa)|0)/(Aa|0)|0)+(fb<<X)|0;Da=((Na&V)<<B)+(gb&V)|0;hb=((Ha&V)<<B)+(La&V)|0;za=(c[l>>2]|0)+((Ga<<3&8)+(ca(fb,Ea)|0))|0;if(Y){fb=(c[K>>2]|0)+((ca(Na>>1,va)|0)+(gb>>1))|0;mf[c[(c[O>>2]|0)+16+(Da<<2)>>2]&2047](za,fb,va,8);fb=(c[Z>>2]|0)+((ca(Ha>>1,va)|0)+(La>>1))|0;mf[c[(c[A>>2]|0)+16+(hb<<2)>>2]&2047](za,fb,va,8)}else{fb=(c[K>>2]|0)+((ca(Na>>2,va)|0)+(gb>>2))|0;ef[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095](za,fb,va);fb=(c[Z>>2]|0)+((ca(Ha>>2,va)|0)+(La>>2))|0;ef[c[(c[_>>2]|0)+64+(hb<<2)>>2]&4095](za,fb,va)}Ga=Ga+1|0;}while((Ga|0)<4)}else{Ga=0;do{xa=(c[a+12160+(Ga<<3)>>2]|0)+Ma|0;_a=(c[a+12160+(Ga<<3)+4>>2]|0)+Ba|0;fb=xa-(c[a+12128+(Ga<<3)>>2]|0)|0;za=_a-(c[a+12128+(Ga<<3)+4>>2]|0)|0;hb=((_a&V)<<B)+(xa&V)|0;La=((za&V)<<B)+(fb&V)|0;Ha=(c[l>>2]|0)+((Ga<<3&8)+(ca(Ga>>1,Ea)|0))|0;if(Y){Da=(c[K>>2]|0)+((ca(_a>>1,va)|0)+(xa>>1))|0;mf[c[(c[O>>2]|0)+16+(hb<<2)>>2]&2047](Ha,Da,va,8);Da=(c[Z>>2]|0)+((ca(za>>1,va)|0)+(fb>>1))|0;mf[c[(c[A>>2]|0)+16+(La<<2)>>2]&2047](Ha,Da,va,8)}else{Da=(c[K>>2]|0)+((ca(_a>>2,va)|0)+(xa>>2))|0;ef[c[(c[h>>2]|0)+64+(hb<<2)>>2]&4095](Ha,Da,va);Da=(c[Z>>2]|0)+((ca(za>>2,va)|0)+(fb>>2))|0;ef[c[(c[_>>2]|0)+64+(La<<2)>>2]&4095](Ha,Da,va)}Ga=Ga+1|0;}while((Ga|0)<4)}}else{Ga=(c[$>>2]|0)+Ma|0;Ea=(c[aa>>2]|0)+Ba|0;Da=c[ba>>2]|0;if((Ma|0)==0){ub=(ca(Da,wa-Aa|0)|0)/(Aa|0)|0}else{ub=Ga-Da|0}Da=c[da>>2]|0;if((Ba|0)==0){vb=(ca(Da,wa-Aa|0)|0)/(Aa|0)|0}else{vb=Ea-Da|0}Da=((Ea&V)<<B)+(Ga&V)|0;Ha=((vb&V)<<B)+(ub&V)|0;if(Y){La=(c[K>>2]|0)+((ca(Ea>>1,va)|0)+(Ga>>1))|0;mf[c[(c[O>>2]|0)+(Da<<2)>>2]&2047](c[l>>2]|0,La,va,16);La=(c[Z>>2]|0)+((ca(vb>>1,va)|0)+(ub>>1))|0;mf[c[(c[A>>2]|0)+(Ha<<2)>>2]&2047](c[l>>2]|0,La,va,16);break}else{La=(ca(Ea>>2,va)|0)+(Ga>>2)|0;ef[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095](c[l>>2]|0,(c[K>>2]|0)+La|0,va);Ga=La+8|0;ef[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[K>>2]|0)+Ga|0,va);Ea=va<<3;ef[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[K>>2]|0)+(La+Ea)|0,va);La=Ea+8|0;ef[c[(c[h>>2]|0)+64+(Da<<2)>>2]&4095]((c[l>>2]|0)+La|0,(c[K>>2]|0)+(Ga+Ea)|0,va);Ga=(ca(vb>>2,va)|0)+(ub>>2)|0;ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095](c[l>>2]|0,(c[Z>>2]|0)+Ga|0,va);Da=Ga+8|0;ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+8|0,(c[Z>>2]|0)+Da|0,va);ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+Ea|0,(c[Z>>2]|0)+(Ga+Ea)|0,va);ef[c[(c[_>>2]|0)+64+(Ha<<2)>>2]&4095]((c[l>>2]|0)+La|0,(c[Z>>2]|0)+(Da+Ea)|0,va);break}}}while(0);rb=Xe[D&511](M,c[l>>2]|0,c[L>>2]|0,va,16)|0}}while(0);c[ra>>2]=Ca;c[n+(ua<<2)>>2]=rb;va=(ca((d[w+((na<<B)-y)|0]|0)+(d[w+((oa<<B)-x)|0]|0)|0,i)|0)+rb|0;if((va|0)>=(kb|0)){qb=kb;break}c[b>>2]=oa;c[G>>2]=na;qb=va}else{qb=bb}}while(0);na=c[b>>2]|0;if((na|0)!=(ka|0)){ja=qb;ka=na;continue}if((c[G>>2]|0)==(la|0)){break}else{ja=qb;ka=na}}ja=ea?fa-1|0:ga;if((ja|0)==0){F=qb;break}else{fa=ja;m=qb;f=ka}}return F|0}function wrb(a,b){a=a|0;b=b|0;return(c[a>>2]|0)-(c[b>>2]|0)|0}function xrb(a,f,h,j,k,l,m,n){a=a|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0;o=i;i=i+19216|0;p=o|0;c[(o|0)>>2]=0;c[(o|0)+4>>2]=0;q=c[a+12232>>2]|0;r=c[a+124>>2]|0;s=(ca(c[(a+12480|0)>>2]|0,r)|0)+(c[a+12476>>2]|0)|0;t=c[(a+12220|0)>>2]|0;u=c[(a+12264|0)>>2]|0;v=c[(a+12272|0)>>2]|0;w=c[(a+12268|0)>>2]|0;y=c[(a+12276|0)>>2]|0;z=c[(a+12464|0)>>2]|0;A=c[(a+12280|0)>>2]|0;B=c[(a+12284|0)>>2]|0;C=c[a+12244>>2]|0;D=c[(a+12216|0)>>2]|0;G=(C&1)+1|0;H=c[(a+10472|0)>>2]|0;I=c[(a+10476|0)>>2]|0;J=(c[(a+12224|0)>>2]|0)+4194304|0;c[(a+12224|0)>>2]=J;if((J|0)==0){c[(a+12224|0)>>2]=4194304;mrc(D|0,0,256)|0;K=c[(a+12224|0)>>2]|0}else{K=J}do{J=1;if(J){J=0;if((c[a+14084>>2]|0)==0){L=c[(j+76|0)>>2]>>G;M=c[(j+72|0)>>2]>>G;N=M+K+(L<<11)|0;do{if((c[(D+(((L<<3)+M&63)<<2)|0)>>2]|0)==(N|0)){O=1e6;P=0;Q=0}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;S=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ca(R,L)|0)+M)|0;U=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){V=U;break}T=c[a+12208>>2]|0;W=(ca(S,L>>1)|0)+(M>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&2047](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+W|0,S,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&2047](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+W|0,S,4);W=(Xe[I&511](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,S,4)|0)+U|0;V=W+(Xe[I&511](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,S,4)|0)|0}else{S=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(M|0)){V=536870912;break}if((M<<G|0)>(c[(a+12268|0)>>2]<<G|0)){V=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){V=536870912;break}if((L<<G|0)>(c[(a+12276|0)>>2]<<G|0)){V=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;W=(C&1)<<1|1;a:do{if((c[a+11740>>2]|0)==1){if((M<<G|0)==0){U=0;while(1){X=c[a+12160+(U<<3)>>2]|0;Y=(c[a+12160+(U<<3)+4>>2]|0)+(L<<G)|0;Z=((ca(c[a+12128+(U<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((U&1)<<(C&1|4))|0;_=c[a+12128+(U<<3)+4>>2]|0;if((L<<G|0)==0){$=U>>1;aa=((ca(_,T-R|0)|0)/(R|0)|0)+($<<(C&1|4))|0;ba=$}else{aa=Y-_|0;ba=U>>1}_=((aa&W)<<G)+(Z&W)|0;$=(c[(a+12208|0)>>2]|0)+((ca(ba,S<<3)|0)+(U<<3&8))|0;if((C&1|0)==0){da=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,S)|0)+(X>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&W)<<G)+(X&W)|0)<<2)>>2]&2047]($,da,S,8);da=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(aa>>1,S)|0)+(Z>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(_<<2)>>2]&2047]($,da,S,8)}else{da=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>2,S)|0)+(X>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&W)<<G)+(X&W)|0)<<2)>>2]&4095]($,da,S);da=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(aa>>2,S)|0)+(Z>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]($,da,S)}U=U+1|0;if((U|0)>=4){break a}}}if((L<<G|0)==0){U=0;do{da=(c[a+12160+(U<<3)>>2]|0)+(M<<G)|0;$=c[a+12160+(U<<3)+4>>2]|0;_=da-(c[a+12128+(U<<3)>>2]|0)|0;Z=U>>1;X=((ca(c[a+12128+(U<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(Z<<(C&1|4))|0;Y=(c[(a+12208|0)>>2]|0)+((U<<3&8)+(ca(Z,S<<3)|0))|0;if((C&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($>>1,S)|0)+(da>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+(((($&W)<<G)+(da&W)|0)<<2)>>2]&2047](Y,Z,S,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>1,S)|0)+(_>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((X&W)<<G)+(_&W)|0)<<2)>>2]&2047](Y,Z,S,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($>>2,S)|0)+(da>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(da&W)|0)<<2)>>2]&4095](Y,Z,S);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>2,S)|0)+(_>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((X&W)<<G)+(_&W)|0)<<2)>>2]&4095](Y,Z,S)}U=U+1|0;}while((U|0)<4)}else{U=0;do{Z=(c[a+12160+(U<<3)>>2]|0)+(M<<G)|0;Y=(c[a+12160+(U<<3)+4>>2]|0)+(L<<G)|0;_=Z-(c[a+12128+(U<<3)>>2]|0)|0;X=Y-(c[a+12128+(U<<3)+4>>2]|0)|0;da=(c[(a+12208|0)>>2]|0)+((U<<3&8)+(ca(U>>1,S<<3)|0))|0;if((C&1|0)==0){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,S)|0)+(Z>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&W)<<G)+(Z&W)|0)<<2)>>2]&2047](da,$,S,8);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>1,S)|0)+(_>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((X&W)<<G)+(_&W)|0)<<2)>>2]&2047](da,$,S,8)}else{$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>2,S)|0)+(Z>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&W)<<G)+(Z&W)|0)<<2)>>2]&4095](da,$,S);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>2,S)|0)+(_>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((X&W)<<G)+(_&W)|0)<<2)>>2]&4095](da,$,S)}U=U+1|0;}while((U|0)<4)}}else{U=(c[a+12160>>2]|0)+(M<<G)|0;$=(c[a+12164>>2]|0)+(L<<G)|0;da=c[a+12128>>2]|0;if((M<<G|0)==0){ea=(ca(da,T-R|0)|0)/(R|0)|0}else{ea=U-da|0}da=c[a+12132>>2]|0;if((L<<G|0)==0){fa=(ca(da,T-R|0)|0)/(R|0)|0}else{fa=$-da|0}da=((fa&W)<<G)+(ea&W)|0;if((C&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($>>1,S)|0)+(U>>1))|0;mf[c[(c[a+12444>>2]|0)+(((($&W)<<G)+(U&W)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,_,S,16);_=(c[a+12352+(l<<4)+32>>2]|0)+((ca(fa>>1,S)|0)+(ea>>1))|0;mf[c[(c[a+12448>>2]|0)+(da<<2)>>2]&2047](c[(a+12208|0)>>2]|0,_,S,16);break}else{_=(ca($>>2,S)|0)+(U>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(U&W)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+_|0,S);ef[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(U&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_+8|0)|0,S);ef[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(U&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(S<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(_+(S<<3))|0,S);ef[c[(c[(a+12452|0)>>2]|0)+64+(((($&W)<<G)+(U&W)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((S<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((_+8|0)+(S<<3))|0,S);_=(ca(fa>>2,S)|0)+(ea>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(da<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+_|0,S);ef[c[(c[(a+12456|0)>>2]|0)+64+(da<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_+8|0)|0,S);ef[c[(c[(a+12456|0)>>2]|0)+64+(da<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(S<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(_+(S<<3))|0,S);ef[c[(c[(a+12456|0)>>2]|0)+64+(da<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((S<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((_+8|0)+(S<<3))|0,S);break}}}while(0);V=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,S,16)|0}}while(0);c[(D+(((L<<3)+M&63)<<2)|0)>>2]=N;c[t+(((L<<3)+M&63)<<2)>>2]=V;W=c[(j+72|0)>>2]>>G;R=c[(j+76|0)>>2]>>G;T=(ca((d[z+((R<<G)-B)|0]|0)+(d[z+((W<<G)-A)|0]|0)|0,q)|0)+V|0;if((T|0)>=1e6){O=1e6;P=0;Q=0;break}c[(o|0)>>2]=W;c[p+4>>2]=R;O=T;P=W;Q=R}}while(0);M=c[(j+36|0)>>2]>>G;L=c[(j+32|0)>>2]>>G;N=L+K+(M<<11)|0;do{if((c[(D+(((M<<3)+L&63)<<2)|0)>>2]|0)==(N|0)){ga=O;ha=P;ia=Q}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;W=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ca(R,M)|0)+L)|0;_=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){ja=_;break}T=c[a+12208>>2]|0;da=(ca(W,M>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((M<<1&2|L&1)<<2)>>2]&2047](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+da|0,W,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((M<<1&2|L&1)<<2)>>2]&2047](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+da|0,W,4);da=(Xe[I&511](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,W,4)|0)+_|0;ja=da+(Xe[I&511](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,W,4)|0)|0}else{W=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){ja=536870912;break}if((L<<G|0)>(c[(a+12268|0)>>2]<<G|0)){ja=536870912;break}if((c[(a+12272|0)>>2]|0)>(M|0)){ja=536870912;break}if((M<<G|0)>(c[(a+12276|0)>>2]<<G|0)){ja=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;da=(C&1)<<1|1;b:do{if((c[a+11740>>2]|0)==1){if((L<<G|0)==0){_=0;while(1){U=c[a+12160+(_<<3)>>2]|0;$=(c[a+12160+(_<<3)+4>>2]|0)+(M<<G)|0;X=((ca(c[a+12128+(_<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((_&1)<<(C&1|4))|0;Z=c[a+12128+(_<<3)+4>>2]|0;if((M<<G|0)==0){Y=_>>1;ka=((ca(Z,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;la=Y}else{ka=$-Z|0;la=_>>1}Z=((ka&da)<<G)+(X&da)|0;Y=(c[(a+12208|0)>>2]|0)+((ca(la,W<<3)|0)+(_<<3&8))|0;if((C&1|0)==0){ma=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($>>1,W)|0)+(U>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+(((($&da)<<G)+(U&da)|0)<<2)>>2]&2047](Y,ma,W,8);ma=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ka>>1,W)|0)+(X>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Z<<2)>>2]&2047](Y,ma,W,8)}else{ma=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($>>2,W)|0)+(U>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+(((($&da)<<G)+(U&da)|0)<<2)>>2]&4095](Y,ma,W);ma=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ka>>2,W)|0)+(X>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Z<<2)>>2]&4095](Y,ma,W)}_=_+1|0;if((_|0)>=4){break b}}}if((M<<G|0)==0){_=0;do{ma=(c[a+12160+(_<<3)>>2]|0)+(L<<G)|0;Y=c[a+12160+(_<<3)+4>>2]|0;Z=ma-(c[a+12128+(_<<3)>>2]|0)|0;X=_>>1;U=((ca(c[a+12128+(_<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(X<<(C&1|4))|0;$=(c[(a+12208|0)>>2]|0)+((_<<3&8)+(ca(X,W<<3)|0))|0;if((C&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,W)|0)+(ma>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&da)<<G)+(ma&da)|0)<<2)>>2]&2047]($,X,W,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(U>>1,W)|0)+(Z>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((U&da)<<G)+(Z&da)|0)<<2)>>2]&2047]($,X,W,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>2,W)|0)+(ma>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(ma&da)|0)<<2)>>2]&4095]($,X,W);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(U>>2,W)|0)+(Z>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((U&da)<<G)+(Z&da)|0)<<2)>>2]&4095]($,X,W)}_=_+1|0;}while((_|0)<4)}else{_=0;do{X=(c[a+12160+(_<<3)>>2]|0)+(L<<G)|0;$=(c[a+12160+(_<<3)+4>>2]|0)+(M<<G)|0;Z=X-(c[a+12128+(_<<3)>>2]|0)|0;U=$-(c[a+12128+(_<<3)+4>>2]|0)|0;ma=(c[(a+12208|0)>>2]|0)+((_<<3&8)+(ca(_>>1,W<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($>>1,W)|0)+(X>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+(((($&da)<<G)+(X&da)|0)<<2)>>2]&2047](ma,Y,W,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(U>>1,W)|0)+(Z>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((U&da)<<G)+(Z&da)|0)<<2)>>2]&2047](ma,Y,W,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca($>>2,W)|0)+(X>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+(((($&da)<<G)+(X&da)|0)<<2)>>2]&4095](ma,Y,W);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(U>>2,W)|0)+(Z>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((U&da)<<G)+(Z&da)|0)<<2)>>2]&4095](ma,Y,W)}_=_+1|0;}while((_|0)<4)}}else{_=(c[a+12160>>2]|0)+(L<<G)|0;Y=(c[a+12164>>2]|0)+(M<<G)|0;ma=c[a+12128>>2]|0;if((L<<G|0)==0){na=(ca(ma,T-R|0)|0)/(R|0)|0}else{na=_-ma|0}ma=c[a+12132>>2]|0;if((M<<G|0)==0){oa=(ca(ma,T-R|0)|0)/(R|0)|0}else{oa=Y-ma|0}ma=((oa&da)<<G)+(na&da)|0;if((C&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,W)|0)+(_>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Z,W,16);Z=(c[a+12352+(l<<4)+32>>2]|0)+((ca(oa>>1,W)|0)+(na>>1))|0;mf[c[(c[a+12448>>2]|0)+(ma<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Z,W,16);break}else{Z=(ca(Y>>2,W)|0)+(_>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Z|0,W);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Z+8|0)|0,W);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(W<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Z+(W<<3))|0,W);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&da)<<G)+(_&da)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((W<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Z+8|0)+(W<<3))|0,W);Z=(ca(oa>>2,W)|0)+(na>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Z|0,W);ef[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Z+8|0)|0,W);ef[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(W<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Z+(W<<3))|0,W);ef[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((W<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Z+8|0)+(W<<3))|0,W);break}}}while(0);ja=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,W,16)|0}}while(0);c[(D+(((M<<3)+L&63)<<2)|0)>>2]=N;c[t+(((M<<3)+L&63)<<2)>>2]=ja;da=c[(j+32|0)>>2]>>G;R=c[(j+36|0)>>2]>>G;T=(ca((d[z+((R<<G)-B)|0]|0)+(d[z+((da<<G)-A)|0]|0)|0,q)|0)+ja|0;if((T|0)>=(O|0)){ga=O;ha=P;ia=Q;break}c[(o|0)>>2]=da;c[p+4>>2]=R;ga=T;ha=da;ia=R}}while(0);L=c[(j+12|0)>>2]>>G;M=c[(j+8|0)>>2]>>G;N=M+K+(L<<11)|0;do{if((c[(D+(((L<<3)+M&63)<<2)|0)>>2]|0)==(N|0)){pa=ga;qa=ha;ra=ia}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;da=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ca(R,L)|0)+M)|0;S=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){sa=S;break}T=c[a+12208>>2]|0;Z=(ca(da,L>>1)|0)+(M>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&2047](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+Z|0,da,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&2047](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+Z|0,da,4);Z=(Xe[I&511](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,da,4)|0)+S|0;sa=Z+(Xe[I&511](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,da,4)|0)|0}else{da=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(M|0)){sa=536870912;break}if((M<<G|0)>(c[(a+12268|0)>>2]<<G|0)){sa=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){sa=536870912;break}if((L<<G|0)>(c[(a+12276|0)>>2]<<G|0)){sa=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;Z=(C&1)<<1|1;c:do{if((c[a+11740>>2]|0)==1){if((M<<G|0)==0){S=0;while(1){ma=c[a+12160+(S<<3)>>2]|0;_=(c[a+12160+(S<<3)+4>>2]|0)+(L<<G)|0;Y=((ca(c[a+12128+(S<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((S&1)<<(C&1|4))|0;U=c[a+12128+(S<<3)+4>>2]|0;if((L<<G|0)==0){X=S>>1;ta=((ca(U,T-R|0)|0)/(R|0)|0)+(X<<(C&1|4))|0;ua=X}else{ta=_-U|0;ua=S>>1}U=((ta&Z)<<G)+(Y&Z)|0;X=(c[(a+12208|0)>>2]|0)+((ca(ua,da<<3)|0)+(S<<3&8))|0;if((C&1|0)==0){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>1,da)|0)+(ma>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((_&Z)<<G)+(ma&Z)|0)<<2)>>2]&2047](X,$,da,8);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ta>>1,da)|0)+(Y>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(U<<2)>>2]&2047](X,$,da,8)}else{$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>2,da)|0)+(ma>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&Z)<<G)+(ma&Z)|0)<<2)>>2]&4095](X,$,da);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ta>>2,da)|0)+(Y>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](X,$,da)}S=S+1|0;if((S|0)>=4){break c}}}if((L<<G|0)==0){S=0;do{$=(c[a+12160+(S<<3)>>2]|0)+(M<<G)|0;X=c[a+12160+(S<<3)+4>>2]|0;U=$-(c[a+12128+(S<<3)>>2]|0)|0;Y=S>>1;ma=((ca(c[a+12128+(S<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;_=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ca(Y,da<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,da)|0)+($>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((X&Z)<<G)+($&Z)|0)<<2)>>2]&2047](_,Y,da,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ma>>1,da)|0)+(U>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ma&Z)<<G)+(U&Z)|0)<<2)>>2]&2047](_,Y,da,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>2,da)|0)+($>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+($&Z)|0)<<2)>>2]&4095](_,Y,da);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ma>>2,da)|0)+(U>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ma&Z)<<G)+(U&Z)|0)<<2)>>2]&4095](_,Y,da)}S=S+1|0;}while((S|0)<4)}else{S=0;do{Y=(c[a+12160+(S<<3)>>2]|0)+(M<<G)|0;_=(c[a+12160+(S<<3)+4>>2]|0)+(L<<G)|0;U=Y-(c[a+12128+(S<<3)>>2]|0)|0;ma=_-(c[a+12128+(S<<3)+4>>2]|0)|0;$=(c[(a+12208|0)>>2]|0)+((S<<3&8)+(ca(S>>1,da<<3)|0))|0;if((C&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>1,da)|0)+(Y>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((_&Z)<<G)+(Y&Z)|0)<<2)>>2]&2047]($,X,da,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ma>>1,da)|0)+(U>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ma&Z)<<G)+(U&Z)|0)<<2)>>2]&2047]($,X,da,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_>>2,da)|0)+(Y>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_&Z)<<G)+(Y&Z)|0)<<2)>>2]&4095]($,X,da);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ma>>2,da)|0)+(U>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ma&Z)<<G)+(U&Z)|0)<<2)>>2]&4095]($,X,da)}S=S+1|0;}while((S|0)<4)}}else{S=(c[a+12160>>2]|0)+(M<<G)|0;X=(c[a+12164>>2]|0)+(L<<G)|0;$=c[a+12128>>2]|0;if((M<<G|0)==0){va=(ca($,T-R|0)|0)/(R|0)|0}else{va=S-$|0}$=c[a+12132>>2]|0;if((L<<G|0)==0){wa=(ca($,T-R|0)|0)/(R|0)|0}else{wa=X-$|0}$=((wa&Z)<<G)+(va&Z)|0;if((C&1|0)==0){U=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,da)|0)+(S>>1))|0;mf[c[(c[a+12444>>2]|0)+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,U,da,16);U=(c[a+12352+(l<<4)+32>>2]|0)+((ca(wa>>1,da)|0)+(va>>1))|0;mf[c[(c[a+12448>>2]|0)+($<<2)>>2]&2047](c[(a+12208|0)>>2]|0,U,da,16);break}else{U=(ca(X>>2,da)|0)+(S>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+U|0,da);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(U+8|0)|0,da);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(da<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(U+(da<<3))|0,da);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&Z)<<G)+(S&Z)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((da<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((U+8|0)+(da<<3))|0,da);U=(ca(wa>>2,da)|0)+(va>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+U|0,da);ef[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(U+8|0)|0,da);ef[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(da<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(U+(da<<3))|0,da);ef[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((da<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((U+8|0)+(da<<3))|0,da);break}}}while(0);sa=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,da,16)|0}}while(0);c[(D+(((L<<3)+M&63)<<2)|0)>>2]=N;c[t+(((L<<3)+M&63)<<2)>>2]=sa;Z=c[(j+8|0)>>2]>>G;R=c[(j+12|0)>>2]>>G;T=(ca((d[z+((R<<G)-B)|0]|0)+(d[z+((Z<<G)-A)|0]|0)|0,q)|0)+sa|0;if((T|0)>=(ga|0)){pa=ga;qa=ha;ra=ia;break}c[(o|0)>>2]=Z;c[p+4>>2]=R;pa=T;qa=Z;ra=R}}while(0);M=c[(j+20|0)>>2]>>G;L=c[(j+16|0)>>2]>>G;N=L+K+(M<<11)|0;do{if((c[(D+(((M<<3)+L&63)<<2)|0)>>2]|0)==(N|0)){xa=pa;ya=qa;za=ra}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;Z=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ca(R,M)|0)+L)|0;W=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){Aa=W;break}T=c[a+12208>>2]|0;U=(ca(Z,M>>1)|0)+(L>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((M<<1&2|L&1)<<2)>>2]&2047](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+U|0,Z,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((M<<1&2|L&1)<<2)>>2]&2047](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+U|0,Z,4);U=(Xe[I&511](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,Z,4)|0)+W|0;Aa=U+(Xe[I&511](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,Z,4)|0)|0}else{Z=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(L|0)){Aa=536870912;break}if((L<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Aa=536870912;break}if((c[(a+12272|0)>>2]|0)>(M|0)){Aa=536870912;break}if((M<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Aa=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;U=(C&1)<<1|1;d:do{if((c[a+11740>>2]|0)==1){if((L<<G|0)==0){W=0;while(1){$=c[a+12160+(W<<3)>>2]|0;S=(c[a+12160+(W<<3)+4>>2]|0)+(M<<G)|0;X=((ca(c[a+12128+(W<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((W&1)<<(C&1|4))|0;ma=c[a+12128+(W<<3)+4>>2]|0;if((M<<G|0)==0){Y=W>>1;Ba=((ca(ma,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;Ca=Y}else{Ba=S-ma|0;Ca=W>>1}ma=((Ba&U)<<G)+(X&U)|0;Y=(c[(a+12208|0)>>2]|0)+((ca(Ca,Z<<3)|0)+(W<<3&8))|0;if((C&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,Z)|0)+($>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&U)<<G)+($&U)|0)<<2)>>2]&2047](Y,_,Z,8);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ba>>1,Z)|0)+(X>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(ma<<2)>>2]&2047](Y,_,Z,8)}else{_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,Z)|0)+($>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&U)<<G)+($&U)|0)<<2)>>2]&4095](Y,_,Z);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ba>>2,Z)|0)+(X>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](Y,_,Z)}W=W+1|0;if((W|0)>=4){break d}}}if((M<<G|0)==0){W=0;do{_=(c[a+12160+(W<<3)>>2]|0)+(L<<G)|0;Y=c[a+12160+(W<<3)+4>>2]|0;ma=_-(c[a+12128+(W<<3)>>2]|0)|0;X=W>>1;$=((ca(c[a+12128+(W<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(X<<(C&1|4))|0;S=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ca(X,Z<<3)|0))|0;if((C&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,Z)|0)+(_>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Y&U)<<G)+(_&U)|0)<<2)>>2]&2047](S,X,Z,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>1,Z)|0)+(ma>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(((($&U)<<G)+(ma&U)|0)<<2)>>2]&2047](S,X,Z,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>2,Z)|0)+(_>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(_&U)|0)<<2)>>2]&4095](S,X,Z);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>2,Z)|0)+(ma>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(((($&U)<<G)+(ma&U)|0)<<2)>>2]&4095](S,X,Z)}W=W+1|0;}while((W|0)<4)}else{W=0;do{X=(c[a+12160+(W<<3)>>2]|0)+(L<<G)|0;S=(c[a+12160+(W<<3)+4>>2]|0)+(M<<G)|0;ma=X-(c[a+12128+(W<<3)>>2]|0)|0;$=S-(c[a+12128+(W<<3)+4>>2]|0)|0;_=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ca(W>>1,Z<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,Z)|0)+(X>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&U)<<G)+(X&U)|0)<<2)>>2]&2047](_,Y,Z,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>1,Z)|0)+(ma>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(((($&U)<<G)+(ma&U)|0)<<2)>>2]&2047](_,Y,Z,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,Z)|0)+(X>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&U)<<G)+(X&U)|0)<<2)>>2]&4095](_,Y,Z);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>2,Z)|0)+(ma>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(((($&U)<<G)+(ma&U)|0)<<2)>>2]&4095](_,Y,Z)}W=W+1|0;}while((W|0)<4)}}else{W=(c[a+12160>>2]|0)+(L<<G)|0;Y=(c[a+12164>>2]|0)+(M<<G)|0;_=c[a+12128>>2]|0;if((L<<G|0)==0){Da=(ca(_,T-R|0)|0)/(R|0)|0}else{Da=W-_|0}_=c[a+12132>>2]|0;if((M<<G|0)==0){Ea=(ca(_,T-R|0)|0)/(R|0)|0}else{Ea=Y-_|0}_=((Ea&U)<<G)+(Da&U)|0;if((C&1|0)==0){ma=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Y>>1,Z)|0)+(W>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ma,Z,16);ma=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Ea>>1,Z)|0)+(Da>>1))|0;mf[c[(c[a+12448>>2]|0)+(_<<2)>>2]&2047](c[(a+12208|0)>>2]|0,ma,Z,16);break}else{ma=(ca(Y>>2,Z)|0)+(W>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+ma|0,Z);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ma+8|0)|0,Z);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Z<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(ma+(Z<<3))|0,Z);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Y&U)<<G)+(W&U)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Z<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((ma+8|0)+(Z<<3))|0,Z);ma=(ca(Ea>>2,Z)|0)+(Da>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+ma|0,Z);ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ma+8|0)|0,Z);ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(Z<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(ma+(Z<<3))|0,Z);ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((Z<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ma+8|0)+(Z<<3))|0,Z);break}}}while(0);Aa=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,Z,16)|0}}while(0);c[(D+(((M<<3)+L&63)<<2)|0)>>2]=N;c[t+(((M<<3)+L&63)<<2)>>2]=Aa;U=c[(j+16|0)>>2]>>G;R=c[(j+20|0)>>2]>>G;T=(ca((d[z+((R<<G)-B)|0]|0)+(d[z+((U<<G)-A)|0]|0)|0,q)|0)+Aa|0;if((T|0)>=(pa|0)){xa=pa;ya=qa;za=ra;break}c[(o|0)>>2]=U;c[p+4>>2]=R;xa=T;ya=U;za=R}}while(0);L=c[(j+28|0)>>2]>>G;M=c[(j+24|0)>>2]>>G;N=M+K+(L<<11)|0;do{if((c[(D+(((L<<3)+M&63)<<2)|0)>>2]|0)==(N|0)){Fa=xa;Ga=ya;Ha=za}else{do{if((C&4|0)==0){R=c[a+12416>>2]|0;U=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ca(R,L)|0)+M)|0;da=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){Ia=da;break}T=c[a+12208>>2]|0;ma=(ca(U,L>>1)|0)+(M>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&2047](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ma|0,U,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&2047](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ma|0,U,4);ma=(Xe[I&511](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,U,4)|0)+da|0;Ia=ma+(Xe[I&511](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,U,4)|0)|0}else{U=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(M|0)){Ia=536870912;break}if((M<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Ia=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Ia=536870912;break}if((L<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Ia=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;ma=(C&1)<<1|1;e:do{if((c[a+11740>>2]|0)==1){if((M<<G|0)==0){da=0;while(1){_=c[a+12160+(da<<3)>>2]|0;W=(c[a+12160+(da<<3)+4>>2]|0)+(L<<G)|0;Y=((ca(c[a+12128+(da<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((da&1)<<(C&1|4))|0;$=c[a+12128+(da<<3)+4>>2]|0;if((L<<G|0)==0){X=da>>1;Ja=((ca($,T-R|0)|0)/(R|0)|0)+(X<<(C&1|4))|0;Ka=X}else{Ja=W-$|0;Ka=da>>1}$=((Ja&ma)<<G)+(Y&ma)|0;X=(c[(a+12208|0)>>2]|0)+((ca(Ka,U<<3)|0)+(da<<3&8))|0;if((C&1|0)==0){S=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,U)|0)+(_>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((W&ma)<<G)+(_&ma)|0)<<2)>>2]&2047](X,S,U,8);S=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ja>>1,U)|0)+(Y>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+($<<2)>>2]&2047](X,S,U,8)}else{S=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>2,U)|0)+(_>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(_&ma)|0)<<2)>>2]&4095](X,S,U);S=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ja>>2,U)|0)+(Y>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095](X,S,U)}da=da+1|0;if((da|0)>=4){break e}}}if((L<<G|0)==0){da=0;do{S=(c[a+12160+(da<<3)>>2]|0)+(M<<G)|0;X=c[a+12160+(da<<3)+4>>2]|0;$=S-(c[a+12128+(da<<3)>>2]|0)|0;Y=da>>1;_=((ca(c[a+12128+(da<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;W=(c[(a+12208|0)>>2]|0)+((da<<3&8)+(ca(Y,U<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,U)|0)+(S>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((X&ma)<<G)+(S&ma)|0)<<2)>>2]&2047](W,Y,U,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>1,U)|0)+($>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((_&ma)<<G)+($&ma)|0)<<2)>>2]&2047](W,Y,U,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>2,U)|0)+(S>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(S&ma)|0)<<2)>>2]&4095](W,Y,U);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>2,U)|0)+($>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((_&ma)<<G)+($&ma)|0)<<2)>>2]&4095](W,Y,U)}da=da+1|0;}while((da|0)<4)}else{da=0;do{Y=(c[a+12160+(da<<3)>>2]|0)+(M<<G)|0;W=(c[a+12160+(da<<3)+4>>2]|0)+(L<<G)|0;$=Y-(c[a+12128+(da<<3)>>2]|0)|0;_=W-(c[a+12128+(da<<3)+4>>2]|0)|0;S=(c[(a+12208|0)>>2]|0)+((da<<3&8)+(ca(da>>1,U<<3)|0))|0;if((C&1|0)==0){X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,U)|0)+(Y>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((W&ma)<<G)+(Y&ma)|0)<<2)>>2]&2047](S,X,U,8);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>1,U)|0)+($>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((_&ma)<<G)+($&ma)|0)<<2)>>2]&2047](S,X,U,8)}else{X=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>2,U)|0)+(Y>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(Y&ma)|0)<<2)>>2]&4095](S,X,U);X=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>2,U)|0)+($>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((_&ma)<<G)+($&ma)|0)<<2)>>2]&4095](S,X,U)}da=da+1|0;}while((da|0)<4)}}else{da=(c[a+12160>>2]|0)+(M<<G)|0;X=(c[a+12164>>2]|0)+(L<<G)|0;S=c[a+12128>>2]|0;if((M<<G|0)==0){La=(ca(S,T-R|0)|0)/(R|0)|0}else{La=da-S|0}S=c[a+12132>>2]|0;if((L<<G|0)==0){Ma=(ca(S,T-R|0)|0)/(R|0)|0}else{Ma=X-S|0}S=((Ma&ma)<<G)+(La&ma)|0;if((C&1|0)==0){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,U)|0)+(da>>1))|0;mf[c[(c[a+12444>>2]|0)+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,$,U,16);$=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Ma>>1,U)|0)+(La>>1))|0;mf[c[(c[a+12448>>2]|0)+(S<<2)>>2]&2047](c[(a+12208|0)>>2]|0,$,U,16);break}else{$=(ca(X>>2,U)|0)+(da>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+$|0,U);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+8|0)|0,U);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(U<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+(U<<3))|0,U);ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&ma)<<G)+(da&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((U<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(($+8|0)+(U<<3))|0,U);$=(ca(Ma>>2,U)|0)+(La>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+$|0,U);ef[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+8|0)|0,U);ef[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(U<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+(U<<3))|0,U);ef[c[(c[(a+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((U<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(($+8|0)+(U<<3))|0,U);break}}}while(0);Ia=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,U,16)|0}}while(0);c[(D+(((L<<3)+M&63)<<2)|0)>>2]=N;c[t+(((L<<3)+M&63)<<2)>>2]=Ia;ma=c[(j+24|0)>>2]>>G;R=c[(j+28|0)>>2]>>G;T=(ca((d[z+((R<<G)-B)|0]|0)+(d[z+((ma<<G)-A)|0]|0)|0,q)|0)+Ia|0;if((T|0)>=(xa|0)){Fa=xa;Ga=ya;Ha=za;break}c[(o|0)>>2]=ma;c[p+4>>2]=R;Fa=T;Ga=ma;Ha=R}}while(0);M=(ca(b[m+(s<<2)>>1]|0,n)|0)+32768>>16;L=(ca(b[m+(s<<2)+2>>1]|0,n)|0)+32768>>16;N=(M|0)>(w|0)?w:M;M=(u|0)>(N|0)?u:N;N=(L|0)>(y|0)?y:L;L=(v|0)>(N|0)?v:N;N=M+K+(L<<11)|0;if((c[(D+(((L<<3)+M&63)<<2)|0)>>2]|0)==(N|0)){Na=Fa;Oa=Ga;Pa=Ha;break}do{if((C&4|0)==0){R=c[a+12416>>2]|0;ma=c[a+12420>>2]|0;T=(c[a+12352+(l<<4)>>2]|0)+((ca(R,L)|0)+M)|0;Z=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,T,R,8)|0;if((C&2|0)==0){Qa=Z;break}T=c[a+12208>>2]|0;$=(ca(ma,L>>1)|0)+(M>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&2047](T+(R<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+$|0,ma,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((L<<1&2|M&1)<<2)>>2]&2047](T+(R<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+$|0,ma,4);$=(Xe[I&511](a,T+(R<<4)|0,c[a+12288+(k<<4)+4>>2]|0,ma,4)|0)+Z|0;Qa=$+(Xe[I&511](a,T+(R<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,ma,4)|0)|0}else{ma=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(M|0)){Qa=536870912;break}if((M<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Qa=536870912;break}if((c[(a+12272|0)>>2]|0)>(L|0)){Qa=536870912;break}if((L<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Qa=536870912;break}R=e[a+13872>>1]|0;T=e[a+13874>>1]|0;$=(C&1)<<1|1;f:do{if((c[a+11740>>2]|0)==1){if((M<<G|0)==0){Z=0;while(1){S=c[a+12160+(Z<<3)>>2]|0;da=(c[a+12160+(Z<<3)+4>>2]|0)+(L<<G)|0;X=((ca(c[a+12128+(Z<<3)>>2]|0,T-R|0)|0)/(R|0)|0)+((Z&1)<<(C&1|4))|0;_=c[a+12128+(Z<<3)+4>>2]|0;if((L<<G|0)==0){Y=Z>>1;Ra=((ca(_,T-R|0)|0)/(R|0)|0)+(Y<<(C&1|4))|0;Sa=Y}else{Ra=da-_|0;Sa=Z>>1}_=((Ra&$)<<G)+(X&$)|0;Y=(c[(a+12208|0)>>2]|0)+((ca(Sa,ma<<3)|0)+(Z<<3&8))|0;if((C&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(da>>1,ma)|0)+(S>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((da&$)<<G)+(S&$)|0)<<2)>>2]&2047](Y,W,ma,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ra>>1,ma)|0)+(X>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(_<<2)>>2]&2047](Y,W,ma,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(da>>2,ma)|0)+(S>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((da&$)<<G)+(S&$)|0)<<2)>>2]&4095](Y,W,ma);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Ra>>2,ma)|0)+(X>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](Y,W,ma)}Z=Z+1|0;if((Z|0)>=4){break f}}}if((L<<G|0)==0){Z=0;do{U=(c[a+12160+(Z<<3)>>2]|0)+(M<<G)|0;W=c[a+12160+(Z<<3)+4>>2]|0;Y=U-(c[a+12128+(Z<<3)>>2]|0)|0;_=Z>>1;X=((ca(c[a+12128+(Z<<3)+4>>2]|0,T-R|0)|0)/(R|0)|0)+(_<<(C&1|4))|0;S=(c[(a+12208|0)>>2]|0)+((Z<<3&8)+(ca(_,ma<<3)|0))|0;if((C&1|0)==0){_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,ma)|0)+(U>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((W&$)<<G)+(U&$)|0)<<2)>>2]&2047](S,_,ma,8);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>1,ma)|0)+(Y>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((X&$)<<G)+(Y&$)|0)<<2)>>2]&2047](S,_,ma,8)}else{_=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>2,ma)|0)+(U>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(U&$)|0)<<2)>>2]&4095](S,_,ma);_=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>2,ma)|0)+(Y>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((X&$)<<G)+(Y&$)|0)<<2)>>2]&4095](S,_,ma)}Z=Z+1|0;}while((Z|0)<4)}else{Z=0;do{_=(c[a+12160+(Z<<3)>>2]|0)+(M<<G)|0;S=(c[a+12160+(Z<<3)+4>>2]|0)+(L<<G)|0;Y=_-(c[a+12128+(Z<<3)>>2]|0)|0;X=S-(c[a+12128+(Z<<3)+4>>2]|0)|0;U=(c[(a+12208|0)>>2]|0)+((Z<<3&8)+(ca(Z>>1,ma<<3)|0))|0;if((C&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,ma)|0)+(_>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&$)<<G)+(_&$)|0)<<2)>>2]&2047](U,W,ma,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>1,ma)|0)+(Y>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((X&$)<<G)+(Y&$)|0)<<2)>>2]&2047](U,W,ma,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,ma)|0)+(_>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&$)<<G)+(_&$)|0)<<2)>>2]&4095](U,W,ma);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(X>>2,ma)|0)+(Y>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((X&$)<<G)+(Y&$)|0)<<2)>>2]&4095](U,W,ma)}Z=Z+1|0;}while((Z|0)<4)}}else{Z=(c[a+12160>>2]|0)+(M<<G)|0;W=(c[a+12164>>2]|0)+(L<<G)|0;U=c[a+12128>>2]|0;if((M<<G|0)==0){Ta=(ca(U,T-R|0)|0)/(R|0)|0}else{Ta=Z-U|0}U=c[a+12132>>2]|0;if((L<<G|0)==0){Ua=(ca(U,T-R|0)|0)/(R|0)|0}else{Ua=W-U|0}U=((Ua&$)<<G)+(Ta&$)|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,ma)|0)+(Z>>1))|0;mf[c[(c[a+12444>>2]|0)+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Y,ma,16);Y=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Ua>>1,ma)|0)+(Ta>>1))|0;mf[c[(c[a+12448>>2]|0)+(U<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Y,ma,16);break}else{Y=(ca(W>>2,ma)|0)+(Z>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Y|0,ma);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Y+8|0)|0,ma);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ma<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Y+(ma<<3))|0,ma);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&$)<<G)+(Z&$)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Y+8|0)+(ma<<3))|0,ma);Y=(ca(Ua>>2,ma)|0)+(Ta>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Y|0,ma);ef[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Y+8|0)|0,ma);ef[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(ma<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Y+(ma<<3))|0,ma);ef[c[(c[(a+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Y+8|0)+(ma<<3))|0,ma);break}}}while(0);Qa=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(D+(((L<<3)+M&63)<<2)|0)>>2]=N;c[t+(((L<<3)+M&63)<<2)>>2]=Qa;$=(ca((d[z+((L<<G)-B)|0]|0)+(d[z+((M<<G)-A)|0]|0)|0,q)|0)+Qa|0;if(($|0)>=(Fa|0)){Na=Fa;Oa=Ga;Pa=Ha;break}c[(o|0)>>2]=M;c[p+4>>2]=L;Na=$;Oa=M;Pa=L}else{J=1}}if(J){J=0;if(1){$=c[(j+12|0)>>2]>>G;R=c[(j+8|0)>>2]>>G;T=R+K+($<<11)|0;do{if((c[(D+((($<<3)+R&63)<<2)|0)>>2]|0)==(T|0)){Va=1e6;Wa=0;Xa=0}else{do{if((C&4|0)==0){Y=c[a+12416>>2]|0;U=c[a+12420>>2]|0;Z=(c[a+12352+(l<<4)>>2]|0)+((ca(Y,$)|0)+R)|0;W=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,Z,Y,8)|0;if((C&2|0)==0){Ya=W;break}Z=c[a+12208>>2]|0;X=(ca(U,$>>1)|0)+(R>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&2047](Z+(Y<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+X|0,U,4);mf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&2047](Z+(Y<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+X|0,U,4);X=(Xe[I&511](a,Z+(Y<<4)|0,c[a+12288+(k<<4)+4>>2]|0,U,4)|0)+W|0;Ya=X+(Xe[I&511](a,Z+(Y<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,U,4)|0)|0}else{U=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(R|0)){Ya=536870912;break}if((R<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Ya=536870912;break}if((c[(a+12272|0)>>2]|0)>($|0)){Ya=536870912;break}if(($<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Ya=536870912;break}Y=e[a+13872>>1]|0;Z=e[a+13874>>1]|0;X=(C&1)<<1|1;g:do{if((c[a+11740>>2]|0)==1){if((R<<G|0)==0){W=0;while(1){_=c[a+12160+(W<<3)>>2]|0;S=(c[a+12160+(W<<3)+4>>2]|0)+($<<G)|0;da=((ca(c[a+12128+(W<<3)>>2]|0,Z-Y|0)|0)/(Y|0)|0)+((W&1)<<(C&1|4))|0;Za=c[a+12128+(W<<3)+4>>2]|0;if(($<<G|0)==0){_a=W>>1;$a=((ca(Za,Z-Y|0)|0)/(Y|0)|0)+(_a<<(C&1|4))|0;ab=_a}else{$a=S-Za|0;ab=W>>1}Za=(($a&X)<<G)+(da&X)|0;_a=(c[(a+12208|0)>>2]|0)+((ca(ab,U<<3)|0)+(W<<3&8))|0;if((C&1|0)==0){bb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,U)|0)+(_>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&X)<<G)+(_&X)|0)<<2)>>2]&2047](_a,bb,U,8);bb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($a>>1,U)|0)+(da>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Za<<2)>>2]&2047](_a,bb,U,8)}else{bb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,U)|0)+(_>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&X)<<G)+(_&X)|0)<<2)>>2]&4095](_a,bb,U);bb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($a>>2,U)|0)+(da>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095](_a,bb,U)}W=W+1|0;if((W|0)>=4){break g}}}if(($<<G|0)==0){W=0;do{bb=(c[a+12160+(W<<3)>>2]|0)+(R<<G)|0;_a=c[a+12160+(W<<3)+4>>2]|0;Za=bb-(c[a+12128+(W<<3)>>2]|0)|0;da=W>>1;_=((ca(c[a+12128+(W<<3)+4>>2]|0,Z-Y|0)|0)/(Y|0)|0)+(da<<(C&1|4))|0;S=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ca(da,U<<3)|0))|0;if((C&1|0)==0){da=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_a>>1,U)|0)+(bb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((_a&X)<<G)+(bb&X)|0)<<2)>>2]&2047](S,da,U,8);da=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>1,U)|0)+(Za>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((_&X)<<G)+(Za&X)|0)<<2)>>2]&2047](S,da,U,8)}else{da=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_a>>2,U)|0)+(bb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(bb&X)|0)<<2)>>2]&4095](S,da,U);da=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>2,U)|0)+(Za>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((_&X)<<G)+(Za&X)|0)<<2)>>2]&4095](S,da,U)}W=W+1|0;}while((W|0)<4)}else{W=0;do{da=(c[a+12160+(W<<3)>>2]|0)+(R<<G)|0;S=(c[a+12160+(W<<3)+4>>2]|0)+($<<G)|0;Za=da-(c[a+12128+(W<<3)>>2]|0)|0;_=S-(c[a+12128+(W<<3)+4>>2]|0)|0;bb=(c[(a+12208|0)>>2]|0)+((W<<3&8)+(ca(W>>1,U<<3)|0))|0;if((C&1|0)==0){_a=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>1,U)|0)+(da>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((S&X)<<G)+(da&X)|0)<<2)>>2]&2047](bb,_a,U,8);_a=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>1,U)|0)+(Za>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((_&X)<<G)+(Za&X)|0)<<2)>>2]&2047](bb,_a,U,8)}else{_a=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(S>>2,U)|0)+(da>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((S&X)<<G)+(da&X)|0)<<2)>>2]&4095](bb,_a,U);_a=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_>>2,U)|0)+(Za>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((_&X)<<G)+(Za&X)|0)<<2)>>2]&4095](bb,_a,U)}W=W+1|0;}while((W|0)<4)}}else{W=(c[a+12160>>2]|0)+(R<<G)|0;_a=(c[a+12164>>2]|0)+($<<G)|0;bb=c[a+12128>>2]|0;if((R<<G|0)==0){cb=(ca(bb,Z-Y|0)|0)/(Y|0)|0}else{cb=W-bb|0}bb=c[a+12132>>2]|0;if(($<<G|0)==0){db=(ca(bb,Z-Y|0)|0)/(Y|0)|0}else{db=_a-bb|0}bb=((db&X)<<G)+(cb&X)|0;if((C&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_a>>1,U)|0)+(W>>1))|0;mf[c[(c[a+12444>>2]|0)+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Za,U,16);Za=(c[a+12352+(l<<4)+32>>2]|0)+((ca(db>>1,U)|0)+(cb>>1))|0;mf[c[(c[a+12448>>2]|0)+(bb<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Za,U,16);break}else{Za=(ca(_a>>2,U)|0)+(W>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Za|0,U);ef[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Za+8|0)|0,U);ef[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(U<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Za+(U<<3))|0,U);ef[c[(c[(a+12452|0)>>2]|0)+64+((((_a&X)<<G)+(W&X)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((U<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Za+8|0)+(U<<3))|0,U);Za=(ca(db>>2,U)|0)+(cb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Za|0,U);ef[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Za+8|0)|0,U);ef[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(U<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Za+(U<<3))|0,U);ef[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((U<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Za+8|0)+(U<<3))|0,U);break}}}while(0);Ya=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,U,16)|0}}while(0);c[(D+((($<<3)+R&63)<<2)|0)>>2]=T;c[t+((($<<3)+R&63)<<2)>>2]=Ya;ma=c[(j+8|0)>>2]>>G;X=c[(j+12|0)>>2]>>G;Y=(ca((d[z+((X<<G)-B)|0]|0)+(d[z+((ma<<G)-A)|0]|0)|0,q)|0)+Ya|0;if((Y|0)>=1e6){Va=1e6;Wa=0;Xa=0;break}c[(o|0)>>2]=ma;c[p+4>>2]=X;Va=Y;Wa=ma;Xa=X}}while(0);R=(ca(b[m+(s<<2)>>1]|0,n)|0)+32768>>16;$=(ca(b[m+(s<<2)+2>>1]|0,n)|0)+32768>>16;T=(R|0)>(w|0)?w:R;R=(u|0)>(T|0)?u:T;T=($|0)>(y|0)?y:$;$=(v|0)>(T|0)?v:T;T=R+K+($<<11)|0;do{if((c[(D+((($<<3)+R&63)<<2)|0)>>2]|0)==(T|0)){eb=Va;fb=Wa;gb=Xa}else{do{if((C&4|0)==0){L=c[a+12416>>2]|0;M=c[a+12420>>2]|0;N=(c[a+12352+(l<<4)>>2]|0)+((ca(L,$)|0)+R)|0;X=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,N,L,8)|0;if((C&2|0)==0){hb=X;break}N=c[a+12208>>2]|0;ma=(ca(M,$>>1)|0)+(R>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&2047](N+(L<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+ma|0,M,4);mf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&2047](N+(L<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+ma|0,M,4);ma=(Xe[I&511](a,N+(L<<4)|0,c[a+12288+(k<<4)+4>>2]|0,M,4)|0)+X|0;hb=ma+(Xe[I&511](a,N+(L<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,M,4)|0)|0}else{M=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(R|0)){hb=536870912;break}if((R<<G|0)>(c[(a+12268|0)>>2]<<G|0)){hb=536870912;break}if((c[(a+12272|0)>>2]|0)>($|0)){hb=536870912;break}if(($<<G|0)>(c[(a+12276|0)>>2]<<G|0)){hb=536870912;break}L=e[a+13872>>1]|0;N=e[a+13874>>1]|0;ma=(C&1)<<1|1;h:do{if((c[a+11740>>2]|0)==1){if((R<<G|0)==0){X=0;while(1){Y=c[a+12160+(X<<3)>>2]|0;Z=(c[a+12160+(X<<3)+4>>2]|0)+($<<G)|0;Za=((ca(c[a+12128+(X<<3)>>2]|0,N-L|0)|0)/(L|0)|0)+((X&1)<<(C&1|4))|0;bb=c[a+12128+(X<<3)+4>>2]|0;if(($<<G|0)==0){W=X>>1;ib=((ca(bb,N-L|0)|0)/(L|0)|0)+(W<<(C&1|4))|0;jb=W}else{ib=Z-bb|0;jb=X>>1}bb=((ib&ma)<<G)+(Za&ma)|0;W=(c[(a+12208|0)>>2]|0)+((ca(jb,M<<3)|0)+(X<<3&8))|0;if((C&1|0)==0){_a=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>1,M)|0)+(Y>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&ma)<<G)+(Y&ma)|0)<<2)>>2]&2047](W,_a,M,8);_a=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ib>>1,M)|0)+(Za>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(bb<<2)>>2]&2047](W,_a,M,8)}else{_a=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>2,M)|0)+(Y>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&ma)<<G)+(Y&ma)|0)<<2)>>2]&4095](W,_a,M);_a=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ib>>2,M)|0)+(Za>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(bb<<2)>>2]&4095](W,_a,M)}X=X+1|0;if((X|0)>=4){break h}}}if(($<<G|0)==0){X=0;do{_a=(c[a+12160+(X<<3)>>2]|0)+(R<<G)|0;W=c[a+12160+(X<<3)+4>>2]|0;bb=_a-(c[a+12128+(X<<3)>>2]|0)|0;Za=X>>1;Y=((ca(c[a+12128+(X<<3)+4>>2]|0,N-L|0)|0)/(L|0)|0)+(Za<<(C&1|4))|0;Z=(c[(a+12208|0)>>2]|0)+((X<<3&8)+(ca(Za,M<<3)|0))|0;if((C&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,M)|0)+(_a>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((W&ma)<<G)+(_a&ma)|0)<<2)>>2]&2047](Z,Za,M,8);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Y>>1,M)|0)+(bb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((Y&ma)<<G)+(bb&ma)|0)<<2)>>2]&2047](Z,Za,M,8)}else{Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>2,M)|0)+(_a>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(_a&ma)|0)<<2)>>2]&4095](Z,Za,M);Za=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Y>>2,M)|0)+(bb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((Y&ma)<<G)+(bb&ma)|0)<<2)>>2]&4095](Z,Za,M)}X=X+1|0;}while((X|0)<4)}else{X=0;do{Za=(c[a+12160+(X<<3)>>2]|0)+(R<<G)|0;Z=(c[a+12160+(X<<3)+4>>2]|0)+($<<G)|0;bb=Za-(c[a+12128+(X<<3)>>2]|0)|0;Y=Z-(c[a+12128+(X<<3)+4>>2]|0)|0;_a=(c[(a+12208|0)>>2]|0)+((X<<3&8)+(ca(X>>1,M<<3)|0))|0;if((C&1|0)==0){W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>1,M)|0)+(Za>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&ma)<<G)+(Za&ma)|0)<<2)>>2]&2047](_a,W,M,8);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Y>>1,M)|0)+(bb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((Y&ma)<<G)+(bb&ma)|0)<<2)>>2]&2047](_a,W,M,8)}else{W=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>2,M)|0)+(Za>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&ma)<<G)+(Za&ma)|0)<<2)>>2]&4095](_a,W,M);W=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Y>>2,M)|0)+(bb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((Y&ma)<<G)+(bb&ma)|0)<<2)>>2]&4095](_a,W,M)}X=X+1|0;}while((X|0)<4)}}else{X=(c[a+12160>>2]|0)+(R<<G)|0;W=(c[a+12164>>2]|0)+($<<G)|0;_a=c[a+12128>>2]|0;if((R<<G|0)==0){kb=(ca(_a,N-L|0)|0)/(L|0)|0}else{kb=X-_a|0}_a=c[a+12132>>2]|0;if(($<<G|0)==0){lb=(ca(_a,N-L|0)|0)/(L|0)|0}else{lb=W-_a|0}_a=((lb&ma)<<G)+(kb&ma)|0;if((C&1|0)==0){bb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(W>>1,M)|0)+(X>>1))|0;mf[c[(c[a+12444>>2]|0)+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,bb,M,16);bb=(c[a+12352+(l<<4)+32>>2]|0)+((ca(lb>>1,M)|0)+(kb>>1))|0;mf[c[(c[a+12448>>2]|0)+(_a<<2)>>2]&2047](c[(a+12208|0)>>2]|0,bb,M,16);break}else{bb=(ca(W>>2,M)|0)+(X>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+bb|0,M);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(bb+8|0)|0,M);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(M<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(bb+(M<<3))|0,M);ef[c[(c[(a+12452|0)>>2]|0)+64+((((W&ma)<<G)+(X&ma)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((bb+8|0)+(M<<3))|0,M);bb=(ca(lb>>2,M)|0)+(kb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(_a<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+bb|0,M);ef[c[(c[(a+12456|0)>>2]|0)+64+(_a<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(bb+8|0)|0,M);ef[c[(c[(a+12456|0)>>2]|0)+64+(_a<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(M<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(bb+(M<<3))|0,M);ef[c[(c[(a+12456|0)>>2]|0)+64+(_a<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((bb+8|0)+(M<<3))|0,M);break}}}while(0);hb=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,M,16)|0}}while(0);c[(D+((($<<3)+R&63)<<2)|0)>>2]=T;c[t+((($<<3)+R&63)<<2)>>2]=hb;ma=(ca((d[z+(($<<G)-B)|0]|0)+(d[z+((R<<G)-A)|0]|0)|0,q)|0)+hb|0;if((ma|0)>=(Va|0)){eb=Va;fb=Wa;gb=Xa;break}c[(o|0)>>2]=R;c[p+4>>2]=$;eb=ma;fb=R;gb=$}}while(0);$=c[(j+76|0)>>2]>>G;R=c[(j+72|0)>>2]>>G;T=R+K+($<<11)|0;if((c[(D+((($<<3)+R&63)<<2)|0)>>2]|0)==(T|0)){Na=eb;Oa=fb;Pa=gb;break}do{if((C&4|0)==0){ma=c[a+12416>>2]|0;L=c[a+12420>>2]|0;N=(c[a+12352+(l<<4)>>2]|0)+((ca(ma,$)|0)+R)|0;U=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,N,ma,8)|0;if((C&2|0)==0){mb=U;break}N=c[a+12208>>2]|0;bb=(ca(L,$>>1)|0)+(R>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&2047](N+(ma<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+bb|0,L,4);mf[c[(c[(a+12444|0)>>2]|0)+32+(($<<1&2|R&1)<<2)>>2]&2047](N+(ma<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+bb|0,L,4);bb=(Xe[I&511](a,N+(ma<<4)|0,c[a+12288+(k<<4)+4>>2]|0,L,4)|0)+U|0;mb=bb+(Xe[I&511](a,N+(ma<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,L,4)|0)|0}else{L=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(R|0)){mb=536870912;break}if((R<<G|0)>(c[(a+12268|0)>>2]<<G|0)){mb=536870912;break}if((c[(a+12272|0)>>2]|0)>($|0)){mb=536870912;break}if(($<<G|0)>(c[(a+12276|0)>>2]<<G|0)){mb=536870912;break}ma=e[a+13872>>1]|0;N=e[a+13874>>1]|0;bb=(C&1)<<1|1;i:do{if((c[a+11740>>2]|0)==1){if((R<<G|0)==0){U=0;while(1){_a=c[a+12160+(U<<3)>>2]|0;X=(c[a+12160+(U<<3)+4>>2]|0)+($<<G)|0;W=((ca(c[a+12128+(U<<3)>>2]|0,N-ma|0)|0)/(ma|0)|0)+((U&1)<<(C&1|4))|0;Y=c[a+12128+(U<<3)+4>>2]|0;if(($<<G|0)==0){Za=U>>1;nb=((ca(Y,N-ma|0)|0)/(ma|0)|0)+(Za<<(C&1|4))|0;ob=Za}else{nb=X-Y|0;ob=U>>1}Y=((nb&bb)<<G)+(W&bb)|0;Za=(c[(a+12208|0)>>2]|0)+((ca(ob,L<<3)|0)+(U<<3&8))|0;if((C&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>1,L)|0)+(_a>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((X&bb)<<G)+(_a&bb)|0)<<2)>>2]&2047](Za,Z,L,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(nb>>1,L)|0)+(W>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Y<<2)>>2]&2047](Za,Z,L,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(X>>2,L)|0)+(_a>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((X&bb)<<G)+(_a&bb)|0)<<2)>>2]&4095](Za,Z,L);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(nb>>2,L)|0)+(W>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Y<<2)>>2]&4095](Za,Z,L)}U=U+1|0;if((U|0)>=4){break i}}}if(($<<G|0)==0){U=0;do{M=(c[a+12160+(U<<3)>>2]|0)+(R<<G)|0;Z=c[a+12160+(U<<3)+4>>2]|0;Za=M-(c[a+12128+(U<<3)>>2]|0)|0;Y=U>>1;W=((ca(c[a+12128+(U<<3)+4>>2]|0,N-ma|0)|0)/(ma|0)|0)+(Y<<(C&1|4))|0;_a=(c[(a+12208|0)>>2]|0)+((U<<3&8)+(ca(Y,L<<3)|0))|0;if((C&1|0)==0){Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>1,L)|0)+(M>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Z&bb)<<G)+(M&bb)|0)<<2)>>2]&2047](_a,Y,L,8);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>1,L)|0)+(Za>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((W&bb)<<G)+(Za&bb)|0)<<2)>>2]&2047](_a,Y,L,8)}else{Y=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>2,L)|0)+(M>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(M&bb)|0)<<2)>>2]&4095](_a,Y,L);Y=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>2,L)|0)+(Za>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((W&bb)<<G)+(Za&bb)|0)<<2)>>2]&4095](_a,Y,L)}U=U+1|0;}while((U|0)<4)}else{U=0;do{Y=(c[a+12160+(U<<3)>>2]|0)+(R<<G)|0;_a=(c[a+12160+(U<<3)+4>>2]|0)+($<<G)|0;Za=Y-(c[a+12128+(U<<3)>>2]|0)|0;W=_a-(c[a+12128+(U<<3)+4>>2]|0)|0;M=(c[(a+12208|0)>>2]|0)+((U<<3&8)+(ca(U>>1,L<<3)|0))|0;if((C&1|0)==0){Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_a>>1,L)|0)+(Y>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((_a&bb)<<G)+(Y&bb)|0)<<2)>>2]&2047](M,Z,L,8);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>1,L)|0)+(Za>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((W&bb)<<G)+(Za&bb)|0)<<2)>>2]&2047](M,Z,L,8)}else{Z=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(_a>>2,L)|0)+(Y>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((_a&bb)<<G)+(Y&bb)|0)<<2)>>2]&4095](M,Z,L);Z=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(W>>2,L)|0)+(Za>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((W&bb)<<G)+(Za&bb)|0)<<2)>>2]&4095](M,Z,L)}U=U+1|0;}while((U|0)<4)}}else{U=(c[a+12160>>2]|0)+(R<<G)|0;Z=(c[a+12164>>2]|0)+($<<G)|0;M=c[a+12128>>2]|0;if((R<<G|0)==0){pb=(ca(M,N-ma|0)|0)/(ma|0)|0}else{pb=U-M|0}M=c[a+12132>>2]|0;if(($<<G|0)==0){qb=(ca(M,N-ma|0)|0)/(ma|0)|0}else{qb=Z-M|0}M=((qb&bb)<<G)+(pb&bb)|0;if((C&1|0)==0){Za=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Z>>1,L)|0)+(U>>1))|0;mf[c[(c[a+12444>>2]|0)+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Za,L,16);Za=(c[a+12352+(l<<4)+32>>2]|0)+((ca(qb>>1,L)|0)+(pb>>1))|0;mf[c[(c[a+12448>>2]|0)+(M<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Za,L,16);break}else{Za=(ca(Z>>2,L)|0)+(U>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Za|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Za+8|0)|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Za+(L<<3))|0,L);ef[c[(c[(a+12452|0)>>2]|0)+64+((((Z&bb)<<G)+(U&bb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Za+8|0)+(L<<3))|0,L);Za=(ca(qb>>2,L)|0)+(pb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(M<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Za|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(M<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Za+8|0)|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(M<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(L<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Za+(L<<3))|0,L);ef[c[(c[(a+12456|0)>>2]|0)+64+(M<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((L<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Za+8|0)+(L<<3))|0,L);break}}}while(0);mb=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,L,16)|0}}while(0);c[(D+((($<<3)+R&63)<<2)|0)>>2]=T;c[t+((($<<3)+R&63)<<2)>>2]=mb;bb=c[(j+72|0)>>2]>>G;ma=c[(j+76|0)>>2]>>G;N=(ca((d[z+((ma<<G)-B)|0]|0)+(d[z+((bb<<G)-A)|0]|0)|0,q)|0)+mb|0;if((N|0)>=(eb|0)){Na=eb;Oa=fb;Pa=gb;break}c[(o|0)>>2]=bb;c[p+4>>2]=ma;Na=N;Oa=bb;Pa=ma}else{J=1}}}while(0);do{if((Na|0)>256){gb=(ca(b[m+((s+1|0)<<2)>>1]|0,n)|0)+32768>>16;fb=(ca(b[m+((s+1|0)<<2)+2>>1]|0,n)|0)+32768>>16;eb=(gb|0)>(w|0)?w:gb;gb=(u|0)>(eb|0)?u:eb;eb=(fb|0)>(y|0)?y:fb;fb=(v|0)>(eb|0)?v:eb;eb=gb+K+(fb<<11)|0;do{if((c[(D+(((fb<<3)+gb&63)<<2)|0)>>2]|0)==(eb|0)){rb=Na;sb=Oa;tb=Pa}else{do{if((C&4|0)==0){mb=c[a+12416>>2]|0;j=c[a+12420>>2]|0;pb=(c[a+12352+(l<<4)>>2]|0)+((ca(mb,fb)|0)+gb)|0;qb=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,pb,mb,8)|0;if((C&2|0)==0){ub=qb;break}pb=c[a+12208>>2]|0;nb=(ca(j,fb>>1)|0)+(gb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((fb<<1&2|gb&1)<<2)>>2]&2047](pb+(mb<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+nb|0,j,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((fb<<1&2|gb&1)<<2)>>2]&2047](pb+(mb<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+nb|0,j,4);nb=(Xe[I&511](a,pb+(mb<<4)|0,c[a+12288+(k<<4)+4>>2]|0,j,4)|0)+qb|0;ub=nb+(Xe[I&511](a,pb+(mb<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,j,4)|0)|0}else{j=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(gb|0)){ub=536870912;break}if((gb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){ub=536870912;break}if((c[(a+12272|0)>>2]|0)>(fb|0)){ub=536870912;break}if((fb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){ub=536870912;break}mb=e[a+13872>>1]|0;pb=e[a+13874>>1]|0;nb=(C&1)<<1|1;j:do{if((c[a+11740>>2]|0)==1){if((gb<<G|0)==0){qb=0;while(1){ob=c[a+12160+(qb<<3)>>2]|0;Xa=(c[a+12160+(qb<<3)+4>>2]|0)+(fb<<G)|0;Wa=((ca(c[a+12128+(qb<<3)>>2]|0,pb-mb|0)|0)/(mb|0)|0)+((qb&1)<<(C&1|4))|0;Va=c[a+12128+(qb<<3)+4>>2]|0;if((fb<<G|0)==0){hb=qb>>1;vb=((ca(Va,pb-mb|0)|0)/(mb|0)|0)+(hb<<(C&1|4))|0;wb=hb}else{vb=Xa-Va|0;wb=qb>>1}Va=((vb&nb)<<G)+(Wa&nb)|0;hb=(c[(a+12208|0)>>2]|0)+((ca(wb,j<<3)|0)+(qb<<3&8))|0;if((C&1|0)==0){kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Xa>>1,j)|0)+(ob>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Xa&nb)<<G)+(ob&nb)|0)<<2)>>2]&2047](hb,kb,j,8);kb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(vb>>1,j)|0)+(Wa>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Va<<2)>>2]&2047](hb,kb,j,8)}else{kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Xa>>2,j)|0)+(ob>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Xa&nb)<<G)+(ob&nb)|0)<<2)>>2]&4095](hb,kb,j);kb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(vb>>2,j)|0)+(Wa>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](hb,kb,j)}qb=qb+1|0;if((qb|0)>=4){break j}}}if((fb<<G|0)==0){qb=0;do{kb=(c[a+12160+(qb<<3)>>2]|0)+(gb<<G)|0;hb=c[a+12160+(qb<<3)+4>>2]|0;Va=kb-(c[a+12128+(qb<<3)>>2]|0)|0;Wa=qb>>1;ob=((ca(c[a+12128+(qb<<3)+4>>2]|0,pb-mb|0)|0)/(mb|0)|0)+(Wa<<(C&1|4))|0;Xa=(c[(a+12208|0)>>2]|0)+((qb<<3&8)+(ca(Wa,j<<3)|0))|0;if((C&1|0)==0){Wa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hb>>1,j)|0)+(kb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((hb&nb)<<G)+(kb&nb)|0)<<2)>>2]&2047](Xa,Wa,j,8);Wa=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>1,j)|0)+(Va>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&nb)<<G)+(Va&nb)|0)<<2)>>2]&2047](Xa,Wa,j,8)}else{Wa=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hb>>2,j)|0)+(kb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(kb&nb)|0)<<2)>>2]&4095](Xa,Wa,j);Wa=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>2,j)|0)+(Va>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ob&nb)<<G)+(Va&nb)|0)<<2)>>2]&4095](Xa,Wa,j)}qb=qb+1|0;}while((qb|0)<4)}else{qb=0;do{Wa=(c[a+12160+(qb<<3)>>2]|0)+(gb<<G)|0;Xa=(c[a+12160+(qb<<3)+4>>2]|0)+(fb<<G)|0;Va=Wa-(c[a+12128+(qb<<3)>>2]|0)|0;ob=Xa-(c[a+12128+(qb<<3)+4>>2]|0)|0;kb=(c[(a+12208|0)>>2]|0)+((qb<<3&8)+(ca(qb>>1,j<<3)|0))|0;if((C&1|0)==0){hb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Xa>>1,j)|0)+(Wa>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Xa&nb)<<G)+(Wa&nb)|0)<<2)>>2]&2047](kb,hb,j,8);hb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>1,j)|0)+(Va>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((ob&nb)<<G)+(Va&nb)|0)<<2)>>2]&2047](kb,hb,j,8)}else{hb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Xa>>2,j)|0)+(Wa>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Xa&nb)<<G)+(Wa&nb)|0)<<2)>>2]&4095](kb,hb,j);hb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(ob>>2,j)|0)+(Va>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((ob&nb)<<G)+(Va&nb)|0)<<2)>>2]&4095](kb,hb,j)}qb=qb+1|0;}while((qb|0)<4)}}else{qb=(c[a+12160>>2]|0)+(gb<<G)|0;hb=(c[a+12164>>2]|0)+(fb<<G)|0;kb=c[a+12128>>2]|0;if((gb<<G|0)==0){xb=(ca(kb,pb-mb|0)|0)/(mb|0)|0}else{xb=qb-kb|0}kb=c[a+12132>>2]|0;if((fb<<G|0)==0){yb=(ca(kb,pb-mb|0)|0)/(mb|0)|0}else{yb=hb-kb|0}kb=((yb&nb)<<G)+(xb&nb)|0;if((C&1|0)==0){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(hb>>1,j)|0)+(qb>>1))|0;mf[c[(c[a+12444>>2]|0)+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Va,j,16);Va=(c[a+12352+(l<<4)+32>>2]|0)+((ca(yb>>1,j)|0)+(xb>>1))|0;mf[c[(c[a+12448>>2]|0)+(kb<<2)>>2]&2047](c[(a+12208|0)>>2]|0,Va,j,16);break}else{Va=(ca(hb>>2,j)|0)+(qb>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+Va|0,j);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Va+8|0)|0,j);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(j<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(Va+(j<<3))|0,j);ef[c[(c[(a+12452|0)>>2]|0)+64+((((hb&nb)<<G)+(qb&nb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((j<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((Va+8|0)+(j<<3))|0,j);Va=(ca(yb>>2,j)|0)+(xb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+Va|0,j);ef[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Va+8|0)|0,j);ef[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(j<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(Va+(j<<3))|0,j);ef[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((j<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((Va+8|0)+(j<<3))|0,j);break}}}while(0);ub=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,j,16)|0}}while(0);c[(D+(((fb<<3)+gb&63)<<2)|0)>>2]=eb;c[t+(((fb<<3)+gb&63)<<2)>>2]=ub;L=(ca((d[z+((fb<<G)-B)|0]|0)+(d[z+((gb<<G)-A)|0]|0)|0,q)|0)+ub|0;if((L|0)>=(Na|0)){rb=Na;sb=Oa;tb=Pa;break}c[(o|0)>>2]=gb;c[p+4>>2]=fb;rb=L;sb=gb;tb=fb}}while(0);if(((c[(a+12480|0)>>2]|0)+1|0)>=(c[a+812>>2]|0)){zb=rb;Ab=sb;Bb=tb;break}fb=(ca(b[m+((s+r|0)<<2)>>1]|0,n)|0)+32768>>16;gb=(ca(b[m+((s+r|0)<<2)+2>>1]|0,n)|0)+32768>>16;eb=(fb|0)>(w|0)?w:fb;fb=(u|0)>(eb|0)?u:eb;eb=(gb|0)>(y|0)?y:gb;gb=(v|0)>(eb|0)?v:eb;eb=fb+K+(gb<<11)|0;if((c[(D+(((gb<<3)+fb&63)<<2)|0)>>2]|0)==(eb|0)){zb=rb;Ab=sb;Bb=tb;break}do{if((C&4|0)==0){J=c[a+12416>>2]|0;R=c[a+12420>>2]|0;$=(c[a+12352+(l<<4)>>2]|0)+((ca(J,gb)|0)+fb)|0;T=Xe[H&511](a,c[a+12288+(k<<4)>>2]|0,$,J,8)|0;if((C&2|0)==0){Cb=T;break}$=c[a+12208>>2]|0;L=(ca(R,gb>>1)|0)+(fb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((gb<<1&2|fb&1)<<2)>>2]&2047]($+(J<<4)|0,(c[a+12352+(l<<4)+4>>2]|0)+L|0,R,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((gb<<1&2|fb&1)<<2)>>2]&2047]($+(J<<4|8)|0,(c[a+12352+(l<<4)+8>>2]|0)+L|0,R,4);L=(Xe[I&511](a,$+(J<<4)|0,c[a+12288+(k<<4)+4>>2]|0,R,4)|0)+T|0;Cb=L+(Xe[I&511](a,$+(J<<4|8)|0,c[a+12288+(k<<4)+8>>2]|0,R,4)|0)|0}else{R=c[a+12416>>2]|0;if((c[(a+12264|0)>>2]|0)>(fb|0)){Cb=536870912;break}if((fb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Cb=536870912;break}if((c[(a+12272|0)>>2]|0)>(gb|0)){Cb=536870912;break}if((gb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Cb=536870912;break}J=e[a+13872>>1]|0;$=e[a+13874>>1]|0;L=(C&1)<<1|1;k:do{if((c[a+11740>>2]|0)==1){if((fb<<G|0)==0){T=0;while(1){nb=c[a+12160+(T<<3)>>2]|0;mb=(c[a+12160+(T<<3)+4>>2]|0)+(gb<<G)|0;pb=((ca(c[a+12128+(T<<3)>>2]|0,$-J|0)|0)/(J|0)|0)+((T&1)<<(C&1|4))|0;Va=c[a+12128+(T<<3)+4>>2]|0;if((gb<<G|0)==0){kb=T>>1;Db=((ca(Va,$-J|0)|0)/(J|0)|0)+(kb<<(C&1|4))|0;Eb=kb}else{Db=mb-Va|0;Eb=T>>1}Va=((Db&L)<<G)+(pb&L)|0;kb=(c[(a+12208|0)>>2]|0)+((ca(Eb,R<<3)|0)+(T<<3&8))|0;if((C&1|0)==0){qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mb>>1,R)|0)+(nb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((mb&L)<<G)+(nb&L)|0)<<2)>>2]&2047](kb,qb,R,8);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Db>>1,R)|0)+(pb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(Va<<2)>>2]&2047](kb,qb,R,8)}else{qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(mb>>2,R)|0)+(nb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((mb&L)<<G)+(nb&L)|0)<<2)>>2]&4095](kb,qb,R);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Db>>2,R)|0)+(pb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](kb,qb,R)}T=T+1|0;if((T|0)>=4){break k}}}if((gb<<G|0)==0){T=0;do{j=(c[a+12160+(T<<3)>>2]|0)+(fb<<G)|0;qb=c[a+12160+(T<<3)+4>>2]|0;kb=j-(c[a+12128+(T<<3)>>2]|0)|0;Va=T>>1;pb=((ca(c[a+12128+(T<<3)+4>>2]|0,$-J|0)|0)/(J|0)|0)+(Va<<(C&1|4))|0;nb=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ca(Va,R<<3)|0))|0;if((C&1|0)==0){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(qb>>1,R)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((qb&L)<<G)+(j&L)|0)<<2)>>2]&2047](nb,Va,R,8);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(pb>>1,R)|0)+(kb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((pb&L)<<G)+(kb&L)|0)<<2)>>2]&2047](nb,Va,R,8)}else{Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(qb>>2,R)|0)+(j>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(j&L)|0)<<2)>>2]&4095](nb,Va,R);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(pb>>2,R)|0)+(kb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((pb&L)<<G)+(kb&L)|0)<<2)>>2]&4095](nb,Va,R)}T=T+1|0;}while((T|0)<4)}else{T=0;do{Va=(c[a+12160+(T<<3)>>2]|0)+(fb<<G)|0;nb=(c[a+12160+(T<<3)+4>>2]|0)+(gb<<G)|0;kb=Va-(c[a+12128+(T<<3)>>2]|0)|0;pb=nb-(c[a+12128+(T<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((T<<3&8)+(ca(T>>1,R<<3)|0))|0;if((C&1|0)==0){qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(nb>>1,R)|0)+(Va>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((nb&L)<<G)+(Va&L)|0)<<2)>>2]&2047](j,qb,R,8);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(pb>>1,R)|0)+(kb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((pb&L)<<G)+(kb&L)|0)<<2)>>2]&2047](j,qb,R,8)}else{qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(nb>>2,R)|0)+(Va>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((nb&L)<<G)+(Va&L)|0)<<2)>>2]&4095](j,qb,R);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(pb>>2,R)|0)+(kb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((pb&L)<<G)+(kb&L)|0)<<2)>>2]&4095](j,qb,R)}T=T+1|0;}while((T|0)<4)}}else{T=(c[a+12160>>2]|0)+(fb<<G)|0;qb=(c[a+12164>>2]|0)+(gb<<G)|0;j=c[a+12128>>2]|0;if((fb<<G|0)==0){Fb=(ca(j,$-J|0)|0)/(J|0)|0}else{Fb=T-j|0}j=c[a+12132>>2]|0;if((gb<<G|0)==0){Gb=(ca(j,$-J|0)|0)/(J|0)|0}else{Gb=qb-j|0}j=((Gb&L)<<G)+(Fb&L)|0;if((C&1|0)==0){kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(qb>>1,R)|0)+(T>>1))|0;mf[c[(c[a+12444>>2]|0)+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,kb,R,16);kb=(c[a+12352+(l<<4)+32>>2]|0)+((ca(Gb>>1,R)|0)+(Fb>>1))|0;mf[c[(c[a+12448>>2]|0)+(j<<2)>>2]&2047](c[(a+12208|0)>>2]|0,kb,R,16);break}else{kb=(ca(qb>>2,R)|0)+(T>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+kb|0,R);ef[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kb+8|0)|0,R);ef[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(R<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(kb+(R<<3))|0,R);ef[c[(c[(a+12452|0)>>2]|0)+64+((((qb&L)<<G)+(T&L)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((kb+8|0)+(R<<3))|0,R);kb=(ca(Gb>>2,R)|0)+(Fb>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+kb|0,R);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kb+8|0)|0,R);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(R<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(kb+(R<<3))|0,R);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((kb+8|0)+(R<<3))|0,R);break}}}while(0);Cb=Xe[H&511](a,c[a+12208>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,R,16)|0}}while(0);c[(D+(((gb<<3)+fb&63)<<2)|0)>>2]=eb;c[t+(((gb<<3)+fb&63)<<2)>>2]=Cb;L=(ca((d[z+((gb<<G)-B)|0]|0)+(d[z+((fb<<G)-A)|0]|0)|0,q)|0)+Cb|0;if((L|0)>=(rb|0)){zb=rb;Ab=sb;Bb=tb;break}c[(o|0)>>2]=fb;c[p+4>>2]=gb;zb=L;Ab=fb;Bb=gb}else{zb=Na;Ab=Oa;Bb=Pa}}while(0);Pa=o|0;Oa=c[(a+12260|0)>>2]|0;if((Oa|0)==-1){Na=c[(a+12220|0)>>2]|0;tb=c[(a+12264|0)>>2]|0;sb=c[(a+12272|0)>>2]|0;rb=c[(a+12268|0)>>2]|0;Cb=c[(a+12276|0)>>2]|0;A=c[(a+12464|0)>>2]|0;z=c[(a+12280|0)>>2]|0;B=c[(a+12284|0)>>2]|0;t=c[(a+12216|0)>>2]|0;D=c[(a+12224|0)>>2]|0;H=c[(a+10472|0)>>2]|0;Fb=c[(a+10476|0)>>2]|0;Gb=(C&1)<<1|1;Db=C&1|4;Eb=(C&1|0)==0;I=zb;K=Ab;v=Bb;y=Ab;l:while(1){u=1;w=I;n=v;r=y;while(1){do{if((u-1&u|0)==0){s=u+K|0;if((s|0)>(rb|0)){Hb=w;Ib=n;Jb=r;break}m=K-u|0;if((m|0)<(tb|0)){Hb=w;Ib=n;Jb=r;break}ub=u+v|0;if((ub|0)>(Cb|0)){Hb=w;Ib=n;Jb=r;break}xb=v-u|0;if((xb|0)<(sb|0)){Hb=w;Ib=n;Jb=r;break}else{Kb=0;Lb=w;Mb=n;Nb=r}while(1){yb=ub-Kb|0;vb=Kb+K|0;do{if((c[(t+(((yb<<3)+vb&63)<<2)|0)>>2]|0)==(vb+D+(yb<<11)|0|0)){Ob=Lb;Pb=Mb;Qb=Nb}else{wb=c[(a+12416|0)>>2]|0;do{if((C&4|0)==0){L=c[(a+12420|0)>>2]|0;J=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(wb,yb)|0)+vb)|0;$=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,J,wb,8)|0;if((C&2|0)==0){Rb=$;break}J=c[(a+12208|0)>>2]|0;kb=(ca(L,yb>>1)|0)+(vb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((yb<<1&2|vb&1)<<2)>>2]&2047](J+(wb<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+kb|0,L,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((yb<<1&2|vb&1)<<2)>>2]&2047](J+(wb<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+kb|0,L,4);kb=(Xe[Fb&511](a,J+(wb<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,L,4)|0)+$|0;Rb=kb+(Xe[Fb&511](a,J+(wb<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,L,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(vb|0)){Rb=536870912;break}if((vb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Rb=536870912;break}if((c[(a+12272|0)>>2]|0)>(yb|0)){Rb=536870912;break}if((yb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Rb=536870912;break}L=e[(a+13872|0)>>1]|0;J=e[(a+13874|0)>>1]|0;m:do{if((c[(a+11740|0)>>2]|0)==1){if((vb<<G|0)==0){kb=0;while(1){$=c[a+12160+(kb<<3)>>2]|0;j=(c[a+12160+(kb<<3)+4>>2]|0)+(yb<<G)|0;T=((ca(c[a+12128+(kb<<3)>>2]|0,J-L|0)|0)/(L|0)|0)+((kb&1)<<Db)|0;qb=c[a+12128+(kb<<3)+4>>2]|0;if((yb<<G|0)==0){pb=kb>>1;Sb=((ca(qb,J-L|0)|0)/(L|0)|0)+(pb<<Db)|0;Tb=pb}else{Sb=j-qb|0;Tb=kb>>1}qb=((Sb&Gb)<<G)+(T&Gb)|0;pb=(c[(a+12208|0)>>2]|0)+((ca(Tb,wb<<3)|0)+(kb<<3&8))|0;if(Eb){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>1,wb)|0)+($>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Gb)<<G)+($&Gb)|0)<<2)>>2]&2047](pb,Va,wb,8);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Sb>>1,wb)|0)+(T>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(qb<<2)>>2]&2047](pb,Va,wb,8)}else{Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>2,wb)|0)+($>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((j&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](pb,Va,wb);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Sb>>2,wb)|0)+(T>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(qb<<2)>>2]&4095](pb,Va,wb)}kb=kb+1|0;if((kb|0)>=4){break m}}}if((yb<<G|0)==0){kb=0;do{Va=(c[a+12160+(kb<<3)>>2]|0)+(vb<<G)|0;pb=c[a+12160+(kb<<3)+4>>2]|0;qb=Va-(c[a+12128+(kb<<3)>>2]|0)|0;T=kb>>1;$=((ca(c[a+12128+(kb<<3)+4>>2]|0,J-L|0)|0)/(L|0)|0)+(T<<Db)|0;j=(c[(a+12208|0)>>2]|0)+((kb<<3&8)+(ca(T,wb<<3)|0))|0;if(Eb){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,wb)|0)+(Va>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&2047](j,T,wb,8);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>1,wb)|0)+(qb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&2047](j,T,wb,8)}else{T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>2,wb)|0)+(Va>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095](j,T,wb);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>2,wb)|0)+(qb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](j,T,wb)}kb=kb+1|0;}while((kb|0)<4)}else{kb=0;do{T=(c[a+12160+(kb<<3)>>2]|0)+(vb<<G)|0;j=(c[a+12160+(kb<<3)+4>>2]|0)+(yb<<G)|0;qb=T-(c[a+12128+(kb<<3)>>2]|0)|0;$=j-(c[a+12128+(kb<<3)+4>>2]|0)|0;Va=(c[(a+12208|0)>>2]|0)+((kb<<3&8)+(ca(kb>>1,wb<<3)|0))|0;if(Eb){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>1,wb)|0)+(T>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Gb)<<G)+(T&Gb)|0)<<2)>>2]&2047](Va,pb,wb,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>1,wb)|0)+(qb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&2047](Va,pb,wb,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>2,wb)|0)+(T>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((j&Gb)<<G)+(T&Gb)|0)<<2)>>2]&4095](Va,pb,wb);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>2,wb)|0)+(qb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](Va,pb,wb)}kb=kb+1|0;}while((kb|0)<4)}}else{kb=(c[(a+12160|0)>>2]|0)+(vb<<G)|0;pb=(c[(a+12164|0)>>2]|0)+(yb<<G)|0;Va=c[(a+12128|0)>>2]|0;if((vb<<G|0)==0){Ub=(ca(Va,J-L|0)|0)/(L|0)|0}else{Ub=kb-Va|0}Va=c[(a+12132|0)>>2]|0;if((yb<<G|0)==0){Vb=(ca(Va,J-L|0)|0)/(L|0)|0}else{Vb=pb-Va|0}Va=((Vb&Gb)<<G)+(Ub&Gb)|0;if(Eb){qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,wb)|0)+(kb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,qb,wb,16);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(Vb>>1,wb)|0)+(Ub>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+(Va<<2)>>2]&2047](c[(a+12208|0)>>2]|0,qb,wb,16);break}else{qb=(ca(pb>>2,wb)|0)+(kb>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+qb|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(qb+8|0)|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(qb+(wb<<3))|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((qb+8|0)+(wb<<3))|0,wb);qb=(ca(Vb>>2,wb)|0)+(Ub>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+qb|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(qb+8|0)|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(qb+(wb<<3))|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((qb+8|0)+(wb<<3))|0,wb);break}}}while(0);Rb=Xe[H&511](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,wb,16)|0}}while(0);c[(t+(((yb<<3)+vb&63)<<2)|0)>>2]=vb+D+(yb<<11)|0;c[Na+(((yb<<3)+vb&63)<<2)>>2]=Rb;wb=(ca((d[A+((yb<<G)-B)|0]|0)+(d[A+((vb<<G)-z)|0]|0)|0,q)|0)+Rb|0;if((wb|0)>=(Lb|0)){Ob=Lb;Pb=Mb;Qb=Nb;break}c[Pa>>2]=vb;c[(Pa+4|0)>>2]=yb;Ob=wb;Pb=yb;Qb=vb}}while(0);vb=v-Kb|0;yb=s-Kb|0;do{if((c[(t+(((vb<<3)+yb&63)<<2)|0)>>2]|0)==(yb+D+(vb<<11)|0|0)){Wb=Ob;Xb=Pb;Yb=Qb}else{wb=c[(a+12416|0)>>2]|0;do{if((C&4|0)==0){L=c[(a+12420|0)>>2]|0;J=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(wb,vb)|0)+yb)|0;qb=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,J,wb,8)|0;if((C&2|0)==0){Zb=qb;break}J=c[(a+12208|0)>>2]|0;Va=(ca(L,vb>>1)|0)+(yb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((vb<<1&2|yb&1)<<2)>>2]&2047](J+(wb<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+Va|0,L,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((vb<<1&2|yb&1)<<2)>>2]&2047](J+(wb<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+Va|0,L,4);Va=(Xe[Fb&511](a,J+(wb<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,L,4)|0)+qb|0;Zb=Va+(Xe[Fb&511](a,J+(wb<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,L,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(yb|0)){Zb=536870912;break}if((yb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){Zb=536870912;break}if((c[(a+12272|0)>>2]|0)>(vb|0)){Zb=536870912;break}if((vb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){Zb=536870912;break}L=e[(a+13872|0)>>1]|0;J=e[(a+13874|0)>>1]|0;n:do{if((c[(a+11740|0)>>2]|0)==1){if((yb<<G|0)==0){Va=0;while(1){qb=c[a+12160+(Va<<3)>>2]|0;kb=(c[a+12160+(Va<<3)+4>>2]|0)+(vb<<G)|0;pb=((ca(c[a+12128+(Va<<3)>>2]|0,J-L|0)|0)/(L|0)|0)+((Va&1)<<Db)|0;$=c[a+12128+(Va<<3)+4>>2]|0;if((vb<<G|0)==0){T=Va>>1;_b=((ca($,J-L|0)|0)/(L|0)|0)+(T<<Db)|0;$b=T}else{_b=kb-$|0;$b=Va>>1}$=((_b&Gb)<<G)+(pb&Gb)|0;T=(c[(a+12208|0)>>2]|0)+((ca($b,wb<<3)|0)+(Va<<3&8))|0;if(Eb){j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kb>>1,wb)|0)+(qb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((kb&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&2047](T,j,wb,8);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_b>>1,wb)|0)+(pb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+($<<2)>>2]&2047](T,j,wb,8)}else{j=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kb>>2,wb)|0)+(qb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((kb&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](T,j,wb);j=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(_b>>2,wb)|0)+(pb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095](T,j,wb)}Va=Va+1|0;if((Va|0)>=4){break n}}}if((vb<<G|0)==0){Va=0;do{j=(c[a+12160+(Va<<3)>>2]|0)+(yb<<G)|0;T=c[a+12160+(Va<<3)+4>>2]|0;$=j-(c[a+12128+(Va<<3)>>2]|0)|0;pb=Va>>1;qb=((ca(c[a+12128+(Va<<3)+4>>2]|0,J-L|0)|0)/(L|0)|0)+(pb<<Db)|0;kb=(c[(a+12208|0)>>2]|0)+((Va<<3&8)+(ca(pb,wb<<3)|0))|0;if(Eb){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(T>>1,wb)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((T&Gb)<<G)+(j&Gb)|0)<<2)>>2]&2047](kb,pb,wb,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qb>>1,wb)|0)+($>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&2047](kb,pb,wb,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(T>>2,wb)|0)+(j>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095](kb,pb,wb);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qb>>2,wb)|0)+($>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](kb,pb,wb)}Va=Va+1|0;}while((Va|0)<4)}else{Va=0;do{pb=(c[a+12160+(Va<<3)>>2]|0)+(yb<<G)|0;kb=(c[a+12160+(Va<<3)+4>>2]|0)+(vb<<G)|0;$=pb-(c[a+12128+(Va<<3)>>2]|0)|0;qb=kb-(c[a+12128+(Va<<3)+4>>2]|0)|0;j=(c[(a+12208|0)>>2]|0)+((Va<<3&8)+(ca(Va>>1,wb<<3)|0))|0;if(Eb){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kb>>1,wb)|0)+(pb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((kb&Gb)<<G)+(pb&Gb)|0)<<2)>>2]&2047](j,T,wb,8);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qb>>1,wb)|0)+($>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&2047](j,T,wb,8)}else{T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(kb>>2,wb)|0)+(pb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((kb&Gb)<<G)+(pb&Gb)|0)<<2)>>2]&4095](j,T,wb);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qb>>2,wb)|0)+($>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](j,T,wb)}Va=Va+1|0;}while((Va|0)<4)}}else{Va=(c[(a+12160|0)>>2]|0)+(yb<<G)|0;T=(c[(a+12164|0)>>2]|0)+(vb<<G)|0;j=c[(a+12128|0)>>2]|0;if((yb<<G|0)==0){ac=(ca(j,J-L|0)|0)/(L|0)|0}else{ac=Va-j|0}j=c[(a+12132|0)>>2]|0;if((vb<<G|0)==0){bc=(ca(j,J-L|0)|0)/(L|0)|0}else{bc=T-j|0}j=((bc&Gb)<<G)+(ac&Gb)|0;if(Eb){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(T>>1,wb)|0)+(Va>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,$,wb,16);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(bc>>1,wb)|0)+(ac>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+(j<<2)>>2]&2047](c[(a+12208|0)>>2]|0,$,wb,16);break}else{$=(ca(T>>2,wb)|0)+(Va>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+$|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+8|0)|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+(wb<<3))|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(($+8|0)+(wb<<3))|0,wb);$=(ca(bc>>2,wb)|0)+(ac>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+$|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+8|0)|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+(wb<<3))|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(j<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(($+8|0)+(wb<<3))|0,wb);break}}}while(0);Zb=Xe[H&511](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,wb,16)|0}}while(0);c[(t+(((vb<<3)+yb&63)<<2)|0)>>2]=yb+D+(vb<<11)|0;c[Na+(((vb<<3)+yb&63)<<2)>>2]=Zb;wb=(ca((d[A+((vb<<G)-B)|0]|0)+(d[A+((yb<<G)-z)|0]|0)|0,q)|0)+Zb|0;if((wb|0)>=(Ob|0)){Wb=Ob;Xb=Pb;Yb=Qb;break}c[Pa>>2]=yb;c[(Pa+4|0)>>2]=vb;Wb=wb;Xb=vb;Yb=yb}}while(0);yb=Kb+xb|0;vb=K-Kb|0;do{if((c[(t+(((yb<<3)+vb&63)<<2)|0)>>2]|0)==(vb+D+(yb<<11)|0|0)){cc=Wb;dc=Xb;ec=Yb}else{wb=c[(a+12416|0)>>2]|0;do{if((C&4|0)==0){L=c[(a+12420|0)>>2]|0;J=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(wb,yb)|0)+vb)|0;$=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,J,wb,8)|0;if((C&2|0)==0){fc=$;break}J=c[(a+12208|0)>>2]|0;j=(ca(L,yb>>1)|0)+(vb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((yb<<1&2|vb&1)<<2)>>2]&2047](J+(wb<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+j|0,L,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((yb<<1&2|vb&1)<<2)>>2]&2047](J+(wb<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+j|0,L,4);j=(Xe[Fb&511](a,J+(wb<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,L,4)|0)+$|0;fc=j+(Xe[Fb&511](a,J+(wb<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,L,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(vb|0)){fc=536870912;break}if((vb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){fc=536870912;break}if((c[(a+12272|0)>>2]|0)>(yb|0)){fc=536870912;break}if((yb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){fc=536870912;break}L=e[(a+13872|0)>>1]|0;J=e[(a+13874|0)>>1]|0;o:do{if((c[(a+11740|0)>>2]|0)==1){if((vb<<G|0)==0){j=0;while(1){$=c[a+12160+(j<<3)>>2]|0;Va=(c[a+12160+(j<<3)+4>>2]|0)+(yb<<G)|0;T=((ca(c[a+12128+(j<<3)>>2]|0,J-L|0)|0)/(L|0)|0)+((j&1)<<Db)|0;qb=c[a+12128+(j<<3)+4>>2]|0;if((yb<<G|0)==0){pb=j>>1;gc=((ca(qb,J-L|0)|0)/(L|0)|0)+(pb<<Db)|0;hc=pb}else{gc=Va-qb|0;hc=j>>1}qb=((gc&Gb)<<G)+(T&Gb)|0;pb=(c[(a+12208|0)>>2]|0)+((ca(hc,wb<<3)|0)+(j<<3&8))|0;if(Eb){kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Va>>1,wb)|0)+($>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Va&Gb)<<G)+($&Gb)|0)<<2)>>2]&2047](pb,kb,wb,8);kb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(gc>>1,wb)|0)+(T>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(qb<<2)>>2]&2047](pb,kb,wb,8)}else{kb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Va>>2,wb)|0)+($>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Va&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](pb,kb,wb);kb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(gc>>2,wb)|0)+(T>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(qb<<2)>>2]&4095](pb,kb,wb)}j=j+1|0;if((j|0)>=4){break o}}}if((yb<<G|0)==0){j=0;do{kb=(c[a+12160+(j<<3)>>2]|0)+(vb<<G)|0;pb=c[a+12160+(j<<3)+4>>2]|0;qb=kb-(c[a+12128+(j<<3)>>2]|0)|0;T=j>>1;$=((ca(c[a+12128+(j<<3)+4>>2]|0,J-L|0)|0)/(L|0)|0)+(T<<Db)|0;Va=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ca(T,wb<<3)|0))|0;if(Eb){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,wb)|0)+(kb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&2047](Va,T,wb,8);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>1,wb)|0)+(qb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&2047](Va,T,wb,8)}else{T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>2,wb)|0)+(kb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095](Va,T,wb);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>2,wb)|0)+(qb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](Va,T,wb)}j=j+1|0;}while((j|0)<4)}else{j=0;do{T=(c[a+12160+(j<<3)>>2]|0)+(vb<<G)|0;Va=(c[a+12160+(j<<3)+4>>2]|0)+(yb<<G)|0;qb=T-(c[a+12128+(j<<3)>>2]|0)|0;$=Va-(c[a+12128+(j<<3)+4>>2]|0)|0;kb=(c[(a+12208|0)>>2]|0)+((j<<3&8)+(ca(j>>1,wb<<3)|0))|0;if(Eb){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Va>>1,wb)|0)+(T>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((Va&Gb)<<G)+(T&Gb)|0)<<2)>>2]&2047](kb,pb,wb,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>1,wb)|0)+(qb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&2047](kb,pb,wb,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(Va>>2,wb)|0)+(T>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((Va&Gb)<<G)+(T&Gb)|0)<<2)>>2]&4095](kb,pb,wb);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca($>>2,wb)|0)+(qb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(((($&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](kb,pb,wb)}j=j+1|0;}while((j|0)<4)}}else{j=(c[(a+12160|0)>>2]|0)+(vb<<G)|0;pb=(c[(a+12164|0)>>2]|0)+(yb<<G)|0;kb=c[(a+12128|0)>>2]|0;if((vb<<G|0)==0){ic=(ca(kb,J-L|0)|0)/(L|0)|0}else{ic=j-kb|0}kb=c[(a+12132|0)>>2]|0;if((yb<<G|0)==0){jc=(ca(kb,J-L|0)|0)/(L|0)|0}else{jc=pb-kb|0}kb=((jc&Gb)<<G)+(ic&Gb)|0;if(Eb){qb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(pb>>1,wb)|0)+(j>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,qb,wb,16);qb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(jc>>1,wb)|0)+(ic>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+(kb<<2)>>2]&2047](c[(a+12208|0)>>2]|0,qb,wb,16);break}else{qb=(ca(pb>>2,wb)|0)+(j>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+qb|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(qb+8|0)|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(qb+(wb<<3))|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((pb&Gb)<<G)+(j&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+((qb+8|0)+(wb<<3))|0,wb);qb=(ca(jc>>2,wb)|0)+(ic>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+qb|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(qb+8|0)|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(qb+(wb<<3))|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(kb<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+((qb+8|0)+(wb<<3))|0,wb);break}}}while(0);fc=Xe[H&511](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,wb,16)|0}}while(0);c[(t+(((yb<<3)+vb&63)<<2)|0)>>2]=vb+D+(yb<<11)|0;c[Na+(((yb<<3)+vb&63)<<2)>>2]=fc;wb=(ca((d[A+((yb<<G)-B)|0]|0)+(d[A+((vb<<G)-z)|0]|0)|0,q)|0)+fc|0;if((wb|0)>=(Wb|0)){cc=Wb;dc=Xb;ec=Yb;break}c[Pa>>2]=vb;c[(Pa+4|0)>>2]=yb;cc=wb;dc=yb;ec=vb}}while(0);vb=Kb+v|0;yb=Kb+m|0;do{if((c[(t+(((vb<<3)+yb&63)<<2)|0)>>2]|0)==(yb+D+(vb<<11)|0|0)){kc=cc;lc=dc;mc=ec}else{wb=c[(a+12416|0)>>2]|0;do{if((C&4|0)==0){L=c[(a+12420|0)>>2]|0;J=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(wb,vb)|0)+yb)|0;qb=Xe[H&511](a,c[(a+12288+(k<<4)|0)>>2]|0,J,wb,8)|0;if((C&2|0)==0){nc=qb;break}J=c[(a+12208|0)>>2]|0;kb=(ca(L,vb>>1)|0)+(yb>>1)|0;mf[c[(c[(a+12444|0)>>2]|0)+32+((vb<<1&2|yb&1)<<2)>>2]&2047](J+(wb<<4)|0,(c[(a+12352+(l<<4)+4|0)>>2]|0)+kb|0,L,4);mf[c[(c[(a+12444|0)>>2]|0)+32+((vb<<1&2|yb&1)<<2)>>2]&2047](J+(wb<<4|8)|0,(c[(a+12352+(l<<4)+8|0)>>2]|0)+kb|0,L,4);kb=(Xe[Fb&511](a,J+(wb<<4)|0,c[(a+12288+(k<<4)+4|0)>>2]|0,L,4)|0)+qb|0;nc=kb+(Xe[Fb&511](a,J+(wb<<4|8)|0,c[(a+12288+(k<<4)+8|0)>>2]|0,L,4)|0)|0}else{if((c[(a+12264|0)>>2]|0)>(yb|0)){nc=536870912;break}if((yb<<G|0)>(c[(a+12268|0)>>2]<<G|0)){nc=536870912;break}if((c[(a+12272|0)>>2]|0)>(vb|0)){nc=536870912;break}if((vb<<G|0)>(c[(a+12276|0)>>2]<<G|0)){nc=536870912;break}L=e[(a+13872|0)>>1]|0;J=e[(a+13874|0)>>1]|0;p:do{if((c[(a+11740|0)>>2]|0)==1){if((yb<<G|0)==0){kb=0;while(1){qb=c[a+12160+(kb<<3)>>2]|0;j=(c[a+12160+(kb<<3)+4>>2]|0)+(vb<<G)|0;pb=((ca(c[a+12128+(kb<<3)>>2]|0,J-L|0)|0)/(L|0)|0)+((kb&1)<<Db)|0;$=c[a+12128+(kb<<3)+4>>2]|0;if((vb<<G|0)==0){T=kb>>1;oc=((ca($,J-L|0)|0)/(L|0)|0)+(T<<Db)|0;pc=T}else{oc=j-$|0;pc=kb>>1}$=((oc&Gb)<<G)+(pb&Gb)|0;T=(c[(a+12208|0)>>2]|0)+((ca(pc,wb<<3)|0)+(kb<<3&8))|0;if(Eb){Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>1,wb)|0)+(qb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&2047](T,Va,wb,8);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(oc>>1,wb)|0)+(pb>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+($<<2)>>2]&2047](T,Va,wb,8)}else{Va=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>2,wb)|0)+(qb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((j&Gb)<<G)+(qb&Gb)|0)<<2)>>2]&4095](T,Va,wb);Va=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(oc>>2,wb)|0)+(pb>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+($<<2)>>2]&4095](T,Va,wb)}kb=kb+1|0;if((kb|0)>=4){break p}}}if((vb<<G|0)==0){kb=0;do{Va=(c[a+12160+(kb<<3)>>2]|0)+(yb<<G)|0;T=c[a+12160+(kb<<3)+4>>2]|0;$=Va-(c[a+12128+(kb<<3)>>2]|0)|0;pb=kb>>1;qb=((ca(c[a+12128+(kb<<3)+4>>2]|0,J-L|0)|0)/(L|0)|0)+(pb<<Db)|0;j=(c[(a+12208|0)>>2]|0)+((kb<<3&8)+(ca(pb,wb<<3)|0))|0;if(Eb){pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(T>>1,wb)|0)+(Va>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&2047](j,pb,wb,8);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qb>>1,wb)|0)+($>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&2047](j,pb,wb,8)}else{pb=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(T>>2,wb)|0)+(Va>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(Va&Gb)|0)<<2)>>2]&4095](j,pb,wb);pb=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qb>>2,wb)|0)+($>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](j,pb,wb)}kb=kb+1|0;}while((kb|0)<4)}else{kb=0;do{pb=(c[a+12160+(kb<<3)>>2]|0)+(yb<<G)|0;j=(c[a+12160+(kb<<3)+4>>2]|0)+(vb<<G)|0;$=pb-(c[a+12128+(kb<<3)>>2]|0)|0;qb=j-(c[a+12128+(kb<<3)+4>>2]|0)|0;Va=(c[(a+12208|0)>>2]|0)+((kb<<3&8)+(ca(kb>>1,wb<<3)|0))|0;if(Eb){T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>1,wb)|0)+(pb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+16+((((j&Gb)<<G)+(pb&Gb)|0)<<2)>>2]&2047](Va,T,wb,8);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qb>>1,wb)|0)+($>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+16+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&2047](Va,T,wb,8)}else{T=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(j>>2,wb)|0)+(pb>>2))|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((j&Gb)<<G)+(pb&Gb)|0)<<2)>>2]&4095](Va,T,wb);T=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(qb>>2,wb)|0)+($>>2))|0;ef[c[(c[(a+12456|0)>>2]|0)+64+((((qb&Gb)<<G)+($&Gb)|0)<<2)>>2]&4095](Va,T,wb)}kb=kb+1|0;}while((kb|0)<4)}}else{kb=(c[(a+12160|0)>>2]|0)+(yb<<G)|0;T=(c[(a+12164|0)>>2]|0)+(vb<<G)|0;Va=c[(a+12128|0)>>2]|0;if((yb<<G|0)==0){qc=(ca(Va,J-L|0)|0)/(L|0)|0}else{qc=kb-Va|0}Va=c[(a+12132|0)>>2]|0;if((vb<<G|0)==0){rc=(ca(Va,J-L|0)|0)/(L|0)|0}else{rc=T-Va|0}Va=((rc&Gb)<<G)+(qc&Gb)|0;if(Eb){$=(c[(a+12352+(l<<4)|0)>>2]|0)+((ca(T>>1,wb)|0)+(kb>>1))|0;mf[c[(c[(a+12444|0)>>2]|0)+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&2047](c[(a+12208|0)>>2]|0,$,wb,16);$=(c[(a+12352+(l<<4)+32|0)>>2]|0)+((ca(rc>>1,wb)|0)+(qc>>1))|0;mf[c[(c[(a+12448|0)>>2]|0)+(Va<<2)>>2]&2047](c[(a+12208|0)>>2]|0,$,wb,16);break}else{$=(ca(T>>2,wb)|0)+(kb>>2)|0;ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)|0)>>2]|0)+$|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+8|0)|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+($+(wb<<3))|0,wb);ef[c[(c[(a+12452|0)>>2]|0)+64+((((T&Gb)<<G)+(kb&Gb)|0)<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)|0)>>2]|0)+(($+8|0)+(wb<<3))|0,wb);$=(ca(rc>>2,wb)|0)+(qc>>2)|0;ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](c[(a+12208|0)>>2]|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+$|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+8|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+8|0)|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+(wb<<3)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+($+(wb<<3))|0,wb);ef[c[(c[(a+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095]((c[(a+12208|0)>>2]|0)+((wb<<3)+8|0)|0,(c[(a+12352+(l<<4)+32|0)>>2]|0)+(($+8|0)+(wb<<3))|0,wb);break}}}while(0);nc=Xe[H&511](a,c[(a+12208|0)>>2]|0,c[(a+12288+(k<<4)|0)>>2]|0,wb,16)|0}}while(0);c[(t+(((vb<<3)+yb&63)<<2)|0)>>2]=yb+D+(vb<<11)|0;c[Na+(((vb<<3)+yb&63)<<2)>>2]=nc;wb=(ca((d[A+((vb<<G)-B)|0]|0)+(d[A+((yb<<G)-z)|0]|0)|0,q)|0)+nc|0;if((wb|0)>=(cc|0)){kc=cc;lc=dc;mc=ec;break}c[Pa>>2]=yb;c[(Pa+4|0)>>2]=vb;kc=wb;lc=vb;mc=yb}}while(0);yb=Kb+2|0;if((yb|0)<(u|0)){Kb=yb;Lb=kc;Mb=lc;Nb=mc}else{break}}if((K|0)!=(mc|0)){I=kc;K=mc;v=lc;y=mc;continue l}if((v|0)==(lc|0)){Hb=kc;Ib=v;Jb=K}else{I=kc;K=K;v=lc;y=mc;continue l}}else{Hb=w;Ib=n;Jb=r}}while(0);R=u+1|0;if((R|0)<5){u=R;w=Hb;n=Ib;r=Jb}else{sc=Hb;break l}}}tc=c[Pa>>2]|0;c[f>>2]=tc;uc=p+4|0;vc=c[uc>>2]|0;c[h>>2]=vc;i=o;return sc|0}if((Oa|0)<-1){sc=trb(a,Pa,k,l,q,1,8,C)|0;tc=c[Pa>>2]|0;c[f>>2]=tc;uc=p+4|0;vc=c[uc>>2]|0;c[h>>2]=vc;i=o;return sc|0}c[o+16>>2]=a;c[o+24>>2]=f;c[o+32>>2]=h;c[o+48>>2]=k;c[o+56>>2]=l;c[o+80>>2]=p;c[o+88>>2]=q;c[o+176>>2]=C;c[o+192>>2]=G;c[o+6144>>2]=Bb;c[o+6152>>2]=Ab;c[o+6160>>2]=zb;c[o+6168>>2]=Pa;c[o+6176>>2]=Oa;c[o+19104>>2]=sc;c[o+19112>>2]=tc;c[o+19120>>2]=uc;c[o+19128>>2]=vc;c[o+19152>>2]=0;c[o+19156>>2]=0;_epzs_motion_search4$0(o);sc=c[o+19104>>2]|0;tc=c[o+19112>>2]|0;uc=c[o+19120>>2]|0;vc=c[o+19128>>2]|0;E=c[o+19152>>2]|0;x=c[o+19156>>2]|0;F=+g[o+19156>>2];c[o+19152>>2]=0;c[o+19156>>2]=0;if((E|0)==6){return x|0}return 0|0;return 0}function yrb(a,b,d,f,g,h,i,j,k,l,m,n){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;if((n&4|0)==0){o=n&2;n=c[a+12416>>2]|0;p=c[a+12420>>2]|0;q=(g<<1)+f|0;r=d<<1;s=a+12352+(j<<4)|0;t=a+12288+(k<<4)|0;do{if((q|0)==0){u=(c[s>>2]|0)+((ca(n,d)|0)+b)|0;v=Xe[l&511](a,c[t>>2]|0,u,n,i)|0;if((o|0)==0){w=v;return w|0}else{x=v;y=r&2|b&1;break}}else{v=a+12208|0;u=(c[s>>2]|0)+((ca(n,d)|0)+b)|0;mf[c[(c[a+12444>>2]|0)+(h<<4)+(q<<2)>>2]&2047](c[v>>2]|0,u,n,i);if((o|0)==0){z=0}else{z=r&2|b&1|q}x=Xe[l&511](a,c[v>>2]|0,c[t>>2]|0,n,i)|0;y=z}}while(0);if((o|0)==0){w=x;return w|0}o=c[a+12208>>2]|0;z=n<<4;n=o+z|0;t=h+1|0;h=a+12444|0;q=(ca(p,d>>1)|0)+(b>>1)|0;r=i>>1;mf[c[(c[h>>2]|0)+(t<<4)+(y<<2)>>2]&2047](n,(c[a+12352+(j<<4)+4>>2]|0)+q|0,p,r);i=o+(z|8)|0;mf[c[(c[h>>2]|0)+(t<<4)+(y<<2)>>2]&2047](i,(c[a+12352+(j<<4)+8>>2]|0)+q|0,p,r);q=a;y=(Xe[m&511](q,n,c[a+12288+(k<<4)+4>>2]|0,p,r)|0)+x|0;w=y+(Xe[m&511](q,i,c[a+12288+(k<<4)+8>>2]|0,p,r)|0)|0;return w|0}r=c[a+12416>>2]|0;p=(b<<1)+f|0;f=(d<<1)+g|0;g=a+12352+(j<<4)|0;i=a+12288+(k<<4)|0;if((c[a+12264>>2]|0)>(b|0)){w=536870912;return w|0}if((p|0)>(c[a+12268>>2]<<1|0)){w=536870912;return w|0}if((c[a+12272>>2]|0)>(d|0)){w=536870912;return w|0}if((f|0)>(c[a+12276>>2]<<1|0)){w=536870912;return w|0}d=e[a+13872>>1]|0;b=e[a+13874>>1]|0;a:do{if((c[a+11740>>2]|0)==1){k=b-d|0;q=(f|0)==0;m=a+12208|0;y=r<<3;x=a+12444|0;n=a+12448|0;t=a+12352+(j<<4)+32|0;if((p|0)==0){A=0}else{if(q){h=0;while(1){z=(c[a+12160+(h<<3)>>2]|0)+p|0;o=c[a+12160+(h<<3)+4>>2]|0;s=z-(c[a+12128+(h<<3)>>2]|0)|0;v=h>>1;u=((ca(c[a+12128+(h<<3)+4>>2]|0,k)|0)/(d|0)|0)+(v<<4)|0;B=(c[m>>2]|0)+((h<<3&8)+(ca(v,y)|0))|0;v=(c[g>>2]|0)+((ca(o>>1,r)|0)+(z>>1))|0;mf[c[(c[x>>2]|0)+16+((o<<1&2|z&1)<<2)>>2]&2047](B,v,r,8);v=(c[t>>2]|0)+((ca(u>>1,r)|0)+(s>>1))|0;mf[c[(c[n>>2]|0)+16+((u<<1&2|s&1)<<2)>>2]&2047](B,v,r,8);h=h+1|0;if((h|0)>=4){break a}}}else{h=0;while(1){v=(c[a+12160+(h<<3)>>2]|0)+p|0;B=(c[a+12160+(h<<3)+4>>2]|0)+f|0;s=v-(c[a+12128+(h<<3)>>2]|0)|0;u=B-(c[a+12128+(h<<3)+4>>2]|0)|0;z=(c[m>>2]|0)+((h<<3&8)+(ca(h>>1,y)|0))|0;o=(c[g>>2]|0)+((ca(B>>1,r)|0)+(v>>1))|0;mf[c[(c[x>>2]|0)+16+((B<<1&2|v&1)<<2)>>2]&2047](z,o,r,8);o=(c[t>>2]|0)+((ca(u>>1,r)|0)+(s>>1))|0;mf[c[(c[n>>2]|0)+16+((u<<1&2|s&1)<<2)>>2]&2047](z,o,r,8);h=h+1|0;if((h|0)>=4){break a}}}}do{h=c[a+12160+(A<<3)>>2]|0;o=(c[a+12160+(A<<3)+4>>2]|0)+f|0;z=((ca(c[a+12128+(A<<3)>>2]|0,k)|0)/(d|0)|0)+(A<<4&16)|0;s=c[a+12128+(A<<3)+4>>2]|0;if(q){u=A>>1;C=((ca(s,k)|0)/(d|0)|0)+(u<<4)|0;D=u}else{C=o-s|0;D=A>>1}s=(c[m>>2]|0)+((ca(D,y)|0)+(A<<3&8))|0;u=(c[g>>2]|0)+((ca(o>>1,r)|0)+(h>>1))|0;mf[c[(c[x>>2]|0)+16+((o<<1&2|h&1)<<2)>>2]&2047](s,u,r,8);u=(c[t>>2]|0)+((ca(C>>1,r)|0)+(z>>1))|0;mf[c[(c[n>>2]|0)+16+((C<<1&2|z&1)<<2)>>2]&2047](s,u,r,8);A=A+1|0;}while((A|0)<4)}else{n=(c[a+12160>>2]|0)+p|0;t=(c[a+12164>>2]|0)+f|0;x=c[a+12128>>2]|0;if((p|0)==0){E=(ca(x,b-d|0)|0)/(d|0)|0}else{E=n-x|0}x=c[a+12132>>2]|0;if((f|0)==0){F=(ca(x,b-d|0)|0)/(d|0)|0}else{F=t-x|0}x=a+12208|0;y=(c[g>>2]|0)+((ca(t>>1,r)|0)+(n>>1))|0;mf[c[(c[a+12444>>2]|0)+((t<<1&2|n&1)<<2)>>2]&2047](c[x>>2]|0,y,r,16);y=(c[a+12352+(j<<4)+32>>2]|0)+((ca(F>>1,r)|0)+(E>>1))|0;mf[c[(c[a+12448>>2]|0)+((F<<1&2|E&1)<<2)>>2]&2047](c[x>>2]|0,y,r,16)}}while(0);w=Xe[l&511](a,c[a+12208>>2]|0,c[i>>2]|0,r,16)|0;return w|0}function zrb(){SSa(7690816);return}function Arb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0;f=i;i=i+8|0;h=f|0;mrc(a+20944|0,0,9216)|0;if((b|0)>=0){j=0;k=0;while(1){l=0;do{m=a+1572+(k*52|0)+4+(l<<2)|0;n=c[m>>2]|0;if((n|0)!=0){o=+g[800024+(n+1<<2)>>2]*+g[799e3+((c[a+1572+(k*52|0)+20+(l*12|0)>>2]&255)<<2)>>2];c[a+20944+(l*4608|0)+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j<<2)>>2]|0));c[a+20944+(l*4608|0)+128+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+((j|1)<<2)>>2]|0));c[a+20944+(l*4608|0)+256+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+((j|2)<<2)>>2]|0));c[a+20944+(l*4608|0)+384+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+((j|3)<<2)>>2]|0));c[a+20944+(l*4608|0)+512+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+4<<2)>>2]|0));c[a+20944+(l*4608|0)+640+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+5<<2)>>2]|0));c[a+20944+(l*4608|0)+768+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+6<<2)>>2]|0));c[a+20944+(l*4608|0)+896+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+7<<2)>>2]|0));c[a+20944+(l*4608|0)+1024+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+8<<2)>>2]|0));c[a+20944+(l*4608|0)+1152+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+9<<2)>>2]|0));c[a+20944+(l*4608|0)+1280+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+10<<2)>>2]|0));c[a+20944+(l*4608|0)+1408+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+11<<2)>>2]|0));o=+g[800024+((c[m>>2]|0)+1<<2)>>2]*+g[799e3+((c[a+1572+(k*52|0)+20+(l*12|0)+4>>2]&255)<<2)>>2];c[a+20944+(l*4608|0)+1536+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+12<<2)>>2]|0));c[a+20944+(l*4608|0)+1664+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+13<<2)>>2]|0));c[a+20944+(l*4608|0)+1792+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+14<<2)>>2]|0));c[a+20944+(l*4608|0)+1920+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+15<<2)>>2]|0));c[a+20944+(l*4608|0)+2048+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+16<<2)>>2]|0));c[a+20944+(l*4608|0)+2176+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+17<<2)>>2]|0));c[a+20944+(l*4608|0)+2304+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+18<<2)>>2]|0));c[a+20944+(l*4608|0)+2432+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+19<<2)>>2]|0));c[a+20944+(l*4608|0)+2560+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+20<<2)>>2]|0));c[a+20944+(l*4608|0)+2688+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+21<<2)>>2]|0));c[a+20944+(l*4608|0)+2816+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+22<<2)>>2]|0));c[a+20944+(l*4608|0)+2944+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(j+23<<2)>>2]|0));o=+g[800024+((c[m>>2]|0)+1<<2)>>2]*+g[799e3+((c[a+1572+(k*52|0)+20+(l*12|0)+8>>2]&255)<<2)>>2];m=24;do{c[a+20944+(l*4608|0)+(m<<7)+(k<<2)>>2]=~~(o*+(c[a+3236+(l*4608|0)+(m+j<<2)>>2]|0));m=m+1|0;}while((m|0)<36)}l=l+1|0;}while((l|0)<2);if((c[a+1572+(k*52|0)>>2]|0)!=0){l=0;do{m=a+20944+(l<<7)+(k<<2)|0;n=c[m>>2]|0;p=a+25552+(l<<7)+(k<<2)|0;q=c[p>>2]|0;c[m>>2]=q+n;c[p>>2]=n-q;l=l+1|0;}while((l|0)<36)}l=k+1|0;if((l|0)>(b|0)){break}else{j=j+36|0;k=l}}}c[h>>2]=0;if((e|0)<=0){i=f;return}k=a+1244|0;j=0;do{b=a+12736+(j<<12)|0;l=a+20928+(j<<2)|0;q=d+(j<<2)|0;n=0;do{RSa(k,b,l,7690816,h,(c[q>>2]|0)+(n<<5<<1)|0,1,a+20944+(j*4608|0)+(n<<7)|0);n=n+1|0;}while((n|0)<36);j=j+1|0;}while((j|0)<(e|0));i=f;return}function Brb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=(a|0)/(b|0)|0;if((d|0)!=0){f=4;return f|0}if((c|0)==48e3&(e|0)>55|(e-56|0)>>>0<25>>>0){f=0;return f|0}if((c|0)!=48e3&(e|0)>95){f=1;return f|0}else{return((c|0)!=32e3&(e|0)<49?2:3)|0}return 0}function Crb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[a+14092>>2]|0;a:do{switch(b|0){case 4:case 5:{c[a+9888>>2]=1246568;c[a+9892>>2]=1247064;e=9;break};case 3:{f=a+9888|0;if((c[a+84>>2]|0)==0){c[f>>2]=1343568;c[a+9892>>2]=1344936;break a}else{c[f>>2]=1334952;c[a+9892>>2]=1247064;e=8;break a}break};case 6:{c[a+9888>>2]=1246136;c[a+9892>>2]=1246136;e=9;break};case 1:case 2:{c[a+9892>>2]=1347360;c[a+9888>>2]=1347360;break};default:{e=8}}}while(0);if((e|0)==8){if((b|0)>3){e=9}}if((e|0)==9){e=a+11184|0;L6(e,a+364|0,1246664);L6(e,a+496|0,1246728);L6(e,a+628|0,1246792);L6(e,a+232|0,1246600)}if((c[1554235]|0)==0){g=-256}else{return}do{a=-g|0;e=(g|0)>-1?g:a;if((e|0)==0){h=0}else{b=0;f=e;while(1){e=f>>1;i=b+1|0;if((e|0)==0){h=i;break}else{b=i;f=e}}}if((g|0)<0){j=(1<<h)-1^a}else{j=g}f=d[1344969+(h<<1)|0]|0;b=(1<<f)-1^(d[1344968+(h<<1)|0]|0);e=(h|0)>0;do{if(e){i=b<<h|j;k=f+h|0;if((h|0)<=8){l=k;m=i;break}l=k+1|0;m=i<<1|1}else{l=f;m=b}}while(0);b=g+256|0;c[6208752+(b<<3)>>2]=m;c[6208756+(b<<3)>>2]=l;f=d[1345001+(h<<1)|0]|0;a=(1<<f)-1^(d[1345e3+(h<<1)|0]|0);do{if(e){i=a<<h|j;k=f+h|0;if((h|0)<=8){n=k;o=i;break}n=k+1|0;o=i<<1|1}else{n=f;o=a}}while(0);c[6212848+(b<<3)>>2]=o;c[6212852+(b<<3)>>2]=n;g=g+1|0;}while((g|0)<256);return}function Drb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[b+12496+(d<<2)>>2]|0;d=c[b+128>>2]|0;g=f-1|0;h=c[b+9904>>2]|0;b=a[h+(f-d)|0]|0;if((a[h+(g-d)|0]|0)==b<<24>>24){i=a[h+g|0]|0}else{i=b}c[e>>2]=h+f;return i&255|0}function Erb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=(e|0)<4;i=c[(h?a+168|0:a+172|0)>>2]|0;j=c[a+12520+(e<<2)>>2]|0;k=c[a+9876>>2]|0;l=c[a+12496+(e<<2)>>2]|0;m=k+(l<<1)|0;n=b[k+(l-1<<1)>>1]|0;o=b[k+(l+~j<<1)>>1]|0;p=b[k+(l-j<<1)>>1]|0;do{if((c[a+14084>>2]|0)==0){q=o;r=p}else{if((e&2|0)!=0){q=o;r=p;break}j=(c[a+14092>>2]|0)<4;q=j?1024:o;r=j?1024:p}}while(0);if((i|0)==8){s=(n+4|0)/8|0;t=(q+4|0)/8|0;u=(r+4|0)/8|0}else{p=i>>1;o=n+p|0;n=c[1367848+(i<<2)>>2]|0;j=0;Erc(n,j,o,(o|0)<0|0?-1:0)|0;o=G;l=q+p|0;Erc(n,j,l,(l|0)<0|0?-1:0)|0;l=G;q=r+p|0;Erc(n,j,q,(q|0)<0|0?-1:0)|0;s=o;t=l;u=G}if((c[a+14092>>2]|0)<=3){l=s-t|0;o=t-u|0;if((((l|0)>-1?l:-l|0)|0)>(((o|0)>-1?o:-o|0)|0)){c[g>>2]=0;v=s;c[f>>2]=m;return v|0}else{c[g>>2]=1;v=u;c[f>>2]=m;return v|0}}if((c[a+14112>>2]|0)==0){o=s-t|0;l=t-u|0;if((((o|0)>-1?o:-o|0)|0)<(((l|0)>-1?l:-l|0)|0)){c[g>>2]=1;v=u;c[f>>2]=m;return v|0}else{c[g>>2]=0;v=s;c[f>>2]=m;return v|0}}if((e|0)==1){c[g>>2]=0;v=s;c[f>>2]=m;return v|0}else if((e|0)==3){l=s-t|0;o=t-u|0;if((((l|0)>-1?l:-l|0)|0)<(((o|0)>-1?o:-o|0)|0)){c[g>>2]=1;v=u;c[f>>2]=m;return v|0}else{c[g>>2]=0;v=s;c[f>>2]=m;return v|0}}else if((e|0)==2){c[g>>2]=1;v=u;c[f>>2]=m;return v|0}else{u=c[(c[a+4>>2]|0)+800>>2]|0;s=8>>>(u>>>0);if(h){h=c[a+148>>2]|0;o=c[a+12480>>2]|0;l=ca((o<<1)+(e>>1)|0,h)|0;t=c[a+12476>>2]|0;w=h;x=(c[a+7624>>2]|0)+(ca((t<<1|e&1)+l|0,s)|0)|0;y=t;z=o}else{o=c[a+152>>2]|0;t=c[a+12480>>2]|0;l=ca(t,o)|0;h=c[a+12476>>2]|0;w=o;x=(c[a+7624+(e-3<<2)>>2]|0)+(ca(h+l|0,s)|0)|0;y=h;z=t}if((y|0)==0){A=((i>>1)+1024|0)/(i|0)|0}else{y=i<<3>>(u<<1);if((s|0)>0){t=0;h=0;while(1){l=(ca(t,w)|0)-s|0;o=h;q=0;do{o=(d[x+(l+q)|0]|0)+o|0;q=q+1|0;}while((q|0)<(s|0));q=t+1|0;if((q|0)<(s|0)){t=q;h=o}else{B=o;break}}}else{B=0}h=B+(y>>1)|0;Erc(c[1367848+(y<<2)>>2]|0,0,h,(h|0)<0|0?-1:0)|0;A=G}if((z|0)==0){C=((i>>1)+1024|0)/(i|0)|0}else{z=i<<3>>(u<<1);if((s|0)>0){u=0;i=0;while(1){h=ca(u-s|0,w)|0;y=i;B=0;do{y=(d[x+(h+B)|0]|0)+y|0;B=B+1|0;}while((B|0)<(s|0));B=u+1|0;if((B|0)<(s|0)){u=B;i=y}else{D=y;break}}}else{D=0}i=D+(z>>1)|0;Erc(c[1367848+(z<<2)>>2]|0,0,i,(i|0)<0|0?-1:0)|0;C=G}i=c[a+13820>>2]|0;if((i|0)==0){c[g>>2]=0;v=A;c[f>>2]=m;return v|0}else if((i|0)==1){if((e|0)==0){c[g>>2]=1;v=C;c[f>>2]=m;return v|0}else{c[g>>2]=0;v=A;c[f>>2]=m;return v|0}}else if((i|0)==2){if((e|0)==0){c[g>>2]=0;v=A;c[f>>2]=m;return v|0}else{c[g>>2]=1;v=C;c[f>>2]=m;return v|0}}else{c[g>>2]=1;v=C;c[f>>2]=m;return v|0}}return 0}function Frb(a,e){a=a|0;e=e|0;var f=0,h=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;f=i;i=i+256|0;h=f|0;j=0;k=0;do{l=+(j|0);m=+g[a+(k<<2)>>2];j=~~(l>m?l:m);k=k+1|0;}while((k|0)<124);do{if((j|0)==0){n=15;o=15;p=7}else{k=(j|0)>-1?j:-j|0;q=k>>>0>65535>>>0;r=q?k>>>16:k;k=q?16:0;if((r&65280|0)==0){s=k;t=r}else{s=k|8;t=r>>>8}r=65550-s-(d[1359664+t|0]|0)&65535;k=r<<16>>16;q=-k|0;if(r<<16>>16>0){n=r;o=k;p=7;break}else{u=0;v=0}while(1){k=((~~+g[a+(v<<2)>>2]>>q<<16>>16)*3|0)>>>2&65535;b[h+(v<<1)>>1]=k;w=(k<<16>>16)+u|0;k=v+1|0;if((k|0)<124){u=w;v=k}else{x=w;y=r;break}}}}while(0);if((p|0)==7){p=0;v=0;while(1){u=((~~+g[a+(v<<2)>>2]<<o<<16>>16)*3|0)>>>2&65535;b[h+(v<<1)>>1]=u;t=(u<<16>>16)+p|0;u=v+1|0;if((u|0)<124){p=t;v=u}else{x=t;y=n;break}}}n=(y+11&65535)<<16>>16;v=198<<n;p=x-v|0;if((x|0)==(v|0)){z=31;A=0}else{v=(p|0)>-1?p:-p|0;x=v>>>0>65535>>>0;o=x?v>>>16:v;v=x?16:0;if((o&65280|0)==0){B=v;C=o}else{B=v|8;C=o>>>8}o=30-B-(d[1359664+C|0]|0)|0;z=o;A=((p<<o>>16)*4228|0)>>15}o=-65524-z<<16;z=o>>16;if((o|0)>0){D=A<<z}else{D=A>>-z}z=D<<16>>16;A=n-1|0;n=0;o=0;do{p=((b[h+(o<<1)>>1]|0)-z>>A)+1>>1;if((p|0)<0){E=0}else{E=(p|0)>6?6:p}n=E+n|0;o=o+1|0;}while((o|0)<124);if((n|0)==198){F=D;G=198}else{o=n-198|0;if((((o|0)>-1?o:198-n|0)|0)<16384){E=0;z=o;while(1){p=z<<1;C=E+1&65535;if((((p|0)>-1?p:-p|0)|0)<16384){E=C;z=p}else{H=C;I=p;break}}}else{H=0;I=o}o=(I*4228|0)>>15;I=(y+7&65535)-H&65535;H=I<<16>>16;if(I<<16>>16>0){J=o<<H}else{J=o>>-H}H=D;D=0;o=0;I=n;n=1;while(1){K=(n|0)<20;if(!K){L=H;M=D;N=o;O=I;break}y=H+J|0;z=y<<16>>16;E=0;p=0;do{C=((b[h+(p<<1)>>1]|0)-z>>A)+1>>1;if((C|0)<0){P=0}else{P=(C|0)>6?6:C}E=P+E|0;p=p+1|0;}while((p|0)<124);if((ca(E-198|0,I-198|0)|0)<1){L=y;M=H;N=I;O=E;break}else{D=H;H=y;o=I;I=E;n=n+1|0}}I=(O|0)>198;o=I?N:O;H=I?O:N;N=I?L:M;D=I?M:L;if((O|0)!=198&K){K=n;n=o;O=H;L=N;M=D;while(1){I=M+L>>1;P=I<<16>>16;J=0;p=0;do{z=((b[h+(p<<1)>>1]|0)-P>>A)+1>>1;if((z|0)<0){Q=0}else{Q=(z|0)>6?6:z}J=Q+J|0;p=p+1|0;}while((p|0)<124);p=(J|0)>198;P=p?n:J;E=p?J:O;y=p?I:L;z=p?M:I;p=K+1|0;if((J|0)!=198&(p|0)<20){K=p;n=P;O=E;L=y;M=z}else{R=P;S=E;T=y;U=z;break}}}else{R=o;S=H;T=N;U=D}D=S-198|0;N=R-198|0;H=(((D|0)>-1?D:198-S|0)|0)<(((N|0)>-1?N:198-R|0)|0);F=H?T:U;G=H?S:R}R=0;do{S=((b[h+(R<<1)>>1]|0)-F>>A)+1>>1;if((S|0)<0){V=0}else{V=(S|0)>6?6:S}c[e+(R<<2)>>2]=V;R=R+1|0;}while((R|0)<124);if((G|0)>198){W=0;X=0}else{i=f;return}while(1){Y=e+(W<<2)|0;Z=c[Y>>2]|0;_=Z+X|0;$=W+1|0;if((_|0)<198){W=$;X=_}else{break}}c[Y>>2]=198-_+Z;if(($|0)>=124){i=f;return}mrc(e+($<<2)|0,0,(W*-4|0)+492|0)|0;i=f;return}function Grb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;do{if((c|0)==0){d=0}else{if(!((2147483647/(c>>>0)|0)>>>0>b>>>0)){d=0;break}d=pJb(ca(c,b)|0)|0}}while(0);return d|0}function Hrb(a,b){a=a|0;b=b|0;kJb(b);return}function Irb(a){a=a|0;return((a&3|0)==2?3:1)+(a>>>2&1)|0}function Jrb(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;e=d[1323240+a|0]|0;if((e|0)>=(c|0)){f=0;return f|0}g=d[1323232+a|0]|0;f=(ca(c-1-e+(1<<g)>>g,b)|0)+7>>3;return f|0}function Krb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;f=i;i=i+64|0;g=f|0;h=f+32|0;j=g|0;k=e|0;l=c[k>>2]|0;m=e+8|0;n=c[m>>2]|0;a:do{if(l>>>0<n>>>0){o=l;while(1){p=o+1|0;c[k>>2]=p;q=a[o]|0;r=q&255;b:do{if(q<<24>>24==35){s=r;t=p;while(1){if(!(t>>>0<n>>>0)){u=s;v=t;break b}w=t+1|0;c[k>>2]=w;x=a[t]|0;if(x<<24>>24==10){u=10;v=w;break}else{s=x&255;t=w}}}else{if((r|0)==32|(r|0)==13|(r|0)==10){u=r;v=p;break}if(q<<24>>24==9){u=r;v=p}else{y=r;z=p;break a}}}while(0);if(v>>>0<n>>>0){o=v}else{y=u;z=v;break}}}else{y=0;z=l}}while(0);c:do{if(z>>>0<n>>>0){l=g;v=j;u=y;o=z;p=n;while(1){if((u|0)==32|(u|0)==13|(u|0)==10|(u|0)==9){A=v;break c}if((v-l|0)<31){a[v]=u;B=v+1|0;C=c[k>>2]|0;D=c[m>>2]|0}else{B=v;C=o;D=p}r=C+1|0;c[k>>2]=r;if(r>>>0<D>>>0){v=B;u=d[C]|0;o=r;p=D}else{A=B;break}}}else{A=j}}while(0);a[A]=0;A=a[g+1|0]|0;c[e+16>>2]=A-48;if((a[j]|0)!=80){E=-1094995529;i=f;return E|0}d:do{switch(A|0){case 50:case 53:{B=b+140|0;if((c[b+48>>2]|0)==66){c[B>>2]=0;break d}else{c[B>>2]=8;break d}break};case 55:{B=h|0;a[B]=0;D=g;C=h;n=-1;z=-1;y=-1;p=-1;e:while(1){o=n;u=z;F=y;f:while(1){v=o;G=u;g:while(1){H=v;h:while(1){while(1){l=c[k>>2]|0;r=c[m>>2]|0;i:do{if(l>>>0<r>>>0){q=l;while(1){t=q+1|0;c[k>>2]=t;s=a[q]|0;w=s&255;j:do{if(s<<24>>24==35){x=w;I=t;while(1){if(!(I>>>0<r>>>0)){J=x;K=I;break j}L=I+1|0;c[k>>2]=L;M=a[I]|0;if(M<<24>>24==10){J=10;K=L;break}else{x=M&255;I=L}}}else{if((w|0)==32|(w|0)==13|(w|0)==10){J=w;K=t;break}if(s<<24>>24==9){J=w;K=t}else{N=w;O=t;break i}}}while(0);if(K>>>0<r>>>0){q=K}else{N=J;O=K;break}}}else{N=0;O=l}}while(0);k:do{if(O>>>0<r>>>0){l=j;q=N;t=O;w=r;while(1){if((q|0)==32|(q|0)==13|(q|0)==10|(q|0)==9){P=l;break k}if((l-D|0)<31){a[l]=q;Q=l+1|0;R=c[k>>2]|0;S=c[m>>2]|0}else{Q=l;R=t;S=w}s=R+1|0;c[k>>2]=s;if(s>>>0<S>>>0){l=Q;q=d[R]|0;t=s;w=S}else{P=Q;break}}}else{P=j}}while(0);a[P]=0;if((irc(j,2424536)|0)==0){break g}if((irc(j,2580976)|0)==0){break f}if((irc(j,2437112)|0)==0){break h}if((irc(j,2350320)|0)==0){break}if((irc(j,2288736)|0)!=0){if((irc(j,2238624)|0)!=0){break e}}r=c[k>>2]|0;w=c[m>>2]|0;l:do{if(r>>>0<w>>>0){t=r;while(1){q=t+1|0;c[k>>2]=q;l=a[t]|0;s=l&255;m:do{if(l<<24>>24==35){I=s;x=q;while(1){if(!(x>>>0<w>>>0)){T=I;U=x;break m}L=x+1|0;c[k>>2]=L;M=a[x]|0;if(M<<24>>24==10){T=10;U=L;break}else{I=M&255;x=L}}}else{if((s|0)==32|(s|0)==13|(s|0)==10){T=s;U=q;break}if(l<<24>>24==9){T=s;U=q}else{V=s;W=q;break l}}}while(0);if(U>>>0<w>>>0){t=U}else{V=T;W=U;break}}}else{V=0;W=r}}while(0);n:do{if(W>>>0<w>>>0){r=B;t=V;q=W;s=w;while(1){if((t|0)==32|(t|0)==13|(t|0)==10|(t|0)==9){X=r;break n}if((r-C|0)<31){a[r]=t;Y=r+1|0;Z=c[k>>2]|0;_=c[m>>2]|0}else{Y=r;Z=q;_=s}l=Z+1|0;c[k>>2]=l;if(l>>>0<_>>>0){r=Y;t=d[Z]|0;q=l;s=_}else{X=Y;break}}}else{X=B}}while(0);a[X]=0}w=c[k>>2]|0;s=c[m>>2]|0;o:do{if(w>>>0<s>>>0){q=w;while(1){t=q+1|0;c[k>>2]=t;r=a[q]|0;l=r&255;p:do{if(r<<24>>24==35){x=l;I=t;while(1){if(!(I>>>0<s>>>0)){$=x;aa=I;break p}L=I+1|0;c[k>>2]=L;M=a[I]|0;if(M<<24>>24==10){$=10;aa=L;break}else{x=M&255;I=L}}}else{if((l|0)==32|(l|0)==13|(l|0)==10){$=l;aa=t;break}if(r<<24>>24==9){$=l;aa=t}else{ba=l;ca=t;break o}}}while(0);if(aa>>>0<s>>>0){q=aa}else{ba=$;ca=aa;break}}}else{ba=0;ca=w}}while(0);q:do{if(ca>>>0<s>>>0){w=j;q=ba;t=ca;l=s;while(1){if((q|0)==32|(q|0)==13|(q|0)==10|(q|0)==9){da=w;break q}if((w-D|0)<31){a[w]=q;ea=w+1|0;fa=c[k>>2]|0;ga=c[m>>2]|0}else{ea=w;fa=t;ga=l}r=fa+1|0;c[k>>2]=r;if(r>>>0<ga>>>0){w=ea;q=d[fa]|0;t=r;l=ga}else{da=ea;break}}}else{da=j}}while(0);a[da]=0;H=rb(j|0,0,10)|0}s=c[k>>2]|0;l=c[m>>2]|0;r:do{if(s>>>0<l>>>0){t=s;while(1){q=t+1|0;c[k>>2]=q;w=a[t]|0;r=w&255;s:do{if(w<<24>>24==35){I=r;x=q;while(1){if(!(x>>>0<l>>>0)){ha=I;ia=x;break s}L=x+1|0;c[k>>2]=L;M=a[x]|0;if(M<<24>>24==10){ha=10;ia=L;break}else{I=M&255;x=L}}}else{if((r|0)==32|(r|0)==13|(r|0)==10){ha=r;ia=q;break}if(w<<24>>24==9){ha=r;ia=q}else{ja=r;ka=q;break r}}}while(0);if(ia>>>0<l>>>0){t=ia}else{ja=ha;ka=ia;break}}}else{ja=0;ka=s}}while(0);t:do{if(ka>>>0<l>>>0){s=j;t=ja;q=ka;r=l;while(1){if((t|0)==32|(t|0)==13|(t|0)==10|(t|0)==9){la=s;break t}if((s-D|0)<31){a[s]=t;ma=s+1|0;na=c[k>>2]|0;oa=c[m>>2]|0}else{ma=s;na=q;oa=r}w=na+1|0;c[k>>2]=w;if(w>>>0<oa>>>0){s=ma;t=d[na]|0;q=w;r=oa}else{la=ma;break}}}else{la=j}}while(0);a[la]=0;v=H;G=rb(j|0,0,10)|0}v=c[k>>2]|0;l=c[m>>2]|0;u:do{if(v>>>0<l>>>0){r=v;while(1){q=r+1|0;c[k>>2]=q;t=a[r]|0;s=t&255;v:do{if(t<<24>>24==35){w=s;x=q;while(1){if(!(x>>>0<l>>>0)){pa=w;qa=x;break v}I=x+1|0;c[k>>2]=I;L=a[x]|0;if(L<<24>>24==10){pa=10;qa=I;break}else{w=L&255;x=I}}}else{if((s|0)==32|(s|0)==13|(s|0)==10){pa=s;qa=q;break}if(t<<24>>24==9){pa=s;qa=q}else{ra=s;sa=q;break u}}}while(0);if(qa>>>0<l>>>0){r=qa}else{ra=pa;sa=qa;break}}}else{ra=0;sa=v}}while(0);w:do{if(sa>>>0<l>>>0){v=j;r=ra;q=sa;s=l;while(1){if((r|0)==32|(r|0)==13|(r|0)==10|(r|0)==9){ta=v;break w}if((v-D|0)<31){a[v]=r;ua=v+1|0;va=c[k>>2]|0;wa=c[m>>2]|0}else{ua=v;va=q;wa=s}t=va+1|0;c[k>>2]=t;if(t>>>0<wa>>>0){v=ua;r=d[va]|0;q=t;s=wa}else{ta=ua;break}}}else{ta=j}}while(0);a[ta]=0;o=H;u=G;F=rb(j|0,0,10)|0}u=c[k>>2]|0;o=c[m>>2]|0;x:do{if(u>>>0<o>>>0){l=u;while(1){s=l+1|0;c[k>>2]=s;q=a[l]|0;r=q&255;y:do{if(q<<24>>24==35){v=r;t=s;while(1){if(!(t>>>0<o>>>0)){xa=v;ya=t;break y}x=t+1|0;c[k>>2]=x;w=a[t]|0;if(w<<24>>24==10){xa=10;ya=x;break}else{v=w&255;t=x}}}else{if((r|0)==32|(r|0)==13|(r|0)==10){xa=r;ya=s;break}if(q<<24>>24==9){xa=r;ya=s}else{za=r;Aa=s;break x}}}while(0);if(ya>>>0<o>>>0){l=ya}else{za=xa;Aa=ya;break}}}else{za=0;Aa=u}}while(0);z:do{if(Aa>>>0<o>>>0){u=j;l=za;s=Aa;r=o;while(1){if((l|0)==32|(l|0)==13|(l|0)==10|(l|0)==9){Ba=u;break z}if((u-D|0)<31){a[u]=l;Ca=u+1|0;Da=c[k>>2]|0;Ea=c[m>>2]|0}else{Ca=u;Da=s;Ea=r}q=Da+1|0;c[k>>2]=q;if(q>>>0<Ea>>>0){u=Ca;l=d[Da]|0;s=q;r=Ea}else{Ba=Ca;break}}}else{Ba=j}}while(0);a[Ba]=0;n=H;z=G;y=F;p=rb(j|0,0,10)|0}if((irc(j,2197840)|0)!=0){E=-1094995529;i=f;return E|0}if((F|0)<1|(p|0)<1|(H|0)<1|(G|0)<1){E=-1094995529;i=f;return E|0}if((a[B]|0)==0){E=-1094995529;i=f;return E|0}if((tIb(F,p,0,b)|0)!=0){E=-1094995529;i=f;return E|0}if(!((c[k>>2]|0)>>>0<(c[m>>2]|0)>>>0)){E=-1094995529;i=f;return E|0}c[b+120>>2]=F;c[b+124>>2]=p;c[e+12>>2]=H;if((G|0)==1){if((H|0)==1){c[b+140>>2]=10;E=0;i=f;return E|0}y=b+140|0;if((H|0)<256){c[y>>2]=8;E=0;i=f;return E|0}else{c[y>>2]=32;E=0;i=f;return E|0}}else if((G|0)==2){if((H|0)!=255){E=0;i=f;return E|0}c[b+140>>2]=66;E=0;i=f;return E|0}else if((G|0)==3){y=b+140|0;if((H|0)<256){c[y>>2]=2;E=0;i=f;return E|0}else{c[y>>2]=42;E=0;i=f;return E|0}}else if((G|0)==4){y=b+140|0;if((H|0)<256){c[y>>2]=28;E=0;i=f;return E|0}else{c[y>>2]=292;E=0;i=f;return E|0}}else{E=-1094995529;i=f;return E|0}break};case 51:case 54:{c[b+140>>2]=2;break};case 49:case 52:{c[b+140>>2]=9;break};default:{E=-1094995529;i=f;return E|0}}}while(0);H=c[k>>2]|0;G=c[m>>2]|0;A:do{if(H>>>0<G>>>0){F=H;while(1){Ba=F+1|0;c[k>>2]=Ba;Ca=a[F]|0;Ea=Ca&255;B:do{if(Ca<<24>>24==35){Da=Ea;Aa=Ba;while(1){if(!(Aa>>>0<G>>>0)){Fa=Da;Ga=Aa;break B}za=Aa+1|0;c[k>>2]=za;ya=a[Aa]|0;if(ya<<24>>24==10){Fa=10;Ga=za;break}else{Da=ya&255;Aa=za}}}else{if((Ea|0)==32|(Ea|0)==13|(Ea|0)==10){Fa=Ea;Ga=Ba;break}if(Ca<<24>>24==9){Fa=Ea;Ga=Ba}else{Ha=Ea;Ia=Ba;break A}}}while(0);if(Ga>>>0<G>>>0){F=Ga}else{Ha=Fa;Ia=Ga;break}}}else{Ha=0;Ia=H}}while(0);C:do{if(Ia>>>0<G>>>0){H=g;Ga=j;Fa=Ha;F=Ia;p=G;while(1){if((Fa|0)==32|(Fa|0)==13|(Fa|0)==10|(Fa|0)==9){Ja=Ga;break C}if((Ga-H|0)<31){a[Ga]=Fa;Ka=Ga+1|0;La=c[k>>2]|0;Ma=c[m>>2]|0}else{Ka=Ga;La=F;Ma=p}B=La+1|0;c[k>>2]=B;if(B>>>0<Ma>>>0){Ga=Ka;Fa=d[La]|0;F=B;p=Ma}else{Ja=Ka;break}}}else{Ja=j}}while(0);a[Ja]=0;Ja=kd(j|0)|0;Ka=c[k>>2]|0;Ma=c[m>>2]|0;D:do{if(Ka>>>0<Ma>>>0){La=Ka;while(1){G=La+1|0;c[k>>2]=G;Ia=a[La]|0;Ha=Ia&255;E:do{if(Ia<<24>>24==35){p=Ha;F=G;while(1){if(!(F>>>0<Ma>>>0)){Na=p;Oa=F;break E}Fa=F+1|0;c[k>>2]=Fa;Ga=a[F]|0;if(Ga<<24>>24==10){Na=10;Oa=Fa;break}else{p=Ga&255;F=Fa}}}else{if((Ha|0)==32|(Ha|0)==13|(Ha|0)==10){Na=Ha;Oa=G;break}if(Ia<<24>>24==9){Na=Ha;Oa=G}else{Pa=Ha;Qa=G;break D}}}while(0);if(Oa>>>0<Ma>>>0){La=Oa}else{Pa=Na;Qa=Oa;break}}}else{Pa=0;Qa=Ka}}while(0);F:do{if(Qa>>>0<Ma>>>0){Ka=g;Oa=j;Na=Pa;La=Qa;G=Ma;while(1){if((Na|0)==32|(Na|0)==13|(Na|0)==10|(Na|0)==9){Ra=Oa;break F}if((Oa-Ka|0)<31){a[Oa]=Na;Sa=Oa+1|0;Ta=c[k>>2]|0;Ua=c[m>>2]|0}else{Sa=Oa;Ta=La;Ua=G}Ha=Ta+1|0;c[k>>2]=Ha;if(Ha>>>0<Ua>>>0){Oa=Sa;Na=d[Ta]|0;La=Ha;G=Ua}else{Ra=Sa;break}}}else{Ra=j}}while(0);a[Ra]=0;Ra=kd(j|0)|0;if((Ja|0)<1|(Ra|0)<1){E=-1094995529;i=f;return E|0}Sa=b;if((tIb(Ja,Ra,0,Sa)|0)!=0){E=-1094995529;i=f;return E|0}Ua=c[k>>2]|0;Ta=c[m>>2]|0;if(!(Ua>>>0<Ta>>>0)){E=-1094995529;i=f;return E|0}Ma=b+120|0;c[Ma>>2]=Ja;Ja=b+124|0;c[Ja>>2]=Ra;Ra=b+140|0;G:do{if(((c[Ra>>2]|0)-9|0)>>>0<2>>>0){c[e+12>>2]=1}else{b=Ua;H:while(1){Qa=b+1|0;c[k>>2]=Qa;Pa=a[b]|0;G=Pa&255;I:do{if(Pa<<24>>24==35){La=G;Na=Qa;while(1){if(!(Na>>>0<Ta>>>0)){Va=La;Wa=Na;break I}Oa=Na+1|0;c[k>>2]=Oa;Ka=a[Na]|0;if(Ka<<24>>24==10){Va=10;Wa=Oa;break}else{La=Ka&255;Na=Oa}}}else{if((G|0)==32|(G|0)==13|(G|0)==10){Va=G;Wa=Qa;break}if(Pa<<24>>24==9){Va=G;Wa=Qa}else{Xa=G;Ya=Qa;break H}}}while(0);if(Wa>>>0<Ta>>>0){b=Wa}else{Xa=Va;Ya=Wa;break}}J:do{if(Ya>>>0<Ta>>>0){b=g;Qa=j;G=Xa;Pa=Ya;Na=Ta;while(1){if((G|0)==32|(G|0)==13|(G|0)==10|(G|0)==9){Za=Qa;break J}if((Qa-b|0)<31){a[Qa]=G;_a=Qa+1|0;$a=c[k>>2]|0;ab=c[m>>2]|0}else{_a=Qa;$a=Pa;ab=Na}La=$a+1|0;c[k>>2]=La;if(La>>>0<ab>>>0){Qa=_a;G=d[$a]|0;Pa=La;Na=ab}else{Za=_a;break}}}else{Za=j}}while(0);a[Za]=0;Na=kd(j|0)|0;Pa=e+12|0;c[Pa>>2]=Na;if((Na|0)<1){KIb(Sa,16,2166168,(bb=i,i=i+8|0,c[bb>>2]=Na,bb)|0);i=bb;c[Pa>>2]=255;break}if((Na|0)<=255){break}Pa=c[Ra>>2]|0;do{if((Pa|0)==8){c[Ra>>2]=32;break G}else if((Pa|0)==2){c[Ra>>2]=42;break G}else if((Pa|0)==0){if((Na|0)>=65536){break}if((Na|0)<512){c[Ra>>2]=70;break G}if((Na|0)<1024){c[Ra>>2]=72;break G}else{c[Ra>>2]=54;break G}}}while(0);KIb(Sa,16,2139888,(bb=i,i=i+1|0,i=i+7&-8,c[bb>>2]=0,bb)|0);i=bb;c[Ra>>2]=-1;E=-1094995529;i=f;return E|0}}while(0);if((a[(qKb(c[Ra>>2]|0)|0)+7|0]&16)==0){E=0;i=f;return E|0}if((c[Ma>>2]&1|0)!=0){E=-1094995529;i=f;return E|0}Ma=c[Ja>>2]<<1;if(((Ma|0)%3|0|0)!=0){E=-1094995529;i=f;return E|0}c[Ja>>2]=(Ma|0)/3|0;E=0;i=f;return E|0}function Lrb(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=b|0;c[k>>2]=e;l=b+8|0;c[l>>2]=pJb((c[e+416>>2]|0)*5128|0)|0;e=b+12|0;c[e>>2]=pJb(i*212|0)|0;m=f<<2;f=b+20|0;c[f>>2]=hJb(m)|0;n=b+24|0;c[n>>2]=hJb(m)|0;nrc(c[f>>2]|0,g|0,m)|0;nrc(c[n>>2]|0,h|0,m)|0;if((i|0)>0){m=0;h=0;n=c[e>>2]|0;while(1){a[n+(m*212|0)+80|0]=(a[j+m|0]|0)+1;g=c[e>>2]|0;if((a[g+(m*212|0)+80|0]|0)==0){o=h;p=g}else{f=0;q=h;r=g;while(1){g=q+1|0;c[r+(m*212|0)+(f<<2)>>2]=(c[l>>2]|0)+(q*2564|0);s=f+1|0;t=c[e>>2]|0;if((s|0)<(d[t+(m*212|0)+80|0]<<1|0)){f=s;q=g;r=t}else{o=g;p=t;break}}}r=m+1|0;if((r|0)<(i|0)){m=r;h=o;n=p}else{break}}}p=b+4|0;if((c[(c[k>>2]|0)+48>>2]|0)==86018){c[p>>2]=1446152;u=1446152}else{u=c[p>>2]|0}p=c[u+4>>2]|0;if((p|0)==0){v=0;return v|0}v=ve[p&4095](b)|0;return v|0}function Mrb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[a+12>>2]|0;if((b|0)<0){f=-1;g=e+(f*212|0)|0;return g|0}else{h=0;i=0}while(1){a=(d[e+(h*212|0)+80|0]|0)+i|0;if((a|0)>(b|0)){f=h;break}else{h=h+1|0;i=a}}g=e+(f*212|0)|0;return g|0}function Nrb(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;do{if((b|0)!=0){d=c[b+16>>2]|0;if((d|0)==0){break}qe[d&1023](a)}}while(0);mJb(a+20|0);mJb(a+24|0);mJb(a+12|0);mJb(a+8|0);return}function Orb(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0.0,h=0.0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=pJb(20)|0;d=b;c[b>>2]=a;e=c[a+436>>2]|0;if((e|0)>0){f=+(e|0)*2.0/+(c[a+412>>2]|0);if(f!=0.0){g=f}else{h=f;i=3}}else{h=0.0;i=3}do{if((i|0)==3){if((c[a+48>>2]|0)!=86018){g=h;break}e=c[a+72>>2]|0;if((e|0)==0){j=c[a+412>>2]|0;k=(j|0)/2|0;l=j}else{j=((e|0)/8|0)+4e3|0;m=((e|0)/32|0)+12e3|0;e=(j|0)>(m|0)?m:j;j=c[a+412>>2]|0;m=(j|0)/2|0;k=(e|0)>(m|0)?m:e;l=j}g=+(k|0)*2.0/+(l|0)}}while(0);if(g!=0.0&g<.98){l=bvb(a,2,0,4,g,0.0,0.0)|0;c[b+8>>2]=l;n=l}else{n=c[b+8>>2]|0}if((n|0)==0){o=b+16|0;p=o;gvb(p);return d|0}n=a+416|0;a=b+12|0;c[a>>2]=pJb(c[n>>2]<<2)|0;if((c[n>>2]|0)>0){q=0}else{o=b+16|0;p=o;gvb(p);return d|0}do{l=dvb(4)|0;c[(c[a>>2]|0)+(q<<2)>>2]=l;q=q+1|0;}while((q|0)<(c[n>>2]|0));o=b+16|0;p=o;gvb(p);return d|0}function Prb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[(c[a>>2]|0)+424>>2]|0;f=a+12|0;g=c[f>>2]|0;if(!((g|0)!=0&(d|0)>0)){return}h=a+16|0;i=a+8|0;a=0;j=g;while(1){g=(c[b+(a<<2)>>2]|0)+(e<<2)|0;Se[c[h>>2]&1023](c[i>>2]|0,c[j+(a<<2)>>2]|0,e,g,1,g,1);g=a+1|0;if((g|0)>=(d|0)){break}a=g;j=c[f>>2]|0}return}function Qrb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;cvb(c[a+8>>2]|0);b=a+12|0;d=c[b>>2]|0;a:do{if((d|0)!=0){e=a|0;if((c[(c[e>>2]|0)+416>>2]|0)>0){f=0;g=d}else{break}while(1){fvb(c[g+(f<<2)>>2]|0);h=f+1|0;if((h|0)>=(c[(c[e>>2]|0)+416>>2]|0)){break a}f=h;g=c[b>>2]|0}}}while(0);mJb(b);kJb(a);return}function Rrb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+(146-c<<1)|0;b=(c|0)<40;nrc(a|0,d|0,b?c<<1:80)|0;if(!b){return}nrc(a+(c<<1)|0,d|0,40-c<<1)|0;return}function Srb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+80|0;g=f+40|0;h=g|0;c[h>>2]=b[d>>1]|0;c[g+4>>2]=b[d+2>>1]|0;c[g+8>>2]=b[d+4>>1]|0;c[g+12>>2]=b[d+6>>1]|0;c[g+16>>2]=b[d+8>>1]|0;c[g+20>>2]=b[d+10>>1]|0;c[g+24>>2]=b[d+12>>1]|0;c[g+28>>2]=b[d+14>>1]|0;c[g+32>>2]=b[d+16>>1]|0;j=b[d+18>>1]|0;c[g+36>>2]=j;c[a+36>>2]=j;if((j+4096|0)>>>0>8191>>>0){KIb(e,16,2424264,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;k=1;i=f;return k|0}e=8;g=f|0;d=h;h=j;while(1){j=e+1|0;l=c[d+(j<<2)>>2]|0;m=(ca(l,l)|0)>>>12;l=16777216/(((m|0)==4096?-2:4096-m|0)|0)|0;m=a+(j<<2)|0;j=0;n=h;while(1){c[g+(j<<2)>>2]=(ca((c[d+(j<<2)>>2]|0)-((ca(c[d+(e-j<<2)>>2]|0,n)|0)>>12)|0,l)|0)>>12;o=j+1|0;if((o|0)>(e|0)){break}j=o;n=c[m>>2]|0}m=c[g+(e<<2)>>2]|0;if((m+4096|0)>>>0>8191>>>0){k=1;p=9;break}c[a+(e<<2)>>2]=m;if((e|0)>0){n=g;g=d;e=e-1|0;h=m;d=n}else{k=0;p=9;break}}if((p|0)==9){i=f;return k|0}return 0}function Trb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+40|0;e=a;f=0;g=d|0;while(1){h=b+(f<<2)|0;c[g+(f<<2)>>2]=c[h>>2]<<4;if((f|0)>0){j=f-1|0;k=0;do{l=(ca(c[e+(j-k<<2)>>2]|0,c[h>>2]|0)|0)>>12;c[g+(k<<2)>>2]=l+(c[e+(k<<2)>>2]|0);k=k+1|0;}while((k|0)<(f|0))}k=f+1|0;if((k|0)<10){h=e;e=g;f=k;g=h}else{break}}c[a>>2]=c[a>>2]>>4;g=a+4|0;c[g>>2]=c[g>>2]>>4;g=a+8|0;c[g>>2]=c[g>>2]>>4;g=a+12|0;c[g>>2]=c[g>>2]>>4;g=a+16|0;c[g>>2]=c[g>>2]>>4;g=a+20|0;c[g>>2]=c[g>>2]>>4;g=a+24|0;c[g>>2]=c[g>>2]>>4;g=a+28|0;c[g>>2]=c[g>>2]>>4;g=a+32|0;c[g>>2]=c[g>>2]>>4;g=a+36|0;c[g>>2]=c[g>>2]>>4;i=d;return}function Urb(a,d){a=a|0;d=d|0;b[a>>1]=c[d>>2];b[a+2>>1]=c[d+4>>2];b[a+4>>1]=c[d+8>>2];b[a+6>>1]=c[d+12>>2];b[a+8>>1]=c[d+16>>2];b[a+10>>1]=c[d+20>>2];b[a+12>>1]=c[d+24>>2];b[a+14>>1]=c[d+28>>2];b[a+16>>1]=c[d+32>>2];b[a+18>>1]=c[d+36>>2];return}function Vrb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(a>>>0>4095>>>0){b=a;e=2;while(1){f=e+1|0;g=b>>>2;if(b>>>0>16383>>>0){b=g;e=f}else{h=g;i=f;break}}}else{h=a;i=2}a=h<<20;if(a>>>0<255>>>0){j=(d[1303320+(a|1)|0]|0)-1>>4;k=j<<i;return k|0}do{if(a>>>0<4096>>>0){l=(d[1303320+(h<<16&268369920)|0]|0)>>>2}else{if(a>>>0<16384>>>0){l=(d[1303320+(h<<14&67092480)|0]|0)>>>1;break}if(a>>>0<65536>>>0){l=d[1303320+(h<<12&16773120)|0]|0;break}else{e=h<<4;b=(e&65280|0)==0;f=((d[1359664+(b?e&65520:h>>>4&255)|0]|0)+(b?0:8)|0)>>>1;b=a>>>((f+2|0)>>>0);e=d[1303320+(b>>>((f+8|0)>>>0))|0]|0;Erc(b,0,c[1367848+(e<<2)>>2]|0,0)|0;l=G+(e<<f)|0;break}}}while(0);j=l-((ca(l,l)|0)>>>0>a>>>0)|0;k=j<<i;return k|0}function Wrb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=0;d=65536;e=10;while(1){f=c[a+(b<<2)>>2]|0;g=ca(16777216-(ca(f,f)|0)>>12,d)|0;f=g>>>12;if((f|0)==0){h=0;i=7;break}if(g>>>0<67108864>>>0){g=f;j=e;while(1){k=j+1|0;l=g<<2;if(l>>>0<16384>>>0){g=l;j=k}else{m=l;n=k;break}}}else{m=f;n=e}j=b+1|0;if((j|0)<10){b=j;d=m;e=n}else{break}}if((i|0)==7){return h|0}h=(Vrb(m)|0)>>n;return h|0}function Xrb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;i=i+40|0;j=h|0;k=4-e|0;l=c[a+1388>>2]|0;m=c[a+1392>>2]|0;n=ca(c[l>>2]|0,e)|0;b[d>>1]=((ca(c[m>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+4>>2]|0,e)|0;o=d+2|0;b[o>>1]=((ca(c[m+4>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+8>>2]|0,e)|0;p=d+4|0;b[p>>1]=((ca(c[m+8>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+12>>2]|0,e)|0;q=d+6|0;b[q>>1]=((ca(c[m+12>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+16>>2]|0,e)|0;r=d+8|0;b[r>>1]=((ca(c[m+16>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+20>>2]|0,e)|0;s=d+10|0;b[s>>1]=((ca(c[m+20>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+24>>2]|0,e)|0;t=d+12|0;b[t>>1]=((ca(c[m+24>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+28>>2]|0,e)|0;u=d+14|0;b[u>>1]=((ca(c[m+28>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+32>>2]|0,e)|0;v=d+16|0;b[v>>1]=((ca(c[m+32>>2]|0,k)|0)+n|0)>>>2;n=ca(c[l+36>>2]|0,e)|0;e=d+18|0;b[e>>1]=((ca(c[m+36>>2]|0,k)|0)+n|0)>>>2;if((Srb(j|0,d,c[a>>2]|0)|0)==0){w=0;x=65536;y=10}else{n=c[a+1388+(f<<2)>>2]|0;b[d>>1]=c[n>>2];b[o>>1]=c[n+4>>2];b[p>>1]=c[n+8>>2];b[q>>1]=c[n+12>>2];b[r>>1]=c[n+16>>2];b[s>>1]=c[n+20>>2];b[t>>1]=c[n+24>>2];b[u>>1]=c[n+28>>2];b[v>>1]=c[n+32>>2];b[e>>1]=c[n+36>>2];z=c[a+1396+(f<<2)>>2]|0;A=ca(z,g)|0;B=A>>>10;i=h;return B|0}while(1){f=c[j+(w<<2)>>2]|0;a=ca(16777216-(ca(f,f)|0)>>12,x)|0;f=a>>>12;if((f|0)==0){z=0;C=8;break}if(a>>>0<67108864>>>0){a=f;n=y;while(1){e=n+1|0;v=a<<2;if(v>>>0<16384>>>0){a=v;n=e}else{D=v;E=e;break}}}else{D=f;E=y}n=w+1|0;if((n|0)<10){w=n;x=D;y=E}else{break}}if((C|0)==8){A=ca(z,g)|0;B=A>>>10;i=h;return B|0}z=(Vrb(D)|0)>>E;A=ca(z,g)|0;B=A>>>10;i=h;return B|0}function Yrb(a,b){a=a|0;b=b|0;return(ca(b,a)|0)>>>10|0}function Zrb(a,b){a=a|0;b=b|0;var d=0,e=0;d=Ee[c[a+1224>>2]&511](b,b,40)|0;if((d|0)==0){e=0;return e|0}e=536870912/((Vrb(d)|0)>>8|0)|0;return e|0}function _rb(f,g,h,j,k,l,m){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=i;i=i+32|0;o=n|0;p=n+16|0;if((h|0)==0){c[p>>2]=0;q=1;r=f+2128|0}else{s=h+19|0;t=f+2128|0;u=f+1824+(127-h<<1)|0;v=(s|0)<40;nrc(t|0,u|0,v?s<<1:80)|0;if(v){nrc(f+2128+(s<<1)|0,u|0,21-h<<1)|0}h=Ee[c[f+1228>>2]&511](t,t,40)|0;if((h|0)==0){w=0}else{w=536870912/((Vrb(h)|0)>>8|0)|0}c[p>>2]=(ca(w,l)|0)>>12;q=(s|0)==0;r=t}c[p+4>>2]=(ca(e[1423472+(j<<1)>>1]|0,l)|0)>>8;c[p+8>>2]=(ca(e[1418096+(k<<1)>>1]|0,l)|0)>>8;orc(f+1824|0,f+1904|0,212)|0;l=o|0;c[l>>2]=0;t=d[1384904+m|0]|0;s=q&1;do{c[o+(s<<2)>>2]=(ca(b[1383368+(m*6|0)+(s<<1)>>1]|0,c[p+(s<<2)>>2]|0)|0)>>t;s=s+1|0;}while((s|0)<3);s=f+2036|0;t=q?0:r;r=c[l>>2]|0;l=c[o+4>>2]|0;q=c[o+8>>2]|0;if((r|0)==0){o=0;do{p=ca(a[1418352+(j*40|0)+o|0]|0,l)|0;b[f+1824+(o+106<<1)>>1]=((ca(a[1412976+(k*40|0)+o|0]|0,q)|0)+p|0)>>>12;o=o+1|0;}while((o|0)<40)}else{o=0;do{p=ca(b[t+(o<<1)>>1]|0,r)|0;m=(ca(a[1418352+(j*40|0)+o|0]|0,l)|0)+p|0;b[f+1824+(o+106<<1)>>1]=(m+(ca(a[1412976+(k*40|0)+o|0]|0,q)|0)|0)>>>12;o=o+1|0;}while((o|0)<40)}o=f+1724|0;nrc(o|0,f+1804|0,20)|0;if((L3(f+1744|0,g,s,40,10,1,0,4095)|0)==0){i=n;return}mrc(o|0,0,100)|0;i=n;return}function $rb(b,c,d,e,f,g,h,i,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a:do{if((f|0)>0){k=(e|0)==1;l=e+1|0;m=b+c|0;n=d;o=0;p=b;b:while(1){q=f-o|0;r=n+e|0;s=(q|0)<127?q:127;c:do{if((s|0)>1){d:do{if(k){q=a[n]|0;t=1;u=r;while(1){if(!(q<<24>>24==(a[u]|0))){v=t;break d}w=t+1|0;if((w|0)<(s|0)){t=w;u=u+1|0}else{v=w;break}}}else{u=n;t=1;q=r;while(1){if((grc(u,q,e)|0)!=0){v=t;break d}w=t+1|0;if((w|0)<(s|0)){u=q;t=w;q=q+e|0}else{v=w;break}}}}while(0);if((v|0)>1){if((p+l|0)>>>0>m>>>0){x=-1;y=26;break b}a[p]=(v^h)+g;nrc(p+1|0,n|0,e)|0;z=e;A=v;break}e:do{if(k){q=n;t=1;u=r;w=a[n]|0;while(1){B=a[u]|0;C=t+1|0;if(w<<24>>24==B<<24>>24){if((C|0)>=(s|0)){D=t;break e}if(w<<24>>24==(a[q+l|0]|0)){D=t;break e}}if((C|0)<(s|0)){q=u;t=C;u=u+1|0;w=B}else{E=C;y=22;break c}}}else{w=n;u=1;t=r;while(1){if((grc(w,t,e)|0)==0){D=u;break e}q=u+1|0;if((q|0)<(s|0)){w=t;u=q;t=t+e|0}else{E=q;y=22;break c}}}}while(0);E=D-1|0;y=22}else{E=1;y=22}}while(0);if((y|0)==22){y=0;s=ca(E,e)|0;if(!((p+s|0)>>>0<m>>>0)){x=-1;y=26;break}a[p]=(E^j)+i;nrc(p+1|0,n|0,s)|0;z=s;A=E}s=p+(z+1)|0;r=n+(ca(A,e)|0)|0;t=A+o|0;if((t|0)<(f|0)){n=r;o=t;p=s}else{F=s;break a}}if((y|0)==26){return x|0}}else{F=b}}while(0);x=F-b|0;return x|0}function asb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=b+12|0;b=c[g>>2]|0;h=c[b+32>>2]|0;i=(ca(h,e)|0)+d|0;j=c[b>>2]|0;a[j+i|0]=a[f|0]|0;a[j+(i+1)|0]=a[f+1|0]|0;a[j+(i+h)|0]=a[f+2|0]|0;a[j+(h+1+i)|0]=a[f+3|0]|0;i=c[g>>2]|0;h=c[i+36>>2]|0;j=(ca(h,e)|0)+d|0;d=c[i+4>>2]|0;i=a[f+4|0]|0;e=h+1+j|0;a[d+e|0]=i;b=j+h|0;a[d+b|0]=i;h=j+1|0;a[d+h|0]=i;a[d+j|0]=i;i=c[(c[g>>2]|0)+8>>2]|0;g=a[f+5|0]|0;a[i+e|0]=g;a[i+b|0]=g;a[i+h|0]=g;a[i+j|0]=g;return}function bsb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=b+12|0;b=c[g>>2]|0;h=c[b+32>>2]|0;i=(ca(h,e)|0)+d|0;j=c[b>>2]|0;b=a[f|0]|0;a[j+(h+1+i)|0]=b;a[j+(i+h)|0]=b;a[j+(i+1)|0]=b;a[j+i|0]=b;b=a[f+1|0]|0;a[j+(h+3+i)|0]=b;a[j+(h+2+i)|0]=b;a[j+(i+3)|0]=b;a[j+(i+2)|0]=b;b=a[f+2|0]|0;k=h*3|0;a[j+(k+1+i)|0]=b;a[j+(i+k)|0]=b;l=h<<1;a[j+(i+(l|1))|0]=b;a[j+(i+l)|0]=b;b=a[f+3|0]|0;a[j+(k+3+i)|0]=b;a[j+(k+2+i)|0]=b;a[j+(l+3+i)|0]=b;a[j+(l+2+i)|0]=b;b=c[g>>2]|0;i=c[b+36>>2]|0;l=(ca(i,e)|0)+d|0;d=c[b+4>>2]|0;b=a[f+4|0]|0;e=i*3|0;j=e+3+l|0;a[d+j|0]=b;k=e+2+l|0;a[d+k|0]=b;h=i<<1;m=h+3+l|0;a[d+m|0]=b;n=h+2+l|0;a[d+n|0]=b;o=e+1+l|0;a[d+o|0]=b;p=l+e|0;a[d+p|0]=b;e=l+(h|1)|0;a[d+e|0]=b;q=l+h|0;a[d+q|0]=b;h=i+3+l|0;a[d+h|0]=b;r=i+2+l|0;a[d+r|0]=b;s=l+3|0;a[d+s|0]=b;t=l+2|0;a[d+t|0]=b;u=i+1+l|0;a[d+u|0]=b;v=l+i|0;a[d+v|0]=b;i=l+1|0;a[d+i|0]=b;a[d+l|0]=b;b=c[(c[g>>2]|0)+8>>2]|0;g=a[f+5|0]|0;a[b+j|0]=g;a[b+k|0]=g;a[b+m|0]=g;a[b+n|0]=g;a[b+o|0]=g;a[b+p|0]=g;a[b+e|0]=g;a[b+q|0]=g;a[b+h|0]=g;a[b+r|0]=g;a[b+s|0]=g;a[b+t|0]=g;a[b+u|0]=g;a[b+v|0]=g;a[b+i|0]=g;a[b+l|0]=g;return}function csb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dsb(a,b,c,d,e,4);return}function dsb(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=e+b|0;e=f+d|0;f=c[a+5664>>2]|0;do{if((j|0)>=0){if((j|0)>(f-g|0)|(e|0)<0){break}if((e|0)>((c[a+5668>>2]|0)-g|0)){break}k=a+8|0;l=c[k>>2]|0;m=c[l>>2]|0;if((m|0)==0){KIb(c[a+4>>2]|0,16,2580864,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;i=h;return}o=a+12|0;if((g|0)==0){i=h;return}p=c[o>>2]|0;q=c[p+32>>2]|0;r=c[l+32>>2]|0;l=(ca(r,e)|0)+j|0;s=(ca(q,d)|0)+b|0;t=m+l|0;l=(c[p>>2]|0)+s|0;s=g;while(1){p=s-1|0;nrc(l|0,t|0,g)|0;if((p|0)==0){break}else{t=t+r|0;l=l+q|0;s=p}}s=c[o>>2]|0;q=c[k>>2]|0;l=c[s+36>>2]|0;r=c[q+36>>2]|0;t=ca(l,d)|0;p=(ca(r,e)|0)+j|0;m=(c[q+4>>2]|0)+p|0;p=(c[s+4>>2]|0)+(t+b)|0;t=g;while(1){s=t-1|0;nrc(p|0,m|0,g)|0;if((s|0)==0){break}else{m=m+r|0;p=p+l|0;t=s}}t=c[o>>2]|0;l=c[k>>2]|0;p=c[t+40>>2]|0;r=c[l+40>>2]|0;m=ca(p,d)|0;s=(ca(r,e)|0)+j|0;q=(c[l+8>>2]|0)+s|0;s=(c[t+8>>2]|0)+(m+b)|0;m=g;while(1){t=m-1|0;nrc(s|0,q|0,g)|0;if((t|0)==0){break}else{q=q+r|0;s=s+p|0;m=t}}i=h;return}}while(0);g=c[a+5668>>2]|0;KIb(c[a+4>>2]|0,16,2424088,(n=i,i=i+32|0,c[n>>2]=j,c[n+8>>2]=e,c[n+16>>2]=f,c[n+24>>2]=g,n)|0);i=n;i=h;return}function esb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dsb(a,b,c,d,e,8);return}function fsb(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+544|0;d=b|0;e=b+32|0;Ysb(a);Mia(d,8);nta(e,8);c[a>>2]=c[e>>2];c[a+4>>2]=1138;c[a+8>>2]=1228;c[a+16>>2]=196;c[a+20>>2]=1468;c[a+24>>2]=1554;c[a+32>>2]=2280;c[a+36>>2]=524;c[a+40>>2]=2;c[a+256>>2]=c[e+256>>2];c[a+260>>2]=676;c[a+264>>2]=1580;c[a+272>>2]=252;c[a+276>>2]=1626;c[a+280>>2]=1232;c[a+288>>2]=1764;c[a+292>>2]=72;c[a+296>>2]=314;c[a+64>>2]=c[e+64>>2];c[a+68>>2]=154;c[a+72>>2]=418;c[a+80>>2]=1406;c[a+84>>2]=2244;c[a+88>>2]=346;c[a+96>>2]=1422;c[a+100>>2]=1052;c[a+104>>2]=1896;c[a+320>>2]=c[e+320>>2];c[a+324>>2]=1924;c[a+328>>2]=176;c[a+336>>2]=2120;c[a+340>>2]=980;c[a+344>>2]=1098;c[a+352>>2]=626;c[a+356>>2]=1312;c[a+360>>2]=1982;c[a+512>>2]=c[d>>2];c[a+516>>2]=c[d+4>>2];c[a+524>>2]=c[d+16>>2];c[a+528>>2]=c[d+20>>2];i=b;return}function gsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Xsb(a,b,c,c,12,6);Xsb(a+8|0,b+8|0,c,c,12,6);d=c<<3;Xsb(a+d|0,b+d|0,c,c,12,6);e=d+8|0;Xsb(a+e|0,b+e|0,c,c,12,6);return}function hsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Xsb(a,b,c,c,6,12);Xsb(a+8|0,b+8|0,c,c,6,12);d=c<<3;Xsb(a+d|0,b+d|0,c,c,6,12);e=d+8|0;Xsb(a+e|0,b+e|0,c,c,6,12);return}function isb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Usb(a,b,c,c,12,6);Usb(a+8|0,b+8|0,c,c,12,6);d=c<<3;Usb(a+d|0,b+d|0,c,c,12,6);e=d+8|0;Usb(a+e|0,b+e|0,c,c,12,6);return}function jsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Wsb(a,b,c,c);Wsb(a+8|0,b+8|0,c,c);d=c<<3;Wsb(a+d|0,b+d|0,c,c);e=d+8|0;Wsb(a+e|0,b+e|0,c,c);return}function ksb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Vsb(a,b,c,c);Vsb(a+8|0,b+8|0,c,c);d=c<<3;Vsb(a+d|0,b+d|0,c,c);e=d+8|0;Vsb(a+e|0,b+e|0,c,c);return}function lsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Usb(a,b,c,c,6,12);Usb(a+8|0,b+8|0,c,c,6,12);d=c<<3;Usb(a+d|0,b+d|0,c,c,6,12);e=d+8|0;Usb(a+e|0,b+e|0,c,c,6,12);return}function msb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Tsb(a,b,c,c);Tsb(a+8|0,b+8|0,c,c);d=c<<3;Tsb(a+d|0,b+d|0,c,c);e=d+8|0;Tsb(a+e|0,b+e|0,c,c);return}function nsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Ssb(a,b,c,c);Ssb(a+8|0,b+8|0,c,c);d=c<<3;Ssb(a+d|0,b+d|0,c,c);e=d+8|0;Ssb(a+e|0,b+e|0,c,c);return}function osb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Rsb(a,b,c,c,12,6);Rsb(a+8|0,b+8|0,c,c,12,6);d=c<<3;Rsb(a+d|0,b+d|0,c,c,12,6);e=d+8|0;Rsb(a+e|0,b+e|0,c,c,12,6);return}function psb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Rsb(a,b,c,c,6,12);Rsb(a+8|0,b+8|0,c,c,6,12);d=c<<3;Rsb(a+d|0,b+d|0,c,c,6,12);e=d+8|0;Rsb(a+e|0,b+e|0,c,c,6,12);return}function qsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Osb(a,b,c,c,12,6);Osb(a+8|0,b+8|0,c,c,12,6);d=c<<3;Osb(a+d|0,b+d|0,c,c,12,6);e=d+8|0;Osb(a+e|0,b+e|0,c,c,12,6);return}function rsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Qsb(a,b,c,c);Qsb(a+8|0,b+8|0,c,c);d=c<<3;Qsb(a+d|0,b+d|0,c,c);e=d+8|0;Qsb(a+e|0,b+e|0,c,c);return}function ssb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Psb(a,b,c,c);Psb(a+8|0,b+8|0,c,c);d=c<<3;Psb(a+d|0,b+d|0,c,c);e=d+8|0;Psb(a+e|0,b+e|0,c,c);return}function tsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Osb(a,b,c,c,6,12);Osb(a+8|0,b+8|0,c,c,6,12);d=c<<3;Osb(a+d|0,b+d|0,c,c,6,12);e=d+8|0;Osb(a+e|0,b+e|0,c,c,6,12);return}function usb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Nsb(a,b,c,c);Nsb(a+8|0,b+8|0,c,c);d=c<<3;Nsb(a+d|0,b+d|0,c,c);e=d+8|0;Nsb(a+e|0,b+e|0,c,c);return}function vsb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Msb(a,b,c,c);Msb(a+8|0,b+8|0,c,c);d=c<<3;Msb(a+d|0,b+d|0,c,c);e=d+8|0;Msb(a+e|0,b+e|0,c,c);return}function wsb(a,b,c){a=a|0;b=b|0;c=c|0;Xsb(a,b,c,c,12,6);return}function xsb(a,b,c){a=a|0;b=b|0;c=c|0;Xsb(a,b,c,c,6,12);return}function ysb(a,b,c){a=a|0;b=b|0;c=c|0;Usb(a,b,c,c,12,6);return}function zsb(a,b,c){a=a|0;b=b|0;c=c|0;Wsb(a,b,c,c);return}function Asb(a,b,c){a=a|0;b=b|0;c=c|0;Vsb(a,b,c,c);return}function Bsb(a,b,c){a=a|0;b=b|0;c=c|0;Usb(a,b,c,c,6,12);return}function Csb(a,b,c){a=a|0;b=b|0;c=c|0;Tsb(a,b,c,c);return}function Dsb(a,b,c){a=a|0;b=b|0;c=c|0;Ssb(a,b,c,c);return}function Esb(a,b,c){a=a|0;b=b|0;c=c|0;Rsb(a,b,c,c,12,6);return}function Fsb(a,b,c){a=a|0;b=b|0;c=c|0;Rsb(a,b,c,c,6,12);return}function Gsb(a,b,c){a=a|0;b=b|0;c=c|0;Osb(a,b,c,c,12,6);return}function Hsb(a,b,c){a=a|0;b=b|0;c=c|0;Qsb(a,b,c,c);return}function Isb(a,b,c){a=a|0;b=b|0;c=c|0;Psb(a,b,c,c);return}function Jsb(a,b,c){a=a|0;b=b|0;c=c|0;Osb(a,b,c,c,6,12);return}function Ksb(a,b,c){a=a|0;b=b|0;c=c|0;Nsb(a,b,c,c);return}function Lsb(a,b,c){a=a|0;b=b|0;c=c|0;Msb(a,b,c,c);return}function Msb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=c+i|0;k=i+1|0;l=i+2|0;a[j]=((d[j]|0)+1+(d[(((d[h+i|0]|0)*36|0)+128+((d[h+(k+f)|0]|0)*81|0)+(d[h+(l+g)|0]|0)+(((d[h+(k+g)|0]|0)+(d[h+(l+f)|0]|0)|0)*9|0)+(((d[h+(i+g)|0]|0)+(d[h+l|0]|0)|0)*6|0)+(((d[h+(i+f)|0]|0)+(d[h+k|0]|0)|0)*54|0)>>8)+1404400|0]|0)|0)>>>1;if((k|0)<8){i=k}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Nsb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=c+i|0;k=i-f|0;l=i+1|0;m=i+f|0;n=i+g|0;a[j]=((d[j]|0)+1+(d[((d[h+(k-1)|0]|0)+128+(d[h+(k+2)|0]|0)+((d[h+l|0]|0)*36|0)+((d[h+m|0]|0)*144|0)+(d[h+(n-1)|0]|0)+(d[h+(n+2)|0]|0)+(((d[h+(i-1)|0]|0)+(d[h+(k+1)|0]|0)+(d[h+(i+2)|0]|0)+(d[h+(n+1)|0]|0)|0)*-6|0)+(((d[h+(m-1)|0]|0)+(d[h+k|0]|0)+(d[h+(m+2)|0]|0)+(d[h+n|0]|0)|0)*-12|0)+(((d[h+(m+1)|0]|0)+(d[h+i|0]|0)|0)*72|0)>>8)+1404400|0]|0)|0)>>>1;if((l|0)<8){i=l}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Osb(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=-f|0;j=f<<1;k=f*3|0;l=f<<2;m=f*5|0;n=f*6|0;o=f*7|0;p=f<<3;q=f*9|0;r=e<<1;s=e*3|0;t=e<<2;u=e*5|0;v=e*6|0;w=e*7|0;x=0;y=c;c=b;while(1){b=d[y]|0;z=d[y+f|0]|0;A=d[y+j|0]|0;B=d[y+k|0]|0;C=d[y+l|0]|0;D=d[y+m|0]|0;E=d[y+n|0]|0;F=d[y+o|0]|0;G=d[y+p|0]|0;H=d[y+q|0]|0;a[c]=((d[c]|0)+1+(d[(8-(d[y+i|0]|0)+(ca(b,g)|0)-A+(ca(z,h)|0)>>4)+1404400|0]|0)|0)>>>1;I=c+e|0;a[I]=((d[I]|0)+1+(d[(8-b+(ca(z,g)|0)-B+(ca(A,h)|0)>>4)+1404400|0]|0)|0)>>>1;b=c+r|0;a[b]=((d[b]|0)+1+(d[(8-z+(ca(A,g)|0)-C+(ca(B,h)|0)>>4)+1404400|0]|0)|0)>>>1;z=c+s|0;a[z]=((d[z]|0)+1+(d[(8-A+(ca(B,g)|0)-D+(ca(C,h)|0)>>4)+1404400|0]|0)|0)>>>1;A=c+t|0;a[A]=((d[A]|0)+1+(d[(8-B+(ca(C,g)|0)-E+(ca(D,h)|0)>>4)+1404400|0]|0)|0)>>>1;B=c+u|0;a[B]=((d[B]|0)+1+(d[(8-C+(ca(D,g)|0)-F+(ca(E,h)|0)>>4)+1404400|0]|0)|0)>>>1;C=c+v|0;a[C]=((d[C]|0)+1+(d[(8-D+(ca(E,g)|0)-G+(ca(F,h)|0)>>4)+1404400|0]|0)|0)>>>1;D=c+w|0;a[D]=((d[D]|0)+1+(d[(8-E+(ca(F,g)|0)-H+(ca(G,h)|0)>>4)+1404400|0]|0)|0)>>>1;G=x+1|0;if((G|0)<8){x=G;y=y+1|0;c=c+1|0}else{break}}return}function Psb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=c+i|0;k=i-f|0;l=i+1|0;m=i+f|0;n=i+g|0;a[j]=((d[j]|0)+1+(d[((d[h+(k-1)|0]|0)+128+(d[h+(k+2)|0]|0)+((d[h+l|0]|0)*144|0)+((d[h+m|0]|0)*36|0)+(d[h+(n-1)|0]|0)+(d[h+(n+2)|0]|0)+(((d[h+(m-1)|0]|0)+(d[h+k|0]|0)+(d[h+(m+2)|0]|0)+(d[h+n|0]|0)|0)*-6|0)+(((d[h+(i-1)|0]|0)+(d[h+(k+1)|0]|0)+(d[h+(i+2)|0]|0)+(d[h+(n+1)|0]|0)|0)*-12|0)+(((d[h+(m+1)|0]|0)+(d[h+i|0]|0)|0)*72|0)>>8)+1404400|0]|0)|0)>>>1;if((l|0)<8){i=l}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Qsb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=c+i|0;k=i-f|0;l=i+1|0;m=i+f|0;n=i+g|0;a[j]=((d[j]|0)+1+(d[((d[h+(k-1)|0]|0)+128+(d[h+(k+2)|0]|0)+((d[h+i|0]|0)*144|0)+((d[h+(m+1)|0]|0)*36|0)+(d[h+(n-1)|0]|0)+(d[h+(n+2)|0]|0)+(((d[h+(m-1)|0]|0)+(d[h+(k+1)|0]|0)+(d[h+(m+2)|0]|0)+(d[h+(n+1)|0]|0)|0)*-6|0)+(((d[h+(i-1)|0]|0)+(d[h+k|0]|0)+(d[h+(i+2)|0]|0)+(d[h+n|0]|0)|0)*-12|0)+(((d[h+m|0]|0)+(d[h+l|0]|0)|0)*72|0)>>8)+1404400|0]|0)|0)>>>1;if((l|0)<8){i=l}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Rsb(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=c;c=b;b=0;while(1){j=i+2|0;k=ca(d[i]|0,g)|0;l=i+1|0;a[c]=((d[c]|0)+1+(d[(8-(d[i-1|0]|0)-(d[j]|0)+k+(ca(d[l]|0,h)|0)>>4)+1404400|0]|0)|0)>>>1;k=c+1|0;m=i+3|0;n=ca(d[l]|0,g)|0;a[k]=((d[k]|0)+1+(d[(8-(d[i]|0)-(d[m]|0)+n+(ca(d[j]|0,h)|0)>>4)+1404400|0]|0)|0)>>>1;n=c+2|0;k=i+4|0;o=ca(d[j]|0,g)|0;a[n]=((d[n]|0)+1+(d[(8-(d[l]|0)-(d[k]|0)+o+(ca(d[m]|0,h)|0)>>4)+1404400|0]|0)|0)>>>1;o=c+3|0;l=i+5|0;n=ca(d[m]|0,g)|0;a[o]=((d[o]|0)+1+(d[(8-(d[j]|0)-(d[l]|0)+n+(ca(d[k]|0,h)|0)>>4)+1404400|0]|0)|0)>>>1;n=c+4|0;j=i+6|0;o=ca(d[k]|0,g)|0;a[n]=((d[n]|0)+1+(d[(8-(d[m]|0)-(d[j]|0)+o+(ca(d[l]|0,h)|0)>>4)+1404400|0]|0)|0)>>>1;o=c+5|0;m=i+7|0;n=ca(d[l]|0,g)|0;a[o]=((d[o]|0)+1+(d[(8-(d[k]|0)-(d[m]|0)+n+(ca(d[j]|0,h)|0)>>4)+1404400|0]|0)|0)>>>1;n=c+6|0;k=i+8|0;o=ca(d[j]|0,g)|0;a[n]=((d[n]|0)+1+(d[(8-(d[l]|0)-(d[k]|0)+o+(ca(d[m]|0,h)|0)>>4)+1404400|0]|0)|0)>>>1;o=c+7|0;l=ca(d[m]|0,g)|0;a[o]=((d[o]|0)+1+(d[(8-(d[j]|0)-(d[i+9|0]|0)+l+(ca(d[k]|0,h)|0)>>4)+1404400|0]|0)|0)>>>1;k=b+1|0;if((k|0)<8){i=i+f|0;c=c+e|0;b=k}else{break}}return}function Ssb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=i+1|0;k=i+2|0;a[c+i|0]=a[(((d[h+i|0]|0)*36|0)+128+((d[h+(j+f)|0]|0)*81|0)+(d[h+(k+g)|0]|0)+(((d[h+(j+g)|0]|0)+(d[h+(k+f)|0]|0)|0)*9|0)+(((d[h+(i+g)|0]|0)+(d[h+k|0]|0)|0)*6|0)+(((d[h+(i+f)|0]|0)+(d[h+j|0]|0)|0)*54|0)>>8)+1404400|0]|0;if((j|0)<8){i=j}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Tsb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=i-f|0;k=i+1|0;l=i+f|0;m=i+g|0;a[c+i|0]=a[((d[h+(j-1)|0]|0)+128+(d[h+(j+2)|0]|0)+((d[h+k|0]|0)*36|0)+((d[h+l|0]|0)*144|0)+(d[h+(m-1)|0]|0)+(d[h+(m+2)|0]|0)+(((d[h+(i-1)|0]|0)+(d[h+(j+1)|0]|0)+(d[h+(i+2)|0]|0)+(d[h+(m+1)|0]|0)|0)*-6|0)+(((d[h+(l-1)|0]|0)+(d[h+j|0]|0)+(d[h+(l+2)|0]|0)+(d[h+m|0]|0)|0)*-12|0)+(((d[h+(l+1)|0]|0)+(d[h+i|0]|0)|0)*72|0)>>8)+1404400|0]|0;if((k|0)<8){i=k}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Usb(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;i=-f|0;j=f<<1;k=f*3|0;l=f<<2;m=f*5|0;n=f*6|0;o=f*7|0;p=f<<3;q=f*9|0;r=e<<1;s=e*3|0;t=e<<2;u=e*5|0;v=e*6|0;w=e*7|0;x=0;y=c;c=b;while(1){b=d[y]|0;z=d[y+f|0]|0;A=d[y+j|0]|0;B=d[y+k|0]|0;C=d[y+l|0]|0;D=d[y+m|0]|0;E=d[y+n|0]|0;F=d[y+o|0]|0;G=d[y+p|0]|0;H=d[y+q|0]|0;a[c]=a[(8-(d[y+i|0]|0)+(ca(b,g)|0)-A+(ca(z,h)|0)>>4)+1404400|0]|0;a[c+e|0]=a[(8-b+(ca(z,g)|0)-B+(ca(A,h)|0)>>4)+1404400|0]|0;a[c+r|0]=a[(8-z+(ca(A,g)|0)-C+(ca(B,h)|0)>>4)+1404400|0]|0;a[c+s|0]=a[(8-A+(ca(B,g)|0)-D+(ca(C,h)|0)>>4)+1404400|0]|0;a[c+t|0]=a[(8-B+(ca(C,g)|0)-E+(ca(D,h)|0)>>4)+1404400|0]|0;a[c+u|0]=a[(8-C+(ca(D,g)|0)-F+(ca(E,h)|0)>>4)+1404400|0]|0;a[c+v|0]=a[(8-D+(ca(E,g)|0)-G+(ca(F,h)|0)>>4)+1404400|0]|0;a[c+w|0]=a[(8-E+(ca(F,g)|0)-H+(ca(G,h)|0)>>4)+1404400|0]|0;G=x+1|0;if((G|0)<8){x=G;y=y+1|0;c=c+1|0}else{break}}return}function Vsb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=i-f|0;k=i+1|0;l=i+f|0;m=i+g|0;a[c+i|0]=a[((d[h+(j-1)|0]|0)+128+(d[h+(j+2)|0]|0)+((d[h+k|0]|0)*144|0)+((d[h+l|0]|0)*36|0)+(d[h+(m-1)|0]|0)+(d[h+(m+2)|0]|0)+(((d[h+(l-1)|0]|0)+(d[h+j|0]|0)+(d[h+(l+2)|0]|0)+(d[h+m|0]|0)|0)*-6|0)+(((d[h+(i-1)|0]|0)+(d[h+(j+1)|0]|0)+(d[h+(i+2)|0]|0)+(d[h+(m+1)|0]|0)|0)*-12|0)+(((d[h+(l+1)|0]|0)+(d[h+i|0]|0)|0)*72|0)>>8)+1404400|0]|0;if((k|0)<8){i=k}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Wsb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f<<1;h=c;c=b;b=0;while(1){i=0;while(1){j=i-f|0;k=i+1|0;l=i+f|0;m=i+g|0;a[c+i|0]=a[((d[h+(j-1)|0]|0)+128+(d[h+(j+2)|0]|0)+((d[h+i|0]|0)*144|0)+((d[h+(l+1)|0]|0)*36|0)+(d[h+(m-1)|0]|0)+(d[h+(m+2)|0]|0)+(((d[h+(l-1)|0]|0)+(d[h+(j+1)|0]|0)+(d[h+(l+2)|0]|0)+(d[h+(m+1)|0]|0)|0)*-6|0)+(((d[h+(i-1)|0]|0)+(d[h+j|0]|0)+(d[h+(i+2)|0]|0)+(d[h+m|0]|0)|0)*-12|0)+(((d[h+l|0]|0)+(d[h+k|0]|0)|0)*72|0)>>8)+1404400|0]|0;if((k|0)<8){i=k}else{break}}i=b+1|0;if((i|0)<8){h=h+f|0;c=c+e|0;b=i}else{break}}return}function Xsb(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c;c=b;b=0;while(1){j=i+2|0;k=ca(d[i]|0,g)|0;l=i+1|0;a[c]=a[(8-(d[i-1|0]|0)-(d[j]|0)+k+(ca(d[l]|0,h)|0)>>4)+1404400|0]|0;k=i+3|0;m=ca(d[l]|0,g)|0;a[c+1|0]=a[(8-(d[i]|0)-(d[k]|0)+m+(ca(d[j]|0,h)|0)>>4)+1404400|0]|0;m=i+4|0;n=ca(d[j]|0,g)|0;a[c+2|0]=a[(8-(d[l]|0)-(d[m]|0)+n+(ca(d[k]|0,h)|0)>>4)+1404400|0]|0;n=i+5|0;l=ca(d[k]|0,g)|0;a[c+3|0]=a[(8-(d[j]|0)-(d[n]|0)+l+(ca(d[m]|0,h)|0)>>4)+1404400|0]|0;l=i+6|0;j=ca(d[m]|0,g)|0;a[c+4|0]=a[(8-(d[k]|0)-(d[l]|0)+j+(ca(d[n]|0,h)|0)>>4)+1404400|0]|0;j=i+7|0;k=ca(d[n]|0,g)|0;a[c+5|0]=a[(8-(d[m]|0)-(d[j]|0)+k+(ca(d[l]|0,h)|0)>>4)+1404400|0]|0;k=i+8|0;m=ca(d[l]|0,g)|0;a[c+6|0]=a[(8-(d[n]|0)-(d[k]|0)+m+(ca(d[j]|0,h)|0)>>4)+1404400|0]|0;m=ca(d[j]|0,g)|0;a[c+7|0]=a[(8-(d[l]|0)-(d[i+9|0]|0)+m+(ca(d[k]|0,h)|0)>>4)+1404400|0]|0;k=b+1|0;if((k|0)<8){i=i+f|0;c=c+e|0;b=k}else{break}}return}function Ysb(a){a=a|0;c[a+552>>2]=366;c[a+556>>2]=546;c[a+560>>2]=740;c[a+564>>2]=1346;return}function Zsb(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+64|0;e=d|0;f=0;while(1){g=b[a+(f<<1)>>1]|0;h=b[a+(f+8<<1)>>1]|0;j=(h+g|0)*13|0;k=(g-h|0)*13|0;h=b[a+(f+4<<1)>>1]|0;g=b[a+(f+12<<1)>>1]|0;l=(g*-17|0)+(h*7|0)|0;m=(g*7|0)+(h*17|0)|0;h=f<<2;c[e+(h<<2)>>2]=m+j;c[e+((h|1)<<2)>>2]=l+k;c[e+((h|2)<<2)>>2]=k-l;c[e+((h|3)<<2)>>2]=j-m;m=f+1|0;if((m|0)<4){f=m}else{n=0;break}}do{f=c[e+(n<<2)>>2]|0;m=c[e+(n+8<<2)>>2]|0;j=(m+f|0)*39|0;h=(f-m|0)*39|0;m=c[e+(n+4<<2)>>2]|0;f=c[e+(n+12<<2)>>2]|0;l=(f*-51|0)+(m*21|0)|0;k=(f*21|0)+(m*51|0)|0;m=n<<2;b[a+(m<<1)>>1]=(k+j|0)>>>11;b[a+((m|1)<<1)>>1]=(l+h|0)>>>11;b[a+((m|2)<<1)>>1]=(h-l|0)>>>11;b[a+((m|3)<<1)>>1]=(j-k|0)>>>11;n=n+1|0;}while((n|0)<4);i=d;return}function _sb(a){a=a|0;var c=0;c=((b[a>>1]|0)*507|0)>>>11&65535;b[a>>1]=c;b[a+2>>1]=c;b[a+4>>1]=c;b[a+6>>1]=c;b[a+8>>1]=c;b[a+10>>1]=c;b[a+12>>1]=c;b[a+14>>1]=c;b[a+16>>1]=c;b[a+18>>1]=c;b[a+20>>1]=c;b[a+22>>1]=c;b[a+24>>1]=c;b[a+26>>1]=c;b[a+28>>1]=c;b[a+30>>1]=c;return}function $sb(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+64|0;j=h|0;k=0;do{l=b[g+(k<<1)>>1]|0;m=b[g+(k+8<<1)>>1]|0;n=(m+l|0)*13|0;o=(l-m|0)*13|0;m=b[g+(k+4<<1)>>1]|0;l=b[g+(k+12<<1)>>1]|0;p=(l*-17|0)+(m*7|0)|0;q=(l*7|0)+(m*17|0)|0;m=k<<2;c[j+(m<<2)>>2]=q+n;c[j+((m|1)<<2)>>2]=p+o;c[j+((m|2)<<2)>>2]=o-p;c[j+((m|3)<<2)>>2]=n-q;k=k+1|0;}while((k|0)<4);mrc(g|0,0,32)|0;g=0;k=e;while(1){e=c[j+(g<<2)>>2]|0;q=c[j+(g+8<<2)>>2]|0;n=((q+e|0)*13|0)+512|0;m=((e-q|0)*13|0)+512|0;q=c[j+(g+4<<2)>>2]|0;e=c[j+(g+12<<2)>>2]|0;p=(e*-17|0)+(q*7|0)|0;o=(e*7|0)+(q*17|0)|0;q=(o+n>>10)+(d[k]|0)|0;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[k]=r;q=k+1|0;e=(d[q]|0)+(p+m>>10)|0;if(e>>>0>255>>>0){s=-e>>31&255}else{s=e&255}a[q]=s;q=k+2|0;e=(d[q]|0)+(m-p>>10)|0;if(e>>>0>255>>>0){t=-e>>31&255}else{t=e&255}a[q]=t;q=k+3|0;e=(d[q]|0)+(n-o>>10)|0;if(e>>>0>255>>>0){u=-e>>31&255}else{u=e&255}a[q]=u;q=g+1|0;if((q|0)<4){g=q;k=k+f|0}else{break}}i=h;return}function atb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(e*169|0)+512>>10;e=b;b=0;while(1){g=(d[e]|0)+f|0;if(g>>>0>255>>>0){h=-g>>31&255}else{h=g&255}a[e]=h;g=e+1|0;i=(d[g]|0)+f|0;if(i>>>0>255>>>0){j=-i>>31&255}else{j=i&255}a[g]=j;g=e+2|0;i=(d[g]|0)+f|0;if(i>>>0>255>>>0){k=-i>>31&255}else{k=i&255}a[g]=k;g=e+3|0;i=(d[g]|0)+f|0;if(i>>>0>255>>>0){l=-i>>31&255}else{l=i&255}a[g]=l;g=b+1|0;if((g|0)<4){e=e+c|0;b=g}else{break}}return}function btb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=e>>>2;g=d>>>2;if((g|0)==0){return}d=c>>>2;h=e-c|0;if((d|0)==0){return}c=d<<2;e=0;i=b;while(1){b=0;j=i;while(1){ctb(a,j,f,0,0,0);k=b+1|0;if(k>>>0<d>>>0){b=k;j=j+16|0}else{break}}j=e+1|0;if(j>>>0<g>>>0){e=j;i=i+(c+h<<2)|0}else{break}}return}function ctb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=i;i=i+16|0;k=j|0;l=(f|0)!=0;f=-(l&1^1)<<24;m=a|0;n=c[m>>2]|0;o=c[a+4>>2]|0;if((o-n|0)<2){p=0;q=n}else{a=n+2|0;c[m>>2]=a;r=n;p=(d[r]|d[r+1|0]<<8)<<16>>16&65535;q=a}if((o-q|0)<2){s=0;t=q}else{a=q+2|0;c[m>>2]=a;r=q;s=(d[r]|d[r+1|0]<<8)<<16>>16&65535;t=a}a=p<<3|p<<8;r=s<<3|s<<8;q=a>>>5&458759|a&16253176;a=r>>>5&458759|r&16253176;r=p<<5&64512;n=s<<5&64512;u=r>>>6&768|r;r=n>>>6&768|n;c[k>>2]=u|f|q;c[k+4>>2]=r|f|a;if(p>>>0>s>>>0|l){c[k+12>>2]=(((r<<1)+u|0)*21|0)>>>6&65280|f|(((a<<1)+q|0)*21|0)>>>6&16711935;v=((r+(u<<1)|0)*21|0)>>>6;w=((a+(q<<1)|0)*21|0)>>>6}else{c[k+12>>2]=0;v=(r+u|0)>>>1;w=(a+q|0)>>>1}c[k+8>>2]=w&16711935|f|v&65280;if((o-t|0)<4){x=0;y=h;z=g;A=b;B=0}else{c[m>>2]=t+4;m=t;x=0;y=h;z=g;A=b;B=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0}while(1){c[A>>2]=(c[k+((B&3)<<2)>>2]|0)+((z<<24|0>>>8)&251658240|(z<<28|0>>>4));m=z>>>4|y<<28;c[A+4>>2]=(c[k+((B>>>2&3)<<2)>>2]|0)+((m<<24|0>>>8)&251658240|(m<<28|0>>>4));m=z>>>8|y<<24;c[A+8>>2]=(c[k+((B>>>4&3)<<2)>>2]|0)+((m<<24|0>>>8)&251658240|(m<<28|0>>>4));m=z>>>12|y<<20;c[A+12>>2]=(c[k+((B>>>6&3)<<2)>>2]|0)+((m<<24|0>>>8)&251658240|(m<<28|0>>>4));m=z>>>16|y<<16;b=x+1|0;if(b>>>0<4>>>0){x=b;y=y>>>16|0<<16;z=m;A=A+(e<<2)|0;B=B>>>8}else{break}}i=j;return}function dtb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=g>>>2;i=f>>>2;if((i|0)==0){return}f=e>>>2;j=g-e|0;e=a+4|0;g=a|0;if((f|0)==0){return}k=f<<2;l=0;m=b;while(1){b=0;n=m;while(1){o=c[g>>2]|0;if(((c[e>>2]|0)-o|0)<8){p=0;q=0}else{c[g>>2]=o+8;r=o;o=r|0;s=r+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0}ctb(a,n,h,1,q,p);o=b+1|0;if(o>>>0<f>>>0){b=o;n=n+16|0}else{break}}n=l+1|0;if(n>>>0<i>>>0){l=n;m=m+(k+j<<2)|0}else{break}}return}function etb(a){a=a|0;c[a>>2]=302;c[a+4>>2]=2;c[a+8>>2]=548;c[a+12>>2]=382;c[a+16>>2]=540;c[a+20>>2]=274;c[a+24>>2]=134;c[a+28>>2]=52;c[a+32>>2]=4;c[a+36>>2]=106;c[a+40>>2]=24;c[a+44>>2]=170;c[a+48>>2]=26;c[a+52>>2]=172;return}function ftb(a){a=a|0;var b=0,c=0;b=0;do{c=a+(b<<2)|0;g[c>>2]=+g[c>>2]+ +g[a+(b+64<<2)>>2]+ +g[a+(b+128<<2)>>2]+ +g[a+(b+192<<2)>>2]+ +g[a+(b+256<<2)>>2];b=b+1|0;}while((b|0)<64);return}function gtb(a,b){a=a|0;b=b|0;var c=0.0,d=0.0,e=0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0,m=0.0,n=0.0;if((b|0)>0){c=0.0;d=0.0;e=0}else{f=0.0;h=0.0;i=f+h;return+i}while(1){j=+g[a+(e<<3)>>2];k=+g[a+(e<<3)+4>>2];l=e|1;m=+g[a+(l<<3)>>2];n=c+j*j+m*m;m=+g[a+(l<<3)+4>>2];j=d+k*k+m*m;l=e+2|0;if((l|0)<(b|0)){c=n;d=j;e=l}else{f=n;h=j;break}}i=f+h;return+i}function htb(a){a=a|0;var b=0,d=0;b=1;do{d=a+(b<<2)|0;c[d>>2]=c[d>>2]^-2147483648;d=a+(b+2<<2)|0;c[d>>2]=c[d>>2]^-2147483648;b=b+4|0;}while((b|0)<64);return}function itb(a){a=a|0;var b=0,d=0;c[a+256>>2]=c[a>>2];c[a+260>>2]=c[a+4>>2];b=1;do{d=b<<1;c[a+(d+64<<2)>>2]=c[a+(64-b<<2)>>2]^-2147483648;c[a+(d+65<<2)>>2]=c[a+(b+1<<2)>>2];c[a+(d+66<<2)>>2]=c[a+(63-b<<2)>>2]^-2147483648;b=b+2|0;c[a+(d+67<<2)>>2]=c[a+(b<<2)>>2];}while((b|0)<31);c[a+504>>2]=c[a+132>>2]^-2147483648;c[a+508>>2]=c[a+128>>2];return}function jtb(a,b){a=a|0;b=b|0;var d=0,e=0;d=0;do{e=d<<1;c[a+(e<<2)>>2]=c[b+(63-d<<2)>>2]^-2147483648;c[a+((e|1)<<2)>>2]=c[b+(d<<2)>>2];c[a+((e|2)<<2)>>2]=c[b+(62-d<<2)>>2]^-2147483648;c[a+((e|3)<<2)>>2]=c[b+((d|1)<<2)>>2];d=d+2|0;}while((d|0)<32);return}function ktb(a,b){a=a|0;b=b|0;var d=0,e=0;d=0;do{e=63-(d<<1)|0;c[a+(d<<2)>>2]=c[b+(e<<2)>>2];c[a+(63-d<<2)>>2]=c[b+(e-1<<2)>>2]^-2147483648;d=d+1|0;}while((d|0)<32);return}function ltb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=0;do{e=b+(d<<2)|0;f=c+(63-d<<2)|0;g[a+(d<<2)>>2]=+g[e>>2]- +g[f>>2];g[a+(127-d<<2)>>2]=+g[e>>2]+ +g[f>>2];d=d+1|0;}while((d|0)<64);return}function mtb(a,b){a=a|0;b=b|0;var c=0,d=0.0,e=0.0,f=0,h=0.0,i=0.0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0,u=0.0,v=0.0,w=0,x=0.0,y=0.0,z=0.0;c=a|0;d=+g[c>>2];e=+g[a+16>>2];f=a+4|0;h=+g[f>>2];i=+g[a+20>>2];j=a+8|0;k=a+12|0;l=d*e+h*i;m=d*i-e*h;h=0.0;d=0.0;n=0.0;o=1;p=+g[j>>2];q=+g[k>>2];r=e;e=i;while(1){s=n+(p*p+q*q);t=o+1|0;u=h+(p*r+q*e);v=d+(p*e-q*r);w=o+2|0;i=+g[a+(w<<3)>>2];x=+g[a+(w<<3)+4>>2];y=l+(p*i+q*x);z=m+(p*x-q*i);if((t|0)<38){l=y;m=z;h=u;d=v;n=s;o=t;p=r;q=e;r=i;e=x}else{break}}g[b+8>>2]=y;g[b+12>>2]=z;z=+g[c>>2];y=+g[f>>2];g[b+40>>2]=s+z*z+y*y;o=a+304|0;y=+g[o>>2];t=a+308|0;z=+g[t>>2];g[b+16>>2]=s+y*y+z*z;g[b+24>>2]=u+ +g[c>>2]*+g[j>>2]+ +g[f>>2]*+g[k>>2];g[b+28>>2]=v+ +g[c>>2]*+g[k>>2]- +g[f>>2]*+g[j>>2];j=a+312|0;f=a+316|0;g[b>>2]=u+ +g[o>>2]*+g[j>>2]+ +g[t>>2]*+g[f>>2];g[b+4>>2]=v+ +g[o>>2]*+g[f>>2]- +g[t>>2]*+g[j>>2];return}function ntb(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=f|0;h=h|0;var i=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0;i=+g[d>>2]*e*e;j=+g[d+4>>2]*e*e;k=+g[c>>2]*e;l=+g[c+4>>2]*e;if((f|0)<(h|0)){m=f}else{return}do{f=m-2|0;c=b+(f<<3)|0;d=b+(f<<3)+4|0;f=m-1|0;n=b+(f<<3)|0;o=b+(f<<3)+4|0;g[a+(m<<3)>>2]=+g[b+(m<<3)>>2]+(i*+g[c>>2]-j*+g[d>>2]+k*+g[n>>2]-l*+g[o>>2]);g[a+(m<<3)+4>>2]=+g[b+(m<<3)+4>>2]+(i*+g[d>>2]+j*+g[c>>2]+k*+g[o>>2]+l*+g[n>>2]);m=m+1|0;}while((m|0)<(h|0));return}function otb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0;if((d|0)>0){f=0}else{return}do{h=c+(f<<2)|0;g[a+(f<<3)>>2]=+g[b+(f*320|0)+(e<<3)>>2]*+g[h>>2];g[a+(f<<3)+4>>2]=+g[b+(f*320|0)+(e<<3)+4>>2]*+g[h>>2];f=f+1|0;}while((f|0)<(d|0));return}function ptb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0;if((f|0)>0){h=0.0;i=d;j=0}else{return}while(1){d=a+(j<<3)|0;e=a+(j<<3)+4|0;k=i+1&511;l=+g[b+(j<<2)>>2];if(l!=0.0){m=h*l;n=l}else{l=+g[c+(j<<2)>>2];m=l*+g[1307364+(k<<3)>>2];n=l*+g[1307360+(k<<3)>>2]}l=+g[e>>2]+m;g[d>>2]=+g[d>>2]+n;g[e>>2]=l;e=j+1|0;if((e|0)<(f|0)){h=-0.0-h;i=k;j=e}else{break}}return}function qtb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0;if((f|0)<=0){return}h=+(1-(e<<1&2)|0);e=d;d=0;while(1){i=a+(d<<3)|0;j=a+(d<<3)+4|0;k=e+1&511;l=+g[b+(d<<2)>>2];if(l!=0.0){m=h*l;n=l*0.0}else{l=+g[c+(d<<2)>>2];m=l*+g[1307364+(k<<3)>>2];n=l*+g[1307360+(k<<3)>>2]}l=+g[j>>2]+m;g[i>>2]=+g[i>>2]+n;g[j>>2]=l;j=d+1|0;if((j|0)<(f|0)){h=-0.0-h;e=k;d=j}else{break}}return}function rtb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0;if((f|0)>0){h=0.0;i=d;j=0}else{return}while(1){d=a+(j<<3)|0;e=a+(j<<3)+4|0;k=i+1&511;l=+g[b+(j<<2)>>2];if(l!=0.0){m=h*l;n=l*-1.0}else{l=+g[c+(j<<2)>>2];m=l*+g[1307364+(k<<3)>>2];n=l*+g[1307360+(k<<3)>>2]}l=+g[e>>2]+m;g[d>>2]=+g[d>>2]+n;g[e>>2]=l;e=j+1|0;if((e|0)<(f|0)){h=-0.0-h;i=k;j=e}else{break}}return}function stb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0.0,i=0,j=0,k=0.0,l=0.0,m=0.0;if((f|0)<=0){return}h=+(1-(e<<1&2)|0);e=d;d=0;do{h=-0.0-h;i=a+(d<<3)|0;j=a+(d<<3)+4|0;e=e+1&511;k=+g[b+(d<<2)>>2];if(k!=0.0){l=k*h;m=k*0.0}else{k=+g[c+(d<<2)>>2];l=k*+g[1307364+(e<<3)>>2];m=k*+g[1307360+(e<<3)>>2]}k=+g[j>>2]+l;g[i>>2]=+g[i>>2]+m;g[j>>2]=k;d=d+1|0;}while((d|0)<(f|0));return}function ttb(f,g,h,i,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((j|0)<=0){return}q=g>>1;r=n|0;s=(i|0)>0;t=h+12|0;u=h+8|0;v=h+4|0;w=(o|0)==0;o=0;do{x=ca(o,g)|0;y=x+q|0;z=ca(o+q|0,g)|0;A=z+q|0;B=o+l|0;C=c[(c[r>>2]|0)+(B<<2)>>2]|0;if((C|0)==0){D=a1a(n,B)|0}else{D=C}a:do{if(s){C=ca(o,m)|0;if(w){B=0;while(1){E=B+C|0;F=D+(B+k<<1)|0;G=(ca(d[(c[u>>2]|0)+E|0]|0,d[f+(y+B)|0]|0)|0)+(ca(d[(c[t>>2]|0)+E|0]|0,d[f+(B+x)|0]|0)|0)+(ca(d[(c[v>>2]|0)+E|0]|0,d[f+(B+z)|0]|0)|0)+(ca(d[(c[h>>2]|0)+E|0]|0,d[f+(A+B)|0]|0)|0)|0;b[F>>1]=(e[F>>1]|0)-(G>>>4);B=B+1|0;if((B|0)>=(i|0)){break a}}}else{H=0}do{B=H+C|0;G=(ca(d[(c[u>>2]|0)+B|0]|0,d[f+(y+H)|0]|0)|0)+(ca(d[(c[t>>2]|0)+B|0]|0,d[f+(H+x)|0]|0)|0)+(ca(d[(c[v>>2]|0)+B|0]|0,d[f+(H+z)|0]|0)|0)+(ca(d[(c[h>>2]|0)+B|0]|0,d[f+(A+H)|0]|0)|0)|0;F=(b[D+(H+k<<1)>>1]|0)+8+(G>>>4)|0;G=F>>4;if(G>>>0>255>>>0){I=(F>>31^255)&255}else{I=G&255}a[p+B|0]=I;H=H+1|0;}while((H|0)<(i|0))}}while(0);o=o+1|0;}while((o|0)<(j|0));return}function utb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=0;do{c=0;while(1){mrc(a+7548+(b*533028|0)+8+(c*16656|0)+48|0,-128|0,16608)|0;d=c+1|0;if((d|0)<4){c=d}else{e=1;break}}while(1){mrc(a+7548+(b*533028|0)+66632+(e*16656|0)+48|0,-128|0,16608)|0;c=e+1|0;if((c|0)<4){e=c}else{f=1;break}}while(1){mrc(a+7548+(b*533028|0)+133256+(f*16656|0)+48|0,-128|0,16608)|0;c=f+1|0;if((c|0)<4){f=c}else{g=1;break}}while(1){mrc(a+7548+(b*533028|0)+199880+(g*16656|0)+48|0,-128|0,16608)|0;c=g+1|0;if((c|0)<4){g=c}else{h=1;break}}while(1){mrc(a+7548+(b*533028|0)+266504+(h*16656|0)+48|0,-128|0,16608)|0;c=h+1|0;if((c|0)<4){h=c}else{i=1;break}}while(1){mrc(a+7548+(b*533028|0)+333128+(i*16656|0)+48|0,-128|0,16608)|0;c=i+1|0;if((c|0)<4){i=c}else{j=1;break}}while(1){mrc(a+7548+(b*533028|0)+399752+(j*16656|0)+48|0,-128|0,16608)|0;c=j+1|0;if((c|0)<4){j=c}else{k=1;break}}do{mrc(a+7548+(b*533028|0)+466376+(k*16656|0)+48|0,-128|0,16608)|0;k=k+1|0;}while((k|0)<4);b=b+1|0;}while((b|0)<3);mrc(a+3092|0,-128|0,4256)|0;return}function vtb(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+4>>2]|0;d=(c[b+120>>2]|0)+15>>4;e=(c[b+124>>2]|0)+15>>4;c[a+7528>>2]=d;c[a+7532>>2]=e;b=a+2139660|0;kJb(c[b>>2]|0);f=ca(d*10|0,e)|0;e=pJb(f<<(c[a+7536>>2]<<1))|0;c[b>>2]=e;return((e|0)==0?-12:0)|0}function wtb(e,f,g,h,i,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if(!((a[m+8|0]&1)==0)){q=a[m+5+n|0]|0;r=ca(q&255,16843009)|0;if((k|0)==16){if((l|0)>0){s=0}else{return}do{t=ca(s,h)|0;c[f+t>>2]=r;c[f+(t+4)>>2]=r;c[f+(t+8)>>2]=r;c[f+(t+12)>>2]=r;s=s+1|0;}while((s|0)<(l|0));return}else if((k|0)==32){if((l|0)>0){u=0}else{return}do{s=ca(u,h)|0;c[f+s>>2]=r;c[f+(s+4)>>2]=r;c[f+(s+8)>>2]=r;c[f+(s+12)>>2]=r;c[f+(s+16)>>2]=r;c[f+(s+20)>>2]=r;c[f+(s+24)>>2]=r;c[f+(s+28)>>2]=r;u=u+1|0;}while((u|0)<(l|0));return}else if((k|0)==4){if((l|0)>0){v=0}else{return}do{c[f+(ca(v,h)|0)>>2]=r;v=v+1|0;}while((v|0)<(l|0));return}else if((k|0)==8){if((l|0)>0){w=0}else{return}do{v=ca(w,h)|0;c[f+v>>2]=r;c[f+(v+4)>>2]=r;w=w+1|0;}while((w|0)<(l|0));return}else{if((l|0)>0&(k|0)>0){x=0}else{return}do{mrc(f+(ca(x,h)|0)|0,q|0,k|0)|0;x=x+1|0;}while((x|0)<(l|0));return}}x=c[e+7512>>2]<<1;if((n|0)==0){y=x}else{y=x>>c[e+7480>>2]}x=ca(b[m>>1]|0,y)|0;q=ca(b[m+2>>1]|0,y)|0;y=x&15;w=q&15;r=3-(k>>2)+(k>>4)|0;v=i-3+(x>>4)|0;i=j-3+(q>>4)|0;j=(c[(c[e+2544+(d[m+4|0]<<2)>>2]|0)+(n<<2)>>2]|0)+((ca(i,h)|0)+v)|0;m=o-k-6|0;if(v>>>0<((m|0)>0?m:0)>>>0){m=p-l-6|0;if(i>>>0<((m|0)>0?m:0)>>>0){z=j}else{A=17}}else{A=17}if((A|0)==17){A=g+16|0;Ve[c[e+2e3>>2]&127](A,j,h,h,k+7|0,l+7|0,v,i,o,p);z=A}do{if((x&3|0)==0){if((q&3|0)!=0){break}A=(k|0)==(l|0);p=(l<<1|0)==(k|0);if(!(A|(k<<1|0)==(l|0)|p)){break}if((k-1&k|0)!=0){break}if((c[e+7548+(n*533028|0)+533012>>2]|0)==0){break}if((k|0)==32){if((l|0)<=0){return}o=e+2008+(w+(y>>>2)<<2)|0;i=0;do{v=ca(i,h)|0;j=ca(i|3,h)|0;ef[c[o>>2]&4095](f+v|0,z+(j+3)|0,h);ef[c[o>>2]&4095](f+(v+16)|0,z+(j+19)|0,h);i=i+16|0;}while((i|0)<(l|0));return}i=w+(y>>>2)|0;if(A){ef[c[e+2008+(r<<6)+(i<<2)>>2]&4095](f,z+((h*3|0)+3)|0,h);return}if(p){o=e+2008+(r+1<<6)+(i<<2)|0;j=(h*3|0)+3|0;ef[c[o>>2]&4095](f,z+j|0,h);ef[c[o>>2]&4095](f+l|0,z+(j+l)|0,h);return}else{j=e+2008+(r<<6)+(i<<2)|0;i=(h*3|0)+3|0;ef[c[j>>2]&4095](f,z+i|0,h);o=ca(k,h)|0;ef[c[j>>2]&4095](f+o|0,z+(o+i)|0,h);return}}}while(0);xtb(e+7548+(n*533028|0)|0,f,z,h,k,l,y,w);return}function xtb(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;n=i;i=i+12848|0;o=n+5120|0;p=n+12800|0;q=n|0;r=o|0;s=d[832592+((m<<4)+l)|0]|0;t=s&15;u=s>>>4;s=(a[832576+t|0]|a[832576+u|0])&255;v=(e|0)!=0;if(v){w=(c[e+533008>>2]|0)==0?15:s}else{w=s}if((w&5|0)==0){x=g}else{s=k+7|0;if((s|0)>0){y=(j|0)>0;z=e+533012|0;A=e+533004|0;B=e+533005|0;C=e+533006|0;D=e+533007|0;E=ca(s,h)|0;F=r;r=q;G=0;H=g;while(1){if(y){I=0;J=a[H]|0;K=a[H+1|0]|0;L=a[H+2|0]|0;M=a[H+3|0]|0;N=a[H+4|0]|0;O=a[H+5|0]|0;P=a[H+6|0]|0;while(1){Q=J&255;R=I+1|0;S=K&255;T=L&255;U=M&255;V=N&255;W=O&255;X=P&255;Y=a[H+(I+7)|0]|0;Z=Y&255;do{if(v){if((c[z>>2]|0)!=0){_=10;break}$=ca(a[A]|0,V+U|0)|0;aa=(ca(a[B]|0,W+T|0)|0)+$|0;$=aa+(ca(a[C]|0,X+S|0)|0)|0;aa=$+(ca(a[D]|0,Z+Q|0)|0)|0;b[r+(I<<1)>>1]=aa;ba=aa+32>>6}else{_=10}}while(0);if((_|0)==10){_=0;Q=((V+U|0)*20|0)+S+X+((W+T|0)*-5|0)|0;b[r+(I<<1)>>1]=Q;ba=Q+16>>5}if(ba>>>0>255>>>0){da=(ba>>31^255)&255}else{da=ba&255}a[F+I|0]=da;if((R|0)<(j|0)){I=R;J=K;K=L;L=M;M=N;N=O;O=P;P=Y}else{break}}}P=G+1|0;if((P|0)<(s|0)){F=F+64|0;r=r+128|0;G=P;H=H+h|0}else{break}}ea=s;fa=g+E|0}else{ea=0;fa=g}x=fa+(ca(ea,-h|0)|0)|0}ea=x+3|0;fa=o+2560|0;if((w&2|0)==0){ga=ea}else{if((k|0)>0){g=j+1|0;E=(g|0)>0;s=h<<1;H=h*3|0;G=h<<2;r=h*5|0;F=h*6|0;da=h*7|0;ba=e+533012|0;D=e+533004|0;C=e+533005|0;B=e+533006|0;A=e+533007|0;z=(ca(k,h)|0)+3|0;y=fa;P=0;O=ea;while(1){if(E){N=0;do{M=d[O+N|0]|0;L=d[O+(N+h)|0]|0;K=d[O+(N+s)|0]|0;J=d[O+(N+H)|0]|0;I=d[O+(N+G)|0]|0;Q=d[O+(N+r)|0]|0;Z=d[O+(N+F)|0]|0;aa=d[O+(N+da)|0]|0;do{if(v){if((c[ba>>2]|0)!=0){_=24;break}$=ca(a[D]|0,I+J|0)|0;ha=ca(a[C]|0,Q+K|0)|0;ia=ca(a[B]|0,Z+L|0)|0;ja=$+32+ha+ia+(ca(a[A]|0,aa+M|0)|0)>>6}else{_=24}}while(0);if((_|0)==24){_=0;ja=L+16+((I+J|0)*20|0)+Z+((Q+K|0)*-5|0)>>5}if(ja>>>0>255>>>0){ka=(ja>>31^255)&255}else{ka=ja&255}a[y+N|0]=ka;N=N+1|0;}while((N|0)<(g|0))}N=P+1|0;if((N|0)<(k|0)){y=y+64|0;P=N;O=O+h|0}else{break}}la=k;ma=x+z|0}else{la=0;ma=ea}ga=ma+(ca(la,-h|0)|0)|0}la=h*3|0;ma=ga+la|0;ea=o+5120|0;if((w&4|0)!=0&(k|0)>0){z=(j|0)>0;x=e+533012|0;O=e+533004|0;P=e+533005|0;y=e+533006|0;g=e+533007|0;e=ea;ka=q;q=0;while(1){if(z){ja=0;do{A=b[ka+(ja<<1)>>1]|0;B=b[ka+(ja+64<<1)>>1]|0;C=b[ka+(ja+128<<1)>>1]|0;D=b[ka+(ja+192<<1)>>1]|0;ba=b[ka+(ja+256<<1)>>1]|0;da=b[ka+(ja+320<<1)>>1]|0;F=b[ka+(ja+384<<1)>>1]|0;r=b[ka+(ja+448<<1)>>1]|0;do{if(v){if((c[x>>2]|0)!=0){_=37;break}G=ca(a[O]|0,ba+D|0)|0;H=ca(a[P]|0,da+C|0)|0;s=ca(a[y]|0,F+B|0)|0;na=G+2048+H+s+(ca(a[g]|0,r+A|0)|0)>>12}else{_=37}}while(0);if((_|0)==37){_=0;na=B+512+((ba+D|0)*20|0)+F+((da+C|0)*-5|0)>>10}if(na>>>0>255>>>0){oa=(na>>31^255)&255}else{oa=na&255}a[e+ja|0]=oa;ja=ja+1|0;}while((ja|0)<(j|0))}ja=q+1|0;if((ja|0)<(k|0)){e=e+64|0;ka=ka+128|0;q=ja}else{break}}}c[p>>2]=ma;c[p+4>>2]=o+192;c[p+8>>2]=ga+(la+1);c[p+16>>2]=fa;c[p+20>>2]=ea;c[p+24>>2]=o+2561;ea=la+h|0;c[p+32>>2]=ga+ea;c[p+36>>2]=o+256;c[p+40>>2]=ga+(ea+1);if((w|0)!=15){w=(4722>>>(u>>>0)&1|0)!=0?64:h;ea=(4722>>>(t>>>0)&1|0)!=0?64:h;ga=d[832512+(m<<3&56|l&7)|0]|0;o=8-ga|0;if((k|0)>0&(j|0)>0){pa=0;qa=c[p+(u<<2)>>2]|0;ra=c[p+(t<<2)>>2]|0;sa=f}else{i=n;return}while(1){t=0;do{u=ca(d[qa+t|0]|0,ga)|0;a[sa+t|0]=(u+4+(ca(d[ra+t|0]|0,o)|0)|0)>>>3;t=t+1|0;}while((t|0)<(j|0));t=pa+1|0;if((t|0)<(k|0)){pa=t;qa=qa+w|0;ra=ra+ea|0;sa=sa+h|0}else{break}}i=n;return}sa=(((m|0)/8|0)<<2)+((l|0)/8|0)|0;ea=sa+1|0;ra=sa+4|0;w=sa+5|0;qa=(4722>>>(sa>>>0)&1|0)!=0?64:h;pa=(4722>>>(ea>>>0)&1|0)!=0?64:h;o=(4722>>>(ra>>>0)&1|0)!=0?64:h;ga=(4722>>>(w>>>0)&1|0)!=0?64:h;t=l&7;l=m&7;if((k|0)<=0){i=n;return}m=8-t|0;u=8-l|0;if((j|0)>0){ta=c[p+(sa<<2)>>2]|0;ua=c[p+(ea<<2)>>2]|0;va=c[p+(ra<<2)>>2]|0;wa=c[p+(w<<2)>>2]|0;xa=0;ya=f}else{i=n;return}while(1){f=0;do{w=ca(d[ta+f|0]|0,m)|0;p=ca(d[ua+f|0]|0,t)|0;ra=ca(d[va+f|0]|0,m)|0;a[ya+f|0]=((ca((ca(d[wa+f|0]|0,t)|0)+ra|0,l)|0)+32+(ca(p+w|0,u)|0)|0)>>>6;f=f+1|0;}while((f|0)<(j|0));f=xa+1|0;if((f|0)<(k|0)){ta=ta+qa|0;ua=ua+pa|0;va=va+o|0;wa=wa+ga|0;xa=f;ya=ya+h|0}else{break}}i=n;return}function ytb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=c[b+60>>2]|0;f=e+4|0;c[f>>2]=b;c[e+7384>>2]=1;l8(e+548|0,b);g=e+1792|0;YJa(g,c[b+88>>2]|0);G8a(e+2e3|0,8);s1a(e+2520|0);h=e+2008|0;nta(h,8);j=c[h>>2]|0;c[e+1428>>2]=j;c[e+1172>>2]=j;j=c[e+2072>>2]|0;c[e+1492>>2]=j;c[e+1236>>2]=j;j=c[e+2012>>2]|0;c[e+1432>>2]=j;c[e+1176>>2]=j;j=c[e+2076>>2]|0;c[e+1496>>2]=j;c[e+1240>>2]=j;j=c[e+2016>>2]|0;c[e+1436>>2]=j;c[e+1180>>2]=j;j=c[e+2080>>2]|0;c[e+1500>>2]=j;c[e+1244>>2]=j;j=c[e+2020>>2]|0;c[e+1440>>2]=j;c[e+1184>>2]=j;j=c[e+2084>>2]|0;c[e+1504>>2]=j;c[e+1248>>2]=j;j=c[e+2024>>2]|0;c[e+1444>>2]=j;c[e+1188>>2]=j;j=c[e+2088>>2]|0;c[e+1508>>2]=j;c[e+1252>>2]=j;j=c[e+2028>>2]|0;c[e+1448>>2]=j;c[e+1192>>2]=j;j=c[e+2092>>2]|0;c[e+1512>>2]=j;c[e+1256>>2]=j;j=c[e+2032>>2]|0;c[e+1452>>2]=j;c[e+1196>>2]=j;j=c[e+2096>>2]|0;c[e+1516>>2]=j;c[e+1260>>2]=j;j=c[e+2036>>2]|0;c[e+1456>>2]=j;c[e+1200>>2]=j;j=c[e+2100>>2]|0;c[e+1520>>2]=j;c[e+1264>>2]=j;j=c[e+2040>>2]|0;c[e+1460>>2]=j;c[e+1204>>2]=j;j=c[e+2104>>2]|0;c[e+1524>>2]=j;c[e+1268>>2]=j;j=c[e+2044>>2]|0;c[e+1464>>2]=j;c[e+1208>>2]=j;j=c[e+2108>>2]|0;c[e+1528>>2]=j;c[e+1272>>2]=j;j=c[e+2048>>2]|0;c[e+1468>>2]=j;c[e+1212>>2]=j;j=c[e+2112>>2]|0;c[e+1532>>2]=j;c[e+1276>>2]=j;j=c[e+2052>>2]|0;c[e+1472>>2]=j;c[e+1216>>2]=j;j=c[e+2116>>2]|0;c[e+1536>>2]=j;c[e+1280>>2]=j;j=c[e+2056>>2]|0;c[e+1476>>2]=j;c[e+1220>>2]=j;j=c[e+2120>>2]|0;c[e+1540>>2]=j;c[e+1284>>2]=j;j=c[e+2060>>2]|0;c[e+1480>>2]=j;c[e+1224>>2]=j;j=c[e+2124>>2]|0;c[e+1544>>2]=j;c[e+1288>>2]=j;j=c[e+2064>>2]|0;c[e+1484>>2]=j;c[e+1228>>2]=j;j=c[e+2128>>2]|0;c[e+1548>>2]=j;c[e+1292>>2]=j;j=c[e+2068>>2]|0;c[e+1488>>2]=j;c[e+1232>>2]=j;j=c[e+2132>>2]|0;c[e+1552>>2]=j;c[e+1296>>2]=j;c[e+1920>>2]=634;c[g>>2]=634;c[e+1936>>2]=938;c[e+1808>>2]=938;c[e+1924>>2]=656;c[e+1796>>2]=656;c[e+1940>>2]=614;c[e+1812>>2]=614;c[e+1928>>2]=958;c[e+1800>>2]=958;c[e+1944>>2]=760;c[e+1816>>2]=760;c[e+1932>>2]=622;c[e+1804>>2]=622;c[e+1948>>2]=772;c[e+1820>>2]=772;g=0;k=128.0;while(1){a[6549120+g|0]=Lc(+k)|0;j=g+1|0;if((j|0)<32){g=j;k=k*1.0218971486541166}else{break}}g=c[f>>2]|0;f=c[g+120>>2]|0;j=c[g+124>>2]|0;g=ca(j,f)|0;h=g<<1;l=pJb(h)|0;c[e+7464>>2]=l;a:do{if((l|0)!=0|(h|0)==0){m=g<<2;n=pJb(m)|0;c[e+7456>>2]=n;if(!((n|0)!=0|(m|0)==0)){KIb(b,16,2423920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}m=f<<2;n=pJb(m)|0;c[e+7460>>2]=n;if(!((n|0)!=0|(m|0)==0)){KIb(b,16,2423920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}m=f<<1;n=pJb(m)|0;c[e+7468>>2]=n;if(!((n|0)!=0|(m|0)==0)){KIb(b,16,2423920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}m=ca((f+1|0)>>>1<<2,j+1>>1)|0;n=hJb(m)|0;c[e+7472>>2]=n;if(!((n|0)!=0|(m|0)==0)){KIb(b,16,2423920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}m=e+2544|0;n=0;while(1){if((n|0)>=8){break}p=(n<<8)+256|0;c[6548856+(n<<5)>>2]=p;c[6548860+(n<<5)>>2]=(p|0)/2|0;c[6548864+(n<<5)>>2]=(p|0)/3|0;c[6548868+(n<<5)>>2]=(p|0)/4|0;c[6548872+(n<<5)>>2]=(p|0)/5|0;c[6548876+(n<<5)>>2]=(p|0)/6|0;c[6548880+(n<<5)>>2]=(p|0)/7|0;c[6548884+(n<<5)>>2]=(p|0)/8|0;p=UHb()|0;c[m+(n<<2)>>2]=p;if((p|0)==0){break a}else{n=n+1|0}}n=e+3088|0;c[n>>2]=UHb()|0;m=UHb()|0;c[e+2540>>2]=m;if((c[n>>2]|0)==0|(m|0)==0){break}else{q=0}i=d;return q|0}else{KIb(b,16,2423920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);q=-12;i=d;return q|0}function ztb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xtb(0,a,b+((c*-3|0)-3)|0,c,16,16,0,0);return}function Atb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xtb(0,a,b+((c*-3|0)-3)|0,c,8,8,0,0);return}function Btb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xtb(0,a,b+((c*-3|0)-3)|0,c,16,16,8,0);return}function Ctb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xtb(0,a,b+((c*-3|0)-3)|0,c,8,8,8,0);return}function Dtb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xtb(0,a,b+((c*-3|0)-3)|0,c,16,16,0,8);return}function Etb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xtb(0,a,b+((c*-3|0)-3)|0,c,8,8,0,8);return}function Ftb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xtb(0,a,b+((c*-3|0)-3)|0,c,16,16,8,8);return}function Gtb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xtb(0,a,b+((c*-3|0)-3)|0,c,8,8,8,8);return}function Htb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;b=i;d=c[a+60>>2]|0;e=d+2158472|0;do{if((c[e>>2]|0)==0){f=d+3088|0;g=M4a(c[d+4>>2]|0,c[f>>2]|0,1)|0;if((g|0)<0){h=g;i=b;return h|0}g=c[(c[f>>2]|0)+32>>2]|0;j=a+120|0;k=(c[j>>2]<<1)+256|0;l=pJb(((g|0)>(k|0)?g:k)*112|0)|0;c[e>>2]=l;k=c[(c[f>>2]|0)+32>>2]|0;g=c[j>>2]|0;do{if((l|0)==0){j=(g<<1)+256|0;if((((k|0)>(j|0)?k:j)*112|0|0)==0){break}KIb(a,16,2423920,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-12;i=b;return h|0}}while(0);l=(g<<1)+256|0;j=((k|0)>(l|0)?k:l)*39|0;l=hJb(j)|0;c[d+2158476>>2]=l;if((l|0)!=0|(j|0)==0){n=f;break}KIb(a,16,2423920,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-12;i=b;return h|0}else{n=d+3088|0}}while(0);if((c[(c[n>>2]|0)+80>>2]|0)!=(c[a+140>>2]|0)){KIb(a,16,2580832,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=b;return h|0}m=d+7544|0;if((c[m>>2]|0)<=0){h=0;i=b;return h|0}a=d+4|0;n=d+7548|0;e=d+7372|0;j=d+7456|0;l=d+7464|0;o=d+7480|0;p=d+7484|0;d=0;a:while(1){q=c[a>>2]|0;r=c[q+120>>2]|0;s=c[q+124>>2]|0;if((d|0)==0){t=s;u=r}else{t=s>>c[p>>2];u=r>>c[o>>2]}r=n+(d*533028|0)|0;c[r>>2]=u;c[n+(d*533028|0)+4>>2]=t;s=c[e>>2]|0;if((s|0)>0){q=u;v=t;w=s;while(1){s=w-1|0;x=(s|0)!=0;y=w-2|0;z=q+1>>1;A=x&1;while(1){if((A|0)>=4){break}B=c[j>>2]|0;C=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+20|0;c[C>>2]=B;c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)>>2]=s;D=c[r>>2]<<(c[e>>2]|0)-s;c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+4>>2]=D;E=A&1;F=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+8|0;c[F>>2]=(E^1)+q>>1;G=(A|0)>1;H=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+12|0;c[H>>2]=(G&1^1)+v>>1;I=1<<(c[e>>2]|0)-s;c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+36>>2]=I;J=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+28|0;c[J>>2]=0;K=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+32|0;c[K>>2]=0;if((E|0)==0){L=B}else{E=B+(z<<2)|0;c[C>>2]=E;c[J>>2]=z;L=E}if(G){G=L+(D>>1<<2)|0;c[C>>2]=G;c[K>>2]=I>>1;M=G}else{M=L}c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+24>>2]=(c[l>>2]|0)+(M-(c[j>>2]|0)>>2<<1);if(x){c[n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+44>>2]=n+(d*533028|0)+8+(y*66624|0)+(A*16656|0)}G=n+(d*533028|0)+8+(s*66624|0)+(A*16656|0)+40|0;mJb(G);I=pJb((ca(c[H>>2]<<2,(c[F>>2]|0)+1|0)|0)+4|0)|0;c[G>>2]=I;if((I|0)==0){h=-12;N=27;break a}else{A=A+1|0}}if((s|0)>0){q=z;v=v+1>>1;w=s}else{break}}}w=d+1|0;if((w|0)<(c[m>>2]|0)){d=w}else{h=0;N=27;break}}if((N|0)==27){i=b;return h|0}return 0}function Itb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+60>>2]|0;a=b+7384|0;d=c[b+2544+((c[a>>2]|0)-1<<2)>>2]|0;if((c[d>>2]|0)==0){return}WHb(d);d=b+2576|0;e=b+2540|0;b=0;do{f=(b|0)%3|0;g=c[d+((c[a>>2]|0)-1<<6)+(((b|0)/3|0)+1<<4)+(f<<2)>>2]|0;if((g|0)!=0){kJb(g+(-16-(c[(c[e>>2]|0)+32+(f<<2)>>2]<<4))|0)}b=b+1|0;}while((b|0)<9);return}function Jtb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=a+4|0;e=c[d>>2]|0;f=c[e+120>>2]|0;g=c[e+124>>2]|0;h=a+2540|0;j=c[h>>2]|0;k=c[j>>2]|0;do{if((k|0)!=0){if((c[e+88>>2]&16384|0)!=0){break}l=a+1752|0;Se[c[l>>2]&1023](k,c[j+32>>2]|0,f,g,16,16,3);m=c[h>>2]|0;if((c[m+8>>2]|0)==0){break}n=a+7480|0;o=c[n>>2]|0;p=a+7484|0;q=c[p>>2]|0;Se[c[l>>2]&1023](c[m+4>>2]|0,c[m+36>>2]|0,f>>o,g>>q,16>>>(o>>>0),16>>>(q>>>0),3);q=c[h>>2]|0;o=c[n>>2]|0;n=c[p>>2]|0;Se[c[l>>2]&1023](c[q+8>>2]|0,c[q+40>>2]|0,f>>o,g>>n,16>>>(o>>>0),16>>>(n>>>0),3)}}while(0);g=c[(c[d>>2]|0)+60>>2]|0;f=g+7384|0;j=c[g+2544+((c[f>>2]|0)-1<<2)>>2]|0;if((c[j>>2]|0)!=0){WHb(j);j=g+2576|0;k=g+2540|0;g=0;do{e=(g|0)%3|0;n=c[j+((c[f>>2]|0)-1<<6)+(((g|0)/3|0)+1<<4)+(e<<2)>>2]|0;if((n|0)!=0){kJb(n+(-16-(c[(c[k>>2]|0)+32+(e<<2)>>2]<<4))|0)}g=g+1|0;}while((g|0)<9)}g=a+7384|0;k=c[g>>2]|0;f=k-1|0;j=c[a+2544+(f<<2)>>2]|0;if((f|0)>0){e=f;while(1){f=e-1|0;c[a+2544+(e<<2)>>2]=c[a+2544+(f<<2)>>2];if((f|0)>0){e=f}else{break}}r=c[g>>2]|0}else{r=k}orc(a+2640|0,a+2576|0,(r<<6)-64|0)|0;r=c[h>>2]|0;c[a+2544>>2]=r;c[h>>2]=j;k=a+7348|0;do{if((c[k>>2]|0)==0){e=c[g>>2]|0;if((e|0)>0){f=0;n=r;while(1){if((c[n>>2]|0)==0){s=f;break}if((f|0)!=0){if((c[(c[a+2544+(f-1<<2)>>2]|0)+84>>2]|0)!=0){s=f;break}}o=f+1|0;if((o|0)>=(e|0)){s=o;break}f=o;n=c[a+2544+(o<<2)>>2]|0}c[a+7388>>2]=s;if((s|0)!=0){break}}else{c[a+7388>>2]=0}KIb(c[d>>2]|0,16,2437064,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;t=-1;i=b;return t|0}else{c[a+7388>>2]=0}}while(0);a=M4a(c[d>>2]|0,j,1)|0;if((a|0)<0){t=a;i=b;return t|0}c[(c[h>>2]|0)+84>>2]=c[k>>2];t=0;i=b;return t|0}function Ktb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;mJb(a+7456|0);mJb(a+7460|0);mJb(a+7464|0);mJb(a+7468|0);mJb(a+7472|0);c[a+2156008>>2]=0;mJb(a+2155992|0);mJb(a+2156016|0);mJb(a+2156020|0);mJb(a+2153752|0);mJb(a+2139660|0);mJb(a+2158472|0);mJb(a+2158476|0);d=a+2540|0;e=0;do{mJb(a+7392+(e<<2)|0);mJb(a+7424+(e<<2)|0);f=a+2544+(e<<2)|0;g=c[c[f>>2]>>2]|0;if((g|0)!=0){if((g|0)==(c[c[d>>2]>>2]|0)){h=6;break}}VHb(f);e=e+1|0;}while((e|0)<8);if((h|0)==6){KIb(0,0,2350248,(h=i,i=i+24|0,c[h>>2]=2288504,c[h+8>>2]=2238504,c[h+16>>2]=693,h)|0);i=h;Hd()}h=a+7544|0;e=c[h>>2]|0;if((e|0)<=0){j=a+3088|0;VHb(j);VHb(d);i=b;return}f=a+7372|0;g=0;k=e;while(1){e=c[f>>2]|0;if((e|0)>0){l=e;do{l=l-1|0;e=(l|0)!=0|0;do{mJb(a+7548+(g*533028|0)+8+(l*66624|0)+(e*16656|0)+40|0);e=e+1|0;}while((e|0)<4);}while((l|0)>0);m=c[h>>2]|0}else{m=k}l=g+1|0;if((l|0)<(m|0)){g=l;k=m}else{break}}j=a+3088|0;VHb(j);VHb(d);i=b;return}function Ltb(a,b,c){a=a|0;b=b|0;c=c|0;var f=0,g=0,h=0;if((b|0)>0){f=c;g=0}else{h=c&65535;return h|0}do{f=(e[1706936+(((d[a+g|0]|0)^f>>8)<<1)>>1]|0)^f<<8&65280;g=g+1|0;}while((g|0)<(b|0));h=f&65535;return h|0}function Mtb(a,b){a=a|0;b=b|0;return((d[a+1|0]|0)-(d[b+1|0]|0)<<8|(d[a]|0))-(d[b]|0)|0}function Ntb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=b-1|0;if((c|0)==0){b=0;while(1){d=b+1|0;if(d>>>0>a>>>0){e=b;break}else{b=d}}return e|0}else{f=0}while(1){b=f+1|0;d=0;g=b;do{g=ca(g,b)|0;d=d+1|0;}while(d>>>0<c>>>0);if(g>>>0>a>>>0){e=f;break}else{f=b}}return e|0}function Otb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+136|0;g=f|0;mrc(g|0,0,132)|0;c[g>>2]=404;h=0;while(1){j=b+h|0;k=h+1|0;if((a[j]|0)==0&h>>>0<e>>>0){h=k}else{break}}if((h|0)==(e|0)){l=0;i=f;return l|0}c[d+(h<<2)>>2]=0;h=a[j]|0;if((h&255)>>>0>32>>>0){l=1;i=f;return l|0}if(h<<24>>24==0){m=k}else{j=h&255;h=0;while(1){n=h+1|0;c[g+(n<<2)>>2]=1<<h;if(n>>>0<j>>>0){h=n}else{m=k;break}}}while(1){if((a[b+m|0]|0)==0&m>>>0<e>>>0){m=m+1|0}else{break}}if((m|0)==(e|0)){l=0;i=f;return l|0}a:do{if(k>>>0<e>>>0){m=k;b:while(1){h=a[b+m|0]|0;if((h&255)>>>0>32>>>0){l=1;o=22;break}if(!(h<<24>>24==0)){j=h&255;h=j;while(1){if((h|0)==0){l=1;o=22;break b}p=g+(h<<2)|0;q=c[p>>2]|0;if((q|0)==0){h=h-1|0}else{break}}c[p>>2]=0;n=h+1|0;if(!(n>>>0>j>>>0)){r=h;s=n;while(1){c[g+(s<<2)>>2]=(1<<r)+q;n=s+1|0;if(n>>>0>j>>>0){break}else{r=s;s=n}}}c[d+(m<<2)>>2]=q}s=m+1|0;if(s>>>0<e>>>0){m=s}else{t=1;break a}}if((o|0)==22){i=f;return l|0}}else{t=1}}while(0);while(1){if(!(t>>>0<33>>>0)){l=0;o=22;break}if((c[g+(t<<2)>>2]|0)==0){t=t+1|0}else{l=1;o=22;break}}if((o|0)==22){i=f;return l|0}return 0}function Ptb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;b[d+2>>1]=0;b[d+10>>1]=1;if((f|0)>2){h=2;do{j=d+(h<<3)+4|0;b[j>>1]=0;k=d+(h<<3)+6|0;b[k>>1]=1;b[d+(h<<3)+2>>1]=h;if((h|0)>2){l=b[d+(h<<3)>>1]|0;m=2;n=0;o=1;while(1){p=b[d+(m<<3)>>1]|0;do{if((p&65535)>>>0<(l&65535)>>>0){if(!((p&65535)>>>0>(e[d+((n&65535)<<3)>>1]|0)>>>0)){q=n;r=o;break}s=m&65535;b[j>>1]=s;q=s;r=o}else{if(!((p&65535)>>>0<(e[d+((o&65535)<<3)>>1]|0)>>>0)){q=n;r=o;break}s=m&65535;b[k>>1]=s;q=n;r=s}}while(0);p=m+1|0;if((p|0)<(h|0)){m=p;n=q;o=r}else{break}}}h=h+1|0;}while((h|0)<(f|0))}h=f-1|0;if((h|0)>0){t=0}else{u=0;i=g;return u|0}a:while(1){r=t+1|0;if((r|0)<(f|0)){q=b[d+(t<<3)>>1]|0;o=d+(t<<3)+2|0;n=r;do{if(q<<16>>16==(b[d+(n<<3)>>1]|0)){break a}m=b[o>>1]|0;k=d+(n<<3)+2|0;j=b[k>>1]|0;if((e[d+((m&65535)<<3)>>1]|0)>>>0>(e[d+((j&65535)<<3)>>1]|0)>>>0){b[o>>1]=j;b[k>>1]=m}n=n+1|0;}while((n|0)<(f|0))}if((r|0)<(h|0)){t=r}else{u=0;v=20;break}}if((v|0)==20){i=g;return u|0}KIb(a,16,2423624,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;u=-1094995529;i=g;return u|0}function Qtb(a,b,d,f,g,h,i){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=0;k=ca(e[d>>1]|0,g)|0;l=1;while(1){if((l|0)>=(b|0)){m=j;n=k;break}o=e[a+(l<<3)+2>>1]|0;do{if((c[f+(o<<2)>>2]|0)==0){p=j;q=k}else{r=e[a+(o<<3)>>1]|0;s=ca(e[d+(o<<1)>>1]|0,g)|0;if((j|0)>=(i|0)){p=r;q=s;break}Rtb(j,k,(r|0)>(i|0)?i:r,s,h);p=r;q=s}}while(0);if((p|0)<(i|0)){j=p;k=q;l=l+1|0}else{m=p;n=q;break}}if((m|0)>=(i|0)){return}Rtb(m,n,i,n,h);return}function Rtb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=d-b|0;d=c-a|0;h=-d|0;i=(f|0)>-1?f:-f|0;j=f>>31|1;if(b>>>0>255>>>0){k=-b>>31&255}else{k=b&255}g[e+(a<<2)>>2]=+g[1253680+((k&255)<<2)>>2];if((i<<1|0)>(d|0)){k=(f|0)/(d|0)|0;f=i-(ca((k|0)>-1?k:-k|0,d)|0)|0;l=a+1|0;if((l|0)<(c|0)){m=b;n=h;o=l}else{return}while(1){l=m+k|0;p=n+f|0;if((p|0)>-1){q=p-d|0;r=l+j|0}else{q=p;r=l}if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}g[e+(o<<2)>>2]=+g[1253680+((s&255)<<2)>>2];l=o+1|0;if((l|0)<(c|0)){m=r;n=q;o=l}else{break}}return}o=c-1|0;q=a-o|0;a=q+1|0;if((a|0)<0){n=i-d|0;d=b;r=q;m=h;s=a;while(1){a=m+i|0;if((a|0)>-1){f=d+j|0;if(f>>>0>255>>>0){t=-f>>31&255}else{t=f&255}g[e+(r+c<<2)>>2]=+g[1253680+((t&255)<<2)>>2];u=n+a|0;v=r+2|0;w=f}else{u=a;v=s;w=d}if(w>>>0>255>>>0){x=-w>>31&255}else{x=w&255}g[e+(v+o<<2)>>2]=+g[1253680+((x&255)<<2)>>2];a=v+1|0;if((a|0)<0){d=w;r=v;m=u;s=a}else{y=w;z=v;A=u;break}}}else{y=b;z=q;A=h}if((z|0)>=0){return}h=((A+i|0)>-1?j:0)+y|0;if(h>>>0>255>>>0){B=-h>>31&255}else{B=h&255}g[e+(z+c<<2)>>2]=+g[1253680+((B&255)<<2)>>2];return}function Stb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(e<<24>>24==0){return}f=b+4|0;g=b|0;b=c[g>>2]|0;if((b|0)<1){h=0;i=f;j=e;k=b;l=0}else{b=0;m=f;f=e&255;while(1){e=(d[m]|0)+f&65535;n=m+1|0;a[m]=e;o=(e&65535)>>>8;p=b+1|0;q=c[g>>2]|0;r=o<<16>>16==0;if((p|0)>=(q|0)|r){break}else{b=p;m=n;f=o}}h=p;i=n;j=o&255;k=q;l=r}if((h|0)!=(k|0)|l){return}c[g>>2]=k+1;a[i]=j;return}function Ttb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=b;do{if(!(e<<24>>24==1)){h=b|0;i=c[h>>2]|0;if((i|0)==0){break}if(e<<24>>24==0){j=i-1|0;c[h>>2]=j;k=b+4|0;a[f]=a[k]|0;if((j|0)==0){l=k}else{m=i+3|0;n=j;j=k;while(1){k=n-1|0;o=j+1|0;a[j]=a[o]|0;if((k|0)==0){break}else{n=k;j=o}}l=g+m|0}a[l]=0;return}else{j=e&255;n=i;o=b+4+i|0;k=0;while(1){p=n-1|0;q=o-1|0;r=(d[q]|k<<8)&65535;s=(r>>>0)%(j>>>0)|0;a[q]=(r>>>0)/(j>>>0)|0;if((p|0)==0){break}else{n=p;o=q;k=s&65535}}a[f]=s;k=(c[h>>2]|0)-1|0;if((a[b+4+k|0]|0)!=0){return}c[h>>2]=k;return}}}while(0);a[f]=0;return}function Utb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;if(e<<24>>24==1){return}g=b|0;h=c[g>>2]|0;if((h|0)==0){return}if(e<<24>>24==0){c[g>>2]=h+1;i=h;j=b+4+h|0;while(1){k=i-1|0;l=j-1|0;a[j]=a[l]|0;if((k|0)==0){break}else{i=k;j=l}}a[b+4|0]=0;return}j=e&255;e=h+4|0;i=h;h=b+4|0;b=0;while(1){l=i-1|0;k=(ca(d[h]|0,j)|0)+b&65535;a[h]=k;m=(k&65535)>>>8;if((l|0)==0){break}else{i=l;h=h+1|0;b=m}}if(m<<16>>16==0){return}c[g>>2]=(c[g>>2]|0)+1;a[f+e|0]=m;return}function Vtb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=0;while(1){f=e*48|0;g=e-2|0;h=0;a:while(1){i=h+2|0;j=0;k=h-2|0;while(1){l=(k-1|0)>>>0<48>>>0;do{if((k|0)<(h|0)){if(l){m=j;n=g}else{o=j;break}while(1){if((n|0)>0){p=(d[c+((n*48|0)+k)|0]|0)+(m<<1)|0}else{p=m}q=n+1|0;if((q|0)>(e|0)){o=p;break}else{m=p;n=q}}}else{if(l){r=j;s=g}else{o=j;break}while(1){if((s|0)!=(e|0)&(s|0)>0){t=(d[c+((s*48|0)+k)|0]|0)+(r<<1)|0}else{t=r}q=s+1|0;if((q|0)>(e|0)){o=t;break}else{r=t;s=q}}}}while(0);l=k+1|0;if((l|0)>(i|0)){break}else{j=o;k=l}}u=h+f|0;do{if((h|0)==47){if((e|0)==2){v=25;break a}else if((e|0)!=1){v=26;break a}k=b+u|0;a[k]=(d[1203056+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36}else if((h|0)==2){if((e|0)==2){k=b+u|0;a[k]=(d[1203128+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=35;break}else if((e|0)==1){k=b+u|0;a[k]=(d[1203120+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}else{k=b+u|0;a[k]=(d[1203136+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=35;break}}else if((h|0)==1){if((e|0)==1){k=b+u|0;a[k]=(d[6041736+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}else if((e|0)==2){k=b+u|0;a[k]=(d[1203104+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=35;break}else{k=b+u|0;a[k]=(d[1203112+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=35;break}}else if((h|0)==48){if((e|0)==2){v=29;break a}else if((e|0)!=1){v=30;break a}k=b+u|0;a[k]=(d[1203056+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36}else{if((e|0)==1){k=b+u|0;a[k]=(d[1203200+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}else if((e|0)==2){k=b+u|0;a[k]=(d[1203208+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}else{k=b+u|0;a[k]=(d[1203224+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[k]|0);v=36;break}}}while(0);if((v|0)==35){v=0;h=h+1|0;continue}else if((v|0)==36){v=0;k=h+1|0;if((k|0)<48){h=k;continue}else{v=38;break}}}if((v|0)==25){v=0;h=b+u|0;a[h]=(d[1202920+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[h]|0);v=37}else if((v|0)==26){v=0;h=b+u|0;a[h]=(d[1202928+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[h]|0);v=38}else if((v|0)==29){v=0;h=b+u|0;a[h]=(d[1203064+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[h]|0);v=37}else if((v|0)==30){v=0;h=b+u|0;a[h]=(d[1203072+(o>>3)|0]|0)>>>((o&7^7)>>>0)&1^(d[h]|0);v=38}if((v|0)==37){v=0;e=e+1|0;continue}else if((v|0)==38){v=0;h=e+1|0;if((h|0)<48){e=h;continue}else{break}}}return}function Wtb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=+h;var j=0,k=0,l=0,m=0,n=0.0,o=0,p=0.0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0.0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0.0,U=0,V=0,W=0,X=0.0,Y=0.0,Z=0,_=0.0,$=0,aa=0.0,ba=0.0,ca=0.0,da=0.0,ea=0,fa=0,ga=0.0,ha=0,ia=0.0,ja=0.0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0.0,va=0,wa=0.0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0.0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0.0,Ja=0,Ka=0.0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0.0,Sa=0,Ta=0.0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0;b=i;i=i+1024|0;j=b|0;k=b+512|0;l=f+88|0;m=c[l>>2]|0;n=((m|0)>1?85.8:147.84)/h;o=c[f+80>>2]|0;if((m|0)==1){p=0.0;q=0;r=0;t=0;u=0;v=0;while(1){w=d[o+q|0]|0;if((u-v|0)<(w|0)){x=v;y=q}else{x=w+v|0;y=q+1|0}z=+g[f+5312+(u<<2)>>2];if(z!=0.0){A=u;B=y;C=p+z*z}else{A=t;B=r;C=p}w=u+1|0;if((w|0)<1024){p=C;q=y;r=B;t=A;u=w;v=x}else{D=A;E=B;F=C;break}}}else{C=0.0;B=0;A=0;x=0;while(1){v=x<<7;p=C;u=0;t=B;r=A;y=0;q=0;while(1){w=d[o+u|0]|0;if((y-q|0)<(w|0)){G=q;H=u}else{G=w+q|0;H=u+1|0}z=+g[f+5312+(y+v<<2)>>2];if(z!=0.0){I=(r|0)>(y|0)?r:y;J=(t|0)>(H|0)?t:H;K=p+z*z}else{I=r;J=t;K=p}w=y+1|0;if((w|0)<128){p=K;u=H;t=J;r=I;y=w;q=G}else{break}}q=x+1|0;if((q|0)<8){C=K;B=J;A=I;x=q}else{D=I;E=J;F=K;break}}}J=D+1|0;K=F/+(J|0);if(K==0.0){D=0;do{c[f+4644+(D<<2)>>2]=140;D=D+1|0;}while(D>>>0<128>>>0);i=b;return}if((m|0)>0){D=f+84|0;I=f+80|0;F=+(E|0);C=+(J|0);p=n;J=0;x=c[D>>2]|0;A=m;while(1){if((x|0)>0){B=J<<4;G=f+20+J|0;H=0;o=J<<7;q=x;while(1){y=a[(c[I>>2]|0)+H|0]|0;r=y&255;t=r+o|0;u=H+B|0;v=k+(u<<2)|0;g[v>>2]=0.0;do{if((H|0)>(E|0)){g[v>>2]=0.0;if((a[G]|0)==0){L=q;M=0;break}w=r<<2;N=0;do{mrc(f+5312+((N<<7)+o<<2)|0,0,w|0)|0;N=N+1|0;O=a[G]|0;}while((N|0)<(O&255|0));L=c[D>>2]|0;M=O}else{N=a[G]|0;a:do{if(N<<24>>24==0){P=o;Q=0.0}else{w=N&255;if(y<<24>>24==0){U=0;while(1){V=U+1|0;if((V|0)<(w|0)){U=V}else{P=o;Q=0.0;break a}}}else{W=o;X=-1.0;Y=0.0;Z=0;_=0.0}while(1){U=(Z<<7)+o|0;if((c[l>>2]|0)==1){V=W;n=X;z=Y;$=0;aa=_;while(1){ba=+g[f+5312+(U+$<<2)>>2];ca=ba*ba;da=+R(+ba);ba=aa>da?aa:da;da=z+ca;ea=n<ca;fa=ea?$+o|0:V;ga=ea?ca:n;ea=$+1|0;if((ea|0)<(r|0)){V=fa;n=ga;z=da;$=ea;aa=ba}else{ha=fa;ia=ga;ja=da;ka=ba;break}}}else{aa=Y;$=0;z=_;while(1){n=+g[f+5312+(U+$<<2)>>2];ba=+R(+n);da=z>ba?z:ba;ba=aa+n*n;V=$+1|0;if((V|0)<(r|0)){aa=ba;$=V;z=da}else{ha=W;ia=X;ja=ba;ka=da;break}}}g[v>>2]=ka;$=Z+1|0;if(($|0)<(w|0)){W=ha;X=ia;Y=ja;Z=$;_=ka}else{P=ha;Q=ja;break}}}}while(0);if((c[l>>2]|0)==1){w=P-2|0;$=P+3|0;la=($|0)>(t|0)?t:$;ma=(w|0)>(o|0)?w:o}else{la=r;ma=0}z=1.0- +(ma|0)/C;g[j+(u<<2)>>2]=p/(+T(+(Q/(K*+(la-ma|0))),+(+(E-H|0)*.1/F+.3))*1.4+z*z*z+.075);L=q;M=N}}while(0);u=H+1|0;if((u|0)<(L|0)){H=u;o=t;q=L}else{break}}na=L;oa=M;pa=c[l>>2]|0}else{na=x;oa=a[f+20+J|0]|0;pa=A}q=(oa&255)+J|0;if((q|0)<(pa|0)){J=q;x=na;A=pa}else{qa=pa;break}}}else{qa=m}m=f+4644|0;mrc(m|0,0,512)|0;pa=0;do{F=+R(+(+g[f+5312+(pa<<2)>>2]));g[e+736+(pa<<2)>>2]=+S(F*+S(F));pa=pa+1|0;}while((pa|0)<1024);pa=e+736|0;if((qa|0)>0){A=f+84|0;na=f+80|0;F=.001953125/h;x=c[361382]|0;J=0;oa=0;M=qa;qa=c[A>>2]|0;while(1){if((qa|0)>0){L=oa<<4;E=f+20+oa|0;ma=J;la=0;P=oa<<7;while(1){ha=d[(c[na>>2]|0)+la|0]|0;Z=la+L|0;K=+g[k+(Z<<2)>>2];W=f+5156+Z|0;do{if(K<21.544){a[W]=1;ra=ma}else{a[W]=0;O=~~(104.0- +lc(+(1.0/K))*16.0/3.0);if((O|0)<60){sa=60}else{sa=(O|0)>218?218:O}O=j+(Z<<2)|0;D=256;I=-1;q=sa;o=sa;H=ma;G=a[E]|0;while(1){if(G<<24>>24==0){ta=H;ua=0.0;va=0}else{B=200-o+104|0;u=8815024+(B<<2)|0;r=8813312+(B<<2)|0;B=8815024+(o+96<<2)|0;v=H;y=0;Q=0.0;while(1){w=(y<<7)+P|0;$=e+736+(w<<2)|0;U=a[(c[na>>2]|0)+la|0]|0;V=U&255;p=+g[u>>2];C=+g[r>>2];ja=+g[B>>2];ka=ja*165140.0;do{if(($|0)==0){if(U<<24>>24==0){wa=0.0;xa=0;break}else{ya=0}while(1){_=+R(+(+g[f+5312+(ya+w<<2)>>2]));g[e+736+(ya<<2)>>2]=+S(_*+S(_));fa=ya+1|0;if((fa|0)<(V|0)){ya=fa}else{za=pa;Aa=56;break}}}else{za=$;Aa=56}}while(0);b:do{if((Aa|0)==56){Aa=0;$=U<<24>>24==0;if($){wa=0.0;xa=0;break}else{Ba=0}do{_=C*+g[za+(Ba<<2)>>2]+.4054;c[e+336+(Ba<<2)>>2]=_>16.0?16:~~_;Ba=Ba+1|0;}while((Ba|0)<(V|0));if($){wa=0.0;xa=0;break}else{Ca=0;Da=0.0;Ea=0}while(1){fa=(c[e+336+((Ea|1)<<2)>>2]|0)+((c[e+336+(Ea<<2)>>2]|0)*17|0)|0;ea=d[x+fa|0]|0;Fa=fa<<1;fa=c[363628]|0;Ga=Ea+w|0;_=+R(+(+g[f+5312+(Ga<<2)>>2]));Ha=fa+(Fa<<2)|0;Y=+g[Ha>>2];do{if(Y==64.0){if(!(_<ka)){Ia=ka;Ja=ea+21|0;Ka=Y;break}ia=p*_;La=~~(+S(ia*+S(ia))+.4054);if((La|0)<0){Ma=0}else{Ma=(La|0)>8191?8191:La}ia=+(Ma|0);X=ja*ia*+yb(+ia);La=Ma>>>0>65535>>>0;Na=La?Ma>>>16:Ma;Oa=La?16:0;if((Na&65280|0)==0){Pa=Oa;Qa=Na}else{Pa=Oa|8;Qa=Na>>>8}Ia=X;Ja=ea-3+((d[1359664+Qa|0]|0)+Pa<<1)|0;Ka=+g[Ha>>2]}else{Ia=ja*Y;Ja=ea;Ka=Y}}while(0);Y=_-Ia;ea=(Ka!=0.0)+Ja|0;X=Y*Y+0.0;Y=+R(+(+g[f+5312+(Ga+1<<2)>>2]));Ha=fa+((Fa|1)<<2)|0;ia=+g[Ha>>2];do{if(ia==64.0){if(!(Y<ka)){Ra=ka;Sa=ea+21|0;Ta=ia;break}z=p*Y;Na=~~(+S(z*+S(z))+.4054);if((Na|0)<0){Ua=0}else{Ua=(Na|0)>8191?8191:Na}z=+(Ua|0);aa=ja*z*+yb(+z);Na=Ua>>>0>65535>>>0;Oa=Na?Ua>>>16:Ua;La=Na?16:0;if((Oa&65280|0)==0){Va=La;Wa=Oa}else{Va=La|8;Wa=Oa>>>8}Ra=aa;Sa=ea-3+((d[1359664+Wa|0]|0)+Va<<1)|0;Ta=+g[Ha>>2]}else{Ra=ja*ia;Sa=ea;Ta=ia}}while(0);ia=Y-Ra;ea=(Ta!=0.0)+Sa|0;_=Da+(+(ea|0)+(X+ia*ia)*h);if(!(_<s)){wa=s;xa=v;break b}Ha=ea+Ca|0;ea=Ea+2|0;if((ea|0)<(V|0)){Ca=Ha;Da=_;Ea=ea}else{wa=_;xa=Ha;break}}}}while(0);ja=Q+wa- +(xa|0);V=y+1|0;w=a[E]|0;if((V|0)<(w&255|0)){v=xa;y=V;Q=ja}else{ta=xa;ua=ja;va=w;break}}}Q=ua*F;ja=K*+g[8815024+(304-o<<2)>>2];if((~~(+S(ja*+S(ja))+.4054)|0)>8190){Aa=72;break}ja=+g[O>>2];p=+R(+(Q-ja));if(p>1.0){Xa=~~+lc(+p)}else{Xa=0}y=(Q>ja?-Xa|0:Xa)+o|0;if(y>>>0>255>>>0){Ya=-y>>31&255}else{Ya=y&255}Za=Ya&255;y=Za-o|0;v=(y|0)>-1;if(((v?y:-y|0)|0)<2){break}B=(y|0)>0;if(!((Za|0)<(D|0)|B^1)){break}if(!(v|(Za|0)>(I|0))){break}D=B?D:o;I=B?o:I;q=o;o=Za;H=ta;G=va}if((Aa|0)==72){Aa=0;c[f+4644+(Z<<2)>>2]=q;ra=ta;break}if((Za|0)<(I|0)){_a=I}else{_a=(Za|0)>(D|0)?D:Za}c[f+4644+(Z<<2)>>2]=_a;ra=ta}}while(0);Z=la+1|0;$a=c[A>>2]|0;if((Z|0)>=($a|0)){break}ma=ra;la=Z;P=ha+P|0}ab=ra;bb=c[l>>2]|0;cb=$a;db=E}else{ab=J;bb=M;cb=qa;db=f+20+oa|0}P=(d[db]|0)+oa|0;if((P|0)<(bb|0)){J=ab;oa=P;M=bb;qa=cb}else{break}}eb=c[m>>2]|0}else{eb=0}m=(eb|0)==0?2147483647:eb;eb=1;while(1){cb=f+4644+(eb<<2)|0;qa=c[cb>>2]|0;if((qa|0)==0){c[cb>>2]=c[f+4644+(eb-1<<2)>>2];fb=m}else{fb=(m|0)>(qa|0)?qa:m}qa=eb+1|0;if((qa|0)<128){m=fb;eb=qa}else{break}}eb=(fb|0)==2147483647?0:fb;fb=(eb|0)>255?255:eb;eb=fb+60|0;m=(eb|0)>255?255:eb;eb=126;while(1){qa=f+4644+(eb<<2)|0;cb=c[qa>>2]|0;if((cb|0)==0){bb=c[f+4644+(eb+1<<2)>>2]|0;c[qa>>2]=bb;gb=bb}else{gb=cb}if((gb|0)<(fb|0)){hb=fb}else{hb=(gb|0)>(m|0)?m:gb}c[qa>>2]=hb;if((eb|0)>0){eb=eb-1|0}else{break}}i=b;return}function Xtb(b,e,f,h,j){b=b|0;e=e|0;f=f|0;h=h|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0.0,w=0,x=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0,L=0,M=0.0,N=0,O=0,P=0.0,Q=0.0,T=0,U=0,V=0,W=0.0,X=0.0,Y=0,Z=0.0,_=0,$=0,aa=0,ba=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;k=i;i=i+18240|0;l=k|0;m=k+17280|0;n=k+17760|0;o=a[e|0]|0;p=e+88|0;q=c[p>>2]|0;r=(q|0)==1?5:3;t=1<<r;u=0;do{v=+R(+(+g[e+5312+(u<<2)>>2]));g[b+736+(u<<2)>>2]=+S(v*+S(v));u=u+1|0;}while((u|0)<1024);u=o&255;w=t-1|0;g[l+4>>2]=0.0;c[l>>2]=-1;c[l+8>>2]=0;g[l+16>>2]=0.0;c[l+12>>2]=-1;c[l+20>>2]=0;g[l+28>>2]=0.0;c[l+24>>2]=-1;c[l+32>>2]=0;g[l+40>>2]=0.0;c[l+36>>2]=-1;c[l+44>>2]=0;g[l+52>>2]=0.0;c[l+48>>2]=-1;c[l+56>>2]=0;g[l+64>>2]=0.0;c[l+60>>2]=-1;c[l+68>>2]=0;g[l+76>>2]=0.0;c[l+72>>2]=-1;c[l+80>>2]=0;g[l+88>>2]=0.0;c[l+84>>2]=-1;c[l+92>>2]=0;g[l+100>>2]=0.0;c[l+96>>2]=-1;c[l+104>>2]=0;g[l+112>>2]=0.0;c[l+108>>2]=-1;c[l+116>>2]=0;g[l+124>>2]=0.0;c[l+120>>2]=-1;c[l+128>>2]=0;g[l+136>>2]=0.0;c[l+132>>2]=-1;c[l+140>>2]=0;t=o<<24>>24==0;if(!t){o=e+80|0;x=f<<4;z=(h|0)>0;v=+(r|0);A=b+292|0;B=b+248|0;C=s;D=0;E=f<<7;F=0;G=c[o>>2]|0;H=q;while(1){q=d[G+F|0]|0;I=F+1|0;a:do{if((a[F+x+(e+5156)|0]|0)==0){if(z){J=s;K=0;L=0}else{M=s;N=0;O=0;while(1){P=+g[l+(F*144|0)+(O*12|0)+4>>2]+0.0;Q=v+(C+0.0)+4.0;T=c[l+(F*144|0)+(O*12|0)+8>>2]|0;U=c[676392+(((H|0)==8)<<2)>>2]|0;V=T+1|0;if((a[U+T|0]|0)==(a[U+V|0]|0)){W=P}else{W=v+P}U=l+(I*144|0)+(O*12|0)|0;if(Q<W){c[U>>2]=D;g[l+(I*144|0)+(O*12|0)+4>>2]=Q;c[l+(I*144|0)+(O*12|0)+8>>2]=1;X=Q}else{c[U>>2]=O;g[l+(I*144|0)+(O*12|0)+4>>2]=W;c[l+(I*144|0)+(O*12|0)+8>>2]=V;X=W}V=X<M;Q=V?X:M;U=V?O:N;V=O+1|0;if((V|0)<12){M=Q;N=U;O=V}else{Y=U;Z=Q;_=H;$=G;break a}}}do{O=c[687440+(L<<2)>>2]|0;M=0.0;N=0;do{U=(N+f<<4)+F|0;V=(N<<7)+E|0;M=M+ +De[O&15](b,0,e+5312+(V<<2)|0,b+736+(V<<2)|0,q,c[e+4644+(U<<2)>>2]|0,L,j/+g[(c[B>>2]|0)+((c[A>>2]|0)*2564|0)+(U*20|0)+8>>2],s,0);N=N+1|0;}while((N|0)<(h|0));aa=c[p>>2]|0;Q=M+ +g[l+(F*144|0)+(L*12|0)+4>>2];P=v+(C+M)+4.0;N=c[l+(F*144|0)+(L*12|0)+8>>2]|0;O=c[676392+(((aa|0)==8)<<2)>>2]|0;U=N+1|0;if((a[O+N|0]|0)==(a[O+U|0]|0)){ba=Q}else{ba=v+Q}O=l+(I*144|0)+(L*12|0)|0;if(P<ba){c[O>>2]=D;g[l+(I*144|0)+(L*12|0)+4>>2]=P;c[l+(I*144|0)+(L*12|0)+8>>2]=1;ca=P}else{c[O>>2]=L;g[l+(I*144|0)+(L*12|0)+4>>2]=ba;c[l+(I*144|0)+(L*12|0)+8>>2]=U;ca=ba}U=ca<J;J=U?ca:J;K=U?L:K;L=L+1|0;}while((L|0)<12);Y=K;Z=J;_=aa;$=c[o>>2]|0}else{U=0;while(1){c[l+(I*144|0)+(U*12|0)>>2]=U;g[l+(I*144|0)+(U*12|0)+4>>2]=+g[l+(F*144|0)+(U*12|0)+4>>2];c[l+(I*144|0)+(U*12|0)+8>>2]=(c[l+(F*144|0)+(U*12|0)+8>>2]|0)+1;O=U+1|0;if((O|0)<12){U=O}else{Y=D;Z=C;_=H;$=G;break}}}}while(0);I=F+1|0;if((I|0)<(u|0)){C=Z;D=Y;E=(d[$+F|0]|0)+E|0;F=I;G=$;H=_}else{break}}}_=+g[l+(u*144|0)+16>>2]<+g[l+(u*144|0)+4>>2]|0;H=+g[l+(u*144|0)+28>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?2:_;_=+g[l+(u*144|0)+40>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?3:H;H=+g[l+(u*144|0)+52>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?4:_;_=+g[l+(u*144|0)+64>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?5:H;H=+g[l+(u*144|0)+76>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?6:_;_=+g[l+(u*144|0)+88>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?7:H;H=+g[l+(u*144|0)+100>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?8:_;_=+g[l+(u*144|0)+112>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?9:H;H=+g[l+(u*144|0)+124>>2]<+g[l+(u*144|0)+(_*12|0)+4>>2]?10:_;if(t){i=k;return}t=+g[l+(u*144|0)+136>>2]<+g[l+(u*144|0)+(H*12|0)+4>>2]?11:H;H=u;u=0;while(1){_=c[l+(H*144|0)+(t*12|0)+8>>2]|0;c[m+(u<<2)>>2]=_;c[n+(u<<2)>>2]=t;$=H-_|0;da=u+1|0;if(($|0)>0){t=c[l+(($+1|0)*144|0)+(t*12|0)>>2]|0;H=$;u=da}else{break}}if((da|0)<=0){i=k;return}u=b+12|0;H=b+16|0;t=f<<4;f=b+24|0;b=32-r|0;l=0;$=da;da=c[u>>2]|0;_=c[H>>2]|0;while(1){G=$-1|0;F=c[n+(G<<2)>>2]|0;if((_|0)>4){ea=_-4|0;fa=da<<4|F}else{E=je(F>>>((4-_|0)>>>0)|da<<_|0)|0;Y=c[f>>2]|0;y=E;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;ea=_+28|0;fa=F}c[u>>2]=fa;c[H>>2]=ea;Y=c[m+(G<<2)>>2]|0;mrc(l+t+(e+5156)|0,(F|0)==0|0,Y|0)|0;if((Y|0)>0){E=0;D=l;while(1){c[e+3172+(D+t<<2)>>2]=F;o=E+1|0;if((o|0)<(Y|0)){E=o;D=D+1|0}else{break}}ga=l+Y|0}else{ga=l}D=c[u>>2]|0;E=c[H>>2]|0;F=(E|0)>(r|0);if((Y|0)<(w|0)){ha=Y;ia=D;ja=E;ka=F}else{o=Y;aa=D;D=E;E=F;while(1){if(E){la=D-r|0;ma=aa<<r|w}else{F=je(w>>>((r-D|0)>>>0)|aa<<D|0)|0;K=c[f>>2]|0;y=F;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;la=b+D|0;ma=w}c[u>>2]=ma;c[H>>2]=la;K=o-w|0;F=(la|0)>(r|0);if((K|0)<(w|0)){ha=K;ia=ma;ja=la;ka=F;break}else{o=K;aa=ma;D=la;E=F}}}if(ka){na=ja-r|0;oa=ia<<r|ha}else{E=je(ha>>>((r-ja|0)>>>0)|ia<<ja|0)|0;D=c[f>>2]|0;y=E;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;na=b+ja|0;oa=ha}c[u>>2]=oa;c[H>>2]=na;if((G|0)>0){l=ga;$=G;da=oa;_=na}else{break}}i=k;return}function Ytb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;+De[c[687440+(g<<2)>>2]&15](a,b,d,0,e,f,g,h,s,0);return}function Ztb(b,e,f){b=b|0;e=e|0;f=+f;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0,T=0,U=0.0,V=0,W=0.0,X=0.0,Y=0.0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0.0,pa=0,qa=0,ra=0,sa=0,ta=0;h=i;i=i+1024|0;j=h|0;k=h+512|0;l=b+736|0;m=b+1248|0;n=b+1760|0;o=b+2272|0;if((c[e>>2]|0)==0){i=h;return}p=e+248|0;q=c[p>>2]|0;if((q|0)<=0){i=h;return}r=e+244|0;t=b+292|0;u=b+248|0;v=e+240|0;w=j|0;x=k|0;y=e+52432|0;z=0;A=0;B=c[r>>2]|0;C=q;while(1){if((B|0)>0){q=z<<4;D=e+180+z|0;E=0;F=A;G=B;while(1){H=E+q|0;do{if((a[e+5316+H|0]|0)==0){if((a[e+57508+H|0]|0)!=0){I=G;break}if((a[D]|0)==0){J=0.0;K=0.0}else{L=0.0;M=0.0;N=0;while(1){O=(N+z<<4)+E|0;P=c[t>>2]|0;Q=c[u>>2]|0;T=Q+(P*2564|0)+(O*20|0)+8|0;U=+g[T>>2];V=Q+((P+1|0)*2564|0)+(O*20|0)+8|0;W=+g[V>>2];P=U>W;X=P?W:U;Y=P?U:W;P=(c[v>>2]|0)+E|0;Q=(N<<7)+F|0;do{if((a[P]|0)==0){Z=e+5472+(Q<<2)|0;_=15}else{$=0;do{aa=$+Q|0;W=+g[e+57664+(aa<<2)>>2];U=(+g[e+5472+(aa<<2)>>2]+W)*.5;g[j+($<<2)>>2]=U;g[k+($<<2)>>2]=U-W;$=$+1|0;ba=a[P]|0;ca=ba&255;}while(($|0)<(ca|0));$=e+5472+(Q<<2)|0;if(ba<<24>>24==0){Z=$;_=15;break}else{da=0}do{W=+R(+(+g[e+5472+(da+Q<<2)>>2]));g[b+736+(da<<2)>>2]=+S(W*+S(W));da=da+1|0;}while((da|0)<(ca|0));aa=a[P]|0;ea=e+57664+(Q<<2)|0;fa=aa&255;if(aa<<24>>24==0){ga=0;ha=$;ia=ea;break}else{ja=0}do{W=+R(+(+g[e+57664+(ja+Q<<2)>>2]));g[b+736+(ja+128<<2)>>2]=+S(W*+S(W));ja=ja+1|0;}while((ja|0)<(fa|0));fa=a[P]|0;aa=fa&255;if(fa<<24>>24==0){ga=0;ha=$;ia=ea;break}else{ka=0}do{W=+R(+(+g[j+(ka<<2)>>2]));g[b+736+(ka+256<<2)>>2]=+S(W*+S(W));ka=ka+1|0;}while((ka|0)<(aa|0));aa=a[P]|0;fa=aa&255;if(aa<<24>>24==0){ga=0;ha=$;ia=ea;break}else{la=0}do{W=+R(+(+g[k+(la<<2)>>2]));g[b+736+(la+384<<2)>>2]=+S(W*+S(W));la=la+1|0;}while((la|0)<(fa|0));ga=d[P]|0;ha=$;ia=ea}}while(0);if((_|0)==15){_=0;ga=0;ha=Z;ia=e+57664+(Q<<2)|0}P=e+4804+(O<<2)|0;fa=e+3332+(O<<2)|0;aa=c[fa>>2]|0;W=L+ +De[c[687440+(aa<<2)>>2]&15](b,0,ha,l,ga,c[P>>2]|0,aa,f/+g[T>>2],s,0);aa=e+56996+(O<<2)|0;ma=e+55524+(O<<2)|0;na=c[ma>>2]|0;U=W+ +De[c[687440+(na<<2)>>2]&15](b,0,ia,m,d[(c[y>>2]|0)+E|0]|0,c[aa>>2]|0,na,f/+g[V>>2],s,0);na=c[fa>>2]|0;W=M+ +De[c[687440+(na<<2)>>2]&15](b,0,w,n,d[(c[v>>2]|0)+E|0]|0,c[P>>2]|0,na,f/Y,s,0);na=c[ma>>2]|0;oa=W+ +De[c[687440+(na<<2)>>2]&15](b,0,x,o,d[(c[y>>2]|0)+E|0]|0,c[aa>>2]|0,na,f/X,s,0);na=N+1|0;if((na|0)<(d[D]|0)){L=U;M=oa;N=na}else{J=U;K=oa;break}}}a[e+8+H|0]=K<J|0;I=c[r>>2]|0}else{I=G}}while(0);pa=(d[(c[v>>2]|0)+E|0]|0)+F|0;H=E+1|0;if((H|0)<(I|0)){E=H;F=pa;G=I}else{break}}qa=pa;ra=I;sa=c[p>>2]|0;ta=D}else{qa=A;ra=B;sa=C;ta=e+180+z|0}G=(d[ta]|0)+z|0;if((G|0)<(sa|0)){z=G;A=qa;B=ra;C=sa}else{break}}i=h;return}function _tb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=+h;var j=0,k=0,l=0.0,m=0,n=0.0,o=0.0,p=0,q=0.0,r=0.0,t=0.0,u=0.0,v=0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,T=0,U=0,V=0,W=0,X=0.0,Y=0.0,Z=0,_=0,$=0,aa=0.0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0,ka=0,la=0.0,ma=0,na=0.0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;b=i;i=i+59536|0;j=b|0;k=b+59048|0;l=0.0;m=0;n=0.0;o=3.4028234663852886e+38;p=0;while(1){q=+g[f+5312+(p<<2)>>2];r=+R(+q);if(q==0.0){t=o;u=n;v=m;w=l}else{t=o>r?r:o;u=n>r?n:r;v=m+1|0;w=l+r*r}x=p+1|0;if((x|0)<1024){l=w;m=v;n=u;o=t;p=x}else{break}}if((v|0)==0){mrc(f+4644|0,0,512)|0;mrc(f+5156|0,1,128)|0;i=b;return}p=~~(+lc(+t)*4.0+-69.0+140.0+-36.0);if(p>>>0>255>>>0){y=-p>>31&255}else{y=p&255}p=y&255;y=~~(+lc(+u)*4.0+6.0+140.0+-36.0);if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}y=z&255;do{if((y-p|0)>60){z=~~(+lc(+(+S(w/+(v|0))))*4.0+-31.0+140.0+-36.0);if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}z=A&255;m=z+30|0;x=z-30|0;if((x|0)<(p|0)){B=p+60|0;C=p;break}else{z=m>>>0>y>>>0;B=z?y:m;C=z?y-60|0:x;break}}else{B=y;C=p}}while(0);p=0;while(1){g[j+(p<<3)>>2]=0.0;c[j+(p<<3)+4>>2]=-1;y=p+1|0;if((y|0)<61){p=y}else{D=1;break}}while(1){p=0;do{g[j+(D*488|0)+(p<<3)>>2]=s;c[j+(D*488|0)+(p<<3)+4>>2]=-2;p=p+1|0;}while((p|0)<61);p=D+1|0;if((p|0)<121){D=p}else{E=0;break}}do{w=+R(+(+g[f+5312+(E<<2)>>2]));g[e+736+(E<<2)>>2]=+S(w*+S(w));E=E+1|0;}while((E|0)<1024);E=f+88|0;D=c[E>>2]|0;if((D|0)>0){p=f+84|0;y=f+80|0;A=B-C|0;B=(A|0)>0;v=e+292|0;x=e+248|0;z=1;m=0;F=c[p>>2]|0;G=D;while(1){if((F|0)>0){H=m<<4;I=f+20+m|0;J=z;K=m<<7;L=0;while(1){M=L+H|0;c[k+(J<<2)>>2]=M;do{if((a[I]|0)==0){N=38}else{w=2147483648.0;u=0.0;O=0;P=0;while(1){Q=(P+m<<4)+L|0;T=c[v>>2]|0;U=c[x>>2]|0;t=+g[U+(T*2564|0)+(Q*20|0)+8>>2];V=f+5156+Q|0;do{if(+g[U+(T*2564|0)+(Q*20|0)+4>>2]<=t|t==0.0){a[V]=1;W=O;X=u;Y=w}else{a[V]=0;Z=a[(c[y>>2]|0)+L|0]|0;if(Z<<24>>24==0){W=1;X=u;Y=w;break}_=(P<<7)+K|0;$=Z&255;o=w;n=u;Z=0;while(1){l=+g[f+5312+(_+Z<<2)>>2];r=+R(+l);if(l==0.0){aa=o}else{aa=o>r?r:o}l=n>r?n:r;ba=Z+1|0;if((ba|0)<($|0)){o=aa;n=l;Z=ba}else{W=1;X=l;Y=aa;break}}}}while(0);V=P+1|0;ca=a[I]|0;if((V|0)<(ca&255|0)){w=Y;u=X;O=W;P=V}else{break}}P=(W|0)!=0;if(!P){N=38;break}O=~~(+lc(+Y)*4.0+-69.0+140.0+-36.0);if(O>>>0>255>>>0){da=-O>>31&255}else{da=O&255}O=~~(+lc(+X)*4.0+6.0+140.0+-36.0);if(O>>>0>255>>>0){ea=-O>>31&255}else{ea=O&255}O=(da&255)-C|0;if((O|0)<0){fa=0}else{fa=(O|0)>60?60:O}O=(ea&255)-C|0;if((O|0)<0){ga=0}else{ga=(O|0)>61?61:O}O=ca&255;V=a[(c[y>>2]|0)+L|0]|0;Q=V&255;if(ca<<24>>24==0){ha=0.0}else{T=V<<24>>24==0;u=0.0;V=0;while(1){if(T){ia=u}else{U=(V<<7)+K|0;w=u;Z=0;while(1){t=+g[e+736+(U+Z<<2)>>2];n=w>t?w:t;$=Z+1|0;if(($|0)<(Q|0)){w=n;Z=$}else{ia=n;break}}}Z=V+1|0;if((Z|0)<(O|0)){u=ia;V=Z}else{ha=ia;break}}}if((fa|0)>=(ga|0)){ja=P;break}V=f+4644+(M<<2)|0;O=J-1|0;Q=fa;T=ca;while(1){u=+g[8815024+(304-(c[V>>2]|0)<<2)>>2];Z=~~(ha*+S(u*+S(u))+.40540000796318054);do{if((Z|0)==1){ka=1}else if((Z|0)==2){ka=3}else if((Z|0)==0){ka=0}else{if((Z|0)<5){ka=5;break}if((Z|0)<8){ka=7;break}ka=(Z|0)<13?9:11}}while(0);if(T<<24>>24==0){la=0.0;ma=0}else{Z=Q+C|0;U=c[687440+(ka<<2)>>2]|0;u=0.0;$=0;while(1){_=($<<7)+K|0;w=u+ +De[U&15](e,0,f+5312+(_<<2)|0,e+736+(_<<2)|0,d[(c[y>>2]|0)+L|0]|0,Z,ka,h/+g[(c[x>>2]|0)+((c[v>>2]|0)*2564|0)+((($+m<<4)+L|0)*20|0)+8>>2],s,0);_=$+1|0;ba=a[I]|0;if((_|0)<(ba&255|0)){u=w;$=_}else{la=w;ma=ba;break}}}if(B){$=Q+60|0;Z=j+(J*488|0)+(Q<<3)|0;U=j+(J*488|0)+(Q<<3)+4|0;ba=0;u=+g[Z>>2];while(1){w=la+ +g[j+(O*488|0)+(ba<<3)>>2]+ +(d[1446024+($-ba)|0]|0);if(w<u){g[Z>>2]=w;c[U>>2]=ba;na=w}else{na=u}_=ba+1|0;if((_|0)<(A|0)){ba=_;u=na}else{break}}}ba=Q+1|0;if((ba|0)<(ga|0)){Q=ba;T=ma}else{ja=P;break}}}}while(0);do{if((N|0)==38){N=0;if(!B){ja=0;break}P=J-1|0;T=0;while(1){g[j+(J*488|0)+(T<<3)>>2]=+g[j+(P*488|0)+(T<<3)>>2]+1.0;c[j+(J*488|0)+(T<<3)+4>>2]=T;Q=T+1|0;if((Q|0)<(A|0)){T=Q}else{ja=0;break}}}}while(0);a[f+5156+M|0]=ja&1^1;oa=J+1|0;T=L+1|0;pa=c[p>>2]|0;if((T|0)<(pa|0)){J=oa;K=(d[(c[y>>2]|0)+L|0]|0)+K|0;L=T}else{break}}qa=oa;ra=pa;sa=c[E>>2]|0;ta=I}else{qa=z;ra=F;sa=G;ta=f+20+m|0}L=(d[ta]|0)+m|0;if((L|0)<(sa|0)){z=qa;m=L;F=ra;G=sa}else{ua=qa;va=sa;break}}}else{ua=1;va=D}D=ua-1|0;na=+g[j+(D*488|0)>>2];ua=0;sa=1;while(1){la=+g[j+(D*488|0)+(sa<<3)>>2];qa=la<na;wa=qa?sa:ua;G=sa+1|0;if((G|0)<61){na=qa?la:na;ua=wa;sa=G}else{break}}if((D|0)==0){xa=va}else{va=wa;wa=D;while(1){c[f+4644+(c[k+(wa<<2)>>2]<<2)>>2]=va+C;D=wa-1|0;if((D|0)==0){break}else{va=c[j+(wa*488|0)+(va<<3)+4>>2]|0;wa=D}}xa=c[E>>2]|0}if((xa|0)<=0){i=b;return}wa=f+84|0;va=0;j=c[wa>>2]|0;C=xa;while(1){xa=f+20+va|0;if((j|0)>0){k=va<<4;D=0;sa=a[xa]|0;ua=j;while(1){if((sa&255)>>>0>1>>>0){G=f+4644+(D+k<<2)|0;qa=1;do{c[f+4644+((qa+va<<4)+D<<2)>>2]=c[G>>2];qa=qa+1|0;ya=a[xa]|0;}while((qa|0)<(ya&255|0));za=ya;Aa=c[wa>>2]|0}else{za=sa;Aa=ua}qa=D+1|0;if((qa|0)<(Aa|0)){D=qa;sa=za;ua=Aa}else{break}}Ba=Aa;Ca=c[E>>2]|0;Da=za}else{Ba=j;Ca=C;Da=a[xa]|0}ua=(Da&255)+va|0;if((ua|0)<(Ca|0)){va=ua;j=Ba;C=Ca}else{break}}i=b;return}function $tb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=+h;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0.0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0,O=0,P=0.0,Q=0,T=0,U=0,V=0.0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0.0,da=0.0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;j=i;i=i+1544|0;k=j|0;l=j+512|0;m=j+1024|0;n=j+1536|0;o=~~(+(c[b+72>>2]|0)*1024.0/+(c[b+412>>2]|0)/+(c[b+416>>2]|0)*(h/120.0));mrc(k|0,0,512)|0;b=(o|0)>5800?5800:o;o=f+88|0;p=c[o>>2]|0;if((p|0)<=0){i=j;return}q=f+84|0;r=e+292|0;t=e+248|0;u=0;h=s;v=0;w=c[q>>2]|0;x=p;while(1){p=f+20+v|0;if((w|0)>0){y=v<<4;z=u;A=h;B=0;while(1){C=a[p]|0;if(C<<24>>24==0){D=0;E=0.0}else{F=0;G=0.0;H=0;I=C;while(1){C=(H+v<<4)+B|0;J=c[r>>2]|0;K=c[t>>2]|0;L=+g[K+(J*2564|0)+(C*20|0)+8>>2];M=G+L;if(+g[K+(J*2564|0)+(C*20|0)+4>>2]<=L|L==0.0){a[f+5156+C|0]=1;N=F;O=a[p]|0}else{N=1;O=I}C=H+1|0;if((C|0)<(O&255|0)){F=N;G=M;H=C;I=O}else{D=N;E=M;break}}}I=B+y|0;g[l+(I<<2)>>2]=E*512.0;H=(D|0)!=0;a[f+5156+I|0]=H&1^1;if(H){P=A>E?E:A}else{P=A}Q=D|z;H=B+1|0;T=c[q>>2]|0;if((H|0)<(T|0)){z=Q;A=P;B=H}else{break}}U=Q;V=P;W=T;X=c[o>>2]|0}else{U=u;V=h;W=w;X=x}B=(d[p]|0)+v|0;if((B|0)<(X|0)){u=U;h=V;v=B;w=W;x=X}else{break}}if((X|0)>0){x=f+84|0;W=0;w=c[x>>2]|0;v=X;while(1){if((w|0)>0){u=W<<4;T=0;do{Q=T+u|0;if((a[f+5156+Q|0]|0)==0){h=+lc(+(+g[l+(Q<<2)>>2]/V))*4.0;if(h>59.0){Y=199}else{Y=~~(h+140.0)}c[f+4644+(Q<<2)>>2]=Y}else{c[f+4644+(Q<<2)>>2]=140}T=T+1|0;Z=c[x>>2]|0;}while((T|0)<(Z|0));_=Z;$=c[o>>2]|0}else{_=w;$=v}T=(d[f+20+W|0]|0)+W|0;if((T|0)<($|0)){W=T;w=_;v=$}else{aa=$;break}}}else{aa=X}if((U|0)==0){i=j;return}else{ba=0}do{V=+R(+(+g[f+5312+(ba<<2)>>2]));g[e+736+(ba<<2)>>2]=+S(V*+S(V));ba=ba+1|0;}while((ba|0)<1024);ba=f+84|0;if((aa|0)>0){U=c[ba>>2]|0;X=(U|0)>0;$=f+80|0;v=0;while(1){_=a[f+20+v|0]|0;w=_&255;if(X){W=c[$>>2]|0;Z=v<<4;x=0;Y=v<<7;while(1){T=a[W+x|0]|0;u=T&255;if(_<<24>>24==0){ca=0.0}else{p=T<<24>>24==0;V=0.0;T=0;while(1){if(p){da=V}else{Q=(T<<7)+Y|0;h=V;q=0;while(1){P=+g[e+736+(Q+q<<2)>>2];E=h>P?h:P;D=q+1|0;if((D|0)<(u|0)){h=E;q=D}else{da=E;break}}}q=T+1|0;if((q|0)<(w|0)){V=da;T=q}else{ca=da;break}}}g[m+(x+Z<<2)>>2]=ca;T=x+1|0;if((T|0)<(U|0)){x=T;Y=u+Y|0}else{break}}}Y=w+v|0;if((Y|0)<(aa|0)){v=Y}else{ea=$;break}}}else{ea=f+80|0}$=f+4644|0;ca=+(b|0)*1.02;v=0;U=aa;while(1){aa=(v|0)!=0?1:32;X=c[$>>2]|0;Y=U;while(1){if((Y|0)>0){x=X;Z=0;_=-1;W=0;T=c[ba>>2]|0;p=Y;while(1){if((T|0)>0){q=W<<4;Q=f+20+W|0;D=x;N=0;O=Z;t=_;r=W<<7;B=T;while(1){z=N+q|0;do{if((a[f+5156+z|0]|0)==0){y=f+4644+(z<<2)|0;H=c[y>>2]|0;if((H|0)>217){fa=t;ga=O;ha=D;ia=B;break}I=(D|0)>(H|0)?H:D;da=+g[8815024+(304-H<<2)>>2];F=~~(+g[m+(z<<2)>>2]*+S(da*+S(da))+.40540000796318054);do{if((F|0)==1){ja=1}else if((F|0)==2){ja=3}else if((F|0)==0){ja=0}else{if((F|0)<5){ja=5;break}if((F|0)<8){ja=7;break}ja=(F|0)<13?9:11}}while(0);a:do{if((a[Q]|0)==0){ka=0;la=0.0}else{F=c[687440+(ja<<2)>>2]|0;C=0;J=0;da=0.0;K=H;while(1){ma=(C<<7)+r|0;V=da+ +De[F&15](e,0,f+5312+(ma<<2)|0,e+736+(ma<<2)|0,d[(c[ea>>2]|0)+N|0]|0,K,ja,1.0,s,n);ma=(c[n>>2]|0)+J|0;na=C+1|0;if((na|0)>=(d[Q]|0)){ka=ma;la=V;break a}C=na;J=ma;da=V;K=c[y>>2]|0}}}while(0);g[k+(z<<2)>>2]=la- +(ka|0);H=c[y>>2]|0;if((t|0)==-1){oa=ka}else{oa=(d[1446024+(60-t+H)|0]|0)+ka|0}fa=H;ga=oa+O|0;ha=I;ia=c[ba>>2]|0}else{fa=t;ga=O;ha=D;ia=B}}while(0);z=(d[(c[ea>>2]|0)+N|0]|0)+r|0;H=N+1|0;if((H|0)<(ia|0)){D=ha;N=H;O=ga;t=fa;r=z;B=ia}else{break}}pa=ha;qa=ga;ra=fa;sa=ia;ta=c[o>>2]|0;ua=Q}else{pa=x;qa=Z;ra=_;sa=T;ta=p;ua=f+20+W|0}B=(d[ua]|0)+W|0;if((B|0)<(ta|0)){x=pa;Z=qa;_=ra;W=B;T=sa;p=ta}else{va=pa;wa=qa;break}}}else{va=X;wa=0}if((wa|0)>(b|0)){p=218-aa|0;T=0;do{W=f+4644+(T<<2)|0;_=c[W>>2]|0;if((_|0)<(p|0)){c[W>>2]=_+aa}T=T+1|0;}while((T|0)<128)}else{T=60-aa|0;p=0;do{_=f+4644+(p<<2)|0;W=c[_>>2]|0;if((W|0)>(T|0)){c[_>>2]=W-aa}p=p+1|0;}while((p|0)<128)}p=aa>>1;if((p|0)==0){if(!(+(wa|0)>ca)){break}T=(c[$>>2]|0)<217;if(!T){break}xa=T&1}else{xa=p}aa=xa;X=va;Y=c[o>>2]|0}if((va|0)<60){ya=60}else{ya=(va|0)>195?195:va}Y=c[o>>2]|0;if((Y|0)<=0){za=102;break}X=ya+60|0;aa=0;w=0;p=Y;Y=c[ba>>2]|0;while(1){if((Y|0)>0){T=w<<4;W=aa;_=0;do{Z=_+T|0;x=f+4644+(Z<<2)|0;u=c[x>>2]|0;do{if(+g[k+(Z<<2)>>2]>+g[l+(Z<<2)>>2]&(u|0)>60){da=+g[8815024+(305-u<<2)>>2];if((~~(+g[m+(Z<<2)>>2]*+S(da*+S(da))+.40540000796318054)|0)==0){B=u-2|0;c[x>>2]=B;Aa=B;break}else{B=u-1|0;c[x>>2]=B;Aa=B;break}}else{Aa=u}}while(0);if((Aa|0)<(ya|0)){Ba=ya}else{Ba=(Aa|0)>(X|0)?X:Aa}Q=(Ba|0)>219?219:Ba;c[x>>2]=Q;W=(Q|0)==(u|0)?W:1;da=+g[8815024+(304-Q<<2)>>2];Q=~~(+g[m+(Z<<2)>>2]*+S(da*+S(da))+.40540000796318054);do{if((Q|0)==1){Ca=1}else if((Q|0)==2){Ca=3}else if((Q|0)==0){Ca=0}else{if((Q|0)<5){Ca=5;break}if((Q|0)<8){Ca=7;break}Ca=(Q|0)<13?9:11}}while(0);c[f+3172+(Z<<2)>>2]=Ca;_=_+1|0;Da=c[ba>>2]|0;}while((_|0)<(Da|0));Ea=W;Fa=c[o>>2]|0;Ga=Da}else{Ea=aa;Fa=p;Ga=Y}_=(d[f+20+w|0]|0)+w|0;if((_|0)<(Fa|0)){aa=Ea;w=_;p=Fa;Y=Ga}else{break}}Y=v+1|0;if((Ea|0)!=0&(Y|0)<10){v=Y;U=Fa}else{za=102;break}}if((za|0)==102){i=j;return}}function aub(b,e,f,h,j){b=b|0;e=e|0;f=f|0;h=h|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,z=0.0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0.0,P=0,Q=0,T=0,U=0,V=0.0,W=0,X=0.0,Y=0,Z=0.0,_=0.0,$=0.0,aa=0.0,ba=0.0,ca=0,da=0.0,ea=0.0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;k=i;i=i+18240|0;l=k|0;m=k+17280|0;n=k+17760|0;o=a[e|0]|0;p=e+88|0;q=c[p>>2]|0;r=(q|0)==1?5:3;t=1<<r;u=0;do{j=+R(+(+g[e+5312+(u<<2)>>2]));g[b+736+(u<<2)>>2]=+S(j*+S(j));u=u+1|0;}while((u|0)<1024);u=o&255;v=t-1|0;j=+(r+4|0);g[l+4>>2]=j;c[l>>2]=-1;c[l+8>>2]=0;g[l+16>>2]=j;c[l+12>>2]=-1;c[l+20>>2]=0;g[l+28>>2]=j;c[l+24>>2]=-1;c[l+32>>2]=0;g[l+40>>2]=j;c[l+36>>2]=-1;c[l+44>>2]=0;g[l+52>>2]=j;c[l+48>>2]=-1;c[l+56>>2]=0;g[l+64>>2]=j;c[l+60>>2]=-1;c[l+68>>2]=0;g[l+76>>2]=j;c[l+72>>2]=-1;c[l+80>>2]=0;g[l+88>>2]=j;c[l+84>>2]=-1;c[l+92>>2]=0;g[l+100>>2]=j;c[l+96>>2]=-1;c[l+104>>2]=0;g[l+112>>2]=j;c[l+108>>2]=-1;c[l+116>>2]=0;g[l+124>>2]=j;c[l+120>>2]=-1;c[l+128>>2]=0;g[l+136>>2]=j;c[l+132>>2]=-1;c[l+140>>2]=0;t=o<<24>>24==0;if(!t){o=e+80|0;w=f<<4;x=(h|0)>0;j=+(r|0);z=s;A=0;B=f<<7;C=0;D=c[o>>2]|0;E=q;while(1){q=d[D+C|0]|0;F=C+w|0;a:do{if((a[e+5156+F|0]|0)==0){G=c[e+3172+(F<<2)>>2]|0;do{if((G|0)>0){H=C+1|0;I=0;do{g[l+(H*144|0)+(I*12|0)+4>>2]=61450.0;c[l+(H*144|0)+(I*12|0)>>2]=-1;c[l+(H*144|0)+(I*12|0)+8>>2]=0;I=I+1|0;}while((I|0)<(G|0));if((G|0)<12){break}J=0;K=s;L=E;M=D;N=C+1|0;break a}}while(0);I=C+1|0;O=s;H=0;P=G;Q=E;while(1){if(x){T=c[687440+(P<<2)>>2]|0;U=0;V=0.0;do{W=(U<<7)+B|0;V=V+ +De[T&15](b,0,e+5312+(W<<2)|0,b+736+(W<<2)|0,q,c[e+4644+((U+f<<4)+C<<2)>>2]|0,P,0.0,s,0);U=U+1|0;}while((U|0)<(h|0));X=V;Y=c[p>>2]|0}else{X=0.0;Y=Q}Z=X+ +g[l+(C*144|0)+(P*12|0)+4>>2];_=j+(z+X)+4.0;U=c[l+(C*144|0)+(P*12|0)+8>>2]|0;T=c[676392+(((Y|0)==8)<<2)>>2]|0;W=U+1|0;if((a[T+U|0]|0)==(a[T+W|0]|0)){$=Z}else{$=j+Z}T=l+(I*144|0)+(P*12|0)|0;if(_<$){c[T>>2]=A;g[l+(I*144|0)+(P*12|0)+4>>2]=_;c[l+(I*144|0)+(P*12|0)+8>>2]=1;aa=_}else{c[T>>2]=P;g[l+(I*144|0)+(P*12|0)+4>>2]=$;c[l+(I*144|0)+(P*12|0)+8>>2]=W;aa=$}W=aa<O;ba=W?aa:O;ca=W?P:H;W=P+1|0;if((W|0)<12){O=ba;H=ca;P=W;Q=Y}else{break}}J=ca;K=ba;L=Y;M=c[o>>2]|0;N=I}else{O=+g[l+(C*144|0)+4>>2];_=j+z+4.0;Q=c[l+(C*144|0)+8>>2]|0;P=c[676392+(((E|0)==8)<<2)>>2]|0;H=Q+1|0;if((a[P+Q|0]|0)==(a[P+H|0]|0)){da=O}else{da=j+O}P=C+1|0;Q=l+(P*144|0)|0;if(_<da){c[Q>>2]=A;g[l+(P*144|0)+4>>2]=_;c[l+(P*144|0)+8>>2]=1;ea=_}else{c[Q>>2]=0;g[l+(P*144|0)+4>>2]=da;c[l+(P*144|0)+8>>2]=H;ea=da}g[l+(P*144|0)+16>>2]=61450.0;c[l+(P*144|0)+12>>2]=-1;c[l+(P*144|0)+20>>2]=0;g[l+(P*144|0)+28>>2]=61450.0;c[l+(P*144|0)+24>>2]=-1;c[l+(P*144|0)+32>>2]=0;g[l+(P*144|0)+40>>2]=61450.0;c[l+(P*144|0)+36>>2]=-1;c[l+(P*144|0)+44>>2]=0;g[l+(P*144|0)+52>>2]=61450.0;c[l+(P*144|0)+48>>2]=-1;c[l+(P*144|0)+56>>2]=0;g[l+(P*144|0)+64>>2]=61450.0;c[l+(P*144|0)+60>>2]=-1;c[l+(P*144|0)+68>>2]=0;g[l+(P*144|0)+76>>2]=61450.0;c[l+(P*144|0)+72>>2]=-1;c[l+(P*144|0)+80>>2]=0;g[l+(P*144|0)+88>>2]=61450.0;c[l+(P*144|0)+84>>2]=-1;c[l+(P*144|0)+92>>2]=0;g[l+(P*144|0)+100>>2]=61450.0;c[l+(P*144|0)+96>>2]=-1;c[l+(P*144|0)+104>>2]=0;g[l+(P*144|0)+112>>2]=61450.0;c[l+(P*144|0)+108>>2]=-1;c[l+(P*144|0)+116>>2]=0;g[l+(P*144|0)+124>>2]=61450.0;c[l+(P*144|0)+120>>2]=-1;c[l+(P*144|0)+128>>2]=0;g[l+(P*144|0)+136>>2]=61450.0;c[l+(P*144|0)+132>>2]=-1;c[l+(P*144|0)+140>>2]=0;J=0;K=ea;L=E;M=D;N=P}}while(0);if((N|0)<(u|0)){z=K;A=J;B=(d[M+C|0]|0)+B|0;C=N;D=M;E=L}else{break}}}L=+g[l+(u*144|0)+16>>2]<+g[l+(u*144|0)+4>>2]|0;E=+g[l+(u*144|0)+28>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?2:L;L=+g[l+(u*144|0)+40>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?3:E;E=+g[l+(u*144|0)+52>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?4:L;L=+g[l+(u*144|0)+64>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?5:E;E=+g[l+(u*144|0)+76>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?6:L;L=+g[l+(u*144|0)+88>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?7:E;E=+g[l+(u*144|0)+100>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?8:L;L=+g[l+(u*144|0)+112>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?9:E;E=+g[l+(u*144|0)+124>>2]<+g[l+(u*144|0)+(L*12|0)+4>>2]?10:L;if(t){i=k;return}t=+g[l+(u*144|0)+136>>2]<+g[l+(u*144|0)+(E*12|0)+4>>2]?11:E;E=u;u=0;while(1){L=c[l+(E*144|0)+(t*12|0)+8>>2]|0;c[m+(u<<2)>>2]=L;c[n+(u<<2)>>2]=t;M=E-L|0;fa=u+1|0;if((M|0)>0){t=c[l+((M+1|0)*144|0)+(t*12|0)>>2]|0;E=M;u=fa}else{break}}if((fa|0)<=0){i=k;return}u=b+12|0;E=b+16|0;t=f<<4;f=b+24|0;b=32-r|0;l=0;M=fa;fa=c[u>>2]|0;L=c[E>>2]|0;while(1){D=M-1|0;N=c[n+(D<<2)>>2]|0;if((L|0)>4){ga=L-4|0;ha=fa<<4|N}else{C=je(N>>>((4-L|0)>>>0)|fa<<L|0)|0;B=c[f>>2]|0;y=C;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;ga=L+28|0;ha=N}c[u>>2]=ha;c[E>>2]=ga;B=c[m+(D<<2)>>2]|0;mrc(l+t+(e+5156)|0,(N|0)==0|0,B|0)|0;if((B|0)>0){C=0;J=l;while(1){c[e+3172+(J+t<<2)>>2]=N;A=C+1|0;if((A|0)<(B|0)){C=A;J=J+1|0}else{break}}ia=l+B|0}else{ia=l}J=c[u>>2]|0;C=c[E>>2]|0;N=(C|0)>(r|0);if((B|0)<(v|0)){ja=B;ka=J;la=C;ma=N}else{A=B;o=J;J=C;C=N;while(1){if(C){na=J-r|0;oa=o<<r|v}else{N=je(v>>>((r-J|0)>>>0)|o<<J|0)|0;Y=c[f>>2]|0;y=N;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;na=b+J|0;oa=v}c[u>>2]=oa;c[E>>2]=na;Y=A-v|0;N=(na|0)>(r|0);if((Y|0)<(v|0)){ja=Y;ka=oa;la=na;ma=N;break}else{A=Y;o=oa;J=na;C=N}}}if(ma){pa=la-r|0;qa=ka<<r|ja}else{C=je(ja>>>((r-la|0)>>>0)|ka<<la|0)|0;J=c[f>>2]|0;y=C;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;pa=b+la|0;qa=ja}c[u>>2]=qa;c[E>>2]=pa;if((D|0)>0){l=ia;M=D;fa=qa;L=pa}else{break}}i=k;return}function bub(b,d,e,f){b=b|0;d=d|0;e=e|0;f=+f;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;mrc(e+4644|0,0,512)|0;b=e+88|0;h=c[b>>2]|0;if((h|0)>0){i=e+84|0;j=d+292|0;k=d+248|0;d=0;l=c[i>>2]|0;m=h;while(1){h=e+20+d|0;n=a[h]|0;if((l|0)>0){o=0;p=n;q=l;r=n;while(1){if(p<<24>>24==0){s=0;t=q;u=r}else{v=0;do{w=(v+d<<4)+o|0;x=c[j>>2]|0;y=c[k>>2]|0;f=+g[y+(x*2564|0)+(w*20|0)+8>>2];if(+g[y+(x*2564|0)+(w*20|0)+4>>2]>f){x=~~(+lc(+f)+104.0);if((x|0)<80){z=80}else{z=(x|0)>218?218:x}c[e+4644+(w<<2)>>2]=z;a[e+5156+w|0]=0}else{c[e+4644+(w<<2)>>2]=218;a[e+5156+w|0]=1}v=v+1|0;A=a[h]|0;}while((v|0)<(A&255|0));s=A;t=c[i>>2]|0;u=A}v=o+1|0;if((v|0)<(t|0)){o=v;p=s;q=t;r=u}else{break}}B=t;C=u;D=c[b>>2]|0}else{B=l;C=n;D=m}r=(C&255)+d|0;if((r|0)<(D|0)){d=r;l=B;m=D}else{E=0;break}}}else{E=0}do{c[e+4644+(E<<2)>>2]=140;E=E+1|0;}while((E|0)<128);E=c[b>>2]|0;if((E|0)<=0){return}D=e+84|0;m=0;B=c[D>>2]|0;l=E;while(1){E=e+20+m|0;if((B|0)>0){d=m<<4;C=0;u=a[E]|0;t=B;while(1){if((u&255)>>>0>1>>>0){s=e+4644+(C+d<<2)|0;A=1;do{c[e+4644+((A+m<<4)+C<<2)>>2]=c[s>>2];A=A+1|0;F=a[E]|0;}while((A|0)<(F&255|0));G=F;H=c[D>>2]|0}else{G=u;H=t}A=C+1|0;if((A|0)<(H|0)){C=A;u=G;t=H}else{break}}I=H;J=c[b>>2]|0;K=G}else{I=B;J=l;K=a[E]|0}t=(K&255)+m|0;if((t|0)<(J|0)){m=t;B=I;l=J}else{break}}return}function cub(a,b,d,e,f,h,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=+j;k=+k;l=l|0;var m=0.0,n=0.0,o=0.0,p=0.0;if((f|0)>0){k=0.0;i=0;while(1){m=+g[d+(i<<2)>>2];n=k+m*m;h=i+1|0;if((h|0)<(f|0)){k=n;i=h}else{o=n;break}}}else{o=0.0}if((l|0)==0){p=o*j;return+p}c[l>>2]=0;p=o*j;return+p}function dub(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0,T=0.0,U=0,V=0;p=+g[8813312+(304-k<<2)>>2];q=+g[8815024+(k+96<<2)>>2];k=d[2103944+l|0]|0;r=d[2103960+l|0]|0;do{if((i|0)==0){s=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+R(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+S(w*+S(w));x=t+1|0;if((x|0)<(j|0)){t=x}else{z=s;A=4;break}}}else{z=i;A=4}}while(0);a:do{if((A|0)==4){if((j|0)<=0){u=0;v=0.0;break}w=+(r|0);i=0;do{B=p*+g[z+(i<<2)>>2]+.4054;t=~~(B>w?w:B);s=b+336+(i<<2)|0;c[s>>2]=t;if(+g[h+(i<<2)>>2]<0.0){c[s>>2]=-t}i=i+1|0;}while((i|0)<(j|0));i=l-1|0;t=c[1445488+(i<<2)>>2]|0;s=1454472+(i<<2)|0;x=(f|0)==0;C=1445440+(i<<2)|0;i=f|0;D=f+4|0;E=f+12|0;F=0;w=0.0;G=0;while(1){H=ca(r+(c[b+336+(G<<2)>>2]|0)|0,k)|0;I=G|1;J=ca(H+r+(c[b+336+(I<<2)>>2]|0)|0,k)|0;H=G|2;K=ca(J+r+(c[b+336+(H<<2)>>2]|0)|0,k)|0;J=G|3;L=K+r+(c[b+336+(J<<2)>>2]|0)|0;K=L<<2;M=c[s>>2]|0;B=+g[h+(G<<2)>>2]-q*+g[M+(K<<2)>>2];N=+g[h+(I<<2)>>2]-q*+g[M+((K|1)<<2)>>2];O=+g[h+(H<<2)>>2]-q*+g[M+((K|2)<<2)>>2];P=+g[h+(J<<2)>>2]-q*+g[M+((K|3)<<2)>>2];K=d[t+L|0]|0;Q=w+(+(K|0)+(B*B+0.0+N*N+O*O+P*P)*m);M=K+F|0;if(!(Q<n)){T=n;break}if(!x){J=e[(c[C>>2]|0)+(L<<1)>>1]|0;L=c[i>>2]|0;H=c[D>>2]|0;if((H|0)>(K|0)){U=H-K|0;V=L<<K|J}else{I=je(J>>>((K-H|0)>>>0)|L<<H|0)|0;L=c[E>>2]|0;y=I;a[L]=y;y=y>>8;a[L+1|0]=y;y=y>>8;a[L+2|0]=y;y=y>>8;a[L+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;U=32-K+H|0;V=J}c[i>>2]=V;c[D>>2]=U}J=G+4|0;if((J|0)<(j|0)){F=M;w=Q;G=J}else{u=M;v=Q;break a}}return+T}}while(0);if((o|0)==0){T=v;return+T}c[o>>2]=u;T=v;return+T}function eub(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,T=0,U=0.0,V=0.0,W=0,X=0.0,Y=0.0,Z=0,_=0.0,$=0.0,aa=0,ba=0,da=0.0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0.0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;p=+g[8813312+(304-k<<2)>>2];q=+g[8815024+(k+96<<2)>>2];k=d[2103944+l|0]|0;r=d[2103960+l|0]|0;do{if((i|0)==0){s=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+R(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+S(w*+S(w));x=t+1|0;if((x|0)<(j|0)){t=x}else{z=s;A=4;break}}}else{z=i;A=4}}while(0);a:do{if((A|0)==4){if((j|0)<=0){u=0;v=0.0;break}w=+(r|0);i=0;do{B=p*+g[z+(i<<2)>>2]+.4054;c[b+336+(i<<2)>>2]=~~(B>w?w:B);i=i+1|0;}while((i|0)<(j|0));i=l-1|0;t=c[1445488+(i<<2)>>2]|0;s=1454472+(i<<2)|0;x=(f|0)==0;C=1445440+(i<<2)|0;i=f|0;D=f+4|0;E=f+12|0;F=0;w=0.0;G=0;while(1){H=ca(c[b+336+(G<<2)>>2]|0,k)|0;I=G|1;J=ca(H+(c[b+336+(I<<2)>>2]|0)|0,k)|0;H=G|2;K=ca(J+(c[b+336+(H<<2)>>2]|0)|0,k)|0;J=G|3;L=K+(c[b+336+(J<<2)>>2]|0)|0;K=d[t+L|0]|0;M=L<<2;N=c[s>>2]|0;O=h+(G<<2)|0;B=+R(+(+g[O>>2]));P=+g[N+(M<<2)>>2];Q=B-q*P;T=h+(I<<2)|0;B=+R(+(+g[T>>2]));I=M|1;U=+g[N+(I<<2)>>2];V=B-q*U;W=h+(H<<2)|0;B=+R(+(+g[W>>2]));H=M|2;X=+g[N+(H<<2)>>2];Y=B-q*X;Z=h+(J<<2)|0;B=+R(+(+g[Z>>2]));J=M|3;_=+g[N+(J<<2)>>2];$=B-q*_;aa=(_!=0.0)+((X!=0.0)+((U!=0.0)+((P!=0.0)+K)))|0;U=w+(+(aa|0)+(Q*Q+0.0+V*V+Y*Y+$*$)*m);ba=aa+F|0;if(!(U<n)){da=n;break}do{if(!x){aa=e[(c[C>>2]|0)+(L<<1)>>1]|0;ea=c[i>>2]|0;fa=c[D>>2]|0;if((fa|0)>(K|0)){ga=fa-K|0;ha=ea<<K|aa;ia=N;ja=P}else{ka=je(aa>>>((K-fa|0)>>>0)|ea<<fa|0)|0;ea=c[E>>2]|0;y=ka;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;ea=c[s>>2]|0;ga=32-K+fa|0;ha=aa;ia=ea;ja=+g[ea+(M<<2)>>2]}c[i>>2]=ha;c[D>>2]=ga;if(ja!=0.0){ea=+g[O>>2]<0.0|0;if((ga|0)>1){la=ga-1|0;ma=ea|ha<<1;na=ia}else{aa=je(ea>>>((1-ga|0)>>>0)|ha<<ga|0)|0;fa=c[E>>2]|0;y=aa;a[fa]=y;y=y>>8;a[fa+1|0]=y;y=y>>8;a[fa+2|0]=y;y=y>>8;a[fa+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;la=ga+31|0;ma=ea;na=c[s>>2]|0}c[i>>2]=ma;c[D>>2]=la;oa=ma;pa=la;qa=na}else{oa=ha;pa=ga;qa=ia}if(+g[qa+(I<<2)>>2]!=0.0){ea=+g[T>>2]<0.0|0;if((pa|0)>1){ra=pa-1|0;sa=ea|oa<<1;ta=qa}else{fa=je(ea>>>((1-pa|0)>>>0)|oa<<pa|0)|0;aa=c[E>>2]|0;y=fa;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;ra=pa+31|0;sa=ea;ta=c[s>>2]|0}c[i>>2]=sa;c[D>>2]=ra;ua=sa;va=ra;wa=ta}else{ua=oa;va=pa;wa=qa}if(+g[wa+(H<<2)>>2]!=0.0){ea=+g[W>>2]<0.0|0;if((va|0)>1){xa=va-1|0;ya=ea|ua<<1;za=wa}else{aa=je(ea>>>((1-va|0)>>>0)|ua<<va|0)|0;fa=c[E>>2]|0;y=aa;a[fa]=y;y=y>>8;a[fa+1|0]=y;y=y>>8;a[fa+2|0]=y;y=y>>8;a[fa+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;xa=va+31|0;ya=ea;za=c[s>>2]|0}c[i>>2]=ya;c[D>>2]=xa;Aa=ya;Ba=xa;Ca=za}else{Aa=ua;Ba=va;Ca=wa}if(!(+g[Ca+(J<<2)>>2]!=0.0)){break}ea=+g[Z>>2]<0.0|0;if((Ba|0)>1){Da=Ba-1|0;Ea=ea|Aa<<1}else{fa=je(ea>>>((1-Ba|0)>>>0)|Aa<<Ba|0)|0;aa=c[E>>2]|0;y=fa;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;Da=Ba+31|0;Ea=ea}c[i>>2]=Ea;c[D>>2]=Da}}while(0);Z=G+4|0;if((Z|0)<(j|0)){F=ba;w=U;G=Z}else{u=ba;v=U;break a}}return+da}}while(0);if((o|0)==0){da=v;return+da}c[o>>2]=u;da=v;return+da}function fub(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0.0,O=0,P=0,Q=0,T=0;p=+g[8813312+(304-k<<2)>>2];q=+g[8815024+(k+96<<2)>>2];k=d[2103944+l|0]|0;r=d[2103960+l|0]|0;do{if((i|0)==0){s=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+R(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+S(w*+S(w));x=t+1|0;if((x|0)<(j|0)){t=x}else{z=s;A=4;break}}}else{z=i;A=4}}while(0);a:do{if((A|0)==4){if((j|0)<=0){u=0;v=0.0;break}w=+(r|0);i=0;do{B=p*+g[z+(i<<2)>>2]+.4054;t=~~(B>w?w:B);s=b+336+(i<<2)|0;c[s>>2]=t;if(+g[h+(i<<2)>>2]<0.0){c[s>>2]=-t}i=i+1|0;}while((i|0)<(j|0));i=l-1|0;t=c[1445488+(i<<2)>>2]|0;s=1454472+(i<<2)|0;x=(f|0)==0;C=1445440+(i<<2)|0;i=f|0;D=f+4|0;E=f+12|0;F=0;w=0.0;G=0;while(1){H=ca(r+(c[b+336+(G<<2)>>2]|0)|0,k)|0;I=G|1;J=H+r+(c[b+336+(I<<2)>>2]|0)|0;H=J<<1;K=c[s>>2]|0;B=+g[h+(G<<2)>>2]-q*+g[K+(H<<2)>>2];L=+g[h+(I<<2)>>2]-q*+g[K+((H|1)<<2)>>2];H=d[t+J|0]|0;M=w+(+(H|0)+(B*B+0.0+L*L)*m);K=H+F|0;if(!(M<n)){N=n;break}if(!x){I=e[(c[C>>2]|0)+(J<<1)>>1]|0;J=c[i>>2]|0;O=c[D>>2]|0;if((O|0)>(H|0)){P=O-H|0;Q=J<<H|I}else{T=je(I>>>((H-O|0)>>>0)|J<<O|0)|0;J=c[E>>2]|0;y=T;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;P=32-H+O|0;Q=I}c[i>>2]=Q;c[D>>2]=P}I=G+2|0;if((I|0)<(j|0)){F=K;w=M;G=I}else{u=K;v=M;break a}}return+N}}while(0);if((o|0)==0){N=v;return+N}c[o>>2]=u;N=v;return+N}function gub(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0.0,T=0.0,U=0,V=0,W=0.0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;p=+g[8813312+(304-k<<2)>>2];q=+g[8815024+(k+96<<2)>>2];k=d[2103944+l|0]|0;r=d[2103960+l|0]|0;do{if((i|0)==0){s=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+R(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+S(w*+S(w));x=t+1|0;if((x|0)<(j|0)){t=x}else{z=s;A=4;break}}}else{z=i;A=4}}while(0);a:do{if((A|0)==4){if((j|0)<=0){u=0;v=0.0;break}w=+(r|0);i=0;do{B=p*+g[z+(i<<2)>>2]+.4054;c[b+336+(i<<2)>>2]=~~(B>w?w:B);i=i+1|0;}while((i|0)<(j|0));i=l-1|0;t=c[1445488+(i<<2)>>2]|0;s=1454472+(i<<2)|0;x=(f|0)==0;C=1445440+(i<<2)|0;i=f|0;D=f+4|0;E=f+12|0;F=0;w=0.0;G=0;while(1){H=ca(c[b+336+(G<<2)>>2]|0,k)|0;I=G|1;J=H+(c[b+336+(I<<2)>>2]|0)|0;H=d[t+J|0]|0;K=J<<1;L=c[s>>2]|0;M=h+(G<<2)|0;B=+R(+(+g[M>>2]));N=+g[L+(K<<2)>>2];O=B-q*N;P=h+(I<<2)|0;B=+R(+(+g[P>>2]));I=K|1;Q=+g[L+(I<<2)>>2];T=B-q*Q;U=(Q!=0.0)+((N!=0.0)+H)|0;Q=w+(+(U|0)+(O*O+0.0+T*T)*m);V=U+F|0;if(!(Q<n)){W=n;break}do{if(!x){U=e[(c[C>>2]|0)+(J<<1)>>1]|0;X=c[i>>2]|0;Y=c[D>>2]|0;if((Y|0)>(H|0)){Z=Y-H|0;_=X<<H|U;$=L;aa=N}else{ba=je(U>>>((H-Y|0)>>>0)|X<<Y|0)|0;X=c[E>>2]|0;y=ba;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;X=c[s>>2]|0;Z=32-H+Y|0;_=U;$=X;aa=+g[X+(K<<2)>>2]}c[i>>2]=_;c[D>>2]=Z;if(aa!=0.0){X=+g[M>>2]<0.0|0;if((Z|0)>1){da=Z-1|0;ea=X|_<<1;fa=$}else{U=je(X>>>((1-Z|0)>>>0)|_<<Z|0)|0;Y=c[E>>2]|0;y=U;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;da=Z+31|0;ea=X;fa=c[s>>2]|0}c[i>>2]=ea;c[D>>2]=da;ga=ea;ha=da;ia=fa}else{ga=_;ha=Z;ia=$}if(!(+g[ia+(I<<2)>>2]!=0.0)){break}X=+g[P>>2]<0.0|0;if((ha|0)>1){ja=ha-1|0;ka=X|ga<<1}else{Y=je(X>>>((1-ha|0)>>>0)|ga<<ha|0)|0;U=c[E>>2]|0;y=Y;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;ja=ha+31|0;ka=X}c[i>>2]=ka;c[D>>2]=ja}}while(0);P=G+2|0;if((P|0)<(j|0)){F=V;w=Q;G=P}else{u=V;v=Q;break a}}return+W}}while(0);if((o|0)==0){W=v;return+W}c[o>>2]=u;W=v;return+W}function hub(b,f,h,i,j,k,l,m,n,o){b=b|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=+m;n=+n;o=o|0;var p=0.0,q=0.0,r=0.0,s=0.0,t=0,u=0,v=0.0,w=0.0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0.0,P=0.0,Q=0,T=0.0,U=0.0,V=0,W=0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0.0,ba=0,ca=0.0,da=0.0,ea=0,fa=0.0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;l=200-k+104|0;p=+g[8815024+(l<<2)>>2];q=+g[8813312+(l<<2)>>2];r=+g[8815024+(k+96<<2)>>2];s=r*165140.0;do{if((i|0)==0){k=b+736|0;if((j|0)>0){t=0}else{u=0;v=0.0;break}while(1){w=+R(+(+g[h+(t<<2)>>2]));g[b+736+(t<<2)>>2]=+S(w*+S(w));l=t+1|0;if((l|0)<(j|0)){t=l}else{x=k;z=4;break}}}else{x=i;z=4}}while(0);a:do{if((z|0)==4){if((j|0)>0){A=0}else{u=0;v=0.0;break}do{w=q*+g[x+(A<<2)>>2]+.4054;c[b+336+(A<<2)>>2]=w>16.0?16:~~w;A=A+1|0;}while((A|0)<(j|0));i=c[361382]|0;t=(f|0)==0;k=f|0;l=f+4|0;B=f+12|0;C=c[361370]|0;D=0;w=0.0;E=0;while(1){F=E|1;G=((c[b+336+(E<<2)>>2]|0)*17|0)+(c[b+336+(F<<2)>>2]|0)|0;H=i+G|0;I=d[H]|0;J=G<<1;K=c[363628]|0;L=h+(E<<2)|0;M=+R(+(+g[L>>2]));N=K+(J<<2)|0;O=+g[N>>2];do{if(O==64.0){if(!(M<s)){P=s;Q=I+21|0;T=O;break}U=p*M;V=~~(+S(U*+S(U))+.4054);if((V|0)<0){W=0}else{W=(V|0)>8191?8191:V}U=+(W|0);X=r*U*+yb(+U);V=W>>>0>65535>>>0;Y=V?W>>>16:W;Z=V?16:0;if((Y&65280|0)==0){_=Z;$=Y}else{_=Z|8;$=Y>>>8}P=X;Q=I-3+((d[1359664+$|0]|0)+_<<1)|0;T=+g[N>>2]}else{P=r*O;Q=I;T=O}}while(0);O=M-P;I=(T!=0.0)+Q|0;X=O*O+0.0;N=h+(F<<2)|0;O=+R(+(+g[N>>2]));Y=J|1;Z=K+(Y<<2)|0;U=+g[Z>>2];do{if(U==64.0){if(!(O<s)){aa=s;ba=I+21|0;ca=U;break}da=p*O;V=~~(+S(da*+S(da))+.4054);if((V|0)<0){ea=0}else{ea=(V|0)>8191?8191:V}da=+(ea|0);fa=r*da*+yb(+da);V=ea>>>0>65535>>>0;ga=V?ea>>>16:ea;ha=V?16:0;if((ga&65280|0)==0){ia=ha;ja=ga}else{ia=ha|8;ja=ga>>>8}aa=fa;ba=I-3+((d[1359664+ja|0]|0)+ia<<1)|0;ca=+g[Z>>2]}else{aa=r*U;ba=I;ca=U}}while(0);U=O-aa;I=(ca!=0.0)+ba|0;M=w+((X+U*U)*m+ +(I|0));Z=I+D|0;if(!(M<n)){ka=n;break}if(!t){I=d[H]|0;K=e[C+(G<<1)>>1]|0;F=c[k>>2]|0;ga=c[l>>2]|0;if((ga|0)>(I|0)){la=ga-I|0;ma=F<<I|K}else{ha=je(K>>>((I-ga|0)>>>0)|F<<ga|0)|0;F=c[B>>2]|0;y=ha;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;la=32-I+ga|0;ma=K}c[k>>2]=ma;c[l>>2]=la;K=c[363628]|0;if(+g[K+(J<<2)>>2]!=0.0){ga=+g[L>>2]<0.0|0;if((la|0)>1){na=la-1|0;oa=ga|ma<<1;pa=K}else{I=je(ga>>>((1-la|0)>>>0)|ma<<la|0)|0;F=c[B>>2]|0;y=I;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;na=la+31|0;oa=ga;pa=c[363628]|0}c[k>>2]=oa;c[l>>2]=na;qa=oa;ra=na;sa=pa}else{qa=ma;ra=la;sa=K}if(+g[sa+(Y<<2)>>2]!=0.0){K=+g[N>>2]<0.0|0;if((ra|0)>1){ta=ra-1|0;ua=K|qa<<1}else{ga=je(K>>>((1-ra|0)>>>0)|qa<<ra|0)|0;F=c[B>>2]|0;y=ga;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;ta=ra+31|0;ua=K}c[k>>2]=ua;c[l>>2]=ta;va=0;wa=ua;xa=ta}else{va=0;wa=qa;xa=ra}while(1){if(+g[(c[363628]|0)+(va+J<<2)>>2]==64.0){U=p*+R(+(+g[h+(va+E<<2)>>2]));K=~~(+S(U*+S(U))+.4054);if((K|0)<0){ya=0}else{ya=(K|0)>8191?8191:K}K=ya>>>0>65535>>>0;F=K?ya>>>16:ya;ga=K?16:0;if((F&65280|0)==0){za=ga;Aa=F}else{za=ga|8;Aa=F>>>8}F=(d[1359664+Aa|0]|0)+za|0;ga=F-3|0;K=(1<<ga)-2|0;if((xa|0)>(ga|0)){Ba=xa-ga|0;Ca=K|wa<<ga}else{I=je(K>>>((ga-xa|0)>>>0)|wa<<xa|0)|0;ga=c[B>>2]|0;y=I;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;Ba=xa+35-F|0;Ca=K}c[k>>2]=Ca;c[l>>2]=Ba;K=(1<<F)-1&ya;if((Ba|0)>(F|0)){Da=Ba-F|0;Ea=Ca<<F|K}else{ga=je(K>>>((F-Ba|0)>>>0)|Ca<<Ba|0)|0;I=c[B>>2]|0;y=ga;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;Da=32-F+Ba|0;Ea=K}c[k>>2]=Ea;c[l>>2]=Da;Fa=Ea;Ga=Da}else{Fa=wa;Ga=xa}K=va+1|0;if((K|0)<2){va=K;wa=Fa;xa=Ga}else{break}}}J=E+2|0;if((J|0)<(j|0)){D=Z;w=M;E=J}else{u=Z;v=M;break a}}return+ka}}while(0);if((o|0)==0){ka=v;return+ka}c[o>>2]=u;ka=v;return+ka}function iub(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0;j=i;i=i+24|0;k=j|0;l=f+8|0;m=c[l>>2]|0;n=k;o=f;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];c[n+8>>2]=c[o+8>>2];c[n+12>>2]=c[o+12>>2];c[n+16>>2]=c[o+16>>2];o=k+8|0;n=c[o>>2]|0;p=k|0;q=c[p>>2]|0;r=d[q+(n>>>3)|0]|0;s=k+16|0;t=c[s>>2]|0;u=((n|0)<(t|0))+n|0;c[o>>2]=u;v=(r&128>>>((n&7)>>>0)|0)!=0;a:do{if(v){n=d[q+(u>>>3)|0]<<(u&7)>>>7;r=((u|0)<(t|0))+u|0;c[o>>2]=r;w=n&1;c[g+4>>2]=w;do{if((w|0)==0){x=r}else{n=q+(r>>>3)|0;y=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(r&7);n=y>>>29;z=r+3|0;A=t>>>0>z>>>0?z:t;c[o>>2]=A;if(y>>>0>3221225471>>>0){KIb(e,16,2423520,(B=i,i=i+8|0,c[B>>2]=n,B)|0);i=B;break a}else{c[g+12>>2]=a[778272+n|0]|0;c[g+8>>2]=y>>>0>1610612735>>>0;c[g+16>>2]=a[778264+n|0]|0;x=A;break}}}while(0);r=d[q+(x>>>3)|0]<<(x&7)>>>7;w=((x|0)<(t|0))+x|0;c[o>>2]=w;A=r&1;c[g+20>>2]=A;do{if((A|0)==0){C=w}else{r=q+(w>>>3)|0;n=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(w&7);r=n>>>29;y=w+3|0;z=t>>>0>y>>>0?y:t;c[o>>2]=z;c[g+24>>2]=r;if(n>>>0>3221225471>>>0){KIb(e,16,2580736,(B=i,i=i+8|0,c[B>>2]=r,B)|0);i=B;break a}else{c[g+28>>2]=a[778272+r|0]|0;C=z;break}}}while(0);w=d[q+(C>>>3)|0]<<(C&7)>>>7;A=((C|0)<(t|0))+C|0;c[o>>2]=A;c[g+32>>2]=w&1;D=A;E=11}else{D=u;E=11}}while(0);b:do{if((E|0)==11){u=((D|0)<(t|0))+D|0;C=d[q+(D>>>3)|0]<<(D&7)>>>7&1;c[g+36>>2]=C;x=g+44|0;A=g+40|0;c[A>>2]=c[x>>2];w=q+(u>>>3)|0;z=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>30;w=u+2|0;u=t>>>0>w>>>0?w:t;c[o>>2]=u;w=a[777656+(C<<2)+z|0]|0;z=w<<24>>24;c[x>>2]=z;c[g+52>>2]=-1;r=w<<24>>24<1;do{if((C|0)==0){if(r){F=z;G=u;break}else{H=1;I=z}while(1){c[g+52+(H<<2)>>2]=(H<<5>>d[1359664+I|0])-1;w=H+1|0;n=c[x>>2]|0;if((w|0)>(n|0)){F=n;G=u;break}else{H=w;I=n}}}else{if(r){F=z;G=u;break}else{J=1;K=u}do{n=q+(K>>>3)|0;w=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(K&7)>>>27;n=K+5|0;K=t>>>0>n>>>0?n:t;c[g+52+(J<<2)>>2]=w;J=J+1|0;L=c[x>>2]|0;}while((J|0)<=(L|0));c[o>>2]=K;F=L;G=K}}while(0);u=g+4|0;do{if((c[u>>2]|0)==0){mrc(g+76|0,0,170)|0;M=F;N=G}else{if((F|0)<=0){M=F;N=G;break}z=g+8|0;r=g+12|0;C=0;w=G;n=c[z>>2]|0;c:while(1){y=((w|0)<(t|0))+w|0;O=d[q+(w>>>3)|0]<<(w&7)>>>7&1;P=c[1080728+((O<<1)+n<<2)>>2]|0;Q=c[r>>2]|0;R=c[3387724+(P*20|0)>>2]|0;d:do{if((O|0)==0){S=1079872+P|0;T=0;U=0;V=y;W=n;while(1){if((U|0)>=(Q|0)){X=V;Y=W;break d}Z=q+(V>>>3)|0;_=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(V&7)>>>23;Z=b[R+(_<<2)>>1]|0;$=b[R+(_<<2)+2>>1]|0;_=$<<16>>16;do{if($<<16>>16<0){aa=V+9|0;ba=t>>>0>aa>>>0?aa:t;aa=q+(ba>>>3)|0;ca=((je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ba&7)>>>((_+32|0)>>>0))+Z|0;aa=b[R+(ca<<2)>>1]|0;da=b[R+(ca<<2)+2>>1]|0;ca=da<<16>>16;if(!(da<<16>>16<0)){ea=ca;fa=aa;ga=ba;break}da=ba-_|0;ba=t>>>0>da>>>0?da:t;da=q+(ba>>>3)|0;ha=((je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ba&7)>>>((ca+32|0)>>>0))+aa|0;ea=b[R+(ha<<2)+2>>1]|0;fa=b[R+(ha<<2)>>1]|0;ga=ba}else{ea=_;fa=Z;ga=V}}while(0);Z=ea+ga|0;_=t>>>0>Z>>>0?Z:t;Z=fa-(a[S]|0)+T|0;$=Z&255;a[g+76+(C*34|0)+U|0]=$;ba=$<<24>>24;ha=c[z>>2]|0;if((($<<24>>24>-1?ba:-ba|0)|0)>(ha<<3|7|0)){ia=_;E=35;break c}else{T=Z;U=U+1|0;V=_;W=ha}}}else{if((C|0)==0){ja=c[A>>2]|0}else{ja=C}W=ja-1|0;V=(W|0)>0?W:0;W=1079872+P|0;U=0;T=y;S=n;while(1){if((U|0)>=(Q|0)){X=T;Y=S;break d}ha=d[g+76+(V*34|0)+U|0]|0;_=q+(T>>>3)|0;Z=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(T&7)>>>23;_=b[R+(Z<<2)>>1]|0;ba=b[R+(Z<<2)+2>>1]|0;Z=ba<<16>>16;do{if(ba<<16>>16<0){$=T+9|0;aa=t>>>0>$>>>0?$:t;$=q+(aa>>>3)|0;ca=((je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(aa&7)>>>((Z+32|0)>>>0))+_|0;$=b[R+(ca<<2)>>1]|0;da=b[R+(ca<<2)+2>>1]|0;ca=da<<16>>16;if(!(da<<16>>16<0)){ka=ca;la=$;ma=aa;break}da=aa-Z|0;aa=t>>>0>da>>>0?da:t;da=q+(aa>>>3)|0;na=((je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(aa&7)>>>((ca+32|0)>>>0))+$|0;ka=b[R+(na<<2)+2>>1]|0;la=b[R+(na<<2)>>1]|0;ma=aa}else{ka=Z;la=_;ma=T}}while(0);_=ka+ma|0;Z=t>>>0>_>>>0?_:t;_=la+ha-(d[W]|0)&255;a[g+76+(C*34|0)+U|0]=_;ba=_<<24>>24;aa=c[z>>2]|0;if(((_<<24>>24>-1?ba:-ba|0)|0)>(aa<<3|7|0)){ia=Z;E=35;break c}else{U=U+1|0;T=Z;S=aa}}}}while(0);R=C+1|0;oa=c[x>>2]|0;if((R|0)<(oa|0)){C=R;w=X;n=Y}else{E=38;break}}if((E|0)==35){c[o>>2]=ia;KIb(e,16,2499560,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}else if((E|0)==38){c[o>>2]=X;M=oa;N=X;break}}}while(0);n=g+20|0;do{if((c[n>>2]|0)==0){mrc(g+246|0,0,170)|0;pa=M;qa=N}else{if((M|0)<=0){pa=M;qa=N;break}w=g+28|0;C=0;z=N;e:while(1){r=((z|0)<(t|0))+z|0;R=d[q+(z>>>3)|0]<<(z&7)>>>7&1;Q=R|4;y=c[w>>2]|0;P=c[3387724+(Q*20|0)>>2]|0;f:do{if((R|0)==0){O=1079872+Q|0;S=0;T=0;U=r;while(1){if((T|0)>=(y|0)){ra=U;break f}W=q+(U>>>3)|0;V=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(U&7)>>>23;W=b[P+(V<<2)>>1]|0;aa=b[P+(V<<2)+2>>1]|0;V=aa<<16>>16;do{if(aa<<16>>16<0){Z=U+9|0;ba=t>>>0>Z>>>0?Z:t;Z=q+(ba>>>3)|0;_=((je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(ba&7)>>>((V+32|0)>>>0))+W|0;Z=b[P+(_<<2)>>1]|0;na=b[P+(_<<2)+2>>1]|0;_=na<<16>>16;if(!(na<<16>>16<0)){sa=_;ta=Z;ua=ba;break}na=ba-V|0;ba=t>>>0>na>>>0?na:t;na=q+(ba>>>3)|0;$=((je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ba&7)>>>((_+32|0)>>>0))+Z|0;sa=b[P+($<<2)+2>>1]|0;ta=b[P+($<<2)>>1]|0;ua=ba}else{sa=V;ta=W;ua=U}}while(0);W=sa+ua|0;V=t>>>0>W>>>0?W:t;W=ta-(a[O]|0)+S|0;aa=W&255;a[g+246+(C*34|0)+T|0]=aa;if((aa&255)>>>0>7>>>0){va=V;E=57;break e}else{S=W;T=T+1|0;U=V}}}else{if((C|0)==0){wa=c[A>>2]|0}else{wa=C}U=wa-1|0;T=(U|0)>0?U:0;U=1079872+Q|0;S=0;O=r;while(1){if((S|0)>=(y|0)){ra=O;break f}V=d[g+246+(T*34|0)+S|0]|0;W=q+(O>>>3)|0;aa=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(O&7)>>>23;W=b[P+(aa<<2)>>1]|0;ha=b[P+(aa<<2)+2>>1]|0;aa=ha<<16>>16;do{if(ha<<16>>16<0){ba=O+9|0;$=t>>>0>ba>>>0?ba:t;ba=q+($>>>3)|0;Z=((je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<($&7)>>>((aa+32|0)>>>0))+W|0;ba=b[P+(Z<<2)>>1]|0;_=b[P+(Z<<2)+2>>1]|0;Z=_<<16>>16;if(!(_<<16>>16<0)){xa=Z;ya=ba;za=$;break}_=$-aa|0;$=t>>>0>_>>>0?_:t;_=q+($>>>3)|0;na=((je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<($&7)>>>((Z+32|0)>>>0))+ba|0;xa=b[P+(na<<2)+2>>1]|0;ya=b[P+(na<<2)>>1]|0;za=$}else{xa=aa;ya=W;za=O}}while(0);W=xa+za|0;aa=t>>>0>W>>>0?W:t;W=ya+V-(d[U]|0)&255;a[g+246+(C*34|0)+S|0]=W;if((W&255)>>>0>7>>>0){va=aa;E=57;break e}else{S=S+1|0;O=aa}}}}while(0);P=C+1|0;Aa=c[x>>2]|0;if((P|0)<(Aa|0)){C=P;z=ra}else{E=60;break}}if((E|0)==57){c[o>>2]=va;KIb(e,16,2513160,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}else if((E|0)==60){c[o>>2]=ra;pa=Aa;qa=ra;break}}}while(0);do{if((c[g+32>>2]|0)==0){Ba=pa;Ca=qa}else{z=q+(qa>>>3)|0;C=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(qa&7)>>>28;z=qa+4|0;w=t>>>0>z>>>0?z:t;c[o>>2]=w;if((C|0)==15){z=q+(w>>>3)|0;P=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7)>>>24;z=w+8|0;y=t>>>0>z>>>0?z:t;c[o>>2]=y;Da=P+15|0;Ea=y}else{Da=C;Ea=w}w=Da<<3;g:do{if((w|0)>7){C=g+48|0;y=g+416|0;P=g+586|0;z=w;r=pa;Q=Ea;R=t;O=q;while(1){S=O+(Q>>>3)|0;U=je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0;S=Q+2|0;T=R>>>0>S>>>0?S:R;c[o>>2]=T;if((U&-1073741824>>>((Q&7)>>>0)|0)==0){U=d[O+(T>>>3)|0]<<(T&7)>>>7;S=((T|0)<(R|0))+T|0;c[o>>2]=S;aa=U&1;c[C>>2]=aa;if((aa|0)!=0&(r|0)>0){aa=0;U=O;W=S;ha=R;while(1){$=d[U+(W>>>3)|0]<<(W&7)>>>7;c[o>>2]=((W|0)<(ha|0))+W;na=$&1;qub(k,g,y,na|6,aa,na);na=c[o>>2]|0;$=d[(c[p>>2]|0)+(na>>>3)|0]<<(na&7)>>>7;c[o>>2]=((na|0)<(c[s>>2]|0))+na;na=$&1;qub(k,g,P,na|8,aa,na);na=aa+1|0;Fa=c[x>>2]|0;if((na|0)>=(Fa|0)){break}aa=na;U=c[p>>2]|0;W=c[o>>2]|0;ha=c[s>>2]|0}Ga=Fa;Ha=c[o>>2]|0;Ia=c[s>>2]|0}else{Ga=r;Ha=S;Ia=R}ha=Ha+1|0;W=Ia>>>0>ha>>>0?ha:Ia;c[o>>2]=W;Ja=2-T+W|0;Ka=Ga;La=W;Ma=Ia}else{Ja=2;Ka=r;La=T;Ma=R}W=z-Ja|0;if((W|0)<=7){Na=W;Oa=Ka;Pa=La;Qa=Ma;break g}z=W;r=Ka;Q=La;R=Ma;O=c[p>>2]|0}}else{Na=w;Oa=pa;Pa=Ea;Qa=t}}while(0);if((Na|0)<0){KIb(e,16,2437032,(B=i,i=i+8|0,c[B>>2]=Na,B)|0);i=B;break b}else{w=Pa+Na|0;O=Qa>>>0>w>>>0?w:Qa;c[o>>2]=O;Ba=Oa;Ca=O;break}}}while(0);O=g+48|0;c[O>>2]=c[O>>2]&1;if((Ba|0)==0){Ra=c[A>>2]|0;Sa=0;E=80}else{if((c[g+52+(Ba<<2)>>2]|0)<31){Ra=Ba;Sa=Ba;E=80}}if((E|0)==80){w=Ra-1|0;do{if(!((Ra|0)<1|(w|0)==(Sa|0))){if((c[u>>2]|0)!=0){nrc(g+76+(Sa*34|0)|0,g+76+(w*34|0)|0,34)|0}if((c[n>>2]|0)!=0){nrc(g+246+((c[x>>2]|0)*34|0)|0,g+246+(w*34|0)|0,34)|0}if((c[O>>2]|0)==0){break}nrc(g+416+((c[x>>2]|0)*34|0)|0,g+416+(w*34|0)|0,34)|0;nrc(g+586+((c[x>>2]|0)*34|0)|0,g+586+(w*34|0)|0,34)|0}}while(0);h:do{if((c[u>>2]|0)!=0){w=c[g+12>>2]|0;A=g+8|0;R=0;while(1){if((R|0)>=(w|0)){break h}Q=a[g+76+((c[x>>2]|0)*34|0)+R|0]|0;r=Q<<24>>24;if(((Q<<24>>24>-1?r:-r|0)|0)>(c[A>>2]<<3|7|0)){break}else{R=R+1|0}}KIb(e,16,2350224,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}}while(0);i:do{if((c[n>>2]|0)!=0){R=c[g+12>>2]|0;A=0;while(1){if((A|0)>=(R|0)){break i}if((d[g+246+((c[x>>2]|0)*34|0)+A|0]|0)>>>0>7>>>0){break}else{A=A+1|0}}KIb(e,16,2288480,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;break b}}while(0);A=(c[x>>2]|0)+1|0;c[x>>2]=A;c[g+52+(A<<2)>>2]=31}A=g+756|0;c[g+760>>2]=c[A>>2];do{if((c[u>>2]|0)==0){if((c[n>>2]|0)!=0){E=102}}else{if((c[g+12>>2]|0)==34){Ta=1;E=103;break}if((c[n>>2]|0)==0){Ta=0;E=103}else{E=102}}}while(0);if((E|0)==102){Ta=(c[g+28>>2]|0)==34|0;E=103}if((E|0)==103){c[A>>2]=Ta}if((c[O>>2]|0)==0){mrc(g+416|0,0,340)|0}if(v){c[g>>2]=1}n=Ca-m|0;if((n|0)>(h|0)){KIb(e,16,2238456,(B=i,i=i+16|0,c[B>>2]=h,c[B+8>>2]=n,B)|0);i=B;break}u=c[l>>2]|0;x=-u|0;R=(c[f+16>>2]|0)-u|0;if((n|0)<(x|0)){Ua=x}else{Ua=(R|0)<(n|0)?R:n}c[l>>2]=Ua+u;Va=n;i=j;return Va|0}}while(0);c[g>>2]=0;Ua=c[l>>2]|0;B=-Ua|0;e=(c[f+16>>2]|0)-Ua|0;if((h|0)<(B|0)){Wa=B}else{Wa=(e|0)<(h|0)?e:h}c[l>>2]=Wa+Ua;mrc(g+76|0,0,680)|0;Va=h;i=j;return Va|0}function jub(b,d,e,f,h){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0.0,ba=0.0,ca=0.0,da=0.0,ea=0.0,fa=0,ga=0,ha=0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0,na=0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0.0,ta=0.0,ua=0,va=0;b=i;i=i+56160|0;j=b|0;k=b+176|0;l=b+352|0;m=b+528|0;n=b+704|0;o=b+712|0;p=b+720|0;q=b+728|0;r=b+736|0;s=b+768|0;t=b+800|0;u=b+5152|0;v=b+9504|0;w=b+9568|0;x=b+32864|0;y=w|0;z=x|0;A=c[d+756>>2]|0;B=2656848+(A<<2)|0;C=c[B>>2]|0;D=h-64+C|0;mrc(d+2528+(D*368|0)|0,0,(64-h|0)*368|0|0)|0;h=c[2656856+(A<<2)>>2]|0;if((D|0)<(h|0)){mrc(d+36016+(D*888|0)|0,0,(h-D|0)*888|0|0)|0}D=d+87444|0;E=0;do{F=E+6|0;g[d+768+(F<<3)>>2]=+g[e+(E<<8)>>2];g[d+768+(F<<3)+4>>2]=+g[e+9728+(E<<8)>>2];E=E+1|0;}while((E|0)<38);E=d+768|0;F=0;while(1){G=F+6|0;g[d+1120+(G<<3)>>2]=+g[e+(F<<8)+4>>2];g[d+1120+(G<<3)+4>>2]=+g[e+9728+(F<<8)+4>>2];G=F+1|0;if((G|0)<38){F=G}else{H=0;break}}while(1){F=H+6|0;g[d+1472+(F<<3)>>2]=+g[e+(H<<8)+8>>2];g[d+1472+(F<<3)+4>>2]=+g[e+9728+(H<<8)+8>>2];F=H+1|0;if((F|0)<38){H=F}else{I=0;break}}while(1){H=I+6|0;g[d+1824+(H<<3)>>2]=+g[e+(I<<8)+12>>2];g[d+1824+(H<<3)+4>>2]=+g[e+9728+(I<<8)+12>>2];H=I+1|0;if((H|0)<38){I=H}else{J=0;break}}do{I=J+6|0;g[d+2176+(I<<3)>>2]=+g[e+(J<<8)+16>>2];g[d+2176+(I<<3)+4>>2]=+g[e+9728+(J<<8)+16>>2];J=J+1|0;}while((J|0)<38);J=E|0;if((A|0)==0){I=v|0;H=d+87452|0;F=v+48|0;G=v+52|0;K=v+56|0;L=v+60|0;M=v|0;N=v+4|0;O=v+8|0;P=v+12|0;Q=v+16|0;R=v+40|0;S=v+20|0;T=v+44|0;U=v+24|0;V=v+32|0;W=v+28|0;X=v+36|0;v=0;Y=J;while(1){pe[c[H>>2]&1023](I,Y,8839280,1,8);g[w+(v<<3)>>2]=+g[F>>2];g[w+(v<<3)+4>>2]=+g[G>>2];g[w+256+(v<<3)>>2]=+g[K>>2];g[w+256+(v<<3)+4>>2]=+g[L>>2];g[w+512+(v<<3)>>2]=+g[M>>2];g[w+512+(v<<3)+4>>2]=+g[N>>2];g[w+768+(v<<3)>>2]=+g[O>>2];g[w+768+(v<<3)+4>>2]=+g[P>>2];g[w+1024+(v<<3)>>2]=+g[Q>>2]+ +g[R>>2];g[w+1024+(v<<3)+4>>2]=+g[S>>2]+ +g[T>>2];g[w+1280+(v<<3)>>2]=+g[U>>2]+ +g[V>>2];g[w+1280+(v<<3)+4>>2]=+g[W>>2]+ +g[X>>2];Z=v+1|0;if((Z|0)<32){v=Z;Y=Y+8|0}else{break}}Y=0;v=d+1120|0;while(1){_=(+g[v+8>>2]+ +g[v+88>>2])*.018994875252246857+0.0+(+g[v+24>>2]+ +g[v+72>>2])*-.07293139398097992+(+g[v+40>>2]+ +g[v+56>>2])*.305966317653656;$=(+g[v+12>>2]+ +g[v+92>>2])*.018994875252246857+0.0+(+g[v+28>>2]+ +g[v+76>>2])*-.07293139398097992+(+g[v+44>>2]+ +g[v+60>>2])*.305966317653656;aa=+g[v+48>>2]*.5;ba=+g[v+52>>2]*.5;g[w+1792+(Y<<3)>>2]=aa+_;g[w+1792+(Y<<3)+4>>2]=ba+$;g[w+1536+(Y<<3)>>2]=aa-_;g[w+1536+(Y<<3)+4>>2]=ba-$;X=Y+1|0;if((X|0)<32){Y=X;v=v+8|0}else{break}}v=0;Y=d+1472|0;while(1){$=(+g[Y+8>>2]+ +g[Y+88>>2])*.018994875252246857+0.0+(+g[Y+24>>2]+ +g[Y+72>>2])*-.07293139398097992+(+g[Y+40>>2]+ +g[Y+56>>2])*.305966317653656;ba=(+g[Y+12>>2]+ +g[Y+92>>2])*.018994875252246857+0.0+(+g[Y+28>>2]+ +g[Y+76>>2])*-.07293139398097992+(+g[Y+44>>2]+ +g[Y+60>>2])*.305966317653656;_=+g[Y+48>>2]*.5;aa=+g[Y+52>>2]*.5;g[w+2048+(v<<3)>>2]=_+$;g[w+2048+(v<<3)+4>>2]=aa+ba;g[w+2304+(v<<3)>>2]=_-$;g[w+2304+(v<<3)+4>>2]=aa-ba;X=v+1|0;if((X|0)<32){v=X;Y=Y+8|0}else{break}}mf[c[d+87456>>2]&2047](w+1792|0,e,3,32)}else{Y=d+87452|0;v=J;J=0;while(1){pe[c[Y>>2]&1023](w+(J<<3)|0,v,8838512,32,12);X=J+1|0;if((X|0)<32){v=v+8|0;J=X}else{break}}J=d+1120|0;v=0;while(1){pe[c[Y>>2]&1023](w+3072+(v<<3)|0,J,8838e3,32,8);X=v+1|0;if((X|0)<32){J=J+8|0;v=X}else{break}}v=d+1472|0;J=0;while(1){pe[c[Y>>2]&1023](w+5120+(J<<3)|0,v,8837744,32,4);X=J+1|0;if((X|0)<32){v=v+8|0;J=X}else{break}}J=d+1824|0;v=0;while(1){pe[c[Y>>2]&1023](w+6144+(v<<3)|0,J,8837744,32,4);X=v+1|0;if((X|0)<32){J=J+8|0;v=X}else{break}}v=d+2176|0;J=0;while(1){pe[c[Y>>2]&1023](w+7168+(J<<3)|0,v,8837744,32,4);X=J+1|0;if((X|0)<32){v=v+8|0;J=X}else{break}}mf[c[d+87456>>2]&2047](w+6912|0,e,5,32)}nrc(E|0,d+1024|0,48)|0;nrc(d+1120|0,d+1376|0,48)|0;nrc(d+1472|0,d+1728|0,48)|0;nrc(d+1824|0,d+2080|0,48)|0;nrc(d+2176|0,d+2432|0,48)|0;E=(A|0)!=0;J=E?1036656:1036752;mrc(t|0,0,4352)|0;v=d+760|0;if((c[v>>2]|0)!=(A|0)){mrc(d+80560|0,0,136)|0;mrc(d+80704|0,0,136)|0;mrc(d+2528|0,0,78024)|0}Y=A>>>0<2>>>0;if(Y){X=d+87444|0;W=0;do{ef[c[X>>2]&4095](t+(a[J+W|0]<<7)|0,w+(W<<8)|0,32);W=W+1|0;}while((W|0)<(C|0));W=c[2656832+(A<<2)>>2]|0;X=0;do{V=d+80416+(X<<2)|0;U=d+80560+(X<<2)|0;T=d+80704+(X<<2)|0;S=0;ba=+g[V>>2];aa=+g[U>>2];$=+g[T>>2];do{_=ba*.765928328037262;ca=+g[t+(X<<7)+(S<<2)>>2];ba=_>ca?_:ca;aa=aa+(ca-aa)*.25;$=$+(ba-ca-$)*.25;ca=$*1.5;if(ca>aa){da=aa/ca}else{da=1.0}g[u+(X<<7)+(S<<2)>>2]=da;S=S+1|0;}while((S|0)<32);g[V>>2]=ba;g[U>>2]=aa;g[T>>2]=$;X=X+1|0;}while((X|0)<(W|0));W=c[2659552+(A<<2)>>2]|0;X=d+87464|0;t=0;do{S=a[J+t|0]|0;da=1.0- +(t-W|0)*.05000000074505806;if(da<0.0){ea=0.0}else{ea=da>1.0?1.0:da}nrc(d+2528+(t*368|0)|0,d+2528+(t*368|0)+256|0,112)|0;nrc(d+2528+(t*368|0)+112|0,w+(t<<8)|0,256)|0;R=d+36016+(t*888|0)|0;nrc(R|0,d+36016+(t*888|0)+256|0,40)|0;nrc(d+36016+(t*888|0)+296|0,d+36016+(t*888|0)+552|0,40)|0;nrc(d+36016+(t*888|0)+592|0,d+36016+(t*888|0)+848|0,40)|0;ne[c[X>>2]&3](x+(t<<8)|0,d+2528+(t*368|0)+96|0,R,5462520+(A*400|0)+(t<<3)|0,10231248+(A*1200|0)+(t*24|0)|0,u+(S<<7)|0,ea,32);t=t+1|0;}while((t|0)<(h|0));fa=(h|0)>1?h:1}else{fa=0}h=c[2655976+(A<<2)>>2]|0;if((fa|0)<(h|0)){t=d+87448|0;X=fa+1|0;W=fa;do{S=a[J+W|0]|0;nrc(d+2528+(W*368|0)|0,d+2528+(W*368|0)+256|0,112)|0;nrc(d+2528+(W*368|0)+112|0,w+(W<<8)|0,256)|0;mf[c[t>>2]&2047](x+(W<<8)|0,d+2528+(W*368|0)|0,u+(S<<7)|0,32);W=W+1|0;}while((W|0)<(h|0));ga=(h|0)>(X|0)?h:X}else{ga=fa}if((ga|0)<(C|0)){fa=d+87448|0;X=ga;do{ga=a[J+X|0]|0;nrc(d+2528+(X*368|0)|0,d+2528+(X*368|0)+256|0,112)|0;nrc(d+2528+(X*368|0)+112|0,w+(X<<8)|0,256)|0;mf[c[fa>>2]&2047](x+(X<<8)|0,d+2528+(X*368|0)+104|0,u+(ga<<7)|0,32);X=X+1|0;}while((X|0)<(C|0))}C=d+80848|0;X=d+82480|0;u=d+84112|0;fa=d+85744|0;ga=d+87376|0;h=d+87410|0;c[n>>2]=j;c[o>>2]=k;c[p>>2]=l;c[q>>2]=m;m=(c[d+24>>2]|0)<3?10239536:10233648;l=c[d+40>>2]|0;if((l|0)!=0){nrc(C|0,d+80848+(l*136|0)|0,136)|0;nrc(d+81664|0,d+81664+(l*136|0)|0,136)|0;nrc(X|0,d+82480+(l*136|0)|0,136)|0;nrc(d+83296|0,d+83296+(l*136|0)|0,136)|0;nrc(u|0,d+84112+(l*136|0)|0,136)|0;nrc(d+84928|0,d+84928+(l*136|0)|0,136)|0;nrc(fa|0,d+85744+(l*136|0)|0,136)|0;nrc(d+86560|0,d+86560+(l*136|0)|0,136)|0}l=d+76|0;k=c[d+12>>2]|0;j=d+44|0;W=c[j>>2]|0;do{if(E){nub(n,l,k,W,1);nub(o,d+246|0,c[d+28>>2]|0,c[j>>2]|0,1);if((c[d+48>>2]|0)!=0){t=d+16|0;nub(p,d+416|0,c[t>>2]|0,c[j>>2]|0,0);nub(q,d+586|0,c[t>>2]|0,c[j>>2]|0,0)}if((c[v>>2]|0)!=0){break}t=d+80924|0;ea=+g[t>>2];g[d+80980>>2]=ea;g[d+80976>>2]=ea;S=d+80920|0;ea=+g[S>>2];g[d+80972>>2]=ea;g[d+80968>>2]=ea;g[d+80964>>2]=ea;g[d+80960>>2]=ea;R=d+80916|0;ea=+g[R>>2];g[d+80956>>2]=ea;g[d+80952>>2]=ea;Q=d+80912|0;ea=+g[Q>>2];g[d+80948>>2]=ea;g[d+80944>>2]=ea;P=d+80908|0;ea=+g[P>>2];g[d+80940>>2]=ea;g[d+80936>>2]=ea;O=d+80904|0;ea=+g[O>>2];g[d+80932>>2]=ea;g[d+80928>>2]=ea;N=d+80900|0;g[t>>2]=+g[N>>2];t=d+80896|0;g[S>>2]=+g[t>>2];S=d+80892|0;g[R>>2]=+g[S>>2];R=d+80888|0;g[Q>>2]=+g[R>>2];Q=d+80884|0;ea=+g[Q>>2];g[P>>2]=ea;g[O>>2]=ea;O=d+80880|0;ea=+g[O>>2];g[N>>2]=ea;g[t>>2]=ea;t=d+80876|0;g[S>>2]=+g[t>>2];S=d+80872|0;g[R>>2]=+g[S>>2];R=d+80868|0;ea=+g[R>>2];g[Q>>2]=ea;g[O>>2]=ea;O=d+80864|0;ea=+g[O>>2];g[t>>2]=ea;g[S>>2]=ea;S=d+80860|0;ea=+g[S>>2];g[R>>2]=ea;R=d+80856|0;da=+g[R>>2];g[O>>2]=(ea+da)*.5;g[S>>2]=da;S=d+80852|0;da=+g[S>>2];g[R>>2]=da;g[S>>2]=(da+ +g[C>>2])*.5;S=d+81740|0;da=+g[S>>2];g[d+81796>>2]=da;g[d+81792>>2]=da;R=d+81736|0;da=+g[R>>2];g[d+81788>>2]=da;g[d+81784>>2]=da;g[d+81780>>2]=da;g[d+81776>>2]=da;O=d+81732|0;da=+g[O>>2];g[d+81772>>2]=da;g[d+81768>>2]=da;t=d+81728|0;da=+g[t>>2];g[d+81764>>2]=da;g[d+81760>>2]=da;Q=d+81724|0;da=+g[Q>>2];g[d+81756>>2]=da;g[d+81752>>2]=da;N=d+81720|0;da=+g[N>>2];g[d+81748>>2]=da;g[d+81744>>2]=da;P=d+81716|0;g[S>>2]=+g[P>>2];S=d+81712|0;g[R>>2]=+g[S>>2];R=d+81708|0;g[O>>2]=+g[R>>2];O=d+81704|0;g[t>>2]=+g[O>>2];t=d+81700|0;da=+g[t>>2];g[Q>>2]=da;g[N>>2]=da;N=d+81696|0;da=+g[N>>2];g[P>>2]=da;g[S>>2]=da;S=d+81692|0;g[R>>2]=+g[S>>2];R=d+81688|0;g[O>>2]=+g[R>>2];O=d+81684|0;da=+g[O>>2];g[t>>2]=da;g[N>>2]=da;N=d+81680|0;da=+g[N>>2];g[S>>2]=da;g[R>>2]=da;R=d+81676|0;da=+g[R>>2];g[O>>2]=da;O=d+81672|0;ea=+g[O>>2];g[N>>2]=(da+ea)*.5;g[R>>2]=ea;R=d+81668|0;ea=+g[R>>2];g[O>>2]=ea;g[R>>2]=(ea+ +g[d+81664>>2])*.5;R=d+82556|0;ea=+g[R>>2];g[d+82612>>2]=ea;g[d+82608>>2]=ea;O=d+82552|0;ea=+g[O>>2];g[d+82604>>2]=ea;g[d+82600>>2]=ea;g[d+82596>>2]=ea;g[d+82592>>2]=ea;N=d+82548|0;ea=+g[N>>2];g[d+82588>>2]=ea;g[d+82584>>2]=ea;S=d+82544|0;ea=+g[S>>2];g[d+82580>>2]=ea;g[d+82576>>2]=ea;t=d+82540|0;ea=+g[t>>2];g[d+82572>>2]=ea;g[d+82568>>2]=ea;P=d+82536|0;ea=+g[P>>2];g[d+82564>>2]=ea;g[d+82560>>2]=ea;Q=d+82532|0;g[R>>2]=+g[Q>>2];R=d+82528|0;g[O>>2]=+g[R>>2];O=d+82524|0;g[N>>2]=+g[O>>2];N=d+82520|0;g[S>>2]=+g[N>>2];S=d+82516|0;ea=+g[S>>2];g[t>>2]=ea;g[P>>2]=ea;P=d+82512|0;ea=+g[P>>2];g[Q>>2]=ea;g[R>>2]=ea;R=d+82508|0;g[O>>2]=+g[R>>2];O=d+82504|0;g[N>>2]=+g[O>>2];N=d+82500|0;ea=+g[N>>2];g[S>>2]=ea;g[P>>2]=ea;P=d+82496|0;ea=+g[P>>2];g[R>>2]=ea;g[O>>2]=ea;O=d+82492|0;ea=+g[O>>2];g[N>>2]=ea;N=d+82488|0;da=+g[N>>2];g[P>>2]=(ea+da)*.5;g[O>>2]=da;O=d+82484|0;da=+g[O>>2];g[N>>2]=da;g[O>>2]=(da+ +g[X>>2])*.5;O=d+83372|0;da=+g[O>>2];g[d+83428>>2]=da;g[d+83424>>2]=da;N=d+83368|0;da=+g[N>>2];g[d+83420>>2]=da;g[d+83416>>2]=da;g[d+83412>>2]=da;g[d+83408>>2]=da;P=d+83364|0;da=+g[P>>2];g[d+83404>>2]=da;g[d+83400>>2]=da;R=d+83360|0;da=+g[R>>2];g[d+83396>>2]=da;g[d+83392>>2]=da;S=d+83356|0;da=+g[S>>2];g[d+83388>>2]=da;g[d+83384>>2]=da;Q=d+83352|0;da=+g[Q>>2];g[d+83380>>2]=da;g[d+83376>>2]=da;t=d+83348|0;g[O>>2]=+g[t>>2];O=d+83344|0;g[N>>2]=+g[O>>2];N=d+83340|0;g[P>>2]=+g[N>>2];P=d+83336|0;g[R>>2]=+g[P>>2];R=d+83332|0;da=+g[R>>2];g[S>>2]=da;g[Q>>2]=da;Q=d+83328|0;da=+g[Q>>2];g[t>>2]=da;g[O>>2]=da;O=d+83324|0;g[N>>2]=+g[O>>2];N=d+83320|0;g[P>>2]=+g[N>>2];P=d+83316|0;da=+g[P>>2];g[R>>2]=da;g[Q>>2]=da;Q=d+83312|0;da=+g[Q>>2];g[O>>2]=da;g[N>>2]=da;N=d+83308|0;da=+g[N>>2];g[P>>2]=da;P=d+83304|0;ea=+g[P>>2];g[Q>>2]=(da+ea)*.5;g[N>>2]=ea;N=d+83300|0;ea=+g[N>>2];g[P>>2]=ea;g[N>>2]=(ea+ +g[d+83296>>2])*.5;N=d+84188|0;ea=+g[N>>2];g[d+84244>>2]=ea;g[d+84240>>2]=ea;P=d+84184|0;ea=+g[P>>2];g[d+84236>>2]=ea;g[d+84232>>2]=ea;g[d+84228>>2]=ea;g[d+84224>>2]=ea;Q=d+84180|0;ea=+g[Q>>2];g[d+84220>>2]=ea;g[d+84216>>2]=ea;O=d+84176|0;ea=+g[O>>2];g[d+84212>>2]=ea;g[d+84208>>2]=ea;R=d+84172|0;ea=+g[R>>2];g[d+84204>>2]=ea;g[d+84200>>2]=ea;t=d+84168|0;ea=+g[t>>2];g[d+84196>>2]=ea;g[d+84192>>2]=ea;S=d+84164|0;g[N>>2]=+g[S>>2];N=d+84160|0;g[P>>2]=+g[N>>2];P=d+84156|0;g[Q>>2]=+g[P>>2];Q=d+84152|0;g[O>>2]=+g[Q>>2];O=d+84148|0;ea=+g[O>>2];g[R>>2]=ea;g[t>>2]=ea;t=d+84144|0;ea=+g[t>>2];g[S>>2]=ea;g[N>>2]=ea;N=d+84140|0;g[P>>2]=+g[N>>2];P=d+84136|0;g[Q>>2]=+g[P>>2];Q=d+84132|0;ea=+g[Q>>2];g[O>>2]=ea;g[t>>2]=ea;t=d+84128|0;ea=+g[t>>2];g[N>>2]=ea;g[P>>2]=ea;P=d+84124|0;ea=+g[P>>2];g[Q>>2]=ea;Q=d+84120|0;da=+g[Q>>2];g[t>>2]=(ea+da)*.5;g[P>>2]=da;P=d+84116|0;da=+g[P>>2];g[Q>>2]=da;g[P>>2]=(da+ +g[u>>2])*.5;P=d+85004|0;da=+g[P>>2];g[d+85060>>2]=da;g[d+85056>>2]=da;Q=d+85e3|0;da=+g[Q>>2];g[d+85052>>2]=da;g[d+85048>>2]=da;g[d+85044>>2]=da;g[d+85040>>2]=da;t=d+84996|0;da=+g[t>>2];g[d+85036>>2]=da;g[d+85032>>2]=da;N=d+84992|0;da=+g[N>>2];g[d+85028>>2]=da;g[d+85024>>2]=da;O=d+84988|0;da=+g[O>>2];g[d+85020>>2]=da;g[d+85016>>2]=da;S=d+84984|0;da=+g[S>>2];g[d+85012>>2]=da;g[d+85008>>2]=da;R=d+84980|0;g[P>>2]=+g[R>>2];P=d+84976|0;g[Q>>2]=+g[P>>2];Q=d+84972|0;g[t>>2]=+g[Q>>2];t=d+84968|0;g[N>>2]=+g[t>>2];N=d+84964|0;da=+g[N>>2];g[O>>2]=da;g[S>>2]=da;S=d+84960|0;da=+g[S>>2];g[R>>2]=da;g[P>>2]=da;P=d+84956|0;g[Q>>2]=+g[P>>2];Q=d+84952|0;g[t>>2]=+g[Q>>2];t=d+84948|0;da=+g[t>>2];g[N>>2]=da;g[S>>2]=da;S=d+84944|0;da=+g[S>>2];g[P>>2]=da;g[Q>>2]=da;Q=d+84940|0;da=+g[Q>>2];g[t>>2]=da;t=d+84936|0;ea=+g[t>>2];g[S>>2]=(da+ea)*.5;g[Q>>2]=ea;Q=d+84932|0;ea=+g[Q>>2];g[t>>2]=ea;g[Q>>2]=(ea+ +g[d+84928>>2])*.5;Q=d+85820|0;ea=+g[Q>>2];g[d+85876>>2]=ea;g[d+85872>>2]=ea;t=d+85816|0;ea=+g[t>>2];g[d+85868>>2]=ea;g[d+85864>>2]=ea;g[d+85860>>2]=ea;g[d+85856>>2]=ea;S=d+85812|0;ea=+g[S>>2];g[d+85852>>2]=ea;g[d+85848>>2]=ea;P=d+85808|0;ea=+g[P>>2];g[d+85844>>2]=ea;g[d+85840>>2]=ea;N=d+85804|0;ea=+g[N>>2];g[d+85836>>2]=ea;g[d+85832>>2]=ea;R=d+85800|0;ea=+g[R>>2];g[d+85828>>2]=ea;g[d+85824>>2]=ea;O=d+85796|0;g[Q>>2]=+g[O>>2];Q=d+85792|0;g[t>>2]=+g[Q>>2];t=d+85788|0;g[S>>2]=+g[t>>2];S=d+85784|0;g[P>>2]=+g[S>>2];P=d+85780|0;ea=+g[P>>2];g[N>>2]=ea;g[R>>2]=ea;R=d+85776|0;ea=+g[R>>2];g[O>>2]=ea;g[Q>>2]=ea;Q=d+85772|0;g[t>>2]=+g[Q>>2];t=d+85768|0;g[S>>2]=+g[t>>2];S=d+85764|0;ea=+g[S>>2];g[P>>2]=ea;g[R>>2]=ea;R=d+85760|0;ea=+g[R>>2];g[Q>>2]=ea;g[t>>2]=ea;t=d+85756|0;ea=+g[t>>2];g[S>>2]=ea;S=d+85752|0;da=+g[S>>2];g[R>>2]=(ea+da)*.5;g[t>>2]=da;t=d+85748|0;da=+g[t>>2];g[S>>2]=da;g[t>>2]=(da+ +g[fa>>2])*.5;t=d+86636|0;da=+g[t>>2];g[d+86692>>2]=da;g[d+86688>>2]=da;S=d+86632|0;da=+g[S>>2];g[d+86684>>2]=da;g[d+86680>>2]=da;g[d+86676>>2]=da;g[d+86672>>2]=da;R=d+86628|0;da=+g[R>>2];g[d+86668>>2]=da;g[d+86664>>2]=da;Q=d+86624|0;da=+g[Q>>2];g[d+86660>>2]=da;g[d+86656>>2]=da;P=d+86620|0;da=+g[P>>2];g[d+86652>>2]=da;g[d+86648>>2]=da;O=d+86616|0;da=+g[O>>2];g[d+86644>>2]=da;g[d+86640>>2]=da;N=d+86612|0;g[t>>2]=+g[N>>2];t=d+86608|0;g[S>>2]=+g[t>>2];S=d+86604|0;g[R>>2]=+g[S>>2];R=d+86600|0;g[Q>>2]=+g[R>>2];Q=d+86596|0;da=+g[Q>>2];g[P>>2]=da;g[O>>2]=da;O=d+86592|0;da=+g[O>>2];g[N>>2]=da;g[t>>2]=da;t=d+86588|0;g[S>>2]=+g[t>>2];S=d+86584|0;g[R>>2]=+g[S>>2];R=d+86580|0;da=+g[R>>2];g[Q>>2]=da;g[O>>2]=da;O=d+86576|0;da=+g[O>>2];g[t>>2]=da;g[S>>2]=da;S=d+86572|0;da=+g[S>>2];g[R>>2]=da;R=d+86568|0;ea=+g[R>>2];g[O>>2]=(da+ea)*.5;g[S>>2]=ea;S=d+86564|0;ea=+g[S>>2];g[R>>2]=ea;g[S>>2]=(ea+ +g[d+86560>>2])*.5;mrc(ga|0,0,17)|0;mrc(h|0,0,17)|0}else{oub(n,l,k,W,1);oub(o,d+246|0,c[d+28>>2]|0,c[j>>2]|0,1);if((c[d+48>>2]|0)!=0){S=d+16|0;oub(p,d+416|0,c[S>>2]|0,c[j>>2]|0,0);oub(q,d+586|0,c[S>>2]|0,c[j>>2]|0,0)}if((c[v>>2]|0)==0){break}pub(C|0);pub(d+81664|0);pub(X|0);pub(d+83296|0);pub(u|0);pub(d+84928|0);pub(fa|0);pub(d+86560|0);mrc(ga|0,0,17)|0;mrc(h|0,0,17)|0}}while(0);if((c[j>>2]|0)<=0){kub(D,e,y,A);kub(D,f,z,A);i=b;return 0}h=2656832+(A<<2)|0;ga=r|0;fa=r|0;u=r+4|0;X=r+8|0;C=r+12|0;v=d+48|0;W=s|0;k=s|0;l=s+4|0;S=s+8|0;R=s+12|0;O=r+16|0;t=s+16|0;Q=r+20|0;N=s+20|0;P=r+24|0;M=s+24|0;L=r+28|0;r=s+28|0;s=c[o>>2]|0;o=c[n>>2]|0;n=d+8|0;K=2656840+(A<<2)|0;G=c[q>>2]|0;q=c[p>>2]|0;p=0;while(1){F=p+1|0;if(Y){I=c[h>>2]|0;H=0;do{Z=a[s+(p*34|0)+H|0]|0;ha=(a[o+(p*34|0)+H|0]|0)+7+((c[n>>2]|0)*23|0)|0;ea=+g[m+(ha<<7)+(Z<<4)>>2];da=+g[m+(ha<<7)+(Z<<4)+4>>2];ca=+g[m+(ha<<7)+(Z<<4)+8>>2];_=+g[m+(ha<<7)+(Z<<4)+12>>2];do{if((c[v>>2]|0)==0){ia=ea;ja=da;ka=ca;la=_}else{if((H|0)>=(c[K>>2]|0)){ia=ea;ja=da;ka=ca;la=_;break}Z=d+87376+H|0;ha=(a[G+(p*34|0)+H|0]|0)+(a[Z]<<3)|0;ma=d+87410+H|0;na=(a[q+(p*34|0)+H|0]|0)+(a[ma]<<3)|0;oa=+g[5463320+(ha<<2)>>2];pa=+g[5465368+(ha<<2)>>2];qa=+g[5463320+(na<<2)>>2];ra=+g[5465368+(na<<2)>>2];a[Z]=ha&63;a[ma]=na&63;sa=oa*qa+pa*ra;ta=pa*qa-oa*ra;g[d+81664+(F*136|0)+(H<<2)>>2]=ea*pa;g[d+83296+(F*136|0)+(H<<2)>>2]=da*ta;g[d+84928+(F*136|0)+(H<<2)>>2]=ca*pa;g[d+86560+(F*136|0)+(H<<2)>>2]=_*ta;ia=ea*oa;ja=da*sa;ka=ca*oa;la=_*sa}}while(0);g[d+80848+(F*136|0)+(H<<2)>>2]=ia;g[d+82480+(F*136|0)+(H<<2)>>2]=ja;g[d+84112+(F*136|0)+(H<<2)>>2]=ka;g[d+85744+(F*136|0)+(H<<2)>>2]=la;H=H+1|0;}while((H|0)<(I|0));I=d+52+(p<<2)|0;H=d+52+(F<<2)|0;T=c[B>>2]|0;U=0;do{V=c[I>>2]|0;na=(c[H>>2]|0)-V|0;$=1.0/+(na|0);ma=a[J+U|0]|0;aa=+g[d+80848+(p*136|0)+(ma<<2)>>2];g[fa>>2]=aa;ba=+g[d+82480+(p*136|0)+(ma<<2)>>2];g[u>>2]=ba;_=+g[d+84112+(p*136|0)+(ma<<2)>>2];g[X>>2]=_;ca=+g[d+85744+(p*136|0)+(ma<<2)>>2];g[C>>2]=ca;ha=c[v>>2]|0;Z=(ha|0)==0;do{if(!Z){if(E){if((U-9|0)>>>0<5>>>0){ua=76}else{ua=77}}else{if((U|0)<2){ua=76}else{ua=77}}if((ua|0)==76){ua=0;g[O>>2]=-0.0- +g[d+81664+(p*136|0)+(ma<<2)>>2];g[Q>>2]=-0.0- +g[d+83296+(p*136|0)+(ma<<2)>>2];g[P>>2]=-0.0- +g[d+84928+(p*136|0)+(ma<<2)>>2];g[L>>2]=-0.0- +g[d+86560+(p*136|0)+(ma<<2)>>2];break}else if((ua|0)==77){ua=0;g[O>>2]=+g[d+81664+(p*136|0)+(ma<<2)>>2];g[Q>>2]=+g[d+83296+(p*136|0)+(ma<<2)>>2];g[P>>2]=+g[d+84928+(p*136|0)+(ma<<2)>>2];g[L>>2]=+g[d+86560+(p*136|0)+(ma<<2)>>2];break}}}while(0);g[k>>2]=$*(+g[d+80848+(F*136|0)+(ma<<2)>>2]-aa);g[l>>2]=$*(+g[d+82480+(F*136|0)+(ma<<2)>>2]-ba);g[S>>2]=$*(+g[d+84112+(F*136|0)+(ma<<2)>>2]-_);g[R>>2]=$*(+g[d+85744+(F*136|0)+(ma<<2)>>2]-ca);if(!Z){g[t>>2]=$*(+g[d+81664+(F*136|0)+(ma<<2)>>2]- +g[O>>2]);g[N>>2]=$*(+g[d+83296+(F*136|0)+(ma<<2)>>2]- +g[Q>>2]);g[M>>2]=$*(+g[d+84928+(F*136|0)+(ma<<2)>>2]- +g[P>>2]);g[r>>2]=$*(+g[d+86560+(F*136|0)+(ma<<2)>>2]- +g[L>>2])}va=V+1|0;pe[c[d+87468+(((ha|0)!=0)<<2)>>2]&1023](w+(U<<8)+(va<<3)|0,x+(U<<8)+(va<<3)|0,ga,W,na);U=U+1|0;}while((U|0)<(T|0))}if((F|0)<(c[j>>2]|0)){p=F}else{break}}kub(D,e,y,A);kub(D,f,z,A);i=b;return 0}function kub(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0;if((e|0)==0){e=0;do{g[b+(e<<8)>>2]=+g[d+(e<<3)>>2]+ +g[d+256+(e<<3)>>2]+ +g[d+512+(e<<3)>>2]+ +g[d+768+(e<<3)>>2]+ +g[d+1024+(e<<3)>>2]+ +g[d+1280+(e<<3)>>2];g[b+9728+(e<<8)>>2]=+g[d+(e<<3)+4>>2]+ +g[d+256+(e<<3)+4>>2]+ +g[d+512+(e<<3)+4>>2]+ +g[d+768+(e<<3)+4>>2]+ +g[d+1024+(e<<3)+4>>2]+ +g[d+1280+(e<<3)+4>>2];g[b+(e<<8)+4>>2]=+g[d+1536+(e<<3)>>2]+ +g[d+1792+(e<<3)>>2];g[b+9728+(e<<8)+4>>2]=+g[d+1536+(e<<3)+4>>2]+ +g[d+1792+(e<<3)+4>>2];g[b+(e<<8)+8>>2]=+g[d+2048+(e<<3)>>2]+ +g[d+2304+(e<<3)>>2];g[b+9728+(e<<8)+8>>2]=+g[d+2048+(e<<3)+4>>2]+ +g[d+2304+(e<<3)+4>>2];e=e+1|0;}while((e|0)<32);mf[c[a+16>>2]&2047](b,d+1792|0,3,32);return}else{f=0}do{e=b+(f<<8)|0;mrc(e|0,0,20)|0;h=b+9728+(f<<8)|0;mrc(h|0,0,20)|0;i=e|0;e=h|0;h=0;j=0.0;k=0.0;do{j=+g[d+(h<<8)+(f<<3)>>2]+j;g[i>>2]=j;k=+g[d+(h<<8)+(f<<3)+4>>2]+k;g[e>>2]=k;h=h+1|0;}while((h|0)<12);h=b+(f<<8)+4|0;e=b+9728+(f<<8)+4|0;k=+g[d+3072+(f<<3)>>2]+ +g[h>>2];g[h>>2]=k;j=+g[d+3072+(f<<3)+4>>2]+ +g[e>>2];g[e>>2]=j;l=+g[d+3328+(f<<3)>>2]+k;g[h>>2]=l;k=+g[d+3328+(f<<3)+4>>2]+j;g[e>>2]=k;j=+g[d+3584+(f<<3)>>2]+l;g[h>>2]=j;l=+g[d+3584+(f<<3)+4>>2]+k;g[e>>2]=l;k=+g[d+3840+(f<<3)>>2]+j;g[h>>2]=k;j=+g[d+3840+(f<<3)+4>>2]+l;g[e>>2]=j;l=+g[d+4096+(f<<3)>>2]+k;g[h>>2]=l;k=+g[d+4096+(f<<3)+4>>2]+j;g[e>>2]=k;j=+g[d+4352+(f<<3)>>2]+l;g[h>>2]=j;l=+g[d+4352+(f<<3)+4>>2]+k;g[e>>2]=l;k=+g[d+4608+(f<<3)>>2]+j;g[h>>2]=k;j=+g[d+4608+(f<<3)+4>>2]+l;g[e>>2]=j;g[h>>2]=+g[d+4864+(f<<3)>>2]+k;g[e>>2]=+g[d+4864+(f<<3)+4>>2]+j;e=b+(f<<8)+8|0;h=b+9728+(f<<8)+8|0;i=b+(f<<8)+12|0;m=b+9728+(f<<8)+12|0;n=b+(f<<8)+16|0;o=b+9728+(f<<8)+16|0;j=+g[d+5120+(f<<3)>>2]+ +g[e>>2];g[e>>2]=j;k=+g[d+5120+(f<<3)+4>>2]+ +g[h>>2];g[h>>2]=k;l=+g[d+6144+(f<<3)>>2]+ +g[i>>2];g[i>>2]=l;p=+g[d+6144+(f<<3)+4>>2]+ +g[m>>2];g[m>>2]=p;q=+g[d+7168+(f<<3)>>2]+ +g[n>>2];g[n>>2]=q;r=+g[d+7168+(f<<3)+4>>2]+ +g[o>>2];g[o>>2]=r;s=+g[d+5376+(f<<3)>>2]+j;g[e>>2]=s;j=+g[d+5376+(f<<3)+4>>2]+k;g[h>>2]=j;k=+g[d+6400+(f<<3)>>2]+l;g[i>>2]=k;l=+g[d+6400+(f<<3)+4>>2]+p;g[m>>2]=l;p=+g[d+7424+(f<<3)>>2]+q;g[n>>2]=p;q=+g[d+7424+(f<<3)+4>>2]+r;g[o>>2]=q;r=+g[d+5632+(f<<3)>>2]+s;g[e>>2]=r;s=+g[d+5632+(f<<3)+4>>2]+j;g[h>>2]=s;j=+g[d+6656+(f<<3)>>2]+k;g[i>>2]=j;k=+g[d+6656+(f<<3)+4>>2]+l;g[m>>2]=k;l=+g[d+7680+(f<<3)>>2]+p;g[n>>2]=l;p=+g[d+7680+(f<<3)+4>>2]+q;g[o>>2]=p;g[e>>2]=+g[d+5888+(f<<3)>>2]+r;g[h>>2]=+g[d+5888+(f<<3)+4>>2]+s;g[i>>2]=+g[d+6912+(f<<3)>>2]+j;g[m>>2]=+g[d+6912+(f<<3)+4>>2]+k;g[n>>2]=+g[d+7936+(f<<3)>>2]+l;g[o>>2]=+g[d+7936+(f<<3)+4>>2]+p;f=f+1|0;}while((f|0)<32);mf[c[a+16>>2]&2047](b,d+6912|0,5,32);return}function lub(){var b=0,d=0.0,e=0.0,f=0,h=0,i=0.0,j=0.0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0.0,B=0,C=0,D=0;c[846931]=6573264;c[846933]=1544;$2(3387720,9,61,1080512,1,1,1080264,4,4,0,0,0,4)|0;c[846936]=6559568;c[846938]=832;$2(3387740,9,61,1080048,1,1,1079920,2,2,0,0,0,4)|0;c[846941]=6555472;c[846943]=1024;$2(3387760,9,29,1080696,1,1,1080576,4,4,0,0,0,4)|0;c[846946]=6551328;c[846948]=1036;$2(3387780,9,29,1080232,1,1,1080112,4,4,0,0,0,4)|0;c[846951]=6549152;c[846953]=544;$2(3387800,9,15,1080824,1,1,1080792,2,2,0,0,0,4)|0;c[846956]=6571088;c[846958]=544;$2(3387820,9,15,1080776,1,1,1080744,2,2,0,0,0,4)|0;c[846961]=6569040;c[846963]=512;$2(3387840,9,8,1079912,1,1,1079904,1,1,0,0,0,4)|0;c[846966]=6566992;c[846968]=512;$2(3387860,9,8,1079896,1,1,1079888,1,1,0,0,0,4)|0;c[846971]=6564944;c[846973]=512;$2(3387880,9,8,1079864,1,1,1079856,1,1,0,0,0,4)|0;c[846976]=6562896;c[846978]=512;$2(3387900,9,8,1079848,1,1,1079840,1,1,0,0,0,4)|0;b=0;while(1){d=+g[698240+(b<<2)>>2]*.25;e=+g[698208+(b<<2)>>2]*.25;f=b<<6;h=0;do{i=d+ +g[698240+(h<<2)>>2]*.5;j=e+ +g[698208+(h<<2)>>2]*.5;k=(h<<3)+f|0;l=0;do{m=i+ +g[698240+(l<<2)>>2];n=j+ +g[698208+(l<<2)>>2];o=1.0/+S(m*m+n*n);p=k+l|0;g[5463320+(p<<2)>>2]=m*o;g[5465368+(p<<2)>>2]=n*o;l=l+1|0;}while((l|0)<8);h=h+1|0;}while((h|0)<8);h=b+1|0;if((h|0)<8){b=h}else{q=0;break}}while(1){e=+g[698272+(q<<2)>>2];d=e*e;j=1.4142135381698608/+S(d+1.0);i=e*j;o=j-i;n=e*2.0;m=d+-1.0;d=e+1.0/e;e=d*d;b=0;do{d=+g[698536+(b<<2)>>2]*.5;r=o*d*.7071067690849304;s=d+r;g[10239536+(q<<7)+(b<<4)>>2]=i*+U(s);t=r-d;g[10239536+(q<<7)+(b<<4)+4>>2]=j*+U(t);g[10239536+(q<<7)+(b<<4)+8>>2]=i*+V(s);g[10239536+(q<<7)+(b<<4)+12>>2]=j*+V(t);if(b>>>0<5>>>0){u=+g[698456+(b<<2)>>2]}else{u=.05000000074505806}t=+_(+(n*u),+m)*.5;s=+S((u*u*4.0+-4.0)/e+1.0);d=+Z(+S((1.0-s)/(s+1.0)));if(t<0.0){v=t+1.5707963267948966}else{v=t}t=+V(v);s=+V(d);r=+U(v)*1.4142135623730951;w=+U(d);g[10233648+(q<<7)+(b<<4)>>2]=r*w;d=t;g[10233648+(q<<7)+(b<<4)+4>>2]=d*1.4142135623730951*w;w=s;g[10233648+(q<<7)+(b<<4)+8>>2]=d*-1.4142135623730951*w;g[10233648+(q<<7)+(b<<4)+12>>2]=r*w;b=b+1|0;}while((b|0)<8);b=q+1|0;if((b|0)<46){q=b}else{x=0;break}}while(1){if(x>>>0<10>>>0){y=+(a[698520+x|0]|0)*.125}else{y=+(x|0)+ -6.5}v=y*-1.3508848635140327;g[10231248+(x*24|0)>>2]=+U(v);g[10231252+(x*24|0)>>2]=+V(v);v=y*-2.356194490192345;g[10231256+(x*24|0)>>2]=+U(v);g[10231260+(x*24|0)>>2]=+V(v);v=y*-1.0901326597838268;g[10231264+(x*24|0)>>2]=+U(v);g[10231268+(x*24|0)>>2]=+V(v);v=y*-1.225221089959176;g[5462520+(x<<3)>>2]=+U(v);g[5462524+(x<<3)>>2]=+V(v);q=x+1|0;if((q|0)<30){x=q}else{z=0;break}}while(1){if(z>>>0<32>>>0){A=+(a[698488+z|0]|0)/24.0}else{A=+(z|0)+ -26.5}y=A*-1.3508848635140327;g[10232448+(z*24|0)>>2]=+U(y);g[10232452+(z*24|0)>>2]=+V(y);y=A*-2.356194490192345;g[10232456+(z*24|0)>>2]=+U(y);g[10232460+(z*24|0)>>2]=+V(y);y=A*-1.0901326597838268;g[10232464+(z*24|0)>>2]=+U(y);g[10232468+(z*24|0)>>2]=+V(y);y=A*-1.225221089959176;g[5462920+(z<<3)>>2]=+U(y);g[5462924+(z<<3)>>2]=+V(y);x=z+1|0;if((x|0)<50){z=x}else{B=0;break}}while(1){A=(+(B|0)+.5)*6.283185307179586;y=A*-6.0*.125;g[8839280+(B<<6)>>2]=+U(y)*.007460829336196184;g[8839284+(B<<6)>>2]=+V(y)*-.007460829336196184;y=A*-5.0*.125;g[8839288+(B<<6)>>2]=+U(y)*.02270421013236046;g[8839292+(B<<6)>>2]=+V(y)*-.02270421013236046;y=A*-4.0*.125;g[8839296+(B<<6)>>2]=+U(y)*.045468658208847046;g[8839300+(B<<6)>>2]=+V(y)*-.045468658208847046;y=A*-3.0*.125;g[8839304+(B<<6)>>2]=+U(y)*.0726611390709877;g[8839308+(B<<6)>>2]=+V(y)*-.0726611390709877;y=A*-2.0*.125;g[8839312+(B<<6)>>2]=+U(y)*.09885108470916748;g[8839316+(B<<6)>>2]=+V(y)*-.09885108470916748;y=A*-1.0*.125;g[8839320+(B<<6)>>2]=+U(y)*.1179371029138565;g[8839324+(B<<6)>>2]=+V(y)*-.1179371029138565;y=A*0.0*.125;g[8839328+(B<<6)>>2]=+U(y)*.125;g[8839332+(B<<6)>>2]=+V(y)*-.125;z=B+1|0;if((z|0)<8){B=z}else{C=0;break}}while(1){y=(+(C|0)+.5)*6.283185307179586;A=y*-6.0/12.0;g[8838512+(C<<6)>>2]=+U(A)*.040811799466609955;g[8838516+(C<<6)>>2]=+V(A)*-.040811799466609955;A=y*-5.0/12.0;g[8838520+(C<<6)>>2]=+U(A)*.03812811151146889;g[8838524+(C<<6)>>2]=+V(A)*-.03812811151146889;A=y*-4.0/12.0;g[8838528+(C<<6)>>2]=+U(A)*.05144908279180527;g[8838532+(C<<6)>>2]=+V(A)*-.05144908279180527;A=y*-3.0/12.0;g[8838536+(C<<6)>>2]=+U(A)*.06399831175804138;g[8838540+(C<<6)>>2]=+V(A)*-.06399831175804138;A=y*-2.0/12.0;g[8838544+(C<<6)>>2]=+U(A)*.07428313791751862;g[8838548+(C<<6)>>2]=+V(A)*-.07428313791751862;A=y*-1.0/12.0;g[8838552+(C<<6)>>2]=+U(A)*.08100347965955734;g[8838556+(C<<6)>>2]=+V(A)*-.08100347965955734;A=y*0.0/12.0;g[8838560+(C<<6)>>2]=+U(A)*.0833333358168602;g[8838564+(C<<6)>>2]=+V(A)*-.0833333358168602;B=C+1|0;if((B|0)<12){C=B}else{D=0;break}}do{A=(+(D|0)+.5)*6.283185307179586;y=A*-6.0*.125;g[8838e3+(D<<6)>>2]=+U(y)*.01565675623714924;g[8838004+(D<<6)>>2]=+V(y)*-.01565675623714924;y=A*-5.0*.125;g[8838008+(D<<6)>>2]=+U(y)*.037527162581682205;g[8838012+(D<<6)>>2]=+V(y)*-.037527162581682205;y=A*-4.0*.125;g[8838016+(D<<6)>>2]=+U(y)*.054178912192583084;g[8838020+(D<<6)>>2]=+V(y)*-.054178912192583084;y=A*-3.0*.125;g[8838024+(D<<6)>>2]=+U(y)*.08417043834924698;g[8838028+(D<<6)>>2]=+V(y)*-.08417043834924698;y=A*-2.0*.125;g[8838032+(D<<6)>>2]=+U(y)*.10307344049215317;g[8838036+(D<<6)>>2]=+V(y)*-.10307344049215317;y=A*-1.0*.125;g[8838040+(D<<6)>>2]=+U(y)*.12222452461719513;g[8838044+(D<<6)>>2]=+V(y)*-.12222452461719513;y=A*0.0*.125;g[8838048+(D<<6)>>2]=+U(y)*.125;g[8838052+(D<<6)>>2]=+V(y)*-.125;D=D+1|0;}while((D|0)<8);g[2209436]=1.0853208515459211e-17;g[2209437]=.059082113206386566;g[2209438]=.03444669395685196;g[2209439]=.03444669395685196;g[2209440]=-0.0;g[2209441]=0.0;g[2209442]=-.05500388517975807;g[2209443]=.05500388517975807;g[2209444]=1.0094949418724715e-17;g[2209445]=.16486303508281708;g[2209446]=.16461344063282013;g[2209447]=.16461344063282013;g[2209448]=.25;g[2209449]=-0.0;g[2209452]=-3.2559625546377634e-17;g[2209453]=-.059082113206386566;g[2209454]=-.03444669395685196;g[2209455]=.03444669395685196;g[2209456]=-0.0;g[2209457]=0.0;g[2209458]=.05500388517975807;g[2209459]=.05500388517975807;g[2209460]=-3.0284849083354756e-17;g[2209461]=-.16486303508281708;g[2209462]=-.16461344063282013;g[2209463]=.16461344063282013;g[2209464]=.25;g[2209465]=-0.0;g[2209468]=1.5921695514895825e-16;g[2209469]=.059082113206386566;g[2209470]=-.03444669395685196;g[2209471]=-.03444669395685196;g[2209472]=-0.0;g[2209473]=0.0;g[2209474]=.05500388517975807;g[2209475]=-.05500388517975807;g[2209476]=5.047474626644296e-17;g[2209477]=.16486303508281708;g[2209478]=-.16461344063282013;g[2209479]=-.16461344063282013;g[2209480]=.25;g[2209481]=-0.0;g[2209484]=2.897845958089261e-17;g[2209485]=-.059082113206386566;g[2209486]=.03444669395685196;g[2209487]=-.03444669395685196;g[2209488]=-0.0;g[2209489]=0.0;g[2209490]=-.05500388517975807;g[2209491]=-.05500388517975807;g[2209492]=-7.066464344953116e-17;g[2209493]=-.16486303508281708;g[2209494]=.16461344063282013;g[2209495]=-.16461344063282013;g[2209496]=.25;g[2209497]=-0.0;return}function mub(a){a=a|0;rub(a+87444|0);return}function nub(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=c[b>>2]|0;if((e|0)==20|(e|0)==11){if((f|0)<=0){return}if((g|0)==0){i=0;do{j=d+(i*34|0)|0;a[h+(i*34|0)+16|0]=a[d+(i*34|0)+10|0]|0;k=d+(i*34|0)+9|0;a[h+(i*34|0)+15|0]=a[k]|0;a[h+(i*34|0)+14|0]=a[k]|0;k=d+(i*34|0)+8|0;a[h+(i*34|0)+13|0]=a[k]|0;a[h+(i*34|0)+12|0]=a[k]|0;a[h+(i*34|0)+11|0]=a[d+(i*34|0)+7|0]|0;a[h+(i*34|0)+10|0]=a[d+(i*34|0)+6|0]|0;k=d+(i*34|0)+5|0;a[h+(i*34|0)+9|0]=a[k]|0;a[h+(i*34|0)+8|0]=a[k]|0;k=d+(i*34|0)+4|0;a[h+(i*34|0)+7|0]=a[k]|0;a[h+(i*34|0)+6|0]=a[k]|0;k=d+(i*34|0)+3|0;a[h+(i*34|0)+5|0]=a[k]|0;l=d+(i*34|0)+2|0;a[h+(i*34|0)+4|0]=((a[k]|0)+(a[l]|0)|0)/2|0;a[h+(i*34|0)+3|0]=a[l]|0;l=d+(i*34|0)+1|0;a[h+(i*34|0)+2|0]=a[l]|0;a[h+(i*34|0)+1|0]=((a[l]|0)+(a[j]|0)|0)/2|0;a[h+(i*34|0)|0]=a[j]|0;i=i+1|0;}while((i|0)<(f|0));return}else{i=0;do{j=d+(i*34|0)|0;l=d+(i*34|0)+19|0;a[h+(i*34|0)+33|0]=a[l]|0;a[h+(i*34|0)+32|0]=a[l]|0;l=d+(i*34|0)+18|0;a[h+(i*34|0)+31|0]=a[l]|0;a[h+(i*34|0)+30|0]=a[l]|0;a[h+(i*34|0)+29|0]=a[l]|0;a[h+(i*34|0)+28|0]=a[l]|0;l=d+(i*34|0)+17|0;a[h+(i*34|0)+27|0]=a[l]|0;a[h+(i*34|0)+26|0]=a[l]|0;l=d+(i*34|0)+16|0;a[h+(i*34|0)+25|0]=a[l]|0;a[h+(i*34|0)+24|0]=a[l]|0;l=d+(i*34|0)+15|0;a[h+(i*34|0)+23|0]=a[l]|0;a[h+(i*34|0)+22|0]=a[l]|0;l=d+(i*34|0)+14|0;a[h+(i*34|0)+21|0]=a[l]|0;a[h+(i*34|0)+20|0]=a[l]|0;a[h+(i*34|0)+19|0]=a[d+(i*34|0)+13|0]|0;a[h+(i*34|0)+18|0]=a[d+(i*34|0)+12|0]|0;a[h+(i*34|0)+17|0]=a[d+(i*34|0)+11|0]|0;a[h+(i*34|0)+16|0]=a[d+(i*34|0)+10|0]|0;l=d+(i*34|0)+9|0;a[h+(i*34|0)+15|0]=a[l]|0;a[h+(i*34|0)+14|0]=a[l]|0;l=d+(i*34|0)+8|0;a[h+(i*34|0)+13|0]=a[l]|0;a[h+(i*34|0)+12|0]=a[l]|0;a[h+(i*34|0)+11|0]=a[d+(i*34|0)+7|0]|0;a[h+(i*34|0)+10|0]=a[d+(i*34|0)+6|0]|0;l=d+(i*34|0)+5|0;a[h+(i*34|0)+9|0]=a[l]|0;a[h+(i*34|0)+8|0]=a[l]|0;l=d+(i*34|0)+4|0;a[h+(i*34|0)+7|0]=a[l]|0;a[h+(i*34|0)+6|0]=a[l]|0;l=d+(i*34|0)+3|0;a[h+(i*34|0)+5|0]=a[l]|0;k=d+(i*34|0)+2|0;a[h+(i*34|0)+4|0]=((a[l]|0)+(a[k]|0)|0)/2|0;a[h+(i*34|0)+3|0]=a[k]|0;k=d+(i*34|0)+1|0;a[h+(i*34|0)+2|0]=a[k]|0;a[h+(i*34|0)+1|0]=((a[k]|0)+(a[j]|0)|0)/2|0;a[h+(i*34|0)|0]=a[j]|0;i=i+1|0;}while((i|0)<(f|0));return}}else if((e|0)==10|(e|0)==5){if((f|0)<=0){return}if((g|0)==0){g=0;do{e=d+(g*34|0)|0;a[h+(g*34|0)+16|0]=0;i=d+(g*34|0)+4|0;a[h+(g*34|0)+15|0]=a[i]|0;a[h+(g*34|0)+14|0]=a[i]|0;a[h+(g*34|0)+13|0]=a[i]|0;a[h+(g*34|0)+12|0]=a[i]|0;i=d+(g*34|0)+3|0;a[h+(g*34|0)+11|0]=a[i]|0;a[h+(g*34|0)+10|0]=a[i]|0;i=d+(g*34|0)+2|0;a[h+(g*34|0)+9|0]=a[i]|0;a[h+(g*34|0)+8|0]=a[i]|0;a[h+(g*34|0)+7|0]=a[i]|0;a[h+(g*34|0)+6|0]=a[i]|0;i=d+(g*34|0)+1|0;a[h+(g*34|0)+5|0]=a[i]|0;a[h+(g*34|0)+4|0]=a[i]|0;a[h+(g*34|0)+3|0]=a[i]|0;a[h+(g*34|0)+2|0]=a[e]|0;a[h+(g*34|0)+1|0]=a[e]|0;a[h+(g*34|0)|0]=a[e]|0;g=g+1|0;}while((g|0)<(f|0));return}else{g=0;do{e=d+(g*34|0)|0;i=d+(g*34|0)+9|0;a[h+(g*34|0)+33|0]=a[i]|0;a[h+(g*34|0)+32|0]=a[i]|0;a[h+(g*34|0)+31|0]=a[i]|0;a[h+(g*34|0)+30|0]=a[i]|0;a[h+(g*34|0)+29|0]=a[i]|0;a[h+(g*34|0)+28|0]=a[i]|0;i=d+(g*34|0)+8|0;a[h+(g*34|0)+27|0]=a[i]|0;a[h+(g*34|0)+26|0]=a[i]|0;a[h+(g*34|0)+25|0]=a[i]|0;a[h+(g*34|0)+24|0]=a[i]|0;i=d+(g*34|0)+7|0;a[h+(g*34|0)+23|0]=a[i]|0;a[h+(g*34|0)+22|0]=a[i]|0;a[h+(g*34|0)+21|0]=a[i]|0;a[h+(g*34|0)+20|0]=a[i]|0;i=d+(g*34|0)+6|0;a[h+(g*34|0)+19|0]=a[i]|0;a[h+(g*34|0)+18|0]=a[i]|0;i=d+(g*34|0)+5|0;a[h+(g*34|0)+17|0]=a[i]|0;a[h+(g*34|0)+16|0]=a[i]|0;i=d+(g*34|0)+4|0;a[h+(g*34|0)+15|0]=a[i]|0;a[h+(g*34|0)+14|0]=a[i]|0;a[h+(g*34|0)+13|0]=a[i]|0;a[h+(g*34|0)+12|0]=a[i]|0;i=d+(g*34|0)+3|0;a[h+(g*34|0)+11|0]=a[i]|0;a[h+(g*34|0)+10|0]=a[i]|0;i=d+(g*34|0)+2|0;a[h+(g*34|0)+9|0]=a[i]|0;a[h+(g*34|0)+8|0]=a[i]|0;a[h+(g*34|0)+7|0]=a[i]|0;a[h+(g*34|0)+6|0]=a[i]|0;i=d+(g*34|0)+1|0;a[h+(g*34|0)+5|0]=a[i]|0;a[h+(g*34|0)+4|0]=a[i]|0;a[h+(g*34|0)+3|0]=a[i]|0;a[h+(g*34|0)+2|0]=a[e]|0;a[h+(g*34|0)+1|0]=a[e]|0;a[h+(g*34|0)|0]=a[e]|0;g=g+1|0;}while((g|0)<(f|0));return}}else{c[b>>2]=d;return}}function oub(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=c[b>>2]|0;if((e|0)==34|(e|0)==17){if((f|0)<=0){return}if((g|0)==0){i=0;do{j=d+(i*34|0)+1|0;a[h+(i*34|0)|0]=((a[d+(i*34|0)|0]<<1)+(a[j]|0)|0)/3|0;a[h+(i*34|0)+1|0]=((a[d+(i*34|0)+2|0]<<1)+(a[j]|0)|0)/3|0;j=d+(i*34|0)+4|0;a[h+(i*34|0)+2|0]=((a[d+(i*34|0)+3|0]<<1)+(a[j]|0)|0)/3|0;a[h+(i*34|0)+3|0]=((a[d+(i*34|0)+5|0]<<1)+(a[j]|0)|0)/3|0;a[h+(i*34|0)+4|0]=((a[d+(i*34|0)+7|0]|0)+(a[d+(i*34|0)+6|0]|0)|0)/2|0;a[h+(i*34|0)+5|0]=((a[d+(i*34|0)+9|0]|0)+(a[d+(i*34|0)+8|0]|0)|0)/2|0;a[h+(i*34|0)+6|0]=a[d+(i*34|0)+10|0]|0;a[h+(i*34|0)+7|0]=a[d+(i*34|0)+11|0]|0;a[h+(i*34|0)+8|0]=((a[d+(i*34|0)+13|0]|0)+(a[d+(i*34|0)+12|0]|0)|0)/2|0;a[h+(i*34|0)+9|0]=((a[d+(i*34|0)+15|0]|0)+(a[d+(i*34|0)+14|0]|0)|0)/2|0;a[h+(i*34|0)+10|0]=a[d+(i*34|0)+16|0]|0;i=i+1|0;}while((i|0)<(f|0));return}else{i=0;do{j=d+(i*34|0)+1|0;a[h+(i*34|0)|0]=((a[d+(i*34|0)|0]<<1)+(a[j]|0)|0)/3|0;a[h+(i*34|0)+1|0]=((a[d+(i*34|0)+2|0]<<1)+(a[j]|0)|0)/3|0;j=d+(i*34|0)+4|0;a[h+(i*34|0)+2|0]=((a[d+(i*34|0)+3|0]<<1)+(a[j]|0)|0)/3|0;a[h+(i*34|0)+3|0]=((a[d+(i*34|0)+5|0]<<1)+(a[j]|0)|0)/3|0;a[h+(i*34|0)+4|0]=((a[d+(i*34|0)+7|0]|0)+(a[d+(i*34|0)+6|0]|0)|0)/2|0;a[h+(i*34|0)+5|0]=((a[d+(i*34|0)+9|0]|0)+(a[d+(i*34|0)+8|0]|0)|0)/2|0;a[h+(i*34|0)+6|0]=a[d+(i*34|0)+10|0]|0;a[h+(i*34|0)+7|0]=a[d+(i*34|0)+11|0]|0;a[h+(i*34|0)+8|0]=((a[d+(i*34|0)+13|0]|0)+(a[d+(i*34|0)+12|0]|0)|0)/2|0;a[h+(i*34|0)+9|0]=((a[d+(i*34|0)+15|0]|0)+(a[d+(i*34|0)+14|0]|0)|0)/2|0;a[h+(i*34|0)+10|0]=a[d+(i*34|0)+16|0]|0;a[h+(i*34|0)+11|0]=a[d+(i*34|0)+17|0]|0;a[h+(i*34|0)+12|0]=a[d+(i*34|0)+18|0]|0;a[h+(i*34|0)+13|0]=a[d+(i*34|0)+19|0]|0;a[h+(i*34|0)+14|0]=((a[d+(i*34|0)+21|0]|0)+(a[d+(i*34|0)+20|0]|0)|0)/2|0;a[h+(i*34|0)+15|0]=((a[d+(i*34|0)+23|0]|0)+(a[d+(i*34|0)+22|0]|0)|0)/2|0;a[h+(i*34|0)+16|0]=((a[d+(i*34|0)+25|0]|0)+(a[d+(i*34|0)+24|0]|0)|0)/2|0;a[h+(i*34|0)+17|0]=((a[d+(i*34|0)+27|0]|0)+(a[d+(i*34|0)+26|0]|0)|0)/2|0;a[h+(i*34|0)+18|0]=((a[d+(i*34|0)+29|0]|0)+(a[d+(i*34|0)+28|0]|0)+(a[d+(i*34|0)+30|0]|0)+(a[d+(i*34|0)+31|0]|0)|0)/4|0;a[h+(i*34|0)+19|0]=((a[d+(i*34|0)+33|0]|0)+(a[d+(i*34|0)+32|0]|0)|0)/2|0;i=i+1|0;}while((i|0)<(f|0));return}}else if((e|0)==10|(e|0)==5){if((f|0)<=0){return}if((g|0)==0){g=0;do{a[h+(g*34|0)+10|0]=0;e=4;while(1){i=a[d+(g*34|0)+e|0]|0;j=e<<1;a[h+(g*34|0)+j|0]=i;a[(j|1)+(h+(g*34|0))|0]=i;if((e|0)>0){e=e-1|0}else{break}}g=g+1|0;}while((g|0)<(f|0));return}else{g=0;do{e=9;while(1){i=a[d+(g*34|0)+e|0]|0;j=e<<1;a[h+(g*34|0)+j|0]=i;a[(j|1)+(h+(g*34|0))|0]=i;if((e|0)>0){e=e-1|0}else{break}}g=g+1|0;}while((g|0)<(f|0));return}}else{c[b>>2]=d;return}}function pub(a){a=a|0;var b=0,c=0.0,d=0,e=0,f=0,h=0,i=0,j=0;b=a+4|0;c=+g[b>>2];g[a>>2]=(+g[a>>2]*2.0+c)*.3333333432674408;d=a+8|0;g[b>>2]=(c+ +g[d>>2]*2.0)*.3333333432674408;b=a+12|0;e=a+16|0;c=+g[e>>2];g[d>>2]=(+g[b>>2]*2.0+c)*.3333333432674408;d=a+20|0;g[b>>2]=(c+ +g[d>>2]*2.0)*.3333333432674408;b=a+24|0;f=a+28|0;g[e>>2]=(+g[b>>2]+ +g[f>>2])*.5;e=a+32|0;h=a+36|0;g[d>>2]=(+g[e>>2]+ +g[h>>2])*.5;d=a+40|0;g[b>>2]=+g[d>>2];b=a+44|0;g[f>>2]=+g[b>>2];f=a+48|0;i=a+52|0;g[e>>2]=(+g[f>>2]+ +g[i>>2])*.5;e=a+56|0;j=a+60|0;g[h>>2]=(+g[e>>2]+ +g[j>>2])*.5;h=a+64|0;g[d>>2]=+g[h>>2];d=a+68|0;g[b>>2]=+g[d>>2];b=a+72|0;g[f>>2]=+g[b>>2];f=a+76|0;g[i>>2]=+g[f>>2];g[e>>2]=(+g[a+80>>2]+ +g[a+84>>2])*.5;g[j>>2]=(+g[a+88>>2]+ +g[a+92>>2])*.5;g[h>>2]=(+g[a+96>>2]+ +g[a+100>>2])*.5;g[d>>2]=(+g[a+104>>2]+ +g[a+108>>2])*.5;g[b>>2]=(+g[a+112>>2]+ +g[a+116>>2]+ +g[a+120>>2]+ +g[a+124>>2])*.25;g[f>>2]=(+g[a+128>>2]+ +g[a+132>>2])*.5;return}function qub(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=c[f+16>>2]|0;l=c[3387724+(h*20|0)>>2]|0;if((j|0)==0){if((k|0)<=0){return}j=e+8|0;h=e+16|0;m=e|0;n=0;o=0;do{p=c[j>>2]|0;q=c[h>>2]|0;r=c[m>>2]|0;s=r+(p>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(p&7)>>>23;s=b[l+(t<<2)>>1]|0;u=b[l+(t<<2)+2>>1]|0;t=u<<16>>16;do{if(u<<16>>16<0){v=p+9|0;w=q>>>0>v>>>0?v:q;v=r+(w>>>3)|0;x=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(w&7)>>>((t+32|0)>>>0))+s|0;v=b[l+(x<<2)>>1]|0;y=b[l+(x<<2)+2>>1]|0;x=y<<16>>16;if(!(y<<16>>16<0)){z=x;A=v;B=w;break}y=w-t|0;w=q>>>0>y>>>0?y:q;y=r+(w>>>3)|0;C=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>((x+32|0)>>>0))+v|0;z=b[l+(C<<2)+2>>1]|0;A=b[l+(C<<2)>>1]|0;B=w}else{z=t;A=s;B=p}}while(0);p=z+B|0;c[j>>2]=q>>>0>p>>>0?p:q;o=A+o&7;a[g+(i*34|0)+n|0]=o;n=n+1|0;}while((n|0)<(k|0));return}if((i|0)==0){D=c[f+40>>2]|0}else{D=i}f=D-1|0;D=(f|0)>0?f:0;if((k|0)<=0){return}f=e+8|0;n=e+16|0;o=e|0;e=0;do{A=d[g+(D*34|0)+e|0]|0;j=c[f>>2]|0;B=c[n>>2]|0;z=c[o>>2]|0;m=z+(j>>>3)|0;h=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>23;m=b[l+(h<<2)>>1]|0;p=b[l+(h<<2)+2>>1]|0;h=p<<16>>16;do{if(p<<16>>16<0){s=j+9|0;t=B>>>0>s>>>0?s:B;s=z+(t>>>3)|0;r=((je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(t&7)>>>((h+32|0)>>>0))+m|0;s=b[l+(r<<2)>>1]|0;u=b[l+(r<<2)+2>>1]|0;r=u<<16>>16;if(!(u<<16>>16<0)){E=r;F=s;G=t;break}u=t-h|0;t=B>>>0>u>>>0?u:B;u=z+(t>>>3)|0;w=((je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>>((r+32|0)>>>0))+s|0;E=b[l+(w<<2)+2>>1]|0;F=b[l+(w<<2)>>1]|0;G=t}else{E=h;F=m;G=j}}while(0);j=E+G|0;c[f>>2]=B>>>0>j>>>0?j:B;a[g+(i*34|0)+e|0]=F+A&7;e=e+1|0;}while((e|0)<(k|0));return}function rub(a){a=a|0;c[a>>2]=1442;c[a+4>>2]=302;c[a+8>>2]=362;c[a+12>>2]=646;c[a+16>>2]=162;c[a+20>>2]=2;c[a+24>>2]=284;c[a+28>>2]=568;return}function sub(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0.0,f=0.0,h=0;if((c|0)>0){d=0}else{return}do{e=+g[b+(d<<3)>>2];f=+g[b+(d<<3)+4>>2];h=a+(d<<2)|0;g[h>>2]=+g[h>>2]+(e*e+f*f);d=d+1|0;}while((d|0)<(c|0));return}function tub(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((d|0)>0){e=0}else{return}do{f=c+(e<<2)|0;g[a+(e<<3)>>2]=+g[b+(e<<3)>>2]*+g[f>>2];g[a+(e<<3)+4>>2]=+g[b+(e<<3)+4>>2]*+g[f>>2];e=e+1|0;}while((e|0)<(d|0));return}function uub(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0.0;if((e|0)<=0){return}f=b+48|0;h=b+52|0;i=0;do{j=+g[c+(i<<6)+48>>2];k=j*+g[h>>2];l=j*+g[f>>2];m=0;do{j=+g[b+(m<<3)>>2];n=+g[b+(m<<3)+4>>2];o=12-m|0;p=+g[b+(o<<3)>>2];q=+g[b+(o<<3)+4>>2];r=+g[c+(i<<6)+(m<<3)>>2];s=+g[c+(i<<6)+(m<<3)+4>>2];l=l+((j+p)*r-(n-q)*s);k=k+(r*(n+q)+(j-p)*s);m=m+1|0;}while((m|0)<6);m=ca(i,d)|0;g[a+(m<<3)>>2]=l;g[a+(m<<3)+4>>2]=k;i=i+1|0;}while((i|0)<(e|0));return}function vub(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((c|0)<64&(d|0)>0){e=c}else{return}do{c=0;do{g[a+(e<<8)+(c<<3)>>2]=+g[b+(c<<8)+(e<<2)>>2];g[a+(e<<8)+(c<<3)+4>>2]=+g[b+9728+(c<<8)+(e<<2)>>2];c=c+1|0;}while((c|0)<(d|0));e=e+1|0;}while((e|0)<64);return}function wub(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((c|0)<64&(d|0)>0){e=c}else{return}do{c=0;do{g[a+(c<<8)+(e<<2)>>2]=+g[b+(e<<8)+(c<<3)>>2];g[a+9728+(c<<8)+(e<<2)>>2]=+g[b+(e<<8)+(c<<3)+4>>2];c=c+1|0;}while((c|0)<(d|0));e=e+1|0;}while((e|0)<64);return}function xub(a,b,c,d,e,f,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=+h;i=i|0;var j=0.0,k=0.0,l=0.0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0,u=0,v=0.0,w=0.0;j=h*.6514390707015991;k=h*.5647181272506714;l=h*.4895416498184204;if((i|0)<=0){return}m=d+4|0;n=0;do{h=+g[b+(n<<3)>>2];o=+g[d>>2];p=+g[b+(n<<3)+4>>2];q=+g[m>>2];r=h*o-p*q;s=o*p+h*q;t=n+2|0;u=n+5|0;q=+g[c+(t<<3)>>2];h=+g[c+(t<<3)+4>>2];p=+g[e>>2];o=+g[e+4>>2];v=q*p-h*o-r*j;w=h*p+q*o-s*j;g[c+(u<<3)>>2]=r+j*v;g[c+(u<<3)+4>>2]=s+j*w;t=n+1|0;s=+g[c+296+(t<<3)>>2];r=+g[c+296+(t<<3)+4>>2];o=+g[e+8>>2];q=+g[e+12>>2];p=s*o-r*q-v*k;h=r*o+s*q-w*k;g[c+296+(u<<3)>>2]=v+k*p;g[c+296+(u<<3)+4>>2]=w+k*h;w=+g[c+592+(n<<3)>>2];v=+g[c+592+(n<<3)+4>>2];q=+g[e+16>>2];s=+g[e+20>>2];o=w*q-v*s-p*l;r=v*q+w*s-h*l;g[c+592+(u<<3)>>2]=p+l*o;g[c+592+(u<<3)+4>>2]=h+l*r;u=f+(n<<2)|0;g[a+(n<<3)>>2]=o*+g[u>>2];g[a+(n<<3)+4>>2]=r*+g[u>>2];n=n+1|0;}while((n|0)<(i|0));return}function yub(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0;f=+g[d>>2];h=+g[d+4>>2];i=+g[d+8>>2];j=+g[d+12>>2];if((e|0)<=0){return}d=0;k=+g[c+12>>2];l=+g[c+8>>2];m=+g[c+4>>2];n=+g[c>>2];do{c=a+(d<<3)|0;o=+g[c>>2];p=a+(d<<3)+4|0;q=+g[p>>2];r=b+(d<<3)|0;s=+g[r>>2];t=b+(d<<3)+4|0;u=+g[t>>2];n=f+n;m=h+m;l=i+l;k=j+k;g[c>>2]=n*o+l*s;g[p>>2]=n*q+l*u;g[r>>2]=m*o+k*s;g[t>>2]=m*q+k*u;d=d+1|0;}while((d|0)<(e|0));return}function zub(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0.0,B=0,C=0.0;f=+g[d>>2];h=+g[d+16>>2];i=+g[d+4>>2];j=+g[d+20>>2];k=+g[d+8>>2];l=+g[d+24>>2];m=+g[d+12>>2];n=+g[d+28>>2];if((e|0)<=0){return}o=+g[c+28>>2];p=+g[c+12>>2];q=+g[c+24>>2];r=+g[c+8>>2];d=0;s=+g[c+20>>2];t=+g[c+4>>2];u=+g[c+16>>2];v=+g[c>>2];do{c=a+(d<<3)|0;w=+g[c>>2];x=a+(d<<3)+4|0;y=+g[x>>2];z=b+(d<<3)|0;A=+g[z>>2];B=b+(d<<3)+4|0;C=+g[B>>2];v=f+v;t=i+t;r=k+r;p=m+p;u=h+u;s=j+s;q=l+q;o=n+o;g[c>>2]=v*w+r*A-u*y-q*C;g[x>>2]=q*A+(u*w+(v*y+r*C));g[z>>2]=t*w+p*A-s*y-o*C;g[B>>2]=o*A+(s*w+(t*y+p*C));d=d+1|0;}while((d|0)<(e|0));return}function Aub(b){b=b|0;var e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0.0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0,E=0.0,F=0,G=0,H=0.0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;e=b|0;f=c[e>>2]|0;h=c[f+72>>2]|0;i=(h|0)/(c[f+416>>2]|0)|0;j=c[f+436>>2]|0;do{if((j|0)==0){if((h|0)==0){k=(c[f+412>>2]|0)/2|0;break}else{l=((h|0)/8|0)+4e3|0;m=((h|0)/32|0)+12e3|0;n=(l|0)>(m|0)?m:l;l=(c[f+412>>2]|0)/2|0;k=(n|0)>(l|0)?l:n;break}}else{k=j}}while(0);o=+(k|0);p=o/7500.0;q=+Z(o*.0007600000244565308)*13.300000190734863+ +Z(p*p)*3.5;k=pJb(3616)|0;c[b+40>>2]=k;c[k>>2]=i;j=c[e>>2]|0;f=j+412|0;h=(i<<10|0)/(c[f>>2]|0)|0;c[k+4>>2]=h;p=+(c[f>>2]|0)*2.0;g[k+12>>2]=o*8192.0/p;g[k+16>>2]=o*12288.0/p;n=6144-h|0;h=n-((n|0)%8|0)|0;c[b+32>>2]=h;c[k+8>>2]=h;h=k+28|0;p=+(i|0);i=b+24|0;o=p<=22.0?1.5:2.0;n=c[b+20>>2]|0;b=c[f>>2]|0;f=0;do{l=c[n+(f<<2)>>2]|0;r=+(b|0);m=(f|0)!=0;s=r/(m?256.0:2048.0);t=p*(m?128.0:1024.0)/r*1.1799999475479126*.024000000208616257/q;r=m?2.0:3.0;u=m?1.5:o;m=c[(c[i>>2]|0)+(f<<2)>>2]|0;v=(m|0)>0;if(v){w=0.0;x=0;y=0;while(1){z=(d[l+x|0]|0)+y|0;A=s*+(z-1|0);B=A/7500.0;C=+Z(A*.0007600000244565308)*13.300000190734863+ +Z(B*B)*3.5;g[h+(f*1792|0)+(x*28|0)+4>>2]=(w+C)*.5;D=x+1|0;if((D|0)<(m|0)){w=C;x=D;y=z}else{break}}}y=m-1|0;if((y|0)>0){x=h+(f*1792|0)+4|0;z=0;while(1){D=z+1|0;w=+g[h+(f*1792|0)+(D*28|0)+4>>2]- +g[x>>2];C=-0.0-w;g[h+(f*1792|0)+(z*28|0)+8>>2]=+T(+10.0,+(w*-3.0));g[h+(f*1792|0)+(z*28|0)+16>>2]=+T(+10.0,+(w*-1.5));g[h+(f*1792|0)+(z*28|0)+12>>2]=+T(+10.0,+(r*C));g[h+(f*1792|0)+(z*28|0)+20>>2]=+T(+10.0,+(u*C));C=1.0/(+ad(+(t*w/+(d[l+z|0]|0|0)))+ -1.5);if(C<.003162277629598975){E=.003162277629598975}else{E=C>.7943282127380371?.7943282127380371:C}g[h+(f*1792|0)+(z*28|0)+24>>2]=E;if((D|0)<(y|0)){z=D}else{break}}}if(v){z=0;y=0;while(1){t=s*+(z|0)/1.0e3;u=t+ -3.4;r=t+ -8.7;C=+T(+t,+-.8)*3.64- +$(u*u*-.6)*6.8+ +$(r*r*-.15)*6.0+t*t*t*t*76.0e-5;x=l+y|0;D=a[x]|0;if((D&255)>>>0>1>>>0){F=D&255;t=C;D=1;while(1){r=s*+(D+z|0)/1.0e3;u=r+ -3.4;w=r+ -8.7;B=+T(+r,+-.8)*3.64- +$(u*u*-.6)*6.8+ +$(w*w*-.15)*6.0+r*r*r*r*76.0e-5;r=t>B?B:t;G=D+1|0;if((G|0)<(F|0)){t=r;D=G}else{H=r;break}}}else{H=C}g[h+(f*1792|0)+(y*28|0)>>2]=H+5.242379665374756;D=y+1|0;if((D|0)<(m|0)){z=(d[x]|0)+z|0;y=D}else{break}}}f=f+1|0;}while((f|0)<2);f=pJb((c[j+416>>2]|0)*9340|0)|0;c[k+3612>>2]=f;k=c[e>>2]|0;e=c[k+416>>2]|0;if((e|0)<=0){return 0}j=k+72|0;h=k+80|0;if((c[k+88>>2]&2|0)==0){I=0}else{k=0;do{g[f+(k*9340|0)+9236>>2]=+g[697476+(((c[h>>2]|0)/118|0)<<3)>>2];g[f+(k*9340|0)+9240>>2]=10.0;g[f+(k*9340|0)+9244>>2]=10.0;g[f+(k*9340|0)+9248>>2]=10.0;g[f+(k*9340|0)+9252>>2]=10.0;g[f+(k*9340|0)+9256>>2]=10.0;g[f+(k*9340|0)+9260>>2]=10.0;g[f+(k*9340|0)+9264>>2]=10.0;g[f+(k*9340|0)+9268>>2]=10.0;g[f+(k*9340|0)+9272>>2]=10.0;g[f+(k*9340|0)+9276>>2]=10.0;g[f+(k*9340|0)+9280>>2]=10.0;g[f+(k*9340|0)+9284>>2]=10.0;g[f+(k*9340|0)+9288>>2]=10.0;g[f+(k*9340|0)+9292>>2]=10.0;g[f+(k*9340|0)+9296>>2]=10.0;g[f+(k*9340|0)+9300>>2]=10.0;g[f+(k*9340|0)+9304>>2]=10.0;g[f+(k*9340|0)+9308>>2]=10.0;g[f+(k*9340|0)+9312>>2]=10.0;g[f+(k*9340|0)+9316>>2]=10.0;g[f+(k*9340|0)+9320>>2]=10.0;g[f+(k*9340|0)+9324>>2]=10.0;g[f+(k*9340|0)+9328>>2]=10.0;g[f+(k*9340|0)+9332>>2]=10.0;k=k+1|0;}while((k|0)<(e|0));return 0}do{k=((c[j>>2]|0)/(e|0)|0|0)/1e3|0;h=1;while(1){if((h|0)>=13){J=160;K=160;L=12;M=12;break}N=c[697560+(h<<3)>>2]|0;if((((N|0)<(k|0)?k:N)|0)==(k|0)){h=h+1|0}else{O=24;break}}if((O|0)==24){O=0;i=h-1|0;J=N;K=c[697560+(i<<3)>>2]|0;L=h;M=i}g[f+(I*9340|0)+9236>>2]=+g[697564+(((J-k|0)>(k-K|0)?M:L)<<3)>>2];g[f+(I*9340|0)+9240>>2]=10.0;g[f+(I*9340|0)+9244>>2]=10.0;g[f+(I*9340|0)+9248>>2]=10.0;g[f+(I*9340|0)+9252>>2]=10.0;g[f+(I*9340|0)+9256>>2]=10.0;g[f+(I*9340|0)+9260>>2]=10.0;g[f+(I*9340|0)+9264>>2]=10.0;g[f+(I*9340|0)+9268>>2]=10.0;g[f+(I*9340|0)+9272>>2]=10.0;g[f+(I*9340|0)+9276>>2]=10.0;g[f+(I*9340|0)+9280>>2]=10.0;g[f+(I*9340|0)+9284>>2]=10.0;g[f+(I*9340|0)+9288>>2]=10.0;g[f+(I*9340|0)+9292>>2]=10.0;g[f+(I*9340|0)+9296>>2]=10.0;g[f+(I*9340|0)+9300>>2]=10.0;g[f+(I*9340|0)+9304>>2]=10.0;g[f+(I*9340|0)+9308>>2]=10.0;g[f+(I*9340|0)+9312>>2]=10.0;g[f+(I*9340|0)+9316>>2]=10.0;g[f+(I*9340|0)+9320>>2]=10.0;g[f+(I*9340|0)+9324>>2]=10.0;g[f+(I*9340|0)+9328>>2]=10.0;g[f+(I*9340|0)+9332>>2]=10.0;I=I+1|0;}while((I|0)<(e|0));return 0}function Bub(b,e,f,h,j,k){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,S=0.0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0.0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;f=i;i=i+4456|0;l=f|0;m=f+40|0;n=f+96|0;o=f+4192|0;p=f+4304|0;q=f+4416|0;r=c[(c[e+40>>2]|0)+3612>>2]|0;mrc(l|0,0,36)|0;e=m;mrc(e|0,0,56)|0;a:do{if((h|0)==0){s=r+(j*9340|0)+9232|0;t=c[s>>2]|0;if((k|0)==2){u=s;v=t;w=36}else{x=s;y=t;w=35}}else{mrc(q|0,0,36)|0;t=0;z=+g[h+44>>2];A=+g[h+48>>2];B=+g[h+124>>2];C=+g[h+52>>2];D=+g[h+56>>2];E=+g[h+116>>2];F=+g[h+60>>2];G=+g[h+64>>2];H=+g[h+108>>2];I=+g[h+68>>2];J=+g[h+72>>2];K=+g[h+100>>2];L=+g[h+76>>2];M=+g[h+80>>2];N=+g[h+92>>2];while(1){O=+g[h+(t+21<<2)>>2];P=+g[h+(t+32<<2)>>2];s=t+1|0;Q=+g[h+(t+30<<2)>>2];S=+g[h+(t+28<<2)>>2];T=+g[h+(t+26<<2)>>2];U=+g[h+(t+24<<2)>>2];g[n+(t<<2)>>2]=(O+(z+P)*-1.7303260184043527e-17+(C+Q)*-1.3495279640235235e-17+(F+S)*-6.732779685849225e-17+(I+T)*-3.0835000291318875e-17+(L+U)*-1.1044240253100168e-16+((A+B)*-.017031719908118248+0.0+(D+E)*.04180720075964928+(G+H)*-.08763240277767181+(J+K)*.1863476037979126+(M+N)*-.6276379823684692))*32768.0;if((s|0)<1024){t=s;z=A;A=C;B=P;C=D;D=F;E=Q;F=G;G=I;H=S;I=J;J=L;K=T;L=M;M=O;N=U}else{break}}t=q|0;N=+g[r+(j*9340|0)+9324>>2];g[p>>2]=N;g[o>>2]=N/+g[r+(j*9340|0)+9316>>2];M=+g[r+(j*9340|0)+9328>>2];g[p+4>>2]=M;g[o+4>>2]=M/+g[r+(j*9340|0)+9320>>2];L=+g[r+(j*9340|0)+9332>>2];g[p+8>>2]=L;g[o+8>>2]=L/N;g[t>>2]=L+(M+(N+0.0));s=n|0;V=0;while(1){W=s+168|0;X=s;N=1.0;do{M=+R(+(+g[X>>2]));N=N>M?N:M;X=X+4|0;}while(X>>>0<W>>>0);W=V+3|0;g[p+(W<<2)>>2]=N;g[r+(j*9340|0)+9240+(V<<2)>>2]=N;Y=q+(((V|0)/3|0)+1<<2)|0;g[Y>>2]=N+ +g[Y>>2];Y=V+1|0;M=+g[p+(Y<<2)>>2];do{if(N>M){Z=N/M}else{L=N*10.0;if(!(M>L)){Z=0.0;break}Z=M/L}}while(0);g[o+(W<<2)>>2]=Z;if((Y|0)<24){s=X;V=Y}else{break}}V=r+(j*9340|0)+9236|0;s=0;do{_=l+(((s|0)/3|0)<<2)|0;do{if((c[_>>2]|0)==0){if(!(+g[o+(s<<2)>>2]>+g[V>>2])){break}c[_>>2]=((s|0)%3|0)+1}}while(0);s=s+1|0;}while((s|0)<27);s=l|0;V=0;_=1;M=+g[t>>2];while(1){N=+g[q+(_<<2)>>2];if((M>N?M:N)<4.0e4&M<N*1.7000000476837158&N<M*1.7000000476837158){do{if((_|0)==1){if((c[s>>2]|0)>=(c[l+4>>2]|0)){break}c[s>>2]=0}}while(0);c[l+(_<<2)>>2]=0;$=0}else{$=c[l+(_<<2)>>2]|0}aa=$+V|0;Y=_+1|0;if((Y|0)<9){V=aa;_=Y;M=N}else{break}}_=c[s>>2]|0;V=c[r+(j*9340|0)+9336>>2]|0;if((_|0)>(V|0)){ba=_}else{c[s>>2]=0;ba=0}do{if((V|0)!=3){if((aa|0)!=(-ba|0)){break}_=r+(j*9340|0)+9232|0;x=_;y=c[_>>2]|0;w=35;break a}}while(0);V=l+4|0;s=c[V>>2]|0;do{if((s|0)==0){ca=0}else{if((ba|0)==0){ca=s;break}c[V>>2]=0;ca=0}}while(0);V=l+8|0;s=c[V>>2]|0;do{if((s|0)==0){da=0}else{if((ca|0)==0){da=s;break}c[V>>2]=0;da=0}}while(0);V=l+12|0;s=c[V>>2]|0;do{if((s|0)==0){ea=0}else{if((da|0)==0){ea=s;break}c[V>>2]=0;ea=0}}while(0);V=l+16|0;s=c[V>>2]|0;do{if((s|0)==0){fa=0}else{if((ea|0)==0){fa=s;break}c[V>>2]=0;fa=0}}while(0);V=l+20|0;s=c[V>>2]|0;do{if((s|0)==0){ga=0}else{if((fa|0)==0){ga=s;break}c[V>>2]=0;ga=0}}while(0);V=l+24|0;s=c[V>>2]|0;do{if((s|0)==0){ha=0}else{if((ga|0)==0){ha=s;break}c[V>>2]=0;ha=0}}while(0);V=l+28|0;s=c[V>>2]|0;do{if((s|0)==0){ia=0}else{if((ha|0)==0){ia=s;break}c[V>>2]=0;ia=0}}while(0);V=l+32|0;if(!((c[V>>2]|0)==0|(ia|0)==0)){c[V>>2]=0}V=r+(j*9340|0)+9232|0;u=V;v=c[V>>2]|0;w=36}}while(0);do{if((w|0)==35){ja=(y|0)==2?3:0;ka=y;la=x}else if((w|0)==36){if((v|0)==0){c[u>>2]=1;ja=2;ka=1;la=u;break}else if((v|0)==3){c[u>>2]=2;ja=2;ka=2;la=u;break}else{ja=2;ka=v;la=u;break}}}while(0);c[m>>2]=ka;c[la>>2]=ja;c[m+4>>2]=k;k=m+16|0;do{if((ka|0)==2){c[k>>2]=8;c[m+12>>2]=0;ja=d[r+(j*9340|0)+9228|0]|0;c[m+20>>2]=1;la=ja>>>1&1^1;u=m+20+(la<<2)|0;c[u>>2]=(c[u>>2]|0)+1;u=(ja&4|0)==0?2:la;la=m+20+(u<<2)|0;c[la>>2]=(c[la>>2]|0)+1;la=(ja&8|0)==0?3:u;u=m+20+(la<<2)|0;c[u>>2]=(c[u>>2]|0)+1;u=(ja&16|0)==0?4:la;la=m+20+(u<<2)|0;c[la>>2]=(c[la>>2]|0)+1;la=(ja&32|0)==0?5:u;u=m+20+(la<<2)|0;c[u>>2]=(c[u>>2]|0)+1;u=(ja&64|0)==0?6:la;la=m+20+(u<<2)|0;c[la>>2]=(c[la>>2]|0)+1;la=m+20+(((ja&128|0)==0?7:u)<<2)|0;c[la>>2]=(c[la>>2]|0)+1;ma=0}else{c[k>>2]=1;c[m+20>>2]=1;la=m+12|0;if((ka|0)==1){c[la>>2]=0;ma=0;break}else{c[la>>2]=1;ma=0;break}}}while(0);while(1){if((ma|0)>=9){na=0;w=46;break}if((c[l+(ma<<2)>>2]|0)==0){ma=ma+1|0}else{na=ma;w=46;break}}if((w|0)==46){a[r+(j*9340|0)+9228|0]=a[152120+na|0]|0;c[r+(j*9340|0)+9336>>2]=c[l+32>>2];nrc(b|0,e|0,56)|0;i=f;return}}function Cub(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,T=0.0,U=0.0,V=0.0,W=0.0,X=0,Y=0.0,Z=0,_=0.0,$=0,aa=0.0,ba=0.0,ca=0,da=0,ea=0.0,fa=0.0,ga=0.0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0,ta=0.0,ua=0.0,va=0.0,wa=0,xa=0.0,ya=0.0,za=0.0,Aa=0,Ba=0,Ca=0.0,Da=0.0,Ea=0.0,Fa=0.0,Ga=0.0,Ha=0.0,Ia=0.0,Ja=0.0,Ka=0.0,La=0.0,Ma=0.0,Na=0.0,Oa=0.0,Pa=0.0,Qa=0.0,Ra=0.0,Sa=0.0,Ta=0,Ua=0.0,Va=0.0,Wa=0,Xa=0.0,Ya=0.0,Za=0.0,_a=0,$a=0,ab=0.0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0.0,gb=0.0,hb=0.0,ib=0,jb=0.0,kb=0.0,lb=0.0,mb=0.0,nb=0.0,ob=0.0,pb=0.0,qb=0.0,rb=0.0,sb=0.0,tb=0,ub=0.0,vb=0.0,wb=0,xb=0,yb=0.0,zb=0,Ab=0,Bb=0.0,Cb=0.0,Db=0.0;j=i;i=i+512|0;k=j|0;l=(Mrb(b,e)|0)+80|0;if((a[l]|0)==0){i=j;return}m=k;n=b+40|0;o=b+24|0;p=b+20|0;q=k|0;s=b+8|0;t=b+36|0;u=b+32|0;b=0;do{v=b+e|0;w=c[f+(b<<2)>>2]|0;x=c[n>>2]|0;y=c[x+3612>>2]|0;z=y+(v*9340|0)|0;mrc(m|0,0,512)|0;A=c[x>>2]|0;do{if((A|0)>32e3){B=0.0}else{C=100.0- +(A|0)*100.0/32.0e3;if(C<50.0){B=50.0;break}B=C}}while(0);A=h+(b*56|0)+16|0;D=c[A>>2]|0;E=(D|0)==8;F=E&1;G=c[(c[o>>2]|0)+(F<<2)>>2]|0;H=c[(c[p>>2]|0)+(F<<2)>>2]|0;I=x+28|0;C=E?.6299999952316284:.5;E=D<<4;if((E|0)>0){J=(G|0)>0;if(J){K=0;L=0;while(1){M=0;N=K;do{O=M+L|0;P=y+(v*9340|0)+(O*36|0)|0;g[P>>2]=0.0;Q=H+M|0;do{if((a[Q]|0)==0){T=0.0;U=0.0;V=0.0}else{W=0.0;X=0;Y=0.0;do{Z=w+(X+N<<2)|0;_=+g[Z>>2];Y=Y+_*_;g[P>>2]=Y;W=W+ +S(+R(+(+g[Z>>2])));X=X+1|0;$=a[Q]|0;}while((X|0)<($&255|0));if(!(Y>0.0)){T=0.0;U=Y;V=W;break}T=+S(+(($&255)>>>0)/Y);U=Y;V=W}}while(0);g[y+(v*9340|0)+(O*36|0)+4>>2]=U*.0012589249527081847;g[y+(v*9340|0)+(O*36|0)+12>>2]=V*+S(T);N=(d[Q]|0)+N|0;M=M+1|0;}while((M|0)<(G|0));M=L+16|0;if((M|0)<(E|0)){K=N;L=M}else{break}}}L=(G|0)>1;K=G-2|0;E=(K|0)>-1;w=h+(b*56|0)|0;H=h+(b*56|0)+4|0;_=B;aa=0.0;ba=0.0;M=0;P=D;while(1){g[q>>2]=+g[y+(v*9340|0)+(M*36|0)>>2];if(L){X=M-1|0;Z=1;do{ca=Z+M|0;da=y+(v*9340|0)+(ca*36|0)+4|0;ea=+g[da>>2];fa=+g[y+(v*9340|0)+((X+Z|0)*36|0)+4>>2]*+g[I+(F*1792|0)+(Z*28|0)+16>>2];g[da>>2]=ea>fa?ea:fa;fa=+g[y+(v*9340|0)+(ca*36|0)>>2];ea=+g[k+(ca-1<<2)>>2]*+g[I+(F*1792|0)+(Z*28|0)+20>>2];g[k+(ca<<2)>>2]=fa>ea?fa:ea;Z=Z+1|0;}while((Z|0)<(G|0))}if(E){Z=M|1;X=K;while(1){N=X+M|0;ca=y+(v*9340|0)+(N*36|0)+4|0;ea=+g[ca>>2];fa=+g[y+(v*9340|0)+((X+Z|0)*36|0)+4>>2]*+g[I+(F*1792|0)+(X*28|0)+8>>2];g[ca>>2]=ea>fa?ea:fa;ca=k+(N<<2)|0;fa=+g[ca>>2];ea=+g[k+(N+1<<2)>>2]*+g[I+(F*1792|0)+(X*28|0)+12>>2];g[ca>>2]=fa>ea?fa:ea;if((X|0)>0){X=X-1|0}else{break}}}if(J){X=(M|0)==0;ea=_;fa=aa;ga=ba;Z=0;do{ca=Z+M|0;N=y+(v*9340|0)+(ca*36|0)+4|0;ha=+g[N>>2];ia=+g[I+(F*1792|0)+(Z*28|0)>>2];ja=ha>ia?ha:ia;g[N>>2]=ja;g[y+(v*9340|0)+(ca*36|0)+8>>2]=ja;do{if((c[w>>2]|0)==3){ka=ja}else{if((c[H>>2]|0)==1&X){ka=ja;break}ia=ja*.009999999776482582;ha=+g[y+(v*9340|0)+4608+(ca*36|0)+8>>2]*2.0;la=ja>ha?ha:ja;ha=ia>la?ia:la;g[N>>2]=ha;ka=ha}}while(0);N=y+(v*9340|0)+(ca*36|0)+20|0;g[N>>2]=0.0;Q=y+(v*9340|0)+(ca*36|0)+24|0;g[Q>>2]=0.0;O=y+(v*9340|0)+(ca*36|0)+16|0;g[O>>2]=0.0;ja=+g[y+(v*9340|0)+(ca*36|0)>>2];if(ja>ka){ha=+lc(+ja);la=ha- +lc(+ka);ia=+g[y+(v*9340|0)+(ca*36|0)+12>>2];if(la<3.0){ma=ha*.5593572854995728+1.3219281435012817;na=la*.5593572854995728+1.3219281435012817;oa=ia*.5593572854995728}else{ma=ha;na=la;oa=ia}g[O>>2]=oa;la=ia*na;g[N>>2]=la;ha=ia*ma;g[Q>>2]=ha;pa=la;qa=ha;ra=oa}else{pa=0.0;qa=0.0;ra=0.0}ea=ea+pa;ga=ga+qa;fa=fa+ra;do{if(C*+g[k+(ca<<2)>>2]>ja){sa=33}else{if(+g[I+(F*1792|0)+(Z*28|0)+24>>2]>1.0){sa=33;break}c[y+(v*9340|0)+(ca*36|0)+32>>2]=1}}while(0);if((sa|0)==33){sa=0;c[y+(v*9340|0)+(ca*36|0)+32>>2]=0}Z=Z+1|0;}while((Z|0)<(G|0));ta=ea;ua=fa;va=ga;wa=c[A>>2]|0}else{ta=_;ua=aa;va=ba;wa=P}Z=M+16|0;if((Z|0)<(wa<<4|0)){_=ta;aa=ua;ba=va;M=Z;P=wa}else{xa=ta;ya=ua;za=va;Aa=wa;break}}}else{xa=B;ya=0.0;za=0.0;Aa=D}g[(c[s>>2]|0)+(v*2564|0)+2560>>2]=xa;P=c[t>>2]|0;M=c[u>>2]|0;H=(Aa|0)==8;ba=H?.75:.949999988079071;w=c[x+4>>2]|0;J=x+8|0;K=(c[J>>2]|0)+(w-P)|0;if((K|0)<0){Ba=0}else{Ba=(K|0)>(M|0)?M:K}c[J>>2]=Ba;aa=+(Ba|0)/+(M|0);if(aa<.20000000298023224){Ca=.20000000298023224}else{Ca=aa>ba?ba:aa}J=x+12|0;aa=+g[J>>2];K=x+16|0;ba=+g[K>>2];if(aa>xa){Da=aa}else{Da=ba<xa?ba:xa}_=(H?-.3636363744735718:-.46666666865348816)*((H?-.75:-.8428571224212646)+Ca);g[K>>2]=ba<xa?xa:ba;g[J>>2]=aa<xa?aa:xa;C=+(w|0)*(1.0-_+((H?.8181818127632141:.6666666865348816)*((H?-.2611111104488373:-.3499999940395355)+Ca)-_)/(ba-aa)*(Da-aa));aa=+(M-P+w|0);ba=+(~~(C>aa?aa:C)|0)*1.1799999475479126;w=c[t>>2]|0;P=x+20|0;if((w|0)>0){C=+g[P>>2]/(+(w|0)*1.1799999475479126);if(C<.8500000238418579){Ea=.8500000238418579}else{Ea=C>1.149999976158142?1.149999976158142:C}Fa=ba*Ea}else{Fa=ba}g[P>>2]=ba;P=c[A>>2]|0;a:do{if(Fa<xa){if((P<<4|0)>0){w=(G|0)>0;ba=xa;C=ya;aa=za;M=0;H=P;while(1){if(C==0.0){Ga=0.0}else{_=C*4.0;ja=+ad(+((aa-ba)/_));ha=+ad(+((aa-Fa)/_))-ja;Ga=ha>0.0?ha:0.0}if(w){ha=0.0;ja=0.0;_=0.0;J=0;do{K=J+M|0;E=y+(v*9340|0)+(K*36|0)+4|0;la=+g[E>>2];ia=+g[y+(v*9340|0)+(K*36|0)>>2];do{if(ia>la){Ha=Ga+ +S(+S(la));Ia=Ha*Ha;Ha=Ia*Ia;Ia=ia*+g[I+(F*1792|0)+(J*28|0)+24>>2];if(!(Ha>Ia)){Ja=Ha;break}L=y+(v*9340|0)+(K*36|0)+32|0;if((c[L>>2]|0)==0){Ja=Ha;break}c[L>>2]=2;Ja=la>Ia?la:Ia}else{Ja=la}}while(0);g[E>>2]=Ja;L=y+(v*9340|0)+(K*36|0)+20|0;g[L>>2]=0.0;Z=y+(v*9340|0)+(K*36|0)+24|0;g[Z>>2]=0.0;X=y+(v*9340|0)+(K*36|0)+16|0;g[X>>2]=0.0;if(ia>Ja){la=+lc(+ia);W=la- +lc(+Ja);Y=+g[y+(v*9340|0)+(K*36|0)+12>>2];if(W<3.0){Ka=la*.5593572854995728+1.3219281435012817;La=W*.5593572854995728+1.3219281435012817;Ma=Y*.5593572854995728}else{Ka=la;La=W;Ma=Y}g[X>>2]=Ma;W=Y*La;g[L>>2]=W;la=Y*Ka;g[Z>>2]=la;Na=W;Oa=la;Pa=Ma}else{Na=0.0;Oa=0.0;Pa=0.0}ha=ha+Na;_=_+Oa;ja=ja+Pa;J=J+1|0;}while((J|0)<(G|0));Qa=ha;Ra=ja;Sa=_;Ta=c[A>>2]|0}else{Qa=0.0;Ra=0.0;Sa=0.0;Ta=H}J=M+16|0;if((J|0)<(Ta<<4|0)){ba=Qa;C=Ra;aa=Sa;M=J;H=Ta}else{Ua=Qa;Va=Ga;Wa=Ta;break}}}else{Ua=xa;Va=+r;Wa=P}aa=Fa*.05000000074505806;H=(G|0)>0;M=0;C=0.0;ba=Va;ga=0.0;fa=Ua;w=Wa;J=Wa;while(1){if((M|0)>=2){Xa=C;Ya=ga;Za=fa;_a=w;$a=J;break}ca=w<<4;if((ca|0)>0){ea=0.0;la=0.0;W=0.0;Z=0;while(1){if(H){Y=ea;Ia=la;Ha=W;L=0;while(1){X=L+Z|0;if((c[y+(v*9340|0)+(X*36|0)+32>>2]|0)==2){ab=Ha;bb=Ia;cb=Y}else{ab=Ha+ +g[y+(v*9340|0)+(X*36|0)+24>>2];bb=Ia+ +g[y+(v*9340|0)+(X*36|0)+16>>2];cb=Y+ +g[y+(v*9340|0)+(X*36|0)+20>>2]}X=L+1|0;if((X|0)<(G|0)){Y=cb;Ia=bb;Ha=ab;L=X}else{db=cb;eb=bb;fb=ab;break}}}else{db=ea;eb=la;fb=W}L=Z+16|0;if((L|0)<(ca|0)){ea=db;la=eb;W=fb;Z=L}else{break}}W=Fa-(fa-db);la=W>0.0?W:0.0;if(eb>0.0){if(eb==0.0){gb=0.0}else{W=eb*4.0;ea=+ad(+((fb-db)/W));_=+ad(+((fb-la)/W))-ea;gb=_>0.0?_:0.0}hb=ba+gb;ib=1}else{hb=ba;ib=0}_=0.0;ea=ga;Z=0;ca=J;while(1){if(H){W=_;la=ea;L=0;do{K=L+Z|0;E=y+(v*9340|0)+(K*36|0)|0;if(ib){X=y+(v*9340|0)+(K*36|0)+4|0;ja=+g[X>>2];ha=+g[E>>2];do{if(ha>ja){Ha=hb+ +S(+S(ja));Ia=Ha*Ha;Ha=Ia*Ia;Ia=ha*+g[I+(F*1792|0)+(L*28|0)+24>>2];if(!(Ha>Ia)){jb=Ha;break}Q=y+(v*9340|0)+(K*36|0)+32|0;if((c[Q>>2]|0)==0){jb=Ha;break}c[Q>>2]=2;jb=ja>Ia?ja:Ia}else{jb=ja}}while(0);g[X>>2]=jb;kb=ha;lb=jb}else{kb=+g[E>>2];lb=+g[y+(v*9340|0)+(K*36|0)+4>>2]}Q=y+(v*9340|0)+(K*36|0)+20|0;g[Q>>2]=0.0;N=y+(v*9340|0)+(K*36|0)+24|0;g[N>>2]=0.0;O=y+(v*9340|0)+(K*36|0)+16|0;g[O>>2]=0.0;if(kb>lb){ja=+lc(+kb);Ia=ja- +lc(+lb);Ha=+g[y+(v*9340|0)+(K*36|0)+12>>2];if(Ia<3.0){mb=ja*.5593572854995728+1.3219281435012817;nb=Ia*.5593572854995728+1.3219281435012817;ob=Ha*.5593572854995728}else{mb=ja;nb=Ia;ob=Ha}g[O>>2]=ob;Ia=Ha*nb;g[Q>>2]=Ia;g[N>>2]=Ha*mb;pb=Ia;qb=ob}else{pb=0.0;qb=0.0}W=W+pb;Ia=qb/lb;g[y+(v*9340|0)+(K*36|0)+28>>2]=Ia;la=la+Ia;L=L+1|0;}while((L|0)<(G|0));rb=W;sb=la;tb=c[A>>2]|0}else{rb=_;sb=ea;tb=ca}L=Z+16|0;if((L|0)<(tb<<4|0)){_=rb;ea=sb;Z=L;ca=tb}else{ub=rb;vb=sb;wb=tb;xb=tb;yb=hb;break}}}else{ub=0.0;vb=ga;wb=w;xb=J;yb=ba}ea=Fa-ub;if(+R(+ea)>aa){Xa=ea;Ya=vb;Za=ub;_a=wb;$a=xb;break}else{M=M+1|0;C=ea;ba=yb;ga=vb;fa=ub;w=wb;J=xb}}if(Za<Fa*1.149999976158142){fa=1.0/Ya;J=_a<<4;if((J|0)>0){zb=0}else{Ab=$a;break}while(1){if(H){w=0;do{M=w+zb|0;ga=+g[y+(v*9340|0)+(M*36|0)+16>>2];if(ga>.5){ca=y+(v*9340|0)+(M*36|0)+4|0;ba=+g[ca>>2];C=ba*+ad(+(Xa*fa*+g[y+(v*9340|0)+(M*36|0)+28>>2]/ga));ga=+g[I+(F*1792|0)+(w*28|0)+24>>2]*+g[y+(v*9340|0)+(M*36|0)>>2];do{if(C>ga){if((c[y+(v*9340|0)+(M*36|0)+32>>2]|0)!=1){Bb=C;break}Bb=ba>ga?ba:ga}else{Bb=C}}while(0);g[ca>>2]=Bb}w=w+1|0;}while((w|0)<(G|0))}w=zb+16|0;if((w|0)<(J|0)){zb=w}else{Ab=$a;break a}}}if(!(Za>Fa)){Ab=$a;break}J=_a<<4;H=(J|0)>0;fa=Za;w=G;while(1){M=w-1|0;if((w|0)==0){Ab=$a;break a}if(H){Z=I+(F*1792|0)+(M*28|0)+24|0;C=fa;L=0;while(1){N=L+M|0;do{if((c[y+(v*9340|0)+(N*36|0)+32>>2]|0)==0){Cb=C}else{if(!(+g[Z>>2]<.7943282127380371)){Cb=C;break}g[Z>>2]=.7943282127380371;g[y+(v*9340|0)+(N*36|0)+4>>2]=+g[y+(v*9340|0)+(N*36|0)>>2]*.7943282127380371;Cb=C+(+g[y+(v*9340|0)+(N*36|0)+16>>2]*1.5- +g[y+(v*9340|0)+(N*36|0)+20>>2])}}while(0);N=L+16|0;if((N|0)<(J|0)){C=Cb;L=N}else{Db=Cb;break}}}else{Db=fa}if(Db>Fa){fa=Db;w=M}else{Ab=$a;break}}}else{Ab=P}}while(0);P=Ab<<4;if((P|0)>0){F=(G|0)>0;I=0;do{if(F){A=c[s>>2]|0;x=0;do{D=x+I|0;g[A+(v*2564|0)+(D*20|0)+8>>2]=+g[y+(v*9340|0)+(D*36|0)+4>>2];g[A+(v*2564|0)+(D*20|0)+4>>2]=+g[y+(v*9340|0)+(D*36|0)>>2];x=x+1|0;}while((x|0)<(G|0))}I=I+16|0;}while((I|0)<(P|0))}nrc(y+(v*9340|0)+4608|0,z|0,4608)|0;b=b+1|0;}while((b|0)<(d[l]|0));i=j;return}function Dub(a){a=a|0;var b=0;b=a+40|0;mJb((c[b>>2]|0)+3612|0);mJb(b);return}function Eub(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((e|0)<(f|0)){i=e;do{b[g+(i<<1)>>1]=3072-(a[c+i|0]<<7);i=i+1|0;}while((i|0)<(f|0))}i=~f;c=e;j=d[8779912+e|0]|0;while(1){e=b[g+(c<<1)>>1]|0;k=j+1|0;l=d[1445128+k|0]|0;m=(l|0)>(f|0)?f:l;n=c+1|0;if((n|0)<(m|0)){o=~l;p=(i|0)>(o|0)?i:o;o=e<<16>>16;q=n;do{r=b[g+(q<<1)>>1]|0;s=(o|0)>(r|0)?o:r;t=s-(o+1+r>>1)|0;o=s+(d[1443432+((t|0)>255?255:t)|0]|0)|0;q=q+1|0;}while((q|0)<(m|0));u=o&65535;v=~p}else{u=e;v=n}b[h+(j<<1)>>1]=u;if((l|0)<(f|0)){c=v;j=k}else{break}}return}function Fub(f,g,h,j,k,l,m,n,o,p,q,r){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;s=i;i=i+104|0;t=s|0;u=a[8779912+h|0]|0;h=u&255;v=(d[8779912+(j-1)|0]|0)+1|0;a:do{if(u<<24>>24==0){j=b[g>>1]|0;w=b[g+2>>1]|0;x=w<<16>>16;y=((j<<16>>16)+256|0)==(x|0)?384:0;b[t>>1]=(j&65535)-k-y;j=b[g+4>>1]|0;do{if((x+256|0)==(j<<16>>16|0)){z=384}else{if(!(w<<16>>16>j<<16>>16)){z=y;break}A=y-64|0;z=(A|0)>0?A:0}}while(0);b[t+2>>1]=(w&65535)-(z+k);y=(l|0)==0;j=c[f+8>>2]|0;b:do{if(y){x=2;A=z;while(1){B=b[g+(x<<1)>>1]|0;C=b[g+(x+1<<1)>>1]|0;do{if(((B<<16>>16)+256|0)==(C<<16>>16|0)){D=384}else{if(!(B<<16>>16>C<<16>>16)){D=A;break}E=A-64|0;D=(E|0)>0?E:0}}while(0);C=B<<16>>16;E=C-k|0;b[t+(x<<1)>>1]=E-D;F=x+1|0;if(!(B<<16>>16>(b[g+(F<<1)>>1]|0))){G=C;H=E;I=D;J=F;break b}if((F|0)<7){x=F;A=D}else{G=C;H=E;I=D;J=7;break}}}else{A=2;x=z;while(1){E=(A|0)==6;do{if(E){C=b[g+12>>1]|0;F=C-k|0;b[t+(A<<1)>>1]=F-x;K=x;L=C;M=F;N=13}else{F=b[g+(A<<1)>>1]|0;C=b[g+(A+1<<1)>>1]|0;if(((F<<16>>16)+256|0)==(C<<16>>16|0)){O=F<<16>>16;P=O-k|0;b[t+(A<<1)>>1]=P+65152;Q=384;R=O;S=P}else{if(F<<16>>16>C<<16>>16){C=x-64|0;T=(C|0)>0?C:0}else{T=x}C=F<<16>>16;P=C-k|0;b[t+(A<<1)>>1]=P-T;if(E){K=T;L=C;M=P;N=13;break}else{Q=T;R=C;S=P}}P=A+1|0;if(F<<16>>16>(b[g+(P<<1)>>1]|0)){U=P;V=Q;W=R;X=S}else{G=R;H=S;I=Q;J=P;break b}}}while(0);if((N|0)==13){N=0;U=A+1|0;V=K;W=L;X=M}if((U|0)<7){A=U;x=V}else{G=W;H=X;I=V;J=7;break}}}}while(0);w=G-j|0;x=v>>>0>22>>>0?22:v;if((J|0)>=(x|0)){Y=w;Z=H;_=22;break}A=c[f+16>>2]|0;E=c[f+12>>2]|0;if(y){B=J;P=I;F=H;C=w;while(1){O=b[g+(B<<1)>>1]|0;$=O<<16>>16;aa=B+1|0;ba=b[g+(aa<<1)>>1]|0;ca=ba<<16>>16;do{if((B|0)<7){if(($+256|0)==(ca|0)){da=384;break}if(!(O<<16>>16>ba<<16>>16)){da=P;break}ea=P-64|0;da=(ea|0)>0?ea:0}else{if((B|0)>=20){ea=P-128|0;da=(ea|0)>0?ea:0;break}if(($+256|0)==(ca|0)){da=320;break}if(!(O<<16>>16>ba<<16>>16)){da=P;break}ea=P-64|0;da=(ea|0)>0?ea:0}}while(0);ba=F-A|0;ca=O<<16>>16;$=ca-k|0;ea=(ba|0)>($|0)?ba:$;$=C-E|0;ba=ca-j|0;ca=($|0)>(ba|0)?$:ba;ba=ea-da|0;b[t+(B<<1)>>1]=(ba|0)>(ca|0)?ba:ca;if((aa|0)<(x|0)){B=aa;P=da;F=ea;C=ca}else{Y=ca;Z=ea;_=22;break a}}}else{fa=J;ga=I;ha=H;ia=w}while(1){do{if((fa|0)==6){ja=ga;ka=b[g+12>>1]|0;la=7}else{C=b[g+(fa<<1)>>1]|0;F=C<<16>>16;P=fa+1|0;B=b[g+(P<<1)>>1]|0;y=B<<16>>16;if((fa|0)<7){if((F+256|0)==(y|0)){ja=384;ka=C;la=P;break}if(!(C<<16>>16>B<<16>>16)){ja=ga;ka=C;la=P;break}ea=ga-64|0;ja=(ea|0)>0?ea:0;ka=C;la=P;break}if((fa|0)>=20){ea=ga-128|0;ja=(ea|0)>0?ea:0;ka=C;la=P;break}if((F+256|0)==(y|0)){ja=320;ka=C;la=P;break}if(!(C<<16>>16>B<<16>>16)){ja=ga;ka=C;la=P;break}B=ga-64|0;ja=(B|0)>0?B:0;ka=C;la=P}}while(0);aa=ha-A|0;O=ka<<16>>16;P=O-k|0;C=(aa|0)>(P|0)?aa:P;P=ia-E|0;aa=O-j|0;O=(P|0)>(aa|0)?P:aa;aa=C-ja|0;b[t+(fa<<1)>>1]=(aa|0)>(O|0)?aa:O;if((la|0)<(x|0)){fa=la;ga=ja;ha=C;ia=O}else{Y=O;Z=C;_=22;break}}}else{Y=(c[f+32>>2]<<8)+768|0;Z=(c[f+28>>2]<<8)+768|0;_=h}}while(0);if(_>>>0<v>>>0){ia=c[f+16>>2]|0;ha=c[f+12>>2]|0;ja=c[f+8>>2]|0;ga=_;_=Z;Z=Y;do{Y=_-ia|0;la=b[g+(ga<<1)>>1]|0;fa=la-k|0;_=(Y|0)>(fa|0)?Y:fa;fa=Z-ha|0;Y=la-ja|0;Z=(fa|0)>(Y|0)?fa:Y;b[t+(ga<<1)>>1]=(_|0)>(Z|0)?_:Z;ga=ga+1|0;}while((ga|0)<(v|0))}if(h>>>0<v>>>0){ga=c[f+20>>2]|0;Z=c[f>>2]|0;_=c[f+4>>2]|0;f=h;do{ja=ga-(b[g+(f<<1)>>1]|0)|0;if((ja|0)>0){ha=t+(f<<1)|0;k=(e[ha>>1]|0)+(ja>>>2)&65535;b[ha>>1]=k;ma=k}else{ma=b[t+(f<<1)>>1]|0}k=b[1443696+((f>>_)*6|0)+(Z<<1)>>1]|0;b[r+(f<<1)>>1]=(k&65535|0)>(ma<<16>>16|0)?k:ma;f=f+1|0;}while((f|0)<(v|0))}if(!(m>>>0<2>>>0)){na=0;i=s;return na|0}if((n|0)>8){na=-1;i=s;return na|0}if((n|0)>0){oa=h;pa=0}else{na=0;i=s;return na|0}while(1){h=(d[o+pa|0]|0)+oa|0;if((h|0)>49){na=-1;N=63;break}m=p+pa|0;v=a[m]|0;if((v&255|0)>(50-h|0)){na=-1;N=63;break}f=a[q+pa|0]|0;ma=((f&255)<<7)+((f&255)>>>0>3>>>0?-384:-512)&65535;if(v<<24>>24==0){qa=h}else{v=h;h=0;while(1){f=v+1|0;Z=r+(v<<1)|0;b[Z>>1]=ma+(b[Z>>1]|0);Z=h+1|0;if((Z|0)<(d[m]|0)){v=f;h=Z}else{qa=f;break}}}h=pa+1|0;if((h|0)<(n|0)){oa=qa;pa=h}else{na=0;N=63;break}}if((N|0)==63){i=s;return na|0}return 0}function Gub(){var a=0,b=0,c=0,e=0,f=0;a=0;b=0;while(1){c=a+1|0;e=d[1445128+c|0]|0;if((b|0)<(e|0)){mrc(8779912+b|0,a&255|0,e-b|0)|0;f=e}else{f=b}if((c|0)<50){a=c;b=f}else{break}}return}function Hub(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;do{if((d-2|0)>>>0>14>>>0){f=a+8|0}else{g=a|0;c[g>>2]=d;h=1<<d;i=hJb(h<<1)|0;j=a+8|0;c[j>>2]=i;if((i|0)==0){f=j;break}i=hJb(h<<2)|0;c[a+12>>2]=i;if((i|0)==0){f=j;break}i=a+4|0;c[i>>2]=e;k=a+56|0;c[k>>2]=0;c[a+32>>2]=632;c[a+36>>2]=286;c[a+40>>2]=2274;c[a+44>>2]=1984;c[a+48>>2]=1144;c[a+52>>2]=646;do{if((d|0)<4){l=0}else{m=4;do{n=1<<m;o=6.283185307179586/+(n|0);p=c[1405872+(m<<2)>>2]|0;q=(n|0)/4|0;do{if(!((n|0)<-3)){r=0;do{s=Lc(+(+U(o*+(r|0))*32768.0))|0;if((s|0)<-32767){t=-32767}else{t=(s|0)>32767?32767:s&65535}b[p+(r<<1)>>1]=t;r=r+1|0;}while((r|0)<=(q|0));if((n|0)<=7){break}r=(n|0)/2|0;s=1;do{b[p+(r-s<<1)>>1]=b[p+(s<<1)>>1]|0;s=s+1|0;}while((s|0)<(q|0))}}while(0);m=m+1|0;}while((m|0)<=(d|0));m=c[k>>2]|0;if((m|0)!=2){l=m;break}m=1<<c[g>>2];if((m|0)<=0){u=0;return u|0}q=m-1|0;p=c[i>>2]|0;n=c[j>>2]|0;s=0;while(1){r=m;v=s;a:while(1){w=r;while(1){if((w|0)<33){break a}x=(w|0)/2|0;if((x|0)>(v|0)){w=x}else{break}}y=(w*3|0|0)/4|0;r=(w|0)/4|0;v=v-((y|0)>(v|0)?x:y)|0}if((v|0)>15){r=0;do{y=(c[1960944+(r<<2)>>2]|0)+s&65535;b[n+((q&-(Kub(r+s|0,m,p)|0))<<1)>>1]=y;r=r+1|0;}while((r|0)<16)}else{r=0;do{v=r+s|0;b[n+((q&-(Kub(v,m,p)|0))<<1)>>1]=v>>>1&3|v&65528|v<<2&4;r=r+1|0;}while((r|0)<16)}r=s+16|0;if((r|0)<(m|0)){s=r}else{u=0;break}}return u|0}}while(0);if((h|0)<=0){u=0;return u|0}g=c[i>>2]|0;k=h-1|0;s=c[j>>2]|0;if((l|0)==1){m=0;while(1){b[s+((k&-(Kub(m,h,g)|0))<<1)>>1]=m>>>1&1|m&65532|m<<1&2;p=m+1|0;if((p|0)<(h|0)){m=p}else{u=0;break}}return u|0}else{m=0;while(1){b[s+((k&-(Kub(m,h,g)|0))<<1)>>1]=m;j=m+1|0;if((j|0)<(h|0)){m=j}else{u=0;break}}return u|0}}}while(0);mJb(f);mJb(a+12|0);u=-1;return u|0}function Iub(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[a+8>>2]|0;g=1<<c[a>>2];h=a+12|0;if((g|0)>0){i=0}else{j=d;k=c[h>>2]|0;l=k;m=g<<2;nrc(j|0,l|0,m)|0;return}do{a=d+(i<<2)|0;n=(c[h>>2]|0)+((e[f+(i<<1)>>1]|0)<<2)|0;y=e[a>>1]|e[a+2>>1]<<16;b[n>>1]=y;b[n+2>>1]=y>>16;i=i+1|0;}while((i|0)<(g|0));j=d;k=c[h>>2]|0;l=k;m=g<<2;nrc(j|0,l|0,m)|0;return}function Jub(a,b){a=a|0;b=b|0;qe[c[1241120+((c[a>>2]|0)-2<<2)>>2]&1023](b);return}function Kub(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if((b|0)<3){d=a&1;return d|0}e=b>>1;if((e&a|0)==0){return(Kub(a,e,c)|0)<<1|0}e=b>>2;b=(Kub(a,e,c)|0)<<2;if(((e&a|0)==0|0)==(c|0)){d=b|1;return d|0}else{d=b-1|0;return d|0}return 0}function Lub(a){a=a|0;mJb(a+8|0);mJb(a+12|0);return}function Mub(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=a|0;d=b[c>>1]|0;e=a+4|0;f=b[e>>1]|0;g=d-f>>1;h=f+d>>1;d=a+12|0;f=b[d>>1]|0;i=a+8|0;j=b[i>>1]|0;k=f-j>>1;l=j+f>>1;b[i>>1]=(h-l|0)>>>1;b[c>>1]=(l+h|0)>>>1;h=a+2|0;l=b[h>>1]|0;c=a+6|0;i=b[c>>1]|0;f=l-i>>1;j=i+l>>1;l=a+10|0;i=b[l>>1]|0;m=a+14|0;a=b[m>>1]|0;n=i-a>>1;o=a+i>>1;b[m>>1]=(f-k|0)>>>1;b[c>>1]=(f+k|0)>>>1;b[d>>1]=(g-n|0)>>>1;b[e>>1]=(n+g|0)>>>1;b[l>>1]=(j-o|0)>>>1;b[h>>1]=(o+j|0)>>>1;return}function Nub(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;c=a|0;d=b[c>>1]|0;e=a+4|0;f=b[e>>1]|0;g=d-f>>1;h=f+d>>1;d=a+12|0;f=b[d>>1]|0;i=a+8|0;j=b[i>>1]|0;k=f-j>>1;l=j+f>>1;f=a+2|0;j=b[f>>1]|0;m=a+6|0;n=b[m>>1]|0;o=j-n>>1;p=n+j>>1;j=a+10|0;n=b[j>>1]|0;q=a+14|0;r=b[q>>1]|0;s=n-r>>1;t=r+n>>1;n=a+16|0;r=b[n>>1]|0;u=a+20|0;v=b[u>>1]|0;w=v+r>>1;x=a+18|0;y=b[x>>1]|0;z=a+22|0;A=b[z>>1]|0;B=A+y>>1;C=a+24|0;D=b[C>>1]|0;E=a+28|0;F=b[E>>1]|0;G=F+D>>1;H=a+26|0;I=b[H>>1]|0;J=a+30|0;a=b[J>>1]|0;K=a+I>>1;L=G-w>>1;M=G+w>>1;w=(l+h|0)>>>1<<16>>16;b[n>>1]=(w-M|0)>>>1;b[c>>1]=(M+w|0)>>>1;w=(p-t|0)>>>1<<16>>16;b[H>>1]=(w-L|0)>>>1;b[j>>1]=(w+L|0)>>>1;L=B-K>>1;w=K+B>>1;B=(h-l|0)>>>1<<16>>16;b[C>>1]=(B-L|0)>>>1;b[i>>1]=(L+B|0)>>>1;B=(t+p|0)>>>1<<16>>16;b[x>>1]=(B-w|0)>>>1;b[f>>1]=(w+B|0)>>>1;B=(r-v|0)>>>1<<16>>16;v=(y-A|0)>>>1<<16>>16;A=((v+B|0)*23170|0)>>15;y=((v-B|0)*23170|0)>>15;B=(D-F|0)>>>1<<16>>16;F=(I-a|0)>>>1<<16>>16;a=((B-F|0)*23170|0)>>15;I=((F+B|0)*23170|0)>>15;B=a-A>>1;F=a+A>>1;A=(s+g|0)>>>1<<16>>16;b[u>>1]=(A-F|0)>>>1;b[e>>1]=(F+A|0)>>>1;A=(o-k|0)>>>1<<16>>16;b[J>>1]=(A-B|0)>>>1;b[q>>1]=(B+A|0)>>>1;A=y-I>>1;B=I+y>>1;y=(g-s|0)>>>1<<16>>16;b[E>>1]=(y-A|0)>>>1;b[d>>1]=(A+y|0)>>>1;y=(o+k|0)>>>1<<16>>16;b[z>>1]=(y-B|0)>>>1;b[m>>1]=(B+y|0)>>>1;return}function Oub(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;c=b[4360113]|0;d=b[4360115]|0;Nub(a);e=a+32|0;f=b[e>>1]|0;g=a+36|0;h=b[g>>1]|0;i=f-h>>1;j=h+f>>1;f=a+44|0;h=b[f>>1]|0;k=a+40|0;l=b[k>>1]|0;m=h-l>>1;n=l+h>>1;h=a+34|0;l=b[h>>1]|0;o=a+38|0;p=b[o>>1]|0;q=l-p>>1;r=p+l>>1;l=a+42|0;p=b[l>>1]|0;s=a+46|0;t=b[s>>1]|0;u=p-t>>1;v=t+p>>1;p=a+48|0;t=b[p>>1]|0;w=a+52|0;x=b[w>>1]|0;y=t-x>>1;z=x+t>>1;t=a+60|0;x=b[t>>1]|0;A=a+56|0;B=b[A>>1]|0;C=x-B>>1;D=B+x>>1;x=a+50|0;B=b[x>>1]|0;E=a+54|0;F=b[E>>1]|0;G=B-F>>1;H=F+B>>1;B=a+58|0;F=b[B>>1]|0;I=a+62|0;J=b[I>>1]|0;K=F-J>>1;L=J+F>>1;F=(n+j|0)>>>1<<16>>16;J=(v+r|0)>>>1<<16>>16;M=(D+z|0)>>>1<<16>>16;N=(L+H|0)>>>1<<16>>16;O=a|0;P=a+2|0;Q=b[P>>1]|0;R=a+16|0;S=b[R>>1]|0;T=a+18|0;U=b[T>>1]|0;V=M-F>>1;W=M+F>>1;F=b[O>>1]|0;b[e>>1]=(F-W|0)>>>1;b[O>>1]=(F+W|0)>>>1;W=U<<16>>16;b[x>>1]=(W-V|0)>>>1;b[T>>1]=(W+V|0)>>>1;V=J-N>>1;W=N+J>>1;J=S<<16>>16;b[p>>1]=(J-V|0)>>>1;b[R>>1]=(J+V|0)>>>1;V=Q<<16>>16;b[h>>1]=(V-W|0)>>>1;b[P>>1]=(V+W|0)>>>1;W=(j-n|0)>>>1<<16>>16;n=(r-v|0)>>>1<<16>>16;v=((n+W|0)*23170|0)>>15;r=((n-W|0)*23170|0)>>15;W=(z-D|0)>>>1<<16>>16;D=(H-L|0)>>>1<<16>>16;L=((W-D|0)*23170|0)>>15;H=((D+W|0)*23170|0)>>15;W=a+8|0;D=a+10|0;z=b[D>>1]|0;n=a+24|0;j=b[n>>1]|0;V=a+26|0;P=b[V>>1]|0;h=L-v>>1;Q=L+v>>1;v=b[W>>1]|0;b[k>>1]=(v-Q|0)>>>1;b[W>>1]=(Q+v|0)>>>1;v=P<<16>>16;b[B>>1]=(v-h|0)>>>1;b[V>>1]=(h+v|0)>>>1;v=r-H>>1;h=H+r>>1;r=j<<16>>16;b[A>>1]=(r-v|0)>>>1;b[n>>1]=(v+r|0)>>>1;r=z<<16>>16;b[l>>1]=(r-h|0)>>>1;b[D>>1]=(h+r|0)>>>1;r=(u+i|0)>>>1<<16>>16;h=c<<16>>16;c=(q+m|0)>>>1<<16>>16;D=d<<16>>16;d=(ca(c,D)|0)+(ca(r,h)|0)>>15;l=(ca(c,h)|0)-(ca(r,D)|0)>>15;r=(K+y|0)>>>1<<16>>16;c=(G+C|0)>>>1<<16>>16;z=(ca(r,h)|0)-(ca(c,D)|0)>>15;v=(ca(c,h)|0)+(ca(r,D)|0)>>15;r=a+4|0;c=a+6|0;n=b[c>>1]|0;A=a+20|0;j=b[A>>1]|0;H=a+22|0;V=b[H>>1]|0;B=z-d>>1;P=z+d>>1;d=b[r>>1]|0;b[g>>1]=(d-P|0)>>>1;b[r>>1]=(P+d|0)>>>1;d=V<<16>>16;b[E>>1]=(d-B|0)>>>1;b[H>>1]=(B+d|0)>>>1;d=l-v>>1;B=v+l>>1;l=j<<16>>16;b[w>>1]=(l-d|0)>>>1;b[A>>1]=(d+l|0)>>>1;l=n<<16>>16;b[o>>1]=(l-B|0)>>>1;b[c>>1]=(B+l|0)>>>1;l=(i-u|0)>>>1<<16>>16;u=(q-m|0)>>>1<<16>>16;m=(ca(u,h)|0)+(ca(l,D)|0)>>15;q=(ca(u,D)|0)-(ca(l,h)|0)>>15;l=(y-K|0)>>>1<<16>>16;K=(G-C|0)>>>1<<16>>16;C=(ca(l,D)|0)-(ca(K,h)|0)>>15;G=(ca(K,D)|0)+(ca(l,h)|0)>>15;h=a+12|0;l=a+14|0;D=b[l>>1]|0;K=a+28|0;y=b[K>>1]|0;u=a+30|0;a=b[u>>1]|0;i=C-m>>1;B=C+m>>1;m=b[h>>1]|0;b[f>>1]=(m-B|0)>>>1;b[h>>1]=(B+m|0)>>>1;m=a<<16>>16;b[I>>1]=(m-i|0)>>>1;b[u>>1]=(i+m|0)>>>1;m=q-G>>1;i=G+q>>1;q=y<<16>>16;b[t>>1]=(q-m|0)>>>1;b[K>>1]=(m+q|0)>>>1;q=D<<16>>16;b[s>>1]=(q-i|0)>>>1;b[l>>1]=(i+q|0)>>>1;return}function Pub(a){a=a|0;Oub(a);Nub(a+64|0);Nub(a+96|0);avb(a,8614912,4);return}function Qub(a){a=a|0;Oub(a);Nub(a+64|0);Nub(a+96|0);avb(a,8614912,4);Oub(a+128|0);Oub(a+192|0);avb(a,8600896,8);return}function Rub(a){a=a|0;var b=0;Oub(a);Nub(a+64|0);Nub(a+96|0);avb(a,8614912,4);Oub(a+128|0);Oub(a+192|0);avb(a,8600896,8);b=a+256|0;Oub(b);Nub(a+320|0);Nub(a+352|0);avb(b,8614912,4);b=a+384|0;Oub(b);Nub(a+448|0);Nub(a+480|0);avb(b,8614912,4);avb(a,8769424,16);return}function Sub(a){a=a|0;var b=0;Rub(a);b=a+512|0;Oub(b);Nub(a+576|0);Nub(a+608|0);avb(b,8614912,4);Oub(a+640|0);Oub(a+704|0);avb(b,8600896,8);b=a+768|0;Oub(b);Nub(a+832|0);Nub(a+864|0);avb(b,8614912,4);Oub(a+896|0);Oub(a+960|0);avb(b,8600896,8);avb(a,8713312,32);return}function Tub(a){a=a|0;Sub(a);Rub(a+1024|0);Rub(a+1536|0);avb(a,8601088,64);return}function Uub(a){a=a|0;Sub(a);Rub(a+1024|0);Rub(a+1536|0);avb(a,8601088,64);Sub(a+2048|0);Sub(a+3072|0);$ub(a,8769808,128);return}function Vub(a){a=a|0;var b=0;Sub(a);Rub(a+1024|0);Rub(a+1536|0);avb(a,8601088,64);Sub(a+2048|0);Sub(a+3072|0);$ub(a,8769808,128);b=a+4096|0;Sub(b);Rub(a+5120|0);Rub(a+5632|0);avb(b,8601088,64);b=a+6144|0;Sub(b);Rub(a+7168|0);Rub(a+7680|0);avb(b,8601088,64);$ub(a,8714080,256);return}function Wub(a){a=a|0;var b=0;Vub(a);b=a+8192|0;Sub(b);Rub(a+9216|0);Rub(a+9728|0);avb(b,8601088,64);Sub(a+10240|0);Sub(a+11264|0);$ub(b,8769808,128);b=a+12288|0;Sub(b);Rub(a+13312|0);Rub(a+13824|0);avb(b,8601088,64);Sub(a+14336|0);Sub(a+15360|0);$ub(b,8769808,128);$ub(a,8602624,512);return}function Xub(a){a=a|0;Wub(a);Vub(a+16384|0);Vub(a+24576|0);$ub(a,8379712,1024);return}function Yub(a){a=a|0;Wub(a);Vub(a+16384|0);Vub(a+24576|0);$ub(a,8379712,1024);Wub(a+32768|0);Wub(a+49152|0);$ub(a,8720240,2048);return}function Zub(a){a=a|0;var b=0;Wub(a);Vub(a+16384|0);Vub(a+24576|0);$ub(a,8379712,1024);Wub(a+32768|0);Wub(a+49152|0);$ub(a,8720240,2048);b=a+65536|0;Wub(b);Vub(a+81920|0);Vub(a+90112|0);$ub(b,8379712,1024);b=a+98304|0;Wub(b);Vub(a+114688|0);Vub(a+122880|0);$ub(b,8379712,1024);$ub(a,8614944,4096);return}function _ub(a){a=a|0;var b=0;Zub(a);b=a+131072|0;Wub(b);Vub(a+147456|0);Vub(a+155648|0);$ub(b,8379712,1024);Wub(a+163840|0);Wub(a+180224|0);$ub(b,8720240,2048);b=a+196608|0;Wub(b);Vub(a+212992|0);Vub(a+221184|0);$ub(b,8379712,1024);Wub(a+229376|0);Wub(a+245760|0);$ub(b,8720240,2048);$ub(a,8404288,8192);return}function $ub(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=d<<1;f=d<<2;g=d*6|0;h=a+(f<<2)|0;i=b[h>>1]|0;j=a+(f<<2)+2|0;k=b[j>>1]|0;l=a+(g<<2)|0;m=b[l>>1]|0;n=a+(g<<2)+2|0;o=b[n>>1]|0;p=a|0;q=a+2|0;r=b[q>>1]|0;s=a+(e<<2)|0;t=b[s>>1]|0;u=a+(e<<2)+2|0;v=b[u>>1]|0;w=m-i>>1;x=m+i>>1;i=b[p>>1]|0;b[h>>1]=(i-x|0)>>>1;b[p>>1]=(i+x|0)>>>1;x=v<<16>>16;b[n>>1]=(x-w|0)>>>1;b[u>>1]=(x+w|0)>>>1;w=k-o>>1;x=o+k>>1;k=t<<16>>16;b[l>>1]=(k-w|0)>>>1;b[s>>1]=(k+w|0)>>>1;w=r<<16>>16;b[j>>1]=(w-x|0)>>>1;b[q>>1]=(w+x|0)>>>1;x=f|1;w=a+(x<<2)|0;q=b[w>>1]|0;j=b[c+2>>1]|0;r=ca(j,q)|0;k=a+(x<<2)+2|0;x=b[k>>1]|0;s=b[c+(e-1<<1)>>1]|0;l=(ca(s,x)|0)+r>>15;r=(ca(x,j)|0)-(ca(s,q)|0)>>15;q=g|1;x=a+(q<<2)|0;t=b[x>>1]|0;o=ca(t,j)|0;u=a+(q<<2)+2|0;n=b[u>>1]|0;v=o-(ca(n,s)|0)>>15;o=(ca(n,j)|0)+(ca(t,s)|0)>>15;s=a+4|0;t=a+6|0;j=b[t>>1]|0;n=e|1;i=a+(n<<2)|0;p=b[i>>1]|0;h=a+(n<<2)+2|0;m=b[h>>1]|0;y=v-l>>1;z=v+l>>1;l=b[s>>1]|0;b[w>>1]=(l-z|0)>>>1;b[s>>1]=(z+l|0)>>>1;l=m<<16>>16;b[u>>1]=(l-y|0)>>>1;b[h>>1]=(y+l|0)>>>1;l=r-o>>1;y=o+r>>1;r=p<<16>>16;b[x>>1]=(r-l|0)>>>1;b[i>>1]=(l+r|0)>>>1;r=j<<16>>16;b[k>>1]=(r-y|0)>>>1;b[t>>1]=(y+r|0)>>>1;r=f|2;y=g+2|0;g=e+2|0;t=f|3;f=q+2|0;q=n+2|0;n=a;a=c;k=d-1|0;d=c+(e<<1)|0;while(1){e=n+8|0;c=a+4|0;j=d-4|0;l=n+(r<<2)|0;i=b[l>>1]|0;x=b[c>>1]|0;p=ca(x,i)|0;o=n+(r<<2)+2|0;h=b[o>>1]|0;u=b[j>>1]|0;m=(ca(u,h)|0)+p>>15;p=(ca(h,x)|0)-(ca(u,i)|0)>>15;i=n+(y<<2)|0;h=b[i>>1]|0;z=ca(h,x)|0;s=n+(y<<2)+2|0;w=b[s>>1]|0;v=z-(ca(w,u)|0)>>15;z=(ca(w,x)|0)+(ca(h,u)|0)>>15;u=e|0;h=n+10|0;x=b[h>>1]|0;w=n+(g<<2)|0;A=b[w>>1]|0;B=n+(g<<2)+2|0;C=b[B>>1]|0;D=v-m>>1;E=v+m>>1;m=b[u>>1]|0;b[l>>1]=(m-E|0)>>>1;b[u>>1]=(E+m|0)>>>1;m=C<<16>>16;b[s>>1]=(m-D|0)>>>1;b[B>>1]=(D+m|0)>>>1;m=p-z>>1;D=z+p>>1;p=A<<16>>16;b[i>>1]=(p-m|0)>>>1;b[w>>1]=(m+p|0)>>>1;p=x<<16>>16;b[o>>1]=(p-D|0)>>>1;b[h>>1]=(D+p|0)>>>1;p=n+(t<<2)|0;D=b[p>>1]|0;h=b[a+6>>1]|0;o=ca(h,D)|0;x=n+(t<<2)+2|0;m=b[x>>1]|0;w=b[d-6>>1]|0;i=(ca(w,m)|0)+o>>15;o=(ca(m,h)|0)-(ca(w,D)|0)>>15;D=n+(f<<2)|0;m=b[D>>1]|0;A=ca(m,h)|0;z=n+(f<<2)+2|0;B=b[z>>1]|0;s=A-(ca(B,w)|0)>>15;A=(ca(B,h)|0)+(ca(m,w)|0)>>15;w=n+12|0;m=n+14|0;h=b[m>>1]|0;B=n+(q<<2)|0;C=b[B>>1]|0;E=n+(q<<2)+2|0;u=b[E>>1]|0;l=s-i>>1;v=s+i>>1;i=b[w>>1]|0;b[p>>1]=(i-v|0)>>>1;b[w>>1]=(v+i|0)>>>1;i=u<<16>>16;b[z>>1]=(i-l|0)>>>1;b[E>>1]=(l+i|0)>>>1;i=o-A>>1;l=A+o>>1;o=C<<16>>16;b[D>>1]=(o-i|0)>>>1;b[B>>1]=(i+o|0)>>>1;o=h<<16>>16;b[x>>1]=(o-l|0)>>>1;b[m>>1]=(l+o|0)>>>1;o=k-1|0;if((o|0)==0){break}else{n=e;a=c;k=o;d=j}}return}function avb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=d<<1;f=d<<2;g=d*6|0;h=a+(f<<2)|0;i=b[h>>1]|0;j=a+(f<<2)+2|0;k=b[j>>1]|0;l=a+(g<<2)|0;m=b[l>>1]|0;n=a+(g<<2)+2|0;o=b[n>>1]|0;p=m-i>>1;q=m+i>>1;i=a|0;b[h>>1]=((b[i>>1]|0)-q|0)>>>1;b[i>>1]=((b[i>>1]|0)+q|0)>>>1;q=a+(e<<2)+2|0;b[n>>1]=((b[q>>1]|0)-p|0)>>>1;b[q>>1]=((b[q>>1]|0)+p|0)>>>1;p=k-o>>1;q=o+k>>1;k=a+(e<<2)|0;b[l>>1]=((b[k>>1]|0)-p|0)>>>1;b[k>>1]=((b[k>>1]|0)+p|0)>>>1;p=a+2|0;b[j>>1]=((b[p>>1]|0)-q|0)>>>1;b[p>>1]=((b[p>>1]|0)+q|0)>>>1;q=f|1;p=a+(q<<2)|0;j=b[p>>1]|0;k=b[c+2>>1]|0;l=ca(k,j)|0;o=a+(q<<2)+2|0;q=b[o>>1]|0;n=b[c+(e-1<<1)>>1]|0;i=(ca(n,q)|0)+l>>15;l=(ca(q,k)|0)-(ca(n,j)|0)>>15;j=g|1;q=a+(j<<2)|0;h=b[q>>1]|0;m=ca(h,k)|0;r=a+(j<<2)+2|0;s=b[r>>1]|0;t=m-(ca(s,n)|0)>>15;m=(ca(s,k)|0)+(ca(h,n)|0)>>15;n=t-i>>1;h=t+i>>1;i=a+4|0;b[p>>1]=((b[i>>1]|0)-h|0)>>>1;b[i>>1]=(h+(b[i>>1]|0)|0)>>>1;i=e|1;h=a+(i<<2)+2|0;b[r>>1]=((b[h>>1]|0)-n|0)>>>1;b[h>>1]=(n+(b[h>>1]|0)|0)>>>1;h=l-m>>1;n=m+l>>1;l=a+(i<<2)|0;b[q>>1]=((b[l>>1]|0)-h|0)>>>1;b[l>>1]=((b[l>>1]|0)+h|0)>>>1;h=a+6|0;b[o>>1]=((b[h>>1]|0)-n|0)>>>1;b[h>>1]=((b[h>>1]|0)+n|0)>>>1;n=f|2;h=g+2|0;g=e+2|0;o=f|3;f=j+2|0;j=i+2|0;i=c+(e<<1)|0;e=a;a=c;c=d-1|0;while(1){d=e+8|0;l=a+4|0;q=i-4|0;m=e+(n<<2)|0;r=b[m>>1]|0;p=b[l>>1]|0;t=ca(p,r)|0;k=e+(n<<2)+2|0;s=b[k>>1]|0;u=b[q>>1]|0;v=(ca(u,s)|0)+t>>15;t=(ca(s,p)|0)-(ca(u,r)|0)>>15;r=e+(h<<2)|0;s=b[r>>1]|0;w=ca(s,p)|0;x=e+(h<<2)+2|0;y=b[x>>1]|0;z=w-(ca(y,u)|0)>>15;w=(ca(y,p)|0)+(ca(s,u)|0)>>15;u=z-v>>1;s=z+v>>1;v=d|0;b[m>>1]=((b[v>>1]|0)-s|0)>>>1;b[v>>1]=(s+(b[v>>1]|0)|0)>>>1;v=e+(g<<2)+2|0;b[x>>1]=((b[v>>1]|0)-u|0)>>>1;b[v>>1]=(u+(b[v>>1]|0)|0)>>>1;v=t-w>>1;u=w+t>>1;t=e+(g<<2)|0;b[r>>1]=((b[t>>1]|0)-v|0)>>>1;b[t>>1]=((b[t>>1]|0)+v|0)>>>1;v=e+10|0;b[k>>1]=((b[v>>1]|0)-u|0)>>>1;b[v>>1]=((b[v>>1]|0)+u|0)>>>1;u=e+(o<<2)|0;v=b[u>>1]|0;k=b[a+6>>1]|0;t=ca(k,v)|0;r=e+(o<<2)+2|0;w=b[r>>1]|0;x=b[i-6>>1]|0;s=(ca(x,w)|0)+t>>15;t=(ca(w,k)|0)-(ca(x,v)|0)>>15;v=e+(f<<2)|0;w=b[v>>1]|0;m=ca(w,k)|0;z=e+(f<<2)+2|0;p=b[z>>1]|0;y=m-(ca(p,x)|0)>>15;m=(ca(p,k)|0)+(ca(w,x)|0)>>15;x=y-s>>1;w=y+s>>1;s=e+12|0;b[u>>1]=((b[s>>1]|0)-w|0)>>>1;b[s>>1]=(w+(b[s>>1]|0)|0)>>>1;s=e+(j<<2)+2|0;b[z>>1]=((b[s>>1]|0)-x|0)>>>1;b[s>>1]=(x+(b[s>>1]|0)|0)>>>1;s=t-m>>1;x=m+t>>1;t=e+(j<<2)|0;b[v>>1]=((b[t>>1]|0)-s|0)>>>1;b[t>>1]=((b[t>>1]|0)+s|0)>>>1;s=e+14|0;b[r>>1]=((b[s>>1]|0)-x|0)>>>1;b[s>>1]=((b[s>>1]|0)+x|0)>>>1;x=c-1|0;if((x|0)==0){break}else{i=q;e=d;a=l;c=x}}return}function bvb(a,b,d,e,f,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=+f;j=+j;k=+k;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0;l=i;i=i+496|0;m=l|0;if(!((e-1|0)>>>0<30>>>0&f<1.0)){n=0;i=l;return n|0}o=pJb(16)|0;p=o;q=(o|0)==0;do{if(q){KIb(a,16,2423304,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}else{s=(e>>>1<<2)+4|0;t=hJb(s)|0;u=o+8|0;c[u>>2]=t;if((t|0)!=0|(s|0)==0){s=e<<2;t=hJb(s)|0;v=t;c[o+12>>2]=v;do{if((t|0)!=0|(s|0)==0){c[o>>2]=e;if((b|0)==2){if((d|0)!=0){KIb(a,16,2288392,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}if((e&1|0)!=0){KIb(a,16,2238336,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}k=+W(f*1.5707963267948966)*2.0;w=c[u>>2]|0;c[w>>2]=1;x=e>>1;y=x+1|0;if((x|0)>0){z=1;A=1;do{B=e-z|0;C=wrc(B,(B|0)<0|0?-1:0,1,0)|0;B=Erc(C,G,A,(A|0)<0|0?-1:0)|0;C=Crc(B,G,z,(z|0)<0|0?-1:0)|0;A=C;c[w+(z<<2)>>2]=A;z=z+1|0;}while((z|0)<(y|0))}y=m|0;h[y>>3]=1.0;z=m+8|0;h[z>>3]=0.0;a:do{if((e|0)<1){j=+h[m+(e<<4)>>3];A=o+4|0;g[A>>2]=j;D=j;E=A}else{A=1;while(1){w=A+1|0;mrc(m+(A<<4)|0,0,16)|0;if((w|0)>(e|0)){break}else{A=w}}if((e|0)<=0){j=+h[m+(e<<4)>>3];A=o+4|0;g[A>>2]=j;D=j;E=A;break}j=+(e|0);A=m+(e<<4)|0;w=m+(e<<4)+8|0;C=0;do{F=(+(C+x|0)+.5)*3.141592653589793/j;H=k*+U(F);I=k*+V(F);F=H+2.0;J=H+-2.0;H=I*I;K=J*J+H;L=(F*J+H)/K;H=(I*J-F*I)/K;B=e;K=+h[A>>3];I=+h[w>>3];while(1){M=B-1|0;F=+h[m+(M<<4)>>3];h[m+(B<<4)>>3]=F+(L*K-H*I);J=+h[m+(M<<4)+8>>3];h[m+(B<<4)+8>>3]=L*I+H*K+J;if((M|0)>0){B=M;K=F;I=J}else{break}}I=+h[y>>3];K=+h[z>>3];N=L*I-H*K;O=H*I+L*K;h[z>>3]=O;h[y>>3]=N;C=C+1|0;}while((C|0)<(e|0));j=+h[A>>3];K=j;C=o+4|0;g[C>>2]=K;I=+h[w>>3];J=j*j+I*I;B=0;F=K;K=N;P=O;while(1){Q=F+K;g[C>>2]=Q;g[v+(B<<2)>>2]=(j*(-0.0-K)+I*(-0.0-P))/J;M=B+1|0;if((M|0)>=(e|0)){D=Q;E=C;break a}B=M;F=Q;K=+h[m+(M<<4)>>3];P=+h[m+(M<<4)+8>>3]}}}while(0);g[E>>2]=D/+(1<<e|0);n=p;i=l;return n|0}else if((b|0)==1){if(d>>>0>1>>>0){KIb(a,16,2436920,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}if((e|0)!=2){KIb(a,16,2350168,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}k=f*3.141592653589793;P=+U(k);K=+V(k)*.5;k=K+1.0;if((d|0)==1){F=P+1.0;J=F*.5/k;I=J;g[o+4>>2]=I;R=-0.0-F;S=J;T=I}else{I=1.0-P;J=I*.5/k;F=J;g[o+4>>2]=F;R=I;S=J;T=F}g[v>>2]=(K+-1.0)/k;g[t+4>>2]=P*2.0/k;y=Lc(+(S/T))|0;c[c[u>>2]>>2]=y;y=Lc(+(R/k/+g[o+4>>2]))|0;c[(c[u>>2]|0)+4>>2]=y;n=p;i=l;return n|0}else{KIb(a,16,2580608,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;break}}else{KIb(a,16,2423304,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}}while(0);if(q){break}}else{KIb(a,16,2423304,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}kJb(c[o+8>>2]|0);kJb(c[o+12>>2]|0)}}while(0);kJb(o);n=0;i=l;return n|0}function cvb(a){a=a|0;var b=0;if((a|0)==0){b=a;kJb(b);return}kJb(c[a+8>>2]|0);kJb(c[a+12>>2]|0);b=a;kJb(b);return}function dvb(a){a=a|0;return pJb(a<<2)|0}function evb(a,b,d,e,f,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0,L=0,M=0.0,N=0.0;j=c[a>>2]|0;if((j|0)==4){if((d|0)<=0){return}k=a+4|0;l=c[a+12>>2]|0;m=b|0;n=l+4|0;o=b+4|0;p=l+8|0;q=b+8|0;r=l+12|0;s=b+12|0;t=f<<1;u=i<<1;v=t+f|0;w=u+i|0;x=v+f|0;y=w+i|0;z=0;A=e;B=h;C=+g[s>>2];while(1){D=+g[m>>2];E=+g[o>>2];F=+g[q>>2];G=+g[A>>2]*+g[k>>2]+ +g[l>>2]*D+ +g[n>>2]*E+ +g[p>>2]*F+ +g[r>>2]*C;g[B>>2]=F*6.0+((E+C)*4.0+(D+G));g[m>>2]=G;D=+g[o>>2];E=+g[q>>2];F=+g[s>>2];H=+g[A+(f<<2)>>2]*+g[k>>2]+ +g[l>>2]*D+ +g[n>>2]*E+ +g[p>>2]*F+G*+g[r>>2];g[B+(i<<2)>>2]=F*6.0+((G+E)*4.0+(D+H));g[o>>2]=H;D=+g[q>>2];E=+g[s>>2];G=+g[m>>2];F=+g[A+(t<<2)>>2]*+g[k>>2]+ +g[l>>2]*D+ +g[n>>2]*E+ +g[p>>2]*G+H*+g[r>>2];g[B+(u<<2)>>2]=G*6.0+((H+E)*4.0+(D+F));g[q>>2]=F;D=+g[s>>2];E=+g[m>>2];H=+g[o>>2];G=+g[A+(v<<2)>>2]*+g[k>>2]+ +g[l>>2]*D+ +g[n>>2]*E+ +g[p>>2]*H+F*+g[r>>2];g[B+(w<<2)>>2]=H*6.0+((F+E)*4.0+(D+G));g[s>>2]=G;I=z+4|0;if((I|0)<(d|0)){z=I;A=A+(x<<2)|0;B=B+(y<<2)|0;C=G}else{break}}return}else if((j|0)==2){if((d|0)<=0){return}y=a+4|0;B=b|0;x=c[a+12>>2]|0;A=b+4|0;z=x+4|0;C=+(c[(c[a+8>>2]|0)+4>>2]|0);s=h;w=e;r=0;G=+g[B>>2];D=+g[A>>2];while(1){E=+g[w>>2]*+g[y>>2]+G*+g[x>>2]+D*+g[z>>2];g[s>>2]=G+E+D*C;F=+g[A>>2];g[B>>2]=F;g[A>>2]=E;p=r+1|0;if((p|0)<(d|0)){s=s+(i<<2)|0;w=w+(f<<2)|0;r=p;G=F;D=E}else{break}}return}else{if((d|0)<=0){return}r=a+4|0;w=b|0;s=c[a+8>>2]|0;A=j>>1;B=(A|0)>1;z=j-1|0;x=(z|0)>0;y=b+(z<<2)|0;p=a+12|0;if((j|0)>0){J=0;K=e;L=h}else{a=0;n=e;e=h;while(1){D=+g[n>>2]*+g[r>>2];G=D+ +g[w>>2]+ +g[b+(A<<2)>>2]*+(c[s+(A<<2)>>2]|0);if(B){h=1;C=G;while(1){E=C+(+g[b+(h<<2)>>2]+ +g[b+(j-h<<2)>>2])*+(c[s+(h<<2)>>2]|0);l=h+1|0;if((l|0)<(A|0)){h=l;C=E}else{M=E;break}}}else{M=G}if(x){h=0;while(1){l=h+1|0;g[b+(h<<2)>>2]=+g[b+(l<<2)>>2];if((l|0)<(z|0)){h=l}else{break}}}g[e>>2]=M;g[y>>2]=D;h=a+1|0;if((h|0)<(d|0)){a=h;n=n+(f<<2)|0;e=e+(i<<2)|0}else{break}}return}while(1){e=c[p>>2]|0;n=0;M=+g[K>>2]*+g[r>>2];do{M=M+ +g[e+(n<<2)>>2]*+g[b+(n<<2)>>2];n=n+1|0;}while((n|0)<(j|0));D=M+ +g[w>>2]+ +g[b+(A<<2)>>2]*+(c[s+(A<<2)>>2]|0);if(B){n=1;G=D;while(1){C=G+(+g[b+(n<<2)>>2]+ +g[b+(j-n<<2)>>2])*+(c[s+(n<<2)>>2]|0);e=n+1|0;if((e|0)<(A|0)){n=e;G=C}else{N=C;break}}}else{N=D}if(x){n=0;while(1){e=n+1|0;g[b+(n<<2)>>2]=+g[b+(e<<2)>>2];if((e|0)<(z|0)){n=e}else{break}}}g[L>>2]=N;g[y>>2]=M;n=J+1|0;if((n|0)<(d|0)){J=n;K=K+(f<<2)|0;L=L+(i<<2)|0}else{break}}return}}function fvb(a){a=a|0;kJb(a);return}function gvb(a){a=a|0;c[a>>2]=198;return}function hvb(){return 3408740}function ivb(){return 2422528}function jvb(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;e=i;i=i+568|0;f=e|0;h=e+504|0;j=e+544|0;k=e+552|0;l=e+560|0;m=f|0;if((b|0)==0){KIb(0,16,2436888,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=0;i=e;return o|0}if((irc(b,2350160)|0)==0){p=700560;q=700593;while(1){r=q-p+2|0;CFb(m,p,r>>>0<500>>>0?r:500)|0;KIb(0,32,2288384,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;r=(_b(p|0,10)|0)+1|0;s=_b(r|0,10)|0;if((s|0)==0){o=0;break}else{p=r;q=s}}i=e;return o|0}q=hJb(48)|0;p=q;c[p>>2]=0;s=q+4|0;c[s>>2]=0;r=q+24|0;t=r;c[r>>2]=700;c[q+28>>2]=1500;c[q+32>>2]=3e3;r=q+16|0;c[r>>2]=234;u=q+12|0;c[u>>2]=16;v=q+36|0;c[v>>2]=32;w=q+40|0;c[w>>2]=39;g[q+20>>2]=.009999999776482582;x=q+8|0;c[x>>2]=0;mrc(m|0,0,500)|0;CFb(m,b,499)|0;KIb(0,48,2238328,(n=i,i=i+8|0,c[n>>2]=b,n)|0);i=n;y=tb(m|0,703064)|0;a:do{if((y|0)!=0){z=f;A=q+44|0;B=h|0;C=m;D=y;while(1){E=C+((lrc(D|0)|0)+1)|0;F=tb(D|0,703056)|0;if((F|0)==0){break}KIb(0,48,2197672,(n=i,i=i+16|0,c[n>>2]=D,c[n+8>>2]=F,n)|0);i=n;G=(a[F]|0)==45;H=G?F+1|0:F;F=1e6;I=0;J=-1;K=-1;while(1){L=tb(0,703056)|0;if((L|0)==0){M=F;N=I;O=J;P=K;break}KIb(0,48,2166128,(n=i,i=i+8|0,c[n>>2]=L,n)|0);i=n;do{if((irc(2139808,L)|0)==0){Q=d;R=I;S=J;T=K}else{if((irc(2116440,L)|0)==0){Q=d;R=I;S=J;T=K;break}if((irc(2634264,L)|0)==0){Q=F;R=I;S=0;T=K;break}if((irc(2610600,L)|0)==0){Q=F;R=I;S=0;T=K;break}if((irc(2584128,L)|0)==0){Q=F;R=I;S=1;T=K;break}if((irc(2563464,L)|0)==0){Q=F;R=I;S=1;T=K;break}if((irc(2545920,L)|0)==0){Q=F;R=I;S=J;T=0;break}if((irc(2528072,L)|0)==0){Q=F;R=I;S=J;T=0;break}c[h+(I<<2)>>2]=L;Q=F;R=I+1|0;S=J;T=K}}while(0);if((R|0)>8){M=Q;N=R;O=S;P=T;break}else{F=Q;I=R;J=S;K=T}}c[h+(N<<2)>>2]=0;K=0;J=0;I=E;F=0;while(1){if((irc(c[680432+(F<<2)>>2]|0,H)|0)==0){L=c[680432+((F|1)<<2)>>2]|0;U=lrc(L|0)|0;V=I-1|0;a[V]=44;W=lrc(V|0)|0;if((V-z+U+W|0)>498){X=24;break}orc(I+(U-1)|0,V|0,W+1|0)|0;nrc(V|0,L|0,U)|0;Y=V;Z=1}else{Y=I;Z=J}U=K+1|0;L=U<<1;if((L|0)==10){_=Y;$=Z;break}else{K=U;J=Z;I=Y;F=L}}if((X|0)==24){X=0;c[x>>2]=(c[x>>2]|0)+1;_=V;$=J}F=(P|0)==0;I=0;K=$;E=N;L=1224424;b:while(1){if((irc(c[1224428+(I*24|0)>>2]|0,H)|0)==0){X=30}else{if((irc(c[L>>2]|0,H)|0)==0){X=30}else{aa=E;ba=K}}c:do{if((X|0)==30){X=0;U=c[1224444+(I*24|0)>>2]|0;W=~U;ca=c[p>>2]&W;c[p>>2]=ca;da=c[s>>2]&W;c[s>>2]=da;if(G){ea=E;break b}if(!((M|0)<(c[1224436+(I*24|0)>>2]|0)|F)){c[p>>2]=ca|U}if((O|0)==1){X=35}else if((O|0)==(-1|0)){if((I|0)==17){X=56}else if((I|0)!=7){X=35}}else{X=37}do{if((X|0)==35){X=0;if((M|0)<(c[1224440+(I*24|0)>>2]|0)){X=37;break}c[s>>2]=da|U;X=37}}while(0);d:do{if((X|0)==37){X=0;switch(I|0){case 15:{c[A>>2]=15;U=c[B>>2]|0;if((U|0)==0){X=56;break d}da=rb(U|0,l|0,0)|0;if((c[l>>2]|0)==(c[B>>2]|0)){aa=E;ba=1;break c}c[A>>2]=da;aa=E-1|0;ba=1;break c;break};case 7:{break d;break};case 14:{da=c[B>>2]|0;if((da|0)==0){X=56;break d}else{fa=E;ga=0;ha=0;ia=B;ja=da}while(1){c[t+(ha<<2)>>2]=rb(ja|0,j|0,0)|0;if((c[j>>2]|0)==(c[ia>>2]|0)){ka=ha;la=fa}else{da=ha+1|0;U=fa-1|0;if((da|0)>2){aa=U;ba=1;break c}else{ka=da;la=U}}U=ga+1|0;da=h+(U<<2)|0;ca=c[da>>2]|0;if((ca|0)==0){aa=la;ba=1;break c}else{fa=la;ga=U;ha=ka;ia=da;ja=ca}}break};case 1:case 0:case 5:case 4:{ca=c[B>>2]|0;if((ca|0)==0){aa=E;ba=1;break c}else{ma=E;na=0;oa=B;pa=ca}while(1){ca=rb(pa|0,k|0,0)|0;if((c[k>>2]|0)==(c[oa>>2]|0)){aa=ma;ba=1;break c}da=ma-1|0;if((na|0)==0){c[v>>2]=ca}else{c[w>>2]=ca}ca=na+1|0;U=h+(ca<<2)|0;W=c[U>>2]|0;if((W|0)!=0&(ca|0)<2){ma=da;na=ca;oa=U;pa=W}else{aa=da;ba=1;break c}}break};default:{aa=E;ba=1;break c}}}}while(0);if((X|0)==56){X=0;da=I+1|0;I=da;K=1;E=E;L=1224424+(da*24|0)|0;continue b}c[u>>2]=16;c[r>>2]=234;da=c[B>>2]|0;if((da|0)==0){aa=E;ba=1;break}else{qa=E;ra=0;sa=da}while(1){if((irc(sa,2513112)|0)==0){X=43}else{if((irc(sa,2499536)|0)==0){X=43}else{ta=qa}}if((X|0)==43){X=0;c[u>>2]=0;c[r>>2]=255;ta=qa-1|0}da=ra+1|0;W=c[h+(da<<2)>>2]|0;if((W|0)==0){aa=ta;ba=1;break}else{qa=ta;ra=da;sa=W}}}}while(0);W=I+1|0;if((W|0)==17){X=58;break}else{I=W;K=ba;E=aa;L=1224424+(W*24|0)|0}}do{if((X|0)==58){X=0;if((ba|0)!=0){ea=aa;break}c[x>>2]=(c[x>>2]|0)+1;ea=aa}}while(0);c[x>>2]=(c[x>>2]|0)+ea;L=tb(_|0,703064)|0;if((L|0)==0){break a}else{C=_;D=L}}c[x>>2]=(c[x>>2]|0)+1}}while(0);_=c[s>>2]|0;KIb(0,48,2486944,(n=i,i=i+16|0,c[n>>2]=c[p>>2],c[n+8>>2]=_,n)|0);i=n;_=c[x>>2]|0;if((_|0)==0){o=q;i=e;return o|0}KIb(0,16,2475400,(n=i,i=i+16|0,c[n>>2]=_,c[n+8>>2]=b,n)|0);i=n;kJb(q);o=0;i=e;return o|0}function kvb(a){a=a|0;kJb(a);return}function lvb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hJb(1208)|0;f=e;g=a+15|0;h=g&-16;i=((g|0)/16|0)+2|0;mrc(e|0,0,1208)|0;c[e>>2]=2004208;if((d&8|0)==0){c[e+1148>>2]=1;c[e+1152>>2]=1}else{c[e+1148>>2]=d&3;c[e+1152>>2]=d>>>4&3}do{if((d&524288|0)==0){g=e+1136|0;j=d>>>31;k=(d&536870912|0)==0?j:j|2;j=(d&1073741824|0)==0?k:k|4;c[g>>2]=j;if((d&268435456|0)==0){break}c[g>>2]=j|1}else{c[e+1136>>2]=AGb()|0}}while(0);mvb(f,a,b,h,i);c[e+1132>>2]=-1;return e|0}function mvb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=b+15|0;h=d+15|0;c[a+1144>>2]=e;c[a+1140>>2]=f;i=a+56|0;j=e*24|0;kJb(c[i>>2]|0);c[i>>2]=pJb(j+32|0)|0;i=a+60|0;kJb(c[i>>2]|0);c[i>>2]=pJb(j)|0;j=a+4|0;kJb(c[j>>2]|0);c[j>>2]=pJb(256)|0;j=a+8|0;kJb(c[j>>2]|0);i=pJb(2048)|0;c[j>>2]=i;j=(((ca(d,b)|0)/64|0)*15|0|0)/256|0;k=j;l=(j|0)<0|0?-1:0;j=0;do{m=i+(j<<3)|0;c[m>>2]=k;c[m+4>>2]=l;j=j+1|0;}while((j|0)<256);j=h>>4;h=(ca(e<<4,j)|0)+17408|0;e=(((d<<8)+1792&-2048|0)/2|0)+17408|0;d=a+32|0;kJb(c[d>>2]|0);c[d>>2]=pJb(h)|0;d=a+44|0;kJb(c[d>>2]|0);c[d>>2]=pJb(e)|0;d=a+36|0;kJb(c[d>>2]|0);c[d>>2]=pJb(h)|0;d=a+48|0;kJb(c[d>>2]|0);c[d>>2]=pJb(e)|0;d=a+40|0;kJb(c[d>>2]|0);c[d>>2]=pJb(h)|0;h=a+52|0;kJb(c[h>>2]|0);c[h>>2]=pJb(e)|0;e=a+64|0;kJb(c[e>>2]|0);c[e>>2]=pJb((b<<1)+32|0)|0;b=a+1116|0;e=ca(j,f)|0;kJb(c[b>>2]|0);c[b>>2]=pJb(e)|0;b=a+1112|0;kJb(c[b>>2]|0);c[b>>2]=pJb(e)|0;e=a+1120|0;kJb(c[e>>2]|0);c[e>>2]=pJb(g>>4)|0;return}function nvb(a){a=a|0;kJb(c[a+32>>2]|0);kJb(c[a+36>>2]|0);kJb(c[a+40>>2]|0);kJb(c[a+44>>2]|0);kJb(c[a+48>>2]|0);kJb(c[a+52>>2]|0);kJb(c[a+4>>2]|0);kJb(c[a+8>>2]|0);kJb(c[a+56>>2]|0);kJb(c[a+60>>2]|0);kJb(c[a+64>>2]|0);kJb(c[a+1112>>2]|0);kJb(c[a+1116>>2]|0);kJb(c[a+1120>>2]|0);mrc(a|0,0,1208)|0;kJb(a);return}function ovb(b,d,e,f,g,h,j,k,l,m,n){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;o=i;p=g+15>>4;q=h+15>>4;r=c[d>>2]|0;s=(r|0)>-1?r:-r|0;r=c[f>>2]|0;t=(r|0)>-1?r:-r|0;r=(s|0)>(t|0)?s:t;t=(k|0)>-1?k:-k|0;s=c[m+1144>>2]|0;u=(s|0)<(r|0);v=c[m+1140>>2]|0;if(u|(v|0)<(t|0)){mvb(m,g,h,u?r:s,(v|0)>(t|0)?v:t)}v=c[l>>2]|0;if((j|0)==0){w=5}else{if((v&2097152|0)==0){x=t;y=j;z=k}else{w=5}}a:do{if((w|0)==5){k=m+1120|0;j=c[k>>2]|0;t=(p|0)>0;if((v&2097152|0)==0){if(t){A=0;B=j}else{x=0;y=j;z=0;break}while(1){a[B+A|0]=1;s=A+1|0;if((s|0)>=(p|0)){x=0;y=j;z=0;break a}A=s;B=c[k>>2]|0}}if(!t){x=0;y=j;z=0;break}s=l+44|0;r=0;u=j;while(1){a[u+r|0]=c[s>>2];C=r+1|0;if((C|0)>=(p|0)){x=0;y=j;z=0;break a}r=C;u=c[k>>2]|0}}}while(0);if((n&16|0)==0){D=y;E=z}else{z=ca(x,q)|0;p=z>>2;if((p|0)>0){B=y;A=c[m+1112>>2]|0;v=0;do{c[A+(v<<2)>>2]=(c[B+(v<<2)>>2]|0)>>>1&2139062143;v=v+1|0;}while((v|0)<(p|0));F=p<<2}else{F=0}p=m+1112|0;if((F|0)<(z|0)){v=F;do{a[(c[p>>2]|0)+v|0]=(a[y+v|0]|0)>>>1;v=v+1|0;}while((v|0)<(z|0))}D=c[p>>2]|0;E=x}b:do{if((n&7|0)!=3){if(!((E|0)>-1)){if((q|0)<=0){break}p=m+1116|0;if((x|0)>0){G=0}else{break}while(1){z=ca(G,E)|0;v=ca(G,x)|0;y=0;do{a[(c[p>>2]|0)+(y+v)|0]=a[D+(y+z)|0]&63;y=y+1|0;}while((y|0)<(x|0));G=G+1|0;if((G|0)>=(q|0)){break b}}}p=ca(E,q)|0;y=p>>2;if((y|0)>0){z=D;v=c[m+1116>>2]|0;F=0;do{c[v+(F<<2)>>2]=c[z+(F<<2)>>2]&1061109567;F=F+1|0;}while((F|0)<(y|0));H=y<<2}else{H=0}if((H|0)>=(p|0)){break}F=m+1116|0;z=H;do{a[(c[F>>2]|0)+z|0]=a[D+z|0]&63;z=z+1|0;}while((z|0)<(p|0))}}while(0);H=l+4|0;q=c[H>>2]|0;KIb(m,48,2466528,(G=i,i=i+16|0,c[G>>2]=c[l>>2],c[G+8>>2]=q,G)|0);i=G;pvb(c[b>>2]|0,c[d>>2]|0,c[e>>2]|0,c[f>>2]|0,g,h,D,E,0,l,m);G=g>>c[m+1148>>2];g=h>>c[m+1152>>2];if((c[H>>2]|0)!=0){pvb(c[b+4>>2]|0,c[d+4>>2]|0,c[e+4>>2]|0,c[f+4>>2]|0,G,g,D,E,1,l,m);pvb(c[b+8>>2]|0,c[d+8>>2]|0,c[e+8>>2]|0,c[f+8>>2]|0,G,g,D,E,2,l,m);i=o;return}m=d+4|0;l=c[m>>2]|0;E=f+4|0;D=c[E>>2]|0;do{if((l|0)==(D|0)){H=d+8|0;if((c[H>>2]|0)!=(c[f+8>>2]|0)){break}h=c[e+4>>2]|0;q=c[b+4>>2]|0;if((l|0)>0){nrc(h|0,q|0,ca(l,g)|0)|0}else{x=ca(l,g-1|0)|0;nrc(h+x|0,q+x|0,ca(l,-g|0)|0)|0}x=c[e+8>>2]|0;q=c[b+8>>2]|0;h=c[H>>2]|0;if((h|0)>0){nrc(x|0,q|0,ca(h,g)|0)|0;i=o;return}else{H=ca(h,g-1|0)|0;nrc(x+H|0,q+H|0,ca(h,-g|0)|0)|0;i=o;return}}}while(0);if((g|0)<=0){i=o;return}h=e+4|0;H=b+4|0;q=f+8|0;f=e+8|0;e=d+8|0;d=b+8|0;b=0;x=D;D=l;while(1){l=ca(x,b)|0;n=ca(D,b)|0;nrc((c[h>>2]|0)+l|0,(c[H>>2]|0)+n|0,G)|0;n=ca(c[q>>2]|0,b)|0;l=ca(c[e>>2]|0,b)|0;nrc((c[f>>2]|0)+n|0,(c[d>>2]|0)+l|0,G)|0;l=b+1|0;if((l|0)>=(g|0)){break}b=l;x=c[E>>2]|0;D=c[m>>2]|0}i=o;return}function pvb(b,e,f,h,j,k,l,m,n,o,p){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0.0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0;q=i;i=i+1208|0;r=q|0;nrc(p+1156|0,o|0,48)|0;o=r;s=-h|0;nrc(o|0,p|0,1208)|0;t=(n|0)!=0;u=t?c[r+1160>>2]|0:c[r+1156>>2]|0;if(t){v=4-(c[r+1152>>2]|0)|0;w=4-(c[r+1148>>2]|0)|0}else{v=4;w=4}x=c[r+8>>2]|0;z=(e|0)>0;A=c[r+60>>2]|0;if(z){B=A}else{B=A+(e*-23|0)|0}A=(h|0)>0;C=c[r+56>>2]|0;if(A){D=C}else{D=C+(h*-23|0)|0}C=D+32|0;E=(u&262144|0)!=0;do{if(E){H=16}else{if((u&12713984|0)!=0){H=14;break}if((u&590849|0)!=0){H=13;break}if((u&512|0)!=0){H=11;break}H=u>>>2&1|8}}while(0);I=H-8|0;do{if(t){J=r+24|0;c[J>>2]=16777472;c[J+4>>2]=16777472;J=r+16|0;c[J>>2]=0;c[J+4>>2]=0;K=65536}else{J=r+1132|0;L=c[J>>2]|0;c[J>>2]=L+1;if((L|0)==0){L=Erc(k,(k|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;J=G;M=Erc(L>>>6|J<<26,J>>>6|0<<26,15,0)|0;J=G;c[x>>2]=M>>>8|J<<24;c[x+4>>2]=J>>>8|0<<24;N=0;O=0;P=0}else{N=0;O=0;P=0}do{J=x+(N<<3)|0;P=wrc(c[J>>2]|0,c[J+4>>2]|0,P,O)|0;O=G;N=N+1|0;}while((N|0)<256);S=(+(P>>>0)+ +(O>>>0)*4294967296.0)*+g[r+1176>>2];J=~~+S>>>0;M=(F=+S,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);if(O>>>0<M>>>0|O>>>0==M>>>0&P>>>0<J>>>0){T=0;U=255}else{L=O;V=P;W=255;while(1){X=x+(W<<3)|0;Y=xrc(V,L,c[X>>2]|0,c[X+4>>2]|0)|0;X=G;Z=W-1|0;if((Z|0)<1|(X>>>0<M>>>0|X>>>0==M>>>0&Y>>>0<J>>>0)){_=O;$=P;aa=0;break}else{L=X;V=Y;W=Z}}while(1){W=x+(aa<<3)|0;V=xrc($,_,c[W>>2]|0,c[W+4>>2]|0)|0;W=G;L=aa+1|0;if((L|0)>255|(W>>>0<M>>>0|W>>>0==M>>>0&V>>>0<J>>>0)){T=L;U=Z;break}else{_=W;$=V;aa=L}}}J=c[r+1168>>2]|0;S=+((c[r+1172>>2]|0)-J|0)/+(T-U|0);M=~~(S*1024.0+.5)&65535;L=r+24|0;V=U-J&65535;J=r+16|0;W=V|0;Y=V|0;c[J>>2]=W<<16|0>>>16|W;c[J+4>>2]=Y<<16|W>>>16|Y;Y=M|0;W=M|0;c[L>>2]=Y<<16|0>>>16|Y;c[L+4>>2]=W<<16|Y>>>16|W;if((u&8|0)==0){K=65536;break}K=~~(S*256.0*256.0+.5)}}while(0);U=b+(e*-8|0)|0;T=h+32|0;aa=D+T|0;$=(j|0)>0;a:do{if($){_=h<<3;Z=e<<3;P=_+h|0;O=Z+e|0;N=_+(h<<1)|0;W=Z+(e<<1)|0;Y=_+(h*3|0)|0;L=Z+(e*3|0)|0;M=_+(h<<2)|0;J=Z+(e<<2)|0;V=_+(h*5|0)|0;X=Z+(e*5|0)|0;da=_+(h*6|0)|0;ea=Z+(e*6|0)|0;fa=_+(h*7|0)|0;ga=Z+(e*7|0)|0;ia=_-h|0;ja=s<<1;ka=_+ja|0;la=ja-h|0;ja=la+_|0;ma=la-h|0;la=ma+_|0;na=ma+ia|0;ma=(u&131072|0)==0;oa=(u&524288|0)==0;pa=(u&4194304|0)==0;qa=(u&8388608|0)==0;ra=r+64|0;if((u&65536|0)==0){sa=U;ta=aa;ua=0}else{va=U;wa=aa;xa=0;while(1){ya=va+Z|0;za=wa+_|0;Aa=ya|0;Ba=ya+4|0;ya=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;Ba=za|0;y=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=za+4|0;y=ya;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=va+O|0;ya=wa+P|0;Aa=Ba|0;Ca=Ba+4|0;Ba=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=ya|0;y=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=ya+4|0;y=Ba;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=va+W|0;Ba=wa+N|0;ya=Ca|0;Aa=Ca+4|0;Ca=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0;Aa=Ba|0;y=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;a[Aa]=y;y=y>>8;a[Aa+1|0]=y;y=y>>8;a[Aa+2|0]=y;y=y>>8;a[Aa+3|0]=y;Aa=Ba+4|0;y=Ca;a[Aa]=y;y=y>>8;a[Aa+1|0]=y;y=y>>8;a[Aa+2|0]=y;y=y>>8;a[Aa+3|0]=y;Aa=va+L|0;Ca=wa+Y|0;Ba=Aa|0;ya=Aa+4|0;Aa=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;ya=Ca|0;y=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=Ca+4|0;y=Aa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=va+J|0;Aa=wa+M|0;Ca=ya|0;Ba=ya+4|0;ya=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;Ba=Aa|0;y=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=Aa+4|0;y=ya;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;y=y>>8;a[Ba+2|0]=y;y=y>>8;a[Ba+3|0]=y;Ba=va+X|0;ya=wa+V|0;Aa=Ba|0;Ca=Ba+4|0;Ba=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=ya|0;y=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=ya+4|0;y=Ba;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=va+ea|0;Ba=wa+da|0;ya=Ca|0;Aa=Ca+4|0;Ca=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0;Aa=Ba|0;y=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;a[Aa]=y;y=y>>8;a[Aa+1|0]=y;y=y>>8;a[Aa+2|0]=y;y=y>>8;a[Aa+3|0]=y;Aa=Ba+4|0;y=Ca;a[Aa]=y;y=y>>8;a[Aa+1|0]=y;y=y>>8;a[Aa+2|0]=y;y=y>>8;a[Aa+3|0]=y;Aa=va+ga|0;Ca=wa+fa|0;Ba=Aa|0;ya=Aa+4|0;Aa=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;ya=Ca|0;y=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=Ca+4|0;y=Aa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=wa+ia|0;Aa=za|0;Ca=za+4|0;Ba=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=ya|0;y=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=ya+4|0;y=Ba;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=wa+ka|0;Ba=za|0;ya=za+4|0;Aa=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;ya=Ca|0;y=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=Ca+4|0;y=Aa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=wa+ja|0;Aa=za|0;Ca=za+4|0;Ba=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=ya|0;y=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=ya+4|0;y=Ba;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=wa+la|0;Ba=za|0;ya=za+4|0;Aa=d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0;ya=Ca|0;y=d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=Ca+4|0;y=Aa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;ya=wa+na|0;Aa=za|0;Ca=za+4|0;za=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=ya|0;y=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=ya+4|0;y=za;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;qvb(wa,h);Ca=xa+8|0;if((Ca|0)<(j|0)){va=va+8|0;wa=wa+8|0;xa=Ca}else{break a}}}while(1){xa=sa+Z|0;wa=ta+_|0;va=xa|0;Ca=xa+4|0;xa=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=wa|0;y=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=wa+4|0;y=xa;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=sa+O|0;xa=ta+P|0;va=Ca|0;za=Ca+4|0;Ca=d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0;za=xa|0;y=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=xa+4|0;y=Ca;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=sa+W|0;Ca=ta+N|0;xa=za|0;va=za+4|0;za=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;va=Ca|0;y=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=Ca+4|0;y=za;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=sa+L|0;za=ta+Y|0;Ca=va|0;xa=va+4|0;va=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;xa=za|0;y=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=za+4|0;y=va;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=sa+J|0;va=ta+M|0;za=xa|0;Ca=xa+4|0;xa=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;Ca=va|0;y=d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=va+4|0;y=xa;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;Ca=sa+X|0;xa=ta+V|0;va=Ca|0;za=Ca+4|0;Ca=d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0;za=xa|0;y=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=xa+4|0;y=Ca;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=sa+ea|0;Ca=ta+da|0;xa=za|0;va=za+4|0;za=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;va=Ca|0;y=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=Ca+4|0;y=za;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=sa+ga|0;za=ta+fa|0;Ca=va|0;xa=va+4|0;va=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;xa=za|0;y=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=za+4|0;y=va;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=ta+ia|0;va=wa|0;za=wa+4|0;Ca=d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0;za=xa|0;y=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=xa+4|0;y=Ca;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=ta+ka|0;Ca=wa|0;xa=wa+4|0;va=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;xa=za|0;y=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=za+4|0;y=va;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=ta+ja|0;va=wa|0;za=wa+4|0;Ca=d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0;za=xa|0;y=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=xa+4|0;y=Ca;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=ta+la|0;Ca=wa|0;xa=wa+4|0;va=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;xa=za|0;y=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=za+4|0;y=va;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=ta+na|0;va=wa|0;za=wa+4|0;wa=d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0;za=xa|0;y=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;za=xa+4|0;y=wa;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;do{if(ma){if(!oa){svb(ta,h);break}if(E){tvb(ta,h);break}if(!pa){uvb(ta,h,(c[ra>>2]|0)+ua|0);break}if(qa){break}za=c[ra>>2]|0;vvb(ta,h,za+ua|0,za+(ua+j)|0)}else{rvb(ta,h,(c[ra>>2]|0)+ua|0)}}while(0);za=ua+8|0;if((za|0)<(j|0)){sa=sa+8|0;ta=ta+8|0;ua=za}else{break}}}}while(0);ua=(h|0)>-1?h:s;ta=(ua|0)==(j|0);do{if(ta){sa=(h*9|0)+32|0;if(A){nrc(f|0,D+sa|0,ca(I,h)|0)|0;break}else{U=ca(H-9|0,h)|0;nrc(f+U|0,D+(U+sa)|0,ca(8-H|0,h)|0)|0;break}}else{if((I|0)>0){Da=0}else{break}do{nrc(f+(ca(Da,h)|0)|0,D+((ca(Da+9|0,h)|0)+32)|0,j)|0;Da=Da+1|0;}while((Da|0)<(I|0))}}while(0);if((k|0)<=0){nrc(p|0,o|0,1208)|0;i=q;return}Da=(m|0)>-1?m:-m|0;sa=r+1116|0;U=ca(I,e)|0;ra=B+U|0;qa=H-7|0;pa=k-1|0;oa=f+(ca(pa,h)|0)|0;ma=b+(ca(pa,e)|0)|0;pa=-e|0;na=(e|0)>-1?e:pa;la=(u&4|0)!=0;ja=-8-h|0;ka=r+1124|0;ia=(u&1048576|0)==0;fa=r+32+(n<<2)|0;ga=r+44+(n<<2)|0;n=r+1180|0;da=r+1128|0;ea=ca(I,h)|0;V=ea+h|0;X=U+e|0;M=h<<1;J=ea+M|0;Y=U+(e<<1)|0;L=h*3|0;N=H-5|0;W=ca(N,h)|0;P=ca(N,e)|0;N=h<<2;O=ea+N|0;_=U+(e<<2)|0;Z=h*5|0;za=H-3|0;wa=ca(za,h)|0;xa=ca(za,e)|0;za=h*6|0;va=H-2|0;Ca=ca(va,h)|0;ya=ca(va,e)|0;va=h*7|0;Aa=H-1|0;Ba=ca(Aa,h)|0;Ea=ca(Aa,e)|0;Aa=(u&65536|0)==0;Fa=(u&131072|0)==0;Ga=(u&524288|0)==0;Ha=(u&4194304|0)==0;Ia=(u&8388608|0)==0;Ja=r+64|0;Ka=(u&512|0)==0;La=(u&1|0)==0;Ma=(u&1024|0)==0;Na=r+1192|0;Oa=h<<3;Pa=r+1196|0;r=h+1|0;Qa=h+2|0;Ra=h+3|0;Sa=h+4|0;Ta=h+5|0;Ua=h+6|0;Va=h+7|0;Wa=N+Z|0;Xa=N+M|0;Ya=N+va|0;Za=N+h|0;_a=N+za|0;$a=N+L|0;ab=M+h|0;bb=ab+h|0;cb=bb+h|0;db=cb+h|0;eb=db+h|0;fb=eb+h|0;gb=fb+h|0;hb=(u&8192|0)==0;ib=(u&2|0)==0;jb=(u&16384|0)==0;u=h-2|0;kb=(M|1)-4|0;lb=ab+2|0;mb=ab-1|0;nb=bb-4|0;ob=bb+1|0;pb=bb+u|0;qb=bb+Ra|0;rb=bb+M|0;sb=kb+bb|0;tb=lb+bb|0;ub=mb+bb|0;vb=(e*12|0)+4|0;wb=0;do{xb=b+(ca(wb,e)|0)|0;yb=ca(wb,h)|0;zb=f+yb|0;Ab=wb>>v;Bb=ca(Ab,m)|0;Cb=ca(Ab,Da)|0;Ab=c[sa>>2]|0;Db=(wb+15|0)>=(k|0);do{if(Db){Eb=wb+I|0;Fb=k-wb|0;Gb=Fb-I|0;Hb=(Gb|0)>0?Gb:0;if(z){nrc(ra|0,b+(ca(Eb,e)|0)|0,ca(Hb,e)|0)|0}else{Gb=Hb-1|0;nrc(B+(ca(Gb+I|0,e)|0)|0,b+(ca(Gb+Eb|0,e)|0)|0,ca(Hb,pa)|0)|0}Hb=(Fb|0)>8?Fb:8;if((Hb|0)<(H|0)){Eb=Hb;do{nrc(B+(ca(Eb,e)|0)|0,ma|0,na)|0;Eb=Eb+1|0;}while((Eb|0)<(H|0))}Eb=yb-h|0;Hb=Fb+1|0;Gb=(Hb|0)>(qa|0)?I:Fb;if(A){nrc(C|0,f+Eb|0,ca(Gb+1|0,h)|0)|0}else{Ib=ca(Gb,h)|0;nrc(D+(Ib+32)|0,f+(Ib+Eb)|0,ca(~Gb,h)|0)|0}if((Hb|0)>(I|0)){Jb=aa;Kb=B;break}else{Lb=Hb}while(1){nrc(D+((ca(Lb,h)|0)+32)|0,oa|0,ua)|0;Hb=Lb+1|0;if((Hb|0)>(I|0)){Jb=aa;Kb=B;break}else{Lb=Hb}}}else{Jb=zb;Kb=xb}}while(0);if($){xb=(wb+8|0)<(k|0);Fb=la&(wb|0)>0;Hb=(wb<<5)+256|0;Gb=Kb;Eb=Jb;Ib=0;while(1){if(t){Mb=Ib>>w;Nb=a[l+(Mb+Bb)|0]|0;c[da>>2]=a[Ab+(Mb+Cb)|0]|0;Ob=Nb}else{Nb=Ib>>4;Mb=(ca(a[l+(Nb+Bb)|0]|0,K)|0)+32768>>16;c[da>>2]=(ca(a[Ab+(Nb+Cb)|0]|0,K)|0)+32768>>16;Nb=x+(d[Gb+vb|0]<<3)|0;Pb=wrc(c[Nb>>2]|0,c[Nb+4>>2]|0,1,0)|0;c[Nb>>2]=Pb;c[Nb+4>>2]=G;Ob=Mb}c[ka>>2]=Ob;Mb=Gb+U|0;Nb=Eb+ea|0;Pb=Mb|0;Qb=Mb+4|0;Mb=d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0;Qb=Nb|0;y=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;a[Qb]=y;y=y>>8;a[Qb+1|0]=y;y=y>>8;a[Qb+2|0]=y;y=y>>8;a[Qb+3|0]=y;Qb=Nb+4|0;y=Mb;a[Qb]=y;y=y>>8;a[Qb+1|0]=y;y=y>>8;a[Qb+2|0]=y;y=y>>8;a[Qb+3|0]=y;Qb=Gb+X|0;Mb=Eb+V|0;Nb=Qb|0;Pb=Qb+4|0;Qb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;Pb=Mb|0;y=d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0;a[Pb]=y;y=y>>8;a[Pb+1|0]=y;y=y>>8;a[Pb+2|0]=y;y=y>>8;a[Pb+3|0]=y;Pb=Mb+4|0;y=Qb;a[Pb]=y;y=y>>8;a[Pb+1|0]=y;y=y>>8;a[Pb+2|0]=y;y=y>>8;a[Pb+3|0]=y;Pb=Gb+Y|0;Qb=Eb+J|0;Mb=Pb|0;Nb=Pb+4|0;Pb=d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0;Nb=Qb|0;y=d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0;a[Nb]=y;y=y>>8;a[Nb+1|0]=y;y=y>>8;a[Nb+2|0]=y;y=y>>8;a[Nb+3|0]=y;Nb=Qb+4|0;y=Pb;a[Nb]=y;y=y>>8;a[Nb+1|0]=y;y=y>>8;a[Nb+2|0]=y;y=y>>8;a[Nb+3|0]=y;Nb=Gb+P|0;Pb=Eb+W|0;Qb=Nb|0;Mb=Nb+4|0;Nb=d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0;Mb=Pb|0;y=d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0;a[Mb]=y;y=y>>8;a[Mb+1|0]=y;y=y>>8;a[Mb+2|0]=y;y=y>>8;a[Mb+3|0]=y;Mb=Pb+4|0;y=Nb;a[Mb]=y;y=y>>8;a[Mb+1|0]=y;y=y>>8;a[Mb+2|0]=y;y=y>>8;a[Mb+3|0]=y;Mb=Gb+_|0;Nb=Eb+O|0;Pb=Mb|0;Qb=Mb+4|0;Mb=d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0;Qb=Nb|0;y=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;a[Qb]=y;y=y>>8;a[Qb+1|0]=y;y=y>>8;a[Qb+2|0]=y;y=y>>8;a[Qb+3|0]=y;Qb=Nb+4|0;y=Mb;a[Qb]=y;y=y>>8;a[Qb+1|0]=y;y=y>>8;a[Qb+2|0]=y;y=y>>8;a[Qb+3|0]=y;Qb=Gb+xa|0;Mb=Eb+wa|0;Nb=Qb|0;Pb=Qb+4|0;Qb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;Pb=Mb|0;y=d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0;a[Pb]=y;y=y>>8;a[Pb+1|0]=y;y=y>>8;a[Pb+2|0]=y;y=y>>8;a[Pb+3|0]=y;Pb=Mb+4|0;y=Qb;a[Pb]=y;y=y>>8;a[Pb+1|0]=y;y=y>>8;a[Pb+2|0]=y;y=y>>8;a[Pb+3|0]=y;Pb=Gb+ya|0;Qb=Eb+Ca|0;Mb=Pb|0;Nb=Pb+4|0;Pb=d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0;Nb=Qb|0;y=d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0;a[Nb]=y;y=y>>8;a[Nb+1|0]=y;y=y>>8;a[Nb+2|0]=y;y=y>>8;a[Nb+3|0]=y;Nb=Qb+4|0;y=Pb;a[Nb]=y;y=y>>8;a[Nb+1|0]=y;y=y>>8;a[Nb+2|0]=y;y=y>>8;a[Nb+3|0]=y;Nb=Gb+Ea|0;Pb=Eb+Ba|0;Qb=Nb|0;Mb=Nb+4|0;Nb=d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0;Mb=Pb|0;y=d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0;a[Mb]=y;y=y>>8;a[Mb+1|0]=y;y=y>>8;a[Mb+2|0]=y;y=y>>8;a[Mb+3|0]=y;Mb=Pb+4|0;y=Nb;a[Mb]=y;y=y>>8;a[Mb+1|0]=y;y=y>>8;a[Mb+2|0]=y;y=y>>8;a[Mb+3|0]=y;do{if(Aa){if(!Fa){rvb(Eb,h,(c[Ja>>2]|0)+Ib|0);break}if(!Ga){svb(Eb,h);break}if(E){tvb(Eb,h);break}if(!Ha){uvb(Eb,h,(c[Ja>>2]|0)+Ib|0);break}if(Ia){break}Mb=c[Ja>>2]|0;vvb(Eb,h,Mb+Ib|0,Mb+(Ib+j)|0)}else{qvb(Eb,h)}}while(0);b:do{if(xb){if(!Ka){Mb=1;Nb=Eb+L|0;while(1){Pb=Nb+ab|0;Qb=Nb+bb|0;Rb=d[Qb]|0;Sb=(d[Pb]|0)-Rb|0;Tb=Nb+cb|0;Ub=d[Tb]|0;Vb=Rb-Ub|0;Rb=Nb+db|0;Wb=Ub-(d[Rb]|0)|0;Ub=((Vb|0)>-1?Vb:-Vb|0)-(((Wb|0)>-1?Wb:-Wb|0)+((Sb|0)>-1?Sb:-Sb|0)>>1)|0;Sb=(Ub|0)>0?Ub:0;if((Sb|0)<(c[ka>>2]<<1|0)){Ub=ca(Sb,(Vb>>31&2)-1|0)|0;Vb=Ub>>3;Sb=Nb+M|0;a[Sb]=(d[Sb]|0)+Vb;Sb=Ub>>2;a[Pb]=(d[Pb]|0)+Sb;Pb=(Ub*3|0)>>3;a[Qb]=(d[Qb]|0)+Pb;a[Tb]=(d[Tb]|0)-Pb;a[Rb]=(d[Rb]|0)-Sb;Sb=Nb+eb|0;a[Sb]=(d[Sb]|0)-Vb}if((Mb|0)>=8){break b}Mb=Mb+1|0;Nb=Nb+1|0}}if(!La){Nb=((ca(c[Na>>2]|0,c[da>>2]|0)|0)>>8)+1|0;Mb=Nb<<1|1;Vb=Eb+N|0;Sb=0;Rb=0;Pb=Vb;Tb=a[Vb]|0;while(1){Vb=Pb+h|0;Qb=a[Vb]|0;Xb=(((Tb&255)+Nb-(Qb&255)|0)>>>0<Mb>>>0)+Rb+(((d[Pb+1|0]|0)+Nb-(d[Pb+r|0]|0)|0)>>>0<Mb>>>0)+(((d[Pb+2|0]|0)+Nb-(d[Pb+Qa|0]|0)|0)>>>0<Mb>>>0)+(((d[Pb+3|0]|0)+Nb-(d[Pb+Ra|0]|0)|0)>>>0<Mb>>>0)+(((d[Pb+4|0]|0)+Nb-(d[Pb+Sa|0]|0)|0)>>>0<Mb>>>0)+(((d[Pb+5|0]|0)+Nb-(d[Pb+Ta|0]|0)|0)>>>0<Mb>>>0)+(((d[Pb+6|0]|0)+Nb-(d[Pb+Ua|0]|0)|0)>>>0<Mb>>>0)+(((d[Pb+7|0]|0)+Nb-(d[Pb+Va|0]|0)|0)>>>0<Mb>>>0)|0;Ub=Sb+1|0;if((Ub|0)<7){Sb=Ub;Rb=Xb;Pb=Vb;Tb=Qb}else{break}}if((Xb|0)<=(c[Pa>>2]|0)){Tb=1;Pb=Eb+L|0;while(1){Rb=Pb+cb|0;Sb=d[Rb]|0;Mb=Pb+bb|0;Nb=d[Mb]|0;Qb=d[Pb+ab|0]|0;Vb=d[Pb+db|0]|0;Ub=(Qb-Vb<<1)+((Sb-Nb|0)*5|0)|0;Wb=(Ub|0)>-1?Ub:-Ub|0;if((Wb|0)<(c[ka>>2]<<3|0)){Yb=Nb-Sb|0;Zb=(Yb|0)/2|0;_b=((d[Pb+h|0]|0)-Nb<<1)+((Qb-(d[Pb+M|0]|0)|0)*5|0)|0;Qb=(Sb-(d[Pb+fb|0]|0)<<1)+(((d[Pb+eb|0]|0)-Vb|0)*5|0)|0;Vb=(_b|0)>-1?_b:-_b|0;_b=(Qb|0)>-1?Qb:-Qb|0;Qb=Wb-((Vb|0)>(_b|0)?_b:Vb)|0;Vb=ca((Qb|0)>0?(Qb*5|0)+32>>6:0,(Ub>>31&2)-1|0)|0;if((Yb|0)>1){Yb=(Vb|0)<0?0:Vb;$b=(Yb|0)>(Zb|0)?Zb:Yb}else{Yb=(Vb|0)>0?0:Vb;$b=(Yb|0)<(Zb|0)?Zb:Yb}a[Mb]=Nb-$b;a[Rb]=(d[Rb]|0)+$b}if((Tb|0)>=8){break b}Tb=Tb+1|0;Pb=Pb+1|0}}Pb=c[ka>>2]|0;Tb=Pb<<1;Rb=Pb<<2;Nb=0;while(1){if((Nb|0)>=8){break}if(((d[Eb+(Nb+N)|0]|0)+Tb-(d[Eb+(Wa+Nb)|0]|0)|0)>>>0>Rb>>>0){break b}Mb=Nb|1;if(((d[Eb+(Xa+Mb)|0]|0)+Tb-(d[Eb+(Ya+Mb)|0]|0)|0)>>>0>Rb>>>0){break b}Mb=Nb|2;if(((d[Eb+(Mb+Oa)|0]|0)+Tb-(d[Eb+(Za+Mb)|0]|0)|0)>>>0>Rb>>>0){break b}Mb=Nb|3;if(((d[Eb+(_a+Mb)|0]|0)+Tb-(d[Eb+($a+Mb)|0]|0)|0)>>>0>Rb>>>0){break b}else{Nb=Nb+4|0}}Nb=1;Rb=Eb+L|0;Tb=Pb;while(1){Mb=a[Rb]|0;Yb=Rb+h|0;Zb=a[Yb]|0;Vb=Zb&255;Ub=(Mb&255)-Vb|0;Qb=((((Ub|0)>-1?Ub:-Ub|0)|0)<(Tb|0)?Mb:Zb)&255;Zb=Rb+fb|0;Mb=a[Zb]|0;Ub=Mb&255;_b=a[Rb+gb|0]|0;Wb=Ub-(_b&255)|0;Sb=((((Wb|0)>-1?Wb:-Wb|0)|0)<(Tb|0)?_b:Mb)&255;Mb=Rb+M|0;_b=d[Mb]|0;Wb=Rb+ab|0;ac=d[Wb]|0;bc=Vb+4+_b+ac+(Qb<<2)|0;cc=Rb+bb|0;dc=d[cc]|0;ec=bc-Qb+dc|0;fc=Rb+cb|0;gc=d[fc]|0;hc=ec-Qb+gc|0;ic=Rb+db|0;jc=hc-Qb+(d[ic]|0)|0;kc=Rb+eb|0;lc=jc-Qb+(d[kc]|0)|0;Qb=lc-Vb+Ub|0;Ub=Qb-_b+Sb|0;_b=Ub-ac+Sb|0;ac=_b-dc+Sb|0;a[Yb]=(bc+(Vb<<1)+hc|0)>>>4;a[Mb]=((d[Mb]<<1)+ec+jc|0)>>>4;a[Wb]=(hc+(d[Wb]<<1)+lc|0)>>>4;a[cc]=(jc+(d[cc]<<1)+Qb|0)>>>4;a[fc]=(lc+(d[fc]<<1)+Ub|0)>>>4;a[ic]=(Qb+(d[ic]<<1)+_b|0)>>>4;a[kc]=(Ub+(d[kc]<<1)+ac|0)>>>4;a[Zb]=(Sb-gc+(d[Zb]<<1)+_b+ac|0)>>>4;if((Nb|0)>=8){break b}Nb=Nb+1|0;Rb=Rb+1|0;Tb=c[ka>>2]|0}}if(Ma){break}Tb=c[ka>>2]|0;Rb=((ca(c[Na>>2]|0,c[da>>2]|0)|0)>>8)+1|0;Nb=Rb<<1|1;Pb=Tb<<1;ac=Tb<<3;_b=1;Zb=Eb+N|0;while(1){gc=a[Zb+s|0]|0;Sb=gc&255;kc=a[Zb]|0;Ub=kc&255;ic=(Sb+Rb-Ub|0)>>>0<Nb>>>0;Qb=Zb+h|0;fc=a[Qb]|0;lc=fc&255;cc=Zb+M|0;jc=a[cc]|0;Wb=jc&255;hc=Zb+L|0;ec=a[hc]|0;Mb=ec&255;Vb=Zb+N|0;bc=a[Vb]|0;Yb=bc&255;dc=Mb-Yb|0;mc=Zb+Z|0;nc=a[mc]|0;oc=nc&255;pc=Zb+za|0;qc=a[pc]|0;rc=qc&255;sc=Zb+va|0;tc=a[sc]|0;uc=tc&255;vc=a[Zb+Oa|0]|0;wc=vc&255;do{if((((lc+Rb-Wb|0)>>>0<Nb>>>0)+((Ub+Rb-lc|0)>>>0<Nb>>>0?ic?2:1:ic&1)+((Wb+Rb-Mb|0)>>>0<Nb>>>0)+((dc+Rb|0)>>>0<Nb>>>0)+((Yb+Rb-oc|0)>>>0<Nb>>>0)+((oc+Rb-rc|0)>>>0<Nb>>>0)+((rc+Rb-uc|0)>>>0<Nb>>>0)+((uc+Rb-wc|0)>>>0<Nb>>>0)|0)>(c[Pa>>2]|0)){xc=(kc&255)>>>0>(fc&255)>>>0;yc=xc?Ub:lc;zc=xc?lc:Ub;if((jc&255)>>>0>(ec&255)>>>0){Ac=Mb>>>0<zc>>>0?Mb:zc;Bc=Wb>>>0>yc>>>0?Wb:yc}else{Ac=Wb>>>0<zc>>>0?Wb:zc;Bc=Mb>>>0>yc>>>0?Mb:yc}if((bc&255)>>>0>(nc&255)>>>0){Cc=(oc|0)<(Ac|0)?oc:Ac;Dc=(Yb|0)>(Bc|0)?Yb:Bc}else{Cc=(Yb|0)<(Ac|0)?Yb:Ac;Dc=(oc|0)>(Bc|0)?oc:Bc}if((qc&255)>>>0>(tc&255)>>>0){Ec=(uc|0)<(Cc|0)?uc:Cc;Fc=(rc|0)>(Dc|0)?rc:Dc}else{Ec=(rc|0)<(Cc|0)?rc:Cc;Fc=(uc|0)>(Dc|0)?uc:Dc}if((Fc-Ec|0)>=(Pb|0)){break}yc=Sb-Ub|0;zc=((((yc|0)>-1?yc:-yc|0)|0)<(Tb|0)?gc:kc)&255;yc=wc-uc|0;xc=((((yc|0)>-1?yc:-yc|0)|0)<(Tb|0)?vc:tc)&255;yc=Ub+4+lc+Wb+(zc<<2)|0;Gc=yc-zc+Mb|0;Hc=Gc-zc+Yb|0;Ic=Hc-zc+oc|0;Jc=Ic-zc+rc|0;zc=Jc-Ub+uc|0;Kc=zc-lc+xc|0;Lc=Kc-Wb+xc|0;Mc=Lc-Mb+xc|0;a[Zb]=(yc+(Ub<<1)+Hc|0)>>>4;a[Qb]=(Ic+Gc+(d[Qb]<<1)|0)>>>4;a[cc]=(Jc+Hc+(d[cc]<<1)|0)>>>4;a[hc]=(zc+Ic+(d[hc]<<1)|0)>>>4;a[Vb]=(Kc+Jc+(d[Vb]<<1)|0)>>>4;a[mc]=(Lc+zc+(d[mc]<<1)|0)>>>4;a[pc]=(Mc+Kc+(d[pc]<<1)|0)>>>4;a[sc]=(xc-Yb+Lc+Mc+(d[sc]<<1)|0)>>>4}else{Mc=(Wb-oc<<1)+((Yb-Mb|0)*5|0)|0;Lc=(Mc|0)>-1?Mc:-Mc|0;if((Lc|0)>=(ac|0)){break}xc=(dc|0)/2|0;Kc=(Ub-Mb<<1)+((Wb-lc|0)*5|0)|0;zc=(Yb-uc<<1)+((rc-oc|0)*5|0)|0;Jc=(Kc|0)>-1?Kc:-Kc|0;Kc=(zc|0)>-1?zc:-zc|0;zc=Lc-((Jc|0)>(Kc|0)?Kc:Jc)|0;Jc=ca((zc|0)>0?(zc*5|0)+32>>6:0,(Mc>>31&2)-1|0)|0;if((dc|0)>1){Mc=(Jc|0)<0?0:Jc;Nc=(Mc|0)>(xc|0)?xc:Mc}else{Mc=(Jc|0)>0?0:Jc;Nc=(Mc|0)<(xc|0)?xc:Mc}a[hc]=Mb-Nc;a[Vb]=(d[Vb]|0)+Nc}}while(0);if((_b|0)>=8){break b}_b=_b+1|0;Zb=Zb+1|0}}}while(0);do{if((Ib-8|0)>-1){c:do{if(hb){if(!ib){Zb=Eb-4|0;_b=((ca(c[Na>>2]|0,c[da>>2]|0)|0)>>8)+1|0;ac=_b<<1|1;Tb=0;Pb=0;Nb=Zb;while(1){Rb=d[Nb+1|0]|0;Vb=d[Nb+2|0]|0;Mb=d[Nb+3|0]|0;hc=d[Nb+4|0]|0;dc=d[Nb+5|0]|0;oc=d[Nb+6|0]|0;Oc=(((d[Nb]|0)+_b-Rb|0)>>>0<ac>>>0)+Pb+((Rb+_b-Vb|0)>>>0<ac>>>0)+((Vb+_b-Mb|0)>>>0<ac>>>0)+((Mb+_b-hc|0)>>>0<ac>>>0)+((hc+_b-dc|0)>>>0<ac>>>0)+((dc+_b-oc|0)>>>0<ac>>>0)+((oc+_b-(d[Nb+7|0]|0)|0)>>>0<ac>>>0)|0;oc=Tb+1|0;if((oc|0)<8){Tb=oc;Pb=Oc;Nb=Nb+h|0}else{break}}if((Oc|0)<=(c[Pa>>2]|0)){Nb=1;Pb=Zb;while(1){Tb=Pb+4|0;ac=d[Tb]|0;_b=Pb+3|0;oc=d[_b]|0;dc=d[Pb+2|0]|0;hc=d[Pb+5|0]|0;Mb=(dc-hc<<1)+((ac-oc|0)*5|0)|0;Vb=(Mb|0)>-1?Mb:-Mb|0;if((Vb|0)<(c[ka>>2]<<3|0)){Rb=oc-ac|0;rc=(Rb|0)/2|0;uc=((d[Pb]|0)-oc<<1)+((dc-(d[Pb+1|0]|0)|0)*5|0)|0;dc=(ac-(d[Pb+7|0]|0)<<1)+(((d[Pb+6|0]|0)-hc|0)*5|0)|0;hc=(uc|0)>-1?uc:-uc|0;uc=(dc|0)>-1?dc:-dc|0;dc=Vb-((hc|0)>(uc|0)?uc:hc)|0;hc=ca((dc|0)>0?(dc*5|0)+32>>6:0,(Mb>>31&2)-1|0)|0;if((Rb|0)>1){Rb=(hc|0)<0?0:hc;Pc=(Rb|0)>(rc|0)?rc:Rb}else{Rb=(hc|0)>0?0:hc;Pc=(Rb|0)<(rc|0)?rc:Rb}a[_b]=oc-Pc;a[Tb]=Pc+ac}if((Nb|0)>=8){break c}Nb=Nb+1|0;Pb=Pb+h|0}}Pb=c[ka>>2]|0;Nb=Pb<<1;ac=Pb<<2;Tb=a[Zb]|0;if(((Tb&255)+Nb-(d[Eb+1|0]|0)|0)>>>0>ac>>>0){break}if(((d[Eb+u|0]|0)+Nb-(d[Eb+Ra|0]|0)|0)>>>0>ac>>>0){break}if(((d[Eb+M|0]|0)+Nb-(d[Eb+kb|0]|0)|0)>>>0>ac>>>0){break}if(((d[Eb+lb|0]|0)+Nb-(d[Eb+mb|0]|0)|0)>>>0>ac>>>0){break}if(((d[Eb+nb|0]|0)+Nb-(d[Eb+ob|0]|0)|0)>>>0>ac>>>0){break}if(((d[Eb+pb|0]|0)+Nb-(d[Eb+qb|0]|0)|0)>>>0>ac>>>0){break}if(((d[Eb+rb|0]|0)+Nb-(d[Eb+sb|0]|0)|0)>>>0>ac>>>0){break}if(((d[Eb+tb|0]|0)+Nb-(d[Eb+ub|0]|0)|0)>>>0>ac>>>0){break}else{Qc=1;Rc=Zb;Sc=Tb;Tc=Pb}while(1){Pb=a[Rc-1|0]|0;Tb=Sc&255;ac=(Pb&255)-Tb|0;Nb=((((ac|0)>-1?ac:-ac|0)|0)<(Tc|0)?Pb:Sc)&255;Pb=a[Rc+8|0]|0;ac=Rc+7|0;oc=a[ac]|0;_b=oc&255;Rb=(Pb&255)-_b|0;rc=((((Rb|0)>-1?Rb:-Rb|0)|0)<(Tc|0)?Pb:oc)&255;oc=Rc+1|0;Pb=d[oc]|0;Rb=Rc+2|0;hc=d[Rb]|0;Mb=Tb+4+Pb+hc+(Nb<<2)|0;dc=Rc+3|0;uc=d[dc]|0;Vb=Mb-Nb+uc|0;Yb=Rc+4|0;lc=d[Yb]|0;Wb=Vb-Nb+lc|0;Ub=Rc+5|0;sc=d[Ub]|0;pc=Wb-Nb+sc|0;mc=Rc+6|0;cc=d[mc]|0;Qb=pc-Nb+cc|0;Nb=Qb-Tb+_b|0;tc=Nb-Pb+rc|0;vc=tc-hc+rc|0;wc=vc-uc+rc|0;a[Rc]=(Mb+(Tb<<1)+Wb|0)>>>4;a[oc]=(Vb+(Pb<<1)+pc|0)>>>4;a[Rb]=(Wb+(hc<<1)+Qb|0)>>>4;a[dc]=(pc+(uc<<1)+Nb|0)>>>4;a[Yb]=(Qb+(lc<<1)+tc|0)>>>4;a[Ub]=(Nb+(sc<<1)+vc|0)>>>4;a[mc]=(tc+(cc<<1)+wc|0)>>>4;a[ac]=((_b<<1)-lc+rc+vc+wc|0)>>>4;wc=Rc+h|0;if((Qc|0)>=8){break c}Qc=Qc+1|0;Rc=wc;Sc=a[wc]|0;Tc=c[ka>>2]|0}}if(jb){break}Zb=c[ka>>2]|0;wc=((ca(c[Na>>2]|0,c[da>>2]|0)|0)>>8)+1|0;vc=wc<<1|1;rc=Zb<<1;lc=Zb<<3;_b=1;ac=Eb-4|0;while(1){cc=a[ac-1|0]|0;tc=cc&255;mc=a[ac]|0;sc=mc&255;Nb=(tc+wc-sc|0)>>>0<vc>>>0;Ub=ac+1|0;Qb=a[Ub]|0;Yb=Qb&255;uc=ac+2|0;pc=a[uc]|0;dc=pc&255;hc=ac+3|0;Wb=a[hc]|0;Rb=Wb&255;Pb=ac+4|0;Vb=a[Pb]|0;oc=Vb&255;Tb=Rb-oc|0;Mb=ac+5|0;kc=a[Mb]|0;gc=kc&255;Sb=ac+6|0;qc=a[Sb]|0;nc=qc&255;bc=ac+7|0;ec=a[bc]|0;jc=ec&255;fc=a[ac+8|0]|0;ic=fc&255;do{if((((Yb+wc-dc|0)>>>0<vc>>>0)+((sc+wc-Yb|0)>>>0<vc>>>0?Nb?2:1:Nb&1)+((dc+wc-Rb|0)>>>0<vc>>>0)+((Tb+wc|0)>>>0<vc>>>0)+((oc+wc-gc|0)>>>0<vc>>>0)+((gc+wc-nc|0)>>>0<vc>>>0)+((nc+wc-jc|0)>>>0<vc>>>0)+((jc+wc-ic|0)>>>0<vc>>>0)|0)>(c[Pa>>2]|0)){Mc=(mc&255)>>>0>(Qb&255)>>>0;xc=Mc?sc:Yb;Jc=Mc?Yb:sc;if((pc&255)>>>0>(Wb&255)>>>0){Uc=Rb>>>0<Jc>>>0?Rb:Jc;Vc=dc>>>0>xc>>>0?dc:xc}else{Uc=dc>>>0<Jc>>>0?dc:Jc;Vc=Rb>>>0>xc>>>0?Rb:xc}if((Vb&255)>>>0>(kc&255)>>>0){Wc=(gc|0)<(Uc|0)?gc:Uc;Xc=(oc|0)>(Vc|0)?oc:Vc}else{Wc=(oc|0)<(Uc|0)?oc:Uc;Xc=(gc|0)>(Vc|0)?gc:Vc}if((qc&255)>>>0>(ec&255)>>>0){Yc=(jc|0)<(Wc|0)?jc:Wc;Zc=(nc|0)>(Xc|0)?nc:Xc}else{Yc=(nc|0)<(Wc|0)?nc:Wc;Zc=(jc|0)>(Xc|0)?jc:Xc}if((Zc-Yc|0)>=(rc|0)){break}xc=tc-sc|0;Jc=((((xc|0)>-1?xc:-xc|0)|0)<(Zb|0)?cc:mc)&255;xc=ic-jc|0;Mc=((((xc|0)>-1?xc:-xc|0)|0)<(Zb|0)?fc:ec)&255;xc=sc+4+Yb+dc+(Jc<<2)|0;zc=xc-Jc+Rb|0;Kc=zc-Jc+oc|0;Lc=Kc-Jc+gc|0;Ic=Lc-Jc+nc|0;Jc=Ic-sc+jc|0;Hc=Jc-Yb+Mc|0;Gc=Hc-dc+Mc|0;yc=Gc-Rb+Mc|0;a[ac]=(xc+(sc<<1)+Kc|0)>>>4;a[Ub]=(zc+(Yb<<1)+Lc|0)>>>4;a[uc]=(Kc+(dc<<1)+Ic|0)>>>4;a[hc]=(Lc+(Rb<<1)+Jc|0)>>>4;a[Pb]=(Ic+(oc<<1)+Hc|0)>>>4;a[Mb]=(Jc+(gc<<1)+Gc|0)>>>4;a[Sb]=(Hc+(nc<<1)+yc|0)>>>4;a[bc]=((jc<<1)-oc+Mc+Gc+yc|0)>>>4}else{yc=(dc-gc<<1)+((oc-Rb|0)*5|0)|0;Gc=(yc|0)>-1?yc:-yc|0;if((Gc|0)>=(lc|0)){break}Mc=(Tb|0)/2|0;Hc=(sc-Rb<<1)+((dc-Yb|0)*5|0)|0;Jc=(oc-jc<<1)+((nc-gc|0)*5|0)|0;Ic=(Hc|0)>-1?Hc:-Hc|0;Hc=(Jc|0)>-1?Jc:-Jc|0;Jc=Gc-((Ic|0)>(Hc|0)?Hc:Ic)|0;Ic=ca((Jc|0)>0?(Jc*5|0)+32>>6:0,(yc>>31&2)-1|0)|0;if((Tb|0)>1){yc=(Ic|0)<0?0:Ic;_c=(yc|0)>(Mc|0)?Mc:yc}else{yc=(Ic|0)>0?0:Ic;_c=(yc|0)<(Mc|0)?Mc:yc}a[hc]=Rb-_c;a[Pb]=_c+oc}}while(0);if((_b|0)>=8){break c}_b=_b+1|0;ac=ac+h|0}}else{ac=Eb-4|0;_b=5949576;if((c[_b>>2]|0)==0&(c[_b+4>>2]|0)==0){_b=0;while(1){lc=(_b|0)<128?_b:_b-256|0;Zb=((lc<<1|0)/16|0)&255;rc=((lc*6|0|0)/16|0)&255;vc=((lc*10|0|0)/16|0)&255;wc=xrc(0,0,Zb,0)|0;oc=G&0;Pb=xrc(0,0,rc,0)|0;Rb=G;hc=xrc(0,0,vc,0)|0;Tb=hc&255;hc=G&0;gc=5947536+(_b<<3)|0;c[gc>>2]=wc&255|(0<<24|0>>>8)|(0<<16|0>>>16)|(0<<8|0>>>24)|(Pb<<8|0>>>24)&65280|(Tb<<24|0>>>8)|(Tb<<16|0>>>16);c[gc+4>>2]=oc|(Zb<<24|0>>>8)|(rc<<16|0>>>16)|(vc<<8|0>>>24)|(Rb<<8|Pb>>>24)&0|((lc*14|0|0)/16|0)&255|(hc<<24|Tb>>>8)|(hc<<16|Tb>>>16);Tb=_b+1|0;if((Tb|0)<256){_b=Tb}else{$c=0;ad=ac;break}}}else{$c=0;ad=ac}while(1){_b=ad+1|0;Tb=d[_b]|0;hc=ad+2|0;lc=d[hc]|0;Pb=Tb-lc|0;Rb=ad+3|0;vc=d[Rb]|0;rc=ad+4|0;Zb=d[rc]|0;oc=vc-Zb|0;gc=ad+5|0;wc=d[gc]|0;nc=ad+6|0;jc=d[nc]|0;Yb=wc-jc|0;dc=((oc|0)>-1?oc:-oc|0)-((((Yb|0)>-1?Yb:-Yb|0)+((Pb|0)>-1?Pb:-Pb|0)|0)/2|0)|0;Pb=(dc|0)>0?dc:0;if((Pb|0)<(Ob|0)){dc=ca(Pb,(oc>>31&2)-1|0)|0;oc=(dc|0)/8|0;a[_b]=oc+Tb;Tb=(dc|0)/4|0;a[hc]=Tb+lc;lc=(dc*3|0|0)/8|0;a[Rb]=lc+vc;a[rc]=Zb-lc;a[gc]=wc-Tb;a[nc]=jc-oc}oc=$c+1|0;if((oc|0)<8){$c=oc;ad=ad+h|0}else{break}}}}while(0);if(Fb){wvb(Eb+ja|0,h,c[ka>>2]|0)}if(ia){break}xvb(Eb-8|0,h,(c[fa>>2]|0)+(Ib+yb)|0,(c[ga>>2]|0)+(Hb+(Ib>>3)<<2)|0,n)}}while(0);ac=Eb+8|0;oc=Ib+8|0;if((oc|0)<(j|0)){Gb=Gb+8|0;Eb=ac;Ib=oc}else{bd=ac;cd=oc;break}}}else{bd=Jb;cd=0}if(la&(wb|0)>0){wvb(bd+ja|0,h,c[ka>>2]|0)}if(!ia){xvb(bd-8|0,h,(c[fa>>2]|0)+(cd+yb)|0,(c[ga>>2]|0)+((wb<<5)+256+(cd>>3)<<2)|0,n)}d:do{if(Db){Ib=k-wb|0;if(!ta){if((Ib|0)>0){dd=0}else{break}while(1){Eb=dd+1|0;nrc(f+(ca(dd+wb|0,h)|0)|0,D+((ca(Eb,h)|0)+32)|0,j)|0;if((Eb|0)<(Ib|0)){dd=Eb}else{break d}}}if(A){nrc(zb|0,aa|0,ca(Ib,h)|0)|0;break}else{nrc(oa|0,D+((ca(Ib-1|0,h)|0)+T)|0,ca(Ib,s)|0)|0;break}}}while(0);wb=wb+8|0;}while((wb|0)<(k|0));nrc(p|0,o|0,1208)|0;i=q;return}function qvb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b<<2;e=b<<1;f=b*3|0;g=b*6|0;h=b*5|0;i=b<<3;j=b*7|0;k=c[a+d>>2]|0;l=c[a+(d+e)>>2]|0;c[a+(d+b)>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[a+(b<<3)>>2]|0;c[a+(d+f)>>2]=(k|l)-((k^l)>>>1&2139062143);l=c[a+(d+g)>>2]|0;c[a+(d+h)>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[a+(d+i)>>2]|0;c[a+(d+j)>>2]=(k|l)-((k^l)>>>1&2139062143);l=d+4|0;k=c[a+l>>2]|0;m=c[a+(l+e)>>2]|0;c[a+(l+b)>>2]=(m|k)-((m^k)>>>1&2139062143);k=c[a+(l+d)>>2]|0;c[a+(l+f)>>2]=(k|m)-((k^m)>>>1&2139062143);m=c[a+(l+g)>>2]|0;c[a+(l+h)>>2]=(m|k)-((m^k)>>>1&2139062143);k=c[a+(l+i)>>2]|0;c[a+(l+j)>>2]=(k|m)-((k^m)>>>1&2139062143);return}function rvb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b<<2;f=b<<1;g=b*3|0;h=b*5|0;i=b*6|0;j=b*7|0;k=b<<3;l=d;d=a+e|0;a=0;while(1){m=l;n=c[m>>2]|0;o=d;p=c[o>>2]|0;q=d+b|0;r=c[q>>2]|0;s=((r^n)>>>1&2139062143)+(r&n)|0;c[o>>2]=(s|p)-((s^p)>>>1&2139062143);s=d+f|0;o=c[s>>2]|0;n=((o^p)>>>1&2139062143)+(o&p)|0;c[q>>2]=(n|r)-((n^r)>>>1&2139062143);n=d+g|0;q=c[n>>2]|0;p=((q^r)>>>1&2139062143)+(q&r)|0;c[s>>2]=(p|o)-((p^o)>>>1&2139062143);p=d+e|0;s=c[p>>2]|0;r=((s^o)>>>1&2139062143)+(s&o)|0;c[n>>2]=(r|q)-((r^q)>>>1&2139062143);r=d+h|0;n=c[r>>2]|0;o=((n^q)>>>1&2139062143)+(n&q)|0;c[p>>2]=(o|s)-((o^s)>>>1&2139062143);o=d+i|0;p=c[o>>2]|0;q=((p^s)>>>1&2139062143)+(p&s)|0;c[r>>2]=(q|n)-((q^n)>>>1&2139062143);q=d+j|0;r=c[q>>2]|0;s=((r^n)>>>1&2139062143)+(r&n)|0;c[o>>2]=(s|p)-((s^p)>>>1&2139062143);s=c[d+k>>2]|0;o=((s^p)>>>1&2139062143)+(s&p)|0;c[q>>2]=(o|r)-((o^r)>>>1&2139062143);c[m>>2]=r;r=a+1|0;if((r|0)<2){l=l+4|0;d=d+4|0;a=r}else{break}}return}function svb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c<<1;f=0;g=b+(c<<2)|0;while(1){b=d[g]|0;h=g+c|0;i=d[h]|0;j=g+e|0;k=d[j]|0;l=b-i>>31;m=i-k>>31;n=k-b>>31;a[h]=(n^l|b)&(m^l|i)&(m^n|k);k=d[j]|0;j=g+(e+c)|0;n=d[j]|0;m=c<<2;i=g+m|0;l=d[i]|0;b=k-n>>31;h=n-l>>31;o=l-k>>31;a[j]=(o^b|k)&(h^b|n)&(h^o|l);l=d[i]|0;i=g+(m+c)|0;o=d[i]|0;h=m+e|0;m=g+h|0;n=d[m]|0;b=l-o>>31;k=o-n>>31;j=n-l>>31;a[i]=(j^b|l)&(k^b|o)&(k^j|n);n=d[m]|0;m=g+(h+c)|0;j=d[m]|0;k=d[g+(h+e)|0]|0;h=n-j>>31;o=j-k>>31;b=k-n>>31;a[m]=(b^h|n)&(o^h|j)&(o^b|k);k=f+1|0;if((k|0)<8){f=k;g=g+1|0}else{break}}return}function tvb(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c*3|0;f=c<<1;g=c<<2;h=c*6|0;i=c<<3;j=c*5|0;k=c*10|0;l=c*7|0;m=c*12|0;n=c*9|0;c=b+e|0;b=0;while(1){o=c+f|0;p=c+g|0;q=c+h|0;r=(((d[p]|0)+(d[o]|0)|0)*9|0)-((d[q]|0)+(d[c]|0))>>4;if(r>>>0>255>>>0){s=-r>>31&255}else{s=r&255}a[c+e|0]=s;r=c+i|0;t=(((d[q]|0)+(d[p]|0)|0)*9|0)-((d[r]|0)+(d[o]|0))>>4;if(t>>>0>255>>>0){u=-t>>31&255}else{u=t&255}a[c+j|0]=u;t=c+k|0;o=(((d[r]|0)+(d[q]|0)|0)*9|0)-((d[t]|0)+(d[p]|0))>>4;if(o>>>0>255>>>0){v=-o>>31&255}else{v=o&255}a[c+l|0]=v;o=(((d[t]|0)+(d[r]|0)|0)*9|0)-((d[c+m|0]|0)+(d[q]|0))>>4;if(o>>>0>255>>>0){w=-o>>31&255}else{w=o&255}a[c+n|0]=w;o=b+1|0;if((o|0)<8){c=c+1|0;b=o}else{break}}return}function uvb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=c<<2;g=c<<1;h=c*3|0;i=c*5|0;j=c*6|0;k=c*7|0;l=c<<3;m=c*9|0;n=0;o=b+f|0;while(1){b=e+n|0;p=o+c|0;q=d[p]|0;r=o+g|0;s=o+h|0;t=4-(d[b]|0)+(q<<1)+((d[o]|0)<<2)+((d[r]|0)<<2)-(d[s]|0)>>3;if(t>>>0>255>>>0){u=-t>>31&255}else{u=t&255}a[p]=u;p=o+f|0;t=d[p]|0;v=o+i|0;w=4-q+((d[r]|0)<<2)-(d[v]|0)+(t*6|0)>>3;if(w>>>0>255>>>0){x=-w>>31&255}else{x=w&255}a[s]=x;s=o+j|0;w=d[s]|0;r=o+k|0;q=4-t+((d[p]|0)<<2)-(d[r]|0)+(w*6|0)>>3;if(q>>>0>255>>>0){y=-q>>31&255}else{y=q&255}a[v]=y;v=a[o+l|0]|0;q=4-w+((d[s]|0)<<2)-(d[o+m|0]|0)+((v&255)*6|0)>>3;if(q>>>0>255>>>0){z=-q>>31&255}else{z=q&255}a[r]=z;a[b]=v;v=n+1|0;if((v|0)<8){n=v;o=o+1|0}else{break}}return}function vvb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=c<<2;h=c<<1;i=c*3|0;j=c*5|0;k=c*6|0;l=c*7|0;m=c<<3;n=c*9|0;o=0;p=b+g|0;while(1){b=e+o|0;q=f+o|0;r=d[q]|0;s=d[p]|0;t=p+h|0;u=p+c|0;v=4-(d[b]|0)-(d[t]|0)+(s*6|0)+((d[u]|0)+r<<1)>>3;if(v>>>0>255>>>0){w=-v>>31&255}else{w=v&255}a[p]=w;v=d[u]|0;x=p+i|0;y=4-r-(d[x]|0)+(v*6|0)+((d[t]|0)+s<<1)>>3;if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}a[u]=z;u=d[t]|0;y=p+g|0;r=4-s-(d[y]|0)+(u*6|0)+((d[x]|0)+v<<1)>>3;if(r>>>0>255>>>0){A=-r>>31&255}else{A=r&255}a[t]=A;t=d[x]|0;r=p+j|0;s=4-v-(d[r]|0)+(t*6|0)+((d[y]|0)+u<<1)>>3;if(s>>>0>255>>>0){B=-s>>31&255}else{B=s&255}a[x]=B;x=d[y]|0;s=p+k|0;v=4-u-(d[s]|0)+(x*6|0)+((d[r]|0)+t<<1)>>3;if(v>>>0>255>>>0){C=-v>>31&255}else{C=v&255}a[y]=C;y=d[r]|0;v=p+l|0;u=4-t-(d[v]|0)+(y*6|0)+((d[s]|0)+x<<1)>>3;if(u>>>0>255>>>0){D=-u>>31&255}else{D=u&255}a[r]=D;r=a[s]|0;u=r&255;t=p+m|0;E=4-x-(d[t]|0)+(u*6|0)+((d[v]|0)+y<<1)>>3;if(E>>>0>255>>>0){F=-E>>31&255}else{F=E&255}a[s]=F;s=a[v]|0;E=4-y-(d[p+n|0]|0)+((s&255)*6|0)+((d[t]|0)+u<<1)>>3;if(E>>>0>255>>>0){G=-E>>31&255}else{G=E&255}a[v]=G;a[b]=r;a[q]=s;s=o+1|0;if((s|0)<8){o=s;p=p+1|0}else{break}}return}function wvb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+40|0;h=g|0;j=(f|0)/2|0;f=0;k=255;l=1;do{m=ca(l,e)|0;n=d[b+m|0]|0;o=(n|0)>(f|0)?n:f;p=(n|0)<(k|0)?n:k;n=d[b+(m+1)|0]|0;q=(n|0)>(o|0)?n:o;o=(n|0)<(p|0)?n:p;p=d[b+(m+2)|0]|0;n=(p|0)>(q|0)?p:q;q=(p|0)<(o|0)?p:o;o=d[b+(m+3)|0]|0;p=(o|0)>(n|0)?o:n;n=(o|0)<(q|0)?o:q;q=d[b+(m+4)|0]|0;o=(q|0)>(p|0)?q:p;p=(q|0)<(n|0)?q:n;n=d[b+(m+5)|0]|0;q=(n|0)>(o|0)?n:o;o=(n|0)<(p|0)?n:p;p=d[b+(m+6)|0]|0;n=(p|0)>(q|0)?p:q;q=(p|0)<(o|0)?p:o;o=d[b+(m+7)|0]|0;f=(o|0)>(n|0)?o:n;k=(o|0)<(q|0)?o:q;l=l+1|0;}while((l|0)<9);l=j+1|0;j=f+1+k>>1;if((f-k|0)<20){i=g;return}else{r=0}do{k=ca(r,e)|0;f=(d[b+(k-1)|0]|0|0)>(j|0)|0;q=(d[b+k|0]|0|0)>(j|0)?f|2:f;f=(d[b+(k+1)|0]|0|0)>(j|0)?q|4:q;q=(d[b+(k+2)|0]|0|0)>(j|0)?f|8:f;f=(d[b+(k+3)|0]|0|0)>(j|0)?q+16|0:q;q=(d[b+(k+4)|0]|0|0)>(j|0)?f+32|0:f;f=(d[b+(k+5)|0]|0|0)>(j|0)?q+64|0:q;q=(d[b+(k+6)|0]|0|0)>(j|0)?f+128|0:f;f=(d[b+(k+7)|0]|0|0)>(j|0)?q+256|0:q;q=(d[b+(k+8)|0]|0|0)>(j|0)?f+512|0:f;f=q<<16^-65536|q;c[h+(r<<2)>>2]=f>>1&f&f<<1;r=r+1|0;}while((r|0)<10);r=h|0;j=h+4|0;f=c[j>>2]|0;q=h+8|0;k=c[q>>2]|0;o=f&c[r>>2]&k;n=o>>16|o;c[r>>2]=n;r=h+12|0;o=c[r>>2]|0;m=k&f&o;c[j>>2]=m>>16|m;m=h+16|0;j=c[m>>2]|0;f=o&k&j;c[q>>2]=f>>16|f;f=h+20|0;q=c[f>>2]|0;k=j&o&q;c[r>>2]=k>>16|k;k=h+24|0;r=c[k>>2]|0;o=q&j&r;c[m>>2]=o>>16|o;o=h+28|0;m=c[o>>2]|0;j=r&q&m;c[f>>2]=j>>16|j;j=c[h+32>>2]|0;f=m&r&j;c[k>>2]=f>>16|f;f=j&m&c[h+36>>2];c[o>>2]=f>>16|f;f=1-e|0;o=f-1|0;m=f+1|0;j=e+1|0;k=e+2|0;r=1;q=n;while(1){n=b+((ca(r,e)|0)-1)|0;p=1;while(1){s=n+1|0;do{if((1<<p&q|0)!=0){t=d[s]|0;u=(d[n+o|0]|0)+8+(d[n+m|0]|0)+(t<<2)+(d[n+e|0]|0)+(d[n+k|0]|0)+((d[n]|0)+(d[n+f|0]|0)+(d[n+2|0]|0)+(d[n+j|0]|0)<<1)>>4;v=t+l|0;if((v|0)<(u|0)){a[s]=v;break}v=t-l|0;if((v|0)>(u|0)){a[s]=v;break}else{a[s]=u;break}}}while(0);u=p+1|0;if((u|0)<9){n=s;p=u}else{break}}p=r+1|0;if((p|0)>=9){break}n=c[h+(r<<2)>>2]|0;r=p;q=n}i=g;return}function xvb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[g+508>>2]=c[h>>2];i=h+4|0;c[g+512>>2]=c[i>>2];j=h+8|0;c[g+516>>2]=c[j>>2];k=0;l=0;do{m=ca(l,e)|0;n=(d[f+m|0]|0)-(d[b+m|0]|0)|0;o=(ca(n,n)|0)+k|0;n=m+1|0;p=(d[f+n|0]|0)-(d[b+n|0]|0)|0;n=(ca(p,p)|0)+o|0;o=m+2|0;p=(d[f+o|0]|0)-(d[b+o|0]|0)|0;o=(ca(p,p)|0)+n|0;n=m+3|0;p=(d[f+n|0]|0)-(d[b+n|0]|0)|0;n=(ca(p,p)|0)+o|0;o=m+4|0;p=(d[f+o|0]|0)-(d[b+o|0]|0)|0;o=(ca(p,p)|0)+n|0;n=m+5|0;p=(d[f+n|0]|0)-(d[b+n|0]|0)|0;n=(ca(p,p)|0)+o|0;o=m+6|0;p=(d[f+o|0]|0)-(d[b+o|0]|0)|0;o=(ca(p,p)|0)+n|0;n=m+7|0;m=(d[f+n|0]|0)-(d[b+n|0]|0)|0;k=(ca(m,m)|0)+o|0;l=l+1|0;}while((l|0)<8);l=((k<<2)+4+(c[g-1024>>2]|0)+(c[g-4>>2]|0)+(c[g+4>>2]|0)+(c[g+1024>>2]|0)|0)>>>3;c[g>>2]=k;if((l|0)>(c[i>>2]|0)){if((l|0)<(c[j>>2]|0)){j=0;do{i=ca(j,e)|0;k=f+i|0;g=b+i|0;o=((d[k]|0)+1+(d[g]|0)|0)>>>1&255;a[g]=o;a[k]=o;o=i+1|0;k=f+o|0;g=b+o|0;o=((d[k]|0)+1+(d[g]|0)|0)>>>1&255;a[g]=o;a[k]=o;o=i+2|0;k=f+o|0;g=b+o|0;o=((d[k]|0)+1+(d[g]|0)|0)>>>1&255;a[g]=o;a[k]=o;o=i+3|0;k=f+o|0;g=b+o|0;o=((d[k]|0)+1+(d[g]|0)|0)>>>1&255;a[g]=o;a[k]=o;o=i+4|0;k=f+o|0;g=b+o|0;o=((d[k]|0)+1+(d[g]|0)|0)>>>1&255;a[g]=o;a[k]=o;o=i+5|0;k=f+o|0;g=b+o|0;o=((d[k]|0)+1+(d[g]|0)|0)>>>1&255;a[g]=o;a[k]=o;o=i+6|0;k=f+o|0;g=b+o|0;o=((d[k]|0)+1+(d[g]|0)|0)>>>1&255;a[g]=o;a[k]=o;o=i+7|0;i=f+o|0;k=b+o|0;o=((d[i]|0)+1+(d[k]|0)|0)>>>1&255;a[k]=o;a[i]=o;j=j+1|0;}while((j|0)<8);return}else{j=0;do{o=ca(j,e)|0;a[f+o|0]=a[b+o|0]|0;i=o+1|0;a[f+i|0]=a[b+i|0]|0;i=o+2|0;a[f+i|0]=a[b+i|0]|0;i=o+3|0;a[f+i|0]=a[b+i|0]|0;i=o+4|0;a[f+i|0]=a[b+i|0]|0;i=o+5|0;a[f+i|0]=a[b+i|0]|0;i=o+6|0;a[f+i|0]=a[b+i|0]|0;i=o+7|0;a[f+i|0]=a[b+i|0]|0;j=j+1|0;}while((j|0)<8);return}}else{if((l|0)<(c[h>>2]|0)){h=0;do{l=ca(h,e)|0;j=f+l|0;i=b+l|0;o=((d[i]|0)+4+((d[j]|0)*7|0)|0)>>>3&255;a[i]=o;a[j]=o;o=l+1|0;j=f+o|0;i=b+o|0;o=((d[i]|0)+4+((d[j]|0)*7|0)|0)>>>3&255;a[i]=o;a[j]=o;o=l+2|0;j=f+o|0;i=b+o|0;o=((d[i]|0)+4+((d[j]|0)*7|0)|0)>>>3&255;a[i]=o;a[j]=o;o=l+3|0;j=f+o|0;i=b+o|0;o=((d[i]|0)+4+((d[j]|0)*7|0)|0)>>>3&255;a[i]=o;a[j]=o;o=l+4|0;j=f+o|0;i=b+o|0;o=((d[i]|0)+4+((d[j]|0)*7|0)|0)>>>3&255;a[i]=o;a[j]=o;o=l+5|0;j=f+o|0;i=b+o|0;o=((d[i]|0)+4+((d[j]|0)*7|0)|0)>>>3&255;a[i]=o;a[j]=o;o=l+6|0;j=f+o|0;i=b+o|0;o=((d[i]|0)+4+((d[j]|0)*7|0)|0)>>>3&255;a[i]=o;a[j]=o;o=l+7|0;l=f+o|0;j=b+o|0;o=((d[j]|0)+4+((d[l]|0)*7|0)|0)>>>3&255;a[j]=o;a[l]=o;h=h+1|0;}while((h|0)<8);return}else{h=0;do{o=ca(h,e)|0;l=f+o|0;j=b+o|0;i=((d[j]|0)+2+((d[l]|0)*3|0)|0)>>>2&255;a[j]=i;a[l]=i;i=o+1|0;l=f+i|0;j=b+i|0;i=((d[j]|0)+2+((d[l]|0)*3|0)|0)>>>2&255;a[j]=i;a[l]=i;i=o+2|0;l=f+i|0;j=b+i|0;i=((d[j]|0)+2+((d[l]|0)*3|0)|0)>>>2&255;a[j]=i;a[l]=i;i=o+3|0;l=f+i|0;j=b+i|0;i=((d[j]|0)+2+((d[l]|0)*3|0)|0)>>>2&255;a[j]=i;a[l]=i;i=o+4|0;l=f+i|0;j=b+i|0;i=((d[j]|0)+2+((d[l]|0)*3|0)|0)>>>2&255;a[j]=i;a[l]=i;i=o+5|0;l=f+i|0;j=b+i|0;i=((d[j]|0)+2+((d[l]|0)*3|0)|0)>>>2&255;a[j]=i;a[l]=i;i=o+6|0;l=f+i|0;j=b+i|0;i=((d[j]|0)+2+((d[l]|0)*3|0)|0)>>>2&255;a[j]=i;a[l]=i;i=o+7|0;o=f+i|0;l=b+i|0;i=((d[l]|0)+2+((d[o]|0)*3|0)|0)>>>2&255;a[l]=i;a[o]=i;h=h+1|0;}while((h|0)<8);return}}}function yvb(a){a=a|0;return 2439136}function zvb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0,k=0;if((a|0)==0){e=-22;return e|0}if((c[a+6964>>2]|0)!=0){e=-22;return e|0}mrc(a+6984|0,0,4096)|0;f=a+24|0;i=rGb(c[f>>2]|0,c[f+4>>2]|0)|0;f=a+32|0;j=rGb(c[f>>2]|0,c[f+4>>2]|0)|0;if((j|0)>0&(i|0)>0){f=b;b=0;while(1){k=0;do{g[a+6984+(b<<7)+(k<<2)>>2]=+h[f+(k<<3)>>3];k=k+1|0;}while((k|0)<(i|0));k=b+1|0;if((k|0)<(j|0)){f=f+(d<<3)|0;b=k}else{break}}}c[a+5704>>2]=1;e=0;return e|0}function Avb(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0.0,E=0.0,F=0,H=0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0;d=i;i=i+33024|0;e=d+128|0;f=b+24|0;j=rGb(c[f>>2]|0,c[f+4>>2]|0)|0;k=b+32|0;l=rGb(c[k>>2]|0,c[k+4>>2]|0)|0;m=b+16264|0;c[m>>2]=0;a:do{if((c[b+5704>>2]|0)==0){n=d+32896|0;mrc(e|0,0,32768)|0;o=c[b+72>>2]|0;p=c[f>>2]|0;q=c[f+4>>2]|0;r=d|0;do{if((p|0)==4&(q|0)==0|(p|0)==0&(q|0)==0){s=5}else{t=wrc(p,q,-1,-1)|0;if(!((t&p|0)==0&(G&q|0)==0)){s=5;break}sGb(r,128,-1,p,q);KIb(b,40,2116416,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;v=0;w=4}}while(0);if((s|0)==5){q=p;v=(q|0)<0|0?-1:0;w=q}q=c[k>>2]|0;t=c[k+4>>2]|0;do{if((q|0)==4&(t|0)==0|(q|0)==0&(t|0)==0){s=9}else{x=wrc(q,t,-1,-1)|0;if(!((x&q|0)==0&(G&t|0)==0)){s=9;break}sGb(r,128,-1,q,t);KIb(b,40,2116416,(u=i,i=i+8|0,c[u>>2]=r,u)|0);i=u;y=0;z=4}}while(0);do{if((s|0)==9){r=q;t=r;p=(r|0)<0|0?-1:0;if((r|0)!=1610612736){y=p;z=t;break}r=(w&1610612736|0)==0&(v&0|0)==0;y=r?0:p;z=r?3:t}}while(0);do{if(!((w&7|0)==0&(v&0|0)==0)){q=w&3;t=v&0;r=(q|0)==0&(t|0)==0;if(!r){p=wrc(w,v,3,0)|0;if((p&q|0)==0&(G&t|0)==0){break}}t=w&1536;q=v&0;if(!((t|0)==0&(q|0)==0)){p=wrc(t,q,2047,0)|0;if((p&t|0)==0&(G&q|0)==0){break}}q=w&48;t=v&0;if(!((q|0)==0&(t|0)==0)){p=wrc(q,t,63,0)|0;if((p&q|0)==0&(G&t|0)==0){break}}t=w&192;q=v&0;if(!((t|0)==0&(q|0)==0)){p=wrc(t,q,255,0)|0;if((p&t|0)==0&(G&q|0)==0){break}}if((rGb(w,v)|0)>=32){break}do{if(!((z&7|0)==0&(y&0|0)==0)){q=z&3;t=y&0;if(!((q|0)==0&(t|0)==0)){p=wrc(z,y,3,0)|0;if((p&q|0)==0&(G&t|0)==0){break}}p=z&1536;x=y&0;if(!((p|0)==0&(x|0)==0)){A=wrc(p,x,2047,0)|0;if((A&p|0)==0&(G&x|0)==0){break}}x=z&48;p=y&0;if(!((x|0)==0&(p|0)==0)){A=wrc(x,p,63,0)|0;if((A&x|0)==0&(G&p|0)==0){break}}p=z&192;x=y&0;if(!((p|0)==0&(x|0)==0)){A=wrc(p,x,255,0)|0;if((A&p|0)==0&(G&x|0)==0){break}}if((rGb(z,y)|0)>=32){break}mrc(b+6984|0,0,4096)|0;x=z&w;p=y&v;A=0;do{B=yrc(1,0,A|0)|0;if(!((x&B|0)==0&(p&G|0)==0)){h[e+(A<<9)+(A<<3)>>3]=1.0}A=A+1|0;}while((A|0)<64);A=w&~z;p=v&~y;do{if(!((A&4|0)==0&(p&0|0)==0)){if(!((q|0)==3&(t|0)==0)){KIb(0,0,2421912,(u=i,i=i+24|0,c[u>>2]=2580456,c[u+8>>2]=2436848,c[u+16>>2]=164,u)|0);i=u;Hd();return 0}if(r){x=e+16|0;h[x>>3]=+h[x>>3]+.7071067811865476;x=e+528|0;h[x>>3]=+h[x>>3]+.7071067811865476;break}else{C=+g[b+56>>2];x=e+16|0;h[x>>3]=+h[x>>3]+C;x=e+528|0;h[x>>3]=C+ +h[x>>3];break}}}while(0);do{if(!((A&3|0)==0&(p&0|0)==0)){if((z&4|0)==0&(y&0|0)==0){KIb(0,0,2421912,(u=i,i=i+24|0,c[u>>2]=2580456,c[u+8>>2]=2436848,c[u+16>>2]=173,u)|0);i=u;Hd();return 0}t=e+1024|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+1032|0;h[t>>3]=+h[t>>3]+.7071067811865476;if((w&4|0)==0&(v&0|0)==0){break}h[e+1040>>3]=+g[b+56>>2]*1.4142135623730951}}while(0);do{if(!((A&256|0)==0&(p&0|0)==0)){if(!((z&16|0)==0&(y&0|0)==0)){t=e+2112|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+2624|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}if(!((z&512|0)==0&(y&0|0)==0)){t=e+4672|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+5184|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}if((z&1|0)==0&(y&0|0)==0){if((z&4|0)==0&(y&0|0)==0){KIb(0,0,2421912,(u=i,i=i+24|0,c[u>>2]=2580456,c[u+8>>2]=2436848,c[u+16>>2]=200,u)|0);i=u;Hd();return 0}else{t=e+1088|0;h[t>>3]=+h[t>>3]+ +g[b+52>>2]*.7071067811865476;break}}if(!((o-1|0)>>>0<2>>>0)){C=+g[b+52>>2]*.7071067811865476;t=e+64|0;h[t>>3]=+h[t>>3]+C;t=e+576|0;h[t>>3]=+h[t>>3]+C;break}C=+g[b+52>>2];if((A&528|0)==0&(p&0|0)==0){t=e+64|0;h[t>>3]=+h[t>>3]-C;t=e+576|0;h[t>>3]=C+ +h[t>>3];break}else{D=C*.7071067811865476;t=e+64|0;h[t>>3]=+h[t>>3]-D;t=e+576|0;h[t>>3]=D+ +h[t>>3];break}}}while(0);do{if(!((A&16|0)==0&(p&0|0)==0)){if(!((z&256|0)==0&(y&0|0)==0)){t=e+4128|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+4136|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}if(!((z&512|0)==0&(y&0|0)==0)){t=e+4640|0;D=+h[t>>3];if((w&512|0)==0&(v&0|0)==0){h[t>>3]=D+1.0;q=e+5160|0;h[q>>3]=+h[q>>3]+1.0;break}else{h[t>>3]=D+.7071067811865476;t=e+5160|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}}if((z&1|0)==0&(y&0|0)==0){if((z&4|0)==0&(y&0|0)==0){KIb(0,0,2421912,(u=i,i=i+24|0,c[u>>2]=2580456,c[u+8>>2]=2436848,c[u+16>>2]=233,u)|0);i=u;Hd();return 0}else{D=+g[b+52>>2]*.7071067811865476;t=e+1056|0;h[t>>3]=+h[t>>3]+D;t=e+1064|0;h[t>>3]=+h[t>>3]+D;break}}if((o|0)==1){D=+g[b+52>>2]*.7071067811865476;t=e+32|0;h[t>>3]=+h[t>>3]-D;t=e+40|0;h[t>>3]=+h[t>>3]-D;t=e+544|0;h[t>>3]=D+ +h[t>>3];t=e+552|0;h[t>>3]=D+ +h[t>>3];break}D=+g[b+52>>2];if((o|0)==2){C=D*1.224744871391589;t=e+32|0;h[t>>3]=+h[t>>3]-C;E=D*.7071067811865476;t=e+40|0;h[t>>3]=+h[t>>3]-E;t=e+544|0;h[t>>3]=E+ +h[t>>3];t=e+552|0;h[t>>3]=C+ +h[t>>3];break}else{t=e+32|0;h[t>>3]=D+ +h[t>>3];t=e+552|0;h[t>>3]=D+ +h[t>>3];break}}}while(0);do{if(!((A&512|0)==0&(p&0|0)==0)){if(!((z&16|0)==0&(y&0|0)==0)){t=e+2120|0;D=+h[t>>3];if((w&16|0)==0&(v&0|0)==0){h[t>>3]=D+1.0;q=e+2640|0;h[q>>3]=+h[q>>3]+1.0;break}else{h[t>>3]=D+.7071067811865476;t=e+2640|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}}if(!((z&256|0)==0&(y&0|0)==0)){t=e+4168|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+4176|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}if((z&1|0)==0&(y&0|0)==0){if((z&4|0)==0&(y&0|0)==0){KIb(0,0,2421912,(u=i,i=i+24|0,c[u>>2]=2580456,c[u+8>>2]=2436848,c[u+16>>2]=269,u)|0);i=u;Hd();return 0}else{D=+g[b+52>>2]*.7071067811865476;t=e+1096|0;h[t>>3]=+h[t>>3]+D;t=e+1104|0;h[t>>3]=+h[t>>3]+D;break}}if((o|0)==1){D=+g[b+52>>2]*.7071067811865476;t=e+72|0;h[t>>3]=+h[t>>3]-D;t=e+80|0;h[t>>3]=+h[t>>3]-D;t=e+584|0;h[t>>3]=D+ +h[t>>3];t=e+592|0;h[t>>3]=D+ +h[t>>3];break}D=+g[b+52>>2];if((o|0)==2){C=D*1.224744871391589;t=e+72|0;h[t>>3]=+h[t>>3]-C;E=D*.7071067811865476;t=e+80|0;h[t>>3]=+h[t>>3]-E;t=e+584|0;h[t>>3]=E+ +h[t>>3];t=e+592|0;h[t>>3]=C+ +h[t>>3];break}else{t=e+72|0;h[t>>3]=D+ +h[t>>3];t=e+592|0;h[t>>3]=D+ +h[t>>3];break}}}while(0);do{if(!((A&64|0)==0&(p&0|0)==0)){if(!((z&1|0)==0&(y&0|0)==0)){t=e+48|0;h[t>>3]=+h[t>>3]+1.0;t=e+568|0;h[t>>3]=+h[t>>3]+1.0;break}if((z&4|0)==0&(y&0|0)==0){KIb(0,0,2421912,(u=i,i=i+24|0,c[u>>2]=2580456,c[u+8>>2]=2436848,c[u+16>>2]=280,u)|0);i=u;Hd();return 0}else{t=e+1072|0;h[t>>3]=+h[t>>3]+.7071067811865476;t=e+1080|0;h[t>>3]=+h[t>>3]+.7071067811865476;break}}}while(0);do{if((A&8|0)==0&(p&0|0)==0){F=0;H=0;I=0.0}else{if(!((z&4|0)==0&(y&0|0)==0)){t=e+1048|0;h[t>>3]=+h[t>>3]+ +g[b+60>>2];F=0;H=0;I=0.0;break}if((z&1|0)==0&(y&0|0)==0){KIb(0,0,2421912,(u=i,i=i+24|0,c[u>>2]=2580456,c[u+8>>2]=2436848,c[u+16>>2]=290,u)|0);i=u;Hd();return 0}else{D=+g[b+60>>2]*.7071067811865476;t=e+24|0;h[t>>3]=+h[t>>3]+D;t=e+536|0;h[t>>3]=+h[t>>3]+D;F=0;H=0;I=0.0;break}}}while(0);while(1){p=0;D=0.0;A=0;while(1){C=+h[e+(H<<9)+(p<<3)>>3];g[b+6984+(F<<7)+(A<<2)>>2]=C;if(C!=0.0){J=D+ +R(+C)}else{J=D}t=yrc(1,0,p|0)|0;q=p+1|0;if((q|0)<64){p=q;D=J;A=(((t&w|0)!=0|(G&v|0)!=0)&1)+A|0}else{break}}K=I>J?I:J;A=yrc(1,0,H|0)|0;p=H+1|0;if((p|0)<64){F=(((A&z|0)!=0|(G&y|0)!=0)&1)+F|0;H=p;I=K}else{break}}p=b+64|0;D=+g[p>>2];if(D<0.0){L=-0.0-D}else{L=K}D=+g[b+68>>2];do{if(D>0.0){M=D}else{if((NKb(c[b+20>>2]|0)|0)<3){M=1.0;break}A=(NKb(c[b+16>>2]|0)|0)<3;M=A?1.0:2147483648.0}}while(0);if(L>M){s=119}else{D=+g[p>>2];if(D<0.0){s=119}else{N=D}}if((s|0)==119){D=L/M;A=0;do{t=0;do{q=b+6984+(A<<7)+(t<<2)|0;g[q>>2]=+g[q>>2]/D;t=t+1|0;}while((t|0)<32);A=A+1|0;}while((A|0)<32);N=+g[p>>2]}if(N>0.0){A=0;do{t=0;do{q=b+6984+(A<<7)+(t<<2)|0;g[q>>2]=+g[p>>2]*+g[q>>2];t=t+1|0;}while((t|0)<32);A=A+1|0;}while((A|0)<32)}if((rGb(z,y)|0)>0){O=0}else{break a}while(1){if((rGb(w,v)|0)>0){A=0;do{KIb(0,48,2166112,(u=i,i=i+8|0,h[u>>3]=+g[b+6984+(O<<7)+(A<<2)>>2],u)|0);i=u;A=A+1|0;}while((A|0)<(rGb(w,v)|0))}KIb(0,48,2139800,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;O=O+1|0;if((O|0)>=(rGb(z,y)|0)){break a}}}}while(0);sGb(n,128,-1,c[k>>2]|0,c[k+4>>2]|0);KIb(b,16,2197624,(u=i,i=i+8|0,c[u>>2]=n,u)|0);i=u;P=-22;i=d;return P|0}}while(0);sGb(n,128,-1,c[f>>2]|0,c[f+4>>2]|0);KIb(b,16,2238280,(u=i,i=i+8|0,c[u>>2]=n,u)|0);i=u;P=-22;i=d;return P|0}}while(0);y=c[b+6160>>2]|0;if((y|0)==6){z=b+11080|0;c[z>>2]=qJb(ca(l,j)|0,4)|0;O=pJb(4)|0;v=b+11084|0;c[v>>2]=O;if((l|0)>0&(j|0)>0){w=0;do{H=ca(w,j)|0;F=0;do{e=Lc(+(+g[b+6984+(w<<7)+(F<<2)>>2]*32768.0))|0;c[(c[z>>2]|0)+(F+H<<2)>>2]=e;F=F+1|0;}while((F|0)<(j|0));w=w+1|0;}while((w|0)<(l|0));Q=c[v>>2]|0}else{Q=O}c[Q>>2]=32768;c[b+16248>>2]=266;c[b+16256>>2]=280;do{if((c[k>>2]|0)==3&(c[k+4>>2]|0)==0){Q=c[f>>2]|0;O=c[f+4>>2]|0;v=1599;w=0;if((Q|0)==1551&(O|0)==0|(Q|0)==63&(O|0)==0){if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=154;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=154;break}if(+g[b+6988>>2]!=0.0){s=154;break}if(+g[b+7004>>2]!=0.0){s=154;break}if(+g[b+7112>>2]!=0.0){s=154;break}if(+g[b+7128>>2]!=0.0){s=154;break}else{S=264;break}}else if(!((Q|0)==(v|0)&(O|0)==(w|0))){s=154;break}if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=154;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=154;break}if(+g[b+6988>>2]!=0.0){s=154;break}if(+g[b+7004>>2]!=0.0){s=154;break}if(+g[b+7112>>2]!=0.0){s=154;break}if(+g[b+7128>>2]!=0.0){s=154;break}if(+g[b+7012>>2]!=0.0){s=154;break}if(+g[b+7136>>2]!=0.0){s=154}else{S=1022}}else{s=154}}while(0);if((s|0)==154){S=0}c[m>>2]=S;T=0}else if((y|0)==7){S=pJb(4)|0;c[b+11084>>2]=S;c[S>>2]=32768;c[b+16248>>2]=240;c[b+16256>>2]=292;do{if((c[k>>2]|0)==3&(c[k+4>>2]|0)==0){S=c[f>>2]|0;w=c[f+4>>2]|0;O=1599;v=0;if((S|0)==1551&(w|0)==0|(S|0)==63&(w|0)==0){if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=216;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=216;break}if(+g[b+6988>>2]!=0.0){s=216;break}if(+g[b+7004>>2]!=0.0){s=216;break}if(+g[b+7112>>2]!=0.0){s=216;break}if(+g[b+7128>>2]!=0.0){s=216;break}else{U=286;break}}else if(!((S|0)==(O|0)&(w|0)==(v|0))){s=216;break}if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=216;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=216;break}if(+g[b+6988>>2]!=0.0){s=216;break}if(+g[b+7004>>2]!=0.0){s=216;break}if(+g[b+7112>>2]!=0.0){s=216;break}if(+g[b+7128>>2]!=0.0){s=216;break}if(+g[b+7012>>2]!=0.0){s=216;break}if(+g[b+7136>>2]!=0.0){s=216}else{U=30}}else{s=216}}while(0);if((s|0)==216){U=0}c[m>>2]=U;T=0}else if((y|0)==9){U=b+11080|0;c[U>>2]=qJb(ca(l,j)|0,8)|0;v=pJb(8)|0;c[b+11084>>2]=v;if((l|0)>0&(j|0)>0){w=0;do{O=ca(w,j)|0;S=c[U>>2]|0;Q=0;do{h[S+(Q+O<<3)>>3]=+g[b+6984+(w<<7)+(Q<<2)>>2];Q=Q+1|0;}while((Q|0)<(j|0));w=w+1|0;}while((w|0)<(l|0))}h[v>>3]=1.0;c[b+16248>>2]=296;c[b+16256>>2]=62;do{if((c[k>>2]|0)==3&(c[k+4>>2]|0)==0){v=c[f>>2]|0;w=c[f+4>>2]|0;U=1599;Q=0;if((v|0)==1551&(w|0)==0|(v|0)==63&(w|0)==0){if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=198;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=198;break}if(+g[b+6988>>2]!=0.0){s=198;break}if(+g[b+7004>>2]!=0.0){s=198;break}if(+g[b+7112>>2]!=0.0){s=198;break}if(+g[b+7128>>2]!=0.0){s=198;break}else{V=284;break}}else if(!((v|0)==(U|0)&(w|0)==(Q|0))){s=198;break}if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=198;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=198;break}if(+g[b+6988>>2]!=0.0){s=198;break}if(+g[b+7004>>2]!=0.0){s=198;break}if(+g[b+7112>>2]!=0.0){s=198;break}if(+g[b+7128>>2]!=0.0){s=198;break}if(+g[b+7012>>2]!=0.0){s=198;break}if(+g[b+7136>>2]!=0.0){s=198}else{V=128}}else{s=198}}while(0);if((s|0)==198){V=0}c[m>>2]=V;T=0}else if((y|0)==8){y=b+11080|0;c[y>>2]=qJb(ca(l,j)|0,4)|0;V=pJb(4)|0;c[b+11084>>2]=V;if((l|0)>0&(j|0)>0){Q=0;do{w=ca(Q,j)|0;U=c[y>>2]|0;v=0;do{g[U+(v+w<<2)>>2]=+g[b+6984+(Q<<7)+(v<<2)>>2];v=v+1|0;}while((v|0)<(j|0));Q=Q+1|0;}while((Q|0)<(l|0))}g[V>>2]=1.0;c[b+16248>>2]=132;c[b+16256>>2]=184;do{if((c[k>>2]|0)==3&(c[k+4>>2]|0)==0){V=c[f>>2]|0;l=c[f+4>>2]|0;Q=1599;j=0;if((V|0)==1551&(l|0)==0|(V|0)==63&(l|0)==0){if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=176;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=176;break}if(+g[b+6988>>2]!=0.0){s=176;break}if(+g[b+7004>>2]!=0.0){s=176;break}if(+g[b+7112>>2]!=0.0){s=176;break}if(+g[b+7128>>2]!=0.0){s=176;break}else{W=942;break}}else if(!((V|0)==(Q|0)&(l|0)==(j|0))){s=176;break}if(!(+g[b+6992>>2]==+g[b+7120>>2])){s=176;break}if(!(+g[b+6996>>2]==+g[b+7124>>2])){s=176;break}if(+g[b+6988>>2]!=0.0){s=176;break}if(+g[b+7004>>2]!=0.0){s=176;break}if(+g[b+7112>>2]!=0.0){s=176;break}if(+g[b+7128>>2]!=0.0){s=176;break}if(+g[b+7012>>2]!=0.0){s=176;break}if(+g[b+7136>>2]!=0.0){s=176}else{W=970}}else{s=176}}while(0);if((s|0)==176){W=0}c[m>>2]=W;T=0}else{KIb(0,0,2421912,(u=i,i=i+24|0,c[u>>2]=2580456,c[u+8>>2]=2436848,c[u+16>>2]=397,u)|0);i=u;Hd();return 0}while(1){u=0;W=0;while(1){m=b+6984+(T<<7)+(u<<2)|0;c[b+11096+(T<<7)+(u<<2)>>2]=Lc(+(+g[m>>2]*32768.0))|0;if(+g[m>>2]!=0.0){m=W+1|0;a[b+15192+(T*33|0)+m|0]=u;X=m}else{X=W}m=u+1|0;if((m|0)<32){u=m;W=X}else{break}}a[b+15192+(T*33|0)|0]=X;W=T+1|0;if((W|0)<32){T=W}else{P=0;break}}i=d;return P|0}function Bvb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=c[e+(f<<2)>>2]|0;if((g|0)>0){i=0}else{return}do{b[a+(i<<1)>>1]=((ca(b[d+(i<<1)>>1]|0,h)|0)+16384|0)>>>15;i=i+1|0;}while((i|0)<(g|0));return}function Cvb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=c[f+(g<<2)>>2]|0;g=c[f+(h<<2)>>2]|0;if((i|0)>0){k=0}else{return}do{h=ca(b[d+(k<<1)>>1]|0,j)|0;b[a+(k<<1)>>1]=(h+16384+(ca(b[e+(k<<1)>>1]|0,g)|0)|0)>>>15;k=k+1|0;}while((k|0)<(i|0));return}function Dvb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,h=0;f=+g[c+(d<<2)>>2];if((e|0)>0){h=0}else{return}do{g[a+(h<<2)>>2]=f*+g[b+(h<<2)>>2];h=h+1|0;}while((h|0)<(e|0));return}function Evb(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0.0,j=0.0,k=0;i=+g[d+(e<<2)>>2];j=+g[d+(f<<2)>>2];if((h|0)>0){k=0}else{return}do{g[a+(k<<2)>>2]=i*+g[b+(k<<2)>>2]+j*+g[c+(k<<2)>>2];k=k+1|0;}while((k|0)<(h|0));return}function Fvb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0.0,g=0;f=+h[c+(d<<3)>>3];if((e|0)>0){g=0}else{return}do{h[a+(g<<3)>>3]=f*+h[b+(g<<3)>>3];g=g+1|0;}while((g|0)<(e|0));return}function Gvb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0.0,j=0.0,k=0;i=+h[d+(e<<3)>>3];j=+h[d+(f<<3)>>3];if((g|0)>0){k=0}else{return}do{h[a+(k<<3)>>3]=i*+h[b+(k<<3)>>3]+j*+h[c+(k<<3)>>3];k=k+1|0;}while((k|0)<(g|0));return}function Hvb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=c[d+(e<<2)>>2]|0;e=g;d=(g|0)<0|0?-1:0;if((f|0)>0){h=0}else{return}do{g=c[b+(h<<2)>>2]|0;i=Erc(g,(g|0)<0|0?-1:0,e,d)|0;g=wrc(i,G,16384,0)|0;c[a+(h<<2)>>2]=g>>>15|G<<17;h=h+1|0;}while((h|0)<(f|0));return}function Ivb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=c[e+(f<<2)>>2]|0;f=i;j=(i|0)<0|0?-1:0;i=c[e+(g<<2)>>2]|0;g=i;e=(i|0)<0|0?-1:0;if((h|0)>0){k=0}else{return}do{i=c[b+(k<<2)>>2]|0;l=Erc(i,(i|0)<0|0?-1:0,f,j)|0;i=G;m=c[d+(k<<2)>>2]|0;n=Erc(m,(m|0)<0|0?-1:0,g,e)|0;m=G;o=wrc(l,i,16384,0)|0;i=wrc(o,G,n,m)|0;c[a+(k<<2)>>2]=i>>>15|G<<17;k=k+1|0;}while((k|0)<(h|0));return}function Jvb(a){a=a|0;mJb(a+11080|0);mJb(a+11084|0);mJb(a+11092|0);mJb(a+11088|0);return}function Kvb(e,f,j,k,l){e=e|0;f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0,O=0.0,P=0,Q=0,R=0.0,S=0.0,T=0;m=i;n=c[e+16264>>2]|0;if((n|0)!=0){mf[n&2047](f|0,j|0,c[e+11080>>2]|0,k);i=m;return 0}n=e+16260|0;if((c[n>>2]|0)==0){if((c[e+16252>>2]|0)==0){o=0;p=0}else{q=5}}else{q=5}if((q|0)==5){q=k&-16;o=ca(c[f+136>>2]|0,q)|0;p=q}q=e+32|0;r=c[q>>2]|0;s=c[q+4>>2]|0;do{if(!((r|0)==0&(s|0)==0)){q=c[f+132>>2]|0;if((q|0)==(rGb(r,s)|0)){break}KIb(0,0,2421912,(t=i,i=i+24|0,c[t>>2]=2350064,c[t+8>>2]=2436848,c[t+16>>2]=436,t)|0);i=t;Hd();return 0}}while(0);s=e+24|0;r=c[s>>2]|0;q=c[s+4>>2]|0;do{if(!((r|0)==0&(q|0)==0)){s=c[j+132>>2]|0;if((s|0)==(rGb(r,q)|0)){break}KIb(0,0,2421912,(t=i,i=i+24|0,c[t>>2]=2288288,c[t+8>>2]=2436848,c[t+16>>2]=437,t)|0);i=t;Hd();return 0}}while(0);t=f+132|0;if((c[t>>2]|0)<=0){i=m;return 0}q=e+16|0;r=(k|0)>0;s=(l|0)==0;l=e+16252|0;u=(p|0)==0;v=(p|0)==(k|0);w=e+16248|0;x=e+11080|0;y=j+132|0;z=k-p|0;A=e+11092|0;B=f+136|0;C=e+16256|0;D=0;do{E=e+15192+(D*33|0)|0;F=a[E]|0;G=F&255;a:do{if((G|0)==0){if(s){break}H=c[f+(D<<2)>>2]|0;mrc(H|0,0,ca(QKb(c[q>>2]|0)|0,k)|0)|0}else if((G|0)==2){H=d[e+15192+(D*33|0)+1|0]|0;I=d[e+15192+(D*33|0)+2|0]|0;J=c[n>>2]|0;if((J|0)==0|u){K=ca(c[y>>2]|0,D)|0;Se[c[C>>2]&1023](c[f+(D<<2)>>2]|0,c[j+(H<<2)>>2]|0,c[j+(I<<2)>>2]|0,c[x>>2]|0,K+H|0,K+I|0,p)}else{K=ca(c[y>>2]|0,D)|0;Se[J&1023](c[f+(D<<2)>>2]|0,c[j+(H<<2)>>2]|0,c[j+(I<<2)>>2]|0,c[A>>2]|0,K+H|0,K+I|0,p)}if(v){break}K=ca(c[y>>2]|0,D)|0;Se[c[C>>2]&1023]((c[f+(D<<2)>>2]|0)+o|0,(c[j+(H<<2)>>2]|0)+o|0,(c[j+(I<<2)>>2]|0)+o|0,c[x>>2]|0,K+H|0,K+I|0,z)}else if((G|0)==1){I=d[e+15192+(D*33|0)+1|0]|0;if(!(+g[e+6984+(D<<7)+(I<<2)>>2]!=1.0)){if(s){c[f+(D<<2)>>2]=c[j+(I<<2)>>2];break}else{nrc(c[f+(D<<2)>>2]|0,c[j+(I<<2)>>2]|0,ca(c[B>>2]|0,k)|0)|0;break}}K=c[l>>2]|0;if(!((K|0)==0|u)){H=(ca(c[y>>2]|0,D)|0)+I|0;pe[K&1023](c[f+(D<<2)>>2]|0,c[j+(I<<2)>>2]|0,c[A>>2]|0,H,p)}if(v){break}H=(ca(c[y>>2]|0,D)|0)+I|0;pe[c[w>>2]&1023]((c[f+(D<<2)>>2]|0)+o|0,(c[j+(I<<2)>>2]|0)+o|0,c[x>>2]|0,H,z)}else{H=c[q>>2]|0;if((H|0)==8){if(!r){break}I=f+(D<<2)|0;K=0;J=F;while(1){if(J<<24>>24==0){L=0.0}else{M=J&255;N=0;O=0.0;while(1){P=N+1|0;Q=d[e+15192+(D*33|0)+P|0]|0;R=O+ +g[(c[j+(Q<<2)>>2]|0)+(K<<2)>>2]*+g[e+6984+(D<<7)+(Q<<2)>>2];if((P|0)<(M|0)){N=P;O=R}else{L=R;break}}}g[(c[I>>2]|0)+(K<<2)>>2]=L;N=K+1|0;if((N|0)>=(k|0)){break a}K=N;J=a[E]|0}}else if((H|0)==9){if(!r){break}J=f+(D<<2)|0;K=0;I=F;while(1){if(I<<24>>24==0){S=0.0}else{N=I&255;M=0;O=0.0;while(1){P=M+1|0;Q=d[e+15192+(D*33|0)+P|0]|0;R=O+ +h[(c[j+(Q<<2)>>2]|0)+(K<<3)>>3]*+g[e+6984+(D<<7)+(Q<<2)>>2];if((P|0)<(N|0)){M=P;O=R}else{S=R;break}}}h[(c[J>>2]|0)+(K<<3)>>3]=S;M=K+1|0;if((M|0)>=(k|0)){break a}K=M;I=a[E]|0}}else{if(!r){break}I=f+(D<<2)|0;K=0;J=F;while(1){if(J<<24>>24==0){T=0}else{H=J&255;M=0;N=0;do{M=M+1|0;P=d[e+15192+(D*33|0)+M|0]|0;N=(ca(b[(c[j+(P<<2)>>2]|0)+(K<<1)>>1]|0,c[e+11096+(D<<7)+(P<<2)>>2]|0)|0)+N|0;}while((M|0)<(H|0));T=(N+16384|0)>>>15&65535}b[(c[I>>2]|0)+(K<<1)>>1]=T;H=K+1|0;if((H|0)>=(k|0)){break a}K=H;J=a[E]|0}}}}while(0);D=D+1|0;}while((D|0)<(c[t>>2]|0));i=m;return 0}function Lvb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((e|0)<=0){return}f=c[b+8>>2]|0;g=d+8|0;h=c[b+12>>2]|0;i=d+12|0;j=c[b>>2]|0;k=c[b+16>>2]|0;l=d+16|0;m=c[a>>2]|0;n=c[b+4>>2]|0;o=d+28|0;p=c[b+20>>2]|0;b=d+44|0;q=c[a+4>>2]|0;a=0;do{r=c[f+(a<<2)>>2]|0;s=c[g>>2]|0;t=Erc(s,(s|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;r=G;s=c[h+(a<<2)>>2]|0;u=c[i>>2]|0;v=Erc(u,(u|0)<0|0?-1:0,s,(s|0)<0|0?-1:0)|0;s=wrc(v,G,t,r)|0;r=G;t=c[j+(a<<2)>>2]|0;v=c[d>>2]|0;u=Erc(v,(v|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;t=G;v=c[k+(a<<2)>>2]|0;w=c[l>>2]|0;x=Erc(w,(w|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=G;w=wrc(s,r,16384,0)|0;r=G;s=wrc(w,r,u,t)|0;t=wrc(s,G,x,v)|0;c[m+(a<<2)>>2]=t>>>15|G<<17;t=c[n+(a<<2)>>2]|0;v=c[o>>2]|0;x=Erc(v,(v|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;t=G;v=c[p+(a<<2)>>2]|0;s=c[b>>2]|0;u=Erc(s,(s|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=G;s=wrc(w,r,x,t)|0;t=wrc(s,G,u,v)|0;c[q+(a<<2)>>2]=t>>>15|G<<17;a=a+1|0;}while((a|0)<(e|0));return}function Mvb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((e|0)<=0){return}f=c[b+8>>2]|0;g=d+8|0;h=c[b+12>>2]|0;i=d+12|0;j=c[b>>2]|0;k=c[b+16>>2]|0;l=d+16|0;m=c[b+24>>2]|0;n=d+24|0;o=c[a>>2]|0;p=c[b+4>>2]|0;q=d+36|0;r=c[b+20>>2]|0;s=d+52|0;t=c[b+28>>2]|0;b=d+60|0;u=c[a+4>>2]|0;a=0;do{v=c[f+(a<<2)>>2]|0;w=c[g>>2]|0;x=Erc(w,(w|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=G;w=c[h+(a<<2)>>2]|0;y=c[i>>2]|0;z=Erc(y,(y|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=wrc(z,G,x,v)|0;v=G;x=c[j+(a<<2)>>2]|0;z=c[d>>2]|0;y=Erc(z,(z|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=G;z=c[k+(a<<2)>>2]|0;A=c[l>>2]|0;B=Erc(A,(A|0)<0|0?-1:0,z,(z|0)<0|0?-1:0)|0;z=G;A=c[m+(a<<2)>>2]|0;C=c[n>>2]|0;D=Erc(C,(C|0)<0|0?-1:0,A,(A|0)<0|0?-1:0)|0;A=G;C=wrc(w,v,16384,0)|0;v=G;w=wrc(C,v,y,x)|0;x=wrc(w,G,B,z)|0;z=wrc(x,G,D,A)|0;c[o+(a<<2)>>2]=z>>>15|G<<17;z=c[p+(a<<2)>>2]|0;A=c[q>>2]|0;D=Erc(A,(A|0)<0|0?-1:0,z,(z|0)<0|0?-1:0)|0;z=G;A=c[r+(a<<2)>>2]|0;x=c[s>>2]|0;B=Erc(x,(x|0)<0|0?-1:0,A,(A|0)<0|0?-1:0)|0;A=G;x=c[t+(a<<2)>>2]|0;w=c[b>>2]|0;y=Erc(w,(w|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=G;w=wrc(C,v,D,z)|0;z=wrc(w,G,B,A)|0;A=wrc(z,G,y,x)|0;c[u+(a<<2)>>2]=A>>>15|G<<17;a=a+1|0;}while((a|0)<(e|0));return}function Nvb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0;if((e|0)<=0){return}f=c[b+8>>2]|0;g=d+16|0;i=c[b+12>>2]|0;j=d+24|0;k=c[b>>2]|0;l=c[b+16>>2]|0;m=d+32|0;n=c[a>>2]|0;o=c[b+4>>2]|0;p=d+56|0;q=c[b+20>>2]|0;b=d+88|0;r=c[a+4>>2]|0;a=0;do{s=+h[f+(a<<3)>>3]*+h[g>>3]+ +h[i+(a<<3)>>3]*+h[j>>3];h[n+(a<<3)>>3]=s+ +h[k+(a<<3)>>3]*+h[d>>3]+ +h[l+(a<<3)>>3]*+h[m>>3];h[r+(a<<3)>>3]=s+ +h[o+(a<<3)>>3]*+h[p>>3]+ +h[q+(a<<3)>>3]*+h[b>>3];a=a+1|0;}while((a|0)<(e|0));return}function Ovb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;if((e|0)<=0){return}f=c[b+8>>2]|0;g=d+16|0;i=c[b+12>>2]|0;j=d+24|0;k=c[b>>2]|0;l=c[b+16>>2]|0;m=d+32|0;n=c[b+24>>2]|0;o=d+48|0;p=c[a>>2]|0;q=c[b+4>>2]|0;r=d+72|0;s=c[b+20>>2]|0;t=d+104|0;u=c[b+28>>2]|0;b=d+120|0;v=c[a+4>>2]|0;a=0;do{w=+h[f+(a<<3)>>3]*+h[g>>3]+ +h[i+(a<<3)>>3]*+h[j>>3];h[p+(a<<3)>>3]=w+ +h[k+(a<<3)>>3]*+h[d>>3]+ +h[l+(a<<3)>>3]*+h[m>>3]+ +h[n+(a<<3)>>3]*+h[o>>3];h[v+(a<<3)>>3]=w+ +h[q+(a<<3)>>3]*+h[r>>3]+ +h[s+(a<<3)>>3]*+h[t>>3]+ +h[u+(a<<3)>>3]*+h[b>>3];a=a+1|0;}while((a|0)<(e|0));return}function Pvb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0;if((e|0)<=0){return}f=c[b+8>>2]|0;h=d+8|0;i=c[b+12>>2]|0;j=d+12|0;k=c[b>>2]|0;l=c[b+16>>2]|0;m=d+16|0;n=c[a>>2]|0;o=c[b+4>>2]|0;p=d+28|0;q=c[b+20>>2]|0;b=d+44|0;r=c[a+4>>2]|0;a=0;do{s=+g[f+(a<<2)>>2]*+g[h>>2]+ +g[i+(a<<2)>>2]*+g[j>>2];g[n+(a<<2)>>2]=s+ +g[k+(a<<2)>>2]*+g[d>>2]+ +g[l+(a<<2)>>2]*+g[m>>2];g[r+(a<<2)>>2]=s+ +g[o+(a<<2)>>2]*+g[p>>2]+ +g[q+(a<<2)>>2]*+g[b>>2];a=a+1|0;}while((a|0)<(e|0));return}function Qvb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;if((e|0)<=0){return}f=c[b+8>>2]|0;h=d+8|0;i=c[b+12>>2]|0;j=d+12|0;k=c[b>>2]|0;l=c[b+16>>2]|0;m=d+16|0;n=c[b+24>>2]|0;o=d+24|0;p=c[a>>2]|0;q=c[b+4>>2]|0;r=d+36|0;s=c[b+20>>2]|0;t=d+52|0;u=c[b+28>>2]|0;b=d+60|0;v=c[a+4>>2]|0;a=0;do{w=+g[f+(a<<2)>>2]*+g[h>>2]+ +g[i+(a<<2)>>2]*+g[j>>2];g[p+(a<<2)>>2]=w+ +g[k+(a<<2)>>2]*+g[d>>2]+ +g[l+(a<<2)>>2]*+g[m>>2]+ +g[n+(a<<2)>>2]*+g[o>>2];g[v+(a<<2)>>2]=w+ +g[q+(a<<2)>>2]*+g[r>>2]+ +g[s+(a<<2)>>2]*+g[t>>2]+ +g[u+(a<<2)>>2]*+g[b>>2];a=a+1|0;}while((a|0)<(e|0));return}function Rvb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((f|0)<=0){return}g=c[d+8>>2]|0;h=c[e+8>>2]|0;i=c[d+12>>2]|0;j=c[e+12>>2]|0;k=c[d>>2]|0;l=c[e>>2]|0;m=c[d+16>>2]|0;n=c[e+16>>2]|0;o=c[a>>2]|0;p=c[d+4>>2]|0;q=c[e+28>>2]|0;r=c[d+20>>2]|0;d=c[e+44>>2]|0;e=c[a+4>>2]|0;a=0;do{s=ca(b[g+(a<<1)>>1]|0,h)|0;t=(ca(b[i+(a<<1)>>1]|0,j)|0)+s|0;s=ca(b[k+(a<<1)>>1]|0,l)|0;u=t+16384|0;b[o+(a<<1)>>1]=(u+s+(ca(b[m+(a<<1)>>1]|0,n)|0)|0)>>>15;s=ca(b[p+(a<<1)>>1]|0,q)|0;b[e+(a<<1)>>1]=(u+s+(ca(b[r+(a<<1)>>1]|0,d)|0)|0)>>>15;a=a+1|0;}while((a|0)<(f|0));return}function Svb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((f|0)<=0){return}g=c[d+8>>2]|0;h=c[e+8>>2]|0;i=c[d+12>>2]|0;j=c[e+12>>2]|0;k=c[d>>2]|0;l=c[e>>2]|0;m=c[d+16>>2]|0;n=c[e+16>>2]|0;o=c[d+24>>2]|0;p=c[e+24>>2]|0;q=c[a>>2]|0;r=c[d+4>>2]|0;s=c[e+36>>2]|0;t=c[d+20>>2]|0;u=c[e+52>>2]|0;v=c[d+28>>2]|0;d=c[e+60>>2]|0;e=c[a+4>>2]|0;a=0;do{w=ca(b[g+(a<<1)>>1]|0,h)|0;x=(ca(b[i+(a<<1)>>1]|0,j)|0)+w|0;w=ca(b[k+(a<<1)>>1]|0,l)|0;y=ca(b[m+(a<<1)>>1]|0,n)|0;z=x+16384|0;b[q+(a<<1)>>1]=(z+w+y+(ca(b[o+(a<<1)>>1]|0,p)|0)|0)>>>15;y=ca(b[r+(a<<1)>>1]|0,s)|0;w=ca(b[t+(a<<1)>>1]|0,u)|0;b[e+(a<<1)>>1]=(z+y+w+(ca(b[v+(a<<1)>>1]|0,d)|0)|0)>>>15;a=a+1|0;}while((a|0)<(f|0));return}function Tvb(){return 4708}function Uvb(){return 2420992}function Vvb(a,b){a=a|0;b=b|0;var d=0;do{if((a|0)==0){d=-22}else{if((c[a+6964>>2]|0)!=0){d=-22;break}c[a+76>>2]=b;d=0}}while(0);return d|0}function Wvb(){return 2004304}function Xvb(){var a=0,b=0;a=pJb(16272)|0;b=a;if((a|0)==0){return b|0}c[a>>2]=2004304;SJb(a);return b|0}function Yvb(a,b,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;do{if((a|0)==0){m=pJb(16272)|0;if((m|0)==0){n=0;return n|0}else{c[m>>2]=2004304;SJb(m);o=m;break}}else{o=a}}while(0);c[o+4>>2]=k;c[o+8>>2]=l;l=o;IJb(l,2436832,b,d,0)|0;IJb(l,2350024,e,(e|0)<0|0?-1:0,0)|0;IJb(l,2288264,f,(f|0)<0|0?-1:0,0)|0;IJb(l,2238264,g,h,0)|0;IJb(l,2197616,i,(i|0)<0|0?-1:0,0)|0;IJb(l,2166104,j,(j|0)<0|0?-1:0,0)|0;IJb(l,2139792,-1,-1,0)|0;j=o+24|0;i=rGb(c[j>>2]|0,c[j+4>>2]|0)|0;IJb(l,2116408,i,(i|0)<0|0?-1:0,0)|0;i=o+32|0;j=rGb(c[i>>2]|0,c[i+4>>2]|0)|0;IJb(l,2634256,j,(j|0)<0|0?-1:0,0)|0;IJb(l,2610536,0,0,0)|0;n=o;return n|0}function Zvb(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;do{if((b|0)!=0){_vb(b);d=c[b+6980>>2]|0;if((d|0)==0){break}qe[c[d+4>>2]&1023](b+6976|0)}}while(0);mJb(a);return}function _vb(a){a=a|0;c[a+6924>>2]=0;c[a+6928>>2]=0;c[a+6932>>2]=0;mrc(a+5708|0,0,128)|0;mrc(a+6316|0,0,128)|0;kJb(c[a+5988>>2]|0);mrc(a+5860|0,0,152)|0;kJb(c[a+6140>>2]|0);mrc(a+6012|0,0,152)|0;kJb(c[a+6292>>2]|0);mrc(a+6164|0,0,152)|0;kJb(c[a+6596>>2]|0);mrc(a+6468|0,0,152)|0;kJb(c[a+6748>>2]|0);mrc(a+6620|0,0,152)|0;kJb(c[a+6900>>2]|0);mrc(a+6772|0,0,152)|0;kJb(c[a+5448>>2]|0);mrc(a+5320|0,0,152)|0;kJb(c[a+5600>>2]|0);mrc(a+5472|0,0,152)|0;owb(a+6964|0);owb(a+6968|0);owb(a+6972|0);Jvb(a);c[a+6936>>2]=0;return}function $vb(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,F=0.0,H=0,I=0,J=0,K=0;b=i;i=i+2048|0;d=b|0;e=b+1024|0;_vb(a);f=a+12|0;j=c[f>>2]|0;if((j|0)>9){KIb(a,16,2584056,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;l=-22;i=b;return l|0}j=a+20|0;m=c[j>>2]|0;if((m|0)>9){KIb(a,16,2563416,(k=i,i=i+8|0,c[k>>2]=m,k)|0);i=k;l=-22;i=b;return l|0}m=a+24|0;if((rGb(c[m>>2]|0,c[m+4>>2]|0)|0)>32){n=c[m+4>>2]|0;KIb(a,24,2545864,(k=i,i=i+16|0,c[k>>2]=c[m>>2],c[k+8>>2]=n,k)|0);i=k;c[m>>2]=0;c[m+4>>2]=0}n=a+32|0;if((rGb(c[n>>2]|0,c[n+4>>2]|0)|0)>32){o=c[n+4>>2]|0;KIb(a,24,2528008,(k=i,i=i+16|0,c[k>>2]=c[n>>2],c[k+8>>2]=o,k)|0);i=k;c[n>>2]=0;c[n+4>>2]=0}o=a+84|0;if((c[o>>2]|0)!=0){KIb(a,16,2513064,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-22;i=b;return l|0}p=a+6980|0;c[p>>2]=525376;q=a+80|0;r=c[q>>2]|0;if((r|0)==0){s=c[a+5840>>2]|0;c[q>>2]=s;if((s|0)==0){t=16}else{u=s;t=13}}else{u=r;t=13}do{if((t|0)==13){r=c[m>>2]|0;s=c[m+4>>2]|0;if((r|0)==0&(s|0)==0){t=17;break}if((u|0)==(rGb(r,s)|0)){t=16;break}KIb(a,24,2499424,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;c[m>>2]=0;c[m+4>>2]=0;t=17}}while(0);if((t|0)==16){u=c[m>>2]|0;s=c[m+4>>2]|0;if((u|0)==0&(s|0)==0){t=17}else{v=s;w=u}}if((t|0)==17){u=tGb(c[q>>2]|0)|0;s=G;c[m>>2]=u;c[m+4>>2]=s;v=s;w=u}u=c[n>>2]|0;s=c[n+4>>2]|0;if((u|0)==0&(s|0)==0){r=tGb(c[a+6448>>2]|0)|0;x=G;c[n>>2]=r;c[n+4>>2]=x;y=x;z=r;A=c[m+4>>2]|0;B=c[m>>2]|0}else{y=s;z=u;A=v;B=w}do{if((z|0)==(B|0)&(y|0)==(A|0)){if(+g[a+64>>2]!=1.0){C=1;break}C=(c[a+5704>>2]|0)!=0|0}else{C=1}}while(0);A=a+5700|0;c[A>>2]=C;C=a+16|0;y=c[C>>2]|0;a:do{if((y|0)==-1){if((OKb(c[f>>2]|0)|0)<7){c[C>>2]=6;break}do{if((OKb(c[f>>2]|0)|0)==7){if((OKb(c[j>>2]|0)|0)!=7){break}if((c[A>>2]|0)!=0){break}if((c[o>>2]|0)==1){break}c[C>>2]=7;break a}}while(0);if((OKb(c[f>>2]|0)|0)<9){c[C>>2]=8;break}else{KIb(a,48,2486912,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;c[C>>2]=9;break}}else{if((y-6|0)>>>0<4>>>0){break}B=LKb(y)|0;KIb(a,16,2475312,(k=i,i=i+8|0,c[k>>2]=B,k)|0);i=k;l=-22;i=b;return l|0}}while(0);y=a+5708|0;o=c[f>>2]|0;c[a+5856>>2]=o;c[a+5844>>2]=QKb(o)|0;c[a+5852>>2]=RKb(o)|0;o=a+6316|0;B=c[j>>2]|0;c[a+6464>>2]=B;c[a+6452>>2]=QKb(B)|0;c[a+6460>>2]=RKb(B)|0;B=a+5688|0;z=c[B>>2]|0;w=c[B+4>>2]|0;if((z|0)==0&(w|0)==(-2147483648|0)){B=a+6952|0;c[B>>2]=0;c[B+4>>2]=-2147483648;D=+g[a+5684>>2]}else{B=a+5684|0;E=+g[B>>2];do{if(E!=0.0){F=E}else{if(+g[a+5668>>2]<1.7014117331926443e+38){F=E;break}g[B>>2]=1.0;F=1.0}}while(0);B=c[a+44>>2]|0;v=Erc(B,(B|0)<0|0?-1:0,z,w)|0;w=G;z=a+6944|0;c[z>>2]=v;c[z+4>>2]=w;z=a+6952|0;c[z>>2]=v;c[z+4>>2]=w;D=F}w=a+5684|0;do{if(D!=0.0){z=a+5668|0;if(!(+g[z>>2]<1.7014117331926443e+38)){g[z>>2]=.0010000000474974513}F=+g[w>>2];if(!(F>1.0001)){break}g[a+5680>>2]=F/+(c[a+40>>2]|0)}}while(0);w=a+44|0;z=c[w>>2]|0;v=a+40|0;B=c[v>>2]|0;do{if((z|0)==(B|0)){if((c[a+48>>2]&1|0)!=0){t=49;break}qe[c[(c[p>>2]|0)+4>>2]&1023](a+6976|0)}else{t=49}}while(0);if((t|0)==49){u=a+6976|0;c[u>>2]=$e[c[c[p>>2]>>2]&3](c[u>>2]|0,z,B,c[a+5628>>2]|0,c[a+5632>>2]|0,c[a+5636>>2]|0,+h[a+5640>>3],c[C>>2]|0,c[a+5648>>2]|0,c[a+5652>>2]|0,+h[a+5656>>3],c[a+5664>>2]|0)|0}do{if(!(((c[C>>2]|0)-6|0)>>>0<4>>>0)){if((c[a+6976>>2]|0)==0){break}KIb(a,16,2466464,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}}while(0);B=a+5840|0;z=c[B>>2]|0;if((z|0)==0){u=rGb(c[m>>2]|0,c[m+4>>2]|0)|0;c[B>>2]=u;H=u}else{H=z}if((c[q>>2]|0)==0){c[q>>2]=H}z=a+6448|0;u=c[z>>2]|0;if((u|0)==0){p=rGb(c[n>>2]|0,c[n+4>>2]|0)|0;c[z>>2]=p;I=c[B>>2]|0;J=p}else{I=H;J=u}if((I|0)==0){if(!((c[m>>2]|0)==0&(c[m+4>>2]|0)==0)){KIb(0,0,2456304,(k=i,i=i+24|0,c[k>>2]=2439056,c[k+8>>2]=2428448,c[k+16>>2]=370,k)|0);i=k;Hd();return 0}KIb(a,16,2418008,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}do{if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){t=67}else{if((c[m>>2]|0)==0&(c[m+4>>2]|0)==0){t=67;break}K=c[q>>2]|0}}while(0);do{if((t|0)==67){u=c[q>>2]|0;if((u|0)==(J|0)){K=J;break}if((c[a+5704>>2]|0)!=0){K=u;break}u=d|0;sGb(u,1024,I,c[m>>2]|0,c[m+4>>2]|0);H=e|0;sGb(H,1024,c[z>>2]|0,c[n>>2]|0,c[n+4>>2]|0);KIb(a,16,2408952,(k=i,i=i+16|0,c[k>>2]=u,c[k+8>>2]=H,k)|0);i=k;l=-1;i=b;return l|0}}while(0);if((K|0)==0){KIb(0,0,2456304,(k=i,i=i+24|0,c[k>>2]=2401424,c[k+8>>2]=2428448,c[k+16>>2]=384,k)|0);i=k;Hd();return 0}if((J|0)==0){KIb(0,0,2456304,(k=i,i=i+24|0,c[k>>2]=2394560,c[k+8>>2]=2428448,c[k+16>>2]=385,k)|0);i=k;Hd();return 0}k=a+5696|0;c[k>>2]=+(((J|0)/(I|0)|0)-1|0)<+(c[w>>2]|0)/+(c[v>>2]|0)+-1.0;v=y;nrc(a+6468|0,v|0,152)|0;nrc(a+6620|0,v|0,152)|0;y=o;nrc(a+6772|0,y|0,152)|0;o=a+6976|0;do{if((c[o>>2]|0)==0){if((c[A>>2]|0)!=0){break}if((c[a+76>>2]|0)!=0){break}if((c[a+88>>2]|0)!=0){break}c[a+6972>>2]=jwb(c[j>>2]|0,c[f>>2]|0,I,0,0)|0;l=0;i=b;return l|0}}while(0);I=a+76|0;w=a+6964|0;c[w>>2]=jwb(c[C>>2]|0,c[f>>2]|0,K,c[I>>2]|0,0)|0;K=jwb(c[j>>2]|0,c[C>>2]|0,c[z>>2]|0,0,0)|0;c[a+6968>>2]=K;if((c[w>>2]|0)==0|(K|0)==0){l=-12;i=b;return l|0}nrc(a+5860|0,v|0,152)|0;nrc(a+6164|0,y|0,152)|0;nrc(a+6012|0,v|0,152)|0;do{if((c[I>>2]|0)!=0){v=c[q>>2]|0;c[a+6144>>2]=v;c[a+5992>>2]=v;if((c[o>>2]|0)==0){break}c[a+6600>>2]=v}}while(0);do{if((c[k>>2]|0)==0){q=c[z>>2]|0;c[a+6144>>2]=q;if((c[o>>2]|0)==0){break}c[a+6600>>2]=q}}while(0);z=c[C>>2]|0;c[a+6008>>2]=z;c[a+5996>>2]=QKb(z)|0;c[a+6004>>2]=RKb(z)|0;z=c[C>>2]|0;c[a+6160>>2]=z;c[a+6148>>2]=QKb(z)|0;c[a+6156>>2]=RKb(z)|0;z=c[C>>2]|0;c[a+6312>>2]=z;c[a+6300>>2]=QKb(z)|0;c[a+6308>>2]=RKb(z)|0;if((c[o>>2]|0)!=0){o=c[C>>2]|0;c[a+6616>>2]=o;c[a+6604>>2]=QKb(o)|0;c[a+6612>>2]=RKb(o)|0}o=Qwb(a,c[j>>2]|0,c[C>>2]|0)|0;if((o|0)<0){l=o;i=b;return l|0}do{if((c[A>>2]|0)==0){if((c[a+88>>2]|0)==0){l=0}else{break}i=b;return l|0}}while(0);l=Avb(a)|0;i=b;return l|0}function awb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+152|0;e=d|0;if((b|0)<0){f=-22;i=d;return f|0}g=a+136|0;h=c[g>>2]|0;j=a+132|0;k=c[j>>2]|0;if(((1073741823/(h|0)|0|0)/(k|0)|0|0)<(b|0)){f=-22;i=d;return f|0}l=a+140|0;if((c[l>>2]|0)>=(b|0)){f=0;i=d;return f|0}m=b<<1;b=(ca(h,m)|0)+31&-32;nrc(e|0,a|0,152)|0;if((h|0)==0){KIb(0,0,2456304,(n=i,i=i+24|0,c[n>>2]=2387496,c[n+8>>2]=2428448,c[n+16>>2]=454,n)|0);i=n;Hd();return 0}if((k|0)==0){KIb(0,0,2456304,(n=i,i=i+24|0,c[n>>2]=2380640,c[n+8>>2]=2428448,c[n+16>>2]=455,n)|0);i=n;Hd();return 0}n=pJb(ca(k,b)|0)|0;k=a+128|0;c[k>>2]=n;if((n|0)==0){f=-12;i=d;return f|0}h=c[j>>2]|0;o=a+144|0;a:do{if((h|0)>0){p=0;q=n;while(1){if((c[o>>2]|0)==0){r=c[g>>2]|0}else{r=b}s=q+(ca(r,p)|0)|0;c[a+(p<<2)>>2]=s;if((c[o>>2]|0)!=0){nrc(s|0,c[e+(p<<2)>>2]|0,ca(c[g>>2]|0,c[l>>2]|0)|0)|0}s=p+1|0;t=c[j>>2]|0;if((s|0)>=(t|0)){u=t;break a}p=s;q=c[k>>2]|0}}else{u=h}}while(0);if((c[o>>2]|0)==0){o=ca(c[l>>2]|0,u)|0;nrc(c[a>>2]|0,c[e>>2]|0,ca(o,c[g>>2]|0)|0)|0}mJb(e+128|0);c[l>>2]=m;f=1;i=d;return f|0}function bwb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;i=i+128|0;h=g|0;j=h;k=i;i=i+152|0;l=a+5708|0;m=a+6316|0;if((c[a+6600>>2]|0)==0){KIb(a,16,2374240,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-22;i=g;return o|0}n=a+6960|0;p=c[n>>2]|0;a:do{if((p|0)>0){q=a+6772|0;r=h|0;s=a+6916|0;t=q|0;u=a+6904|0;v=a+6772|0;if((b|0)==0){w=f;x=p;while(1){y=awb(q,(x|0)>16384?16384:x)|0;if((y|0)<0){o=y;z=97;break}do{if((c[s>>2]|0)==0){c[r>>2]=c[t>>2]}else{y=c[u>>2]|0;if((y|0)<=0){break}nrc(j|0,v|0,y<<2)|0}}while(0);y=c[n>>2]|0;c[n>>2]=-y;A=bwb(a,r,(y|0)>16384?16384:y,e,w)|0;y=-(c[n>>2]|0)|0;c[n>>2]=y;if((A|0)<=0){o=0;z=97;break}B=y-A|0;c[n>>2]=B;if((B|0)>0){w=0;x=B}else{C=0;break a}}if((z|0)==97){i=g;return o|0}}else{D=f;E=p}while(1){x=awb(q,(E|0)>16384?16384:E)|0;if((x|0)<0){o=x;z=97;break}do{if((c[s>>2]|0)==0){c[r>>2]=c[t>>2]}else{x=c[u>>2]|0;if((x|0)<=0){break}nrc(j|0,v|0,x<<2)|0}}while(0);x=c[n>>2]|0;c[n>>2]=-x;w=bwb(a,r,(x|0)>16384?16384:x,e,D)|0;x=c[n>>2]|0;B=-x|0;c[n>>2]=B;if((w|0)>0){A=B-w|0;c[n>>2]=A;F=A}else{if((x|0)==0){F=B}else{o=0;z=97;break}}if((F|0)>0){D=0;E=F}else{C=0;break a}}if((z|0)==97){i=g;return o|0}}else{C=f}}while(0);b:do{if((e|0)==0){if((c[a+6976>>2]|0)==0){if((c[a+6928>>2]|0)==0){o=0}else{break}i=g;return o|0}f=a+6936|0;if((c[f>>2]|0)==0){ve[c[(c[a+6980>>2]|0)+12>>2]&4095](a)|0}c[a+6932>>2]=0;c[f>>2]=1}else{f=a+5840|0;z=(c[f>>2]|0)>0;if((c[a+5852>>2]|0)!=0){if(z){H=0}else{break}while(1){c[a+5708+(H<<2)>>2]=c[e+(H<<2)>>2];H=H+1|0;if((H|0)>=(c[f>>2]|0)){break b}}}if(!z){break}F=a+5844|0;E=0;do{c[a+5708+(E<<2)>>2]=(c[e>>2]|0)+(ca(c[F>>2]|0,E)|0);E=E+1|0;}while((E|0)<(c[f>>2]|0))}}while(0);c:do{if((b|0)==0){mrc(m|0,0,128)|0}else{e=a+6448|0;H=(c[e>>2]|0)>0;if((c[a+6460>>2]|0)!=0){if(H){I=0}else{break}while(1){c[a+6316+(I<<2)>>2]=c[b+(I<<2)>>2];I=I+1|0;if((I|0)>=(c[e>>2]|0)){break c}}}if(!H){break}f=a+6452|0;E=0;do{c[a+6316+(E<<2)>>2]=(c[b>>2]|0)+(ca(c[f>>2]|0,E)|0);E=E+1|0;}while((E|0)<(c[e>>2]|0))}}while(0);if((c[a+6976>>2]|0)!=0){b=cwb(a,m,d,l,C)|0;if((b|0)<=0){o=b;i=g;return o|0}if((c[n>>2]|0)!=0){o=b;i=g;return o|0}I=c[a+40>>2]|0;e=Erc(I,(I|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;I=a+6944|0;E=wrc(e,G,c[I>>2]|0,c[I+4>>2]|0)|0;c[I>>2]=E;c[I+4>>2]=G;o=b;i=g;return o|0}nrc(k|0,l|0,152)|0;b=a+6928|0;I=c[b>>2]|0;E=(I|0)<(d|0)?I:d;do{if((E|0)==0){J=0;K=d;L=I}else{e=a+6924|0;f=c[e>>2]|0;H=k+132|0;F=c[H>>2]|0;z=(F|0)>0;do{if((c[a+6612>>2]|0)==0){if(!z){break}D=k+136|0;j=F-1|0;p=c[a+6468>>2]|0;h=j+(ca(F,f)|0)|0;c[k+(j<<2)>>2]=p+(ca(h,c[D>>2]|0)|0);if((j|0)>0){M=j}else{break}do{M=M-1|0;j=M+(ca(c[H>>2]|0,f)|0)|0;c[k+(M<<2)>>2]=p+(ca(j,c[D>>2]|0)|0);}while((M|0)>0)}else{if(!z){break}D=k+136|0;p=0;do{c[k+(p<<2)>>2]=(c[a+6468+(p<<2)>>2]|0)+(ca(c[D>>2]|0,f)|0);p=p+1|0;}while((p|0)<(c[H>>2]|0))}}while(0);H=cwb(a,m,E,k,E)|0;if((H|0)<0){o=H;i=g;return o|0}c[b>>2]=(c[b>>2]|0)-H;c[e>>2]=(c[e>>2]|0)+H;f=a+6448|0;z=c[f>>2]|0;F=(z|0)>0;do{if((c[a+6460>>2]|0)==0){if(!F){break}p=m|0;D=a+6452|0;j=z-1|0;h=j+(ca(z,H)|0)|0;c[a+6316+(j<<2)>>2]=(c[p>>2]|0)+(ca(h,c[D>>2]|0)|0);if((j|0)>0){N=j}else{break}do{N=N-1|0;j=N+(ca(c[f>>2]|0,H)|0)|0;c[a+6316+(N<<2)>>2]=(c[p>>2]|0)+(ca(j,c[D>>2]|0)|0);}while((N|0)>0)}else{if(!F){break}D=a+6452|0;p=0;do{j=a+6316+(p<<2)|0;c[j>>2]=(c[j>>2]|0)+(ca(c[D>>2]|0,H)|0);p=p+1|0;}while((p|0)<(c[f>>2]|0))}}while(0);f=d-H|0;F=c[b>>2]|0;if((F|0)!=0){J=H;K=f;L=F;break}c[e>>2]=0;J=H;K=f;L=0}}while(0);do{if((C|0)==0){O=J}else{d=a+6924|0;N=c[d>>2]|0;E=C-K|0;M=E+N+L|0;I=(C|0)>(K|0);do{if(I){f=a+6468|0;if((M|0)<=(c[a+6608>>2]|0)|(E+L|0)>(N|0)){F=awb(f,M)|0;if((F|0)<0){o=F}else{break}i=g;return o|0}F=k+132|0;z=c[F>>2]|0;p=(z|0)>0;do{if((c[a+6612>>2]|0)==0){if(!p){break}D=k+136|0;j=z-1|0;h=c[f>>2]|0;r=j+(ca(z,N)|0)|0;c[k+(j<<2)>>2]=h+(ca(r,c[D>>2]|0)|0);if((j|0)>0){P=j}else{break}do{P=P-1|0;j=P+(ca(c[F>>2]|0,N)|0)|0;c[k+(P<<2)>>2]=h+(ca(j,c[D>>2]|0)|0);}while((P|0)>0)}else{if(!p){break}D=k+136|0;h=0;do{c[k+(h<<2)>>2]=(c[a+6468+(h<<2)>>2]|0)+(ca(c[D>>2]|0,N)|0);h=h+1|0;}while((h|0)<(c[F>>2]|0))}}while(0);dwb(f,k,L);c[d>>2]=0}}while(0);if((K|0)==0){Q=J;R=C}else{N=I?K:C;M=cwb(a,m,N,l,N)|0;if((M|0)<0){o=M;i=g;return o|0}N=a+5840|0;E=c[N>>2]|0;H=(E|0)>0;do{if((c[a+5852>>2]|0)==0){if(!H){break}e=l|0;F=a+5844|0;p=E-1|0;z=p+(ca(E,M)|0)|0;c[a+5708+(p<<2)>>2]=(c[e>>2]|0)+(ca(z,c[F>>2]|0)|0);if((p|0)>0){S=p}else{break}do{S=S-1|0;p=S+(ca(c[N>>2]|0,M)|0)|0;c[a+5708+(S<<2)>>2]=(c[e>>2]|0)+(ca(p,c[F>>2]|0)|0);}while((S|0)>0)}else{if(!H){break}F=a+5844|0;e=0;do{f=a+5708+(e<<2)|0;c[f>>2]=(c[f>>2]|0)+(ca(c[F>>2]|0,M)|0);e=e+1|0;}while((e|0)<(c[N>>2]|0))}}while(0);Q=M+J|0;R=C-M|0}if((R|0)==0){O=Q;break}N=(c[b>>2]|0)+(c[d>>2]|0)|0;H=k+132|0;E=c[H>>2]|0;I=(E|0)>0;do{if((c[a+6612>>2]|0)==0){if(!I){break}e=k+136|0;F=E-1|0;f=c[a+6468>>2]|0;p=F+(ca(E,N)|0)|0;c[k+(F<<2)>>2]=f+(ca(p,c[e>>2]|0)|0);if((F|0)>0){T=F}else{break}do{T=T-1|0;F=T+(ca(c[H>>2]|0,N)|0)|0;c[k+(T<<2)>>2]=f+(ca(F,c[e>>2]|0)|0);}while((T|0)>0)}else{if(!I){break}e=k+136|0;f=0;do{c[k+(f<<2)>>2]=(c[a+6468+(f<<2)>>2]|0)+(ca(c[e>>2]|0,N)|0);f=f+1|0;}while((f|0)<(c[H>>2]|0))}}while(0);dwb(k,l,R);c[b>>2]=(c[b>>2]|0)+R;O=Q}}while(0);if((O|0)<=0){o=O;i=g;return o|0}if((c[n>>2]|0)!=0){o=O;i=g;return o|0}n=c[a+40>>2]|0;Q=Erc(n,(n|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;n=a+6944|0;a=wrc(Q,G,c[n>>2]|0,c[n+4>>2]|0)|0;c[n>>2]=a;c[n+4>>2]=G;o=O;i=g;return o|0}function cwb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+304|0;h=g|0;j=g+152|0;k=c[a+6972>>2]|0;if((k|0)!=0){if((c[a+6976>>2]|0)!=0){KIb(0,0,2456304,(l=i,i=i+24|0,c[l>>2]=2316224,c[l+8>>2]=2428448,c[l+16>>2]=616,l)|0);i=l;Hd();return 0}pwb(k,b,e,f)|0;m=d;i=g;return m|0}k=a+5860|0;n=awb(k,f)|0;if((n|0)<0){m=n;i=g;return m|0}n=a+5696|0;o=a+6012|0;p=c[a+6144>>2]|0;do{if((c[n>>2]|0)==0){if((p|0)!=(c[a+6448>>2]|0)){KIb(0,0,2456304,(l=i,i=i+24|0,c[l>>2]=2307144,c[l+8>>2]=2428448,c[l+16>>2]=631,l)|0);i=l;Hd();return 0}q=awb(o,f)|0;if((q|0)<0){m=q}else{break}i=g;return m|0}else{if((p|0)!=(c[a+80>>2]|0)){KIb(0,0,2456304,(l=i,i=i+24|0,c[l>>2]=2311872,c[l+8>>2]=2428448,c[l+16>>2]=627,l)|0);i=l;Hd();return 0}q=awb(o,d)|0;if((q|0)<0){m=q}else{break}i=g;return m|0}}while(0);p=a+6164|0;q=awb(p,d)|0;if((q|0)<0){m=q;i=g;return m|0}nrc(j|0,o|0,152)|0;nrc(h|0,p|0,152)|0;p=a+16|0;o=c[p>>2]|0;do{if((o|0)==(c[a+12>>2]|0)){if((c[a+5852>>2]|0)==0){r=k;break}r=(c[a+76>>2]|0)==0?e:k}else{r=k}}while(0);k=c[n>>2]|0;if((k|0)==0){q=(c[a+5700>>2]|0)==0?r:j;if((c[a+6976>>2]|0)==0){s=q;t=20}else{u=h;v=q}}else{q=(c[a+6976>>2]|0)==0?r:j;if((c[a+5700>>2]|0)==0){s=q;t=20}else{u=h;v=q}}if((t|0)==20){u=s;v=s}do{if((o|0)==(c[a+20>>2]|0)){if((c[a+6460>>2]|0)==0){w=r;x=u;y=v;break}if((o|0)==7){if((c[a+5624>>2]&31|0)!=0){w=r;x=u;y=v;break}}if((u|0)!=(e|0)){if((u|0)==(r|0)){w=b;x=b;y=b;break}w=r;x=b;y=(u|0)==(v|0)?b:v;break}s=(d|0)>(f|0)?f:d;if((c[a+5852>>2]|0)==0){KIb(0,0,2456304,(l=i,i=i+24|0,c[l>>2]=2301112,c[l+8>>2]=2428448,c[l+16>>2]=658,l)|0);i=l;Hd();return 0}dwb(b,e,s);m=s;i=g;return m|0}else{w=r;x=u;y=v}}while(0);if((w|0)==(e|0)){z=k}else{pwb(c[a+6964>>2]|0,w,e,f)|0;z=c[n>>2]|0}n=(w|0)!=(y|0);do{if((z|0)==0){if(n){Kvb(a,y,w,f,(y|0)==(b|0)|0)|0}if((y|0)==(x|0)){A=d;break}A=hwb(a,x,d,y,f)|0}else{if(n){B=hwb(a,y,d,w,f)|0}else{B=d}if((y|0)==(x|0)){A=B;break}Kvb(a,x,y,B,(x|0)==(b|0)|0)|0;A=B}}while(0);if((x|0)==(b|0)|(A|0)==0){m=A;i=g;return m|0}B=a+88|0;if((c[B>>2]|0)==0){C=x}else{y=(A|0)>65536?A:65536;do{if((x|0)==(e|0)){d=a+5472|0;f=awb(d,y)|0;if((f|0)<0){m=f}else{D=d;break}i=g;return m|0}else{D=x}}while(0);e=a+5320|0;d=awb(e,y)|0;if((d|0)<0){m=d;i=g;return m|0}y=a+5452|0;f=c[y>>2]|0;if((d|0)!=0&(f|0)>0){d=a+5460|0;w=a+5468|0;n=0;while(1){z=c[a+5320+(n<<2)>>2]|0;k=c[d>>2]|0;v=yrc(1942904875,2874,n|0)|0;Pwb(a,z,k,v,c[w>>2]|0);v=n+1|0;k=c[y>>2]|0;if((v|0)<(k|0)){n=v}else{E=k;break}}}else{E=f}f=x+132|0;if((E|0)!=(c[f>>2]|0)){KIb(0,0,2456304,(l=i,i=i+24|0,c[l>>2]=2290016,c[l+8>>2]=2428448,c[l+16>>2]=700,l)|0);i=l;Hd();return 0}l=a+92|0;E=c[l>>2]|0;if((E+A|0)>(c[a+5460>>2]|0)){c[l>>2]=0;F=0}else{F=E}a:do{if((c[B>>2]|0)>>>0<64>>>0){E=a+16260|0;n=c[E>>2]|0;if((n|0)==0){if((c[f>>2]|0)<=0){break}y=a+16256|0;w=a+5456|0;d=a+11084|0;k=0;v=F;while(1){z=(c[a+5320+(k<<2)>>2]|0)+(ca(v,c[w>>2]|0)|0)|0;Se[c[y>>2]&1023](c[D+(k<<2)>>2]|0,c[x+(k<<2)>>2]|0,z,c[d>>2]|0,0,0,A);z=k+1|0;if((z|0)>=(c[f>>2]|0)){break a}k=z;v=c[l>>2]|0}}v=A&-16;k=ca(c[x+136>>2]|0,v)|0;b:do{if((v|0)!=0){if((c[f>>2]|0)<=0){break}d=a+5456|0;y=a+11088|0;w=0;z=n;u=F;while(1){r=(c[a+5320+(w<<2)>>2]|0)+(ca(u,c[d>>2]|0)|0)|0;Se[z&1023](c[D+(w<<2)>>2]|0,c[x+(w<<2)>>2]|0,r,c[y>>2]|0,0,0,v);r=w+1|0;if((r|0)>=(c[f>>2]|0)){break b}w=r;z=c[E>>2]|0;u=c[l>>2]|0}}}while(0);if((A|0)==(v|0)){break}if((c[f>>2]|0)<=0){break}E=a+16256|0;n=a+5456|0;u=k+v|0;z=a+11084|0;w=A-v|0;y=0;do{d=(c[a+5320+(y<<2)>>2]|0)+(u+(ca(c[l>>2]|0,c[n>>2]|0)|0))|0;Se[c[E>>2]&1023]((c[D+(y<<2)>>2]|0)+k|0,(c[x+(y<<2)>>2]|0)+k|0,d,c[z>>2]|0,0,0,w);y=y+1|0;}while((y|0)<(c[f>>2]|0))}else{y=c[p>>2]|0;if((y|0)==9){Uwb(a,D,x,e,A);break}else if((y|0)==7){Swb(a,D,x,e,A);break}else if((y|0)==6){Rwb(a,D,x,e,A);break}else if((y|0)==8){Twb(a,D,x,e,A);break}else{break}}}while(0);c[l>>2]=(c[l>>2]|0)+A;C=D}pwb(c[a+6968>>2]|0,b,C,A)|0;m=A;i=g;return m|0}function dwb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[a+144>>2]|0;if((f|0)!=(c[b+144>>2]|0)){KIb(0,0,2456304,(g=i,i=i+24|0,c[g>>2]=2332568,c[g+8>>2]=2428448,c[g+16>>2]=473,g)|0);i=g;Hd()}h=a+136|0;j=c[h>>2]|0;if((j|0)!=(c[b+136>>2]|0)){KIb(0,0,2456304,(g=i,i=i+24|0,c[g>>2]=2327064,c[g+8>>2]=2428448,c[g+16>>2]=474,g)|0);i=g;Hd()}k=a+132|0;l=c[k>>2]|0;if((l|0)!=(c[b+132>>2]|0)){KIb(0,0,2456304,(g=i,i=i+24|0,c[g>>2]=2321272,c[g+8>>2]=2428448,c[g+16>>2]=475,g)|0);i=g;Hd()}if((f|0)==0){nrc(c[a>>2]|0,c[b>>2]|0,ca(ca(j,d)|0,l)|0)|0;i=e;return}if((l|0)>0){m=0;n=j}else{i=e;return}while(1){nrc(c[a+(m<<2)>>2]|0,c[b+(m<<2)>>2]|0,ca(n,d)|0)|0;j=m+1|0;if((j|0)>=(c[k>>2]|0)){break}m=j;n=c[h>>2]|0}i=e;return}function ewb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+128|0;e=d|0;f=e;if((b|0)<1){g=0;i=d;return g|0}else{h=b}while(1){if((h|0)<=16384){break}b=ewb(a,16384)|0;if((b|0)<0){g=b;j=15;break}else{h=h-16384|0}}if((j|0)==15){i=d;return g|0}j=a+6620|0;b=awb(j,h)|0;if((b|0)<0){g=b;i=d;return g|0}b=a+6764|0;do{if((c[b>>2]|0)==0){k=c[a+6756>>2]|0;l=ca(k,h)|0;mrc(c[j>>2]|0,((k|0)==1?-128:0)|0,ca(l,c[a+6752>>2]|0)|0)|0}else{l=a+6752|0;if((c[l>>2]|0)<=0){break}k=a+6756|0;m=0;do{n=c[k>>2]|0;mrc(c[a+6620+(m<<2)>>2]|0,((n|0)==1?-128:0)|0,ca(n,h)|0)|0;m=m+1|0;}while((m|0)<(c[l>>2]|0))}}while(0);l=e|0;do{if((c[b>>2]|0)==0){c[l>>2]=c[j>>2]}else{e=c[a+6752>>2]|0;if((e|0)<=0){break}nrc(f|0,a+6620|0,e<<2)|0}}while(0);KIb(a,40,2351832,(f=i,i=i+8|0,c[f>>2]=h,f)|0);i=f;g=bwb(a,0,0,l,h)|0;i=d;return g|0}function fwb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[a+6980>>2]|0;do{if((e|0)!=0){if((c[a+6976>>2]|0)==0){break}f=Ee[c[e+20>>2]&511](a,b,d)|0;g=G;h=f;return(G=g,h)|0}}while(0);e=c[a+6928>>2]|0;f=Erc(e,(e|0)<0|0?-1:0,b,d)|0;d=c[a+40>>2]|0;a=d>>1;b=wrc(a,(a|0)<0|0?-1:0,f,G)|0;f=Crc(b,G,d,(d|0)<0|0?-1:0)|0;g=G;h=f;return(G=g,h)|0}function gwb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,H=0.0,I=0,J=0,K=0,L=0;e=i;if((b|0)==0&(d|0)==(-2147483648|0)){f=a+6944|0;j=c[f+4>>2]|0;k=c[f>>2]|0;i=e;return(G=j,k)|0}f=a+6952|0;if((c[f>>2]|0)==0&(c[f+4>>2]|0)==(-2147483648|0)){c[f>>2]=b;c[f+4>>2]=d;l=a+6944|0;c[l>>2]=b;c[l+4>>2]=d}l=a+5668|0;m=+g[l>>2]<3.4028234663852886e+38;n=a+40|0;o=c[n>>2]|0;p=o;q=(o|0)<0|0?-1:0;r=a+44|0;s=c[r>>2]|0;t=Erc(s,(s|0)<0|0?-1:0,p,q)|0;s=G;u=a+6980|0;v=c[u>>2]|0;do{if((v|0)==0){w=8}else{if((c[a+6976>>2]|0)==0){w=8;break}x=Ee[c[v+20>>2]&511](a,t,s)|0;y=G;z=x}}while(0);if((w|0)==8){w=c[a+6928>>2]|0;v=Erc(w,(w|0)<0|0?-1:0,t,s)|0;s=o>>1;o=wrc(s,(s|0)<0|0?-1:0,v,G)|0;v=Crc(o,G,p,q)|0;y=G;z=v}v=xrc(b,d,z,y)|0;y=G;z=a+6944|0;if(!m){c[z>>2]=v;c[z+4>>2]=y;j=y;k=v;i=e;return(G=j,k)|0}m=c[z>>2]|0;d=c[z+4>>2]|0;b=xrc(v,y,m,d)|0;y=G;v=a+6960|0;q=c[v>>2]|0;p=c[n>>2]|0;n=p;o=(p|0)<0|0?-1:0;s=Erc(n,o,q,(q|0)<0|0?-1:0)|0;t=wrc(s,G,b,y)|0;y=G;b=c[r>>2]|0;r=b;s=(b|0)<0|0?-1:0;w=Erc(r,s,n,o)|0;A=(+(t>>>0)+ +(y|0)*4294967296.0)/(+(w>>>0)+ +(G|0)*4294967296.0);B=+R(+A);a:do{if(B>+g[l>>2]){do{if(!((m|0)==(c[f>>2]|0)&(d|0)==(c[f+4>>2]|0))){if(B>+g[a+5672>>2]){break}C=+g[a+5676>>2];if(!(C!=0.0)){break a}D=+g[a+5680>>2];if(!(D!=0.0)){break a}w=~~(+(b|0)*C);if(D<0.0){E=+(-p|0)}else{E=1.0}C=D/E;D=A;F=-0.0-C;if(D<F){H=F}else{H=D>C?C:D}x=~~(+(w|0)*H);KIb(a,40,2338136,(I=i,i=i+24|0,h[I>>3]=A,c[I+8>>2]=x,c[I+16>>2]=w,I)|0);i=I;if((a|0)==0|(w|0)<0){break a}if(!((w|0)!=0|(x|0)==0)){break a}J=a+6976|0;if((c[J>>2]|0)==0){K=a+48|0;c[K>>2]=c[K>>2]|1;if(($vb(a)|0)<0){break a}}K=c[(c[u>>2]|0)+16>>2]|0;if((K|0)==0){break a}Ee[K&511](c[J>>2]|0,x,w)|0;break a}}while(0);w=0;if((y|0)>(w|0)|(y|0)==(w|0)&t>>>0>0>>>0){w=Crc(t,y,r,s)|0;L=ewb(a,w)|0}else{w=xrc(0,0,t,y)|0;x=Crc(w,G,n,o)|0;w=x;x=q+w|0;c[v>>2]=x;if((x|0)<1){break}KIb(a,40,2366720,(I=i,i=i+8|0,c[I>>2]=w,I)|0);i=I;L=bwb(a,0,c[v>>2]|0,0,0)|0}if((L|0)>=0){break}KIb(a,16,2344144,(I=i,i=i+8|0,h[I>>3]=A,I)|0);i=I}}while(0);j=c[z+4>>2]|0;k=c[z>>2]|0;i=e;return(G=j,k)|0}function hwb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;g=i;i=i+464|0;h=g|0;j=g+152|0;k=g+304|0;l=g+456|0;m=b;nrc(j|0,m|0,152)|0;nrc(k|0,m|0,152)|0;nrc(h|0,e|0,152)|0;e=a+6932|0;m=a+6928|0;b=a+6924|0;n=a+6612|0;o=k+132|0;p=a+6468|0;q=k+136|0;r=a+6980|0;s=a+6976|0;t=j+144|0;u=j+132|0;v=j|0;w=j+136|0;x=h+144|0;y=h+132|0;z=h|0;A=h+136|0;B=a+6936|0;C=a+6468|0;D=a+6608|0;E=C|0;F=0;G=0;H=f;f=d;d=(c[e>>2]|0)==0;a:while(1){do{if(d){I=c[m>>2]|0;if((I|0)==0){J=F;K=G;L=H;M=f;break}N=c[b>>2]|0;O=c[o>>2]|0;P=(O|0)>0;do{if((c[n>>2]|0)==0){if(!P){break}Q=O-1|0;R=c[p>>2]|0;S=Q+(ca(O,N)|0)|0;c[k+(Q<<2)>>2]=R+(ca(S,c[q>>2]|0)|0);if((Q|0)>0){T=Q}else{break}do{T=T-1|0;Q=T+(ca(c[o>>2]|0,N)|0)|0;c[k+(T<<2)>>2]=R+(ca(Q,c[q>>2]|0)|0);}while((T|0)>0)}else{if(P){U=0}else{break}do{c[k+(U<<2)>>2]=(c[a+6468+(U<<2)>>2]|0)+(ca(c[q>>2]|0,N)|0);U=U+1|0;}while((U|0)<(c[o>>2]|0))}}while(0);N=se[c[(c[r>>2]|0)+8>>2]&127](c[s>>2]|0,j,f,k,I,l)|0;P=f-N|0;O=N+G|0;R=c[u>>2]|0;Q=(R|0)>0;do{if((c[t>>2]|0)==0){if(!Q){break}S=R-1|0;V=S+(ca(R,N)|0)|0;c[j+(S<<2)>>2]=(c[v>>2]|0)+(ca(V,c[w>>2]|0)|0);if((S|0)>0){W=S}else{break}do{W=W-1|0;S=W+(ca(c[u>>2]|0,N)|0)|0;c[j+(W<<2)>>2]=(c[v>>2]|0)+(ca(S,c[w>>2]|0)|0);}while((W|0)>0)}else{if(Q){X=0}else{break}do{S=j+(X<<2)|0;c[S>>2]=(c[S>>2]|0)+(ca(c[w>>2]|0,N)|0);X=X+1|0;}while((X|0)<(c[u>>2]|0))}}while(0);N=c[l>>2]|0;Q=(c[m>>2]|0)-N|0;c[m>>2]=Q;c[b>>2]=(c[b>>2]|0)+N;if((H|0)==0){Y=O;Z=P;break a}if((Q|0)>(F|0)){J=F;K=O;L=H;M=P;break}N=-Q|0;R=c[y>>2]|0;I=(R|0)>0;do{if((c[x>>2]|0)==0){if(!I){break}S=R-1|0;V=S+(ca(R,N)|0)|0;c[h+(S<<2)>>2]=(c[z>>2]|0)+(ca(V,c[A>>2]|0)|0);if((S|0)>0){_=S}else{break}do{_=_-1|0;S=_+(ca(c[y>>2]|0,N)|0)|0;c[h+(_<<2)>>2]=(c[z>>2]|0)+(ca(S,c[A>>2]|0)|0);}while((_|0)>0)}else{if(I){$=0}else{break}do{S=h+($<<2)|0;c[S>>2]=(c[S>>2]|0)+(ca(c[A>>2]|0,N)|0);$=$+1|0;}while(($|0)<(c[y>>2]|0))}}while(0);c[m>>2]=0;c[b>>2]=0;J=0;K=O;L=Q+H|0;M=P}else{J=F;K=G;L=H;M=f}}while(0);N=(L|0)>0;b:do{if((c[B>>2]|0)!=0|N){if((c[m>>2]|0)!=0){aa=K;ba=L;da=M;break}c[b>>2]=0;I=se[c[(c[r>>2]|0)+8>>2]&127](c[s>>2]|0,j,M,h,N?L:0,l)|0;R=M-I|0;S=I+K|0;V=c[u>>2]|0;ea=(V|0)>0;do{if((c[t>>2]|0)==0){if(!ea){break}fa=V-1|0;ga=fa+(ca(V,I)|0)|0;c[j+(fa<<2)>>2]=(c[v>>2]|0)+(ca(ga,c[w>>2]|0)|0);if((fa|0)>0){ha=fa}else{break}do{ha=ha-1|0;fa=ha+(ca(c[u>>2]|0,I)|0)|0;c[j+(ha<<2)>>2]=(c[v>>2]|0)+(ca(fa,c[w>>2]|0)|0);}while((ha|0)>0)}else{if(ea){ia=0}else{break}do{fa=j+(ia<<2)|0;c[fa>>2]=(c[fa>>2]|0)+(ca(c[w>>2]|0,I)|0);ia=ia+1|0;}while((ia|0)<(c[u>>2]|0))}}while(0);I=c[l>>2]|0;ea=L-I|0;V=c[y>>2]|0;P=(V|0)>0;if((c[x>>2]|0)!=0){if(P){ja=0}else{aa=S;ba=ea;da=R;break}while(1){Q=h+(ja<<2)|0;c[Q>>2]=(c[Q>>2]|0)+(ca(c[A>>2]|0,I)|0);Q=ja+1|0;if((Q|0)<(c[y>>2]|0)){ja=Q}else{aa=S;ba=ea;da=R;break b}}}if(!P){aa=S;ba=ea;da=R;break}Q=V-1|0;O=Q+(ca(V,I)|0)|0;c[h+(Q<<2)>>2]=(c[z>>2]|0)+(ca(O,c[A>>2]|0)|0);if((Q|0)>0){ka=Q}else{aa=S;ba=ea;da=R;break}while(1){Q=ka-1|0;O=Q+(ca(c[y>>2]|0,I)|0)|0;c[h+(Q<<2)>>2]=(c[z>>2]|0)+(ca(O,c[A>>2]|0)|0);if((Q|0)>0){ka=Q}else{aa=S;ba=ea;da=R;break}}}else{aa=K;ba=L;da=M}}while(0);N=c[b>>2]|0;R=c[m>>2]|0;ea=N+ba+R|0;if((ea|0)<=(c[D>>2]|0)|(R+ba|0)>(N|0)){S=awb(C,ea)|0;if((S|0)<0){la=S;ma=65;break}}else{S=c[o>>2]|0;ea=(S|0)>0;do{if((c[n>>2]|0)==0){if(!ea){break}I=S-1|0;V=c[E>>2]|0;P=I+(ca(S,N)|0)|0;c[k+(I<<2)>>2]=V+(ca(P,c[q>>2]|0)|0);if((I|0)>0){na=I}else{break}do{na=na-1|0;I=na+(ca(c[o>>2]|0,N)|0)|0;c[k+(na<<2)>>2]=V+(ca(I,c[q>>2]|0)|0);}while((na|0)>0)}else{if(ea){oa=0}else{break}do{c[k+(oa<<2)>>2]=(c[a+6468+(oa<<2)>>2]|0)+(ca(c[q>>2]|0,N)|0);oa=oa+1|0;}while((oa|0)<(c[o>>2]|0))}}while(0);dwb(C,k,R);c[b>>2]=0}if((ba|0)==0){Y=aa;Z=da;break}N=c[m>>2]|0;if((N|0)==0){pa=ba}else{ea=N+2|0;pa=(ea|0)>=(ba|0)|(da|0)==0?ba:ea}ea=N+(c[b>>2]|0)|0;N=c[o>>2]|0;S=(N|0)>0;do{if((c[n>>2]|0)==0){if(!S){break}V=N-1|0;I=c[E>>2]|0;P=V+(ca(N,ea)|0)|0;c[k+(V<<2)>>2]=I+(ca(P,c[q>>2]|0)|0);if((V|0)>0){qa=V}else{break}do{qa=qa-1|0;V=qa+(ca(c[o>>2]|0,ea)|0)|0;c[k+(qa<<2)>>2]=I+(ca(V,c[q>>2]|0)|0);}while((qa|0)>0)}else{if(S){ra=0}else{break}do{c[k+(ra<<2)>>2]=(c[a+6468+(ra<<2)>>2]|0)+(ca(c[q>>2]|0,ea)|0);ra=ra+1|0;}while((ra|0)<(c[o>>2]|0))}}while(0);dwb(k,h,pa);ea=c[m>>2]|0;c[m>>2]=ea+pa;S=ba-pa|0;N=pa+J|0;R=c[y>>2]|0;I=(R|0)>0;do{if((c[x>>2]|0)==0){if(!I){break}V=R-1|0;P=V+(ca(R,pa)|0)|0;c[h+(V<<2)>>2]=(c[z>>2]|0)+(ca(P,c[A>>2]|0)|0);if((V|0)>0){sa=V}else{break}do{sa=sa-1|0;V=sa+(ca(c[y>>2]|0,pa)|0)|0;c[h+(sa<<2)>>2]=(c[z>>2]|0)+(ca(V,c[A>>2]|0)|0);}while((sa|0)>0)}else{if(I){ta=0}else{break}do{V=h+(ta<<2)|0;c[V>>2]=(c[V>>2]|0)+(ca(c[A>>2]|0,pa)|0);ta=ta+1|0;}while((ta|0)<(c[y>>2]|0))}}while(0);c[e>>2]=0;if((ea|0)==0&(ba|0)==(pa|0)){Y=aa;Z=da;break}else{F=N;G=aa;H=S;f=da;d=1}}if((ma|0)==65){i=g;return la|0}c[e>>2]=(Z|0)!=0;la=Y;i=g;return la|0}function iwb(a){a=a|0;return 2520056}function jwb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;g=NKb(b)|0;h=c[1211840+(((NKb(d)|0)*10|0)+g<<2)>>2]|0;if((h|0)==0){i=0;return i|0}g=pJb(32)|0;j=g;if((g|0)==0){i=0;return i|0}if((e|0)==1){k=OKb(d)|0;l=OKb(b)|0;m=k}else{l=b;m=d}c[g>>2]=e;c[g+12>>2]=h;c[g+20>>2]=f;if((m|0)==5|(m|0)==0){h=g+24|0;e=h|0;y=-2139062144;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=h+4|0;y=-2139062144;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y}if(!((l|0)==(m|0)&(f|0)==0)){i=j;return i|0}f=QKb(m)|0;if((f|0)==4){c[g+16>>2]=2100;i=j;return i|0}else if((f|0)==8){c[g+16>>2]=470;i=j;return i|0}else if((f|0)==2){c[g+16>>2]=2098;i=j;return i|0}else if((f|0)==1){c[g+16>>2]=2096;i=j;return i|0}else{i=j;return i|0}return 0}function kwb(a,b,d){a=a|0;b=b|0;d=d|0;nrc(c[a>>2]|0,c[b>>2]|0,d)|0;return}function lwb(a,b,d){a=a|0;b=b|0;d=d|0;nrc(c[a>>2]|0,c[b>>2]|0,d<<1)|0;return}function mwb(a,b,d){a=a|0;b=b|0;d=d|0;nrc(c[a>>2]|0,c[b>>2]|0,d<<2)|0;return}function nwb(a,b,d){a=a|0;b=b|0;d=d|0;nrc(c[a>>2]|0,c[b>>2]|0,d<<3)|0;return}function owb(a){a=a|0;mJb(a);return}function pwb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;g=b+144|0;h=c[g>>2]|0;j=(h|0)==0;k=c[b+132>>2]|0;l=ca(c[b+136>>2]|0,j?k:1)|0;m=a|0;n=b+132|0;if((c[m>>2]|0)!=(k|0)){KIb(0,0,2417264,(o=i,i=i+24|0,c[o>>2]=2580008,c[o+8>>2]=2436576,c[o+16>>2]=175,o)|0);i=o;Hd();return 0}o=c[a+4>>2]|0;if((o|0)==0){p=0}else{if((c[d+144>>2]|0)==0){q=1;r=6}else{s=c[d+132>>2]|0;if((s|0)>0){q=s;r=6}else{t=0}}if((r|0)==6){s=0;u=0;while(1){v=c[d+(u<<2)>>2]|s;w=u+1|0;if((w|0)<(q|0)){s=v;u=w}else{t=v;break}}}p=o&t}t=c[a+8>>2]|0;if((t|0)==0){x=p}else{if(j){y=1;r=12}else{if((k|0)>0){y=k;r=12}else{z=0}}if((r|0)==12){r=0;o=0;while(1){u=c[b+(o<<2)>>2]|r;s=o+1|0;if((s|0)<(y|0)){r=u;o=s}else{z=u;break}}}x=t&z|p}p=a+16|0;z=c[p>>2]|0;do{if((z|0)==0){A=0;B=k}else{if(!((c[a+20>>2]|0)==0&(x|0)==0)){A=0;B=k;break}t=e&-16;a:do{if((t|0)>0){if((h|0)!=(c[d+144>>2]|0)){ef[z&4095](b|0,d|0,t);break}if(j){C=1}else{if((k|0)>0){C=k}else{break}}o=0;r=z;y=h;while(1){if((y|0)==0){D=c[n>>2]|0}else{D=1}u=ca(D,t)|0;ef[r&4095](b+(o<<2)|0,d+(o<<2)|0,u);u=o+1|0;if((u|0)>=(C|0)){break a}o=u;r=c[p>>2]|0;y=c[g>>2]|0}}}while(0);if((t|0)==(e|0)){i=f;return 0}else{A=t;B=c[m>>2]|0;break}}}while(0);if((B|0)<=0){i=f;return 0}g=a+20|0;p=a+24|0;C=ca(l,e)|0;e=a+12|0;a=ca(A,l)|0;D=d+144|0;n=d+132|0;h=d+136|0;z=0;k=B;while(1){B=c[g>>2]|0;if((B|0)==0){E=z}else{E=c[B+(z<<2)>>2]|0}if((E|0)<0){F=p;G=0}else{if((c[D>>2]|0)==0){H=ca(c[h>>2]|0,c[n>>2]|0)|0}else{H=c[h>>2]|0}F=c[d+(E<<2)>>2]|0;G=H}B=c[b+(z<<2)>>2]|0;if((B|0)==0){I=k}else{j=F+(ca(G,A)|0)|0;pe[c[e>>2]&1023](B+a|0,j,G,l,B+C|0);I=c[m>>2]|0}B=z+1|0;if((B|0)<(I|0)){z=B;k=I}else{break}}i=f;return 0}function qwb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+(e*-3|0)|0;if(g>>>0>b>>>0){h=d<<1;i=e<<1;j=h+d|0;k=i+e|0;l=j+d|0;m=k+e|0;n=c;o=b;while(1){a[o]=a[n]|0;a[o+e|0]=a[n+d|0]|0;a[o+i|0]=a[n+h|0]|0;a[o+k|0]=a[n+j|0]|0;p=n+l|0;q=o+m|0;if(q>>>0<g>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=c;s=b}if(s>>>0<f>>>0){t=r;u=s}else{return}while(1){a[u]=a[t]|0;s=u+e|0;if(s>>>0<f>>>0){t=t+d|0;u=s}else{break}}return}function rwb(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>a>>>0){i=e<<1;j=f<<1;k=i+e|0;l=j+f|0;m=k+e|0;n=l+f|0;o=c;p=a;while(1){b[p>>1]=(d[o]|0)<<8^-32768;b[p+f>>1]=(d[o+e|0]|0)<<8^-32768;b[p+j>>1]=(d[o+i|0]|0)<<8^-32768;b[p+l>>1]=(d[o+k|0]|0)<<8^-32768;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=c;t=a}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){b[v>>1]=(d[u]|0)<<8^-32768;t=v+f|0;if(t>>>0<g>>>0){u=u+e|0;v=t}else{break}}return}function swb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>a>>>0){i=e<<1;j=f<<1;k=i+e|0;l=j+f|0;m=k+e|0;n=l+f|0;o=b;p=a;while(1){c[p>>2]=(d[o]|0)<<24^-2147483648;c[p+f>>2]=(d[o+e|0]|0)<<24^-2147483648;c[p+j>>2]=(d[o+i|0]|0)<<24^-2147483648;c[p+l>>2]=(d[o+k|0]|0)<<24^-2147483648;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){c[v>>2]=(d[u]|0)<<24^-2147483648;t=v+f|0;if(t>>>0<g>>>0){u=u+e|0;v=t}else{break}}return}function twb(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=c<<1;j=e<<1;k=i+c|0;l=j+e|0;m=k+c|0;n=l+e|0;o=b;p=a;while(1){g[p>>2]=+((d[o]|0)-128|0)*.0078125;g[p+e>>2]=+((d[o+c|0]|0)-128|0)*.0078125;g[p+j>>2]=+((d[o+i|0]|0)-128|0)*.0078125;g[p+l>>2]=+((d[o+k|0]|0)-128|0)*.0078125;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){g[v>>2]=+((d[u]|0)-128|0)*.0078125;t=v+e|0;if(t>>>0<f>>>0){u=u+c|0;v=t}else{break}}return}function uwb(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=c<<1;j=e<<1;k=i+c|0;l=j+e|0;m=k+c|0;n=l+e|0;o=b;p=a;while(1){h[p>>3]=+((d[o]|0)-128|0)*.0078125;h[p+e>>3]=+((d[o+c|0]|0)-128|0)*.0078125;h[p+j>>3]=+((d[o+i|0]|0)-128|0)*.0078125;h[p+l>>3]=+((d[o+k|0]|0)-128|0)*.0078125;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){h[v>>3]=+((d[u]|0)-128|0)*.0078125;t=v+e|0;if(t>>>0<f>>>0){u=u+c|0;v=t}else{break}}return}function vwb(b,c,d,f,g){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>b>>>0){i=d<<1;j=f<<1;k=i+d|0;l=j+f|0;m=k+d|0;n=l+f|0;o=c;p=b;while(1){a[p]=((e[o>>1]|0)>>>8)+128;a[p+f|0]=((e[o+d>>1]|0)>>>8)+128;a[p+j|0]=((e[o+i>>1]|0)>>>8)+128;a[p+l|0]=((e[o+k>>1]|0)>>>8)+128;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=c;t=b}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){a[v]=((e[u>>1]|0)>>>8)+128;t=v+f|0;if(t>>>0<g>>>0){u=u+d|0;v=t}else{break}}return}function wwb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){h=d<<1;i=e<<1;j=h+d|0;k=i+e|0;l=j+d|0;m=k+e|0;n=c;o=a;while(1){b[o>>1]=b[n>>1]|0;b[o+e>>1]=b[n+d>>1]|0;b[o+i>>1]=b[n+h>>1]|0;b[o+k>>1]=b[n+j>>1]|0;p=n+l|0;q=o+m|0;if(q>>>0<g>>>0){n=p;o=q}else{r=p;s=q;break}}}else{r=c;s=a}if(s>>>0<f>>>0){t=r;u=s}else{return}while(1){b[u>>1]=b[t>>1]|0;s=u+e|0;if(s>>>0<f>>>0){t=t+d|0;u=s}else{break}}return}function xwb(a,b,d,f,g){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=f<<1;k=i+d|0;l=j+f|0;m=k+d|0;n=l+f|0;o=b;p=a;while(1){c[p>>2]=(e[o>>1]|0)<<16;c[p+f>>2]=(e[o+d>>1]|0)<<16;c[p+j>>2]=(e[o+i>>1]|0)<<16;c[p+l>>2]=(e[o+k>>1]|0)<<16;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=b;t=a}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){c[v>>2]=(e[u>>1]|0)<<16;t=v+f|0;if(t>>>0<g>>>0){u=u+d|0;v=t}else{break}}return}function ywb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=f+(e*-3|0)|0;if(h>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=a;while(1){g[p>>2]=+(b[o>>1]|0)*30517578125.0e-15;g[p+e>>2]=+(b[o+d>>1]|0)*30517578125.0e-15;g[p+j>>2]=+(b[o+i>>1]|0)*30517578125.0e-15;g[p+l>>2]=+(b[o+k>>1]|0)*30517578125.0e-15;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=c;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){g[v>>2]=+(b[u>>1]|0)*30517578125.0e-15;t=v+e|0;if(t>>>0<f>>>0){u=u+d|0;v=t}else{break}}return}function zwb(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+(e*-3|0)|0;if(g>>>0>a>>>0){i=d<<1;j=e<<1;k=i+d|0;l=j+e|0;m=k+d|0;n=l+e|0;o=c;p=a;while(1){h[p>>3]=+(b[o>>1]|0)*30517578125.0e-15;h[p+e>>3]=+(b[o+d>>1]|0)*30517578125.0e-15;h[p+j>>3]=+(b[o+i>>1]|0)*30517578125.0e-15;h[p+l>>3]=+(b[o+k>>1]|0)*30517578125.0e-15;q=o+m|0;r=p+n|0;if(r>>>0<g>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=c;t=a}if(t>>>0<f>>>0){u=s;v=t}else{return}while(1){h[v>>3]=+(b[u>>1]|0)*30517578125.0e-15;t=v+e|0;if(t>>>0<f>>>0){u=u+d|0;v=t}else{break}}return}function Awb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=g+(f*-3|0)|0;if(h>>>0>b>>>0){i=e<<1;j=f<<1;k=i+e|0;l=j+f|0;m=k+e|0;n=l+f|0;o=d;p=b;while(1){a[p]=((c[o>>2]|0)>>>24)+128;a[p+f|0]=((c[o+e>>2]|0)>>>24)+128;a[p+j|0]=((c[o+i>>2]|0)>>>24)+128;a[p+l|0]=((c[o+k>>2]|0)>>>24)+128;q=o+m|0;r=p+n|0;if(r>>>0<h>>>0){o=q;p=r}else{s=q;t=r;break}}}else{s=d;t=b}if(t>>>0<g>>>0){u=s;v=t}else{return}while(1){a[v]=((c[u>>2]|0)>>>24)+128;t=v+f|0;if(t>>>0<g>>>0){u=u+e|0;v=t}else{break}}return}function _ff_epzs_motion_search$0(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0;f=c[a+24>>2]|0;g=c[a+32>>2]|0;h=c[a+40>>2]|0;j=c[a+56>>2]|0;k=c[a+64>>2]|0;l=c[a+72>>2]|0;m=c[a+80>>2]|0;n=c[a+88>>2]|0;o=c[a+96>>2]|0;p=c[a+104>>2]|0;q=c[a+5344>>2]|0;r=c[a+5352>>2]|0;s=c[a+5368>>2]|0;t=c[a+5376>>2]|0;u=c[a+5384>>2]|0;v=c[a+5392>>2]|0;w=c[a+5400>>2]|0;x=c[a+5408>>2]|0;y=c[a+5416>>2]|0;z=c[a+5424>>2]|0;A=c[a+5432>>2]|0;B=c[a+5440>>2]|0;C=c[a+5472>>2]|0;D=c[a+5480>>2]|0;E=c[a+5488>>2]|0;F=c[a+5504>>2]|0;G=c[a+13904>>2]|0;H=c[a+13912>>2]|0;I=c[a+13920>>2]|0;J=c[a+13928>>2]|0;K=c[a+27600>>2]|0;a:do{do{if((J|0)==0){L=I;M=H;N=G}else{O=c[(f+12476|0)>>2]|0;P=(O-J|0|0)<0?0:O-J|0;Q=c[(f+12480|0)>>2]|0;R=(Q-J|0|0)<0?0:Q-J|0;S=c[f+116>>2]|0;T=(S|0)>(O+(J+1|0)|0|0)?O+(J+1|0)|0:S;S=c[f+120>>2]|0;O=(S|0)>(Q+(J+1|0)|0|0)?Q+(J+1|0)|0:S;if((R|0)>=(O|0)){L=I;M=H;N=G;break}S=(p&1)<<1|1;Q=R;R=I;U=H;V=G;while(1){W=Q+1|0;b:do{if((P|0)<(T|0)){X=ca(W,r)|0;Y=P;Z=R;_=U;$=V;while(1){aa=Y;c:while(1){ba=aa+1|0;da=(ca(b[l+((ba+X|0)<<2)>>1]|0,m)|0)+32768|0;ea=(ca(b[l+((ba+X|0)<<2)+2>>1]|0,m)|0)+32768|0;do{if(!((da>>16|0)>(v|0)|(da>>16|0)<(t|0)|(ea>>16|0)>(w|0)|(ea>>16|0)<(u|0))){fa=(da>>16)+F+(ea>>16<<11)|0;if((c[(A+(((ea>>16<<3)+(da>>16)&63)<<2)|0)>>2]|0)==(fa|0)){break}ga=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ha=c[(f+12420|0)>>2]|0;ia=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ga,ea>>16)|0)+(da>>16))|0;ja=Xe[D&511](f,c[(f+12288+(j<<4)|0)>>2]|0,ia,ga,o)|0;if((p&2|0)==0){ka=ja;break}ia=c[(f+12208|0)>>2]|0;la=(ca(ha,ea>>17)|0)+(da>>17)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ea>>16<<1&2|da>>16&1)<<2)>>2]&2047](ia+(ga<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+la|0,ha,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ea>>16<<1&2|da>>16&1)<<2)>>2]&2047](ia+(ga<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+la|0,ha,o>>1);la=(Xe[E&511](f,ia+(ga<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ha,o>>1)|0)+ja|0;ka=la+(Xe[E&511](f,ia+(ga<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ha,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(da>>16|0)){ka=536870912;break}if((da>>16<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ka=536870912;break}if((c[(f+12272|0)>>2]|0)>(ea>>16|0)){ka=536870912;break}if((ea>>16<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ka=536870912;break}ha=e[(f+13872|0)>>1]|0;ia=e[(f+13874|0)>>1]|0;d:do{if((c[(f+11740|0)>>2]|0)==1){if((da>>16<<B|0)==0){la=0;while(1){ja=c[f+12160+(la<<3)>>2]|0;ma=(c[f+12160+(la<<3)+4>>2]|0)+(ea>>16<<B)|0;na=((ca(c[f+12128+(la<<3)>>2]|0,ia-ha|0)|0)/(ha|0)|0)+((la&1)<<(p&1|4))|0;oa=c[f+12128+(la<<3)+4>>2]|0;if((ea>>16<<B|0)==0){pa=la>>1;qa=((ca(oa,ia-ha|0)|0)/(ha|0)|0)+(pa<<(p&1|4))|0;ra=pa}else{qa=ma-oa|0;ra=la>>1}oa=((qa&S)<<B)+(na&S)|0;pa=(c[(f+12208|0)>>2]|0)+((ca(ra,ga<<3)|0)+(la<<3&8))|0;if((p&1|0)==0){sa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ma>>1,ga)|0)+(ja>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ma&S)<<B)+(ja&S)|0)<<2)>>2]&2047](pa,sa,ga,8);sa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(qa>>1,ga)|0)+(na>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(oa<<2)>>2]&2047](pa,sa,ga,8)}else{sa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ma>>2,ga)|0)+(ja>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ma&S)<<B)+(ja&S)|0)<<2)>>2]&4095](pa,sa,ga);sa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(qa>>2,ga)|0)+(na>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(oa<<2)>>2]&4095](pa,sa,ga)}la=la+1|0;if((la|0)>=4){break d}}}if((ea>>16<<B|0)==0){la=0;do{sa=(c[f+12160+(la<<3)>>2]|0)+(da>>16<<B)|0;pa=c[f+12160+(la<<3)+4>>2]|0;oa=sa-(c[f+12128+(la<<3)>>2]|0)|0;na=la>>1;ja=((ca(c[f+12128+(la<<3)+4>>2]|0,ia-ha|0)|0)/(ha|0)|0)+(na<<(p&1|4))|0;ma=(c[(f+12208|0)>>2]|0)+((la<<3&8)+(ca(na,ga<<3)|0))|0;if((p&1|0)==0){na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(pa>>1,ga)|0)+(sa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((pa&S)<<B)+(sa&S)|0)<<2)>>2]&2047](ma,na,ga,8);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ja>>1,ga)|0)+(oa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ja&S)<<B)+(oa&S)|0)<<2)>>2]&2047](ma,na,ga,8)}else{na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(pa>>2,ga)|0)+(sa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(sa&S)|0)<<2)>>2]&4095](ma,na,ga);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ja>>2,ga)|0)+(oa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ja&S)<<B)+(oa&S)|0)<<2)>>2]&4095](ma,na,ga)}la=la+1|0;}while((la|0)<4)}else{la=0;do{na=(c[f+12160+(la<<3)>>2]|0)+(da>>16<<B)|0;ma=(c[f+12160+(la<<3)+4>>2]|0)+(ea>>16<<B)|0;oa=na-(c[f+12128+(la<<3)>>2]|0)|0;ja=ma-(c[f+12128+(la<<3)+4>>2]|0)|0;sa=(c[(f+12208|0)>>2]|0)+((la<<3&8)+(ca(la>>1,ga<<3)|0))|0;if((p&1|0)==0){pa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ma>>1,ga)|0)+(na>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ma&S)<<B)+(na&S)|0)<<2)>>2]&2047](sa,pa,ga,8);pa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ja>>1,ga)|0)+(oa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ja&S)<<B)+(oa&S)|0)<<2)>>2]&2047](sa,pa,ga,8)}else{pa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ma>>2,ga)|0)+(na>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ma&S)<<B)+(na&S)|0)<<2)>>2]&4095](sa,pa,ga);pa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ja>>2,ga)|0)+(oa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ja&S)<<B)+(oa&S)|0)<<2)>>2]&4095](sa,pa,ga)}la=la+1|0;}while((la|0)<4)}}else{la=(c[(f+12160|0)>>2]|0)+(da>>16<<B)|0;pa=(c[(f+12164|0)>>2]|0)+(ea>>16<<B)|0;sa=c[(f+12128|0)>>2]|0;if((da>>16<<B|0)==0){ta=(ca(sa,ia-ha|0)|0)/(ha|0)|0}else{ta=la-sa|0}sa=c[(f+12132|0)>>2]|0;if((ea>>16<<B|0)==0){ua=(ca(sa,ia-ha|0)|0)/(ha|0)|0}else{ua=pa-sa|0}sa=((ua&S)<<B)+(ta&S)|0;if((p&1|0)==0){oa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(pa>>1,ga)|0)+(la>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,oa,ga,16);oa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ua>>1,ga)|0)+(ta>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(sa<<2)>>2]&2047](c[(f+12208|0)>>2]|0,oa,ga,16);break}else{oa=(ca(pa>>2,ga)|0)+(la>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+oa|0,ga);ef[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(oa+8|0)|0,ga);ef[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ga<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(oa+(ga<<3))|0,ga);ef[c[(c[(f+12452|0)>>2]|0)+64+((((pa&S)<<B)+(la&S)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ga<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((oa+8|0)+(ga<<3))|0,ga);oa=(ca(ua>>2,ga)|0)+(ta>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(sa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+oa|0,ga);ef[c[(c[(f+12456|0)>>2]|0)+64+(sa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(oa+8|0)|0,ga);ef[c[(c[(f+12456|0)>>2]|0)+64+(sa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ga<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(oa+(ga<<3))|0,ga);ef[c[(c[(f+12456|0)>>2]|0)+64+(sa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ga<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((oa+8|0)+(ga<<3))|0,ga);break}}}while(0);ka=Xe[D&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ga,16)|0}}while(0);c[(A+(((ea>>16<<3)+(da>>16)&63)<<2)|0)>>2]=fa;c[s+(((ea>>16<<3)+(da>>16)&63)<<2)>>2]=ka;va=(ca((d[x+((ea>>16<<B)-z)|0]|0)+(d[x+((da>>16<<B)-y)|0]|0)|0,C)|0)+ka|0;if((va|0)<(Z|0)){break c}}}while(0);if((ba|0)<(T|0)){aa=ba}else{wa=Z;xa=_;ya=$;break b}}c[(a|0)>>2]=da>>16;c[(q+4|0)>>2]=ea>>16;if((ba|0)<(T|0)){Y=ba;Z=va;_=da>>16;$=ea>>16}else{wa=va;xa=da>>16;ya=ea>>16;break}}}else{wa=R;xa=U;ya=V}}while(0);if((W|0)<(O|0)){Q=W;R=wa;U=xa;V=ya}else{L=wa;M=xa;N=ya;break}}}}while(0);V=a|0;U=c[(f+12260|0)>>2]|0;e:do{R=1;if(R){R=0;if((U|0)==-1){Q=c[(f+12220|0)>>2]|0;O=c[(f+12264|0)>>2]|0;T=c[(f+12272|0)>>2]|0;S=c[(f+12268|0)>>2]|0;P=c[(f+12276|0)>>2]|0;$=c[(f+12464|0)>>2]|0;_=c[(f+12280|0)>>2]|0;Z=c[(f+12284|0)>>2]|0;Y=c[(f+12216|0)>>2]|0;X=c[(f+12224|0)>>2]|0;aa=c[f+10468+(n<<2)>>2]|0;ga=c[f+10468+((n+1|0)<<2)>>2]|0;ha=(p&1)<<1|1;ia=p&1|4;oa=(p&1|0)==0;sa=L;la=N;pa=M;f:while(1){ja=1;na=sa;ma=la;za=pa;while(1){do{if((ja-1&ja|0)==0){Aa=ja+pa|0;if((Aa|0)>(S|0)){Ba=na;Ca=ma;Da=za;break}Ea=pa-ja|0;if((Ea|0)<(O|0)){Ba=na;Ca=ma;Da=za;break}Fa=ja+la|0;if((Fa|0)>(P|0)){Ba=na;Ca=ma;Da=za;break}Ga=la-ja|0;if((Ga|0)<(T|0)){Ba=na;Ca=ma;Da=za;break}else{Ha=0;Ia=na;Ja=ma;Ka=za}while(1){La=Fa-Ha|0;Ma=Ha+pa|0;do{if((c[(Y+(((La<<3)+Ma&63)<<2)|0)>>2]|0)==(Ma+X+(La<<11)|0|0)){Na=Ia;Oa=Ja;Pa=Ka}else{Qa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Ra=c[(f+12420|0)>>2]|0;Sa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa,La)|0)+Ma)|0;Ta=Xe[aa&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Sa,Qa,o)|0;if((p&2|0)==0){Ua=Ta;break}Sa=c[(f+12208|0)>>2]|0;Va=(ca(Ra,La>>1)|0)+(Ma>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((La<<1&2|Ma&1)<<2)>>2]&2047](Sa+(Qa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Va|0,Ra,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((La<<1&2|Ma&1)<<2)>>2]&2047](Sa+(Qa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Va|0,Ra,o>>1);Va=(Xe[ga&511](f,Sa+(Qa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Ra,o>>1)|0)+Ta|0;Ua=Va+(Xe[ga&511](f,Sa+(Qa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Ra,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(Ma|0)){Ua=536870912;break}if((Ma<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Ua=536870912;break}if((c[(f+12272|0)>>2]|0)>(La|0)){Ua=536870912;break}if((La<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Ua=536870912;break}Ra=e[(f+13872|0)>>1]|0;Sa=e[(f+13874|0)>>1]|0;g:do{if((c[(f+11740|0)>>2]|0)==1){if((Ma<<B|0)==0){Va=0;while(1){Ta=c[f+12160+(Va<<3)>>2]|0;Wa=(c[f+12160+(Va<<3)+4>>2]|0)+(La<<B)|0;Xa=((ca(c[f+12128+(Va<<3)>>2]|0,Sa-Ra|0)|0)/(Ra|0)|0)+((Va&1)<<ia)|0;Ya=c[f+12128+(Va<<3)+4>>2]|0;if((La<<B|0)==0){Za=Va>>1;_a=((ca(Ya,Sa-Ra|0)|0)/(Ra|0)|0)+(Za<<ia)|0;$a=Za}else{_a=Wa-Ya|0;$a=Va>>1}Ya=((_a&ha)<<B)+(Xa&ha)|0;Za=(c[(f+12208|0)>>2]|0)+((ca($a,Qa<<3)|0)+(Va<<3&8))|0;if(oa){ab=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa>>1,Qa)|0)+(Ta>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Wa&ha)<<B)+(Ta&ha)|0)<<2)>>2]&2047](Za,ab,Qa,8);ab=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(_a>>1,Qa)|0)+(Xa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Ya<<2)>>2]&2047](Za,ab,Qa,8)}else{ab=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa>>2,Qa)|0)+(Ta>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Wa&ha)<<B)+(Ta&ha)|0)<<2)>>2]&4095](Za,ab,Qa);ab=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(_a>>2,Qa)|0)+(Xa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095](Za,ab,Qa)}Va=Va+1|0;if((Va|0)>=4){break g}}}if((La<<B|0)==0){Va=0;do{ab=(c[f+12160+(Va<<3)>>2]|0)+(Ma<<B)|0;Za=c[f+12160+(Va<<3)+4>>2]|0;Ya=ab-(c[f+12128+(Va<<3)>>2]|0)|0;Xa=Va>>1;Ta=((ca(c[f+12128+(Va<<3)+4>>2]|0,Sa-Ra|0)|0)/(Ra|0)|0)+(Xa<<ia)|0;Wa=(c[(f+12208|0)>>2]|0)+((Va<<3&8)+(ca(Xa,Qa<<3)|0))|0;if(oa){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Za>>1,Qa)|0)+(ab>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Za&ha)<<B)+(ab&ha)|0)<<2)>>2]&2047](Wa,Xa,Qa,8);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ta>>1,Qa)|0)+(Ya>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&2047](Wa,Xa,Qa,8)}else{Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Za>>2,Qa)|0)+(ab>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095](Wa,Xa,Qa);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ta>>2,Qa)|0)+(Ya>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095](Wa,Xa,Qa)}Va=Va+1|0;}while((Va|0)<4)}else{Va=0;do{Xa=(c[f+12160+(Va<<3)>>2]|0)+(Ma<<B)|0;Wa=(c[f+12160+(Va<<3)+4>>2]|0)+(La<<B)|0;Ya=Xa-(c[f+12128+(Va<<3)>>2]|0)|0;Ta=Wa-(c[f+12128+(Va<<3)+4>>2]|0)|0;ab=(c[(f+12208|0)>>2]|0)+((Va<<3&8)+(ca(Va>>1,Qa<<3)|0))|0;if(oa){Za=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa>>1,Qa)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Wa&ha)<<B)+(Xa&ha)|0)<<2)>>2]&2047](ab,Za,Qa,8);Za=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ta>>1,Qa)|0)+(Ya>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&2047](ab,Za,Qa,8)}else{Za=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa>>2,Qa)|0)+(Xa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Wa&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095](ab,Za,Qa);Za=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ta>>2,Qa)|0)+(Ya>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095](ab,Za,Qa)}Va=Va+1|0;}while((Va|0)<4)}}else{Va=(c[(f+12160|0)>>2]|0)+(Ma<<B)|0;Za=(c[(f+12164|0)>>2]|0)+(La<<B)|0;ab=c[(f+12128|0)>>2]|0;if((Ma<<B|0)==0){bb=(ca(ab,Sa-Ra|0)|0)/(Ra|0)|0}else{bb=Va-ab|0}ab=c[(f+12132|0)>>2]|0;if((La<<B|0)==0){cb=(ca(ab,Sa-Ra|0)|0)/(Ra|0)|0}else{cb=Za-ab|0}ab=((cb&ha)<<B)+(bb&ha)|0;if(oa){Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Za>>1,Qa)|0)+(Va>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ya,Qa,16);Ya=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(cb>>1,Qa)|0)+(bb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(ab<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ya,Qa,16);break}else{Ya=(ca(Za>>2,Qa)|0)+(Va>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ya|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ya+8|0)|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ya+(Qa<<3))|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Za&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ya+8|0)+(Qa<<3))|0,Qa);Ya=(ca(cb>>2,Qa)|0)+(bb>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ya|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ya+8|0)|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ya+(Qa<<3))|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ya+8|0)+(Qa<<3))|0,Qa);break}}}while(0);Ua=Xe[aa&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Qa,16)|0}}while(0);c[(Y+(((La<<3)+Ma&63)<<2)|0)>>2]=Ma+X+(La<<11)|0;c[Q+(((La<<3)+Ma&63)<<2)>>2]=Ua;Qa=(ca((d[$+((La<<B)-Z)|0]|0)+(d[$+((Ma<<B)-_)|0]|0)|0,C)|0)+Ua|0;if((Qa|0)>=(Ia|0)){Na=Ia;Oa=Ja;Pa=Ka;break}c[V>>2]=Ma;c[(V+4|0)>>2]=La;Na=Qa;Oa=La;Pa=Ma}}while(0);Ma=la-Ha|0;La=Aa-Ha|0;do{if((c[(Y+(((Ma<<3)+La&63)<<2)|0)>>2]|0)==(La+X+(Ma<<11)|0|0)){db=Na;eb=Oa;fb=Pa}else{Qa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){fa=c[(f+12420|0)>>2]|0;Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa,Ma)|0)+La)|0;Sa=Xe[aa&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ra,Qa,o)|0;if((p&2|0)==0){gb=Sa;break}Ra=c[(f+12208|0)>>2]|0;Ya=(ca(fa,Ma>>1)|0)+(La>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ma<<1&2|La&1)<<2)>>2]&2047](Ra+(Qa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Ya|0,fa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ma<<1&2|La&1)<<2)>>2]&2047](Ra+(Qa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Ya|0,fa,o>>1);Ya=(Xe[ga&511](f,Ra+(Qa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,fa,o>>1)|0)+Sa|0;gb=Ya+(Xe[ga&511](f,Ra+(Qa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,fa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(La|0)){gb=536870912;break}if((La<<B|0)>(c[(f+12268|0)>>2]<<B|0)){gb=536870912;break}if((c[(f+12272|0)>>2]|0)>(Ma|0)){gb=536870912;break}if((Ma<<B|0)>(c[(f+12276|0)>>2]<<B|0)){gb=536870912;break}fa=e[(f+13872|0)>>1]|0;Ra=e[(f+13874|0)>>1]|0;h:do{if((c[(f+11740|0)>>2]|0)==1){if((La<<B|0)==0){Ya=0;while(1){Sa=c[f+12160+(Ya<<3)>>2]|0;ab=(c[f+12160+(Ya<<3)+4>>2]|0)+(Ma<<B)|0;Va=((ca(c[f+12128+(Ya<<3)>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+((Ya&1)<<ia)|0;Za=c[f+12128+(Ya<<3)+4>>2]|0;if((Ma<<B|0)==0){Ta=Ya>>1;hb=((ca(Za,Ra-fa|0)|0)/(fa|0)|0)+(Ta<<ia)|0;ib=Ta}else{hb=ab-Za|0;ib=Ya>>1}Za=((hb&ha)<<B)+(Va&ha)|0;Ta=(c[(f+12208|0)>>2]|0)+((ca(ib,Qa<<3)|0)+(Ya<<3&8))|0;if(oa){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ab>>1,Qa)|0)+(Sa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ab&ha)<<B)+(Sa&ha)|0)<<2)>>2]&2047](Ta,Xa,Qa,8);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(hb>>1,Qa)|0)+(Va>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Za<<2)>>2]&2047](Ta,Xa,Qa,8)}else{Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ab>>2,Qa)|0)+(Sa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ab&ha)<<B)+(Sa&ha)|0)<<2)>>2]&4095](Ta,Xa,Qa);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(hb>>2,Qa)|0)+(Va>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095](Ta,Xa,Qa)}Ya=Ya+1|0;if((Ya|0)>=4){break h}}}if((Ma<<B|0)==0){Ya=0;do{Xa=(c[f+12160+(Ya<<3)>>2]|0)+(La<<B)|0;Ta=c[f+12160+(Ya<<3)+4>>2]|0;Za=Xa-(c[f+12128+(Ya<<3)>>2]|0)|0;Va=Ya>>1;Sa=((ca(c[f+12128+(Ya<<3)+4>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+(Va<<ia)|0;ab=(c[(f+12208|0)>>2]|0)+((Ya<<3&8)+(ca(Va,Qa<<3)|0))|0;if(oa){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>1,Qa)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ta&ha)<<B)+(Xa&ha)|0)<<2)>>2]&2047](ab,Va,Qa,8);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>1,Qa)|0)+(Za>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&2047](ab,Va,Qa,8)}else{Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>2,Qa)|0)+(Xa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095](ab,Va,Qa);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>2,Qa)|0)+(Za>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](ab,Va,Qa)}Ya=Ya+1|0;}while((Ya|0)<4)}else{Ya=0;do{Va=(c[f+12160+(Ya<<3)>>2]|0)+(La<<B)|0;ab=(c[f+12160+(Ya<<3)+4>>2]|0)+(Ma<<B)|0;Za=Va-(c[f+12128+(Ya<<3)>>2]|0)|0;Sa=ab-(c[f+12128+(Ya<<3)+4>>2]|0)|0;Xa=(c[(f+12208|0)>>2]|0)+((Ya<<3&8)+(ca(Ya>>1,Qa<<3)|0))|0;if(oa){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ab>>1,Qa)|0)+(Va>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ab&ha)<<B)+(Va&ha)|0)<<2)>>2]&2047](Xa,Ta,Qa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>1,Qa)|0)+(Za>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&2047](Xa,Ta,Qa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ab>>2,Qa)|0)+(Va>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ab&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095](Xa,Ta,Qa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>2,Qa)|0)+(Za>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](Xa,Ta,Qa)}Ya=Ya+1|0;}while((Ya|0)<4)}}else{Ya=(c[(f+12160|0)>>2]|0)+(La<<B)|0;Ta=(c[(f+12164|0)>>2]|0)+(Ma<<B)|0;Xa=c[(f+12128|0)>>2]|0;if((La<<B|0)==0){jb=(ca(Xa,Ra-fa|0)|0)/(fa|0)|0}else{jb=Ya-Xa|0}Xa=c[(f+12132|0)>>2]|0;if((Ma<<B|0)==0){kb=(ca(Xa,Ra-fa|0)|0)/(fa|0)|0}else{kb=Ta-Xa|0}Xa=((kb&ha)<<B)+(jb&ha)|0;if(oa){Za=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>1,Qa)|0)+(Ya>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Za,Qa,16);Za=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(kb>>1,Qa)|0)+(jb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(Xa<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Za,Qa,16);break}else{Za=(ca(Ta>>2,Qa)|0)+(Ya>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Za|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Za+8|0)|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Za+(Qa<<3))|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Za+8|0)+(Qa<<3))|0,Qa);Za=(ca(kb>>2,Qa)|0)+(jb>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Za|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Za+8|0)|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Za+(Qa<<3))|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Za+8|0)+(Qa<<3))|0,Qa);break}}}while(0);gb=Xe[aa&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Qa,16)|0}}while(0);c[(Y+(((Ma<<3)+La&63)<<2)|0)>>2]=La+X+(Ma<<11)|0;c[Q+(((Ma<<3)+La&63)<<2)>>2]=gb;Qa=(ca((d[$+((Ma<<B)-Z)|0]|0)+(d[$+((La<<B)-_)|0]|0)|0,C)|0)+gb|0;if((Qa|0)>=(Na|0)){db=Na;eb=Oa;fb=Pa;break}c[V>>2]=La;c[(V+4|0)>>2]=Ma;db=Qa;eb=Ma;fb=La}}while(0);La=Ha+Ga|0;Ma=pa-Ha|0;do{if((c[(Y+(((La<<3)+Ma&63)<<2)|0)>>2]|0)==(Ma+X+(La<<11)|0|0)){lb=db;mb=eb;nb=fb}else{Qa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){fa=c[(f+12420|0)>>2]|0;Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa,La)|0)+Ma)|0;Za=Xe[aa&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ra,Qa,o)|0;if((p&2|0)==0){ob=Za;break}Ra=c[(f+12208|0)>>2]|0;Xa=(ca(fa,La>>1)|0)+(Ma>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((La<<1&2|Ma&1)<<2)>>2]&2047](Ra+(Qa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Xa|0,fa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((La<<1&2|Ma&1)<<2)>>2]&2047](Ra+(Qa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Xa|0,fa,o>>1);Xa=(Xe[ga&511](f,Ra+(Qa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,fa,o>>1)|0)+Za|0;ob=Xa+(Xe[ga&511](f,Ra+(Qa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,fa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(Ma|0)){ob=536870912;break}if((Ma<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ob=536870912;break}if((c[(f+12272|0)>>2]|0)>(La|0)){ob=536870912;break}if((La<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ob=536870912;break}fa=e[(f+13872|0)>>1]|0;Ra=e[(f+13874|0)>>1]|0;i:do{if((c[(f+11740|0)>>2]|0)==1){if((Ma<<B|0)==0){Xa=0;while(1){Za=c[f+12160+(Xa<<3)>>2]|0;Ya=(c[f+12160+(Xa<<3)+4>>2]|0)+(La<<B)|0;Ta=((ca(c[f+12128+(Xa<<3)>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+((Xa&1)<<ia)|0;Sa=c[f+12128+(Xa<<3)+4>>2]|0;if((La<<B|0)==0){Va=Xa>>1;pb=((ca(Sa,Ra-fa|0)|0)/(fa|0)|0)+(Va<<ia)|0;qb=Va}else{pb=Ya-Sa|0;qb=Xa>>1}Sa=((pb&ha)<<B)+(Ta&ha)|0;Va=(c[(f+12208|0)>>2]|0)+((ca(qb,Qa<<3)|0)+(Xa<<3&8))|0;if(oa){ab=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ya>>1,Qa)|0)+(Za>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ya&ha)<<B)+(Za&ha)|0)<<2)>>2]&2047](Va,ab,Qa,8);ab=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(pb>>1,Qa)|0)+(Ta>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Sa<<2)>>2]&2047](Va,ab,Qa,8)}else{ab=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ya>>2,Qa)|0)+(Za>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ya&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](Va,ab,Qa);ab=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(pb>>2,Qa)|0)+(Ta>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Sa<<2)>>2]&4095](Va,ab,Qa)}Xa=Xa+1|0;if((Xa|0)>=4){break i}}}if((La<<B|0)==0){Xa=0;do{ab=(c[f+12160+(Xa<<3)>>2]|0)+(Ma<<B)|0;Va=c[f+12160+(Xa<<3)+4>>2]|0;Sa=ab-(c[f+12128+(Xa<<3)>>2]|0)|0;Ta=Xa>>1;Za=((ca(c[f+12128+(Xa<<3)+4>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+(Ta<<ia)|0;Ya=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ca(Ta,Qa<<3)|0))|0;if(oa){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Va>>1,Qa)|0)+(ab>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Va&ha)<<B)+(ab&ha)|0)<<2)>>2]&2047](Ya,Ta,Qa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Za>>1,Qa)|0)+(Sa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Za&ha)<<B)+(Sa&ha)|0)<<2)>>2]&2047](Ya,Ta,Qa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Va>>2,Qa)|0)+(ab>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095](Ya,Ta,Qa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Za>>2,Qa)|0)+(Sa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Za&ha)<<B)+(Sa&ha)|0)<<2)>>2]&4095](Ya,Ta,Qa)}Xa=Xa+1|0;}while((Xa|0)<4)}else{Xa=0;do{Ta=(c[f+12160+(Xa<<3)>>2]|0)+(Ma<<B)|0;Ya=(c[f+12160+(Xa<<3)+4>>2]|0)+(La<<B)|0;Sa=Ta-(c[f+12128+(Xa<<3)>>2]|0)|0;Za=Ya-(c[f+12128+(Xa<<3)+4>>2]|0)|0;ab=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ca(Xa>>1,Qa<<3)|0))|0;if(oa){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ya>>1,Qa)|0)+(Ta>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ya&ha)<<B)+(Ta&ha)|0)<<2)>>2]&2047](ab,Va,Qa,8);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Za>>1,Qa)|0)+(Sa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Za&ha)<<B)+(Sa&ha)|0)<<2)>>2]&2047](ab,Va,Qa,8)}else{Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ya>>2,Qa)|0)+(Ta>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ya&ha)<<B)+(Ta&ha)|0)<<2)>>2]&4095](ab,Va,Qa);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Za>>2,Qa)|0)+(Sa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Za&ha)<<B)+(Sa&ha)|0)<<2)>>2]&4095](ab,Va,Qa)}Xa=Xa+1|0;}while((Xa|0)<4)}}else{Xa=(c[(f+12160|0)>>2]|0)+(Ma<<B)|0;Va=(c[(f+12164|0)>>2]|0)+(La<<B)|0;ab=c[(f+12128|0)>>2]|0;if((Ma<<B|0)==0){rb=(ca(ab,Ra-fa|0)|0)/(fa|0)|0}else{rb=Xa-ab|0}ab=c[(f+12132|0)>>2]|0;if((La<<B|0)==0){sb=(ca(ab,Ra-fa|0)|0)/(fa|0)|0}else{sb=Va-ab|0}ab=((sb&ha)<<B)+(rb&ha)|0;if(oa){Sa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Va>>1,Qa)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Sa,Qa,16);Sa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(sb>>1,Qa)|0)+(rb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(ab<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Sa,Qa,16);break}else{Sa=(ca(Va>>2,Qa)|0)+(Xa>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Sa|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Sa+8|0)|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Sa+(Qa<<3))|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Va&ha)<<B)+(Xa&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Sa+8|0)+(Qa<<3))|0,Qa);Sa=(ca(sb>>2,Qa)|0)+(rb>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Sa|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Sa+8|0)|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Sa+(Qa<<3))|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ab<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Sa+8|0)+(Qa<<3))|0,Qa);break}}}while(0);ob=Xe[aa&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Qa,16)|0}}while(0);c[(Y+(((La<<3)+Ma&63)<<2)|0)>>2]=Ma+X+(La<<11)|0;c[Q+(((La<<3)+Ma&63)<<2)>>2]=ob;Qa=(ca((d[$+((La<<B)-Z)|0]|0)+(d[$+((Ma<<B)-_)|0]|0)|0,C)|0)+ob|0;if((Qa|0)>=(db|0)){lb=db;mb=eb;nb=fb;break}c[V>>2]=Ma;c[(V+4|0)>>2]=La;lb=Qa;mb=La;nb=Ma}}while(0);Ma=Ha+la|0;La=Ha+Ea|0;do{if((c[(Y+(((Ma<<3)+La&63)<<2)|0)>>2]|0)==(La+X+(Ma<<11)|0|0)){tb=lb;ub=mb;vb=nb}else{Qa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){fa=c[(f+12420|0)>>2]|0;Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa,Ma)|0)+La)|0;Sa=Xe[aa&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ra,Qa,o)|0;if((p&2|0)==0){wb=Sa;break}Ra=c[(f+12208|0)>>2]|0;ab=(ca(fa,Ma>>1)|0)+(La>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ma<<1&2|La&1)<<2)>>2]&2047](Ra+(Qa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+ab|0,fa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ma<<1&2|La&1)<<2)>>2]&2047](Ra+(Qa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+ab|0,fa,o>>1);ab=(Xe[ga&511](f,Ra+(Qa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,fa,o>>1)|0)+Sa|0;wb=ab+(Xe[ga&511](f,Ra+(Qa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,fa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(La|0)){wb=536870912;break}if((La<<B|0)>(c[(f+12268|0)>>2]<<B|0)){wb=536870912;break}if((c[(f+12272|0)>>2]|0)>(Ma|0)){wb=536870912;break}if((Ma<<B|0)>(c[(f+12276|0)>>2]<<B|0)){wb=536870912;break}fa=e[(f+13872|0)>>1]|0;Ra=e[(f+13874|0)>>1]|0;j:do{if((c[(f+11740|0)>>2]|0)==1){if((La<<B|0)==0){ab=0;while(1){Sa=c[f+12160+(ab<<3)>>2]|0;Xa=(c[f+12160+(ab<<3)+4>>2]|0)+(Ma<<B)|0;Va=((ca(c[f+12128+(ab<<3)>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+((ab&1)<<ia)|0;Za=c[f+12128+(ab<<3)+4>>2]|0;if((Ma<<B|0)==0){Ta=ab>>1;xb=((ca(Za,Ra-fa|0)|0)/(fa|0)|0)+(Ta<<ia)|0;yb=Ta}else{xb=Xa-Za|0;yb=ab>>1}Za=((xb&ha)<<B)+(Va&ha)|0;Ta=(c[(f+12208|0)>>2]|0)+((ca(yb,Qa<<3)|0)+(ab<<3&8))|0;if(oa){Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Xa>>1,Qa)|0)+(Sa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Xa&ha)<<B)+(Sa&ha)|0)<<2)>>2]&2047](Ta,Ya,Qa,8);Ya=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(xb>>1,Qa)|0)+(Va>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Za<<2)>>2]&2047](Ta,Ya,Qa,8)}else{Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Xa>>2,Qa)|0)+(Sa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Xa&ha)<<B)+(Sa&ha)|0)<<2)>>2]&4095](Ta,Ya,Qa);Ya=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(xb>>2,Qa)|0)+(Va>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Za<<2)>>2]&4095](Ta,Ya,Qa)}ab=ab+1|0;if((ab|0)>=4){break j}}}if((Ma<<B|0)==0){ab=0;do{Ya=(c[f+12160+(ab<<3)>>2]|0)+(La<<B)|0;Ta=c[f+12160+(ab<<3)+4>>2]|0;Za=Ya-(c[f+12128+(ab<<3)>>2]|0)|0;Va=ab>>1;Sa=((ca(c[f+12128+(ab<<3)+4>>2]|0,Ra-fa|0)|0)/(fa|0)|0)+(Va<<ia)|0;Xa=(c[(f+12208|0)>>2]|0)+((ab<<3&8)+(ca(Va,Qa<<3)|0))|0;if(oa){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>1,Qa)|0)+(Ya>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&2047](Xa,Va,Qa,8);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>1,Qa)|0)+(Za>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&2047](Xa,Va,Qa,8)}else{Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>2,Qa)|0)+(Ya>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(Ya&ha)|0)<<2)>>2]&4095](Xa,Va,Qa);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>2,Qa)|0)+(Za>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](Xa,Va,Qa)}ab=ab+1|0;}while((ab|0)<4)}else{ab=0;do{Va=(c[f+12160+(ab<<3)>>2]|0)+(La<<B)|0;Xa=(c[f+12160+(ab<<3)+4>>2]|0)+(Ma<<B)|0;Za=Va-(c[f+12128+(ab<<3)>>2]|0)|0;Sa=Xa-(c[f+12128+(ab<<3)+4>>2]|0)|0;Ya=(c[(f+12208|0)>>2]|0)+((ab<<3&8)+(ca(ab>>1,Qa<<3)|0))|0;if(oa){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Xa>>1,Qa)|0)+(Va>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Xa&ha)<<B)+(Va&ha)|0)<<2)>>2]&2047](Ya,Ta,Qa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>1,Qa)|0)+(Za>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&2047](Ya,Ta,Qa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Xa>>2,Qa)|0)+(Va>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Xa&ha)<<B)+(Va&ha)|0)<<2)>>2]&4095](Ya,Ta,Qa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>2,Qa)|0)+(Za>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&ha)<<B)+(Za&ha)|0)<<2)>>2]&4095](Ya,Ta,Qa)}ab=ab+1|0;}while((ab|0)<4)}}else{ab=(c[(f+12160|0)>>2]|0)+(La<<B)|0;Ta=(c[(f+12164|0)>>2]|0)+(Ma<<B)|0;Ya=c[(f+12128|0)>>2]|0;if((La<<B|0)==0){zb=(ca(Ya,Ra-fa|0)|0)/(fa|0)|0}else{zb=ab-Ya|0}Ya=c[(f+12132|0)>>2]|0;if((Ma<<B|0)==0){Ab=(ca(Ya,Ra-fa|0)|0)/(fa|0)|0}else{Ab=Ta-Ya|0}Ya=((Ab&ha)<<B)+(zb&ha)|0;if(oa){Za=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>1,Qa)|0)+(ab>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Za,Qa,16);Za=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ab>>1,Qa)|0)+(zb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(Ya<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Za,Qa,16);break}else{Za=(ca(Ta>>2,Qa)|0)+(ab>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Za|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Za+8|0)|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Za+(Qa<<3))|0,Qa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&ha)<<B)+(ab&ha)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Za+8|0)+(Qa<<3))|0,Qa);Za=(ca(Ab>>2,Qa)|0)+(zb>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Za|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Za+8|0)|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Qa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Za+(Qa<<3))|0,Qa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ya<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Qa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Za+8|0)+(Qa<<3))|0,Qa);break}}}while(0);wb=Xe[aa&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Qa,16)|0}}while(0);c[(Y+(((Ma<<3)+La&63)<<2)|0)>>2]=La+X+(Ma<<11)|0;c[Q+(((Ma<<3)+La&63)<<2)>>2]=wb;Qa=(ca((d[$+((Ma<<B)-Z)|0]|0)+(d[$+((La<<B)-_)|0]|0)|0,C)|0)+wb|0;if((Qa|0)>=(lb|0)){tb=lb;ub=mb;vb=nb;break}c[V>>2]=La;c[(V+4|0)>>2]=Ma;tb=Qa;ub=Ma;vb=La}}while(0);La=Ha+2|0;if((La|0)<(ja|0)){Ha=La;Ia=tb;Ja=ub;Ka=vb}else{break}}if((pa|0)!=(vb|0)){sa=tb;la=ub;pa=vb;continue f}if((la|0)==(ub|0)){Ba=tb;Ca=la;Da=pa}else{sa=tb;la=ub;pa=pa;continue f}}else{Ba=na;Ca=ma;Da=za}}while(0);Ea=ja+1|0;if((Ea|0)<5){ja=Ea;na=Ba;ma=Ca;za=Da}else{Bb=Ba;break e}}}}else{R=1}}if(R){R=0;if(1){if((U|0)<-1){Bb=trb(f,V,j,k,C,n,o,p)|0;break}if((U|0)<2){pa=c[(f+12220|0)>>2]|0;la=c[(f+12264|0)>>2]|0;sa=c[(f+12272|0)>>2]|0;_=c[(f+12268|0)>>2]|0;$=c[(f+12276|0)>>2]|0;Z=c[(f+12464|0)>>2]|0;Q=c[(f+12280|0)>>2]|0;X=c[(f+12284|0)>>2]|0;Y=c[(f+12216|0)>>2]|0;aa=c[(f+12224|0)>>2]|0;ha=c[f+10468+(n<<2)>>2]|0;oa=c[f+10468+((n+1|0)<<2)>>2]|0;ia=(N<<11)+M+aa|0;ga=(N<<3)+M&63;if((c[(Y+(ga<<2)|0)>>2]|0)!=(ia|0)){do{if((p&4|0)==0){T=c[f+12416>>2]|0;P=c[f+12420>>2]|0;O=(c[f+12352+(k<<4)>>2]|0)+((ca(T,N)|0)+M)|0;S=Xe[ha&511](f,c[f+12288+(j<<4)>>2]|0,O,T,o)|0;if((p&2|0)==0){Cb=S;break}O=N<<1&2|M&1;za=c[f+12208>>2]|0;ma=(ca(P,N>>1)|0)+(M>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(O<<2)>>2]&2047](za+(T<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+ma|0,P,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(O<<2)>>2]&2047](za+(T<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+ma|0,P,o>>1);ma=(Xe[oa&511](f,za+(T<<4)|0,c[f+12288+(j<<4)+4>>2]|0,P,o>>1)|0)+S|0;Cb=ma+(Xe[oa&511](f,za+(T<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,P,o>>1)|0)|0}else{P=c[f+12416>>2]|0;T=M<<B;za=N<<B;if((la|0)>(M|0)){Cb=536870912;break}if((T|0)>(_<<B|0)|(sa|0)>(N|0)){Cb=536870912;break}if((za|0)>($<<B|0)){Cb=536870912;break}ma=e[f+13872>>1]|0;S=e[f+13874>>1]|0;O=(p&1)<<1|1;k:do{if((c[f+11740>>2]|0)==1){if((T|0)==0){na=0;while(1){ja=c[f+12160+(na<<3)>>2]|0;W=(c[f+12160+(na<<3)+4>>2]|0)+za|0;Ea=((ca(c[f+12128+(na<<3)>>2]|0,S-ma|0)|0)/(ma|0)|0)+((na&1)<<(p&1|4))|0;Ga=c[f+12128+(na<<3)+4>>2]|0;if((za|0)==0){Aa=na>>1;Db=((ca(Ga,S-ma|0)|0)/(ma|0)|0)+(Aa<<(p&1|4))|0;Eb=Aa}else{Db=W-Ga|0;Eb=na>>1}Ga=((Db&O)<<B)+(Ea&O)|0;Aa=(c[(f+12208|0)>>2]|0)+((ca(Eb,P<<3)|0)+(na<<3&8))|0;if((p&1|0)==0){Fa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(W>>1,P)|0)+(ja>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((W&O)<<B)+(ja&O)|0)<<2)>>2]&2047](Aa,Fa,P,8);Fa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Db>>1,P)|0)+(Ea>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Ga<<2)>>2]&2047](Aa,Fa,P,8)}else{Fa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(W>>2,P)|0)+(ja>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((W&O)<<B)+(ja&O)|0)<<2)>>2]&4095](Aa,Fa,P);Fa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Db>>2,P)|0)+(Ea>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095](Aa,Fa,P)}na=na+1|0;if((na|0)>=4){break k}}}if((za|0)==0){na=0;do{Fa=(c[f+12160+(na<<3)>>2]|0)+T|0;Aa=c[f+12160+(na<<3)+4>>2]|0;Ga=Fa-(c[f+12128+(na<<3)>>2]|0)|0;Ea=na>>1;ja=((ca(c[f+12128+(na<<3)+4>>2]|0,S-ma|0)|0)/(ma|0)|0)+(Ea<<(p&1|4))|0;W=(c[(f+12208|0)>>2]|0)+((na<<3&8)+(ca(Ea,P<<3)|0))|0;if((p&1|0)==0){Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Aa>>1,P)|0)+(Fa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Aa&O)<<B)+(Fa&O)|0)<<2)>>2]&2047](W,Ea,P,8);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ja>>1,P)|0)+(Ga>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ja&O)<<B)+(Ga&O)|0)<<2)>>2]&2047](W,Ea,P,8)}else{Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Aa>>2,P)|0)+(Fa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(Fa&O)|0)<<2)>>2]&4095](W,Ea,P);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ja>>2,P)|0)+(Ga>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ja&O)<<B)+(Ga&O)|0)<<2)>>2]&4095](W,Ea,P)}na=na+1|0;}while((na|0)<4)}else{na=0;do{Ea=(c[f+12160+(na<<3)>>2]|0)+T|0;W=(c[f+12160+(na<<3)+4>>2]|0)+za|0;Ga=Ea-(c[f+12128+(na<<3)>>2]|0)|0;ja=W-(c[f+12128+(na<<3)+4>>2]|0)|0;Fa=(c[(f+12208|0)>>2]|0)+((na<<3&8)+(ca(na>>1,P<<3)|0))|0;if((p&1|0)==0){Aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(W>>1,P)|0)+(Ea>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((W&O)<<B)+(Ea&O)|0)<<2)>>2]&2047](Fa,Aa,P,8);Aa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ja>>1,P)|0)+(Ga>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ja&O)<<B)+(Ga&O)|0)<<2)>>2]&2047](Fa,Aa,P,8)}else{Aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(W>>2,P)|0)+(Ea>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((W&O)<<B)+(Ea&O)|0)<<2)>>2]&4095](Fa,Aa,P);Aa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ja>>2,P)|0)+(Ga>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ja&O)<<B)+(Ga&O)|0)<<2)>>2]&4095](Fa,Aa,P)}na=na+1|0;}while((na|0)<4)}}else{na=(c[f+12160>>2]|0)+T|0;Aa=(c[f+12164>>2]|0)+za|0;Fa=c[f+12128>>2]|0;if((T|0)==0){Fb=(ca(Fa,S-ma|0)|0)/(ma|0)|0}else{Fb=na-Fa|0}Fa=c[f+12132>>2]|0;if((za|0)==0){Gb=(ca(Fa,S-ma|0)|0)/(ma|0)|0}else{Gb=Aa-Fa|0}Fa=((Gb&O)<<B)+(Fb&O)|0;if((p&1|0)==0){Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Aa>>1,P)|0)+(na>>1))|0;mf[c[(c[f+12444>>2]|0)+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ga,P,16);Ga=(c[f+12352+(k<<4)+32>>2]|0)+((ca(Gb>>1,P)|0)+(Fb>>1))|0;mf[c[(c[f+12448>>2]|0)+(Fa<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ga,P,16);break}else{Ga=(ca(Aa>>2,P)|0)+(na>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ga|0,P);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ga+8|0)|0,P);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(P<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ga+(P<<3))|0,P);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Aa&O)<<B)+(na&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((P<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ga+8|0)+(P<<3))|0,P);Ga=(ca(Gb>>2,P)|0)+(Fb>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Fa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ga|0,P);ef[c[(c[(f+12456|0)>>2]|0)+64+(Fa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ga+8|0)|0,P);ef[c[(c[(f+12456|0)>>2]|0)+64+(Fa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(P<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ga+(P<<3))|0,P);ef[c[(c[(f+12456|0)>>2]|0)+64+(Fa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((P<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ga+8|0)+(P<<3))|0,P);break}}}while(0);Cb=Xe[ha&511](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,P,16)|0}}while(0);c[pa+(ga<<2)>>2]=Cb;c[(Y+(ga<<2)|0)>>2]=ia}O=(p&1)<<1|1;ma=p&1|4;S=(p&1|0)==0;za=L;T=-1;Ga=M;Fa=N;while(1){na=(Ga|0)>(la|0);Aa=Ga-1|0;ja=Ga+aa|0;Ea=Ga&1;W=Ga>>1;La=Ga<<B;Ma=(Ga|0)<(_|0);Qa=Ga+1|0;fa=za;Ra=T;Za=Fa;while(1){do{if((Ra|0)!=2&na){Ya=(Za<<11)+aa+Aa|0;ab=Aa+(Za<<3)&63;if((c[(Y+(ab<<2)|0)>>2]|0)==(Ya|0)){Hb=fa;Ib=-1;Jb=Ga;break}Ta=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Sa=c[(f+12420|0)>>2]|0;Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta,Za)|0)+Aa)|0;Xa=Xe[ha&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Va,Ta,o)|0;if((p&2|0)==0){Kb=Xa;break}Va=Aa&1|Za<<1&2;Wa=c[(f+12208|0)>>2]|0;Lb=(ca(Sa,Za>>1)|0)+(Aa>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Va<<2)>>2]&2047](Wa+(Ta<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Lb|0,Sa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Va<<2)>>2]&2047](Wa+(Ta<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Lb|0,Sa,o>>1);Lb=(Xe[oa&511](f,Wa+(Ta<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Sa,o>>1)|0)+Xa|0;Kb=Lb+(Xe[oa&511](f,Wa+(Ta<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Sa,o>>1)|0)|0}else{Sa=Za<<B;if((c[(f+12264|0)>>2]|0)>(Aa|0)){Kb=536870912;break}if((Aa<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Kb=536870912;break}if((c[(f+12272|0)>>2]|0)>(Za|0)){Kb=536870912;break}if((Sa|0)>(c[(f+12276|0)>>2]<<B|0)){Kb=536870912;break}Wa=e[(f+13872|0)>>1]|0;Lb=e[(f+13874|0)>>1]|0;l:do{if((c[(f+11740|0)>>2]|0)==1){if((Aa<<B|0)==0){Xa=0;while(1){Va=c[f+12160+(Xa<<3)>>2]|0;Mb=(c[f+12160+(Xa<<3)+4>>2]|0)+Sa|0;Nb=((ca(c[f+12128+(Xa<<3)>>2]|0,Lb-Wa|0)|0)/(Wa|0)|0)+((Xa&1)<<ma)|0;Ob=c[f+12128+(Xa<<3)+4>>2]|0;if((Sa|0)==0){Pb=Xa>>1;Qb=((ca(Ob,Lb-Wa|0)|0)/(Wa|0)|0)+(Pb<<ma)|0;Rb=Pb}else{Qb=Mb-Ob|0;Rb=Xa>>1}Ob=((Qb&O)<<B)+(Nb&O)|0;Pb=(c[(f+12208|0)>>2]|0)+((ca(Rb,Ta<<3)|0)+(Xa<<3&8))|0;if(S){Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>1,Ta)|0)+(Va>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(Va&O)|0)<<2)>>2]&2047](Pb,Sb,Ta,8);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Qb>>1,Ta)|0)+(Nb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Ob<<2)>>2]&2047](Pb,Sb,Ta,8)}else{Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>2,Ta)|0)+(Va>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Va&O)|0)<<2)>>2]&4095](Pb,Sb,Ta);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Qb>>2,Ta)|0)+(Nb>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ob<<2)>>2]&4095](Pb,Sb,Ta)}Xa=Xa+1|0;if((Xa|0)>=4){break l}}}if((Sa|0)==0){Xa=0;do{Sb=(c[f+12160+(Xa<<3)>>2]|0)+(Aa<<B)|0;Pb=c[f+12160+(Xa<<3)+4>>2]|0;Ob=Sb-(c[f+12128+(Xa<<3)>>2]|0)|0;Nb=Xa>>1;Va=((ca(c[f+12128+(Xa<<3)+4>>2]|0,Lb-Wa|0)|0)/(Wa|0)|0)+(Nb<<ma)|0;Mb=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ca(Nb,Ta<<3)|0))|0;if(S){Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>1,Ta)|0)+(Sb>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Pb&O)<<B)+(Sb&O)|0)<<2)>>2]&2047](Mb,Nb,Ta,8);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Va>>1,Ta)|0)+(Ob>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Va&O)<<B)+(Ob&O)|0)<<2)>>2]&2047](Mb,Nb,Ta,8)}else{Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>2,Ta)|0)+(Sb>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Sb&O)|0)<<2)>>2]&4095](Mb,Nb,Ta);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Va>>2,Ta)|0)+(Ob>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Va&O)<<B)+(Ob&O)|0)<<2)>>2]&4095](Mb,Nb,Ta)}Xa=Xa+1|0;}while((Xa|0)<4)}else{Xa=0;do{Nb=(c[f+12160+(Xa<<3)>>2]|0)+(Aa<<B)|0;Mb=(c[f+12160+(Xa<<3)+4>>2]|0)+Sa|0;Ob=Nb-(c[f+12128+(Xa<<3)>>2]|0)|0;Va=Mb-(c[f+12128+(Xa<<3)+4>>2]|0)|0;Sb=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ca(Xa>>1,Ta<<3)|0))|0;if(S){Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>1,Ta)|0)+(Nb>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(Nb&O)|0)<<2)>>2]&2047](Sb,Pb,Ta,8);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Va>>1,Ta)|0)+(Ob>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Va&O)<<B)+(Ob&O)|0)<<2)>>2]&2047](Sb,Pb,Ta,8)}else{Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>2,Ta)|0)+(Nb>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](Sb,Pb,Ta);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Va>>2,Ta)|0)+(Ob>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Va&O)<<B)+(Ob&O)|0)<<2)>>2]&4095](Sb,Pb,Ta)}Xa=Xa+1|0;}while((Xa|0)<4)}}else{Xa=(c[(f+12160|0)>>2]|0)+(Aa<<B)|0;Pb=(c[(f+12164|0)>>2]|0)+Sa|0;Sb=c[(f+12128|0)>>2]|0;if((Aa<<B|0)==0){Tb=(ca(Sb,Lb-Wa|0)|0)/(Wa|0)|0}else{Tb=Xa-Sb|0}Sb=c[(f+12132|0)>>2]|0;if((Sa|0)==0){Ub=(ca(Sb,Lb-Wa|0)|0)/(Wa|0)|0}else{Ub=Pb-Sb|0}Sb=((Ub&O)<<B)+(Tb&O)|0;if(S){Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>1,Ta)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ob,Ta,16);Ob=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ub>>1,Ta)|0)+(Tb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(Sb<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ob,Ta,16);break}else{Ob=(ca(Pb>>2,Ta)|0)+(Xa>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ob|0,Ta);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ob+8|0)|0,Ta);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ta<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ob+(Ta<<3))|0,Ta);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ta<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ob+8|0)+(Ta<<3))|0,Ta);Ob=(ca(Ub>>2,Ta)|0)+(Tb>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ob|0,Ta);ef[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ob+8|0)|0,Ta);ef[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ta<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ob+(Ta<<3))|0,Ta);ef[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ta<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ob+8|0)+(Ta<<3))|0,Ta);break}}}while(0);Kb=Xe[ha&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Ta,16)|0}}while(0);c[(Y+(ab<<2)|0)>>2]=Ya;c[pa+(ab<<2)>>2]=Kb;Ta=(ca((d[Z+((Za<<B)-X)|0]|0)+(d[Z+((Aa<<B)-Q)|0]|0)|0,C)|0)+Kb|0;if((Ta|0)>=(fa|0)){Hb=fa;Ib=-1;Jb=Ga;break}c[V>>2]=Aa;c[(V+4|0)>>2]=Za;Hb=Ta;Ib=0;Jb=Aa}else{Hb=fa;Ib=-1;Jb=Ga}}while(0);do{if((Ra|0)!=3&(Za|0)>(sa|0)){Ta=Za-1|0;Wa=(Ta<<3)+Ga&63;if((c[(Y+(Wa<<2)|0)>>2]|0)==(ja+(Ta<<11)|0|0)){Vb=Hb;Wb=Ib;Xb=Jb;Yb=Za;break}Lb=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Sa=c[(f+12420|0)>>2]|0;Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Lb,Ta)|0)+Ga)|0;Sb=Xe[ha&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ob,Lb,o)|0;if((p&2|0)==0){Zb=Sb;break}Ob=c[(f+12208|0)>>2]|0;Xa=(ca(Sa,Ta>>1)|0)+W|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ta<<1&2|Ea)<<2)>>2]&2047](Ob+(Lb<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Xa|0,Sa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ta<<1&2|Ea)<<2)>>2]&2047](Ob+(Lb<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Xa|0,Sa,o>>1);Xa=(Xe[oa&511](f,Ob+(Lb<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Sa,o>>1)|0)+Sb|0;Zb=Xa+(Xe[oa&511](f,Ob+(Lb<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Sa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(Ga|0)){Zb=536870912;break}if((La|0)>(c[(f+12268|0)>>2]<<B|0)){Zb=536870912;break}if((c[(f+12272|0)>>2]|0)>(Ta|0)){Zb=536870912;break}if((Ta<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Zb=536870912;break}Sa=e[(f+13872|0)>>1]|0;Ob=e[(f+13874|0)>>1]|0;m:do{if((c[(f+11740|0)>>2]|0)==1){if((La|0)==0){Xa=0;while(1){Sb=c[f+12160+(Xa<<3)>>2]|0;Pb=(c[f+12160+(Xa<<3)+4>>2]|0)+(Ta<<B)|0;Va=((ca(c[f+12128+(Xa<<3)>>2]|0,Ob-Sa|0)|0)/(Sa|0)|0)+((Xa&1)<<ma)|0;Nb=c[f+12128+(Xa<<3)+4>>2]|0;if((Ta<<B|0)==0){Mb=Xa>>1;_b=((ca(Nb,Ob-Sa|0)|0)/(Sa|0)|0)+(Mb<<ma)|0;$b=Mb}else{_b=Pb-Nb|0;$b=Xa>>1}Nb=((_b&O)<<B)+(Va&O)|0;Mb=(c[(f+12208|0)>>2]|0)+((ca($b,Lb<<3)|0)+(Xa<<3&8))|0;if(S){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>1,Lb)|0)+(Sb>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Pb&O)<<B)+(Sb&O)|0)<<2)>>2]&2047](Mb,ac,Lb,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(_b>>1,Lb)|0)+(Va>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Nb<<2)>>2]&2047](Mb,ac,Lb,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>2,Lb)|0)+(Sb>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Sb&O)|0)<<2)>>2]&4095](Mb,ac,Lb);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(_b>>2,Lb)|0)+(Va>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Nb<<2)>>2]&4095](Mb,ac,Lb)}Xa=Xa+1|0;if((Xa|0)>=4){break m}}}if((Ta<<B|0)==0){Xa=0;do{ac=(c[f+12160+(Xa<<3)>>2]|0)+La|0;Mb=c[f+12160+(Xa<<3)+4>>2]|0;Nb=ac-(c[f+12128+(Xa<<3)>>2]|0)|0;Va=Xa>>1;Sb=((ca(c[f+12128+(Xa<<3)+4>>2]|0,Ob-Sa|0)|0)/(Sa|0)|0)+(Va<<ma)|0;Pb=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ca(Va,Lb<<3)|0))|0;if(S){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>1,Lb)|0)+(ac>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(ac&O)|0)<<2)>>2]&2047](Pb,Va,Lb,8);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sb>>1,Lb)|0)+(Nb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Sb&O)<<B)+(Nb&O)|0)<<2)>>2]&2047](Pb,Va,Lb,8)}else{Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>2,Lb)|0)+(ac>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(ac&O)|0)<<2)>>2]&4095](Pb,Va,Lb);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sb>>2,Lb)|0)+(Nb>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Sb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](Pb,Va,Lb)}Xa=Xa+1|0;}while((Xa|0)<4)}else{Xa=0;do{Va=(c[f+12160+(Xa<<3)>>2]|0)+La|0;Pb=(c[f+12160+(Xa<<3)+4>>2]|0)+(Ta<<B)|0;Nb=Va-(c[f+12128+(Xa<<3)>>2]|0)|0;Sb=Pb-(c[f+12128+(Xa<<3)+4>>2]|0)|0;ac=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ca(Xa>>1,Lb<<3)|0))|0;if(S){Mb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>1,Lb)|0)+(Va>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Pb&O)<<B)+(Va&O)|0)<<2)>>2]&2047](ac,Mb,Lb,8);Mb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sb>>1,Lb)|0)+(Nb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Sb&O)<<B)+(Nb&O)|0)<<2)>>2]&2047](ac,Mb,Lb,8)}else{Mb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>2,Lb)|0)+(Va>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Va&O)|0)<<2)>>2]&4095](ac,Mb,Lb);Mb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sb>>2,Lb)|0)+(Nb>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Sb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](ac,Mb,Lb)}Xa=Xa+1|0;}while((Xa|0)<4)}}else{Xa=(c[(f+12160|0)>>2]|0)+La|0;Mb=(c[(f+12164|0)>>2]|0)+(Ta<<B)|0;ac=c[(f+12128|0)>>2]|0;if((La|0)==0){bc=(ca(ac,Ob-Sa|0)|0)/(Sa|0)|0}else{bc=Xa-ac|0}ac=c[(f+12132|0)>>2]|0;if((Ta<<B|0)==0){cc=(ca(ac,Ob-Sa|0)|0)/(Sa|0)|0}else{cc=Mb-ac|0}ac=((cc&O)<<B)+(bc&O)|0;if(S){Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>1,Lb)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Nb,Lb,16);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(cc>>1,Lb)|0)+(bc>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(ac<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Nb,Lb,16);break}else{Nb=(ca(Mb>>2,Lb)|0)+(Xa>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Nb|0,Lb);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Nb+8|0)|0,Lb);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Lb<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Nb+(Lb<<3))|0,Lb);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Xa&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Lb<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Nb+8|0)+(Lb<<3))|0,Lb);Nb=(ca(cc>>2,Lb)|0)+(bc>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Nb|0,Lb);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Nb+8|0)|0,Lb);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Lb<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Nb+(Lb<<3))|0,Lb);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Lb<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Nb+8|0)+(Lb<<3))|0,Lb);break}}}while(0);Zb=Xe[ha&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Lb,16)|0}}while(0);c[(Y+(Wa<<2)|0)>>2]=ja+(Ta<<11)|0;c[pa+(Wa<<2)>>2]=Zb;Lb=(ca((d[Z+((Ta<<B)-X)|0]|0)+(d[Z+(La-Q)|0]|0)|0,C)|0)+Zb|0;if((Lb|0)>=(Hb|0)){Vb=Hb;Wb=Ib;Xb=Jb;Yb=Za;break}c[V>>2]=Ga;c[(V+4|0)>>2]=Ta;Vb=Lb;Wb=1;Xb=Ga;Yb=Ta}else{Vb=Hb;Wb=Ib;Xb=Jb;Yb=Za}}while(0);do{if((Ra|0)!=0&Ma){Lb=(Za<<11)+aa+Qa|0;ab=Qa+(Za<<3)&63;if((c[(Y+(ab<<2)|0)>>2]|0)==(Lb|0)){dc=Vb;ec=Wb;fc=Xb;gc=Yb;break}Ya=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Sa=c[(f+12420|0)>>2]|0;Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ya,Za)|0)+Qa)|0;Nb=Xe[ha&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ob,Ya,o)|0;if((p&2|0)==0){hc=Nb;break}Ob=Qa&1|Za<<1&2;ac=c[(f+12208|0)>>2]|0;Xa=(ca(Sa,Za>>1)|0)+(Qa>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Ob<<2)>>2]&2047](ac+(Ya<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Xa|0,Sa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Ob<<2)>>2]&2047](ac+(Ya<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Xa|0,Sa,o>>1);Xa=(Xe[oa&511](f,ac+(Ya<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Sa,o>>1)|0)+Nb|0;hc=Xa+(Xe[oa&511](f,ac+(Ya<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Sa,o>>1)|0)|0}else{Sa=Za<<B;if((c[(f+12264|0)>>2]|0)>(Qa|0)){hc=536870912;break}if((Qa<<B|0)>(c[(f+12268|0)>>2]<<B|0)){hc=536870912;break}if((c[(f+12272|0)>>2]|0)>(Za|0)){hc=536870912;break}if((Sa|0)>(c[(f+12276|0)>>2]<<B|0)){hc=536870912;break}ac=e[(f+13872|0)>>1]|0;Xa=e[(f+13874|0)>>1]|0;n:do{if((c[(f+11740|0)>>2]|0)==1){if((Qa<<B|0)==0){Nb=0;while(1){Ob=c[f+12160+(Nb<<3)>>2]|0;Mb=(c[f+12160+(Nb<<3)+4>>2]|0)+Sa|0;Sb=((ca(c[f+12128+(Nb<<3)>>2]|0,Xa-ac|0)|0)/(ac|0)|0)+((Nb&1)<<ma)|0;Va=c[f+12128+(Nb<<3)+4>>2]|0;if((Sa|0)==0){Pb=Nb>>1;ic=((ca(Va,Xa-ac|0)|0)/(ac|0)|0)+(Pb<<ma)|0;jc=Pb}else{ic=Mb-Va|0;jc=Nb>>1}Va=((ic&O)<<B)+(Sb&O)|0;Pb=(c[(f+12208|0)>>2]|0)+((ca(jc,Ya<<3)|0)+(Nb<<3&8))|0;if(S){kc=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>1,Ya)|0)+(Ob>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(Ob&O)|0)<<2)>>2]&2047](Pb,kc,Ya,8);kc=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ic>>1,Ya)|0)+(Sb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Va<<2)>>2]&2047](Pb,kc,Ya,8)}else{kc=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>2,Ya)|0)+(Ob>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Ob&O)|0)<<2)>>2]&4095](Pb,kc,Ya);kc=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ic>>2,Ya)|0)+(Sb>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Va<<2)>>2]&4095](Pb,kc,Ya)}Nb=Nb+1|0;if((Nb|0)>=4){break n}}}if((Sa|0)==0){Nb=0;do{kc=(c[f+12160+(Nb<<3)>>2]|0)+(Qa<<B)|0;Pb=c[f+12160+(Nb<<3)+4>>2]|0;Va=kc-(c[f+12128+(Nb<<3)>>2]|0)|0;Sb=Nb>>1;Ob=((ca(c[f+12128+(Nb<<3)+4>>2]|0,Xa-ac|0)|0)/(ac|0)|0)+(Sb<<ma)|0;Mb=(c[(f+12208|0)>>2]|0)+((Nb<<3&8)+(ca(Sb,Ya<<3)|0))|0;if(S){Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>1,Ya)|0)+(kc>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Pb&O)<<B)+(kc&O)|0)<<2)>>2]&2047](Mb,Sb,Ya,8);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ob>>1,Ya)|0)+(Va>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&2047](Mb,Sb,Ya,8)}else{Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>2,Ya)|0)+(kc>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(kc&O)|0)<<2)>>2]&4095](Mb,Sb,Ya);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ob>>2,Ya)|0)+(Va>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095](Mb,Sb,Ya)}Nb=Nb+1|0;}while((Nb|0)<4)}else{Nb=0;do{Sb=(c[f+12160+(Nb<<3)>>2]|0)+(Qa<<B)|0;Mb=(c[f+12160+(Nb<<3)+4>>2]|0)+Sa|0;Va=Sb-(c[f+12128+(Nb<<3)>>2]|0)|0;Ob=Mb-(c[f+12128+(Nb<<3)+4>>2]|0)|0;kc=(c[(f+12208|0)>>2]|0)+((Nb<<3&8)+(ca(Nb>>1,Ya<<3)|0))|0;if(S){Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>1,Ya)|0)+(Sb>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Mb&O)<<B)+(Sb&O)|0)<<2)>>2]&2047](kc,Pb,Ya,8);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ob>>1,Ya)|0)+(Va>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&2047](kc,Pb,Ya,8)}else{Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Mb>>2,Ya)|0)+(Sb>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Mb&O)<<B)+(Sb&O)|0)<<2)>>2]&4095](kc,Pb,Ya);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ob>>2,Ya)|0)+(Va>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095](kc,Pb,Ya)}Nb=Nb+1|0;}while((Nb|0)<4)}}else{Nb=(c[(f+12160|0)>>2]|0)+(Qa<<B)|0;Pb=(c[(f+12164|0)>>2]|0)+Sa|0;kc=c[(f+12128|0)>>2]|0;if((Qa<<B|0)==0){lc=(ca(kc,Xa-ac|0)|0)/(ac|0)|0}else{lc=Nb-kc|0}kc=c[(f+12132|0)>>2]|0;if((Sa|0)==0){mc=(ca(kc,Xa-ac|0)|0)/(ac|0)|0}else{mc=Pb-kc|0}kc=((mc&O)<<B)+(lc&O)|0;if(S){Va=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Pb>>1,Ya)|0)+(Nb>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Va,Ya,16);Va=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(mc>>1,Ya)|0)+(lc>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(kc<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Va,Ya,16);break}else{Va=(ca(Pb>>2,Ya)|0)+(Nb>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Va|0,Ya);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Va+8|0)|0,Ya);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ya<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Va+(Ya<<3))|0,Ya);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Pb&O)<<B)+(Nb&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ya<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Va+8|0)+(Ya<<3))|0,Ya);Va=(ca(mc>>2,Ya)|0)+(lc>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Va|0,Ya);ef[c[(c[(f+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Va+8|0)|0,Ya);ef[c[(c[(f+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ya<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Va+(Ya<<3))|0,Ya);ef[c[(c[(f+12456|0)>>2]|0)+64+(kc<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ya<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Va+8|0)+(Ya<<3))|0,Ya);break}}}while(0);hc=Xe[ha&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Ya,16)|0}}while(0);c[(Y+(ab<<2)|0)>>2]=Lb;c[pa+(ab<<2)>>2]=hc;Ya=(ca((d[Z+((Za<<B)-X)|0]|0)+(d[Z+((Qa<<B)-Q)|0]|0)|0,C)|0)+hc|0;if((Ya|0)>=(Vb|0)){dc=Vb;ec=Wb;fc=Xb;gc=Yb;break}c[V>>2]=Qa;c[(V+4|0)>>2]=Za;dc=Ya;ec=2;fc=Qa;gc=Za}else{dc=Vb;ec=Wb;fc=Xb;gc=Yb}}while(0);if(!((Ra|0)!=1&(Za|0)<($|0))){break}Ya=Za+1|0;Ta=(Ya<<3)+Ga&63;if((c[(Y+(Ta<<2)|0)>>2]|0)==(ja+(Ya<<11)|0|0)){break}Wa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ac=c[(f+12420|0)>>2]|0;Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa,Ya)|0)+Ga)|0;Sa=Xe[ha&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Xa,Wa,o)|0;if((p&2|0)==0){nc=Sa;break}Xa=c[(f+12208|0)>>2]|0;Va=(ca(ac,Ya>>1)|0)+W|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ya<<1&2|Ea)<<2)>>2]&2047](Xa+(Wa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Va|0,ac,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((Ya<<1&2|Ea)<<2)>>2]&2047](Xa+(Wa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Va|0,ac,o>>1);Va=(Xe[oa&511](f,Xa+(Wa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ac,o>>1)|0)+Sa|0;nc=Va+(Xe[oa&511](f,Xa+(Wa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ac,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(Ga|0)){nc=536870912;break}if((La|0)>(c[(f+12268|0)>>2]<<B|0)){nc=536870912;break}if((c[(f+12272|0)>>2]|0)>(Ya|0)){nc=536870912;break}if((Ya<<B|0)>(c[(f+12276|0)>>2]<<B|0)){nc=536870912;break}ac=e[(f+13872|0)>>1]|0;Xa=e[(f+13874|0)>>1]|0;o:do{if((c[(f+11740|0)>>2]|0)==1){if((La|0)==0){Va=0;while(1){Sa=c[f+12160+(Va<<3)>>2]|0;kc=(c[f+12160+(Va<<3)+4>>2]|0)+(Ya<<B)|0;Nb=((ca(c[f+12128+(Va<<3)>>2]|0,Xa-ac|0)|0)/(ac|0)|0)+((Va&1)<<ma)|0;Pb=c[f+12128+(Va<<3)+4>>2]|0;if((Ya<<B|0)==0){Ob=Va>>1;oc=((ca(Pb,Xa-ac|0)|0)/(ac|0)|0)+(Ob<<ma)|0;pc=Ob}else{oc=kc-Pb|0;pc=Va>>1}Pb=((oc&O)<<B)+(Nb&O)|0;Ob=(c[(f+12208|0)>>2]|0)+((ca(pc,Wa<<3)|0)+(Va<<3&8))|0;if(S){Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(kc>>1,Wa)|0)+(Sa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((kc&O)<<B)+(Sa&O)|0)<<2)>>2]&2047](Ob,Sb,Wa,8);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(oc>>1,Wa)|0)+(Nb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Pb<<2)>>2]&2047](Ob,Sb,Wa,8)}else{Sb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(kc>>2,Wa)|0)+(Sa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((kc&O)<<B)+(Sa&O)|0)<<2)>>2]&4095](Ob,Sb,Wa);Sb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(oc>>2,Wa)|0)+(Nb>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Pb<<2)>>2]&4095](Ob,Sb,Wa)}Va=Va+1|0;if((Va|0)>=4){break o}}}if((Ya<<B|0)==0){Va=0;do{Sb=(c[f+12160+(Va<<3)>>2]|0)+La|0;Ob=c[f+12160+(Va<<3)+4>>2]|0;Pb=Sb-(c[f+12128+(Va<<3)>>2]|0)|0;Nb=Va>>1;Sa=((ca(c[f+12128+(Va<<3)+4>>2]|0,Xa-ac|0)|0)/(ac|0)|0)+(Nb<<ma)|0;kc=(c[(f+12208|0)>>2]|0)+((Va<<3&8)+(ca(Nb,Wa<<3)|0))|0;if(S){Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ob>>1,Wa)|0)+(Sb>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ob&O)<<B)+(Sb&O)|0)<<2)>>2]&2047](kc,Nb,Wa,8);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>1,Wa)|0)+(Pb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&O)<<B)+(Pb&O)|0)<<2)>>2]&2047](kc,Nb,Wa,8)}else{Nb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ob>>2,Wa)|0)+(Sb>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Sb&O)|0)<<2)>>2]&4095](kc,Nb,Wa);Nb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>2,Wa)|0)+(Pb>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&O)<<B)+(Pb&O)|0)<<2)>>2]&4095](kc,Nb,Wa)}Va=Va+1|0;}while((Va|0)<4)}else{Va=0;do{Nb=(c[f+12160+(Va<<3)>>2]|0)+La|0;kc=(c[f+12160+(Va<<3)+4>>2]|0)+(Ya<<B)|0;Pb=Nb-(c[f+12128+(Va<<3)>>2]|0)|0;Sa=kc-(c[f+12128+(Va<<3)+4>>2]|0)|0;Sb=(c[(f+12208|0)>>2]|0)+((Va<<3&8)+(ca(Va>>1,Wa<<3)|0))|0;if(S){Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(kc>>1,Wa)|0)+(Nb>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((kc&O)<<B)+(Nb&O)|0)<<2)>>2]&2047](Sb,Ob,Wa,8);Ob=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>1,Wa)|0)+(Pb>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Sa&O)<<B)+(Pb&O)|0)<<2)>>2]&2047](Sb,Ob,Wa,8)}else{Ob=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(kc>>2,Wa)|0)+(Nb>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((kc&O)<<B)+(Nb&O)|0)<<2)>>2]&4095](Sb,Ob,Wa);Ob=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sa>>2,Wa)|0)+(Pb>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Sa&O)<<B)+(Pb&O)|0)<<2)>>2]&4095](Sb,Ob,Wa)}Va=Va+1|0;}while((Va|0)<4)}}else{Va=(c[(f+12160|0)>>2]|0)+La|0;Ob=(c[(f+12164|0)>>2]|0)+(Ya<<B)|0;Sb=c[(f+12128|0)>>2]|0;if((La|0)==0){qc=(ca(Sb,Xa-ac|0)|0)/(ac|0)|0}else{qc=Va-Sb|0}Sb=c[(f+12132|0)>>2]|0;if((Ya<<B|0)==0){rc=(ca(Sb,Xa-ac|0)|0)/(ac|0)|0}else{rc=Ob-Sb|0}Sb=((rc&O)<<B)+(qc&O)|0;if(S){Pb=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ob>>1,Wa)|0)+(Va>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Pb,Wa,16);Pb=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(rc>>1,Wa)|0)+(qc>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(Sb<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Pb,Wa,16);break}else{Pb=(ca(Ob>>2,Wa)|0)+(Va>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Pb|0,Wa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Pb+8|0)|0,Wa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Wa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Pb+(Wa<<3))|0,Wa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ob&O)<<B)+(Va&O)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Wa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Pb+8|0)+(Wa<<3))|0,Wa);Pb=(ca(rc>>2,Wa)|0)+(qc>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Pb|0,Wa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Pb+8|0)|0,Wa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Wa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Pb+(Wa<<3))|0,Wa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Sb<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Wa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Pb+8|0)+(Wa<<3))|0,Wa);break}}}while(0);nc=Xe[ha&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Wa,16)|0}}while(0);c[(Y+(Ta<<2)|0)>>2]=ja+(Ya<<11)|0;c[pa+(Ta<<2)>>2]=nc;Wa=(ca((d[Z+((Ya<<B)-X)|0]|0)+(d[Z+(La-Q)|0]|0)|0,C)|0)+nc|0;if((Wa|0)>=(dc|0)){break}c[V>>2]=Ga;c[(V+4|0)>>2]=Ya;fa=Wa;Ra=3;Za=Ya}if((ec|0)==-1){Bb=dc;break e}else{za=dc;T=ec;Ga=fc;Fa=gc}}}if((U|0)>1024){Bb=urb(f,V,L,j,k,C,n,o,p)|0;break}if((U|0)>768){Fa=c[(f+12220|0)>>2]|0;Ga=c[(f+12264|0)>>2]|0;T=c[(f+12272|0)>>2]|0;za=c[(f+12268|0)>>2]|0;Q=c[(f+12276|0)>>2]|0;Z=c[(f+12464|0)>>2]|0;X=c[(f+12280|0)>>2]|0;pa=c[(f+12284|0)>>2]|0;Y=c[(f+12216|0)>>2]|0;ha=c[(f+12224|0)>>2]|0;O=c[f+10468+(n<<2)>>2]|0;S=c[f+10468+((n+1|0)<<2)>>2]|0;ma=M-(U&254)+1|0;oa=(ma|0)>(Ga|0)?ma:Ga;ma=M-1+(U&254)|0;$=(ma|0)>(za|0)?za:ma;if((oa|0)>($|0)){sc=L;tc=M;uc=N}else{ma=ha+(N<<11)|0;aa=N<<3;sa=N<<1&2;_=N>>1;la=N<<B;ia=(p&1)<<1|1;ga=oa;oa=L;Za=M;Ra=N;while(1){fa=ma+ga|0;La=ga+aa&63;do{if((c[(Y+(La<<2)|0)>>2]|0)==(fa|0)){vc=oa;wc=Za;xc=Ra}else{ja=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Ea=c[(f+12420|0)>>2]|0;W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja,N)|0)+ga)|0;Qa=Xe[O&511](f,c[(f+12288+(j<<4)|0)>>2]|0,W,ja,o)|0;if((p&2|0)==0){yc=Qa;break}W=ga&1|sa;Ma=c[(f+12208|0)>>2]|0;Aa=(ca(Ea,_)|0)+(ga>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(W<<2)>>2]&2047](Ma+(ja<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Aa|0,Ea,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(W<<2)>>2]&2047](Ma+(ja<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Aa|0,Ea,o>>1);Aa=(Xe[S&511](f,Ma+(ja<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Ea,o>>1)|0)+Qa|0;yc=Aa+(Xe[S&511](f,Ma+(ja<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Ea,o>>1)|0)|0}else{Ea=ga<<B;if((c[(f+12264|0)>>2]|0)>(ga|0)){yc=536870912;break}if((Ea|0)>(c[(f+12268|0)>>2]<<B|0)){yc=536870912;break}if((c[(f+12272|0)>>2]|0)>(N|0)){yc=536870912;break}if((la|0)>(c[(f+12276|0)>>2]<<B|0)){yc=536870912;break}Ma=e[(f+13872|0)>>1]|0;Aa=e[(f+13874|0)>>1]|0;p:do{if((c[(f+11740|0)>>2]|0)==1){if((Ea|0)==0){Qa=0;while(1){W=c[f+12160+(Qa<<3)>>2]|0;na=(c[f+12160+(Qa<<3)+4>>2]|0)+la|0;P=((ca(c[f+12128+(Qa<<3)>>2]|0,Aa-Ma|0)|0)/(Ma|0)|0)+((Qa&1)<<(p&1|4))|0;Wa=c[f+12128+(Qa<<3)+4>>2]|0;if((la|0)==0){ac=Qa>>1;zc=((ca(Wa,Aa-Ma|0)|0)/(Ma|0)|0)+(ac<<(p&1|4))|0;Ac=ac}else{zc=na-Wa|0;Ac=Qa>>1}Wa=((zc&ia)<<B)+(P&ia)|0;ac=(c[(f+12208|0)>>2]|0)+((ca(Ac,ja<<3)|0)+(Qa<<3&8))|0;if((p&1|0)==0){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>1,ja)|0)+(W>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((na&ia)<<B)+(W&ia)|0)<<2)>>2]&2047](ac,Xa,ja,8);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(zc>>1,ja)|0)+(P>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Wa<<2)>>2]&2047](ac,Xa,ja,8)}else{Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>2,ja)|0)+(W>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((na&ia)<<B)+(W&ia)|0)<<2)>>2]&4095](ac,Xa,ja);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(zc>>2,ja)|0)+(P>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Wa<<2)>>2]&4095](ac,Xa,ja)}Qa=Qa+1|0;if((Qa|0)>=4){break p}}}if((la|0)==0){Qa=0;do{Xa=(c[f+12160+(Qa<<3)>>2]|0)+Ea|0;ac=c[f+12160+(Qa<<3)+4>>2]|0;Wa=Xa-(c[f+12128+(Qa<<3)>>2]|0)|0;P=Qa>>1;W=((ca(c[f+12128+(Qa<<3)+4>>2]|0,Aa-Ma|0)|0)/(Ma|0)|0)+(P<<(p&1|4))|0;na=(c[(f+12208|0)>>2]|0)+((Qa<<3&8)+(ca(P,ja<<3)|0))|0;if((p&1|0)==0){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>1,ja)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ac&ia)<<B)+(Xa&ia)|0)<<2)>>2]&2047](na,P,ja,8);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(W>>1,ja)|0)+(Wa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((W&ia)<<B)+(Wa&ia)|0)<<2)>>2]&2047](na,P,ja,8)}else{P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>2,ja)|0)+(Xa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Xa&ia)|0)<<2)>>2]&4095](na,P,ja);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(W>>2,ja)|0)+(Wa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((W&ia)<<B)+(Wa&ia)|0)<<2)>>2]&4095](na,P,ja)}Qa=Qa+1|0;}while((Qa|0)<4)}else{Qa=0;do{P=(c[f+12160+(Qa<<3)>>2]|0)+Ea|0;na=(c[f+12160+(Qa<<3)+4>>2]|0)+la|0;Wa=P-(c[f+12128+(Qa<<3)>>2]|0)|0;W=na-(c[f+12128+(Qa<<3)+4>>2]|0)|0;Xa=(c[(f+12208|0)>>2]|0)+((Qa<<3&8)+(ca(Qa>>1,ja<<3)|0))|0;if((p&1|0)==0){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>1,ja)|0)+(P>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((na&ia)<<B)+(P&ia)|0)<<2)>>2]&2047](Xa,ac,ja,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(W>>1,ja)|0)+(Wa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((W&ia)<<B)+(Wa&ia)|0)<<2)>>2]&2047](Xa,ac,ja,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>2,ja)|0)+(P>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((na&ia)<<B)+(P&ia)|0)<<2)>>2]&4095](Xa,ac,ja);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(W>>2,ja)|0)+(Wa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((W&ia)<<B)+(Wa&ia)|0)<<2)>>2]&4095](Xa,ac,ja)}Qa=Qa+1|0;}while((Qa|0)<4)}}else{Qa=(c[(f+12160|0)>>2]|0)+Ea|0;ac=(c[(f+12164|0)>>2]|0)+la|0;Xa=c[(f+12128|0)>>2]|0;if((Ea|0)==0){Bc=(ca(Xa,Aa-Ma|0)|0)/(Ma|0)|0}else{Bc=Qa-Xa|0}Xa=c[(f+12132|0)>>2]|0;if((la|0)==0){Cc=(ca(Xa,Aa-Ma|0)|0)/(Ma|0)|0}else{Cc=ac-Xa|0}Xa=((Cc&ia)<<B)+(Bc&ia)|0;if((p&1|0)==0){Wa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>1,ja)|0)+(Qa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Wa,ja,16);Wa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Cc>>1,ja)|0)+(Bc>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(Xa<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Wa,ja,16);break}else{Wa=(ca(ac>>2,ja)|0)+(Qa>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Wa|0,ja);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Wa+8|0)|0,ja);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ja<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Wa+(ja<<3))|0,ja);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&ia)<<B)+(Qa&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Wa+8|0)+(ja<<3))|0,ja);Wa=(ca(Cc>>2,ja)|0)+(Bc>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Wa|0,ja);ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Wa+8|0)|0,ja);ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ja<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Wa+(ja<<3))|0,ja);ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Wa+8|0)+(ja<<3))|0,ja);break}}}while(0);yc=Xe[O&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ja,16)|0}}while(0);c[(Y+(La<<2)|0)>>2]=fa;c[Fa+(La<<2)>>2]=yc;ja=(ca((d[Z+(la-pa)|0]|0)+(d[Z+((ga<<B)-X)|0]|0)|0,C)|0)+yc|0;if((ja|0)>=(oa|0)){vc=oa;wc=Za;xc=Ra;break}c[V>>2]=ga;c[(V+4|0)>>2]=N;vc=ja;wc=ga;xc=N}}while(0);La=ga+2|0;if((La|0)>($|0)){sc=vc;tc=wc;uc=xc;break}else{ga=La;oa=vc;Za=wc;Ra=xc}}}Ra=N-((U&254)>>>1)+1|0;Za=(Ra|0)>(T|0)?Ra:T;Ra=N-1+((U&254)>>>1)|0;oa=(Ra|0)>(Q|0)?Q:Ra;if((Za|0)>(oa|0)){Dc=sc;Ec=tc;Fc=uc}else{Ra=ha+M|0;ga=M&1;$=M>>1;la=M<<B;ia=(p&1)<<1|1;_=Za;Za=sc;sa=tc;aa=uc;while(1){ma=Ra+(_<<11)|0;La=(_<<3)+M&63;do{if((c[(Y+(La<<2)|0)>>2]|0)==(ma|0)){Gc=Za;Hc=sa;Ic=aa}else{fa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ja=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(fa,_)|0)+M)|0;Ta=Xe[O&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,fa,o)|0;if((p&2|0)==0){Jc=Ta;break}Ya=_<<1&2|ga;Ma=c[(f+12208|0)>>2]|0;Aa=(ca(ja,_>>1)|0)+$|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Ya<<2)>>2]&2047](Ma+(fa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Aa|0,ja,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(Ya<<2)>>2]&2047](Ma+(fa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Aa|0,ja,o>>1);Aa=(Xe[S&511](f,Ma+(fa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ja,o>>1)|0)+Ta|0;Jc=Aa+(Xe[S&511](f,Ma+(fa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ja,o>>1)|0)|0}else{ja=_<<B;if((c[(f+12264|0)>>2]|0)>(M|0)){Jc=536870912;break}if((la|0)>(c[(f+12268|0)>>2]<<B|0)){Jc=536870912;break}if((c[(f+12272|0)>>2]|0)>(_|0)){Jc=536870912;break}if((ja|0)>(c[(f+12276|0)>>2]<<B|0)){Jc=536870912;break}Ma=e[(f+13872|0)>>1]|0;Aa=e[(f+13874|0)>>1]|0;q:do{if((c[(f+11740|0)>>2]|0)==1){if((la|0)==0){Ta=0;while(1){Ya=c[f+12160+(Ta<<3)>>2]|0;Ea=(c[f+12160+(Ta<<3)+4>>2]|0)+ja|0;Wa=((ca(c[f+12128+(Ta<<3)>>2]|0,Aa-Ma|0)|0)/(Ma|0)|0)+((Ta&1)<<(p&1|4))|0;Xa=c[f+12128+(Ta<<3)+4>>2]|0;if((ja|0)==0){Qa=Ta>>1;Kc=((ca(Xa,Aa-Ma|0)|0)/(Ma|0)|0)+(Qa<<(p&1|4))|0;Lc=Qa}else{Kc=Ea-Xa|0;Lc=Ta>>1}Xa=((Kc&ia)<<B)+(Wa&ia)|0;Qa=(c[(f+12208|0)>>2]|0)+((ca(Lc,fa<<3)|0)+(Ta<<3&8))|0;if((p&1|0)==0){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>1,fa)|0)+(Ya>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&ia)<<B)+(Ya&ia)|0)<<2)>>2]&2047](Qa,ac,fa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Kc>>1,fa)|0)+(Wa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Xa<<2)>>2]&2047](Qa,ac,fa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>2,fa)|0)+(Ya>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&ia)<<B)+(Ya&ia)|0)<<2)>>2]&4095](Qa,ac,fa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Kc>>2,fa)|0)+(Wa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](Qa,ac,fa)}Ta=Ta+1|0;if((Ta|0)>=4){break q}}}if((ja|0)==0){Ta=0;do{ac=(c[f+12160+(Ta<<3)>>2]|0)+la|0;Qa=c[f+12160+(Ta<<3)+4>>2]|0;Xa=ac-(c[f+12128+(Ta<<3)>>2]|0)|0;Wa=Ta>>1;Ya=((ca(c[f+12128+(Ta<<3)+4>>2]|0,Aa-Ma|0)|0)/(Ma|0)|0)+(Wa<<(p&1|4))|0;Ea=(c[(f+12208|0)>>2]|0)+((Ta<<3&8)+(ca(Wa,fa<<3)|0))|0;if((p&1|0)==0){Wa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa>>1,fa)|0)+(ac>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Qa&ia)<<B)+(ac&ia)|0)<<2)>>2]&2047](Ea,Wa,fa,8);Wa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ya>>1,fa)|0)+(Xa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ya&ia)<<B)+(Xa&ia)|0)<<2)>>2]&2047](Ea,Wa,fa,8)}else{Wa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa>>2,fa)|0)+(ac>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(ac&ia)|0)<<2)>>2]&4095](Ea,Wa,fa);Wa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ya>>2,fa)|0)+(Xa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ya&ia)<<B)+(Xa&ia)|0)<<2)>>2]&4095](Ea,Wa,fa)}Ta=Ta+1|0;}while((Ta|0)<4)}else{Ta=0;do{Wa=(c[f+12160+(Ta<<3)>>2]|0)+la|0;Ea=(c[f+12160+(Ta<<3)+4>>2]|0)+ja|0;Xa=Wa-(c[f+12128+(Ta<<3)>>2]|0)|0;Ya=Ea-(c[f+12128+(Ta<<3)+4>>2]|0)|0;ac=(c[(f+12208|0)>>2]|0)+((Ta<<3&8)+(ca(Ta>>1,fa<<3)|0))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>1,fa)|0)+(Wa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&ia)<<B)+(Wa&ia)|0)<<2)>>2]&2047](ac,Qa,fa,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ya>>1,fa)|0)+(Xa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ya&ia)<<B)+(Xa&ia)|0)<<2)>>2]&2047](ac,Qa,fa,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>2,fa)|0)+(Wa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&ia)<<B)+(Wa&ia)|0)<<2)>>2]&4095](ac,Qa,fa);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ya>>2,fa)|0)+(Xa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ya&ia)<<B)+(Xa&ia)|0)<<2)>>2]&4095](ac,Qa,fa)}Ta=Ta+1|0;}while((Ta|0)<4)}}else{Ta=(c[(f+12160|0)>>2]|0)+la|0;Qa=(c[(f+12164|0)>>2]|0)+ja|0;ac=c[(f+12128|0)>>2]|0;if((la|0)==0){Mc=(ca(ac,Aa-Ma|0)|0)/(Ma|0)|0}else{Mc=Ta-ac|0}ac=c[(f+12132|0)>>2]|0;if((ja|0)==0){Nc=(ca(ac,Aa-Ma|0)|0)/(Ma|0)|0}else{Nc=Qa-ac|0}ac=((Nc&ia)<<B)+(Mc&ia)|0;if((p&1|0)==0){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa>>1,fa)|0)+(Ta>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Xa,fa,16);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Nc>>1,fa)|0)+(Mc>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(ac<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Xa,fa,16);break}else{Xa=(ca(Qa>>2,fa)|0)+(Ta>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Xa|0,fa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+8|0)|0,fa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(fa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+(fa<<3))|0,fa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&ia)<<B)+(Ta&ia)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((fa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Xa+8|0)+(fa<<3))|0,fa);Xa=(ca(Nc>>2,fa)|0)+(Mc>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Xa|0,fa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+8|0)|0,fa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(fa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+(fa<<3))|0,fa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((fa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Xa+8|0)+(fa<<3))|0,fa);break}}}while(0);Jc=Xe[O&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,fa,16)|0}}while(0);c[(Y+(La<<2)|0)>>2]=ma;c[Fa+(La<<2)>>2]=Jc;fa=(ca((d[Z+((_<<B)-pa)|0]|0)+(d[Z+(la-X)|0]|0)|0,C)|0)+Jc|0;if((fa|0)>=(Za|0)){Gc=Za;Hc=sa;Ic=aa;break}c[V>>2]=M;c[(V+4|0)>>2]=_;Gc=fa;Hc=M;Ic=_}}while(0);La=_+2|0;if((La|0)>(oa|0)){Dc=Gc;Ec=Hc;Fc=Ic;break}else{_=La;Za=Gc;sa=Hc;aa=Ic}}}aa=Fc-2|0;sa=(aa|0)>(T|0)?aa:T;aa=Fc+2|0;Za=(aa|0)>(Q|0)?Q:aa;if((sa|0)>(Za|0)){Oc=Dc}else{aa=Ec-2|0;_=(aa|0)>(Ga|0)?aa:Ga;aa=Ec+2|0;oa=(aa|0)>(za|0)?za:aa;aa=(p&1)<<1|1;la=sa;sa=Dc;while(1){if((_|0)>(oa|0)){Pc=sa}else{ia=(la<<11)+ha|0;$=la<<3;ga=la<<1&2;Ra=la>>1;La=la<<B;ma=_;fa=sa;while(1){Ma=ia+ma|0;Aa=ma+$&63;do{if((c[(Y+(Aa<<2)|0)>>2]|0)==(Ma|0)){Qc=fa}else{ja=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Xa=c[(f+12420|0)>>2]|0;ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja,la)|0)+ma)|0;Ta=Xe[O&511](f,c[(f+12288+(j<<4)|0)>>2]|0,ac,ja,o)|0;if((p&2|0)==0){Rc=Ta;break}ac=ma&1|ga;Qa=c[(f+12208|0)>>2]|0;Ya=(ca(Xa,Ra)|0)+(ma>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(ac<<2)>>2]&2047](Qa+(ja<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Ya|0,Xa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+(ac<<2)>>2]&2047](Qa+(ja<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Ya|0,Xa,o>>1);Ya=(Xe[S&511](f,Qa+(ja<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Xa,o>>1)|0)+Ta|0;Rc=Ya+(Xe[S&511](f,Qa+(ja<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Xa,o>>1)|0)|0}else{Xa=ma<<B;if((c[(f+12264|0)>>2]|0)>(ma|0)){Rc=536870912;break}if((Xa|0)>(c[(f+12268|0)>>2]<<B|0)){Rc=536870912;break}if((c[(f+12272|0)>>2]|0)>(la|0)){Rc=536870912;break}if((La|0)>(c[(f+12276|0)>>2]<<B|0)){Rc=536870912;break}Qa=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;r:do{if((c[(f+11740|0)>>2]|0)==1){if((Xa|0)==0){Ta=0;while(1){ac=c[f+12160+(Ta<<3)>>2]|0;Wa=(c[f+12160+(Ta<<3)+4>>2]|0)+La|0;Ea=((ca(c[f+12128+(Ta<<3)>>2]|0,Ya-Qa|0)|0)/(Qa|0)|0)+((Ta&1)<<(p&1|4))|0;W=c[f+12128+(Ta<<3)+4>>2]|0;if((La|0)==0){P=Ta>>1;Sc=((ca(W,Ya-Qa|0)|0)/(Qa|0)|0)+(P<<(p&1|4))|0;Tc=P}else{Sc=Wa-W|0;Tc=Ta>>1}W=((Sc&aa)<<B)+(Ea&aa)|0;P=(c[(f+12208|0)>>2]|0)+((ca(Tc,ja<<3)|0)+(Ta<<3&8))|0;if((p&1|0)==0){na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa>>1,ja)|0)+(ac>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Wa&aa)<<B)+(ac&aa)|0)<<2)>>2]&2047](P,na,ja,8);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sc>>1,ja)|0)+(Ea>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(W<<2)>>2]&2047](P,na,ja,8)}else{na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa>>2,ja)|0)+(ac>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Wa&aa)<<B)+(ac&aa)|0)<<2)>>2]&4095](P,na,ja);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Sc>>2,ja)|0)+(Ea>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](P,na,ja)}Ta=Ta+1|0;if((Ta|0)>=4){break r}}}if((La|0)==0){Ta=0;do{na=(c[f+12160+(Ta<<3)>>2]|0)+Xa|0;P=c[f+12160+(Ta<<3)+4>>2]|0;W=na-(c[f+12128+(Ta<<3)>>2]|0)|0;Ea=Ta>>1;ac=((ca(c[f+12128+(Ta<<3)+4>>2]|0,Ya-Qa|0)|0)/(Qa|0)|0)+(Ea<<(p&1|4))|0;Wa=(c[(f+12208|0)>>2]|0)+((Ta<<3&8)+(ca(Ea,ja<<3)|0))|0;if((p&1|0)==0){Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(P>>1,ja)|0)+(na>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((P&aa)<<B)+(na&aa)|0)<<2)>>2]&2047](Wa,Ea,ja,8);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ac>>1,ja)|0)+(W>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ac&aa)<<B)+(W&aa)|0)<<2)>>2]&2047](Wa,Ea,ja,8)}else{Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(P>>2,ja)|0)+(na>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(na&aa)|0)<<2)>>2]&4095](Wa,Ea,ja);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ac>>2,ja)|0)+(W>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ac&aa)<<B)+(W&aa)|0)<<2)>>2]&4095](Wa,Ea,ja)}Ta=Ta+1|0;}while((Ta|0)<4)}else{Ta=0;do{Ea=(c[f+12160+(Ta<<3)>>2]|0)+Xa|0;Wa=(c[f+12160+(Ta<<3)+4>>2]|0)+La|0;W=Ea-(c[f+12128+(Ta<<3)>>2]|0)|0;ac=Wa-(c[f+12128+(Ta<<3)+4>>2]|0)|0;na=(c[(f+12208|0)>>2]|0)+((Ta<<3&8)+(ca(Ta>>1,ja<<3)|0))|0;if((p&1|0)==0){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa>>1,ja)|0)+(Ea>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Wa&aa)<<B)+(Ea&aa)|0)<<2)>>2]&2047](na,P,ja,8);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ac>>1,ja)|0)+(W>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ac&aa)<<B)+(W&aa)|0)<<2)>>2]&2047](na,P,ja,8)}else{P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Wa>>2,ja)|0)+(Ea>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Wa&aa)<<B)+(Ea&aa)|0)<<2)>>2]&4095](na,P,ja);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ac>>2,ja)|0)+(W>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ac&aa)<<B)+(W&aa)|0)<<2)>>2]&4095](na,P,ja)}Ta=Ta+1|0;}while((Ta|0)<4)}}else{Ta=(c[(f+12160|0)>>2]|0)+Xa|0;P=(c[(f+12164|0)>>2]|0)+La|0;na=c[(f+12128|0)>>2]|0;if((Xa|0)==0){Uc=(ca(na,Ya-Qa|0)|0)/(Qa|0)|0}else{Uc=Ta-na|0}na=c[(f+12132|0)>>2]|0;if((La|0)==0){Vc=(ca(na,Ya-Qa|0)|0)/(Qa|0)|0}else{Vc=P-na|0}na=((Vc&aa)<<B)+(Uc&aa)|0;if((p&1|0)==0){W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(P>>1,ja)|0)+(Ta>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,W,ja,16);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Vc>>1,ja)|0)+(Uc>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(na<<2)>>2]&2047](c[(f+12208|0)>>2]|0,W,ja,16);break}else{W=(ca(P>>2,ja)|0)+(Ta>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+W|0,ja);ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(W+8|0)|0,ja);ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ja<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(W+(ja<<3))|0,ja);ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&aa)<<B)+(Ta&aa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((W+8|0)+(ja<<3))|0,ja);W=(ca(Vc>>2,ja)|0)+(Uc>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+W|0,ja);ef[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(W+8|0)|0,ja);ef[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ja<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(W+(ja<<3))|0,ja);ef[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((W+8|0)+(ja<<3))|0,ja);break}}}while(0);Rc=Xe[O&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ja,16)|0}}while(0);c[(Y+(Aa<<2)|0)>>2]=Ma;c[Fa+(Aa<<2)>>2]=Rc;ja=(ca((d[Z+(La-pa)|0]|0)+(d[Z+((ma<<B)-X)|0]|0)|0,C)|0)+Rc|0;if((ja|0)>=(fa|0)){Qc=fa;break}c[V>>2]=ma;c[(V+4|0)>>2]=la;Qc=ja}}while(0);Aa=ma+1|0;if((Aa|0)>(oa|0)){Pc=Qc;break}else{ma=Aa;fa=Qc}}}fa=la+1|0;if((fa|0)>(Za|0)){Oc=Pc;break}else{la=fa;sa=Pc}}}if(((U&254)>>>2|0)==0){Wc=Oc}else{sa=(p&1)<<1|1;la=1;Za=Oc;while(1){oa=0;aa=Za;while(1){_=(ca(c[284520+(oa<<3)>>2]|0,la)|0)+Ec|0;fa=(ca(c[284524+(oa<<3)>>2]|0,la)|0)+Fc|0;ma=(_|0)>(za|0)?za:_;_=(Ga|0)>(ma|0)?Ga:ma;ma=(fa|0)>(Q|0)?Q:fa;fa=(T|0)>(ma|0)?T:ma;do{if((c[(Y+(((fa<<3)+_&63)<<2)|0)>>2]|0)==(_+ha+(fa<<11)|0|0)){Xc=aa}else{ma=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){La=c[(f+12420|0)>>2]|0;Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ma,fa)|0)+_)|0;ga=Xe[O&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ra,ma,o)|0;if((p&2|0)==0){Yc=ga;break}Ra=c[(f+12208|0)>>2]|0;$=(ca(La,fa>>1)|0)+(_>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((fa<<1&2|_&1)<<2)>>2]&2047](Ra+(ma<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+$|0,La,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((fa<<1&2|_&1)<<2)>>2]&2047](Ra+(ma<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+$|0,La,o>>1);$=(Xe[S&511](f,Ra+(ma<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,La,o>>1)|0)+ga|0;Yc=$+(Xe[S&511](f,Ra+(ma<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,La,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(_|0)){Yc=536870912;break}if((_<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Yc=536870912;break}if((c[(f+12272|0)>>2]|0)>(fa|0)){Yc=536870912;break}if((fa<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Yc=536870912;break}La=e[(f+13872|0)>>1]|0;Ra=e[(f+13874|0)>>1]|0;s:do{if((c[(f+11740|0)>>2]|0)==1){if((_<<B|0)==0){$=0;while(1){ga=c[f+12160+($<<3)>>2]|0;ia=(c[f+12160+($<<3)+4>>2]|0)+(fa<<B)|0;Aa=((ca(c[f+12128+($<<3)>>2]|0,Ra-La|0)|0)/(La|0)|0)+(($&1)<<(p&1|4))|0;Ma=c[f+12128+($<<3)+4>>2]|0;if((fa<<B|0)==0){ja=$>>1;Zc=((ca(Ma,Ra-La|0)|0)/(La|0)|0)+(ja<<(p&1|4))|0;_c=ja}else{Zc=ia-Ma|0;_c=$>>1}Ma=((Zc&sa)<<B)+(Aa&sa)|0;ja=(c[(f+12208|0)>>2]|0)+((ca(_c,ma<<3)|0)+($<<3&8))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ia>>1,ma)|0)+(ga>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ia&sa)<<B)+(ga&sa)|0)<<2)>>2]&2047](ja,Qa,ma,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Zc>>1,ma)|0)+(Aa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Ma<<2)>>2]&2047](ja,Qa,ma,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ia>>2,ma)|0)+(ga>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ia&sa)<<B)+(ga&sa)|0)<<2)>>2]&4095](ja,Qa,ma);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Zc>>2,ma)|0)+(Aa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ma<<2)>>2]&4095](ja,Qa,ma)}$=$+1|0;if(($|0)>=4){break s}}}if((fa<<B|0)==0){$=0;do{Qa=(c[f+12160+($<<3)>>2]|0)+(_<<B)|0;ja=c[f+12160+($<<3)+4>>2]|0;Ma=Qa-(c[f+12128+($<<3)>>2]|0)|0;Aa=$>>1;ga=((ca(c[f+12128+($<<3)+4>>2]|0,Ra-La|0)|0)/(La|0)|0)+(Aa<<(p&1|4))|0;ia=(c[(f+12208|0)>>2]|0)+(($<<3&8)+(ca(Aa,ma<<3)|0))|0;if((p&1|0)==0){Aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>1,ma)|0)+(Qa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ja&sa)<<B)+(Qa&sa)|0)<<2)>>2]&2047](ia,Aa,ma,8);Aa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>1,ma)|0)+(Ma>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&sa)<<B)+(Ma&sa)|0)<<2)>>2]&2047](ia,Aa,ma,8)}else{Aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>2,ma)|0)+(Qa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+(Qa&sa)|0)<<2)>>2]&4095](ia,Aa,ma);Aa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>2,ma)|0)+(Ma>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ga&sa)<<B)+(Ma&sa)|0)<<2)>>2]&4095](ia,Aa,ma)}$=$+1|0;}while(($|0)<4)}else{$=0;do{Aa=(c[f+12160+($<<3)>>2]|0)+(_<<B)|0;ia=(c[f+12160+($<<3)+4>>2]|0)+(fa<<B)|0;Ma=Aa-(c[f+12128+($<<3)>>2]|0)|0;ga=ia-(c[f+12128+($<<3)+4>>2]|0)|0;Qa=(c[(f+12208|0)>>2]|0)+(($<<3&8)+(ca($>>1,ma<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ia>>1,ma)|0)+(Aa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ia&sa)<<B)+(Aa&sa)|0)<<2)>>2]&2047](Qa,ja,ma,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>1,ma)|0)+(Ma>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&sa)<<B)+(Ma&sa)|0)<<2)>>2]&2047](Qa,ja,ma,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ia>>2,ma)|0)+(Aa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ia&sa)<<B)+(Aa&sa)|0)<<2)>>2]&4095](Qa,ja,ma);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>2,ma)|0)+(Ma>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ga&sa)<<B)+(Ma&sa)|0)<<2)>>2]&4095](Qa,ja,ma)}$=$+1|0;}while(($|0)<4)}}else{$=(c[(f+12160|0)>>2]|0)+(_<<B)|0;ja=(c[(f+12164|0)>>2]|0)+(fa<<B)|0;Qa=c[(f+12128|0)>>2]|0;if((_<<B|0)==0){$c=(ca(Qa,Ra-La|0)|0)/(La|0)|0}else{$c=$-Qa|0}Qa=c[(f+12132|0)>>2]|0;if((fa<<B|0)==0){ad=(ca(Qa,Ra-La|0)|0)/(La|0)|0}else{ad=ja-Qa|0}Qa=((ad&sa)<<B)+($c&sa)|0;if((p&1|0)==0){Ma=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>1,ma)|0)+($>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ma,ma,16);Ma=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ad>>1,ma)|0)+($c>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(Qa<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ma,ma,16);break}else{Ma=(ca(ja>>2,ma)|0)+($>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ma|0,ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ma+8|0)|0,ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ma<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ma+(ma<<3))|0,ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&sa)<<B)+($&sa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ma+8|0)+(ma<<3))|0,ma);Ma=(ca(ad>>2,ma)|0)+($c>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Qa<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ma|0,ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Qa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ma+8|0)|0,ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Qa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ma<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ma+(ma<<3))|0,ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Qa<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ma+8|0)+(ma<<3))|0,ma);break}}}while(0);Yc=Xe[O&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(Y+(((fa<<3)+_&63)<<2)|0)>>2]=_+ha+(fa<<11)|0;c[Fa+(((fa<<3)+_&63)<<2)>>2]=Yc;ma=(ca((d[Z+((fa<<B)-pa)|0]|0)+(d[Z+((_<<B)-X)|0]|0)|0,C)|0)+Yc|0;if((ma|0)>=(aa|0)){Xc=aa;break}c[V>>2]=_;c[(V+4|0)>>2]=fa;Xc=ma}}while(0);fa=oa+1|0;if((fa|0)<16){oa=fa;aa=Xc}else{break}}aa=la+1|0;if((aa|0)>((U&254)>>>2|0)){Wc=Xc;break}else{la=aa;Za=Xc}}}Bb=vrb(f,V,Wc,j,k,C,n,o,p,2)|0;break}if((U|0)>512){Bb=vrb(f,V,L,j,k,C,n,o,p,U&255)|0;break}Za=c[(f+12220|0)>>2]|0;la=c[(f+12264|0)>>2]|0;X=c[(f+12272|0)>>2]|0;Z=c[(f+12268|0)>>2]|0;pa=c[(f+12276|0)>>2]|0;Fa=c[(f+12464|0)>>2]|0;ha=c[(f+12280|0)>>2]|0;Y=c[(f+12284|0)>>2]|0;O=c[(f+12216|0)>>2]|0;sa=c[(f+12224|0)>>2]|0;if((U|0)<=256){S=c[f+10468+(n<<2)>>2]|0;T=c[f+10468+((n+1|0)<<2)>>2]|0;Q=(p&1)<<1|1;Ga=p&1|4;za=(p&1|0)==0;aa=1;oa=L;fa=M;_=N;while(1){ma=aa+_|0;La=(ma-pa|0|0)<0?0:ma-pa|0;Ra=Z-fa+1|0;Ma=(aa|0)>(Ra|0)?Ra:aa;if((La|0)<(Ma|0)){Ra=La;La=oa;Qa=_;$=fa;while(1){ja=ma-Ra|0;ga=Ra+fa|0;do{if((c[(O+(((ja<<3)+ga&63)<<2)|0)>>2]|0)==(ga+sa+(ja<<11)|0|0)){bd=La;cd=Qa;dd=$}else{Aa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ia=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Aa,ja)|0)+ga)|0;Xa=Xe[S&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,Aa,o)|0;if((p&2|0)==0){ed=Xa;break}Ya=c[(f+12208|0)>>2]|0;W=(ca(ia,ja>>1)|0)+(ga>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|ga&1)<<2)>>2]&2047](Ya+(Aa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+W|0,ia,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|ga&1)<<2)>>2]&2047](Ya+(Aa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+W|0,ia,o>>1);W=(Xe[T&511](f,Ya+(Aa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ia,o>>1)|0)+Xa|0;ed=W+(Xe[T&511](f,Ya+(Aa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ia,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(ga|0)){ed=536870912;break}if((ga<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ed=536870912;break}if((c[(f+12272|0)>>2]|0)>(ja|0)){ed=536870912;break}if((ja<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ed=536870912;break}ia=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;t:do{if((c[(f+11740|0)>>2]|0)==1){if((ga<<B|0)==0){W=0;while(1){Xa=c[f+12160+(W<<3)>>2]|0;na=(c[f+12160+(W<<3)+4>>2]|0)+(ja<<B)|0;Ta=((ca(c[f+12128+(W<<3)>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+((W&1)<<Ga)|0;P=c[f+12128+(W<<3)+4>>2]|0;if((ja<<B|0)==0){ac=W>>1;fd=((ca(P,Ya-ia|0)|0)/(ia|0)|0)+(ac<<Ga)|0;gd=ac}else{fd=na-P|0;gd=W>>1}P=((fd&Q)<<B)+(Ta&Q)|0;ac=(c[(f+12208|0)>>2]|0)+((ca(gd,Aa<<3)|0)+(W<<3&8))|0;if(za){Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>1,Aa)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((na&Q)<<B)+(Xa&Q)|0)<<2)>>2]&2047](ac,Ea,Aa,8);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(fd>>1,Aa)|0)+(Ta>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(P<<2)>>2]&2047](ac,Ea,Aa,8)}else{Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>2,Aa)|0)+(Xa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((na&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](ac,Ea,Aa);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(fd>>2,Aa)|0)+(Ta>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(P<<2)>>2]&4095](ac,Ea,Aa)}W=W+1|0;if((W|0)>=4){break t}}}if((ja<<B|0)==0){W=0;do{Ea=(c[f+12160+(W<<3)>>2]|0)+(ga<<B)|0;ac=c[f+12160+(W<<3)+4>>2]|0;P=Ea-(c[f+12128+(W<<3)>>2]|0)|0;Ta=W>>1;Xa=((ca(c[f+12128+(W<<3)+4>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+(Ta<<Ga)|0;na=(c[(f+12208|0)>>2]|0)+((W<<3&8)+(ca(Ta,Aa<<3)|0))|0;if(za){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>1,Aa)|0)+(Ea>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ac&Q)<<B)+(Ea&Q)|0)<<2)>>2]&2047](na,Ta,Aa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Xa>>1,Aa)|0)+(P>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&2047](na,Ta,Aa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>2,Aa)|0)+(Ea>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095](na,Ta,Aa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Xa>>2,Aa)|0)+(P>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](na,Ta,Aa)}W=W+1|0;}while((W|0)<4)}else{W=0;do{Ta=(c[f+12160+(W<<3)>>2]|0)+(ga<<B)|0;na=(c[f+12160+(W<<3)+4>>2]|0)+(ja<<B)|0;P=Ta-(c[f+12128+(W<<3)>>2]|0)|0;Xa=na-(c[f+12128+(W<<3)+4>>2]|0)|0;Ea=(c[(f+12208|0)>>2]|0)+((W<<3&8)+(ca(W>>1,Aa<<3)|0))|0;if(za){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>1,Aa)|0)+(Ta>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((na&Q)<<B)+(Ta&Q)|0)<<2)>>2]&2047](Ea,ac,Aa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Xa>>1,Aa)|0)+(P>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&2047](Ea,ac,Aa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>2,Aa)|0)+(Ta>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((na&Q)<<B)+(Ta&Q)|0)<<2)>>2]&4095](Ea,ac,Aa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Xa>>2,Aa)|0)+(P>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](Ea,ac,Aa)}W=W+1|0;}while((W|0)<4)}}else{W=(c[(f+12160|0)>>2]|0)+(ga<<B)|0;ac=(c[(f+12164|0)>>2]|0)+(ja<<B)|0;Ea=c[(f+12128|0)>>2]|0;if((ga<<B|0)==0){hd=(ca(Ea,Ya-ia|0)|0)/(ia|0)|0}else{hd=W-Ea|0}Ea=c[(f+12132|0)>>2]|0;if((ja<<B|0)==0){id=(ca(Ea,Ya-ia|0)|0)/(ia|0)|0}else{id=ac-Ea|0}Ea=((id&Q)<<B)+(hd&Q)|0;if(za){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>1,Aa)|0)+(W>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,P,Aa,16);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(id>>1,Aa)|0)+(hd>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(Ea<<2)>>2]&2047](c[(f+12208|0)>>2]|0,P,Aa,16);break}else{P=(ca(ac>>2,Aa)|0)+(W>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+P|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(P+8|0)|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(P+(Aa<<3))|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((P+8|0)+(Aa<<3))|0,Aa);P=(ca(id>>2,Aa)|0)+(hd>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+P|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(P+8|0)|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(P+(Aa<<3))|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((P+8|0)+(Aa<<3))|0,Aa);break}}}while(0);ed=Xe[S&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Aa,16)|0}}while(0);c[(O+(((ja<<3)+ga&63)<<2)|0)>>2]=ga+sa+(ja<<11)|0;c[Za+(((ja<<3)+ga&63)<<2)>>2]=ed;Aa=(ca((d[Fa+((ja<<B)-Y)|0]|0)+(d[Fa+((ga<<B)-ha)|0]|0)|0,C)|0)+ed|0;if((Aa|0)>=(La|0)){bd=La;cd=Qa;dd=$;break}c[V>>2]=ga;c[(V+4|0)>>2]=ja;bd=Aa;cd=ja;dd=ga}}while(0);ga=Ra+1|0;if((ga|0)<(Ma|0)){Ra=ga;La=bd;Qa=cd;$=dd}else{jd=bd;kd=cd;ld=dd;break}}}else{jd=oa;kd=_;ld=fa}$=aa+fa|0;Qa=($-Z|0|0)<0?0:$-Z|0;La=_-X+1|0;Ra=(aa|0)>(La|0)?La:aa;if((Qa|0)<(Ra|0)){La=Qa;Qa=jd;Ma=kd;ma=ld;while(1){ga=_-La|0;ja=$-La|0;do{if((c[(O+(((ga<<3)+ja&63)<<2)|0)>>2]|0)==(ja+sa+(ga<<11)|0|0)){md=Qa;nd=Ma;od=ma}else{Aa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ia=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Aa,ga)|0)+ja)|0;P=Xe[S&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,Aa,o)|0;if((p&2|0)==0){pd=P;break}Ya=c[(f+12208|0)>>2]|0;Ea=(ca(ia,ga>>1)|0)+(ja>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ga<<1&2|ja&1)<<2)>>2]&2047](Ya+(Aa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Ea|0,ia,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ga<<1&2|ja&1)<<2)>>2]&2047](Ya+(Aa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Ea|0,ia,o>>1);Ea=(Xe[T&511](f,Ya+(Aa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ia,o>>1)|0)+P|0;pd=Ea+(Xe[T&511](f,Ya+(Aa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ia,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(ja|0)){pd=536870912;break}if((ja<<B|0)>(c[(f+12268|0)>>2]<<B|0)){pd=536870912;break}if((c[(f+12272|0)>>2]|0)>(ga|0)){pd=536870912;break}if((ga<<B|0)>(c[(f+12276|0)>>2]<<B|0)){pd=536870912;break}ia=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;u:do{if((c[(f+11740|0)>>2]|0)==1){if((ja<<B|0)==0){Ea=0;while(1){P=c[f+12160+(Ea<<3)>>2]|0;W=(c[f+12160+(Ea<<3)+4>>2]|0)+(ga<<B)|0;ac=((ca(c[f+12128+(Ea<<3)>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+((Ea&1)<<Ga)|0;Xa=c[f+12128+(Ea<<3)+4>>2]|0;if((ga<<B|0)==0){Ta=Ea>>1;qd=((ca(Xa,Ya-ia|0)|0)/(ia|0)|0)+(Ta<<Ga)|0;rd=Ta}else{qd=W-Xa|0;rd=Ea>>1}Xa=((qd&Q)<<B)+(ac&Q)|0;Ta=(c[(f+12208|0)>>2]|0)+((ca(rd,Aa<<3)|0)+(Ea<<3&8))|0;if(za){na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(W>>1,Aa)|0)+(P>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((W&Q)<<B)+(P&Q)|0)<<2)>>2]&2047](Ta,na,Aa,8);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(qd>>1,Aa)|0)+(ac>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Xa<<2)>>2]&2047](Ta,na,Aa,8)}else{na=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(W>>2,Aa)|0)+(P>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((W&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](Ta,na,Aa);na=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(qd>>2,Aa)|0)+(ac>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](Ta,na,Aa)}Ea=Ea+1|0;if((Ea|0)>=4){break u}}}if((ga<<B|0)==0){Ea=0;do{na=(c[f+12160+(Ea<<3)>>2]|0)+(ja<<B)|0;Ta=c[f+12160+(Ea<<3)+4>>2]|0;Xa=na-(c[f+12128+(Ea<<3)>>2]|0)|0;ac=Ea>>1;P=((ca(c[f+12128+(Ea<<3)+4>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+(ac<<Ga)|0;W=(c[(f+12208|0)>>2]|0)+((Ea<<3&8)+(ca(ac,Aa<<3)|0))|0;if(za){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>1,Aa)|0)+(na>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ta&Q)<<B)+(na&Q)|0)<<2)>>2]&2047](W,ac,Aa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(P>>1,Aa)|0)+(Xa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&2047](W,ac,Aa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>2,Aa)|0)+(na>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(na&Q)|0)<<2)>>2]&4095](W,ac,Aa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(P>>2,Aa)|0)+(Xa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](W,ac,Aa)}Ea=Ea+1|0;}while((Ea|0)<4)}else{Ea=0;do{ac=(c[f+12160+(Ea<<3)>>2]|0)+(ja<<B)|0;W=(c[f+12160+(Ea<<3)+4>>2]|0)+(ga<<B)|0;Xa=ac-(c[f+12128+(Ea<<3)>>2]|0)|0;P=W-(c[f+12128+(Ea<<3)+4>>2]|0)|0;na=(c[(f+12208|0)>>2]|0)+((Ea<<3&8)+(ca(Ea>>1,Aa<<3)|0))|0;if(za){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(W>>1,Aa)|0)+(ac>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((W&Q)<<B)+(ac&Q)|0)<<2)>>2]&2047](na,Ta,Aa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(P>>1,Aa)|0)+(Xa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&2047](na,Ta,Aa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(W>>2,Aa)|0)+(ac>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((W&Q)<<B)+(ac&Q)|0)<<2)>>2]&4095](na,Ta,Aa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(P>>2,Aa)|0)+(Xa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](na,Ta,Aa)}Ea=Ea+1|0;}while((Ea|0)<4)}}else{Ea=(c[(f+12160|0)>>2]|0)+(ja<<B)|0;Ta=(c[(f+12164|0)>>2]|0)+(ga<<B)|0;na=c[(f+12128|0)>>2]|0;if((ja<<B|0)==0){sd=(ca(na,Ya-ia|0)|0)/(ia|0)|0}else{sd=Ea-na|0}na=c[(f+12132|0)>>2]|0;if((ga<<B|0)==0){td=(ca(na,Ya-ia|0)|0)/(ia|0)|0}else{td=Ta-na|0}na=((td&Q)<<B)+(sd&Q)|0;if(za){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>1,Aa)|0)+(Ea>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Xa,Aa,16);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(td>>1,Aa)|0)+(sd>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(na<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Xa,Aa,16);break}else{Xa=(ca(Ta>>2,Aa)|0)+(Ea>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Xa|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+8|0)|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+(Aa<<3))|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Xa+8|0)+(Aa<<3))|0,Aa);Xa=(ca(td>>2,Aa)|0)+(sd>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Xa|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+8|0)|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+(Aa<<3))|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Xa+8|0)+(Aa<<3))|0,Aa);break}}}while(0);pd=Xe[S&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Aa,16)|0}}while(0);c[(O+(((ga<<3)+ja&63)<<2)|0)>>2]=ja+sa+(ga<<11)|0;c[Za+(((ga<<3)+ja&63)<<2)>>2]=pd;Aa=(ca((d[Fa+((ga<<B)-Y)|0]|0)+(d[Fa+((ja<<B)-ha)|0]|0)|0,C)|0)+pd|0;if((Aa|0)>=(Qa|0)){md=Qa;nd=Ma;od=ma;break}c[V>>2]=ja;c[(V+4|0)>>2]=ga;md=Aa;nd=ga;od=ja}}while(0);ja=La+1|0;if((ja|0)<(Ra|0)){La=ja;Qa=md;Ma=nd;ma=od}else{ud=md;vd=nd;wd=od;break}}}else{ud=jd;vd=kd;wd=ld}ma=aa-_+X|0;Ma=(ma|0)<0?0:ma;ma=fa-la+1|0;Qa=(aa|0)>(ma|0)?ma:aa;if((Ma|0)<(Qa|0)){ma=_-aa|0;La=Ma;Ma=ud;Ra=vd;$=wd;while(1){ja=La+ma|0;ga=fa-La|0;do{if((c[(O+(((ja<<3)+ga&63)<<2)|0)>>2]|0)==(ga+sa+(ja<<11)|0|0)){xd=Ma;yd=Ra;zd=$}else{Aa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ia=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Aa,ja)|0)+ga)|0;Xa=Xe[S&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,Aa,o)|0;if((p&2|0)==0){Ad=Xa;break}Ya=c[(f+12208|0)>>2]|0;na=(ca(ia,ja>>1)|0)+(ga>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|ga&1)<<2)>>2]&2047](Ya+(Aa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+na|0,ia,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|ga&1)<<2)>>2]&2047](Ya+(Aa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+na|0,ia,o>>1);na=(Xe[T&511](f,Ya+(Aa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ia,o>>1)|0)+Xa|0;Ad=na+(Xe[T&511](f,Ya+(Aa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ia,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(ga|0)){Ad=536870912;break}if((ga<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Ad=536870912;break}if((c[(f+12272|0)>>2]|0)>(ja|0)){Ad=536870912;break}if((ja<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Ad=536870912;break}ia=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;v:do{if((c[(f+11740|0)>>2]|0)==1){if((ga<<B|0)==0){na=0;while(1){Xa=c[f+12160+(na<<3)>>2]|0;Ea=(c[f+12160+(na<<3)+4>>2]|0)+(ja<<B)|0;Ta=((ca(c[f+12128+(na<<3)>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+((na&1)<<Ga)|0;P=c[f+12128+(na<<3)+4>>2]|0;if((ja<<B|0)==0){ac=na>>1;Bd=((ca(P,Ya-ia|0)|0)/(ia|0)|0)+(ac<<Ga)|0;Cd=ac}else{Bd=Ea-P|0;Cd=na>>1}P=((Bd&Q)<<B)+(Ta&Q)|0;ac=(c[(f+12208|0)>>2]|0)+((ca(Cd,Aa<<3)|0)+(na<<3&8))|0;if(za){W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>1,Aa)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&Q)<<B)+(Xa&Q)|0)<<2)>>2]&2047](ac,W,Aa,8);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Bd>>1,Aa)|0)+(Ta>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(P<<2)>>2]&2047](ac,W,Aa,8)}else{W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>2,Aa)|0)+(Xa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](ac,W,Aa);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Bd>>2,Aa)|0)+(Ta>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(P<<2)>>2]&4095](ac,W,Aa)}na=na+1|0;if((na|0)>=4){break v}}}if((ja<<B|0)==0){na=0;do{W=(c[f+12160+(na<<3)>>2]|0)+(ga<<B)|0;ac=c[f+12160+(na<<3)+4>>2]|0;P=W-(c[f+12128+(na<<3)>>2]|0)|0;Ta=na>>1;Xa=((ca(c[f+12128+(na<<3)+4>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+(Ta<<Ga)|0;Ea=(c[(f+12208|0)>>2]|0)+((na<<3&8)+(ca(Ta,Aa<<3)|0))|0;if(za){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>1,Aa)|0)+(W>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&2047](Ea,Ta,Aa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Xa>>1,Aa)|0)+(P>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&2047](Ea,Ta,Aa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>2,Aa)|0)+(W>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(W&Q)|0)<<2)>>2]&4095](Ea,Ta,Aa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Xa>>2,Aa)|0)+(P>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](Ea,Ta,Aa)}na=na+1|0;}while((na|0)<4)}else{na=0;do{Ta=(c[f+12160+(na<<3)>>2]|0)+(ga<<B)|0;Ea=(c[f+12160+(na<<3)+4>>2]|0)+(ja<<B)|0;P=Ta-(c[f+12128+(na<<3)>>2]|0)|0;Xa=Ea-(c[f+12128+(na<<3)+4>>2]|0)|0;W=(c[(f+12208|0)>>2]|0)+((na<<3&8)+(ca(na>>1,Aa<<3)|0))|0;if(za){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>1,Aa)|0)+(Ta>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&Q)<<B)+(Ta&Q)|0)<<2)>>2]&2047](W,ac,Aa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Xa>>1,Aa)|0)+(P>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&2047](W,ac,Aa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>2,Aa)|0)+(Ta>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&Q)<<B)+(Ta&Q)|0)<<2)>>2]&4095](W,ac,Aa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Xa>>2,Aa)|0)+(P>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Xa&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](W,ac,Aa)}na=na+1|0;}while((na|0)<4)}}else{na=(c[(f+12160|0)>>2]|0)+(ga<<B)|0;ac=(c[(f+12164|0)>>2]|0)+(ja<<B)|0;W=c[(f+12128|0)>>2]|0;if((ga<<B|0)==0){Dd=(ca(W,Ya-ia|0)|0)/(ia|0)|0}else{Dd=na-W|0}W=c[(f+12132|0)>>2]|0;if((ja<<B|0)==0){Ed=(ca(W,Ya-ia|0)|0)/(ia|0)|0}else{Ed=ac-W|0}W=((Ed&Q)<<B)+(Dd&Q)|0;if(za){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ac>>1,Aa)|0)+(na>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,P,Aa,16);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ed>>1,Aa)|0)+(Dd>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(W<<2)>>2]&2047](c[(f+12208|0)>>2]|0,P,Aa,16);break}else{P=(ca(ac>>2,Aa)|0)+(na>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+P|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(P+8|0)|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(P+(Aa<<3))|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ac&Q)<<B)+(na&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((P+8|0)+(Aa<<3))|0,Aa);P=(ca(Ed>>2,Aa)|0)+(Dd>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+P|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(P+8|0)|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(P+(Aa<<3))|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((P+8|0)+(Aa<<3))|0,Aa);break}}}while(0);Ad=Xe[S&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Aa,16)|0}}while(0);c[(O+(((ja<<3)+ga&63)<<2)|0)>>2]=ga+sa+(ja<<11)|0;c[Za+(((ja<<3)+ga&63)<<2)>>2]=Ad;Aa=(ca((d[Fa+((ja<<B)-Y)|0]|0)+(d[Fa+((ga<<B)-ha)|0]|0)|0,C)|0)+Ad|0;if((Aa|0)>=(Ma|0)){xd=Ma;yd=Ra;zd=$;break}c[V>>2]=ga;c[(V+4|0)>>2]=ja;xd=Aa;yd=ja;zd=ga}}while(0);ga=La+1|0;if((ga|0)<(Qa|0)){La=ga;Ma=xd;Ra=yd;$=zd}else{Fd=xd;Gd=yd;Hd=zd;break}}}else{Fd=ud;Gd=vd;Hd=wd}$=aa-fa+la|0;Ra=($|0)<0?0:$;$=pa-_+1|0;Ma=(aa|0)>($|0)?$:aa;if((Ra|0)<(Ma|0)){$=fa-aa|0;La=Ra;Ra=Fd;Qa=Gd;ma=Hd;while(1){ga=La+_|0;ja=La+$|0;do{if((c[(O+(((ga<<3)+ja&63)<<2)|0)>>2]|0)==(ja+sa+(ga<<11)|0|0)){Id=Ra;Jd=Qa;Kd=ma}else{Aa=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){ia=c[(f+12420|0)>>2]|0;Ya=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Aa,ga)|0)+ja)|0;P=Xe[S&511](f,c[(f+12288+(j<<4)|0)>>2]|0,Ya,Aa,o)|0;if((p&2|0)==0){Ld=P;break}Ya=c[(f+12208|0)>>2]|0;W=(ca(ia,ga>>1)|0)+(ja>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ga<<1&2|ja&1)<<2)>>2]&2047](Ya+(Aa<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+W|0,ia,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ga<<1&2|ja&1)<<2)>>2]&2047](Ya+(Aa<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+W|0,ia,o>>1);W=(Xe[T&511](f,Ya+(Aa<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,ia,o>>1)|0)+P|0;Ld=W+(Xe[T&511](f,Ya+(Aa<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,ia,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>(ja|0)){Ld=536870912;break}if((ja<<B|0)>(c[(f+12268|0)>>2]<<B|0)){Ld=536870912;break}if((c[(f+12272|0)>>2]|0)>(ga|0)){Ld=536870912;break}if((ga<<B|0)>(c[(f+12276|0)>>2]<<B|0)){Ld=536870912;break}ia=e[(f+13872|0)>>1]|0;Ya=e[(f+13874|0)>>1]|0;w:do{if((c[(f+11740|0)>>2]|0)==1){if((ja<<B|0)==0){W=0;while(1){P=c[f+12160+(W<<3)>>2]|0;na=(c[f+12160+(W<<3)+4>>2]|0)+(ga<<B)|0;ac=((ca(c[f+12128+(W<<3)>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+((W&1)<<Ga)|0;Xa=c[f+12128+(W<<3)+4>>2]|0;if((ga<<B|0)==0){Ta=W>>1;Md=((ca(Xa,Ya-ia|0)|0)/(ia|0)|0)+(Ta<<Ga)|0;Nd=Ta}else{Md=na-Xa|0;Nd=W>>1}Xa=((Md&Q)<<B)+(ac&Q)|0;Ta=(c[(f+12208|0)>>2]|0)+((ca(Nd,Aa<<3)|0)+(W<<3&8))|0;if(za){Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>1,Aa)|0)+(P>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((na&Q)<<B)+(P&Q)|0)<<2)>>2]&2047](Ta,Ea,Aa,8);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Md>>1,Aa)|0)+(ac>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Xa<<2)>>2]&2047](Ta,Ea,Aa,8)}else{Ea=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>2,Aa)|0)+(P>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((na&Q)<<B)+(P&Q)|0)<<2)>>2]&4095](Ta,Ea,Aa);Ea=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Md>>2,Aa)|0)+(ac>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Xa<<2)>>2]&4095](Ta,Ea,Aa)}W=W+1|0;if((W|0)>=4){break w}}}if((ga<<B|0)==0){W=0;do{Ea=(c[f+12160+(W<<3)>>2]|0)+(ja<<B)|0;Ta=c[f+12160+(W<<3)+4>>2]|0;Xa=Ea-(c[f+12128+(W<<3)>>2]|0)|0;ac=W>>1;P=((ca(c[f+12128+(W<<3)+4>>2]|0,Ya-ia|0)|0)/(ia|0)|0)+(ac<<Ga)|0;na=(c[(f+12208|0)>>2]|0)+((W<<3&8)+(ca(ac,Aa<<3)|0))|0;if(za){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>1,Aa)|0)+(Ea>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&2047](na,ac,Aa,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(P>>1,Aa)|0)+(Xa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&2047](na,ac,Aa,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>2,Aa)|0)+(Ea>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(Ea&Q)|0)<<2)>>2]&4095](na,ac,Aa);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(P>>2,Aa)|0)+(Xa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](na,ac,Aa)}W=W+1|0;}while((W|0)<4)}else{W=0;do{ac=(c[f+12160+(W<<3)>>2]|0)+(ja<<B)|0;na=(c[f+12160+(W<<3)+4>>2]|0)+(ga<<B)|0;Xa=ac-(c[f+12128+(W<<3)>>2]|0)|0;P=na-(c[f+12128+(W<<3)+4>>2]|0)|0;Ea=(c[(f+12208|0)>>2]|0)+((W<<3&8)+(ca(W>>1,Aa<<3)|0))|0;if(za){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>1,Aa)|0)+(ac>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((na&Q)<<B)+(ac&Q)|0)<<2)>>2]&2047](Ea,Ta,Aa,8);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(P>>1,Aa)|0)+(Xa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&2047](Ea,Ta,Aa,8)}else{Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(na>>2,Aa)|0)+(ac>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((na&Q)<<B)+(ac&Q)|0)<<2)>>2]&4095](Ea,Ta,Aa);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(P>>2,Aa)|0)+(Xa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((P&Q)<<B)+(Xa&Q)|0)<<2)>>2]&4095](Ea,Ta,Aa)}W=W+1|0;}while((W|0)<4)}}else{W=(c[(f+12160|0)>>2]|0)+(ja<<B)|0;Ta=(c[(f+12164|0)>>2]|0)+(ga<<B)|0;Ea=c[(f+12128|0)>>2]|0;if((ja<<B|0)==0){Od=(ca(Ea,Ya-ia|0)|0)/(ia|0)|0}else{Od=W-Ea|0}Ea=c[(f+12132|0)>>2]|0;if((ga<<B|0)==0){Pd=(ca(Ea,Ya-ia|0)|0)/(ia|0)|0}else{Pd=Ta-Ea|0}Ea=((Pd&Q)<<B)+(Od&Q)|0;if(za){Xa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ta>>1,Aa)|0)+(W>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Xa,Aa,16);Xa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Pd>>1,Aa)|0)+(Od>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(Ea<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Xa,Aa,16);break}else{Xa=(ca(Ta>>2,Aa)|0)+(W>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Xa|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+8|0)|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Xa+(Aa<<3))|0,Aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ta&Q)<<B)+(W&Q)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Xa+8|0)+(Aa<<3))|0,Aa);Xa=(ca(Pd>>2,Aa)|0)+(Od>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Xa|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+8|0)|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Xa+(Aa<<3))|0,Aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ea<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Xa+8|0)+(Aa<<3))|0,Aa);break}}}while(0);Ld=Xe[S&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Aa,16)|0}}while(0);c[(O+(((ga<<3)+ja&63)<<2)|0)>>2]=ja+sa+(ga<<11)|0;c[Za+(((ga<<3)+ja&63)<<2)>>2]=Ld;Aa=(ca((d[Fa+((ga<<B)-Y)|0]|0)+(d[Fa+((ja<<B)-ha)|0]|0)|0,C)|0)+Ld|0;if((Aa|0)>=(Ra|0)){Id=Ra;Jd=Qa;Kd=ma;break}c[V>>2]=ja;c[(V+4|0)>>2]=ga;Id=Aa;Jd=ga;Kd=ja}}while(0);ja=La+1|0;if((ja|0)<(Ma|0)){La=ja;Ra=Id;Qa=Jd;ma=Kd}else{Qd=Id;Rd=Jd;Sd=Kd;break}}}else{Qd=Fd;Rd=Gd;Sd=Hd}ma=(fa|0)==(Sd|0)&(_|0)==(Rd|0);Qa=ma?aa+1|0:1;if((Qa|0)>(c[(f+12260|0)>>2]|0)){Bb=Qd;break e}else{aa=Qa;oa=Qd;fa=Sd;_=ma?_:Rd}}}_=c[f+10468+(n<<2)>>2]|0;fa=c[f+10468+((n+1|0)<<2)>>2]|0;if((U&255|0)==0){Td=L;Ud=M;Vd=N;Wd=V+4|0}else{oa=(p&1)<<1|1;aa=U&255;S=L;Q=N;za=M;while(1){Ga=S;T=Q;ma=za;while(1){Qa=0;Ra=Ga;La=T;Ma=ma;while(1){$=(ca(c[1017160+(Qa<<3)>>2]|0,aa)|0)+ma|0;ja=(ca(c[1017164+(Qa<<3)>>2]|0,aa)|0)+T|0;ga=($|0)>(Z|0)?Z:$;$=(la|0)>(ga|0)?la:ga;ga=(ja|0)>(pa|0)?pa:ja;ja=(X|0)>(ga|0)?X:ga;do{if((c[(O+(((ja<<3)+$&63)<<2)|0)>>2]|0)==($+sa+(ja<<11)|0|0)){Xd=Ra;Yd=La;Zd=Ma}else{ga=c[(f+12416|0)>>2]|0;do{if((p&4|0)==0){Aa=c[(f+12420|0)>>2]|0;ia=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ga,ja)|0)+$)|0;Ya=Xe[_&511](f,c[(f+12288+(j<<4)|0)>>2]|0,ia,ga,o)|0;if((p&2|0)==0){_d=Ya;break}ia=c[(f+12208|0)>>2]|0;Xa=(ca(Aa,ja>>1)|0)+($>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|$&1)<<2)>>2]&2047](ia+(ga<<4)|0,(c[(f+12352+(k<<4)+4|0)>>2]|0)+Xa|0,Aa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((ja<<1&2|$&1)<<2)>>2]&2047](ia+(ga<<4|8)|0,(c[(f+12352+(k<<4)+8|0)>>2]|0)+Xa|0,Aa,o>>1);Xa=(Xe[fa&511](f,ia+(ga<<4)|0,c[(f+12288+(j<<4)+4|0)>>2]|0,Aa,o>>1)|0)+Ya|0;_d=Xa+(Xe[fa&511](f,ia+(ga<<4|8)|0,c[(f+12288+(j<<4)+8|0)>>2]|0,Aa,o>>1)|0)|0}else{if((c[(f+12264|0)>>2]|0)>($|0)){_d=536870912;break}if(($<<B|0)>(c[(f+12268|0)>>2]<<B|0)){_d=536870912;break}if((c[(f+12272|0)>>2]|0)>(ja|0)){_d=536870912;break}if((ja<<B|0)>(c[(f+12276|0)>>2]<<B|0)){_d=536870912;break}Aa=e[(f+13872|0)>>1]|0;ia=e[(f+13874|0)>>1]|0;x:do{if((c[(f+11740|0)>>2]|0)==1){if(($<<B|0)==0){Xa=0;while(1){Ya=c[f+12160+(Xa<<3)>>2]|0;Ea=(c[f+12160+(Xa<<3)+4>>2]|0)+(ja<<B)|0;W=((ca(c[f+12128+(Xa<<3)>>2]|0,ia-Aa|0)|0)/(Aa|0)|0)+((Xa&1)<<(p&1|4))|0;Ta=c[f+12128+(Xa<<3)+4>>2]|0;if((ja<<B|0)==0){P=Xa>>1;$d=((ca(Ta,ia-Aa|0)|0)/(Aa|0)|0)+(P<<(p&1|4))|0;ae=P}else{$d=Ea-Ta|0;ae=Xa>>1}Ta=(($d&oa)<<B)+(W&oa)|0;P=(c[(f+12208|0)>>2]|0)+((ca(ae,ga<<3)|0)+(Xa<<3&8))|0;if((p&1|0)==0){ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>1,ga)|0)+(Ya>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&oa)<<B)+(Ya&oa)|0)<<2)>>2]&2047](P,ac,ga,8);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca($d>>1,ga)|0)+(W>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Ta<<2)>>2]&2047](P,ac,ga,8)}else{ac=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>2,ga)|0)+(Ya>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&oa)<<B)+(Ya&oa)|0)<<2)>>2]&4095](P,ac,ga);ac=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca($d>>2,ga)|0)+(W>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ta<<2)>>2]&4095](P,ac,ga)}Xa=Xa+1|0;if((Xa|0)>=4){break x}}}if((ja<<B|0)==0){Xa=0;do{ac=(c[f+12160+(Xa<<3)>>2]|0)+($<<B)|0;P=c[f+12160+(Xa<<3)+4>>2]|0;Ta=ac-(c[f+12128+(Xa<<3)>>2]|0)|0;W=Xa>>1;Ya=((ca(c[f+12128+(Xa<<3)+4>>2]|0,ia-Aa|0)|0)/(Aa|0)|0)+(W<<(p&1|4))|0;Ea=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ca(W,ga<<3)|0))|0;if((p&1|0)==0){W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(P>>1,ga)|0)+(ac>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((P&oa)<<B)+(ac&oa)|0)<<2)>>2]&2047](Ea,W,ga,8);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ya>>1,ga)|0)+(Ta>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ya&oa)<<B)+(Ta&oa)|0)<<2)>>2]&2047](Ea,W,ga,8)}else{W=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(P>>2,ga)|0)+(ac>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(ac&oa)|0)<<2)>>2]&4095](Ea,W,ga);W=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ya>>2,ga)|0)+(Ta>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ya&oa)<<B)+(Ta&oa)|0)<<2)>>2]&4095](Ea,W,ga)}Xa=Xa+1|0;}while((Xa|0)<4)}else{Xa=0;do{W=(c[f+12160+(Xa<<3)>>2]|0)+($<<B)|0;Ea=(c[f+12160+(Xa<<3)+4>>2]|0)+(ja<<B)|0;Ta=W-(c[f+12128+(Xa<<3)>>2]|0)|0;Ya=Ea-(c[f+12128+(Xa<<3)+4>>2]|0)|0;ac=(c[(f+12208|0)>>2]|0)+((Xa<<3&8)+(ca(Xa>>1,ga<<3)|0))|0;if((p&1|0)==0){P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>1,ga)|0)+(W>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ea&oa)<<B)+(W&oa)|0)<<2)>>2]&2047](ac,P,ga,8);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ya>>1,ga)|0)+(Ta>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ya&oa)<<B)+(Ta&oa)|0)<<2)>>2]&2047](ac,P,ga,8)}else{P=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ea>>2,ga)|0)+(W>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ea&oa)<<B)+(W&oa)|0)<<2)>>2]&4095](ac,P,ga);P=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ya>>2,ga)|0)+(Ta>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ya&oa)<<B)+(Ta&oa)|0)<<2)>>2]&4095](ac,P,ga)}Xa=Xa+1|0;}while((Xa|0)<4)}}else{Xa=(c[(f+12160|0)>>2]|0)+($<<B)|0;P=(c[(f+12164|0)>>2]|0)+(ja<<B)|0;ac=c[(f+12128|0)>>2]|0;if(($<<B|0)==0){be=(ca(ac,ia-Aa|0)|0)/(Aa|0)|0}else{be=Xa-ac|0}ac=c[(f+12132|0)>>2]|0;if((ja<<B|0)==0){ce=(ca(ac,ia-Aa|0)|0)/(Aa|0)|0}else{ce=P-ac|0}ac=((ce&oa)<<B)+(be&oa)|0;if((p&1|0)==0){Ta=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(P>>1,ga)|0)+(Xa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ta,ga,16);Ta=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ce>>1,ga)|0)+(be>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+(ac<<2)>>2]&2047](c[(f+12208|0)>>2]|0,Ta,ga,16);break}else{Ta=(ca(P>>2,ga)|0)+(Xa>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+Ta|0,ga);ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ta+8|0)|0,ga);ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ga<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(Ta+(ga<<3))|0,ga);ef[c[(c[(f+12452|0)>>2]|0)+64+((((P&oa)<<B)+(Xa&oa)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ga<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((Ta+8|0)+(ga<<3))|0,ga);Ta=(ca(ce>>2,ga)|0)+(be>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+Ta|0,ga);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ta+8|0)|0,ga);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ga<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(Ta+(ga<<3))|0,ga);ef[c[(c[(f+12456|0)>>2]|0)+64+(ac<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ga<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((Ta+8|0)+(ga<<3))|0,ga);break}}}while(0);_d=Xe[_&511](f,c[(f+12208|0)>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ga,16)|0}}while(0);c[(O+(((ja<<3)+$&63)<<2)|0)>>2]=$+sa+(ja<<11)|0;c[Za+(((ja<<3)+$&63)<<2)>>2]=_d;ga=(ca((d[Fa+((ja<<B)-Y)|0]|0)+(d[Fa+(($<<B)-ha)|0]|0)|0,C)|0)+_d|0;if((ga|0)>=(Ra|0)){Xd=Ra;Yd=La;Zd=Ma;break}c[V>>2]=$;c[(V+4|0)>>2]=ja;Xd=ga;Yd=ja;Zd=$}}while(0);$=Qa+1|0;if(($|0)<8){Qa=$;Ra=Xd;La=Yd;Ma=Zd}else{break}}if((Zd|0)==(ma|0)&(Yd|0)==(T|0)){break}else{Ga=Xd;T=Yd;ma=Zd}}Ga=(U+255&(U&255)|0)!=0?aa-1|0:aa>>1;if((Ga|0)==0){Td=Xd;Ud=ma;Vd=T;Wd=V+4|0;break}else{aa=Ga;S=Xd;Q=T;za=ma}}}za=Ud+1|0;Q=(za|0)>(Z|0)?Z:za;za=(la|0)>(Q|0)?la:Q;Q=(Vd|0)>(pa|0)?pa:Vd;S=(X|0)>(Q|0)?X:Q;do{if((c[(O+((za+(S<<3)&63)<<2)|0)>>2]|0)==(((S<<11)+sa|0)+za|0|0)){de=Td}else{do{if((p&4|0)==0){Q=c[f+12416>>2]|0;aa=c[f+12420>>2]|0;oa=(c[f+12352+(k<<4)>>2]|0)+((ca(Q,S)|0)+za)|0;Ga=Xe[_&511](f,c[f+12288+(j<<4)>>2]|0,oa,Q,o)|0;if((p&2|0)==0){ee=Ga;break}oa=c[f+12208>>2]|0;Ma=(ca(aa,S>>1)|0)+(za>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za&1|S<<1&2)<<2)>>2]&2047](oa+(Q<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+Ma|0,aa,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za&1|S<<1&2)<<2)>>2]&2047](oa+(Q<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+Ma|0,aa,o>>1);Ma=(Xe[fa&511](f,oa+(Q<<4)|0,c[f+12288+(j<<4)+4>>2]|0,aa,o>>1)|0)+Ga|0;ee=Ma+(Xe[fa&511](f,oa+(Q<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,aa,o>>1)|0)|0}else{aa=c[f+12416>>2]|0;if((c[(f+12264|0)>>2]|0)>(za|0)){ee=536870912;break}if((za<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ee=536870912;break}if((c[(f+12272|0)>>2]|0)>(S|0)){ee=536870912;break}if((S<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ee=536870912;break}Q=e[f+13872>>1]|0;oa=e[f+13874>>1]|0;Ma=(p&1)<<1|1;y:do{if((c[f+11740>>2]|0)==1){if((za<<B|0)==0){Ga=0;while(1){La=c[f+12160+(Ga<<3)>>2]|0;Ra=(c[f+12160+(Ga<<3)+4>>2]|0)+(S<<B)|0;Qa=((ca(c[f+12128+(Ga<<3)>>2]|0,oa-Q|0)|0)/(Q|0)|0)+((Ga&1)<<(p&1|4))|0;$=c[f+12128+(Ga<<3)+4>>2]|0;if((S<<B|0)==0){ja=Ga>>1;fe=((ca($,oa-Q|0)|0)/(Q|0)|0)+(ja<<(p&1|4))|0;ge=ja}else{fe=Ra-$|0;ge=Ga>>1}$=((fe&Ma)<<B)+(Qa&Ma)|0;ja=(c[(f+12208|0)>>2]|0)+((ca(ge,aa<<3)|0)+(Ga<<3&8))|0;if((p&1|0)==0){ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ra>>1,aa)|0)+(La>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ra&Ma)<<B)+(La&Ma)|0)<<2)>>2]&2047](ja,ga,aa,8);ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(fe>>1,aa)|0)+(Qa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+($<<2)>>2]&2047](ja,ga,aa,8)}else{ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ra>>2,aa)|0)+(La>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ra&Ma)<<B)+(La&Ma)|0)<<2)>>2]&4095](ja,ga,aa);ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(fe>>2,aa)|0)+(Qa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+($<<2)>>2]&4095](ja,ga,aa)}Ga=Ga+1|0;if((Ga|0)>=4){break y}}}if((S<<B|0)==0){Ga=0;do{ga=(c[f+12160+(Ga<<3)>>2]|0)+(za<<B)|0;ja=c[f+12160+(Ga<<3)+4>>2]|0;$=ga-(c[f+12128+(Ga<<3)>>2]|0)|0;Qa=Ga>>1;La=((ca(c[f+12128+(Ga<<3)+4>>2]|0,oa-Q|0)|0)/(Q|0)|0)+(Qa<<(p&1|4))|0;Ra=(c[(f+12208|0)>>2]|0)+((Ga<<3&8)+(ca(Qa,aa<<3)|0))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>1,aa)|0)+(ga>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ja&Ma)<<B)+(ga&Ma)|0)<<2)>>2]&2047](Ra,Qa,aa,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(La>>1,aa)|0)+($>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((La&Ma)<<B)+($&Ma)|0)<<2)>>2]&2047](Ra,Qa,aa,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>2,aa)|0)+(ga>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(ga&Ma)|0)<<2)>>2]&4095](Ra,Qa,aa);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(La>>2,aa)|0)+($>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((La&Ma)<<B)+($&Ma)|0)<<2)>>2]&4095](Ra,Qa,aa)}Ga=Ga+1|0;}while((Ga|0)<4)}else{Ga=0;do{Qa=(c[f+12160+(Ga<<3)>>2]|0)+(za<<B)|0;Ra=(c[f+12160+(Ga<<3)+4>>2]|0)+(S<<B)|0;$=Qa-(c[f+12128+(Ga<<3)>>2]|0)|0;La=Ra-(c[f+12128+(Ga<<3)+4>>2]|0)|0;ga=(c[(f+12208|0)>>2]|0)+((Ga<<3&8)+(ca(Ga>>1,aa<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ra>>1,aa)|0)+(Qa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ra&Ma)<<B)+(Qa&Ma)|0)<<2)>>2]&2047](ga,ja,aa,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(La>>1,aa)|0)+($>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((La&Ma)<<B)+($&Ma)|0)<<2)>>2]&2047](ga,ja,aa,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ra>>2,aa)|0)+(Qa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ra&Ma)<<B)+(Qa&Ma)|0)<<2)>>2]&4095](ga,ja,aa);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(La>>2,aa)|0)+($>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((La&Ma)<<B)+($&Ma)|0)<<2)>>2]&4095](ga,ja,aa)}Ga=Ga+1|0;}while((Ga|0)<4)}}else{Ga=(c[f+12160>>2]|0)+(za<<B)|0;ja=(c[f+12164>>2]|0)+(S<<B)|0;ga=c[f+12128>>2]|0;if((za<<B|0)==0){he=(ca(ga,oa-Q|0)|0)/(Q|0)|0}else{he=Ga-ga|0}ga=c[f+12132>>2]|0;if((S<<B|0)==0){ie=(ca(ga,oa-Q|0)|0)/(Q|0)|0}else{ie=ja-ga|0}ga=((ie&Ma)<<B)+(he&Ma)|0;if((p&1|0)==0){$=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>1,aa)|0)+(Ga>>1))|0;mf[c[(c[f+12444>>2]|0)+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,$,aa,16);$=(c[f+12352+(k<<4)+32>>2]|0)+((ca(ie>>1,aa)|0)+(he>>1))|0;mf[c[(c[f+12448>>2]|0)+(ga<<2)>>2]&2047](c[(f+12208|0)>>2]|0,$,aa,16);break}else{$=(ca(ja>>2,aa)|0)+(Ga>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+$|0,aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+($+8|0)|0,aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(aa<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+($+(aa<<3))|0,aa);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&Ma)<<B)+(Ga&Ma)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((aa<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(($+8|0)+(aa<<3))|0,aa);$=(ca(ie>>2,aa)|0)+(he>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+$|0,aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+($+8|0)|0,aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(aa<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+($+(aa<<3))|0,aa);ef[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((aa<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(($+8|0)+(aa<<3))|0,aa);break}}}while(0);ee=Xe[_&511](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,aa,16)|0}}while(0);c[(O+((za+(S<<3)&63)<<2)|0)>>2]=((S<<11)+sa|0)+za|0;c[Za+((za+(S<<3)&63)<<2)>>2]=ee;ma=(ca((d[Fa+((S<<B)-Y)|0]|0)+(d[Fa+((za<<B)-ha)|0]|0)|0,C)|0)+ee|0;if((ma|0)>=(Td|0)){de=Td;break}c[V>>2]=za;c[Wd>>2]=S;de=ma}}while(0);za=Vd+1|0;ma=(Ud|0)>(Z|0)?Z:Ud;T=(la|0)>(ma|0)?la:ma;ma=(za|0)>(pa|0)?pa:za;za=(X|0)>(ma|0)?X:ma;do{if((c[(O+(((za<<3)+T&63)<<2)|0)>>2]|0)==((T+sa|0)+(za<<11)|0|0)){je=de}else{do{if((p&4|0)==0){ma=c[f+12416>>2]|0;Ma=c[f+12420>>2]|0;Q=(c[f+12352+(k<<4)>>2]|0)+((ca(ma,za)|0)+T)|0;oa=Xe[_&511](f,c[f+12288+(j<<4)>>2]|0,Q,ma,o)|0;if((p&2|0)==0){ke=oa;break}Q=c[f+12208>>2]|0;$=(ca(Ma,za>>1)|0)+(T>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za<<1&2|T&1)<<2)>>2]&2047](Q+(ma<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+$|0,Ma,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za<<1&2|T&1)<<2)>>2]&2047](Q+(ma<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+$|0,Ma,o>>1);$=(Xe[fa&511](f,Q+(ma<<4)|0,c[f+12288+(j<<4)+4>>2]|0,Ma,o>>1)|0)+oa|0;ke=$+(Xe[fa&511](f,Q+(ma<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,Ma,o>>1)|0)|0}else{Ma=c[f+12416>>2]|0;if((c[(f+12264|0)>>2]|0)>(T|0)){ke=536870912;break}if((T<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ke=536870912;break}if((c[(f+12272|0)>>2]|0)>(za|0)){ke=536870912;break}if((za<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ke=536870912;break}ma=e[f+13872>>1]|0;Q=e[f+13874>>1]|0;$=(p&1)<<1|1;z:do{if((c[f+11740>>2]|0)==1){if((T<<B|0)==0){oa=0;while(1){ga=c[f+12160+(oa<<3)>>2]|0;Ga=(c[f+12160+(oa<<3)+4>>2]|0)+(za<<B)|0;ja=((ca(c[f+12128+(oa<<3)>>2]|0,Q-ma|0)|0)/(ma|0)|0)+((oa&1)<<(p&1|4))|0;La=c[f+12128+(oa<<3)+4>>2]|0;if((za<<B|0)==0){Qa=oa>>1;le=((ca(La,Q-ma|0)|0)/(ma|0)|0)+(Qa<<(p&1|4))|0;me=Qa}else{le=Ga-La|0;me=oa>>1}La=((le&$)<<B)+(ja&$)|0;Qa=(c[(f+12208|0)>>2]|0)+((ca(me,Ma<<3)|0)+(oa<<3&8))|0;if((p&1|0)==0){Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ga>>1,Ma)|0)+(ga>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ga&$)<<B)+(ga&$)|0)<<2)>>2]&2047](Qa,Ra,Ma,8);Ra=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(le>>1,Ma)|0)+(ja>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(La<<2)>>2]&2047](Qa,Ra,Ma,8)}else{Ra=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ga>>2,Ma)|0)+(ga>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ga&$)<<B)+(ga&$)|0)<<2)>>2]&4095](Qa,Ra,Ma);Ra=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(le>>2,Ma)|0)+(ja>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(La<<2)>>2]&4095](Qa,Ra,Ma)}oa=oa+1|0;if((oa|0)>=4){break z}}}if((za<<B|0)==0){oa=0;do{Ra=(c[f+12160+(oa<<3)>>2]|0)+(T<<B)|0;Qa=c[f+12160+(oa<<3)+4>>2]|0;La=Ra-(c[f+12128+(oa<<3)>>2]|0)|0;ja=oa>>1;ga=((ca(c[f+12128+(oa<<3)+4>>2]|0,Q-ma|0)|0)/(ma|0)|0)+(ja<<(p&1|4))|0;Ga=(c[(f+12208|0)>>2]|0)+((oa<<3&8)+(ca(ja,Ma<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa>>1,Ma)|0)+(Ra>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Qa&$)<<B)+(Ra&$)|0)<<2)>>2]&2047](Ga,ja,Ma,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>1,Ma)|0)+(La>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&$)<<B)+(La&$)|0)<<2)>>2]&2047](Ga,ja,Ma,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa>>2,Ma)|0)+(Ra>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(Ra&$)|0)<<2)>>2]&4095](Ga,ja,Ma);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>2,Ma)|0)+(La>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ga&$)<<B)+(La&$)|0)<<2)>>2]&4095](Ga,ja,Ma)}oa=oa+1|0;}while((oa|0)<4)}else{oa=0;do{ja=(c[f+12160+(oa<<3)>>2]|0)+(T<<B)|0;Ga=(c[f+12160+(oa<<3)+4>>2]|0)+(za<<B)|0;La=ja-(c[f+12128+(oa<<3)>>2]|0)|0;ga=Ga-(c[f+12128+(oa<<3)+4>>2]|0)|0;Ra=(c[(f+12208|0)>>2]|0)+((oa<<3&8)+(ca(oa>>1,Ma<<3)|0))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ga>>1,Ma)|0)+(ja>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ga&$)<<B)+(ja&$)|0)<<2)>>2]&2047](Ra,Qa,Ma,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>1,Ma)|0)+(La>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&$)<<B)+(La&$)|0)<<2)>>2]&2047](Ra,Qa,Ma,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ga>>2,Ma)|0)+(ja>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ga&$)<<B)+(ja&$)|0)<<2)>>2]&4095](Ra,Qa,Ma);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>2,Ma)|0)+(La>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ga&$)<<B)+(La&$)|0)<<2)>>2]&4095](Ra,Qa,Ma)}oa=oa+1|0;}while((oa|0)<4)}}else{oa=(c[f+12160>>2]|0)+(T<<B)|0;Qa=(c[f+12164>>2]|0)+(za<<B)|0;Ra=c[f+12128>>2]|0;if((T<<B|0)==0){ne=(ca(Ra,Q-ma|0)|0)/(ma|0)|0}else{ne=oa-Ra|0}Ra=c[f+12132>>2]|0;if((za<<B|0)==0){oe=(ca(Ra,Q-ma|0)|0)/(ma|0)|0}else{oe=Qa-Ra|0}Ra=((oe&$)<<B)+(ne&$)|0;if((p&1|0)==0){La=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Qa>>1,Ma)|0)+(oa>>1))|0;mf[c[(c[f+12444>>2]|0)+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,La,Ma,16);La=(c[f+12352+(k<<4)+32>>2]|0)+((ca(oe>>1,Ma)|0)+(ne>>1))|0;mf[c[(c[f+12448>>2]|0)+(Ra<<2)>>2]&2047](c[(f+12208|0)>>2]|0,La,Ma,16);break}else{La=(ca(Qa>>2,Ma)|0)+(oa>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+La|0,Ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(La+8|0)|0,Ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ma<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(La+(Ma<<3))|0,Ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((Qa&$)<<B)+(oa&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ma<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((La+8|0)+(Ma<<3))|0,Ma);La=(ca(oe>>2,Ma)|0)+(ne>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ra<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+La|0,Ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ra<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(La+8|0)|0,Ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ra<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(Ma<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(La+(Ma<<3))|0,Ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ra<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((Ma<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((La+8|0)+(Ma<<3))|0,Ma);break}}}while(0);ke=Xe[_&511](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,Ma,16)|0}}while(0);c[(O+(((za<<3)+T&63)<<2)|0)>>2]=(T+sa|0)+(za<<11)|0;c[Za+(((za<<3)+T&63)<<2)>>2]=ke;$=(ca((d[Fa+((za<<B)-Y)|0]|0)+(d[Fa+((T<<B)-ha)|0]|0)|0,C)|0)+ke|0;if(($|0)>=(de|0)){je=de;break}c[V>>2]=T;c[Wd>>2]=za;je=$}}while(0);za=Ud-1|0;$=(za|0)>(Z|0)?Z:za;za=(la|0)>($|0)?la:$;do{if((c[(O+((za+(S<<3)&63)<<2)|0)>>2]|0)==(((S<<11)+sa|0)+za|0|0)){pe=je}else{do{if((p&4|0)==0){$=c[f+12416>>2]|0;ma=c[f+12420>>2]|0;Q=(c[f+12352+(k<<4)>>2]|0)+((ca($,S)|0)+za)|0;aa=Xe[_&511](f,c[f+12288+(j<<4)>>2]|0,Q,$,o)|0;if((p&2|0)==0){qe=aa;break}Q=c[f+12208>>2]|0;La=(ca(ma,S>>1)|0)+(za>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za&1|S<<1&2)<<2)>>2]&2047](Q+($<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+La|0,ma,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((za&1|S<<1&2)<<2)>>2]&2047](Q+($<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+La|0,ma,o>>1);La=(Xe[fa&511](f,Q+($<<4)|0,c[f+12288+(j<<4)+4>>2]|0,ma,o>>1)|0)+aa|0;qe=La+(Xe[fa&511](f,Q+($<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,ma,o>>1)|0)|0}else{ma=c[f+12416>>2]|0;if((c[(f+12264|0)>>2]|0)>(za|0)){qe=536870912;break}if((za<<B|0)>(c[(f+12268|0)>>2]<<B|0)){qe=536870912;break}if((c[(f+12272|0)>>2]|0)>(S|0)){qe=536870912;break}if((S<<B|0)>(c[(f+12276|0)>>2]<<B|0)){qe=536870912;break}$=e[f+13872>>1]|0;Q=e[f+13874>>1]|0;La=(p&1)<<1|1;A:do{if((c[f+11740>>2]|0)==1){if((za<<B|0)==0){aa=0;while(1){Ra=c[f+12160+(aa<<3)>>2]|0;oa=(c[f+12160+(aa<<3)+4>>2]|0)+(S<<B)|0;Qa=((ca(c[f+12128+(aa<<3)>>2]|0,Q-$|0)|0)/($|0)|0)+((aa&1)<<(p&1|4))|0;ga=c[f+12128+(aa<<3)+4>>2]|0;if((S<<B|0)==0){ja=aa>>1;re=((ca(ga,Q-$|0)|0)/($|0)|0)+(ja<<(p&1|4))|0;se=ja}else{re=oa-ga|0;se=aa>>1}ga=((re&La)<<B)+(Qa&La)|0;ja=(c[(f+12208|0)>>2]|0)+((ca(se,ma<<3)|0)+(aa<<3&8))|0;if((p&1|0)==0){Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(oa>>1,ma)|0)+(Ra>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((oa&La)<<B)+(Ra&La)|0)<<2)>>2]&2047](ja,Ga,ma,8);Ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(re>>1,ma)|0)+(Qa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(ga<<2)>>2]&2047](ja,Ga,ma,8)}else{Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(oa>>2,ma)|0)+(Ra>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((oa&La)<<B)+(Ra&La)|0)<<2)>>2]&4095](ja,Ga,ma);Ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(re>>2,ma)|0)+(Qa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](ja,Ga,ma)}aa=aa+1|0;if((aa|0)>=4){break A}}}if((S<<B|0)==0){aa=0;do{Ga=(c[f+12160+(aa<<3)>>2]|0)+(za<<B)|0;ja=c[f+12160+(aa<<3)+4>>2]|0;ga=Ga-(c[f+12128+(aa<<3)>>2]|0)|0;Qa=aa>>1;Ra=((ca(c[f+12128+(aa<<3)+4>>2]|0,Q-$|0)|0)/($|0)|0)+(Qa<<(p&1|4))|0;oa=(c[(f+12208|0)>>2]|0)+((aa<<3&8)+(ca(Qa,ma<<3)|0))|0;if((p&1|0)==0){Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>1,ma)|0)+(Ga>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ja&La)<<B)+(Ga&La)|0)<<2)>>2]&2047](oa,Qa,ma,8);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ra>>1,ma)|0)+(ga>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ra&La)<<B)+(ga&La)|0)<<2)>>2]&2047](oa,Qa,ma,8)}else{Qa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>2,ma)|0)+(Ga>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(Ga&La)|0)<<2)>>2]&4095](oa,Qa,ma);Qa=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ra>>2,ma)|0)+(ga>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ra&La)<<B)+(ga&La)|0)<<2)>>2]&4095](oa,Qa,ma)}aa=aa+1|0;}while((aa|0)<4)}else{aa=0;do{Qa=(c[f+12160+(aa<<3)>>2]|0)+(za<<B)|0;oa=(c[f+12160+(aa<<3)+4>>2]|0)+(S<<B)|0;ga=Qa-(c[f+12128+(aa<<3)>>2]|0)|0;Ra=oa-(c[f+12128+(aa<<3)+4>>2]|0)|0;Ga=(c[(f+12208|0)>>2]|0)+((aa<<3&8)+(ca(aa>>1,ma<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(oa>>1,ma)|0)+(Qa>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((oa&La)<<B)+(Qa&La)|0)<<2)>>2]&2047](Ga,ja,ma,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ra>>1,ma)|0)+(ga>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((Ra&La)<<B)+(ga&La)|0)<<2)>>2]&2047](Ga,ja,ma,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(oa>>2,ma)|0)+(Qa>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((oa&La)<<B)+(Qa&La)|0)<<2)>>2]&4095](Ga,ja,ma);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(Ra>>2,ma)|0)+(ga>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((Ra&La)<<B)+(ga&La)|0)<<2)>>2]&4095](Ga,ja,ma)}aa=aa+1|0;}while((aa|0)<4)}}else{aa=(c[f+12160>>2]|0)+(za<<B)|0;ja=(c[f+12164>>2]|0)+(S<<B)|0;Ga=c[f+12128>>2]|0;if((za<<B|0)==0){te=(ca(Ga,Q-$|0)|0)/($|0)|0}else{te=aa-Ga|0}Ga=c[f+12132>>2]|0;if((S<<B|0)==0){ue=(ca(Ga,Q-$|0)|0)/($|0)|0}else{ue=ja-Ga|0}Ga=((ue&La)<<B)+(te&La)|0;if((p&1|0)==0){ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>1,ma)|0)+(aa>>1))|0;mf[c[(c[f+12444>>2]|0)+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,ga,ma,16);ga=(c[f+12352+(k<<4)+32>>2]|0)+((ca(ue>>1,ma)|0)+(te>>1))|0;mf[c[(c[f+12448>>2]|0)+(Ga<<2)>>2]&2047](c[(f+12208|0)>>2]|0,ga,ma,16);break}else{ga=(ca(ja>>2,ma)|0)+(aa>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+ga|0,ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(ga+8|0)|0,ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ma<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(ga+(ma<<3))|0,ma);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&La)<<B)+(aa&La)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((ga+8|0)+(ma<<3))|0,ma);ga=(ca(ue>>2,ma)|0)+(te>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+ga|0,ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(ga+8|0)|0,ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(ma<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(ga+(ma<<3))|0,ma);ef[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ga+8|0)+(ma<<3))|0,ma);break}}}while(0);qe=Xe[_&511](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(O+((za+(S<<3)&63)<<2)|0)>>2]=((S<<11)+sa|0)+za|0;c[Za+((za+(S<<3)&63)<<2)>>2]=qe;La=(ca((d[Fa+((S<<B)-Y)|0]|0)+(d[Fa+((za<<B)-ha)|0]|0)|0,C)|0)+qe|0;if((La|0)>=(je|0)){pe=je;break}c[V>>2]=za;c[Wd>>2]=S;pe=La}}while(0);S=Vd-1|0;za=(S|0)>(pa|0)?pa:S;S=(X|0)>(za|0)?X:za;if((c[(O+(((S<<3)+T&63)<<2)|0)>>2]|0)==((T+sa|0)+(S<<11)|0|0)){Bb=pe;break}do{if((p&4|0)==0){za=c[f+12416>>2]|0;la=c[f+12420>>2]|0;Z=(c[f+12352+(k<<4)>>2]|0)+((ca(za,S)|0)+T)|0;La=Xe[_&511](f,c[f+12288+(j<<4)>>2]|0,Z,za,o)|0;if((p&2|0)==0){ve=La;break}Z=c[f+12208>>2]|0;$=(ca(la,S>>1)|0)+(T>>1)|0;mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((S<<1&2|T&1)<<2)>>2]&2047](Z+(za<<4)|0,(c[f+12352+(k<<4)+4>>2]|0)+$|0,la,o>>1);mf[c[(c[(f+12444|0)>>2]|0)+((n+1|0)<<4)+((S<<1&2|T&1)<<2)>>2]&2047](Z+(za<<4|8)|0,(c[f+12352+(k<<4)+8>>2]|0)+$|0,la,o>>1);$=(Xe[fa&511](f,Z+(za<<4)|0,c[f+12288+(j<<4)+4>>2]|0,la,o>>1)|0)+La|0;ve=$+(Xe[fa&511](f,Z+(za<<4|8)|0,c[f+12288+(j<<4)+8>>2]|0,la,o>>1)|0)|0}else{la=c[f+12416>>2]|0;if((c[(f+12264|0)>>2]|0)>(T|0)){ve=536870912;break}if((T<<B|0)>(c[(f+12268|0)>>2]<<B|0)){ve=536870912;break}if((c[(f+12272|0)>>2]|0)>(S|0)){ve=536870912;break}if((S<<B|0)>(c[(f+12276|0)>>2]<<B|0)){ve=536870912;break}za=e[f+13872>>1]|0;Z=e[f+13874>>1]|0;$=(p&1)<<1|1;B:do{if((c[f+11740>>2]|0)==1){if((T<<B|0)==0){La=0;while(1){Q=c[f+12160+(La<<3)>>2]|0;Ma=(c[f+12160+(La<<3)+4>>2]|0)+(S<<B)|0;ga=((ca(c[f+12128+(La<<3)>>2]|0,Z-za|0)|0)/(za|0)|0)+((La&1)<<(p&1|4))|0;Ga=c[f+12128+(La<<3)+4>>2]|0;if((S<<B|0)==0){aa=La>>1;we=((ca(Ga,Z-za|0)|0)/(za|0)|0)+(aa<<(p&1|4))|0;xe=aa}else{we=Ma-Ga|0;xe=La>>1}Ga=((we&$)<<B)+(ga&$)|0;aa=(c[(f+12208|0)>>2]|0)+((ca(xe,la<<3)|0)+(La<<3&8))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ma>>1,la)|0)+(Q>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Ma&$)<<B)+(Q&$)|0)<<2)>>2]&2047](aa,ja,la,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(we>>1,la)|0)+(ga>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+(Ga<<2)>>2]&2047](aa,ja,la,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Ma>>2,la)|0)+(Q>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Ma&$)<<B)+(Q&$)|0)<<2)>>2]&4095](aa,ja,la);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(we>>2,la)|0)+(ga>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(Ga<<2)>>2]&4095](aa,ja,la)}La=La+1|0;if((La|0)>=4){break B}}}if((S<<B|0)==0){La=0;do{ma=(c[f+12160+(La<<3)>>2]|0)+(T<<B)|0;ja=c[f+12160+(La<<3)+4>>2]|0;aa=ma-(c[f+12128+(La<<3)>>2]|0)|0;Ga=La>>1;ga=((ca(c[f+12128+(La<<3)+4>>2]|0,Z-za|0)|0)/(za|0)|0)+(Ga<<(p&1|4))|0;Q=(c[(f+12208|0)>>2]|0)+((La<<3&8)+(ca(Ga,la<<3)|0))|0;if((p&1|0)==0){Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>1,la)|0)+(ma>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((ja&$)<<B)+(ma&$)|0)<<2)>>2]&2047](Q,Ga,la,8);Ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>1,la)|0)+(aa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&$)<<B)+(aa&$)|0)<<2)>>2]&2047](Q,Ga,la,8)}else{Ga=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>2,la)|0)+(ma>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(ma&$)|0)<<2)>>2]&4095](Q,Ga,la);Ga=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>2,la)|0)+(aa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ga&$)<<B)+(aa&$)|0)<<2)>>2]&4095](Q,Ga,la)}La=La+1|0;}while((La|0)<4)}else{La=0;do{Ga=(c[f+12160+(La<<3)>>2]|0)+(T<<B)|0;Q=(c[f+12160+(La<<3)+4>>2]|0)+(S<<B)|0;aa=Ga-(c[f+12128+(La<<3)>>2]|0)|0;ga=Q-(c[f+12128+(La<<3)+4>>2]|0)|0;ma=(c[(f+12208|0)>>2]|0)+((La<<3&8)+(ca(La>>1,la<<3)|0))|0;if((p&1|0)==0){ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Q>>1,la)|0)+(Ga>>1))|0;mf[c[(c[(f+12444|0)>>2]|0)+16+((((Q&$)<<B)+(Ga&$)|0)<<2)>>2]&2047](ma,ja,la,8);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>1,la)|0)+(aa>>1))|0;mf[c[(c[(f+12448|0)>>2]|0)+16+((((ga&$)<<B)+(aa&$)|0)<<2)>>2]&2047](ma,ja,la,8)}else{ja=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(Q>>2,la)|0)+(Ga>>2))|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((Q&$)<<B)+(Ga&$)|0)<<2)>>2]&4095](ma,ja,la);ja=(c[(f+12352+(k<<4)+32|0)>>2]|0)+((ca(ga>>2,la)|0)+(aa>>2))|0;ef[c[(c[(f+12456|0)>>2]|0)+64+((((ga&$)<<B)+(aa&$)|0)<<2)>>2]&4095](ma,ja,la)}La=La+1|0;}while((La|0)<4)}}else{La=(c[f+12160>>2]|0)+(T<<B)|0;ja=(c[f+12164>>2]|0)+(S<<B)|0;ma=c[f+12128>>2]|0;if((T<<B|0)==0){ye=(ca(ma,Z-za|0)|0)/(za|0)|0}else{ye=La-ma|0}ma=c[f+12132>>2]|0;if((S<<B|0)==0){ze=(ca(ma,Z-za|0)|0)/(za|0)|0}else{ze=ja-ma|0}ma=((ze&$)<<B)+(ye&$)|0;if((p&1|0)==0){aa=(c[(f+12352+(k<<4)|0)>>2]|0)+((ca(ja>>1,la)|0)+(La>>1))|0;mf[c[(c[f+12444>>2]|0)+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&2047](c[(f+12208|0)>>2]|0,aa,la,16);aa=(c[f+12352+(k<<4)+32>>2]|0)+((ca(ze>>1,la)|0)+(ye>>1))|0;mf[c[(c[f+12448>>2]|0)+(ma<<2)>>2]&2047](c[(f+12208|0)>>2]|0,aa,la,16);break}else{aa=(ca(ja>>2,la)|0)+(La>>2)|0;ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)|0)>>2]|0)+aa|0,la);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(aa+8|0)|0,la);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(la<<3)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+(aa+(la<<3))|0,la);ef[c[(c[(f+12452|0)>>2]|0)+64+((((ja&$)<<B)+(La&$)|0)<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((la<<3)+8|0)|0,(c[(f+12352+(k<<4)|0)>>2]|0)+((aa+8|0)+(la<<3))|0,la);aa=(ca(ze>>2,la)|0)+(ye>>2)|0;ef[c[(c[(f+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](c[(f+12208|0)>>2]|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+aa|0,la);ef[c[(c[(f+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+8|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(aa+8|0)|0,la);ef[c[(c[(f+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+(la<<3)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+(aa+(la<<3))|0,la);ef[c[(c[(f+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095]((c[(f+12208|0)>>2]|0)+((la<<3)+8|0)|0,(c[(f+12352+(k<<4)+32|0)>>2]|0)+((aa+8|0)+(la<<3))|0,la);break}}}while(0);ve=Xe[_&511](f,c[f+12208>>2]|0,c[(f+12288+(j<<4)|0)>>2]|0,la,16)|0}}while(0);c[(O+(((S<<3)+T&63)<<2)|0)>>2]=(T+sa|0)+(S<<11)|0;c[Za+(((S<<3)+T&63)<<2)>>2]=ve;_=(ca((d[Fa+((S<<B)-Y)|0]|0)+(d[Fa+((T<<B)-ha)|0]|0)|0,C)|0)+ve|0;if((_|0)>=(pe|0)){Bb=pe;break}c[V>>2]=T;c[Wd>>2]=S;Bb=_}else{R=1}}}while(0);c[g>>2]=c[V>>2];c[h>>2]=c[q+4>>2];K=Bb;i=a;c[a+27640>>2]=6;c[a+27644>>2]=K|0;break a}while(0);c[a+27600>>2]=K}function _epzs_motion_search2$0(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0;b=c[a+16>>2]|0;f=c[a+24>>2]|0;g=c[a+32>>2]|0;h=c[a+48>>2]|0;j=c[a+56>>2]|0;k=c[a+72>>2]|0;l=c[a+80>>2]|0;m=c[a+168>>2]|0;n=c[a+184>>2]|0;o=c[a+6136>>2]|0;p=c[a+6144>>2]|0;q=c[a+6152>>2]|0;r=c[a+6160>>2]|0;s=c[a+6168>>2]|0;t=c[a+19096>>2]|0;u=c[a+19104>>2]|0;v=c[a+19112>>2]|0;w=c[a+19120>>2]|0;a:do{if((s|0)<2){x=c[(b+12220|0)>>2]|0;y=c[(b+12264|0)>>2]|0;z=c[(b+12272|0)>>2]|0;A=c[(b+12268|0)>>2]|0;B=c[(b+12276|0)>>2]|0;C=c[(b+12464|0)>>2]|0;D=c[(b+12280|0)>>2]|0;E=c[(b+12284|0)>>2]|0;F=c[(b+12216|0)>>2]|0;G=c[(b+12224|0)>>2]|0;H=c[(b+10468|0)>>2]|0;I=c[(b+10472|0)>>2]|0;J=p+G+(o<<11)|0;K=(o<<3)+p&63;if((c[(F+(K<<2)|0)>>2]|0)!=(J|0)){do{if((m&4|0)==0){L=c[b+12416>>2]|0;M=c[b+12420>>2]|0;N=(c[b+12352+(j<<4)>>2]|0)+((ca(L,o)|0)+p)|0;O=Xe[H&511](b,c[b+12288+(h<<4)>>2]|0,N,L,8)|0;if((m&2|0)==0){P=O;break}N=o<<1&2|p&1;Q=c[b+12208>>2]|0;R=(ca(M,o>>1)|0)+(p>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(N<<2)>>2]&2047](Q+(L<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+R|0,M,4);mf[c[(c[(b+12444|0)>>2]|0)+16+(N<<2)>>2]&2047](Q+(L<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+R|0,M,4);R=(Xe[I&511](b,Q+(L<<4)|0,c[b+12288+(h<<4)+4>>2]|0,M,4)|0)+O|0;P=R+(Xe[I&511](b,Q+(L<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,M,4)|0)|0}else{M=c[b+12416>>2]|0;L=p<<n;Q=o<<n;if((y|0)>(p|0)){P=536870912;break}if((L|0)>(A<<n|0)|(z|0)>(o|0)){P=536870912;break}if((Q|0)>(B<<n|0)){P=536870912;break}R=e[b+13872>>1]|0;O=e[b+13874>>1]|0;N=(m&1)<<1|1;b:do{if((c[b+11740>>2]|0)==1){if((L|0)==0){S=0;while(1){T=c[b+12160+(S<<3)>>2]|0;U=(c[b+12160+(S<<3)+4>>2]|0)+Q|0;V=((ca(c[b+12128+(S<<3)>>2]|0,O-R|0)|0)/(R|0)|0)+((S&1)<<(m&1|4))|0;W=c[b+12128+(S<<3)+4>>2]|0;if((Q|0)==0){X=S>>1;Y=((ca(W,O-R|0)|0)/(R|0)|0)+(X<<(m&1|4))|0;Z=X}else{Y=U-W|0;Z=S>>1}W=((Y&N)<<n)+(V&N)|0;X=(c[(b+12208|0)>>2]|0)+((ca(Z,M<<3)|0)+(S<<3&8))|0;if((m&1|0)==0){_=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,M)|0)+(T>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(T&N)|0)<<2)>>2]&2047](X,_,M,8);_=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Y>>1,M)|0)+(V>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(W<<2)>>2]&2047](X,_,M,8)}else{_=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,M)|0)+(T>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(T&N)|0)<<2)>>2]&4095](X,_,M);_=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Y>>2,M)|0)+(V>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](X,_,M)}S=S+1|0;if((S|0)>=4){break b}}}if((Q|0)==0){S=0;do{_=(c[b+12160+(S<<3)>>2]|0)+L|0;X=c[b+12160+(S<<3)+4>>2]|0;W=_-(c[b+12128+(S<<3)>>2]|0)|0;V=S>>1;T=((ca(c[b+12128+(S<<3)+4>>2]|0,O-R|0)|0)/(R|0)|0)+(V<<(m&1|4))|0;U=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ca(V,M<<3)|0))|0;if((m&1|0)==0){V=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(X>>1,M)|0)+(_>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((X&N)<<n)+(_&N)|0)<<2)>>2]&2047](U,V,M,8);V=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(T>>1,M)|0)+(W>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((T&N)<<n)+(W&N)|0)<<2)>>2]&2047](U,V,M,8)}else{V=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(X>>2,M)|0)+(_>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(_&N)|0)<<2)>>2]&4095](U,V,M);V=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(T>>2,M)|0)+(W>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((T&N)<<n)+(W&N)|0)<<2)>>2]&4095](U,V,M)}S=S+1|0;}while((S|0)<4)}else{S=0;do{V=(c[b+12160+(S<<3)>>2]|0)+L|0;U=(c[b+12160+(S<<3)+4>>2]|0)+Q|0;W=V-(c[b+12128+(S<<3)>>2]|0)|0;T=U-(c[b+12128+(S<<3)+4>>2]|0)|0;_=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ca(S>>1,M<<3)|0))|0;if((m&1|0)==0){X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,M)|0)+(V>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(V&N)|0)<<2)>>2]&2047](_,X,M,8);X=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(T>>1,M)|0)+(W>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((T&N)<<n)+(W&N)|0)<<2)>>2]&2047](_,X,M,8)}else{X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,M)|0)+(V>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(V&N)|0)<<2)>>2]&4095](_,X,M);X=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(T>>2,M)|0)+(W>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((T&N)<<n)+(W&N)|0)<<2)>>2]&4095](_,X,M)}S=S+1|0;}while((S|0)<4)}}else{S=(c[b+12160>>2]|0)+L|0;X=(c[b+12164>>2]|0)+Q|0;_=c[b+12128>>2]|0;if((L|0)==0){$=(ca(_,O-R|0)|0)/(R|0)|0}else{$=S-_|0}_=c[b+12132>>2]|0;if((Q|0)==0){aa=(ca(_,O-R|0)|0)/(R|0)|0}else{aa=X-_|0}_=((aa&N)<<n)+($&N)|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(X>>1,M)|0)+(S>>1))|0;mf[c[(c[b+12444>>2]|0)+((((X&N)<<n)+(S&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,W,M,16);W=(c[b+12352+(j<<4)+32>>2]|0)+((ca(aa>>1,M)|0)+($>>1))|0;mf[c[(c[b+12448>>2]|0)+(_<<2)>>2]&2047](c[(b+12208|0)>>2]|0,W,M,16);break}else{W=(ca(X>>2,M)|0)+(S>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+W|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(W+8|0)|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(W+(M<<3))|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((W+8|0)+(M<<3))|0,M);W=(ca(aa>>2,M)|0)+($>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+W|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(W+8|0)|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(W+(M<<3))|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((W+8|0)+(M<<3))|0,M);break}}}while(0);P=Xe[H&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,M,16)|0}}while(0);c[x+(K<<2)>>2]=P;c[(F+(K<<2)|0)>>2]=J}N=(m&1)<<1|1;R=m&1|4;O=(m&1|0)==0;Q=q;L=-1;W=p;_=o;c:while(1){do{if((L|0)!=2&(W|0)>(y|0)){S=W-1|0;X=S+G+(_<<11)|0;T=(_<<3)+S&63;if((c[(F+(T<<2)|0)>>2]|0)==(X|0)){ba=Q;da=-1;ea=W;break}V=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){U=c[(b+12420|0)>>2]|0;fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(V,_)|0)+S)|0;ga=Xe[H&511](b,c[(b+12288+(h<<4)|0)>>2]|0,fa,V,8)|0;if((m&2|0)==0){ha=ga;break}fa=_<<1&2|S&1;ia=c[(b+12208|0)>>2]|0;ja=(ca(U,_>>1)|0)+(S>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(fa<<2)>>2]&2047](ia+(V<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ja|0,U,4);mf[c[(c[(b+12444|0)>>2]|0)+16+(fa<<2)>>2]&2047](ia+(V<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ja|0,U,4);ja=(Xe[I&511](b,ia+(V<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,U,4)|0)+ga|0;ha=ja+(Xe[I&511](b,ia+(V<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,U,4)|0)|0}else{U=_<<n;if((c[(b+12264|0)>>2]|0)>(S|0)){ha=536870912;break}if((S<<n|0)>(c[(b+12268|0)>>2]<<n|0)){ha=536870912;break}if((c[(b+12272|0)>>2]|0)>(_|0)){ha=536870912;break}if((U|0)>(c[(b+12276|0)>>2]<<n|0)){ha=536870912;break}ia=e[(b+13872|0)>>1]|0;ja=e[(b+13874|0)>>1]|0;d:do{if((c[(b+11740|0)>>2]|0)==1){if((S<<n|0)==0){ga=0;while(1){fa=c[b+12160+(ga<<3)>>2]|0;ka=(c[b+12160+(ga<<3)+4>>2]|0)+U|0;la=((ca(c[b+12128+(ga<<3)>>2]|0,ja-ia|0)|0)/(ia|0)|0)+((ga&1)<<R)|0;ma=c[b+12128+(ga<<3)+4>>2]|0;if((U|0)==0){na=ga>>1;oa=((ca(ma,ja-ia|0)|0)/(ia|0)|0)+(na<<R)|0;pa=na}else{oa=ka-ma|0;pa=ga>>1}ma=((oa&N)<<n)+(la&N)|0;na=(c[(b+12208|0)>>2]|0)+((ca(pa,V<<3)|0)+(ga<<3&8))|0;if(O){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,V)|0)+(fa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&N)<<n)+(fa&N)|0)<<2)>>2]&2047](na,qa,V,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(oa>>1,V)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ma<<2)>>2]&2047](na,qa,V,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>2,V)|0)+(fa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&N)<<n)+(fa&N)|0)<<2)>>2]&4095](na,qa,V);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(oa>>2,V)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](na,qa,V)}ga=ga+1|0;if((ga|0)>=4){break d}}}if((U|0)==0){ga=0;do{qa=(c[b+12160+(ga<<3)>>2]|0)+(S<<n)|0;na=c[b+12160+(ga<<3)+4>>2]|0;ma=qa-(c[b+12128+(ga<<3)>>2]|0)|0;la=ga>>1;fa=((ca(c[b+12128+(ga<<3)+4>>2]|0,ja-ia|0)|0)/(ia|0)|0)+(la<<R)|0;ka=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(la,V<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,V)|0)+(qa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((na&N)<<n)+(qa&N)|0)<<2)>>2]&2047](ka,la,V,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(fa>>1,V)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&2047](ka,la,V,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>2,V)|0)+(qa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(qa&N)|0)<<2)>>2]&4095](ka,la,V);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(fa>>2,V)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](ka,la,V)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{la=(c[b+12160+(ga<<3)>>2]|0)+(S<<n)|0;ka=(c[b+12160+(ga<<3)+4>>2]|0)+U|0;ma=la-(c[b+12128+(ga<<3)>>2]|0)|0;fa=ka-(c[b+12128+(ga<<3)+4>>2]|0)|0;qa=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(ga>>1,V<<3)|0))|0;if(O){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,V)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&N)<<n)+(la&N)|0)<<2)>>2]&2047](qa,na,V,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(fa>>1,V)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&2047](qa,na,V,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>2,V)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&N)<<n)+(la&N)|0)<<2)>>2]&4095](qa,na,V);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(fa>>2,V)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](qa,na,V)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+(S<<n)|0;na=(c[(b+12164|0)>>2]|0)+U|0;qa=c[(b+12128|0)>>2]|0;if((S<<n|0)==0){ra=(ca(qa,ja-ia|0)|0)/(ia|0)|0}else{ra=ga-qa|0}qa=c[(b+12132|0)>>2]|0;if((U|0)==0){sa=(ca(qa,ja-ia|0)|0)/(ia|0)|0}else{sa=na-qa|0}qa=((sa&N)<<n)+(ra&N)|0;if(O){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,V)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ma,V,16);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(sa>>1,V)|0)+(ra>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(qa<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ma,V,16);break}else{ma=(ca(na>>2,V)|0)+(ga>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ma|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+8|0)|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+(V<<3))|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ma+8|0)+(V<<3))|0,V);ma=(ca(sa>>2,V)|0)+(ra>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ma|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+8|0)|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+(V<<3))|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ma+8|0)+(V<<3))|0,V);break}}}while(0);ha=Xe[H&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,V,16)|0}}while(0);c[(F+(T<<2)|0)>>2]=X;c[x+(T<<2)>>2]=ha;V=(ca((d[C+((_<<n)-E)|0]|0)+(d[C+((S<<n)-D)|0]|0)|0,l)|0)+ha|0;if((V|0)>=(Q|0)){ba=Q;da=-1;ea=W;break}c[r>>2]=S;c[(r+4|0)>>2]=_;ba=V;da=0;ea=S}else{ba=Q;da=-1;ea=W}}while(0);do{if((L|0)!=3&(_|0)>(z|0)){M=_-1|0;V=W+G+(M<<11)|0;ia=(M<<3)+W&63;if((c[(F+(ia<<2)|0)>>2]|0)==(V|0)){ta=ba;ua=da;va=ea;wa=_;break}ja=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){U=c[(b+12420|0)>>2]|0;ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja,M)|0)+W)|0;qa=Xe[H&511](b,c[(b+12288+(h<<4)|0)>>2]|0,ma,ja,8)|0;if((m&2|0)==0){xa=qa;break}ma=M<<1&2|W&1;ga=c[(b+12208|0)>>2]|0;na=(ca(U,M>>1)|0)+(W>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(ma<<2)>>2]&2047](ga+(ja<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+na|0,U,4);mf[c[(c[(b+12444|0)>>2]|0)+16+(ma<<2)>>2]&2047](ga+(ja<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+na|0,U,4);na=(Xe[I&511](b,ga+(ja<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,U,4)|0)+qa|0;xa=na+(Xe[I&511](b,ga+(ja<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,U,4)|0)|0}else{U=W<<n;if((c[(b+12264|0)>>2]|0)>(W|0)){xa=536870912;break}if((U|0)>(c[(b+12268|0)>>2]<<n|0)){xa=536870912;break}if((c[(b+12272|0)>>2]|0)>(M|0)){xa=536870912;break}if((M<<n|0)>(c[(b+12276|0)>>2]<<n|0)){xa=536870912;break}ga=e[(b+13872|0)>>1]|0;na=e[(b+13874|0)>>1]|0;e:do{if((c[(b+11740|0)>>2]|0)==1){if((U|0)==0){qa=0;while(1){ma=c[b+12160+(qa<<3)>>2]|0;fa=(c[b+12160+(qa<<3)+4>>2]|0)+(M<<n)|0;la=((ca(c[b+12128+(qa<<3)>>2]|0,na-ga|0)|0)/(ga|0)|0)+((qa&1)<<R)|0;ka=c[b+12128+(qa<<3)+4>>2]|0;if((M<<n|0)==0){ya=qa>>1;za=((ca(ka,na-ga|0)|0)/(ga|0)|0)+(ya<<R)|0;Aa=ya}else{za=fa-ka|0;Aa=qa>>1}ka=((za&N)<<n)+(la&N)|0;ya=(c[(b+12208|0)>>2]|0)+((ca(Aa,ja<<3)|0)+(qa<<3&8))|0;if(O){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>1,ja)|0)+(ma>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&2047](ya,Ba,ja,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(za>>1,ja)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&2047](ya,Ba,ja,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>2,ja)|0)+(ma>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](ya,Ba,ja);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(za>>2,ja)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](ya,Ba,ja)}qa=qa+1|0;if((qa|0)>=4){break e}}}if((M<<n|0)==0){qa=0;do{Ba=(c[b+12160+(qa<<3)>>2]|0)+U|0;ya=c[b+12160+(qa<<3)+4>>2]|0;ka=Ba-(c[b+12128+(qa<<3)>>2]|0)|0;la=qa>>1;ma=((ca(c[b+12128+(qa<<3)+4>>2]|0,na-ga|0)|0)/(ga|0)|0)+(la<<R)|0;fa=(c[(b+12208|0)>>2]|0)+((qa<<3&8)+(ca(la,ja<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,ja)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&N)<<n)+(Ba&N)|0)<<2)>>2]&2047](fa,la,ja,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ma>>1,ja)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&2047](fa,la,ja,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>2,ja)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(Ba&N)|0)<<2)>>2]&4095](fa,la,ja);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ma>>2,ja)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&4095](fa,la,ja)}qa=qa+1|0;}while((qa|0)<4)}else{qa=0;do{la=(c[b+12160+(qa<<3)>>2]|0)+U|0;fa=(c[b+12160+(qa<<3)+4>>2]|0)+(M<<n)|0;ka=la-(c[b+12128+(qa<<3)>>2]|0)|0;ma=fa-(c[b+12128+(qa<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((qa<<3&8)+(ca(qa>>1,ja<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>1,ja)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&N)<<n)+(la&N)|0)<<2)>>2]&2047](Ba,ya,ja,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ma>>1,ja)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&2047](Ba,ya,ja,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>2,ja)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((fa&N)<<n)+(la&N)|0)<<2)>>2]&4095](Ba,ya,ja);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ma>>2,ja)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&4095](Ba,ya,ja)}qa=qa+1|0;}while((qa|0)<4)}}else{qa=(c[(b+12160|0)>>2]|0)+U|0;ya=(c[(b+12164|0)>>2]|0)+(M<<n)|0;Ba=c[(b+12128|0)>>2]|0;if((U|0)==0){Ca=(ca(Ba,na-ga|0)|0)/(ga|0)|0}else{Ca=qa-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((M<<n|0)==0){Da=(ca(Ba,na-ga|0)|0)/(ga|0)|0}else{Da=ya-Ba|0}Ba=((Da&N)<<n)+(Ca&N)|0;if(O){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,ja)|0)+(qa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,ja,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Da>>1,ja)|0)+(Ca>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,ja,16);break}else{ka=(ca(ya>>2,ja)|0)+(qa>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,ja);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,ja);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ja<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(ja<<3))|0,ja);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(ja<<3))|0,ja);ka=(ca(Da>>2,ja)|0)+(Ca>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,ja);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,ja);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ja<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(ja<<3))|0,ja);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(ja<<3))|0,ja);break}}}while(0);xa=Xe[H&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ja,16)|0}}while(0);c[(F+(ia<<2)|0)>>2]=V;c[x+(ia<<2)>>2]=xa;ja=(ca((d[C+((M<<n)-E)|0]|0)+(d[C+((W<<n)-D)|0]|0)|0,l)|0)+xa|0;if((ja|0)>=(ba|0)){ta=ba;ua=da;va=ea;wa=_;break}c[r>>2]=W;c[(r+4|0)>>2]=M;ta=ja;ua=1;va=W;wa=M}else{ta=ba;ua=da;va=ea;wa=_}}while(0);do{if((L|0)!=0&(W|0)<(A|0)){ja=W+1|0;S=ja+G+(_<<11)|0;T=(_<<3)+ja&63;if((c[(F+(T<<2)|0)>>2]|0)==(S|0)){Ea=ta;Fa=ua;Ga=va;Ha=wa;break}X=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ga=c[(b+12420|0)>>2]|0;na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(X,_)|0)+ja)|0;U=Xe[H&511](b,c[(b+12288+(h<<4)|0)>>2]|0,na,X,8)|0;if((m&2|0)==0){Ia=U;break}na=_<<1&2|ja&1;ka=c[(b+12208|0)>>2]|0;Ba=(ca(ga,_>>1)|0)+(ja>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(na<<2)>>2]&2047](ka+(X<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+Ba|0,ga,4);mf[c[(c[(b+12444|0)>>2]|0)+16+(na<<2)>>2]&2047](ka+(X<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+Ba|0,ga,4);Ba=(Xe[I&511](b,ka+(X<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ga,4)|0)+U|0;Ia=Ba+(Xe[I&511](b,ka+(X<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ga,4)|0)|0}else{ga=_<<n;if((c[(b+12264|0)>>2]|0)>(ja|0)){Ia=536870912;break}if((ja<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Ia=536870912;break}if((c[(b+12272|0)>>2]|0)>(_|0)){Ia=536870912;break}if((ga|0)>(c[(b+12276|0)>>2]<<n|0)){Ia=536870912;break}ka=e[(b+13872|0)>>1]|0;Ba=e[(b+13874|0)>>1]|0;f:do{if((c[(b+11740|0)>>2]|0)==1){if((ja<<n|0)==0){U=0;while(1){na=c[b+12160+(U<<3)>>2]|0;qa=(c[b+12160+(U<<3)+4>>2]|0)+ga|0;ya=((ca(c[b+12128+(U<<3)>>2]|0,Ba-ka|0)|0)/(ka|0)|0)+((U&1)<<R)|0;ma=c[b+12128+(U<<3)+4>>2]|0;if((ga|0)==0){la=U>>1;Ja=((ca(ma,Ba-ka|0)|0)/(ka|0)|0)+(la<<R)|0;Ka=la}else{Ja=qa-ma|0;Ka=U>>1}ma=((Ja&N)<<n)+(ya&N)|0;la=(c[(b+12208|0)>>2]|0)+((ca(Ka,X<<3)|0)+(U<<3&8))|0;if(O){fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa>>1,X)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((qa&N)<<n)+(na&N)|0)<<2)>>2]&2047](la,fa,X,8);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ja>>1,X)|0)+(ya>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ma<<2)>>2]&2047](la,fa,X,8)}else{fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa>>2,X)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((qa&N)<<n)+(na&N)|0)<<2)>>2]&4095](la,fa,X);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ja>>2,X)|0)+(ya>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](la,fa,X)}U=U+1|0;if((U|0)>=4){break f}}}if((ga|0)==0){U=0;do{fa=(c[b+12160+(U<<3)>>2]|0)+(ja<<n)|0;la=c[b+12160+(U<<3)+4>>2]|0;ma=fa-(c[b+12128+(U<<3)>>2]|0)|0;ya=U>>1;na=((ca(c[b+12128+(U<<3)+4>>2]|0,Ba-ka|0)|0)/(ka|0)|0)+(ya<<R)|0;qa=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(ya,X<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(la>>1,X)|0)+(fa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((la&N)<<n)+(fa&N)|0)<<2)>>2]&2047](qa,ya,X,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>1,X)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&2047](qa,ya,X,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(la>>2,X)|0)+(fa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(fa&N)|0)<<2)>>2]&4095](qa,ya,X);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>2,X)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&4095](qa,ya,X)}U=U+1|0;}while((U|0)<4)}else{U=0;do{ya=(c[b+12160+(U<<3)>>2]|0)+(ja<<n)|0;qa=(c[b+12160+(U<<3)+4>>2]|0)+ga|0;ma=ya-(c[b+12128+(U<<3)>>2]|0)|0;na=qa-(c[b+12128+(U<<3)+4>>2]|0)|0;fa=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(U>>1,X<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa>>1,X)|0)+(ya>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((qa&N)<<n)+(ya&N)|0)<<2)>>2]&2047](fa,la,X,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>1,X)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&2047](fa,la,X,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa>>2,X)|0)+(ya>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((qa&N)<<n)+(ya&N)|0)<<2)>>2]&4095](fa,la,X);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>2,X)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&4095](fa,la,X)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(ja<<n)|0;la=(c[(b+12164|0)>>2]|0)+ga|0;fa=c[(b+12128|0)>>2]|0;if((ja<<n|0)==0){La=(ca(fa,Ba-ka|0)|0)/(ka|0)|0}else{La=U-fa|0}fa=c[(b+12132|0)>>2]|0;if((ga|0)==0){Ma=(ca(fa,Ba-ka|0)|0)/(ka|0)|0}else{Ma=la-fa|0}fa=((Ma&N)<<n)+(La&N)|0;if(O){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(la>>1,X)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((la&N)<<n)+(U&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ma,X,16);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ma>>1,X)|0)+(La>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(fa<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ma,X,16);break}else{ma=(ca(la>>2,X)|0)+(U>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ma|0,X);ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+8|0)|0,X);ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(X<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+(X<<3))|0,X);ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((X<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ma+8|0)+(X<<3))|0,X);ma=(ca(Ma>>2,X)|0)+(La>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ma|0,X);ef[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+8|0)|0,X);ef[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(X<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+(X<<3))|0,X);ef[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((X<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ma+8|0)+(X<<3))|0,X);break}}}while(0);Ia=Xe[H&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,X,16)|0}}while(0);c[(F+(T<<2)|0)>>2]=S;c[x+(T<<2)>>2]=Ia;X=(ca((d[C+((_<<n)-E)|0]|0)+(d[C+((ja<<n)-D)|0]|0)|0,l)|0)+Ia|0;if((X|0)>=(ta|0)){Ea=ta;Fa=ua;Ga=va;Ha=wa;break}c[r>>2]=ja;c[(r+4|0)>>2]=_;Ea=X;Fa=2;Ga=ja;Ha=_}else{Ea=ta;Fa=ua;Ga=va;Ha=wa}}while(0);do{if((L|0)!=1&(_|0)<(B|0)){X=_+1|0;M=W+G+(X<<11)|0;ia=(X<<3)+W&63;if((c[(F+(ia<<2)|0)>>2]|0)==(M|0)){break}V=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ka=c[(b+12420|0)>>2]|0;Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(V,X)|0)+W)|0;ga=Xe[H&511](b,c[(b+12288+(h<<4)|0)>>2]|0,Ba,V,8)|0;if((m&2|0)==0){Na=ga;break}Ba=X<<1&2|W&1;ma=c[(b+12208|0)>>2]|0;fa=(ca(ka,X>>1)|0)+(W>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(Ba<<2)>>2]&2047](ma+(V<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+fa|0,ka,4);mf[c[(c[(b+12444|0)>>2]|0)+16+(Ba<<2)>>2]&2047](ma+(V<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+fa|0,ka,4);fa=(Xe[I&511](b,ma+(V<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ka,4)|0)+ga|0;Na=fa+(Xe[I&511](b,ma+(V<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ka,4)|0)|0}else{ka=W<<n;if((c[(b+12264|0)>>2]|0)>(W|0)){Na=536870912;break}if((ka|0)>(c[(b+12268|0)>>2]<<n|0)){Na=536870912;break}if((c[(b+12272|0)>>2]|0)>(X|0)){Na=536870912;break}if((X<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Na=536870912;break}ma=e[(b+13872|0)>>1]|0;fa=e[(b+13874|0)>>1]|0;g:do{if((c[(b+11740|0)>>2]|0)==1){if((ka|0)==0){ga=0;while(1){Ba=c[b+12160+(ga<<3)>>2]|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(X<<n)|0;la=((ca(c[b+12128+(ga<<3)>>2]|0,fa-ma|0)|0)/(ma|0)|0)+((ga&1)<<R)|0;na=c[b+12128+(ga<<3)+4>>2]|0;if((X<<n|0)==0){ya=ga>>1;Oa=((ca(na,fa-ma|0)|0)/(ma|0)|0)+(ya<<R)|0;Pa=ya}else{Oa=U-na|0;Pa=ga>>1}na=((Oa&N)<<n)+(la&N)|0;ya=(c[(b+12208|0)>>2]|0)+((ca(Pa,V<<3)|0)+(ga<<3&8))|0;if(O){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,V)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(Ba&N)|0)<<2)>>2]&2047](ya,qa,V,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Oa>>1,V)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(na<<2)>>2]&2047](ya,qa,V,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,V)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(Ba&N)|0)<<2)>>2]&4095](ya,qa,V);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Oa>>2,V)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](ya,qa,V)}ga=ga+1|0;if((ga|0)>=4){break g}}}if((X<<n|0)==0){ga=0;do{qa=(c[b+12160+(ga<<3)>>2]|0)+ka|0;ya=c[b+12160+(ga<<3)+4>>2]|0;na=qa-(c[b+12128+(ga<<3)>>2]|0)|0;la=ga>>1;Ba=((ca(c[b+12128+(ga<<3)+4>>2]|0,fa-ma|0)|0)/(ma|0)|0)+(la<<R)|0;U=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(la,V<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,V)|0)+(qa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&2047](U,la,V,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ba>>1,V)|0)+(na>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&2047](U,la,V,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>2,V)|0)+(qa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095](U,la,V);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ba>>2,V)|0)+(na>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&4095](U,la,V)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{la=(c[b+12160+(ga<<3)>>2]|0)+ka|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(X<<n)|0;na=la-(c[b+12128+(ga<<3)>>2]|0)|0;Ba=U-(c[b+12128+(ga<<3)+4>>2]|0)|0;qa=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(ga>>1,V<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,V)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(la&N)|0)<<2)>>2]&2047](qa,ya,V,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ba>>1,V)|0)+(na>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&2047](qa,ya,V,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,V)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(la&N)|0)<<2)>>2]&4095](qa,ya,V);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ba>>2,V)|0)+(na>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&4095](qa,ya,V)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+ka|0;ya=(c[(b+12164|0)>>2]|0)+(X<<n)|0;qa=c[(b+12128|0)>>2]|0;if((ka|0)==0){Qa=(ca(qa,fa-ma|0)|0)/(ma|0)|0}else{Qa=ga-qa|0}qa=c[(b+12132|0)>>2]|0;if((X<<n|0)==0){Ra=(ca(qa,fa-ma|0)|0)/(ma|0)|0}else{Ra=ya-qa|0}qa=((Ra&N)<<n)+(Qa&N)|0;if(O){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,V)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,na,V,16);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ra>>1,V)|0)+(Qa>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(qa<<2)>>2]&2047](c[(b+12208|0)>>2]|0,na,V,16);break}else{na=(ca(ya>>2,V)|0)+(ga>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+na|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(na+8|0)|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(na+(V<<3))|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((na+8|0)+(V<<3))|0,V);na=(ca(Ra>>2,V)|0)+(Qa>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+na|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(na+8|0)|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(na+(V<<3))|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((na+8|0)+(V<<3))|0,V);break}}}while(0);Na=Xe[H&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,V,16)|0}}while(0);c[(F+(ia<<2)|0)>>2]=M;c[x+(ia<<2)>>2]=Na;V=(ca((d[C+((X<<n)-E)|0]|0)+(d[C+((W<<n)-D)|0]|0)|0,l)|0)+Na|0;if((V|0)>=(Ea|0)){break}c[r>>2]=W;c[(r+4|0)>>2]=X;Q=V;L=3;W=W;_=X;continue c}}while(0);if((Fa|0)==-1){t=Ea;break}else{Q=Ea;L=Fa;W=Ga;_=Ha}}u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}if((s|0)>1024){t=urb(b,r,q,h,j,l,0,8,m)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}if((s|0)>768){_=c[(b+12220|0)>>2]|0;W=c[(b+12264|0)>>2]|0;L=c[(b+12272|0)>>2]|0;Q=c[(b+12268|0)>>2]|0;D=c[(b+12276|0)>>2]|0;C=c[(b+12464|0)>>2]|0;E=c[(b+12280|0)>>2]|0;x=c[(b+12284|0)>>2]|0;F=c[(b+12216|0)>>2]|0;H=c[(b+12224|0)>>2]|0;N=c[(b+10468|0)>>2]|0;O=c[(b+10472|0)>>2]|0;R=p-(s&254)+1|0;I=(R|0)>(W|0)?R:W;R=(s&254)-1+p|0;G=(R|0)>(Q|0)?Q:R;if((I|0)>(G|0)){Sa=q;Ta=p;Ua=o}else{R=(o<<11)+H|0;B=o<<3;A=o<<1&2;z=o>>1;y=o<<n;J=(m&1)<<1|1;K=I;I=q;V=p;ja=o;while(1){T=R+K|0;S=K+B&63;do{if((c[(F+(S<<2)|0)>>2]|0)==(T|0)){Va=I;Wa=V;Xa=ja}else{ma=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){fa=c[(b+12420|0)>>2]|0;ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma,o)|0)+K)|0;na=Xe[N&511](b,c[(b+12288+(h<<4)|0)>>2]|0,ka,ma,8)|0;if((m&2|0)==0){Ya=na;break}ka=K&1|A;qa=c[(b+12208|0)>>2]|0;ga=(ca(fa,z)|0)+(K>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(ka<<2)>>2]&2047](qa+(ma<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ga|0,fa,4);mf[c[(c[(b+12444|0)>>2]|0)+16+(ka<<2)>>2]&2047](qa+(ma<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ga|0,fa,4);ga=(Xe[O&511](b,qa+(ma<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,fa,4)|0)+na|0;Ya=ga+(Xe[O&511](b,qa+(ma<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,fa,4)|0)|0}else{fa=K<<n;if((c[(b+12264|0)>>2]|0)>(K|0)){Ya=536870912;break}if((fa|0)>(c[(b+12268|0)>>2]<<n|0)){Ya=536870912;break}if((c[(b+12272|0)>>2]|0)>(o|0)){Ya=536870912;break}if((y|0)>(c[(b+12276|0)>>2]<<n|0)){Ya=536870912;break}qa=e[(b+13872|0)>>1]|0;ga=e[(b+13874|0)>>1]|0;h:do{if((c[(b+11740|0)>>2]|0)==1){if((fa|0)==0){na=0;while(1){ka=c[b+12160+(na<<3)>>2]|0;ya=(c[b+12160+(na<<3)+4>>2]|0)+y|0;Ba=((ca(c[b+12128+(na<<3)>>2]|0,ga-qa|0)|0)/(qa|0)|0)+((na&1)<<(m&1|4))|0;la=c[b+12128+(na<<3)+4>>2]|0;if((y|0)==0){U=na>>1;Za=((ca(la,ga-qa|0)|0)/(qa|0)|0)+(U<<(m&1|4))|0;_a=U}else{Za=ya-la|0;_a=na>>1}la=((Za&J)<<n)+(Ba&J)|0;U=(c[(b+12208|0)>>2]|0)+((ca(_a,ma<<3)|0)+(na<<3&8))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,ma)|0)+(ka>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&J)<<n)+(ka&J)|0)<<2)>>2]&2047](U,$a,ma,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Za>>1,ma)|0)+(Ba>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&2047](U,$a,ma,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>2,ma)|0)+(ka>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&J)<<n)+(ka&J)|0)<<2)>>2]&4095](U,$a,ma);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Za>>2,ma)|0)+(Ba>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](U,$a,ma)}na=na+1|0;if((na|0)>=4){break h}}}if((y|0)==0){na=0;do{$a=(c[b+12160+(na<<3)>>2]|0)+fa|0;U=c[b+12160+(na<<3)+4>>2]|0;la=$a-(c[b+12128+(na<<3)>>2]|0)|0;Ba=na>>1;ka=((ca(c[b+12128+(na<<3)+4>>2]|0,ga-qa|0)|0)/(qa|0)|0)+(Ba<<(m&1|4))|0;ya=(c[(b+12208|0)>>2]|0)+((na<<3&8)+(ca(Ba,ma<<3)|0))|0;if((m&1|0)==0){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,ma)|0)+($a>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&J)<<n)+($a&J)|0)<<2)>>2]&2047](ya,Ba,ma,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,ma)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&2047](ya,Ba,ma,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,ma)|0)+($a>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+($a&J)|0)<<2)>>2]&4095](ya,Ba,ma);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,ma)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&4095](ya,Ba,ma)}na=na+1|0;}while((na|0)<4)}else{na=0;do{Ba=(c[b+12160+(na<<3)>>2]|0)+fa|0;ya=(c[b+12160+(na<<3)+4>>2]|0)+y|0;la=Ba-(c[b+12128+(na<<3)>>2]|0)|0;ka=ya-(c[b+12128+(na<<3)+4>>2]|0)|0;$a=(c[(b+12208|0)>>2]|0)+((na<<3&8)+(ca(na>>1,ma<<3)|0))|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,ma)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&J)<<n)+(Ba&J)|0)<<2)>>2]&2047]($a,U,ma,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,ma)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&2047]($a,U,ma,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>2,ma)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&J)<<n)+(Ba&J)|0)<<2)>>2]&4095]($a,U,ma);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,ma)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&4095]($a,U,ma)}na=na+1|0;}while((na|0)<4)}}else{na=(c[(b+12160|0)>>2]|0)+fa|0;U=(c[(b+12164|0)>>2]|0)+y|0;$a=c[(b+12128|0)>>2]|0;if((fa|0)==0){ab=(ca($a,ga-qa|0)|0)/(qa|0)|0}else{ab=na-$a|0}$a=c[(b+12132|0)>>2]|0;if((y|0)==0){bb=(ca($a,ga-qa|0)|0)/(qa|0)|0}else{bb=U-$a|0}$a=((bb&J)<<n)+(ab&J)|0;if((m&1|0)==0){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,ma)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((U&J)<<n)+(na&J)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,ma,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(bb>>1,ma)|0)+(ab>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+($a<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,ma,16);break}else{la=(ca(U>>2,ma)|0)+(na>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(ma<<3))|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(ma<<3))|0,ma);la=(ca(bb>>2,ma)|0)+(ab>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(ma<<3))|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(ma<<3))|0,ma);break}}}while(0);Ya=Xe[N&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(S<<2)|0)>>2]=T;c[_+(S<<2)>>2]=Ya;ma=(ca((d[C+(y-x)|0]|0)+(d[C+((K<<n)-E)|0]|0)|0,l)|0)+Ya|0;if((ma|0)>=(I|0)){Va=I;Wa=V;Xa=ja;break}c[r>>2]=K;c[(r+4|0)>>2]=o;Va=ma;Wa=K;Xa=o}}while(0);S=K+2|0;if((S|0)>(G|0)){Sa=Va;Ta=Wa;Ua=Xa;break}else{K=S;I=Va;V=Wa;ja=Xa}}}ja=o-((s&254)>>>1)+1|0;V=(ja|0)>(L|0)?ja:L;ja=((s&254)>>>1)-1+o|0;I=(ja|0)>(D|0)?D:ja;if((V|0)>(I|0)){cb=Sa;db=Ta;eb=Ua}else{ja=p+H|0;K=p&1;G=p>>1;y=p<<n;J=(m&1)<<1|1;z=V;V=Sa;A=Ta;B=Ua;while(1){R=ja+(z<<11)|0;S=(z<<3)+p&63;do{if((c[(F+(S<<2)|0)>>2]|0)==(R|0)){fb=V;gb=A;hb=B}else{T=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ma=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(T,z)|0)+p)|0;ia=Xe[N&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,T,8)|0;if((m&2|0)==0){ib=ia;break}X=z<<1&2|K;M=c[(b+12208|0)>>2]|0;qa=(ca(ma,z>>1)|0)+G|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(X<<2)>>2]&2047](M+(T<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+qa|0,ma,4);mf[c[(c[(b+12444|0)>>2]|0)+16+(X<<2)>>2]&2047](M+(T<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+qa|0,ma,4);qa=(Xe[O&511](b,M+(T<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ma,4)|0)+ia|0;ib=qa+(Xe[O&511](b,M+(T<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ma,4)|0)|0}else{ma=z<<n;if((c[(b+12264|0)>>2]|0)>(p|0)){ib=536870912;break}if((y|0)>(c[(b+12268|0)>>2]<<n|0)){ib=536870912;break}if((c[(b+12272|0)>>2]|0)>(z|0)){ib=536870912;break}if((ma|0)>(c[(b+12276|0)>>2]<<n|0)){ib=536870912;break}M=e[(b+13872|0)>>1]|0;qa=e[(b+13874|0)>>1]|0;i:do{if((c[(b+11740|0)>>2]|0)==1){if((y|0)==0){ia=0;while(1){X=c[b+12160+(ia<<3)>>2]|0;ga=(c[b+12160+(ia<<3)+4>>2]|0)+ma|0;fa=((ca(c[b+12128+(ia<<3)>>2]|0,qa-M|0)|0)/(M|0)|0)+((ia&1)<<(m&1|4))|0;la=c[b+12128+(ia<<3)+4>>2]|0;if((ma|0)==0){$a=ia>>1;jb=((ca(la,qa-M|0)|0)/(M|0)|0)+($a<<(m&1|4))|0;kb=$a}else{jb=ga-la|0;kb=ia>>1}la=((jb&J)<<n)+(fa&J)|0;$a=(c[(b+12208|0)>>2]|0)+((ca(kb,T<<3)|0)+(ia<<3&8))|0;if((m&1|0)==0){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,T)|0)+(X>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&J)<<n)+(X&J)|0)<<2)>>2]&2047]($a,na,T,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(jb>>1,T)|0)+(fa>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&2047]($a,na,T,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,T)|0)+(X>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&J)<<n)+(X&J)|0)<<2)>>2]&4095]($a,na,T);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(jb>>2,T)|0)+(fa>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]($a,na,T)}ia=ia+1|0;if((ia|0)>=4){break i}}}if((ma|0)==0){ia=0;do{na=(c[b+12160+(ia<<3)>>2]|0)+y|0;$a=c[b+12160+(ia<<3)+4>>2]|0;la=na-(c[b+12128+(ia<<3)>>2]|0)|0;fa=ia>>1;X=((ca(c[b+12128+(ia<<3)+4>>2]|0,qa-M|0)|0)/(M|0)|0)+(fa<<(m&1|4))|0;ga=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ca(fa,T<<3)|0))|0;if((m&1|0)==0){fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>1,T)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(((($a&J)<<n)+(na&J)|0)<<2)>>2]&2047](ga,fa,T,8);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>1,T)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((X&J)<<n)+(la&J)|0)<<2)>>2]&2047](ga,fa,T,8)}else{fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>2,T)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(na&J)|0)<<2)>>2]&4095](ga,fa,T);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>2,T)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((X&J)<<n)+(la&J)|0)<<2)>>2]&4095](ga,fa,T)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{fa=(c[b+12160+(ia<<3)>>2]|0)+y|0;ga=(c[b+12160+(ia<<3)+4>>2]|0)+ma|0;la=fa-(c[b+12128+(ia<<3)>>2]|0)|0;X=ga-(c[b+12128+(ia<<3)+4>>2]|0)|0;na=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ca(ia>>1,T<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,T)|0)+(fa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&J)<<n)+(fa&J)|0)<<2)>>2]&2047](na,$a,T,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>1,T)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((X&J)<<n)+(la&J)|0)<<2)>>2]&2047](na,$a,T,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,T)|0)+(fa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&J)<<n)+(fa&J)|0)<<2)>>2]&4095](na,$a,T);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>2,T)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((X&J)<<n)+(la&J)|0)<<2)>>2]&4095](na,$a,T)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[(b+12160|0)>>2]|0)+y|0;$a=(c[(b+12164|0)>>2]|0)+ma|0;na=c[(b+12128|0)>>2]|0;if((y|0)==0){lb=(ca(na,qa-M|0)|0)/(M|0)|0}else{lb=ia-na|0}na=c[(b+12132|0)>>2]|0;if((ma|0)==0){mb=(ca(na,qa-M|0)|0)/(M|0)|0}else{mb=$a-na|0}na=((mb&J)<<n)+(lb&J)|0;if((m&1|0)==0){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>1,T)|0)+(ia>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,T,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(mb>>1,T)|0)+(lb>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(na<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,T,16);break}else{la=(ca($a>>2,T)|0)+(ia>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,T);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,T);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(T<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(T<<3))|0,T);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(T<<3))|0,T);la=(ca(mb>>2,T)|0)+(lb>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,T);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,T);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(T<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(T<<3))|0,T);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(T<<3))|0,T);break}}}while(0);ib=Xe[N&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,T,16)|0}}while(0);c[(F+(S<<2)|0)>>2]=R;c[_+(S<<2)>>2]=ib;T=(ca((d[C+((z<<n)-x)|0]|0)+(d[C+(y-E)|0]|0)|0,l)|0)+ib|0;if((T|0)>=(V|0)){fb=V;gb=A;hb=B;break}c[r>>2]=p;c[(r+4|0)>>2]=z;fb=T;gb=p;hb=z}}while(0);S=z+2|0;if((S|0)>(I|0)){cb=fb;db=gb;eb=hb;break}else{z=S;V=fb;A=gb;B=hb}}}B=eb-2|0;A=(B|0)>(L|0)?B:L;B=eb+2|0;V=(B|0)>(D|0)?D:B;if((A|0)>(V|0)){nb=cb}else{B=db-2|0;z=(B|0)>(W|0)?B:W;B=db+2|0;I=(B|0)>(Q|0)?Q:B;B=(m&1)<<1|1;y=A;A=cb;while(1){if((z|0)>(I|0)){ob=A}else{J=(y<<11)+H|0;G=y<<3;K=y<<1&2;ja=y>>1;S=y<<n;R=z;T=A;while(1){M=J+R|0;qa=R+G&63;do{if((c[(F+(qa<<2)|0)>>2]|0)==(M|0)){pb=T}else{ma=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){la=c[(b+12420|0)>>2]|0;na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma,y)|0)+R)|0;ia=Xe[N&511](b,c[(b+12288+(h<<4)|0)>>2]|0,na,ma,8)|0;if((m&2|0)==0){qb=ia;break}na=R&1|K;$a=c[(b+12208|0)>>2]|0;X=(ca(la,ja)|0)+(R>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(na<<2)>>2]&2047]($a+(ma<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+X|0,la,4);mf[c[(c[(b+12444|0)>>2]|0)+16+(na<<2)>>2]&2047]($a+(ma<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+X|0,la,4);X=(Xe[O&511](b,$a+(ma<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,la,4)|0)+ia|0;qb=X+(Xe[O&511](b,$a+(ma<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,la,4)|0)|0}else{la=R<<n;if((c[(b+12264|0)>>2]|0)>(R|0)){qb=536870912;break}if((la|0)>(c[(b+12268|0)>>2]<<n|0)){qb=536870912;break}if((c[(b+12272|0)>>2]|0)>(y|0)){qb=536870912;break}if((S|0)>(c[(b+12276|0)>>2]<<n|0)){qb=536870912;break}$a=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;j:do{if((c[(b+11740|0)>>2]|0)==1){if((la|0)==0){ia=0;while(1){na=c[b+12160+(ia<<3)>>2]|0;fa=(c[b+12160+(ia<<3)+4>>2]|0)+S|0;ga=((ca(c[b+12128+(ia<<3)>>2]|0,X-$a|0)|0)/($a|0)|0)+((ia&1)<<(m&1|4))|0;U=c[b+12128+(ia<<3)+4>>2]|0;if((S|0)==0){ka=ia>>1;rb=((ca(U,X-$a|0)|0)/($a|0)|0)+(ka<<(m&1|4))|0;sb=ka}else{rb=fa-U|0;sb=ia>>1}U=((rb&B)<<n)+(ga&B)|0;ka=(c[(b+12208|0)>>2]|0)+((ca(sb,ma<<3)|0)+(ia<<3&8))|0;if((m&1|0)==0){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>1,ma)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&B)<<n)+(na&B)|0)<<2)>>2]&2047](ka,Ba,ma,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(rb>>1,ma)|0)+(ga>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(U<<2)>>2]&2047](ka,Ba,ma,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>2,ma)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((fa&B)<<n)+(na&B)|0)<<2)>>2]&4095](ka,Ba,ma);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(rb>>2,ma)|0)+(ga>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](ka,Ba,ma)}ia=ia+1|0;if((ia|0)>=4){break j}}}if((S|0)==0){ia=0;do{Ba=(c[b+12160+(ia<<3)>>2]|0)+la|0;ka=c[b+12160+(ia<<3)+4>>2]|0;U=Ba-(c[b+12128+(ia<<3)>>2]|0)|0;ga=ia>>1;na=((ca(c[b+12128+(ia<<3)+4>>2]|0,X-$a|0)|0)/($a|0)|0)+(ga<<(m&1|4))|0;fa=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ca(ga,ma<<3)|0))|0;if((m&1|0)==0){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,ma)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&B)<<n)+(Ba&B)|0)<<2)>>2]&2047](fa,ga,ma,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>1,ma)|0)+(U>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((na&B)<<n)+(U&B)|0)<<2)>>2]&2047](fa,ga,ma,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>2,ma)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(Ba&B)|0)<<2)>>2]&4095](fa,ga,ma);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>2,ma)|0)+(U>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((na&B)<<n)+(U&B)|0)<<2)>>2]&4095](fa,ga,ma)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{ga=(c[b+12160+(ia<<3)>>2]|0)+la|0;fa=(c[b+12160+(ia<<3)+4>>2]|0)+S|0;U=ga-(c[b+12128+(ia<<3)>>2]|0)|0;na=fa-(c[b+12128+(ia<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ca(ia>>1,ma<<3)|0))|0;if((m&1|0)==0){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>1,ma)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&B)<<n)+(ga&B)|0)<<2)>>2]&2047](Ba,ka,ma,8);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>1,ma)|0)+(U>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((na&B)<<n)+(U&B)|0)<<2)>>2]&2047](Ba,ka,ma,8)}else{ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>2,ma)|0)+(ga>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((fa&B)<<n)+(ga&B)|0)<<2)>>2]&4095](Ba,ka,ma);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>2,ma)|0)+(U>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((na&B)<<n)+(U&B)|0)<<2)>>2]&4095](Ba,ka,ma)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[(b+12160|0)>>2]|0)+la|0;ka=(c[(b+12164|0)>>2]|0)+S|0;Ba=c[(b+12128|0)>>2]|0;if((la|0)==0){tb=(ca(Ba,X-$a|0)|0)/($a|0)|0}else{tb=ia-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((S|0)==0){ub=(ca(Ba,X-$a|0)|0)/($a|0)|0}else{ub=ka-Ba|0}Ba=((ub&B)<<n)+(tb&B)|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,ma)|0)+(ia>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,U,ma,16);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ub>>1,ma)|0)+(tb>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&2047](c[(b+12208|0)>>2]|0,U,ma,16);break}else{U=(ca(ka>>2,ma)|0)+(ia>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+U|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(U+8|0)|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(U+(ma<<3))|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((U+8|0)+(ma<<3))|0,ma);U=(ca(ub>>2,ma)|0)+(tb>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+U|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(U+8|0)|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(U+(ma<<3))|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((U+8|0)+(ma<<3))|0,ma);break}}}while(0);qb=Xe[N&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(qa<<2)|0)>>2]=M;c[_+(qa<<2)>>2]=qb;ma=(ca((d[C+(S-x)|0]|0)+(d[C+((R<<n)-E)|0]|0)|0,l)|0)+qb|0;if((ma|0)>=(T|0)){pb=T;break}c[r>>2]=R;c[(r+4|0)>>2]=y;pb=ma}}while(0);qa=R+1|0;if((qa|0)>(I|0)){ob=pb;break}else{R=qa;T=pb}}}T=y+1|0;if((T|0)>(V|0)){nb=ob;break}else{y=T;A=ob}}}if(((s&254)>>>2|0)==0){vb=nb}else{A=(m&1)<<1|1;y=1;V=nb;while(1){I=0;B=V;while(1){z=(ca(c[284520+(I<<3)>>2]|0,y)|0)+db|0;T=(ca(c[284524+(I<<3)>>2]|0,y)|0)+eb|0;R=(z|0)>(Q|0)?Q:z;z=(W|0)>(R|0)?W:R;R=(T|0)>(D|0)?D:T;T=(L|0)>(R|0)?L:R;do{if((c[(F+(((T<<3)+z&63)<<2)|0)>>2]|0)==(z+H+(T<<11)|0|0)){wb=B}else{R=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){S=c[(b+12420|0)>>2]|0;ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(R,T)|0)+z)|0;K=Xe[N&511](b,c[(b+12288+(h<<4)|0)>>2]|0,ja,R,8)|0;if((m&2|0)==0){xb=K;break}ja=c[(b+12208|0)>>2]|0;G=(ca(S,T>>1)|0)+(z>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((T<<1&2|z&1)<<2)>>2]&2047](ja+(R<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+G|0,S,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((T<<1&2|z&1)<<2)>>2]&2047](ja+(R<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+G|0,S,4);G=(Xe[O&511](b,ja+(R<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,S,4)|0)+K|0;xb=G+(Xe[O&511](b,ja+(R<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,S,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(z|0)){xb=536870912;break}if((z<<n|0)>(c[(b+12268|0)>>2]<<n|0)){xb=536870912;break}if((c[(b+12272|0)>>2]|0)>(T|0)){xb=536870912;break}if((T<<n|0)>(c[(b+12276|0)>>2]<<n|0)){xb=536870912;break}S=e[(b+13872|0)>>1]|0;ja=e[(b+13874|0)>>1]|0;k:do{if((c[(b+11740|0)>>2]|0)==1){if((z<<n|0)==0){G=0;while(1){K=c[b+12160+(G<<3)>>2]|0;J=(c[b+12160+(G<<3)+4>>2]|0)+(T<<n)|0;qa=((ca(c[b+12128+(G<<3)>>2]|0,ja-S|0)|0)/(S|0)|0)+((G&1)<<(m&1|4))|0;M=c[b+12128+(G<<3)+4>>2]|0;if((T<<n|0)==0){ma=G>>1;yb=((ca(M,ja-S|0)|0)/(S|0)|0)+(ma<<(m&1|4))|0;zb=ma}else{yb=J-M|0;zb=G>>1}M=((yb&A)<<n)+(qa&A)|0;ma=(c[(b+12208|0)>>2]|0)+((ca(zb,R<<3)|0)+(G<<3&8))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(J>>1,R)|0)+(K>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((J&A)<<n)+(K&A)|0)<<2)>>2]&2047](ma,$a,R,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(yb>>1,R)|0)+(qa>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(M<<2)>>2]&2047](ma,$a,R,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(J>>2,R)|0)+(K>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((J&A)<<n)+(K&A)|0)<<2)>>2]&4095](ma,$a,R);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(yb>>2,R)|0)+(qa>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(M<<2)>>2]&4095](ma,$a,R)}G=G+1|0;if((G|0)>=4){break k}}}if((T<<n|0)==0){G=0;do{$a=(c[b+12160+(G<<3)>>2]|0)+(z<<n)|0;ma=c[b+12160+(G<<3)+4>>2]|0;M=$a-(c[b+12128+(G<<3)>>2]|0)|0;qa=G>>1;K=((ca(c[b+12128+(G<<3)+4>>2]|0,ja-S|0)|0)/(S|0)|0)+(qa<<(m&1|4))|0;J=(c[(b+12208|0)>>2]|0)+((G<<3&8)+(ca(qa,R<<3)|0))|0;if((m&1|0)==0){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,R)|0)+($a>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&A)<<n)+($a&A)|0)<<2)>>2]&2047](J,qa,R,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,R)|0)+(M>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&A)<<n)+(M&A)|0)<<2)>>2]&2047](J,qa,R,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>2,R)|0)+($a>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+($a&A)|0)<<2)>>2]&4095](J,qa,R);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,R)|0)+(M>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&A)<<n)+(M&A)|0)<<2)>>2]&4095](J,qa,R)}G=G+1|0;}while((G|0)<4)}else{G=0;do{qa=(c[b+12160+(G<<3)>>2]|0)+(z<<n)|0;J=(c[b+12160+(G<<3)+4>>2]|0)+(T<<n)|0;M=qa-(c[b+12128+(G<<3)>>2]|0)|0;K=J-(c[b+12128+(G<<3)+4>>2]|0)|0;$a=(c[(b+12208|0)>>2]|0)+((G<<3&8)+(ca(G>>1,R<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(J>>1,R)|0)+(qa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((J&A)<<n)+(qa&A)|0)<<2)>>2]&2047]($a,ma,R,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,R)|0)+(M>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&A)<<n)+(M&A)|0)<<2)>>2]&2047]($a,ma,R,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(J>>2,R)|0)+(qa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((J&A)<<n)+(qa&A)|0)<<2)>>2]&4095]($a,ma,R);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,R)|0)+(M>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&A)<<n)+(M&A)|0)<<2)>>2]&4095]($a,ma,R)}G=G+1|0;}while((G|0)<4)}}else{G=(c[(b+12160|0)>>2]|0)+(z<<n)|0;ma=(c[(b+12164|0)>>2]|0)+(T<<n)|0;$a=c[(b+12128|0)>>2]|0;if((z<<n|0)==0){Ab=(ca($a,ja-S|0)|0)/(S|0)|0}else{Ab=G-$a|0}$a=c[(b+12132|0)>>2]|0;if((T<<n|0)==0){Bb=(ca($a,ja-S|0)|0)/(S|0)|0}else{Bb=ma-$a|0}$a=((Bb&A)<<n)+(Ab&A)|0;if((m&1|0)==0){M=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,R)|0)+(G>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,M,R,16);M=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Bb>>1,R)|0)+(Ab>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+($a<<2)>>2]&2047](c[(b+12208|0)>>2]|0,M,R,16);break}else{M=(ca(ma>>2,R)|0)+(G>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+M|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(M+8|0)|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(M+(R<<3))|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((M+8|0)+(R<<3))|0,R);M=(ca(Bb>>2,R)|0)+(Ab>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+M|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(M+8|0)|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(M+(R<<3))|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((M+8|0)+(R<<3))|0,R);break}}}while(0);xb=Xe[N&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,R,16)|0}}while(0);c[(F+(((T<<3)+z&63)<<2)|0)>>2]=z+H+(T<<11)|0;c[_+(((T<<3)+z&63)<<2)>>2]=xb;R=(ca((d[C+((T<<n)-x)|0]|0)+(d[C+((z<<n)-E)|0]|0)|0,l)|0)+xb|0;if((R|0)>=(B|0)){wb=B;break}c[r>>2]=z;c[(r+4|0)>>2]=T;wb=R}}while(0);T=I+1|0;if((T|0)<16){I=T;B=wb}else{break}}B=y+1|0;if((B|0)>((s&254)>>>2|0)){vb=wb;break}else{y=B;V=wb}}}t=vrb(b,r,vb,h,j,l,0,8,m,2)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}if((s|0)>512){t=vrb(b,r,q,h,j,l,0,8,m,s&255)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}V=c[(b+12220|0)>>2]|0;y=c[(b+12264|0)>>2]|0;E=c[(b+12272|0)>>2]|0;C=c[(b+12268|0)>>2]|0;x=c[(b+12276|0)>>2]|0;_=c[(b+12464|0)>>2]|0;H=c[(b+12280|0)>>2]|0;F=c[(b+12284|0)>>2]|0;N=c[(b+12216|0)>>2]|0;A=c[(b+12224|0)>>2]|0;if((s|0)<=256){O=c[(b+10468|0)>>2]|0;L=c[(b+10472|0)>>2]|0;D=(m&1)<<1|1;W=m&1|4;Q=(m&1|0)==0;B=1;I=q;T=p;z=o;while(1){R=z+B|0;S=(R-x|0|0)<0?0:R-x|0;ja=C-T+1|0;M=(B|0)>(ja|0)?ja:B;if((S|0)<(M|0)){ja=S;S=I;$a=z;G=T;while(1){ma=R-ja|0;K=ja+T|0;do{if((c[(N+(((ma<<3)+K&63)<<2)|0)>>2]|0)==(K+A+(ma<<11)|0|0)){Cb=S;Db=$a;Eb=G}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa,ma)|0)+K)|0;la=Xe[O&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){Fb=la;break}X=c[(b+12208|0)>>2]|0;U=(ca(J,ma>>1)|0)+(K>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|K&1)<<2)>>2]&2047](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+U|0,J,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|K&1)<<2)>>2]&2047](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+U|0,J,4);U=(Xe[L&511](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+la|0;Fb=U+(Xe[L&511](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(K|0)){Fb=536870912;break}if((K<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Fb=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){Fb=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Fb=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;l:do{if((c[(b+11740|0)>>2]|0)==1){if((K<<n|0)==0){U=0;while(1){la=c[b+12160+(U<<3)>>2]|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(ma<<n)|0;ia=((ca(c[b+12128+(U<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((U&1)<<W)|0;ka=c[b+12128+(U<<3)+4>>2]|0;if((ma<<n|0)==0){na=U>>1;Gb=((ca(ka,X-J|0)|0)/(J|0)|0)+(na<<W)|0;Hb=na}else{Gb=Ba-ka|0;Hb=U>>1}ka=((Gb&D)<<n)+(ia&D)|0;na=(c[(b+12208|0)>>2]|0)+((ca(Hb,qa<<3)|0)+(U<<3&8))|0;if(Q){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(la&D)|0)<<2)>>2]&2047](na,ga,qa,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Gb>>1,qa)|0)+(ia>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&2047](na,ga,qa,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(la&D)|0)<<2)>>2]&4095](na,ga,qa);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Gb>>2,qa)|0)+(ia>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](na,ga,qa)}U=U+1|0;if((U|0)>=4){break l}}}if((ma<<n|0)==0){U=0;do{ga=(c[b+12160+(U<<3)>>2]|0)+(K<<n)|0;na=c[b+12160+(U<<3)+4>>2]|0;ka=ga-(c[b+12128+(U<<3)>>2]|0)|0;ia=U>>1;la=((ca(c[b+12128+(U<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;Ba=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(ia,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,qa)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((na&D)<<n)+(ga&D)|0)<<2)>>2]&2047](Ba,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&2047](Ba,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>2,qa)|0)+(ga>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(ga&D)|0)<<2)>>2]&4095](Ba,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](Ba,ia,qa)}U=U+1|0;}while((U|0)<4)}else{U=0;do{ia=(c[b+12160+(U<<3)>>2]|0)+(K<<n)|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(ma<<n)|0;ka=ia-(c[b+12128+(U<<3)>>2]|0)|0;la=Ba-(c[b+12128+(U<<3)+4>>2]|0)|0;ga=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(U>>1,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>1,qa)|0)+(ia>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(ia&D)|0)<<2)>>2]&2047](ga,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&2047](ga,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>2,qa)|0)+(ia>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(ia&D)|0)<<2)>>2]&4095](ga,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ga,na,qa)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(K<<n)|0;na=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;ga=c[(b+12128|0)>>2]|0;if((K<<n|0)==0){Ib=(ca(ga,X-J|0)|0)/(J|0)|0}else{Ib=U-ga|0}ga=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){Jb=(ca(ga,X-J|0)|0)/(J|0)|0}else{Jb=na-ga|0}ga=((Jb&D)<<n)+(Ib&D)|0;if(Q){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,qa)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((na&D)<<n)+(U&D)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,qa,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Jb>>1,qa)|0)+(Ib>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(ga<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,qa,16);break}else{ka=(ca(na>>2,qa)|0)+(U>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(qa<<3))|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);ka=(ca(Jb>>2,qa)|0)+(Ib>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(qa<<3))|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);break}}}while(0);Fb=Xe[O&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((ma<<3)+K&63)<<2)|0)>>2]=K+A+(ma<<11)|0;c[V+(((ma<<3)+K&63)<<2)>>2]=Fb;qa=(ca((d[_+((ma<<n)-F)|0]|0)+(d[_+((K<<n)-H)|0]|0)|0,l)|0)+Fb|0;if((qa|0)>=(S|0)){Cb=S;Db=$a;Eb=G;break}c[r>>2]=K;c[(r+4|0)>>2]=ma;Cb=qa;Db=ma;Eb=K}}while(0);K=ja+1|0;if((K|0)<(M|0)){ja=K;S=Cb;$a=Db;G=Eb}else{Kb=Cb;Lb=Db;Mb=Eb;break}}}else{Kb=I;Lb=z;Mb=T}G=B+T|0;$a=(G-C|0|0)<0?0:G-C|0;S=z-E+1|0;ja=(B|0)>(S|0)?S:B;if(($a|0)<(ja|0)){S=$a;$a=Kb;M=Lb;R=Mb;while(1){K=z-S|0;ma=G-S|0;do{if((c[(N+(((K<<3)+ma&63)<<2)|0)>>2]|0)==(ma+A+(K<<11)|0|0)){Nb=$a;Ob=M;Pb=R}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa,K)|0)+ma)|0;ka=Xe[O&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){Qb=ka;break}X=c[(b+12208|0)>>2]|0;ga=(ca(J,K>>1)|0)+(ma>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((K<<1&2|ma&1)<<2)>>2]&2047](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ga|0,J,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((K<<1&2|ma&1)<<2)>>2]&2047](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ga|0,J,4);ga=(Xe[L&511](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+ka|0;Qb=ga+(Xe[L&511](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(ma|0)){Qb=536870912;break}if((ma<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Qb=536870912;break}if((c[(b+12272|0)>>2]|0)>(K|0)){Qb=536870912;break}if((K<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Qb=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;m:do{if((c[(b+11740|0)>>2]|0)==1){if((ma<<n|0)==0){ga=0;while(1){ka=c[b+12160+(ga<<3)>>2]|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(K<<n)|0;na=((ca(c[b+12128+(ga<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((ga&1)<<W)|0;la=c[b+12128+(ga<<3)+4>>2]|0;if((K<<n|0)==0){ia=ga>>1;Rb=((ca(la,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;Sb=ia}else{Rb=U-la|0;Sb=ga>>1}la=((Rb&D)<<n)+(na&D)|0;ia=(c[(b+12208|0)>>2]|0)+((ca(Sb,qa<<3)|0)+(ga<<3&8))|0;if(Q){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&D)<<n)+(ka&D)|0)<<2)>>2]&2047](ia,Ba,qa,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Rb>>1,qa)|0)+(na>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&2047](ia,Ba,qa,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ia,Ba,qa);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Rb>>2,qa)|0)+(na>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](ia,Ba,qa)}ga=ga+1|0;if((ga|0)>=4){break m}}}if((K<<n|0)==0){ga=0;do{Ba=(c[b+12160+(ga<<3)>>2]|0)+(ma<<n)|0;ia=c[b+12160+(ga<<3)+4>>2]|0;la=Ba-(c[b+12128+(ga<<3)>>2]|0)|0;na=ga>>1;ka=((ca(c[b+12128+(ga<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(na<<W)|0;U=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(na,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>1,qa)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ia&D)<<n)+(Ba&D)|0)<<2)>>2]&2047](U,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&2047](U,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>2,qa)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(Ba&D)|0)<<2)>>2]&4095](U,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](U,na,qa)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{na=(c[b+12160+(ga<<3)>>2]|0)+(ma<<n)|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(K<<n)|0;la=na-(c[b+12128+(ga<<3)>>2]|0)|0;ka=U-(c[b+12128+(ga<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(ga>>1,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,qa)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&D)<<n)+(na&D)|0)<<2)>>2]&2047](Ba,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&2047](Ba,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,qa)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&D)<<n)+(na&D)|0)<<2)>>2]&4095](Ba,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](Ba,ia,qa)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+(ma<<n)|0;ia=(c[(b+12164|0)>>2]|0)+(K<<n)|0;Ba=c[(b+12128|0)>>2]|0;if((ma<<n|0)==0){Tb=(ca(Ba,X-J|0)|0)/(J|0)|0}else{Tb=ga-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((K<<n|0)==0){Ub=(ca(Ba,X-J|0)|0)/(J|0)|0}else{Ub=ia-Ba|0}Ba=((Ub&D)<<n)+(Tb&D)|0;if(Q){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>1,qa)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,qa,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ub>>1,qa)|0)+(Tb>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,qa,16);break}else{la=(ca(ia>>2,qa)|0)+(ga>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(qa<<3))|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);la=(ca(Ub>>2,qa)|0)+(Tb>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(qa<<3))|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);break}}}while(0);Qb=Xe[O&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((K<<3)+ma&63)<<2)|0)>>2]=ma+A+(K<<11)|0;c[V+(((K<<3)+ma&63)<<2)>>2]=Qb;qa=(ca((d[_+((K<<n)-F)|0]|0)+(d[_+((ma<<n)-H)|0]|0)|0,l)|0)+Qb|0;if((qa|0)>=($a|0)){Nb=$a;Ob=M;Pb=R;break}c[r>>2]=ma;c[(r+4|0)>>2]=K;Nb=qa;Ob=K;Pb=ma}}while(0);ma=S+1|0;if((ma|0)<(ja|0)){S=ma;$a=Nb;M=Ob;R=Pb}else{Vb=Nb;Wb=Ob;Xb=Pb;break}}}else{Vb=Kb;Wb=Lb;Xb=Mb}R=B-z+E|0;M=(R|0)<0?0:R;R=T-y+1|0;$a=(B|0)>(R|0)?R:B;if((M|0)<($a|0)){R=z-B|0;S=M;M=Vb;ja=Wb;G=Xb;while(1){ma=S+R|0;K=T-S|0;do{if((c[(N+(((ma<<3)+K&63)<<2)|0)>>2]|0)==(K+A+(ma<<11)|0|0)){Yb=M;Zb=ja;_b=G}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa,ma)|0)+K)|0;la=Xe[O&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){$b=la;break}X=c[(b+12208|0)>>2]|0;Ba=(ca(J,ma>>1)|0)+(K>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|K&1)<<2)>>2]&2047](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+Ba|0,J,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|K&1)<<2)>>2]&2047](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+Ba|0,J,4);Ba=(Xe[L&511](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+la|0;$b=Ba+(Xe[L&511](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(K|0)){$b=536870912;break}if((K<<n|0)>(c[(b+12268|0)>>2]<<n|0)){$b=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){$b=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){$b=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;n:do{if((c[(b+11740|0)>>2]|0)==1){if((K<<n|0)==0){Ba=0;while(1){la=c[b+12160+(Ba<<3)>>2]|0;ga=(c[b+12160+(Ba<<3)+4>>2]|0)+(ma<<n)|0;ia=((ca(c[b+12128+(Ba<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((Ba&1)<<W)|0;ka=c[b+12128+(Ba<<3)+4>>2]|0;if((ma<<n|0)==0){na=Ba>>1;ac=((ca(ka,X-J|0)|0)/(J|0)|0)+(na<<W)|0;bc=na}else{ac=ga-ka|0;bc=Ba>>1}ka=((ac&D)<<n)+(ia&D)|0;na=(c[(b+12208|0)>>2]|0)+((ca(bc,qa<<3)|0)+(Ba<<3&8))|0;if(Q){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&D)<<n)+(la&D)|0)<<2)>>2]&2047](na,U,qa,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ac>>1,qa)|0)+(ia>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&2047](na,U,qa,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&D)<<n)+(la&D)|0)<<2)>>2]&4095](na,U,qa);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ac>>2,qa)|0)+(ia>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](na,U,qa)}Ba=Ba+1|0;if((Ba|0)>=4){break n}}}if((ma<<n|0)==0){Ba=0;do{U=(c[b+12160+(Ba<<3)>>2]|0)+(K<<n)|0;na=c[b+12160+(Ba<<3)+4>>2]|0;ka=U-(c[b+12128+(Ba<<3)>>2]|0)|0;ia=Ba>>1;la=((ca(c[b+12128+(Ba<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;ga=(c[(b+12208|0)>>2]|0)+((Ba<<3&8)+(ca(ia,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,qa)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((na&D)<<n)+(U&D)|0)<<2)>>2]&2047](ga,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&2047](ga,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>2,qa)|0)+(U>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095](ga,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ga,ia,qa)}Ba=Ba+1|0;}while((Ba|0)<4)}else{Ba=0;do{ia=(c[b+12160+(Ba<<3)>>2]|0)+(K<<n)|0;ga=(c[b+12160+(Ba<<3)+4>>2]|0)+(ma<<n)|0;ka=ia-(c[b+12128+(Ba<<3)>>2]|0)|0;la=ga-(c[b+12128+(Ba<<3)+4>>2]|0)|0;U=(c[(b+12208|0)>>2]|0)+((Ba<<3&8)+(ca(Ba>>1,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,qa)|0)+(ia>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&D)<<n)+(ia&D)|0)<<2)>>2]&2047](U,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&2047](U,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,qa)|0)+(ia>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&D)<<n)+(ia&D)|0)<<2)>>2]&4095](U,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](U,na,qa)}Ba=Ba+1|0;}while((Ba|0)<4)}}else{Ba=(c[(b+12160|0)>>2]|0)+(K<<n)|0;na=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;U=c[(b+12128|0)>>2]|0;if((K<<n|0)==0){cc=(ca(U,X-J|0)|0)/(J|0)|0}else{cc=Ba-U|0}U=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){dc=(ca(U,X-J|0)|0)/(J|0)|0}else{dc=na-U|0}U=((dc&D)<<n)+(cc&D)|0;if(Q){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,qa)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,qa,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(dc>>1,qa)|0)+(cc>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(U<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,qa,16);break}else{ka=(ca(na>>2,qa)|0)+(Ba>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(qa<<3))|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);ka=(ca(dc>>2,qa)|0)+(cc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(qa<<3))|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);break}}}while(0);$b=Xe[O&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((ma<<3)+K&63)<<2)|0)>>2]=K+A+(ma<<11)|0;c[V+(((ma<<3)+K&63)<<2)>>2]=$b;qa=(ca((d[_+((ma<<n)-F)|0]|0)+(d[_+((K<<n)-H)|0]|0)|0,l)|0)+$b|0;if((qa|0)>=(M|0)){Yb=M;Zb=ja;_b=G;break}c[r>>2]=K;c[(r+4|0)>>2]=ma;Yb=qa;Zb=ma;_b=K}}while(0);K=S+1|0;if((K|0)<($a|0)){S=K;M=Yb;ja=Zb;G=_b}else{ec=Yb;fc=Zb;gc=_b;break}}}else{ec=Vb;fc=Wb;gc=Xb}G=B-T+y|0;ja=(G|0)<0?0:G;G=x-z+1|0;M=(B|0)>(G|0)?G:B;if((ja|0)<(M|0)){G=T-B|0;S=ja;ja=ec;$a=fc;R=gc;while(1){K=S+z|0;ma=S+G|0;do{if((c[(N+(((K<<3)+ma&63)<<2)|0)>>2]|0)==(ma+A+(K<<11)|0|0)){hc=ja;ic=$a;jc=R}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa,K)|0)+ma)|0;ka=Xe[O&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){kc=ka;break}X=c[(b+12208|0)>>2]|0;U=(ca(J,K>>1)|0)+(ma>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((K<<1&2|ma&1)<<2)>>2]&2047](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+U|0,J,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((K<<1&2|ma&1)<<2)>>2]&2047](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+U|0,J,4);U=(Xe[L&511](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+ka|0;kc=U+(Xe[L&511](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(ma|0)){kc=536870912;break}if((ma<<n|0)>(c[(b+12268|0)>>2]<<n|0)){kc=536870912;break}if((c[(b+12272|0)>>2]|0)>(K|0)){kc=536870912;break}if((K<<n|0)>(c[(b+12276|0)>>2]<<n|0)){kc=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;o:do{if((c[(b+11740|0)>>2]|0)==1){if((ma<<n|0)==0){U=0;while(1){ka=c[b+12160+(U<<3)>>2]|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(K<<n)|0;na=((ca(c[b+12128+(U<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((U&1)<<W)|0;la=c[b+12128+(U<<3)+4>>2]|0;if((K<<n|0)==0){ia=U>>1;lc=((ca(la,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;mc=ia}else{lc=Ba-la|0;mc=U>>1}la=((lc&D)<<n)+(na&D)|0;ia=(c[(b+12208|0)>>2]|0)+((ca(mc,qa<<3)|0)+(U<<3&8))|0;if(Q){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(ka&D)|0)<<2)>>2]&2047](ia,ga,qa,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(lc>>1,qa)|0)+(na>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&2047](ia,ga,qa,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ia,ga,qa);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(lc>>2,qa)|0)+(na>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](ia,ga,qa)}U=U+1|0;if((U|0)>=4){break o}}}if((K<<n|0)==0){U=0;do{ga=(c[b+12160+(U<<3)>>2]|0)+(ma<<n)|0;ia=c[b+12160+(U<<3)+4>>2]|0;la=ga-(c[b+12128+(U<<3)>>2]|0)|0;na=U>>1;ka=((ca(c[b+12128+(U<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(na<<W)|0;Ba=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(na,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>1,qa)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&2047](Ba,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&2047](Ba,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>2,qa)|0)+(ga>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095](Ba,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](Ba,na,qa)}U=U+1|0;}while((U|0)<4)}else{U=0;do{na=(c[b+12160+(U<<3)>>2]|0)+(ma<<n)|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(K<<n)|0;la=na-(c[b+12128+(U<<3)>>2]|0)|0;ka=Ba-(c[b+12128+(U<<3)+4>>2]|0)|0;ga=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(U>>1,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>1,qa)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(na&D)|0)<<2)>>2]&2047](ga,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&2047](ga,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>2,qa)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(na&D)|0)<<2)>>2]&4095](ga,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](ga,ia,qa)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(ma<<n)|0;ia=(c[(b+12164|0)>>2]|0)+(K<<n)|0;ga=c[(b+12128|0)>>2]|0;if((ma<<n|0)==0){nc=(ca(ga,X-J|0)|0)/(J|0)|0}else{nc=U-ga|0}ga=c[(b+12132|0)>>2]|0;if((K<<n|0)==0){oc=(ca(ga,X-J|0)|0)/(J|0)|0}else{oc=ia-ga|0}ga=((oc&D)<<n)+(nc&D)|0;if(Q){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>1,qa)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,qa,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(oc>>1,qa)|0)+(nc>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(ga<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,qa,16);break}else{la=(ca(ia>>2,qa)|0)+(U>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(qa<<3))|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);la=(ca(oc>>2,qa)|0)+(nc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(qa<<3))|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);break}}}while(0);kc=Xe[O&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((K<<3)+ma&63)<<2)|0)>>2]=ma+A+(K<<11)|0;c[V+(((K<<3)+ma&63)<<2)>>2]=kc;qa=(ca((d[_+((K<<n)-F)|0]|0)+(d[_+((ma<<n)-H)|0]|0)|0,l)|0)+kc|0;if((qa|0)>=(ja|0)){hc=ja;ic=$a;jc=R;break}c[r>>2]=ma;c[(r+4|0)>>2]=K;hc=qa;ic=K;jc=ma}}while(0);ma=S+1|0;if((ma|0)<(M|0)){S=ma;ja=hc;$a=ic;R=jc}else{pc=hc;qc=ic;rc=jc;break}}}else{pc=ec;qc=fc;rc=gc}R=(T|0)==(rc|0)&(z|0)==(qc|0);$a=R?B+1|0:1;if(($a|0)>(c[(b+12260|0)>>2]|0)){t=pc;break}else{B=$a;I=pc;T=rc;z=R?z:qc}}u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}z=c[(b+10468|0)>>2]|0;T=c[(b+10472|0)>>2]|0;if((s&255|0)==0){sc=q;tc=p;uc=o}else{I=(m&1)<<1|1;B=s&255;O=q;D=o;Q=p;while(1){W=O;L=D;R=Q;while(1){$a=0;ja=W;S=L;M=R;while(1){G=(ca(c[1017160+($a<<3)>>2]|0,B)|0)+R|0;ma=(ca(c[1017164+($a<<3)>>2]|0,B)|0)+L|0;K=(G|0)>(C|0)?C:G;G=(y|0)>(K|0)?y:K;K=(ma|0)>(x|0)?x:ma;ma=(E|0)>(K|0)?E:K;do{if((c[(N+(((ma<<3)+G&63)<<2)|0)>>2]|0)==(G+A+(ma<<11)|0|0)){vc=ja;wc=S;xc=M}else{K=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){qa=c[(b+12420|0)>>2]|0;J=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(K,ma)|0)+G)|0;X=Xe[z&511](b,c[(b+12288+(h<<4)|0)>>2]|0,J,K,8)|0;if((m&2|0)==0){yc=X;break}J=c[(b+12208|0)>>2]|0;la=(ca(qa,ma>>1)|0)+(G>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|G&1)<<2)>>2]&2047](J+(K<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+la|0,qa,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((ma<<1&2|G&1)<<2)>>2]&2047](J+(K<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+la|0,qa,4);la=(Xe[T&511](b,J+(K<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,qa,4)|0)+X|0;yc=la+(Xe[T&511](b,J+(K<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,qa,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(G|0)){yc=536870912;break}if((G<<n|0)>(c[(b+12268|0)>>2]<<n|0)){yc=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){yc=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){yc=536870912;break}qa=e[(b+13872|0)>>1]|0;J=e[(b+13874|0)>>1]|0;p:do{if((c[(b+11740|0)>>2]|0)==1){if((G<<n|0)==0){la=0;while(1){X=c[b+12160+(la<<3)>>2]|0;ga=(c[b+12160+(la<<3)+4>>2]|0)+(ma<<n)|0;U=((ca(c[b+12128+(la<<3)>>2]|0,J-qa|0)|0)/(qa|0)|0)+((la&1)<<(m&1|4))|0;ia=c[b+12128+(la<<3)+4>>2]|0;if((ma<<n|0)==0){ka=la>>1;zc=((ca(ia,J-qa|0)|0)/(qa|0)|0)+(ka<<(m&1|4))|0;Ac=ka}else{zc=ga-ia|0;Ac=la>>1}ia=((zc&I)<<n)+(U&I)|0;ka=(c[(b+12208|0)>>2]|0)+((ca(Ac,K<<3)|0)+(la<<3&8))|0;if((m&1|0)==0){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,K)|0)+(X>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&I)<<n)+(X&I)|0)<<2)>>2]&2047](ka,na,K,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(zc>>1,K)|0)+(U>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ia<<2)>>2]&2047](ka,na,K,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,K)|0)+(X>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&I)<<n)+(X&I)|0)<<2)>>2]&4095](ka,na,K);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(zc>>2,K)|0)+(U>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ia<<2)>>2]&4095](ka,na,K)}la=la+1|0;if((la|0)>=4){break p}}}if((ma<<n|0)==0){la=0;do{na=(c[b+12160+(la<<3)>>2]|0)+(G<<n)|0;ka=c[b+12160+(la<<3)+4>>2]|0;ia=na-(c[b+12128+(la<<3)>>2]|0)|0;U=la>>1;X=((ca(c[b+12128+(la<<3)+4>>2]|0,J-qa|0)|0)/(qa|0)|0)+(U<<(m&1|4))|0;ga=(c[(b+12208|0)>>2]|0)+((la<<3&8)+(ca(U,K<<3)|0))|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,K)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&I)<<n)+(na&I)|0)<<2)>>2]&2047](ga,U,K,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>1,K)|0)+(ia>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&2047](ga,U,K,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>2,K)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(na&I)|0)<<2)>>2]&4095](ga,U,K);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>2,K)|0)+(ia>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&4095](ga,U,K)}la=la+1|0;}while((la|0)<4)}else{la=0;do{U=(c[b+12160+(la<<3)>>2]|0)+(G<<n)|0;ga=(c[b+12160+(la<<3)+4>>2]|0)+(ma<<n)|0;ia=U-(c[b+12128+(la<<3)>>2]|0)|0;X=ga-(c[b+12128+(la<<3)+4>>2]|0)|0;na=(c[(b+12208|0)>>2]|0)+((la<<3&8)+(ca(la>>1,K<<3)|0))|0;if((m&1|0)==0){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,K)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&I)<<n)+(U&I)|0)<<2)>>2]&2047](na,ka,K,8);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>1,K)|0)+(ia>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&2047](na,ka,K,8)}else{ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,K)|0)+(U>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&I)<<n)+(U&I)|0)<<2)>>2]&4095](na,ka,K);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>2,K)|0)+(ia>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&4095](na,ka,K)}la=la+1|0;}while((la|0)<4)}}else{la=(c[(b+12160|0)>>2]|0)+(G<<n)|0;ka=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;na=c[(b+12128|0)>>2]|0;if((G<<n|0)==0){Bc=(ca(na,J-qa|0)|0)/(qa|0)|0}else{Bc=la-na|0}na=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){Cc=(ca(na,J-qa|0)|0)/(qa|0)|0}else{Cc=ka-na|0}na=((Cc&I)<<n)+(Bc&I)|0;if((m&1|0)==0){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,K)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ia,K,16);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Cc>>1,K)|0)+(Bc>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(na<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ia,K,16);break}else{ia=(ca(ka>>2,K)|0)+(la>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ia|0,K);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ia+8|0)|0,K);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(K<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ia+(K<<3))|0,K);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ia+8|0)+(K<<3))|0,K);ia=(ca(Cc>>2,K)|0)+(Bc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ia|0,K);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ia+8|0)|0,K);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(K<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ia+(K<<3))|0,K);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ia+8|0)+(K<<3))|0,K);break}}}while(0);yc=Xe[z&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,K,16)|0}}while(0);c[(N+(((ma<<3)+G&63)<<2)|0)>>2]=G+A+(ma<<11)|0;c[V+(((ma<<3)+G&63)<<2)>>2]=yc;K=(ca((d[_+((ma<<n)-F)|0]|0)+(d[_+((G<<n)-H)|0]|0)|0,l)|0)+yc|0;if((K|0)>=(ja|0)){vc=ja;wc=S;xc=M;break}c[r>>2]=G;c[(r+4|0)>>2]=ma;vc=K;wc=ma;xc=G}}while(0);G=$a+1|0;if((G|0)<8){$a=G;ja=vc;S=wc;M=xc}else{break}}if((xc|0)==(R|0)&(wc|0)==(L|0)){break}else{W=vc;L=wc;R=xc}}W=(s+255&(s&255)|0)!=0?B-1|0:B>>1;if((W|0)==0){sc=vc;tc=R;uc=L;break}else{B=W;O=vc;D=L;Q=R}}}Q=tc+1|0;D=(Q|0)>(C|0)?C:Q;Q=(y|0)>(D|0)?y:D;D=(uc|0)>(x|0)?x:uc;O=(E|0)>(D|0)?E:D;do{if((c[(N+((Q+(O<<3)&63)<<2)|0)>>2]|0)==(((O<<11)+A|0)+Q|0|0)){Dc=sc}else{do{if((m&4|0)==0){D=c[b+12416>>2]|0;B=c[b+12420>>2]|0;I=(c[b+12352+(j<<4)>>2]|0)+((ca(D,O)|0)+Q)|0;W=Xe[z&511](b,c[b+12288+(h<<4)>>2]|0,I,D,8)|0;if((m&2|0)==0){Ec=W;break}I=c[b+12208>>2]|0;M=(ca(B,O>>1)|0)+(Q>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((Q&1|O<<1&2)<<2)>>2]&2047](I+(D<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+M|0,B,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((Q&1|O<<1&2)<<2)>>2]&2047](I+(D<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+M|0,B,4);M=(Xe[T&511](b,I+(D<<4)|0,c[b+12288+(h<<4)+4>>2]|0,B,4)|0)+W|0;Ec=M+(Xe[T&511](b,I+(D<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,B,4)|0)|0}else{B=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(Q|0)){Ec=536870912;break}if((Q<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Ec=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Ec=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Ec=536870912;break}D=e[b+13872>>1]|0;I=e[b+13874>>1]|0;M=(m&1)<<1|1;q:do{if((c[b+11740>>2]|0)==1){if((Q<<n|0)==0){W=0;while(1){S=c[b+12160+(W<<3)>>2]|0;ja=(c[b+12160+(W<<3)+4>>2]|0)+(O<<n)|0;$a=((ca(c[b+12128+(W<<3)>>2]|0,I-D|0)|0)/(D|0)|0)+((W&1)<<(m&1|4))|0;G=c[b+12128+(W<<3)+4>>2]|0;if((O<<n|0)==0){ma=W>>1;Fc=((ca(G,I-D|0)|0)/(D|0)|0)+(ma<<(m&1|4))|0;Gc=ma}else{Fc=ja-G|0;Gc=W>>1}G=((Fc&M)<<n)+($a&M)|0;ma=(c[(b+12208|0)>>2]|0)+((ca(Gc,B<<3)|0)+(W<<3&8))|0;if((m&1|0)==0){K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja>>1,B)|0)+(S>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ja&M)<<n)+(S&M)|0)<<2)>>2]&2047](ma,K,B,8);K=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Fc>>1,B)|0)+($a>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(G<<2)>>2]&2047](ma,K,B,8)}else{K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja>>2,B)|0)+(S>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ja&M)<<n)+(S&M)|0)<<2)>>2]&4095](ma,K,B);K=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Fc>>2,B)|0)+($a>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(G<<2)>>2]&4095](ma,K,B)}W=W+1|0;if((W|0)>=4){break q}}}if((O<<n|0)==0){W=0;do{K=(c[b+12160+(W<<3)>>2]|0)+(Q<<n)|0;ma=c[b+12160+(W<<3)+4>>2]|0;G=K-(c[b+12128+(W<<3)>>2]|0)|0;$a=W>>1;S=((ca(c[b+12128+(W<<3)+4>>2]|0,I-D|0)|0)/(D|0)|0)+($a<<(m&1|4))|0;ja=(c[(b+12208|0)>>2]|0)+((W<<3&8)+(ca($a,B<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,B)|0)+(K>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&M)<<n)+(K&M)|0)<<2)>>2]&2047](ja,$a,B,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(S>>1,B)|0)+(G>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((S&M)<<n)+(G&M)|0)<<2)>>2]&2047](ja,$a,B,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>2,B)|0)+(K>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(K&M)|0)<<2)>>2]&4095](ja,$a,B);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(S>>2,B)|0)+(G>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((S&M)<<n)+(G&M)|0)<<2)>>2]&4095](ja,$a,B)}W=W+1|0;}while((W|0)<4)}else{W=0;do{$a=(c[b+12160+(W<<3)>>2]|0)+(Q<<n)|0;ja=(c[b+12160+(W<<3)+4>>2]|0)+(O<<n)|0;G=$a-(c[b+12128+(W<<3)>>2]|0)|0;S=ja-(c[b+12128+(W<<3)+4>>2]|0)|0;K=(c[(b+12208|0)>>2]|0)+((W<<3&8)+(ca(W>>1,B<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja>>1,B)|0)+($a>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ja&M)<<n)+($a&M)|0)<<2)>>2]&2047](K,ma,B,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(S>>1,B)|0)+(G>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((S&M)<<n)+(G&M)|0)<<2)>>2]&2047](K,ma,B,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja>>2,B)|0)+($a>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ja&M)<<n)+($a&M)|0)<<2)>>2]&4095](K,ma,B);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(S>>2,B)|0)+(G>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((S&M)<<n)+(G&M)|0)<<2)>>2]&4095](K,ma,B)}W=W+1|0;}while((W|0)<4)}}else{W=(c[b+12160>>2]|0)+(Q<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;K=c[b+12128>>2]|0;if((Q<<n|0)==0){Hc=(ca(K,I-D|0)|0)/(D|0)|0}else{Hc=W-K|0}K=c[b+12132>>2]|0;if((O<<n|0)==0){Ic=(ca(K,I-D|0)|0)/(D|0)|0}else{Ic=ma-K|0}K=((Ic&M)<<n)+(Hc&M)|0;if((m&1|0)==0){G=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,B)|0)+(W>>1))|0;mf[c[(c[b+12444>>2]|0)+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,G,B,16);G=(c[b+12352+(j<<4)+32>>2]|0)+((ca(Ic>>1,B)|0)+(Hc>>1))|0;mf[c[(c[b+12448>>2]|0)+(K<<2)>>2]&2047](c[(b+12208|0)>>2]|0,G,B,16);break}else{G=(ca(ma>>2,B)|0)+(W>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+G|0,B);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(G+8|0)|0,B);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(B<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(G+(B<<3))|0,B);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((B<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((G+8|0)+(B<<3))|0,B);G=(ca(Ic>>2,B)|0)+(Hc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+G|0,B);ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(G+8|0)|0,B);ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(B<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(G+(B<<3))|0,B);ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((B<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((G+8|0)+(B<<3))|0,B);break}}}while(0);Ec=Xe[z&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,B,16)|0}}while(0);c[(N+((Q+(O<<3)&63)<<2)|0)>>2]=((O<<11)+A|0)+Q|0;c[V+((Q+(O<<3)&63)<<2)>>2]=Ec;R=(ca((d[_+((O<<n)-F)|0]|0)+(d[_+((Q<<n)-H)|0]|0)|0,l)|0)+Ec|0;if((R|0)>=(sc|0)){Dc=sc;break}c[r>>2]=Q;c[(r+4|0)>>2]=O;Dc=R}}while(0);Q=uc+1|0;R=(tc|0)>(C|0)?C:tc;L=(y|0)>(R|0)?y:R;R=(Q|0)>(x|0)?x:Q;Q=(E|0)>(R|0)?E:R;do{if((c[(N+(((Q<<3)+L&63)<<2)|0)>>2]|0)==((L+A|0)+(Q<<11)|0|0)){Jc=Dc}else{do{if((m&4|0)==0){R=c[b+12416>>2]|0;M=c[b+12420>>2]|0;D=(c[b+12352+(j<<4)>>2]|0)+((ca(R,Q)|0)+L)|0;I=Xe[z&511](b,c[b+12288+(h<<4)>>2]|0,D,R,8)|0;if((m&2|0)==0){Kc=I;break}D=c[b+12208>>2]|0;G=(ca(M,Q>>1)|0)+(L>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((Q<<1&2|L&1)<<2)>>2]&2047](D+(R<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+G|0,M,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((Q<<1&2|L&1)<<2)>>2]&2047](D+(R<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+G|0,M,4);G=(Xe[T&511](b,D+(R<<4)|0,c[b+12288+(h<<4)+4>>2]|0,M,4)|0)+I|0;Kc=G+(Xe[T&511](b,D+(R<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,M,4)|0)|0}else{M=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(L|0)){Kc=536870912;break}if((L<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Kc=536870912;break}if((c[(b+12272|0)>>2]|0)>(Q|0)){Kc=536870912;break}if((Q<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Kc=536870912;break}R=e[b+13872>>1]|0;D=e[b+13874>>1]|0;G=(m&1)<<1|1;r:do{if((c[b+11740>>2]|0)==1){if((L<<n|0)==0){I=0;while(1){K=c[b+12160+(I<<3)>>2]|0;W=(c[b+12160+(I<<3)+4>>2]|0)+(Q<<n)|0;ma=((ca(c[b+12128+(I<<3)>>2]|0,D-R|0)|0)/(R|0)|0)+((I&1)<<(m&1|4))|0;S=c[b+12128+(I<<3)+4>>2]|0;if((Q<<n|0)==0){$a=I>>1;Lc=((ca(S,D-R|0)|0)/(R|0)|0)+($a<<(m&1|4))|0;Mc=$a}else{Lc=W-S|0;Mc=I>>1}S=((Lc&G)<<n)+(ma&G)|0;$a=(c[(b+12208|0)>>2]|0)+((ca(Mc,M<<3)|0)+(I<<3&8))|0;if((m&1|0)==0){ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(W>>1,M)|0)+(K>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((W&G)<<n)+(K&G)|0)<<2)>>2]&2047]($a,ja,M,8);ja=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Lc>>1,M)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(S<<2)>>2]&2047]($a,ja,M,8)}else{ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(W>>2,M)|0)+(K>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((W&G)<<n)+(K&G)|0)<<2)>>2]&4095]($a,ja,M);ja=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Lc>>2,M)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]($a,ja,M)}I=I+1|0;if((I|0)>=4){break r}}}if((Q<<n|0)==0){I=0;do{ja=(c[b+12160+(I<<3)>>2]|0)+(L<<n)|0;$a=c[b+12160+(I<<3)+4>>2]|0;S=ja-(c[b+12128+(I<<3)>>2]|0)|0;ma=I>>1;K=((ca(c[b+12128+(I<<3)+4>>2]|0,D-R|0)|0)/(R|0)|0)+(ma<<(m&1|4))|0;W=(c[(b+12208|0)>>2]|0)+((I<<3&8)+(ca(ma,M<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>1,M)|0)+(ja>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(((($a&G)<<n)+(ja&G)|0)<<2)>>2]&2047](W,ma,M,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,M)|0)+(S>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(S&G)|0)<<2)>>2]&2047](W,ma,M,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>2,M)|0)+(ja>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(ja&G)|0)<<2)>>2]&4095](W,ma,M);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,M)|0)+(S>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(S&G)|0)<<2)>>2]&4095](W,ma,M)}I=I+1|0;}while((I|0)<4)}else{I=0;do{ma=(c[b+12160+(I<<3)>>2]|0)+(L<<n)|0;W=(c[b+12160+(I<<3)+4>>2]|0)+(Q<<n)|0;S=ma-(c[b+12128+(I<<3)>>2]|0)|0;K=W-(c[b+12128+(I<<3)+4>>2]|0)|0;ja=(c[(b+12208|0)>>2]|0)+((I<<3&8)+(ca(I>>1,M<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(W>>1,M)|0)+(ma>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((W&G)<<n)+(ma&G)|0)<<2)>>2]&2047](ja,$a,M,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,M)|0)+(S>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(S&G)|0)<<2)>>2]&2047](ja,$a,M,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(W>>2,M)|0)+(ma>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((W&G)<<n)+(ma&G)|0)<<2)>>2]&4095](ja,$a,M);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,M)|0)+(S>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(S&G)|0)<<2)>>2]&4095](ja,$a,M)}I=I+1|0;}while((I|0)<4)}}else{I=(c[b+12160>>2]|0)+(L<<n)|0;$a=(c[b+12164>>2]|0)+(Q<<n)|0;ja=c[b+12128>>2]|0;if((L<<n|0)==0){Nc=(ca(ja,D-R|0)|0)/(R|0)|0}else{Nc=I-ja|0}ja=c[b+12132>>2]|0;if((Q<<n|0)==0){Oc=(ca(ja,D-R|0)|0)/(R|0)|0}else{Oc=$a-ja|0}ja=((Oc&G)<<n)+(Nc&G)|0;if((m&1|0)==0){S=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>1,M)|0)+(I>>1))|0;mf[c[(c[b+12444>>2]|0)+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,S,M,16);S=(c[b+12352+(j<<4)+32>>2]|0)+((ca(Oc>>1,M)|0)+(Nc>>1))|0;mf[c[(c[b+12448>>2]|0)+(ja<<2)>>2]&2047](c[(b+12208|0)>>2]|0,S,M,16);break}else{S=(ca($a>>2,M)|0)+(I>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+S|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(S+8|0)|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(S+(M<<3))|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((S+8|0)+(M<<3))|0,M);S=(ca(Oc>>2,M)|0)+(Nc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+S|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(S+8|0)|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(S+(M<<3))|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((S+8|0)+(M<<3))|0,M);break}}}while(0);Kc=Xe[z&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,M,16)|0}}while(0);c[(N+(((Q<<3)+L&63)<<2)|0)>>2]=(L+A|0)+(Q<<11)|0;c[V+(((Q<<3)+L&63)<<2)>>2]=Kc;G=(ca((d[_+((Q<<n)-F)|0]|0)+(d[_+((L<<n)-H)|0]|0)|0,l)|0)+Kc|0;if((G|0)>=(Dc|0)){Jc=Dc;break}c[r>>2]=L;c[(r+4|0)>>2]=Q;Jc=G}}while(0);Q=tc-1|0;G=(Q|0)>(C|0)?C:Q;Q=(y|0)>(G|0)?y:G;do{if((c[(N+((Q+(O<<3)&63)<<2)|0)>>2]|0)==(((O<<11)+A|0)+Q|0|0)){Pc=Jc}else{do{if((m&4|0)==0){G=c[b+12416>>2]|0;R=c[b+12420>>2]|0;D=(c[b+12352+(j<<4)>>2]|0)+((ca(G,O)|0)+Q)|0;B=Xe[z&511](b,c[b+12288+(h<<4)>>2]|0,D,G,8)|0;if((m&2|0)==0){Qc=B;break}D=c[b+12208>>2]|0;S=(ca(R,O>>1)|0)+(Q>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((Q&1|O<<1&2)<<2)>>2]&2047](D+(G<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+S|0,R,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((Q&1|O<<1&2)<<2)>>2]&2047](D+(G<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+S|0,R,4);S=(Xe[T&511](b,D+(G<<4)|0,c[b+12288+(h<<4)+4>>2]|0,R,4)|0)+B|0;Qc=S+(Xe[T&511](b,D+(G<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,R,4)|0)|0}else{R=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(Q|0)){Qc=536870912;break}if((Q<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Qc=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Qc=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Qc=536870912;break}G=e[b+13872>>1]|0;D=e[b+13874>>1]|0;S=(m&1)<<1|1;s:do{if((c[b+11740>>2]|0)==1){if((Q<<n|0)==0){B=0;while(1){ja=c[b+12160+(B<<3)>>2]|0;I=(c[b+12160+(B<<3)+4>>2]|0)+(O<<n)|0;$a=((ca(c[b+12128+(B<<3)>>2]|0,D-G|0)|0)/(G|0)|0)+((B&1)<<(m&1|4))|0;K=c[b+12128+(B<<3)+4>>2]|0;if((O<<n|0)==0){ma=B>>1;Rc=((ca(K,D-G|0)|0)/(G|0)|0)+(ma<<(m&1|4))|0;Sc=ma}else{Rc=I-K|0;Sc=B>>1}K=((Rc&S)<<n)+($a&S)|0;ma=(c[(b+12208|0)>>2]|0)+((ca(Sc,R<<3)|0)+(B<<3&8))|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(I>>1,R)|0)+(ja>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((I&S)<<n)+(ja&S)|0)<<2)>>2]&2047](ma,W,R,8);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Rc>>1,R)|0)+($a>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(K<<2)>>2]&2047](ma,W,R,8)}else{W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(I>>2,R)|0)+(ja>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((I&S)<<n)+(ja&S)|0)<<2)>>2]&4095](ma,W,R);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Rc>>2,R)|0)+($a>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095](ma,W,R)}B=B+1|0;if((B|0)>=4){break s}}}if((O<<n|0)==0){B=0;do{W=(c[b+12160+(B<<3)>>2]|0)+(Q<<n)|0;ma=c[b+12160+(B<<3)+4>>2]|0;K=W-(c[b+12128+(B<<3)>>2]|0)|0;$a=B>>1;ja=((ca(c[b+12128+(B<<3)+4>>2]|0,D-G|0)|0)/(G|0)|0)+($a<<(m&1|4))|0;I=(c[(b+12208|0)>>2]|0)+((B<<3&8)+(ca($a,R<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,R)|0)+(W>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&S)<<n)+(W&S)|0)<<2)>>2]&2047](I,$a,R,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ja>>1,R)|0)+(K>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&2047](I,$a,R,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>2,R)|0)+(W>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(W&S)|0)<<2)>>2]&4095](I,$a,R);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ja>>2,R)|0)+(K>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&4095](I,$a,R)}B=B+1|0;}while((B|0)<4)}else{B=0;do{$a=(c[b+12160+(B<<3)>>2]|0)+(Q<<n)|0;I=(c[b+12160+(B<<3)+4>>2]|0)+(O<<n)|0;K=$a-(c[b+12128+(B<<3)>>2]|0)|0;ja=I-(c[b+12128+(B<<3)+4>>2]|0)|0;W=(c[(b+12208|0)>>2]|0)+((B<<3&8)+(ca(B>>1,R<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(I>>1,R)|0)+($a>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((I&S)<<n)+($a&S)|0)<<2)>>2]&2047](W,ma,R,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ja>>1,R)|0)+(K>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&2047](W,ma,R,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(I>>2,R)|0)+($a>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((I&S)<<n)+($a&S)|0)<<2)>>2]&4095](W,ma,R);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ja>>2,R)|0)+(K>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&4095](W,ma,R)}B=B+1|0;}while((B|0)<4)}}else{B=(c[b+12160>>2]|0)+(Q<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;W=c[b+12128>>2]|0;if((Q<<n|0)==0){Tc=(ca(W,D-G|0)|0)/(G|0)|0}else{Tc=B-W|0}W=c[b+12132>>2]|0;if((O<<n|0)==0){Uc=(ca(W,D-G|0)|0)/(G|0)|0}else{Uc=ma-W|0}W=((Uc&S)<<n)+(Tc&S)|0;if((m&1|0)==0){K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,R)|0)+(B>>1))|0;mf[c[(c[b+12444>>2]|0)+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,K,R,16);K=(c[b+12352+(j<<4)+32>>2]|0)+((ca(Uc>>1,R)|0)+(Tc>>1))|0;mf[c[(c[b+12448>>2]|0)+(W<<2)>>2]&2047](c[(b+12208|0)>>2]|0,K,R,16);break}else{K=(ca(ma>>2,R)|0)+(B>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+K|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(K+8|0)|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(K+(R<<3))|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((K+8|0)+(R<<3))|0,R);K=(ca(Uc>>2,R)|0)+(Tc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+K|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(K+8|0)|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(K+(R<<3))|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((K+8|0)+(R<<3))|0,R);break}}}while(0);Qc=Xe[z&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,R,16)|0}}while(0);c[(N+((Q+(O<<3)&63)<<2)|0)>>2]=((O<<11)+A|0)+Q|0;c[V+((Q+(O<<3)&63)<<2)>>2]=Qc;S=(ca((d[_+((O<<n)-F)|0]|0)+(d[_+((Q<<n)-H)|0]|0)|0,l)|0)+Qc|0;if((S|0)>=(Jc|0)){Pc=Jc;break}c[r>>2]=Q;c[(r+4|0)>>2]=O;Pc=S}}while(0);O=uc-1|0;Q=(O|0)>(x|0)?x:O;O=(E|0)>(Q|0)?E:Q;if((c[(N+(((O<<3)+L&63)<<2)|0)>>2]|0)==((L+A|0)+(O<<11)|0|0)){t=Pc;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}do{if((m&4|0)==0){Q=c[b+12416>>2]|0;y=c[b+12420>>2]|0;C=(c[b+12352+(j<<4)>>2]|0)+((ca(Q,O)|0)+L)|0;S=Xe[z&511](b,c[b+12288+(h<<4)>>2]|0,C,Q,8)|0;if((m&2|0)==0){Vc=S;break}C=c[b+12208>>2]|0;G=(ca(y,O>>1)|0)+(L>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((O<<1&2|L&1)<<2)>>2]&2047](C+(Q<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+G|0,y,4);mf[c[(c[(b+12444|0)>>2]|0)+16+((O<<1&2|L&1)<<2)>>2]&2047](C+(Q<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+G|0,y,4);G=(Xe[T&511](b,C+(Q<<4)|0,c[b+12288+(h<<4)+4>>2]|0,y,4)|0)+S|0;Vc=G+(Xe[T&511](b,C+(Q<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,y,4)|0)|0}else{y=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(L|0)){Vc=536870912;break}if((L<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Vc=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Vc=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Vc=536870912;break}Q=e[b+13872>>1]|0;C=e[b+13874>>1]|0;G=(m&1)<<1|1;t:do{if((c[b+11740>>2]|0)==1){if((L<<n|0)==0){S=0;while(1){D=c[b+12160+(S<<3)>>2]|0;M=(c[b+12160+(S<<3)+4>>2]|0)+(O<<n)|0;K=((ca(c[b+12128+(S<<3)>>2]|0,C-Q|0)|0)/(Q|0)|0)+((S&1)<<(m&1|4))|0;W=c[b+12128+(S<<3)+4>>2]|0;if((O<<n|0)==0){B=S>>1;Wc=((ca(W,C-Q|0)|0)/(Q|0)|0)+(B<<(m&1|4))|0;Xc=B}else{Wc=M-W|0;Xc=S>>1}W=((Wc&G)<<n)+(K&G)|0;B=(c[(b+12208|0)>>2]|0)+((ca(Xc,y<<3)|0)+(S<<3&8))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(M>>1,y)|0)+(D>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((M&G)<<n)+(D&G)|0)<<2)>>2]&2047](B,ma,y,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Wc>>1,y)|0)+(K>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(W<<2)>>2]&2047](B,ma,y,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(M>>2,y)|0)+(D>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((M&G)<<n)+(D&G)|0)<<2)>>2]&4095](B,ma,y);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Wc>>2,y)|0)+(K>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](B,ma,y)}S=S+1|0;if((S|0)>=4){break t}}}if((O<<n|0)==0){S=0;do{R=(c[b+12160+(S<<3)>>2]|0)+(L<<n)|0;ma=c[b+12160+(S<<3)+4>>2]|0;B=R-(c[b+12128+(S<<3)>>2]|0)|0;W=S>>1;K=((ca(c[b+12128+(S<<3)+4>>2]|0,C-Q|0)|0)/(Q|0)|0)+(W<<(m&1|4))|0;D=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ca(W,y<<3)|0))|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,y)|0)+(R>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&G)<<n)+(R&G)|0)<<2)>>2]&2047](D,W,y,8);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,y)|0)+(B>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(B&G)|0)<<2)>>2]&2047](D,W,y,8)}else{W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>2,y)|0)+(R>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(R&G)|0)<<2)>>2]&4095](D,W,y);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,y)|0)+(B>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(B&G)|0)<<2)>>2]&4095](D,W,y)}S=S+1|0;}while((S|0)<4)}else{S=0;do{W=(c[b+12160+(S<<3)>>2]|0)+(L<<n)|0;D=(c[b+12160+(S<<3)+4>>2]|0)+(O<<n)|0;B=W-(c[b+12128+(S<<3)>>2]|0)|0;K=D-(c[b+12128+(S<<3)+4>>2]|0)|0;R=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ca(S>>1,y<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(D>>1,y)|0)+(W>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((D&G)<<n)+(W&G)|0)<<2)>>2]&2047](R,ma,y,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,y)|0)+(B>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(B&G)|0)<<2)>>2]&2047](R,ma,y,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(D>>2,y)|0)+(W>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((D&G)<<n)+(W&G)|0)<<2)>>2]&4095](R,ma,y);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,y)|0)+(B>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(B&G)|0)<<2)>>2]&4095](R,ma,y)}S=S+1|0;}while((S|0)<4)}}else{S=(c[b+12160>>2]|0)+(L<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;R=c[b+12128>>2]|0;if((L<<n|0)==0){Yc=(ca(R,C-Q|0)|0)/(Q|0)|0}else{Yc=S-R|0}R=c[b+12132>>2]|0;if((O<<n|0)==0){Zc=(ca(R,C-Q|0)|0)/(Q|0)|0}else{Zc=ma-R|0}R=((Zc&G)<<n)+(Yc&G)|0;if((m&1|0)==0){B=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,y)|0)+(S>>1))|0;mf[c[(c[b+12444>>2]|0)+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,B,y,16);B=(c[b+12352+(j<<4)+32>>2]|0)+((ca(Zc>>1,y)|0)+(Yc>>1))|0;mf[c[(c[b+12448>>2]|0)+(R<<2)>>2]&2047](c[(b+12208|0)>>2]|0,B,y,16);break}else{B=(ca(ma>>2,y)|0)+(S>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+B|0,y);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(B+8|0)|0,y);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(y<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(B+(y<<3))|0,y);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((y<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((B+8|0)+(y<<3))|0,y);B=(ca(Zc>>2,y)|0)+(Yc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+B|0,y);ef[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(B+8|0)|0,y);ef[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(y<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(B+(y<<3))|0,y);ef[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((y<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((B+8|0)+(y<<3))|0,y);break}}}while(0);Vc=Xe[z&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,y,16)|0}}while(0);c[(N+(((O<<3)+L&63)<<2)|0)>>2]=(L+A|0)+(O<<11)|0;c[V+(((O<<3)+L&63)<<2)>>2]=Vc;z=(ca((d[_+((O<<n)-F)|0]|0)+(d[_+((L<<n)-H)|0]|0)|0,l)|0)+Vc|0;if((z|0)>=(Pc|0)){t=Pc;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}c[r>>2]=L;c[(r+4|0)>>2]=O;t=z;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19144>>2]=6;c[a+19148>>2]=t|0;break a}while(0);c[a+19096>>2]=t;c[a+19104>>2]=u;c[a+19112>>2]=v;c[a+19120>>2]=w}function _epzs_motion_search4$0(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0;b=c[a+16>>2]|0;f=c[a+24>>2]|0;g=c[a+32>>2]|0;h=c[a+48>>2]|0;j=c[a+56>>2]|0;k=c[a+80>>2]|0;l=c[a+88>>2]|0;m=c[a+176>>2]|0;n=c[a+192>>2]|0;o=c[a+6144>>2]|0;p=c[a+6152>>2]|0;q=c[a+6160>>2]|0;r=c[a+6168>>2]|0;s=c[a+6176>>2]|0;t=c[a+19104>>2]|0;u=c[a+19112>>2]|0;v=c[a+19120>>2]|0;w=c[a+19128>>2]|0;a:do{if((s|0)<2){x=c[(b+12220|0)>>2]|0;y=c[(b+12264|0)>>2]|0;z=c[(b+12272|0)>>2]|0;A=c[(b+12268|0)>>2]|0;B=c[(b+12276|0)>>2]|0;C=c[(b+12464|0)>>2]|0;D=c[(b+12280|0)>>2]|0;E=c[(b+12284|0)>>2]|0;F=c[(b+12216|0)>>2]|0;G=c[(b+12224|0)>>2]|0;H=c[(b+10472|0)>>2]|0;I=c[(b+10476|0)>>2]|0;J=p+G+(o<<11)|0;K=(o<<3)+p&63;if((c[(F+(K<<2)|0)>>2]|0)!=(J|0)){do{if((m&4|0)==0){L=c[b+12416>>2]|0;M=c[b+12420>>2]|0;N=(c[b+12352+(j<<4)>>2]|0)+((ca(L,o)|0)+p)|0;O=Xe[H&511](b,c[b+12288+(h<<4)>>2]|0,N,L,8)|0;if((m&2|0)==0){P=O;break}N=o<<1&2|p&1;Q=c[b+12208>>2]|0;R=(ca(M,o>>1)|0)+(p>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+(N<<2)>>2]&2047](Q+(L<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+R|0,M,4);mf[c[(c[(b+12444|0)>>2]|0)+32+(N<<2)>>2]&2047](Q+(L<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+R|0,M,4);R=(Xe[I&511](b,Q+(L<<4)|0,c[b+12288+(h<<4)+4>>2]|0,M,4)|0)+O|0;P=R+(Xe[I&511](b,Q+(L<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,M,4)|0)|0}else{M=c[b+12416>>2]|0;L=p<<n;Q=o<<n;if((y|0)>(p|0)){P=536870912;break}if((L|0)>(A<<n|0)|(z|0)>(o|0)){P=536870912;break}if((Q|0)>(B<<n|0)){P=536870912;break}R=e[b+13872>>1]|0;O=e[b+13874>>1]|0;N=(m&1)<<1|1;b:do{if((c[b+11740>>2]|0)==1){if((L|0)==0){S=0;while(1){T=c[b+12160+(S<<3)>>2]|0;U=(c[b+12160+(S<<3)+4>>2]|0)+Q|0;V=((ca(c[b+12128+(S<<3)>>2]|0,O-R|0)|0)/(R|0)|0)+((S&1)<<(m&1|4))|0;W=c[b+12128+(S<<3)+4>>2]|0;if((Q|0)==0){X=S>>1;Y=((ca(W,O-R|0)|0)/(R|0)|0)+(X<<(m&1|4))|0;Z=X}else{Y=U-W|0;Z=S>>1}W=((Y&N)<<n)+(V&N)|0;X=(c[(b+12208|0)>>2]|0)+((ca(Z,M<<3)|0)+(S<<3&8))|0;if((m&1|0)==0){_=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,M)|0)+(T>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(T&N)|0)<<2)>>2]&2047](X,_,M,8);_=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Y>>1,M)|0)+(V>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(W<<2)>>2]&2047](X,_,M,8)}else{_=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,M)|0)+(T>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(T&N)|0)<<2)>>2]&4095](X,_,M);_=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Y>>2,M)|0)+(V>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](X,_,M)}S=S+1|0;if((S|0)>=4){break b}}}if((Q|0)==0){S=0;do{_=(c[b+12160+(S<<3)>>2]|0)+L|0;X=c[b+12160+(S<<3)+4>>2]|0;W=_-(c[b+12128+(S<<3)>>2]|0)|0;V=S>>1;T=((ca(c[b+12128+(S<<3)+4>>2]|0,O-R|0)|0)/(R|0)|0)+(V<<(m&1|4))|0;U=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ca(V,M<<3)|0))|0;if((m&1|0)==0){V=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(X>>1,M)|0)+(_>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((X&N)<<n)+(_&N)|0)<<2)>>2]&2047](U,V,M,8);V=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(T>>1,M)|0)+(W>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((T&N)<<n)+(W&N)|0)<<2)>>2]&2047](U,V,M,8)}else{V=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(X>>2,M)|0)+(_>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(_&N)|0)<<2)>>2]&4095](U,V,M);V=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(T>>2,M)|0)+(W>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((T&N)<<n)+(W&N)|0)<<2)>>2]&4095](U,V,M)}S=S+1|0;}while((S|0)<4)}else{S=0;do{V=(c[b+12160+(S<<3)>>2]|0)+L|0;U=(c[b+12160+(S<<3)+4>>2]|0)+Q|0;W=V-(c[b+12128+(S<<3)>>2]|0)|0;T=U-(c[b+12128+(S<<3)+4>>2]|0)|0;_=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ca(S>>1,M<<3)|0))|0;if((m&1|0)==0){X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,M)|0)+(V>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(V&N)|0)<<2)>>2]&2047](_,X,M,8);X=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(T>>1,M)|0)+(W>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((T&N)<<n)+(W&N)|0)<<2)>>2]&2047](_,X,M,8)}else{X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,M)|0)+(V>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(V&N)|0)<<2)>>2]&4095](_,X,M);X=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(T>>2,M)|0)+(W>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((T&N)<<n)+(W&N)|0)<<2)>>2]&4095](_,X,M)}S=S+1|0;}while((S|0)<4)}}else{S=(c[b+12160>>2]|0)+L|0;X=(c[b+12164>>2]|0)+Q|0;_=c[b+12128>>2]|0;if((L|0)==0){$=(ca(_,O-R|0)|0)/(R|0)|0}else{$=S-_|0}_=c[b+12132>>2]|0;if((Q|0)==0){aa=(ca(_,O-R|0)|0)/(R|0)|0}else{aa=X-_|0}_=((aa&N)<<n)+($&N)|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(X>>1,M)|0)+(S>>1))|0;mf[c[(c[b+12444>>2]|0)+((((X&N)<<n)+(S&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,W,M,16);W=(c[b+12352+(j<<4)+32>>2]|0)+((ca(aa>>1,M)|0)+($>>1))|0;mf[c[(c[b+12448>>2]|0)+(_<<2)>>2]&2047](c[(b+12208|0)>>2]|0,W,M,16);break}else{W=(ca(X>>2,M)|0)+(S>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+W|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(W+8|0)|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(W+(M<<3))|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+((((X&N)<<n)+(S&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((W+8|0)+(M<<3))|0,M);W=(ca(aa>>2,M)|0)+($>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+W|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(W+8|0)|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(W+(M<<3))|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(_<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((W+8|0)+(M<<3))|0,M);break}}}while(0);P=Xe[H&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,M,16)|0}}while(0);c[x+(K<<2)>>2]=P;c[(F+(K<<2)|0)>>2]=J}N=(m&1)<<1|1;R=m&1|4;O=(m&1|0)==0;Q=q;L=-1;W=p;_=o;c:while(1){do{if((L|0)!=2&(W|0)>(y|0)){S=W-1|0;X=S+G+(_<<11)|0;T=(_<<3)+S&63;if((c[(F+(T<<2)|0)>>2]|0)==(X|0)){ba=Q;da=-1;ea=W;break}V=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){U=c[(b+12420|0)>>2]|0;fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(V,_)|0)+S)|0;ga=Xe[H&511](b,c[(b+12288+(h<<4)|0)>>2]|0,fa,V,8)|0;if((m&2|0)==0){ha=ga;break}fa=_<<1&2|S&1;ia=c[(b+12208|0)>>2]|0;ja=(ca(U,_>>1)|0)+(S>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+(fa<<2)>>2]&2047](ia+(V<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ja|0,U,4);mf[c[(c[(b+12444|0)>>2]|0)+32+(fa<<2)>>2]&2047](ia+(V<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ja|0,U,4);ja=(Xe[I&511](b,ia+(V<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,U,4)|0)+ga|0;ha=ja+(Xe[I&511](b,ia+(V<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,U,4)|0)|0}else{U=_<<n;if((c[(b+12264|0)>>2]|0)>(S|0)){ha=536870912;break}if((S<<n|0)>(c[(b+12268|0)>>2]<<n|0)){ha=536870912;break}if((c[(b+12272|0)>>2]|0)>(_|0)){ha=536870912;break}if((U|0)>(c[(b+12276|0)>>2]<<n|0)){ha=536870912;break}ia=e[(b+13872|0)>>1]|0;ja=e[(b+13874|0)>>1]|0;d:do{if((c[(b+11740|0)>>2]|0)==1){if((S<<n|0)==0){ga=0;while(1){fa=c[b+12160+(ga<<3)>>2]|0;ka=(c[b+12160+(ga<<3)+4>>2]|0)+U|0;la=((ca(c[b+12128+(ga<<3)>>2]|0,ja-ia|0)|0)/(ia|0)|0)+((ga&1)<<R)|0;ma=c[b+12128+(ga<<3)+4>>2]|0;if((U|0)==0){na=ga>>1;oa=((ca(ma,ja-ia|0)|0)/(ia|0)|0)+(na<<R)|0;pa=na}else{oa=ka-ma|0;pa=ga>>1}ma=((oa&N)<<n)+(la&N)|0;na=(c[(b+12208|0)>>2]|0)+((ca(pa,V<<3)|0)+(ga<<3&8))|0;if(O){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,V)|0)+(fa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&N)<<n)+(fa&N)|0)<<2)>>2]&2047](na,qa,V,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(oa>>1,V)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ma<<2)>>2]&2047](na,qa,V,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>2,V)|0)+(fa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&N)<<n)+(fa&N)|0)<<2)>>2]&4095](na,qa,V);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(oa>>2,V)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](na,qa,V)}ga=ga+1|0;if((ga|0)>=4){break d}}}if((U|0)==0){ga=0;do{qa=(c[b+12160+(ga<<3)>>2]|0)+(S<<n)|0;na=c[b+12160+(ga<<3)+4>>2]|0;ma=qa-(c[b+12128+(ga<<3)>>2]|0)|0;la=ga>>1;fa=((ca(c[b+12128+(ga<<3)+4>>2]|0,ja-ia|0)|0)/(ia|0)|0)+(la<<R)|0;ka=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(la,V<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,V)|0)+(qa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((na&N)<<n)+(qa&N)|0)<<2)>>2]&2047](ka,la,V,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(fa>>1,V)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&2047](ka,la,V,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>2,V)|0)+(qa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(qa&N)|0)<<2)>>2]&4095](ka,la,V);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(fa>>2,V)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](ka,la,V)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{la=(c[b+12160+(ga<<3)>>2]|0)+(S<<n)|0;ka=(c[b+12160+(ga<<3)+4>>2]|0)+U|0;ma=la-(c[b+12128+(ga<<3)>>2]|0)|0;fa=ka-(c[b+12128+(ga<<3)+4>>2]|0)|0;qa=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(ga>>1,V<<3)|0))|0;if(O){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,V)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&N)<<n)+(la&N)|0)<<2)>>2]&2047](qa,na,V,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(fa>>1,V)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&2047](qa,na,V,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>2,V)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&N)<<n)+(la&N)|0)<<2)>>2]&4095](qa,na,V);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(fa>>2,V)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](qa,na,V)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+(S<<n)|0;na=(c[(b+12164|0)>>2]|0)+U|0;qa=c[(b+12128|0)>>2]|0;if((S<<n|0)==0){ra=(ca(qa,ja-ia|0)|0)/(ia|0)|0}else{ra=ga-qa|0}qa=c[(b+12132|0)>>2]|0;if((U|0)==0){sa=(ca(qa,ja-ia|0)|0)/(ia|0)|0}else{sa=na-qa|0}qa=((sa&N)<<n)+(ra&N)|0;if(O){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,V)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ma,V,16);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(sa>>1,V)|0)+(ra>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(qa<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ma,V,16);break}else{ma=(ca(na>>2,V)|0)+(ga>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ma|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+8|0)|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+(V<<3))|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ma+8|0)+(V<<3))|0,V);ma=(ca(sa>>2,V)|0)+(ra>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ma|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+8|0)|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+(V<<3))|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ma+8|0)+(V<<3))|0,V);break}}}while(0);ha=Xe[H&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,V,16)|0}}while(0);c[(F+(T<<2)|0)>>2]=X;c[x+(T<<2)>>2]=ha;V=(ca((d[C+((_<<n)-E)|0]|0)+(d[C+((S<<n)-D)|0]|0)|0,l)|0)+ha|0;if((V|0)>=(Q|0)){ba=Q;da=-1;ea=W;break}c[r>>2]=S;c[(r+4|0)>>2]=_;ba=V;da=0;ea=S}else{ba=Q;da=-1;ea=W}}while(0);do{if((L|0)!=3&(_|0)>(z|0)){M=_-1|0;V=W+G+(M<<11)|0;ia=(M<<3)+W&63;if((c[(F+(ia<<2)|0)>>2]|0)==(V|0)){ta=ba;ua=da;va=ea;wa=_;break}ja=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){U=c[(b+12420|0)>>2]|0;ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja,M)|0)+W)|0;qa=Xe[H&511](b,c[(b+12288+(h<<4)|0)>>2]|0,ma,ja,8)|0;if((m&2|0)==0){xa=qa;break}ma=M<<1&2|W&1;ga=c[(b+12208|0)>>2]|0;na=(ca(U,M>>1)|0)+(W>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+(ma<<2)>>2]&2047](ga+(ja<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+na|0,U,4);mf[c[(c[(b+12444|0)>>2]|0)+32+(ma<<2)>>2]&2047](ga+(ja<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+na|0,U,4);na=(Xe[I&511](b,ga+(ja<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,U,4)|0)+qa|0;xa=na+(Xe[I&511](b,ga+(ja<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,U,4)|0)|0}else{U=W<<n;if((c[(b+12264|0)>>2]|0)>(W|0)){xa=536870912;break}if((U|0)>(c[(b+12268|0)>>2]<<n|0)){xa=536870912;break}if((c[(b+12272|0)>>2]|0)>(M|0)){xa=536870912;break}if((M<<n|0)>(c[(b+12276|0)>>2]<<n|0)){xa=536870912;break}ga=e[(b+13872|0)>>1]|0;na=e[(b+13874|0)>>1]|0;e:do{if((c[(b+11740|0)>>2]|0)==1){if((U|0)==0){qa=0;while(1){ma=c[b+12160+(qa<<3)>>2]|0;fa=(c[b+12160+(qa<<3)+4>>2]|0)+(M<<n)|0;la=((ca(c[b+12128+(qa<<3)>>2]|0,na-ga|0)|0)/(ga|0)|0)+((qa&1)<<R)|0;ka=c[b+12128+(qa<<3)+4>>2]|0;if((M<<n|0)==0){ya=qa>>1;za=((ca(ka,na-ga|0)|0)/(ga|0)|0)+(ya<<R)|0;Aa=ya}else{za=fa-ka|0;Aa=qa>>1}ka=((za&N)<<n)+(la&N)|0;ya=(c[(b+12208|0)>>2]|0)+((ca(Aa,ja<<3)|0)+(qa<<3&8))|0;if(O){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>1,ja)|0)+(ma>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&2047](ya,Ba,ja,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(za>>1,ja)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&2047](ya,Ba,ja,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>2,ja)|0)+(ma>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((fa&N)<<n)+(ma&N)|0)<<2)>>2]&4095](ya,Ba,ja);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(za>>2,ja)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](ya,Ba,ja)}qa=qa+1|0;if((qa|0)>=4){break e}}}if((M<<n|0)==0){qa=0;do{Ba=(c[b+12160+(qa<<3)>>2]|0)+U|0;ya=c[b+12160+(qa<<3)+4>>2]|0;ka=Ba-(c[b+12128+(qa<<3)>>2]|0)|0;la=qa>>1;ma=((ca(c[b+12128+(qa<<3)+4>>2]|0,na-ga|0)|0)/(ga|0)|0)+(la<<R)|0;fa=(c[(b+12208|0)>>2]|0)+((qa<<3&8)+(ca(la,ja<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,ja)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&N)<<n)+(Ba&N)|0)<<2)>>2]&2047](fa,la,ja,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ma>>1,ja)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&2047](fa,la,ja,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>2,ja)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(Ba&N)|0)<<2)>>2]&4095](fa,la,ja);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ma>>2,ja)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&4095](fa,la,ja)}qa=qa+1|0;}while((qa|0)<4)}else{qa=0;do{la=(c[b+12160+(qa<<3)>>2]|0)+U|0;fa=(c[b+12160+(qa<<3)+4>>2]|0)+(M<<n)|0;ka=la-(c[b+12128+(qa<<3)>>2]|0)|0;ma=fa-(c[b+12128+(qa<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((qa<<3&8)+(ca(qa>>1,ja<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>1,ja)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&N)<<n)+(la&N)|0)<<2)>>2]&2047](Ba,ya,ja,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ma>>1,ja)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&2047](Ba,ya,ja,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>2,ja)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((fa&N)<<n)+(la&N)|0)<<2)>>2]&4095](Ba,ya,ja);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ma>>2,ja)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ma&N)<<n)+(ka&N)|0)<<2)>>2]&4095](Ba,ya,ja)}qa=qa+1|0;}while((qa|0)<4)}}else{qa=(c[(b+12160|0)>>2]|0)+U|0;ya=(c[(b+12164|0)>>2]|0)+(M<<n)|0;Ba=c[(b+12128|0)>>2]|0;if((U|0)==0){Ca=(ca(Ba,na-ga|0)|0)/(ga|0)|0}else{Ca=qa-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((M<<n|0)==0){Da=(ca(Ba,na-ga|0)|0)/(ga|0)|0}else{Da=ya-Ba|0}Ba=((Da&N)<<n)+(Ca&N)|0;if(O){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,ja)|0)+(qa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,ja,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Da>>1,ja)|0)+(Ca>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,ja,16);break}else{ka=(ca(ya>>2,ja)|0)+(qa>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,ja);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,ja);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ja<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(ja<<3))|0,ja);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(ja<<3))|0,ja);ka=(ca(Da>>2,ja)|0)+(Ca>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,ja);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,ja);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ja<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(ja<<3))|0,ja);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ja<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(ja<<3))|0,ja);break}}}while(0);xa=Xe[H&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ja,16)|0}}while(0);c[(F+(ia<<2)|0)>>2]=V;c[x+(ia<<2)>>2]=xa;ja=(ca((d[C+((M<<n)-E)|0]|0)+(d[C+((W<<n)-D)|0]|0)|0,l)|0)+xa|0;if((ja|0)>=(ba|0)){ta=ba;ua=da;va=ea;wa=_;break}c[r>>2]=W;c[(r+4|0)>>2]=M;ta=ja;ua=1;va=W;wa=M}else{ta=ba;ua=da;va=ea;wa=_}}while(0);do{if((L|0)!=0&(W|0)<(A|0)){ja=W+1|0;S=ja+G+(_<<11)|0;T=(_<<3)+ja&63;if((c[(F+(T<<2)|0)>>2]|0)==(S|0)){Ea=ta;Fa=ua;Ga=va;Ha=wa;break}X=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ga=c[(b+12420|0)>>2]|0;na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(X,_)|0)+ja)|0;U=Xe[H&511](b,c[(b+12288+(h<<4)|0)>>2]|0,na,X,8)|0;if((m&2|0)==0){Ia=U;break}na=_<<1&2|ja&1;ka=c[(b+12208|0)>>2]|0;Ba=(ca(ga,_>>1)|0)+(ja>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+(na<<2)>>2]&2047](ka+(X<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+Ba|0,ga,4);mf[c[(c[(b+12444|0)>>2]|0)+32+(na<<2)>>2]&2047](ka+(X<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+Ba|0,ga,4);Ba=(Xe[I&511](b,ka+(X<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ga,4)|0)+U|0;Ia=Ba+(Xe[I&511](b,ka+(X<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ga,4)|0)|0}else{ga=_<<n;if((c[(b+12264|0)>>2]|0)>(ja|0)){Ia=536870912;break}if((ja<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Ia=536870912;break}if((c[(b+12272|0)>>2]|0)>(_|0)){Ia=536870912;break}if((ga|0)>(c[(b+12276|0)>>2]<<n|0)){Ia=536870912;break}ka=e[(b+13872|0)>>1]|0;Ba=e[(b+13874|0)>>1]|0;f:do{if((c[(b+11740|0)>>2]|0)==1){if((ja<<n|0)==0){U=0;while(1){na=c[b+12160+(U<<3)>>2]|0;qa=(c[b+12160+(U<<3)+4>>2]|0)+ga|0;ya=((ca(c[b+12128+(U<<3)>>2]|0,Ba-ka|0)|0)/(ka|0)|0)+((U&1)<<R)|0;ma=c[b+12128+(U<<3)+4>>2]|0;if((ga|0)==0){la=U>>1;Ja=((ca(ma,Ba-ka|0)|0)/(ka|0)|0)+(la<<R)|0;Ka=la}else{Ja=qa-ma|0;Ka=U>>1}ma=((Ja&N)<<n)+(ya&N)|0;la=(c[(b+12208|0)>>2]|0)+((ca(Ka,X<<3)|0)+(U<<3&8))|0;if(O){fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa>>1,X)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((qa&N)<<n)+(na&N)|0)<<2)>>2]&2047](la,fa,X,8);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ja>>1,X)|0)+(ya>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ma<<2)>>2]&2047](la,fa,X,8)}else{fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa>>2,X)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((qa&N)<<n)+(na&N)|0)<<2)>>2]&4095](la,fa,X);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ja>>2,X)|0)+(ya>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ma<<2)>>2]&4095](la,fa,X)}U=U+1|0;if((U|0)>=4){break f}}}if((ga|0)==0){U=0;do{fa=(c[b+12160+(U<<3)>>2]|0)+(ja<<n)|0;la=c[b+12160+(U<<3)+4>>2]|0;ma=fa-(c[b+12128+(U<<3)>>2]|0)|0;ya=U>>1;na=((ca(c[b+12128+(U<<3)+4>>2]|0,Ba-ka|0)|0)/(ka|0)|0)+(ya<<R)|0;qa=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(ya,X<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(la>>1,X)|0)+(fa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((la&N)<<n)+(fa&N)|0)<<2)>>2]&2047](qa,ya,X,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>1,X)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&2047](qa,ya,X,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(la>>2,X)|0)+(fa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(fa&N)|0)<<2)>>2]&4095](qa,ya,X);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>2,X)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&4095](qa,ya,X)}U=U+1|0;}while((U|0)<4)}else{U=0;do{ya=(c[b+12160+(U<<3)>>2]|0)+(ja<<n)|0;qa=(c[b+12160+(U<<3)+4>>2]|0)+ga|0;ma=ya-(c[b+12128+(U<<3)>>2]|0)|0;na=qa-(c[b+12128+(U<<3)+4>>2]|0)|0;fa=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(U>>1,X<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa>>1,X)|0)+(ya>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((qa&N)<<n)+(ya&N)|0)<<2)>>2]&2047](fa,la,X,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>1,X)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&2047](fa,la,X,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa>>2,X)|0)+(ya>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((qa&N)<<n)+(ya&N)|0)<<2)>>2]&4095](fa,la,X);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>2,X)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((na&N)<<n)+(ma&N)|0)<<2)>>2]&4095](fa,la,X)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(ja<<n)|0;la=(c[(b+12164|0)>>2]|0)+ga|0;fa=c[(b+12128|0)>>2]|0;if((ja<<n|0)==0){La=(ca(fa,Ba-ka|0)|0)/(ka|0)|0}else{La=U-fa|0}fa=c[(b+12132|0)>>2]|0;if((ga|0)==0){Ma=(ca(fa,Ba-ka|0)|0)/(ka|0)|0}else{Ma=la-fa|0}fa=((Ma&N)<<n)+(La&N)|0;if(O){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(la>>1,X)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((la&N)<<n)+(U&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ma,X,16);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ma>>1,X)|0)+(La>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(fa<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ma,X,16);break}else{ma=(ca(la>>2,X)|0)+(U>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ma|0,X);ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+8|0)|0,X);ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(X<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ma+(X<<3))|0,X);ef[c[(c[(b+12452|0)>>2]|0)+64+((((la&N)<<n)+(U&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((X<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ma+8|0)+(X<<3))|0,X);ma=(ca(Ma>>2,X)|0)+(La>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ma|0,X);ef[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+8|0)|0,X);ef[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(X<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ma+(X<<3))|0,X);ef[c[(c[(b+12456|0)>>2]|0)+64+(fa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((X<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ma+8|0)+(X<<3))|0,X);break}}}while(0);Ia=Xe[H&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,X,16)|0}}while(0);c[(F+(T<<2)|0)>>2]=S;c[x+(T<<2)>>2]=Ia;X=(ca((d[C+((_<<n)-E)|0]|0)+(d[C+((ja<<n)-D)|0]|0)|0,l)|0)+Ia|0;if((X|0)>=(ta|0)){Ea=ta;Fa=ua;Ga=va;Ha=wa;break}c[r>>2]=ja;c[(r+4|0)>>2]=_;Ea=X;Fa=2;Ga=ja;Ha=_}else{Ea=ta;Fa=ua;Ga=va;Ha=wa}}while(0);do{if((L|0)!=1&(_|0)<(B|0)){X=_+1|0;M=W+G+(X<<11)|0;ia=(X<<3)+W&63;if((c[(F+(ia<<2)|0)>>2]|0)==(M|0)){break}V=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ka=c[(b+12420|0)>>2]|0;Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(V,X)|0)+W)|0;ga=Xe[H&511](b,c[(b+12288+(h<<4)|0)>>2]|0,Ba,V,8)|0;if((m&2|0)==0){Na=ga;break}Ba=X<<1&2|W&1;ma=c[(b+12208|0)>>2]|0;fa=(ca(ka,X>>1)|0)+(W>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+(Ba<<2)>>2]&2047](ma+(V<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+fa|0,ka,4);mf[c[(c[(b+12444|0)>>2]|0)+32+(Ba<<2)>>2]&2047](ma+(V<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+fa|0,ka,4);fa=(Xe[I&511](b,ma+(V<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ka,4)|0)+ga|0;Na=fa+(Xe[I&511](b,ma+(V<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ka,4)|0)|0}else{ka=W<<n;if((c[(b+12264|0)>>2]|0)>(W|0)){Na=536870912;break}if((ka|0)>(c[(b+12268|0)>>2]<<n|0)){Na=536870912;break}if((c[(b+12272|0)>>2]|0)>(X|0)){Na=536870912;break}if((X<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Na=536870912;break}ma=e[(b+13872|0)>>1]|0;fa=e[(b+13874|0)>>1]|0;g:do{if((c[(b+11740|0)>>2]|0)==1){if((ka|0)==0){ga=0;while(1){Ba=c[b+12160+(ga<<3)>>2]|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(X<<n)|0;la=((ca(c[b+12128+(ga<<3)>>2]|0,fa-ma|0)|0)/(ma|0)|0)+((ga&1)<<R)|0;na=c[b+12128+(ga<<3)+4>>2]|0;if((X<<n|0)==0){ya=ga>>1;Oa=((ca(na,fa-ma|0)|0)/(ma|0)|0)+(ya<<R)|0;Pa=ya}else{Oa=U-na|0;Pa=ga>>1}na=((Oa&N)<<n)+(la&N)|0;ya=(c[(b+12208|0)>>2]|0)+((ca(Pa,V<<3)|0)+(ga<<3&8))|0;if(O){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,V)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(Ba&N)|0)<<2)>>2]&2047](ya,qa,V,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Oa>>1,V)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(na<<2)>>2]&2047](ya,qa,V,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,V)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(Ba&N)|0)<<2)>>2]&4095](ya,qa,V);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Oa>>2,V)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](ya,qa,V)}ga=ga+1|0;if((ga|0)>=4){break g}}}if((X<<n|0)==0){ga=0;do{qa=(c[b+12160+(ga<<3)>>2]|0)+ka|0;ya=c[b+12160+(ga<<3)+4>>2]|0;na=qa-(c[b+12128+(ga<<3)>>2]|0)|0;la=ga>>1;Ba=((ca(c[b+12128+(ga<<3)+4>>2]|0,fa-ma|0)|0)/(ma|0)|0)+(la<<R)|0;U=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(la,V<<3)|0))|0;if(O){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,V)|0)+(qa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&2047](U,la,V,8);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ba>>1,V)|0)+(na>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&2047](U,la,V,8)}else{la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>2,V)|0)+(qa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(qa&N)|0)<<2)>>2]&4095](U,la,V);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ba>>2,V)|0)+(na>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&4095](U,la,V)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{la=(c[b+12160+(ga<<3)>>2]|0)+ka|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(X<<n)|0;na=la-(c[b+12128+(ga<<3)>>2]|0)|0;Ba=U-(c[b+12128+(ga<<3)+4>>2]|0)|0;qa=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(ga>>1,V<<3)|0))|0;if(O){ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,V)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&N)<<n)+(la&N)|0)<<2)>>2]&2047](qa,ya,V,8);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ba>>1,V)|0)+(na>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&2047](qa,ya,V,8)}else{ya=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,V)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&N)<<n)+(la&N)|0)<<2)>>2]&4095](qa,ya,V);ya=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ba>>2,V)|0)+(na>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((Ba&N)<<n)+(na&N)|0)<<2)>>2]&4095](qa,ya,V)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+ka|0;ya=(c[(b+12164|0)>>2]|0)+(X<<n)|0;qa=c[(b+12128|0)>>2]|0;if((ka|0)==0){Qa=(ca(qa,fa-ma|0)|0)/(ma|0)|0}else{Qa=ga-qa|0}qa=c[(b+12132|0)>>2]|0;if((X<<n|0)==0){Ra=(ca(qa,fa-ma|0)|0)/(ma|0)|0}else{Ra=ya-qa|0}qa=((Ra&N)<<n)+(Qa&N)|0;if(O){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,V)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,na,V,16);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ra>>1,V)|0)+(Qa>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(qa<<2)>>2]&2047](c[(b+12208|0)>>2]|0,na,V,16);break}else{na=(ca(ya>>2,V)|0)+(ga>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+na|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(na+8|0)|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(na+(V<<3))|0,V);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&N)<<n)+(ga&N)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((na+8|0)+(V<<3))|0,V);na=(ca(Ra>>2,V)|0)+(Qa>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+na|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(na+8|0)|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(V<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(na+(V<<3))|0,V);ef[c[(c[(b+12456|0)>>2]|0)+64+(qa<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((V<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((na+8|0)+(V<<3))|0,V);break}}}while(0);Na=Xe[H&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,V,16)|0}}while(0);c[(F+(ia<<2)|0)>>2]=M;c[x+(ia<<2)>>2]=Na;V=(ca((d[C+((X<<n)-E)|0]|0)+(d[C+((W<<n)-D)|0]|0)|0,l)|0)+Na|0;if((V|0)>=(Ea|0)){break}c[r>>2]=W;c[(r+4|0)>>2]=X;Q=V;L=3;W=W;_=X;continue c}}while(0);if((Fa|0)==-1){t=Ea;break}else{Q=Ea;L=Fa;W=Ga;_=Ha}}u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}if((s|0)>1024){t=urb(b,r,q,h,j,l,1,8,m)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}if((s|0)>768){_=c[(b+12220|0)>>2]|0;W=c[(b+12264|0)>>2]|0;L=c[(b+12272|0)>>2]|0;Q=c[(b+12268|0)>>2]|0;D=c[(b+12276|0)>>2]|0;C=c[(b+12464|0)>>2]|0;E=c[(b+12280|0)>>2]|0;x=c[(b+12284|0)>>2]|0;F=c[(b+12216|0)>>2]|0;H=c[(b+12224|0)>>2]|0;N=c[(b+10472|0)>>2]|0;O=c[(b+10476|0)>>2]|0;R=p-(s&254)+1|0;I=(R|0)>(W|0)?R:W;R=(s&254)-1+p|0;G=(R|0)>(Q|0)?Q:R;if((I|0)>(G|0)){Sa=q;Ta=p;Ua=o}else{R=(o<<11)+H|0;B=o<<3;A=o<<1&2;z=o>>1;y=o<<n;J=(m&1)<<1|1;K=I;I=q;V=p;ja=o;while(1){T=R+K|0;S=K+B&63;do{if((c[(F+(S<<2)|0)>>2]|0)==(T|0)){Va=I;Wa=V;Xa=ja}else{ma=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){fa=c[(b+12420|0)>>2]|0;ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma,o)|0)+K)|0;na=Xe[N&511](b,c[(b+12288+(h<<4)|0)>>2]|0,ka,ma,8)|0;if((m&2|0)==0){Ya=na;break}ka=K&1|A;qa=c[(b+12208|0)>>2]|0;ga=(ca(fa,z)|0)+(K>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+(ka<<2)>>2]&2047](qa+(ma<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ga|0,fa,4);mf[c[(c[(b+12444|0)>>2]|0)+32+(ka<<2)>>2]&2047](qa+(ma<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ga|0,fa,4);ga=(Xe[O&511](b,qa+(ma<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,fa,4)|0)+na|0;Ya=ga+(Xe[O&511](b,qa+(ma<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,fa,4)|0)|0}else{fa=K<<n;if((c[(b+12264|0)>>2]|0)>(K|0)){Ya=536870912;break}if((fa|0)>(c[(b+12268|0)>>2]<<n|0)){Ya=536870912;break}if((c[(b+12272|0)>>2]|0)>(o|0)){Ya=536870912;break}if((y|0)>(c[(b+12276|0)>>2]<<n|0)){Ya=536870912;break}qa=e[(b+13872|0)>>1]|0;ga=e[(b+13874|0)>>1]|0;h:do{if((c[(b+11740|0)>>2]|0)==1){if((fa|0)==0){na=0;while(1){ka=c[b+12160+(na<<3)>>2]|0;ya=(c[b+12160+(na<<3)+4>>2]|0)+y|0;Ba=((ca(c[b+12128+(na<<3)>>2]|0,ga-qa|0)|0)/(qa|0)|0)+((na&1)<<(m&1|4))|0;la=c[b+12128+(na<<3)+4>>2]|0;if((y|0)==0){U=na>>1;Za=((ca(la,ga-qa|0)|0)/(qa|0)|0)+(U<<(m&1|4))|0;_a=U}else{Za=ya-la|0;_a=na>>1}la=((Za&J)<<n)+(Ba&J)|0;U=(c[(b+12208|0)>>2]|0)+((ca(_a,ma<<3)|0)+(na<<3&8))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,ma)|0)+(ka>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&J)<<n)+(ka&J)|0)<<2)>>2]&2047](U,$a,ma,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Za>>1,ma)|0)+(Ba>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&2047](U,$a,ma,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>2,ma)|0)+(ka>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&J)<<n)+(ka&J)|0)<<2)>>2]&4095](U,$a,ma);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Za>>2,ma)|0)+(Ba>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](U,$a,ma)}na=na+1|0;if((na|0)>=4){break h}}}if((y|0)==0){na=0;do{$a=(c[b+12160+(na<<3)>>2]|0)+fa|0;U=c[b+12160+(na<<3)+4>>2]|0;la=$a-(c[b+12128+(na<<3)>>2]|0)|0;Ba=na>>1;ka=((ca(c[b+12128+(na<<3)+4>>2]|0,ga-qa|0)|0)/(qa|0)|0)+(Ba<<(m&1|4))|0;ya=(c[(b+12208|0)>>2]|0)+((na<<3&8)+(ca(Ba,ma<<3)|0))|0;if((m&1|0)==0){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,ma)|0)+($a>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&J)<<n)+($a&J)|0)<<2)>>2]&2047](ya,Ba,ma,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,ma)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&2047](ya,Ba,ma,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,ma)|0)+($a>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+($a&J)|0)<<2)>>2]&4095](ya,Ba,ma);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,ma)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&4095](ya,Ba,ma)}na=na+1|0;}while((na|0)<4)}else{na=0;do{Ba=(c[b+12160+(na<<3)>>2]|0)+fa|0;ya=(c[b+12160+(na<<3)+4>>2]|0)+y|0;la=Ba-(c[b+12128+(na<<3)>>2]|0)|0;ka=ya-(c[b+12128+(na<<3)+4>>2]|0)|0;$a=(c[(b+12208|0)>>2]|0)+((na<<3&8)+(ca(na>>1,ma<<3)|0))|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>1,ma)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ya&J)<<n)+(Ba&J)|0)<<2)>>2]&2047]($a,U,ma,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,ma)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&2047]($a,U,ma,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ya>>2,ma)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ya&J)<<n)+(Ba&J)|0)<<2)>>2]&4095]($a,U,ma);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,ma)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&J)<<n)+(la&J)|0)<<2)>>2]&4095]($a,U,ma)}na=na+1|0;}while((na|0)<4)}}else{na=(c[(b+12160|0)>>2]|0)+fa|0;U=(c[(b+12164|0)>>2]|0)+y|0;$a=c[(b+12128|0)>>2]|0;if((fa|0)==0){ab=(ca($a,ga-qa|0)|0)/(qa|0)|0}else{ab=na-$a|0}$a=c[(b+12132|0)>>2]|0;if((y|0)==0){bb=(ca($a,ga-qa|0)|0)/(qa|0)|0}else{bb=U-$a|0}$a=((bb&J)<<n)+(ab&J)|0;if((m&1|0)==0){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,ma)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((U&J)<<n)+(na&J)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,ma,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(bb>>1,ma)|0)+(ab>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+($a<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,ma,16);break}else{la=(ca(U>>2,ma)|0)+(na>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(ma<<3))|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&J)<<n)+(na&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(ma<<3))|0,ma);la=(ca(bb>>2,ma)|0)+(ab>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(ma<<3))|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(ma<<3))|0,ma);break}}}while(0);Ya=Xe[N&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(S<<2)|0)>>2]=T;c[_+(S<<2)>>2]=Ya;ma=(ca((d[C+(y-x)|0]|0)+(d[C+((K<<n)-E)|0]|0)|0,l)|0)+Ya|0;if((ma|0)>=(I|0)){Va=I;Wa=V;Xa=ja;break}c[r>>2]=K;c[(r+4|0)>>2]=o;Va=ma;Wa=K;Xa=o}}while(0);S=K+2|0;if((S|0)>(G|0)){Sa=Va;Ta=Wa;Ua=Xa;break}else{K=S;I=Va;V=Wa;ja=Xa}}}ja=o-((s&254)>>>1)+1|0;V=(ja|0)>(L|0)?ja:L;ja=((s&254)>>>1)-1+o|0;I=(ja|0)>(D|0)?D:ja;if((V|0)>(I|0)){cb=Sa;db=Ta;eb=Ua}else{ja=p+H|0;K=p&1;G=p>>1;y=p<<n;J=(m&1)<<1|1;z=V;V=Sa;A=Ta;B=Ua;while(1){R=ja+(z<<11)|0;S=(z<<3)+p&63;do{if((c[(F+(S<<2)|0)>>2]|0)==(R|0)){fb=V;gb=A;hb=B}else{T=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){ma=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(T,z)|0)+p)|0;ia=Xe[N&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,T,8)|0;if((m&2|0)==0){ib=ia;break}X=z<<1&2|K;M=c[(b+12208|0)>>2]|0;qa=(ca(ma,z>>1)|0)+G|0;mf[c[(c[(b+12444|0)>>2]|0)+32+(X<<2)>>2]&2047](M+(T<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+qa|0,ma,4);mf[c[(c[(b+12444|0)>>2]|0)+32+(X<<2)>>2]&2047](M+(T<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+qa|0,ma,4);qa=(Xe[O&511](b,M+(T<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,ma,4)|0)+ia|0;ib=qa+(Xe[O&511](b,M+(T<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,ma,4)|0)|0}else{ma=z<<n;if((c[(b+12264|0)>>2]|0)>(p|0)){ib=536870912;break}if((y|0)>(c[(b+12268|0)>>2]<<n|0)){ib=536870912;break}if((c[(b+12272|0)>>2]|0)>(z|0)){ib=536870912;break}if((ma|0)>(c[(b+12276|0)>>2]<<n|0)){ib=536870912;break}M=e[(b+13872|0)>>1]|0;qa=e[(b+13874|0)>>1]|0;i:do{if((c[(b+11740|0)>>2]|0)==1){if((y|0)==0){ia=0;while(1){X=c[b+12160+(ia<<3)>>2]|0;ga=(c[b+12160+(ia<<3)+4>>2]|0)+ma|0;fa=((ca(c[b+12128+(ia<<3)>>2]|0,qa-M|0)|0)/(M|0)|0)+((ia&1)<<(m&1|4))|0;la=c[b+12128+(ia<<3)+4>>2]|0;if((ma|0)==0){$a=ia>>1;jb=((ca(la,qa-M|0)|0)/(M|0)|0)+($a<<(m&1|4))|0;kb=$a}else{jb=ga-la|0;kb=ia>>1}la=((jb&J)<<n)+(fa&J)|0;$a=(c[(b+12208|0)>>2]|0)+((ca(kb,T<<3)|0)+(ia<<3&8))|0;if((m&1|0)==0){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,T)|0)+(X>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&J)<<n)+(X&J)|0)<<2)>>2]&2047]($a,na,T,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(jb>>1,T)|0)+(fa>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&2047]($a,na,T,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,T)|0)+(X>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&J)<<n)+(X&J)|0)<<2)>>2]&4095]($a,na,T);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(jb>>2,T)|0)+(fa>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095]($a,na,T)}ia=ia+1|0;if((ia|0)>=4){break i}}}if((ma|0)==0){ia=0;do{na=(c[b+12160+(ia<<3)>>2]|0)+y|0;$a=c[b+12160+(ia<<3)+4>>2]|0;la=na-(c[b+12128+(ia<<3)>>2]|0)|0;fa=ia>>1;X=((ca(c[b+12128+(ia<<3)+4>>2]|0,qa-M|0)|0)/(M|0)|0)+(fa<<(m&1|4))|0;ga=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ca(fa,T<<3)|0))|0;if((m&1|0)==0){fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>1,T)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(((($a&J)<<n)+(na&J)|0)<<2)>>2]&2047](ga,fa,T,8);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>1,T)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((X&J)<<n)+(la&J)|0)<<2)>>2]&2047](ga,fa,T,8)}else{fa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>2,T)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(na&J)|0)<<2)>>2]&4095](ga,fa,T);fa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>2,T)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((X&J)<<n)+(la&J)|0)<<2)>>2]&4095](ga,fa,T)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{fa=(c[b+12160+(ia<<3)>>2]|0)+y|0;ga=(c[b+12160+(ia<<3)+4>>2]|0)+ma|0;la=fa-(c[b+12128+(ia<<3)>>2]|0)|0;X=ga-(c[b+12128+(ia<<3)+4>>2]|0)|0;na=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ca(ia>>1,T<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,T)|0)+(fa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&J)<<n)+(fa&J)|0)<<2)>>2]&2047](na,$a,T,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>1,T)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((X&J)<<n)+(la&J)|0)<<2)>>2]&2047](na,$a,T,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,T)|0)+(fa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&J)<<n)+(fa&J)|0)<<2)>>2]&4095](na,$a,T);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>2,T)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((X&J)<<n)+(la&J)|0)<<2)>>2]&4095](na,$a,T)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[(b+12160|0)>>2]|0)+y|0;$a=(c[(b+12164|0)>>2]|0)+ma|0;na=c[(b+12128|0)>>2]|0;if((y|0)==0){lb=(ca(na,qa-M|0)|0)/(M|0)|0}else{lb=ia-na|0}na=c[(b+12132|0)>>2]|0;if((ma|0)==0){mb=(ca(na,qa-M|0)|0)/(M|0)|0}else{mb=$a-na|0}na=((mb&J)<<n)+(lb&J)|0;if((m&1|0)==0){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>1,T)|0)+(ia>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,T,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(mb>>1,T)|0)+(lb>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(na<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,T,16);break}else{la=(ca($a>>2,T)|0)+(ia>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,T);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,T);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(T<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(T<<3))|0,T);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&J)<<n)+(ia&J)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(T<<3))|0,T);la=(ca(mb>>2,T)|0)+(lb>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,T);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,T);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(T<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(T<<3))|0,T);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((T<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(T<<3))|0,T);break}}}while(0);ib=Xe[N&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,T,16)|0}}while(0);c[(F+(S<<2)|0)>>2]=R;c[_+(S<<2)>>2]=ib;T=(ca((d[C+((z<<n)-x)|0]|0)+(d[C+(y-E)|0]|0)|0,l)|0)+ib|0;if((T|0)>=(V|0)){fb=V;gb=A;hb=B;break}c[r>>2]=p;c[(r+4|0)>>2]=z;fb=T;gb=p;hb=z}}while(0);S=z+2|0;if((S|0)>(I|0)){cb=fb;db=gb;eb=hb;break}else{z=S;V=fb;A=gb;B=hb}}}B=eb-2|0;A=(B|0)>(L|0)?B:L;B=eb+2|0;V=(B|0)>(D|0)?D:B;if((A|0)>(V|0)){nb=cb}else{B=db-2|0;z=(B|0)>(W|0)?B:W;B=db+2|0;I=(B|0)>(Q|0)?Q:B;B=(m&1)<<1|1;y=A;A=cb;while(1){if((z|0)>(I|0)){ob=A}else{J=(y<<11)+H|0;G=y<<3;K=y<<1&2;ja=y>>1;S=y<<n;R=z;T=A;while(1){M=J+R|0;qa=R+G&63;do{if((c[(F+(qa<<2)|0)>>2]|0)==(M|0)){pb=T}else{ma=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){la=c[(b+12420|0)>>2]|0;na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma,y)|0)+R)|0;ia=Xe[N&511](b,c[(b+12288+(h<<4)|0)>>2]|0,na,ma,8)|0;if((m&2|0)==0){qb=ia;break}na=R&1|K;$a=c[(b+12208|0)>>2]|0;X=(ca(la,ja)|0)+(R>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+(na<<2)>>2]&2047]($a+(ma<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+X|0,la,4);mf[c[(c[(b+12444|0)>>2]|0)+32+(na<<2)>>2]&2047]($a+(ma<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+X|0,la,4);X=(Xe[O&511](b,$a+(ma<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,la,4)|0)+ia|0;qb=X+(Xe[O&511](b,$a+(ma<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,la,4)|0)|0}else{la=R<<n;if((c[(b+12264|0)>>2]|0)>(R|0)){qb=536870912;break}if((la|0)>(c[(b+12268|0)>>2]<<n|0)){qb=536870912;break}if((c[(b+12272|0)>>2]|0)>(y|0)){qb=536870912;break}if((S|0)>(c[(b+12276|0)>>2]<<n|0)){qb=536870912;break}$a=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;j:do{if((c[(b+11740|0)>>2]|0)==1){if((la|0)==0){ia=0;while(1){na=c[b+12160+(ia<<3)>>2]|0;fa=(c[b+12160+(ia<<3)+4>>2]|0)+S|0;ga=((ca(c[b+12128+(ia<<3)>>2]|0,X-$a|0)|0)/($a|0)|0)+((ia&1)<<(m&1|4))|0;U=c[b+12128+(ia<<3)+4>>2]|0;if((S|0)==0){ka=ia>>1;rb=((ca(U,X-$a|0)|0)/($a|0)|0)+(ka<<(m&1|4))|0;sb=ka}else{rb=fa-U|0;sb=ia>>1}U=((rb&B)<<n)+(ga&B)|0;ka=(c[(b+12208|0)>>2]|0)+((ca(sb,ma<<3)|0)+(ia<<3&8))|0;if((m&1|0)==0){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>1,ma)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&B)<<n)+(na&B)|0)<<2)>>2]&2047](ka,Ba,ma,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(rb>>1,ma)|0)+(ga>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(U<<2)>>2]&2047](ka,Ba,ma,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>2,ma)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((fa&B)<<n)+(na&B)|0)<<2)>>2]&4095](ka,Ba,ma);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(rb>>2,ma)|0)+(ga>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](ka,Ba,ma)}ia=ia+1|0;if((ia|0)>=4){break j}}}if((S|0)==0){ia=0;do{Ba=(c[b+12160+(ia<<3)>>2]|0)+la|0;ka=c[b+12160+(ia<<3)+4>>2]|0;U=Ba-(c[b+12128+(ia<<3)>>2]|0)|0;ga=ia>>1;na=((ca(c[b+12128+(ia<<3)+4>>2]|0,X-$a|0)|0)/($a|0)|0)+(ga<<(m&1|4))|0;fa=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ca(ga,ma<<3)|0))|0;if((m&1|0)==0){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,ma)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&B)<<n)+(Ba&B)|0)<<2)>>2]&2047](fa,ga,ma,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>1,ma)|0)+(U>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((na&B)<<n)+(U&B)|0)<<2)>>2]&2047](fa,ga,ma,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>2,ma)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(Ba&B)|0)<<2)>>2]&4095](fa,ga,ma);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>2,ma)|0)+(U>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((na&B)<<n)+(U&B)|0)<<2)>>2]&4095](fa,ga,ma)}ia=ia+1|0;}while((ia|0)<4)}else{ia=0;do{ga=(c[b+12160+(ia<<3)>>2]|0)+la|0;fa=(c[b+12160+(ia<<3)+4>>2]|0)+S|0;U=ga-(c[b+12128+(ia<<3)>>2]|0)|0;na=fa-(c[b+12128+(ia<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((ia<<3&8)+(ca(ia>>1,ma<<3)|0))|0;if((m&1|0)==0){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>1,ma)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((fa&B)<<n)+(ga&B)|0)<<2)>>2]&2047](Ba,ka,ma,8);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>1,ma)|0)+(U>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((na&B)<<n)+(U&B)|0)<<2)>>2]&2047](Ba,ka,ma,8)}else{ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(fa>>2,ma)|0)+(ga>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((fa&B)<<n)+(ga&B)|0)<<2)>>2]&4095](Ba,ka,ma);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(na>>2,ma)|0)+(U>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((na&B)<<n)+(U&B)|0)<<2)>>2]&4095](Ba,ka,ma)}ia=ia+1|0;}while((ia|0)<4)}}else{ia=(c[(b+12160|0)>>2]|0)+la|0;ka=(c[(b+12164|0)>>2]|0)+S|0;Ba=c[(b+12128|0)>>2]|0;if((la|0)==0){tb=(ca(Ba,X-$a|0)|0)/($a|0)|0}else{tb=ia-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((S|0)==0){ub=(ca(Ba,X-$a|0)|0)/($a|0)|0}else{ub=ka-Ba|0}Ba=((ub&B)<<n)+(tb&B)|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,ma)|0)+(ia>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,U,ma,16);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ub>>1,ma)|0)+(tb>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&2047](c[(b+12208|0)>>2]|0,U,ma,16);break}else{U=(ca(ka>>2,ma)|0)+(ia>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+U|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(U+8|0)|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(U+(ma<<3))|0,ma);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&B)<<n)+(ia&B)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((U+8|0)+(ma<<3))|0,ma);U=(ca(ub>>2,ma)|0)+(tb>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+U|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(U+8|0)|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(ma<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(U+(ma<<3))|0,ma);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((ma<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((U+8|0)+(ma<<3))|0,ma);break}}}while(0);qb=Xe[N&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,ma,16)|0}}while(0);c[(F+(qa<<2)|0)>>2]=M;c[_+(qa<<2)>>2]=qb;ma=(ca((d[C+(S-x)|0]|0)+(d[C+((R<<n)-E)|0]|0)|0,l)|0)+qb|0;if((ma|0)>=(T|0)){pb=T;break}c[r>>2]=R;c[(r+4|0)>>2]=y;pb=ma}}while(0);qa=R+1|0;if((qa|0)>(I|0)){ob=pb;break}else{R=qa;T=pb}}}T=y+1|0;if((T|0)>(V|0)){nb=ob;break}else{y=T;A=ob}}}if(((s&254)>>>2|0)==0){vb=nb}else{A=(m&1)<<1|1;y=1;V=nb;while(1){I=0;B=V;while(1){z=(ca(c[284520+(I<<3)>>2]|0,y)|0)+db|0;T=(ca(c[284524+(I<<3)>>2]|0,y)|0)+eb|0;R=(z|0)>(Q|0)?Q:z;z=(W|0)>(R|0)?W:R;R=(T|0)>(D|0)?D:T;T=(L|0)>(R|0)?L:R;do{if((c[(F+(((T<<3)+z&63)<<2)|0)>>2]|0)==(z+H+(T<<11)|0|0)){wb=B}else{R=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){S=c[(b+12420|0)>>2]|0;ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(R,T)|0)+z)|0;K=Xe[N&511](b,c[(b+12288+(h<<4)|0)>>2]|0,ja,R,8)|0;if((m&2|0)==0){xb=K;break}ja=c[(b+12208|0)>>2]|0;G=(ca(S,T>>1)|0)+(z>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((T<<1&2|z&1)<<2)>>2]&2047](ja+(R<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+G|0,S,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((T<<1&2|z&1)<<2)>>2]&2047](ja+(R<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+G|0,S,4);G=(Xe[O&511](b,ja+(R<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,S,4)|0)+K|0;xb=G+(Xe[O&511](b,ja+(R<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,S,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(z|0)){xb=536870912;break}if((z<<n|0)>(c[(b+12268|0)>>2]<<n|0)){xb=536870912;break}if((c[(b+12272|0)>>2]|0)>(T|0)){xb=536870912;break}if((T<<n|0)>(c[(b+12276|0)>>2]<<n|0)){xb=536870912;break}S=e[(b+13872|0)>>1]|0;ja=e[(b+13874|0)>>1]|0;k:do{if((c[(b+11740|0)>>2]|0)==1){if((z<<n|0)==0){G=0;while(1){K=c[b+12160+(G<<3)>>2]|0;J=(c[b+12160+(G<<3)+4>>2]|0)+(T<<n)|0;qa=((ca(c[b+12128+(G<<3)>>2]|0,ja-S|0)|0)/(S|0)|0)+((G&1)<<(m&1|4))|0;M=c[b+12128+(G<<3)+4>>2]|0;if((T<<n|0)==0){ma=G>>1;yb=((ca(M,ja-S|0)|0)/(S|0)|0)+(ma<<(m&1|4))|0;zb=ma}else{yb=J-M|0;zb=G>>1}M=((yb&A)<<n)+(qa&A)|0;ma=(c[(b+12208|0)>>2]|0)+((ca(zb,R<<3)|0)+(G<<3&8))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(J>>1,R)|0)+(K>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((J&A)<<n)+(K&A)|0)<<2)>>2]&2047](ma,$a,R,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(yb>>1,R)|0)+(qa>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(M<<2)>>2]&2047](ma,$a,R,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(J>>2,R)|0)+(K>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((J&A)<<n)+(K&A)|0)<<2)>>2]&4095](ma,$a,R);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(yb>>2,R)|0)+(qa>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(M<<2)>>2]&4095](ma,$a,R)}G=G+1|0;if((G|0)>=4){break k}}}if((T<<n|0)==0){G=0;do{$a=(c[b+12160+(G<<3)>>2]|0)+(z<<n)|0;ma=c[b+12160+(G<<3)+4>>2]|0;M=$a-(c[b+12128+(G<<3)>>2]|0)|0;qa=G>>1;K=((ca(c[b+12128+(G<<3)+4>>2]|0,ja-S|0)|0)/(S|0)|0)+(qa<<(m&1|4))|0;J=(c[(b+12208|0)>>2]|0)+((G<<3&8)+(ca(qa,R<<3)|0))|0;if((m&1|0)==0){qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,R)|0)+($a>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&A)<<n)+($a&A)|0)<<2)>>2]&2047](J,qa,R,8);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,R)|0)+(M>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&A)<<n)+(M&A)|0)<<2)>>2]&2047](J,qa,R,8)}else{qa=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>2,R)|0)+($a>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+($a&A)|0)<<2)>>2]&4095](J,qa,R);qa=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,R)|0)+(M>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&A)<<n)+(M&A)|0)<<2)>>2]&4095](J,qa,R)}G=G+1|0;}while((G|0)<4)}else{G=0;do{qa=(c[b+12160+(G<<3)>>2]|0)+(z<<n)|0;J=(c[b+12160+(G<<3)+4>>2]|0)+(T<<n)|0;M=qa-(c[b+12128+(G<<3)>>2]|0)|0;K=J-(c[b+12128+(G<<3)+4>>2]|0)|0;$a=(c[(b+12208|0)>>2]|0)+((G<<3&8)+(ca(G>>1,R<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(J>>1,R)|0)+(qa>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((J&A)<<n)+(qa&A)|0)<<2)>>2]&2047]($a,ma,R,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,R)|0)+(M>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&A)<<n)+(M&A)|0)<<2)>>2]&2047]($a,ma,R,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(J>>2,R)|0)+(qa>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((J&A)<<n)+(qa&A)|0)<<2)>>2]&4095]($a,ma,R);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,R)|0)+(M>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&A)<<n)+(M&A)|0)<<2)>>2]&4095]($a,ma,R)}G=G+1|0;}while((G|0)<4)}}else{G=(c[(b+12160|0)>>2]|0)+(z<<n)|0;ma=(c[(b+12164|0)>>2]|0)+(T<<n)|0;$a=c[(b+12128|0)>>2]|0;if((z<<n|0)==0){Ab=(ca($a,ja-S|0)|0)/(S|0)|0}else{Ab=G-$a|0}$a=c[(b+12132|0)>>2]|0;if((T<<n|0)==0){Bb=(ca($a,ja-S|0)|0)/(S|0)|0}else{Bb=ma-$a|0}$a=((Bb&A)<<n)+(Ab&A)|0;if((m&1|0)==0){M=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,R)|0)+(G>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,M,R,16);M=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Bb>>1,R)|0)+(Ab>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+($a<<2)>>2]&2047](c[(b+12208|0)>>2]|0,M,R,16);break}else{M=(ca(ma>>2,R)|0)+(G>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+M|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(M+8|0)|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(M+(R<<3))|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&A)<<n)+(G&A)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((M+8|0)+(R<<3))|0,R);M=(ca(Bb>>2,R)|0)+(Ab>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+M|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(M+8|0)|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(M+(R<<3))|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+($a<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((M+8|0)+(R<<3))|0,R);break}}}while(0);xb=Xe[N&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,R,16)|0}}while(0);c[(F+(((T<<3)+z&63)<<2)|0)>>2]=z+H+(T<<11)|0;c[_+(((T<<3)+z&63)<<2)>>2]=xb;R=(ca((d[C+((T<<n)-x)|0]|0)+(d[C+((z<<n)-E)|0]|0)|0,l)|0)+xb|0;if((R|0)>=(B|0)){wb=B;break}c[r>>2]=z;c[(r+4|0)>>2]=T;wb=R}}while(0);T=I+1|0;if((T|0)<16){I=T;B=wb}else{break}}B=y+1|0;if((B|0)>((s&254)>>>2|0)){vb=wb;break}else{y=B;V=wb}}}t=vrb(b,r,vb,h,j,l,1,8,m,2)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}if((s|0)>512){t=vrb(b,r,q,h,j,l,1,8,m,s&255)|0;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}V=c[(b+12220|0)>>2]|0;y=c[(b+12264|0)>>2]|0;E=c[(b+12272|0)>>2]|0;C=c[(b+12268|0)>>2]|0;x=c[(b+12276|0)>>2]|0;_=c[(b+12464|0)>>2]|0;H=c[(b+12280|0)>>2]|0;F=c[(b+12284|0)>>2]|0;N=c[(b+12216|0)>>2]|0;A=c[(b+12224|0)>>2]|0;if((s|0)<=256){O=c[(b+10472|0)>>2]|0;L=c[(b+10476|0)>>2]|0;D=(m&1)<<1|1;W=m&1|4;Q=(m&1|0)==0;B=1;I=q;T=p;z=o;while(1){R=z+B|0;S=(R-x|0|0)<0?0:R-x|0;ja=C-T+1|0;M=(B|0)>(ja|0)?ja:B;if((S|0)<(M|0)){ja=S;S=I;$a=z;G=T;while(1){ma=R-ja|0;K=ja+T|0;do{if((c[(N+(((ma<<3)+K&63)<<2)|0)>>2]|0)==(K+A+(ma<<11)|0|0)){Cb=S;Db=$a;Eb=G}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa,ma)|0)+K)|0;la=Xe[O&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){Fb=la;break}X=c[(b+12208|0)>>2]|0;U=(ca(J,ma>>1)|0)+(K>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|K&1)<<2)>>2]&2047](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+U|0,J,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|K&1)<<2)>>2]&2047](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+U|0,J,4);U=(Xe[L&511](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+la|0;Fb=U+(Xe[L&511](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(K|0)){Fb=536870912;break}if((K<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Fb=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){Fb=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Fb=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;l:do{if((c[(b+11740|0)>>2]|0)==1){if((K<<n|0)==0){U=0;while(1){la=c[b+12160+(U<<3)>>2]|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(ma<<n)|0;ia=((ca(c[b+12128+(U<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((U&1)<<W)|0;ka=c[b+12128+(U<<3)+4>>2]|0;if((ma<<n|0)==0){na=U>>1;Gb=((ca(ka,X-J|0)|0)/(J|0)|0)+(na<<W)|0;Hb=na}else{Gb=Ba-ka|0;Hb=U>>1}ka=((Gb&D)<<n)+(ia&D)|0;na=(c[(b+12208|0)>>2]|0)+((ca(Hb,qa<<3)|0)+(U<<3&8))|0;if(Q){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(la&D)|0)<<2)>>2]&2047](na,ga,qa,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Gb>>1,qa)|0)+(ia>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&2047](na,ga,qa,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(la&D)|0)<<2)>>2]&4095](na,ga,qa);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Gb>>2,qa)|0)+(ia>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](na,ga,qa)}U=U+1|0;if((U|0)>=4){break l}}}if((ma<<n|0)==0){U=0;do{ga=(c[b+12160+(U<<3)>>2]|0)+(K<<n)|0;na=c[b+12160+(U<<3)+4>>2]|0;ka=ga-(c[b+12128+(U<<3)>>2]|0)|0;ia=U>>1;la=((ca(c[b+12128+(U<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;Ba=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(ia,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,qa)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((na&D)<<n)+(ga&D)|0)<<2)>>2]&2047](Ba,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&2047](Ba,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>2,qa)|0)+(ga>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(ga&D)|0)<<2)>>2]&4095](Ba,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](Ba,ia,qa)}U=U+1|0;}while((U|0)<4)}else{U=0;do{ia=(c[b+12160+(U<<3)>>2]|0)+(K<<n)|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(ma<<n)|0;ka=ia-(c[b+12128+(U<<3)>>2]|0)|0;la=Ba-(c[b+12128+(U<<3)+4>>2]|0)|0;ga=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(U>>1,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>1,qa)|0)+(ia>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(ia&D)|0)<<2)>>2]&2047](ga,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&2047](ga,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>2,qa)|0)+(ia>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(ia&D)|0)<<2)>>2]&4095](ga,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ga,na,qa)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(K<<n)|0;na=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;ga=c[(b+12128|0)>>2]|0;if((K<<n|0)==0){Ib=(ca(ga,X-J|0)|0)/(J|0)|0}else{Ib=U-ga|0}ga=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){Jb=(ca(ga,X-J|0)|0)/(J|0)|0}else{Jb=na-ga|0}ga=((Jb&D)<<n)+(Ib&D)|0;if(Q){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,qa)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((na&D)<<n)+(U&D)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,qa,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Jb>>1,qa)|0)+(Ib>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(ga<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,qa,16);break}else{ka=(ca(na>>2,qa)|0)+(U>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(qa<<3))|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);ka=(ca(Jb>>2,qa)|0)+(Ib>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(qa<<3))|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);break}}}while(0);Fb=Xe[O&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((ma<<3)+K&63)<<2)|0)>>2]=K+A+(ma<<11)|0;c[V+(((ma<<3)+K&63)<<2)>>2]=Fb;qa=(ca((d[_+((ma<<n)-F)|0]|0)+(d[_+((K<<n)-H)|0]|0)|0,l)|0)+Fb|0;if((qa|0)>=(S|0)){Cb=S;Db=$a;Eb=G;break}c[r>>2]=K;c[(r+4|0)>>2]=ma;Cb=qa;Db=ma;Eb=K}}while(0);K=ja+1|0;if((K|0)<(M|0)){ja=K;S=Cb;$a=Db;G=Eb}else{Kb=Cb;Lb=Db;Mb=Eb;break}}}else{Kb=I;Lb=z;Mb=T}G=B+T|0;$a=(G-C|0|0)<0?0:G-C|0;S=z-E+1|0;ja=(B|0)>(S|0)?S:B;if(($a|0)<(ja|0)){S=$a;$a=Kb;M=Lb;R=Mb;while(1){K=z-S|0;ma=G-S|0;do{if((c[(N+(((K<<3)+ma&63)<<2)|0)>>2]|0)==(ma+A+(K<<11)|0|0)){Nb=$a;Ob=M;Pb=R}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa,K)|0)+ma)|0;ka=Xe[O&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){Qb=ka;break}X=c[(b+12208|0)>>2]|0;ga=(ca(J,K>>1)|0)+(ma>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((K<<1&2|ma&1)<<2)>>2]&2047](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+ga|0,J,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((K<<1&2|ma&1)<<2)>>2]&2047](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+ga|0,J,4);ga=(Xe[L&511](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+ka|0;Qb=ga+(Xe[L&511](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(ma|0)){Qb=536870912;break}if((ma<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Qb=536870912;break}if((c[(b+12272|0)>>2]|0)>(K|0)){Qb=536870912;break}if((K<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Qb=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;m:do{if((c[(b+11740|0)>>2]|0)==1){if((ma<<n|0)==0){ga=0;while(1){ka=c[b+12160+(ga<<3)>>2]|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(K<<n)|0;na=((ca(c[b+12128+(ga<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((ga&1)<<W)|0;la=c[b+12128+(ga<<3)+4>>2]|0;if((K<<n|0)==0){ia=ga>>1;Rb=((ca(la,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;Sb=ia}else{Rb=U-la|0;Sb=ga>>1}la=((Rb&D)<<n)+(na&D)|0;ia=(c[(b+12208|0)>>2]|0)+((ca(Sb,qa<<3)|0)+(ga<<3&8))|0;if(Q){Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&D)<<n)+(ka&D)|0)<<2)>>2]&2047](ia,Ba,qa,8);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Rb>>1,qa)|0)+(na>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&2047](ia,Ba,qa,8)}else{Ba=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ia,Ba,qa);Ba=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Rb>>2,qa)|0)+(na>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](ia,Ba,qa)}ga=ga+1|0;if((ga|0)>=4){break m}}}if((K<<n|0)==0){ga=0;do{Ba=(c[b+12160+(ga<<3)>>2]|0)+(ma<<n)|0;ia=c[b+12160+(ga<<3)+4>>2]|0;la=Ba-(c[b+12128+(ga<<3)>>2]|0)|0;na=ga>>1;ka=((ca(c[b+12128+(ga<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(na<<W)|0;U=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(na,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>1,qa)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ia&D)<<n)+(Ba&D)|0)<<2)>>2]&2047](U,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&2047](U,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>2,qa)|0)+(Ba>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(Ba&D)|0)<<2)>>2]&4095](U,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](U,na,qa)}ga=ga+1|0;}while((ga|0)<4)}else{ga=0;do{na=(c[b+12160+(ga<<3)>>2]|0)+(ma<<n)|0;U=(c[b+12160+(ga<<3)+4>>2]|0)+(K<<n)|0;la=na-(c[b+12128+(ga<<3)>>2]|0)|0;ka=U-(c[b+12128+(ga<<3)+4>>2]|0)|0;Ba=(c[(b+12208|0)>>2]|0)+((ga<<3&8)+(ca(ga>>1,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>1,qa)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((U&D)<<n)+(na&D)|0)<<2)>>2]&2047](Ba,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&2047](Ba,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(U>>2,qa)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((U&D)<<n)+(na&D)|0)<<2)>>2]&4095](Ba,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](Ba,ia,qa)}ga=ga+1|0;}while((ga|0)<4)}}else{ga=(c[(b+12160|0)>>2]|0)+(ma<<n)|0;ia=(c[(b+12164|0)>>2]|0)+(K<<n)|0;Ba=c[(b+12128|0)>>2]|0;if((ma<<n|0)==0){Tb=(ca(Ba,X-J|0)|0)/(J|0)|0}else{Tb=ga-Ba|0}Ba=c[(b+12132|0)>>2]|0;if((K<<n|0)==0){Ub=(ca(Ba,X-J|0)|0)/(J|0)|0}else{Ub=ia-Ba|0}Ba=((Ub&D)<<n)+(Tb&D)|0;if(Q){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>1,qa)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,qa,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Ub>>1,qa)|0)+(Tb>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(Ba<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,qa,16);break}else{la=(ca(ia>>2,qa)|0)+(ga>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(qa<<3))|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);la=(ca(Ub>>2,qa)|0)+(Tb>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(qa<<3))|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(Ba<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);break}}}while(0);Qb=Xe[O&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((K<<3)+ma&63)<<2)|0)>>2]=ma+A+(K<<11)|0;c[V+(((K<<3)+ma&63)<<2)>>2]=Qb;qa=(ca((d[_+((K<<n)-F)|0]|0)+(d[_+((ma<<n)-H)|0]|0)|0,l)|0)+Qb|0;if((qa|0)>=($a|0)){Nb=$a;Ob=M;Pb=R;break}c[r>>2]=ma;c[(r+4|0)>>2]=K;Nb=qa;Ob=K;Pb=ma}}while(0);ma=S+1|0;if((ma|0)<(ja|0)){S=ma;$a=Nb;M=Ob;R=Pb}else{Vb=Nb;Wb=Ob;Xb=Pb;break}}}else{Vb=Kb;Wb=Lb;Xb=Mb}R=B-z+E|0;M=(R|0)<0?0:R;R=T-y+1|0;$a=(B|0)>(R|0)?R:B;if((M|0)<($a|0)){R=z-B|0;S=M;M=Vb;ja=Wb;G=Xb;while(1){ma=S+R|0;K=T-S|0;do{if((c[(N+(((ma<<3)+K&63)<<2)|0)>>2]|0)==(K+A+(ma<<11)|0|0)){Yb=M;Zb=ja;_b=G}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa,ma)|0)+K)|0;la=Xe[O&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){$b=la;break}X=c[(b+12208|0)>>2]|0;Ba=(ca(J,ma>>1)|0)+(K>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|K&1)<<2)>>2]&2047](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+Ba|0,J,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|K&1)<<2)>>2]&2047](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+Ba|0,J,4);Ba=(Xe[L&511](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+la|0;$b=Ba+(Xe[L&511](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(K|0)){$b=536870912;break}if((K<<n|0)>(c[(b+12268|0)>>2]<<n|0)){$b=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){$b=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){$b=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;n:do{if((c[(b+11740|0)>>2]|0)==1){if((K<<n|0)==0){Ba=0;while(1){la=c[b+12160+(Ba<<3)>>2]|0;ga=(c[b+12160+(Ba<<3)+4>>2]|0)+(ma<<n)|0;ia=((ca(c[b+12128+(Ba<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((Ba&1)<<W)|0;ka=c[b+12128+(Ba<<3)+4>>2]|0;if((ma<<n|0)==0){na=Ba>>1;ac=((ca(ka,X-J|0)|0)/(J|0)|0)+(na<<W)|0;bc=na}else{ac=ga-ka|0;bc=Ba>>1}ka=((ac&D)<<n)+(ia&D)|0;na=(c[(b+12208|0)>>2]|0)+((ca(bc,qa<<3)|0)+(Ba<<3&8))|0;if(Q){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&D)<<n)+(la&D)|0)<<2)>>2]&2047](na,U,qa,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ac>>1,qa)|0)+(ia>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ka<<2)>>2]&2047](na,U,qa,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&D)<<n)+(la&D)|0)<<2)>>2]&4095](na,U,qa);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ac>>2,qa)|0)+(ia>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ka<<2)>>2]&4095](na,U,qa)}Ba=Ba+1|0;if((Ba|0)>=4){break n}}}if((ma<<n|0)==0){Ba=0;do{U=(c[b+12160+(Ba<<3)>>2]|0)+(K<<n)|0;na=c[b+12160+(Ba<<3)+4>>2]|0;ka=U-(c[b+12128+(Ba<<3)>>2]|0)|0;ia=Ba>>1;la=((ca(c[b+12128+(Ba<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;ga=(c[(b+12208|0)>>2]|0)+((Ba<<3&8)+(ca(ia,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,qa)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((na&D)<<n)+(U&D)|0)<<2)>>2]&2047](ga,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&2047](ga,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>2,qa)|0)+(U>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(U&D)|0)<<2)>>2]&4095](ga,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ga,ia,qa)}Ba=Ba+1|0;}while((Ba|0)<4)}else{Ba=0;do{ia=(c[b+12160+(Ba<<3)>>2]|0)+(K<<n)|0;ga=(c[b+12160+(Ba<<3)+4>>2]|0)+(ma<<n)|0;ka=ia-(c[b+12128+(Ba<<3)>>2]|0)|0;la=ga-(c[b+12128+(Ba<<3)+4>>2]|0)|0;U=(c[(b+12208|0)>>2]|0)+((Ba<<3&8)+(ca(Ba>>1,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,qa)|0)+(ia>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&D)<<n)+(ia&D)|0)<<2)>>2]&2047](U,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&2047](U,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,qa)|0)+(ia>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&D)<<n)+(ia&D)|0)<<2)>>2]&4095](U,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(la>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((la&D)<<n)+(ka&D)|0)<<2)>>2]&4095](U,na,qa)}Ba=Ba+1|0;}while((Ba|0)<4)}}else{Ba=(c[(b+12160|0)>>2]|0)+(K<<n)|0;na=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;U=c[(b+12128|0)>>2]|0;if((K<<n|0)==0){cc=(ca(U,X-J|0)|0)/(J|0)|0}else{cc=Ba-U|0}U=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){dc=(ca(U,X-J|0)|0)/(J|0)|0}else{dc=na-U|0}U=((dc&D)<<n)+(cc&D)|0;if(Q){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(na>>1,qa)|0)+(Ba>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,qa,16);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(dc>>1,qa)|0)+(cc>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(U<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ka,qa,16);break}else{ka=(ca(na>>2,qa)|0)+(Ba>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ka|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+8|0)|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ka+(qa<<3))|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((na&D)<<n)+(Ba&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);ka=(ca(dc>>2,qa)|0)+(cc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ka|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+8|0)|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ka+(qa<<3))|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(U<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ka+8|0)+(qa<<3))|0,qa);break}}}while(0);$b=Xe[O&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((ma<<3)+K&63)<<2)|0)>>2]=K+A+(ma<<11)|0;c[V+(((ma<<3)+K&63)<<2)>>2]=$b;qa=(ca((d[_+((ma<<n)-F)|0]|0)+(d[_+((K<<n)-H)|0]|0)|0,l)|0)+$b|0;if((qa|0)>=(M|0)){Yb=M;Zb=ja;_b=G;break}c[r>>2]=K;c[(r+4|0)>>2]=ma;Yb=qa;Zb=ma;_b=K}}while(0);K=S+1|0;if((K|0)<($a|0)){S=K;M=Yb;ja=Zb;G=_b}else{ec=Yb;fc=Zb;gc=_b;break}}}else{ec=Vb;fc=Wb;gc=Xb}G=B-T+y|0;ja=(G|0)<0?0:G;G=x-z+1|0;M=(B|0)>(G|0)?G:B;if((ja|0)<(M|0)){G=T-B|0;S=ja;ja=ec;$a=fc;R=gc;while(1){K=S+z|0;ma=S+G|0;do{if((c[(N+(((K<<3)+ma&63)<<2)|0)>>2]|0)==(ma+A+(K<<11)|0|0)){hc=ja;ic=$a;jc=R}else{qa=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){J=c[(b+12420|0)>>2]|0;X=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(qa,K)|0)+ma)|0;ka=Xe[O&511](b,c[(b+12288+(h<<4)|0)>>2]|0,X,qa,8)|0;if((m&2|0)==0){kc=ka;break}X=c[(b+12208|0)>>2]|0;U=(ca(J,K>>1)|0)+(ma>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((K<<1&2|ma&1)<<2)>>2]&2047](X+(qa<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+U|0,J,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((K<<1&2|ma&1)<<2)>>2]&2047](X+(qa<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+U|0,J,4);U=(Xe[L&511](b,X+(qa<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,J,4)|0)+ka|0;kc=U+(Xe[L&511](b,X+(qa<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,J,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(ma|0)){kc=536870912;break}if((ma<<n|0)>(c[(b+12268|0)>>2]<<n|0)){kc=536870912;break}if((c[(b+12272|0)>>2]|0)>(K|0)){kc=536870912;break}if((K<<n|0)>(c[(b+12276|0)>>2]<<n|0)){kc=536870912;break}J=e[(b+13872|0)>>1]|0;X=e[(b+13874|0)>>1]|0;o:do{if((c[(b+11740|0)>>2]|0)==1){if((ma<<n|0)==0){U=0;while(1){ka=c[b+12160+(U<<3)>>2]|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(K<<n)|0;na=((ca(c[b+12128+(U<<3)>>2]|0,X-J|0)|0)/(J|0)|0)+((U&1)<<W)|0;la=c[b+12128+(U<<3)+4>>2]|0;if((K<<n|0)==0){ia=U>>1;lc=((ca(la,X-J|0)|0)/(J|0)|0)+(ia<<W)|0;mc=ia}else{lc=Ba-la|0;mc=U>>1}la=((lc&D)<<n)+(na&D)|0;ia=(c[(b+12208|0)>>2]|0)+((ca(mc,qa<<3)|0)+(U<<3&8))|0;if(Q){ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>1,qa)|0)+(ka>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(ka&D)|0)<<2)>>2]&2047](ia,ga,qa,8);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(lc>>1,qa)|0)+(na>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(la<<2)>>2]&2047](ia,ga,qa,8)}else{ga=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>2,qa)|0)+(ka>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(ka&D)|0)<<2)>>2]&4095](ia,ga,qa);ga=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(lc>>2,qa)|0)+(na>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(la<<2)>>2]&4095](ia,ga,qa)}U=U+1|0;if((U|0)>=4){break o}}}if((K<<n|0)==0){U=0;do{ga=(c[b+12160+(U<<3)>>2]|0)+(ma<<n)|0;ia=c[b+12160+(U<<3)+4>>2]|0;la=ga-(c[b+12128+(U<<3)>>2]|0)|0;na=U>>1;ka=((ca(c[b+12128+(U<<3)+4>>2]|0,X-J|0)|0)/(J|0)|0)+(na<<W)|0;Ba=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(na,qa<<3)|0))|0;if(Q){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>1,qa)|0)+(ga>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&2047](Ba,na,qa,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&2047](Ba,na,qa,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>2,qa)|0)+(ga>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(ga&D)|0)<<2)>>2]&4095](Ba,na,qa);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](Ba,na,qa)}U=U+1|0;}while((U|0)<4)}else{U=0;do{na=(c[b+12160+(U<<3)>>2]|0)+(ma<<n)|0;Ba=(c[b+12160+(U<<3)+4>>2]|0)+(K<<n)|0;la=na-(c[b+12128+(U<<3)>>2]|0)|0;ka=Ba-(c[b+12128+(U<<3)+4>>2]|0)|0;ga=(c[(b+12208|0)>>2]|0)+((U<<3&8)+(ca(U>>1,qa<<3)|0))|0;if(Q){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>1,qa)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((Ba&D)<<n)+(na&D)|0)<<2)>>2]&2047](ga,ia,qa,8);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>1,qa)|0)+(la>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&2047](ga,ia,qa,8)}else{ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(Ba>>2,qa)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((Ba&D)<<n)+(na&D)|0)<<2)>>2]&4095](ga,ia,qa);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ka>>2,qa)|0)+(la>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ka&D)<<n)+(la&D)|0)<<2)>>2]&4095](ga,ia,qa)}U=U+1|0;}while((U|0)<4)}}else{U=(c[(b+12160|0)>>2]|0)+(ma<<n)|0;ia=(c[(b+12164|0)>>2]|0)+(K<<n)|0;ga=c[(b+12128|0)>>2]|0;if((ma<<n|0)==0){nc=(ca(ga,X-J|0)|0)/(J|0)|0}else{nc=U-ga|0}ga=c[(b+12132|0)>>2]|0;if((K<<n|0)==0){oc=(ca(ga,X-J|0)|0)/(J|0)|0}else{oc=ia-ga|0}ga=((oc&D)<<n)+(nc&D)|0;if(Q){la=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ia>>1,qa)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,qa,16);la=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(oc>>1,qa)|0)+(nc>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(ga<<2)>>2]&2047](c[(b+12208|0)>>2]|0,la,qa,16);break}else{la=(ca(ia>>2,qa)|0)+(U>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+la|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+8|0)|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(la+(qa<<3))|0,qa);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ia&D)<<n)+(U&D)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);la=(ca(oc>>2,qa)|0)+(nc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+la|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+8|0)|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(qa<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(la+(qa<<3))|0,qa);ef[c[(c[(b+12456|0)>>2]|0)+64+(ga<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((qa<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((la+8|0)+(qa<<3))|0,qa);break}}}while(0);kc=Xe[O&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,qa,16)|0}}while(0);c[(N+(((K<<3)+ma&63)<<2)|0)>>2]=ma+A+(K<<11)|0;c[V+(((K<<3)+ma&63)<<2)>>2]=kc;qa=(ca((d[_+((K<<n)-F)|0]|0)+(d[_+((ma<<n)-H)|0]|0)|0,l)|0)+kc|0;if((qa|0)>=(ja|0)){hc=ja;ic=$a;jc=R;break}c[r>>2]=ma;c[(r+4|0)>>2]=K;hc=qa;ic=K;jc=ma}}while(0);ma=S+1|0;if((ma|0)<(M|0)){S=ma;ja=hc;$a=ic;R=jc}else{pc=hc;qc=ic;rc=jc;break}}}else{pc=ec;qc=fc;rc=gc}R=(T|0)==(rc|0)&(z|0)==(qc|0);$a=R?B+1|0:1;if(($a|0)>(c[(b+12260|0)>>2]|0)){t=pc;break}else{B=$a;I=pc;T=rc;z=R?z:qc}}u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}z=c[(b+10472|0)>>2]|0;T=c[(b+10476|0)>>2]|0;if((s&255|0)==0){sc=q;tc=p;uc=o}else{I=(m&1)<<1|1;B=s&255;O=q;D=o;Q=p;while(1){W=O;L=D;R=Q;while(1){$a=0;ja=W;S=L;M=R;while(1){G=(ca(c[1017160+($a<<3)>>2]|0,B)|0)+R|0;ma=(ca(c[1017164+($a<<3)>>2]|0,B)|0)+L|0;K=(G|0)>(C|0)?C:G;G=(y|0)>(K|0)?y:K;K=(ma|0)>(x|0)?x:ma;ma=(E|0)>(K|0)?E:K;do{if((c[(N+(((ma<<3)+G&63)<<2)|0)>>2]|0)==(G+A+(ma<<11)|0|0)){vc=ja;wc=S;xc=M}else{K=c[(b+12416|0)>>2]|0;do{if((m&4|0)==0){qa=c[(b+12420|0)>>2]|0;J=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(K,ma)|0)+G)|0;X=Xe[z&511](b,c[(b+12288+(h<<4)|0)>>2]|0,J,K,8)|0;if((m&2|0)==0){yc=X;break}J=c[(b+12208|0)>>2]|0;la=(ca(qa,ma>>1)|0)+(G>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|G&1)<<2)>>2]&2047](J+(K<<4)|0,(c[(b+12352+(j<<4)+4|0)>>2]|0)+la|0,qa,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((ma<<1&2|G&1)<<2)>>2]&2047](J+(K<<4|8)|0,(c[(b+12352+(j<<4)+8|0)>>2]|0)+la|0,qa,4);la=(Xe[T&511](b,J+(K<<4)|0,c[(b+12288+(h<<4)+4|0)>>2]|0,qa,4)|0)+X|0;yc=la+(Xe[T&511](b,J+(K<<4|8)|0,c[(b+12288+(h<<4)+8|0)>>2]|0,qa,4)|0)|0}else{if((c[(b+12264|0)>>2]|0)>(G|0)){yc=536870912;break}if((G<<n|0)>(c[(b+12268|0)>>2]<<n|0)){yc=536870912;break}if((c[(b+12272|0)>>2]|0)>(ma|0)){yc=536870912;break}if((ma<<n|0)>(c[(b+12276|0)>>2]<<n|0)){yc=536870912;break}qa=e[(b+13872|0)>>1]|0;J=e[(b+13874|0)>>1]|0;p:do{if((c[(b+11740|0)>>2]|0)==1){if((G<<n|0)==0){la=0;while(1){X=c[b+12160+(la<<3)>>2]|0;ga=(c[b+12160+(la<<3)+4>>2]|0)+(ma<<n)|0;U=((ca(c[b+12128+(la<<3)>>2]|0,J-qa|0)|0)/(qa|0)|0)+((la&1)<<(m&1|4))|0;ia=c[b+12128+(la<<3)+4>>2]|0;if((ma<<n|0)==0){ka=la>>1;zc=((ca(ia,J-qa|0)|0)/(qa|0)|0)+(ka<<(m&1|4))|0;Ac=ka}else{zc=ga-ia|0;Ac=la>>1}ia=((zc&I)<<n)+(U&I)|0;ka=(c[(b+12208|0)>>2]|0)+((ca(Ac,K<<3)|0)+(la<<3&8))|0;if((m&1|0)==0){na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,K)|0)+(X>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&I)<<n)+(X&I)|0)<<2)>>2]&2047](ka,na,K,8);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(zc>>1,K)|0)+(U>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(ia<<2)>>2]&2047](ka,na,K,8)}else{na=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,K)|0)+(X>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&I)<<n)+(X&I)|0)<<2)>>2]&4095](ka,na,K);na=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(zc>>2,K)|0)+(U>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ia<<2)>>2]&4095](ka,na,K)}la=la+1|0;if((la|0)>=4){break p}}}if((ma<<n|0)==0){la=0;do{na=(c[b+12160+(la<<3)>>2]|0)+(G<<n)|0;ka=c[b+12160+(la<<3)+4>>2]|0;ia=na-(c[b+12128+(la<<3)>>2]|0)|0;U=la>>1;X=((ca(c[b+12128+(la<<3)+4>>2]|0,J-qa|0)|0)/(qa|0)|0)+(U<<(m&1|4))|0;ga=(c[(b+12208|0)>>2]|0)+((la<<3&8)+(ca(U,K<<3)|0))|0;if((m&1|0)==0){U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,K)|0)+(na>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ka&I)<<n)+(na&I)|0)<<2)>>2]&2047](ga,U,K,8);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>1,K)|0)+(ia>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&2047](ga,U,K,8)}else{U=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>2,K)|0)+(na>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(na&I)|0)<<2)>>2]&4095](ga,U,K);U=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>2,K)|0)+(ia>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&4095](ga,U,K)}la=la+1|0;}while((la|0)<4)}else{la=0;do{U=(c[b+12160+(la<<3)>>2]|0)+(G<<n)|0;ga=(c[b+12160+(la<<3)+4>>2]|0)+(ma<<n)|0;ia=U-(c[b+12128+(la<<3)>>2]|0)|0;X=ga-(c[b+12128+(la<<3)+4>>2]|0)|0;na=(c[(b+12208|0)>>2]|0)+((la<<3&8)+(ca(la>>1,K<<3)|0))|0;if((m&1|0)==0){ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>1,K)|0)+(U>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ga&I)<<n)+(U&I)|0)<<2)>>2]&2047](na,ka,K,8);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>1,K)|0)+(ia>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&2047](na,ka,K,8)}else{ka=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ga>>2,K)|0)+(U>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ga&I)<<n)+(U&I)|0)<<2)>>2]&4095](na,ka,K);ka=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(X>>2,K)|0)+(ia>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((X&I)<<n)+(ia&I)|0)<<2)>>2]&4095](na,ka,K)}la=la+1|0;}while((la|0)<4)}}else{la=(c[(b+12160|0)>>2]|0)+(G<<n)|0;ka=(c[(b+12164|0)>>2]|0)+(ma<<n)|0;na=c[(b+12128|0)>>2]|0;if((G<<n|0)==0){Bc=(ca(na,J-qa|0)|0)/(qa|0)|0}else{Bc=la-na|0}na=c[(b+12132|0)>>2]|0;if((ma<<n|0)==0){Cc=(ca(na,J-qa|0)|0)/(qa|0)|0}else{Cc=ka-na|0}na=((Cc&I)<<n)+(Bc&I)|0;if((m&1|0)==0){ia=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ka>>1,K)|0)+(la>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ia,K,16);ia=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Cc>>1,K)|0)+(Bc>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+(na<<2)>>2]&2047](c[(b+12208|0)>>2]|0,ia,K,16);break}else{ia=(ca(ka>>2,K)|0)+(la>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+ia|0,K);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ia+8|0)|0,K);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(K<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(ia+(K<<3))|0,K);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ka&I)<<n)+(la&I)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((ia+8|0)+(K<<3))|0,K);ia=(ca(Cc>>2,K)|0)+(Bc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+ia|0,K);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ia+8|0)|0,K);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(K<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(ia+(K<<3))|0,K);ef[c[(c[(b+12456|0)>>2]|0)+64+(na<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((K<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ia+8|0)+(K<<3))|0,K);break}}}while(0);yc=Xe[z&511](b,c[(b+12208|0)>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,K,16)|0}}while(0);c[(N+(((ma<<3)+G&63)<<2)|0)>>2]=G+A+(ma<<11)|0;c[V+(((ma<<3)+G&63)<<2)>>2]=yc;K=(ca((d[_+((ma<<n)-F)|0]|0)+(d[_+((G<<n)-H)|0]|0)|0,l)|0)+yc|0;if((K|0)>=(ja|0)){vc=ja;wc=S;xc=M;break}c[r>>2]=G;c[(r+4|0)>>2]=ma;vc=K;wc=ma;xc=G}}while(0);G=$a+1|0;if((G|0)<8){$a=G;ja=vc;S=wc;M=xc}else{break}}if((xc|0)==(R|0)&(wc|0)==(L|0)){break}else{W=vc;L=wc;R=xc}}W=(s+255&(s&255)|0)!=0?B-1|0:B>>1;if((W|0)==0){sc=vc;tc=R;uc=L;break}else{B=W;O=vc;D=L;Q=R}}}Q=tc+1|0;D=(Q|0)>(C|0)?C:Q;Q=(y|0)>(D|0)?y:D;D=(uc|0)>(x|0)?x:uc;O=(E|0)>(D|0)?E:D;do{if((c[(N+((Q+(O<<3)&63)<<2)|0)>>2]|0)==(((O<<11)+A|0)+Q|0|0)){Dc=sc}else{do{if((m&4|0)==0){D=c[b+12416>>2]|0;B=c[b+12420>>2]|0;I=(c[b+12352+(j<<4)>>2]|0)+((ca(D,O)|0)+Q)|0;W=Xe[z&511](b,c[b+12288+(h<<4)>>2]|0,I,D,8)|0;if((m&2|0)==0){Ec=W;break}I=c[b+12208>>2]|0;M=(ca(B,O>>1)|0)+(Q>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((Q&1|O<<1&2)<<2)>>2]&2047](I+(D<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+M|0,B,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((Q&1|O<<1&2)<<2)>>2]&2047](I+(D<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+M|0,B,4);M=(Xe[T&511](b,I+(D<<4)|0,c[b+12288+(h<<4)+4>>2]|0,B,4)|0)+W|0;Ec=M+(Xe[T&511](b,I+(D<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,B,4)|0)|0}else{B=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(Q|0)){Ec=536870912;break}if((Q<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Ec=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Ec=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Ec=536870912;break}D=e[b+13872>>1]|0;I=e[b+13874>>1]|0;M=(m&1)<<1|1;q:do{if((c[b+11740>>2]|0)==1){if((Q<<n|0)==0){W=0;while(1){S=c[b+12160+(W<<3)>>2]|0;ja=(c[b+12160+(W<<3)+4>>2]|0)+(O<<n)|0;$a=((ca(c[b+12128+(W<<3)>>2]|0,I-D|0)|0)/(D|0)|0)+((W&1)<<(m&1|4))|0;G=c[b+12128+(W<<3)+4>>2]|0;if((O<<n|0)==0){ma=W>>1;Fc=((ca(G,I-D|0)|0)/(D|0)|0)+(ma<<(m&1|4))|0;Gc=ma}else{Fc=ja-G|0;Gc=W>>1}G=((Fc&M)<<n)+($a&M)|0;ma=(c[(b+12208|0)>>2]|0)+((ca(Gc,B<<3)|0)+(W<<3&8))|0;if((m&1|0)==0){K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja>>1,B)|0)+(S>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ja&M)<<n)+(S&M)|0)<<2)>>2]&2047](ma,K,B,8);K=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Fc>>1,B)|0)+($a>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(G<<2)>>2]&2047](ma,K,B,8)}else{K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja>>2,B)|0)+(S>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ja&M)<<n)+(S&M)|0)<<2)>>2]&4095](ma,K,B);K=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Fc>>2,B)|0)+($a>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(G<<2)>>2]&4095](ma,K,B)}W=W+1|0;if((W|0)>=4){break q}}}if((O<<n|0)==0){W=0;do{K=(c[b+12160+(W<<3)>>2]|0)+(Q<<n)|0;ma=c[b+12160+(W<<3)+4>>2]|0;G=K-(c[b+12128+(W<<3)>>2]|0)|0;$a=W>>1;S=((ca(c[b+12128+(W<<3)+4>>2]|0,I-D|0)|0)/(D|0)|0)+($a<<(m&1|4))|0;ja=(c[(b+12208|0)>>2]|0)+((W<<3&8)+(ca($a,B<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,B)|0)+(K>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&M)<<n)+(K&M)|0)<<2)>>2]&2047](ja,$a,B,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(S>>1,B)|0)+(G>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((S&M)<<n)+(G&M)|0)<<2)>>2]&2047](ja,$a,B,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>2,B)|0)+(K>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(K&M)|0)<<2)>>2]&4095](ja,$a,B);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(S>>2,B)|0)+(G>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((S&M)<<n)+(G&M)|0)<<2)>>2]&4095](ja,$a,B)}W=W+1|0;}while((W|0)<4)}else{W=0;do{$a=(c[b+12160+(W<<3)>>2]|0)+(Q<<n)|0;ja=(c[b+12160+(W<<3)+4>>2]|0)+(O<<n)|0;G=$a-(c[b+12128+(W<<3)>>2]|0)|0;S=ja-(c[b+12128+(W<<3)+4>>2]|0)|0;K=(c[(b+12208|0)>>2]|0)+((W<<3&8)+(ca(W>>1,B<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja>>1,B)|0)+($a>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ja&M)<<n)+($a&M)|0)<<2)>>2]&2047](K,ma,B,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(S>>1,B)|0)+(G>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((S&M)<<n)+(G&M)|0)<<2)>>2]&2047](K,ma,B,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ja>>2,B)|0)+($a>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ja&M)<<n)+($a&M)|0)<<2)>>2]&4095](K,ma,B);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(S>>2,B)|0)+(G>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((S&M)<<n)+(G&M)|0)<<2)>>2]&4095](K,ma,B)}W=W+1|0;}while((W|0)<4)}}else{W=(c[b+12160>>2]|0)+(Q<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;K=c[b+12128>>2]|0;if((Q<<n|0)==0){Hc=(ca(K,I-D|0)|0)/(D|0)|0}else{Hc=W-K|0}K=c[b+12132>>2]|0;if((O<<n|0)==0){Ic=(ca(K,I-D|0)|0)/(D|0)|0}else{Ic=ma-K|0}K=((Ic&M)<<n)+(Hc&M)|0;if((m&1|0)==0){G=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,B)|0)+(W>>1))|0;mf[c[(c[b+12444>>2]|0)+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,G,B,16);G=(c[b+12352+(j<<4)+32>>2]|0)+((ca(Ic>>1,B)|0)+(Hc>>1))|0;mf[c[(c[b+12448>>2]|0)+(K<<2)>>2]&2047](c[(b+12208|0)>>2]|0,G,B,16);break}else{G=(ca(ma>>2,B)|0)+(W>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+G|0,B);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(G+8|0)|0,B);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(B<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(G+(B<<3))|0,B);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&M)<<n)+(W&M)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((B<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((G+8|0)+(B<<3))|0,B);G=(ca(Ic>>2,B)|0)+(Hc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+G|0,B);ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(G+8|0)|0,B);ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(B<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(G+(B<<3))|0,B);ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((B<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((G+8|0)+(B<<3))|0,B);break}}}while(0);Ec=Xe[z&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,B,16)|0}}while(0);c[(N+((Q+(O<<3)&63)<<2)|0)>>2]=((O<<11)+A|0)+Q|0;c[V+((Q+(O<<3)&63)<<2)>>2]=Ec;R=(ca((d[_+((O<<n)-F)|0]|0)+(d[_+((Q<<n)-H)|0]|0)|0,l)|0)+Ec|0;if((R|0)>=(sc|0)){Dc=sc;break}c[r>>2]=Q;c[(r+4|0)>>2]=O;Dc=R}}while(0);Q=uc+1|0;R=(tc|0)>(C|0)?C:tc;L=(y|0)>(R|0)?y:R;R=(Q|0)>(x|0)?x:Q;Q=(E|0)>(R|0)?E:R;do{if((c[(N+(((Q<<3)+L&63)<<2)|0)>>2]|0)==((L+A|0)+(Q<<11)|0|0)){Jc=Dc}else{do{if((m&4|0)==0){R=c[b+12416>>2]|0;M=c[b+12420>>2]|0;D=(c[b+12352+(j<<4)>>2]|0)+((ca(R,Q)|0)+L)|0;I=Xe[z&511](b,c[b+12288+(h<<4)>>2]|0,D,R,8)|0;if((m&2|0)==0){Kc=I;break}D=c[b+12208>>2]|0;G=(ca(M,Q>>1)|0)+(L>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((Q<<1&2|L&1)<<2)>>2]&2047](D+(R<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+G|0,M,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((Q<<1&2|L&1)<<2)>>2]&2047](D+(R<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+G|0,M,4);G=(Xe[T&511](b,D+(R<<4)|0,c[b+12288+(h<<4)+4>>2]|0,M,4)|0)+I|0;Kc=G+(Xe[T&511](b,D+(R<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,M,4)|0)|0}else{M=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(L|0)){Kc=536870912;break}if((L<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Kc=536870912;break}if((c[(b+12272|0)>>2]|0)>(Q|0)){Kc=536870912;break}if((Q<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Kc=536870912;break}R=e[b+13872>>1]|0;D=e[b+13874>>1]|0;G=(m&1)<<1|1;r:do{if((c[b+11740>>2]|0)==1){if((L<<n|0)==0){I=0;while(1){K=c[b+12160+(I<<3)>>2]|0;W=(c[b+12160+(I<<3)+4>>2]|0)+(Q<<n)|0;ma=((ca(c[b+12128+(I<<3)>>2]|0,D-R|0)|0)/(R|0)|0)+((I&1)<<(m&1|4))|0;S=c[b+12128+(I<<3)+4>>2]|0;if((Q<<n|0)==0){$a=I>>1;Lc=((ca(S,D-R|0)|0)/(R|0)|0)+($a<<(m&1|4))|0;Mc=$a}else{Lc=W-S|0;Mc=I>>1}S=((Lc&G)<<n)+(ma&G)|0;$a=(c[(b+12208|0)>>2]|0)+((ca(Mc,M<<3)|0)+(I<<3&8))|0;if((m&1|0)==0){ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(W>>1,M)|0)+(K>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((W&G)<<n)+(K&G)|0)<<2)>>2]&2047]($a,ja,M,8);ja=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Lc>>1,M)|0)+(ma>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(S<<2)>>2]&2047]($a,ja,M,8)}else{ja=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(W>>2,M)|0)+(K>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((W&G)<<n)+(K&G)|0)<<2)>>2]&4095]($a,ja,M);ja=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Lc>>2,M)|0)+(ma>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(S<<2)>>2]&4095]($a,ja,M)}I=I+1|0;if((I|0)>=4){break r}}}if((Q<<n|0)==0){I=0;do{ja=(c[b+12160+(I<<3)>>2]|0)+(L<<n)|0;$a=c[b+12160+(I<<3)+4>>2]|0;S=ja-(c[b+12128+(I<<3)>>2]|0)|0;ma=I>>1;K=((ca(c[b+12128+(I<<3)+4>>2]|0,D-R|0)|0)/(R|0)|0)+(ma<<(m&1|4))|0;W=(c[(b+12208|0)>>2]|0)+((I<<3&8)+(ca(ma,M<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>1,M)|0)+(ja>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+(((($a&G)<<n)+(ja&G)|0)<<2)>>2]&2047](W,ma,M,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,M)|0)+(S>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(S&G)|0)<<2)>>2]&2047](W,ma,M,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>2,M)|0)+(ja>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(ja&G)|0)<<2)>>2]&4095](W,ma,M);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,M)|0)+(S>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(S&G)|0)<<2)>>2]&4095](W,ma,M)}I=I+1|0;}while((I|0)<4)}else{I=0;do{ma=(c[b+12160+(I<<3)>>2]|0)+(L<<n)|0;W=(c[b+12160+(I<<3)+4>>2]|0)+(Q<<n)|0;S=ma-(c[b+12128+(I<<3)>>2]|0)|0;K=W-(c[b+12128+(I<<3)+4>>2]|0)|0;ja=(c[(b+12208|0)>>2]|0)+((I<<3&8)+(ca(I>>1,M<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(W>>1,M)|0)+(ma>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((W&G)<<n)+(ma&G)|0)<<2)>>2]&2047](ja,$a,M,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,M)|0)+(S>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(S&G)|0)<<2)>>2]&2047](ja,$a,M,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(W>>2,M)|0)+(ma>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((W&G)<<n)+(ma&G)|0)<<2)>>2]&4095](ja,$a,M);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,M)|0)+(S>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(S&G)|0)<<2)>>2]&4095](ja,$a,M)}I=I+1|0;}while((I|0)<4)}}else{I=(c[b+12160>>2]|0)+(L<<n)|0;$a=(c[b+12164>>2]|0)+(Q<<n)|0;ja=c[b+12128>>2]|0;if((L<<n|0)==0){Nc=(ca(ja,D-R|0)|0)/(R|0)|0}else{Nc=I-ja|0}ja=c[b+12132>>2]|0;if((Q<<n|0)==0){Oc=(ca(ja,D-R|0)|0)/(R|0)|0}else{Oc=$a-ja|0}ja=((Oc&G)<<n)+(Nc&G)|0;if((m&1|0)==0){S=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca($a>>1,M)|0)+(I>>1))|0;mf[c[(c[b+12444>>2]|0)+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,S,M,16);S=(c[b+12352+(j<<4)+32>>2]|0)+((ca(Oc>>1,M)|0)+(Nc>>1))|0;mf[c[(c[b+12448>>2]|0)+(ja<<2)>>2]&2047](c[(b+12208|0)>>2]|0,S,M,16);break}else{S=(ca($a>>2,M)|0)+(I>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+S|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(S+8|0)|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(S+(M<<3))|0,M);ef[c[(c[(b+12452|0)>>2]|0)+64+(((($a&G)<<n)+(I&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((S+8|0)+(M<<3))|0,M);S=(ca(Oc>>2,M)|0)+(Nc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+S|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(S+8|0)|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(M<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(S+(M<<3))|0,M);ef[c[(c[(b+12456|0)>>2]|0)+64+(ja<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((M<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((S+8|0)+(M<<3))|0,M);break}}}while(0);Kc=Xe[z&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,M,16)|0}}while(0);c[(N+(((Q<<3)+L&63)<<2)|0)>>2]=(L+A|0)+(Q<<11)|0;c[V+(((Q<<3)+L&63)<<2)>>2]=Kc;G=(ca((d[_+((Q<<n)-F)|0]|0)+(d[_+((L<<n)-H)|0]|0)|0,l)|0)+Kc|0;if((G|0)>=(Dc|0)){Jc=Dc;break}c[r>>2]=L;c[(r+4|0)>>2]=Q;Jc=G}}while(0);Q=tc-1|0;G=(Q|0)>(C|0)?C:Q;Q=(y|0)>(G|0)?y:G;do{if((c[(N+((Q+(O<<3)&63)<<2)|0)>>2]|0)==(((O<<11)+A|0)+Q|0|0)){Pc=Jc}else{do{if((m&4|0)==0){G=c[b+12416>>2]|0;R=c[b+12420>>2]|0;D=(c[b+12352+(j<<4)>>2]|0)+((ca(G,O)|0)+Q)|0;B=Xe[z&511](b,c[b+12288+(h<<4)>>2]|0,D,G,8)|0;if((m&2|0)==0){Qc=B;break}D=c[b+12208>>2]|0;S=(ca(R,O>>1)|0)+(Q>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((Q&1|O<<1&2)<<2)>>2]&2047](D+(G<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+S|0,R,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((Q&1|O<<1&2)<<2)>>2]&2047](D+(G<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+S|0,R,4);S=(Xe[T&511](b,D+(G<<4)|0,c[b+12288+(h<<4)+4>>2]|0,R,4)|0)+B|0;Qc=S+(Xe[T&511](b,D+(G<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,R,4)|0)|0}else{R=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(Q|0)){Qc=536870912;break}if((Q<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Qc=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Qc=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Qc=536870912;break}G=e[b+13872>>1]|0;D=e[b+13874>>1]|0;S=(m&1)<<1|1;s:do{if((c[b+11740>>2]|0)==1){if((Q<<n|0)==0){B=0;while(1){ja=c[b+12160+(B<<3)>>2]|0;I=(c[b+12160+(B<<3)+4>>2]|0)+(O<<n)|0;$a=((ca(c[b+12128+(B<<3)>>2]|0,D-G|0)|0)/(G|0)|0)+((B&1)<<(m&1|4))|0;K=c[b+12128+(B<<3)+4>>2]|0;if((O<<n|0)==0){ma=B>>1;Rc=((ca(K,D-G|0)|0)/(G|0)|0)+(ma<<(m&1|4))|0;Sc=ma}else{Rc=I-K|0;Sc=B>>1}K=((Rc&S)<<n)+($a&S)|0;ma=(c[(b+12208|0)>>2]|0)+((ca(Sc,R<<3)|0)+(B<<3&8))|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(I>>1,R)|0)+(ja>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((I&S)<<n)+(ja&S)|0)<<2)>>2]&2047](ma,W,R,8);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Rc>>1,R)|0)+($a>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(K<<2)>>2]&2047](ma,W,R,8)}else{W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(I>>2,R)|0)+(ja>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((I&S)<<n)+(ja&S)|0)<<2)>>2]&4095](ma,W,R);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Rc>>2,R)|0)+($a>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(K<<2)>>2]&4095](ma,W,R)}B=B+1|0;if((B|0)>=4){break s}}}if((O<<n|0)==0){B=0;do{W=(c[b+12160+(B<<3)>>2]|0)+(Q<<n)|0;ma=c[b+12160+(B<<3)+4>>2]|0;K=W-(c[b+12128+(B<<3)>>2]|0)|0;$a=B>>1;ja=((ca(c[b+12128+(B<<3)+4>>2]|0,D-G|0)|0)/(G|0)|0)+($a<<(m&1|4))|0;I=(c[(b+12208|0)>>2]|0)+((B<<3&8)+(ca($a,R<<3)|0))|0;if((m&1|0)==0){$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,R)|0)+(W>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&S)<<n)+(W&S)|0)<<2)>>2]&2047](I,$a,R,8);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ja>>1,R)|0)+(K>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&2047](I,$a,R,8)}else{$a=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>2,R)|0)+(W>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(W&S)|0)<<2)>>2]&4095](I,$a,R);$a=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ja>>2,R)|0)+(K>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&4095](I,$a,R)}B=B+1|0;}while((B|0)<4)}else{B=0;do{$a=(c[b+12160+(B<<3)>>2]|0)+(Q<<n)|0;I=(c[b+12160+(B<<3)+4>>2]|0)+(O<<n)|0;K=$a-(c[b+12128+(B<<3)>>2]|0)|0;ja=I-(c[b+12128+(B<<3)+4>>2]|0)|0;W=(c[(b+12208|0)>>2]|0)+((B<<3&8)+(ca(B>>1,R<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(I>>1,R)|0)+($a>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((I&S)<<n)+($a&S)|0)<<2)>>2]&2047](W,ma,R,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ja>>1,R)|0)+(K>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&2047](W,ma,R,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(I>>2,R)|0)+($a>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((I&S)<<n)+($a&S)|0)<<2)>>2]&4095](W,ma,R);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(ja>>2,R)|0)+(K>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((ja&S)<<n)+(K&S)|0)<<2)>>2]&4095](W,ma,R)}B=B+1|0;}while((B|0)<4)}}else{B=(c[b+12160>>2]|0)+(Q<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;W=c[b+12128>>2]|0;if((Q<<n|0)==0){Tc=(ca(W,D-G|0)|0)/(G|0)|0}else{Tc=B-W|0}W=c[b+12132>>2]|0;if((O<<n|0)==0){Uc=(ca(W,D-G|0)|0)/(G|0)|0}else{Uc=ma-W|0}W=((Uc&S)<<n)+(Tc&S)|0;if((m&1|0)==0){K=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,R)|0)+(B>>1))|0;mf[c[(c[b+12444>>2]|0)+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,K,R,16);K=(c[b+12352+(j<<4)+32>>2]|0)+((ca(Uc>>1,R)|0)+(Tc>>1))|0;mf[c[(c[b+12448>>2]|0)+(W<<2)>>2]&2047](c[(b+12208|0)>>2]|0,K,R,16);break}else{K=(ca(ma>>2,R)|0)+(B>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+K|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(K+8|0)|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(K+(R<<3))|0,R);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&S)<<n)+(B&S)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((K+8|0)+(R<<3))|0,R);K=(ca(Uc>>2,R)|0)+(Tc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+K|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(K+8|0)|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(R<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(K+(R<<3))|0,R);ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((R<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((K+8|0)+(R<<3))|0,R);break}}}while(0);Qc=Xe[z&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,R,16)|0}}while(0);c[(N+((Q+(O<<3)&63)<<2)|0)>>2]=((O<<11)+A|0)+Q|0;c[V+((Q+(O<<3)&63)<<2)>>2]=Qc;S=(ca((d[_+((O<<n)-F)|0]|0)+(d[_+((Q<<n)-H)|0]|0)|0,l)|0)+Qc|0;if((S|0)>=(Jc|0)){Pc=Jc;break}c[r>>2]=Q;c[(r+4|0)>>2]=O;Pc=S}}while(0);O=uc-1|0;Q=(O|0)>(x|0)?x:O;O=(E|0)>(Q|0)?E:Q;if((c[(N+(((O<<3)+L&63)<<2)|0)>>2]|0)==((L+A|0)+(O<<11)|0|0)){t=Pc;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}do{if((m&4|0)==0){Q=c[b+12416>>2]|0;y=c[b+12420>>2]|0;C=(c[b+12352+(j<<4)>>2]|0)+((ca(Q,O)|0)+L)|0;S=Xe[z&511](b,c[b+12288+(h<<4)>>2]|0,C,Q,8)|0;if((m&2|0)==0){Vc=S;break}C=c[b+12208>>2]|0;G=(ca(y,O>>1)|0)+(L>>1)|0;mf[c[(c[(b+12444|0)>>2]|0)+32+((O<<1&2|L&1)<<2)>>2]&2047](C+(Q<<4)|0,(c[b+12352+(j<<4)+4>>2]|0)+G|0,y,4);mf[c[(c[(b+12444|0)>>2]|0)+32+((O<<1&2|L&1)<<2)>>2]&2047](C+(Q<<4|8)|0,(c[b+12352+(j<<4)+8>>2]|0)+G|0,y,4);G=(Xe[T&511](b,C+(Q<<4)|0,c[b+12288+(h<<4)+4>>2]|0,y,4)|0)+S|0;Vc=G+(Xe[T&511](b,C+(Q<<4|8)|0,c[b+12288+(h<<4)+8>>2]|0,y,4)|0)|0}else{y=c[b+12416>>2]|0;if((c[(b+12264|0)>>2]|0)>(L|0)){Vc=536870912;break}if((L<<n|0)>(c[(b+12268|0)>>2]<<n|0)){Vc=536870912;break}if((c[(b+12272|0)>>2]|0)>(O|0)){Vc=536870912;break}if((O<<n|0)>(c[(b+12276|0)>>2]<<n|0)){Vc=536870912;break}Q=e[b+13872>>1]|0;C=e[b+13874>>1]|0;G=(m&1)<<1|1;t:do{if((c[b+11740>>2]|0)==1){if((L<<n|0)==0){S=0;while(1){D=c[b+12160+(S<<3)>>2]|0;M=(c[b+12160+(S<<3)+4>>2]|0)+(O<<n)|0;K=((ca(c[b+12128+(S<<3)>>2]|0,C-Q|0)|0)/(Q|0)|0)+((S&1)<<(m&1|4))|0;W=c[b+12128+(S<<3)+4>>2]|0;if((O<<n|0)==0){B=S>>1;Wc=((ca(W,C-Q|0)|0)/(Q|0)|0)+(B<<(m&1|4))|0;Xc=B}else{Wc=M-W|0;Xc=S>>1}W=((Wc&G)<<n)+(K&G)|0;B=(c[(b+12208|0)>>2]|0)+((ca(Xc,y<<3)|0)+(S<<3&8))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(M>>1,y)|0)+(D>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((M&G)<<n)+(D&G)|0)<<2)>>2]&2047](B,ma,y,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Wc>>1,y)|0)+(K>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+(W<<2)>>2]&2047](B,ma,y,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(M>>2,y)|0)+(D>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((M&G)<<n)+(D&G)|0)<<2)>>2]&4095](B,ma,y);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(Wc>>2,y)|0)+(K>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(W<<2)>>2]&4095](B,ma,y)}S=S+1|0;if((S|0)>=4){break t}}}if((O<<n|0)==0){S=0;do{R=(c[b+12160+(S<<3)>>2]|0)+(L<<n)|0;ma=c[b+12160+(S<<3)+4>>2]|0;B=R-(c[b+12128+(S<<3)>>2]|0)|0;W=S>>1;K=((ca(c[b+12128+(S<<3)+4>>2]|0,C-Q|0)|0)/(Q|0)|0)+(W<<(m&1|4))|0;D=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ca(W,y<<3)|0))|0;if((m&1|0)==0){W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,y)|0)+(R>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((ma&G)<<n)+(R&G)|0)<<2)>>2]&2047](D,W,y,8);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,y)|0)+(B>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(B&G)|0)<<2)>>2]&2047](D,W,y,8)}else{W=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>2,y)|0)+(R>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(R&G)|0)<<2)>>2]&4095](D,W,y);W=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,y)|0)+(B>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(B&G)|0)<<2)>>2]&4095](D,W,y)}S=S+1|0;}while((S|0)<4)}else{S=0;do{W=(c[b+12160+(S<<3)>>2]|0)+(L<<n)|0;D=(c[b+12160+(S<<3)+4>>2]|0)+(O<<n)|0;B=W-(c[b+12128+(S<<3)>>2]|0)|0;K=D-(c[b+12128+(S<<3)+4>>2]|0)|0;R=(c[(b+12208|0)>>2]|0)+((S<<3&8)+(ca(S>>1,y<<3)|0))|0;if((m&1|0)==0){ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(D>>1,y)|0)+(W>>1))|0;mf[c[(c[(b+12444|0)>>2]|0)+16+((((D&G)<<n)+(W&G)|0)<<2)>>2]&2047](R,ma,y,8);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>1,y)|0)+(B>>1))|0;mf[c[(c[(b+12448|0)>>2]|0)+16+((((K&G)<<n)+(B&G)|0)<<2)>>2]&2047](R,ma,y,8)}else{ma=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(D>>2,y)|0)+(W>>2))|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((D&G)<<n)+(W&G)|0)<<2)>>2]&4095](R,ma,y);ma=(c[(b+12352+(j<<4)+32|0)>>2]|0)+((ca(K>>2,y)|0)+(B>>2))|0;ef[c[(c[(b+12456|0)>>2]|0)+64+((((K&G)<<n)+(B&G)|0)<<2)>>2]&4095](R,ma,y)}S=S+1|0;}while((S|0)<4)}}else{S=(c[b+12160>>2]|0)+(L<<n)|0;ma=(c[b+12164>>2]|0)+(O<<n)|0;R=c[b+12128>>2]|0;if((L<<n|0)==0){Yc=(ca(R,C-Q|0)|0)/(Q|0)|0}else{Yc=S-R|0}R=c[b+12132>>2]|0;if((O<<n|0)==0){Zc=(ca(R,C-Q|0)|0)/(Q|0)|0}else{Zc=ma-R|0}R=((Zc&G)<<n)+(Yc&G)|0;if((m&1|0)==0){B=(c[(b+12352+(j<<4)|0)>>2]|0)+((ca(ma>>1,y)|0)+(S>>1))|0;mf[c[(c[b+12444>>2]|0)+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&2047](c[(b+12208|0)>>2]|0,B,y,16);B=(c[b+12352+(j<<4)+32>>2]|0)+((ca(Zc>>1,y)|0)+(Yc>>1))|0;mf[c[(c[b+12448>>2]|0)+(R<<2)>>2]&2047](c[(b+12208|0)>>2]|0,B,y,16);break}else{B=(ca(ma>>2,y)|0)+(S>>2)|0;ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)|0)>>2]|0)+B|0,y);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(B+8|0)|0,y);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(y<<3)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+(B+(y<<3))|0,y);ef[c[(c[(b+12452|0)>>2]|0)+64+((((ma&G)<<n)+(S&G)|0)<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((y<<3)+8|0)|0,(c[(b+12352+(j<<4)|0)>>2]|0)+((B+8|0)+(y<<3))|0,y);B=(ca(Zc>>2,y)|0)+(Yc>>2)|0;ef[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095](c[(b+12208|0)>>2]|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+B|0,y);ef[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+8|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(B+8|0)|0,y);ef[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+(y<<3)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+(B+(y<<3))|0,y);ef[c[(c[(b+12456|0)>>2]|0)+64+(R<<2)>>2]&4095]((c[(b+12208|0)>>2]|0)+((y<<3)+8|0)|0,(c[(b+12352+(j<<4)+32|0)>>2]|0)+((B+8|0)+(y<<3))|0,y);break}}}while(0);Vc=Xe[z&511](b,c[b+12208>>2]|0,c[(b+12288+(h<<4)|0)>>2]|0,y,16)|0}}while(0);c[(N+(((O<<3)+L&63)<<2)|0)>>2]=(L+A|0)+(O<<11)|0;c[V+(((O<<3)+L&63)<<2)>>2]=Vc;z=(ca((d[_+((O<<n)-F)|0]|0)+(d[_+((L<<n)-H)|0]|0)|0,l)|0)+Vc|0;if((z|0)>=(Pc|0)){t=Pc;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}c[r>>2]=L;c[(r+4|0)>>2]=O;t=z;u=c[r>>2]|0;c[f>>2]=u;v=k+4|0;w=c[v>>2]|0;c[g>>2]=w;i=a;c[a+19152>>2]=6;c[a+19156>>2]=t|0;break a}while(0);c[a+19104>>2]=t;c[a+19112>>2]=u;c[a+19120>>2]=v;c[a+19128>>2]=w}



function Sfa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0;h=i;i=i+56|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=c[d+60>>2]|0;r=q;s=c[f>>2]|0;t=f+76|0;u=((c[t>>2]|0)+1|0)/2|0;v=d5a(d,e,u,(u|0)<0|0?-1:0)|0;if((v|0)<0){w=v;i=h;return w|0}v=c[t>>2]|0;u=v&-2;x=c[d+600>>2]|0;y=e+24|0;z=c[y>>2]|0;do{if((x|0)==0){if((u|0)<=0){break}A=q+2056|0;B=q+8|0;C=q+2116|0;D=C;E=C;C=q+2170|0;F=q+2060|0;H=F;I=F;F=q+2114|0;J=z;K=0;while(1){L=J+1|0;M=b[s+(K<<1)>>1]|0;N=c[A>>2]|0;c[A>>2]=N+1;b[r+8+(N<<1)>>1]=M;M=b[s+((K|1)<<1)>>1]|0;N=c[A>>2]|0;c[A>>2]=N+1;b[r+8+(N<<1)>>1]=M;Spb(r+8+((c[A>>2]|0)-24<<1)|0,m,n);M=c[m>>2]|0;N=c[n>>2]|0;O=c[A>>2]|0;if((O|0)>1023){orc(B|0,r+8+(O-22<<1)|0,44)|0;c[A>>2]=22}O=(M-N>>14)-(b[E>>1]|0)|0;if((O+32768|0)>>>0>65535>>>0){P=(O>>31^32767)&65535}else{P=O&65535}O=P<<16>>16;Q=b[C>>1]|0;R=((O>>31^O|0)<((Q*141|0)>>8|0)|((P&65535)>>>15&65535)<<1)^2;O=(N+M>>14)-(b[I>>1]|0)|0;if((O+32768|0)>>>0>65535>>>0){S=(O>>31^32767)&65535}else{S=O&65535}O=S<<16>>16;M=((O>>31^O)<<10)+1024|0;O=b[F>>1]|0;N=(M|0)>(O*370|0|0)?9:0;while(1){if((N|0)>=29){break}if((M|0)>(ca(b[920080+(N<<1)>>1]|0,O)|0)){N=N+1|0}else{break}}if(S<<16>>16<0){T=(N|0)<2?63:33}else{T=61}O=T-N|0;Rpb(D,(ca(b[1386128+(R<<1)>>1]|0,Q)|0)>>10,R);Ppb(H,O>>2);a[J]=O|R<<6;O=K+2|0;if((O|0)<(u|0)){J=L;K=O}else{break}}}else{K=1<<x;J=K<<3;H=c[q+2180>>2]|0;mrc(H|0,0,J|0)|0;D=q+2172|0;F=c[D>>2]|0;I=F+(K<<6)|0;c[H>>2]=I;c[F+(K<<6)+56>>2]=0;c[F+(K<<6)+60>>2]=0;F=q+2060|0;nrc(I|0,F|0,56)|0;I=c[q+2184>>2]|0;mrc(I|0,0,J|0)|0;J=q+2176|0;C=c[J>>2]|0;E=C+(K<<6)|0;c[I>>2]=E;c[C+(K<<6)+56>>2]=0;c[C+(K<<6)+60>>2]=0;C=q+2116|0;nrc(E|0,C|0,56)|0;E=v>>1;if((E|0)>0){A=K<<2;B=q+2056|0;O=q+8|0;M=(K|0)>0;U=(K|0)/2|0;V=q+2188|0;W=K>>1;X=W-1|0;Y=q+2192|0;Z=(K|0)>1;_=A-4|0;$=-1;aa=0;ba=0;da=0;ea=H+(K<<2)|0;fa=I+(K<<2)|0;ga=H;ha=I;while(1){ia=(da&1)<<x;ja=(c[D>>2]|0)+(ia<<6)|0;mrc(ea|0,0,A|0)|0;ka=(c[J>>2]|0)+(ia<<6)|0;mrc(fa|0,0,A|0)|0;ia=da<<1;la=b[s+(ia<<1)>>1]|0;ma=c[B>>2]|0;c[B>>2]=ma+1;b[r+8+(ma<<1)>>1]=la;la=b[s+((ia|1)<<1)>>1]|0;ia=c[B>>2]|0;c[B>>2]=ia+1;b[r+8+(ia<<1)>>1]=la;Spb(r+8+((c[B>>2]|0)-24<<1)|0,o,p);la=c[o>>2]|0;ia=c[p>>2]|0;ma=ia+la>>14;na=la-ia>>14;ia=c[B>>2]|0;if((ia|0)>1023){orc(O|0,r+8+(ia-22<<1)|0,44)|0;c[B>>2]=22}a:do{if(M){ia=0;la=aa;oa=0;pa=ja;while(1){qa=c[ga+(oa<<2)>>2]|0;if((qa|0)==0){ra=la;break}sa=(oa|0)<(U|0)?4:0;ta=qa|0;ua=ma-(b[ta>>1]|0)|0;if((ua+32768|0)>>>0>65535>>>0){va=(ua>>31^32767)&65535}else{va=ua&65535}ua=va<<16>>16;wa=((ua>>31^ua)<<10)+1024|0;ua=qa+54|0;xa=b[ua>>1]|0;ya=(wa|0)>(xa*370|0|0)?9:0;while(1){if((ya|0)>=29){break}if((wa|0)>(ca(b[920080+(ya<<1)>>1]|0,xa)|0)){ya=ya+1|0}else{break}}if(va<<16>>16<0){za=(ya|0)<2?63:33}else{za=61}xa=za-ya|0;wa=xa-sa|0;Aa=xa+sa|0;if((wa|0)<=(Aa|0)&(wa|0)<64){xa=qa+56|0;Ba=qa;Ca=qa+60|0;Da=ia;Ea=la;Fa=wa;wa=pa;while(1){b:do{if((Fa|0)<0){Ga=Ea;Ha=Da;Ia=wa}else{Ja=(ca(b[1385968+(Fa<<1)>>1]|0,b[ua>>1]|0)|0)>>10;Ka=Ja+(b[ta>>1]|0)|0;if((Ka|0)<-16384){La=-16384}else{La=(Ka|0)>16383?16383:Ka}Ka=ma-La|0;Ja=qc(c[xa>>2]|0,ca(Ka,Ka)|0)|0;Ka=Ja;if(G){Ga=Ea;Ha=Da;Ia=wa;break}if((Da|0)<(K|0)){c[ea+(Da<<2)>>2]=wa;c[wa+60>>2]=Ea;Ma=Ea+1|0;Na=wa;Oa=Da;Pa=wa+64|0}else{Ja=(Da&X)+W|0;Qa=c[ea+(Ja<<2)>>2]|0;if(Ka>>>0<(c[Qa+56>>2]|0)>>>0){Ma=Ea;Na=Qa;Oa=Ja;Pa=wa}else{Ga=Ea;Ha=Da;Ia=wa;break}}Ja=Da+1|0;c[Na+56>>2]=Ka;nrc(Na|0,Ba|0,56)|0;Ppb(Na|0,Fa>>2);Qa=Na+60|0;Ra=c[V>>2]|0;c[Ra+(c[Qa>>2]<<3)>>2]=Fa;c[Ra+(c[Qa>>2]<<3)+4>>2]=c[Ca>>2];if((Oa|0)>0){Sa=Oa}else{Ga=Ma;Ha=Ja;Ia=Pa;break}while(1){Qa=Sa-1>>1;Ra=ea+(Qa<<2)|0;Ta=c[Ra>>2]|0;if(!((c[Ta+56>>2]|0)>>>0>Ka>>>0)){Ga=Ma;Ha=Ja;Ia=Pa;break b}Ua=ea+(Sa<<2)|0;Va=c[Ua>>2]|0;c[Ua>>2]=Ta;c[Ra>>2]=Va;if((Qa|0)>0){Sa=Qa}else{Ga=Ma;Ha=Ja;Ia=Pa;break}}}}while(0);Ja=Fa+4|0;if((Ja|0)<=(Aa|0)&(Ja|0)<64){Da=Ha;Ea=Ga;Fa=Ja;wa=Ia}else{Wa=Ha;Xa=Ga;Ya=Ia;break}}}else{Wa=ia;Xa=la;Ya=pa}wa=oa+1|0;if((wa|0)<(K|0)){ia=Wa;la=Xa;oa=wa;pa=Ya}else{ra=Xa;break}}pa=0;oa=ba;la=0;ia=ka;while(1){wa=c[ha+(la<<2)>>2]|0;if((wa|0)==0){Za=oa;_a=ra;break a}Fa=wa+54|0;Ea=wa|0;Da=wa+56|0;Aa=wa;Ca=wa+60|0;wa=pa;Ba=0;xa=oa;ta=ia;while(1){ua=(ca(b[1386128+(Ba<<1)>>1]|0,b[Fa>>1]|0)|0)>>10;qa=ua+(b[Ea>>1]|0)|0;if((qa|0)<-16384){$a=-16384}else{$a=(qa|0)>16383?16383:qa}qa=na-$a|0;sa=qc(c[Da>>2]|0,ca(qa,qa)|0)|0;qa=sa;c:do{if(G){ab=xa;bb=wa;cb=ta}else{if((wa|0)<(K|0)){c[fa+(wa<<2)>>2]=ta;c[ta+60>>2]=xa;db=ta;eb=xa+1|0;fb=wa;gb=ta+64|0}else{sa=(wa&X)+W|0;ya=c[fa+(sa<<2)>>2]|0;if(qa>>>0<(c[ya+56>>2]|0)>>>0){db=ya;eb=xa;fb=sa;gb=ta}else{ab=xa;bb=wa;cb=ta;break}}sa=wa+1|0;c[db+56>>2]=qa;nrc(db|0,Aa|0,56)|0;Rpb(db|0,ua,Ba);ya=db+60|0;Ja=c[Y>>2]|0;c[Ja+(c[ya>>2]<<3)>>2]=Ba;c[Ja+(c[ya>>2]<<3)+4>>2]=c[Ca>>2];if((fb|0)>0){hb=fb}else{ab=eb;bb=sa;cb=gb;break}while(1){ya=hb-1>>1;Ja=fa+(ya<<2)|0;Ka=c[Ja>>2]|0;if(!((c[Ka+56>>2]|0)>>>0>qa>>>0)){ab=eb;bb=sa;cb=gb;break c}Qa=fa+(hb<<2)|0;Va=c[Qa>>2]|0;c[Qa>>2]=Ka;c[Ja>>2]=Va;if((ya|0)>0){hb=ya}else{ab=eb;bb=sa;cb=gb;break}}}}while(0);qa=Ba+1|0;if((qa|0)<4){wa=bb;Ba=qa;xa=ab;ta=cb}else{break}}ta=la+1|0;if((ta|0)<(K|0)){pa=bb;oa=ab;la=ta;ia=cb}else{Za=ab;_a=ra;break}}}else{Za=ba;_a=aa}}while(0);na=c[ea>>2]|0;ka=na+56|0;ma=(c[ka>>2]|0)>>>0>65536>>>0;do{if(Z){if(ma){ja=1;do{L=c[ea+(ja<<2)>>2]|0;if((L|0)==0){break}R=L+56|0;c[R>>2]=(c[R>>2]|0)-(c[ka>>2]|0);ja=ja+1|0;}while((ja|0)<(K|0));c[ka>>2]=0}ja=c[fa>>2]|0;R=ja+56|0;if((c[R>>2]|0)>>>0>65536>>>0){ib=1}else{jb=ja;break}do{L=c[fa+(ib<<2)>>2]|0;if((L|0)==0){break}Q=L+56|0;c[Q>>2]=(c[Q>>2]|0)-(c[R>>2]|0);ib=ib+1|0;}while((ib|0)<(K|0));c[R>>2]=0;jb=ja}else{if(ma){c[ka>>2]=0}Q=c[fa>>2]|0;L=Q+56|0;if(!((c[L>>2]|0)>>>0>65536>>>0)){jb=Q;break}c[L>>2]=0;jb=Q}}while(0);if((da|0)==($+128|0)){if((da|0)>($|0)){ka=(c[V>>2]|0)+(c[na+60>>2]<<3)|0;ma=(c[Y>>2]|0)+(c[jb+60>>2]<<3)|0;Q=da;while(1){a[z+Q|0]=c[ma>>2]<<6|c[ka>>2];L=Q-1|0;if((L|0)>($|0)){ka=(c[V>>2]|0)+(c[ka+4>>2]<<3)|0;ma=(c[Y>>2]|0)+(c[ma+4>>2]<<3)|0;Q=L}else{break}}}mrc(ea+4|0,0,_|0)|0;mrc(fa+4|0,0,_|0)|0;kb=0;lb=0;mb=da}else{kb=Za;lb=_a;mb=$}Q=da+1|0;if((Q|0)<(E|0)){ma=fa;ka=ea;ea=ga;fa=ha;$=mb;aa=lb;ba=kb;da=Q;ha=ma;ga=ka}else{break}}if((E|0)>(mb|0)){nb=Y;ob=V;pb=ea;qb=fa;rb=E;sb=mb;tb=61}else{ub=ea;vb=fa}}else{nb=q+2192|0;ob=q+2188|0;pb=H;qb=I;rb=0;sb=-1;tb=61}if((tb|0)==61){ga=(c[ob>>2]|0)+(c[(c[pb>>2]|0)+60>>2]<<3)|0;ha=(c[nb>>2]|0)+(c[(c[qb>>2]|0)+60>>2]<<3)|0;da=rb;while(1){a[z+da|0]=c[ha>>2]<<6|c[ga>>2];ba=da-1|0;if((ba|0)>(sb|0)){ga=(c[ob>>2]|0)+(c[ga+4>>2]<<3)|0;ha=(c[nb>>2]|0)+(c[ha+4>>2]<<3)|0;da=ba}else{ub=pb;vb=qb;break}}}nrc(F|0,c[ub>>2]|0,56)|0;nrc(C|0,c[vb>>2]|0,56)|0}}while(0);if((u|0)<(c[t>>2]|0)){t=b[s+(u<<1)>>1]|0;u=(c[y>>2]|0)+(v>>1)|0;v=q+2056|0;y=c[v>>2]|0;c[v>>2]=y+1;b[r+8+(y<<1)>>1]=t;y=c[v>>2]|0;c[v>>2]=y+1;b[r+8+(y<<1)>>1]=t;Spb(r+8+((c[v>>2]|0)-24<<1)|0,k,l);t=c[k>>2]|0;k=c[l>>2]|0;l=c[v>>2]|0;if((l|0)>1023){orc(q+8|0,r+8+(l-22<<1)|0,44)|0;c[v>>2]=22}v=q+2116|0;l=v;r=(t-k>>14)-(b[v>>1]|0)|0;if((r+32768|0)>>>0>65535>>>0){wb=(r>>31^32767)&65535}else{wb=r&65535}r=wb<<16>>16;v=b[q+2170>>1]|0;y=((r>>31^r|0)<((v*141|0)>>8|0)|((wb&65535)>>>15&65535)<<1)^2;wb=q+2060|0;r=wb;s=(k+t>>14)-(b[wb>>1]|0)|0;if((s+32768|0)>>>0>65535>>>0){xb=(s>>31^32767)&65535}else{xb=s&65535}s=xb<<16>>16;wb=((s>>31^s)<<10)+1024|0;s=b[q+2114>>1]|0;q=(wb|0)>(s*370|0|0)?9:0;while(1){if((q|0)>=29){break}if((wb|0)>(ca(b[920080+(q<<1)>>1]|0,s)|0)){q=q+1|0}else{break}}if(xb<<16>>16<0){yb=(q|0)<2?63:33}else{yb=61}xb=yb-q|0;Rpb(l,(ca(b[1386128+(y<<1)>>1]|0,v)|0)>>10,y);Ppb(r,xb>>2);a[u]=xb|y<<6}y=f+136|0;f=c[y>>2]|0;xb=c[y+4>>2]|0;if(!((f|0)==0&(xb|0)==(-2147483648|0))){y=c[d+116>>2]|0;c[j>>2]=1;c[j+4>>2]=c[d+412>>2];u=XIb(y,(y|0)<0|0?-1:0,j,d+104|0)|0;d=xrc(f,xb,u,G)|0;u=e+8|0;c[u>>2]=d;c[u+4>>2]=G}c[g>>2]=1;w=0;i=h;return w|0}function Tfa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+2188|0);mJb(b+2172|0);mJb(b+2180|0);mJb(b+2192|0);mJb(b+2176|0);mJb(b+2184|0);return 0}function Ufa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;c[a+420>>2]=1;c[a+416>>2]=1;c[b+1360>>2]=4096;nrc(b+144|0,1615400,20)|0;nrc(b+164|0,1615400,20)|0;c[b+1336>>2]=12345;c[b+120>>2]=1;return 0}function Vfa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0;k=i;i=i+2088|0;l=k|0;m=k+16|0;n=k+104|0;o=k+192|0;p=k+672|0;q=k+792|0;r=k+832|0;s=k+1832|0;t=k+1864|0;u=k+1888|0;v=k+1968|0;w=c[f+60>>2]|0;x=w;y=g;z=c[j+24>>2]|0;A=c[j+28>>2]|0;j=w+1368|0;B=j;C=j;D=d[1209912+(a[z]&3)|0]|0;if((A|0)<(D|0)){if((A|0)!=0){KIb(f,24,2205976,(E=i,i=i+16|0,c[E>>2]=D,c[E+8>>2]=A,E)|0);i=E}c[h>>2]=0;F=A;i=k;return F|0}E=A<<3;A=E>>>0>2147483639>>>0|(z|0)==0;H=A?0:z;z=A?8:E+8|0;E=H;A=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24)&3;E=z>>>0>2>>>0?2:z;a:do{if((A|0)==3){c[w+116>>2]=2;I=0}else{J=H+(E>>>3)|0;K=E+8|0;L=z>>>0>K>>>0?K:z;a[w+130|0]=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((E&2)>>>0);J=H+(L>>>3)|0;K=L+8|0;M=z>>>0>K>>>0?K:z;a[w+129|0]=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((L&7)>>>0);L=H+(M>>>3)|0;J=M+8|0;K=z>>>0>J>>>0?J:z;a[w+128|0]=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((M&7)>>>0);if((A|0)==2){c[w+116>>2]=1;M=H+(K>>>3)|0;c[w+24>>2]=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((K&7)>>>0)&63;I=0;break}M=w+124|0;c[M>>2]=(A|0)!=0;L=w+116|0;c[L>>2]=0;J=H+(K>>>3)|0;N=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((K&7)>>>0)&127;J=K+7|0;K=z>>>0>J>>>0?J:z;J=w+132|0;c[J>>2]=N;b:do{if(!(N>>>0>123>>>0)){c[J>>2]=N+18;O=H+(K>>>3)|0;P=K+2|0;Q=z>>>0>P>>>0?P:z;c[w+32>>2]=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((K&7)>>>0)&3;O=H+(Q>>>3)|0;P=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((Q&7)>>>0)&127;O=Q+7|0;Q=z>>>0>O>>>0?O:z;O=w+136|0;c[O>>2]=P;if(P>>>0>123>>>0){break}c[O>>2]=P+18;P=H+(Q>>>3)|0;O=Q+2|0;R=z>>>0>O>>>0?O:z;c[w+88>>2]=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((Q&7)>>>0)&3;c[w+4>>2]=1;c[w+60>>2]=1;Q=c[341986]|0;P=0;O=R;S=0;T=H+(R>>>3)|0;do{R=T;U=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((O&7)>>>0);R=U&4095;V=O+12|0;O=z>>>0>V>>>0?V:z;V=x+4+(S*28|0)+8|0;c[V>>2]=0;do{if((c[M>>2]|0)==0){if((c[x+132+(S>>1<<2)>>2]|0)>=58){W=R;X=170;break}c[V>>2]=R>>>11;W=U&2047;X=85}else{W=R;X=170}}while(0);Erc(W,0,Q,P)|0;R=G;c[x+4+(S*28|0)+4>>2]=R;if(!(R>>>0<X>>>0)){break b}c[x+4+(S*28|0)+20>>2]=(R*-24|0)+W;S=S+1|0;T=H+(O>>>3)|0}while((S|0)<4);S=((O|0)<(z|0))+O|0;c[w+20>>2]=(d[T]|0)>>>((O&7)>>>0)&1;P=((S|0)<(z|0))+S|0;c[w+48>>2]=(d[H+(S>>>3)|0]|0)>>>((S&7)>>>0)&1;S=((P|0)<(z|0))+P|0;c[w+76>>2]=(d[H+(P>>>3)|0]|0)>>>((P&7)>>>0)&1;P=((S|0)<(z|0))+S|0;c[w+104>>2]=(d[H+(S>>>3)|0]|0)>>>((S&7)>>>0)&1;if((c[M>>2]|0)==0){S=P+1|0;Q=z>>>0>S>>>0?S:z;S=H+(Q>>>3)|0;R=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((Q&7)>>>0)&8191;S=Q+13|0;Q=z>>>0>S>>>0?S:z;S=(R>>>0)/810|0;U=w+28|0;c[U>>2]=S;V=R+(S*-810|0)|0;Erc(V,(V|0)<0|0?-1:0,c[342052]|0,0)|0;R=G;Y=R;Z=w+56|0;c[Z>>2]=Y;_=(Y*-90|0)+V|0;Erc(_,(_|0)<0|0?-1:0,c[341971]|0,0)|0;V=G;Y=V;$=w+84|0;c[$>>2]=Y;aa=(Y*-9|0)+_|0;_=w+112|0;c[_>>2]=aa;Y=H+(Q>>>3)|0;ba=Q+16|0;da=z>>>0>ba>>>0?ba:z;c[U>>2]=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((Q&7)>>>0)&65535|S<<16;S=H+(da>>>3)|0;Q=da+14|0;Y=z>>>0>Q>>>0?Q:z;c[Z>>2]=R<<14|0>>>18|(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((da&7)>>>0)&16383;da=H+(Y>>>3)|0;S=Y+16|0;R=z>>>0>S>>>0?S:z;c[$>>2]=V<<16|0>>>16|(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((Y&7)>>>0)&65535;Y=H+(R>>>3)|0;da=R+14|0;V=z>>>0>da>>>0?da:z;c[_>>2]=aa<<14|(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&16383;R=H+(V>>>3)|0;Y=V+6|0;aa=z>>>0>Y>>>0?Y:z;c[w+16>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((V&7)>>>0)&63;V=H+(aa>>>3)|0;R=aa+5|0;Y=z>>>0>R>>>0?R:z;c[w+44>>2]=(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((aa&7)>>>0)&31;aa=H+(Y>>>3)|0;V=Y+6|0;R=z>>>0>V>>>0?V:z;c[w+72>>2]=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((Y&7)>>>0)&63;Y=H+(R>>>3)|0;c[w+100>>2]=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&31;I=0;break a}else{R=H+(P>>>3)|0;Y=P+12|0;aa=z>>>0>Y>>>0?Y:z;c[w+28>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((P&7)>>>0)&4095;P=H+(aa>>>3)|0;R=aa+12|0;Y=z>>>0>R>>>0?R:z;c[w+56>>2]=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((aa&7)>>>0)&4095;aa=H+(Y>>>3)|0;P=Y+12|0;R=z>>>0>P>>>0?P:z;c[w+84>>2]=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((Y&7)>>>0)&4095;Y=H+(R>>>3)|0;aa=R+12|0;P=z>>>0>aa>>>0?aa:z;c[w+112>>2]=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&4095;R=H+(P>>>3)|0;Y=P+4|0;aa=z>>>0>Y>>>0?Y:z;c[w+16>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((P&7)>>>0)&15;P=H+(aa>>>3)|0;R=aa+4|0;Y=z>>>0>R>>>0?R:z;c[w+44>>2]=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((aa&7)>>>0)&15;aa=H+(Y>>>3)|0;P=Y+4|0;R=z>>>0>P>>>0?P:z;c[w+72>>2]=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((Y&7)>>>0)&15;Y=H+(R>>>3)|0;c[w+100>>2]=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&15;I=0;break a}}}while(0);if((c[w+120>>2]|0)==0){c[L>>2]=0;I=1;break}else{c[L>>2]=2;I=1;break}}}while(0);c[g+76>>2]=240;H=M4a(f,y,0)|0;if((H|0)<0){F=H;i=k;return F|0}H=g;g=c[H>>2]|0;y=w+116|0;f=c[y>>2]|0;do{if((f|0)==0){z=w+140|0;do{if((I|0)==0){c[z>>2]=0}else{W=c[z>>2]|0;if((W|0)==3){break}c[z>>2]=W+1}}while(0);L=t|0;W=w+144|0;X=W;Zfa(L,X,w+128|0,I);_fa(u|0,L,X);nrc(W|0,t|0,20)|0;W=w+474|0;X=W;L=w+184|0;nrc(W|0,L|0,290)|0;A=c[z>>2]|0;do{if((A|0)==0){E=w+764|0;M=w+4|0;c[w+1344>>2]=b[1215464+((c[w+108>>2]|0)+(c[w+80>>2]|0)>>1<<1)>>1]|0;K=w+124|0;N=w+132|0;J=p;R=v|0;Y=0;aa=E;while(1){P=M+(Y*28|0)|0;V=c[K>>2]|0;_=N+(Y>>1<<2)|0;da=c[_>>2]|0;$=aa;mrc($|0,0,120)|0;do{if((V|0)==0){S=c[M+(Y*28|0)+24>>2]|0;if((S|0)>=(c[833080+(Y<<2)>>2]|0)){break}Z=M+(Y*28|0)+12|0;Q=M+(Y*28|0)+20|0;U=M+(Y*28|0)+16|0;ba=6-(a[696544+Y|0]|0)|0;ea=0;fa=S;while(1){S=fa-(c[1639352+(ba*120|0)+(ea<<2)>>2]|0)|0;if((S|0)>-1){ga=S;ha=ba}else{S=ba+1|0;ia=b[1215464+(c[Q>>2]<<1)>>1]|0;if((c[Z>>2]&1<<5-ba|0)==0){b[aa+((c[U>>2]|0)+(ea<<1)<<1)>>1]=ia}else{b[aa+((c[U>>2]|0)+(ea<<1)<<1)>>1]=-ia}if((S|0)==6){break}else{ga=fa;ha=S}}S=ea+1|0;if((S|0)<30){ba=ha;ea=S;fa=ga}else{break}}if((c[M+(Y*28|0)+8>>2]|0)!=1){break}nrc(J|0,$|0,120)|0;if((da|0)<60){ja=da}else{break}do{fa=60-ja|0;if((fa|0)>0){ea=0;do{ba=aa+(ea+ja<<1)|0;b[ba>>1]=(b[ba>>1]|0)+(b[p+(ea<<1)>>1]|0);ea=ea+1|0;}while((ea|0)<(fa|0))}ja=ja+da|0;}while((ja|0)<60)}else{fa=b[1215464+(c[M+(Y*28|0)+20>>2]<<1)>>1]|0;ea=c[M+(Y*28|0)+16>>2]|0;ba=c[M+(Y*28|0)+12>>2]|0;U=c[M+(Y*28|0)+24>>2]|0;Z=-fa&65535;b[aa+((U<<3&56)+ea<<1)>>1]=(ba&1|0)!=0?fa:Z;b[aa+(ea+2+(U>>3<<3&56)<<1)>>1]=(ba&2|0)!=0?fa:Z;b[aa+(ea+4+(U>>6<<3&56)<<1)>>1]=(ba&4|0)!=0?fa:Z;b[aa+(ea+6+(U>>9<<3&56)<<1)>>1]=(ba&8|0)!=0?fa:Z;Z=c[M+(Y*28|0)+4>>2]<<1;fa=da-1+(b[729344+(Z<<1)>>1]|0)+(c[P>>2]|0)|0;ba=b[729344+((Z|1)<<1)>>1]|0;if((fa|0)<58){ka=fa}else{break}do{Z=(ca(b[aa+(ka-fa<<1)>>1]|0,ba)|0)>>>15;U=aa+(ka<<1)|0;b[U>>1]=Z+(e[U>>1]|0);ka=ka+1|0;}while((ka|0)<60)}}while(0);aga(R,X+((Y*60|0)<<1)|0,c[_>>2]|0,P,c[K>>2]|0);da=0;do{$=aa+(da<<1)|0;V=b[$>>1]|0;ba=V<<1;if((ba+32768|0)>>>0>65535>>>0){la=(V>>30^32767)&65535}else{la=ba&65535}ba=(b[v+(da<<1)>>1]|0)+(la<<16>>16)|0;if((ba+32768|0)>>>0>65535>>>0){ma=(ba>>31^32767)&65535}else{ma=ba&65535}b[$>>1]=ma;da=da+1|0;}while((da|0)<60);da=Y+1|0;if((da|0)<4){Y=da;aa=aa+120|0}else{break}}aa=c[w+136>>2]|0;Y=w+1348|0;R=w+1352|0;M=0;J=0;do{O=b[x+474+(J<<1)>>1]|0;T=O<<16>>16;M=(O<<16>>16>-1?T:-T|0)|M;J=J+1|0;}while((J|0)<385);J=Y;T=R;O=(M&65280|0)==0;da=(O?14:6)-(d[1359664+(O?M:M>>>8)|0]|0)|0;O=(da|0)>0?da:0;da=0;do{b[x+1368+(da+10<<1)>>1]=b[x+474+(da<<1)>>1]<<O>>>3;da=da+1|0;}while((da|0)<385);c[T>>2]=O-3;da=w+1918|0;M=(aa|0)<142?aa:142;R=M+3|0;Y=0;P=M-3|0;M=0;do{_=Q3(da,x+1368+(275-P<<1)|0,120)|0;$=_;_=0>>>31|$<<1;ba=wrc(_,$>>31|(($|0)<0|0?-1:0)<<1,-2147483648,0)|0;V=G;fa=0;if(V>>>0>fa>>>0|V>>>0==fa>>>0&ba>>>0>-1>>>0){(($|0)<0|0?-1:0)>>31|(($|0)<0|0?-1:0)<<1;na=($>>31|(($|0)<0|0?-1:0)<<1)^2147483647}else{na=_}_=(na|0)>(M|0);M=_?na:M;Y=_?P:Y;P=P+1|0;}while((P|0)<=(R|0));R=M;P=(M|0)<0|0?-1:0;aa=wrc(R,P,32768,0)|0;O=G;T=wrc(R,P,-2147450880,0)|0;P=G;R=0;if(P>>>0>R>>>0|P>>>0==R>>>0&T>>>0>-1>>>0){((O|0)<0|0?-1:0)>>31|((O|0)<0|0?-1:0)<<1;oa=(O>>31|((O|0)<0|0?-1:0)<<1)^2147483647}else{oa=aa}aa=oa>>16;O=Q3(da,da,120)|0;T=O;O=0>>>31|T<<1;R=wrc(O,T>>31|((T|0)<0|0?-1:0)<<1,-2147483648,0)|0;P=G;_=0;if(P>>>0>_>>>0|P>>>0==_>>>0&R>>>0>-1>>>0){((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;pa=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{pa=O}O=pa;T=(pa|0)<0|0?-1:0;R=wrc(O,T,32768,0)|0;_=G;P=wrc(O,T,-2147450880,0)|0;T=G;O=0;if(T>>>0>O>>>0|T>>>0==O>>>0&P>>>0>-1>>>0){((_|0)<0|0?-1:0)>>31|((_|0)<0|0?-1:0)<<1;qa=(_>>31|((_|0)<0|0?-1:0)<<1)^2147483647}else{qa=R}c[J>>2]=qa>>16;if((aa|0)<1){ra=0}else{R=x+1368+(275-Y<<1)|0;_=Q3(R,R,120)|0;R=_;_=0>>>31|R<<1;P=wrc(_,R>>31|((R|0)<0|0?-1:0)<<1,-2147483648,0)|0;O=G;T=0;if(O>>>0>T>>>0|O>>>0==T>>>0&P>>>0>-1>>>0){((R|0)<0|0?-1:0)>>31|((R|0)<0|0?-1:0)<<1;sa=(R>>31|((R|0)<0|0?-1:0)<<1)^2147483647}else{sa=_}_=sa;R=(sa|0)<0|0?-1:0;P=wrc(_,R,32768,0)|0;T=G;O=wrc(_,R,-2147450880,0)|0;R=G;_=0;if(R>>>0>_>>>0|R>>>0==_>>>0&O>>>0>-1>>>0){((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;ta=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{ta=P}P=((ca(ta>>16,c[J>>2]|0)|0)>>3|0)<(ca(aa,aa)|0);ra=P?Y:0}c[w+1340>>2]=ra;if((c[w+1364>>2]|0)==0){ua=w+744|0}else{P=0;aa=145;while(1){T=c[N+(P>>1<<2)>>2]|0;O=s+(P<<3)|0;_=c[K>>2]|0;R=aa+10|0;$=x+1368+(R<<1)|0;ba=(T|0)<142?T:142;T=385-aa-60|0;fa=ba+3|0;V=(T|0)>(fa|0)?fa:T;T=ba-3|0;if((T|0)>(V|0)){va=0;wa=0}else{ba=0;U=T;Z=0;while(1){ea=Q3($,x+1368+(U+R<<1)|0,60)|0;Q=ea;ea=0>>>31|Q<<1;S=wrc(ea,Q>>31|((Q|0)<0|0?-1:0)<<1,-2147483648,0)|0;ia=G;xa=0;if(ia>>>0>xa>>>0|ia>>>0==xa>>>0&S>>>0>-1>>>0){((Q|0)<0|0?-1:0)>>31|((Q|0)<0|0?-1:0)<<1;ya=(Q>>31|((Q|0)<0|0?-1:0)<<1)^2147483647}else{ya=ea}ea=(ya|0)>(Z|0);Q=ea?ya:Z;S=ea?U:ba;ea=U+1|0;if((ea|0)>(V|0)){va=S;wa=Q;break}else{ba=S;U=ea;Z=Q}}}Z=0;U=T;ba=0;do{V=Q3($,x+1368+(R-U<<1)|0,60)|0;Q=V;V=0>>>31|Q<<1;ea=wrc(V,Q>>31|((Q|0)<0|0?-1:0)<<1,-2147483648,0)|0;S=G;xa=0;if(S>>>0>xa>>>0|S>>>0==xa>>>0&ea>>>0>-1>>>0){((Q|0)<0|0?-1:0)>>31|((Q|0)<0|0?-1:0)<<1;za=(Q>>31|((Q|0)<0|0?-1:0)<<1)^2147483647}else{za=V}V=(za|0)>(ba|0);ba=V?za:ba;Z=V?U:Z;U=U+1|0;}while((U|0)<=(fa|0));c[O>>2]=0;b[s+(P<<3)+4>>1]=0;b[s+(P<<3)+6>>1]=32767;fa=(Z|0)!=0;do{if(!((va|0)==0&(fa^1))){U=Q3($,$,60)|0;T=U;U=0>>>31|T<<1;V=wrc(U,T>>31|((T|0)<0|0?-1:0)<<1,-2147483648,0)|0;Q=G;ea=0;if(Q>>>0>ea>>>0|Q>>>0==ea>>>0&V>>>0>-1>>>0){((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;Aa=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{Aa=U}U=(va|0)!=0;do{if(U){T=x+1368+(va+R<<1)|0;V=Q3(T,T,60)|0;T=V;V=0>>>31|T<<1;ea=wrc(V,T>>31|((T|0)<0|0?-1:0)<<1,-2147483648,0)|0;Q=G;xa=0;if(!(Q>>>0>xa>>>0|Q>>>0==xa>>>0&ea>>>0>-1>>>0)){Ba=V;break}((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;Ba=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{Ba=0}}while(0);do{if(fa){T=x+1368+(R-Z<<1)|0;V=Q3(T,T,60)|0;T=V;V=0>>>31|T<<1;ea=wrc(V,T>>31|((T|0)<0|0?-1:0)<<1,-2147483648,0)|0;xa=G;Q=0;if(!(xa>>>0>Q>>>0|xa>>>0==Q>>>0&ea>>>0>-1>>>0)){Ca=V;break}((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;Ca=(T>>31|((T|0)<0|0?-1:0)<<1)^2147483647}else{Ca=0}}while(0);T=(Aa|0)>0?Aa:0;V=(wa|0)>(T|0)?wa:T;T=(Ba|0)>(V|0)?Ba:V;V=(ba|0)>(T|0)?ba:T;T=(Ca|0)>(V|0)?Ca:V;V=T>>>0>65535>>>0;ea=V?T>>>16:T;T=V?16:0;if((ea&65280|0)==0){Da=T;Ea=ea}else{Da=T|8;Ea=ea>>>8}ea=30-Da-(d[1359664+Ea|0]|0)|0;T=Aa<<ea>>16;V=wa<<ea>>16;Q=Ba<<ea>>16;xa=ba<<ea>>16;S=Ca<<ea>>16;if(!(fa|U^1)){dga(va,O,_,T,V,Q);break}if(!U){dga(-Z|0,O,_,T,xa,S);break}if((ca(((ca(V,V)|0)+16384|0)>>>15,S)|0)<(ca(((ca(xa,xa)|0)+16384|0)>>>15,Q)|0)){dga(-Z|0,O,_,T,xa,S);break}else{dga(va,O,_,T,V,Q);break}}}while(0);_=P+1|0;if((_|0)<4){P=_;aa=aa+60|0}else{break}}ylb(w+1388|0,E,E+(c[s>>2]<<1)|0,b[s+6>>1]|0,b[s+4>>1]|0,16384,15,60);ylb(w+1508|0,w+884|0,E+((c[s+8>>2]|0)+60<<1)|0,b[s+14>>1]|0,b[s+12>>1]|0,16384,15,60);ylb(w+1628|0,w+1004|0,E+((c[s+16>>2]|0)+120<<1)|0,b[s+22>>1]|0,b[s+20>>1]|0,16384,15,60);ylb(w+1748|0,w+1124|0,E+((c[s+24>>2]|0)+180<<1)|0,b[s+30>>1]|0,b[s+28>>1]|0,16384,15,60);ua=C}nrc(L|0,w+954|0,290)|0;Fa=ua}else{aa=w+1344|0;P=((c[aa>>2]|0)*3|0)+2>>2;c[aa>>2]=P;if((A|0)==3){mrc(L|0,0,1060)|0;mrc(c[H>>2]|0,0,500)|0;Fa=C;break}aa=w+1388|0;K=W;N=c[w+1340>>2]|0;Y=w+1332|0;if((N|0)==0){J=0;da=c[Y>>2]|0;do{da=(da*521|0)+259|0;b[aa+(J<<1)>>1]=(ca(da,P)|0)>>>15;J=J+1|0;}while((J|0)<240);c[Y>>2]=da;mrc(W|0,0,770)|0}else{if((N|0)>0){J=145-N|0;P=0;do{b[aa+(P<<1)>>1]=((b[K+(J+P<<1)>>1]|0)*3|0)>>>2;P=P+1|0;}while((P|0)<(N|0))}vJb(aa+(N<<1)|0,N<<1,240-N<<1)}nrc(L|0,w+1578|0,290)|0;Fa=C}}while(0);c[w+1336>>2]=12345;Ga=Fa}else if((f|0)==1){L=c[w+24>>2]|0;do{if((L|0)<16){Ha=L<<6}else{if((L|0)<32){Ha=(L<<7)-1024|0;break}else{Ha=(L<<8)-5120|0;break}}}while(0);c[w+1348>>2]=Ha;Zfa(w+164|0,w+144|0,w+128|0,0);if((c[w+120>>2]|0)==0){Ia=137}else{Ia=138}}else{if((c[w+120>>2]|0)!=0){Ia=138;break}L=w+1348|0;W=c[L>>2]|0;A=16-(c[w+1352>>2]<<1)|0;if((A|0)>0){Ja=W<<A}else{Ja=W>>-A}A=(Ja*273|0)>>16;if((A|0)>18431){Ka=4;La=3}else{Ka=3;La=(A|0)>2047|0}W=1<<Ka;X=La<<5;z=(W<<La)+X|0;P=W;J=0;K=W;W=ca(z,z)|0;do{K=K>>1;P=((A|0)<(W|0)?-K|0:K)+P|0;J=J+1|0;z=(P<<La)+X|0;W=ca(z,z)|0}while((J|0)<(Ka|0));J=W-A|0;do{if((J|0)<1){K=(P+1<<La)+X|0;z=(La<<4)-16+P|0;if(((ca(K,K)|0)-A|0)<(J|0)){Ma=z;break}Ma=z+1|0}else{z=(P-1<<La)+X|0;K=(La<<4)-16+P|0;if(((ca(z,z)|0)-A|0)<(J|0)){Ma=K;break}Ma=K-1|0}}while(0);c[L>>2]=Ma;Ia=137}}while(0);if((Ia|0)==137){c[w+1352>>2]=c[w+1348>>2];Ia=139}else if((Ia|0)==138){Ma=w+1352|0;c[Ma>>2]=((c[Ma>>2]|0)*7|0)+(c[w+1348>>2]|0)>>3;Ia=139}if((Ia|0)==139){Ma=w+1336|0;La=((c[Ma>>2]|0)*521|0)+259|0;c[w+132>>2]=(((La&32767)*21|0)>>>15)+123;Ka=((La&65535)*521|0)+259|0;c[w+136>>2]=(((Ka&32767)*19|0)>>>15)+123;La=((Ka&65535)*521|0)+259|0;c[w+8>>2]=(((La&32767)*50|0)>>>15)+1;c[w+4>>2]=1;Ka=((La&65535)*521|0)+259|0;c[w+36>>2]=(((Ka&32767)*50|0)>>>15)+1;c[w+32>>2]=0;La=((Ka&65535)*521|0)+259|0;c[w+64>>2]=(((La&32767)*50|0)>>>15)+1;c[w+60>>2]=1;Ka=((La&65535)*521|0)+259|0;La=Ka&65535;c[Ma>>2]=La;c[w+92>>2]=(((Ka&32767)*50|0)>>>15)+1;c[w+88>>2]=3;Ka=0;Ja=La;do{La=(Ja*521|0)+259|0;Ha=Ka<<1;c[l+(Ha<<2)>>2]=La>>>2&1;c[l+((Ha|1)<<2)>>2]=La>>>3&1|60;Ha=La>>>4&2047;f=Ka*11|0;c[m+(f<<2)>>2]=(Ha<<15&32768)-16384;c[m+(f+1<<2)>>2]=(Ha>>>1<<15&32768)-16384;c[m+(f+2<<2)>>2]=(Ha>>>2<<15&32768)-16384;c[m+(f+3<<2)>>2]=(Ha>>>3<<15&32768)-16384;c[m+(f+4<<2)>>2]=(Ha>>>4<<15&32768)-16384;c[m+(f+5<<2)>>2]=(Ha>>>5<<15&32768)-16384;c[m+(f+6<<2)>>2]=(Ha>>>6<<15&32768)-16384;c[m+(f+7<<2)>>2]=(Ha>>>7<<15&32768)-16384;c[m+(f+8<<2)>>2]=(Ha>>>8<<15&32768)-16384;c[m+(f+9<<2)>>2]=(Ha>>>9<<15&32768)-16384;c[m+(f+10<<2)>>2]=(Ha>>>10<<15)-16384;Ja=La&65535;Ka=Ka+1|0;}while((Ka|0)<2);c[Ma>>2]=Ja;Ka=o|0;La=o+4|0;Ha=o+8|0;f=o+12|0;Fa=o+16|0;H=o+20|0;ua=o+24|0;s=o+28|0;va=o+32|0;Ca=o+36|0;Ba=o+40|0;wa=o+44|0;Aa=o+48|0;Ea=o+52|0;Da=o+56|0;za=o+60|0;ya=o+64|0;ra=o+68|0;ta=o+72|0;sa=o+76|0;qa=o+80|0;pa=o+84|0;oa=o+88|0;na=o+92|0;ma=o+96|0;la=o+100|0;v=o+104|0;ka=o+108|0;ja=o+112|0;p=o+116|0;ga=0;ha=0;t=Ja;while(1){c[Ka>>2]=0;c[La>>2]=1;c[Ha>>2]=2;c[f>>2]=3;c[Fa>>2]=4;c[H>>2]=5;c[ua>>2]=6;c[s>>2]=7;c[va>>2]=8;c[Ca>>2]=9;c[Ba>>2]=10;c[wa>>2]=11;c[Aa>>2]=12;c[Ea>>2]=13;c[Da>>2]=14;c[za>>2]=15;c[ya>>2]=16;c[ra>>2]=17;c[ta>>2]=18;c[sa>>2]=19;c[qa>>2]=20;c[pa>>2]=21;c[oa>>2]=22;c[na>>2]=23;c[ma>>2]=24;c[la>>2]=25;c[v>>2]=26;c[ka>>2]=27;c[ja>>2]=28;c[p>>2]=29;Ja=c[l+(ha<<2)>>2]|0;I=a[696544+ha|0]|0;J=(I|0)>1;A=1;P=ga;X=30;W=t;while(1){K=(W*521|0)+259|0;Na=K&65535;c[Ma>>2]=Na;z=o+((ca(K&32767,X)|0)>>15<<2)|0;c[n+(P<<2)>>2]=(c[z>>2]<<1)+Ja;K=X-1|0;c[z>>2]=c[o+(K<<2)>>2];if((A|0)>=(I|0)){break}A=A+1|0;P=P+1|0;X=K;W=Na}W=ha+1|0;if((W|0)<4){ga=(J?I:1)+ga|0;ha=W;t=Na}else{break}}Na=w+1388|0;t=w+184|0;nrc(Na|0,t|0,290)|0;ha=w+124|0;ga=w+1352|0;Ma=Na;Na=0;while(1){l=x+132+(Na>>1<<2)|0;aga(Ma,Ma,c[l>>2]|0,x+4+(Na*28|0)|0,c[ha>>2]|0);p=Ma+120|0;aga(p,p,c[l>>2]|0,x+4+((Na|1)*28|0)|0,c[ha>>2]|0);l=0;p=0;do{ja=b[Ma+(l<<1)>>1]|0;ka=ja<<16>>16;p=(ja<<16>>16>-1?ka:-ka|0)|p;l=l+1|0;}while((l|0)<120);l=(p|0)>32767?32767:p;do{if((l|0)==0){Oa=0;Ia=150}else{I=l>>>0>65535>>>0;J=I?l>>>16:l;ka=I?16:0;if((J&65280|0)==0){Pa=ka;Qa=J}else{Pa=ka|8;Qa=J>>>8}J=Pa-10+(d[1359664+Qa|0]|0)|0;ka=(J|0)<-2?-2:J;if((ka|0)>=0){Oa=ka;Ia=150;break}J=-ka|0;I=0;ja=0;v=0;while(1){la=b[Ma+(I<<1)>>1]<<J;ma=wrc(ca(la,la)|0,0,v,ja)|0;na=G;c[o+(I<<2)>>2]=la;la=I+1|0;if((la|0)<120){I=la;ja=na;v=ma}else{Ra=na;Sa=ma;Ta=ka;break}}}}while(0);if((Ia|0)==150){Ia=0;l=0;p=0;ka=0;while(1){v=b[Ma+(l<<1)>>1]>>Oa;ja=wrc(ca(v,v)|0,0,ka,p)|0;I=G;c[o+(l<<2)>>2]=v;v=l+1|0;if((v|0)<120){l=v;p=I;ka=ja}else{Ra=I;Sa=ja;Ta=Oa;break}}}ka=((Na|0)/2|0)*11|0;p=ca(c[m+(ka<<2)>>2]|0,c[o+(c[n+(ka<<2)>>2]<<2)>>2]|0)|0;l=ka+1|0;ja=(ca(c[m+(l<<2)>>2]|0,c[o+(c[n+(l<<2)>>2]<<2)>>2]|0)|0)+p|0;p=ka+2|0;l=ja+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+3|0;ja=l+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+4|0;l=ja+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+5|0;ja=l+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+6|0;l=ja+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+7|0;ja=l+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+8|0;l=ja+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+9|0;ja=l+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)|0;p=ka+10|0;l=ja+(ca(c[m+(p<<2)>>2]|0,c[o+(c[n+(p<<2)>>2]<<2)>>2]|0)|0)<<1;p=Erc(l,(l|0)<0|0?-1:0,2979,0)|0;l=wrc(p,G,536870912,0)|0;p=l>>>30|G<<2;l=p;ja=c[ga>>2]|0;I=ca((ja*60|0)>>5,ja)|0;ja=Ta<<1;v=ja+3|0;if((v|0)>-1){Ua=I>>v}else{Ua=I<<-3-ja}ja=Sa<<1|0>>>31;I=Ra<<1|Sa>>>31;v=wrc(ja,I,-2147483648,0)|0;J=G;N=0;if(J>>>0>N>>>0|J>>>0==N>>>0&v>>>0>-1>>>0){((I|0)<0|0?-1:0)>>31|((I|0)<0|0?-1:0)<<1;Va=(I>>31|((I|0)<0|0?-1:0)<<1)^2147483647}else{Va=ja}ja=Va-Ua|0;I=Erc(ja,(ja|0)<0|0?-1:0,2979,0)|0;ja=(ca(p<<1|0>>>31,l)|0)-(I>>>15|G<<17)|0;if((ja|0)<1){Wa=-l|0}else{I=(cga(ja)|0)<<16>>16;ja=I-l|0;p=I+l|0;l=-p|0;Wa=(((p|0)>-1?p:l)|0)<(((ja|0)>-1?ja:-ja|0)|0)?l:ja}ja=Ta+1|0;if((ja|0)<0){Xa=Wa>>~Ta}else{Xa=Wa<<ja}if((Xa|0)<-1e4){Ya=-1e4}else{Ya=(Xa|0)>1e4?1e4:Xa}ja=0;do{l=ja+ka|0;p=Ma+(c[n+(l<<2)>>2]<<1)|0;I=((ca(c[m+(l<<2)>>2]|0,Ya)|0)>>15)+(b[p>>1]|0)|0;if((I+32768|0)>>>0>65535>>>0){Za=(I>>31^32767)&65535}else{Za=I&65535}b[p>>1]=Za;ja=ja+1|0;}while((ja|0)<11);nrc(Ma+290|0,Ma|0,240)|0;ja=Na+2|0;if((ja|0)<4){Ma=Ma+240|0;Na=ja}else{break}}nrc(t|0,w+1868|0,290)|0;t=w+164|0;Na=w+144|0;_fa(u|0,t,Na);nrc(Na|0,t|0,20)|0;Ga=C}c[w+120>>2]=c[y>>2];y=w+1252|0;nrc(j|0,y|0,20)|0;t=u|0;L3(w+1388|0,t,Ga+20|0,60,10,0,1,4096)|0;L3(w+1508|0,u+20|0,Ga+140|0,60,10,0,1,4096)|0;L3(w+1628|0,u+40|0,Ga+260|0,60,10,0,1,4096)|0;L3(w+1748|0,u+60|0,Ga+380|0,60,10,0,1,4096)|0;Ga=w+1848|0;nrc(y|0,Ga|0,20)|0;if((c[w+1364>>2]|0)==0){y=0;do{u=b[B+(y+10<<1)>>1]|0;Na=u<<1;if((Na+32768|0)>>>0>65535>>>0){_a=(u>>30^32767)&65535}else{_a=Na&65535}b[g+(y<<1)>>1]=_a;y=y+1|0;}while((y|0)<240)}else{y=w+1272|0;nrc(j|0,y|0,20)|0;j=w+1292|0;nrc(r|0,j|0,40)|0;_a=0;B=10;Na=t;while(1){t=0;while(1){u=Na+(t<<1)|0;b[q+(t<<1)>>1]=(16384-(ca(b[704e3+(t<<1)>>1]|0,b[u>>1]|0)|0)|0)>>>15;b[q+20+(t<<1)>>1]=(16384-(ca(b[704020+(t<<1)>>1]|0,b[u>>1]|0)|0)|0)>>>15;u=t+1|0;if((u|0)<10){t=u}else{$a=0;break}}do{t=1;u=0;Ma=0;do{Za=t-1|0;Ya=$a-t+B|0;m=ca(b[C+(Ya<<1)>>1]|0,b[q+(Za<<1)>>1]|0)|0;n=m-(ca(c[r+(Ya<<2)>>2]>>16,b[q+20+(Za<<1)>>1]|0)|0)|0;Ma=xrc(Ma,u,n,(n|0)<0|0?-1:0)|0;u=G;t=t+1|0;}while((t|0)<11);t=$a+B|0;n=e[C+(t<<1)>>1]<<16;Za=wrc(n,(n|0)<0|0?-1:0,Ma<<3|0>>>29,u<<3|Ma>>>29)|0;n=G;Ya=wrc(Za,n,32768,0)|0;m=G;Xa=wrc(Za,n,-2147450880,0)|0;n=G;Za=0;if(n>>>0>Za>>>0|n>>>0==Za>>>0&Xa>>>0>-1>>>0){((m|0)<0|0?-1:0)>>31|((m|0)<0|0?-1:0)<<1;ab=(m>>31|((m|0)<0|0?-1:0)<<1)^2147483647}else{ab=Ya}c[r+(t<<2)>>2]=ab;$a=$a+1|0;}while(($a|0)<60);t=_a+1|0;if((t|0)<4){_a=t;B=B+60|0;Na=Na+20|0}else{break}}nrc(y|0,Ga|0,20)|0;nrc(j|0,r+960|0,40)|0;j=w+1356|0;Ga=w+1360|0;y=0;Na=r+40|0;r=g;g=w+1388|0;while(1){w=0;B=0;do{_a=b[g+(B<<1)>>1]|0;$a=_a<<16>>16;w=(_a<<16>>16>-1?$a:-$a|0)|w;B=B+1|0;}while((B|0)<60);B=(w&65280|0)==0;$a=(B?14:6)-(d[1359664+(B?w:w>>>8)|0]|0)|0;B=($a|0)>0?$a:0;$a=0;do{b[r+($a<<1)>>1]=b[g+($a<<1)>>1]<<B>>>3;$a=$a+1|0;}while(($a|0)<60);$a=Q3(r,r+2|0,59)|0;w=$a;$a=0>>>31|w<<1;_a=wrc($a,w>>31|((w|0)<0|0?-1:0)<<1,-2147483648,0)|0;ab=G;C=0;if(ab>>>0>C>>>0|ab>>>0==C>>>0&_a>>>0>-1>>>0){((w|0)<0|0?-1:0)>>31|((w|0)<0|0?-1:0)<<1;bb=(w>>31|((w|0)<0|0?-1:0)<<1)^2147483647}else{bb=$a}$a=Q3(r,r,60)|0;w=$a;$a=0>>>31|w<<1;_a=wrc($a,w>>31|((w|0)<0|0?-1:0)<<1,-2147483648,0)|0;C=G;ab=0;if(C>>>0>ab>>>0|C>>>0==ab>>>0&_a>>>0>-1>>>0){((w|0)<0|0?-1:0)>>31|((w|0)<0|0?-1:0)<<1;cb=(w>>31|((w|0)<0|0?-1:0)<<1)^2147483647}else{cb=$a}$a=cb>>16;if(($a|0)==0){db=2}else{db=((bb>>2|0)/($a|0)|0)+2|0}$a=((c[j>>2]|0)*3|0)+db>>2;c[j>>2]=$a;w=-$a>>1&-4;$a=0;_a=c[Na-4>>2]|0;while(1){ab=c[Na+($a<<2)>>2]|0;C=ca(_a>>16,w)|0;q=C;t=(C|0)<0|0?-1:0;C=q<<1|0>>>31;Ya=wrc(C,t<<1|q>>>31,-2147483648,0)|0;q=G;m=0;if(q>>>0>m>>>0|q>>>0==m>>>0&Ya>>>0>-1>>>0){((t|0)<0|0?-1:0)>>30|((t|0)<0|0?-1:0)<<2;eb=(t>>30|((t|0)<0|0?-1:0)<<2)^2147483647}else{eb=C}C=wrc(eb,(eb|0)<0|0?-1:0,ab,(ab|0)<0|0?-1:0)|0;t=G;Ya=wrc(C,t,-2147483648,0)|0;m=G;q=0;if(m>>>0>q>>>0|m>>>0==q>>>0&Ya>>>0>-1>>>0){((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1;fb=((t>>31|((t|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{fb=C>>>16&65535}b[r+($a<<1)>>1]=fb;C=$a+1|0;if((C|0)<60){$a=C;_a=ab}else{break}}_a=B<<1;$a=_a-2|0;do{if(($a|0)<0){w=yrc(cb|0,((cb|0)<0|0?-1:0)|0,2-_a|0)|0;ab=G;C=wrc(w,ab,-2147483648,0)|0;t=G;Ya=0;if(!(t>>>0>Ya>>>0|t>>>0==Ya>>>0&C>>>0>-1>>>0)){gb=w;break}((ab|0)<0|0?-1:0)>>31|((ab|0)<0|0?-1:0)<<1;gb=(ab>>31|((ab|0)<0|0?-1:0)<<1)^2147483647}else{gb=cb>>$a}}while(0);$a=0;_a=0;while(1){B=b[r+(_a<<1)>>1]>>2;ab=ca(B,B)|0;B=wrc(ab<<1|0>>>31,0<<1|ab>>>31,-2147483648,0)|0;w=G;C=0;Ya=w>>>0>C>>>0|w>>>0==C>>>0&B>>>0>-1>>>0;B=ab<<1|0>>>31;ab=wrc(Ya?2147483647:B,Ya?0:(B|0)<0|0?-1:0,$a,($a|0)<0|0?-1:0)|0;B=G;Ya=wrc(ab,B,-2147483648,0)|0;C=G;w=0;if(C>>>0>w>>>0|C>>>0==w>>>0&Ya>>>0>-1>>>0){((B|0)<0|0?-1:0)>>31|((B|0)<0|0?-1:0)<<1;hb=(B>>31|((B|0)<0|0?-1:0)<<1)^2147483647}else{hb=ab}ab=_a+1|0;if((ab|0)<60){$a=hb;_a=ab}else{break}}if((gb|0)==0|(hb|0)==0){ib=4104}else{_a=gb>>>0>65535>>>0;$a=_a?gb>>>16:gb;ab=_a?16:0;if(($a&65280|0)==0){jb=ab;kb=$a}else{jb=ab|8;kb=$a>>>8}$a=30-jb-(d[1359664+kb|0]|0)|0;ab=hb>>>0>65535>>>0;_a=ab?hb>>>16:hb;B=ab?16:0;if((_a&65280|0)==0){lb=B;mb=_a}else{lb=B|8;mb=_a>>>8}_a=30-lb-(d[1359664+mb|0]|0)|0;B=$a+5-_a|0;ib=((cga(((gb<<$a>>2|0)/(hb<<_a>>16|0)|0)<<16>>((B|0)<0?0:B))|0)<<16>>16)+8|0}B=0;_a=c[Ga>>2]|0;do{$a=(_a*15|0)+ib|0;_a=$a>>4;ab=r+(B<<1)|0;Ya=(ca(_a+($a>>8)|0,b[ab>>1]|0)|0)+1024|0;$a=Ya>>11;if(($a+32768|0)>>>0>65535>>>0){nb=(Ya>>31^32767)&65535}else{nb=$a&65535}b[ab>>1]=nb;B=B+1|0;}while((B|0)<60);c[Ga>>2]=_a;B=y+1|0;if((B|0)<4){y=B;Na=Na+240|0;r=r+120|0;g=g+120|0}else{break}}}c[h>>2]=1;F=D;i=k;return F|0}function Wfa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+60>>2]|0;if((c[a+412>>2]|0)!=8e3){KIb(a,16,2453448,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1;i=b;return f|0}if((c[a+416>>2]|0)!=1){KIb(a,16,2364056,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}g=c[a+72>>2]|0;if((g|0)==6300){c[d+124>>2]=0;c[a+424>>2]=240;nrc(d+144|0,1615400,20)|0;f=0;i=b;return f|0}d=a;if((g|0)==5300){KIb(d,16,2298880,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1163346256;i=b;return f|0}else{KIb(d,16,2248016,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}return 0}function Xfa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0;k=i;i=i+3808|0;l=k|0;m=k+120|0;n=k+184|0;o=k+784|0;p=k+1104|0;q=k+1168|0;r=k+1672|0;s=k+1680|0;t=k+1688|0;u=k+1696|0;v=k+1744|0;w=k+1768|0;x=k+2128|0;z=k+2216|0;A=k+2296|0;B=k+2376|0;C=k+2400|0;D=k+2560|0;E=k+3336|0;F=k+3368|0;H=k+3488|0;I=k+3616|0;J=k+3736|0;K=k+3760|0;L=k+3784|0;M=c[f+60>>2]|0;N=c[h>>2]|0;h=N;O=M+2696|0;P=M+2700|0;Q=0;R=c[P>>2]|0;do{S=h+(Q<<1)|0;T=b[S>>1]|0;U=(T<<16>>16)-(b[O>>1]|0)<<15;V=Erc(R,(R|0)<0|0?-1:0,32512,0)|0;W=G;X=wrc(U,0,V>>>15|W<<17,W>>>15|0<<17)|0;R=X;b[O>>1]=T;T=R;X=(R|0)<0|0?-1:0;W=wrc(T,X,32768,0)|0;V=G;U=wrc(T,X,-2147450880,0)|0;X=G;T=0;if(X>>>0>T>>>0|X>>>0==T>>>0&U>>>0>-1>>>0){((V|0)<0|0?-1:0)>>31|((V|0)<0|0?-1:0)<<1;Y=((V>>31|((V|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{Y=W>>>16&65535}b[S>>1]=Y;Q=Q+1|0;}while((Q|0)<240);Q=M;c[P>>2]=R;R=D;P=M+2166|0;nrc(R|0,P|0,240)|0;nrc(D+240|0,N|0,480)|0;Y=w|0;O=v;S=x|0;x=z|0;W=0;V=0;while(1){U=0;T=0;do{X=b[D+(T+W<<1)>>1]|0;Z=X<<16>>16;U=(X<<16>>16>-1?Z:-Z|0)|U;T=T+1|0;}while((T|0)<180);T=(U&65280|0)==0;Z=(T?14:6)-(d[1359664+(T?U:U>>>8)|0]|0)|0;T=(Z|0)>0?Z:0;Z=0;while(1){b[w+(Z<<1)>>1]=b[D+(Z+W<<1)>>1]<<T>>>3;X=Z+1|0;if((X|0)<180){Z=X}else{_=0;break}}do{Z=w+(_<<1)|0;b[Z>>1]=((ca(b[1142560+(_<<1)>>1]|0,b[Z>>1]|0)|0)+16384|0)>>>15;_=_+1|0;}while((_|0)<180);Z=Q3(Y,Y,180)|0;T=Z;Z=(T>>10)+T|0;T=Z>>>0>65535>>>0;U=T?Z>>>16:Z;X=T?16:0;if((U&65280|0)==0){$=X;aa=U}else{$=X|8;aa=U>>>8}U=30-$-(d[1359664+aa|0]|0)|0;X=Z<<U;Z=X;T=(X|0)<0|0?-1:0;X=wrc(Z,T,32768,0)|0;ba=G;da=wrc(Z,T,-2147450880,0)|0;T=G;Z=0;if(T>>>0>Z>>>0|T>>>0==Z>>>0&da>>>0>-1>>>0){((ba|0)<0|0?-1:0)>>31|((ba|0)<0|0?-1:0)<<1;ea=((ba>>31|((ba|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{ea=X>>>16&65535}b[S>>1]=ea;if(ea<<16>>16==0){mrc(S+2|0,0,20)|0}else{X=1;do{ba=Q3(Y,w+(X<<1)|0,180-X|0)|0;da=ba<<U;ba=b[1914504+(X-1<<1)>>1]|0;Z=Erc(da,(da|0)<0|0?-1:0,ba<<16>>16,ba<<16>>16<0|0?-1:0)|0;ba=Z>>>15|G<<17;Z=ba;da=(ba|0)<0|0?-1:0;ba=wrc(Z,da,32768,0)|0;T=G;fa=wrc(Z,da,-2147450880,0)|0;da=G;Z=0;if(da>>>0>Z>>>0|da>>>0==Z>>>0&fa>>>0>-1>>>0){((T|0)<0|0?-1:0)>>31|((T|0)<0|0?-1:0)<<1;ga=((T>>31|((T|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{ga=ba>>>16&65535}b[S+(X<<1)>>1]=ga;X=X+1|0;}while((X|0)<11)}X=b[S>>1]|0;U=x;mrc(U|0,0,20)|0;ba=X;X=0;while(1){T=(X|0)>0;if(T){fa=0;Z=0;while(1){da=Z-(ca(b[S+(X-fa<<1)>>1]|0,b[x+(fa<<1)>>1]|0)|0)|0;ha=fa+1|0;if((ha|0)<(X|0)){fa=ha;Z=da}else{ia=da;break}}}else{ia=0}Z=X+1|0;fa=(b[S+(Z<<1)>>1]<<13)+ia<<3;da=ba<<16>>16;ha=da<<16;if((((fa|0)>-1?fa:-fa|0)|0)>=(ha|0)){break}ja=((fa|0)/(da<<1|0)|0)&65535;da=ja<<16>>16;ka=(da<<14)+32768|0;la=(ka|0)<0|0?-1:0;ma=wrc(ka,la,-2147483648,0)|0;na=G;oa=0;if(na>>>0>oa>>>0|na>>>0==oa>>>0&ma>>>0>-1>>>0){((la|0)<0|0?-1:0)>>31|((la|0)<0|0?-1:0)<<1;pa=((la>>31|((la|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{pa=ka>>>16&65535}b[x+(X<<1)>>1]=pa;ka=Erc(ja<<16>>16,ja<<16>>16<0|0?-1:0,fa,(fa|0)<0|0?-1:0)|0;fa=ka>>>15|G<<17;ka=xrc(ha,(ha|0)<0|0?-1:0,fa,(fa|0)<0|0?-1:0)|0;fa=G;ha=wrc(ka,fa,32768,0)|0;ja=G;la=wrc(ka,fa,-2147450880,0)|0;fa=G;ka=0;if(fa>>>0>ka>>>0|fa>>>0==ka>>>0&la>>>0>-1>>>0){((ja|0)<0|0?-1:0)>>31|((ja|0)<0|0?-1:0)<<1;qa=((ja>>31|((ja|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{qa=ha>>>16&65535}nrc(O|0,U|0,X<<1)|0;if(T){ha=X-1|0;ja=da<<1;da=0;do{la=ca(ja,b[v+(ha-da<<1)>>1]|0)|0;ka=x+(da<<1)|0;fa=e[ka>>1]<<16;ma=xrc(fa,(fa|0)<0|0?-1:0,la,(la|0)<0|0?-1:0)|0;la=G;fa=wrc(ma,la,32768,0)|0;oa=G;na=wrc(ma,la,-2147450880,0)|0;la=G;ma=0;if(la>>>0>ma>>>0|la>>>0==ma>>>0&na>>>0>-1>>>0){((oa|0)<0|0?-1:0)>>31|((oa|0)<0|0?-1:0)<<1;ra=((oa>>31|((oa|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{ra=fa>>>16&65535}b[ka>>1]=ra;da=da+1|0;}while((da|0)<(X|0))}if((Z|0)<10){ba=qa;X=Z}else{break}}X=V+1|0;if((X|0)<4){S=S+22|0;x=x+20|0;W=W+60|0;V=X}else{break}}V=D|0;W=M+144|0;x=B|0;S=(((b[z+60>>1]|0)*32571|0)+16384|0)>>>15&65535;b[x>>1]=S;qa=B+2|0;b[qa>>1]=(((b[z+62>>1]|0)*32376|0)+16384|0)>>>15;b[B+4>>1]=(((b[z+64>>1]|0)*32182|0)+16384|0)>>>15;ra=B+6|0;b[ra>>1]=(((b[z+66>>1]|0)*31989|0)+16384|0)>>>15;b[B+8>>1]=(((b[z+68>>1]|0)*31797|0)+16384|0)>>>15;b[B+10>>1]=(((b[z+70>>1]|0)*31606|0)+16384|0)>>>15;O=B+12|0;b[O>>1]=(((b[z+72>>1]|0)*31416|0)+16384|0)>>>15;b[B+14>>1]=(((b[z+74>>1]|0)*31228|0)+16384|0)>>>15;pa=B+16|0;b[pa>>1]=(((b[z+76>>1]|0)*31040|0)+16384|0)>>>15;ia=B+18|0;b[ia>>1]=(((b[z+78>>1]|0)*30854|0)+16384|0)>>>15;ga=u+4|0;c[ga>>2]=33554432;w=u|0;c[w>>2]=33554432;Y=0;ea=S;while(1){S=Y<<1;aa=ea<<16>>16;$=b[B+(9-Y<<1)>>1]|0;c[u+(S+2<<2)>>2]=-(($+aa<<12)+(c[u+(S<<2)>>2]|0)|0);c[u+(S+3<<2)>>2]=(c[u+((S|1)<<2)>>2]|0)-(aa-$<<12);$=Y+1|0;if(($|0)>=5){break}Y=$;ea=b[B+($<<1)>>1]|0}ea=W;Y=u+40|0;$=c[Y>>2]>>1;c[Y>>2]=$;aa=u+44|0;S=c[aa>>2]>>1;c[aa>>2]=S;aa=c[w>>2]|0;_=(aa|0)>-1?aa:-aa|0;X=c[ga>>2]|0;ga=(X|0)>-1?X:-X|0;X=(_|0)>(ga|0)?_:ga;ga=u+8|0;_=c[ga>>2]|0;ba=(_|0)>-1?_:-_|0;_=(X|0)>(ba|0)?X:ba;ba=c[u+12>>2]|0;X=(ba|0)>-1?ba:-ba|0;ba=(_|0)>(X|0)?_:X;X=u+16|0;_=c[X>>2]|0;U=(_|0)>-1?_:-_|0;_=(ba|0)>(U|0)?ba:U;U=c[u+20>>2]|0;ba=(U|0)>-1?U:-U|0;U=(_|0)>(ba|0)?_:ba;ba=u+24|0;_=c[ba>>2]|0;da=(_|0)>-1?_:-_|0;_=(U|0)>(da|0)?U:da;da=c[u+28>>2]|0;U=(da|0)>-1?da:-da|0;da=(_|0)>(U|0)?_:U;U=u+32|0;_=c[U>>2]|0;ha=(_|0)>-1?_:-_|0;_=(da|0)>(ha|0)?da:ha;ha=c[u+36>>2]|0;da=(ha|0)>-1?ha:-ha|0;ha=(_|0)>(da|0)?_:da;da=($|0)>-1?$:-$|0;$=(ha|0)>(da|0)?ha:da;da=(S|0)>-1?S:-S|0;S=($|0)>(da|0)?$:da;da=S>>>0>65535>>>0;$=da?S>>>16:S;S=da?16:0;if(($&65280|0)==0){sa=S;ta=$}else{sa=S|8;ta=$>>>8}$=30-sa-(d[1359664+ta|0]|0)|0;ta=0;sa=aa;while(1){aa=sa<<$;S=aa;da=(aa|0)<0|0?-1:0;aa=wrc(S,da,32768,0)|0;ha=G;_=wrc(S,da,-2147450880,0)|0;da=G;S=0;if(da>>>0>S>>>0|da>>>0==S>>>0&_>>>0>-1>>>0){((ha|0)<0|0?-1:0)>>31|((ha|0)<0|0?-1:0)<<1;ua=(ha>>31|((ha|0)<0|0?-1:0)<<1)^2147483647}else{ua=aa}c[u+(ta<<2)>>2]=ua>>16;aa=ta+1|0;if((aa|0)>=12){break}ta=aa;sa=c[u+(aa<<2)>>2]|0}sa=c[w>>2]|0;w=sa<<14;ta=c[ga>>2]<<14;ga=wrc(ta,(ta|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=c[X>>2]<<14;X=wrc(ga,G,w,(w|0)<0|0?-1:0)|0;w=c[ba>>2]<<14;ba=wrc(X,G,w,(w|0)<0|0?-1:0)|0;w=c[U>>2]<<14;U=wrc(ba,G,w,(w|0)<0|0?-1:0)|0;w=c[Y>>2]<<14;Y=wrc(U,G,w,(w|0)<0|0?-1:0)|0;w=G;U=Y<<1|0>>>31;ba=wrc(U,w<<1|Y>>>31,-2147483648,0)|0;Y=G;X=0;if(Y>>>0>X>>>0|Y>>>0==X>>>0&ba>>>0>-1>>>0){((w|0)<0|0?-1:0)>>30|((w|0)<0|0?-1:0)<<2;va=(w>>30|((w|0)<0|0?-1:0)<<2)^2147483647;wa=0;xa=0;ya=1;za=sa}else{va=U;wa=0;xa=0;ya=1;za=sa}a:while(1){sa=c[u+(xa+10<<2)>>2]<<14;U=b[1636104+(ya<<1)>>1]|0;w=ca(U,c[u+(xa+8<<2)>>2]|0)|0;ba=wrc(w,(w|0)<0|0?-1:0,sa,(sa|0)<0|0?-1:0)|0;sa=b[1636104+(ya<<1<<1)>>1]|0;w=ca(sa,c[u+(xa+6<<2)>>2]|0)|0;X=wrc(ba,G,w,(w|0)<0|0?-1:0)|0;w=b[1636104+(((ya*3|0|0)%512|0)<<1)>>1]|0;ba=ca(w,c[u+(xa+4<<2)>>2]|0)|0;Y=wrc(X,G,ba,(ba|0)<0|0?-1:0)|0;ba=b[1636104+(((ya<<2|0)%512|0)<<1)>>1]|0;X=ca(ba,c[u+(xa+2<<2)>>2]|0)|0;ga=wrc(Y,G,X,(X|0)<0|0?-1:0)|0;X=b[1636104+(((ya*5|0|0)%512|0)<<1)>>1]|0;Y=ca(X,za)|0;ta=wrc(ga,G,Y,(Y|0)<0|0?-1:0)|0;Y=G;ga=ta<<1|0>>>31;ua=wrc(ga,Y<<1|ta>>>31,-2147483648,0)|0;ta=G;$=0;if(ta>>>0>$>>>0|ta>>>0==$>>>0&ua>>>0>-1>>>0){((Y|0)<0|0?-1:0)>>30|((Y|0)<0|0?-1:0)<<2;Aa=(Y>>30|((Y|0)<0|0?-1:0)<<2)^2147483647}else{Aa=ga}do{if((Aa^va|0)<0){ga=(va|0)>-1?va:-va|0;Y=((Aa|0)>-1?Aa:-Aa|0)+ga|0;ua=Y>>>0>65535>>>0;$=ua?Y>>>16:Y;ta=ua?16:0;if(($&65280|0)==0){Ba=ta;Ca=$}else{Ba=ta|8;Ca=$>>>8}$=30-Ba-(d[1359664+Ca|0]|0)|0;ta=wa+1|0;b[B+(wa<<1)>>1]=(ya<<7)+65408+((ga<<$>>9|0)/(Y<<$>>16|0)|0);if((ta|0)==10){break a}$=xa^1;Y=c[u+($+10<<2)>>2]<<14;ga=ca(c[u+($+8<<2)>>2]|0,U)|0;ua=wrc(ga,(ga|0)<0|0?-1:0,Y,(Y|0)<0|0?-1:0)|0;Y=ca(c[u+($+6<<2)>>2]|0,sa)|0;ga=wrc(ua,G,Y,(Y|0)<0|0?-1:0)|0;Y=ca(c[u+($+4<<2)>>2]|0,w)|0;ua=wrc(ga,G,Y,(Y|0)<0|0?-1:0)|0;Y=ca(c[u+($+2<<2)>>2]|0,ba)|0;ga=wrc(ua,G,Y,(Y|0)<0|0?-1:0)|0;Y=c[u+($<<2)>>2]|0;ua=ca(Y,X)|0;aa=wrc(ga,G,ua,(ua|0)<0|0?-1:0)|0;ua=G;ga=aa<<1|0>>>31;ha=wrc(ga,ua<<1|aa>>>31,-2147483648,0)|0;aa=G;_=0;if(!(aa>>>0>_>>>0|aa>>>0==_>>>0&ha>>>0>-1>>>0)){Da=ga;Ea=$;Fa=ta;Ga=Y;break}((ua|0)<0|0?-1:0)>>30|((ua|0)<0|0?-1:0)<<2;Da=(ua>>30|((ua|0)<0|0?-1:0)<<2)^2147483647;Ea=$;Fa=ta;Ga=Y}else{Da=Aa;Ea=xa;Fa=wa;Ga=za}}while(0);X=ya+1|0;if((X|0)<256){va=Da;wa=Fa;xa=Ea;ya=X;za=Ga}else{Ha=56;break}}do{if((Ha|0)==56){if((Fa|0)==10){break}nrc(B|0,W|0,20)|0}}while(0);Fa=b[qa>>1]|0;qa=b[x>>1]|0;Ga=v|0;b[Ga>>1]=1048576/((Fa<<16>>16)-(qa<<16>>16)|0)|0;za=v+18|0;b[za>>1]=1048576/((b[ia>>1]|0)-(b[pa>>1]|0)|0)|0;pa=1;ia=Fa;Fa=qa;while(1){ya=ia<<16>>16;Ea=ya-(Fa<<16>>16)|0;xa=pa+1|0;wa=b[B+(xa<<1)>>1]|0;Da=(wa<<16>>16)-ya|0;ya=((Ea|0)>(Da|0)?Da:Ea)&65535;if(ya<<16>>16>32){b[v+(pa<<1)>>1]=1048576/(ya<<16>>16|0)|0}else{b[v+(pa<<1)>>1]=32767}if((xa|0)>=9){break}ya=b[B+(pa<<1)>>1]|0;pa=xa;ia=wa;Fa=ya}Fa=M+128|0;ia=b[Ga>>1]|0;pa=ia<<16>>16>0?ia:0;ya=v+2|0;wa=b[ya>>1]|0;xa=wa<<16>>16>pa<<16>>16?wa:pa;pa=v+4|0;Ea=b[pa>>1]|0;Da=Ea<<16>>16>xa<<16>>16?Ea:xa;xa=v+6|0;va=b[xa>>1]|0;Aa=va<<16>>16>Da<<16>>16?va:Da;Da=v+8|0;u=b[Da>>1]|0;Ca=u<<16>>16>Aa<<16>>16?u:Aa;Aa=v+10|0;Ba=b[Aa>>1]|0;X=Ba<<16>>16>Ca<<16>>16?Ba:Ca;Ca=v+12|0;ba=b[Ca>>1]|0;w=ba<<16>>16>X<<16>>16?ba:X;X=v+14|0;sa=b[X>>1]|0;U=sa<<16>>16>w<<16>>16?sa:w;w=v+16|0;v=b[w>>1]|0;Y=v<<16>>16>U<<16>>16?v:U;U=b[za>>1]|0;ta=U<<16>>16>Y<<16>>16?U:Y;Y=ta<<16>>16;$=ta<<16>>16<0;ta=$?Y>>>16:Y;Y=$?16:0;if((ta&65280|0)==0){Ia=Y;Ja=ta}else{Ia=Y|8;Ja=ta>>>8}ta=14-Ia-(d[1359664+Ja|0]|0)|0;Ja=ia<<16>>16<<ta&65535;b[Ga>>1]=Ja;Ga=wa<<16>>16<<ta&65535;b[ya>>1]=Ga;ya=Ea<<16>>16<<ta&65535;b[pa>>1]=ya;pa=va<<16>>16<<ta&65535;b[xa>>1]=pa;xa=u<<16>>16<<ta&65535;b[Da>>1]=xa;Da=Ba<<16>>16<<ta&65535;b[Aa>>1]=Da;Aa=ba<<16>>16<<ta&65535;b[Ca>>1]=Aa;Ca=sa<<16>>16<<ta&65535;b[X>>1]=Ca;X=v<<16>>16<<ta&65535;b[w>>1]=X;w=U<<16>>16<<ta&65535;b[za>>1]=w;za=0;ta=qa;while(1){qa=b[1615400+(za<<1)>>1]|0;b[B+(za<<1)>>1]=(ta&65535)-qa-(((((b[ea+(za<<1)>>1]|0)-qa|0)*12288|0)+16384|0)>>>15);qa=za+1|0;if((qa|0)>=10){break}za=qa;ta=b[B+(qa<<1)>>1]|0}ta=r|0;za=Ja<<16>>16;Ja=Ga<<16>>16;Ga=r+2|0;qa=ya<<16>>16;ya=r+4|0;r=-1;U=0;while(1){v=845544+(U*6|0)|0;b[ta>>1]=((ca(b[v>>1]|0,za)|0)+16384|0)>>>15;b[Ga>>1]=((ca(b[845546+(U*6|0)>>1]|0,Ja)|0)+16384|0)>>>15;b[ya>>1]=((ca(b[845548+(U*6|0)>>1]|0,qa)|0)+16384|0)>>>15;sa=Q3(x,ta,3)|0;ba=sa;sa=0>>>31|ba<<1;Ba=wrc(sa,ba>>31|((ba|0)<0|0?-1:0)<<1,-2147483648,0)|0;u=G;va=0;if(u>>>0>va>>>0|u>>>0==va>>>0&Ba>>>0>-1>>>0){((ba|0)<0|0?-1:0)>>31|((ba|0)<0|0?-1:0)<<1;Ka=(ba>>31|((ba|0)<0|0?-1:0)<<1)^2147483647}else{Ka=sa}sa=Q3(v,ta,3)|0;v=sa;sa=0>>>31|v<<1;ba=wrc(sa,v>>31|((v|0)<0|0?-1:0)<<1,-2147483648,0)|0;Ba=G;va=0;if(Ba>>>0>va>>>0|Ba>>>0==va>>>0&ba>>>0>-1>>>0){((v|0)<0|0?-1:0)>>31|((v|0)<0|0?-1:0)<<1;La=(v>>31|((v|0)<0|0?-1:0)<<1)^2147483647}else{La=sa}sa=(Ka<<1)-La|0;if((sa|0)>(r|0)){a[Fa]=U;Ma=sa}else{Ma=r}sa=U+1|0;if((sa|0)<256){r=Ma;U=sa}else{break}}U=s|0;Ma=M+129|0;r=pa<<16>>16;pa=xa<<16>>16;xa=s+2|0;La=Da<<16>>16;Da=s+4|0;s=-1;Ka=0;while(1){ta=844008+(Ka*6|0)|0;b[U>>1]=((ca(b[ta>>1]|0,r)|0)+16384|0)>>>15;b[xa>>1]=((ca(b[844010+(Ka*6|0)>>1]|0,pa)|0)+16384|0)>>>15;b[Da>>1]=((ca(b[844012+(Ka*6|0)>>1]|0,La)|0)+16384|0)>>>15;qa=Q3(ra,U,3)|0;ya=qa;qa=0>>>31|ya<<1;Ja=wrc(qa,ya>>31|((ya|0)<0|0?-1:0)<<1,-2147483648,0)|0;Ga=G;za=0;if(Ga>>>0>za>>>0|Ga>>>0==za>>>0&Ja>>>0>-1>>>0){((ya|0)<0|0?-1:0)>>31|((ya|0)<0|0?-1:0)<<1;Na=(ya>>31|((ya|0)<0|0?-1:0)<<1)^2147483647}else{Na=qa}qa=Q3(ta,U,3)|0;ta=qa;qa=0>>>31|ta<<1;ya=wrc(qa,ta>>31|((ta|0)<0|0?-1:0)<<1,-2147483648,0)|0;Ja=G;za=0;if(Ja>>>0>za>>>0|Ja>>>0==za>>>0&ya>>>0>-1>>>0){((ta|0)<0|0?-1:0)>>31|((ta|0)<0|0?-1:0)<<1;Oa=(ta>>31|((ta|0)<0|0?-1:0)<<1)^2147483647}else{Oa=qa}qa=(Na<<1)-Oa|0;if((qa|0)>(s|0)){a[Ma]=Ka;Pa=qa}else{Pa=s}qa=Ka+1|0;if((qa|0)<256){s=Pa;Ka=qa}else{break}}Ka=t|0;Pa=M+130|0;s=Aa<<16>>16;Aa=Ca<<16>>16;Ca=t+2|0;Oa=X<<16>>16;X=t+4|0;Na=w<<16>>16;w=t+6|0;t=-1;U=0;while(1){ra=841960+(U<<3)|0;b[Ka>>1]=((ca(b[ra>>1]|0,s)|0)+16384|0)>>>15;b[Ca>>1]=((ca(b[841962+(U<<3)>>1]|0,Aa)|0)+16384|0)>>>15;b[X>>1]=((ca(b[841964+(U<<3)>>1]|0,Oa)|0)+16384|0)>>>15;b[w>>1]=((ca(b[841966+(U<<3)>>1]|0,Na)|0)+16384|0)>>>15;La=Q3(O,Ka,4)|0;Da=La;La=0>>>31|Da<<1;pa=wrc(La,Da>>31|((Da|0)<0|0?-1:0)<<1,-2147483648,0)|0;xa=G;r=0;if(xa>>>0>r>>>0|xa>>>0==r>>>0&pa>>>0>-1>>>0){((Da|0)<0|0?-1:0)>>31|((Da|0)<0|0?-1:0)<<1;Qa=(Da>>31|((Da|0)<0|0?-1:0)<<1)^2147483647}else{Qa=La}La=Q3(ra,Ka,4)|0;ra=La;La=0>>>31|ra<<1;Da=wrc(La,ra>>31|((ra|0)<0|0?-1:0)<<1,-2147483648,0)|0;pa=G;r=0;if(pa>>>0>r>>>0|pa>>>0==r>>>0&Da>>>0>-1>>>0){((ra|0)<0|0?-1:0)>>31|((ra|0)<0|0?-1:0)<<1;Ra=(ra>>31|((ra|0)<0|0?-1:0)<<1)^2147483647}else{Ra=La}La=(Qa<<1)-Ra|0;if((La|0)>(t|0)){a[Pa]=U;Sa=La}else{Sa=t}La=U+1|0;if((La|0)<256){t=Sa;U=La}else{break}}U=D+20|0;nrc(U|0,M+2286|0,120)|0;nrc(D+140|0,N|0,360)|0;nrc(P|0,N+240|0,240)|0;nrc(N|0,U|0,480)|0;P=M+1292|0;nrc(R|0,P|0,20)|0;Sa=M+1272|0;nrc(q|0,Sa|0,20)|0;nrc(q+20|0,U|0,480)|0;t=0;Ra=0;Qa=10;while(1){Ka=t<<1;O=0;do{Na=b[z+(O+t<<1)>>1]|0;w=O+Ka|0;b[C+(w<<1)>>1]=((ca(b[732288+(O<<1)>>1]|0,Na)|0)+16384|0)>>>15;b[C+(w+10<<1)>>1]=((ca(b[732308+(O<<1)>>1]|0,Na)|0)+16384|0)>>>15;O=O+1|0;}while((O|0)<10);O=Ka+10|0;Na=0;do{w=1;Oa=0;X=0;do{Aa=w-1|0;Ca=Na-w+Qa|0;s=ca(b[q+(Ca<<1)>>1]|0,b[C+(Aa+Ka<<1)>>1]|0)|0;La=s-(ca(b[D+(Ca<<1)>>1]|0,b[C+(O+Aa<<1)>>1]|0)|0)|0;X=xrc(X,Oa,La,(La|0)<0|0?-1:0)|0;Oa=G;w=w+1|0;}while((w|0)<11);w=Na+Qa|0;Z=e[q+(w<<1)>>1]<<16;La=wrc(Z,(Z|0)<0|0?-1:0,X<<3|0>>>29,Oa<<3|X>>>29)|0;Z=G;Aa=wrc(La,Z,32768,0)|0;Ca=G;s=wrc(La,Z,-2147450880,0)|0;Z=G;La=0;if(Z>>>0>La>>>0|Z>>>0==La>>>0&s>>>0>-1>>>0){((Ca|0)<0|0?-1:0)>>31|((Ca|0)<0|0?-1:0)<<1;Ta=((Ca>>31|((Ca|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{Ta=Aa>>>16&65535}b[D+(w<<1)>>1]=Ta;Na=Na+1|0;}while((Na|0)<60);Na=Ra+1|0;if((Na|0)<4){t=t+10|0;Ra=Na;Qa=Qa+60|0}else{break}}Qa=D+480|0;nrc(P|0,Qa|0,20)|0;nrc(Sa|0,q+480|0,20)|0;nrc(N|0,U|0,480)|0;U=M+2406|0;nrc(R|0,U|0,290)|0;q=D+290|0;Sa=q;nrc(Sa|0,N|0,480)|0;P=0;Ra=0;do{t=b[D+(Ra<<1)>>1]|0;Ta=t<<16>>16;P=(t<<16>>16>-1?Ta:-Ta|0)|P;Ra=Ra+1|0;}while((Ra|0)<385);Ra=(P&65280|0)==0;Ta=(Ra?14:6)-(d[1359664+(Ra?P:P>>>8)|0]|0)|0;P=(Ta|0)>0?Ta:0;Ta=0;do{Ra=D+(Ta<<1)|0;b[Ra>>1]=b[Ra>>1]<<P>>>3;Ta=Ta+1|0;}while((Ta|0)<385);Ta=M+132|0;P=Ta;Ra=Ta;c[Ra>>2]=Yfa(V,145)|0;Ta=M+136|0;c[Ta>>2]=Yfa(V,265)|0;V=p+56|0;t=p|0;z=p+4|0;Na=p+8|0;O=p+12|0;Ka=p+16|0;w=p+20|0;Aa=p+24|0;Ca=p+28|0;s=p+32|0;La=p+36|0;Z=p+40|0;ra=p+44|0;Da=p+48|0;r=p+52|0;pa=145;xa=0;while(1){qa=D+(pa<<1)|0;ta=c[P+(xa>>1<<2)>>2]<<16>>16;ya=ta-3|0;za=ta+3|0;Ja=0;Ga=ya;while(1){sa=D+(pa-Ga<<1)|0;v=Q3(sa,sa,60)|0;ba=Ja<<1;c[p+(ba<<2)>>2]=v;v=Q3(qa,sa,60)|0;c[p+((ba|1)<<2)>>2]=v;v=Ga+1|0;if((v|0)>(za|0)){break}else{Ja=Ja+1|0;Ga=v}}Ga=Q3(qa,qa,60)|0;Ja=Ga;c[V>>2]=Ja;Ga=c[t>>2]|0;za=(Ga|0)>-1?Ga:-Ga|0;v=(za|0)<0?0:za;za=c[z>>2]|0;ba=(za|0)>-1?za:-za|0;za=(v|0)>(ba|0)?v:ba;ba=c[Na>>2]|0;v=(ba|0)>-1?ba:-ba|0;ba=(za|0)>(v|0)?za:v;v=c[O>>2]|0;za=(v|0)>-1?v:-v|0;v=(ba|0)>(za|0)?ba:za;za=c[Ka>>2]|0;ba=(za|0)>-1?za:-za|0;za=(v|0)>(ba|0)?v:ba;ba=c[w>>2]|0;v=(ba|0)>-1?ba:-ba|0;ba=(za|0)>(v|0)?za:v;v=c[Aa>>2]|0;za=(v|0)>-1?v:-v|0;v=(ba|0)>(za|0)?ba:za;za=c[Ca>>2]|0;ba=(za|0)>-1?za:-za|0;za=(v|0)>(ba|0)?v:ba;ba=c[s>>2]|0;v=(ba|0)>-1?ba:-ba|0;ba=(za|0)>(v|0)?za:v;v=c[La>>2]|0;za=(v|0)>-1?v:-v|0;v=(ba|0)>(za|0)?ba:za;za=c[Z>>2]|0;ba=(za|0)>-1?za:-za|0;za=(v|0)>(ba|0)?v:ba;ba=c[ra>>2]|0;v=(ba|0)>-1?ba:-ba|0;ba=(za|0)>(v|0)?za:v;v=c[Da>>2]|0;za=(v|0)>-1?v:-v|0;v=(ba|0)>(za|0)?ba:za;za=c[r>>2]|0;ba=(za|0)>-1?za:-za|0;za=(v|0)>(ba|0)?v:ba;ba=(Ja|0)>-1?Ja:-Ja|0;Ja=(za|0)>(ba|0)?za:ba;ba=Ja>>>0>65535>>>0;za=ba?Ja>>>16:Ja;Ja=ba?16:0;if((za&65280|0)==0){Ua=Ja;Va=za}else{Ua=Ja|8;Va=za>>>8}za=30-Ua-(d[1359664+Va|0]|0)|0;Ja=0;ba=Ga;while(1){Ga=ba<<za;v=Ga;sa=(Ga|0)<0|0?-1:0;Ga=wrc(v,sa,32768,0)|0;va=G;Ba=wrc(v,sa,-2147450880,0)|0;sa=G;v=0;if(sa>>>0>v>>>0|sa>>>0==v>>>0&Ba>>>0>-1>>>0){((va|0)<0|0?-1:0)>>31|((va|0)<0|0?-1:0)<<1;Wa=(va>>31|((va|0)<0|0?-1:0)<<1)^2147483647}else{Wa=Ga}c[p+(Ja<<2)>>2]=Wa>>16;Ga=Ja+1|0;if((Ga|0)>=15){break}Ja=Ga;ba=c[p+(Ga<<2)>>2]|0}ba=E+(xa<<3)|0;c[ba>>2]=-1;Ja=E+(xa<<3)+4|0;c[Ja>>2]=0;za=c[t>>2]|0;qa=c[z>>2]|0;do{if((qa|0)<1){Xa=32767;Ya=1;Za=-1}else{Ga=((ca(qa,qa)|0)+16384|0)>>>15;if(((Ga*32767|0)-za|0)<=0){Xa=32767;Ya=1;Za=-1;break}c[ba>>2]=0;Xa=za;Ya=Ga;Za=0}}while(0);za=c[Na>>2]|0;qa=c[O>>2]|0;do{if((qa|0)<1){_a=Xa;$a=Ya;ab=Za}else{Ga=((ca(qa,qa)|0)+16384|0)>>>15;if(((ca(Ga,Xa)|0)-(ca(za,Ya)|0)|0)<=0){_a=Xa;$a=Ya;ab=Za;break}c[ba>>2]=1;_a=za;$a=Ga;ab=1}}while(0);za=c[Ka>>2]|0;qa=c[w>>2]|0;do{if((qa|0)<1){bb=_a;cb=$a;db=ab}else{Ga=((ca(qa,qa)|0)+16384|0)>>>15;if(((ca(Ga,_a)|0)-(ca(za,$a)|0)|0)<=0){bb=_a;cb=$a;db=ab;break}c[ba>>2]=2;bb=za;cb=Ga;db=2}}while(0);za=c[Aa>>2]|0;qa=c[Ca>>2]|0;do{if((qa|0)<1){eb=bb;fb=cb;gb=db}else{Ga=((ca(qa,qa)|0)+16384|0)>>>15;if(((ca(Ga,bb)|0)-(ca(za,cb)|0)|0)<=0){eb=bb;fb=cb;gb=db;break}c[ba>>2]=3;eb=za;fb=Ga;gb=3}}while(0);za=c[s>>2]|0;qa=c[La>>2]|0;do{if((qa|0)<1){hb=eb;ib=fb;jb=gb}else{Ga=((ca(qa,qa)|0)+16384|0)>>>15;if(((ca(Ga,eb)|0)-(ca(za,fb)|0)|0)<=0){hb=eb;ib=fb;jb=gb;break}c[ba>>2]=4;hb=za;ib=Ga;jb=4}}while(0);za=c[Z>>2]|0;qa=c[ra>>2]|0;do{if((qa|0)<1){kb=hb;lb=ib;mb=jb}else{Ga=((ca(qa,qa)|0)+16384|0)>>>15;if(((ca(Ga,hb)|0)-(ca(za,ib)|0)|0)<=0){kb=hb;lb=ib;mb=jb;break}c[ba>>2]=5;kb=za;lb=Ga;mb=5}}while(0);za=c[Da>>2]|0;qa=c[r>>2]|0;do{if((qa|0)<1){Ha=143}else{if(((ca(((ca(qa,qa)|0)+16384|0)>>>15,kb)|0)-(ca(za,lb)|0)|0)<=0){Ha=143;break}c[ba>>2]=6;nb=6;ob=za;Ha=121}}while(0);if((Ha|0)==143){Ha=0;if((mb|0)==-1){pb=ta}else{nb=mb;ob=kb;Ha=121}}if((Ha|0)==121){Ha=0;za=ca(c[V>>2]|0,ob)|0;qa=c[p+((nb<<1|1)<<2)>>2]|0;do{if(((za>>2)+(za>>3)|0)<(ca(qa,qa)|0)){if((qa|0)<(ob|0)){c[Ja>>2]=(((qa<<15|0)/(ob|0)|0)*10240|0)+16384>>15;break}else{c[Ja>>2]=10240;break}}}while(0);pb=nb+ya|0}c[ba>>2]=pb;Ja=xa+1|0;if((Ja|0)<4){pa=pa+60|0;xa=Ja}else{break}}nrc(R|0,U|0,290)|0;nrc(Sa|0,N|0,480)|0;nrc(U|0,Qa|0,290)|0;Qa=0;U=0;while(1){N=Qa+145|0;xa=c[E+(U<<3)+4>>2]<<1;pa=N-(c[E+(U<<3)>>2]|0)|0;pb=0;do{nb=ca(xa,b[D+(pa+pb<<1)>>1]|0)|0;ob=e[D+(pb+N<<1)>>1]<<16;p=xrc(ob,(ob|0)<0|0?-1:0,nb,(nb|0)<0|0?-1:0)|0;nb=G;ob=wrc(p,nb,32768,0)|0;V=G;kb=wrc(p,nb,-2147450880,0)|0;nb=G;p=0;if(nb>>>0>p>>>0|nb>>>0==p>>>0&kb>>>0>-1>>>0){((V|0)<0|0?-1:0)>>31|((V|0)<0|0?-1:0)<<1;qb=((V>>31|((V|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{qb=ob>>>16&65535}b[h+(pb+Qa<<1)>>1]=qb;pb=pb+1|0;}while((pb|0)<60);pb=U+1|0;if((pb|0)<4){Qa=Qa+60|0;U=pb}else{break}}Zfa(x,ea,Fa,0);_fa(A|0,x,ea);nrc(W|0,B|0,20)|0;B=J;W=I;ea=I|0;I=J|0;J=F|0;x=K;U=M+2704|0;Qa=L;qb=M+2724|0;pb=K|0;K=L|0;L=M+2744|0;N=H|0;pa=H+2|0;xa=n|0;ba=n+120|0;ya=n+240|0;ob=n+360|0;V=n+480|0;kb=M+184|0;p=kb;nb=M+4|0;mb=M+124|0;lb=m|0;r=m+8|0;Da=m+4|0;jb=m+12|0;ib=M+304|0;hb=M+354|0;ra=U;Z=qb;gb=M+2864|0;fb=M+2914|0;eb=l;La=0;s=h;h=0;while(1){mrc(B|0,0,20)|0;mrc(R|0,0,290)|0;mrc(W|0,0,120)|0;b[ea>>1]=8192;db=A+(La<<1)|0;cb=C+(La<<1<<1)|0;$fa(db,cb,I,I,ea,q,1);bb=c[E+(h<<3)+4>>2]<<1;Ca=145-(c[E+(h<<3)>>2]|0)|0;Aa=0;do{ab=ca(bb,b[D+(Ca+Aa<<1)>>1]|0)|0;$a=e[D+(Aa+145<<1)>>1]<<16;_a=xrc($a,($a|0)<0|0?-1:0,ab,(ab|0)<0|0?-1:0)|0;ab=G;$a=wrc(_a,ab,32768,0)|0;w=G;Ka=wrc(_a,ab,-2147450880,0)|0;ab=G;_a=0;if(ab>>>0>_a>>>0|ab>>>0==_a>>>0&Ka>>>0>-1>>>0){((w|0)<0|0?-1:0)>>31|((w|0)<0|0?-1:0)<<1;rb=((w>>31|((w|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{rb=$a>>>16&65535}b[F+(Aa<<1)>>1]=rb;Aa=Aa+1|0;}while((Aa|0)<60);b[ea>>1]=0;nrc(x|0,U|0,20)|0;nrc(Qa|0,qb|0,20)|0;$fa(db,cb,pb,K,ea,q,0);nrc(R|0,L|0,290)|0;Aa=0;do{$a=ca(bb,b[D+(Ca+Aa<<1)>>1]|0)|0;w=s+(Aa<<1)|0;Ka=(e[w>>1]|0)-(e[D+(Aa+145<<1)>>1]|0)<<16;_a=wrc(Ka,(Ka|0)<0|0?-1:0,$a,($a|0)<0|0?-1:0)|0;$a=G;Ka=wrc(_a,$a,32768,0)|0;ab=G;Za=wrc(_a,$a,-2147450880,0)|0;$a=G;_a=0;if($a>>>0>_a>>>0|$a>>>0==_a>>>0&Za>>>0>-1>>>0){((ab|0)<0|0?-1:0)>>31|((ab|0)<0|0?-1:0)<<1;sb=((ab>>31|((ab|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{sb=Ka>>>16&65535}b[w>>1]=sb;Aa=Aa+1|0;}while((Aa|0)<60);Aa=h>>1;Ca=Q+132+(Aa<<2)|0;bb=c[Ca>>2]|0;w=h&1;Ka=w+3|0;ab=(w|0)!=0;do{if(ab){tb=bb}else{if((bb|0)==18){tb=19;break}tb=(bb|0)>140?140:bb}}while(0);bb=0;w=0;while(1){Za=w+tb|0;_a=Za-1|0;$a=144-Za|0;b[N>>1]=b[Q+184+($a<<1)>>1]|0;b[pa>>1]=b[Q+184+($a+1<<1)>>1]|0;Za=$a+2|0;$a=2;while(1){b[H+($a<<1)>>1]=b[Q+184+(Za+(($a-2|0)%(_a|0)|0)<<1)>>1]|0;Ya=$a+1|0;if((Ya|0)<64){$a=Ya}else{ub=0;break}}while(1){$a=0;_a=0;Za=0;do{X=ca(b[F+(ub-$a<<1)>>1]|0,b[H+($a+4<<1)>>1]|0)|0;Za=wrc(X,(X|0)<0|0?-1:0,Za,_a)|0;_a=G;$a=$a+1|0;}while(($a|0)<=(ub|0));$a=Za<<1|0>>>31;X=_a<<1|Za>>>31;Oa=wrc($a,X,32768,0)|0;Ya=G;Xa=wrc($a,X,-2147450880,0)|0;X=G;$a=0;if(X>>>0>$a>>>0|X>>>0==$a>>>0&Xa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;vb=((Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{vb=Oa>>>16&65535}b[n+480+(ub<<1)>>1]=vb;Oa=ub+1|0;if((Oa|0)<60){ub=Oa}else{wb=3;break}}while(1){Oa=b[H+(wb<<1)>>1]|0;b[n+(wb*120|0)>>1]=((Oa<<13)+16384|0)>>>15;Ya=wb+1|0;Xa=1;do{$a=(ca(b[F+(Xa<<1)>>1]|0,Oa)|0)+(b[n+(Ya*120|0)+(Xa-1<<1)>>1]<<15)|0;X=$a;O=X<<1|0>>>31;Na=(($a|0)<0|0?-1:0)<<1|X>>>31;X=wrc(O,Na,32768,0)|0;$a=G;z=wrc(O,Na,-2147450880,0)|0;Na=G;O=0;if(Na>>>0>O>>>0|Na>>>0==O>>>0&z>>>0>-1>>>0){(($a|0)<0|0?-1:0)>>31|(($a|0)<0|0?-1:0)<<1;xb=(($a>>31|(($a|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{xb=X>>>16&65535}b[n+(wb*120|0)+(Xa<<1)>>1]=xb;Xa=Xa+1|0;}while((Xa|0)<60);if((wb|0)>0){wb=wb-1|0}else{break}}Xa=Q3(s,xa,60)|0;Ya=Xa<<1|0>>>31;Oa=G<<1|Xa>>>31;Xa=wrc(Ya,Oa,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;yb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{yb=Ya}c[o+(bb<<2)>>2]=yb;Ya=Q3(s,ba,60)|0;Oa=Ya<<1|0>>>31;Xa=G<<1|Ya>>>31;Ya=wrc(Oa,Xa,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;zb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{zb=Oa}c[o+((bb|1)<<2)>>2]=zb;Oa=Q3(s,ya,60)|0;Xa=Oa<<1|0>>>31;Ya=G<<1|Oa>>>31;Oa=wrc(Xa,Ya,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Ab=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Ab=Xa}c[o+((bb|2)<<2)>>2]=Ab;Xa=Q3(s,ob,60)|0;Ya=Xa<<1|0>>>31;Oa=G<<1|Xa>>>31;Xa=wrc(Ya,Oa,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;Bb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{Bb=Ya}c[o+((bb|3)<<2)>>2]=Bb;Ya=Q3(s,V,60)|0;Oa=Ya<<1|0>>>31;Xa=G<<1|Ya>>>31;Ya=wrc(Oa,Xa,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Cb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Cb=Oa}c[o+(bb+4<<2)>>2]=Cb;Oa=Q3(xa,xa,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=wrc(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Db=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Db=Oa}c[o+(bb+5<<2)>>2]=Db;Oa=Q3(ba,ba,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=wrc(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Eb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Eb=Oa}c[o+(bb+6<<2)>>2]=Eb;Oa=Q3(ya,ya,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=wrc(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Fb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Fb=Oa}c[o+(bb+7<<2)>>2]=Fb;Oa=Q3(ob,ob,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=wrc(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Gb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Gb=Oa}c[o+(bb+8<<2)>>2]=Gb;Oa=Q3(V,V,60)|0;Xa=Oa;Oa=0>>>31|Xa<<1;Ya=wrc(Oa,Xa>>31|((Xa|0)<0|0?-1:0)<<1,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Hb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Hb=Oa}c[o+(bb+9<<2)>>2]=Hb;Oa=Q3(ba,xa,60)|0;Xa=Oa<<2|0>>>30;Ya=G<<2|Oa>>>30;Oa=wrc(Xa,Ya,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Ib=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Ib=Xa}c[o+(bb+10<<2)>>2]=Ib;Xa=Q3(ya,xa,60)|0;Ya=Xa<<2|0>>>30;Oa=G<<2|Xa>>>30;Xa=wrc(Ya,Oa,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;Jb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{Jb=Ya}c[o+(bb+11<<2)>>2]=Jb;Ya=Q3(ya,ba,60)|0;Oa=Ya<<2|0>>>30;Xa=G<<2|Ya>>>30;Ya=wrc(Oa,Xa,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Kb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Kb=Oa}c[o+(bb+12<<2)>>2]=Kb;Oa=Q3(ob,xa,60)|0;Xa=Oa<<2|0>>>30;Ya=G<<2|Oa>>>30;Oa=wrc(Xa,Ya,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Lb=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Lb=Xa}c[o+(bb+13<<2)>>2]=Lb;Xa=Q3(ob,ba,60)|0;Ya=Xa<<2|0>>>30;Oa=G<<2|Xa>>>30;Xa=wrc(Ya,Oa,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;Mb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{Mb=Ya}c[o+(bb+14<<2)>>2]=Mb;Ya=Q3(ob,ya,60)|0;Oa=Ya<<2|0>>>30;Xa=G<<2|Ya>>>30;Ya=wrc(Oa,Xa,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Nb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Nb=Oa}c[o+(bb+15<<2)>>2]=Nb;Oa=Q3(V,xa,60)|0;Xa=Oa<<2|0>>>30;Ya=G<<2|Oa>>>30;Oa=wrc(Xa,Ya,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Ob=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Ob=Xa}c[o+(bb+16<<2)>>2]=Ob;Xa=Q3(V,ba,60)|0;Ya=Xa<<2|0>>>30;Oa=G<<2|Xa>>>30;Xa=wrc(Ya,Oa,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Xa>>>0>-1>>>0){((Oa|0)<0|0?-1:0)>>31|((Oa|0)<0|0?-1:0)<<1;Pb=(Oa>>31|((Oa|0)<0|0?-1:0)<<1)^2147483647}else{Pb=Ya}c[o+(bb+17<<2)>>2]=Pb;Ya=Q3(V,ya,60)|0;Oa=Ya<<2|0>>>30;Xa=G<<2|Ya>>>30;Ya=wrc(Oa,Xa,-2147483648,0)|0;Za=G;_a=0;if(Za>>>0>_a>>>0|Za>>>0==_a>>>0&Ya>>>0>-1>>>0){((Xa|0)<0|0?-1:0)>>31|((Xa|0)<0|0?-1:0)<<1;Qb=(Xa>>31|((Xa|0)<0|0?-1:0)<<1)^2147483647}else{Qb=Oa}c[o+(bb+18<<2)>>2]=Qb;Oa=Q3(V,ob,60)|0;Xa=Oa<<2|0>>>30;Ya=G<<2|Oa>>>30;Oa=wrc(Xa,Ya,-2147483648,0)|0;_a=G;Za=0;if(_a>>>0>Za>>>0|_a>>>0==Za>>>0&Oa>>>0>-1>>>0){((Ya|0)<0|0?-1:0)>>31|((Ya|0)<0|0?-1:0)<<1;Rb=(Ya>>31|((Ya|0)<0|0?-1:0)<<1)^2147483647}else{Rb=Xa}c[o+(bb+19<<2)>>2]=Rb;Xa=w+1|0;if((Xa|0)<(Ka|0)){bb=bb+20|0;w=Xa}else{break}}w=Ka*20|0;bb=0;Xa=0;do{Ya=c[o+(bb<<2)>>2]|0;Oa=(Ya|0)>-1?Ya:-Ya|0;Xa=(Xa|0)>(Oa|0)?Xa:Oa;bb=bb+1|0;}while((bb|0)<(w|0));bb=Xa>>>0>65535>>>0;Oa=bb?Xa>>>16:Xa;Ya=bb?16:0;if((Oa&65280|0)==0){Sb=Ya;Tb=Oa}else{Sb=Ya|8;Tb=Oa>>>8}Oa=30-Sb-(d[1359664+Tb|0]|0)|0;Ya=0;do{bb=o+(Ya<<2)|0;Za=c[bb>>2]<<Oa;_a=Za;X=(Za|0)<0|0?-1:0;Za=wrc(_a,X,32768,0)|0;$a=G;z=wrc(_a,X,-2147450880,0)|0;X=G;_a=0;if(X>>>0>_a>>>0|X>>>0==_a>>>0&z>>>0>-1>>>0){(($a|0)<0|0?-1:0)>>31|(($a|0)<0|0?-1:0)<<1;Ub=($a>>31|(($a|0)<0|0?-1:0)<<1)^2147483647}else{Ub=Za}c[bb>>2]=Ub>>16;Ya=Ya+1|0;}while((Ya|0)<(w|0));w=(tb|0)>57;Ya=tb-1|0;if(ab){Oa=1;Xa=0;bb=2066672;Za=85;$a=0;z=0;while(1){if(w){Vb=2070072;Wb=170;Ha=197}else{if((Za|0)>0){Vb=bb;Wb=Za;Ha=197}else{Xb=Oa;Yb=Xa;Zb=z;_b=bb;$b=Za}}if((Ha|0)==197){Ha=0;_a=$a*20|0;X=Oa;O=Xa;Na=0;t=0;Wa=z;while(1){Va=0;Ua=0;Ja=0;do{qa=ca(b[Vb+(Va+t<<1)>>1]|0,c[o+(Va+_a<<2)>>2]|0)|0;Ja=wrc(qa,(qa|0)<0|0?-1:0,Ja,Ua)|0;Ua=G;Va=Va+1|0;}while((Va|0)<20);Va=wrc(Ja,Ua,-2147483648,0)|0;qa=G;za=0;if(qa>>>0>za>>>0|qa>>>0==za>>>0&Va>>>0>-1>>>0){((Ua|0)<0|0?-1:0)>>31|((Ua|0)<0|0?-1:0)<<1;ac=(Ua>>31|((Ua|0)<0|0?-1:0)<<1)^2147483647}else{ac=Ja}Va=(ac|0)>(Wa|0);za=Va?$a:X;qa=Va?Na:O;ta=Va?ac:Wa;Va=Na+1|0;if((Va|0)<(Wb|0)){X=za;O=qa;Na=Va;t=t+20|0;Wa=ta}else{Xb=za;Yb=qa;Zb=ta;_b=Vb;$b=Wb;break}}}Wa=$a+1|0;if((Wa|0)<(Ka|0)){Oa=Xb;Xa=Yb;bb=_b;Za=$b;$a=Wa;z=Zb}else{bc=Xb;cc=Yb;break}}}else{z=1;$a=0;Za=2066672;bb=85;Xa=0;Oa=0;while(1){if((Xa+Ya|0)>57){dc=2070072;ec=170;Ha=203}else{if((bb|0)>0){dc=Za;ec=bb;Ha=203}else{fc=z;gc=$a;hc=Oa;ic=Za;jc=bb}}if((Ha|0)==203){Ha=0;w=Xa*20|0;Wa=z;t=$a;Na=0;O=0;X=Oa;while(1){_a=0;ta=0;qa=0;do{za=ca(b[dc+(_a+O<<1)>>1]|0,c[o+(_a+w<<2)>>2]|0)|0;qa=wrc(za,(za|0)<0|0?-1:0,qa,ta)|0;ta=G;_a=_a+1|0;}while((_a|0)<20);_a=wrc(qa,ta,-2147483648,0)|0;Ja=G;Ua=0;if(Ja>>>0>Ua>>>0|Ja>>>0==Ua>>>0&_a>>>0>-1>>>0){((ta|0)<0|0?-1:0)>>31|((ta|0)<0|0?-1:0)<<1;kc=(ta>>31|((ta|0)<0|0?-1:0)<<1)^2147483647}else{kc=qa}_a=(kc|0)>(X|0);Ua=_a?Xa:Wa;Ja=_a?Na:t;za=_a?kc:X;_a=Na+1|0;if((_a|0)<(ec|0)){Wa=Ua;t=Ja;Na=_a;O=O+20|0;X=za}else{fc=Ua;gc=Ja;hc=za;ic=dc;jc=ec;break}}}X=Xa+1|0;if((X|0)<(Ka|0)){z=fc;$a=gc;Za=ic;bb=jc;Xa=X;Oa=hc}else{bc=fc;cc=gc;break}}}c[Ca>>2]=ab?tb:bc+Ya|0;c[Q+4+(h*28|0)>>2]=ab?bc:1;c[Q+4+(h*28|0)+4>>2]=cc;Oa=P+(Aa<<2)|0;Xa=nb+(h*28|0)|0;aga(N,p,c[Oa>>2]|0,Xa,c[mb>>2]|0);bb=0;do{Za=s+(bb<<1)|0;$a=b[Za>>1]<<14;z=0;Ka=($a|0)<0|0?-1:0;X=$a;do{$a=ca(b[F+(bb-z<<1)>>1]|0,b[H+(z<<1)>>1]|0)|0;X=xrc(X,Ka,$a,($a|0)<0|0?-1:0)|0;Ka=G;z=z+1|0;}while((z|0)<=(bb|0));z=X<<2|0>>>30;$a=Ka<<2|X>>>30;O=wrc(z,$a,32768,0)|0;Na=G;t=wrc(z,$a,-2147450880,0)|0;$a=G;z=0;if($a>>>0>z>>>0|$a>>>0==z>>>0&t>>>0>-1>>>0){((Na|0)<0|0?-1:0)>>31|((Na|0)<0|0?-1:0)<<1;lc=((Na>>31|((Na|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{lc=O>>>16&65535}b[Za>>1]=lc;bb=bb+1|0;}while((bb|0)<60);bb=a[696544+h|0]|0;c[lb>>2]=1073741824;bga(m,J,s,bb,60);Aa=c[Ca>>2]|0;if((Aa|0)<58){bga(m,J,s,bb,Aa)}Aa=s;mrc(Aa|0,0,120)|0;ab=0;do{b[s+(c[m+16+(ab<<2)>>2]<<1)>>1]=c[m+40+(ab<<2)>>2];ab=ab+1|0;}while((ab|0)<(bb|0));ab=Q+4+(h*28|0)+12|0;c[ab>>2]=0;Ya=Q+4+(h*28|0)+24|0;c[Ya>>2]=0;O=c[r>>2]|0;Na=6-bb|0;t=0;z=0;$a=0;while(1){Wa=b[s+((t<<1)+O<<1)>>1]|0;if(Wa<<16>>16==0){w=(c[1639352+(Na*120|0)+(t<<2)>>2]|0)+z|0;c[Ya>>2]=w;mc=Na;nc=w;oc=$a}else{w=(Wa&65535)>>>15&65535|$a<<1;c[ab>>2]=w;Wa=Na+1|0;if((Wa|0)==6){break}else{mc=Wa;nc=z;oc=w}}w=t+1|0;if((w|0)<30){Na=mc;t=w;z=nc;$a=oc}else{break}}c[Q+4+(h*28|0)+20>>2]=c[Da>>2];c[Q+4+(h*28|0)+16>>2]=O;$a=c[jb>>2]|0;c[Q+4+(h*28|0)+8>>2]=$a;do{if(($a|0)==0){pc=c[Oa>>2]|0}else{z=c[Ca>>2]|0;nrc(eb|0,Aa|0,120)|0;if((z|0)<60){qc=z}else{pc=z;break}while(1){t=60-qc|0;if((t|0)>0){Na=0;do{ab=s+(Na+qc<<1)|0;b[ab>>1]=(b[ab>>1]|0)+(b[l+(Na<<1)>>1]|0);Na=Na+1|0;}while((Na|0)<(t|0))}t=qc+z|0;if((t|0)<60){qc=t}else{pc=z;break}}}}while(0);aga(J,p,pc,Xa,0);orc(kb|0,ib|0,170)|0;Ca=0;do{Oa=s+(Ca<<1)|0;$a=(b[Oa>>1]<<1)+(b[F+(Ca<<1)>>1]|0)|0;if(($a+32768|0)>>>0>65535>>>0){rc=($a>>31^32767)&65535}else{rc=$a&65535}b[Oa>>1]=rc;Ca=Ca+1|0;}while((Ca|0)<60);nrc(hb|0,Aa|0,120)|0;$fa(db,cb,ra,Z,s,q,0);orc(L|0,gb|0,170)|0;nrc(fb|0,Sa|0,120)|0;Ca=h+1|0;if((Ca|0)<4){La=La+10|0;s=s+120|0;h=Ca}else{break}}h=d5a(f,g,24,0)|0;if((h|0)<0){sc=h;i=k;return sc|0}c[j>>2]=1;j=g+28|0;h=(c[j>>2]|0)<0?0:c[g+24>>2]|0;g=(c[mb>>2]|0)==0?30:32;f=g-8|0;s=d[Ma]|0;Ma=s<<40-g|d[Pa]<<32-g;if((f|0)>8){tc=f;uc=Ma;vc=h}else{Pa=h;y=Ma;a[Pa]=y;y=y>>8;a[Pa+1|0]=y;y=y>>8;a[Pa+2|0]=y;y=y>>8;a[Pa+3|0]=y;tc=g+24|0;uc=s>>>(f>>>0);vc=h+4|0}h=tc-8|0;f=d[Fa]|0;Fa=f<<40-tc|uc;if((h|0)>8){wc=h;xc=Fa;yc=vc}else{uc=vc;y=Fa;a[uc]=y;y=y>>8;a[uc+1|0]=y;y=y>>8;a[uc+2|0]=y;y=y>>8;a[uc+3|0]=y;wc=tc+24|0;xc=f>>>(h>>>0);yc=vc+4|0}vc=wc-8|0;h=(c[Ra>>2]|0)-18|0;Ra=h<<40-wc|xc;if((vc|0)>7){zc=vc;Ac=Ra;Bc=yc}else{xc=yc;y=Ra;a[xc]=y;y=y>>8;a[xc+1|0]=y;y=y>>8;a[xc+2|0]=y;y=y>>8;a[xc+3|0]=y;zc=wc+24|0;Ac=h>>>(vc>>>0);Bc=yc+4|0}yc=zc-7|0;vc=c[M+32>>2]|0;h=vc<<39-zc|Ac;if((yc|0)>2){Cc=yc;Dc=h;Ec=Bc}else{Ac=Bc;y=h;a[Ac]=y;y=y>>8;a[Ac+1|0]=y;y=y>>8;a[Ac+2|0]=y;y=y>>8;a[Ac+3|0]=y;Cc=zc+25|0;Dc=vc>>>(yc>>>0);Ec=Bc+4|0}Bc=Cc-2|0;yc=(c[Ta>>2]|0)-18|0;Ta=yc<<34-Cc|Dc;if((Bc|0)>7){Fc=Bc;Gc=Ta;Hc=Ec}else{Dc=Ec;y=Ta;a[Dc]=y;y=y>>8;a[Dc+1|0]=y;y=y>>8;a[Dc+2|0]=y;y=y>>8;a[Dc+3|0]=y;Fc=Cc+30|0;Gc=yc>>>(Bc>>>0);Hc=Ec+4|0}Ec=Fc-7|0;Bc=c[M+88>>2]|0;yc=Bc<<39-Fc|Gc;if((Ec|0)>2){Ic=Ec;Jc=yc;Kc=Hc}else{Gc=Hc;y=yc;a[Gc]=y;y=y>>8;a[Gc+1|0]=y;y=y>>8;a[Gc+2|0]=y;y=y>>8;a[Gc+3|0]=y;Ic=Fc+25|0;Jc=Bc>>>(Ec>>>0);Kc=Hc+4|0}Hc=Ic-2|0;Ec=((c[M+8>>2]|0)*24|0)+(c[M+24>>2]|0)|0;Bc=c[mb>>2]|0;if((Bc|0)==0){Lc=(c[M+12>>2]<<11)+Ec|0}else{Lc=Ec}Ec=Lc<<34-Ic|Jc;if((Hc|0)>12){Mc=Hc;Nc=Ec;Oc=Kc;Pc=Bc}else{Bc=Kc;y=Ec;a[Bc]=y;y=y>>8;a[Bc+1|0]=y;y=y>>8;a[Bc+2|0]=y;y=y>>8;a[Bc+3|0]=y;Mc=Ic+30|0;Nc=Lc>>>(Hc>>>0);Oc=Kc+4|0;Pc=c[mb>>2]|0}Kc=Mc-12|0;Hc=((c[M+36>>2]|0)*24|0)+(c[M+52>>2]|0)|0;if((Pc|0)==0){Qc=(c[M+40>>2]<<11)+Hc|0}else{Qc=Hc}Hc=Qc<<44-Mc|Nc;if((Kc|0)>12){Rc=Kc;Sc=Hc;Tc=Oc;Uc=Pc}else{Pc=Oc;y=Hc;a[Pc]=y;y=y>>8;a[Pc+1|0]=y;y=y>>8;a[Pc+2|0]=y;y=y>>8;a[Pc+3|0]=y;Rc=Mc+20|0;Sc=Qc>>>(Kc>>>0);Tc=Oc+4|0;Uc=c[mb>>2]|0}Oc=Rc-12|0;Kc=((c[M+64>>2]|0)*24|0)+(c[M+80>>2]|0)|0;if((Uc|0)==0){Vc=(c[M+68>>2]<<11)+Kc|0}else{Vc=Kc}Kc=Vc<<44-Rc|Sc;if((Oc|0)>12){Wc=Oc;Xc=Kc;Yc=Tc;Zc=Uc}else{Uc=Tc;y=Kc;a[Uc]=y;y=y>>8;a[Uc+1|0]=y;y=y>>8;a[Uc+2|0]=y;y=y>>8;a[Uc+3|0]=y;Wc=Rc+20|0;Xc=Vc>>>(Oc>>>0);Yc=Tc+4|0;Zc=c[mb>>2]|0}Tc=Wc-12|0;Oc=((c[M+92>>2]|0)*24|0)+(c[M+108>>2]|0)|0;if((Zc|0)==0){_c=(c[M+96>>2]<<11)+Oc|0}else{_c=Oc}Oc=_c<<44-Wc|Xc;if((Tc|0)>12){$c=Tc;ad=Oc;bd=Yc}else{Xc=Yc;y=Oc;a[Xc]=y;y=y>>8;a[Xc+1|0]=y;y=y>>8;a[Xc+2|0]=y;y=y>>8;a[Xc+3|0]=y;$c=Wc+20|0;ad=_c>>>(Tc>>>0);bd=Yc+4|0}Yc=$c-12|0;Tc=c[M+20>>2]|0;_c=Tc<<44-$c|ad;if((Yc|0)>1){cd=Yc;dd=_c;ed=bd}else{ad=bd;y=_c;a[ad]=y;y=y>>8;a[ad+1|0]=y;y=y>>8;a[ad+2|0]=y;y=y>>8;a[ad+3|0]=y;cd=$c+20|0;dd=Tc>>>(Yc>>>0);ed=bd+4|0}bd=cd-1|0;Yc=c[M+48>>2]|0;Tc=Yc<<33-cd|dd;if((bd|0)>1){fd=bd;gd=Tc;hd=ed}else{dd=ed;y=Tc;a[dd]=y;y=y>>8;a[dd+1|0]=y;y=y>>8;a[dd+2|0]=y;y=y>>8;a[dd+3|0]=y;fd=cd+31|0;gd=Yc>>>(bd>>>0);hd=ed+4|0}ed=fd-1|0;bd=c[M+76>>2]|0;Yc=bd<<33-fd|gd;if((ed|0)>1){id=ed;jd=Yc;kd=hd}else{gd=hd;y=Yc;a[gd]=y;y=y>>8;a[gd+1|0]=y;y=y>>8;a[gd+2|0]=y;y=y>>8;a[gd+3|0]=y;id=fd+31|0;jd=bd>>>(ed>>>0);kd=hd+4|0}hd=id-1|0;ed=c[M+104>>2]|0;bd=ed<<33-id|jd;if((hd|0)>1){ld=hd;md=bd;nd=kd}else{jd=kd;y=bd;a[jd]=y;y=y>>8;a[jd+1|0]=y;y=y>>8;a[jd+2|0]=y;y=y>>8;a[jd+3|0]=y;ld=id+31|0;md=ed>>>(hd>>>0);nd=kd+4|0}kd=ld-1|0;if((c[mb>>2]|0)==0){mb=ld-2|0;ld=mb>>5<<2;hd=nd+(-ld|0)|0;ed=mb&31;mb=M+28|0;id=c[mb>>2]|0;jd=M+56|0;bd=M+84|0;fd=M+112|0;gd=((c[jd>>2]>>14)*90|0)+((id>>16)*810|0)+((c[bd>>2]>>16)*9|0)+(c[fd>>2]>>14)|0;Yc=gd<<32-ed|md;if(ed>>>0>13>>>0){od=ed;pd=Yc;qd=hd;rd=id}else{id=hd;y=Yc;a[id]=y;y=y>>8;a[id+1|0]=y;y=y>>8;a[id+2|0]=y;y=y>>8;a[id+3|0]=y;od=ed|32;pd=gd>>>(ed>>>0);qd=nd+(4-ld)|0;rd=c[mb>>2]|0}mb=od-13|0;ld=rd&65535;rd=ld<<45-od|pd;if((mb|0)>16){sd=mb;td=rd;ud=qd}else{pd=qd;y=rd;a[pd]=y;y=y>>8;a[pd+1|0]=y;y=y>>8;a[pd+2|0]=y;y=y>>8;a[pd+3|0]=y;sd=od+19|0;td=ld>>>(mb>>>0);ud=qd+4|0}qd=sd-16|0;mb=c[jd>>2]&16383;jd=mb<<48-sd|td;if((qd|0)>14){vd=qd;wd=jd;xd=ud}else{td=ud;y=jd;a[td]=y;y=y>>8;a[td+1|0]=y;y=y>>8;a[td+2|0]=y;y=y>>8;a[td+3|0]=y;vd=sd+16|0;wd=mb>>>(qd>>>0);xd=ud+4|0}ud=vd-14|0;qd=c[bd>>2]&65535;bd=qd<<46-vd|wd;if((ud|0)>16){yd=ud;zd=bd;Ad=xd}else{wd=xd;y=bd;a[wd]=y;y=y>>8;a[wd+1|0]=y;y=y>>8;a[wd+2|0]=y;y=y>>8;a[wd+3|0]=y;yd=vd+18|0;zd=qd>>>(ud>>>0);Ad=xd+4|0}xd=yd-16|0;ud=c[fd>>2]&16383;fd=ud<<48-yd|zd;if((xd|0)>14){Bd=xd;Cd=fd;Dd=Ad}else{zd=Ad;y=fd;a[zd]=y;y=y>>8;a[zd+1|0]=y;y=y>>8;a[zd+2|0]=y;y=y>>8;a[zd+3|0]=y;Bd=yd+16|0;Cd=ud>>>(xd>>>0);Dd=Ad+4|0}Ad=Bd-14|0;xd=c[M+16>>2]|0;ud=xd<<46-Bd|Cd;if((Ad|0)>6){Ed=Ad;Fd=ud;Gd=Dd}else{Cd=Dd;y=ud;a[Cd]=y;y=y>>8;a[Cd+1|0]=y;y=y>>8;a[Cd+2|0]=y;y=y>>8;a[Cd+3|0]=y;Ed=Bd+18|0;Fd=xd>>>(Ad>>>0);Gd=Dd+4|0}Dd=Ed-6|0;Ad=c[M+44>>2]|0;xd=Ad<<38-Ed|Fd;if((Dd|0)>5){Hd=Dd;Id=xd;Jd=Gd}else{Fd=Gd;y=xd;a[Fd]=y;y=y>>8;a[Fd+1|0]=y;y=y>>8;a[Fd+2|0]=y;y=y>>8;a[Fd+3|0]=y;Hd=Ed+26|0;Id=Ad>>>(Dd>>>0);Jd=Gd+4|0}Gd=Hd-5|0;Dd=c[M+72>>2]|0;Ad=Dd<<37-Hd|Id;if((Gd|0)>6){Kd=Gd;Ld=Ad;Md=Jd}else{Id=Jd;y=Ad;a[Id]=y;y=y>>8;a[Id+1|0]=y;y=y>>8;a[Id+2|0]=y;y=y>>8;a[Id+3|0]=y;Kd=Hd+27|0;Ld=Dd>>>(Gd>>>0);Md=Jd+4|0}Jd=Kd-6|0;Gd=c[M+100>>2]|0;M=Gd<<38-Kd|Ld;if((Jd|0)>5){Nd=Jd;Od=M;Pd=Md}else{Ld=Md;y=M;a[Ld]=y;y=y>>8;a[Ld+1|0]=y;y=y>>8;a[Ld+2|0]=y;y=y>>8;a[Ld+3|0]=y;Nd=Kd+26|0;Od=Gd>>>(Jd>>>0);Pd=Md+4|0}Qd=Od;Rd=Nd-5|0;Sd=Pd}else{Qd=md;Rd=kd;Sd=nd}if((Rd|0)<32){nd=Qd&255;kd=Qd;Qd=Rd;Rd=Sd;while(1){a[Rd]=nd;Sd=kd>>>8;md=Qd+8|0;if((md|0)<32){nd=Sd&255;kd=Sd;Qd=md;Rd=Rd+1|0}else{break}}}c[j>>2]=24;sc=0;i=k;return sc|0}function Yfa(a,c){a=a|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;e=c-17|0;f=a+(e<<1)|0;g=Q3(f,f,120)|0;f=a+(c<<1)|0;c=18;h=e;e=32767;i=g;g=16384;j=32;k=18;while(1){l=h-1|0;m=a+(l<<1)|0;n=b[m>>1]|0;o=ca(n,n)|0;n=b[a+(h+119<<1)>>1]|0;p=o-(ca(n,n)|0)+i|0;n=Q3(f,m,120)|0;m=n;a:do{if((m|0)<1){q=j;r=g;s=e;t=c}else{n=m>>>0>65535>>>0;o=n?m>>>16:m;u=n?16:0;if((o&65280|0)==0){v=u;w=o}else{v=u|8;w=o>>>8}o=30-v-(d[1359664+w|0]|0)|0;u=m<<o;n=u;x=(u|0)<0|0?-1:0;u=wrc(n,x,32768,0)|0;y=G;z=wrc(n,x,-2147450880,0)|0;x=G;n=0;if(x>>>0>n>>>0|x>>>0==n>>>0&z>>>0>-1>>>0){((y|0)<0|0?-1:0)>>31|((y|0)<0|0?-1:0)<<1;A=(y>>31|((y|0)<0|0?-1:0)<<1)^2147483647}else{A=u}u=A>>16;y=ca(u,u)|0;u=y>>>0>65535>>>0;z=u?y>>>16:y;n=u?16:0;if((z&65280|0)==0){B=n;C=z}else{B=n|8;C=z>>>8}z=30-B-(d[1359664+C|0]|0)|0;n=y<<z;y=n>>16;u=p>>>0>65535>>>0;x=u?p>>>16:p;D=u?16:0;if((x&65280|0)==0){E=D;F=x}else{E=D|8;F=x>>>8}x=30-E-(d[1359664+F|0]|0)|0;D=p<<x;u=D;H=(D|0)<0|0?-1:0;D=wrc(u,H,32768,0)|0;I=G;J=wrc(u,H,-2147450880,0)|0;H=G;u=0;if(H>>>0>u>>>0|H>>>0==u>>>0&J>>>0>-1>>>0){((I|0)<0|0?-1:0)>>31|((I|0)<0|0?-1:0)<<1;K=(I>>31|((I|0)<0|0?-1:0)<<1)^2147483647}else{K=D}D=K>>16;I=z+(o<<1)-x|0;if((y|0)<(D|0)){L=I;M=y}else{L=I-1|0;M=n>>17}if((L|0)>(j|0)){q=j;r=g;s=e;t=c;break}n=L+1|0;do{if((n|0)>=(j|0)){I=ca(M,e)|0;y=I-(ca(g>>((n|0)==(j|0)),D)|0)|0;if((y|0)<=0){q=j;r=g;s=e;t=c;break a}if((k-c|0)<18){break}if((y|0)<=(I>>2|0)){q=j;r=g;s=e;t=c;break a}}}while(0);q=L;r=M;s=D;t=k}}while(0);m=k+1|0;if((m|0)<143){c=t;h=l;e=s;i=p;g=r;j=q;k=m}else{break}}return t|0}function Zfa(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((g|0)==0){h=12288;i=256;j=d[f]|0;k=f+1|0;l=f+2|0}else{g=f+2|0;a[g]=0;m=f+1|0;a[m]=0;a[f]=0;h=23552;i=512;j=0;k=m;l=g}g=b[845544+(j*6|0)>>1]|0;b[c>>1]=g;b[c+2>>1]=b[845546+((d[f]|0)*6|0)>>1]|0;b[c+4>>1]=b[845548+((d[f]|0)*6|0)>>1]|0;b[c+6>>1]=b[844008+((d[k]|0)*6|0)>>1]|0;b[c+8>>1]=b[844010+((d[k]|0)*6|0)>>1]|0;b[c+10>>1]=b[844012+((d[k]|0)*6|0)>>1]|0;b[c+12>>1]=b[841960+(d[l]<<3)>>1]|0;b[c+14>>1]=b[841962+(d[l]<<3)>>1]|0;b[c+16>>1]=b[841964+(d[l]<<3)>>1]|0;k=c+18|0;b[k>>1]=b[841966+(d[l]<<3)>>1]|0;l=0;f=g;while(1){g=b[1615400+(l<<1)>>1]|0;b[c+(l<<1)>>1]=(f&65535)+g+(((ca((b[e+(l<<1)>>1]|0)-g|0,h)|0)+16384|0)>>>15);g=l+1|0;if((g|0)>=10){break}l=g;f=b[c+(g<<1)>>1]|0}f=i-4|0;l=1;a:while(1){h=b[c>>1]|0;g=h<<16>>16>384?h:384;b[c>>1]=g;h=b[k>>1]|0;b[k>>1]=h<<16>>16>32256?32256:h;h=1;j=g;while(1){g=j<<16>>16;m=c+(h<<1)|0;n=b[m>>1]|0;o=g+i-(n<<16>>16)|0;if((o|0)>0){p=o>>1;b[c+(h-1<<1)>>1]=g-p;g=(n&65535)+p&65535;b[m>>1]=g;q=g}else{q=n}n=h+1|0;if((n|0)<10){h=n;j=q}else{r=1;break}}while(1){if((r|0)>=10){s=17;break a}if((f+(b[c+(r-1<<1)>>1]|0)-(b[c+(r<<1)>>1]|0)|0)>0){break}else{r=r+1|0}}if((l|0)>=10){break}l=l+1|0}if((s|0)==17){return}nrc(c|0,e|0,20)|0;return}function _fa(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=i;i=i+48|0;g=f|0;h=f+24|0;ylb(a,d,e,4096,12288,8192,14,10);ylb(a+20|0,d,e,8192,8192,8192,14,10);ylb(a+40|0,d,e,12288,4096,8192,14,10);nrc(a+60|0,d|0,20)|0;d=g|0;e=g+4|0;j=g+8|0;k=h|0;l=h+4|0;m=h+8|0;n=0;o=a;while(1){a=0;do{p=o+(a<<1)|0;q=b[p>>1]|0;r=q>>>7&511;s=b[1636104+(r<<1)>>1]|0;t=(ca(q<<9&65024|256,(b[1636104+(r+1<<1)>>1]|0)-s|0)|0)+(s<<16)|0;s=t;r=(t|0)<0|0?-1:0;t=s<<1|0>>>31;q=wrc(t,r<<1|s>>>31,-2147483648,0)|0;s=G;u=0;if(s>>>0>u>>>0|s>>>0==u>>>0&q>>>0>-1>>>0){((r|0)<0|0?-1:0)>>30|((r|0)<0|0?-1:0)<<2;v=(r>>30|((r|0)<0|0?-1:0)<<2)^2147483647}else{v=t}t=v;r=(v|0)<0|0?-1:0;q=wrc(t,r,32768,0)|0;u=G;s=wrc(t,r,-2147450880,0)|0;r=G;t=0;if(r>>>0>t>>>0|r>>>0==t>>>0&s>>>0>-1>>>0){((u|0)<0|0?-1:0)>>31|((u|0)<0|0?-1:0)<<1;w=(u>>31|((u|0)<0|0?-1:0)<<1)^2147483647}else{w=q}b[p>>1]=-(w>>>16);a=a+1|0;}while((a|0)<10);c[d>>2]=268435456;a=b[o>>1]|0;p=b[o+4>>1]|0;q=p+a<<14;c[e>>2]=q;u=(ca(p,a)|0)+536870912|0;c[j>>2]=u;c[k>>2]=268435456;a=b[o+2>>1]|0;p=b[o+6>>1]|0;s=p+a<<14;c[l>>2]=s;t=(ca(p,a)|0)+536870912|0;c[m>>2]=t;a=2;p=q;q=u;u=s;s=t;while(1){t=a<<1;r=b[o+(t<<1)>>1]|0;x=r<<16>>16;y=r<<16>>16<0|0?-1:0;z=Erc(x,y,q,(q|0)<0|0?-1:0)|0;A=G;B=wrc(z>>>15|A<<17,A>>>15|0<<17,p,0)|0;A=a+1|0;z=g+(A<<2)|0;c[z>>2]=B;B=b[o+((t|1)<<1)>>1]|0;t=B<<16>>16;C=B<<16>>16<0|0?-1:0;D=Erc(t,C,s,(s|0)<0|0?-1:0)|0;E=G;F=wrc(D>>>15|E<<17,E>>>15|0<<17,u,0)|0;E=h+(A<<2)|0;c[E>>2]=F;F=a;D=p;H=u;I=q;J=s;while(1){K=F-1|0;L=Erc(D,(D|0)<0|0?-1:0,x,y)|0;M=G;N=wrc(L>>>15|M<<17,M>>>15|0<<17,I>>1,0)|0;M=F-2|0;L=c[g+(M<<2)>>2]|0;O=wrc(N,G,L>>1,0)|0;c[g+(F<<2)>>2]=O;O=Erc(H,(H|0)<0|0?-1:0,t,C)|0;N=G;P=wrc(O>>>15|N<<17,N>>>15|0<<17,J>>1,0)|0;N=c[h+(M<<2)>>2]|0;M=wrc(P,G,N>>1,0)|0;c[h+(F<<2)>>2]=M;if((K|0)<=1){break}F=K;D=L;H=N;I=c[g+(K<<2)>>2]|0;J=c[h+(K<<2)>>2]|0}J=c[d>>2]>>1;c[d>>2]=J;I=c[k>>2]>>1;c[k>>2]=I;c[e>>2]=(c[e>>2]|0)+((r&65535)<<16>>a)>>1;c[l>>2]=(c[l>>2]|0)+((B&65535)<<16>>a)>>1;if((A|0)>=5){Q=0;R=J;S=I;break}I=c[g+(a<<2)>>2]|0;J=c[h+(a<<2)>>2]|0;a=A;p=I;q=c[z>>2]|0;u=J;s=c[E>>2]|0}while(1){s=Q+1|0;u=c[g+(s<<2)>>2]|0;q=u+R|0;p=q;a=(q|0)<0|0?-1:0;q=c[h+(s<<2)>>2]|0;J=q-S|0;I=J;H=(J|0)<0|0?-1:0;J=wrc(I,H,p,a)|0;D=J<<3|0>>>29;F=G<<3|J>>>29;J=wrc(D,F,32768,0)|0;C=G;t=wrc(D,F,-2147450880,0)|0;F=G;D=0;if(F>>>0>D>>>0|F>>>0==D>>>0&t>>>0>-1>>>0){((C|0)<0|0?-1:0)>>31|((C|0)<0|0?-1:0)<<1;T=((C>>31|((C|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{T=J>>>16&65535}b[o+(Q<<1)>>1]=T;J=xrc(p,a,I,H)|0;H=J<<3|0>>>29;I=G<<3|J>>>29;J=wrc(H,I,32768,0)|0;a=G;p=wrc(H,I,-2147450880,0)|0;I=G;H=0;if(I>>>0>H>>>0|I>>>0==H>>>0&p>>>0>-1>>>0){((a|0)<0|0?-1:0)>>31|((a|0)<0|0?-1:0)<<1;U=((a>>31|((a|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{U=J>>>16&65535}b[o+(9-Q<<1)>>1]=U;if((s|0)<5){Q=s;R=u;S=q}else{break}}q=n+1|0;if((q|0)<4){n=q;o=o+20|0}else{break}}i=f;return}function $fa(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=i;i=i+624|0;l=k|0;m=k+144|0;n=e;nrc(l|0,n|0,20)|0;e=f;nrc(h-20|0,e|0,20)|0;f=b[a>>1]|0;o=b[a+2>>1]|0;p=b[a+4>>1]|0;q=b[a+6>>1]|0;r=b[a+8>>1]|0;s=b[a+10>>1]|0;t=b[a+12>>1]|0;u=b[a+14>>1]|0;v=b[a+16>>1]|0;w=b[a+18>>1]|0;a=0;do{x=ca(b[l+(a+9<<1)>>1]|0,f<<16>>16)|0;y=xrc(0,0,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a+8<<1)>>1]|0,o<<16>>16)|0;z=xrc(y,G,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a+7<<1)>>1]|0,p<<16>>16)|0;y=xrc(z,G,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a+6<<1)>>1]|0,q<<16>>16)|0;z=xrc(y,G,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a+5<<1)>>1]|0,r<<16>>16)|0;y=xrc(z,G,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a+4<<1)>>1]|0,s<<16>>16)|0;z=xrc(y,G,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a+3<<1)>>1]|0,t<<16>>16)|0;y=xrc(z,G,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a+2<<1)>>1]|0,u<<16>>16)|0;z=xrc(y,G,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a+1<<1)>>1]|0,v<<16>>16)|0;y=xrc(z,G,x,(x|0)<0|0?-1:0)|0;x=ca(b[l+(a<<1)>>1]|0,w<<16>>16)|0;z=xrc(y,G,x,(x|0)<0|0?-1:0)|0;x=b[g+(a<<1)>>1]<<15;y=wrc(x,(x|0)<0|0?-1:0,z<<3|0>>>29,G<<3|z>>>29)|0;z=G;x=m+(a<<3)|0;c[x>>2]=y;c[x+4>>2]=z;x=wrc(y,z,32768,0)|0;A=G;B=wrc(y,z,-2147450880,0)|0;z=G;y=0;if(z>>>0>y>>>0|z>>>0==y>>>0&B>>>0>-1>>>0){((A|0)<0|0?-1:0)>>31|((A|0)<0|0?-1:0)<<1;C=((A>>31|((A|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{C=x>>>16&65535}b[l+(a+10<<1)>>1]=C;a=a+1|0;}while((a|0)<60);a=j;j=0;do{C=1;g=0;w=0;v=0;u=0;do{t=j-C|0;s=ca(b[l+(t+10<<1)>>1]|0,b[d+(C-1<<1)>>1]|0)|0;w=xrc(w,g,s,(s|0)<0|0?-1:0)|0;g=G;s=ca(b[h+(t<<1)>>1]|0,b[d+(C+9<<1)>>1]|0)|0;u=wrc(s,(s|0)<0|0?-1:0,u,v)|0;v=G;C=C+1|0;}while((C|0)<11);C=m+(j<<3)|0;s=wrc(c[C>>2]|0,c[C+4>>2]|0,w<<3|0>>>29,g<<3|w>>>29)|0;C=yrc(s|0,G|0,a|0)|0;s=wrc(C,G,u<<3|0>>>29,v<<3|u>>>29)|0;C=G;t=wrc(s,C,32768,0)|0;r=G;q=wrc(s,C,-2147450880,0)|0;C=G;s=0;if(C>>>0>s>>>0|C>>>0==s>>>0&q>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;D=((r>>31|((r|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{D=t>>>16&65535}b[h+(j<<1)>>1]=D;j=j+1|0;}while((j|0)<60);nrc(n|0,l+120|0,20)|0;nrc(e|0,h+100|0,20)|0;i=k;return}function aga(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+128|0;j=h|0;k=(c[f>>2]|0)+e|0;l=k-1|0;m=144-k|0;b[j>>1]=b[d+(m<<1)>>1]|0;b[j+2>>1]=b[d+(m+1<<1)>>1]|0;k=m+2|0;m=2;do{b[j+(m<<1)>>1]=b[d+(k+((m-2|0)%(l|0)|0)<<1)>>1]|0;m=m+1|0;}while((m|0)<64);m=((g|0)==0&(e|0)<58?2066672:2070072)+(((c[f+4>>2]|0)*20|0)<<1)|0;f=0;do{e=Q3(j+(f<<1)|0,m,5)|0;g=e;e=0>>>31|g<<1;l=wrc(e,g>>31|((g|0)<0|0?-1:0)<<1,-2147483648,0)|0;k=G;d=0;if(k>>>0>d>>>0|k>>>0==d>>>0&l>>>0>-1>>>0){((g|0)<0|0?-1:0)>>31|((g|0)<0|0?-1:0)<<1;n=(g>>31|((g|0)<0|0?-1:0)<<1)^2147483647}else{n=e}e=n;g=(n|0)<0|0?-1:0;l=e<<1|0>>>31;d=wrc(l,g<<1|e>>>31,-2147483648,0)|0;e=G;k=0;if(e>>>0>k>>>0|e>>>0==k>>>0&d>>>0>-1>>>0){((g|0)<0|0?-1:0)>>30|((g|0)<0|0?-1:0)<<2;o=(g>>30|((g|0)<0|0?-1:0)<<2)^2147483647}else{o=l}l=o;g=(o|0)<0|0?-1:0;d=wrc(l,g,32768,0)|0;k=G;e=wrc(l,g,-2147450880,0)|0;g=G;l=0;if(g>>>0>l>>>0|g>>>0==l>>>0&e>>>0>-1>>>0){((k|0)<0|0?-1:0)>>31|((k|0)<0|0?-1:0)<<1;p=((k>>31|((k|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{p=d>>>16&65535}b[a+(f<<1)>>1]=p;f=f+1|0;}while((f|0)<60);i=h;return}function bga(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;j=i;i=i+1024|0;k=j|0;l=j+120|0;m=j+184|0;n=j+304|0;o=j+424|0;p=j+544|0;q=j+784|0;r=m;nrc(r|0,e|0,120)|0;e=l+12|0;c[e>>2]=0;if((h|0)<58){c[e>>2]=1;nrc(k|0,r|0,120)|0;r=h;while(1){s=60-r|0;if((s|0)>0){t=0;do{u=m+(t+r<<1)|0;b[u>>1]=(b[u>>1]|0)+(b[k+(t<<1)>>1]|0);t=t+1|0;}while((t|0)<(s|0))}s=r+h|0;if((s|0)<60){r=s}else{v=0;break}}}else{v=0}do{b[n+(v<<1)>>1]=(b[m+(v<<1)>>1]|0)>>>1;v=v+1|0;}while((v|0)<60);v=n|0;r=Q3(v,v,60)|0;h=r;r=0>>>31|h<<1;k=wrc(r,h>>31|((h|0)<0|0?-1:0)<<1,-2147483648,0)|0;s=G;t=0;if(s>>>0>t>>>0|s>>>0==t>>>0&k>>>0>-1>>>0){((h|0)<0|0?-1:0)>>31|((h|0)<0|0?-1:0)<<1;w=(h>>31|((h|0)<0|0?-1:0)<<1)^2147483647}else{w=r}r=w>>>0>65535>>>0;h=r?w>>>16:w;k=r?16:0;if((h&65280|0)==0){x=k;y=h}else{x=k|8;y=h>>>8}h=30-x-(d[1359664+y|0]|0)|0;y=h;x=yrc(w|0,((w|0)<0|0?-1:0)|0,y|0)|0;w=G;k=wrc(x,w,32768,0)|0;r=G;t=wrc(x,w,-2147450880,0)|0;w=G;x=0;if(w>>>0>x>>>0|w>>>0==x>>>0&t>>>0>-1>>>0){((r|0)<0|0?-1:0)>>31|((r|0)<0|0?-1:0)<<1;z=((r>>31|((r|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{z=k>>>16&65535}k=o|0;b[k>>1]=z;z=1;do{r=Q3(n+(z<<1)|0,v,60-z|0)|0;t=r;r=0>>>31|t<<1;x=wrc(r,t>>31|((t|0)<0|0?-1:0)<<1,-2147483648,0)|0;w=G;s=0;if(w>>>0>s>>>0|w>>>0==s>>>0&x>>>0>-1>>>0){((t|0)<0|0?-1:0)>>31|((t|0)<0|0?-1:0)<<1;A=(t>>31|((t|0)<0|0?-1:0)<<1)^2147483647}else{A=r}r=yrc(A|0,((A|0)<0|0?-1:0)|0,y|0)|0;t=G;x=wrc(r,t,32768,0)|0;s=G;w=wrc(r,t,-2147450880,0)|0;t=G;r=0;if(t>>>0>r>>>0|t>>>0==r>>>0&w>>>0>-1>>>0){((s|0)<0|0?-1:0)>>31|((s|0)<0|0?-1:0)<<1;B=((s>>31|((s|0)<0|0?-1:0)<<1)^2147418112)>>>16&65535}else{B=x>>>16&65535}b[o+(z<<1)>>1]=B;z=z+1|0;}while((z|0)<60);z=h-4|0;B=m|0;y=(z|0)<0;A=4-h|0;h=z;z=0;do{v=Q3(f+(z<<1)|0,B,60-z|0)|0;x=v;v=0>>>31|x<<1;s=wrc(v,x>>31|((x|0)<0|0?-1:0)<<1,-2147483648,0)|0;w=G;r=0;if(w>>>0>r>>>0|w>>>0==r>>>0&s>>>0>-1>>>0){((x|0)<0|0?-1:0)>>31|((x|0)<0|0?-1:0)<<1;C=(x>>31|((x|0)<0|0?-1:0)<<1)^2147483647}else{C=v}v=C;x=(C|0)<0|0?-1:0;if(y){s=Arc(v|0,x|0,A|0)|0;c[p+(z<<2)>>2]=s}else{s=yrc(v|0,x|0,h|0)|0;x=G;v=wrc(s,x,-2147483648,0)|0;r=G;w=0;if(r>>>0>w>>>0|r>>>0==w>>>0&v>>>0>-1>>>0){((x|0)<0|0?-1:0)>>31|((x|0)<0|0?-1:0)<<1;D=(x>>31|((x|0)<0|0?-1:0)<<1)^2147483647}else{D=s}c[p+(z<<2)>>2]=D}z=z+1|0;}while((z|0)<60);z=b[k>>1]|0;k=z<<16>>16;D=z<<16>>16<0|0?-1:0;z=l+4|0;h=l+16|0;A=l+40|0;y=(g|0)>1;C=n;B=(g|0)>0;s=a|0;x=a+8|0;v=a+4|0;w=a+12|0;r=0;do{t=0;u=r;while(1){E=c[p+(u<<2)>>2]|0;F=(E|0)>-1?E:-E|0;if((F|0)<(t|0)){H=t}else{c[h>>2]=u;H=F}F=u+2|0;if((F|0)<60){t=H;u=F}else{break}}u=H;t=(H|0)<0|0?-1:0;F=22;E=1073741824;I=22;while(1){J=b[1215464+(I<<1)>>1]|0;K=J<<16>>16;L=Erc(K<<1|0>>>31,(J<<16>>16<0|0?-1:0)<<1|K>>>31,k,D)|0;K=G;J=wrc(L,K,-2147483648,0)|0;M=G;N=0;if(M>>>0>N>>>0|M>>>0==N>>>0&J>>>0>-1>>>0){((K|0)<0|0?-1:0)>>31|((K|0)<0|0?-1:0)<<1;O=(K>>31|((K|0)<0|0?-1:0)<<1)^2147483647}else{O=L}L=xrc(O,(O|0)<0|0?-1:0,u,t)|0;K=G;J=-1;N=(K|0)>(J|0)|(K|0)==(J|0)&L>>>0>-1>>>0;J=xrc(0,0,L,K)|0;M=N?L:J;J=N?K:G;K=(E|0)<0|0?-1:0;N=(J|0)<(K|0)|(J|0)==(K|0)&M>>>0<E>>>0;P=N?I:F;K=I-1|0;if((K|0)>1){F=P;E=N?M:E;I=K}else{break}}I=P-3|0;E=1;do{F=r;do{b[n+(F<<1)>>1]=0;c[q+(F<<2)>>2]=c[p+(F<<2)>>2];F=F+2|0;}while((F|0)<60);F=I+E|0;c[z>>2]=F;t=b[1215464+(F<<1)>>1]|0;F=c[h>>2]|0;u=-t|0;K=(c[q+(F<<2)>>2]|0)<0?u:t;c[A>>2]=K;b[n+(F<<1)>>1]=1;if(y){M=1;N=F;F=K;do{K=l+16+(M<<2)|0;J=-1073741824;L=r;while(1){do{if((b[n+(L<<1)>>1]|0)==0){Q=L-N|0;R=b[o+(((Q|0)>-1?Q:-Q|0)<<1)>>1]|0;Q=R<<16>>16;S=Erc(Q<<1|0>>>31,(R<<16>>16<0|0?-1:0)<<1|Q>>>31,F,(F|0)<0|0?-1:0)|0;Q=G;R=wrc(S,Q,-2147483648,0)|0;T=G;U=0;if(T>>>0>U>>>0|T>>>0==U>>>0&R>>>0>-1>>>0){((Q|0)<0|0?-1:0)>>31|((Q|0)<0|0?-1:0)<<1;V=(Q>>31|((Q|0)<0|0?-1:0)<<1)^2147483647}else{V=S}S=q+(L<<2)|0;Q=(c[S>>2]|0)-V|0;c[S>>2]=Q;S=(Q|0)>-1?Q:-Q|0;if((S|0)<=(J|0)){W=J;break}c[K>>2]=L;W=S}else{W=J}}while(0);S=L+2|0;if((S|0)<60){J=W;L=S}else{break}}N=c[K>>2]|0;F=(c[q+(N<<2)>>2]|0)<0?u:t;c[l+40+(M<<2)>>2]=F;b[n+(N<<1)>>1]=1;M=M+1|0;}while((M|0)<(g|0))}mrc(C|0,0,120)|0;if(B){M=0;while(1){b[n+(c[l+16+(M<<2)>>2]<<1)>>1]=c[l+40+(M<<2)>>2];N=M+1|0;if((N|0)<(g|0)){M=N}else{X=59;break}}}else{X=59}while(1){M=0;N=0;F=0;do{t=b[n+(M<<1)>>1]|0;u=t<<16>>16;L=b[m+(X-M<<1)>>1]|0;J=Erc(u<<1|0>>>31,(t<<16>>16<0|0?-1:0)<<1|u>>>31,L<<16>>16,L<<16>>16<0|0?-1:0)|0;L=G;u=wrc(J,L,-2147483648,0)|0;t=G;S=0;if(t>>>0>S>>>0|t>>>0==S>>>0&u>>>0>-1>>>0){((L|0)<0|0?-1:0)>>31|((L|0)<0|0?-1:0)<<1;Y=(L>>31|((L|0)<0|0?-1:0)<<1)^2147483647}else{Y=J}J=wrc(Y,(Y|0)<0|0?-1:0,F,N)|0;L=G;u=wrc(J,L,-2147483648,0)|0;S=G;t=0;if(S>>>0>t>>>0|S>>>0==t>>>0&u>>>0>-1>>>0){((L|0)<0|0?-1:0)>>31|((L|0)<0|0?-1:0)<<1;Z=(L>>31|((L|0)<0|0?-1:0)<<1)^2147483647}else{Z=J}F=Z;N=(Z|0)<0|0?-1:0;M=M+1|0;}while((M|0)<=(X|0));b[n+(X<<1)>>1]=F>>>14|N<<18;if((X|0)>0){X=X-1|0}else{_=0;$=0;break}}while(1){M=b[f+(_<<1)>>1]|0;K=M<<16>>16;J=b[n+(_<<1)>>1]|0;L=J<<16>>16;u=J<<16>>16<0|0?-1:0;J=Erc(K<<1|0>>>31,(M<<16>>16<0|0?-1:0)<<1|K>>>31,L,u)|0;K=G;M=wrc(J,K,-2147483648,0)|0;t=G;S=0;if(t>>>0>S>>>0|t>>>0==S>>>0&M>>>0>-1>>>0){((K|0)<0|0?-1:0)>>31|((K|0)<0|0?-1:0)<<1;aa=(K>>31|((K|0)<0|0?-1:0)<<1)^2147483647}else{aa=J}J=xrc($,($|0)<0|0?-1:0,aa,(aa|0)<0|0?-1:0)|0;K=G;M=wrc(J,K,-2147483648,0)|0;S=G;t=0;if(S>>>0>t>>>0|S>>>0==t>>>0&M>>>0>-1>>>0){((K|0)<0|0?-1:0)>>31|((K|0)<0|0?-1:0)<<1;ba=(K>>31|((K|0)<0|0?-1:0)<<1)^2147483647}else{ba=J}J=Erc(L,u,L,u)|0;u=wrc(J,G,-2147483648,0)|0;L=G;K=0;M=L>>>0>K>>>0|L>>>0==K>>>0&u>>>0>-1>>>0;u=J;J=wrc(ba,(ba|0)<0|0?-1:0,M?2147483647:u,M?0:(u|0)<0|0?-1:0)|0;u=G;M=wrc(J,u,-2147483648,0)|0;K=G;L=0;if(K>>>0>L>>>0|K>>>0==L>>>0&M>>>0>-1>>>0){((u|0)<0|0?-1:0)>>31|((u|0)<0|0?-1:0)<<1;ca=(u>>31|((u|0)<0|0?-1:0)<<1)^2147483647}else{ca=J}J=_+1|0;if((J|0)<60){_=J;$=ca}else{break}}do{if((ca|0)<(c[s>>2]|0)){c[s>>2]=ca;c[x>>2]=r;c[v>>2]=c[z>>2];c[w>>2]=c[e>>2];if(B){da=0}else{break}do{c[a+40+(da<<2)>>2]=c[l+40+(da<<2)>>2];c[a+16+(da<<2)>>2]=c[l+16+(da<<2)>>2];da=da+1|0;}while((da|0)<(g|0))}}while(0);E=E+1|0;}while((E|0)<5);r=r+1|0;}while((r|0)<2);i=j;return}function cga(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a<<1;if(b>>>0<255>>>0){e=((d[1303320+(b|1)|0]|0)+2097151|0)>>>5&65535;f=e&-2;return f|0}do{if(b>>>0<4096>>>0){g=(d[1303320+(a>>>3&268435455)|0]|0)>>>2}else{if(b>>>0<16384>>>0){g=(d[1303320+(a>>>5&67108863)|0]|0)>>>1;break}if(b>>>0<65536>>>0){g=d[1303320+(a>>>7&16777215)|0]|0;break}else{h=a>>>15;i=(h&65280|0)==0;j=((d[1359664+(i?h&65535:a>>>23&255)|0]|0)+(i?0:8)|0)>>>1;i=b>>>((j+2|0)>>>0);h=d[1303320+(i>>>((j+8|0)>>>0))|0]|0;Erc(i,0,c[1367848+(h<<2)>>2]|0,0)|0;g=G+(h<<j)|0;break}}}while(0);e=(g-((ca(g,g)|0)>>>0>b>>>0)|0)>>>1&65535;f=e&-2;return f|0}function dga(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[d>>2]=a;a=g<<1;if((ca(a,g)|0)>((ca(h,f)|0)>>1|0)){if((g|0)<(h|0)){i=(ca(b[700184+(e<<1)>>1]|0,(g<<15|0)/(h|0)|0)|0)>>>15&65535;b[d+4>>1]=i;j=i}else{i=b[700184+(e<<1)>>1]|0;b[d+4>>1]=i;j=i}i=j<<16>>16;e=(ca(a,i)|0)+(f<<15)|0;a=(ca((ca(i,i)|0)>>>15,h)|0)+32768|0;h=wrc(a,(a|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=G;a=wrc(h,e,-2147483648,0)|0;i=G;g=0;if(i>>>0>g>>>0|i>>>0==g>>>0&a>>>0>-1>>>0){((e|0)<0|0?-1:0)>>31|((e|0)<0|0?-1:0)<<1;k=(e>>31|((e|0)<0|0?-1:0)<<1)^2147483647}else{k=h}h=k>>16;if((h<<1|0)>(f|0)){l=((f<<14|0)/(h|0)|0)<<16}else{l=2147418112}h=cga(l)|0;b[d+6>>1]=h;m=j;n=h<<16>>16}else{b[d+4>>1]=0;b[d+6>>1]=32767;m=0;n=32767}h=d+4|0;d=ca(n,m<<16>>16)|0;m=d>>15;if(!((m+32768|0)>>>0>65535>>>0)){o=m&65535;b[h>>1]=o;return}o=(d>>31^32767)&65535;b[h>>1]=o;return}function ega(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+16|0;e=d|0;f=c[b+60>>2]|0;g=c[b+412>>2]|0;do{if((c[b+680>>2]|0)>-1){if((g|0)==8e3){h=8e3;break}KIb(b,16,2173680,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=d;return k|0}else{if((g|0)>0){h=g;break}KIb(0,0,2146168,(j=i,i=i+24|0,c[j>>2]=2122400,c[j+8>>2]=2640128,c[j+16>>2]=319,j)|0);i=j;Hd();return 0}}while(0);if((c[b+416>>2]|0)!=1){KIb(b,16,2617336,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=d;return k|0}j=b+72|0;g=c[j>>2]|0;if((g|0)==0){l=c[f+120>>2]|0}else{m=(((h|0)/2|0)+g|0)/(h|0)|0;c[f+120>>2]=m;l=m}m=f+120|0;if((l|0)<2){n=2}else{n=(l|0)>5?5:l}c[m>>2]=n;c[j>>2]=ca(c[b+412>>2]|0,n)|0;c[b+792>>2]=c[m>>2];n=f+4|0;j=(c[m>>2]|0)-2|0;m=2659112+(j<<4)|0;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];a[f+22|0]=32;c[f+76>>2]=1;a[f+25|0]=32;c[f+80>>2]=1;a[f+28|0]=32;a[f+31|0]=32;a[f+34|0]=32;a[f+37|0]=32;a[f+40|0]=32;a[f+43|0]=32;c[f+88>>2]=544;c[f+92>>2]=34816;c[f+116>>2]=544;c[e>>2]=4096;c[e+4>>2]=2736;c[e+8>>2]=2048;c[e+12>>2]=1640;c[b+424>>2]=c[e+(j<<2)>>2];k=0;i=d;return k|0}function fga(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=i;k=c[e+60>>2]|0;l=k;m=c[g>>2]|0;n=g+76|0;g=k+120|0;o=((ca(c[g>>2]|0,c[n>>2]|0)|0)+7|0)/8|0;p=d5a(e,f,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=j;return q|0}p=f+28|0;e=0;do{if((c[n>>2]|0)>0){r=k+108|0;s=k+116|0;t=k+4|0;u=(c[p>>2]|0)<0?0:c[f+24>>2]|0;v=32;w=0;x=m;z=0;while(1){A=c[g>>2]|0;B=((b[x>>1]|0)/4|0)-(c[r>>2]|0)|0;C=(B|0)<0?-B|0:B;D=(C&65280|0)==0;E=(D?0:8)+(d[1359664+(D?C:C>>>8)|0]|0)|0;D=(C<<7>>E&127|E<<7)-(c[s>>2]>>2)|0;E=c[t>>2]|0;C=0;while(1){F=c[E+(C<<2)>>2]|0;if((F|0)!=2147483647&(F|0)<(D|0)){C=C+1|0}else{break}}D=B>>31;E=(C^D)&255;if((A|0)==2){G=E}else{G=(C|0)==(D|0)?-1:E}E=G&255&(1<<A)+255;jga(l,E)|0;if((v|0)>(A|0)){H=v;I=z<<A|E;J=u}else{D=u;y=je(E>>>((A-v|0)>>>0)|z<<v|0)|0;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;H=v+32|0;I=E;J=u+4|0}K=H-A|0;e=I;E=w+1|0;if((E|0)<(c[n>>2]|0)){u=J;v=K;w=E;x=x+2|0;z=I}else{break}}if((K|0)>=32){break}z=I<<K;e=z;x=z>>>24&255;z=K;w=J;while(1){a[w]=x;v=e;e=v<<8;u=z+8|0;if((u|0)<32){x=v>>>16&255;z=u;w=w+1|0}else{break}}}}while(0);e=0;c[p>>2]=o;c[h>>2]=1;q=0;i=j;return q|0}function gga(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=c[b+60>>2]|0;f=b+416|0;if((c[f>>2]|0)>1){QIb(b,2247984,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1163346256;i=d;return h|0}c[f>>2]=1;f=b+448|0;c[f>>2]=4;c[f+4>>2]=0;c[e+124>>2]=(irc(c[c[b+12>>2]>>2]|0,2453440)|0)==0;f=c[b+792>>2]|0;c[e+120>>2]=f;j=f-2|0;if(j>>>0>3>>>0){KIb(b,16,2205936,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-22;i=d;return h|0}else{g=e+4|0;f=2659112+(j<<4)|0;c[g>>2]=c[f>>2];c[g+4>>2]=c[f+4>>2];c[g+8>>2]=c[f+8>>2];c[g+12>>2]=c[f+12>>2];a[e+22|0]=32;c[e+76>>2]=1;a[e+25|0]=32;c[e+80>>2]=1;a[e+28|0]=32;a[e+31|0]=32;a[e+34|0]=32;a[e+37|0]=32;a[e+40|0]=32;a[e+43|0]=32;c[e+88>>2]=544;c[e+92>>2]=34816;c[e+116>>2]=544;c[b+420>>2]=1;h=0;i=d;return h|0}return 0}function hga(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[a+60>>2]|0;l=g;m=k<<3;n=g+120|0;o=(m|0)/(c[n>>2]|0)|0;c[e+76>>2]=o;p=M4a(a,e,0)|0;if((p|0)<0){q=p;i=h;return q|0}p=m>>>0>2147483639>>>0|(j|0)==0;r=p?0:j;j=p?0:m;m=j+8|0;if((o|0)==0){s=0}else{p=g+124|0;g=0;t=c[e>>2]|0;e=o;while(1){o=e-1|0;u=c[n>>2]|0;v=r+(g>>>3)|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;if((c[p>>2]|0)==0){v=(je(w|0)|0)<<(g&7)>>>((32-u|0)>>>0);x=u+g|0;y=v;z=m>>>0>x>>>0?x:m}else{x=32-u|0;v=u+g|0;y=w>>>((g&7)>>>0)<<x>>>(x>>>0);z=m>>>0>v>>>0?v:m}b[t>>1]=jga(l,y)|0;if((o|0)==0){s=z;break}else{g=z;t=t+2|0;e=o}}}if((j-s|0)>0){KIb(a,16,2298840,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a}c[f>>2]=1;q=k;i=h;return q|0}function iga(b){b=b|0;var d=0,e=0;d=c[b+60>>2]|0;b=d+4|0;e=2659112+((c[d+120>>2]|0)-2<<4)|0;c[b>>2]=c[e>>2];c[b+4>>2]=c[e+4>>2];c[b+8>>2]=c[e+8>>2];c[b+12>>2]=c[e+12>>2];a[d+22|0]=32;c[d+76>>2]=1;a[d+25|0]=32;c[d+80>>2]=1;a[d+28|0]=32;a[d+31|0]=32;a[d+34|0]=32;a[d+37|0]=32;a[d+40|0]=32;a[d+43|0]=32;c[d+88>>2]=544;c[d+92>>2]=34816;c[d+116>>2]=544;return}function jga(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;g=f>>(c[e+120>>2]|0)-1;h=e+116|0;i=c[h>>2]|0;j=(b[(c[e+8>>2]|0)+(f<<1)>>1]|0)+(i>>2)|0;if((j|0)<0){k=0}else{k=(j&127|128)<<(j>>>7&15)>>>7<<16>>16}j=e+92|0;l=c[j>>2]|0;m=l>>15;if((m|0)>9){n=23808}else{n=(((l>>>10&31|32)<<m)*3|0)>>2}m=e+104|0;o=(c[m>>2]|0)==1&(k|0)>(n|0);n=(g|0)==0?k:-k|0;p=e+108|0;q=(c[p>>2]|0)+n|0;r=e+112|0;s=(c[r>>2]|0)+n|0;if((s|0)==0){t=0}else{t=s>>31|1}if((n|0)==0){u=0}else{u=n>>31<<7|128}s=e+44|0;if(o){mrc(s|0,0,32)|0;v=c[e+76>>2]|0;w=0;x=0;y=0;z=e+80|0}else{A=c[s>>2]|0;B=c[e+76>>2]|0;C=(ca(ca(A,-t|0)|0,B)|0)>>5;if((C|0)<-256){D=-256}else{D=(C|0)>255?255:C}C=e+80|0;E=(ca(t<<7,c[C>>2]|0)|0)+D|0;D=e+48|0;F=c[D>>2]|0;G=E+F-(F>>7)|0;if((G|0)<-12288){H=-12288}else{H=(G|0)>12288?12288:G}c[D>>2]=H;D=(ca(t*192|0,B)|0)-(A>>8)+A|0;c[s>>2]=D;A=15360-H|0;G=-A|0;if((D|0)<(G|0)){I=G}else{I=(D|0)>(A|0)?A:D}c[s>>2]=I;s=ca(-(d[e+26|0]|0)>>31|1,u)|0;D=e+52|0;A=c[D>>2]|0;G=A-(A>>8)+s|0;c[D>>2]=G;D=ca(-(d[e+29|0]|0)>>31|1,u)|0;s=e+56|0;A=c[s>>2]|0;c[s>>2]=A-(A>>8)+D;D=ca(-(d[e+32|0]|0)>>31|1,u)|0;A=e+60|0;s=c[A>>2]|0;c[A>>2]=s-(s>>8)+D;D=ca(-(d[e+35|0]|0)>>31|1,u)|0;s=e+64|0;A=c[s>>2]|0;c[s>>2]=A-(A>>8)+D;D=ca(-(d[e+38|0]|0)>>31|1,u)|0;A=e+68|0;s=c[A>>2]|0;c[A>>2]=s-(s>>8)+D;D=ca(-(d[e+41|0]|0)>>31|1,u)|0;u=e+72|0;s=c[u>>2]|0;c[u>>2]=s-(s>>8)+D;v=B;w=H;x=I;y=G;z=C}c[z>>2]=v;c[e+76>>2]=(t|0)!=0?t:1;t=e+23|0;v=e+20|0;a[t]=a[v]|0;a[t+1|0]=a[v+1|0]|0;a[t+2|0]=a[v+2|0]|0;z=q>>>31&255;a[v]=z;v=z<<24>>24==0?q:-q|0;C=(v&65280|0)==0;G=(q|0)!=0;I=(d[1359664+(C?v:v>>>8)|0]|0)+((C?0:8)|G&1)|0;a[e+21|0]=I;if(G){J=v<<6>>(I&255)&255}else{J=32}a[e+22|0]=J;v=e+41|0;G=e+38|0;a[v]=a[G]|0;a[v+1|0]=a[G+1|0]|0;a[v+2|0]=a[G+2|0]|0;v=e+35|0;a[G]=a[v]|0;a[G+1|0]=a[v+1|0]|0;a[G+2|0]=a[v+2|0]|0;G=e+32|0;a[v]=a[G]|0;a[v+1|0]=a[G+1|0]|0;a[v+2|0]=a[G+2|0]|0;v=e+29|0;a[G]=a[v]|0;a[G+1|0]=a[v+1|0]|0;a[G+2|0]=a[v+2|0]|0;G=e+26|0;a[v]=a[G]|0;a[v+1|0]=a[G+1|0]|0;a[v+2|0]=a[G+2|0]|0;G=n>>>31&255;v=e+26|0;a[v]=G;C=G<<24>>24==0?n:-n|0;n=(C&65280|0)==0;G=(k|0)!=0;k=(d[1359664+(n?C:C>>>8)|0]|0)+((n?0:8)|G&1)|0;a[e+27|0]=k;if(G){K=C<<6>>(k&255)&255}else{K=32}a[e+28|0]=K;a[v]=g;g=(w|0)<-11776;c[m>>2]=g&1;m=(c[e+16>>2]|0)+f|0;v=e+96|0;K=c[v>>2]|0;k=(-K>>5)+K+(d[m]<<4)|0;c[v>>2]=k;v=e+100|0;K=c[v>>2]|0;C=(-K>>7)+K+(d[m]<<4)|0;c[v>>2]=C;v=e+84|0;do{if(o){c[v>>2]=256;L=256}else{m=c[v>>2]|0;K=(-m>>4)+m|0;c[v>>2]=K;if(!((i|0)<1536|g)){m=(k<<2)-C|0;if((((m|0)>-1?m:-m|0)|0)<(C>>3|0)){L=K;break}}m=K+32|0;c[v>>2]=m;L=m}}while(0);v=(-i>>5)+i+(b[(c[e+12>>2]|0)+(f<<1)>>1]|0)|0;if((v|0)<544){M=544}else{M=(v|0)>5120?5120:v}c[e+88>>2]=M;v=l+M+(-l>>6)|0;c[j>>2]=v;c[h>>2]=(ca(M-(v>>6)|0,(L|0)>255?64:L>>2)|0)+v>>6;c[p>>2]=0;v=0;L=0;M=y;while(1){y=M>>2;h=y>>>31&255;j=h<<24>>24==0?y:-y|0;l=(j&65280|0)==0;f=(y|0)!=0;y=((l?0:8)|f&1)+(d[1359664+(l?j:j>>>8)|0]|0)|0;if(f){f=y&255;N=j<<6>>f&255;O=f}else{N=32;O=y&255}y=(d[e+26+(v*3|0)+1|0]|0)+O|0;f=((ca(d[e+26+(v*3|0)+2|0]|0,N)|0)+48|0)>>>4;if((y|0)>19){P=f<<y-19}else{P=f>>>((19-y|0)>>>0)}Q=((h<<24>>24!=(a[e+26+(v*3|0)|0]|0)?-P|0:P)<<16>>16)+L|0;c[p>>2]=Q;h=v+1|0;if((h|0)>=6){break}v=h;L=Q;M=c[e+52+(h<<2)>>2]|0}c[r>>2]=Q>>1;r=x>>2;x=r>>>31&255;M=x<<24>>24==0?r:-r|0;L=(M&65280|0)==0;v=(r|0)!=0;r=((L?0:8)|v&1)+(d[1359664+(L?M:M>>>8)|0]|0)|0;if(v){v=r&255;R=M<<6>>v&255;S=v}else{R=32;S=r&255}r=(I&255)+S|0;S=((ca(J&255,R)|0)+48|0)>>>4;if((r|0)>19){T=S<<r-19}else{T=S>>>((19-r|0)>>>0)}r=((x<<24>>24!=z<<24>>24?-T|0:T)<<16>>16)+Q|0;c[p>>2]=r;Q=w>>2;w=Q>>>31&255;T=w<<24>>24==0?Q:-Q|0;z=(T&65280|0)==0;x=(Q|0)!=0;Q=((z?0:8)|x&1)+(d[1359664+(z?T:T>>>8)|0]|0)|0;if(x){x=Q&255;U=T<<6>>x&255;V=x}else{U=32;V=Q&255}Q=(d[e+24|0]|0)+V|0;V=((ca(d[e+25|0]|0,U)|0)+48|0)>>>4;if((Q|0)>19){W=V<<Q-19}else{W=V>>>((19-Q|0)>>>0)}c[p>>2]=((w<<24>>24!=(a[t]|0)?-W|0:W)<<16>>16)+r>>1;r=q<<2;if((r|0)<-65535){X=1;return X|0}X=(r|0)>65535?-1:r&65535;return X|0}function kga(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[a+60>>2]|0;f=c[a+416>>2]|0;if((f|0)==1){c[a+420>>2]=1;c[a+424>>2]=80;c[e+2544>>2]=16384;g=e+1720|0;c[e+1820>>2]=g;b[g>>1]=2339;b[e+1722>>1]=4679;b[e+1724>>1]=7018;b[e+1726>>1]=9358;b[e+1728>>1]=11698;b[e+1730>>1]=14037;b[e+1732>>1]=16377;b[e+1734>>1]=18717;b[e+1736>>1]=21056;b[e+1738>>1]=23396;g=e+1740|0;c[e+1824>>2]=g;b[g>>1]=2339;b[e+1742>>1]=4679;b[e+1744>>1]=7018;b[e+1746>>1]=9358;b[e+1748>>1]=11698;b[e+1750>>1]=14037;b[e+1752>>1]=16377;b[e+1754>>1]=18717;b[e+1756>>1]=21056;b[e+1758>>1]=23396;g=e+1760|0;c[e+1828>>2]=g;b[g>>1]=2339;b[e+1762>>1]=4679;b[e+1764>>1]=7018;b[e+1766>>1]=9358;b[e+1768>>1]=11698;b[e+1770>>1]=14037;b[e+1772>>1]=16377;b[e+1774>>1]=18717;b[e+1776>>1]=21056;b[e+1778>>1]=23396;g=e+1780|0;c[e+1832>>2]=g;b[g>>1]=2339;b[e+1782>>1]=4679;b[e+1784>>1]=7018;b[e+1786>>1]=9358;b[e+1788>>1]=11698;b[e+1790>>1]=14037;b[e+1792>>1]=16377;b[e+1794>>1]=18717;b[e+1796>>1]=21056;b[e+1798>>1]=23396;g=e+1800|0;c[e+1836>>2]=g;b[g>>1]=2339;b[e+1802>>1]=4679;b[e+1804>>1]=7018;b[e+1806>>1]=9358;b[e+1808>>1]=11698;b[e+1810>>1]=14037;b[e+1812>>1]=16377;b[e+1814>>1]=18717;b[e+1816>>1]=21056;b[e+1818>>1]=23396;g=e+1860|0;c[e+1900>>2]=g;c[e+1904>>2]=e+1880;nrc(g|0,841936,20)|0;c[e+1712>>2]=e+1552;c[e+1716>>2]=20;b[e+2548>>1]=21845;b[e+1908>>1]=-14336;b[e+1910>>1]=-14336;b[e+1912>>1]=-14336;b[e+1914>>1]=-14336;l8(e,a);c[e+1224>>2]=286;h=0;i=d;return h|0}else{KIb(a,16,2173624,(a=i,i=i+8|0,c[a>>2]=f,a)|0);i=a;h=-22;i=d;return h|0}return 0}function lga(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0;k=i;i=i+408|0;l=k|0;m=k+80|0;n=k+128|0;o=k+136|0;p=k+216|0;q=k+320|0;r=k+328|0;s=c[j+24>>2]|0;t=c[j+28>>2]|0;j=c[f+60>>2]|0;c[q>>2]=0;c[g+76>>2]=80;u=M4a(f,g,0)|0;if((u|0)<0){v=u;i=k;return v|0}u=c[g>>2]|0;if((t|0)==10){b[j+2538>>1]=0;b[j+2536>>1]=2;KIb(f,48,2453408,(w=i,i=i+8|0,c[w>>2]=2363976,w)|0);i=w;x=1211376;z=0}else if((t|0)==8){KIb(f,48,2453408,(w=i,i=i+8|0,c[w>>2]=2298800,w)|0);i=w;x=1211368;z=1}else{KIb(f,16,2247936,(w=i,i=i+8|0,c[w>>2]=t,w)|0);i=w;v=-1094995529;i=k;return v|0}g=0;A=0;do{A=d[s+g|0]|A;g=g+1|0;}while((g|0)<(t|0));g=(A|0)==0;A=g&1;B=t<<3;C=B>>>0>2147483639>>>0|(s|0)==0;D=C?0:s;s=C?8:B+8|0;B=D;C=(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)>>>7;B=s>>>0>1>>>0?1:s;E=B+7|0;F=s>>>0>E>>>0?E:s;E=F+5|0;G=s>>>0>E>>>0?E:s;E=G+5|0;H=s>>>0>E>>>0?E:s;E=j+1840|0;I=j+1820|0;J=I;if(g){K=c[j+2552>>2]|0;L=c[j+1836>>2]|0;M=c[J>>2]|0;N=c[j+1824>>2]|0;O=c[j+1828>>2]|0;P=c[j+1832>>2]|0;Q=0;while(1){R=(b[E+(Q<<1)>>1]<<15)-(ca(b[1722640+(K*80|0)+(Q<<1)>>1]|0,b[M+(Q<<1)>>1]|0)|0)|0;S=R-(ca(b[1722660+(K*80|0)+(Q<<1)>>1]|0,b[N+(Q<<1)>>1]|0)|0)|0;R=S-(ca(b[1722680+(K*80|0)+(Q<<1)>>1]|0,b[O+(Q<<1)>>1]|0)|0)|0;S=R-(ca(b[1722700+(K*80|0)+(Q<<1)>>1]|0,b[P+(Q<<1)>>1]|0)|0)>>15;b[L+(Q<<1)>>1]=(ca(S,b[1722560+(K*20|0)+(Q<<1)>>1]|0)|0)>>>12;S=Q+1|0;if((S|0)<10){Q=S}else{T=L;break}}}else{L=D+(G>>>3)|0;Q=D+(F>>>3)|0;K=D+(B>>>3)|0;P=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;Q=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;K=je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=je(P|0)|0;P=K<<(G&7)>>>27;G=L<<(F&7)>>>27;F=(je(Q|0)|0)<<(B&1)>>>25;B=j+1836|0;Q=c[B>>2]|0;L=(b[1722800+(G*20|0)>>1]|0)+(b[1723440+(F*20|0)>>1]|0)&65535;b[Q>>1]=L;b[Q+10>>1]=(b[1722810+(P*20|0)>>1]|0)+(b[1723450+(F*20|0)>>1]|0);K=(b[1722802+(G*20|0)>>1]|0)+(b[1723442+(F*20|0)>>1]|0)&65535;b[Q+2>>1]=K;b[Q+12>>1]=(b[1722812+(P*20|0)>>1]|0)+(b[1723452+(F*20|0)>>1]|0);b[Q+4>>1]=(b[1722804+(G*20|0)>>1]|0)+(b[1723444+(F*20|0)>>1]|0);b[Q+14>>1]=(b[1722814+(P*20|0)>>1]|0)+(b[1723454+(F*20|0)>>1]|0);b[Q+6>>1]=(b[1722806+(G*20|0)>>1]|0)+(b[1723446+(F*20|0)>>1]|0);b[Q+16>>1]=(b[1722816+(P*20|0)>>1]|0)+(b[1723456+(F*20|0)>>1]|0);b[Q+8>>1]=(b[1722808+(G*20|0)>>1]|0)+(b[1723448+(F*20|0)>>1]|0);b[Q+18>>1]=(b[1722818+(P*20|0)>>1]|0)+(b[1723458+(F*20|0)>>1]|0);F=1;P=L;L=K;while(1){K=P<<16>>16;G=10-(L<<16>>16)+K>>1;if((G|0)>0){b[Q+(F-1<<1)>>1]=K-G;K=G+(L&65535)&65535;b[Q+(F<<1)>>1]=K;U=K}else{U=L}K=F+1|0;if((K|0)>=10){break}F=K;P=U;L=b[Q+(K<<1)>>1]|0}L=1;U=b[Q>>1]|0;while(1){P=U<<16>>16;F=Q+(L<<1)|0;K=b[F>>1]|0;G=P+5-(K<<16>>16)>>1;if((G|0)>0){b[Q+(L-1<<1)>>1]=P-G;P=G+(K&65535)&65535;b[F>>1]=P;V=P}else{V=K}K=L+1|0;if((K|0)<10){L=K;U=V}else{break}}V=C&1;C=c[J>>2]|0;U=c[j+1824>>2]|0;L=c[j+1828>>2]|0;K=c[j+1832>>2]|0;P=0;do{F=ca(b[1722600+(V*20|0)+(P<<1)>>1]|0,b[Q+(P<<1)>>1]|0)|0;G=(ca(b[1722640+(V*80|0)+(P<<1)>>1]|0,b[C+(P<<1)>>1]|0)|0)+F|0;F=G+(ca(b[1722660+(V*80|0)+(P<<1)>>1]|0,b[U+(P<<1)>>1]|0)|0)|0;G=F+(ca(b[1722680+(V*80|0)+(P<<1)>>1]|0,b[L+(P<<1)>>1]|0)|0)|0;b[E+(P<<1)>>1]=(G+(ca(b[1722700+(V*80|0)+(P<<1)>>1]|0,b[K+(P<<1)>>1]|0)|0)|0)>>>15;P=P+1|0;}while((P|0)<10);vPa(E,321,40,25681,10);c[j+2552>>2]=V;T=c[B>>2]|0}orc(j+1824|0,I|0,16)|0;c[J>>2]=T;T=j+1904|0;xPa(c[T>>2]|0,E,10);E=j+1900|0;BPa(m|0,m+22|0,c[T>>2]|0,c[E>>2]|0,10);J=c[E>>2]|0;c[E>>2]=c[T>>2];c[T>>2]=J;J=d[x+6|0]|0;T=32-J|0;E=d[x+5|0]|0;I=32-E|0;B=d[x+3|0]|0;V=32-B|0;P=d[x+4|0]|0;K=32-P|0;L=j+1716|0;U=f;f=j+2548|0;C=o;Q=o|0;G=j+2520|0;F=G;O=j+2522|0;N=j+2532|0;M=j+2534|0;S=j+1908|0;R=j+1712|0;W=j+2540|0;X=g^1;Y=p;Z=j+1916|0;_=p+20|0;$=(z|0)==1;aa=j+2538|0;ba=j+2536|0;da=O;ea=j+2524|0;fa=j+2526|0;ga=j+2528|0;ha=j+2530|0;ia=r|0;ja=l|0;ka=p+80|0;la=j;ma=j+2542|0;na=n|0;oa=j+1936|0;pa=j+2320|0;qa=j+2420|0;ra=j+2544|0;sa=j+2564|0;ta=p+16|0;ua=j+2556|0;va=p+96|0;wa=j+1244|0;xa=wa;ya=x+2|0;za=H;H=0;Aa=0;while(1){Ba=d[x+H|0]|0;Ca=D+(za>>>3)|0;Da=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(za&7)>>>((32-Ba|0)>>>0);Ca=Ba+za|0;Ba=s>>>0>Ca>>>0?Ca:s;Ca=(H|0)!=0;do{if(Ca){Ea=Aa;Fa=Ba}else{if((a[ya]|0)==0){Ea=Aa;Fa=Ba;break}Ga=zrc(-1771476586|0,1771476585,Da>>>2&63|0)|0;Ea=(d[D+(Ba>>>3)|0]<<(Ba&7)>>>7^Ga)&1^1;Fa=((Ba|0)<(s|0))+Ba|0}}while(0);Ba=D+(Fa>>>3)|0;Ga=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Fa&7)>>>(T>>>0);Ba=J+Fa|0;Ha=s>>>0>Ba>>>0?Ba:s;Ba=D+(Ha>>>3)|0;Ia=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ha&7)>>>(I>>>0);Ba=Ha+E|0;Ha=s>>>0>Ba>>>0?Ba:s;Ba=Ia&255;Ia=D+(Ha>>>3)|0;Ja=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ha&7)>>>(V>>>0);Ia=Ha+B|0;Ha=s>>>0>Ia>>>0?Ia:s;Ia=D+(Ha>>>3)|0;Ka=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ha&7)>>>(K>>>0);Ia=Ha+P|0;Ha=s>>>0>Ia>>>0?Ia:s;do{if(g){La=(c[L>>2]|0)*3|0}else{if(!Ca){if((Ea|0)==0){La=plb(Da&255)|0;break}else{La=(c[L>>2]|0)*3|0;break}}Ia=(c[L>>2]|0)-5|0;if((Ia|0)<20){Ma=20}else{Ma=(Ia|0)>134?134:Ia}Ia=Da&255;if($){La=qlb(Ia,Ma)|0;break}else{La=rlb(Ia,Ma)|0;break}}}while(0);Da=La+1|0;Ca=(Da|0)/3|0;Ia=n+(H<<2)|0;c[Ia>>2]=Ca;if((Da|0)>431){KIb(U,24,2205896,(w=i,i=i+8|0,c[w>>2]=Ca,w)|0);i=w;c[Ia>>2]=143;Na=143}else{Na=Ca}if(g){Ca=((b[f>>1]|0)*31821&65535)+13849&65535;Ia=(Ca*31821&65535)+13849&65535;b[f>>1]=Ia;Oa=(1<<J)+65535&(Ca&65535);Pa=Ia&255}else{Oa=Ga;Pa=Ba}mrc(C|0,0,80)|0;if((z|0)==0){wlb(Q,1390328,1390344,Oa,Pa&255,3,3)}else if((z|0)==1){wlb(Q,1390408,1390376,Oa,Pa&255,1,4)}Ia=o+(Na<<1)|0;Ca=b[F>>1]|0;if(Ca<<16>>16<3277){Qa=3277}else{Qa=Ca<<16>>16>13017?13017:Ca}ylb(Ia,Ia,Q,16384,Qa,0,14,40-Na|0);orc(O|0,G|0,10)|0;Ia=b[N>>1]|0;b[M>>1]=Ia;if(g){b[F>>1]=((b[F>>1]|0)*29491|0)>>>15;Ra=0;Sa=((Ia<<16>>16)*2007|0)>>>11&65535}else{Ia=Ja&255;if($){Ca=Ka&255;b[F>>1]=(b[1726064+(Ca<<2)>>1]|0)+(b[1726128+(Ia<<2)>>1]|0);Da=(b[1726066+(Ca<<2)>>1]|0)+(b[1726130+(Ia<<2)>>1]|0)|0;Ta=(Da|0)>1024?Da>>1:512}else{Da=Ka&255;b[F>>1]=(b[1726e3+(Da<<2)>>1]|0)+(b[1726096+(Ia<<2)>>1]|0);Ta=(b[1726002+(Da<<2)>>1]|0)+(b[1726098+(Ia<<2)>>1]|0)|0}Ra=Ta;Sa=tlb(la,Ta,Q,1018156,S,840608,40,4)|0}b[N>>1]=Sa;slb(S,Ra,2,A);Ia=c[R>>2]|0;Da=H*40|0;jlb(Ia+(Da<<1)|0,Ia+(((La|0)/-3|0)+Da<<1)|0,1442520,6,((La|0)%3|0)<<1,10,40);Ia=(c[R>>2]|0)+(Da<<1)|0;Ca=b[W>>1]|0;if(Ca<<16>>16!=0|X){Ua=b[F>>1]|0}else{Ua=0}if(Ca<<16>>16==0|X){Va=b[N>>1]|0}else{Va=0}ylb(Ia,Ia,Q,Ua,Va,8192,14,40);nrc(Y|0,Z|0,20)|0;Ia=m+(H*22|0)+2|0;if((L3(_,Ia,(c[R>>2]|0)+(Da<<1)|0,40,10,1,0,2048)|0)!=0){Ca=0;do{Wa=xa+(Ca<<1)|0;b[Wa>>1]=(b[Wa>>1]|0)>>>2;Ca=Ca+1|0;}while((Ca|0)<234)}if($){Ca=b[N>>1]|0;if((Ca>>1|0)>(b[M>>1]|0)){Xa=2}else{Ka=(b[aa>>1]|0)-1|0;Xa=(Ka|0)>0?Ka&65535:0}b[aa>>1]=Xa;Ka=b[F>>1]|0;if(Ka<<16>>16>14744){Ya=2}else{Ya=Ka<<16>>16>9830|0}Ja=Xa<<16>>16==0;Ba=(((b[da>>1]|0)<9830)+(Ka<<16>>16<9830)+((b[ea>>1]|0)<9830)+((b[fa>>1]|0)<9830)+((b[ga>>1]|0)<9830)+((b[ha>>1]|0)<9830)|0)>2&Ja?0:Ya;do{if(Ja){Za=(((Ba|0)>((b[ba>>1]|0)+1|0))<<31>>31)+Ba&65535}else{if(!(Ba>>>0<2>>>0)){Za=Ba&65535;break}Za=Ba+1&65535}}while(0);b[ba>>1]=Za;Ba=c[R>>2]|0;J3(ja,Q,730792+((Za<<16>>16)*80|0)|0,40);Ja=0;do{Ka=(e[Ba+(Ja+Da<<1)>>1]|0)-(((ca(b[o+(Ja<<1)>>1]|0,Ca)|0)+8192|0)>>>14)|0;b[r+(Ja<<1)>>1]=Ka+(((ca(b[l+(Ja<<1)>>1]|0,Ca)|0)+8192|0)>>>14);Ja=Ja+1|0;}while((Ja|0)<40);L3(_,Ia,ia,40,10,0,0,2048)|0}else{L3(_,Ia,(c[R>>2]|0)+(Da<<1)|0,40,10,0,0,2048)|0}nrc(Z|0,ka|0,20)|0;Ja=0;Ca=0;do{Ba=b[p+(Ja+10<<1)>>1]|0;Ka=Ba<<16>>16;Ca=(Ba<<16>>16>-1?Ka:-Ka|0)+Ca|0;Ja=Ja+1|0;}while((Ja|0)<40);nga(la,ma,q,m+(H*22|0)|0,c[na>>2]|0,oa,pa,qa,_,40);Ja=0;Ia=0;do{Ka=b[p+(Ja+10<<1)>>1]|0;Ba=Ka<<16>>16;Ia=(Ka<<16>>16>-1?Ba:-Ba|0)+Ia|0;Ja=Ja+1|0;}while((Ja|0)<40);c[ra>>2]=(pga(Ca,Ia,_,40,c[ra>>2]&65535)|0)<<16>>16;if(g){Ja=(c[L>>2]|0)+1|0;_a=(Ja|0)>143?143:Ja}else{_a=Na}c[L>>2]=_a;y=e[sa>>1]|e[sa+2>>1]<<16;b[ta>>1]=y;b[ta+2>>1]=y>>16;llb(u+(Da<<1)|0,ua,_,40);y=e[va>>1]|e[va+2>>1]<<16;b[sa>>1]=y;b[sa+2>>1]=y>>16;Ja=H+1|0;if((Ja|0)<2){za=Ha;H=Ja;Aa=Ea}else{break}}b[W>>1]=c[q>>2];orc(wa|0,j+1404|0,308)|0;c[h>>2]=1;v=t;i=k;return v|0}function mga(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)==0){e=0;return e|0}else{f=a;g=c;h=d;i=0}while(1){d=h-1|0;c=(ca(b[g>>1]|0,b[f>>1]|0)|0)+i|0;if((d|0)==0){e=c;break}else{f=f+2|0;g=g+2|0;h=d;i=c}}return e|0}function nga(a,f,g,h,j,k,l,m,n,o){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;p=i;i=i+200|0;q=p|0;r=p+104|0;s=p+176|0;mrc(r|0,0,66)|0;t=0;while(1){u=t+1|0;b[r+(t+11<<1)>>1]=((ca(b[1211768+(t<<1)>>1]|0,b[h+(u<<1)>>1]|0)|0)+16384|0)>>>15;if((u|0)<10){t=u}else{break}}t=s+2|0;b[t>>1]=(((b[h+2>>1]|0)*22938|0)+16384|0)>>>15;b[s+4>>1]=(((b[h+4>>1]|0)*16057|0)+16384|0)>>>15;b[s+6>>1]=(((b[h+6>>1]|0)*11240|0)+16384|0)>>>15;b[s+8>>1]=(((b[h+8>>1]|0)*7868|0)+16384|0)>>>15;b[s+10>>1]=(((b[h+10>>1]|0)*5508|0)+16384|0)>>>15;b[s+12>>1]=(((b[h+12>>1]|0)*3856|0)+16384|0)>>>15;b[s+14>>1]=(((b[h+14>>1]|0)*2699|0)+16384|0)>>>15;b[s+16>>1]=(((b[h+16>>1]|0)*1889|0)+16384|0)>>>15;b[s+18>>1]=(((b[h+18>>1]|0)*1322|0)+16384|0)>>>15;b[s+20>>1]=(((b[h+20>>1]|0)*925|0)+16384|0)>>>15;h=l;nrc(n-20|0,h|0,20)|0;l=(o|0)>0;if(l){s=b[r+22>>1]|0;u=b[r+24>>1]|0;v=b[r+26>>1]|0;w=b[r+28>>1]|0;x=b[r+30>>1]|0;y=b[r+32>>1]|0;z=b[r+34>>1]|0;A=b[r+36>>1]|0;B=b[r+38>>1]|0;C=b[r+40>>1]|0;D=o;while(1){E=(ca(b[n+(D-2<<1)>>1]|0,s)|0)+2048|0;F=E+(ca(b[n+(D-3<<1)>>1]|0,u)|0)|0;E=F+(ca(b[n+(D-4<<1)>>1]|0,v)|0)|0;F=E+(ca(b[n+(D-5<<1)>>1]|0,w)|0)|0;E=F+(ca(b[n+(D-6<<1)>>1]|0,x)|0)|0;F=E+(ca(b[n+(D-7<<1)>>1]|0,y)|0)|0;E=F+(ca(b[n+(D-8<<1)>>1]|0,z)|0)|0;F=E+(ca(b[n+(D-9<<1)>>1]|0,A)|0)|0;E=F+(ca(b[n+(D-10<<1)>>1]|0,B)|0)|0;F=E+(ca(b[n+(D-11<<1)>>1]|0,C)|0)|0;E=D-1|0;b[k+(D+151<<1)>>1]=(F>>>12)+(e[n+(E<<1)>>1]|0);if((E|0)>0){D=E}else{break}}}nrc(h|0,n+(o-10<<1)|0,20)|0;h=c[g>>2]|0;D=q+20|0;if((h|0)>((oga(a,j,k,D,o)|0)<<16>>16|0)){G=c[g>>2]|0}else{G=(oga(a,j,k,D,o)|0)<<16>>16}c[g>>2]=G;orc(k|0,k+(o<<1)|0,304)|0;k=r+20|0;b[k>>1]=4096;G=r+22|0;L3(G,t,G,22,10,0,0,2048)|0;g=a+1224|0;a=Ee[c[g>>2]&511](k,k,20)|0;j=Ee[c[g>>2]&511](k,G,20)|0;G=a>>>0>65535>>>0;k=G?a>>>16:a;g=G?16:0;if((k&65280|0)==0){H=g;I=k}else{H=g|8;I=k>>>8}k=H-14+(d[1359664+I|0]|0)|0;if((k|0)>0){J=a>>k;K=j>>k}else{J=a;K=j}if((((K|0)>-1?K:-K|0)|0)<=(J|0)&(J|0)!=0){j=0;a=0;do{k=b[r+(j+10<<1)>>1]|0;I=k<<16>>16;a=(k<<16>>16>-1?I:-I|0)+a|0;j=j+1|0;}while((j|0)<20);j=a>>2;do{if((j|0)>1024){a=33554432/(j|0)|0;if(l){L=0}else{break}do{r=q+(L+10<<1)|0;b[r>>1]=((ca(b[r>>1]|0,a)|0)+16384|0)>>>15;L=L+1|0;}while((L|0)<(o|0))}}while(0);M=((-(K<<15)|0)/(J|0)|0)<<16>>16}else{M=0}J=m+20|0;L3(J,t,D,o,10,0,0,2048)|0;nrc(m|0,m+(o<<1)|0,20)|0;D=b[f>>1]|0;if((M|0)>0){N=15;O=16384;P=M*6554|0}else{N=12;O=2048;P=M*29491|0}M=P+16384|0;P=M>>15;t=32768-((P|0)>-1?P:-P|0)|0;if((t+32768|0)>>>0>65535>>>0){Q=(t>>31^32767)&65535}else{Q=t&65535}t=(O<<15|0)/(Q<<16>>16|0)|0;Q=M>>16;M=o-1|0;P=b[m+(o+9<<1)>>1]|0;if((M|0)<=0){R=t<<1;S=b[J>>1]|0;T=S<<16>>16;U=T<<15;V=D<<16>>16;W=V<<1;X=ca(W,Q)|0;Y=X+16384|0;Z=Y+U|0;_=Z>>15;$=ca(_,R)|0;aa=$+O|0;ba=aa>>N;da=ba&65535;b[n>>1]=da;b[f>>1]=P;i=p;return}o=Q<<1;K=t<<1;t=M;M=P;while(1){L=t-1|0;q=m+(t+9<<1)|0;b[n+(t<<1)>>1]=(ca((ca(o,b[q>>1]|0)|0)+(M<<16>>16<<15|16384)>>15,K)|0)+O>>N;if((L|0)<=0){R=K;break}t=L;M=b[q>>1]|0}S=b[J>>1]|0;T=S<<16>>16;U=T<<15;V=D<<16>>16;W=V<<1;X=ca(W,Q)|0;Y=X+16384|0;Z=Y+U|0;_=Z>>15;$=ca(_,R)|0;aa=$+O|0;ba=aa>>N;da=ba&65535;b[n>>1]=da;b[f>>1]=P;i=p;return}function oga(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;j=i;i=i+1016|0;k=j|0;l=j+384|0;m=j+960|0;n=h+152|0;o=(n|0)>0;a:do{if(o){p=0;q=0;do{r=b[f+(q<<1)>>1]|0;s=r<<16>>16;p=(r<<16>>16>-1?s:-s|0)|p;q=q+1|0;}while((q|0)<(n|0));do{if((p|0)==0){t=3}else{q=p>>>0>65535>>>0;s=q?p>>>16:p;r=q?16:0;if((s&65280|0)==0){u=r;v=s}else{u=r|8;v=s>>>8}s=((d[1359664+v|0]|0)+u<<16)-720896|0;r=s>>16;if((s|0)>0){t=r;break}if(!o){w=r;x=0;break a}s=-r|0;q=0;while(1){b[k+(q<<1)>>1]=b[f+(q<<1)>>1]<<s;y=q+1|0;if((y|0)<(n|0)){q=y}else{w=r;x=0;break a}}}}while(0);if(o){z=0}else{w=t;x=1;break}while(1){b[k+(z<<1)>>1]=b[f+(z<<1)>>1]>>t;p=z+1|0;if((p|0)<(n|0)){z=p}else{w=t;x=1;break}}}else{w=3;x=1}}while(0);t=a+1224|0;a=k+304|0;z=Ee[c[t>>2]&511](a,a,h)|0;do{if((z|0)!=0){n=z>>>0>65535>>>0;o=n?z>>>16:z;u=n?16:0;if((o&65280|0)==0){A=u;B=o}else{A=u|8;B=o>>>8}o=A-14+(d[1359664+B|0]|0)|0;u=(o|0)>0?o&65535:0;o=u<<16>>16;n=e-1|0;v=e+1|0;p=0;r=n&65535;q=n;do{n=Ee[c[t>>2]&511](a,k+(152-q<<1)|0,h)|0;s=(n|0)>(p|0);p=s?n:p;r=s?q&65535:r;q=q+1|0;}while((q|0)<=(v|0));v=z>>o;if((p|0)==0){break}q=r<<16>>16;s=152-q|0;n=k+(s<<1)|0;y=Ee[c[t>>2]&511](n,n,h)|0;C=h+1|0;jlb(l|0,n,1385160,8,7,2,C);jlb(l+82|0,n,1385160,8,6,2,C);jlb(l+164|0,n,1385160,8,5,2,C);jlb(l+246|0,n,1385160,8,4,2,C);jlb(l+328|0,n,1385160,8,3,2,C);jlb(l+410|0,n,1385160,8,2,2,C);jlb(l+492|0,n,1385160,8,1,2,C);n=h-1|0;D=y;E=0;do{F=l+(E*82|0)+2|0;H=Ee[c[t>>2]&511](F,F,n)|0;F=b[l+(E*82|0)>>1]|0;I=(ca(F,F)|0)+H|0;c[m+(E<<3)>>2]=I;F=b[l+(E*82|0)+(h<<1)>>1]|0;J=(ca(F,F)|0)+H|0;c[m+(E<<3)+4>>2]=J;H=(D|0)>(I|0)?D:I;D=(H|0)>(J|0)?H:J;E=E+1|0;}while((E|0)<7);E=D>>>0>65535>>>0;n=E?D>>>16:D;r=E?16:0;if((n&65280|0)==0){K=r;L=n}else{K=r|8;L=n>>>8}n=K+65522+(d[1359664+L|0]|0)&65535;r=n<<16>>16;if(!(n<<16>>16>-1)){break}E=n<<16>>16>u<<16>>16?n:u;J=E<<16>>16;H=p>>J&65535;I=H<<16>>16;F=H;H=y>>r&65535;M=ca(I,I)|0;I=0;N=1;O=0;while(1){P=O+1|0;Q=P&65535;R=(Ee[c[t>>2]&511](l+(O*82|0)|0,a,h)|0)>>J;S=(R|0)>0?R&65535:0;R=S<<16>>16;T=ca(R,R)|0;R=c[m+(O<<3)>>2]>>r&65535;U=Erc(T,0,H<<16>>16,H<<16>>16<0|0?-1:0)|0;V=U>>>15|G<<17;U=Erc(R<<16>>16,R<<16>>16<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;W=(V|0)>(U>>>15|G<<17|0);U=W?R:H;R=W?T:M;T=(Ee[c[t>>2]&511](l+(O*82|0)+2|0,a,h)|0)>>J;V=(T|0)>0?T&65535:0;T=V<<16>>16;X=ca(T,T)|0;T=c[m+(O<<3)+4>>2]>>r&65535;Y=Erc(X,0,U<<16>>16,U<<16>>16<0|0?-1:0)|0;Z=Y>>>15|G<<17;Y=Erc(T<<16>>16,T<<16>>16<0|0?-1:0,R,(R|0)<0|0?-1:0)|0;_=(Z|0)>(Y>>>15|G<<17|0);$=_?V:W?S:F;aa=_?T:U;ba=_?X:R;da=_?Q:W?Q:I;ea=_?1:W?0:N;if((P|0)<7){F=$;H=aa;M=ba;I=da;N=ea;O=P}else{break}}O=yrc(ba|0,((ba|0)<0|0?-1:0)|0,J<<1|1|0)|0;N=G;I=aa<<16>>16;M=aa<<16>>16<0|0?-1:0;H=Erc(I,M,v,(v|0)<0|0?-1:0)|0;F=yrc(H|0,G|0,r+o|0)|0;H=G;y=(N|0)<(H|0)|(N|0)==(H|0)&O>>>0<F>>>0?0:$;if(y<<16>>16==0){break}F=ea<<16>>16;b:do{if(da<<16>>16==0){fa=f+(151-q+F<<1)|0;ga=n;ha=E;ia=aa;ja=y}else{O=da<<16>>16;jlb(g,k+(s+F<<1)|0,1385192,8,8-O|0,8,C);H=Ee[c[t>>2]&511](g,a,h)|0;if((H|0)<0){ka=0;la=0}else{N=H>>>0>65535>>>0;p=N?H>>>16:H;u=N?16:0;if((p&65280|0)==0){ma=u;na=p}else{ma=u|8;na=p>>>8}p=ma-14+(d[1359664+na|0]|0)|0;u=(p|0)>0?p:0;ka=u&65535;la=H>>u&65535}u=Ee[c[t>>2]&511](g,g,h)|0;H=u>>>0>65535>>>0;p=H?u>>>16:u;N=H?16:0;if((p&65280|0)==0){oa=N;pa=p}else{oa=N|8;pa=p>>>8}p=oa-14+(d[1359664+pa|0]|0)|0;N=(p|0)>0?p:0;p=u>>N&65535;u=N&65535;N=y<<16>>16;H=ca(N,N)|0;N=Erc(p<<16>>16,p<<16>>16<0|0?-1:0,H,0)|0;H=N>>>15|G<<17;N=la<<16>>16;D=Erc(ca(N,N)|0,0,I,M)|0;N=D>>>15|G<<17;D=r-(u<<16>>16)+((ka<<16>>16)-J<<1)|0;if((D|0)>0){qa=H>>D;ra=N}else{qa=H;ra=N>>-D}if((ra|0)>(qa|0)){sa=g;ta=u;ua=ka;va=p;wa=la}else{sa=l+((O-1|0)*82|0)+(F<<1)|0;ta=n;ua=E;va=aa;wa=y}O=(h|0)>0;if(x){if(O){xa=0}else{fa=sa;ga=ta;ha=ua;ia=va;ja=wa;break}while(1){p=sa+(xa<<1)|0;b[p>>1]=b[p>>1]<<w;p=xa+1|0;if((p|0)<(h|0)){xa=p}else{fa=sa;ga=ta;ha=ua;ia=va;ja=wa;break b}}}if(!O){fa=sa;ga=ta;ha=ua;ia=va;ja=wa;break}p=-w|0;u=0;while(1){D=sa+(u<<1)|0;b[D>>1]=b[D>>1]>>p;D=u+1|0;if((D|0)<(h|0)){u=D}else{fa=sa;ga=ta;ha=ua;ia=va;ja=wa;break}}}}while(0);y=yrc(ja<<16>>16|0,(ja<<16>>16<0|0?-1:0)|0,(ha<<16>>16)-1|0)|0;E=G;n=yrc(ia<<16>>16|0,(ia<<16>>16<0|0?-1:0)|0,ga<<16>>16|0)|0;F=G;J=wrc(n,F,y,E)|0;E=Crc(n<<15|0>>>17,F<<15|n>>>17,J,G)|0;J=G;n=0;F=(J|0)>(n|0)|(J|0)==(n|0)&E>>>0>21845>>>0?E:21845;ylb(g,f+304|0,fa,F&65535,32768-F&65535,16384,15,h);ya=1;i=j;return ya|0}}while(0);nrc(g|0,f+304|0,h<<1)|0;ya=0;i=j;return ya|0}function pga(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=(a|0)==0;if(!((c|0)!=0|h)){i=0;return i|0}if(h){j=0}else{h=a>>>0>65535>>>0;k=h?a>>>16:a;l=h?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=14-m-(d[1359664+n|0]|0)|0;if((k|0)<0){o=a>>-k}else{o=a<<k}a=c>>>0>65535>>>0;n=a?c>>>16:c;m=a?16:0;if((n&65280|0)==0){p=m;q=n}else{p=m|8;q=n>>>8}n=14-p-(d[1359664+q|0]|0)|0;if((n|0)<0){r=c>>-n}else{r=c<<n}do{if((o|0)<(r|0)){c=(o<<15|0)/(r|0)|0;q=n-k|0;p=q-1|0;if((p|0)<0){s=c>>1-q;break}else{s=c<<p;break}}else{p=((o-r<<14|0)/(r|0)|0)+16384|0;c=n-k|0;if((c|0)<0){s=p>>-c;break}else{s=p<<c;break}}}while(0);j=(s*410|0)+16384>>15}if((f|0)>0){t=g;u=0}else{i=g;return i|0}while(1){g=((((t<<16>>16)*32358|0)+16384|0)>>>15<<16>>16)+j|0;if((g+32768|0)>>>0>65535>>>0){v=(g>>31^32767)&65535}else{v=g&65535}g=e+(u<<1)|0;s=(ca(b[g>>1]|0,v<<16>>16)|0)+8192|0;k=s>>14;if((k+32768|0)>>>0>65535>>>0){w=(s>>31^32767)&65535}else{w=k&65535}b[g>>1]=w;g=u+1|0;if((g|0)<(f|0)){t=v;u=g}else{i=v;break}}return i|0}function qga(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+60>>2]|0;e=a+120|0;do{if((c[e>>2]|0)<=65535){f=a+124|0;if((c[f>>2]|0)>65535){break}g=UHb()|0;c[a+804>>2]=g;if((g|0)==0){h=-12;i=b;return h|0}c[g+88>>2]=1;c[g+84>>2]=1;g=d+4|0;c[g>>2]=pJb(c[339864]|0)|0;j=d+8|0;c[j>>2]=hJb(ca(c[e>>2]<<1,c[f>>2]|0)|0)|0;f=hJb(c[e>>2]|0)|0;c[d+1044>>2]=f;if((f|0)==0){h=-12;i=b;return h|0}if((c[j>>2]|0)==0){h=-12;i=b;return h|0}if((c[g>>2]|0)==0){h=-12;i=b;return h|0}g=a+140|0;if((rIb(d+20|0,c[g>>2]|0)|0)>=0){h=0;i=b;return h|0}if((c[g>>2]|0)==11){h=0;i=b;return h|0}else{KIb(0,0,2247904,(k=i,i=i+24|0,c[k>>2]=2205856,c[k+8>>2]=2173600,c[k+16>>2]=233,k)|0);i=k;Hd();return 0}}}while(0);KIb(a,16,2298744,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;h=-22;i=b;return h|0}function rga(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;i=i+1024|0;j=h|0;k=b+60|0;l=c[k>>2]|0;m=b+120|0;n=b+124|0;o=((ca((c[m>>2]|0)*7|0,c[n>>2]|0)|0)/5|0)+16384|0;p=d5a(b,e,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=h;return q|0}p=e+24|0;o=c[p>>2]|0;r=e+28|0;s=o+(c[r>>2]|0)|0;do{if((c[b+140>>2]|0)==11){t=U1(e,0,1024)|0;if((t|0)==0){q=-12;i=h;return q|0}else{u=f+4|0;nrc(t|0,c[u>>2]|0,1024)|0;v=c[u>>2]|0;break}}else{v=0}}while(0);u=c[f>>2]|0;t=c[f+32>>2]|0;w=c[k>>2]|0;k=c[n>>2]|0;n=c[m>>2]|0;m=w+16|0;do{if((c[m>>2]&1|0)==0){x=k;z=n;A=0;B=0}else{C=c[w+12>>2]|0;if(!((C|0)!=0&(v|0)==0)){x=k;z=n;A=0;B=0;break}D=c[C>>2]|0;E=c[C+32>>2]|0;C=n-1|0;F=k-1|0;G=0;while(1){if((G|0)>=(F|0)){H=F;break}if((grc(D+(ca(G,E)|0)|0,u+(ca(G,t)|0)|0,n)|0)==0){G=G+1|0}else{H=F;break}}while(1){if((H|0)<=(G|0)){break}if((grc(D+(ca(H,E)|0)|0,u+(ca(H,t)|0)|0,n)|0)==0){H=H-1|0}else{break}}F=H+(1-G)|0;a:do{if((C|0)>0){I=0;while(1){J=G;while(1){if((J|0)>=(H|0)){break}K=a[D+((ca(J,E)|0)+I)|0]|0;if(K<<24>>24==(a[u+((ca(J,t)|0)+I)|0]|0)){J=J+1|0}else{L=I;break a}}J=I+1|0;if((J|0)<(C|0)){I=J}else{L=J;break}}}else{L=0}}while(0);b:do{if((C|0)>(L|0)){I=C;while(1){J=G;while(1){if((J|0)>=(H|0)){break}K=a[D+((ca(J,E)|0)+I)|0]|0;if(K<<24>>24==(a[u+((ca(J,t)|0)+I)|0]|0)){J=J+1|0}else{M=I;break b}}J=I-1|0;if((J|0)>(L|0)){I=J}else{M=J;break}}}else{M=C}}while(0);C=M+(1-L)|0;KIb(b,48,2453360,(N=i,i=i+48|0,c[N>>2]=C,c[N+8>>2]=F,c[N+16>>2]=L,c[N+24>>2]=G,c[N+32>>2]=n,c[N+40>>2]=k,N)|0);i=N;x=F;z=C;A=G;B=L}}while(0);a[o]=44;L=o+1|0;y=B&65535;a[L]=y;y=y>>8;a[L+1|0]=y;L=o+3|0;y=A&65535;a[L]=y;y=y>>8;a[L+1|0]=y;L=o+5|0;y=z&65535;a[L]=y;y=y>>8;a[L+1|0]=y;L=o+7|0;y=x&65535;a[L]=y;y=y>>8;a[L+1|0]=y;L=o+9|0;k=(v|0)!=0;if(k){a[L]=-121;n=0;M=o+10|0;while(1){H=c[v+(n<<2)>>2]|0;a[M+2|0]=H;a[M+1|0]=H>>>8;a[M]=H>>>16;H=n+1|0;if(H>>>0<256>>>0){n=H;M=M+3|0}else{break}}O=o+778|0}else{a[L]=0;O=o+10|0}c:do{if((c[m>>2]&2|0)==0){P=-1;Q=41}else{if((c[w+12>>2]|0)==0|k){P=-1;Q=41;break}mrc(j|0,0,1024)|0;if((x|0)>0&(z|0)>0){o=u+((ca(A,t)|0)+B)|0;L=0;while(1){M=0;do{n=j+(d[o+M|0]<<2)|0;c[n>>2]=(c[n>>2]|0)+1;M=M+1|0;}while((M|0)<(z|0));M=L+1|0;if((M|0)<(x|0)){o=o+t|0;L=M}else{R=0;break}}}else{R=0}while(1){if(!(R>>>0<256>>>0)){S=-1;break}if((c[j+(R<<2)>>2]|0)==0){Q=37;break}else{R=R+1|0}}do{if((Q|0)==37){if((R|0)<0){S=R;break}L=U1(e,0,1024)|0;if((L|0)==0){T=O;break c}nrc(L|0,w+20|0,1024)|0;a[L+(R<<2|3)|0]=0;P=R;Q=41;break c}}while(0);KIb(b,48,2363928,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;P=S;Q=41}}while(0);d:do{if((Q|0)==41){a[O]=8;S=O+1|0;N=w+4|0;b=w+8|0;JPa(c[N>>2]|0,c[b>>2]|0,ca(z<<1,x)|0,12,0,1688);R=u+((ca(A,t)|0)+B)|0;e:do{if((P|0)>-1){j=c[w+12>>2]|0;k=c[j+32>>2]|0;if((x|0)<=0){U=0;break}m=w+1044|0;L=P&255;if((z|0)<=0){o=R;G=0;F=0;while(1){nrc(c[m>>2]|0,o|0,z)|0;M=(KPa(c[N>>2]|0,c[m>>2]|0,z)|0)+F|0;n=G+1|0;if((n|0)<(x|0)){o=o+t|0;G=n;F=M}else{U=M;break e}}}F=ca(k,A)|0;G=R;o=0;M=0;n=(c[j>>2]|0)+(F+B)|0;while(1){nrc(c[m>>2]|0,G|0,z)|0;F=0;do{if((a[n+F|0]|0)==(a[G+F|0]|0)){a[(c[m>>2]|0)+F|0]=L}F=F+1|0;}while((F|0)<(z|0));F=(KPa(c[N>>2]|0,c[m>>2]|0,z)|0)+M|0;v=o+1|0;if((v|0)<(x|0)){G=G+t|0;o=v;M=F;n=n+k|0}else{U=F;break}}}else{if((x|0)>0){V=R;W=0;X=0}else{U=0;break}while(1){k=(KPa(c[N>>2]|0,V,z)|0)+X|0;n=W+1|0;if((n|0)<(x|0)){V=V+t|0;W=n;X=k}else{U=k;break}}}}while(0);R=(LPa(c[N>>2]|0,230)|0)+U|0;if((R|0)>0){k=s;n=c[b>>2]|0;M=R;R=S;while(1){o=(M|0)<255?M:255;a[R]=o;G=R+1|0;if((k-G|0)<(o|0)){T=G;break d}nrc(G|0,n|0,o)|0;G=R+(o+1)|0;m=M-o|0;if((m|0)>0){n=n+o|0;M=m;R=G}else{Y=G;break}}}else{Y=S}a[Y]=0;T=Y+1|0}}while(0);Y=l+12|0;l=c[Y>>2]|0;do{if((l|0)==0){s=UHb()|0;c[Y>>2]=s;if((s|0)==0){q=-12}else{Z=s;break}i=h;return q|0}else{Z=l}}while(0);WHb(Z);Z=YHb(c[Y>>2]|0,f)|0;if((Z|0)<0){q=Z;i=h;return q|0}c[r>>2]=T-(c[p>>2]|0);p=e+36|0;c[p>>2]=c[p>>2]|1;c[g>>2]=1;q=0;i=h;return q|0}function sga(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(a+804|0);mJb(b+4|0);mJb(b+8|0);VHb(b+12|0);mJb(b+1044|0);return 0}function tga(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b|0;g=b+4|0;h=c[g>>2]|0;i=e<<32-h|c[f>>2];if((h|0)>(d|0)){j=h;k=i;l=j-d|0;c[f>>2]=k;c[g>>2]=l;return}m=b+12|0;b=c[m>>2]|0;y=i;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;j=h+32|0;k=(h|0)==32?0:e>>>(h>>>0);l=j-d|0;c[f>>2]=k;c[g>>2]=l;return}function uga(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+4|0;e=b|0;if((c[d>>2]|0)>=32){c[d>>2]=32;c[e>>2]=0;return}f=b+12|0;b=c[e>>2]&255;while(1){g=c[f>>2]|0;c[f>>2]=g+1;a[g]=b;g=(c[e>>2]|0)>>>8;c[e>>2]=g;h=(c[d>>2]|0)+8|0;c[d>>2]=h;if((h|0)<32){b=g&255}else{break}}c[d>>2]=32;c[e>>2]=0;return}function vga(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b+2148>>2]=a;c[a+140>>2]=30;a=UHb()|0;c[b+4>>2]=a;if((a|0)==0){d=-12;return d|0}FPa(b+96|0);d=0;return d|0}function wga(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;h=i;i=i+8|0;j=h|0;k=c[b+60>>2]|0;l=k;m=g+24|0;n=c[m>>2]|0;o=g+28|0;p=c[o>>2]|0;if(!((p|0)>-1)){KIb(0,0,2122344,(q=i,i=i+24|0,c[q>>2]=2640080,c[q+8>>2]=2617288,c[q+16>>2]=135,q)|0);i=q;Hd();return 0}r=k+84|0;c[r>>2]=n;s=k+92|0;c[s>>2]=n;t=k+88|0;c[t>>2]=n+p;p=g+8|0;n=c[p+4>>2]|0;u=k+4|0;v=c[u>>2]|0;w=v+136|0;c[w>>2]=c[p>>2];c[w+4>>2]=n;n=c[p+4>>2]|0;w=v+144|0;c[w>>2]=c[p>>2];c[w+4>>2]=n;n=g+16|0;w=c[n+4>>2]|0;p=v+152|0;c[p>>2]=c[n>>2];c[p+4>>2]=w;w=c[g+48>>2]|0;CHb(v,w,(w|0)<0|0?-1:0);do{if((c[o>>2]|0)>5){w=c[m>>2]|0;if((grc(w,1147792,6)|0)==0){c[k+2152>>2]=1;x=k+2152|0;y=k+2156|0}else{v=(grc(w,1147776,6)|0)==0;c[k+2152>>2]=v&1;w=k+2152|0;g=k+2156|0;if(v){x=w;y=g}else{z=w;A=g;B=25;break}}c[y>>2]=0;c[k+48>>2]=0;g=j|0;w=c[r>>2]|0;v=c[t>>2]|0;if((v-w|0)>>>0<13>>>0){C=-1094995529;i=h;return C|0}a[g]=a[w]|0;a[g+1|0]=a[w+1|0]|0;a[g+2|0]=a[w+2|0]|0;a[g+3|0]=a[w+3|0]|0;a[g+4|0]=a[w+4|0]|0;a[g+5|0]=a[w+5|0]|0;p=w+6|0;c[r>>2]=p;do{if((grc(g,1147792,6)|0)!=0){if((grc(g,1147776,6)|0)==0){break}else{C=-1094995529}i=h;return C|0}}while(0);c[k+32>>2]=-1;g=w+8|0;c[r>>2]=g;n=p;D=k+8|0;c[D>>2]=(d[n]|d[n+1|0]<<8)<<16>>16&65535;n=w+10|0;c[r>>2]=n;E=g;g=k+12|0;c[g>>2]=(d[E]|d[E+1|0]<<8)<<16>>16&65535;E=w+11|0;c[r>>2]=E;F=d[n]|0;c[k+36>>2]=(F>>>4&7)+1;n=F&128;G=k+16|0;c[G>>2]=n;H=k+20|0;c[H>>2]=(F&7)+1;F=w+12|0;c[r>>2]=F;I=d[E]|0;E=w+13|0;c[r>>2]=E;J=a[F]|0;if(J<<24>>24==0){K=n}else{n=c[k+2148>>2]|0;c[n+224>>2]=(J&255)+15;c[n+228>>2]=64;K=c[G>>2]|0}G=k+28|0;if((K|0)==0){c[G>>2]=-1}else{c[G>>2]=I;n=c[H>>2]|0;if((v-E|0)>>>0<3<<n>>>0){C=-1094995529;i=h;return C|0}H=1<<n;if((H|0)>0){n=k+100|0;J=0;F=E;while(1){E=F+3|0;c[r>>2]=E;c[n>>2]=(d[F]|0)<<16|(d[F+1|0]|0)<<8|(d[F+2|0]|0)|-16777216;L=J+1|0;if((L|0)<(H|0)){n=n+4|0;J=L;F=E}else{break}}M=c[G>>2]|0}else{M=I}c[k+24>>2]=c[l+100+(M<<2)>>2]}F=H4a(b,c[D>>2]|0,c[g>>2]|0)|0;if((F|0)<0){C=F;i=h;return C|0}WHb(c[u>>2]|0);F=M4a(b,c[u>>2]|0,0)|0;if((F|0)<0){C=F;i=h;return C|0}F=k+40|0;xJb(F,k+44|0,c[D>>2]|0);if((c[F>>2]|0)==0){C=-12;i=h;return C|0}else{F=c[u>>2]|0;c[F+88>>2]=1;c[F+84>>2]=1;c[y>>2]=1;N=F;O=x;break}}else{c[k+2152>>2]=0;z=k+2152|0;A=k+2156|0;B=25}}while(0);do{if((B|0)==25){if((c[A>>2]|0)==0){KIb(b,16,2453248,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}x=N4a(b,c[u>>2]|0)|0;if((x|0)<0){C=x;i=h;return C|0}else{x=c[u>>2]|0;c[x+88>>2]=2;c[x+84>>2]=0;N=x;O=z;break}}}while(0);z=c[r>>2]|0;b=c[t>>2]|0;if((b|0)==(z|0)){C=-541478725;i=h;return C|0}A=k+2148|0;x=k+32|0;y=k+52|0;M=b;b=z;a:while(1){if((M-b|0)<1){B=32;break}c[r>>2]=b+1;z=d[b]|0;KIb(c[A>>2]|0,48,2363904,(q=i,i=i+16|0,c[q>>2]=z,c[q+8>>2]=z,q)|0);i=q;if((z|0)==44){B=34;break}else if((z|0)==59){C=-541478725;B=113;break}else if((z|0)!=33){B=112;break}z=c[r>>2]|0;l=c[t>>2]|0;K=l;if((K-z|0)>>>0<2>>>0){C=-1094995529;B=113;break}j=z+1|0;c[r>>2]=j;m=a[z]|0;o=z+2|0;c[r>>2]=o;F=a[j]|0;if(m<<24>>24==-7&F<<24>>24==4){if((K-o|0)>>>0<5>>>0){C=-1094995529;B=113;break}c[r>>2]=z+3;m=d[o]|0;j=z+6|0;c[r>>2]=j;if((m&1|0)==0){P=-1}else{P=d[z+5|0]|0}c[x>>2]=P;J=m>>>2&7;c[y>>2]=J>>>0>3>>>0?0:J;J=z+7|0;c[r>>2]=J;Q=a[j]|0;R=J}else{Q=F;R=o}if(Q<<24>>24==0){S=R}else{o=Q;F=R;while(1){J=o&255;j=J+1|0;if((K-F|0)>>>0<j>>>0){C=-1094995529;B=113;break a}z=F+j|0;c[r>>2]=z;j=a[F+J|0]|0;if(j<<24>>24==0){S=z;break}else{o=j;F=z}}}if((l|0)==(S|0)){C=-541478725;B=113;break}else{M=l;b=S}}if((B|0)==32){KIb(c[A>>2]|0,48,2363904,(q=i,i=i+16|0,c[q>>2]=0,c[q+8>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}else if((B|0)==34){S=c[r>>2]|0;b=c[t>>2]|0;if((b-S|0)>>>0<9>>>0){C=-1094995529;i=h;return C|0}M=S+2|0;c[r>>2]=M;R=S;Q=(d[R]|d[R+1|0]<<8)<<16>>16&65535;R=S+4|0;c[r>>2]=R;P=M;M=(d[P]|d[P+1|0]<<8)<<16>>16&65535;P=S+6|0;c[r>>2]=P;F=R;R=(d[F]|d[F+1|0]<<8)<<16>>16;F=R&65535;o=S+8|0;c[r>>2]=o;K=P;P=(d[K]|d[K+1|0]<<8)<<16>>16;K=P&65535;D=S+9|0;c[r>>2]=D;S=d[o]|0;o=S&64;do{if((S&128|0)==0){if((c[k+16>>2]|0)!=0){T=k+100|0;break}KIb(c[A>>2]|0,16,2298672,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}else{g=(S&7)+1|0;if((b-D|0)>>>0<3<<g>>>0){C=-1094995529;i=h;return C|0}I=1<<g;g=k+1124|0;if((I|0)>0){U=g;V=0;W=D}else{T=g;break}while(1){G=W+3|0;c[r>>2]=G;c[U>>2]=(d[W]|0)<<16|(d[W+1|0]|0)<<8|(d[W+2|0]|0)|-16777216;z=V+1|0;if((z|0)<(I|0)){U=U+4|0;V=z;W=G}else{T=g;break}}}}while(0);b:do{if((c[O>>2]|0)!=0){do{if((c[x>>2]|0)==-1){if((c[k+16>>2]|0)==0){break}W=c[k+24>>2]|0;V=c[N>>2]|0;U=V+((ca((c[N+32>>2]|0)>>>2,c[N+72>>2]|0)|0)<<2)|0;if(V>>>0<U>>>0){X=V}else{break b}while(1){c[X>>2]=W;X=X+4|0;if(!(X>>>0<U>>>0)){break b}}}}while(0);U=c[k+2160>>2]|0;W=c[N>>2]|0;V=W+((ca((c[N+32>>2]|0)>>>2,c[N+72>>2]|0)|0)<<2)|0;if(W>>>0<V>>>0){Y=W}else{break}do{c[Y>>2]=U;Y=Y+4|0;}while(Y>>>0<V>>>0)}}while(0);do{if((F+Q|0)<=(c[k+8>>2]|0)){Y=K+M|0;if((Y|0)>(c[k+12>>2]|0)){break}if(R<<16>>16==0|P<<16>>16==0){KIb(c[A>>2]|0,16,2205824,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}X=k+48|0;O=c[X>>2]|0;c:do{if((O|0)==3){V=c[k+72>>2]|0;U=(c[N+32>>2]|0)>>>2;W=c[k+56>>2]|0;D=c[k+60>>2]|0;b=ca(D,U)|0;S=ca((c[k+68>>2]|0)+D|0,U)|0;D=V+(S<<2)|0;if((b|0)>=(S|0)){break}S=c[k+64>>2]<<2;g=(c[N>>2]|0)+(b<<2)|0;I=V+(b<<2)|0;while(1){nrc(g+(W<<2)|0,I+(W<<2)|0,S)|0;b=I+(U<<2)|0;if(b>>>0<D>>>0){g=g+(U<<2)|0;I=b}else{break}}}else if((O|0)==2){I=c[k+80>>2]|0;U=c[k+56>>2]|0;g=c[k+60>>2]|0;D=(c[N+32>>2]|0)>>>2;S=c[N>>2]|0;W=ca(D,g)|0;b=ca(D,(c[k+68>>2]|0)+g|0)|0;g=S+(b<<2)|0;if((W|0)>=(b|0)){break}b=S+(W<<2)|0;W=(c[k+64>>2]|0)+U|0;if((W|0)>(U|0)){Z=b}else{S=b;while(1){S=S+(D<<2)|0;if(!(S>>>0<g>>>0)){break c}}}do{S=Z+(W<<2)|0;b=Z+(U<<2)|0;do{c[b>>2]=I;b=b+4|0;}while(b>>>0<S>>>0);Z=Z+(D<<2)|0;}while(Z>>>0<g>>>0)}}while(0);O=c[y>>2]|0;c[X>>2]=O;do{if((O|0)!=0){c[k+56>>2]=Q;c[k+60>>2]=M;c[k+64>>2]=F;c[k+68>>2]=K;if((O|0)==2){if((c[x>>2]|0)>-1){c[k+80>>2]=c[k+2160>>2];break}else{c[k+80>>2]=c[k+24>>2];break}}else if((O|0)!=3){break}g=k+72|0;D=N+32|0;xJb(g,k+76|0,ca(c[N+72>>2]|0,c[D>>2]|0)|0);I=c[g>>2]|0;if((I|0)==0){C=-12;i=h;return C|0}g=c[N>>2]|0;U=(c[D>>2]|0)>>>2;D=ca(U,M)|0;W=ca(U,Y)|0;S=g+(W<<2)|0;if((D|0)>=(W|0)){break}W=F<<2;b=I+(D<<2)|0;I=g+(D<<2)|0;while(1){nrc(b+(Q<<2)|0,I+(Q<<2)|0,W)|0;D=I+(U<<2)|0;if(D>>>0<S>>>0){b=b+(U<<2)|0;I=D}else{break}}}}while(0);Y=c[r>>2]|0;O=c[t>>2]|0;if((O-Y|0)>>>0<2>>>0){C=-1094995529;i=h;return C|0}X=Y+1|0;c[r>>2]=X;I=k+96|0;U=HPa(c[I>>2]|0,d[Y]|0,X,O-X|0,0)|0;if((U|0)<0){KIb(c[A>>2]|0,16,2173576,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=U;i=h;return C|0}U=(c[N+32>>2]|0)>>>2;X=c[N>>2]|0;O=(ca(U,M)|0)+Q|0;Y=X+(O<<2)|0;b=k+40|0;S=U<<3;W=U<<1;D=U<<2;g=X+(O+U<<2)|0;d:do{if((o|0)==0){V=IPa(c[I>>2]|0,c[b>>2]|0,F)|0;if((V|0)==(F|0)){_=1;$=Y}else{aa=V;B=87;break}while(1){V=$+(F<<2)|0;l=c[b>>2]|0;G=$;z=l;while(1){j=d[z]|0;if((j|0)!=(c[x>>2]|0)){c[G>>2]=c[T+(j<<2)>>2]}j=G+4|0;if(!(j>>>0<V>>>0)){break}G=j;z=z+1|0}if((_|0)>=(K|0)){break d}z=IPa(c[I>>2]|0,l,F)|0;if((z|0)==(F|0)){_=_+1|0;$=$+(U<<2)|0}else{aa=z;B=87;break}}}else{z=Y;G=0;V=0;j=1;J=c[b>>2]|0;while(1){m=IPa(c[I>>2]|0,J,F)|0;if((m|0)!=(F|0)){aa=m;B=87;break d}m=z+(F<<2)|0;n=c[b>>2]|0;H=z;v=n;while(1){w=d[v]|0;if((w|0)!=(c[x>>2]|0)){c[H>>2]=c[T+(w<<2)>>2]}w=H+4|0;if(!(w>>>0<m>>>0)){break}H=w;v=v+1|0}do{if((V|0)==2){v=G+4|0;H=(v|0)<(K|0);ba=H?2:3;da=H?v:1;ea=H?z+(D<<2)|0:g}else if((V|0)==3){ba=3;da=G+2|0;ea=z+(W<<2)|0}else{H=G+8|0;if((H|0)<(K|0)){ba=V;da=H;ea=z+(S<<2)|0;break}H=(V|0)!=0?2:4;ba=V+1|0;da=H;ea=X+((ca(H,U)|0)+O<<2)|0}}while(0);if((j|0)<(K|0)){z=ea;G=da;V=ba;j=j+1|0;J=n}else{break}}}}while(0);do{if((B|0)==87){if((aa|0)==0){break}KIb(c[A>>2]|0,16,2146120,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}}while(0);EPa(c[I>>2]|0);c[x>>2]=-1;c[y>>2]=0;O=YHb(e,c[u>>2]|0)|0;if((O|0)<0){C=O;i=h;return C|0}c[f>>2]=1;C=(c[r>>2]|0)-(c[s>>2]|0)|0;i=h;return C|0}}while(0);KIb(c[A>>2]|0,16,2247832,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;C=-1094995529;i=h;return C|0}else if((B|0)==112){C=-1094995529;i=h;return C|0}else if((B|0)==113){i=h;return C|0}return 0}function xga(a){a=a|0;var b=0;b=c[a+60>>2]|0;GPa(b+96|0);VHb(b+4|0);mJb(b+40|0);mJb(b+72|0);return 0}function yga(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;c[a+416>>2]=1;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;d=a+412|0;if((c[d>>2]|0)==0){c[d>>2]=8e3}c[a+420>>2]=1;d=c[a+48>>2]|0;if((d|0)==86034){c[a+424>>2]=160;c[a+432>>2]=33;e=0;i=b;return e|0}else if((d|0)==86046){c[a+424>>2]=320;d=a+432|0;f=c[d>>2]|0;if((f|0)==0){c[d>>2]=65;e=0;i=b;return e|0}d=f-41|0;if(d>>>0<25>>>0&((d|0)%3|0|0)==0){e=0;i=b;return e|0}KIb(a,16,2205768,(a=i,i=i+8|0,c[a>>2]=f,a)|0);i=a;e=-1094995529;i=b;return e|0}else{e=0;i=b;return e|0}return 0}function zga(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=a+432|0;if((l|0)<(c[h>>2]|0)){KIb(a,16,2298624,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=j;return n|0}c[f+76>>2]=c[a+424>>2];o=M4a(a,f,0)|0;if((o|0)<0){n=o;i=j;return n|0}o=c[f>>2]|0;f=c[a+48>>2]|0;do{if((f|0)==86034){p=l<<3;q=p>>>0>2147483639>>>0|(k|0)==0;r=q?0:k;s=q?8:p+8|0;p=r;q=s>>>0>4>>>0?4:s;if(((d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24)&240|0)!=208){KIb(a,24,2247784,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}p=c[a+60>>2]|0;t=p+240|0;u=p+660|0;v=c[u>>2]|0;w=p+596|0;x=r+(q>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&4)>>>26;x=q+6|0;q=s>>>0>x>>>0?x:s;c[w+(v<<5)>>2]=(ca(y,13421568)|0)-429473792>>15<<1;y=r+(q>>>3)|0;x=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>26;y=q+6|0;q=s>>>0>y>>>0?y:s;c[w+(v<<5)+4>>2]=(ca(x,13421568)|0)-429473792>>15<<1;x=r+(q>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>27;x=q+5|0;q=s>>>0>x>>>0?x:s;c[w+(v<<5)+8>>2]=(ca(y,13421568)|0)-268414976>>15<<1;y=r+(q>>>3)|0;x=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>27;y=q+5|0;q=s>>>0>y>>>0?y:s;c[w+(v<<5)+12>>2]=(ca(x,13421568)|0)-147620864>>15<<1;x=r+(q>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>28;x=q+4|0;q=s>>>0>x>>>0?x:s;c[w+(v<<5)+16>>2]=(ca(y,19684352)|0)-161072356>>15<<1;y=r+(q>>>3)|0;x=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>28;y=q+4|0;q=s>>>0>y>>>0?y:s;c[w+(v<<5)+20>>2]=(ca(x,17895424)|0)-80513024>>15<<1;x=r+(q>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>29;x=q+3|0;q=s>>>0>x>>>0?x:s;c[w+(v<<5)+24>>2]=(ca(y,32208896)|0)-107367572>>15<<1;y=r+(q>>>3)|0;x=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>29;y=q+3|0;c[w+(v<<5)+28>>2]=(ca(x,30420992)|0)-53695680>>15<<1;x=t;v=0;w=s>>>0>y>>>0?y:s;while(1){y=r+(w>>>3)|0;q=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7);y=q>>>25;z=w+7|0;A=s>>>0>z>>>0?z:s;z=r+(A>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(A&7)>>>30;z=A+2|0;A=s>>>0>z>>>0?z:s;z=r+(A>>>3)|0;C=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(A&7)>>>30;z=A+2|0;A=s>>>0>z>>>0?z:s;if(q>>>0<1342177280>>>0){D=40}else{D=y>>>0>120>>>0?120:y}y=e[1380728+(B<<1)>>1]|0;B=0;do{b[x+(B<<1)>>1]=((ca(b[x+(B-D<<1)>>1]|0,y)|0)+16384|0)>>>15;B=B+1|0;}while((B|0)<40);B=c[1381944+(v<<2)>>2]|0;y=r+(A>>>3)|0;q=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(A&7)>>>26;y=A+6|0;z=0;E=s>>>0>y>>>0?y:s;do{y=c[B+(z<<2)>>2]|0;F=r+(E>>>3)|0;G=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>((32-y|0)>>>0);F=y+E|0;E=s>>>0>F>>>0?F:s;F=x+((z*3|0)+C<<1)|0;b[F>>1]=(b[F>>1]|0)+(b[1380736+(q<<4)+(c[680064+(y<<5)+(G<<2)>>2]<<1)>>1]|0);z=z+1|0;}while((z|0)<13);z=v+1|0;if((z|0)<4){x=x+80|0;v=z;w=E}else{break}}w=p;nrc(p|0,p+320|0,240)|0;v=c[u>>2]|0;x=v^1;s=w+596+(x<<5)|0;r=c[s>>2]|0;z=w+596+(v<<5)|0;q=Bga((r>>2)+(r>>1)+(c[z>>2]>>2)|0)|0;r=w+596+(x<<5)+4|0;C=c[r>>2]|0;B=w+596+(v<<5)+4|0;A=Bga((C>>2)+(C>>1)+(c[B>>2]>>2)|0)|0;C=w+596+(x<<5)+8|0;G=c[C>>2]|0;y=w+596+(v<<5)+8|0;F=Bga((G>>2)+(G>>1)+(c[y>>2]>>2)|0)|0;G=w+596+(x<<5)+12|0;H=c[G>>2]|0;I=w+596+(v<<5)+12|0;J=Bga((H>>2)+(H>>1)+(c[I>>2]>>2)|0)|0;H=w+596+(x<<5)+16|0;K=c[H>>2]|0;L=w+596+(v<<5)+16|0;M=Bga((K>>2)+(K>>1)+(c[L>>2]>>2)|0)|0;K=w+596+(x<<5)+20|0;N=c[K>>2]|0;O=w+596+(v<<5)+20|0;P=Bga((N>>2)+(N>>1)+(c[O>>2]>>2)|0)|0;N=w+596+(x<<5)+24|0;Q=c[N>>2]|0;R=w+596+(v<<5)+24|0;S=Bga((Q>>2)+(Q>>1)+(c[R>>2]>>2)|0)|0;Q=w+596+(x<<5)+28|0;T=c[Q>>2]|0;U=w+596+(v<<5)+28|0;v=Bga((T>>2)+(T>>1)+(c[U>>2]>>2)|0)|0;T=p+560|0;w=p+588|0;V=p+584|0;W=p+580|0;X=p+576|0;Y=p+572|0;Z=p+568|0;_=p+564|0;$=0;aa=c[w>>2]|0;ba=c[V>>2]|0;da=c[W>>2]|0;ea=c[X>>2]|0;fa=c[Y>>2]|0;ga=c[Z>>2]|0;ha=c[_>>2]|0;ia=c[T>>2]|0;while(1){ja=(b[t+($<<1)>>1]|0)-((ca(aa,v)|0)+16384>>15)|0;ka=ja-((ca(ba,S)|0)+16384>>15)|0;la=((ca(ka,S)|0)+16384>>15)+ba|0;ma=ka-((ca(da,P)|0)+16384>>15)|0;na=((ca(ma,P)|0)+16384>>15)+da|0;ka=ma-((ca(ea,M)|0)+16384>>15)|0;oa=((ca(ka,M)|0)+16384>>15)+ea|0;ma=ka-((ca(fa,J)|0)+16384>>15)|0;pa=((ca(ma,J)|0)+16384>>15)+fa|0;ka=ma-((ca(ga,F)|0)+16384>>15)|0;qa=((ca(ka,F)|0)+16384>>15)+ga|0;ma=ka-((ca(ha,A)|0)+16384>>15)|0;ra=((ca(ma,A)|0)+16384>>15)+ha|0;sa=ma-((ca(ia,q)|0)+16384>>15)|0;ta=((ca(sa,q)|0)+16384>>15)+ia|0;b[o+($<<1)>>1]=sa;ma=$+1|0;if((ma|0)<13){$=ma;aa=la;ba=na;da=oa;ea=pa;fa=qa;ga=ra;ha=ta;ia=sa}else{break}}ia=p+592|0;ha=((ca(ja,v)|0)+16384>>15)+aa|0;c[w>>2]=la;c[ia>>2]=ha;c[V>>2]=na;c[W>>2]=oa;c[X>>2]=pa;c[Y>>2]=qa;c[Z>>2]=ra;c[_>>2]=ta;c[T>>2]=sa;ha=Bga((c[z>>2]>>1)+(c[s>>2]>>1)|0)|0;ga=Bga((c[B>>2]>>1)+(c[r>>2]>>1)|0)|0;fa=Bga((c[y>>2]>>1)+(c[C>>2]>>1)|0)|0;ea=Bga((c[I>>2]>>1)+(c[G>>2]>>1)|0)|0;da=Bga((c[L>>2]>>1)+(c[H>>2]>>1)|0)|0;ba=Bga((c[O>>2]>>1)+(c[K>>2]>>1)|0)|0;$=Bga((c[R>>2]>>1)+(c[N>>2]>>1)|0)|0;q=Bga((c[U>>2]>>1)+(c[Q>>2]>>1)|0)|0;A=13;F=la;J=na;M=oa;P=pa;S=qa;ma=ra;ka=ta;ua=sa;while(1){va=(b[t+(A<<1)>>1]|0)-((ca(F,q)|0)+16384>>15)|0;wa=va-((ca(J,$)|0)+16384>>15)|0;xa=((ca(wa,$)|0)+16384>>15)+J|0;ya=wa-((ca(M,ba)|0)+16384>>15)|0;za=((ca(ya,ba)|0)+16384>>15)+M|0;wa=ya-((ca(P,da)|0)+16384>>15)|0;Aa=((ca(wa,da)|0)+16384>>15)+P|0;ya=wa-((ca(S,ea)|0)+16384>>15)|0;Ba=((ca(ya,ea)|0)+16384>>15)+S|0;wa=ya-((ca(ma,fa)|0)+16384>>15)|0;Ca=((ca(wa,fa)|0)+16384>>15)+ma|0;ya=wa-((ca(ka,ga)|0)+16384>>15)|0;Da=((ca(ya,ga)|0)+16384>>15)+ka|0;Ea=ya-((ca(ua,ha)|0)+16384>>15)|0;Fa=((ca(Ea,ha)|0)+16384>>15)+ua|0;b[o+(A<<1)>>1]=Ea;ya=A+1|0;if((ya|0)<27){A=ya;F=xa;J=za;M=Aa;P=Ba;S=Ca;ma=Da;ka=Fa;ua=Ea}else{break}}ua=((ca(va,q)|0)+16384>>15)+F|0;c[w>>2]=xa;c[ia>>2]=ua;c[V>>2]=za;c[W>>2]=Aa;c[X>>2]=Ba;c[Y>>2]=Ca;c[Z>>2]=Da;c[_>>2]=Fa;c[T>>2]=Ea;ua=c[z>>2]|0;ka=Bga((ua>>1)+(c[s>>2]>>2)+(ua>>2)|0)|0;ua=c[B>>2]|0;ma=Bga((ua>>1)+(c[r>>2]>>2)+(ua>>2)|0)|0;ua=c[y>>2]|0;S=Bga((ua>>1)+(c[C>>2]>>2)+(ua>>2)|0)|0;ua=c[I>>2]|0;P=Bga((ua>>1)+(c[G>>2]>>2)+(ua>>2)|0)|0;ua=c[L>>2]|0;M=Bga((ua>>1)+(c[H>>2]>>2)+(ua>>2)|0)|0;ua=c[O>>2]|0;J=Bga((ua>>1)+(c[K>>2]>>2)+(ua>>2)|0)|0;ua=c[R>>2]|0;A=Bga((ua>>1)+(c[N>>2]>>2)+(ua>>2)|0)|0;ua=c[U>>2]|0;ha=Bga((ua>>1)+(c[Q>>2]>>2)+(ua>>2)|0)|0;ua=27;ga=xa;fa=za;ea=Aa;da=Ba;ba=Ca;$=Da;aa=Fa;v=Ea;while(1){Ga=(b[t+(ua<<1)>>1]|0)-((ca(ga,ha)|0)+16384>>15)|0;ya=Ga-((ca(fa,A)|0)+16384>>15)|0;Ha=((ca(ya,A)|0)+16384>>15)+fa|0;wa=ya-((ca(ea,J)|0)+16384>>15)|0;Ia=((ca(wa,J)|0)+16384>>15)+ea|0;ya=wa-((ca(da,M)|0)+16384>>15)|0;Ja=((ca(ya,M)|0)+16384>>15)+da|0;wa=ya-((ca(ba,P)|0)+16384>>15)|0;Ka=((ca(wa,P)|0)+16384>>15)+ba|0;ya=wa-((ca($,S)|0)+16384>>15)|0;La=((ca(ya,S)|0)+16384>>15)+$|0;wa=ya-((ca(aa,ma)|0)+16384>>15)|0;Ma=((ca(wa,ma)|0)+16384>>15)+aa|0;Na=wa-((ca(v,ka)|0)+16384>>15)|0;Oa=((ca(Na,ka)|0)+16384>>15)+v|0;b[o+(ua<<1)>>1]=Na;wa=ua+1|0;if((wa|0)<40){ua=wa;ga=Ha;fa=Ia;ea=Ja;da=Ka;ba=La;$=Ma;aa=Oa;v=Na}else{break}}v=((ca(Ga,ha)|0)+16384>>15)+ga|0;c[w>>2]=Ha;c[ia>>2]=v;c[V>>2]=Ia;c[W>>2]=Ja;c[X>>2]=Ka;c[Y>>2]=La;c[Z>>2]=Ma;c[_>>2]=Oa;c[T>>2]=Na;v=Bga(c[z>>2]|0)|0;aa=Bga(c[B>>2]|0)|0;$=Bga(c[y>>2]|0)|0;ba=Bga(c[I>>2]|0)|0;da=Bga(c[L>>2]|0)|0;ea=Bga(c[O>>2]|0)|0;fa=Bga(c[R>>2]|0)|0;ua=Bga(c[U>>2]|0)|0;ka=40;ma=Ha;S=Ia;P=Ja;M=Ka;J=La;A=Ma;Q=Oa;N=Na;while(1){Pa=(b[t+(ka<<1)>>1]|0)-((ca(ma,ua)|0)+16384>>15)|0;K=Pa-((ca(S,fa)|0)+16384>>15)|0;Qa=((ca(K,fa)|0)+16384>>15)+S|0;H=K-((ca(P,ea)|0)+16384>>15)|0;Ra=((ca(H,ea)|0)+16384>>15)+P|0;K=H-((ca(M,da)|0)+16384>>15)|0;Sa=((ca(K,da)|0)+16384>>15)+M|0;H=K-((ca(J,ba)|0)+16384>>15)|0;Ta=((ca(H,ba)|0)+16384>>15)+J|0;K=H-((ca(A,$)|0)+16384>>15)|0;Ua=((ca(K,$)|0)+16384>>15)+A|0;H=K-((ca(Q,aa)|0)+16384>>15)|0;Va=((ca(H,aa)|0)+16384>>15)+Q|0;Wa=H-((ca(N,v)|0)+16384>>15)|0;Xa=((ca(Wa,v)|0)+16384>>15)+N|0;b[o+(ka<<1)>>1]=Wa;H=ka+1|0;if((H|0)<160){ka=H;ma=Qa;S=Ra;P=Sa;M=Ta;J=Ua;A=Va;Q=Xa;N=Wa}else{break}}N=((ca(Pa,ua)|0)+16384>>15)+ma|0;c[w>>2]=Qa;c[ia>>2]=N;c[V>>2]=Ra;c[W>>2]=Sa;c[X>>2]=Ta;c[Y>>2]=Ua;c[Z>>2]=Va;c[_>>2]=Xa;c[T>>2]=Wa;c[u>>2]=x;N=p+664|0;Q=c[N>>2]|0;A=0;do{J=o+(A<<1)|0;M=((Q*28180|0)+16384>>15)+(b[J>>1]|0)|0;if((M+32768|0)>>>0>65535>>>0){Ya=(M>>31^32767)&65535}else{Ya=M&65535}Q=Ya<<16>>16;M=Q<<1;if((M+32768|0)>>>0>65535>>>0){Za=(Q>>30^32767)&65535}else{Za=M&65535}b[J>>1]=Za&-8;A=A+1|0;}while((A|0)<160);c[N>>2]=Q}else if((f|0)==86046){A=BUa(a,o,k,(65-(c[h>>2]|0)|0)/3|0)|0;if((A|0)<0){n=A}else{break}i=j;return n|0}}while(0);c[g>>2]=1;n=c[h>>2]|0;i=j;return n|0}function Aga(a){a=a|0;mrc(c[a+60>>2]|0,0,668)|0;return}function Bga(a){a=a|0;var b=0,c=0;b=(a|0)>-1?a:-a|0;do{if((b|0)<11059){c=b<<1}else{if((b|0)<20070){c=b+11059|0;break}else{c=(b>>2)+26112|0;break}}}while(0);return((a|0)<0?-c|0:c)|0}function Cga(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[b+60>>2]|0;uTa(d);c[d+4>>2]=b;c[d+8>>2]=c[b+128>>2];c[d+12>>2]=c[b+132>>2];e=(c[b+12>>2]|0)+12|0;f=d+48|0;c[f>>2]=c[e>>2];c[d+28>>2]=1;c[d+13944>>2]=1;c[b+140>>2]=0;c[f>>2]=c[e>>2];Vpb();if(a[1146544]|0){g=d+14696|0;h=g;c[h>>2]=0;return 0}a[1146544]=1;c[1487679]=5955888;c[1487681]=662;$2(5950712,9,35,1379992,1,1,1379952,1,1,0,0,0,4)|0;c[1487673]=5955568;c[1487675]=80;$2(5950688,6,10,1379936,1,1,1379920,1,1,0,0,0,4)|0;c[1487667]=5954992;c[1487669]=144;$2(5950664,7,17,1379753,2,1,1379752,2,1,0,0,0,4)|0;c[1507299]=5952944;c[1507301]=512;$2(6029192,9,63,1380329,2,1,1380328,2,1,0,0,0,4)|0;c[344902]=5950736;c[344904]=552;e=c[344892]|0;$2(1379604,9,(c[344890]|0)+1|0,e+2|0,4,2,e,4,2,0,0,0,4)|0;if((c[344906]|0)==0){i=0}else{g=d+14696|0;h=g;c[h>>2]=0;return 0}do{c[1379624+(i<<2)>>2]=5958536+(i*2208|0);i=i+1|0;}while((i|0)<32);BTa(1379560);g=d+14696|0;h=g;c[h>>2]=0;return 0}function Dga(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;j=i;i=i+64|0;k=j|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;h=c[e+60>>2]|0;n=h;o=h;p=f;c[h+60>>2]=c[e+88>>2];c[h+64>>2]=c[e+92>>2];f=h+14696|0;c[f>>2]=0;q=h+14120|0;r=m<<3;s=r>>>0>2147483639>>>0|(l|0)==0;t=s?0:l;l=s?0:r;r=q;s=h+14132|0;u=l+8|0;v=h+14136|0;w=t+(l>>3)|0;x=h+14124|0;y=h+14128|0;z=h+96|0;A=h+108|0;B=h+4|0;C=h+8|0;D=h+12|0;E=h+116|0;F=h+120|0;G=h+144|0;H=h+9992|0;I=h+14692|0;J=e+128|0;K=e+132|0;L=h+13744|0;M=j+24|0;N=L;a:while(1){c[r>>2]=t;c[s>>2]=l;c[v>>2]=u;c[x>>2]=w;c[y>>2]=0;if((c[z>>2]|0)==0){if((rTa(o)|0)<0){O=-1;P=109;break}Q=c[y>>2]|0;R=c[s>>2]|0}else{Q=0;R=l}S=R-Q|0;T=0;U=Q;while(1){if((S|0)<=24){P=8;break}V=c[v>>2]|0;W=c[r>>2]|0;X=W+(U>>>3)|0;Y=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(U&7)>>>31;X=U+1|0;Z=V>>>0>X>>>0?X:V;c[y>>2]=Z;X=Y|T<<1&1048574;if((X|0)==16){_=Z;$=V;aa=W;break}else{S=S-1|0;T=X;U=Z}}if((P|0)==8){P=0;if((T|0)!=16){P=10;break}_=U;$=c[v>>2]|0;aa=c[r>>2]|0}S=aa+(_>>>3)|0;Z=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(_&7)>>>27;S=_+5|0;c[y>>2]=$>>>0>S>>>0?S:$;S=c[A>>2]|0;c[A>>2]=(Z>>>0<(S&31)>>>0?Z|32:Z)+(S&-32);S=c[B>>2]|0;c[S+104>>2]=1001;c[S+108>>2]=3e4;S=c[v>>2]|0;Z=(c[y>>2]|0)+1|0;X=(S>>>0>Z>>>0?Z:S)+1|0;Z=(S>>>0>X>>>0?X:S)+1|0;X=S>>>0>Z>>>0?Z:S;c[y>>2]=X;Z=c[r>>2]|0;W=d[Z+(X>>>3)|0]|0;V=((X|0)<(S|0))+X|0;c[y>>2]=V;Y=(128>>>((X&7)>>>0)&W|0)==0;W=Y?176:352;X=Y?144:288;ba=Y?11:22;da=Y?9:18;c[C>>2]=W;c[D>>2]=X;c[E>>2]=ba;c[F>>2]=da;c[G>>2]=ca(ba,da)|0;da=V+1|0;V=(S>>>0>da>>>0?da:S)+1|0;da=S>>>0>V>>>0?V:S;c[y>>2]=da;V=c[s>>2]|0;if((V-da|0)<1){break}else{ea=da}while(1){da=d[Z+(ea>>>3)|0]|0;ba=((ea|0)<(S|0))+ea|0;c[y>>2]=ba;if((da&128>>>((ea&7)>>>0)|0)==0){break}da=ba+8|0;ea=S>>>0>da>>>0?da:S;c[y>>2]=ea;if((V-ea|0)<1){break a}}c[H>>2]=2;c[I>>2]=0;if((W|0)==(c[J>>2]|0)){if((X|0)!=(c[K>>2]|0)){P=17}}else{P=17}if((P|0)==17){P=0;c[M>>2]=c[L>>2];c[M+4>>2]=c[L+4>>2];c[M+8>>2]=c[L+8>>2];c[M+12>>2]=c[L+12>>2];c[M+16>>2]=c[L+16>>2];c[M+20>>2]=c[L+20>>2];c[M+24>>2]=c[L+24>>2];c[M+28>>2]=c[L+28>>2];c[M+32>>2]=c[L+32>>2];c[M+36>>2]=c[L+36>>2];c[N>>2]=0;xTa(o);c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];c[L+8>>2]=c[M+8>>2];c[L+12>>2]=c[M+12>>2];c[L+16>>2]=c[M+16>>2];c[L+20>>2]=c[M+20>>2];c[L+24>>2]=c[M+24>>2];c[L+28>>2]=c[M+28>>2];c[L+32>>2]=c[M+32>>2];c[L+36>>2]=c[M+36>>2]}if((c[z>>2]|0)!=0){P=20;break}V=H4a(e,c[C>>2]|0,c[D>>2]|0)|0;if((V|0)<0){O=V;P=109;break}}if((P|0)==10){KIb(c[B>>2]|0,16,2532160,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa}else if((P|0)==20){D=c[H>>2]|0;C=h+7712|0;c[C>>2]=D;z=(D|0)==1;c[h+7708>>2]=z&1;M=c[e+856>>2]|0;do{if((M|0)>7){if((D|0)!=3){if((M|0)<=31){break}if(!((M|0)>47|z^1)){break}}L=c[y>>2]>>3;N=(L|0)==0?1:L;O=(N+10|0)>(m|0)?m:N;i=j;return O|0}}while(0);if((DTa(o,e)|0)<0){O=-1;i=j;return O|0}STa(o);e=h+12476|0;c[e>>2]=0;z=h+12480|0;c[z>>2]=0;b:do{if((c[I>>2]|0)<(((c[F>>2]|0)==18?12:5)|0)){M=k;D=h+13712|0;N=h+9960|0;L=h+14672|0;K=q;J=h+14676|0;ea=h+124|0;G=h+12496|0;E=h+12500|0;A=h+12504|0;$=h+12508|0;_=h+12512|0;aa=h+12516|0;Q=h+12544|0;R=h+12548|0;l=h+12552|0;w=h+14680|0;x=h+12488|0;u=h+14684|0;t=h+14688|0;V=h+11736|0;S=h+11740|0;Z=h+9160|0;U=h+11744|0;T=h+11748|0;da=h+180|0;ba=h+14340|0;Y=h+10096|0;c:while(1){d:do{if((c[f>>2]|0)==0){ga=c[y>>2]|0;ha=(c[r>>2]|0)+(ga>>>3)|0;if(((je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)&-131072>>>((ga&7)>>>0)|0)==0){if((Hga(n)|0)>-1){break}}c[q>>2]=c[D>>2];c[q+4>>2]=c[D+4>>2];c[q+8>>2]=c[D+8>>2];c[q+12>>2]=c[D+12>>2];c[q+16>>2]=c[D+16>>2];ga=c[y>>2]|0;ha=-ga&7;if((ha|0)==0){ia=ga}else{ja=c[v>>2]|0;ka=ha+ga|0;ga=ja>>>0>ka>>>0?ka:ja;c[y>>2]=ga;ia=ga}ga=(c[s>>2]|0)-ia|0;if((ga|0)>25){la=ga;ma=ia}else{break b}while(1){ga=(c[r>>2]|0)+(ma>>>3)|0;if(((je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)&-131072>>>((ma&7)>>>0)|0)==0){c[M>>2]=c[q>>2];c[M+4>>2]=c[q+4>>2];c[M+8>>2]=c[q+8>>2];c[M+12>>2]=c[q+12>>2];c[M+16>>2]=c[q+16>>2];if((Hga(n)|0)>-1){break d}c[q>>2]=c[M>>2];c[q+4>>2]=c[M+4>>2];c[q+8>>2]=c[M+8>>2];c[q+12>>2]=c[M+12>>2];c[q+16>>2]=c[M+16>>2];na=c[y>>2]|0}else{na=ma}ga=c[v>>2]|0;ja=na+8|0;ma=ga>>>0>ja>>>0?ja:ga;c[y>>2]=ma;la=la-8|0;if((la|0)<=25){break b}}}else{if(!((Hga(n)|0)>-1)){break b}}}while(0);QTa(o,c[N>>2]|0);ga=c[L>>2]|0;e:do{if((ga|0)<34){ja=ga;f:while(1){ka=c[1487679]|0;ha=c[v>>2]|0;oa=c[r>>2]|0;pa=c[y>>2]|0;while(1){qa=oa+(pa>>>3)|0;ra=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(pa&7)>>>23;qa=b[ka+(ra<<2)>>1]|0;sa=b[ka+(ra<<2)+2>>1]|0;ra=sa<<16>>16;if(sa<<16>>16<0){sa=pa+9|0;ta=ha>>>0>sa>>>0?sa:ha;sa=oa+(ta>>>3)|0;ua=((je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ta&7)>>>((ra+32|0)>>>0))+qa|0;va=b[ka+(ua<<2)+2>>1]|0;wa=b[ka+(ua<<2)>>1]|0;xa=ta}else{va=ra;wa=qa;xa=pa}qa=va+xa|0;ya=ha>>>0>qa>>>0?qa:ha;c[y>>2]=ya;c[J>>2]=wa;if((wa|0)==33){pa=ya}else if((wa|0)==34){P=45;break f}else{break}}if((wa|0)<0){P=47;break}pa=wa+1|0;c[J>>2]=pa;ha=pa+ja|0;c[L>>2]=ha;if((ha|0)>33){P=101;break}ha=(c[I>>2]|0)-1|0;pa=wa+ja|0;ka=(((ha|0)%2|0)*11|0)+((pa|0)%11|0)|0;c[e>>2]=ka;oa=((pa|0)/11|0)+(((ha|0)/2|0)*3|0)|0;c[z>>2]=oa;ha=(ca(c[ea>>2]|0,oa)|0)+ka|0;NTa(o);za=c[B>>2]|0;ka=8>>>((c[za+800>>2]|0)>>>0);c[G>>2]=(c[G>>2]|0)+2;c[E>>2]=(c[E>>2]|0)+2;c[A>>2]=(c[A>>2]|0)+2;c[$>>2]=(c[$>>2]|0)+2;c[_>>2]=(c[_>>2]|0)+1;c[aa>>2]=(c[aa>>2]|0)+1;c[Q>>2]=(c[Q>>2]|0)+(ka<<1);c[R>>2]=(c[R>>2]|0)+ka;c[l>>2]=(c[l>>2]|0)+ka;ka=c[1487673]|0;oa=c[y>>2]|0;pa=c[v>>2]|0;qa=c[r>>2]|0;ra=qa+(oa>>>3)|0;ta=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(oa&7)>>>26;ra=b[ka+(ta<<2)>>1]|0;ua=b[ka+(ta<<2)+2>>1]|0;ta=ua<<16>>16;if(ua<<16>>16<0){ua=oa+6|0;sa=pa>>>0>ua>>>0?ua:pa;ua=qa+(sa>>>3)|0;Aa=((je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(sa&7)>>>((ta+32|0)>>>0))+ra|0;Ba=b[ka+(Aa<<2)+2>>1]|0;Ca=b[ka+(Aa<<2)>>1]|0;Da=sa}else{Ba=ta;Ca=ra;Da=oa}oa=Ba+Da|0;ra=pa>>>0>oa>>>0?oa:pa;c[y>>2]=ra;c[w>>2]=Ca;if((Ca|0)<0){P=53;break}if(!(Ca>>>0<10>>>0)){break c}oa=c[1379880+(Ca<<2)>>2]|0;c[w>>2]=oa;if((oa&65536|0)==0){Ea=oa}else{oa=qa+(ra>>>3)|0;qa=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ra&7)>>>27;oa=ra+5|0;c[y>>2]=pa>>>0>oa>>>0?oa:pa;QTa(o,qa);Ea=c[w>>2]|0}c[x>>2]=Ea&1;if((Ea&8|0)==0){c[u>>2]=0;c[t>>2]=0;Fa=Ea}else{qa=c[L>>2]|0;do{if((qa|0)==1|(qa|0)==12|(qa|0)==23){P=62}else{if((c[J>>2]|0)!=1){P=62;break}Ga=c[u>>2]|0}}while(0);if((P|0)==62){P=0;c[u>>2]=0;c[t>>2]=0;Ga=0}c[u>>2]=Gga(K,Ga)|0;c[t>>2]=Gga(K,c[t>>2]|0)|0;Fa=c[w>>2]|0}if((Fa&131072|0)==0){Ha=63}else{qa=c[1507299]|0;pa=c[y>>2]|0;oa=c[v>>2]|0;ra=c[r>>2]|0;ta=ra+(pa>>>3)|0;sa=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(pa&7)>>>23;ta=b[qa+(sa<<2)>>1]|0;Aa=b[qa+(sa<<2)+2>>1]|0;sa=Aa<<16>>16;if(Aa<<16>>16<0){Aa=pa+9|0;ka=oa>>>0>Aa>>>0?Aa:oa;Aa=ra+(ka>>>3)|0;ra=((je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(ka&7)>>>((sa+32|0)>>>0))+ta|0;Ia=b[qa+(ra<<2)+2>>1]|0;Ja=b[qa+(ra<<2)>>1]|0;Ka=ka}else{Ia=sa;Ja=ta;Ka=pa}pa=Ia+Ka|0;c[y>>2]=oa>>>0>pa>>>0?pa:oa;Ha=Ja+1|0}if((c[x>>2]|0)==0){c[V>>2]=1;c[S>>2]=0;c[(c[Z>>2]|0)+(ha<<2)>>2]=12296;c[U>>2]=c[u>>2]<<1;c[T>>2]=c[t>>2]<<1}else{c[(c[Z>>2]|0)+(ha<<2)>>2]=1}do{if((c[x>>2]|0)==0){if((c[w>>2]&131072|0)!=0){P=75;break}mrc(da|0,-1|0,24)|0}else{P=75}}while(0);if((P|0)==75){P=0;qe[c[Y>>2]&1023](c[ba>>2]|0);ha=0;oa=Ha;while(1){pa=c[ba>>2]|0;ta=pa+(ha<<7)|0;sa=oa&32;do{if((c[x>>2]|0)==0){if((sa|0)==0){La=0;P=85;break}ka=c[r>>2]|0;ra=c[y>>2]|0;qa=ka+(ra>>>3)|0;Aa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ra&7)>>>30;if((Aa&2|0)==0){Ma=0;Na=ra;Oa=ka;P=83;break}qa=c[v>>2]|0;ua=ra+2|0;ra=qa>>>0>ua>>>0?ua:qa;c[y>>2]=ra;b[ta>>1]=(Aa<<1&2^2)+65535;Ma=1;Na=ra;Oa=ka;P=83}else{ka=c[y>>2]|0;ra=c[v>>2]|0;Aa=c[r>>2]|0;qa=Aa+(ka>>>3)|0;Pa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ka&7)>>>24;qa=ka+8|0;ka=ra>>>0>qa>>>0?qa:ra;c[y>>2]=ka;if((Pa&127|0)==0){P=78;break f}b[ta>>1]=(Pa|0)==255?128:Pa&65535;Ma=1;Na=ka;Oa=Aa;P=83}}while(0);do{if((P|0)==83){P=0;if((sa|0)==0){La=Ma;P=85;break}ta=c[344902]|0;Aa=c[v>>2]|0;ka=Ma;ra=Na;g:while(1){qa=Oa+(ra>>>3)|0;ua=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ra&7)>>>23;qa=b[ta+(ua<<2)>>1]|0;Qa=b[ta+(ua<<2)+2>>1]|0;ua=Qa<<16>>16;if(Qa<<16>>16<0){Qa=ra+9|0;Ra=Aa>>>0>Qa>>>0?Qa:Aa;Qa=Oa+(Ra>>>3)|0;Sa=((je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Ra&7)>>>((ua+32|0)>>>0))+qa|0;Ta=b[ta+(Sa<<2)+2>>1]|0;Ua=b[ta+(Sa<<2)>>1]|0;Va=Ra}else{Ta=ua;Ua=qa;Va=ra}qa=Ta+Va|0;ua=Aa>>>0>qa>>>0?qa:Aa;c[y>>2]=ua;if((Ua|0)<0){P=89;break f}do{if((Ua|0)==(c[344890]|0)){qa=Oa+(ua>>>3)|0;Ra=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ua&7)>>>26;qa=ua+6|0;Sa=Aa>>>0>qa>>>0?qa:Aa;c[y>>2]=Sa;qa=Oa+(Sa>>>3)|0;Qa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Sa&7)>>24;qa=Sa+8|0;Sa=Aa>>>0>qa>>>0?qa:Aa;c[y>>2]=Sa;Wa=Qa&65535;Xa=Ra;Ya=Sa}else{if((Ua|0)==0){break g}Sa=a[(c[344893]|0)+Ua|0]|0;Ra=a[(c[344894]|0)+Ua|0]|0;Qa=d[Oa+(ua>>>3)|0]|0;qa=((ua|0)<(Aa|0))+ua|0;c[y>>2]=qa;Za=Ra<<24>>24;if((Qa&128>>>((ua&7)>>>0)|0)==0){Wa=Za;Xa=Sa;Ya=qa;break}Wa=-Za&65535;Xa=Sa;Ya=qa}}while(0);ua=Xa+ka|0;if((ua|0)>63){P=96;break f}b[pa+(ha<<7)+(d[n+368+ua|0]<<1)>>1]=Wa;ka=ua+1|0;ra=Ya}c[n+180+(ha<<2)>>2]=ka-1}}while(0);if((P|0)==85){P=0;c[n+180+(ha<<2)>>2]=La-1}pa=ha+1|0;if((pa|0)<6){ha=pa;oa=oa<<1}else{break}}}KTa(o,c[ba>>2]|0);oa=c[L>>2]|0;Fga(n,oa-(c[J>>2]|0)|0,oa-1|0);oa=c[L>>2]|0;if((oa|0)<34){ja=oa}else{break e}}do{if((P|0)==45){P=0;c[f>>2]=1;P=100}else if((P|0)==47){P=0;if(((c[s>>2]|0)-ya|0)<8){P=100;break}oa=c[z>>2]|0;KIb(c[B>>2]|0,16,2146096,(fa=i,i=i+16|0,c[fa>>2]=c[e>>2],c[fa+8>>2]=oa,fa)|0);i=fa;P=101}else if((P|0)==53){P=0;KIb(za,16,2122320,(fa=i,i=i+8|0,c[fa>>2]=Ca,fa)|0);i=fa;P=101}else if((P|0)==78){P=0;oa=c[e>>2]|0;ha=c[z>>2]|0;KIb(c[B>>2]|0,16,2617264,(fa=i,i=i+24|0,c[fa>>2]=Pa,c[fa+8>>2]=oa,c[fa+16>>2]=ha,fa)|0);i=fa;P=101}else if((P|0)==89){P=0;ha=c[z>>2]|0;KIb(c[B>>2]|0,16,2590048,(fa=i,i=i+16|0,c[fa>>2]=c[e>>2],c[fa+8>>2]=ha,fa)|0);i=fa;P=101}else if((P|0)==96){P=0;ha=c[z>>2]|0;KIb(c[B>>2]|0,16,2568360,(fa=i,i=i+16|0,c[fa>>2]=c[e>>2],c[fa+8>>2]=ha,fa)|0);i=fa;P=101}}while(0);if((P|0)==100){P=0;Fga(n,ja,33);break}else if((P|0)==101){P=0;ha=(ca(c[ea>>2]|0,c[z>>2]|0)|0)+(c[e>>2]|0)|0;KIb(c[B>>2]|0,16,2173520,(fa=i,i=i+8|0,c[fa>>2]=ha,fa)|0);i=fa;break}}}while(0);if((c[I>>2]|0)>=(((c[F>>2]|0)==18?12:5)|0)){break b}}KIb(0,0,2363808,(fa=i,i=i+24|0,c[fa>>2]=2640008,c[fa+8>>2]=2247760,c[fa+16>>2]=386,fa)|0);i=fa;Hd();return 0}}while(0);ETa(o);F=c[C>>2]|0;C=h+9856|0;h=c[C>>2]|0;if((F|0)!=(c[h+88>>2]|0)){KIb(0,0,2363808,(fa=i,i=i+24|0,c[fa>>2]=2298552,c[fa+8>>2]=2247760,c[fa+16>>2]=636,fa)|0);i=fa;Hd();return 0}if((F|0)!=(c[H>>2]|0)){KIb(0,0,2363808,(fa=i,i=i+24|0,c[fa>>2]=2205720,c[fa+8>>2]=2247760,c[fa+16>>2]=637,fa)|0);i=fa;Hd();return 0}H=YHb(p,h|0)|0;if((H|0)<0){O=H;i=j;return O|0}HTa(o,c[C>>2]|0,p);c[g>>2]=1;g=c[y>>2]>>3;y=(g|0)==0?1:g;O=(y+10|0)>(m|0)?m:y;i=j;return O|0}else if((P|0)==109){i=j;return O|0}KIb(c[B>>2]|0,16,2453096,(fa=i,i=i+1|0,i=i+7&-8,c[fa>>2]=0,fa)|0);i=fa;O=-1;i=j;return O|0}function Ega(a){a=a|0;xTa(c[a+60>>2]|0);return 0}function Fga(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=a|0;c[a+12488>>2]=0;if((b|0)>=(d|0)){return}f=a+14692|0;g=a+12476|0;h=a+12480|0;i=a+124|0;j=a+4|0;k=a+12496|0;l=a+12500|0;m=a+12504|0;n=a+12508|0;o=a+12512|0;p=a+12516|0;q=a+12544|0;r=a+12548|0;s=a+12552|0;t=a+11736|0;u=a+11740|0;v=a+9160|0;w=a+11744|0;x=a+11748|0;y=a+9924|0;z=a+14680|0;A=a+14340|0;B=a+180|0;a=b;do{b=(c[f>>2]|0)-1|0;C=(((b|0)%2|0)*11|0)+((a|0)%11|0)|0;c[g>>2]=C;D=(((b|0)/2|0)*3|0)+((a|0)/11|0)|0;c[h>>2]=D;b=ca(c[i>>2]|0,D)|0;NTa(e);D=8>>>((c[(c[j>>2]|0)+800>>2]|0)>>>0);c[k>>2]=(c[k>>2]|0)+2;c[l>>2]=(c[l>>2]|0)+2;c[m>>2]=(c[m>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+1;c[p>>2]=(c[p>>2]|0)+1;c[q>>2]=(c[q>>2]|0)+(D<<1);c[r>>2]=(c[r>>2]|0)+D;c[s>>2]=(c[s>>2]|0)+D;mrc(B|0,-1|0,24)|0;c[t>>2]=1;c[u>>2]=0;c[(c[v>>2]|0)+(b+C<<2)>>2]=14344;c[w>>2]=0;c[x>>2]=0;c[y>>2]=1;c[z>>2]=c[z>>2]&-8388609;KTa(e,c[A>>2]|0);a=a+1|0;}while((a|0)<(d|0));return}function Gga(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c[1487667]|0;g=a+8|0;h=c[g>>2]|0;i=c[a+16>>2]|0;j=c[a>>2]|0;a=j+(h>>>3)|0;k=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(h&7)>>>25;a=b[f+(k<<2)>>1]|0;l=b[f+(k<<2)+2>>1]|0;k=l<<16>>16;if(l<<16>>16<0){l=h+7|0;m=i>>>0>l>>>0?l:i;l=j+(m>>>3)|0;n=((je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>((k+32|0)>>>0))+a|0;o=b[f+(n<<2)+2>>1]|0;p=b[f+(n<<2)>>1]|0;q=m}else{o=k;p=a;q=h}h=o+q|0;q=i>>>0>h>>>0?h:i;c[g>>2]=q;if((p|0)<0){r=e;return r|0}h=c[790928+(p<<2)>>2]|0;if((p|0)==0){s=h}else{p=d[j+(q>>>3)|0]|0;c[g>>2]=((q|0)<(i|0))+q;s=(p&128>>>((q&7)>>>0)|0)==0?-h|0:h}h=s+e|0;if(!((h|0)<-15)){return((h|0)>15?h-32|0:h)|0}r=h+32|0;return r|0}function Hga(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;e=a+14696|0;do{if((c[e>>2]|0)==0){f=c[a+14120>>2]|0;g=a+14128|0;h=c[g>>2]|0;j=f+(h>>>3)|0;if(((je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)&-131072>>>((h&7)>>>0)|0)==0){j=c[a+14136>>2]|0;k=h+16|0;h=j>>>0>k>>>0?k:j;c[g>>2]=h;l=h;m=j;n=f;break}else{o=-1;i=b;return o|0}}else{l=c[a+14128>>2]|0;m=c[a+14136>>2]|0;n=c[a+14120>>2]|0}}while(0);c[e>>2]=0;e=a+14128|0;f=n+(l>>>3)|0;j=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7)>>>28;f=l+4|0;l=m>>>0>f>>>0?f:m;c[e>>2]=l;c[a+14692>>2]=j;f=n+(l>>>3)|0;h=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(l&7)>>>27;f=l+5|0;l=m>>>0>f>>>0?f:m;c[e>>2]=l;c[a+9960>>2]=h;do{if((c[a+120>>2]|0)==18){if((j-1|0)>>>0>11>>>0){o=-1}else{break}i=b;return o|0}else{if((j|0)==1|(j|0)==3|(j|0)==5){break}else{o=-1}i=b;return o|0}}while(0);j=c[a+14132>>2]|0;if((j-l|0)<1){o=-1094995529;i=b;return o|0}else{p=l}while(1){l=d[n+(p>>>3)|0]|0;f=((p|0)<(m|0))+p|0;c[e>>2]=f;if((l&128>>>((p&7)>>>0)|0)==0){break}l=f+8|0;f=m>>>0>l>>>0?l:m;c[e>>2]=f;if((j-f|0)<1){o=-1094995529;q=14;break}else{p=f}}if((q|0)==14){i=b;return o|0}do{if((h|0)==0){q=a+4|0;KIb(c[q>>2]|0,16,2550296,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;if((c[(c[q>>2]|0)+696>>2]&131074|0)==0){break}else{o=-1}i=b;return o|0}}while(0);c[a+14672>>2]=0;c[a+14676>>2]=0;o=0;i=b;return o|0}function Iga(a,b){a=a|0;b=b|0;if((a|0)==176&(b|0)==144){return 0}else{return((a|0)==352&(b|0)==288?1:-1)|0}return 0}function Jga(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=b+784|0;Y2(d);e=b+796|0;f=c[e>>2]|0;c[b+14280>>2]=f;g=d|0;d=c[g>>2]|0;h=b+788|0;i=c[h>>2]|0;if((i|0)>20){j=i-20|0;k=d<<20|16;l=f}else{m=f;y=je(16>>>((20-i|0)>>>0)|d<<i|0)|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=(c[e>>2]|0)+4|0;c[e>>2]=m;j=i+12|0;k=16;l=m}c[g>>2]=k;c[h>>2]=j;m=c[b+108>>2]|0;i=Erc(m,(m|0)<0|0?-1:0,3e4,0)|0;m=c[b+4>>2]|0;d=c[m+104>>2]|0;f=Erc(i,G,d,(d|0)<0|0?-1:0)|0;d=G;i=c[m+108>>2]|0;m=Erc(i,(i|0)<0|0?-1:0,1001,0)|0;i=Crc(f,d,m,G)|0;m=i&31;if((j|0)>5){n=j-5|0;o=k<<5|m;p=l}else{i=l;y=je(m>>>((5-j|0)>>>0)|k<<j|0)|0;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;i=(c[e>>2]|0)+4|0;c[e>>2]=i;n=j+27|0;o=m;p=i}c[g>>2]=o;c[h>>2]=n;if((n|0)>1){q=n-1|0;r=o<<1;s=p}else{i=p;y=je(o<<n|0)|0;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;i=(c[e>>2]|0)+4|0;c[e>>2]=i;q=n+31|0;r=0;s=i}c[g>>2]=r;c[h>>2]=q;if((q|0)>1){t=q-1|0;u=r<<1;v=s}else{i=s;y=je(r<<q|0)|0;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;i=(c[e>>2]|0)+4|0;c[e>>2]=i;t=q+31|0;u=0;v=i}c[g>>2]=u;c[h>>2]=t;if((t|0)>1){w=t-1|0;x=u<<1;z=v}else{i=v;y=je(u<<t|0)|0;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;i=(c[e>>2]|0)+4|0;c[e>>2]=i;w=t+31|0;x=0;z=i}c[g>>2]=x;c[h>>2]=w;i=c[b+8>>2]|0;t=c[b+12>>2]|0;if((i|0)==176&(t|0)==144){A=0}else{A=(i|0)==352&(t|0)==288?1:-1}if((w|0)>1){B=w-1|0;C=x<<1|A;D=z}else{t=z;y=je(A>>>((1-w|0)>>>0)|x<<w|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[e>>2]|0)+4|0;c[e>>2]=t;B=w+31|0;C=A;D=t}c[g>>2]=C;c[h>>2]=B;if((B|0)>1){E=B-1|0;F=C<<1;H=D}else{t=D;y=je(C<<B|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[e>>2]|0)+4|0;c[e>>2]=t;E=B+31|0;F=0;H=t}c[g>>2]=F;c[h>>2]=E;if((E|0)>1){I=E-1|0;J=F<<1;K=H}else{t=H;y=je(F<<E|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[e>>2]|0)+4|0;c[e>>2]=t;I=E+31|0;J=0;K=t}c[g>>2]=J;c[h>>2]=I;if((I|0)>1){L=I-1|0;M=J<<1;c[g>>2]=M;c[h>>2]=L;N=(A|0)==0;O=b+14692|0;P=N<<31>>31;c[O>>2]=P;Q=b+12484|0;c[Q>>2]=0;return}else{t=K;y=je(J<<I|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[e>>2]=(c[e>>2]|0)+4;L=I+31|0;M=0;c[g>>2]=M;c[h>>2]=L;N=(A|0)==0;O=b+14692|0;P=N<<31>>31;c[O>>2]=P;Q=b+12484|0;c[Q>>2]=0;return}}function Kga(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;d=b+12476|0;e=b+12480|0;f=(ca(c[b+116>>2]|0,c[e>>2]|0)|0)+(c[d>>2]|0)|0;g=(f|0)%11|0;if((g|0)==0){if(((f|0)%33|0|0)==0){h=b+14692|0;i=((c[b+8>>2]|0)==176&(c[b+12>>2]|0)==144?2:1)+(c[h>>2]|0)|0;c[h>>2]=i;j=b+784|0;k=c[j>>2]|0;l=b+788|0;m=c[l>>2]|0;if((m|0)>16){n=m-16|0;o=k<<16|1;p=i}else{i=je(1>>>((16-m|0)>>>0)|k<<m|0)|0;k=b+796|0;q=c[k>>2]|0;y=i;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;n=m+16|0;o=1;p=c[h>>2]|0}c[j>>2]=o;c[l>>2]=n;if((n|0)>4){r=n-4|0;s=o<<4|p}else{h=je(p>>>((4-n|0)>>>0)|o<<n|0)|0;o=b+796|0;m=c[o>>2]|0;y=h;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;r=n+28|0;s=p}c[j>>2]=s;c[l>>2]=r;p=c[b+9960>>2]|0;if((r|0)>5){t=r-5|0;u=p|s<<5}else{n=je(p>>>((5-r|0)>>>0)|s<<r|0)|0;s=b+796|0;o=c[s>>2]|0;y=n;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;t=r+27|0;u=p}c[j>>2]=u;c[l>>2]=t;if((t|0)>1){v=t-1|0;w=u<<1}else{p=je(u<<t|0)|0;u=b+796|0;r=c[u>>2]|0;y=p;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+31|0;w=0}c[j>>2]=w;c[l>>2]=v;c[b+12484>>2]=0;v=b+11824|0;c[v>>2]=0;l=b+11828|0;c[l>>2]=0;x=v;z=l}else{x=b+11824|0;z=b+11828|0}c[x>>2]=0;c[z>>2]=0}z=c[b+8>>2]|0;x=c[b+12>>2]|0;if((z|0)==176&(x|0)==144){return}if(!((z|0)==352&(x|0)==288)){return}c[d>>2]=g+((((f|0)/33|0|0)%2|0)*11|0);c[e>>2]=(((f|0)/11|0|0)%3|0)+(((f|0)/66|0)*3|0);NTa(b);f=8>>>((c[(c[b+4>>2]|0)+800>>2]|0)>>>0);e=b+12496|0;c[e>>2]=(c[e>>2]|0)+2;e=b+12500|0;c[e>>2]=(c[e>>2]|0)+2;e=b+12504|0;c[e>>2]=(c[e>>2]|0)+2;e=b+12508|0;c[e>>2]=(c[e>>2]|0)+2;e=b+12512|0;c[e>>2]=(c[e>>2]|0)+1;e=b+12516|0;c[e>>2]=(c[e>>2]|0)+1;e=b+12544|0;c[e>>2]=(c[e>>2]|0)+(f<<1);e=b+12548|0;c[e>>2]=(c[e>>2]|0)+f;e=b+12552|0;c[e>>2]=(c[e>>2]|0)+f;return}function Lga(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;j=f;k=f+14680|0;c[k>>2]=0;l=f+12488|0;m=c[l>>2]|0;do{if((m|0)==0){n=(c[f+180>>2]>>31)+32&-32;o=(c[f+184>>2]|0)>-1?n|16:n;n=(c[f+188>>2]|0)>-1?o|8:o;o=(c[f+192>>2]|0)>-1?n|4:n;n=((c[f+196>>2]|0)>-1?o|2:o)|(c[f+200>>2]|0)>>>31^1;o=i|h;if((c[f+9984>>2]|o|n|0)!=0){p=n;q=o;break}o=f+13692|0;c[o>>2]=(c[o>>2]|0)+1;o=f+12484|0;c[o>>2]=(c[o>>2]|0)+1;c[f+11824>>2]=0;c[f+11828>>2]=0;return}else{p=63;q=0}}while(0);o=f+12484|0;n=c[o>>2]|0;r=d[1379992+n|0]|0;s=d[1379952+n|0]|0;n=f+784|0;t=c[n>>2]|0;u=f+788|0;v=c[u>>2]|0;if((v|0)>(r|0)){w=v-r|0;x=t<<r|s;z=m}else{m=je(s>>>((r-v|0)>>>0)|t<<v|0)|0;t=f+796|0;A=c[t>>2]|0;y=m;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;w=32-r+v|0;x=s;z=c[l>>2]|0}c[n>>2]=x;c[u>>2]=w;c[o>>2]=0;do{if((z|0)==0){o=c[k>>2]|0;s=o+1|0;c[k>>2]=s;v=c[f+13836>>2]|0;do{if((q|0)==0){if((v|0)==0){B=s;break}r=o+4|0;c[k>>2]=r;C=r;D=12}else{r=o+4|0;c[k>>2]=r;if((v|0)==0){B=r}else{C=r;D=12}}}while(0);if((D|0)==12){v=C+3|0;c[k>>2]=v;B=v}if((p|0)==0){if((c[f+9984>>2]|0)==0){break}}c[k>>2]=B+1}}while(0);B=f+9984|0;C=c[k>>2]|0;if((c[B>>2]|0)==0){E=C}else{q=C+1|0;c[k>>2]=q;E=q}q=d[1379936+E|0]|0;C=d[1379920+E|0]|0;if((w|0)>(q|0)){F=w-q|0;G=x<<q|C;H=E}else{E=je(C>>>((q-w|0)>>>0)|x<<w|0)|0;x=f+796|0;z=c[x>>2]|0;y=E;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;F=32-q+w|0;G=C;H=c[k>>2]|0}c[n>>2]=G;c[u>>2]=F;C=c[1379880+(H<<2)>>2]|0;c[k>>2]=C;if((C&65536|0)==0){I=C;J=G;K=F}else{F=f+9960|0;QTa(f,(c[B>>2]|0)+(c[F>>2]|0)|0);B=c[F>>2]|0;F=c[n>>2]|0;G=c[u>>2]|0;if((G|0)>5){L=G-5|0;M=F<<5|B}else{C=je(B>>>((5-G|0)>>>0)|F<<G|0)|0;F=f+796|0;H=c[F>>2]|0;y=C;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[F>>2]=(c[F>>2]|0)+4;L=G+27|0;M=B}c[n>>2]=M;c[u>>2]=L;I=c[k>>2]|0;J=M;K=L}do{if((I&8|0)==0){N=J;O=K}else{L=h>>1;M=f+11824|0;B=c[M>>2]|0;G=L-B|0;F=i>>1;H=f+11828|0;C=c[H>>2]|0;w=F-C|0;c[M>>2]=L;c[H>>2]=F;do{if((L|0)==(B|0)){H=d[1379753]|0;M=d[1379752]|0;if((K|0)>(H|0)){P=K-H|0;Q=J<<H|M;break}else{q=je(M>>>((H-K|0)>>>0)|J<<K|0)|0;x=f+796|0;z=c[x>>2]|0;y=q;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;P=32-H+K|0;Q=M;break}}else{M=(G|0)>15?G-32|0:G;H=(M|0)<-16?M+32|0:M;M=H>>>31;x=(H|0)<0?-H|0:H;H=d[1379753+(x<<1)|0]|0;z=d[1379752+(x<<1)|0]|0;if((K|0)>(H|0)){R=K-H|0;S=J<<H|z}else{x=je(z>>>((H-K|0)>>>0)|J<<K|0)|0;q=f+796|0;E=c[q>>2]|0;y=x;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;R=32-H+K|0;S=z}c[n>>2]=S;c[u>>2]=R;if((R|0)>1){P=R-1|0;Q=S<<1|M;break}else{z=je(M>>>((1-R|0)>>>0)|S<<R|0)|0;H=f+796|0;q=c[H>>2]|0;y=z;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;P=R+31|0;Q=M;break}}}while(0);c[n>>2]=Q;c[u>>2]=P;if((F|0)==(C|0)){G=d[1379753]|0;B=d[1379752]|0;if((P|0)>(G|0)){T=P-G|0;U=Q<<G|B}else{L=je(B>>>((G-P|0)>>>0)|Q<<P|0)|0;M=f+796|0;H=c[M>>2]|0;y=L;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[M>>2]=(c[M>>2]|0)+4;T=32-G+P|0;U=B}c[n>>2]=U;c[u>>2]=T;N=U;O=T;break}B=(w|0)>15?w-32|0:w;G=(B|0)<-16?B+32|0:B;B=G>>>31;M=(G|0)<0?-G|0:G;G=d[1379753+(M<<1)|0]|0;H=d[1379752+(M<<1)|0]|0;if((P|0)>(G|0)){V=P-G|0;W=Q<<G|H}else{M=je(H>>>((G-P|0)>>>0)|Q<<P|0)|0;L=f+796|0;q=c[L>>2]|0;y=M;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[L>>2]=(c[L>>2]|0)+4;V=32-G+P|0;W=H}c[n>>2]=W;c[u>>2]=V;if((V|0)>1){X=V-1|0;Y=W<<1|B}else{H=je(B>>>((1-V|0)>>>0)|W<<V|0)|0;G=f+796|0;L=c[G>>2]|0;y=H;a[L]=y;y=y>>8;a[L+1|0]=y;y=y>>8;a[L+2|0]=y;y=y>>8;a[L+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;X=V+31|0;Y=B}c[n>>2]=Y;c[u>>2]=X;N=Y;O=X}}while(0);if((c[k>>2]&131072|0)==0){Z=O;_=N}else{X=p-1|0;p=d[1380329+(X<<1)|0]|0;Y=d[1380328+(X<<1)|0]|0;if((O|0)>(p|0)){$=O-p|0;aa=N<<p|Y}else{X=je(Y>>>((p-O|0)>>>0)|N<<O|0)|0;N=f+796|0;V=c[N>>2]|0;y=X;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;$=32-p+O|0;aa=Y}c[n>>2]=aa;c[u>>2]=$;Z=$;_=aa}aa=f+796|0;$=f+784|0;Y=0;O=Z;Z=_;while(1){_=g+(Y<<7)|0;p=b[_>>1]|0;N=p<<16>>16;a:do{if((c[l>>2]|0)==0){if(!((p<<16>>16|0)==1|(p<<16>>16|0)==(-1|0))){ba=0;ca=O;da=Z;break}if(!((c[j+180+(Y<<2)>>2]|0)>-1)){ba=0;ca=O;da=Z;break}V=p<<16>>16>0?2:3;if((O|0)>2){ea=O-2|0;fa=Z<<2|V}else{X=je(V>>>((2-O|0)>>>0)|Z<<O|0)|0;W=c[aa>>2]|0;y=X;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;c[aa>>2]=(c[aa>>2]|0)+4;ea=O+30|0;fa=V}c[n>>2]=fa;c[u>>2]=ea;ba=1;ca=ea;da=fa}else{do{if(p<<16>>16>254){ga=254;ha=254;D=58}else{if(p<<16>>16<1){ga=1;ha=1;D=58;break}if(!(p<<16>>16==128)){ia=N;ja=Z;ka=O;la=f+788|0;break}if((O|0)>8){ma=O-8|0;na=Z<<8|255}else{V=je(255>>>((8-O|0)>>>0)|Z<<O|0)|0;W=c[aa>>2]|0;y=V;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;c[aa>>2]=(c[aa>>2]|0)+4;ma=O+24|0;na=255}c[$>>2]=na;c[u>>2]=ma;ba=1;ca=ma;da=na;break a}}while(0);if((D|0)==58){D=0;b[_>>1]=ha;W=f+788|0;ia=ga;ja=c[$>>2]|0;ka=c[W>>2]|0;la=W}if((ka|0)>8){oa=ka-8|0;pa=ja<<8|ia}else{W=je(ia>>>((8-ka|0)>>>0)|ja<<ka|0)|0;V=f+796|0;X=c[V>>2]|0;y=W;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;c[V>>2]=(c[V>>2]|0)+4;oa=ka+24|0;pa=ia}c[$>>2]=pa;c[la>>2]=oa;ba=1;ca=oa;da=pa}}while(0);_=c[j+180+(Y<<2)>>2]|0;if((ba|0)>(_|0)){qa=ca;ra=da}else{N=ba-1|0;p=ba;w=ca;C=da;while(1){F=b[g+(Y<<7)+(d[j+368+p|0]<<1)>>1]|0;V=F<<16>>16;do{if(F<<16>>16==0){sa=N;ta=w;ua=C}else{X=p-N-1|0;W=(F&65535)>>>15&65535;P=F<<16>>16<0?-V|0:V;Q=d[(c[344895]|0)+X|0]|0;T=c[344890]|0;do{if((Q|0)<(T|0)){if((a[(c[344897]|0)+X|0]|0)<(P|0)){va=T;break}va=P-1+Q|0}else{va=T}}while(0);T=va+((X|0)==0&(P|0)<16&1)|0;Q=c[344892]|0;U=e[Q+(T<<2)+2>>1]|0;R=e[Q+(T<<2)>>1]|0;if((w|0)>(U|0)){wa=w-U|0;xa=C<<U|R}else{Q=je(R>>>((U-w|0)>>>0)|C<<w|0)|0;S=c[aa>>2]|0;y=Q;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;c[aa>>2]=(c[aa>>2]|0)+4;wa=32-U+w|0;xa=R}c[n>>2]=xa;c[u>>2]=wa;if((T|0)!=(c[344890]|0)){if((wa|0)>1){ya=wa-1|0;za=xa<<1|W}else{T=je(W>>>((1-wa|0)>>>0)|xa<<wa|0)|0;R=c[aa>>2]|0;y=T;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[aa>>2]=(c[aa>>2]|0)+4;ya=wa+31|0;za=W}c[n>>2]=za;c[u>>2]=ya;sa=p;ta=ya;ua=za;break}if((wa|0)>6){Aa=wa-6|0;Ba=xa<<6|X}else{R=je(X>>>((6-wa|0)>>>0)|xa<<wa|0)|0;T=c[aa>>2]|0;y=R;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[aa>>2]=(c[aa>>2]|0)+4;Aa=wa+26|0;Ba=X}c[n>>2]=Ba;c[u>>2]=Aa;T=V&255;if((Aa|0)>8){Ca=Aa-8|0;Da=Ba<<8|T}else{R=je(T>>>((8-Aa|0)>>>0)|Ba<<Aa|0)|0;U=c[aa>>2]|0;y=R;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;c[aa>>2]=(c[aa>>2]|0)+4;Ca=Aa+24|0;Da=T}c[n>>2]=Da;c[u>>2]=Ca;sa=p;ta=Ca;ua=Da}}while(0);V=p+1|0;if((V|0)>(_|0)){qa=ta;ra=ua;break}else{N=sa;p=V;w=ta;C=ua}}}if((_|0)>-1){C=c[344892]|0;w=e[C+2>>1]|0;p=e[C>>1]|0;if((qa|0)>(w|0)){Ea=qa-w|0;Fa=ra<<w|p}else{C=je(p>>>((w-qa|0)>>>0)|ra<<qa|0)|0;N=c[aa>>2]|0;y=C;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[aa>>2]=(c[aa>>2]|0)+4;Ea=32-w+qa|0;Fa=p}c[n>>2]=Fa;c[u>>2]=Ea;Ga=Ea;Ha=Fa}else{Ga=qa;Ha=ra}p=Y+1|0;if((p|0)<6){Y=p;O=Ga;Z=Ha}else{break}}if((c[k>>2]&8|0)!=0){return}c[f+11824>>2]=0;c[f+11828>>2]=0;return}function Mga(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;Vpb();c[f+13080>>2]=-127;c[f+13084>>2]=127;c[f+9892>>2]=1347360;c[f+9888>>2]=1347360;c[f+13088>>2]=20;g=-64;while(1){if((g|0)==0){g=1;continue}h=g+64|0;i=(g|0)<0?-g|0:g;j=i-1|0;k=c[344895]|0;l=c[344890]|0;m=0;do{n=h+(m<<7)|0;o=3602160+n|0;a[o]=100;p=k+m|0;q=d[p]|0;do{if((q|0)<(l|0)){if((a[(c[344897]|0)+m|0]|0)<(i|0)){r=6;break}s=q+j|0;t=c[344892]|0;u=(e[t+(s<<2)+2>>1]|0)+1|0;if(!((s|0)!=(l|0)&u>>>0<100>>>0)){v=100;w=t;break}a[o]=u;v=u&255;w=t}else{r=6}}while(0);if((r|0)==6){r=0;v=100;w=c[344892]|0}q=w+(l<<2)+2|0;t=b[q>>1]|0;if((t&65535)>>>0<v>>>0){a[o]=t}t=n+3610352|0;a[t]=100;u=d[p]|0;do{if((u|0)<(l|0)){if((a[(c[344897]|0)+m|0]|0)<(i|0)){x=100;break}s=u+j|0;y=(e[w+(s<<2)+2>>1]|0)+3|0;if(!((s|0)!=(l|0)&y>>>0<100>>>0)){x=100;break}a[t]=y;x=y&255}else{x=100}}while(0);u=(e[q>>1]|0)+2|0;if(u>>>0<x>>>0){a[t]=u}m=m+1|0;}while((m|0)<64);g=g+1|0;if((g|0)>=64){break}}c[f+13100>>2]=3602160;c[f+13092>>2]=3602160;c[f+13104>>2]=3610352;c[f+13096>>2]=3610352;return}function Nga(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=ca(c[d+124>>2]|0,c[d+12480>>2]|0)|0;f=e+(c[d+12476>>2]|0)|0;e=c[d+128>>2]|0;g=c[d+12496>>2]|0;a[(c[d+9168>>2]|0)+f|0]=c[d+9924>>2];h=d+11740|0;i=c[h>>2]|0;if((i|0)!=1){do{if((c[d+12488>>2]|0)==0){j=c[d+11744>>2]|0;if((i|0)==0){k=c[d+11748>>2]&65535;l=j&65535;break}else{m=c[d+11752>>2]|0;n=m+j|0;o=c[d+11748>>2]|0;p=c[d+11756>>2]|0;q=c[d+11660>>2]|0;b[q+(f<<2)>>1]=j;b[q+(f<<2)+2>>1]=o;q=c[d+11668>>2]|0;b[q+(f<<2)>>1]=m;b[q+(f<<2)+2>>1]=p;q=c[d+11808>>2]&255;m=f<<2;j=d+9180|0;a[(c[j>>2]|0)+(m|1)|0]=q;a[(c[j>>2]|0)+m|0]=q;q=c[d+11812>>2]&255;a[(c[j>>2]|0)+(m|3)|0]=q;a[(c[j>>2]|0)+(m|2)|0]=q;k=p+o&65535;l=(n>>>1|n&1)&65535;break}}else{k=0;l=0}}while(0);i=c[d+9148>>2]|0;b[i+(g<<2)>>1]=l;b[i+(g<<2)+2>>1]=k;n=g+1|0;b[i+(n<<2)>>1]=l;b[i+(n<<2)+2>>1]=k;o=g+e|0;b[i+(o<<2)>>1]=l;b[i+(o<<2)+2>>1]=k;o=n+e|0;b[i+(o<<2)>>1]=l;b[i+(o<<2)+2>>1]=k}if((c[d+56>>2]|0)==0){return}if((c[h>>2]|0)==1){c[(c[d+9160>>2]|0)+(f<<2)>>2]=12352;return}h=(c[d+9160>>2]|0)+(f<<2)|0;if((c[d+12488>>2]|0)==0){c[h>>2]=12296;return}else{c[h>>2]=1;return}}function Oga(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[a+12476>>2]|0;if((d|0)<4){g=a+9876|0;h=a+128|0;i=c[a+12480>>2]<<1|d>>>1&1;j=f<<1|d&1}else{g=a+9876+(d-3<<2)|0;h=a+124|0;i=c[a+12480>>2]|0;j=f}k=c[g>>2]|0;g=c[h>>2]|0;h=ca(g,i)|0;l=b[k+(j-1+h<<1)>>1]|0;m=b[k+((ca(g,i-1|0)|0)+j<<1)>>1]|0;do{if((c[a+14084>>2]|0)==0|(d|0)==3){n=m;o=l}else{i=(d|0)==2?m:1024;if((d|0)==1){n=i;o=l;break}n=i;o=(f|0)==(c[a+13704>>2]|0)?1024:l}}while(0);l=(o|0)!=1024;if((n|0)==1024|l^1){p=l?o:n;q=h+j|0;r=k+(q<<1)|0;c[e>>2]=r;return p|0}else{p=n+o>>1;q=h+j|0;r=k+(q<<1)|0;c[e>>2]=r;return p|0}return 0}function Pga(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[b+148>>2]|0;f=c[b+152>>2]|0;g=b+12480|0;h=c[g>>2]|0;i=b+124|0;j=ca(c[i>>2]|0,h)|0;k=b+12476|0;l=j+(c[k>>2]|0)|0;j=c[b+12544>>2]|0;m=c[b+12548>>2]|0;n=c[b+12552>>2]|0;o=b+9160|0;if((c[(c[o>>2]|0)+(l<<2)>>2]&2048|0)==0){p=c[b+9960>>2]|0;q=b+11552|0;r=e<<3;ef[c[q>>2]&4095](j+r|0,e,p);ef[c[q>>2]&4095](j+(r+8)|0,e,p);s=p;t=c[g>>2]|0}else{s=0;t=h}do{if((t|0)!=0){h=l-(c[i>>2]|0)|0;if((c[(c[o>>2]|0)+(h<<2)>>2]&2048|0)==0){u=a[(c[b+9136>>2]|0)+h|0]|0}else{u=0}h=(s|0)==0?u:s;if((h|0)!=0){p=d[(c[b+9896>>2]|0)+h|0]|0;r=b+11552|0;ef[c[r>>2]&4095](j,e,h);ef[c[r>>2]&4095](j+8|0,e,h);ef[c[r>>2]&4095](m,f,p);ef[c[r>>2]&4095](n,f,p)}p=(u|0)!=0;if(p){ef[c[b+11548>>2]&4095](j+(8-(e<<3))|0,e,u)}if((c[k>>2]|0)==0){break}if(p){v=u}else{p=l-1-(c[i>>2]|0)|0;if((c[(c[o>>2]|0)+(p<<2)>>2]&2048|0)!=0){break}r=a[(c[b+9136>>2]|0)+p|0]|0;if(r<<24>>24==0){break}else{v=r<<24>>24}}r=d[(c[b+9896>>2]|0)+v|0]|0;p=b+11548|0;ef[c[p>>2]&4095](j+(-(e<<3)|0)|0,e,v);h=-(f<<3)|0;ef[c[p>>2]&4095](m+h|0,f,r);ef[c[p>>2]&4095](n+h|0,f,r)}}while(0);v=(s|0)!=0;do{if(v){i=b+11548|0;ef[c[i>>2]&4095](j+8|0,e,s);if(((c[g>>2]|0)+1|0)!=(c[b+120>>2]|0)){break}ef[c[i>>2]&4095](j+((e<<3)+8)|0,e,s)}}while(0);if((c[k>>2]|0)==0){return}do{if(v){w=s}else{k=l-1|0;if((c[(c[o>>2]|0)+(k<<2)>>2]&2048|0)!=0){return}i=a[(c[b+9136>>2]|0)+k|0]|0;if(!(i<<24>>24==0)){w=i<<24>>24;break}return}}while(0);o=b+11548|0;ef[c[o>>2]&4095](j,e,w);if(((c[g>>2]|0)+1|0)!=(c[b+120>>2]|0)){return}g=d[(c[b+9896>>2]|0)+w|0]|0;ef[c[o>>2]&4095](j+(e<<3)|0,e,w);ef[c[o>>2]&4095](m,f,g);ef[c[o>>2]&4095](n,f,g);return}function Qga(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=c[a+12476>>2]|0;if((f|0)<4){h=g<<1|f&1;i=a+9912|0;j=a+9876|0;k=a+168|0;l=a+128|0;m=(c[a+12480>>2]<<1)+(f>>1)|0}else{n=f-3|0;h=g;i=a+9912+(n<<2)|0;j=a+9876+(n<<2)|0;k=a+172|0;l=a+124|0;m=c[a+12480>>2]|0}n=c[i>>2]|0;i=c[j>>2]|0;j=c[k>>2]|0;k=c[l>>2]|0;l=ca(k,m)|0;o=l+h|0;p=o<<4;q=b[i+(h-1+l<<1)>>1]|0;l=b[i+((ca(k,m-1|0)|0)+h<<1)>>1]|0;do{if((c[a+14084>>2]|0)==0|(f|0)==3){r=l;s=q}else{h=(f|0)==2?l:1024;if((f|0)==1){r=h;s=q;break}r=h;s=(g|0)==(c[a+13704>>2]|0)?1024:q}}while(0);do{if((c[a+176>>2]|0)==0){q=(s|0)!=1024;if((r|0)==1024|q^1){t=q?s:r;break}else{t=r+s>>1;break}}else{if((c[a+13820>>2]|0)==0){if((r|0)==1024){t=1024;break}q=(-(k<<4)|8)+p|0;g=e+(d[a+11185|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|1)<<1)>>1]|0);g=e+(d[a+11186|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|2)<<1)>>1]|0);g=e+(d[a+11187|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|3)<<1)>>1]|0);g=e+(d[a+11188|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|4)<<1)>>1]|0);g=e+(d[a+11189|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|5)<<1)>>1]|0);g=e+(d[a+11190|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|6)<<1)>>1]|0);g=e+(d[a+11191|0]<<1)|0;b[g>>1]=(b[g>>1]|0)+(b[n+((q|7)<<1)>>1]|0);t=r;break}else{if((s|0)==1024){t=1024;break}q=e+(d[a+11192|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-15<<1)>>1]|0);q=e+(d[a+11200|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-14<<1)>>1]|0);q=e+(d[a+11208|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-13<<1)>>1]|0);q=e+(d[a+11216|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-12<<1)>>1]|0);q=e+(d[a+11224|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-11<<1)>>1]|0);q=e+(d[a+11232|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-10<<1)>>1]|0);q=e+(d[a+11240|0]<<1)|0;b[q>>1]=(b[q>>1]|0)+(b[n+(p-9<<1)>>1]|0);t=s;break}}}while(0);s=(ca(b[e>>1]|0,j)|0)+t&65535;t=s<<16>>16<0?0:s|1;b[e>>1]=t;b[i+(o<<1)>>1]=t;b[n+((p|1)<<1)>>1]=b[e+(d[a+11192|0]<<1)>>1]|0;b[n+((p|2)<<1)>>1]=b[e+(d[a+11200|0]<<1)>>1]|0;b[n+((p|3)<<1)>>1]=b[e+(d[a+11208|0]<<1)>>1]|0;b[n+((p|4)<<1)>>1]=b[e+(d[a+11216|0]<<1)>>1]|0;b[n+((p|5)<<1)>>1]=b[e+(d[a+11224|0]<<1)>>1]|0;b[n+((p|6)<<1)>>1]=b[e+(d[a+11232|0]<<1)>>1]|0;b[n+((p|7)<<1)>>1]=b[e+(d[a+11240|0]<<1)>>1]|0;b[n+((p|9)<<1)>>1]=b[e+(d[a+11185|0]<<1)>>1]|0;b[n+((p|10)<<1)>>1]=b[e+(d[a+11186|0]<<1)>>1]|0;b[n+((p|11)<<1)>>1]=b[e+(d[a+11187|0]<<1)>>1]|0;b[n+((p|12)<<1)>>1]=b[e+(d[a+11188|0]<<1)>>1]|0;b[n+((p|13)<<1)>>1]=b[e+(d[a+11189|0]<<1)>>1]|0;b[n+((p|14)<<1)>>1]=b[e+(d[a+11190|0]<<1)>>1]|0;b[n+((p|15)<<1)>>1]=b[e+(d[a+11191|0]<<1)>>1]|0;return}function Rga(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=c[a+128>>2]|0;i=c[a+9148+(e<<2)>>2]|0;e=c[a+12496+(d<<2)>>2]|0;j=e-1|0;k=i+(j<<2)|0;if(!((c[a+14084>>2]|0)!=0&(d|0)<3)){l=e-h|0;m=(c[1378720+(d<<2)>>2]|0)-h+e|0;n=b[k>>1]|0;o=n<<16>>16;p=b[i+(l<<2)>>1]|0;q=p<<16>>16;r=b[i+(m<<2)>>1]|0;s=r<<16>>16;do{if(n<<16>>16>p<<16>>16){if(!(r<<16>>16>p<<16>>16)){t=q;break}t=(s|0)>(o|0)?o:s}else{if(!(p<<16>>16>r<<16>>16)){t=q;break}t=(s|0)>(o|0)?s:o}}while(0);c[f>>2]=t;t=b[i+(j<<2)+2>>1]|0;o=t<<16>>16;s=b[i+(l<<2)+2>>1]|0;l=s<<16>>16;q=b[i+(m<<2)+2>>1]|0;m=q<<16>>16;do{if(t<<16>>16>s<<16>>16){if(!(q<<16>>16>s<<16>>16)){u=l;break}u=(m|0)>(o|0)?o:m}else{if(!(s<<16>>16>q<<16>>16)){u=l;break}u=(m|0)>(o|0)?m:o}}while(0);c[g>>2]=u;v=i+(e<<2)|0;return v|0}if((d|0)==0){u=c[a+12476>>2]|0;o=c[a+13704>>2]|0;if((u|0)==(o|0)){c[g>>2]=0;c[f>>2]=0;v=i+(e<<2)|0;return v|0}do{if((u+1|0)==(o|0)){if((c[a+32>>2]|0)==0){break}m=2-h+e|0;l=i+(m<<2)|0;if((u|0)==0){c[f>>2]=b[l>>1]|0;c[g>>2]=b[i+(m<<2)+2>>1]|0;v=i+(e<<2)|0;return v|0}q=b[k>>1]|0;s=q<<16>>16;t=b[l>>1]|0;l=t<<16>>16;do{if(q<<16>>16>0){if(!(t<<16>>16>0)){w=0;break}w=(l|0)>(s|0)?s:l}else{if(!(t<<16>>16<0)){w=0;break}w=(l|0)>(s|0)?l:s}}while(0);c[f>>2]=w;s=b[i+(j<<2)+2>>1]|0;l=s<<16>>16;t=b[i+(m<<2)+2>>1]|0;q=t<<16>>16;do{if(s<<16>>16>0){if(!(t<<16>>16>0)){x=0;break}x=(q|0)>(l|0)?l:q}else{if(!(t<<16>>16<0)){x=0;break}x=(q|0)>(l|0)?q:l}}while(0);c[g>>2]=x;v=i+(e<<2)|0;return v|0}}while(0);c[f>>2]=b[k>>1]|0;c[g>>2]=b[i+(j<<2)+2>>1]|0;v=i+(e<<2)|0;return v|0}else if((d|0)==1){do{if(((c[a+12476>>2]|0)+1|0)==(c[a+13704>>2]|0)){if((c[a+32>>2]|0)==0){break}x=1-h+e|0;w=b[k>>1]|0;u=w<<16>>16;o=b[i+(x<<2)>>1]|0;l=o<<16>>16;do{if(w<<16>>16>0){if(!(o<<16>>16>0)){y=0;break}y=(l|0)>(u|0)?u:l}else{if(!(o<<16>>16<0)){y=0;break}y=(l|0)>(u|0)?l:u}}while(0);c[f>>2]=y;u=b[i+(j<<2)+2>>1]|0;l=u<<16>>16;o=b[i+(x<<2)+2>>1]|0;w=o<<16>>16;do{if(u<<16>>16>0){if(!(o<<16>>16>0)){z=0;break}z=(w|0)>(l|0)?l:w}else{if(!(o<<16>>16<0)){z=0;break}z=(w|0)>(l|0)?w:l}}while(0);c[g>>2]=z;v=i+(e<<2)|0;return v|0}}while(0);c[f>>2]=b[k>>1]|0;c[g>>2]=b[i+(j<<2)+2>>1]|0;v=i+(e<<2)|0;return v|0}else{z=e-h|0;y=(c[1378720+(d<<2)>>2]|0)-h+e|0;if((c[a+12476>>2]|0)==(c[a+13704>>2]|0)){b[i+(j<<2)+2>>1]=0;b[k>>1]=0;A=0}else{A=b[k>>1]|0}k=A<<16>>16;a=b[i+(z<<2)>>1]|0;h=a<<16>>16;d=b[i+(y<<2)>>1]|0;l=d<<16>>16;do{if(A<<16>>16>a<<16>>16){if(!(d<<16>>16>a<<16>>16)){B=h;break}B=(l|0)>(k|0)?k:l}else{if(!(a<<16>>16>d<<16>>16)){B=h;break}B=(l|0)>(k|0)?l:k}}while(0);c[f>>2]=B;B=b[i+(j<<2)+2>>1]|0;j=B<<16>>16;f=b[i+(z<<2)+2>>1]|0;z=f<<16>>16;k=b[i+(y<<2)+2>>1]|0;y=k<<16>>16;do{if(B<<16>>16>f<<16>>16){if(!(k<<16>>16>f<<16>>16)){C=z;break}C=(y|0)>(j|0)?j:y}else{if(!(f<<16>>16>k<<16>>16)){C=z;break}C=(y|0)>(j|0)?y:j}}while(0);c[g>>2]=C;v=i+(e<<2)|0;return v|0}return 0}function Sga(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)<401){d=1;return d|0}d=(b|0)<801?2:4;return d|0}function Tga(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=a+20|0;g=c[f>>2]|0;h=a+16|0;a=c[h>>2]|0;a:do{if((g|0)==0){i=a;j=0;while(1){if((j|0)>=(e|0)){k=i;l=0;break a}m=d[b+j|0]|0|i<<8;n=j+1|0;if((i&16777212|0)==128){o=m;p=n;q=1;r=4;break}else{i=m;j=n}}}else{o=a;p=0;q=g;r=4}}while(0);b:do{if((r|0)==4){if((p|0)<(e|0)){s=p;t=o}else{k=o;l=q;break}while(1){if((t&16777212|0)==128){break}g=d[b+s|0]|0|t<<8;a=s+1|0;if((a|0)<(e|0)){s=a;t=g}else{k=g;l=q;break b}}c[f>>2]=0;c[h>>2]=-1;u=s-3|0;return u|0}}while(0);c[f>>2]=l;c[h>>2]=k;u=-100;return u|0}function Uga(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;i=i+16|0;j=b|0;k=b+8|0;c[j>>2]=g;c[k>>2]=h;l=c[a>>2]|0;m=l;do{if((c[a+176>>2]&1|0)==0){n=l+20|0;o=c[n>>2]|0;p=l+16|0;q=c[p>>2]|0;a:do{if((o|0)==0){r=q;s=0;while(1){if((s|0)>=(h|0)){t=r;u=0;v=9;break a}w=d[g+s|0]|0|r<<8;x=s+1|0;if((r&16777212|0)==128){y=w;z=x;A=1;v=5;break}else{r=w;s=x}}}else{y=q;z=0;A=o;v=5}}while(0);b:do{if((v|0)==5){if((z|0)<(h|0)){B=z;C=y}else{t=y;u=A;v=9;break}while(1){if((C&16777212|0)==128){break}o=d[g+B|0]|0|C<<8;q=B+1|0;if((q|0)<(h|0)){B=q;C=o}else{t=o;u=A;v=9;break b}}c[n>>2]=0;c[p>>2]=-1;D=B-3|0}}while(0);if((v|0)==9){c[n>>2]=u;c[p>>2]=t;D=-100}if((IWa(m,D,j,k)|0)>=0){E=D;F=c[j>>2]|0;G=c[k>>2]|0;break}c[e>>2]=0;c[f>>2]=0;H=c[k>>2]|0;i=b;return H|0}else{E=h;F=g;G=h}}while(0);c[e>>2]=F;c[f>>2]=G;H=E;i=b;return H|0}function Vga(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[b+60>>2]|0;f=e;c[e+4>>2]=b;c[e+28>>2]=2;c[e+8>>2]=c[b+128>>2];c[e+12>>2]=c[b+132>>2];c[e+84>>2]=c[b+676>>2];uTa(f);c[e+13920>>2]=5;c[e+14348>>2]=900;c[e+13944>>2]=1;g=b+12|0;h=c[g>>2]|0;a:do{if((c[h+12>>2]|0)==168){c[b+140>>2]=0;c[e+10048>>2]=1;j=168;k=10}else{c[b+140>>2]=We[c[b+152>>2]&2047](b,c[h+24>>2]|0)|0;l=c[(c[g>>2]|0)+12>>2]|0;m=e+10048|0;c[m>>2]=1;switch(l|0){case 17:{c[e+32>>2]=1;c[e+14092>>2]=3;n=17;break a;break};case 16:{c[e+32>>2]=1;c[e+14092>>2]=2;n=16;break a;break};case 5:case 20:{c[m>>2]=0;c[b+400>>2]=2;n=l;break a;break};case 18:{c[e+32>>2]=1;c[e+14092>>2]=4;n=18;break a;break};case 13:case 21:{n=l;break a;break};case 22:{c[e+44>>2]=1;n=22;break a;break};case 19:{c[e+32>>2]=1;c[e+14092>>2]=5;n=19;break a;break};case 71:case 72:case 153:case 152:case 168:{j=l;k=10;break a;break};case 15:{c[e+32>>2]=1;c[e+14092>>2]=1;n=15;break a;break};default:{KIb(b,16,2545576,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;o=-38;i=d;return o|0}}}}while(0);if((k|0)==10){c[e+32>>2]=1;c[e+14092>>2]=6;c[b+400>>2]=1;n=j}c[e+48>>2]=n;c[b+712>>2]=E5a(b)|0;do{if((c[b+56>>2]|0)==859189868){if((c[b+100>>2]|0)!=56){break}if((a[c[b+96>>2]|0]|0)!=1){break}c[e+13812>>2]=1}}while(0);b=c[(c[g>>2]|0)+12>>2]|0;do{if(!((b|0)==5|(b|0)==20|(b|0)==13)){g=rTa(f)|0;if((g|0)<0){o=g}else{break}i=d;return o|0}}while(0);Zga(e+11548|0);DMa();o=0;i=d;return o|0}function Wga(a){a=a|0;xTa(c[a+60>>2]|0);return 0}function Xga(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;g=i;i=i+40|0;h=g|0;j=g+8|0;k=g+16|0;l=c[f+24>>2]|0;c[h>>2]=l;c[j>>2]=c[f+28>>2];f=b+60|0;m=c[f>>2]|0;n=m;o=d;p=c[b+88>>2]|0;q=m+60|0;c[q>>2]=p;c[m+64>>2]=c[b+92>>2];r=c[j>>2]|0;if((r|0)==0){if((c[m+13944>>2]|0)!=0){s=0;i=g;return s|0}t=m+9852|0;u=c[t>>2]|0;if((u|0)==0){s=0;i=g;return s|0}v=YHb(o,u|0)|0;if((v|0)<0){s=v;i=g;return s|0}c[t>>2]=0;c[e>>2]=1;s=0;i=g;return s|0}t=m+48|0;do{if((p&65536|0)!=0){v=c[t>>2]|0;if((v|0)==20){w=Tga(m+13744|0,l,r)|0}else if((v|0)==13){w=JRa(m+13744|0,l,r)|0}else if((v|0)==5){w=Tga(m+13744|0,l,r)|0}else{KIb(c[m+4>>2]|0,16,2453016,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;s=-38;i=g;return s|0}if((IWa(m+13744|0,w,h,j)|0)>=0){break}s=c[j>>2]|0;i=g;return s|0}}while(0);w=m+14012|0;r=m+14020|0;l=m+14120|0;p=l;v=m+14132|0;u=m+14136|0;y=m+14124|0;z=m+14128|0;A=m+96|0;B=m+9856|0;C=m+156|0;D=m+14092|0;E=m+8|0;F=b+128|0;G=m+12|0;H=b+132|0;I=m+4|0;J=m+13944|0;K=b+176|0;L=b+48|0;M=l;l=m+108|0;N=k|0;O=k+12|0;P=k+16|0;Q=k+4|0;R=k+8|0;S=m+44|0;T=m+14016|0;while(1){U=c[r>>2]|0;a:do{if((c[w>>2]|0)==0){V=25}else{if((U|0)==0){V=26;break}W=(c[j>>2]|0)-3|0;if((W|0)<=0){V=27;break}X=c[h>>2]|0;Y=0;b:while(1){Z=Y+1|0;do{if((a[X+Y|0]|0)==0){if((a[X+Z|0]|0)!=0){break}if((a[X+(Y+2)|0]|0)==1){break b}}}while(0);if((Z|0)<(W|0)){Y=Z}else{V=25;break a}}if(!((a[X+(Y+3)|0]|0)==-80)){V=25;break}KIb(c[I>>2]|0,24,2363760,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;c[r>>2]=0;V=26}}while(0);if((V|0)==25){V=0;if((U|0)==0){V=26}else{V=27}}do{if((V|0)==26){V=0;_=c[j>>2]|0;V=30}else if((V|0)==27){V=0;if((c[w>>2]|0)==0){W=c[j>>2]|0;if((W|0)>=20){_=W;V=30;break}}W=c[T>>2]|0;$=U>>>0>268435455>>>0?-8:U<<3;aa=$>>>0>2147483639>>>0|(W|0)==0;ba=aa?0:W;W=aa?0:$;c[p>>2]=ba;c[v>>2]=W;c[u>>2]=W+8;da=aa?-1094995529:0;ea=ba+(W>>3)|0}}while(0);if((V|0)==30){V=0;U=c[h>>2]|0;W=_>>>0>268435455>>>0?-8:_<<3;ba=W>>>0>2147483639>>>0|(U|0)==0;aa=ba?0:U;U=ba?0:W;c[p>>2]=aa;c[v>>2]=U;c[u>>2]=U+8;da=ba?-1094995529:0;ea=aa+(U>>3)|0}c[y>>2]=ea;c[z>>2]=0;c[r>>2]=0;if((da|0)<0){s=da;V=161;break}if((c[A>>2]|0)==0){U=rTa(n)|0;if((U|0)<0){s=U;V=161;break}}U=c[B>>2]|0;if((U|0)==0){V=36}else{if((c[U>>2]|0)!=0){V=36}}if((V|0)==36){V=0;U=CTa(n,0)|0;if((U|0)<0){s=U;V=161;break}c[B>>2]=(c[C>>2]|0)+(U*2224|0)}U=c[D>>2]|0;do{if((U|0)==5){fa=Ihb(n)|0}else if((U|0)==0){if((c[L>>2]|0)==13){aa=c[I>>2]|0;ba=c[aa+100>>2]|0;do{if((ba|0)!=0){if((c[l>>2]|0)!=0){break}W=c[aa+96>>2]|0;$=ba>>>0>268435455>>>0?-8:ba<<3;ga=$>>>0>2147483639>>>0|(W|0)==0;ha=ga?0:W;W=ga?0:$;c[N>>2]=ha;c[O>>2]=W;c[P>>2]=W+8;c[Q>>2]=ha+(W>>3);c[R>>2]=0;if(ga){break}RRa(c[f>>2]|0,k)|0}}while(0);fa=RRa(c[f>>2]|0,M)|0;break}else{if((c[t>>2]|0)==21){fa=_La(n)|0;break}if((c[S>>2]|0)==0){fa=OMa(n)|0;break}else{fa=ufa(n)|0;break}}}else{fa=HUa(n)|0}}while(0);U=(fa|0)<0;ba=(fa|0)==100;do{if(U|ba){if((c[E>>2]|0)==(c[F>>2]|0)){if((c[G>>2]|0)==(c[H>>2]|0)){break}}KIb(c[I>>2]|0,24,2298480,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;c[E>>2]=c[F>>2];c[G>>2]=c[H>>2]}}while(0);if(ba){V=57;break}if(U){V=63;break}c[K>>2]=(c[J>>2]|0)==0;if((c[L>>2]|0)!=13){V=66;break}if((QRa(b)|0)!=1){V=66;break}}if((V|0)==57){K=c[j>>2]|0;S=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=K;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=K;i=g;return s|0}if((c[q>>2]&65536|0)==0){M=(S|0)==0?1:S;s=(M+10|0)>(K|0)?K:M;i=g;return s|0}else{M=S-(c[m+13752>>2]|0)|0;s=(M|0)<0?0:M;i=g;return s|0}}else if((V|0)==63){KIb(c[I>>2]|0,16,2247744,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;s=fa;i=g;return s|0}else if((V|0)==66){fa=c[E>>2]|0;E=c[G>>2]|0;do{if((fa|0)==(c[F>>2]|0)){if((E|0)!=(c[H>>2]|0)){V=69;break}if((c[m+14420>>2]|0)!=0){V=69}}else{V=69}}while(0);do{if((V|0)==69){c[m+14420>>2]=0;H=H4a(b,fa,E)|0;if((H|0)<0){s=H;i=g;return s|0}H=sTa(n)|0;if((H|0)==0){break}else{s=H}i=g;return s|0}}while(0);E=c[t>>2]|0;if((E|0)==5|(E|0)==20|(E|0)==21){c[m+13784>>2]=Sga(n)|0}E=m+9992|0;t=c[E>>2]|0;c[m+7712>>2]=t;fa=(t|0)==1;c[m+7708>>2]=fa&1;H=m+9848|0;do{if((c[H>>2]|0)==0){if((t|0)!=3){if((c[m+10008>>2]|0)==0){break}}F=c[j>>2]|0;G=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=F;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=F;i=g;return s|0}if((c[q>>2]&65536|0)==0){x=(G|0)==0?1:G;s=(x+10|0)>(F|0)?F:x;i=g;return s|0}else{x=G-(c[m+13752>>2]|0)|0;s=(x|0)<0?0:x;i=g;return s|0}}}while(0);x=c[b+856>>2]|0;do{if((x|0)>7){if((t|0)!=3){if((x|0)<=31){break}if(!((x|0)>47|fa^1)){break}}G=c[j>>2]|0;F=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=G;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=G;i=g;return s|0}if((c[q>>2]&65536|0)==0){M=(F|0)==0?1:F;s=(M+10|0)>(G|0)?G:M;i=g;return s|0}else{M=F-(c[m+13752>>2]|0)|0;s=(M|0)<0?0:M;i=g;return s|0}}}while(0);fa=m+13736|0;do{if((c[fa>>2]|0)!=0){if((t|0)!=3){c[fa>>2]=0;break}x=c[j>>2]|0;M=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=x;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=x;i=g;return s|0}if((c[q>>2]&65536|0)==0){F=(M|0)==0?1:M;s=(F+10|0)>(x|0)?x:F;i=g;return s|0}else{F=M-(c[m+13752>>2]|0)|0;s=(F|0)<0?0:F;i=g;return s|0}}}while(0);if((c[m+12472>>2]|0)==0|(t|0)==3){c[m+12452>>2]=m+10680;c[m+12456>>2]=m+10808}else{c[m+12452>>2]=m+10936;c[m+12456>>2]=m+10808}t=DTa(n,b)|0;if((t|0)<0){s=t;i=g;return s|0}fa=b+712|0;do{if((c[w>>2]|0)==0){if((c[fa>>2]|0)!=0){break}K5a(b)}}while(0);F=c[fa>>2]|0;do{if((F|0)==0){ia=t}else{M=c[p>>2]|0;x=Ee[c[F+24>>2]&511](b,M,(c[y>>2]|0)-M|0)|0;if((x|0)<0){s=x}else{ia=x;break}i=g;return s|0}}while(0);STa(n);do{if((c[D>>2]|0)==5){y=Jhb(n)|0;if((y|0)<0){s=y;i=g;return s|0}else{if((y|0)==1){ja=1;ka=0;break}else{la=y;V=110;break}}}else{la=ia;V=110}}while(0);do{if((V|0)==110){ia=m+12476|0;c[ia>>2]=0;y=m+12480|0;c[y>>2]=0;F=Yga(n)|0;p=m+14080|0;t=c[y>>2]|0;x=m+120|0;c:do{if((t|0)<(c[x>>2]|0)){M=m+116|0;G=m+14460|0;S=m+32|0;K=F;f=t;while(1){do{if((c[D>>2]|0)==0){k=c[ia>>2]|0;if((FMa(n)|0)<0){ma=K;break c}R=c[M>>2]|0;Q=(ca(R,f)|0)+k|0;k=ca(c[y>>2]|0,R)|0;if((Q|0)>=(k+(c[ia>>2]|0)|0)){break}c[G>>2]=1}else{k=c[p>>2]|0;if((k|0)==0){ma=K;break c}if((c[ia>>2]|0)!=0){ma=K;break c}if(((f|0)%(k|0)|0|0)!=0){ma=K;break c}if(((c[v>>2]|0)-(c[z>>2]|0)|0)<0){ma=K;break c}}}while(0);do{if((c[D>>2]|0)<4){if((c[S>>2]|0)==0){break}FRa(n)}}while(0);Z=(Yga(n)|0)<0;k=Z?-1094995529:K;Z=c[y>>2]|0;if((Z|0)<(c[x>>2]|0)){K=k;f=Z}else{ma=k;break}}}else{ma=F}}while(0);F=c[D>>2]|0;if(!((F|0)!=0&(F|0)<4)){ja=la;ka=ma;break}if((c[E>>2]|0)!=1){ja=la;ka=ma;break}if((IUa(n,c[j>>2]|0)|0)>=0){ja=la;ka=ma;break}a[(c[m+14464>>2]|0)+((c[m+144>>2]|0)-1)|0]=14;ja=la;ka=ma}}while(0);zpb(m+14424|0);ma=c[fa>>2]|0;do{if((ma|0)==0){na=ja}else{la=ve[c[ma+32>>2]&4095](b)|0;if((la|0)<0){s=la}else{na=la;break}i=g;return s|0}}while(0);ETa(n);if((c[L>>2]|0)==13){TRa(b,c[h>>2]|0,c[j>>2]|0)|0}do{if((c[w>>2]|0)==0){if((c[fa>>2]|0)==0){break}K5a(b)}}while(0);do{if((c[E>>2]|0)==3){V=137}else{if((c[J>>2]|0)!=0){V=137;break}fa=c[H>>2]|0;if((fa|0)==0){oa=na;break}h=YHb(o,fa|0)|0;if((h|0)<0){s=h;i=g;return s|0}else{HTa(n,c[H>>2]|0,o);ITa(n,o,c[H>>2]|0,0)|0;pa=h;V=142;break}}}while(0);do{if((V|0)==137){na=YHb(o,c[B>>2]|0)|0;if((na|0)<0){s=na;i=g;return s|0}else{HTa(n,c[B>>2]|0,o);ITa(n,o,c[B>>2]|0,0)|0;pa=na;V=142;break}}}while(0);do{if((V|0)==142){if((c[H>>2]|0)==0){if((c[J>>2]|0)==0){oa=pa;break}}do{if((c[d+80>>2]|0)==0){B=c[m+88>>2]|0;if(!((B|0)==1448035655|(B|0)==1481590087)){break}cIb(o)|0;B=d+68|0;n=d+72|0;na=c[B>>2]|0;E=c[n>>2]|0;h=c[d+32>>2]|0;fa=E>>1;do{if((fa|0)>0){L=E-1|0;ma=d;if((na|0)>0){qa=0}else{ra=na;sa=E;break}do{ja=ca(L-qa|0,h)|0;la=ca(qa,h)|0;D=0;do{v=c[ma>>2]|0;F=v+(D+ja)|0;x=a[F]|0;y=D+la|0;a[F]=a[v+y|0]|0;a[(c[ma>>2]|0)+y|0]=x;D=D+1|0;}while((D|0)<(na|0));qa=qa+1|0;}while((qa|0)<(fa|0));ra=c[B>>2]|0;sa=c[n>>2]|0}else{ra=na;sa=E}}while(0);E=-ra>>1;na=-E|0;fa=-sa>>1;h=c[d+36>>2]|0;ma=-fa>>1;do{if((ma|0)>0){L=~fa;D=d+4|0;if((E|0)<0){ta=0}else{ua=ra;va=sa;break}do{la=ca(L-ta|0,h)|0;ja=ca(ta,h)|0;x=0;do{y=c[D>>2]|0;v=y+(x+la)|0;F=a[v]|0;ia=x+ja|0;a[v]=a[y+ia|0]|0;a[(c[D>>2]|0)+ia|0]=F;x=x+1|0;}while((x|0)<(na|0));ta=ta+1|0;}while((ta|0)<(ma|0));ua=c[B>>2]|0;va=c[n>>2]|0}else{ua=ra;va=sa}}while(0);n=-ua>>1;B=-n|0;ma=-va>>1;na=c[d+40>>2]|0;h=-ma>>1;if((h|0)<=0){break}E=~ma;ma=d+8|0;if((n|0)<0){wa=0}else{break}do{n=ca(E-wa|0,na)|0;fa=ca(wa,na)|0;D=0;do{L=c[ma>>2]|0;x=L+(D+n)|0;ja=a[x]|0;la=D+fa|0;a[x]=a[L+la|0]|0;a[(c[ma>>2]|0)+la|0]=ja;D=D+1|0;}while((D|0)<(B|0));wa=wa+1|0;}while((wa|0)<(h|0))}}while(0);c[e>>2]=1;oa=pa}}while(0);do{if((ka|0)<0){if((c[b+696>>2]&8|0)==0){break}else{s=oa}i=g;return s|0}}while(0);oa=c[j>>2]|0;j=(c[z>>2]|0)+7>>3;if((c[w>>2]|0)!=0){s=oa;i=g;return s|0}if((c[(c[I>>2]|0)+712>>2]|0)!=0){s=oa;i=g;return s|0}if((c[q>>2]&65536|0)==0){q=(j|0)==0?1:j;s=(q+10|0)>(oa|0)?oa:q;i=g;return s|0}else{q=j-(c[m+13752>>2]|0)|0;s=(q|0)<0?0:q;i=g;return s|0}}else if((V|0)==161){i=g;return s|0}return 0}function Yga(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;b=i;e=a+13940|0;f=(c[e>>2]|0)!=0?18:127;g=a+4|0;h=16>>>((c[(c[g>>2]|0)+800>>2]|0)>>>0);j=a+14120|0;k=a+13712|0;l=j;c[k>>2]=c[l>>2];c[k+4>>2]=c[l+4>>2];c[k+8>>2]=c[l+8>>2];c[k+12>>2]=c[l+12>>2];c[k+16>>2]=c[l+16>>2];l=a+14084|0;c[l>>2]=1;k=a+12476|0;m=a+13704|0;c[m>>2]=c[k>>2];n=a+12480|0;o=a+13708|0;c[o>>2]=c[n>>2];p=a+9960|0;QTa(a,c[p>>2]|0);q=c[g>>2]|0;r=c[q+712>>2]|0;if((r|0)!=0){s=(c[j>>2]|0)+((c[a+14128>>2]|0)/8|0)|0;t=Ee[c[r+28>>2]&511](q,s,(c[a+14124>>2]|0)-s|0)|0;c[n>>2]=c[a+120>>2];u=t;i=b;return u|0}if((c[e>>2]|0)!=0){e=c[p>>2]|0;do{if((c[a+48>>2]|0)==13){p=PRa(c[q+60>>2]|0)|0;if((p|0)<0){u=p}else{break}i=b;return u|0}}while(0);c[l>>2]=1;c[k>>2]=c[m>>2];c[n>>2]=c[o>>2];QTa(a,e)}e=c[n>>2]|0;q=a+120|0;a:do{if((e|0)<(c[q>>2]|0)){p=a+14092|0;t=a+116|0;s=a+12496|0;r=a+12500|0;v=a+12504|0;w=a+12508|0;x=a+12512|0;y=a+12516|0;z=a+12544|0;A=a+12548|0;B=a+12552|0;C=a+11736|0;D=a+11740|0;E=a+14348|0;F=a+14340|0;G=a+9992|0;H=a+13836|0;I=a+14080|0;J=a+9868|0;K=a+9864|0;L=a+9860|0;M=e;b:while(1){N=c[p>>2]|0;do{if((N|0)!=0){O=c[o>>2]|0;if(((c[I>>2]|0)+O|0)==(M|0)){P=11;break b}if((N|0)!=1){break}c[J>>2]=128;c[K>>2]=128;c[L>>2]=128}}while(0);NTa(a);N=c[k>>2]|0;if((N|0)<(c[t>>2]|0)){Q=N;do{N=8>>>((c[(c[g>>2]|0)+800>>2]|0)>>>0);c[s>>2]=(c[s>>2]|0)+2;c[r>>2]=(c[r>>2]|0)+2;c[v>>2]=(c[v>>2]|0)+2;c[w>>2]=(c[w>>2]|0)+2;c[x>>2]=(c[x>>2]|0)+1;c[y>>2]=(c[y>>2]|0)+1;c[z>>2]=(c[z>>2]|0)+(N<<1);c[A>>2]=(c[A>>2]|0)+N;c[B>>2]=(c[B>>2]|0)+N;do{if((c[m>>2]|0)==(Q|0)){if(((c[o>>2]|0)+1|0)!=(c[n>>2]|0)){break}c[l>>2]=0}}while(0);c[C>>2]=1;c[D>>2]=0;R=We[c[E>>2]&2047](a,c[F>>2]|0)|0;if((c[G>>2]|0)!=3){Nga(a)}if((R|0)<0){break b}KTa(a,c[F>>2]|0);if((c[H>>2]|0)!=0){Pga(a)}Q=(c[k>>2]|0)+1|0;c[k>>2]=Q;}while((Q|0)<(c[t>>2]|0))}MTa(a,ca(c[n>>2]|0,h)|0,h);RTa(a);c[k>>2]=0;Q=(c[n>>2]|0)+1|0;c[n>>2]=Q;if((Q|0)<(c[q>>2]|0)){M=Q}else{S=Q;break a}}if((P|0)==11){ypb(a+14424|0,c[m>>2]|0,O,(c[k>>2]|0)-1|0,M,112);u=0;i=b;return u|0}G=(ca(c[a+124>>2]|0,c[n>>2]|0)|0)+(c[k>>2]|0)|0;if(!((R|0)==-2)){E=c[g>>2]|0;if((R|0)==-3){KIb(E,16,2617232,(T=i,i=i+8|0,c[T>>2]=G,T)|0);i=T;ypb(a+14424|0,c[m>>2]|0,c[o>>2]|0,(c[k>>2]|0)+1|0,c[n>>2]|0,f&112);u=-1094995529;i=b;return u|0}else{KIb(E,16,2590024,(T=i,i=i+8|0,c[T>>2]=G,T)|0);i=T;ypb(a+14424|0,c[m>>2]|0,c[o>>2]|0,c[k>>2]|0,c[n>>2]|0,f&14);u=-1094995529;i=b;return u|0}}KTa(a,c[F>>2]|0);if((c[H>>2]|0)!=0){Pga(a)}ypb(a+14424|0,c[m>>2]|0,c[o>>2]|0,c[k>>2]|0,c[n>>2]|0,f&112);G=a+14008|0;c[G>>2]=(c[G>>2]|0)-1;G=(c[k>>2]|0)+1|0;c[k>>2]=G;if((G|0)<(c[t>>2]|0)){u=0;i=b;return u|0}c[k>>2]=0;MTa(a,ca(c[n>>2]|0,h)|0,h);RTa(a);c[n>>2]=(c[n>>2]|0)+1;u=0;i=b;return u|0}else{S=e}}while(0);e=c[a+84>>2]|0;c:do{if((c[a+48>>2]|0)==13){if((e&1|0)==0){break}h=c[a+14128>>2]|0;do{if(((c[a+14132>>2]|0)-h|0)>47){R=(c[j>>2]|0)+(h>>>3)|0;if(((je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(h&7)&-256|0)!=4198400){break}if((c[a+13936>>2]|0)!=0){break}R=a+14008|0;c[R>>2]=(c[R>>2]|0)+32}}while(0);h=c[a+14128>>2]|0;t=c[a+14132>>2]|0;H=t-h|0;if(!(H>>>0<137>>>0)){break}if((c[a+13936>>2]|0)!=0){break}if((t|0)==(h|0)){t=a+14008|0;c[t>>2]=(c[t>>2]|0)+16;break}if((H|0)==1){break}t=(c[j>>2]|0)+(h>>>3)|0;F=h&7;M=((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<F>>>24|127>>>((F^7)>>>0)|0)==127;if(M&(H|0)<9){F=a+14008|0;c[F>>2]=(c[F>>2]|0)-1;break}do{if(M){if(!((h&8|0)==0&(H|0)<17)){break}F=a+14008|0;c[F>>2]=(c[F>>2]|0)+4;break c}}while(0);H=a+14008|0;c[H>>2]=(c[H>>2]|0)+1}}while(0);H=a+84|0;d:do{if((e&1|0)==0){U=e}else{do{if((c[a+14008>>2]|0)>-2){if((c[a+13936>>2]|0)!=0){break}h=e|16;c[H>>2]=h;U=h;break d}}while(0);h=e&-17;c[H>>2]=h;U=h}}while(0);do{if((c[a+14092>>2]|0)==0){H=U&16;if((H|0)!=0){e=c[a+14128>>2]|0;V=7;W=(c[a+14132>>2]|0)-e|0;X=e;Y=H;break}H=c[g>>2]|0;e=c[a+14128>>2]|0;h=(c[a+14132>>2]|0)-e|0;M=(c[j>>2]|0)+(e>>>3)|0;F=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(e&7)>>>8;e=c[a+14008>>2]|0;KIb(H,16,2532088,(T=i,i=i+24|0,c[T>>2]=h,c[T+8>>2]=F,c[T+16>>2]=e,T)|0);i=T;ypb(a+14424|0,c[m>>2]|0,c[o>>2]|0,c[k>>2]|0,c[n>>2]|0,f&112);u=-1094995529;i=b;return u|0}else{e=c[a+14128>>2]|0;V=(c[a+9992>>2]|0)==1?24:7;W=(c[a+14132>>2]|0)-e|0;X=e;Y=U&16}}while(0);U=(Y|0)==0;do{if(U){P=62}else{if((c[a+13740>>2]&262148|0)==0){P=62;break}Z=V+48|0}}while(0);if((P|0)==62){Z=U?V:V|1073741824}if((W|0)>(Z|0)){Z=c[g>>2]|0;V=(c[j>>2]|0)+(X>>>3)|0;j=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(X&7)>>>8;KIb(Z,16,2568304,(T=i,i=i+16|0,c[T>>2]=W,c[T+8>>2]=j,T)|0);i=T;u=0;i=b;return u|0}if((W|0)<0){KIb(c[g>>2]|0,16,2550272,(T=i,i=i+8|0,c[T>>2]=-W,T)|0);i=T;u=0;i=b;return u|0}else{ypb(a+14424|0,c[m>>2]|0,c[o>>2]|0,(c[k>>2]|0)-1|0,S,112);u=0;i=b;return u|0}return 0}function Zga(a){a=a|0;c[a>>2]=1466;c[a+4>>2]=274;return}function _ga(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d[1379032+e|0]|0;e=f*-2|0;g=-f|0;h=f<<1;i=0;do{j=ca(i,c)|0;k=b+(j-2)|0;l=d[k]|0;m=b+(j-1)|0;n=d[m]|0;o=b+j|0;p=d[o]|0;q=b+(j+1)|0;j=d[q]|0;r=l-j|0;s=(r+(p-n<<2)|0)/8|0;do{if((s|0)<(e|0)){t=0}else{if((s|0)<(g|0)){t=e-s|0;break}if((s|0)<(f|0)){t=s;break}t=(s|0)<(h|0)?h-s|0:0}}while(0);s=t+n|0;u=p-t|0;if((s&256|0)==0){v=s&255}else{v=(s>>31^255)&255}if((u&256|0)==0){w=u&255}else{w=(u>>31^255)&255}a[m]=v;a[o]=w;u=((t|0)>-1?t:-t|0)>>1;s=(r|0)/4|0;x=-u|0;if((s|0)<(x|0)){y=x}else{y=(s|0)>(u|0)?u:s}a[k]=l-y;a[q]=y+j;i=i+1|0;}while((i|0)<8);return}function $ga(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=d[1379032+e|0]|0;e=c<<1;g=f*-2|0;h=-f|0;i=f<<1;j=0;do{k=b+(j-e)|0;l=d[k]|0;m=b+(j-c)|0;n=d[m]|0;o=b+j|0;p=d[o]|0;q=b+(j+c)|0;r=d[q]|0;s=l-r|0;t=(s+(p-n<<2)|0)/8|0;do{if((t|0)<(g|0)){u=0}else{if((t|0)<(h|0)){u=g-t|0;break}if((t|0)<(f|0)){u=t;break}u=(t|0)<(i|0)?i-t|0:0}}while(0);t=u+n|0;v=p-u|0;if((t&256|0)==0){w=t&255}else{w=(t>>31^255)&255}if((v&256|0)==0){x=v&255}else{x=(v>>31^255)&255}a[m]=w;a[o]=x;v=((u|0)>-1?u:-u|0)>>1;t=(s|0)/4|0;y=-v|0;if((t|0)<(y|0)){z=y}else{z=(t|0)>(v|0)?v:t}a[k]=l-z;a[q]=z+r;j=j+1|0;}while((j|0)<8);return}function aha(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;if((b|0)==0){d=0;return d|0}d=c[b+6788>>2]|0;return d|0}function bha(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+32|0;g=f|0;h=c[a>>2]|0;j=a+199440|0;k=(c[j>>2]|0)==0?0:j;j=d[(qKb(c[h+140>>2]|0)|0)+6|0]|0;l=c[a+177100>>2]|0;do{if((l|0)==3){m=(c[h+124>>2]|0)-b|0;n=b;o=(m|0)<(e|0)?m:e}else{m=e<<1;p=b<<1;q=(c[h+124>>2]|0)-p|0;r=(m|0)>(q|0)?q:m;if((c[a+177104>>2]|0)==0){n=p;o=r;break}if((c[h+288>>2]&2|0)!=0){n=p;o=r;break}i=f;return}}while(0);b=h+148|0;if((c[b>>2]|0)==0){i=f;return}e=a+2528|0;do{if((c[a+2616>>2]|0)==3){s=e}else{if((c[a+4808>>2]|0)!=0){s=e;break}if((c[h+288>>2]&1|0)!=0){s=e;break}if((k|0)==0){i=f;return}else{s=k|0;break}}}while(0);k=g|0;c[k>>2]=ca(c[s+32>>2]|0,n)|0;e=ca(c[s+36>>2]|0,n>>j)|0;c[g+8>>2]=e;c[g+4>>2]=e;mrc(g+12|0,0,20)|0;_e[c[b>>2]&511](h,s,k,n,l,o);i=f;return}function cha(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;a:do{if((c[b+5164>>2]&32768|0)==0){e=b+4900|0;f=a[e]|0;g=a[1376792+f|0]|0;do{if((249>>>(f>>>0)&1|0)==0){if((253>>>(f>>>0)&1|0)!=0){a[e]=g}h=b+4901|0;j=a[h]|0;k=a[1376792+j|0]|0;if((249>>>(j>>>0)&1|0)!=0){l=k;break}if((253>>>(j>>>0)&1|0)!=0){a[h]=k}k=b+4902|0;h=a[k]|0;j=a[1376792+h|0]|0;if((249>>>(h>>>0)&1|0)!=0){l=j;break}if((253>>>(h>>>0)&1|0)!=0){a[k]=j}j=b+4903|0;k=a[j]|0;h=a[1376792+k|0]|0;if((249>>>(k>>>0)&1|0)!=0){l=h;break}if((253>>>(k>>>0)&1|0)==0){break a}a[j]=h;break a}else{l=g}}while(0);g=c[b+427376>>2]|0;e=c[b+427380>>2]|0;KIb(c[b>>2]|0,16,2545200,(m=i,i=i+24|0,c[m>>2]=l<<24>>24,c[m+8>>2]=g,c[m+16>>2]=e,m)|0);i=m;n=-1094995529;i=d;return n|0}}while(0);l=c[b+5172>>2]|0;if((l&34952|0)==34952){n=0;i=d;return n|0}do{if((l&32768|0)==0){e=b+4900|0;g=a[e]|0;f=a[1376808+g|0]|0;if((370>>>(g>>>0)&1|0)!=0){o=f;break}if((886>>>(g>>>0)&1|0)==0){p=13;break}a[e]=f;p=13}else{p=13}}while(0);b:do{if((p|0)==13){do{if((l&8192|0)==0){f=b+4908|0;e=a[f]|0;g=a[1376808+e|0]|0;if((370>>>(e>>>0)&1|0)!=0){o=g;break b}if((886>>>(e>>>0)&1|0)==0){break}a[f]=g}}while(0);do{if((l&128|0)==0){g=b+4916|0;f=a[g]|0;e=a[1376808+f|0]|0;if((370>>>(f>>>0)&1|0)!=0){o=e;break b}if((886>>>(f>>>0)&1|0)==0){break}a[g]=e}}while(0);if((l&32|0)!=0){n=0;i=d;return n|0}e=b+4924|0;g=a[e]|0;f=a[1376808+g|0]|0;if((370>>>(g>>>0)&1|0)!=0){o=f;break}if((886>>>(g>>>0)&1|0)==0){n=0;i=d;return n|0}a[e]=f;n=0;i=d;return n|0}}while(0);l=c[b+427376>>2]|0;p=c[b+427380>>2]|0;KIb(c[b>>2]|0,16,2605704,(m=i,i=i+24|0,c[m>>2]=o<<24>>24,c[m+8>>2]=l,c[m+16>>2]=p,m)|0);i=m;n=-1094995529;i=d;return n|0}function dha(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;if(d>>>0>3>>>0){g=c[b+427380>>2]|0;KIb(c[b>>2]|0,16,2452968,(h=i,i=i+16|0,c[h>>2]=c[b+427376>>2],c[h+8>>2]=g,h)|0);i=h;j=-1094995529;i=f;return j|0}do{if((c[b+5164>>2]&32768|0)==0){if(!((d-2|0)>>>0<2>>>0)){k=a[1376776+d|0]|0;break}g=c[b+427380>>2]|0;KIb(c[b>>2]|0,16,2363696,(h=i,i=i+16|0,c[h>>2]=c[b+427376>>2],c[h+8>>2]=g,h)|0);i=h;j=-1094995529;i=f;return j|0}else{k=d}}while(0);d=c[b+5172>>2]|0;g=d&32896;if((g|0)==32896){j=k;i=f;return j|0}if(!((e|0)==0|(g|0)==0)){j=8-(d>>>15&1)+(((k|0)==4)<<1)|0;i=f;return j|0}if(!((k|0)==3|(k|0)==1)){j=a[1376784+k|0]|0;i=f;return j|0}k=c[b+427380>>2]|0;KIb(c[b>>2]|0,16,2298416,(h=i,i=i+16|0,c[h>>2]=c[b+427376>>2],c[h+8>>2]=k,h)|0);i=h;j=-1094995529;i=f;return j|0}function eha(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;c[b+427432>>2]=(d[e]|0)>>>5;i=a[e]&31;c[b+427436>>2]=i;j=e+1|0;k=h-1|0;a:do{if((k|0)>1){h=0;b:while(1){do{if((a[e+(h+1)|0]|0)==0){if((h|0)>0){l=(((a[e+h|0]|0)==0)<<31>>31)+h|0}else{l=h}m=l+2|0;if((m|0)>=(k|0)){n=l;break}if((a[e+m|0]|0)!=0){n=l;break}o=a[e+(l+3)|0]|0;if((o&255)>>>0<4>>>0){break b}else{n=l}}else{n=h}}while(0);m=n+2|0;if((n+3|0)<(k|0)){h=m}else{p=m;q=k;break a}}p=l;q=o<<24>>24==3?k:l}else{p=0;q=k}}while(0);k=(i|0)==4|0;i=b+427440+(k<<2)|0;A4a(i,b+427448+(k<<2)|0,q+262144|0);k=c[i>>2]|0;if((k|0)==0){r=0;return r|0}if((p|0)>=(q-1|0)){c[f>>2]=q;c[g>>2]=q+1;if((c[(c[b>>2]|0)+92>>2]&1|0)!=0){r=j;return r|0}nrc(k|0,j|0,q)|0;r=k;return r|0}nrc(k|0,j|0,p)|0;j=p+2|0;c:do{if((j|0)<(q|0)){b=p;i=p;l=j;while(1){o=b+3|0;n=a[e+o|0]|0;h=a[e+(b+1)|0]|0;do{if((n&255)>>>0>3>>>0){a[k+i|0]=h;a[k+(i+1)|0]=a[e+(b+2)|0]|0;s=i+2|0;t=l;u=24}else{if(!(h<<24>>24==0)){s=i;t=b;u=24;break}if((a[e+(b+2)|0]|0)!=0){s=i;t=b;u=24;break}if(!(n<<24>>24==3)){v=i;w=b;break c}a[k+i|0]=0;a[k+(i+1)|0]=0;x=i+2|0;y=o}}while(0);if((u|0)==24){u=0;o=t+1|0;a[k+s|0]=a[e+o|0]|0;x=s+1|0;y=o}o=y+2|0;if((o|0)<(q|0)){b=y;i=x;l=o}else{z=y;A=x;u=15;break}}}else{z=p;A=p;u=15}}while(0);do{if((u|0)==15){if((z|0)>=(q|0)){v=A;w=z;break}p=q+A|0;x=z;y=A;while(1){s=x+1|0;a[k+y|0]=a[e+s|0]|0;if((s|0)<(q|0)){x=s;y=y+1|0}else{break}}v=p-z|0;w=q}}while(0);mrc(k+v|0,0,16)|0;c[f>>2]=v;c[g>>2]=w+1;r=k;return r|0}function fha(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;d=a+427404|0;e=c[d>>2]|0;f=a+427396|0;g=ca((c[f>>2]|0)+1|0,e)|0;h=a|0;j=c[(c[h>>2]|0)+808>>2]|0;k=ca((j|0)>1?j:1,e<<1)|0;e=k<<3;j=pJb(e)|0;c[a+4928>>2]=j;a:do{if((j|0)!=0|(e|0)==0){l=g*48|0;m=pJb(l)|0;c[a+5304>>2]=m;if(!((m|0)!=0|(l|0)==0)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}l=pJb((c[d>>2]|0)+g<<1)|0;m=a+428632|0;c[m>>2]=l;do{if((l|0)==0){if(((c[d>>2]|0)+g&2147483647|0)==0){break}KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break a}}while(0);l=g<<1;o=pJb(l)|0;c[a+426560>>2]=o;if(!((o|0)!=0|(l|0)==0)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}l=pJb(g)|0;c[a+426576>>2]=l;o=(g|0)==0;if(!((l|0)!=0|o)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}l=k<<4;p=pJb(l)|0;c[a+426584>>2]=p;q=(l|0)==0;if(!((p|0)!=0|q)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}p=pJb(l)|0;c[a+426588>>2]=p;if(!((p|0)!=0|q)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}q=g<<2;p=pJb(q)|0;c[a+426752>>2]=p;l=(q|0)==0;if(!((p|0)!=0|l)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}p=pJb(g)|0;c[a+199432>>2]=p;if(!((p|0)!=0|o)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}mrc(c[m>>2]|0,-1|0,(c[d>>2]|0)+g<<1|0)|0;c[a+177072>>2]=(c[m>>2]|0)+((c[d>>2]<<1|1)<<1);o=pJb(q)|0;p=a+6100|0;c[p>>2]=o;if(!((o|0)!=0|l)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}o=pJb(q)|0;q=o;c[a+6104>>2]=q;if(!((o|0)!=0|l)){KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;break}l=c[f>>2]|0;if((l|0)>0){o=a+427400|0;r=a+6108|0;s=0;t=c[o>>2]|0;u=l;while(1){if((t|0)>0){l=c[p>>2]|0;v=0;do{w=(ca(c[d>>2]|0,s)|0)+v|0;c[l+(w<<2)>>2]=(ca(c[r>>2]|0,s)|0)+v<<2;c[q+(w<<2)>>2]=((w|0)%(c[d>>2]<<1|0)|0)<<3;v=v+1|0;x=c[o>>2]|0;}while((v|0)<(x|0));y=x;z=c[f>>2]|0}else{y=t;z=u}v=s+1|0;if((v|0)<(z|0)){s=v;t=y;u=z}else{break}}}if((c[a+177020>>2]|0)==0){gha(a)}u=a+2520|0;if((c[u>>2]|0)!=0){A=0;i=b;return A|0}t=pJb(80064)|0;s=t;c[u>>2]=s;if((t|0)==0){A=-12;i=b;return A|0}else{B=0;C=s}while(1){WHb(C+(B*2224|0)|0);s=B+1|0;if((s|0)>=36){break}B=s;C=c[u>>2]|0}WHb(a+2528|0);A=0;i=b;return A|0}else{KIb(c[h>>2]|0,16,2247712,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}}while(0);hha(a,1);A=-12;i=b;return A|0}function gha(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=a+7308|0;e=((c[b>>2]|0)*6|0)+4|0;a:do{if((e|0)>0){f=0;do{g=a+177020+(f<<2)|0;c[g>>2]=a+8060+(f*5632|0);h=a+7396+(f<<4)|0;i=0;while(1){if((i|0)>=(f|0)){j=0;k=4;break}if((grc(a+7396+(i<<4)|0,h,16)|0)==0){k=8;break}else{i=i+1|0}}if((k|0)==4){while(1){k=0;h=(d[1530928+j|0]|0)+2|0;l=d[681992+j|0]|0;m=0;do{n=m>>2;c[a+8060+(f*5632|0)+(j<<6)+((m<<2&12|n)<<2)>>2]=(ca(d[a+7396+(f<<4)+m|0]|0,d[(n&1)+(m&1)+(1552296+(l*3|0))|0]|0)|0)<<h;m=m+1|0;}while((m|0)<16);m=j+1|0;if((m|0)<(e|0)){j=m;k=4}else{break}}}else if((k|0)==8){k=0;c[g>>2]=a+8060+(i*5632|0)}f=f+1|0;}while((f|0)<6)}else{c[a+177020>>2]=a+8060;f=a+177024|0;c[f>>2]=a+13692;m=a+7412|0;h=0;while(1){if((h|0)>=1){break}if((grc(a+7396+(h<<4)|0,m,16)|0)==0){k=13;break}else{h=h+1|0}}if((k|0)==13){c[f>>2]=a+8060+(h*5632|0)}m=a+177028|0;c[m>>2]=a+19324;l=a+7428|0;n=0;while(1){if((n|0)>=2){break}if((grc(a+7396+(n<<4)|0,l,16)|0)==0){k=17;break}else{n=n+1|0}}if((k|0)==17){c[m>>2]=a+8060+(n*5632|0)}l=a+177032|0;c[l>>2]=a+24956;h=a+7444|0;f=0;while(1){if((f|0)>=3){break}if((grc(a+7396+(f<<4)|0,h,16)|0)==0){k=21;break}else{f=f+1|0}}if((k|0)==21){c[l>>2]=a+8060+(f*5632|0)}h=a+177036|0;c[h>>2]=a+30588;n=a+7460|0;m=0;while(1){if((m|0)>=4){break}if((grc(a+7396+(m<<4)|0,n,16)|0)==0){k=25;break}else{m=m+1|0}}if((k|0)==25){c[h>>2]=a+8060+(m*5632|0)}n=a+177040|0;c[n>>2]=a+36220;f=a+7476|0;l=0;while(1){if((l|0)>=5){break a}if((grc(a+7396+(l<<4)|0,f,16)|0)==0){break}else{l=l+1|0}}c[n>>2]=a+8060+(l*5632|0)}}while(0);mrc(a+177044|0,0,24)|0;j=a+7392|0;if((c[j>>2]|0)!=0){e=((c[b>>2]|0)*6|0)+4|0;b=(e|0)>0;f=0;do{m=a+177044+(f<<2)|0;c[m>>2]=a+41852+(f*22528|0);h=a+7492+(f<<6)|0;o=0;while(1){if((o|0)>=(f|0)){k=36;break}if((grc(a+7492+(o<<6)|0,h,64)|0)==0){k=35;break}else{o=o+1|0}}do{if((k|0)==35){k=0;c[m>>2]=a+41852+(o*22528|0)}else if((k|0)==36){k=0;if(b){p=0}else{break}do{h=d[1530928+p|0]|0;l=d[681992+p|0]|0;n=0;do{c[a+41852+(f*22528|0)+(p<<8)+((n<<3&56|n>>3)<<2)>>2]=(ca(d[a+7492+(f<<6)+n|0]|0,d[(d[1552216+(n>>>1&12|n&3)|0]|0)+(1552232+(l*6|0))|0]|0)|0)<<h;n=n+1|0;}while((n|0)<64);p=p+1|0;}while((p|0)<(e|0))}}while(0);f=f+1|0;}while((f|0)<6)}if((c[a+6140>>2]|0)==0){return}f=c[a+177020>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177024>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177028>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177032>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177036>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;f=c[a+177040>>2]|0;c[f>>2]=64;c[f+4>>2]=64;c[f+8>>2]=64;c[f+12>>2]=64;c[f+16>>2]=64;c[f+20>>2]=64;c[f+24>>2]=64;c[f+28>>2]=64;c[f+32>>2]=64;c[f+36>>2]=64;c[f+40>>2]=64;c[f+44>>2]=64;c[f+48>>2]=64;c[f+52>>2]=64;c[f+56>>2]=64;c[f+60>>2]=64;if((c[j>>2]|0)==0){return}j=c[a+177044>>2]|0;f=0;do{c[j+(f<<2)>>2]=64;f=f+1|0;}while((f|0)<64);f=c[a+177048>>2]|0;j=0;do{c[f+(j<<2)>>2]=64;j=j+1|0;}while((j|0)<64);j=c[a+177052>>2]|0;f=0;do{c[j+(f<<2)>>2]=64;f=f+1|0;}while((f|0)<64);f=c[a+177056>>2]|0;j=0;do{c[f+(j<<2)>>2]=64;j=j+1|0;}while((j|0)<64);j=c[a+177060>>2]|0;f=0;do{c[j+(f<<2)>>2]=64;f=f+1|0;}while((f|0)<64);f=c[a+177064>>2]|0;a=0;do{c[f+(a<<2)>>2]=64;a=a+1|0;}while((a|0)<64);return}function hha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;mJb(a+4928|0);mJb(a+426576|0);mJb(a+426560|0);mJb(a+426584|0);mJb(a+426588|0);mJb(a+426752|0);mJb(a+5304|0);mJb(a+428632|0);c[a+177072>>2]=0;mJb(a+199432|0);mJb(a+6100|0);mJb(a+6104|0);lGb(a+572692|0);lGb(a+572696|0);lGb(a+572700|0);lGb(a+572704|0);d=(b|0)!=0;b=a+2520|0;e=c[b>>2]|0;f=(e|0)==0;do{if(d){if(f){c[a+2524>>2]=0;g=0;h=11;break}else{i=0;j=e}while(1){zha(a,j+(i*2224|0)|0);k=i+1|0;if((k|0)>=36){break}i=k;j=c[b>>2]|0}mJb(b);h=10}else{if(f){c[a+2524>>2]=0;l=0;h=16;break}else{k=0;while(1){c[e+(k*2224|0)+2188>>2]=1;m=k+1|0;if((m|0)<36){k=m}else{h=10;break}}}}}while(0);if((h|0)==10){c[a+2524>>2]=0;if(d){g=0;h=11}else{l=0;h=16}}if((h|0)==11){a:while(1){h=0;d=a+572248+(g<<2)|0;e=c[d>>2]|0;do{if((e|0)!=0){mJb(e+5180|0);mJb(e+5176|0);mJb(e+572636|0);mJb(e+572684|0);mJb(e+572688|0);mJb(e+768|0);mJb(e+2360|0);mJb(e+2392|0);mJb(e+2396|0);mJb(e+2416|0);mJb(e+2412|0);mJb(e+427444|0);mJb(e+427440|0);c[e+427448>>2]=0;c[e+427452>>2]=0;if((g|0)==0){g=g+1|0;h=11;continue a}else{mJb(d);break}}}while(0);d=g+1|0;if((d|0)<32){g=d;h=11}else{break}}return}else if((h|0)==16){b:while(1){h=0;g=a+572248+(l<<2)|0;d=c[g>>2]|0;do{if((d|0)!=0){mJb(d+5180|0);mJb(d+5176|0);mJb(d+572636|0);mJb(d+572684|0);mJb(d+572688|0);mJb(d+768|0);mJb(d+2360|0);mJb(d+2392|0);mJb(d+2396|0);mJb(d+2416|0);mJb(d+2412|0);if((l|0)==0){l=l+1|0;h=16;continue b}else{mJb(g);break}}}while(0);g=l+1|0;if((g|0)<32){l=g;h=16}else{break}}return}}function iha(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=c[b>>2]|0;if((e|0)==0|(f|0)<1){j=-1;i=g;return j|0}k=b+427456|0;do{if((a[e]|0)==1){c[k>>2]=1;if((f|0)<7){KIb(h,16,2205696,(l=i,i=i+8|0,c[l>>2]=f,l)|0);i=l;j=-1094995529;i=g;return j|0}m=b+427460|0;c[m>>2]=2;n=a[e+5|0]&31;o=e+6|0;a:do{if((n|0)==0){p=o}else{q=e+f|0;r=0;s=o;while(1){t=s;u=((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)+2|0;if((u|0)>(q-s|0)){j=-1094995529;v=20;break}w=jha(b,s,u,1)|0;if((w|0)<0){break}t=s+u|0;u=r+1|0;if((u|0)<(n|0)){r=u;s=t}else{p=t;break a}}if((v|0)==20){i=g;return j|0}KIb(h,16,2173480,(l=i,i=i+8|0,c[l>>2]=r,l)|0);i=l;j=w;i=g;return j|0}}while(0);n=a[p]|0;o=n&255;b:do{if(!(n<<24>>24==0)){s=e+f|0;q=0;t=p+1|0;while(1){u=t;x=((he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)+2|0;if((x|0)>(s-t|0)){j=-1094995529;v=20;break}y=jha(b,t,x,1)|0;if((y|0)<0){break}u=q+1|0;if((u|0)<(o|0)){q=u;t=t+x|0}else{break b}}if((v|0)==20){i=g;return j|0}KIb(h,16,2146048,(l=i,i=i+8|0,c[l>>2]=q,l)|0);i=l;j=y;i=g;return j|0}}while(0);c[m>>2]=(a[e+4|0]&3)+1}else{c[k>>2]=0;o=jha(b,e,f,1)|0;if((o|0)<0){j=o}else{break}i=g;return j|0}}while(0);j=f;i=g;return j|0}function jha(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=b|0;m=c[l>>2]|0;n=m+816|0;o=c[n>>2]&1^1;p=b+427436|0;c[p>>2]=0;q=b+572384|0;r=c[q>>2]|0;if((r|0)==0){c[q>>2]=1;s=1}else{s=r}r=b+572380|0;c[r>>2]=s;s=m+92|0;if((c[s>>2]&32768|0)==0){c[b+572376>>2]=0;if((c[b+177104>>2]|0)==0){c[b+2524>>2]=0}Jia(b)}q=b+427460|0;a:do{if((c[q>>2]|0)==4){do{if((f|0)>8){t=e;if((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)!=16777216){break}t=e+5|0;if(!((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)>>>0>f>>>0)){break}c[b+427456>>2]=0;break a}}while(0);if((f|0)<=3){break}t=e;u=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;if(u>>>0<2>>>0|u>>>0>f>>>0){break}c[b+427456>>2]=1}}while(0);u=b+427456|0;t=b+4820|0;v=m+856|0;w=b+427432|0;x=(g|0)==0;g=m;y=b+428676|0;z=b+428672|0;A=b+428660|0;B=b+428664|0;C=b+571360|0;D=b+571364|0;E=b+571368|0;F=b+571372|0;G=b+571376|0;H=b+571380|0;I=b+571384|0;J=b+571388|0;K=b+571392|0;L=b+571396|0;M=b+571400|0;N=b+571404|0;O=b+571408|0;P=b+571412|0;Q=b+571416|0;R=b+571420|0;S=b+572444|0;T=b+428656|0;U=b+572476|0;V=b+6144|0;W=b+572448|0;X=b+2524|0;Y=b+572480|0;Z=m+88|0;_=b+572376|0;$=m+712|0;aa=b+4800|0;ba=b+1088|0;ca=b+1100|0;da=b+1104|0;ea=b+1092|0;fa=b+1096|0;ga=b+8056|0;ha=b+199428|0;ia=b+199424|0;ja=b+199420|0;ka=o;o=0;la=0;ma=0;na=0;b:while(1){oa=(ka|0)==0;pa=na;qa=ma;ra=la;sa=0;ta=o;ua=(c[u>>2]|0)!=0?0:f;va=0;wa=0;c:while(1){if((wa|0)<(ua|0)){xa=wa+3|0;d:do{if((xa|0)<(ua|0)){ya=wa;za=xa;while(1){Aa=ya+1|0;do{if((a[e+ya|0]|0)==0){if((a[e+Aa|0]|0)!=0){break}if((a[e+(ya+2)|0]|0)==1){Ba=za;Ca=1;break d}}}while(0);Da=ya+4|0;if((Da|0)<(ua|0)){ya=Aa;za=Da}else{Ba=Da;Ca=0;break}}}else{Ba=xa;Ca=0}}while(0);if((Ba|0)>=(f|0)){Ea=f;break}if(Ca){Fa=0;Ga=ua;Ha=Ba}else{pa=pa;qa=qa;ra=ra;sa=sa;ta=ta;ua=ua;va=va;wa=Ba;continue}}else{xa=c[q>>2]|0;if((wa|0)>=(f-xa|0)){Ea=wa;break}if((xa|0)<=0){Ia=0;Ja=wa;Ka=25;break}za=(xa|0)>1?xa:1;ya=wa;Da=0;La=0;while(1){Ma=d[e+ya|0]|La<<8;Na=Da+1|0;if((Na|0)<(xa|0)){ya=ya+1|0;Da=Na;La=Ma}else{break}}La=wa+za|0;if((Ma|0)<1){Ia=Ma;Ja=La;Ka=25;break}if((Ma|0)>(f-La|0)){Ia=Ma;Ja=La;Ka=25;break}Fa=Ma;Ga=Ma+La|0;Ha=La}La=c[b+572248+(va<<2)>>2]|0;Da=e+Ha|0;ya=eha(La,Da,k,j,Ga-Ha|0)|0;xa=c[k>>2]|0;if((ya|0)==0|(xa|0)<0){Oa=-1;Pa=Ha;break b}Na=c[j>>2]|0;Qa=Na+Ha|0;Ra=c[t>>2]|0;do{if((Ra&1|0)==0){Sa=Ra}else{Ta=Qa+3|0;if((Ta|0)>=(Ga|0)){Sa=Ra;break}if((a[e+Qa|0]|0)!=0){Sa=Ra;break}if((a[e+(Qa+1)|0]|0)!=0){Sa=Ra;break}if((a[e+(Qa+2)|0]|0)!=1){Sa=Ra;break}if(!((a[e+Ta|0]|0)==-32)){Sa=Ra;break}Ta=Ra|16384;c[t>>2]=Ta;Sa=Ta}}while(0);e:do{if((Sa&16384|0)==0&(xa|0)>0){Ra=xa;while(1){za=Ra-1|0;if((a[ya+za|0]|0)!=0){Ua=Ra;break e}c[k>>2]=za;if((za|0)>0){Ra=za}else{Ua=za;break}}}else{Ua=xa}}while(0);if((Ua|0)==0){Va=0}else{xa=Ua<<3;Ra=d[ya+(Ua-1)|0]|0;do{if((Ra&1|0)==0){if((Ra&2|0)!=0){Wa=2;break}if((Ra&4|0)!=0){Wa=3;break}if((Ra&8|0)!=0){Wa=4;break}if((Ra&16|0)!=0){Wa=5;break}if((Ra&32|0)!=0){Wa=6;break}if((Ra&64|0)!=0){Wa=7;break}Wa=Ra>>>4&8}else{Wa=1}}while(0);Va=xa-Wa|0}Ra=c[l>>2]|0;if((c[Ra+688>>2]&256|0)!=0){za=c[La+427432>>2]|0;KIb(Ra,48,2281384,(Xa=i,i=i+48|0,c[Xa>>2]=c[La+427436>>2],c[Xa+8>>2]=za,c[Xa+16>>2]=Ha,c[Xa+24>>2]=f,c[Xa+32>>2]=Ua,c[Xa+40>>2]=ka,Xa)|0);i=Xa}do{if((c[u>>2]|0)!=0){if(!((Fa|0)!=(Na|0)&(Fa|0)!=0)){break}KIb(c[l>>2]|0,48,2277312,(Xa=i,i=i+16|0,c[Xa>>2]=Na,c[Xa+8>>2]=Fa,Xa)|0);i=Xa}}while(0);xa=sa+1|0;if(oa){za=c[La+427436>>2]|0;switch(za|0){case 2:case 5:case 1:{break};case 7:case 8:{pa=pa;qa=qa;ra=ra;sa=xa;ta=xa;ua=Ga;va=va;wa=Qa;continue c;break};default:{pa=pa;qa=qa;ra=ra;sa=xa;ta=ta;ua=Ga;va=va;wa=Qa;continue c}}Ra=Va>>>0>2147483639>>>0;Ta=Ra?0:ya;Ya=Ra?0:Va;c[La+1088>>2]=Ta;c[La+1100>>2]=Ya;c[La+1104>>2]=Ya+8;c[La+1092>>2]=Ta+(Ya+7>>3);Ya=La+1096|0;c[Ya>>2]=0;Ra=Ta;Ta=je(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0;if(Ta>>>0>134217727>>>0){Ra=Ta>>>23;c[Ya>>2]=d[1382088+Ra|0]|0;Za=d[1276064+Ra|0]|0}else{Ra=Ta>>>0>65535>>>0;_a=Ra?Ta>>>16:Ta;$a=Ra?16:0;if((_a&65280|0)==0){ab=$a;bb=_a}else{ab=$a|8;bb=_a>>>8}_a=(d[1359664+bb|0]|0)+ab<<1;c[Ya>>2]=63-_a;Za=(Ta>>>((_a-31|0)>>>0))-1|0}_a=(qa|0)==0;Ta=(qa|0)==(za|0)&(((Za|0)==0|_a)^1);pa=pa;qa=_a?Ta?qa:za:qa;ra=ra;sa=xa;ta=Ta?ta:xa;ua=Ga;va=va;wa=Qa;continue}do{if((qa|0)==0){Ta=c[La+427436>>2]|0;if(!((Ta|0)==2|(Ta|0)==5|(Ta|0)==1)){cb=0;break}cb=Ta}else{cb=qa}}while(0);do{if((c[v>>2]|0)>7){if((c[w>>2]|0)!=0){break}if((c[p>>2]|0)!=6){pa=pa;qa=cb;ra=ra;sa=xa;ta=ta;ua=Ga;va=va;wa=Qa;continue c}}}while(0);Ta=(ta|0)<(xa|0);za=Va>>>0>2147483639>>>0;_a=za?0:ya;Ya=za?0:Va;za=Ya+8|0;$a=_a+(Ya+7>>3)|0;Ra=(xa|0)>=(ta|0)|0;db=(Fa|0)==0;eb=Ga-1-Qa+Na|0;fb=(eb|0)>268435454;gb=e+(Qa+1-Na)|0;hb=eb<<3;eb=hb>>>0>2147483639>>>0|(gb|0)==0;ib=eb?0:gb;gb=eb?0:hb;hb=gb+8|0;eb=ib+(gb>>3)|0;jb=(Ga-Qa+Na|0)==(Fa|0);kb=La;lb=pa;mb=ra;nb=va;while(1){if(!((c[n>>2]&1|0)!=0&Ta)){c[ga>>2]=-1}ob=kb+427436|0;pb=c[ob>>2]|0;f:do{if(x){Ka=81}else{switch(pb|0){case 5:case 1:case 2:case 3:case 4:{KIb(c[l>>2]|0,24,2272856,(Xa=i,i=i+8|0,c[Xa>>2]=pb,Xa)|0);i=Xa;break};case 19:{break};default:{Ka=81;break f}}c[ob>>2]=267448321;qb=0;rb=lb;sb=mb;tb=nb;ub=kb+427436|0}}while(0);g:do{if((Ka|0)==81){Ka=0;ob=kb+427436|0;do{if((pb|0)==7){c[ba>>2]=_a;c[ca>>2]=Ya;c[da>>2]=za;c[ea>>2]=$a;c[fa>>2]=0;if((xia(b)|0)>=0){qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}if((c[u>>2]|0)!=0&db){qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}KIb(c[l>>2]|0,48,2256024,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;if(!((c[u>>2]|0)==0|jb)){Ka=127;break b}if(fb){qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}c[ba>>2]=ib;c[ca>>2]=gb;c[da>>2]=hb;c[ea>>2]=eb;c[fa>>2]=0;xia(b)|0;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==4){vb=kb+421156|0;c[vb>>2]=_a;c[kb+421168>>2]=Ya;c[kb+421172>>2]=za;c[kb+421160>>2]=$a;c[kb+421164>>2]=0;c[kb+421180>>2]=vb;KIb(c[l>>2]|0,16,2260488,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==6){c[ba>>2]=_a;c[ca>>2]=Ya;c[da>>2]=za;c[ea>>2]=$a;c[fa>>2]=0;Kia(b)|0;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==3){vb=kb+421136|0;c[vb>>2]=_a;c[kb+421148>>2]=Ya;c[kb+421152>>2]=za;c[kb+421140>>2]=$a;c[kb+421144>>2]=0;c[kb+421176>>2]=vb;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==1){wb=mb}else if((pb|0)==2){xb=c[l>>2]|0;if((c[xb+88>>2]&32768|0)!=0){Ka=117;break b}c[kb+1088>>2]=_a;c[kb+1100>>2]=Ya;c[kb+1104>>2]=za;c[kb+1092>>2]=$a;c[kb+1096>>2]=0;c[kb+421180>>2]=0;c[kb+421176>>2]=0;vb=Dha(kb,b)|0;if((vb|0)<0){c[aa>>2]=0;qb=vb;rb=lb;sb=mb;tb=nb;ub=ob;break g}else{c[kb+4800>>2]=1;qb=vb;rb=lb;sb=mb;tb=nb;ub=ob;break g}}else if((pb|0)==8){c[ba>>2]=_a;c[ca>>2]=Ya;c[da>>2]=za;c[ea>>2]=$a;c[fa>>2]=0;zia(b,Va)|0;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==9|(pb|0)==10|(pb|0)==11|(pb|0)==12|(pb|0)==13|(pb|0)==19|(pb|0)==267448321){qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}else if((pb|0)==5){if((c[p>>2]|0)!=5){Ka=83;break b}if((mb|0)!=0){wb=1;break}Fia(b);c[y>>2]=0;c[z>>2]=0;c[A>>2]=65536;c[B>>2]=0;c[C>>2]=-2147483648;c[D>>2]=-2147483648;c[E>>2]=-2147483648;c[F>>2]=-2147483648;c[G>>2]=-2147483648;c[H>>2]=-2147483648;c[I>>2]=-2147483648;c[J>>2]=-2147483648;c[K>>2]=-2147483648;c[L>>2]=-2147483648;c[M>>2]=-2147483648;c[N>>2]=-2147483648;c[O>>2]=-2147483648;c[P>>2]=-2147483648;c[Q>>2]=-2147483648;c[R>>2]=-2147483648;wb=1}else{KIb(g,48,2241496,(Xa=i,i=i+16|0,c[Xa>>2]=pb,c[Xa+8>>2]=Va,Xa)|0);i=Xa;qb=0;rb=lb;sb=mb;tb=nb;ub=ob;break g}}while(0);Aa=kb+1088|0;c[Aa>>2]=_a;c[kb+1100>>2]=Ya;c[kb+1104>>2]=za;c[kb+1092>>2]=$a;c[kb+1096>>2]=0;c[kb+421180>>2]=Aa;c[kb+421176>>2]=Aa;c[kb+4800>>2]=0;Aa=Dha(kb,b)|0;if((Aa|0)!=0){qb=Aa;rb=lb;sb=wb;tb=nb;ub=ob;break}Aa=c[S>>2]|0;do{if((Aa|0)>-1){vb=c[T>>2]|0;if((vb|0)==(Aa|0)){if((c[kb+177080>>2]|0)!=1){Ka=90}}else{Ka=90}if((Ka|0)==90){Ka=0;c[W>>2]=1}yb=c[U>>2]|0;if((yb|0)<0){zb=c[V>>2]|0}else{Ab=c[V>>2]|0;if(((1<<Ab)-1&yb-vb|0)>(Aa|0)){zb=Ab}else{break}}c[U>>2]=(1<<zb)-1&Aa+vb;if((c[W>>2]|0)!=0){break}c[U>>2]=vb}}while(0);Aa=c[X>>2]|0;vb=Aa+84|0;c[vb>>2]=c[vb>>2]|(c[ob>>2]|0)==5;if((c[ob>>2]|0)==5){Ka=98}else{if((c[U>>2]|0)==(c[T>>2]|0)){Ka=98}else{Ka=99}}do{if((Ka|0)==98){Ka=0;c[U>>2]=-1;c[Aa+2200>>2]=1;if((c[ob>>2]|0)!=5){Ka=99;break}vb=c[Y>>2]|1;c[Y>>2]=vb;Bb=vb}}while(0);if((Ka|0)==99){Ka=0;Bb=c[Y>>2]|0}vb=-((c[s>>2]|0)>>>22&1)&3|Bb;c[Y>>2]=vb;Ab=-((c[Z>>2]|0)>>>3&1)&3|vb;c[Y>>2]=Ab;vb=Aa+2200|0;c[vb>>2]=Ab|c[vb>>2];do{if((c[_>>2]|0)==1){if((c[s>>2]&32768|0)==0){Bha(b,Ra)}vb=c[l>>2]|0;Ab=c[vb+712>>2]|0;if((Ab|0)==0){Cb=lb;break}yb=Ee[c[Ab+24>>2]&511](vb,0,0)|0;if((yb|0)<0){Db=yb;Ka=145;break b}else{Cb=yb}}else{Cb=lb}}while(0);if((c[kb+428688>>2]|0)!=0){qb=0;rb=Cb;sb=wb;tb=nb;ub=ob;break}Aa=c[v>>2]|0;do{if((Aa|0)>=8){if((c[kb+427432>>2]|0)==0){qb=0;rb=Cb;sb=wb;tb=nb;ub=ob;break g}if((Aa|0)<16){break}yb=c[kb+177080>>2]|0;if((yb|0)==3){qb=0;rb=Cb;sb=wb;tb=nb;ub=ob;break g}if((Aa|0)<32){break}if(!((yb|0)==1&(Aa|0)<48)){qb=0;rb=Cb;sb=wb;tb=nb;ub=ob;break g}}}while(0);Aa=c[$>>2]|0;if((Aa|0)==0){qb=0;rb=Cb;sb=wb;tb=nb+1|0;ub=ob;break}else{yb=Ee[c[Aa+28>>2]&511](m,Da,Na)|0;if((yb|0)<0){Db=yb;Ka=145;break b}else{qb=0;rb=yb;sb=wb;tb=nb;ub=ob;break}}}}while(0);if((tb|0)==(c[r>>2]|0)){Eha(b,tb);Eb=0}else{Eb=tb}if((qb|0)<0){break}if((qb|0)!=1){pa=rb;qa=cb;ra=sb;sa=xa;ta=ta;ua=Ga;va=Eb;wa=Qa;continue c}c[p>>2]=c[ub>>2];c[w>>2]=c[kb+427432>>2];kb=b;lb=rb;mb=sb;nb=Eb}KIb(c[l>>2]|0,16,2235560,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;c[ha>>2]=0;c[ia>>2]=0;c[ja>>2]=0;pa=rb;qa=cb;ra=sb;sa=xa;ta=ta;ua=Ga;va=Eb;wa=Qa}if((Ka|0)==25){Ka=0;KIb(c[l>>2]|0,16,2285416,(Xa=i,i=i+8|0,c[Xa>>2]=Ia,Xa)|0);i=Xa;Ea=Ja}wa=ka+1|0;if((wa|0)<2){ka=wa;o=ta;la=ra;ma=qa;na=pa}else{Ka=139;break}}do{if((Ka|0)==83){KIb(c[l>>2]|0,16,2268024,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;Oa=-1;Pa=Qa}else if((Ka|0)==117){KIb(xb,16,2264272,(Xa=i,i=i+1|0,i=i+7&-8,c[Xa>>2]=0,Xa)|0);i=Xa;Db=-38;i=h;return Db|0}else if((Ka|0)==127){KIb(0,0,2122224,(Xa=i,i=i+24|0,c[Xa>>2]=2251872,c[Xa+8>>2]=2617208,c[Xa+16>>2]=5089,Xa)|0);i=Xa;Hd();return 0}else if((Ka|0)==139){if((va|0)==0){Oa=pa;Pa=Ea;break}Eha(b,va);Oa=pa;Pa=Ea}else if((Ka|0)==145){i=h;return Db|0}}while(0);Ka=c[b+2524>>2]|0;do{if((Ka|0)!=0){if((c[b+4796>>2]|0)!=0){break}L5a(Ka+1496|0,2147483647,(c[b+177100>>2]|0)==2|0)}}while(0);Db=(Oa|0)<0?Oa:Pa;i=h;return Db|0}function kha(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;d=c[a+60>>2]|0;e=d;f=d;c[f>>2]=a;c[d+427468>>2]=8;c[d+427472>>2]=1;g=a+796|0;c[g>>2]=8;c[d+572632>>2]=1;bja(d+12|0,8,1);if((c[d+7312>>2]|0)!=0){KIb(0,0,2122224,(h=i,i=i+24|0,c[h>>2]=2639968,c[h+8>>2]=2617208,c[h+16>>2]=1585,h)|0);i=h;Hd();return 0}Mia(d+148|0,0);nta(d+180|0,8);zma(d+4932|0,c[(c[f>>2]|0)+48>>2]|0,8,1);c[d+428628>>2]=-1;c[d+6120>>2]=-1;l8(d+1108|0,c[f>>2]|0);G8a(d+4|0,8);mrc(d+7396|0,16,224)|0;c[d+177100>>2]=3;c[d+572384>>2]=1;c[d+4820>>2]=c[a+676>>2];c[d+4816>>2]=c[a+88>>2];if((c[a+176>>2]|0)==0){c[d+4808>>2]=1}c[a+400>>2]=1;fia();Imb();c[d+4752>>2]=0;c[g>>2]=8;c[d+7308>>2]=8;c[d+572248>>2]=e;g=d+571432|0;c[g>>2]=-2147483648;h=d+571428|0;c[h>>2]=-2147483648;j=d+571360|0;c[j>>2]=-2147483648;c[d+571364>>2]=-2147483648;c[d+571368>>2]=-2147483648;c[d+571372>>2]=-2147483648;c[d+571376>>2]=-2147483648;c[d+571380>>2]=-2147483648;c[d+571384>>2]=-2147483648;c[d+571388>>2]=-2147483648;c[d+571392>>2]=-2147483648;c[d+571396>>2]=-2147483648;c[d+571400>>2]=-2147483648;c[d+571404>>2]=-2147483648;c[d+571408>>2]=-2147483648;c[d+571412>>2]=-2147483648;c[d+571416>>2]=-2147483648;c[d+571420>>2]=-2147483648;k=d+428660|0;c[k>>2]=65536;l=d+428676|0;c[l>>2]=-1;c[d+427372>>2]=-1;c[d+572456>>2]=-1;Jia(e);if((c[a+48>>2]|0)==28){m=a+112|0;do{if((c[m>>2]|0)==1){n=c[f>>2]|0;o=n+108|0;p=c[o>>2]|0;if((p|0)<1073741823){c[o>>2]=p<<1;break}else{p=n+104|0;c[p>>2]=(c[p>>2]|0)/2|0;break}}}while(0);c[m>>2]=2}m=c[a+100>>2]|0;do{if((m|0)>0){p=c[a+96>>2]|0;if((p|0)==0){break}n=iha(e,p,m)|0;if((n|0)>=0){break}hha(e,1);p=0;while(1){mJb(e+427476+(p<<2)|0);o=p+1|0;if((o|0)<32){p=o}else{q=0;break}}while(1){mJb(e+427604+(q<<2)|0);p=q+1|0;if((p|0)<256){q=p}else{r=n;break}}i=b;return r|0}}while(0);do{if((c[d+6784>>2]|0)!=0){q=(c[f>>2]|0)+176|0;m=c[d+6788>>2]|0;if((c[q>>2]|0)>=(m|0)){break}c[q>>2]=m;c[d+4808>>2]=0}}while(0);c[(c[a+64>>2]|0)+4>>2]=1;c[g>>2]=-2147483648;c[h>>2]=-2147483648;c[d+572412>>2]=1;Fia(e);c[d+428672>>2]=0;c[k>>2]=65536;c[d+428664>>2]=0;c[j>>2]=-2147483648;c[d+571364>>2]=-2147483648;c[d+571368>>2]=-2147483648;c[d+571372>>2]=-2147483648;c[d+571376>>2]=-2147483648;c[d+571380>>2]=-2147483648;c[d+571384>>2]=-2147483648;c[d+571388>>2]=-2147483648;c[d+571392>>2]=-2147483648;c[d+571396>>2]=-2147483648;c[d+571400>>2]=-2147483648;c[d+571404>>2]=-2147483648;c[d+571408>>2]=-2147483648;c[d+571412>>2]=-2147483648;c[d+571416>>2]=-2147483648;c[d+571420>>2]=-2147483648;c[l>>2]=-1;l=d+2524|0;j=c[l>>2]|0;if((j|0)!=0){c[j+2192>>2]=0;k=c[d+571288>>2]|0;a:do{if((k|0)==0){s=0}else{h=1;g=0;a=k;f=j;while(1){if((a|0)==(f|0)){t=g}else{c[e+571288+(g<<2)>>2]=a;t=g+1|0}m=c[e+571288+(h<<2)>>2]|0;if((m|0)==0){s=t;break a}h=h+1|0;g=t;a=m;f=c[l>>2]|0}}}while(0);c[e+571288+(s<<2)>>2]=0}c[d+177104>>2]=0;mrc(d+199440|0,0,213504)|0;mrc(d+428696|0,0,142336)|0;Jia(e);c[d+572476>>2]=-1;c[d+572480>>2]=0;c[d+199428>>2]=0;c[d+572376>>2]=0;c[d+572232>>2]=1;r=0;i=b;return r|0}function lha(a){a=a|0;var b=0,c=0,d=0;hha(a,1);b=0;while(1){mJb(a+427476+(b<<2)|0);c=b+1|0;if((c|0)<32){b=c}else{d=0;break}}do{mJb(a+427604+(d<<2)|0);d=d+1|0;}while((d|0)<256);return}function mha(a){a=a|0;var b=0;do{if((c[a+427416>>2]|0)==0){if((c[(c[a+4064>>2]|0)+(c[a+427412>>2]<<2)>>2]&4|0)!=0){b=1;break}b=(c[a+4792>>2]|0)==0}else{b=1}}while(0);if((c[a+6136>>2]|0)==3){do{if(!b){if((c[a+4752>>2]|0)!=0){break}oha(a);return}}while(0);nha(a);return}if(b){pha(a);return}if((c[a+4752>>2]|0)==0){rha(a);return}else{qha(a);return}}function nha(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0;g=i;i=i+32|0;h=g|0;j=g+8|0;k=g+16|0;l=f+427376|0;m=c[l>>2]|0;n=f+427380|0;o=c[n>>2]|0;p=f+427412|0;q=c[p>>2]|0;r=f+4064|0;s=c[(c[r>>2]|0)+(q<<2)>>2]|0;t=f+4792|0;if((c[t>>2]|0)==0){u=(c[f+6140>>2]|0)!=0|0}else{u=0}v=f+4752|0;w=f+4776|0;x=f+8|0;y=c[f+2528>>2]|0;z=c[v>>2]|0;A=c[w>>2]|0;B=(ca(A,o)|0)+(m<<z)<<4;C=y+B|0;D=k|0;c[D>>2]=C;E=y+((ca(m<<2&12,A)|0)+B+(64<<z))|0;ef[c[x>>2]&4095](E,A,4);A=c[f+2532>>2]|0;E=c[v>>2]|0;z=c[w>>2]|0;F=(ca(z,o)|0)+(m<<E)<<4;H=A+F|0;I=k+4|0;c[I>>2]=H;J=A+((ca(c[l>>2]<<2&12,z)|0)+F+(64<<E))|0;ef[c[x>>2]&4095](J,z,4);z=c[f+2536>>2]|0;J=c[v>>2]|0;E=c[w>>2]|0;K=(ca(E,o)|0)+(m<<J)<<4;m=z+K|0;L=k+8|0;c[L>>2]=m;M=z+((ca(c[l>>2]<<2&12,E)|0)+K+(64<<J))|0;ef[c[x>>2]&4095](M,E,4);E=f+199428|0;a[(c[f+199432>>2]|0)+q|0]=c[E>>2];q=f+177092|0;M=c[w>>2]|0;do{if((c[q>>2]|0)==0){c[f+6116>>2]=M;c[f+6112>>2]=M;N=M;O=f+5716|0;P=m;Q=C;R=H}else{J=M<<1;c[f+6116>>2]=J;c[f+6112>>2]=J;S=f+5908|0;if((o&1|0)==0){T=m;U=C;V=H}else{W=M*-15|0;X=y+(B+W)|0;c[D>>2]=X;Y=A+(F+W)|0;c[I>>2]=Y;Z=z+(K+W)|0;c[L>>2]=Z;T=Z;U=X;V=Y}if((c[f+177088>>2]|0)==0){N=J;O=S;P=T;Q=U;R=V;break}if((c[E>>2]|0)==0){N=J;O=S;P=T;Q=U;R=V;break}Y=(s&8|0)==0;X=0;while(1){do{if((12288<<(X<<1)&s|0)!=0){Z=f+5632+(X*40|0)+12|0;W=a[Z]|0;if(!Y){_=ca((W<<24>>24)+16^c[n>>2]&1,16843009)|0;c[Z>>2]=_;c[f+5632+(X*40|0)+20>>2]=_;c[f+5632+(X*40|0)+28>>2]=_;c[f+5632+(X*40|0)+36>>2]=_;break}if(W<<24>>24>-1){_=((c[n>>2]&1^(W<<24>>24)+16)*257|0)&65535;b[Z>>1]=_;b[f+5632+(X*40|0)+20>>1]=_}_=f+5632+(X*40|0)+14|0;Z=a[_]|0;if(Z<<24>>24>-1){W=((c[n>>2]&1^(Z<<24>>24)+16)*257|0)&65535;b[_>>1]=W;b[f+5632+(X*40|0)+22>>1]=W}W=f+5632+(X*40|0)+28|0;_=a[W]|0;if(_<<24>>24>-1){Z=((c[n>>2]&1^(_<<24>>24)+16)*257|0)&65535;b[W>>1]=Z;b[f+5632+(X*40|0)+36>>1]=Z}Z=f+5632+(X*40|0)+30|0;W=a[Z]|0;if(!(W<<24>>24>-1)){break}_=((c[n>>2]&1^(W<<24>>24)+16)*257|0)&65535;b[Z>>1]=_;b[f+5632+(X*40|0)+38>>1]=_}}while(0);_=X+1|0;if(_>>>0<(c[E>>2]|0)>>>0){X=_}else{N=J;O=S;P=T;Q=U;R=V;break}}}}while(0);if((s&4|0)!=0){if((c[v>>2]|0)==0){V=f+421184|0;U=0;while(1){T=Q+(ca(U,N)|0)|0;nrc(T|0,(c[V>>2]|0)+(U<<4)|0,16)|0;T=U+1|0;if((T|0)<16){U=T}else{$=0;break}}while(1){U=R+(ca($,N)|0)|0;nrc(U|0,(c[V>>2]|0)+(($<<4)+256)|0,16)|0;U=$+1|0;if((U|0)<16){$=U}else{aa=0;break}}do{$=P+(ca(aa,N)|0)|0;nrc($|0,(c[V>>2]|0)+((aa<<4)+512)|0,16)|0;aa=aa+1|0;}while((aa|0)<16);i=g;return}aa=c[f+7308>>2]|0;V=c[f+421184>>2]|0;$=(aa*768|0)>>>0>2147483639>>>0|(V|0)==0?0:V;V=32-aa|0;U=aa<<4;T=aa<<8;E=0;L=0;while(1){K=Q+(ca(L,N)|0)|0;z=E;I=0;while(1){F=$+(z>>>3)|0;b[K+(I<<1)>>1]=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(z&7)>>>(V>>>0);F=I+1|0;if((F|0)<16){z=z+aa|0;I=F}else{break}}I=L+1|0;if((I|0)<16){E=U+E|0;L=I}else{ba=T;da=0;break}}while(1){T=R+(ca(da,N)|0)|0;L=ba;E=0;while(1){I=$+(L>>>3)|0;b[T+(E<<1)>>1]=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>(V>>>0);I=E+1|0;if((I|0)<16){L=L+aa|0;E=I}else{break}}E=da+1|0;if((E|0)<16){ba=U+ba|0;da=E}else{break}}da=aa<<9;ba=0;while(1){E=P+(ca(ba,N)|0)|0;L=da;T=0;while(1){I=$+(L>>>3)|0;b[E+(T<<1)>>1]=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(L&7)>>>(V>>>0);I=T+1|0;if((I|0)<16){L=L+aa|0;T=I}else{break}}T=ba+1|0;if((T|0)<16){da=U+da|0;ba=T}else{break}}i=g;return}a:do{if((s&7|0)==0){ba=c[f+1028>>2]|0;da=f+148|0;U=c[f+1032>>2]|0;aa=f+164|0;V=f+12|0;$=f+28|0;T=c[(c[r>>2]|0)+(c[p>>2]<<2)>>2]|0;L=c[v>>2]|0;E=a[f+5644|0]|0;if(E<<24>>24>-1){I=E<<24>>24;E=c[l>>2]|0;z=((E<<4|8)+(b[f+5360>>1]>>2)<<L)+(64<<L)+(ca((c[n>>2]<<4|E<<2&12)+(b[f+5362>>1]>>2)|0,N)|0)|0;ef[c[x>>2]&4095]((c[f+199440+(I*2224|0)>>2]|0)+z|0,M,4);ef[c[x>>2]&4095]((c[f+199440+(I*2224|0)+4>>2]|0)+z|0,c[w>>2]|0,4);ef[c[x>>2]&4095]((c[f+199440+(I*2224|0)+8>>2]|0)+z|0,c[w>>2]|0,4)}do{if((T&8|0)==0){if((T&16|0)!=0){z=ba+64|0;I=U+64|0;Uha(f,0,0,8,8<<c[v>>2],Q,R,P,0,0,z,c[da>>2]|0,I,c[aa>>2]|0,V,$,T&4096,T&16384);Uha(f,8,0,8,8<<c[v>>2],Q,R,P,0,4,z,c[da>>2]|0,I,c[aa>>2]|0,V,$,T&8192,T&32768);break}I=f+6112|0;if((T&32|0)!=0){z=ba+64|0;E=f+152|0;L=U+64|0;K=f+168|0;F=f+16|0;A=f+32|0;Uha(f,0,0,16,c[I>>2]<<3,Q,R,P,0,0,z,c[E>>2]|0,L,c[K>>2]|0,F,A,T&4096,T&16384);Uha(f,4,0,16,c[I>>2]<<3,Q,R,P,4,0,z,c[E>>2]|0,L,c[K>>2]|0,F,A,T&8192,T&32768);break}A=ba+128|0;F=f+156|0;K=U+128|0;L=f+172|0;E=f+20|0;z=f+36|0;D=f+152|0;B=f+168|0;y=f+16|0;H=f+32|0;C=ba+64|0;m=U+64|0;o=0;do{S=e[f+177112+(o<<1)>>1]|0;J=o<<2;X=J&4;Y=o<<1&4;do{if((S&8|0)==0){if((S&16|0)!=0){_=S&4096;Z=S&16384;Uha(f,J,0,4,4<<c[v>>2],Q,R,P,X,Y,A,c[D>>2]|0,K,c[B>>2]|0,y,H,_,Z);Uha(f,J|2,0,4,4<<c[v>>2],Q,R,P,X,Y|2,A,c[D>>2]|0,K,c[B>>2]|0,y,H,_,Z);break}if((S&32|0)==0){Z=S&4096;_=S&16384;Uha(f,J,1,4,0,Q,R,P,X,Y,A,c[F>>2]|0,K,c[L>>2]|0,E,z,Z,_);W=X|2;Uha(f,J|1,1,4,0,Q,R,P,W,Y,A,c[F>>2]|0,K,c[L>>2]|0,E,z,Z,_);ea=Y|2;Uha(f,J|2,1,4,0,Q,R,P,X,ea,A,c[F>>2]|0,K,c[L>>2]|0,E,z,Z,_);Uha(f,J|3,1,4,0,Q,R,P,W,ea,A,c[F>>2]|0,K,c[L>>2]|0,E,z,Z,_);break}else{_=S&4096;Z=S&16384;Uha(f,J,0,8,c[I>>2]<<2,Q,R,P,X,Y,A,c[F>>2]|0,K,c[L>>2]|0,E,z,_,Z);Uha(f,J|1,0,8,c[I>>2]<<2,Q,R,P,X|2,Y,A,c[F>>2]|0,K,c[L>>2]|0,E,z,_,Z);break}}else{Uha(f,J,1,8,0,Q,R,P,X,Y,C,c[D>>2]|0,m,c[B>>2]|0,y,H,S&4096,S&16384)}}while(0);o=o+1|0;}while((o|0)<4)}else{Uha(f,0,1,16,0,Q,R,P,0,0,ba|0,c[da>>2]|0,U|0,c[aa>>2]|0,V,$,T&4096,T&16384)}}while(0);T=c[v>>2]|0;$=a[f+5684|0]|0;if(!($<<24>>24>-1)){break}V=$<<24>>24;$=c[l>>2]|0;aa=(($<<4|8)+(b[f+5520>>1]>>2)<<T)+(64<<T)+(ca((c[n>>2]<<4|$<<2&12)+(b[f+5522>>1]>>2)|0,c[f+6112>>2]|0)|0)|0;ef[c[x>>2]&4095]((c[f+306192+(V*2224|0)>>2]|0)+aa|0,c[w>>2]|0,4);ef[c[x>>2]&4095]((c[f+306192+(V*2224|0)+4>>2]|0)+aa|0,c[w>>2]|0,4);ef[c[x>>2]&4095]((c[f+306192+(V*2224|0)+8>>2]|0)+aa|0,c[w>>2]|0,4)}else{aa=f+427420|0;V=c[aa>>2]|0;b:do{if((V|0)!=0){$=c[v>>2]|0;do{if((c[f+177088>>2]|0)==0){fa=1}else{T=(c[f+177096>>2]|0)!=0;if((c[n>>2]&1|0)==0){fa=T&1^1;break}else{if(T){fa=1;break}else{break b}}}}while(0);if((V|0)==2){ga=(e[(c[f+177072>>2]|0)+((c[p>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);ha=c[f+4864>>2]|0;ia=c[l>>2]|0}else{T=c[l>>2]|0;ga=(T|0)>0;ha=(c[n>>2]|0)>((c[q>>2]|0)!=0|0)|0;ia=T}T=N+1+$|0;U=ia-1|0;da=f+5176+(fa<<2)|0;ba=c[da>>2]|0;o=ba+(ia*96|0)|0;if((ha|0)==0){break}do{if(ga){H=8<<$;y=ba+(U*96|0)+H|0;B=c[y>>2]|0;m=c[y+4>>2]|0;D=(-7<<$)-T|0;C=Q+D|0;z=c[C+4>>2]|0;c[y>>2]=c[C>>2];c[y+4>>2]=z;c[C>>2]=B;c[C+4>>2]=m;if(($|0)==0){m=o;ja=Q+(1-T)|0;ka=1;la=c[m+4>>2]|0;ma=c[m>>2]|0;na=m;oa=41;break}else{m=H+8+(ba+(U*96|0))|0;H=c[m>>2]|0;C=c[m+4>>2]|0;B=Q+(D+8)|0;D=c[B+4>>2]|0;c[m>>2]=c[B>>2];c[m+4>>2]=D;c[B>>2]=H;c[B+4>>2]=C;oa=39;break}}else{oa=39}}while(0);do{if((oa|0)==39){C=o;B=c[C>>2]|0;H=c[C+4>>2]|0;D=1<<$;m=D-T|0;z=Q+m|0;if(($|0)==0){ja=z;ka=D;la=H;ma=B;na=C;oa=41;break}y=c[z+4>>2]|0;c[C>>2]=c[z>>2];c[C+4>>2]=y;c[z>>2]=B;c[z+4>>2]=H;H=ba+(ia*96|0)+8|0;z=c[H>>2]|0;B=c[H+4>>2]|0;y=Q+(m+8)|0;m=c[y+4>>2]|0;c[H>>2]=c[y>>2];c[H+4>>2]=m;c[y>>2]=z;c[y+4>>2]=B;pa=1;qa=D}}while(0);if((oa|0)==41){o=c[ja+4>>2]|0;c[na>>2]=c[ja>>2];c[na+4>>2]=o;c[ja>>2]=ma;c[ja+4>>2]=la;pa=0;qa=ka}o=8<<$;D=ba+(ia*96|0)+o|0;B=c[D>>2]|0;y=c[D+4>>2]|0;z=(9<<$)-T|0;m=Q+z|0;H=c[m+4>>2]|0;c[D>>2]=c[m>>2];c[D+4>>2]=H;c[m>>2]=B;c[m+4>>2]=y;if(pa){y=o+8+(ba+(ia*96|0))|0;o=c[y>>2]|0;m=c[y+4>>2]|0;B=Q+(z+8)|0;H=c[B+4>>2]|0;c[y>>2]=c[B>>2];c[y+4>>2]=H;c[B>>2]=o;c[B+4>>2]=m}m=(c[l>>2]|0)+1|0;B=f+427400|0;do{if((m|0)<(c[B>>2]|0)){o=(c[da>>2]|0)+(m*96|0)|0;H=c[o>>2]|0;y=c[o+4>>2]|0;D=(17<<$)-T|0;C=Q+D|0;E=c[C+4>>2]|0;c[o>>2]=c[C>>2];c[o+4>>2]=E;c[C>>2]=H;c[C+4>>2]=y;if(!pa){break}y=(c[da>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+8|0;C=c[y>>2]|0;H=c[y+4>>2]|0;E=Q+(D+8)|0;D=c[E+4>>2]|0;c[y>>2]=c[E>>2];c[y+4>>2]=D;c[E>>2]=C;c[E+4>>2]=H}}while(0);do{if(ga){m=24<<$;H=ba+(U*96|0)+m|0;E=c[H>>2]|0;C=c[H+4>>2]|0;D=(-7<<$)-T|0;y=R+D|0;o=c[y+4>>2]|0;c[H>>2]=c[y>>2];c[H+4>>2]=o;c[y>>2]=E;c[y+4>>2]=C;if(pa){C=m+8+(ba+(U*96|0))|0;m=c[C>>2]|0;y=c[C+4>>2]|0;E=R+(D+8)|0;o=c[E+4>>2]|0;c[C>>2]=c[E>>2];c[C+4>>2]=o;c[E>>2]=m;c[E+4>>2]=y}y=40<<$;E=ba+(U*96|0)+y|0;m=c[E>>2]|0;o=c[E+4>>2]|0;C=P+D|0;H=c[C+4>>2]|0;c[E>>2]=c[C>>2];c[E+4>>2]=H;c[C>>2]=m;c[C+4>>2]=o;if(pa){o=y+8+(ba+(U*96|0))|0;y=c[o>>2]|0;C=c[o+4>>2]|0;m=P+(D+8)|0;D=c[m+4>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=D;c[m>>2]=y;c[m+4>>2]=C;C=16<<$;m=ba+(ia*96|0)+C|0;y=qa-T|0;ra=C;sa=m;ta=c[m+4>>2]|0;ua=c[m>>2]|0;va=y;wa=R+y|0;oa=54;break}else{y=16<<$;m=ba+(ia*96|0)+y|0;C=qa-T|0;xa=y;ya=m;za=c[m+4>>2]|0;Aa=c[m>>2]|0;Ba=C;Ca=R+C|0;oa=55;break}}else{C=16<<$;m=ba+(ia*96|0)+C|0;y=c[m>>2]|0;D=c[m+4>>2]|0;o=qa-T|0;H=R+o|0;if(pa){ra=C;sa=m;ta=D;ua=y;va=o;wa=H;oa=54}else{xa=C;ya=m;za=D;Aa=y;Ba=o;Ca=H;oa=55}}}while(0);if((oa|0)==54){U=c[wa+4>>2]|0;c[sa>>2]=c[wa>>2];c[sa+4>>2]=U;c[wa>>2]=ua;c[wa+4>>2]=ta;U=ra+8+(ba+(ia*96|0))|0;H=c[U>>2]|0;o=c[U+4>>2]|0;y=R+(va+8)|0;D=c[y+4>>2]|0;c[U>>2]=c[y>>2];c[U+4>>2]=D;c[y>>2]=H;c[y+4>>2]=o;Da=1;Ea=ra;Fa=va}else if((oa|0)==55){o=c[Ca+4>>2]|0;c[ya>>2]=c[Ca>>2];c[ya+4>>2]=o;c[Ca>>2]=Aa;c[Ca+4>>2]=za;Da=0;Ea=xa;Fa=Ba}o=24<<$;y=ba+(ia*96|0)+o|0;H=c[y>>2]|0;D=c[y+4>>2]|0;U=R+z|0;m=c[U+4>>2]|0;c[y>>2]=c[U>>2];c[y+4>>2]=m;c[U>>2]=H;c[U+4>>2]=D;if(Da){D=o+8+(ba+(ia*96|0))|0;o=c[D>>2]|0;U=c[D+4>>2]|0;H=R+(z+8)|0;m=c[H+4>>2]|0;c[D>>2]=c[H>>2];c[D+4>>2]=m;c[H>>2]=o;c[H+4>>2]=U;U=32<<$;H=ba+(ia*96|0)+U|0;o=c[H>>2]|0;m=c[H+4>>2]|0;D=P+Fa|0;y=c[D+4>>2]|0;c[H>>2]=c[D>>2];c[H+4>>2]=y;c[D>>2]=o;c[D+4>>2]=m;m=U+8+(ba+(ia*96|0))|0;D=c[m>>2]|0;o=c[m+4>>2]|0;y=P+(Fa+8)|0;H=c[y+4>>2]|0;c[m>>2]=c[y>>2];c[m+4>>2]=H;c[y>>2]=D;c[y+4>>2]=o;Ga=U}else{U=32<<$;o=ba+(ia*96|0)+U|0;y=c[o>>2]|0;D=c[o+4>>2]|0;H=P+Fa|0;m=c[H+4>>2]|0;c[o>>2]=c[H>>2];c[o+4>>2]=m;c[H>>2]=y;c[H+4>>2]=D;Ga=U}U=40<<$;D=ba+(ia*96|0)+U|0;H=c[D>>2]|0;y=c[D+4>>2]|0;m=P+z|0;o=c[m+4>>2]|0;c[D>>2]=c[m>>2];c[D+4>>2]=o;c[m>>2]=H;c[m+4>>2]=y;if(Da){y=U+8+(ba+(ia*96|0))|0;U=c[y>>2]|0;m=c[y+4>>2]|0;H=P+(z+8)|0;o=c[H+4>>2]|0;c[y>>2]=c[H>>2];c[y+4>>2]=o;c[H>>2]=U;c[H+4>>2]=m}m=(c[l>>2]|0)+1|0;if((m|0)>=(c[B>>2]|0)){break}H=(c[da>>2]|0)+(m*96|0)+Ea|0;m=c[H>>2]|0;U=c[H+4>>2]|0;o=(17<<$)-T|0;y=R+o|0;D=c[y+4>>2]|0;c[H>>2]=c[y>>2];c[H+4>>2]=D;c[y>>2]=m;c[y+4>>2]=U;if(Da){U=Ea+8+((c[da>>2]|0)+(((c[l>>2]|0)+1|0)*96|0))|0;y=c[U>>2]|0;m=c[U+4>>2]|0;D=R+(o+8)|0;H=c[D+4>>2]|0;c[U>>2]=c[D>>2];c[U+4>>2]=H;c[D>>2]=y;c[D+4>>2]=m;Ha=1}else{Ha=0}m=(c[da>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+Ga|0;D=c[m>>2]|0;y=c[m+4>>2]|0;H=P+o|0;U=c[H+4>>2]|0;c[m>>2]=c[H>>2];c[m+4>>2]=U;c[H>>2]=D;c[H+4>>2]=y;if(!Ha){break}y=Ga+8+((c[da>>2]|0)+(((c[l>>2]|0)+1|0)*96|0))|0;H=c[y>>2]|0;D=c[y+4>>2]|0;U=P+(o+8)|0;o=c[U+4>>2]|0;c[y>>2]=c[U>>2];c[y+4>>2]=o;c[U>>2]=H;c[U+4>>2]=D}}while(0);V=h;D=j;U=(s&1|0)==0;H=f+4836|0;o=(u|0)==0;y=f+128|0;m=(s&16777216|0)==0;C=(u|0)!=0;E=f+140|0;L=f+6128|0;K=f+421200|0;F=f+5168|0;A=3-N|0;I=3-((N|0)/2|0)|0;S=f+104|0;Y=f+96|0;X=f+136|0;J=f+5160|0;Z=f+108|0;_=f+100|0;ea=0;do{W=c[v>>2]|0;Ia=c[k+(ea<<2)>>2]|0;if((ea|0)==0){Ja=t}else{Ja=f+4756+(ea-1<<2)|0}Ka=c[Ja>>2]|0;La=ea<<4;c:do{if(U){re[c[f+5084+(c[H>>2]<<2)>>2]&1023](Ia,N);if((a[(d[ea+602376|0]|0)+(f+5184)|0]|0)==0){break}if(o){ef[c[y>>2]&4095](f+421200+(ea<<8<<W<<1)|0,f+424272+(ea<<6)|0,c[(c[f+177020+(ea<<2)>>2]|0)+(Ka<<6)>>2]|0);break}Ma=ea<<8<<W;Na=(W|0)==0;Oa=f+424272+(ea<<6)|0;Pa=f+421200+(Ma<<1)|0;Qa=0;do{Ra=d[1091856+Qa|0]|0;if(Na){b[f+421200+(Ra+Ma<<1)>>1]=b[f+424272+(ea<<6)+(Qa<<1)>>1]|0}else{c[Pa+(Ra<<2)>>2]=c[Oa+(Qa<<2)>>2]}Qa=Qa+1|0;}while((Qa|0)<16)}else{if(!m){if(C){Qa=c[X>>2]|0;Sa=Qa;Ta=Qa}else{Sa=c[_>>2]|0;Ta=c[Z>>2]|0}Qa=ea<<8;Oa=(W|0)==0;Pa=0;while(1){Ma=Pa+La|0;Na=Ia+(c[O+(Ma<<2)>>2]|0)|0;Ra=a[(d[602328+Pa|0]|0)+(f+4888)|0]|0;Ua=Ra<<24>>24;do{if(C){if(!((c[L>>2]|0)==244&Ra<<24>>24<2)){oa=78;break}ef[c[f+5128+(Ua<<2)>>2]&4095](Na,f+421200+((Pa<<4)+Qa<<W<<1)|0,N)}else{oa=78}}while(0);d:do{if((oa|0)==78){oa=0;Ra=a[(d[602328+Ma|0]|0)+(f+5184)|0]|0;mf[c[f+4992+(Ua<<2)>>2]&2047](Na,c[J>>2]<<Pa&32768,c[F>>2]<<Pa&16384,N);do{if((Ra<<24>>24|0)==1){Va=(Pa<<4)+Qa|0;if(Oa){Wa=e[f+421200+(Va<<1)>>1]|0}else{Wa=c[K+(Va<<2)>>2]|0}if((Wa|0)==0){Xa=Va;break}ef[Ta&4095](Na,f+421200+(Va<<W<<1)|0,N);break d}else if((Ra<<24>>24|0)==0){break d}else{Xa=(Pa<<4)+Qa|0}}while(0);ef[Sa&4095](Na,f+421200+(Xa<<W<<1)|0,N)}}while(0);Pa=Pa+4|0;if((Pa|0)>=16){break c}}}if(C){Pa=c[E>>2]|0;Ya=Pa;Za=Pa}else{Ya=c[Y>>2]|0;Za=c[S>>2]|0}Pa=ea<<8;Qa=(W|0)==0;Oa=(4<<W)-N|0;Na=0;do{Ua=Na+La|0;Ma=c[O+(Ua<<2)>>2]|0;Ra=Ia+Ma|0;Va=a[(d[602328+Na|0]|0)+(f+4888)|0]|0;_a=Va<<24>>24;do{if(C){if(!((c[L>>2]|0)==244&Va<<24>>24<2)){oa=94;break}ef[c[f+5120+(_a<<2)>>2]&4095](Ra,f+421200+((Na<<4)+Pa<<W<<1)|0,N)}else{oa=94}}while(0);e:do{if((oa|0)==94){oa=0;do{if((Va<<24>>24|0)==7|(Va<<24>>24|0)==3){if((c[F>>2]&32768>>>(Na>>>0)|0)!=0){$a=Ia+(Oa+Ma)|0;break}if(Qa){c[h>>2]=ca(d[Ia+(A+Ma)|0]|0,16843009)|0;$a=V;break}else{ab=Erc(e[Ra+(I<<1)>>1]|0,0,65537,65537)|0;c[j>>2]=ab;c[j+4>>2]=G;$a=D;break}}else{$a=0}}while(0);ef[c[f+4932+(_a<<2)>>2]&4095](Ra,$a,N);ab=a[(d[602328+Ua|0]|0)+(f+5184)|0]|0;if(ab<<24>>24==0){break}bb=(Na<<4)+Pa|0;do{if(ab<<24>>24==1){if(Qa){cb=e[f+421200+(bb<<1)>>1]|0}else{cb=c[K+(bb<<2)>>2]|0}if((cb|0)==0){break}ef[Za&4095](Ra,f+421200+(bb<<W<<1)|0,N);break e}}while(0);ef[Ya&4095](Ra,f+421200+(bb<<W<<1)|0,N)}}while(0);Na=Na+1|0;}while((Na|0)<16)}}while(0);ea=ea+1|0;}while((ea|0)<3);ea=c[aa>>2]|0;if((ea|0)==0){break}K=c[v>>2]|0;do{if((c[f+177088>>2]|0)==0){db=1}else{D=(c[f+177096>>2]|0)!=0;if((c[n>>2]&1|0)==0){db=D&1^1;break}else{if(D){db=1;break}else{break a}}}}while(0);if((ea|0)==2){eb=(e[(c[f+177072>>2]|0)+((c[p>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);fb=c[f+4864>>2]|0;gb=c[l>>2]|0}else{aa=c[l>>2]|0;eb=(aa|0)>0;fb=(c[n>>2]|0)>((c[q>>2]|0)!=0|0)|0;gb=aa}aa=N+1+K|0;D=gb-1|0;I=f+5176+(db<<2)|0;V=c[I>>2]|0;A=V+(gb*96|0)|0;if((fb|0)==0){break}do{if(eb){F=8<<K;L=V+(D*96|0)+F|0;C=c[L>>2]|0;S=c[L+4>>2]|0;Y=(-7<<K)-aa|0;E=Q+Y|0;J=c[E+4>>2]|0;c[L>>2]=c[E>>2];c[L+4>>2]=J;c[E>>2]=C;c[E+4>>2]=S;if((K|0)==0){S=A;hb=Q+(1-aa)|0;ib=1;jb=c[S+4>>2]|0;kb=c[S>>2]|0;oa=133;break}else{S=F+8+(V+(D*96|0))|0;F=c[S>>2]|0;E=c[S+4>>2]|0;C=Q+(Y+8)|0;Y=c[C+4>>2]|0;c[S>>2]=c[C>>2];c[S+4>>2]=Y;c[C>>2]=F;c[C+4>>2]=E;oa=131;break}}else{oa=131}}while(0);do{if((oa|0)==131){ea=A;E=c[ea>>2]|0;C=c[ea+4>>2]|0;ea=1<<K;F=ea-aa|0;Y=Q+F|0;if((K|0)==0){hb=Y;ib=ea;jb=C;kb=E;oa=133;break}c[Y>>2]=E;c[Y+4>>2]=C;C=V+(gb*96|0)+8|0;Y=c[C+4>>2]|0;E=Q+(F+8)|0;c[E>>2]=c[C>>2];c[E+4>>2]=Y;lb=1;mb=ea}}while(0);if((oa|0)==133){c[hb>>2]=kb;c[hb+4>>2]=jb;lb=0;mb=ib}A=8<<K;ea=V+(gb*96|0)+A|0;Y=c[ea>>2]|0;E=c[ea+4>>2]|0;C=(9<<K)-aa|0;F=Q+C|0;S=c[F+4>>2]|0;c[ea>>2]=c[F>>2];c[ea+4>>2]=S;c[F>>2]=Y;c[F+4>>2]=E;if(lb){E=A+8+(V+(gb*96|0))|0;A=c[E>>2]|0;F=c[E+4>>2]|0;Y=Q+(C+8)|0;S=c[Y+4>>2]|0;c[E>>2]=c[Y>>2];c[E+4>>2]=S;c[Y>>2]=A;c[Y+4>>2]=F}F=(c[l>>2]|0)+1|0;Y=f+427400|0;do{if((F|0)<(c[Y>>2]|0)){A=(c[I>>2]|0)+(F*96|0)|0;S=c[A>>2]|0;E=c[A+4>>2]|0;ea=(17<<K)-aa|0;J=Q+ea|0;L=c[J+4>>2]|0;c[A>>2]=c[J>>2];c[A+4>>2]=L;c[J>>2]=S;c[J+4>>2]=E;if(!lb){break}E=(c[I>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+8|0;J=c[E>>2]|0;S=c[E+4>>2]|0;L=Q+(ea+8)|0;ea=c[L+4>>2]|0;c[E>>2]=c[L>>2];c[E+4>>2]=ea;c[L>>2]=J;c[L+4>>2]=S}}while(0);do{if(eb){F=24<<K;S=V+(D*96|0)+F|0;L=c[S>>2]|0;J=c[S+4>>2]|0;ea=(-7<<K)-aa|0;E=R+ea|0;A=c[E+4>>2]|0;c[S>>2]=c[E>>2];c[S+4>>2]=A;c[E>>2]=L;c[E+4>>2]=J;if(lb){J=F+8+(V+(D*96|0))|0;F=c[J>>2]|0;E=c[J+4>>2]|0;L=R+(ea+8)|0;A=c[L+4>>2]|0;c[J>>2]=c[L>>2];c[J+4>>2]=A;c[L>>2]=F;c[L+4>>2]=E}E=40<<K;L=V+(D*96|0)+E|0;F=c[L>>2]|0;A=c[L+4>>2]|0;J=P+ea|0;S=c[J+4>>2]|0;c[L>>2]=c[J>>2];c[L+4>>2]=S;c[J>>2]=F;c[J+4>>2]=A;if(lb){A=E+8+(V+(D*96|0))|0;E=c[A>>2]|0;J=c[A+4>>2]|0;F=P+(ea+8)|0;ea=c[F+4>>2]|0;c[A>>2]=c[F>>2];c[A+4>>2]=ea;c[F>>2]=E;c[F+4>>2]=J;J=16<<K;F=V+(gb*96|0)+J|0;E=mb-aa|0;nb=J;ob=c[F+4>>2]|0;pb=c[F>>2]|0;qb=E;rb=R+E|0;oa=146;break}else{E=16<<K;F=V+(gb*96|0)+E|0;J=mb-aa|0;sb=E;tb=c[F+4>>2]|0;ub=c[F>>2]|0;vb=J;wb=R+J|0;oa=147;break}}else{J=16<<K;F=V+(gb*96|0)+J|0;E=c[F>>2]|0;ea=c[F+4>>2]|0;F=mb-aa|0;A=R+F|0;if(lb){nb=J;ob=ea;pb=E;qb=F;rb=A;oa=146}else{sb=J;tb=ea;ub=E;vb=F;wb=A;oa=147}}}while(0);if((oa|0)==146){c[rb>>2]=pb;c[rb+4>>2]=ob;D=nb+8+(V+(gb*96|0))|0;A=c[D+4>>2]|0;F=R+(qb+8)|0;c[F>>2]=c[D>>2];c[F+4>>2]=A;xb=1;yb=nb;zb=qb}else if((oa|0)==147){c[wb>>2]=ub;c[wb+4>>2]=tb;xb=0;yb=sb;zb=vb}A=24<<K;F=V+(gb*96|0)+A|0;D=c[F>>2]|0;E=c[F+4>>2]|0;ea=R+C|0;J=c[ea+4>>2]|0;c[F>>2]=c[ea>>2];c[F+4>>2]=J;c[ea>>2]=D;c[ea+4>>2]=E;if(xb){E=A+8+(V+(gb*96|0))|0;A=c[E>>2]|0;ea=c[E+4>>2]|0;D=R+(C+8)|0;J=c[D+4>>2]|0;c[E>>2]=c[D>>2];c[E+4>>2]=J;c[D>>2]=A;c[D+4>>2]=ea;ea=32<<K;D=V+(gb*96|0)+ea|0;A=c[D+4>>2]|0;J=P+zb|0;c[J>>2]=c[D>>2];c[J+4>>2]=A;A=ea+8+(V+(gb*96|0))|0;J=c[A+4>>2]|0;D=P+(zb+8)|0;c[D>>2]=c[A>>2];c[D+4>>2]=J;Ab=ea}else{ea=32<<K;J=V+(gb*96|0)+ea|0;D=c[J+4>>2]|0;A=P+zb|0;c[A>>2]=c[J>>2];c[A+4>>2]=D;Ab=ea}ea=40<<K;D=V+(gb*96|0)+ea|0;A=c[D>>2]|0;J=c[D+4>>2]|0;E=P+C|0;F=c[E+4>>2]|0;c[D>>2]=c[E>>2];c[D+4>>2]=F;c[E>>2]=A;c[E+4>>2]=J;if(xb){J=ea+8+(V+(gb*96|0))|0;ea=c[J>>2]|0;E=c[J+4>>2]|0;A=P+(C+8)|0;F=c[A+4>>2]|0;c[J>>2]=c[A>>2];c[J+4>>2]=F;c[A>>2]=ea;c[A+4>>2]=E}E=(c[l>>2]|0)+1|0;if((E|0)>=(c[Y>>2]|0)){break}A=(c[I>>2]|0)+(E*96|0)+yb|0;E=c[A>>2]|0;ea=c[A+4>>2]|0;F=(17<<K)-aa|0;J=R+F|0;D=c[J+4>>2]|0;c[A>>2]=c[J>>2];c[A+4>>2]=D;c[J>>2]=E;c[J+4>>2]=ea;if(xb){ea=yb+8+((c[I>>2]|0)+(((c[l>>2]|0)+1|0)*96|0))|0;J=c[ea>>2]|0;E=c[ea+4>>2]|0;D=R+(F+8)|0;A=c[D+4>>2]|0;c[ea>>2]=c[D>>2];c[ea+4>>2]=A;c[D>>2]=J;c[D+4>>2]=E;Bb=1}else{Bb=0}E=(c[I>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+Ab|0;D=c[E>>2]|0;J=c[E+4>>2]|0;A=P+F|0;ea=c[A+4>>2]|0;c[E>>2]=c[A>>2];c[E+4>>2]=ea;c[A>>2]=D;c[A+4>>2]=J;if(!Bb){break}J=Ab+8+((c[I>>2]|0)+(((c[l>>2]|0)+1|0)*96|0))|0;A=c[J>>2]|0;D=c[J+4>>2]|0;ea=P+(F+8)|0;F=c[ea+4>>2]|0;c[J>>2]=c[ea>>2];c[J+4>>2]=F;c[ea>>2]=A;c[ea+4>>2]=D}}while(0);P=(s&1|0)==0;l=(s&2|0)==0;Ab=f+426564|0;Bb=(u|0)==0;u=(s&16777216|0)!=0;s=f+116|0;R=f+112|0;yb=u?4:1;xb=f+140|0;gb=u?f+136|0:xb;zb=f+124|0;vb=f+6128|0;sb=f+4836|0;tb=f+421200|0;wb=0;do{ub=c[v>>2]|0;qb=c[k+(wb<<2)>>2]|0;nb=wb<<4;ob=O+(nb<<2)|0;f:do{if(P){if(l){if((c[Ab>>2]&15|0)==0){break}if(Bb){if(u){pe[c[s>>2]&1023](qb,ob,f+421200+(wb<<8<<ub<<1)|0,N,(wb*40|0)+(f+5184)|0);break}else{pe[c[R>>2]&1023](qb,ob,f+421200+(wb<<8<<ub<<1)|0,N,(wb*40|0)+(f+5184)|0);break}}rb=c[gb>>2]|0;pb=wb<<8;lb=0;while(1){mb=lb+nb|0;if((a[(d[602328+mb|0]|0)+(f+5184)|0]|0)!=0){ef[rb&4095](qb+(c[O+(mb<<2)>>2]|0)|0,f+421200+((lb<<4)+pb<<ub<<1)|0,N)}lb=lb+yb|0;if((lb|0)>=16){break f}}}if(Bb){pe[c[zb>>2]&1023](qb,ob,f+421200+(wb<<8<<ub<<1)|0,N,(wb*40|0)+(f+5184)|0);break}do{if((c[vb>>2]|0)==244){lb=c[sb>>2]|0;if(!((lb-1|0)>>>0<2>>>0)){break}mf[c[f+5148+(lb<<2)>>2]&2047](qb,ob,f+421200+(wb<<8<<ub<<1)|0,N);break f}}while(0);lb=wb<<8;pb=(ub|0)==0;rb=0;do{mb=rb+nb|0;eb=(rb<<4)+lb|0;if((a[(d[602328+mb|0]|0)+(f+5184)|0]|0)==0){if(pb){Cb=e[f+421200+(eb<<1)>>1]|0}else{Cb=c[tb+(eb<<2)>>2]|0}if((Cb|0)!=0){oa=190}}else{oa=190}if((oa|0)==190){oa=0;ef[c[xb>>2]&4095](qb+(c[O+(mb<<2)>>2]|0)|0,f+421200+(eb<<ub<<1)|0,N)}rb=rb+1|0;}while((rb|0)<16)}}while(0);wb=wb+1|0;}while((wb|0)<3);i=g;return}function oha(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=f+427376|0;l=c[k>>2]|0;m=f+427380|0;n=c[m>>2]|0;o=f+427412|0;p=c[o>>2]|0;q=f+4064|0;r=c[(c[q>>2]|0)+(p<<2)>>2]|0;s=f+4776|0;t=f+8|0;u=c[f+2528>>2]|0;v=c[s>>2]|0;w=(ca(v,n)|0)+l<<4;x=u+w|0;c[j>>2]=x;y=u+(w+64+(ca(l<<2&12,v)|0))|0;ef[c[t>>2]&4095](y,v,4);v=c[f+2532>>2]|0;y=c[s>>2]|0;z=(ca(y,n)|0)+l<<4;A=v+z|0;c[j+4>>2]=A;B=v+(z+64+(ca(c[k>>2]<<2&12,y)|0))|0;ef[c[t>>2]&4095](B,y,4);y=c[f+2536>>2]|0;B=c[s>>2]|0;C=(ca(B,n)|0)+l<<4;l=y+C|0;c[j+8>>2]=l;n=y+(C+64+(ca(c[k>>2]<<2&12,B)|0))|0;ef[c[t>>2]&4095](n,B,4);a[(c[f+199432>>2]|0)+p|0]=c[f+199428>>2];p=c[s>>2]|0;c[f+6116>>2]=p;B=f+6112|0;c[B>>2]=p;do{if((r&7|0)==0){n=c[f+1028>>2]|0;D=f+148|0;E=c[f+1032>>2]|0;F=f+164|0;G=f+12|0;H=f+28|0;I=c[(c[q>>2]|0)+(c[o>>2]<<2)>>2]|0;J=a[f+5644|0]|0;if(J<<24>>24>-1){K=J<<24>>24;J=c[k>>2]|0;L=(b[f+5360>>1]>>2)+64+(J<<4|8)+(ca((c[m>>2]<<4|J<<2&12)+(b[f+5362>>1]>>2)|0,p)|0)|0;ef[c[t>>2]&4095]((c[f+199440+(K*2224|0)>>2]|0)+L|0,p,4);ef[c[t>>2]&4095]((c[f+199440+(K*2224|0)+4>>2]|0)+L|0,c[s>>2]|0,4);ef[c[t>>2]&4095]((c[f+199440+(K*2224|0)+8>>2]|0)+L|0,c[s>>2]|0,4)}do{if((I&8|0)==0){if((I&16|0)!=0){L=n+64|0;K=E+64|0;Tha(f,0,0,8,8,x,A,l,0,0,L,c[D>>2]|0,K,c[F>>2]|0,G,H,I&4096,I&16384);Tha(f,8,0,8,8,x,A,l,0,4,L,c[D>>2]|0,K,c[F>>2]|0,G,H,I&8192,I&32768);break}if((I&32|0)!=0){K=n+64|0;L=f+152|0;J=E+64|0;M=f+168|0;N=f+16|0;O=f+32|0;Tha(f,0,0,16,c[B>>2]<<3,x,A,l,0,0,K,c[L>>2]|0,J,c[M>>2]|0,N,O,I&4096,I&16384);Tha(f,4,0,16,c[B>>2]<<3,x,A,l,4,0,K,c[L>>2]|0,J,c[M>>2]|0,N,O,I&8192,I&32768);break}O=n+128|0;N=f+156|0;M=E+128|0;J=f+172|0;L=f+20|0;K=f+36|0;P=f+152|0;Q=f+168|0;R=f+16|0;S=f+32|0;T=n+64|0;U=E+64|0;V=0;do{W=e[f+177112+(V<<1)>>1]|0;X=V<<2;Y=X&4;Z=V<<1&4;do{if((W&8|0)==0){if((W&16|0)!=0){_=W&4096;$=W&16384;Tha(f,X,0,4,4,x,A,l,Y,Z,O,c[P>>2]|0,M,c[Q>>2]|0,R,S,_,$);Tha(f,X|2,0,4,4,x,A,l,Y,Z|2,O,c[P>>2]|0,M,c[Q>>2]|0,R,S,_,$);break}if((W&32|0)==0){$=W&4096;_=W&16384;Tha(f,X,1,4,0,x,A,l,Y,Z,O,c[N>>2]|0,M,c[J>>2]|0,L,K,$,_);aa=Y|2;Tha(f,X|1,1,4,0,x,A,l,aa,Z,O,c[N>>2]|0,M,c[J>>2]|0,L,K,$,_);ba=Z|2;Tha(f,X|2,1,4,0,x,A,l,Y,ba,O,c[N>>2]|0,M,c[J>>2]|0,L,K,$,_);Tha(f,X|3,1,4,0,x,A,l,aa,ba,O,c[N>>2]|0,M,c[J>>2]|0,L,K,$,_);break}else{_=W&4096;$=W&16384;Tha(f,X,0,8,c[B>>2]<<2,x,A,l,Y,Z,O,c[N>>2]|0,M,c[J>>2]|0,L,K,_,$);Tha(f,X|1,0,8,c[B>>2]<<2,x,A,l,Y|2,Z,O,c[N>>2]|0,M,c[J>>2]|0,L,K,_,$);break}}else{Tha(f,X,1,8,0,x,A,l,Y,Z,T,c[P>>2]|0,U,c[Q>>2]|0,R,S,W&4096,W&16384)}}while(0);V=V+1|0;}while((V|0)<4)}else{Tha(f,0,1,16,0,x,A,l,0,0,n|0,c[D>>2]|0,E|0,c[F>>2]|0,G,H,I&4096,I&16384)}}while(0);I=a[f+5684|0]|0;if(!(I<<24>>24>-1)){break}H=I<<24>>24;I=c[k>>2]|0;G=(b[f+5520>>1]>>2)+64+(I<<4|8)+(ca((c[m>>2]<<4|I<<2&12)+(b[f+5522>>1]>>2)|0,c[B>>2]|0)|0)|0;ef[c[t>>2]&4095]((c[f+306192+(H*2224|0)>>2]|0)+G|0,c[s>>2]|0,4);ef[c[t>>2]&4095]((c[f+306192+(H*2224|0)+4>>2]|0)+G|0,c[s>>2]|0,4);ef[c[t>>2]&4095]((c[f+306192+(H*2224|0)+8>>2]|0)+G|0,c[s>>2]|0,4)}else{G=f+427420|0;H=c[G>>2]|0;if((H|0)==2){da=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);ea=c[f+4864>>2]|0;fa=c[k>>2]|0;ga=5}else if((H|0)!=0){H=c[k>>2]|0;da=(H|0)>0;ea=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;fa=H;ga=5}do{if((ga|0)==5){H=fa-1|0;I=f+5180|0;F=c[I>>2]|0;if((ea|0)==0){break}if(da){E=F+(H*96|0)+8|0;D=c[E>>2]|0;n=c[E+4>>2]|0;V=u+(w+(-8-p))|0;S=c[V+4>>2]|0;c[E>>2]=c[V>>2];c[E+4>>2]=S;c[V>>2]=D;c[V+4>>2]=n}n=F+(fa*96|0)|0;V=c[n>>2]|0;D=c[n+4>>2]|0;S=u+(w-p)|0;E=c[S+4>>2]|0;c[n>>2]=c[S>>2];c[n+4>>2]=E;c[S>>2]=V;c[S+4>>2]=D;D=F+(fa*96|0)+8|0;S=c[D>>2]|0;V=c[D+4>>2]|0;E=8-p|0;n=u+(w+E)|0;R=c[n+4>>2]|0;c[D>>2]=c[n>>2];c[D+4>>2]=R;c[n>>2]=S;c[n+4>>2]=V;V=(c[k>>2]|0)+1|0;n=f+427400|0;if((V|0)<(c[n>>2]|0)){S=(c[I>>2]|0)+(V*96|0)|0;V=c[S>>2]|0;R=c[S+4>>2]|0;D=u+(w+(16-p))|0;Q=c[D+4>>2]|0;c[S>>2]=c[D>>2];c[S+4>>2]=Q;c[D>>2]=V;c[D+4>>2]=R}if(da){R=F+(H*96|0)+24|0;D=c[R>>2]|0;V=c[R+4>>2]|0;Q=-8-p|0;S=v+(z+Q)|0;U=c[S+4>>2]|0;c[R>>2]=c[S>>2];c[R+4>>2]=U;c[S>>2]=D;c[S+4>>2]=V;V=F+(H*96|0)+40|0;H=c[V>>2]|0;S=c[V+4>>2]|0;D=y+(C+Q)|0;Q=c[D+4>>2]|0;c[V>>2]=c[D>>2];c[V+4>>2]=Q;c[D>>2]=H;c[D+4>>2]=S}S=F+(fa*96|0)+16|0;D=c[S>>2]|0;H=c[S+4>>2]|0;Q=v+(z-p)|0;V=c[Q+4>>2]|0;c[S>>2]=c[Q>>2];c[S+4>>2]=V;c[Q>>2]=D;c[Q+4>>2]=H;H=F+(fa*96|0)+24|0;Q=c[H>>2]|0;D=c[H+4>>2]|0;V=v+(z+E)|0;S=c[V+4>>2]|0;c[H>>2]=c[V>>2];c[H+4>>2]=S;c[V>>2]=Q;c[V+4>>2]=D;D=F+(fa*96|0)+32|0;V=c[D>>2]|0;Q=c[D+4>>2]|0;S=y+(C-p)|0;H=c[S+4>>2]|0;c[D>>2]=c[S>>2];c[D+4>>2]=H;c[S>>2]=V;c[S+4>>2]=Q;Q=F+(fa*96|0)+40|0;F=c[Q>>2]|0;S=c[Q+4>>2]|0;V=y+(C+E)|0;E=c[V+4>>2]|0;c[Q>>2]=c[V>>2];c[Q+4>>2]=E;c[V>>2]=F;c[V+4>>2]=S;S=(c[k>>2]|0)+1|0;if((S|0)>=(c[n>>2]|0)){break}n=(c[I>>2]|0)+(S*96|0)+16|0;S=c[n>>2]|0;V=c[n+4>>2]|0;F=16-p|0;E=v+(z+F)|0;Q=c[E+4>>2]|0;c[n>>2]=c[E>>2];c[n+4>>2]=Q;c[E>>2]=S;c[E+4>>2]=V;V=(c[I>>2]|0)+(((c[k>>2]|0)+1|0)*96|0)+32|0;I=c[V>>2]|0;E=c[V+4>>2]|0;S=y+(C+F)|0;F=c[S+4>>2]|0;c[V>>2]=c[S>>2];c[V+4>>2]=F;c[S>>2]=I;c[S+4>>2]=E}}while(0);E=h;S=f+4792|0;I=(r&1|0)==0;F=f+4836|0;V=f+128|0;Q=(r&16777216|0)==0;n=f+104|0;H=f+96|0;D=f+5168|0;U=3-p|0;R=4-p|0;P=f+108|0;T=f+100|0;K=f+5160|0;L=0;J=x;while(1){if((L|0)==0){ha=S}else{ha=f+4756+(L-1<<2)|0}M=c[ha>>2]|0;N=L<<4;a:do{if(I){re[c[f+5084+(c[F>>2]<<2)>>2]&1023](J,p);if((a[(d[L+602376|0]|0)+(f+5184)|0]|0)==0){break}ef[c[V>>2]&4095](f+421200+(L<<8<<1)|0,f+424272+(L<<6)|0,c[(c[f+177020+(L<<2)>>2]|0)+(M<<6)>>2]|0)}else{if(!Q){O=c[P>>2]|0;W=c[T>>2]|0;Z=L<<8;Y=0;while(1){X=Y+N|0;$=J+(c[f+5716+(X<<2)>>2]|0)|0;_=a[(d[602328+X|0]|0)+(f+5184)|0]|0;mf[c[f+4992+(a[(a[602328+Y|0]&255)+(f+4888)|0]<<24>>24<<2)>>2]&2047]($,c[K>>2]<<Y&32768,c[D>>2]<<Y&16384,p);do{if((_<<24>>24|0)==1){X=(Y<<4)+Z|0;ba=f+421200+(X<<1)|0;if((b[ba>>1]|0)==0){ia=X;ga=24;break}ef[O&4095]($,ba,p)}else if((_<<24>>24|0)!=0){ia=(Y<<4)+Z|0;ga=24}}while(0);if((ga|0)==24){ga=0;ef[W&4095]($,f+421200+(ia<<1)|0,p)}Y=Y+4|0;if((Y|0)>=16){break a}}}Y=c[n>>2]|0;W=c[H>>2]|0;Z=L<<8;O=0;do{_=O+N|0;ba=c[f+5716+(_<<2)>>2]|0;X=J+ba|0;aa=a[(d[602328+O|0]|0)+(f+4888)|0]|0;ja=aa<<24>>24;do{if((aa<<24>>24|0)==7|(aa<<24>>24|0)==3){if((c[D>>2]&32768>>>(O>>>0)|0)==0){c[h>>2]=ca(d[J+(U+ba)|0]|0,16843009)|0;ka=E;break}else{ka=J+(R+ba)|0;break}}else{ka=0}}while(0);ef[c[f+4932+(ja<<2)>>2]&4095](X,ka,p);ba=a[(d[602328+_|0]|0)+(f+5184)|0]|0;b:do{if(!(ba<<24>>24==0)){aa=f+421200+((O<<4)+Z<<1)|0;do{if(ba<<24>>24==1){if((b[aa>>1]|0)==0){break}ef[Y&4095](X,aa,p);break b}}while(0);ef[W&4095](X,aa,p)}}while(0);O=O+1|0;}while((O|0)<16)}}while(0);N=L+1|0;if((N|0)>=3){break}L=N;J=c[j+(N<<2)>>2]|0}J=c[G>>2]|0;if((J|0)==2){la=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);ma=c[f+4864>>2]|0;na=c[k>>2]|0}else if((J|0)==0){break}else{J=c[k>>2]|0;la=(J|0)>0;ma=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;na=J}J=na-1|0;L=f+5180|0;R=c[L>>2]|0;if((ma|0)==0){break}if(la){E=R+(J*96|0)+8|0;U=c[E>>2]|0;D=c[E+4>>2]|0;H=u+(w+(-8-p))|0;n=c[H+4>>2]|0;c[E>>2]=c[H>>2];c[E+4>>2]=n;c[H>>2]=U;c[H+4>>2]=D}D=R+(na*96|0)|0;H=c[D+4>>2]|0;U=u+(w-p)|0;c[U>>2]=c[D>>2];c[U+4>>2]=H;H=R+(na*96|0)+8|0;U=c[H>>2]|0;D=c[H+4>>2]|0;n=8-p|0;E=u+(w+n)|0;K=c[E+4>>2]|0;c[H>>2]=c[E>>2];c[H+4>>2]=K;c[E>>2]=U;c[E+4>>2]=D;D=(c[k>>2]|0)+1|0;E=f+427400|0;if((D|0)<(c[E>>2]|0)){U=(c[L>>2]|0)+(D*96|0)|0;D=c[U>>2]|0;K=c[U+4>>2]|0;H=u+(w+(16-p))|0;T=c[H+4>>2]|0;c[U>>2]=c[H>>2];c[U+4>>2]=T;c[H>>2]=D;c[H+4>>2]=K}if(la){K=R+(J*96|0)+24|0;H=c[K>>2]|0;D=c[K+4>>2]|0;T=-8-p|0;U=v+(z+T)|0;P=c[U+4>>2]|0;c[K>>2]=c[U>>2];c[K+4>>2]=P;c[U>>2]=H;c[U+4>>2]=D;D=R+(J*96|0)+40|0;J=c[D>>2]|0;U=c[D+4>>2]|0;H=y+(C+T)|0;T=c[H+4>>2]|0;c[D>>2]=c[H>>2];c[D+4>>2]=T;c[H>>2]=J;c[H+4>>2]=U}U=R+(na*96|0)+16|0;H=c[U+4>>2]|0;J=v+(z-p)|0;c[J>>2]=c[U>>2];c[J+4>>2]=H;H=R+(na*96|0)+24|0;J=c[H>>2]|0;U=c[H+4>>2]|0;T=v+(z+n)|0;D=c[T+4>>2]|0;c[H>>2]=c[T>>2];c[H+4>>2]=D;c[T>>2]=J;c[T+4>>2]=U;U=R+(na*96|0)+32|0;T=c[U+4>>2]|0;J=y+(C-p)|0;c[J>>2]=c[U>>2];c[J+4>>2]=T;T=R+(na*96|0)+40|0;R=c[T>>2]|0;J=c[T+4>>2]|0;U=y+(C+n)|0;n=c[U+4>>2]|0;c[T>>2]=c[U>>2];c[T+4>>2]=n;c[U>>2]=R;c[U+4>>2]=J;J=(c[k>>2]|0)+1|0;if((J|0)>=(c[E>>2]|0)){break}E=(c[L>>2]|0)+(J*96|0)+16|0;J=c[E>>2]|0;U=c[E+4>>2]|0;R=16-p|0;n=v+(z+R)|0;T=c[n+4>>2]|0;c[E>>2]=c[n>>2];c[E+4>>2]=T;c[n>>2]=J;c[n+4>>2]=U;U=(c[L>>2]|0)+(((c[k>>2]|0)+1|0)*96|0)+32|0;L=c[U>>2]|0;n=c[U+4>>2]|0;J=y+(C+R)|0;R=c[J+4>>2]|0;c[U>>2]=c[J>>2];c[U+4>>2]=R;c[J>>2]=L;c[J+4>>2]=n}}while(0);C=(r&1|0)==0;y=(r&2|0)==0;k=f+426564|0;z=(r&16777216|0)==0;r=f+112|0;v=f+116|0;na=f+124|0;la=f+5716|0;if(!C){i=g;return}c:do{if(y){do{if((c[k>>2]&15|0)!=0){if(z){pe[c[r>>2]&1023](x,la,f+421200|0,p,f+5184|0);break}else{pe[c[v>>2]&1023](x,la,f+421200|0,p,f+5184|0);ga=80;break c}}}while(0)}else{pe[c[na>>2]&1023](x,la,f+421200|0,p,f+5184|0);ga=80}}while(0);do{if((ga|0)==80){if(C){break}i=g;return}}while(0);ga=f+5780|0;do{if(y){if((c[k>>2]&15|0)==0){break}if(z){pe[c[r>>2]&1023](A,ga,f+421712|0,p,f+5224|0);break}else{pe[c[v>>2]&1023](A,ga,f+421712|0,p,f+5224|0);break}}else{pe[c[na>>2]&1023](A,ga,f+421712|0,p,f+5224|0)}}while(0);ga=f+5844|0;if(!C){i=g;return}if(!y){pe[c[na>>2]&1023](l,ga,f+422224|0,p,f+5264|0);i=g;return}if((c[k>>2]&15|0)==0){i=g;return}if(z){pe[c[r>>2]&1023](l,ga,f+422224|0,p,f+5264|0);i=g;return}else{pe[c[v>>2]&1023](l,ga,f+422224|0,p,f+5264|0);i=g;return}}function pha(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=f+427376|0;m=c[l>>2]|0;n=f+427380|0;o=c[n>>2]|0;p=f+427412|0;q=c[p>>2]|0;r=f+4064|0;s=c[(c[r>>2]|0)+(q<<2)>>2]|0;t=f+4792|0;if((c[t>>2]|0)==0){u=(c[f+6140>>2]|0)!=0}else{u=0}v=(c[(c[f>>2]|0)+48>>2]|0)==28;w=16>>>((c[f+4788>>2]|0)>>>0);x=f+6136|0;z=(c[x>>2]|0)==2;A=c[f+2528>>2]|0;B=f+4752|0;C=c[B>>2]|0;D=m<<C;E=f+4776|0;F=c[E>>2]|0;H=(ca(F,o)|0)+D<<4;I=A+H|0;J=c[f+2532>>2]|0;K=f+4780|0;L=(ca(ca(w,o)|0,c[K>>2]|0)|0)+(D<<3)|0;D=J+L|0;M=c[f+2536>>2]|0;N=M+L|0;O=f+8|0;P=A+(H+(64<<C)+(ca(m<<2&12,F)|0))|0;ef[c[O>>2]&4095](P,F,4);F=(ca(c[l>>2]&7,c[K>>2]|0)|0)+L|0;ef[c[O>>2]&4095](J+(F+(64<<c[B>>2]))|0,N-D|0,2);F=f+199428|0;a[(c[f+199432>>2]|0)+q|0]=c[F>>2];q=f+177092|0;P=c[E>>2]|0;do{if((c[q>>2]|0)==0){c[f+6112>>2]=P;m=c[K>>2]|0;c[f+6116>>2]=m;Q=I;R=D;S=N;T=P;U=m;V=f+5716|0}else{m=P<<1;c[f+6112>>2]=m;C=c[K>>2]|0;W=C<<1;c[f+6116>>2]=W;X=f+5908|0;if((o&1|0)==0){Y=I;Z=D;_=N}else{$=L-(ca(C,w-1|0)|0)|0;Y=A+((P*-15|0)+H)|0;Z=J+$|0;_=M+$|0}if((c[f+177088>>2]|0)==0){Q=Y;R=Z;S=_;T=m;U=W;V=X;break}if((c[F>>2]|0)==0){Q=Y;R=Z;S=_;T=m;U=W;V=X;break}$=(s&8|0)==0;C=0;while(1){do{if((12288<<(C<<1)&s|0)!=0){aa=f+5632+(C*40|0)+12|0;ba=a[aa]|0;if(!$){da=ca((ba<<24>>24)+16^c[n>>2]&1,16843009)|0;c[aa>>2]=da;c[f+5632+(C*40|0)+20>>2]=da;c[f+5632+(C*40|0)+28>>2]=da;c[f+5632+(C*40|0)+36>>2]=da;break}if(ba<<24>>24>-1){da=((c[n>>2]&1^(ba<<24>>24)+16)*257|0)&65535;b[aa>>1]=da;b[f+5632+(C*40|0)+20>>1]=da}da=f+5632+(C*40|0)+14|0;aa=a[da]|0;if(aa<<24>>24>-1){ba=((c[n>>2]&1^(aa<<24>>24)+16)*257|0)&65535;b[da>>1]=ba;b[f+5632+(C*40|0)+22>>1]=ba}ba=f+5632+(C*40|0)+28|0;da=a[ba]|0;if(da<<24>>24>-1){aa=((c[n>>2]&1^(da<<24>>24)+16)*257|0)&65535;b[ba>>1]=aa;b[f+5632+(C*40|0)+36>>1]=aa}aa=f+5632+(C*40|0)+30|0;ba=a[aa]|0;if(!(ba<<24>>24>-1)){break}da=((c[n>>2]&1^(ba<<24>>24)+16)*257|0)&65535;b[aa>>1]=da;b[f+5632+(C*40|0)+38>>1]=da}}while(0);da=C+1|0;if(da>>>0<(c[F>>2]|0)>>>0){C=da}else{Q=Y;R=Z;S=_;T=m;U=W;V=X;break}}}}while(0);if((s&4|0)!=0){_=c[f+7308>>2]|0;Z=f+421184|0;Y=c[Z>>2]|0;if((c[B>>2]|0)==0){nrc(Q|0,Y|0,16)|0;nrc(Q+T|0,(c[Z>>2]|0)+16|0,16)|0;nrc(Q+(T<<1)|0,(c[Z>>2]|0)+32|0,16)|0;nrc(Q+(T*3|0)|0,(c[Z>>2]|0)+48|0,16)|0;nrc(Q+(T<<2)|0,(c[Z>>2]|0)+64|0,16)|0;nrc(Q+(T*5|0)|0,(c[Z>>2]|0)+80|0,16)|0;nrc(Q+(T*6|0)|0,(c[Z>>2]|0)+96|0,16)|0;nrc(Q+(T*7|0)|0,(c[Z>>2]|0)+112|0,16)|0;nrc(Q+(T<<3)|0,(c[Z>>2]|0)+128|0,16)|0;nrc(Q+(T*9|0)|0,(c[Z>>2]|0)+144|0,16)|0;nrc(Q+(T*10|0)|0,(c[Z>>2]|0)+160|0,16)|0;nrc(Q+(T*11|0)|0,(c[Z>>2]|0)+176|0,16)|0;nrc(Q+(T*12|0)|0,(c[Z>>2]|0)+192|0,16)|0;nrc(Q+(T*13|0)|0,(c[Z>>2]|0)+208|0,16)|0;nrc(Q+(T*14|0)|0,(c[Z>>2]|0)+224|0,16)|0;nrc(Q+(T*15|0)|0,(c[Z>>2]|0)+240|0,16)|0;if((c[x>>2]|0)==0){F=1<<_-1&255;mrc(R|0,F|0,8)|0;mrc(S|0,F|0,8)|0;mrc(R+U|0,F|0,8)|0;mrc(S+U|0,F|0,8)|0;M=U<<1;mrc(R+M|0,F|0,8)|0;mrc(S+M|0,F|0,8)|0;M=U*3|0;mrc(R+M|0,F|0,8)|0;mrc(S+M|0,F|0,8)|0;M=U<<2;mrc(R+M|0,F|0,8)|0;mrc(S+M|0,F|0,8)|0;M=U*5|0;mrc(R+M|0,F|0,8)|0;mrc(S+M|0,F|0,8)|0;M=U*6|0;mrc(R+M|0,F|0,8)|0;mrc(S+M|0,F|0,8)|0;M=U*7|0;mrc(R+M|0,F|0,8)|0;mrc(S+M|0,F|0,8)|0;i=g;return}F=c[Z>>2]|0;Z=(w<<3)+256|0;if((w|0)>0){ea=0}else{i=g;return}do{M=ca(ea,U)|0;J=ea<<3;H=F+(J+256)|0;A=R+M|0;L=H|0;N=H+4|0;H=d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0;N=A|0;y=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;N=A+4|0;y=H;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;N=F+(Z+J)|0;J=S+M|0;M=N|0;H=N+4|0;N=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=J|0;y=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=J+4|0;y=N;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;ea=ea+1|0;}while((ea|0)<(w|0));i=g;return}ea=c[x>>2]|0;x=(ca(e[1375896+(ea<<1)>>1]|0,_)|0)>>>0>2147483639>>>0|(Y|0)==0;Z=x?0:Y;Y=32-_|0;x=_<<4;F=_<<8;H=0;N=0;while(1){J=Q+(ca(N,T)|0)|0;M=H;A=0;while(1){L=Z+(M>>>3)|0;b[J+(A<<1)>>1]=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);L=A+1|0;if((L|0)<16){M=M+_|0;A=L}else{break}}A=N+1|0;if((A|0)<16){H=x+H|0;N=A}else{break}}N=(w|0)>0;if((ea|0)==0){if(!N){i=g;return}ea=1<<_-1&65535;H=0;do{x=ca(H,U)|0;b[S+x>>1]=ea;b[R+x>>1]=ea;b[S+(x+2)>>1]=ea;b[R+(x+2)>>1]=ea;b[S+(x+4)>>1]=ea;b[R+(x+4)>>1]=ea;b[S+(x+6)>>1]=ea;b[R+(x+6)>>1]=ea;b[S+(x+8)>>1]=ea;b[R+(x+8)>>1]=ea;b[S+(x+10)>>1]=ea;b[R+(x+10)>>1]=ea;b[S+(x+12)>>1]=ea;b[R+(x+12)>>1]=ea;b[S+(x+14)>>1]=ea;b[R+(x+14)>>1]=ea;H=H+1|0;}while((H|0)<(w|0));i=g;return}if(!N){i=g;return}H=_<<3;ea=w<<3;x=F;F=0;while(1){A=ca(F,U)|0;M=Z+(x>>>3)|0;J=x+_|0;b[R+A>>1]=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)>>>(Y>>>0);M=Z+(J>>>3)|0;L=J+_|0;b[R+(A+2)>>1]=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=Z+(L>>>3)|0;M=L+_|0;b[R+(A+4)>>1]=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7)>>>(Y>>>0);L=Z+(M>>>3)|0;J=M+_|0;b[R+(A+6)>>1]=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);M=Z+(J>>>3)|0;L=J+_|0;b[R+(A+8)>>1]=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=Z+(L>>>3)|0;M=L+_|0;b[R+(A+10)>>1]=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7)>>>(Y>>>0);L=Z+(M>>>3)|0;J=M+_|0;b[R+(A+12)>>1]=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);M=Z+(J>>>3)|0;b[R+(A+14)>>1]=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=F+1|0;if((J|0)<(w|0)){x=H+x|0;F=J}else{break}}if(!N){i=g;return}N=_<<3;F=ca(_,ea+256|0)|0;ea=0;while(1){x=ca(ea,U)|0;H=Z+(F>>>3)|0;J=F+_|0;b[S+x>>1]=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>(Y>>>0);H=Z+(J>>>3)|0;M=J+_|0;b[S+(x+2)>>1]=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=Z+(M>>>3)|0;H=M+_|0;b[S+(x+4)>>1]=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);M=Z+(H>>>3)|0;J=H+_|0;b[S+(x+6)>>1]=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(H&7)>>>(Y>>>0);H=Z+(J>>>3)|0;M=J+_|0;b[S+(x+8)>>1]=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=Z+(M>>>3)|0;H=M+_|0;b[S+(x+10)>>1]=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(M&7)>>>(Y>>>0);M=Z+(H>>>3)|0;J=H+_|0;b[S+(x+12)>>1]=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(H&7)>>>(Y>>>0);H=Z+(J>>>3)|0;b[S+(x+14)>>1]=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>(Y>>>0);J=ea+1|0;if((J|0)<(w|0)){F=N+F|0;ea=J}else{break}}i=g;return}ea=(s&7|0)!=0;a:do{if(ea){F=f+427420|0;N=c[F>>2]|0;b:do{if((N|0)!=0){w=c[B>>2]|0;do{if((c[f+177088>>2]|0)==0){fa=1}else{Y=(c[f+177096>>2]|0)!=0;if((c[n>>2]&1|0)==0){fa=Y&1^1;break}else{if(Y){fa=1;break}else{break b}}}}while(0);if((N|0)==2){ga=(e[(c[f+177072>>2]|0)+((c[p>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);ha=c[f+4864>>2]|0;ia=c[l>>2]|0}else{Y=c[l>>2]|0;ga=(Y|0)>0;ha=(c[n>>2]|0)>((c[q>>2]|0)!=0|0)|0;ia=Y}Y=T+1+w|0;Z=U+1+w|0;_=ia-1|0;J=f+5176+(fa<<2)|0;H=c[J>>2]|0;x=H+(ia*96|0)|0;if((ha|0)==0){break}do{if(ga){M=8<<w;A=H+(_*96|0)+M|0;L=c[A>>2]|0;D=c[A+4>>2]|0;I=(-7<<w)-Y|0;o=Q+I|0;X=c[o+4>>2]|0;c[A>>2]=c[o>>2];c[A+4>>2]=X;c[o>>2]=L;c[o+4>>2]=D;if((w|0)==0){D=x;ja=Q+(1-Y)|0;ka=c[D+4>>2]|0;la=c[D>>2]|0;ma=D;na=53;break}else{D=M+8+(H+(_*96|0))|0;M=c[D>>2]|0;o=c[D+4>>2]|0;L=Q+(I+8)|0;I=c[L+4>>2]|0;c[D>>2]=c[L>>2];c[D+4>>2]=I;c[L>>2]=M;c[L+4>>2]=o;na=51;break}}else{na=51}}while(0);do{if((na|0)==51){o=x;L=c[o>>2]|0;M=c[o+4>>2]|0;I=(1<<w)-Y|0;D=Q+I|0;if((w|0)==0){ja=D;ka=M;la=L;ma=o;na=53;break}X=c[D+4>>2]|0;c[o>>2]=c[D>>2];c[o+4>>2]=X;c[D>>2]=L;c[D+4>>2]=M;M=H+(ia*96|0)+8|0;D=c[M>>2]|0;L=c[M+4>>2]|0;X=Q+(I+8)|0;I=c[X+4>>2]|0;c[M>>2]=c[X>>2];c[M+4>>2]=I;c[X>>2]=D;c[X+4>>2]=L;oa=1}}while(0);if((na|0)==53){x=c[ja+4>>2]|0;c[ma>>2]=c[ja>>2];c[ma+4>>2]=x;c[ja>>2]=la;c[ja+4>>2]=ka;oa=0}x=8<<w;L=H+(ia*96|0)+x|0;X=c[L>>2]|0;D=c[L+4>>2]|0;I=(9<<w)-Y|0;M=Q+I|0;o=c[M+4>>2]|0;c[L>>2]=c[M>>2];c[L+4>>2]=o;c[M>>2]=X;c[M+4>>2]=D;if(oa){D=x+8+(H+(ia*96|0))|0;x=c[D>>2]|0;M=c[D+4>>2]|0;X=Q+(I+8)|0;I=c[X+4>>2]|0;c[D>>2]=c[X>>2];c[D+4>>2]=I;c[X>>2]=x;c[X+4>>2]=M}M=(c[l>>2]|0)+1|0;do{if((M|0)<(c[f+427400>>2]|0)){X=(c[J>>2]|0)+(M*96|0)|0;x=c[X>>2]|0;I=c[X+4>>2]|0;D=(17<<w)-Y|0;o=Q+D|0;L=c[o+4>>2]|0;c[X>>2]=c[o>>2];c[X+4>>2]=L;c[o>>2]=x;c[o+4>>2]=I;if(!oa){break}I=(c[J>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+8|0;o=c[I>>2]|0;x=c[I+4>>2]|0;L=Q+(D+8)|0;D=c[L+4>>2]|0;c[I>>2]=c[L>>2];c[I+4>>2]=D;c[L>>2]=o;c[L+4>>2]=x}}while(0);J=16<<w;do{if(ga){Y=H+(_*96|0)+J|0;M=c[Y>>2]|0;x=c[Y+4>>2]|0;L=(-7<<w)-Z|0;o=R+L|0;D=c[o+4>>2]|0;c[Y>>2]=c[o>>2];c[Y+4>>2]=D;c[o>>2]=M;c[o+4>>2]=x;if(oa){x=J+8+(H+(_*96|0))|0;o=c[x>>2]|0;M=c[x+4>>2]|0;D=R+(L+8)|0;Y=c[D+4>>2]|0;c[x>>2]=c[D>>2];c[x+4>>2]=Y;c[D>>2]=o;c[D+4>>2]=M}M=24<<w;D=H+(_*96|0)+M|0;o=c[D>>2]|0;Y=c[D+4>>2]|0;x=S+L|0;I=c[x+4>>2]|0;c[D>>2]=c[x>>2];c[D+4>>2]=I;c[x>>2]=o;c[x+4>>2]=Y;if(!oa){pa=0;break}Y=M+8+(H+(_*96|0))|0;M=c[Y>>2]|0;x=c[Y+4>>2]|0;o=S+(L+8)|0;L=c[o+4>>2]|0;c[Y>>2]=c[o>>2];c[Y+4>>2]=L;c[o>>2]=M;c[o+4>>2]=x;pa=1}else{pa=oa}}while(0);_=H+(ia*96|0)+J|0;x=c[_>>2]|0;o=c[_+4>>2]|0;M=1-Z+w|0;L=R+M|0;Y=c[L+4>>2]|0;c[_>>2]=c[L>>2];c[_+4>>2]=Y;c[L>>2]=x;c[L+4>>2]=o;if(pa){o=J+8+(H+(ia*96|0))|0;L=c[o>>2]|0;x=c[o+4>>2]|0;Y=R+(M+8)|0;_=c[Y+4>>2]|0;c[o>>2]=c[Y>>2];c[o+4>>2]=_;c[Y>>2]=L;c[Y+4>>2]=x}x=24<<w;Y=H+(ia*96|0)+x|0;L=c[Y>>2]|0;_=c[Y+4>>2]|0;o=S+M|0;I=c[o+4>>2]|0;c[Y>>2]=c[o>>2];c[Y+4>>2]=I;c[o>>2]=L;c[o+4>>2]=_;if(!pa){break}_=x+8+(H+(ia*96|0))|0;x=c[_>>2]|0;o=c[_+4>>2]|0;L=S+(M+8)|0;M=c[L+4>>2]|0;c[_>>2]=c[L>>2];c[_+4>>2]=M;c[L>>2]=x;c[L+4>>2]=o}}while(0);N=f+4832|0;re[c[f+5040+(c[N>>2]<<2)>>2]&1023](R,U);re[c[f+5040+(c[N>>2]<<2)>>2]&1023](S,U);N=c[B>>2]|0;o=h;L=j;x=c[t>>2]|0;c:do{if((s&1|0)==0){re[c[f+5084+(c[f+4836>>2]<<2)>>2]&1023](Q,T);if(!v){D2a(f+421200|0,f+424272|0,x);break}if((a[f+5184|0]|0)==0){break}if(!u){ef[c[f+128>>2]&4095](f+421200|0,f+424272|0,c[(c[f+177020>>2]|0)+(x<<6)>>2]|0);break}M=(N|0)==0;_=f+424272|0;I=f+421200|0;Y=0;do{D=d[1091856+Y|0]|0;if(M){b[f+421200+(D<<1)>>1]=b[f+424272+(Y<<1)>>1]|0}else{c[I+(D<<2)>>2]=c[_+(Y<<2)>>2]}Y=Y+1|0;}while((Y|0)<16)}else{if((s&16777216|0)!=0){if(u){Y=c[f+136>>2]|0;qa=Y;ra=Y}else{qa=c[f+100>>2]|0;ra=c[f+108>>2]|0}Y=f+6128|0;_=f+5160|0;I=f+5168|0;M=(N|0)==0;H=f+421200|0;w=0;while(1){J=Q+(c[V+(w<<2)>>2]|0)|0;Z=d[602328+w|0]|0;D=a[f+4888+Z|0]|0;X=D<<24>>24;do{if(u){if(!((c[Y>>2]|0)==244&D<<24>>24<2)){na=77;break}ef[c[f+5128+(X<<2)>>2]&4095](J,f+421200+(w<<4<<N<<1)|0,T)}else{na=77}}while(0);d:do{if((na|0)==77){na=0;D=a[f+5184+Z|0]|0;mf[c[f+4992+(X<<2)>>2]&2047](J,c[_>>2]<<w&32768,c[I>>2]<<w&16384,T);do{if((D<<24>>24|0)==1){A=w<<4;if(M){sa=e[f+421200+(A<<1)>>1]|0}else{sa=c[H+(A<<2)>>2]|0}if((sa|0)==0){ta=A;break}ef[ra&4095](J,f+421200+(A<<N<<1)|0,T);break d}else if((D<<24>>24|0)==0){break d}else{ta=w<<4}}while(0);ef[qa&4095](J,f+421200+(ta<<N<<1)|0,T)}}while(0);w=w+4|0;if((w|0)>=16){break c}}}if(u){w=c[f+140>>2]|0;ua=w;va=w}else{ua=c[f+96>>2]|0;va=c[f+104>>2]|0}w=f+6128|0;H=(N|0)==0;M=f+421200|0;I=f+5168|0;_=3-T|0;Y=3-((T|0)/2|0)|0;J=(4<<N)-T|0;X=0;do{Z=c[V+(X<<2)>>2]|0;D=Q+Z|0;A=d[602328+X|0]|0;W=a[f+4888+A|0]|0;m=W<<24>>24;do{if(u){if(!((c[w>>2]|0)==244&W<<24>>24<2)){na=93;break}ef[c[f+5120+(m<<2)>>2]&4095](D,f+421200+(X<<4<<N<<1)|0,T)}else{na=93}}while(0);e:do{if((na|0)==93){na=0;do{if((W<<24>>24|0)==7|(W<<24>>24|0)==3){if((c[I>>2]&32768>>>(X>>>0)|0)!=0){wa=Q+(J+Z)|0;break}if(H){c[h>>2]=ca(d[Q+(_+Z)|0]|0,16843009)|0;wa=o;break}else{C=Erc(e[D+(Y<<1)>>1]|0,0,65537,65537)|0;c[j>>2]=C;c[j+4>>2]=G;wa=L;break}}else{wa=0}}while(0);ef[c[f+4932+(m<<2)>>2]&4095](D,wa,T);C=a[f+5184+A|0]|0;if(C<<24>>24==0){break}if(!v){E2a(D,f+421200+(X<<4<<1)|0,T,x,0);break}$=X<<4;do{if(C<<24>>24==1){if(H){xa=e[f+421200+($<<1)>>1]|0}else{xa=c[M+($<<2)>>2]|0}if((xa|0)==0){break}ef[va&4095](D,f+421200+($<<N<<1)|0,T);break e}}while(0);ef[ua&4095](D,f+421200+($<<N<<1)|0,T)}}while(0);X=X+1|0;}while((X|0)<16)}}while(0);N=c[F>>2]|0;if((N|0)==0){na=190;break}x=c[B>>2]|0;do{if((c[f+177088>>2]|0)==0){ya=1}else{L=(c[f+177096>>2]|0)!=0;if((c[n>>2]&1|0)==0){ya=L&1^1;break}else{if(L){ya=1;break}else{na=190;break a}}}}while(0);if((N|0)==2){za=(e[(c[f+177072>>2]|0)+((c[p>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);Aa=c[f+4864>>2]|0;Ba=c[l>>2]|0}else{F=c[l>>2]|0;za=(F|0)>0;Aa=(c[n>>2]|0)>((c[q>>2]|0)!=0|0)|0;Ba=F}F=T+1+x|0;L=U+1+x|0;o=Ba-1|0;X=f+5176+(ya<<2)|0;M=c[X>>2]|0;H=M+(Ba*96|0)|0;if((Aa|0)==0){na=190;break}do{if(za){Y=8<<x;_=M+(o*96|0)+Y|0;J=c[_>>2]|0;I=c[_+4>>2]|0;w=(-7<<x)-F|0;D=Q+w|0;A=c[D+4>>2]|0;c[_>>2]=c[D>>2];c[_+4>>2]=A;c[D>>2]=J;c[D+4>>2]=I;if((x|0)==0){I=H;Ca=Q+(1-F)|0;Da=c[I+4>>2]|0;Ea=c[I>>2]|0;na=135;break}else{I=Y+8+(M+(o*96|0))|0;Y=c[I>>2]|0;D=c[I+4>>2]|0;J=Q+(w+8)|0;w=c[J+4>>2]|0;c[I>>2]=c[J>>2];c[I+4>>2]=w;c[J>>2]=Y;c[J+4>>2]=D;na=133;break}}else{na=133}}while(0);do{if((na|0)==133){N=H;D=c[N>>2]|0;J=c[N+4>>2]|0;N=(1<<x)-F|0;Y=Q+N|0;if((x|0)==0){Ca=Y;Da=J;Ea=D;na=135;break}c[Y>>2]=D;c[Y+4>>2]=J;J=M+(Ba*96|0)+8|0;Y=c[J+4>>2]|0;D=Q+(N+8)|0;c[D>>2]=c[J>>2];c[D+4>>2]=Y;Fa=1}}while(0);if((na|0)==135){c[Ca>>2]=Ea;c[Ca+4>>2]=Da;Fa=0}H=8<<x;Y=M+(Ba*96|0)+H|0;D=c[Y>>2]|0;J=c[Y+4>>2]|0;N=(9<<x)-F|0;w=Q+N|0;I=c[w+4>>2]|0;c[Y>>2]=c[w>>2];c[Y+4>>2]=I;c[w>>2]=D;c[w+4>>2]=J;if(Fa){J=H+8+(M+(Ba*96|0))|0;H=c[J>>2]|0;w=c[J+4>>2]|0;D=Q+(N+8)|0;N=c[D+4>>2]|0;c[J>>2]=c[D>>2];c[J+4>>2]=N;c[D>>2]=H;c[D+4>>2]=w}w=(c[l>>2]|0)+1|0;do{if((w|0)<(c[f+427400>>2]|0)){D=(c[X>>2]|0)+(w*96|0)|0;H=c[D>>2]|0;N=c[D+4>>2]|0;J=(17<<x)-F|0;I=Q+J|0;Y=c[I+4>>2]|0;c[D>>2]=c[I>>2];c[D+4>>2]=Y;c[I>>2]=H;c[I+4>>2]=N;if(!Fa){break}N=(c[X>>2]|0)+(((c[l>>2]|0)+1|0)*96|0)+8|0;I=c[N>>2]|0;H=c[N+4>>2]|0;Y=Q+(J+8)|0;J=c[Y+4>>2]|0;c[N>>2]=c[Y>>2];c[N+4>>2]=J;c[Y>>2]=I;c[Y+4>>2]=H}}while(0);X=16<<x;do{if(za){F=M+(o*96|0)+X|0;w=c[F>>2]|0;H=c[F+4>>2]|0;Y=(-7<<x)-L|0;I=R+Y|0;J=c[I+4>>2]|0;c[F>>2]=c[I>>2];c[F+4>>2]=J;c[I>>2]=w;c[I+4>>2]=H;if(Fa){H=X+8+(M+(o*96|0))|0;I=c[H>>2]|0;w=c[H+4>>2]|0;J=R+(Y+8)|0;F=c[J+4>>2]|0;c[H>>2]=c[J>>2];c[H+4>>2]=F;c[J>>2]=I;c[J+4>>2]=w}w=24<<x;J=M+(o*96|0)+w|0;I=c[J>>2]|0;F=c[J+4>>2]|0;H=S+Y|0;N=c[H+4>>2]|0;c[J>>2]=c[H>>2];c[J+4>>2]=N;c[H>>2]=I;c[H+4>>2]=F;if(!Fa){Ga=0;break}F=w+8+(M+(o*96|0))|0;w=c[F>>2]|0;H=c[F+4>>2]|0;I=S+(Y+8)|0;Y=c[I+4>>2]|0;c[F>>2]=c[I>>2];c[F+4>>2]=Y;c[I>>2]=w;c[I+4>>2]=H;Ga=1}else{Ga=Fa}}while(0);o=M+(Ba*96|0)+X|0;H=c[o>>2]|0;I=c[o+4>>2]|0;w=1-L+x|0;Y=R+w|0;F=c[Y+4>>2]|0;c[o>>2]=c[Y>>2];c[o+4>>2]=F;c[Y>>2]=H;c[Y+4>>2]=I;if(Ga){I=X+8+(M+(Ba*96|0))|0;Y=c[I>>2]|0;H=c[I+4>>2]|0;F=R+(w+8)|0;o=c[F+4>>2]|0;c[I>>2]=c[F>>2];c[I+4>>2]=o;c[F>>2]=Y;c[F+4>>2]=H}H=24<<x;F=M+(Ba*96|0)+H|0;Y=c[F>>2]|0;o=c[F+4>>2]|0;I=S+w|0;N=c[I+4>>2]|0;c[F>>2]=c[I>>2];c[F+4>>2]=N;c[I>>2]=Y;c[I+4>>2]=o;if(!Ga){na=190;break}o=H+8+(M+(Ba*96|0))|0;H=c[o>>2]|0;I=c[o+4>>2]|0;Y=S+(w+8)|0;w=c[Y+4>>2]|0;c[o>>2]=c[Y>>2];c[o+4>>2]=w;c[Y>>2]=H;c[Y+4>>2]=I;na=190}else{if(!v){na=190;break}I=c[f+1028>>2]|0;Y=f+148|0;H=c[f+1032>>2]|0;w=f+164|0;o=f+12|0;N=f+28|0;F=c[(c[r>>2]|0)+(c[p>>2]<<2)>>2]|0;J=c[B>>2]|0;D=a[f+5644|0]|0;A=D<<24>>24>-1;if(z){if(A){_=D<<24>>24;m=c[l>>2]|0;Z=(m<<4|8)+(b[f+5360>>1]>>2)|0;W=(b[f+5362>>1]>>2)+(c[n>>2]<<4)|0;C=(Z<<J)+(64<<J)+(ca(W+(m<<2&12)|0,T)|0)|0;ef[c[O>>2]&4095]((c[f+199440+(_*2224|0)>>2]|0)+C|0,P,4);C=(ca((c[l>>2]&7)+(W>>1)|0,c[K>>2]|0)|0)+((Z>>1)+64<<J)|0;Z=c[f+199440+(_*2224|0)+4>>2]|0;ef[c[O>>2]&4095](Z+C|0,(c[f+199440+(_*2224|0)+8>>2]|0)-Z|0,2)}do{if((F&8|0)==0){if((F&16|0)!=0){Z=I+64|0;_=H+64|0;Sha(f,0,0,8,8<<c[B>>2],Q,R,S,0,0,Z,c[Y>>2]|0,_,c[w>>2]|0,o,N,F&4096,F&16384);Sha(f,8,0,8,8<<c[B>>2],Q,R,S,0,4,Z,c[Y>>2]|0,_,c[w>>2]|0,o,N,F&8192,F&32768);break}_=f+6112|0;if((F&32|0)!=0){Z=I+64|0;C=f+152|0;W=H+64|0;m=f+168|0;da=f+16|0;aa=f+32|0;Sha(f,0,0,16,c[_>>2]<<3,Q,R,S,0,0,Z,c[C>>2]|0,W,c[m>>2]|0,da,aa,F&4096,F&16384);Sha(f,4,0,16,c[_>>2]<<3,Q,R,S,4,0,Z,c[C>>2]|0,W,c[m>>2]|0,da,aa,F&8192,F&32768);break}aa=I+128|0;da=f+156|0;m=H+128|0;W=f+172|0;C=f+20|0;Z=f+36|0;ba=f+152|0;Ha=f+168|0;Ia=f+16|0;Ja=f+32|0;Ka=I+64|0;La=H+64|0;Ma=0;do{Na=e[f+177112+(Ma<<1)>>1]|0;Oa=Ma<<2;Pa=Oa&4;Qa=Ma<<1&4;do{if((Na&8|0)==0){if((Na&16|0)!=0){Ra=Na&4096;Sa=Na&16384;Sha(f,Oa,0,4,4<<c[B>>2],Q,R,S,Pa,Qa,aa,c[ba>>2]|0,m,c[Ha>>2]|0,Ia,Ja,Ra,Sa);Sha(f,Oa|2,0,4,4<<c[B>>2],Q,R,S,Pa,Qa|2,aa,c[ba>>2]|0,m,c[Ha>>2]|0,Ia,Ja,Ra,Sa);break}if((Na&32|0)==0){Sa=Na&4096;Ra=Na&16384;Sha(f,Oa,1,4,0,Q,R,S,Pa,Qa,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Sa,Ra);Ta=Pa|2;Sha(f,Oa|1,1,4,0,Q,R,S,Ta,Qa,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Sa,Ra);Ua=Qa|2;Sha(f,Oa|2,1,4,0,Q,R,S,Pa,Ua,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Sa,Ra);Sha(f,Oa|3,1,4,0,Q,R,S,Ta,Ua,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Sa,Ra);break}else{Ra=Na&4096;Sa=Na&16384;Sha(f,Oa,0,8,c[_>>2]<<2,Q,R,S,Pa,Qa,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Ra,Sa);Sha(f,Oa|1,0,8,c[_>>2]<<2,Q,R,S,Pa|2,Qa,aa,c[da>>2]|0,m,c[W>>2]|0,C,Z,Ra,Sa);break}}else{Sha(f,Oa,1,8,0,Q,R,S,Pa,Qa,Ka,c[ba>>2]|0,La,c[Ha>>2]|0,Ia,Ja,Na&4096,Na&16384)}}while(0);Ma=Ma+1|0;}while((Ma|0)<4)}else{Sha(f,0,1,16,0,Q,R,S,0,0,I|0,c[Y>>2]|0,H|0,c[w>>2]|0,o,N,F&4096,F&16384)}}while(0);M=c[B>>2]|0;x=a[f+5684|0]|0;if(!(x<<24>>24>-1)){Va=M;break}X=x<<24>>24;x=c[l>>2]|0;L=(x<<4|8)+(b[f+5520>>1]>>2)|0;Ma=(b[f+5522>>1]>>2)+(c[n>>2]<<4)|0;Ja=(L<<M)+(64<<M)+(ca(Ma+(x<<2&12)|0,c[f+6112>>2]|0)|0)|0;ef[c[O>>2]&4095]((c[f+306192+(X*2224|0)>>2]|0)+Ja|0,c[E>>2]|0,4);Ja=(ca((c[l>>2]&7)+(Ma>>1)|0,c[K>>2]|0)|0)+((L>>1)+64<<M)|0;M=c[f+306192+(X*2224|0)+4>>2]|0;ef[c[O>>2]&4095](M+Ja|0,(c[f+306192+(X*2224|0)+8>>2]|0)-M|0,2);na=190;break}else{if(A){M=D<<24>>24;X=c[l>>2]|0;Ja=(X<<4|8)+(b[f+5360>>1]>>2)|0;L=(b[f+5362>>1]>>2)+(c[n>>2]<<4)|0;Ma=(Ja<<J)+(64<<J)+(ca(L+(X<<2&12)|0,T)|0)|0;ef[c[O>>2]&4095]((c[f+199440+(M*2224|0)>>2]|0)+Ma|0,P,4);Ma=(ca((c[l>>2]&7)+(L>>1)|0,c[K>>2]|0)|0)+((Ja>>1)+64<<J)|0;Ja=c[f+199440+(M*2224|0)+4>>2]|0;ef[c[O>>2]&4095](Ja+Ma|0,(c[f+199440+(M*2224|0)+8>>2]|0)-Ja|0,2)}do{if((F&8|0)==0){if((F&16|0)!=0){Ja=I+64|0;M=H+64|0;Rha(f,0,0,8,8<<c[B>>2],Q,R,S,0,0,Ja,c[Y>>2]|0,M,c[w>>2]|0,o,N,F&4096,F&16384);Rha(f,8,0,8,8<<c[B>>2],Q,R,S,0,4,Ja,c[Y>>2]|0,M,c[w>>2]|0,o,N,F&8192,F&32768);break}M=f+6112|0;if((F&32|0)!=0){Ja=I+64|0;Ma=f+152|0;L=H+64|0;X=f+168|0;x=f+16|0;Ia=f+32|0;Rha(f,0,0,16,c[M>>2]<<3,Q,R,S,0,0,Ja,c[Ma>>2]|0,L,c[X>>2]|0,x,Ia,F&4096,F&16384);Rha(f,4,0,16,c[M>>2]<<3,Q,R,S,4,0,Ja,c[Ma>>2]|0,L,c[X>>2]|0,x,Ia,F&8192,F&32768);break}Ia=I+128|0;x=f+156|0;X=H+128|0;L=f+172|0;Ma=f+20|0;Ja=f+36|0;Ha=f+152|0;La=f+168|0;ba=f+16|0;Ka=f+32|0;Z=I+64|0;C=H+64|0;W=0;do{m=e[f+177112+(W<<1)>>1]|0;da=W<<2;aa=da&4;_=W<<1&4;do{if((m&8|0)==0){if((m&16|0)!=0){Na=m&4096;Qa=m&16384;Rha(f,da,0,4,4<<c[B>>2],Q,R,S,aa,_,Ia,c[Ha>>2]|0,X,c[La>>2]|0,ba,Ka,Na,Qa);Rha(f,da|2,0,4,4<<c[B>>2],Q,R,S,aa,_|2,Ia,c[Ha>>2]|0,X,c[La>>2]|0,ba,Ka,Na,Qa);break}if((m&32|0)==0){Qa=m&4096;Na=m&16384;Rha(f,da,1,4,0,Q,R,S,aa,_,Ia,c[x>>2]|0,X,c[L>>2]|0,Ma,Ja,Qa,Na);Pa=aa|2;Rha(f,da|1,1,4,0,Q,R,S,Pa,_,Ia,c[x>>2]|0,X,c[L>>2]|0,Ma,Ja,Qa,Na);Oa=_|2;Rha(f,da|2,1,4,0,Q,R,S,aa,Oa,Ia,c[x>>2]|0,X,c[L>>2]|0,Ma,Ja,Qa,Na);Rha(f,da|3,1,4,0,Q,R,S,Pa,Oa,Ia,c[x>>2]|0,X,c[L>>2]|0,Ma,Ja,Qa,Na);break}else{Na=m&4096;Qa=m&16384;Rha(f,da,0,8,c[M>>2]<<2,Q,R,S,aa,_,Ia,c[x>>2]|0,X,c[L>>2]|0,Ma,Ja,Na,Qa);Rha(f,da|1,0,8,c[M>>2]<<2,Q,R,S,aa|2,_,Ia,c[x>>2]|0,X,c[L>>2]|0,Ma,Ja,Na,Qa);break}}else{Rha(f,da,1,8,0,Q,R,S,aa,_,Z,c[Ha>>2]|0,C,c[La>>2]|0,ba,Ka,m&4096,m&16384)}}while(0);W=W+1|0;}while((W|0)<4)}else{Rha(f,0,1,16,0,Q,R,S,0,0,I|0,c[Y>>2]|0,H|0,c[w>>2]|0,o,N,F&4096,F&16384)}}while(0);F=c[B>>2]|0;N=a[f+5684|0]|0;if(!(N<<24>>24>-1)){Va=F;break}o=N<<24>>24;N=c[l>>2]|0;w=(N<<4|8)+(b[f+5520>>1]>>2)|0;H=(b[f+5522>>1]>>2)+(c[n>>2]<<4)|0;Y=(w<<F)+(64<<F)+(ca(H+(N<<2&12)|0,c[f+6112>>2]|0)|0)|0;ef[c[O>>2]&4095]((c[f+306192+(o*2224|0)>>2]|0)+Y|0,c[E>>2]|0,4);Y=(ca((c[l>>2]&7)+(H>>1)|0,c[K>>2]|0)|0)+((w>>1)+64<<F)|0;F=c[f+306192+(o*2224|0)+4>>2]|0;ef[c[O>>2]&4095](F+Y|0,(c[f+306192+(o*2224|0)+8>>2]|0)-F|0,2);na=190;break}}}while(0);if((na|0)==190){Va=c[B>>2]|0}f:do{if((s&1|0)==0){if(!v){O=ea&1;K=0;while(1){l=f+421200+(K<<4<<1)|0;if((a[(d[602328+K|0]|0)+(f+5184)|0]|0)==0){if((b[l>>1]|0)!=0){na=219}}else{na=219}if((na|0)==219){na=0;E2a(Q+(c[V+(K<<2)>>2]|0)|0,l,T,c[t>>2]|0,O)}K=K+1|0;if((K|0)>=16){break f}}}if((s&2|0)==0){if((c[f+426564>>2]&15|0)==0){break}K=(s&16777216|0)!=0;if(!u){if(K){pe[c[f+116>>2]&1023](Q,V,f+421200|0,T,f+5184|0);break}else{pe[c[f+112>>2]&1023](Q,V,f+421200|0,T,f+5184|0);break}}O=K?4:1;l=c[(K?f+136|0:f+140|0)>>2]|0;K=0;while(1){if((a[(d[602328+K|0]|0)+(f+5184)|0]|0)!=0){ef[l&4095](Q+(c[V+(K<<2)>>2]|0)|0,f+421200+(K<<4<<Va<<1)|0,T)}K=K+O|0;if((K|0)>=16){break f}}}if(!u){pe[c[f+124>>2]&1023](Q,V,f+421200|0,T,f+5184|0);break}do{if((c[f+6128>>2]|0)==244){K=c[f+4836>>2]|0;if(!((K-1|0)>>>0<2>>>0)){break}mf[c[f+5148+(K<<2)>>2]&2047](Q,V,f+421200|0,T);break f}}while(0);K=(Va|0)==0;O=f+421200|0;l=f+140|0;E=0;do{n=E<<4;if((a[(d[602328+E|0]|0)+(f+5184)|0]|0)==0){if(K){Wa=e[f+421200+(n<<1)>>1]|0}else{Wa=c[O+(n<<2)>>2]|0}if((Wa|0)!=0){na=205}}else{na=205}if((na|0)==205){na=0;ef[c[l>>2]&4095](Q+(c[V+(E<<2)>>2]|0)|0,f+421200+(n<<Va<<1)|0,T)}E=E+1|0;}while((E|0)<16)}}while(0);if((c[f+426564>>2]&48|0)==0){i=g;return}T=k|0;c[T>>2]=R;Va=k+4|0;c[Va>>2]=S;if(!u){if(v){v=c[f+4756>>2]|0;if(z){Xa=v+3|0;Ya=(c[f+4760>>2]|0)+3|0}else{Xa=v;Ya=c[f+4760>>2]|0}if((a[f+5224|0]|0)!=0){re[c[f+132>>2]&1023](f+421200+(256<<c[B>>2]<<1)|0,c[(c[f+177020+((ea?1:4)<<2)>>2]|0)+(Xa<<6)>>2]|0)}if((a[f+5264|0]|0)!=0){re[c[f+132>>2]&1023](f+421200+(512<<c[B>>2]<<1)|0,c[(c[f+177020+((ea?2:5)<<2)>>2]|0)+(Ya<<6)>>2]|0)}pe[c[f+120>>2]&1023](T,V,f+421200|0,U,f+5184|0);i=g;return}T=f+132|0;re[c[T>>2]&1023](f+421712|0,c[(c[f+177020+((ea?1:4)<<2)>>2]|0)+(c[f+4756>>2]<<6)>>2]|0);re[c[T>>2]&1023](f+422224|0,c[(c[f+177020+((ea?2:5)<<2)>>2]|0)+(c[f+4760>>2]<<6)>>2]|0);T=1;do{Ya=T<<4;do{if((Ya|0)<(Ya|4|0)){Xa=k+(T-1<<2)|0;v=f+421200+(T<<8<<1)|0;if((a[(d[602328+Ya|0]|0)+(f+5184)|0]|0)==0){if((b[v>>1]|0)!=0){na=259}}else{na=259}if((na|0)==259){na=0;E2a((c[Xa>>2]|0)+(c[V+(Ya<<2)>>2]|0)|0,v,U,(d[(c[t>>2]|0)+1376172|0]|0)-12|0,2)}v=Ya|1;u=f+421200+(v<<4<<1)|0;if((a[(d[602328+v|0]|0)+(f+5184)|0]|0)==0){if((b[u>>1]|0)!=0){na=298}}else{na=298}if((na|0)==298){na=0;E2a((c[Xa>>2]|0)+(c[V+(v<<2)>>2]|0)|0,u,U,(d[(c[t>>2]|0)+1376172|0]|0)-12|0,2)}u=v+1|0;v=f+421200+(u<<4<<1)|0;if((a[(d[602328+u|0]|0)+(f+5184)|0]|0)==0){if((b[v>>1]|0)!=0){na=301}}else{na=301}if((na|0)==301){na=0;E2a((c[Xa>>2]|0)+(c[V+(u<<2)>>2]|0)|0,v,U,(d[(c[t>>2]|0)+1376172|0]|0)-12|0,2)}v=Ya|3;u=f+421200+(v<<4<<1)|0;if((a[(d[602328+v|0]|0)+(f+5184)|0]|0)==0){if((b[u>>1]|0)==0){break}}E2a((c[Xa>>2]|0)+(c[V+(v<<2)>>2]|0)|0,u,U,(d[(c[t>>2]|0)+1376172|0]|0)-12|0,2)}}while(0);T=T+1|0;}while((T|0)<3);i=g;return}do{if(ea){if((c[f+6128>>2]|0)!=244){break}T=f+4832|0;t=c[T>>2]|0;if(!((t-1|0)>>>0<2>>>0)){break}mf[c[f+5136+(t<<2)>>2]&2047](R,V+64|0,f+421200+(256<<c[B>>2]<<1)|0,U);mf[c[f+5136+(c[T>>2]<<2)>>2]&2047](c[Va>>2]|0,V+128|0,f+421200+(512<<c[B>>2]<<1)|0,U);i=g;return}}while(0);Va=c[f+140>>2]|0;R=f+421200|0;ea=1;do{T=ea<<4;t=T|4;do{if((T|0)<(t|0)){Ya=k+(ea-1<<2)|0;u=c[B>>2]|0;v=ea<<8;if((a[(d[602328+T|0]|0)+(f+5184)|0]|0)==0){if((u|0)==0){Za=e[f+421200+(v<<1)>>1]|0}else{Za=c[R+(v<<2)>>2]|0}if((Za|0)!=0){na=234}}else{na=234}if((na|0)==234){na=0;ef[Va&4095]((c[Ya>>2]|0)+(c[V+(T<<2)>>2]|0)|0,f+421200+(v<<u<<1)|0,U)}u=T|1;v=c[B>>2]|0;Xa=u<<4;if((a[(d[602328+u|0]|0)+(f+5184)|0]|0)==0){if((v|0)==0){_a=e[f+421200+(Xa<<1)>>1]|0}else{_a=c[R+(Xa<<2)>>2]|0}if((_a|0)!=0){na=267}}else{na=267}if((na|0)==267){na=0;ef[Va&4095]((c[Ya>>2]|0)+(c[V+(u<<2)>>2]|0)|0,f+421200+(Xa<<v<<1)|0,U)}v=u+1|0;u=c[B>>2]|0;Xa=v<<4;if((a[(d[602328+v|0]|0)+(f+5184)|0]|0)==0){if((u|0)==0){$a=e[f+421200+(Xa<<1)>>1]|0}else{$a=c[R+(Xa<<2)>>2]|0}if(($a|0)!=0){na=273}}else{na=273}if((na|0)==273){na=0;ef[Va&4095]((c[Ya>>2]|0)+(c[V+(v<<2)>>2]|0)|0,f+421200+(Xa<<u<<1)|0,U)}u=T|3;Xa=c[B>>2]|0;v=u<<4;if((a[(d[602328+u|0]|0)+(f+5184)|0]|0)==0){if((Xa|0)==0){ab=e[f+421200+(v<<1)>>1]|0}else{ab=c[R+(v<<2)>>2]|0}if((ab|0)==0){break}}ef[Va&4095]((c[Ya>>2]|0)+(c[V+(u<<2)>>2]|0)|0,f+421200+(v<<Xa<<1)|0,U)}}while(0);do{if(z){if((t|0)>=(T|8|0)){break}Xa=k+(ea-1<<2)|0;v=t+4|0;u=c[B>>2]|0;Ya=t<<4;if((a[(d[602328+v|0]|0)+(f+5184)|0]|0)==0){if((u|0)==0){bb=e[f+421200+(Ya<<1)>>1]|0}else{bb=c[R+(Ya<<2)>>2]|0}if((bb|0)!=0){na=243}}else{na=243}if((na|0)==243){na=0;ef[Va&4095]((c[Xa>>2]|0)+(c[V+(v<<2)>>2]|0)|0,f+421200+(Ya<<u<<1)|0,U)}u=T|5;Ya=u+4|0;v=c[B>>2]|0;S=u<<4;if((a[(d[602328+Ya|0]|0)+(f+5184)|0]|0)==0){if((v|0)==0){cb=e[f+421200+(S<<1)>>1]|0}else{cb=c[R+(S<<2)>>2]|0}if((cb|0)!=0){na=284}}else{na=284}if((na|0)==284){na=0;ef[Va&4095]((c[Xa>>2]|0)+(c[V+(Ya<<2)>>2]|0)|0,f+421200+(S<<v<<1)|0,U)}v=u+5|0;S=c[B>>2]|0;Ya=(u<<4)+16|0;if((a[(d[602328+v|0]|0)+(f+5184)|0]|0)==0){if((S|0)==0){db=e[f+421200+(Ya<<1)>>1]|0}else{db=c[R+(Ya<<2)>>2]|0}if((db|0)!=0){na=290}}else{na=290}if((na|0)==290){na=0;ef[Va&4095]((c[Xa>>2]|0)+(c[V+(v<<2)>>2]|0)|0,f+421200+(Ya<<S<<1)|0,U)}S=T|7;Ya=S+4|0;v=c[B>>2]|0;u=S<<4;if((a[(d[602328+Ya|0]|0)+(f+5184)|0]|0)==0){if((v|0)==0){eb=e[f+421200+(u<<1)>>1]|0}else{eb=c[R+(u<<2)>>2]|0}if((eb|0)==0){break}}ef[Va&4095]((c[Xa>>2]|0)+(c[V+(Ya<<2)>>2]|0)|0,f+421200+(u<<v<<1)|0,U)}}while(0);ea=ea+1|0;}while((ea|0)<3);i=g;return}function qha(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=f+427376|0;l=c[k>>2]|0;m=f+427380|0;n=c[m>>2]|0;o=f+427412|0;p=c[o>>2]|0;q=f+4064|0;r=c[(c[q>>2]|0)+(p<<2)>>2]|0;s=f+5716|0;t=(c[f+6136>>2]|0)==2;u=c[f+2528>>2]|0;v=f+4776|0;w=c[v>>2]|0;x=(ca(w,n)|0)+(l<<1)<<4;y=u+x|0;z=c[f+2532>>2]|0;A=f+4780|0;B=(ca(ca(16>>>((c[f+4788>>2]|0)>>>0),n)|0,c[A>>2]|0)|0)+(l<<4)|0;n=z+B|0;C=c[f+2536>>2]|0;D=C+B|0;E=f+8|0;F=u+((ca(w,l<<2&12)|0)+128+x)|0;ef[c[E>>2]&4095](F,w,4);w=z+(B+128+(ca(c[k>>2]&7,c[A>>2]|0)|0))|0;ef[c[E>>2]&4095](w,D-n|0,2);a[(c[f+199432>>2]|0)+p|0]=c[f+199428>>2];p=c[v>>2]|0;w=f+6112|0;c[w>>2]=p;F=c[A>>2]|0;c[f+6116>>2]=F;l=(r&7|0)!=0;do{if(l){H=f+427420|0;I=c[H>>2]|0;if((I|0)==2){J=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);K=c[f+4864>>2]|0;L=c[k>>2]|0;M=5}else if((I|0)!=0){I=c[k>>2]|0;J=(I|0)>0;K=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;L=I;M=5}do{if((M|0)==5){I=L-1|0;N=f+5180|0;O=c[N>>2]|0;if((K|0)==0){break}if(J){P=O+(I*96|0)+16|0;Q=c[P>>2]|0;R=c[P+4>>2]|0;S=-16-p|0;T=u+(S+x)|0;U=c[T+4>>2]|0;c[P>>2]=c[T>>2];c[P+4>>2]=U;c[T>>2]=Q;c[T+4>>2]=R;R=O+(I*96|0)+24|0;T=c[R>>2]|0;Q=c[R+4>>2]|0;U=x|8;P=u+(U+S)|0;S=c[P+4>>2]|0;c[R>>2]=c[P>>2];c[R+4>>2]=S;c[P>>2]=T;c[P+4>>2]=Q;V=U}else{V=x|8}U=O+(L*96|0)|0;Q=c[U>>2]|0;P=c[U+4>>2]|0;T=u+(x-p)|0;S=c[T+4>>2]|0;c[U>>2]=c[T>>2];c[U+4>>2]=S;c[T>>2]=Q;c[T+4>>2]=P;P=O+(L*96|0)+8|0;T=c[P>>2]|0;Q=c[P+4>>2]|0;S=u+(V-p)|0;U=c[S+4>>2]|0;c[P>>2]=c[S>>2];c[P+4>>2]=U;c[S>>2]=T;c[S+4>>2]=Q;Q=O+(L*96|0)+16|0;S=c[Q>>2]|0;T=c[Q+4>>2]|0;U=16-p|0;P=u+(U+x)|0;R=c[P+4>>2]|0;c[Q>>2]=c[P>>2];c[Q+4>>2]=R;c[P>>2]=S;c[P+4>>2]=T;T=O+(L*96|0)+24|0;P=c[T>>2]|0;S=c[T+4>>2]|0;R=u+(V+U)|0;U=c[R+4>>2]|0;c[T>>2]=c[R>>2];c[T+4>>2]=U;c[R>>2]=P;c[R+4>>2]=S;S=(c[k>>2]|0)+1|0;if((S|0)<(c[f+427400>>2]|0)){R=(c[N>>2]|0)+(S*96|0)|0;S=c[R>>2]|0;P=c[R+4>>2]|0;U=32-p|0;T=u+(U+x)|0;Q=c[T+4>>2]|0;c[R>>2]=c[T>>2];c[R+4>>2]=Q;c[T>>2]=S;c[T+4>>2]=P;P=(c[N>>2]|0)+(((c[k>>2]|0)+1|0)*96|0)+8|0;N=c[P>>2]|0;T=c[P+4>>2]|0;S=u+(V+U)|0;U=c[S+4>>2]|0;c[P>>2]=c[S>>2];c[P+4>>2]=U;c[S>>2]=N;c[S+4>>2]=T}if(J){T=O+(I*96|0)+32|0;S=c[T>>2]|0;N=c[T+4>>2]|0;U=-16-F|0;P=U+B|0;Q=z+P|0;R=c[Q+4>>2]|0;c[T>>2]=c[Q>>2];c[T+4>>2]=R;c[Q>>2]=S;c[Q+4>>2]=N;N=O+(I*96|0)+40|0;Q=c[N>>2]|0;S=c[N+4>>2]|0;R=U+8+B|0;U=z+R|0;T=c[U+4>>2]|0;c[N>>2]=c[U>>2];c[N+4>>2]=T;c[U>>2]=Q;c[U+4>>2]=S;S=O+(I*96|0)+48|0;U=c[S>>2]|0;Q=c[S+4>>2]|0;T=C+P|0;P=c[T+4>>2]|0;c[S>>2]=c[T>>2];c[S+4>>2]=P;c[T>>2]=U;c[T+4>>2]=Q;Q=O+(I*96|0)+56|0;I=c[Q>>2]|0;T=c[Q+4>>2]|0;U=C+R|0;R=c[U+4>>2]|0;c[Q>>2]=c[U>>2];c[Q+4>>2]=R;c[U>>2]=I;c[U+4>>2]=T}T=O+(L*96|0)+32|0;U=c[T>>2]|0;I=c[T+4>>2]|0;R=B-F|0;Q=z+R|0;P=c[Q+4>>2]|0;c[T>>2]=c[Q>>2];c[T+4>>2]=P;c[Q>>2]=U;c[Q+4>>2]=I;I=O+(L*96|0)+40|0;Q=c[I>>2]|0;U=c[I+4>>2]|0;P=8-F+B|0;T=z+P|0;S=c[T+4>>2]|0;c[I>>2]=c[T>>2];c[I+4>>2]=S;c[T>>2]=Q;c[T+4>>2]=U;U=O+(L*96|0)+48|0;T=c[U>>2]|0;Q=c[U+4>>2]|0;S=C+R|0;R=c[S+4>>2]|0;c[U>>2]=c[S>>2];c[U+4>>2]=R;c[S>>2]=T;c[S+4>>2]=Q;Q=O+(L*96|0)+56|0;O=c[Q>>2]|0;S=c[Q+4>>2]|0;T=C+P|0;P=c[T+4>>2]|0;c[Q>>2]=c[T>>2];c[Q+4>>2]=P;c[T>>2]=O;c[T+4>>2]=S}}while(0);S=f+4832|0;re[c[f+5040+(c[S>>2]<<2)>>2]&1023](n,F);re[c[f+5040+(c[S>>2]<<2)>>2]&1023](D,F);S=h;T=c[f+4792>>2]|0;a:do{if((r&1|0)==0){re[c[f+5084+(c[f+4836>>2]<<2)>>2]&1023](y,p);if((a[f+5184|0]|0)==0){break}ef[c[f+128>>2]&4095](f+421200|0,f+424272|0,c[(c[f+177020>>2]|0)+(T<<6)>>2]|0)}else{if((r&16777216|0)!=0){O=c[f+108>>2]|0;P=c[f+100>>2]|0;Q=f+5160|0;R=f+5168|0;U=f+421200|0;I=0;while(1){N=u+((c[f+5716+(I<<2)>>2]|0)+x)|0;W=d[602328+I|0]|0;X=a[f+5184+W|0]|0;mf[c[f+4992+(a[f+4888+W|0]<<24>>24<<2)>>2]&2047](N,c[Q>>2]<<I&32768,c[R>>2]<<I&16384,p);do{if((X<<24>>24|0)==1){W=I<<4;if((c[U+(W<<2)>>2]|0)==0){Y=W;M=21;break}ef[O&4095](N,f+421200+(I<<5<<1)|0,p)}else if((X<<24>>24|0)!=0){Y=I<<4;M=21}}while(0);if((M|0)==21){M=0;ef[P&4095](N,f+421200+(Y<<1<<1)|0,p)}I=I+4|0;if((I|0)>=16){break a}}}I=c[f+104>>2]|0;P=c[f+96>>2]|0;O=f+421200|0;U=f+5168|0;R=3-((p|0)/2|0)|0;Q=(x|8)-p|0;X=0;do{W=c[f+5716+(X<<2)>>2]|0;Z=u+(W+x)|0;_=d[602328+X|0]|0;$=a[f+4888+_|0]|0;aa=$<<24>>24;do{if(($<<24>>24|0)==7|($<<24>>24|0)==3){if((c[U>>2]&32768>>>(X>>>0)|0)==0){ba=Erc(e[Z+(R<<1)>>1]|0,0,65537,65537)|0;c[h>>2]=ba;c[h+4>>2]=G;da=S;break}else{da=u+(Q+W)|0;break}}else{da=0}}while(0);ef[c[f+4932+(aa<<2)>>2]&4095](Z,da,p);W=a[f+5184+_|0]|0;do{if((W<<24>>24|0)==1){if((c[O+(X<<4<<2)>>2]|0)==0){M=31;break}ef[I&4095](Z,f+421200+(X<<5<<1)|0,p)}else if((W<<24>>24|0)!=0){M=31}}while(0);if((M|0)==31){M=0;ef[P&4095](Z,f+421200+(X<<5<<1)|0,p)}X=X+1|0;}while((X|0)<16)}}while(0);S=c[H>>2]|0;if((S|0)==0){break}else if((S|0)==2){ea=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);fa=c[f+4864>>2]|0;ga=c[k>>2]|0}else{S=c[k>>2]|0;ea=(S|0)>0;fa=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;ga=S}S=ga-1|0;T=f+5180|0;X=c[T>>2]|0;if((fa|0)==0){break}if(ea){P=X+(S*96|0)+16|0;I=c[P>>2]|0;O=c[P+4>>2]|0;Q=-16-p|0;R=u+(Q+x)|0;U=c[R+4>>2]|0;c[P>>2]=c[R>>2];c[P+4>>2]=U;c[R>>2]=I;c[R+4>>2]=O;O=X+(S*96|0)+24|0;R=c[O>>2]|0;I=c[O+4>>2]|0;U=x|8;P=u+(U+Q)|0;Q=c[P+4>>2]|0;c[O>>2]=c[P>>2];c[O+4>>2]=Q;c[P>>2]=R;c[P+4>>2]=I;ha=U}else{ha=x|8}U=X+(ga*96|0)|0;I=c[U+4>>2]|0;P=u+(x-p)|0;c[P>>2]=c[U>>2];c[P+4>>2]=I;I=X+(ga*96|0)+8|0;P=c[I+4>>2]|0;U=u+(ha-p)|0;c[U>>2]=c[I>>2];c[U+4>>2]=P;P=X+(ga*96|0)+16|0;U=c[P>>2]|0;I=c[P+4>>2]|0;R=16-p|0;Q=u+(R+x)|0;O=c[Q+4>>2]|0;c[P>>2]=c[Q>>2];c[P+4>>2]=O;c[Q>>2]=U;c[Q+4>>2]=I;I=X+(ga*96|0)+24|0;Q=c[I>>2]|0;U=c[I+4>>2]|0;O=u+(ha+R)|0;R=c[O+4>>2]|0;c[I>>2]=c[O>>2];c[I+4>>2]=R;c[O>>2]=Q;c[O+4>>2]=U;U=(c[k>>2]|0)+1|0;if((U|0)<(c[f+427400>>2]|0)){O=(c[T>>2]|0)+(U*96|0)|0;U=c[O>>2]|0;Q=c[O+4>>2]|0;R=32-p|0;I=u+(R+x)|0;P=c[I+4>>2]|0;c[O>>2]=c[I>>2];c[O+4>>2]=P;c[I>>2]=U;c[I+4>>2]=Q;Q=(c[T>>2]|0)+(((c[k>>2]|0)+1|0)*96|0)+8|0;T=c[Q>>2]|0;I=c[Q+4>>2]|0;U=u+(ha+R)|0;R=c[U+4>>2]|0;c[Q>>2]=c[U>>2];c[Q+4>>2]=R;c[U>>2]=T;c[U+4>>2]=I}if(ea){I=X+(S*96|0)+32|0;U=c[I>>2]|0;T=c[I+4>>2]|0;R=-16-F|0;Q=R+B|0;P=z+Q|0;O=c[P+4>>2]|0;c[I>>2]=c[P>>2];c[I+4>>2]=O;c[P>>2]=U;c[P+4>>2]=T;T=X+(S*96|0)+40|0;P=c[T>>2]|0;U=c[T+4>>2]|0;O=R+8+B|0;R=z+O|0;I=c[R+4>>2]|0;c[T>>2]=c[R>>2];c[T+4>>2]=I;c[R>>2]=P;c[R+4>>2]=U;U=X+(S*96|0)+48|0;R=c[U>>2]|0;P=c[U+4>>2]|0;I=C+Q|0;Q=c[I+4>>2]|0;c[U>>2]=c[I>>2];c[U+4>>2]=Q;c[I>>2]=R;c[I+4>>2]=P;P=X+(S*96|0)+56|0;S=c[P>>2]|0;I=c[P+4>>2]|0;R=C+O|0;O=c[R+4>>2]|0;c[P>>2]=c[R>>2];c[P+4>>2]=O;c[R>>2]=S;c[R+4>>2]=I}I=X+(ga*96|0)+32|0;R=c[I>>2]|0;S=c[I+4>>2]|0;O=B-F|0;P=z+O|0;Q=c[P+4>>2]|0;c[I>>2]=c[P>>2];c[I+4>>2]=Q;c[P>>2]=R;c[P+4>>2]=S;S=X+(ga*96|0)+40|0;P=c[S>>2]|0;R=c[S+4>>2]|0;Q=8-F+B|0;I=z+Q|0;U=c[I+4>>2]|0;c[S>>2]=c[I>>2];c[S+4>>2]=U;c[I>>2]=P;c[I+4>>2]=R;R=X+(ga*96|0)+48|0;I=c[R>>2]|0;P=c[R+4>>2]|0;U=C+O|0;O=c[U+4>>2]|0;c[R>>2]=c[U>>2];c[R+4>>2]=O;c[U>>2]=I;c[U+4>>2]=P;P=X+(ga*96|0)+56|0;X=c[P>>2]|0;U=c[P+4>>2]|0;I=C+Q|0;Q=c[I+4>>2]|0;c[P>>2]=c[I>>2];c[P+4>>2]=Q;c[I>>2]=X;c[I+4>>2]=U}else{U=c[f+1028>>2]|0;I=f+148|0;X=c[f+1032>>2]|0;Q=f+164|0;P=f+12|0;O=f+28|0;R=c[(c[q>>2]|0)+(c[o>>2]<<2)>>2]|0;S=a[f+5644|0]|0;T=S<<24>>24>-1;if(t){if(T){W=S<<24>>24;_=c[k>>2]|0;aa=(_<<4|8)+(b[f+5360>>1]>>2)|0;$=(b[f+5362>>1]>>2)+(c[m>>2]<<4)|0;N=(aa<<1)+128+(ca($+(_<<2&12)|0,p)|0)|0;ef[c[E>>2]&4095]((c[f+199440+(W*2224|0)>>2]|0)+N|0,p,4);N=(ca((c[k>>2]&7)+($>>1)|0,c[A>>2]|0)|0)+(aa+128&-2)|0;aa=c[f+199440+(W*2224|0)+4>>2]|0;ef[c[E>>2]&4095](aa+N|0,(c[f+199440+(W*2224|0)+8>>2]|0)-aa|0,2)}do{if((R&8|0)==0){if((R&16|0)!=0){aa=U+64|0;W=X+64|0;Qha(f,0,0,8,16,y,n,D,0,0,aa,c[I>>2]|0,W,c[Q>>2]|0,P,O,R&4096,R&16384);Qha(f,8,0,8,16,y,n,D,0,4,aa,c[I>>2]|0,W,c[Q>>2]|0,P,O,R&8192,R&32768);break}if((R&32|0)!=0){W=U+64|0;aa=f+152|0;N=X+64|0;$=f+168|0;_=f+16|0;ba=f+32|0;Qha(f,0,0,16,c[w>>2]<<3,y,n,D,0,0,W,c[aa>>2]|0,N,c[$>>2]|0,_,ba,R&4096,R&16384);Qha(f,4,0,16,c[w>>2]<<3,y,n,D,4,0,W,c[aa>>2]|0,N,c[$>>2]|0,_,ba,R&8192,R&32768);break}ba=U+128|0;_=f+156|0;$=X+128|0;N=f+172|0;aa=f+20|0;W=f+36|0;ia=f+152|0;ja=f+168|0;ka=f+16|0;la=f+32|0;ma=U+64|0;na=X+64|0;oa=0;do{pa=e[f+177112+(oa<<1)>>1]|0;qa=oa<<2;ra=qa&4;sa=oa<<1&4;do{if((pa&8|0)==0){if((pa&16|0)!=0){ta=pa&4096;ua=pa&16384;Qha(f,qa,0,4,8,y,n,D,ra,sa,ba,c[ia>>2]|0,$,c[ja>>2]|0,ka,la,ta,ua);Qha(f,qa|2,0,4,8,y,n,D,ra,sa|2,ba,c[ia>>2]|0,$,c[ja>>2]|0,ka,la,ta,ua);break}if((pa&32|0)==0){ua=pa&4096;ta=pa&16384;Qha(f,qa,1,4,0,y,n,D,ra,sa,ba,c[_>>2]|0,$,c[N>>2]|0,aa,W,ua,ta);va=ra|2;Qha(f,qa|1,1,4,0,y,n,D,va,sa,ba,c[_>>2]|0,$,c[N>>2]|0,aa,W,ua,ta);wa=sa|2;Qha(f,qa|2,1,4,0,y,n,D,ra,wa,ba,c[_>>2]|0,$,c[N>>2]|0,aa,W,ua,ta);Qha(f,qa|3,1,4,0,y,n,D,va,wa,ba,c[_>>2]|0,$,c[N>>2]|0,aa,W,ua,ta);break}else{ta=pa&4096;ua=pa&16384;Qha(f,qa,0,8,c[w>>2]<<2,y,n,D,ra,sa,ba,c[_>>2]|0,$,c[N>>2]|0,aa,W,ta,ua);Qha(f,qa|1,0,8,c[w>>2]<<2,y,n,D,ra|2,sa,ba,c[_>>2]|0,$,c[N>>2]|0,aa,W,ta,ua);break}}else{Qha(f,qa,1,8,0,y,n,D,ra,sa,ma,c[ia>>2]|0,na,c[ja>>2]|0,ka,la,pa&4096,pa&16384)}}while(0);oa=oa+1|0;}while((oa|0)<4)}else{Qha(f,0,1,16,0,y,n,D,0,0,U|0,c[I>>2]|0,X|0,c[Q>>2]|0,P,O,R&4096,R&16384)}}while(0);H=a[f+5684|0]|0;if(!(H<<24>>24>-1)){break}oa=H<<24>>24;H=c[k>>2]|0;la=(H<<4|8)+(b[f+5520>>1]>>2)|0;ka=(b[f+5522>>1]>>2)+(c[m>>2]<<4)|0;ja=(la<<1)+128+(ca(ka+(H<<2&12)|0,c[w>>2]|0)|0)|0;ef[c[E>>2]&4095]((c[f+306192+(oa*2224|0)>>2]|0)+ja|0,c[v>>2]|0,4);ja=(ca((c[k>>2]&7)+(ka>>1)|0,c[A>>2]|0)|0)+(la+128&-2)|0;la=c[f+306192+(oa*2224|0)+4>>2]|0;ef[c[E>>2]&4095](la+ja|0,(c[f+306192+(oa*2224|0)+8>>2]|0)-la|0,2);break}else{if(T){la=S<<24>>24;oa=c[k>>2]|0;ja=(oa<<4|8)+(b[f+5360>>1]>>2)|0;ka=(b[f+5362>>1]>>2)+(c[m>>2]<<4)|0;H=(ja<<1)+128+(ca(ka+(oa<<2&12)|0,p)|0)|0;ef[c[E>>2]&4095]((c[f+199440+(la*2224|0)>>2]|0)+H|0,p,4);H=(ca((c[k>>2]&7)+(ka>>1)|0,c[A>>2]|0)|0)+(ja+128&-2)|0;ja=c[f+199440+(la*2224|0)+4>>2]|0;ef[c[E>>2]&4095](ja+H|0,(c[f+199440+(la*2224|0)+8>>2]|0)-ja|0,2)}do{if((R&8|0)==0){if((R&16|0)!=0){ja=U+64|0;la=X+64|0;Pha(f,0,0,8,16,y,n,D,0,0,ja,c[I>>2]|0,la,c[Q>>2]|0,P,O,R&4096,R&16384);Pha(f,8,0,8,16,y,n,D,0,4,ja,c[I>>2]|0,la,c[Q>>2]|0,P,O,R&8192,R&32768);break}if((R&32|0)!=0){la=U+64|0;ja=f+152|0;H=X+64|0;ka=f+168|0;oa=f+16|0;na=f+32|0;Pha(f,0,0,16,c[w>>2]<<3,y,n,D,0,0,la,c[ja>>2]|0,H,c[ka>>2]|0,oa,na,R&4096,R&16384);Pha(f,4,0,16,c[w>>2]<<3,y,n,D,4,0,la,c[ja>>2]|0,H,c[ka>>2]|0,oa,na,R&8192,R&32768);break}na=U+128|0;oa=f+156|0;ka=X+128|0;H=f+172|0;ja=f+20|0;la=f+36|0;ia=f+152|0;ma=f+168|0;W=f+16|0;aa=f+32|0;N=U+64|0;$=X+64|0;_=0;do{ba=e[f+177112+(_<<1)>>1]|0;pa=_<<2;sa=pa&4;ra=_<<1&4;do{if((ba&8|0)==0){if((ba&16|0)!=0){qa=ba&4096;Z=ba&16384;Pha(f,pa,0,4,8,y,n,D,sa,ra,na,c[ia>>2]|0,ka,c[ma>>2]|0,W,aa,qa,Z);Pha(f,pa|2,0,4,8,y,n,D,sa,ra|2,na,c[ia>>2]|0,ka,c[ma>>2]|0,W,aa,qa,Z);break}if((ba&32|0)==0){Z=ba&4096;qa=ba&16384;Pha(f,pa,1,4,0,y,n,D,sa,ra,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,Z,qa);ua=sa|2;Pha(f,pa|1,1,4,0,y,n,D,ua,ra,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,Z,qa);ta=ra|2;Pha(f,pa|2,1,4,0,y,n,D,sa,ta,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,Z,qa);Pha(f,pa|3,1,4,0,y,n,D,ua,ta,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,Z,qa);break}else{qa=ba&4096;Z=ba&16384;Pha(f,pa,0,8,c[w>>2]<<2,y,n,D,sa,ra,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,qa,Z);Pha(f,pa|1,0,8,c[w>>2]<<2,y,n,D,sa|2,ra,na,c[oa>>2]|0,ka,c[H>>2]|0,ja,la,qa,Z);break}}else{Pha(f,pa,1,8,0,y,n,D,sa,ra,N,c[ia>>2]|0,$,c[ma>>2]|0,W,aa,ba&4096,ba&16384)}}while(0);_=_+1|0;}while((_|0)<4)}else{Pha(f,0,1,16,0,y,n,D,0,0,U|0,c[I>>2]|0,X|0,c[Q>>2]|0,P,O,R&4096,R&16384)}}while(0);R=a[f+5684|0]|0;if(!(R<<24>>24>-1)){break}O=R<<24>>24;R=c[k>>2]|0;P=(R<<4|8)+(b[f+5520>>1]>>2)|0;Q=(b[f+5522>>1]>>2)+(c[m>>2]<<4)|0;X=(P<<1)+128+(ca(Q+(R<<2&12)|0,c[w>>2]|0)|0)|0;ef[c[E>>2]&4095]((c[f+306192+(O*2224|0)>>2]|0)+X|0,c[v>>2]|0,4);X=(ca((c[k>>2]&7)+(Q>>1)|0,c[A>>2]|0)|0)+(P+128&-2)|0;P=c[f+306192+(O*2224|0)+4>>2]|0;ef[c[E>>2]&4095](P+X|0,(c[f+306192+(O*2224|0)+8>>2]|0)-P|0,2);break}}}while(0);do{if((r&1|0)==0){if((r&2|0)!=0){pe[c[f+124>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}if((c[f+426564>>2]&15|0)==0){break}if((r&16777216|0)==0){pe[c[f+112>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}else{pe[c[f+116>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}}}while(0);if((c[f+426564>>2]&48|0)==0){i=g;return}p=j|0;c[p>>2]=n;c[j+4>>2]=D;D=c[f+4756>>2]|0;if(t){xa=D+3|0;ya=(c[f+4760>>2]|0)+3|0}else{xa=D;ya=c[f+4760>>2]|0}if((a[f+5224|0]|0)!=0){re[c[f+132>>2]&1023](f+422224|0,c[(c[f+177020+((l?1:4)<<2)>>2]|0)+(xa<<6)>>2]|0)}if((a[f+5264|0]|0)!=0){re[c[f+132>>2]&1023](f+423248|0,c[(c[f+177020+((l?2:5)<<2)>>2]|0)+(ya<<6)>>2]|0)}pe[c[f+120>>2]&1023](p,s,f+421200|0,F,f+5184|0);i=g;return}function rha(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=f+427376|0;l=c[k>>2]|0;m=f+427380|0;n=c[m>>2]|0;o=f+427412|0;p=c[o>>2]|0;q=f+4064|0;r=c[(c[q>>2]|0)+(p<<2)>>2]|0;s=f+5716|0;t=(c[f+6136>>2]|0)==2;u=c[f+2528>>2]|0;v=f+4776|0;w=c[v>>2]|0;x=(ca(w,n)|0)+l<<4;y=u+x|0;z=c[f+2532>>2]|0;A=f+4780|0;B=(ca(ca(16>>>((c[f+4788>>2]|0)>>>0),n)|0,c[A>>2]|0)|0)+(l<<3)|0;n=z+B|0;C=c[f+2536>>2]|0;D=C+B|0;E=f+8|0;F=u+((ca(w,l<<2&12)|0)+64+x)|0;ef[c[E>>2]&4095](F,w,4);w=z+(B+64+(ca(c[k>>2]&7,c[A>>2]|0)|0))|0;ef[c[E>>2]&4095](w,D-n|0,2);a[(c[f+199432>>2]|0)+p|0]=c[f+199428>>2];p=c[v>>2]|0;w=f+6112|0;c[w>>2]=p;F=c[A>>2]|0;c[f+6116>>2]=F;l=(r&7|0)!=0;do{if(l){G=f+427420|0;H=c[G>>2]|0;if((H|0)==2){I=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);J=c[f+4864>>2]|0;K=c[k>>2]|0;L=5}else if((H|0)!=0){H=c[k>>2]|0;I=(H|0)>0;J=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;K=H;L=5}do{if((L|0)==5){H=K-1|0;M=f+5180|0;N=c[M>>2]|0;if((J|0)==0){break}if(I){O=N+(H*96|0)+8|0;P=c[O>>2]|0;Q=c[O+4>>2]|0;R=u+(x-8-p)|0;S=c[R+4>>2]|0;c[O>>2]=c[R>>2];c[O+4>>2]=S;c[R>>2]=P;c[R+4>>2]=Q}Q=N+(K*96|0)|0;R=c[Q>>2]|0;P=c[Q+4>>2]|0;S=u+(x-p)|0;O=c[S+4>>2]|0;c[Q>>2]=c[S>>2];c[Q+4>>2]=O;c[S>>2]=R;c[S+4>>2]=P;P=N+(K*96|0)+8|0;S=c[P>>2]|0;R=c[P+4>>2]|0;O=u+((x|8)-p)|0;Q=c[O+4>>2]|0;c[P>>2]=c[O>>2];c[P+4>>2]=Q;c[O>>2]=S;c[O+4>>2]=R;R=(c[k>>2]|0)+1|0;if((R|0)<(c[f+427400>>2]|0)){O=(c[M>>2]|0)+(R*96|0)|0;R=c[O>>2]|0;M=c[O+4>>2]|0;S=u+(x+16-p)|0;Q=c[S+4>>2]|0;c[O>>2]=c[S>>2];c[O+4>>2]=Q;c[S>>2]=R;c[S+4>>2]=M}if(I){M=N+(H*96|0)+16|0;S=c[M>>2]|0;R=c[M+4>>2]|0;Q=-8-F+B|0;O=z+Q|0;P=c[O+4>>2]|0;c[M>>2]=c[O>>2];c[M+4>>2]=P;c[O>>2]=S;c[O+4>>2]=R;R=N+(H*96|0)+24|0;H=c[R>>2]|0;O=c[R+4>>2]|0;S=C+Q|0;Q=c[S+4>>2]|0;c[R>>2]=c[S>>2];c[R+4>>2]=Q;c[S>>2]=H;c[S+4>>2]=O}O=N+(K*96|0)+16|0;S=c[O>>2]|0;H=c[O+4>>2]|0;Q=B-F|0;R=z+Q|0;P=c[R+4>>2]|0;c[O>>2]=c[R>>2];c[O+4>>2]=P;c[R>>2]=S;c[R+4>>2]=H;H=N+(K*96|0)+24|0;N=c[H>>2]|0;R=c[H+4>>2]|0;S=C+Q|0;Q=c[S+4>>2]|0;c[H>>2]=c[S>>2];c[H+4>>2]=Q;c[S>>2]=N;c[S+4>>2]=R}}while(0);R=f+4832|0;re[c[f+5040+(c[R>>2]<<2)>>2]&1023](n,F);re[c[f+5040+(c[R>>2]<<2)>>2]&1023](D,F);R=h;S=c[f+4792>>2]|0;a:do{if((r&1|0)==0){re[c[f+5084+(c[f+4836>>2]<<2)>>2]&1023](y,p);if((a[f+5184|0]|0)==0){break}ef[c[f+128>>2]&4095](f+421200|0,f+424272|0,c[(c[f+177020>>2]|0)+(S<<6)>>2]|0)}else{if((r&16777216|0)!=0){N=c[f+108>>2]|0;Q=c[f+100>>2]|0;H=f+5160|0;P=f+5168|0;O=0;while(1){M=u+((c[f+5716+(O<<2)>>2]|0)+x)|0;T=d[602328+O|0]|0;U=a[f+5184+T|0]|0;mf[c[f+4992+(a[f+4888+T|0]<<24>>24<<2)>>2]&2047](M,c[H>>2]<<O&32768,c[P>>2]<<O&16384,p);do{if((U<<24>>24|0)==1){T=O<<4;V=f+421200+(T<<1)|0;if((b[V>>1]|0)==0){W=T;L=20;break}ef[N&4095](M,V,p)}else if((U<<24>>24|0)!=0){W=O<<4;L=20}}while(0);if((L|0)==20){L=0;ef[Q&4095](M,f+421200+(W<<1)|0,p)}O=O+4|0;if((O|0)>=16){break a}}}O=c[f+104>>2]|0;Q=c[f+96>>2]|0;N=f+5168|0;P=(x|3)-p|0;H=(x|4)-p|0;U=0;do{V=c[f+5716+(U<<2)>>2]|0;T=u+(V+x)|0;X=d[602328+U|0]|0;Y=a[f+4888+X|0]|0;Z=Y<<24>>24;do{if((Y<<24>>24|0)==7|(Y<<24>>24|0)==3){if((c[N>>2]&32768>>>(U>>>0)|0)==0){c[h>>2]=ca(d[u+(P+V)|0]|0,16843009)|0;_=R;break}else{_=u+(H+V)|0;break}}else{_=0}}while(0);ef[c[f+4932+(Z<<2)>>2]&4095](T,_,p);V=a[f+5184+X|0]|0;b:do{if(!(V<<24>>24==0)){Y=f+421200+(U<<4<<1)|0;do{if(V<<24>>24==1){if((b[Y>>1]|0)==0){break}ef[O&4095](T,Y,p);break b}}while(0);ef[Q&4095](T,Y,p)}}while(0);U=U+1|0;}while((U|0)<16)}}while(0);R=c[G>>2]|0;if((R|0)==0){break}else if((R|0)==2){$=(e[(c[f+177072>>2]|0)+((c[o>>2]|0)-1-(c[f+427404>>2]|0)<<1)>>1]|0)==(c[f+177068>>2]|0);aa=c[f+4864>>2]|0;ba=c[k>>2]|0}else{R=c[k>>2]|0;$=(R|0)>0;aa=(c[m>>2]|0)>((c[f+177092>>2]|0)!=0|0)|0;ba=R}R=ba-1|0;S=f+5180|0;U=c[S>>2]|0;if((aa|0)==0){break}if($){Q=U+(R*96|0)+8|0;O=c[Q>>2]|0;H=c[Q+4>>2]|0;P=u+(x-8-p)|0;N=c[P+4>>2]|0;c[Q>>2]=c[P>>2];c[Q+4>>2]=N;c[P>>2]=O;c[P+4>>2]=H}H=U+(ba*96|0)|0;P=c[H+4>>2]|0;O=u+(x-p)|0;c[O>>2]=c[H>>2];c[O+4>>2]=P;P=U+(ba*96|0)+8|0;O=c[P>>2]|0;H=c[P+4>>2]|0;N=u+((x|8)-p)|0;Q=c[N+4>>2]|0;c[P>>2]=c[N>>2];c[P+4>>2]=Q;c[N>>2]=O;c[N+4>>2]=H;H=(c[k>>2]|0)+1|0;if((H|0)<(c[f+427400>>2]|0)){N=(c[S>>2]|0)+(H*96|0)|0;H=c[N>>2]|0;S=c[N+4>>2]|0;O=u+(x+16-p)|0;Q=c[O+4>>2]|0;c[N>>2]=c[O>>2];c[N+4>>2]=Q;c[O>>2]=H;c[O+4>>2]=S}if($){S=U+(R*96|0)+16|0;O=c[S>>2]|0;H=c[S+4>>2]|0;Q=-8-F+B|0;N=z+Q|0;P=c[N+4>>2]|0;c[S>>2]=c[N>>2];c[S+4>>2]=P;c[N>>2]=O;c[N+4>>2]=H;H=U+(R*96|0)+24|0;R=c[H>>2]|0;N=c[H+4>>2]|0;O=C+Q|0;Q=c[O+4>>2]|0;c[H>>2]=c[O>>2];c[H+4>>2]=Q;c[O>>2]=R;c[O+4>>2]=N}N=U+(ba*96|0)+16|0;O=c[N>>2]|0;R=c[N+4>>2]|0;Q=B-F|0;H=z+Q|0;P=c[H+4>>2]|0;c[N>>2]=c[H>>2];c[N+4>>2]=P;c[H>>2]=O;c[H+4>>2]=R;R=U+(ba*96|0)+24|0;U=c[R>>2]|0;H=c[R+4>>2]|0;O=C+Q|0;Q=c[O+4>>2]|0;c[R>>2]=c[O>>2];c[R+4>>2]=Q;c[O>>2]=U;c[O+4>>2]=H}else{H=c[f+1028>>2]|0;O=f+148|0;U=c[f+1032>>2]|0;Q=f+164|0;R=f+12|0;P=f+28|0;N=c[(c[q>>2]|0)+(c[o>>2]<<2)>>2]|0;S=a[f+5644|0]|0;T=S<<24>>24>-1;if(t){if(T){V=S<<24>>24;X=c[k>>2]|0;Z=(X<<4|8)+(b[f+5360>>1]>>2)|0;M=(b[f+5362>>1]>>2)+(c[m>>2]<<4)|0;da=Z+64+(ca(M+(X<<2&12)|0,p)|0)|0;ef[c[E>>2]&4095]((c[f+199440+(V*2224|0)>>2]|0)+da|0,p,4);da=(Z>>1)+64+(ca((c[k>>2]&7)+(M>>1)|0,c[A>>2]|0)|0)|0;M=c[f+199440+(V*2224|0)+4>>2]|0;ef[c[E>>2]&4095](M+da|0,(c[f+199440+(V*2224|0)+8>>2]|0)-M|0,2)}do{if((N&8|0)==0){if((N&16|0)!=0){M=H+64|0;V=U+64|0;Oha(f,0,0,8,8,y,n,D,0,0,M,c[O>>2]|0,V,c[Q>>2]|0,R,P,N&4096,N&16384);Oha(f,8,0,8,8,y,n,D,0,4,M,c[O>>2]|0,V,c[Q>>2]|0,R,P,N&8192,N&32768);break}if((N&32|0)!=0){V=H+64|0;M=f+152|0;da=U+64|0;Z=f+168|0;X=f+16|0;ea=f+32|0;Oha(f,0,0,16,c[w>>2]<<3,y,n,D,0,0,V,c[M>>2]|0,da,c[Z>>2]|0,X,ea,N&4096,N&16384);Oha(f,4,0,16,c[w>>2]<<3,y,n,D,4,0,V,c[M>>2]|0,da,c[Z>>2]|0,X,ea,N&8192,N&32768);break}ea=H+128|0;X=f+156|0;Z=U+128|0;da=f+172|0;M=f+20|0;V=f+36|0;fa=f+152|0;ga=f+168|0;ha=f+16|0;ia=f+32|0;ja=H+64|0;ka=U+64|0;la=0;do{ma=e[f+177112+(la<<1)>>1]|0;na=la<<2;oa=na&4;pa=la<<1&4;do{if((ma&8|0)==0){if((ma&16|0)!=0){qa=ma&4096;ra=ma&16384;Oha(f,na,0,4,4,y,n,D,oa,pa,ea,c[fa>>2]|0,Z,c[ga>>2]|0,ha,ia,qa,ra);Oha(f,na|2,0,4,4,y,n,D,oa,pa|2,ea,c[fa>>2]|0,Z,c[ga>>2]|0,ha,ia,qa,ra);break}if((ma&32|0)==0){ra=ma&4096;qa=ma&16384;Oha(f,na,1,4,0,y,n,D,oa,pa,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,ra,qa);sa=oa|2;Oha(f,na|1,1,4,0,y,n,D,sa,pa,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,ra,qa);ta=pa|2;Oha(f,na|2,1,4,0,y,n,D,oa,ta,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,ra,qa);Oha(f,na|3,1,4,0,y,n,D,sa,ta,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,ra,qa);break}else{qa=ma&4096;ra=ma&16384;Oha(f,na,0,8,c[w>>2]<<2,y,n,D,oa,pa,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,qa,ra);Oha(f,na|1,0,8,c[w>>2]<<2,y,n,D,oa|2,pa,ea,c[X>>2]|0,Z,c[da>>2]|0,M,V,qa,ra);break}}else{Oha(f,na,1,8,0,y,n,D,oa,pa,ja,c[fa>>2]|0,ka,c[ga>>2]|0,ha,ia,ma&4096,ma&16384)}}while(0);la=la+1|0;}while((la|0)<4)}else{Oha(f,0,1,16,0,y,n,D,0,0,H|0,c[O>>2]|0,U|0,c[Q>>2]|0,R,P,N&4096,N&16384)}}while(0);G=a[f+5684|0]|0;if(!(G<<24>>24>-1)){break}la=G<<24>>24;G=c[k>>2]|0;ia=(G<<4|8)+(b[f+5520>>1]>>2)|0;ha=(b[f+5522>>1]>>2)+(c[m>>2]<<4)|0;ga=ia+64+(ca(ha+(G<<2&12)|0,c[w>>2]|0)|0)|0;ef[c[E>>2]&4095]((c[f+306192+(la*2224|0)>>2]|0)+ga|0,c[v>>2]|0,4);ga=(ia>>1)+64+(ca((c[k>>2]&7)+(ha>>1)|0,c[A>>2]|0)|0)|0;ha=c[f+306192+(la*2224|0)+4>>2]|0;ef[c[E>>2]&4095](ha+ga|0,(c[f+306192+(la*2224|0)+8>>2]|0)-ha|0,2);break}else{if(T){ha=S<<24>>24;la=c[k>>2]|0;ga=(la<<4|8)+(b[f+5360>>1]>>2)|0;ia=(b[f+5362>>1]>>2)+(c[m>>2]<<4)|0;G=ga+64+(ca(ia+(la<<2&12)|0,p)|0)|0;ef[c[E>>2]&4095]((c[f+199440+(ha*2224|0)>>2]|0)+G|0,p,4);G=(ga>>1)+64+(ca((c[k>>2]&7)+(ia>>1)|0,c[A>>2]|0)|0)|0;ia=c[f+199440+(ha*2224|0)+4>>2]|0;ef[c[E>>2]&4095](ia+G|0,(c[f+199440+(ha*2224|0)+8>>2]|0)-ia|0,2)}do{if((N&8|0)==0){if((N&16|0)!=0){ia=H+64|0;ha=U+64|0;Nha(f,0,0,8,8,y,n,D,0,0,ia,c[O>>2]|0,ha,c[Q>>2]|0,R,P,N&4096,N&16384);Nha(f,8,0,8,8,y,n,D,0,4,ia,c[O>>2]|0,ha,c[Q>>2]|0,R,P,N&8192,N&32768);break}if((N&32|0)!=0){ha=H+64|0;ia=f+152|0;G=U+64|0;ga=f+168|0;la=f+16|0;ka=f+32|0;Nha(f,0,0,16,c[w>>2]<<3,y,n,D,0,0,ha,c[ia>>2]|0,G,c[ga>>2]|0,la,ka,N&4096,N&16384);Nha(f,4,0,16,c[w>>2]<<3,y,n,D,4,0,ha,c[ia>>2]|0,G,c[ga>>2]|0,la,ka,N&8192,N&32768);break}ka=H+128|0;la=f+156|0;ga=U+128|0;G=f+172|0;ia=f+20|0;ha=f+36|0;fa=f+152|0;ja=f+168|0;V=f+16|0;M=f+32|0;da=H+64|0;Z=U+64|0;X=0;do{ea=e[f+177112+(X<<1)>>1]|0;ma=X<<2;pa=ma&4;oa=X<<1&4;do{if((ea&8|0)==0){if((ea&16|0)!=0){na=ea&4096;ra=ea&16384;Nha(f,ma,0,4,4,y,n,D,pa,oa,ka,c[fa>>2]|0,ga,c[ja>>2]|0,V,M,na,ra);Nha(f,ma|2,0,4,4,y,n,D,pa,oa|2,ka,c[fa>>2]|0,ga,c[ja>>2]|0,V,M,na,ra);break}if((ea&32|0)==0){ra=ea&4096;na=ea&16384;Nha(f,ma,1,4,0,y,n,D,pa,oa,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,ra,na);qa=pa|2;Nha(f,ma|1,1,4,0,y,n,D,qa,oa,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,ra,na);ta=oa|2;Nha(f,ma|2,1,4,0,y,n,D,pa,ta,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,ra,na);Nha(f,ma|3,1,4,0,y,n,D,qa,ta,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,ra,na);break}else{na=ea&4096;ra=ea&16384;Nha(f,ma,0,8,c[w>>2]<<2,y,n,D,pa,oa,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,na,ra);Nha(f,ma|1,0,8,c[w>>2]<<2,y,n,D,pa|2,oa,ka,c[la>>2]|0,ga,c[G>>2]|0,ia,ha,na,ra);break}}else{Nha(f,ma,1,8,0,y,n,D,pa,oa,da,c[fa>>2]|0,Z,c[ja>>2]|0,V,M,ea&4096,ea&16384)}}while(0);X=X+1|0;}while((X|0)<4)}else{Nha(f,0,1,16,0,y,n,D,0,0,H|0,c[O>>2]|0,U|0,c[Q>>2]|0,R,P,N&4096,N&16384)}}while(0);N=a[f+5684|0]|0;if(!(N<<24>>24>-1)){break}P=N<<24>>24;N=c[k>>2]|0;R=(N<<4|8)+(b[f+5520>>1]>>2)|0;Q=(b[f+5522>>1]>>2)+(c[m>>2]<<4)|0;U=R+64+(ca(Q+(N<<2&12)|0,c[w>>2]|0)|0)|0;ef[c[E>>2]&4095]((c[f+306192+(P*2224|0)>>2]|0)+U|0,c[v>>2]|0,4);U=(R>>1)+64+(ca((c[k>>2]&7)+(Q>>1)|0,c[A>>2]|0)|0)|0;Q=c[f+306192+(P*2224|0)+4>>2]|0;ef[c[E>>2]&4095](Q+U|0,(c[f+306192+(P*2224|0)+8>>2]|0)-Q|0,2);break}}}while(0);do{if((r&1|0)==0){if((r&2|0)!=0){pe[c[f+124>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}if((c[f+426564>>2]&15|0)==0){break}if((r&16777216|0)==0){pe[c[f+112>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}else{pe[c[f+116>>2]&1023](y,s,f+421200|0,p,f+5184|0);break}}}while(0);if((c[f+426564>>2]&48|0)==0){i=g;return}p=j|0;c[p>>2]=n;c[j+4>>2]=D;D=c[f+4756>>2]|0;if(t){ua=D+3|0;va=(c[f+4760>>2]|0)+3|0}else{ua=D;va=c[f+4760>>2]|0}if((a[f+5224|0]|0)!=0){re[c[f+132>>2]&1023](f+421712|0,c[(c[f+177020+((l?1:4)<<2)>>2]|0)+(ua<<6)>>2]|0)}if((a[f+5264|0]|0)!=0){re[c[f+132>>2]&1023](f+422224|0,c[(c[f+177020+((l?2:5)<<2)>>2]|0)+(va<<6)>>2]|0)}pe[c[f+120>>2]&1023](p,s,f+421200|0,F,f+5184|0);i=g;return}function sha(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=b+177120|0;c[e>>2]=0;f=b+177124|0;c[f>>2]=0;g=b+1096|0;h=c[g>>2]|0;i=b+1088|0;j=c[i>>2]|0;k=j+(h>>>3)|0;l=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(h&7);if(l>>>0>134217727>>>0){k=l>>>23;m=(d[1382088+k|0]|0)+h|0;c[g>>2]=m;n=d[1276064+k|0]|0;o=m}else{m=l>>>0>65535>>>0;k=m?l>>>16:l;p=m?16:0;if((k&65280|0)==0){q=p;r=k}else{q=p|8;r=k>>>8}k=(d[1359664+r|0]|0)+q<<1;q=h+63-k|0;c[g>>2]=q;n=(l>>>((k-31|0)>>>0))-1|0;o=q}c[b+177128>>2]=n;q=b+6136|0;if((c[q>>2]|0)==0){s=c[b+177132>>2]|0}else{k=j+(o>>>3)|0;j=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(o&7);if(j>>>0>134217727>>>0){k=j>>>23;c[g>>2]=(d[1382088+k|0]|0)+o;t=d[1276064+k|0]|0}else{k=j>>>0>65535>>>0;l=k?j>>>16:j;h=k?16:0;if((l&65280|0)==0){u=h;v=l}else{u=h|8;v=l>>>8}l=(d[1359664+v|0]|0)+u<<1;c[g>>2]=o+63-l;t=(j>>>((l-31|0)>>>0))-1|0}c[b+177132>>2]=t;s=t}t=1<<n;n=1<<s;s=b+177080|0;l=0;while(1){if((l|0)>=2){break}j=b+572484+(l<<2)|0;c[j>>2]=0;o=b+572492+(l<<2)|0;c[o>>2]=0;u=b+199420+(l<<2)|0;if((c[u>>2]|0)!=0){v=0;do{h=c[g>>2]|0;k=c[i>>2]|0;r=d[k+(h>>>3)|0]|0;p=h+1|0;c[g>>2]=p;do{if((r&128>>>((h&7)>>>0)|0)==0){c[b+177136+(v<<4)+(l<<3)>>2]=t;c[b+177136+(v<<4)+(l<<3)+4>>2]=0}else{m=k+(p>>>3)|0;w=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7);if(w>>>0>134217727>>>0){m=w>>>23;c[g>>2]=(d[1382088+m|0]|0)+p;x=a[1306768+m|0]|0}else{m=w>>>0>65535>>>0;y=m?w>>>16:w;w=m?16:0;if((y&65280|0)==0){z=w;A=y}else{z=w|8;A=y>>>8}y=(d[1359664+A|0]|0)+z|0;w=31-y+p|0;m=k+(w>>>3)|0;B=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(w&7)>>>(y>>>0);c[g>>2]=32-y+w;w=B>>>1;x=(B&1|0)==0?w:-w|0}w=b+177136+(v<<4)+(l<<3)|0;c[w>>2]=x;B=c[g>>2]|0;y=c[i>>2]|0;m=y+(B>>>3)|0;C=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(B&7);if(C>>>0>134217727>>>0){m=C>>>23;c[g>>2]=(d[1382088+m|0]|0)+B;D=a[1306768+m|0]|0}else{m=C>>>0>65535>>>0;E=m?C>>>16:C;C=m?16:0;if((E&65280|0)==0){F=C;G=E}else{F=C|8;G=E>>>8}E=(d[1359664+G|0]|0)+F|0;C=31-E+B|0;B=y+(C>>>3)|0;y=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>(E>>>0);c[g>>2]=32-E+C;C=y>>>1;D=(y&1|0)==0?C:-C|0}c[b+177136+(v<<4)+(l<<3)+4>>2]=D;if((c[w>>2]|0)==(t|0)&(D|0)==0){break}c[e>>2]=1;c[j>>2]=1}}while(0);a:do{if((c[q>>2]|0)!=0){k=c[g>>2]|0;p=c[i>>2]|0;h=d[p+(k>>>3)|0]|0;r=k+1|0;c[g>>2]=r;if((h&128>>>((k&7)>>>0)|0)==0){c[b+177904+(v<<5)+(l<<4)>>2]=n;c[b+177904+(v<<5)+(l<<4)+4>>2]=0;c[b+177904+(v<<5)+(l<<4)+8>>2]=n;c[b+177904+(v<<5)+(l<<4)+12>>2]=0;break}else{H=0;I=r;J=p}while(1){p=J+(I>>>3)|0;r=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(I&7);if(r>>>0>134217727>>>0){p=r>>>23;c[g>>2]=(d[1382088+p|0]|0)+I;K=a[1306768+p|0]|0}else{p=r>>>0>65535>>>0;k=p?r>>>16:r;r=p?16:0;if((k&65280|0)==0){L=r;M=k}else{L=r|8;M=k>>>8}k=(d[1359664+M|0]|0)+L|0;r=31-k+I|0;p=J+(r>>>3)|0;h=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>(k>>>0);c[g>>2]=32-k+r;r=h>>>1;K=(h&1|0)==0?r:-r|0}r=b+177904+(v<<5)+(l<<4)+(H<<3)|0;c[r>>2]=K;h=c[g>>2]|0;k=c[i>>2]|0;p=k+(h>>>3)|0;w=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(h&7);if(w>>>0>134217727>>>0){p=w>>>23;c[g>>2]=(d[1382088+p|0]|0)+h;N=a[1306768+p|0]|0}else{p=w>>>0>65535>>>0;C=p?w>>>16:w;w=p?16:0;if((C&65280|0)==0){O=w;P=C}else{O=w|8;P=C>>>8}C=(d[1359664+P|0]|0)+O|0;w=31-C+h|0;h=k+(w>>>3)|0;k=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(w&7)>>>(C>>>0);c[g>>2]=32-C+w;w=k>>>1;N=(k&1|0)==0?w:-w|0}c[b+177904+(v<<5)+(l<<4)+(H<<3)+4>>2]=N;if(!((c[r>>2]|0)==(n|0)&(N|0)==0)){c[f>>2]=1;c[o>>2]=1}r=H+1|0;if((r|0)>=2){break a}H=r;I=c[g>>2]|0;J=c[i>>2]|0}}}while(0);v=v+1|0;}while(v>>>0<(c[u>>2]|0)>>>0)}if((c[s>>2]|0)==3){l=l+1|0}else{break}}if((c[e>>2]|0)!=0){Q=1;c[e>>2]=Q;return 0}Q=(c[f>>2]|0)!=0|0;c[e>>2]=Q;return 0}function tha(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=c[a+6144>>2]|0;g=c[a+428672>>2]|0;h=a+428668|0;c[h>>2]=g;i=c[a+428656>>2]|0;if((i|0)<(c[a+428676>>2]|0)){j=g+(1<<f)|0;c[h>>2]=j;k=j}else{k=g}g=c[a+6148>>2]|0;do{if((g|0)==0){j=1<<c[a+6152>>2];h=c[a+428636>>2]|0;f=c[a+428664>>2]|0;do{if((h|0)<(f|0)){if((f-h|0)<((j|0)/2|0|0)){l=7;break}m=(c[a+428660>>2]|0)+j|0;c[a+428640>>2]=m;n=m}else{l=7}}while(0);a:do{if((l|0)==7){do{if((h|0)>(f|0)){if((f-h|0)>=((j|0)/-2|0|0)){break}m=(c[a+428660>>2]|0)-j|0;c[a+428640>>2]=m;n=m;break a}}while(0);m=c[a+428660>>2]|0;c[a+428640>>2]=m;n=m}}while(0);j=h+n|0;f=c[a+177100>>2]|0;if((f|0)!=3){o=j;p=j;q=f;l=23;break}r=j;s=(c[a+428644>>2]|0)+j|0;l=25}else if((g|0)==1){j=c[a+6168>>2]|0;f=(j|0)==0?0:i+k|0;m=(c[a+427432>>2]|0)==0;t=((m&(f|0)>0)<<31>>31)+f|0;if((j|0)>0){f=0;u=0;while(1){v=(b[a+6272+(u<<1)>>1]|0)+f|0;w=u+1|0;if((w|0)<(j|0)){f=v;u=w}else{x=v;break}}}else{x=0}do{if((t|0)>0){u=t-1|0;f=(u|0)%(j|0)|0;h=ca((u|0)/(j|0)|0,x)|0;if((f|0)<0){y=h;break}else{z=h;A=0}while(1){h=(b[a+6272+(A<<1)>>1]|0)+z|0;u=A+1|0;if((u|0)>(f|0)){y=h;break}else{z=h;A=u}}}else{y=0}}while(0);if(m){B=(c[a+6160>>2]|0)+y|0}else{B=y}j=(c[a+428648>>2]|0)+B|0;t=j+(c[a+6164>>2]|0)|0;f=c[a+177100>>2]|0;if((f|0)!=3){o=t;p=j;q=f;l=23;break}r=j;s=(c[a+428652>>2]|0)+t|0;l=25}else{t=(((c[a+427432>>2]|0)==0)<<31>>31)+(i+k<<1)|0;o=t;p=t;q=c[a+177100>>2]|0;l=23}}while(0);do{if((l|0)==23){if((q|0)!=2){r=p;s=o;l=25;break}C=c[d>>2]|0;D=o}}while(0);do{if((l|0)==25){c[d>>2]=r;if((c[a+177100>>2]|0)!=1){C=r;D=s;break}E=r;F=c[d+4>>2]|0;G=(E|0)>(F|0);H=G?F:E;c[e>>2]=H;return 0}}while(0);c[d+4>>2]=D;E=C;F=D;G=(E|0)>(F|0);H=G?F:E;c[e>>2]=H;return 0}function uha(a){a=a|0;var b=0,d=0;b=c[a+4>>2]|0;if((b|0)==110|(b|0)==122|(b|0)==244){d=c[a+1196>>2]<<8&2048|b}else if((b|0)==66){d=c[a+1196>>2]<<8&512|66}else{d=b}return d|0}function vha(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;e=c[a+7348>>2]|0;f=c[a+7352>>2]|0;g=c[a+177080>>2]|0;do{if((g|0)==1){h=0;j=0;k=0}else{l=(c[a+177100>>2]|0)==3?15:31;m=(g|0)==3;n=a+1096|0;o=c[n>>2]|0;if(m){p=c[a+1088>>2]|0;q=(d[p+(o>>>3)|0]|0)<<(o&7)>>>7;r=o+1|0;c[n>>2]=r;c[a+197872>>2]=q&1;s=r;t=p}else{s=o;t=c[a+1088>>2]|0}o=a+1096|0;p=d[t+(s>>>3)|0]|0;r=s+1|0;c[o>>2]=r;do{if((p&128>>>((s&7)>>>0)|0)==0){u=f;v=e;w=g}else{q=t+(r>>>3)|0;n=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7);if(n>>>0>134217727>>>0){q=n>>>23;x=(d[1382088+q|0]|0)+r|0;c[o>>2]=x;y=d[1276064+q|0]|0;z=x}else{x=n>>>0>65535>>>0;q=x?n>>>16:n;A=x?16:0;if((q&65280|0)==0){B=A;C=q}else{B=A|8;C=q>>>8}q=(d[1359664+C|0]|0)+B<<1;A=s+64-q|0;c[o>>2]=A;y=(n>>>((q-31|0)>>>0))-1|0;z=A}A=y+1|0;if(!m){u=1;v=A;w=g;break}q=t+(z>>>3)|0;n=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(z&7);if(n>>>0>134217727>>>0){q=n>>>23;c[o>>2]=(d[1382088+q|0]|0)+z;D=d[1276064+q|0]|0}else{q=n>>>0>65535>>>0;x=q?n>>>16:n;E=q?16:0;if((x&65280|0)==0){F=E;G=x}else{F=E|8;G=x>>>8}x=(d[1359664+G|0]|0)+F<<1;c[o>>2]=z+63-x;D=(n>>>((x-31|0)>>>0))-1|0}u=D+1|0;v=A;w=3}}while(0);o=v-1|0;m=u-1|0;if(!(o>>>0>l>>>0|m>>>0>l>>>0)){h=u;j=v;k=(w|0)==3?2:1;break}KIb(c[a>>2]|0,16,2589984,(r=i,i=i+32|0,c[r>>2]=o,c[r+8>>2]=l,c[r+16>>2]=m,c[r+24>>2]=l,r)|0);i=r;c[a+199424>>2]=0;c[a+199420>>2]=0;c[a+199428>>2]=0;H=-1094995529;i=b;return H|0}}while(0);w=a+199428|0;v=a+199420|0;do{if((k|0)==(c[w>>2]|0)){if((j|0)!=(c[v>>2]|0)){break}if((h|0)==(c[a+199424>>2]|0)){H=0}else{break}i=b;return H|0}}while(0);c[v>>2]=j;c[a+199424>>2]=h;c[w>>2]=k;H=1;i=b;return H|0}function wha(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=c[b+60>>2]|0;l=g;m=e;c[g+4816>>2]=c[b+88>>2];c[g+4800>>2]=0;a:do{if((k|0)==0){n=0;o=g+2524|0}else{b:do{if((c[g+427456>>2]|0)!=0&(k|0)>8){if((a[j]|0)!=1){break}if((a[j+2|0]|0)!=0){break}if(!((a[j+4|0]&-4)<<24>>24==-4)){break}e=a[j+5|0]&31;if((e|0)==0){break}if((a[j+8|0]|0)!=103){break}p=k+j|0;q=j+6|0;r=e;while(1){e=r-1|0;s=q;t=(he((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535;s=t+2|0;if((s|0)>(p-q|0)){break b}if((a[q+2|0]|0)!=103){break b}u=q+s|0;if((e|0)==0){break}else{q=u;r=e}}r=a[u]|0;if(r<<24>>24==0){break}p=k+j|0;e=q+(t+3)|0;s=r&255;while(1){r=s-1|0;v=e;w=((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)+2|0;if((w|0)>(p-e|0)){break b}if((a[e+2|0]|0)!=104){break b}if((r|0)==0){break}else{e=e+w|0;s=r}}x=iha(l,j,k)|0;i=h;return x|0}}while(0);s=jha(l,j,k,0)|0;if((s|0)<0){x=-1094995529;i=h;return x|0}e=g+2524|0;p=(c[e>>2]|0)==0;do{if(p){if((c[g+427436>>2]|0)!=10){break}if((s|0)<=(k|0)){n=s;o=e;break a}KIb(0,0,2122224,(y=i,i=i+24|0,c[y>>2]=2532064,c[y+8>>2]=2617208,c[y+16>>2]=5264,y)|0);i=y;Hd();return 0}}while(0);do{if((c[b+92>>2]&32768|0)==0){if(!p){z=41;break}if((c[b+856>>2]|0)>7){x=k;i=h;return x|0}do{if((k|0)>3){if((grc(2516896,j,4)|0)==0){x=k}else{break}i=h;return x|0}}while(0);KIb(b,16,2502888,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;x=-1094995529;i=h;return x|0}else{e=c[g+427396>>2]|0;if((c[g+427380>>2]|0)<(e|0)|(e|0)==0){break}Bha(l,1);z=41}}while(0);do{if((z|0)==41){Cha(l,0);c[f>>2]=0;p=g+571424|0;e=c[p>>2]|0;if((e|0)==0){break}if((c[e+2200>>2]|0)==0){break}q=Aha(l,m,e)|0;if((q|0)<0){x=q;i=h;return x|0}else{c[f>>2]=1;FTa(c[g>>2]|0,c[p>>2]|0,m,c[g+2412>>2]|0,g+4808|0,c[g+427400>>2]|0,c[g+427396>>2]|0,c[g+427404>>2]|0,1);break}}}while(0);p=(s|0)==0?1:s;x=(p+10|0)>(k|0)?k:p;i=h;return x|0}}while(0);c[o>>2]=0;c[g+177104>>2]=0;o=g+571288|0;k=o;z=c[o>>2]|0;o=c[g+571292>>2]|0;c:do{if((o|0)==0){A=z;B=0}else{g=z;y=1;b=0;j=o;while(1){if((c[j+84>>2]|0)!=0){A=g;B=b;break c}if((c[j+1620>>2]|0)!=0){A=g;B=b;break c}t=(c[j+1612>>2]|0)<(c[g+1612>>2]|0);u=t?j:g;p=t?y:b;t=y+1|0;q=c[k+(t<<2)>>2]|0;if((q|0)==0){A=u;B=p;break}else{g=u;y=t;b=p;j=q}}}}while(0);o=k+(B<<2)|0;if((c[o>>2]|0)!=0){z=B;B=o;while(1){o=z+1|0;j=k+(o<<2)|0;c[B>>2]=c[j>>2];if((c[j>>2]|0)==0){break}else{z=o;B=j}}}if((A|0)==0){x=n;i=h;return x|0}B=A+2192|0;c[B>>2]=c[B>>2]&-5;B=Aha(l,m,A)|0;if((B|0)<0){x=B;i=h;return x|0}c[f>>2]=1;x=n;i=h;return x|0}function xha(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;a=b;Fia(a);hha(a,1);d=0;while(1){mJb(a+427476+(d<<2)|0);e=d+1|0;if((e|0)<32){d=e}else{f=0;break}}do{mJb(a+427604+(f<<2)|0);f=f+1|0;}while((f|0)<256);zha(a,b+2528|0);return 0}function yha(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=c[a+60>>2]|0;a=b+571288|0;d=a;e=0;do{f=d+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){c[g+2192>>2]=0}c[f>>2]=0;e=e+1|0;}while((e|0)<17);e=b;c[b+571432>>2]=-2147483648;c[b+571428>>2]=-2147483648;c[b+572412>>2]=1;Fia(e);c[b+428672>>2]=0;c[b+428660>>2]=65536;c[b+428664>>2]=0;c[b+571360>>2]=-2147483648;c[b+571364>>2]=-2147483648;c[b+571368>>2]=-2147483648;c[b+571372>>2]=-2147483648;c[b+571376>>2]=-2147483648;c[b+571380>>2]=-2147483648;c[b+571384>>2]=-2147483648;c[b+571388>>2]=-2147483648;c[b+571392>>2]=-2147483648;c[b+571396>>2]=-2147483648;c[b+571400>>2]=-2147483648;c[b+571404>>2]=-2147483648;c[b+571408>>2]=-2147483648;c[b+571412>>2]=-2147483648;c[b+571416>>2]=-2147483648;c[b+571420>>2]=-2147483648;c[b+428676>>2]=-1;d=b+2524|0;f=c[d>>2]|0;if((f|0)!=0){c[f+2192>>2]=0;g=c[a>>2]|0;a:do{if((g|0)==0){h=0}else{a=1;i=0;j=g;k=f;while(1){if((j|0)==(k|0)){l=i}else{c[e+571288+(i<<2)>>2]=j;l=i+1|0}m=c[e+571288+(a<<2)>>2]|0;if((m|0)==0){h=l;break a}a=a+1|0;i=l;j=m;k=c[d>>2]|0}}}while(0);c[e+571288+(h<<2)>>2]=0}c[b+177104>>2]=0;mrc(b+199440|0,0,213504)|0;mrc(b+428696|0,0,142336)|0;Jia(e);c[b+572476>>2]=-1;c[b+572480>>2]=0;c[b+199428>>2]=0;c[b+572376>>2]=0;c[b+572232>>2]=1;h=b+2520|0;l=c[h>>2]|0;if((l|0)==0){c[d>>2]=0;n=b+2528|0;o=n;zha(e,o);p=b+427380|0;q=p;c[q>>2]=0;r=b+427376|0;s=r;c[s>>2]=0;t=b+1064|0;u=t;c[u>>2]=-1;v=b+1068|0;w=v;c[w>>2]=0;x=b+1072|0;y=x;c[y>>2]=0;z=b+1076|0;A=z;c[A>>2]=0;B=b+1052|0;C=B;c[C>>2]=0;D=b+1056|0;E=D;c[E>>2]=0;hha(e,1);F=b+4812|0;G=F;c[G>>2]=0;return}else{H=0;I=l}while(1){zha(e,I+(H*2224|0)|0);l=H+1|0;if((l|0)>=36){break}H=l;I=c[h>>2]|0}c[d>>2]=0;n=b+2528|0;o=n;zha(e,o);p=b+427380|0;q=p;c[q>>2]=0;r=b+427376|0;s=r;c[s>>2]=0;t=b+1064|0;u=t;c[u>>2]=-1;v=b+1068|0;w=v;c[w>>2]=0;x=b+1072|0;y=x;c[y>>2]=0;z=b+1076|0;A=z;c[A>>2]=0;B=b+1052|0;C=B;c[C>>2]=0;D=b+1056|0;E=D;c[E>>2]=0;hha(e,1);F=b+4812|0;G=F;c[G>>2]=0;return}function zha(a,b){a=a|0;b=b|0;if((c[b+360>>2]|0)==0){return}H5a(c[a>>2]|0,b+1496|0);fGb(b+1596|0);a=b+1508|0;fGb(a);fGb(b+1532|0);fGb(b+1516|0);fGb(b+1548|0);fGb(b+1520|0);fGb(b+1552|0);mrc(a|0,0,716)|0;return}function Aha(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=qKb(c[f+80>>2]|0)|0;h=YHb(e,f|0)|0;if((h|0)<0){i=h;return i|0}MGb(e+440|0,2411312,Lia(b)|0,0)|0;if((c[f+2208>>2]|0)==0){i=0;return i|0}h=g+4|0;if((a[h]|0)==0){i=0;return i|0}j=g+5|0;k=g+6|0;g=f+2212|0;l=b+4752|0;b=f+2216|0;f=0;while(1){if((f|0)>0){m=d[k]|0;n=d[j]|0}else{m=0;n=0}o=(ca(c[b>>2]>>m,c[e+32+(f<<2)>>2]|0)|0)+(c[g>>2]>>n<<c[l>>2])|0;p=e+(f<<2)|0;c[p>>2]=(c[p>>2]|0)+o;o=f+1|0;if((o|0)<(d[h]|0)){f=o}else{i=0;break}}return i|0}function Bha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;e=c[a+2524>>2]|0;f=e|0;g=e+88|0;c[g>>2]=c[a+572392>>2];h=a+571424|0;if((c[h>>2]|0)!=0){i=d;return}j=e+1604|0;if((c[j>>2]|0)==2147483647){i=d;return}k=e+1608|0;if((c[k>>2]|0)==2147483647){i=d;return}l=e+296|0;c[l>>2]=0;m=e+292|0;c[m>>2]=0;n=a+7284|0;do{if((c[n>>2]|0)==0){if((c[a+177088>>2]|0)==0){o=(c[a+177100>>2]|0)!=3|0}else{o=1}c[l>>2]=o;p=o}else{q=a+572408|0;a:do{switch(c[q>>2]|0){case 8:{c[m>>2]=4;r=0;break};case 5:case 6:{c[m>>2]=1;r=0;break};case 7:{c[m>>2]=2;r=0;break};case 3:case 4:{do{if((c[a+177088>>2]|0)==0){if((c[a+177100>>2]|0)!=3){break}s=c[a+572412>>2]|0;c[l>>2]=s;r=s;break a}}while(0);c[l>>2]=1;r=1;break};case 1:case 2:{c[l>>2]=1;r=1;break};default:{r=0}}}while(0);s=c[a+572432>>2]|0;if((s&3|0)==0){p=r;break}if(!((c[q>>2]|0)>>>0<5>>>0)){p=r;break}t=s>>>1&1;c[l>>2]=t;p=t}}while(0);c[a+572412>>2]=p;p=c[j>>2]|0;j=c[k>>2]|0;b:do{if((p|0)==(j|0)){do{if((c[l>>2]|0)==0){if((c[n>>2]|0)!=0){break}c[e+300>>2]=0;break b}}while(0);q=c[a+572408>>2]|0;if((q|0)==3|(q|0)==5){c[e+300>>2]=1;break}else{c[e+300>>2]=0;break}}else{c[e+300>>2]=(p|0)<(j|0)}}while(0);do{if((c[a+572416>>2]|0)!=0){j=a+572420|0;if(!((c[j>>2]|0)>>>0<7>>>0)){break}p=a+572424|0;if(!(((c[p>>2]|0)-1|0)>>>0<2>>>0)){break}n=iLb(f)|0;if((n|0)==0){i=d;return}c:do{switch(c[j>>2]|0){case 2:{c[n>>2]=7;break};case 5:{c[n>>2]=3;break};case 0:{c[n>>2]=4;break};case 3:{l=n|0;if((c[a+572428>>2]|0)==0){c[l>>2]=1;break c}else{c[l>>2]=5;break c}break};case 4:{c[n>>2]=2;break};case 1:{c[n>>2]=6;break};case 6:{c[n>>2]=0;break};default:{}}}while(0);if((c[p>>2]|0)!=2){break}c[n+4>>2]=1}}while(0);f=a+572232|0;j=e+1620|0;c[j>>2]=c[f>>2];c[f>>2]=0;f=a+6784|0;l=c[a>>2]|0;do{if((c[f>>2]|0)!=0){q=l+176|0;k=c[a+6788>>2]|0;if((c[q>>2]|0)>=(k|0)){break}c[q>>2]=k;c[a+4808>>2]=0}}while(0);k=a|0;do{if((c[l+680>>2]|0)>0){if((c[f>>2]|0)!=0){break}c[l+176>>2]=15;c[a+4808>>2]=0}}while(0);l=e+1612|0;q=0;while(1){u=c[l>>2]|0;r=c[a+571360+(q<<2)>>2]|0;v=(q|0)==0;if((u|0)<(r|0)){w=52;break}if(v){q=q+1|0;continue}else{c[a+571360+(q-1<<2)>>2]=r;r=q+1|0;if((r|0)==16){w=53;break}else{q=r;continue}}}if((w|0)==52){if(v){x=0}else{y=q;z=u;w=54}}else if((w|0)==53){y=16;z=c[l>>2]|0;w=54}if((w|0)==54){c[a+571360+(y-1<<2)>>2]=z;x=y}y=16-x|0;do{if((c[g>>2]|0)==3){w=61}else{x=c[a+571416>>2]|0;if((x|0)==-2147483648){A=y;break}if(((c[a+571420>>2]|0)-x|0)>2){w=61}else{A=y}}}while(0);if((w|0)==61){A=(y|0)>1?y:1}y=c[k>>2]|0;do{if((A|0)==16){g=a+571360|0;x=c[g>>2]|0;KIb(y,40,2478920,(B=i,i=i+16|0,c[B>>2]=c[l>>2],c[B+8>>2]=x,B)|0);i=B;c[a+571364>>2]=-2147483648;c[a+571368>>2]=-2147483648;c[a+571372>>2]=-2147483648;c[a+571376>>2]=-2147483648;c[a+571380>>2]=-2147483648;c[a+571384>>2]=-2147483648;c[a+571388>>2]=-2147483648;c[a+571392>>2]=-2147483648;c[a+571396>>2]=-2147483648;c[a+571400>>2]=-2147483648;c[a+571404>>2]=-2147483648;c[a+571408>>2]=-2147483648;c[a+571412>>2]=-2147483648;c[a+571416>>2]=-2147483648;c[a+571420>>2]=-2147483648;c[g>>2]=c[l>>2];c[j>>2]=1;C=0}else{if((c[y+176>>2]|0)>=(A|0)){C=0;break}if((c[f>>2]|0)!=0){C=0;break}KIb(y,40,2469144,(B=i,i=i+8|0,c[B>>2]=A,B)|0);i=B;c[(c[k>>2]|0)+176>>2]=A;c[a+4808>>2]=0;C=0}}while(0);while(1){D=a+571288+(C<<2)|0;E=C+1|0;if((c[D>>2]|0)==0){break}else{C=E}}if((C|0)>=17){KIb(0,0,2122224,(B=i,i=i+24|0,c[B>>2]=2459944,c[B+8>>2]=2617208,c[B+16>>2]=2219,B)|0);i=B;Hd()}c[D>>2]=e;D=e+2192|0;if((c[D>>2]|0)==0){c[D>>2]=4}D=a+571288|0;e=c[D>>2]|0;C=c[a+571292>>2]|0;d:do{if((C|0)==0){F=0;G=e}else{A=1;y=0;f=e;j=C;while(1){if((c[j+84>>2]|0)!=0){F=y;G=f;break d}if((c[j+1620>>2]|0)!=0){F=y;G=f;break d}l=(c[j+1612>>2]|0)<(c[f+1612>>2]|0);g=l?A:y;x=l?j:f;l=A+1|0;z=c[a+571288+(l<<2)>>2]|0;if((z|0)==0){F=g;G=x;break}else{A=l;y=g;f=x;j=z}}}}while(0);C=c[k>>2]|0;j=C+176|0;do{if((c[j>>2]|0)==0){if((c[e+84>>2]|0)==0){if((c[e+1620>>2]|0)==0){break}}c[a+571432>>2]=-2147483648}}while(0);e=c[G+1612>>2]|0;f=a+571432|0;y=(e|0)<(c[f>>2]|0);if(y){w=82}else{A=c[j>>2]|0;if((E|0)>(A|0)){w=82}else{H=C;I=A;w=86}}do{if((w|0)==82){A=G+2192|0;c[A>>2]=c[A>>2]&-5;A=a+571288+(F<<2)|0;if((c[A>>2]|0)!=0){C=F;j=A;while(1){A=C+1|0;n=a+571288+(A<<2)|0;c[j>>2]=c[n>>2];if((c[n>>2]|0)==0){break}else{C=A;j=n}}}j=c[k>>2]|0;if(y){J=j;w=93;break}H=j;I=c[j+176>>2]|0;w=86}}while(0);e:do{if((w|0)==86){if((E|0)<=(I|0)){J=H;w=93;break}c[h>>2]=G;do{if((F|0)==0){j=c[D>>2]|0;if((j|0)==0){break}if((c[j+84>>2]|0)==0){if((c[j+1620>>2]|0)==0){break}}c[f>>2]=-2147483648;K=G;break e}}while(0);c[f>>2]=e;K=G}}while(0);if((w|0)==93){KIb(J,48,2443288,(B=i,i=i+8|0,c[B>>2]=y?2430864:10230440,B)|0);i=B;K=c[h>>2]|0}if((K|0)!=0){h=K+2200|0;K=a+572480|0;a=c[K>>2]|0;if((c[h>>2]|0)==0){L=0;M=a}else{B=a|2;c[K>>2]=B;L=c[h>>2]|0;M=B}c[h>>2]=L|M>>>1&1}if((b|0)==0){i=d;return}b=c[k>>2]|0;if((c[b+712>>2]|0)!=0){i=d;return}K5a(b);i=d;return}function Cha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[a>>2]|0;c[a+427380>>2]=0;f=(b|0)!=0;if(f){g=3}else{if((c[e+816>>2]&1|0)==0){g=3}}if((g|0)==3){if((c[a+4796>>2]|0)==0){Hia(a,a+571436|0,c[a+572228>>2]|0)|0;c[a+428660>>2]=c[a+428640>>2];c[a+428664>>2]=c[a+428636>>2]}c[a+428672>>2]=c[a+428668>>2];c[a+428676>>2]=c[a+428656>>2];c[a+571428>>2]=c[a+571432>>2]}g=c[e+712>>2]|0;do{if((g|0)!=0){if((ve[c[g+32>>2]&4095](e)|0)>=0){break}KIb(e,16,2489744,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b}}while(0);e=a+177100|0;do{if((c[e>>2]|0)==3){if((c[a+572376>>2]|0)==0){break}if((c[a+7324>>2]|0)!=0){break}c[a+2484>>2]=c[a+2524>>2];zpb(a+2352|0)}}while(0);if(f){h=a+572376|0;c[h>>2]=0;i=d;return}if((c[a+4796>>2]|0)!=0){h=a+572376|0;c[h>>2]=0;i=d;return}L5a((c[a+2524>>2]|0)+1496|0,2147483647,(c[e>>2]|0)==2|0);h=a+572376|0;c[h>>2]=0;i=d;return}function Dha(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0;g=i;i=i+64|0;h=g|0;c[e+1028>>2]=e+180;c[e+1032>>2]=e+436;j=e+1088|0;k=j|0;l=c[k>>2]|0;m=e+1096|0;n=c[m>>2]|0;o=l+(n>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(n&7);o=n+16|0;q=l+(o>>>3)|0;r=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(o&7)>>>16|p&-65536;o=r>>>0>65535>>>0;q=o?p>>>16:r;r=o?16:0;if((q&65280|0)==0){s=r;t=q}else{s=r|8;t=q>>>8}q=(d[1359664+t|0]|0)+s|0;s=31-q|0;t=s+n|0;c[m>>2]=t;n=s+1|0;do{if((n|0)==0){u=-1}else{r=l+(t>>>3)|0;o=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7);if((n|0)<26){c[m>>2]=t+n;v=o>>>(q>>>0)}else{r=t+16|0;c[m>>2]=r;p=l+(r>>>3)|0;w=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(r&7)>>>((47-s|0)>>>0);c[m>>2]=t+n;v=w|o>>>16<<s-15}o=v-1|0;if((o|0)!=0){u=o;break}o=f+572376|0;do{if((c[o>>2]|0)!=0){if((c[e+2524>>2]|0)==0){break}if((c[e+177100>>2]|0)==3){break}Cha(e,1)}}while(0);c[o>>2]=0;if((c[f+177104>>2]|0)!=0){u=0;break}w=e+2524|0;r=c[w>>2]|0;do{if((r|0)!=0){if((c[e+4796>>2]|0)!=0){break}L5a(r+1496|0,2147483647,(c[e+177100>>2]|0)==2|0)}}while(0);c[w>>2]=0;u=0}}while(0);v=c[m>>2]|0;s=c[k>>2]|0;n=s+(v>>>3)|0;t=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(v&7)>>>23;n=(d[1382088+t|0]|0)+v|0;c[m>>2]=n;v=a[1276064+t|0]|0;t=v&255;if((v&255)>>>0>9>>>0){l=c[e+427376>>2]|0;q=c[e+427380>>2]|0;KIb(c[e>>2]|0,16,2211592,(x=i,i=i+24|0,c[x>>2]=t,c[x+8>>2]=l,c[x+16>>2]=q,x)|0);i=x;y=-1094995529;i=g;return y|0}if((v&255)>>>0>4>>>0){c[e+177084>>2]=1;z=t-5|0}else{c[e+177084>>2]=0;z=t}t=d[1147192+z|0]|0;v=e+177076|0;c[v>>2]=t;q=t&3;l=e+177080|0;c[l>>2]=q;r=e+427436|0;if(!((c[r>>2]|0)!=5|(q|0)==1)){KIb(c[e>>2]|0,16,2208896,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=g;return y|0}c[e+572392>>2]=t;q=s+(n>>>3)|0;s=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(n&7);do{if(s>>>0>134217727>>>0){q=s>>>23;c[m>>2]=(d[1382088+q|0]|0)+n;A=d[1276064+q|0]|0}else{q=s>>>0>65535>>>0;o=q?s>>>16:s;p=q?16:0;if((o&65280|0)==0){B=p;C=o}else{B=p|8;C=o>>>8}o=(d[1359664+C|0]|0)+B<<1;c[m>>2]=n+63-o;p=(s>>>((o-31|0)>>>0))-1|0;if(!(p>>>0>255>>>0)){A=p;break}KIb(c[e>>2]|0,16,2200448,(x=i,i=i+8|0,c[x>>2]=p,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);s=c[f+427604+(A<<2)>>2]|0;if((s|0)==0){KIb(c[e>>2]|0,16,2195760,(x=i,i=i+8|0,c[x>>2]=A,x)|0);i=x;y=-1094995529;i=g;return y|0}n=f+8056|0;B=c[n>>2]|0;if(!((B|0)<0|(A|0)==(B|0))){KIb(c[e>>2]|0,16,2193152,(x=i,i=i+16|0,c[x>>2]=B,c[x+8>>2]=A,x)|0);i=x;y=-1094995529;i=g;return y|0}B=e+7328|0;nrc(B|0,s|0,728)|0;s=B|0;B=c[s>>2]|0;C=c[f+427476+(B<<2)>>2]|0;if((C|0)==0){KIb(c[e>>2]|0,16,2190680,(x=i,i=i+8|0,c[x>>2]=B,x)|0);i=x;y=-1094995529;i=g;return y|0}p=e+6124|0;do{if((B|0)==(c[p>>2]|0)){if((B|0)!=(c[e+6120>>2]|0)){D=39;break}if((c[C+1200>>2]|0)==0){E=0}else{D=39}}else{D=39}}while(0);do{if((D|0)==39){nrc(p|0,C|0,1204)|0;do{if((c[e+427400>>2]|0)==(c[e+6180>>2]|0)){if((c[e+427396>>2]|0)!=(ca(2-(c[e+6188>>2]|0)|0,c[e+6184>>2]|0)|0)){D=43;break}B=c[(c[e>>2]|0)+796>>2]|0;if((B|0)!=(c[e+7308>>2]|0)){D=43;break}if((c[e+572632>>2]|0)==(c[e+6136>>2]|0)){F=0;H=B}else{D=43}}else{D=43}}while(0);if((D|0)==43){F=1;H=c[e+7308>>2]|0}w=e+427468|0;B=e+7308|0;if((c[w>>2]|0)==(H|0)){o=e+427472|0;q=c[e+6136>>2]|0;if((c[o>>2]|0)==(q|0)){I=F}else{J=q;K=o;D=47}}else{J=c[e+6136>>2]|0;K=e+427472|0;D=47}if((D|0)==47){c[w>>2]=c[B>>2];c[K>>2]=J;I=1}do{if((c[e+4816>>2]&524288|0)==0){if((c[e+6784>>2]|0)==0){break}if((c[e+6788>>2]|0)==0){D=51}}else{D=51}}while(0);a:do{if((D|0)==51){w=c[e>>2]|0;do{if((c[w+176>>2]|0)<=1){if((c[e+571288>>2]|0)!=0){break}c[e+4808>>2]=1;break a}}while(0);KIb(w,24,2612960,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x}}while(0);o=e|0;q=c[o>>2]|0;L=q+176|0;if((c[L>>2]|0)<2){c[L>>2]=(c[e+4808>>2]|0)==0}L=q+796|0;M=c[B>>2]|0;if((c[L>>2]|0)==(M|0)){if((c[e+572632>>2]|0)==(c[e+6136>>2]|0)){E=I;break}}N=c[q+12>>2]|0;do{if((N|0)==0){D=64}else{if((c[N+16>>2]&128|0)==0){D=64;break}if((M|0)==8){O=e+6136|0;if((c[O>>2]|0)<=1){P=8;Q=O;break}}KIb(q,16,2609080,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);b:do{if((D|0)==64){do{if(!((M-8|0)>>>0>6>>>0)){if((M|0)==13|(M|0)==11){break}P=M;Q=e+6136|0;break b}}while(0);KIb(q,16,2619256,(x=i,i=i+8|0,c[x>>2]=M,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);c[L>>2]=P;M=c[Q>>2]|0;c[e+572632>>2]=M;q=c[B>>2]|0;c[e+4752>>2]=(q|0)>8;bja(e+12|0,q,M);Mia(e+148|0,c[e+7312>>2]|0);nta(e+180|0,c[B>>2]|0);zma(e+4932|0,c[(c[o>>2]|0)+48>>2]|0,c[B>>2]|0,c[Q>>2]|0);l8(e+1108|0,c[o>>2]|0);G8a(e+4|0,c[B>>2]|0);E=I}}while(0);I=c[e+6128>>2]|0;if((I|0)==66){R=c[e+7320>>2]<<8&512|66}else if((I|0)==110|(I|0)==122|(I|0)==244){R=c[e+7320>>2]<<8&2048|I}else{R=I}I=e|0;Q=c[I>>2]|0;c[Q+840>>2]=R;c[Q+844>>2]=c[e+6132>>2];R=e+6172|0;c[Q+364>>2]=c[R>>2];P=e+4812|0;do{if((c[P>>2]|0)==0){S=0}else{J=c[e+6180>>2]|0;if((J<<4|0)!=(c[Q+128>>2]|0)){S=1;break}K=c[e+6184>>2]|0;F=2-(c[e+6188>>2]|0)|0;H=ca(K<<4,F)|0;if((H|0)!=(c[Q+132>>2]|0)){S=1;break}if((c[Q+796>>2]|0)!=(c[e+7308>>2]|0)){S=1;break}if((c[e+572632>>2]|0)!=(c[e+6136>>2]|0)){S=1;break}H=c[e+6224>>2]|0;C=c[e+6228>>2]|0;p=c[Q+224>>2]|0;M=c[Q+228>>2]|0;q=Erc(M,(M|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;w=G;N=Erc(p,(p|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;if(!((q|0)==(N|0)&(w|0)==(G|0))){S=1;break}if((M|0)==0|(C|0)==0){if((H|0)==0|(p|0)==0){S=1;break}if((H>>31|0)!=(p>>31|0)){S=1;break}}if((c[e+427400>>2]|0)!=(J|0)){S=1;break}S=(c[e+427396>>2]|0)!=(ca(F,K)|0)|0}}while(0);Q=f|0;K=c[(c[Q>>2]|0)+140>>2]|0;if((K|0)==14){T=5}else if((K|0)==12){T=0}else if((K|0)==13){T=4}else{T=K}K=Iha(f,0)|0;if((K|0)==13){U=4}else if((K|0)==12){U=0}else if((K|0)==14){U=5}else{U=K}K=(T|0)==(U|0);U=c[e+6180>>2]|0;T=e+427400|0;c[T>>2]=U;F=e+6188|0;J=ca(2-(c[F>>2]|0)|0,c[e+6184>>2]|0)|0;p=e+427396|0;c[p>>2]=J;H=e+427408|0;c[H>>2]=ca(J,U)|0;C=e+427404|0;c[C>>2]=U+1;c[e+6108>>2]=U<<2;c[e+4788>>2]=(c[e+6136>>2]|0)<2;M=U<<4;U=e+4768|0;c[U>>2]=M;w=J<<4;J=e+4772|0;c[J>>2]=w;N=(c[e+6204>>2]|0)+(c[e+6208>>2]|0)|0;q=M-N|0;O=(c[e+6216>>2]|0)+(c[e+6212>>2]|0)|0;V=w-O|0;if(!(N>>>0<M>>>0)){KIb(0,0,2122224,(x=i,i=i+24|0,c[x>>2]=2628912,c[x+8>>2]=2617208,c[x+16>>2]=3256,x)|0);i=x;Hd();return 0}if(!(O>>>0<w>>>0)){KIb(0,0,2122224,(x=i,i=i+24|0,c[x>>2]=2627376,c[x+8>>2]=2617208,c[x+16>>2]=3257,x)|0);i=x;Hd();return 0}O=e+6200|0;do{if((c[O>>2]|0)==0){N=c[I>>2]|0;W=c[N+120>>2]|0;if((W+15&-16|0)!=(M|0)){X=V;Y=q;break}Z=c[N+124>>2]|0;N=(Z+15&-16|0)==(w|0);X=N?Z:V;Y=N?W:q}else{X=V;Y=q}}while(0);do{if((Y|0)<1|(X|0)<1){KIb(c[I>>2]|0,16,2626040,(x=i,i=i+16|0,c[x>>2]=Y,c[x+8>>2]=X,x)|0);i=x;q=c[I>>2]|0;if((c[q+696>>2]&8|0)==0){KIb(q,24,2624792,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;mrc(O|0,0,20)|0;q=c[U>>2]|0;_=c[J>>2]|0;$=q;aa=q;break}else{y=-1094995529;i=g;return y|0}}else{_=X;$=Y;aa=M}}while(0);M=c[I>>2]|0;c[M+128>>2]=aa;Y=c[J>>2]|0;c[M+132>>2]=Y;c[M+120>>2]=$;c[M+124>>2]=_;do{if((c[e+6232>>2]|0)==0){ba=E}else{c[M+396>>2]=(c[e+6236>>2]|0)>0?2:1;if((c[e+6240>>2]|0)==0){ba=E;break}_=M+392|0;$=c[e+6252>>2]|0;X=(c[_>>2]|0)==($|0)?E:1;c[M+384>>2]=c[e+6244>>2];c[M+388>>2]=c[e+6248>>2];c[_>>2]=$;ba=X}}while(0);E=c[P>>2]|0;if((E|0)==0){D=121}else{X=c[U>>2]|0;if((X|0)==(aa|0)){if((c[J>>2]|0)==(Y|0)&(K&(S|0)==0)&(ba|0)==0){da=E}else{D=107}}else{D=107}do{if((D|0)==107){if((e|0)!=(f|0)){E=c[J>>2]|0;ba=(c[f+572376>>2]|0)+1|0;KIb(M,16,2188040,(x=i,i=i+40|0,c[x>>2]=X,c[x+8>>2]=aa,c[x+16>>2]=E,c[x+24>>2]=Y,c[x+32>>2]=ba,x)|0);i=x;y=-1094995529;i=g;return y|0}c[e+571432>>2]=-2147483648;c[e+571428>>2]=-2147483648;c[e+572412>>2]=1;Fia(e);c[e+428672>>2]=0;c[e+428660>>2]=65536;c[e+428664>>2]=0;c[e+571360>>2]=-2147483648;c[e+571364>>2]=-2147483648;c[e+571368>>2]=-2147483648;c[e+571372>>2]=-2147483648;c[e+571376>>2]=-2147483648;c[e+571380>>2]=-2147483648;c[e+571384>>2]=-2147483648;c[e+571388>>2]=-2147483648;c[e+571392>>2]=-2147483648;c[e+571396>>2]=-2147483648;c[e+571400>>2]=-2147483648;c[e+571404>>2]=-2147483648;c[e+571408>>2]=-2147483648;c[e+571412>>2]=-2147483648;c[e+571416>>2]=-2147483648;c[e+571420>>2]=-2147483648;c[e+428676>>2]=-1;ba=e+2524|0;E=c[ba>>2]|0;if((E|0)!=0){c[E+2192>>2]=0;S=c[e+571288>>2]|0;c:do{if((S|0)==0){ea=0}else{K=1;$=0;_=S;O=E;while(1){if((_|0)==(O|0)){fa=$}else{c[e+571288+($<<2)>>2]=_;fa=$+1|0}q=c[e+571288+(K<<2)>>2]|0;if((q|0)==0){ea=fa;break c}K=K+1|0;$=fa;_=q;O=c[ba>>2]|0}}}while(0);c[e+571288+(ea<<2)>>2]=0}c[e+177104>>2]=0;mrc(e+199440|0,0,213504)|0;mrc(e+428696|0,0,142336)|0;Jia(e);c[e+572476>>2]=-1;c[e+572480>>2]=0;c[e+199428>>2]=0;c[e+572376>>2]=0;c[e+572232>>2]=1;ba=Iha(e,1)|0;if((ba|0)<0){y=ba;i=g;return y|0}E=c[I>>2]|0;c[E+140>>2]=ba;S=c[U>>2]|0;B=c[J>>2]|0;o=mKb(ba)|0;KIb(E,32,2185496,(x=i,i=i+24|0,c[x>>2]=S,c[x+8>>2]=B,c[x+16>>2]=o,x)|0);i=x;o=Jha(e,1)|0;if((o|0)>=0){da=c[P>>2]|0;break}KIb(c[I>>2]|0,16,2183208,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=o;i=g;return y|0}}while(0);if((da|0)==0){D=121}}do{if((D|0)==121){if((e|0)!=(f|0)){KIb(c[I>>2]|0,16,2181104,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1163346256;i=g;return y|0}da=Iha(e,1)|0;if((da|0)<0){y=da;i=g;return y|0}c[(c[I>>2]|0)+140>>2]=da;da=Jha(e,0)|0;if((da|0)>=0){break}KIb(c[I>>2]|0,16,2183208,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=da;i=g;return y|0}}while(0);do{if((e|0)==(f|0)){da=e+428628|0;if((c[da>>2]|0)==(A|0)){break}c[da>>2]=A;gha(e)}}while(0);da=e+6144|0;P=c[da>>2]|0;J=c[m>>2]|0;U=c[k>>2]|0;ea=U+(J>>>3)|0;fa=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(J&7)>>>((32-P|0)>>>0);ea=J+P|0;c[m>>2]=ea;J=e+428656|0;c[J>>2]=fa;c[e+177096>>2]=0;Y=e+177088|0;c[Y>>2]=0;aa=f+177100|0;X=c[aa>>2]|0;M=c[f+4796>>2]|0;o=e+427432|0;B=(c[o>>2]|0)==0|0;S=e+4796|0;c[S>>2]=B;do{if((c[F>>2]|0)==0){if((c[e+6196>>2]|0)==0&(z|0)==1){KIb(c[I>>2]|0,16,2178800,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1;i=g;return y|0}E=d[U+(ea>>>3)|0]|0;ba=ea+1|0;c[m>>2]=ba;if((E&128>>>((ea&7)>>>0)|0)==0){c[e+177100>>2]=3;c[Y>>2]=c[e+6192>>2];ga=3;break}else{E=d[U+(ba>>>3)|0]<<(ba&7)>>>7;c[m>>2]=ea+2;ba=(E&1)+1|0;c[e+177100>>2]=ba;ga=ba;break}}else{c[e+177100>>2]=3;ga=3}}while(0);ea=e+177100|0;c[e+177092>>2]=(ga|0)!=3;U=f+572376|0;F=c[U>>2]|0;do{if((F|0)==0){ba=e+428676|0;E=c[ba>>2]|0;do{if((fa|0)!=(E|0)){L=1<<P;O=c[R>>2]|0;if((fa-E+((E|0)>(fa|0)?L:0)|0)<=(O|0)){break}_=fa-O-1|0;c[ba>>2]=((_|0)<0?L:0)+_}}while(0);E=f+177104|0;do{if((c[E>>2]|0)!=0){_=f+2524|0;L=c[_>>2]|0;if((c[L+1500>>2]|0)==(c[Q>>2]|0)){L5a(L+1496|0,2147483647,(X|0)==2|0);ha=c[ea>>2]|0}else{ha=ga}if((ha|0)==3|(ha|0)==(X|0)){if((X|0)==3){break}L5a((c[_>>2]|0)+1496|0,2147483647,(X|0)==1|0);break}L=c[_>>2]|0;if((c[L+1616>>2]|0)!=(c[J>>2]|0)){if((X|0)==3){break}L5a(L+1496|0,2147483647,(X|0)==1|0);break}do{if(!((X|0)==1&(ha|0)==2)){if((X|0)==2&(ha|0)==1){break}KIb(c[I>>2]|0,16,2164168,(x=i,i=i+16|0,c[x>>2]=X,c[x+8>>2]=ha,x)|0);i=x;c[ea>>2]=X;c[S>>2]=M;y=-1094995529;i=g;return y|0}}while(0);if((M|0)==(c[S>>2]|0)){break}QIb(c[I>>2]|0,2162104,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;c[ea>>2]=X;c[S>>2]=M;y=-1163346256;i=g;return y|0}}while(0);L=c[J>>2]|0;_=c[ba>>2]|0;d:do{if((L|0)==(_|0)){ia=L;D=178}else{O=e+572240|0;$=e+6176|0;K=e+2524|0;q=e+571436|0;V=e+572228|0;w=e+571032|0;W=L;N=_;while(1){if((c[E>>2]|0)!=0){D=161;break}if((W|0)==((N+1|0)%(1<<c[da>>2]|0)|0|0)){ia=W;D=178;break d}if((c[O>>2]|0)==0){ja=0}else{ja=c[w>>2]|0}KIb(c[I>>2]|0,48,2160056,(x=i,i=i+16|0,c[x>>2]=W,c[x+8>>2]=N,x)|0);i=x;if((c[$>>2]|0)==0){c[e+571360>>2]=-2147483648;c[e+571364>>2]=-2147483648;c[e+571368>>2]=-2147483648;c[e+571372>>2]=-2147483648;c[e+571376>>2]=-2147483648;c[e+571380>>2]=-2147483648;c[e+571384>>2]=-2147483648;c[e+571388>>2]=-2147483648;c[e+571392>>2]=-2147483648;c[e+571396>>2]=-2147483648;c[e+571400>>2]=-2147483648;c[e+571404>>2]=-2147483648;c[e+571408>>2]=-2147483648;c[e+571412>>2]=-2147483648;c[e+571416>>2]=-2147483648;c[e+571420>>2]=-2147483648}ka=Kha(e)|0;if((ka|0)<0){D=168;break}Z=((c[ba>>2]|0)+1|0)%(1<<c[da>>2]|0)|0;c[ba>>2]=Z;la=c[K>>2]|0;c[la+1616>>2]=Z;c[la+2204>>2]=(c[$>>2]|0)==0;L5a(la+1496|0,2147483647,0);L5a((c[K>>2]|0)+1496|0,2147483647,1);la=Gia(e,1)|0;if((la|0)<0){if((c[(c[I>>2]|0)+696>>2]&8|0)!=0){y=la;D=372;break}}la=Hia(e,q,c[V>>2]|0)|0;if((la|0)<0){if((c[(c[I>>2]|0)+696>>2]&8|0)!=0){y=la;D=372;break}}if((c[O>>2]|0)!=0){la=c[w>>2]|0;if((ja|0)==0){ma=la}else{vIb(la|0,la+32|0,ja|0,ja+32|0,c[(c[I>>2]|0)+140>>2]|0,c[T>>2]<<4,c[p>>2]<<4);la=c[w>>2]|0;c[la+1612>>2]=(c[ja+1612>>2]|0)+2;ma=la}c[ma+1616>>2]=c[ba>>2]}la=c[J>>2]|0;Z=c[ba>>2]|0;if((la|0)==(Z|0)){ia=la;D=178;break d}else{W=la;N=Z}}if((D|0)==161){N=c[ea>>2]|0;na=N;oa=(N|0)!=3;pa=W;D=179;break}else if((D|0)==168){c[E>>2]=0;y=ka;i=g;return y|0}else if((D|0)==372){i=g;return y|0}}}while(0);do{if((D|0)==178){ba=c[ea>>2]|0;_=(ba|0)!=3;if((c[E>>2]|0)!=0){na=ba;oa=_;pa=ia;D=179;break}ba=_&1;c[E>>2]=ba;qa=ba}}while(0);do{if((D|0)==179){ba=f+2524|0;if((na|0)==(X|0)|oa^1){c[ba>>2]=0;_=(na|0)!=3|0;c[E>>2]=_;qa=_;break}_=c[ba>>2]|0;if((c[_+1616>>2]|0)==(pa|0)){c[E>>2]=0;qa=0;break}else{L5a(_+1496|0,2147483647,(c[aa>>2]|0)==2|0);c[E>>2]=1;c[ba>>2]=0;qa=1;break}}}while(0);do{if((c[ea>>2]|0)!=3&(qa|0)==0){ba=e+2520|0;_=e+2524|0;L=0;do{N=c[ba>>2]|0;w=N+(L*2224|0)|0;do{if((c[N+(L*2224|0)+360>>2]|0)!=0){if((c[N+(L*2224|0)+2192>>2]|0)!=0){break}if((w|0)==(c[_>>2]|0)){break}zha(e,w)}}while(0);L=L+1|0;}while((L|0)<36)}else{if((Kha(e)|0)>=0){break}c[E>>2]=0;y=-1094995529;i=g;return y|0}}while(0);E=c[ea>>2]|0;do{if((E|0)==3){mrc(c[e+177072>>2]|0,-1|0,(ca(c[p>>2]<<1,c[C>>2]|0)|0)-2|0)|0}else{L=(E|0)==2|0;_=c[p>>2]|0;if(!(L>>>0<_>>>0)){break}ba=e+177072|0;W=L;L=_;while(1){_=c[C>>2]|0;w=W+1|0;mrc((c[ba>>2]|0)+((ca(_,W)|0)<<1)|0,-1|0,_-((w|0)==(L|0))<<1|0)|0;_=c[p>>2]|0;if(w>>>0<_>>>0){W=w;L=_}else{break}}}}while(0);c[f+572396>>2]=-1}else{if(!((X|0)==(ga|0)&(M|0)==(B|0))){KIb(c[I>>2]|0,16,2176320,(x=i,i=i+16|0,c[x>>2]=X,c[x+8>>2]=ga,x)|0);i=x;c[ea>>2]=X;c[S>>2]=M;y=-1094995529;i=g;return y|0}if((c[f+2524>>2]|0)!=0){break}KIb(c[I>>2]|0,16,2168640,(x=i,i=i+8|0,c[x>>2]=F+1,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);F=(e|0)!=(f|0);if(F){nrc(e+5716|0,f+5716|0,384)|0;c[e+2524>>2]=c[f+2524>>2];nrc(e+2528|0,f+2528|0,2224)|0;c[e+4776>>2]=c[f+4776>>2];c[e+4780>>2]=c[f+4780>>2];c[e+177104>>2]=c[f+177104>>2];c[e+428660>>2]=c[f+428660>>2];c[e+428664>>2]=c[f+428664>>2];c[e+428672>>2]=c[f+428672>>2];c[e+428676>>2]=c[f+428676>>2];c[e+572240>>2]=c[f+572240>>2];nrc(e+571032|0,f+571032|0,128)|0;nrc(e+571160|0,f+571160|0,128)|0;nrc(e+428696|0,f+428696|0,142336)|0;M=e+177020|0;S=f+177020|0;c[M>>2]=c[S>>2];c[M+4>>2]=c[S+4>>2];c[M+8>>2]=c[S+8>>2];c[M+12>>2]=c[S+12>>2];c[M+16>>2]=c[S+16>>2];c[M+20>>2]=c[S+20>>2];S=e+177044|0;M=f+177044|0;c[S>>2]=c[M>>2];c[S+4>>2]=c[M+4>>2];c[S+8>>2]=c[M+8>>2];c[S+12>>2]=c[M+12>>2];c[S+16>>2]=c[M+16>>2];c[S+20>>2]=c[M+20>>2]}M=e+572384|0;S=c[M>>2]|0;e:do{if((S|0)!=0){X=e+4776|0;ga=0;B=S;f:while(1){p=c[e+572248+(ga<<2)>>2]|0;do{if((p|0)==0){ra=B}else{C=c[X>>2]|0;qa=((C|0)>-1?C:-C|0)+63&-32;sa=p+572636|0;if((c[sa>>2]|0)!=0){ra=B;break}c[sa>>2]=hJb(qa*96|0)|0;ta=p+572684|0;c[ta>>2]=pJb(qa*42|0)|0;C=pJb(qa<<6)|0;ua=p+768|0;c[ua>>2]=C;if((c[sa>>2]|0)==0){break f}if((c[ta>>2]|0)==0|(C|0)==0){break f}c[p+784>>2]=C;ra=c[M>>2]|0}}while(0);p=ga+1|0;if(p>>>0<ra>>>0){ga=p;B=ra}else{break e}}mJb(sa);mJb(ta);mJb(ua);y=-12;i=g;return y|0}}while(0);ua=e+2524|0;ta=c[ua>>2]|0;c[ta+1616>>2]=c[J>>2];sa=(c[Y>>2]|0)==0;if(sa){va=(c[ea>>2]|0)!=3|0}else{va=1}ra=c[H>>2]|0;if(!(u<<va>>>0<ra>>>0&u>>>0<ra>>>0)){KIb(c[I>>2]|0,16,2158208,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=g;return y|0}ra=c[T>>2]|0;T=(u>>>0)%(ra>>>0)|0;c[e+427376>>2]=T;c[e+427384>>2]=T;T=c[ea>>2]|0;if(sa){wa=(T|0)!=3|0}else{wa=1}sa=((u>>>0)/(ra>>>0)|0)<<wa;wa=e+427380|0;c[wa>>2]=sa;ra=e+427388|0;c[ra>>2]=sa;do{if((T|0)==2){va=sa+1|0;c[wa>>2]=va;c[ra>>2]=va;xa=c[J>>2]|0;D=221}else{va=c[J>>2]|0;if((T|0)!=3){xa=va;D=221;break}c[e+428680>>2]=va;c[e+428684>>2]=1<<c[da>>2];ya=0}}while(0);if((D|0)==221){c[e+428680>>2]=xa<<1|1;c[e+428684>>2]=1<<(c[da>>2]|0)+1;ya=1}do{if((c[r>>2]|0)==5){da=c[m>>2]|0;xa=(c[k>>2]|0)+(da>>>3)|0;T=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(da&7);if(T>>>0>134217727>>>0){c[m>>2]=(d[1382088+(T>>>23)|0]|0)+da;break}xa=T>>>0>65535>>>0;wa=xa?T>>>16:T;T=xa?16:0;if((wa&65280|0)==0){za=T;Aa=wa}else{za=T|8;Aa=wa>>>8}c[m>>2]=da+63-((d[1359664+Aa|0]|0)+za<<1)}}while(0);za=c[e+6148>>2]|0;do{if((za|0)==0){Aa=c[e+6152>>2]|0;da=c[m>>2]|0;wa=c[k>>2]|0;T=wa+(da>>>3)|0;xa=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(da&7)>>>((32-Aa|0)>>>0);T=da+Aa|0;c[m>>2]=T;c[e+428636>>2]=xa;if((c[e+7336>>2]|0)!=1|ya){break}xa=wa+(T>>>3)|0;Aa=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(T&7);if(Aa>>>0>134217727>>>0){xa=Aa>>>23;c[m>>2]=(d[1382088+xa|0]|0)+T;Ba=a[1306768+xa|0]|0}else{xa=Aa>>>0>65535>>>0;da=xa?Aa>>>16:Aa;Aa=xa?16:0;if((da&65280|0)==0){Ca=Aa;Da=da}else{Ca=Aa|8;Da=da>>>8}da=(d[1359664+Da|0]|0)+Ca|0;Aa=31-da+T|0;T=wa+(Aa>>>3)|0;wa=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(Aa&7)>>>(da>>>0);c[m>>2]=32-da+Aa;Aa=wa>>>1;Ba=(wa&1|0)==0?Aa:-Aa|0}c[e+428644>>2]=Ba;if((za|0)==1){D=236}}else if((za|0)==1){D=236}}while(0);do{if((D|0)==236){if((c[e+6156>>2]|0)!=0){break}za=c[m>>2]|0;Ba=c[k>>2]|0;Ca=Ba+(za>>>3)|0;Da=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(za&7);if(Da>>>0>134217727>>>0){Ca=Da>>>23;Aa=(d[1382088+Ca|0]|0)+za|0;c[m>>2]=Aa;Ea=a[1306768+Ca|0]|0;Fa=Aa}else{Aa=Da>>>0>65535>>>0;Ca=Aa?Da>>>16:Da;Da=Aa?16:0;if((Ca&65280|0)==0){Ga=Da;Ha=Ca}else{Ga=Da|8;Ha=Ca>>>8}Ca=(d[1359664+Ha|0]|0)+Ga|0;Da=31-Ca+za|0;za=Ba+(Da>>>3)|0;Aa=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Da&7)>>>(Ca>>>0);za=32-Ca+Da|0;c[m>>2]=za;Da=Aa>>>1;Ea=(Aa&1|0)==0?Da:-Da|0;Fa=za}c[e+428648>>2]=Ea;if((c[e+7336>>2]|0)!=1|ya){break}za=Ba+(Fa>>>3)|0;Da=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Fa&7);if(Da>>>0>134217727>>>0){za=Da>>>23;c[m>>2]=(d[1382088+za|0]|0)+Fa;Ia=a[1306768+za|0]|0}else{za=Da>>>0>65535>>>0;Aa=za?Da>>>16:Da;Da=za?16:0;if((Aa&65280|0)==0){Ja=Da;Ka=Aa}else{Ja=Da|8;Ka=Aa>>>8}Aa=(d[1359664+Ka|0]|0)+Ja|0;Da=31-Aa+Fa|0;za=Ba+(Da>>>3)|0;Ba=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Da&7)>>>(Aa>>>0);c[m>>2]=32-Aa+Da;Da=Ba>>>1;Ia=(Ba&1|0)==0?Da:-Da|0}c[e+428652>>2]=Ia}}while(0);tha(e,ta+1604|0,ta+1612|0)|0;if((c[e+7388>>2]|0)!=0){ta=c[m>>2]|0;Ia=(c[k>>2]|0)+(ta>>>3)|0;Fa=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(ta&7);if(Fa>>>0>134217727>>>0){Ia=Fa>>>23;c[m>>2]=(d[1382088+Ia|0]|0)+ta;La=d[1276064+Ia|0]|0}else{Ia=Fa>>>0>65535>>>0;Ja=Ia?Fa>>>16:Fa;Ka=Ia?16:0;if((Ja&65280|0)==0){Ma=Ka;Na=Ja}else{Ma=Ka|8;Na=Ja>>>8}Ja=(d[1359664+Na|0]|0)+Ma<<1;c[m>>2]=ta+63-Ja;La=(Fa>>>((Ja-31|0)>>>0))-1|0}c[e+428688>>2]=La}La=vha(e)|0;if((La|0)<0){y=La;i=g;return y|0}g:do{if((z|0)!=2){do{if((c[U>>2]|0)!=0){if((t|0)!=(c[f+572396>>2]|0)){break}if((grc(f+572400|0,f+199420|0,8)|0)==0){break g}}}while(0);Bia(e)|0}}while(0);do{if((c[l>>2]|0)!=1){z=Dia(e)|0;if((z|0)>=0){break}c[e+199420>>2]=0;c[e+199424>>2]=0;y=z;i=g;return y|0}}while(0);if((c[e+7356>>2]|0)==0){D=267}else{if((c[l>>2]|0)==2){D=269}else{D=267}}h:do{if((D|0)==267){z=c[e+7360>>2]|0;do{if((z|0)==1){if((c[l>>2]|0)==3){D=269;break h}}else if((z|0)==2){if((c[l>>2]|0)!=3){break}Lha(e,-1);break h}}while(0);c[e+177120>>2]=0;mrc(e+572484|0,0,16)|0}}while(0);if((D|0)==269){sha(e)|0}do{if((c[o>>2]|0)!=0){if((c[(c[I>>2]|0)+816>>2]&1|0)==0){Oa=1}else{Oa=(c[U>>2]|0)==0|0}if((Iia(f,j,Oa)|0)>=0){break}if((c[(c[I>>2]|0)+696>>2]&8|0)==0){break}else{y=-1094995529}i=g;return y|0}}while(0);do{if((c[Y>>2]|0)==0){D=282}else{Eia(e);if((c[e+7360>>2]|0)!=2){D=282;break}if((c[l>>2]|0)!=3){break}Lha(e,0);Lha(e,1);D=282}}while(0);do{if((D|0)==282){if((c[l>>2]|0)!=3){break}if((c[e+197872>>2]|0)!=0){break}kia(e)}}while(0);lia(e);Y=c[l>>2]|0;l=(Y|0)==1;do{if(!l){if((c[e+7332>>2]|0)==0){break}Oa=c[m>>2]|0;j=(c[k>>2]|0)+(Oa>>>3)|0;z=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(Oa&7)>>>23;c[m>>2]=(d[1382088+z|0]|0)+Oa;Oa=a[1276064+z|0]|0;z=Oa&255;if(!((Oa&255)>>>0>2>>>0)){c[e+572244>>2]=z;break}KIb(c[I>>2]|0,16,2156344,(x=i,i=i+8|0,c[x>>2]=z,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);c[e+426580>>2]=0;z=c[e+7364>>2]|0;Oa=c[m>>2]|0;j=c[k>>2]|0;k=j+(Oa>>>3)|0;La=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Oa&7);if(La>>>0>134217727>>>0){k=La>>>23;Ja=(d[1382088+k|0]|0)+Oa|0;c[m>>2]=Ja;Pa=a[1306768+k|0]|0;Qa=Ja}else{Ja=La>>>0>65535>>>0;k=Ja?La>>>16:La;La=Ja?16:0;if((k&65280|0)==0){Ra=La;Sa=k}else{Ra=La|8;Sa=k>>>8}k=(d[1359664+Sa|0]|0)+Ra|0;Ra=31-k+Oa|0;Oa=j+(Ra>>>3)|0;Sa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Ra&7)>>>(k>>>0);Oa=32-k+Ra|0;c[m>>2]=Oa;Ra=Sa>>>1;Pa=(Sa&1|0)==0?Ra:-Ra|0;Qa=Oa}Oa=Pa+z|0;z=e+7308|0;Pa=c[z>>2]|0;if(Oa>>>0>((Pa*6|0)+3|0)>>>0){KIb(c[I>>2]|0,16,2154816,(x=i,i=i+8|0,c[x>>2]=Oa,x)|0);i=x;y=-1094995529;i=g;return y|0}Ra=e+4792|0;c[Ra>>2]=Oa;c[e+4756>>2]=d[e+7876+Oa|0]|0;c[e+4760>>2]=d[e+7964+Oa|0]|0;Oa=c[v>>2]|0;if((Oa|0)==6){Sa=Qa+1|0;c[m>>2]=Sa;Ta=Sa;D=300}else{if((Oa-5|0)>>>0<2>>>0){Ta=Qa;D=300}else{Ua=Qa}}do{if((D|0)==300){Qa=j+(Ta>>>3)|0;Oa=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(Ta&7);if(Oa>>>0>134217727>>>0){Qa=(d[1382088+(Oa>>>23)|0]|0)+Ta|0;c[m>>2]=Qa;Ua=Qa;break}Qa=Oa>>>0>65535>>>0;Sa=Qa?Oa>>>16:Oa;Oa=Qa?16:0;if((Sa&65280|0)==0){Va=Oa;Wa=Sa}else{Va=Oa|8;Wa=Sa>>>8}Sa=Ta+63+(((d[1359664+Wa|0]|0)+Va|0)*-2|0)|0;c[m>>2]=Sa;Ua=Sa}}while(0);Va=e+427420|0;c[Va>>2]=1;Wa=e+427424|0;c[Wa>>2]=0;Ta=e+427428|0;c[Ta>>2]=0;do{if((c[e+7380>>2]|0)==0){Xa=1;Ya=0;Za=0}else{Sa=j+(Ua>>>3)|0;Oa=(je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ua&7)>>>23;Sa=(d[1382088+Oa|0]|0)+Ua|0;c[m>>2]=Sa;Qa=a[1276064+Oa|0]|0;Oa=Qa&255;if((Qa&255)>>>0>2>>>0){KIb(c[I>>2]|0,16,2152848,(x=i,i=i+8|0,c[x>>2]=Oa,x)|0);i=x;y=-1094995529;i=g;return y|0}k=(Qa&255)>>>0<2>>>0|0;Qa=k^Oa;c[Va>>2]=Qa;if((Oa|0)==(k|0)){Xa=Qa;Ya=0;Za=0;break}k=j+(Sa>>>3)|0;Oa=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(Sa&7);if(Oa>>>0>134217727>>>0){k=Oa>>>23;La=(d[1382088+k|0]|0)+Sa|0;c[m>>2]=La;_a=a[1306768+k|0]|0;$a=La}else{La=Oa>>>0>65535>>>0;k=La?Oa>>>16:Oa;Oa=La?16:0;if((k&65280|0)==0){ab=Oa;bb=k}else{ab=Oa|8;bb=k>>>8}k=(d[1359664+bb|0]|0)+ab|0;Oa=31-k+Sa|0;Sa=j+(Oa>>>3)|0;La=(je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Oa&7)>>>(k>>>0);Sa=32-k+Oa|0;c[m>>2]=Sa;Oa=La>>>1;_a=(La&1|0)==0?Oa:-Oa|0;$a=Sa}Sa=_a<<1;c[Wa>>2]=Sa;Oa=j+($a>>>3)|0;La=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<($a&7);if(La>>>0>134217727>>>0){Oa=La>>>23;c[m>>2]=(d[1382088+Oa|0]|0)+$a;cb=a[1306768+Oa|0]|0}else{Oa=La>>>0>65535>>>0;k=Oa?La>>>16:La;La=Oa?16:0;if((k&65280|0)==0){db=La;eb=k}else{db=La|8;eb=k>>>8}k=(d[1359664+eb|0]|0)+db|0;La=31-k+$a|0;Oa=j+(La>>>3)|0;Ja=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(La&7)>>>(k>>>0);c[m>>2]=32-k+La;La=Ja>>>1;cb=(Ja&1|0)==0?La:-La|0}La=cb<<1;c[Ta>>2]=La;if(!((Sa+12|0)>>>0>24>>>0|(La|0)>12|(La|0)<-12)){Xa=Qa;Ya=Sa;Za=La;break}KIb(c[I>>2]|0,16,2150528,(x=i,i=i+16|0,c[x>>2]=Sa,c[x+8>>2]=La,x)|0);i=x;y=-1094995529;i=g;return y|0}}while(0);cb=c[I>>2]|0;m=c[cb+848>>2]|0;do{if((m|0)>47){D=326}else{if(!((m|0)<32|l)){D=326;break}if((m|0)>15&(Y|0)==3){D=326;break}if((m|0)>7){if((c[o>>2]|0)==0){D=326;break}}if((Xa|0)!=1){fb=Ya;gb=Za;hb=Pa;break}j=f+572380|0;if((c[j>>2]|0)<=1){fb=Ya;gb=Za;hb=Pa;break}if((c[cb+92>>2]&1|0)!=0){c[Va>>2]=2;fb=Ya;gb=Za;hb=Pa;break}c[j>>2]=1;j=f+572388|0;if((c[j>>2]|0)==0){KIb(cb,32,2148376,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;c[j>>2]=1}if(!F){fb=c[Wa>>2]|0;gb=c[Ta>>2]|0;hb=c[z>>2]|0;break}KIb(c[I>>2]|0,16,2141896,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=1;i=g;return y|0}}while(0);if((D|0)==326){c[Va>>2]=0;fb=Ya;gb=Za;hb=Pa}Pa=c[e+7372>>2]|0;Za=(Pa|0)<0?0:Pa;Pa=c[e+7376>>2]|0;c[e+4764>>2]=-33-((fb|0)>(gb|0)?gb:fb)+(hb*6|0)-((Za|0)>(Pa|0)?Za:Pa);c[f+572396>>2]=t;t=f+199420|0;Pa=f+572400|0;Za=c[t+4>>2]|0;c[Pa>>2]=c[t>>2];c[Pa+4>>2]=Za;Za=c[U>>2]|0;Pa=Za+1|0;c[U>>2]=Pa;U=e+177068|0;c[U>>2]=Pa;t=c[ra>>2]|0;if((Pa|0)!=0){b[f+572640+((Za&15)<<1)>>1]=t}Za=b[f+572640+((Pa&15)<<1)>>1]|0;if((Za|0)<=(t|0)&(Za+3|0)>=(t|0)&(Pa|0)>15){KIb(c[I>>2]|0,24,2138184,(x=i,i=i+16|0,c[x>>2]=Pa,c[x+8>>2]=16,x)|0);i=x}Pa=e+199428|0;t=e+572240|0;Za=e+572236|0;ra=0;do{hb=c[U>>2]&15;fb=e+199420+(ra<<2)|0;gb=c[Pa>>2]|0;Ya=0;do{z=h+(Ya<<2)|0;c[z>>2]=60;i:do{if(ra>>>0<gb>>>0){if(!(Ya>>>0<(c[fb>>2]|0)>>>0)){break}F=c[e+199440+(ra*106752|0)+(Ya*2224|0)+360>>2]|0;if((F|0)==0){break}cb=c[F>>2]|0;F=c[t>>2]|0;Xa=0;while(1){if((Xa|0)>=(F|0)){break}if((c[c[(c[e+571032+(Xa<<2)>>2]|0)+360>>2]>>2]|0)==(cb|0)){D=348;break}else{Xa=Xa+1|0}}if((D|0)==348){D=0;c[z>>2]=Xa}o=c[Za>>2]|0;if((o|0)>0){ib=0}else{break}while(1){m=c[e+571160+(ib<<2)>>2]|0;if((m|0)!=0){if((c[c[m+360>>2]>>2]|0)==(cb|0)){break}}m=ib+1|0;if((m|0)<(o|0)){ib=m}else{break i}}c[z>>2]=F+ib}}while(0);Ya=Ya+1|0;}while(Ya>>>0<16>>>0);c[e+412944+(hb<<9)+(ra<<8)+4>>2]=-1;c[e+412944+(hb<<9)+(ra<<8)>>2]=-1;Ya=0;do{c[e+412944+(hb<<9)+(ra<<8)+(Ya+2<<2)>>2]=c[e+199440+(ra*106752|0)+(Ya*2224|0)+2192>>2]&3|c[h+(Ya<<2)>>2]<<2;Ya=Ya+1|0;}while(Ya>>>0<16>>>0);c[e+412944+(hb<<9)+(ra<<8)+76>>2]=-1;c[e+412944+(hb<<9)+(ra<<8)+72>>2]=-1;Ya=16;do{c[e+412944+(hb<<9)+(ra<<8)+(Ya+4<<2)>>2]=c[e+199440+(ra*106752|0)+(Ya*2224|0)+2192>>2]&3|c[h+((Ya-16|0)>>>1<<2)>>2]<<2;Ya=Ya+1|0;}while(Ya>>>0<48>>>0);ra=ra+1|0;}while(ra>>>0<2>>>0);ra=e+199420|0;h=c[ra>>2]|0;if((h|0)!=0){c[e+2488>>2]=e+199440}ib=e+199424|0;if((c[ib>>2]|0)!=0){c[e+2492>>2]=e+306192}c[e+2508>>2]=h;c[n>>2]=A;c[(c[f+427476+(c[s>>2]<<2)>>2]|0)+1200>>2]=0;c[e+7324>>2]=0;c[e+6120>>2]=c[s>>2];s=c[I>>2]|0;if((c[s+688>>2]&1|0)==0){y=0;i=g;return y|0}I=c[U>>2]|0;U=c[ea>>2]|0;if((U|0)==3){jb=2134584}else{jb=(U|0)==1?2132688:2131200}U=(BLb(c[v>>2]|0)|0)<<24>>24;ea=(c[e+177084>>2]|0)!=0?2129712:10230440;f=(c[r>>2]|0)==5?2128216:10230440;r=c[J>>2]|0;J=c[ua>>2]|0;ua=c[J+1604>>2]|0;n=c[J+1608>>2]|0;J=c[ra>>2]|0;ra=c[ib>>2]|0;ib=c[Ra>>2]|0;Ra=c[Va>>2]|0;Va=c[Wa>>2]|0;Wa=c[Ta>>2]|0;Ta=c[e+177120>>2]|0;if((Ta|0)==1){kb=(c[e+177124>>2]|0)!=0?2126928:10230440}else{kb=10230440}if((c[v>>2]|0)==3){lb=(c[e+197872>>2]|0)!=0?2124496:2118392}else{lb=10230440}KIb(s,48,2136448,(x=i,i=i+152|0,c[x>>2]=I,c[x+8>>2]=jb,c[x+16>>2]=u,c[x+24>>2]=U,c[x+32>>2]=ea,c[x+40>>2]=f,c[x+48>>2]=A,c[x+56>>2]=r,c[x+64>>2]=ua,c[x+72>>2]=n,c[x+80>>2]=J,c[x+88>>2]=ra,c[x+96>>2]=ib,c[x+104>>2]=Ra,c[x+112>>2]=Va,c[x+120>>2]=Wa,c[x+128>>2]=Ta,c[x+136>>2]=kb,c[x+144>>2]=lb,x)|0);i=x;y=0;i=g;return y|0}function Eha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;c[e>>2]=a;f=c[a>>2]|0;g=a+427380|0;if((c[g>>2]|0)>=(c[a+427396>>2]|0)){KIb(0,0,2122224,(h=i,i=i+24|0,c[h>>2]=2231944,c[h+8>>2]=2617208,c[h+16>>2]=4731,h)|0);i=h;Hd()}if((c[f+712>>2]|0)!=0){i=d;return}if((c[(c[f+12>>2]|0)+16>>2]&128|0)!=0){i=d;return}if((b|0)==1){Fha(f,e)|0;i=d;return}else if((b|0)==0){KIb(0,0,2122224,(h=i,i=i+24|0,c[h>>2]=2228104,c[h+8>>2]=2617208,c[h+16>>2]=4739,h)|0);i=h;Hd()}else{h=a+427372|0;e=1;do{j=c[a+572248+(e<<2)>>2]|0;c[j+2384>>2]=0;c[j+427372>>2]=c[h>>2];e=e+1|0;}while(e>>>0<b>>>0);se[c[f+824>>2]&127](f,60,a+572248|0,0,b,4)|0;f=c[a+572248+(b-1<<2)>>2]|0;c[a+427376>>2]=c[f+427376>>2];c[g>>2]=c[f+427380>>2];c[a+4796>>2]=c[f+4796>>2];c[a+177100>>2]=c[f+177100>>2];f=a+2384|0;g=1;e=c[f>>2]|0;do{e=e+(c[(c[a+572248+(g<<2)>>2]|0)+2384>>2]|0)|0;c[f>>2]=e;g=g+1|0;}while(g>>>0<b>>>0);i=d;return}}function Fha(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=i;h=c[f>>2]|0;f=h;j=h+427376|0;k=c[j>>2]|0;l=h+427392|0;c[l>>2]=-1;if((c[h+5776>>2]|0)!=(((c[h+4776>>2]|0)*12|0)+(12<<c[h+4752>>2])|0)){KIb(0,0,2122224,(m=i,i=i+24|0,c[m>>2]=2223344,c[m+8>>2]=2617208,c[m+16>>2]=4550,m)|0);i=m;Hd();return 0}n=h+177088|0;do{if((c[n>>2]|0)==0){if((c[h+177100>>2]|0)!=3){o=1;break}o=(c[b+48>>2]|0)!=28|0}else{o=1}}while(0);c[h+427416>>2]=o;o=h;do{if((c[(c[o>>2]|0)+816>>2]&2|0)==0){if((c[h+177100>>2]|0)!=3){break}b=c[h+2392>>2]|0;if((b|0)==0){break}p=(ca(c[h+427400>>2]|0,c[h+427388>>2]|0)|0)+(c[h+427384>>2]|0)|0;q=(c[h+427408>>2]|0)-1|0;if((p|0)<0){break}r=(p|0)>(q|0)?q:p;if((r|0)==0){break}if((a[b+(c[(c[h+2360>>2]|0)+(r-1<<2)>>2]|0)|0]&-2)<<24>>24==112){break}c[h+2388>>2]=1}}while(0);if((c[h+7332>>2]|0)==0){r=gia(f)|0;a:do{if((r|0)>-1){b=h+427400|0;p=h+1096|0;q=h+1100|0;s=h+427380|0;t=h+177100|0;u=h+427396|0;v=h+427404|0;w=h+177072|0;x=h+177068|0;y=h+4064|0;z=h+177092|0;A=h+177096|0;B=k;C=r;while(1){mha(f);if((c[n>>2]|0)==0){D=C}else{c[s>>2]=(c[s>>2]|0)+1;E=gia(f)|0;if((E|0)>-1){mha(f)}c[s>>2]=(c[s>>2]|0)-1;D=E}if((D|0)<0){F=D;G=s;break a}E=(c[j>>2]|0)+1|0;c[j>>2]=E;if((E|0)<(c[b>>2]|0)){H=B}else{Gha(f,B,E);c[j>>2]=0;Hha(f);E=c[s>>2]|0;I=E+1|0;c[s>>2]=I;do{if((c[n>>2]|0)==0){if((c[t>>2]|0)==3){J=I;break}K=E+2|0;c[s>>2]=K;J=K}else{K=E+2|0;c[s>>2]=K;if((K|0)>=(c[u>>2]|0)){J=K;break}L=c[v>>2]|0;M=(ca(L,K)|0)+(c[j>>2]|0)|0;N=M-1|0;O=c[w>>2]|0;P=c[x>>2]|0;do{if((e[O+(N<<1)>>1]|0|0)==(P|0)){Q=c[(c[y>>2]|0)+(N<<2)>>2]|0}else{R=M-L|0;if((e[O+(R<<1)>>1]|0|0)!=(P|0)){Q=0;break}Q=c[(c[y>>2]|0)+(R<<2)>>2]|0}}while(0);P=Q>>>7&1;c[z>>2]=P;c[A>>2]=P;J=K}}while(0);if((J|0)<(c[u>>2]|0)){H=0}else{S=70;break}}T=c[p>>2]|0;U=c[q>>2]|0;if((U-T|0)<1){if((c[l>>2]|0)<1){S=78;break}}E=gia(f)|0;if((E|0)>-1){B=H;C=E}else{F=E;G=s;break a}}if((S|0)==70){C=c[p>>2]|0;B=c[q>>2]|0;do{if((B|0)!=(C|0)){if((B-C|0)>0){if((c[(c[o>>2]|0)+696>>2]&262144|0)==0){break}}ypb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,c[j>>2]|0,J,112);V=-1094995529;i=g;return V|0}}while(0);ypb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,(c[j>>2]|0)-1|0,J,112);V=0;i=g;return V|0}else if((S|0)==78){C=c[h+427384>>2]|0;B=c[h+427388>>2]|0;q=c[j>>2]|0;if((U|0)!=(T|0)){ypb(h+2352|0,C,B,q,c[s>>2]|0,14);V=-1094995529;i=g;return V|0}ypb(h+2352|0,C,B,q-1|0,c[s>>2]|0,112);q=c[j>>2]|0;if((q|0)<=(H|0)){V=0;i=g;return V|0}Gha(f,H,q);V=0;i=g;return V|0}}else{F=r;G=h+427380|0}}while(0);r=c[G>>2]|0;KIb(c[o>>2]|0,16,2214016,(m=i,i=i+16|0,c[m>>2]=c[j>>2],c[m+8>>2]=r,m)|0);i=m;ypb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,c[j>>2]|0,c[G>>2]|0,14);V=F;i=g;return V|0}F=h+1096|0;G=c[F>>2]|0;r=-G&7;if((r|0)==0){W=G}else{H=r+G|0;c[F>>2]=H;W=H}H=h+425488|0;Hmb(H,(c[h+1088>>2]|0)+((W|0)/8|0)|0,(7-W+(c[h+1100>>2]|0)|0)/8|0);Vha(f);W=h+427380|0;F=h+425492|0;G=H;H=h+425504|0;r=h+4820|0;T=h+425508|0;U=h+427400|0;J=h+427396|0;l=h+177100|0;Q=h+427404|0;D=h+177072|0;q=h+177068|0;B=h+4064|0;C=h+177092|0;p=h+177096|0;u=h+425500|0;A=k;while(1){k=Wha(f)|0;do{if((k|0)>-1){mha(f);if((c[n>>2]|0)==0){X=k;break}c[W>>2]=(c[W>>2]|0)+1;z=Wha(f)|0;if((z|0)>-1){mha(f)}c[W>>2]=(c[W>>2]|0)-1;X=z}else{X=k}}while(0);k=c[F>>2]|0;s=k-2|0;c[F>>2]=s;z=c[G>>2]|0;do{if((z|0)<(s<<17|0)){y=(k-258|0)>>>31;c[F>>2]=s<<y;x=z<<y;c[G>>2]=x;if((x&65535|0)!=0){Y=0;break}y=c[H>>2]|0;c[G>>2]=x-65535+((d[y+1|0]|0)<<1|(d[y]|0)<<9);c[H>>2]=y+2;Y=0}else{Y=(c[H>>2]|0)-(c[u>>2]|0)|0}}while(0);z=c[H>>2]|0;s=c[T>>2]|0;if((c[r>>2]&16384|0)!=0){if(z>>>0>(s+2|0)>>>0){S=31;break}}if(z>>>0>(s+2|0)>>>0){KIb(c[o>>2]|0,48,2219776,(m=i,i=i+8|0,c[m>>2]=s-z,m)|0);i=m}if((X|0)<0){S=36;break}z=c[H>>2]|0;s=c[T>>2]|0;if(z>>>0>(s+4|0)>>>0){Z=s;_=z;break}z=(c[j>>2]|0)+1|0;c[j>>2]=z;do{if((z|0)<(c[U>>2]|0)){$=A}else{Gha(f,A,z);c[j>>2]=0;Hha(f);s=c[W>>2]|0;c[W>>2]=s+1;if((c[n>>2]|0)==0){if((c[l>>2]|0)==3){$=0;break}c[W>>2]=s+2;$=0;break}k=s+2|0;c[W>>2]=k;if((k|0)>=(c[J>>2]|0)){$=0;break}s=c[Q>>2]|0;y=(ca(s,k)|0)+(c[j>>2]|0)|0;k=y-1|0;x=c[D>>2]|0;w=c[q>>2]|0;do{if((e[x+(k<<1)>>1]|0|0)==(w|0)){aa=c[(c[B>>2]|0)+(k<<2)>>2]|0}else{v=y-s|0;if((e[x+(v<<1)>>1]|0|0)!=(w|0)){aa=0;break}aa=c[(c[B>>2]|0)+(v<<2)>>2]|0}}while(0);w=aa>>>7&1;c[C>>2]=w;c[p>>2]=w;$=0}}while(0);ba=c[W>>2]|0;if((Y|0)!=0){S=51;break}if((ba|0)<(c[J>>2]|0)){A=$}else{S=51;break}}if((S|0)==31){ypb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,(c[j>>2]|0)-1|0,c[W>>2]|0,112);J=c[j>>2]|0;if((J|0)<(A|0)){V=0;i=g;return V|0}Gha(f,A,J+1|0);V=0;i=g;return V|0}else if((S|0)==36){Z=c[T>>2]|0;_=c[H>>2]|0}else if((S|0)==51){ypb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,(c[j>>2]|0)-1|0,ba,112);ba=c[j>>2]|0;if((ba|0)<=($|0)){V=0;i=g;return V|0}Gha(f,$,ba);V=0;i=g;return V|0}ba=c[W>>2]|0;KIb(c[o>>2]|0,16,2216792,(m=i,i=i+24|0,c[m>>2]=c[j>>2],c[m+8>>2]=ba,c[m+16>>2]=Z-_,m)|0);i=m;ypb(h+2352|0,c[h+427384>>2]|0,c[h+427388>>2]|0,c[j>>2]|0,c[W>>2]|0,14);V=-1094995529;i=g;return V|0}function Gha(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0;i=f+427380|0;j=f+177088|0;k=c[j>>2]|0;l=k+(c[i>>2]|0)|0;m=f+177076|0;n=c[m>>2]|0;o=f+4752|0;p=c[o>>2]|0;q=16>>>((c[f+4788>>2]|0)>>>0);r=f+427420|0;if(!((c[r>>2]|0)!=0&(g|0)<(h|0))){s=k;c[m>>2]=n;t=f+427376|0;c[t>>2]=h;u=l-s|0;c[i>>2]=u;v=f+4792|0;w=c[v>>2]|0;x=f+7876+w|0;y=a[x]|0;z=y&255;A=f+4756|0;c[A>>2]=z;B=f+7964+w|0;C=a[B]|0;D=C&255;E=f+4760|0;c[E>>2]=D;return}F=f+427404|0;G=f+427412|0;H=f+177072|0;I=f+177068|0;J=f+4064|0;K=f+199432|0;L=f+199428|0;M=f+427376|0;N=f+2528|0;O=f+4776|0;P=f+2532|0;Q=f+6136|0;R=f+4780|0;S=f+2536|0;T=f+177092|0;U=f+6112|0;V=f+6116|0;W=f+4844|0;X=f+4852|0;Y=f+4856|0;Z=f+4764|0;_=f+4040|0;$=f+4864|0;aa=f+4872|0;ba=f+4876|0;da=f+6108|0;ea=f+5360|0;fa=f+5392|0;ga=f+5424|0;ha=f+5456|0;ia=f+5644|0;ja=ea;ka=fa;la=ga;ma=ha;na=f+5652|0;oa=f+5660|0;pa=f+5668|0;qa=f+5520|0;ra=f+5552|0;sa=f+5584|0;ta=f+5616|0;ua=f+5684|0;va=qa;wa=ra;xa=sa;ya=ta;za=f+5692|0;Aa=f+5700|0;Ba=f+5708|0;Ca=f+4088|0;Da=f+177096|0;Ea=f+4056|0;Fa=qa;qa=f+5528|0;Ga=ra;ra=f+5560|0;Ha=sa;sa=f+5592|0;Ia=ta;ta=f+5624|0;Ja=f+5488|0;Ka=f+5676|0;La=Ka;Ma=Ja;Na=f+5516|0;Oa=f+5548|0;Pa=f+5580|0;Qa=f+5612|0;Ra=f+5707|0;Sa=f+5699|0;Ta=f+5691|0;Ua=f+5683|0;Va=f+6100|0;Wa=Ja;Ja=f+5496|0;Xa=f+5677|0;Ya=f+5679|0;Za=f+5678|0;_a=f+5304|0;$a=f+5196|0;ab=$a;bb=f+5204|0;cb=bb;db=f+5212|0;eb=db;fb=f+5220|0;gb=fb;hb=f+426560|0;ib=f+426564|0;jb=f+7332|0;kb=f+7392|0;lb=f+5205|0;mb=f+5197|0;nb=f+5207|0;ob=f+5206|0;pb=f+5199|0;qb=f+5198|0;rb=f+5221|0;sb=f+5213|0;tb=f+5223|0;ub=f+5222|0;vb=f+5215|0;wb=f+5214|0;xb=f+5219|0;yb=f+5211|0;zb=f+5203|0;Ab=f+5195|0;Bb=f+5189|0;Cb=f+5188|0;Db=f+5191|0;Eb=f+5190|0;Fb=Cb;Gb=f+4084|0;Hb=f+4052|0;Ib=ea;ea=f+5368|0;Jb=fa;fa=f+5400|0;Kb=ga;ga=f+5432|0;Lb=ha;ha=f+5464|0;Mb=f+5328|0;Nb=f+5636|0;Ob=Nb;Pb=Mb;Qb=f+5356|0;Rb=f+5388|0;Sb=f+5420|0;Tb=f+5452|0;Ub=f+5667|0;Vb=f+5659|0;Wb=f+5651|0;Xb=f+5643|0;Yb=Mb;Mb=f+5336|0;Zb=f+5637|0;_b=f+5639|0;$b=f+5638|0;ac=f+4756|0;bc=f+4760|0;cc=f+5176|0;dc=q-1|0;ec=g;g=k;while(1){a:do{if((g|0)>=0){k=ec<<p;fc=l-g|0;gc=g;while(1){hc=(ca(c[F>>2]|0,fc)|0)+ec|0;c[G>>2]=hc;c[I>>2]=e[(c[H>>2]|0)+(hc<<1)>>1]|0;ic=c[(c[J>>2]|0)+(hc<<2)>>2]|0;c[L>>2]=d[(c[K>>2]|0)+hc|0]|0;jc=(gc|0)==0;if(jc){kc=c[T>>2]|0}else{lc=ic>>>7&1;c[T>>2]=lc;c[Da>>2]=lc;kc=lc}c[M>>2]=ec;c[i>>2]=fc;lc=c[N>>2]|0;mc=c[O>>2]|0;nc=(ca(mc,fc)|0)+k<<4;oc=lc+nc|0;pc=c[P>>2]|0;qc=c[Q>>2]|0;rc=(qc|0)==3;sc=ca(8<<(rc&1),k)|0;tc=c[R>>2]|0;uc=sc+(ca(ca(fc,q)|0,tc)|0)|0;sc=pc+uc|0;vc=c[S>>2]|0;wc=vc+uc|0;do{if((kc|0)==0){c[U>>2]=mc;c[V>>2]=tc;xc=oc;yc=sc;zc=wc;Ac=mc;Bc=tc}else{Cc=mc<<1;c[U>>2]=Cc;Dc=tc<<1;c[V>>2]=Dc;if((fc&1|0)==0){xc=oc;yc=sc;zc=wc;Ac=Cc;Bc=Dc;break}Ec=uc-(ca(tc,dc)|0)|0;xc=lc+((mc*-15|0)+nc)|0;yc=pc+Ec|0;zc=vc+Ec|0;Ac=Cc;Bc=Dc}}while(0);vc=c[o>>2]|0;pc=(qc|0)==2;do{if(jc){Fc=1;Gc=29}else{nc=(c[Da>>2]|0)!=0;if((fc&1|0)==0){if(nc){Fc=0;Gc=29;break}else{break}}if(nc){Fc=1;Gc=29;break}nc=c[cc>>2]|0;mc=Ac*14|0;lc=xc+mc|0;tc=c[lc+4>>2]|0;uc=nc+(ec*96|0)|0;c[uc>>2]=c[lc>>2];c[uc+4>>2]=tc;tc=xc+(mc+8)|0;uc=c[tc+4>>2]|0;lc=nc+(ec*96|0)+8|0;c[lc>>2]=c[tc>>2];c[lc+4>>2]=uc;uc=(vc|0)!=0;if(uc){lc=xc+(mc+16)|0;tc=c[lc+4>>2]|0;wc=nc+(ec*96|0)+16|0;c[wc>>2]=c[lc>>2];c[wc+4>>2]=tc;tc=xc+(mc+24)|0;mc=c[tc+4>>2]|0;wc=nc+(ec*96|0)+24|0;c[wc>>2]=c[tc>>2];c[wc+4>>2]=mc}if(rc){mc=Bc*14|0;wc=yc+mc|0;tc=c[wc>>2]|0;lc=c[wc+4>>2]|0;if(uc){wc=nc+(ec*96|0)+32|0;c[wc>>2]=tc;c[wc+4>>2]=lc;wc=mc+8|0;sc=yc+wc|0;oc=c[sc+4>>2]|0;Dc=nc+(ec*96|0)+40|0;c[Dc>>2]=c[sc>>2];c[Dc+4>>2]=oc;oc=mc+16|0;Dc=yc+oc|0;sc=c[Dc+4>>2]|0;Cc=nc+(ec*96|0)+48|0;c[Cc>>2]=c[Dc>>2];c[Cc+4>>2]=sc;sc=mc+24|0;Cc=yc+sc|0;Dc=c[Cc+4>>2]|0;Ec=nc+(ec*96|0)+56|0;c[Ec>>2]=c[Cc>>2];c[Ec+4>>2]=Dc;Dc=zc+mc|0;Ec=c[Dc+4>>2]|0;Cc=nc+(ec*96|0)+64|0;c[Cc>>2]=c[Dc>>2];c[Cc+4>>2]=Ec;Ec=zc+wc|0;wc=c[Ec+4>>2]|0;Cc=nc+(ec*96|0)+72|0;c[Cc>>2]=c[Ec>>2];c[Cc+4>>2]=wc;wc=zc+oc|0;oc=c[wc+4>>2]|0;Cc=nc+(ec*96|0)+80|0;c[Cc>>2]=c[wc>>2];c[Cc+4>>2]=oc;oc=zc+sc|0;sc=c[oc+4>>2]|0;Cc=nc+(ec*96|0)+88|0;c[Cc>>2]=c[oc>>2];c[Cc+4>>2]=sc;Fc=1;Gc=29;break}else{sc=nc+(ec*96|0)+16|0;c[sc>>2]=tc;c[sc+4>>2]=lc;lc=mc+8|0;sc=yc+lc|0;tc=c[sc+4>>2]|0;Cc=nc+(ec*96|0)+24|0;c[Cc>>2]=c[sc>>2];c[Cc+4>>2]=tc;tc=zc+mc|0;mc=c[tc+4>>2]|0;Cc=nc+(ec*96|0)+32|0;c[Cc>>2]=c[tc>>2];c[Cc+4>>2]=mc;mc=zc+lc|0;lc=c[mc+4>>2]|0;Cc=nc+(ec*96|0)+40|0;c[Cc>>2]=c[mc>>2];c[Cc+4>>2]=lc;Fc=1;Gc=29;break}}if(pc){lc=Bc*14|0;Cc=yc+lc|0;mc=c[Cc>>2]|0;tc=c[Cc+4>>2]|0;if(uc){Cc=nc+(ec*96|0)+32|0;c[Cc>>2]=mc;c[Cc+4>>2]=tc;Cc=lc+8|0;sc=yc+Cc|0;oc=c[sc+4>>2]|0;wc=nc+(ec*96|0)+40|0;c[wc>>2]=c[sc>>2];c[wc+4>>2]=oc;oc=zc+lc|0;wc=c[oc+4>>2]|0;sc=nc+(ec*96|0)+48|0;c[sc>>2]=c[oc>>2];c[sc+4>>2]=wc;wc=zc+Cc|0;Cc=c[wc+4>>2]|0;sc=nc+(ec*96|0)+56|0;c[sc>>2]=c[wc>>2];c[sc+4>>2]=Cc;Fc=1;Gc=29;break}else{Cc=nc+(ec*96|0)+16|0;c[Cc>>2]=mc;c[Cc+4>>2]=tc;tc=zc+lc|0;lc=c[tc+4>>2]|0;Cc=nc+(ec*96|0)+24|0;c[Cc>>2]=c[tc>>2];c[Cc+4>>2]=lc;Fc=1;Gc=29;break}}else{lc=Bc*6|0;Cc=yc+lc|0;tc=c[Cc>>2]|0;mc=c[Cc+4>>2]|0;if(uc){uc=nc+(ec*96|0)+32|0;c[uc>>2]=tc;c[uc+4>>2]=mc;uc=lc+8|0;Cc=yc+uc|0;sc=c[Cc+4>>2]|0;wc=nc+(ec*96|0)+40|0;c[wc>>2]=c[Cc>>2];c[wc+4>>2]=sc;sc=zc+lc|0;wc=c[sc+4>>2]|0;Cc=nc+(ec*96|0)+48|0;c[Cc>>2]=c[sc>>2];c[Cc+4>>2]=wc;wc=zc+uc|0;uc=c[wc+4>>2]|0;Cc=nc+(ec*96|0)+56|0;c[Cc>>2]=c[wc>>2];c[Cc+4>>2]=uc;Fc=1;Gc=29;break}else{uc=nc+(ec*96|0)+16|0;c[uc>>2]=tc;c[uc+4>>2]=mc;mc=zc+lc|0;lc=c[mc+4>>2]|0;uc=nc+(ec*96|0)+24|0;c[uc>>2]=c[mc>>2];c[uc+4>>2]=lc;Fc=1;Gc=29;break}}}}while(0);do{if((Gc|0)==29){Gc=0;jc=c[M>>2]|0;qc=c[f+5176+(Fc<<2)>>2]|0;lc=Ac<<4;uc=lc-Ac|0;mc=xc+uc|0;nc=c[mc+4>>2]|0;tc=qc+(jc*96|0)|0;c[tc>>2]=c[mc>>2];c[tc+4>>2]=nc;nc=xc+(uc+8)|0;tc=c[nc+4>>2]|0;mc=qc+(jc*96|0)+8|0;c[mc>>2]=c[nc>>2];c[mc+4>>2]=tc;tc=(vc|0)!=0;if(tc){mc=xc+(uc+16)|0;nc=c[mc+4>>2]|0;Cc=qc+(jc*96|0)+16|0;c[Cc>>2]=c[mc>>2];c[Cc+4>>2]=nc;nc=xc+(uc+24)|0;uc=c[nc+4>>2]|0;Cc=qc+(jc*96|0)+24|0;c[Cc>>2]=c[nc>>2];c[Cc+4>>2]=uc}if(rc){uc=lc-Bc|0;lc=yc+uc|0;Cc=c[lc>>2]|0;nc=c[lc+4>>2]|0;if(tc){lc=qc+(jc*96|0)+32|0;c[lc>>2]=Cc;c[lc+4>>2]=nc;lc=uc+8|0;mc=yc+lc|0;wc=c[mc+4>>2]|0;sc=qc+(jc*96|0)+40|0;c[sc>>2]=c[mc>>2];c[sc+4>>2]=wc;wc=uc+16|0;sc=yc+wc|0;mc=c[sc+4>>2]|0;oc=qc+(jc*96|0)+48|0;c[oc>>2]=c[sc>>2];c[oc+4>>2]=mc;mc=uc+24|0;oc=yc+mc|0;sc=c[oc+4>>2]|0;Ec=qc+(jc*96|0)+56|0;c[Ec>>2]=c[oc>>2];c[Ec+4>>2]=sc;sc=zc+uc|0;Ec=c[sc+4>>2]|0;oc=qc+(jc*96|0)+64|0;c[oc>>2]=c[sc>>2];c[oc+4>>2]=Ec;Ec=zc+lc|0;lc=c[Ec+4>>2]|0;oc=qc+(jc*96|0)+72|0;c[oc>>2]=c[Ec>>2];c[oc+4>>2]=lc;lc=zc+wc|0;wc=c[lc+4>>2]|0;oc=qc+(jc*96|0)+80|0;c[oc>>2]=c[lc>>2];c[oc+4>>2]=wc;wc=zc+mc|0;mc=c[wc+4>>2]|0;oc=qc+(jc*96|0)+88|0;c[oc>>2]=c[wc>>2];c[oc+4>>2]=mc;break}else{mc=qc+(jc*96|0)+16|0;c[mc>>2]=Cc;c[mc+4>>2]=nc;nc=uc+8|0;mc=yc+nc|0;Cc=c[mc+4>>2]|0;oc=qc+(jc*96|0)+24|0;c[oc>>2]=c[mc>>2];c[oc+4>>2]=Cc;Cc=zc+uc|0;uc=c[Cc+4>>2]|0;oc=qc+(jc*96|0)+32|0;c[oc>>2]=c[Cc>>2];c[oc+4>>2]=uc;uc=zc+nc|0;nc=c[uc+4>>2]|0;oc=qc+(jc*96|0)+40|0;c[oc>>2]=c[uc>>2];c[oc+4>>2]=nc;break}}if(pc){nc=Bc*15|0;oc=yc+nc|0;uc=c[oc>>2]|0;Cc=c[oc+4>>2]|0;if(tc){oc=qc+(jc*96|0)+32|0;c[oc>>2]=uc;c[oc+4>>2]=Cc;oc=nc+8|0;mc=yc+oc|0;wc=c[mc+4>>2]|0;lc=qc+(jc*96|0)+40|0;c[lc>>2]=c[mc>>2];c[lc+4>>2]=wc;wc=zc+nc|0;lc=c[wc+4>>2]|0;mc=qc+(jc*96|0)+48|0;c[mc>>2]=c[wc>>2];c[mc+4>>2]=lc;lc=zc+oc|0;oc=c[lc+4>>2]|0;mc=qc+(jc*96|0)+56|0;c[mc>>2]=c[lc>>2];c[mc+4>>2]=oc;break}else{oc=qc+(jc*96|0)+16|0;c[oc>>2]=uc;c[oc+4>>2]=Cc;Cc=zc+nc|0;nc=c[Cc+4>>2]|0;oc=qc+(jc*96|0)+24|0;c[oc>>2]=c[Cc>>2];c[oc+4>>2]=nc;break}}else{nc=Bc*7|0;oc=yc+nc|0;Cc=c[oc>>2]|0;uc=c[oc+4>>2]|0;if(tc){tc=qc+(jc*96|0)+32|0;c[tc>>2]=Cc;c[tc+4>>2]=uc;tc=nc+8|0;oc=yc+tc|0;mc=c[oc+4>>2]|0;lc=qc+(jc*96|0)+40|0;c[lc>>2]=c[oc>>2];c[lc+4>>2]=mc;mc=zc+nc|0;lc=c[mc+4>>2]|0;oc=qc+(jc*96|0)+48|0;c[oc>>2]=c[mc>>2];c[oc+4>>2]=lc;lc=zc+tc|0;tc=c[lc+4>>2]|0;oc=qc+(jc*96|0)+56|0;c[oc>>2]=c[lc>>2];c[oc+4>>2]=tc;break}else{tc=qc+(jc*96|0)+16|0;c[tc>>2]=Cc;c[tc+4>>2]=uc;uc=zc+nc|0;nc=c[uc+4>>2]|0;tc=qc+(jc*96|0)+24|0;c[tc>>2]=c[uc>>2];c[tc+4>>2]=nc;break}}}}while(0);pc=c[G>>2]|0;rc=c[F>>2]|0;vc=pc-(rc<<c[T>>2])|0;nc=pc-1|0;tc=(c[j>>2]|0)==0;do{if(tc){Hc=vc;Ic=nc;Jc=nc}else{uc=c[J>>2]|0;jc=c[uc+(nc<<2)>>2]&128;qc=ic&128;if((c[i>>2]&1|0)!=0){Hc=vc;Ic=nc-((jc|0)==(qc|0)?0:rc)|0;Jc=nc;break}if((qc|0)==0){Kc=vc}else{Kc=(((c[uc+(vc<<2)>>2]|0)>>>7&1)-1&rc)+vc|0}Hc=Kc;Ic=nc;Jc=((jc|0)==(qc|0)?0:rc)+nc|0}}while(0);c[W>>2]=Hc;c[X>>2]=Ic;c[Y>>2]=Jc;nc=c[Z>>2]|0;vc=c[_>>2]|0;qc=a[vc+pc|0]|0;do{if((qc|0)>(nc|0)){Gc=58}else{jc=(Ic|0)<0;if(!jc){if((qc+1+(a[vc+Ic|0]|0)>>1|0)>(nc|0)){Gc=58;break}}if((Hc|0)>=0){if((qc+1+(a[vc+Hc|0]|0)>>1|0)>(nc|0)){Gc=58;break}}if(tc){break}if(!jc){if((qc+1+(a[vc+Jc|0]|0)>>1|0)>(nc|0)){Gc=58;break}}if((Hc|0)<(rc|0)){break}if((qc+1+(a[vc+(Hc-rc)|0]|0)>>1|0)>(nc|0)){Gc=58}}}while(0);do{if((Gc|0)==58){Gc=0;nc=c[J>>2]|0;rc=c[nc+(Hc<<2)>>2]|0;qc=c[nc+(Ic<<2)>>2]|0;jc=c[nc+(Jc<<2)>>2]|0;nc=c[H>>2]|0;uc=nc+(Hc<<1)|0;Cc=b[uc>>1]|0;if((c[r>>2]|0)==2){oc=c[I>>2]|0;lc=(e[nc+(Jc<<1)>>1]|0)==(oc|0);Lc=(Cc&65535|0)==(oc|0)?rc:0;Mc=lc?qc:0;Nc=lc?jc:0}else{lc=(b[nc+(Jc<<1)>>1]|0)==-1;Lc=Cc<<16>>16==-1?0:rc;Mc=lc?0:qc;Nc=lc?0:jc}c[$>>2]=Lc;c[aa>>2]=Mc;c[ba>>2]=Nc;do{if((ic&7|0)==0){jc=c[da>>2]|0;lc=(ic&376|0)==0;do{if(!lc){if((Lc&12288|0)==0){mrc(Pb|0,0,16)|0;c[Ob>>2]=-1}else{qc=(c[(c[Va>>2]|0)+(Hc<<2)>>2]|0)+(jc*3|0)|0;rc=Hc<<2;oc=Cc&15;mc=(c[Da>>2]|0)!=0?20:2;wc=c[Hb>>2]|0;Ec=wc+(qc<<2)|0;sc=c[Ec+4>>2]|0;c[Yb>>2]=c[Ec>>2];c[Yb+4>>2]=sc;sc=wc+(qc<<2)+8|0;qc=c[sc+4>>2]|0;c[Mb>>2]=c[sc>>2];c[Mb+4>>2]=qc;qc=c[Gb>>2]|0;sc=c[f+412944+(oc<<9)+((a[qc+(rc|2)|0]|0)+mc<<2)>>2]&255;a[Zb]=sc;a[Nb]=sc;sc=c[f+412944+(oc<<9)+((a[qc+(rc|3)|0]|0)+mc<<2)>>2]&255;a[_b]=sc;a[$b]=sc}if(((Mc^ic)&128|0)!=0){break}if((Mc&12288|0)==0){c[Qb>>2]=0;c[Rb>>2]=0;c[Sb>>2]=0;c[Tb>>2]=0;a[Ub]=-1;a[Vb]=-1;a[Wb]=-1;a[Xb]=-1;break}else{sc=(c[(c[Va>>2]|0)+(Ic<<2)>>2]|0)+3|0;mc=Ic<<2;rc=b[nc+(Ic<<1)>>1]&15;qc=(c[Da>>2]|0)!=0?20:2;oc=c[Hb>>2]|0;c[Qb>>2]=c[oc+(sc<<2)>>2];c[Rb>>2]=c[oc+(sc+jc<<2)>>2];c[Sb>>2]=c[oc+(sc+(jc<<1)<<2)>>2];c[Tb>>2]=c[oc+(sc+(jc*3|0)<<2)>>2];sc=c[Gb>>2]|0;oc=c[f+412944+(rc<<9)+((a[sc+(mc|1)|0]|0)+qc<<2)>>2]&255;a[Wb]=oc;a[Xb]=oc;oc=c[f+412944+(rc<<9)+((a[sc+(mc|3)|0]|0)+qc<<2)>>2]&255;a[Ub]=oc;a[Vb]=oc;break}}}while(0);if((ic&12288|0)==0){mrc(ja|0,0,16)|0;mrc(ka|0,0,16)|0;mrc(la|0,0,16)|0;mrc(ma|0,0,16)|0;c[ia>>2]=-1;c[na>>2]=-1;c[oa>>2]=-1;c[pa>>2]=-1}else{oc=pc<<2;qc=c[Gb>>2]|0;mc=c[I>>2]&15;sc=(c[Da>>2]|0)!=0?20:2;rc=(c[f+412944+(mc<<9)+((a[qc+(oc|1)|0]|0)+sc<<2)>>2]<<16&16711680|c[f+412944+(mc<<9)+(sc+(a[qc+oc|0]|0)<<2)>>2]&255)*257|0;wc=(c[f+412944+(mc<<9)+((a[qc+(oc|3)|0]|0)+sc<<2)>>2]<<16&16711680|c[f+412944+(mc<<9)+((a[qc+(oc|2)|0]|0)+sc<<2)>>2]&255)*257|0;c[ia>>2]=rc;c[na>>2]=rc;c[oa>>2]=wc;c[pa>>2]=wc;wc=(ca(jc<<2,c[i>>2]|0)|0)+(c[M>>2]<<2)|0;rc=c[Hb>>2]|0;sc=rc+(wc<<2)|0;oc=c[sc+4>>2]|0;c[Ib>>2]=c[sc>>2];c[Ib+4>>2]=oc;oc=rc+((wc|2)<<2)|0;sc=c[oc+4>>2]|0;c[ea>>2]=c[oc>>2];c[ea+4>>2]=sc;sc=wc+jc|0;oc=rc+(sc<<2)|0;qc=c[oc+4>>2]|0;c[Jb>>2]=c[oc>>2];c[Jb+4>>2]=qc;qc=rc+(sc+2<<2)|0;sc=c[qc+4>>2]|0;c[fa>>2]=c[qc>>2];c[fa+4>>2]=sc;sc=wc+(jc<<1)|0;qc=rc+(sc<<2)|0;oc=c[qc+4>>2]|0;c[Kb>>2]=c[qc>>2];c[Kb+4>>2]=oc;oc=rc+(sc+2<<2)|0;sc=c[oc+4>>2]|0;c[ga>>2]=c[oc>>2];c[ga+4>>2]=sc;sc=wc+(jc*3|0)|0;wc=rc+(sc<<2)|0;oc=c[wc+4>>2]|0;c[Lb>>2]=c[wc>>2];c[Lb+4>>2]=oc;oc=rc+(sc+2<<2)|0;sc=c[oc+4>>2]|0;c[ha>>2]=c[oc>>2];c[ha+4>>2]=sc}do{if((c[L>>2]|0)==2){do{if(!lc){if((Lc&49152|0)==0){mrc(Ma|0,0,16)|0;c[La>>2]=-1}else{sc=(c[(c[Va>>2]|0)+(Hc<<2)>>2]|0)+(jc*3|0)|0;oc=Hc<<2;rc=f+412944+((b[uc>>1]&15)<<9)+(((c[Da>>2]|0)!=0?20:2)<<2)|0;wc=c[Ea>>2]|0;qc=wc+(sc<<2)|0;mc=c[qc+4>>2]|0;c[Wa>>2]=c[qc>>2];c[Wa+4>>2]=mc;mc=wc+(sc<<2)+8|0;sc=c[mc+4>>2]|0;c[Ja>>2]=c[mc>>2];c[Ja+4>>2]=sc;sc=c[Ca>>2]|0;mc=c[rc+256+(a[sc+(oc|2)|0]<<2)>>2]&255;a[Xa]=mc;a[Ka]=mc;mc=c[rc+256+(a[sc+(oc|3)|0]<<2)>>2]&255;a[Ya]=mc;a[Za]=mc}if(((Mc^ic)&128|0)!=0){break}if((Mc&49152|0)==0){c[Na>>2]=0;c[Oa>>2]=0;c[Pa>>2]=0;c[Qa>>2]=0;a[Ra]=-1;a[Sa]=-1;a[Ta]=-1;a[Ua]=-1;break}else{mc=(c[(c[Va>>2]|0)+(Ic<<2)>>2]|0)+3|0;oc=Ic<<2;sc=f+412944+((b[nc+(Ic<<1)>>1]&15)<<9)+(((c[Da>>2]|0)!=0?20:2)<<2)|0;rc=c[Ea>>2]|0;c[Na>>2]=c[rc+(mc<<2)>>2];c[Oa>>2]=c[rc+(mc+jc<<2)>>2];c[Pa>>2]=c[rc+(mc+(jc<<1)<<2)>>2];c[Qa>>2]=c[rc+(mc+(jc*3|0)<<2)>>2];mc=c[Ca>>2]|0;rc=c[sc+256+(a[mc+(oc|1)|0]<<2)>>2]&255;a[Ta]=rc;a[Ua]=rc;rc=c[sc+256+(a[mc+(oc|3)|0]<<2)>>2]&255;a[Ra]=rc;a[Sa]=rc;break}}}while(0);if((ic&49152|0)==0){mrc(va|0,0,16)|0;mrc(wa|0,0,16)|0;mrc(xa|0,0,16)|0;mrc(ya|0,0,16)|0;c[ua>>2]=-1;c[za>>2]=-1;c[Aa>>2]=-1;c[Ba>>2]=-1;break}else{rc=pc<<2;oc=c[Ca>>2]|0;mc=f+412944+((c[I>>2]&15)<<9)+(((c[Da>>2]|0)!=0?20:2)<<2)|0;sc=(c[mc+256+(a[oc+(rc|1)|0]<<2)>>2]<<16&16711680|c[mc+256+(a[oc+rc|0]<<2)>>2]&255)*257|0;wc=(c[mc+256+(a[oc+(rc|3)|0]<<2)>>2]<<16&16711680|c[mc+256+(a[oc+(rc|2)|0]<<2)>>2]&255)*257|0;c[ua>>2]=sc;c[za>>2]=sc;c[Aa>>2]=wc;c[Ba>>2]=wc;wc=(ca(jc<<2,c[i>>2]|0)|0)+(c[M>>2]<<2)|0;sc=c[Ea>>2]|0;rc=sc+(wc<<2)|0;oc=c[rc+4>>2]|0;c[Fa>>2]=c[rc>>2];c[Fa+4>>2]=oc;oc=sc+((wc|2)<<2)|0;rc=c[oc+4>>2]|0;c[qa>>2]=c[oc>>2];c[qa+4>>2]=rc;rc=wc+jc|0;oc=sc+(rc<<2)|0;mc=c[oc+4>>2]|0;c[Ga>>2]=c[oc>>2];c[Ga+4>>2]=mc;mc=sc+(rc+2<<2)|0;rc=c[mc+4>>2]|0;c[ra>>2]=c[mc>>2];c[ra+4>>2]=rc;rc=wc+(jc<<1)|0;mc=sc+(rc<<2)|0;oc=c[mc+4>>2]|0;c[Ha>>2]=c[mc>>2];c[Ha+4>>2]=oc;oc=sc+(rc+2<<2)|0;rc=c[oc+4>>2]|0;c[sa>>2]=c[oc>>2];c[sa+4>>2]=rc;rc=wc+(jc*3|0)|0;wc=sc+(rc<<2)|0;oc=c[wc+4>>2]|0;c[Ia>>2]=c[wc>>2];c[Ia+4>>2]=oc;oc=sc+(rc+2<<2)|0;rc=c[oc+4>>2]|0;c[ta>>2]=c[oc>>2];c[ta+4>>2]=rc;break}}}while(0);jc=c[_a>>2]|0;c[ab>>2]=c[jc+(pc*48|0)>>2];c[cb>>2]=c[jc+(pc*48|0)+4>>2];c[eb>>2]=c[jc+(pc*48|0)+8>>2];c[gb>>2]=c[jc+(pc*48|0)+12>>2];lc=c[hb>>2]|0;rc=b[lc+(pc<<1)>>1]|0;c[ib>>2]=rc&65535;if((Lc|0)!=0){c[Fb>>2]=c[jc+(Hc*48|0)+12>>2]}if((Mc|0)!=0){a[Ab]=a[jc+(Ic*48|0)+3|0]|0;a[zb]=a[jc+(Ic*48|0)+7|0]|0;a[yb]=a[jc+(Ic*48|0)+11|0]|0;a[xb]=a[jc+(Ic*48|0)+15|0]|0}if((c[jb>>2]|0)!=0){break}if((c[kb>>2]|0)==0){break}if((Lc&16777216|0)!=0){jc=lc+(Hc<<1)|0;oc=(e[jc>>1]|0)>>>12&4;a[Bb]=oc;a[Cb]=oc;oc=(e[jc>>1]|0)>>>12&8;a[Db]=oc;a[Eb]=oc}if((Mc&16777216|0)!=0){oc=(e[lc+(Ic<<1)>>1]|0)>>>12&2;a[zb]=oc;a[Ab]=oc}if((Nc&16777216|0)!=0){oc=(e[lc+(Jc<<1)>>1]|0)>>>12&8;a[xb]=oc;a[yb]=oc}if((ic&16777216|0)==0){break}oc=(rc&65535)>>>12&255;rc=oc&1;a[lb]=rc;a[bb]=rc;a[mb]=rc;a[$a]=rc;rc=oc&2;a[nb]=rc;a[ob]=rc;a[pb]=rc;a[qb]=rc;rc=oc&4;a[rb]=rc;a[fb]=rc;a[sb]=rc;a[db]=rc;rc=oc&8;a[tb]=rc;a[ub]=rc;a[vb]=rc;a[wb]=rc}}while(0);nc=vc+hc|0;c[ac>>2]=d[(a[nc]|0)+(f+7876)|0]|0;c[bc>>2]=d[(a[nc]|0)+(f+7964)|0]|0;if(tc){oia(f,ec,fc,xc,yc,zc,Ac,Bc);break}else{pia(f,ec,fc,xc,yc,zc,Ac,Bc);break}}}while(0);tc=fc+1|0;if((tc|0)>(l|0)){break a}fc=tc;gc=c[j>>2]|0}}}while(0);gc=ec+1|0;fc=c[j>>2]|0;if((gc|0)<(h|0)){ec=gc;g=fc}else{s=fc;break}}c[m>>2]=n;t=f+427376|0;c[t>>2]=h;u=l-s|0;c[i>>2]=u;v=f+4792|0;w=c[v>>2]|0;x=f+7876+w|0;y=a[x]|0;z=y&255;A=f+4756|0;c[A>>2]=z;B=f+7964+w|0;C=a[B]|0;D=C&255;E=f+4760|0;c[E>>2]=D;return}function Hha(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+177100|0;d=(c[b>>2]|0)!=3|0;e=c[a+427380>>2]>>d<<4;f=c[a+427396>>2]<<4>>d;d=c[a+177088>>2]|0;g=16<<d;h=20<<d;if((c[a+427420>>2]|0)==0){i=e;j=g}else{i=e-h|0;j=((e+g|0)<(f|0)?0:h)+g|0}if((i|0)>=(f|0)){return}if((i+j|0)<0){return}g=f-i|0;f=(i|0)<0;h=((j|0)>(g|0)?g:j)+(f?i:0)|0;j=f?0:i;bha(a,j,h);if((c[a+4796>>2]|0)!=0){return}if((c[a+2388>>2]|0)!=0){return}L5a((c[a+2524>>2]|0)+1496|0,j-1+h|0,(c[b>>2]|0)==2|0);return}function Iha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+7308>>2]|0;a:do{switch(e|0){case 14:{f=c[a+6136>>2]|0;if((f|0)==3){g=(c[(c[a>>2]|0)+392>>2]|0)==0?316:312;break a}else if((f|0)==2){g=308;break a}else{g=304;break a}break};case 12:{f=c[a+6136>>2]|0;if((f|0)==3){g=(c[(c[a>>2]|0)+392>>2]|0)==0?314:310;break a}else if((f|0)==2){g=306;break a}else{g=302;break a}break};case 10:{f=c[a+6136>>2]|0;if((f|0)==3){g=(c[(c[a>>2]|0)+392>>2]|0)==0?86:78;break a}else if((f|0)==2){g=74;break a}else{g=72;break a}break};case 9:{f=c[a+6136>>2]|0;if((f|0)==3){g=(c[(c[a>>2]|0)+392>>2]|0)==0?84:76;break a}else if((f|0)==2){g=80;break a}else{g=70;break a}break};case 8:{f=c[a+6136>>2]|0;if((f|0)==3){h=a|0;j=c[h>>2]|0;k=c[j+392>>2]|0;if((k|0)==8){KIb(j,24,2621872,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=c[h>>2]|0}else if((k|0)==0){KIb(j,48,2623304,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;g=82;break a}else{m=j}g=(c[m+396>>2]|0)==2?14:5;break a}j=c[a>>2]|0;if((f|0)==2){g=(c[j+396>>2]|0)==2?13:4;break a}f=c[(c[j+12>>2]|0)+24>>2]|0;if((f|0)==0){n=(c[j+396>>2]|0)==2?1144320:1144328}else{n=f}f=j+140|0;b:do{if((b|0)==0){k=0;while(1){h=c[n+(k<<2)>>2]|0;if((h|0)==-1){break b}if((h|0)==(c[f>>2]|0)){g=h;break a}else{k=k+1|0}}}else{k=0;while(1){if((c[n+(k<<2)>>2]|0)==-1){break b}k=k+1|0}}}while(0);g=I5a(j,n)|0;break};default:{KIb(c[a>>2]|0,16,2619256,(l=i,i=i+8|0,c[l>>2]=e,l)|0);i=l;g=-1094995529}}}while(0);i=d;return g|0}function Jha(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;g=d|0;h=d+6224|0;j=(c[g>>2]|0)+224|0;k=c[h+4>>2]|0;c[j>>2]=c[h>>2];c[j+4>>2]=k;k=c[g>>2]|0;if((c[k+228>>2]|0)==0){KIb(0,0,2122224,(l=i,i=i+24|0,c[l>>2]=2105320,c[l+8>>2]=2617208,c[l+16>>2]=3297,l)|0);i=l;Hd();return 0}tKb(c[k+140>>2]|0,d+4784|0,d+4788|0)|0;if((c[d+6256>>2]|0)!=0){k=yrc(c[d+6264>>2]|0,0,(c[d+427372>>2]|0)>>>0<44>>>0|0)|0;j=c[g>>2]|0;xKb(j+104|0,j+108|0,c[d+6260>>2]|0,0,k,G,1073741824,0)|0}k=E5a(c[g>>2]|0)|0;c[(c[g>>2]|0)+712>>2]=k;if((e|0)!=0){hha(d,0)}c[d+177104>>2]=0;c[d+572412>>2]=1;e=0;while(1){k=a[144+e|0]|0;a[d+426796+e|0]=k<<2&12|(k&255)>>>2;k=a[1237336+e|0]|0;a[d+426940+e|0]=k<<2&12|(k&255)>>>2;k=e+1|0;if((k|0)<16){e=k}else{m=0;break}}do{e=a[1242080+m|0]|0;a[d+426812+m|0]=e<<3&56|(e&255)>>>3;e=a[8+m|0]|0;a[d+426876+m|0]=e<<3&56|(e&255)>>>3;e=a[1237264+m|0]|0;a[d+426956+m|0]=e<<3&56|(e&255)>>>3;e=a[1237192+m|0]|0;a[d+427020+m|0]=e<<3&56|(e&255)>>>3;m=m+1|0;}while((m|0)<64);m=d+427084|0;if((c[d+6140>>2]|0)==0){nrc(m|0,d+426796|0,16)|0;nrc(d+427100|0,d+426812|0,64)|0;nrc(d+427164|0,d+426876|0,64)|0;nrc(d+427228|0,d+426940|0,16)|0;nrc(d+427244|0,d+426956|0,64)|0;nrc(d+427308|0,d+427020|0,64)|0}else{nrc(m|0,144,16)|0;nrc(d+427100|0,1242080,64)|0;nrc(d+427164|0,8,64)|0;nrc(d+427228|0,1237336,16)|0;nrc(d+427244|0,1237264,64)|0;nrc(d+427308|0,1237192,64)|0}m=fha(d)|0;if((m|0)<0){KIb(c[g>>2]|0,16,2644384,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;n=m;i=f;return n|0}m=d+427396|0;e=c[m>>2]|0;if((e|0)>-1){o=1;p=e}else{KIb(c[g>>2]|0,24,2642632,(l=i,i=i+16|0,c[l>>2]=1,c[l+8>>2]=e,l)|0);i=l;o=e;p=c[m>>2]|0}c[d+572384>>2]=o;o=d+427404|0;e=c[o>>2]|0;k=ca(e,p)|0;j=d+427400|0;h=c[j>>2]|0;q=ca(h<<1|1,p<<1|1)|0;r=ca(e,p+1|0)|0;p=q+(r<<1)|0;e=pJb(h*96|0)|0;c[d+5176>>2]=e;h=(c[j>>2]|0)*96|0;do{if((e|0)==0){if((h|0)==0){s=0;t=20;break}KIb(c[g>>2]|0,16,2247712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l}else{s=h;t=20}}while(0);a:do{if((t|0)==20){h=pJb(s)|0;c[d+5180>>2]=h;e=c[j>>2]|0;do{if((h|0)==0){if((e*96|0|0)==0){break}KIb(c[g>>2]|0,16,2247712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break a}}while(0);a[d+5704|0]=-2;a[d+5696|0]=-2;a[d+5688|0]=-2;a[d+5664|0]=-2;a[d+5656|0]=-2;a[d+5648|0]=-2;c[d+2352>>2]=c[g>>2];c[d+2356>>2]=d+1108;c[d+2512>>2]=72;c[d+2516>>2]=d;c[d+2500>>2]=1;h=d+427408|0;u=c[h>>2]|0;c[d+2364>>2]=u;c[d+2368>>2]=e;c[d+2372>>2]=c[m>>2];c[d+2376>>2]=c[o>>2];c[d+2380>>2]=e<<1|1;v=pJb((u<<2)+4|0)|0;u=v;c[d+2360>>2]=u;do{if((v|0)==0){if((c[h>>2]&1073741823|0)==1073741823){break}KIb(c[g>>2]|0,16,2247712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break a}}while(0);h=c[m>>2]|0;v=c[j>>2]|0;if((h|0)>0){e=0;do{if((v|0)>0){w=ca(c[o>>2]|0,e)|0;x=0;do{c[u+((ca(v,e)|0)+x<<2)>>2]=w+x;x=x+1|0;}while((x|0)<(v|0))}e=e+1|0;}while((e|0)<(h|0))}c[u+((ca(h,v)|0)<<2)>>2]=(ca(c[o>>2]|0,h-1|0)|0)+v;e=pJb(k)|0;c[d+2392>>2]=e;x=(k|0)==0;if(!((e|0)!=0|x)){KIb(c[g>>2]|0,16,2247712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}e=hJb(k)|0;c[d+2416>>2]=e;if(!((e|0)!=0|x)){KIb(c[g>>2]|0,16,2247712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}mrc(e|0,1,k|0)|0;e=k+2|0;x=pJb(e)|0;c[d+2412>>2]=x;if(!((x|0)!=0|(e|0)==0)){KIb(c[g>>2]|0,16,2247712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}e=hJb(ca(c[o>>2]|0,c[m>>2]|0)|0)|0;c[d+2396>>2]=e;do{if((e|0)==0){if((ca(c[o>>2]|0,c[m>>2]|0)|0)==0){break}KIb(c[g>>2]|0,16,2247712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break a}}while(0);e=p<<1;v=pJb(e)|0;h=v;c[d+572688>>2]=h;if(!((v|0)!=0|(e|0)==0)){KIb(c[g>>2]|0,16,2247712,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;break}c[d+2400>>2]=h+((c[j>>2]<<1)+2<<1);e=q+1+(c[o>>2]|0)|0;c[d+2404>>2]=h+(e<<1);c[d+2408>>2]=h+(e+r<<1);if((p|0)>0){e=0;do{b[h+(e<<1)>>1]=1024;e=e+1|0;}while((e|0)<(p|0))}c[d+4812>>2]=1;n=0;i=f;return n|0}}while(0);KIb(c[g>>2]|0,16,2636312,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;n=-12;i=f;return n|0}function Kha(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+16|0;e=b|0;f=c[a+4752>>2]|0;g=e|0;c[g>>2]=1<<(c[a+7308>>2]|0)-1;h=1<<(c[a+7312>>2]|0)-1;c[e+4>>2]=h;c[e+8>>2]=h;c[e+12>>2]=-1;e=a|0;if((N5a(c[e>>2]|0)|0)==0){KIb(c[e>>2]|0,16,2114816,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=b;return k|0}h=a+2520|0;l=0;do{m=c[h>>2]|0;n=m+(l*2224|0)|0;do{if((c[m+(l*2224|0)+360>>2]|0)!=0){if((c[m+(l*2224|0)+2192>>2]|0)!=0){break}zha(a,n)}}while(0);l=l+1|0;}while((l|0)<36);l=a+2524|0;c[l>>2]=0;n=c[h>>2]|0;m=0;while(1){if((c[n+(m*2224|0)+360>>2]|0)==0){o=m;break}if((c[n+(m*2224|0)+2188>>2]|0)!=0){if((c[n+(m*2224|0)+2192>>2]&4|0)==0){o=m;break}}p=m+1|0;if((p|0)<36){m=p}else{o=p;break}}do{if((o|0)==36){q=-1094995529}else{m=n+(o*2224|0)+2188|0;if((c[m>>2]|0)!=0){c[m>>2]=0;zha(a,n+(o*2224|0)|0)}if((o|0)<0){q=o;break}m=c[h>>2]|0;p=m+(o*2224|0)|0;r=a+177100|0;if((c[a+4796>>2]|0)==0){s=c[r>>2]|0}else{s=0}t=m+(o*2224|0)+2192|0;c[t>>2]=s;u=a+4804|0;v=c[u>>2]|0;c[u>>2]=v+1;u=p|0;c[m+(o*2224|0)+160>>2]=v;c[m+(o*2224|0)+2164>>2]=(c[r>>2]|0)!=3;c[m+(o*2224|0)+84>>2]=0;c[m+(o*2224|0)+1620>>2]=0;c[m+(o*2224|0)+2200>>2]=0;c[m+(o*2224|0)+2204>>2]=0;if((c[p>>2]|0)!=0){KIb(0,0,2122224,(j=i,i=i+24|0,c[j>>2]=2108008,c[j+8>>2]=2617208,c[j+16>>2]=434,j)|0);i=j;Hd();return 0}r=m+(o*2224|0)+1496|0;c[r>>2]=u;v=J5a(c[e>>2]|0,r,(c[t>>2]|0)!=0|0)|0;a:do{if((v|0)<0){w=v}else{t=a+4776|0;c[t>>2]=c[m+(o*2224|0)+32>>2];r=a+4780|0;c[r>>2]=c[m+(o*2224|0)+36>>2];c[m+(o*2224|0)+2208>>2]=c[a+6200>>2];c[m+(o*2224|0)+2216>>2]=c[a+6212>>2];c[m+(o*2224|0)+2212>>2]=c[a+6204>>2];x=c[(c[e>>2]|0)+712>>2]|0;do{if((x|0)!=0){y=m+(o*2224|0)+1600|0;if((c[y>>2]|0)!=0){KIb(0,0,2122224,(j=i,i=i+24|0,c[j>>2]=2106648,c[j+8>>2]=2617208,c[j+16>>2]=450,j)|0);i=j;Hd();return 0}z=c[x+36>>2]|0;if((z|0)==0){break}A=dGb(z)|0;c[m+(o*2224|0)+1596>>2]=A;if((A|0)==0){k=-12;i=b;return k|0}else{c[y>>2]=c[A+4>>2];break}}}while(0);x=a+572692|0;A=c[x>>2]|0;b:do{if((A|0)==0){y=a+427404|0;z=c[y>>2]|0;B=c[a+427396>>2]|0;C=(ca(B+1|0,z)|0)+1|0;D=ca(B<<4,c[a+427400>>2]<<2|1)|0;c[x>>2]=kGb(C+z|0,792)|0;E=a+572696|0;c[E>>2]=kGb(C+(c[y>>2]|0)<<2,792)|0;y=a+572700|0;c[y>>2]=kGb(D+16|0,792)|0;D=kGb(ca(z<<2,B)|0,792)|0;B=a+572704|0;c[B>>2]=D;z=c[x>>2]|0;do{if((z|0)!=0){if((c[E>>2]|0)==0){break}if(!((c[y>>2]|0)==0|(D|0)==0)){F=0;G=z;H=E;break b}}}while(0);lGb(x);lGb(E);lGb(y);lGb(B);w=-12;break a}else{F=v;G=A;H=a+572696|0}}while(0);A=m+(o*2224|0)+1508|0;c[A>>2]=mGb(G)|0;x=mGb(c[H>>2]|0)|0;c[m+(o*2224|0)+1532>>2]=x;z=c[A>>2]|0;if((z|0)==0|(x|0)==0){w=F;break}A=c[a+427404>>2]<<1|1;c[m+(o*2224|0)+1536>>2]=(c[x+4>>2]|0)+(A<<2);c[m+(o*2224|0)+1512>>2]=(c[z+4>>2]|0)+A;A=a+572700|0;z=a+572704|0;x=m+(o*2224|0)+1516|0;c[x>>2]=mGb(c[A>>2]|0)|0;D=mGb(c[z>>2]|0)|0;c[m+(o*2224|0)+1548>>2]=D;C=c[x>>2]|0;if((C|0)==0|(D|0)==0){w=F;break}c[m+(o*2224|0)+1524>>2]=(c[C+4>>2]|0)+16;c[m+(o*2224|0)+1556>>2]=c[D+4>>2];D=m+(o*2224|0)+1520|0;c[D>>2]=mGb(c[A>>2]|0)|0;A=mGb(c[z>>2]|0)|0;c[m+(o*2224|0)+1552>>2]=A;z=c[D>>2]|0;if((z|0)==0|(A|0)==0){w=F;break}c[m+(o*2224|0)+1528>>2]=(c[z+4>>2]|0)+16;c[m+(o*2224|0)+1560>>2]=c[A+4>>2];do{if((c[a+572480>>2]|0)==0){A=c[e>>2]|0;if((c[A+712>>2]|0)!=0){break}if((c[(c[A+12>>2]|0)+16>>2]&128|0)!=0){break}J4a(u,g)}}while(0);c[l>>2]=p;A=a+2528|0;zha(a,A);c[a+2484>>2]=0;z=c[l>>2]|0;if((c[a+2888>>2]|0)!=0){KIb(0,0,2122224,(j=i,i=i+24|0,c[j>>2]=2111272,c[j+8>>2]=2617208,c[j+16>>2]=319,j)|0);i=j;Hd();return 0}if((c[z+360>>2]|0)==0){KIb(0,0,2122224,(j=i,i=i+24|0,c[j>>2]=2109592,c[j+8>>2]=2617208,c[j+16>>2]=320,j)|0);i=j;Hd();return 0}D=z+1496|0;c[D>>2]=z;C=a+4024|0;c[C>>2]=A;x=G5a(C,D)|0;if((x|0)<0){zha(a,A);k=x;i=b;return k|0}x=a+4036|0;c[x>>2]=eGb(c[z+1508>>2]|0)|0;D=eGb(c[z+1532>>2]|0)|0;c[a+4060>>2]=D;c:do{if((c[x>>2]|0)==0|(D|0)==0){I=56}else{c[a+4040>>2]=c[z+1512>>2];c[a+4064>>2]=c[z+1536>>2];C=a+4044|0;c[C>>2]=eGb(c[z+1516>>2]|0)|0;J=eGb(c[z+1548>>2]|0)|0;c[a+4076>>2]=J;if((c[C>>2]|0)==0|(J|0)==0){I=56;break}c[a+4052>>2]=c[z+1524>>2];c[a+4084>>2]=c[z+1556>>2];J=a+4048|0;c[J>>2]=eGb(c[z+1520>>2]|0)|0;C=eGb(c[z+1552>>2]|0)|0;c[a+4080>>2]=C;if((c[J>>2]|0)==0|(C|0)==0){I=56;break}c[a+4056>>2]=c[z+1528>>2];c[a+4088>>2]=c[z+1560>>2];do{if((c[z+1600>>2]|0)!=0){C=eGb(c[z+1596>>2]|0)|0;c[a+4124>>2]=C;if((C|0)==0){zha(a,A);break c}else{c[a+4128>>2]=c[C+4>>2];break}}}while(0);c[a+4132>>2]=c[z+1604>>2];c[a+4136>>2]=c[z+1608>>2];nrc(a+4160|0,z+1632|0,512)|0;B=a+4672|0;y=z+2144|0;c[B>>2]=c[y>>2];c[B+4>>2]=c[y+4>>2];c[B+8>>2]=c[y+8>>2];c[B+12>>2]=c[y+12>>2];c[a+4140>>2]=c[z+1612>>2];c[a+4144>>2]=c[z+1616>>2];c[a+4148>>2]=c[z+1620>>2];c[a+4152>>2]=c[z+1624>>2];c[a+4156>>2]=c[z+1628>>2];c[a+4688>>2]=c[z+2160>>2];c[a+4692>>2]=c[z+2164>>2];c[a+4716>>2]=c[z+2188>>2];c[a+4720>>2]=c[z+2192>>2];c[a+4736>>2]=c[z+2208>>2];c[a+4740>>2]=c[z+2212>>2];c[a+4744>>2]=c[z+2216>>2];c[a+4728>>2]=c[z+2200>>2];c[a+4732>>2]=c[z+2204>>2]}}while(0);if((I|0)==56){zha(a,A)}xpb(a+2352|0);c[a+2492>>2]=0;c[a+2488>>2]=0;z=0;while(1){D=(d[602328+z|0]|0)-12|0;x=(D<<2&28)<<f;y=D>>3;c[a+5716+(z<<2)>>2]=x+(ca(c[t>>2]<<2,y)|0);c[a+5716+(z+48<<2)>>2]=x+(ca(c[t>>2]<<3,y)|0);y=z+1|0;if((y|0)<16){z=y}else{K=0;break}}do{z=(d[602328+K|0]|0)-12|0;t=(z<<2&28)<<f;A=z>>3;z=t+(ca(c[r>>2]<<2,A)|0)|0;c[a+5716+(K+32<<2)>>2]=z;c[a+5716+(K+16<<2)>>2]=z;z=t+(ca(c[r>>2]<<3,A)|0)|0;c[a+5716+(K+80<<2)>>2]=z;c[a+5716+(K+64<<2)>>2]=z;K=K+1|0;}while((K|0)<16);r=c[l>>2]|0;c[r+2192>>2]=0;c[r+1608>>2]=2147483647;c[r+1604>>2]=2147483647;c[a+571424>>2]=0;k=0;i=b;return k|0}}while(0);zha(a,p);k=(w|0)<0?w:-12;i=b;return k|0}}while(0);KIb(c[e>>2]|0,16,2113152,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=q;i=b;return k|0}function Lha(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=(b|0)<0;mrc(a+572484|0,0,16)|0;do{if(d){e=c[a+177100>>2]|0;if((e|0)==3){f=(c[a+2524>>2]|0)+1612|0}else{f=(c[a+2524>>2]|0)+1604+(e-1<<2)|0}e=c[f>>2]|0;g=c[a+199420>>2]|0;h=c[a+199424>>2]|0;if((g|0)!=1){i=e;j=0;k=g;l=h;break}if((h|0)!=1){i=e;j=0;k=1;l=h;break}if((c[a+177088>>2]|0)!=0){i=e;j=0;k=g;l=1;break}if(((c[a+307804>>2]|0)+(c[a+201052>>2]|0)|0)!=(e<<1|0)){i=e;j=0;k=g;l=1;break}c[a+177120>>2]=0;c[a+177124>>2]=0;return}else{i=c[(c[a+2524>>2]|0)+1604+(b<<2)>>2]|0;j=16;k=(c[a+199420>>2]<<1)+16|0;l=(c[a+199424>>2]<<1)+16|0}}while(0);c[a+177120>>2]=2;c[a+177124>>2]=2;c[a+177128>>2]=5;c[a+177132>>2]=5;if((j|0)>=(k|0)){return}f=(j|0)<(l|0);g=j;do{e=c[a+199440+(g*2224|0)+1612>>2]|0;if(f){h=a+199440+(g*2224|0)+1628|0;m=i-e|0;n=(m|0)<-128;o=(m|0)>127?127:m;m=j;do{do{if((c[h>>2]|0)==0){if((c[a+306192+(m*2224|0)+1628>>2]|0)!=0){p=32;break}q=(c[a+306192+(m*2224|0)+1612>>2]|0)-e|0;if((q|0)<-128){r=-128}else{s=(q|0)>127?127:q;if((s|0)==0){p=32;break}else{r=s}}s=(ca(((((r|0)>-1?r:-r|0)>>1)+16384|0)/(r|0)|0,n?-128:o)|0)+32>>8;if(!((s+64|0)>>>0<193>>>0)){p=32;break}p=64-s|0}else{p=32}}while(0);if(d){c[a+179440+(g*384|0)+(m<<3)+4>>2]=p;c[a+179440+(g*384|0)+(m<<3)>>2]=p}else{c[a+179440+(g*384|0)+(m<<3)+(b<<2)>>2]=p}m=m+1|0;}while((m|0)<(l|0))}g=g+1|0;}while((g|0)<(k|0));return}function Mha(a,d,e,f,g,h,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;l=i;c[a+427376>>2]=h;c[a+427380>>2]=j;k=a+427412|0;c[k>>2]=(ca(c[a+427404>>2]|0,j)|0)+h;mrc(a+5184|0,0,120)|0;h=(c[a+199420>>2]|0)>>>0>d>>>0?d:0;d=a+199440|0;if((c[d+(h*2224|0)>>2]|0)==0){KIb(c[a>>2]|0,48,2632912,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=0}else{n=h}if((c[d+(n*2224|0)+2192>>2]&3|0)==3){d=c[k>>2]<<2;k=c[a+4084>>2]|0;h=(n*257|0)&65535;b[k+d>>1]=h;b[k+(d|2)>>1]=h;h=ca(n,16843009)|0;c[a+5644>>2]=h;c[a+5652>>2]=h;c[a+5660>>2]=h;c[a+5668>>2]=h;h=c[g+4>>2]<<16|c[g>>2]&65535;c[a+5360>>2]=h;c[a+5364>>2]=h;c[a+5368>>2]=h;c[a+5372>>2]=h;c[a+5392>>2]=h;c[a+5396>>2]=h;c[a+5400>>2]=h;c[a+5404>>2]=h;c[a+5424>>2]=h;c[a+5428>>2]=h;c[a+5432>>2]=h;c[a+5436>>2]=h;c[a+5456>>2]=h;c[a+5460>>2]=h;c[a+5464>>2]=h;c[a+5468>>2]=h;c[a+177092>>2]=0;c[a+177096>>2]=0;mha(a);i=l;return}else{KIb(c[a>>2]|0,48,2630736,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;i=l;return}}function Nha(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[602328+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=e+6112|0;B=c[A>>2]|0;D=(ca(n<<1,B)|0)+(m<<1)|0;E=j+D|0;F=e+6116|0;G=(ca(c[F>>2]|0,n)|0)+m|0;H=k+G|0;I=l+G|0;G=(c[e+427376>>2]<<3)+m|0;J=e+427380|0;K=e+177092|0;L=c[K>>2]|0;M=(c[J>>2]>>L<<3)+n|0;if(y){N=p;O=o}else{P=d[602328+f|0]|0;Q=a[e+5632+P|0]|0;R=(b[e+5312+(P<<2)>>1]|0)+(G<<3)|0;S=(b[e+5312+(P<<2)+2>>1]|0)+(M<<3)|0;P=S<<2&12|R&3;T=R>>2;U=S>>2;V=(ca(U,B)|0)+T|0;W=c[e+199440+(Q*2224|0)>>2]|0;X=W+V|0;Y=c[e+427400>>2]|0;Z=Y<<4;_=c[e+427396>>2]<<4>>L;L=R&7;$=(L|0)==0?0:-3;aa=(S&7|0)==0?0:-3;do{if((T|0)<(-$|0)){z=58}else{if((U|0)<(-aa|0)){z=58;break}if((T+16|0)>($+Z|0)){z=58;break}if((U+16|0)>(_+aa|0)){z=58}else{ba=X;da=0;ea=B}}}while(0);if((z|0)==58){X=e+572684|0;Ve[c[e+4>>2]&127](c[X>>2]|0,W+(-2-(B<<1)+V)|0,B,B,21,21,T-2|0,U-2|0,Z,_);aa=c[A>>2]|0;ba=(c[X>>2]|0)+((aa<<1)+2)|0;da=1;ea=aa}aa=o+(P<<2)|0;ef[c[aa>>2]&4095](E,ba,ea);if((g|0)==0){ef[c[aa>>2]&4095](j+(D+i)|0,ba+i|0,c[A>>2]|0)}if((c[K>>2]|0)==0){fa=S;ga=da}else{aa=(1-(c[e+199440+(Q*2224|0)+2192>>2]|0)+(c[J>>2]&1)<<1)+S|0;X=aa>>3;if((X|0)<0){ha=1}else{ha=(X+8|0)>=(_>>1|0)|0}fa=aa;ga=ha|da}aa=R>>3;X=fa>>3;$=c[F>>2]|0;ia=(ca($,X)|0)+aa|0;ja=(c[e+199440+(Q*2224|0)+4>>2]|0)+ia|0;ka=(c[e+199440+(Q*2224|0)+8>>2]|0)+ia|0;if((ga|0)==0){ia=h>>1;la=fa&7;_e[p&511](H,ja,$,ia,L,la);ma=ka;na=ia;oa=la}else{la=e+4|0;ia=e+572684|0;pa=Y<<3;qa=_>>1;Ve[c[la>>2]&127](c[ia>>2]|0,ja,$,$,9,9,aa,X,pa,qa);$=h>>1;ja=fa&7;_e[p&511](H,c[ia>>2]|0,c[F>>2]|0,$,L,ja);ra=c[F>>2]|0;Ve[c[la>>2]&127](c[ia>>2]|0,ka,ra,ra,9,9,aa,X,pa,qa);ma=c[ia>>2]|0;na=$;oa=ja}_e[p&511](I,ma,c[F>>2]|0,na,L,oa);N=r;O=q}if(u){return}ja=d[602328+f|0]|0;$=a[e+5672+ja|0]|0;ia=(b[e+5472+(ja<<2)>>1]|0)+(G<<3)|0;qa=(b[e+5472+(ja<<2)+2>>1]|0)+(M<<3)|0;ja=qa<<2&12|ia&3;pa=ia>>2;X=qa>>2;aa=c[A>>2]|0;ra=(ca(X,aa)|0)+pa|0;ka=c[e+306192+($*2224|0)>>2]|0;la=ka+ra|0;sa=c[e+427400>>2]|0;ta=sa<<4;ua=c[e+427396>>2]<<4>>c[K>>2];va=ia&7;wa=(va|0)==0?0:-3;xa=(qa&7|0)==0?0:-3;do{if((pa|0)<(-wa|0)){z=74}else{if((X|0)<(-xa|0)){z=74;break}if((pa+16|0)>(ta+wa|0)){z=74;break}if((X+16|0)>(ua+xa|0)){z=74}else{ya=la;za=0;Aa=aa}}}while(0);if((z|0)==74){la=e+572684|0;Ve[c[e+4>>2]&127](c[la>>2]|0,ka+(-2-(aa<<1)+ra)|0,aa,aa,21,21,pa-2|0,X-2|0,ta,ua);xa=c[A>>2]|0;ya=(c[la>>2]|0)+((xa<<1)+2)|0;za=1;Aa=xa}xa=O+(ja<<2)|0;ef[c[xa>>2]&4095](E,ya,Aa);if((g|0)==0){ef[c[xa>>2]&4095](j+(D+i)|0,ya+i|0,c[A>>2]|0)}if((c[K>>2]|0)==0){Ba=qa;Ca=za}else{xa=(1-(c[e+306192+($*2224|0)+2192>>2]|0)+(c[J>>2]&1)<<1)+qa|0;la=xa>>3;if((la|0)<0){Da=1}else{Da=(la+8|0)>=(ua>>1|0)|0}Ba=xa;Ca=Da|za}xa=ia>>3;la=Ba>>3;wa=c[F>>2]|0;M=(ca(wa,la)|0)+xa|0;G=(c[e+306192+($*2224|0)+4>>2]|0)+M|0;L=(c[e+306192+($*2224|0)+8>>2]|0)+M|0;if((Ca|0)==0){M=h>>1;_=Ba&7;_e[N&511](H,G,wa,M,va,_);Ea=L;Fa=M;Ga=_}else{_=e+4|0;M=e+572684|0;Y=sa<<3;Q=ua>>1;Ve[c[_>>2]&127](c[M>>2]|0,G,wa,wa,9,9,xa,la,Y,Q);wa=h>>1;G=Ba&7;_e[N&511](H,c[M>>2]|0,c[F>>2]|0,wa,va,G);R=c[F>>2]|0;Ve[c[_>>2]&127](c[M>>2]|0,L,R,R,9,9,xa,la,Y,Q);Ea=c[M>>2]|0;Fa=wa;Ga=G}_e[N&511](I,Ea,c[F>>2]|0,Fa,va,Ga);return}}while(0);Ga=c[s>>2]|0;Fa=c[s+4>>2]|0;s=c[t>>2]|0;Ea=c[t+4>>2]|0;t=e+6112|0;N=c[t>>2]|0;Ba=(ca(n<<1,N)|0)+(m<<1)|0;Ca=j+Ba|0;za=h>>1;Da=e+6116|0;ya=c[Da>>2]|0;Aa=(ca(ya,n)|0)+m|0;O=k+Aa|0;k=l+Aa|0;Aa=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;q=c[l>>2]|0;r=(C>>q<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[602328+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(Aa<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(r<<3)|0;v=C<<2&12|n&3;oa=n>>2;na=C>>2;ma=(ca(na,N)|0)+oa|0;fa=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;ga=fa+ma|0;da=c[e+427400>>2]|0;ha=da<<4;ba=c[e+427396>>2]<<4>>q;ea=n&7;x=(ea|0)==0?0:-3;G=(C&7|0)==0?0:-3;do{if((oa|0)<(-x|0)){z=41}else{if((na|0)<(-G|0)){z=41;break}if((oa+16|0)>(x+ha|0)){z=41;break}if((na+16|0)>(ba+G|0)){z=41}else{Ha=ga;Ia=0;Ja=N}}}while(0);if((z|0)==41){ga=e+572684|0;Ve[c[e+4>>2]&127](c[ga>>2]|0,fa+(-2-(N<<1)+ma)|0,N,N,21,21,oa-2|0,na-2|0,ha,ba);ha=c[t>>2]|0;Ha=(c[ga>>2]|0)+((ha<<1)+2)|0;Ia=1;Ja=ha}ha=o+(v<<2)|0;ef[c[ha>>2]&4095](Ca,Ha,Ja);if((g|0)==0){ef[c[ha>>2]&4095](j+(Ba+i)|0,Ha+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){Ka=C;La=Ia}else{Ha=(1-(c[e+199440+(u*106752|0)+(y*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+C|0;C=Ha>>3;if((C|0)<0){Ma=1}else{Ma=(C+8|0)>=(ba>>1|0)|0}Ka=Ha;La=Ma|Ia}Ia=n>>3;n=Ka>>3;Ma=c[Da>>2]|0;Ha=(ca(Ma,n)|0)+Ia|0;C=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+Ha|0;ha=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+Ha|0;if((La|0)==0){La=Ka&7;_e[p&511](O,C,Ma,za,ea,La);Na=ha;Oa=La}else{La=e+4|0;Ha=e+572684|0;Ja=da<<3;da=ba>>1;Ve[c[La>>2]&127](c[Ha>>2]|0,C,Ma,Ma,9,9,Ia,n,Ja,da);Ma=Ka&7;_e[p&511](O,c[Ha>>2]|0,c[Da>>2]|0,za,ea,Ma);Ka=c[Da>>2]|0;Ve[c[La>>2]&127](c[Ha>>2]|0,ha,Ka,Ka,9,9,Ia,n,Ja,da);Na=c[Ha>>2]|0;Oa=Ma}_e[p&511](k,Na,c[Da>>2]|0,za,ea,Oa);_e[Ga&511](Ca,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}Ga=e+177132|0;_e[Fa&511](O,c[Da>>2]|0,za,c[Ga>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);_e[Fa&511](k,c[Da>>2]|0,za,c[Ga>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+16|0;Ga=ya<<4;ya=u+Ga|0;Fa=d[602328+f|0]|0;f=a[e+5632+Fa|0]|0;Oa=a[e+5672+Fa|0]|0;ea=Aa<<3;Aa=(b[e+5312+(Fa<<2)>>1]|0)+ea|0;Na=r<<3;r=(b[e+5312+(Fa<<2)+2>>1]|0)+Na|0;Ma=r<<2&12|Aa&3;Ha=Aa>>2;da=r>>2;Ja=(ca(da,N)|0)+Ha|0;n=c[e+199440+(f*2224|0)>>2]|0;Ia=n+Ja|0;Ka=e+427400|0;ha=c[Ka>>2]|0;La=ha<<4;C=e+427396|0;ba=c[C>>2]<<4>>q;q=Aa&7;v=(q|0)==0?0:-3;ga=(r&7|0)==0?0:-3;do{if((Ha|0)<(-v|0)){z=10}else{if((da|0)<(-ga|0)){z=10;break}if((Ha+16|0)>(v+La|0)){z=10;break}if((da+16|0)>(ba+ga|0)){z=10}else{Pa=Ia;Qa=0;Ra=N}}}while(0);if((z|0)==10){Ia=e+572684|0;Ve[c[e+4>>2]&127](c[Ia>>2]|0,n+(-2-(N<<1)+Ja)|0,N,N,21,21,Ha-2|0,da-2|0,La,ba);La=c[t>>2]|0;Pa=(c[Ia>>2]|0)+((La<<1)+2)|0;Qa=1;Ra=La}La=o+(Ma<<2)|0;ef[c[La>>2]&4095](Ca,Pa,Ra);Ra=(g|0)!=0;if(!Ra){ef[c[La>>2]&4095](j+(Ba+i)|0,Pa+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){Sa=r;Ta=Qa}else{Pa=(1-(c[e+199440+(f*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+r|0;r=Pa>>3;if((r|0)<0){Ua=1}else{Ua=(r+8|0)>=(ba>>1|0)|0}Sa=Pa;Ta=Ua|Qa}Qa=Aa>>3;Aa=Sa>>3;Ua=c[Da>>2]|0;Pa=(ca(Ua,Aa)|0)+Qa|0;r=(c[e+199440+(f*2224|0)+4>>2]|0)+Pa|0;Ba=(c[e+199440+(f*2224|0)+8>>2]|0)+Pa|0;if((Ta|0)==0){Ta=Sa&7;_e[p&511](O,r,Ua,za,q,Ta);Va=Ba;Wa=Ta}else{Ta=e+4|0;Pa=e+572684|0;j=ha<<3;ha=ba>>1;Ve[c[Ta>>2]&127](c[Pa>>2]|0,r,Ua,Ua,9,9,Qa,Aa,j,ha);Ua=Sa&7;_e[p&511](O,c[Pa>>2]|0,c[Da>>2]|0,za,q,Ua);Sa=c[Da>>2]|0;Ve[c[Ta>>2]&127](c[Pa>>2]|0,Ba,Sa,Sa,9,9,Qa,Aa,j,ha);Va=c[Pa>>2]|0;Wa=Ua}_e[p&511](k,Va,c[Da>>2]|0,za,q,Wa);Wa=(b[e+5472+(Fa<<2)>>1]|0)+ea|0;ea=(b[e+5472+(Fa<<2)+2>>1]|0)+Na|0;Na=ea<<2&12|Wa&3;Fa=Wa>>2;q=ea>>2;Va=c[t>>2]|0;Ua=(ca(q,Va)|0)+Fa|0;Pa=c[e+306192+(Oa*2224|0)>>2]|0;ha=Pa+Ua|0;j=c[Ka>>2]|0;Ka=j<<4;Aa=c[C>>2]<<4>>c[l>>2];C=Wa&7;Qa=(C|0)==0?0:-3;Sa=(ea&7|0)==0?0:-3;do{if((Fa|0)<(-Qa|0)){z=24}else{if((q|0)<(-Sa|0)){z=24;break}if((Fa+16|0)>(Ka+Qa|0)){z=24;break}if((q+16|0)>(Aa+Sa|0)){z=24}else{Xa=ha;Ya=0;Za=Va}}}while(0);if((z|0)==24){z=e+572684|0;Ve[c[e+4>>2]&127](c[z>>2]|0,Pa+(-2-(Va<<1)+Ua)|0,Va,Va,21,21,Fa-2|0,q-2|0,Ka,Aa);Ka=c[t>>2]|0;Xa=(c[z>>2]|0)+((Ka<<1)+2)|0;Ya=1;Za=Ka}Ka=o+(Na<<2)|0;ef[c[Ka>>2]&4095](ya,Xa,Za);if(!Ra){ef[c[Ka>>2]&4095](u+(Ga+i)|0,Xa+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){_a=ea;$a=Ya}else{l=(1-(c[e+306192+(Oa*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+ea|0;ea=l>>3;if((ea|0)<0){ab=1}else{ab=(ea+8|0)>=(Aa>>1|0)|0}_a=l;$a=ab|Ya}Ya=Wa>>3;Wa=_a>>3;ab=c[Da>>2]|0;l=(ca(ab,Wa)|0)+Ya|0;ea=(c[e+306192+(Oa*2224|0)+4>>2]|0)+l|0;i=(c[e+306192+(Oa*2224|0)+8>>2]|0)+l|0;if(($a|0)==0){$a=_a&7;_e[p&511](u,ea,ab,za,C,$a);bb=i;cb=$a}else{$a=e+4|0;l=e+572684|0;Xa=j<<3;j=Aa>>1;Ve[c[$a>>2]&127](c[l>>2]|0,ea,ab,ab,9,9,Ya,Wa,Xa,j);ab=_a&7;_e[p&511](u,c[l>>2]|0,c[Da>>2]|0,za,C,ab);_a=c[Da>>2]|0;Ve[c[$a>>2]&127](c[l>>2]|0,i,_a,_a,9,9,Ya,Wa,Xa,j);bb=c[l>>2]|0;cb=ab}_e[p&511](y,bb,c[Da>>2]|0,za,C,cb);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Oa<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Ge[s&255](Ca,ya,c[t>>2]|0,h,5,w,m,0);Ge[Ea&255](O,u,c[Da>>2]|0,za,5,w,m,0);Ge[Ea&255](k,y,c[Da>>2]|0,za,5,w,m,0);return}else{Ge[s&255](Ca,ya,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Oa<<4)+8>>2]|0,(c[e+177136+(Oa<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);h=e+177132|0;Ge[Ea&255](O,u,c[Da>>2]|0,za,c[h>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Oa<<5)+16>>2]|0,(c[e+177904+(Oa<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Ge[Ea&255](k,y,c[Da>>2]|0,za,c[h>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Oa<<5)+24>>2]|0,(c[e+177904+(Oa<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Oha(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[602328+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=n<<1;B=e+6112|0;D=c[B>>2]|0;E=(ca(D,A)|0)+(m<<1)|0;F=j+E|0;G=e+6116|0;H=(ca(c[G>>2]|0,A)|0)+m|0;A=k+H|0;I=l+H|0;H=(c[e+427376>>2]<<3)+m|0;J=e+177092|0;K=c[J>>2]|0;L=(c[e+427380>>2]>>K<<3)+n|0;if(y){M=p;N=o}else{O=d[602328+f|0]|0;P=a[e+5632+O|0]|0;Q=(b[e+5312+(O<<2)>>1]|0)+(H<<3)|0;R=(b[e+5312+(O<<2)+2>>1]|0)+(L<<3)|0;O=R<<2&12|Q&3;S=Q>>2;T=R>>2;U=(ca(T,D)|0)+S|0;V=c[e+199440+(P*2224|0)>>2]|0;W=V+U|0;X=c[e+427400>>2]|0;Y=X<<4;Z=c[e+427396>>2]<<4>>K;K=Q&7;_=(K|0)==0?0:-3;$=(R&7|0)==0?0:-3;do{if((S|0)<(-_|0)){z=46}else{if((T|0)<(-$|0)){z=46;break}if((S+16|0)>(_+Y|0)){z=46;break}if((T+16|0)>(Z+$|0)){z=46}else{aa=W;ba=0;da=D}}}while(0);if((z|0)==46){W=e+572684|0;Ve[c[e+4>>2]&127](c[W>>2]|0,V+(-2-(D<<1)+U)|0,D,D,21,21,S-2|0,T-2|0,Y,Z);$=c[B>>2]|0;aa=(c[W>>2]|0)+(($<<1)+2)|0;ba=1;da=$}$=o+(O<<2)|0;ef[c[$>>2]&4095](F,aa,da);if((g|0)==0){ef[c[$>>2]&4095](j+(E+i)|0,aa+i|0,c[B>>2]|0)}$=Q>>3;W=c[G>>2]|0;_=(ca(W,T)|0)+$|0;ea=(c[e+199440+(P*2224|0)+4>>2]|0)+_|0;fa=(c[e+199440+(P*2224|0)+8>>2]|0)+_|0;if((ba|0)==0){_=R<<1&6;_e[p&511](A,ea,W,h,K,_);ga=fa;ha=_}else{_=e+4|0;ia=e+572684|0;ja=X<<3;Ve[c[_>>2]&127](c[ia>>2]|0,ea,W,W,9,17,$,T,ja,Z);W=R<<1&6;_e[p&511](A,c[ia>>2]|0,c[G>>2]|0,h,K,W);ea=c[G>>2]|0;Ve[c[_>>2]&127](c[ia>>2]|0,fa,ea,ea,9,17,$,T,ja,Z);ga=c[ia>>2]|0;ha=W}_e[p&511](I,ga,c[G>>2]|0,h,K,ha);M=r;N=q}if(u){return}W=d[602328+f|0]|0;ia=a[e+5672+W|0]|0;ja=(b[e+5472+(W<<2)>>1]|0)+(H<<3)|0;$=(b[e+5472+(W<<2)+2>>1]|0)+(L<<3)|0;W=$<<2&12|ja&3;ea=ja>>2;fa=$>>2;_=c[B>>2]|0;ka=(ca(fa,_)|0)+ea|0;la=c[e+306192+(ia*2224|0)>>2]|0;ma=la+ka|0;na=c[e+427400>>2]|0;oa=na<<4;pa=c[e+427396>>2]<<4>>c[J>>2];qa=ja&7;ra=(qa|0)==0?0:-3;sa=($&7|0)==0?0:-3;do{if((ea|0)<(-ra|0)){z=58}else{if((fa|0)<(-sa|0)){z=58;break}if((ea+16|0)>(oa+ra|0)){z=58;break}if((fa+16|0)>(pa+sa|0)){z=58}else{ta=ma;ua=0;va=_}}}while(0);if((z|0)==58){ma=e+572684|0;Ve[c[e+4>>2]&127](c[ma>>2]|0,la+(-2-(_<<1)+ka)|0,_,_,21,21,ea-2|0,fa-2|0,oa,pa);sa=c[B>>2]|0;ta=(c[ma>>2]|0)+((sa<<1)+2)|0;ua=1;va=sa}sa=N+(W<<2)|0;ef[c[sa>>2]&4095](F,ta,va);if((g|0)==0){ef[c[sa>>2]&4095](j+(E+i)|0,ta+i|0,c[B>>2]|0)}sa=ja>>3;ma=c[G>>2]|0;ra=(ca(ma,fa)|0)+sa|0;J=(c[e+306192+(ia*2224|0)+4>>2]|0)+ra|0;L=(c[e+306192+(ia*2224|0)+8>>2]|0)+ra|0;if((ua|0)==0){ra=$<<1&6;_e[M&511](A,J,ma,h,qa,ra);wa=L;xa=ra}else{ra=e+4|0;H=e+572684|0;K=na<<3;Ve[c[ra>>2]&127](c[H>>2]|0,J,ma,ma,9,17,sa,fa,K,pa);ma=$<<1&6;_e[M&511](A,c[H>>2]|0,c[G>>2]|0,h,qa,ma);J=c[G>>2]|0;Ve[c[ra>>2]&127](c[H>>2]|0,L,J,J,9,17,sa,fa,K,pa);wa=c[H>>2]|0;xa=ma}_e[M&511](I,wa,c[G>>2]|0,h,qa,xa);return}}while(0);xa=c[s>>2]|0;wa=c[s+4>>2]|0;s=c[t>>2]|0;M=c[t+4>>2]|0;t=n<<1;ua=e+6112|0;ta=c[ua>>2]|0;va=(ca(ta,t)|0)+(m<<1)|0;N=j+va|0;q=e+6116|0;r=c[q>>2]|0;ha=(ca(r,t)|0)+m|0;t=k+ha|0;k=l+ha|0;ha=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;ga=c[l>>2]|0;ba=(C>>ga<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[602328+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(ha<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(ba<<3)|0;v=C<<2&12|n&3;aa=n>>2;da=C>>2;x=(ca(da,ta)|0)+aa|0;ma=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;H=ma+x|0;K=c[e+427400>>2]|0;sa=K<<4;J=c[e+427396>>2]<<4>>ga;L=n&7;ra=(L|0)==0?0:-3;Z=(C&7|0)==0?0:-3;do{if((aa|0)<(-ra|0)){z=33}else{if((da|0)<(-Z|0)){z=33;break}if((aa+16|0)>(ra+sa|0)){z=33;break}if((da+16|0)>(J+Z|0)){z=33}else{ya=H;za=0;Aa=ta}}}while(0);if((z|0)==33){H=e+572684|0;Ve[c[e+4>>2]&127](c[H>>2]|0,ma+(-2-(ta<<1)+x)|0,ta,ta,21,21,aa-2|0,da-2|0,sa,J);sa=c[ua>>2]|0;ya=(c[H>>2]|0)+((sa<<1)+2)|0;za=1;Aa=sa}sa=o+(v<<2)|0;ef[c[sa>>2]&4095](N,ya,Aa);if((g|0)==0){ef[c[sa>>2]&4095](j+(va+i)|0,ya+i|0,c[ua>>2]|0)}ya=n>>3;n=c[q>>2]|0;sa=(ca(n,da)|0)+ya|0;Aa=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+sa|0;v=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+sa|0;if((za|0)==0){za=C<<1&6;_e[p&511](t,Aa,n,h,L,za);Ba=v;Ca=za}else{za=e+4|0;sa=e+572684|0;H=K<<3;Ve[c[za>>2]&127](c[sa>>2]|0,Aa,n,n,9,17,ya,da,H,J);n=C<<1&6;_e[p&511](t,c[sa>>2]|0,c[q>>2]|0,h,L,n);C=c[q>>2]|0;Ve[c[za>>2]&127](c[sa>>2]|0,v,C,C,9,17,ya,da,H,J);Ba=c[sa>>2]|0;Ca=n}_e[p&511](k,Ba,c[q>>2]|0,h,L,Ca);_e[xa&511](N,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}xa=e+177132|0;_e[wa&511](t,c[q>>2]|0,h,c[xa>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);_e[wa&511](k,c[q>>2]|0,h,c[xa>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+16|0;xa=r<<4;r=u+xa|0;wa=d[602328+f|0]|0;f=a[e+5632+wa|0]|0;Ca=a[e+5672+wa|0]|0;L=ha<<3;ha=(b[e+5312+(wa<<2)>>1]|0)+L|0;Ba=ba<<3;ba=(b[e+5312+(wa<<2)+2>>1]|0)+Ba|0;n=ba<<2&12|ha&3;sa=ha>>2;J=ba>>2;H=(ca(J,ta)|0)+sa|0;da=c[e+199440+(f*2224|0)>>2]|0;ya=da+H|0;C=e+427400|0;v=c[C>>2]|0;za=v<<4;Aa=e+427396|0;K=c[Aa>>2]<<4>>ga;ga=ha&7;aa=(ga|0)==0?0:-3;x=(ba&7|0)==0?0:-3;do{if((sa|0)<(-aa|0)){z=10}else{if((J|0)<(-x|0)){z=10;break}if((sa+16|0)>(aa+za|0)){z=10;break}if((J+16|0)>(K+x|0)){z=10}else{Da=ya;Ea=0;Fa=ta}}}while(0);if((z|0)==10){ya=e+572684|0;Ve[c[e+4>>2]&127](c[ya>>2]|0,da+(-2-(ta<<1)+H)|0,ta,ta,21,21,sa-2|0,J-2|0,za,K);za=c[ua>>2]|0;Da=(c[ya>>2]|0)+((za<<1)+2)|0;Ea=1;Fa=za}za=o+(n<<2)|0;ef[c[za>>2]&4095](N,Da,Fa);Fa=(g|0)!=0;if(!Fa){ef[c[za>>2]&4095](j+(va+i)|0,Da+i|0,c[ua>>2]|0)}Da=ha>>3;ha=c[q>>2]|0;va=(ca(ha,J)|0)+Da|0;j=(c[e+199440+(f*2224|0)+4>>2]|0)+va|0;za=(c[e+199440+(f*2224|0)+8>>2]|0)+va|0;if((Ea|0)==0){Ea=ba<<1&6;_e[p&511](t,j,ha,h,ga,Ea);Ga=za;Ha=Ea}else{Ea=e+4|0;va=e+572684|0;g=v<<3;Ve[c[Ea>>2]&127](c[va>>2]|0,j,ha,ha,9,17,Da,J,g,K);ha=ba<<1&6;_e[p&511](t,c[va>>2]|0,c[q>>2]|0,h,ga,ha);ba=c[q>>2]|0;Ve[c[Ea>>2]&127](c[va>>2]|0,za,ba,ba,9,17,Da,J,g,K);Ga=c[va>>2]|0;Ha=ha}_e[p&511](k,Ga,c[q>>2]|0,h,ga,Ha);Ha=(b[e+5472+(wa<<2)>>1]|0)+L|0;L=(b[e+5472+(wa<<2)+2>>1]|0)+Ba|0;Ba=L<<2&12|Ha&3;wa=Ha>>2;ga=L>>2;Ga=c[ua>>2]|0;ha=(ca(ga,Ga)|0)+wa|0;va=c[e+306192+(Ca*2224|0)>>2]|0;K=va+ha|0;g=c[C>>2]|0;C=g<<4;J=c[Aa>>2]<<4>>c[l>>2];l=Ha&7;Aa=(l|0)==0?0:-3;Da=(L&7|0)==0?0:-3;do{if((wa|0)<(-Aa|0)){z=20}else{if((ga|0)<(-Da|0)){z=20;break}if((wa+16|0)>(C+Aa|0)){z=20;break}if((ga+16|0)>(J+Da|0)){z=20}else{Ia=K;Ja=0;Ka=Ga}}}while(0);if((z|0)==20){z=e+572684|0;Ve[c[e+4>>2]&127](c[z>>2]|0,va+(-2-(Ga<<1)+ha)|0,Ga,Ga,21,21,wa-2|0,ga-2|0,C,J);C=c[ua>>2]|0;Ia=(c[z>>2]|0)+((C<<1)+2)|0;Ja=1;Ka=C}C=o+(Ba<<2)|0;ef[c[C>>2]&4095](r,Ia,Ka);if(!Fa){ef[c[C>>2]&4095](u+(xa+i)|0,Ia+i|0,c[ua>>2]|0)}i=Ha>>3;Ha=c[q>>2]|0;Ia=(ca(Ha,ga)|0)+i|0;xa=(c[e+306192+(Ca*2224|0)+4>>2]|0)+Ia|0;C=(c[e+306192+(Ca*2224|0)+8>>2]|0)+Ia|0;if((Ja|0)==0){Ja=L<<1&6;_e[p&511](u,xa,Ha,h,l,Ja);La=C;Ma=Ja}else{Ja=e+4|0;Ia=e+572684|0;Fa=g<<3;Ve[c[Ja>>2]&127](c[Ia>>2]|0,xa,Ha,Ha,9,17,i,ga,Fa,J);Ha=L<<1&6;_e[p&511](u,c[Ia>>2]|0,c[q>>2]|0,h,l,Ha);L=c[q>>2]|0;Ve[c[Ja>>2]&127](c[Ia>>2]|0,C,L,L,9,17,i,ga,Fa,J);La=c[Ia>>2]|0;Ma=Ha}_e[p&511](y,La,c[q>>2]|0,h,l,Ma);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Ca<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Ge[s&255](N,r,c[ua>>2]|0,h,5,w,m,0);Ge[M&255](t,u,c[q>>2]|0,h,5,w,m,0);Ge[M&255](k,y,c[q>>2]|0,h,5,w,m,0);return}else{Ge[s&255](N,r,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Ca<<4)+8>>2]|0,(c[e+177136+(Ca<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);ua=e+177132|0;Ge[M&255](t,u,c[q>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Ca<<5)+16>>2]|0,(c[e+177904+(Ca<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Ge[M&255](k,y,c[q>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Ca<<5)+24>>2]|0,(c[e+177904+(Ca<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Pha(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[602328+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=e+6112|0;B=c[A>>2]|0;D=(ca(n<<1,B)|0)+(m<<2)|0;E=j+D|0;F=e+6116|0;G=(ca(c[F>>2]|0,n)|0)+(m<<1)|0;H=k+G|0;I=l+G|0;G=(c[e+427376>>2]<<3)+m|0;J=e+427380|0;K=e+177092|0;L=c[K>>2]|0;M=(c[J>>2]>>L<<3)+n|0;if(y){N=p;O=o}else{P=d[602328+f|0]|0;Q=a[e+5632+P|0]|0;R=(b[e+5312+(P<<2)>>1]|0)+(G<<3)|0;S=(b[e+5312+(P<<2)+2>>1]|0)+(M<<3)|0;P=S<<2&12|R&3;T=R>>2;U=S>>2;V=(ca(U,B)|0)+(T<<1)|0;W=c[e+199440+(Q*2224|0)>>2]|0;X=W+V|0;Y=c[e+427400>>2]|0;Z=Y<<4;_=c[e+427396>>2]<<4>>L;L=R&7;$=(L|0)==0?0:-3;aa=(S&7|0)==0?0:-3;do{if((T|0)<(-$|0)){z=58}else{if((U|0)<(-aa|0)){z=58;break}if((T+16|0)>($+Z|0)){z=58;break}if((U+16|0)>(_+aa|0)){z=58}else{ba=X;da=0;ea=B}}}while(0);if((z|0)==58){X=e+572684|0;Ve[c[e+4>>2]&127](c[X>>2]|0,W+(-4-(B<<1)+V)|0,B,B,21,21,T-2|0,U-2|0,Z,_);aa=c[A>>2]|0;ba=(c[X>>2]|0)+((aa<<1)+4)|0;da=1;ea=aa}aa=o+(P<<2)|0;ef[c[aa>>2]&4095](E,ba,ea);if((g|0)==0){ef[c[aa>>2]&4095](j+(D+i)|0,ba+i|0,c[A>>2]|0)}if((c[K>>2]|0)==0){fa=S;ga=da}else{aa=(1-(c[e+199440+(Q*2224|0)+2192>>2]|0)+(c[J>>2]&1)<<1)+S|0;X=aa>>3;if((X|0)<0){ha=1}else{ha=(X+8|0)>=(_>>1|0)|0}fa=aa;ga=ha|da}aa=R>>3;X=fa>>3;$=c[F>>2]|0;ia=(ca($,X)|0)+(aa<<1)|0;ja=(c[e+199440+(Q*2224|0)+4>>2]|0)+ia|0;ka=(c[e+199440+(Q*2224|0)+8>>2]|0)+ia|0;if((ga|0)==0){ia=h>>1;la=fa&7;_e[p&511](H,ja,$,ia,L,la);ma=ka;na=ia;oa=la}else{la=e+4|0;ia=e+572684|0;pa=Y<<3;qa=_>>1;Ve[c[la>>2]&127](c[ia>>2]|0,ja,$,$,9,9,aa,X,pa,qa);$=h>>1;ja=fa&7;_e[p&511](H,c[ia>>2]|0,c[F>>2]|0,$,L,ja);ra=c[F>>2]|0;Ve[c[la>>2]&127](c[ia>>2]|0,ka,ra,ra,9,9,aa,X,pa,qa);ma=c[ia>>2]|0;na=$;oa=ja}_e[p&511](I,ma,c[F>>2]|0,na,L,oa);N=r;O=q}if(u){return}ja=d[602328+f|0]|0;$=a[e+5672+ja|0]|0;ia=(b[e+5472+(ja<<2)>>1]|0)+(G<<3)|0;qa=(b[e+5472+(ja<<2)+2>>1]|0)+(M<<3)|0;ja=qa<<2&12|ia&3;pa=ia>>2;X=qa>>2;aa=c[A>>2]|0;ra=(ca(X,aa)|0)+(pa<<1)|0;ka=c[e+306192+($*2224|0)>>2]|0;la=ka+ra|0;sa=c[e+427400>>2]|0;ta=sa<<4;ua=c[e+427396>>2]<<4>>c[K>>2];va=ia&7;wa=(va|0)==0?0:-3;xa=(qa&7|0)==0?0:-3;do{if((pa|0)<(-wa|0)){z=74}else{if((X|0)<(-xa|0)){z=74;break}if((pa+16|0)>(ta+wa|0)){z=74;break}if((X+16|0)>(ua+xa|0)){z=74}else{ya=la;za=0;Aa=aa}}}while(0);if((z|0)==74){la=e+572684|0;Ve[c[e+4>>2]&127](c[la>>2]|0,ka+(-4-(aa<<1)+ra)|0,aa,aa,21,21,pa-2|0,X-2|0,ta,ua);xa=c[A>>2]|0;ya=(c[la>>2]|0)+((xa<<1)+4)|0;za=1;Aa=xa}xa=O+(ja<<2)|0;ef[c[xa>>2]&4095](E,ya,Aa);if((g|0)==0){ef[c[xa>>2]&4095](j+(D+i)|0,ya+i|0,c[A>>2]|0)}if((c[K>>2]|0)==0){Ba=qa;Ca=za}else{xa=(1-(c[e+306192+($*2224|0)+2192>>2]|0)+(c[J>>2]&1)<<1)+qa|0;la=xa>>3;if((la|0)<0){Da=1}else{Da=(la+8|0)>=(ua>>1|0)|0}Ba=xa;Ca=Da|za}xa=ia>>3;la=Ba>>3;wa=c[F>>2]|0;M=(ca(wa,la)|0)+(xa<<1)|0;G=(c[e+306192+($*2224|0)+4>>2]|0)+M|0;L=(c[e+306192+($*2224|0)+8>>2]|0)+M|0;if((Ca|0)==0){M=h>>1;_=Ba&7;_e[N&511](H,G,wa,M,va,_);Ea=L;Fa=M;Ga=_}else{_=e+4|0;M=e+572684|0;Y=sa<<3;Q=ua>>1;Ve[c[_>>2]&127](c[M>>2]|0,G,wa,wa,9,9,xa,la,Y,Q);wa=h>>1;G=Ba&7;_e[N&511](H,c[M>>2]|0,c[F>>2]|0,wa,va,G);R=c[F>>2]|0;Ve[c[_>>2]&127](c[M>>2]|0,L,R,R,9,9,xa,la,Y,Q);Ea=c[M>>2]|0;Fa=wa;Ga=G}_e[N&511](I,Ea,c[F>>2]|0,Fa,va,Ga);return}}while(0);Ga=c[s>>2]|0;Fa=c[s+4>>2]|0;s=c[t>>2]|0;Ea=c[t+4>>2]|0;t=e+6112|0;N=c[t>>2]|0;Ba=(ca(n<<1,N)|0)+(m<<2)|0;Ca=j+Ba|0;za=h>>1;Da=e+6116|0;ya=c[Da>>2]|0;Aa=(ca(ya,n)|0)+(m<<1)|0;O=k+Aa|0;k=l+Aa|0;Aa=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;q=c[l>>2]|0;r=(C>>q<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[602328+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(Aa<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(r<<3)|0;v=C<<2&12|n&3;oa=n>>2;na=C>>2;ma=(ca(na,N)|0)+(oa<<1)|0;fa=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;ga=fa+ma|0;da=c[e+427400>>2]|0;ha=da<<4;ba=c[e+427396>>2]<<4>>q;ea=n&7;x=(ea|0)==0?0:-3;G=(C&7|0)==0?0:-3;do{if((oa|0)<(-x|0)){z=41}else{if((na|0)<(-G|0)){z=41;break}if((oa+16|0)>(x+ha|0)){z=41;break}if((na+16|0)>(ba+G|0)){z=41}else{Ha=ga;Ia=0;Ja=N}}}while(0);if((z|0)==41){ga=e+572684|0;Ve[c[e+4>>2]&127](c[ga>>2]|0,fa+(-4-(N<<1)+ma)|0,N,N,21,21,oa-2|0,na-2|0,ha,ba);ha=c[t>>2]|0;Ha=(c[ga>>2]|0)+((ha<<1)+4)|0;Ia=1;Ja=ha}ha=o+(v<<2)|0;ef[c[ha>>2]&4095](Ca,Ha,Ja);if((g|0)==0){ef[c[ha>>2]&4095](j+(Ba+i)|0,Ha+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){Ka=C;La=Ia}else{Ha=(1-(c[e+199440+(u*106752|0)+(y*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+C|0;C=Ha>>3;if((C|0)<0){Ma=1}else{Ma=(C+8|0)>=(ba>>1|0)|0}Ka=Ha;La=Ma|Ia}Ia=n>>3;n=Ka>>3;Ma=c[Da>>2]|0;Ha=(ca(Ma,n)|0)+(Ia<<1)|0;C=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+Ha|0;ha=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+Ha|0;if((La|0)==0){La=Ka&7;_e[p&511](O,C,Ma,za,ea,La);Na=ha;Oa=La}else{La=e+4|0;Ha=e+572684|0;Ja=da<<3;da=ba>>1;Ve[c[La>>2]&127](c[Ha>>2]|0,C,Ma,Ma,9,9,Ia,n,Ja,da);Ma=Ka&7;_e[p&511](O,c[Ha>>2]|0,c[Da>>2]|0,za,ea,Ma);Ka=c[Da>>2]|0;Ve[c[La>>2]&127](c[Ha>>2]|0,ha,Ka,Ka,9,9,Ia,n,Ja,da);Na=c[Ha>>2]|0;Oa=Ma}_e[p&511](k,Na,c[Da>>2]|0,za,ea,Oa);_e[Ga&511](Ca,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}Ga=e+177132|0;_e[Fa&511](O,c[Da>>2]|0,za,c[Ga>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);_e[Fa&511](k,c[Da>>2]|0,za,c[Ga>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+32|0;Ga=ya<<4;ya=u+Ga|0;Fa=d[602328+f|0]|0;f=a[e+5632+Fa|0]|0;Oa=a[e+5672+Fa|0]|0;ea=Aa<<3;Aa=(b[e+5312+(Fa<<2)>>1]|0)+ea|0;Na=r<<3;r=(b[e+5312+(Fa<<2)+2>>1]|0)+Na|0;Ma=r<<2&12|Aa&3;Ha=Aa>>2;da=r>>2;Ja=(ca(da,N)|0)+(Ha<<1)|0;n=c[e+199440+(f*2224|0)>>2]|0;Ia=n+Ja|0;Ka=e+427400|0;ha=c[Ka>>2]|0;La=ha<<4;C=e+427396|0;ba=c[C>>2]<<4>>q;q=Aa&7;v=(q|0)==0?0:-3;ga=(r&7|0)==0?0:-3;do{if((Ha|0)<(-v|0)){z=10}else{if((da|0)<(-ga|0)){z=10;break}if((Ha+16|0)>(v+La|0)){z=10;break}if((da+16|0)>(ba+ga|0)){z=10}else{Pa=Ia;Qa=0;Ra=N}}}while(0);if((z|0)==10){Ia=e+572684|0;Ve[c[e+4>>2]&127](c[Ia>>2]|0,n+(-4-(N<<1)+Ja)|0,N,N,21,21,Ha-2|0,da-2|0,La,ba);La=c[t>>2]|0;Pa=(c[Ia>>2]|0)+((La<<1)+4)|0;Qa=1;Ra=La}La=o+(Ma<<2)|0;ef[c[La>>2]&4095](Ca,Pa,Ra);Ra=(g|0)!=0;if(!Ra){ef[c[La>>2]&4095](j+(Ba+i)|0,Pa+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){Sa=r;Ta=Qa}else{Pa=(1-(c[e+199440+(f*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+r|0;r=Pa>>3;if((r|0)<0){Ua=1}else{Ua=(r+8|0)>=(ba>>1|0)|0}Sa=Pa;Ta=Ua|Qa}Qa=Aa>>3;Aa=Sa>>3;Ua=c[Da>>2]|0;Pa=(ca(Ua,Aa)|0)+(Qa<<1)|0;r=(c[e+199440+(f*2224|0)+4>>2]|0)+Pa|0;Ba=(c[e+199440+(f*2224|0)+8>>2]|0)+Pa|0;if((Ta|0)==0){Ta=Sa&7;_e[p&511](O,r,Ua,za,q,Ta);Va=Ba;Wa=Ta}else{Ta=e+4|0;Pa=e+572684|0;j=ha<<3;ha=ba>>1;Ve[c[Ta>>2]&127](c[Pa>>2]|0,r,Ua,Ua,9,9,Qa,Aa,j,ha);Ua=Sa&7;_e[p&511](O,c[Pa>>2]|0,c[Da>>2]|0,za,q,Ua);Sa=c[Da>>2]|0;Ve[c[Ta>>2]&127](c[Pa>>2]|0,Ba,Sa,Sa,9,9,Qa,Aa,j,ha);Va=c[Pa>>2]|0;Wa=Ua}_e[p&511](k,Va,c[Da>>2]|0,za,q,Wa);Wa=(b[e+5472+(Fa<<2)>>1]|0)+ea|0;ea=(b[e+5472+(Fa<<2)+2>>1]|0)+Na|0;Na=ea<<2&12|Wa&3;Fa=Wa>>2;q=ea>>2;Va=c[t>>2]|0;Ua=(ca(q,Va)|0)+(Fa<<1)|0;Pa=c[e+306192+(Oa*2224|0)>>2]|0;ha=Pa+Ua|0;j=c[Ka>>2]|0;Ka=j<<4;Aa=c[C>>2]<<4>>c[l>>2];C=Wa&7;Qa=(C|0)==0?0:-3;Sa=(ea&7|0)==0?0:-3;do{if((Fa|0)<(-Qa|0)){z=24}else{if((q|0)<(-Sa|0)){z=24;break}if((Fa+16|0)>(Ka+Qa|0)){z=24;break}if((q+16|0)>(Aa+Sa|0)){z=24}else{Xa=ha;Ya=0;Za=Va}}}while(0);if((z|0)==24){z=e+572684|0;Ve[c[e+4>>2]&127](c[z>>2]|0,Pa+(-4-(Va<<1)+Ua)|0,Va,Va,21,21,Fa-2|0,q-2|0,Ka,Aa);Ka=c[t>>2]|0;Xa=(c[z>>2]|0)+((Ka<<1)+4)|0;Ya=1;Za=Ka}Ka=o+(Na<<2)|0;ef[c[Ka>>2]&4095](ya,Xa,Za);if(!Ra){ef[c[Ka>>2]&4095](u+(Ga+i)|0,Xa+i|0,c[t>>2]|0)}if((c[l>>2]|0)==0){_a=ea;$a=Ya}else{l=(1-(c[e+306192+(Oa*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+ea|0;ea=l>>3;if((ea|0)<0){ab=1}else{ab=(ea+8|0)>=(Aa>>1|0)|0}_a=l;$a=ab|Ya}Ya=Wa>>3;Wa=_a>>3;ab=c[Da>>2]|0;l=(ca(ab,Wa)|0)+(Ya<<1)|0;ea=(c[e+306192+(Oa*2224|0)+4>>2]|0)+l|0;i=(c[e+306192+(Oa*2224|0)+8>>2]|0)+l|0;if(($a|0)==0){$a=_a&7;_e[p&511](u,ea,ab,za,C,$a);bb=i;cb=$a}else{$a=e+4|0;l=e+572684|0;Xa=j<<3;j=Aa>>1;Ve[c[$a>>2]&127](c[l>>2]|0,ea,ab,ab,9,9,Ya,Wa,Xa,j);ab=_a&7;_e[p&511](u,c[l>>2]|0,c[Da>>2]|0,za,C,ab);_a=c[Da>>2]|0;Ve[c[$a>>2]&127](c[l>>2]|0,i,_a,_a,9,9,Ya,Wa,Xa,j);bb=c[l>>2]|0;cb=ab}_e[p&511](y,bb,c[Da>>2]|0,za,C,cb);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Oa<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Ge[s&255](Ca,ya,c[t>>2]|0,h,5,w,m,0);Ge[Ea&255](O,u,c[Da>>2]|0,za,5,w,m,0);Ge[Ea&255](k,y,c[Da>>2]|0,za,5,w,m,0);return}else{Ge[s&255](Ca,ya,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Oa<<4)+8>>2]|0,(c[e+177136+(Oa<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);h=e+177132|0;Ge[Ea&255](O,u,c[Da>>2]|0,za,c[h>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Oa<<5)+16>>2]|0,(c[e+177904+(Oa<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Ge[Ea&255](k,y,c[Da>>2]|0,za,c[h>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Oa<<5)+24>>2]|0,(c[e+177904+(Oa<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Qha(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[602328+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=n<<1;B=e+6112|0;D=c[B>>2]|0;E=(ca(D,A)|0)+(m<<2)|0;F=j+E|0;G=e+6116|0;H=(ca(c[G>>2]|0,A)|0)+(m<<1)|0;A=k+H|0;I=l+H|0;H=(c[e+427376>>2]<<3)+m|0;J=e+177092|0;K=c[J>>2]|0;L=(c[e+427380>>2]>>K<<3)+n|0;if(y){M=p;N=o}else{O=d[602328+f|0]|0;P=a[e+5632+O|0]|0;Q=(b[e+5312+(O<<2)>>1]|0)+(H<<3)|0;R=(b[e+5312+(O<<2)+2>>1]|0)+(L<<3)|0;O=R<<2&12|Q&3;S=Q>>2;T=R>>2;U=(ca(T,D)|0)+(S<<1)|0;V=c[e+199440+(P*2224|0)>>2]|0;W=V+U|0;X=c[e+427400>>2]|0;Y=X<<4;Z=c[e+427396>>2]<<4>>K;K=Q&7;_=(K|0)==0?0:-3;$=(R&7|0)==0?0:-3;do{if((S|0)<(-_|0)){z=46}else{if((T|0)<(-$|0)){z=46;break}if((S+16|0)>(_+Y|0)){z=46;break}if((T+16|0)>(Z+$|0)){z=46}else{aa=W;ba=0;da=D}}}while(0);if((z|0)==46){W=e+572684|0;Ve[c[e+4>>2]&127](c[W>>2]|0,V+(-4-(D<<1)+U)|0,D,D,21,21,S-2|0,T-2|0,Y,Z);$=c[B>>2]|0;aa=(c[W>>2]|0)+(($<<1)+4)|0;ba=1;da=$}$=o+(O<<2)|0;ef[c[$>>2]&4095](F,aa,da);if((g|0)==0){ef[c[$>>2]&4095](j+(E+i)|0,aa+i|0,c[B>>2]|0)}$=Q>>3;W=c[G>>2]|0;_=(ca(W,T)|0)+($<<1)|0;ea=(c[e+199440+(P*2224|0)+4>>2]|0)+_|0;fa=(c[e+199440+(P*2224|0)+8>>2]|0)+_|0;if((ba|0)==0){_=R<<1&6;_e[p&511](A,ea,W,h,K,_);ga=fa;ha=_}else{_=e+4|0;ia=e+572684|0;ja=X<<3;Ve[c[_>>2]&127](c[ia>>2]|0,ea,W,W,9,17,$,T,ja,Z);W=R<<1&6;_e[p&511](A,c[ia>>2]|0,c[G>>2]|0,h,K,W);ea=c[G>>2]|0;Ve[c[_>>2]&127](c[ia>>2]|0,fa,ea,ea,9,17,$,T,ja,Z);ga=c[ia>>2]|0;ha=W}_e[p&511](I,ga,c[G>>2]|0,h,K,ha);M=r;N=q}if(u){return}W=d[602328+f|0]|0;ia=a[e+5672+W|0]|0;ja=(b[e+5472+(W<<2)>>1]|0)+(H<<3)|0;$=(b[e+5472+(W<<2)+2>>1]|0)+(L<<3)|0;W=$<<2&12|ja&3;ea=ja>>2;fa=$>>2;_=c[B>>2]|0;ka=(ca(fa,_)|0)+(ea<<1)|0;la=c[e+306192+(ia*2224|0)>>2]|0;ma=la+ka|0;na=c[e+427400>>2]|0;oa=na<<4;pa=c[e+427396>>2]<<4>>c[J>>2];qa=ja&7;ra=(qa|0)==0?0:-3;sa=($&7|0)==0?0:-3;do{if((ea|0)<(-ra|0)){z=58}else{if((fa|0)<(-sa|0)){z=58;break}if((ea+16|0)>(oa+ra|0)){z=58;break}if((fa+16|0)>(pa+sa|0)){z=58}else{ta=ma;ua=0;va=_}}}while(0);if((z|0)==58){ma=e+572684|0;Ve[c[e+4>>2]&127](c[ma>>2]|0,la+(-4-(_<<1)+ka)|0,_,_,21,21,ea-2|0,fa-2|0,oa,pa);sa=c[B>>2]|0;ta=(c[ma>>2]|0)+((sa<<1)+4)|0;ua=1;va=sa}sa=N+(W<<2)|0;ef[c[sa>>2]&4095](F,ta,va);if((g|0)==0){ef[c[sa>>2]&4095](j+(E+i)|0,ta+i|0,c[B>>2]|0)}sa=ja>>3;ma=c[G>>2]|0;ra=(ca(ma,fa)|0)+(sa<<1)|0;J=(c[e+306192+(ia*2224|0)+4>>2]|0)+ra|0;L=(c[e+306192+(ia*2224|0)+8>>2]|0)+ra|0;if((ua|0)==0){ra=$<<1&6;_e[M&511](A,J,ma,h,qa,ra);wa=L;xa=ra}else{ra=e+4|0;H=e+572684|0;K=na<<3;Ve[c[ra>>2]&127](c[H>>2]|0,J,ma,ma,9,17,sa,fa,K,pa);ma=$<<1&6;_e[M&511](A,c[H>>2]|0,c[G>>2]|0,h,qa,ma);J=c[G>>2]|0;Ve[c[ra>>2]&127](c[H>>2]|0,L,J,J,9,17,sa,fa,K,pa);wa=c[H>>2]|0;xa=ma}_e[M&511](I,wa,c[G>>2]|0,h,qa,xa);return}}while(0);xa=c[s>>2]|0;wa=c[s+4>>2]|0;s=c[t>>2]|0;M=c[t+4>>2]|0;t=n<<1;ua=e+6112|0;ta=c[ua>>2]|0;va=(ca(ta,t)|0)+(m<<2)|0;N=j+va|0;q=e+6116|0;r=c[q>>2]|0;ha=(ca(r,t)|0)+(m<<1)|0;t=k+ha|0;k=l+ha|0;ha=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;ga=c[l>>2]|0;ba=(C>>ga<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[602328+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(ha<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(ba<<3)|0;v=C<<2&12|n&3;aa=n>>2;da=C>>2;x=(ca(da,ta)|0)+(aa<<1)|0;ma=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;H=ma+x|0;K=c[e+427400>>2]|0;sa=K<<4;J=c[e+427396>>2]<<4>>ga;L=n&7;ra=(L|0)==0?0:-3;Z=(C&7|0)==0?0:-3;do{if((aa|0)<(-ra|0)){z=33}else{if((da|0)<(-Z|0)){z=33;break}if((aa+16|0)>(ra+sa|0)){z=33;break}if((da+16|0)>(J+Z|0)){z=33}else{ya=H;za=0;Aa=ta}}}while(0);if((z|0)==33){H=e+572684|0;Ve[c[e+4>>2]&127](c[H>>2]|0,ma+(-4-(ta<<1)+x)|0,ta,ta,21,21,aa-2|0,da-2|0,sa,J);sa=c[ua>>2]|0;ya=(c[H>>2]|0)+((sa<<1)+4)|0;za=1;Aa=sa}sa=o+(v<<2)|0;ef[c[sa>>2]&4095](N,ya,Aa);if((g|0)==0){ef[c[sa>>2]&4095](j+(va+i)|0,ya+i|0,c[ua>>2]|0)}ya=n>>3;n=c[q>>2]|0;sa=(ca(n,da)|0)+(ya<<1)|0;Aa=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+sa|0;v=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+sa|0;if((za|0)==0){za=C<<1&6;_e[p&511](t,Aa,n,h,L,za);Ba=v;Ca=za}else{za=e+4|0;sa=e+572684|0;H=K<<3;Ve[c[za>>2]&127](c[sa>>2]|0,Aa,n,n,9,17,ya,da,H,J);n=C<<1&6;_e[p&511](t,c[sa>>2]|0,c[q>>2]|0,h,L,n);C=c[q>>2]|0;Ve[c[za>>2]&127](c[sa>>2]|0,v,C,C,9,17,ya,da,H,J);Ba=c[sa>>2]|0;Ca=n}_e[p&511](k,Ba,c[q>>2]|0,h,L,Ca);_e[xa&511](N,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}xa=e+177132|0;_e[wa&511](t,c[q>>2]|0,h,c[xa>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);_e[wa&511](k,c[q>>2]|0,h,c[xa>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+32|0;xa=r<<4;r=u+xa|0;wa=d[602328+f|0]|0;f=a[e+5632+wa|0]|0;Ca=a[e+5672+wa|0]|0;L=ha<<3;ha=(b[e+5312+(wa<<2)>>1]|0)+L|0;Ba=ba<<3;ba=(b[e+5312+(wa<<2)+2>>1]|0)+Ba|0;n=ba<<2&12|ha&3;sa=ha>>2;J=ba>>2;H=(ca(J,ta)|0)+(sa<<1)|0;da=c[e+199440+(f*2224|0)>>2]|0;ya=da+H|0;C=e+427400|0;v=c[C>>2]|0;za=v<<4;Aa=e+427396|0;K=c[Aa>>2]<<4>>ga;ga=ha&7;aa=(ga|0)==0?0:-3;x=(ba&7|0)==0?0:-3;do{if((sa|0)<(-aa|0)){z=10}else{if((J|0)<(-x|0)){z=10;break}if((sa+16|0)>(aa+za|0)){z=10;break}if((J+16|0)>(K+x|0)){z=10}else{Da=ya;Ea=0;Fa=ta}}}while(0);if((z|0)==10){ya=e+572684|0;Ve[c[e+4>>2]&127](c[ya>>2]|0,da+(-4-(ta<<1)+H)|0,ta,ta,21,21,sa-2|0,J-2|0,za,K);za=c[ua>>2]|0;Da=(c[ya>>2]|0)+((za<<1)+4)|0;Ea=1;Fa=za}za=o+(n<<2)|0;ef[c[za>>2]&4095](N,Da,Fa);Fa=(g|0)!=0;if(!Fa){ef[c[za>>2]&4095](j+(va+i)|0,Da+i|0,c[ua>>2]|0)}Da=ha>>3;ha=c[q>>2]|0;va=(ca(ha,J)|0)+(Da<<1)|0;j=(c[e+199440+(f*2224|0)+4>>2]|0)+va|0;za=(c[e+199440+(f*2224|0)+8>>2]|0)+va|0;if((Ea|0)==0){Ea=ba<<1&6;_e[p&511](t,j,ha,h,ga,Ea);Ga=za;Ha=Ea}else{Ea=e+4|0;va=e+572684|0;g=v<<3;Ve[c[Ea>>2]&127](c[va>>2]|0,j,ha,ha,9,17,Da,J,g,K);ha=ba<<1&6;_e[p&511](t,c[va>>2]|0,c[q>>2]|0,h,ga,ha);ba=c[q>>2]|0;Ve[c[Ea>>2]&127](c[va>>2]|0,za,ba,ba,9,17,Da,J,g,K);Ga=c[va>>2]|0;Ha=ha}_e[p&511](k,Ga,c[q>>2]|0,h,ga,Ha);Ha=(b[e+5472+(wa<<2)>>1]|0)+L|0;L=(b[e+5472+(wa<<2)+2>>1]|0)+Ba|0;Ba=L<<2&12|Ha&3;wa=Ha>>2;ga=L>>2;Ga=c[ua>>2]|0;ha=(ca(ga,Ga)|0)+(wa<<1)|0;va=c[e+306192+(Ca*2224|0)>>2]|0;K=va+ha|0;g=c[C>>2]|0;C=g<<4;J=c[Aa>>2]<<4>>c[l>>2];l=Ha&7;Aa=(l|0)==0?0:-3;Da=(L&7|0)==0?0:-3;do{if((wa|0)<(-Aa|0)){z=20}else{if((ga|0)<(-Da|0)){z=20;break}if((wa+16|0)>(C+Aa|0)){z=20;break}if((ga+16|0)>(J+Da|0)){z=20}else{Ia=K;Ja=0;Ka=Ga}}}while(0);if((z|0)==20){z=e+572684|0;Ve[c[e+4>>2]&127](c[z>>2]|0,va+(-4-(Ga<<1)+ha)|0,Ga,Ga,21,21,wa-2|0,ga-2|0,C,J);C=c[ua>>2]|0;Ia=(c[z>>2]|0)+((C<<1)+4)|0;Ja=1;Ka=C}C=o+(Ba<<2)|0;ef[c[C>>2]&4095](r,Ia,Ka);if(!Fa){ef[c[C>>2]&4095](u+(xa+i)|0,Ia+i|0,c[ua>>2]|0)}i=Ha>>3;Ha=c[q>>2]|0;Ia=(ca(Ha,ga)|0)+(i<<1)|0;xa=(c[e+306192+(Ca*2224|0)+4>>2]|0)+Ia|0;C=(c[e+306192+(Ca*2224|0)+8>>2]|0)+Ia|0;if((Ja|0)==0){Ja=L<<1&6;_e[p&511](u,xa,Ha,h,l,Ja);La=C;Ma=Ja}else{Ja=e+4|0;Ia=e+572684|0;Fa=g<<3;Ve[c[Ja>>2]&127](c[Ia>>2]|0,xa,Ha,Ha,9,17,i,ga,Fa,J);Ha=L<<1&6;_e[p&511](u,c[Ia>>2]|0,c[q>>2]|0,h,l,Ha);L=c[q>>2]|0;Ve[c[Ja>>2]&127](c[Ia>>2]|0,C,L,L,9,17,i,ga,Fa,J);La=c[Ia>>2]|0;Ma=Ha}_e[p&511](y,La,c[q>>2]|0,h,l,Ma);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Ca<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Ge[s&255](N,r,c[ua>>2]|0,h,5,w,m,0);Ge[M&255](t,u,c[q>>2]|0,h,5,w,m,0);Ge[M&255](k,y,c[q>>2]|0,h,5,w,m,0);return}else{Ge[s&255](N,r,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Ca<<4)+8>>2]|0,(c[e+177136+(Ca<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);ua=e+177132|0;Ge[M&255](t,u,c[q>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Ca<<5)+16>>2]|0,(c[e+177904+(Ca<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Ge[M&255](k,y,c[q>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Ca<<5)+24>>2]|0,(c[e+177904+(Ca<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Rha(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[602328+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=c[e+4752>>2]|0;B=e+6112|0;D=c[B>>2]|0;E=(ca(n<<1,D)|0)+(m<<1<<A)|0;F=j+E|0;G=e+6116|0;H=(ca(c[G>>2]|0,n)|0)+(m<<A)|0;I=k+H|0;J=l+H|0;H=(c[e+427376>>2]<<3)+m|0;K=e+427380|0;L=e+177092|0;M=c[L>>2]|0;N=(c[K>>2]>>M<<3)+n|0;if(y){O=p;P=o}else{Q=d[602328+f|0]|0;R=a[e+5632+Q|0]|0;S=(b[e+5312+(Q<<2)>>1]|0)+(H<<3)|0;T=(b[e+5312+(Q<<2)+2>>1]|0)+(N<<3)|0;Q=T<<2&12|S&3;U=S>>2;V=T>>2;W=(ca(V,D)|0)+(U<<A)|0;X=c[e+199440+(R*2224|0)>>2]|0;Y=X+W|0;Z=c[e+427400>>2]|0;_=Z<<4;$=c[e+427396>>2]<<4>>M;M=S&7;aa=(M|0)==0?0:-3;ba=(T&7|0)==0?0:-3;do{if((U|0)<(-aa|0)){z=58}else{if((V|0)<(-ba|0)){z=58;break}if((U+16|0)>(aa+_|0)){z=58;break}if((V+16|0)>($+ba|0)){z=58}else{da=Y;ea=0;fa=D}}}while(0);if((z|0)==58){Y=e+572684|0;ba=2<<A;Ve[c[e+4>>2]&127](c[Y>>2]|0,X+(W-((D<<1)+ba))|0,D,D,21,21,U-2|0,V-2|0,_,$);aa=c[B>>2]|0;da=(c[Y>>2]|0)+((aa<<1)+ba)|0;ea=1;fa=aa}aa=o+(Q<<2)|0;ef[c[aa>>2]&4095](F,da,fa);if((g|0)==0){ef[c[aa>>2]&4095](j+(E+i)|0,da+i|0,c[B>>2]|0)}if((c[L>>2]|0)==0){ga=T;ha=ea}else{aa=(1-(c[e+199440+(R*2224|0)+2192>>2]|0)+(c[K>>2]&1)<<1)+T|0;ba=aa>>3;if((ba|0)<0){ia=1}else{ia=(ba+8|0)>=($>>1|0)|0}ga=aa;ha=ia|ea}aa=S>>3;ba=ga>>3;Y=c[G>>2]|0;ja=(ca(Y,ba)|0)+(aa<<A)|0;ka=(c[e+199440+(R*2224|0)+4>>2]|0)+ja|0;la=(c[e+199440+(R*2224|0)+8>>2]|0)+ja|0;if((ha|0)==0){ja=h>>1;ma=ga&7;_e[p&511](I,ka,Y,ja,M,ma);na=la;oa=ja;pa=ma}else{ma=e+4|0;ja=e+572684|0;qa=Z<<3;ra=$>>1;Ve[c[ma>>2]&127](c[ja>>2]|0,ka,Y,Y,9,9,aa,ba,qa,ra);Y=h>>1;ka=ga&7;_e[p&511](I,c[ja>>2]|0,c[G>>2]|0,Y,M,ka);sa=c[G>>2]|0;Ve[c[ma>>2]&127](c[ja>>2]|0,la,sa,sa,9,9,aa,ba,qa,ra);na=c[ja>>2]|0;oa=Y;pa=ka}_e[p&511](J,na,c[G>>2]|0,oa,M,pa);O=r;P=q}if(u){return}ka=d[602328+f|0]|0;Y=a[e+5672+ka|0]|0;ja=(b[e+5472+(ka<<2)>>1]|0)+(H<<3)|0;ra=(b[e+5472+(ka<<2)+2>>1]|0)+(N<<3)|0;ka=ra<<2&12|ja&3;qa=ja>>2;ba=ra>>2;aa=c[B>>2]|0;sa=(ca(ba,aa)|0)+(qa<<A)|0;la=c[e+306192+(Y*2224|0)>>2]|0;ma=la+sa|0;ta=c[e+427400>>2]|0;ua=ta<<4;va=c[e+427396>>2]<<4>>c[L>>2];wa=ja&7;xa=(wa|0)==0?0:-3;ya=(ra&7|0)==0?0:-3;do{if((qa|0)<(-xa|0)){z=74}else{if((ba|0)<(-ya|0)){z=74;break}if((qa+16|0)>(ua+xa|0)){z=74;break}if((ba+16|0)>(va+ya|0)){z=74}else{za=ma;Aa=0;Ba=aa}}}while(0);if((z|0)==74){ma=e+572684|0;ya=2<<A;Ve[c[e+4>>2]&127](c[ma>>2]|0,la+(sa-((aa<<1)+ya))|0,aa,aa,21,21,qa-2|0,ba-2|0,ua,va);xa=c[B>>2]|0;za=(c[ma>>2]|0)+((xa<<1)+ya)|0;Aa=1;Ba=xa}xa=P+(ka<<2)|0;ef[c[xa>>2]&4095](F,za,Ba);if((g|0)==0){ef[c[xa>>2]&4095](j+(E+i)|0,za+i|0,c[B>>2]|0)}if((c[L>>2]|0)==0){Ca=ra;Da=Aa}else{xa=(1-(c[e+306192+(Y*2224|0)+2192>>2]|0)+(c[K>>2]&1)<<1)+ra|0;ya=xa>>3;if((ya|0)<0){Ea=1}else{Ea=(ya+8|0)>=(va>>1|0)|0}Ca=xa;Da=Ea|Aa}xa=ja>>3;ya=Ca>>3;ma=c[G>>2]|0;N=(ca(ma,ya)|0)+(xa<<A)|0;H=(c[e+306192+(Y*2224|0)+4>>2]|0)+N|0;M=(c[e+306192+(Y*2224|0)+8>>2]|0)+N|0;if((Da|0)==0){N=h>>1;$=Ca&7;_e[O&511](I,H,ma,N,wa,$);Fa=M;Ga=N;Ha=$}else{$=e+4|0;N=e+572684|0;Z=ta<<3;R=va>>1;Ve[c[$>>2]&127](c[N>>2]|0,H,ma,ma,9,9,xa,ya,Z,R);ma=h>>1;H=Ca&7;_e[O&511](I,c[N>>2]|0,c[G>>2]|0,ma,wa,H);S=c[G>>2]|0;Ve[c[$>>2]&127](c[N>>2]|0,M,S,S,9,9,xa,ya,Z,R);Fa=c[N>>2]|0;Ga=ma;Ha=H}_e[O&511](J,Fa,c[G>>2]|0,Ga,wa,Ha);return}}while(0);Ha=c[s>>2]|0;Ga=c[s+4>>2]|0;s=c[t>>2]|0;Fa=c[t+4>>2]|0;t=c[e+4752>>2]|0;O=e+6112|0;Ca=c[O>>2]|0;Da=(ca(n<<1,Ca)|0)+(m<<1<<t)|0;Aa=j+Da|0;Ea=h>>1;za=e+6116|0;Ba=c[za>>2]|0;P=(ca(Ba,n)|0)+(m<<t)|0;q=k+P|0;k=l+P|0;P=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;r=c[l>>2]|0;pa=(C>>r<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[602328+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(P<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(pa<<3)|0;v=C<<2&12|n&3;oa=n>>2;na=C>>2;ga=(ca(na,Ca)|0)+(oa<<t)|0;ha=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;ea=ha+ga|0;ia=c[e+427400>>2]|0;da=ia<<4;fa=c[e+427396>>2]<<4>>r;x=n&7;H=(x|0)==0?0:-3;ma=(C&7|0)==0?0:-3;do{if((oa|0)<(-H|0)){z=41}else{if((na|0)<(-ma|0)){z=41;break}if((oa+16|0)>(H+da|0)){z=41;break}if((na+16|0)>(fa+ma|0)){z=41}else{Ia=ea;Ja=0;Ka=Ca}}}while(0);if((z|0)==41){ea=e+572684|0;ma=2<<t;Ve[c[e+4>>2]&127](c[ea>>2]|0,ha+(ga-((Ca<<1)+ma))|0,Ca,Ca,21,21,oa-2|0,na-2|0,da,fa);da=c[O>>2]|0;Ia=(c[ea>>2]|0)+((da<<1)+ma)|0;Ja=1;Ka=da}da=o+(v<<2)|0;ef[c[da>>2]&4095](Aa,Ia,Ka);if((g|0)==0){ef[c[da>>2]&4095](j+(Da+i)|0,Ia+i|0,c[O>>2]|0)}if((c[l>>2]|0)==0){La=C;Ma=Ja}else{Ia=(1-(c[e+199440+(u*106752|0)+(y*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+C|0;C=Ia>>3;if((C|0)<0){Na=1}else{Na=(C+8|0)>=(fa>>1|0)|0}La=Ia;Ma=Na|Ja}Ja=n>>3;n=La>>3;Na=c[za>>2]|0;Ia=(ca(Na,n)|0)+(Ja<<t)|0;C=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+Ia|0;da=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+Ia|0;if((Ma|0)==0){Ma=La&7;_e[p&511](q,C,Na,Ea,x,Ma);Oa=da;Pa=Ma}else{Ma=e+4|0;Ia=e+572684|0;Ka=ia<<3;ia=fa>>1;Ve[c[Ma>>2]&127](c[Ia>>2]|0,C,Na,Na,9,9,Ja,n,Ka,ia);Na=La&7;_e[p&511](q,c[Ia>>2]|0,c[za>>2]|0,Ea,x,Na);La=c[za>>2]|0;Ve[c[Ma>>2]&127](c[Ia>>2]|0,da,La,La,9,9,Ja,n,Ka,ia);Oa=c[Ia>>2]|0;Pa=Na}_e[p&511](k,Oa,c[za>>2]|0,Ea,x,Pa);_e[Ha&511](Aa,c[O>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}Ha=e+177132|0;_e[Ga&511](q,c[za>>2]|0,Ea,c[Ha>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);_e[Ga&511](k,c[za>>2]|0,Ea,c[Ha>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+(16<<t)|0;Ha=Ba<<4;Ba=u+Ha|0;Ga=d[602328+f|0]|0;f=a[e+5632+Ga|0]|0;Pa=a[e+5672+Ga|0]|0;x=P<<3;P=(b[e+5312+(Ga<<2)>>1]|0)+x|0;Oa=pa<<3;pa=(b[e+5312+(Ga<<2)+2>>1]|0)+Oa|0;Na=pa<<2&12|P&3;Ia=P>>2;ia=pa>>2;Ka=(ca(ia,Ca)|0)+(Ia<<t)|0;n=c[e+199440+(f*2224|0)>>2]|0;Ja=n+Ka|0;La=e+427400|0;da=c[La>>2]|0;Ma=da<<4;C=e+427396|0;fa=c[C>>2]<<4>>r;r=P&7;v=(r|0)==0?0:-3;ma=(pa&7|0)==0?0:-3;do{if((Ia|0)<(-v|0)){z=10}else{if((ia|0)<(-ma|0)){z=10;break}if((Ia+16|0)>(v+Ma|0)){z=10;break}if((ia+16|0)>(fa+ma|0)){z=10}else{Qa=Ja;Ra=0;Sa=Ca}}}while(0);if((z|0)==10){Ja=e+572684|0;ma=2<<t;Ve[c[e+4>>2]&127](c[Ja>>2]|0,n+(Ka-((Ca<<1)+ma))|0,Ca,Ca,21,21,Ia-2|0,ia-2|0,Ma,fa);Ma=c[O>>2]|0;Qa=(c[Ja>>2]|0)+((Ma<<1)+ma)|0;Ra=1;Sa=Ma}Ma=o+(Na<<2)|0;ef[c[Ma>>2]&4095](Aa,Qa,Sa);Sa=(g|0)!=0;if(!Sa){ef[c[Ma>>2]&4095](j+(Da+i)|0,Qa+i|0,c[O>>2]|0)}if((c[l>>2]|0)==0){Ta=pa;Ua=Ra}else{Qa=(1-(c[e+199440+(f*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+pa|0;pa=Qa>>3;if((pa|0)<0){Va=1}else{Va=(pa+8|0)>=(fa>>1|0)|0}Ta=Qa;Ua=Va|Ra}Ra=P>>3;P=Ta>>3;Va=c[za>>2]|0;Qa=(ca(Va,P)|0)+(Ra<<t)|0;pa=(c[e+199440+(f*2224|0)+4>>2]|0)+Qa|0;Da=(c[e+199440+(f*2224|0)+8>>2]|0)+Qa|0;if((Ua|0)==0){Ua=Ta&7;_e[p&511](q,pa,Va,Ea,r,Ua);Wa=Da;Xa=Ua}else{Ua=e+4|0;Qa=e+572684|0;j=da<<3;da=fa>>1;Ve[c[Ua>>2]&127](c[Qa>>2]|0,pa,Va,Va,9,9,Ra,P,j,da);Va=Ta&7;_e[p&511](q,c[Qa>>2]|0,c[za>>2]|0,Ea,r,Va);Ta=c[za>>2]|0;Ve[c[Ua>>2]&127](c[Qa>>2]|0,Da,Ta,Ta,9,9,Ra,P,j,da);Wa=c[Qa>>2]|0;Xa=Va}_e[p&511](k,Wa,c[za>>2]|0,Ea,r,Xa);Xa=(b[e+5472+(Ga<<2)>>1]|0)+x|0;x=(b[e+5472+(Ga<<2)+2>>1]|0)+Oa|0;Oa=x<<2&12|Xa&3;Ga=Xa>>2;r=x>>2;Wa=c[O>>2]|0;Va=(ca(r,Wa)|0)+(Ga<<t)|0;Qa=c[e+306192+(Pa*2224|0)>>2]|0;da=Qa+Va|0;j=c[La>>2]|0;La=j<<4;P=c[C>>2]<<4>>c[l>>2];C=Xa&7;Ra=(C|0)==0?0:-3;Ta=(x&7|0)==0?0:-3;do{if((Ga|0)<(-Ra|0)){z=24}else{if((r|0)<(-Ta|0)){z=24;break}if((Ga+16|0)>(La+Ra|0)){z=24;break}if((r+16|0)>(P+Ta|0)){z=24}else{Ya=da;Za=0;_a=Wa}}}while(0);if((z|0)==24){z=e+572684|0;da=2<<t;Ve[c[e+4>>2]&127](c[z>>2]|0,Qa+(Va-((Wa<<1)+da))|0,Wa,Wa,21,21,Ga-2|0,r-2|0,La,P);La=c[O>>2]|0;Ya=(c[z>>2]|0)+((La<<1)+da)|0;Za=1;_a=La}La=o+(Oa<<2)|0;ef[c[La>>2]&4095](Ba,Ya,_a);if(!Sa){ef[c[La>>2]&4095](u+(Ha+i)|0,Ya+i|0,c[O>>2]|0)}if((c[l>>2]|0)==0){$a=x;ab=Za}else{l=(1-(c[e+306192+(Pa*2224|0)+2192>>2]|0)+(c[m>>2]&1)<<1)+x|0;x=l>>3;if((x|0)<0){bb=1}else{bb=(x+8|0)>=(P>>1|0)|0}$a=l;ab=bb|Za}Za=Xa>>3;Xa=$a>>3;bb=c[za>>2]|0;l=(ca(bb,Xa)|0)+(Za<<t)|0;t=(c[e+306192+(Pa*2224|0)+4>>2]|0)+l|0;x=(c[e+306192+(Pa*2224|0)+8>>2]|0)+l|0;if((ab|0)==0){ab=$a&7;_e[p&511](u,t,bb,Ea,C,ab);cb=x;db=ab}else{ab=e+4|0;l=e+572684|0;i=j<<3;j=P>>1;Ve[c[ab>>2]&127](c[l>>2]|0,t,bb,bb,9,9,Za,Xa,i,j);bb=$a&7;_e[p&511](u,c[l>>2]|0,c[za>>2]|0,Ea,C,bb);$a=c[za>>2]|0;Ve[c[ab>>2]&127](c[l>>2]|0,x,$a,$a,9,9,Za,Xa,i,j);cb=c[l>>2]|0;db=bb}_e[p&511](y,cb,c[za>>2]|0,Ea,C,db);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Pa<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Ge[s&255](Aa,Ba,c[O>>2]|0,h,5,w,m,0);Ge[Fa&255](q,u,c[za>>2]|0,Ea,5,w,m,0);Ge[Fa&255](k,y,c[za>>2]|0,Ea,5,w,m,0);return}else{Ge[s&255](Aa,Ba,c[O>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Pa<<4)+8>>2]|0,(c[e+177136+(Pa<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);h=e+177132|0;Ge[Fa&255](q,u,c[za>>2]|0,Ea,c[h>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Pa<<5)+16>>2]|0,(c[e+177904+(Pa<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Ge[Fa&255](k,y,c[za>>2]|0,Ea,c[h>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Pa<<5)+24>>2]|0,(c[e+177904+(Pa<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Sha(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;w=e+177120|0;x=c[w>>2]|0;y=(u|0)==0;u=(v|0)==0;if((x|0)!=2|y|u){z=3}else{A=c[e+427380>>2]|0;B=d[602328+f|0]|0;if((c[e+179440+((a[e+5632+B|0]|0)*384|0)+(a[e+5672+B|0]<<3)+((A&1)<<2)>>2]|0)==32){z=3}else{C=A}}do{if((z|0)==3){if((x|0)==1){C=c[e+427380>>2]|0;break}A=c[e+4752>>2]|0;B=n<<1;D=e+6112|0;E=c[D>>2]|0;F=(ca(E,B)|0)+(m<<1<<A)|0;G=j+F|0;H=e+6116|0;I=(ca(c[H>>2]|0,B)|0)+(m<<A)|0;B=k+I|0;J=l+I|0;I=(c[e+427376>>2]<<3)+m|0;K=e+177092|0;L=c[K>>2]|0;M=(c[e+427380>>2]>>L<<3)+n|0;if(y){N=p;O=o}else{P=d[602328+f|0]|0;Q=a[e+5632+P|0]|0;R=(b[e+5312+(P<<2)>>1]|0)+(I<<3)|0;S=(b[e+5312+(P<<2)+2>>1]|0)+(M<<3)|0;P=S<<2&12|R&3;T=R>>2;U=S>>2;V=(ca(U,E)|0)+(T<<A)|0;W=c[e+199440+(Q*2224|0)>>2]|0;X=W+V|0;Y=c[e+427400>>2]|0;Z=Y<<4;_=c[e+427396>>2]<<4>>L;L=R&7;$=(L|0)==0?0:-3;aa=(S&7|0)==0?0:-3;do{if((T|0)<(-$|0)){z=46}else{if((U|0)<(-aa|0)){z=46;break}if((T+16|0)>($+Z|0)){z=46;break}if((U+16|0)>(_+aa|0)){z=46}else{ba=X;da=0;ea=E}}}while(0);if((z|0)==46){X=e+572684|0;aa=2<<A;Ve[c[e+4>>2]&127](c[X>>2]|0,W+(V-((E<<1)+aa))|0,E,E,21,21,T-2|0,U-2|0,Z,_);$=c[D>>2]|0;ba=(c[X>>2]|0)+(($<<1)+aa)|0;da=1;ea=$}$=o+(P<<2)|0;ef[c[$>>2]&4095](G,ba,ea);if((g|0)==0){ef[c[$>>2]&4095](j+(F+i)|0,ba+i|0,c[D>>2]|0)}$=R>>3;aa=c[H>>2]|0;X=(ca(aa,U)|0)+($<<A)|0;fa=(c[e+199440+(Q*2224|0)+4>>2]|0)+X|0;ga=(c[e+199440+(Q*2224|0)+8>>2]|0)+X|0;if((da|0)==0){X=S<<1&6;_e[p&511](B,fa,aa,h,L,X);ha=ga;ia=X}else{X=e+4|0;ja=e+572684|0;ka=Y<<3;Ve[c[X>>2]&127](c[ja>>2]|0,fa,aa,aa,9,17,$,U,ka,_);aa=S<<1&6;_e[p&511](B,c[ja>>2]|0,c[H>>2]|0,h,L,aa);fa=c[H>>2]|0;Ve[c[X>>2]&127](c[ja>>2]|0,ga,fa,fa,9,17,$,U,ka,_);ha=c[ja>>2]|0;ia=aa}_e[p&511](J,ha,c[H>>2]|0,h,L,ia);N=r;O=q}if(u){return}aa=d[602328+f|0]|0;ja=a[e+5672+aa|0]|0;ka=(b[e+5472+(aa<<2)>>1]|0)+(I<<3)|0;$=(b[e+5472+(aa<<2)+2>>1]|0)+(M<<3)|0;aa=$<<2&12|ka&3;fa=ka>>2;ga=$>>2;X=c[D>>2]|0;la=(ca(ga,X)|0)+(fa<<A)|0;ma=c[e+306192+(ja*2224|0)>>2]|0;na=ma+la|0;oa=c[e+427400>>2]|0;pa=oa<<4;qa=c[e+427396>>2]<<4>>c[K>>2];ra=ka&7;sa=(ra|0)==0?0:-3;ta=($&7|0)==0?0:-3;do{if((fa|0)<(-sa|0)){z=58}else{if((ga|0)<(-ta|0)){z=58;break}if((fa+16|0)>(pa+sa|0)){z=58;break}if((ga+16|0)>(qa+ta|0)){z=58}else{ua=na;va=0;wa=X}}}while(0);if((z|0)==58){na=e+572684|0;ta=2<<A;Ve[c[e+4>>2]&127](c[na>>2]|0,ma+(la-((X<<1)+ta))|0,X,X,21,21,fa-2|0,ga-2|0,pa,qa);sa=c[D>>2]|0;ua=(c[na>>2]|0)+((sa<<1)+ta)|0;va=1;wa=sa}sa=O+(aa<<2)|0;ef[c[sa>>2]&4095](G,ua,wa);if((g|0)==0){ef[c[sa>>2]&4095](j+(F+i)|0,ua+i|0,c[D>>2]|0)}sa=ka>>3;ta=c[H>>2]|0;na=(ca(ta,ga)|0)+(sa<<A)|0;K=(c[e+306192+(ja*2224|0)+4>>2]|0)+na|0;M=(c[e+306192+(ja*2224|0)+8>>2]|0)+na|0;if((va|0)==0){na=$<<1&6;_e[N&511](B,K,ta,h,ra,na);xa=M;ya=na}else{na=e+4|0;I=e+572684|0;L=oa<<3;Ve[c[na>>2]&127](c[I>>2]|0,K,ta,ta,9,17,sa,ga,L,qa);ta=$<<1&6;_e[N&511](B,c[I>>2]|0,c[H>>2]|0,h,ra,ta);K=c[H>>2]|0;Ve[c[na>>2]&127](c[I>>2]|0,M,K,K,9,17,sa,ga,L,qa);xa=c[I>>2]|0;ya=ta}_e[N&511](J,xa,c[H>>2]|0,h,ra,ya);return}}while(0);ya=c[s>>2]|0;xa=c[s+4>>2]|0;s=c[t>>2]|0;N=c[t+4>>2]|0;t=c[e+4752>>2]|0;va=n<<1;ua=e+6112|0;wa=c[ua>>2]|0;O=(ca(wa,va)|0)+(m<<1<<t)|0;q=j+O|0;r=e+6116|0;ia=c[r>>2]|0;ha=(ca(ia,va)|0)+(m<<t)|0;va=k+ha|0;k=l+ha|0;ha=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;l=e+177092|0;da=c[l>>2]|0;ba=(C>>da<<3)+n|0;if(y|u){u=(v|0)!=0|0;v=d[602328+f|0]|0;y=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(ha<<3)|0;C=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(ba<<3)|0;v=C<<2&12|n&3;ea=n>>2;x=C>>2;ta=(ca(x,wa)|0)+(ea<<t)|0;I=c[e+199440+(u*106752|0)+(y*2224|0)>>2]|0;L=I+ta|0;sa=c[e+427400>>2]|0;K=sa<<4;M=c[e+427396>>2]<<4>>da;na=n&7;_=(na|0)==0?0:-3;U=(C&7|0)==0?0:-3;do{if((ea|0)<(-_|0)){z=33}else{if((x|0)<(-U|0)){z=33;break}if((ea+16|0)>(_+K|0)){z=33;break}if((x+16|0)>(M+U|0)){z=33}else{za=L;Aa=0;Ba=wa}}}while(0);if((z|0)==33){L=e+572684|0;U=2<<t;Ve[c[e+4>>2]&127](c[L>>2]|0,I+(ta-((wa<<1)+U))|0,wa,wa,21,21,ea-2|0,x-2|0,K,M);K=c[ua>>2]|0;za=(c[L>>2]|0)+((K<<1)+U)|0;Aa=1;Ba=K}K=o+(v<<2)|0;ef[c[K>>2]&4095](q,za,Ba);if((g|0)==0){ef[c[K>>2]&4095](j+(O+i)|0,za+i|0,c[ua>>2]|0)}za=n>>3;n=c[r>>2]|0;K=(ca(n,x)|0)+(za<<t)|0;Ba=(c[e+199440+(u*106752|0)+(y*2224|0)+4>>2]|0)+K|0;v=(c[e+199440+(u*106752|0)+(y*2224|0)+8>>2]|0)+K|0;if((Aa|0)==0){Aa=C<<1&6;_e[p&511](va,Ba,n,h,na,Aa);Ca=v;Da=Aa}else{Aa=e+4|0;K=e+572684|0;U=sa<<3;Ve[c[Aa>>2]&127](c[K>>2]|0,Ba,n,n,9,17,za,x,U,M);n=C<<1&6;_e[p&511](va,c[K>>2]|0,c[r>>2]|0,h,na,n);C=c[r>>2]|0;Ve[c[Aa>>2]&127](c[K>>2]|0,v,C,C,9,17,za,x,U,M);Ca=c[K>>2]|0;Da=n}_e[p&511](k,Ca,c[r>>2]|0,h,na,Da);_e[ya&511](q,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(y<<4)+(u<<3)>>2]|0,c[e+177136+(y<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}ya=e+177132|0;_e[xa&511](va,c[r>>2]|0,h,c[ya>>2]|0,c[e+177904+(y<<5)+(u<<4)>>2]|0,c[e+177904+(y<<5)+(u<<4)+4>>2]|0);_e[xa&511](k,c[r>>2]|0,h,c[ya>>2]|0,c[e+177904+(y<<5)+(u<<4)+8>>2]|0,c[e+177904+(y<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;y=u+(16<<t)|0;ya=ia<<4;ia=u+ya|0;xa=d[602328+f|0]|0;f=a[e+5632+xa|0]|0;Da=a[e+5672+xa|0]|0;na=ha<<3;ha=(b[e+5312+(xa<<2)>>1]|0)+na|0;Ca=ba<<3;ba=(b[e+5312+(xa<<2)+2>>1]|0)+Ca|0;n=ba<<2&12|ha&3;K=ha>>2;M=ba>>2;U=(ca(M,wa)|0)+(K<<t)|0;x=c[e+199440+(f*2224|0)>>2]|0;za=x+U|0;C=e+427400|0;v=c[C>>2]|0;Aa=v<<4;Ba=e+427396|0;sa=c[Ba>>2]<<4>>da;da=ha&7;L=(da|0)==0?0:-3;ea=(ba&7|0)==0?0:-3;do{if((K|0)<(-L|0)){z=10}else{if((M|0)<(-ea|0)){z=10;break}if((K+16|0)>(L+Aa|0)){z=10;break}if((M+16|0)>(sa+ea|0)){z=10}else{Ea=za;Fa=0;Ga=wa}}}while(0);if((z|0)==10){za=e+572684|0;ea=2<<t;Ve[c[e+4>>2]&127](c[za>>2]|0,x+(U-((wa<<1)+ea))|0,wa,wa,21,21,K-2|0,M-2|0,Aa,sa);Aa=c[ua>>2]|0;Ea=(c[za>>2]|0)+((Aa<<1)+ea)|0;Fa=1;Ga=Aa}Aa=o+(n<<2)|0;ef[c[Aa>>2]&4095](q,Ea,Ga);Ga=(g|0)!=0;if(!Ga){ef[c[Aa>>2]&4095](j+(O+i)|0,Ea+i|0,c[ua>>2]|0)}Ea=ha>>3;ha=c[r>>2]|0;O=(ca(ha,M)|0)+(Ea<<t)|0;j=(c[e+199440+(f*2224|0)+4>>2]|0)+O|0;Aa=(c[e+199440+(f*2224|0)+8>>2]|0)+O|0;if((Fa|0)==0){Fa=ba<<1&6;_e[p&511](va,j,ha,h,da,Fa);Ha=Aa;Ia=Fa}else{Fa=e+4|0;O=e+572684|0;g=v<<3;Ve[c[Fa>>2]&127](c[O>>2]|0,j,ha,ha,9,17,Ea,M,g,sa);ha=ba<<1&6;_e[p&511](va,c[O>>2]|0,c[r>>2]|0,h,da,ha);ba=c[r>>2]|0;Ve[c[Fa>>2]&127](c[O>>2]|0,Aa,ba,ba,9,17,Ea,M,g,sa);Ha=c[O>>2]|0;Ia=ha}_e[p&511](k,Ha,c[r>>2]|0,h,da,Ia);Ia=(b[e+5472+(xa<<2)>>1]|0)+na|0;na=(b[e+5472+(xa<<2)+2>>1]|0)+Ca|0;Ca=na<<2&12|Ia&3;xa=Ia>>2;da=na>>2;Ha=c[ua>>2]|0;ha=(ca(da,Ha)|0)+(xa<<t)|0;O=c[e+306192+(Da*2224|0)>>2]|0;sa=O+ha|0;g=c[C>>2]|0;C=g<<4;M=c[Ba>>2]<<4>>c[l>>2];l=Ia&7;Ba=(l|0)==0?0:-3;Ea=(na&7|0)==0?0:-3;do{if((xa|0)<(-Ba|0)){z=20}else{if((da|0)<(-Ea|0)){z=20;break}if((xa+16|0)>(C+Ba|0)){z=20;break}if((da+16|0)>(M+Ea|0)){z=20}else{Ja=sa;Ka=0;La=Ha}}}while(0);if((z|0)==20){z=e+572684|0;sa=2<<t;Ve[c[e+4>>2]&127](c[z>>2]|0,O+(ha-((Ha<<1)+sa))|0,Ha,Ha,21,21,xa-2|0,da-2|0,C,M);C=c[ua>>2]|0;Ja=(c[z>>2]|0)+((C<<1)+sa)|0;Ka=1;La=C}C=o+(Ca<<2)|0;ef[c[C>>2]&4095](ia,Ja,La);if(!Ga){ef[c[C>>2]&4095](u+(ya+i)|0,Ja+i|0,c[ua>>2]|0)}i=Ia>>3;Ia=c[r>>2]|0;Ja=(ca(Ia,da)|0)+(i<<t)|0;t=(c[e+306192+(Da*2224|0)+4>>2]|0)+Ja|0;ya=(c[e+306192+(Da*2224|0)+8>>2]|0)+Ja|0;if((Ka|0)==0){Ka=na<<1&6;_e[p&511](u,t,Ia,h,l,Ka);Ma=ya;Na=Ka}else{Ka=e+4|0;Ja=e+572684|0;C=g<<3;Ve[c[Ka>>2]&127](c[Ja>>2]|0,t,Ia,Ia,9,17,i,da,C,M);Ia=na<<1&6;_e[p&511](u,c[Ja>>2]|0,c[r>>2]|0,h,l,Ia);na=c[r>>2]|0;Ve[c[Ka>>2]&127](c[Ja>>2]|0,ya,na,na,9,17,i,da,C,M);Ma=c[Ja>>2]|0;Na=Ia}_e[p&511](y,Ma,c[r>>2]|0,h,l,Na);if((c[w>>2]|0)==2){w=c[e+179440+(f*384|0)+(Da<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-w|0;Ge[s&255](q,ia,c[ua>>2]|0,h,5,w,m,0);Ge[N&255](va,u,c[r>>2]|0,h,5,w,m,0);Ge[N&255](k,y,c[r>>2]|0,h,5,w,m,0);return}else{Ge[s&255](q,ia,c[ua>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Da<<4)+8>>2]|0,(c[e+177136+(Da<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);ua=e+177132|0;Ge[N&255](va,u,c[r>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Da<<5)+16>>2]|0,(c[e+177904+(Da<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Ge[N&255](k,y,c[r>>2]|0,h,c[ua>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Da<<5)+24>>2]|0,(c[e+177904+(Da<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Tha(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0;r=e+177120|0;p=c[r>>2]|0;w=(u|0)==0;u=(v|0)==0;if((p|0)!=2|w|u){x=3}else{y=c[e+427380>>2]|0;z=d[602328+f|0]|0;if((c[e+179440+((a[e+5632+z|0]|0)*384|0)+(a[e+5672+z|0]<<3)+((y&1)<<2)>>2]|0)==32){x=3}else{A=y}}do{if((x|0)==3){if((p|0)==1){A=c[e+427380>>2]|0;break}y=e+6112|0;z=c[y>>2]|0;B=(ca(n<<1,z)|0)+(m<<1)|0;C=j+B|0;D=k+B|0;E=l+B|0;F=(c[e+427376>>2]<<3)+m|0;G=e+177092|0;H=c[G>>2]|0;I=(c[e+427380>>2]>>H<<3)+n|0;do{if(w){J=o}else{K=d[602328+f|0]|0;L=a[e+5632+K|0]|0;M=(b[e+5312+(K<<2)>>1]|0)+(F<<3)|0;N=(b[e+5312+(K<<2)+2>>1]|0)+(I<<3)|0;K=N<<2&12|M&3;O=M>>2;P=N>>2;Q=(ca(P,z)|0)+O|0;R=c[e+199440+(L*2224|0)>>2]|0;S=R+Q|0;T=c[e+427400>>2]<<4;U=c[e+427396>>2]<<4>>H;V=(M&7|0)==0?0:-3;M=(N&7|0)==0?0:-3;do{if((O|0)<(-V|0)){x=67}else{if((P|0)<(-M|0)){x=67;break}if((O+16|0)>(V+T|0)){x=67;break}if((P+16|0)>(U+M|0)){x=67}else{W=S;X=0;Y=z}}}while(0);if((x|0)==67){S=e+572684|0;Ve[c[e+4>>2]&127](c[S>>2]|0,R+(-2-(z<<1)+Q)|0,z,z,21,21,O-2|0,P-2|0,T,U);M=c[y>>2]|0;W=(c[S>>2]|0)+((M<<1)+2)|0;X=1;Y=M}M=o+(K<<2)|0;ef[c[M>>2]&4095](C,W,Y);S=(g|0)!=0;if(!S){ef[c[M>>2]&4095](j+(B+i)|0,W+i|0,c[y>>2]|0)}V=c[e+199440+(L*2224|0)+4>>2]|0;N=(X|0)!=0;if(N){Z=e+572684|0;_=c[y>>2]|0;Ve[c[e+4>>2]&127](c[Z>>2]|0,V+(Q-2-(_<<1))|0,_,_,21,21,O-2|0,P-2|0,T,U);_=c[y>>2]|0;$=(c[Z>>2]|0)+((_<<1)+2)|0;aa=_}else{$=V+Q|0;aa=c[y>>2]|0}ef[c[M>>2]&4095](D,$,aa);if(!S){ef[c[M>>2]&4095](k+(B+i)|0,$+i|0,c[y>>2]|0)}V=c[e+199440+(L*2224|0)+8>>2]|0;if(N){N=e+572684|0;_=c[y>>2]|0;Ve[c[e+4>>2]&127](c[N>>2]|0,V+(Q-2-(_<<1))|0,_,_,21,21,O-2|0,P-2|0,T,U);_=c[y>>2]|0;ba=(c[N>>2]|0)+((_<<1)+2)|0;da=_}else{ba=V+Q|0;da=c[y>>2]|0}ef[c[M>>2]&4095](E,ba,da);if(S){J=q;break}ef[c[M>>2]&4095](l+(B+i)|0,ba+i|0,c[y>>2]|0);J=q}}while(0);if(u){return}z=d[602328+f|0]|0;H=a[e+5672+z|0]|0;M=(b[e+5472+(z<<2)>>1]|0)+(F<<3)|0;S=(b[e+5472+(z<<2)+2>>1]|0)+(I<<3)|0;z=S<<2&12|M&3;V=M>>2;_=S>>2;N=c[y>>2]|0;Z=(ca(_,N)|0)+V|0;ea=c[e+306192+(H*2224|0)>>2]|0;fa=ea+Z|0;ga=c[e+427400>>2]<<4;ha=c[e+427396>>2]<<4>>c[G>>2];ia=(M&7|0)==0?0:-3;M=(S&7|0)==0?0:-3;do{if((V|0)<(-ia|0)){x=85}else{if((_|0)<(-M|0)){x=85;break}if((V+16|0)>(ga+ia|0)){x=85;break}if((_+16|0)>(ha+M|0)){x=85}else{ja=fa;ka=0;la=N}}}while(0);if((x|0)==85){fa=e+572684|0;Ve[c[e+4>>2]&127](c[fa>>2]|0,ea+(-2-(N<<1)+Z)|0,N,N,21,21,V-2|0,_-2|0,ga,ha);M=c[y>>2]|0;ja=(c[fa>>2]|0)+((M<<1)+2)|0;ka=1;la=M}M=J+(z<<2)|0;ef[c[M>>2]&4095](C,ja,la);fa=(g|0)!=0;if(!fa){ef[c[M>>2]&4095](j+(B+i)|0,ja+i|0,c[y>>2]|0)}ia=c[e+306192+(H*2224|0)+4>>2]|0;G=(ka|0)!=0;if(G){I=e+572684|0;F=c[y>>2]|0;Ve[c[e+4>>2]&127](c[I>>2]|0,ia+(Z-2-(F<<1))|0,F,F,21,21,V-2|0,_-2|0,ga,ha);F=c[y>>2]|0;ma=(c[I>>2]|0)+((F<<1)+2)|0;na=F}else{ma=ia+Z|0;na=c[y>>2]|0}ef[c[M>>2]&4095](D,ma,na);if(!fa){ef[c[M>>2]&4095](k+(B+i)|0,ma+i|0,c[y>>2]|0)}ia=c[e+306192+(H*2224|0)+8>>2]|0;if(G){G=e+572684|0;F=c[y>>2]|0;Ve[c[e+4>>2]&127](c[G>>2]|0,ia+(Z-2-(F<<1))|0,F,F,21,21,V-2|0,_-2|0,ga,ha);F=c[y>>2]|0;oa=(c[G>>2]|0)+((F<<1)+2)|0;pa=F}else{oa=ia+Z|0;pa=c[y>>2]|0}ef[c[M>>2]&4095](E,oa,pa);if(fa){return}ef[c[M>>2]&4095](l+(B+i)|0,oa+i|0,c[y>>2]|0);return}}while(0);oa=c[s>>2]|0;s=c[t>>2]|0;t=e+6112|0;pa=c[t>>2]|0;ma=(ca(n<<1,pa)|0)+(m<<1)|0;na=j+ma|0;ka=k+ma|0;ja=l+ma|0;la=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;J=e+177092|0;q=c[J>>2]|0;ba=(A>>q<<3)+n|0;if(w|u){u=(v|0)!=0|0;v=d[602328+f|0]|0;w=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(la<<3)|0;A=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(ba<<3)|0;v=A<<2&12|n&3;da=n>>2;$=A>>2;aa=(ca($,pa)|0)+da|0;X=c[e+199440+(u*106752|0)+(w*2224|0)>>2]|0;W=X+aa|0;Y=c[e+427400>>2]<<4;p=c[e+427396>>2]<<4>>q;M=(n&7|0)==0?0:-3;n=(A&7|0)==0?0:-3;do{if((da|0)<(-M|0)){x=47}else{if(($|0)<(-n|0)){x=47;break}if((da+16|0)>(M+Y|0)){x=47;break}if(($+16|0)>(p+n|0)){x=47}else{qa=W;ra=0;sa=pa}}}while(0);if((x|0)==47){W=e+572684|0;Ve[c[e+4>>2]&127](c[W>>2]|0,X+(-2-(pa<<1)+aa)|0,pa,pa,21,21,da-2|0,$-2|0,Y,p);X=c[t>>2]|0;qa=(c[W>>2]|0)+((X<<1)+2)|0;ra=1;sa=X}X=o+(v<<2)|0;ef[c[X>>2]&4095](na,qa,sa);sa=(g|0)!=0;if(!sa){ef[c[X>>2]&4095](j+(ma+i)|0,qa+i|0,c[t>>2]|0)}qa=c[e+199440+(u*106752|0)+(w*2224|0)+4>>2]|0;v=(ra|0)!=0;if(v){ra=e+572684|0;W=c[t>>2]|0;Ve[c[e+4>>2]&127](c[ra>>2]|0,qa+(aa-2-(W<<1))|0,W,W,21,21,da-2|0,$-2|0,Y,p);W=c[t>>2]|0;ta=(c[ra>>2]|0)+((W<<1)+2)|0;ua=W}else{ta=qa+aa|0;ua=c[t>>2]|0}ef[c[X>>2]&4095](ka,ta,ua);if(!sa){ef[c[X>>2]&4095](k+(ma+i)|0,ta+i|0,c[t>>2]|0)}ta=c[e+199440+(u*106752|0)+(w*2224|0)+8>>2]|0;if(v){v=e+572684|0;ua=c[t>>2]|0;Ve[c[e+4>>2]&127](c[v>>2]|0,ta+(aa-2-(ua<<1))|0,ua,ua,21,21,da-2|0,$-2|0,Y,p);p=c[t>>2]|0;va=(c[v>>2]|0)+((p<<1)+2)|0;wa=p}else{va=ta+aa|0;wa=c[t>>2]|0}ef[c[X>>2]&4095](ja,va,wa);if(!sa){ef[c[X>>2]&4095](l+(ma+i)|0,va+i|0,c[t>>2]|0)}_e[oa&511](na,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(w<<4)+(u<<3)>>2]|0,c[e+177136+(w<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}va=e+6116|0;X=e+177132|0;_e[oa&511](ka,c[va>>2]|0,h,c[X>>2]|0,c[e+177904+(w<<5)+(u<<4)>>2]|0,c[e+177904+(w<<5)+(u<<4)+4>>2]|0);_e[oa&511](ja,c[va>>2]|0,h,c[X>>2]|0,c[e+177904+(w<<5)+(u<<4)+8>>2]|0,c[e+177904+(w<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;w=u+16|0;X=e+6116|0;va=c[X>>2]<<4;oa=u+va|0;sa=d[602328+f|0]|0;f=a[e+5632+sa|0]|0;wa=a[e+5672+sa|0]|0;aa=la<<3;la=(b[e+5312+(sa<<2)>>1]|0)+aa|0;ta=ba<<3;ba=(b[e+5312+(sa<<2)+2>>1]|0)+ta|0;p=ba<<2&12|la&3;v=la>>2;Y=ba>>2;$=(ca(Y,pa)|0)+v|0;da=c[e+199440+(f*2224|0)>>2]|0;ua=da+$|0;qa=e+427400|0;W=c[qa>>2]<<4;ra=e+427396|0;n=c[ra>>2]<<4>>q;q=(la&7|0)==0?0:-3;la=(ba&7|0)==0?0:-3;do{if((v|0)<(-q|0)){x=10}else{if((Y|0)<(-la|0)){x=10;break}if((v+16|0)>(q+W|0)){x=10;break}if((Y+16|0)>(n+la|0)){x=10}else{xa=ua;ya=0;za=pa}}}while(0);if((x|0)==10){ua=e+572684|0;Ve[c[e+4>>2]&127](c[ua>>2]|0,da+(-2-(pa<<1)+$)|0,pa,pa,21,21,v-2|0,Y-2|0,W,n);pa=c[t>>2]|0;xa=(c[ua>>2]|0)+((pa<<1)+2)|0;ya=1;za=pa}pa=o+(p<<2)|0;ef[c[pa>>2]&4095](na,xa,za);za=(g|0)!=0;if(!za){ef[c[pa>>2]&4095](j+(ma+i)|0,xa+i|0,c[t>>2]|0)}xa=c[e+199440+(f*2224|0)+4>>2]|0;j=(ya|0)!=0;if(j){ya=e+572684|0;g=c[t>>2]|0;Ve[c[e+4>>2]&127](c[ya>>2]|0,xa+($-2-(g<<1))|0,g,g,21,21,v-2|0,Y-2|0,W,n);g=c[t>>2]|0;Aa=(c[ya>>2]|0)+((g<<1)+2)|0;Ba=g}else{Aa=xa+$|0;Ba=c[t>>2]|0}ef[c[pa>>2]&4095](ka,Aa,Ba);if(!za){ef[c[pa>>2]&4095](k+(ma+i)|0,Aa+i|0,c[t>>2]|0)}Aa=c[e+199440+(f*2224|0)+8>>2]|0;if(j){j=e+572684|0;k=c[t>>2]|0;Ve[c[e+4>>2]&127](c[j>>2]|0,Aa+($-2-(k<<1))|0,k,k,21,21,v-2|0,Y-2|0,W,n);n=c[t>>2]|0;Ca=(c[j>>2]|0)+((n<<1)+2)|0;Da=n}else{Ca=Aa+$|0;Da=c[t>>2]|0}ef[c[pa>>2]&4095](ja,Ca,Da);if(!za){ef[c[pa>>2]&4095](l+(ma+i)|0,Ca+i|0,c[t>>2]|0)}Ca=(b[e+5472+(sa<<2)>>1]|0)+aa|0;aa=(b[e+5472+(sa<<2)+2>>1]|0)+ta|0;ta=aa<<2&12|Ca&3;sa=Ca>>2;ma=aa>>2;l=c[t>>2]|0;pa=(ca(ma,l)|0)+sa|0;Da=c[e+306192+(wa*2224|0)>>2]|0;$=Da+pa|0;Aa=c[qa>>2]<<4;qa=c[ra>>2]<<4>>c[J>>2];J=(Ca&7|0)==0?0:-3;Ca=(aa&7|0)==0?0:-3;do{if((sa|0)<(-J|0)){x=27}else{if((ma|0)<(-Ca|0)){x=27;break}if((sa+16|0)>(Aa+J|0)){x=27;break}if((ma+16|0)>(qa+Ca|0)){x=27}else{Ea=$;Fa=0;Ga=l}}}while(0);if((x|0)==27){x=e+572684|0;Ve[c[e+4>>2]&127](c[x>>2]|0,Da+(-2-(l<<1)+pa)|0,l,l,21,21,sa-2|0,ma-2|0,Aa,qa);l=c[t>>2]|0;Ea=(c[x>>2]|0)+((l<<1)+2)|0;Fa=1;Ga=l}l=o+(ta<<2)|0;ef[c[l>>2]&4095](oa,Ea,Ga);if(!za){ef[c[l>>2]&4095](u+(va+i)|0,Ea+i|0,c[t>>2]|0)}Ea=c[e+306192+(wa*2224|0)+4>>2]|0;va=(Fa|0)!=0;if(va){Fa=e+572684|0;Ga=c[t>>2]|0;Ve[c[e+4>>2]&127](c[Fa>>2]|0,Ea+(pa-2-(Ga<<1))|0,Ga,Ga,21,21,sa-2|0,ma-2|0,Aa,qa);Ga=c[t>>2]|0;Ha=(c[Fa>>2]|0)+((Ga<<1)+2)|0;Ia=Ga}else{Ha=Ea+pa|0;Ia=c[t>>2]|0}ef[c[l>>2]&4095](u,Ha,Ia);if(!za){ef[c[l>>2]&4095](u+i|0,Ha+i|0,c[t>>2]|0)}Ha=c[e+306192+(wa*2224|0)+8>>2]|0;if(va){va=e+572684|0;Ia=c[t>>2]|0;Ve[c[e+4>>2]&127](c[va>>2]|0,Ha+(pa-2-(Ia<<1))|0,Ia,Ia,21,21,sa-2|0,ma-2|0,Aa,qa);qa=c[t>>2]|0;Ja=(c[va>>2]|0)+((qa<<1)+2)|0;Ka=qa}else{Ja=Ha+pa|0;Ka=c[t>>2]|0}ef[c[l>>2]&4095](w,Ja,Ka);if(!za){ef[c[l>>2]&4095](u+(i+16)|0,Ja+i|0,c[t>>2]|0)}if((c[r>>2]|0)==2){r=c[e+179440+(f*384|0)+(wa<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-r|0;Ge[s&255](na,oa,c[t>>2]|0,h,5,r,m,0);Ge[s&255](ka,u,c[X>>2]|0,h,5,r,m,0);Ge[s&255](ja,w,c[X>>2]|0,h,5,r,m,0);return}else{Ge[s&255](na,oa,c[t>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(wa<<4)+8>>2]|0,(c[e+177136+(wa<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);t=e+177132|0;Ge[s&255](ka,u,c[X>>2]|0,h,c[t>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(wa<<5)+16>>2]|0,(c[e+177904+(wa<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Ge[s&255](ja,w,c[X>>2]|0,h,c[t>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(wa<<5)+24>>2]|0,(c[e+177904+(wa<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Uha(e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;var w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;r=e+177120|0;p=c[r>>2]|0;w=(u|0)==0;u=(v|0)==0;if((p|0)!=2|w|u){x=3}else{y=c[e+427380>>2]|0;z=d[602328+f|0]|0;if((c[e+179440+((a[e+5632+z|0]|0)*384|0)+(a[e+5672+z|0]<<3)+((y&1)<<2)>>2]|0)==32){x=3}else{A=y}}do{if((x|0)==3){if((p|0)==1){A=c[e+427380>>2]|0;break}y=c[e+4752>>2]|0;z=e+6112|0;B=c[z>>2]|0;C=(ca(n<<1,B)|0)+(m<<1<<y)|0;D=j+C|0;E=k+C|0;F=l+C|0;G=(c[e+427376>>2]<<3)+m|0;H=e+177092|0;I=c[H>>2]|0;J=(c[e+427380>>2]>>I<<3)+n|0;do{if(w){K=o}else{L=d[602328+f|0]|0;M=a[e+5632+L|0]|0;N=(b[e+5312+(L<<2)>>1]|0)+(G<<3)|0;O=(b[e+5312+(L<<2)+2>>1]|0)+(J<<3)|0;L=O<<2&12|N&3;P=N>>2;Q=O>>2;R=(ca(Q,B)|0)+(P<<y)|0;S=c[e+199440+(M*2224|0)>>2]|0;T=S+R|0;U=c[e+427400>>2]<<4;V=c[e+427396>>2]<<4>>I;W=(N&7|0)==0?0:-3;N=(O&7|0)==0?0:-3;do{if((P|0)<(-W|0)){x=67}else{if((Q|0)<(-N|0)){x=67;break}if((P+16|0)>(W+U|0)){x=67;break}if((Q+16|0)>(V+N|0)){x=67}else{X=T;Y=0;Z=B}}}while(0);if((x|0)==67){T=e+572684|0;N=2<<y;Ve[c[e+4>>2]&127](c[T>>2]|0,S+(R-((B<<1)+N))|0,B,B,21,21,P-2|0,Q-2|0,U,V);W=c[z>>2]|0;X=(c[T>>2]|0)+((W<<1)+N)|0;Y=1;Z=W}W=o+(L<<2)|0;ef[c[W>>2]&4095](D,X,Z);N=(g|0)!=0;if(!N){ef[c[W>>2]&4095](j+(C+i)|0,X+i|0,c[z>>2]|0)}T=c[e+199440+(M*2224|0)+4>>2]|0;O=(Y|0)!=0;if(O){_=e+572684|0;$=2<<y;aa=c[z>>2]|0;Ve[c[e+4>>2]&127](c[_>>2]|0,T+(R-$-(aa<<1))|0,aa,aa,21,21,P-2|0,Q-2|0,U,V);aa=c[z>>2]|0;ba=(c[_>>2]|0)+((aa<<1)+$)|0;da=aa}else{ba=T+R|0;da=c[z>>2]|0}ef[c[W>>2]&4095](E,ba,da);if(!N){ef[c[W>>2]&4095](k+(C+i)|0,ba+i|0,c[z>>2]|0)}T=c[e+199440+(M*2224|0)+8>>2]|0;if(O){O=e+572684|0;aa=2<<y;$=c[z>>2]|0;Ve[c[e+4>>2]&127](c[O>>2]|0,T+(R-aa-($<<1))|0,$,$,21,21,P-2|0,Q-2|0,U,V);$=c[z>>2]|0;ea=(c[O>>2]|0)+(($<<1)+aa)|0;fa=$}else{ea=T+R|0;fa=c[z>>2]|0}ef[c[W>>2]&4095](F,ea,fa);if(N){K=q;break}ef[c[W>>2]&4095](l+(C+i)|0,ea+i|0,c[z>>2]|0);K=q}}while(0);if(u){return}B=d[602328+f|0]|0;I=a[e+5672+B|0]|0;W=(b[e+5472+(B<<2)>>1]|0)+(G<<3)|0;N=(b[e+5472+(B<<2)+2>>1]|0)+(J<<3)|0;B=N<<2&12|W&3;T=W>>2;$=N>>2;aa=c[z>>2]|0;O=(ca($,aa)|0)+(T<<y)|0;_=c[e+306192+(I*2224|0)>>2]|0;ga=_+O|0;ha=c[e+427400>>2]<<4;ia=c[e+427396>>2]<<4>>c[H>>2];ja=(W&7|0)==0?0:-3;W=(N&7|0)==0?0:-3;do{if((T|0)<(-ja|0)){x=85}else{if(($|0)<(-W|0)){x=85;break}if((T+16|0)>(ha+ja|0)){x=85;break}if(($+16|0)>(ia+W|0)){x=85}else{ka=ga;la=0;ma=aa}}}while(0);if((x|0)==85){ga=e+572684|0;W=2<<y;Ve[c[e+4>>2]&127](c[ga>>2]|0,_+(O-((aa<<1)+W))|0,aa,aa,21,21,T-2|0,$-2|0,ha,ia);ja=c[z>>2]|0;ka=(c[ga>>2]|0)+((ja<<1)+W)|0;la=1;ma=ja}ja=K+(B<<2)|0;ef[c[ja>>2]&4095](D,ka,ma);W=(g|0)!=0;if(!W){ef[c[ja>>2]&4095](j+(C+i)|0,ka+i|0,c[z>>2]|0)}ga=c[e+306192+(I*2224|0)+4>>2]|0;H=(la|0)!=0;if(H){J=e+572684|0;G=2<<y;N=c[z>>2]|0;Ve[c[e+4>>2]&127](c[J>>2]|0,ga+(O-G-(N<<1))|0,N,N,21,21,T-2|0,$-2|0,ha,ia);N=c[z>>2]|0;na=(c[J>>2]|0)+((N<<1)+G)|0;oa=N}else{na=ga+O|0;oa=c[z>>2]|0}ef[c[ja>>2]&4095](E,na,oa);if(!W){ef[c[ja>>2]&4095](k+(C+i)|0,na+i|0,c[z>>2]|0)}ga=c[e+306192+(I*2224|0)+8>>2]|0;if(H){H=e+572684|0;N=2<<y;G=c[z>>2]|0;Ve[c[e+4>>2]&127](c[H>>2]|0,ga+(O-N-(G<<1))|0,G,G,21,21,T-2|0,$-2|0,ha,ia);G=c[z>>2]|0;pa=(c[H>>2]|0)+((G<<1)+N)|0;qa=G}else{pa=ga+O|0;qa=c[z>>2]|0}ef[c[ja>>2]&4095](F,pa,qa);if(W){return}ef[c[ja>>2]&4095](l+(C+i)|0,pa+i|0,c[z>>2]|0);return}}while(0);pa=c[s>>2]|0;s=c[t>>2]|0;t=c[e+4752>>2]|0;qa=e+6112|0;na=c[qa>>2]|0;oa=(ca(n<<1,na)|0)+(m<<1<<t)|0;la=j+oa|0;ka=k+oa|0;ma=l+oa|0;K=(c[e+427376>>2]<<3)+m|0;m=e+427380|0;q=e+177092|0;ea=c[q>>2]|0;fa=(A>>ea<<3)+n|0;if(w|u){u=(v|0)!=0|0;v=d[602328+f|0]|0;w=a[e+5632+(u*40|0)+v|0]|0;n=(b[e+5312+(u*160|0)+(v<<2)>>1]|0)+(K<<3)|0;A=(b[e+5312+(u*160|0)+(v<<2)+2>>1]|0)+(fa<<3)|0;v=A<<2&12|n&3;ba=n>>2;da=A>>2;Y=(ca(da,na)|0)+(ba<<t)|0;X=c[e+199440+(u*106752|0)+(w*2224|0)>>2]|0;Z=X+Y|0;p=c[e+427400>>2]<<4;ja=c[e+427396>>2]<<4>>ea;W=(n&7|0)==0?0:-3;n=(A&7|0)==0?0:-3;do{if((ba|0)<(-W|0)){x=47}else{if((da|0)<(-n|0)){x=47;break}if((ba+16|0)>(W+p|0)){x=47;break}if((da+16|0)>(ja+n|0)){x=47}else{ra=Z;sa=0;ta=na}}}while(0);if((x|0)==47){Z=e+572684|0;n=2<<t;Ve[c[e+4>>2]&127](c[Z>>2]|0,X+(Y-((na<<1)+n))|0,na,na,21,21,ba-2|0,da-2|0,p,ja);X=c[qa>>2]|0;ra=(c[Z>>2]|0)+((X<<1)+n)|0;sa=1;ta=X}X=o+(v<<2)|0;ef[c[X>>2]&4095](la,ra,ta);ta=(g|0)!=0;if(!ta){ef[c[X>>2]&4095](j+(oa+i)|0,ra+i|0,c[qa>>2]|0)}ra=c[e+199440+(u*106752|0)+(w*2224|0)+4>>2]|0;v=(sa|0)!=0;if(v){sa=e+572684|0;n=2<<t;Z=c[qa>>2]|0;Ve[c[e+4>>2]&127](c[sa>>2]|0,ra+(Y-n-(Z<<1))|0,Z,Z,21,21,ba-2|0,da-2|0,p,ja);Z=c[qa>>2]|0;ua=(c[sa>>2]|0)+((Z<<1)+n)|0;va=Z}else{ua=ra+Y|0;va=c[qa>>2]|0}ef[c[X>>2]&4095](ka,ua,va);if(!ta){ef[c[X>>2]&4095](k+(oa+i)|0,ua+i|0,c[qa>>2]|0)}ua=c[e+199440+(u*106752|0)+(w*2224|0)+8>>2]|0;if(v){v=e+572684|0;va=2<<t;ra=c[qa>>2]|0;Ve[c[e+4>>2]&127](c[v>>2]|0,ua+(Y-va-(ra<<1))|0,ra,ra,21,21,ba-2|0,da-2|0,p,ja);ja=c[qa>>2]|0;wa=(c[v>>2]|0)+((ja<<1)+va)|0;xa=ja}else{wa=ua+Y|0;xa=c[qa>>2]|0}ef[c[X>>2]&4095](ma,wa,xa);if(!ta){ef[c[X>>2]&4095](l+(oa+i)|0,wa+i|0,c[qa>>2]|0)}_e[pa&511](la,c[qa>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(w<<4)+(u<<3)>>2]|0,c[e+177136+(w<<4)+(u<<3)+4>>2]|0);if((c[e+177124>>2]|0)==0){return}wa=e+6116|0;X=e+177132|0;_e[pa&511](ka,c[wa>>2]|0,h,c[X>>2]|0,c[e+177904+(w<<5)+(u<<4)>>2]|0,c[e+177904+(w<<5)+(u<<4)+4>>2]|0);_e[pa&511](ma,c[wa>>2]|0,h,c[X>>2]|0,c[e+177904+(w<<5)+(u<<4)+8>>2]|0,c[e+177904+(w<<5)+(u<<4)+12>>2]|0);return}u=c[e+572636>>2]|0;w=16<<t;X=u+w|0;wa=e+6116|0;pa=c[wa>>2]<<4;ta=u+pa|0;xa=d[602328+f|0]|0;f=a[e+5632+xa|0]|0;Y=a[e+5672+xa|0]|0;ua=K<<3;K=(b[e+5312+(xa<<2)>>1]|0)+ua|0;ja=fa<<3;fa=(b[e+5312+(xa<<2)+2>>1]|0)+ja|0;va=fa<<2&12|K&3;v=K>>2;p=fa>>2;da=(ca(p,na)|0)+(v<<t)|0;ba=c[e+199440+(f*2224|0)>>2]|0;ra=ba+da|0;Z=e+427400|0;n=c[Z>>2]<<4;sa=e+427396|0;W=c[sa>>2]<<4>>ea;ea=(K&7|0)==0?0:-3;K=(fa&7|0)==0?0:-3;do{if((v|0)<(-ea|0)){x=10}else{if((p|0)<(-K|0)){x=10;break}if((v+16|0)>(ea+n|0)){x=10;break}if((p+16|0)>(W+K|0)){x=10}else{ya=ra;za=0;Aa=na}}}while(0);if((x|0)==10){ra=e+572684|0;K=2<<t;Ve[c[e+4>>2]&127](c[ra>>2]|0,ba+(da-((na<<1)+K))|0,na,na,21,21,v-2|0,p-2|0,n,W);na=c[qa>>2]|0;ya=(c[ra>>2]|0)+((na<<1)+K)|0;za=1;Aa=na}na=o+(va<<2)|0;ef[c[na>>2]&4095](la,ya,Aa);Aa=(g|0)!=0;if(!Aa){ef[c[na>>2]&4095](j+(oa+i)|0,ya+i|0,c[qa>>2]|0)}ya=c[e+199440+(f*2224|0)+4>>2]|0;j=(za|0)!=0;if(j){za=e+572684|0;g=2<<t;va=c[qa>>2]|0;Ve[c[e+4>>2]&127](c[za>>2]|0,ya+(da-g-(va<<1))|0,va,va,21,21,v-2|0,p-2|0,n,W);va=c[qa>>2]|0;Ba=(c[za>>2]|0)+((va<<1)+g)|0;Ca=va}else{Ba=ya+da|0;Ca=c[qa>>2]|0}ef[c[na>>2]&4095](ka,Ba,Ca);if(!Aa){ef[c[na>>2]&4095](k+(oa+i)|0,Ba+i|0,c[qa>>2]|0)}Ba=c[e+199440+(f*2224|0)+8>>2]|0;if(j){j=e+572684|0;k=2<<t;Ca=c[qa>>2]|0;Ve[c[e+4>>2]&127](c[j>>2]|0,Ba+(da-k-(Ca<<1))|0,Ca,Ca,21,21,v-2|0,p-2|0,n,W);W=c[qa>>2]|0;Da=(c[j>>2]|0)+((W<<1)+k)|0;Ea=W}else{Da=Ba+da|0;Ea=c[qa>>2]|0}ef[c[na>>2]&4095](ma,Da,Ea);if(!Aa){ef[c[na>>2]&4095](l+(oa+i)|0,Da+i|0,c[qa>>2]|0)}Da=(b[e+5472+(xa<<2)>>1]|0)+ua|0;ua=(b[e+5472+(xa<<2)+2>>1]|0)+ja|0;ja=ua<<2&12|Da&3;xa=Da>>2;oa=ua>>2;l=c[qa>>2]|0;na=(ca(oa,l)|0)+(xa<<t)|0;Ea=c[e+306192+(Y*2224|0)>>2]|0;da=Ea+na|0;Ba=c[Z>>2]<<4;Z=c[sa>>2]<<4>>c[q>>2];q=(Da&7|0)==0?0:-3;Da=(ua&7|0)==0?0:-3;do{if((xa|0)<(-q|0)){x=27}else{if((oa|0)<(-Da|0)){x=27;break}if((xa+16|0)>(Ba+q|0)){x=27;break}if((oa+16|0)>(Z+Da|0)){x=27}else{Fa=da;Ga=0;Ha=l}}}while(0);if((x|0)==27){x=e+572684|0;da=2<<t;Ve[c[e+4>>2]&127](c[x>>2]|0,Ea+(na-((l<<1)+da))|0,l,l,21,21,xa-2|0,oa-2|0,Ba,Z);l=c[qa>>2]|0;Fa=(c[x>>2]|0)+((l<<1)+da)|0;Ga=1;Ha=l}l=o+(ja<<2)|0;ef[c[l>>2]&4095](ta,Fa,Ha);if(!Aa){ef[c[l>>2]&4095](u+(pa+i)|0,Fa+i|0,c[qa>>2]|0)}Fa=c[e+306192+(Y*2224|0)+4>>2]|0;pa=(Ga|0)!=0;if(pa){Ga=e+572684|0;Ha=2<<t;ja=c[qa>>2]|0;Ve[c[e+4>>2]&127](c[Ga>>2]|0,Fa+(na-Ha-(ja<<1))|0,ja,ja,21,21,xa-2|0,oa-2|0,Ba,Z);ja=c[qa>>2]|0;Ia=(c[Ga>>2]|0)+((ja<<1)+Ha)|0;Ja=ja}else{Ia=Fa+na|0;Ja=c[qa>>2]|0}ef[c[l>>2]&4095](u,Ia,Ja);if(!Aa){ef[c[l>>2]&4095](u+i|0,Ia+i|0,c[qa>>2]|0)}Ia=c[e+306192+(Y*2224|0)+8>>2]|0;if(pa){pa=e+572684|0;Ja=2<<t;t=c[qa>>2]|0;Ve[c[e+4>>2]&127](c[pa>>2]|0,Ia+(na-Ja-(t<<1))|0,t,t,21,21,xa-2|0,oa-2|0,Ba,Z);Z=c[qa>>2]|0;Ka=(c[pa>>2]|0)+((Z<<1)+Ja)|0;La=Z}else{Ka=Ia+na|0;La=c[qa>>2]|0}ef[c[l>>2]&4095](X,Ka,La);if(!Aa){ef[c[l>>2]&4095](u+(w+i)|0,Ka+i|0,c[qa>>2]|0)}if((c[r>>2]|0)==2){r=c[e+179440+(f*384|0)+(Y<<3)+((c[m>>2]&1)<<2)>>2]|0;m=64-r|0;Ge[s&255](la,ta,c[qa>>2]|0,h,5,r,m,0);Ge[s&255](ka,u,c[wa>>2]|0,h,5,r,m,0);Ge[s&255](ma,X,c[wa>>2]|0,h,5,r,m,0);return}else{Ge[s&255](la,ta,c[qa>>2]|0,h,c[e+177128>>2]|0,c[e+177136+(f<<4)>>2]|0,c[e+177136+(Y<<4)+8>>2]|0,(c[e+177136+(Y<<4)+12>>2]|0)+(c[e+177136+(f<<4)+4>>2]|0)|0);qa=e+177132|0;Ge[s&255](ka,u,c[wa>>2]|0,h,c[qa>>2]|0,c[e+177904+(f<<5)>>2]|0,c[e+177904+(Y<<5)+16>>2]|0,(c[e+177904+(Y<<5)+20>>2]|0)+(c[e+177904+(f<<5)+4>>2]|0)|0);Ge[s&255](ma,X,c[wa>>2]|0,h,c[qa>>2]|0,c[e+177904+(f<<5)+8>>2]|0,c[e+177904+(Y<<5)+24>>2]|0,(c[e+177904+(Y<<5)+28>>2]|0)+(c[e+177904+(f<<5)+12>>2]|0)|0);return}}function Vha(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(c[b+4792>>2]|0)+48+((c[b+7308>>2]|0)*-6|0)|0;if((d|0)<0){e=0}else{e=(d|0)>51?51:d}if((c[b+177080>>2]|0)==1){f=1895104}else{f=1888960+(c[b+572244>>2]<<11)|0}d=0;do{g=(ca(a[f+(d<<1)|0]|0,e)|0)>>4;h=(g+(a[f+(d<<1)+1|0]|0)<<1)-127|0;g=h>>31^h;if((g|0)>124){i=(g&1|124)&255}else{i=g&255}a[b+425536+d|0]=i;d=d+1|0;}while((d|0)<1024);return}function Wha(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0;g=i;i=i+120|0;h=g|0;j=g+16|0;k=g+24|0;l=g+32|0;m=g+40|0;n=g+56|0;o=g+64|0;p=g+72|0;q=g+80|0;r=g+88|0;s=g+96|0;t=g+104|0;u=g+112|0;v=c[f+7392>>2]|0;w=f+6136|0;x=((c[w>>2]|0)-1|0)>>>0<2>>>0;y=c[f+4752>>2]|0;z=f+427376|0;A=c[z>>2]|0;B=f+427380|0;C=c[B>>2]|0;D=f+427404|0;E=(ca(c[D>>2]|0,C)|0)+A|0;F=f+427412|0;c[F>>2]=E;G=f+177080|0;H=f+177088|0;do{if((c[G>>2]|0)!=1){do{if((c[H>>2]|0)==0){I=6}else{if((C&1|0)==0){I=6;break}if((c[f+4824>>2]|0)==0){I=6;break}J=c[f+4828>>2]|0}}while(0);if((I|0)==6){J=Xha(f,A,C)|0}if((J|0)==0){break}do{if((c[H>>2]|0)!=0){if((c[B>>2]&1|0)!=0){break}K=f+4064|0;c[(c[K>>2]|0)+(E<<2)>>2]=2048;L=Xha(f,c[z>>2]|0,(c[B>>2]|0)+1|0)|0;c[f+4828>>2]=L;if((L|0)!=0){break}L=(c[F>>2]|0)-(c[D>>2]<<1)|0;M=f+177092|0;N=Zha(f+425488|0,((e[(c[f+177072>>2]|0)+(L<<1)>>1]|0)==(c[f+177068>>2]|0)&(c[(c[K>>2]|0)+(L<<2)>>2]|0)>>>7)+((c[z>>2]|0)!=0&c[M>>2]|70)+(f+425536)|0)|0;c[M>>2]=N;c[f+177096>>2]=N}}while(0);N=c[F>>2]|0;c[j>>2]=0;mrc((c[f+5304>>2]|0)+(N*48|0)|0,0,48)|0;M=f+177092|0;if((c[M>>2]|0)==0){O=0}else{c[j>>2]=128;O=128}a:do{if((c[G>>2]|0)==3){L=O|63744;c[j>>2]=L;if((c[f+197872>>2]|0)!=0){Yha(f,L);$ha(f,c[j>>2]|0)}nia(f,j);c[j>>2]=c[j>>2]|2048;P=c[f+6108>>2]|0}else{L=O|14344;c[j>>2]=L;Yha(f,L);L=h;K=c[f+4084>>2]|0;Q=c[f+4052>>2]|0;R=c[f+6108>>2]|0;c[f+5644>>2]=0;c[f+5652>>2]=0;c[f+5660>>2]=0;c[f+5668>>2]=0;S=c[f+4872>>2]|0;if((S&12288|0)==0){if((S|0)!=0){T=5453640;U=-1;I=27}}else{V=c[f+4852>>2]|0;W=d[c[f+4880>>2]|0]|0;X=a[K+((W&254)+(V<<2|1))|0]|0;Y=Q+((ca(W,R)|0)+3+(c[(c[f+6100>>2]|0)+(V<<2)>>2]|0)<<2)|0;do{if((c[H>>2]|0)==0){Z=Y;_=X}else{V=(S&128|0)!=0;if((c[M>>2]|0)==0){if(!V){Z=Y;_=X;break}W=c[Y>>2]|0;c[h>>2]=W;b[h+2>>1]=W>>>16<<1;Z=h;_=X>>1;break}else{if(V){Z=Y;_=X;break}V=c[Y>>2]|0;c[h>>2]=V;b[h+2>>1]=(V>>16|0)/2|0;Z=h;_=X<<1;break}}}while(0);if((c[Z>>2]|_|0)!=0){T=Z;U=_;I=27}}do{if((I|0)==27){X=c[f+4864>>2]|0;if((X&12288|0)==0){if((X|0)==0){break}else{$=-1;aa=5453640}}else{Y=c[f+4844>>2]|0;S=a[K+(Y<<2|2)|0]|0;V=Q+((c[(c[f+6100>>2]|0)+(Y<<2)>>2]|0)+(R*3|0)<<2)|0;do{if((c[H>>2]|0)==0){ba=S;da=V}else{Y=(X&128|0)!=0;if((c[M>>2]|0)==0){if(!Y){ba=S;da=V;break}W=c[V>>2]|0;ea=h+4|0;c[ea>>2]=W;b[L+6>>1]=W>>>16<<1;ba=S>>1;da=ea;break}else{if(Y){ba=S;da=V;break}Y=c[V>>2]|0;ea=h+4|0;c[ea>>2]=Y;b[L+6>>1]=(Y>>16|0)/2|0;ba=S<<1;da=ea;break}}}while(0);if((c[da>>2]|ba|0)==0){break}else{$=ba;aa=da}}S=c[f+4868>>2]|0;do{if((S&12288|0)==0){if((S|0)!=0){fa=5453640;ga=-1;break}V=c[f+4860>>2]|0;if((V&12288|0)==0){fa=5453640;ga=(V|0)==0?-2:-1;break}X=c[f+4840>>2]|0;ea=c[f+4884>>2]|0;Y=a[K+(X<<2|ea&2|1)|0]|0;W=Q+(R+3+(ea&R<<1)+(c[(c[f+6100>>2]|0)+(X<<2)>>2]|0)<<2)|0;if((c[H>>2]|0)==0){fa=W;ga=Y;break}X=(V&128|0)!=0;if((c[M>>2]|0)==0){if(!X){fa=W;ga=Y;break}V=c[W>>2]|0;ea=h+8|0;c[ea>>2]=V;b[L+10>>1]=V>>>16<<1;fa=ea;ga=Y>>1;break}else{if(X){fa=W;ga=Y;break}X=c[W>>2]|0;W=h+8|0;c[W>>2]=X;b[L+10>>1]=(X>>16|0)/2|0;fa=W;ga=Y<<1;break}}else{Y=c[f+4848>>2]|0;W=a[K+(Y<<2|2)|0]|0;X=Q+((c[(c[f+6100>>2]|0)+(Y<<2)>>2]|0)+(R*3|0)<<2)|0;if((c[H>>2]|0)==0){fa=X;ga=W;break}Y=(S&128|0)!=0;if((c[M>>2]|0)==0){if(!Y){fa=X;ga=W;break}ea=c[X>>2]|0;V=h+8|0;c[V>>2]=ea;b[L+10>>1]=ea>>>16<<1;fa=V;ga=W>>1;break}else{if(Y){fa=X;ga=W;break}Y=c[X>>2]|0;X=h+8|0;c[X>>2]=Y;b[L+10>>1]=(Y>>16|0)/2|0;fa=X;ga=W<<1;break}}}while(0);S=($|0)!=0;W=(U|0)!=0;X=(S&1^1)+(W&1^1)+((ga|0)==0)|0;do{if((X|0)>1){Y=b[T>>1]|0;V=Y<<16>>16;ea=b[aa>>1]|0;ha=ea<<16>>16;ia=b[fa>>1]|0;ja=ia<<16>>16;do{if(Y<<16>>16>ea<<16>>16){if(!(ia<<16>>16>ea<<16>>16)){ka=ha;break}ka=(ja|0)>(V|0)?V:ja}else{if(!(ea<<16>>16>ia<<16>>16)){ka=ha;break}ka=(ja|0)>(V|0)?ja:V}}while(0);V=b[T+2>>1]|0;ja=V<<16>>16;ha=b[aa+2>>1]|0;ia=ha<<16>>16;ea=b[fa+2>>1]|0;Y=ea<<16>>16;if(V<<16>>16>ha<<16>>16){if(!(ea<<16>>16>ha<<16>>16)){la=ia;ma=ka;break}la=(Y|0)>(ja|0)?ja:Y;ma=ka;break}else{if(!(ha<<16>>16>ea<<16>>16)){la=ia;ma=ka;break}la=(Y|0)>(ja|0)?Y:ja;ma=ka;break}}else{if((X|0)==1){if(!W){la=b[T+2>>1]|0;ma=b[T>>1]|0;break}if(S){la=b[fa+2>>1]|0;ma=b[fa>>1]|0;break}else{la=b[aa+2>>1]|0;ma=b[aa>>1]|0;break}}ja=b[T>>1]|0;Y=ja<<16>>16;ia=b[aa>>1]|0;ea=ia<<16>>16;ha=b[fa>>1]|0;V=ha<<16>>16;do{if(ja<<16>>16>ia<<16>>16){if(!(ha<<16>>16>ia<<16>>16)){na=ea;break}na=(V|0)>(Y|0)?Y:V}else{if(!(ia<<16>>16>ha<<16>>16)){na=ea;break}na=(V|0)>(Y|0)?V:Y}}while(0);Y=b[T+2>>1]|0;V=Y<<16>>16;ea=b[aa+2>>1]|0;ha=ea<<16>>16;ia=b[fa+2>>1]|0;ja=ia<<16>>16;if(Y<<16>>16>ea<<16>>16){if(!(ia<<16>>16>ea<<16>>16)){la=ha;ma=na;break}la=(ja|0)>(V|0)?V:ja;ma=na;break}else{if(!(ea<<16>>16>ia<<16>>16)){la=ha;ma=na;break}la=(ja|0)>(V|0)?ja:V;ma=na;break}}}while(0);S=la<<16|ma&65535;c[f+5360>>2]=S;c[f+5364>>2]=S;c[f+5368>>2]=S;c[f+5372>>2]=S;c[f+5392>>2]=S;c[f+5396>>2]=S;c[f+5400>>2]=S;c[f+5404>>2]=S;c[f+5424>>2]=S;c[f+5428>>2]=S;c[f+5432>>2]=S;c[f+5436>>2]=S;c[f+5456>>2]=S;c[f+5460>>2]=S;c[f+5464>>2]=S;c[f+5468>>2]=S;P=R;break a}}while(0);mrc(f+5360|0,0,16)|0;mrc(f+5392|0,0,16)|0;mrc(f+5424|0,0,16)|0;mrc(f+5456|0,0,16)|0;P=R}}while(0);M=c[j>>2]|0;L=(ca(P<<2,c[B>>2]|0)|0)+(c[z>>2]<<2)|0;Q=c[F>>2]<<2;if((M&12288|0)==0){K=c[f+4084>>2]|0;b[K+Q>>1]=-1;b[K+(Q|2)>>1]=-1}else{K=c[f+4052>>2]|0;S=f+5360|0;W=c[S+4>>2]|0;X=K+(L<<2)|0;c[X>>2]=c[S>>2];c[X+4>>2]=W;W=f+5368|0;X=c[W+4>>2]|0;S=K+((L|2)<<2)|0;c[S>>2]=c[W>>2];c[S+4>>2]=X;X=f+5392|0;S=c[X+4>>2]|0;W=L+P|0;V=K+(W<<2)|0;c[V>>2]=c[X>>2];c[V+4>>2]=S;S=f+5400|0;V=c[S+4>>2]|0;X=K+(W+2<<2)|0;c[X>>2]=c[S>>2];c[X+4>>2]=V;V=f+5424|0;X=c[V+4>>2]|0;S=L+(P<<1)|0;W=K+(S<<2)|0;c[W>>2]=c[V>>2];c[W+4>>2]=X;X=f+5432|0;W=c[X+4>>2]|0;V=K+(S+2<<2)|0;c[V>>2]=c[X>>2];c[V+4>>2]=W;W=f+5456|0;V=c[W+4>>2]|0;X=L+(P*3|0)|0;S=K+(X<<2)|0;c[S>>2]=c[W>>2];c[S+4>>2]=V;V=f+5464|0;S=c[V+4>>2]|0;W=K+(X+2<<2)|0;c[W>>2]=c[V>>2];c[W+4>>2]=S;S=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;W=c[f+426584>>2]|0;V=W+(S<<1)|0;if((M&2048|0)==0){X=f+426664|0;K=c[X+4>>2]|0;ja=V;c[ja>>2]=c[X>>2];c[ja+4>>2]=K;b[W+(S+6<<1)>>1]=b[f+426622>>1]|0;b[W+(S+5<<1)>>1]=b[f+426638>>1]|0;b[W+(S+4<<1)>>1]=b[f+426654>>1]|0}else{mrc(V|0,0,16)|0}V=c[f+4084>>2]|0;a[V+Q|0]=a[f+5644|0]|0;a[V+(Q|1)|0]=a[f+5646|0]|0;a[V+(Q|2)|0]=a[f+5660|0]|0;a[V+(Q|3)|0]=a[f+5662|0]|0}if((M&49152|0)!=0){V=c[f+4056>>2]|0;S=f+5520|0;W=c[S+4>>2]|0;K=V+(L<<2)|0;c[K>>2]=c[S>>2];c[K+4>>2]=W;W=f+5528|0;K=c[W+4>>2]|0;S=V+((L|2)<<2)|0;c[S>>2]=c[W>>2];c[S+4>>2]=K;K=f+5552|0;S=c[K+4>>2]|0;W=L+P|0;ja=V+(W<<2)|0;c[ja>>2]=c[K>>2];c[ja+4>>2]=S;S=f+5560|0;ja=c[S+4>>2]|0;K=V+(W+2<<2)|0;c[K>>2]=c[S>>2];c[K+4>>2]=ja;ja=f+5584|0;K=c[ja+4>>2]|0;S=L+(P<<1)|0;W=V+(S<<2)|0;c[W>>2]=c[ja>>2];c[W+4>>2]=K;K=f+5592|0;W=c[K+4>>2]|0;ja=V+(S+2<<2)|0;c[ja>>2]=c[K>>2];c[ja+4>>2]=W;W=f+5616|0;ja=c[W+4>>2]|0;K=L+(P*3|0)|0;L=V+(K<<2)|0;c[L>>2]=c[W>>2];c[L+4>>2]=ja;ja=f+5624|0;L=c[ja+4>>2]|0;W=V+(K+2<<2)|0;c[W>>2]=c[ja>>2];c[W+4>>2]=L;L=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;W=c[f+426588>>2]|0;ja=W+(L<<1)|0;if((M&2048|0)==0){K=f+426744|0;V=c[K+4>>2]|0;S=ja;c[S>>2]=c[K>>2];c[S+4>>2]=V;b[W+(L+6<<1)>>1]=b[f+426702>>1]|0;b[W+(L+5<<1)>>1]=b[f+426718>>1]|0;b[W+(L+4<<1)>>1]=b[f+426734>>1]|0}else{mrc(ja|0,0,16)|0}ja=c[f+4088>>2]|0;a[ja+Q|0]=a[f+5684|0]|0;a[ja+(Q|1)|0]=a[f+5686|0]|0;a[ja+(Q|2)|0]=a[f+5700|0]|0;a[ja+(Q|3)|0]=a[f+5702|0]|0}do{if((c[G>>2]|0)==3){if((M&64|0)==0){break}Q=c[F>>2]<<2;ja=c[f+426752>>2]|0;a[ja+(Q|1)|0]=(e[f+177114>>1]|0)>>>1;a[ja+(Q|2)|0]=(e[f+177116>>1]|0)>>>1;a[ja+(Q|3)|0]=(e[f+177118>>1]|0)>>>1}}while(0);c[(c[f+4064>>2]|0)+(N<<2)>>2]=c[j>>2];a[(c[f+4040>>2]|0)+N|0]=c[f+4792>>2];b[(c[f+177072>>2]|0)+(N<<1)>>1]=c[f+177068>>2];c[f+4824>>2]=1;b[(c[f+426560>>2]|0)+(E<<1)>>1]=0;a[(c[f+426576>>2]|0)+E|0]=0;c[f+426580>>2]=0;oa=0;i=g;return oa|0}}while(0);do{if((c[H>>2]|0)!=0){if((c[B>>2]&1|0)!=0){break}j=(c[F>>2]|0)-(c[D>>2]<<1)|0;P=f+177092|0;ma=Zha(f+425488|0,((e[(c[f+177072>>2]|0)+(j<<1)>>1]|0)==(c[f+177068>>2]|0)&(c[(c[f+4064>>2]|0)+(j<<2)>>2]|0)>>>7)+((c[z>>2]|0)!=0&c[P>>2]|70)+(f+425536)|0)|0;c[P>>2]=ma;c[f+177096>>2]=ma}}while(0);c[f+4824>>2]=0;ma=f+177092|0;Yha(f,-(c[ma>>2]|0)|0);P=c[G>>2]|0;b:do{if((P|0)==3){j=f+425488|0;do{if((Zha(j,28-(((c[f+4872>>2]|0)+511|0)>>>8&1)+(((c[f+4864>>2]|0)+511|0)>>>8&1^1)+(f+425536)|0)|0)==0){c[k>>2]=0;pa=0}else{if((Zha(j,f+425566|0)|0)==0){la=(Zha(j,f+425568|0)|0)+1|0;c[k>>2]=la;pa=la;break}la=(Zha(j,f+425567|0)|0)<<3;na=f+425568|0;fa=((Zha(j,na)|0)<<2)+la|0;la=fa+((Zha(j,na)|0)<<1)|0;fa=la+(Zha(j,na)|0)|0;if((fa|0)<8){la=fa+3|0;c[k>>2]=la;pa=la;break}if((fa|0)==13){la=_ha(f,32,0)|0;c[k>>2]=la;qa=la;I=120;break b}else if((fa|0)==14){c[k>>2]=11;pa=11;break}else if((fa|0)==15){c[k>>2]=22;pa=22;break}else{la=(fa<<1)-4+(Zha(j,na)|0)|0;c[k>>2]=la;pa=la;break}}}while(0);j=d[1960602+(pa<<2)|0]|0;N=e[1960600+(pa<<2)>>1]|0;c[k>>2]=N;ra=j;sa=0;ta=N}else if((P|0)==2){N=f+425488|0;if((Zha(N,f+425550|0)|0)!=0){j=_ha(f,17,0)|0;c[k>>2]=j;qa=j;I=120;break}if((Zha(N,f+425551|0)|0)==0){ua=(Zha(N,f+425552|0)|0)*3|0}else{ua=2-(Zha(N,f+425553|0)|0)|0}N=d[736650+(ua<<2)|0]|0;j=e[736648+(ua<<2)>>1]|0;c[k>>2]=j;ra=N;sa=0;ta=j}else{j=_ha(f,3,1)|0;c[k>>2]=j;if((c[f+177076>>2]|0)!=5|(j|0)==0){qa=j;I=120;break}N=j-1|0;c[k>>2]=N;qa=N;I=120}}while(0);if((I|0)==120){ua=d[1077979+(qa<<2)|0]|0;c[f+4836>>2]=d[1077978+(qa<<2)|0]|0;P=e[1077976+(qa<<2)>>1]|0;c[k>>2]=P;ra=0;sa=ua;ta=P}if((c[ma>>2]|0)==0){va=ta}else{P=ta|128;c[k>>2]=P;va=P}b[(c[f+177072>>2]|0)+(E<<1)>>1]=c[f+177068>>2];if((va&4|0)!=0){P=(ca(e[1375896+(c[w>>2]<<1)>>1]|0,c[f+7308>>2]|0)|0)>>3;ta=f+425488|0;ua=c[f+425504>>2]|0;qa=c[ta>>2]|0;pa=(qa&1|0)==0?ua:ua-1|0;ua=(qa&511|0)==0?pa:pa-1|0;pa=c[f+425508>>2]|0;if((pa-ua|0)<(P|0)){oa=-1;i=g;return oa|0}c[f+421184>>2]=ua;qa=ua+P|0;Hmb(ta,qa,pa-qa|0);b[(c[f+426560>>2]|0)+(E<<1)>>1]=-2065;a[(c[f+426576>>2]|0)+E|0]=0;a[(c[f+4040>>2]|0)+E|0]=0;mrc((c[f+5304>>2]|0)+(E*48|0)|0,16,48)|0;c[(c[f+4064>>2]|0)+(E<<2)>>2]=c[k>>2];c[f+426580>>2]=0;oa=0;i=g;return oa|0}qa=c[f+177096>>2]|0;c[l>>2]=c[f+199420>>2]<<qa;c[l+4>>2]=c[f+199424>>2]<<qa;$ha(f,va);va=c[k>>2]|0;c:do{if((va&7|0)==0){if((ra|0)==4){qa=f+425488|0;do{if((c[G>>2]|0)==3){pa=f+425572|0;ta=f+425573|0;P=f+425575|0;ua=f+425574|0;N=0;do{d:do{if((bia(qa,pa)|0)==0){wa=0}else{if((bia(qa,ta)|0)==0){wa=(bia(qa,P)|0)+1|0;break}do{if((bia(qa,ua)|0)==0){xa=3}else{if((bia(qa,P)|0)==0){xa=7;break}wa=(bia(qa,P)|0)+11|0;break d}}while(0);j=((bia(qa,P)|0)<<1)+xa|0;wa=j+(bia(qa,P)|0)|0}}while(0);c[m+(N<<2)>>2]=d[1960450+((wa&65535)<<2)|0]|0;b[f+177112+(N<<1)>>1]=b[1960448+((wa&65535)<<2)>>1]|0;N=N+1|0;}while((N|0)<4);N=f+177112|0;P=f+177114|0;ua=f+177116|0;ta=f+177118|0;if(((b[P>>1]|b[N>>1]|b[ua>>1]|b[ta>>1])&256)==0){break}nia(f,k);a[f+5702|0]=-2;a[f+5662|0]=-2;a[f+5686|0]=-2;a[f+5646|0]=-2;pa=((e[N>>1]|0)>>>1&255)*257&65535;b[f+426768>>1]=pa;b[f+426776>>1]=pa;pa=((e[P>>1]|0)>>>1&255)*257&65535;b[f+426770>>1]=pa;b[f+426778>>1]=pa;pa=((e[ua>>1]|0)>>>1&255)*257&65535;b[f+426784>>1]=pa;b[f+426792>>1]=pa;pa=((e[ta>>1]|0)>>>1&255)*257&65535;b[f+426786>>1]=pa;b[f+426794>>1]=pa}else{pa=f+425557|0;ta=f+425558|0;ua=f+425559|0;do{if((bia(qa,pa)|0)==0){if((bia(qa,ta)|0)==0){ya=1;break}P=(bia(qa,ua)|0)==0;ya=P?3:2}else{ya=0}}while(0);c[m>>2]=d[736610+(ya<<2)|0]|0;b[f+177112>>1]=b[736608+(ya<<2)>>1]|0;do{if((bia(qa,pa)|0)==0){if((bia(qa,ta)|0)==0){za=1;break}P=(bia(qa,ua)|0)==0;za=P?3:2}else{za=0}}while(0);c[m+4>>2]=d[736610+(za<<2)|0]|0;b[f+177114>>1]=b[736608+(za<<2)>>1]|0;do{if((bia(qa,pa)|0)==0){if((bia(qa,ta)|0)==0){Aa=1;break}P=(bia(qa,ua)|0)==0;Aa=P?3:2}else{Aa=0}}while(0);c[m+8>>2]=d[736610+(Aa<<2)|0]|0;b[f+177116>>1]=b[736608+(Aa<<2)>>1]|0;do{if((bia(qa,pa)|0)==0){if((bia(qa,ta)|0)==0){Ba=1;break}P=(bia(qa,ua)|0)==0;Ba=P?3:2}else{Ba=0}}while(0);c[m+12>>2]=d[736610+(Ba<<2)|0]|0;b[f+177118>>1]=b[736608+(Ba<<2)>>1]|0}}while(0);qa=f+199428|0;e:do{if((c[qa>>2]|0)==0){Ca=0}else{ua=f+425488|0;ta=0;f:while(1){pa=4096<<(ta<<1);P=l+(ta<<2)|0;N=0;do{R=e[f+177112+(N<<1)>>1]|0;if((R&256|0)==0){do{if((R&pa|0)==0){Da=-1}else{Ea=c[P>>2]|0;if(!(Ea>>>0>1>>>0)){Da=0;break}j=d[602272+(N<<2)|0]|0;la=j-1|0;na=j-8|0;j=a[f+5632+(ta*40|0)+na|0]|0;fa=(a[f+5632+(ta*40|0)+la|0]|0)>0;do{if((c[G>>2]|0)==3){if(fa){Fa=(d[f+426756+la|0]|0)>>>7&255^1}else{Fa=0}if(!(j<<24>>24>0)){Ga=Fa;Ha=0;break}Ga=(a[f+426756+na|0]|0)<0?Fa:Fa|2;Ha=0}else{aa=fa&1;if(!(j<<24>>24>0)){Ga=aa;Ha=0;break}Ga=aa|2;Ha=0}}while(0);while(1){if((bia(ua,Ga+54+(f+425536)|0)|0)==0){break}j=Ha+1|0;if((j|0)>31){Ia=-1;break f}else{Ga=(Ga>>2)+4|0;Ha=j}}if(Ha>>>0<Ea>>>0){Da=Ha&255}else{Ia=Ha;break f}}}while(0);R=d[602272+(N<<2)|0]|0;a[R+9+(f+5632+(ta*40|0))|0]=Da;a[R+8+(f+5632+(ta*40|0))|0]=Da;a[R+1+(f+5632+(ta*40|0))|0]=Da}N=N+1|0;}while((N|0)<4);N=ta+1|0;P=c[qa>>2]|0;if(N>>>0<P>>>0){ta=N}else{Ca=P;break e}}KIb(c[f>>2]|0,16,2543472,(Ja=i,i=i+16|0,c[Ja>>2]=Ia,c[Ja+8>>2]=Ea,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}}while(0);if((v|0)==0){Ka=0}else{ta=(c[f+6196>>2]|0)==0;ua=f+177112|0;Ka=((ta?24117616:7340144)&c[ua>>2]|0)==0&((ta?24117616:7340144)&c[ua+4>>2]|0)==0&1}if((Ca|0)==0){La=Ka;break}ua=f+2524|0;ta=f+4872|0;P=f+4852|0;N=f+6100|0;pa=f+6108|0;R=0;while(1){j=R<<1;fa=4096<<j;na=f+5632+(R*40|0)+11|0;la=f+5312+(R*160|0)+40|0;aa=la|0;T=la;la=12288<<j;j=f+5312+(R*160|0)+42|0;ka=0;do{ga=ka<<2;U=d[602272+ga|0]|0;a[f+5632+(R*40|0)+U|0]=a[U+1+(f+5632+(R*40|0))|0]|0;$=e[f+177112+(ka<<1)>>1]|0;do{if(($&256|0)==0){if(($&fa|0)==0){c[f+5312+(R*160|0)+(U<<2)>>2]=0;c[f+5312+(R*160|0)+(U<<2)+4>>2]=0;c[f+5312+(R*160|0)+(U<<2)+32>>2]=0;c[f+5312+(R*160|0)+(U<<2)+36>>2]=0;c[f+426592+(R*80|0)+(U<<1)>>2]=0;c[f+426592+(R*80|0)+(U<<1)+16>>2]=0;break}h=($&24|0)!=0?2:1;da=c[m+(ka<<2)>>2]|0;if((da|0)<=0){break}ba=($&8|0)==0;_=($&16|0)==0;Z=($&32|0)==0;O=0;do{J=a[602272+((ca(O,h)|0)+ga)|0]|0;C=J&255;A=a[f+5632+(R*40|0)+C|0]|0;M=A<<24>>24;Q=C-8|0;ja=a[f+5632+(R*40|0)+Q|0]|0;L=C-1|0;W=a[f+5632+(R*40|0)+L|0]|0;V=f+5312+(R*160|0)+(L<<2)|0;S=f+5312+(R*160|0)+(Q<<2)|0;K=Q+h|0;X=a[f+5632+(R*40|0)+K|0]|0;ha=X<<24>>24;ia=X<<24>>24==-2;do{if((c[H>>2]|0)!=0&ia&(J&255)>>>0>19>>>0&(C&7|0)==4){if((a[na]|0)==-2){I=207;break}X=c[ua>>2]|0;ea=c[X+1536>>2]|0;c[T>>2]=0;Y=(c[ta>>2]&128|0)==0;if((c[ma>>2]|0)==0){if(Y){I=207;break}Ma=c[D>>2]|0;Na=Ma+(c[P>>2]|0)|0;Oa=(c[B>>2]<<1&2)+(C>>>5)|0;if((c[ea+((ca(Oa>>>2,Ma)|0)+Na<<2)>>2]&la|0)==0){Pa=-1;Qa=aa;break}Ma=(c[(c[N>>2]|0)+(Na<<2)>>2]|0)+3+(ca(c[pa>>2]|0,Oa)|0)|0;Ra=c[X+1524+(R<<2)>>2]|0;b[aa>>1]=b[Ra+(Ma<<2)>>1]|0;b[j>>1]=b[Ra+(Ma<<2)+2>>1]<<1;Pa=a[(c[X+1556+(R<<2)>>2]|0)+((Oa&2147483646)+(Na<<2|1))|0]>>1;Qa=aa;break}else{if(!Y){I=207;break}Y=c[f+4852+(((J&255)>>>0>35>>>0)<<2)>>2]|0;Na=C>>>2;if((c[ea+(Y<<2)>>2]&la|0)==0){Pa=-1;Qa=aa;break}ea=(c[(c[N>>2]|0)+(Y<<2)>>2]|0)+3+(ca(c[pa>>2]|0,Na&3)|0)|0;Oa=c[X+1524+(R<<2)>>2]|0;b[aa>>1]=b[Oa+(ea<<2)>>1]|0;b[j>>1]=(b[Oa+(ea<<2)+2>>1]|0)/2|0;Pa=a[(c[X+1556+(R<<2)>>2]|0)+(Na&2|Y<<2|1)|0]<<1;Qa=aa;break}}else{I=207}}while(0);do{if((I|0)==207){I=0;if(ia){J=C-9|0;Pa=a[f+5632+(R*40|0)+J|0]|0;Qa=f+5312+(R*160|0)+(J<<2)|0;break}else{Pa=ha;Qa=f+5312+(R*160|0)+(K<<2)|0;break}}}while(0);K=ja<<24>>24==A<<24>>24;ha=W<<24>>24==A<<24>>24;ia=(ha&1)+(K&1)+((Pa|0)==(M|0))|0;do{if((ia|0)>1){J=b[V>>1]|0;Y=J<<16>>16;Na=b[S>>1]|0;X=Na<<16>>16;ea=b[Qa>>1]|0;Oa=ea<<16>>16;do{if(J<<16>>16>Na<<16>>16){if(!(ea<<16>>16>Na<<16>>16)){Sa=X;break}Sa=(Oa|0)>(Y|0)?Y:Oa}else{if(!(Na<<16>>16>ea<<16>>16)){Sa=X;break}Sa=(Oa|0)>(Y|0)?Oa:Y}}while(0);Y=b[f+5312+(R*160|0)+(L<<2)+2>>1]|0;Oa=Y<<16>>16;X=b[f+5312+(R*160|0)+(Q<<2)+2>>1]|0;ea=X<<16>>16;Na=b[Qa+2>>1]|0;J=Na<<16>>16;if(Y<<16>>16>X<<16>>16){if(!(Na<<16>>16>X<<16>>16)){Ta=ea;Ua=Sa;break}Ta=(J|0)>(Oa|0)?Oa:J;Ua=Sa;break}else{if(!(X<<16>>16>Na<<16>>16)){Ta=ea;Ua=Sa;break}Ta=(J|0)>(Oa|0)?J:Oa;Ua=Sa;break}}else{if((ia|0)==1){if(ha){Ta=b[f+5312+(R*160|0)+(L<<2)+2>>1]|0;Ua=b[V>>1]|0;break}if(K){Ta=b[f+5312+(R*160|0)+(Q<<2)+2>>1]|0;Ua=b[S>>1]|0;break}else{Ta=b[Qa+2>>1]|0;Ua=b[Qa>>1]|0;break}}Oa=b[V>>1]|0;J=Oa<<16>>16;if(!((Pa|0)!=-2|ja<<24>>24!=-2|W<<24>>24==-2)){Ta=b[f+5312+(R*160|0)+(L<<2)+2>>1]|0;Ua=J;break}ea=b[S>>1]|0;Na=ea<<16>>16;X=b[Qa>>1]|0;Y=X<<16>>16;do{if(Oa<<16>>16>ea<<16>>16){if(!(X<<16>>16>ea<<16>>16)){Va=Na;break}Va=(Y|0)>(J|0)?J:Y}else{if(!(ea<<16>>16>X<<16>>16)){Va=Na;break}Va=(Y|0)>(J|0)?Y:J}}while(0);J=b[f+5312+(R*160|0)+(L<<2)+2>>1]|0;Y=J<<16>>16;Na=b[f+5312+(R*160|0)+(Q<<2)+2>>1]|0;X=Na<<16>>16;ea=b[Qa+2>>1]|0;Oa=ea<<16>>16;if(J<<16>>16>Na<<16>>16){if(!(ea<<16>>16>Na<<16>>16)){Ta=X;Ua=Va;break}Ta=(Oa|0)>(Y|0)?Y:Oa;Ua=Va;break}else{if(!(Na<<16>>16>ea<<16>>16)){Ta=X;Ua=Va;break}Ta=(Oa|0)>(Y|0)?Oa:Y;Ua=Va;break}}}while(0);S=(d[f+426592+(R*80|0)+(Q<<1)+1|0]|0)+(d[f+426592+(R*80|0)+(L<<1)+1|0]|0)|0;W=(aia(f,40,(d[f+426592+(R*80|0)+(Q<<1)|0]|0)+(d[f+426592+(R*80|0)+(L<<1)|0]|0)|0,n)|0)+Ua|0;ja=(aia(f,47,S,o)|0)+Ta|0;do{if(ba){if(!_){S=W&65535;V=C+1|0;b[f+5312+(R*160|0)+(V<<2)>>1]=S;K=ja&65535;b[f+5312+(R*160|0)+(V<<2)+2>>1]=K;ha=c[n>>2]|0;a[f+426592+(R*80|0)+(V<<1)|0]=ha;ia=c[o>>2]|0;a[f+426592+(R*80|0)+(V<<1)+1|0]=ia;Wa=ha&255;Xa=ia&255;Ya=S;Za=K;break}if(Z){Wa=c[n>>2]&255;Xa=c[o>>2]&255;Ya=W&65535;Za=ja&65535;break}else{K=W&65535;S=C+8|0;b[f+5312+(R*160|0)+(S<<2)>>1]=K;ia=ja&65535;b[f+5312+(R*160|0)+(S<<2)+2>>1]=ia;ha=c[n>>2]|0;a[f+426592+(R*80|0)+(S<<1)|0]=ha;V=c[o>>2]|0;a[f+426592+(R*80|0)+(S<<1)+1|0]=V;Wa=ha&255;Xa=V&255;Ya=K;Za=ia;break}}else{ia=W&65535;K=C+9|0;b[f+5312+(R*160|0)+(K<<2)>>1]=ia;V=C+8|0;b[f+5312+(R*160|0)+(V<<2)>>1]=ia;ha=C+1|0;b[f+5312+(R*160|0)+(ha<<2)>>1]=ia;S=ja&65535;b[f+5312+(R*160|0)+(K<<2)+2>>1]=S;b[f+5312+(R*160|0)+(V<<2)+2>>1]=S;b[f+5312+(R*160|0)+(ha<<2)+2>>1]=S;M=c[n>>2]|0;A=M&255;a[f+426592+(R*80|0)+(K<<1)|0]=A;a[f+426592+(R*80|0)+(V<<1)|0]=A;a[f+426592+(R*80|0)+(ha<<1)|0]=A;A=c[o>>2]|0;Y=A&255;a[f+426592+(R*80|0)+(K<<1)+1|0]=Y;a[f+426592+(R*80|0)+(V<<1)+1|0]=Y;a[f+426592+(R*80|0)+(ha<<1)+1|0]=Y;Wa=M&255;Xa=A&255;Ya=ia;Za=S}}while(0);b[f+5312+(R*160|0)+(C<<2)>>1]=Ya;b[f+5312+(R*160|0)+(C<<2)+2>>1]=Za;a[f+426592+(R*80|0)+(C<<1)|0]=Wa;a[f+426592+(R*80|0)+(C<<1)+1|0]=Xa;O=O+1|0;}while((O|0)<(da|0))}else{c[f+426592+(R*80|0)+(U<<1)>>2]=0;c[f+426592+(R*80|0)+(U<<1)+16>>2]=0}}while(0);ka=ka+1|0;}while((ka|0)<4);ka=R+1|0;if(ka>>>0<(c[qa>>2]|0)>>>0){R=ka}else{La=Ka;break c}}}if((va&256|0)!=0){nia(f,k);c[f+426616>>2]=0;c[f+426620>>2]=0;c[f+426632>>2]=0;c[f+426636>>2]=0;c[f+426648>>2]=0;c[f+426652>>2]=0;c[f+426664>>2]=0;c[f+426668>>2]=0;c[f+426696>>2]=0;c[f+426700>>2]=0;c[f+426712>>2]=0;c[f+426716>>2]=0;c[f+426728>>2]=0;c[f+426732>>2]=0;c[f+426744>>2]=0;c[f+426748>>2]=0;La=c[f+6196>>2]&v;break}if((va&8|0)!=0){R=f+199428|0;qa=c[R>>2]|0;if((qa|0)==0){La=v;break}pa=f+426767|0;N=f+426760|0;P=f+425488|0;ta=0;ua=qa;qa=va;g:while(1){if((qa&4096<<(ta<<1)|0)==0){_a=ua}else{$a=c[l+(ta<<2)>>2]|0;if($a>>>0>1>>>0){ka=a[f+5632+(ta*40|0)+4|0]|0;aa=(a[f+5632+(ta*40|0)+11|0]|0)>0;do{if((c[G>>2]|0)==3){if(aa){ab=(d[pa]|0)>>>7&255^1}else{ab=0}if(!(ka<<24>>24>0)){bb=ab;cb=0;break}bb=(a[N]|0)<0?ab:ab|2;cb=0}else{j=aa&1;if(!(ka<<24>>24>0)){bb=j;cb=0;break}bb=j|2;cb=0}}while(0);while(1){if((bia(P,bb+54+(f+425536)|0)|0)==0){break}ka=cb+1|0;if((ka|0)>31){db=-1;I=268;break g}else{bb=(bb>>2)+4|0;cb=ka}}if(cb>>>0<$a>>>0){eb=cb}else{db=cb;I=268;break}}else{eb=0}ka=ca(eb,16843009)|0;c[f+5632+(ta*40|0)+12>>2]=ka;c[f+5632+(ta*40|0)+20>>2]=ka;c[f+5632+(ta*40|0)+28>>2]=ka;c[f+5632+(ta*40|0)+36>>2]=ka;_a=c[R>>2]|0}ka=ta+1|0;if(!(ka>>>0<_a>>>0)){break}ta=ka;ua=_a;qa=c[k>>2]|0}if((I|0)==268){KIb(c[f>>2]|0,16,2543472,(Ja=i,i=i+16|0,c[Ja>>2]=db,c[Ja+8>>2]=$a,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}if((_a|0)==0){La=v;break}else{fb=0;gb=_a}while(1){if((c[k>>2]&4096<<(fb<<1)|0)==0){hb=gb}else{qa=a[f+5632+(fb*40|0)+12|0]|0;ua=a[f+5632+(fb*40|0)+4|0]|0;ta=a[f+5632+(fb*40|0)+11|0]|0;P=f+5312+(fb*160|0)+44|0;N=f+5312+(fb*160|0)+16|0;pa=a[f+5632+(fb*40|0)+8|0]|0;if(pa<<24>>24==-2){ib=a[f+5632+(fb*40|0)+3|0]|0;jb=f+5312+(fb*160|0)+12|0}else{ib=pa;jb=f+5312+(fb*160|0)+32|0}pa=ua<<24>>24==qa<<24>>24;ka=ta<<24>>24==qa<<24>>24;aa=(ka&1)+(pa&1)+(ib<<24>>24==qa<<24>>24)|0;do{if((aa|0)>1){qa=b[P>>1]|0;j=qa<<16>>16;la=b[N>>1]|0;T=la<<16>>16;na=b[jb>>1]|0;fa=na<<16>>16;do{if(qa<<16>>16>la<<16>>16){if(!(na<<16>>16>la<<16>>16)){kb=T;break}kb=(fa|0)>(j|0)?j:fa}else{if(!(la<<16>>16>na<<16>>16)){kb=T;break}kb=(fa|0)>(j|0)?fa:j}}while(0);j=b[f+5312+(fb*160|0)+46>>1]|0;fa=j<<16>>16;T=b[f+5312+(fb*160|0)+18>>1]|0;na=T<<16>>16;la=b[jb+2>>1]|0;qa=la<<16>>16;if(j<<16>>16>T<<16>>16){if(!(la<<16>>16>T<<16>>16)){lb=na;mb=kb;break}lb=(qa|0)>(fa|0)?fa:qa;mb=kb;break}else{if(!(T<<16>>16>la<<16>>16)){lb=na;mb=kb;break}lb=(qa|0)>(fa|0)?qa:fa;mb=kb;break}}else{if((aa|0)==1){if(ka){lb=b[f+5312+(fb*160|0)+46>>1]|0;mb=b[P>>1]|0;break}if(pa){lb=b[f+5312+(fb*160|0)+18>>1]|0;mb=b[N>>1]|0;break}else{lb=b[jb+2>>1]|0;mb=b[jb>>1]|0;break}}fa=b[P>>1]|0;qa=fa<<16>>16;if(!(ib<<24>>24!=-2|ua<<24>>24!=-2|ta<<24>>24==-2)){lb=b[f+5312+(fb*160|0)+46>>1]|0;mb=qa;break}na=b[N>>1]|0;la=na<<16>>16;T=b[jb>>1]|0;j=T<<16>>16;do{if(fa<<16>>16>na<<16>>16){if(!(T<<16>>16>na<<16>>16)){nb=la;break}nb=(j|0)>(qa|0)?qa:j}else{if(!(na<<16>>16>T<<16>>16)){nb=la;break}nb=(j|0)>(qa|0)?j:qa}}while(0);qa=b[f+5312+(fb*160|0)+46>>1]|0;j=qa<<16>>16;la=b[f+5312+(fb*160|0)+18>>1]|0;T=la<<16>>16;na=b[jb+2>>1]|0;fa=na<<16>>16;if(qa<<16>>16>la<<16>>16){if(!(na<<16>>16>la<<16>>16)){lb=T;mb=nb;break}lb=(fa|0)>(j|0)?j:fa;mb=nb;break}else{if(!(la<<16>>16>na<<16>>16)){lb=T;mb=nb;break}lb=(fa|0)>(j|0)?fa:j;mb=nb;break}}}while(0);N=(d[f+426592+(fb*80|0)+9|0]|0)+(d[f+426592+(fb*80|0)+23|0]|0)|0;ta=(aia(f,40,(d[f+426592+(fb*80|0)+8|0]|0)+(d[f+426592+(fb*80|0)+22|0]|0)|0,p)|0)+mb|0;ua=(aia(f,47,N,q)|0)+lb|0;N=(c[q>>2]<<8&65280|c[p>>2]&255)*65537|0;c[f+426592+(fb*80|0)+24>>2]=N;c[f+426592+(fb*80|0)+28>>2]=N;c[f+426592+(fb*80|0)+40>>2]=N;c[f+426592+(fb*80|0)+44>>2]=N;c[f+426592+(fb*80|0)+56>>2]=N;c[f+426592+(fb*80|0)+60>>2]=N;c[f+426592+(fb*80|0)+72>>2]=N;c[f+426592+(fb*80|0)+76>>2]=N;N=ua<<16|ta&65535;c[f+5312+(fb*160|0)+48>>2]=N;c[f+5312+(fb*160|0)+52>>2]=N;c[f+5312+(fb*160|0)+56>>2]=N;c[f+5312+(fb*160|0)+60>>2]=N;c[f+5312+(fb*160|0)+80>>2]=N;c[f+5312+(fb*160|0)+84>>2]=N;c[f+5312+(fb*160|0)+88>>2]=N;c[f+5312+(fb*160|0)+92>>2]=N;c[f+5312+(fb*160|0)+112>>2]=N;c[f+5312+(fb*160|0)+116>>2]=N;c[f+5312+(fb*160|0)+120>>2]=N;c[f+5312+(fb*160|0)+124>>2]=N;c[f+5312+(fb*160|0)+144>>2]=N;c[f+5312+(fb*160|0)+148>>2]=N;c[f+5312+(fb*160|0)+152>>2]=N;c[f+5312+(fb*160|0)+156>>2]=N;hb=c[R>>2]|0}N=fb+1|0;if(N>>>0<hb>>>0){fb=N;gb=hb}else{La=v;break c}}}R=f+199428|0;N=(c[R>>2]|0)==0;if((va&16|0)!=0){if(N){La=v;break}ta=f+425488|0;ua=0;h:do{P=ua<<1;pa=l+(ua<<2)|0;ka=0;do{if((c[k>>2]&4096<<ka+P|0)==0){aa=ka<<4|12;c[f+5632+(ua*40|0)+aa>>2]=-1;c[aa+8+(f+5632+(ua*40|0))>>2]=-1}else{ob=c[pa>>2]|0;if(ob>>>0>1>>>0){aa=d[602272+(ka<<3)|0]|0;j=aa-1|0;fa=aa-8|0;aa=a[f+5632+(ua*40|0)+fa|0]|0;T=(a[f+5632+(ua*40|0)+j|0]|0)>0;do{if((c[G>>2]|0)==3){if(T){pb=(d[f+426756+j|0]|0)>>>7&255^1}else{pb=0}if(!(aa<<24>>24>0)){qb=pb;rb=0;break}qb=(a[f+426756+fa|0]|0)<0?pb:pb|2;rb=0}else{na=T&1;if(!(aa<<24>>24>0)){qb=na;rb=0;break}qb=na|2;rb=0}}while(0);while(1){if((bia(ta,qb+54+(f+425536)|0)|0)==0){break}aa=rb+1|0;if((aa|0)>31){sb=-1;I=327;break h}else{qb=(qb>>2)+4|0;rb=aa}}if(rb>>>0<ob>>>0){tb=rb}else{sb=rb;I=327;break h}}else{tb=0}aa=ka<<4|12;T=ca(tb,16843009)|0;c[f+5632+(ua*40|0)+aa>>2]=T;c[aa+8+(f+5632+(ua*40|0))>>2]=T}ka=ka+1|0;}while((ka|0)<2);ua=ua+1|0;ub=c[R>>2]|0;}while(ua>>>0<ub>>>0);if((I|0)==327){KIb(c[f>>2]|0,16,2543472,(Ja=i,i=i+16|0,c[Ja>>2]=sb,c[Ja+8>>2]=ob,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}if((ub|0)==0){La=v;break}ua=f+2524|0;ta=f+4872|0;ka=f+4852|0;pa=f+6100|0;P=f+6108|0;T=0;while(1){aa=T<<1;fa=f+5632+(T*40|0)+4|0;j=f+5312+(T*160|0)+16|0;na=f+5312+(T*160|0)+18|0;la=f+5632+(T*40|0)+11|0;qa=f+5312+(T*160|0)+40|0;U=qa|0;ga=qa;qa=12288<<aa;$=f+5312+(T*160|0)+42|0;da=f+5632+(T*40|0)+27|0;O=f+5312+(T*160|0)+108|0;Z=f+5312+(T*160|0)+110|0;_=0;do{if((c[k>>2]&4096<<_+aa|0)==0){ba=_<<4|12;c[f+426592+(T*80|0)+(ba<<1)>>2]=0;c[f+426592+(T*80|0)+(ba<<1)+4>>2]=0;c[f+426592+(T*80|0)+(ba<<1)+16>>2]=0;c[f+426592+(T*80|0)+(ba<<1)+20>>2]=0;mrc(f+5312+(T*160|0)+(ba<<2)|0,0,16)|0;mrc(f+5312+(T*160|0)+(ba<<2)+32|0,0,16)|0}else{ba=_<<3;h=_<<4|12;ja=a[f+5632+(T*40|0)+h|0]|0;W=ja<<24>>24;do{if((ba|0)==0){if(!((a[fa]|0)==ja<<24>>24)){I=339;break}vb=b[na>>1]|0;wb=b[j>>1]|0}else{if(!((a[da]|0)==ja<<24>>24)){I=339;break}vb=b[Z>>1]|0;wb=b[O>>1]|0}}while(0);do{if((I|0)==339){I=0;L=a[602272+ba|0]|0;Q=L&255;S=Q-8|0;ia=a[f+5632+(T*40|0)+S|0]|0;A=Q-1|0;M=a[f+5632+(T*40|0)+A|0]|0;Y=f+5312+(T*160|0)+(A<<2)|0;ha=f+5312+(T*160|0)+(S<<2)|0;V=Q-4|0;K=a[f+5632+(T*40|0)+V|0]|0;Oa=K<<24>>24;X=K<<24>>24==-2;do{if((c[H>>2]|0)!=0&X&(L&255)>>>0>19>>>0&(Q&7|0)==4){if((a[la]|0)==-2){I=348;break}K=c[ua>>2]|0;ea=c[K+1536>>2]|0;c[ga>>2]=0;Na=(c[ta>>2]&128|0)==0;if((c[ma>>2]|0)==0){if(Na){I=348;break}J=c[D>>2]|0;Ma=J+(c[ka>>2]|0)|0;Ra=(c[B>>2]<<1&2)+(Q>>>5)|0;if((c[ea+((ca(Ra>>>2,J)|0)+Ma<<2)>>2]&qa|0)==0){xb=-1;yb=U;break}J=(c[(c[pa>>2]|0)+(Ma<<2)>>2]|0)+3+(ca(c[P>>2]|0,Ra)|0)|0;zb=c[K+1524+(T<<2)>>2]|0;b[U>>1]=b[zb+(J<<2)>>1]|0;b[$>>1]=b[zb+(J<<2)+2>>1]<<1;xb=a[(c[K+1556+(T<<2)>>2]|0)+((Ra&2147483646)+(Ma<<2|1))|0]>>1;yb=U;break}else{if(!Na){I=348;break}Na=c[f+4852+(((L&255)>>>0>35>>>0)<<2)>>2]|0;Ma=Q>>>2;if((c[ea+(Na<<2)>>2]&qa|0)==0){xb=-1;yb=U;break}ea=(c[(c[pa>>2]|0)+(Na<<2)>>2]|0)+3+(ca(c[P>>2]|0,Ma&3)|0)|0;Ra=c[K+1524+(T<<2)>>2]|0;b[U>>1]=b[Ra+(ea<<2)>>1]|0;b[$>>1]=(b[Ra+(ea<<2)+2>>1]|0)/2|0;xb=a[(c[K+1556+(T<<2)>>2]|0)+(Ma&2|Na<<2|1)|0]<<1;yb=U;break}}else{I=348}}while(0);do{if((I|0)==348){I=0;if(X){L=Q-9|0;xb=a[f+5632+(T*40|0)+L|0]|0;yb=f+5312+(T*160|0)+(L<<2)|0;break}else{xb=Oa;yb=f+5312+(T*160|0)+(V<<2)|0;break}}}while(0);V=ia<<24>>24==ja<<24>>24;Oa=M<<24>>24==ja<<24>>24;Q=(Oa&1)+(V&1)+((xb|0)==(W|0))|0;if((Q|0)>1){X=b[Y>>1]|0;L=X<<16>>16;Na=b[ha>>1]|0;Ma=Na<<16>>16;K=b[yb>>1]|0;ea=K<<16>>16;do{if(X<<16>>16>Na<<16>>16){if(!(K<<16>>16>Na<<16>>16)){Ab=Ma;break}Ab=(ea|0)>(L|0)?L:ea}else{if(!(Na<<16>>16>K<<16>>16)){Ab=Ma;break}Ab=(ea|0)>(L|0)?ea:L}}while(0);L=b[f+5312+(T*160|0)+(A<<2)+2>>1]|0;ea=L<<16>>16;Ma=b[f+5312+(T*160|0)+(S<<2)+2>>1]|0;K=Ma<<16>>16;Na=b[yb+2>>1]|0;X=Na<<16>>16;if(L<<16>>16>Ma<<16>>16){if(!(Na<<16>>16>Ma<<16>>16)){vb=K;wb=Ab;break}vb=(X|0)>(ea|0)?ea:X;wb=Ab;break}else{if(!(Ma<<16>>16>Na<<16>>16)){vb=K;wb=Ab;break}vb=(X|0)>(ea|0)?X:ea;wb=Ab;break}}if((Q|0)==1){if(Oa){vb=b[f+5312+(T*160|0)+(A<<2)+2>>1]|0;wb=b[Y>>1]|0;break}if(V){vb=b[f+5312+(T*160|0)+(S<<2)+2>>1]|0;wb=b[ha>>1]|0;break}else{vb=b[yb+2>>1]|0;wb=b[yb>>1]|0;break}}ea=b[Y>>1]|0;X=ea<<16>>16;if(!((xb|0)!=-2|ia<<24>>24!=-2|M<<24>>24==-2)){vb=b[f+5312+(T*160|0)+(A<<2)+2>>1]|0;wb=X;break}K=b[ha>>1]|0;Na=K<<16>>16;Ma=b[yb>>1]|0;L=Ma<<16>>16;do{if(ea<<16>>16>K<<16>>16){if(!(Ma<<16>>16>K<<16>>16)){Bb=Na;break}Bb=(L|0)>(X|0)?X:L}else{if(!(K<<16>>16>Ma<<16>>16)){Bb=Na;break}Bb=(L|0)>(X|0)?L:X}}while(0);X=b[f+5312+(T*160|0)+(A<<2)+2>>1]|0;L=X<<16>>16;Na=b[f+5312+(T*160|0)+(S<<2)+2>>1]|0;Ma=Na<<16>>16;K=b[yb+2>>1]|0;ea=K<<16>>16;if(X<<16>>16>Na<<16>>16){if(!(K<<16>>16>Na<<16>>16)){vb=Ma;wb=Bb;break}vb=(ea|0)>(L|0)?L:ea;wb=Bb;break}else{if(!(Na<<16>>16>K<<16>>16)){vb=Ma;wb=Bb;break}vb=(ea|0)>(L|0)?ea:L;wb=Bb;break}}}while(0);W=d[602272+ba|0]|0;ja=W-1|0;L=W-8|0;W=(d[f+426592+(T*80|0)+(L<<1)+1|0]|0)+(d[f+426592+(T*80|0)+(ja<<1)+1|0]|0)|0;ea=(aia(f,40,(d[f+426592+(T*80|0)+(L<<1)|0]|0)+(d[f+426592+(T*80|0)+(ja<<1)|0]|0)|0,r)|0)+wb|0;ja=(aia(f,47,W,s)|0)+vb|0;W=(c[s>>2]<<8&65280|c[r>>2]&255)*65537|0;c[f+426592+(T*80|0)+(h<<1)>>2]=W;c[f+426592+(T*80|0)+(h<<1)+4>>2]=W;c[f+426592+(T*80|0)+(h<<1)+16>>2]=W;c[f+426592+(T*80|0)+(h<<1)+20>>2]=W;W=ja<<16|ea&65535;c[f+5312+(T*160|0)+(h<<2)>>2]=W;c[f+5312+(T*160|0)+(h<<2)+4>>2]=W;c[f+5312+(T*160|0)+(h<<2)+8>>2]=W;c[f+5312+(T*160|0)+(h<<2)+12>>2]=W;c[f+5312+(T*160|0)+(h<<2)+32>>2]=W;c[f+5312+(T*160|0)+(h<<2)+36>>2]=W;c[f+5312+(T*160|0)+(h<<2)+40>>2]=W;c[f+5312+(T*160|0)+(h<<2)+44>>2]=W}_=_+1|0;}while((_|0)<2);_=T+1|0;if(_>>>0<(c[R>>2]|0)>>>0){T=_}else{La=v;break c}}}if(N){La=v;break}T=f+425488|0;P=0;i:do{pa=P<<1;ka=l+(P<<2)|0;ta=0;do{if((c[k>>2]&4096<<ta+pa|0)==0){ua=ta<<1;b[ua+12+(f+5632+(P*40|0))>>1]=-1;b[ua+20+(f+5632+(P*40|0))>>1]=-1;b[ua+28+(f+5632+(P*40|0))>>1]=-1;b[ua+36+(f+5632+(P*40|0))>>1]=-1}else{Cb=c[ka>>2]|0;if(Cb>>>0>1>>>0){ua=d[602272+(ta<<2)|0]|0;_=ua-1|0;U=ua-8|0;ua=a[f+5632+(P*40|0)+U|0]|0;$=(a[f+5632+(P*40|0)+_|0]|0)>0;do{if((c[G>>2]|0)==3){if($){Db=(d[f+426756+_|0]|0)>>>7&255^1}else{Db=0}if(!(ua<<24>>24>0)){Eb=Db;Fb=0;break}Eb=(a[f+426756+U|0]|0)<0?Db:Db|2;Fb=0}else{qa=$&1;if(!(ua<<24>>24>0)){Eb=qa;Fb=0;break}Eb=qa|2;Fb=0}}while(0);while(1){if((bia(T,Eb+54+(f+425536)|0)|0)==0){break}ua=Fb+1|0;if((ua|0)>31){Gb=-1;I=399;break i}else{Eb=(Eb>>2)+4|0;Fb=ua}}if(Fb>>>0<Cb>>>0){Hb=Fb}else{Gb=Fb;I=399;break i}}else{Hb=0}ua=ta<<1;$=(Hb*257|0)&65535;b[ua+12+(f+5632+(P*40|0))>>1]=$;b[ua+20+(f+5632+(P*40|0))>>1]=$;b[ua+28+(f+5632+(P*40|0))>>1]=$;b[ua+36+(f+5632+(P*40|0))>>1]=$}ta=ta+1|0;}while((ta|0)<2);P=P+1|0;Ib=c[R>>2]|0;}while(P>>>0<Ib>>>0);if((I|0)==399){KIb(c[f>>2]|0,16,2543472,(Ja=i,i=i+16|0,c[Ja>>2]=Gb,c[Ja+8>>2]=Cb,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}if((Ib|0)==0){La=v;break}P=f+2524|0;T=f+4872|0;N=f+4852|0;ta=f+6100|0;ka=f+6108|0;pa=0;while(1){$=pa<<1;ua=f+5632+(pa*40|0)+11|0;U=f+5312+(pa*160|0)+44|0;_=f+5312+(pa*160|0)+46|0;h=f+5312+(pa*160|0)+40|0;ba=h|0;qa=h;h=12288<<$;ga=f+5312+(pa*160|0)+42|0;la=f+5632+(pa*40|0)+8|0;O=f+5312+(pa*160|0)+20|0;Z=f+5632+(pa*40|0)+5|0;da=f+5312+(pa*160|0)+32|0;j=0;do{if((c[k>>2]&4096<<j+$|0)==0){na=(j<<1)+12|0;c[f+426592+(pa*80|0)+(na<<1)>>2]=0;c[f+426592+(pa*80|0)+(na<<1)+16>>2]=0;c[f+426592+(pa*80|0)+(na<<1)+32>>2]=0;c[f+426592+(pa*80|0)+(na<<1)+48>>2]=0;c[f+5312+(pa*160|0)+(na<<2)>>2]=0;c[f+5312+(pa*160|0)+(na<<2)+4>>2]=0;c[f+5312+(pa*160|0)+(na<<2)+32>>2]=0;c[f+5312+(pa*160|0)+(na<<2)+36>>2]=0;c[f+5312+(pa*160|0)+(na<<2)+64>>2]=0;c[f+5312+(pa*160|0)+(na<<2)+68>>2]=0;c[f+5312+(pa*160|0)+(na<<2)+96>>2]=0;c[f+5312+(pa*160|0)+(na<<2)+100>>2]=0}else{na=j<<2;fa=(j<<1)+12|0;aa=a[f+5632+(pa*40|0)+fa|0]|0;W=aa<<24>>24;do{if((na|0)==0){if(!((a[ua]|0)==aa<<24>>24)){I=413;break}Jb=b[_>>1]|0;Kb=b[U>>1]|0}else{ea=a[la]|0;if(ea<<24>>24==-2){Lb=a[Z]|0;Mb=O}else{Lb=ea;Mb=da}if(!(Lb<<24>>24==aa<<24>>24)){I=413;break}Jb=b[Mb+2>>1]|0;Kb=b[Mb>>1]|0}}while(0);do{if((I|0)==413){I=0;ea=a[602272+na|0]|0;ja=ea&255;L=ja-8|0;Ma=a[f+5632+(pa*40|0)+L|0]|0;K=ja-1|0;Na=a[f+5632+(pa*40|0)+K|0]|0;X=f+5312+(pa*160|0)+(K<<2)|0;ha=f+5312+(pa*160|0)+(L<<2)|0;M=ja-6|0;ia=a[f+5632+(pa*40|0)+M|0]|0;Y=ia<<24>>24;V=ia<<24>>24==-2;do{if((c[H>>2]|0)!=0&V&(ea&255)>>>0>19>>>0&(ja&7|0)==4){if((a[ua]|0)==-2){I=422;break}ia=c[P>>2]|0;Oa=c[ia+1536>>2]|0;c[qa>>2]=0;Q=(c[T>>2]&128|0)==0;if((c[ma>>2]|0)==0){if(Q){I=422;break}Ra=c[D>>2]|0;J=Ra+(c[N>>2]|0)|0;zb=(c[B>>2]<<1&2)+(ja>>>5)|0;if((c[Oa+((ca(zb>>>2,Ra)|0)+J<<2)>>2]&h|0)==0){Nb=-1;Ob=ba;break}Ra=(c[(c[ta>>2]|0)+(J<<2)>>2]|0)+3+(ca(c[ka>>2]|0,zb)|0)|0;Pb=c[ia+1524+(pa<<2)>>2]|0;b[ba>>1]=b[Pb+(Ra<<2)>>1]|0;b[ga>>1]=b[Pb+(Ra<<2)+2>>1]<<1;Nb=a[(c[ia+1556+(pa<<2)>>2]|0)+((zb&2147483646)+(J<<2|1))|0]>>1;Ob=ba;break}else{if(!Q){I=422;break}Q=c[f+4852+(((ea&255)>>>0>35>>>0)<<2)>>2]|0;J=ja>>>2;if((c[Oa+(Q<<2)>>2]&h|0)==0){Nb=-1;Ob=ba;break}Oa=(c[(c[ta>>2]|0)+(Q<<2)>>2]|0)+3+(ca(c[ka>>2]|0,J&3)|0)|0;zb=c[ia+1524+(pa<<2)>>2]|0;b[ba>>1]=b[zb+(Oa<<2)>>1]|0;b[ga>>1]=(b[zb+(Oa<<2)+2>>1]|0)/2|0;Nb=a[(c[ia+1556+(pa<<2)>>2]|0)+(J&2|Q<<2|1)|0]<<1;Ob=ba;break}}else{I=422}}while(0);do{if((I|0)==422){I=0;if(V){ea=ja-9|0;Nb=a[f+5632+(pa*40|0)+ea|0]|0;Ob=f+5312+(pa*160|0)+(ea<<2)|0;break}else{Nb=Y;Ob=f+5312+(pa*160|0)+(M<<2)|0;break}}}while(0);M=Ma<<24>>24==aa<<24>>24;Y=Na<<24>>24==aa<<24>>24;ja=(Y&1)+(M&1)+((Nb|0)==(W|0))|0;if((ja|0)>1){V=b[X>>1]|0;ea=V<<16>>16;S=b[ha>>1]|0;A=S<<16>>16;Q=b[Ob>>1]|0;J=Q<<16>>16;do{if(V<<16>>16>S<<16>>16){if(!(Q<<16>>16>S<<16>>16)){Qb=A;break}Qb=(J|0)>(ea|0)?ea:J}else{if(!(S<<16>>16>Q<<16>>16)){Qb=A;break}Qb=(J|0)>(ea|0)?J:ea}}while(0);ea=b[f+5312+(pa*160|0)+(K<<2)+2>>1]|0;J=ea<<16>>16;A=b[f+5312+(pa*160|0)+(L<<2)+2>>1]|0;Q=A<<16>>16;S=b[Ob+2>>1]|0;V=S<<16>>16;if(ea<<16>>16>A<<16>>16){if(!(S<<16>>16>A<<16>>16)){Jb=Q;Kb=Qb;break}Jb=(V|0)>(J|0)?J:V;Kb=Qb;break}else{if(!(A<<16>>16>S<<16>>16)){Jb=Q;Kb=Qb;break}Jb=(V|0)>(J|0)?V:J;Kb=Qb;break}}if((ja|0)==1){if(Y){Jb=b[f+5312+(pa*160|0)+(K<<2)+2>>1]|0;Kb=b[X>>1]|0;break}if(M){Jb=b[f+5312+(pa*160|0)+(L<<2)+2>>1]|0;Kb=b[ha>>1]|0;break}else{Jb=b[Ob+2>>1]|0;Kb=b[Ob>>1]|0;break}}J=b[X>>1]|0;V=J<<16>>16;if(!((Nb|0)!=-2|Ma<<24>>24!=-2|Na<<24>>24==-2)){Jb=b[f+5312+(pa*160|0)+(K<<2)+2>>1]|0;Kb=V;break}Q=b[ha>>1]|0;S=Q<<16>>16;A=b[Ob>>1]|0;ea=A<<16>>16;do{if(J<<16>>16>Q<<16>>16){if(!(A<<16>>16>Q<<16>>16)){Rb=S;break}Rb=(ea|0)>(V|0)?V:ea}else{if(!(Q<<16>>16>A<<16>>16)){Rb=S;break}Rb=(ea|0)>(V|0)?ea:V}}while(0);V=b[f+5312+(pa*160|0)+(K<<2)+2>>1]|0;ea=V<<16>>16;S=b[f+5312+(pa*160|0)+(L<<2)+2>>1]|0;A=S<<16>>16;Q=b[Ob+2>>1]|0;J=Q<<16>>16;if(V<<16>>16>S<<16>>16){if(!(Q<<16>>16>S<<16>>16)){Jb=A;Kb=Rb;break}Jb=(J|0)>(ea|0)?ea:J;Kb=Rb;break}else{if(!(S<<16>>16>Q<<16>>16)){Jb=A;Kb=Rb;break}Jb=(J|0)>(ea|0)?J:ea;Kb=Rb;break}}}while(0);W=d[602272+na|0]|0;aa=W-1|0;ea=W-8|0;W=(d[f+426592+(pa*80|0)+(ea<<1)+1|0]|0)+(d[f+426592+(pa*80|0)+(aa<<1)+1|0]|0)|0;J=(aia(f,40,(d[f+426592+(pa*80|0)+(ea<<1)|0]|0)+(d[f+426592+(pa*80|0)+(aa<<1)|0]|0)|0,t)|0)+Kb|0;aa=(aia(f,47,W,u)|0)+Jb|0;W=(c[u>>2]<<8&65280|c[t>>2]&255)*65537|0;c[f+426592+(pa*80|0)+(fa<<1)>>2]=W;c[f+426592+(pa*80|0)+(fa<<1)+16>>2]=W;c[f+426592+(pa*80|0)+(fa<<1)+32>>2]=W;c[f+426592+(pa*80|0)+(fa<<1)+48>>2]=W;W=aa<<16|J&65535;c[f+5312+(pa*160|0)+(fa<<2)>>2]=W;c[f+5312+(pa*160|0)+(fa<<2)+4>>2]=W;c[f+5312+(pa*160|0)+(fa<<2)+32>>2]=W;c[f+5312+(pa*160|0)+(fa<<2)+36>>2]=W;c[f+5312+(pa*160|0)+(fa<<2)+64>>2]=W;c[f+5312+(pa*160|0)+(fa<<2)+68>>2]=W;c[f+5312+(pa*160|0)+(fa<<2)+96>>2]=W;c[f+5312+(pa*160|0)+(fa<<2)+100>>2]=W}j=j+1|0;}while((j|0)<2);j=pa+1|0;if(j>>>0<(c[R>>2]|0)>>>0){pa=j}else{La=v;break}}}else{do{if((va&1|0)==0){pa=f+4836|0;R=dha(f,c[pa>>2]|0,0)|0;c[pa>>2]=R;if((R|0)<0){oa=-1}else{break}i=g;return oa|0}else{R=f+425488|0;do{if((v|0)==0){I=129}else{if((Zha(R,(c[f+5712>>2]|0)+399+(f+425536)|0)|0)==0){I=129;break}c[k>>2]=c[k>>2]|16777216;pa=f+425604|0;ka=f+425605|0;ta=0;do{N=d[602272+ta|0]|0;T=a[N-1+(f+4888)|0]|0;P=a[N-8+(f+4888)|0]|0;j=(T|0)>(P|0)?P:T;T=(j|0)<0?2:j;if((bia(R,pa)|0)==0){j=bia(R,ka)|0;P=((bia(R,ka)|0)<<1)+j|0;j=P+((bia(R,ka)|0)<<2)|0;Sb=((j|0)>=(T|0))+j|0}else{Sb=T}T=(Sb*257|0)&65535;b[f+4888+N>>1]=T;b[N+8+(f+4888)>>1]=T;ta=ta+4|0;}while((ta|0)<16)}}while(0);if((I|0)==129){ta=f+425604|0;ka=f+425605|0;pa=0;do{fa=d[602272+pa|0]|0;na=a[fa-1+(f+4888)|0]|0;T=a[fa-8+(f+4888)|0]|0;N=(na|0)>(T|0)?T:na;na=(N|0)<0?2:N;if((bia(R,ta)|0)==0){N=bia(R,ka)|0;T=((bia(R,ka)|0)<<1)+N|0;N=T+((bia(R,ka)|0)<<2)|0;Tb=((N|0)>=(na|0))+N&255}else{Tb=na&255}a[f+4888+fa|0]=Tb;pa=pa+1|0;}while((pa|0)<16)}pa=c[f+4928>>2]|0;ka=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;c[pa+ka>>2]=c[f+4924>>2];a[pa+(ka+4)|0]=a[f+4919|0]|0;a[pa+(ka+5)|0]=a[f+4911|0]|0;a[pa+(ka+6)|0]=a[f+4903|0]|0;if((cha(f)|0)<0){oa=-1}else{break}i=g;return oa|0}}while(0);if(!x){c[f+4832>>2]=6;La=v;break}if((c[f+4872>>2]|0)==0){Ub=0}else{Ub=(a[(c[f+426576>>2]|0)+(c[f+4852>>2]|0)|0]|0)!=0|0}if((c[f+4864>>2]|0)==0){Vb=Ub}else{Vb=((a[(c[f+426576>>2]|0)+(c[f+4844>>2]|0)|0]|0)!=0)+Ub|0}ka=f+425488|0;do{if((Zha(ka,Vb+64+(f+425536)|0)|0)==0){Wb=0}else{pa=f+425603|0;if((Zha(ka,pa)|0)==0){Wb=1;break}R=(Zha(ka,pa)|0)==0;Wb=R?2:3}}while(0);a[(c[f+426576>>2]|0)+E|0]=Wb;ka=dha(f,Wb,1)|0;if((ka|0)<0){oa=-1;i=g;return oa|0}else{c[f+4832>>2]=ka;La=v;break}}}while(0);do{if((c[k>>2]&120|0)!=0){a[(c[f+426576>>2]|0)+E|0]=0;v=c[k>>2]|0;Wb=c[f+6108>>2]|0;Vb=(ca(Wb<<2,c[B>>2]|0)|0)+(c[z>>2]<<2)|0;Ub=c[F>>2]<<2;if((v&12288|0)==0){Tb=c[f+4084>>2]|0;b[Tb+Ub>>1]=-1;b[Tb+(Ub|2)>>1]=-1}else{Tb=c[f+4052>>2]|0;Sb=f+5360|0;va=c[Sb+4>>2]|0;t=Tb+(Vb<<2)|0;c[t>>2]=c[Sb>>2];c[t+4>>2]=va;va=f+5368|0;t=c[va+4>>2]|0;Sb=Tb+((Vb|2)<<2)|0;c[Sb>>2]=c[va>>2];c[Sb+4>>2]=t;t=f+5392|0;Sb=c[t+4>>2]|0;va=Vb+Wb|0;u=Tb+(va<<2)|0;c[u>>2]=c[t>>2];c[u+4>>2]=Sb;Sb=f+5400|0;u=c[Sb+4>>2]|0;t=Tb+(va+2<<2)|0;c[t>>2]=c[Sb>>2];c[t+4>>2]=u;u=f+5424|0;t=c[u+4>>2]|0;Sb=Vb+(Wb<<1)|0;va=Tb+(Sb<<2)|0;c[va>>2]=c[u>>2];c[va+4>>2]=t;t=f+5432|0;va=c[t+4>>2]|0;u=Tb+(Sb+2<<2)|0;c[u>>2]=c[t>>2];c[u+4>>2]=va;va=f+5456|0;u=c[va+4>>2]|0;t=Vb+(Wb*3|0)|0;Sb=Tb+(t<<2)|0;c[Sb>>2]=c[va>>2];c[Sb+4>>2]=u;u=f+5464|0;Sb=c[u+4>>2]|0;va=Tb+(t+2<<2)|0;c[va>>2]=c[u>>2];c[va+4>>2]=Sb;Sb=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;va=c[f+426584>>2]|0;u=va+(Sb<<1)|0;if((v&2048|0)==0){t=f+426664|0;Tb=c[t+4>>2]|0;Jb=u;c[Jb>>2]=c[t>>2];c[Jb+4>>2]=Tb;b[va+(Sb+6<<1)>>1]=b[f+426622>>1]|0;b[va+(Sb+5<<1)>>1]=b[f+426638>>1]|0;b[va+(Sb+4<<1)>>1]=b[f+426654>>1]|0}else{mrc(u|0,0,16)|0}u=c[f+4084>>2]|0;a[u+Ub|0]=a[f+5644|0]|0;a[u+(Ub|1)|0]=a[f+5646|0]|0;a[u+(Ub|2)|0]=a[f+5660|0]|0;a[u+(Ub|3)|0]=a[f+5662|0]|0}if((v&49152|0)!=0){u=c[f+4056>>2]|0;Sb=f+5520|0;va=c[Sb+4>>2]|0;Tb=u+(Vb<<2)|0;c[Tb>>2]=c[Sb>>2];c[Tb+4>>2]=va;va=f+5528|0;Tb=c[va+4>>2]|0;Sb=u+((Vb|2)<<2)|0;c[Sb>>2]=c[va>>2];c[Sb+4>>2]=Tb;Tb=f+5552|0;Sb=c[Tb+4>>2]|0;va=Vb+Wb|0;Jb=u+(va<<2)|0;c[Jb>>2]=c[Tb>>2];c[Jb+4>>2]=Sb;Sb=f+5560|0;Jb=c[Sb+4>>2]|0;Tb=u+(va+2<<2)|0;c[Tb>>2]=c[Sb>>2];c[Tb+4>>2]=Jb;Jb=f+5584|0;Tb=c[Jb+4>>2]|0;Sb=Vb+(Wb<<1)|0;va=u+(Sb<<2)|0;c[va>>2]=c[Jb>>2];c[va+4>>2]=Tb;Tb=f+5592|0;va=c[Tb+4>>2]|0;Jb=u+(Sb+2<<2)|0;c[Jb>>2]=c[Tb>>2];c[Jb+4>>2]=va;va=f+5616|0;Jb=c[va+4>>2]|0;Tb=Vb+(Wb*3|0)|0;Wb=u+(Tb<<2)|0;c[Wb>>2]=c[va>>2];c[Wb+4>>2]=Jb;Jb=f+5624|0;Wb=c[Jb+4>>2]|0;va=u+(Tb+2<<2)|0;c[va>>2]=c[Jb>>2];c[va+4>>2]=Wb;Wb=c[(c[f+6104>>2]|0)+(c[F>>2]<<2)>>2]|0;va=c[f+426588>>2]|0;Jb=va+(Wb<<1)|0;if((v&2048|0)==0){Tb=f+426744|0;u=c[Tb+4>>2]|0;Vb=Jb;c[Vb>>2]=c[Tb>>2];c[Vb+4>>2]=u;b[va+(Wb+6<<1)>>1]=b[f+426702>>1]|0;b[va+(Wb+5<<1)>>1]=b[f+426718>>1]|0;b[va+(Wb+4<<1)>>1]=b[f+426734>>1]|0}else{mrc(Jb|0,0,16)|0}Jb=c[f+4088>>2]|0;a[Jb+Ub|0]=a[f+5684|0]|0;a[Jb+(Ub|1)|0]=a[f+5686|0]|0;a[Jb+(Ub|2)|0]=a[f+5700|0]|0;a[Jb+(Ub|3)|0]=a[f+5702|0]|0}if((c[G>>2]|0)!=3){break}if((v&64|0)==0){break}v=c[F>>2]<<2;Ub=c[f+426752>>2]|0;a[Ub+(v|1)|0]=(e[f+177114>>1]|0)>>>1;a[Ub+(v|2)|0]=(e[f+177116>>1]|0)>>>1;a[Ub+(v|3)|0]=(e[f+177118>>1]|0)>>>1}}while(0);do{if((c[k>>2]&2|0)==0){G=f+426572|0;v=c[G>>2]|0;Ub=f+426568|0;Jb=c[Ub>>2]|0;Wb=f+425488|0;va=Zha(Wb,76-(Jb>>>2<<1&2|v>>>1&1)+(f+425536)|0)|0;u=((Zha(Wb,76-(Jb>>>3<<1&2|va&1)+(f+425536)|0)|0)<<1)+va|0;va=u+((Zha(Wb,76-(u<<1&2|v>>>3&1)+(f+425536)|0)|0)<<2)|0;v=va+((Zha(Wb,76-(va>>>2&1|va&2)+(f+425536)|0)|0)<<3)|0;if(!x){Xb=v;break}va=(c[G>>2]|0)>>>4&3;G=(c[Ub>>2]|0)>>>4&3;Ub=(va|0)!=0|0;if((Zha(Wb,((G|0)==0?Ub:Ub|2)+77+(f+425536)|0)|0)==0){Yb=0}else{Ub=(va|0)==2?5:4;Yb=((Zha(Wb,((G|0)==2?Ub|2:Ub)+77+(f+425536)|0)|0)<<4)+16|0}Xb=Yb|v}else{if(!(sa>>>0>15>>>0&(x^1))){Xb=sa;break}KIb(c[f>>2]|0,16,2605456,(Ja=i,i=i+1|0,i=i+7&-8,c[Ja>>2]=0,Ja)|0);i=Ja;oa=-1094995529;i=g;return oa|0}}while(0);c[f+426564>>2]=Xb;b[(c[f+426560>>2]|0)+(E<<1)>>1]=Xb;do{if((La|0)!=0){if((Xb&15|0)==0){break}if((c[k>>2]&7|0)!=0){break}sa=(Zha(f+425488|0,(c[f+5712>>2]|0)+399+(f+425536)|0)|0)<<24;c[k>>2]=c[k>>2]|sa}}while(0);La=c[k>>2]|0;do{if((c[w>>2]|0)==3){if((La&16777216|0)==0){break}sa=La&7;x=(sa|0)!=0?64:0;Yb=c[f+4872>>2]|0;if((Yb|0)!=0&(Yb&16777216|0)==0){a[f+5283|0]=x;a[f+5275|0]=x;a[f+5243|0]=x;a[f+5235|0]=x;a[f+5203|0]=x;a[f+5195|0]=x}Yb=c[f+4876>>2]|0;if((Yb|0)!=0&(Yb&16777216|0)==0){a[f+5299|0]=x;a[f+5291|0]=x;a[f+5259|0]=x;a[f+5251|0]=x;a[f+5219|0]=x;a[f+5211|0]=x}x=c[f+4864>>2]|0;if(!((x|0)!=0&(x&16777216|0)==0)){break}x=(sa|0)==0?0:1077952576;c[f+5188>>2]=x;c[f+5228>>2]=x;c[f+5268>>2]=x}}while(0);c[(c[f+4064>>2]|0)+(E<<2)>>2]=La;La=c[k>>2]|0;do{if((Xb|0)==0){if((La&2|0)!=0){I=492;break}c[f+5196>>2]=0;c[f+5204>>2]=0;c[f+5212>>2]=0;c[f+5220>>2]=0;c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;c[f+426580>>2]=0;Zb=f+4792|0}else{I=492}}while(0);j:do{if((I|0)==492){x=f+4792|0;sa=(c[x>>2]|0)!=0;if((La&128|0)==0){_b=sa?f+426812|0:f+427100|0;$b=sa?f+426796|0:f+427084|0}else{_b=sa?f+426956|0:f+427244|0;$b=sa?f+426940|0:f+427228|0}sa=_b|0;Yb=$b|0;v=f+425488|0;Ub=f+426580|0;if((Zha(v,((c[Ub>>2]|0)!=0|60)+(f+425536)|0)|0)==0){c[Ub>>2]=0;ac=c[x>>2]|0}else{G=(c[f+7308>>2]|0)*6|0;Wb=G+3|0;va=Wb<<1;u=62;Jb=1;while(1){if((Zha(v,f+425536+u|0)|0)==0){break}Vb=Jb+1|0;if((Vb|0)>(va|0)){I=499;break}else{u=63;Jb=Vb}}if((I|0)==499){u=c[B>>2]|0;KIb(c[f>>2]|0,16,2452848,(Ja=i,i=i+16|0,c[Ja>>2]=c[z>>2],c[Ja+8>>2]=u,Ja)|0);i=Ja;oa=-1;i=g;return oa|0}u=Jb+1>>1;va=(Jb&1|0)==0?-u|0:u;c[Ub>>2]=va;u=(c[x>>2]|0)+va|0;c[x>>2]=u;do{if(u>>>0>Wb>>>0){va=G+4|0;if((u|0)<0){Vb=u+va|0;c[x>>2]=Vb;bc=Vb;break}else{Vb=u-va|0;c[x>>2]=Vb;bc=Vb;break}}else{bc=u}}while(0);c[f+4756>>2]=d[f+7876+bc|0]|0;c[f+4760>>2]=d[f+7964+bc|0]|0;ac=bc}u=c[k>>2]|0;do{if((u&2|0)==0){G=(u&7|0)!=0?0:3;Wb=(u&16777216|0)==0;Ub=f+177020+(G<<2)|0;Jb=f+177044+(G<<2)|0;G=0;do{k:do{if((1<<G&Xb|0)==0){Vb=d[602272+(G<<2)|0]|0;b[f+5184+Vb>>1]=0;b[Vb+8+(f+5184)>>1]=0}else{if(!Wb){Vb=G<<2;va=f+421200+(G<<6<<y<<1)|0;Tb=(c[Jb>>2]|0)+(ac<<8)|0;do{if((c[w>>2]|0)==3){Sb=d[602272+Vb|0]|0;t=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((bia(v,(((a[Sb-8+(f+5184)|0]|0)!=0?t|2:t)|1012)+(f+425536)|0)|0)!=0){break}b[f+5184+Sb>>1]=0;b[Sb+8+(f+5184)>>1]=0;break k}}while(0);dia(f,va,5,Vb,sa,Tb,64);break}L=(c[Ub>>2]|0)+(ac<<6)|0;K=G<<2;Sb=0;do{t=Sb+K|0;Kb=d[602272+t|0]|0;Rb=(a[Kb-1+(f+5184)|0]|0)!=0|0;if((bia(v,((a[Kb-8+(f+5184)|0]|0)!=0?Rb|2:Rb)+93+(f+425536)|0)|0)==0){a[f+5184+Kb|0]=0}else{dia(f,f+421200+(t<<4<<y<<1)|0,2,t,Yb,L,16)}Sb=Sb+1|0;}while((Sb|0)<4)}}while(0);G=G+1|0;}while((G|0)<4)}else{G=f+424272|0;mrc(G|0,0,64)|0;Ub=(c[f+426572>>2]|0)>>>8&1;if((bia(v,((c[f+426568>>2]&256|0)!=0?Ub|2:Ub)+85+(f+425536)|0)|0)==0){a[f+5184|0]=0}else{cia(f,G,0,48,Yb,16)}if((Xb&15|0)==0){c[f+5196>>2]=0;c[f+5204>>2]=0;c[f+5212>>2]=0;c[f+5220>>2]=0;break}G=(c[f+177020>>2]|0)+(ac<<6)|0;Ub=$b+1|0;Jb=0;do{Wb=d[602272+Jb|0]|0;Sb=(a[Wb-1+(f+5184)|0]|0)!=0|0;if((bia(v,((a[Wb-8+(f+5184)|0]|0)!=0?Sb|2:Sb)+89+(f+425536)|0)|0)==0){a[f+5184+Wb|0]=0}else{dia(f,f+421200+(Jb<<4<<y<<1)|0,1,Jb,Ub,G,15)}Jb=Jb+1|0;}while((Jb|0)<16)}}while(0);u=c[w>>2]|0;if((u|0)!=3){Jb=(Xb&48|0)!=0;if((u|0)!=2){do{if(Jb){u=f+426572|0;G=f+426568|0;Ub=(c[u>>2]|0)>>>6&1;if((bia(v,((c[G>>2]&64|0)!=0?Ub|2:Ub)+97+(f+425536)|0)|0)==0){a[f+5224|0]=0}else{cia(f,f+421200+(256<<y<<1)|0,3,49,1706360,4)}Ub=(c[u>>2]|0)>>>7&1;if((bia(v,((c[G>>2]&128|0)!=0?Ub|2:Ub)+97+(f+425536)|0)|0)==0){a[f+5264|0]=0;break}else{cia(f,f+421200+(512<<y<<1)|0,3,50,1706360,4);break}}}while(0);if((Xb&32|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;Zb=x;break}Ub=$b+1|0;G=(c[f+177020+(((c[k>>2]&7|0)!=0?1:4)<<2)>>2]|0)+(c[f+4756>>2]<<6)|0;u=0;do{Wb=u+16|0;Sb=d[602272+Wb|0]|0;L=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((bia(v,((a[Sb-8+(f+5184)|0]|0)!=0?L|2:L)+101+(f+425536)|0)|0)==0){a[f+5184+Sb|0]=0}else{dia(f,f+421200+(Wb<<4<<y<<1)|0,4,Wb,Ub,G,15)}u=u+1|0;}while((u|0)<4);u=(c[f+177020+(((c[k>>2]&7|0)!=0?2:5)<<2)>>2]|0)+(c[f+4760>>2]<<6)|0;G=0;while(1){Wb=G+32|0;Sb=d[602272+Wb|0]|0;L=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((bia(v,((a[Sb-8+(f+5184)|0]|0)!=0?L|2:L)+101+(f+425536)|0)|0)==0){a[f+5184+Sb|0]=0}else{dia(f,f+421200+(Wb<<4<<y<<1)|0,4,Wb,Ub,u,15)}Wb=G+1|0;if((Wb|0)<4){G=Wb}else{Zb=x;break j}}}do{if(Jb){G=f+426572|0;u=f+426568|0;Ub=(c[G>>2]|0)>>>6&1;if((bia(v,((c[u>>2]&64|0)!=0?Ub|2:Ub)+97+(f+425536)|0)|0)==0){a[f+5224|0]=0}else{eia(f,f+421200+(256<<y<<1)|0,49)}Ub=(c[G>>2]|0)>>>7&1;if((bia(v,((c[u>>2]&128|0)!=0?Ub|2:Ub)+97+(f+425536)|0)|0)==0){a[f+5264|0]=0;break}else{eia(f,f+421200+(512<<y<<1)|0,50);break}}}while(0);if((Xb&32|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;Zb=x;break}Jb=16<<y;Ub=$b+1|0;u=Jb<<2;G=0;while(1){Wb=(G<<4)+16|0;Sb=G+1|0;L=(c[f+177020+(((c[k>>2]&7|0)!=0?0:3)+Sb<<2)>>2]|0)+(c[f+4756+(G<<2)>>2]<<6)|0;K=0;Tb=f+421200+(Wb<<4<<y<<1)|0;while(1){Vb=(K<<3)+Wb|0;va=d[602272+Vb|0]|0;t=(a[va-1+(f+5184)|0]|0)!=0|0;if((bia(v,((a[va-8+(f+5184)|0]|0)!=0?t|2:t)+101+(f+425536)|0)|0)==0){a[f+5184+va|0]=0}else{dia(f,Tb,4,Vb,Ub,L,15)}va=Vb|1;t=d[602272+va|0]|0;Kb=(a[t-1+(f+5184)|0]|0)!=0|0;if((bia(v,((a[t-8+(f+5184)|0]|0)!=0?Kb|2:Kb)+101+(f+425536)|0)|0)==0){a[f+5184+t|0]=0}else{dia(f,Tb+(Jb<<1)|0,4,va,Ub,L,15)}va=Jb<<1;t=Vb|2;Kb=d[602272+t|0]|0;Rb=(a[Kb-1+(f+5184)|0]|0)!=0|0;if((bia(v,((a[Kb-8+(f+5184)|0]|0)!=0?Rb|2:Rb)+101+(f+425536)|0)|0)==0){a[f+5184+Kb|0]=0}else{dia(f,Tb+(va<<1)|0,4,t,Ub,L,15)}t=Vb|3;Vb=d[602272+t|0]|0;Kb=(a[Vb-1+(f+5184)|0]|0)!=0|0;if((bia(v,((a[Vb-8+(f+5184)|0]|0)!=0?Kb|2:Kb)+101+(f+425536)|0)|0)==0){a[f+5184+Vb|0]=0}else{dia(f,Tb+(va+Jb<<1)|0,4,t,Ub,L,15)}t=K+1|0;if((t|0)<2){K=t;Tb=Tb+(u<<1)|0}else{break}}if((Sb|0)<2){G=Sb}else{Zb=x;break j}}}G=c[k>>2]|0;u=c[f+4756>>2]|0;do{if((G&2|0)==0){Ub=(G&7|0)!=0?1:4;Jb=(G&16777216|0)==0;Tb=f+177020+(Ub<<2)|0;K=f+177044+(Ub<<2)|0;Ub=0;do{do{if((1<<Ub&Xb|0)==0){L=d[(Ub<<2)+602288|0]|0;b[f+5184+L>>1]=0;b[L+8+(f+5184)>>1]=0}else{if(!Jb){L=(Ub<<2)+16|0;Wb=c[K>>2]|0;t=d[602272+L|0]|0;va=(a[t-1+(f+5184)|0]|0)!=0|0;if((bia(v,(((a[t-8+(f+5184)|0]|0)!=0?va|2:va)|1016)+(f+425536)|0)|0)==0){b[f+5184+t>>1]=0;b[t+8+(f+5184)>>1]=0;break}else{dia(f,f+421200+(L<<4<<y<<1)|0,9,L,sa,Wb+(u<<8)|0,64);break}}Wb=(c[Tb>>2]|0)+(u<<6)|0;L=(Ub<<2)+16|0;t=0;do{va=L+t|0;Vb=d[602272+va|0]|0;Kb=(a[Vb-1+(f+5184)|0]|0)!=0|0;if((bia(v,(((a[Vb-8+(f+5184)|0]|0)!=0?Kb|2:Kb)|468)+(f+425536)|0)|0)==0){a[f+5184+Vb|0]=0}else{dia(f,f+421200+(va<<4<<y<<1)|0,8,va,Yb,Wb,16)}t=t+1|0;}while((t|0)<4)}}while(0);Ub=Ub+1|0;}while((Ub|0)<4)}else{Ub=f+424336|0;mrc(Ub|0,0,64)|0;Tb=(c[f+426572>>2]|0)>>>9&1;if((bia(v,(((c[f+426568>>2]&512|0)!=0?Tb|2:Tb)|460)+(f+425536)|0)|0)==0){a[f+5224|0]=0}else{cia(f,Ub,6,49,Yb,16)}if((Xb&15|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;break}Ub=(c[f+177024>>2]|0)+(u<<6)|0;Tb=$b+1|0;K=0;do{Jb=K+16|0;Sb=d[602272+Jb|0]|0;t=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((bia(v,(((a[Sb-8+(f+5184)|0]|0)!=0?t|2:t)|464)+(f+425536)|0)|0)==0){a[f+5184+Sb|0]=0}else{dia(f,f+421200+(Jb<<4<<y<<1)|0,7,Jb,Tb,Ub,15)}K=K+1|0;}while((K|0)<16)}}while(0);u=c[k>>2]|0;G=c[f+4760>>2]|0;if((u&2|0)!=0){K=f+424400|0;mrc(K|0,0,64)|0;Ub=(c[f+426572>>2]|0)>>>10&1;if((bia(v,(((c[f+426568>>2]&1024|0)!=0?Ub|2:Ub)|472)+(f+425536)|0)|0)==0){a[f+5264|0]=0}else{cia(f,K,10,50,Yb,16)}if((Xb&15|0)==0){c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;Zb=x;break}K=(c[f+177028>>2]|0)+(G<<6)|0;Ub=$b+1|0;Tb=0;while(1){Jb=Tb+32|0;Sb=d[602272+Jb|0]|0;t=(a[Sb-1+(f+5184)|0]|0)!=0|0;if((bia(v,(((a[Sb-8+(f+5184)|0]|0)!=0?t|2:t)|476)+(f+425536)|0)|0)==0){a[f+5184+Sb|0]=0}else{dia(f,f+421200+(Jb<<4<<y<<1)|0,11,Jb,Ub,K,15)}Jb=Tb+1|0;if((Jb|0)<16){Tb=Jb}else{Zb=x;break j}}}Tb=(u&7|0)!=0?2:5;K=(u&16777216|0)==0;Ub=f+177020+(Tb<<2)|0;Jb=f+177044+(Tb<<2)|0;Tb=0;while(1){do{if((1<<Tb&Xb|0)==0){Sb=d[(Tb<<2)+602304|0]|0;b[f+5184+Sb>>1]=0;b[Sb+8+(f+5184)>>1]=0}else{if(!K){Sb=(Tb<<2)+32|0;t=c[Jb>>2]|0;Wb=d[602272+Sb|0]|0;L=(a[Wb-1+(f+5184)|0]|0)!=0|0;if((bia(v,(((a[Wb-8+(f+5184)|0]|0)!=0?L|2:L)|1020)+(f+425536)|0)|0)==0){b[f+5184+Wb>>1]=0;b[Wb+8+(f+5184)>>1]=0;break}else{dia(f,f+421200+(Sb<<4<<y<<1)|0,13,Sb,sa,t+(G<<8)|0,64);break}}t=(c[Ub>>2]|0)+(G<<6)|0;Sb=(Tb<<2)+32|0;Wb=0;do{L=Sb+Wb|0;va=d[602272+L|0]|0;Vb=(a[va-1+(f+5184)|0]|0)!=0|0;if((bia(v,(((a[va-8+(f+5184)|0]|0)!=0?Vb|2:Vb)|480)+(f+425536)|0)|0)==0){a[f+5184+va|0]=0}else{dia(f,f+421200+(L<<4<<y<<1)|0,12,L,Yb,t,16)}Wb=Wb+1|0;}while((Wb|0)<4)}}while(0);Wb=Tb+1|0;if((Wb|0)<4){Tb=Wb}else{Zb=x;break}}}}while(0);a[(c[f+4040>>2]|0)+E|0]=c[Zb>>2];Zb=c[F>>2]|0;F=c[f+5304>>2]|0;c[F+(Zb*48|0)>>2]=c[f+5196>>2];c[F+(Zb*48|0)+4>>2]=c[f+5204>>2];c[F+(Zb*48|0)+8>>2]=c[f+5212>>2];c[F+(Zb*48|0)+12>>2]=c[f+5220>>2];c[F+(Zb*48|0)+16>>2]=c[f+5236>>2];c[F+(Zb*48|0)+20>>2]=c[f+5244>>2];c[F+(Zb*48|0)+32>>2]=c[f+5276>>2];c[F+(Zb*48|0)+36>>2]=c[f+5284>>2];if((c[f+4788>>2]|0)!=0){oa=0;i=g;return oa|0}c[F+(Zb*48|0)+24>>2]=c[f+5252>>2];c[F+(Zb*48|0)+28>>2]=c[f+5260>>2];c[F+(Zb*48|0)+40>>2]=c[f+5292>>2];c[F+(Zb*48|0)+44>>2]=c[f+5300>>2];oa=0;i=g;return oa|0}function Xha(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;do{if((c[a+177088>>2]|0)==0){f=c[a+427412>>2]|0;g=f-1|0;h=f-(c[a+427404>>2]<<((c[a+177100>>2]|0)!=3))|0}else{f=c[a+427404>>2]|0;i=(ca(f,d&-2)|0)+b|0;j=i-1|0;k=(d&1|0)!=0;do{if(k){if((e[(c[a+177072>>2]|0)+(j<<1)>>1]|0|0)!=(c[a+177068>>2]|0)){l=j;break}l=((c[a+177092>>2]|0)==((c[(c[a+4064>>2]|0)+(j<<2)>>2]|0)>>>7&1|0)?f:0)+j|0}else{l=j}}while(0);if((c[a+177092>>2]|0)==0){g=l;h=(ca(f,d-1|0)|0)+b|0;break}j=i-f|0;if(k){g=l;h=j;break}if((e[(c[a+177072>>2]|0)+(j<<1)>>1]|0|0)!=(c[a+177068>>2]|0)){g=l;h=j;break}g=l;h=j-((c[(c[a+4064>>2]|0)+(j<<2)>>2]&128|0)==0?0:f)|0}}while(0);l=c[a+177072>>2]|0;b=c[a+177068>>2]|0;if((e[l+(g<<1)>>1]|0|0)==(b|0)){m=(c[(c[a+4064>>2]|0)+(g<<2)>>2]|0)>>>11&1^1}else{m=0}if((e[l+(h<<1)>>1]|0|0)!=(b|0)){n=m;o=a+177080|0;p=c[o>>2]|0;q=(p|0)==3;r=n+13|0;s=q?r:n;t=a+425488|0;u=s+11|0;v=a+425536+u|0;w=Zha(t,v)|0;return w|0}n=((c[(c[a+4064>>2]|0)+(h<<2)>>2]|0)>>>11&1^1)+m|0;o=a+177080|0;p=c[o>>2]|0;q=(p|0)==3;r=n+13|0;s=q?r:n;t=a+425488|0;u=s+11|0;v=a+425536+u|0;w=Zha(t,v)|0;return w|0}function Yha(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[a+427412>>2]|0;f=a+4884|0;c[f>>2]=-1;g=c[a+427404>>2]|0;h=d-(g<<c[a+177092>>2])|0;i=h-1|0;j=h+1|0;k=d-1|0;l=a+4880|0;c[l>>2]=1234784;m=c[a+4064>>2]|0;do{if((c[a+177088>>2]|0)==0){n=i;o=h;p=k;q=k;r=j}else{s=c[m+(k<<2)>>2]&128;t=b&128;if((c[a+427380>>2]&1|0)!=0){if((s|0)==(t|0)){n=i;o=h;p=k;q=k;r=j;break}u=d-g-1|0;if((t|0)==0){c[f>>2]=0;c[l>>2]=1234816;n=g+i|0;o=h;p=u;q=u;r=j;break}else{c[l>>2]=1234880;n=i;o=h;p=u;q=k;r=j;break}}u=(t|0)!=0;if(u){v=(((c[m+(i<<2)>>2]|0)>>>7&1)-1&g)+i|0;w=(((c[m+(h<<2)>>2]|0)>>>7&1)-1&g)+h|0;x=(((c[m+(j<<2)>>2]|0)>>>7&1)-1&g)+j|0}else{v=i;w=h;x=j}if((s|0)==(t|0)){n=v;o=w;p=k;q=k;r=x;break}if(u){c[l>>2]=1234880;n=v;o=w;p=k;q=g+k|0;r=x;break}else{c[l>>2]=1234848;n=v;o=w;p=k;q=k;r=x;break}}}while(0);c[a+4840>>2]=n;c[a+4844>>2]=o;c[a+4848>>2]=r;c[a+4852>>2]=p;c[a+4856>>2]=q;x=a+4860|0;c[x>>2]=c[m+(n<<2)>>2];k=a+4864|0;c[k>>2]=c[m+(o<<2)>>2];w=a+4868|0;c[w>>2]=c[m+(r<<2)>>2];v=a+4872|0;c[v>>2]=c[m+(p<<2)>>2];l=a+4876|0;c[l>>2]=c[m+(q<<2)>>2];q=c[a+177072>>2]|0;m=e[q+(n<<1)>>1]|0;n=c[a+177068>>2]|0;do{if((m|0)==(n|0)){y=m}else{c[x>>2]=0;if((e[q+(o<<1)>>1]|0|0)!=(n|0)){c[k>>2]=0}if((e[q+(p<<1)>>1]|0|0)==(n|0)){y=n;break}c[l>>2]=0;c[v>>2]=0;y=n}}while(0);if((e[q+(r<<1)>>1]|0|0)==(y|0)){return}c[w>>2]=0;return}function Zha(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[e]|0;g=b+4|0;h=c[g>>2]|0;i=d[1376824+((h<<1&384)+(f|512))|0]|0;j=h-i|0;h=j<<17;k=b|0;l=c[k>>2]|0;m=h-l>>31;c[k>>2]=l-(m&h);c[g>>2]=(m&i-j)+j;j=m^f;a[e]=a[j+1377976|0]|0;e=j&1;j=c[g>>2]|0;f=d[1376824+j|0]|0;c[g>>2]=j<<f;j=c[k>>2]<<f;c[k>>2]=j;if((j&65535|0)!=0){return e|0}f=b+16|0;b=c[f>>2]|0;c[k>>2]=(((d[b+1|0]|0)<<1|(d[b]|0)<<9)-65535<<7-(d[1376824+((j-1^j)>>15)|0]|0))+j;c[f>>2]=b+2;return e|0}function _ha(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a+425536+b|0;do{if((e|0)==0){if((Zha(a+425488|0,f)|0)==0){g=0}else{h=f;break}return g|0}else{i=(c[a+4872>>2]&6|0)!=0;if((Zha(a+425488|0,((c[a+4864>>2]&6|0)==0?i&1:i?2:1)+b+(a+425536)|0)|0)==0){g=0;return g|0}else{h=b+2+(a+425536)|0;break}}}while(0);b=a+425488|0;f=a+425492|0;i=c[f>>2]|0;j=i-2|0;c[f>>2]=j;k=b|0;l=c[k>>2]|0;do{if((l|0)<(j<<17|0)){m=(i-258|0)>>>31;c[f>>2]=j<<m;n=l<<m;c[k>>2]=n;if((n&65535|0)!=0){break}m=a+425504|0;o=c[m>>2]|0;c[k>>2]=n-65535+((d[o+1|0]|0)<<1|(d[o]|0)<<9);c[m>>2]=o+2}else{if((c[a+425504>>2]|0)==(c[a+425500>>2]|0)){break}else{g=25}return g|0}}while(0);a=(Zha(b,h+1|0)|0)*12|0|1;if((Zha(b,h+2|0)|0)==0){p=a}else{p=a+4+((Zha(b,h+(e+2)|0)|0)<<2)|0}a=((Zha(b,h+(e+3)|0)|0)<<1)+p|0;g=a+(Zha(b,h+((e<<1)+3)|0)|0)|0;return g|0}function $ha(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[f+4880>>2]|0;m=c[f+4840>>2]|0;n=c[f+4844>>2]|0;o=c[f+4848>>2]|0;p=c[f+4852>>2]|0;c[j>>2]=p;q=c[f+4856>>2]|0;c[j+4>>2]=q;r=c[f+4860>>2]|0;s=c[f+4864>>2]|0;t=c[f+4868>>2]|0;u=c[f+4872>>2]|0;c[k>>2]=u;v=c[f+4876>>2]|0;c[k+4>>2]=v;do{if((g&2048|0)==0){w=(g&7|0)!=0;do{if(w){x=(c[f+7384>>2]|0)!=0?7:-1;y=f+5172|0;c[y>>2]=65535;z=f+5164|0;c[z>>2]=65535;A=f+5160|0;c[A>>2]=65535;B=f+5168|0;c[B>>2]=61162;C=(x&s|0)!=0;if(C){D=65535;E=60138}else{c[A>>2]=46079;c[z>>2]=13311;c[B>>2]=9962;D=46079;E=8938}z=g&128;do{if((z|0)==(u&128|0)){if((u&x|0)!=0){F=D;break}G=D&57183;c[A>>2]=G;c[y>>2]=24415;F=G}else{if((z|0)==0){if((c[(c[f+4064>>2]|0)+((c[f+427404>>2]|0)+p<<2)>>2]&x|0)!=0){if((u&x|0)!=0){F=D;break}}G=D&57183;c[A>>2]=G;c[y>>2]=24415;F=G;break}if((u&x|0)==0){G=D&57343;c[A>>2]=G;c[y>>2]=24575;H=G;I=24415}else{H=D;I=65375}if((v&x|0)!=0){F=H;break}G=H&65375;c[A>>2]=G;c[y>>2]=I;F=G}}while(0);if((x&r|0)==0){c[A>>2]=F&32767}if((x&t|0)==0){c[B>>2]=E}if((g&1|0)==0){break}if((s&1|0)==0){mrc(f+4892|0,2-(-(C&1^1)&3)&255|0,4)|0;J=f+4928|0;K=f+6104|0}else{y=f+4928|0;z=f+6104|0;c[f+4892>>2]=c[(c[y>>2]|0)+(c[(c[z>>2]|0)+(n<<2)>>2]|0)>>2];J=y;K=z}if((u&1|0)==0){z=2-(-((u&x|0)==0|0)&3)&255;a[f+4907|0]=z;a[f+4899|0]=z}else{z=c[J>>2]|0;y=(c[(c[K>>2]|0)+(p<<2)>>2]|0)+6|0;a[f+4899|0]=a[z+(y-(d[l]|0))|0]|0;a[f+4907|0]=a[z+(y-(d[l+1|0]|0))|0]|0}if((v&1|0)==0){y=2-(-((v&x|0)==0|0)&3)&255;a[f+4923|0]=y;a[f+4915|0]=y;break}else{y=c[J>>2]|0;z=(c[(c[K>>2]|0)+(q<<2)>>2]|0)+6|0;a[f+4915|0]=a[y+(z-(d[l+2|0]|0))|0]|0;a[f+4923|0]=a[y+(z-(d[l+3|0]|0))|0]|0;break}}}while(0);z=(s|0)!=0;do{if(z){y=f+5304|0;G=c[y>>2]|0;c[f+5188>>2]=c[G+(n*48|0)+12>>2];if((c[f+4788>>2]|0)==0){c[f+5228>>2]=c[G+(n*48|0)+28>>2];c[f+5268>>2]=c[G+(n*48|0)+44>>2];L=y;break}else{c[f+5228>>2]=c[G+(n*48|0)+20>>2];c[f+5268>>2]=c[G+(n*48|0)+36>>2];L=y;break}}else{y=w?1077952576:0;c[f+5188>>2]=y;c[f+5228>>2]=y;c[f+5268>>2]=y;L=f+5304|0}}while(0);y=w?64:0;G=f+6136|0;M=0;N=u;while(1){do{if((N|0)==0){O=M<<4;a[O+99+(f+5184)|0]=y;a[O+91+(f+5184)|0]=y;a[O+59+(f+5184)|0]=y;a[O+51+(f+5184)|0]=y;a[O+19+(f+5184)|0]=y;a[(O|11)+(f+5184)|0]=y}else{O=c[j+(M<<2)>>2]|0;P=c[L>>2]|0;Q=M<<1;R=l+(Q+8)|0;S=M<<4;a[(S|11)+(f+5184)|0]=a[(d[R]|0)+(P+(O*48|0))|0]|0;T=l+(Q+9)|0;a[S+19+(f+5184)|0]=a[(d[T]|0)+(P+(O*48|0))|0]|0;U=c[G>>2]|0;if((U|0)==2){a[S+51+(f+5184)|0]=a[(d[R]|0)+14+(P+(O*48|0))|0]|0;a[S+59+(f+5184)|0]=a[(d[T]|0)+14+(P+(O*48|0))|0]|0;a[S+91+(f+5184)|0]=a[(d[R]|0)+30+(P+(O*48|0))|0]|0;a[S+99+(f+5184)|0]=a[(d[T]|0)+30+(P+(O*48|0))|0]|0;break}else if((U|0)==3){a[S+51+(f+5184)|0]=a[(d[R]|0)+16+(P+(O*48|0))|0]|0;a[S+59+(f+5184)|0]=a[(d[T]|0)+16+(P+(O*48|0))|0]|0;a[S+91+(f+5184)|0]=a[(d[R]|0)+32+(P+(O*48|0))|0]|0;a[S+99+(f+5184)|0]=a[(d[T]|0)+32+(P+(O*48|0))|0]|0;break}else{T=M<<3;a[T+51+(f+5184)|0]=a[(d[l+(Q+12)|0]|0)+(P+(O*48|0))|0]|0;a[T+91+(f+5184)|0]=a[(d[l+(Q+13)|0]|0)+(P+(O*48|0))|0]|0;break}}}while(0);x=M+1|0;if((x|0)>=2){break}M=x;N=c[k+(x<<2)>>2]|0}if(z){c[f+426568>>2]=e[(c[f+426560>>2]|0)+(n<<1)>>1]|0}else{c[f+426568>>2]=w?1999:15}if((u|0)==0){c[f+426572>>2]=w?1999:15;break}else{N=c[f+426560>>2]|0;M=e[N+(p<<1)>>1]|0;c[f+426572>>2]=M>>>((a[l]&254)>>>0)&2|M&2032|(e[N+(q<<1)>>1]|0)>>>((a[l+2|0]&254)>>>0)<<2&8;break}}}while(0);do{if((g&120|0)==0){if((g&256|0)==0){V=s>>>24;W=V&1;X=u>>>24;Y=X&1;Z=Y+W|0;_=f+5712|0;c[_>>2]=Z;i=h;return}if((c[f+197872>>2]|0)!=0){break}V=s>>>24;W=V&1;X=u>>>24;Y=X&1;Z=Y+W|0;_=f+5712|0;c[_>>2]=Z;i=h;return}}while(0);k=c[f+6108>>2]|0;L=f+199428|0;if((c[L>>2]|0)==0){V=s>>>24;W=V&1;X=u>>>24;Y=X&1;Z=Y+W|0;_=f+5712|0;c[_>>2]=Z;i=h;return}j=f+6100|0;K=k*3|0;J=n<<2;E=J|2;F=J|3;J=(g&80|0)==0;I=(u|0)!=0?-1:-2;H=p<<2|1;D=(t|0)!=0?-1:-2;N=(r|0)!=0?-1:-2;M=f+4884|0;G=k<<1;y=k+3|0;x=m<<2;C=(g&2304|0)==0;B=f+6104|0;A=f+177080|0;O=f+426752|0;P=f+426768|0;Q=f+426776|0;T=f+426784|0;S=f+426792|0;R=(s&256|0)==0;U=(s&64|0)==0;$=f+426760|0;aa=$;ba=f+426762|0;da=(u&256|0)==0;ea=(u&64|0)==0;fa=f+426767|0;ga=(v&256|0)==0;ha=(v&64|0)==0;ia=f+426783|0;ja=q<<2|1;ka=l+2|0;la=l+3|0;ma=l+1|0;na=f+177088|0;oa=f+177092|0;pa=(r&128|0)!=0;qa=(s&128|0)!=0;ra=(t&128|0)==0;sa=(u&128|0)==0;ta=(v&128|0)==0;ua=o<<2|2;va=(s|0)!=0?-1:-16843010;wa=0;do{xa=c[f+4084+(wa<<2)>>2]|0;ya=c[f+4052+(wa<<2)>>2]|0;za=12288<<(wa<<1);do{if((za&g|0)!=0){Aa=(za&s|0)!=0;if(Aa){Ba=(c[(c[j>>2]|0)+(n<<2)>>2]|0)+K|0;Ca=ya+(Ba<<2)|0;Da=c[Ca+4>>2]|0;Ea=f+5312+(wa*160|0)+16|0;c[Ea>>2]=c[Ca>>2];c[Ea+4>>2]=Da;Da=ya+(Ba<<2)+8|0;Ba=c[Da+4>>2]|0;Ea=f+5312+(wa*160|0)+24|0;c[Ea>>2]=c[Da>>2];c[Ea+4>>2]=Ba;Ba=a[xa+E|0]|0;a[f+5632+(wa*40|0)+5|0]=Ba;a[f+5632+(wa*40|0)+4|0]=Ba;Ba=a[xa+F|0]|0;a[f+5632+(wa*40|0)+7|0]=Ba;a[f+5632+(wa*40|0)+6|0]=Ba}else{mrc(f+5312+(wa*160|0)+16|0,0,16)|0;c[f+5632+(wa*40|0)+4>>2]=va}Ba=(u&za|0)==0;do{if(J){if(Ba){c[f+5312+(wa*160|0)+44>>2]=0;a[f+5632+(wa*40|0)+11|0]=I;break}else{c[f+5312+(wa*160|0)+44>>2]=c[ya+((c[(c[j>>2]|0)+(p<<2)>>2]|0)+3+(ca(d[l]|0,k)|0)<<2)>>2];a[f+5632+(wa*40|0)+11|0]=a[xa+((a[l]&254)+H)|0]|0;break}}else{if(Ba){c[f+5312+(wa*160|0)+44>>2]=0;c[f+5312+(wa*160|0)+76>>2]=0;a[f+5632+(wa*40|0)+19|0]=I;a[f+5632+(wa*40|0)+11|0]=I}else{Ea=(c[(c[j>>2]|0)+(p<<2)>>2]|0)+3|0;c[f+5312+(wa*160|0)+44>>2]=c[ya+((ca(d[l]|0,k)|0)+Ea<<2)>>2];c[f+5312+(wa*160|0)+76>>2]=c[ya+((ca(d[ma]|0,k)|0)+Ea<<2)>>2];a[f+5632+(wa*40|0)+11|0]=a[xa+((a[l]&254)+H)|0]|0;a[f+5632+(wa*40|0)+19|0]=a[xa+((a[ma]&254)+H)|0]|0}if((v&za|0)==0){c[f+5312+(wa*160|0)+108>>2]=0;c[f+5312+(wa*160|0)+140>>2]=0;Ea=(v|0)!=0?-1:-2;a[f+5632+(wa*40|0)+35|0]=Ea;a[f+5632+(wa*40|0)+27|0]=Ea;break}else{Ea=(c[(c[j>>2]|0)+(q<<2)>>2]|0)+3|0;c[f+5312+(wa*160|0)+108>>2]=c[ya+((ca(d[ka]|0,k)|0)+Ea<<2)>>2];c[f+5312+(wa*160|0)+140>>2]=c[ya+((ca(d[la]|0,k)|0)+Ea<<2)>>2];a[f+5632+(wa*40|0)+27|0]=a[xa+((a[ka]&254)+ja)|0]|0;a[f+5632+(wa*40|0)+35|0]=a[xa+((a[la]&254)+ja)|0]|0;break}}}while(0);if((za&t|0)==0){c[f+5312+(wa*160|0)+32>>2]=0;a[f+5632+(wa*40|0)+8|0]=D;Fa=D}else{c[f+5312+(wa*160|0)+32>>2]=c[ya+((c[(c[j>>2]|0)+(o<<2)>>2]|0)+K<<2)>>2];Ba=a[xa+ua|0]|0;a[f+5632+(wa*40|0)+8|0]=Ba;Fa=Ba}Ba=f+5632+(wa*40|0)+6|0;do{if((a[Ba]|Fa)<<24>>24<0){if((za&r|0)==0){c[f+5312+(wa*160|0)+12>>2]=0;a[f+5632+(wa*40|0)+3|0]=N;break}else{Ea=c[M>>2]|0;c[f+5312+(wa*160|0)+12>>2]=c[ya+(y+(c[(c[j>>2]|0)+(m<<2)>>2]|0)+(Ea&G)<<2)>>2];a[f+5632+(wa*40|0)+3|0]=a[xa+(x|Ea&2|1)|0]|0;break}}}while(0);if(C){Ea=c[f+426584+(wa<<2)>>2]|0;a[f+5632+(wa*40|0)+30|0]=-2;a[f+5632+(wa*40|0)+14|0]=-2;c[f+5312+(wa*160|0)+56>>2]=0;c[f+5312+(wa*160|0)+120>>2]=0;if(Aa){Da=Ea+(c[(c[B>>2]|0)+(n<<2)>>2]<<1)|0;Ca=c[Da+4>>2]|0;Ga=f+426592+(wa*80|0)+8|0;c[Ga>>2]=c[Da>>2];c[Ga+4>>2]=Ca}else{Ca=f+426592+(wa*80|0)+8|0;c[Ca>>2]=0;c[Ca+4>>2]=0}if((u&za|0)==0){b[f+426592+(wa*80|0)+22>>1]=0;b[f+426592+(wa*80|0)+38>>1]=0}else{Ca=(c[(c[B>>2]|0)+(p<<2)>>2]|0)+6|0;b[f+426592+(wa*80|0)+22>>1]=b[Ea+(Ca-(d[l]|0)<<1)>>1]|0;b[f+426592+(wa*80|0)+38>>1]=b[Ea+(Ca-(d[ma]|0)<<1)>>1]|0}if((v&za|0)==0){b[f+426592+(wa*80|0)+54>>1]=0;b[f+426592+(wa*80|0)+70>>1]=0}else{Ca=(c[(c[B>>2]|0)+(q<<2)>>2]|0)+6|0;b[f+426592+(wa*80|0)+54>>1]=b[Ea+(Ca-(d[ka]|0)<<1)>>1]|0;b[f+426592+(wa*80|0)+70>>1]=b[Ea+(Ca-(d[la]|0)<<1)>>1]|0}b[f+426592+(wa*80|0)+28>>1]=0;b[f+426592+(wa*80|0)+60>>1]=0;do{if((c[A>>2]|0)==3){Ca=c[O>>2]|0;c[P>>2]=67372036;c[Q>>2]=67372036;c[T>>2]=67372036;c[S>>2]=67372036;do{if(R){if(U){c[aa>>2]=67372036;break}else{a[$]=a[Ca+E|0]|0;a[ba]=a[Ca+F|0]|0;break}}else{c[aa>>2]=-2139062144}}while(0);do{if(da){if(ea){a[fa]=4;break}else{a[fa]=a[Ca+((a[l]&254)+H)|0]|0;break}}else{a[fa]=-128}}while(0);if(!ga){a[ia]=-128;break}if(ha){a[ia]=4;break}else{a[ia]=a[Ca+((a[ka]&254)+ja)|0]|0;break}}}while(0);if((c[na>>2]|0)==0){break}}else{if((c[na>>2]|0)==0){break}}if((c[oa>>2]|0)==0){do{if(pa){Aa=f+5632+(wa*40|0)+3|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+14|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+7|0;a[Ea]=a[Ea]<<1}}while(0);do{if(qa){Ea=f+5632+(wa*40|0)+4|0;Aa=a[Ea]|0;if(Aa<<24>>24>-1){a[Ea]=Aa<<24>>24>>>1;Aa=f+5312+(wa*160|0)+18|0;b[Aa>>1]=b[Aa>>1]<<1;Aa=f+426592+(wa*80|0)+9|0;a[Aa]=a[Aa]<<1}Aa=f+5632+(wa*40|0)+5|0;Ea=a[Aa]|0;if(Ea<<24>>24>-1){a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+22|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+11|0;a[Ea]=a[Ea]<<1}Ea=a[Ba]|0;if(Ea<<24>>24>-1){a[Ba]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+26|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+13|0;a[Ea]=a[Ea]<<1}Ea=f+5632+(wa*40|0)+7|0;Aa=a[Ea]|0;if(!(Aa<<24>>24>-1)){break}a[Ea]=Aa<<24>>24>>>1;Aa=f+5312+(wa*160|0)+30|0;b[Aa>>1]=b[Aa>>1]<<1;Aa=f+426592+(wa*80|0)+15|0;a[Aa]=a[Aa]<<1}}while(0);do{if(!ra){Aa=f+5632+(wa*40|0)+8|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+34|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+17|0;a[Ea]=a[Ea]<<1}}while(0);do{if(!sa){Ea=f+5632+(wa*40|0)+11|0;Aa=a[Ea]|0;if(Aa<<24>>24>-1){a[Ea]=Aa<<24>>24>>>1;Aa=f+5312+(wa*160|0)+46|0;b[Aa>>1]=b[Aa>>1]<<1;Aa=f+426592+(wa*80|0)+23|0;a[Aa]=a[Aa]<<1;if(sa){break}}Aa=f+5632+(wa*40|0)+19|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+78|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+39|0;a[Ea]=a[Ea]<<1}}while(0);if(ta){break}Ea=f+5632+(wa*40|0)+27|0;Aa=a[Ea]|0;if(Aa<<24>>24>-1){a[Ea]=Aa<<24>>24>>>1;Aa=f+5312+(wa*160|0)+110|0;b[Aa>>1]=b[Aa>>1]<<1;Aa=f+426592+(wa*80|0)+55|0;a[Aa]=a[Aa]<<1;if(ta){break}}Aa=f+5632+(wa*40|0)+35|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<24>>24>>>1;Ea=f+5312+(wa*160|0)+142|0;b[Ea>>1]=b[Ea>>1]<<1;Ea=f+426592+(wa*80|0)+71|0;a[Ea]=a[Ea]<<1;break}else{do{if(!pa){Ea=f+5632+(wa*40|0)+3|0;Aa=a[Ea]|0;if(!(Aa<<24>>24>-1)){break}a[Ea]=Aa<<1;Aa=f+5312+(wa*160|0)+14|0;b[Aa>>1]=(b[Aa>>1]|0)/2|0;Aa=f+426592+(wa*80|0)+7|0;a[Aa]=(d[Aa]|0)>>>1}}while(0);do{if(!qa){Aa=f+5632+(wa*40|0)+4|0;Ea=a[Aa]|0;if(Ea<<24>>24>-1){a[Aa]=Ea<<1;Ea=f+5312+(wa*160|0)+18|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+9|0;a[Ea]=(d[Ea]|0)>>>1}Ea=f+5632+(wa*40|0)+5|0;Aa=a[Ea]|0;if(Aa<<24>>24>-1){a[Ea]=Aa<<1;Aa=f+5312+(wa*160|0)+22|0;b[Aa>>1]=(b[Aa>>1]|0)/2|0;Aa=f+426592+(wa*80|0)+11|0;a[Aa]=(d[Aa]|0)>>>1}Aa=a[Ba]|0;if(Aa<<24>>24>-1){a[Ba]=Aa<<1;Aa=f+5312+(wa*160|0)+26|0;b[Aa>>1]=(b[Aa>>1]|0)/2|0;Aa=f+426592+(wa*80|0)+13|0;a[Aa]=(d[Aa]|0)>>>1}Aa=f+5632+(wa*40|0)+7|0;Ea=a[Aa]|0;if(!(Ea<<24>>24>-1)){break}a[Aa]=Ea<<1;Ea=f+5312+(wa*160|0)+30|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+15|0;a[Ea]=(d[Ea]|0)>>>1}}while(0);do{if(ra){Ba=f+5632+(wa*40|0)+8|0;Ea=a[Ba]|0;if(!(Ea<<24>>24>-1)){break}a[Ba]=Ea<<1;Ea=f+5312+(wa*160|0)+34|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+17|0;a[Ea]=(d[Ea]|0)>>>1}}while(0);do{if(sa){Ea=f+5632+(wa*40|0)+11|0;Ba=a[Ea]|0;if(Ba<<24>>24>-1){a[Ea]=Ba<<1;Ba=f+5312+(wa*160|0)+46|0;b[Ba>>1]=(b[Ba>>1]|0)/2|0;Ba=f+426592+(wa*80|0)+23|0;a[Ba]=(d[Ba]|0)>>>1}Ba=f+5632+(wa*40|0)+19|0;Ea=a[Ba]|0;if(!(Ea<<24>>24>-1)){break}a[Ba]=Ea<<1;Ea=f+5312+(wa*160|0)+78|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+39|0;a[Ea]=(d[Ea]|0)>>>1}}while(0);if(!ta){break}Ea=f+5632+(wa*40|0)+27|0;Ba=a[Ea]|0;if(Ba<<24>>24>-1){a[Ea]=Ba<<1;Ba=f+5312+(wa*160|0)+110|0;b[Ba>>1]=(b[Ba>>1]|0)/2|0;Ba=f+426592+(wa*80|0)+55|0;a[Ba]=(d[Ba]|0)>>>1}Ba=f+5632+(wa*40|0)+35|0;Ea=a[Ba]|0;if(!(Ea<<24>>24>-1)){break}a[Ba]=Ea<<1;Ea=f+5312+(wa*160|0)+142|0;b[Ea>>1]=(b[Ea>>1]|0)/2|0;Ea=f+426592+(wa*80|0)+71|0;a[Ea]=(d[Ea]|0)>>>1;break}}}while(0);wa=wa+1|0;}while(wa>>>0<(c[L>>2]|0)>>>0);V=s>>>24;W=V&1;X=u>>>24;Y=X&1;Z=Y+W|0;_=f+5712|0;c[_>>2]=Z;i=h;return}function aia(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;h=a+425488|0;if((bia(h,b+2+(e-3>>31)+(e-33>>31)+(a+425536)|0)|0)==0){c[f>>2]=0;j=0;i=g;return j|0}do{if((bia(h,b+3+(a+425536)|0)|0)==0){k=1;l=17}else{if((bia(h,b+4+(a+425536)|0)|0)==0){k=2;l=17;break}if((bia(h,b+5+(a+425536)|0)|0)==0){k=3;l=17;break}e=b+6+(a+425536)|0;if((bia(h,e)|0)==0){k=4;l=17;break}if((bia(h,e)|0)==0){k=5;l=17;break}if((bia(h,e)|0)==0){k=6;l=17;break}if((bia(h,e)|0)==0){k=7;l=17;break}if((bia(h,e)|0)==0){k=8;l=17;break}e=h|0;m=a+425504|0;n=a+425492|0;o=3;p=9;q=c[e>>2]|0;while(1){r=q<<1;c[e>>2]=r;if((r&65534|0)==0){s=c[m>>2]|0;t=r-65535+((d[s+1|0]|0)<<1|(d[s]|0)<<9)|0;c[e>>2]=t;c[m>>2]=s+2;u=t}else{u=r}v=c[n>>2]<<17;if((u|0)<(v|0)){break}r=u-v|0;c[e>>2]=r;t=(1<<o)+p|0;s=o+1|0;if((s|0)>24){l=10;break}else{o=s;p=t;q=r}}if((l|0)==10){KIb(c[a>>2]|0,16,2363576,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-2147483648;i=g;return j|0}if((o|0)==0){w=p}else{q=p;n=o;r=u;while(1){t=n-1|0;s=r<<1;c[e>>2]=s;if((s&65534|0)==0){x=c[m>>2]|0;y=s-65535+((d[x+1|0]|0)<<1|(d[x]|0)<<9)|0;c[e>>2]=y;c[m>>2]=x+2;z=y}else{z=s}if((z|0)<(v|0)){A=0;B=z}else{s=z-v|0;c[e>>2]=s;A=1;B=s}s=(A<<t)+q|0;if((t|0)==0){w=s;break}else{q=s;n=t;r=B}}}C=w;D=(w|0)<70?w:70;E=e}}while(0);if((l|0)==17){C=k;D=k;E=h|0}c[f>>2]=D;D=c[E>>2]<<1;c[E>>2]=D;if((D&65534|0)==0){f=a+425504|0;h=c[f>>2]|0;k=D-65535+((d[h+1|0]|0)<<1|(d[h]|0)<<9)|0;c[E>>2]=k;c[f>>2]=h+2;F=k}else{F=D}D=c[a+425492>>2]<<17;a=F-D|0;F=a>>31;c[E>>2]=(F&D)+a;j=(F^-C)-F|0;i=g;return j|0}function bia(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[e]|0;g=b+4|0;h=c[g>>2]|0;i=d[1376824+((h<<1&384)+(f|512))|0]|0;j=h-i|0;h=j<<17;k=b|0;l=c[k>>2]|0;m=h-l>>31;c[k>>2]=l-(m&h);c[g>>2]=(m&i-j)+j;j=m^f;a[e]=a[j+1377976|0]|0;e=j&1;j=c[g>>2]|0;f=d[1376824+j|0]|0;c[g>>2]=j<<f;j=c[k>>2]<<f;c[k>>2]=j;if((j&65535|0)!=0){return e|0}f=b+16|0;b=c[f>>2]|0;c[k>>2]=(((d[b+1|0]|0)<<1|(d[b]|0)<<9)-65535<<7-(d[1376824+((j-1^j)>>15)|0]|0))+j;c[f>>2]=b+2;return e|0}function cia(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;m=i;i=i+256|0;n=m|0;o=f+425492|0;p=c[o>>2]|0;q=f+425488|0;r=c[q>>2]|0;s=f+425504|0;t=c[s>>2]|0;u=c[f+177092>>2]|0;v=c[1585440+(u*56|0)+(h<<2)>>2]|0;w=c[1585560+(u*56|0)+(h<<2)>>2]|0;u=c[1585704+(h<<2)>>2]|0;x=l-1|0;a:do{if((x|0)>0){l=t;y=p;z=r;A=0;B=0;while(1){C=B+v+(f+425536)|0;D=d[C]|0;E=d[1376824+((D|512)+(y<<1&384))|0]|0;F=y-E|0;G=F<<17;H=G-z>>31;I=(H&E-F)+F|0;F=H^D;a[C]=a[F+1377976|0]|0;C=d[1376824+I|0]|0;D=I<<C;I=z-(H&G)<<C;if((I&65535|0)==0){J=(((d[l+1|0]|0)<<1|(d[l]|0)<<9)-65535<<7-(d[1376824+((I-1^I)>>15)|0]|0))+I|0;K=l+2|0}else{J=I;K=l}if((F&1|0)==0){L=A;M=J;N=D;O=K}else{F=B+w+(f+425536)|0;I=A+1|0;c[n+(A<<2)>>2]=B;C=d[F]|0;G=d[1376824+((C|512)+(D<<1&384))|0]|0;H=D-G|0;D=H<<17;E=D-J>>31;P=(E&G-H)+H|0;H=E^C;a[F]=a[H+1377976|0]|0;F=d[1376824+P|0]|0;C=P<<F;P=J-(E&D)<<F;if((P&65535|0)==0){Q=(((d[K+1|0]|0)<<1|(d[K]|0)<<9)-65535<<7-(d[1376824+((P-1^P)>>15)|0]|0))+P|0;R=K+2|0}else{Q=P;R=K}if((H&1|0)==0){L=I;M=Q;N=C;O=R}else{S=I;T=Q;U=C;V=R;break a}}C=B+1|0;if((C|0)<(x|0)){l=O;y=N;z=M;A=L;B=C}else{W=O;X=N;Y=M;Z=L;_=C;$=9;break}}}else{W=t;X=p;Y=r;Z=0;_=0;$=9}}while(0);do{if(($|0)==9){if((_|0)!=(x|0)){S=Z;T=Y;U=X;V=W;break}c[n+(Z<<2)>>2]=x;S=Z+1|0;T=Y;U=X;V=W}}while(0);if((h|0)==3){h=(c[f+426560>>2]|0)+(c[f+427412>>2]<<1)|0;b[h>>1]=e[h>>1]|0|64<<j-49}else{h=(c[f+426560>>2]|0)+(c[f+427412>>2]<<1)|0;b[h>>1]=e[h>>1]|0|256<<j-48}a[(d[602272+j|0]|0)+(f+5184)|0]=S;if((c[f+4752>>2]|0)==0){j=S;h=0;W=T;X=U;Y=V;while(1){Z=(d[1585760+h|0]|0)+u+(f+425536)|0;x=j-1|0;_=d[k+(c[n+(x<<2)>>2]|0)|0]|0;r=d[Z]|0;p=d[1376824+((r|512)+(X<<1&384))|0]|0;t=X-p|0;L=t<<17;M=L-W>>31;N=(M&p-t)+t|0;t=M^r;a[Z]=a[t+1377976|0]|0;Z=d[1376824+N|0]|0;r=N<<Z;N=W-(M&L)<<Z;if((N&65535|0)==0){aa=(((d[Y+1|0]|0)<<1|(d[Y]|0)<<9)-65535<<7-(d[1376824+((N-1^N)>>15)|0]|0))+N|0;ba=Y+2|0}else{aa=N;ba=Y}if((t&1|0)==0){t=a[1585688+h|0]|0;N=aa<<1;if((N&65534|0)==0){ca=N-65535+((d[ba+1|0]|0)<<1|(d[ba]|0)<<9)|0;da=ba+2|0}else{ca=N;da=ba}N=r<<17;Z=ca-N|0;L=Z>>31;b[g+(_<<1)>>1]=(L^65535)-L;ea=t;fa=(L&N)+Z|0;ga=r;ha=da}else{Z=(d[1585672+h|0]|0)+u+(f+425536)|0;N=a[1585696+h|0]|0;L=2;t=aa;M=r;r=ba;while(1){if((L|0)>=15){ia=t;ja=r;ka=M;$=54;break}p=d[Z]|0;O=d[1376824+((p|512)+(M<<1&384))|0]|0;R=M-O|0;Q=R<<17;K=Q-t>>31;J=(K&O-R)+R|0;R=K^p;a[Z]=a[R+1377976|0]|0;p=d[1376824+J|0]|0;la=J<<p;J=t-(K&Q)<<p;if((J&65535|0)==0){ma=(((d[r+1|0]|0)<<1|(d[r]|0)<<9)-65535<<7-(d[1376824+((J-1^J)>>15)|0]|0))+J|0;na=r+2|0}else{ma=J;na=r}if((R&1|0)==0){$=53;break}else{L=L+1|0;t=ma;M=la;r=na}}if(($|0)==53){$=0;if((L|0)>14){ia=ma;ja=na;ka=la;$=54}else{oa=L;pa=ma;qa=na;ra=la}}do{if(($|0)==54){$=0;r=ka<<17;M=0;t=ia;Z=ja;while(1){R=t<<1;if((R&65534|0)==0){sa=R-65535+((d[Z+1|0]|0)<<1|(d[Z]|0)<<9)|0;ta=Z+2|0}else{sa=R;ta=Z}if((sa|0)<(r|0)){$=59;break}R=sa-r|0;if((M|0)<30){M=M+1|0;t=R;Z=ta}else{ua=ta;va=R;wa=1;xa=M;break}}if(($|0)==59){$=0;if((M|0)==0){oa=15;pa=sa;qa=ta;ra=ka;break}else{ua=ta;va=sa;wa=1;xa=M}}while(1){Z=xa-1|0;t=va<<1;if((t&65534|0)==0){ya=t-65535+((d[ua+1|0]|0)<<1|(d[ua]|0)<<9)|0;za=ua+2|0}else{ya=t;za=ua}t=(ya|0)<(r|0);Aa=ya-(t?0:r)|0;Ba=(t&1|wa<<1)^1;if((Z|0)==0){break}else{ua=za;va=Aa;wa=Ba;xa=Z}}oa=Ba+14|0;pa=Aa;qa=za;ra=ka}}while(0);L=pa<<1;if((L&65534|0)==0){Ca=L-65535+((d[qa+1|0]|0)<<1|(d[qa]|0)<<9)|0;Da=qa+2|0}else{Ca=L;Da=qa}L=ra<<17;r=Ca-L|0;M=r>>31;b[g+(_<<1)>>1]=(M^-oa)-M;ea=N;fa=(M&L)+r|0;ga=ra;ha=Da}if((x|0)==0){Ea=fa;Fa=ga;Ga=ha;break}else{j=x;h=ea&255;W=fa;X=ga;Y=ha}}c[o>>2]=Fa;c[q>>2]=Ea;c[s>>2]=Ga;i=m;return}ha=g;g=S;S=0;Y=T;T=U;U=V;while(1){V=(d[1585760+S|0]|0)+u+(f+425536)|0;ga=g-1|0;X=d[k+(c[n+(ga<<2)>>2]|0)|0]|0;fa=d[V]|0;W=d[1376824+((fa|512)+(T<<1&384))|0]|0;ea=T-W|0;h=ea<<17;j=h-Y>>31;Da=(j&W-ea)+ea|0;ea=j^fa;a[V]=a[ea+1377976|0]|0;V=d[1376824+Da|0]|0;fa=Da<<V;Da=Y-(j&h)<<V;if((Da&65535|0)==0){Ha=(((d[U+1|0]|0)<<1|(d[U]|0)<<9)-65535<<7-(d[1376824+((Da-1^Da)>>15)|0]|0))+Da|0;Ia=U+2|0}else{Ha=Da;Ia=U}if((ea&1|0)==0){ea=a[1585688+S|0]|0;Da=Ha<<1;if((Da&65534|0)==0){Ja=Da-65535+((d[Ia+1|0]|0)<<1|(d[Ia]|0)<<9)|0;Ka=Ia+2|0}else{Ja=Da;Ka=Ia}Da=fa<<17;V=Ja-Da|0;h=V>>31;c[ha+(X<<2)>>2]=~h-h;La=ea;Ma=(h&Da)+V|0;Na=fa;Oa=Ka}else{V=(d[1585672+S|0]|0)+u+(f+425536)|0;Da=a[1585696+S|0]|0;h=2;ea=Ha;j=fa;fa=Ia;while(1){if((h|0)>=15){Pa=ea;Qa=fa;Ra=j;$=28;break}W=d[V]|0;ra=d[1376824+((W|512)+(j<<1&384))|0]|0;oa=j-ra|0;Ca=oa<<17;qa=Ca-ea>>31;pa=(qa&ra-oa)+oa|0;oa=qa^W;a[V]=a[oa+1377976|0]|0;W=d[1376824+pa|0]|0;Sa=pa<<W;pa=ea-(qa&Ca)<<W;if((pa&65535|0)==0){Ta=(((d[fa+1|0]|0)<<1|(d[fa]|0)<<9)-65535<<7-(d[1376824+((pa-1^pa)>>15)|0]|0))+pa|0;Ua=fa+2|0}else{Ta=pa;Ua=fa}if((oa&1|0)==0){$=27;break}else{h=h+1|0;ea=Ta;j=Sa;fa=Ua}}if(($|0)==27){$=0;if((h|0)>14){Pa=Ta;Qa=Ua;Ra=Sa;$=28}else{Va=h;Wa=Ta;Xa=Ua;Ya=Sa}}do{if(($|0)==28){$=0;fa=Ra<<17;j=0;ea=Pa;V=Qa;while(1){x=ea<<1;if((x&65534|0)==0){Za=x-65535+((d[V+1|0]|0)<<1|(d[V]|0)<<9)|0;_a=V+2|0}else{Za=x;_a=V}if((Za|0)<(fa|0)){$=33;break}x=Za-fa|0;if((j|0)<30){j=j+1|0;ea=x;V=_a}else{$a=_a;ab=x;bb=1;cb=j;break}}if(($|0)==33){$=0;if((j|0)==0){Va=15;Wa=Za;Xa=_a;Ya=Ra;break}else{$a=_a;ab=Za;bb=1;cb=j}}while(1){V=cb-1|0;ea=ab<<1;if((ea&65534|0)==0){db=ea-65535+((d[$a+1|0]|0)<<1|(d[$a]|0)<<9)|0;eb=$a+2|0}else{db=ea;eb=$a}ea=(db|0)<(fa|0);fb=db-(ea?0:fa)|0;gb=(ea&1|bb<<1)^1;if((V|0)==0){break}else{$a=eb;ab=fb;bb=gb;cb=V}}Va=gb+14|0;Wa=fb;Xa=eb;Ya=Ra}}while(0);h=Wa<<1;if((h&65534|0)==0){hb=h-65535+((d[Xa+1|0]|0)<<1|(d[Xa]|0)<<9)|0;ib=Xa+2|0}else{hb=h;ib=Xa}h=Ya<<17;fa=hb-h|0;j=fa>>31;c[ha+(X<<2)>>2]=(j^-Va)-j;La=Da;Ma=(j&h)+fa|0;Na=Ya;Oa=ib}if((ga|0)==0){Ea=Ma;Fa=Na;Ga=Oa;break}else{g=ga;S=La&255;Y=Ma;T=Na;U=Oa}}c[o>>2]=Fa;c[q>>2]=Ea;c[s>>2]=Ga;i=m;return}function dia(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0;m=i;i=i+256|0;n=m|0;o=e+425492|0;p=c[o>>2]|0;q=e+425488|0;r=c[q>>2]|0;s=e+425504|0;t=c[s>>2]|0;u=c[e+177092>>2]|0;v=c[1585440+(u*56|0)+(g<<2)>>2]|0;w=c[1585560+(u*56|0)+(g<<2)>>2]|0;x=c[1585704+(g<<2)>>2]|0;g=(l|0)==64;a:do{if(g){y=t;z=p;A=r;B=0;C=0;while(1){D=(d[1585312+(u*63|0)+C|0]|0)+v+(e+425536)|0;E=d[D]|0;F=d[1376824+((E|512)+(z<<1&384))|0]|0;G=z-F|0;H=G<<17;I=H-A>>31;J=(I&F-G)+G|0;G=I^E;a[D]=a[G+1377976|0]|0;D=d[1376824+J|0]|0;E=J<<D;J=A-(I&H)<<D;if((J&65535|0)==0){K=(((d[y+1|0]|0)<<1|(d[y]|0)<<9)-65535<<7-(d[1376824+((J-1^J)>>15)|0]|0))+J|0;L=y+2|0}else{K=J;L=y}if((G&1|0)==0){M=B;N=K;O=E;P=L}else{G=(d[C+1378104|0]|0)+w+(e+425536)|0;J=B+1|0;c[n+(B<<2)>>2]=C;D=d[G]|0;H=d[1376824+((D|512)+(E<<1&384))|0]|0;I=E-H|0;E=I<<17;F=E-K>>31;Q=(F&H-I)+I|0;I=F^D;a[G]=a[I+1377976|0]|0;G=d[1376824+Q|0]|0;D=Q<<G;Q=K-(F&E)<<G;if((Q&65535|0)==0){R=(((d[L+1|0]|0)<<1|(d[L]|0)<<9)-65535<<7-(d[1376824+((Q-1^Q)>>15)|0]|0))+Q|0;S=L+2|0}else{R=Q;S=L}if((I&1|0)==0){M=J;N=R;O=D;P=S}else{T=J;U=R;V=D;W=S;break a}}X=C+1|0;if((X|0)<63){y=P;z=O;A=N;B=M;C=X}else{break}}if((X|0)!=63){T=M;U=N;V=O;W=P;break}c[n+(M<<2)>>2]=63;T=M+1|0;U=N;V=O;W=P}else{C=l-1|0;if((C|0)>0){B=t;A=p;z=r;y=0;D=0;while(1){J=D+v+(e+425536)|0;I=d[J]|0;Q=d[1376824+((I|512)+(A<<1&384))|0]|0;G=A-Q|0;E=G<<17;F=E-z>>31;H=(F&Q-G)+G|0;G=F^I;a[J]=a[G+1377976|0]|0;J=d[1376824+H|0]|0;I=H<<J;H=z-(F&E)<<J;if((H&65535|0)==0){Y=(((d[B+1|0]|0)<<1|(d[B]|0)<<9)-65535<<7-(d[1376824+((H-1^H)>>15)|0]|0))+H|0;Z=B+2|0}else{Y=H;Z=B}if((G&1|0)==0){_=y;$=Y;aa=I;ba=Z}else{G=D+w+(e+425536)|0;H=y+1|0;c[n+(y<<2)>>2]=D;J=d[G]|0;E=d[1376824+((J|512)+(I<<1&384))|0]|0;F=I-E|0;I=F<<17;Q=I-Y>>31;da=(Q&E-F)+F|0;F=Q^J;a[G]=a[F+1377976|0]|0;G=d[1376824+da|0]|0;J=da<<G;da=Y-(Q&I)<<G;if((da&65535|0)==0){ea=(((d[Z+1|0]|0)<<1|(d[Z]|0)<<9)-65535<<7-(d[1376824+((da-1^da)>>15)|0]|0))+da|0;fa=Z+2|0}else{ea=da;fa=Z}if((F&1|0)==0){_=H;$=ea;aa=J;ba=fa}else{T=H;U=ea;V=J;W=fa;break a}}J=D+1|0;if((J|0)<(C|0)){B=ba;A=aa;z=$;y=_;D=J}else{ga=ba;ha=aa;ia=$;ja=_;ka=J;break}}}else{ga=t;ha=p;ia=r;ja=0;ka=0}if((ka|0)!=(C|0)){T=ja;U=ia;V=ha;W=ga;break}c[n+(ja<<2)>>2]=C;T=ja+1|0;U=ia;V=ha;W=ga}}while(0);if(g){g=d[602272+h|0]|0;ga=(T*257|0)&65535;b[e+5184+g>>1]=ga;b[g+8+(e+5184)>>1]=ga}else{a[(d[602272+h|0]|0)+(e+5184)|0]=T}if((c[e+4752>>2]|0)==0){h=T;ga=0;g=U;ha=V;ia=W;while(1){ja=(d[1585760+ga|0]|0)+x+(e+425536)|0;ka=h-1|0;r=d[j+(c[n+(ka<<2)>>2]|0)|0]|0;p=d[ja]|0;t=d[1376824+((p|512)+(ha<<1&384))|0]|0;_=ha-t|0;$=_<<17;aa=$-g>>31;ba=(aa&t-_)+_|0;_=aa^p;a[ja]=a[_+1377976|0]|0;ja=d[1376824+ba|0]|0;p=ba<<ja;ba=g-(aa&$)<<ja;if((ba&65535|0)==0){la=(((d[ia+1|0]|0)<<1|(d[ia]|0)<<9)-65535<<7-(d[1376824+((ba-1^ba)>>15)|0]|0))+ba|0;ma=ia+2|0}else{la=ba;ma=ia}if((_&1|0)==0){_=a[1585688+ga|0]|0;ba=la<<1;if((ba&65534|0)==0){na=ba-65535+((d[ma+1|0]|0)<<1|(d[ma]|0)<<9)|0;oa=ma+2|0}else{na=ba;oa=ma}ba=p<<17;ja=na-ba|0;$=ja>>31;b[f+(r<<1)>>1]=((ja>>>31|32)+($^-(c[k+(r<<2)>>2]|0))|0)>>>6;pa=_;qa=($&ba)+ja|0;ra=p;sa=oa}else{ja=(d[1585672+ga|0]|0)+x+(e+425536)|0;ba=a[1585696+ga|0]|0;$=2;_=la;aa=p;p=ma;while(1){if(($|0)>=15){ta=_;ua=p;va=aa;wa=64;break}t=d[ja]|0;fa=d[1376824+((t|512)+(aa<<1&384))|0]|0;ea=aa-fa|0;Z=ea<<17;Y=Z-_>>31;w=(Y&fa-ea)+ea|0;ea=Y^t;a[ja]=a[ea+1377976|0]|0;t=d[1376824+w|0]|0;xa=w<<t;w=_-(Y&Z)<<t;if((w&65535|0)==0){ya=(((d[p+1|0]|0)<<1|(d[p]|0)<<9)-65535<<7-(d[1376824+((w-1^w)>>15)|0]|0))+w|0;za=p+2|0}else{ya=w;za=p}if((ea&1|0)==0){wa=63;break}else{$=$+1|0;_=ya;aa=xa;p=za}}if((wa|0)==63){wa=0;if(($|0)>14){ta=ya;ua=za;va=xa;wa=64}else{Aa=$;Ba=ya;Ca=za;Da=xa}}do{if((wa|0)==64){wa=0;p=va<<17;aa=0;_=ta;ja=ua;while(1){C=_<<1;if((C&65534|0)==0){Ea=C-65535+((d[ja+1|0]|0)<<1|(d[ja]|0)<<9)|0;Fa=ja+2|0}else{Ea=C;Fa=ja}if((Ea|0)<(p|0)){wa=69;break}C=Ea-p|0;if((aa|0)<30){aa=aa+1|0;_=C;ja=Fa}else{Ga=Fa;Ha=C;Ia=1;Ja=aa;break}}if((wa|0)==69){wa=0;if((aa|0)==0){Aa=15;Ba=Ea;Ca=Fa;Da=va;break}else{Ga=Fa;Ha=Ea;Ia=1;Ja=aa}}while(1){ja=Ja-1|0;_=Ha<<1;if((_&65534|0)==0){Ka=_-65535+((d[Ga+1|0]|0)<<1|(d[Ga]|0)<<9)|0;La=Ga+2|0}else{Ka=_;La=Ga}_=(Ka|0)<(p|0);Ma=Ka-(_?0:p)|0;Na=(_&1|Ia<<1)^1;if((ja|0)==0){break}else{Ga=La;Ha=Ma;Ia=Na;Ja=ja}}Aa=Na+14|0;Ba=Ma;Ca=La;Da=va}}while(0);$=Ba<<1;if(($&65534|0)==0){Oa=$-65535+((d[Ca+1|0]|0)<<1|(d[Ca]|0)<<9)|0;Pa=Ca+2|0}else{Oa=$;Pa=Ca}$=Da<<17;p=Oa-$|0;aa=p>>31;b[f+(r<<1)>>1]=((ca((aa^-Aa)-aa|0,c[k+(r<<2)>>2]|0)|0)+32|0)>>>6;pa=ba;qa=(aa&$)+p|0;ra=Da;sa=Pa}if((ka|0)==0){Qa=qa;Ra=ra;Sa=sa;break}else{h=ka;ga=pa&255;g=qa;ha=ra;ia=sa}}c[o>>2]=Ra;c[q>>2]=Qa;c[s>>2]=Sa;i=m;return}sa=f;f=T;T=0;ia=U;U=V;V=W;while(1){W=(d[1585760+T|0]|0)+x+(e+425536)|0;ra=f-1|0;ha=d[j+(c[n+(ra<<2)>>2]|0)|0]|0;qa=d[W]|0;g=d[1376824+((qa|512)+(U<<1&384))|0]|0;pa=U-g|0;ga=pa<<17;h=ga-ia>>31;Pa=(h&g-pa)+pa|0;pa=h^qa;a[W]=a[pa+1377976|0]|0;W=d[1376824+Pa|0]|0;qa=Pa<<W;Pa=ia-(h&ga)<<W;if((Pa&65535|0)==0){Ta=(((d[V+1|0]|0)<<1|(d[V]|0)<<9)-65535<<7-(d[1376824+((Pa-1^Pa)>>15)|0]|0))+Pa|0;Ua=V+2|0}else{Ta=Pa;Ua=V}if((pa&1|0)==0){pa=a[1585688+T|0]|0;Pa=Ta<<1;if((Pa&65534|0)==0){Va=Pa-65535+((d[Ua+1|0]|0)<<1|(d[Ua]|0)<<9)|0;Wa=Ua+2|0}else{Va=Pa;Wa=Ua}Pa=qa<<17;W=Va-Pa|0;ga=W>>31;c[sa+(ha<<2)>>2]=(W>>>31|32)+(ga^-(c[k+(ha<<2)>>2]|0))>>6;Xa=pa;Ya=(ga&Pa)+W|0;Za=qa;_a=Wa}else{W=(d[1585672+T|0]|0)+x+(e+425536)|0;Pa=a[1585696+T|0]|0;ga=2;pa=Ta;h=qa;qa=Ua;while(1){if((ga|0)>=15){$a=pa;ab=qa;bb=h;wa=38;break}g=d[W]|0;Da=d[1376824+((g|512)+(h<<1&384))|0]|0;Aa=h-Da|0;Oa=Aa<<17;Ca=Oa-pa>>31;Ba=(Ca&Da-Aa)+Aa|0;Aa=Ca^g;a[W]=a[Aa+1377976|0]|0;g=d[1376824+Ba|0]|0;cb=Ba<<g;Ba=pa-(Ca&Oa)<<g;if((Ba&65535|0)==0){db=(((d[qa+1|0]|0)<<1|(d[qa]|0)<<9)-65535<<7-(d[1376824+((Ba-1^Ba)>>15)|0]|0))+Ba|0;eb=qa+2|0}else{db=Ba;eb=qa}if((Aa&1|0)==0){wa=37;break}else{ga=ga+1|0;pa=db;h=cb;qa=eb}}if((wa|0)==37){wa=0;if((ga|0)>14){$a=db;ab=eb;bb=cb;wa=38}else{fb=ga;gb=db;hb=eb;ib=cb}}do{if((wa|0)==38){wa=0;qa=bb<<17;h=0;pa=$a;W=ab;while(1){ka=pa<<1;if((ka&65534|0)==0){jb=ka-65535+((d[W+1|0]|0)<<1|(d[W]|0)<<9)|0;kb=W+2|0}else{jb=ka;kb=W}if((jb|0)<(qa|0)){wa=43;break}ka=jb-qa|0;if((h|0)<30){h=h+1|0;pa=ka;W=kb}else{lb=kb;mb=ka;nb=1;ob=h;break}}if((wa|0)==43){wa=0;if((h|0)==0){fb=15;gb=jb;hb=kb;ib=bb;break}else{lb=kb;mb=jb;nb=1;ob=h}}while(1){W=ob-1|0;pa=mb<<1;if((pa&65534|0)==0){pb=pa-65535+((d[lb+1|0]|0)<<1|(d[lb]|0)<<9)|0;qb=lb+2|0}else{pb=pa;qb=lb}pa=(pb|0)<(qa|0);rb=pb-(pa?0:qa)|0;sb=(pa&1|nb<<1)^1;if((W|0)==0){break}else{lb=qb;mb=rb;nb=sb;ob=W}}fb=sb+14|0;gb=rb;hb=qb;ib=bb}}while(0);ga=gb<<1;if((ga&65534|0)==0){tb=ga-65535+((d[hb+1|0]|0)<<1|(d[hb]|0)<<9)|0;ub=hb+2|0}else{tb=ga;ub=hb}ga=ib<<17;qa=tb-ga|0;h=qa>>31;c[sa+(ha<<2)>>2]=(ca((h^-fb)-h|0,c[k+(ha<<2)>>2]|0)|0)+32>>6;Xa=Pa;Ya=(h&ga)+qa|0;Za=ib;_a=ub}if((ra|0)==0){Qa=Ya;Ra=Za;Sa=_a;break}else{f=ra;T=Xa&255;ia=Ya;U=Za;V=_a}}c[o>>2]=Ra;c[q>>2]=Qa;c[s>>2]=Sa;i=m;return}function eia(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;j=i;i=i+256|0;k=j|0;l=f+425492|0;m=f+425488|0;n=f+425504|0;o=c[f+177092>>2]|0;p=c[1585452+(o*56|0)>>2]|0;q=c[1585572+(o*56|0)>>2]|0;o=c[n>>2]|0;r=c[l>>2]|0;s=c[m>>2]|0;t=0;u=0;while(1){v=d[1585552+u|0]|0;w=v+p+(f+425536)|0;x=d[w]|0;y=d[1376824+((x|512)+(r<<1&384))|0]|0;z=r-y|0;A=z<<17;B=A-s>>31;C=(B&y-z)+z|0;z=B^x;a[w]=a[z+1377976|0]|0;w=d[1376824+C|0]|0;x=C<<w;C=s-(B&A)<<w;if((C&65535|0)==0){D=(((d[o+1|0]|0)<<1|(d[o]|0)<<9)-65535<<7-(d[1376824+((C-1^C)>>15)|0]|0))+C|0;E=o+2|0}else{D=C;E=o}if((z&1|0)==0){F=t;G=D;H=x;I=E}else{z=v+q+(f+425536)|0;v=t+1|0;c[k+(t<<2)>>2]=u;C=d[z]|0;w=d[1376824+((C|512)+(x<<1&384))|0]|0;A=x-w|0;x=A<<17;B=x-D>>31;y=(B&w-A)+A|0;A=B^C;a[z]=a[A+1377976|0]|0;z=d[1376824+y|0]|0;C=y<<z;y=D-(B&x)<<z;if((y&65535|0)==0){J=(((d[E+1|0]|0)<<1|(d[E]|0)<<9)-65535<<7-(d[1376824+((y-1^y)>>15)|0]|0))+y|0;K=E+2|0}else{J=y;K=E}if((A&1|0)==0){F=v;G=J;H=C;I=K}else{L=v;M=J;N=C;O=K;break}}P=u+1|0;if((P|0)<7){o=I;r=H;s=G;t=F;u=P}else{Q=9;break}}do{if((Q|0)==9){if((P|0)!=7){L=F;M=G;N=H;O=I;break}c[k+(F<<2)>>2]=7;L=F+1|0;M=G;N=H;O=I}}while(0);I=(c[f+426560>>2]|0)+(c[f+427412>>2]<<1)|0;b[I>>1]=e[I>>1]|0|64<<h-49;a[(d[602272+h|0]|0)+(f+5184)|0]=L;if((c[f+4752>>2]|0)==0){h=L;I=0;H=M;G=N;F=O;while(1){P=(d[1585760+I|0]|0)+257+(f+425536)|0;u=h-1|0;t=d[1706568+(c[k+(u<<2)>>2]|0)|0]|0;s=d[P]|0;r=d[1376824+((s|512)+(G<<1&384))|0]|0;o=G-r|0;K=o<<17;J=K-H>>31;E=(J&r-o)+o|0;o=J^s;a[P]=a[o+1377976|0]|0;P=d[1376824+E|0]|0;s=E<<P;E=H-(J&K)<<P;if((E&65535|0)==0){R=(((d[F+1|0]|0)<<1|(d[F]|0)<<9)-65535<<7-(d[1376824+((E-1^E)>>15)|0]|0))+E|0;S=F+2|0}else{R=E;S=F}if((o&1|0)==0){o=a[1585688+I|0]|0;E=R<<1;if((E&65534|0)==0){T=E-65535+((d[S+1|0]|0)<<1|(d[S]|0)<<9)|0;U=S+2|0}else{T=E;U=S}E=s<<17;P=T-E|0;K=P>>31;b[g+(t<<1)>>1]=(K^65535)-K;V=o;W=(K&E)+P|0;X=s;Y=U}else{P=(d[1585680+I|0]|0)+257+(f+425536)|0;E=a[1585696+I|0]|0;K=2;o=R;J=s;s=S;while(1){if((K|0)>=15){Z=o;_=s;$=J;Q=51;break}r=d[P]|0;D=d[1376824+((r|512)+(J<<1&384))|0]|0;q=J-D|0;p=q<<17;C=p-o>>31;v=(C&D-q)+q|0;q=C^r;a[P]=a[q+1377976|0]|0;r=d[1376824+v|0]|0;aa=v<<r;v=o-(C&p)<<r;if((v&65535|0)==0){ba=(((d[s+1|0]|0)<<1|(d[s]|0)<<9)-65535<<7-(d[1376824+((v-1^v)>>15)|0]|0))+v|0;ca=s+2|0}else{ba=v;ca=s}if((q&1|0)==0){Q=50;break}else{K=K+1|0;o=ba;J=aa;s=ca}}if((Q|0)==50){Q=0;if((K|0)>14){Z=ba;_=ca;$=aa;Q=51}else{da=K;ea=ba;fa=ca;ga=aa}}do{if((Q|0)==51){Q=0;s=$<<17;J=0;o=Z;P=_;while(1){q=o<<1;if((q&65534|0)==0){ha=q-65535+((d[P+1|0]|0)<<1|(d[P]|0)<<9)|0;ia=P+2|0}else{ha=q;ia=P}if((ha|0)<(s|0)){Q=56;break}q=ha-s|0;if((J|0)<30){J=J+1|0;o=q;P=ia}else{ja=ia;ka=q;la=1;ma=J;break}}if((Q|0)==56){Q=0;if((J|0)==0){da=15;ea=ha;fa=ia;ga=$;break}else{ja=ia;ka=ha;la=1;ma=J}}while(1){P=ma-1|0;o=ka<<1;if((o&65534|0)==0){na=o-65535+((d[ja+1|0]|0)<<1|(d[ja]|0)<<9)|0;oa=ja+2|0}else{na=o;oa=ja}o=(na|0)<(s|0);pa=na-(o?0:s)|0;qa=(o&1|la<<1)^1;if((P|0)==0){break}else{ja=oa;ka=pa;la=qa;ma=P}}da=qa+14|0;ea=pa;fa=oa;ga=$}}while(0);K=ea<<1;if((K&65534|0)==0){ra=K-65535+((d[fa+1|0]|0)<<1|(d[fa]|0)<<9)|0;sa=fa+2|0}else{ra=K;sa=fa}K=ga<<17;s=ra-K|0;J=s>>31;b[g+(t<<1)>>1]=(J^-da)-J;V=E;W=(J&K)+s|0;X=ga;Y=sa}if((u|0)==0){ta=W;ua=X;va=Y;break}else{h=u;I=V&255;H=W;G=X;F=Y}}c[l>>2]=ua;c[m>>2]=ta;c[n>>2]=va;i=j;return}Y=g;g=L;L=0;F=M;M=N;N=O;while(1){O=(d[1585760+L|0]|0)+257+(f+425536)|0;X=g-1|0;G=d[1706568+(c[k+(X<<2)>>2]|0)|0]|0;W=d[O]|0;H=d[1376824+((W|512)+(M<<1&384))|0]|0;V=M-H|0;I=V<<17;h=I-F>>31;sa=(h&H-V)+V|0;V=h^W;a[O]=a[V+1377976|0]|0;O=d[1376824+sa|0]|0;W=sa<<O;sa=F-(h&I)<<O;if((sa&65535|0)==0){wa=(((d[N+1|0]|0)<<1|(d[N]|0)<<9)-65535<<7-(d[1376824+((sa-1^sa)>>15)|0]|0))+sa|0;xa=N+2|0}else{wa=sa;xa=N}if((V&1|0)==0){V=a[1585688+L|0]|0;sa=wa<<1;if((sa&65534|0)==0){ya=sa-65535+((d[xa+1|0]|0)<<1|(d[xa]|0)<<9)|0;za=xa+2|0}else{ya=sa;za=xa}sa=W<<17;O=ya-sa|0;I=O>>31;c[Y+(G<<2)>>2]=~I-I;Aa=V;Ba=(I&sa)+O|0;Ca=W;Da=za}else{O=(d[1585680+L|0]|0)+257+(f+425536)|0;sa=a[1585696+L|0]|0;I=2;V=wa;h=W;W=xa;while(1){if((I|0)>=15){Ea=V;Fa=W;Ga=h;Q=25;break}H=d[O]|0;ga=d[1376824+((H|512)+(h<<1&384))|0]|0;da=h-ga|0;ra=da<<17;fa=ra-V>>31;ea=(fa&ga-da)+da|0;da=fa^H;a[O]=a[da+1377976|0]|0;H=d[1376824+ea|0]|0;Ha=ea<<H;ea=V-(fa&ra)<<H;if((ea&65535|0)==0){Ia=(((d[W+1|0]|0)<<1|(d[W]|0)<<9)-65535<<7-(d[1376824+((ea-1^ea)>>15)|0]|0))+ea|0;Ja=W+2|0}else{Ia=ea;Ja=W}if((da&1|0)==0){Q=24;break}else{I=I+1|0;V=Ia;h=Ha;W=Ja}}if((Q|0)==24){Q=0;if((I|0)>14){Ea=Ia;Fa=Ja;Ga=Ha;Q=25}else{Ka=I;La=Ia;Ma=Ja;Na=Ha}}do{if((Q|0)==25){Q=0;W=Ga<<17;h=0;V=Ea;O=Fa;while(1){u=V<<1;if((u&65534|0)==0){Oa=u-65535+((d[O+1|0]|0)<<1|(d[O]|0)<<9)|0;Pa=O+2|0}else{Oa=u;Pa=O}if((Oa|0)<(W|0)){Q=30;break}u=Oa-W|0;if((h|0)<30){h=h+1|0;V=u;O=Pa}else{Qa=Pa;Ra=u;Sa=1;Ta=h;break}}if((Q|0)==30){Q=0;if((h|0)==0){Ka=15;La=Oa;Ma=Pa;Na=Ga;break}else{Qa=Pa;Ra=Oa;Sa=1;Ta=h}}while(1){O=Ta-1|0;V=Ra<<1;if((V&65534|0)==0){Ua=V-65535+((d[Qa+1|0]|0)<<1|(d[Qa]|0)<<9)|0;Va=Qa+2|0}else{Ua=V;Va=Qa}V=(Ua|0)<(W|0);Wa=Ua-(V?0:W)|0;Xa=(V&1|Sa<<1)^1;if((O|0)==0){break}else{Qa=Va;Ra=Wa;Sa=Xa;Ta=O}}Ka=Xa+14|0;La=Wa;Ma=Va;Na=Ga}}while(0);I=La<<1;if((I&65534|0)==0){Ya=I-65535+((d[Ma+1|0]|0)<<1|(d[Ma]|0)<<9)|0;Za=Ma+2|0}else{Ya=I;Za=Ma}I=Na<<17;W=Ya-I|0;h=W>>31;c[Y+(G<<2)>>2]=(h^-Ka)-h;Aa=sa;Ba=(h&I)+W|0;Ca=Na;Da=Za}if((X|0)==0){ta=Ba;ua=Ca;va=Da;break}else{g=X;L=Aa&255;F=Ba;M=Ca;N=Da}}c[l>>2]=ua;c[m>>2]=ta;c[n>>2]=va;i=j;return}function fia(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(a[1376152]|0){return}a[1376152]=1;c[2450359]=9800408;c[2450361]=256;$2(9801432,8,20,1706368,1,1,1706392,1,1,0,0,0,4)|0;c[2458817]=9802496;c[2458819]=8192;$2(9835264,13,36,1706576,1,1,1706616,1,1,0,0,0,4)|0;c[2450021]=9794528;c[2450023]=520;$2(9800080,8,68,1645216,1,1,1645488,1,1,0,0,0,4)|0;c[2450026]=9796608;c[2450028]=332;$2(9800100,8,68,1645284,1,1,1645556,1,1,0,0,0,4)|0;c[2450031]=9797936;c[2450033]=280;$2(9800120,8,68,1645352,1,1,1645624,1,1,0,0,0,4)|0;c[2450036]=9799056;c[2450038]=256;$2(9800140,8,68,1645420,1,1,1645692,1,1,0,0,0,4)|0;c[2450087]=9800248;c[2450089]=8;$2(9800344,3,4,1706312,1,1,1706328,1,1,0,0,0,4)|0;c[2450092]=9800280;c[2450094]=8;$2(9800364,3,4,1706316,1,1,1706332,1,1,0,0,0,4)|0;c[2450097]=9800312;c[2450099]=8;$2(9800384,3,4,1706320,1,1,1706336,1,1,0,0,0,4)|0;b=0;while(1){c[9802356+(b*20|0)>>2]=9801456+(b<<7);c[9802364+(b*20|0)>>2]=32;$2(9802352+(b*20|0)|0,5,8,1706448+(b<<3)|0,1,1,1706504+(b<<3)|0,1,1,0,0,0,4)|0;e=b+1|0;if((e|0)<7){b=e}else{f=0;break}}do{c[3660924+(f*20|0)>>2]=3630200+(f<<11);c[3660932+(f*20|0)>>2]=512;$2(3660920+(f*20|0)|0,9,16,306928+(f<<4)|0,1,1,307184+(f<<4)|0,1,1,0,0,0,4)|0;f=f+1|0;}while((f|0)<15);c[1339211]=5356648;c[1339213]=8;$2(5356840,3,7,676432,1,1,676544,1,1,0,0,0,4)|0;c[1339216]=5356680;c[1339218]=8;$2(5356860,3,7,676448,1,1,676560,1,1,0,0,0,4)|0;c[1339221]=5356712;c[1339223]=8;$2(5356880,3,7,676464,1,1,676576,1,1,0,0,0,4)|0;c[1339226]=5356744;c[1339228]=8;$2(5356900,3,7,676480,1,1,676592,1,1,0,0,0,4)|0;c[1339231]=5356776;c[1339233]=8;$2(5356920,3,7,676496,1,1,676608,1,1,0,0,0,4)|0;c[1339236]=5356808;c[1339238]=8;$2(5356940,3,7,676512,1,1,676624,1,1,0,0,0,4)|0;c[1339337]=5356960;c[1339339]=96;$2(5357344,6,16,676528,1,1,676640,1,1,0,0,0,4)|0;f=0;do{b=-1<<f;e=0;do{g=e<<1;if((g&65280|0)==0){h=0;i=g}else{h=8;i=e>>>7&16777215}g=8-h-(d[1359664+i|0]|0)|0;j=g+1|0;k=j+f|0;do{if((k|0)<9){l=(e&65280|0)==0;m=(g<<f)+b+(e>>>(((l?0:8)-f+(d[1359664+(l?e:e>>>8)|0]|0)|0)>>>0))|0;l=m&1;a[9877400+(f<<9)+(e<<1)|0]=((m+2|0)>>>1^-l)+l;a[9877400+(f<<9)+(e<<1)+1|0]=k}else{if((j|0)<9){a[9877400+(f<<9)+(e<<1)|0]=g+100;a[9877400+(f<<9)+(e<<1)+1|0]=j;break}else{a[9877400+(f<<9)+(e<<1)|0]=108;a[9877400+(f<<9)+(e<<1)+1|0]=8;break}}}while(0);e=e+1|0;}while(e>>>0<256>>>0);f=f+1|0;}while((f|0)<7);return}function gia(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0;g=i;i=i+88|0;h=g|0;j=g+16|0;k=g+24|0;l=g+32|0;m=g+40|0;n=g+56|0;o=c[f+7392>>2]|0;p=f+6136|0;q=c[p>>2]|0;r=(q-1|0)>>>0<2>>>0;s=c[f+4752>>2]|0;t=f+427376|0;u=f+427380|0;v=c[u>>2]|0;w=f+427404|0;x=(ca(c[w>>2]|0,v)|0)+(c[t>>2]|0)|0;y=f+427412|0;c[y>>2]=x;z=f+177080|0;A=c[z>>2]|0;do{if((A|0)!=1){B=f+427392|0;C=c[B>>2]|0;if((C|0)==-1){D=c[f+1088>>2]|0;E=f+1096|0;F=c[E>>2]|0;G=D+(F>>>3)|0;H=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(F&7);G=F+16|0;I=D+(G>>>3)|0;J=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(G&7)>>>16|H&-65536;G=J>>>0>65535>>>0;I=G?H>>>16:J;J=G?16:0;if((I&65280|0)==0){K=J;L=I}else{K=J|8;L=I>>>8}I=(d[1359664+L|0]|0)+K|0;J=31-I|0;G=J+F|0;c[E>>2]=G;F=J+1|0;do{if((F|0)==0){M=0}else{H=D+(G>>>3)|0;N=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7);if((F|0)<26){c[E>>2]=G+F;M=N>>>(I>>>0);break}else{H=G+16|0;c[E>>2]=H;O=D+(H>>>3)|0;P=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(H&7)>>>((47-J|0)>>>0);c[E>>2]=G+F;M=P|N>>>16<<J-15;break}}}while(0);J=M-1|0;c[B>>2]=J;Q=J}else{Q=C}J=Q-1|0;c[B>>2]=J;if((Q|0)==0){break}F=f+177088|0;do{if((c[F>>2]|0)!=0){if((v&1|J|0)!=0){break}G=f+1096|0;E=c[G>>2]|0;D=d[(c[f+1088>>2]|0)+(E>>>3)|0]<<(E&7)>>>7;c[G>>2]=E+1;E=D&1;c[f+177092>>2]=E;c[f+177096>>2]=E}}while(0);c[j>>2]=0;mrc((c[f+5304>>2]|0)+(x*48|0)|0,0,48)|0;J=f+177092|0;if((c[J>>2]|0)==0){R=0}else{c[j>>2]=128;R=128}a:do{if((c[z>>2]|0)==3){B=R|63744;c[j>>2]=B;if((c[f+197872>>2]|0)!=0){hia(f,B);iia(f,c[j>>2]|0)}nia(f,j);c[j>>2]=c[j>>2]|2048;S=c[f+6108>>2]|0}else{B=R|14344;c[j>>2]=B;hia(f,B);B=h;C=c[f+4084>>2]|0;E=c[f+4052>>2]|0;D=c[f+6108>>2]|0;c[f+5644>>2]=0;c[f+5652>>2]=0;c[f+5660>>2]=0;c[f+5668>>2]=0;G=c[f+4872>>2]|0;if((G&12288|0)==0){if((G|0)!=0){T=5453632;U=-1;V=29}}else{I=c[f+4852>>2]|0;N=d[c[f+4880>>2]|0]|0;P=a[C+((N&254)+(I<<2|1))|0]|0;H=E+((ca(N,D)|0)+3+(c[(c[f+6100>>2]|0)+(I<<2)>>2]|0)<<2)|0;do{if((c[F>>2]|0)==0){W=H;X=P}else{I=(G&128|0)!=0;if((c[J>>2]|0)==0){if(!I){W=H;X=P;break}N=c[H>>2]|0;c[h>>2]=N;b[h+2>>1]=N>>>16<<1;W=h;X=P>>1;break}else{if(I){W=H;X=P;break}I=c[H>>2]|0;c[h>>2]=I;b[h+2>>1]=(I>>16|0)/2|0;W=h;X=P<<1;break}}}while(0);if((c[W>>2]|X|0)!=0){T=W;U=X;V=29}}do{if((V|0)==29){P=c[f+4864>>2]|0;if((P&12288|0)==0){if((P|0)==0){break}else{Y=-1;Z=5453632}}else{H=c[f+4844>>2]|0;G=a[C+(H<<2|2)|0]|0;I=E+((c[(c[f+6100>>2]|0)+(H<<2)>>2]|0)+(D*3|0)<<2)|0;do{if((c[F>>2]|0)==0){_=G;$=I}else{H=(P&128|0)!=0;if((c[J>>2]|0)==0){if(!H){_=G;$=I;break}N=c[I>>2]|0;O=h+4|0;c[O>>2]=N;b[B+6>>1]=N>>>16<<1;_=G>>1;$=O;break}else{if(H){_=G;$=I;break}H=c[I>>2]|0;O=h+4|0;c[O>>2]=H;b[B+6>>1]=(H>>16|0)/2|0;_=G<<1;$=O;break}}}while(0);if((c[$>>2]|_|0)==0){break}else{Y=_;Z=$}}G=c[f+4868>>2]|0;do{if((G&12288|0)==0){if((G|0)!=0){aa=5453632;ba=-1;break}I=c[f+4860>>2]|0;if((I&12288|0)==0){aa=5453632;ba=(I|0)==0?-2:-1;break}P=c[f+4840>>2]|0;O=c[f+4884>>2]|0;H=a[C+(P<<2|O&2|1)|0]|0;N=E+(D+3+(O&D<<1)+(c[(c[f+6100>>2]|0)+(P<<2)>>2]|0)<<2)|0;if((c[F>>2]|0)==0){aa=N;ba=H;break}P=(I&128|0)!=0;if((c[J>>2]|0)==0){if(!P){aa=N;ba=H;break}I=c[N>>2]|0;O=h+8|0;c[O>>2]=I;b[B+10>>1]=I>>>16<<1;aa=O;ba=H>>1;break}else{if(P){aa=N;ba=H;break}P=c[N>>2]|0;N=h+8|0;c[N>>2]=P;b[B+10>>1]=(P>>16|0)/2|0;aa=N;ba=H<<1;break}}else{H=c[f+4848>>2]|0;N=a[C+(H<<2|2)|0]|0;P=E+((c[(c[f+6100>>2]|0)+(H<<2)>>2]|0)+(D*3|0)<<2)|0;if((c[F>>2]|0)==0){aa=P;ba=N;break}H=(G&128|0)!=0;if((c[J>>2]|0)==0){if(!H){aa=P;ba=N;break}O=c[P>>2]|0;I=h+8|0;c[I>>2]=O;b[B+10>>1]=O>>>16<<1;aa=I;ba=N>>1;break}else{if(H){aa=P;ba=N;break}H=c[P>>2]|0;P=h+8|0;c[P>>2]=H;b[B+10>>1]=(H>>16|0)/2|0;aa=P;ba=N<<1;break}}}while(0);G=(Y|0)!=0;N=(U|0)!=0;P=(G&1^1)+(N&1^1)+((ba|0)==0)|0;do{if((P|0)>1){H=b[T>>1]|0;I=H<<16>>16;O=b[Z>>1]|0;da=O<<16>>16;ea=b[aa>>1]|0;fa=ea<<16>>16;do{if(H<<16>>16>O<<16>>16){if(!(ea<<16>>16>O<<16>>16)){ga=da;break}ga=(fa|0)>(I|0)?I:fa}else{if(!(O<<16>>16>ea<<16>>16)){ga=da;break}ga=(fa|0)>(I|0)?fa:I}}while(0);I=b[T+2>>1]|0;fa=I<<16>>16;da=b[Z+2>>1]|0;ea=da<<16>>16;O=b[aa+2>>1]|0;H=O<<16>>16;if(I<<16>>16>da<<16>>16){if(!(O<<16>>16>da<<16>>16)){ha=ea;ia=ga;break}ha=(H|0)>(fa|0)?fa:H;ia=ga;break}else{if(!(da<<16>>16>O<<16>>16)){ha=ea;ia=ga;break}ha=(H|0)>(fa|0)?H:fa;ia=ga;break}}else{if((P|0)==1){if(!N){ha=b[T+2>>1]|0;ia=b[T>>1]|0;break}if(G){ha=b[aa+2>>1]|0;ia=b[aa>>1]|0;break}else{ha=b[Z+2>>1]|0;ia=b[Z>>1]|0;break}}fa=b[T>>1]|0;H=fa<<16>>16;ea=b[Z>>1]|0;O=ea<<16>>16;da=b[aa>>1]|0;I=da<<16>>16;do{if(fa<<16>>16>ea<<16>>16){if(!(da<<16>>16>ea<<16>>16)){ja=O;break}ja=(I|0)>(H|0)?H:I}else{if(!(ea<<16>>16>da<<16>>16)){ja=O;break}ja=(I|0)>(H|0)?I:H}}while(0);H=b[T+2>>1]|0;I=H<<16>>16;O=b[Z+2>>1]|0;da=O<<16>>16;ea=b[aa+2>>1]|0;fa=ea<<16>>16;if(H<<16>>16>O<<16>>16){if(!(ea<<16>>16>O<<16>>16)){ha=da;ia=ja;break}ha=(fa|0)>(I|0)?I:fa;ia=ja;break}else{if(!(O<<16>>16>ea<<16>>16)){ha=da;ia=ja;break}ha=(fa|0)>(I|0)?fa:I;ia=ja;break}}}while(0);G=ha<<16|ia&65535;c[f+5360>>2]=G;c[f+5364>>2]=G;c[f+5368>>2]=G;c[f+5372>>2]=G;c[f+5392>>2]=G;c[f+5396>>2]=G;c[f+5400>>2]=G;c[f+5404>>2]=G;c[f+5424>>2]=G;c[f+5428>>2]=G;c[f+5432>>2]=G;c[f+5436>>2]=G;c[f+5456>>2]=G;c[f+5460>>2]=G;c[f+5464>>2]=G;c[f+5468>>2]=G;S=D;break a}}while(0);mrc(f+5360|0,0,16)|0;mrc(f+5392|0,0,16)|0;mrc(f+5424|0,0,16)|0;mrc(f+5456|0,0,16)|0;S=D}}while(0);J=c[j>>2]|0;F=(ca(S<<2,c[u>>2]|0)|0)+(c[t>>2]<<2)|0;B=c[y>>2]<<2;if((J&12288|0)==0){E=c[f+4084>>2]|0;b[E+B>>1]=-1;b[E+(B|2)>>1]=-1}else{E=c[f+4052>>2]|0;C=f+5360|0;G=c[C+4>>2]|0;N=E+(F<<2)|0;c[N>>2]=c[C>>2];c[N+4>>2]=G;G=f+5368|0;N=c[G+4>>2]|0;C=E+((F|2)<<2)|0;c[C>>2]=c[G>>2];c[C+4>>2]=N;N=f+5392|0;C=c[N+4>>2]|0;G=F+S|0;P=E+(G<<2)|0;c[P>>2]=c[N>>2];c[P+4>>2]=C;C=f+5400|0;P=c[C+4>>2]|0;N=E+(G+2<<2)|0;c[N>>2]=c[C>>2];c[N+4>>2]=P;P=f+5424|0;N=c[P+4>>2]|0;C=F+(S<<1)|0;G=E+(C<<2)|0;c[G>>2]=c[P>>2];c[G+4>>2]=N;N=f+5432|0;G=c[N+4>>2]|0;P=E+(C+2<<2)|0;c[P>>2]=c[N>>2];c[P+4>>2]=G;G=f+5456|0;P=c[G+4>>2]|0;N=F+(S*3|0)|0;C=E+(N<<2)|0;c[C>>2]=c[G>>2];c[C+4>>2]=P;P=f+5464|0;C=c[P+4>>2]|0;G=E+(N+2<<2)|0;c[G>>2]=c[P>>2];c[G+4>>2]=C;C=c[f+4084>>2]|0;a[C+B|0]=a[f+5644|0]|0;a[C+(B|1)|0]=a[f+5646|0]|0;a[C+(B|2)|0]=a[f+5660|0]|0;a[C+(B|3)|0]=a[f+5662|0]|0}if((J&49152|0)!=0){J=c[f+4056>>2]|0;C=f+5520|0;G=c[C+4>>2]|0;P=J+(F<<2)|0;c[P>>2]=c[C>>2];c[P+4>>2]=G;G=f+5528|0;P=c[G+4>>2]|0;C=J+((F|2)<<2)|0;c[C>>2]=c[G>>2];c[C+4>>2]=P;P=f+5552|0;C=c[P+4>>2]|0;G=F+S|0;N=J+(G<<2)|0;c[N>>2]=c[P>>2];c[N+4>>2]=C;C=f+5560|0;N=c[C+4>>2]|0;P=J+(G+2<<2)|0;c[P>>2]=c[C>>2];c[P+4>>2]=N;N=f+5584|0;P=c[N+4>>2]|0;C=F+(S<<1)|0;G=J+(C<<2)|0;c[G>>2]=c[N>>2];c[G+4>>2]=P;P=f+5592|0;G=c[P+4>>2]|0;N=J+(C+2<<2)|0;c[N>>2]=c[P>>2];c[N+4>>2]=G;G=f+5616|0;N=c[G+4>>2]|0;P=F+(S*3|0)|0;F=J+(P<<2)|0;c[F>>2]=c[G>>2];c[F+4>>2]=N;N=f+5624|0;F=c[N+4>>2]|0;G=J+(P+2<<2)|0;c[G>>2]=c[N>>2];c[G+4>>2]=F;F=c[f+4088>>2]|0;a[F+B|0]=a[f+5684|0]|0;a[F+(B|1)|0]=a[f+5686|0]|0;a[F+(B|2)|0]=a[f+5700|0]|0;a[F+(B|3)|0]=a[f+5702|0]|0}c[(c[f+4064>>2]|0)+(x<<2)>>2]=c[j>>2];a[(c[f+4040>>2]|0)+x|0]=c[f+4792>>2];b[(c[f+177072>>2]|0)+(x<<1)>>1]=c[f+177068>>2];c[f+4824>>2]=1;ka=0;i=g;return ka|0}}while(0);j=f+177088|0;do{if((c[j>>2]|0)!=0){if((v&1|0)!=0){break}S=f+1096|0;ia=c[S>>2]|0;ha=d[(c[f+1088>>2]|0)+(ia>>>3)|0]<<(ia&7)>>>7;c[S>>2]=ia+1;ia=ha&1;c[f+177092>>2]=ia;c[f+177096>>2]=ia}}while(0);c[f+4824>>2]=0;v=f+1096|0;ia=c[v>>2]|0;ha=f+1088|0;S=c[ha>>2]|0;ja=S+(ia>>>3)|0;aa=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ia&7);if(aa>>>0>134217727>>>0){ja=aa>>>23;Z=(d[1382088+ja|0]|0)+ia|0;c[v>>2]=Z;la=d[1276064+ja|0]|0;ma=Z}else{Z=aa>>>0>65535>>>0;ja=Z?aa>>>16:aa;T=Z?16:0;if((ja&65280|0)==0){na=T;oa=ja}else{na=T|8;oa=ja>>>8}ja=(d[1359664+oa|0]|0)+na<<1;na=ia+63-ja|0;c[v>>2]=na;la=(aa>>>((ja-31|0)>>>0))-1|0;ma=na}c[k>>2]=la;do{if((A|0)==3){if(la>>>0<23>>>0){na=d[1960506+(la<<2)|0]|0;ja=e[1960504+(la<<2)>>1]|0;c[k>>2]=ja;pa=na;qa=0;ra=ja;break}else{ja=la-23|0;c[k>>2]=ja;sa=ja;V=106;break}}else if((A|0)==2){if(la>>>0<5>>>0){ja=d[736626+(la<<2)|0]|0;na=e[736624+(la<<2)>>1]|0;c[k>>2]=na;pa=ja;qa=0;ra=na;break}else{na=la-5|0;c[k>>2]=na;sa=na;V=106;break}}else{if((c[f+177076>>2]|0)!=5|(la|0)==0){sa=la;V=106;break}na=la-1|0;c[k>>2]=na;sa=na;V=106}}while(0);do{if((V|0)==106){if(!(sa>>>0>25>>>0)){la=d[1077875+(sa<<2)|0]|0;c[f+4836>>2]=d[1077874+(sa<<2)|0]|0;A=e[1077872+(sa<<2)>>1]|0;c[k>>2]=A;pa=0;qa=la;ra=A;break}A=c[f>>2]|0;la=(BLb(c[f+177076>>2]|0)|0)<<24>>24;na=c[t>>2]|0;ja=c[u>>2]|0;KIb(A,16,2363528,(ta=i,i=i+32|0,c[ta>>2]=sa,c[ta+8>>2]=la,c[ta+16>>2]=na,c[ta+24>>2]=ja,ta)|0);i=ta;ka=-1;i=g;return ka|0}}while(0);sa=f+177092|0;if((c[sa>>2]|0)==0){ua=ra}else{ja=ra|128;c[k>>2]=ja;ua=ja}b[(c[f+177072>>2]|0)+(x<<1)>>1]=c[f+177068>>2];if((ua&4|0)!=0){ja=ca(e[1375896+(q<<1)>>1]|0,c[f+7308>>2]|0)|0;q=-ma&7;if((q|0)==0){va=ma}else{ra=q+ma|0;c[v>>2]=ra;va=ra}c[f+421184>>2]=S+(va>>3);if(((c[f+1100>>2]|0)-va|0)<(ja|0)){KIb(c[f>>2]|0,16,2298368,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;ka=-1094995529;i=g;return ka|0}else{c[v>>2]=va+ja;a[(c[f+4040>>2]|0)+x|0]=0;mrc((c[f+5304>>2]|0)+(x*48|0)|0,16,48)|0;c[(c[f+4064>>2]|0)+(x<<2)>>2]=c[k>>2];ka=0;i=g;return ka|0}}ja=c[f+177096>>2]|0;c[l>>2]=c[f+199420>>2]<<ja;c[l+4>>2]=c[f+199424>>2]<<ja;hia(f,ua);iia(f,c[k>>2]|0);ua=c[k>>2]|0;b:do{if((ua&7|0)==0){if((pa|0)==4){ja=(c[z>>2]|0)==3;va=c[v>>2]|0;S=c[ha>>2]|0;ra=S+(va>>>3)|0;ma=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(va&7)>>>23;ra=(d[1382088+ma|0]|0)+va|0;c[v>>2]=ra;va=a[1276064+ma|0]|0;ma=va&255;q=f+177112|0;b[q>>1]=va&255;c:do{if(ja){do{if((va&255)>>>0>12>>>0){wa=ma}else{c[m>>2]=d[1960394+(ma<<2)|0]|0;na=b[1960392+((va&255)<<2)>>1]|0;b[q>>1]=na;la=S+(ra>>>3)|0;A=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ra&7)>>>23;la=(d[1382088+A|0]|0)+ra|0;c[v>>2]=la;aa=a[1276064+A|0]|0;A=aa&255;ia=f+177114|0;b[ia>>1]=aa&255;if((aa&255)>>>0>12>>>0){wa=A;break}c[m+4>>2]=d[1960394+(A<<2)|0]|0;A=b[1960392+((aa&255)<<2)>>1]|0;b[ia>>1]=A;ia=S+(la>>>3)|0;aa=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(la&7)>>>23;ia=(d[1382088+aa|0]|0)+la|0;c[v>>2]=ia;la=a[1276064+aa|0]|0;aa=la&255;oa=f+177116|0;b[oa>>1]=la&255;if((la&255)>>>0>12>>>0){wa=aa;break}c[m+8>>2]=d[1960394+(aa<<2)|0]|0;aa=b[1960392+((la&255)<<2)>>1]|0;b[oa>>1]=aa;oa=S+(ia>>>3)|0;la=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ia&7)>>>23;c[v>>2]=(d[1382088+la|0]|0)+ia;ia=a[1276064+la|0]|0;la=ia&255;oa=f+177118|0;b[oa>>1]=ia&255;if((ia&255)>>>0>12>>>0){wa=la;break}c[m+12>>2]=d[1960394+(la<<2)|0]|0;la=b[1960392+((ia&255)<<2)>>1]|0;b[oa>>1]=la;if(((A|na|aa|la)&256)==0){break c}nia(f,k);a[f+5702|0]=-2;a[f+5662|0]=-2;a[f+5686|0]=-2;a[f+5646|0]=-2;break c}}while(0);D=c[t>>2]|0;la=c[u>>2]|0;KIb(c[f>>2]|0,16,2247672,(ta=i,i=i+24|0,c[ta>>2]=wa,c[ta+8>>2]=D,c[ta+16>>2]=la,ta)|0);i=ta;ka=-1;i=g;return ka|0}else{do{if((va&255)>>>0>3>>>0){xa=ma}else{c[m>>2]=d[736594+(ma<<2)|0]|0;b[q>>1]=b[736592+((va&255)<<2)>>1]|0;la=S+(ra>>>3)|0;D=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ra&7)>>>23;la=(d[1382088+D|0]|0)+ra|0;c[v>>2]=la;aa=a[1276064+D|0]|0;D=aa&255;na=f+177114|0;b[na>>1]=aa&255;if((aa&255)>>>0>3>>>0){xa=D;break}c[m+4>>2]=d[736594+(D<<2)|0]|0;b[na>>1]=b[736592+((aa&255)<<2)>>1]|0;aa=S+(la>>>3)|0;na=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(la&7)>>>23;aa=(d[1382088+na|0]|0)+la|0;c[v>>2]=aa;la=a[1276064+na|0]|0;na=la&255;D=f+177116|0;b[D>>1]=la&255;if((la&255)>>>0>3>>>0){xa=na;break}c[m+8>>2]=d[736594+(na<<2)|0]|0;b[D>>1]=b[736592+((la&255)<<2)>>1]|0;la=S+(aa>>>3)|0;D=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(aa&7)>>>23;c[v>>2]=(d[1382088+D|0]|0)+aa;aa=a[1276064+D|0]|0;D=aa&255;la=f+177118|0;b[la>>1]=aa&255;if((aa&255)>>>0>3>>>0){xa=D;break}c[m+12>>2]=d[736594+(D<<2)|0]|0;b[la>>1]=b[736592+((aa&255)<<2)>>1]|0;break c}}while(0);aa=c[t>>2]|0;la=c[u>>2]|0;KIb(c[f>>2]|0,16,2205656,(ta=i,i=i+24|0,c[ta>>2]=xa,c[ta+8>>2]=aa,c[ta+16>>2]=la,ta)|0);i=ta;ka=-1;i=g;return ka|0}}while(0);S=f+199428|0;ra=c[S>>2]|0;d:do{if((ra|0)==0){ya=0}else{va=c[k>>2]|0;q=0;e:while(1){if((va&512|0)==0){za=c[l+(q<<2)>>2]|0}else{za=1}ma=4096<<(q<<1);ja=0;do{la=e[f+177112+(ja<<1)>>1]|0;do{if((la&256|0)==0){if((la&ma|0)==0){c[n+(q<<4)+(ja<<2)>>2]=-1;break}if((za|0)==2){aa=c[v>>2]|0;D=d[(c[ha>>2]|0)+(aa>>>3)|0]<<(aa&7)>>>7;c[v>>2]=aa+1;Aa=D&1^1}else if((za|0)==1){Aa=0}else{D=c[v>>2]|0;aa=(c[ha>>2]|0)+(D>>>3)|0;na=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(D&7)>>>23;c[v>>2]=(d[1382088+na|0]|0)+D;Ba=d[1276064+na|0]|0;if(Ba>>>0<za>>>0){Aa=Ba}else{break e}}c[n+(q<<4)+(ja<<2)>>2]=Aa}}while(0);ja=ja+1|0;}while((ja|0)<4);ja=q+1|0;if(ja>>>0<ra>>>0){q=ja}else{ya=ra;break d}}KIb(c[f>>2]|0,16,2173456,(ta=i,i=i+8|0,c[ta>>2]=Ba,ta)|0);i=ta;ka=-1;i=g;return ka|0}}while(0);if((o|0)==0){Ca=0}else{ra=(c[f+6196>>2]|0)==0;q=f+177112|0;Ca=((ra?24117616:7340144)&c[q>>2]|0)==0&((ra?24117616:7340144)&c[q+4>>2]|0)==0&1}if((ya|0)==0){Da=Ca;break}q=f+2524|0;ra=f+4872|0;va=f+4852|0;ja=f+6100|0;ma=f+6108|0;la=0;while(1){na=la<<1;D=4096<<na;aa=f+5632+(la*40|0)+11|0;A=f+5312+(la*160|0)+40|0;oa=A|0;ia=A;A=12288<<na;na=f+5312+(la*160|0)+42|0;T=0;do{Z=f+177112+(T<<1)|0;do{if((b[Z>>1]&256)==0){ga=c[n+(la<<4)+(T<<2)>>2]&255;ba=T<<2;U=d[602216+ba|0]|0;a[U+9+(f+5632+(la*40|0))|0]=ga;a[U+8+(f+5632+(la*40|0))|0]=ga;a[U+1+(f+5632+(la*40|0))|0]=ga;a[f+5632+(la*40|0)+U|0]=ga;ga=e[Z>>1]|0;if((ga&D|0)==0){c[f+5312+(la*160|0)+(U<<2)+36>>2]=0;c[f+5312+(la*160|0)+(U<<2)+32>>2]=0;c[f+5312+(la*160|0)+(U<<2)+4>>2]=0;c[f+5312+(la*160|0)+(U<<2)>>2]=0;break}U=(ga&24|0)!=0?2:1;Y=c[m+(T<<2)>>2]|0;if((Y|0)<=0){break}h=(ga&8|0)==0;$=(ga&16|0)==0;_=(ga&32|0)==0;ga=0;do{X=a[602216+((ca(ga,U)|0)+ba)|0]|0;W=X&255;R=a[f+5632+(la*40|0)+W|0]|0;Q=R<<24>>24;M=W-8|0;K=a[f+5632+(la*40|0)+M|0]|0;L=W-1|0;B=a[f+5632+(la*40|0)+L|0]|0;F=f+5312+(la*160|0)+(L<<2)|0;G=f+5312+(la*160|0)+(M<<2)|0;N=M+U|0;P=a[f+5632+(la*40|0)+N|0]|0;J=P<<24>>24;C=P<<24>>24==-2;do{if((c[j>>2]|0)!=0&C&(X&255)>>>0>19>>>0&(W&7|0)==4){if((a[aa]|0)==-2){V=178;break}P=c[q>>2]|0;E=c[P+1536>>2]|0;c[ia>>2]=0;I=(c[ra>>2]&128|0)==0;if((c[sa>>2]|0)==0){if(I){V=178;break}fa=c[w>>2]|0;da=fa+(c[va>>2]|0)|0;ea=(c[u>>2]<<1&2)+(W>>>5)|0;if((c[E+((ca(ea>>>2,fa)|0)+da<<2)>>2]&A|0)==0){Ea=-1;Fa=oa;break}fa=(c[(c[ja>>2]|0)+(da<<2)>>2]|0)+3+(ca(c[ma>>2]|0,ea)|0)|0;O=c[P+1524+(la<<2)>>2]|0;b[oa>>1]=b[O+(fa<<2)>>1]|0;b[na>>1]=b[O+(fa<<2)+2>>1]<<1;Ea=a[(c[P+1556+(la<<2)>>2]|0)+((ea&2147483646)+(da<<2|1))|0]>>1;Fa=oa;break}else{if(!I){V=178;break}I=c[f+4852+(((X&255)>>>0>35>>>0)<<2)>>2]|0;da=W>>>2;if((c[E+(I<<2)>>2]&A|0)==0){Ea=-1;Fa=oa;break}E=(c[(c[ja>>2]|0)+(I<<2)>>2]|0)+3+(ca(c[ma>>2]|0,da&3)|0)|0;ea=c[P+1524+(la<<2)>>2]|0;b[oa>>1]=b[ea+(E<<2)>>1]|0;b[na>>1]=(b[ea+(E<<2)+2>>1]|0)/2|0;Ea=a[(c[P+1556+(la<<2)>>2]|0)+(da&2|I<<2|1)|0]<<1;Fa=oa;break}}else{V=178}}while(0);do{if((V|0)==178){V=0;if(C){X=W-9|0;Ea=a[f+5632+(la*40|0)+X|0]|0;Fa=f+5312+(la*160|0)+(X<<2)|0;break}else{Ea=J;Fa=f+5312+(la*160|0)+(N<<2)|0;break}}}while(0);N=K<<24>>24==R<<24>>24;J=B<<24>>24==R<<24>>24;C=(J&1)+(N&1)+((Ea|0)==(Q|0))|0;do{if((C|0)>1){X=b[F>>1]|0;I=X<<16>>16;da=b[G>>1]|0;P=da<<16>>16;E=b[Fa>>1]|0;ea=E<<16>>16;do{if(X<<16>>16>da<<16>>16){if(!(E<<16>>16>da<<16>>16)){Ga=P;break}Ga=(ea|0)>(I|0)?I:ea}else{if(!(da<<16>>16>E<<16>>16)){Ga=P;break}Ga=(ea|0)>(I|0)?ea:I}}while(0);I=b[f+5312+(la*160|0)+(L<<2)+2>>1]|0;ea=I<<16>>16;P=b[f+5312+(la*160|0)+(M<<2)+2>>1]|0;E=P<<16>>16;da=b[Fa+2>>1]|0;X=da<<16>>16;if(I<<16>>16>P<<16>>16){if(!(da<<16>>16>P<<16>>16)){Ha=E;Ia=Ga;break}Ha=(X|0)>(ea|0)?ea:X;Ia=Ga;break}else{if(!(P<<16>>16>da<<16>>16)){Ha=E;Ia=Ga;break}Ha=(X|0)>(ea|0)?X:ea;Ia=Ga;break}}else{if((C|0)==1){if(J){Ha=b[f+5312+(la*160|0)+(L<<2)+2>>1]|0;Ia=b[F>>1]|0;break}if(N){Ha=b[f+5312+(la*160|0)+(M<<2)+2>>1]|0;Ia=b[G>>1]|0;break}else{Ha=b[Fa+2>>1]|0;Ia=b[Fa>>1]|0;break}}ea=b[F>>1]|0;X=ea<<16>>16;if(!((Ea|0)!=-2|K<<24>>24!=-2|B<<24>>24==-2)){Ha=b[f+5312+(la*160|0)+(L<<2)+2>>1]|0;Ia=X;break}E=b[G>>1]|0;da=E<<16>>16;P=b[Fa>>1]|0;I=P<<16>>16;do{if(ea<<16>>16>E<<16>>16){if(!(P<<16>>16>E<<16>>16)){Ja=da;break}Ja=(I|0)>(X|0)?X:I}else{if(!(E<<16>>16>P<<16>>16)){Ja=da;break}Ja=(I|0)>(X|0)?I:X}}while(0);X=b[f+5312+(la*160|0)+(L<<2)+2>>1]|0;I=X<<16>>16;da=b[f+5312+(la*160|0)+(M<<2)+2>>1]|0;P=da<<16>>16;E=b[Fa+2>>1]|0;ea=E<<16>>16;if(X<<16>>16>da<<16>>16){if(!(E<<16>>16>da<<16>>16)){Ha=P;Ia=Ja;break}Ha=(ea|0)>(I|0)?I:ea;Ia=Ja;break}else{if(!(da<<16>>16>E<<16>>16)){Ha=P;Ia=Ja;break}Ha=(ea|0)>(I|0)?ea:I;Ia=Ja;break}}}while(0);M=c[v>>2]|0;L=c[ha>>2]|0;G=L+(M>>>3)|0;B=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(M&7);if(B>>>0>134217727>>>0){G=B>>>23;K=(d[1382088+G|0]|0)+M|0;c[v>>2]=K;Ka=a[1306768+G|0]|0;La=K}else{K=B>>>0>65535>>>0;G=K?B>>>16:B;B=K?16:0;if((G&65280|0)==0){Ma=B;Na=G}else{Ma=B|8;Na=G>>>8}G=(d[1359664+Na|0]|0)+Ma|0;B=31-G+M|0;M=L+(B>>>3)|0;K=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(B&7)>>>(G>>>0);M=32-G+B|0;c[v>>2]=M;B=K>>>1;Ka=(K&1|0)==0?B:-B|0;La=M}M=Ka+Ia|0;B=L+(La>>>3)|0;K=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(La&7);if(K>>>0>134217727>>>0){B=K>>>23;c[v>>2]=(d[1382088+B|0]|0)+La;Oa=a[1306768+B|0]|0}else{B=K>>>0>65535>>>0;G=B?K>>>16:K;K=B?16:0;if((G&65280|0)==0){Pa=K;Qa=G}else{Pa=K|8;Qa=G>>>8}G=(d[1359664+Qa|0]|0)+Pa|0;K=31-G+La|0;B=L+(K>>>3)|0;L=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(K&7)>>>(G>>>0);c[v>>2]=32-G+K;K=L>>>1;Oa=(L&1|0)==0?K:-K|0}K=Oa+Ha|0;L=M&65535;do{if(h){if(!$){M=W+1|0;b[f+5312+(la*160|0)+(M<<2)>>1]=L;G=K&65535;b[f+5312+(la*160|0)+(M<<2)+2>>1]=G;Ra=G;break}if(_){Ra=K&65535;break}else{G=W+8|0;b[f+5312+(la*160|0)+(G<<2)>>1]=L;M=K&65535;b[f+5312+(la*160|0)+(G<<2)+2>>1]=M;Ra=M;break}}else{M=W+9|0;b[f+5312+(la*160|0)+(M<<2)>>1]=L;G=W+8|0;b[f+5312+(la*160|0)+(G<<2)>>1]=L;B=W+1|0;b[f+5312+(la*160|0)+(B<<2)>>1]=L;F=K&65535;b[f+5312+(la*160|0)+(M<<2)+2>>1]=F;b[f+5312+(la*160|0)+(G<<2)+2>>1]=F;b[f+5312+(la*160|0)+(B<<2)+2>>1]=F;Ra=F}}while(0);b[f+5312+(la*160|0)+(W<<2)>>1]=L;b[f+5312+(la*160|0)+(W<<2)+2>>1]=Ra;ga=ga+1|0;}while((ga|0)<(Y|0))}else{Y=d[602216+(T<<2)|0]|0;a[f+5632+(la*40|0)+Y|0]=a[Y+1+(f+5632+(la*40|0))|0]|0}}while(0);T=T+1|0;}while((T|0)<4);T=la+1|0;if(T>>>0<(c[S>>2]|0)>>>0){la=T}else{Da=Ca;break b}}}if((ua&256|0)!=0){nia(f,k);Da=c[f+6196>>2]&o;break}if((ua&8|0)!=0){la=f+199428|0;S=c[la>>2]|0;if((S|0)==0){Da=o;break}else{Sa=0;Ta=S}while(1){if((ua&4096<<(Sa<<1)|0)==0){Ua=Ta}else{S=c[l+(Sa<<2)>>2]|0;if((S|0)==2){ma=c[v>>2]|0;ja=d[(c[ha>>2]|0)+(ma>>>3)|0]<<(ma&7)>>>7;c[v>>2]=ma+1;Va=ja&1^1}else if((S|0)==1){Va=0}else{ja=c[v>>2]|0;ma=(c[ha>>2]|0)+(ja>>>3)|0;va=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ja&7)>>>23;c[v>>2]=(d[1382088+va|0]|0)+ja;Wa=d[1276064+va|0]|0;if(Wa>>>0<S>>>0){Va=Wa}else{V=240;break}}S=ca(Va,16843009)|0;c[f+5632+(Sa*40|0)+12>>2]=S;c[f+5632+(Sa*40|0)+20>>2]=S;c[f+5632+(Sa*40|0)+28>>2]=S;c[f+5632+(Sa*40|0)+36>>2]=S;Ua=c[la>>2]|0}S=Sa+1|0;if(S>>>0<Ua>>>0){Sa=S;Ta=Ua}else{break}}if((V|0)==240){KIb(c[f>>2]|0,16,2173456,(ta=i,i=i+8|0,c[ta>>2]=Wa,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((Ua|0)==0){Da=o;break}else{Xa=0}while(1){if((ua&4096<<(Xa<<1)|0)!=0){la=a[f+5632+(Xa*40|0)+12|0]|0;S=a[f+5632+(Xa*40|0)+4|0]|0;va=a[f+5632+(Xa*40|0)+11|0]|0;ja=f+5312+(Xa*160|0)+44|0;ma=f+5312+(Xa*160|0)+16|0;ra=a[f+5632+(Xa*40|0)+8|0]|0;if(ra<<24>>24==-2){Ya=a[f+5632+(Xa*40|0)+3|0]|0;Za=f+5312+(Xa*160|0)+12|0}else{Ya=ra;Za=f+5312+(Xa*160|0)+32|0}ra=S<<24>>24==la<<24>>24;q=va<<24>>24==la<<24>>24;T=(q&1)+(ra&1)+(Ya<<24>>24==la<<24>>24)|0;do{if((T|0)>1){la=b[ja>>1]|0;oa=la<<16>>16;na=b[ma>>1]|0;A=na<<16>>16;ia=b[Za>>1]|0;aa=ia<<16>>16;do{if(la<<16>>16>na<<16>>16){if(!(ia<<16>>16>na<<16>>16)){_a=A;break}_a=(aa|0)>(oa|0)?oa:aa}else{if(!(na<<16>>16>ia<<16>>16)){_a=A;break}_a=(aa|0)>(oa|0)?aa:oa}}while(0);oa=b[f+5312+(Xa*160|0)+46>>1]|0;aa=oa<<16>>16;A=b[f+5312+(Xa*160|0)+18>>1]|0;ia=A<<16>>16;na=b[Za+2>>1]|0;la=na<<16>>16;if(oa<<16>>16>A<<16>>16){if(!(na<<16>>16>A<<16>>16)){$a=ia;ab=_a;break}$a=(la|0)>(aa|0)?aa:la;ab=_a;break}else{if(!(A<<16>>16>na<<16>>16)){$a=ia;ab=_a;break}$a=(la|0)>(aa|0)?la:aa;ab=_a;break}}else{if((T|0)==1){if(q){$a=b[f+5312+(Xa*160|0)+46>>1]|0;ab=b[ja>>1]|0;break}if(ra){$a=b[f+5312+(Xa*160|0)+18>>1]|0;ab=b[ma>>1]|0;break}else{$a=b[Za+2>>1]|0;ab=b[Za>>1]|0;break}}aa=b[ja>>1]|0;la=aa<<16>>16;if(!(Ya<<24>>24!=-2|S<<24>>24!=-2|va<<24>>24==-2)){$a=b[f+5312+(Xa*160|0)+46>>1]|0;ab=la;break}ia=b[ma>>1]|0;na=ia<<16>>16;A=b[Za>>1]|0;oa=A<<16>>16;do{if(aa<<16>>16>ia<<16>>16){if(!(A<<16>>16>ia<<16>>16)){bb=na;break}bb=(oa|0)>(la|0)?la:oa}else{if(!(ia<<16>>16>A<<16>>16)){bb=na;break}bb=(oa|0)>(la|0)?oa:la}}while(0);la=b[f+5312+(Xa*160|0)+46>>1]|0;oa=la<<16>>16;na=b[f+5312+(Xa*160|0)+18>>1]|0;A=na<<16>>16;ia=b[Za+2>>1]|0;aa=ia<<16>>16;if(la<<16>>16>na<<16>>16){if(!(ia<<16>>16>na<<16>>16)){$a=A;ab=bb;break}$a=(aa|0)>(oa|0)?oa:aa;ab=bb;break}else{if(!(na<<16>>16>ia<<16>>16)){$a=A;ab=bb;break}$a=(aa|0)>(oa|0)?aa:oa;ab=bb;break}}}while(0);ma=c[v>>2]|0;va=c[ha>>2]|0;S=va+(ma>>>3)|0;ja=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(ma&7);if(ja>>>0>134217727>>>0){S=ja>>>23;ra=(d[1382088+S|0]|0)+ma|0;c[v>>2]=ra;cb=a[1306768+S|0]|0;db=ra}else{ra=ja>>>0>65535>>>0;S=ra?ja>>>16:ja;ja=ra?16:0;if((S&65280|0)==0){eb=ja;fb=S}else{eb=ja|8;fb=S>>>8}S=(d[1359664+fb|0]|0)+eb|0;ja=31-S+ma|0;ma=va+(ja>>>3)|0;ra=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ja&7)>>>(S>>>0);ma=32-S+ja|0;c[v>>2]=ma;ja=ra>>>1;cb=(ra&1|0)==0?ja:-ja|0;db=ma}ma=cb+ab|0;ja=va+(db>>>3)|0;ra=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(db&7);if(ra>>>0>134217727>>>0){ja=ra>>>23;c[v>>2]=(d[1382088+ja|0]|0)+db;gb=a[1306768+ja|0]|0}else{ja=ra>>>0>65535>>>0;S=ja?ra>>>16:ra;ra=ja?16:0;if((S&65280|0)==0){hb=ra;ib=S}else{hb=ra|8;ib=S>>>8}S=(d[1359664+ib|0]|0)+hb|0;ra=31-S+db|0;ja=va+(ra>>>3)|0;va=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ra&7)>>>(S>>>0);c[v>>2]=32-S+ra;ra=va>>>1;gb=(va&1|0)==0?ra:-ra|0}ra=gb+$a<<16|ma&65535;c[f+5312+(Xa*160|0)+48>>2]=ra;c[f+5312+(Xa*160|0)+52>>2]=ra;c[f+5312+(Xa*160|0)+56>>2]=ra;c[f+5312+(Xa*160|0)+60>>2]=ra;c[f+5312+(Xa*160|0)+80>>2]=ra;c[f+5312+(Xa*160|0)+84>>2]=ra;c[f+5312+(Xa*160|0)+88>>2]=ra;c[f+5312+(Xa*160|0)+92>>2]=ra;c[f+5312+(Xa*160|0)+112>>2]=ra;c[f+5312+(Xa*160|0)+116>>2]=ra;c[f+5312+(Xa*160|0)+120>>2]=ra;c[f+5312+(Xa*160|0)+124>>2]=ra;c[f+5312+(Xa*160|0)+144>>2]=ra;c[f+5312+(Xa*160|0)+148>>2]=ra;c[f+5312+(Xa*160|0)+152>>2]=ra;c[f+5312+(Xa*160|0)+156>>2]=ra}ra=Xa+1|0;if(ra>>>0<Ua>>>0){Xa=ra}else{Da=o;break b}}}ra=f+199428|0;ma=(c[ra>>2]|0)==0;if((ua&16|0)!=0){if(ma){Da=o;break}else{jb=0}f:do{va=jb<<1;S=l+(jb<<2)|0;do{if((ua&4096<<va|0)==0){kb=255}else{ja=c[S>>2]|0;if((ja|0)==2){q=c[v>>2]|0;T=d[(c[ha>>2]|0)+(q>>>3)|0]<<(q&7)>>>7;c[v>>2]=q+1;kb=T&1^1;break}else if((ja|0)==1){kb=0;break}else{T=c[v>>2]|0;q=(c[ha>>2]|0)+(T>>>3)|0;oa=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(T&7)>>>23;c[v>>2]=(d[1382088+oa|0]|0)+T;T=d[1276064+oa|0]|0;if(T>>>0<ja>>>0){kb=T;break}else{lb=T;V=297;break f}}}}while(0);T=ca(kb,16843009)|0;c[f+5632+(jb*40|0)+12>>2]=T;c[f+5632+(jb*40|0)+20>>2]=T;do{if((ua&4096<<(va|1)|0)==0){mb=255}else{T=c[S>>2]|0;if((T|0)==2){ja=c[v>>2]|0;oa=d[(c[ha>>2]|0)+(ja>>>3)|0]<<(ja&7)>>>7;c[v>>2]=ja+1;mb=oa&1^1;break}else if((T|0)==1){mb=0;break}else{oa=c[v>>2]|0;ja=(c[ha>>2]|0)+(oa>>>3)|0;q=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(oa&7)>>>23;c[v>>2]=(d[1382088+q|0]|0)+oa;oa=d[1276064+q|0]|0;if(oa>>>0<T>>>0){mb=oa;break}else{lb=oa;V=297;break f}}}}while(0);S=ca(mb,16843009)|0;c[f+5632+(jb*40|0)+28>>2]=S;c[f+5632+(jb*40|0)+36>>2]=S;jb=jb+1|0;nb=c[ra>>2]|0;}while(jb>>>0<nb>>>0);if((V|0)==297){KIb(c[f>>2]|0,16,2173456,(ta=i,i=i+8|0,c[ta>>2]=lb,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((nb|0)==0){Da=o;break}S=f+2524|0;va=f+4872|0;oa=f+4852|0;T=f+6100|0;q=f+6108|0;ja=0;while(1){aa=ja<<1;A=f+5632+(ja*40|0)+4|0;ia=f+5312+(ja*160|0)+16|0;na=f+5312+(ja*160|0)+18|0;la=f+5632+(ja*40|0)+11|0;D=f+5312+(ja*160|0)+40|0;Z=D|0;Y=D;D=12288<<aa;ga=f+5312+(ja*160|0)+42|0;_=f+5632+(ja*40|0)+27|0;$=f+5312+(ja*160|0)+108|0;h=f+5312+(ja*160|0)+110|0;U=0;do{if((ua&4096<<U+aa|0)==0){ob=0;pb=U<<4|12}else{ba=U<<3;K=U<<4|12;F=a[f+5632+(ja*40|0)+K|0]|0;B=F<<24>>24;do{if((ba|0)==0){if(!((a[A]|0)==F<<24>>24)){V=307;break}qb=b[na>>1]|0;rb=b[ia>>1]|0}else{if(!((a[_]|0)==F<<24>>24)){V=307;break}qb=b[h>>1]|0;rb=b[$>>1]|0}}while(0);do{if((V|0)==307){V=0;G=a[602216+ba|0]|0;M=G&255;N=M-8|0;J=a[f+5632+(ja*40|0)+N|0]|0;C=M-1|0;Q=a[f+5632+(ja*40|0)+C|0]|0;R=f+5312+(ja*160|0)+(C<<2)|0;I=f+5312+(ja*160|0)+(N<<2)|0;ea=M-4|0;P=a[f+5632+(ja*40|0)+ea|0]|0;E=P<<24>>24;da=P<<24>>24==-2;do{if((c[j>>2]|0)!=0&da&(G&255)>>>0>19>>>0&(M&7|0)==4){if((a[la]|0)==-2){V=316;break}P=c[S>>2]|0;X=c[P+1536>>2]|0;c[Y>>2]=0;fa=(c[va>>2]&128|0)==0;if((c[sa>>2]|0)==0){if(fa){V=316;break}O=c[w>>2]|0;H=O+(c[oa>>2]|0)|0;sb=(c[u>>2]<<1&2)+(M>>>5)|0;if((c[X+((ca(sb>>>2,O)|0)+H<<2)>>2]&D|0)==0){tb=-1;ub=Z;break}O=(c[(c[T>>2]|0)+(H<<2)>>2]|0)+3+(ca(c[q>>2]|0,sb)|0)|0;vb=c[P+1524+(ja<<2)>>2]|0;b[Z>>1]=b[vb+(O<<2)>>1]|0;b[ga>>1]=b[vb+(O<<2)+2>>1]<<1;tb=a[(c[P+1556+(ja<<2)>>2]|0)+((sb&2147483646)+(H<<2|1))|0]>>1;ub=Z;break}else{if(!fa){V=316;break}fa=c[f+4852+(((G&255)>>>0>35>>>0)<<2)>>2]|0;H=M>>>2;if((c[X+(fa<<2)>>2]&D|0)==0){tb=-1;ub=Z;break}X=(c[(c[T>>2]|0)+(fa<<2)>>2]|0)+3+(ca(c[q>>2]|0,H&3)|0)|0;sb=c[P+1524+(ja<<2)>>2]|0;b[Z>>1]=b[sb+(X<<2)>>1]|0;b[ga>>1]=(b[sb+(X<<2)+2>>1]|0)/2|0;tb=a[(c[P+1556+(ja<<2)>>2]|0)+(H&2|fa<<2|1)|0]<<1;ub=Z;break}}else{V=316}}while(0);do{if((V|0)==316){V=0;if(da){G=M-9|0;tb=a[f+5632+(ja*40|0)+G|0]|0;ub=f+5312+(ja*160|0)+(G<<2)|0;break}else{tb=E;ub=f+5312+(ja*160|0)+(ea<<2)|0;break}}}while(0);ea=J<<24>>24==F<<24>>24;E=Q<<24>>24==F<<24>>24;M=(E&1)+(ea&1)+((tb|0)==(B|0))|0;if((M|0)>1){da=b[R>>1]|0;G=da<<16>>16;fa=b[I>>1]|0;H=fa<<16>>16;P=b[ub>>1]|0;X=P<<16>>16;do{if(da<<16>>16>fa<<16>>16){if(!(P<<16>>16>fa<<16>>16)){wb=H;break}wb=(X|0)>(G|0)?G:X}else{if(!(fa<<16>>16>P<<16>>16)){wb=H;break}wb=(X|0)>(G|0)?X:G}}while(0);G=b[f+5312+(ja*160|0)+(C<<2)+2>>1]|0;X=G<<16>>16;H=b[f+5312+(ja*160|0)+(N<<2)+2>>1]|0;P=H<<16>>16;fa=b[ub+2>>1]|0;da=fa<<16>>16;if(G<<16>>16>H<<16>>16){if(!(fa<<16>>16>H<<16>>16)){qb=P;rb=wb;break}qb=(da|0)>(X|0)?X:da;rb=wb;break}else{if(!(H<<16>>16>fa<<16>>16)){qb=P;rb=wb;break}qb=(da|0)>(X|0)?da:X;rb=wb;break}}if((M|0)==1){if(E){qb=b[f+5312+(ja*160|0)+(C<<2)+2>>1]|0;rb=b[R>>1]|0;break}if(ea){qb=b[f+5312+(ja*160|0)+(N<<2)+2>>1]|0;rb=b[I>>1]|0;break}else{qb=b[ub+2>>1]|0;rb=b[ub>>1]|0;break}}X=b[R>>1]|0;da=X<<16>>16;if(!((tb|0)!=-2|J<<24>>24!=-2|Q<<24>>24==-2)){qb=b[f+5312+(ja*160|0)+(C<<2)+2>>1]|0;rb=da;break}P=b[I>>1]|0;fa=P<<16>>16;H=b[ub>>1]|0;G=H<<16>>16;do{if(X<<16>>16>P<<16>>16){if(!(H<<16>>16>P<<16>>16)){xb=fa;break}xb=(G|0)>(da|0)?da:G}else{if(!(P<<16>>16>H<<16>>16)){xb=fa;break}xb=(G|0)>(da|0)?G:da}}while(0);da=b[f+5312+(ja*160|0)+(C<<2)+2>>1]|0;G=da<<16>>16;fa=b[f+5312+(ja*160|0)+(N<<2)+2>>1]|0;H=fa<<16>>16;P=b[ub+2>>1]|0;X=P<<16>>16;if(da<<16>>16>fa<<16>>16){if(!(P<<16>>16>fa<<16>>16)){qb=H;rb=xb;break}qb=(X|0)>(G|0)?G:X;rb=xb;break}else{if(!(fa<<16>>16>P<<16>>16)){qb=H;rb=xb;break}qb=(X|0)>(G|0)?X:G;rb=xb;break}}}while(0);B=c[v>>2]|0;F=c[ha>>2]|0;ba=F+(B>>>3)|0;G=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(B&7);if(G>>>0>134217727>>>0){ba=G>>>23;X=(d[1382088+ba|0]|0)+B|0;c[v>>2]=X;yb=a[1306768+ba|0]|0;zb=X}else{X=G>>>0>65535>>>0;ba=X?G>>>16:G;G=X?16:0;if((ba&65280|0)==0){Ab=G;Bb=ba}else{Ab=G|8;Bb=ba>>>8}ba=(d[1359664+Bb|0]|0)+Ab|0;G=31-ba+B|0;B=F+(G>>>3)|0;X=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(G&7)>>>(ba>>>0);B=32-ba+G|0;c[v>>2]=B;G=X>>>1;yb=(X&1|0)==0?G:-G|0;zb=B}B=yb+rb|0;G=F+(zb>>>3)|0;X=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(zb&7);if(X>>>0>134217727>>>0){G=X>>>23;c[v>>2]=(d[1382088+G|0]|0)+zb;Cb=a[1306768+G|0]|0}else{G=X>>>0>65535>>>0;ba=G?X>>>16:X;X=G?16:0;if((ba&65280|0)==0){Db=X;Eb=ba}else{Db=X|8;Eb=ba>>>8}ba=(d[1359664+Eb|0]|0)+Db|0;X=31-ba+zb|0;G=F+(X>>>3)|0;F=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(X&7)>>>(ba>>>0);c[v>>2]=32-ba+X;X=F>>>1;Cb=(F&1|0)==0?X:-X|0}ob=Cb+qb<<16|B&65535;pb=K}c[f+5312+(ja*160|0)+(pb<<2)>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+4>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+8>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+12>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+32>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+36>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+40>>2]=ob;c[f+5312+(ja*160|0)+(pb<<2)+44>>2]=ob;U=U+1|0;}while((U|0)<2);U=ja+1|0;if(U>>>0<nb>>>0){ja=U}else{Da=o;break b}}}if(ma){Da=o;break}else{Fb=0}g:do{ja=Fb<<1;q=l+(Fb<<2)|0;do{if((ua&4096<<ja|0)==0){Gb=255}else{T=c[q>>2]|0;if((T|0)==2){oa=c[v>>2]|0;va=d[(c[ha>>2]|0)+(oa>>>3)|0]<<(oa&7)>>>7;c[v>>2]=oa+1;Gb=va&1^1;break}else if((T|0)==1){Gb=0;break}else{va=c[v>>2]|0;oa=(c[ha>>2]|0)+(va>>>3)|0;S=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(va&7)>>>23;c[v>>2]=(d[1382088+S|0]|0)+va;va=d[1276064+S|0]|0;if(va>>>0<T>>>0){Gb=va;break}else{Hb=va;V=367;break g}}}}while(0);va=(Gb*257|0)&65535;b[f+5632+(Fb*40|0)+12>>1]=va;b[f+5632+(Fb*40|0)+20>>1]=va;b[f+5632+(Fb*40|0)+28>>1]=va;b[f+5632+(Fb*40|0)+36>>1]=va;do{if((ua&4096<<(ja|1)|0)==0){Ib=255}else{va=c[q>>2]|0;if((va|0)==2){T=c[v>>2]|0;S=d[(c[ha>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[v>>2]=T+1;Ib=S&1^1;break}else if((va|0)==1){Ib=0;break}else{S=c[v>>2]|0;T=(c[ha>>2]|0)+(S>>>3)|0;oa=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(S&7)>>>23;c[v>>2]=(d[1382088+oa|0]|0)+S;S=d[1276064+oa|0]|0;if(S>>>0<va>>>0){Ib=S;break}else{Hb=S;V=367;break g}}}}while(0);q=(Ib*257|0)&65535;b[f+5632+(Fb*40|0)+14>>1]=q;b[f+5632+(Fb*40|0)+22>>1]=q;b[f+5632+(Fb*40|0)+30>>1]=q;b[f+5632+(Fb*40|0)+38>>1]=q;Fb=Fb+1|0;Jb=c[ra>>2]|0;}while(Fb>>>0<Jb>>>0);if((V|0)==367){KIb(c[f>>2]|0,16,2173456,(ta=i,i=i+8|0,c[ta>>2]=Hb,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((Jb|0)==0){Da=o;break}ma=f+2524|0;q=f+4872|0;ja=f+4852|0;S=f+6100|0;va=f+6108|0;oa=0;while(1){T=oa<<1;U=f+5632+(oa*40|0)+11|0;Z=f+5312+(oa*160|0)+44|0;ga=f+5312+(oa*160|0)+46|0;D=f+5312+(oa*160|0)+40|0;Y=D|0;la=D;D=12288<<T;$=f+5312+(oa*160|0)+42|0;h=f+5632+(oa*40|0)+8|0;_=f+5312+(oa*160|0)+20|0;ia=f+5632+(oa*40|0)+5|0;na=f+5312+(oa*160|0)+32|0;A=0;do{if((ua&4096<<A+T|0)==0){Kb=0;Lb=(A<<1)+12|0}else{aa=A<<2;B=(A<<1)+12|0;X=a[f+5632+(oa*40|0)+B|0]|0;F=X<<24>>24;do{if((aa|0)==0){if(!((a[U]|0)==X<<24>>24)){V=379;break}Mb=b[ga>>1]|0;Nb=b[Z>>1]|0}else{ba=a[h]|0;if(ba<<24>>24==-2){Ob=a[ia]|0;Pb=_}else{Ob=ba;Pb=na}if(!(Ob<<24>>24==X<<24>>24)){V=379;break}Mb=b[Pb+2>>1]|0;Nb=b[Pb>>1]|0}}while(0);do{if((V|0)==379){V=0;K=a[602216+aa|0]|0;ba=K&255;G=ba-8|0;H=a[f+5632+(oa*40|0)+G|0]|0;P=ba-1|0;fa=a[f+5632+(oa*40|0)+P|0]|0;da=f+5312+(oa*160|0)+(P<<2)|0;I=f+5312+(oa*160|0)+(G<<2)|0;Q=ba-6|0;J=a[f+5632+(oa*40|0)+Q|0]|0;R=J<<24>>24;ea=J<<24>>24==-2;do{if((c[j>>2]|0)!=0&ea&(K&255)>>>0>19>>>0&(ba&7|0)==4){if((a[U]|0)==-2){V=388;break}J=c[ma>>2]|0;E=c[J+1536>>2]|0;c[la>>2]=0;M=(c[q>>2]&128|0)==0;if((c[sa>>2]|0)==0){if(M){V=388;break}sb=c[w>>2]|0;O=sb+(c[ja>>2]|0)|0;vb=(c[u>>2]<<1&2)+(ba>>>5)|0;if((c[E+((ca(vb>>>2,sb)|0)+O<<2)>>2]&D|0)==0){Qb=-1;Rb=Y;break}sb=(c[(c[S>>2]|0)+(O<<2)>>2]|0)+3+(ca(c[va>>2]|0,vb)|0)|0;Sb=c[J+1524+(oa<<2)>>2]|0;b[Y>>1]=b[Sb+(sb<<2)>>1]|0;b[$>>1]=b[Sb+(sb<<2)+2>>1]<<1;Qb=a[(c[J+1556+(oa<<2)>>2]|0)+((vb&2147483646)+(O<<2|1))|0]>>1;Rb=Y;break}else{if(!M){V=388;break}M=c[f+4852+(((K&255)>>>0>35>>>0)<<2)>>2]|0;O=ba>>>2;if((c[E+(M<<2)>>2]&D|0)==0){Qb=-1;Rb=Y;break}E=(c[(c[S>>2]|0)+(M<<2)>>2]|0)+3+(ca(c[va>>2]|0,O&3)|0)|0;vb=c[J+1524+(oa<<2)>>2]|0;b[Y>>1]=b[vb+(E<<2)>>1]|0;b[$>>1]=(b[vb+(E<<2)+2>>1]|0)/2|0;Qb=a[(c[J+1556+(oa<<2)>>2]|0)+(O&2|M<<2|1)|0]<<1;Rb=Y;break}}else{V=388}}while(0);do{if((V|0)==388){V=0;if(ea){K=ba-9|0;Qb=a[f+5632+(oa*40|0)+K|0]|0;Rb=f+5312+(oa*160|0)+(K<<2)|0;break}else{Qb=R;Rb=f+5312+(oa*160|0)+(Q<<2)|0;break}}}while(0);Q=H<<24>>24==X<<24>>24;R=fa<<24>>24==X<<24>>24;ba=(R&1)+(Q&1)+((Qb|0)==(F|0))|0;if((ba|0)>1){ea=b[da>>1]|0;K=ea<<16>>16;N=b[I>>1]|0;C=N<<16>>16;M=b[Rb>>1]|0;O=M<<16>>16;do{if(ea<<16>>16>N<<16>>16){if(!(M<<16>>16>N<<16>>16)){Tb=C;break}Tb=(O|0)>(K|0)?K:O}else{if(!(N<<16>>16>M<<16>>16)){Tb=C;break}Tb=(O|0)>(K|0)?O:K}}while(0);K=b[f+5312+(oa*160|0)+(P<<2)+2>>1]|0;O=K<<16>>16;C=b[f+5312+(oa*160|0)+(G<<2)+2>>1]|0;M=C<<16>>16;N=b[Rb+2>>1]|0;ea=N<<16>>16;if(K<<16>>16>C<<16>>16){if(!(N<<16>>16>C<<16>>16)){Mb=M;Nb=Tb;break}Mb=(ea|0)>(O|0)?O:ea;Nb=Tb;break}else{if(!(C<<16>>16>N<<16>>16)){Mb=M;Nb=Tb;break}Mb=(ea|0)>(O|0)?ea:O;Nb=Tb;break}}if((ba|0)==1){if(R){Mb=b[f+5312+(oa*160|0)+(P<<2)+2>>1]|0;Nb=b[da>>1]|0;break}if(Q){Mb=b[f+5312+(oa*160|0)+(G<<2)+2>>1]|0;Nb=b[I>>1]|0;break}else{Mb=b[Rb+2>>1]|0;Nb=b[Rb>>1]|0;break}}O=b[da>>1]|0;ea=O<<16>>16;if(!((Qb|0)!=-2|H<<24>>24!=-2|fa<<24>>24==-2)){Mb=b[f+5312+(oa*160|0)+(P<<2)+2>>1]|0;Nb=ea;break}M=b[I>>1]|0;N=M<<16>>16;C=b[Rb>>1]|0;K=C<<16>>16;do{if(O<<16>>16>M<<16>>16){if(!(C<<16>>16>M<<16>>16)){Ub=N;break}Ub=(K|0)>(ea|0)?ea:K}else{if(!(M<<16>>16>C<<16>>16)){Ub=N;break}Ub=(K|0)>(ea|0)?K:ea}}while(0);ea=b[f+5312+(oa*160|0)+(P<<2)+2>>1]|0;K=ea<<16>>16;N=b[f+5312+(oa*160|0)+(G<<2)+2>>1]|0;C=N<<16>>16;M=b[Rb+2>>1]|0;O=M<<16>>16;if(ea<<16>>16>N<<16>>16){if(!(M<<16>>16>N<<16>>16)){Mb=C;Nb=Ub;break}Mb=(O|0)>(K|0)?K:O;Nb=Ub;break}else{if(!(N<<16>>16>M<<16>>16)){Mb=C;Nb=Ub;break}Mb=(O|0)>(K|0)?O:K;Nb=Ub;break}}}while(0);F=c[v>>2]|0;X=c[ha>>2]|0;aa=X+(F>>>3)|0;K=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(F&7);if(K>>>0>134217727>>>0){aa=K>>>23;O=(d[1382088+aa|0]|0)+F|0;c[v>>2]=O;Vb=a[1306768+aa|0]|0;Wb=O}else{O=K>>>0>65535>>>0;aa=O?K>>>16:K;K=O?16:0;if((aa&65280|0)==0){Xb=K;Yb=aa}else{Xb=K|8;Yb=aa>>>8}aa=(d[1359664+Yb|0]|0)+Xb|0;K=31-aa+F|0;F=X+(K>>>3)|0;O=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(K&7)>>>(aa>>>0);F=32-aa+K|0;c[v>>2]=F;K=O>>>1;Vb=(O&1|0)==0?K:-K|0;Wb=F}F=Vb+Nb|0;K=X+(Wb>>>3)|0;O=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Wb&7);if(O>>>0>134217727>>>0){K=O>>>23;c[v>>2]=(d[1382088+K|0]|0)+Wb;Zb=a[1306768+K|0]|0}else{K=O>>>0>65535>>>0;aa=K?O>>>16:O;O=K?16:0;if((aa&65280|0)==0){_b=O;$b=aa}else{_b=O|8;$b=aa>>>8}aa=(d[1359664+$b|0]|0)+_b|0;O=31-aa+Wb|0;K=X+(O>>>3)|0;X=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(O&7)>>>(aa>>>0);c[v>>2]=32-aa+O;O=X>>>1;Zb=(X&1|0)==0?O:-O|0}Kb=Zb+Mb<<16|F&65535;Lb=B}c[f+5312+(oa*160|0)+(Lb<<2)>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+4>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+32>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+36>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+64>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+68>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+96>>2]=Kb;c[f+5312+(oa*160|0)+(Lb<<2)+100>>2]=Kb;A=A+1|0;}while((A|0)<2);A=oa+1|0;if(A>>>0<(c[ra>>2]|0)>>>0){oa=A}else{Da=o;break}}}else{do{if((ua&1|0)==0){oa=f+4836|0;ra=dha(f,c[oa>>2]|0,0)|0;c[oa>>2]=ra;if((ra|0)<0){ka=-1}else{break}i=g;return ka|0}else{do{if((o|0)==0){ac=1}else{ra=c[v>>2]|0;oa=d[(c[ha>>2]|0)+(ra>>>3)|0]|0;c[v>>2]=ra+1;if((oa&128>>>((ra&7)>>>0)|0)==0){ac=1;break}c[k>>2]=ua|16777216;ac=4}}while(0);ra=(ac|0)==4;oa=0;do{va=d[602216+oa|0]|0;S=a[va-1+(f+4888)|0]|0;ja=a[va-8+(f+4888)|0]|0;q=(S|0)>(ja|0)?ja:S;S=(q|0)<0?2:q;q=c[v>>2]|0;ja=c[ha>>2]|0;ma=d[ja+(q>>>3)|0]|0;A=q+1|0;c[v>>2]=A;if((ma&128>>>((q&7)>>>0)|0)==0){ma=ja+(A>>>3)|0;ja=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(A&7)>>>29;c[v>>2]=q+4;bc=((ja|0)>=(S|0))+ja|0}else{bc=S}if(ra){S=(bc*257|0)&65535;b[f+4888+va>>1]=S;b[va+8+(f+4888)>>1]=S}else{a[f+4888+va|0]=bc}oa=oa+ac|0;}while((oa|0)<16);oa=c[f+4928>>2]|0;ra=c[(c[f+6104>>2]|0)+(c[y>>2]<<2)>>2]|0;c[oa+ra>>2]=c[f+4924>>2];a[oa+(ra+4)|0]=a[f+4919|0]|0;a[oa+(ra+5)|0]=a[f+4911|0]|0;a[oa+(ra+6)|0]=a[f+4903|0]|0;if((cha(f)|0)<0){ka=-1}else{break}i=g;return ka|0}}while(0);if(!r){c[f+4832>>2]=6;Da=o;break}ra=c[v>>2]|0;oa=(c[ha>>2]|0)+(ra>>>3)|0;va=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ra&7)>>>23;c[v>>2]=(d[1382088+va|0]|0)+ra;ra=dha(f,d[1276064+va|0]|0,1)|0;if((ra|0)<0){ka=-1;i=g;return ka|0}else{c[f+4832>>2]=ra;Da=o;break}}}while(0);o=c[k>>2]|0;do{if((o&120|0)!=0){ac=c[f+6108>>2]|0;bc=(ca(ac<<2,c[u>>2]|0)|0)+(c[t>>2]<<2)|0;ua=c[y>>2]<<2;if((o&12288|0)==0){Kb=c[f+4084>>2]|0;b[Kb+ua>>1]=-1;b[Kb+(ua|2)>>1]=-1}else{Kb=c[f+4052>>2]|0;Lb=f+5360|0;Mb=c[Lb+4>>2]|0;Zb=Kb+(bc<<2)|0;c[Zb>>2]=c[Lb>>2];c[Zb+4>>2]=Mb;Mb=f+5368|0;Zb=c[Mb+4>>2]|0;Lb=Kb+((bc|2)<<2)|0;c[Lb>>2]=c[Mb>>2];c[Lb+4>>2]=Zb;Zb=f+5392|0;Lb=c[Zb+4>>2]|0;Mb=bc+ac|0;Wb=Kb+(Mb<<2)|0;c[Wb>>2]=c[Zb>>2];c[Wb+4>>2]=Lb;Lb=f+5400|0;Wb=c[Lb+4>>2]|0;Zb=Kb+(Mb+2<<2)|0;c[Zb>>2]=c[Lb>>2];c[Zb+4>>2]=Wb;Wb=f+5424|0;Zb=c[Wb+4>>2]|0;Lb=bc+(ac<<1)|0;Mb=Kb+(Lb<<2)|0;c[Mb>>2]=c[Wb>>2];c[Mb+4>>2]=Zb;Zb=f+5432|0;Mb=c[Zb+4>>2]|0;Wb=Kb+(Lb+2<<2)|0;c[Wb>>2]=c[Zb>>2];c[Wb+4>>2]=Mb;Mb=f+5456|0;Wb=c[Mb+4>>2]|0;Zb=bc+(ac*3|0)|0;Lb=Kb+(Zb<<2)|0;c[Lb>>2]=c[Mb>>2];c[Lb+4>>2]=Wb;Wb=f+5464|0;Lb=c[Wb+4>>2]|0;Mb=Kb+(Zb+2<<2)|0;c[Mb>>2]=c[Wb>>2];c[Mb+4>>2]=Lb;Lb=c[f+4084>>2]|0;a[Lb+ua|0]=a[f+5644|0]|0;a[Lb+(ua|1)|0]=a[f+5646|0]|0;a[Lb+(ua|2)|0]=a[f+5660|0]|0;a[Lb+(ua|3)|0]=a[f+5662|0]|0}if((o&49152|0)==0){break}Lb=c[f+4056>>2]|0;Mb=f+5520|0;Wb=c[Mb+4>>2]|0;Zb=Lb+(bc<<2)|0;c[Zb>>2]=c[Mb>>2];c[Zb+4>>2]=Wb;Wb=f+5528|0;Zb=c[Wb+4>>2]|0;Mb=Lb+((bc|2)<<2)|0;c[Mb>>2]=c[Wb>>2];c[Mb+4>>2]=Zb;Zb=f+5552|0;Mb=c[Zb+4>>2]|0;Wb=bc+ac|0;Kb=Lb+(Wb<<2)|0;c[Kb>>2]=c[Zb>>2];c[Kb+4>>2]=Mb;Mb=f+5560|0;Kb=c[Mb+4>>2]|0;Zb=Lb+(Wb+2<<2)|0;c[Zb>>2]=c[Mb>>2];c[Zb+4>>2]=Kb;Kb=f+5584|0;Zb=c[Kb+4>>2]|0;Mb=bc+(ac<<1)|0;Wb=Lb+(Mb<<2)|0;c[Wb>>2]=c[Kb>>2];c[Wb+4>>2]=Zb;Zb=f+5592|0;Wb=c[Zb+4>>2]|0;Kb=Lb+(Mb+2<<2)|0;c[Kb>>2]=c[Zb>>2];c[Kb+4>>2]=Wb;Wb=f+5616|0;Kb=c[Wb+4>>2]|0;Zb=bc+(ac*3|0)|0;ac=Lb+(Zb<<2)|0;c[ac>>2]=c[Wb>>2];c[ac+4>>2]=Kb;Kb=f+5624|0;ac=c[Kb+4>>2]|0;Wb=Lb+(Zb+2<<2)|0;c[Wb>>2]=c[Kb>>2];c[Wb+4>>2]=ac;ac=c[f+4088>>2]|0;a[ac+ua|0]=a[f+5684|0]|0;a[ac+(ua|1)|0]=a[f+5686|0]|0;a[ac+(ua|2)|0]=a[f+5700|0]|0;a[ac+(ua|3)|0]=a[f+5702|0]|0}}while(0);o=c[k>>2]|0;do{if((o&2|0)==0){ua=c[v>>2]|0;ac=(c[ha>>2]|0)+(ua>>>3)|0;Wb=(je(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(ua&7);if(Wb>>>0>134217727>>>0){ac=Wb>>>23;c[v>>2]=(d[1382088+ac|0]|0)+ua;cc=d[1276064+ac|0]|0}else{ac=Wb>>>0>65535>>>0;Kb=ac?Wb>>>16:Wb;Zb=ac?16:0;if((Kb&65280|0)==0){dc=Zb;ec=Kb}else{dc=Zb|8;ec=Kb>>>8}Kb=(d[1359664+ec|0]|0)+dc<<1;c[v>>2]=ua+63-Kb;cc=(Wb>>>((Kb-31|0)>>>0))-1|0}if(r){if(cc>>>0>47>>>0){Kb=c[t>>2]|0;Wb=c[u>>2]|0;KIb(c[f>>2]|0,16,2146016,(ta=i,i=i+24|0,c[ta>>2]=cc,c[ta+8>>2]=Kb,c[ta+16>>2]=Wb,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((o&1|0)==0){fc=d[1147376+cc|0]|0;break}else{fc=d[1147264+cc|0]|0;break}}else{if(cc>>>0>15>>>0){Wb=c[t>>2]|0;Kb=c[u>>2]|0;KIb(c[f>>2]|0,16,2146016,(ta=i,i=i+24|0,c[ta>>2]=cc,c[ta+8>>2]=Wb,c[ta+16>>2]=Kb,ta)|0);i=ta;ka=-1;i=g;return ka|0}if((o&1|0)==0){fc=d[1147312+cc|0]|0;break}else{fc=d[1147200+cc|0]|0;break}}}else{if(!(qa>>>0>15>>>0&(r^1))){fc=qa;break}KIb(c[f>>2]|0,16,2122208,(ta=i,i=i+1|0,i=i+7&-8,c[ta>>2]=0,ta)|0);i=ta;ka=-1094995529;i=g;return ka|0}}while(0);do{if((Da|0)==0){gc=o}else{if((fc&15|0)==0){gc=o;break}if((o&7|0)!=0){gc=o;break}qa=c[v>>2]|0;r=d[(c[ha>>2]|0)+(qa>>>3)|0]<<(qa&7)>>>7;c[v>>2]=qa+1;qa=r<<24&16777216|o;c[k>>2]=qa;gc=qa}}while(0);o=f+426560|0;b[(c[o>>2]|0)+(x<<1)>>1]=fc;c[f+426564>>2]=fc&65535;c[(c[f+4064>>2]|0)+(x<<2)>>2]=gc;gc=c[k>>2]|0;do{if((fc|0)==0){if((gc&2|0)!=0){V=464;break}c[f+5196>>2]=0;c[f+5204>>2]=0;c[f+5212>>2]=0;c[f+5220>>2]=0;c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;hc=f+4792|0}else{V=464}}while(0);h:do{if((V|0)==464){Da=gc&7;qa=f+421176|0;r=c[((Da|0)==0?f+421180|0:qa)>>2]|0;cc=(c[f+7308>>2]|0)*6|0;dc=cc+3|0;ec=f+4792|0;Kb=c[ec>>2]|0;Wb=(Kb|0)!=0;if((gc&128|0)==0){ic=Wb?f+426876|0:f+427164|0;jc=Wb?f+426796|0:f+427084|0}else{ic=Wb?f+427020|0:f+427308|0;jc=Wb?f+426940|0:f+427228|0}Wb=jc|0;ua=c[v>>2]|0;Zb=c[ha>>2]|0;ac=Zb+(ua>>>3)|0;Lb=(je(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(ua&7);if(Lb>>>0>134217727>>>0){ac=Lb>>>23;c[v>>2]=(d[1382088+ac|0]|0)+ua;kc=a[1306768+ac|0]|0}else{ac=Lb>>>0>65535>>>0;bc=ac?Lb>>>16:Lb;Lb=ac?16:0;if((bc&65280|0)==0){lc=Lb;mc=bc}else{lc=Lb|8;mc=bc>>>8}bc=(d[1359664+mc|0]|0)+lc|0;Lb=31-bc+ua|0;ua=Zb+(Lb>>>3)|0;Zb=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(Lb&7)>>>(bc>>>0);c[v>>2]=32-bc+Lb;Lb=Zb>>>1;kc=(Zb&1|0)==0?Lb:-Lb|0}Lb=Kb+kc|0;c[ec>>2]=Lb;do{if(Lb>>>0>dc>>>0){Kb=((Lb|0)<0?cc+4|0:-4-cc|0)+Lb|0;c[ec>>2]=Kb;if(!(Kb>>>0>dc>>>0)){nc=Kb;break}Kb=c[t>>2]|0;Zb=c[u>>2]|0;KIb(c[f>>2]|0,16,2639928,(ta=i,i=i+24|0,c[ta>>2]=kc,c[ta+8>>2]=Kb,c[ta+16>>2]=Zb,ta)|0);i=ta;ka=-1;i=g;return ka|0}else{nc=Lb}}while(0);Lb=f+4756|0;c[Lb>>2]=d[f+7876+nc|0]|0;dc=f+4760|0;c[dc>>2]=d[f+7964+nc|0]|0;i:do{if((gc&2|0)==0){cc=(Da|0)!=0?0:3;Zb=f+177044+(cc<<2)|0;Kb=f+177020+(cc<<2)|0;j:do{if((gc&16777216|0)==0){cc=0;bc=0;while(1){ua=bc<<2;if((1<<bc&fc|0)==0){ac=d[602216+ua|0]|0;a[ac+9+(f+5184)|0]=0;a[ac+8+(f+5184)|0]=0;a[ac+1+(f+5184)|0]=0;a[f+5184+ac|0]=0;oc=cc}else{if((jia(f,r,f+421200+(bc<<6<<s<<1)|0,ua,Wb,(c[Kb>>2]|0)+(nc<<6)|0,16)|0)<0){ka=-1;V=579;break}ac=a[(d[602216+ua|0]|0)+(f+5184)|0]|0;Mb=ua|1;if((jia(f,r,f+421200+(Mb<<4<<s<<1)|0,Mb,Wb,(c[Kb>>2]|0)+(nc<<6)|0,16)|0)<0){ka=-1;V=579;break}_b=a[(d[602216+Mb|0]|0)+(f+5184)|0]|0;Mb=ua|2;if((jia(f,r,f+421200+(Mb<<4<<s<<1)|0,Mb,Wb,(c[Kb>>2]|0)+(nc<<6)|0,16)|0)<0){ka=-1;V=579;break}$b=a[(d[602216+Mb|0]|0)+(f+5184)|0]|0;Mb=ua|3;if((jia(f,r,f+421200+(Mb<<4<<s<<1)|0,Mb,Wb,(c[Kb>>2]|0)+(nc<<6)|0,16)|0)<0){ka=-1;V=579;break}oc=(ac&255)<<bc|cc|(_b&255)<<bc|($b&255)<<bc|d[(d[602216+Mb|0]|0)+(f+5184)|0]<<bc}Mb=bc+1|0;if((Mb|0)<4){cc=oc;bc=Mb}else{pc=oc;break j}}if((V|0)==579){i=g;return ka|0}}else{bc=0;cc=0;k:while(1){if((1<<cc&fc|0)==0){B=d[602216+(cc<<2)|0]|0;a[B+9+(f+5184)|0]=0;a[B+8+(f+5184)|0]=0;a[B+1+(f+5184)|0]=0;a[f+5184+B|0]=0;qc=bc}else{B=f+421200+(cc<<6<<s<<1)|0;Mb=cc<<2;$b=0;while(1){if(($b|0)>=4){break}if((jia(f,r,B,$b+Mb|0,ic+($b<<4)|0,(c[Zb>>2]|0)+(nc<<8)|0,16)|0)<0){ka=-1;break k}else{$b=$b+1|0}}$b=d[602216+Mb|0]|0;B=f+5184+$b|0;G=(((a[$b+8+(f+5184)|0]|0)+(a[$b+1+(f+5184)|0]|0)&255)+(a[$b+9+(f+5184)|0]|0)&255)+(a[B]|0)&255;a[B]=G;qc=(G<<24>>24!=0)<<cc|bc}G=cc+1|0;if((G|0)<4){bc=qc;cc=G}else{pc=qc;break j}}i=g;return ka|0}}while(0);if((pc|0)<0){ka=-1}else{rc=pc;break}i=g;return ka|0}else{Zb=f+424272|0;mrc(Zb|0,0,64)|0;if((jia(f,c[qa>>2]|0,Zb,48,Wb,0,16)|0)<0){ka=-1;i=g;return ka|0}if((fc&15|0)==0){c[f+5196>>2]=0;c[f+5204>>2]=0;c[f+5212>>2]=0;c[f+5220>>2]=0;rc=0;break}Zb=jc+1|0;Kb=f+177020|0;cc=0;while(1){if((cc|0)>=4){sc=0;break}if((jia(f,c[qa>>2]|0,f+421200+(cc<<4<<s<<1)|0,cc,Zb,(c[Kb>>2]|0)+(nc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{cc=cc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((sc|0)>=4){tc=0;break}cc=sc+4|0;if((jia(f,c[qa>>2]|0,f+421200+(cc<<4<<s<<1)|0,cc,Zb,(c[Kb>>2]|0)+(nc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{sc=sc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((tc|0)>=4){uc=0;break}cc=tc+8|0;if((jia(f,c[qa>>2]|0,f+421200+(cc<<4<<s<<1)|0,cc,Zb,(c[Kb>>2]|0)+(nc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{tc=tc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((uc|0)>=4){rc=15;break i}cc=uc+12|0;if((jia(f,c[qa>>2]|0,f+421200+(cc<<4<<s<<1)|0,cc,Zb,(c[Kb>>2]|0)+(nc<<6)|0,15)|0)<0){ka=-1;break}else{uc=uc+1|0}}i=g;return ka|0}}while(0);Da=(c[o>>2]|0)+(x<<1)|0;b[Da>>1]=e[Da>>1]|rc<<12;Da=c[p>>2]|0;if((Da|0)!=3){l:do{if((fc&48|0)!=0){Kb=Da<<2;Zb=0;while(1){if((Zb|0)>=2){break l}if((jia(f,r,f+421200+((Zb<<8)+256<<s<<1)|0,Zb+49|0,(c[p>>2]|0)==2?1706560:1706352,0,Kb)|0)<0){ka=-1;break}else{Zb=Zb+1|0}}i=g;return ka|0}}while(0);if((fc&32|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;hc=ec;break}Zb=jc+1|0;Kb=16<<s;if((Da|0)<=0){hc=ec;break}cc=(c[f+177020+(((c[k>>2]&7|0)!=0?1:4)<<2)>>2]|0)+(c[Lb>>2]<<6)|0;bc=0;G=f+421200+(256<<s<<1)|0;while(1){B=bc<<3;if((jia(f,r,G,B+16|0,Zb,cc,15)|0)<0){ka=-1;V=579;break}if((jia(f,r,G+(Kb<<1)|0,B+17|0,Zb,cc,15)|0)<0){ka=-1;V=579;break}$b=Kb<<1;if((jia(f,r,G+($b<<1)|0,B+18|0,Zb,cc,15)|0)<0){ka=-1;V=579;break}P=$b+Kb|0;if((jia(f,r,G+(P<<1)|0,B+19|0,Zb,cc,15)|0)<0){ka=-1;V=579;break}B=bc+1|0;if((B|0)<(Da|0)){bc=B;G=G+(P+Kb<<1)|0}else{V=597;break}}if((V|0)==579){i=g;return ka|0}else if((V|0)==597){G=(c[f+177020+(((c[k>>2]&7|0)!=0?2:5)<<2)>>2]|0)+(c[dc>>2]<<6)|0;bc=0;cc=f+421200+(512<<s<<1)|0;while(1){P=bc<<3;if((jia(f,r,cc,P+32|0,Zb,G,15)|0)<0){ka=-1;V=579;break}if((jia(f,r,cc+(Kb<<1)|0,P+33|0,Zb,G,15)|0)<0){ka=-1;V=579;break}B=Kb<<1;if((jia(f,r,cc+(B<<1)|0,P+34|0,Zb,G,15)|0)<0){ka=-1;V=579;break}$b=B+Kb|0;if((jia(f,r,cc+($b<<1)|0,P+35|0,Zb,G,15)|0)<0){ka=-1;V=579;break}P=bc+1|0;if((P|0)<(Da|0)){bc=P;cc=cc+($b+Kb<<1)|0}else{hc=ec;break h}}if((V|0)==579){i=g;return ka|0}}}Kb=c[k>>2]|0;cc=c[Lb>>2]|0;m:do{if((Kb&2|0)==0){bc=(Kb&7|0)!=0?1:4;Da=f+177044+(bc<<2)|0;G=f+177020+(bc<<2)|0;n:do{if((Kb&16777216|0)==0){bc=0;Zb=0;while(1){$b=(Zb<<2)+16|0;if((1<<Zb&fc|0)==0){P=d[602216+$b|0]|0;a[P+9+(f+5184)|0]=0;a[P+8+(f+5184)|0]=0;a[P+1+(f+5184)|0]=0;a[f+5184+P|0]=0;vc=bc}else{if((jia(f,r,f+421200+($b<<4<<s<<1)|0,$b,Wb,(c[G>>2]|0)+(cc<<6)|0,16)|0)<0){ka=-1;V=579;break}P=a[(d[602216+$b|0]|0)+(f+5184)|0]|0;B=$b|1;if((jia(f,r,f+421200+(B<<4<<s<<1)|0,B,Wb,(c[G>>2]|0)+(cc<<6)|0,16)|0)<0){ka=-1;V=579;break}_b=a[(d[602216+B|0]|0)+(f+5184)|0]|0;B=$b|2;if((jia(f,r,f+421200+(B<<4<<s<<1)|0,B,Wb,(c[G>>2]|0)+(cc<<6)|0,16)|0)<0){ka=-1;V=579;break}ac=a[(d[602216+B|0]|0)+(f+5184)|0]|0;B=$b|3;if((jia(f,r,f+421200+(B<<4<<s<<1)|0,B,Wb,(c[G>>2]|0)+(cc<<6)|0,16)|0)<0){ka=-1;V=579;break}vc=(P&255)<<Zb|bc|(_b&255)<<Zb|(ac&255)<<Zb|d[(d[602216+B|0]|0)+(f+5184)|0]<<Zb}B=Zb+1|0;if((B|0)<4){bc=vc;Zb=B}else{wc=vc;break n}}if((V|0)==579){i=g;return ka|0}}else{Zb=0;bc=0;o:while(1){if((1<<bc&fc|0)==0){B=d[(bc<<2)+602232|0]|0;a[B+9+(f+5184)|0]=0;a[B+8+(f+5184)|0]=0;a[B+1+(f+5184)|0]=0;a[f+5184+B|0]=0;xc=Zb}else{B=f+421200+((bc<<6)+256<<s<<1)|0;ac=(bc<<2)+16|0;_b=0;while(1){if((_b|0)>=4){break}if((jia(f,r,B,_b+ac|0,ic+(_b<<4)|0,(c[Da>>2]|0)+(cc<<8)|0,16)|0)<0){ka=-1;break o}else{_b=_b+1|0}}_b=d[602216+ac|0]|0;B=f+5184+_b|0;Mb=(((a[_b+8+(f+5184)|0]|0)+(a[_b+1+(f+5184)|0]|0)&255)+(a[_b+9+(f+5184)|0]|0)&255)+(a[B]|0)&255;a[B]=Mb;xc=(Mb<<24>>24!=0)<<bc|Zb}Mb=bc+1|0;if((Mb|0)<4){Zb=xc;bc=Mb}else{wc=xc;break n}}i=g;return ka|0}}while(0);if((wc|0)<0){ka=-1}else{break}i=g;return ka|0}else{Da=f+424336|0;mrc(Da|0,0,64)|0;if((jia(f,c[qa>>2]|0,Da,49,Wb,0,16)|0)<0){ka=-1;i=g;return ka|0}if((fc&15|0)==0){c[f+5236>>2]=0;c[f+5244>>2]=0;c[f+5252>>2]=0;c[f+5260>>2]=0;break}Da=jc+1|0;G=f+177024|0;bc=0;while(1){if((bc|0)>=4){yc=0;break}Zb=bc+16|0;if((jia(f,c[qa>>2]|0,f+421200+(Zb<<4<<s<<1)|0,Zb,Da,(c[G>>2]|0)+(cc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{bc=bc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((yc|0)>=4){zc=0;break}bc=yc+20|0;if((jia(f,c[qa>>2]|0,f+421200+(bc<<4<<s<<1)|0,bc,Da,(c[G>>2]|0)+(cc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{yc=yc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((zc|0)>=4){Ac=0;break}bc=zc+24|0;if((jia(f,c[qa>>2]|0,f+421200+(bc<<4<<s<<1)|0,bc,Da,(c[G>>2]|0)+(cc<<6)|0,15)|0)<0){ka=-1;V=579;break}else{zc=zc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((Ac|0)>=4){break m}bc=Ac+28|0;if((jia(f,c[qa>>2]|0,f+421200+(bc<<4<<s<<1)|0,bc,Da,(c[G>>2]|0)+(cc<<6)|0,15)|0)<0){ka=-1;break}else{Ac=Ac+1|0}}i=g;return ka|0}}while(0);cc=c[k>>2]|0;Kb=c[dc>>2]|0;if((cc&2|0)!=0){Lb=f+424400|0;mrc(Lb|0,0,64)|0;if((jia(f,c[qa>>2]|0,Lb,50,Wb,0,16)|0)<0){ka=-1;i=g;return ka|0}if((fc&15|0)==0){c[f+5276>>2]=0;c[f+5284>>2]=0;c[f+5292>>2]=0;c[f+5300>>2]=0;hc=ec;break}Lb=jc+1|0;G=f+177028|0;Da=0;while(1){if((Da|0)>=4){Bc=0;break}bc=Da+32|0;if((jia(f,c[qa>>2]|0,f+421200+(bc<<4<<s<<1)|0,bc,Lb,(c[G>>2]|0)+(Kb<<6)|0,15)|0)<0){ka=-1;V=579;break}else{Da=Da+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((Bc|0)>=4){Cc=0;break}Da=Bc+36|0;if((jia(f,c[qa>>2]|0,f+421200+(Da<<4<<s<<1)|0,Da,Lb,(c[G>>2]|0)+(Kb<<6)|0,15)|0)<0){ka=-1;V=579;break}else{Bc=Bc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((Cc|0)>=4){Dc=0;break}Da=Cc+40|0;if((jia(f,c[qa>>2]|0,f+421200+(Da<<4<<s<<1)|0,Da,Lb,(c[G>>2]|0)+(Kb<<6)|0,15)|0)<0){ka=-1;V=579;break}else{Cc=Cc+1|0}}if((V|0)==579){i=g;return ka|0}while(1){if((Dc|0)>=4){hc=ec;break h}Da=Dc+44|0;if((jia(f,c[qa>>2]|0,f+421200+(Da<<4<<s<<1)|0,Da,Lb,(c[G>>2]|0)+(Kb<<6)|0,15)|0)<0){ka=-1;break}else{Dc=Dc+1|0}}i=g;return ka|0}G=(cc&7|0)!=0?2:5;Lb=f+177044+(G<<2)|0;qa=f+177020+(G<<2)|0;p:do{if((cc&16777216|0)==0){G=0;Da=0;while(1){dc=(Da<<2)+32|0;if((1<<Da&fc|0)==0){bc=d[602216+dc|0]|0;a[bc+9+(f+5184)|0]=0;a[bc+8+(f+5184)|0]=0;a[bc+1+(f+5184)|0]=0;a[f+5184+bc|0]=0;Ec=G}else{if((jia(f,r,f+421200+(dc<<4<<s<<1)|0,dc,Wb,(c[qa>>2]|0)+(Kb<<6)|0,16)|0)<0){ka=-1;V=579;break}bc=a[(d[602216+dc|0]|0)+(f+5184)|0]|0;Zb=dc|1;if((jia(f,r,f+421200+(Zb<<4<<s<<1)|0,Zb,Wb,(c[qa>>2]|0)+(Kb<<6)|0,16)|0)<0){ka=-1;V=579;break}Mb=a[(d[602216+Zb|0]|0)+(f+5184)|0]|0;Zb=dc|2;if((jia(f,r,f+421200+(Zb<<4<<s<<1)|0,Zb,Wb,(c[qa>>2]|0)+(Kb<<6)|0,16)|0)<0){ka=-1;V=579;break}B=a[(d[602216+Zb|0]|0)+(f+5184)|0]|0;Zb=dc|3;if((jia(f,r,f+421200+(Zb<<4<<s<<1)|0,Zb,Wb,(c[qa>>2]|0)+(Kb<<6)|0,16)|0)<0){ka=-1;V=579;break}Ec=(bc&255)<<Da|G|(Mb&255)<<Da|(B&255)<<Da|d[(d[602216+Zb|0]|0)+(f+5184)|0]<<Da}Zb=Da+1|0;if((Zb|0)<4){G=Ec;Da=Zb}else{Fc=Ec;break p}}if((V|0)==579){i=g;return ka|0}}else{Da=0;G=0;q:while(1){if((1<<G&fc|0)==0){Zb=d[(G<<2)+602248|0]|0;a[Zb+9+(f+5184)|0]=0;a[Zb+8+(f+5184)|0]=0;a[Zb+1+(f+5184)|0]=0;a[f+5184+Zb|0]=0;Gc=Da}else{Zb=f+421200+((G<<6)+512<<s<<1)|0;B=(G<<2)+32|0;Mb=0;while(1){if((Mb|0)>=4){break}if((jia(f,r,Zb,Mb+B|0,ic+(Mb<<4)|0,(c[Lb>>2]|0)+(Kb<<8)|0,16)|0)<0){ka=-1;break q}else{Mb=Mb+1|0}}Mb=d[602216+B|0]|0;Zb=f+5184+Mb|0;bc=(((a[Mb+8+(f+5184)|0]|0)+(a[Mb+1+(f+5184)|0]|0)&255)+(a[Mb+9+(f+5184)|0]|0)&255)+(a[Zb]|0)&255;a[Zb]=bc;Gc=(bc<<24>>24!=0)<<G|Da}bc=G+1|0;if((bc|0)<4){Da=Gc;G=bc}else{Fc=Gc;break p}}i=g;return ka|0}}while(0);if((Fc|0)<0){ka=-1}else{hc=ec;break}i=g;return ka|0}}while(0);a[(c[f+4040>>2]|0)+x|0]=c[hc>>2];hc=c[y>>2]|0;y=c[f+5304>>2]|0;c[y+(hc*48|0)>>2]=c[f+5196>>2];c[y+(hc*48|0)+4>>2]=c[f+5204>>2];c[y+(hc*48|0)+8>>2]=c[f+5212>>2];c[y+(hc*48|0)+12>>2]=c[f+5220>>2];c[y+(hc*48|0)+16>>2]=c[f+5236>>2];c[y+(hc*48|0)+20>>2]=c[f+5244>>2];c[y+(hc*48|0)+32>>2]=c[f+5276>>2];c[y+(hc*48|0)+36>>2]=c[f+5284>>2];if((c[f+4788>>2]|0)!=0){ka=0;i=g;return ka|0}c[y+(hc*48|0)+24>>2]=c[f+5252>>2];c[y+(hc*48|0)+28>>2]=c[f+5260>>2];c[y+(hc*48|0)+40>>2]=c[f+5292>>2];c[y+(hc*48|0)+44>>2]=c[f+5300>>2];ka=0;i=g;return ka|0}function hia(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[a+427412>>2]|0;f=a+4884|0;c[f>>2]=-1;g=c[a+427404>>2]|0;h=d-(g<<c[a+177092>>2])|0;i=h-1|0;j=h+1|0;k=d-1|0;l=a+4880|0;c[l>>2]=1234656;m=c[a+4064>>2]|0;do{if((c[a+177088>>2]|0)==0){n=i;o=h;p=k;q=k;r=j}else{s=c[m+(k<<2)>>2]&128;t=b&128;if((c[a+427380>>2]&1|0)!=0){if((s|0)==(t|0)){n=i;o=h;p=k;q=k;r=j;break}u=d-g-1|0;if((t|0)==0){c[f>>2]=0;c[l>>2]=1234688;n=g+i|0;o=h;p=u;q=u;r=j;break}else{c[l>>2]=1234752;n=i;o=h;p=u;q=k;r=j;break}}u=(t|0)!=0;if(u){v=(((c[m+(i<<2)>>2]|0)>>>7&1)-1&g)+i|0;w=(((c[m+(h<<2)>>2]|0)>>>7&1)-1&g)+h|0;x=(((c[m+(j<<2)>>2]|0)>>>7&1)-1&g)+j|0}else{v=i;w=h;x=j}if((s|0)==(t|0)){n=v;o=w;p=k;q=k;r=x;break}if(u){c[l>>2]=1234752;n=v;o=w;p=k;q=g+k|0;r=x;break}else{c[l>>2]=1234720;n=v;o=w;p=k;q=k;r=x;break}}}while(0);c[a+4840>>2]=n;c[a+4844>>2]=o;c[a+4848>>2]=r;c[a+4852>>2]=p;c[a+4856>>2]=q;x=a+4860|0;c[x>>2]=c[m+(n<<2)>>2];k=a+4864|0;c[k>>2]=c[m+(o<<2)>>2];w=a+4868|0;c[w>>2]=c[m+(r<<2)>>2];v=a+4872|0;c[v>>2]=c[m+(p<<2)>>2];l=a+4876|0;c[l>>2]=c[m+(q<<2)>>2];q=c[a+177072>>2]|0;m=e[q+(n<<1)>>1]|0;n=c[a+177068>>2]|0;do{if((m|0)==(n|0)){y=m}else{c[x>>2]=0;if((e[q+(o<<1)>>1]|0|0)!=(n|0)){c[k>>2]=0}if((e[q+(p<<1)>>1]|0|0)==(n|0)){y=n;break}c[l>>2]=0;c[v>>2]=0;y=n}}while(0);if((e[q+(r<<1)>>1]|0|0)==(y|0)){return}c[w>>2]=0;return}function iia(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[e+4880>>2]|0;l=c[e+4840>>2]|0;m=c[e+4844>>2]|0;n=c[e+4848>>2]|0;o=c[e+4852>>2]|0;c[h>>2]=o;p=c[e+4856>>2]|0;c[h+4>>2]=p;q=c[e+4860>>2]|0;r=c[e+4864>>2]|0;s=c[e+4868>>2]|0;t=c[e+4872>>2]|0;c[j>>2]=t;u=c[e+4876>>2]|0;c[j+4>>2]=u;a:do{if((f&2048|0)==0){do{if((f&7|0)!=0){v=(c[e+7384>>2]|0)!=0?7:-1;w=e+5172|0;c[w>>2]=65535;x=e+5164|0;c[x>>2]=65535;y=e+5160|0;c[y>>2]=65535;z=e+5168|0;c[z>>2]=61162;A=(v&r|0)!=0;if(A){B=65535;C=60138}else{c[y>>2]=46079;c[x>>2]=13311;c[z>>2]=9962;B=46079;C=8938}x=f&128;do{if((x|0)==(t&128|0)){if((t&v|0)!=0){D=B;break}E=B&57183;c[y>>2]=E;c[w>>2]=24415;D=E}else{if((x|0)==0){if((c[(c[e+4064>>2]|0)+((c[e+427404>>2]|0)+o<<2)>>2]&v|0)!=0){if((t&v|0)!=0){D=B;break}}E=B&57183;c[y>>2]=E;c[w>>2]=24415;D=E;break}if((t&v|0)==0){E=B&57343;c[y>>2]=E;c[w>>2]=24575;F=E;G=24415}else{F=B;G=65375}if((u&v|0)!=0){D=F;break}E=F&65375;c[y>>2]=E;c[w>>2]=G;D=E}}while(0);if((v&q|0)==0){c[y>>2]=D&32767}if((v&s|0)==0){c[z>>2]=C}if((f&1|0)==0){break}if((r&1|0)==0){mrc(e+4892|0,2-(-(A&1^1)&3)&255|0,4)|0;H=e+4928|0;I=e+6104|0}else{w=e+4928|0;x=e+6104|0;c[e+4892>>2]=c[(c[w>>2]|0)+(c[(c[x>>2]|0)+(m<<2)>>2]|0)>>2];H=w;I=x}if((t&1|0)==0){x=2-(-((t&v|0)==0|0)&3)&255;a[e+4907|0]=x;a[e+4899|0]=x}else{x=c[H>>2]|0;w=(c[(c[I>>2]|0)+(o<<2)>>2]|0)+6|0;a[e+4899|0]=a[x+(w-(d[k]|0))|0]|0;a[e+4907|0]=a[x+(w-(d[k+1|0]|0))|0]|0}if((u&1|0)==0){w=2-(-((u&v|0)==0|0)&3)&255;a[e+4923|0]=w;a[e+4915|0]=w;break}else{w=c[H>>2]|0;x=(c[(c[I>>2]|0)+(p<<2)>>2]|0)+6|0;a[e+4915|0]=a[w+(x-(d[k+2|0]|0))|0]|0;a[e+4923|0]=a[w+(x-(d[k+3|0]|0))|0]|0;break}}}while(0);do{if((r|0)==0){c[e+5188>>2]=1077952576;c[e+5228>>2]=1077952576;c[e+5268>>2]=1077952576;J=e+5304|0}else{x=e+5304|0;w=c[x>>2]|0;c[e+5188>>2]=c[w+(m*48|0)+12>>2];if((c[e+4788>>2]|0)==0){c[e+5228>>2]=c[w+(m*48|0)+28>>2];c[e+5268>>2]=c[w+(m*48|0)+44>>2];J=x;break}else{c[e+5228>>2]=c[w+(m*48|0)+20>>2];c[e+5268>>2]=c[w+(m*48|0)+36>>2];J=x;break}}}while(0);x=e+6136|0;w=0;E=t;while(1){do{if((E|0)==0){K=w<<4;a[K+99+(e+5184)|0]=64;a[K+91+(e+5184)|0]=64;a[K+59+(e+5184)|0]=64;a[K+51+(e+5184)|0]=64;a[K+19+(e+5184)|0]=64;a[(K|11)+(e+5184)|0]=64}else{K=c[h+(w<<2)>>2]|0;L=c[J>>2]|0;M=w<<1;N=k+(M+8)|0;O=w<<4;a[(O|11)+(e+5184)|0]=a[(d[N]|0)+(L+(K*48|0))|0]|0;P=k+(M+9)|0;a[O+19+(e+5184)|0]=a[(d[P]|0)+(L+(K*48|0))|0]|0;Q=c[x>>2]|0;if((Q|0)==3){a[O+51+(e+5184)|0]=a[(d[N]|0)+16+(L+(K*48|0))|0]|0;a[O+59+(e+5184)|0]=a[(d[P]|0)+16+(L+(K*48|0))|0]|0;a[O+91+(e+5184)|0]=a[(d[N]|0)+32+(L+(K*48|0))|0]|0;a[O+99+(e+5184)|0]=a[(d[P]|0)+32+(L+(K*48|0))|0]|0;break}else if((Q|0)==2){a[O+51+(e+5184)|0]=a[(d[N]|0)+14+(L+(K*48|0))|0]|0;a[O+59+(e+5184)|0]=a[(d[P]|0)+14+(L+(K*48|0))|0]|0;a[O+91+(e+5184)|0]=a[(d[N]|0)+30+(L+(K*48|0))|0]|0;a[O+99+(e+5184)|0]=a[(d[P]|0)+30+(L+(K*48|0))|0]|0;break}else{P=w<<3;a[P+51+(e+5184)|0]=a[(d[k+(M+12)|0]|0)+(L+(K*48|0))|0]|0;a[P+91+(e+5184)|0]=a[(d[k+(M+13)|0]|0)+(L+(K*48|0))|0]|0;break}}}while(0);v=w+1|0;if((v|0)>=2){break a}w=v;E=c[j+(v<<2)>>2]|0}}}while(0);do{if((f&120|0)==0){if((f&256|0)==0){R=r>>>24;S=R&1;T=t>>>24;U=T&1;V=U+S|0;W=e+5712|0;c[W>>2]=V;i=g;return}if((c[e+197872>>2]|0)!=0){break}R=r>>>24;S=R&1;T=t>>>24;U=T&1;V=U+S|0;W=e+5712|0;c[W>>2]=V;i=g;return}}while(0);j=c[e+6108>>2]|0;J=e+199428|0;if((c[J>>2]|0)==0){R=r>>>24;S=R&1;T=t>>>24;U=T&1;V=U+S|0;W=e+5712|0;c[W>>2]=V;i=g;return}h=(r|0)!=0?-1:-16843010;I=(f&80|0)==0;H=(t|0)!=0?-1:-2;C=e+6100|0;D=o<<2|1;G=(s|0)!=0?-1:-2;F=(q|0)!=0?-1:-2;B=e+4884|0;E=j<<1;w=j+3|0;x=l<<2;v=(f&2304|0)==0;A=e+177088|0;z=e+177092|0;y=(q&128|0)!=0;K=(r&128|0)!=0;L=(s&128|0)==0;M=(t&128|0)==0;P=(u&128|0)==0;O=j*3|0;N=n<<2|2;Q=m<<2;X=Q|2;Y=Q|3;Q=0;do{Z=c[e+4084+(Q<<2)>>2]|0;_=c[e+4052+(Q<<2)>>2]|0;$=12288<<(Q<<1);do{if(($&f|0)!=0){if(($&r|0)==0){mrc(e+5312+(Q*160|0)+16|0,0,16)|0;c[e+5632+(Q*40|0)+4>>2]=h}else{aa=(c[(c[C>>2]|0)+(m<<2)>>2]|0)+O|0;ba=_+(aa<<2)|0;da=c[ba+4>>2]|0;ea=e+5312+(Q*160|0)+16|0;c[ea>>2]=c[ba>>2];c[ea+4>>2]=da;da=_+(aa<<2)+8|0;aa=c[da+4>>2]|0;ea=e+5312+(Q*160|0)+24|0;c[ea>>2]=c[da>>2];c[ea+4>>2]=aa;aa=a[Z+X|0]|0;a[e+5632+(Q*40|0)+5|0]=aa;a[e+5632+(Q*40|0)+4|0]=aa;aa=a[Z+Y|0]|0;a[e+5632+(Q*40|0)+7|0]=aa;a[e+5632+(Q*40|0)+6|0]=aa}aa=(t&$|0)==0;do{if(I){if(aa){c[e+5312+(Q*160|0)+44>>2]=0;a[e+5632+(Q*40|0)+11|0]=H;break}else{c[e+5312+(Q*160|0)+44>>2]=c[_+((c[(c[C>>2]|0)+(o<<2)>>2]|0)+3+(ca(d[k]|0,j)|0)<<2)>>2];a[e+5632+(Q*40|0)+11|0]=a[Z+((a[k]&254)+D)|0]|0;break}}else{if(aa){c[e+5312+(Q*160|0)+44>>2]=0;c[e+5312+(Q*160|0)+76>>2]=0;a[e+5632+(Q*40|0)+19|0]=H;a[e+5632+(Q*40|0)+11|0]=H}else{ea=(c[(c[C>>2]|0)+(o<<2)>>2]|0)+3|0;c[e+5312+(Q*160|0)+44>>2]=c[_+((ca(d[k]|0,j)|0)+ea<<2)>>2];da=k+1|0;c[e+5312+(Q*160|0)+76>>2]=c[_+((ca(d[da]|0,j)|0)+ea<<2)>>2];a[e+5632+(Q*40|0)+11|0]=a[Z+((a[k]&254)+D)|0]|0;a[e+5632+(Q*40|0)+19|0]=a[Z+((a[da]&254)+D)|0]|0}if((u&$|0)==0){c[e+5312+(Q*160|0)+108>>2]=0;c[e+5312+(Q*160|0)+140>>2]=0;da=(u|0)!=0?-1:-2;a[e+5632+(Q*40|0)+35|0]=da;a[e+5632+(Q*40|0)+27|0]=da;break}else{da=(c[(c[C>>2]|0)+(p<<2)>>2]|0)+3|0;ea=p<<2|1;ba=k+2|0;c[e+5312+(Q*160|0)+108>>2]=c[_+((ca(d[ba]|0,j)|0)+da<<2)>>2];fa=k+3|0;c[e+5312+(Q*160|0)+140>>2]=c[_+((ca(d[fa]|0,j)|0)+da<<2)>>2];a[e+5632+(Q*40|0)+27|0]=a[Z+((a[ba]&254)+ea)|0]|0;a[e+5632+(Q*40|0)+35|0]=a[Z+((a[fa]&254)+ea)|0]|0;break}}}while(0);if(($&s|0)==0){c[e+5312+(Q*160|0)+32>>2]=0;a[e+5632+(Q*40|0)+8|0]=G;ga=G}else{c[e+5312+(Q*160|0)+32>>2]=c[_+((c[(c[C>>2]|0)+(n<<2)>>2]|0)+O<<2)>>2];aa=a[Z+N|0]|0;a[e+5632+(Q*40|0)+8|0]=aa;ga=aa}aa=e+5632+(Q*40|0)+6|0;do{if((a[aa]|ga)<<24>>24<0){if(($&q|0)==0){c[e+5312+(Q*160|0)+12>>2]=0;a[e+5632+(Q*40|0)+3|0]=F;break}else{ea=c[B>>2]|0;c[e+5312+(Q*160|0)+12>>2]=c[_+(w+(c[(c[C>>2]|0)+(l<<2)>>2]|0)+(ea&E)<<2)>>2];a[e+5632+(Q*40|0)+3|0]=a[Z+(x|ea&2|1)|0]|0;break}}}while(0);if(v){a[e+5632+(Q*40|0)+30|0]=-2;a[e+5632+(Q*40|0)+14|0]=-2;c[e+5312+(Q*160|0)+56>>2]=0;c[e+5312+(Q*160|0)+120>>2]=0;if((c[A>>2]|0)==0){break}}else{if((c[A>>2]|0)==0){break}}if((c[z>>2]|0)==0){do{if(y){ea=e+5632+(Q*40|0)+3|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+14|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+7|0;a[fa]=a[fa]<<1}}while(0);do{if(K){fa=e+5632+(Q*40|0)+4|0;ea=a[fa]|0;if(ea<<24>>24>-1){a[fa]=ea<<24>>24>>>1;ea=e+5312+(Q*160|0)+18|0;b[ea>>1]=b[ea>>1]<<1;ea=e+426592+(Q*80|0)+9|0;a[ea]=a[ea]<<1}ea=e+5632+(Q*40|0)+5|0;fa=a[ea]|0;if(fa<<24>>24>-1){a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+22|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+11|0;a[fa]=a[fa]<<1}fa=a[aa]|0;if(fa<<24>>24>-1){a[aa]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+26|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+13|0;a[fa]=a[fa]<<1}fa=e+5632+(Q*40|0)+7|0;ea=a[fa]|0;if(!(ea<<24>>24>-1)){break}a[fa]=ea<<24>>24>>>1;ea=e+5312+(Q*160|0)+30|0;b[ea>>1]=b[ea>>1]<<1;ea=e+426592+(Q*80|0)+15|0;a[ea]=a[ea]<<1}}while(0);do{if(!L){ea=e+5632+(Q*40|0)+8|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+34|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+17|0;a[fa]=a[fa]<<1}}while(0);do{if(!M){fa=e+5632+(Q*40|0)+11|0;ea=a[fa]|0;if(ea<<24>>24>-1){a[fa]=ea<<24>>24>>>1;ea=e+5312+(Q*160|0)+46|0;b[ea>>1]=b[ea>>1]<<1;ea=e+426592+(Q*80|0)+23|0;a[ea]=a[ea]<<1;if(M){break}}ea=e+5632+(Q*40|0)+19|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+78|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+39|0;a[fa]=a[fa]<<1}}while(0);if(P){break}fa=e+5632+(Q*40|0)+27|0;ea=a[fa]|0;if(ea<<24>>24>-1){a[fa]=ea<<24>>24>>>1;ea=e+5312+(Q*160|0)+110|0;b[ea>>1]=b[ea>>1]<<1;ea=e+426592+(Q*80|0)+55|0;a[ea]=a[ea]<<1;if(P){break}}ea=e+5632+(Q*40|0)+35|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<24>>24>>>1;fa=e+5312+(Q*160|0)+142|0;b[fa>>1]=b[fa>>1]<<1;fa=e+426592+(Q*80|0)+71|0;a[fa]=a[fa]<<1;break}else{do{if(!y){fa=e+5632+(Q*40|0)+3|0;ea=a[fa]|0;if(!(ea<<24>>24>-1)){break}a[fa]=ea<<1;ea=e+5312+(Q*160|0)+14|0;b[ea>>1]=(b[ea>>1]|0)/2|0;ea=e+426592+(Q*80|0)+7|0;a[ea]=(d[ea]|0)>>>1}}while(0);do{if(!K){ea=e+5632+(Q*40|0)+4|0;fa=a[ea]|0;if(fa<<24>>24>-1){a[ea]=fa<<1;fa=e+5312+(Q*160|0)+18|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+9|0;a[fa]=(d[fa]|0)>>>1}fa=e+5632+(Q*40|0)+5|0;ea=a[fa]|0;if(ea<<24>>24>-1){a[fa]=ea<<1;ea=e+5312+(Q*160|0)+22|0;b[ea>>1]=(b[ea>>1]|0)/2|0;ea=e+426592+(Q*80|0)+11|0;a[ea]=(d[ea]|0)>>>1}ea=a[aa]|0;if(ea<<24>>24>-1){a[aa]=ea<<1;ea=e+5312+(Q*160|0)+26|0;b[ea>>1]=(b[ea>>1]|0)/2|0;ea=e+426592+(Q*80|0)+13|0;a[ea]=(d[ea]|0)>>>1}ea=e+5632+(Q*40|0)+7|0;fa=a[ea]|0;if(!(fa<<24>>24>-1)){break}a[ea]=fa<<1;fa=e+5312+(Q*160|0)+30|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+15|0;a[fa]=(d[fa]|0)>>>1}}while(0);do{if(L){aa=e+5632+(Q*40|0)+8|0;fa=a[aa]|0;if(!(fa<<24>>24>-1)){break}a[aa]=fa<<1;fa=e+5312+(Q*160|0)+34|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+17|0;a[fa]=(d[fa]|0)>>>1}}while(0);do{if(M){fa=e+5632+(Q*40|0)+11|0;aa=a[fa]|0;if(aa<<24>>24>-1){a[fa]=aa<<1;aa=e+5312+(Q*160|0)+46|0;b[aa>>1]=(b[aa>>1]|0)/2|0;aa=e+426592+(Q*80|0)+23|0;a[aa]=(d[aa]|0)>>>1}aa=e+5632+(Q*40|0)+19|0;fa=a[aa]|0;if(!(fa<<24>>24>-1)){break}a[aa]=fa<<1;fa=e+5312+(Q*160|0)+78|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+39|0;a[fa]=(d[fa]|0)>>>1}}while(0);if(!P){break}fa=e+5632+(Q*40|0)+27|0;aa=a[fa]|0;if(aa<<24>>24>-1){a[fa]=aa<<1;aa=e+5312+(Q*160|0)+110|0;b[aa>>1]=(b[aa>>1]|0)/2|0;aa=e+426592+(Q*80|0)+55|0;a[aa]=(d[aa]|0)>>>1}aa=e+5632+(Q*40|0)+35|0;fa=a[aa]|0;if(!(fa<<24>>24>-1)){break}a[aa]=fa<<1;fa=e+5312+(Q*160|0)+142|0;b[fa>>1]=(b[fa>>1]|0)/2|0;fa=e+426592+(Q*80|0)+71|0;a[fa]=(d[fa]|0)>>>1;break}}}while(0);Q=Q+1|0;}while(Q>>>0<(c[J>>2]|0)>>>0);R=r>>>24;S=R&1;T=t>>>24;U=T&1;V=U+S|0;W=e+5712|0;c[W>>2]=V;i=g;return}function jia(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0;m=i;i=i+64|0;n=m|0;o=(l|0)<9;do{if(o){if((l|0)==4){p=c[2450359]|0;q=f+8|0;r=c[q>>2]|0;s=(c[f>>2]|0)+(r>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>>24;s=b[p+(t<<2)>>1]|0;c[q>>2]=(b[p+(t<<2)+2>>1]|0)+r;u=s;break}else{s=c[2458817]|0;r=f+8|0;t=c[r>>2]|0;p=(c[f>>2]|0)+(t>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(t&7)>>>19;p=b[s+(q<<2)>>1]|0;c[r>>2]=(b[s+(q<<2)+2>>1]|0)+t;u=p;break}}else{if((h|0)>47){p=d[602216+((h<<4)-768)|0]|0;t=(d[p-8+(e+5184)|0]|0)+(d[p-1+(e+5184)|0]|0)|0;if((t|0)<64){v=(t+1|0)>>>1}else{v=t}t=c[9800084+((c[1584776+((v&31)<<2)>>2]|0)*20|0)>>2]|0;p=f+8|0;q=c[p>>2]|0;s=c[f>>2]|0;r=s+(q>>>3)|0;w=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>24;r=b[t+(w<<2)>>1]|0;x=b[t+(w<<2)+2>>1]|0;w=x<<16>>16;if(x<<16>>16<0){x=q+8|0;y=s+(x>>>3)|0;s=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>((w+32|0)>>>0))+r|0;z=b[t+(s<<2)+2>>1]|0;A=x;B=b[t+(s<<2)>>1]|0}else{z=w;A=q;B=r}c[p>>2]=z+A;u=B;break}else{p=d[602216+h|0]|0;r=(d[p-8+(e+5184)|0]|0)+(d[p-1+(e+5184)|0]|0)|0;if((r|0)<64){C=(r+1|0)>>>1}else{C=r}r=c[9800084+((c[1584776+((C&31)<<2)>>2]|0)*20|0)>>2]|0;p=f+8|0;q=c[p>>2]|0;w=c[f>>2]|0;s=w+(q>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(q&7)>>>24;s=b[r+(t<<2)>>1]|0;x=b[r+(t<<2)+2>>1]|0;t=x<<16>>16;if(x<<16>>16<0){x=q+8|0;y=w+(x>>>3)|0;w=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(x&7)>>>((t+32|0)>>>0))+s|0;D=b[r+(w<<2)+2>>1]|0;E=x;F=b[r+(w<<2)>>1]|0}else{D=t;E=q;F=s}c[p>>2]=D+E;u=F;break}}}while(0);F=u>>2;a[(d[602216+h|0]|0)+(e+5184)|0]=F;if((F|0)==0){G=0;i=m;return G|0}if(F>>>0>l>>>0){E=c[e+427380>>2]|0;KIb(c[e>>2]|0,16,2617144,(H=i,i=i+24|0,c[H>>2]=c[e+427376>>2],c[H+8>>2]=E,c[H+16>>2]=F,H)|0);i=H;G=-1;i=m;return G|0}E=u&3;u=c[f>>2]|0;D=f+8|0;f=c[D>>2]|0;C=u+(f>>>3)|0;B=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(f&7);C=B>>>29;A=f+E|0;c[D>>2]=A;f=n|0;c[f>>2]=1-(B>>>30&2);c[n+4>>2]=1-(C&2);c[n+8>>2]=1-(C<<1&2);a:do{if((E|0)<(F|0)){C=(E|0)!=3;B=(F|0)>10&C;z=B&1;v=u+(A>>>3)|0;p=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(A&7)>>>24;v=a[9877400+(z<<9)+(p<<1)|0]|0;s=v<<24>>24;q=A+(a[9877400+(z<<9)+(p<<1)+1|0]|0)|0;c[D>>2]=q;if(v<<24>>24>99){v=s-100|0;if((v|0)==8){p=u+(q>>>3)|0;z=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(q&7);p=z>>>0>65535>>>0;t=p?z>>>16:z;z=p?16:0;if((t&65280|0)==0){I=z;J=t}else{I=z|8;J=t>>>8}t=32-I-(d[1359664+J|0]|0)|0;z=t+q|0;c[D>>2]=z;K=s-101+t|0;L=z}else{K=v;L=q}do{if((K|0)<14){if(!B){M=K;N=L;break}v=d[u+(L>>>3)|0]<<(L&7)>>>7;z=L+1|0;c[D>>2]=z;M=v&1|K<<1;N=z}else{if((K|0)==14){z=u+(L>>>3)|0;if(B){v=d[z]<<(L&7)>>>7;t=L+1|0;c[D>>2]=t;M=v&1|28;N=t;break}else{t=z;z=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(L&7)>>>28;t=L+4|0;c[D>>2]=t;M=z+14|0;N=t;break}}do{if((K|0)>15){if((K|0)<=28){t=K-3|0;O=(1<<t)-4066|0;P=t;break}KIb(c[e>>2]|0,16,2589960,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;G=-1;i=m;return G|0}else{O=30;P=K-3|0}}while(0);t=u+(L>>>3)|0;z=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(L&7)>>>((35-K|0)>>>0);t=P+L|0;c[D>>2]=t;M=z+O|0;N=t}}while(0);B=C?M+2|0:M;t=B&1;c[n+(E<<2)>>2]=(B+2>>1^-t)+t;Q=2;R=N}else{t=((s>>31|1)&-(C&1))+s|0;c[n+(E<<2)>>2]=t;Q=(t+3|0)>>>0>6>>>0?2:1;R=q}t=E+1|0;if((t|0)<(F|0)){S=Q;T=t;U=R}else{V=R;break}while(1){t=u+(U>>>3)|0;B=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(U&7)>>>24;t=a[9877400+(S<<9)+(B<<1)|0]|0;z=t<<24>>24;v=U+(a[9877400+(S<<9)+(B<<1)+1|0]|0)|0;c[D>>2]=v;if(t<<24>>24>99){t=z-100|0;if((t|0)==8){B=u+(v>>>3)|0;p=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(v&7);B=p>>>0>65535>>>0;w=B?p>>>16:p;p=B?16:0;if((w&65280|0)==0){W=p;X=w}else{W=p|8;X=w>>>8}w=32-W-(d[1359664+X|0]|0)|0;p=w+v|0;c[D>>2]=p;Y=z-101+w|0;Z=p}else{Y=t;Z=v}if((Y|0)<15){t=u+(Z>>>3)|0;p=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Z&7)>>>((32-S|0)>>>0);t=Z+S|0;c[D>>2]=t;_=p+(Y<<S)|0;$=t}else{t=15<<S;if((Y|0)>15){if((Y|0)>28){break}p=Y-3|0;aa=t-4096+(1<<p)|0;ba=p}else{aa=t;ba=Y-3|0}t=u+(Z>>>3)|0;p=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Z&7)>>>((35-Y|0)>>>0);t=ba+Z|0;c[D>>2]=t;_=p+aa|0;$=t}t=_&1;da=(_+2>>1^-t)+t|0;ea=$}else{da=z;ea=v}c[n+(T<<2)>>2]=da;v=c[1584744+(S<<2)>>2]|0;z=T+1|0;if((z|0)<(F|0)){S=((v+da|0)>>>0>v<<1>>>0)+S|0;T=z;U=ea}else{V=ea;break a}}KIb(c[e>>2]|0,16,2589960,(H=i,i=i+1|0,i=i+7&-8,c[H>>2]=0,H)|0);i=H;G=-1094995529;i=m;return G|0}else{V=A}}while(0);do{if((F|0)==(l|0)){fa=0;ga=V;ha=F-1|0}else{if(!o){A=F-1|0;ea=c[3660924+(A*20|0)>>2]|0;U=u+(V>>>3)|0;T=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(V&7)>>>23;U=b[ea+(T<<2)>>1]|0;S=(b[ea+(T<<2)+2>>1]|0)+V|0;c[D>>2]=S;fa=U;ga=S;ha=A;break}A=F-1|0;if((l|0)==4){S=c[9800348+(A*20|0)>>2]|0;U=u+(V>>>3)|0;T=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(V&7)>>>29;U=b[S+(T<<2)>>1]|0;ea=(b[S+(T<<2)+2>>1]|0)+V|0;c[D>>2]=ea;fa=U;ga=ea;ha=A;break}else{ea=c[9802356+(A*20|0)>>2]|0;U=u+(V>>>3)|0;T=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(V&7)>>>27;U=b[ea+(T<<2)>>1]|0;S=(b[ea+(T<<2)+2>>1]|0)+V|0;c[D>>2]=S;fa=U;ga=S;ha=A;break}}}while(0);V=j+(ha+fa)|0;ha=(h|0)>47;h=c[f>>2]|0;do{if((c[e+4752>>2]|0)==0){if(ha){b[g+(d[V]<<1)>>1]=h;if((F|0)>1&(fa|0)>0){f=1;j=fa;l=V;o=ga;while(1){if((j|0)<7){A=c[5356844+((j-1|0)*20|0)>>2]|0;S=u+(o>>>3)|0;U=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(o&7)>>>29;ia=b[A+(U<<2)>>1]|0;ja=(b[A+(U<<2)+2>>1]|0)+o|0}else{U=c[1339337]|0;A=u+(o>>>3)|0;S=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(o&7)>>>26;A=b[U+(S<<2)>>1]|0;T=b[U+(S<<2)+2>>1]|0;S=T<<16>>16;if(T<<16>>16<0){T=o+6|0;ea=u+(T>>>3)|0;da=((je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(T&7)>>>((S+32|0)>>>0))+A|0;ka=b[U+(da<<2)+2>>1]|0;la=T;ma=b[U+(da<<2)>>1]|0}else{ka=S;la=o;ma=A}ia=ma;ja=ka+la|0}c[D>>2]=ja;A=j-ia|0;S=l+~ia|0;b[g+(d[S]<<1)>>1]=c[n+(f<<2)>>2];da=f+1|0;if((da|0)<(F|0)&(A|0)>0){f=da;j=A;l=S;o=ja}else{na=da;oa=A;pa=S;break}}}else{na=1;oa=fa;pa=V}if((na|0)<(F|0)){qa=na;ra=pa}else{sa=oa;break}while(1){o=ra-1|0;b[g+(d[o]<<1)>>1]=c[n+(qa<<2)>>2];l=qa+1|0;if((l|0)<(F|0)){qa=l;ra=o}else{sa=oa;break}}}else{o=d[V]|0;b[g+(o<<1)>>1]=((ca(c[k+(o<<2)>>2]|0,h)|0)+32|0)>>>6;if((F|0)>1&(fa|0)>0){o=1;l=fa;j=V;f=ga;while(1){if((l|0)<7){S=c[5356844+((l-1|0)*20|0)>>2]|0;A=u+(f>>>3)|0;da=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(f&7)>>>29;ta=b[S+(da<<2)>>1]|0;ua=(b[S+(da<<2)+2>>1]|0)+f|0}else{da=c[1339337]|0;S=u+(f>>>3)|0;A=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(f&7)>>>26;S=b[da+(A<<2)>>1]|0;U=b[da+(A<<2)+2>>1]|0;A=U<<16>>16;if(U<<16>>16<0){U=f+6|0;T=u+(U>>>3)|0;ea=((je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(U&7)>>>((A+32|0)>>>0))+S|0;va=b[da+(ea<<2)+2>>1]|0;wa=U;xa=b[da+(ea<<2)>>1]|0}else{va=A;wa=f;xa=S}ta=xa;ua=va+wa|0}c[D>>2]=ua;S=l-ta|0;A=j+~ta|0;ea=d[A]|0;b[g+(ea<<1)>>1]=((ca(c[k+(ea<<2)>>2]|0,c[n+(o<<2)>>2]|0)|0)+32|0)>>>6;ea=o+1|0;if((ea|0)<(F|0)&(S|0)>0){o=ea;l=S;j=A;f=ua}else{ya=ea;za=S;Aa=A;break}}}else{ya=1;za=fa;Aa=V}if((ya|0)<(F|0)){Ba=ya;Ca=Aa}else{sa=za;break}while(1){f=Ca-1|0;j=d[f]|0;b[g+(j<<1)>>1]=((ca(c[k+(j<<2)>>2]|0,c[n+(Ba<<2)>>2]|0)|0)+32|0)>>>6;j=Ba+1|0;if((j|0)<(F|0)){Ba=j;Ca=f}else{sa=za;break}}}}else{f=d[V]|0;if(ha){j=g;c[j+(f<<2)>>2]=h;if((F|0)>1&(fa|0)>0){l=1;o=fa;A=V;while(1){if((o|0)<7){S=c[5356844+((o-1|0)*20|0)>>2]|0;ea=c[D>>2]|0;da=u+(ea>>>3)|0;U=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ea&7)>>>29;Da=b[S+(U<<2)>>1]|0;Ea=(b[S+(U<<2)+2>>1]|0)+ea|0}else{ea=c[1339337]|0;U=c[D>>2]|0;S=u+(U>>>3)|0;da=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(U&7)>>>26;S=b[ea+(da<<2)>>1]|0;T=b[ea+(da<<2)+2>>1]|0;da=T<<16>>16;if(T<<16>>16<0){T=U+6|0;$=u+(T>>>3)|0;_=((je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(T&7)>>>((da+32|0)>>>0))+S|0;Fa=b[ea+(_<<2)+2>>1]|0;Ga=T;Ha=b[ea+(_<<2)>>1]|0}else{Fa=da;Ga=U;Ha=S}Da=Ha;Ea=Fa+Ga|0}c[D>>2]=Ea;S=o-Da|0;U=A+~Da|0;c[j+(d[U]<<2)>>2]=c[n+(l<<2)>>2];da=l+1|0;if((da|0)<(F|0)&(S|0)>0){l=da;o=S;A=U}else{Ia=da;Ja=S;Ka=U;break}}}else{Ia=1;Ja=fa;Ka=V}if((Ia|0)<(F|0)){La=Ia;Ma=Ka}else{sa=Ja;break}while(1){A=Ma-1|0;c[j+(d[A]<<2)>>2]=c[n+(La<<2)>>2];o=La+1|0;if((o|0)<(F|0)){La=o;Ma=A}else{sa=Ja;break}}}else{j=g;c[j+(f<<2)>>2]=(ca(c[k+(f<<2)>>2]|0,h)|0)+32>>6;if((F|0)>1&(fa|0)>0){A=1;o=fa;l=V;while(1){if((o|0)<7){U=c[5356844+((o-1|0)*20|0)>>2]|0;S=c[D>>2]|0;da=u+(S>>>3)|0;_=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(S&7)>>>29;Na=b[U+(_<<2)>>1]|0;Oa=(b[U+(_<<2)+2>>1]|0)+S|0}else{S=c[1339337]|0;_=c[D>>2]|0;U=u+(_>>>3)|0;da=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(_&7)>>>26;U=b[S+(da<<2)>>1]|0;ea=b[S+(da<<2)+2>>1]|0;da=ea<<16>>16;if(ea<<16>>16<0){ea=_+6|0;T=u+(ea>>>3)|0;$=((je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(ea&7)>>>((da+32|0)>>>0))+U|0;Pa=b[S+($<<2)+2>>1]|0;Qa=ea;Ra=b[S+($<<2)>>1]|0}else{Pa=da;Qa=_;Ra=U}Na=Ra;Oa=Pa+Qa|0}c[D>>2]=Oa;U=o-Na|0;_=l+~Na|0;da=d[_]|0;c[j+(da<<2)>>2]=(ca(c[k+(da<<2)>>2]|0,c[n+(A<<2)>>2]|0)|0)+32>>6;da=A+1|0;if((da|0)<(F|0)&(U|0)>0){A=da;o=U;l=_}else{Sa=da;Ta=U;Ua=_;break}}}else{Sa=1;Ta=fa;Ua=V}if((Sa|0)<(F|0)){Va=Sa;Wa=Ua}else{sa=Ta;break}while(1){l=Wa-1|0;o=d[l]|0;c[j+(o<<2)>>2]=(ca(c[k+(o<<2)>>2]|0,c[n+(Va<<2)>>2]|0)|0)+32>>6;o=Va+1|0;if((o|0)<(F|0)){Va=o;Wa=l}else{sa=Ta;break}}}}}while(0);if((sa|0)>=0){G=0;i=m;return G|0}sa=c[e+427380>>2]|0;KIb(c[e>>2]|0,16,2568216,(H=i,i=i+16|0,c[H>>2]=c[e+427376>>2],c[H+8>>2]=sa,H)|0);i=H;G=-1;i=m;return G|0}function kia(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=a+2524|0;d=c[b>>2]|0;e=c[d+1604+(((c[a+177100>>2]|0)==2)<<2)>>2]|0;f=c[a+307804>>2]|0;g=a+199420|0;do{if((c[a+177088>>2]|0)==0){h=c[g>>2]|0}else{i=c[d+1604>>2]|0;j=c[a+307796>>2]|0;k=c[g>>2]|0;if((k&2147483647|0)==0){l=d;m=k}else{k=0;do{n=k+16|0;o=c[a+199440+(n*2224|0)+1612>>2]|0;p=j-o|0;if((p|0)<-128){q=-128;r=7}else{s=(p|0)>127?127:p;if((s|0)==0){t=256}else{q=s;r=7}}do{if((r|0)==7){r=0;if((c[a+199440+(n*2224|0)+1628>>2]|0)!=0){t=256;break}s=i-o|0;if((s|0)<-128){u=-128}else{u=(s|0)>127?127:s}s=(ca(((((q|0)>-1?q:-q|0)>>1)+16384|0)/(q|0)|0,u)|0)+32>>6;if((s|0)<-1024){t=-1024;break}t=(s|0)>1023?1023:s}}while(0);c[a+198012+(k<<2)>>2]=t;k=k+1|0;v=c[g>>2]|0;}while(k>>>0<v<<1>>>0);l=c[b>>2]|0;m=v}k=c[l+1608>>2]|0;i=c[a+307800>>2]|0;if((m&2147483647|0)==0){h=m;break}else{w=0}while(1){j=w+16|0;o=c[a+199440+(j*2224|0)+1612>>2]|0;n=i-o|0;if((n|0)<-128){x=-128;r=26}else{s=(n|0)>127?127:n;if((s|0)==0){y=256}else{x=s;r=26}}do{if((r|0)==26){r=0;if((c[a+199440+(j*2224|0)+1628>>2]|0)!=0){y=256;break}s=k-o|0;if((s|0)<-128){z=-128}else{z=(s|0)>127?127:s}s=(ca(((((x|0)>-1?x:-x|0)>>1)+16384|0)/(x|0)|0,z)|0)+32>>6;if((s|0)<-1024){y=-1024;break}y=(s|0)>1023?1023:s}}while(0);c[a+198140+((w^1)<<2)>>2]=y;o=w+1|0;j=c[g>>2]|0;if(o>>>0<j<<1>>>0){w=o}else{h=j;break}}}}while(0);w=a+199420|0;if((h|0)==0){return}else{A=0}do{h=c[a+199440+(A*2224|0)+1612>>2]|0;g=f-h|0;if((g|0)<-128){B=-128;r=17}else{y=(g|0)>127?127:g;if((y|0)==0){C=256}else{B=y;r=17}}do{if((r|0)==17){r=0;if((c[a+199440+(A*2224|0)+1628>>2]|0)!=0){C=256;break}y=e-h|0;if((y|0)<-128){D=-128}else{D=(y|0)>127?127:y}y=(ca(((((B|0)>-1?B:-B|0)>>1)+16384|0)/(B|0)|0,D)|0)+32>>6;if((y|0)<-1024){C=-1024;break}C=(y|0)>1023?1023:y}}while(0);c[a+197884+(A<<2)>>2]=C;A=A+1|0;}while(A>>>0<(c[w>>2]|0)>>>0);return}function lia(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+2524|0;d=c[b>>2]|0;e=a+177100|0;f=c[e>>2]&1^1;g=a+308384|0;h=c[g>>2]&1;i=a+199420|0;c[d+2144+(f<<3)>>2]=c[i>>2];if((c[i>>2]|0)!=0){j=0;do{c[d+1632+(f<<8)+(j<<2)>>2]=c[a+199440+(j*2224|0)+2192>>2]&3|c[a+199440+(j*2224|0)+1616>>2]<<2;j=j+1|0;}while(j>>>0<(c[i>>2]|0)>>>0)}i=a+199424|0;c[d+2144+(f<<3)+4>>2]=c[i>>2];if((c[i>>2]|0)!=0){j=0;do{c[d+1632+(f<<8)+128+(j<<2)>>2]=c[a+306192+(j*2224|0)+2192>>2]&3|c[a+306192+(j*2224|0)+1616>>2]<<2;j=j+1|0;}while(j>>>0<(c[i>>2]|0)>>>0)}i=h^1;if((c[e>>2]|0)==3){h=d+2144|0;j=d+2152|0;k=c[h+4>>2]|0;c[j>>2]=c[h>>2];c[j+4>>2]=k;nrc(d+1888|0,d+1632|0,256)|0}k=a+177088|0;c[d+2160>>2]=c[k>>2];d=a+197880|0;c[d>>2]=0;j=c[e>>2]|0;do{if((j|0)==3){e=c[(c[b>>2]|0)+1612>>2]|0;h=(c[a+307796>>2]|0)-e|0;l=(c[a+307800>>2]|0)-e|0;e=(((h|0)>-1?h:-h|0)|0)>=(((l|0)>-1?l:-l|0)|0)|0;c[a+197876>>2]=e;m=e;n=e}else{e=c[g>>2]|0;if((e&j|0)!=0){m=i;n=f;break}if((c[a+308352>>2]|0)!=0){m=i;n=f;break}c[d>>2]=(e<<1)-3;m=i;n=f}}while(0);if((c[a+177080>>2]|0)!=3){return}if((c[a+197872>>2]|0)!=0){return}f=a+198268|0;mia(a,f,0,n,m,0);if((c[k>>2]|0)!=0){mia(a,a+198652|0,0,0,0,1);mia(a,a+199036|0,0,1,1,1)}mia(a,f,1,n,m,0);if((c[k>>2]|0)==0){return}mia(a,a+198652|0,1,0,0,1);mia(a,a+199036|0,1,1,1,1);return}function mia(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=(g|0)!=0;g=h?16:0;i=c[a+199420>>2]|0;if(h){j=1;k=(i<<1)+16|0}else{j=(c[a+177100>>2]|0)!=3;k=i}mrc(b+(d*192|0)|0,0,192)|0;i=a+308336+(f<<3)+(d<<2)|0;l=a+308352|0;m=j^1;n=0;o=c[i>>2]|0;while(1){p=n+1|0;a:do{if((o|0)>0){q=(n|0)==(e|0)|m;r=(n^e)+16|0;if(j){s=0;while(1){t=c[a+307824+(f<<8)+(d<<7)+(s<<2)>>2]|0;if((t&3|0)==3){u=p+(t&-4)|0}else{u=t}t=g;while(1){if((t|0)>=(k|0)){break}if((c[a+199440+(t*2224|0)+2192>>2]&3|c[a+199440+(t*2224|0)+1616>>2]<<2|0)==(u|0)){v=13;break}else{t=t+1|0}}do{if((v|0)==13){v=0;if(h){w=t-16^e}else{w=t}if((c[l>>2]|0)!=0){c[b+(d*192|0)+(r+(s<<1)<<2)>>2]=w}if(!q){break}c[b+(d*192|0)+(s<<2)>>2]=w}}while(0);t=s+1|0;x=c[i>>2]|0;if((t|0)<(x|0)){s=t}else{y=x;break a}}}if(h){s=0;while(1){x=c[a+307824+(f<<8)+(d<<7)+(s<<2)>>2]|3;t=g;while(1){if((t|0)>=(k|0)){break}if((c[a+199440+(t*2224|0)+2192>>2]&3|c[a+199440+(t*2224|0)+1616>>2]<<2|0)==(x|0)){v=23;break}else{t=t+1|0}}do{if((v|0)==23){v=0;x=t-16^e;if((c[l>>2]|0)!=0){c[b+(d*192|0)+(r+(s<<1)<<2)>>2]=x}if(!q){break}c[b+(d*192|0)+(s<<2)>>2]=x}}while(0);t=s+1|0;x=c[i>>2]|0;if((t|0)<(x|0)){s=t}else{y=x;break}}}else{s=0;while(1){x=c[a+307824+(f<<8)+(d<<7)+(s<<2)>>2]|3;t=g;while(1){if((t|0)>=(k|0)){break}if((c[a+199440+(t*2224|0)+2192>>2]&3|c[a+199440+(t*2224|0)+1616>>2]<<2|0)==(x|0)){v=31;break}else{t=t+1|0}}do{if((v|0)==31){v=0;if((c[l>>2]|0)!=0){c[b+(d*192|0)+(r+(s<<1)<<2)>>2]=t}if(!q){break}c[b+(d*192|0)+(s<<2)>>2]=t}}while(0);t=s+1|0;x=c[i>>2]|0;if((t|0)<(x|0)){s=t}else{y=x;break}}}}else{y=o}}while(0);if((p|0)<2){n=p;o=y}else{break}}return}function nia(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;if((c[f+197872>>2]|0)==0){m=c[f+6108>>2]|0;n=c[f+427412>>2]|0;o=f+427380|0;p=c[g>>2]|0;q=p&64;r=c[f+307728>>2]|0;s=(p&128|0)!=0;a:do{if((c[r+(n<<2)>>2]&128|0)==0){if(!s){t=2;u=n;v=130;break}w=c[f+427404>>2]|0;x=(ca(w,c[o>>2]&-2)|0)+(c[f+427376>>2]|0)|0;y=c[r+(x<<2)>>2]|0;z=j|0;c[z>>2]=y;A=c[r+(x+w<<2)>>2]|0;B=j+4|0;c[B>>2]=A;C=w<<2|2;w=m*6|0;if(((A^y)&128|0)==0){D=y;E=A}else{F=y&-129;c[z>>2]=F;z=A&-129;c[B>>2]=z;D=F;E=z}do{if((D&15|0)!=0){if(!((E&15|0)!=0&(q|0)==0)){break}z=p|61712;c[g>>2]=z;G=C;H=w;I=x;J=20744;K=D;L=z;break a}}while(0);z=p|61504;c[g>>2]=z;G=C;H=w;I=x;J=20744;K=D;L=z}else{if(s){t=2;u=(ca(c[f+427404>>2]|0,c[f+197880>>2]|0)|0)+n|0;v=130;break}else{t=0;u=(ca(c[f+427404>>2]|0,(c[o>>2]&-2)+(c[f+197876>>2]|0)|0)|0)+(c[f+427376>>2]|0)|0;v=130;break}}}while(0);b:do{if((v|0)==130){n=c[r+(u<<2)>>2]|0;c[j+4>>2]=n;c[j>>2]=n;do{if((q|0)==0){if((n&15|0)!=0){s=p|20744;c[g>>2]=s;G=t;H=m;I=u;J=20744;K=n;L=s;break b}s=n&48;if((s|0)==0){break}D=p|s|61696;c[g>>2]=D;G=t;H=m;I=u;J=20744;K=n;L=D;break b}}while(0);x=(c[f+6196>>2]|0)==0?20800:20744;w=p|61504;c[g>>2]=w;G=t;H=m;I=u;J=x;K=n;L=w}}while(0);u=c[(c[f+6100>>2]|0)+(I<<2)>>2]|0;m=c[f+307716>>2]|0;t=m+(u<<2)|0;p=c[f+307720>>2]|0;r=p+(u<<2)|0;w=I<<2;I=c[f+307748>>2]|0;x=I+w|0;C=c[f+307752>>2]|0;D=C+w|0;do{if((G|0)==0){if((c[o>>2]&1|0)==0){M=t;N=r;O=x;P=D;break}s=w|2;E=u+(H<<1)|0;M=m+(E<<2)|0;N=p+(E<<2)|0;O=I+s|0;P=C+s|0}else{M=t;N=r;O=x;P=D}}while(0);D=f+198268|0;x=f+198460|0;r=f+197884|0;t=L&128;do{if((c[f+177088>>2]|0)==0){Q=x;R=D;S=r;T=t}else{if((t|0)==0){Q=x;R=D;S=r;T=0;break}C=c[o>>2]&1;Q=f+198652+(C*384|0)+192|0;R=f+198652+(C*384|0)|0;S=f+198012+(C<<7)|0;T=t}}while(0);t=c[f+308352>>2]<<4&K>>3;if((T|0)!=(K&128|0)){o=T>>>6^2;T=(q|0)==0;r=J&65535;D=0;do{x=D&1;C=D>>1;I=f+177112+(D<<1)|0;if(T){v=146}else{if(!((b[I>>1]&256)==0)){v=146}}do{if((v|0)==146){v=0;b[I>>1]=r;p=d[602160+(D<<2)|0]|0;b[f+5672+p>>1]=0;m=p+8|0;b[f+5672+m>>1]=0;if((c[j+(C<<2)>>2]&7|0)!=0){b[f+5632+p>>1]=0;b[f+5632+m>>1]=0;c[f+5312+(p<<2)>>2]=0;u=p+1|0;c[f+5312+(u<<2)>>2]=0;c[f+5312+(m<<2)>>2]=0;w=p+9|0;c[f+5312+(w<<2)>>2]=0;c[f+5472+(p<<2)>>2]=0;c[f+5472+(u<<2)>>2]=0;c[f+5472+(m<<2)>>2]=0;c[f+5472+(w<<2)>>2]=0;break}w=(ca(C,G)|0)+x|0;u=a[O+w|0]|0;if(u<<24>>24>-1){U=R+((u<<24>>24)+t<<2)|0;V=M}else{U=Q+((a[P+w|0]|0)+t<<2)|0;V=N}w=c[U>>2]|0;u=c[S+(w<<2)>>2]|0;s=(w*257|0)&65535;b[f+5632+p>>1]=s;b[f+5632+m>>1]=s;s=(-x&3)+(ca(C,H)|0)|0;w=(b[V+(s<<2)+2>>1]<<o|0)/2|0;E=b[V+(s<<2)>>1]|0;s=(ca(E<<16>>16,u)|0)+128>>8;z=(ca(w,u)|0)+128>>8;u=s&65535|z<<16;c[f+5312+(p<<2)>>2]=u;F=p+1|0;c[f+5312+(F<<2)>>2]=u;c[f+5312+(m<<2)>>2]=u;B=p+9|0;c[f+5312+(B<<2)>>2]=u;u=s-(E&65535)&65535|z-w<<16;c[f+5472+(p<<2)>>2]=u;c[f+5472+(F<<2)>>2]=u;c[f+5472+(m<<2)>>2]=u;c[f+5472+(B<<2)>>2]=u}}while(0);D=D+1|0;}while((D|0)<4);i=h;return}if((L&8|0)!=0){c[f+5684>>2]=0;c[f+5692>>2]=0;c[f+5700>>2]=0;c[f+5708>>2]=0;if((K&7|0)==0){L=a[O]|0;D=L<<24>>24>-1;if(D){W=R+((L<<24>>24)+t<<2)|0}else{W=Q+((a[P]|0)+t<<2)|0}L=c[W>>2]|0;W=c[S+(L<<2)>>2]|0;V=D?M:N;D=b[V>>1]|0;o=(ca(D,W)|0)+128>>8;U=b[V+2>>1]|0;V=(ca(U,W)|0)+128>>8;X=V-U<<16|o-D&65535;Y=V<<16|o&65535;Z=ca(L,16843009)|0}else{X=0;Y=0;Z=0}c[f+5644>>2]=Z;c[f+5652>>2]=Z;c[f+5660>>2]=Z;c[f+5668>>2]=Z;c[f+5360>>2]=Y;c[f+5364>>2]=Y;c[f+5368>>2]=Y;c[f+5372>>2]=Y;c[f+5392>>2]=Y;c[f+5396>>2]=Y;c[f+5400>>2]=Y;c[f+5404>>2]=Y;c[f+5424>>2]=Y;c[f+5428>>2]=Y;c[f+5432>>2]=Y;c[f+5436>>2]=Y;c[f+5456>>2]=Y;c[f+5460>>2]=Y;c[f+5464>>2]=Y;c[f+5468>>2]=Y;c[f+5520>>2]=X;c[f+5524>>2]=X;c[f+5528>>2]=X;c[f+5532>>2]=X;c[f+5552>>2]=X;c[f+5556>>2]=X;c[f+5560>>2]=X;c[f+5564>>2]=X;c[f+5584>>2]=X;c[f+5588>>2]=X;c[f+5592>>2]=X;c[f+5596>>2]=X;c[f+5616>>2]=X;c[f+5620>>2]=X;c[f+5624>>2]=X;c[f+5628>>2]=X;i=h;return}X=(q|0)==0;q=J&65535;Y=(K&7|0)==0;K=(J&8|0)==0;J=H*3|0;Z=0;do{L=Z&1;o=Z>>1;V=f+177112+(Z<<1)|0;if(X){v=163}else{if(!((b[V>>1]&256)==0)){v=163}}do{if((v|0)==163){v=0;b[V>>1]=q;D=Z<<2;U=d[602160+D|0]|0;b[f+5672+U>>1]=0;W=U+8|0;b[f+5672+W>>1]=0;if(!Y){b[f+5632+U>>1]=0;b[f+5632+W>>1]=0;c[f+5312+(U<<2)>>2]=0;G=U+1|0;c[f+5312+(G<<2)>>2]=0;c[f+5312+(W<<2)>>2]=0;r=U+9|0;c[f+5312+(r<<2)>>2]=0;c[f+5472+(U<<2)>>2]=0;c[f+5472+(G<<2)>>2]=0;c[f+5472+(W<<2)>>2]=0;c[f+5472+(r<<2)>>2]=0;break}r=a[O+Z|0]|0;if(r<<24>>24>-1){_=M;$=R+((r<<24>>24)+t<<2)|0}else{_=N;$=Q+((a[P+Z|0]|0)+t<<2)|0}r=c[$>>2]|0;G=c[S+(r<<2)>>2]|0;T=(r*257|0)&65535;b[f+5632+U>>1]=T;b[f+5632+W>>1]=T;if(!K){T=(-L&3)+(ca(J,o)|0)|0;r=b[_+(T<<2)>>1]|0;C=(ca(r<<16>>16,G)|0)+128>>8;x=b[_+(T<<2)+2>>1]|0;T=(ca(x<<16>>16,G)|0)+128>>8;I=T<<16|C&65535;c[f+5312+(U<<2)>>2]=I;n=U+1|0;c[f+5312+(n<<2)>>2]=I;c[f+5312+(W<<2)>>2]=I;u=U+9|0;c[f+5312+(u<<2)>>2]=I;I=T-(x&65535)<<16|C-(r&65535)&65535;c[f+5472+(U<<2)>>2]=I;c[f+5472+(n<<2)>>2]=I;c[f+5472+(W<<2)>>2]=I;c[f+5472+(u<<2)>>2]=I;break}I=L<<1;u=o<<1;W=0;do{n=(ca((W>>1)+u|0,H)|0)+(W&1|I)|0;U=_+(n<<2)|0;r=d[602160+(W+D)|0]|0;C=((ca(b[U>>1]|0,G)|0)+128|0)>>>8;b[f+5312+(r<<2)>>1]=C;x=_+(n<<2)+2|0;n=((ca(b[x>>1]|0,G)|0)+128|0)>>>8;b[f+5312+(r<<2)+2>>1]=n;c[f+5472+(r<<2)>>2]=n-(e[x>>1]|0)<<16|C-(e[U>>1]|0)&65535;W=W+1|0;}while((W|0)<4)}}while(0);Z=Z+1|0;}while((Z|0)<4);i=h;return}Z=c[f+6108>>2]|0;_=c[f+427412>>2]|0;H=c[g>>2]|0;J=H&64;K=(J|0)==0;S=0;$=61440;t=H;while(1){H=a[f+5632+(S*40|0)+11|0]|0;P=a[f+5632+(S*40|0)+4|0]|0;Q=a[f+5632+(S*40|0)+8|0]|0;if(Q<<24>>24==-2){aa=a[f+5632+(S*40|0)+3|0]|0;ba=f+5312+(S*160|0)+12|0}else{aa=Q;ba=f+5312+(S*160|0)+32|0}Q=aa<<24>>24;N=H>>>0>P>>>0?P:H;R=N>>>0>Q>>>0?Q:N;N=k+(S<<2)|0;c[N>>2]=R;do{if((R|0)>-1){M=f+5312+(S*160|0)+44|0;O=f+5312+(S*160|0)+16|0;Y=(H|0)==(R|0);q=(P|0)==(R|0);if(((Y&1)+(q&1)+((Q|0)==(R|0))|0)<=1){if(Y){c[l+(S<<2)>>2]=c[M>>2];da=$;ea=t;break}if(q){c[l+(S<<2)>>2]=c[O>>2];da=$;ea=t;break}else{c[l+(S<<2)>>2]=c[ba>>2];da=$;ea=t;break}}q=b[M>>1]|0;M=q<<16>>16;Y=b[O>>1]|0;O=Y<<16>>16;X=b[ba>>1]|0;o=X<<16>>16;do{if(q<<16>>16>Y<<16>>16){if(!(X<<16>>16>Y<<16>>16)){fa=O;break}fa=(o|0)>(M|0)?M:o}else{if(!(Y<<16>>16>X<<16>>16)){fa=O;break}fa=(o|0)>(M|0)?o:M}}while(0);M=b[f+5312+(S*160|0)+46>>1]|0;o=M<<16>>16;O=b[f+5312+(S*160|0)+18>>1]|0;X=O<<16>>16;Y=b[ba+2>>1]|0;q=Y<<16>>16;do{if(M<<16>>16>O<<16>>16){if(!(Y<<16>>16>O<<16>>16)){ga=X;break}ga=(q|0)>(o|0)?o:q}else{if(!(O<<16>>16>Y<<16>>16)){ga=X;break}ga=(q|0)>(o|0)?q:o}}while(0);c[l+(S<<2)>>2]=ga<<16|fa&65535;da=$;ea=t}else{o=~(12288<<(S<<1));c[l+(S<<2)>>2]=0;c[N>>2]=-1;if(K){q=t&o;c[g>>2]=q;ha=q}else{ha=t}da=$&o;ea=ha}}while(0);N=S+1|0;if((N|0)<2){S=N;$=da;t=ea}else{break}}t=f+427380|0;$=k|0;S=c[$>>2]|0;do{if((S|0)<0){ha=k+4|0;if((c[ha>>2]|0)>=0){ia=da;ja=S;ka=ea;break}c[ha>>2]=0;c[$>>2]=0;if(K){ha=ea|61440;c[g>>2]=ha;la=ha}else{la=ea}ia=da|61440;ja=0;ka=la}else{ia=da;ja=S;ka=ea}}while(0);ea=c[l>>2]|0;S=c[l+4>>2]|0;if((ea|J|S|0)==0){J=ca(ja&255,16843009)|0;c[f+5644>>2]=J;c[f+5652>>2]=J;c[f+5660>>2]=J;c[f+5668>>2]=J;J=ca(c[k+4>>2]&255,16843009)|0;c[f+5684>>2]=J;c[f+5692>>2]=J;c[f+5700>>2]=J;c[f+5708>>2]=J;mrc(f+5360|0,0,16)|0;mrc(f+5392|0,0,16)|0;mrc(f+5424|0,0,16)|0;mrc(f+5456|0,0,16)|0;mrc(f+5520|0,0,16)|0;mrc(f+5552|0,0,16)|0;mrc(f+5584|0,0,16)|0;mrc(f+5616|0,0,16)|0;c[g>>2]=c[g>>2]&-41337|264;i=h;return}J=c[f+307728>>2]|0;l=(ka&128|0)!=0;c:do{if((c[J+(_<<2)>>2]&128|0)==0){if(!l){ma=2;na=_;v=45;break}da=c[f+427404>>2]|0;la=(ca(da,c[t>>2]&-2)|0)+(c[f+427376>>2]|0)|0;$=c[J+(la<<2)>>2]|0;ha=j|0;c[ha>>2]=$;fa=c[J+(la+da<<2)>>2]|0;ga=j+4|0;c[ga>>2]=fa;ba=da<<2|2;da=Z*6|0;if(((fa^$)&128|0)==0){oa=$;pa=fa}else{aa=$&-129;c[ha>>2]=aa;ha=fa&-129;c[ga>>2]=ha;oa=aa;pa=ha}ha=ia|264;do{if((oa&15|0)!=0){if(!((pa&15|0)!=0&K)){break}aa=ka|272;c[g>>2]=aa;qa=ba;ra=da;sa=la;ta=ha;ua=aa;va=oa;break c}}while(0);aa=ka|64;c[g>>2]=aa;qa=ba;ra=da;sa=la;ta=ha;ua=aa;va=oa}else{if(l){ma=2;na=(ca(c[f+427404>>2]|0,c[f+197880>>2]|0)|0)+_|0;v=45;break}else{ma=0;na=(ca(c[f+427404>>2]|0,(c[t>>2]&-2)+(c[f+197876>>2]|0)|0)|0)+(c[f+427376>>2]|0)|0;v=45;break}}}while(0);d:do{if((v|0)==45){_=c[J+(na<<2)>>2]|0;c[j+4>>2]=_;c[j>>2]=_;l=ia|264;do{if(K){if((_&15|0)!=0){oa=ka|264;c[g>>2]=oa;qa=ma;ra=Z;sa=na;ta=l;ua=oa;va=_;break d}oa=_&48;if((oa|0)==0){break}pa=ka|oa|256;c[g>>2]=pa;qa=ma;ra=Z;sa=na;ta=l;ua=pa;va=_;break d}}while(0);ha=(c[f+6196>>2]|0)==0?l+56|0:l;la=ka|64;c[g>>2]=la;qa=ma;ra=Z;sa=na;ta=ha;ua=la;va=_}}while(0);na=c[(c[f+6100>>2]|0)+(sa<<2)>>2]|0;Z=c[f+307716>>2]|0;ma=Z+(na<<2)|0;ka=c[f+307720>>2]|0;ia=ka+(na<<2)|0;J=sa<<2;sa=c[f+307748>>2]|0;la=sa+J|0;ha=c[f+307752>>2]|0;da=ha+J|0;do{if((qa|0)==0){if((c[t>>2]&1|0)==0){wa=ma;xa=ia;ya=la;za=da;break}ba=J|2;pa=na+(ra<<1)|0;wa=Z+(pa<<2)|0;xa=ka+(pa<<2)|0;ya=sa+ba|0;za=ha+ba|0}else{wa=ma;xa=ia;ya=la;za=da}}while(0);if(((ua^va)&128|0)!=0){da=ta&65535;la=((ja&255)*257|0)&65535;ia=c[k+4>>2]|0;ma=((ia&255)*257|0)&65535;ha=f+307820|0;sa=(ja|0)>0?ea:0;ka=(ia|0)>0?S:0;ia=0;Z=0;while(1){na=ia&1;J=ia>>1;t=(ca(J,qa)|0)+na|0;ba=(-na&3)+(ca(J,ra)|0)|0;na=f+177112+(ia<<1)|0;if(K){v=58}else{if((b[na>>1]&256)==0){Aa=Z}else{v=58}}if((v|0)==58){v=0;b[na>>1]=da;na=d[602160+(ia<<2)|0]|0;b[f+5632+na>>1]=la;pa=na+8|0;b[f+5632+pa>>1]=la;b[f+5672+na>>1]=ma;b[f+5672+pa>>1]=ma;do{if((c[j+(J<<2)>>2]&7|0)==0){if((c[ha>>2]|0)!=0){Ba=S;Ca=ea;Da=Z;break}oa=a[ya+t|0]|0;if(oa<<24>>24==0){aa=b[wa+(ba<<2)>>1]|0;ga=aa<<16>>16;if(((aa<<16>>16>-1?ga:-ga|0)|0)>=2){Ba=S;Ca=ea;Da=Z;break}ga=b[wa+(ba<<2)+2>>1]|0;aa=ga<<16>>16;if(((ga<<16>>16>-1?aa:-aa|0)|0)>=2){v=63}}else{v=63}if((v|0)==63){v=0;if(!(oa<<24>>24<0)){Ba=S;Ca=ea;Da=Z;break}if((a[za+t|0]|0)!=0){Ba=S;Ca=ea;Da=Z;break}oa=b[xa+(ba<<2)>>1]|0;aa=oa<<16>>16;if(((oa<<16>>16>-1?aa:-aa|0)|0)>=2){Ba=S;Ca=ea;Da=Z;break}aa=b[xa+(ba<<2)+2>>1]|0;oa=aa<<16>>16;if(((aa<<16>>16>-1?oa:-oa|0)|0)>=2){Ba=S;Ca=ea;Da=Z;break}}Ba=ka;Ca=sa;Da=Z+1|0}else{Ba=S;Ca=ea;Da=Z}}while(0);c[f+5312+(na<<2)>>2]=Ca;ba=na+1|0;c[f+5312+(ba<<2)>>2]=Ca;c[f+5312+(pa<<2)>>2]=Ca;t=na+9|0;c[f+5312+(t<<2)>>2]=Ca;c[f+5472+(na<<2)>>2]=Ba;c[f+5472+(ba<<2)>>2]=Ba;c[f+5472+(pa<<2)>>2]=Ba;c[f+5472+(t<<2)>>2]=Ba;Aa=Da}t=ia+1|0;if((t|0)<4){ia=t;Z=Aa}else{break}}if(!K){i=h;return}if((Aa&3|0)!=0){i=h;return}c[g>>2]=c[g>>2]&-41337|264;i=h;return}if((ua&8|0)!=0){ua=ca(ja&255,16843009)|0;c[f+5644>>2]=ua;c[f+5652>>2]=ua;c[f+5660>>2]=ua;c[f+5668>>2]=ua;ua=c[k+4>>2]|0;Aa=ca(ua&255,16843009)|0;c[f+5684>>2]=Aa;c[f+5692>>2]=Aa;c[f+5700>>2]=Aa;c[f+5708>>2]=Aa;do{if((va&7|0)==0){if((c[f+307820>>2]|0)!=0){Ea=S;Fa=ea;break}Aa=a[ya]|0;if(Aa<<24>>24==0){Z=b[wa>>1]|0;ia=Z<<16>>16;if(((Z<<16>>16>-1?ia:-ia|0)|0)>=2){Ea=S;Fa=ea;break}ia=b[wa+2>>1]|0;Z=ia<<16>>16;if(((ia<<16>>16>-1?Z:-Z|0)|0)>=2){v=80}}else{v=80}if((v|0)==80){if(!(Aa<<24>>24<0)){Ea=S;Fa=ea;break}if((a[za]|0)!=0){Ea=S;Fa=ea;break}Aa=b[xa>>1]|0;Z=Aa<<16>>16;if(((Aa<<16>>16>-1?Z:-Z|0)|0)>=2){Ea=S;Fa=ea;break}Z=b[xa+2>>1]|0;Aa=Z<<16>>16;if(((Z<<16>>16>-1?Aa:-Aa|0)|0)>=2){Ea=S;Fa=ea;break}if(!((c[f+427372>>2]|0)>>>0>33>>>0)){Ea=S;Fa=ea;break}}Ea=(ua|0)>0?S:0;Fa=(ja|0)>0?ea:0}else{Ea=S;Fa=ea}}while(0);c[f+5360>>2]=Fa;c[f+5364>>2]=Fa;c[f+5368>>2]=Fa;c[f+5372>>2]=Fa;c[f+5392>>2]=Fa;c[f+5396>>2]=Fa;c[f+5400>>2]=Fa;c[f+5404>>2]=Fa;c[f+5424>>2]=Fa;c[f+5428>>2]=Fa;c[f+5432>>2]=Fa;c[f+5436>>2]=Fa;c[f+5456>>2]=Fa;c[f+5460>>2]=Fa;c[f+5464>>2]=Fa;c[f+5468>>2]=Fa;c[f+5520>>2]=Ea;c[f+5524>>2]=Ea;c[f+5528>>2]=Ea;c[f+5532>>2]=Ea;c[f+5552>>2]=Ea;c[f+5556>>2]=Ea;c[f+5560>>2]=Ea;c[f+5564>>2]=Ea;c[f+5584>>2]=Ea;c[f+5588>>2]=Ea;c[f+5592>>2]=Ea;c[f+5596>>2]=Ea;c[f+5616>>2]=Ea;c[f+5620>>2]=Ea;c[f+5624>>2]=Ea;c[f+5628>>2]=Ea;i=h;return}Ea=ta&65535;Fa=((ja&255)*257|0)&65535;ua=c[k+4>>2]|0;k=((ua&255)*257|0)&65535;Aa=(va&7|0)==0;va=f+307820|0;Z=(ta&8|0)==0;ta=ra*3|0;ia=(ja|0)==0;ja=(ua|0)==0;ua=f+427372|0;Da=0;Ba=0;while(1){Ca=Da&1;sa=Da>>1;ka=f+177112+(Da<<1)|0;if(K){v=89}else{if((b[ka>>1]&256)==0){Ga=Ba}else{v=89}}do{if((v|0)==89){v=0;b[ka>>1]=Ea;ha=Da<<2;j=d[602160+ha|0]|0;ma=f+5312+(j<<2)|0;c[ma>>2]=ea;la=j+1|0;da=f+5312+(la<<2)|0;c[da>>2]=ea;qa=j+8|0;t=f+5312+(qa<<2)|0;c[t>>2]=ea;ba=j+9|0;J=f+5312+(ba<<2)|0;c[J>>2]=ea;_=f+5472+(j<<2)|0;c[_>>2]=S;l=f+5472+(la<<2)|0;c[l>>2]=S;la=f+5472+(qa<<2)|0;c[la>>2]=S;oa=f+5472+(ba<<2)|0;c[oa>>2]=S;b[f+5632+j>>1]=Fa;b[f+5632+qa>>1]=Fa;b[f+5672+j>>1]=k;b[f+5672+qa>>1]=k;if(!Aa){Ga=Ba;break}if((c[va>>2]|0)!=0){Ga=Ba;break}qa=a[ya+Da|0]|0;j=qa<<24>>24==0;if(!j){if(!(qa<<24>>24<0)){Ga=Ba;break}if((a[za+Da|0]|0)!=0){Ga=Ba;break}if(!((c[ua>>2]|0)>>>0>33>>>0)){Ga=Ba;break}}qa=j?wa:xa;if(!Z){j=(-Ca&3)+(ca(ta,sa)|0)|0;ba=b[qa+(j<<2)>>1]|0;aa=ba<<16>>16;if(((ba<<16>>16>-1?aa:-aa|0)|0)>=2){Ga=Ba;break}aa=b[qa+(j<<2)+2>>1]|0;j=aa<<16>>16;if(((aa<<16>>16>-1?j:-j|0)|0)>=2){Ga=Ba;break}if(ia){c[ma>>2]=0;c[da>>2]=0;c[t>>2]=0;c[J>>2]=0}if(ja){c[_>>2]=0;c[l>>2]=0;c[la>>2]=0;c[oa>>2]=0}Ga=Ba+4|0;break}oa=Ca<<1;la=sa<<1;l=0;_=0;while(1){J=(ca((l>>1)+la|0,ra)|0)+(l&1|oa)|0;t=b[qa+(J<<2)>>1]|0;da=t<<16>>16;do{if(((t<<16>>16>-1?da:-da|0)|0)<2){ma=b[qa+(J<<2)+2>>1]|0;j=ma<<16>>16;if(((ma<<16>>16>-1?j:-j|0)|0)>=2){Ha=_;break}if(ia){c[f+5312+(d[602160+(l+ha)|0]<<2)>>2]=0}if(ja){c[f+5472+(d[602160+(l+ha)|0]<<2)>>2]=0}Ha=_+1|0}else{Ha=_}}while(0);J=l+1|0;if((J|0)<4){l=J;_=Ha}else{break}}if((Ha&3|0)==0){b[ka>>1]=(b[ka>>1]|0)-56}Ga=Ha+Ba|0}}while(0);ka=Da+1|0;if((ka|0)<4){Da=ka;Ba=Ga}else{break}}if(!K){i=h;return}if((Ga&15|0)!=0){i=h;return}c[g>>2]=c[g>>2]&-41337|264;i=h;return}function oia(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;n=i;i=i+72|0;o=n|0;p=n+8|0;q=c[e+92>>2]|0;do{if((q|0)!=0){if((c[e+8052>>2]|0)!=0){break}r=c[e+6136>>2]|0;s=(r|0)!=0;t=(r|0)==3;u=(r|0)==2;r=c[e+427412>>2]|0;v=c[e+4872>>2]|0;w=c[e+4864>>2]|0;x=((c[e+7308>>2]|0)*-6|0)+48|0;y=(c[e+427424>>2]|0)+52+x|0;z=(c[e+427428>>2]|0)+52+x|0;x=c[(c[e+4064>>2]|0)+(r<<2)>>2]|0;A=c[e+4040>>2]|0;B=a[A+r|0]|0;C=a[A+(r-1)|0]|0;r=a[A+(c[e+4844>>2]|0)|0]|0;A=d[e+7876+B|0]|0;D=B+1|0;E=D+C>>1;F=r+D>>1;D=A+1|0;G=(D+(d[e+7876+C|0]|0)|0)>>>1;C=((d[e+7876+r|0]|0)+D|0)>>>1;D=(x&7|0)==0;if((c[e+4752>>2]|0)==0){if(!D){r=(c[e+177100>>2]|0)!=3?1144344:1144336;H=(v|0)!=0;do{if(H){I=E+y|0;J=E+z|0;if(I>>>0<68>>>0|J>>>0<68>>>0){break}mf[c[e+60>>2]&2047](h,l,d[2020944+I|0]|0,d[1953896+J|0]|0)}}while(0);J=(x&16777216|0)!=0;I=o|0;K=B+y|0;L=2020944+K|0;M=B+z|0;N=1953896+M|0;O=K>>>0<68>>>0|M>>>0<68>>>0;do{if(J){if(!O){M=d[N]|0;P=d[L]|0;mrc(I|0,a[311883+(K<<2)|0]|0,4)|0;pe[c[e+48>>2]&1023](h+8|0,l,P,M,I)}do{if((w|0)!=0){M=F+y|0;P=d[2020944+M|0]|0;Q=F+z|0;R=d[1953896+Q|0]|0;if(M>>>0<68>>>0|Q>>>0<68>>>0){break}Q=b[r>>1]|0;if(Q<<16>>16<4){a[I]=a[(Q<<16>>16)+(311880+(M<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(M<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(M<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(M<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,P,R,I);break}else{mf[c[e+56>>2]&2047](h,l,P,R);break}}}while(0);if(O){break}R=d[N]|0;P=d[L]|0;mrc(I|0,a[311883+(K<<2)|0]|0,4)|0;pe[c[e+44>>2]&1023](h+(l<<3)|0,l,P,R,I)}else{if(!O){R=d[N]|0;P=d[L]|0;M=a[311883+(K<<2)|0]|0;Q=e+48|0;mrc(I|0,M|0,4)|0;pe[c[Q>>2]&1023](h+4|0,l,P,R,I);mrc(I|0,M|0,4)|0;pe[c[Q>>2]&1023](h+8|0,l,P,R,I);mrc(I|0,M|0,4)|0;pe[c[Q>>2]&1023](h+12|0,l,P,R,I)}do{if((w|0)!=0){R=F+y|0;P=d[2020944+R|0]|0;Q=F+z|0;M=d[1953896+Q|0]|0;if(R>>>0<68>>>0|Q>>>0<68>>>0){break}Q=b[r>>1]|0;if(Q<<16>>16<4){a[I]=a[(Q<<16>>16)+(311880+(R<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(R<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(R<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(R<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,P,M,I);break}else{mf[c[e+56>>2]&2047](h,l,P,M);break}}}while(0);if(O){break}M=d[N]|0;P=d[L]|0;R=a[311883+(K<<2)|0]|0;Q=e+44|0;mrc(I|0,R|0,4)|0;pe[c[Q>>2]&1023](h+(l<<2)|0,l,P,M,I);mrc(I|0,R|0,4)|0;pe[c[Q>>2]&1023](h+(l<<3)|0,l,P,M,I);mrc(I|0,R|0,4)|0;pe[c[Q>>2]&1023](h+(l*12|0)|0,l,P,M,I)}}while(0);if(!s){i=n;return}if(t){do{if(H){K=G+y|0;L=G+z|0;if(K>>>0<68>>>0|L>>>0<68>>>0){break}N=d[1953896+L|0]|0;L=d[2020944+K|0]|0;K=e+60|0;mf[c[K>>2]&2047](j,l,L,N);mf[c[K>>2]&2047](k,l,L,N)}}while(0);N=A+y|0;L=2020944+N|0;K=A+z|0;O=1953896+K|0;M=N>>>0<68>>>0|K>>>0<68>>>0;if(J){if(!M){K=d[O]|0;P=d[L]|0;Q=a[311883+(N<<2)|0]|0;R=e+48|0;mrc(I|0,Q|0,4)|0;pe[c[R>>2]&1023](j+8|0,l,P,K,I);mrc(I|0,Q|0,4)|0;pe[c[R>>2]&1023](k+8|0,l,P,K,I)}do{if((w|0)!=0){K=C+y|0;P=d[2020944+K|0]|0;R=C+z|0;Q=d[1953896+R|0]|0;if(K>>>0<68>>>0|R>>>0<68>>>0){break}R=b[r>>1]|0;if(R<<16>>16<4){a[I]=a[(R<<16>>16)+(311880+(K<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(K<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(K<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(K<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,P,Q,I);a[I]=a[(R<<16>>16)+(311880+(K<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(K<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(K<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(K<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,P,Q,I);break}else{mf[c[e+56>>2]&2047](j,l,P,Q);mf[c[e+56>>2]&2047](k,l,P,Q);break}}}while(0);J=l<<3;if(M){i=n;return}Q=d[O]|0;P=d[L]|0;K=a[311883+(N<<2)|0]|0;R=e+44|0;mrc(I|0,K|0,4)|0;pe[c[R>>2]&1023](j+J|0,l,P,Q,I);mrc(I|0,K|0,4)|0;pe[c[R>>2]&1023](k+J|0,l,P,Q,I);i=n;return}else{if(!M){Q=d[O]|0;P=d[L]|0;J=a[311883+(N<<2)|0]|0;R=e+48|0;mrc(I|0,J|0,4)|0;pe[c[R>>2]&1023](j+4|0,l,P,Q,I);mrc(I|0,J|0,4)|0;pe[c[R>>2]&1023](k+4|0,l,P,Q,I);mrc(I|0,J|0,4)|0;pe[c[R>>2]&1023](j+8|0,l,P,Q,I);mrc(I|0,J|0,4)|0;pe[c[R>>2]&1023](k+8|0,l,P,Q,I);mrc(I|0,J|0,4)|0;pe[c[R>>2]&1023](j+12|0,l,P,Q,I);mrc(I|0,J|0,4)|0;pe[c[R>>2]&1023](k+12|0,l,P,Q,I)}do{if((w|0)!=0){Q=C+y|0;P=d[2020944+Q|0]|0;R=C+z|0;J=d[1953896+R|0]|0;if(Q>>>0<68>>>0|R>>>0<68>>>0){break}R=b[r>>1]|0;if(R<<16>>16<4){a[I]=a[(R<<16>>16)+(311880+(Q<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(Q<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(Q<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(Q<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,P,J,I);a[I]=a[(R<<16>>16)+(311880+(Q<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(Q<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(Q<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(Q<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,P,J,I);break}else{mf[c[e+56>>2]&2047](j,l,P,J);mf[c[e+56>>2]&2047](k,l,P,J);break}}}while(0);J=l<<2;if(M){i=n;return}P=d[O]|0;Q=d[L]|0;R=a[311883+(N<<2)|0]|0;K=e+44|0;mrc(I|0,R|0,4)|0;pe[c[K>>2]&1023](j+J|0,l,Q,P,I);mrc(I|0,R|0,4)|0;pe[c[K>>2]&1023](k+J|0,l,Q,P,I);J=l<<3;mrc(I|0,R|0,4)|0;pe[c[K>>2]&1023](j+J|0,l,Q,P,I);mrc(I|0,R|0,4)|0;pe[c[K>>2]&1023](k+J|0,l,Q,P,I);J=l*12|0;mrc(I|0,R|0,4)|0;pe[c[K>>2]&1023](j+J|0,l,Q,P,I);mrc(I|0,R|0,4)|0;pe[c[K>>2]&1023](k+J|0,l,Q,P,I);i=n;return}}if(u){do{if(H){P=G+y|0;Q=G+z|0;if(P>>>0<68>>>0|Q>>>0<68>>>0){break}J=d[1953896+Q|0]|0;Q=d[2020944+P|0]|0;P=e+84|0;mf[c[P>>2]&2047](j,m,Q,J);mf[c[P>>2]&2047](k,m,Q,J)}}while(0);N=A+y|0;L=2020944+N|0;O=A+z|0;M=1953896+O|0;J=N>>>0<68>>>0|O>>>0<68>>>0;if(!J){O=d[M]|0;Q=d[L]|0;P=(a[311883+(N<<2)|0]|0)+1&255;K=e+72|0;mrc(I|0,P|0,4)|0;pe[c[K>>2]&1023](j+4|0,m,Q,O,I);mrc(I|0,P|0,4)|0;pe[c[K>>2]&1023](k+4|0,m,Q,O,I)}do{if((w|0)!=0){O=C+y|0;Q=d[2020944+O|0]|0;K=C+z|0;P=d[1953896+K|0]|0;if(O>>>0<68>>>0|K>>>0<68>>>0){break}K=b[r>>1]|0;if(K<<16>>16<4){a[I]=(a[(K<<16>>16)+(311880+(O<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(311880+(O<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(311880+(O<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(311880+(O<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,Q,P,I);a[I]=(a[(K<<16>>16)+(311880+(O<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(311880+(O<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(311880+(O<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(311880+(O<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,Q,P,I);break}else{mf[c[e+80>>2]&2047](j,m,Q,P);mf[c[e+80>>2]&2047](k,m,Q,P);break}}}while(0);P=m<<2;if(J){i=n;return}Q=d[M]|0;O=d[L]|0;K=(a[311883+(N<<2)|0]|0)+1&255;R=e+68|0;mrc(I|0,K|0,4)|0;pe[c[R>>2]&1023](j+P|0,m,O,Q,I);mrc(I|0,K|0,4)|0;pe[c[R>>2]&1023](k+P|0,m,O,Q,I);P=m<<3;mrc(I|0,K|0,4)|0;pe[c[R>>2]&1023](j+P|0,m,O,Q,I);mrc(I|0,K|0,4)|0;pe[c[R>>2]&1023](k+P|0,m,O,Q,I);P=m*12|0;mrc(I|0,K|0,4)|0;pe[c[R>>2]&1023](j+P|0,m,O,Q,I);mrc(I|0,K|0,4)|0;pe[c[R>>2]&1023](k+P|0,m,O,Q,I);i=n;return}else{do{if(H){Q=G+y|0;O=G+z|0;if(Q>>>0<68>>>0|O>>>0<68>>>0){break}P=d[1953896+O|0]|0;O=d[2020944+Q|0]|0;Q=e+84|0;mf[c[Q>>2]&2047](j,m,O,P);mf[c[Q>>2]&2047](k,m,O,P)}}while(0);H=A+y|0;N=2020944+H|0;L=A+z|0;M=1953896+L|0;J=H>>>0<68>>>0|L>>>0<68>>>0;if(!J){L=d[M]|0;P=d[N]|0;O=(a[311883+(H<<2)|0]|0)+1&255;Q=e+72|0;mrc(I|0,O|0,4)|0;pe[c[Q>>2]&1023](j+4|0,m,P,L,I);mrc(I|0,O|0,4)|0;pe[c[Q>>2]&1023](k+4|0,m,P,L,I)}do{if((w|0)!=0){L=C+y|0;P=d[2020944+L|0]|0;Q=C+z|0;O=d[1953896+Q|0]|0;if(L>>>0<68>>>0|Q>>>0<68>>>0){break}Q=b[r>>1]|0;if(Q<<16>>16<4){a[I]=(a[(Q<<16>>16)+(311880+(L<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(311880+(L<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(311880+(L<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(311880+(L<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,P,O,I);a[I]=(a[(Q<<16>>16)+(311880+(L<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(311880+(L<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(311880+(L<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(311880+(L<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,P,O,I);break}else{mf[c[e+80>>2]&2047](j,m,P,O);mf[c[e+80>>2]&2047](k,m,P,O);break}}}while(0);r=m<<2;if(J){i=n;return}O=d[M]|0;P=d[N]|0;L=(a[311883+(H<<2)|0]|0)+1&255;Q=e+68|0;mrc(I|0,L|0,4)|0;pe[c[Q>>2]&1023](j+r|0,m,P,O,I);mrc(I|0,L|0,4)|0;pe[c[Q>>2]&1023](k+r|0,m,P,O,I);i=n;return}}O=p;P=(x&16777216|0)!=0;r=c[e+426564>>2]|0;do{if(P){if((r&7|0)!=7|t){S=310;break}Q=p|0;c[Q>>2]=131074;c[Q+4>>2]=131074;Q=p+16|0;c[Q>>2]=131074;c[Q+4>>2]=131074;Q=p+32|0;c[Q>>2]=131074;c[Q+4>>2]=131074;Q=p+48|0;c[Q>>2]=131074;c[Q+4>>2]=131074;T=4}else{S=310}}while(0);if((S|0)==310){I=-((x*5|0)>>>5&1)&3|x>>4;H=4-(-((r&15|0)==0&x>>>3)&3)|0;Ve[q&127](O,e+5184|0,e+5632|0,e+5312|0,(c[e+199428>>2]|0)==2|0,H,(x>>24)+1|0,-((v*5|0)>>>5&1&I>>>1)&3,I,(c[e+177100>>2]|0)!=3|0);T=H}if((v&7|0)!=0){H=p|0;c[H>>2]=262148;c[H+4>>2]=262148}if((w&7|0)!=0){H=(c[e+177100>>2]|0)!=3;I=p+32|0;c[I>>2]=H?196611:262148;c[I+4>>2]=H?196611:262148}do{if((v|0)!=0){H=p;I=p|0;N=c[I>>2]|0;M=N&65535;if((N|0)==0&(c[I+4>>2]|0)==0){break}I=o|0;N=E+y|0;J=d[2020944+N|0]|0;Q=E+z|0;L=d[1953896+Q|0]|0;do{if(!(N>>>0<68>>>0|Q>>>0<68>>>0)){if(M<<16>>16<4){a[I]=a[(M<<16>>16)+(311880+(N<<2))|0]|0;a[o+1|0]=a[(b[H+2>>1]|0)+(311880+(N<<2))|0]|0;a[o+2|0]=a[(b[H+4>>1]|0)+(311880+(N<<2))|0]|0;a[o+3|0]=a[(b[H+6>>1]|0)+(311880+(N<<2))|0]|0;pe[c[e+48>>2]&1023](h,l,J,L,I);break}else{mf[c[e+60>>2]&2047](h,l,J,L);break}}}while(0);if(!s){break}L=G+y|0;J=d[2020944+L|0]|0;N=G+z|0;M=d[1953896+N|0]|0;Q=L>>>0<68>>>0|N>>>0<68>>>0;if(t){if(Q){break}N=b[H>>1]|0;if(N<<16>>16<4){a[I]=a[(N<<16>>16)+(311880+(L<<2))|0]|0;a[o+1|0]=a[(b[H+2>>1]|0)+(311880+(L<<2))|0]|0;a[o+2|0]=a[(b[H+4>>1]|0)+(311880+(L<<2))|0]|0;a[o+3|0]=a[(b[H+6>>1]|0)+(311880+(L<<2))|0]|0;pe[c[e+48>>2]&1023](j,l,J,M,I)}else{mf[c[e+60>>2]&2047](j,l,J,M)}N=b[H>>1]|0;if(N<<16>>16<4){a[I]=a[(N<<16>>16)+(311880+(L<<2))|0]|0;a[o+1|0]=a[(b[H+2>>1]|0)+(311880+(L<<2))|0]|0;a[o+2|0]=a[(b[H+4>>1]|0)+(311880+(L<<2))|0]|0;a[o+3|0]=a[(b[H+6>>1]|0)+(311880+(L<<2))|0]|0;pe[c[e+48>>2]&1023](k,l,J,M,I);break}else{mf[c[e+60>>2]&2047](k,l,J,M);break}}else{if(Q){break}Q=b[H>>1]|0;if(Q<<16>>16<4){a[I]=(a[(Q<<16>>16)+(311880+(L<<2))|0]|0)+1;a[o+1|0]=(a[(b[H+2>>1]|0)+(311880+(L<<2))|0]|0)+1;a[o+2|0]=(a[(b[H+4>>1]|0)+(311880+(L<<2))|0]|0)+1;a[o+3|0]=(a[(b[H+6>>1]|0)+(311880+(L<<2))|0]|0)+1;pe[c[e+72>>2]&1023](j,m,J,M,I)}else{mf[c[e+84>>2]&2047](j,m,J,M)}Q=b[H>>1]|0;if(Q<<16>>16<4){a[I]=(a[(Q<<16>>16)+(311880+(L<<2))|0]|0)+1;a[o+1|0]=(a[(b[H+2>>1]|0)+(311880+(L<<2))|0]|0)+1;a[o+2|0]=(a[(b[H+4>>1]|0)+(311880+(L<<2))|0]|0)+1;a[o+3|0]=(a[(b[H+6>>1]|0)+(311880+(L<<2))|0]|0)+1;pe[c[e+72>>2]&1023](k,m,J,M,I);break}else{mf[c[e+84>>2]&2047](k,m,J,M);break}}}}while(0);if((T|0)==1){if((w|0)==0){i=n;return}O=p+32|0;r=O;M=O|0;O=c[M>>2]|0;J=O&65535;if((O|0)==0&(c[M+4>>2]|0)==0){i=n;return}M=o|0;O=F+y|0;L=d[2020944+O|0]|0;Q=F+z|0;N=d[1953896+Q|0]|0;do{if(!(O>>>0<68>>>0|Q>>>0<68>>>0)){if(J<<16>>16<4){a[M]=a[(J<<16>>16)+(311880+(O<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(O<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(O<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(O<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,L,N,M);break}else{mf[c[e+56>>2]&2047](h,l,L,N);break}}}while(0);if(!s){i=n;return}N=C+y|0;L=d[2020944+N|0]|0;O=C+z|0;J=d[1953896+O|0]|0;Q=N>>>0<68>>>0|O>>>0<68>>>0;if(t){if(Q){i=n;return}O=b[r>>1]|0;if(O<<16>>16<4){a[M]=a[(O<<16>>16)+(311880+(N<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(N<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(N<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(N<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,L,J,M)}else{mf[c[e+56>>2]&2047](j,l,L,J)}O=b[r>>1]|0;if(O<<16>>16<4){a[M]=a[(O<<16>>16)+(311880+(N<<2))|0]|0;a[o+1|0]=a[(b[r+2>>1]|0)+(311880+(N<<2))|0]|0;a[o+2|0]=a[(b[r+4>>1]|0)+(311880+(N<<2))|0]|0;a[o+3|0]=a[(b[r+6>>1]|0)+(311880+(N<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,L,J,M);i=n;return}else{mf[c[e+56>>2]&2047](k,l,L,J);i=n;return}}else{if(Q){i=n;return}Q=b[r>>1]|0;if(Q<<16>>16<4){a[M]=(a[(Q<<16>>16)+(311880+(N<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(311880+(N<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(311880+(N<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(311880+(N<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,L,J,M)}else{mf[c[e+80>>2]&2047](j,m,L,J)}Q=b[r>>1]|0;if(Q<<16>>16<4){a[M]=(a[(Q<<16>>16)+(311880+(N<<2))|0]|0)+1;a[o+1|0]=(a[(b[r+2>>1]|0)+(311880+(N<<2))|0]|0)+1;a[o+2|0]=(a[(b[r+4>>1]|0)+(311880+(N<<2))|0]|0)+1;a[o+3|0]=(a[(b[r+6>>1]|0)+(311880+(N<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,L,J,M);i=n;return}else{mf[c[e+80>>2]&2047](k,m,L,J);i=n;return}}}if(P){J=p+16|0;L=J;N=J|0;J=c[N>>2]|0;Q=J&65535;do{if(!((J|0)==0&(c[N+4>>2]|0)==0)){O=o|0;R=B+y|0;K=B+z|0;if(!(R>>>0<68>>>0|K>>>0<68>>>0)){U=d[1953896+K|0]|0;K=d[2020944+R|0]|0;a[O]=a[(Q<<16>>16)+(311880+(R<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(311880+(R<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(311880+(R<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(311880+(R<<2))|0]|0;pe[c[e+48>>2]&1023](h+8|0,l,K,U,O)}if(!s){break}U=A+y|0;K=A+z|0;R=U>>>0<68>>>0|K>>>0<68>>>0;if(t){if(R){break}V=d[1953896+K|0]|0;W=d[2020944+U|0]|0;a[O]=a[(b[L>>1]|0)+(311880+(U<<2))|0]|0;X=L+2|0;Y=o+1|0;a[Y]=a[(b[X>>1]|0)+(311880+(U<<2))|0]|0;Z=L+4|0;_=o+2|0;a[_]=a[(b[Z>>1]|0)+(311880+(U<<2))|0]|0;$=L+6|0;aa=o+3|0;a[aa]=a[(b[$>>1]|0)+(311880+(U<<2))|0]|0;ba=e+48|0;pe[c[ba>>2]&1023](j+8|0,l,W,V,O);a[O]=a[(b[L>>1]|0)+(311880+(U<<2))|0]|0;a[Y]=a[(b[X>>1]|0)+(311880+(U<<2))|0]|0;a[_]=a[(b[Z>>1]|0)+(311880+(U<<2))|0]|0;a[aa]=a[(b[$>>1]|0)+(311880+(U<<2))|0]|0;pe[c[ba>>2]&1023](k+8|0,l,W,V,O);break}else{if(R){break}R=d[1953896+K|0]|0;K=d[2020944+U|0]|0;a[O]=(a[(b[L>>1]|0)+(311880+(U<<2))|0]|0)+1;V=L+2|0;W=o+1|0;a[W]=(a[(b[V>>1]|0)+(311880+(U<<2))|0]|0)+1;ba=L+4|0;$=o+2|0;a[$]=(a[(b[ba>>1]|0)+(311880+(U<<2))|0]|0)+1;aa=L+6|0;Z=o+3|0;a[Z]=(a[(b[aa>>1]|0)+(311880+(U<<2))|0]|0)+1;_=e+72|0;pe[c[_>>2]&1023](j+4|0,m,K,R,O);a[O]=(a[(b[L>>1]|0)+(311880+(U<<2))|0]|0)+1;a[W]=(a[(b[V>>1]|0)+(311880+(U<<2))|0]|0)+1;a[$]=(a[(b[ba>>1]|0)+(311880+(U<<2))|0]|0)+1;a[Z]=(a[(b[aa>>1]|0)+(311880+(U<<2))|0]|0)+1;pe[c[_>>2]&1023](k+4|0,m,K,R,O);break}}}while(0);do{if((w|0)!=0){L=p+32|0;Q=L;N=L|0;L=c[N>>2]|0;J=L&65535;if((L|0)==0&(c[N+4>>2]|0)==0){break}N=o|0;L=F+y|0;P=d[2020944+L|0]|0;M=F+z|0;r=d[1953896+M|0]|0;do{if(!(L>>>0<68>>>0|M>>>0<68>>>0)){if(J<<16>>16<4){a[N]=a[(J<<16>>16)+(311880+(L<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(311880+(L<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(311880+(L<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(311880+(L<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,P,r,N);break}else{mf[c[e+56>>2]&2047](h,l,P,r);break}}}while(0);if(!s){break}r=C+y|0;P=d[2020944+r|0]|0;L=C+z|0;J=d[1953896+L|0]|0;M=r>>>0<68>>>0|L>>>0<68>>>0;if(t){if(M){break}L=b[Q>>1]|0;if(L<<16>>16<4){a[N]=a[(L<<16>>16)+(311880+(r<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(311880+(r<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(311880+(r<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(311880+(r<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,P,J,N)}else{mf[c[e+56>>2]&2047](j,l,P,J)}L=b[Q>>1]|0;if(L<<16>>16<4){a[N]=a[(L<<16>>16)+(311880+(r<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(311880+(r<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(311880+(r<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(311880+(r<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,P,J,N);break}else{mf[c[e+56>>2]&2047](k,l,P,J);break}}else{if(M){break}M=b[Q>>1]|0;if(M<<16>>16<4){a[N]=(a[(M<<16>>16)+(311880+(r<<2))|0]|0)+1;a[o+1|0]=(a[(b[Q+2>>1]|0)+(311880+(r<<2))|0]|0)+1;a[o+2|0]=(a[(b[Q+4>>1]|0)+(311880+(r<<2))|0]|0)+1;a[o+3|0]=(a[(b[Q+6>>1]|0)+(311880+(r<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,P,J,N)}else{mf[c[e+80>>2]&2047](j,m,P,J)}M=b[Q>>1]|0;if(M<<16>>16<4){a[N]=(a[(M<<16>>16)+(311880+(r<<2))|0]|0)+1;a[o+1|0]=(a[(b[Q+2>>1]|0)+(311880+(r<<2))|0]|0)+1;a[o+2|0]=(a[(b[Q+4>>1]|0)+(311880+(r<<2))|0]|0)+1;a[o+3|0]=(a[(b[Q+6>>1]|0)+(311880+(r<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,P,J,N);break}else{mf[c[e+80>>2]&2047](k,m,P,J);break}}}}while(0);J=p+48|0;P=J;r=J|0;J=c[r>>2]|0;if((J|0)==0&(c[r+4>>2]|0)==0){i=n;return}r=l<<3;M=o|0;L=B+y|0;I=B+z|0;if(!(L>>>0<68>>>0|I>>>0<68>>>0)){H=d[1953896+I|0]|0;I=d[2020944+L|0]|0;a[M]=a[((J&65535)<<16>>16)+(311880+(L<<2))|0]|0;a[o+1|0]=a[(b[P+2>>1]|0)+(311880+(L<<2))|0]|0;a[o+2|0]=a[(b[P+4>>1]|0)+(311880+(L<<2))|0]|0;a[o+3|0]=a[(b[P+6>>1]|0)+(311880+(L<<2))|0]|0;pe[c[e+44>>2]&1023](h+r|0,l,I,H,M)}if(!s){i=n;return}if(t){H=A+y|0;I=A+z|0;if(H>>>0<68>>>0|I>>>0<68>>>0){i=n;return}L=d[1953896+I|0]|0;I=d[2020944+H|0]|0;a[M]=a[(b[P>>1]|0)+(311880+(H<<2))|0]|0;J=P+2|0;O=o+1|0;a[O]=a[(b[J>>1]|0)+(311880+(H<<2))|0]|0;R=P+4|0;K=o+2|0;a[K]=a[(b[R>>1]|0)+(311880+(H<<2))|0]|0;_=P+6|0;U=o+3|0;a[U]=a[(b[_>>1]|0)+(311880+(H<<2))|0]|0;aa=e+44|0;pe[c[aa>>2]&1023](j+r|0,l,I,L,M);a[M]=a[(b[P>>1]|0)+(311880+(H<<2))|0]|0;a[O]=a[(b[J>>1]|0)+(311880+(H<<2))|0]|0;a[K]=a[(b[R>>1]|0)+(311880+(H<<2))|0]|0;a[U]=a[(b[_>>1]|0)+(311880+(H<<2))|0]|0;pe[c[aa>>2]&1023](k+r|0,l,I,L,M);i=n;return}else{L=m<<2;I=A+y|0;r=A+z|0;if(I>>>0<68>>>0|r>>>0<68>>>0){i=n;return}aa=d[1953896+r|0]|0;r=d[2020944+I|0]|0;a[M]=(a[(b[P>>1]|0)+(311880+(I<<2))|0]|0)+1;H=P+2|0;_=o+1|0;a[_]=(a[(b[H>>1]|0)+(311880+(I<<2))|0]|0)+1;U=P+4|0;R=o+2|0;a[R]=(a[(b[U>>1]|0)+(311880+(I<<2))|0]|0)+1;K=P+6|0;J=o+3|0;a[J]=(a[(b[K>>1]|0)+(311880+(I<<2))|0]|0)+1;O=e+68|0;pe[c[O>>2]&1023](j+L|0,m,r,aa,M);a[M]=(a[(b[P>>1]|0)+(311880+(I<<2))|0]|0)+1;a[_]=(a[(b[H>>1]|0)+(311880+(I<<2))|0]|0)+1;a[R]=(a[(b[U>>1]|0)+(311880+(I<<2))|0]|0)+1;a[J]=(a[(b[K>>1]|0)+(311880+(I<<2))|0]|0)+1;pe[c[O>>2]&1023](k+L|0,m,r,aa,M);i=n;return}}M=p+8|0;aa=M;r=M|0;M=c[r>>2]|0;L=M&65535;do{if(!((M|0)==0&(c[r+4>>2]|0)==0)){O=o|0;I=B+y|0;K=B+z|0;if(!(I>>>0<68>>>0|K>>>0<68>>>0)){J=d[1953896+K|0]|0;K=d[2020944+I|0]|0;a[O]=a[(L<<16>>16)+(311880+(I<<2))|0]|0;a[o+1|0]=a[(b[aa+2>>1]|0)+(311880+(I<<2))|0]|0;a[o+2|0]=a[(b[aa+4>>1]|0)+(311880+(I<<2))|0]|0;a[o+3|0]=a[(b[aa+6>>1]|0)+(311880+(I<<2))|0]|0;pe[c[e+48>>2]&1023](h+4|0,l,K,J,O)}if(!t){break}J=A+y|0;K=A+z|0;if(J>>>0<68>>>0|K>>>0<68>>>0){break}I=d[1953896+K|0]|0;K=d[2020944+J|0]|0;a[O]=a[(b[aa>>1]|0)+(311880+(J<<2))|0]|0;U=aa+2|0;R=o+1|0;a[R]=a[(b[U>>1]|0)+(311880+(J<<2))|0]|0;H=aa+4|0;_=o+2|0;a[_]=a[(b[H>>1]|0)+(311880+(J<<2))|0]|0;P=aa+6|0;Z=o+3|0;a[Z]=a[(b[P>>1]|0)+(311880+(J<<2))|0]|0;ba=e+48|0;pe[c[ba>>2]&1023](j+4|0,l,K,I,O);a[O]=a[(b[aa>>1]|0)+(311880+(J<<2))|0]|0;a[R]=a[(b[U>>1]|0)+(311880+(J<<2))|0]|0;a[_]=a[(b[H>>1]|0)+(311880+(J<<2))|0]|0;a[Z]=a[(b[P>>1]|0)+(311880+(J<<2))|0]|0;pe[c[ba>>2]&1023](k+4|0,l,K,I,O)}}while(0);aa=p+16|0;L=aa;r=aa|0;aa=c[r>>2]|0;M=aa&65535;do{if(!((aa|0)==0&(c[r+4>>2]|0)==0)){O=o|0;I=B+y|0;K=B+z|0;if(!(I>>>0<68>>>0|K>>>0<68>>>0)){ba=d[1953896+K|0]|0;K=d[2020944+I|0]|0;a[O]=a[(M<<16>>16)+(311880+(I<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(311880+(I<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(311880+(I<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(311880+(I<<2))|0]|0;pe[c[e+48>>2]&1023](h+8|0,l,K,ba,O)}if(!s){break}ba=A+y|0;K=A+z|0;I=ba>>>0<68>>>0|K>>>0<68>>>0;if(t){if(I){break}J=d[1953896+K|0]|0;P=d[2020944+ba|0]|0;a[O]=a[(b[L>>1]|0)+(311880+(ba<<2))|0]|0;Z=L+2|0;H=o+1|0;a[H]=a[(b[Z>>1]|0)+(311880+(ba<<2))|0]|0;_=L+4|0;U=o+2|0;a[U]=a[(b[_>>1]|0)+(311880+(ba<<2))|0]|0;R=L+6|0;$=o+3|0;a[$]=a[(b[R>>1]|0)+(311880+(ba<<2))|0]|0;V=e+48|0;pe[c[V>>2]&1023](j+8|0,l,P,J,O);a[O]=a[(b[L>>1]|0)+(311880+(ba<<2))|0]|0;a[H]=a[(b[Z>>1]|0)+(311880+(ba<<2))|0]|0;a[U]=a[(b[_>>1]|0)+(311880+(ba<<2))|0]|0;a[$]=a[(b[R>>1]|0)+(311880+(ba<<2))|0]|0;pe[c[V>>2]&1023](k+8|0,l,P,J,O);break}else{if(I){break}I=d[1953896+K|0]|0;K=d[2020944+ba|0]|0;a[O]=(a[(b[L>>1]|0)+(311880+(ba<<2))|0]|0)+1;J=L+2|0;P=o+1|0;a[P]=(a[(b[J>>1]|0)+(311880+(ba<<2))|0]|0)+1;V=L+4|0;R=o+2|0;a[R]=(a[(b[V>>1]|0)+(311880+(ba<<2))|0]|0)+1;$=L+6|0;_=o+3|0;a[_]=(a[(b[$>>1]|0)+(311880+(ba<<2))|0]|0)+1;U=e+72|0;pe[c[U>>2]&1023](j+4|0,m,K,I,O);a[O]=(a[(b[L>>1]|0)+(311880+(ba<<2))|0]|0)+1;a[P]=(a[(b[J>>1]|0)+(311880+(ba<<2))|0]|0)+1;a[R]=(a[(b[V>>1]|0)+(311880+(ba<<2))|0]|0)+1;a[_]=(a[(b[$>>1]|0)+(311880+(ba<<2))|0]|0)+1;pe[c[U>>2]&1023](k+4|0,m,K,I,O);break}}}while(0);L=p+24|0;M=L;r=L|0;L=c[r>>2]|0;aa=L&65535;do{if(!((L|0)==0&(c[r+4>>2]|0)==0)){O=o|0;I=B+y|0;K=B+z|0;if(!(I>>>0<68>>>0|K>>>0<68>>>0)){U=d[1953896+K|0]|0;K=d[2020944+I|0]|0;a[O]=a[(aa<<16>>16)+(311880+(I<<2))|0]|0;a[o+1|0]=a[(b[M+2>>1]|0)+(311880+(I<<2))|0]|0;a[o+2|0]=a[(b[M+4>>1]|0)+(311880+(I<<2))|0]|0;a[o+3|0]=a[(b[M+6>>1]|0)+(311880+(I<<2))|0]|0;pe[c[e+48>>2]&1023](h+12|0,l,K,U,O)}if(!t){break}U=A+y|0;K=A+z|0;if(U>>>0<68>>>0|K>>>0<68>>>0){break}I=d[1953896+K|0]|0;K=d[2020944+U|0]|0;a[O]=a[(b[M>>1]|0)+(311880+(U<<2))|0]|0;ba=M+2|0;$=o+1|0;a[$]=a[(b[ba>>1]|0)+(311880+(U<<2))|0]|0;_=M+4|0;V=o+2|0;a[V]=a[(b[_>>1]|0)+(311880+(U<<2))|0]|0;R=M+6|0;J=o+3|0;a[J]=a[(b[R>>1]|0)+(311880+(U<<2))|0]|0;P=e+48|0;pe[c[P>>2]&1023](j+12|0,l,K,I,O);a[O]=a[(b[M>>1]|0)+(311880+(U<<2))|0]|0;a[$]=a[(b[ba>>1]|0)+(311880+(U<<2))|0]|0;a[V]=a[(b[_>>1]|0)+(311880+(U<<2))|0]|0;a[J]=a[(b[R>>1]|0)+(311880+(U<<2))|0]|0;pe[c[P>>2]&1023](k+12|0,l,K,I,O)}}while(0);do{if((w|0)!=0){M=p+32|0;aa=M;r=M|0;M=c[r>>2]|0;L=M&65535;if((M|0)==0&(c[r+4>>2]|0)==0){break}r=o|0;M=F+y|0;O=d[2020944+M|0]|0;I=F+z|0;K=d[1953896+I|0]|0;do{if(!(M>>>0<68>>>0|I>>>0<68>>>0)){if(L<<16>>16<4){a[r]=a[(L<<16>>16)+(311880+(M<<2))|0]|0;a[o+1|0]=a[(b[aa+2>>1]|0)+(311880+(M<<2))|0]|0;a[o+2|0]=a[(b[aa+4>>1]|0)+(311880+(M<<2))|0]|0;a[o+3|0]=a[(b[aa+6>>1]|0)+(311880+(M<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,O,K,r);break}else{mf[c[e+56>>2]&2047](h,l,O,K);break}}}while(0);if(!s){break}K=C+y|0;O=d[2020944+K|0]|0;M=C+z|0;L=d[1953896+M|0]|0;I=K>>>0<68>>>0|M>>>0<68>>>0;if(t){if(I){break}M=b[aa>>1]|0;if(M<<16>>16<4){a[r]=a[(M<<16>>16)+(311880+(K<<2))|0]|0;a[o+1|0]=a[(b[aa+2>>1]|0)+(311880+(K<<2))|0]|0;a[o+2|0]=a[(b[aa+4>>1]|0)+(311880+(K<<2))|0]|0;a[o+3|0]=a[(b[aa+6>>1]|0)+(311880+(K<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,O,L,r)}else{mf[c[e+56>>2]&2047](j,l,O,L)}M=b[aa>>1]|0;if(M<<16>>16<4){a[r]=a[(M<<16>>16)+(311880+(K<<2))|0]|0;a[o+1|0]=a[(b[aa+2>>1]|0)+(311880+(K<<2))|0]|0;a[o+2|0]=a[(b[aa+4>>1]|0)+(311880+(K<<2))|0]|0;a[o+3|0]=a[(b[aa+6>>1]|0)+(311880+(K<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,O,L,r);break}else{mf[c[e+56>>2]&2047](k,l,O,L);break}}else{if(I){break}I=b[aa>>1]|0;if(I<<16>>16<4){a[r]=(a[(I<<16>>16)+(311880+(K<<2))|0]|0)+1;a[o+1|0]=(a[(b[aa+2>>1]|0)+(311880+(K<<2))|0]|0)+1;a[o+2|0]=(a[(b[aa+4>>1]|0)+(311880+(K<<2))|0]|0)+1;a[o+3|0]=(a[(b[aa+6>>1]|0)+(311880+(K<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,O,L,r)}else{mf[c[e+80>>2]&2047](j,m,O,L)}I=b[aa>>1]|0;if(I<<16>>16<4){a[r]=(a[(I<<16>>16)+(311880+(K<<2))|0]|0)+1;a[o+1|0]=(a[(b[aa+2>>1]|0)+(311880+(K<<2))|0]|0)+1;a[o+2|0]=(a[(b[aa+4>>1]|0)+(311880+(K<<2))|0]|0)+1;a[o+3|0]=(a[(b[aa+6>>1]|0)+(311880+(K<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,O,L,r);break}else{mf[c[e+80>>2]&2047](k,m,O,L);break}}}}while(0);L=p+40|0;O=L;K=L|0;L=c[K>>2]|0;I=L&65535;do{if(!((L|0)==0&(c[K+4>>2]|0)==0)){M=l<<2;N=o|0;Q=B+y|0;P=B+z|0;if(!(Q>>>0<68>>>0|P>>>0<68>>>0)){U=d[1953896+P|0]|0;P=d[2020944+Q|0]|0;a[N]=a[(I<<16>>16)+(311880+(Q<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(Q<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(Q<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(Q<<2))|0]|0;pe[c[e+44>>2]&1023](h+M|0,l,P,U,N)}if(!t){break}U=A+y|0;P=A+z|0;if(U>>>0<68>>>0|P>>>0<68>>>0){break}Q=d[1953896+P|0]|0;P=d[2020944+U|0]|0;a[N]=a[(b[O>>1]|0)+(311880+(U<<2))|0]|0;R=O+2|0;J=o+1|0;a[J]=a[(b[R>>1]|0)+(311880+(U<<2))|0]|0;_=O+4|0;V=o+2|0;a[V]=a[(b[_>>1]|0)+(311880+(U<<2))|0]|0;ba=O+6|0;$=o+3|0;a[$]=a[(b[ba>>1]|0)+(311880+(U<<2))|0]|0;Z=e+44|0;pe[c[Z>>2]&1023](j+M|0,l,P,Q,N);a[N]=a[(b[O>>1]|0)+(311880+(U<<2))|0]|0;a[J]=a[(b[R>>1]|0)+(311880+(U<<2))|0]|0;a[V]=a[(b[_>>1]|0)+(311880+(U<<2))|0]|0;a[$]=a[(b[ba>>1]|0)+(311880+(U<<2))|0]|0;pe[c[Z>>2]&1023](k+M|0,l,P,Q,N)}}while(0);O=p+48|0;I=O;K=O|0;O=c[K>>2]|0;L=O&65535;do{if(!((O|0)==0&(c[K+4>>2]|0)==0)){N=l<<3;Q=o|0;P=B+y|0;M=B+z|0;if(!(P>>>0<68>>>0|M>>>0<68>>>0)){Z=d[1953896+M|0]|0;M=d[2020944+P|0]|0;a[Q]=a[(L<<16>>16)+(311880+(P<<2))|0]|0;a[o+1|0]=a[(b[I+2>>1]|0)+(311880+(P<<2))|0]|0;a[o+2|0]=a[(b[I+4>>1]|0)+(311880+(P<<2))|0]|0;a[o+3|0]=a[(b[I+6>>1]|0)+(311880+(P<<2))|0]|0;pe[c[e+44>>2]&1023](h+N|0,l,M,Z,Q)}if(!s){break}if(t){Z=A+y|0;M=A+z|0;if(Z>>>0<68>>>0|M>>>0<68>>>0){break}P=d[1953896+M|0]|0;M=d[2020944+Z|0]|0;a[Q]=a[(b[I>>1]|0)+(311880+(Z<<2))|0]|0;U=I+2|0;ba=o+1|0;a[ba]=a[(b[U>>1]|0)+(311880+(Z<<2))|0]|0;$=I+4|0;_=o+2|0;a[_]=a[(b[$>>1]|0)+(311880+(Z<<2))|0]|0;V=I+6|0;R=o+3|0;a[R]=a[(b[V>>1]|0)+(311880+(Z<<2))|0]|0;J=e+44|0;pe[c[J>>2]&1023](j+N|0,l,M,P,Q);a[Q]=a[(b[I>>1]|0)+(311880+(Z<<2))|0]|0;a[ba]=a[(b[U>>1]|0)+(311880+(Z<<2))|0]|0;a[_]=a[(b[$>>1]|0)+(311880+(Z<<2))|0]|0;a[R]=a[(b[V>>1]|0)+(311880+(Z<<2))|0]|0;pe[c[J>>2]&1023](k+N|0,l,M,P,Q);break}else{P=m<<2;M=A+y|0;N=A+z|0;if(M>>>0<68>>>0|N>>>0<68>>>0){break}J=d[1953896+N|0]|0;N=d[2020944+M|0]|0;a[Q]=(a[(b[I>>1]|0)+(311880+(M<<2))|0]|0)+1;Z=I+2|0;V=o+1|0;a[V]=(a[(b[Z>>1]|0)+(311880+(M<<2))|0]|0)+1;R=I+4|0;$=o+2|0;a[$]=(a[(b[R>>1]|0)+(311880+(M<<2))|0]|0)+1;_=I+6|0;U=o+3|0;a[U]=(a[(b[_>>1]|0)+(311880+(M<<2))|0]|0)+1;ba=e+68|0;pe[c[ba>>2]&1023](j+P|0,m,N,J,Q);a[Q]=(a[(b[I>>1]|0)+(311880+(M<<2))|0]|0)+1;a[V]=(a[(b[Z>>1]|0)+(311880+(M<<2))|0]|0)+1;a[$]=(a[(b[R>>1]|0)+(311880+(M<<2))|0]|0)+1;a[U]=(a[(b[_>>1]|0)+(311880+(M<<2))|0]|0)+1;pe[c[ba>>2]&1023](k+P|0,m,N,J,Q);break}}}while(0);I=p+56|0;L=I;K=I|0;I=c[K>>2]|0;if((I|0)==0&(c[K+4>>2]|0)==0){i=n;return}K=l*12|0;O=o|0;Q=B+y|0;J=B+z|0;if(!(Q>>>0<68>>>0|J>>>0<68>>>0)){N=d[1953896+J|0]|0;J=d[2020944+Q|0]|0;a[O]=a[((I&65535)<<16>>16)+(311880+(Q<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(311880+(Q<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(311880+(Q<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(311880+(Q<<2))|0]|0;pe[c[e+44>>2]&1023](h+K|0,l,J,N,O)}if(!t){i=n;return}N=A+y|0;J=A+z|0;if(N>>>0<68>>>0|J>>>0<68>>>0){i=n;return}Q=d[1953896+J|0]|0;J=d[2020944+N|0]|0;a[O]=a[(b[L>>1]|0)+(311880+(N<<2))|0]|0;I=L+2|0;P=o+1|0;a[P]=a[(b[I>>1]|0)+(311880+(N<<2))|0]|0;ba=L+4|0;M=o+2|0;a[M]=a[(b[ba>>1]|0)+(311880+(N<<2))|0]|0;_=L+6|0;U=o+3|0;a[U]=a[(b[_>>1]|0)+(311880+(N<<2))|0]|0;R=e+44|0;pe[c[R>>2]&1023](j+K|0,l,J,Q,O);a[O]=a[(b[L>>1]|0)+(311880+(N<<2))|0]|0;a[P]=a[(b[I>>1]|0)+(311880+(N<<2))|0]|0;a[M]=a[(b[ba>>1]|0)+(311880+(N<<2))|0]|0;a[U]=a[(b[_>>1]|0)+(311880+(N<<2))|0]|0;pe[c[R>>2]&1023](k+K|0,l,J,Q,O);i=n;return}else{if(!D){O=(c[e+177100>>2]|0)!=3?1144344:1144336;Q=(v|0)!=0;do{if(Q){J=E+y|0;K=E+z|0;if(J>>>0<68>>>0|K>>>0<68>>>0){break}mf[c[e+60>>2]&2047](h,l,d[2020944+J|0]|0,d[1953896+K|0]|0)}}while(0);D=(x&16777216|0)!=0;K=o|0;J=B+y|0;R=2020944+J|0;N=B+z|0;_=1953896+N|0;U=J>>>0<68>>>0|N>>>0<68>>>0;do{if(D){if(!U){N=d[_]|0;ba=d[R]|0;mrc(K|0,a[311883+(J<<2)|0]|0,4)|0;pe[c[e+48>>2]&1023](h+16|0,l,ba,N,K)}do{if((w|0)!=0){N=F+y|0;ba=d[2020944+N|0]|0;M=F+z|0;I=d[1953896+M|0]|0;if(N>>>0<68>>>0|M>>>0<68>>>0){break}M=b[O>>1]|0;if(M<<16>>16<4){a[K]=a[(M<<16>>16)+(311880+(N<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(N<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(N<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(N<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,ba,I,K);break}else{mf[c[e+56>>2]&2047](h,l,ba,I);break}}}while(0);if(U){break}r=d[_]|0;aa=d[R]|0;mrc(K|0,a[311883+(J<<2)|0]|0,4)|0;pe[c[e+44>>2]&1023](h+(l<<3)|0,l,aa,r,K)}else{if(!U){r=d[_]|0;aa=d[R]|0;I=a[311883+(J<<2)|0]|0;ba=e+48|0;mrc(K|0,I|0,4)|0;pe[c[ba>>2]&1023](h+8|0,l,aa,r,K);mrc(K|0,I|0,4)|0;pe[c[ba>>2]&1023](h+16|0,l,aa,r,K);mrc(K|0,I|0,4)|0;pe[c[ba>>2]&1023](h+24|0,l,aa,r,K)}do{if((w|0)!=0){r=F+y|0;aa=d[2020944+r|0]|0;ba=F+z|0;I=d[1953896+ba|0]|0;if(r>>>0<68>>>0|ba>>>0<68>>>0){break}ba=b[O>>1]|0;if(ba<<16>>16<4){a[K]=a[(ba<<16>>16)+(311880+(r<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(r<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(r<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(r<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,aa,I,K);break}else{mf[c[e+56>>2]&2047](h,l,aa,I);break}}}while(0);if(U){break}I=d[_]|0;aa=d[R]|0;r=a[311883+(J<<2)|0]|0;ba=e+44|0;mrc(K|0,r|0,4)|0;pe[c[ba>>2]&1023](h+(l<<2)|0,l,aa,I,K);mrc(K|0,r|0,4)|0;pe[c[ba>>2]&1023](h+(l<<3)|0,l,aa,I,K);mrc(K|0,r|0,4)|0;pe[c[ba>>2]&1023](h+(l*12|0)|0,l,aa,I,K)}}while(0);if(!s){i=n;return}if(t){do{if(Q){J=G+y|0;R=G+z|0;if(J>>>0<68>>>0|R>>>0<68>>>0){break}_=d[1953896+R|0]|0;R=d[2020944+J|0]|0;J=e+60|0;mf[c[J>>2]&2047](j,l,R,_);mf[c[J>>2]&2047](k,l,R,_)}}while(0);_=A+y|0;R=2020944+_|0;J=A+z|0;U=1953896+J|0;I=_>>>0<68>>>0|J>>>0<68>>>0;if(D){if(!I){J=d[U]|0;aa=d[R]|0;ba=a[311883+(_<<2)|0]|0;r=e+48|0;mrc(K|0,ba|0,4)|0;pe[c[r>>2]&1023](j+16|0,l,aa,J,K);mrc(K|0,ba|0,4)|0;pe[c[r>>2]&1023](k+16|0,l,aa,J,K)}do{if((w|0)!=0){J=C+y|0;aa=d[2020944+J|0]|0;r=C+z|0;ba=d[1953896+r|0]|0;if(J>>>0<68>>>0|r>>>0<68>>>0){break}r=b[O>>1]|0;if(r<<16>>16<4){a[K]=a[(r<<16>>16)+(311880+(J<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(J<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(J<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(J<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,aa,ba,K);a[K]=a[(r<<16>>16)+(311880+(J<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(J<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(J<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(J<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,aa,ba,K);break}else{mf[c[e+56>>2]&2047](j,l,aa,ba);mf[c[e+56>>2]&2047](k,l,aa,ba);break}}}while(0);D=l<<3;if(I){i=n;return}ba=d[U]|0;aa=d[R]|0;J=a[311883+(_<<2)|0]|0;r=e+44|0;mrc(K|0,J|0,4)|0;pe[c[r>>2]&1023](j+D|0,l,aa,ba,K);mrc(K|0,J|0,4)|0;pe[c[r>>2]&1023](k+D|0,l,aa,ba,K);i=n;return}else{if(!I){ba=d[U]|0;aa=d[R]|0;D=a[311883+(_<<2)|0]|0;r=e+48|0;mrc(K|0,D|0,4)|0;pe[c[r>>2]&1023](j+8|0,l,aa,ba,K);mrc(K|0,D|0,4)|0;pe[c[r>>2]&1023](k+8|0,l,aa,ba,K);mrc(K|0,D|0,4)|0;pe[c[r>>2]&1023](j+16|0,l,aa,ba,K);mrc(K|0,D|0,4)|0;pe[c[r>>2]&1023](k+16|0,l,aa,ba,K);mrc(K|0,D|0,4)|0;pe[c[r>>2]&1023](j+24|0,l,aa,ba,K);mrc(K|0,D|0,4)|0;pe[c[r>>2]&1023](k+24|0,l,aa,ba,K)}do{if((w|0)!=0){ba=C+y|0;aa=d[2020944+ba|0]|0;r=C+z|0;D=d[1953896+r|0]|0;if(ba>>>0<68>>>0|r>>>0<68>>>0){break}r=b[O>>1]|0;if(r<<16>>16<4){a[K]=a[(r<<16>>16)+(311880+(ba<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(ba<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(ba<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(ba<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,aa,D,K);a[K]=a[(r<<16>>16)+(311880+(ba<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(ba<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(ba<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(ba<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,aa,D,K);break}else{mf[c[e+56>>2]&2047](j,l,aa,D);mf[c[e+56>>2]&2047](k,l,aa,D);break}}}while(0);D=l<<2;if(I){i=n;return}aa=d[U]|0;ba=d[R]|0;r=a[311883+(_<<2)|0]|0;J=e+44|0;mrc(K|0,r|0,4)|0;pe[c[J>>2]&1023](j+D|0,l,ba,aa,K);mrc(K|0,r|0,4)|0;pe[c[J>>2]&1023](k+D|0,l,ba,aa,K);D=l<<3;mrc(K|0,r|0,4)|0;pe[c[J>>2]&1023](j+D|0,l,ba,aa,K);mrc(K|0,r|0,4)|0;pe[c[J>>2]&1023](k+D|0,l,ba,aa,K);D=l*12|0;mrc(K|0,r|0,4)|0;pe[c[J>>2]&1023](j+D|0,l,ba,aa,K);mrc(K|0,r|0,4)|0;pe[c[J>>2]&1023](k+D|0,l,ba,aa,K);i=n;return}}if(u){do{if(Q){aa=G+y|0;ba=G+z|0;if(aa>>>0<68>>>0|ba>>>0<68>>>0){break}D=d[1953896+ba|0]|0;ba=d[2020944+aa|0]|0;aa=e+84|0;mf[c[aa>>2]&2047](j,m,ba,D);mf[c[aa>>2]&2047](k,m,ba,D)}}while(0);u=A+y|0;_=2020944+u|0;R=A+z|0;U=1953896+R|0;I=u>>>0<68>>>0|R>>>0<68>>>0;if(!I){R=d[U]|0;D=d[_]|0;ba=(a[311883+(u<<2)|0]|0)+1&255;aa=e+72|0;mrc(K|0,ba|0,4)|0;pe[c[aa>>2]&1023](j+8|0,m,D,R,K);mrc(K|0,ba|0,4)|0;pe[c[aa>>2]&1023](k+8|0,m,D,R,K)}do{if((w|0)!=0){R=C+y|0;D=d[2020944+R|0]|0;aa=C+z|0;ba=d[1953896+aa|0]|0;if(R>>>0<68>>>0|aa>>>0<68>>>0){break}aa=b[O>>1]|0;if(aa<<16>>16<4){a[K]=(a[(aa<<16>>16)+(311880+(R<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(311880+(R<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(311880+(R<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(311880+(R<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,D,ba,K);a[K]=(a[(aa<<16>>16)+(311880+(R<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(311880+(R<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(311880+(R<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(311880+(R<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,D,ba,K);break}else{mf[c[e+80>>2]&2047](j,m,D,ba);mf[c[e+80>>2]&2047](k,m,D,ba);break}}}while(0);ba=m<<2;if(I){i=n;return}D=d[U]|0;R=d[_]|0;aa=(a[311883+(u<<2)|0]|0)+1&255;J=e+68|0;mrc(K|0,aa|0,4)|0;pe[c[J>>2]&1023](j+ba|0,m,R,D,K);mrc(K|0,aa|0,4)|0;pe[c[J>>2]&1023](k+ba|0,m,R,D,K);ba=m<<3;mrc(K|0,aa|0,4)|0;pe[c[J>>2]&1023](j+ba|0,m,R,D,K);mrc(K|0,aa|0,4)|0;pe[c[J>>2]&1023](k+ba|0,m,R,D,K);ba=m*12|0;mrc(K|0,aa|0,4)|0;pe[c[J>>2]&1023](j+ba|0,m,R,D,K);mrc(K|0,aa|0,4)|0;pe[c[J>>2]&1023](k+ba|0,m,R,D,K);i=n;return}else{do{if(Q){D=G+y|0;R=G+z|0;if(D>>>0<68>>>0|R>>>0<68>>>0){break}ba=d[1953896+R|0]|0;R=d[2020944+D|0]|0;D=e+84|0;mf[c[D>>2]&2047](j,m,R,ba);mf[c[D>>2]&2047](k,m,R,ba)}}while(0);Q=A+y|0;u=2020944+Q|0;_=A+z|0;U=1953896+_|0;I=Q>>>0<68>>>0|_>>>0<68>>>0;if(!I){_=d[U]|0;ba=d[u]|0;R=(a[311883+(Q<<2)|0]|0)+1&255;D=e+72|0;mrc(K|0,R|0,4)|0;pe[c[D>>2]&1023](j+8|0,m,ba,_,K);mrc(K|0,R|0,4)|0;pe[c[D>>2]&1023](k+8|0,m,ba,_,K)}do{if((w|0)!=0){_=C+y|0;ba=d[2020944+_|0]|0;D=C+z|0;R=d[1953896+D|0]|0;if(_>>>0<68>>>0|D>>>0<68>>>0){break}D=b[O>>1]|0;if(D<<16>>16<4){a[K]=(a[(D<<16>>16)+(311880+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(311880+(_<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,ba,R,K);a[K]=(a[(D<<16>>16)+(311880+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(311880+(_<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,ba,R,K);break}else{mf[c[e+80>>2]&2047](j,m,ba,R);mf[c[e+80>>2]&2047](k,m,ba,R);break}}}while(0);O=m<<2;if(I){i=n;return}R=d[U]|0;ba=d[u]|0;_=(a[311883+(Q<<2)|0]|0)+1&255;D=e+68|0;mrc(K|0,_|0,4)|0;pe[c[D>>2]&1023](j+O|0,m,ba,R,K);mrc(K|0,_|0,4)|0;pe[c[D>>2]&1023](k+O|0,m,ba,R,K);i=n;return}}R=p;ba=(x&16777216|0)!=0;O=c[e+426564>>2]|0;do{if(ba){if((O&7|0)!=7|t){S=80;break}D=p|0;c[D>>2]=131074;c[D+4>>2]=131074;D=p+16|0;c[D>>2]=131074;c[D+4>>2]=131074;D=p+32|0;c[D>>2]=131074;c[D+4>>2]=131074;D=p+48|0;c[D>>2]=131074;c[D+4>>2]=131074;ca=4}else{S=80}}while(0);if((S|0)==80){K=-((x*5|0)>>>5&1)&3|x>>4;Q=4-(-((O&15|0)==0&x>>>3)&3)|0;Ve[q&127](R,e+5184|0,e+5632|0,e+5312|0,(c[e+199428>>2]|0)==2|0,Q,(x>>24)+1|0,-((v*5|0)>>>5&1&K>>>1)&3,K,(c[e+177100>>2]|0)!=3|0);ca=Q}if((v&7|0)!=0){Q=p|0;c[Q>>2]=262148;c[Q+4>>2]=262148}if((w&7|0)!=0){Q=(c[e+177100>>2]|0)!=3;K=p+32|0;c[K>>2]=Q?196611:262148;c[K+4>>2]=Q?196611:262148}do{if((v|0)!=0){Q=p;K=p|0;u=c[K>>2]|0;U=u&65535;if((u|0)==0&(c[K+4>>2]|0)==0){break}K=o|0;u=E+y|0;I=d[2020944+u|0]|0;D=E+z|0;_=d[1953896+D|0]|0;do{if(!(u>>>0<68>>>0|D>>>0<68>>>0)){if(U<<16>>16<4){a[K]=a[(U<<16>>16)+(311880+(u<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(311880+(u<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(311880+(u<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(311880+(u<<2))|0]|0;pe[c[e+48>>2]&1023](h,l,I,_,K);break}else{mf[c[e+60>>2]&2047](h,l,I,_);break}}}while(0);if(!s){break}_=G+y|0;I=d[2020944+_|0]|0;u=G+z|0;U=d[1953896+u|0]|0;D=_>>>0<68>>>0|u>>>0<68>>>0;if(t){if(D){break}u=b[Q>>1]|0;if(u<<16>>16<4){a[K]=a[(u<<16>>16)+(311880+(_<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(311880+(_<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(311880+(_<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(311880+(_<<2))|0]|0;pe[c[e+48>>2]&1023](j,l,I,U,K)}else{mf[c[e+60>>2]&2047](j,l,I,U)}u=b[Q>>1]|0;if(u<<16>>16<4){a[K]=a[(u<<16>>16)+(311880+(_<<2))|0]|0;a[o+1|0]=a[(b[Q+2>>1]|0)+(311880+(_<<2))|0]|0;a[o+2|0]=a[(b[Q+4>>1]|0)+(311880+(_<<2))|0]|0;a[o+3|0]=a[(b[Q+6>>1]|0)+(311880+(_<<2))|0]|0;pe[c[e+48>>2]&1023](k,l,I,U,K);break}else{mf[c[e+60>>2]&2047](k,l,I,U);break}}else{if(D){break}D=b[Q>>1]|0;if(D<<16>>16<4){a[K]=(a[(D<<16>>16)+(311880+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[Q+2>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[Q+4>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[Q+6>>1]|0)+(311880+(_<<2))|0]|0)+1;pe[c[e+72>>2]&1023](j,m,I,U,K)}else{mf[c[e+84>>2]&2047](j,m,I,U)}D=b[Q>>1]|0;if(D<<16>>16<4){a[K]=(a[(D<<16>>16)+(311880+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[Q+2>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[Q+4>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[Q+6>>1]|0)+(311880+(_<<2))|0]|0)+1;pe[c[e+72>>2]&1023](k,m,I,U,K);break}else{mf[c[e+84>>2]&2047](k,m,I,U);break}}}}while(0);if((ca|0)==1){if((w|0)==0){i=n;return}G=p+32|0;E=G;v=G|0;G=c[v>>2]|0;x=G&65535;if((G|0)==0&(c[v+4>>2]|0)==0){i=n;return}v=o|0;G=F+y|0;R=d[2020944+G|0]|0;O=F+z|0;U=d[1953896+O|0]|0;do{if(!(G>>>0<68>>>0|O>>>0<68>>>0)){if(x<<16>>16<4){a[v]=a[(x<<16>>16)+(311880+(G<<2))|0]|0;a[o+1|0]=a[(b[E+2>>1]|0)+(311880+(G<<2))|0]|0;a[o+2|0]=a[(b[E+4>>1]|0)+(311880+(G<<2))|0]|0;a[o+3|0]=a[(b[E+6>>1]|0)+(311880+(G<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,R,U,v);break}else{mf[c[e+56>>2]&2047](h,l,R,U);break}}}while(0);if(!s){i=n;return}U=C+y|0;R=d[2020944+U|0]|0;G=C+z|0;x=d[1953896+G|0]|0;O=U>>>0<68>>>0|G>>>0<68>>>0;if(t){if(O){i=n;return}G=b[E>>1]|0;if(G<<16>>16<4){a[v]=a[(G<<16>>16)+(311880+(U<<2))|0]|0;a[o+1|0]=a[(b[E+2>>1]|0)+(311880+(U<<2))|0]|0;a[o+2|0]=a[(b[E+4>>1]|0)+(311880+(U<<2))|0]|0;a[o+3|0]=a[(b[E+6>>1]|0)+(311880+(U<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,R,x,v)}else{mf[c[e+56>>2]&2047](j,l,R,x)}G=b[E>>1]|0;if(G<<16>>16<4){a[v]=a[(G<<16>>16)+(311880+(U<<2))|0]|0;a[o+1|0]=a[(b[E+2>>1]|0)+(311880+(U<<2))|0]|0;a[o+2|0]=a[(b[E+4>>1]|0)+(311880+(U<<2))|0]|0;a[o+3|0]=a[(b[E+6>>1]|0)+(311880+(U<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,R,x,v);i=n;return}else{mf[c[e+56>>2]&2047](k,l,R,x);i=n;return}}else{if(O){i=n;return}O=b[E>>1]|0;if(O<<16>>16<4){a[v]=(a[(O<<16>>16)+(311880+(U<<2))|0]|0)+1;a[o+1|0]=(a[(b[E+2>>1]|0)+(311880+(U<<2))|0]|0)+1;a[o+2|0]=(a[(b[E+4>>1]|0)+(311880+(U<<2))|0]|0)+1;a[o+3|0]=(a[(b[E+6>>1]|0)+(311880+(U<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,R,x,v)}else{mf[c[e+80>>2]&2047](j,m,R,x)}O=b[E>>1]|0;if(O<<16>>16<4){a[v]=(a[(O<<16>>16)+(311880+(U<<2))|0]|0)+1;a[o+1|0]=(a[(b[E+2>>1]|0)+(311880+(U<<2))|0]|0)+1;a[o+2|0]=(a[(b[E+4>>1]|0)+(311880+(U<<2))|0]|0)+1;a[o+3|0]=(a[(b[E+6>>1]|0)+(311880+(U<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,R,x,v);i=n;return}else{mf[c[e+80>>2]&2047](k,m,R,x);i=n;return}}}if(ba){x=p+16|0;R=x;U=x|0;x=c[U>>2]|0;O=x&65535;do{if(!((x|0)==0&(c[U+4>>2]|0)==0)){G=o|0;I=B+y|0;_=B+z|0;if(!(I>>>0<68>>>0|_>>>0<68>>>0)){D=d[1953896+_|0]|0;_=d[2020944+I|0]|0;a[G]=a[(O<<16>>16)+(311880+(I<<2))|0]|0;a[o+1|0]=a[(b[R+2>>1]|0)+(311880+(I<<2))|0]|0;a[o+2|0]=a[(b[R+4>>1]|0)+(311880+(I<<2))|0]|0;a[o+3|0]=a[(b[R+6>>1]|0)+(311880+(I<<2))|0]|0;pe[c[e+48>>2]&1023](h+16|0,l,_,D,G)}if(!s){break}D=A+y|0;_=A+z|0;I=D>>>0<68>>>0|_>>>0<68>>>0;if(t){if(I){break}u=d[1953896+_|0]|0;J=d[2020944+D|0]|0;a[G]=a[(b[R>>1]|0)+(311880+(D<<2))|0]|0;aa=R+2|0;r=o+1|0;a[r]=a[(b[aa>>1]|0)+(311880+(D<<2))|0]|0;N=R+4|0;M=o+2|0;a[M]=a[(b[N>>1]|0)+(311880+(D<<2))|0]|0;P=R+6|0;L=o+3|0;a[L]=a[(b[P>>1]|0)+(311880+(D<<2))|0]|0;$=e+48|0;pe[c[$>>2]&1023](j+16|0,l,J,u,G);a[G]=a[(b[R>>1]|0)+(311880+(D<<2))|0]|0;a[r]=a[(b[aa>>1]|0)+(311880+(D<<2))|0]|0;a[M]=a[(b[N>>1]|0)+(311880+(D<<2))|0]|0;a[L]=a[(b[P>>1]|0)+(311880+(D<<2))|0]|0;pe[c[$>>2]&1023](k+16|0,l,J,u,G);break}else{if(I){break}I=d[1953896+_|0]|0;_=d[2020944+D|0]|0;a[G]=(a[(b[R>>1]|0)+(311880+(D<<2))|0]|0)+1;u=R+2|0;J=o+1|0;a[J]=(a[(b[u>>1]|0)+(311880+(D<<2))|0]|0)+1;$=R+4|0;P=o+2|0;a[P]=(a[(b[$>>1]|0)+(311880+(D<<2))|0]|0)+1;L=R+6|0;N=o+3|0;a[N]=(a[(b[L>>1]|0)+(311880+(D<<2))|0]|0)+1;M=e+72|0;pe[c[M>>2]&1023](j+8|0,m,_,I,G);a[G]=(a[(b[R>>1]|0)+(311880+(D<<2))|0]|0)+1;a[J]=(a[(b[u>>1]|0)+(311880+(D<<2))|0]|0)+1;a[P]=(a[(b[$>>1]|0)+(311880+(D<<2))|0]|0)+1;a[N]=(a[(b[L>>1]|0)+(311880+(D<<2))|0]|0)+1;pe[c[M>>2]&1023](k+8|0,m,_,I,G);break}}}while(0);do{if((w|0)!=0){R=p+32|0;O=R;U=R|0;R=c[U>>2]|0;x=R&65535;if((R|0)==0&(c[U+4>>2]|0)==0){break}U=o|0;R=F+y|0;ba=d[2020944+R|0]|0;v=F+z|0;E=d[1953896+v|0]|0;do{if(!(R>>>0<68>>>0|v>>>0<68>>>0)){if(x<<16>>16<4){a[U]=a[(x<<16>>16)+(311880+(R<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(R<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(R<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(R<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,ba,E,U);break}else{mf[c[e+56>>2]&2047](h,l,ba,E);break}}}while(0);if(!s){break}E=C+y|0;ba=d[2020944+E|0]|0;R=C+z|0;x=d[1953896+R|0]|0;v=E>>>0<68>>>0|R>>>0<68>>>0;if(t){if(v){break}R=b[O>>1]|0;if(R<<16>>16<4){a[U]=a[(R<<16>>16)+(311880+(E<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(E<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(E<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(E<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,ba,x,U)}else{mf[c[e+56>>2]&2047](j,l,ba,x)}R=b[O>>1]|0;if(R<<16>>16<4){a[U]=a[(R<<16>>16)+(311880+(E<<2))|0]|0;a[o+1|0]=a[(b[O+2>>1]|0)+(311880+(E<<2))|0]|0;a[o+2|0]=a[(b[O+4>>1]|0)+(311880+(E<<2))|0]|0;a[o+3|0]=a[(b[O+6>>1]|0)+(311880+(E<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,ba,x,U);break}else{mf[c[e+56>>2]&2047](k,l,ba,x);break}}else{if(v){break}v=b[O>>1]|0;if(v<<16>>16<4){a[U]=(a[(v<<16>>16)+(311880+(E<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(311880+(E<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(311880+(E<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(311880+(E<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,ba,x,U)}else{mf[c[e+80>>2]&2047](j,m,ba,x)}v=b[O>>1]|0;if(v<<16>>16<4){a[U]=(a[(v<<16>>16)+(311880+(E<<2))|0]|0)+1;a[o+1|0]=(a[(b[O+2>>1]|0)+(311880+(E<<2))|0]|0)+1;a[o+2|0]=(a[(b[O+4>>1]|0)+(311880+(E<<2))|0]|0)+1;a[o+3|0]=(a[(b[O+6>>1]|0)+(311880+(E<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,ba,x,U);break}else{mf[c[e+80>>2]&2047](k,m,ba,x);break}}}}while(0);x=p+48|0;ba=x;E=x|0;x=c[E>>2]|0;if((x|0)==0&(c[E+4>>2]|0)==0){i=n;return}E=l<<3;v=o|0;R=B+y|0;K=B+z|0;if(!(R>>>0<68>>>0|K>>>0<68>>>0)){Q=d[1953896+K|0]|0;K=d[2020944+R|0]|0;a[v]=a[((x&65535)<<16>>16)+(311880+(R<<2))|0]|0;a[o+1|0]=a[(b[ba+2>>1]|0)+(311880+(R<<2))|0]|0;a[o+2|0]=a[(b[ba+4>>1]|0)+(311880+(R<<2))|0]|0;a[o+3|0]=a[(b[ba+6>>1]|0)+(311880+(R<<2))|0]|0;pe[c[e+44>>2]&1023](h+E|0,l,K,Q,v)}if(!s){i=n;return}if(t){Q=A+y|0;K=A+z|0;if(Q>>>0<68>>>0|K>>>0<68>>>0){i=n;return}R=d[1953896+K|0]|0;K=d[2020944+Q|0]|0;a[v]=a[(b[ba>>1]|0)+(311880+(Q<<2))|0]|0;x=ba+2|0;G=o+1|0;a[G]=a[(b[x>>1]|0)+(311880+(Q<<2))|0]|0;I=ba+4|0;_=o+2|0;a[_]=a[(b[I>>1]|0)+(311880+(Q<<2))|0]|0;M=ba+6|0;D=o+3|0;a[D]=a[(b[M>>1]|0)+(311880+(Q<<2))|0]|0;L=e+44|0;pe[c[L>>2]&1023](j+E|0,l,K,R,v);a[v]=a[(b[ba>>1]|0)+(311880+(Q<<2))|0]|0;a[G]=a[(b[x>>1]|0)+(311880+(Q<<2))|0]|0;a[_]=a[(b[I>>1]|0)+(311880+(Q<<2))|0]|0;a[D]=a[(b[M>>1]|0)+(311880+(Q<<2))|0]|0;pe[c[L>>2]&1023](k+E|0,l,K,R,v);i=n;return}else{R=m<<2;K=A+y|0;E=A+z|0;if(K>>>0<68>>>0|E>>>0<68>>>0){i=n;return}L=d[1953896+E|0]|0;E=d[2020944+K|0]|0;a[v]=(a[(b[ba>>1]|0)+(311880+(K<<2))|0]|0)+1;Q=ba+2|0;M=o+1|0;a[M]=(a[(b[Q>>1]|0)+(311880+(K<<2))|0]|0)+1;D=ba+4|0;I=o+2|0;a[I]=(a[(b[D>>1]|0)+(311880+(K<<2))|0]|0)+1;_=ba+6|0;x=o+3|0;a[x]=(a[(b[_>>1]|0)+(311880+(K<<2))|0]|0)+1;G=e+68|0;pe[c[G>>2]&1023](j+R|0,m,E,L,v);a[v]=(a[(b[ba>>1]|0)+(311880+(K<<2))|0]|0)+1;a[M]=(a[(b[Q>>1]|0)+(311880+(K<<2))|0]|0)+1;a[I]=(a[(b[D>>1]|0)+(311880+(K<<2))|0]|0)+1;a[x]=(a[(b[_>>1]|0)+(311880+(K<<2))|0]|0)+1;pe[c[G>>2]&1023](k+R|0,m,E,L,v);i=n;return}}v=p+8|0;L=v;E=v|0;v=c[E>>2]|0;R=v&65535;do{if(!((v|0)==0&(c[E+4>>2]|0)==0)){G=o|0;K=B+y|0;_=B+z|0;if(!(K>>>0<68>>>0|_>>>0<68>>>0)){x=d[1953896+_|0]|0;_=d[2020944+K|0]|0;a[G]=a[(R<<16>>16)+(311880+(K<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(311880+(K<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(311880+(K<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(311880+(K<<2))|0]|0;pe[c[e+48>>2]&1023](h+8|0,l,_,x,G)}if(!t){break}x=A+y|0;_=A+z|0;if(x>>>0<68>>>0|_>>>0<68>>>0){break}K=d[1953896+_|0]|0;_=d[2020944+x|0]|0;a[G]=a[(b[L>>1]|0)+(311880+(x<<2))|0]|0;D=L+2|0;I=o+1|0;a[I]=a[(b[D>>1]|0)+(311880+(x<<2))|0]|0;Q=L+4|0;M=o+2|0;a[M]=a[(b[Q>>1]|0)+(311880+(x<<2))|0]|0;ba=L+6|0;N=o+3|0;a[N]=a[(b[ba>>1]|0)+(311880+(x<<2))|0]|0;$=e+48|0;pe[c[$>>2]&1023](j+8|0,l,_,K,G);a[G]=a[(b[L>>1]|0)+(311880+(x<<2))|0]|0;a[I]=a[(b[D>>1]|0)+(311880+(x<<2))|0]|0;a[M]=a[(b[Q>>1]|0)+(311880+(x<<2))|0]|0;a[N]=a[(b[ba>>1]|0)+(311880+(x<<2))|0]|0;pe[c[$>>2]&1023](k+8|0,l,_,K,G)}}while(0);L=p+16|0;R=L;E=L|0;L=c[E>>2]|0;v=L&65535;do{if(!((L|0)==0&(c[E+4>>2]|0)==0)){G=o|0;K=B+y|0;_=B+z|0;if(!(K>>>0<68>>>0|_>>>0<68>>>0)){$=d[1953896+_|0]|0;_=d[2020944+K|0]|0;a[G]=a[(v<<16>>16)+(311880+(K<<2))|0]|0;a[o+1|0]=a[(b[R+2>>1]|0)+(311880+(K<<2))|0]|0;a[o+2|0]=a[(b[R+4>>1]|0)+(311880+(K<<2))|0]|0;a[o+3|0]=a[(b[R+6>>1]|0)+(311880+(K<<2))|0]|0;pe[c[e+48>>2]&1023](h+16|0,l,_,$,G)}if(!s){break}$=A+y|0;_=A+z|0;K=$>>>0<68>>>0|_>>>0<68>>>0;if(t){if(K){break}x=d[1953896+_|0]|0;ba=d[2020944+$|0]|0;a[G]=a[(b[R>>1]|0)+(311880+($<<2))|0]|0;N=R+2|0;Q=o+1|0;a[Q]=a[(b[N>>1]|0)+(311880+($<<2))|0]|0;M=R+4|0;D=o+2|0;a[D]=a[(b[M>>1]|0)+(311880+($<<2))|0]|0;I=R+6|0;P=o+3|0;a[P]=a[(b[I>>1]|0)+(311880+($<<2))|0]|0;u=e+48|0;pe[c[u>>2]&1023](j+16|0,l,ba,x,G);a[G]=a[(b[R>>1]|0)+(311880+($<<2))|0]|0;a[Q]=a[(b[N>>1]|0)+(311880+($<<2))|0]|0;a[D]=a[(b[M>>1]|0)+(311880+($<<2))|0]|0;a[P]=a[(b[I>>1]|0)+(311880+($<<2))|0]|0;pe[c[u>>2]&1023](k+16|0,l,ba,x,G);break}else{if(K){break}K=d[1953896+_|0]|0;_=d[2020944+$|0]|0;a[G]=(a[(b[R>>1]|0)+(311880+($<<2))|0]|0)+1;x=R+2|0;ba=o+1|0;a[ba]=(a[(b[x>>1]|0)+(311880+($<<2))|0]|0)+1;u=R+4|0;I=o+2|0;a[I]=(a[(b[u>>1]|0)+(311880+($<<2))|0]|0)+1;P=R+6|0;M=o+3|0;a[M]=(a[(b[P>>1]|0)+(311880+($<<2))|0]|0)+1;D=e+72|0;pe[c[D>>2]&1023](j+8|0,m,_,K,G);a[G]=(a[(b[R>>1]|0)+(311880+($<<2))|0]|0)+1;a[ba]=(a[(b[x>>1]|0)+(311880+($<<2))|0]|0)+1;a[I]=(a[(b[u>>1]|0)+(311880+($<<2))|0]|0)+1;a[M]=(a[(b[P>>1]|0)+(311880+($<<2))|0]|0)+1;pe[c[D>>2]&1023](k+8|0,m,_,K,G);break}}}while(0);R=p+24|0;v=R;E=R|0;R=c[E>>2]|0;L=R&65535;do{if(!((R|0)==0&(c[E+4>>2]|0)==0)){G=o|0;K=B+y|0;_=B+z|0;if(!(K>>>0<68>>>0|_>>>0<68>>>0)){D=d[1953896+_|0]|0;_=d[2020944+K|0]|0;a[G]=a[(L<<16>>16)+(311880+(K<<2))|0]|0;a[o+1|0]=a[(b[v+2>>1]|0)+(311880+(K<<2))|0]|0;a[o+2|0]=a[(b[v+4>>1]|0)+(311880+(K<<2))|0]|0;a[o+3|0]=a[(b[v+6>>1]|0)+(311880+(K<<2))|0]|0;pe[c[e+48>>2]&1023](h+24|0,l,_,D,G)}if(!t){break}D=A+y|0;_=A+z|0;if(D>>>0<68>>>0|_>>>0<68>>>0){break}K=d[1953896+_|0]|0;_=d[2020944+D|0]|0;a[G]=a[(b[v>>1]|0)+(311880+(D<<2))|0]|0;$=v+2|0;P=o+1|0;a[P]=a[(b[$>>1]|0)+(311880+(D<<2))|0]|0;M=v+4|0;u=o+2|0;a[u]=a[(b[M>>1]|0)+(311880+(D<<2))|0]|0;I=v+6|0;x=o+3|0;a[x]=a[(b[I>>1]|0)+(311880+(D<<2))|0]|0;ba=e+48|0;pe[c[ba>>2]&1023](j+24|0,l,_,K,G);a[G]=a[(b[v>>1]|0)+(311880+(D<<2))|0]|0;a[P]=a[(b[$>>1]|0)+(311880+(D<<2))|0]|0;a[u]=a[(b[M>>1]|0)+(311880+(D<<2))|0]|0;a[x]=a[(b[I>>1]|0)+(311880+(D<<2))|0]|0;pe[c[ba>>2]&1023](k+24|0,l,_,K,G)}}while(0);do{if((w|0)!=0){v=p+32|0;L=v;E=v|0;v=c[E>>2]|0;R=v&65535;if((v|0)==0&(c[E+4>>2]|0)==0){break}E=o|0;v=F+y|0;G=d[2020944+v|0]|0;K=F+z|0;_=d[1953896+K|0]|0;do{if(!(v>>>0<68>>>0|K>>>0<68>>>0)){if(R<<16>>16<4){a[E]=a[(R<<16>>16)+(311880+(v<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(311880+(v<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(311880+(v<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(311880+(v<<2))|0]|0;pe[c[e+44>>2]&1023](h,l,G,_,E);break}else{mf[c[e+56>>2]&2047](h,l,G,_);break}}}while(0);if(!s){break}_=C+y|0;G=d[2020944+_|0]|0;v=C+z|0;R=d[1953896+v|0]|0;K=_>>>0<68>>>0|v>>>0<68>>>0;if(t){if(K){break}v=b[L>>1]|0;if(v<<16>>16<4){a[E]=a[(v<<16>>16)+(311880+(_<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(311880+(_<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(311880+(_<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(311880+(_<<2))|0]|0;pe[c[e+44>>2]&1023](j,l,G,R,E)}else{mf[c[e+56>>2]&2047](j,l,G,R)}v=b[L>>1]|0;if(v<<16>>16<4){a[E]=a[(v<<16>>16)+(311880+(_<<2))|0]|0;a[o+1|0]=a[(b[L+2>>1]|0)+(311880+(_<<2))|0]|0;a[o+2|0]=a[(b[L+4>>1]|0)+(311880+(_<<2))|0]|0;a[o+3|0]=a[(b[L+6>>1]|0)+(311880+(_<<2))|0]|0;pe[c[e+44>>2]&1023](k,l,G,R,E);break}else{mf[c[e+56>>2]&2047](k,l,G,R);break}}else{if(K){break}K=b[L>>1]|0;if(K<<16>>16<4){a[E]=(a[(K<<16>>16)+(311880+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[L+2>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[L+4>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[L+6>>1]|0)+(311880+(_<<2))|0]|0)+1;pe[c[e+68>>2]&1023](j,m,G,R,E)}else{mf[c[e+80>>2]&2047](j,m,G,R)}K=b[L>>1]|0;if(K<<16>>16<4){a[E]=(a[(K<<16>>16)+(311880+(_<<2))|0]|0)+1;a[o+1|0]=(a[(b[L+2>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+2|0]=(a[(b[L+4>>1]|0)+(311880+(_<<2))|0]|0)+1;a[o+3|0]=(a[(b[L+6>>1]|0)+(311880+(_<<2))|0]|0)+1;pe[c[e+68>>2]&1023](k,m,G,R,E);break}else{mf[c[e+80>>2]&2047](k,m,G,R);break}}}}while(0);C=p+40|0;F=C;w=C|0;C=c[w>>2]|0;R=C&65535;do{if(!((C|0)==0&(c[w+4>>2]|0)==0)){G=l<<2;_=o|0;K=B+y|0;v=B+z|0;if(!(K>>>0<68>>>0|v>>>0<68>>>0)){U=d[1953896+v|0]|0;v=d[2020944+K|0]|0;a[_]=a[(R<<16>>16)+(311880+(K<<2))|0]|0;a[o+1|0]=a[(b[F+2>>1]|0)+(311880+(K<<2))|0]|0;a[o+2|0]=a[(b[F+4>>1]|0)+(311880+(K<<2))|0]|0;a[o+3|0]=a[(b[F+6>>1]|0)+(311880+(K<<2))|0]|0;pe[c[e+44>>2]&1023](h+G|0,l,v,U,_)}if(!t){break}U=A+y|0;v=A+z|0;if(U>>>0<68>>>0|v>>>0<68>>>0){break}K=d[1953896+v|0]|0;v=d[2020944+U|0]|0;a[_]=a[(b[F>>1]|0)+(311880+(U<<2))|0]|0;O=F+2|0;ba=o+1|0;a[ba]=a[(b[O>>1]|0)+(311880+(U<<2))|0]|0;D=F+4|0;I=o+2|0;a[I]=a[(b[D>>1]|0)+(311880+(U<<2))|0]|0;x=F+6|0;M=o+3|0;a[M]=a[(b[x>>1]|0)+(311880+(U<<2))|0]|0;u=e+44|0;pe[c[u>>2]&1023](j+G|0,l,v,K,_);a[_]=a[(b[F>>1]|0)+(311880+(U<<2))|0]|0;a[ba]=a[(b[O>>1]|0)+(311880+(U<<2))|0]|0;a[I]=a[(b[D>>1]|0)+(311880+(U<<2))|0]|0;a[M]=a[(b[x>>1]|0)+(311880+(U<<2))|0]|0;pe[c[u>>2]&1023](k+G|0,l,v,K,_)}}while(0);F=p+48|0;R=F;w=F|0;F=c[w>>2]|0;C=F&65535;do{if(!((F|0)==0&(c[w+4>>2]|0)==0)){_=l<<3;K=o|0;v=B+y|0;G=B+z|0;if(!(v>>>0<68>>>0|G>>>0<68>>>0)){u=d[1953896+G|0]|0;G=d[2020944+v|0]|0;a[K]=a[(C<<16>>16)+(311880+(v<<2))|0]|0;a[o+1|0]=a[(b[R+2>>1]|0)+(311880+(v<<2))|0]|0;a[o+2|0]=a[(b[R+4>>1]|0)+(311880+(v<<2))|0]|0;a[o+3|0]=a[(b[R+6>>1]|0)+(311880+(v<<2))|0]|0;pe[c[e+44>>2]&1023](h+_|0,l,G,u,K)}if(!s){break}if(t){u=A+y|0;G=A+z|0;if(u>>>0<68>>>0|G>>>0<68>>>0){break}v=d[1953896+G|0]|0;G=d[2020944+u|0]|0;a[K]=a[(b[R>>1]|0)+(311880+(u<<2))|0]|0;U=R+2|0;x=o+1|0;a[x]=a[(b[U>>1]|0)+(311880+(u<<2))|0]|0;M=R+4|0;D=o+2|0;a[D]=a[(b[M>>1]|0)+(311880+(u<<2))|0]|0;I=R+6|0;O=o+3|0;a[O]=a[(b[I>>1]|0)+(311880+(u<<2))|0]|0;ba=e+44|0;pe[c[ba>>2]&1023](j+_|0,l,G,v,K);a[K]=a[(b[R>>1]|0)+(311880+(u<<2))|0]|0;a[x]=a[(b[U>>1]|0)+(311880+(u<<2))|0]|0;a[D]=a[(b[M>>1]|0)+(311880+(u<<2))|0]|0;a[O]=a[(b[I>>1]|0)+(311880+(u<<2))|0]|0;pe[c[ba>>2]&1023](k+_|0,l,G,v,K);break}else{v=m<<2;G=A+y|0;_=A+z|0;if(G>>>0<68>>>0|_>>>0<68>>>0){break}ba=d[1953896+_|0]|0;_=d[2020944+G|0]|0;a[K]=(a[(b[R>>1]|0)+(311880+(G<<2))|0]|0)+1;u=R+2|0;I=o+1|0;a[I]=(a[(b[u>>1]|0)+(311880+(G<<2))|0]|0)+1;O=R+4|0;M=o+2|0;a[M]=(a[(b[O>>1]|0)+(311880+(G<<2))|0]|0)+1;D=R+6|0;U=o+3|0;a[U]=(a[(b[D>>1]|0)+(311880+(G<<2))|0]|0)+1;x=e+68|0;pe[c[x>>2]&1023](j+v|0,m,_,ba,K);a[K]=(a[(b[R>>1]|0)+(311880+(G<<2))|0]|0)+1;a[I]=(a[(b[u>>1]|0)+(311880+(G<<2))|0]|0)+1;a[M]=(a[(b[O>>1]|0)+(311880+(G<<2))|0]|0)+1;a[U]=(a[(b[D>>1]|0)+(311880+(G<<2))|0]|0)+1;pe[c[x>>2]&1023](k+v|0,m,_,ba,K);break}}}while(0);R=p+56|0;s=R;C=R|0;R=c[C>>2]|0;if((R|0)==0&(c[C+4>>2]|0)==0){i=n;return}C=l*12|0;w=o|0;F=B+y|0;K=B+z|0;if(!(F>>>0<68>>>0|K>>>0<68>>>0)){ba=d[1953896+K|0]|0;K=d[2020944+F|0]|0;a[w]=a[((R&65535)<<16>>16)+(311880+(F<<2))|0]|0;a[o+1|0]=a[(b[s+2>>1]|0)+(311880+(F<<2))|0]|0;a[o+2|0]=a[(b[s+4>>1]|0)+(311880+(F<<2))|0]|0;a[o+3|0]=a[(b[s+6>>1]|0)+(311880+(F<<2))|0]|0;pe[c[e+44>>2]&1023](h+C|0,l,K,ba,w)}if(!t){i=n;return}ba=A+y|0;K=A+z|0;if(ba>>>0<68>>>0|K>>>0<68>>>0){i=n;return}F=d[1953896+K|0]|0;K=d[2020944+ba|0]|0;a[w]=a[(b[s>>1]|0)+(311880+(ba<<2))|0]|0;R=s+2|0;_=o+1|0;a[_]=a[(b[R>>1]|0)+(311880+(ba<<2))|0]|0;v=s+4|0;x=o+2|0;a[x]=a[(b[v>>1]|0)+(311880+(ba<<2))|0]|0;G=s+6|0;D=o+3|0;a[D]=a[(b[G>>1]|0)+(311880+(ba<<2))|0]|0;U=e+44|0;pe[c[U>>2]&1023](j+C|0,l,K,F,w);a[w]=a[(b[s>>1]|0)+(311880+(ba<<2))|0]|0;a[_]=a[(b[R>>1]|0)+(311880+(ba<<2))|0]|0;a[x]=a[(b[v>>1]|0)+(311880+(ba<<2))|0]|0;a[D]=a[(b[G>>1]|0)+(311880+(ba<<2))|0]|0;pe[c[U>>2]&1023](k+C|0,l,K,F,w);i=n;return}}}while(0);pia(e,f,g,h,j,k,l,m);i=n;return}function pia(f,g,h,j,k,l,m,n){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0;o=i;i=i+24|0;p=o|0;q=o+8|0;r=q;s=f+427404|0;t=(ca(c[s>>2]|0,h)|0)+g|0;g=f+4064|0;u=c[(c[g>>2]|0)+(t<<2)>>2]|0;v=(u>>>6&2^2)+2|0;w=f+6136|0;x=(c[w>>2]|0)!=0;y=((c[f+7308>>2]|0)*-6|0)+48|0;z=(c[f+427424>>2]|0)+52+y|0;A=(c[f+427428>>2]|0)+52+y|0;y=f+177088|0;B=f+4872|0;do{if((c[y>>2]|0)==0){C=0}else{D=c[B>>2]|0;if(((D^u)&128|0)==0|(D|0)==0){C=0;break}if((u&7|0)==0){D=h&1;E=c[f+177092>>2]|0;F=(E|0)!=0;G=f+7332|0;H=f+426560|0;I=f+5304|0;J=0;while(1){K=F?J>>2:J&1;L=c[f+4852+(K<<2)>>2]|0;M=c[f+4872+(K<<2)>>2]|0;if((M&7|0)==0){K=d[(J>>>1<<3)+12+(f+5184)|0]|0;do{if((c[G>>2]|0)==0){if((M&16777216|0)==0){N=11;break}O=e[(c[H>>2]|0)+(L<<1)>>1]&(((F?J&2:D)|0)!=0?32768:8192)}else{N=11}}while(0);if((N|0)==11){N=0;O=d[(d[1375912+(E<<4)+(D<<3)+J|0]|0)+((c[I>>2]|0)+(L*48|0))|0]|0}b[r+(J<<1)>>1]=(O|K|0)!=0?2:1}else{b[r+(J<<1)>>1]=4}M=J+1|0;if((M|0)<8){J=M}else{P=E;break}}}else{E=q|0;c[E>>2]=262148;c[E+4>>2]=262148;E=q+8|0;c[E>>2]=262148;c[E+4>>2]=262148;P=c[f+177092>>2]|0}E=c[f+4040>>2]|0;J=a[E+t|0]|0;I=a[E+(c[f+4852>>2]|0)|0]|0;D=a[E+(c[f+4856>>2]|0)|0]|0;E=J+1|0;F=(d[f+7876+J|0]|0)+1|0;H=(d[f+7964+J|0]|0)+1|0;J=E+I>>1;G=(F+(d[f+7876+I|0]|0)|0)>>>1;M=(H+(d[f+7964+I|0]|0)|0)>>>1;I=E+D>>1;E=(F+(d[f+7876+D|0]|0)|0)>>>1;F=(H+(d[f+7964+D|0]|0)|0)>>>1;if((P|0)==0){D=m<<1;H=q;Q=p|0;R=J+z|0;S=d[2020944+R|0]|0;T=J+A|0;U=d[1953896+T|0]|0;do{if(!(R>>>0<68>>>0|T>>>0<68>>>0)){V=b[H>>1]|0;if(V<<16>>16<4){a[Q]=a[(V<<16>>16)+(311880+(R<<2))|0]|0;a[p+1|0]=a[(b[H+4>>1]|0)+(311880+(R<<2))|0]|0;a[p+2|0]=a[(b[q+8>>1]|0)+(311880+(R<<2))|0]|0;a[p+3|0]=a[(b[H+12>>1]|0)+(311880+(R<<2))|0]|0;pe[c[f+52>>2]&1023](j,D,S,U,Q);break}else{mf[c[f+64>>2]&2047](j,D,S,U);break}}}while(0);U=j+m|0;S=r+2|0;R=I+z|0;T=d[2020944+R|0]|0;V=I+A|0;W=d[1953896+V|0]|0;do{if(!(R>>>0<68>>>0|V>>>0<68>>>0)){X=b[S>>1]|0;if(X<<16>>16<4){a[Q]=a[(X<<16>>16)+(311880+(R<<2))|0]|0;a[p+1|0]=a[(b[r+6>>1]|0)+(311880+(R<<2))|0]|0;a[p+2|0]=a[(b[r+10>>1]|0)+(311880+(R<<2))|0]|0;a[p+3|0]=a[(b[r+14>>1]|0)+(311880+(R<<2))|0]|0;pe[c[f+52>>2]&1023](U,D,T,W,Q);break}else{mf[c[f+64>>2]&2047](U,D,T,W);break}}}while(0);if(!x){C=1;break}W=n<<1;T=G+z|0;D=d[2020944+T|0]|0;U=G+A|0;R=d[1953896+U|0]|0;V=T>>>0<68>>>0|U>>>0<68>>>0;if((c[w>>2]|0)==3){do{if(!V){U=b[H>>1]|0;if(U<<16>>16<4){a[Q]=a[(U<<16>>16)+(311880+(T<<2))|0]|0;a[p+1|0]=a[(b[H+4>>1]|0)+(311880+(T<<2))|0]|0;a[p+2|0]=a[(b[q+8>>1]|0)+(311880+(T<<2))|0]|0;a[p+3|0]=a[(b[H+12>>1]|0)+(311880+(T<<2))|0]|0;pe[c[f+52>>2]&1023](k,W,D,R,Q);break}else{mf[c[f+64>>2]&2047](k,W,D,R);break}}}while(0);U=k+n|0;X=E+z|0;Y=d[2020944+X|0]|0;Z=E+A|0;_=d[1953896+Z|0]|0;do{if(!(X>>>0<68>>>0|Z>>>0<68>>>0)){$=b[S>>1]|0;if($<<16>>16<4){a[Q]=a[($<<16>>16)+(311880+(X<<2))|0]|0;a[p+1|0]=a[(b[r+6>>1]|0)+(311880+(X<<2))|0]|0;a[p+2|0]=a[(b[r+10>>1]|0)+(311880+(X<<2))|0]|0;a[p+3|0]=a[(b[r+14>>1]|0)+(311880+(X<<2))|0]|0;pe[c[f+52>>2]&1023](U,W,Y,_,Q);break}else{mf[c[f+64>>2]&2047](U,W,Y,_);break}}}while(0);_=M+z|0;Y=d[2020944+_|0]|0;U=M+A|0;X=d[1953896+U|0]|0;do{if(!(_>>>0<68>>>0|U>>>0<68>>>0)){Z=b[H>>1]|0;if(Z<<16>>16<4){a[Q]=a[(Z<<16>>16)+(311880+(_<<2))|0]|0;a[p+1|0]=a[(b[H+4>>1]|0)+(311880+(_<<2))|0]|0;a[p+2|0]=a[(b[q+8>>1]|0)+(311880+(_<<2))|0]|0;a[p+3|0]=a[(b[H+12>>1]|0)+(311880+(_<<2))|0]|0;pe[c[f+52>>2]&1023](l,W,Y,X,Q);break}else{mf[c[f+64>>2]&2047](l,W,Y,X);break}}}while(0);X=l+n|0;Y=F+z|0;_=d[2020944+Y|0]|0;U=F+A|0;Z=d[1953896+U|0]|0;if(Y>>>0<68>>>0|U>>>0<68>>>0){C=1;break}U=b[S>>1]|0;if(U<<16>>16<4){a[Q]=a[(U<<16>>16)+(311880+(Y<<2))|0]|0;a[p+1|0]=a[(b[r+6>>1]|0)+(311880+(Y<<2))|0]|0;a[p+2|0]=a[(b[r+10>>1]|0)+(311880+(Y<<2))|0]|0;a[p+3|0]=a[(b[r+14>>1]|0)+(311880+(Y<<2))|0]|0;pe[c[f+52>>2]&1023](X,W,_,Z,Q);C=1;break}else{mf[c[f+64>>2]&2047](X,W,_,Z);C=1;break}}else{do{if(!V){Z=b[H>>1]|0;if(Z<<16>>16<4){a[Q]=(a[(Z<<16>>16)+(311880+(T<<2))|0]|0)+1;a[p+1|0]=(a[(b[H+4>>1]|0)+(311880+(T<<2))|0]|0)+1;a[p+2|0]=(a[(b[q+8>>1]|0)+(311880+(T<<2))|0]|0)+1;a[p+3|0]=(a[(b[H+12>>1]|0)+(311880+(T<<2))|0]|0)+1;pe[c[f+76>>2]&1023](k,W,D,R,Q);break}else{mf[c[f+88>>2]&2047](k,W,D,R);break}}}while(0);R=k+n|0;D=E+z|0;T=d[2020944+D|0]|0;V=E+A|0;Z=d[1953896+V|0]|0;do{if(!(D>>>0<68>>>0|V>>>0<68>>>0)){_=b[S>>1]|0;if(_<<16>>16<4){a[Q]=(a[(_<<16>>16)+(311880+(D<<2))|0]|0)+1;a[p+1|0]=(a[(b[r+6>>1]|0)+(311880+(D<<2))|0]|0)+1;a[p+2|0]=(a[(b[r+10>>1]|0)+(311880+(D<<2))|0]|0)+1;a[p+3|0]=(a[(b[r+14>>1]|0)+(311880+(D<<2))|0]|0)+1;pe[c[f+76>>2]&1023](R,W,T,Z,Q);break}else{mf[c[f+88>>2]&2047](R,W,T,Z);break}}}while(0);Z=M+z|0;T=d[2020944+Z|0]|0;R=M+A|0;D=d[1953896+R|0]|0;do{if(!(Z>>>0<68>>>0|R>>>0<68>>>0)){V=b[H>>1]|0;if(V<<16>>16<4){a[Q]=(a[(V<<16>>16)+(311880+(Z<<2))|0]|0)+1;a[p+1|0]=(a[(b[H+4>>1]|0)+(311880+(Z<<2))|0]|0)+1;a[p+2|0]=(a[(b[q+8>>1]|0)+(311880+(Z<<2))|0]|0)+1;a[p+3|0]=(a[(b[H+12>>1]|0)+(311880+(Z<<2))|0]|0)+1;pe[c[f+76>>2]&1023](l,W,T,D,Q);break}else{mf[c[f+88>>2]&2047](l,W,T,D);break}}}while(0);D=l+n|0;T=F+z|0;Z=d[2020944+T|0]|0;H=F+A|0;R=d[1953896+H|0]|0;if(T>>>0<68>>>0|H>>>0<68>>>0){C=1;break}H=b[S>>1]|0;if(H<<16>>16<4){a[Q]=(a[(H<<16>>16)+(311880+(T<<2))|0]|0)+1;a[p+1|0]=(a[(b[r+6>>1]|0)+(311880+(T<<2))|0]|0)+1;a[p+2|0]=(a[(b[r+10>>1]|0)+(311880+(T<<2))|0]|0)+1;a[p+3|0]=(a[(b[r+14>>1]|0)+(311880+(T<<2))|0]|0)+1;pe[c[f+76>>2]&1023](D,W,Z,R,Q);C=1;break}else{mf[c[f+88>>2]&2047](D,W,Z,R);C=1;break}}}R=q;Z=p|0;D=J+z|0;T=d[2020944+D|0]|0;H=J+A|0;V=d[1953896+H|0]|0;do{if(!(D>>>0<68>>>0|H>>>0<68>>>0)){_=b[R>>1]|0;if(_<<16>>16<4){a[Z]=a[(_<<16>>16)+(311880+(D<<2))|0]|0;a[p+1|0]=a[(b[R+2>>1]|0)+(311880+(D<<2))|0]|0;a[p+2|0]=a[(b[R+4>>1]|0)+(311880+(D<<2))|0]|0;a[p+3|0]=a[(b[R+6>>1]|0)+(311880+(D<<2))|0]|0;pe[c[f+52>>2]&1023](j,m,T,V,Z);break}else{mf[c[f+64>>2]&2047](j,m,T,V);break}}}while(0);V=j+(m<<3)|0;T=q+8|0;D=I+z|0;H=d[2020944+D|0]|0;J=I+A|0;W=d[1953896+J|0]|0;do{if(!(D>>>0<68>>>0|J>>>0<68>>>0)){Q=b[T>>1]|0;if(Q<<16>>16<4){a[Z]=a[(Q<<16>>16)+(311880+(D<<2))|0]|0;a[p+1|0]=a[(b[T+2>>1]|0)+(311880+(D<<2))|0]|0;a[p+2|0]=a[(b[T+4>>1]|0)+(311880+(D<<2))|0]|0;a[p+3|0]=a[(b[T+6>>1]|0)+(311880+(D<<2))|0]|0;pe[c[f+52>>2]&1023](V,m,H,W,Z);break}else{mf[c[f+64>>2]&2047](V,m,H,W);break}}}while(0);if(!x){C=1;break}W=c[w>>2]|0;if((W|0)==3){H=G+z|0;V=d[2020944+H|0]|0;D=G+A|0;J=d[1953896+D|0]|0;do{if(!(H>>>0<68>>>0|D>>>0<68>>>0)){I=b[R>>1]|0;if(I<<16>>16<4){a[Z]=a[(I<<16>>16)+(311880+(H<<2))|0]|0;a[p+1|0]=a[(b[R+2>>1]|0)+(311880+(H<<2))|0]|0;a[p+2|0]=a[(b[R+4>>1]|0)+(311880+(H<<2))|0]|0;a[p+3|0]=a[(b[R+6>>1]|0)+(311880+(H<<2))|0]|0;pe[c[f+52>>2]&1023](k,n,V,J,Z);break}else{mf[c[f+64>>2]&2047](k,n,V,J);break}}}while(0);J=n<<3;V=k+J|0;H=E+z|0;D=d[2020944+H|0]|0;I=E+A|0;Q=d[1953896+I|0]|0;do{if(!(H>>>0<68>>>0|I>>>0<68>>>0)){S=b[T>>1]|0;if(S<<16>>16<4){a[Z]=a[(S<<16>>16)+(311880+(H<<2))|0]|0;a[p+1|0]=a[(b[T+2>>1]|0)+(311880+(H<<2))|0]|0;a[p+2|0]=a[(b[T+4>>1]|0)+(311880+(H<<2))|0]|0;a[p+3|0]=a[(b[T+6>>1]|0)+(311880+(H<<2))|0]|0;pe[c[f+52>>2]&1023](V,n,D,Q,Z);break}else{mf[c[f+64>>2]&2047](V,n,D,Q);break}}}while(0);Q=M+z|0;D=d[2020944+Q|0]|0;V=M+A|0;H=d[1953896+V|0]|0;do{if(!(Q>>>0<68>>>0|V>>>0<68>>>0)){I=b[R>>1]|0;if(I<<16>>16<4){a[Z]=a[(I<<16>>16)+(311880+(Q<<2))|0]|0;a[p+1|0]=a[(b[R+2>>1]|0)+(311880+(Q<<2))|0]|0;a[p+2|0]=a[(b[R+4>>1]|0)+(311880+(Q<<2))|0]|0;a[p+3|0]=a[(b[R+6>>1]|0)+(311880+(Q<<2))|0]|0;pe[c[f+52>>2]&1023](l,n,D,H,Z);break}else{mf[c[f+64>>2]&2047](l,n,D,H);break}}}while(0);H=l+J|0;D=F+z|0;Q=d[2020944+D|0]|0;V=F+A|0;I=d[1953896+V|0]|0;if(D>>>0<68>>>0|V>>>0<68>>>0){C=1;break}V=b[T>>1]|0;if(V<<16>>16<4){a[Z]=a[(V<<16>>16)+(311880+(D<<2))|0]|0;a[p+1|0]=a[(b[T+2>>1]|0)+(311880+(D<<2))|0]|0;a[p+2|0]=a[(b[T+4>>1]|0)+(311880+(D<<2))|0]|0;a[p+3|0]=a[(b[T+6>>1]|0)+(311880+(D<<2))|0]|0;pe[c[f+52>>2]&1023](H,n,Q,I,Z);C=1;break}else{mf[c[f+64>>2]&2047](H,n,Q,I);C=1;break}}I=(W|0)==2;Q=G+z|0;H=d[2020944+Q|0]|0;D=G+A|0;V=d[1953896+D|0]|0;do{if(!(Q>>>0<68>>>0|D>>>0<68>>>0)){S=b[R>>1]|0;if(S<<16>>16<4){a[Z]=(a[(S<<16>>16)+(311880+(Q<<2))|0]|0)+1;a[p+1|0]=(a[(b[R+2>>1]|0)+(311880+(Q<<2))|0]|0)+1;a[p+2|0]=(a[(b[R+4>>1]|0)+(311880+(Q<<2))|0]|0)+1;a[p+3|0]=(a[(b[R+6>>1]|0)+(311880+(Q<<2))|0]|0)+1;pe[c[f+76>>2]&1023](k,n,H,V,Z);break}else{mf[c[f+88>>2]&2047](k,n,H,V);break}}}while(0);if(I){V=n<<3;H=k+V|0;Q=E+z|0;D=d[2020944+Q|0]|0;G=E+A|0;W=d[1953896+G|0]|0;do{if(!(Q>>>0<68>>>0|G>>>0<68>>>0)){J=b[T>>1]|0;if(J<<16>>16<4){a[Z]=(a[(J<<16>>16)+(311880+(Q<<2))|0]|0)+1;a[p+1|0]=(a[(b[T+2>>1]|0)+(311880+(Q<<2))|0]|0)+1;a[p+2|0]=(a[(b[T+4>>1]|0)+(311880+(Q<<2))|0]|0)+1;a[p+3|0]=(a[(b[T+6>>1]|0)+(311880+(Q<<2))|0]|0)+1;pe[c[f+76>>2]&1023](H,n,D,W,Z);break}else{mf[c[f+88>>2]&2047](H,n,D,W);break}}}while(0);W=M+z|0;D=d[2020944+W|0]|0;H=M+A|0;Q=d[1953896+H|0]|0;do{if(!(W>>>0<68>>>0|H>>>0<68>>>0)){G=b[R>>1]|0;if(G<<16>>16<4){a[Z]=(a[(G<<16>>16)+(311880+(W<<2))|0]|0)+1;a[p+1|0]=(a[(b[R+2>>1]|0)+(311880+(W<<2))|0]|0)+1;a[p+2|0]=(a[(b[R+4>>1]|0)+(311880+(W<<2))|0]|0)+1;a[p+3|0]=(a[(b[R+6>>1]|0)+(311880+(W<<2))|0]|0)+1;pe[c[f+76>>2]&1023](l,n,D,Q,Z);break}else{mf[c[f+88>>2]&2047](l,n,D,Q);break}}}while(0);Q=l+V|0;D=F+z|0;W=d[2020944+D|0]|0;H=F+A|0;G=d[1953896+H|0]|0;if(D>>>0<68>>>0|H>>>0<68>>>0){C=1;break}H=b[T>>1]|0;if(H<<16>>16<4){a[Z]=(a[(H<<16>>16)+(311880+(D<<2))|0]|0)+1;a[p+1|0]=(a[(b[T+2>>1]|0)+(311880+(D<<2))|0]|0)+1;a[p+2|0]=(a[(b[T+4>>1]|0)+(311880+(D<<2))|0]|0)+1;a[p+3|0]=(a[(b[T+6>>1]|0)+(311880+(D<<2))|0]|0)+1;pe[c[f+76>>2]&1023](Q,n,W,G,Z);C=1;break}else{mf[c[f+88>>2]&2047](Q,n,W,G);C=1;break}}else{G=n<<2;W=k+G|0;Q=E+z|0;D=d[2020944+Q|0]|0;H=E+A|0;I=d[1953896+H|0]|0;do{if(!(Q>>>0<68>>>0|H>>>0<68>>>0)){J=b[T>>1]|0;if(J<<16>>16<4){a[Z]=(a[(J<<16>>16)+(311880+(Q<<2))|0]|0)+1;a[p+1|0]=(a[(b[T+2>>1]|0)+(311880+(Q<<2))|0]|0)+1;a[p+2|0]=(a[(b[T+4>>1]|0)+(311880+(Q<<2))|0]|0)+1;a[p+3|0]=(a[(b[T+6>>1]|0)+(311880+(Q<<2))|0]|0)+1;pe[c[f+76>>2]&1023](W,n,D,I,Z);break}else{mf[c[f+88>>2]&2047](W,n,D,I);break}}}while(0);I=M+z|0;D=d[2020944+I|0]|0;W=M+A|0;Q=d[1953896+W|0]|0;do{if(!(I>>>0<68>>>0|W>>>0<68>>>0)){H=b[R>>1]|0;if(H<<16>>16<4){a[Z]=(a[(H<<16>>16)+(311880+(I<<2))|0]|0)+1;a[p+1|0]=(a[(b[R+2>>1]|0)+(311880+(I<<2))|0]|0)+1;a[p+2|0]=(a[(b[R+4>>1]|0)+(311880+(I<<2))|0]|0)+1;a[p+3|0]=(a[(b[R+6>>1]|0)+(311880+(I<<2))|0]|0)+1;pe[c[f+76>>2]&1023](l,n,D,Q,Z);break}else{mf[c[f+88>>2]&2047](l,n,D,Q);break}}}while(0);Q=l+G|0;D=F+z|0;I=d[2020944+D|0]|0;R=F+A|0;W=d[1953896+R|0]|0;if(D>>>0<68>>>0|R>>>0<68>>>0){C=1;break}R=b[T>>1]|0;if(R<<16>>16<4){a[Z]=(a[(R<<16>>16)+(311880+(D<<2))|0]|0)+1;a[p+1|0]=(a[(b[T+2>>1]|0)+(311880+(D<<2))|0]|0)+1;a[p+2|0]=(a[(b[T+4>>1]|0)+(311880+(D<<2))|0]|0)+1;a[p+3|0]=(a[(b[T+6>>1]|0)+(311880+(D<<2))|0]|0)+1;pe[c[f+76>>2]&1023](Q,n,I,W,Z);C=1;break}else{mf[c[f+88>>2]&2047](Q,n,I,W);C=1;break}}}}while(0);q=(c[w>>2]|0)==3;r=t-1|0;P=c[B>>2]|0;B=u>>>3&7;O=a[1226328+B|0]|0;W=O&255;if(O<<24>>24==3){aa=(c[f+426564>>2]&15|0)!=0?4:1}else{aa=4}O=u&40;do{if((P|0)!=0&(C|0)==0){I=P|u;do{if((I&7|0)==0){do{if((O|0)==0){ba=1;da=0}else{if((P&40|0)==0){ba=1;da=0;break}ba=0;da=(qia(f,12,11,v)|0)&65535}}while(0);K=(a[f+5195|0]|a[f+5196|0])<<24>>24!=0;L=ba^1;if(K|L){ea=K?2:da}else{ea=(qia(f,12,11,v)|0)&65535}K=(a[f+5203|0]|a[f+5204|0])<<24>>24!=0;if(K|L){fa=K?2:da}else{fa=(qia(f,20,19,v)|0)&65535}K=(a[f+5211|0]|a[f+5212|0])<<24>>24!=0;if(K|L){ga=K?2:da}else{ga=(qia(f,28,27,v)|0)&65535}if(!((a[f+5219|0]|a[f+5220|0])<<24>>24==0)){ha=ea;ia=fa;ja=ga;ka=2;break}if(!ba){ha=ea;ia=fa;ja=ga;ka=da;break}ha=ea;ia=fa;ja=ga;ka=(qia(f,36,35,v)|0)&65535}else{if((I&128|0)!=0&(c[y>>2]|0)==0){if((c[f+177100>>2]|0)==3){ha=3;ia=3;ja=3;ka=3;break}}ha=4;ia=4;ja=4;ka=4}}while(0);I=ha<<16>>16;Z=ia<<16>>16;T=ja<<16>>16;F=ka<<16>>16;if((Z+T+I|0)==(-F|0)){break}G=c[f+4040>>2]|0;K=a[G+r|0]|0;L=(a[G+t|0]|0)+1+K>>1;G=(c[f+4756>>2]|0)+1+(d[f+7876+K|0]|0)>>1;Q=(c[f+4760>>2]|0)+1+(d[f+7964+K|0]|0)>>1;K=p|0;D=L+z|0;R=d[2020944+D|0]|0;M=L+A|0;L=d[1953896+M|0]|0;do{if(!(D>>>0<68>>>0|M>>>0<68>>>0)){if(ha<<16>>16<4){a[K]=a[311880+(D<<2)+I|0]|0;a[p+1|0]=a[311880+(D<<2)+Z|0]|0;a[p+2|0]=a[311880+(D<<2)+T|0]|0;a[p+3|0]=a[311880+(D<<2)+F|0]|0;pe[c[f+48>>2]&1023](j,m,R,L,K);break}else{mf[c[f+60>>2]&2047](j,m,R,L);break}}}while(0);if(!x){break}L=G+z|0;R=d[2020944+L|0]|0;D=G+A|0;M=d[1953896+D|0]|0;H=L>>>0<68>>>0|D>>>0<68>>>0;if(q){do{if(!H){if(ha<<16>>16<4){a[K]=a[311880+(L<<2)+I|0]|0;a[p+1|0]=a[311880+(L<<2)+Z|0]|0;a[p+2|0]=a[311880+(L<<2)+T|0]|0;a[p+3|0]=a[311880+(L<<2)+F|0]|0;pe[c[f+48>>2]&1023](k,n,R,M,K);break}else{mf[c[f+60>>2]&2047](k,n,R,M);break}}}while(0);G=Q+z|0;D=d[2020944+G|0]|0;E=Q+A|0;V=d[1953896+E|0]|0;if(G>>>0<68>>>0|E>>>0<68>>>0){break}if(ha<<16>>16<4){a[K]=a[311880+(G<<2)+I|0]|0;a[p+1|0]=a[311880+(G<<2)+Z|0]|0;a[p+2|0]=a[311880+(G<<2)+T|0]|0;a[p+3|0]=a[311880+(G<<2)+F|0]|0;pe[c[f+48>>2]&1023](l,n,D,V,K);break}else{mf[c[f+60>>2]&2047](l,n,D,V);break}}else{do{if(!H){if(ha<<16>>16<4){a[K]=(a[311880+(L<<2)+I|0]|0)+1;a[p+1|0]=(a[311880+(L<<2)+Z|0]|0)+1;a[p+2|0]=(a[311880+(L<<2)+T|0]|0)+1;a[p+3|0]=(a[311880+(L<<2)+F|0]|0)+1;pe[c[f+72>>2]&1023](k,n,R,M,K);break}else{mf[c[f+84>>2]&2047](k,n,R,M);break}}}while(0);M=Q+z|0;R=d[2020944+M|0]|0;L=Q+A|0;H=d[1953896+L|0]|0;if(M>>>0<68>>>0|L>>>0<68>>>0){break}if(ha<<16>>16<4){a[K]=(a[311880+(M<<2)+I|0]|0)+1;a[p+1|0]=(a[311880+(M<<2)+Z|0]|0)+1;a[p+2|0]=(a[311880+(M<<2)+T|0]|0)+1;a[p+3|0]=(a[311880+(M<<2)+F|0]|0)+1;pe[c[f+72>>2]&1023](l,n,R,H,K);break}else{mf[c[f+84>>2]&2047](l,n,R,H);break}}}}while(0);if(aa>>>0>1>>>0){ha=u&16777216;r=(u&7|0)==0;ka=(O|0)==0;O=f+4040|0;ja=f+4752|0;ia=p|0;ga=f+4756|0;fa=f+4760|0;ea=p+1|0;da=p+2|0;ba=p+3|0;P=f+48|0;C=f+72|0;H=1;R=0;M=0;L=0;V=0;D=0;G=0;E=0;J=0;S=0;_=0;X=0;Y=0;while(1){do{if((ha&H<<24|0)==0){if(r){do{if((H&W|0)==0){if(ka){la=1;ma=R;na=M;oa=L;pa=V;qa=D;ra=G;sa=E;ta=J;ua=S;va=_;wa=X;xa=Y;break}U=(qia(f,H+12|0,H+11|0,v)|0)&65535;la=0;ma=U;na=U;oa=U;pa=U;qa=U;ra=U;sa=U;ta=U;ua=U;va=U;wa=U;xa=U}else{la=0;ma=0;na=0;oa=0;pa=0;qa=0;ra=0;sa=0;ta=0;ua=0;va=0;wa=0;xa=0}}while(0);U=H+12|0;$=H+11|0;ya=(a[f+5184+$|0]|a[f+5184+U|0])<<24>>24==0;do{if(la){if(ya){za=(qia(f,U,$,v)|0)&65535}else{za=2}Aa=H+20|0;Ba=H+19|0;if((a[f+5184+Ba|0]|a[f+5184+Aa|0])<<24>>24==0){Ca=(qia(f,Aa,Ba,v)|0)&65535}else{Ca=2}Ba=H+28|0;Aa=H+27|0;if((a[f+5184+Aa|0]|a[f+5184+Ba|0])<<24>>24==0){Da=(qia(f,Ba,Aa,v)|0)&65535}else{Da=2}Aa=H+36|0;Ba=H+35|0;if(!((a[f+5184+Ba|0]|a[f+5184+Aa|0])<<24>>24==0)){Ea=za;Fa=Ca;Ga=Da;Ha=2;Ia=za;Ja=Ca;Ka=Da;La=2;Ma=za;Na=Ca;Oa=Da;Pa=2;break}Qa=(qia(f,Aa,Ba,v)|0)&65535;Ea=za;Fa=Ca;Ga=Da;Ha=Qa;Ia=za;Ja=Ca;Ka=Da;La=Qa;Ma=za;Na=Ca;Oa=Da;Pa=Qa}else{Qa=(a[H+19+(f+5184)|0]|a[H+20+(f+5184)|0])<<24>>24==0;Ba=(a[H+27+(f+5184)|0]|a[H+28+(f+5184)|0])<<24>>24==0;Aa=(a[H+35+(f+5184)|0]|a[H+36+(f+5184)|0])<<24>>24==0;Ea=ya?ma:2;Fa=Qa?na:2;Ga=Ba?oa:2;Ha=Aa?pa:2;Ia=ya?qa:2;Ja=Qa?ra:2;Ka=Ba?sa:2;La=Aa?ta:2;Ma=ya?ua:2;Na=Qa?va:2;Oa=Ba?wa:2;Pa=Aa?xa:2}}while(0);if(((Fa<<16>>16)+(Ga<<16>>16)+(Ea<<16>>16)|0)==(-(Ha<<16>>16)|0)){Ra=Ea;Sa=Fa;Ta=Ga;Ua=Ha;Va=Ia;Wa=Ja;Xa=Ka;Ya=La;Za=Ma;_a=Na;$a=Oa;ab=Pa;break}else{bb=Ea;cb=Fa;db=Ga;eb=Ha;fb=Ia;gb=Ja;hb=Ka;ib=La;jb=Ma;kb=Na;lb=Oa;mb=Pa}}else{bb=3;cb=3;db=3;eb=3;fb=3;gb=3;hb=3;ib=3;jb=3;kb=3;lb=3;mb=3}ya=a[(c[O>>2]|0)+t|0]|0;$=H<<2;U=ya+z|0;Aa=ya+A|0;if(U>>>0<68>>>0|Aa>>>0<68>>>0){nb=bb;ob=cb;pb=db;qb=eb;rb=fb;sb=gb;tb=hb;ub=ib}else{ya=d[1953896+Aa|0]|0;Aa=d[2020944+U|0]|0;Ba=j+($<<c[ja>>2])|0;a[ia]=a[(jb<<16>>16)+(311880+(U<<2))|0]|0;a[ea]=a[(kb<<16>>16)+(311880+(U<<2))|0]|0;a[da]=a[(lb<<16>>16)+(311880+(U<<2))|0]|0;a[ba]=a[(mb<<16>>16)+(311880+(U<<2))|0]|0;pe[c[P>>2]&1023](Ba,m,Aa,ya,ia);nb=jb;ob=kb;pb=lb;qb=mb;rb=jb;sb=kb;tb=lb;ub=mb}if(!x){Ra=nb;Sa=ob;Ta=pb;Ua=qb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}if(q){ya=c[ja>>2]|0;Aa=c[ga>>2]|0;Ba=Aa+z|0;U=Aa+A|0;if(Ba>>>0<68>>>0|U>>>0<68>>>0){vb=ya}else{Aa=d[1953896+U|0]|0;U=d[2020944+Ba|0]|0;a[ia]=a[(nb<<16>>16)+(311880+(Ba<<2))|0]|0;a[ea]=a[(ob<<16>>16)+(311880+(Ba<<2))|0]|0;a[da]=a[(pb<<16>>16)+(311880+(Ba<<2))|0]|0;a[ba]=a[(qb<<16>>16)+(311880+(Ba<<2))|0]|0;pe[c[P>>2]&1023](k+($<<ya)|0,n,U,Aa,ia);vb=c[ja>>2]|0}Aa=c[fa>>2]|0;U=Aa+z|0;ya=Aa+A|0;if(U>>>0<68>>>0|ya>>>0<68>>>0){Ra=nb;Sa=ob;Ta=pb;Ua=qb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}Aa=d[1953896+ya|0]|0;ya=d[2020944+U|0]|0;a[ia]=a[(nb<<16>>16)+(311880+(U<<2))|0]|0;a[ea]=a[(ob<<16>>16)+(311880+(U<<2))|0]|0;a[da]=a[(pb<<16>>16)+(311880+(U<<2))|0]|0;a[ba]=a[(qb<<16>>16)+(311880+(U<<2))|0]|0;pe[c[P>>2]&1023](l+($<<vb)|0,n,ya,Aa,ia);Ra=nb;Sa=ob;Ta=pb;Ua=qb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}if((H&1|0)!=0){Ra=nb;Sa=ob;Ta=pb;Ua=qb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}Aa=H<<1;ya=c[ja>>2]|0;$=c[ga>>2]|0;U=$+z|0;Ba=$+A|0;if(U>>>0<68>>>0|Ba>>>0<68>>>0){wb=nb;xb=ob;yb=pb;zb=qb;Ab=ya}else{$=d[1953896+Ba|0]|0;Ba=d[2020944+U|0]|0;a[ia]=(a[(rb<<16>>16)+(311880+(U<<2))|0]|0)+1;a[ea]=(a[(sb<<16>>16)+(311880+(U<<2))|0]|0)+1;a[da]=(a[(tb<<16>>16)+(311880+(U<<2))|0]|0)+1;a[ba]=(a[(ub<<16>>16)+(311880+(U<<2))|0]|0)+1;pe[c[C>>2]&1023](k+(Aa<<ya)|0,n,Ba,$,ia);wb=rb;xb=sb;yb=tb;zb=ub;Ab=c[ja>>2]|0}$=c[fa>>2]|0;Ba=$+z|0;ya=$+A|0;if(Ba>>>0<68>>>0|ya>>>0<68>>>0){Ra=wb;Sa=xb;Ta=yb;Ua=zb;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb;break}$=d[1953896+ya|0]|0;ya=d[2020944+Ba|0]|0;a[ia]=(a[(rb<<16>>16)+(311880+(Ba<<2))|0]|0)+1;a[ea]=(a[(sb<<16>>16)+(311880+(Ba<<2))|0]|0)+1;a[da]=(a[(tb<<16>>16)+(311880+(Ba<<2))|0]|0)+1;a[ba]=(a[(ub<<16>>16)+(311880+(Ba<<2))|0]|0)+1;pe[c[C>>2]&1023](l+(Aa<<Ab)|0,n,ya,$,ia);Ra=rb;Sa=sb;Ta=tb;Ua=ub;Va=rb;Wa=sb;Xa=tb;Ya=ub;Za=jb;_a=kb;$a=lb;ab=mb}else{Ra=R;Sa=M;Ta=L;Ua=V;Va=D;Wa=G;Xa=E;Ya=J;Za=S;_a=_;$a=X;ab=Y}}while(0);K=H+1|0;if((K|0)<(aa|0)){H=K;R=Ra;M=Sa;L=Ta;V=Ua;D=Va;G=Wa;E=Xa;J=Ya;S=Za;_=_a;X=$a;Y=ab}else{break}}}ab=c[w>>2]|0;w=(ab|0)==3;Y=(ab|0)==2;ab=c[f+4844>>2]|0;$a=c[f+4864>>2]|0;X=a[1226336+B|0]|0;B=X&255;if(X<<24>>24==3){Bb=(c[f+426564>>2]&15|0)!=0?4:1}else{Bb=4}X=u&24;a:do{if(($a|0)!=0){_a=(c[y>>2]|0)==0;do{if(!_a){if((h&1|0)!=0){break}if(($a&(u&128^128)|0)==0){break}_=m<<1;Za=n<<1;S=f+7332|0;Ya=f+426560|0;J=f+5196|0;Xa=f+5197|0;E=f+5199|0;Wa=f+5198|0;G=f+5304|0;Va=f+4040|0;D=p|0;Ua=f+4756|0;V=f+4760|0;Ta=p+1|0;L=p+2|0;Sa=p+3|0;M=f+44|0;Ra=f+68|0;R=0;H=t-(c[s>>2]<<1)|0;while(1){aa=c[(c[g>>2]|0)+(H<<2)>>2]|0;b:do{if(((aa|u)&7|0)==0){do{if((c[S>>2]|0)==0){if((aa&16777216|0)==0){break}mb=b[(c[Ya>>2]|0)+(H<<1)>>1]|0;if((mb&16384)==0){Cb=(a[Xa]|0)!=0?2:1;Db=(a[J]|0)!=0?2:1}else{Cb=2;Db=2}if(mb<<16>>16<0){Eb=Db;Fb=Cb;Gb=2;Hb=2;break b}Eb=Db;Fb=Cb;Gb=(a[Wa]|0)!=0?2:1;Hb=(a[E]|0)!=0?2:1;break b}}while(0);mb=c[G>>2]|0;Eb=(a[mb+(H*48|0)+12|0]|a[J])<<24>>24!=0?2:1;Fb=(a[mb+(H*48|0)+13|0]|a[Xa])<<24>>24!=0?2:1;Gb=(a[mb+(H*48|0)+14|0]|a[Wa])<<24>>24!=0?2:1;Hb=(a[mb+(H*48|0)+15|0]|a[E])<<24>>24!=0?2:1}else{Eb=3;Fb=3;Gb=3;Hb=3}}while(0);aa=c[Va>>2]|0;mb=(a[aa+t|0]|0)+1+(a[aa+H|0]|0)>>1;lb=mb+z|0;kb=mb+A|0;if(lb>>>0<68>>>0|kb>>>0<68>>>0){Ib=aa}else{aa=d[1953896+kb|0]|0;kb=d[2020944+lb|0]|0;mb=j+(ca(R,m)|0)|0;a[D]=a[(Eb<<16>>16)+(311880+(lb<<2))|0]|0;a[Ta]=a[(Fb<<16>>16)+(311880+(lb<<2))|0]|0;a[L]=a[(Gb&65535)+(311880+(lb<<2))|0]|0;a[Sa]=a[(Hb&65535)+(311880+(lb<<2))|0]|0;pe[c[M>>2]&1023](mb,_,kb,aa,D);Ib=c[Va>>2]|0}aa=a[Ib+H|0]|0;kb=(c[Ua>>2]|0)+1+(d[f+7876+aa|0]|0)>>1;mb=(c[V>>2]|0)+1+(d[f+7964+aa|0]|0)>>1;do{if(x){aa=ca(R,n)|0;lb=k+aa|0;jb=kb+z|0;ub=d[2020944+jb|0]|0;tb=kb+A|0;sb=d[1953896+tb|0]|0;rb=jb>>>0<68>>>0|tb>>>0<68>>>0;if(w){if(!rb){a[D]=a[(Eb<<16>>16)+(311880+(jb<<2))|0]|0;a[Ta]=a[(Fb<<16>>16)+(311880+(jb<<2))|0]|0;a[L]=a[(Gb&65535)+(311880+(jb<<2))|0]|0;a[Sa]=a[(Hb&65535)+(311880+(jb<<2))|0]|0;pe[c[M>>2]&1023](lb,Za,ub,sb,D)}tb=mb+z|0;ia=mb+A|0;if(tb>>>0<68>>>0|ia>>>0<68>>>0){break}Ab=d[1953896+ia|0]|0;ia=d[2020944+tb|0]|0;a[D]=a[(Eb<<16>>16)+(311880+(tb<<2))|0]|0;a[Ta]=a[(Fb<<16>>16)+(311880+(tb<<2))|0]|0;a[L]=a[(Gb&65535)+(311880+(tb<<2))|0]|0;a[Sa]=a[(Hb&65535)+(311880+(tb<<2))|0]|0;pe[c[M>>2]&1023](l+aa|0,Za,ia,Ab,D);break}else{if(!rb){a[D]=(a[(Eb<<16>>16)+(311880+(jb<<2))|0]|0)+1;a[Ta]=(a[(Fb<<16>>16)+(311880+(jb<<2))|0]|0)+1;a[L]=(a[(Gb&65535)+(311880+(jb<<2))|0]|0)+1;a[Sa]=(a[(Hb&65535)+(311880+(jb<<2))|0]|0)+1;pe[c[Ra>>2]&1023](lb,Za,ub,sb,D)}sb=mb+z|0;ub=mb+A|0;if(sb>>>0<68>>>0|ub>>>0<68>>>0){break}lb=d[1953896+ub|0]|0;ub=d[2020944+sb|0]|0;a[D]=(a[(Eb<<16>>16)+(311880+(sb<<2))|0]|0)+1;a[Ta]=(a[(Fb<<16>>16)+(311880+(sb<<2))|0]|0)+1;a[L]=(a[(Gb&65535)+(311880+(sb<<2))|0]|0)+1;a[Sa]=(a[(Hb&65535)+(311880+(sb<<2))|0]|0)+1;pe[c[Ra>>2]&1023](l+aa|0,Za,ub,lb,D);break}}}while(0);mb=R+1|0;if((mb|0)>=2){break a}R=mb;H=(c[s>>2]|0)+H|0}}}while(0);H=$a|u;do{if((H&7|0)==0){if(_a){N=219}else{if((($a^u)&128|0)==0){N=219}else{Jb=0;Kb=1}}do{if((N|0)==219){if((X|0)==0){Jb=1;Kb=0;break}if(($a&24|0)==0){Jb=1;Kb=0;break}Jb=0;Kb=(qia(f,12,4,v)|0)&65535}}while(0);R=(a[f+5188|0]|a[f+5196|0])<<24>>24!=0;D=Jb^1;if(R|D){Lb=R?2:Kb}else{Lb=(qia(f,12,4,v)|0)&65535}R=(a[f+5189|0]|a[f+5197|0])<<24>>24!=0;if(R|D){Mb=R?2:Kb}else{Mb=(qia(f,13,5,v)|0)&65535}R=(a[f+5190|0]|a[f+5198|0])<<24>>24!=0;if(R|D){Nb=R?2:Kb}else{Nb=(qia(f,14,6,v)|0)&65535}if(!((a[f+5191|0]|a[f+5199|0])<<24>>24==0)){Ob=Lb;Pb=Mb;Qb=Nb;Rb=2;break}if(!Jb){Ob=Lb;Pb=Mb;Qb=Nb;Rb=Kb;break}Ob=Lb;Pb=Mb;Qb=Nb;Rb=(qia(f,15,7,v)|0)&65535}else{R=(H&128|0)==0?4:3;Ob=R;Pb=R;Qb=R;Rb=R}}while(0);H=Ob<<16>>16;_a=Pb<<16>>16;R=Qb<<16>>16;D=Rb<<16>>16;if((_a+R+H|0)==(-D|0)){break}Za=c[f+4040>>2]|0;Ra=a[Za+ab|0]|0;Sa=(a[Za+t|0]|0)+1+Ra>>1;Za=(c[f+4756>>2]|0)+1+(d[f+7876+Ra|0]|0)>>1;L=(c[f+4760>>2]|0)+1+(d[f+7964+Ra|0]|0)>>1;Ra=p|0;Ta=Sa+z|0;M=d[2020944+Ta|0]|0;V=Sa+A|0;Sa=d[1953896+V|0]|0;do{if(!(Ta>>>0<68>>>0|V>>>0<68>>>0)){if(Ob<<16>>16<4){a[Ra]=a[311880+(Ta<<2)+H|0]|0;a[p+1|0]=a[311880+(Ta<<2)+_a|0]|0;a[p+2|0]=a[311880+(Ta<<2)+R|0]|0;a[p+3|0]=a[311880+(Ta<<2)+D|0]|0;pe[c[f+44>>2]&1023](j,m,M,Sa,Ra);break}else{mf[c[f+56>>2]&2047](j,m,M,Sa);break}}}while(0);if(!x){break}Sa=Za+z|0;M=d[2020944+Sa|0]|0;Ta=Za+A|0;V=d[1953896+Ta|0]|0;Ua=Sa>>>0<68>>>0|Ta>>>0<68>>>0;if(w){do{if(!Ua){if(Ob<<16>>16<4){a[Ra]=a[311880+(Sa<<2)+H|0]|0;a[p+1|0]=a[311880+(Sa<<2)+_a|0]|0;a[p+2|0]=a[311880+(Sa<<2)+R|0]|0;a[p+3|0]=a[311880+(Sa<<2)+D|0]|0;pe[c[f+44>>2]&1023](k,n,M,V,Ra);break}else{mf[c[f+56>>2]&2047](k,n,M,V);break}}}while(0);Za=L+z|0;Ta=d[2020944+Za|0]|0;Va=L+A|0;_=d[1953896+Va|0]|0;if(Za>>>0<68>>>0|Va>>>0<68>>>0){break}if(Ob<<16>>16<4){a[Ra]=a[311880+(Za<<2)+H|0]|0;a[p+1|0]=a[311880+(Za<<2)+_a|0]|0;a[p+2|0]=a[311880+(Za<<2)+R|0]|0;a[p+3|0]=a[311880+(Za<<2)+D|0]|0;pe[c[f+44>>2]&1023](l,n,Ta,_,Ra);break}else{mf[c[f+56>>2]&2047](l,n,Ta,_);break}}else{do{if(!Ua){if(Ob<<16>>16<4){a[Ra]=(a[311880+(Sa<<2)+H|0]|0)+1;a[p+1|0]=(a[311880+(Sa<<2)+_a|0]|0)+1;a[p+2|0]=(a[311880+(Sa<<2)+R|0]|0)+1;a[p+3|0]=(a[311880+(Sa<<2)+D|0]|0)+1;pe[c[f+68>>2]&1023](k,n,M,V,Ra);break}else{mf[c[f+80>>2]&2047](k,n,M,V);break}}}while(0);V=L+z|0;M=d[2020944+V|0]|0;Sa=L+A|0;Ua=d[1953896+Sa|0]|0;if(V>>>0<68>>>0|Sa>>>0<68>>>0){break}if(Ob<<16>>16<4){a[Ra]=(a[311880+(V<<2)+H|0]|0)+1;a[p+1|0]=(a[311880+(V<<2)+_a|0]|0)+1;a[p+2|0]=(a[311880+(V<<2)+R|0]|0)+1;a[p+3|0]=(a[311880+(V<<2)+D|0]|0)+1;pe[c[f+68>>2]&1023](l,n,M,Ua,Ra);break}else{mf[c[f+80>>2]&2047](l,n,M,Ua);break}}}}while(0);if(!(Bb>>>0>1>>>0)){i=o;return}Ob=u&16777216;ab=(u&7|0)==0;u=(X|0)==0;X=f+4040|0;Rb=p|0;Qb=f+4756|0;Pb=f+4760|0;Nb=p+1|0;Mb=p+2|0;Lb=p+3|0;p=m<<2;Kb=f+44|0;Jb=f+68|0;$a=1;N=0;s=0;Hb=0;Gb=0;Fb=0;Eb=0;Ib=0;Cb=0;Db=0;g=0;h=0;y=0;Ua=0;M=0;V=0;Sa=0;_=0;Ta=0;Za=0;Va=0;while(1){E=(Ob&$a<<24|0)==0;do{if(E|Y){if(ab){do{if(($a&B|0)==0){if(u){Sb=1;Tb=N;Ub=s;Vb=Hb;Wb=Gb;Xb=Fb;Yb=Eb;Zb=Ib;_b=Cb;$b=Db;ac=g;bc=h;cc=y;dc=Ua;ec=M;fc=V;gc=Sa;hc=_;ic=Ta;jc=Za;kc=Va;break}Wa=$a<<3;Xa=(qia(f,Wa+12|0,Wa|4,v)|0)&65535;Sb=0;Tb=Xa;Ub=Xa;Vb=Xa;Wb=Xa;Xb=Xa;Yb=Xa;Zb=Xa;_b=Xa;$b=Xa;ac=Xa;bc=Xa;cc=Xa;dc=Xa;ec=Xa;fc=Xa;gc=Xa;hc=Xa;ic=Xa;jc=Xa;kc=Xa}else{Sb=0;Tb=0;Ub=0;Vb=0;Wb=0;Xb=0;Yb=0;Zb=0;_b=0;$b=0;ac=0;bc=0;cc=0;dc=0;ec=0;fc=0;gc=0;hc=0;ic=0;jc=0;kc=0}}while(0);Xa=$a<<3;Wa=Xa+12|0;J=Xa|4;G=(a[f+5184+J|0]|a[f+5184+Wa|0])<<24>>24==0;do{if(Sb){if(G){lc=(qia(f,Wa,J,v)|0)&65535}else{lc=2}Ya=Xa+13|0;S=Xa|5;if((a[f+5184+S|0]|a[f+5184+Ya|0])<<24>>24==0){mc=(qia(f,Ya,S,v)|0)&65535}else{mc=2}S=Xa+14|0;Ya=Xa|6;if((a[f+5184+Ya|0]|a[f+5184+S|0])<<24>>24==0){nc=(qia(f,S,Ya,v)|0)&65535}else{nc=2}Ya=Xa+15|0;S=Xa|7;if(!((a[f+5184+S|0]|a[f+5184+Ya|0])<<24>>24==0)){oc=lc;pc=mc;qc=nc;rc=2;sc=lc;tc=mc;uc=nc;vc=2;wc=lc;xc=mc;yc=nc;zc=2;Ac=lc;Bc=mc;Cc=nc;Dc=2;Ec=lc;Fc=mc;Gc=nc;Hc=2;break}mb=(qia(f,Ya,S,v)|0)&65535;oc=lc;pc=mc;qc=nc;rc=mb;sc=lc;tc=mc;uc=nc;vc=mb;wc=lc;xc=mc;yc=nc;zc=mb;Ac=lc;Bc=mc;Cc=nc;Dc=mb;Ec=lc;Fc=mc;Gc=nc;Hc=mb}else{mb=(a[(Xa|5)+(f+5184)|0]|a[Xa+13+(f+5184)|0])<<24>>24==0;S=(a[(Xa|6)+(f+5184)|0]|a[Xa+14+(f+5184)|0])<<24>>24==0;Ya=(a[(Xa|7)+(f+5184)|0]|a[Xa+15+(f+5184)|0])<<24>>24==0;oc=G?Tb:2;pc=mb?Ub:2;qc=S?Vb:2;rc=Ya?Wb:2;sc=G?Xb:2;tc=mb?Yb:2;uc=S?Zb:2;vc=Ya?_b:2;wc=G?$b:2;xc=mb?ac:2;yc=S?bc:2;zc=Ya?cc:2;Ac=G?dc:2;Bc=mb?ec:2;Cc=S?fc:2;Dc=Ya?gc:2;Ec=G?hc:2;Fc=mb?ic:2;Gc=S?jc:2;Hc=Ya?kc:2}}while(0);if(((pc<<16>>16)+(qc<<16>>16)+(oc<<16>>16)|0)==(-(rc<<16>>16)|0)){Ic=oc;Jc=pc;Kc=qc;Lc=rc;Mc=sc;Nc=tc;Oc=uc;Pc=vc;Qc=wc;Rc=xc;Sc=yc;Tc=zc;Uc=Ac;Vc=Bc;Wc=Cc;Xc=Dc;Yc=Ec;Zc=Fc;_c=Gc;$c=Hc;break}else{ad=oc;bd=pc;cd=qc;dd=rc;ed=sc;fd=tc;gd=uc;hd=vc;id=wc;jd=xc;kd=yc;ld=zc;md=Ac;nd=Bc;od=Cc;pd=Dc;qd=Ec;rd=Fc;sd=Gc;td=Hc}}else{ad=3;bd=3;cd=3;dd=3;ed=3;fd=3;gd=3;hd=3;id=3;jd=3;kd=3;ld=3;md=3;nd=3;od=3;pd=3;qd=3;rd=3;sd=3;td=3}G=a[(c[X>>2]|0)+t|0]|0;if(Y){do{if(E){Xa=G+z|0;J=G+A|0;if(Xa>>>0<68>>>0|J>>>0<68>>>0){ud=ad;vd=bd;wd=cd;xd=dd;break}Wa=d[1953896+J|0]|0;J=d[2020944+Xa|0]|0;Ya=j+(ca(p,$a)|0)|0;a[Rb]=a[(ed<<16>>16)+(311880+(Xa<<2))|0]|0;a[Nb]=a[(fd<<16>>16)+(311880+(Xa<<2))|0]|0;a[Mb]=a[(gd<<16>>16)+(311880+(Xa<<2))|0]|0;a[Lb]=a[(hd<<16>>16)+(311880+(Xa<<2))|0]|0;pe[c[Kb>>2]&1023](Ya,m,J,Wa,Rb);ud=ed;vd=fd;wd=gd;xd=hd}else{ud=ad;vd=bd;wd=cd;xd=dd}}while(0);if(!x){Ic=ud;Jc=vd;Kc=wd;Lc=xd;Mc=ed;Nc=fd;Oc=gd;Pc=hd;Qc=id;Rc=jd;Sc=kd;Tc=ld;Uc=md;Vc=nd;Wc=od;Xc=pd;Yc=qd;Zc=rd;_c=sd;$c=td;break}Wa=ca($a<<2,n)|0;J=c[Qb>>2]|0;Ya=J+z|0;Xa=J+A|0;if(Ya>>>0<68>>>0|Xa>>>0<68>>>0){yd=ud;zd=vd;Ad=wd;Bd=xd}else{J=d[1953896+Xa|0]|0;Xa=d[2020944+Ya|0]|0;a[Rb]=(a[(ed<<16>>16)+(311880+(Ya<<2))|0]|0)+1;a[Nb]=(a[(fd<<16>>16)+(311880+(Ya<<2))|0]|0)+1;a[Mb]=(a[(gd<<16>>16)+(311880+(Ya<<2))|0]|0)+1;a[Lb]=(a[(hd<<16>>16)+(311880+(Ya<<2))|0]|0)+1;pe[c[Jb>>2]&1023](k+Wa|0,n,Xa,J,Rb);yd=ed;zd=fd;Ad=gd;Bd=hd}J=c[Pb>>2]|0;Xa=J+z|0;Ya=J+A|0;if(Xa>>>0<68>>>0|Ya>>>0<68>>>0){Ic=yd;Jc=zd;Kc=Ad;Lc=Bd;Mc=ed;Nc=fd;Oc=gd;Pc=hd;Qc=id;Rc=jd;Sc=kd;Tc=ld;Uc=md;Vc=nd;Wc=od;Xc=pd;Yc=qd;Zc=rd;_c=sd;$c=td;break}J=d[1953896+Ya|0]|0;Ya=d[2020944+Xa|0]|0;a[Rb]=(a[(ed<<16>>16)+(311880+(Xa<<2))|0]|0)+1;a[Nb]=(a[(fd<<16>>16)+(311880+(Xa<<2))|0]|0)+1;a[Mb]=(a[(gd<<16>>16)+(311880+(Xa<<2))|0]|0)+1;a[Lb]=(a[(hd<<16>>16)+(311880+(Xa<<2))|0]|0)+1;pe[c[Jb>>2]&1023](l+Wa|0,n,Ya,J,Rb);Ic=ed;Jc=fd;Kc=gd;Lc=hd;Mc=ed;Nc=fd;Oc=gd;Pc=hd;Qc=id;Rc=jd;Sc=kd;Tc=ld;Uc=md;Vc=nd;Wc=od;Xc=pd;Yc=qd;Zc=rd;_c=sd;$c=td;break}J=$a<<2;Ya=G+z|0;Wa=G+A|0;if(Ya>>>0<68>>>0|Wa>>>0<68>>>0){Cd=ad;Dd=bd;Ed=cd;Fd=dd;Gd=ed;Hd=fd;Id=gd;Jd=hd;Kd=id;Ld=jd;Md=kd;Nd=ld;Od=md;Pd=nd;Qd=od;Rd=pd}else{Xa=d[1953896+Wa|0]|0;Wa=d[2020944+Ya|0]|0;S=j+(ca(J,m)|0)|0;a[Rb]=a[(qd<<16>>16)+(311880+(Ya<<2))|0]|0;a[Nb]=a[(rd<<16>>16)+(311880+(Ya<<2))|0]|0;a[Mb]=a[(sd<<16>>16)+(311880+(Ya<<2))|0]|0;a[Lb]=a[(td<<16>>16)+(311880+(Ya<<2))|0]|0;pe[c[Kb>>2]&1023](S,m,Wa,Xa,Rb);Cd=qd;Dd=rd;Ed=sd;Fd=td;Gd=qd;Hd=rd;Id=sd;Jd=td;Kd=qd;Ld=rd;Md=sd;Nd=td;Od=qd;Pd=rd;Qd=sd;Rd=td}if(!x){Ic=Cd;Jc=Dd;Kc=Ed;Lc=Fd;Mc=Gd;Nc=Hd;Oc=Id;Pc=Jd;Qc=Kd;Rc=Ld;Sc=Md;Tc=Nd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}if(w){Xa=ca(J,n)|0;J=c[Qb>>2]|0;Wa=J+z|0;S=J+A|0;if(Wa>>>0<68>>>0|S>>>0<68>>>0){Sd=Cd;Td=Dd;Ud=Ed;Vd=Fd;Wd=Gd;Xd=Hd;Yd=Id;Zd=Jd}else{J=d[1953896+S|0]|0;S=d[2020944+Wa|0]|0;a[Rb]=a[(Kd<<16>>16)+(311880+(Wa<<2))|0]|0;a[Nb]=a[(Ld<<16>>16)+(311880+(Wa<<2))|0]|0;a[Mb]=a[(Md<<16>>16)+(311880+(Wa<<2))|0]|0;a[Lb]=a[(Nd<<16>>16)+(311880+(Wa<<2))|0]|0;pe[c[Kb>>2]&1023](k+Xa|0,n,S,J,Rb);Sd=Kd;Td=Ld;Ud=Md;Vd=Nd;Wd=Kd;Xd=Ld;Yd=Md;Zd=Nd}J=c[Pb>>2]|0;S=J+z|0;Wa=J+A|0;if(S>>>0<68>>>0|Wa>>>0<68>>>0){Ic=Sd;Jc=Td;Kc=Ud;Lc=Vd;Mc=Wd;Nc=Xd;Oc=Yd;Pc=Zd;Qc=Kd;Rc=Ld;Sc=Md;Tc=Nd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}J=d[1953896+Wa|0]|0;Wa=d[2020944+S|0]|0;a[Rb]=a[(Kd<<16>>16)+(311880+(S<<2))|0]|0;a[Nb]=a[(Ld<<16>>16)+(311880+(S<<2))|0]|0;a[Mb]=a[(Md<<16>>16)+(311880+(S<<2))|0]|0;a[Lb]=a[(Nd<<16>>16)+(311880+(S<<2))|0]|0;pe[c[Kb>>2]&1023](l+Xa|0,n,Wa,J,Rb);Ic=Kd;Jc=Ld;Kc=Md;Lc=Nd;Mc=Kd;Nc=Ld;Oc=Md;Pc=Nd;Qc=Kd;Rc=Ld;Sc=Md;Tc=Nd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}if(($a&1|0)!=0){Ic=Cd;Jc=Dd;Kc=Ed;Lc=Fd;Mc=Gd;Nc=Hd;Oc=Id;Pc=Jd;Qc=Kd;Rc=Ld;Sc=Md;Tc=Nd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}J=ca($a<<1,n)|0;Wa=c[Qb>>2]|0;Xa=Wa+z|0;S=Wa+A|0;if(Xa>>>0<68>>>0|S>>>0<68>>>0){_d=Cd;$d=Dd;ae=Ed;be=Fd;ce=Gd;de=Hd;ee=Id;fe=Jd;ge=Kd;he=Ld;ie=Md;je=Nd}else{Wa=d[1953896+S|0]|0;S=d[2020944+Xa|0]|0;a[Rb]=(a[(Od<<16>>16)+(311880+(Xa<<2))|0]|0)+1;a[Nb]=(a[(Pd<<16>>16)+(311880+(Xa<<2))|0]|0)+1;a[Mb]=(a[(Qd<<16>>16)+(311880+(Xa<<2))|0]|0)+1;a[Lb]=(a[(Rd<<16>>16)+(311880+(Xa<<2))|0]|0)+1;pe[c[Jb>>2]&1023](k+J|0,n,S,Wa,Rb);_d=Od;$d=Pd;ae=Qd;be=Rd;ce=Od;de=Pd;ee=Qd;fe=Rd;ge=Od;he=Pd;ie=Qd;je=Rd}Wa=c[Pb>>2]|0;S=Wa+z|0;Xa=Wa+A|0;if(S>>>0<68>>>0|Xa>>>0<68>>>0){Ic=_d;Jc=$d;Kc=ae;Lc=be;Mc=ce;Nc=de;Oc=ee;Pc=fe;Qc=ge;Rc=he;Sc=ie;Tc=je;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td;break}Wa=d[1953896+Xa|0]|0;Xa=d[2020944+S|0]|0;a[Rb]=(a[(Od<<16>>16)+(311880+(S<<2))|0]|0)+1;a[Nb]=(a[(Pd<<16>>16)+(311880+(S<<2))|0]|0)+1;a[Mb]=(a[(Qd<<16>>16)+(311880+(S<<2))|0]|0)+1;a[Lb]=(a[(Rd<<16>>16)+(311880+(S<<2))|0]|0)+1;pe[c[Jb>>2]&1023](l+J|0,n,Xa,Wa,Rb);Ic=Od;Jc=Pd;Kc=Qd;Lc=Rd;Mc=Od;Nc=Pd;Oc=Qd;Pc=Rd;Qc=Od;Rc=Pd;Sc=Qd;Tc=Rd;Uc=Od;Vc=Pd;Wc=Qd;Xc=Rd;Yc=qd;Zc=rd;_c=sd;$c=td}else{Ic=N;Jc=s;Kc=Hb;Lc=Gb;Mc=Fb;Nc=Eb;Oc=Ib;Pc=Cb;Qc=Db;Rc=g;Sc=h;Tc=y;Uc=Ua;Vc=M;Wc=V;Xc=Sa;Yc=_;Zc=Ta;_c=Za;$c=Va}}while(0);E=$a+1|0;if((E|0)<(Bb|0)){$a=E;N=Ic;s=Jc;Hb=Kc;Gb=Lc;Fb=Mc;Eb=Nc;Ib=Oc;Cb=Pc;Db=Qc;g=Rc;h=Sc;y=Tc;Ua=Uc;M=Vc;V=Wc;Sa=Xc;_=Yc;Ta=Zc;Za=_c;Va=$c}else{break}}i=o;return}function qia(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=a[d+5632+e|0]|0;i=a[d+5632+f|0]|0;j=h<<24>>24!=i<<24>>24;if(j|h<<24>>24==-1){k=j&1}else{j=(b[d+5312+(e<<2)+2>>1]|0)-(b[d+5312+(f<<2)+2>>1]|0)|0;k=(((j|0)>-1?j:-j|0)|0)>=(g|0)|((b[d+5312+(e<<2)>>1]|0)+3-(b[d+5312+(f<<2)>>1]|0)|0)>>>0>6>>>0}if((c[d+199428>>2]|0)!=2){l=k;return l|0}do{if((k|0)==0){j=a[d+5672+e|0]|0;m=a[d+5672+f|0]|0;n=(b[d+5472+(e<<2)+2>>1]|0)-(b[d+5472+(f<<2)+2>>1]|0)|0;if((((b[d+5472+(e<<2)>>1]|0)+3-(b[d+5472+(f<<2)>>1]|0)|0)>>>0>6>>>0|j<<24>>24!=m<<24>>24|(((n|0)>-1?n:-n|0)|0)>=(g|0)|0)==0){l=0}else{o=m;p=j;break}return l|0}else{o=a[d+5672+f|0]|0;p=a[d+5672+e|0]|0}}while(0);if((p<<24>>24!=i<<24>>24|h<<24>>24!=o<<24>>24|0)!=0){l=1;return l|0}o=(b[d+5312+(e<<2)+2>>1]|0)-(b[d+5472+(f<<2)+2>>1]|0)|0;h=(b[d+5472+(e<<2)+2>>1]|0)-(b[d+5312+(f<<2)+2>>1]|0)|0;l=(((o|0)>-1?o:-o|0)|0)>=(g|0)|((b[d+5312+(e<<2)>>1]|0)+3-(b[d+5472+(f<<2)>>1]|0)|0)>>>0>6>>>0|((b[d+5472+(e<<2)>>1]|0)+3-(b[d+5312+(f<<2)>>1]|0)|0)>>>0>6>>>0|(((h|0)>-1?h:-h|0)|0)>=(g|0);return l|0}function ria(a){a=a|0;var b=0;b=c[a>>2]|0;c[b+572248>>2]=b;c[b+572384>>2]=1;bja(b+12|0,8,1);return 0}function sia(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;k=i;i=i+48|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+40|0;c[p>>2]=h;c[q>>2]=j;j=b|0;h=c[j>>2]|0;r=h;s=h+1048|0;t=s;u=h+427464|0;do{if((c[u>>2]|0)==0){c[u>>2]=1;v=e+100|0;w=c[v>>2]|0;if((w|0)==0){break}c[h>>2]=e;if((c[e+176>>2]|0)==0){c[h+4808>>2]=1;x=c[v>>2]|0}else{x=w}iha(r,c[e+96>>2]|0,x)|0}}while(0);x=b+176|0;if((c[x>>2]&1|0)==0){u=via(r,c[p>>2]|0,c[q>>2]|0)|0;if((IWa(t,u,p,q)|0)<0){c[f>>2]=0;c[g>>2]=0;y=c[q>>2]|0;i=k;return y|0}if((u|0)<0&(u|0)!=-100){via(r,(c[s>>2]|0)+((c[h+1056>>2]|0)+u)|0,-u|0)|0}z=u;A=c[q>>2]|0}else{u=c[q>>2]|0;z=u;A=u}u=c[p>>2]|0;s=c[j>>2]|0;r=s;t=u+A|0;c[l>>2]=-1;if((A|0)>3){B=(grc(2542736,u,4)|0)==0}else{B=0}w=b+32|0;c[w>>2]=1;v=b+224|0;c[v>>2]=0;C=b+312|0;c[C>>2]=0;D=s;c[D>>2]=e;Jia(r);c[s+572456>>2]=-1;a:do{if((A|0)!=0){E=s+427456|0;F=t;G=s+1088|0;H=G;I=G;G=s+1100|0;J=s+1104|0;K=s+1092|0;L=s+1096|0;M=s+427436|0;N=s+427460|0;O=u;P=c[E>>2]|0;b:while(1){if((P|0)==0){Q=U5a(O,t,l)|0;if(!(Q>>>0<t>>>0)){R=155;break}S=Q-1|0;T=0;U=F-S|0;V=S}else{S=c[N>>2]|0;if((S|0)>=(F-O|0)){R=155;break}if((S|0)<=0){W=0;R=24;break}Q=(S|0)>1;X=O;Y=0;Z=0;while(1){_=d[X]|Y<<8;$=Z+1|0;if(($|0)<(S|0)){X=X+1|0;Y=_;Z=$}else{break}}Z=O+(Q?S:1)|0;if((_|0)<1){W=_;R=24;break}if((_|0)>(F-Z|0)){W=_;R=24;break}else{T=_;U=_;V=Z}}Z=c[l>>2]|0;Y=Z&31;do{if((Y|0)==1|(Y|0)==5){if((Y|0)==5|(Z&96|0)==0){aa=(U|0)>60?60:U;break}else{aa=(U|0)>1e3?1e3:U;break}}else{aa=U}}while(0);Z=eha(r,V,n,o,aa)|0;if((Z|0)==0){R=155;break}Y=c[n>>2]|0;if((Y|0)<0){R=155;break}S=Y<<3;Y=S>>>0>2147483639>>>0;Q=Y?0:Z;Z=Y?0:S;c[I>>2]=Q;c[G>>2]=Z;c[J>>2]=Z+8;c[K>>2]=Q+(Z>>3);c[L>>2]=0;switch(c[M>>2]|0){case 7:{xia(r)|0;break};case 8:{zia(r,Z)|0;break};case 6:{Kia(r)|0;break};case 5:{R=37;break b;break};case 1:{break b;break};default:{}}Z=c[E>>2]|0;O=V+((Z|0)!=0?T:c[o>>2]|0)|0;P=Z}if((R|0)==24){KIb(c[D>>2]|0,16,2605424,(ba=i,i=i+8|0,c[ba>>2]=W,ba)|0);i=ba;R=155}else if((R|0)==37){c[v>>2]=1;c[s+428676>>2]=0;c[s+428672>>2]=0;c[s+428664>>2]=0;c[s+428660>>2]=0}if((R|0)==155){if(B){break}KIb(c[D>>2]|0,16,2247624,(ba=i,i=i+8|0,c[ba>>2]=A,ba)|0);i=ba;break}wia(H)|0;P=c[L>>2]|0;O=c[I>>2]|0;E=O+(P>>>3)|0;K=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(P&7)>>>23;c[L>>2]=(d[1382088+K|0]|0)+P;c[w>>2]=d[1147184+(((d[1276064+K|0]|0)%5|0)&255)|0]|0;if((c[s+572444>>2]|0)>-1){c[v>>2]=1}K=c[L>>2]|0;P=O+(K>>>3)|0;E=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(K&7);do{if(E>>>0>134217727>>>0){P=E>>>23;J=(d[1382088+P|0]|0)+K|0;c[L>>2]=J;ca=d[1276064+P|0]|0;da=J}else{J=E>>>0>65535>>>0;P=J?E>>>16:E;G=J?16:0;if((P&65280|0)==0){ea=G;fa=P}else{ea=G|8;fa=P>>>8}P=(d[1359664+fa|0]|0)+ea<<1;G=K+63-P|0;c[L>>2]=G;J=(E>>>((P-31|0)>>>0))-1|0;if(!(J>>>0>255>>>0)){ca=J;da=G;break}KIb(c[D>>2]|0,16,2452808,(ba=i,i=i+8|0,c[ba>>2]=J,ba)|0);i=ba;break a}}while(0);E=c[s+427604+(ca<<2)>>2]|0;if((E|0)==0){KIb(c[D>>2]|0,16,2363480,(ba=i,i=i+8|0,c[ba>>2]=ca,ba)|0);i=ba;break}K=s+7328|0;nrc(K|0,E|0,728)|0;E=c[K>>2]|0;K=c[s+427476+(E<<2)>>2]|0;if((K|0)==0){KIb(c[D>>2]|0,16,2298336,(ba=i,i=i+8|0,c[ba>>2]=E,ba)|0);i=ba;break}E=s+6124|0;H=E;nrc(E|0,K|0,1204)|0;K=c[s+6144>>2]|0;E=O+(da>>>3)|0;J=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(da&7)>>>((32-K|0)>>>0);c[L>>2]=K+da;K=s+428656|0;c[K>>2]=J;do{if((c[s+6172>>2]|0)<2){if(!((c[s+7348>>2]|0)>>>0<2>>>0)){break}if((c[w>>2]|0)!=1){break}c[v>>2]=1}}while(0);c[e+840>>2]=uha(H)|0;c[e+844>>2]=c[s+6132>>2];do{if((c[s+6188>>2]|0)==0){O=c[L>>2]|0;J=c[I>>2]|0;E=d[J+(O>>>3)|0]|0;G=O+1|0;c[L>>2]=G;if((E&128>>>((O&7)>>>0)|0)==0){c[s+177100>>2]=3;ga=3;break}else{E=d[J+(G>>>3)|0]<<(G&7)>>>7;c[L>>2]=O+2;O=(E&1)+1|0;c[s+177100>>2]=O;ga=O;break}}else{c[s+177100>>2]=3;ga=3}}while(0);do{if((c[M>>2]|0)==5){H=c[L>>2]|0;O=(c[I>>2]|0)+(H>>>3)|0;E=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(H&7);if(E>>>0>134217727>>>0){c[L>>2]=(d[1382088+(E>>>23)|0]|0)+H;break}O=E>>>0>65535>>>0;G=O?E>>>16:E;E=O?16:0;if((G&65280|0)==0){ha=E;ia=G}else{ha=E|8;ia=G>>>8}c[L>>2]=H+63-((d[1359664+ia|0]|0)+ha<<1)}}while(0);H=c[s+6148>>2]|0;do{if((H|0)==0){G=c[s+6152>>2]|0;E=c[L>>2]|0;O=c[I>>2]|0;J=O+(E>>>3)|0;P=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(E&7)>>>((32-G|0)>>>0);J=E+G|0;c[L>>2]=J;c[s+428636>>2]=P;if(!((c[s+7336>>2]|0)==1&(ga|0)==3)){break}P=O+(J>>>3)|0;G=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(J&7);if(G>>>0>134217727>>>0){P=G>>>23;c[L>>2]=(d[1382088+P|0]|0)+J;ja=a[1306768+P|0]|0}else{P=G>>>0>65535>>>0;E=P?G>>>16:G;G=P?16:0;if((E&65280|0)==0){ka=G;la=E}else{ka=G|8;la=E>>>8}E=(d[1359664+la|0]|0)+ka|0;G=31-E+J|0;J=O+(G>>>3)|0;O=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(G&7)>>>(E>>>0);c[L>>2]=32-E+G;G=O>>>1;ja=(O&1|0)==0?G:-G|0}c[s+428644>>2]=ja}else if((H|0)==1){if((c[s+6156>>2]|0)!=0){break}G=c[L>>2]|0;O=c[I>>2]|0;E=O+(G>>>3)|0;J=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(G&7);if(J>>>0>134217727>>>0){E=J>>>23;P=(d[1382088+E|0]|0)+G|0;c[L>>2]=P;ma=a[1306768+E|0]|0;na=P}else{P=J>>>0>65535>>>0;E=P?J>>>16:J;J=P?16:0;if((E&65280|0)==0){oa=J;pa=E}else{oa=J|8;pa=E>>>8}E=(d[1359664+pa|0]|0)+oa|0;J=31-E+G|0;G=O+(J>>>3)|0;P=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>>(E>>>0);G=J+(32-E)|0;c[L>>2]=G;E=P>>>1;ma=(P&1|0)==0?E:-E|0;na=G}c[s+428648>>2]=ma;if(!((c[s+7336>>2]|0)==1&(ga|0)==3)){break}G=O+(na>>>3)|0;E=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(na&7);if(E>>>0>134217727>>>0){G=E>>>23;c[L>>2]=(d[1382088+G|0]|0)+na;qa=a[1306768+G|0]|0}else{G=E>>>0>65535>>>0;P=G?E>>>16:E;E=G?16:0;if((P&65280|0)==0){ra=E;sa=P}else{ra=E|8;sa=P>>>8}P=(d[1359664+sa|0]|0)+ra|0;E=31-P+na|0;G=O+(E>>>3)|0;O=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(E&7)>>>(P>>>0);c[L>>2]=32-P+E;E=O>>>1;qa=(O&1|0)==0?E:-E|0}c[s+428652>>2]=qa}}while(0);L=m+4|0;c[L>>2]=2147483647;I=m|0;c[I>>2]=2147483647;tha(r,I,b+316|0)|0;H=s+427432|0;c:do{if((c[H>>2]|0)==0){R=126}else{if((c[M>>2]|0)==5){R=126;break}E=c[j>>2]|0;O=E;P=E+177080|0;c[P>>2]=c[w>>2]&3;do{if((c[E+7388>>2]|0)!=0){G=E+1096|0;J=c[G>>2]|0;F=(c[E+1088>>2]|0)+(J>>>3)|0;N=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(J&7);if(N>>>0>134217727>>>0){c[G>>2]=(d[1382088+(N>>>23)|0]|0)+J;break}F=N>>>0>65535>>>0;Z=F?N>>>16:N;N=F?16:0;if((Z&65280|0)==0){ta=N;ua=Z}else{ta=N|8;ua=Z>>>8}c[G>>2]=J+63-((d[1359664+ua|0]|0)+ta<<1)}}while(0);if((vha(O)|0)<0){break a}J=c[P>>2]|0;do{if((J|0)!=1){G=c[E+199428>>2]|0;d:do{if((G|0)!=0){Z=E+1096|0;N=E+199420|0;F=c[E+1088>>2]|0;Q=0;S=c[Z>>2]|0;e:while(1){Y=d[F+(S>>>3)|0]|0;X=S+1|0;c[Z>>2]=X;if((Y&128>>>((S&7)>>>0)|0)==0){va=X}else{Y=N+(Q<<2)|0;wa=0;$=X;while(1){X=F+($>>>3)|0;xa=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<($&7)>>>23;ya=(d[1382088+xa|0]|0)+$|0;c[Z>>2]=ya;za=a[1276064+xa|0]|0;if(!((za&255)>>>0<3>>>0)){break}xa=F+(ya>>>3)|0;X=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(ya&7);if(X>>>0>134217727>>>0){Aa=(d[1382088+(X>>>23)|0]|0)+ya|0}else{xa=X>>>0>65535>>>0;Ba=xa?X>>>16:X;X=xa?16:0;if((Ba&65280|0)==0){Ca=X;Da=Ba}else{Ca=X|8;Da=Ba>>>8}Aa=ya+63-((d[1359664+Da|0]|0)+Ca<<1)|0}c[Z>>2]=Aa;if(wa>>>0<(c[Y>>2]|0)>>>0){wa=wa+1|0;$=Aa}else{R=109;break e}}if((za&255)>>>0>3>>>0){R=108;break}else{va=ya}}$=Q+1|0;if($>>>0<G>>>0){Q=$;S=va}else{break d}}if((R|0)==108){KIb(c[E>>2]|0,16,2205616,(ba=i,i=i+8|0,c[ba>>2]=za&255,ba)|0);i=ba;break a}else if((R|0)==109){KIb(c[E>>2]|0,16,2173424,(ba=i,i=i+8|0,c[ba>>2]=wa,ba)|0);i=ba;break a}}}while(0);if(!((c[E+7356>>2]|0)!=0&(J|0)==2)){if(!((c[E+7360>>2]|0)==1&(J|0)==3)){break}}sha(O)|0}}while(0);O=E+1096|0;J=c[O>>2]|0;P=c[E+1088>>2]|0;G=d[P+(J>>>3)|0]|0;S=J+1|0;c[O>>2]=S;if((G&128>>>((J&7)>>>0)|0)==0){R=126;break}else{Ea=0;Fa=S}f:while(1){S=P+(Fa>>>3)|0;J=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Fa&7)>>>23;S=(d[1382088+J|0]|0)+Fa|0;c[O>>2]=S;G=a[1276064+J|0]|0;Ga=G&255;if((G&255)>>>0>6>>>0){R=116;break}do{if((Ga|0)==3|(Ga|0)==1){J=P+(S>>>3)|0;Q=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(S&7);if(Q>>>0>134217727>>>0){J=(d[1382088+(Q>>>23)|0]|0)+S|0;c[O>>2]=J;Ha=J;break}J=Q>>>0>65535>>>0;Z=J?Q>>>16:Q;Q=J?16:0;if((Z&65280|0)==0){Ia=Q;Ja=Z}else{Ia=Q|8;Ja=Z>>>8}Z=S+63-((d[1359664+Ja|0]|0)+Ia<<1)|0;c[O>>2]=Z;Ha=Z}else if((Ga|0)==0){R=126;break c}else if((Ga|0)==5){R=127;break f}else{Ha=S}}while(0);if((Ga-2|0)>>>0<2>>>0|G<<24>>24==6|G<<24>>24==4){S=P+(Ha>>>3)|0;Z=(d[1382088+((je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Ha&7)>>>23)|0]|0)+Ha|0;c[O>>2]=Z;Ka=Z}else{Ka=Ha}Z=Ea+1|0;if((Z|0)<66){Ea=Z;Fa=Ka}else{R=126;break c}}if((R|0)==116){KIb(c[E>>2]|0,16,2145968,(ba=i,i=i+8|0,c[ba>>2]=Ga,ba)|0);i=ba;break a}else if((R|0)==127){c[s+428676>>2]=0;La=0;Ma=1;break}}}while(0);if((R|0)==126){c[s+428676>>2]=c[K>>2];La=c[s+428668>>2]|0;Ma=0}c[s+428672>>2]=La;do{if((c[H>>2]|0)!=0){if(Ma){c[s+428660>>2]=0;c[s+428664>>2]=(c[s+177100>>2]|0)==2?0:c[I>>2]|0;break}else{c[s+428660>>2]=c[s+428640>>2];c[s+428664>>2]=c[s+428636>>2];break}}}while(0);H=s+7284|0;g:do{if((c[H>>2]|0)==0){c[b+36>>2]=(c[s+177100>>2]|0)==3}else{switch(c[s+572408>>2]|0){case 1:case 2:{c[b+36>>2]=0;break g;break};case 0:case 3:case 4:{c[b+36>>2]=1;break g;break};case 5:case 6:{c[b+36>>2]=2;break g;break};case 7:{c[b+36>>2]=3;break g;break};case 8:{c[b+36>>2]=5;break g;break};default:{c[b+36>>2]=(c[s+177100>>2]|0)==3;break g}}}}while(0);K=c[s+177100>>2]|0;if((K|0)==3){c[C>>2]=3;if((c[H>>2]|0)!=0){M=c[s+572408>>2]|0;if((M|0)==3|(M|0)==5){c[b+308>>2]=2;break}else if((M|0)==4|(M|0)==6){c[b+308>>2]=3;break}else{c[b+308>>2]=1;break}}M=c[I>>2]|0;O=c[L>>2]|0;if((M|0)<(O|0)){c[b+308>>2]=2;break}P=b+308|0;if((M|0)>(O|0)){c[P>>2]=3;break}else{c[P>>2]=1;break}}else if((K|0)==1){Na=1}else{Na=2}c[C>>2]=Na;c[b+308>>2]=0}}while(0);Na=h+572440|0;if((c[Na>>2]|0)>-1){c[b+240>>2]=c[h+572500>>2];c[b+244>>2]=c[Na>>2];c[b+248>>2]=c[h+572436>>2]}else{c[b+240>>2]=-2147483648;c[b+244>>2]=-2147483648;c[b+248>>2]=-2147483648}b=c[x>>2]|0;if((b&2|0)!=0){c[x>>2]=b&1}c[f>>2]=c[p>>2];c[g>>2]=c[q>>2];y=z;i=k;return y|0}function tia(a){a=a|0;var b=0;b=c[a>>2]|0;kJb(c[b+1048>>2]|0);lha(b);return}function uia(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((e|0)<0){f=0;return f|0}else{g=0;h=-1;i=0}while(1){b=h&-225;j=(b|0)==263;k=j?1:i;if(!((h&-256|0)!=256|j|(b|0)==264|(b|0)==265|(k|0)==0)){l=g;break}if((g|0)<(e|0)){m=d[c+g|0]|h<<8}else{m=h}b=g+1|0;if((b|0)>(e|0)){f=0;n=9;break}else{g=b;h=m;i=k}}if((n|0)==9){return f|0}while(1){if((l|0)<=4){break}if((a[c+(l-5)|0]|0)==0){l=l-1|0}else{break}}f=l-4|0;return f|0}function via(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;g=i;i=i+24|0;h=g|0;j=b+427456|0;k=c[j>>2]|0;l=(k|0)!=0?0:f;m=b+1064|0;n=c[m>>2]|0;o=n>>>0>13>>>0?7:n;do{if((k|0)!=0){if((c[b+427460>>2]|0)!=0){break}KIb(c[b>>2]|0,16,2122168,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);a:do{if((f|0)>0){k=b+144|0;n=b+572676|0;q=b+572680|0;r=b+572672|0;s=(r|0)==0;t=h|0;u=h+12|0;v=h+16|0;w=h+4|0;x=h+8|0;y=b+1068|0;z=b+427460|0;A=o;B=l;C=0;b:while(1){do{if((C|0)<(B|0)){if((A|0)==7){D=(We[c[k>>2]&2047](e+C|0,B-C|0)|0)+C|0;E=D;F=(D|0)<(B|0)?2:7;G=B;break}if(A>>>0<3>>>0){D=a[e+C|0]|0;if((D<<24>>24|0)==1){E=C;F=A^5;G=B;break}else if((D<<24>>24|0)==0){E=C;F=A>>>1;G=B;break}else{E=C;F=7;G=B;break}}D=a[e+C|0]|0;if(A>>>0<6>>>0){H=A;I=B;J=C;K=D;L=22;break}M=c[n>>2]|0;c[n>>2]=M+1;a[b+572672+M|0]=D;D=c[n>>2]|0;if((D|0)<=3){E=C;F=A;G=B;break}M=D<<3;D=M>>>0>2147483639>>>0|s;N=D?0:r;O=D?0:M;c[t>>2]=N;c[u>>2]=O;c[v>>2]=O+8;c[w>>2]=N+(O>>3);c[x>>2]=0;c[n>>2]=0;O=wia(h)|0;N=c[q>>2]|0;c[q>>2]=O;if((c[y>>2]|0)==0){c[y>>2]=1;E=C;F=7;G=B;break}else{if(O>>>0>N>>>0){E=C;F=7;G=B;break}else{P=C;Q=A;R=B;break b}}}else{N=c[z>>2]|0;if((N|0)<=0){S=B;T=0;L=11;break b}O=(N|0)>1?N:1;M=0;D=0;U=B;while(1){V=d[e+U|0]|0|D<<8;W=M+1|0;if((W|0)<(N|0)){M=W;D=V;U=U+1|0}else{break}}U=B+O|0;if((V|0)<1){S=U;T=V;L=11;break b}D=f-U|0;if((V|0)>(D|0)){X=D;Y=V;L=13;break b}H=5;I=U+V|0;J=U;K=a[e+U|0]|0;L=22}}while(0);do{if((L|0)==22){L=0;U=K&31;if((U-6|0)>>>0<4>>>0){if((c[y>>2]|0)==0){E=J;F=7;G=I;break}else{L=24;break b}}else{E=J;F=(U-1|0)>>>0<2>>>0|(U|0)==5?H+8|0:7;G=I;break}}}while(0);U=E+1|0;if((U|0)<(f|0)){A=F;B=G;C=U}else{Z=F;_=G;break a}}if((L|0)==11){X=f-S|0;Y=T;L=13}else if((L|0)==24){P=J+1|0;Q=H;R=I}if((L|0)==13){KIb(c[b>>2]|0,16,2639888,(p=i,i=i+16|0,c[p>>2]=Y,c[p+8>>2]=X,p)|0);i=p;$=f;i=g;return $|0}c[m>>2]=7;c[y>>2]=0;if((c[j>>2]|0)!=0){$=R;i=g;return $|0}$=P-(Q&5)-(-(Q>>>0>7>>>0|0)&3)|0;i=g;return $|0}else{Z=o;_=l}}while(0);c[m>>2]=Z;$=(c[j>>2]|0)==0?-100:_;i=g;return $|0}function wia(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a>>2]|0;e=a+8|0;a=c[e>>2]|0;f=b+(a>>>3)|0;g=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(a&7);f=a+16|0;h=b+(f>>>3)|0;i=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(f&7)>>>16|g&-65536;f=i>>>0>65535>>>0;h=f?g>>>16:i;i=f?16:0;if((h&65280|0)==0){j=i;k=h}else{j=i|8;k=h>>>8}h=(d[1359664+k|0]|0)+j|0;j=31-h|0;k=j+a|0;c[e>>2]=k;a=j+1|0;if((a|0)==0){l=0;m=l-1|0;return m|0}i=b+(k>>>3)|0;f=(je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(k&7);if((a|0)<26){c[e>>2]=k+a;l=f>>>(h>>>0);m=l-1|0;return m|0}else{h=k+16|0;c[e>>2]=h;i=b+(h>>>3)|0;b=(je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(h&7)>>>((47-j|0)>>>0);c[e>>2]=k+a;l=b|f>>>16<<j-15;m=l-1|0;return m|0}return 0}function xia(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0;f=i;g=e+1096|0;h=c[g>>2]|0;j=e+1104|0;k=c[j>>2]|0;l=e+1088|0;m=c[l>>2]|0;n=m+(h>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(h&7)>>>24;n=h+8|0;h=k>>>0>n>>>0?n:k;c[g>>2]=h;n=d[m+(h>>>3)|0]<<(h&7)>>>7;p=((h|0)<(k|0))+h|0;c[g>>2]=p;h=d[m+(p>>>3)|0]<<(p&7)>>>7;q=((p|0)<(k|0))+p|0;c[g>>2]=q;p=d[m+(q>>>3)|0]<<(q&7)>>>7;r=((q|0)<(k|0))+q|0;c[g>>2]=r;q=d[m+(r>>>3)|0]<<(r&7)>>>7;s=((r|0)<(k|0))+r|0;c[g>>2]=s;r=d[m+(s>>>3)|0]<<(s&7)>>>7;t=((s|0)<(k|0))+s|0;c[g>>2]=t;s=h<<1&2|n&1|p<<2&4|q<<3&8|r<<4&16|d[m+(t>>>3)|0]<<(t&7)>>>7<<5&32;r=((t|0)<(k|0))+t+2|0;t=k>>>0>r>>>0?r:k;c[g>>2]=t;r=m+(t>>>3)|0;q=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7)>>>24;r=t+8|0;t=k>>>0>r>>>0?r:k;c[g>>2]=t;r=m+(t>>>3)|0;m=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7)>>>23;r=(d[1382088+m|0]|0)+t|0;c[g>>2]=k>>>0>r>>>0?r:k;k=a[1276064+m|0]|0;m=k&255;if((k&255)>>>0>31>>>0){KIb(c[e>>2]|0,16,2542440,(u=i,i=i+8|0,c[u>>2]=m,u)|0);i=u;v=-1094995529;i=f;return v|0}k=pJb(1204)|0;r=k;if((k|0)==0){v=-12;i=f;return v|0}c[k>>2]=m;c[k+1164>>2]=24;t=k+4|0;c[t>>2]=o;c[k+1196>>2]=s;s=k+8|0;c[s>>2]=q;q=k+112|0;c[q>>2]=-1;p=k+672|0;n=k+768|0;mrc(p|0,16,480)|0;c[k+668>>2]=0;h=k+128|0;c[h>>2]=2;a:do{switch(o|0){case 100:case 110:case 122:case 244:case 44:case 83:case 86:case 118:case 128:case 144:{w=c[g>>2]|0;x=c[j>>2]|0;y=c[l>>2]|0;z=y+(w>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7)>>>23;z=(d[1382088+A|0]|0)+w|0;w=x>>>0>z>>>0?z:x;c[g>>2]=w;z=a[1276064+A|0]|0;A=z&255;c[k+12>>2]=A;if((z&255)>>>0>3>>>0){QIb(c[e>>2]|0,2605400,(u=i,i=i+8|0,c[u>>2]=A,u)|0);i=u;break a}do{if(z<<24>>24==3){A=d[y+(w>>>3)|0]<<(w&7)>>>7;B=((w|0)<(x|0))+w|0;c[g>>2]=B;C=A&1;c[k+1192>>2]=C;if((C|0)==0){D=B;break}KIb(c[e>>2]|0,16,2452760,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break a}else{D=w}}while(0);w=y+(D>>>3)|0;z=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(D&7);if(z>>>0>134217727>>>0){w=z>>>23;B=(d[1382088+w|0]|0)+D|0;C=x>>>0>B>>>0?B:x;c[g>>2]=C;E=d[1276064+w|0]|0;F=C}else{C=z>>>0>65535>>>0;w=C?z>>>16:z;B=C?16:0;if((w&65280|0)==0){G=B;H=w}else{G=B|8;H=w>>>8}w=(d[1359664+H|0]|0)+G<<1;B=63-w+D|0;C=x>>>0>B>>>0?B:x;c[g>>2]=C;E=(z>>>((w-31|0)>>>0))-1|0;F=C}C=E+8|0;c[k+1184>>2]=C;w=y+(F>>>3)|0;z=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(F&7);if(z>>>0>134217727>>>0){w=z>>>23;B=(d[1382088+w|0]|0)+F|0;A=x>>>0>B>>>0?B:x;c[g>>2]=A;I=d[1276064+w|0]|0;J=A}else{A=z>>>0>65535>>>0;w=A?z>>>16:z;B=A?16:0;if((w&65280|0)==0){K=B;L=w}else{K=B|8;L=w>>>8}w=(d[1359664+L|0]|0)+K<<1;B=63-w+F|0;A=x>>>0>B>>>0?B:x;c[g>>2]=A;I=(z>>>((w-31|0)>>>0))-1|0;J=A}A=I+8|0;c[k+1188>>2]=A;if((A|0)!=(C|0)){QIb(c[e>>2]|0,2363432,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break a}if(C>>>0>14>>>0){KIb(c[e>>2]|0,16,2298296,(u=i,i=i+16|0,c[u>>2]=C,c[u+8>>2]=C,u)|0);i=u;break a}else{C=d[y+(J>>>3)|0]<<(J&7)>>>7;c[g>>2]=((J|0)<(x|0))+J;c[k+16>>2]=C&1;yia(e,r,0,1,p,n);M=26;break a}break};default:{c[k+12>>2]=1;c[k+1184>>2]=8;c[k+1188>>2]=8;M=26}}}while(0);b:do{if((M|0)==26){n=c[g>>2]|0;p=c[j>>2]|0;J=c[l>>2]|0;I=J+(n>>>3)|0;F=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(n&7);if(F>>>0>134217727>>>0){I=F>>>23;K=(d[1382088+I|0]|0)+n|0;L=p>>>0>K>>>0?K:p;c[g>>2]=L;N=d[1276064+I|0]|0;O=L}else{L=F>>>0>65535>>>0;I=L?F>>>16:F;K=L?16:0;if((I&65280|0)==0){P=K;Q=I}else{P=K|8;Q=I>>>8}I=(d[1359664+Q|0]|0)+P<<1;K=63-I+n|0;n=p>>>0>K>>>0?K:p;c[g>>2]=n;N=(F>>>((I-31|0)>>>0))-1|0;O=n}if(N>>>0>12>>>0){KIb(c[e>>2]|0,16,2247568,(u=i,i=i+8|0,c[u>>2]=N,u)|0);i=u;break}c[k+20>>2]=N+4;n=J+(O>>>3)|0;I=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(O&7)>>>23;n=(d[1382088+I|0]|0)+O|0;F=p>>>0>n>>>0?n:p;c[g>>2]=F;n=d[1276064+I|0]|0;I=k+24|0;c[I>>2]=n;do{if((n|0)==0){K=J+(F>>>3)|0;L=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(F&7);if(L>>>0>134217727>>>0){K=L>>>23;E=(d[1382088+K|0]|0)+F|0;D=p>>>0>E>>>0?E:p;c[g>>2]=D;R=d[1276064+K|0]|0;S=D}else{D=L>>>0>65535>>>0;K=D?L>>>16:L;E=D?16:0;if((K&65280|0)==0){T=E;U=K}else{T=E|8;U=K>>>8}K=(d[1359664+U|0]|0)+T<<1;E=63-K+F|0;D=p>>>0>E>>>0?E:p;c[g>>2]=D;R=(L>>>((K-31|0)>>>0))-1|0;S=D}if(R>>>0>12>>>0){KIb(c[e>>2]|0,16,2205576,(u=i,i=i+8|0,c[u>>2]=R,u)|0);i=u;break b}else{c[k+28>>2]=R+4;V=S;break}}else if((n|0)==1){D=d[J+(F>>>3)|0]<<(F&7)>>>7;K=((F|0)<(p|0))+F|0;c[g>>2]=K;c[k+32>>2]=D&1;D=J+(K>>>3)|0;L=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7);if(L>>>0>134217727>>>0){D=L>>>23;E=(d[1382088+D|0]|0)+K|0;G=p>>>0>E>>>0?E:p;c[g>>2]=G;W=a[1306768+D|0]|0;X=G}else{G=L>>>0>65535>>>0;D=G?L>>>16:L;L=G?16:0;if((D&65280|0)==0){Y=L;Z=D}else{Y=L|8;Z=D>>>8}D=(d[1359664+Z|0]|0)+Y|0;L=31-D+K|0;K=p>>>0>L>>>0?L:p;L=J+(K>>>3)|0;G=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(K&7)>>>(D>>>0);L=K+(32-D)|0;D=p>>>0>L>>>0?L:p;c[g>>2]=D;L=G>>>1;W=(G&1|0)==0?L:-L|0;X=D}c[k+36>>2]=W;D=J+(X>>>3)|0;L=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(X&7);if(L>>>0>134217727>>>0){D=L>>>23;G=(d[1382088+D|0]|0)+X|0;K=p>>>0>G>>>0?G:p;c[g>>2]=K;_=a[1306768+D|0]|0;$=K}else{K=L>>>0>65535>>>0;D=K?L>>>16:L;L=K?16:0;if((D&65280|0)==0){aa=L;ba=D}else{aa=L|8;ba=D>>>8}D=(d[1359664+ba|0]|0)+aa|0;L=31-D+X|0;K=p>>>0>L>>>0?L:p;L=J+(K>>>3)|0;G=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(K&7)>>>(D>>>0);L=K+(32-D)|0;D=p>>>0>L>>>0?L:p;c[g>>2]=D;L=G>>>1;_=(G&1|0)==0?L:-L|0;$=D}c[k+40>>2]=_;D=J+($>>>3)|0;L=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<($&7);do{if(L>>>0>134217727>>>0){D=L>>>23;G=(d[1382088+D|0]|0)+$|0;K=p>>>0>G>>>0?G:p;c[g>>2]=K;G=d[1276064+D|0]|0;D=k+44|0;c[D>>2]=G;da=D;ea=K;fa=G}else{G=L>>>0>65535>>>0;K=G?L>>>16:L;D=G?16:0;if((K&65280|0)==0){ga=D;ha=K}else{ga=D|8;ha=K>>>8}K=(d[1359664+ha|0]|0)+ga<<1;D=63-K+$|0;G=p>>>0>D>>>0?D:p;c[g>>2]=G;D=(L>>>((K-31|0)>>>0))-1|0;K=k+44|0;c[K>>2]=D;if(!(D>>>0>255>>>0)){da=K;ea=G;fa=D;break}KIb(c[e>>2]|0,16,2173392,(u=i,i=i+8|0,c[u>>2]=D,u)|0);i=u;break b}}while(0);if((fa|0)<=0){V=ea;break}L=k+148|0;D=0;G=ea;while(1){K=J+(G>>>3)|0;E=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(G&7);if(E>>>0>134217727>>>0){K=E>>>23;H=(d[1382088+K|0]|0)+G|0;o=p>>>0>H>>>0?H:p;c[g>>2]=o;ia=a[1306768+K|0]|0;ja=o}else{o=E>>>0>65535>>>0;K=o?E>>>16:E;E=o?16:0;if((K&65280|0)==0){ka=E;la=K}else{ka=E|8;la=K>>>8}K=(d[1359664+la|0]|0)+ka|0;E=31-K+G|0;o=p>>>0>E>>>0?E:p;E=J+(o>>>3)|0;H=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(o&7)>>>(K>>>0);E=o+(32-K)|0;K=p>>>0>E>>>0?E:p;c[g>>2]=K;E=H>>>1;ia=((H&1|0)==0?E:-E|0)&65535;ja=K}b[L+(D<<1)>>1]=ia;K=D+1|0;if((K|0)<(c[da>>2]|0)){D=K;G=ja}else{V=ja;break}}}else if((n|0)==2){V=F}else{KIb(c[e>>2]|0,16,2145944,(u=i,i=i+8|0,c[u>>2]=n,u)|0);i=u;break b}}while(0);n=J+(V>>>3)|0;F=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(V&7)>>>23;n=(d[1382088+F|0]|0)+V|0;x=p>>>0>n>>>0?n:p;c[g>>2]=x;n=d[1276064+F|0]|0;F=k+48|0;c[F>>2]=n;y=e|0;G=c[y>>2]|0;if((c[G+52>>2]|0)==844516691){D=n>>>0<2>>>0?2:n;c[F>>2]=D;ma=D}else{ma=n}if((ma|0)>34|ma>>>0>16>>>0){KIb(G,16,2122136,(u=i,i=i+8|0,c[u>>2]=ma,u)|0);i=u;break}n=d[J+(x>>>3)|0]<<(x&7)>>>7;D=((x|0)<(p|0))+x|0;c[g>>2]=D;c[k+52>>2]=n&1;n=J+(D>>>3)|0;x=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(D&7);if(x>>>0>134217727>>>0){n=x>>>23;L=(d[1382088+n|0]|0)+D|0;K=p>>>0>L>>>0?L:p;c[g>>2]=K;na=d[1276064+n|0]|0;oa=K}else{K=x>>>0>65535>>>0;n=K?x>>>16:x;L=K?16:0;if((n&65280|0)==0){pa=L;qa=n}else{pa=L|8;qa=n>>>8}n=(d[1359664+qa|0]|0)+pa<<1;L=63-n+D|0;D=p>>>0>L>>>0?L:p;c[g>>2]=D;na=(x>>>((n-31|0)>>>0))-1|0;oa=D}D=na+1|0;n=k+56|0;c[n>>2]=D;x=J+(oa>>>3)|0;L=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(oa&7);if(L>>>0>134217727>>>0){x=L>>>23;K=(d[1382088+x|0]|0)+oa|0;c[g>>2]=p>>>0>K>>>0?K:p;ra=d[1276064+x|0]|0}else{x=L>>>0>65535>>>0;K=x?L>>>16:L;E=x?16:0;if((K&65280|0)==0){sa=E;ta=K}else{sa=E|8;ta=K>>>8}K=(d[1359664+ta|0]|0)+sa<<1;E=63-K+oa|0;c[g>>2]=p>>>0>E>>>0?E:p;ra=(L>>>((K-31|0)>>>0))-1|0}K=ra+1|0;L=k+60|0;c[L>>2]=K;do{if(D>>>0>134217726>>>0|K>>>0>134217726>>>0){ua=G}else{if((tIb(D<<4,K<<4,0,G)|0)!=0){ua=c[y>>2]|0;break}E=c[g>>2]|0;x=c[l>>2]|0;H=d[x+(E>>>3)|0]<<(E&7)>>>7;o=c[j>>2]|0;C=((E|0)<(o|0))+E|0;c[g>>2]=C;E=H&1;H=k+64|0;c[H>>2]=E;if((E|0)==0){A=d[x+(C>>>3)|0]<<(C&7)>>>7;w=((C|0)<(o|0))+C|0;c[g>>2]=w;c[k+68>>2]=A&1;va=w}else{c[k+68>>2]=0;va=C}C=d[x+(va>>>3)|0]<<(va&7)>>>7;w=((va|0)<(o|0))+va|0;c[g>>2]=w;A=k+72|0;c[A>>2]=C&1;C=d[x+(w>>>3)|0]<<(w&7)>>>7;z=((w|0)<(o|0))+w|0;c[g>>2]=z;w=C&1;C=k+76|0;c[C>>2]=w;c:do{if((w|0)==0){mrc(C|0,0,20)|0}else{B=x+(z>>>3)|0;wa=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7);if(wa>>>0>134217727>>>0){B=wa>>>23;xa=(d[1382088+B|0]|0)+z|0;ya=o>>>0>xa>>>0?xa:o;c[g>>2]=ya;za=d[1276064+B|0]|0;Aa=ya}else{ya=wa>>>0>65535>>>0;B=ya?wa>>>16:wa;xa=ya?16:0;if((B&65280|0)==0){Ba=xa;Ca=B}else{Ba=xa|8;Ca=B>>>8}B=(d[1359664+Ca|0]|0)+Ba<<1;xa=63-B+z|0;ya=o>>>0>xa>>>0?xa:o;c[g>>2]=ya;za=(wa>>>((B-31|0)>>>0))-1|0;Aa=ya}ya=x+(Aa>>>3)|0;B=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(Aa&7);if(B>>>0>134217727>>>0){ya=B>>>23;wa=(d[1382088+ya|0]|0)+Aa|0;xa=o>>>0>wa>>>0?wa:o;c[g>>2]=xa;Da=d[1276064+ya|0]|0;Ea=xa}else{xa=B>>>0>65535>>>0;ya=xa?B>>>16:B;wa=xa?16:0;if((ya&65280|0)==0){Fa=wa;Ga=ya}else{Fa=wa|8;Ga=ya>>>8}ya=(d[1359664+Ga|0]|0)+Fa<<1;wa=63-ya+Aa|0;xa=o>>>0>wa>>>0?wa:o;c[g>>2]=xa;Da=(B>>>((ya-31|0)>>>0))-1|0;Ea=xa}xa=x+(Ea>>>3)|0;ya=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ea&7);if(ya>>>0>134217727>>>0){xa=ya>>>23;B=(d[1382088+xa|0]|0)+Ea|0;wa=o>>>0>B>>>0?B:o;c[g>>2]=wa;Ha=d[1276064+xa|0]|0;Ia=wa}else{wa=ya>>>0>65535>>>0;xa=wa?ya>>>16:ya;B=wa?16:0;if((xa&65280|0)==0){Ja=B;Ka=xa}else{Ja=B|8;Ka=xa>>>8}xa=(d[1359664+Ka|0]|0)+Ja<<1;B=63-xa+Ea|0;wa=o>>>0>B>>>0?B:o;c[g>>2]=wa;Ha=(ya>>>((xa-31|0)>>>0))-1|0;Ia=wa}wa=x+(Ia>>>3)|0;xa=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Ia&7);if(xa>>>0>134217727>>>0){wa=xa>>>23;ya=(d[1382088+wa|0]|0)+Ia|0;c[g>>2]=o>>>0>ya>>>0?ya:o;La=d[1276064+wa|0]|0}else{wa=xa>>>0>65535>>>0;ya=wa?xa>>>16:xa;B=wa?16:0;if((ya&65280|0)==0){Ma=B;Na=ya}else{Ma=B|8;Na=ya>>>8}ya=(d[1359664+Na|0]|0)+Ma<<1;B=63-ya+Ia|0;c[g>>2]=o>>>0>B>>>0?B:o;La=(xa>>>((ya-31|0)>>>0))-1|0}ya=c[n>>2]<<4;xa=2-E|0;B=ca(xa,c[L>>2]<<4)|0;wa=c[y>>2]|0;if((c[wa+92>>2]&65536|0)!=0){KIb(wa,48,2617072,(u=i,i=i+32|0,c[u>>2]=za,c[u+8>>2]=Da,c[u+16>>2]=Ha,c[u+24>>2]=La,u)|0);i=u;mrc(k+80|0,0,16)|0;break}Oa=c[k+12>>2]|0;Pa=(Oa|0)==1;if(Pa){Qa=1}else{Qa=(Oa|0)==2|0}Oa=xa<<(Pa&1);Pa=31>>>(((c[k+1184>>2]|0)>8|0)>>>0);do{if((Pa&za|0)==0){Ra=za}else{if((c[wa+88>>2]&1|0)!=0){Ra=za;break}xa=za&~Pa;KIb(wa,24,2589888,(u=i,i=i+8|0,c[u>>2]=xa,u)|0);i=u;Ra=xa}}while(0);wa=536870911>>>(Qa>>>0);do{if(!(Ra>>>0>wa>>>0|Da>>>0>wa>>>0)){Pa=536870911/(Oa>>>0)|0;if(Ha>>>0>Pa>>>0|La>>>0>Pa>>>0){break}if((Ra+Da<<Qa|0)>=(ya|0)){break}if((ca(Oa,La+Ha|0)|0)>=(B|0)){break}c[k+80>>2]=Ra<<Qa;c[k+84>>2]=Da<<Qa;c[k+88>>2]=ca(Oa,Ha)|0;c[k+92>>2]=ca(Oa,La)|0;break c}}while(0);KIb(c[y>>2]|0,16,2568168,(u=i,i=i+48|0,c[u>>2]=Ra,c[u+8>>2]=Da,c[u+16>>2]=Ha,c[u+24>>2]=La,c[u+32>>2]=ya,c[u+40>>2]=B,u)|0);i=u;break b}}while(0);E=c[g>>2]|0;o=c[l>>2]|0;x=d[o+(E>>>3)|0]<<(E&7)>>>7;z=c[j>>2]|0;C=((E|0)<(z|0))+E|0;c[g>>2]=C;E=x&1;x=k+96|0;c[x>>2]=E;d:do{if((E|0)!=0){w=d[o+(C>>>3)|0]|0;Oa=((C|0)<(z|0))+C|0;c[g>>2]=Oa;do{if((w&128>>>((C&7)>>>0)|0)==0){c[k+104>>2]=0;c[k+100>>2]=0;Sa=Oa}else{wa=o+(Oa>>>3)|0;Pa=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(Oa&7);wa=Pa>>>24;xa=Oa+8|0;Ta=z>>>0>xa>>>0?xa:z;c[g>>2]=Ta;if((wa|0)==255){xa=o+(Ta>>>3)|0;Ua=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ta&7)>>>16;xa=Ta+16|0;Va=z>>>0>xa>>>0?xa:z;c[g>>2]=Va;c[k+100>>2]=Ua;Ua=o+(Va>>>3)|0;xa=(je(d[Ua]|d[Ua+1|0]<<8|d[Ua+2|0]<<16|d[Ua+3|0]<<24|0)|0)<<(Va&7)>>>16;Ua=Va+16|0;Va=z>>>0>Ua>>>0?Ua:z;c[g>>2]=Va;c[k+104>>2]=xa;Sa=Va;break}if(Pa>>>0<285212672>>>0){Pa=728928+(wa<<3)|0;wa=k+100|0;Va=c[Pa+4>>2]|0;c[wa>>2]=c[Pa>>2];c[wa+4>>2]=Va;Sa=Ta;break}else{KIb(c[y>>2]|0,16,2334016,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break b}}}while(0);Oa=((Sa|0)<(z|0))+Sa|0;if((d[o+(Sa>>>3)|0]&128>>>((Sa&7)>>>0)|0)==0){Wa=Oa}else{Wa=((Oa|0)<(z|0))+Oa|0}c[g>>2]=Wa;Oa=d[o+(Wa>>>3)|0]<<(Wa&7)>>>7;w=((Wa|0)<(z|0))+Wa|0;c[g>>2]=w;B=Oa&1;c[k+108>>2]=B;do{if((B|0)==0){Xa=w}else{Oa=w+3|0;ya=z>>>0>Oa>>>0?Oa:z;c[g>>2]=ya;Oa=d[o+(ya>>>3)|0]<<(ya&7)>>>7;Ta=((ya|0)<(z|0))+ya|0;c[g>>2]=Ta;c[q>>2]=Oa&1;Oa=d[o+(Ta>>>3)|0]<<(Ta&7)>>>7;ya=((Ta|0)<(z|0))+Ta|0;c[g>>2]=ya;Ta=Oa&1;c[k+116>>2]=Ta;if((Ta|0)==0){Xa=ya;break}Ta=o+(ya>>>3)|0;Oa=(je(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(ya&7);Ta=ya+8|0;ya=z>>>0>Ta>>>0?Ta:z;c[g>>2]=ya;Ta=k+120|0;c[Ta>>2]=Oa>>>24;Va=o+(ya>>>3)|0;wa=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(ya&7);Va=ya+8|0;ya=z>>>0>Va>>>0?Va:z;c[g>>2]=ya;Va=k+124|0;c[Va>>2]=wa>>>24;Pa=o+(ya>>>3)|0;xa=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(ya&7);Pa=ya+8|0;ya=z>>>0>Pa>>>0?Pa:z;c[g>>2]=ya;c[h>>2]=xa>>>24;if(Oa>>>0>167772159>>>0){c[Ta>>2]=2}if(wa>>>0>268435455>>>0){c[Va>>2]=2}if(!(xa>>>0>184549375>>>0)){Xa=ya;break}c[h>>2]=2;Xa=ya}}while(0);w=d[o+(Xa>>>3)|0]|0;B=((Xa|0)<(z|0))+Xa|0;c[g>>2]=B;do{if((w&128>>>((Xa&7)>>>0)|0)==0){Ya=B}else{ya=o+(B>>>3)|0;xa=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(B&7);if(xa>>>0>134217727>>>0){ya=xa>>>23;Va=(d[1382088+ya|0]|0)+B|0;wa=z>>>0>Va>>>0?Va:z;c[g>>2]=wa;Za=d[1276064+ya|0]|0;_a=wa}else{wa=xa>>>0>65535>>>0;ya=wa?xa>>>16:xa;Va=wa?16:0;if((ya&65280|0)==0){$a=Va;ab=ya}else{$a=Va|8;ab=ya>>>8}ya=(d[1359664+ab|0]|0)+$a<<1;Va=63-ya+B|0;wa=z>>>0>Va>>>0?Va:z;c[g>>2]=wa;Za=(xa>>>((ya-31|0)>>>0))-1|0;_a=wa}c[(c[y>>2]|0)+400>>2]=Za+1;wa=o+(_a>>>3)|0;ya=(je(d[wa]|d[wa+1|0]<<8|d[wa+2|0]<<16|d[wa+3|0]<<24|0)|0)<<(_a&7);if(ya>>>0>134217727>>>0){wa=(d[1382088+(ya>>>23)|0]|0)+_a|0;xa=z>>>0>wa>>>0?wa:z;c[g>>2]=xa;Ya=xa;break}xa=ya>>>0>65535>>>0;wa=xa?ya>>>16:ya;ya=xa?16:0;if((wa&65280|0)==0){bb=ya;cb=wa}else{bb=ya|8;cb=wa>>>8}wa=63-((d[1359664+cb|0]|0)+bb<<1)+_a|0;ya=z>>>0>wa>>>0?wa:z;c[g>>2]=ya;Ya=ya}}while(0);B=o+(Ya>>>3)|0;w=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=Ya&7;do{if(((je(w|0)|0)&-2147483648>>>(B>>>0)|0)!=0){if(((c[e+1100>>2]|0)-Ya|0)>=10){break}KIb(c[y>>2]|0,24,2328760,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break d}}while(0);ya=((Ya|0)<(z|0))+Ya|0;c[g>>2]=ya;wa=(w&255)<<B>>>7&1;c[k+132>>2]=wa;do{if((wa|0)==0){db=ya}else{xa=o+(ya>>>3)|0;Va=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(ya&7)&-65536;xa=ya+16|0;Ta=z>>>0>xa>>>0?xa:z;c[g>>2]=Ta;xa=o+(Ta>>>3)|0;Oa=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ta&7)>>>16;xa=Ta+16|0;Ta=z>>>0>xa>>>0?xa:z;c[g>>2]=Ta;xa=Oa|Va;c[k+136>>2]=xa;Va=o+(Ta>>>3)|0;Oa=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)&-65536;Va=Ta+16|0;Ta=z>>>0>Va>>>0?Va:z;c[g>>2]=Ta;Va=o+(Ta>>>3)|0;Pa=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)>>>16;Va=Ta+16|0;Ta=z>>>0>Va>>>0?Va:z;c[g>>2]=Ta;Va=Pa|Oa;c[k+140>>2]=Va;if((xa|0)==0|(Va|0)==0){KIb(c[y>>2]|0,16,2322848,(u=i,i=i+16|0,c[u>>2]=Va,c[u+8>>2]=xa,u)|0);i=u;break b}else{xa=d[o+(Ta>>>3)|0]<<(Ta&7)>>>7;Va=((Ta|0)<(z|0))+Ta|0;c[g>>2]=Va;c[k+144>>2]=xa&1;db=Va;break}}}while(0);ya=d[o+(db>>>3)|0]<<(db&7)>>>7;wa=((db|0)<(z|0))+db|0;c[g>>2]=wa;B=ya&1;ya=k+1152|0;c[ya>>2]=B;if((B|0)==0){eb=o;fb=wa;gb=z}else{if((Aia(e,r)|0)<0){break b}eb=c[l>>2]|0;fb=c[g>>2]|0;gb=c[j>>2]|0}wa=d[eb+(fb>>>3)|0]<<(fb&7)>>>7;c[g>>2]=((fb|0)<(gb|0))+fb;B=wa&1;wa=k+1156|0;c[wa>>2]=B;if((B|0)!=0){if((Aia(e,r)|0)<0){break b}}do{if((c[ya>>2]|0)==0){if((c[wa>>2]|0)!=0){M=167;break}hb=c[g>>2]|0;ib=c[j>>2]|0}else{M=167}}while(0);if((M|0)==167){wa=c[g>>2]|0;ya=c[j>>2]|0;B=((wa|0)<(ya|0))+wa|0;c[g>>2]=B;hb=B;ib=ya}ya=c[l>>2]|0;B=d[ya+(hb>>>3)|0]<<(hb&7)>>>7;wa=((hb|0)<(ib|0))+hb|0;c[g>>2]=wa;c[k+1160>>2]=B&1;B=c[e+1100>>2]|0;if((B|0)==(wa|0)){break}w=d[ya+(wa>>>3)|0]<<(wa&7)>>>7;Va=((wa|0)<(ib|0))+wa|0;c[g>>2]=Va;wa=w&1;w=k+660|0;c[w>>2]=wa;do{if((wa|0)==0){jb=Va}else{xa=((Va|0)<(ib|0))+Va|0;c[g>>2]=xa;Ta=ya+(xa>>>3)|0;Oa=(je(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(xa&7);if(Oa>>>0>134217727>>>0){Ta=(d[1382088+(Oa>>>23)|0]|0)+xa|0;kb=ib>>>0>Ta>>>0?Ta:ib}else{Ta=Oa>>>0>65535>>>0;Pa=Ta?Oa>>>16:Oa;Oa=Ta?16:0;if((Pa&65280|0)==0){lb=Oa;mb=Pa}else{lb=Oa|8;mb=Pa>>>8}Pa=63-((d[1359664+mb|0]|0)+lb<<1)+xa|0;kb=ib>>>0>Pa>>>0?Pa:ib}c[g>>2]=kb;Pa=ya+(kb>>>3)|0;xa=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(kb&7);if(xa>>>0>134217727>>>0){Pa=(d[1382088+(xa>>>23)|0]|0)+kb|0;nb=ib>>>0>Pa>>>0?Pa:ib}else{Pa=xa>>>0>65535>>>0;Oa=Pa?xa>>>16:xa;xa=Pa?16:0;if((Oa&65280|0)==0){ob=xa;pb=Oa}else{ob=xa|8;pb=Oa>>>8}Oa=63-((d[1359664+pb|0]|0)+ob<<1)+kb|0;nb=ib>>>0>Oa>>>0?Oa:ib}c[g>>2]=nb;Oa=ya+(nb>>>3)|0;xa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(nb&7);if(xa>>>0>134217727>>>0){Oa=(d[1382088+(xa>>>23)|0]|0)+nb|0;qb=ib>>>0>Oa>>>0?Oa:ib}else{Oa=xa>>>0>65535>>>0;Pa=Oa?xa>>>16:xa;xa=Oa?16:0;if((Pa&65280|0)==0){rb=xa;sb=Pa}else{rb=xa|8;sb=Pa>>>8}Pa=63-((d[1359664+sb|0]|0)+rb<<1)+nb|0;qb=ib>>>0>Pa>>>0?Pa:ib}c[g>>2]=qb;Pa=ya+(qb>>>3)|0;xa=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(qb&7);if(xa>>>0>134217727>>>0){Pa=(d[1382088+(xa>>>23)|0]|0)+qb|0;tb=ib>>>0>Pa>>>0?Pa:ib}else{Pa=xa>>>0>65535>>>0;Oa=Pa?xa>>>16:xa;xa=Pa?16:0;if((Oa&65280|0)==0){ub=xa;vb=Oa}else{ub=xa|8;vb=Oa>>>8}Oa=63-((d[1359664+vb|0]|0)+ub<<1)+qb|0;tb=ib>>>0>Oa>>>0?Oa:ib}c[g>>2]=tb;Oa=ya+(tb>>>3)|0;xa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(tb&7);if(xa>>>0>134217727>>>0){Oa=xa>>>23;Pa=(d[1382088+Oa|0]|0)+tb|0;Ta=ib>>>0>Pa>>>0?Pa:ib;c[g>>2]=Ta;wb=d[1276064+Oa|0]|0;xb=Ta}else{Ta=xa>>>0>65535>>>0;Oa=Ta?xa>>>16:xa;Pa=Ta?16:0;if((Oa&65280|0)==0){yb=Pa;zb=Oa}else{yb=Pa|8;zb=Oa>>>8}Oa=(d[1359664+zb|0]|0)+yb<<1;Pa=63-Oa+tb|0;Ta=ib>>>0>Pa>>>0?Pa:ib;c[g>>2]=Ta;wb=(xa>>>((Oa-31|0)>>>0))-1|0;xb=Ta}Ta=k+664|0;c[Ta>>2]=wb;Oa=ya+(xb>>>3)|0;xa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(xb&7);if(xa>>>0>134217727>>>0){Oa=(d[1382088+(xa>>>23)|0]|0)+xb|0;Ab=ib>>>0>Oa>>>0?Oa:ib}else{Oa=xa>>>0>65535>>>0;Pa=Oa?xa>>>16:xa;xa=Oa?16:0;if((Pa&65280|0)==0){Bb=xa;Cb=Pa}else{Bb=xa|8;Cb=Pa>>>8}Pa=63-((d[1359664+Cb|0]|0)+Bb<<1)+xb|0;Ab=ib>>>0>Pa>>>0?Pa:ib}c[g>>2]=Ab;if((B-Ab|0)<0){c[Ta>>2]=0;c[w>>2]=0;jb=Ab;break}if(!(wb>>>0>16>>>0)){jb=Ab;break}KIb(c[y>>2]|0,16,2317848,(u=i,i=i+8|0,c[u>>2]=wb,u)|0);i=u;c[Ta>>2]=16;break b}}while(0);w=B-jb|0;if((w|0)>=0){break}KIb(c[y>>2]|0,16,2313128,(u=i,i=i+8|0,c[u>>2]=-w,u)|0);i=u;break b}}while(0);z=k+104|0;if((c[z>>2]|0)==0){c[z>>2]=1}z=c[y>>2]|0;if((c[z+688>>2]&1|0)!=0){o=c[t>>2]|0;C=c[s>>2]|0;E=c[I>>2]|0;w=c[F>>2]|0;ya=c[n>>2]|0;Va=c[L>>2]|0;if((c[H>>2]|0)==0){Db=(c[k+68>>2]|0)!=0?2516888:2502880}else{Db=2532056}wa=(c[A>>2]|0)!=0?2489736:10230544;Ta=c[k+80>>2]|0;Pa=c[k+84>>2]|0;xa=c[k+88>>2]|0;Oa=c[k+92>>2]|0;Ua=(c[x>>2]|0)!=0?2469136:10230544;Eb=1376128+((c[k+12>>2]|0)*5|0)|0;if((c[k+132>>2]|0)==0){Fb=0;Gb=0}else{Fb=c[k+140>>2]|0;Gb=c[k+136>>2]|0}Hb=c[k+1184>>2]|0;if((c[k+660>>2]|0)==0){Ib=-1}else{Ib=c[k+664>>2]|0}KIb(z,48,2550136,(u=i,i=i+152|0,c[u>>2]=m,c[u+8>>2]=o,c[u+16>>2]=C,c[u+24>>2]=E,c[u+32>>2]=w,c[u+40>>2]=ya,c[u+48>>2]=Va,c[u+56>>2]=Db,c[u+64>>2]=wa,c[u+72>>2]=Ta,c[u+80>>2]=Pa,c[u+88>>2]=xa,c[u+96>>2]=Oa,c[u+104>>2]=Ua,c[u+112>>2]=Eb,c[u+120>>2]=Gb,c[u+128>>2]=Fb,c[u+136>>2]=Hb,c[u+144>>2]=Ib,u)|0);i=u}c[k+1200>>2]=1;Hb=e+427476+(m<<2)|0;kJb(c[Hb>>2]|0);c[Hb>>2]=r;v=0;i=f;return v|0}}while(0);KIb(ua,16,2639856,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u}}while(0);kJb(k);v=-1;i=f;return v|0}function yia(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;j=(g|0)!=0;if(j){k=0}else{k=(c[e+668>>2]|0)!=0}l=k?e+720|0:1576224;m=k?e+768|0:1576080;n=k?e+960|0:1576144;o=b+1096|0;p=c[o>>2]|0;q=b+1088|0;r=c[q>>2]|0;s=d[r+(p>>>3)|0]|0;t=b+1104|0;c[o>>2]=((p|0)<(c[t>>2]|0))+p;if((s&128>>>((p&7)>>>0)|0)==0){return}p=e+668|0;c[p>>2]=c[p>>2]|g;g=h|0;p=c[o>>2]|0;s=d[r+(p>>>3)|0]|0;c[o>>2]=((p|0)<(c[t>>2]|0))+p;a:do{if((s&128>>>((p&7)>>>0)|0)==0){nrc(g|0,(k?e+672|0:1576208)|0,16)|0}else{r=8;b=8;u=0;while(1){if((b|0)==0){v=0}else{w=c[o>>2]|0;x=c[t>>2]|0;y=c[q>>2]|0;z=y+(w>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(w&7);if(A>>>0>134217727>>>0){z=A>>>23;B=(d[1382088+z|0]|0)+w|0;c[o>>2]=x>>>0>B>>>0?B:x;C=a[1306768+z|0]|0}else{z=A>>>0>65535>>>0;B=z?A>>>16:A;A=z?16:0;if((B&65280|0)==0){D=A;E=B}else{D=A|8;E=B>>>8}B=(d[1359664+E|0]|0)+D|0;A=31-B+w|0;w=x>>>0>A>>>0?A:x;A=y+(w>>>3)|0;y=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(w&7)>>>(B>>>0);A=w+(32-B)|0;c[o>>2]=x>>>0>A>>>0?A:x;x=y>>>1;C=(y&1|0)==0?x:-x|0}v=C+r&255}if((v|u|0)==0){break}x=(v|0)!=0?v:r;a[h+(d[120+u|0]|0)|0]=x;y=u+1|0;if((y|0)<16){r=x;b=v;u=y}else{break a}}nrc(g|0,1576208,16)|0}}while(0);v=h+16|0;C=c[o>>2]|0;D=d[(c[q>>2]|0)+(C>>>3)|0]|0;c[o>>2]=((C|0)<(c[t>>2]|0))+C;b:do{if((D&128>>>((C&7)>>>0)|0)==0){nrc(v|0,g|0,16)|0}else{E=8;k=8;p=0;while(1){if((k|0)==0){F=0}else{s=c[o>>2]|0;u=c[t>>2]|0;b=c[q>>2]|0;r=b+(s>>>3)|0;y=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7);if(y>>>0>134217727>>>0){r=y>>>23;x=(d[1382088+r|0]|0)+s|0;c[o>>2]=u>>>0>x>>>0?x:u;G=a[1306768+r|0]|0}else{r=y>>>0>65535>>>0;x=r?y>>>16:y;y=r?16:0;if((x&65280|0)==0){H=y;I=x}else{H=y|8;I=x>>>8}x=(d[1359664+I|0]|0)+H|0;y=31-x+s|0;s=u>>>0>y>>>0?y:u;y=b+(s>>>3)|0;b=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(s&7)>>>(x>>>0);y=s+(32-x)|0;c[o>>2]=u>>>0>y>>>0?y:u;u=b>>>1;G=(b&1|0)==0?u:-u|0}F=G+E&255}if((F|p|0)==0){break}u=(F|0)!=0?F:E;a[(d[120+p|0]|0)+(h+16)|0]=u;b=p+1|0;if((b|0)<16){E=u;k=F;p=b}else{break b}}nrc(v|0,1576208,16)|0}}while(0);F=h+32|0;G=c[o>>2]|0;H=d[(c[q>>2]|0)+(G>>>3)|0]|0;c[o>>2]=((G|0)<(c[t>>2]|0))+G;c:do{if((H&128>>>((G&7)>>>0)|0)==0){nrc(F|0,v|0,16)|0}else{I=8;g=8;C=0;while(1){if((g|0)==0){J=0}else{D=c[o>>2]|0;p=c[t>>2]|0;k=c[q>>2]|0;E=k+(D>>>3)|0;b=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7);if(b>>>0>134217727>>>0){E=b>>>23;u=(d[1382088+E|0]|0)+D|0;c[o>>2]=p>>>0>u>>>0?u:p;K=a[1306768+E|0]|0}else{E=b>>>0>65535>>>0;u=E?b>>>16:b;b=E?16:0;if((u&65280|0)==0){L=b;M=u}else{L=b|8;M=u>>>8}u=(d[1359664+M|0]|0)+L|0;b=31-u+D|0;D=p>>>0>b>>>0?b:p;b=k+(D>>>3)|0;k=(je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(D&7)>>>(u>>>0);b=D+(32-u)|0;c[o>>2]=p>>>0>b>>>0?b:p;p=k>>>1;K=(k&1|0)==0?p:-p|0}J=K+I&255}if((J|C|0)==0){break}p=(J|0)!=0?J:I;a[(d[120+C|0]|0)+(h+32)|0]=p;k=C+1|0;if((k|0)<16){I=p;g=J;C=k}else{break c}}nrc(F|0,1576208,16)|0}}while(0);F=h+48|0;J=c[o>>2]|0;K=d[(c[q>>2]|0)+(J>>>3)|0]|0;c[o>>2]=((J|0)<(c[t>>2]|0))+J;d:do{if((K&128>>>((J&7)>>>0)|0)==0){nrc(F|0,l|0,16)|0}else{L=8;M=8;v=0;while(1){if((M|0)==0){N=0}else{G=c[o>>2]|0;H=c[t>>2]|0;C=c[q>>2]|0;g=C+(G>>>3)|0;I=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(G&7);if(I>>>0>134217727>>>0){g=I>>>23;k=(d[1382088+g|0]|0)+G|0;c[o>>2]=H>>>0>k>>>0?k:H;O=a[1306768+g|0]|0}else{g=I>>>0>65535>>>0;k=g?I>>>16:I;I=g?16:0;if((k&65280|0)==0){P=I;Q=k}else{P=I|8;Q=k>>>8}k=(d[1359664+Q|0]|0)+P|0;I=31-k+G|0;G=H>>>0>I>>>0?I:H;I=C+(G>>>3)|0;C=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(G&7)>>>(k>>>0);I=G+(32-k)|0;c[o>>2]=H>>>0>I>>>0?I:H;H=C>>>1;O=(C&1|0)==0?H:-H|0}N=O+L&255}if((N|v|0)==0){break}H=(N|0)!=0?N:L;a[(d[120+v|0]|0)+(h+48)|0]=H;C=v+1|0;if((C|0)<16){L=H;M=N;v=C}else{break d}}nrc(F|0,1576224,16)|0}}while(0);N=h+64|0;O=c[o>>2]|0;P=d[(c[q>>2]|0)+(O>>>3)|0]|0;c[o>>2]=((O|0)<(c[t>>2]|0))+O;e:do{if((P&128>>>((O&7)>>>0)|0)==0){nrc(N|0,F|0,16)|0}else{Q=8;l=8;J=0;while(1){if((l|0)==0){R=0}else{K=c[o>>2]|0;v=c[t>>2]|0;M=c[q>>2]|0;L=M+(K>>>3)|0;C=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(K&7);if(C>>>0>134217727>>>0){L=C>>>23;H=(d[1382088+L|0]|0)+K|0;c[o>>2]=v>>>0>H>>>0?H:v;S=a[1306768+L|0]|0}else{L=C>>>0>65535>>>0;H=L?C>>>16:C;C=L?16:0;if((H&65280|0)==0){T=C;U=H}else{T=C|8;U=H>>>8}H=(d[1359664+U|0]|0)+T|0;C=31-H+K|0;K=v>>>0>C>>>0?C:v;C=M+(K>>>3)|0;M=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(K&7)>>>(H>>>0);C=K+(32-H)|0;c[o>>2]=v>>>0>C>>>0?C:v;v=M>>>1;S=(M&1|0)==0?v:-v|0}R=S+Q&255}if((R|J|0)==0){break}v=(R|0)!=0?R:Q;a[(d[120+J|0]|0)+(h+64)|0]=v;M=J+1|0;if((M|0)<16){Q=v;l=R;J=M}else{break e}}nrc(N|0,1576224,16)|0}}while(0);R=h+80|0;S=c[o>>2]|0;T=d[(c[q>>2]|0)+(S>>>3)|0]|0;c[o>>2]=((S|0)<(c[t>>2]|0))+S;f:do{if((T&128>>>((S&7)>>>0)|0)==0){nrc(R|0,N|0,16)|0}else{U=8;F=8;O=0;while(1){if((F|0)==0){V=0}else{P=c[o>>2]|0;J=c[t>>2]|0;l=c[q>>2]|0;Q=l+(P>>>3)|0;M=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(P&7);if(M>>>0>134217727>>>0){Q=M>>>23;v=(d[1382088+Q|0]|0)+P|0;c[o>>2]=J>>>0>v>>>0?v:J;W=a[1306768+Q|0]|0}else{Q=M>>>0>65535>>>0;v=Q?M>>>16:M;M=Q?16:0;if((v&65280|0)==0){X=M;Y=v}else{X=M|8;Y=v>>>8}v=(d[1359664+Y|0]|0)+X|0;M=31-v+P|0;P=J>>>0>M>>>0?M:J;M=l+(P>>>3)|0;l=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(P&7)>>>(v>>>0);M=P+(32-v)|0;c[o>>2]=J>>>0>M>>>0?M:J;J=l>>>1;W=(l&1|0)==0?J:-J|0}V=W+U&255}if((V|O|0)==0){break}J=(V|0)!=0?V:U;a[(d[120+O|0]|0)+(h+80)|0]=J;l=O+1|0;if((l|0)<16){U=J;F=V;O=l}else{break f}}nrc(R|0,1576224,16)|0}}while(0);do{if(!j){if((c[f+64>>2]|0)!=0){break}return}}while(0);f=i|0;j=c[o>>2]|0;R=d[(c[q>>2]|0)+(j>>>3)|0]|0;c[o>>2]=((j|0)<(c[t>>2]|0))+j;g:do{if((R&128>>>((j&7)>>>0)|0)==0){nrc(f|0,m|0,64)|0}else{V=8;h=8;W=0;while(1){if((h|0)==0){Z=0}else{X=c[o>>2]|0;Y=c[t>>2]|0;N=c[q>>2]|0;S=N+(X>>>3)|0;T=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(X&7);if(T>>>0>134217727>>>0){S=T>>>23;O=(d[1382088+S|0]|0)+X|0;c[o>>2]=Y>>>0>O>>>0?O:Y;_=a[1306768+S|0]|0}else{S=T>>>0>65535>>>0;O=S?T>>>16:T;T=S?16:0;if((O&65280|0)==0){$=T;aa=O}else{$=T|8;aa=O>>>8}O=(d[1359664+aa|0]|0)+$|0;T=31-O+X|0;X=Y>>>0>T>>>0?T:Y;T=N+(X>>>3)|0;N=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(X&7)>>>(O>>>0);T=X+(32-O)|0;c[o>>2]=Y>>>0>T>>>0?T:Y;Y=N>>>1;_=(N&1|0)==0?Y:-Y|0}Z=_+V&255}if((Z|W|0)==0){break}Y=(Z|0)!=0?Z:V;a[i+(d[1242080+W|0]|0)|0]=Y;N=W+1|0;if((N|0)<64){V=Y;h=Z;W=N}else{break g}}nrc(f|0,1576080,64)|0}}while(0);Z=i+192|0;_=c[o>>2]|0;$=d[(c[q>>2]|0)+(_>>>3)|0]|0;c[o>>2]=((_|0)<(c[t>>2]|0))+_;h:do{if(($&128>>>((_&7)>>>0)|0)==0){nrc(Z|0,n|0,64)|0}else{aa=8;m=8;j=0;while(1){if((m|0)==0){ba=0}else{R=c[o>>2]|0;W=c[t>>2]|0;h=c[q>>2]|0;V=h+(R>>>3)|0;N=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(R&7);if(N>>>0>134217727>>>0){V=N>>>23;Y=(d[1382088+V|0]|0)+R|0;c[o>>2]=W>>>0>Y>>>0?Y:W;ca=a[1306768+V|0]|0}else{V=N>>>0>65535>>>0;Y=V?N>>>16:N;N=V?16:0;if((Y&65280|0)==0){da=N;ea=Y}else{da=N|8;ea=Y>>>8}Y=(d[1359664+ea|0]|0)+da|0;N=31-Y+R|0;R=W>>>0>N>>>0?N:W;N=h+(R>>>3)|0;h=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(R&7)>>>(Y>>>0);N=R+(32-Y)|0;c[o>>2]=W>>>0>N>>>0?N:W;W=h>>>1;ca=(h&1|0)==0?W:-W|0}ba=ca+aa&255}if((ba|j|0)==0){break}W=(ba|0)!=0?ba:aa;a[(d[1242080+j|0]|0)+(i+192)|0]=W;h=j+1|0;if((h|0)<64){aa=W;m=ba;j=h}else{break h}}nrc(Z|0,1576144,64)|0}}while(0);if((c[e+12>>2]|0)!=3){return}e=i+64|0;ba=c[o>>2]|0;ca=d[(c[q>>2]|0)+(ba>>>3)|0]|0;c[o>>2]=((ba|0)<(c[t>>2]|0))+ba;i:do{if((ca&128>>>((ba&7)>>>0)|0)==0){nrc(e|0,f|0,64)|0}else{da=8;ea=8;n=0;while(1){if((ea|0)==0){fa=0}else{_=c[o>>2]|0;$=c[t>>2]|0;j=c[q>>2]|0;m=j+(_>>>3)|0;aa=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(_&7);if(aa>>>0>134217727>>>0){m=aa>>>23;h=(d[1382088+m|0]|0)+_|0;c[o>>2]=$>>>0>h>>>0?h:$;ga=a[1306768+m|0]|0}else{m=aa>>>0>65535>>>0;h=m?aa>>>16:aa;aa=m?16:0;if((h&65280|0)==0){ha=aa;ia=h}else{ha=aa|8;ia=h>>>8}h=(d[1359664+ia|0]|0)+ha|0;aa=31-h+_|0;_=$>>>0>aa>>>0?aa:$;aa=j+(_>>>3)|0;j=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7)>>>(h>>>0);aa=_+(32-h)|0;c[o>>2]=$>>>0>aa>>>0?aa:$;$=j>>>1;ga=(j&1|0)==0?$:-$|0}fa=ga+da&255}if((fa|n|0)==0){break}$=(fa|0)!=0?fa:da;a[(d[1242080+n|0]|0)+(i+64)|0]=$;j=n+1|0;if((j|0)<64){da=$;ea=fa;n=j}else{break i}}nrc(e|0,1576080,64)|0}}while(0);fa=i+256|0;ga=c[o>>2]|0;ha=d[(c[q>>2]|0)+(ga>>>3)|0]|0;c[o>>2]=((ga|0)<(c[t>>2]|0))+ga;j:do{if((ha&128>>>((ga&7)>>>0)|0)==0){nrc(fa|0,Z|0,64)|0}else{ia=8;f=8;ba=0;while(1){if((f|0)==0){ja=0}else{ca=c[o>>2]|0;n=c[t>>2]|0;ea=c[q>>2]|0;da=ea+(ca>>>3)|0;j=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ca&7);if(j>>>0>134217727>>>0){da=j>>>23;$=(d[1382088+da|0]|0)+ca|0;c[o>>2]=n>>>0>$>>>0?$:n;ka=a[1306768+da|0]|0}else{da=j>>>0>65535>>>0;$=da?j>>>16:j;j=da?16:0;if(($&65280|0)==0){la=j;ma=$}else{la=j|8;ma=$>>>8}$=(d[1359664+ma|0]|0)+la|0;j=31-$+ca|0;ca=n>>>0>j>>>0?j:n;j=ea+(ca>>>3)|0;ea=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(ca&7)>>>($>>>0);j=ca+(32-$)|0;c[o>>2]=n>>>0>j>>>0?j:n;n=ea>>>1;ka=(ea&1|0)==0?n:-n|0}ja=ka+ia&255}if((ja|ba|0)==0){break}n=(ja|0)!=0?ja:ia;a[(d[1242080+ba|0]|0)+(i+256)|0]=n;ea=ba+1|0;if((ea|0)<64){ia=n;f=ja;ba=ea}else{break j}}nrc(fa|0,1576144,64)|0}}while(0);ja=i+128|0;ka=c[o>>2]|0;la=d[(c[q>>2]|0)+(ka>>>3)|0]|0;c[o>>2]=((ka|0)<(c[t>>2]|0))+ka;k:do{if((la&128>>>((ka&7)>>>0)|0)==0){nrc(ja|0,e|0,64)|0}else{ma=8;Z=8;ga=0;while(1){if((Z|0)==0){na=0}else{ha=c[o>>2]|0;ba=c[t>>2]|0;f=c[q>>2]|0;ia=f+(ha>>>3)|0;ea=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(ha&7);if(ea>>>0>134217727>>>0){ia=ea>>>23;n=(d[1382088+ia|0]|0)+ha|0;c[o>>2]=ba>>>0>n>>>0?n:ba;oa=a[1306768+ia|0]|0}else{ia=ea>>>0>65535>>>0;n=ia?ea>>>16:ea;ea=ia?16:0;if((n&65280|0)==0){pa=ea;qa=n}else{pa=ea|8;qa=n>>>8}n=(d[1359664+qa|0]|0)+pa|0;ea=31-n+ha|0;ha=ba>>>0>ea>>>0?ea:ba;ea=f+(ha>>>3)|0;f=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ha&7)>>>(n>>>0);ea=ha+(32-n)|0;c[o>>2]=ba>>>0>ea>>>0?ea:ba;ba=f>>>1;oa=(f&1|0)==0?ba:-ba|0}na=oa+ma&255}if((na|ga|0)==0){break}ba=(na|0)!=0?na:ma;a[(d[1242080+ga|0]|0)+(i+128)|0]=ba;f=ga+1|0;if((f|0)<64){ma=ba;Z=na;ga=f}else{break k}}nrc(ja|0,1576080,64)|0}}while(0);ja=i+320|0;na=c[o>>2]|0;oa=d[(c[q>>2]|0)+(na>>>3)|0]|0;c[o>>2]=((na|0)<(c[t>>2]|0))+na;if((oa&128>>>((na&7)>>>0)|0)==0){nrc(ja|0,fa|0,64)|0;return}else{ra=8;sa=8;ta=0}while(1){if((sa|0)==0){ua=0}else{fa=c[o>>2]|0;na=c[t>>2]|0;oa=c[q>>2]|0;pa=oa+(fa>>>3)|0;qa=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(fa&7);if(qa>>>0>134217727>>>0){pa=qa>>>23;e=(d[1382088+pa|0]|0)+fa|0;c[o>>2]=na>>>0>e>>>0?e:na;va=a[1306768+pa|0]|0}else{pa=qa>>>0>65535>>>0;e=pa?qa>>>16:qa;qa=pa?16:0;if((e&65280|0)==0){wa=qa;xa=e}else{wa=qa|8;xa=e>>>8}e=(d[1359664+xa|0]|0)+wa|0;qa=31-e+fa|0;fa=na>>>0>qa>>>0?qa:na;qa=oa+(fa>>>3)|0;oa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(fa&7)>>>(e>>>0);qa=fa+(32-e)|0;c[o>>2]=na>>>0>qa>>>0?qa:na;na=oa>>>1;va=(oa&1|0)==0?na:-na|0}ua=va+ra&255}if((ua|ta|0)==0){break}na=(ua|0)!=0?ua:ra;a[(d[1242080+ta|0]|0)+(i+320)|0]=na;oa=ta+1|0;if((oa|0)<64){ra=na;sa=ua;ta=oa}else{ya=151;break}}if((ya|0)==151){return}nrc(ja|0,1576144,64)|0;return}function zia(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;f=i;g=b+1096|0;h=c[g>>2]|0;j=b+1104|0;k=c[j>>2]|0;l=b+1088|0;m=(c[l>>2]|0)+(h>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7);do{if(n>>>0>134217727>>>0){m=n>>>23;o=(d[1382088+m|0]|0)+h|0;c[g>>2]=k>>>0>o>>>0?o:k;p=d[1276064+m|0]|0}else{m=n>>>0>65535>>>0;o=m?n>>>16:n;q=m?16:0;if((o&65280|0)==0){r=q;s=o}else{r=q|8;s=o>>>8}o=(d[1359664+s|0]|0)+r<<1;q=63-o+h|0;c[g>>2]=k>>>0>q>>>0?q:k;q=(n>>>((o-31|0)>>>0))-1|0;if(!(q>>>0>255>>>0)){p=q;break}KIb(c[b>>2]|0,16,2459912,(t=i,i=i+8|0,c[t>>2]=q,t)|0);i=t;u=-1094995529;i=f;return u|0}}while(0);n=pJb(728)|0;k=n;if((n|0)==0){u=-12;i=f;return u|0}h=c[g>>2]|0;r=c[j>>2]|0;s=c[l>>2]|0;q=s+(h>>>3)|0;o=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(h&7)>>>23;q=(d[1382088+o|0]|0)+h|0;h=r>>>0>q>>>0?q:r;c[g>>2]=h;q=a[1276064+o|0]|0;o=q&255;m=n;c[m>>2]=o;do{if((q&255)>>>0>31>>>0){v=10}else{w=c[b+427476+(o<<2)>>2]|0;if((w|0)==0){v=10;break}x=w+1184|0;w=c[x>>2]|0;y=w*6|0;if((w|0)>14){KIb(c[b>>2]|0,16,2443248,(t=i,i=i+8|0,c[t>>2]=w,t)|0);i=t;break}if((w|0)==11|(w|0)==13){KIb(c[b>>2]|0,16,2430824,(t=i,i=i+8|0,c[t>>2]=w,t)|0);i=t;break}w=d[s+(h>>>3)|0]<<(h&7)>>>7;z=((h|0)<(r|0))+h|0;c[g>>2]=z;A=n+4|0;c[A>>2]=w&1;w=d[s+(z>>>3)|0]<<(z&7)>>>7;B=((z|0)<(r|0))+z|0;c[g>>2]=B;c[n+8>>2]=w&1;w=s+(B>>>3)|0;z=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(B&7);if(z>>>0>134217727>>>0){w=z>>>23;C=(d[1382088+w|0]|0)+B|0;D=r>>>0>C>>>0?C:r;c[g>>2]=D;E=d[1276064+w|0]|0;F=D}else{D=z>>>0>65535>>>0;w=D?z>>>16:z;C=D?16:0;if((w&65280|0)==0){G=C;H=w}else{G=C|8;H=w>>>8}w=(d[1359664+H|0]|0)+G<<1;C=63-w+B|0;B=r>>>0>C>>>0?C:r;c[g>>2]=B;E=(z>>>((w-31|0)>>>0))-1|0;F=B}B=n+12|0;c[B>>2]=E+1;if((E|0)>0){w=s+(F>>>3)|0;z=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(F&7);if(z>>>0>134217727>>>0){w=z>>>23;C=(d[1382088+w|0]|0)+F|0;c[g>>2]=r>>>0>C>>>0?C:r;I=d[1276064+w|0]|0}else{w=z>>>0>65535>>>0;C=w?z>>>16:z;D=w?16:0;if((C&65280|0)==0){J=D;K=C}else{J=D|8;K=C>>>8}C=(d[1359664+K|0]|0)+J<<1;D=63-C+F|0;c[g>>2]=r>>>0>D>>>0?D:r;I=(z>>>((C-31|0)>>>0))-1|0}c[n+16>>2]=I;KIb(c[b>>2]|0,16,2420600,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;L=c[g>>2]|0;M=c[j>>2]|0;N=c[l>>2]|0}else{L=F;M=r;N=s}C=N+(L>>>3)|0;z=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(L&7);if(z>>>0>134217727>>>0){C=z>>>23;D=(d[1382088+C|0]|0)+L|0;w=M>>>0>D>>>0?D:M;c[g>>2]=w;O=d[1276064+C|0]|0;P=w}else{w=z>>>0>65535>>>0;C=w?z>>>16:z;D=w?16:0;if((C&65280|0)==0){Q=D;R=C}else{Q=D|8;R=C>>>8}C=(d[1359664+R|0]|0)+Q<<1;D=63-C+L|0;w=M>>>0>D>>>0?D:M;c[g>>2]=w;O=(z>>>((C-31|0)>>>0))-1|0;P=w}w=n+20|0;c[w>>2]=O+1;C=N+(P>>>3)|0;z=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(P&7);if(z>>>0>134217727>>>0){C=z>>>23;D=(d[1382088+C|0]|0)+P|0;S=M>>>0>D>>>0?D:M;c[g>>2]=S;T=d[1276064+C|0]|0;U=S}else{S=z>>>0>65535>>>0;C=S?z>>>16:z;D=S?16:0;if((C&65280|0)==0){V=D;W=C}else{V=D|8;W=C>>>8}C=(d[1359664+W|0]|0)+V<<1;D=63-C+P|0;S=M>>>0>D>>>0?D:M;c[g>>2]=S;T=(z>>>((C-31|0)>>>0))-1|0;U=S}S=n+24|0;c[S>>2]=T+1;if(O>>>0>31>>>0|T>>>0>31>>>0){KIb(c[b>>2]|0,16,2411280,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;break}C=d[N+(U>>>3)|0]<<(U&7)>>>7;z=((U|0)<(M|0))+U|0;c[g>>2]=z;D=n+28|0;c[D>>2]=C&1;C=N+(z>>>3)|0;X=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(z&7)>>>30;C=z+2|0;z=M>>>0>C>>>0?C:M;c[g>>2]=z;c[n+32>>2]=X;X=N+(z>>>3)|0;C=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(z&7);if(C>>>0>134217727>>>0){X=C>>>23;Y=(d[1382088+X|0]|0)+z|0;Z=M>>>0>Y>>>0?Y:M;c[g>>2]=Z;_=a[1306768+X|0]|0;$=Z}else{Z=C>>>0>65535>>>0;X=Z?C>>>16:C;C=Z?16:0;if((X&65280|0)==0){aa=C;ba=X}else{aa=C|8;ba=X>>>8}X=(d[1359664+ba|0]|0)+aa|0;C=31-X+z|0;z=M>>>0>C>>>0?C:M;C=N+(z>>>3)|0;Z=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(z&7)>>>(X>>>0);C=z+(32-X)|0;X=M>>>0>C>>>0?C:M;c[g>>2]=X;C=Z>>>1;_=(Z&1|0)==0?C:-C|0;$=X}X=y-22|0;y=n+36|0;c[y>>2]=X+_;C=N+($>>>3)|0;Z=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<($&7);if(Z>>>0>134217727>>>0){C=Z>>>23;z=(d[1382088+C|0]|0)+$|0;Y=M>>>0>z>>>0?z:M;c[g>>2]=Y;ca=a[1306768+C|0]|0;da=Y}else{Y=Z>>>0>65535>>>0;C=Y?Z>>>16:Z;Z=Y?16:0;if((C&65280|0)==0){ea=Z;fa=C}else{ea=Z|8;fa=C>>>8}C=(d[1359664+fa|0]|0)+ea|0;Z=31-C+$|0;Y=M>>>0>Z>>>0?Z:M;Z=N+(Y>>>3)|0;z=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Y&7)>>>(C>>>0);Z=Y+(32-C)|0;C=M>>>0>Z>>>0?Z:M;c[g>>2]=C;Z=z>>>1;ca=(z&1|0)==0?Z:-Z|0;da=C}C=n+40|0;c[C>>2]=X+ca;X=N+(da>>>3)|0;Z=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(da&7);if(Z>>>0>134217727>>>0){X=Z>>>23;z=(d[1382088+X|0]|0)+da|0;Y=M>>>0>z>>>0?z:M;c[g>>2]=Y;ga=a[1306768+X|0]|0;ha=Y}else{Y=Z>>>0>65535>>>0;X=Y?Z>>>16:Z;Z=Y?16:0;if((X&65280|0)==0){ia=Z;ja=X}else{ia=Z|8;ja=X>>>8}X=(d[1359664+ja|0]|0)+ia|0;Z=31-X+da|0;Y=M>>>0>Z>>>0?Z:M;Z=N+(Y>>>3)|0;z=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(Y&7)>>>(X>>>0);Z=Y+(32-X)|0;X=M>>>0>Z>>>0?Z:M;c[g>>2]=X;Z=z>>>1;ga=(z&1|0)==0?Z:-Z|0;ha=X}X=n+44|0;c[X>>2]=ga;Z=d[N+(ha>>>3)|0]<<(ha&7)>>>7;z=((ha|0)<(M|0))+ha|0;c[g>>2]=z;Y=n+52|0;c[Y>>2]=Z&1;Z=d[N+(z>>>3)|0]<<(z&7)>>>7;ka=((z|0)<(M|0))+z|0;c[g>>2]=ka;z=n+56|0;c[z>>2]=Z&1;Z=d[N+(ka>>>3)|0]<<(ka&7)>>>7;la=((ka|0)<(M|0))+ka|0;c[g>>2]=la;ka=n+60|0;c[ka>>2]=Z&1;Z=n+64|0;c[Z>>2]=0;c[b+428628>>2]=-1;ma=n+68|0;na=b+427476+(c[m>>2]<<2)|0;oa=c[na>>2]|0;nrc(ma|0,oa+672|0,96)|0;pa=n+164|0;nrc(pa|0,oa+768|0,384)|0;a:do{if((e-la|0)>0){qa=c[oa+4>>2]|0;do{if((qa|0)==88|(qa|0)==77|(qa|0)==66){if((c[oa+1196>>2]&7|0)==0){break}KIb(c[b>>2]|0,40,2339720,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ra=c[X>>2]|0;v=64;break a}}while(0);qa=d[N+(la>>>3)|0]<<(la&7)>>>7;c[g>>2]=((la|0)<(M|0))+la;c[Z>>2]=qa&1;yia(b,c[na>>2]|0,k,0,ma,pa);qa=c[g>>2]|0;sa=c[j>>2]|0;ta=c[l>>2]|0;ua=ta+(qa>>>3)|0;va=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(qa&7);if(va>>>0>134217727>>>0){ua=va>>>23;wa=(d[1382088+ua|0]|0)+qa|0;c[g>>2]=sa>>>0>wa>>>0?wa:sa;xa=a[1306768+ua|0]|0}else{ua=va>>>0>65535>>>0;wa=ua?va>>>16:va;va=ua?16:0;if((wa&65280|0)==0){ya=va;za=wa}else{ya=va|8;za=wa>>>8}wa=(d[1359664+za|0]|0)+ya|0;va=31-wa+qa|0;qa=sa>>>0>va>>>0?va:sa;va=ta+(qa>>>3)|0;ta=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(qa&7)>>>(wa>>>0);va=qa+(32-wa)|0;c[g>>2]=sa>>>0>va>>>0?va:sa;sa=ta>>>1;xa=(ta&1|0)==0?sa:-sa|0}c[n+48>>2]=xa;Aa=c[X>>2]|0;Ba=xa}else{ra=ga;v=64}}while(0);if((v|0)==64){c[n+48>>2]=ra;Aa=ra;Ba=ra}pa=c[x>>2]|0;ma=pa-8|0;na=ma*6|0;la=na+51|0;oa=na+52|0;if((oa|0)>0){na=0;do{sa=na+Aa|0;if((sa|0)<0){Ca=0}else{Ca=(sa|0)>(la|0)?la:sa}a[k+548+na|0]=a[1376160+(ma*88|0)+Ca|0]|0;na=na+1|0;}while((na|0)<(oa|0));oa=n+48|0;Da=c[oa>>2]|0;Ea=c[x>>2]|0;Fa=oa}else{Da=Ba;Ea=pa;Fa=n+48|0}oa=Ea-8|0;na=oa*6|0;ma=na+51|0;la=na+52|0;if((la|0)>0){na=0;do{sa=na+Da|0;if((sa|0)<0){Ga=0}else{Ga=(sa|0)>(ma|0)?ma:sa}a[k+636+na|0]=a[1376160+(oa*88|0)+Ga|0]|0;na=na+1|0;}while((na|0)<(la|0))}la=c[X>>2]|0;na=c[Fa>>2]|0;if((la|0)!=(na|0)){c[n+724>>2]=1}oa=c[b>>2]|0;if((c[oa+688>>2]&1|0)!=0){ma=c[m>>2]|0;pa=(c[A>>2]|0)!=0?2396648:2389704;x=c[B>>2]|0;sa=c[w>>2]|0;ta=c[S>>2]|0;va=(c[D>>2]|0)!=0?2382760:10230544;wa=c[y>>2]|0;qa=c[C>>2]|0;ua=(c[Y>>2]|0)!=0?2376104:10230544;Ha=(c[z>>2]|0)!=0?2369424:10230544;Ia=(c[ka>>2]|0)!=0?2354688:10230544;Ja=(c[Z>>2]|0)!=0?2345808:10230544;KIb(oa,48,2403608,(t=i,i=i+120|0,c[t>>2]=p,c[t+8>>2]=ma,c[t+16>>2]=pa,c[t+24>>2]=x,c[t+32>>2]=sa,c[t+40>>2]=ta,c[t+48>>2]=va,c[t+56>>2]=wa,c[t+64>>2]=qa,c[t+72>>2]=la,c[t+80>>2]=na,c[t+88>>2]=ua,c[t+96>>2]=Ha,c[t+104>>2]=Ia,c[t+112>>2]=Ja,t)|0);i=t}Ja=b+427604+(p<<2)|0;kJb(c[Ja>>2]|0);c[Ja>>2]=k;u=0;i=f;return u|0}}while(0);if((v|0)==10){KIb(c[b>>2]|0,16,2542440,(t=i,i=i+8|0,c[t>>2]=o,t)|0);i=t}kJb(n);u=-1;i=f;return u|0}function Aia(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=a+1096|0;g=c[f>>2]|0;h=a+1104|0;j=c[h>>2]|0;k=c[a+1088>>2]|0;l=k+(g>>>3)|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(g&7)>>>23;l=(d[1382088+m|0]|0)+g|0;g=j>>>0>l>>>0?l:j;c[f>>2]=g;l=(d[1276064+m|0]|0)+1|0;if(l>>>0>32>>>0){KIb(c[a>>2]|0,16,2308480,(a=i,i=i+8|0,c[a>>2]=l,a)|0);i=a;n=-1094995529;i=e;return n|0}a=g+4|0;g=(j>>>0>a>>>0?a:j)+4|0;a=j>>>0>g>>>0?g:j;c[f>>2]=a;g=0;m=a;do{a=k+(m>>>3)|0;o=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(m&7);a=m+16|0;p=j>>>0>a>>>0?a:j;a=k+(p>>>3)|0;q=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(p&7)>>>16|o&-65536;p=q>>>0>65535>>>0;a=p?o>>>16:q;q=p?16:0;if((a&65280|0)==0){r=q;s=a}else{r=q|8;s=a>>>8}a=31-r-(d[1359664+s|0]|0)|0;q=-m|0;p=j-m|0;if((a|0)<(q|0)){t=q}else{t=(p|0)<(a|0)?p:a}p=t+m|0;c[f>>2]=p;q=a+1|0;do{if((q|0)==0){u=p}else{if((q|0)<26){o=p+q|0;v=j>>>0>o>>>0?o:j;c[f>>2]=v;u=v;break}else{v=p+16|0;o=a-15+(j>>>0>v>>>0?v:j)|0;v=j>>>0>o>>>0?o:j;c[f>>2]=v;u=v;break}}}while(0);a=k+(u>>>3)|0;p=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(u&7);a=u+16|0;q=j>>>0>a>>>0?a:j;a=k+(q>>>3)|0;v=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(q&7)>>>16|p&-65536;q=v>>>0>65535>>>0;a=q?p>>>16:v;v=q?16:0;if((a&65280|0)==0){w=v;x=a}else{w=v|8;x=a>>>8}a=31-w-(d[1359664+x|0]|0)|0;v=-u|0;q=j-u|0;if((a|0)<(v|0)){y=v}else{y=(q|0)<(a|0)?q:a}q=y+u|0;c[f>>2]=q;v=a+1|0;do{if((v|0)==0){z=q}else{if((v|0)<26){p=q+v|0;o=j>>>0>p>>>0?p:j;c[f>>2]=o;z=o;break}else{o=q+16|0;p=a-15+(j>>>0>o>>>0?o:j)|0;o=j>>>0>p>>>0?p:j;c[f>>2]=o;z=o;break}}}while(0);m=((z|0)<(j|0))+z|0;c[f>>2]=m;g=g+1|0;}while((g|0)<(l|0));g=k+(m>>>3)|0;z=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(m&7)>>>27;g=m+5|0;c[f>>2]=j>>>0>g>>>0?g:j;c[b+1172>>2]=z+1;z=c[f>>2]|0;j=c[h>>2]|0;g=k+(z>>>3)|0;m=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(z&7)>>>27;g=z+5|0;c[f>>2]=j>>>0>g>>>0?g:j;c[b+1176>>2]=m+1;m=c[f>>2]|0;j=c[h>>2]|0;g=k+(m>>>3)|0;z=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(m&7)>>>27;g=m+5|0;c[f>>2]=j>>>0>g>>>0?g:j;c[b+1180>>2]=z+1;z=c[f>>2]|0;j=c[h>>2]|0;h=k+(z>>>3)|0;k=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(z&7)>>>27;h=z+5|0;c[f>>2]=j>>>0>h>>>0?h:j;c[b+1164>>2]=k;c[b+1168>>2]=l;n=0;i=e;return n|0}function Bia(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;i=i+2360|0;d=b|0;e=b+128|0;f=b+136|0;if((c[a+177080>>2]|0)!=3){g=a+177100|0;h=Cia(a+428696|0,32,a+571032|0,c[a+572240>>2]|0,0,c[g>>2]|0)|0;j=(Cia(a+428696+(h*2224|0)|0,32-h|0,a+571160|0,16,1,c[g>>2]|0)|0)+h|0;if((j|0)>=33){KIb(0,0,2541536,(k=i,i=i+24|0,c[k>>2]=2605328,c[k+8>>2]=2452704,c[k+16>>2]=167,k)|0);i=k;Hd();return 0}h=c[a+199420>>2]|0;if(!(j>>>0<h>>>0)){i=b;return 0}mrc(a+428696+(j*2224|0)|0,0,(h-j|0)*2224|0|0)|0;i=b;return 0}j=a+177100|0;h=c[j>>2]|0;if((h|0)==3){l=(c[a+2524>>2]|0)+1612|0}else{l=(c[a+2524>>2]|0)+1604+(((h|0)==2)<<2)|0}h=c[l>>2]|0;l=d|0;g=a+572240|0;m=a+571160|0;n=0;while(1){o=c[g>>2]|0;p=n^1;q=(n|0)!=1?-2147483648:2147483647;a:do{if((o|0)>0){r=h;s=0;while(1){t=d+(s<<2)|0;u=0;v=q;while(1){w=c[a+571032+(u<<2)>>2]|0;x=c[w+1612>>2]|0;do{if(((x|0)>(r|0)|0)==(p|0)){y=v}else{if(((x|0)<(v|0)|0)==(p|0)){y=v;break}c[t>>2]=w;y=x}}while(0);x=u+1|0;if((x|0)<(o|0)){u=x;v=y}else{break}}if((y|0)==(q|0)){break}r=(c[(c[t>>2]|0)+1612>>2]|0)-p|0;s=s+1|0}r=(n|0)!=0?-2147483648:2147483647;v=h;u=0;while(1){x=d+(u+s<<2)|0;w=0;z=r;while(1){A=c[a+571032+(w<<2)>>2]|0;B=c[A+1612>>2]|0;do{if(((B|0)>(v|0)|0)==(n|0)){C=z}else{if(((B|0)<(z|0)|0)==(n|0)){C=z;break}c[x>>2]=A;C=B}}while(0);B=w+1|0;if((B|0)<(o|0)){w=B;z=C}else{break}}if((C|0)==(r|0)){D=u;E=s;break a}v=(c[(c[x>>2]|0)+1612>>2]|0)-n|0;u=u+1|0}}else{D=0;E=0}}while(0);o=D+E|0;if((o|0)>=33){F=23;break}p=Cia(a+428696+(n*71168|0)|0,32,l,o,0,c[j>>2]|0)|0;o=(Cia(a+428696+(n*71168|0)+(p*2224|0)|0,32-p|0,m,16,1,c[j>>2]|0)|0)+p|0;if((o|0)>=33){F=25;break}p=c[a+199420+(n<<2)>>2]|0;if(o>>>0<p>>>0){mrc(a+428696+(n*71168|0)+(o*2224|0)|0,0,(p-o|0)*2224|0|0)|0}c[e+(n<<2)>>2]=o;o=n+1|0;if((o|0)<2){n=o}else{F=29;break}}if((F|0)==23){KIb(0,0,2541536,(k=i,i=i+24|0,c[k>>2]=2605328,c[k+8>>2]=2452704,c[k+16>>2]=136,k)|0);i=k;Hd();return 0}else if((F|0)==25){KIb(0,0,2541536,(k=i,i=i+24|0,c[k>>2]=2605328,c[k+8>>2]=2452704,c[k+16>>2]=143,k)|0);i=k;Hd();return 0}else if((F|0)==29){F=c[e>>2]|0;k=c[e+4>>2]|0;if((F|0)==(k|0)&(k|0)>1){G=0}else{i=b;return 0}while(1){if((G|0)>=(F|0)){break}if((c[c[a+428696+(G*2224|0)+360>>2]>>2]|0)==(c[c[a+499864+(G*2224|0)+360>>2]>>2]|0)){G=G+1|0}else{break}}if((G|0)!=(F|0)){i=b;return 0}F=a+499864|0;G=f;k=F;nrc(G|0,k|0,2224)|0;c[f+64>>2]=f;c[f+1496>>2]=f;f=a+502088|0;e=f;nrc(k|0,e|0,2224)|0;c[a+499928>>2]=F;c[a+501360>>2]=F;nrc(e|0,G|0,2224)|0;c[a+502152>>2]=f;c[a+503584>>2]=f;i=b;return 0}return 0}function Cia(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;if((e|0)<=0){j=0;i=h;return j|0}k=(f|0)==0;f=(g|0)==3;l=(g|0)==2;m=l&1;n=g^3;o=(g|0)==0;p=(g|0)==1;q=p&1;r=0;s=0;t=0;a:while(1){b:do{if((s|0)<(e|0)){u=s;while(1){v=c[d+(u<<2)>>2]|0;if((v|0)!=0){if((c[v+2192>>2]&g|0)!=0){w=u;x=1;break b}}v=u+1|0;if((v|0)<(e|0)){u=v}else{w=v;x=0;break}}}else{w=s;x=0}}while(0);c:do{if((r|0)<(e|0)){u=r;while(1){v=c[d+(u<<2)>>2]|0;if((v|0)!=0){if((c[v+2192>>2]&n|0)!=0){y=u;z=1;break c}}v=u+1|0;if((v|0)<(e|0)){u=v}else{y=v;z=0;break}}}else{y=r;z=0}}while(0);do{if(x){if((t|0)>=(b|0)){A=13;break a}u=c[d+(w<<2)>>2]|0;if(k){B=c[u+1616>>2]|0}else{B=w}c[u+1624>>2]=B;v=t+1|0;C=a+(t*2224|0)|0;D=w+1|0;if((c[u+2192>>2]&g|0)==0){E=v;F=D;break}nrc(C|0,u|0,2224)|0;u=C|0;c[a+(t*2224|0)+64>>2]=u;c[a+(t*2224|0)+1496>>2]=C;if(f){E=v;F=D;break}C=a+(t*2224|0)+2192|0;G=a+(t*2224|0)+32|0;H=c[G>>2]|0;if(l){c[u>>2]=(c[u>>2]|0)+H;c[G>>2]=H<<1;u=a+(t*2224|0)+36|0;I=c[u>>2]|0;J=a+(t*2224|0)+4|0;c[J>>2]=(c[J>>2]|0)+I;c[u>>2]=I<<1;I=a+(t*2224|0)+40|0;u=c[I>>2]|0;J=a+(t*2224|0)+8|0;c[J>>2]=(c[J>>2]|0)+u;c[I>>2]=u<<1;u=a+(t*2224|0)+44|0;I=c[u>>2]|0;J=a+(t*2224|0)+12|0;c[J>>2]=(c[J>>2]|0)+I;c[C>>2]=2;c[u>>2]=I<<1}else{c[G>>2]=H<<1;H=a+(t*2224|0)+36|0;c[H>>2]=c[H>>2]<<1;H=a+(t*2224|0)+40|0;c[H>>2]=c[H>>2]<<1;c[C>>2]=g;C=a+(t*2224|0)+44|0;c[C>>2]=c[C>>2]<<1}c[a+(t*2224|0)+1612>>2]=c[a+(t*2224|0)+1604+(m<<2)>>2];C=a+(t*2224|0)+1624|0;c[C>>2]=c[C>>2]<<1|1;E=v;F=D}else{E=t;F=w}}while(0);do{if(z){if((E|0)>=(b|0)){A=25;break a}D=c[d+(y<<2)>>2]|0;if(k){K=c[D+1616>>2]|0}else{K=y}c[D+1624>>2]=K;v=E+1|0;C=a+(E*2224|0)|0;H=y+1|0;if((c[D+2192>>2]&n|0)==0){L=v;M=H;break}nrc(C|0,D|0,2224)|0;D=C|0;c[a+(E*2224|0)+64>>2]=D;c[a+(E*2224|0)+1496>>2]=C;if(o){L=v;M=H;break}C=a+(E*2224|0)+2192|0;G=a+(E*2224|0)+32|0;I=c[G>>2]|0;if(p){c[D>>2]=(c[D>>2]|0)+I;c[G>>2]=I<<1;D=a+(E*2224|0)+36|0;u=c[D>>2]|0;J=a+(E*2224|0)+4|0;c[J>>2]=(c[J>>2]|0)+u;c[D>>2]=u<<1;u=a+(E*2224|0)+40|0;D=c[u>>2]|0;J=a+(E*2224|0)+8|0;c[J>>2]=(c[J>>2]|0)+D;c[u>>2]=D<<1;D=a+(E*2224|0)+44|0;u=c[D>>2]|0;J=a+(E*2224|0)+12|0;c[J>>2]=(c[J>>2]|0)+u;c[C>>2]=2;c[D>>2]=u<<1}else{c[G>>2]=I<<1;I=a+(E*2224|0)+36|0;c[I>>2]=c[I>>2]<<1;I=a+(E*2224|0)+40|0;c[I>>2]=c[I>>2]<<1;c[C>>2]=n;C=a+(E*2224|0)+44|0;c[C>>2]=c[C>>2]<<1}c[a+(E*2224|0)+1612>>2]=c[a+(E*2224|0)+1604+(q<<2)>>2];C=a+(E*2224|0)+1624|0;c[C>>2]=c[C>>2]<<1;L=v;M=H}else{L=E;M=y}}while(0);if((F|0)<(e|0)|(M|0)<(e|0)){r=M;s=F;t=L}else{j=L;A=34;break}}if((A|0)==13){KIb(0,0,2541536,(N=i,i=i+24|0,c[N>>2]=2376088,c[N+8>>2]=2452704,c[N+16>>2]=83,N)|0);i=N;Hd();return 0}else if((A|0)==25){KIb(0,0,2541536,(N=i,i=i+24|0,c[N>>2]=2376088,c[N+8>>2]=2452704,c[N+16>>2]=88,N)|0);i=N;Hd();return 0}else if((A|0)==34){i=h;return j|0}return 0}function Dia(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;e=i;f=b|0;g=c[f>>2]|0;do{if((c[g+688>>2]&2048|0)!=0){KIb(g,48,2382736,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=b+572240|0;if((c[j>>2]|0)==0){break}else{k=0}do{l=c[b+571032+(k<<2)>>2]|0;m=c[l+1616>>2]|0;n=c[l+1612>>2]|0;o=c[l>>2]|0;KIb(c[f>>2]|0,48,2389680,(h=i,i=i+32|0,c[h>>2]=k,c[h+8>>2]=m,c[h+16>>2]=n,c[h+24>>2]=o,h)|0);i=h;k=k+1|0;}while(k>>>0<(c[j>>2]|0)>>>0)}}while(0);k=c[f>>2]|0;if((c[k+688>>2]&2048|0)!=0){KIb(k,48,2396624,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;k=0;do{g=c[b+571160+(k<<2)>>2]|0;if((g|0)!=0){j=c[g+1616>>2]|0;o=c[g+1612>>2]|0;n=c[g>>2]|0;KIb(c[f>>2]|0,48,2389680,(h=i,i=i+32|0,c[h>>2]=k,c[h+8>>2]=j,c[h+16>>2]=o,c[h+24>>2]=n,h)|0);i=h}k=k+1|0;}while(k>>>0<16>>>0)}k=b+199428|0;if((c[k>>2]|0)==0){p=0;i=e;return p|0}n=b+1096|0;o=b+1088|0;j=b+1104|0;g=b+428680|0;m=b+428684|0;l=b+177100|0;q=b+572240|0;r=0;a:while(1){s=b+199420+(r<<2)|0;if((c[s>>2]|0)!=0){t=0;do{u=b+199440+(r*106752|0)+(t*2224|0)|0;nrc(u|0,b+428696+(r*71168|0)+(t*2224|0)|0,2224)|0;c[b+199440+(r*106752|0)+(t*2224|0)+64>>2]=u;c[b+199440+(r*106752|0)+(t*2224|0)+1496>>2]=u;t=t+1|0;}while(t>>>0<(c[s>>2]|0)>>>0)}t=c[n>>2]|0;u=c[o>>2]|0;v=d[u+(t>>>3)|0]|0;w=c[j>>2]|0;x=((t|0)<(w|0))+t|0;c[n>>2]=x;b:do{if((v&128>>>((t&7)>>>0)|0)!=0){y=0;z=c[g>>2]|0;A=x;B=w;C=u;while(1){D=C+(A>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(A&7)>>>23;D=(d[1382088+E|0]|0)+A|0;F=B>>>0>D>>>0?D:B;c[n>>2]=F;D=a[1276064+E|0]|0;E=D&255;if(D<<24>>24==3){break b}if(!(y>>>0<(c[s>>2]|0)>>>0)){G=19;break a}do{if((E|0)==2){H=C+(F>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7);if(I>>>0>134217727>>>0){H=I>>>23;J=(d[1382088+H|0]|0)+F|0;c[n>>2]=B>>>0>J>>>0?J:B;K=d[1276064+H|0]|0}else{H=I>>>0>65535>>>0;J=H?I>>>16:I;L=H?16:0;if((J&65280|0)==0){M=L;N=J}else{M=L|8;N=J>>>8}J=(d[1359664+N|0]|0)+M<<1;L=63-J+F|0;c[n>>2]=B>>>0>L>>>0?L:B;K=(I>>>((J-31|0)>>>0))-1|0}J=c[l>>2]|0;if((J|0)==3){O=K;P=3}else{O=K>>1;P=(K&1|0)==0?J^3:J}if((O|0)>31){G=43;break a}J=c[b+571160+(O<<2)>>2]|0;if((J|0)==0){Q=z;G=51;break}if((c[J+2192>>2]&P|0)==0){Q=z;G=51;break}c[J+1624>>2]=K;R=P;S=z;T=J;G=47}else if((E|0)==0|(E|0)==1){J=C+(F>>>3)|0;I=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(F&7);if(I>>>0>134217727>>>0){J=I>>>23;L=(d[1382088+J|0]|0)+F|0;c[n>>2]=B>>>0>L>>>0?L:B;U=d[1276064+J|0]|0}else{J=I>>>0>65535>>>0;L=J?I>>>16:I;H=J?16:0;if((L&65280|0)==0){V=H;W=L}else{V=H|8;W=L>>>8}L=(d[1359664+W|0]|0)+V<<1;H=63-L+F|0;c[n>>2]=B>>>0>H>>>0?H:B;U=(I>>>((L-31|0)>>>0))-1|0}L=U+1|0;I=c[m>>2]|0;if(L>>>0>I>>>0){G=27;break a}H=(D<<24>>24==0?~U:L)+z&I-1;I=c[l>>2]|0;if((I|0)==3){X=H;Y=3}else{X=H>>1;Y=(H&1|0)==0?I^3:I}I=c[q>>2]|0;L=I-1|0;c:do{if((I|0)>0){J=L;while(1){Z=c[b+571032+(J<<2)>>2]|0;if((c[Z+1616>>2]|0)==(X|0)){if((c[Z+2192>>2]&Y|0)!=0){break}}_=J-1|0;if((J|0)>0){J=_}else{$=Z;aa=_;break c}}c[Z+1624>>2]=H;$=Z;aa=J}else{$=0;aa=L}}while(0);if((aa|0)<0){Q=H;G=51}else{R=Y;S=H;T=$;G=47}}else{G=49;break a}}while(0);do{if((G|0)==47){G=0;D=T+1624|0;F=y+1|0;E=c[s>>2]|0;do{if(F>>>0<E>>>0){L=c[T+1628>>2]|0;I=y;_=F;while(1){if((L|0)==(c[b+199440+(r*106752|0)+(I*2224|0)+1628>>2]|0)){if((c[D>>2]|0)==(c[b+199440+(r*106752|0)+(I*2224|0)+1624>>2]|0)){ba=I;break}}ca=_+1|0;if(ca>>>0<E>>>0){I=_;_=ca}else{ba=_;break}}if((ba|0)>(y|0)){da=ba}else{break}while(1){_=b+199440+(r*106752|0)+(da*2224|0)|0;I=da-1|0;nrc(_|0,b+199440+(r*106752|0)+(I*2224|0)|0,2224)|0;c[b+199440+(r*106752|0)+(da*2224|0)+64>>2]=_;c[b+199440+(r*106752|0)+(da*2224|0)+1496>>2]=_;if((I|0)>(y|0)){da=I}else{break}}}}while(0);E=b+199440+(r*106752|0)+(y*2224|0)|0;nrc(E|0,T|0,2224)|0;D=E|0;c[b+199440+(r*106752|0)+(y*2224|0)+64>>2]=D;c[b+199440+(r*106752|0)+(y*2224|0)+1496>>2]=E;if((c[l>>2]|0)==3){ea=S;fa=F;break}E=(R|0)==2;H=b+199440+(r*106752|0)+(y*2224|0)+2192|0;I=b+199440+(r*106752|0)+(y*2224|0)+32|0;_=c[I>>2]|0;if(E){c[D>>2]=(c[D>>2]|0)+_;c[I>>2]=_<<1;D=b+199440+(r*106752|0)+(y*2224|0)+36|0;L=c[D>>2]|0;J=b+199440+(r*106752|0)+(y*2224|0)+4|0;c[J>>2]=(c[J>>2]|0)+L;c[D>>2]=L<<1;L=b+199440+(r*106752|0)+(y*2224|0)+40|0;D=c[L>>2]|0;J=b+199440+(r*106752|0)+(y*2224|0)+8|0;c[J>>2]=(c[J>>2]|0)+D;c[L>>2]=D<<1;D=b+199440+(r*106752|0)+(y*2224|0)+44|0;L=c[D>>2]|0;J=b+199440+(r*106752|0)+(y*2224|0)+12|0;c[J>>2]=(c[J>>2]|0)+L;c[H>>2]=2;c[D>>2]=L<<1}else{c[I>>2]=_<<1;_=b+199440+(r*106752|0)+(y*2224|0)+36|0;c[_>>2]=c[_>>2]<<1;_=b+199440+(r*106752|0)+(y*2224|0)+40|0;c[_>>2]=c[_>>2]<<1;c[H>>2]=R;H=b+199440+(r*106752|0)+(y*2224|0)+44|0;c[H>>2]=c[H>>2]<<1}c[b+199440+(r*106752|0)+(y*2224|0)+1612>>2]=c[b+199440+(r*106752|0)+(y*2224|0)+1604+((E&1)<<2)>>2];ea=S;fa=F}else if((G|0)==51){G=0;KIb(c[f>>2]|0,16,2173344,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;mrc(b+199440+(r*106752|0)+(y*2224|0)|0,0,2224)|0;ea=Q;fa=y+1|0}}while(0);y=fa;z=ea;A=c[n>>2]|0;B=c[j>>2]|0;C=c[o>>2]|0}}}while(0);s=r+1|0;ga=c[k>>2]|0;if(s>>>0<ga>>>0){r=s}else{G=12;break}}if((G|0)==12){if((ga|0)==0){p=0;i=e;return p|0}ga=b+177100|0;r=0;d:while(1){o=b+199420+(r<<2)|0;j=b+428696+(r*71168|0)+1612|0;n=b+428696+(r*71168|0)+360|0;ea=b+428696+(r*71168|0)+2192|0;fa=b+428696+(r*71168|0)|0;Q=0;while(1){if(!(Q>>>0<(c[o>>2]|0)>>>0)){break}S=b+199440+(r*106752|0)+(Q*2224|0)|0;R=S|0;l=b+199440+(r*106752|0)+(Q*2224|0)+360|0;T=c[l>>2]|0;do{if((T|0)==0){G=69}else{if((c[ga>>2]|0)!=3){ha=T;break}if((c[b+199440+(r*106752|0)+(Q*2224|0)+2192>>2]&3|0)==3){ha=T}else{G=69}}}while(0);if((G|0)==69){G=0;KIb(c[f>>2]|0,16,2145896,(h=i,i=i+8|0,c[h>>2]=c[j>>2],h)|0);i=h;c[b+571360>>2]=-2147483648;c[b+571364>>2]=-2147483648;c[b+571368>>2]=-2147483648;c[b+571372>>2]=-2147483648;c[b+571376>>2]=-2147483648;c[b+571380>>2]=-2147483648;c[b+571384>>2]=-2147483648;c[b+571388>>2]=-2147483648;c[b+571392>>2]=-2147483648;c[b+571396>>2]=-2147483648;c[b+571400>>2]=-2147483648;c[b+571404>>2]=-2147483648;c[b+571408>>2]=-2147483648;c[b+571412>>2]=-2147483648;c[b+571416>>2]=-2147483648;c[b+571420>>2]=-2147483648;if((c[n>>2]|0)==0){p=-1;G=76;break d}if((c[ga>>2]|0)==3){if((c[ea>>2]&3|0)!=3){p=-1;G=76;break d}}nrc(S|0,fa|0,2224)|0;c[b+199440+(r*106752|0)+(Q*2224|0)+64>>2]=S;c[b+199440+(r*106752|0)+(Q*2224|0)+1496>>2]=R;ha=c[l>>2]|0}if((hGb(ha)|0)>0){Q=Q+1|0}else{G=74;break d}}Q=r+1|0;if(Q>>>0<(c[k>>2]|0)>>>0){r=Q}else{p=0;G=76;break}}if((G|0)==74){KIb(0,0,2541536,(h=i,i=i+24|0,c[h>>2]=2122072,c[h+8>>2]=2452704,c[h+16>>2]=340,h)|0);i=h;Hd();return 0}else if((G|0)==76){i=e;return p|0}}else if((G|0)==19){KIb(c[f>>2]|0,16,2363368,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-1;i=e;return p|0}else if((G|0)==27){KIb(c[f>>2]|0,16,2298248,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-1094995529;i=e;return p|0}else if((G|0)==43){KIb(c[f>>2]|0,16,2247536,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-1094995529;i=e;return p|0}else if((G|0)==49){KIb(c[f>>2]|0,16,2205536,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=-1094995529;i=e;return p|0}return 0}function Eia(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+199428|0;d=c[b>>2]|0;if((d|0)==0){return}else{e=0;f=d}while(1){d=a+199420+(e<<2)|0;if((c[d>>2]|0)==0){g=f}else{h=0;do{i=h<<1;j=i+16|0;k=a+199440+(e*106752|0)+(j*2224|0)|0;l=k;nrc(l|0,a+199440+(e*106752|0)+(h*2224|0)|0,2224)|0;c[a+199440+(e*106752|0)+(j*2224|0)+64>>2]=k;c[a+199440+(e*106752|0)+(j*2224|0)+1496>>2]=k;k=a+199440+(e*106752|0)+(j*2224|0)+32|0;c[k>>2]=c[k>>2]<<1;k=a+199440+(e*106752|0)+(j*2224|0)+36|0;c[k>>2]=c[k>>2]<<1;k=a+199440+(e*106752|0)+(j*2224|0)+40|0;c[k>>2]=c[k>>2]<<1;c[a+199440+(e*106752|0)+(j*2224|0)+2192>>2]=1;c[a+199440+(e*106752|0)+(j*2224|0)+1612>>2]=c[a+199440+(e*106752|0)+(j*2224|0)+1604>>2];k=i+17|0;i=a+199440+(e*106752|0)+(k*2224|0)|0;nrc(i|0,l|0,2224)|0;c[a+199440+(e*106752|0)+(k*2224|0)+64>>2]=i;c[a+199440+(e*106752|0)+(k*2224|0)+1496>>2]=i;i=a+199440+(e*106752|0)+(k*2224|0)|0;c[i>>2]=(c[i>>2]|0)+(c[a+199440+(e*106752|0)+(h*2224|0)+32>>2]|0);i=a+199440+(e*106752|0)+(k*2224|0)+4|0;c[i>>2]=(c[i>>2]|0)+(c[a+199440+(e*106752|0)+(h*2224|0)+36>>2]|0);i=a+199440+(e*106752|0)+(k*2224|0)+8|0;c[i>>2]=(c[i>>2]|0)+(c[a+199440+(e*106752|0)+(h*2224|0)+40>>2]|0);c[a+199440+(e*106752|0)+(k*2224|0)+2192>>2]=2;c[a+199440+(e*106752|0)+(k*2224|0)+1612>>2]=c[a+199440+(e*106752|0)+(k*2224|0)+1608>>2];i=c[a+177136+(h<<4)+(e<<3)>>2]|0;c[a+177136+(k<<4)+(e<<3)>>2]=i;c[a+177136+(j<<4)+(e<<3)>>2]=i;i=c[a+177136+(h<<4)+(e<<3)+4>>2]|0;c[a+177136+(k<<4)+(e<<3)+4>>2]=i;c[a+177136+(j<<4)+(e<<3)+4>>2]=i;i=c[a+177904+(h<<5)+(e<<4)>>2]|0;c[a+177904+(k<<5)+(e<<4)>>2]=i;c[a+177904+(j<<5)+(e<<4)>>2]=i;i=c[a+177904+(h<<5)+(e<<4)+4>>2]|0;c[a+177904+(k<<5)+(e<<4)+4>>2]=i;c[a+177904+(j<<5)+(e<<4)+4>>2]=i;i=c[a+177904+(h<<5)+(e<<4)+8>>2]|0;c[a+177904+(k<<5)+(e<<4)+8>>2]=i;c[a+177904+(j<<5)+(e<<4)+8>>2]=i;i=c[a+177904+(h<<5)+(e<<4)+12>>2]|0;c[a+177904+(k<<5)+(e<<4)+12>>2]=i;c[a+177904+(j<<5)+(e<<4)+12>>2]=i;h=h+1|0;}while(h>>>0<(c[d>>2]|0)>>>0);g=c[b>>2]|0}d=e+1|0;if(d>>>0<g>>>0){e=d;f=g}else{break}}return}function Fia(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=a+572236|0;d=0;do{e=a+571160+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){g=f+2192|0;c[g>>2]=0;h=0;while(1){i=c[a+571288+(h<<2)>>2]|0;if((i|0)==0){break}if((i|0)==(f|0)){j=7;break}else{h=h+1|0}}if((j|0)==7){j=0;c[g>>2]=4}c[f+1628>>2]=0;c[e>>2]=0;c[b>>2]=(c[b>>2]|0)-1}d=d+1|0;}while((d|0)<16);d=a+572240|0;if((c[d>>2]|0)>0){k=0}else{c[d>>2]=0;l=a+428696|0;m=l;mrc(m|0,0,142336)|0;n=a+199440|0;o=n;mrc(o|0,0,213504)|0;return}do{b=a+571032+(k<<2)|0;h=c[b>>2]|0;i=h+2192|0;c[i>>2]=0;p=0;while(1){q=c[a+571288+(p<<2)>>2]|0;if((q|0)==0){break}if((q|0)==(h|0)){j=13;break}else{p=p+1|0}}if((j|0)==13){j=0;c[i>>2]=4}c[b>>2]=0;k=k+1|0;}while((k|0)<(c[d>>2]|0));c[d>>2]=0;l=a+428696|0;m=l;mrc(m|0,0,142336)|0;n=a+199440|0;o=n;mrc(o|0,0,213504)|0;return}function Gia(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+792|0;e=d|0;f=(b|0)!=0;b=f?a+571436|0:e;g=c[a+572240>>2]|0;a:do{if((g|0)==0){h=0}else{if(((c[a+572236>>2]|0)+g|0)<(c[a+6172>>2]|0)){h=0;break}j=a+177100|0;do{if((c[j>>2]|0)!=3){if((c[a+177104>>2]|0)!=0){break}if((c[(c[a+2524>>2]|0)+2192>>2]|0)!=0){h=0;break a}}}while(0);c[b>>2]=1;k=c[(c[a+571032+(g-1<<2)>>2]|0)+1616>>2]|0;l=b+4|0;c[l>>2]=k;if((c[j>>2]|0)==3){h=1;break}m=k<<1;c[l>>2]=m;c[b+12>>2]=1;c[b+16>>2]=m|1;h=2}}while(0);b=a+572228|0;if(f){c[b>>2]=h;n=0;i=d;return n|0}f=c[b>>2]|0;do{if((h|0)==(f|0)){g=0;while(1){if((g|0)>=(h|0)){n=0;o=15;break}p=c[a+571436+(g*12|0)>>2]|0;q=c[e+(g*12|0)>>2]|0;if((p|0)==(q|0)){g=g+1|0}else{o=13;break}}if((o|0)==13){KIb(0,16,2403552,(r=i,i=i+24|0,c[r>>2]=p,c[r+8>>2]=q,c[r+16>>2]=g,r)|0);i=r;s=c[b>>2]|0;break}else if((o|0)==15){i=d;return n|0}}else{s=f}}while(0);KIb(c[a>>2]|0,16,2639800,(r=i,i=i+16|0,c[r>>2]=h,c[r+8>>2]=s,r)|0);i=r;n=-1094995529;i=d;return n|0}function Hia(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0;e=i;f=a|0;g=c[f>>2]|0;if((c[g+688>>2]&2048|0)!=0&(d|0)==0){KIb(g,48,2617056,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}do{if((d|0)>0){g=a+572240|0;j=a+572236|0;k=a+177100|0;l=a+571032|0;m=a+2524|0;n=l;o=a+571036|0;p=a+428656|0;q=a+572232|0;r=0;s=0;t=0;u=0;v=0;w=0;x=0;a:while(1){y=c[f>>2]|0;if((c[y+688>>2]&2048|0)!=0){z=c[a+571436+(x*12|0)+4>>2]|0;A=c[a+571436+(x*12|0)+8>>2]|0;KIb(y,48,2589872,(h=i,i=i+24|0,c[h>>2]=c[a+571436+(x*12|0)>>2],c[h+8>>2]=z,c[h+16>>2]=A,h)|0);i=h}A=b+(x*12|0)|0;z=c[A>>2]|0;b:do{if((z|0)==1|(z|0)==3){y=c[b+(x*12|0)+4>>2]|0;B=c[k>>2]|0;if((B|0)==3){C=y;D=3}else{C=y>>1;D=(y&1|0)==0?B^3:B}B=0;while(1){if((B|0)>=(c[g>>2]|0)){E=r;break}F=c[a+571032+(B<<2)>>2]|0;y=c[f>>2]|0;if((c[y+688>>2]&2048|0)==0){G=F+1616|0}else{H=F+1616|0;I=c[H>>2]|0;KIb(y,48,2411264,(h=i,i=i+24|0,c[h>>2]=B,c[h+8>>2]=I,c[h+16>>2]=F,h)|0);i=h;G=H}if((c[G>>2]|0)==(C|0)){J=17;break}B=B+1|0}do{if((J|0)==17){J=0;if((F|0)==0){E=B;break}K=C;L=F;M=D;N=B;O=c[A>>2]|0;J=23;break b}}while(0);do{if((c[A>>2]|0)==3){B=c[a+571160+(c[b+(x*12|0)+8>>2]<<2)>>2]|0;if((B|0)==0){break}if((c[B+1616>>2]|0)==(C|0)){P=C;Q=0;R=u;S=t;T=D;U=E;break b}}}while(0);KIb(c[f>>2]|0,(c[g>>2]|0)!=0?16:48,2568136,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;P=C;Q=0;R=-1094995529;S=t;T=D;U=E}else{K=w;L=v;M=s;N=r;O=z;J=23}}while(0);c:do{if((J|0)==23){J=0;switch(O|0){case 6:{do{if((c[l>>2]|0)==(c[m>>2]|0)){KIb(c[f>>2]|0,16,2516816,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;c[l>>2]=0;z=(c[g>>2]|0)-1|0;c[g>>2]=z;if((z|0)==0){break}orc(n|0,o|0,z<<2|0)|0}}while(0);z=b+(x*12|0)+8|0;A=c[a+571160+(c[z>>2]<<2)>>2]|0;B=c[m>>2]|0;if((A|0)==(B|0)){V=N;W=A}else{if((c[B+1628>>2]|0)==0){X=B;Y=N}else{A=0;H=B;do{B=a+571160+(A<<2)|0;if((c[B>>2]|0)==(H|0)){if((H|0)!=0){I=H+2192|0;c[I>>2]=0;y=0;while(1){Z=c[a+571288+(y<<2)>>2]|0;if((Z|0)==0){break}if((Z|0)==(H|0)){J=71;break}else{y=y+1|0}}if((J|0)==71){J=0;c[I>>2]=4}c[H+1628>>2]=0;c[B>>2]=0;c[j>>2]=(c[j>>2]|0)-1}KIb(c[f>>2]|0,16,2502816,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}A=A+1|0;H=c[m>>2]|0}while((A|0)<16);if((c[H+1628>>2]|0)==0){X=H;Y=16}else{J=76;break a}}A=c[z>>2]|0;y=a+571160+(A<<2)|0;Z=c[y>>2]|0;if((Z|0)==0){_=X;$=A}else{A=Z+2192|0;c[A>>2]=0;aa=0;while(1){ba=c[a+571288+(aa<<2)>>2]|0;if((ba|0)==0){break}if((ba|0)==(Z|0)){J=81;break}else{aa=aa+1|0}}if((J|0)==81){J=0;c[A>>2]=4}c[Z+1628>>2]=0;c[y>>2]=0;c[j>>2]=(c[j>>2]|0)-1;_=c[m>>2]|0;$=c[z>>2]|0}c[a+571160+($<<2)>>2]=_;c[_+1628>>2]=1;c[j>>2]=(c[j>>2]|0)+1;V=Y;W=c[m>>2]|0}aa=W+2192|0;c[aa>>2]=c[aa>>2]|c[k>>2];P=K;Q=L;R=u;S=1;T=M;U=V;break c;break};case 5:{aa=c[g>>2]|0;d:do{if((aa|0)==0){ca=0}else{H=aa;while(1){ba=c[(c[l>>2]|0)+1616>>2]|0;da=c[f>>2]|0;if((c[da+688>>2]&2048|0)==0){ea=0}else{KIb(da,48,2420568,(h=i,i=i+16|0,c[h>>2]=ba,c[h+8>>2]=H,h)|0);i=h;ea=0}while(1){da=c[g>>2]|0;if((ea|0)>=(da|0)){fa=da;break}ga=a+571032+(ea<<2)|0;ha=c[ga>>2]|0;da=c[f>>2]|0;if((c[da+688>>2]&2048|0)==0){ia=ha+1616|0}else{ja=ha+1616|0;ka=c[ja>>2]|0;KIb(da,48,2411264,(h=i,i=i+24|0,c[h>>2]=ea,c[h+8>>2]=ka,c[h+16>>2]=ha,h)|0);i=h;ia=ja}la=ea+1|0;if((c[ia>>2]|0)==(ba|0)){J=100;break}else{ea=la}}if((J|0)==100){J=0;if((ha|0)!=0){ba=ha+2192|0;c[ba>>2]=0;ja=0;while(1){ka=c[a+571288+(ja<<2)>>2]|0;if((ka|0)==0){break}if((ka|0)==(ha|0)){J=104;break}else{ja=ja+1|0}}if((J|0)==104){J=0;c[ba>>2]=4}c[ga>>2]=0;ja=(c[g>>2]|0)-1|0;c[g>>2]=ja;if((ja|0)==0){ca=0;break d}orc(ga|0,a+571032+(la<<2)|0,ja-ea<<2|0)|0}fa=c[g>>2]|0}if((fa|0)==0){ca=0;break}else{H=fa}}}}while(0);do{aa=a+571160+(ca<<2)|0;z=c[aa>>2]|0;if((z|0)!=0){y=z+2192|0;c[y>>2]=0;Z=0;while(1){A=c[a+571288+(Z<<2)>>2]|0;if((A|0)==0){break}if((A|0)==(z|0)){J=113;break}else{Z=Z+1|0}}if((J|0)==113){J=0;c[y>>2]=4}c[z+1628>>2]=0;c[aa>>2]=0;c[j>>2]=(c[j>>2]|0)-1}ca=ca+1|0;}while((ca|0)<16);Z=c[m>>2]|0;c[Z+1616>>2]=0;c[p>>2]=0;c[q>>2]=1;c[Z+1620>>2]=1;c[a+571360>>2]=-2147483648;c[a+571364>>2]=-2147483648;c[a+571368>>2]=-2147483648;c[a+571372>>2]=-2147483648;c[a+571376>>2]=-2147483648;c[a+571380>>2]=-2147483648;c[a+571384>>2]=-2147483648;c[a+571388>>2]=-2147483648;c[a+571392>>2]=-2147483648;c[a+571396>>2]=-2147483648;c[a+571400>>2]=-2147483648;c[a+571404>>2]=-2147483648;c[a+571408>>2]=-2147483648;c[a+571412>>2]=-2147483648;c[a+571416>>2]=-2147483648;c[a+571420>>2]=-2147483648;P=K;Q=L;R=u;S=t;T=M;U=16;break c;break};case 1:{Z=c[f>>2]|0;A=c[Z+688>>2]|0;if((A&2048|0)==0){ma=Z;na=A}else{A=c[g>>2]|0;KIb(Z,48,2550104,(h=i,i=i+16|0,c[h>>2]=c[a+571436+(x*12|0)+4>>2],c[h+8>>2]=A,h)|0);i=h;A=c[f>>2]|0;ma=A;na=c[A+688>>2]|0}A=M^3;if((na&2048|0)==0){oa=0}else{Z=c[g>>2]|0;KIb(ma,48,2420568,(h=i,i=i+16|0,c[h>>2]=K,c[h+8>>2]=Z,h)|0);i=h;oa=0}while(1){if((oa|0)>=(c[g>>2]|0)){P=K;Q=L;R=u;S=t;T=M;U=N;break c}pa=a+571032+(oa<<2)|0;qa=c[pa>>2]|0;Z=c[f>>2]|0;if((c[Z+688>>2]&2048|0)==0){ra=qa+1616|0}else{H=qa+1616|0;B=c[H>>2]|0;KIb(Z,48,2411264,(h=i,i=i+24|0,c[h>>2]=oa,c[h+8>>2]=B,c[h+16>>2]=qa,h)|0);i=h;ra=H}sa=oa+1|0;if((c[ra>>2]|0)==(K|0)){break}else{oa=sa}}if((qa|0)==0){P=K;Q=L;R=u;S=t;T=M;U=N;break c}H=qa+2192|0;B=c[H>>2]&A;c[H>>2]=B;if((B|0)==0){ta=0}else{P=K;Q=L;R=u;S=t;T=M;U=N;break c}while(1){B=c[a+571288+(ta<<2)>>2]|0;if((B|0)==0){break}if((B|0)==(qa|0)){J=38;break}else{ta=ta+1|0}}if((J|0)==38){J=0;c[H>>2]=4}c[pa>>2]=0;A=(c[g>>2]|0)-1|0;c[g>>2]=A;if((A|0)==0){P=K;Q=L;R=u;S=t;T=M;U=N;break c}orc(pa|0,a+571032+(sa<<2)|0,A-oa<<2|0)|0;P=K;Q=L;R=u;S=t;T=M;U=N;break c;break};case 4:{A=c[b+(x*12|0)+8>>2]|0;if((A|0)<16){ua=A}else{P=K;Q=L;R=u;S=t;T=M;U=A;break c}while(1){A=a+571160+(ua<<2)|0;B=c[A>>2]|0;if((B|0)!=0){Z=B+2192|0;c[Z>>2]=0;I=0;while(1){ja=c[a+571288+(I<<2)>>2]|0;if((ja|0)==0){break}if((ja|0)==(B|0)){J=90;break}else{I=I+1|0}}if((J|0)==90){J=0;c[Z>>2]=4}c[B+1628>>2]=0;c[A>>2]=0;c[j>>2]=(c[j>>2]|0)-1}I=ua+1|0;if((I|0)<16){ua=I}else{P=K;Q=L;R=u;S=t;T=M;U=16;break}}break};case 3:{H=b+(x*12|0)+8|0;I=a+571160+(c[H>>2]<<2)|0;aa=c[I>>2]|0;if(!((aa|0)==(L|0)|(aa|0)==0)){z=aa+2192|0;c[z>>2]=0;y=0;while(1){ja=c[a+571288+(y<<2)>>2]|0;if((ja|0)==0){break}if((ja|0)==(aa|0)){J=45;break}else{y=y+1|0}}if((J|0)==45){J=0;c[z>>2]=4}c[aa+1628>>2]=0;c[I>>2]=0;c[j>>2]=(c[j>>2]|0)-1}y=a+571032+(N<<2)|0;c[y>>2]=0;ja=(c[g>>2]|0)-1|0;c[g>>2]=ja;if((ja|0)!=0){orc(y|0,a+571032+(N+1<<2)|0,ja-N<<2|0)|0}c[a+571160+(c[H>>2]<<2)>>2]=L;if((L|0)==0){P=K;Q=0;R=u;S=t;T=M;U=N;break c}c[L+1628>>2]=1;c[j>>2]=(c[j>>2]|0)+1;P=K;Q=L;R=u;S=t;T=M;U=N;break c;break};case 2:{ja=c[b+(x*12|0)+8>>2]|0;y=c[k>>2]|0;if((y|0)==3){va=ja;wa=3}else{va=ja>>1;wa=(ja&1|0)==0?y^3:y}y=a+571160+(va<<2)|0;ja=c[y>>2]|0;if((ja|0)==0){ka=c[f>>2]|0;if((c[ka+688>>2]&2048|0)==0){P=K;Q=0;R=u;S=t;T=wa;U=va;break c}KIb(ka,48,2532024,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;P=K;Q=0;R=u;S=t;T=wa;U=va;break c}ka=ja+2192|0;da=c[ka>>2]&(wa^3);c[ka>>2]=da;if((da|0)==0){xa=0}else{P=K;Q=ja;R=u;S=t;T=wa;U=va;break c}while(1){da=c[a+571288+(xa<<2)>>2]|0;if((da|0)==0){break}if((da|0)==(ja|0)){J=57;break}else{xa=xa+1|0}}if((J|0)==57){J=0;c[ka>>2]=4}c[ja+1628>>2]=0;c[y>>2]=0;c[j>>2]=(c[j>>2]|0)-1;P=K;Q=ja;R=u;S=t;T=wa;U=va;break c;break};default:{P=K;Q=L;R=u;S=t;T=M;U=N;break c}}}}while(0);H=x+1|0;if((H|0)<(d|0)){r=U;s=T;t=S;u=R;v=Q;w=P;x=H}else{break}}if((J|0)==76){KIb(0,0,2541536,(h=i,i=i+24|0,c[h>>2]=2489704,c[h+8>>2]=2452704,c[h+16>>2]=662,h)|0);i=h;Hd();return 0}if((S|0)==0){ya=R;J=120;break}za=R;Aa=a+572240|0}else{ya=0;J=120}}while(0);e:do{if((J|0)==120){R=a+572240|0;S=c[R>>2]|0;do{if((S|0)==0){Ba=c[a+2524>>2]|0}else{P=c[a+571032>>2]|0;Q=c[a+2524>>2]|0;if((P|0)!=(Q|0)){Ba=Q;break}c[P+2192>>2]=3;za=ya;Aa=R;break e}}while(0);P=a+2524|0;if((c[Ba+1628>>2]|0)!=0){KIb(c[f>>2]|0,16,2478800,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;za=-1094995529;Aa=R;break}Q=c[Ba+1616>>2]|0;T=c[f>>2]|0;if((c[T+688>>2]&2048|0)==0){Ca=0}else{KIb(T,48,2420568,(h=i,i=i+16|0,c[h>>2]=Q,c[h+8>>2]=S,h)|0);i=h;Ca=0}while(1){T=c[R>>2]|0;if((Ca|0)>=(T|0)){Da=ya;Ea=T;break}Fa=a+571032+(Ca<<2)|0;Ga=c[Fa>>2]|0;T=c[f>>2]|0;if((c[T+688>>2]&2048|0)==0){Ha=Ga+1616|0}else{U=Ga+1616|0;d=c[U>>2]|0;KIb(T,48,2411264,(h=i,i=i+24|0,c[h>>2]=Ca,c[h+8>>2]=d,c[h+16>>2]=Ga,h)|0);i=h;Ha=U}Ia=Ca+1|0;if((c[Ha>>2]|0)==(Q|0)){J=133;break}else{Ca=Ia}}if((J|0)==133){if((Ga|0)==0){Ja=ya}else{Q=Ga+2192|0;c[Q>>2]=0;S=0;while(1){U=c[a+571288+(S<<2)>>2]|0;if((U|0)==0){break}if((U|0)==(Ga|0)){J=137;break}else{S=S+1|0}}if((J|0)==137){c[Q>>2]=4}c[Fa>>2]=0;S=(c[R>>2]|0)-1|0;c[R>>2]=S;if((S|0)!=0){orc(Fa|0,a+571032+(Ia<<2)|0,S-Ca<<2|0)|0}KIb(c[f>>2]|0,16,2469088,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;Ja=-1094995529}Da=Ja;Ea=c[R>>2]|0}if((Ea|0)==0){Ka=Ea;La=a+571032|0}else{S=a+571032|0;orc(a+571036|0,S|0,Ea<<2|0)|0;Ka=c[R>>2]|0;La=S}S=c[P>>2]|0;c[La>>2]=S;c[R>>2]=Ka+1;U=S+2192|0;c[U>>2]=c[U>>2]|c[a+177100>>2];za=Da;Aa=R}}while(0);Da=a+572236|0;Ka=c[Da>>2]|0;La=c[Aa>>2]|0;Ea=a+6172|0;Ja=c[Ea>>2]|0;f:do{if((La+Ka|0)>(((Ja|0)>1?Ja:1)|0)){KIb(c[f>>2]|0,16,2459816,(h=i,i=i+24|0,c[h>>2]=Ka,c[h+8>>2]=La,c[h+16>>2]=Ja,h)|0);i=h;Ca=c[Aa>>2]|0;if((c[Da>>2]|0)!=0&(Ca|0)==0){Ia=0;while(1){Ma=c[a+571160+(Ia<<2)>>2]|0;if((Ia|0)>=16){J=151;break}if((Ma|0)==0){Ia=Ia+1|0}else{J=150;break}}if((J|0)!=150)if((J|0)==151){if((Ma|0)==0){Na=-1094995529;J=171;break}}R=a+571160+(Ia<<2)|0;P=Ma+2192|0;c[P>>2]=0;Q=0;while(1){Fa=c[a+571288+(Q<<2)>>2]|0;if((Fa|0)==0){break}if((Fa|0)==(Ma|0)){J=155;break}else{Q=Q+1|0}}if((J|0)==155){c[P>>2]=4}c[Ma+1628>>2]=0;c[R>>2]=0;c[Da>>2]=(c[Da>>2]|0)-1;Na=-1094995529;J=171;break}Q=c[(c[a+571032+(Ca-1<<2)>>2]|0)+1616>>2]|0;Ia=c[f>>2]|0;if((c[Ia+688>>2]&2048|0)==0){Oa=0}else{KIb(Ia,48,2420568,(h=i,i=i+16|0,c[h>>2]=Q,c[h+8>>2]=Ca,h)|0);i=h;Oa=0}while(1){Ia=c[Aa>>2]|0;if((Oa|0)>=(Ia|0)){Pa=-1094995529;Qa=Ia;J=172;break f}Ra=a+571032+(Oa<<2)|0;Sa=c[Ra>>2]|0;Ia=c[f>>2]|0;if((c[Ia+688>>2]&2048|0)==0){Ta=Sa+1616|0}else{Fa=Sa+1616|0;Ga=c[Fa>>2]|0;KIb(Ia,48,2411264,(h=i,i=i+24|0,c[h>>2]=Oa,c[h+8>>2]=Ga,c[h+16>>2]=Sa,h)|0);i=h;Ta=Fa}Ua=Oa+1|0;if((c[Ta>>2]|0)==(Q|0)){break}else{Oa=Ua}}if((Sa|0)==0){Na=-1094995529;J=171;break}Q=Sa+2192|0;c[Q>>2]=0;Ca=0;while(1){R=c[a+571288+(Ca<<2)>>2]|0;if((R|0)==0){break}if((R|0)==(Sa|0)){J=168;break}else{Ca=Ca+1|0}}if((J|0)==168){c[Q>>2]=4}c[Ra>>2]=0;Ca=(c[Aa>>2]|0)-1|0;c[Aa>>2]=Ca;if((Ca|0)==0){Va=-1094995529;break}orc(Ra|0,a+571032+(Ua<<2)|0,Ca-Oa<<2|0)|0;Na=-1094995529;J=171}else{Na=za;J=171}}while(0);if((J|0)==171){Pa=Na;Qa=c[Aa>>2]|0;J=172}do{if((J|0)==172){if((Qa|0)<=0){Va=Pa;break}Na=a+2524|0;za=a+6144|0;Oa=0;Ua=Qa;while(1){Ra=c[a+571032+(Oa<<2)>>2]|0;g:do{if((c[Ra+2204>>2]|0)!=0){Sa=c[Ra+1616>>2]|0;if(((1<<c[za>>2])-1&(c[(c[Na>>2]|0)+1616>>2]|0)-Sa|0)<=(c[Ea>>2]|0)){break}Ta=c[f>>2]|0;if((c[Ta+688>>2]&2048|0)==0){Wa=0}else{KIb(Ta,48,2420568,(h=i,i=i+16|0,c[h>>2]=Sa,c[h+8>>2]=Ua,h)|0);i=h;Wa=0}while(1){if((Wa|0)>=(c[Aa>>2]|0)){break g}Xa=a+571032+(Wa<<2)|0;Ya=c[Xa>>2]|0;Ta=c[f>>2]|0;if((c[Ta+688>>2]&2048|0)==0){Za=Ya+1616|0}else{Ma=Ya+1616|0;Ja=c[Ma>>2]|0;KIb(Ta,48,2411264,(h=i,i=i+24|0,c[h>>2]=Wa,c[h+8>>2]=Ja,c[h+16>>2]=Ya,h)|0);i=h;Za=Ma}_a=Wa+1|0;if((c[Za>>2]|0)==(Sa|0)){break}else{Wa=_a}}if((Ya|0)==0){break}Sa=Ya+2192|0;c[Sa>>2]=0;ja=0;while(1){y=c[a+571288+(ja<<2)>>2]|0;if((y|0)==0){break}if((y|0)==(Ya|0)){J=187;break}else{ja=ja+1|0}}if((J|0)==187){J=0;c[Sa>>2]=4}c[Xa>>2]=0;ja=(c[Aa>>2]|0)-1|0;c[Aa>>2]=ja;if((ja|0)==0){break}orc(Xa|0,a+571032+(_a<<2)|0,ja-Wa<<2|0)|0}}while(0);Ra=Oa+1|0;ja=c[Aa>>2]|0;if((Ra|0)<(ja|0)){Oa=Ra;Ua=ja}else{Va=Pa;break}}}}while(0);Pa=c[f>>2]|0;do{if((c[Pa+688>>2]&2048|0)!=0){KIb(Pa,48,2382736,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;if((c[Aa>>2]|0)==0){break}else{$a=0}do{Wa=c[a+571032+($a<<2)>>2]|0;_a=c[Wa+1616>>2]|0;Xa=c[Wa+1612>>2]|0;J=c[Wa>>2]|0;KIb(c[f>>2]|0,48,2389680,(h=i,i=i+32|0,c[h>>2]=$a,c[h+8>>2]=_a,c[h+16>>2]=Xa,c[h+24>>2]=J,h)|0);i=h;$a=$a+1|0;}while($a>>>0<(c[Aa>>2]|0)>>>0)}}while(0);$a=c[f>>2]|0;if((c[$a+688>>2]&2048|0)==0){ab=0;bb=0}else{KIb($a,48,2396624,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;$a=0;while(1){Pa=c[a+571160+($a<<2)>>2]|0;if((Pa|0)!=0){J=c[Pa+1616>>2]|0;Xa=c[Pa+1612>>2]|0;_a=c[Pa>>2]|0;KIb(c[f>>2]|0,48,2389680,(h=i,i=i+32|0,c[h>>2]=$a,c[h+8>>2]=J,c[h+16>>2]=Xa,c[h+24>>2]=_a,h)|0);i=h}_a=$a+1|0;if(_a>>>0<16>>>0){$a=_a}else{ab=0;bb=0;break}}}do{ab=((c[a+427604+(bb<<2)>>2]|0)!=0)+ab|0;bb=bb+1|0;}while(bb>>>0<256>>>0);if(!((Va|0)>-1)){cb=c[f>>2]|0;db=cb+696|0;eb=c[db>>2]|0;fb=eb&8;gb=(fb|0)!=0;hb=gb?Va:0;i=e;return hb|0}if((c[Da>>2]|0)!=0){cb=c[f>>2]|0;db=cb+696|0;eb=c[db>>2]|0;fb=eb&8;gb=(fb|0)!=0;hb=gb?Va:0;i=e;return hb|0}Da=c[a+7348>>2]|0;do{if((c[Aa>>2]|0)>=3){if(!(Da>>>0<2>>>0)){cb=c[f>>2]|0;db=cb+696|0;eb=c[db>>2]|0;fb=eb&8;gb=(fb|0)!=0;hb=gb?Va:0;i=e;return hb|0}if((c[a+7352>>2]|0)>>>0<2>>>0&(ab|0)==1){break}cb=c[f>>2]|0;db=cb+696|0;eb=c[db>>2]|0;fb=eb&8;gb=(fb|0)!=0;hb=gb?Va:0;i=e;return hb|0}}while(0);if(Da>>>0>((c[a+177100>>2]|0)!=3|2)>>>0){cb=c[f>>2]|0;db=cb+696|0;eb=c[db>>2]|0;fb=eb&8;gb=(fb|0)!=0;hb=gb?Va:0;i=e;return hb|0}Da=c[a+2524>>2]|0;if((c[Da+88>>2]|0)!=1){cb=c[f>>2]|0;db=cb+696|0;eb=c[db>>2]|0;fb=eb&8;gb=(fb|0)!=0;hb=gb?Va:0;i=e;return hb|0}ab=Da+2200|0;c[ab>>2]=c[ab>>2]|1;if((c[(c[f>>2]|0)+176>>2]|0)!=0){cb=c[f>>2]|0;db=cb+696|0;eb=c[db>>2]|0;fb=eb&8;gb=(fb|0)!=0;hb=gb?Va:0;i=e;return hb|0}ab=a+572480|0;c[ab>>2]=c[ab>>2]|2;cb=c[f>>2]|0;db=cb+696|0;eb=c[db>>2]|0;fb=eb&8;gb=(fb|0)!=0;hb=gb?Va:0;i=e;return hb|0}function Iia(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;i=i+792|0;h=g|0;j=e+8|0;k=c[j>>2]|0;a:do{if((c[b+427436>>2]|0)==5){l=c[e+16>>2]|0;m=k+1|0;n=l>>>0>m>>>0?m:l;c[j>>2]=n;m=d[(c[e>>2]|0)+(n>>>3)|0]|0;c[j>>2]=((n|0)<(l|0))+n;if((128>>>((n&7)>>>0)&m|0)==0){o=0;break}c[h>>2]=6;c[h+8>>2]=0;o=1}else{m=c[e>>2]|0;n=d[m+(k>>>3)|0]|0;l=c[e+16>>2]|0;p=((k|0)<(l|0))+k|0;c[j>>2]=p;if((n&128>>>((k&7)>>>0)|0)==0){do{if((f|0)!=0){n=Gia(b,f)|0;if((n|0)>=0){break}if((c[(c[b>>2]|0)+696>>2]&8|0)==0){break}else{q=n}i=g;return q|0}}while(0);q=0;i=g;return q|0}n=b+177100|0;r=b+428680|0;s=b+428684|0;t=0;u=p;while(1){if((t|0)>=66){o=t;break a}v=m+(u>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(u&7)>>>23;v=(d[1382088+w|0]|0)+u|0;x=l>>>0>v>>>0?v:l;c[j>>2]=x;v=a[1276064+w|0]|0;y=v&255;c[h+(t*12|0)>>2]=y;if((y|0)==3|(y|0)==1){w=c[r>>2]|0;z=m+(x>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7);if(A>>>0>134217727>>>0){z=A>>>23;B=(d[1382088+z|0]|0)+x|0;C=l>>>0>B>>>0?B:l;c[j>>2]=C;D=d[1276064+z|0]|0;E=C}else{C=A>>>0>65535>>>0;z=C?A>>>16:A;B=C?16:0;if((z&65280|0)==0){F=B;G=z}else{F=B|8;G=z>>>8}z=(d[1359664+G|0]|0)+F<<1;B=63-z+x|0;C=l>>>0>B>>>0?B:l;c[j>>2]=C;D=(A>>>((z-31|0)>>>0))-1|0;E=C}c[h+(t*12|0)+4>>2]=(c[s>>2]|0)-1&w-1-D;H=E}else{H=x}x=v<<24>>24==2;w=v<<24>>24==4;if((y-2|0)>>>0<2>>>0|v<<24>>24==6|w){C=m+(H>>>3)|0;z=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(H&7)>>>23;C=(d[1382088+z|0]|0)+H|0;A=l>>>0>C>>>0?C:l;c[j>>2]=A;C=a[1276064+z|0]|0;z=C&255;if((C&255)>>>0>31>>>0){I=19;break}if(!((C&255)>>>0<16>>>0|w&C<<24>>24==16)){if(!x){I=19;break}if((c[n>>2]|0)==3){I=19;break}}c[h+(t*12|0)+8>>2]=z;J=A}else{J=H}if((v&255)>>>0>6>>>0){I=22;break}if(v<<24>>24==0){o=t;break a}else{t=t+1|0;u=J}}if((I|0)==19){KIb(c[b>>2]|0,16,2443184,(K=i,i=i+8|0,c[K>>2]=y,K)|0);i=K;q=-1;i=g;return q|0}else if((I|0)==22){KIb(c[b>>2]|0,16,2430776,(K=i,i=i+8|0,c[K>>2]=y,K)|0);i=K;q=-1;i=g;return q|0}}}while(0);y=(f|0)==0;if(!(y|(o|0)==-1)){nrc(b+571436|0,h|0,792)|0;c[b+572228>>2]=o;q=0;i=g;return q|0}if(!(y&(o|0)>-1)){q=0;i=g;return q|0}y=b+572228|0;f=c[y>>2]|0;do{if((o|0)==(f|0)){J=0;while(1){if((J|0)>=(o|0)){q=0;I=36;break}L=c[b+571436+(J*12|0)>>2]|0;M=c[h+(J*12|0)>>2]|0;if((L|0)==(M|0)){J=J+1|0}else{I=34;break}}if((I|0)==34){KIb(0,16,2403552,(K=i,i=i+24|0,c[K>>2]=L,c[K+8>>2]=M,c[K+16>>2]=J,K)|0);i=K;N=c[y>>2]|0;break}else if((I|0)==36){i=g;return q|0}}else{N=f}}while(0);KIb(c[b>>2]|0,16,2639800,(K=i,i=i+16|0,c[K>>2]=o,c[K+8>>2]=N,K)|0);i=K;q=-1094995529;i=g;return q|0}function Jia(a){a=a|0;c[a+572444>>2]=-1;c[a+572436>>2]=0;c[a+572440>>2]=-1;c[a+572500>>2]=0;c[a+572416>>2]=0;return}function Kia(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;e=i;i=i+280|0;f=e|0;g=e+272|0;h=b+1096|0;j=c[h>>2]|0;k=b+1100|0;l=c[k>>2]|0;if((l-j|0)<=16){m=0;i=e;return m|0}n=b+1088|0;o=b+1104|0;p=b|0;q=b+6124|0;r=b+1088|0;s=b+572408|0;t=b+572432|0;u=b+572440|0;v=b+572436|0;w=f+16|0;x=b+427372|0;y=b+572444|0;z=b+572500|0;A=b+572452|0;B=b+572456|0;C=b+572416|0;D=b+572420|0;E=b+572460|0;F=b+572428|0;G=b+572472|0;H=b+572424|0;I=b+572468|0;J=b+572464|0;K=j;j=l;a:while(1){l=0;L=K;while(1){if((j-L|0)<8){m=-1094995529;M=112;break a}N=c[n>>2]|0;O=N+(L>>>3)|0;P=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7);Q=(P>>>24)+l|0;R=c[o>>2]|0;O=L+8|0;S=R>>>0>O>>>0?O:R;c[h>>2]=S;if((P&-16777216|0)==-16777216){l=Q;L=S}else{T=0;U=S;break}}do{if((j-U|0)<8){m=-1094995529;M=112;break a}L=N+(U>>>3)|0;l=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(U&7);T=(l>>>24)+T|0;L=U+8|0;U=R>>>0>L>>>0?L:R;c[h>>2]=U;}while((l&-16777216|0)==-16777216);l=c[p>>2]|0;if((c[l+688>>2]&256|0)==0){V=U;W=j}else{KIb(l,48,2541080,(X=i,i=i+16|0,c[X>>2]=Q,c[X+8>>2]=T,X)|0);i=X;V=c[h>>2]|0;W=c[k>>2]|0}Y=W-V|0;if(T>>>0>((Y|0)/8|0)>>>0){M=11;break}l=V+(T<<3)|0;b:do{switch(Q|0){case 45:{L=c[o>>2]|0;S=c[r>>2]|0;P=S+(V>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(V&7);if(O>>>0>134217727>>>0){P=O>>>23;Z=(d[1382088+P|0]|0)+V|0;_=L>>>0>Z>>>0?Z:L;c[h>>2]=_;$=d[1276064+P|0]|0;aa=_}else{_=O>>>0>65535>>>0;P=_?O>>>16:O;Z=_?16:0;if((P&65280|0)==0){ba=Z;ca=P}else{ba=Z|8;ca=P>>>8}P=(d[1359664+ca|0]|0)+ba<<1;Z=63-P+V|0;_=L>>>0>Z>>>0?Z:L;c[h>>2]=_;$=(O>>>((P-31|0)>>>0))-1|0;aa=_}c[A>>2]=$;_=(d[S+(aa>>>3)|0]|0)<<(aa&7)>>>7;P=((aa|0)<(L|0))+aa|0;c[h>>2]=P;O=_&1;c[B>>2]=O;c[C>>2]=O^1;if((O|0)==0){_=S+(P>>>3)|0;Z=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(P&7)>>>25;_=P+7|0;da=L>>>0>_>>>0?_:L;c[h>>2]=da;c[D>>2]=Z;c[E>>2]=Z;_=(d[S+(da>>>3)|0]|0)<<(da&7)>>>7;ea=((da|0)<(L|0))+da|0;c[h>>2]=ea;da=_&1;c[F>>2]=da;c[G>>2]=da;_=S+(ea>>>3)|0;fa=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(ea&7)>>>26;_=ea+6|0;c[H>>2]=fa;c[I>>2]=fa;fa=(L>>>0>_>>>0?_:L)+6|0;_=L>>>0>fa>>>0?fa:L;if((da|0)!=0|(Z|0)==5){ga=_}else{Z=_+16|0;ga=L>>>0>Z>>>0?Z:L}Z=ga+8|0;_=L>>>0>Z>>>0?Z:L;c[h>>2]=_;Z=S+(_>>>3)|0;S=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(_&7);if(S>>>0>134217727>>>0){Z=S>>>23;da=(d[1382088+Z|0]|0)+_|0;fa=L>>>0>da>>>0?da:L;c[h>>2]=fa;ha=d[1276064+Z|0]|0;ia=fa}else{fa=S>>>0>65535>>>0;Z=fa?S>>>16:S;da=fa?16:0;if((Z&65280|0)==0){ja=da;ka=Z}else{ja=da|8;ka=Z>>>8}Z=(d[1359664+ka|0]|0)+ja<<1;da=63-Z+_|0;_=L>>>0>da>>>0?da:L;c[h>>2]=_;ha=(S>>>((Z-31|0)>>>0))-1|0;ia=_}c[J>>2]=ha;la=ia}else{la=P}P=la+1|0;c[h>>2]=L>>>0>P>>>0?P:L;L=c[p>>2]|0;if((c[L+688>>2]&1|0)==0){break b}P=c[E>>2]|0;_=c[G>>2]|0;Z=c[I>>2]|0;S=c[J>>2]|0;KIb(L,48,2516784,(X=i,i=i+48|0,c[X>>2]=$,c[X+8>>2]=O,c[X+16>>2]=P,c[X+24>>2]=_,c[X+32>>2]=Z,c[X+40>>2]=S,X)|0);i=X;break};case 6:{S=c[o>>2]|0;Z=(c[r>>2]|0)+(V>>>3)|0;_=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(V&7);if(_>>>0>134217727>>>0){Z=_>>>23;P=(d[1382088+Z|0]|0)+V|0;O=S>>>0>P>>>0?P:S;c[h>>2]=O;ma=d[1276064+Z|0]|0;na=O}else{O=_>>>0>65535>>>0;Z=O?_>>>16:_;P=O?16:0;if((Z&65280|0)==0){oa=P;pa=Z}else{oa=P|8;pa=Z>>>8}Z=(d[1359664+pa|0]|0)+oa<<1;P=63-Z+V|0;O=S>>>0>P>>>0?P:S;c[h>>2]=O;ma=(_>>>((Z-31|0)>>>0))-1|0;na=O}c[y>>2]=ma;O=na+4|0;c[h>>2]=S>>>0>O>>>0?O:S;S=c[p>>2]|0;if((c[S+688>>2]&1|0)==0){break b}KIb(S,48,2489672,(X=i,i=i+8|0,c[X>>2]=ma,X)|0);i=X;break};case 4:{if((T|0)<7){m=-1;M=112;break a}S=T-7|0;O=c[o>>2]|0;Z=V+8|0;_=(O>>>0>Z>>>0?Z:O)+16|0;Z=O>>>0>_>>>0?_:O;c[h>>2]=Z;_=c[r>>2]|0;P=_+(Z>>>3)|0;L=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Z&7)&-65536;P=Z+16|0;Z=O>>>0>P>>>0?P:O;c[h>>2]=Z;P=_+(Z>>>3)|0;da=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(Z&7)>>>16;P=Z+16|0;Z=O>>>0>P>>>0?P:O;c[h>>2]=Z;if((da|L|0)!=1146373937){L=Z+(S<<3)|0;c[h>>2]=O>>>0>L>>>0?L:O;break b}if((S|0)<1){m=-1;M=112;break a}L=Z+1|0;Z=O>>>0>L>>>0?L:O;c[h>>2]=Z;L=_+(Z>>>3)|0;da=je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0;L=Z+1|0;P=(O>>>0>L>>>0?L:O)+6|0;L=O>>>0>P>>>0?P:O;c[h>>2]=L;if((da&-2147483648>>>((Z&7)>>>0)|0)==0){break b}if((S|0)<2){m=-1;M=112;break a}S=L+4|0;L=O>>>0>S>>>0?S:O;c[h>>2]=L;S=_+(L>>>3)|0;_=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(L&7)>>>28;S=L+4|0;c[h>>2]=O>>>0>S>>>0?S:O;c[(c[p>>2]|0)+272>>2]=_;break};case 0:{_=c[o>>2]|0;O=(c[r>>2]|0)+(V>>>3)|0;S=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(V&7)>>>23;O=(d[1382088+S|0]|0)+V|0;L=_>>>0>O>>>0?O:_;c[h>>2]=L;O=a[1276064+S|0]|0;qa=O&255;if((O&255)>>>0>31>>>0){M=72;break a}O=c[b+427476+(qa<<2)>>2]|0;if((O|0)==0){M=72;break a}do{if((c[O+1152>>2]|0)==0){ra=L;sa=_}else{S=O+1168|0;if((c[S>>2]|0)<=0){ra=L;sa=_;break}Z=O+1172|0;da=0;P=L;fa=_;while(1){ea=c[Z>>2]|0;do{if((ea|0)==0){ta=0}else{ua=c[r>>2]|0;va=ua+(P>>>3)|0;wa=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(P&7);if((ea|0)<26){va=ea+P|0;c[h>>2]=fa>>>0>va>>>0?va:fa;ta=wa>>>((32-ea|0)>>>0);break}else{va=P+16|0;xa=fa>>>0>va>>>0?va:fa;c[h>>2]=xa;va=ea-16|0;ya=ua+(xa>>>3)|0;ua=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(xa&7)>>>((48-ea|0)>>>0);ya=xa+va|0;c[h>>2]=fa>>>0>ya>>>0?ya:fa;ta=ua|wa>>>16<<va;break}}}while(0);c[b+572504+(da<<2)>>2]=ta;ea=c[o>>2]|0;va=(c[h>>2]|0)+(c[Z>>2]|0)|0;wa=ea>>>0>va>>>0?va:ea;c[h>>2]=wa;va=da+1|0;if((va|0)<(c[S>>2]|0)){da=va;P=wa;fa=ea}else{ra=wa;sa=ea;break}}}}while(0);do{if((c[O+1156>>2]|0)!=0){_=O+1168|0;if((c[_>>2]|0)<=0){break}L=O+1172|0;fa=0;P=ra;da=sa;do{S=c[L>>2]|0;do{if((S|0)==0){za=0}else{Z=c[r>>2]|0;ea=Z+(P>>>3)|0;wa=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(P&7);if((S|0)<26){ea=S+P|0;c[h>>2]=da>>>0>ea>>>0?ea:da;za=wa>>>((32-S|0)>>>0);break}else{ea=P+16|0;va=da>>>0>ea>>>0?ea:da;c[h>>2]=va;ea=S-16|0;ua=Z+(va>>>3)|0;Z=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(va&7)>>>((48-S|0)>>>0);ua=va+ea|0;c[h>>2]=da>>>0>ua>>>0?ua:da;za=Z|wa>>>16<<ea;break}}}while(0);c[b+572504+(fa<<2)>>2]=za;da=c[o>>2]|0;S=(c[h>>2]|0)+(c[L>>2]|0)|0;P=da>>>0>S>>>0?S:da;c[h>>2]=P;fa=fa+1|0;}while((fa|0)<(c[_>>2]|0))}}while(0);c[z>>2]=1;break};case 5:{if((T|0)<16){m=-1094995529;M=112;break a}O=-T|0;_=c[o>>2]|0;fa=c[r>>2]|0;P=0;da=V;do{L=fa+(da>>>3)|0;S=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(da&7)>>>24;L=da+8|0;da=_>>>0>L>>>0?L:_;c[h>>2]=da;a[f+P|0]=S;P=P+1|0;}while(P>>>0<271>>>0&(P|0)<(T|0));P=O>>>0>4294967025>>>0?T:271;a[f+P|0]=0;da=Bd(w|0,2478784,(X=i,i=i+8|0,c[X>>2]=g,X)|0)|0;i=X;do{if((da|0)==1){_=c[g>>2]|0;if((_|0)<=0){break}c[x>>2]=_;if((_|0)!=1){break}if((krc(w,2469064,16)|0)!=0){break}c[x>>2]=67}}while(0);da=c[p>>2]|0;if((c[da+688>>2]&4096|0)!=0){KIb(da,48,2459800,(X=i,i=i+8|0,c[X>>2]=w,X)|0);i=X}if((P|0)>=(T|0)){break b}da=c[o>>2]|0;O=P;_=c[h>>2]|0;do{fa=_+8|0;_=da>>>0>fa>>>0?fa:da;O=O+1|0;}while((O|0)<(T|0));c[h>>2]=_;break};case 1:{O=0;da=q;while(1){if((c[da+20>>2]|0)==0){P=c[b+427476+(O<<2)>>2]|0;Aa=(P|0)==0?da:P}else{Aa=da}P=O+1|0;if((P|0)<32){O=P;da=Aa}else{break}}if((c[Aa+1152>>2]|0)==0){if((c[Aa+1156>>2]|0)==0){Ba=V}else{M=18}}else{M=18}if((M|0)==18){M=0;da=c[Aa+1176>>2]|0;do{if((da|0)==0){Ca=0;Da=V}else{O=c[o>>2]|0;_=c[n>>2]|0;P=_+(V>>>3)|0;fa=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(V&7);if((da|0)<26){P=V+da|0;S=O>>>0>P>>>0?P:O;c[h>>2]=S;Ca=fa>>>((32-da|0)>>>0);Da=S;break}else{S=V+16|0;P=O>>>0>S>>>0?S:O;c[h>>2]=P;S=da-16|0;L=_+(P>>>3)|0;_=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(P&7)>>>((48-da|0)>>>0);L=P+S|0;P=O>>>0>L>>>0?L:O;c[h>>2]=P;Ca=_|fa>>>16<<S;Da=P;break}}}while(0);c[u>>2]=Ca;da=c[Aa+1180>>2]|0;do{if((da|0)==0){Ea=0;Fa=Da}else{P=c[o>>2]|0;S=c[n>>2]|0;fa=S+(Da>>>3)|0;_=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Da&7);if((da|0)<26){fa=Da+da|0;O=P>>>0>fa>>>0?fa:P;c[h>>2]=O;Ea=_>>>((32-da|0)>>>0);Fa=O;break}else{O=Da+16|0;fa=P>>>0>O>>>0?O:P;c[h>>2]=fa;O=da-16|0;L=S+(fa>>>3)|0;S=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(fa&7)>>>((48-da|0)>>>0);L=fa+O|0;fa=P>>>0>L>>>0?L:P;c[h>>2]=fa;Ea=S|_>>>16<<O;Fa=fa;break}}}while(0);c[v>>2]=Ea;Ba=Fa}if((c[Aa+1160>>2]|0)==0){break b}da=c[o>>2]|0;fa=c[r>>2]|0;O=fa+(Ba>>>3)|0;_=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(Ba&7);O=_>>>28;S=Ba+4|0;P=da>>>0>S>>>0?S:da;c[h>>2]=P;c[s>>2]=O;c[t>>2]=0;if(_>>>0>2415919103>>>0){m=-1094995529;M=112;break a}_=d[601824+O|0]|0;S=Aa+1164|0;L=0;ea=0;wa=P;while(1){P=fa+(wa>>>3)|0;Z=je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=wa+1|0;ua=da>>>0>P>>>0?P:da;c[h>>2]=ua;do{if((Z&-2147483648>>>((wa&7)>>>0)|0)==0){Ga=ea;Ha=ua}else{P=fa+(ua>>>3)|0;va=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(ua&7)>>>30;P=ua+2|0;ya=1<<va|ea;c[t>>2]=ya;va=(da>>>0>P>>>0?P:da)+1|0;P=(da>>>0>va>>>0?va:da)+5|0;va=da>>>0>P>>>0?P:da;c[h>>2]=va;P=fa+(va>>>3)|0;xa=je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0;P=va+1|0;Ia=(da>>>0>P>>>0?P:da)+1|0;P=(da>>>0>Ia>>>0?Ia:da)+1|0;Ia=(da>>>0>P>>>0?P:da)+8|0;P=da>>>0>Ia>>>0?Ia:da;c[h>>2]=P;do{if((xa&-2147483648>>>((va&7)>>>0)|0)==0){Ia=fa+(P>>>3)|0;Ja=je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0;Ia=P+1|0;Ka=da>>>0>Ia>>>0?Ia:da;c[h>>2]=Ka;if((Ja&-2147483648>>>((P&7)>>>0)|0)==0){La=Ka;break}Ja=Ka+6|0;Ka=da>>>0>Ja>>>0?Ja:da;c[h>>2]=Ka;Ja=fa+(Ka>>>3)|0;Ia=je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0;Ja=Ka+1|0;Ma=da>>>0>Ja>>>0?Ja:da;c[h>>2]=Ma;if((Ia&-2147483648>>>((Ka&7)>>>0)|0)==0){La=Ma;break}Ka=Ma+6|0;Ma=da>>>0>Ka>>>0?Ka:da;c[h>>2]=Ma;Ka=fa+(Ma>>>3)|0;Ia=je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0;Ka=Ma+1|0;Ja=da>>>0>Ka>>>0?Ka:da;c[h>>2]=Ja;if((Ia&-2147483648>>>((Ma&7)>>>0)|0)==0){La=Ja;break}Ma=Ja+5|0;Ja=da>>>0>Ma>>>0?Ma:da;c[h>>2]=Ja;La=Ja}else{Ja=P+6|0;Ma=(da>>>0>Ja>>>0?Ja:da)+6|0;Ja=(da>>>0>Ma>>>0?Ma:da)+5|0;Ma=da>>>0>Ja>>>0?Ja:da;c[h>>2]=Ma;La=Ma}}while(0);P=c[S>>2]|0;if((P|0)<=0){Ga=ya;Ha=La;break}va=P+La|0;P=da>>>0>va>>>0?va:da;c[h>>2]=P;Ga=ya;Ha=P}}while(0);ua=L+1|0;if(ua>>>0<_>>>0){L=ua;ea=Ga;wa=Ha}else{break}}wa=c[p>>2]|0;if((c[wa+688>>2]&1|0)==0){break b}KIb(wa,48,2443152,(X=i,i=i+16|0,c[X>>2]=Ga,c[X+8>>2]=O,X)|0);i=X;break};default:{KIb(c[p>>2]|0,48,2452656,(X=i,i=i+8|0,c[X>>2]=Q,X)|0);i=X}}}while(0);wa=c[h>>2]|0;ea=-wa|0;L=l-wa|0;_=c[o>>2]|0;da=_-wa|0;if((L|0)<(ea|0)){Na=ea}else{Na=(da|0)<(L|0)?da:L}L=Na+wa|0;wa=-L&7;if((wa|0)==0){Oa=L;Pa=L}else{da=wa+L|0;L=_>>>0>da>>>0?da:_;Oa=L;Pa=L}c[h>>2]=Pa;L=c[k>>2]|0;if((L-Oa|0)>16){K=Oa;j=L}else{m=0;M=112;break}}if((M|0)==11){KIb(c[p>>2]|0,16,2605152,(X=i,i=i+24|0,c[X>>2]=Q,c[X+8>>2]=T<<3,c[X+16>>2]=Y,X)|0);i=X;m=-1094995529;i=e;return m|0}else if((M|0)==72){KIb(c[p>>2]|0,16,2502760,(X=i,i=i+8|0,c[X>>2]=qa,X)|0);i=X;m=-1094995529;i=e;return m|0}else if((M|0)==112){i=e;return m|0}return 0}function Lia(a){a=a|0;var b=0,d=0;b=c[a+572456>>2]|0;a:do{if((b|0)==0){switch(c[a+572460>>2]|0){case 5:{d=(c[a+572468>>2]|0)==2?2568120:2550088;break a;break};case 0:{d=(c[a+572468>>2]|0)==2?2363312:2298176;break a;break};case 1:{d=(c[a+572468>>2]|0)==2?2247480:2205512;break a;break};case 3:{d=(c[a+572468>>2]|0)==2?2122056:2639784;break a;break};case 2:{d=(c[a+572468>>2]|0)==2?2173320:2145872;break a;break};case 4:{d=(c[a+572468>>2]|0)==2?2617040:2589856;break a;break};default:{d=2532016;break a}}}else if((b|0)==1){d=2532016}else{d=0}}while(0);return d|0}function Mia(a,b){a=a|0;b=b|0;var d=0;d=a|0;if((b-9|0)>>>0<8>>>0){c[d>>2]=226;c[a+4>>2]=164;c[a+8>>2]=4;c[a+12>>2]=92;c[a+16>>2]=70;c[a+20>>2]=140;c[a+24>>2]=104;c[a+28>>2]=34;return}else{c[d>>2]=258;c[a+4>>2]=94;c[a+8>>2]=88;c[a+12>>2]=72;c[a+16>>2]=36;c[a+20>>2]=56;c[a+24>>2]=48;c[a+28>>2]=270;return}}function Nia(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ca(j,c)|0;l=ca(j,g)|0;j=ca(c,h)|0;c=ca(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=g+3|0;n=g+4|0;o=g+5|0;p=g+6|0;q=g+7|0;r=g+8|0;s=a;t=0;u=i;while(1){v=ca(e[s>>1]|0,k)|0;w=s+2|0;x=ca(e[w>>1]|0,l)|0;y=s+(g<<1)|0;z=ca(e[y>>1]|0,j)|0;A=s+(d<<1)|0;b[u>>1]=(v+32+x+z+(ca(e[A>>1]|0,c)|0)|0)>>>6;z=ca(e[w>>1]|0,k)|0;w=s+4|0;x=ca(e[w>>1]|0,l)|0;v=ca(e[A>>1]|0,j)|0;A=s+(h<<1)|0;b[u+2>>1]=(z+32+x+v+(ca(e[A>>1]|0,c)|0)|0)>>>6;v=ca(e[w>>1]|0,k)|0;w=s+6|0;x=ca(e[w>>1]|0,l)|0;z=ca(e[A>>1]|0,j)|0;A=s+(m<<1)|0;b[u+4>>1]=(v+32+x+z+(ca(e[A>>1]|0,c)|0)|0)>>>6;z=ca(e[w>>1]|0,k)|0;w=s+8|0;x=ca(e[w>>1]|0,l)|0;v=ca(e[A>>1]|0,j)|0;A=s+(n<<1)|0;b[u+6>>1]=(z+32+x+v+(ca(e[A>>1]|0,c)|0)|0)>>>6;v=ca(e[w>>1]|0,k)|0;w=s+10|0;x=ca(e[w>>1]|0,l)|0;z=ca(e[A>>1]|0,j)|0;A=s+(o<<1)|0;b[u+8>>1]=(v+32+x+z+(ca(e[A>>1]|0,c)|0)|0)>>>6;z=ca(e[w>>1]|0,k)|0;w=s+12|0;x=ca(e[w>>1]|0,l)|0;v=ca(e[A>>1]|0,j)|0;A=s+(p<<1)|0;b[u+10>>1]=(z+32+x+v+(ca(e[A>>1]|0,c)|0)|0)>>>6;v=ca(e[w>>1]|0,k)|0;w=s+14|0;x=ca(e[w>>1]|0,l)|0;z=ca(e[A>>1]|0,j)|0;A=s+(q<<1)|0;b[u+12>>1]=(v+32+x+z+(ca(e[A>>1]|0,c)|0)|0)>>>6;z=ca(e[w>>1]|0,k)|0;w=ca(e[s+16>>1]|0,l)|0;x=ca(e[A>>1]|0,j)|0;b[u+14>>1]=(z+32+w+x+(ca(e[s+(r<<1)>>1]|0,c)|0)|0)>>>6;x=t+1|0;if((x|0)<(f|0)){s=y;t=x;u=u+(g<<1)|0}else{break}}return}u=l+j|0;if((u|0)==0){if((f|0)>0){B=a;C=0;D=i}else{return}while(1){b[D>>1]=((ca(e[B>>1]|0,k)|0)+32|0)>>>6;b[D+2>>1]=((ca(e[B+2>>1]|0,k)|0)+32|0)>>>6;b[D+4>>1]=((ca(e[B+4>>1]|0,k)|0)+32|0)>>>6;b[D+6>>1]=((ca(e[B+6>>1]|0,k)|0)+32|0)>>>6;b[D+8>>1]=((ca(e[B+8>>1]|0,k)|0)+32|0)>>>6;b[D+10>>1]=((ca(e[B+10>>1]|0,k)|0)+32|0)>>>6;b[D+12>>1]=((ca(e[B+12>>1]|0,k)|0)+32|0)>>>6;b[D+14>>1]=((ca(e[B+14>>1]|0,k)|0)+32|0)>>>6;l=C+1|0;if((l|0)<(f|0)){B=B+(g<<1)|0;C=l;D=D+(g<<1)|0}else{break}}return}D=(j|0)!=0?g:1;if((f|0)<=0){return}j=D+1|0;C=D+2|0;B=D+3|0;l=D+4|0;t=D+5|0;s=D+6|0;c=D+7|0;r=a;a=0;q=i;while(1){i=ca(e[r>>1]|0,k)|0;b[q>>1]=(i+32+(ca(e[r+(D<<1)>>1]|0,u)|0)|0)>>>6;i=ca(e[r+2>>1]|0,k)|0;b[q+2>>1]=(i+32+(ca(e[r+(j<<1)>>1]|0,u)|0)|0)>>>6;i=ca(e[r+4>>1]|0,k)|0;b[q+4>>1]=(i+32+(ca(e[r+(C<<1)>>1]|0,u)|0)|0)>>>6;i=ca(e[r+6>>1]|0,k)|0;b[q+6>>1]=(i+32+(ca(e[r+(B<<1)>>1]|0,u)|0)|0)>>>6;i=ca(e[r+8>>1]|0,k)|0;b[q+8>>1]=(i+32+(ca(e[r+(l<<1)>>1]|0,u)|0)|0)>>>6;i=ca(e[r+10>>1]|0,k)|0;b[q+10>>1]=(i+32+(ca(e[r+(t<<1)>>1]|0,u)|0)|0)>>>6;i=ca(e[r+12>>1]|0,k)|0;b[q+12>>1]=(i+32+(ca(e[r+(s<<1)>>1]|0,u)|0)|0)>>>6;i=ca(e[r+14>>1]|0,k)|0;b[q+14>>1]=(i+32+(ca(e[r+(c<<1)>>1]|0,u)|0)|0)>>>6;i=a+1|0;if((i|0)<(f|0)){r=r+(g<<1)|0;a=i;q=q+(g<<1)|0}else{break}}return}function Oia(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ca(j,c)|0;l=ca(j,g)|0;j=ca(c,h)|0;c=ca(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=g+3|0;n=g+4|0;o=a;p=0;q=i;while(1){r=ca(e[o>>1]|0,k)|0;s=o+2|0;t=ca(e[s>>1]|0,l)|0;u=o+(g<<1)|0;v=ca(e[u>>1]|0,j)|0;w=o+(d<<1)|0;b[q>>1]=(r+32+t+v+(ca(e[w>>1]|0,c)|0)|0)>>>6;v=ca(e[s>>1]|0,k)|0;s=o+4|0;t=ca(e[s>>1]|0,l)|0;r=ca(e[w>>1]|0,j)|0;w=o+(h<<1)|0;b[q+2>>1]=(v+32+t+r+(ca(e[w>>1]|0,c)|0)|0)>>>6;r=ca(e[s>>1]|0,k)|0;s=o+6|0;t=ca(e[s>>1]|0,l)|0;v=ca(e[w>>1]|0,j)|0;w=o+(m<<1)|0;b[q+4>>1]=(r+32+t+v+(ca(e[w>>1]|0,c)|0)|0)>>>6;v=ca(e[s>>1]|0,k)|0;s=ca(e[o+8>>1]|0,l)|0;t=ca(e[w>>1]|0,j)|0;b[q+6>>1]=(v+32+s+t+(ca(e[o+(n<<1)>>1]|0,c)|0)|0)>>>6;t=p+1|0;if((t|0)<(f|0)){o=u;p=t;q=q+(g<<1)|0}else{break}}return}q=l+j|0;if((q|0)==0){if((f|0)>0){x=a;y=0;z=i}else{return}while(1){b[z>>1]=((ca(e[x>>1]|0,k)|0)+32|0)>>>6;b[z+2>>1]=((ca(e[x+2>>1]|0,k)|0)+32|0)>>>6;b[z+4>>1]=((ca(e[x+4>>1]|0,k)|0)+32|0)>>>6;b[z+6>>1]=((ca(e[x+6>>1]|0,k)|0)+32|0)>>>6;l=y+1|0;if((l|0)<(f|0)){x=x+(g<<1)|0;y=l;z=z+(g<<1)|0}else{break}}return}z=(j|0)!=0?g:1;if((f|0)<=0){return}j=z+1|0;y=z+2|0;x=z+3|0;l=a;a=0;p=i;while(1){i=ca(e[l>>1]|0,k)|0;b[p>>1]=(i+32+(ca(e[l+(z<<1)>>1]|0,q)|0)|0)>>>6;i=ca(e[l+2>>1]|0,k)|0;b[p+2>>1]=(i+32+(ca(e[l+(j<<1)>>1]|0,q)|0)|0)>>>6;i=ca(e[l+4>>1]|0,k)|0;b[p+4>>1]=(i+32+(ca(e[l+(y<<1)>>1]|0,q)|0)|0)>>>6;i=ca(e[l+6>>1]|0,k)|0;b[p+6>>1]=(i+32+(ca(e[l+(x<<1)>>1]|0,q)|0)|0)>>>6;i=a+1|0;if((i|0)<(f|0)){l=l+(g<<1)|0;a=i;p=p+(g<<1)|0}else{break}}return}function Pia(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ca(j,c)|0;l=ca(j,g)|0;j=ca(c,h)|0;c=ca(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=a;n=0;o=i;while(1){p=ca(e[m>>1]|0,k)|0;q=m+2|0;r=ca(e[q>>1]|0,l)|0;s=m+(g<<1)|0;t=ca(e[s>>1]|0,j)|0;u=m+(d<<1)|0;b[o>>1]=(p+32+r+t+(ca(e[u>>1]|0,c)|0)|0)>>>6;t=ca(e[q>>1]|0,k)|0;q=ca(e[m+4>>1]|0,l)|0;r=ca(e[u>>1]|0,j)|0;b[o+2>>1]=(t+32+q+r+(ca(e[m+(h<<1)>>1]|0,c)|0)|0)>>>6;r=n+1|0;if((r|0)<(f|0)){m=s;n=r;o=o+(g<<1)|0}else{break}}return}o=l+j|0;if((o|0)==0){if((f|0)>0){v=a;w=0;x=i}else{return}while(1){b[x>>1]=((ca(e[v>>1]|0,k)|0)+32|0)>>>6;b[x+2>>1]=((ca(e[v+2>>1]|0,k)|0)+32|0)>>>6;l=w+1|0;if((l|0)<(f|0)){v=v+(g<<1)|0;w=l;x=x+(g<<1)|0}else{break}}return}x=(j|0)!=0?g:1;if((f|0)<=0){return}j=x+1|0;w=a;a=0;v=i;while(1){i=ca(e[w>>1]|0,k)|0;b[v>>1]=(i+32+(ca(e[w+(x<<1)>>1]|0,o)|0)|0)>>>6;i=ca(e[w+2>>1]|0,k)|0;b[v+2>>1]=(i+32+(ca(e[w+(j<<1)>>1]|0,o)|0)|0)>>>6;i=a+1|0;if((i|0)<(f|0)){w=w+(g<<1)|0;a=i;v=v+(g<<1)|0}else{break}}return}function Qia(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ca(j,c)|0;l=ca(j,g)|0;j=ca(c,h)|0;c=ca(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=a;m=0;n=i;while(1){o=ca(e[h>>1]|0,k)|0;p=ca(e[h+2>>1]|0,l)|0;q=h+(g<<1)|0;r=ca(e[q>>1]|0,j)|0;b[n>>1]=(o+32+p+r+(ca(e[h+(d<<1)>>1]|0,c)|0)|0)>>>6;r=m+1|0;if((r|0)<(f|0)){h=q;m=r;n=n+(g<<1)|0}else{break}}return}n=l+j|0;if((n|0)==0){if((f|0)>0){s=a;t=0;u=i}else{return}while(1){b[u>>1]=((ca(e[s>>1]|0,k)|0)+32|0)>>>6;l=t+1|0;if((l|0)<(f|0)){s=s+(g<<1)|0;t=l;u=u+(g<<1)|0}else{break}}return}else{u=(j|0)!=0?g:1;if((f|0)>0){v=a;w=0;x=i}else{return}while(1){i=ca(e[v>>1]|0,k)|0;b[x>>1]=(i+32+(ca(e[v+(u<<1)>>1]|0,n)|0)|0)>>>6;i=w+1|0;if((i|0)<(f|0)){v=v+(g<<1)|0;w=i;x=x+(g<<1)|0}else{break}}return}}function Ria(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ca(j,c)|0;l=ca(j,g)|0;j=ca(c,h)|0;c=ca(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=g+3|0;n=g+4|0;o=g+5|0;p=g+6|0;q=g+7|0;r=g+8|0;s=a;t=0;u=i;while(1){v=ca(e[s>>1]|0,k)|0;w=s+2|0;x=ca(e[w>>1]|0,l)|0;y=s+(g<<1)|0;z=ca(e[y>>1]|0,j)|0;A=s+(d<<1)|0;b[u>>1]=((e[u>>1]|0)+1+((v+32+x+z+(ca(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;z=u+2|0;x=ca(e[w>>1]|0,k)|0;w=s+4|0;v=ca(e[w>>1]|0,l)|0;B=ca(e[A>>1]|0,j)|0;A=s+(h<<1)|0;b[z>>1]=((e[z>>1]|0)+1+((x+32+v+B+(ca(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;B=u+4|0;v=ca(e[w>>1]|0,k)|0;w=s+6|0;x=ca(e[w>>1]|0,l)|0;z=ca(e[A>>1]|0,j)|0;A=s+(m<<1)|0;b[B>>1]=((e[B>>1]|0)+1+((v+32+x+z+(ca(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;z=u+6|0;x=ca(e[w>>1]|0,k)|0;w=s+8|0;v=ca(e[w>>1]|0,l)|0;B=ca(e[A>>1]|0,j)|0;A=s+(n<<1)|0;b[z>>1]=((e[z>>1]|0)+1+((x+32+v+B+(ca(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;B=u+8|0;v=ca(e[w>>1]|0,k)|0;w=s+10|0;x=ca(e[w>>1]|0,l)|0;z=ca(e[A>>1]|0,j)|0;A=s+(o<<1)|0;b[B>>1]=((e[B>>1]|0)+1+((v+32+x+z+(ca(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;z=u+10|0;x=ca(e[w>>1]|0,k)|0;w=s+12|0;v=ca(e[w>>1]|0,l)|0;B=ca(e[A>>1]|0,j)|0;A=s+(p<<1)|0;b[z>>1]=((e[z>>1]|0)+1+((x+32+v+B+(ca(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;B=u+12|0;v=ca(e[w>>1]|0,k)|0;w=s+14|0;x=ca(e[w>>1]|0,l)|0;z=ca(e[A>>1]|0,j)|0;A=s+(q<<1)|0;b[B>>1]=((e[B>>1]|0)+1+((v+32+x+z+(ca(e[A>>1]|0,c)|0)|0)>>>6)|0)>>>1;z=u+14|0;x=ca(e[w>>1]|0,k)|0;w=ca(e[s+16>>1]|0,l)|0;v=ca(e[A>>1]|0,j)|0;b[z>>1]=((e[z>>1]|0)+1+((x+32+w+v+(ca(e[s+(r<<1)>>1]|0,c)|0)|0)>>>6)|0)>>>1;v=t+1|0;if((v|0)<(f|0)){s=y;t=v;u=u+(g<<1)|0}else{break}}return}u=l+j|0;if((u|0)==0){if((f|0)>0){C=a;D=0;E=i}else{return}while(1){b[E>>1]=((e[E>>1]|0)+1+(((ca(e[C>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+2|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[C+2>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+4|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[C+4>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+6|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[C+6>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+8|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[C+8>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+10|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[C+10>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+12|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[C+12>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+14|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[C+14>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=D+1|0;if((l|0)<(f|0)){C=C+(g<<1)|0;D=l;E=E+(g<<1)|0}else{break}}return}E=(j|0)!=0?g:1;if((f|0)<=0){return}j=E+1|0;D=E+2|0;C=E+3|0;l=E+4|0;t=E+5|0;s=E+6|0;c=E+7|0;r=a;a=0;q=i;while(1){i=ca(e[r>>1]|0,k)|0;b[q>>1]=((e[q>>1]|0)+1+((i+32+(ca(e[r+(E<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;i=q+2|0;p=ca(e[r+2>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((p+32+(ca(e[r+(j<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;p=q+4|0;i=ca(e[r+4>>1]|0,k)|0;b[p>>1]=((e[p>>1]|0)+1+((i+32+(ca(e[r+(D<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;i=q+6|0;p=ca(e[r+6>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((p+32+(ca(e[r+(C<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;p=q+8|0;i=ca(e[r+8>>1]|0,k)|0;b[p>>1]=((e[p>>1]|0)+1+((i+32+(ca(e[r+(l<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;i=q+10|0;p=ca(e[r+10>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((p+32+(ca(e[r+(t<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;p=q+12|0;i=ca(e[r+12>>1]|0,k)|0;b[p>>1]=((e[p>>1]|0)+1+((i+32+(ca(e[r+(s<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;i=q+14|0;p=ca(e[r+14>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((p+32+(ca(e[r+(c<<1)>>1]|0,u)|0)|0)>>>6)|0)>>>1;p=a+1|0;if((p|0)<(f|0)){r=r+(g<<1)|0;a=p;q=q+(g<<1)|0}else{break}}return}function Sia(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ca(j,c)|0;l=ca(j,g)|0;j=ca(c,h)|0;c=ca(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=g+3|0;n=g+4|0;o=a;p=0;q=i;while(1){r=ca(e[o>>1]|0,k)|0;s=o+2|0;t=ca(e[s>>1]|0,l)|0;u=o+(g<<1)|0;v=ca(e[u>>1]|0,j)|0;w=o+(d<<1)|0;b[q>>1]=((e[q>>1]|0)+1+((r+32+t+v+(ca(e[w>>1]|0,c)|0)|0)>>>6)|0)>>>1;v=q+2|0;t=ca(e[s>>1]|0,k)|0;s=o+4|0;r=ca(e[s>>1]|0,l)|0;x=ca(e[w>>1]|0,j)|0;w=o+(h<<1)|0;b[v>>1]=((e[v>>1]|0)+1+((t+32+r+x+(ca(e[w>>1]|0,c)|0)|0)>>>6)|0)>>>1;x=q+4|0;r=ca(e[s>>1]|0,k)|0;s=o+6|0;t=ca(e[s>>1]|0,l)|0;v=ca(e[w>>1]|0,j)|0;w=o+(m<<1)|0;b[x>>1]=((e[x>>1]|0)+1+((r+32+t+v+(ca(e[w>>1]|0,c)|0)|0)>>>6)|0)>>>1;v=q+6|0;t=ca(e[s>>1]|0,k)|0;s=ca(e[o+8>>1]|0,l)|0;r=ca(e[w>>1]|0,j)|0;b[v>>1]=((e[v>>1]|0)+1+((t+32+s+r+(ca(e[o+(n<<1)>>1]|0,c)|0)|0)>>>6)|0)>>>1;r=p+1|0;if((r|0)<(f|0)){o=u;p=r;q=q+(g<<1)|0}else{break}}return}q=l+j|0;if((q|0)==0){if((f|0)>0){y=a;z=0;A=i}else{return}while(1){b[A>>1]=((e[A>>1]|0)+1+(((ca(e[y>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+2|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[y+2>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+4|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[y+4>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+6|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[y+6>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=z+1|0;if((l|0)<(f|0)){y=y+(g<<1)|0;z=l;A=A+(g<<1)|0}else{break}}return}A=(j|0)!=0?g:1;if((f|0)<=0){return}j=A+1|0;z=A+2|0;y=A+3|0;l=a;a=0;p=i;while(1){i=ca(e[l>>1]|0,k)|0;b[p>>1]=((e[p>>1]|0)+1+((i+32+(ca(e[l+(A<<1)>>1]|0,q)|0)|0)>>>6)|0)>>>1;i=p+2|0;o=ca(e[l+2>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((o+32+(ca(e[l+(j<<1)>>1]|0,q)|0)|0)>>>6)|0)>>>1;o=p+4|0;i=ca(e[l+4>>1]|0,k)|0;b[o>>1]=((e[o>>1]|0)+1+((i+32+(ca(e[l+(z<<1)>>1]|0,q)|0)|0)>>>6)|0)>>>1;i=p+6|0;o=ca(e[l+6>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((o+32+(ca(e[l+(y<<1)>>1]|0,q)|0)|0)>>>6)|0)>>>1;o=a+1|0;if((o|0)<(f|0)){l=l+(g<<1)|0;a=o;p=p+(g<<1)|0}else{break}}return}function Tia(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ca(j,c)|0;l=ca(j,g)|0;j=ca(c,h)|0;c=ca(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=g+2|0;m=a;n=0;o=i;while(1){p=ca(e[m>>1]|0,k)|0;q=m+2|0;r=ca(e[q>>1]|0,l)|0;s=m+(g<<1)|0;t=ca(e[s>>1]|0,j)|0;u=m+(d<<1)|0;b[o>>1]=((e[o>>1]|0)+1+((p+32+r+t+(ca(e[u>>1]|0,c)|0)|0)>>>6)|0)>>>1;t=o+2|0;r=ca(e[q>>1]|0,k)|0;q=ca(e[m+4>>1]|0,l)|0;p=ca(e[u>>1]|0,j)|0;b[t>>1]=((e[t>>1]|0)+1+((r+32+q+p+(ca(e[m+(h<<1)>>1]|0,c)|0)|0)>>>6)|0)>>>1;p=n+1|0;if((p|0)<(f|0)){m=s;n=p;o=o+(g<<1)|0}else{break}}return}o=l+j|0;if((o|0)==0){if((f|0)>0){v=a;w=0;x=i}else{return}while(1){b[x>>1]=((e[x>>1]|0)+1+(((ca(e[v>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=x+2|0;b[l>>1]=((e[l>>1]|0)+1+(((ca(e[v+2>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=w+1|0;if((l|0)<(f|0)){v=v+(g<<1)|0;w=l;x=x+(g<<1)|0}else{break}}return}x=(j|0)!=0?g:1;if((f|0)<=0){return}j=x+1|0;w=a;a=0;v=i;while(1){i=ca(e[w>>1]|0,k)|0;b[v>>1]=((e[v>>1]|0)+1+((i+32+(ca(e[w+(x<<1)>>1]|0,o)|0)|0)>>>6)|0)>>>1;i=v+2|0;l=ca(e[w+2>>1]|0,k)|0;b[i>>1]=((e[i>>1]|0)+1+((l+32+(ca(e[w+(j<<1)>>1]|0,o)|0)|0)>>>6)|0)>>>1;l=a+1|0;if((l|0)<(f|0)){w=w+(g<<1)|0;a=l;v=v+(g<<1)|0}else{break}}return}function Uia(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=a;a=c;c=8-g|0;j=8-h|0;k=ca(j,c)|0;l=ca(j,g)|0;j=ca(c,h)|0;c=ca(h,g)|0;g=d>>1;if((c|0)!=0){if((f|0)<=0){return}d=g+1|0;h=a;m=0;n=i;while(1){o=ca(e[h>>1]|0,k)|0;p=ca(e[h+2>>1]|0,l)|0;q=h+(g<<1)|0;r=ca(e[q>>1]|0,j)|0;b[n>>1]=((e[n>>1]|0)+1+((o+32+p+r+(ca(e[h+(d<<1)>>1]|0,c)|0)|0)>>>6)|0)>>>1;r=m+1|0;if((r|0)<(f|0)){h=q;m=r;n=n+(g<<1)|0}else{break}}return}n=l+j|0;if((n|0)==0){if((f|0)>0){s=a;t=0;u=i}else{return}while(1){b[u>>1]=((e[u>>1]|0)+1+(((ca(e[s>>1]|0,k)|0)+32|0)>>>6)|0)>>>1;l=t+1|0;if((l|0)<(f|0)){s=s+(g<<1)|0;t=l;u=u+(g<<1)|0}else{break}}return}else{u=(j|0)!=0?g:1;if((f|0)>0){v=a;w=0;x=i}else{return}while(1){i=ca(e[v>>1]|0,k)|0;b[x>>1]=((e[x>>1]|0)+1+((i+32+(ca(e[v+(u<<1)>>1]|0,n)|0)|0)>>>6)|0)>>>1;i=w+1|0;if((i|0)<(f|0)){v=v+(g<<1)|0;w=i;x=x+(g<<1)|0}else{break}}return}}function Via(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=e+5|0;p=e+6|0;q=e+7|0;r=e+8|0;s=c;t=0;u=b;while(1){v=ca(d[s]|0,k)|0;w=s+1|0;x=ca(d[w]|0,l)|0;y=s+e|0;z=ca(d[y]|0,j)|0;A=s+g|0;a[u]=(v+32+x+z+(ca(d[A]|0,i)|0)|0)>>>6;z=ca(d[w]|0,k)|0;w=s+2|0;x=ca(d[w]|0,l)|0;v=ca(d[A]|0,j)|0;A=s+h|0;a[u+1|0]=(z+32+x+v+(ca(d[A]|0,i)|0)|0)>>>6;v=ca(d[w]|0,k)|0;w=s+3|0;x=ca(d[w]|0,l)|0;z=ca(d[A]|0,j)|0;A=s+m|0;a[u+2|0]=(v+32+x+z+(ca(d[A]|0,i)|0)|0)>>>6;z=ca(d[w]|0,k)|0;w=s+4|0;x=ca(d[w]|0,l)|0;v=ca(d[A]|0,j)|0;A=s+n|0;a[u+3|0]=(z+32+x+v+(ca(d[A]|0,i)|0)|0)>>>6;v=ca(d[w]|0,k)|0;w=s+5|0;x=ca(d[w]|0,l)|0;z=ca(d[A]|0,j)|0;A=s+o|0;a[u+4|0]=(v+32+x+z+(ca(d[A]|0,i)|0)|0)>>>6;z=ca(d[w]|0,k)|0;w=s+6|0;x=ca(d[w]|0,l)|0;v=ca(d[A]|0,j)|0;A=s+p|0;a[u+5|0]=(z+32+x+v+(ca(d[A]|0,i)|0)|0)>>>6;v=ca(d[w]|0,k)|0;w=s+7|0;x=ca(d[w]|0,l)|0;z=ca(d[A]|0,j)|0;A=s+q|0;a[u+6|0]=(v+32+x+z+(ca(d[A]|0,i)|0)|0)>>>6;z=ca(d[w]|0,k)|0;w=ca(d[s+8|0]|0,l)|0;x=ca(d[A]|0,j)|0;a[u+7|0]=(z+32+w+x+(ca(d[s+r|0]|0,i)|0)|0)>>>6;x=t+1|0;if((x|0)<(f|0)){s=y;t=x;u=u+e|0}else{break}}return}u=l+j|0;if((u|0)==0){if((f|0)>0){B=c;C=0;D=b}else{return}while(1){a[D]=((ca(d[B]|0,k)|0)+32|0)>>>6;a[D+1|0]=((ca(d[B+1|0]|0,k)|0)+32|0)>>>6;a[D+2|0]=((ca(d[B+2|0]|0,k)|0)+32|0)>>>6;a[D+3|0]=((ca(d[B+3|0]|0,k)|0)+32|0)>>>6;a[D+4|0]=((ca(d[B+4|0]|0,k)|0)+32|0)>>>6;a[D+5|0]=((ca(d[B+5|0]|0,k)|0)+32|0)>>>6;a[D+6|0]=((ca(d[B+6|0]|0,k)|0)+32|0)>>>6;a[D+7|0]=((ca(d[B+7|0]|0,k)|0)+32|0)>>>6;l=C+1|0;if((l|0)<(f|0)){B=B+e|0;C=l;D=D+e|0}else{break}}return}D=(j|0)!=0?e:1;if((f|0)<=0){return}j=D+1|0;C=D+2|0;B=D+3|0;l=D+4|0;t=D+5|0;s=D+6|0;i=D+7|0;r=c;c=0;q=b;while(1){b=ca(d[r]|0,k)|0;a[q]=(b+32+(ca(d[r+D|0]|0,u)|0)|0)>>>6;b=ca(d[r+1|0]|0,k)|0;a[q+1|0]=(b+32+(ca(d[r+j|0]|0,u)|0)|0)>>>6;b=ca(d[r+2|0]|0,k)|0;a[q+2|0]=(b+32+(ca(d[r+C|0]|0,u)|0)|0)>>>6;b=ca(d[r+3|0]|0,k)|0;a[q+3|0]=(b+32+(ca(d[r+B|0]|0,u)|0)|0)>>>6;b=ca(d[r+4|0]|0,k)|0;a[q+4|0]=(b+32+(ca(d[r+l|0]|0,u)|0)|0)>>>6;b=ca(d[r+5|0]|0,k)|0;a[q+5|0]=(b+32+(ca(d[r+t|0]|0,u)|0)|0)>>>6;b=ca(d[r+6|0]|0,k)|0;a[q+6|0]=(b+32+(ca(d[r+s|0]|0,u)|0)|0)>>>6;b=ca(d[r+7|0]|0,k)|0;a[q+7|0]=(b+32+(ca(d[r+i|0]|0,u)|0)|0)>>>6;b=c+1|0;if((b|0)<(f|0)){r=r+e|0;c=b;q=q+e|0}else{break}}return}function Wia(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=c;p=0;q=b;while(1){r=ca(d[o]|0,k)|0;s=o+1|0;t=ca(d[s]|0,l)|0;u=o+e|0;v=ca(d[u]|0,j)|0;w=o+g|0;a[q]=(r+32+t+v+(ca(d[w]|0,i)|0)|0)>>>6;v=ca(d[s]|0,k)|0;s=o+2|0;t=ca(d[s]|0,l)|0;r=ca(d[w]|0,j)|0;w=o+h|0;a[q+1|0]=(v+32+t+r+(ca(d[w]|0,i)|0)|0)>>>6;r=ca(d[s]|0,k)|0;s=o+3|0;t=ca(d[s]|0,l)|0;v=ca(d[w]|0,j)|0;w=o+m|0;a[q+2|0]=(r+32+t+v+(ca(d[w]|0,i)|0)|0)>>>6;v=ca(d[s]|0,k)|0;s=ca(d[o+4|0]|0,l)|0;t=ca(d[w]|0,j)|0;a[q+3|0]=(v+32+s+t+(ca(d[o+n|0]|0,i)|0)|0)>>>6;t=p+1|0;if((t|0)<(f|0)){o=u;p=t;q=q+e|0}else{break}}return}q=l+j|0;if((q|0)==0){if((f|0)>0){x=c;y=0;z=b}else{return}while(1){a[z]=((ca(d[x]|0,k)|0)+32|0)>>>6;a[z+1|0]=((ca(d[x+1|0]|0,k)|0)+32|0)>>>6;a[z+2|0]=((ca(d[x+2|0]|0,k)|0)+32|0)>>>6;a[z+3|0]=((ca(d[x+3|0]|0,k)|0)+32|0)>>>6;l=y+1|0;if((l|0)<(f|0)){x=x+e|0;y=l;z=z+e|0}else{break}}return}z=(j|0)!=0?e:1;if((f|0)<=0){return}j=z+1|0;y=z+2|0;x=z+3|0;l=c;c=0;p=b;while(1){b=ca(d[l]|0,k)|0;a[p]=(b+32+(ca(d[l+z|0]|0,q)|0)|0)>>>6;b=ca(d[l+1|0]|0,k)|0;a[p+1|0]=(b+32+(ca(d[l+j|0]|0,q)|0)|0)>>>6;b=ca(d[l+2|0]|0,k)|0;a[p+2|0]=(b+32+(ca(d[l+y|0]|0,q)|0)|0)>>>6;b=ca(d[l+3|0]|0,k)|0;a[p+3|0]=(b+32+(ca(d[l+x|0]|0,q)|0)|0)>>>6;b=c+1|0;if((b|0)<(f|0)){l=l+e|0;c=b;p=p+e|0}else{break}}return}function Xia(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=c;n=0;o=b;while(1){p=ca(d[m]|0,k)|0;q=m+1|0;r=ca(d[q]|0,l)|0;s=m+e|0;t=ca(d[s]|0,j)|0;u=m+g|0;a[o]=(p+32+r+t+(ca(d[u]|0,i)|0)|0)>>>6;t=ca(d[q]|0,k)|0;q=ca(d[m+2|0]|0,l)|0;r=ca(d[u]|0,j)|0;a[o+1|0]=(t+32+q+r+(ca(d[m+h|0]|0,i)|0)|0)>>>6;r=n+1|0;if((r|0)<(f|0)){m=s;n=r;o=o+e|0}else{break}}return}o=l+j|0;if((o|0)==0){if((f|0)>0){v=c;w=0;x=b}else{return}while(1){a[x]=((ca(d[v]|0,k)|0)+32|0)>>>6;a[x+1|0]=((ca(d[v+1|0]|0,k)|0)+32|0)>>>6;l=w+1|0;if((l|0)<(f|0)){v=v+e|0;w=l;x=x+e|0}else{break}}return}x=(j|0)!=0?e:1;if((f|0)<=0){return}j=x+1|0;w=c;c=0;v=b;while(1){b=ca(d[w]|0,k)|0;a[v]=(b+32+(ca(d[w+x|0]|0,o)|0)|0)>>>6;b=ca(d[w+1|0]|0,k)|0;a[v+1|0]=(b+32+(ca(d[w+j|0]|0,o)|0)|0)>>>6;b=c+1|0;if((b|0)<(f|0)){w=w+e|0;c=b;v=v+e|0}else{break}}return}function Yia(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=c;m=0;n=b;while(1){o=ca(d[h]|0,k)|0;p=ca(d[h+1|0]|0,l)|0;q=h+e|0;r=ca(d[q]|0,j)|0;a[n]=(o+32+p+r+(ca(d[h+g|0]|0,i)|0)|0)>>>6;r=m+1|0;if((r|0)<(f|0)){h=q;m=r;n=n+e|0}else{break}}return}n=l+j|0;if((n|0)==0){if((f|0)>0){s=c;t=0;u=b}else{return}while(1){a[u]=((ca(d[s]|0,k)|0)+32|0)>>>6;l=t+1|0;if((l|0)<(f|0)){s=s+e|0;t=l;u=u+e|0}else{break}}return}else{u=(j|0)!=0?e:1;if((f|0)>0){v=c;w=0;x=b}else{return}while(1){b=ca(d[v]|0,k)|0;a[x]=(b+32+(ca(d[v+u|0]|0,n)|0)|0)>>>6;b=w+1|0;if((b|0)<(f|0)){v=v+e|0;w=b;x=x+e|0}else{break}}return}}function Zia(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=e+5|0;p=e+6|0;q=e+7|0;r=e+8|0;s=c;t=0;u=b;while(1){v=ca(d[s]|0,k)|0;w=s+1|0;x=ca(d[w]|0,l)|0;y=s+e|0;z=ca(d[y]|0,j)|0;A=s+g|0;a[u]=((d[u]|0)+1+((v+32+x+z+(ca(d[A]|0,i)|0)|0)>>>6)|0)>>>1;z=u+1|0;x=ca(d[w]|0,k)|0;w=s+2|0;v=ca(d[w]|0,l)|0;B=ca(d[A]|0,j)|0;A=s+h|0;a[z]=((d[z]|0)+1+((x+32+v+B+(ca(d[A]|0,i)|0)|0)>>>6)|0)>>>1;B=u+2|0;v=ca(d[w]|0,k)|0;w=s+3|0;x=ca(d[w]|0,l)|0;z=ca(d[A]|0,j)|0;A=s+m|0;a[B]=((d[B]|0)+1+((v+32+x+z+(ca(d[A]|0,i)|0)|0)>>>6)|0)>>>1;z=u+3|0;x=ca(d[w]|0,k)|0;w=s+4|0;v=ca(d[w]|0,l)|0;B=ca(d[A]|0,j)|0;A=s+n|0;a[z]=((d[z]|0)+1+((x+32+v+B+(ca(d[A]|0,i)|0)|0)>>>6)|0)>>>1;B=u+4|0;v=ca(d[w]|0,k)|0;w=s+5|0;x=ca(d[w]|0,l)|0;z=ca(d[A]|0,j)|0;A=s+o|0;a[B]=((d[B]|0)+1+((v+32+x+z+(ca(d[A]|0,i)|0)|0)>>>6)|0)>>>1;z=u+5|0;x=ca(d[w]|0,k)|0;w=s+6|0;v=ca(d[w]|0,l)|0;B=ca(d[A]|0,j)|0;A=s+p|0;a[z]=((d[z]|0)+1+((x+32+v+B+(ca(d[A]|0,i)|0)|0)>>>6)|0)>>>1;B=u+6|0;v=ca(d[w]|0,k)|0;w=s+7|0;x=ca(d[w]|0,l)|0;z=ca(d[A]|0,j)|0;A=s+q|0;a[B]=((d[B]|0)+1+((v+32+x+z+(ca(d[A]|0,i)|0)|0)>>>6)|0)>>>1;z=u+7|0;x=ca(d[w]|0,k)|0;w=ca(d[s+8|0]|0,l)|0;v=ca(d[A]|0,j)|0;a[z]=((d[z]|0)+1+((x+32+w+v+(ca(d[s+r|0]|0,i)|0)|0)>>>6)|0)>>>1;v=t+1|0;if((v|0)<(f|0)){s=y;t=v;u=u+e|0}else{break}}return}u=l+j|0;if((u|0)==0){if((f|0)>0){C=c;D=0;E=b}else{return}while(1){a[E]=((d[E]|0)+1+(((ca(d[C]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+1|0;a[l]=((d[l]|0)+1+(((ca(d[C+1|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+2|0;a[l]=((d[l]|0)+1+(((ca(d[C+2|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+3|0;a[l]=((d[l]|0)+1+(((ca(d[C+3|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+4|0;a[l]=((d[l]|0)+1+(((ca(d[C+4|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+5|0;a[l]=((d[l]|0)+1+(((ca(d[C+5|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+6|0;a[l]=((d[l]|0)+1+(((ca(d[C+6|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=E+7|0;a[l]=((d[l]|0)+1+(((ca(d[C+7|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=D+1|0;if((l|0)<(f|0)){C=C+e|0;D=l;E=E+e|0}else{break}}return}E=(j|0)!=0?e:1;if((f|0)<=0){return}j=E+1|0;D=E+2|0;C=E+3|0;l=E+4|0;t=E+5|0;s=E+6|0;i=E+7|0;r=c;c=0;q=b;while(1){b=ca(d[r]|0,k)|0;a[q]=((d[q]|0)+1+((b+32+(ca(d[r+E|0]|0,u)|0)|0)>>>6)|0)>>>1;b=q+1|0;p=ca(d[r+1|0]|0,k)|0;a[b]=((d[b]|0)+1+((p+32+(ca(d[r+j|0]|0,u)|0)|0)>>>6)|0)>>>1;p=q+2|0;b=ca(d[r+2|0]|0,k)|0;a[p]=((d[p]|0)+1+((b+32+(ca(d[r+D|0]|0,u)|0)|0)>>>6)|0)>>>1;b=q+3|0;p=ca(d[r+3|0]|0,k)|0;a[b]=((d[b]|0)+1+((p+32+(ca(d[r+C|0]|0,u)|0)|0)>>>6)|0)>>>1;p=q+4|0;b=ca(d[r+4|0]|0,k)|0;a[p]=((d[p]|0)+1+((b+32+(ca(d[r+l|0]|0,u)|0)|0)>>>6)|0)>>>1;b=q+5|0;p=ca(d[r+5|0]|0,k)|0;a[b]=((d[b]|0)+1+((p+32+(ca(d[r+t|0]|0,u)|0)|0)>>>6)|0)>>>1;p=q+6|0;b=ca(d[r+6|0]|0,k)|0;a[p]=((d[p]|0)+1+((b+32+(ca(d[r+s|0]|0,u)|0)|0)>>>6)|0)>>>1;b=q+7|0;p=ca(d[r+7|0]|0,k)|0;a[b]=((d[b]|0)+1+((p+32+(ca(d[r+i|0]|0,u)|0)|0)>>>6)|0)>>>1;p=c+1|0;if((p|0)<(f|0)){r=r+e|0;c=p;q=q+e|0}else{break}}return}function _ia(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=e+3|0;n=e+4|0;o=c;p=0;q=b;while(1){r=ca(d[o]|0,k)|0;s=o+1|0;t=ca(d[s]|0,l)|0;u=o+e|0;v=ca(d[u]|0,j)|0;w=o+g|0;a[q]=((d[q]|0)+1+((r+32+t+v+(ca(d[w]|0,i)|0)|0)>>>6)|0)>>>1;v=q+1|0;t=ca(d[s]|0,k)|0;s=o+2|0;r=ca(d[s]|0,l)|0;x=ca(d[w]|0,j)|0;w=o+h|0;a[v]=((d[v]|0)+1+((t+32+r+x+(ca(d[w]|0,i)|0)|0)>>>6)|0)>>>1;x=q+2|0;r=ca(d[s]|0,k)|0;s=o+3|0;t=ca(d[s]|0,l)|0;v=ca(d[w]|0,j)|0;w=o+m|0;a[x]=((d[x]|0)+1+((r+32+t+v+(ca(d[w]|0,i)|0)|0)>>>6)|0)>>>1;v=q+3|0;t=ca(d[s]|0,k)|0;s=ca(d[o+4|0]|0,l)|0;r=ca(d[w]|0,j)|0;a[v]=((d[v]|0)+1+((t+32+s+r+(ca(d[o+n|0]|0,i)|0)|0)>>>6)|0)>>>1;r=p+1|0;if((r|0)<(f|0)){o=u;p=r;q=q+e|0}else{break}}return}q=l+j|0;if((q|0)==0){if((f|0)>0){y=c;z=0;A=b}else{return}while(1){a[A]=((d[A]|0)+1+(((ca(d[y]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+1|0;a[l]=((d[l]|0)+1+(((ca(d[y+1|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+2|0;a[l]=((d[l]|0)+1+(((ca(d[y+2|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=A+3|0;a[l]=((d[l]|0)+1+(((ca(d[y+3|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=z+1|0;if((l|0)<(f|0)){y=y+e|0;z=l;A=A+e|0}else{break}}return}A=(j|0)!=0?e:1;if((f|0)<=0){return}j=A+1|0;z=A+2|0;y=A+3|0;l=c;c=0;p=b;while(1){b=ca(d[l]|0,k)|0;a[p]=((d[p]|0)+1+((b+32+(ca(d[l+A|0]|0,q)|0)|0)>>>6)|0)>>>1;b=p+1|0;o=ca(d[l+1|0]|0,k)|0;a[b]=((d[b]|0)+1+((o+32+(ca(d[l+j|0]|0,q)|0)|0)>>>6)|0)>>>1;o=p+2|0;b=ca(d[l+2|0]|0,k)|0;a[o]=((d[o]|0)+1+((b+32+(ca(d[l+z|0]|0,q)|0)|0)>>>6)|0)>>>1;b=p+3|0;o=ca(d[l+3|0]|0,k)|0;a[b]=((d[b]|0)+1+((o+32+(ca(d[l+y|0]|0,q)|0)|0)>>>6)|0)>>>1;o=c+1|0;if((o|0)<(f|0)){l=l+e|0;c=o;p=p+e|0}else{break}}return}function $ia(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=e+2|0;m=c;n=0;o=b;while(1){p=ca(d[m]|0,k)|0;q=m+1|0;r=ca(d[q]|0,l)|0;s=m+e|0;t=ca(d[s]|0,j)|0;u=m+g|0;a[o]=((d[o]|0)+1+((p+32+r+t+(ca(d[u]|0,i)|0)|0)>>>6)|0)>>>1;t=o+1|0;r=ca(d[q]|0,k)|0;q=ca(d[m+2|0]|0,l)|0;p=ca(d[u]|0,j)|0;a[t]=((d[t]|0)+1+((r+32+q+p+(ca(d[m+h|0]|0,i)|0)|0)>>>6)|0)>>>1;p=n+1|0;if((p|0)<(f|0)){m=s;n=p;o=o+e|0}else{break}}return}o=l+j|0;if((o|0)==0){if((f|0)>0){v=c;w=0;x=b}else{return}while(1){a[x]=((d[x]|0)+1+(((ca(d[v]|0,k)|0)+32|0)>>>6)|0)>>>1;l=x+1|0;a[l]=((d[l]|0)+1+(((ca(d[v+1|0]|0,k)|0)+32|0)>>>6)|0)>>>1;l=w+1|0;if((l|0)<(f|0)){v=v+e|0;w=l;x=x+e|0}else{break}}return}x=(j|0)!=0?e:1;if((f|0)<=0){return}j=x+1|0;w=c;c=0;v=b;while(1){b=ca(d[w]|0,k)|0;a[v]=((d[v]|0)+1+((b+32+(ca(d[w+x|0]|0,o)|0)|0)>>>6)|0)>>>1;b=v+1|0;l=ca(d[w+1|0]|0,k)|0;a[b]=((d[b]|0)+1+((l+32+(ca(d[w+j|0]|0,o)|0)|0)>>>6)|0)>>>1;l=c+1|0;if((l|0)<(f|0)){w=w+e|0;c=l;v=v+e|0}else{break}}return}function aja(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=8-g|0;j=8-h|0;k=ca(j,i)|0;l=ca(j,g)|0;j=ca(i,h)|0;i=ca(h,g)|0;if((i|0)!=0){if((f|0)<=0){return}g=e+1|0;h=c;m=0;n=b;while(1){o=ca(d[h]|0,k)|0;p=ca(d[h+1|0]|0,l)|0;q=h+e|0;r=ca(d[q]|0,j)|0;a[n]=((d[n]|0)+1+((o+32+p+r+(ca(d[h+g|0]|0,i)|0)|0)>>>6)|0)>>>1;r=m+1|0;if((r|0)<(f|0)){h=q;m=r;n=n+e|0}else{break}}return}n=l+j|0;if((n|0)==0){if((f|0)>0){s=c;t=0;u=b}else{return}while(1){a[u]=((d[u]|0)+1+(((ca(d[s]|0,k)|0)+32|0)>>>6)|0)>>>1;l=t+1|0;if((l|0)<(f|0)){s=s+e|0;t=l;u=u+e|0}else{break}}return}else{u=(j|0)!=0?e:1;if((f|0)>0){v=c;w=0;x=b}else{return}while(1){b=ca(d[v]|0,k)|0;a[x]=((d[x]|0)+1+((b+32+(ca(d[v+u|0]|0,n)|0)|0)>>>6)|0)>>>1;b=w+1|0;if((b|0)<(f|0)){v=v+e|0;w=b;x=x+e|0}else{break}}return}}function bja(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a+128|0;if((b-9|0)>>>0<8>>>0){c[f>>2]=244;c[a+124>>2]=1954}else{c[f>>2]=820;c[a+124>>2]=1390}if((b|0)==14){c[a+84>>2]=1968;c[a+88>>2]=2118;c[a+92>>2]=974;c[a+96>>2]=1194;c[a+100>>2]=12;c[a+104>>2]=224;f=(d|0)<2;c[a+108>>2]=f?32:330;c[a+112>>2]=590;c[a+116>>2]=1238;c[a+120>>2]=f?672:562;c[a>>2]=100;c[a+4>>2]=174;c[a+8>>2]=50;c[a+12>>2]=326;c[a+16>>2]=108;c[a+20>>2]=6;c[a+24>>2]=22;c[a+28>>2]=120;c[a+32>>2]=232;c[a+36>>2]=668;c[a+40>>2]=36;c[a+44>>2]=934;c[a+48>>2]=832;c[a+52>>2]=484;c[a+56>>2]=416;c[a+60>>2]=f?40:118;c[a+64>>2]=f?570:500;c[a+68>>2]=428;c[a+72>>2]=f?54:410;c[a+76>>2]=f?594:674;c[a+80>>2]=0;g=a+132|0;c[g>>2]=120;i=e;return}else if((b|0)==12){c[a+84>>2]=1662;c[a+88>>2]=1816;c[a+92>>2]=2104;c[a+96>>2]=1536;c[a+100>>2]=184;c[a+104>>2]=332;f=(d|0)<2;c[a+108>>2]=f?644:166;c[a+112>>2]=486;c[a+116>>2]=1858;c[a+120>>2]=f?602:364;c[a>>2]=12;c[a+4>>2]=220;c[a+8>>2]=294;c[a+12>>2]=234;c[a+16>>2]=84;c[a+20>>2]=116;c[a+24>>2]=136;c[a+28>>2]=20;c[a+32>>2]=536;c[a+36>>2]=516;c[a+40>>2]=586;c[a+44>>2]=32;c[a+48>>2]=60;c[a+52>>2]=588;c[a+56>>2]=218;c[a+60>>2]=f?210:642;c[a+64>>2]=f?10:376;c[a+68>>2]=692;c[a+72>>2]=f?960:668;c[a+76>>2]=f?142:972;c[a+80>>2]=0;g=a+132|0;c[g>>2]=120;i=e;return}else if((b|0)==10){c[a+84>>2]=1056;c[a+88>>2]=910;c[a+92>>2]=2172;c[a+96>>2]=954;c[a+100>>2]=370;c[a+104>>2]=168;f=(d|0)<2;c[a+108>>2]=f?628:672;c[a+112>>2]=650;c[a+116>>2]=42;c[a+120>>2]=f?342:212;c[a>>2]=284;c[a+4>>2]=314;c[a+8>>2]=18;c[a+12>>2]=146;c[a+16>>2]=4;c[a+20>>2]=70;c[a+24>>2]=76;c[a+28>>2]=62;c[a+32>>2]=680;c[a+36>>2]=316;c[a+40>>2]=404;c[a+44>>2]=816;c[a+48>>2]=278;c[a+52>>2]=878;c[a+56>>2]=46;c[a+60>>2]=f?414:658;c[a+64>>2]=f?104:196;c[a+68>>2]=982;c[a+72>>2]=f?550:280;c[a+76>>2]=f?114:170;c[a+80>>2]=0;g=a+132|0;c[g>>2]=120;i=e;return}else if((b|0)==9){c[a+84>>2]=560;c[a+88>>2]=28;c[a+92>>2]=1692;c[a+96>>2]=1556;c[a+100>>2]=276;c[a+104>>2]=488;f=(d|0)<2;c[a+108>>2]=f?278:288;c[a+112>>2]=492;c[a+116>>2]=1198;c[a+120>>2]=f?150:140;c[a>>2]=308;c[a+4>>2]=126;c[a+8>>2]=90;c[a+12>>2]=152;c[a+16>>2]=28;c[a+20>>2]=60;c[a+24>>2]=12;c[a+28>>2]=90;c[a+32>>2]=470;c[a+36>>2]=550;c[a+40>>2]=686;c[a+44>>2]=256;c[a+48>>2]=564;c[a+52>>2]=504;c[a+56>>2]=558;c[a+60>>2]=f?428:324;c[a+64>>2]=f?456:120;c[a+68>>2]=918;c[a+72>>2]=f?754:998;c[a+76>>2]=f?626:872;c[a+80>>2]=0;g=a+132|0;c[g>>2]=120;i=e;return}else{if((b|0)>=9){KIb(0,0,2540616,(b=i,i=i+24|0,c[b>>2]=2605136,c[b+8>>2]=2452624,c[b+16>>2]=177,b)|0);i=b;Hd()}c[a+84>>2]=2056;c[a+88>>2]=1514;c[a+92>>2]=756;c[a+96>>2]=1886;c[a+100>>2]=178;c[a+104>>2]=584;b=(d|0)<2;c[a+108>>2]=b?378:578;c[a+112>>2]=356;c[a+116>>2]=2136;c[a+120>>2]=b?568:564;c[a>>2]=202;c[a+4>>2]=106;c[a+8>>2]=44;c[a+12>>2]=86;c[a+16>>2]=102;c[a+20>>2]=74;c[a+24>>2]=94;c[a+28>>2]=118;c[a+32>>2]=138;c[a+36>>2]=446;c[a+40>>2]=438;c[a+44>>2]=382;c[a+48>>2]=908;c[a+52>>2]=914;c[a+56>>2]=636;c[a+60>>2]=b?154:156;c[a+64>>2]=b?624:398;c[a+68>>2]=740;c[a+72>>2]=b?852:200;c[a+76>>2]=b?776:1012;c[a+80>>2]=0;g=a+132|0;c[g>>2]=120;i=e;return}}function cja(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0;g=a;h=f>>>1;b[g>>1]=(e[g>>1]|0)+(c[d>>2]|0);f=a+2|0;b[f>>1]=(e[f>>1]|0)+(c[d+4>>2]|0);f=a+4|0;b[f>>1]=(e[f>>1]|0)+(c[d+8>>2]|0);f=a+6|0;b[f>>1]=(e[f>>1]|0)+(c[d+12>>2]|0);f=g+(h<<1)|0;b[f>>1]=(e[f>>1]|0)+(c[d+16>>2]|0);f=g+(h+1<<1)|0;b[f>>1]=(e[f>>1]|0)+(c[d+20>>2]|0);f=g+(h+2<<1)|0;b[f>>1]=(e[f>>1]|0)+(c[d+24>>2]|0);f=g+(h+3<<1)|0;b[f>>1]=(e[f>>1]|0)+(c[d+28>>2]|0);f=h<<1;a=g+(f<<1)|0;b[a>>1]=(e[a>>1]|0)+(c[d+32>>2]|0);a=g+((f|1)<<1)|0;b[a>>1]=(e[a>>1]|0)+(c[d+36>>2]|0);a=g+(f+2<<1)|0;b[a>>1]=(e[a>>1]|0)+(c[d+40>>2]|0);a=g+(f+3<<1)|0;b[a>>1]=(e[a>>1]|0)+(c[d+44>>2]|0);a=f+h|0;h=g+(a<<1)|0;b[h>>1]=(e[h>>1]|0)+(c[d+48>>2]|0);h=g+(a+1<<1)|0;b[h>>1]=(e[h>>1]|0)+(c[d+52>>2]|0);h=g+(a+2<<1)|0;b[h>>1]=(e[h>>1]|0)+(c[d+56>>2]|0);h=g+(a+3<<1)|0;b[h>>1]=(e[h>>1]|0)+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function dja(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=f>>>1;f=0;h=a;a=d;while(1){b[h>>1]=(e[h>>1]|0)+(c[a>>2]|0);i=h+2|0;b[i>>1]=(e[i>>1]|0)+(c[a+4>>2]|0);i=h+4|0;b[i>>1]=(e[i>>1]|0)+(c[a+8>>2]|0);i=h+6|0;b[i>>1]=(e[i>>1]|0)+(c[a+12>>2]|0);i=h+8|0;b[i>>1]=(e[i>>1]|0)+(c[a+16>>2]|0);i=h+10|0;b[i>>1]=(e[i>>1]|0)+(c[a+20>>2]|0);i=h+12|0;b[i>>1]=(e[i>>1]|0)+(c[a+24>>2]|0);i=h+14|0;b[i>>1]=(e[i>>1]|0)+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}mrc(d|0,0,256)|0;return}function eja(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0;a[c]=(a[c]|0)+(b[d>>1]&255);f=c+1|0;a[f]=(a[f]|0)+(b[d+2>>1]&255);f=c+2|0;a[f]=(a[f]|0)+(b[d+4>>1]&255);f=c+3|0;a[f]=(a[f]|0)+(b[d+6>>1]&255);f=c+e|0;a[f]=(a[f]|0)+(b[d+8>>1]&255);f=c+(e+1)|0;a[f]=(a[f]|0)+(b[d+10>>1]&255);f=c+(e+2)|0;a[f]=(a[f]|0)+(b[d+12>>1]&255);f=c+(e+3)|0;a[f]=(a[f]|0)+(b[d+14>>1]&255);f=e<<1;g=c+f|0;a[g]=(a[g]|0)+(b[d+16>>1]&255);g=c+(f|1)|0;a[g]=(a[g]|0)+(b[d+18>>1]&255);g=c+(f+2)|0;a[g]=(a[g]|0)+(b[d+20>>1]&255);g=c+(f+3)|0;a[g]=(a[g]|0)+(b[d+22>>1]&255);g=f+e|0;e=c+g|0;a[e]=(a[e]|0)+(b[d+24>>1]&255);e=c+(g+1)|0;a[e]=(a[e]|0)+(b[d+26>>1]&255);e=c+(g+2)|0;a[e]=(a[e]|0)+(b[d+28>>1]&255);e=c+(g+3)|0;a[e]=(a[e]|0)+(b[d+30>>1]&255);mrc(d|0,0,32)|0;return}function fja(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=0;g=c;c=d;while(1){a[g]=(a[g]|0)+(b[c>>1]&255);h=g+1|0;a[h]=(a[h]|0)+(b[c+2>>1]&255);h=g+2|0;a[h]=(a[h]|0)+(b[c+4>>1]&255);h=g+3|0;a[h]=(a[h]|0)+(b[c+6>>1]&255);h=g+4|0;a[h]=(a[h]|0)+(b[c+8>>1]&255);h=g+5|0;a[h]=(a[h]|0)+(b[c+10>>1]&255);h=g+6|0;a[h]=(a[h]|0)+(b[c+12>>1]&255);h=g+7|0;a[h]=(a[h]|0)+(b[c+14>>1]&255);h=f+1|0;if((h|0)<8){f=h;g=g+e|0;c=c+16|0}else{break}}mrc(d|0,0,128)|0;return}function gja(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c>>1;c=h<<f+1;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<512>>>0){m=a&65535}else{m=-a>>31&511}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){n=c&65535}else{n=-c>>31&511}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){o=c&65535}else{o=-c>>31&511}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){p=c&65535}else{p=-c>>31&511}b[a>>1]=p;a=l+8|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){q=c&65535}else{q=-c>>31&511}b[a>>1]=q;a=l+10|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[a>>1]=r;a=l+12|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){s=c&65535}else{s=-c>>31&511}b[a>>1]=s;a=l+14|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){t=c&65535}else{t=-c>>31&511}b[a>>1]=t;a=l+16|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){u=c&65535}else{u=-c>>31&511}b[a>>1]=u;a=l+18|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){v=c&65535}else{v=-c>>31&511}b[a>>1]=v;a=l+20|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){w=c&65535}else{w=-c>>31&511}b[a>>1]=w;a=l+22|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){x=c&65535}else{x=-c>>31&511}b[a>>1]=x;a=l+24|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){y=c&65535}else{y=-c>>31&511}b[a>>1]=y;a=l+26|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){z=c&65535}else{z=-c>>31&511}b[a>>1]=z;a=l+28|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){A=c&65535}else{A=-c>>31&511}b[a>>1]=A;a=l+30|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){B=c&65535}else{B=-c>>31&511}b[a>>1]=B;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function hja(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c>>1;c=h<<f+1;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<512>>>0){m=a&65535}else{m=-a>>31&511}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){n=c&65535}else{n=-c>>31&511}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){o=c&65535}else{o=-c>>31&511}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){p=c&65535}else{p=-c>>31&511}b[a>>1]=p;a=l+8|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){q=c&65535}else{q=-c>>31&511}b[a>>1]=q;a=l+10|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[a>>1]=r;a=l+12|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){s=c&65535}else{s=-c>>31&511}b[a>>1]=s;a=l+14|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){t=c&65535}else{t=-c>>31&511}b[a>>1]=t;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function ija(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c>>1;c=h<<f+1;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<512>>>0){m=a&65535}else{m=-a>>31&511}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){n=c&65535}else{n=-c>>31&511}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){o=c&65535}else{o=-c>>31&511}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){p=c&65535}else{p=-c>>31&511}b[a>>1]=p;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function jja(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c>>1;c=h<<f+1;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<512>>>0){m=a&65535}else{m=-a>>31&511}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<512>>>0){n=c&65535}else{n=-c>>31&511}b[a>>1]=n;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function kja(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=d>>1;d=(j<<1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){q=m&65535}else{q=-m>>31&511}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[m>>1]=r;m=ca(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){s=o&65535}else{s=-o>>31&511}b[c>>1]=s;c=ca(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){t=m&65535}else{t=-m>>31&511}b[o>>1]=t;o=ca(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){u=c&65535}else{u=-c>>31&511}b[m>>1]=u;m=ca(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){v=o&65535}else{v=-o>>31&511}b[c>>1]=v;c=ca(e[a+16>>1]|0,i)|0;o=l+16|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){w=m&65535}else{w=-m>>31&511}b[o>>1]=w;o=ca(e[a+18>>1]|0,i)|0;m=l+18|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){x=c&65535}else{x=-c>>31&511}b[m>>1]=x;m=ca(e[a+20>>1]|0,i)|0;c=l+20|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){y=o&65535}else{y=-o>>31&511}b[c>>1]=y;c=ca(e[a+22>>1]|0,i)|0;o=l+22|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){z=m&65535}else{z=-m>>31&511}b[o>>1]=z;o=ca(e[a+24>>1]|0,i)|0;m=l+24|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){A=c&65535}else{A=-c>>31&511}b[m>>1]=A;m=ca(e[a+26>>1]|0,i)|0;c=l+26|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){B=o&65535}else{B=-o>>31&511}b[c>>1]=B;c=ca(e[a+28>>1]|0,i)|0;o=l+28|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){C=m&65535}else{C=-m>>31&511}b[o>>1]=C;o=ca(e[a+30>>1]|0,i)|0;m=l+30|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){D=c&65535}else{D=-c>>31&511}b[m>>1]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function lja(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=d>>1;d=(j<<1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){q=m&65535}else{q=-m>>31&511}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[m>>1]=r;m=ca(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){s=o&65535}else{s=-o>>31&511}b[c>>1]=s;c=ca(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){t=m&65535}else{t=-m>>31&511}b[o>>1]=t;o=ca(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){u=c&65535}else{u=-c>>31&511}b[m>>1]=u;m=ca(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){v=o&65535}else{v=-o>>31&511}b[c>>1]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function mja(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=d>>1;d=(j<<1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){q=m&65535}else{q=-m>>31&511}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<512>>>0){r=c&65535}else{r=-c>>31&511}b[m>>1]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function nja(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=d>>1;d=(j<<1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<512>>>0){n=m&65535}else{n=-m>>31&511}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<512>>>0){p=o&65535}else{p=-o>>31&511}b[c>>1]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function oja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=d>>1;d=f<<1;f=g<<1;g=-i|0;j=i*-2|0;k=i*-3|0;l=i<<1;m=0;n=c;while(1){c=a[h+m|0]<<1;if((c|0)>=0){o=(c|0)==0;p=c|1;q=-c|0;r=0;s=n;while(1){t=s+(g<<1)|0;u=e[t>>1]|0;v=s+(j<<1)|0;w=e[v>>1]|0;x=e[s+(k<<1)>>1]|0;y=e[s>>1]|0;z=s+(i<<1)|0;A=e[z>>1]|0;B=e[s+(l<<1)>>1]|0;C=u-y|0;do{if((((C|0)>-1?C:-C|0)|0)<(d|0)){D=w-u|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=A-y|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=x-u|0;E=(((D|0)>-1?D:-D|0)|0)>=(f|0);if(E|o){F=E?c:p}else{E=((((u+1+y|0)>>>1)+x|0)>>>1)-w|0;if((E|0)<(q|0)){G=q}else{G=(E|0)>(c|0)?c:E}b[v>>1]=G+w;F=p}E=B-y|0;if((((E|0)>-1?E:-E|0)|0)<(f|0)){if(!o){E=((B+((u+1+y|0)>>>1)|0)>>>1)-A|0;if((E|0)<(q|0)){H=q}else{H=(E|0)>(c|0)?c:E}b[z>>1]=H+A}I=F+1|0}else{I=F}E=w+4-A+(y-u<<2)>>3;D=-I|0;if((E|0)<(D|0)){J=D}else{J=(E|0)>(I|0)?I:E}E=J+u|0;if(E>>>0<512>>>0){K=E&65535}else{K=-E>>31&511}b[t>>1]=K;E=y-J|0;if(E>>>0<512>>>0){L=E&65535}else{L=-E>>31&511}b[s>>1]=L}}while(0);y=r+1|0;if((y|0)<4){r=y;s=s+2|0}else{break}}}s=m+1|0;if((s|0)<4){m=s;n=n+8|0}else{break}}return}function pja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<1;f=g<<1;g=i<<2;j=0;k=c;while(1){c=a[h+j|0]<<1;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<512>>>0){H=B&65535}else{H=-B>>31&511}b[q>>1]=H;B=v-G|0;if(B>>>0<512>>>0){I=B&65535}else{I=-B>>31&511}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<4){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function qja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<1;f=g<<1;g=i<<1;j=0;k=c;while(1){c=a[h+j|0]<<1;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<512>>>0){H=B&65535}else{H=-B>>31&511}b[q>>1]=H;B=v-G|0;if(B>>>0<512>>>0){I=B&65535}else{I=-B>>31&511}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<2){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function rja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c>>1;c=d<<1;d=f<<1;f=g*-3|0;h=g*-2|0;i=-g|0;j=g<<1;k=(c>>2)+2|0;l=g*-4|0;m=g*3|0;n=0;o=a;while(1){a=o+(f<<1)|0;p=e[a>>1]|0;q=o+(h<<1)|0;r=e[q>>1]|0;s=o+(i<<1)|0;t=e[s>>1]|0;u=e[o>>1]|0;v=o+(g<<1)|0;w=e[v>>1]|0;x=o+(j<<1)|0;y=e[x>>1]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(c|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}if((A|0)>=(k|0)){b[s>>1]=(t+2+(r<<1)+w|0)>>>2;b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(l<<1)>>1]|0;b[s>>1]=(p+4+w+(t+r+u<<1)|0)>>>3;b[q>>1]=(p+2+r+t+u|0)>>>2;b[a>>1]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{b[s>>1]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(m<<1)>>1]|0;b[o>>1]=(r+4+y+(u+t+w<<1)|0)>>>3;b[v>>1]=(t+2+u+w+y|0)>>>2;b[x>>1]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+2|0}else{break}}return}function sja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<1;d=f<<1;f=(c>>2)+2|0;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+(g<<1)|0}else{break}}return}function tja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<1;d=f<<1;f=(c>>2)+2|0;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+(g<<1)|0}else{break}}return}function uja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=f<<1;f=g<<1;g=d>>1;d=-g|0;j=g*-2|0;k=0;l=c;while(1){c=a[h+k|0]<<1;m=c-1|0;do{if((m|0)>=1){n=1-c|0;o=l+(d<<1)|0;p=e[o>>1]|0;q=e[l+(j<<1)>>1]|0;r=e[l>>1]|0;s=e[l+(g<<1)>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(n|0)){v=n}else{v=(u|0)>(m|0)?m:u}u=v+p|0;if(u>>>0<512>>>0){w=u&65535}else{w=-u>>31&511}b[o>>1]=w;u=r-v|0;if(u>>>0<512>>>0){x=u&65535}else{x=-u>>31&511}b[l>>1]=x}}while(0);r=l+2|0;o=l+(1-g<<1)|0;p=e[o>>1]|0;s=e[l+((j|1)<<1)>>1]|0;q=e[r>>1]|0;t=e[l+(g+1<<1)>>1]|0;u=p-q|0;if((((u|0)>-1?u:-u|0)|0)>=(i|0)){break}u=s-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=t-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s+4-t+(q-p<<2)>>3;if((u|0)<(n|0)){y=n}else{y=(u|0)>(m|0)?m:u}u=y+p|0;if(u>>>0<512>>>0){z=u&65535}else{z=-u>>31&511}b[o>>1]=z;o=q-y|0;if(o>>>0<512>>>0){A=o&65535}else{A=-o>>31&511}b[r>>1]=A}}while(0);m=k+1|0;if((m|0)<4){k=m;l=l+4|0}else{break}}return}function vja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<1;f=g<<1;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<1;l=c-1|0;do{if((l|0)>=1){m=1-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<512>>>0){v=t&65535}else{v=-t>>31&511}b[n>>1]=v;t=q-u|0;if(t>>>0<512>>>0){w=t&65535}else{w=-t>>31&511}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<512>>>0){y=t&65535}else{y=-t>>31&511}b[n>>1]=y;n=p-x|0;if(n>>>0<512>>>0){z=n&65535}else{z=-n>>31&511}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function wja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=f<<1;f=g<<1;g=d>>1;d=g<<2;j=0;k=c;while(1){c=a[h+j|0]<<1;l=c-1|0;if((l|0)>=1){m=1-c|0;c=0;n=k;while(1){o=n-2|0;p=e[o>>1]|0;q=e[n-4>>1]|0;r=e[n>>1]|0;s=e[n+2>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}u=v+p|0;if(u>>>0<512>>>0){w=u&65535}else{w=-u>>31&511}b[o>>1]=w;u=r-v|0;if(u>>>0<512>>>0){x=u&65535}else{x=-u>>31&511}b[n>>1]=x}}while(0);r=c+1|0;if((r|0)<4){c=r;n=n+(g<<1)|0}else{break}}}n=j+1|0;if((n|0)<4){j=n;k=k+(d<<1)|0}else{break}}return}function xja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=f<<1;f=g<<1;g=d>>1;d=0;j=c;while(1){c=a[h+d|0]<<1;k=c-1|0;do{if((k|0)>=1){l=1-c|0;m=j-2|0;n=e[m>>1]|0;o=e[j-4>>1]|0;p=e[j>>1]|0;q=e[j+2>>1]|0;r=n-p|0;if((((r|0)>-1?r:-r|0)|0)>=(i|0)){break}r=o-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=q-p|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=o+4-q+(p-n<<2)>>3;if((r|0)<(l|0)){s=l}else{s=(r|0)>(k|0)?k:r}r=s+n|0;if(r>>>0<512>>>0){t=r&65535}else{t=-r>>31&511}b[m>>1]=t;m=p-s|0;if(m>>>0<512>>>0){u=m&65535}else{u=-m>>31&511}b[j>>1]=u}}while(0);k=d+1|0;if((k|0)<4){d=k;j=j+(g<<1)|0}else{break}}return}function yja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<1;f=g<<1;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<1;l=c-1|0;do{if((l|0)>=1){m=1-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<512>>>0){v=t&65535}else{v=-t>>31&511}b[n>>1]=v;t=q-u|0;if(t>>>0<512>>>0){w=t&65535}else{w=-t>>31&511}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<512>>>0){y=t&65535}else{y=-t>>31&511}b[n>>1]=y;n=p-x|0;if(n>>>0<512>>>0){z=n&65535}else{z=-n>>31&511}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function zja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c>>1;c=d<<1;d=f<<1;f=-g|0;h=g*-2|0;i=a;a=0;while(1){j=i+(f<<1)|0;k=e[j>>1]|0;l=e[i+(h<<1)>>1]|0;m=e[i>>1]|0;n=e[i+(g<<1)>>1]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(c|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}b[j>>1]=(k+2+(l<<1)+n|0)>>>2;b[i>>1]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=a+1|0;if((n|0)<8){i=i+2|0;a=n}else{break}}return}function Aja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<1;d=f<<1;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function Bja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<1;d=f<<1;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<16){f=f+(g<<1)|0;a=l}else{break}}return}function Cja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<1;d=f<<1;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<4){f=f+(g<<1)|0;a=l}else{break}}return}function Dja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<1;d=f<<1;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function Eja(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c>>1;c=h<<f+2;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<1024>>>0){m=a&65535}else{m=-a>>31&1023}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){n=c&65535}else{n=-c>>31&1023}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){o=c&65535}else{o=-c>>31&1023}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){p=c&65535}else{p=-c>>31&1023}b[a>>1]=p;a=l+8|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){q=c&65535}else{q=-c>>31&1023}b[a>>1]=q;a=l+10|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[a>>1]=r;a=l+12|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){s=c&65535}else{s=-c>>31&1023}b[a>>1]=s;a=l+14|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){t=c&65535}else{t=-c>>31&1023}b[a>>1]=t;a=l+16|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){u=c&65535}else{u=-c>>31&1023}b[a>>1]=u;a=l+18|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){v=c&65535}else{v=-c>>31&1023}b[a>>1]=v;a=l+20|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){w=c&65535}else{w=-c>>31&1023}b[a>>1]=w;a=l+22|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){x=c&65535}else{x=-c>>31&1023}b[a>>1]=x;a=l+24|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){y=c&65535}else{y=-c>>31&1023}b[a>>1]=y;a=l+26|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){z=c&65535}else{z=-c>>31&1023}b[a>>1]=z;a=l+28|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){A=c&65535}else{A=-c>>31&1023}b[a>>1]=A;a=l+30|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){B=c&65535}else{B=-c>>31&1023}b[a>>1]=B;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Fja(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c>>1;c=h<<f+2;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<1024>>>0){m=a&65535}else{m=-a>>31&1023}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){n=c&65535}else{n=-c>>31&1023}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){o=c&65535}else{o=-c>>31&1023}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){p=c&65535}else{p=-c>>31&1023}b[a>>1]=p;a=l+8|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){q=c&65535}else{q=-c>>31&1023}b[a>>1]=q;a=l+10|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[a>>1]=r;a=l+12|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){s=c&65535}else{s=-c>>31&1023}b[a>>1]=s;a=l+14|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){t=c&65535}else{t=-c>>31&1023}b[a>>1]=t;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Gja(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c>>1;c=h<<f+2;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<1024>>>0){m=a&65535}else{m=-a>>31&1023}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){n=c&65535}else{n=-c>>31&1023}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){o=c&65535}else{o=-c>>31&1023}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){p=c&65535}else{p=-c>>31&1023}b[a>>1]=p;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Hja(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c>>1;c=h<<f+2;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<1024>>>0){m=a&65535}else{m=-a>>31&1023}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<1024>>>0){n=c&65535}else{n=-c>>31&1023}b[a>>1]=n;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Ija(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=d>>1;d=(j<<2|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){q=m&65535}else{q=-m>>31&1023}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[m>>1]=r;m=ca(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){s=o&65535}else{s=-o>>31&1023}b[c>>1]=s;c=ca(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){t=m&65535}else{t=-m>>31&1023}b[o>>1]=t;o=ca(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){u=c&65535}else{u=-c>>31&1023}b[m>>1]=u;m=ca(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){v=o&65535}else{v=-o>>31&1023}b[c>>1]=v;c=ca(e[a+16>>1]|0,i)|0;o=l+16|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){w=m&65535}else{w=-m>>31&1023}b[o>>1]=w;o=ca(e[a+18>>1]|0,i)|0;m=l+18|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){x=c&65535}else{x=-c>>31&1023}b[m>>1]=x;m=ca(e[a+20>>1]|0,i)|0;c=l+20|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){y=o&65535}else{y=-o>>31&1023}b[c>>1]=y;c=ca(e[a+22>>1]|0,i)|0;o=l+22|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){z=m&65535}else{z=-m>>31&1023}b[o>>1]=z;o=ca(e[a+24>>1]|0,i)|0;m=l+24|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){A=c&65535}else{A=-c>>31&1023}b[m>>1]=A;m=ca(e[a+26>>1]|0,i)|0;c=l+26|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){B=o&65535}else{B=-o>>31&1023}b[c>>1]=B;c=ca(e[a+28>>1]|0,i)|0;o=l+28|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){C=m&65535}else{C=-m>>31&1023}b[o>>1]=C;o=ca(e[a+30>>1]|0,i)|0;m=l+30|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){D=c&65535}else{D=-c>>31&1023}b[m>>1]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Jja(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=d>>1;d=(j<<2|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){q=m&65535}else{q=-m>>31&1023}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[m>>1]=r;m=ca(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){s=o&65535}else{s=-o>>31&1023}b[c>>1]=s;c=ca(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){t=m&65535}else{t=-m>>31&1023}b[o>>1]=t;o=ca(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){u=c&65535}else{u=-c>>31&1023}b[m>>1]=u;m=ca(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){v=o&65535}else{v=-o>>31&1023}b[c>>1]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Kja(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=d>>1;d=(j<<2|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){q=m&65535}else{q=-m>>31&1023}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<1024>>>0){r=c&65535}else{r=-c>>31&1023}b[m>>1]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Lja(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=d>>1;d=(j<<2|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<1024>>>0){n=m&65535}else{n=-m>>31&1023}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<1024>>>0){p=o&65535}else{p=-o>>31&1023}b[c>>1]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Mja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=d>>1;d=f<<2;f=g<<2;g=-i|0;j=i*-2|0;k=i*-3|0;l=i<<1;m=0;n=c;while(1){c=a[h+m|0]<<2;if((c|0)>=0){o=(c|0)==0;p=c|1;q=-c|0;r=0;s=n;while(1){t=s+(g<<1)|0;u=e[t>>1]|0;v=s+(j<<1)|0;w=e[v>>1]|0;x=e[s+(k<<1)>>1]|0;y=e[s>>1]|0;z=s+(i<<1)|0;A=e[z>>1]|0;B=e[s+(l<<1)>>1]|0;C=u-y|0;do{if((((C|0)>-1?C:-C|0)|0)<(d|0)){D=w-u|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=A-y|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=x-u|0;E=(((D|0)>-1?D:-D|0)|0)>=(f|0);if(E|o){F=E?c:p}else{E=((((u+1+y|0)>>>1)+x|0)>>>1)-w|0;if((E|0)<(q|0)){G=q}else{G=(E|0)>(c|0)?c:E}b[v>>1]=G+w;F=p}E=B-y|0;if((((E|0)>-1?E:-E|0)|0)<(f|0)){if(!o){E=((B+((u+1+y|0)>>>1)|0)>>>1)-A|0;if((E|0)<(q|0)){H=q}else{H=(E|0)>(c|0)?c:E}b[z>>1]=H+A}I=F+1|0}else{I=F}E=w+4-A+(y-u<<2)>>3;D=-I|0;if((E|0)<(D|0)){J=D}else{J=(E|0)>(I|0)?I:E}E=J+u|0;if(E>>>0<1024>>>0){K=E&65535}else{K=-E>>31&1023}b[t>>1]=K;E=y-J|0;if(E>>>0<1024>>>0){L=E&65535}else{L=-E>>31&1023}b[s>>1]=L}}while(0);y=r+1|0;if((y|0)<4){r=y;s=s+2|0}else{break}}}s=m+1|0;if((s|0)<4){m=s;n=n+8|0}else{break}}return}function Nja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<2;f=g<<2;g=i<<2;j=0;k=c;while(1){c=a[h+j|0]<<2;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<1024>>>0){H=B&65535}else{H=-B>>31&1023}b[q>>1]=H;B=v-G|0;if(B>>>0<1024>>>0){I=B&65535}else{I=-B>>31&1023}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<4){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function Oja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<2;f=g<<2;g=i<<1;j=0;k=c;while(1){c=a[h+j|0]<<2;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<1024>>>0){H=B&65535}else{H=-B>>31&1023}b[q>>1]=H;B=v-G|0;if(B>>>0<1024>>>0){I=B&65535}else{I=-B>>31&1023}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<2){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function Pja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c>>1;c=d<<2;d=f<<2;f=g*-3|0;h=g*-2|0;i=-g|0;j=g<<1;k=(c>>2)+2|0;l=g*-4|0;m=g*3|0;n=0;o=a;while(1){a=o+(f<<1)|0;p=e[a>>1]|0;q=o+(h<<1)|0;r=e[q>>1]|0;s=o+(i<<1)|0;t=e[s>>1]|0;u=e[o>>1]|0;v=o+(g<<1)|0;w=e[v>>1]|0;x=o+(j<<1)|0;y=e[x>>1]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(c|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}if((A|0)>=(k|0)){b[s>>1]=(t+2+(r<<1)+w|0)>>>2;b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(l<<1)>>1]|0;b[s>>1]=(p+4+w+(t+r+u<<1)|0)>>>3;b[q>>1]=(p+2+r+t+u|0)>>>2;b[a>>1]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{b[s>>1]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(m<<1)>>1]|0;b[o>>1]=(r+4+y+(u+t+w<<1)|0)>>>3;b[v>>1]=(t+2+u+w+y|0)>>>2;b[x>>1]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+2|0}else{break}}return}function Qja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<2;d=f<<2;f=(c>>2)+2|0;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+(g<<1)|0}else{break}}return}function Rja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<2;d=f<<2;f=(c>>2)+2|0;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+(g<<1)|0}else{break}}return}function Sja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=f<<2;f=g<<2;g=d>>1;d=-g|0;j=g*-2|0;k=0;l=c;while(1){c=a[h+k|0]<<2;m=c-3|0;do{if((m|0)>=1){n=3-c|0;o=l+(d<<1)|0;p=e[o>>1]|0;q=e[l+(j<<1)>>1]|0;r=e[l>>1]|0;s=e[l+(g<<1)>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(n|0)){v=n}else{v=(u|0)>(m|0)?m:u}u=v+p|0;if(u>>>0<1024>>>0){w=u&65535}else{w=-u>>31&1023}b[o>>1]=w;u=r-v|0;if(u>>>0<1024>>>0){x=u&65535}else{x=-u>>31&1023}b[l>>1]=x}}while(0);r=l+2|0;o=l+(1-g<<1)|0;p=e[o>>1]|0;s=e[l+((j|1)<<1)>>1]|0;q=e[r>>1]|0;t=e[l+(g+1<<1)>>1]|0;u=p-q|0;if((((u|0)>-1?u:-u|0)|0)>=(i|0)){break}u=s-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=t-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s+4-t+(q-p<<2)>>3;if((u|0)<(n|0)){y=n}else{y=(u|0)>(m|0)?m:u}u=y+p|0;if(u>>>0<1024>>>0){z=u&65535}else{z=-u>>31&1023}b[o>>1]=z;o=q-y|0;if(o>>>0<1024>>>0){A=o&65535}else{A=-o>>31&1023}b[r>>1]=A}}while(0);m=k+1|0;if((m|0)<4){k=m;l=l+4|0}else{break}}return}function Tja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<2;f=g<<2;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<2;l=c-3|0;do{if((l|0)>=1){m=3-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<1024>>>0){v=t&65535}else{v=-t>>31&1023}b[n>>1]=v;t=q-u|0;if(t>>>0<1024>>>0){w=t&65535}else{w=-t>>31&1023}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<1024>>>0){y=t&65535}else{y=-t>>31&1023}b[n>>1]=y;n=p-x|0;if(n>>>0<1024>>>0){z=n&65535}else{z=-n>>31&1023}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function Uja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=f<<2;f=g<<2;g=d>>1;d=g<<2;j=0;k=c;while(1){c=a[h+j|0]<<2;l=c-3|0;if((l|0)>=1){m=3-c|0;c=0;n=k;while(1){o=n-2|0;p=e[o>>1]|0;q=e[n-4>>1]|0;r=e[n>>1]|0;s=e[n+2>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}u=v+p|0;if(u>>>0<1024>>>0){w=u&65535}else{w=-u>>31&1023}b[o>>1]=w;u=r-v|0;if(u>>>0<1024>>>0){x=u&65535}else{x=-u>>31&1023}b[n>>1]=x}}while(0);r=c+1|0;if((r|0)<4){c=r;n=n+(g<<1)|0}else{break}}}n=j+1|0;if((n|0)<4){j=n;k=k+(d<<1)|0}else{break}}return}function Vja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=f<<2;f=g<<2;g=d>>1;d=0;j=c;while(1){c=a[h+d|0]<<2;k=c-3|0;do{if((k|0)>=1){l=3-c|0;m=j-2|0;n=e[m>>1]|0;o=e[j-4>>1]|0;p=e[j>>1]|0;q=e[j+2>>1]|0;r=n-p|0;if((((r|0)>-1?r:-r|0)|0)>=(i|0)){break}r=o-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=q-p|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=o+4-q+(p-n<<2)>>3;if((r|0)<(l|0)){s=l}else{s=(r|0)>(k|0)?k:r}r=s+n|0;if(r>>>0<1024>>>0){t=r&65535}else{t=-r>>31&1023}b[m>>1]=t;m=p-s|0;if(m>>>0<1024>>>0){u=m&65535}else{u=-m>>31&1023}b[j>>1]=u}}while(0);k=d+1|0;if((k|0)<4){d=k;j=j+(g<<1)|0}else{break}}return}function Wja(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<2;f=g<<2;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<2;l=c-3|0;do{if((l|0)>=1){m=3-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<1024>>>0){v=t&65535}else{v=-t>>31&1023}b[n>>1]=v;t=q-u|0;if(t>>>0<1024>>>0){w=t&65535}else{w=-t>>31&1023}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<1024>>>0){y=t&65535}else{y=-t>>31&1023}b[n>>1]=y;n=p-x|0;if(n>>>0<1024>>>0){z=n&65535}else{z=-n>>31&1023}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function Xja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c>>1;c=d<<2;d=f<<2;f=-g|0;h=g*-2|0;i=a;a=0;while(1){j=i+(f<<1)|0;k=e[j>>1]|0;l=e[i+(h<<1)>>1]|0;m=e[i>>1]|0;n=e[i+(g<<1)>>1]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(c|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}b[j>>1]=(k+2+(l<<1)+n|0)>>>2;b[i>>1]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=a+1|0;if((n|0)<8){i=i+2|0;a=n}else{break}}return}function Yja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<2;d=f<<2;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function Zja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<2;d=f<<2;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<16){f=f+(g<<1)|0;a=l}else{break}}return}function _ja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<2;d=f<<2;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<4){f=f+(g<<1)|0;a=l}else{break}}return}function $ja(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<2;d=f<<2;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function aka(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c>>1;c=h<<f+4;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<4096>>>0){m=a&65535}else{m=-a>>31&4095}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){n=c&65535}else{n=-c>>31&4095}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){o=c&65535}else{o=-c>>31&4095}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){p=c&65535}else{p=-c>>31&4095}b[a>>1]=p;a=l+8|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){q=c&65535}else{q=-c>>31&4095}b[a>>1]=q;a=l+10|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[a>>1]=r;a=l+12|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){s=c&65535}else{s=-c>>31&4095}b[a>>1]=s;a=l+14|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){t=c&65535}else{t=-c>>31&4095}b[a>>1]=t;a=l+16|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){u=c&65535}else{u=-c>>31&4095}b[a>>1]=u;a=l+18|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){v=c&65535}else{v=-c>>31&4095}b[a>>1]=v;a=l+20|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){w=c&65535}else{w=-c>>31&4095}b[a>>1]=w;a=l+22|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){x=c&65535}else{x=-c>>31&4095}b[a>>1]=x;a=l+24|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){y=c&65535}else{y=-c>>31&4095}b[a>>1]=y;a=l+26|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){z=c&65535}else{z=-c>>31&4095}b[a>>1]=z;a=l+28|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){A=c&65535}else{A=-c>>31&4095}b[a>>1]=A;a=l+30|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){B=c&65535}else{B=-c>>31&4095}b[a>>1]=B;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function bka(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c>>1;c=h<<f+4;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<4096>>>0){m=a&65535}else{m=-a>>31&4095}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){n=c&65535}else{n=-c>>31&4095}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){o=c&65535}else{o=-c>>31&4095}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){p=c&65535}else{p=-c>>31&4095}b[a>>1]=p;a=l+8|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){q=c&65535}else{q=-c>>31&4095}b[a>>1]=q;a=l+10|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[a>>1]=r;a=l+12|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){s=c&65535}else{s=-c>>31&4095}b[a>>1]=s;a=l+14|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){t=c&65535}else{t=-c>>31&4095}b[a>>1]=t;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function cka(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c>>1;c=h<<f+4;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<4096>>>0){m=a&65535}else{m=-a>>31&4095}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){n=c&65535}else{n=-c>>31&4095}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){o=c&65535}else{o=-c>>31&4095}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){p=c&65535}else{p=-c>>31&4095}b[a>>1]=p;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function dka(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c>>1;c=h<<f+4;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<4096>>>0){m=a&65535}else{m=-a>>31&4095}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<4096>>>0){n=c&65535}else{n=-c>>31&4095}b[a>>1]=n;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function eka(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=d>>1;d=(j<<4|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){p=o&65535}else{p=-o>>31&4095}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){q=m&65535}else{q=-m>>31&4095}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[m>>1]=r;m=ca(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){s=o&65535}else{s=-o>>31&4095}b[c>>1]=s;c=ca(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){t=m&65535}else{t=-m>>31&4095}b[o>>1]=t;o=ca(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){u=c&65535}else{u=-c>>31&4095}b[m>>1]=u;m=ca(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){v=o&65535}else{v=-o>>31&4095}b[c>>1]=v;c=ca(e[a+16>>1]|0,i)|0;o=l+16|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){w=m&65535}else{w=-m>>31&4095}b[o>>1]=w;o=ca(e[a+18>>1]|0,i)|0;m=l+18|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){x=c&65535}else{x=-c>>31&4095}b[m>>1]=x;m=ca(e[a+20>>1]|0,i)|0;c=l+20|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){y=o&65535}else{y=-o>>31&4095}b[c>>1]=y;c=ca(e[a+22>>1]|0,i)|0;o=l+22|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){z=m&65535}else{z=-m>>31&4095}b[o>>1]=z;o=ca(e[a+24>>1]|0,i)|0;m=l+24|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){A=c&65535}else{A=-c>>31&4095}b[m>>1]=A;m=ca(e[a+26>>1]|0,i)|0;c=l+26|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){B=o&65535}else{B=-o>>31&4095}b[c>>1]=B;c=ca(e[a+28>>1]|0,i)|0;o=l+28|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){C=m&65535}else{C=-m>>31&4095}b[o>>1]=C;o=ca(e[a+30>>1]|0,i)|0;m=l+30|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){D=c&65535}else{D=-c>>31&4095}b[m>>1]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function fka(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=d>>1;d=(j<<4|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){p=o&65535}else{p=-o>>31&4095}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){q=m&65535}else{q=-m>>31&4095}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[m>>1]=r;m=ca(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){s=o&65535}else{s=-o>>31&4095}b[c>>1]=s;c=ca(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){t=m&65535}else{t=-m>>31&4095}b[o>>1]=t;o=ca(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){u=c&65535}else{u=-c>>31&4095}b[m>>1]=u;m=ca(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){v=o&65535}else{v=-o>>31&4095}b[c>>1]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function gka(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=d>>1;d=(j<<4|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){p=o&65535}else{p=-o>>31&4095}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){q=m&65535}else{q=-m>>31&4095}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<4096>>>0){r=c&65535}else{r=-c>>31&4095}b[m>>1]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function hka(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=d>>1;d=(j<<4|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<4096>>>0){n=m&65535}else{n=-m>>31&4095}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<4096>>>0){p=o&65535}else{p=-o>>31&4095}b[c>>1]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function ika(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=d>>1;d=f<<4;f=g<<4;g=-i|0;j=i*-2|0;k=i*-3|0;l=i<<1;m=0;n=c;while(1){c=a[h+m|0]<<4;if((c|0)>=0){o=(c|0)==0;p=c|1;q=-c|0;r=0;s=n;while(1){t=s+(g<<1)|0;u=e[t>>1]|0;v=s+(j<<1)|0;w=e[v>>1]|0;x=e[s+(k<<1)>>1]|0;y=e[s>>1]|0;z=s+(i<<1)|0;A=e[z>>1]|0;B=e[s+(l<<1)>>1]|0;C=u-y|0;do{if((((C|0)>-1?C:-C|0)|0)<(d|0)){D=w-u|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=A-y|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=x-u|0;E=(((D|0)>-1?D:-D|0)|0)>=(f|0);if(E|o){F=E?c:p}else{E=((((u+1+y|0)>>>1)+x|0)>>>1)-w|0;if((E|0)<(q|0)){G=q}else{G=(E|0)>(c|0)?c:E}b[v>>1]=G+w;F=p}E=B-y|0;if((((E|0)>-1?E:-E|0)|0)<(f|0)){if(!o){E=((B+((u+1+y|0)>>>1)|0)>>>1)-A|0;if((E|0)<(q|0)){H=q}else{H=(E|0)>(c|0)?c:E}b[z>>1]=H+A}I=F+1|0}else{I=F}E=w+4-A+(y-u<<2)>>3;D=-I|0;if((E|0)<(D|0)){J=D}else{J=(E|0)>(I|0)?I:E}E=J+u|0;if(E>>>0<4096>>>0){K=E&65535}else{K=-E>>31&4095}b[t>>1]=K;E=y-J|0;if(E>>>0<4096>>>0){L=E&65535}else{L=-E>>31&4095}b[s>>1]=L}}while(0);y=r+1|0;if((y|0)<4){r=y;s=s+2|0}else{break}}}s=m+1|0;if((s|0)<4){m=s;n=n+8|0}else{break}}return}function jka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<4;f=g<<4;g=i<<2;j=0;k=c;while(1){c=a[h+j|0]<<4;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<4096>>>0){H=B&65535}else{H=-B>>31&4095}b[q>>1]=H;B=v-G|0;if(B>>>0<4096>>>0){I=B&65535}else{I=-B>>31&4095}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<4){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function kka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<4;f=g<<4;g=i<<1;j=0;k=c;while(1){c=a[h+j|0]<<4;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<4096>>>0){H=B&65535}else{H=-B>>31&4095}b[q>>1]=H;B=v-G|0;if(B>>>0<4096>>>0){I=B&65535}else{I=-B>>31&4095}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<2){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function lka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c>>1;c=d<<4;d=f<<4;f=g*-3|0;h=g*-2|0;i=-g|0;j=g<<1;k=c>>2|2;l=g*-4|0;m=g*3|0;n=0;o=a;while(1){a=o+(f<<1)|0;p=e[a>>1]|0;q=o+(h<<1)|0;r=e[q>>1]|0;s=o+(i<<1)|0;t=e[s>>1]|0;u=e[o>>1]|0;v=o+(g<<1)|0;w=e[v>>1]|0;x=o+(j<<1)|0;y=e[x>>1]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(c|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}if((A|0)>=(k|0)){b[s>>1]=(t+2+(r<<1)+w|0)>>>2;b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(l<<1)>>1]|0;b[s>>1]=(p+4+w+(t+r+u<<1)|0)>>>3;b[q>>1]=(p+2+r+t+u|0)>>>2;b[a>>1]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{b[s>>1]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(m<<1)>>1]|0;b[o>>1]=(r+4+y+(u+t+w<<1)|0)>>>3;b[v>>1]=(t+2+u+w+y|0)>>>2;b[x>>1]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+2|0}else{break}}return}function mka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<4;d=f<<4;f=c>>2|2;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+(g<<1)|0}else{break}}return}function nka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<4;d=f<<4;f=c>>2|2;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+(g<<1)|0}else{break}}return}function oka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=f<<4;f=g<<4;g=d>>1;d=-g|0;j=g*-2|0;k=0;l=c;while(1){c=a[h+k|0]<<4;m=c-15|0;do{if((m|0)>=1){n=15-c|0;o=l+(d<<1)|0;p=e[o>>1]|0;q=e[l+(j<<1)>>1]|0;r=e[l>>1]|0;s=e[l+(g<<1)>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(n|0)){v=n}else{v=(u|0)>(m|0)?m:u}u=v+p|0;if(u>>>0<4096>>>0){w=u&65535}else{w=-u>>31&4095}b[o>>1]=w;u=r-v|0;if(u>>>0<4096>>>0){x=u&65535}else{x=-u>>31&4095}b[l>>1]=x}}while(0);r=l+2|0;o=l+(1-g<<1)|0;p=e[o>>1]|0;s=e[l+((j|1)<<1)>>1]|0;q=e[r>>1]|0;t=e[l+(g+1<<1)>>1]|0;u=p-q|0;if((((u|0)>-1?u:-u|0)|0)>=(i|0)){break}u=s-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=t-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s+4-t+(q-p<<2)>>3;if((u|0)<(n|0)){y=n}else{y=(u|0)>(m|0)?m:u}u=y+p|0;if(u>>>0<4096>>>0){z=u&65535}else{z=-u>>31&4095}b[o>>1]=z;o=q-y|0;if(o>>>0<4096>>>0){A=o&65535}else{A=-o>>31&4095}b[r>>1]=A}}while(0);m=k+1|0;if((m|0)<4){k=m;l=l+4|0}else{break}}return}function pka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<4;f=g<<4;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<4;l=c-15|0;do{if((l|0)>=1){m=15-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<4096>>>0){v=t&65535}else{v=-t>>31&4095}b[n>>1]=v;t=q-u|0;if(t>>>0<4096>>>0){w=t&65535}else{w=-t>>31&4095}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<4096>>>0){y=t&65535}else{y=-t>>31&4095}b[n>>1]=y;n=p-x|0;if(n>>>0<4096>>>0){z=n&65535}else{z=-n>>31&4095}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function qka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=f<<4;f=g<<4;g=d>>1;d=g<<2;j=0;k=c;while(1){c=a[h+j|0]<<4;l=c-15|0;if((l|0)>=1){m=15-c|0;c=0;n=k;while(1){o=n-2|0;p=e[o>>1]|0;q=e[n-4>>1]|0;r=e[n>>1]|0;s=e[n+2>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}u=v+p|0;if(u>>>0<4096>>>0){w=u&65535}else{w=-u>>31&4095}b[o>>1]=w;u=r-v|0;if(u>>>0<4096>>>0){x=u&65535}else{x=-u>>31&4095}b[n>>1]=x}}while(0);r=c+1|0;if((r|0)<4){c=r;n=n+(g<<1)|0}else{break}}}n=j+1|0;if((n|0)<4){j=n;k=k+(d<<1)|0}else{break}}return}function rka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=f<<4;f=g<<4;g=d>>1;d=0;j=c;while(1){c=a[h+d|0]<<4;k=c-15|0;do{if((k|0)>=1){l=15-c|0;m=j-2|0;n=e[m>>1]|0;o=e[j-4>>1]|0;p=e[j>>1]|0;q=e[j+2>>1]|0;r=n-p|0;if((((r|0)>-1?r:-r|0)|0)>=(i|0)){break}r=o-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=q-p|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=o+4-q+(p-n<<2)>>3;if((r|0)<(l|0)){s=l}else{s=(r|0)>(k|0)?k:r}r=s+n|0;if(r>>>0<4096>>>0){t=r&65535}else{t=-r>>31&4095}b[m>>1]=t;m=p-s|0;if(m>>>0<4096>>>0){u=m&65535}else{u=-m>>31&4095}b[j>>1]=u}}while(0);k=d+1|0;if((k|0)<4){d=k;j=j+(g<<1)|0}else{break}}return}function ska(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<4;f=g<<4;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<4;l=c-15|0;do{if((l|0)>=1){m=15-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<4096>>>0){v=t&65535}else{v=-t>>31&4095}b[n>>1]=v;t=q-u|0;if(t>>>0<4096>>>0){w=t&65535}else{w=-t>>31&4095}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<4096>>>0){y=t&65535}else{y=-t>>31&4095}b[n>>1]=y;n=p-x|0;if(n>>>0<4096>>>0){z=n&65535}else{z=-n>>31&4095}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function tka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c>>1;c=d<<4;d=f<<4;f=-g|0;h=g*-2|0;i=a;a=0;while(1){j=i+(f<<1)|0;k=e[j>>1]|0;l=e[i+(h<<1)>>1]|0;m=e[i>>1]|0;n=e[i+(g<<1)>>1]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(c|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}b[j>>1]=(k+2+(l<<1)+n|0)>>>2;b[i>>1]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=a+1|0;if((n|0)<8){i=i+2|0;a=n}else{break}}return}function uka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<4;d=f<<4;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function vka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<4;d=f<<4;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<16){f=f+(g<<1)|0;a=l}else{break}}return}function wka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<4;d=f<<4;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<4){f=f+(g<<1)|0;a=l}else{break}}return}function xka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<4;d=f<<4;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function yka(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=c>>1;c=h<<f+6;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<16384>>>0){m=a&65535}else{m=-a>>31&16383}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){n=c&65535}else{n=-c>>31&16383}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){o=c&65535}else{o=-c>>31&16383}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){p=c&65535}else{p=-c>>31&16383}b[a>>1]=p;a=l+8|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){q=c&65535}else{q=-c>>31&16383}b[a>>1]=q;a=l+10|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[a>>1]=r;a=l+12|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){s=c&65535}else{s=-c>>31&16383}b[a>>1]=s;a=l+14|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){t=c&65535}else{t=-c>>31&16383}b[a>>1]=t;a=l+16|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){u=c&65535}else{u=-c>>31&16383}b[a>>1]=u;a=l+18|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){v=c&65535}else{v=-c>>31&16383}b[a>>1]=v;a=l+20|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){w=c&65535}else{w=-c>>31&16383}b[a>>1]=w;a=l+22|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){x=c&65535}else{x=-c>>31&16383}b[a>>1]=x;a=l+24|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){y=c&65535}else{y=-c>>31&16383}b[a>>1]=y;a=l+26|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){z=c&65535}else{z=-c>>31&16383}b[a>>1]=z;a=l+28|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){A=c&65535}else{A=-c>>31&16383}b[a>>1]=A;a=l+30|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){B=c&65535}else{B=-c>>31&16383}b[a>>1]=B;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function zka(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=c>>1;c=h<<f+6;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<16384>>>0){m=a&65535}else{m=-a>>31&16383}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){n=c&65535}else{n=-c>>31&16383}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){o=c&65535}else{o=-c>>31&16383}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){p=c&65535}else{p=-c>>31&16383}b[a>>1]=p;a=l+8|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){q=c&65535}else{q=-c>>31&16383}b[a>>1]=q;a=l+10|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[a>>1]=r;a=l+12|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){s=c&65535}else{s=-c>>31&16383}b[a>>1]=s;a=l+14|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){t=c&65535}else{t=-c>>31&16383}b[a>>1]=t;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Aka(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=c>>1;c=h<<f+6;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<16384>>>0){m=a&65535}else{m=-a>>31&16383}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){n=c&65535}else{n=-c>>31&16383}b[a>>1]=n;a=l+4|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){o=c&65535}else{o=-c>>31&16383}b[a>>1]=o;a=l+6|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){p=c&65535}else{p=-c>>31&16383}b[a>>1]=p;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Bka(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=c>>1;c=h<<f+6;if((f|0)==0){j=c}else{j=c+(1<<f-1)|0}if((d|0)>0){k=0;l=a}else{return}while(1){a=(ca(e[l>>1]|0,g)|0)+j>>f;if(a>>>0<16384>>>0){m=a&65535}else{m=-a>>31&16383}b[l>>1]=m;a=l+2|0;c=(ca(e[a>>1]|0,g)|0)+j>>f;if(c>>>0<16384>>>0){n=c&65535}else{n=-c>>31&16383}b[a>>1]=n;a=k+1|0;if((a|0)<(d|0)){k=a;l=l+(i<<1)|0}else{break}}return}function Cka(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=d>>1;d=(j<<6|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){p=o&65535}else{p=-o>>31&16383}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){q=m&65535}else{q=-m>>31&16383}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[m>>1]=r;m=ca(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){s=o&65535}else{s=-o>>31&16383}b[c>>1]=s;c=ca(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){t=m&65535}else{t=-m>>31&16383}b[o>>1]=t;o=ca(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){u=c&65535}else{u=-c>>31&16383}b[m>>1]=u;m=ca(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){v=o&65535}else{v=-o>>31&16383}b[c>>1]=v;c=ca(e[a+16>>1]|0,i)|0;o=l+16|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){w=m&65535}else{w=-m>>31&16383}b[o>>1]=w;o=ca(e[a+18>>1]|0,i)|0;m=l+18|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){x=c&65535}else{x=-c>>31&16383}b[m>>1]=x;m=ca(e[a+20>>1]|0,i)|0;c=l+20|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){y=o&65535}else{y=-o>>31&16383}b[c>>1]=y;c=ca(e[a+22>>1]|0,i)|0;o=l+22|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){z=m&65535}else{z=-m>>31&16383}b[o>>1]=z;o=ca(e[a+24>>1]|0,i)|0;m=l+24|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){A=c&65535}else{A=-c>>31&16383}b[m>>1]=A;m=ca(e[a+26>>1]|0,i)|0;c=l+26|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){B=o&65535}else{B=-o>>31&16383}b[c>>1]=B;c=ca(e[a+28>>1]|0,i)|0;o=l+28|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){C=m&65535}else{C=-m>>31&16383}b[o>>1]=C;o=ca(e[a+30>>1]|0,i)|0;m=l+30|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){D=c&65535}else{D=-c>>31&16383}b[m>>1]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Dka(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=d>>1;d=(j<<6|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){p=o&65535}else{p=-o>>31&16383}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){q=m&65535}else{q=-m>>31&16383}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[m>>1]=r;m=ca(e[a+8>>1]|0,i)|0;c=l+8|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){s=o&65535}else{s=-o>>31&16383}b[c>>1]=s;c=ca(e[a+10>>1]|0,i)|0;o=l+10|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){t=m&65535}else{t=-m>>31&16383}b[o>>1]=t;o=ca(e[a+12>>1]|0,i)|0;m=l+12|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){u=c&65535}else{u=-c>>31&16383}b[m>>1]=u;m=ca(e[a+14>>1]|0,i)|0;c=l+14|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){v=o&65535}else{v=-o>>31&16383}b[c>>1]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Eka(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=d>>1;d=(j<<6|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){p=o&65535}else{p=-o>>31&16383}b[c>>1]=p;c=ca(e[a+4>>1]|0,i)|0;o=l+4|0;m=c+d+(ca(e[o>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){q=m&65535}else{q=-m>>31&16383}b[o>>1]=q;o=ca(e[a+6>>1]|0,i)|0;m=l+6|0;c=o+d+(ca(e[m>>1]|0,h)|0)>>j;if(c>>>0<16384>>>0){r=c&65535}else{r=-c>>31&16383}b[m>>1]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Fka(a,c,d,f,g,h,i,j){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=d>>1;d=(j<<6|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=a;a=c;while(1){c=ca(e[a>>1]|0,i)|0;m=c+d+(ca(e[l>>1]|0,h)|0)>>j;if(m>>>0<16384>>>0){n=m&65535}else{n=-m>>31&16383}b[l>>1]=n;m=ca(e[a+2>>1]|0,i)|0;c=l+2|0;o=m+d+(ca(e[c>>1]|0,h)|0)>>j;if(o>>>0<16384>>>0){p=o&65535}else{p=-o>>31&16383}b[c>>1]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+(k<<1)|0;a=a+(k<<1)|0}else{break}}return}function Gka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=d>>1;d=f<<6;f=g<<6;g=-i|0;j=i*-2|0;k=i*-3|0;l=i<<1;m=0;n=c;while(1){c=a[h+m|0]<<6;if((c|0)>=0){o=(c|0)==0;p=c|1;q=-c|0;r=0;s=n;while(1){t=s+(g<<1)|0;u=e[t>>1]|0;v=s+(j<<1)|0;w=e[v>>1]|0;x=e[s+(k<<1)>>1]|0;y=e[s>>1]|0;z=s+(i<<1)|0;A=e[z>>1]|0;B=e[s+(l<<1)>>1]|0;C=u-y|0;do{if((((C|0)>-1?C:-C|0)|0)<(d|0)){D=w-u|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=A-y|0;if((((D|0)>-1?D:-D|0)|0)>=(f|0)){break}D=x-u|0;E=(((D|0)>-1?D:-D|0)|0)>=(f|0);if(E|o){F=E?c:p}else{E=((((u+1+y|0)>>>1)+x|0)>>>1)-w|0;if((E|0)<(q|0)){G=q}else{G=(E|0)>(c|0)?c:E}b[v>>1]=G+w;F=p}E=B-y|0;if((((E|0)>-1?E:-E|0)|0)<(f|0)){if(!o){E=((B+((u+1+y|0)>>>1)|0)>>>1)-A|0;if((E|0)<(q|0)){H=q}else{H=(E|0)>(c|0)?c:E}b[z>>1]=H+A}I=F+1|0}else{I=F}E=w+4-A+(y-u<<2)>>3;D=-I|0;if((E|0)<(D|0)){J=D}else{J=(E|0)>(I|0)?I:E}E=J+u|0;if(E>>>0<16384>>>0){K=E&65535}else{K=-E>>31&16383}b[t>>1]=K;E=y-J|0;if(E>>>0<16384>>>0){L=E&65535}else{L=-E>>31&16383}b[s>>1]=L}}while(0);y=r+1|0;if((y|0)<4){r=y;s=s+2|0}else{break}}}s=m+1|0;if((s|0)<4){m=s;n=n+8|0}else{break}}return}function Hka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<6;f=g<<6;g=i<<2;j=0;k=c;while(1){c=a[h+j|0]<<6;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<16384>>>0){H=B&65535}else{H=-B>>31&16383}b[q>>1]=H;B=v-G|0;if(B>>>0<16384>>>0){I=B&65535}else{I=-B>>31&16383}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<4){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function Ika(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=d>>1;d=f<<6;f=g<<6;g=i<<1;j=0;k=c;while(1){c=a[h+j|0]<<6;if((c|0)>=0){l=(c|0)==0;m=c|1;n=-c|0;o=0;p=k;while(1){q=p-2|0;r=e[q>>1]|0;s=p-4|0;t=e[s>>1]|0;u=e[p-6>>1]|0;v=e[p>>1]|0;w=p+2|0;x=e[w>>1]|0;y=e[p+4>>1]|0;z=r-v|0;do{if((((z|0)>-1?z:-z|0)|0)<(d|0)){A=t-r|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=x-v|0;if((((A|0)>-1?A:-A|0)|0)>=(f|0)){break}A=u-r|0;B=(((A|0)>-1?A:-A|0)|0)>=(f|0);if(B|l){C=B?c:m}else{B=((((r+1+v|0)>>>1)+u|0)>>>1)-t|0;if((B|0)<(n|0)){D=n}else{D=(B|0)>(c|0)?c:B}b[s>>1]=D+t;C=m}B=y-v|0;if((((B|0)>-1?B:-B|0)|0)<(f|0)){if(!l){B=((y+((r+1+v|0)>>>1)|0)>>>1)-x|0;if((B|0)<(n|0)){E=n}else{E=(B|0)>(c|0)?c:B}b[w>>1]=E+x}F=C+1|0}else{F=C}B=t+4-x+(v-r<<2)>>3;A=-F|0;if((B|0)<(A|0)){G=A}else{G=(B|0)>(F|0)?F:B}B=G+r|0;if(B>>>0<16384>>>0){H=B&65535}else{H=-B>>31&16383}b[q>>1]=H;B=v-G|0;if(B>>>0<16384>>>0){I=B&65535}else{I=-B>>31&16383}b[p>>1]=I}}while(0);v=o+1|0;if((v|0)<2){o=v;p=p+(i<<1)|0}else{break}}}p=j+1|0;if((p|0)<4){j=p;k=k+(g<<1)|0}else{break}}return}function Jka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c>>1;c=d<<6;d=f<<6;f=g*-3|0;h=g*-2|0;i=-g|0;j=g<<1;k=c>>2|2;l=g*-4|0;m=g*3|0;n=0;o=a;while(1){a=o+(f<<1)|0;p=e[a>>1]|0;q=o+(h<<1)|0;r=e[q>>1]|0;s=o+(i<<1)|0;t=e[s>>1]|0;u=e[o>>1]|0;v=o+(g<<1)|0;w=e[v>>1]|0;x=o+(j<<1)|0;y=e[x>>1]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(c|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(d|0)){break}if((A|0)>=(k|0)){b[s>>1]=(t+2+(r<<1)+w|0)>>>2;b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(l<<1)>>1]|0;b[s>>1]=(p+4+w+(t+r+u<<1)|0)>>>3;b[q>>1]=(p+2+r+t+u|0)>>>2;b[a>>1]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{b[s>>1]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(d|0)){z=e[o+(m<<1)>>1]|0;b[o>>1]=(r+4+y+(u+t+w<<1)|0)>>>3;b[v>>1]=(t+2+u+w+y|0)>>>2;b[x>>1]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{b[o>>1]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+2|0}else{break}}return}function Kka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<6;d=f<<6;f=c>>2|2;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+(g<<1)|0}else{break}}return}function Lka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c>>1;c=d<<6;d=f<<6;f=c>>2|2;h=0;i=a;while(1){a=i-6|0;j=e[a>>1]|0;k=i-4|0;l=e[k>>1]|0;m=i-2|0;n=e[m>>1]|0;o=e[i>>1]|0;p=i+2|0;q=e[p>>1]|0;r=i+4|0;s=e[r>>1]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(c|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(d|0)){break}if((u|0)>=(f|0)){b[m>>1]=(n+2+(l<<1)+q|0)>>>2;b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i-8>>1]|0;b[m>>1]=(j+4+q+(n+l+o<<1)|0)>>>3;b[k>>1]=(j+2+l+n+o|0)>>>2;b[a>>1]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{b[m>>1]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(d|0)){t=e[i+6>>1]|0;b[i>>1]=(l+4+s+(o+n+q<<1)|0)>>>3;b[p>>1]=(n+2+o+q+s|0)>>>2;b[r>>1]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{b[i>>1]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+(g<<1)|0}else{break}}return}function Mka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=f<<6;f=g<<6;g=d>>1;d=-g|0;j=g*-2|0;k=0;l=c;while(1){c=a[h+k|0]<<6;m=c-63|0;do{if((m|0)>=1){n=63-c|0;o=l+(d<<1)|0;p=e[o>>1]|0;q=e[l+(j<<1)>>1]|0;r=e[l>>1]|0;s=e[l+(g<<1)>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(n|0)){v=n}else{v=(u|0)>(m|0)?m:u}u=v+p|0;if(u>>>0<16384>>>0){w=u&65535}else{w=-u>>31&16383}b[o>>1]=w;u=r-v|0;if(u>>>0<16384>>>0){x=u&65535}else{x=-u>>31&16383}b[l>>1]=x}}while(0);r=l+2|0;o=l+(1-g<<1)|0;p=e[o>>1]|0;s=e[l+((j|1)<<1)>>1]|0;q=e[r>>1]|0;t=e[l+(g+1<<1)>>1]|0;u=p-q|0;if((((u|0)>-1?u:-u|0)|0)>=(i|0)){break}u=s-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=t-q|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s+4-t+(q-p<<2)>>3;if((u|0)<(n|0)){y=n}else{y=(u|0)>(m|0)?m:u}u=y+p|0;if(u>>>0<16384>>>0){z=u&65535}else{z=-u>>31&16383}b[o>>1]=z;o=q-y|0;if(o>>>0<16384>>>0){A=o&65535}else{A=-o>>31&16383}b[r>>1]=A}}while(0);m=k+1|0;if((m|0)<4){k=m;l=l+4|0}else{break}}return}function Nka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<6;f=g<<6;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<6;l=c-63|0;do{if((l|0)>=1){m=63-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<16384>>>0){v=t&65535}else{v=-t>>31&16383}b[n>>1]=v;t=q-u|0;if(t>>>0<16384>>>0){w=t&65535}else{w=-t>>31&16383}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<16384>>>0){y=t&65535}else{y=-t>>31&16383}b[n>>1]=y;n=p-x|0;if(n>>>0<16384>>>0){z=n&65535}else{z=-n>>31&16383}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function Oka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=f<<6;f=g<<6;g=d>>1;d=g<<2;j=0;k=c;while(1){c=a[h+j|0]<<6;l=c-63|0;if((l|0)>=1){m=63-c|0;c=0;n=k;while(1){o=n-2|0;p=e[o>>1]|0;q=e[n-4>>1]|0;r=e[n>>1]|0;s=e[n+2>>1]|0;t=p-r|0;do{if((((t|0)>-1?t:-t|0)|0)<(i|0)){u=q-p|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=s-r|0;if((((u|0)>-1?u:-u|0)|0)>=(f|0)){break}u=q+4-s+(r-p<<2)>>3;if((u|0)<(m|0)){v=m}else{v=(u|0)>(l|0)?l:u}u=v+p|0;if(u>>>0<16384>>>0){w=u&65535}else{w=-u>>31&16383}b[o>>1]=w;u=r-v|0;if(u>>>0<16384>>>0){x=u&65535}else{x=-u>>31&16383}b[n>>1]=x}}while(0);r=c+1|0;if((r|0)<4){c=r;n=n+(g<<1)|0}else{break}}}n=j+1|0;if((n|0)<4){j=n;k=k+(d<<1)|0}else{break}}return}function Pka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=f<<6;f=g<<6;g=d>>1;d=0;j=c;while(1){c=a[h+d|0]<<6;k=c-63|0;do{if((k|0)>=1){l=63-c|0;m=j-2|0;n=e[m>>1]|0;o=e[j-4>>1]|0;p=e[j>>1]|0;q=e[j+2>>1]|0;r=n-p|0;if((((r|0)>-1?r:-r|0)|0)>=(i|0)){break}r=o-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=q-p|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=o+4-q+(p-n<<2)>>3;if((r|0)<(l|0)){s=l}else{s=(r|0)>(k|0)?k:r}r=s+n|0;if(r>>>0<16384>>>0){t=r&65535}else{t=-r>>31&16383}b[m>>1]=t;m=p-s|0;if(m>>>0<16384>>>0){u=m&65535}else{u=-m>>31&16383}b[j>>1]=u}}while(0);k=d+1|0;if((k|0)<4){d=k;j=j+(g<<1)|0}else{break}}return}function Qka(c,d,f,g,h){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=f<<6;f=g<<6;g=d>>1;d=g<<1;j=0;k=c;while(1){c=a[h+j|0]<<6;l=c-63|0;do{if((l|0)>=1){m=63-c|0;n=k-2|0;o=e[n>>1]|0;p=e[k-4>>1]|0;q=e[k>>1]|0;r=e[k+2>>1]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(i|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0<16384>>>0){v=t&65535}else{v=-t>>31&16383}b[n>>1]=v;t=q-u|0;if(t>>>0<16384>>>0){w=t&65535}else{w=-t>>31&16383}b[k>>1]=w}}while(0);q=k+(g<<1)|0;n=k+(g-1<<1)|0;o=e[n>>1]|0;r=e[k+(g-2<<1)>>1]|0;p=e[q>>1]|0;s=e[k+(g+1<<1)>>1]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(i|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0<16384>>>0){y=t&65535}else{y=-t>>31&16383}b[n>>1]=y;n=p-x|0;if(n>>>0<16384>>>0){z=n&65535}else{z=-n>>31&16383}b[q>>1]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+(d<<1)|0}else{break}}return}function Rka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c>>1;c=d<<6;d=f<<6;f=-g|0;h=g*-2|0;i=a;a=0;while(1){j=i+(f<<1)|0;k=e[j>>1]|0;l=e[i+(h<<1)>>1]|0;m=e[i>>1]|0;n=e[i+(g<<1)>>1]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(c|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(d|0)){break}b[j>>1]=(k+2+(l<<1)+n|0)>>>2;b[i>>1]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=a+1|0;if((n|0)<8){i=i+2|0;a=n}else{break}}return}function Ska(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<6;d=f<<6;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function Tka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<6;d=f<<6;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<16){f=f+(g<<1)|0;a=l}else{break}}return}function Uka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<6;d=f<<6;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<4){f=f+(g<<1)|0;a=l}else{break}}return}function Vka(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c>>1;c=d<<6;d=f<<6;f=a;a=0;while(1){h=f-2|0;i=e[h>>1]|0;j=e[f-4>>1]|0;k=e[f>>1]|0;l=e[f+2>>1]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(c|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(d|0)){break}b[h>>1]=(i+2+(j<<1)+l|0)>>>2;b[f>>1]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=a+1|0;if((l|0)<8){f=f+(g<<1)|0;a=l}else{break}}return}function Wka(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=h<<f;if((f|0)==0){j=i}else{j=i+(1<<f-1)|0}if((e|0)>0){k=0;l=b}else{return}while(1){b=(ca(d[l]|0,g)|0)+j>>f;if(b>>>0>255>>>0){m=-b>>31&255}else{m=b&255}a[l]=m;b=l+1|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b]=n;b=l+2|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){o=-i>>31&255}else{o=i&255}a[b]=o;b=l+3|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[b]=p;b=l+4|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[b]=q;b=l+5|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){r=-i>>31&255}else{r=i&255}a[b]=r;b=l+6|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){s=-i>>31&255}else{s=i&255}a[b]=s;b=l+7|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){t=-i>>31&255}else{t=i&255}a[b]=t;b=l+8|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){u=-i>>31&255}else{u=i&255}a[b]=u;b=l+9|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){v=-i>>31&255}else{v=i&255}a[b]=v;b=l+10|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){w=-i>>31&255}else{w=i&255}a[b]=w;b=l+11|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){x=-i>>31&255}else{x=i&255}a[b]=x;b=l+12|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){y=-i>>31&255}else{y=i&255}a[b]=y;b=l+13|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){z=-i>>31&255}else{z=i&255}a[b]=z;b=l+14|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){A=-i>>31&255}else{A=i&255}a[b]=A;b=l+15|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){B=-i>>31&255}else{B=i&255}a[b]=B;b=k+1|0;if((b|0)<(e|0)){k=b;l=l+c|0}else{break}}return}function Xka(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=h<<f;if((f|0)==0){j=i}else{j=i+(1<<f-1)|0}if((e|0)>0){k=0;l=b}else{return}while(1){b=(ca(d[l]|0,g)|0)+j>>f;if(b>>>0>255>>>0){m=-b>>31&255}else{m=b&255}a[l]=m;b=l+1|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b]=n;b=l+2|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){o=-i>>31&255}else{o=i&255}a[b]=o;b=l+3|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[b]=p;b=l+4|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[b]=q;b=l+5|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){r=-i>>31&255}else{r=i&255}a[b]=r;b=l+6|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){s=-i>>31&255}else{s=i&255}a[b]=s;b=l+7|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){t=-i>>31&255}else{t=i&255}a[b]=t;b=k+1|0;if((b|0)<(e|0)){k=b;l=l+c|0}else{break}}return}function Yka(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=h<<f;if((f|0)==0){j=i}else{j=i+(1<<f-1)|0}if((e|0)>0){k=0;l=b}else{return}while(1){b=(ca(d[l]|0,g)|0)+j>>f;if(b>>>0>255>>>0){m=-b>>31&255}else{m=b&255}a[l]=m;b=l+1|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b]=n;b=l+2|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){o=-i>>31&255}else{o=i&255}a[b]=o;b=l+3|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[b]=p;b=k+1|0;if((b|0)<(e|0)){k=b;l=l+c|0}else{break}}return}function Zka(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=h<<f;if((f|0)==0){j=i}else{j=i+(1<<f-1)|0}if((e|0)>0){k=0;l=b}else{return}while(1){b=(ca(d[l]|0,g)|0)+j>>f;if(b>>>0>255>>>0){m=-b>>31&255}else{m=b&255}a[l]=m;b=l+1|0;i=(ca(d[b]|0,g)|0)+j>>f;if(i>>>0>255>>>0){n=-i>>31&255}else{n=i&255}a[b]=n;b=k+1|0;if((b|0)<(e|0)){k=b;l=l+c|0}else{break}}return}function _ka(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;k=(j+1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=b;b=c;while(1){c=ca(d[b]|0,i)|0;m=c+k+(ca(d[l]|0,h)|0)>>j;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=ca(d[b+1|0]|0,i)|0;c=l+1|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c]=p;c=ca(d[b+2|0]|0,i)|0;o=l+2|0;m=c+k+(ca(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[o]=q;o=ca(d[b+3|0]|0,i)|0;m=l+3|0;c=o+k+(ca(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){r=-c>>31&255}else{r=c&255}a[m]=r;m=ca(d[b+4|0]|0,i)|0;c=l+4|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){s=-o>>31&255}else{s=o&255}a[c]=s;c=ca(d[b+5|0]|0,i)|0;o=l+5|0;m=c+k+(ca(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){t=-m>>31&255}else{t=m&255}a[o]=t;o=ca(d[b+6|0]|0,i)|0;m=l+6|0;c=o+k+(ca(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){u=-c>>31&255}else{u=c&255}a[m]=u;m=ca(d[b+7|0]|0,i)|0;c=l+7|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){v=-o>>31&255}else{v=o&255}a[c]=v;c=ca(d[b+8|0]|0,i)|0;o=l+8|0;m=c+k+(ca(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){w=-m>>31&255}else{w=m&255}a[o]=w;o=ca(d[b+9|0]|0,i)|0;m=l+9|0;c=o+k+(ca(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){x=-c>>31&255}else{x=c&255}a[m]=x;m=ca(d[b+10|0]|0,i)|0;c=l+10|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){y=-o>>31&255}else{y=o&255}a[c]=y;c=ca(d[b+11|0]|0,i)|0;o=l+11|0;m=c+k+(ca(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){z=-m>>31&255}else{z=m&255}a[o]=z;o=ca(d[b+12|0]|0,i)|0;m=l+12|0;c=o+k+(ca(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){A=-c>>31&255}else{A=c&255}a[m]=A;m=ca(d[b+13|0]|0,i)|0;c=l+13|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){B=-o>>31&255}else{B=o&255}a[c]=B;c=ca(d[b+14|0]|0,i)|0;o=l+14|0;m=c+k+(ca(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){C=-m>>31&255}else{C=m&255}a[o]=C;o=ca(d[b+15|0]|0,i)|0;m=l+15|0;c=o+k+(ca(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){D=-c>>31&255}else{D=c&255}a[m]=D;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+e|0;b=b+e|0}else{break}}return}function $ka(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=(j+1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=b;b=c;while(1){c=ca(d[b]|0,i)|0;m=c+k+(ca(d[l]|0,h)|0)>>j;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=ca(d[b+1|0]|0,i)|0;c=l+1|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c]=p;c=ca(d[b+2|0]|0,i)|0;o=l+2|0;m=c+k+(ca(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[o]=q;o=ca(d[b+3|0]|0,i)|0;m=l+3|0;c=o+k+(ca(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){r=-c>>31&255}else{r=c&255}a[m]=r;m=ca(d[b+4|0]|0,i)|0;c=l+4|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){s=-o>>31&255}else{s=o&255}a[c]=s;c=ca(d[b+5|0]|0,i)|0;o=l+5|0;m=c+k+(ca(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){t=-m>>31&255}else{t=m&255}a[o]=t;o=ca(d[b+6|0]|0,i)|0;m=l+6|0;c=o+k+(ca(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){u=-c>>31&255}else{u=c&255}a[m]=u;m=ca(d[b+7|0]|0,i)|0;c=l+7|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){v=-o>>31&255}else{v=o&255}a[c]=v;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+e|0;b=b+e|0}else{break}}return}function ala(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=(j+1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=b;b=c;while(1){c=ca(d[b]|0,i)|0;m=c+k+(ca(d[l]|0,h)|0)>>j;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=ca(d[b+1|0]|0,i)|0;c=l+1|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c]=p;c=ca(d[b+2|0]|0,i)|0;o=l+2|0;m=c+k+(ca(d[o]|0,h)|0)>>j;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[o]=q;o=ca(d[b+3|0]|0,i)|0;m=l+3|0;c=o+k+(ca(d[m]|0,h)|0)>>j;if(c>>>0>255>>>0){r=-c>>31&255}else{r=c&255}a[m]=r;m=g+1|0;if((m|0)<(f|0)){g=m;l=l+e|0;b=b+e|0}else{break}}return}function bla(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=(j+1|1)<<g;if((f|0)<=0){return}j=g+1|0;g=0;l=b;b=c;while(1){c=ca(d[b]|0,i)|0;m=c+k+(ca(d[l]|0,h)|0)>>j;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=ca(d[b+1|0]|0,i)|0;c=l+1|0;o=m+k+(ca(d[c]|0,h)|0)>>j;if(o>>>0>255>>>0){p=-o>>31&255}else{p=o&255}a[c]=p;c=g+1|0;if((c|0)<(f|0)){g=c;l=l+e|0;b=b+e|0}else{break}}return}function cla(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=-c|0;i=c*-2|0;j=c*-3|0;k=c<<1;l=0;m=b;while(1){b=a[g+l|0]|0;n=b<<24>>24;if(!(b<<24>>24<0)){o=b<<24>>24==0;b=n+1|0;p=-n|0;q=0;r=m;while(1){s=r+h|0;t=d[s]|0;u=r+i|0;v=d[u]|0;w=d[r+j|0]|0;x=d[r]|0;y=r+c|0;z=d[y]|0;A=d[r+k|0]|0;B=t-x|0;do{if((((B|0)>-1?B:-B|0)|0)<(e|0)){C=v-t|0;if((((C|0)>-1?C:-C|0)|0)>=(f|0)){break}C=z-x|0;if((((C|0)>-1?C:-C|0)|0)>=(f|0)){break}C=w-t|0;D=(((C|0)>-1?C:-C|0)|0)>=(f|0);if(D|o){E=D?n:b}else{D=((((t+1+x|0)>>>1)+w|0)>>>1)-v|0;if((D|0)<(p|0)){F=p}else{F=(D|0)>(n|0)?n:D}a[u]=F+v;E=b}D=A-x|0;if((((D|0)>-1?D:-D|0)|0)<(f|0)){if(!o){D=((A+((t+1+x|0)>>>1)|0)>>>1)-z|0;if((D|0)<(p|0)){G=p}else{G=(D|0)>(n|0)?n:D}a[y]=G+z}H=E+1|0}else{H=E}D=v+4-z+(x-t<<2)>>3;C=-H|0;if((D|0)<(C|0)){I=C}else{I=(D|0)>(H|0)?H:D}D=I+t|0;if(D>>>0>255>>>0){J=-D>>31&255}else{J=D&255}a[s]=J;D=x-I|0;if(D>>>0>255>>>0){K=-D>>31&255}else{K=D&255}a[r]=K}}while(0);x=q+1|0;if((x|0)<4){q=x;r=r+1|0}else{break}}}r=l+1|0;if((r|0)<4){l=r;m=m+4|0}else{break}}return}function dla(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=c<<2;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;if(!(b<<24>>24<0)){l=b<<24>>24==0;b=k+1|0;m=-k|0;n=0;o=j;while(1){p=o-1|0;q=d[p]|0;r=o-2|0;s=d[r]|0;t=d[o-3|0]|0;u=d[o]|0;v=o+1|0;w=d[v]|0;x=d[o+2|0]|0;y=q-u|0;do{if((((y|0)>-1?y:-y|0)|0)<(e|0)){z=s-q|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=t-q|0;A=(((z|0)>-1?z:-z|0)|0)>=(f|0);if(A|l){B=A?k:b}else{A=((((q+1+u|0)>>>1)+t|0)>>>1)-s|0;if((A|0)<(m|0)){C=m}else{C=(A|0)>(k|0)?k:A}a[r]=C+s;B=b}A=x-u|0;if((((A|0)>-1?A:-A|0)|0)<(f|0)){if(!l){A=((x+((q+1+u|0)>>>1)|0)>>>1)-w|0;if((A|0)<(m|0)){D=m}else{D=(A|0)>(k|0)?k:A}a[v]=D+w}E=B+1|0}else{E=B}A=s+4-w+(u-q<<2)>>3;z=-E|0;if((A|0)<(z|0)){F=z}else{F=(A|0)>(E|0)?E:A}A=F+q|0;if(A>>>0>255>>>0){G=-A>>31&255}else{G=A&255}a[p]=G;A=u-F|0;if(A>>>0>255>>>0){H=-A>>31&255}else{H=A&255}a[o]=H}}while(0);u=n+1|0;if((u|0)<4){n=u;o=o+c|0}else{break}}}o=i+1|0;if((o|0)<4){i=o;j=j+h|0}else{break}}return}function ela(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=c<<1;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;if(!(b<<24>>24<0)){l=b<<24>>24==0;b=k+1|0;m=-k|0;n=0;o=j;while(1){p=o-1|0;q=d[p]|0;r=o-2|0;s=d[r]|0;t=d[o-3|0]|0;u=d[o]|0;v=o+1|0;w=d[v]|0;x=d[o+2|0]|0;y=q-u|0;do{if((((y|0)>-1?y:-y|0)|0)<(e|0)){z=s-q|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=t-q|0;A=(((z|0)>-1?z:-z|0)|0)>=(f|0);if(A|l){B=A?k:b}else{A=((((q+1+u|0)>>>1)+t|0)>>>1)-s|0;if((A|0)<(m|0)){C=m}else{C=(A|0)>(k|0)?k:A}a[r]=C+s;B=b}A=x-u|0;if((((A|0)>-1?A:-A|0)|0)<(f|0)){if(!l){A=((x+((q+1+u|0)>>>1)|0)>>>1)-w|0;if((A|0)<(m|0)){D=m}else{D=(A|0)>(k|0)?k:A}a[v]=D+w}E=B+1|0}else{E=B}A=s+4-w+(u-q<<2)>>3;z=-E|0;if((A|0)<(z|0)){F=z}else{F=(A|0)>(E|0)?E:A}A=F+q|0;if(A>>>0>255>>>0){G=-A>>31&255}else{G=A&255}a[p]=G;A=u-F|0;if(A>>>0>255>>>0){H=-A>>31&255}else{H=A&255}a[o]=H}}while(0);u=n+1|0;if((u|0)<2){n=u;o=o+c|0}else{break}}}o=i+1|0;if((o|0)<4){i=o;j=j+h|0}else{break}}return}function fla(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c*-3|0;h=c*-2|0;i=-c|0;j=c<<1;k=(e>>2)+2|0;l=c*-4|0;m=c*3|0;n=0;o=b;while(1){b=o+g|0;p=d[b]|0;q=o+h|0;r=d[q]|0;s=o+i|0;t=d[s]|0;u=d[o]|0;v=o+c|0;w=d[v]|0;x=o+j|0;y=d[x]|0;z=t-u|0;A=(z|0)>-1?z:-z|0;do{if((A|0)<(e|0)){z=r-t|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}z=w-u|0;if((((z|0)>-1?z:-z|0)|0)>=(f|0)){break}if((A|0)>=(k|0)){a[s]=(t+2+(r<<1)+w|0)>>>2;a[o]=(r+2+u+(w<<1)|0)>>>2;break}z=p-t|0;if((((z|0)>-1?z:-z|0)|0)<(f|0)){z=d[o+l|0]|0;a[s]=(p+4+w+(t+r+u<<1)|0)>>>3;a[q]=(p+2+r+t+u|0)>>>2;a[b]=((p*3|0)+4+r+t+u+(z<<1)|0)>>>3}else{a[s]=(t+2+(r<<1)+w|0)>>>2}z=y-u|0;if((((z|0)>-1?z:-z|0)|0)<(f|0)){z=d[o+m|0]|0;a[o]=(r+4+y+(u+t+w<<1)|0)>>>3;a[v]=(t+2+u+w+y|0)>>>2;a[x]=(t+4+u+w+(y*3|0)+(z<<1)|0)>>>3;break}else{a[o]=(r+2+u+(w<<1)|0)>>>2;break}}}while(0);w=n+1|0;if((w|0)<16){n=w;o=o+1|0}else{break}}return}function gla(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=(e>>2)+2|0;h=0;i=b;while(1){b=i-3|0;j=d[b]|0;k=i-2|0;l=d[k]|0;m=i-1|0;n=d[m]|0;o=d[i]|0;p=i+1|0;q=d[p]|0;r=i+2|0;s=d[r]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(e|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}if((u|0)>=(g|0)){a[m]=(n+2+(l<<1)+q|0)>>>2;a[i]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[i-4|0]|0;a[m]=(j+4+q+(n+l+o<<1)|0)>>>3;a[k]=(j+2+l+n+o|0)>>>2;a[b]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{a[m]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[i+3|0]|0;a[i]=(l+4+s+(o+n+q<<1)|0)>>>3;a[p]=(n+2+o+q+s|0)>>>2;a[r]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{a[i]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<16){h=q;i=i+c|0}else{break}}return}function hla(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=(e>>2)+2|0;h=0;i=b;while(1){b=i-3|0;j=d[b]|0;k=i-2|0;l=d[k]|0;m=i-1|0;n=d[m]|0;o=d[i]|0;p=i+1|0;q=d[p]|0;r=i+2|0;s=d[r]|0;t=n-o|0;u=(t|0)>-1?t:-t|0;do{if((u|0)<(e|0)){t=l-n|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=q-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}if((u|0)>=(g|0)){a[m]=(n+2+(l<<1)+q|0)>>>2;a[i]=(l+2+o+(q<<1)|0)>>>2;break}t=j-n|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[i-4|0]|0;a[m]=(j+4+q+(n+l+o<<1)|0)>>>3;a[k]=(j+2+l+n+o|0)>>>2;a[b]=((j*3|0)+4+l+n+o+(t<<1)|0)>>>3}else{a[m]=(n+2+(l<<1)+q|0)>>>2}t=s-o|0;if((((t|0)>-1?t:-t|0)|0)<(f|0)){t=d[i+3|0]|0;a[i]=(l+4+s+(o+n+q<<1)|0)>>>3;a[p]=(n+2+o+q+s|0)>>>2;a[r]=(n+4+o+q+(s*3|0)+(t<<1)|0)>>>3;break}else{a[i]=(l+2+o+(q<<1)|0)>>>2;break}}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+c|0}else{break}}return}function ila(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=-c|0;i=c*-2|0;j=0;k=b;while(1){b=a[g+j|0]|0;l=b<<24>>24;do{if(!(b<<24>>24<1)){m=-l|0;n=k+h|0;o=d[n]|0;p=d[k+i|0]|0;q=d[k]|0;r=d[k+c|0]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(e|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(m|0)){u=m}else{u=(t|0)>(l|0)?l:t}t=u+o|0;if(t>>>0>255>>>0){v=-t>>31&255}else{v=t&255}a[n]=v;t=q-u|0;if(t>>>0>255>>>0){w=-t>>31&255}else{w=t&255}a[k]=w}}while(0);q=k+1|0;n=k+(1-c)|0;o=d[n]|0;r=d[k+(i|1)|0]|0;p=d[q]|0;s=d[k+(c+1)|0]|0;t=o-p|0;if((((t|0)>-1?t:-t|0)|0)>=(e|0)){break}t=r-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=s-p|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r+4-s+(p-o<<2)>>3;if((t|0)<(m|0)){x=m}else{x=(t|0)>(l|0)?l:t}t=x+o|0;if(t>>>0>255>>>0){y=-t>>31&255}else{y=t&255}a[n]=y;n=p-x|0;if(n>>>0>255>>>0){z=-n>>31&255}else{z=n&255}a[q]=z}}while(0);l=j+1|0;if((l|0)<4){j=l;k=k+2|0}else{break}}return}function jla(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=c<<1;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;do{if(!(b<<24>>24<1)){l=-k|0;m=j-1|0;n=d[m]|0;o=d[j-2|0]|0;p=d[j]|0;q=d[j+1|0]|0;r=n-p|0;do{if((((r|0)>-1?r:-r|0)|0)<(e|0)){s=o-n|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=q-p|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=o+4-q+(p-n<<2)>>3;if((s|0)<(l|0)){t=l}else{t=(s|0)>(k|0)?k:s}s=t+n|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[m]=u;s=p-t|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[j]=v}}while(0);p=j+c|0;m=j+(c-1)|0;n=d[m]|0;q=d[j+(c-2)|0]|0;o=d[p]|0;r=d[j+(c+1)|0]|0;s=n-o|0;if((((s|0)>-1?s:-s|0)|0)>=(e|0)){break}s=q-n|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=r-o|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=q+4-r+(o-n<<2)>>3;if((s|0)<(l|0)){w=l}else{w=(s|0)>(k|0)?k:s}s=w+n|0;if(s>>>0>255>>>0){x=-s>>31&255}else{x=s&255}a[m]=x;m=o-w|0;if(m>>>0>255>>>0){y=-m>>31&255}else{y=m&255}a[p]=y}}while(0);k=i+1|0;if((k|0)<4){i=k;j=j+h|0}else{break}}return}function kla(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=c<<2;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;if(!(b<<24>>24<1)){b=-k|0;l=0;m=j;while(1){n=m-1|0;o=d[n]|0;p=d[m-2|0]|0;q=d[m]|0;r=d[m+1|0]|0;s=o-q|0;do{if((((s|0)>-1?s:-s|0)|0)<(e|0)){t=p-o|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>=(f|0)){break}t=p+4-r+(q-o<<2)>>3;if((t|0)<(b|0)){u=b}else{u=(t|0)>(k|0)?k:t}t=u+o|0;if(t>>>0>255>>>0){v=-t>>31&255}else{v=t&255}a[n]=v;t=q-u|0;if(t>>>0>255>>>0){w=-t>>31&255}else{w=t&255}a[m]=w}}while(0);q=l+1|0;if((q|0)<4){l=q;m=m+c|0}else{break}}}m=i+1|0;if((m|0)<4){i=m;j=j+h|0}else{break}}return}function lla(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=0;i=b;while(1){b=a[g+h|0]|0;j=b<<24>>24;do{if(!(b<<24>>24<1)){k=-j|0;l=i-1|0;m=d[l]|0;n=d[i-2|0]|0;o=d[i]|0;p=d[i+1|0]|0;q=m-o|0;if((((q|0)>-1?q:-q|0)|0)>=(e|0)){break}q=n-m|0;if((((q|0)>-1?q:-q|0)|0)>=(f|0)){break}q=p-o|0;if((((q|0)>-1?q:-q|0)|0)>=(f|0)){break}q=n+4-p+(o-m<<2)>>3;if((q|0)<(k|0)){r=k}else{r=(q|0)>(j|0)?j:q}q=r+m|0;if(q>>>0>255>>>0){s=-q>>31&255}else{s=q&255}a[l]=s;l=o-r|0;if(l>>>0>255>>>0){t=-l>>31&255}else{t=l&255}a[i]=t}}while(0);j=h+1|0;if((j|0)<4){h=j;i=i+c|0}else{break}}return}function mla(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=c<<1;i=0;j=b;while(1){b=a[g+i|0]|0;k=b<<24>>24;do{if(!(b<<24>>24<1)){l=-k|0;m=j-1|0;n=d[m]|0;o=d[j-2|0]|0;p=d[j]|0;q=d[j+1|0]|0;r=n-p|0;do{if((((r|0)>-1?r:-r|0)|0)<(e|0)){s=o-n|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=q-p|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=o+4-q+(p-n<<2)>>3;if((s|0)<(l|0)){t=l}else{t=(s|0)>(k|0)?k:s}s=t+n|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[m]=u;s=p-t|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[j]=v}}while(0);p=j+c|0;m=j+(c-1)|0;n=d[m]|0;q=d[j+(c-2)|0]|0;o=d[p]|0;r=d[j+(c+1)|0]|0;s=n-o|0;if((((s|0)>-1?s:-s|0)|0)>=(e|0)){break}s=q-n|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=r-o|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=q+4-r+(o-n<<2)>>3;if((s|0)<(l|0)){w=l}else{w=(s|0)>(k|0)?k:s}s=w+n|0;if(s>>>0>255>>>0){x=-s>>31&255}else{x=s&255}a[m]=x;m=o-w|0;if(m>>>0>255>>>0){y=-m>>31&255}else{y=m&255}a[p]=y}}while(0);k=i+1|0;if((k|0)<4){i=k;j=j+h|0}else{break}}return}function nla(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=-c|0;h=c*-2|0;i=b;b=0;while(1){j=i+g|0;k=d[j]|0;l=d[i+h|0]|0;m=d[i]|0;n=d[i+c|0]|0;o=k-m|0;do{if((((o|0)>-1?o:-o|0)|0)<(e|0)){p=l-k|0;if((((p|0)>-1?p:-p|0)|0)>=(f|0)){break}p=n-m|0;if((((p|0)>-1?p:-p|0)|0)>=(f|0)){break}a[j]=(k+2+(l<<1)+n|0)>>>2;a[i]=(l+2+m+(n<<1)|0)>>>2}}while(0);n=b+1|0;if((n|0)<8){i=i+1|0;b=n}else{break}}return}function ola(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;b=0;while(1){h=g-1|0;i=d[h]|0;j=d[g-2|0]|0;k=d[g]|0;l=d[g+1|0]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[h]=(i+2+(j<<1)+l|0)>>>2;a[g]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=b+1|0;if((l|0)<8){g=g+c|0;b=l}else{break}}return}function pla(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;b=0;while(1){h=g-1|0;i=d[h]|0;j=d[g-2|0]|0;k=d[g]|0;l=d[g+1|0]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[h]=(i+2+(j<<1)+l|0)>>>2;a[g]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=b+1|0;if((l|0)<16){g=g+c|0;b=l}else{break}}return}function qla(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;b=0;while(1){h=g-1|0;i=d[h]|0;j=d[g-2|0]|0;k=d[g]|0;l=d[g+1|0]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[h]=(i+2+(j<<1)+l|0)>>>2;a[g]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=b+1|0;if((l|0)<4){g=g+c|0;b=l}else{break}}return}function rla(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;b=0;while(1){h=g-1|0;i=d[h]|0;j=d[g-2|0]|0;k=d[g]|0;l=d[g+1|0]|0;m=i-k|0;do{if((((m|0)>-1?m:-m|0)|0)<(e|0)){n=j-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=l-k|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}a[h]=(i+2+(j<<1)+l|0)>>>2;a[g]=(j+2+k+(l<<1)|0)>>>2}}while(0);l=b+1|0;if((l|0)<8){g=g+c|0;b=l}else{break}}return}function sla(b,c){b=b|0;c=c|0;var d=0,e=0;d=0;while(1){if((d|0)>=(c|0)){e=4;break}if((a[b+d|0]|0)==0){e=4;break}else{d=d+1|0}}if((e|0)==4){return d|0}return 0}function tla(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=((b[e>>1]|0)+32&65535)<<16>>16;h=e+16|0;i=b[h>>1]|0;j=i+g|0;k=g-i|0;i=e+8|0;g=b[i>>1]|0;l=e+24|0;m=b[l>>1]|0;n=(g>>1)-m|0;o=(m>>1)+g|0;b[e>>1]=o+j;b[i>>1]=n+k;b[h>>1]=k-n;b[l>>1]=j-o;o=e+2|0;j=b[o>>1]|0;l=e+18|0;n=b[l>>1]|0;k=n+j|0;h=j-n|0;n=e+10|0;j=b[n>>1]|0;i=e+26|0;g=b[i>>1]|0;m=(j>>1)-g|0;p=(g>>1)+j|0;b[o>>1]=p+k;b[n>>1]=m+h;b[l>>1]=h-m;b[i>>1]=k-p;p=e+4|0;k=b[p>>1]|0;i=e+20|0;m=b[i>>1]|0;h=m+k|0;l=k-m|0;m=e+12|0;k=b[m>>1]|0;n=e+28|0;o=b[n>>1]|0;j=(k>>1)-o|0;g=(o>>1)+k|0;b[p>>1]=g+h;b[m>>1]=j+l;b[i>>1]=l-j;b[n>>1]=h-g;g=e+6|0;h=b[g>>1]|0;n=e+22|0;j=b[n>>1]|0;l=j+h|0;i=h-j|0;j=e+14|0;h=b[j>>1]|0;m=e+30|0;p=b[m>>1]|0;k=(h>>1)-p|0;o=(p>>1)+h|0;b[g>>1]=o+l;b[j>>1]=k+i;b[n>>1]=i-k;b[m>>1]=l-o;o=f<<1;l=f*3|0;m=0;do{k=m<<2;i=b[e+(k<<1)>>1]|0;n=b[e+((k|2)<<1)>>1]|0;j=n+i|0;g=i-n|0;n=b[e+((k|1)<<1)>>1]|0;i=b[e+((k|3)<<1)>>1]|0;k=(n>>1)-i|0;h=(i>>1)+n|0;n=c+m|0;i=(h+j>>6)+(d[n]|0)|0;if(i>>>0>255>>>0){q=-i>>31&255}else{q=i&255}a[n]=q;n=c+(m+f)|0;i=(d[n]|0)+(k+g>>6)|0;if(i>>>0>255>>>0){r=-i>>31&255}else{r=i&255}a[n]=r;n=c+(m+o)|0;i=(d[n]|0)+(g-k>>6)|0;if(i>>>0>255>>>0){s=-i>>31&255}else{s=i&255}a[n]=s;n=c+(m+l)|0;i=(d[n]|0)+(j-h>>6)|0;if(i>>>0>255>>>0){t=-i>>31&255}else{t=i&255}a[n]=t;m=m+1|0;}while((m|0)<4);mrc(e|0,0,32)|0;return}function ula(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=(b[e>>1]|0)+32&65535;b[e>>1]=g;h=0;i=g;while(1){g=i<<16>>16;j=e+(h+32<<1)|0;k=b[j>>1]|0;l=k+g|0;m=g-k|0;k=e+(h+16<<1)|0;g=b[k>>1]|0;n=e+(h+48<<1)|0;o=b[n>>1]|0;p=(g>>1)-o|0;q=(o>>1)+g|0;g=q+l|0;o=p+m|0;r=m-p|0;p=l-q|0;q=e+(h+24<<1)|0;l=b[q>>1]|0;m=e+(h+40<<1)|0;s=b[m>>1]|0;t=e+(h+56<<1)|0;u=b[t>>1]|0;v=s-l-u-(u>>1)|0;w=e+(h+8<<1)|0;x=b[w>>1]|0;y=u-((l>>1)+l)+x|0;z=u+s+(s>>1)-x|0;u=s+l+x+(x>>1)|0;x=(u>>2)+v|0;l=(z>>2)+y|0;s=(y>>2)-z|0;z=u-(v>>2)|0;b[e+(h<<1)>>1]=z+g;b[t>>1]=g-z;b[w>>1]=s+o;b[n>>1]=o-s;b[k>>1]=l+r;b[m>>1]=r-l;b[q>>1]=x+p;b[j>>1]=p-x;x=h+1|0;if((x|0)>=8){break}h=x;i=b[e+(x<<1)>>1]|0}i=f<<1;h=f*3|0;x=f<<2;p=f*5|0;j=f*6|0;q=f*7|0;l=0;do{r=l<<3;m=b[e+(r<<1)>>1]|0;k=b[e+((r|4)<<1)>>1]|0;s=k+m|0;o=m-k|0;k=b[e+((r|2)<<1)>>1]|0;m=b[e+((r|6)<<1)>>1]|0;n=(k>>1)-m|0;w=(m>>1)+k|0;k=w+s|0;m=n+o|0;z=o-n|0;n=s-w|0;w=b[e+((r|3)<<1)>>1]|0;s=b[e+((r|5)<<1)>>1]|0;o=b[e+((r|7)<<1)>>1]|0;g=s-w-o-(o>>1)|0;t=b[e+((r|1)<<1)>>1]|0;r=o-((w>>1)+w)+t|0;v=o+s+(s>>1)-t|0;o=s+w+t+(t>>1)|0;t=(o>>2)+g|0;w=(v>>2)+r|0;s=(r>>2)-v|0;v=o-(g>>2)|0;g=c+l|0;o=(v+k>>6)+(d[g]|0)|0;if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}a[g]=A;g=c+(l+f)|0;o=(d[g]|0)+(s+m>>6)|0;if(o>>>0>255>>>0){B=-o>>31&255}else{B=o&255}a[g]=B;g=c+(l+i)|0;o=(d[g]|0)+(w+z>>6)|0;if(o>>>0>255>>>0){C=-o>>31&255}else{C=o&255}a[g]=C;g=c+(l+h)|0;o=(d[g]|0)+(t+n>>6)|0;if(o>>>0>255>>>0){D=-o>>31&255}else{D=o&255}a[g]=D;g=c+(l+x)|0;o=(d[g]|0)+(n-t>>6)|0;if(o>>>0>255>>>0){E=-o>>31&255}else{E=o&255}a[g]=E;g=c+(l+p)|0;o=(d[g]|0)+(z-w>>6)|0;if(o>>>0>255>>>0){F=-o>>31&255}else{F=o&255}a[g]=F;g=c+(l+j)|0;o=(d[g]|0)+(m-s>>6)|0;if(o>>>0>255>>>0){G=-o>>31&255}else{G=o&255}a[g]=G;g=c+(l+q)|0;o=(d[g]|0)+(k-v>>6)|0;if(o>>>0>255>>>0){H=-o>>31&255}else{H=o&255}a[g]=H;l=l+1|0;}while((l|0)<8);mrc(e|0,0,128)|0;return}function vla(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=(b[e>>1]|0)+32>>6;b[e>>1]=0;e=0;h=c;while(1){c=(d[h]|0)+g|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=e+1|0;if((c|0)<4){e=c;h=h+f|0}else{break}}return}function wla(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=(b[e>>1]|0)+32>>6;b[e>>1]=0;e=0;h=c;while(1){c=(d[h]|0)+g|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=h+4|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[c]=n;c=h+5|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[c]=o;c=h+6|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[c]=p;c=h+7|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[c]=q;c=e+1|0;if((c|0)<8){e=c;h=h+f|0}else{break}}return}function xla(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=0;do{k=a[i+(d[602104+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){l=g+(j<<4<<1)|0;m=b[l>>1]|0;if(m<<16>>16==0){n=l;o=15;break}p=e+(c[f+(j<<2)>>2]|0)|0;q=(m<<16>>16)+32>>6;b[l>>1]=0;l=0;m=p;while(1){p=(d[m]|0)+q|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[m]=r;p=m+1|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){t=-s>>31&255}else{t=s&255}a[p]=t;p=m+2|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[p]=u;p=m+3|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[p]=v;p=l+1|0;if((p|0)<4){l=p;m=m+h|0}else{break}}}else if((k<<24>>24|0)!=0){n=g+(j<<4<<1)|0;o=15}}while(0);if((o|0)==15){o=0;tla(e+(c[f+(j<<2)>>2]|0)|0,n,h)}j=j+1|0;}while((j|0)<16);return}function yla(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=0;do{do{if((a[i+(d[602104+j|0]|0)|0]|0)==0){k=g+(j<<4<<1)|0;l=b[k>>1]|0;if(l<<16>>16==0){break}m=e+(c[f+(j<<2)>>2]|0)|0;n=(l<<16>>16)+32>>6;b[k>>1]=0;k=0;l=m;while(1){m=(d[l]|0)+n|0;if(m>>>0>255>>>0){o=-m>>31&255}else{o=m&255}a[l]=o;m=l+1|0;p=(d[m]|0)+n|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[m]=q;m=l+2|0;p=(d[m]|0)+n|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[m]=r;m=l+3|0;p=(d[m]|0)+n|0;if(p>>>0>255>>>0){s=-p>>31&255}else{s=p&255}a[m]=s;m=k+1|0;if((m|0)<4){k=m;l=l+h|0}else{break}}}else{tla(e+(c[f+(j<<2)>>2]|0)|0,g+(j<<4<<1)|0,h)}}while(0);j=j+1|0;}while((j|0)<16);return}function zla(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=a[h+12|0]|0;do{if((i<<24>>24|0)==1){if((b[f>>1]|0)==0){j=4;break}wla(d+(c[e>>2]|0)|0,f,g)}else if((i<<24>>24|0)!=0){j=4}}while(0);if((j|0)==4){ula(d+(c[e>>2]|0)|0,f,g)}i=a[h+14|0]|0;do{if((i<<24>>24|0)==1){k=f+128|0;if((b[k>>1]|0)==0){l=k;j=9;break}wla(d+(c[e+16>>2]|0)|0,k,g)}else if((i<<24>>24|0)!=0){l=f+128|0;j=9}}while(0);if((j|0)==9){ula(d+(c[e+16>>2]|0)|0,l,g)}l=a[h+28|0]|0;do{if((l<<24>>24|0)==1){i=f+256|0;if((b[i>>1]|0)==0){m=i;j=14;break}wla(d+(c[e+32>>2]|0)|0,i,g)}else if((l<<24>>24|0)!=0){m=f+256|0;j=14}}while(0);if((j|0)==14){ula(d+(c[e+32>>2]|0)|0,m,g)}m=a[h+30|0]|0;do{if((m<<24>>24|0)==0){return}else if((m<<24>>24|0)==1){h=f+384|0;if((b[h>>1]|0)==0){n=h;break}wla(d+(c[e+48>>2]|0)|0,h,g);return}else{n=f+384|0}}while(0);ula(d+(c[e+48>>2]|0)|0,n,g);return}function Ala(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=1;do{k=j<<4;l=k|4;if((k|0)<(l|0)){m=e+(j-1<<2)|0;n=k;do{do{if((a[i+(d[602104+n|0]|0)|0]|0)==0){k=g+(n<<4<<1)|0;o=b[k>>1]|0;if(o<<16>>16==0){break}p=(c[m>>2]|0)+(c[f+(n<<2)>>2]|0)|0;q=(o<<16>>16)+32>>6;b[k>>1]=0;k=0;o=p;while(1){p=(d[o]|0)+q|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[o]=r;p=o+1|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){t=-s>>31&255}else{t=s&255}a[p]=t;p=o+2|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[p]=u;p=o+3|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[p]=v;p=k+1|0;if((p|0)<4){k=p;o=o+h|0}else{break}}}else{tla((c[m>>2]|0)+(c[f+(n<<2)>>2]|0)|0,g+(n<<4<<1)|0,h)}}while(0);n=n+1|0;}while((n|0)<(l|0))}j=j+1|0;}while((j|0)<3);return}function Bla(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=1;while(1){k=j<<4;l=k|4;if((k|0)<(l|0)){m=e+(j-1<<2)|0;n=k;do{do{if((a[i+(d[602104+n|0]|0)|0]|0)==0){k=g+(n<<4<<1)|0;o=b[k>>1]|0;if(o<<16>>16==0){break}p=(c[m>>2]|0)+(c[f+(n<<2)>>2]|0)|0;q=(o<<16>>16)+32>>6;b[k>>1]=0;k=0;o=p;while(1){p=(d[o]|0)+q|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[o]=r;p=o+1|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){t=-s>>31&255}else{t=s&255}a[p]=t;p=o+2|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[p]=u;p=o+3|0;s=(d[p]|0)+q|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[p]=v;p=k+1|0;if((p|0)<4){k=p;o=o+h|0}else{break}}}else{tla((c[m>>2]|0)+(c[f+(n<<2)>>2]|0)|0,g+(n<<4<<1)|0,h)}}while(0);n=n+1|0;}while((n|0)<(l|0))}l=j+1|0;if((l|0)<3){j=l}else{w=1;break}}do{j=w<<4;v=j|4;u=j|8;if((v|0)<(u|0)){j=e+(w-1<<2)|0;t=v;do{v=t+4|0;do{if((a[i+(d[602104+v|0]|0)|0]|0)==0){r=g+(t<<4<<1)|0;l=b[r>>1]|0;if(l<<16>>16==0){break}n=(c[j>>2]|0)+(c[f+(v<<2)>>2]|0)|0;m=(l<<16>>16)+32>>6;b[r>>1]=0;r=0;l=n;while(1){n=(d[l]|0)+m|0;if(n>>>0>255>>>0){x=-n>>31&255}else{x=n&255}a[l]=x;n=l+1|0;o=(d[n]|0)+m|0;if(o>>>0>255>>>0){y=-o>>31&255}else{y=o&255}a[n]=y;n=l+2|0;o=(d[n]|0)+m|0;if(o>>>0>255>>>0){z=-o>>31&255}else{z=o&255}a[n]=z;n=l+3|0;o=(d[n]|0)+m|0;if(o>>>0>255>>>0){A=-o>>31&255}else{A=o&255}a[n]=A;n=r+1|0;if((n|0)<4){r=n;l=l+h|0}else{break}}}else{tla((c[j>>2]|0)+(c[f+(v<<2)>>2]|0)|0,g+(t<<4<<1)|0,h)}}while(0);t=t+1|0;}while((t|0)<(u|0))}w=w+1|0;}while((w|0)<3);return}function Cla(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+64|0;h=g|0;j=b[e>>1]|0;k=b[e+2>>1]|0;l=k+j|0;m=j-k|0;k=b[e+4>>1]|0;j=b[e+6>>1]|0;n=k-j|0;o=j+k|0;k=o+l|0;c[h>>2]=k;c[h+4>>2]=l-o;c[h+8>>2]=m-n;c[h+12>>2]=n+m;m=b[e+8>>1]|0;n=b[e+10>>1]|0;o=n+m|0;l=m-n|0;n=b[e+12>>1]|0;m=b[e+14>>1]|0;j=n-m|0;p=m+n|0;c[h+16>>2]=p+o;c[h+20>>2]=o-p;c[h+24>>2]=l-j;c[h+28>>2]=j+l;l=b[e+16>>1]|0;j=b[e+18>>1]|0;p=j+l|0;o=l-j|0;j=b[e+20>>1]|0;l=b[e+22>>1]|0;n=j-l|0;m=l+j|0;c[h+32>>2]=m+p;c[h+36>>2]=p-m;c[h+40>>2]=o-n;c[h+44>>2]=n+o;o=b[e+24>>1]|0;n=b[e+26>>1]|0;m=n+o|0;p=o-n|0;n=b[e+28>>1]|0;o=b[e+30>>1]|0;e=n-o|0;j=o+n|0;c[h+48>>2]=j+m;c[h+52>>2]=m-j;c[h+56>>2]=p-e;c[h+60>>2]=e+p;p=0;e=k;while(1){k=d[1375904+p|0]|0;j=c[h+(p+8<<2)>>2]|0;m=j+e|0;n=e-j|0;j=c[h+(p+4<<2)>>2]|0;o=c[h+(p+12<<2)>>2]|0;l=j-o|0;q=o+j|0;b[a+(k<<1)>>1]=((ca(q+m|0,f)|0)+128|0)>>>8;b[a+(k+16<<1)>>1]=((ca(l+n|0,f)|0)+128|0)>>>8;b[a+(k+64<<1)>>1]=((ca(n-l|0,f)|0)+128|0)>>>8;b[a+(k+80<<1)>>1]=((ca(m-q|0,f)|0)+128|0)>>>8;q=p+1|0;if((q|0)>=4){break}p=q;e=c[h+(q<<2)>>2]|0}i=g;return}function Dla(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[a>>1]|0;e=a+32|0;f=b[e>>1]|0;g=f+d|0;h=d-f|0;f=a+64|0;d=b[f>>1]|0;i=a+96|0;j=b[i>>1]|0;k=j+d|0;l=d-j|0;j=a+128|0;d=b[j>>1]|0;m=a+160|0;n=b[m>>1]|0;o=n+d|0;p=d-n|0;n=a+192|0;d=b[n>>1]|0;q=a+224|0;r=b[q>>1]|0;s=r+d|0;t=d-r|0;r=o+g|0;d=g-o|0;o=k-s|0;g=s+k|0;b[a>>1]=((ca(g+r|0,c)|0)+128|0)>>>8;b[f>>1]=((ca(o+d|0,c)|0)+128|0)>>>8;b[j>>1]=((ca(d-o|0,c)|0)+128|0)>>>8;b[n>>1]=((ca(r-g|0,c)|0)+128|0)>>>8;g=p+h|0;r=h-p|0;p=l-t|0;h=t+l|0;b[e>>1]=((ca(h+g|0,c)|0)+128|0)>>>8;b[i>>1]=((ca(p+r|0,c)|0)+128|0)>>>8;b[m>>1]=((ca(r-p|0,c)|0)+128|0)>>>8;b[q>>1]=((ca(g-h|0,c)|0)+128|0)>>>8;return}function Ela(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[a>>1]|0;e=a+32|0;f=b[e>>1]|0;g=a+64|0;h=b[g>>1]|0;i=a+96|0;j=b[i>>1]|0;k=d-f|0;l=f+d|0;d=h-j|0;f=j+h|0;b[a>>1]=(ca(f+l|0,c)|0)>>>7;b[e>>1]=(ca(d+k|0,c)|0)>>>7;b[g>>1]=(ca(l-f|0,c)|0)>>>7;b[i>>1]=(ca(k-d|0,c)|0)>>>7;return}function Fla(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d;h=(c[g>>2]|0)+32|0;i=d+32|0;j=c[i>>2]|0;k=j+h|0;l=h-j|0;j=d+16|0;h=c[j>>2]|0;m=d+48|0;n=c[m>>2]|0;o=(h>>1)-n|0;p=(n>>1)+h|0;c[g>>2]=p+k;c[j>>2]=o+l;c[i>>2]=l-o;c[m>>2]=k-p;p=d+4|0;k=c[p>>2]|0;m=d+36|0;o=c[m>>2]|0;l=o+k|0;i=k-o|0;o=d+20|0;k=c[o>>2]|0;j=d+52|0;h=c[j>>2]|0;n=(k>>1)-h|0;q=(h>>1)+k|0;c[p>>2]=q+l;c[o>>2]=n+i;c[m>>2]=i-n;c[j>>2]=l-q;q=d+8|0;l=c[q>>2]|0;j=d+40|0;n=c[j>>2]|0;i=n+l|0;m=l-n|0;n=d+24|0;l=c[n>>2]|0;o=d+56|0;p=c[o>>2]|0;k=(l>>1)-p|0;h=(p>>1)+l|0;c[q>>2]=h+i;c[n>>2]=k+m;c[j>>2]=m-k;c[o>>2]=i-h;h=d+12|0;i=c[h>>2]|0;o=d+44|0;k=c[o>>2]|0;m=k+i|0;j=i-k|0;k=d+28|0;i=c[k>>2]|0;n=d+60|0;q=c[n>>2]|0;l=(i>>1)-q|0;p=(q>>1)+i|0;c[h>>2]=p+m;c[k>>2]=l+j;c[o>>2]=j-l;c[n>>2]=m-p;p=a;a=f>>1;f=a<<1;m=a*3|0;n=0;do{l=n<<2;j=c[g+(l<<2)>>2]|0;o=c[g+((l|2)<<2)>>2]|0;k=o+j|0;h=j-o|0;o=c[g+((l|1)<<2)>>2]|0;j=c[g+((l|3)<<2)>>2]|0;l=(o>>1)-j|0;i=(j>>1)+o|0;o=p+(n<<1)|0;j=(i+k>>6)+(e[o>>1]|0)|0;if(j>>>0<512>>>0){r=j&65535}else{r=-j>>31&511}b[o>>1]=r;o=p+(n+a<<1)|0;j=(e[o>>1]|0)+(l+h>>6)|0;if(j>>>0<512>>>0){s=j&65535}else{s=-j>>31&511}b[o>>1]=s;o=p+(n+f<<1)|0;j=(e[o>>1]|0)+(h-l>>6)|0;if(j>>>0<512>>>0){t=j&65535}else{t=-j>>31&511}b[o>>1]=t;o=p+(n+m<<1)|0;j=(e[o>>1]|0)+(k-i>>6)|0;if(j>>>0<512>>>0){u=j&65535}else{u=-j>>31&511}b[o>>1]=u;n=n+1|0;}while((n|0)<4);mrc(d|0,0,64)|0;return}function Gla(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=d;h=(c[g>>2]|0)+32|0;c[g>>2]=h;i=0;j=h;while(1){h=g+(i+32<<2)|0;k=c[h>>2]|0;l=k+j|0;m=j-k|0;k=g+(i+16<<2)|0;n=c[k>>2]|0;o=g+(i+48<<2)|0;p=c[o>>2]|0;q=(n>>1)-p|0;r=(p>>1)+n|0;n=r+l|0;p=q+m|0;s=m-q|0;q=l-r|0;r=g+(i+24<<2)|0;l=c[r>>2]|0;m=g+(i+40<<2)|0;t=c[m>>2]|0;u=g+(i+56<<2)|0;v=c[u>>2]|0;w=t-l-v-(v>>1)|0;x=g+(i+8<<2)|0;y=c[x>>2]|0;z=v-((l>>1)+l)+y|0;A=v+t+(t>>1)-y|0;v=t+l+y+(y>>1)|0;y=(v>>2)+w|0;l=(A>>2)+z|0;t=(z>>2)-A|0;A=v-(w>>2)|0;c[g+(i<<2)>>2]=A+n;c[u>>2]=n-A;c[x>>2]=t+p;c[o>>2]=p-t;c[k>>2]=l+s;c[m>>2]=s-l;c[r>>2]=y+q;c[h>>2]=q-y;y=i+1|0;if((y|0)>=8){break}i=y;j=c[g+(y<<2)>>2]|0}j=a;a=f>>1;f=a<<1;i=a*3|0;y=a<<2;q=a*5|0;h=a*6|0;r=a*7|0;l=0;do{s=l<<3;m=c[g+(s<<2)>>2]|0;k=c[g+((s|4)<<2)>>2]|0;t=k+m|0;p=m-k|0;k=c[g+((s|2)<<2)>>2]|0;m=c[g+((s|6)<<2)>>2]|0;o=(k>>1)-m|0;x=(m>>1)+k|0;k=x+t|0;m=o+p|0;A=p-o|0;o=t-x|0;x=c[g+((s|3)<<2)>>2]|0;t=c[g+((s|5)<<2)>>2]|0;p=c[g+((s|7)<<2)>>2]|0;n=t-x-p-(p>>1)|0;u=c[g+((s|1)<<2)>>2]|0;s=p-((x>>1)+x)+u|0;w=p+t+(t>>1)-u|0;p=t+x+u+(u>>1)|0;u=(p>>2)+n|0;x=(w>>2)+s|0;t=(s>>2)-w|0;w=p-(n>>2)|0;n=j+(l<<1)|0;p=(w+k>>6)+(e[n>>1]|0)|0;if(p>>>0<512>>>0){B=p&65535}else{B=-p>>31&511}b[n>>1]=B;n=j+(l+a<<1)|0;p=(e[n>>1]|0)+(t+m>>6)|0;if(p>>>0<512>>>0){C=p&65535}else{C=-p>>31&511}b[n>>1]=C;n=j+(l+f<<1)|0;p=(e[n>>1]|0)+(x+A>>6)|0;if(p>>>0<512>>>0){D=p&65535}else{D=-p>>31&511}b[n>>1]=D;n=j+(l+i<<1)|0;p=(e[n>>1]|0)+(u+o>>6)|0;if(p>>>0<512>>>0){E=p&65535}else{E=-p>>31&511}b[n>>1]=E;n=j+(l+y<<1)|0;p=(e[n>>1]|0)+(o-u>>6)|0;if(p>>>0<512>>>0){F=p&65535}else{F=-p>>31&511}b[n>>1]=F;n=j+(l+q<<1)|0;p=(e[n>>1]|0)+(A-x>>6)|0;if(p>>>0<512>>>0){G=p&65535}else{G=-p>>31&511}b[n>>1]=G;n=j+(l+h<<1)|0;p=(e[n>>1]|0)+(m-t>>6)|0;if(p>>>0<512>>>0){H=p&65535}else{H=-p>>31&511}b[n>>1]=H;n=j+(l+r<<1)|0;p=(e[n>>1]|0)+(k-w>>6)|0;if(p>>>0<512>>>0){I=p&65535}else{I=-p>>31&511}b[n>>1]=I;l=l+1|0;}while((l|0)<8);mrc(d|0,0,256)|0;return}function Hla(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d;d=(c[g>>2]|0)+32>>6;h=f>>>1;c[g>>2]=0;g=0;f=a;while(1){a=(e[f>>1]|0)+d|0;if(a>>>0<512>>>0){i=a&65535}else{i=-a>>31&511}b[f>>1]=i;a=f+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){k=j&65535}else{k=-j>>31&511}b[a>>1]=k;a=f+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){l=j&65535}else{l=-j>>31&511}b[a>>1]=l;a=f+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){m=j&65535}else{m=-j>>31&511}b[a>>1]=m;a=g+1|0;if((a|0)<4){g=a;f=f+(h<<1)|0}else{break}}return}function Ila(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d;d=(c[g>>2]|0)+32>>6;c[g>>2]=0;g=f>>>1;f=0;h=a;while(1){a=(e[h>>1]|0)+d|0;if(a>>>0<512>>>0){i=a&65535}else{i=-a>>31&511}b[h>>1]=i;a=h+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){k=j&65535}else{k=-j>>31&511}b[a>>1]=k;a=h+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){l=j&65535}else{l=-j>>31&511}b[a>>1]=l;a=h+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){m=j&65535}else{m=-j>>31&511}b[a>>1]=m;a=h+8|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){n=j&65535}else{n=-j>>31&511}b[a>>1]=n;a=h+10|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){o=j&65535}else{o=-j>>31&511}b[a>>1]=o;a=h+12|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){p=j&65535}else{p=-j>>31&511}b[a>>1]=p;a=h+14|0;j=(e[a>>1]|0)+d|0;if(j>>>0<512>>>0){q=j&65535}else{q=-j>>31&511}b[a>>1]=q;a=f+1|0;if((a|0)<8){f=a;h=h+(g<<1)|0}else{break}}return}function Jla(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=f;j=0;do{k=a[h+(d[602104+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){if((c[i+(j<<4<<2)>>2]|0)==0){l=5;break}Hla(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else if((k<<24>>24|0)!=0){l=5}}while(0);if((l|0)==5){l=0;Fla(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}j=j+1|0;}while((j|0)<16);return}function Kla(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=f;j=0;do{do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(j<<4<<2)>>2]|0)==0){break}Hla(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else{Fla(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<16);return}function Lla(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=a[g+12|0]|0;do{if((h<<24>>24|0)==1){if((c[e>>2]|0)==0){i=4;break}Ila(b+(c[d>>2]|0)|0,e,f)}else if((h<<24>>24|0)!=0){i=4}}while(0);if((i|0)==4){Gla(b+(c[d>>2]|0)|0,e,f)}h=a[g+14|0]|0;do{if((h<<24>>24|0)==1){if((c[e+256>>2]|0)==0){i=8;break}Ila(b+(c[d+16>>2]|0)|0,e+256|0,f)}else if((h<<24>>24|0)!=0){i=8}}while(0);if((i|0)==8){Gla(b+(c[d+16>>2]|0)|0,e+256|0,f)}h=a[g+28|0]|0;do{if((h<<24>>24|0)==1){if((c[e+512>>2]|0)==0){i=12;break}Ila(b+(c[d+32>>2]|0)|0,e+512|0,f)}else if((h<<24>>24|0)!=0){i=12}}while(0);if((i|0)==12){Gla(b+(c[d+32>>2]|0)|0,e+512|0,f)}h=a[g+30|0]|0;if((h<<24>>24|0)==0){return}else if((h<<24>>24|0)==1){i=14}do{if((i|0)==14){if((c[e+768>>2]|0)==0){break}Ila(b+(c[d+48>>2]|0)|0,e+768|0,f);return}}while(0);Gla(b+(c[d+48>>2]|0)|0,e+768|0,f);return}function Mla(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=f;j=1;do{k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[602104+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}Hla((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{Fla((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[602104+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}Hla((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{Fla((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[602104+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}Hla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{Fla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[602104+n|0]|0)|0]|0)!=0){Fla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}Hla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<3);return}function Nla(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f;j=1;while(1){k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[602104+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}Hla((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{Fla((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[602104+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}Hla((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{Fla((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[602104+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}Hla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{Fla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[602104+n|0]|0)|0]|0)!=0){Fla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}Hla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);k=j+1|0;if((k|0)<3){j=k}else{o=20;break}}do{j=o+4|0;do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(o<<4<<2)>>2]|0)==0){break}Hla((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}else{Fla((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}}while(0);o=o+1|0;}while((o|0)<24);o=b+4|0;b=36;do{j=b+4|0;do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(b<<4<<2)>>2]|0)==0){break}Hla((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}else{Fla((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}}while(0);b=b+1|0;}while((b|0)<40);return}function Ola(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b>>2]|0;j=c[b+4>>2]|0;k=j+h|0;l=h-j|0;j=c[b+8>>2]|0;h=c[b+12>>2]|0;m=j-h|0;n=h+j|0;j=n+k|0;c[g>>2]=j;c[g+4>>2]=k-n;c[g+8>>2]=l-m;c[g+12>>2]=m+l;l=c[b+16>>2]|0;m=c[b+20>>2]|0;n=m+l|0;k=l-m|0;m=c[b+24>>2]|0;l=c[b+28>>2]|0;h=m-l|0;o=l+m|0;c[g+16>>2]=o+n;c[g+20>>2]=n-o;c[g+24>>2]=k-h;c[g+28>>2]=h+k;k=c[b+32>>2]|0;h=c[b+36>>2]|0;o=h+k|0;n=k-h|0;h=c[b+40>>2]|0;k=c[b+44>>2]|0;m=h-k|0;l=k+h|0;c[g+32>>2]=l+o;c[g+36>>2]=o-l;c[g+40>>2]=n-m;c[g+44>>2]=m+n;n=c[b+48>>2]|0;m=c[b+52>>2]|0;l=m+n|0;o=n-m|0;m=c[b+56>>2]|0;n=c[b+60>>2]|0;b=m-n|0;h=n+m|0;c[g+48>>2]=h+l;c[g+52>>2]=l-h;c[g+56>>2]=o-b;c[g+60>>2]=b+o;o=a;a=0;b=j;while(1){j=d[1375904+a|0]|0;h=c[g+(a+8<<2)>>2]|0;l=h+b|0;m=b-h|0;h=c[g+(a+4<<2)>>2]|0;n=c[g+(a+12<<2)>>2]|0;k=h-n|0;p=n+h|0;c[o+(j<<2)>>2]=(ca(p+l|0,e)|0)+128>>8;c[o+(j+16<<2)>>2]=(ca(k+m|0,e)|0)+128>>8;c[o+(j+64<<2)>>2]=(ca(m-k|0,e)|0)+128>>8;c[o+(j+80<<2)>>2]=(ca(l-p|0,e)|0)+128>>8;p=a+1|0;if((p|0)>=4){break}a=p;b=c[g+(p<<2)>>2]|0}i=f;return}function Pla(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=g+e|0;i=e-g|0;g=a+128|0;e=c[g>>2]|0;j=a+192|0;k=c[j>>2]|0;l=k+e|0;m=e-k|0;k=a+256|0;e=c[k>>2]|0;n=a+320|0;o=c[n>>2]|0;p=o+e|0;q=e-o|0;o=a+384|0;e=c[o>>2]|0;r=a+448|0;a=c[r>>2]|0;s=a+e|0;t=e-a|0;a=p+h|0;e=h-p|0;p=l-s|0;h=s+l|0;c[d>>2]=(ca(h+a|0,b)|0)+128>>8;c[g>>2]=(ca(p+e|0,b)|0)+128>>8;c[k>>2]=(ca(e-p|0,b)|0)+128>>8;c[o>>2]=(ca(a-h|0,b)|0)+128>>8;h=q+i|0;a=i-q|0;q=m-t|0;i=t+m|0;c[f>>2]=(ca(i+h|0,b)|0)+128>>8;c[j>>2]=(ca(q+a|0,b)|0)+128>>8;c[n>>2]=(ca(a-q|0,b)|0)+128>>8;c[r>>2]=(ca(h-i|0,b)|0)+128>>8;return}function Qla(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=a+128|0;i=c[h>>2]|0;j=a+192|0;a=c[j>>2]|0;k=e-g|0;l=g+e|0;e=i-a|0;g=a+i|0;c[d>>2]=(ca(g+l|0,b)|0)>>7;c[f>>2]=(ca(e+k|0,b)|0)>>7;c[h>>2]=(ca(l-g|0,b)|0)>>7;c[j>>2]=(ca(k-e|0,b)|0)>>7;return}function Rla(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d;h=(c[g>>2]|0)+32|0;i=d+32|0;j=c[i>>2]|0;k=j+h|0;l=h-j|0;j=d+16|0;h=c[j>>2]|0;m=d+48|0;n=c[m>>2]|0;o=(h>>1)-n|0;p=(n>>1)+h|0;c[g>>2]=p+k;c[j>>2]=o+l;c[i>>2]=l-o;c[m>>2]=k-p;p=d+4|0;k=c[p>>2]|0;m=d+36|0;o=c[m>>2]|0;l=o+k|0;i=k-o|0;o=d+20|0;k=c[o>>2]|0;j=d+52|0;h=c[j>>2]|0;n=(k>>1)-h|0;q=(h>>1)+k|0;c[p>>2]=q+l;c[o>>2]=n+i;c[m>>2]=i-n;c[j>>2]=l-q;q=d+8|0;l=c[q>>2]|0;j=d+40|0;n=c[j>>2]|0;i=n+l|0;m=l-n|0;n=d+24|0;l=c[n>>2]|0;o=d+56|0;p=c[o>>2]|0;k=(l>>1)-p|0;h=(p>>1)+l|0;c[q>>2]=h+i;c[n>>2]=k+m;c[j>>2]=m-k;c[o>>2]=i-h;h=d+12|0;i=c[h>>2]|0;o=d+44|0;k=c[o>>2]|0;m=k+i|0;j=i-k|0;k=d+28|0;i=c[k>>2]|0;n=d+60|0;q=c[n>>2]|0;l=(i>>1)-q|0;p=(q>>1)+i|0;c[h>>2]=p+m;c[k>>2]=l+j;c[o>>2]=j-l;c[n>>2]=m-p;p=a;a=f>>1;f=a<<1;m=a*3|0;n=0;do{l=n<<2;j=c[g+(l<<2)>>2]|0;o=c[g+((l|2)<<2)>>2]|0;k=o+j|0;h=j-o|0;o=c[g+((l|1)<<2)>>2]|0;j=c[g+((l|3)<<2)>>2]|0;l=(o>>1)-j|0;i=(j>>1)+o|0;o=p+(n<<1)|0;j=(i+k>>6)+(e[o>>1]|0)|0;if(j>>>0<1024>>>0){r=j&65535}else{r=-j>>31&1023}b[o>>1]=r;o=p+(n+a<<1)|0;j=(e[o>>1]|0)+(l+h>>6)|0;if(j>>>0<1024>>>0){s=j&65535}else{s=-j>>31&1023}b[o>>1]=s;o=p+(n+f<<1)|0;j=(e[o>>1]|0)+(h-l>>6)|0;if(j>>>0<1024>>>0){t=j&65535}else{t=-j>>31&1023}b[o>>1]=t;o=p+(n+m<<1)|0;j=(e[o>>1]|0)+(k-i>>6)|0;if(j>>>0<1024>>>0){u=j&65535}else{u=-j>>31&1023}b[o>>1]=u;n=n+1|0;}while((n|0)<4);mrc(d|0,0,64)|0;return}function Sla(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=d;h=(c[g>>2]|0)+32|0;c[g>>2]=h;i=0;j=h;while(1){h=g+(i+32<<2)|0;k=c[h>>2]|0;l=k+j|0;m=j-k|0;k=g+(i+16<<2)|0;n=c[k>>2]|0;o=g+(i+48<<2)|0;p=c[o>>2]|0;q=(n>>1)-p|0;r=(p>>1)+n|0;n=r+l|0;p=q+m|0;s=m-q|0;q=l-r|0;r=g+(i+24<<2)|0;l=c[r>>2]|0;m=g+(i+40<<2)|0;t=c[m>>2]|0;u=g+(i+56<<2)|0;v=c[u>>2]|0;w=t-l-v-(v>>1)|0;x=g+(i+8<<2)|0;y=c[x>>2]|0;z=v-((l>>1)+l)+y|0;A=v+t+(t>>1)-y|0;v=t+l+y+(y>>1)|0;y=(v>>2)+w|0;l=(A>>2)+z|0;t=(z>>2)-A|0;A=v-(w>>2)|0;c[g+(i<<2)>>2]=A+n;c[u>>2]=n-A;c[x>>2]=t+p;c[o>>2]=p-t;c[k>>2]=l+s;c[m>>2]=s-l;c[r>>2]=y+q;c[h>>2]=q-y;y=i+1|0;if((y|0)>=8){break}i=y;j=c[g+(y<<2)>>2]|0}j=a;a=f>>1;f=a<<1;i=a*3|0;y=a<<2;q=a*5|0;h=a*6|0;r=a*7|0;l=0;do{s=l<<3;m=c[g+(s<<2)>>2]|0;k=c[g+((s|4)<<2)>>2]|0;t=k+m|0;p=m-k|0;k=c[g+((s|2)<<2)>>2]|0;m=c[g+((s|6)<<2)>>2]|0;o=(k>>1)-m|0;x=(m>>1)+k|0;k=x+t|0;m=o+p|0;A=p-o|0;o=t-x|0;x=c[g+((s|3)<<2)>>2]|0;t=c[g+((s|5)<<2)>>2]|0;p=c[g+((s|7)<<2)>>2]|0;n=t-x-p-(p>>1)|0;u=c[g+((s|1)<<2)>>2]|0;s=p-((x>>1)+x)+u|0;w=p+t+(t>>1)-u|0;p=t+x+u+(u>>1)|0;u=(p>>2)+n|0;x=(w>>2)+s|0;t=(s>>2)-w|0;w=p-(n>>2)|0;n=j+(l<<1)|0;p=(w+k>>6)+(e[n>>1]|0)|0;if(p>>>0<1024>>>0){B=p&65535}else{B=-p>>31&1023}b[n>>1]=B;n=j+(l+a<<1)|0;p=(e[n>>1]|0)+(t+m>>6)|0;if(p>>>0<1024>>>0){C=p&65535}else{C=-p>>31&1023}b[n>>1]=C;n=j+(l+f<<1)|0;p=(e[n>>1]|0)+(x+A>>6)|0;if(p>>>0<1024>>>0){D=p&65535}else{D=-p>>31&1023}b[n>>1]=D;n=j+(l+i<<1)|0;p=(e[n>>1]|0)+(u+o>>6)|0;if(p>>>0<1024>>>0){E=p&65535}else{E=-p>>31&1023}b[n>>1]=E;n=j+(l+y<<1)|0;p=(e[n>>1]|0)+(o-u>>6)|0;if(p>>>0<1024>>>0){F=p&65535}else{F=-p>>31&1023}b[n>>1]=F;n=j+(l+q<<1)|0;p=(e[n>>1]|0)+(A-x>>6)|0;if(p>>>0<1024>>>0){G=p&65535}else{G=-p>>31&1023}b[n>>1]=G;n=j+(l+h<<1)|0;p=(e[n>>1]|0)+(m-t>>6)|0;if(p>>>0<1024>>>0){H=p&65535}else{H=-p>>31&1023}b[n>>1]=H;n=j+(l+r<<1)|0;p=(e[n>>1]|0)+(k-w>>6)|0;if(p>>>0<1024>>>0){I=p&65535}else{I=-p>>31&1023}b[n>>1]=I;l=l+1|0;}while((l|0)<8);mrc(d|0,0,256)|0;return}function Tla(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d;d=(c[g>>2]|0)+32>>6;h=f>>>1;c[g>>2]=0;g=0;f=a;while(1){a=(e[f>>1]|0)+d|0;if(a>>>0<1024>>>0){i=a&65535}else{i=-a>>31&1023}b[f>>1]=i;a=f+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){k=j&65535}else{k=-j>>31&1023}b[a>>1]=k;a=f+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){l=j&65535}else{l=-j>>31&1023}b[a>>1]=l;a=f+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){m=j&65535}else{m=-j>>31&1023}b[a>>1]=m;a=g+1|0;if((a|0)<4){g=a;f=f+(h<<1)|0}else{break}}return}function Ula(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d;d=(c[g>>2]|0)+32>>6;c[g>>2]=0;g=f>>>1;f=0;h=a;while(1){a=(e[h>>1]|0)+d|0;if(a>>>0<1024>>>0){i=a&65535}else{i=-a>>31&1023}b[h>>1]=i;a=h+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){k=j&65535}else{k=-j>>31&1023}b[a>>1]=k;a=h+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){l=j&65535}else{l=-j>>31&1023}b[a>>1]=l;a=h+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){m=j&65535}else{m=-j>>31&1023}b[a>>1]=m;a=h+8|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){n=j&65535}else{n=-j>>31&1023}b[a>>1]=n;a=h+10|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){o=j&65535}else{o=-j>>31&1023}b[a>>1]=o;a=h+12|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){p=j&65535}else{p=-j>>31&1023}b[a>>1]=p;a=h+14|0;j=(e[a>>1]|0)+d|0;if(j>>>0<1024>>>0){q=j&65535}else{q=-j>>31&1023}b[a>>1]=q;a=f+1|0;if((a|0)<8){f=a;h=h+(g<<1)|0}else{break}}return}function Vla(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=f;j=0;do{k=a[h+(d[602104+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){if((c[i+(j<<4<<2)>>2]|0)==0){l=5;break}Tla(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else if((k<<24>>24|0)!=0){l=5}}while(0);if((l|0)==5){l=0;Rla(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}j=j+1|0;}while((j|0)<16);return}function Wla(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=f;j=0;do{do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(j<<4<<2)>>2]|0)==0){break}Tla(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else{Rla(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<16);return}function Xla(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=a[g+12|0]|0;do{if((h<<24>>24|0)==1){if((c[e>>2]|0)==0){i=4;break}Ula(b+(c[d>>2]|0)|0,e,f)}else if((h<<24>>24|0)!=0){i=4}}while(0);if((i|0)==4){Sla(b+(c[d>>2]|0)|0,e,f)}h=a[g+14|0]|0;do{if((h<<24>>24|0)==1){if((c[e+256>>2]|0)==0){i=8;break}Ula(b+(c[d+16>>2]|0)|0,e+256|0,f)}else if((h<<24>>24|0)!=0){i=8}}while(0);if((i|0)==8){Sla(b+(c[d+16>>2]|0)|0,e+256|0,f)}h=a[g+28|0]|0;do{if((h<<24>>24|0)==1){if((c[e+512>>2]|0)==0){i=12;break}Ula(b+(c[d+32>>2]|0)|0,e+512|0,f)}else if((h<<24>>24|0)!=0){i=12}}while(0);if((i|0)==12){Sla(b+(c[d+32>>2]|0)|0,e+512|0,f)}h=a[g+30|0]|0;if((h<<24>>24|0)==1){i=14}else if((h<<24>>24|0)==0){return}do{if((i|0)==14){if((c[e+768>>2]|0)==0){break}Ula(b+(c[d+48>>2]|0)|0,e+768|0,f);return}}while(0);Sla(b+(c[d+48>>2]|0)|0,e+768|0,f);return}function Yla(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=f;j=1;do{k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[602104+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}Tla((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{Rla((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[602104+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}Tla((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{Rla((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[602104+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}Tla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{Rla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[602104+n|0]|0)|0]|0)!=0){Rla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}Tla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<3);return}function Zla(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f;j=1;while(1){k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[602104+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}Tla((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{Rla((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[602104+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}Tla((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{Rla((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[602104+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}Tla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{Rla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[602104+n|0]|0)|0]|0)!=0){Rla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}Tla((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);k=j+1|0;if((k|0)<3){j=k}else{o=20;break}}do{j=o+4|0;do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(o<<4<<2)>>2]|0)==0){break}Tla((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}else{Rla((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}}while(0);o=o+1|0;}while((o|0)<24);o=b+4|0;b=36;do{j=b+4|0;do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(b<<4<<2)>>2]|0)==0){break}Tla((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}else{Rla((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}}while(0);b=b+1|0;}while((b|0)<40);return}function _la(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b>>2]|0;j=c[b+4>>2]|0;k=j+h|0;l=h-j|0;j=c[b+8>>2]|0;h=c[b+12>>2]|0;m=j-h|0;n=h+j|0;j=n+k|0;c[g>>2]=j;c[g+4>>2]=k-n;c[g+8>>2]=l-m;c[g+12>>2]=m+l;l=c[b+16>>2]|0;m=c[b+20>>2]|0;n=m+l|0;k=l-m|0;m=c[b+24>>2]|0;l=c[b+28>>2]|0;h=m-l|0;o=l+m|0;c[g+16>>2]=o+n;c[g+20>>2]=n-o;c[g+24>>2]=k-h;c[g+28>>2]=h+k;k=c[b+32>>2]|0;h=c[b+36>>2]|0;o=h+k|0;n=k-h|0;h=c[b+40>>2]|0;k=c[b+44>>2]|0;m=h-k|0;l=k+h|0;c[g+32>>2]=l+o;c[g+36>>2]=o-l;c[g+40>>2]=n-m;c[g+44>>2]=m+n;n=c[b+48>>2]|0;m=c[b+52>>2]|0;l=m+n|0;o=n-m|0;m=c[b+56>>2]|0;n=c[b+60>>2]|0;b=m-n|0;h=n+m|0;c[g+48>>2]=h+l;c[g+52>>2]=l-h;c[g+56>>2]=o-b;c[g+60>>2]=b+o;o=a;a=0;b=j;while(1){j=d[1375904+a|0]|0;h=c[g+(a+8<<2)>>2]|0;l=h+b|0;m=b-h|0;h=c[g+(a+4<<2)>>2]|0;n=c[g+(a+12<<2)>>2]|0;k=h-n|0;p=n+h|0;c[o+(j<<2)>>2]=(ca(p+l|0,e)|0)+128>>8;c[o+(j+16<<2)>>2]=(ca(k+m|0,e)|0)+128>>8;c[o+(j+64<<2)>>2]=(ca(m-k|0,e)|0)+128>>8;c[o+(j+80<<2)>>2]=(ca(l-p|0,e)|0)+128>>8;p=a+1|0;if((p|0)>=4){break}a=p;b=c[g+(p<<2)>>2]|0}i=f;return}function $la(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=g+e|0;i=e-g|0;g=a+128|0;e=c[g>>2]|0;j=a+192|0;k=c[j>>2]|0;l=k+e|0;m=e-k|0;k=a+256|0;e=c[k>>2]|0;n=a+320|0;o=c[n>>2]|0;p=o+e|0;q=e-o|0;o=a+384|0;e=c[o>>2]|0;r=a+448|0;a=c[r>>2]|0;s=a+e|0;t=e-a|0;a=p+h|0;e=h-p|0;p=l-s|0;h=s+l|0;c[d>>2]=(ca(h+a|0,b)|0)+128>>8;c[g>>2]=(ca(p+e|0,b)|0)+128>>8;c[k>>2]=(ca(e-p|0,b)|0)+128>>8;c[o>>2]=(ca(a-h|0,b)|0)+128>>8;h=q+i|0;a=i-q|0;q=m-t|0;i=t+m|0;c[f>>2]=(ca(i+h|0,b)|0)+128>>8;c[j>>2]=(ca(q+a|0,b)|0)+128>>8;c[n>>2]=(ca(a-q|0,b)|0)+128>>8;c[r>>2]=(ca(h-i|0,b)|0)+128>>8;return}function ama(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=a+128|0;i=c[h>>2]|0;j=a+192|0;a=c[j>>2]|0;k=e-g|0;l=g+e|0;e=i-a|0;g=a+i|0;c[d>>2]=(ca(g+l|0,b)|0)>>7;c[f>>2]=(ca(e+k|0,b)|0)>>7;c[h>>2]=(ca(l-g|0,b)|0)>>7;c[j>>2]=(ca(k-e|0,b)|0)>>7;return}function bma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d;h=(c[g>>2]|0)+32|0;i=d+32|0;j=c[i>>2]|0;k=j+h|0;l=h-j|0;j=d+16|0;h=c[j>>2]|0;m=d+48|0;n=c[m>>2]|0;o=(h>>1)-n|0;p=(n>>1)+h|0;c[g>>2]=p+k;c[j>>2]=o+l;c[i>>2]=l-o;c[m>>2]=k-p;p=d+4|0;k=c[p>>2]|0;m=d+36|0;o=c[m>>2]|0;l=o+k|0;i=k-o|0;o=d+20|0;k=c[o>>2]|0;j=d+52|0;h=c[j>>2]|0;n=(k>>1)-h|0;q=(h>>1)+k|0;c[p>>2]=q+l;c[o>>2]=n+i;c[m>>2]=i-n;c[j>>2]=l-q;q=d+8|0;l=c[q>>2]|0;j=d+40|0;n=c[j>>2]|0;i=n+l|0;m=l-n|0;n=d+24|0;l=c[n>>2]|0;o=d+56|0;p=c[o>>2]|0;k=(l>>1)-p|0;h=(p>>1)+l|0;c[q>>2]=h+i;c[n>>2]=k+m;c[j>>2]=m-k;c[o>>2]=i-h;h=d+12|0;i=c[h>>2]|0;o=d+44|0;k=c[o>>2]|0;m=k+i|0;j=i-k|0;k=d+28|0;i=c[k>>2]|0;n=d+60|0;q=c[n>>2]|0;l=(i>>1)-q|0;p=(q>>1)+i|0;c[h>>2]=p+m;c[k>>2]=l+j;c[o>>2]=j-l;c[n>>2]=m-p;p=a;a=f>>1;f=a<<1;m=a*3|0;n=0;do{l=n<<2;j=c[g+(l<<2)>>2]|0;o=c[g+((l|2)<<2)>>2]|0;k=o+j|0;h=j-o|0;o=c[g+((l|1)<<2)>>2]|0;j=c[g+((l|3)<<2)>>2]|0;l=(o>>1)-j|0;i=(j>>1)+o|0;o=p+(n<<1)|0;j=(i+k>>6)+(e[o>>1]|0)|0;if(j>>>0<4096>>>0){r=j&65535}else{r=-j>>31&4095}b[o>>1]=r;o=p+(n+a<<1)|0;j=(e[o>>1]|0)+(l+h>>6)|0;if(j>>>0<4096>>>0){s=j&65535}else{s=-j>>31&4095}b[o>>1]=s;o=p+(n+f<<1)|0;j=(e[o>>1]|0)+(h-l>>6)|0;if(j>>>0<4096>>>0){t=j&65535}else{t=-j>>31&4095}b[o>>1]=t;o=p+(n+m<<1)|0;j=(e[o>>1]|0)+(k-i>>6)|0;if(j>>>0<4096>>>0){u=j&65535}else{u=-j>>31&4095}b[o>>1]=u;n=n+1|0;}while((n|0)<4);mrc(d|0,0,64)|0;return}function cma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=d;h=(c[g>>2]|0)+32|0;c[g>>2]=h;i=0;j=h;while(1){h=g+(i+32<<2)|0;k=c[h>>2]|0;l=k+j|0;m=j-k|0;k=g+(i+16<<2)|0;n=c[k>>2]|0;o=g+(i+48<<2)|0;p=c[o>>2]|0;q=(n>>1)-p|0;r=(p>>1)+n|0;n=r+l|0;p=q+m|0;s=m-q|0;q=l-r|0;r=g+(i+24<<2)|0;l=c[r>>2]|0;m=g+(i+40<<2)|0;t=c[m>>2]|0;u=g+(i+56<<2)|0;v=c[u>>2]|0;w=t-l-v-(v>>1)|0;x=g+(i+8<<2)|0;y=c[x>>2]|0;z=v-((l>>1)+l)+y|0;A=v+t+(t>>1)-y|0;v=t+l+y+(y>>1)|0;y=(v>>2)+w|0;l=(A>>2)+z|0;t=(z>>2)-A|0;A=v-(w>>2)|0;c[g+(i<<2)>>2]=A+n;c[u>>2]=n-A;c[x>>2]=t+p;c[o>>2]=p-t;c[k>>2]=l+s;c[m>>2]=s-l;c[r>>2]=y+q;c[h>>2]=q-y;y=i+1|0;if((y|0)>=8){break}i=y;j=c[g+(y<<2)>>2]|0}j=a;a=f>>1;f=a<<1;i=a*3|0;y=a<<2;q=a*5|0;h=a*6|0;r=a*7|0;l=0;do{s=l<<3;m=c[g+(s<<2)>>2]|0;k=c[g+((s|4)<<2)>>2]|0;t=k+m|0;p=m-k|0;k=c[g+((s|2)<<2)>>2]|0;m=c[g+((s|6)<<2)>>2]|0;o=(k>>1)-m|0;x=(m>>1)+k|0;k=x+t|0;m=o+p|0;A=p-o|0;o=t-x|0;x=c[g+((s|3)<<2)>>2]|0;t=c[g+((s|5)<<2)>>2]|0;p=c[g+((s|7)<<2)>>2]|0;n=t-x-p-(p>>1)|0;u=c[g+((s|1)<<2)>>2]|0;s=p-((x>>1)+x)+u|0;w=p+t+(t>>1)-u|0;p=t+x+u+(u>>1)|0;u=(p>>2)+n|0;x=(w>>2)+s|0;t=(s>>2)-w|0;w=p-(n>>2)|0;n=j+(l<<1)|0;p=(w+k>>6)+(e[n>>1]|0)|0;if(p>>>0<4096>>>0){B=p&65535}else{B=-p>>31&4095}b[n>>1]=B;n=j+(l+a<<1)|0;p=(e[n>>1]|0)+(t+m>>6)|0;if(p>>>0<4096>>>0){C=p&65535}else{C=-p>>31&4095}b[n>>1]=C;n=j+(l+f<<1)|0;p=(e[n>>1]|0)+(x+A>>6)|0;if(p>>>0<4096>>>0){D=p&65535}else{D=-p>>31&4095}b[n>>1]=D;n=j+(l+i<<1)|0;p=(e[n>>1]|0)+(u+o>>6)|0;if(p>>>0<4096>>>0){E=p&65535}else{E=-p>>31&4095}b[n>>1]=E;n=j+(l+y<<1)|0;p=(e[n>>1]|0)+(o-u>>6)|0;if(p>>>0<4096>>>0){F=p&65535}else{F=-p>>31&4095}b[n>>1]=F;n=j+(l+q<<1)|0;p=(e[n>>1]|0)+(A-x>>6)|0;if(p>>>0<4096>>>0){G=p&65535}else{G=-p>>31&4095}b[n>>1]=G;n=j+(l+h<<1)|0;p=(e[n>>1]|0)+(m-t>>6)|0;if(p>>>0<4096>>>0){H=p&65535}else{H=-p>>31&4095}b[n>>1]=H;n=j+(l+r<<1)|0;p=(e[n>>1]|0)+(k-w>>6)|0;if(p>>>0<4096>>>0){I=p&65535}else{I=-p>>31&4095}b[n>>1]=I;l=l+1|0;}while((l|0)<8);mrc(d|0,0,256)|0;return}function dma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d;d=(c[g>>2]|0)+32>>6;h=f>>>1;c[g>>2]=0;g=0;f=a;while(1){a=(e[f>>1]|0)+d|0;if(a>>>0<4096>>>0){i=a&65535}else{i=-a>>31&4095}b[f>>1]=i;a=f+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){k=j&65535}else{k=-j>>31&4095}b[a>>1]=k;a=f+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){l=j&65535}else{l=-j>>31&4095}b[a>>1]=l;a=f+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){m=j&65535}else{m=-j>>31&4095}b[a>>1]=m;a=g+1|0;if((a|0)<4){g=a;f=f+(h<<1)|0}else{break}}return}function ema(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d;d=(c[g>>2]|0)+32>>6;c[g>>2]=0;g=f>>>1;f=0;h=a;while(1){a=(e[h>>1]|0)+d|0;if(a>>>0<4096>>>0){i=a&65535}else{i=-a>>31&4095}b[h>>1]=i;a=h+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){k=j&65535}else{k=-j>>31&4095}b[a>>1]=k;a=h+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){l=j&65535}else{l=-j>>31&4095}b[a>>1]=l;a=h+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){m=j&65535}else{m=-j>>31&4095}b[a>>1]=m;a=h+8|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){n=j&65535}else{n=-j>>31&4095}b[a>>1]=n;a=h+10|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){o=j&65535}else{o=-j>>31&4095}b[a>>1]=o;a=h+12|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){p=j&65535}else{p=-j>>31&4095}b[a>>1]=p;a=h+14|0;j=(e[a>>1]|0)+d|0;if(j>>>0<4096>>>0){q=j&65535}else{q=-j>>31&4095}b[a>>1]=q;a=f+1|0;if((a|0)<8){f=a;h=h+(g<<1)|0}else{break}}return}function fma(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=f;j=0;do{k=a[h+(d[602104+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){if((c[i+(j<<4<<2)>>2]|0)==0){l=5;break}dma(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else if((k<<24>>24|0)!=0){l=5}}while(0);if((l|0)==5){l=0;bma(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}j=j+1|0;}while((j|0)<16);return}function gma(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=f;j=0;do{do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(j<<4<<2)>>2]|0)==0){break}dma(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else{bma(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<16);return}function hma(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=a[g+12|0]|0;do{if((h<<24>>24|0)==1){if((c[e>>2]|0)==0){i=4;break}ema(b+(c[d>>2]|0)|0,e,f)}else if((h<<24>>24|0)!=0){i=4}}while(0);if((i|0)==4){cma(b+(c[d>>2]|0)|0,e,f)}h=a[g+14|0]|0;do{if((h<<24>>24|0)==1){if((c[e+256>>2]|0)==0){i=8;break}ema(b+(c[d+16>>2]|0)|0,e+256|0,f)}else if((h<<24>>24|0)!=0){i=8}}while(0);if((i|0)==8){cma(b+(c[d+16>>2]|0)|0,e+256|0,f)}h=a[g+28|0]|0;do{if((h<<24>>24|0)==1){if((c[e+512>>2]|0)==0){i=12;break}ema(b+(c[d+32>>2]|0)|0,e+512|0,f)}else if((h<<24>>24|0)!=0){i=12}}while(0);if((i|0)==12){cma(b+(c[d+32>>2]|0)|0,e+512|0,f)}h=a[g+30|0]|0;if((h<<24>>24|0)==0){return}else if((h<<24>>24|0)==1){i=14}do{if((i|0)==14){if((c[e+768>>2]|0)==0){break}ema(b+(c[d+48>>2]|0)|0,e+768|0,f);return}}while(0);cma(b+(c[d+48>>2]|0)|0,e+768|0,f);return}function ima(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=f;j=1;do{k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[602104+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}dma((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{bma((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[602104+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}dma((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{bma((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[602104+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}dma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{bma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[602104+n|0]|0)|0]|0)!=0){bma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}dma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<3);return}function jma(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f;j=1;while(1){k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[602104+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}dma((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{bma((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[602104+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}dma((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{bma((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[602104+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}dma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{bma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[602104+n|0]|0)|0]|0)!=0){bma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}dma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);k=j+1|0;if((k|0)<3){j=k}else{o=20;break}}do{j=o+4|0;do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(o<<4<<2)>>2]|0)==0){break}dma((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}else{bma((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}}while(0);o=o+1|0;}while((o|0)<24);o=b+4|0;b=36;do{j=b+4|0;do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(b<<4<<2)>>2]|0)==0){break}dma((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}else{bma((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}}while(0);b=b+1|0;}while((b|0)<40);return}function kma(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b>>2]|0;j=c[b+4>>2]|0;k=j+h|0;l=h-j|0;j=c[b+8>>2]|0;h=c[b+12>>2]|0;m=j-h|0;n=h+j|0;j=n+k|0;c[g>>2]=j;c[g+4>>2]=k-n;c[g+8>>2]=l-m;c[g+12>>2]=m+l;l=c[b+16>>2]|0;m=c[b+20>>2]|0;n=m+l|0;k=l-m|0;m=c[b+24>>2]|0;l=c[b+28>>2]|0;h=m-l|0;o=l+m|0;c[g+16>>2]=o+n;c[g+20>>2]=n-o;c[g+24>>2]=k-h;c[g+28>>2]=h+k;k=c[b+32>>2]|0;h=c[b+36>>2]|0;o=h+k|0;n=k-h|0;h=c[b+40>>2]|0;k=c[b+44>>2]|0;m=h-k|0;l=k+h|0;c[g+32>>2]=l+o;c[g+36>>2]=o-l;c[g+40>>2]=n-m;c[g+44>>2]=m+n;n=c[b+48>>2]|0;m=c[b+52>>2]|0;l=m+n|0;o=n-m|0;m=c[b+56>>2]|0;n=c[b+60>>2]|0;b=m-n|0;h=n+m|0;c[g+48>>2]=h+l;c[g+52>>2]=l-h;c[g+56>>2]=o-b;c[g+60>>2]=b+o;o=a;a=0;b=j;while(1){j=d[1375904+a|0]|0;h=c[g+(a+8<<2)>>2]|0;l=h+b|0;m=b-h|0;h=c[g+(a+4<<2)>>2]|0;n=c[g+(a+12<<2)>>2]|0;k=h-n|0;p=n+h|0;c[o+(j<<2)>>2]=(ca(p+l|0,e)|0)+128>>8;c[o+(j+16<<2)>>2]=(ca(k+m|0,e)|0)+128>>8;c[o+(j+64<<2)>>2]=(ca(m-k|0,e)|0)+128>>8;c[o+(j+80<<2)>>2]=(ca(l-p|0,e)|0)+128>>8;p=a+1|0;if((p|0)>=4){break}a=p;b=c[g+(p<<2)>>2]|0}i=f;return}function lma(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=g+e|0;i=e-g|0;g=a+128|0;e=c[g>>2]|0;j=a+192|0;k=c[j>>2]|0;l=k+e|0;m=e-k|0;k=a+256|0;e=c[k>>2]|0;n=a+320|0;o=c[n>>2]|0;p=o+e|0;q=e-o|0;o=a+384|0;e=c[o>>2]|0;r=a+448|0;a=c[r>>2]|0;s=a+e|0;t=e-a|0;a=p+h|0;e=h-p|0;p=l-s|0;h=s+l|0;c[d>>2]=(ca(h+a|0,b)|0)+128>>8;c[g>>2]=(ca(p+e|0,b)|0)+128>>8;c[k>>2]=(ca(e-p|0,b)|0)+128>>8;c[o>>2]=(ca(a-h|0,b)|0)+128>>8;h=q+i|0;a=i-q|0;q=m-t|0;i=t+m|0;c[f>>2]=(ca(i+h|0,b)|0)+128>>8;c[j>>2]=(ca(q+a|0,b)|0)+128>>8;c[n>>2]=(ca(a-q|0,b)|0)+128>>8;c[r>>2]=(ca(h-i|0,b)|0)+128>>8;return}function mma(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=a+128|0;i=c[h>>2]|0;j=a+192|0;a=c[j>>2]|0;k=e-g|0;l=g+e|0;e=i-a|0;g=a+i|0;c[d>>2]=(ca(g+l|0,b)|0)>>7;c[f>>2]=(ca(e+k|0,b)|0)>>7;c[h>>2]=(ca(l-g|0,b)|0)>>7;c[j>>2]=(ca(k-e|0,b)|0)>>7;return}function nma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=d;h=(c[g>>2]|0)+32|0;i=d+32|0;j=c[i>>2]|0;k=j+h|0;l=h-j|0;j=d+16|0;h=c[j>>2]|0;m=d+48|0;n=c[m>>2]|0;o=(h>>1)-n|0;p=(n>>1)+h|0;c[g>>2]=p+k;c[j>>2]=o+l;c[i>>2]=l-o;c[m>>2]=k-p;p=d+4|0;k=c[p>>2]|0;m=d+36|0;o=c[m>>2]|0;l=o+k|0;i=k-o|0;o=d+20|0;k=c[o>>2]|0;j=d+52|0;h=c[j>>2]|0;n=(k>>1)-h|0;q=(h>>1)+k|0;c[p>>2]=q+l;c[o>>2]=n+i;c[m>>2]=i-n;c[j>>2]=l-q;q=d+8|0;l=c[q>>2]|0;j=d+40|0;n=c[j>>2]|0;i=n+l|0;m=l-n|0;n=d+24|0;l=c[n>>2]|0;o=d+56|0;p=c[o>>2]|0;k=(l>>1)-p|0;h=(p>>1)+l|0;c[q>>2]=h+i;c[n>>2]=k+m;c[j>>2]=m-k;c[o>>2]=i-h;h=d+12|0;i=c[h>>2]|0;o=d+44|0;k=c[o>>2]|0;m=k+i|0;j=i-k|0;k=d+28|0;i=c[k>>2]|0;n=d+60|0;q=c[n>>2]|0;l=(i>>1)-q|0;p=(q>>1)+i|0;c[h>>2]=p+m;c[k>>2]=l+j;c[o>>2]=j-l;c[n>>2]=m-p;p=a;a=f>>1;f=a<<1;m=a*3|0;n=0;do{l=n<<2;j=c[g+(l<<2)>>2]|0;o=c[g+((l|2)<<2)>>2]|0;k=o+j|0;h=j-o|0;o=c[g+((l|1)<<2)>>2]|0;j=c[g+((l|3)<<2)>>2]|0;l=(o>>1)-j|0;i=(j>>1)+o|0;o=p+(n<<1)|0;j=(i+k>>6)+(e[o>>1]|0)|0;if(j>>>0<16384>>>0){r=j&65535}else{r=-j>>31&16383}b[o>>1]=r;o=p+(n+a<<1)|0;j=(e[o>>1]|0)+(l+h>>6)|0;if(j>>>0<16384>>>0){s=j&65535}else{s=-j>>31&16383}b[o>>1]=s;o=p+(n+f<<1)|0;j=(e[o>>1]|0)+(h-l>>6)|0;if(j>>>0<16384>>>0){t=j&65535}else{t=-j>>31&16383}b[o>>1]=t;o=p+(n+m<<1)|0;j=(e[o>>1]|0)+(k-i>>6)|0;if(j>>>0<16384>>>0){u=j&65535}else{u=-j>>31&16383}b[o>>1]=u;n=n+1|0;}while((n|0)<4);mrc(d|0,0,64)|0;return}function oma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=d;h=(c[g>>2]|0)+32|0;c[g>>2]=h;i=0;j=h;while(1){h=g+(i+32<<2)|0;k=c[h>>2]|0;l=k+j|0;m=j-k|0;k=g+(i+16<<2)|0;n=c[k>>2]|0;o=g+(i+48<<2)|0;p=c[o>>2]|0;q=(n>>1)-p|0;r=(p>>1)+n|0;n=r+l|0;p=q+m|0;s=m-q|0;q=l-r|0;r=g+(i+24<<2)|0;l=c[r>>2]|0;m=g+(i+40<<2)|0;t=c[m>>2]|0;u=g+(i+56<<2)|0;v=c[u>>2]|0;w=t-l-v-(v>>1)|0;x=g+(i+8<<2)|0;y=c[x>>2]|0;z=v-((l>>1)+l)+y|0;A=v+t+(t>>1)-y|0;v=t+l+y+(y>>1)|0;y=(v>>2)+w|0;l=(A>>2)+z|0;t=(z>>2)-A|0;A=v-(w>>2)|0;c[g+(i<<2)>>2]=A+n;c[u>>2]=n-A;c[x>>2]=t+p;c[o>>2]=p-t;c[k>>2]=l+s;c[m>>2]=s-l;c[r>>2]=y+q;c[h>>2]=q-y;y=i+1|0;if((y|0)>=8){break}i=y;j=c[g+(y<<2)>>2]|0}j=a;a=f>>1;f=a<<1;i=a*3|0;y=a<<2;q=a*5|0;h=a*6|0;r=a*7|0;l=0;do{s=l<<3;m=c[g+(s<<2)>>2]|0;k=c[g+((s|4)<<2)>>2]|0;t=k+m|0;p=m-k|0;k=c[g+((s|2)<<2)>>2]|0;m=c[g+((s|6)<<2)>>2]|0;o=(k>>1)-m|0;x=(m>>1)+k|0;k=x+t|0;m=o+p|0;A=p-o|0;o=t-x|0;x=c[g+((s|3)<<2)>>2]|0;t=c[g+((s|5)<<2)>>2]|0;p=c[g+((s|7)<<2)>>2]|0;n=t-x-p-(p>>1)|0;u=c[g+((s|1)<<2)>>2]|0;s=p-((x>>1)+x)+u|0;w=p+t+(t>>1)-u|0;p=t+x+u+(u>>1)|0;u=(p>>2)+n|0;x=(w>>2)+s|0;t=(s>>2)-w|0;w=p-(n>>2)|0;n=j+(l<<1)|0;p=(w+k>>6)+(e[n>>1]|0)|0;if(p>>>0<16384>>>0){B=p&65535}else{B=-p>>31&16383}b[n>>1]=B;n=j+(l+a<<1)|0;p=(e[n>>1]|0)+(t+m>>6)|0;if(p>>>0<16384>>>0){C=p&65535}else{C=-p>>31&16383}b[n>>1]=C;n=j+(l+f<<1)|0;p=(e[n>>1]|0)+(x+A>>6)|0;if(p>>>0<16384>>>0){D=p&65535}else{D=-p>>31&16383}b[n>>1]=D;n=j+(l+i<<1)|0;p=(e[n>>1]|0)+(u+o>>6)|0;if(p>>>0<16384>>>0){E=p&65535}else{E=-p>>31&16383}b[n>>1]=E;n=j+(l+y<<1)|0;p=(e[n>>1]|0)+(o-u>>6)|0;if(p>>>0<16384>>>0){F=p&65535}else{F=-p>>31&16383}b[n>>1]=F;n=j+(l+q<<1)|0;p=(e[n>>1]|0)+(A-x>>6)|0;if(p>>>0<16384>>>0){G=p&65535}else{G=-p>>31&16383}b[n>>1]=G;n=j+(l+h<<1)|0;p=(e[n>>1]|0)+(m-t>>6)|0;if(p>>>0<16384>>>0){H=p&65535}else{H=-p>>31&16383}b[n>>1]=H;n=j+(l+r<<1)|0;p=(e[n>>1]|0)+(k-w>>6)|0;if(p>>>0<16384>>>0){I=p&65535}else{I=-p>>31&16383}b[n>>1]=I;l=l+1|0;}while((l|0)<8);mrc(d|0,0,256)|0;return}function pma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d;d=(c[g>>2]|0)+32>>6;h=f>>>1;c[g>>2]=0;g=0;f=a;while(1){a=(e[f>>1]|0)+d|0;if(a>>>0<16384>>>0){i=a&65535}else{i=-a>>31&16383}b[f>>1]=i;a=f+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){k=j&65535}else{k=-j>>31&16383}b[a>>1]=k;a=f+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){l=j&65535}else{l=-j>>31&16383}b[a>>1]=l;a=f+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){m=j&65535}else{m=-j>>31&16383}b[a>>1]=m;a=g+1|0;if((a|0)<4){g=a;f=f+(h<<1)|0}else{break}}return}function qma(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d;d=(c[g>>2]|0)+32>>6;c[g>>2]=0;g=f>>>1;f=0;h=a;while(1){a=(e[h>>1]|0)+d|0;if(a>>>0<16384>>>0){i=a&65535}else{i=-a>>31&16383}b[h>>1]=i;a=h+2|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){k=j&65535}else{k=-j>>31&16383}b[a>>1]=k;a=h+4|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){l=j&65535}else{l=-j>>31&16383}b[a>>1]=l;a=h+6|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){m=j&65535}else{m=-j>>31&16383}b[a>>1]=m;a=h+8|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){n=j&65535}else{n=-j>>31&16383}b[a>>1]=n;a=h+10|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){o=j&65535}else{o=-j>>31&16383}b[a>>1]=o;a=h+12|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){p=j&65535}else{p=-j>>31&16383}b[a>>1]=p;a=h+14|0;j=(e[a>>1]|0)+d|0;if(j>>>0<16384>>>0){q=j&65535}else{q=-j>>31&16383}b[a>>1]=q;a=f+1|0;if((a|0)<8){f=a;h=h+(g<<1)|0}else{break}}return}function rma(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=f;j=0;do{k=a[h+(d[602104+j|0]|0)|0]|0;do{if((k<<24>>24|0)==1){if((c[i+(j<<4<<2)>>2]|0)==0){l=5;break}pma(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else if((k<<24>>24|0)!=0){l=5}}while(0);if((l|0)==5){l=0;nma(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}j=j+1|0;}while((j|0)<16);return}function sma(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=f;j=0;do{do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(j<<4<<2)>>2]|0)==0){break}pma(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}else{nma(b+(c[e+(j<<2)>>2]|0)|0,f+(j<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<16);return}function tma(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=a[g+12|0]|0;do{if((h<<24>>24|0)==1){if((c[e>>2]|0)==0){i=4;break}qma(b+(c[d>>2]|0)|0,e,f)}else if((h<<24>>24|0)!=0){i=4}}while(0);if((i|0)==4){oma(b+(c[d>>2]|0)|0,e,f)}h=a[g+14|0]|0;do{if((h<<24>>24|0)==1){if((c[e+256>>2]|0)==0){i=8;break}qma(b+(c[d+16>>2]|0)|0,e+256|0,f)}else if((h<<24>>24|0)!=0){i=8}}while(0);if((i|0)==8){oma(b+(c[d+16>>2]|0)|0,e+256|0,f)}h=a[g+28|0]|0;do{if((h<<24>>24|0)==1){if((c[e+512>>2]|0)==0){i=12;break}qma(b+(c[d+32>>2]|0)|0,e+512|0,f)}else if((h<<24>>24|0)!=0){i=12}}while(0);if((i|0)==12){oma(b+(c[d+32>>2]|0)|0,e+512|0,f)}h=a[g+30|0]|0;if((h<<24>>24|0)==1){i=14}else if((h<<24>>24|0)==0){return}do{if((i|0)==14){if((c[e+768>>2]|0)==0){break}qma(b+(c[d+48>>2]|0)|0,e+768|0,f);return}}while(0);oma(b+(c[d+48>>2]|0)|0,e+768|0,f);return}function uma(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=f;j=1;do{k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[602104+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}pma((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{nma((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[602104+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}pma((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{nma((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[602104+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}pma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{nma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[602104+n|0]|0)|0]|0)!=0){nma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}pma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);j=j+1|0;}while((j|0)<3);return}function vma(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=f;j=1;while(1){k=j<<4;do{if((k|0)<(k|4|0)){l=b+(j-1<<2)|0;do{if((a[h+(d[602104+k|0]|0)|0]|0)==0){if((c[i+(j<<8<<2)>>2]|0)==0){break}pma((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}else{nma((c[l>>2]|0)+(c[e+(k<<2)>>2]|0)|0,f+(j<<9<<1)|0,g)}}while(0);m=k|1;do{if((a[h+(d[602104+m|0]|0)|0]|0)==0){if((c[i+(m<<4<<2)>>2]|0)==0){break}pma((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}else{nma((c[l>>2]|0)+(c[e+(m<<2)>>2]|0)|0,f+(m<<5<<1)|0,g)}}while(0);n=m+1|0;do{if((a[h+(d[602104+n|0]|0)|0]|0)==0){if((c[i+(n<<4<<2)>>2]|0)==0){break}pma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}else{nma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);n=k|3;if((a[h+(d[602104+n|0]|0)|0]|0)!=0){nma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g);break}if((c[i+(n<<4<<2)>>2]|0)==0){break}pma((c[l>>2]|0)+(c[e+(n<<2)>>2]|0)|0,f+(n<<5<<1)|0,g)}}while(0);k=j+1|0;if((k|0)<3){j=k}else{o=20;break}}do{j=o+4|0;do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(o<<4<<2)>>2]|0)==0){break}pma((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}else{nma((c[b>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(o<<5<<1)|0,g)}}while(0);o=o+1|0;}while((o|0)<24);o=b+4|0;b=36;do{j=b+4|0;do{if((a[h+(d[602104+j|0]|0)|0]|0)==0){if((c[i+(b<<4<<2)>>2]|0)==0){break}pma((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}else{nma((c[o>>2]|0)+(c[e+(j<<2)>>2]|0)|0,f+(b<<5<<1)|0,g)}}while(0);b=b+1|0;}while((b|0)<40);return}function wma(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;h=c[b>>2]|0;j=c[b+4>>2]|0;k=j+h|0;l=h-j|0;j=c[b+8>>2]|0;h=c[b+12>>2]|0;m=j-h|0;n=h+j|0;j=n+k|0;c[g>>2]=j;c[g+4>>2]=k-n;c[g+8>>2]=l-m;c[g+12>>2]=m+l;l=c[b+16>>2]|0;m=c[b+20>>2]|0;n=m+l|0;k=l-m|0;m=c[b+24>>2]|0;l=c[b+28>>2]|0;h=m-l|0;o=l+m|0;c[g+16>>2]=o+n;c[g+20>>2]=n-o;c[g+24>>2]=k-h;c[g+28>>2]=h+k;k=c[b+32>>2]|0;h=c[b+36>>2]|0;o=h+k|0;n=k-h|0;h=c[b+40>>2]|0;k=c[b+44>>2]|0;m=h-k|0;l=k+h|0;c[g+32>>2]=l+o;c[g+36>>2]=o-l;c[g+40>>2]=n-m;c[g+44>>2]=m+n;n=c[b+48>>2]|0;m=c[b+52>>2]|0;l=m+n|0;o=n-m|0;m=c[b+56>>2]|0;n=c[b+60>>2]|0;b=m-n|0;h=n+m|0;c[g+48>>2]=h+l;c[g+52>>2]=l-h;c[g+56>>2]=o-b;c[g+60>>2]=b+o;o=a;a=0;b=j;while(1){j=d[1375904+a|0]|0;h=c[g+(a+8<<2)>>2]|0;l=h+b|0;m=b-h|0;h=c[g+(a+4<<2)>>2]|0;n=c[g+(a+12<<2)>>2]|0;k=h-n|0;p=n+h|0;c[o+(j<<2)>>2]=(ca(p+l|0,e)|0)+128>>8;c[o+(j+16<<2)>>2]=(ca(k+m|0,e)|0)+128>>8;c[o+(j+64<<2)>>2]=(ca(m-k|0,e)|0)+128>>8;c[o+(j+80<<2)>>2]=(ca(l-p|0,e)|0)+128>>8;p=a+1|0;if((p|0)>=4){break}a=p;b=c[g+(p<<2)>>2]|0}i=f;return}function xma(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=g+e|0;i=e-g|0;g=a+128|0;e=c[g>>2]|0;j=a+192|0;k=c[j>>2]|0;l=k+e|0;m=e-k|0;k=a+256|0;e=c[k>>2]|0;n=a+320|0;o=c[n>>2]|0;p=o+e|0;q=e-o|0;o=a+384|0;e=c[o>>2]|0;r=a+448|0;a=c[r>>2]|0;s=a+e|0;t=e-a|0;a=p+h|0;e=h-p|0;p=l-s|0;h=s+l|0;c[d>>2]=(ca(h+a|0,b)|0)+128>>8;c[g>>2]=(ca(p+e|0,b)|0)+128>>8;c[k>>2]=(ca(e-p|0,b)|0)+128>>8;c[o>>2]=(ca(a-h|0,b)|0)+128>>8;h=q+i|0;a=i-q|0;q=m-t|0;i=t+m|0;c[f>>2]=(ca(i+h|0,b)|0)+128>>8;c[j>>2]=(ca(q+a|0,b)|0)+128>>8;c[n>>2]=(ca(a-q|0,b)|0)+128>>8;c[r>>2]=(ca(h-i|0,b)|0)+128>>8;return}function yma(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a;e=c[d>>2]|0;f=a+64|0;g=c[f>>2]|0;h=a+128|0;i=c[h>>2]|0;j=a+192|0;a=c[j>>2]|0;k=e-g|0;l=g+e|0;e=i-a|0;g=a+i|0;c[d>>2]=(ca(g+l|0,b)|0)>>7;c[f>>2]=(ca(e+k|0,b)|0)>>7;c[h>>2]=(ca(l-g|0,b)|0)>>7;c[j>>2]=(ca(k-e|0,b)|0)>>7;return}function zma(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;if((d|0)==12){g=(b|0)==70;do{if(g){c[a>>2]=36;c[a+4>>2]=280;c[a+8>>2]=1318;c[a+12>>2]=2142;c[a+16>>2]=1642;c[a+20>>2]=1296;c[a+24>>2]=1926;c[a+28>>2]=1686;c[a+32>>2]=782;c[a+36>>2]=60;c[a+40>>2]=1206;c[a+44>>2]=2346;c[a+48>>2]=10;c[a+52>>2]=1992;c[a+56>>2]=1398}else{h=(b|0)==141;j=a|0;if(h){c[j>>2]=1774;c[a+4>>2]=608}else{c[j>>2]=36;c[a+4>>2]=280}c[a+8>>2]=1318;c[a+12>>2]=(b|0)==24?1754:778;c[a+16>>2]=1642;c[a+20>>2]=1296;c[a+24>>2]=1926;c[a+28>>2]=h?516:1314;c[a+32>>2]=618;j=a+36|0;if(h){c[j>>2]=858;c[a+48>>2]=2164;c[a+52>>2]=534;c[a+40>>2]=36;c[a+56>>2]=280;break}else{c[j>>2]=60;c[a+40>>2]=1206;c[a+44>>2]=2346;break}}}while(0);c[a+60>>2]=538;c[a+64>>2]=122;c[a+68>>2]=324;c[a+72>>2]=224;c[a+76>>2]=566;c[a+80>>2]=690;c[a+84>>2]=268;c[a+88>>2]=528;c[a+92>>2]=508;c[a+96>>2]=828;c[a+100>>2]=700;c[a+104>>2]=56;j=(e|0)<2;h=a+108|0;k=a+116|0;if(j){c[k>>2]=344;c[a+112>>2]=324}else{c[k>>2]=502;c[a+112>>2]=496}k=a+120|0;a:do{if((b|0)==141){c[k>>2]=636;c[h>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+136>>2]=354;c[a+140>>2]=566;c[a+132>>2]=j?60:114;c[a+152>>2]=352;c[a+160>>2]=198;c[a+156>>2]=380;l=77}else{c[k>>2]=j?328:358;m=h|0;do{if(g){c[m>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+132>>2]=j?60:114;c[a+152>>2]=352;c[a+160>>2]=198;c[a+156>>2]=380}else{if(j){c[m>>2]=278;c[a+124>>2]=578;c[a+128>>2]=64;c[a+136>>2]=394;c[a+140>>2]=302;c[a+144>>2]=134;c[a+148>>2]=624}else{c[m>>2]=304;c[a+124>>2]=102;c[a+128>>2]=290;c[a+136>>2]=348;c[a+140>>2]=56;c[a+144>>2]=550;c[a+148>>2]=128}c[a+132>>2]=j?60:114;c[a+152>>2]=352;c[a+160>>2]=198;c[a+156>>2]=380;if((b|0)==24){c[a+164>>2]=656;break a}else if((b|0)==70){break}else if((b|0)==141){l=77;break a}else{c[a+164>>2]=322;break a}}}while(0);c[a+164>>2]=326}}while(0);if((l|0)==77){c[a+164>>2]=552;c[a+180>>2]=76;c[a+184>>2]=372}c[a+168>>2]=398;c[a+172>>2]=570;c[a+176>>2]=294;c[a+188>>2]=582;c[a+192>>2]=288;c[a+196>>2]=570;c[a+200>>2]=1800;g=a+212|0;if(j){c[g>>2]=478;c[a+208>>2]=316}else{c[g>>2]=994;c[a+208>>2]=698}c[a+224>>2]=720;c[a+220>>2]=1004;i=f;return}else if((d|0)==14){g=(b|0)==70;do{if(g){c[a>>2]=1428;c[a+4>>2]=2410;c[a+8>>2]=718;c[a+12>>2]=2142;c[a+16>>2]=1060;c[a+20>>2]=1904;c[a+24>>2]=590;c[a+28>>2]=1686;c[a+32>>2]=782;c[a+36>>2]=1608;c[a+40>>2]=282;c[a+44>>2]=1796;c[a+48>>2]=10;c[a+52>>2]=1992;c[a+56>>2]=1398}else{j=(b|0)==141;h=a|0;if(j){c[h>>2]=1774;c[a+4>>2]=608}else{c[h>>2]=1428;c[a+4>>2]=2410}c[a+8>>2]=718;c[a+12>>2]=(b|0)==24?1754:426;c[a+16>>2]=1060;c[a+20>>2]=1904;c[a+24>>2]=590;c[a+28>>2]=j?516:686;c[a+32>>2]=296;h=a+36|0;if(j){c[h>>2]=858;c[a+48>>2]=1550;c[a+52>>2]=1146;c[a+40>>2]=1428;c[a+56>>2]=2410;break}else{c[h>>2]=1608;c[a+40>>2]=282;c[a+44>>2]=1796;break}}}while(0);c[a+60>>2]=794;c[a+64>>2]=244;c[a+68>>2]=616;c[a+72>>2]=328;c[a+76>>2]=442;c[a+80>>2]=82;c[a+84>>2]=666;c[a+88>>2]=780;c[a+92>>2]=320;c[a+96>>2]=676;c[a+100>>2]=434;c[a+104>>2]=274;h=(e|0)<2;j=a+108|0;k=a+116|0;if(h){c[k>>2]=518;c[a+112>>2]=222}else{c[k>>2]=652;c[a+112>>2]=42}k=a+120|0;b:do{if((b|0)==141){c[k>>2]=636;c[j>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+136>>2]=160;c[a+140>>2]=46;c[a+132>>2]=h?226:310;c[a+152>>2]=522;c[a+160>>2]=30;c[a+156>>2]=466;l=104}else{c[k>>2]=h?426:526;m=j|0;do{if(g){c[m>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+132>>2]=h?226:310;c[a+152>>2]=522;c[a+160>>2]=30;c[a+156>>2]=466}else{if(h){c[m>>2]=82;c[a+124>>2]=420;c[a+128>>2]=504;c[a+136>>2]=390;c[a+140>>2]=298;c[a+144>>2]=136;c[a+148>>2]=626}else{c[m>>2]=106;c[a+124>>2]=202;c[a+128>>2]=86;c[a+136>>2]=350;c[a+140>>2]=58;c[a+144>>2]=548;c[a+148>>2]=124}c[a+132>>2]=h?226:310;c[a+152>>2]=522;c[a+160>>2]=30;c[a+156>>2]=466;if((b|0)==24){c[a+164>>2]=656;break b}else if((b|0)==70){break}else if((b|0)==141){l=104;break b}else{c[a+164>>2]=500;break b}}}while(0);c[a+164>>2]=326}}while(0);if((l|0)==104){c[a+164>>2]=552;c[a+180>>2]=250;c[a+184>>2]=200}c[a+168>>2]=646;c[a+172>>2]=654;c[a+176>>2]=92;c[a+188>>2]=1204;c[a+192>>2]=2090;c[a+196>>2]=1180;c[a+200>>2]=1192;g=a+212|0;if(h){c[g>>2]=738;c[a+208>>2]=1008}else{c[g>>2]=300;c[a+208>>2]=432}c[a+224>>2]=886;c[a+220>>2]=390;i=f;return}else if((d|0)==9){g=(b|0)==70;do{if(g){c[a>>2]=460;c[a+4>>2]=698;c[a+8>>2]=1840;c[a+12>>2]=2142;c[a+16>>2]=1694;c[a+20>>2]=758;c[a+24>>2]=464;c[a+28>>2]=1686;c[a+32>>2]=782;c[a+36>>2]=610;c[a+40>>2]=2390;c[a+44>>2]=1220;c[a+48>>2]=10;c[a+52>>2]=1992;c[a+56>>2]=1398}else{h=(b|0)==141;j=a|0;if(h){c[j>>2]=1774;c[a+4>>2]=608}else{c[j>>2]=460;c[a+4>>2]=698}c[a+8>>2]=1840;c[a+12>>2]=(b|0)==24?1754:458;c[a+16>>2]=1694;c[a+20>>2]=758;c[a+24>>2]=464;c[a+28>>2]=h?516:780;c[a+32>>2]=1236;j=a+36|0;if(h){c[j>>2]=858;c[a+48>>2]=1620;c[a+52>>2]=2418;c[a+40>>2]=460;c[a+56>>2]=698;break}else{c[j>>2]=610;c[a+40>>2]=2390;c[a+44>>2]=1220;break}}}while(0);c[a+60>>2]=108;c[a+64>>2]=766;c[a+68>>2]=792;c[a+72>>2]=644;c[a+76>>2]=140;c[a+80>>2]=968;c[a+84>>2]=650;c[a+88>>2]=378;c[a+92>>2]=364;c[a+96>>2]=746;c[a+100>>2]=624;c[a+104>>2]=446;j=(e|0)<2;h=a+108|0;k=a+116|0;if(j){c[k>>2]=20;c[a+112>>2]=516}else{c[k>>2]=246;c[a+112>>2]=340}k=a+120|0;c:do{if((b|0)==141){c[k>>2]=636;c[h>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+136>>2]=596;c[a+140>>2]=362;c[a+132>>2]=j?196:174;c[a+152>>2]=628;c[a+160>>2]=590;c[a+156>>2]=224;l=23}else{c[k>>2]=j?542:422;m=h|0;do{if(g){c[m>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+132>>2]=j?196:174;c[a+152>>2]=628;c[a+160>>2]=590;c[a+156>>2]=224}else{if(j){c[m>>2]=484;c[a+124>>2]=592;c[a+128>>2]=104;c[a+136>>2]=122;c[a+140>>2]=190;c[a+144>>2]=40;c[a+148>>2]=474}else{c[m>>2]=318;c[a+124>>2]=470;c[a+128>>2]=520;c[a+136>>2]=72;c[a+140>>2]=176;c[a+144>>2]=406;c[a+148>>2]=26}c[a+132>>2]=j?196:174;c[a+152>>2]=628;c[a+160>>2]=590;c[a+156>>2]=224;if((b|0)==70){break}else if((b|0)==141){l=23;break c}else if((b|0)==24){c[a+164>>2]=656;break c}else{c[a+164>>2]=658;break c}}}while(0);c[a+164>>2]=326}}while(0);if((l|0)==23){c[a+164>>2]=552;c[a+180>>2]=450;c[a+184>>2]=536}c[a+168>>2]=148;c[a+172>>2]=610;c[a+176>>2]=660;c[a+188>>2]=2080;c[a+192>>2]=368;c[a+196>>2]=1336;c[a+200>>2]=1094;g=a+212|0;if(j){c[g>>2]=980;c[a+208>>2]=890}else{c[g>>2]=262;c[a+208>>2]=1028}c[a+224>>2]=94;c[a+220>>2]=844;i=f;return}else if((d|0)==10){g=(b|0)==70;do{if(g){c[a>>2]=1546;c[a+4>>2]=1184;c[a+8>>2]=1940;c[a+12>>2]=2142;c[a+16>>2]=2258;c[a+20>>2]=678;c[a+24>>2]=1310;c[a+28>>2]=1686;c[a+32>>2]=782;c[a+36>>2]=664;c[a+40>>2]=1820;c[a+44>>2]=580;c[a+48>>2]=10;c[a+52>>2]=1992;c[a+56>>2]=1398}else{j=(b|0)==141;h=a|0;if(j){c[h>>2]=1774;c[a+4>>2]=608}else{c[h>>2]=1546;c[a+4>>2]=1184}c[a+8>>2]=1940;c[a+12>>2]=(b|0)==24?1754:216;c[a+16>>2]=2258;c[a+20>>2]=678;c[a+24>>2]=1310;c[a+28>>2]=j?516:1846;c[a+32>>2]=40;h=a+36|0;if(j){c[h>>2]=858;c[a+48>>2]=352;c[a+52>>2]=2376;c[a+40>>2]=1546;c[a+56>>2]=1184;break}else{c[h>>2]=664;c[a+40>>2]=1820;c[a+44>>2]=580;break}}}while(0);c[a+60>>2]=742;c[a+64>>2]=342;c[a+68>>2]=590;c[a+72>>2]=900;c[a+76>>2]=842;c[a+80>>2]=438;c[a+84>>2]=46;c[a+88>>2]=628;c[a+92>>2]=870;c[a+96>>2]=58;c[a+100>>2]=988;c[a+104>>2]=826;h=(e|0)<2;j=a+108|0;k=a+116|0;if(h){c[k>>2]=74;c[a+112>>2]=572}else{c[k>>2]=320;c[a+112>>2]=650}k=a+120|0;d:do{if((b|0)==141){c[k>>2]=636;c[j>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+136>>2]=524;c[a+140>>2]=400;c[a+132>>2]=h?576:560;c[a+152>>2]=166;c[a+160>>2]=638;c[a+156>>2]=538;l=50}else{c[k>>2]=h?494:172;m=j|0;do{if(g){c[m>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+132>>2]=h?576:560;c[a+152>>2]=166;c[a+160>>2]=638;c[a+156>>2]=538}else{if(h){c[m>>2]=448;c[a+124>>2]=62;c[a+128>>2]=238;c[a+136>>2]=392;c[a+140>>2]=300;c[a+144>>2]=132;c[a+148>>2]=622}else{c[m>>2]=478;c[a+124>>2]=634;c[a+128>>2]=452;c[a+136>>2]=346;c[a+140>>2]=54;c[a+144>>2]=554;c[a+148>>2]=126}c[a+132>>2]=h?576:560;c[a+152>>2]=166;c[a+160>>2]=638;c[a+156>>2]=538;if((b|0)==70){break}else if((b|0)==141){l=50;break d}else if((b|0)==24){c[a+164>>2]=656;break d}else{c[a+164>>2]=138;break d}}}while(0);c[a+164>>2]=326}}while(0);if((l|0)==50){c[a+164>>2]=552;c[a+180>>2]=600;c[a+184>>2]=544}c[a+168>>2]=214;c[a+172>>2]=416;c[a+176>>2]=18;c[a+188>>2]=2094;c[a+192>>2]=886;c[a+196>>2]=2404;c[a+200>>2]=2422;g=a+212|0;if(h){c[g>>2]=110;c[a+208>>2]=472}else{c[g>>2]=706;c[a+208>>2]=80}c[a+224>>2]=334;c[a+220>>2]=50;i=f;return}else{if((d|0)>=9){KIb(0,0,2538976,(d=i,i=i+24|0,c[d>>2]=2604904,c[d+8>>2]=2452448,c[d+16>>2]=585,d)|0);i=d;Hd()}d=(b|0)==70;do{if(d){c[a>>2]=62;c[a+4>>2]=2192;c[a+8>>2]=1486;c[a+12>>2]=2142;c[a+16>>2]=1370;c[a+20>>2]=406;c[a+24>>2]=1414;c[a+28>>2]=1686;c[a+32>>2]=782;c[a+36>>2]=1562;c[a+40>>2]=904;c[a+44>>2]=1134;c[a+48>>2]=10;c[a+52>>2]=1992;c[a+56>>2]=1398}else{g=(b|0)==141;h=a|0;if(g){c[h>>2]=1774;c[a+4>>2]=608}else{c[h>>2]=62;c[a+4>>2]=2192}c[a+8>>2]=1486;c[a+12>>2]=(b|0)==24?1754:818;c[a+16>>2]=1370;c[a+20>>2]=406;c[a+24>>2]=1414;c[a+28>>2]=g?516:2298;c[a+32>>2]=1582;h=a+36|0;if(g){c[h>>2]=858;c[a+48>>2]=1970;c[a+52>>2]=1130;c[a+40>>2]=62;c[a+56>>2]=2192;break}else{c[h>>2]=1562;c[a+40>>2]=904;c[a+44>>2]=1134;break}}}while(0);c[a+60>>2]=222;c[a+64>>2]=352;c[a+68>>2]=648;c[a+72>>2]=790;c[a+76>>2]=198;c[a+80>>2]=292;c[a+84>>2]=26;c[a+88>>2]=72;c[a+92>>2]=1030;c[a+96>>2]=598;c[a+100>>2]=498;c[a+104>>2]=866;h=(e|0)<2;e=a+108|0;g=a+116|0;if(h){c[g>>2]=94;c[a+112>>2]=236}else{c[g>>2]=288;c[a+112>>2]=240}g=a+120|0;e:do{if((b|0)==141){c[g>>2]=636;c[e>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+136>>2]=6;c[a+140>>2]=460;c[a+132>>2]=h?462:276;c[a+152>>2]=206;c[a+160>>2]=330;c[a+156>>2]=336;l=133}else{c[g>>2]=h?280:666;j=e|0;do{if(d){c[j>>2]=98;c[a+124>>2]=488;c[a+128>>2]=606;c[a+132>>2]=h?462:276;c[a+152>>2]=206;c[a+160>>2]=330;c[a+156>>2]=336}else{if(h){c[j>>2]=382;c[a+124>>2]=164;c[a+128>>2]=384;c[a+136>>2]=120;c[a+140>>2]=188;c[a+144>>2]=38;c[a+148>>2]=472}else{c[j>>2]=418;c[a+124>>2]=556;c[a+128>>2]=608;c[a+136>>2]=70;c[a+140>>2]=32;c[a+144>>2]=404;c[a+148>>2]=24}c[a+132>>2]=h?462:276;c[a+152>>2]=206;c[a+160>>2]=330;c[a+156>>2]=336;if((b|0)==70){break}else if((b|0)==141){l=133;break e}else if((b|0)==24){c[a+164>>2]=656;break e}else{c[a+164>>2]=68;break e}}}while(0);c[a+164>>2]=326}}while(0);if((l|0)==133){c[a+164>>2]=552;c[a+180>>2]=178;c[a+184>>2]=618}c[a+168>>2]=424;c[a+172>>2]=180;c[a+176>>2]=244;c[a+188>>2]=2432;c[a+192>>2]=1860;c[a+196>>2]=376;c[a+200>>2]=1320;l=a+212|0;if(h){c[l>>2]=88;c[a+208>>2]=458}else{c[l>>2]=662;c[a+208>>2]=1014}c[a+224>>2]=206;c[a+220>>2]=418;i=f;return}}function Ama(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d[a+(-e|0)|0]|0;g=d[a+(1-e)|0]|0;h=d[a+(2-e)|0]|0;i=d[a+(3-e)|0]|0;j=(f+2+(g<<1)+h|0)>>>2<<8|((d[a+~e|0]|0)+2+(f<<1)+g|0)>>>2|(g+2+(h<<1)+i|0)>>>2<<16|(h+2+(i<<1)+(d[b]|0)|0)>>>2<<24;c[a>>2]=j;c[a+e>>2]=j;c[a+(e<<1)>>2]=j;c[a+(e*3|0)>>2]=j;return}function Bma(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;b=d[a-1|0]|0;f=d[a+(e-1)|0]|0;g=e<<1;h=d[a+(g-1)|0]|0;i=e*3|0;j=d[a+(i-1)|0]|0;c[a>>2]=ca(((d[a+~e|0]|0)+2+(b<<1)+f|0)>>>2,16843009)|0;c[a+e>>2]=ca((b+2+(f<<1)+h|0)>>>2,16843009)|0;c[a+g>>2]=ca((f+2+(h<<1)+j|0)>>>2,16843009)|0;c[a+i>>2]=ca((h+2+j+(j<<1)|0)>>>2,16843009)|0;return}function Cma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=a;e=d>>1;d=b+(-e<<1)|0;f=c[d>>2]|0;g=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+((e*3|0)<<1)|0;c[d>>2]=f;c[d+4>>2]=g;return}function Dma(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0;b=a;f=d>>1;d=Erc(e[a-2>>1]|0,0,65537,65537)|0;g=a;c[g>>2]=d;c[g+4>>2]=G;g=Erc(e[b+(f-1<<1)>>1]|0,0,65537,65537)|0;d=b+(f<<1)|0;c[d>>2]=g;c[d+4>>2]=G;d=f<<1;g=Erc(e[b+(d-1<<1)>>1]|0,0,65537,65537)|0;a=b+(d<<1)|0;c[a>>2]=g;c[a+4>>2]=G;a=f*3|0;f=Erc(e[b+(a-1<<1)>>1]|0,0,65537,65537)|0;g=b+(a<<1)|0;c[g>>2]=f;c[g+4>>2]=G;return}function Ema(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=(e[b+(-f<<1)>>1]|0)+4+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=b+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(d<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Fma(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;c=d[b+(2-e)|0]|0;f=d[b+(3-e)|0]|0;g=e<<1;h=d[b+(g-1)|0]|0;i=e*3|0;j=d[b+(i-1)|0]|0;a[b]=((d[b+(e-1)|0]|0)+(d[b+(1-e)|0]|0)|0)>>>1;k=(h+c|0)>>>1&255;a[b+e|0]=k;a[b+1|0]=k;k=(j+f|0)>>>1&255;a[b+(i+3)|0]=k;a[b+(i+2)|0]=k;a[b+(g+3)|0]=k;a[b+(i+1)|0]=k;a[b+(g+2)|0]=k;a[b+(e+3)|0]=k;a[b+i|0]=k;a[b+(g|1)|0]=k;a[b+(e+2)|0]=k;a[b+3|0]=k;a[b+g|0]=k;a[b+(e+1)|0]=k;a[b+2|0]=k;return}function Gma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=d>>1;d=e[f+(1-g<<1)>>1]|0;h=e[f+(2-g<<1)>>1]|0;i=e[f+(3-g<<1)>>1]|0;j=e[c>>1]|0;k=e[c+2>>1]|0;l=e[c+4>>1]|0;m=e[c+6>>1]|0;b[f>>1]=((e[f+(-g<<1)>>1]|0)+2+h+(d<<1)|0)>>>2;c=(d+2+i+(h<<1)|0)>>>2&65535;b[f+(g<<1)>>1]=c;b[a+2>>1]=c;c=(h+2+j+(i<<1)|0)>>>2&65535;h=g<<1;b[f+(h<<1)>>1]=c;b[f+(g+1<<1)>>1]=c;b[a+4>>1]=c;c=(i+2+k+(j<<1)|0)>>>2&65535;i=g*3|0;b[f+(i<<1)>>1]=c;b[f+((h|1)<<1)>>1]=c;b[f+(g+2<<1)>>1]=c;b[a+6>>1]=c;c=(j+2+l+(k<<1)|0)>>>2&65535;b[f+(i+1<<1)>>1]=c;b[f+(h+2<<1)>>1]=c;b[f+(g+3<<1)>>1]=c;c=(k+2+m+(l<<1)|0)>>>2&65535;b[f+(i+2<<1)>>1]=c;b[f+(h+3<<1)>>1]=c;b[f+(i+3<<1)>>1]=(l+2+(m*3|0)|0)>>>2;return}function Hma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;b[c+(o<<1)>>1]=(l+2+(n<<1)+(e[c+(o-1<<1)>>1]|0)|0)>>>2;p=(k+2+(l<<1)+n|0)>>>2&65535;b[c+(o+1<<1)>>1]=p;b[c+(m<<1)>>1]=p;p=d+2|0;n=(p+(k<<1)+l|0)>>>2&65535;b[c+(o+2<<1)>>1]=n;b[c+((m|1)<<1)>>1]=n;b[c+(f<<1)>>1]=n;n=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+3<<1)>>1]=n;b[c+(m+2<<1)>>1]=n;b[c+(f+1<<1)>>1]=n;b[c>>1]=n;n=(p+(g<<1)+h|0)>>>2&65535;b[c+(m+3<<1)>>1]=n;b[c+(f+2<<1)>>1]=n;b[a+2>>1]=n;n=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(f+3<<1)>>1]=n;b[a+4>>1]=n;b[a+6>>1]=(h+2+(i<<1)+j|0)>>>2;return}function Ima(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;p=(d+1+g|0)>>>1&65535;b[c+((m|1)<<1)>>1]=p;b[c>>1]=p;p=(g+1+h|0)>>>1&65535;b[c+(m+2<<1)>>1]=p;b[a+2>>1]=p;p=(h+1+i|0)>>>1&65535;b[c+(m+3<<1)>>1]=p;b[a+4>>1]=p;b[a+6>>1]=(i+1+j|0)>>>1;a=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+1<<1)>>1]=a;b[c+(f<<1)>>1]=a;a=d+2|0;d=(a+(g<<1)+h|0)>>>2&65535;b[c+(o+2<<1)>>1]=d;b[c+(f+1<<1)>>1]=d;d=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(o+3<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;b[c+(f+3<<1)>>1]=(h+2+(i<<1)+j|0)>>>2;b[c+(m<<1)>>1]=(a+(k<<1)+l|0)>>>2;b[c+(o<<1)>>1]=(k+2+(l<<1)+n|0)>>>2;return}function Jma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[a-2>>1]|0;k=e[c+(f-1<<1)>>1]|0;l=f<<1;m=e[c+(l-1<<1)>>1]|0;n=f*3|0;o=e[c+(n-1<<1)>>1]|0;p=(d+1+j|0)>>>1&65535;b[c+(f+2<<1)>>1]=p;b[c>>1]=p;p=((d<<1)+2+g+j|0)>>>2&65535;b[c+(f+3<<1)>>1]=p;b[a+2>>1]=p;p=d+2|0;b[a+4>>1]=(p+(g<<1)+h|0)>>>2;b[a+6>>1]=(g+2+(h<<1)+i|0)>>>2;i=(j+1+k|0)>>>1&65535;b[c+(l+2<<1)>>1]=i;b[c+(f<<1)>>1]=i;i=(p+(j<<1)+k|0)>>>2&65535;b[c+(l+3<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;i=(k+1+m|0)>>>1&65535;b[c+(n+2<<1)>>1]=i;b[c+(l<<1)>>1]=i;i=(j+2+(k<<1)+m|0)>>>2&65535;b[c+(n+3<<1)>>1]=i;b[c+((l|1)<<1)>>1]=i;b[c+(n<<1)>>1]=(m+1+o|0)>>>1;b[c+(n+1<<1)>>1]=(k+2+(m<<1)+o|0)>>>2;return}function Kma(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b+(3-e)|0]|0;j=d[c]|0;k=d[c+1|0]|0;l=d[c+2|0]|0;m=d[c+3|0]|0;a[b]=(f+1+g|0)>>>1;c=(g+1+h|0)>>>1&255;n=e<<1;a[b+n|0]=c;a[b+1|0]=c;c=(h+1+i|0)>>>1&255;a[b+(n|1)|0]=c;a[b+2|0]=c;c=(i+1+j|0)>>>1&255;a[b+(n+2)|0]=c;a[b+3|0]=c;a[b+e|0]=(f+2+(g<<1)+h|0)>>>2;f=(g+2+(h<<1)+i|0)>>>2&255;g=e*3|0;a[b+g|0]=f;a[b+(e+1)|0]=f;f=(h+2+(i<<1)+j|0)>>>2&255;a[b+(g+1)|0]=f;a[b+(e+2)|0]=f;f=(i+2+(j<<1)+k|0)>>>2&255;a[b+(g+2)|0]=f;a[b+(e+3)|0]=f;a[b+(n+3)|0]=(j+2+(k<<1)+l|0)>>>2;a[b+(g+3)|0]=(k+2+(l<<1)+m|0)>>>2;return}function Lma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a;g=d>>1;d=e[f+(-g<<1)>>1]|0;h=e[f+(1-g<<1)>>1]|0;i=e[f+(2-g<<1)>>1]|0;j=e[f+(3-g<<1)>>1]|0;k=e[c>>1]|0;l=e[c+2>>1]|0;m=e[c+4>>1]|0;b[f>>1]=(d+1+h|0)>>>1;c=(h+1+i|0)>>>1&65535;n=g<<1;b[f+(n<<1)>>1]=c;b[a+2>>1]=c;c=(i+1+j|0)>>>1&65535;b[f+((n|1)<<1)>>1]=c;b[a+4>>1]=c;c=(j+1+k|0)>>>1&65535;b[f+(n+2<<1)>>1]=c;b[a+6>>1]=c;b[f+(n+3<<1)>>1]=(k+1+l|0)>>>1;b[f+(g<<1)>>1]=(d+2+(h<<1)+i|0)>>>2;d=(h+2+(i<<1)+j|0)>>>2&65535;h=g*3|0;b[f+(h<<1)>>1]=d;b[f+(g+1<<1)>>1]=d;d=(i+2+(j<<1)+k|0)>>>2&65535;b[f+(h+1<<1)>>1]=d;b[f+(g+2<<1)>>1]=d;d=(j+2+(k<<1)+l|0)>>>2&65535;b[f+(h+2<<1)>>1]=d;b[f+(g+3<<1)>>1]=d;b[f+(h+3<<1)>>1]=(k+2+(l<<1)+m|0)>>>2;return}function Mma(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a;f=d>>1;d=e[a-2>>1]|0;g=e[c+(f-1<<1)>>1]|0;h=f<<1;i=e[c+(h-1<<1)>>1]|0;j=f*3|0;k=b[c+(j-1<<1)>>1]|0;l=k&65535;b[c>>1]=(d+1+g|0)>>>1;b[a+2>>1]=(d+2+(g<<1)+i|0)>>>2;d=(g+1+i|0)>>>1&65535;b[c+(f<<1)>>1]=d;b[a+4>>1]=d;d=(g+2+(i<<1)+l|0)>>>2&65535;b[c+(f+1<<1)>>1]=d;b[a+6>>1]=d;d=(i+1+l|0)>>>1&65535;b[c+(h<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;d=(i+2+l+(l<<1)|0)>>>2&65535;b[c+((h|1)<<1)>>1]=d;b[c+(f+3<<1)>>1]=d;b[c+(j+3<<1)>>1]=k;b[c+(j+2<<1)>>1]=k;b[c+(h+2<<1)>>1]=k;b[c+(j<<1)>>1]=k;b[c+(j+1<<1)>>1]=k;b[c+(h+3<<1)>>1]=k;return}function Nma(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=Erc(((e[a-2>>1]|0)+2+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;i=G;j=a;c[j>>2]=h;c[j+4>>2]=i;j=b+(f<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(d<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(g<<1)|0;c[j>>2]=h;c[j+4>>2]=i;return}function Oma(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;b=a;f=d>>1;d=Erc(((e[b+(-f<<1)>>1]|0)+2+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+((f*3|0)<<1)|0;c[h>>2]=d;c[h+4>>2]=g;return}function Pma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=16777472;c[d+4>>2]=16777472;d=b+(e<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=b+(e<<1<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=b+((e*3|0)<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;return}function Qma(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;c=1024-(d[b+~e|0]|0)|0;f=b+(-e|0)|0;g=b+(1-e)|0;h=b+(2-e)|0;i=b+(3-e)|0;j=(d[b-1|0]|0)+c|0;a[b]=a[1403376+(j+(d[f]|0))|0]|0;a[b+1|0]=a[1403376+((d[g]|0)+j)|0]|0;a[b+2|0]=a[1403376+((d[h]|0)+j)|0]|0;a[b+3|0]=a[1403376+((d[i]|0)+j)|0]|0;j=(d[b+(e-1)|0]|0)+c|0;a[b+e|0]=a[1403376+(j+(d[f]|0))|0]|0;a[b+(e+1)|0]=a[1403376+((d[g]|0)+j)|0]|0;a[b+(e+2)|0]=a[1403376+((d[h]|0)+j)|0]|0;a[b+(e+3)|0]=a[1403376+((d[i]|0)+j)|0]|0;j=e<<1;k=(d[b+(j-1)|0]|0)+c|0;a[b+j|0]=a[1403376+(k+(d[f]|0))|0]|0;a[b+(j|1)|0]=a[1403376+((d[g]|0)+k)|0]|0;a[b+(j+2)|0]=a[1403376+((d[h]|0)+k)|0]|0;a[b+(j+3)|0]=a[1403376+((d[i]|0)+k)|0]|0;k=j+e|0;e=(d[b+(k-1)|0]|0)+c|0;a[b+k|0]=a[1403376+(e+(d[f]|0))|0]|0;a[b+(k+1)|0]=a[1403376+((d[g]|0)+e)|0]|0;a[b+(k+2)|0]=a[1403376+((d[h]|0)+e)|0]|0;a[b+(k+3)|0]=a[1403376+((d[i]|0)+e)|0]|0;return}function Rma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=16711935;c[d+4>>2]=16711935;d=b+(e<<1)|0;c[d>>2]=16711935;c[d+4>>2]=16711935;d=b+(e<<1<<1)|0;c[d>>2]=16711935;c[d+4>>2]=16711935;d=b+((e*3|0)<<1)|0;c[d>>2]=16711935;c[d+4>>2]=16711935;return}function Sma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=16843009;c[d+4>>2]=16843009;d=b+(e<<1)|0;c[d>>2]=16843009;c[d+4>>2]=16843009;d=b+(e<<1<<1)|0;c[d>>2]=16843009;c[d+4>>2]=16843009;d=b+((e*3|0)<<1)|0;c[d>>2]=16843009;c[d+4>>2]=16843009;return}function Tma(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d[b+(1-e)|0]|0;g=d[b+(2-e)|0]|0;h=d[b+(3-e)|0]|0;i=d[c]|0;j=d[c+1|0]|0;k=d[c+2|0]|0;l=d[c+3|0]|0;c=d[b+(e-1)|0]|0;m=e<<1;n=d[b+(m-1)|0]|0;o=e*3|0;p=d[b+(o-1)|0]|0;q=d[b+((e<<2)-1)|0]|0;r=d[b+((e*5|0)-1)|0]|0;s=d[b+((e*6|0)-1)|0]|0;t=d[b+((e*7|0)-1)|0]|0;a[b]=((d[b+(-e|0)|0]|0)+4+g+(d[b-1|0]|0)+n+(c+f<<1)|0)>>>3;u=(f+4+h+c+p+(n+g<<1)|0)>>>3&255;a[b+e|0]=u;a[b+1|0]=u;u=(g+4+i+n+q+(p+h<<1)|0)>>>3&255;a[b+m|0]=u;a[b+(e+1)|0]=u;a[b+2|0]=u;u=(h+4+j+p+r+(q+i<<1)|0)>>>3&255;a[b+o|0]=u;a[b+(m|1)|0]=u;a[b+(e+2)|0]=u;a[b+3|0]=u;u=(i+4+k+q+s+(r+j<<1)|0)>>>3&255;a[b+(o+1)|0]=u;a[b+(m+2)|0]=u;a[b+(e+3)|0]=u;u=(j+4+l+r+t+(s+k<<1)|0)>>>3&255;a[b+(o+2)|0]=u;a[b+(m+3)|0]=u;a[b+(o+3)|0]=(k+2+l+s+t|0)>>>2;return}function Uma(b,c,e){b=b|0;c=c|0;e=e|0;mta(b,a[c]|0,a[c+1|0]|0,a[c+2|0]|0,e,d[b+(e-1)|0]|0,d[b+((e<<1)-1)|0]|0,d[b+((e*3|0)-1)|0]|0,d[b+((e<<2)-1)|0]|0);return}function Vma(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d[b-1|0]|0;g=d[b+(e-1)|0]|0;h=e<<1;i=d[b+(h-1)|0]|0;j=e*3|0;k=d[b+(j-1)|0]|0;l=d[b+((e<<2)-1)|0]|0;m=d[b+((e*5|0)-1)|0]|0;n=d[b+((e*6|0)-1)|0]|0;o=d[b+(2-e)|0]|0;p=d[b+(3-e)|0]|0;q=d[c]|0;r=d[c+1|0]|0;s=d[c+2|0]|0;t=d[c+3|0]|0;c=g<<1;u=c+4|0;a[b]=(u+(d[b+(1-e)|0]|0)+p+(o+f<<1)|0)>>>3;a[b+1|0]=(f+4+c+i+o+(p<<1)+q|0)>>>3;o=i<<1;c=(u+o+p+(q<<1)+r|0)>>>3&255;a[b+e|0]=c;a[b+2|0]=c;c=(g+4+o+k+q+(r<<1)+s|0)>>>3&255;a[b+(e+1)|0]=c;a[b+3|0]=c;c=(o+4+r+t+(s+k<<1)|0)>>>3&255;a[b+h|0]=c;a[b+(e+2)|0]=c;c=(i+4+s+((t+k|0)*3|0)|0)>>>3&255;a[b+(h|1)|0]=c;a[b+(e+3)|0]=c;c=k+2|0;k=(c+(l<<1)+m|0)>>>2&255;a[b+(j+1)|0]=k;a[b+(h+3)|0]=k;k=(c+l+s+t|0)>>>2&255;a[b+(h+2)|0]=k;a[b+j|0]=k;a[b+(j+2)|0]=(l+1+m|0)>>>1;a[b+(j+3)|0]=(l+2+(m<<1)+n|0)>>>2;return}function Wma(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d[b+(1-e)|0]|0;g=d[b+(2-e)|0]|0;h=d[b+(3-e)|0]|0;i=d[c]|0;j=d[c+1|0]|0;k=d[c+2|0]|0;l=d[c+3|0]|0;c=d[b+(e-1)|0]|0;m=e<<1;n=d[b+(m-1)|0]|0;o=e*3|0;p=d[b+(o-1)|0]|0;a[b]=((d[b+(-e|0)|0]|0)+4+g+(d[b-1|0]|0)+n+(c+f<<1)|0)>>>3;q=(f+4+h+c+p+(n+g<<1)|0)>>>3&255;a[b+e|0]=q;a[b+1|0]=q;q=(g+4+i+(h<<1)+n+(p*3|0)|0)>>>3&255;a[b+m|0]=q;a[b+(e+1)|0]=q;a[b+2|0]=q;q=p<<2;n=(h+4+j+(i<<1)+q|0)>>>3&255;a[b+o|0]=n;a[b+(m|1)|0]=n;a[b+(e+2)|0]=n;a[b+3|0]=n;n=(i+4+k+(j<<1)+q|0)>>>3&255;a[b+(o+1)|0]=n;a[b+(m+2)|0]=n;a[b+(e+3)|0]=n;n=(j+4+l+(k<<1)+q|0)>>>3&255;a[b+(o+2)|0]=n;a[b+(m+3)|0]=n;a[b+(o+3)|0]=(k+2+l+(p<<1)|0)>>>2;return}function Xma(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d[b-1|0]|0;g=d[b+(e-1)|0]|0;h=e<<1;i=d[b+(h-1)|0]|0;j=e*3|0;k=a[b+(j-1)|0]|0;l=k&255;m=d[b+(2-e)|0]|0;n=d[b+(3-e)|0]|0;o=d[c]|0;p=d[c+1|0]|0;q=d[c+2|0]|0;r=d[c+3|0]|0;c=g<<1;s=c+4|0;a[b]=(s+(d[b+(1-e)|0]|0)+n+(m+f<<1)|0)>>>3;a[b+1|0]=(f+4+c+i+m+(n<<1)+o|0)>>>3;m=i<<1;c=(s+m+n+(o<<1)+p|0)>>>3&255;a[b+e|0]=c;a[b+2|0]=c;c=(g+4+m+l+o+(p<<1)+q|0)>>>3&255;a[b+(e+1)|0]=c;a[b+3|0]=c;c=l<<1;o=(m+4+c+p+(q<<1)+r|0)>>>3&255;a[b+h|0]=o;a[b+(e+2)|0]=o;o=(i+4+q+((r+l|0)*3|0)|0)>>>3&255;a[b+(h|1)|0]=o;a[b+(e+3)|0]=o;a[b+(j+1)|0]=k;a[b+(h+3)|0]=k;o=(c+2+q+r|0)>>>2&255;a[b+(h+2)|0]=o;a[b+j|0]=o;a[b+(j+3)|0]=k;a[b+(j+2)|0]=k;return}function Yma(b,c,e){b=b|0;c=c|0;e=e|0;var f=0;f=d[b+((e*3|0)-1)|0]|0;mta(b,a[c]|0,a[c+1|0]|0,a[c+2|0]|0,e,d[b+(e-1)|0]|0,d[b+((e<<1)-1)|0]|0,f,f);return}function Zma(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}b[h>>1]=((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;b[a+2>>1]=(j+2+(k<<1)+l|0)>>>2;b[a+4>>1]=(k+2+(l<<1)+m|0)>>>2;b[a+6>>1]=(l+2+(m<<1)+n|0)>>>2;l=a+8|0;b[l>>1]=(m+2+(n<<1)+o|0)>>>2;b[a+10>>1]=(n+2+(o<<1)+p|0)>>>2;b[a+12>>1]=(o+2+(p<<1)+r|0)>>>2;b[a+14>>1]=((s&65535)+2+(r<<1)+p|0)>>>2;p=a;a=c[p>>2]|0;r=c[p+4>>2]|0;p=l;l=c[p>>2]|0;s=c[p+4>>2]|0;p=h+(i<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(i+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<1;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*3|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<2;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*5|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i*6|0;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*7|0;i=h+(o<<1)|0;c[i>>2]=a;c[i+4>>2]=r;r=h+(o+4<<1)|0;c[r>>2]=l;c[r+4>>2]=s;return}function _ma(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=g<<1;j=e[d+(f-1<<1)>>1]|0;k=g*3|0;l=e[d+(k-1<<1)>>1]|0;m=g<<2;n=e[d+(m-1<<1)>>1]|0;o=g*5|0;p=e[d+(o-1<<1)>>1]|0;q=g*6|0;r=e[d+(q-1<<1)>>1]|0;s=g*7|0;t=e[d+(s-1<<1)>>1]|0;u=Erc(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2,0,65537,65537)|0;h=G;v=a;c[v>>2]=u;c[v+4>>2]=h;v=a+8|0;c[v>>2]=u;c[v+4>>2]=h;h=Erc((b+2+(i<<1)+j|0)>>>2,0,65537,65537)|0;b=G;v=d+(g<<1)|0;c[v>>2]=h;c[v+4>>2]=b;v=d+(g+4<<1)|0;c[v>>2]=h;c[v+4>>2]=b;b=Erc((i+2+(j<<1)+l|0)>>>2,0,65537,65537)|0;i=G;v=d+(f<<1)|0;c[v>>2]=b;c[v+4>>2]=i;v=d+(f+4<<1)|0;c[v>>2]=b;c[v+4>>2]=i;i=Erc((j+2+(l<<1)+n|0)>>>2,0,65537,65537)|0;j=G;v=d+(k<<1)|0;c[v>>2]=i;c[v+4>>2]=j;v=d+(k+4<<1)|0;c[v>>2]=i;c[v+4>>2]=j;j=Erc((l+2+(n<<1)+p|0)>>>2,0,65537,65537)|0;l=G;v=d+(m<<1)|0;c[v>>2]=j;c[v+4>>2]=l;v=d+(m+4<<1)|0;c[v>>2]=j;c[v+4>>2]=l;l=Erc((n+2+(p<<1)+r|0)>>>2,0,65537,65537)|0;n=G;v=d+(o<<1)|0;c[v>>2]=l;c[v+4>>2]=n;v=d+(o+4<<1)|0;c[v>>2]=l;c[v+4>>2]=n;n=Erc((p+2+(r<<1)+t|0)>>>2,0,65537,65537)|0;p=G;v=d+(q<<1)|0;c[v>>2]=n;c[v+4>>2]=p;v=d+(q+4<<1)|0;c[v>>2]=n;c[v+4>>2]=p;p=Erc((r+2+(t*3|0)|0)>>>2,0,65537,65537)|0;t=G;r=d+(s<<1)|0;c[r>>2]=p;c[r+4>>2]=t;r=d+(s+4<<1)|0;c[r>>2]=p;c[r+4>>2]=t;return}function $ma(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=g>>1;g=(d|0)!=0;if(g){d=~i;j=h+(d<<1)|0;k=a-2|0;l=d}else{d=a-2|0;j=d;k=d;l=~i}d=e[k>>1]|0;k=e[h+(i-1<<1)>>1]|0;m=e[h+((i<<1)-1<<1)>>1]|0;n=e[h+((i*3|0)-1<<1)>>1]|0;o=e[h+((i<<2)-1<<1)>>1]|0;p=e[h+((i*5|0)-1<<1)>>1]|0;q=e[h+((i*6|0)-1<<1)>>1]|0;r=e[h+((i*7|0)-1<<1)>>1]|0;s=-i|0;t=e[h+(s<<1)>>1]|0;u=e[h+(1-i<<1)>>1]|0;v=e[h+(2-i<<1)>>1]|0;w=e[h+(3-i<<1)>>1]|0;x=e[h+(4-i<<1)>>1]|0;y=e[h+(5-i<<1)>>1]|0;z=e[h+(6-i<<1)>>1]|0;A=b[h+(7-i<<1)>>1]|0;B=A&65535;if((f|0)==0){C=A}else{C=b[h+(8-i<<1)>>1]|0}A=(((e[j>>1]|0)+2+(d<<1)+k|0)>>>2)+8+((d+2+(k<<1)+m|0)>>>2)+((k+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q<<1)+r|0)>>>2)+((q+2+(r*3|0)|0)>>>2)+(((e[h+((g?l:s)<<1)>>1]|0)+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+z|0)>>>2)+((y+2+(z<<1)+B|0)>>>2)+(((C&65535)+2+(B<<1)+z|0)>>>2)>>4;z=Erc(A,(A|0)<0|0?-1:0,65537,65537)|0;A=G;B=a;c[B>>2]=z;c[B+4>>2]=A;B=a+8|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=i<<1;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;i=h+(a<<1)|0;c[i>>2]=z;c[i+4>>2]=A;i=h+(a+4<<1)|0;c[i>>2]=z;c[i+4>>2]=A;return}function ana(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=e[g+(2-h<<1)>>1]|0;l=(i+2+(j<<1)+k|0)>>>2;m=e[g+(3-h<<1)>>1]|0;n=(j+2+(k<<1)+m|0)>>>2;o=e[g+(4-h<<1)>>1]|0;p=(k+2+(m<<1)+o|0)>>>2;k=e[g+(5-h<<1)>>1]|0;q=(m+2+(o<<1)+k|0)>>>2;m=e[g+(6-h<<1)>>1]|0;r=(o+2+(k<<1)+m|0)>>>2;o=b[g+(7-h<<1)>>1]|0;s=o&65535;t=(k+2+(m<<1)+s|0)>>>2;if((d|0)==0){u=s;v=s;w=s;x=s;y=s;z=s;A=s;B=s;C=(o&65535)+2+(s<<1)|0}else{o=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;k=e[g+(10-h<<1)>>1]|0;D=e[g+(11-h<<1)>>1]|0;E=e[g+(12-h<<1)>>1]|0;F=e[g+(13-h<<1)>>1]|0;G=e[g+(14-h<<1)>>1]|0;H=e[g+(15-h<<1)>>1]|0;u=(G+2+(H*3|0)|0)>>>2;v=(F+2+(G<<1)+H|0)>>>2;w=(E+2+(F<<1)+G|0)>>>2;x=(D+2+(E<<1)+F|0)>>>2;y=(k+2+(D<<1)+E|0)>>>2;z=(d+2+(k<<1)+D|0)>>>2;A=(o+2+(d<<1)+k|0)>>>2;B=(s+2+(o<<1)+d|0)>>>2;C=(e[g+(8-h<<1)>>1]|0)+2+(s<<1)|0}s=(C+m|0)>>>2;b[g>>1]=((((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2)+2+(l<<1)+n|0)>>>2;j=(l+2+(n<<1)+p|0)>>>2&65535;b[a+2>>1]=j;b[g+(h<<1)>>1]=j;j=(n+2+(p<<1)+q|0)>>>2&65535;b[a+4>>1]=j;b[g+(h+1<<1)>>1]=j;n=h<<1;b[g+(n<<1)>>1]=j;j=(p+2+(q<<1)+r|0)>>>2&65535;b[a+6>>1]=j;b[g+(h+2<<1)>>1]=j;b[g+((n|1)<<1)>>1]=j;p=h*3|0;b[g+(p<<1)>>1]=j;j=(q+2+(r<<1)+t|0)>>>2&65535;b[a+8>>1]=j;b[g+(h+3<<1)>>1]=j;b[g+(n+2<<1)>>1]=j;b[g+(p+1<<1)>>1]=j;q=h<<2;b[g+(q<<1)>>1]=j;j=(r+2+(t<<1)+s|0)>>>2&65535;b[a+10>>1]=j;b[g+(h+4<<1)>>1]=j;b[g+(n+3<<1)>>1]=j;b[g+(p+2<<1)>>1]=j;b[g+((q|1)<<1)>>1]=j;r=h*5|0;b[g+(r<<1)>>1]=j;j=(t+2+(s<<1)+B|0)>>>2&65535;b[a+12>>1]=j;b[g+(h+5<<1)>>1]=j;b[g+(n+4<<1)>>1]=j;b[g+(p+3<<1)>>1]=j;b[g+((q|2)<<1)>>1]=j;b[g+(r+1<<1)>>1]=j;t=h*6|0;b[g+(t<<1)>>1]=j;j=(s+2+(B<<1)+A|0)>>>2&65535;b[a+14>>1]=j;b[g+(h+6<<1)>>1]=j;b[g+(n+5<<1)>>1]=j;b[g+(p+4<<1)>>1]=j;b[g+((q|3)<<1)>>1]=j;b[g+(r+2<<1)>>1]=j;b[g+((t|1)<<1)>>1]=j;a=h*7|0;b[g+(a<<1)>>1]=j;j=(B+2+(A<<1)+z|0)>>>2&65535;b[g+(h+7<<1)>>1]=j;b[g+(n+6<<1)>>1]=j;b[g+(p+5<<1)>>1]=j;b[g+(q+4<<1)>>1]=j;b[g+(r+3<<1)>>1]=j;b[g+(t+2<<1)>>1]=j;b[g+(a+1<<1)>>1]=j;j=(A+2+(z<<1)+y|0)>>>2&65535;b[g+(n+7<<1)>>1]=j;b[g+(p+6<<1)>>1]=j;b[g+(q+5<<1)>>1]=j;b[g+(r+4<<1)>>1]=j;b[g+(t+3<<1)>>1]=j;b[g+(a+2<<1)>>1]=j;j=(z+2+(y<<1)+x|0)>>>2&65535;b[g+(p+7<<1)>>1]=j;b[g+(q+6<<1)>>1]=j;b[g+(r+5<<1)>>1]=j;b[g+(t+4<<1)>>1]=j;b[g+(a+3<<1)>>1]=j;j=(y+2+(x<<1)+w|0)>>>2&65535;b[g+(q+7<<1)>>1]=j;b[g+(r+6<<1)>>1]=j;b[g+(t+5<<1)>>1]=j;b[g+(a+4<<1)>>1]=j;j=(x+2+(w<<1)+v|0)>>>2&65535;b[g+(r+7<<1)>>1]=j;b[g+(t+6<<1)>>1]=j;b[g+(a+5<<1)>>1]=j;j=(w+2+(v<<1)+u|0)>>>2&65535;b[g+(t+7<<1)>>1]=j;b[g+(a+6<<1)>>1]=j;b[g+(a+7<<1)>>1]=(v+2+(u*3|0)|0)>>>2;return}function bna(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;k=e[g+(v-1<<1)>>1]|0;d=i+2|0;i=(d+(w<<1)+k|0)>>>2;c=h*3|0;y=e[g+(c-1<<1)>>1]|0;z=(w+2+(k<<1)+y|0)>>>2;w=h<<2;A=e[g+(w-1<<1)>>1]|0;B=(k+2+(y<<1)+A|0)>>>2;k=h*5|0;C=e[g+(k-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*6|0;E=e[g+(y-1<<1)>>1]|0;F=(A+2+(C<<1)+E|0)>>>2;A=h*7|0;G=e[g+(A-1<<1)>>1]|0;H=(C+2+(E<<1)+G|0)>>>2;C=(d+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(A<<1)>>1]=(F+2+((E+2+(G*3|0)|0)>>>2)+(H<<1)|0)>>>2;G=(D+2+(F<<1)+H|0)>>>2&65535;b[g+(A+1<<1)>>1]=G;b[g+(y<<1)>>1]=G;G=(B+2+(D<<1)+F|0)>>>2&65535;b[g+(A+2<<1)>>1]=G;b[g+((y|1)<<1)>>1]=G;b[g+(k<<1)>>1]=G;G=(z+2+(B<<1)+D|0)>>>2&65535;b[g+(A+3<<1)>>1]=G;b[g+(y+2<<1)>>1]=G;b[g+(k+1<<1)>>1]=G;b[g+(w<<1)>>1]=G;G=(i+2+(z<<1)+B|0)>>>2&65535;b[g+(A+4<<1)>>1]=G;b[g+(y+3<<1)>>1]=G;b[g+(k+2<<1)>>1]=G;b[g+((w|1)<<1)>>1]=G;b[g+(c<<1)>>1]=G;G=(f+2+(i<<1)+z|0)>>>2&65535;b[g+(A+5<<1)>>1]=G;b[g+(y+4<<1)>>1]=G;b[g+(k+3<<1)>>1]=G;b[g+((w|2)<<1)>>1]=G;b[g+(c+1<<1)>>1]=G;b[g+(v<<1)>>1]=G;G=((f<<1)+2+i+C|0)>>>2&65535;b[g+(A+6<<1)>>1]=G;b[g+(y+5<<1)>>1]=G;b[g+(k+4<<1)>>1]=G;b[g+((w|3)<<1)>>1]=G;b[g+(c+2<<1)>>1]=G;b[g+((v|1)<<1)>>1]=G;b[g+(h<<1)>>1]=G;G=l+2|0;i=(G+f+(C<<1)|0)>>>2&65535;b[g+(A+7<<1)>>1]=i;b[g+(y+6<<1)>>1]=i;b[g+(k+5<<1)>>1]=i;b[g+(w+4<<1)>>1]=i;b[g+(c+3<<1)>>1]=i;b[g+(v+2<<1)>>1]=i;b[g+(h+1<<1)>>1]=i;b[g>>1]=i;i=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+7<<1)>>1]=i;b[g+(k+6<<1)>>1]=i;b[g+(w+5<<1)>>1]=i;b[g+(c+4<<1)>>1]=i;b[g+(v+3<<1)>>1]=i;b[g+(h+2<<1)>>1]=i;b[a+2>>1]=i;i=(G+(m<<1)+o|0)>>>2&65535;b[g+(k+7<<1)>>1]=i;b[g+(w+6<<1)>>1]=i;b[g+(c+5<<1)>>1]=i;b[g+(v+4<<1)>>1]=i;b[g+(h+3<<1)>>1]=i;b[a+4>>1]=i;i=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(w+7<<1)>>1]=i;b[g+(c+6<<1)>>1]=i;b[g+(v+5<<1)>>1]=i;b[g+(h+4<<1)>>1]=i;b[a+6>>1]=i;i=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(c+7<<1)>>1]=i;b[g+(v+6<<1)>>1]=i;b[g+(h+5<<1)>>1]=i;b[a+8>>1]=i;i=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(v+7<<1)>>1]=i;b[g+(h+6<<1)>>1]=i;b[a+10>>1]=i;i=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(h+7<<1)>>1]=i;b[a+12>>1]=i;b[a+14>>1]=(r+2+(t<<1)+(((u&65535)+2+(s<<1)+n|0)>>>2)|0)>>>2;return}function cna(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}k=((u&65535)+2+(s<<1)+n|0)>>>2;if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;n=e[g+(v-1<<1)>>1]|0;s=i+2|0;i=(s+(w<<1)+n|0)>>>2;u=h*3|0;d=e[g+(u-1<<1)>>1]|0;c=(w+2+(n<<1)+d|0)>>>2;w=h<<2;y=e[g+(w-1<<1)>>1]|0;z=(n+2+(d<<1)+y|0)>>>2;n=h*5|0;A=e[g+(n-1<<1)>>1]|0;B=(d+2+(y<<1)+A|0)>>>2;d=h*6|0;C=e[g+(d-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*7|0;E=(A+2+(C<<1)+(e[g+(y-1<<1)>>1]|0)|0)>>>2;C=(s+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(d<<1)>>1]=(z+2+(B<<1)+D|0)>>>2;b[g+(y<<1)>>1]=(B+2+(D<<1)+E|0)>>>2;E=(i+2+(c<<1)+z|0)>>>2&65535;b[g+((d|1)<<1)>>1]=E;b[g+(w<<1)>>1]=E;E=(c+2+(z<<1)+B|0)>>>2&65535;b[g+(y+1<<1)>>1]=E;b[g+(n<<1)>>1]=E;E=((f<<1)+2+i+C|0)>>>2&65535;b[g+(d+2<<1)>>1]=E;b[g+((w|1)<<1)>>1]=E;b[g+(v<<1)>>1]=E;E=(f+2+(i<<1)+c|0)>>>2&65535;b[g+(y+2<<1)>>1]=E;b[g+(n+1<<1)>>1]=E;b[g+(u<<1)>>1]=E;E=l+2|0;c=(E+f+(C<<1)|0)>>>2&65535;b[g+(y+3<<1)>>1]=c;b[g+(n+2<<1)>>1]=c;b[g+(u+1<<1)>>1]=c;b[g+(h<<1)>>1]=c;c=l+1|0;f=(c+C|0)>>>1&65535;b[g+(d+3<<1)>>1]=f;b[g+((w|2)<<1)>>1]=f;b[g+((v|1)<<1)>>1]=f;b[g>>1]=f;f=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+4<<1)>>1]=f;b[g+(n+3<<1)>>1]=f;b[g+(u+2<<1)>>1]=f;b[g+(h+1<<1)>>1]=f;f=(c+m|0)>>>1&65535;b[g+(d+4<<1)>>1]=f;b[g+((w|3)<<1)>>1]=f;b[g+(v+2<<1)>>1]=f;b[a+2>>1]=f;f=(E+(m<<1)+o|0)>>>2&65535;b[g+(y+5<<1)>>1]=f;b[g+(n+4<<1)>>1]=f;b[g+(u+3<<1)>>1]=f;b[g+(h+2<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[g+(d+5<<1)>>1]=f;b[g+(w+4<<1)>>1]=f;b[g+(v+3<<1)>>1]=f;b[a+4>>1]=f;f=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(y+6<<1)>>1]=f;b[g+(n+5<<1)>>1]=f;b[g+(u+4<<1)>>1]=f;b[g+(h+3<<1)>>1]=f;f=(o+1+p|0)>>>1&65535;b[g+(d+6<<1)>>1]=f;b[g+(w+5<<1)>>1]=f;b[g+(v+4<<1)>>1]=f;b[a+6>>1]=f;f=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(y+7<<1)>>1]=f;b[g+(n+6<<1)>>1]=f;b[g+(u+5<<1)>>1]=f;b[g+(h+4<<1)>>1]=f;f=(p+1+q|0)>>>1&65535;b[g+(d+7<<1)>>1]=f;b[g+(w+6<<1)>>1]=f;b[g+(v+5<<1)>>1]=f;b[a+8>>1]=f;f=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(n+7<<1)>>1]=f;b[g+(u+6<<1)>>1]=f;b[g+(h+5<<1)>>1]=f;f=(q+1+r|0)>>>1&65535;b[g+(w+7<<1)>>1]=f;b[g+(v+6<<1)>>1]=f;b[a+10>>1]=f;f=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(u+7<<1)>>1]=f;b[g+(h+6<<1)>>1]=f;f=(r+1+t|0)>>>1&65535;b[g+(v+7<<1)>>1]=f;b[a+12>>1]=f;b[g+(h+7<<1)>>1]=(r+2+(t<<1)+k|0)>>>2;b[a+14>>1]=(t+1+k|0)>>>1;return}function dna(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=a;g=f>>1;f=(c|0)!=0;c=-g|0;h=~g;i=e[d+(c<<1)>>1]|0;j=e[d+(1-g<<1)>>1]|0;k=((e[d+((f?h:c)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;c=e[d+(2-g<<1)>>1]|0;l=(i+2+(j<<1)+c|0)>>>2;m=e[d+(3-g<<1)>>1]|0;n=(j+2+(c<<1)+m|0)>>>2;j=e[d+(4-g<<1)>>1]|0;o=(c+2+(m<<1)+j|0)>>>2;c=e[d+(5-g<<1)>>1]|0;p=(m+2+(j<<1)+c|0)>>>2;m=e[d+(6-g<<1)>>1]|0;q=(j+2+(c<<1)+m|0)>>>2;j=(c+2+(m<<1)+(e[d+(7-g<<1)>>1]|0)|0)>>>2;if(f){f=d+(h<<1)|0;r=f;s=a-2|0;t=f}else{f=a-2|0;r=f;s=f;t=d+(h<<1)|0}h=e[s>>1]|0;s=e[d+(g-1<<1)>>1]|0;f=((e[r>>1]|0)+2+(h<<1)+s|0)>>>2;r=g<<1;m=e[d+(r-1<<1)>>1]|0;c=h+2|0;h=(c+(s<<1)+m|0)>>>2;u=g*3|0;v=e[d+(u-1<<1)>>1]|0;w=(s+2+(m<<1)+v|0)>>>2;s=g<<2;x=e[d+(s-1<<1)>>1]|0;y=(m+2+(v<<1)+x|0)>>>2;m=g*5|0;z=e[d+(m-1<<1)>>1]|0;A=(v+2+(x<<1)+z|0)>>>2;v=g*6|0;B=e[d+(v-1<<1)>>1]|0;C=(x+2+(z<<1)+B|0)>>>2;x=g*7|0;D=e[d+(x-1<<1)>>1]|0;E=(z+2+(B<<1)+D|0)>>>2;z=(B+2+(D*3|0)|0)>>>2;D=(c+((e[t>>1]|0)<<1)+i|0)>>>2;b[d+(x<<1)>>1]=(z+1+E|0)>>>1;b[d+(x+1<<1)>>1]=(C+2+z+(E<<1)|0)>>>2;z=(C+1+E|0)>>>1&65535;b[d+(x+2<<1)>>1]=z;b[d+(v<<1)>>1]=z;z=(A+2+(C<<1)+E|0)>>>2&65535;b[d+(x+3<<1)>>1]=z;b[d+((v|1)<<1)>>1]=z;z=(A+1+C|0)>>>1&65535;b[d+(x+4<<1)>>1]=z;b[d+(v+2<<1)>>1]=z;b[d+(m<<1)>>1]=z;z=(y+2+(A<<1)+C|0)>>>2&65535;b[d+(x+5<<1)>>1]=z;b[d+(v+3<<1)>>1]=z;b[d+(m+1<<1)>>1]=z;z=(y+1+A|0)>>>1&65535;b[d+(x+6<<1)>>1]=z;b[d+(v+4<<1)>>1]=z;b[d+(m+2<<1)>>1]=z;b[d+(s<<1)>>1]=z;z=(w+2+(y<<1)+A|0)>>>2&65535;b[d+(x+7<<1)>>1]=z;b[d+(v+5<<1)>>1]=z;b[d+(m+3<<1)>>1]=z;b[d+((s|1)<<1)>>1]=z;z=(w+1+y|0)>>>1&65535;b[d+(v+6<<1)>>1]=z;b[d+(m+4<<1)>>1]=z;b[d+((s|2)<<1)>>1]=z;b[d+(u<<1)>>1]=z;z=(h+2+(w<<1)+y|0)>>>2&65535;b[d+(v+7<<1)>>1]=z;b[d+(m+5<<1)>>1]=z;b[d+((s|3)<<1)>>1]=z;b[d+(u+1<<1)>>1]=z;z=(h+1+w|0)>>>1&65535;b[d+(m+6<<1)>>1]=z;b[d+(s+4<<1)>>1]=z;b[d+(u+2<<1)>>1]=z;b[d+(r<<1)>>1]=z;z=(f+2+(h<<1)+w|0)>>>2&65535;b[d+(m+7<<1)>>1]=z;b[d+(s+5<<1)>>1]=z;b[d+(u+3<<1)>>1]=z;b[d+((r|1)<<1)>>1]=z;z=f+1|0;m=(z+h|0)>>>1&65535;b[d+(s+6<<1)>>1]=m;b[d+(u+4<<1)>>1]=m;b[d+(r+2<<1)>>1]=m;b[d+(g<<1)>>1]=m;m=((f<<1)+2+h+D|0)>>>2&65535;b[d+(s+7<<1)>>1]=m;b[d+(u+5<<1)>>1]=m;b[d+(r+3<<1)>>1]=m;b[d+(g+1<<1)>>1]=m;m=(z+D|0)>>>1&65535;b[d+(u+6<<1)>>1]=m;b[d+(r+4<<1)>>1]=m;b[d+(g+2<<1)>>1]=m;b[d>>1]=m;m=k+2|0;z=(m+f+(D<<1)|0)>>>2&65535;b[d+(u+7<<1)>>1]=z;b[d+(r+5<<1)>>1]=z;b[d+(g+3<<1)>>1]=z;b[a+2>>1]=z;z=((k<<1)+2+l+D|0)>>>2&65535;b[d+(r+6<<1)>>1]=z;b[d+(g+4<<1)>>1]=z;b[a+4>>1]=z;z=(m+(l<<1)+n|0)>>>2&65535;b[d+(r+7<<1)>>1]=z;b[d+(g+5<<1)>>1]=z;b[a+6>>1]=z;z=(l+2+(n<<1)+o|0)>>>2&65535;b[d+(g+6<<1)>>1]=z;b[a+8>>1]=z;z=(n+2+(o<<1)+p|0)>>>2&65535;b[d+(g+7<<1)>>1]=z;b[a+10>>1]=z;b[a+12>>1]=(o+2+(p<<1)+q|0)>>>2;b[a+14>>1]=(p+2+(q<<1)+j|0)>>>2;return}function ena(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;f=e[g+(2-h<<1)>>1]|0;c=(i+2+(j<<1)+f|0)>>>2;i=e[g+(3-h<<1)>>1]|0;l=(j+2+(f<<1)+i|0)>>>2;j=e[g+(4-h<<1)>>1]|0;m=(f+2+(i<<1)+j|0)>>>2;f=e[g+(5-h<<1)>>1]|0;n=(i+2+(j<<1)+f|0)>>>2;i=e[g+(6-h<<1)>>1]|0;o=(j+2+(f<<1)+i|0)>>>2;j=b[g+(7-h<<1)>>1]|0;p=j&65535;q=(f+2+(i<<1)+p|0)>>>2;if((d|0)==0){r=p;s=p;t=p;u=p;v=p;w=(j&65535)+2+(p<<1)|0}else{j=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;f=e[g+(10-h<<1)>>1]|0;x=e[g+(11-h<<1)>>1]|0;y=e[g+(12-h<<1)>>1]|0;r=(x+2+(y<<1)+(e[g+(13-h<<1)>>1]|0)|0)>>>2;s=(f+2+(x<<1)+y|0)>>>2;t=(d+2+(f<<1)+x|0)>>>2;u=(j+2+(d<<1)+f|0)>>>2;v=(p+2+(j<<1)+d|0)>>>2;w=(e[g+(8-h<<1)>>1]|0)+2+(p<<1)|0}p=(w+i|0)>>>2;b[g>>1]=(k+1+c|0)>>>1;b[g+(h<<1)>>1]=(k+2+(c<<1)+l|0)>>>2;k=(c+1+l|0)>>>1&65535;b[a+2>>1]=k;i=h<<1;b[g+(i<<1)>>1]=k;k=(c+2+(l<<1)+m|0)>>>2&65535;b[g+(h+1<<1)>>1]=k;c=h*3|0;b[g+(c<<1)>>1]=k;k=(l+1+m|0)>>>1&65535;b[a+4>>1]=k;b[g+((i|1)<<1)>>1]=k;w=h<<2;b[g+(w<<1)>>1]=k;k=(l+2+(m<<1)+n|0)>>>2&65535;b[g+(h+2<<1)>>1]=k;b[g+(c+1<<1)>>1]=k;l=h*5|0;b[g+(l<<1)>>1]=k;k=(m+1+n|0)>>>1&65535;b[a+6>>1]=k;b[g+(i+2<<1)>>1]=k;b[g+((w|1)<<1)>>1]=k;d=h*6|0;b[g+(d<<1)>>1]=k;k=(m+2+(n<<1)+o|0)>>>2&65535;b[g+(h+3<<1)>>1]=k;b[g+(c+2<<1)>>1]=k;b[g+(l+1<<1)>>1]=k;m=h*7|0;b[g+(m<<1)>>1]=k;k=(n+1+o|0)>>>1&65535;b[a+8>>1]=k;b[g+(i+3<<1)>>1]=k;b[g+((w|2)<<1)>>1]=k;b[g+((d|1)<<1)>>1]=k;k=(n+2+(o<<1)+q|0)>>>2&65535;b[g+(h+4<<1)>>1]=k;b[g+(c+3<<1)>>1]=k;b[g+(l+2<<1)>>1]=k;b[g+(m+1<<1)>>1]=k;k=(o+1+q|0)>>>1&65535;b[a+10>>1]=k;b[g+(i+4<<1)>>1]=k;b[g+((w|3)<<1)>>1]=k;b[g+(d+2<<1)>>1]=k;k=(o+2+(q<<1)+p|0)>>>2&65535;b[g+(h+5<<1)>>1]=k;b[g+(c+4<<1)>>1]=k;b[g+(l+3<<1)>>1]=k;b[g+(m+2<<1)>>1]=k;k=(q+1+p|0)>>>1&65535;b[a+12>>1]=k;b[g+(i+5<<1)>>1]=k;b[g+(w+4<<1)>>1]=k;b[g+(d+3<<1)>>1]=k;k=(q+2+(p<<1)+v|0)>>>2&65535;b[g+(h+6<<1)>>1]=k;b[g+(c+5<<1)>>1]=k;b[g+(l+4<<1)>>1]=k;b[g+(m+3<<1)>>1]=k;k=(p+1+v|0)>>>1&65535;b[a+14>>1]=k;b[g+(i+6<<1)>>1]=k;b[g+(w+5<<1)>>1]=k;b[g+(d+4<<1)>>1]=k;k=(p+2+(v<<1)+u|0)>>>2&65535;b[g+(h+7<<1)>>1]=k;b[g+(c+6<<1)>>1]=k;b[g+(l+5<<1)>>1]=k;b[g+(m+4<<1)>>1]=k;k=(v+1+u|0)>>>1&65535;b[g+(i+7<<1)>>1]=k;b[g+(w+6<<1)>>1]=k;b[g+(d+5<<1)>>1]=k;k=(v+2+(u<<1)+t|0)>>>2&65535;b[g+(c+7<<1)>>1]=k;b[g+(l+6<<1)>>1]=k;b[g+(m+5<<1)>>1]=k;k=(u+1+t|0)>>>1&65535;b[g+(w+7<<1)>>1]=k;b[g+(d+6<<1)>>1]=k;k=(u+2+(t<<1)+s|0)>>>2&65535;b[g+(l+7<<1)>>1]=k;b[g+(m+6<<1)>>1]=k;b[g+(d+7<<1)>>1]=(t+1+s|0)>>>1;b[g+(m+7<<1)>>1]=(t+2+(s<<1)+r|0)>>>2;return}function fna(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a;g=f>>1;if((c|0)==0){c=a-2|0;h=c;i=c}else{h=d+(~g<<1)|0;i=a-2|0}c=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=((e[h>>1]|0)+2+(c<<1)+i|0)>>>2;h=g<<1;j=e[d+(h-1<<1)>>1]|0;k=(c+2+(i<<1)+j|0)>>>2;c=g*3|0;l=e[d+(c-1<<1)>>1]|0;m=(i+2+(j<<1)+l|0)>>>2;i=g<<2;n=e[d+(i-1<<1)>>1]|0;o=(j+2+(l<<1)+n|0)>>>2;j=g*5|0;p=e[d+(j-1<<1)>>1]|0;q=(l+2+(n<<1)+p|0)>>>2;l=g*6|0;r=e[d+(l-1<<1)>>1]|0;s=(n+2+(p<<1)+r|0)>>>2;n=g*7|0;t=e[d+(n-1<<1)>>1]|0;u=(p+2+(r<<1)+t|0)>>>2;p=(r+2+(t*3|0)|0)>>>2;b[d>>1]=(f+1+k|0)>>>1;b[a+2>>1]=(f+2+(k<<1)+m|0)>>>2;f=(k+1+m|0)>>>1&65535;b[a+4>>1]=f;b[d+(g<<1)>>1]=f;f=(k+2+(m<<1)+o|0)>>>2&65535;b[a+6>>1]=f;b[d+(g+1<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[a+8>>1]=f;b[d+(g+2<<1)>>1]=f;b[d+(h<<1)>>1]=f;f=(m+2+(o<<1)+q|0)>>>2&65535;b[a+10>>1]=f;b[d+(g+3<<1)>>1]=f;b[d+((h|1)<<1)>>1]=f;f=(o+1+q|0)>>>1&65535;b[a+12>>1]=f;b[d+(g+4<<1)>>1]=f;b[d+(h+2<<1)>>1]=f;b[d+(c<<1)>>1]=f;f=(o+2+(q<<1)+s|0)>>>2&65535;b[a+14>>1]=f;b[d+(g+5<<1)>>1]=f;b[d+(h+3<<1)>>1]=f;b[d+(c+1<<1)>>1]=f;f=(q+1+s|0)>>>1&65535;b[d+(g+6<<1)>>1]=f;b[d+(h+4<<1)>>1]=f;b[d+(c+2<<1)>>1]=f;b[d+(i<<1)>>1]=f;f=(q+2+(s<<1)+u|0)>>>2&65535;b[d+(g+7<<1)>>1]=f;b[d+(h+5<<1)>>1]=f;b[d+(c+3<<1)>>1]=f;b[d+((i|1)<<1)>>1]=f;f=(s+1+u|0)>>>1&65535;b[d+(h+6<<1)>>1]=f;b[d+(c+4<<1)>>1]=f;b[d+((i|2)<<1)>>1]=f;b[d+(j<<1)>>1]=f;f=(s+2+p+(u<<1)|0)>>>2&65535;b[d+(h+7<<1)>>1]=f;b[d+(c+5<<1)>>1]=f;b[d+((i|3)<<1)>>1]=f;b[d+(j+1<<1)>>1]=f;f=(p+1+u|0)>>>1&65535;b[d+(c+6<<1)>>1]=f;b[d+(i+4<<1)>>1]=f;b[d+(j+2<<1)>>1]=f;b[d+(l<<1)>>1]=f;f=(u+2+(p*3|0)|0)>>>2&65535;b[d+(c+7<<1)>>1]=f;b[d+(i+5<<1)>>1]=f;b[d+(j+3<<1)>>1]=f;b[d+((l|1)<<1)>>1]=f;f=p&65535;b[d+(n+7<<1)>>1]=f;b[d+(l+7<<1)>>1]=f;b[d+(j+7<<1)>>1]=f;b[d+(i+7<<1)>>1]=f;b[d+(n+6<<1)>>1]=f;b[d+(l+6<<1)>>1]=f;b[d+(j+6<<1)>>1]=f;b[d+(i+6<<1)>>1]=f;b[d+(n+5<<1)>>1]=f;b[d+(l+5<<1)>>1]=f;b[d+(j+5<<1)>>1]=f;b[d+(n+4<<1)>>1]=f;b[d+(l+4<<1)>>1]=f;b[d+(j+4<<1)>>1]=f;b[d+(n+3<<1)>>1]=f;b[d+(l+3<<1)>>1]=f;b[d+(n+2<<1)>>1]=f;b[d+(l+2<<1)>>1]=f;b[d+(n+1<<1)>>1]=f;b[d+(n<<1)>>1]=f;return}function gna(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=e[d+((g<<1)-1<<1)>>1]|0;j=e[d+((g*3|0)-1<<1)>>1]|0;k=e[d+((g<<2)-1<<1)>>1]|0;l=e[d+((g*5|0)-1<<1)>>1]|0;m=e[d+((g*6|0)-1<<1)>>1]|0;n=e[d+((g*7|0)-1<<1)>>1]|0;o=(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2)+4+((b+2+(i<<1)+f|0)>>>2)+((i+2+(f<<1)+j|0)>>>2)+((f+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n*3|0)|0)>>>2)>>3;n=Erc(o,(o|0)<0|0?-1:0,65537,65537)|0;o=G;m=a;c[m>>2]=n;c[m+4>>2]=o;m=a+8|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=g<<1;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;g=d+(a<<1)|0;c[g>>2]=n;c[g+4>>2]=o;g=d+(a+4<<1)|0;c[g>>2]=n;c[g+4>>2]=o;return}function hna(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}q=(((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2)+4+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+r|0)>>>2)+(((s&65535)+2+(r<<1)+p|0)>>>2)>>3;p=Erc(q,(q|0)<0|0?-1:0,65537,65537)|0;q=G;r=a;c[r>>2]=p;c[r+4>>2]=q;r=a+8|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=i<<1;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;i=h+(a<<1)|0;c[i>>2]=p;c[i+4>>2]=q;i=h+(a+4<<1)|0;c[i>>2]=p;c[i+4>>2]=q;return}function ina(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;b=e>>1;e=a;c[e>>2]=16777472;c[e+4>>2]=16777472;e=a+8|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(b<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(b+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=b<<1;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e+b|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;return}function jna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function kna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=Erc(e[a-2>>1]|0,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=a+8|0;c[h>>2]=b;c[h+4>>2]=g;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;b=d+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(f+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f<<1;b=Erc(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=G;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*3|0;a=Erc(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;b=G;h=d+(g<<1)|0;c[h>>2]=a;c[h+4>>2]=b;h=d+(g+4<<1)|0;c[h>>2]=a;c[h+4>>2]=b;b=f<<2;h=Erc(e[d+(b-1<<1)>>1]|0,0,65537,65537)|0;a=G;g=d+(b<<1)|0;c[g>>2]=h;c[g+4>>2]=a;g=d+(b+4<<1)|0;c[g>>2]=h;c[g+4>>2]=a;a=f*5|0;g=Erc(e[d+(a-1<<1)>>1]|0,0,65537,65537)|0;h=G;b=d+(a<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(a+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f*6|0;b=Erc(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=G;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*7|0;f=Erc(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;a=G;b=d+(g<<1)|0;c[b>>2]=f;c[b+4>>2]=a;b=d+(g+4<<1)|0;c[b>>2]=f;c[b+4>>2]=a;return}function lna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<3;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+((b|4)<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*9|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*10|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*11|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*12|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*13|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*14|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*15|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function mna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ca(b,a)|0;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function nna(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a;f=c>>1;c=a+6|0;g=(f<<2)-1|0;h=g-(f<<1)|0;i=g+f|0;j=h-f|0;k=i+f|0;l=j-f|0;m=e[d+(k+f<<1)>>1]|0;n=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=(((m-(e[d+(l-f<<1)>>1]|0)<<2)+((((e[d+(k<<1)>>1]|0)-(e[d+(l<<1)>>1]|0)|0)*3|0)+(((e[d+(i<<1)>>1]|0)-(e[d+(j<<1)>>1]|0)<<1)+((e[d+(g<<1)>>1]|0)-(e[d+(h<<1)>>1]|0))))|0)*17|0)+16>>5;h=n<<1;g=n*3|0;j=n<<2;i=n*5|0;l=n*6|0;k=n*7|0;o=d;d=((c+n|0)*-3|0)+16+((e[a-2+(8-f<<1)>>1]|0)+m<<4)|0;m=8;while(1){a=d>>5;if(a>>>0<512>>>0){p=a&65535}else{p=-a>>31&511}b[o>>1]=p;a=d+n>>5;if(a>>>0<512>>>0){q=a&65535}else{q=-a>>31&511}b[o+2>>1]=q;a=d+h>>5;if(a>>>0<512>>>0){r=a&65535}else{r=-a>>31&511}b[o+4>>1]=r;a=d+g>>5;if(a>>>0<512>>>0){s=a&65535}else{s=-a>>31&511}b[o+6>>1]=s;a=d+j>>5;if(a>>>0<512>>>0){t=a&65535}else{t=-a>>31&511}b[o+8>>1]=t;a=d+i>>5;if(a>>>0<512>>>0){u=a&65535}else{u=-a>>31&511}b[o+10>>1]=u;a=d+l>>5;if(a>>>0<512>>>0){v=a&65535}else{v=-a>>31&511}b[o+12>>1]=v;a=d+k>>5;if(a>>>0<512>>>0){w=a&65535}else{w=-a>>31&511}b[o+14>>1]=w;a=m-1|0;if((a|0)>0){o=o+(f<<1)|0;d=d+c|0;m=a}else{break}}return}function ona(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a;f=c>>1;c=a+6|0;g=-f|0;h=(f<<3)-1|0;i=h-(f<<1)|0;j=h+f|0;k=i-f|0;l=j+f|0;m=k-f|0;n=a+((f*6|0)-2)|0;o=a+((f*22|0)-2)|0;p=f<<1;q=g<<1;r=p+f|0;s=q-f|0;t=b[o+(r+f<<1)>>1]|0;u=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=((((t&65535)-(e[n+(s-f<<1)>>1]|0)<<3)+((((e[o+(r<<1)>>1]|0)-(e[n+(s<<1)>>1]|0)|0)*7|0)+((((e[o+(p<<1)>>1]|0)-(e[n+(q<<1)>>1]|0)|0)*6|0)+((((e[o+(f<<1)>>1]|0)-(e[n+(g<<1)>>1]|0)|0)*5|0)+(((e[d+(l+f<<1)>>1]|0)-(e[d+(m-f<<1)>>1]|0)<<2)+((((e[d+(l<<1)>>1]|0)-(e[d+(m<<1)>>1]|0)|0)*3|0)+(((e[d+(j<<1)>>1]|0)-(e[d+(k<<1)>>1]|0)<<1)+((e[d+(h<<1)>>1]|0)-(e[d+(i<<1)>>1]|0))))))))|0)*5|0)+32>>6;i=u*3|0;h=u<<1;k=u<<2;j=u*5|0;m=u*6|0;l=u*7|0;g=d;d=16-i+(c*-7|0)+((e[a+(-2-(f<<1)+16)>>1]|0)+(t&65535)<<4)|0;t=16;while(1){a=d>>5;if(a>>>0<512>>>0){v=a&65535}else{v=-a>>31&511}b[g>>1]=v;a=d+u>>5;if(a>>>0<512>>>0){w=a&65535}else{w=-a>>31&511}b[g+2>>1]=w;a=d+h>>5;if(a>>>0<512>>>0){x=a&65535}else{x=-a>>31&511}b[g+4>>1]=x;a=d+i>>5;if(a>>>0<512>>>0){y=a&65535}else{y=-a>>31&511}b[g+6>>1]=y;a=d+k>>5;if(a>>>0<512>>>0){z=a&65535}else{z=-a>>31&511}b[g+8>>1]=z;a=d+j>>5;if(a>>>0<512>>>0){A=a&65535}else{A=-a>>31&511}b[g+10>>1]=A;a=d+m>>5;if(a>>>0<512>>>0){B=a&65535}else{B=-a>>31&511}b[g+12>>1]=B;a=d+l>>5;if(a>>>0<512>>>0){C=a&65535}else{C=-a>>31&511}b[g+14>>1]=C;a=t-1|0;if((a|0)>0){g=g+(f<<1)|0;d=d+c|0;t=a}else{break}}return}function pna(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=1024-(d[b+~c|0]|0)|0;f=b+(-c|0)|0;g=b+(1-c)|0;h=b+(2-c)|0;i=b+(3-c)|0;j=b+(4-c)|0;k=b+(5-c)|0;l=b+(6-c)|0;m=b+(7-c)|0;n=0;o=b;while(1){b=(d[o-1|0]|0)+e|0;a[o]=a[1403376+(b+(d[f]|0))|0]|0;a[o+1|0]=a[1403376+((d[g]|0)+b)|0]|0;a[o+2|0]=a[1403376+((d[h]|0)+b)|0]|0;a[o+3|0]=a[1403376+((d[i]|0)+b)|0]|0;a[o+4|0]=a[1403376+((d[j]|0)+b)|0]|0;a[o+5|0]=a[1403376+((d[k]|0)+b)|0]|0;a[o+6|0]=a[1403376+((d[l]|0)+b)|0]|0;a[o+7|0]=a[1403376+((d[m]|0)+b)|0]|0;b=n+1|0;if((b|0)<8){n=b;o=o+c|0}else{break}}return}function qna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=(e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+(e[d+(4-f<<1)>>1]|0)))|0;l=f*7|0;m=(e[d+(l-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;n=(e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+((e[a-2>>1]|0)+(e[d+(-f<<1)>>1]|0))+(e[d+(1-f<<1)>>1]|0))+(e[d+(2-f<<1)>>1]|0))+(e[d+(3-f<<1)>>1]|0)+4>>3;o=Erc(n,(n|0)<0|0?-1:0,65537,65537)|0;n=G;p=Erc((k+2|0)>>>2,0,65537,65537)|0;q=G;r=m+4+k>>3;k=a;c[k>>2]=o;c[k+4>>2]=n;k=a+8|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(f<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(f+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(h<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(h+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(j<<1)|0;c[k>>2]=o;c[k+4>>2]=n;n=d+(j+4<<1)|0;c[n>>2]=p;c[n+4>>2]=q;q=Erc((m+2|0)>>>2,0,65537,65537)|0;m=G;n=Erc(r,(r|0)<0|0?-1:0,65537,65537)|0;r=G;p=d+(b<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(b+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(g<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(g+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(i<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(i+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(l<<1)|0;c[p>>2]=q;c[p+4>>2]=m;m=d+(l+4<<1)|0;c[m>>2]=n;c[m+4>>2]=r;return}function rna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=f*7|0;l=(e[d+(k-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;m=Erc(((e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))+2|0)>>>2,0,65537,65537)|0;n=G;o=a;c[o>>2]=m;c[o+4>>2]=n;o=a+8|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;n=Erc((l+2|0)>>>2,0,65537,65537)|0;l=G;o=d+(b<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(b+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;return}function sna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=Erc(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=G;i=Erc((g+2|0)>>>2,0,65537,65537)|0;g=G;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function tna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;sna(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function una(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;qna(a,b);d=a;f=b>>1;b=Erc(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function vna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;rna(a,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=16777472;c[b+4>>2]=16777472;b=f+(g<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=g<<1;e=f+(b<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=16777472;c[h+4>>2]=16777472;h=a+(d+8)|0;d=h;a=h;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(g<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;return}function wna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;rna(a,b);d=a;e=b>>1;b=a;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<1;f=d+(b<<1)|0;c[f>>2]=16777472;c[f+4>>2]=16777472;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=16777472;c[g+4>>2]=16777472;g=a+8|0;a=g;d=g;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(e<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(b<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(f<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;return}function xna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=0;g=0;h=0;i=0;j=0;k=0;do{l=e[d+((ca(k,f)|0)-1<<1)>>1]|0;j=l+j+(e[d+(k-f<<1)>>1]|0)|0;l=k+4|0;i=(e[d+(l-f<<1)>>1]|0)+i|0;h=(e[d+((ca(l,f)|0)-1<<1)>>1]|0)+h|0;g=(e[d+((ca(k+8|0,f)|0)-1<<1)>>1]|0)+g|0;b=(e[d+((ca(k+12|0,f)|0)-1<<1)>>1]|0)+b|0;k=k+1|0;}while((k|0)<4);k=j+4>>3;j=Erc(k,(k|0)<0|0?-1:0,65537,65537)|0;k=G;l=i+2>>2;m=Erc(l,(l|0)<0|0?-1:0,65537,65537)|0;l=G;n=h+2>>2;o=h+4+i>>3;h=g+2>>2;p=g+4+i>>3;g=b+2>>2;q=b+4+i>>3;i=a;c[i>>2]=j;c[i+4>>2]=k;i=a+8|0;c[i>>2]=m;c[i+4>>2]=l;i=d+(f<<1)|0;c[i>>2]=j;c[i+4>>2]=k;i=d+(f+4<<1)|0;c[i>>2]=m;c[i+4>>2]=l;i=f<<1;a=d+(i<<1)|0;c[a>>2]=j;c[a+4>>2]=k;a=d+(i+4<<1)|0;c[a>>2]=m;c[a+4>>2]=l;a=f*3|0;i=d+(a<<1)|0;c[i>>2]=j;c[i+4>>2]=k;k=d+(a+4<<1)|0;c[k>>2]=m;c[k+4>>2]=l;l=Erc(n,(n|0)<0|0?-1:0,65537,65537)|0;n=G;k=Erc(o,(o|0)<0|0?-1:0,65537,65537)|0;o=G;m=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;a=Erc(p,(p|0)<0|0?-1:0,65537,65537)|0;p=G;i=Erc(g,(g|0)<0|0?-1:0,65537,65537)|0;g=G;j=Erc(q,(q|0)<0|0?-1:0,65537,65537)|0;q=G;b=f<<2;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*5|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;b=d+(r+4<<1)|0;c[b>>2]=k;c[b+4>>2]=o;b=f*6|0;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*7|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;n=d+(r+4<<1)|0;c[n>>2]=k;c[n+4>>2]=o;o=f<<3;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+((o|4)<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*9|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;o=d+(n+4<<1)|0;c[o>>2]=a;c[o+4>>2]=p;o=f*10|0;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+(o+4<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*11|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;h=d+(n+4<<1)|0;c[h>>2]=a;c[h+4>>2]=p;p=f*12|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*13|0;p=d+(h<<1)|0;c[p>>2]=i;c[p+4>>2]=g;p=d+(h+4<<1)|0;c[p>>2]=j;c[p+4>>2]=q;p=f*14|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*15|0;f=d+(h<<1)|0;c[f>>2]=i;c[f+4>>2]=g;g=d+(h+4<<1)|0;c[g>>2]=j;c[g+4>>2]=q;return}function yna(a,b){a=a|0;b=b|0;rna(a,b);rna(a+(b<<3)|0,b);return}function zna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=Erc(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=G;i=Erc((g+2|0)>>>2,0,65537,65537)|0;g=G;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<3;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+((j|4)<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*9|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*10|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*11|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*12|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*13|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*14|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*15|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function Ana(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;zna(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Bna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;xna(a,b);d=a;f=b>>1;b=Erc(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function Cna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;rna(a,b);rna(a+(b<<3)|0,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=16777472;c[b+4>>2]=16777472;b=f+(g<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=g<<1;e=f+(b<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=16777472;c[h+4>>2]=16777472;h=a+(d+8)|0;d=h;a=h;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(g<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(e<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;return}function Dna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;rna(a,b);rna(a+(b<<3)|0,b);d=a;e=b>>1;b=a;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<1;f=d+(b<<1)|0;c[f>>2]=16777472;c[f+4>>2]=16777472;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=16777472;c[g+4>>2]=16777472;g=a+8|0;a=g;d=g;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(e<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(b<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;d=a+(f<<1)|0;c[d>>2]=16777472;c[d+4>>2]=16777472;return}function Ena(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b<<2;f=b*5|0;g=b<<1;h=b*6|0;i=b*3|0;j=b*7|0;k=ca(((d[a+(i-1)|0]|0)+((d[a+(g-1)|0]|0)+((d[a+(b-1)|0]|0)+((d[a-1|0]|0)+(d[a+(-b|0)|0]|0)+(d[a+(4-b)|0]|0)+(d[a+(e-1)|0]|0))+(d[a+(1-b)|0]|0)+(d[a+(5-b)|0]|0)+(d[a+(f-1)|0]|0))+(d[a+(2-b)|0]|0)+(d[a+(6-b)|0]|0)+(d[a+(h-1)|0]|0))+(d[a+(3-b)|0]|0)+(d[a+(7-b)|0]|0)+(d[a+(j-1)|0]|0)+8|0)>>>4,16843009)|0;c[a>>2]=k;c[a+4>>2]=k;c[a+b>>2]=k;c[a+(b+4)>>2]=k;c[a+g>>2]=k;c[a+(g+4)>>2]=k;c[a+i>>2]=k;c[a+(i+4)>>2]=k;c[a+e>>2]=k;c[a+(e+4)>>2]=k;c[a+f>>2]=k;c[a+(f+4)>>2]=k;c[a+h>>2]=k;c[a+(h+4)>>2]=k;c[a+j>>2]=k;c[a+(j+4)>>2]=k;return}function Fna(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b<<1;f=b*3|0;g=b<<2;h=b*5|0;i=b*6|0;j=b*7|0;k=ca(((d[a+(j-1)|0]|0)+((d[a+(i-1)|0]|0)+((d[a+(h-1)|0]|0)+((d[a+(g-1)|0]|0)+((d[a+(f-1)|0]|0)+((d[a+(e-1)|0]|0)+((d[a+(b-1)|0]|0)+(d[a-1|0]|0)))))))+4|0)>>>3,16843009)|0;c[a+4>>2]=k;c[a>>2]=k;c[a+(b+4)>>2]=k;c[a+b>>2]=k;c[a+(e+4)>>2]=k;c[a+e>>2]=k;c[a+(f+4)>>2]=k;c[a+f>>2]=k;c[a+(g+4)>>2]=k;c[a+g>>2]=k;c[a+(h+4)>>2]=k;c[a+h>>2]=k;c[a+(i+4)>>2]=k;c[a+i>>2]=k;c[a+(j+4)>>2]=k;c[a+j>>2]=k;return}function Gna(a,b){a=a|0;b=b|0;var e=0,f=0;e=ca(((d[a+(7-b)|0]|0)+((d[a+(6-b)|0]|0)+((d[a+(5-b)|0]|0)+((d[a+(4-b)|0]|0)+((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+(d[a+(-b|0)|0]|0)))))))+4|0)>>>3,16843009)|0;c[a+4>>2]=e;c[a>>2]=e;c[a+(b+4)>>2]=e;c[a+b>>2]=e;f=b<<1;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b*3|0;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b<<2;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b*5|0;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b*6|0;c[a+(f+4)>>2]=e;c[a+f>>2]=e;f=b*7|0;c[a+(f+4)>>2]=e;c[a+f>>2]=e;return}function Hna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+8|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=e<<2;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;e=d+(a+4<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;return}function Ina(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=d+(e<<1)|0;mrc(a|0,1,16)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=d+(e+4<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=d+(b+4<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=d+(a+4<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=e<<2;a=d+(b<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=d+(b+4<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=d+(a+4<<1)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=d+(b+4<<1)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=16843009;c[e+4>>2]=16843009;e=d+(a+4<<1)|0;c[e>>2]=16843009;c[e+4>>2]=16843009;return}function Jna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+8|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<2;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;return}function Kna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=b>>1;f=a;c[f>>2]=16777472;c[f+4>>2]=16777472;f=a+8|0;c[f>>2]=16777472;c[f+4>>2]=16777472;f=d+(e<<1)|0;c[f>>2]=16777472;c[f+4>>2]=16777472;f=e+4|0;g=d+(f<<1)|0;c[g>>2]=16777472;c[g+4>>2]=16777472;g=e<<1;h=d+(g<<1)|0;c[h>>2]=16777472;c[h+4>>2]=16777472;h=g+4|0;i=d+(h<<1)|0;c[i>>2]=16777472;c[i+4>>2]=16777472;i=e*3|0;j=d+(i<<1)|0;c[j>>2]=16777472;c[j+4>>2]=16777472;j=i+4|0;k=d+(j<<1)|0;c[k>>2]=16777472;c[k+4>>2]=16777472;k=e<<2;l=d+(k<<1)|0;c[l>>2]=16777472;c[l+4>>2]=16777472;l=k+4|0;m=d+(l<<1)|0;c[m>>2]=16777472;c[m+4>>2]=16777472;m=e*5|0;n=d+(m<<1)|0;c[n>>2]=16777472;c[n+4>>2]=16777472;n=m+4|0;o=d+(n<<1)|0;c[o>>2]=16777472;c[o+4>>2]=16777472;o=e*6|0;p=d+(o<<1)|0;c[p>>2]=16777472;c[p+4>>2]=16777472;p=o+4|0;q=d+(p<<1)|0;c[q>>2]=16777472;c[q+4>>2]=16777472;q=e*7|0;r=d+(q<<1)|0;c[r>>2]=16777472;c[r+4>>2]=16777472;r=q+4|0;s=d+(r<<1)|0;c[s>>2]=16777472;c[s+4>>2]=16777472;s=b<<3;b=a+s|0;d=b;t=b;c[t>>2]=16777472;c[t+4>>2]=16777472;t=a+(s+8)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(e<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(f<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(g<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(h<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(i<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(j<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(k<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(l<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(m<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(n<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(o<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(p<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(q<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;t=d+(r<<1)|0;c[t>>2]=16777472;c[t+4>>2]=16777472;return}function Lna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+((e[d+(-f<<1)>>1]|0)+((e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))))))))))))))))))+16>>5;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Mna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a;a=b>>1;b=d+(-a<<1)|0;e=c[b>>2]|0;f=c[b+4>>2]|0;b=d+(4-a<<1)|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=d+(8-a<<1)|0;i=c[b>>2]|0;j=c[b+4>>2]|0;b=d+(12-a<<1)|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=0;do{m=ca(b,a)|0;n=d+(m<<1)|0;c[n>>2]=e;c[n+4>>2]=f;n=d+(m+4<<1)|0;c[n>>2]=g;c[n+4>>2]=h;n=d+(m+8<<1)|0;c[n>>2]=i;c[n+4>>2]=j;n=d+(m+12<<1)|0;c[n>>2]=k;c[n+4>>2]=l;b=b+1|0;}while((b|0)<16);return}function Nna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ca(b,a)|0;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+8<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+12<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Ona(a,b){a=a|0;b=b|0;lta(a,b,1,0);return}function Pna(a,b){a=a|0;b=b|0;lta(a,b,0,1);return}function Qna(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=1024-(d[b+~c|0]|0)|0;f=b+(-c|0)|0;g=b+(1-c)|0;h=b+(2-c)|0;i=b+(3-c)|0;j=b+(4-c)|0;k=b+(5-c)|0;l=b+(6-c)|0;m=b+(7-c)|0;n=b+(8-c)|0;o=b+(9-c)|0;p=b+(10-c)|0;q=b+(11-c)|0;r=b+(12-c)|0;s=b+(13-c)|0;t=b+(14-c)|0;u=b+(15-c)|0;v=0;w=b;while(1){b=(d[w-1|0]|0)+e|0;a[w]=a[1403376+(b+(d[f]|0))|0]|0;a[w+1|0]=a[1403376+((d[g]|0)+b)|0]|0;a[w+2|0]=a[1403376+((d[h]|0)+b)|0]|0;a[w+3|0]=a[1403376+((d[i]|0)+b)|0]|0;a[w+4|0]=a[1403376+((d[j]|0)+b)|0]|0;a[w+5|0]=a[1403376+((d[k]|0)+b)|0]|0;a[w+6|0]=a[1403376+((d[l]|0)+b)|0]|0;a[w+7|0]=a[1403376+((d[m]|0)+b)|0]|0;a[w+8|0]=a[1403376+((d[n]|0)+b)|0]|0;a[w+9|0]=a[1403376+((d[o]|0)+b)|0]|0;a[w+10|0]=a[1403376+((d[p]|0)+b)|0]|0;a[w+11|0]=a[1403376+((d[q]|0)+b)|0]|0;a[w+12|0]=a[1403376+((d[r]|0)+b)|0]|0;a[w+13|0]=a[1403376+((d[s]|0)+b)|0]|0;a[w+14|0]=a[1403376+((d[t]|0)+b)|0]|0;a[w+15|0]=a[1403376+((d[u]|0)+b)|0]|0;b=v+1|0;if((b|0)<16){v=b;w=w+c|0}else{break}}return}function Rna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+8|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+16|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+24|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(e+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+4<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+8<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=d+(a+12<<1)|0;c[b>>2]=16711935;c[b+4>>2]=16711935;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+4<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+8<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=d+(b+12<<1)|0;c[a>>2]=16711935;c[a+4>>2]=16711935;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;e=d+(a+4<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;e=d+(a+8<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;e=d+(a+12<<1)|0;c[e>>2]=16711935;c[e+4>>2]=16711935;return}function Sna(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a;e=b>>1;b=d+(e<<1)|0;mrc(a|0,1,32)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=e<<1;a=d+(b<<1)|0;mrc(d+(e+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;f=d+(a<<1)|0;mrc(d+(b+4<<1)|0,1,24)|0;c[f>>2]=16843009;c[f+4>>2]=16843009;f=a+e|0;b=d+(f<<1)|0;mrc(d+(a+4<<1)|0,1,24)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=f+e|0;a=d+(b<<1)|0;mrc(d+(f+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;f=d+(a<<1)|0;mrc(d+(b+4<<1)|0,1,24)|0;c[f>>2]=16843009;c[f+4>>2]=16843009;f=a+e|0;b=d+(f<<1)|0;mrc(d+(a+4<<1)|0,1,24)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=f+e|0;a=d+(b<<1)|0;mrc(d+(f+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;f=d+(a<<1)|0;mrc(d+(b+4<<1)|0,1,24)|0;c[f>>2]=16843009;c[f+4>>2]=16843009;f=a+e|0;b=d+(f<<1)|0;mrc(d+(a+4<<1)|0,1,24)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=f+e|0;a=d+(b<<1)|0;mrc(d+(f+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;f=d+(a<<1)|0;mrc(d+(b+4<<1)|0,1,24)|0;c[f>>2]=16843009;c[f+4>>2]=16843009;f=a+e|0;b=d+(f<<1)|0;mrc(d+(a+4<<1)|0,1,24)|0;c[b>>2]=16843009;c[b+4>>2]=16843009;b=f+e|0;a=d+(b<<1)|0;mrc(d+(f+4<<1)|0,1,24)|0;c[a>>2]=16843009;c[a+4>>2]=16843009;a=b+e|0;e=d+(a<<1)|0;mrc(d+(b+4<<1)|0,1,24)|0;c[e>>2]=16843009;c[e+4>>2]=16843009;mrc(d+(a+4<<1)|0,1,24)|0;return}function Tna(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a;f=c>>1;c=a+14|0;g=-f|0;h=(f<<3)-1|0;i=d+(h<<1)|0;j=d+(h-(f<<1)<<1)|0;h=a+((f*30|0)-2)|0;k=2;l=i;m=j;n=(e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0)|0;o=(e[i>>1]|0)-(e[j>>1]|0)|0;do{l=l+(f<<1)|0;m=m+(g<<1)|0;n=(ca((e[c+(k-f<<1)>>1]|0)-(e[c+(-(f+k|0)<<1)>>1]|0)|0,k)|0)+n|0;o=(ca((e[l>>1]|0)-(e[m>>1]|0)|0,k)|0)+o|0;k=k+1|0;}while((k|0)<9);k=(n*5|0)+32>>6;n=(o*5|0)+32>>6;o=k<<1;m=k*3|0;l=k<<2;c=((n+k|0)*-7|0)+16+((e[a-2+(16-f<<1)>>1]|0)+(e[h>>1]|0)<<4)|0;h=d;d=16;while(1){a=-16;g=c;while(1){j=g>>5;if(j>>>0<512>>>0){p=j&65535}else{p=-j>>31&511}b[h+(a+16<<1)>>1]=p;j=g+k>>5;if(j>>>0<512>>>0){q=j&65535}else{q=-j>>31&511}b[h+(a+17<<1)>>1]=q;j=g+o>>5;if(j>>>0<512>>>0){r=j&65535}else{r=-j>>31&511}b[h+(a+18<<1)>>1]=r;j=g+m>>5;if(j>>>0<512>>>0){s=j&65535}else{s=-j>>31&511}b[h+(a+19<<1)>>1]=s;j=a+4|0;if((j|0)<0){a=j;g=g+l|0}else{break}}g=d-1|0;if((g|0)>0){c=c+n|0;h=h+(f<<1)|0;d=g}else{break}}return}function Una(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))+8>>4;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Vna(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))))))))))))))+8>>4;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Wna(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+8|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+16|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+24|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(e+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=e<<1;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+4<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+8<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=d+(a+12<<1)|0;c[b>>2]=16777472;c[b+4>>2]=16777472;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+4<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+8<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=d+(b+12<<1)|0;c[a>>2]=16777472;c[a+4>>2]=16777472;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+4<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+8<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;e=d+(a+12<<1)|0;c[e>>2]=16777472;c[e+4>>2]=16777472;return}function Xna(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a;h=f>>1;f=h<<1;i=h*3|0;j=h<<2;k=(e[g+(-h<<1)>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=k;l=k+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=l;k=l+(c[d+32>>2]|0)|0;b[g+(i-h<<1)>>1]=k;b[g+(j-h<<1)>>1]=k+(c[d+48>>2]|0);k=1-h|0;h=(e[g+(k<<1)>>1]|0)+(c[d+4>>2]|0)|0;b[a+2>>1]=h;l=h+(c[d+20>>2]|0)|0;b[g+(k+f<<1)>>1]=l;h=l+(c[d+36>>2]|0)|0;b[g+(k+i<<1)>>1]=h;b[g+(k+j<<1)>>1]=h+(c[d+52>>2]|0);h=k+1|0;l=(e[g+(h<<1)>>1]|0)+(c[d+8>>2]|0)|0;b[a+4>>1]=l;m=l+(c[d+24>>2]|0)|0;b[g+(h+f<<1)>>1]=m;l=m+(c[d+40>>2]|0)|0;b[g+(h+i<<1)>>1]=l;b[g+(h+j<<1)>>1]=l+(c[d+56>>2]|0);l=k+2|0;k=(e[g+(l<<1)>>1]|0)+(c[d+12>>2]|0)|0;b[a+6>>1]=k;a=k+(c[d+28>>2]|0)|0;b[g+(l+f<<1)>>1]=a;f=a+(c[d+44>>2]|0)|0;b[g+(l+i<<1)>>1]=f;b[g+(l+j<<1)>>1]=f+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function Yna(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=a;h=f>>1;f=(e[a-2>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=f;i=f+(c[d+4>>2]|0)|0;b[a+2>>1]=i;f=i+(c[d+8>>2]|0)|0;b[a+4>>1]=f;b[a+6>>1]=f+(c[d+12>>2]|0);f=(e[g+(h-1<<1)>>1]|0)+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=f;a=f+(c[d+20>>2]|0)|0;b[g+(h+1<<1)>>1]=a;f=a+(c[d+24>>2]|0)|0;b[g+(h+2<<1)>>1]=f;b[g+(h+3<<1)>>1]=f+(c[d+28>>2]|0);f=h<<1;a=(e[g+(f-1<<1)>>1]|0)+(c[d+32>>2]|0)|0;b[g+(f<<1)>>1]=a;i=a+(c[d+36>>2]|0)|0;b[g+((f|1)<<1)>>1]=i;a=i+(c[d+40>>2]|0)|0;b[g+(f+2<<1)>>1]=a;b[g+(f+3<<1)>>1]=a+(c[d+44>>2]|0);a=f+h|0;h=(e[g+(a-1<<1)>>1]|0)+(c[d+48>>2]|0)|0;b[g+(a<<1)>>1]=h;f=h+(c[d+52>>2]|0)|0;b[g+(a+1<<1)>>1]=f;h=f+(c[d+56>>2]|0)|0;b[g+(a+2<<1)>>1]=h;b[g+(a+3<<1)>>1]=h+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function Zna(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=g<<1;h=g*3|0;i=g<<2;j=g*5|0;k=g*6|0;l=g*7|0;m=g<<3;n=0;o=a+(-g<<1)|0;a=d;while(1){p=(e[o>>1]|0)+(c[a>>2]|0)|0;b[o+(g<<1)>>1]=p;q=p+(c[a+32>>2]|0)|0;b[o+(f<<1)>>1]=q;p=q+(c[a+64>>2]|0)|0;b[o+(h<<1)>>1]=p;q=p+(c[a+96>>2]|0)|0;b[o+(i<<1)>>1]=q;p=q+(c[a+128>>2]|0)|0;b[o+(j<<1)>>1]=p;q=p+(c[a+160>>2]|0)|0;b[o+(k<<1)>>1]=q;p=q+(c[a+192>>2]|0)|0;b[o+(l<<1)>>1]=p;b[o+(m<<1)>>1]=p+(c[a+224>>2]|0);p=n+1|0;if((p|0)<8){n=p;o=o+2|0;a=a+4|0}else{break}}mrc(d|0,0,256)|0;return}function _na(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>1;f=0;h=a;a=d;while(1){i=(e[h-2>>1]|0)+(c[a>>2]|0)|0;b[h>>1]=i;j=i+(c[a+4>>2]|0)|0;b[h+2>>1]=j;i=j+(c[a+8>>2]|0)|0;b[h+4>>1]=i;j=i+(c[a+12>>2]|0)|0;b[h+6>>1]=j;i=j+(c[a+16>>2]|0)|0;b[h+8>>1]=i;j=i+(c[a+20>>2]|0)|0;b[h+10>>1]=j;i=j+(c[a+24>>2]|0)|0;b[h+12>>1]=i;b[h+14>>1]=i+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}mrc(d|0,0,256)|0;return}function $na(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Xna(a+(c[b>>2]|0)|0,d,e);Xna(a+(c[b+4>>2]|0)|0,d+64|0,e);Xna(a+(c[b+8>>2]|0)|0,d+128|0,e);Xna(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function aoa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Yna(a+(c[b>>2]|0)|0,d,e);Yna(a+(c[b+4>>2]|0)|0,d+64|0,e);Yna(a+(c[b+8>>2]|0)|0,d+128|0,e);Yna(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function boa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Xna(a+(c[b>>2]|0)|0,d,e);Xna(a+(c[b+4>>2]|0)|0,d+64|0,e);Xna(a+(c[b+8>>2]|0)|0,d+128|0,e);Xna(a+(c[b+12>>2]|0)|0,d+192|0,e);Xna(a+(c[b+32>>2]|0)|0,d+256|0,e);Xna(a+(c[b+36>>2]|0)|0,d+320|0,e);Xna(a+(c[b+40>>2]|0)|0,d+384|0,e);Xna(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function coa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Yna(a+(c[b>>2]|0)|0,d,e);Yna(a+(c[b+4>>2]|0)|0,d+64|0,e);Yna(a+(c[b+8>>2]|0)|0,d+128|0,e);Yna(a+(c[b+12>>2]|0)|0,d+192|0,e);Yna(a+(c[b+32>>2]|0)|0,d+256|0,e);Yna(a+(c[b+36>>2]|0)|0,d+320|0,e);Yna(a+(c[b+40>>2]|0)|0,d+384|0,e);Yna(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function doa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Xna(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function eoa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Yna(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function foa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=a;e=d>>1;d=b+(-e<<1)|0;f=c[d>>2]|0;g=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+((e*3|0)<<1)|0;c[d>>2]=f;c[d+4>>2]=g;return}function goa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0;b=a;f=d>>1;d=Erc(e[a-2>>1]|0,0,65537,65537)|0;g=a;c[g>>2]=d;c[g+4>>2]=G;g=Erc(e[b+(f-1<<1)>>1]|0,0,65537,65537)|0;d=b+(f<<1)|0;c[d>>2]=g;c[d+4>>2]=G;d=f<<1;g=Erc(e[b+(d-1<<1)>>1]|0,0,65537,65537)|0;a=b+(d<<1)|0;c[a>>2]=g;c[a+4>>2]=G;a=f*3|0;f=Erc(e[b+(a-1<<1)>>1]|0,0,65537,65537)|0;g=b+(a<<1)|0;c[g>>2]=f;c[g+4>>2]=G;return}function hoa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=(e[b+(-f<<1)>>1]|0)+4+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=b+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(d<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function ioa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=d>>1;d=e[f+(1-g<<1)>>1]|0;h=e[f+(2-g<<1)>>1]|0;i=e[f+(3-g<<1)>>1]|0;j=e[c>>1]|0;k=e[c+2>>1]|0;l=e[c+4>>1]|0;m=e[c+6>>1]|0;b[f>>1]=((e[f+(-g<<1)>>1]|0)+2+h+(d<<1)|0)>>>2;c=(d+2+i+(h<<1)|0)>>>2&65535;b[f+(g<<1)>>1]=c;b[a+2>>1]=c;c=(h+2+j+(i<<1)|0)>>>2&65535;h=g<<1;b[f+(h<<1)>>1]=c;b[f+(g+1<<1)>>1]=c;b[a+4>>1]=c;c=(i+2+k+(j<<1)|0)>>>2&65535;i=g*3|0;b[f+(i<<1)>>1]=c;b[f+((h|1)<<1)>>1]=c;b[f+(g+2<<1)>>1]=c;b[a+6>>1]=c;c=(j+2+l+(k<<1)|0)>>>2&65535;b[f+(i+1<<1)>>1]=c;b[f+(h+2<<1)>>1]=c;b[f+(g+3<<1)>>1]=c;c=(k+2+m+(l<<1)|0)>>>2&65535;b[f+(i+2<<1)>>1]=c;b[f+(h+3<<1)>>1]=c;b[f+(i+3<<1)>>1]=(l+2+(m*3|0)|0)>>>2;return}function joa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;b[c+(o<<1)>>1]=(l+2+(n<<1)+(e[c+(o-1<<1)>>1]|0)|0)>>>2;p=(k+2+(l<<1)+n|0)>>>2&65535;b[c+(o+1<<1)>>1]=p;b[c+(m<<1)>>1]=p;p=d+2|0;n=(p+(k<<1)+l|0)>>>2&65535;b[c+(o+2<<1)>>1]=n;b[c+((m|1)<<1)>>1]=n;b[c+(f<<1)>>1]=n;n=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+3<<1)>>1]=n;b[c+(m+2<<1)>>1]=n;b[c+(f+1<<1)>>1]=n;b[c>>1]=n;n=(p+(g<<1)+h|0)>>>2&65535;b[c+(m+3<<1)>>1]=n;b[c+(f+2<<1)>>1]=n;b[a+2>>1]=n;n=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(f+3<<1)>>1]=n;b[a+4>>1]=n;b[a+6>>1]=(h+2+(i<<1)+j|0)>>>2;return}function koa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;p=(d+1+g|0)>>>1&65535;b[c+((m|1)<<1)>>1]=p;b[c>>1]=p;p=(g+1+h|0)>>>1&65535;b[c+(m+2<<1)>>1]=p;b[a+2>>1]=p;p=(h+1+i|0)>>>1&65535;b[c+(m+3<<1)>>1]=p;b[a+4>>1]=p;b[a+6>>1]=(i+1+j|0)>>>1;a=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+1<<1)>>1]=a;b[c+(f<<1)>>1]=a;a=d+2|0;d=(a+(g<<1)+h|0)>>>2&65535;b[c+(o+2<<1)>>1]=d;b[c+(f+1<<1)>>1]=d;d=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(o+3<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;b[c+(f+3<<1)>>1]=(h+2+(i<<1)+j|0)>>>2;b[c+(m<<1)>>1]=(a+(k<<1)+l|0)>>>2;b[c+(o<<1)>>1]=(k+2+(l<<1)+n|0)>>>2;return}function loa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[a-2>>1]|0;k=e[c+(f-1<<1)>>1]|0;l=f<<1;m=e[c+(l-1<<1)>>1]|0;n=f*3|0;o=e[c+(n-1<<1)>>1]|0;p=(d+1+j|0)>>>1&65535;b[c+(f+2<<1)>>1]=p;b[c>>1]=p;p=((d<<1)+2+g+j|0)>>>2&65535;b[c+(f+3<<1)>>1]=p;b[a+2>>1]=p;p=d+2|0;b[a+4>>1]=(p+(g<<1)+h|0)>>>2;b[a+6>>1]=(g+2+(h<<1)+i|0)>>>2;i=(j+1+k|0)>>>1&65535;b[c+(l+2<<1)>>1]=i;b[c+(f<<1)>>1]=i;i=(p+(j<<1)+k|0)>>>2&65535;b[c+(l+3<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;i=(k+1+m|0)>>>1&65535;b[c+(n+2<<1)>>1]=i;b[c+(l<<1)>>1]=i;i=(j+2+(k<<1)+m|0)>>>2&65535;b[c+(n+3<<1)>>1]=i;b[c+((l|1)<<1)>>1]=i;b[c+(n<<1)>>1]=(m+1+o|0)>>>1;b[c+(n+1<<1)>>1]=(k+2+(m<<1)+o|0)>>>2;return}function moa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a;g=d>>1;d=e[f+(-g<<1)>>1]|0;h=e[f+(1-g<<1)>>1]|0;i=e[f+(2-g<<1)>>1]|0;j=e[f+(3-g<<1)>>1]|0;k=e[c>>1]|0;l=e[c+2>>1]|0;m=e[c+4>>1]|0;b[f>>1]=(d+1+h|0)>>>1;c=(h+1+i|0)>>>1&65535;n=g<<1;b[f+(n<<1)>>1]=c;b[a+2>>1]=c;c=(i+1+j|0)>>>1&65535;b[f+((n|1)<<1)>>1]=c;b[a+4>>1]=c;c=(j+1+k|0)>>>1&65535;b[f+(n+2<<1)>>1]=c;b[a+6>>1]=c;b[f+(n+3<<1)>>1]=(k+1+l|0)>>>1;b[f+(g<<1)>>1]=(d+2+(h<<1)+i|0)>>>2;d=(h+2+(i<<1)+j|0)>>>2&65535;h=g*3|0;b[f+(h<<1)>>1]=d;b[f+(g+1<<1)>>1]=d;d=(i+2+(j<<1)+k|0)>>>2&65535;b[f+(h+1<<1)>>1]=d;b[f+(g+2<<1)>>1]=d;d=(j+2+(k<<1)+l|0)>>>2&65535;b[f+(h+2<<1)>>1]=d;b[f+(g+3<<1)>>1]=d;b[f+(h+3<<1)>>1]=(k+2+(l<<1)+m|0)>>>2;return}function noa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a;f=d>>1;d=e[a-2>>1]|0;g=e[c+(f-1<<1)>>1]|0;h=f<<1;i=e[c+(h-1<<1)>>1]|0;j=f*3|0;k=b[c+(j-1<<1)>>1]|0;l=k&65535;b[c>>1]=(d+1+g|0)>>>1;b[a+2>>1]=(d+2+(g<<1)+i|0)>>>2;d=(g+1+i|0)>>>1&65535;b[c+(f<<1)>>1]=d;b[a+4>>1]=d;d=(g+2+(i<<1)+l|0)>>>2&65535;b[c+(f+1<<1)>>1]=d;b[a+6>>1]=d;d=(i+1+l|0)>>>1&65535;b[c+(h<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;d=(i+2+l+(l<<1)|0)>>>2&65535;b[c+((h|1)<<1)>>1]=d;b[c+(f+3<<1)>>1]=d;b[c+(j+3<<1)>>1]=k;b[c+(j+2<<1)>>1]=k;b[c+(h+2<<1)>>1]=k;b[c+(j<<1)>>1]=k;b[c+(j+1<<1)>>1]=k;b[c+(h+3<<1)>>1]=k;return}function ooa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=Erc(((e[a-2>>1]|0)+2+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;i=G;j=a;c[j>>2]=h;c[j+4>>2]=i;j=b+(f<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(d<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(g<<1)|0;c[j>>2]=h;c[j+4>>2]=i;return}function poa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;b=a;f=d>>1;d=Erc(((e[b+(-f<<1)>>1]|0)+2+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+((f*3|0)<<1)|0;c[h>>2]=d;c[h+4>>2]=g;return}function qoa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=33554944;c[d+4>>2]=33554944;d=b+(e<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=b+(e<<1<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=b+((e*3|0)<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;return}function roa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=33489407;c[d+4>>2]=33489407;d=b+(e<<1)|0;c[d>>2]=33489407;c[d+4>>2]=33489407;d=b+(e<<1<<1)|0;c[d>>2]=33489407;c[d+4>>2]=33489407;d=b+((e*3|0)<<1)|0;c[d>>2]=33489407;c[d+4>>2]=33489407;return}function soa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=33620481;c[d+4>>2]=33620481;d=b+(e<<1)|0;c[d>>2]=33620481;c[d+4>>2]=33620481;d=b+(e<<1<<1)|0;c[d>>2]=33620481;c[d+4>>2]=33620481;d=b+((e*3|0)<<1)|0;c[d>>2]=33620481;c[d+4>>2]=33620481;return}function toa(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}b[h>>1]=((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;b[a+2>>1]=(j+2+(k<<1)+l|0)>>>2;b[a+4>>1]=(k+2+(l<<1)+m|0)>>>2;b[a+6>>1]=(l+2+(m<<1)+n|0)>>>2;l=a+8|0;b[l>>1]=(m+2+(n<<1)+o|0)>>>2;b[a+10>>1]=(n+2+(o<<1)+p|0)>>>2;b[a+12>>1]=(o+2+(p<<1)+r|0)>>>2;b[a+14>>1]=((s&65535)+2+(r<<1)+p|0)>>>2;p=a;a=c[p>>2]|0;r=c[p+4>>2]|0;p=l;l=c[p>>2]|0;s=c[p+4>>2]|0;p=h+(i<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(i+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<1;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*3|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<2;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*5|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i*6|0;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*7|0;i=h+(o<<1)|0;c[i>>2]=a;c[i+4>>2]=r;r=h+(o+4<<1)|0;c[r>>2]=l;c[r+4>>2]=s;return}function uoa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=g<<1;j=e[d+(f-1<<1)>>1]|0;k=g*3|0;l=e[d+(k-1<<1)>>1]|0;m=g<<2;n=e[d+(m-1<<1)>>1]|0;o=g*5|0;p=e[d+(o-1<<1)>>1]|0;q=g*6|0;r=e[d+(q-1<<1)>>1]|0;s=g*7|0;t=e[d+(s-1<<1)>>1]|0;u=Erc(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2,0,65537,65537)|0;h=G;v=a;c[v>>2]=u;c[v+4>>2]=h;v=a+8|0;c[v>>2]=u;c[v+4>>2]=h;h=Erc((b+2+(i<<1)+j|0)>>>2,0,65537,65537)|0;b=G;v=d+(g<<1)|0;c[v>>2]=h;c[v+4>>2]=b;v=d+(g+4<<1)|0;c[v>>2]=h;c[v+4>>2]=b;b=Erc((i+2+(j<<1)+l|0)>>>2,0,65537,65537)|0;i=G;v=d+(f<<1)|0;c[v>>2]=b;c[v+4>>2]=i;v=d+(f+4<<1)|0;c[v>>2]=b;c[v+4>>2]=i;i=Erc((j+2+(l<<1)+n|0)>>>2,0,65537,65537)|0;j=G;v=d+(k<<1)|0;c[v>>2]=i;c[v+4>>2]=j;v=d+(k+4<<1)|0;c[v>>2]=i;c[v+4>>2]=j;j=Erc((l+2+(n<<1)+p|0)>>>2,0,65537,65537)|0;l=G;v=d+(m<<1)|0;c[v>>2]=j;c[v+4>>2]=l;v=d+(m+4<<1)|0;c[v>>2]=j;c[v+4>>2]=l;l=Erc((n+2+(p<<1)+r|0)>>>2,0,65537,65537)|0;n=G;v=d+(o<<1)|0;c[v>>2]=l;c[v+4>>2]=n;v=d+(o+4<<1)|0;c[v>>2]=l;c[v+4>>2]=n;n=Erc((p+2+(r<<1)+t|0)>>>2,0,65537,65537)|0;p=G;v=d+(q<<1)|0;c[v>>2]=n;c[v+4>>2]=p;v=d+(q+4<<1)|0;c[v>>2]=n;c[v+4>>2]=p;p=Erc((r+2+(t*3|0)|0)>>>2,0,65537,65537)|0;t=G;r=d+(s<<1)|0;c[r>>2]=p;c[r+4>>2]=t;r=d+(s+4<<1)|0;c[r>>2]=p;c[r+4>>2]=t;return}function voa(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=g>>1;g=(d|0)!=0;if(g){d=~i;j=h+(d<<1)|0;k=a-2|0;l=d}else{d=a-2|0;j=d;k=d;l=~i}d=e[k>>1]|0;k=e[h+(i-1<<1)>>1]|0;m=e[h+((i<<1)-1<<1)>>1]|0;n=e[h+((i*3|0)-1<<1)>>1]|0;o=e[h+((i<<2)-1<<1)>>1]|0;p=e[h+((i*5|0)-1<<1)>>1]|0;q=e[h+((i*6|0)-1<<1)>>1]|0;r=e[h+((i*7|0)-1<<1)>>1]|0;s=-i|0;t=e[h+(s<<1)>>1]|0;u=e[h+(1-i<<1)>>1]|0;v=e[h+(2-i<<1)>>1]|0;w=e[h+(3-i<<1)>>1]|0;x=e[h+(4-i<<1)>>1]|0;y=e[h+(5-i<<1)>>1]|0;z=e[h+(6-i<<1)>>1]|0;A=b[h+(7-i<<1)>>1]|0;B=A&65535;if((f|0)==0){C=A}else{C=b[h+(8-i<<1)>>1]|0}A=(((e[j>>1]|0)+2+(d<<1)+k|0)>>>2)+8+((d+2+(k<<1)+m|0)>>>2)+((k+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q<<1)+r|0)>>>2)+((q+2+(r*3|0)|0)>>>2)+(((e[h+((g?l:s)<<1)>>1]|0)+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+z|0)>>>2)+((y+2+(z<<1)+B|0)>>>2)+(((C&65535)+2+(B<<1)+z|0)>>>2)>>4;z=Erc(A,(A|0)<0|0?-1:0,65537,65537)|0;A=G;B=a;c[B>>2]=z;c[B+4>>2]=A;B=a+8|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=i<<1;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;i=h+(a<<1)|0;c[i>>2]=z;c[i+4>>2]=A;i=h+(a+4<<1)|0;c[i>>2]=z;c[i+4>>2]=A;return}function woa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=e[g+(2-h<<1)>>1]|0;l=(i+2+(j<<1)+k|0)>>>2;m=e[g+(3-h<<1)>>1]|0;n=(j+2+(k<<1)+m|0)>>>2;o=e[g+(4-h<<1)>>1]|0;p=(k+2+(m<<1)+o|0)>>>2;k=e[g+(5-h<<1)>>1]|0;q=(m+2+(o<<1)+k|0)>>>2;m=e[g+(6-h<<1)>>1]|0;r=(o+2+(k<<1)+m|0)>>>2;o=b[g+(7-h<<1)>>1]|0;s=o&65535;t=(k+2+(m<<1)+s|0)>>>2;if((d|0)==0){u=s;v=s;w=s;x=s;y=s;z=s;A=s;B=s;C=(o&65535)+2+(s<<1)|0}else{o=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;k=e[g+(10-h<<1)>>1]|0;D=e[g+(11-h<<1)>>1]|0;E=e[g+(12-h<<1)>>1]|0;F=e[g+(13-h<<1)>>1]|0;G=e[g+(14-h<<1)>>1]|0;H=e[g+(15-h<<1)>>1]|0;u=(G+2+(H*3|0)|0)>>>2;v=(F+2+(G<<1)+H|0)>>>2;w=(E+2+(F<<1)+G|0)>>>2;x=(D+2+(E<<1)+F|0)>>>2;y=(k+2+(D<<1)+E|0)>>>2;z=(d+2+(k<<1)+D|0)>>>2;A=(o+2+(d<<1)+k|0)>>>2;B=(s+2+(o<<1)+d|0)>>>2;C=(e[g+(8-h<<1)>>1]|0)+2+(s<<1)|0}s=(C+m|0)>>>2;b[g>>1]=((((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2)+2+(l<<1)+n|0)>>>2;j=(l+2+(n<<1)+p|0)>>>2&65535;b[a+2>>1]=j;b[g+(h<<1)>>1]=j;j=(n+2+(p<<1)+q|0)>>>2&65535;b[a+4>>1]=j;b[g+(h+1<<1)>>1]=j;n=h<<1;b[g+(n<<1)>>1]=j;j=(p+2+(q<<1)+r|0)>>>2&65535;b[a+6>>1]=j;b[g+(h+2<<1)>>1]=j;b[g+((n|1)<<1)>>1]=j;p=h*3|0;b[g+(p<<1)>>1]=j;j=(q+2+(r<<1)+t|0)>>>2&65535;b[a+8>>1]=j;b[g+(h+3<<1)>>1]=j;b[g+(n+2<<1)>>1]=j;b[g+(p+1<<1)>>1]=j;q=h<<2;b[g+(q<<1)>>1]=j;j=(r+2+(t<<1)+s|0)>>>2&65535;b[a+10>>1]=j;b[g+(h+4<<1)>>1]=j;b[g+(n+3<<1)>>1]=j;b[g+(p+2<<1)>>1]=j;b[g+((q|1)<<1)>>1]=j;r=h*5|0;b[g+(r<<1)>>1]=j;j=(t+2+(s<<1)+B|0)>>>2&65535;b[a+12>>1]=j;b[g+(h+5<<1)>>1]=j;b[g+(n+4<<1)>>1]=j;b[g+(p+3<<1)>>1]=j;b[g+((q|2)<<1)>>1]=j;b[g+(r+1<<1)>>1]=j;t=h*6|0;b[g+(t<<1)>>1]=j;j=(s+2+(B<<1)+A|0)>>>2&65535;b[a+14>>1]=j;b[g+(h+6<<1)>>1]=j;b[g+(n+5<<1)>>1]=j;b[g+(p+4<<1)>>1]=j;b[g+((q|3)<<1)>>1]=j;b[g+(r+2<<1)>>1]=j;b[g+((t|1)<<1)>>1]=j;a=h*7|0;b[g+(a<<1)>>1]=j;j=(B+2+(A<<1)+z|0)>>>2&65535;b[g+(h+7<<1)>>1]=j;b[g+(n+6<<1)>>1]=j;b[g+(p+5<<1)>>1]=j;b[g+(q+4<<1)>>1]=j;b[g+(r+3<<1)>>1]=j;b[g+(t+2<<1)>>1]=j;b[g+(a+1<<1)>>1]=j;j=(A+2+(z<<1)+y|0)>>>2&65535;b[g+(n+7<<1)>>1]=j;b[g+(p+6<<1)>>1]=j;b[g+(q+5<<1)>>1]=j;b[g+(r+4<<1)>>1]=j;b[g+(t+3<<1)>>1]=j;b[g+(a+2<<1)>>1]=j;j=(z+2+(y<<1)+x|0)>>>2&65535;b[g+(p+7<<1)>>1]=j;b[g+(q+6<<1)>>1]=j;b[g+(r+5<<1)>>1]=j;b[g+(t+4<<1)>>1]=j;b[g+(a+3<<1)>>1]=j;j=(y+2+(x<<1)+w|0)>>>2&65535;b[g+(q+7<<1)>>1]=j;b[g+(r+6<<1)>>1]=j;b[g+(t+5<<1)>>1]=j;b[g+(a+4<<1)>>1]=j;j=(x+2+(w<<1)+v|0)>>>2&65535;b[g+(r+7<<1)>>1]=j;b[g+(t+6<<1)>>1]=j;b[g+(a+5<<1)>>1]=j;j=(w+2+(v<<1)+u|0)>>>2&65535;b[g+(t+7<<1)>>1]=j;b[g+(a+6<<1)>>1]=j;b[g+(a+7<<1)>>1]=(v+2+(u*3|0)|0)>>>2;return}function xoa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;k=e[g+(v-1<<1)>>1]|0;d=i+2|0;i=(d+(w<<1)+k|0)>>>2;c=h*3|0;y=e[g+(c-1<<1)>>1]|0;z=(w+2+(k<<1)+y|0)>>>2;w=h<<2;A=e[g+(w-1<<1)>>1]|0;B=(k+2+(y<<1)+A|0)>>>2;k=h*5|0;C=e[g+(k-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*6|0;E=e[g+(y-1<<1)>>1]|0;F=(A+2+(C<<1)+E|0)>>>2;A=h*7|0;G=e[g+(A-1<<1)>>1]|0;H=(C+2+(E<<1)+G|0)>>>2;C=(d+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(A<<1)>>1]=(F+2+((E+2+(G*3|0)|0)>>>2)+(H<<1)|0)>>>2;G=(D+2+(F<<1)+H|0)>>>2&65535;b[g+(A+1<<1)>>1]=G;b[g+(y<<1)>>1]=G;G=(B+2+(D<<1)+F|0)>>>2&65535;b[g+(A+2<<1)>>1]=G;b[g+((y|1)<<1)>>1]=G;b[g+(k<<1)>>1]=G;G=(z+2+(B<<1)+D|0)>>>2&65535;b[g+(A+3<<1)>>1]=G;b[g+(y+2<<1)>>1]=G;b[g+(k+1<<1)>>1]=G;b[g+(w<<1)>>1]=G;G=(i+2+(z<<1)+B|0)>>>2&65535;b[g+(A+4<<1)>>1]=G;b[g+(y+3<<1)>>1]=G;b[g+(k+2<<1)>>1]=G;b[g+((w|1)<<1)>>1]=G;b[g+(c<<1)>>1]=G;G=(f+2+(i<<1)+z|0)>>>2&65535;b[g+(A+5<<1)>>1]=G;b[g+(y+4<<1)>>1]=G;b[g+(k+3<<1)>>1]=G;b[g+((w|2)<<1)>>1]=G;b[g+(c+1<<1)>>1]=G;b[g+(v<<1)>>1]=G;G=((f<<1)+2+i+C|0)>>>2&65535;b[g+(A+6<<1)>>1]=G;b[g+(y+5<<1)>>1]=G;b[g+(k+4<<1)>>1]=G;b[g+((w|3)<<1)>>1]=G;b[g+(c+2<<1)>>1]=G;b[g+((v|1)<<1)>>1]=G;b[g+(h<<1)>>1]=G;G=l+2|0;i=(G+f+(C<<1)|0)>>>2&65535;b[g+(A+7<<1)>>1]=i;b[g+(y+6<<1)>>1]=i;b[g+(k+5<<1)>>1]=i;b[g+(w+4<<1)>>1]=i;b[g+(c+3<<1)>>1]=i;b[g+(v+2<<1)>>1]=i;b[g+(h+1<<1)>>1]=i;b[g>>1]=i;i=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+7<<1)>>1]=i;b[g+(k+6<<1)>>1]=i;b[g+(w+5<<1)>>1]=i;b[g+(c+4<<1)>>1]=i;b[g+(v+3<<1)>>1]=i;b[g+(h+2<<1)>>1]=i;b[a+2>>1]=i;i=(G+(m<<1)+o|0)>>>2&65535;b[g+(k+7<<1)>>1]=i;b[g+(w+6<<1)>>1]=i;b[g+(c+5<<1)>>1]=i;b[g+(v+4<<1)>>1]=i;b[g+(h+3<<1)>>1]=i;b[a+4>>1]=i;i=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(w+7<<1)>>1]=i;b[g+(c+6<<1)>>1]=i;b[g+(v+5<<1)>>1]=i;b[g+(h+4<<1)>>1]=i;b[a+6>>1]=i;i=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(c+7<<1)>>1]=i;b[g+(v+6<<1)>>1]=i;b[g+(h+5<<1)>>1]=i;b[a+8>>1]=i;i=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(v+7<<1)>>1]=i;b[g+(h+6<<1)>>1]=i;b[a+10>>1]=i;i=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(h+7<<1)>>1]=i;b[a+12>>1]=i;b[a+14>>1]=(r+2+(t<<1)+(((u&65535)+2+(s<<1)+n|0)>>>2)|0)>>>2;return}function yoa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}k=((u&65535)+2+(s<<1)+n|0)>>>2;if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;n=e[g+(v-1<<1)>>1]|0;s=i+2|0;i=(s+(w<<1)+n|0)>>>2;u=h*3|0;d=e[g+(u-1<<1)>>1]|0;c=(w+2+(n<<1)+d|0)>>>2;w=h<<2;y=e[g+(w-1<<1)>>1]|0;z=(n+2+(d<<1)+y|0)>>>2;n=h*5|0;A=e[g+(n-1<<1)>>1]|0;B=(d+2+(y<<1)+A|0)>>>2;d=h*6|0;C=e[g+(d-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*7|0;E=(A+2+(C<<1)+(e[g+(y-1<<1)>>1]|0)|0)>>>2;C=(s+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(d<<1)>>1]=(z+2+(B<<1)+D|0)>>>2;b[g+(y<<1)>>1]=(B+2+(D<<1)+E|0)>>>2;E=(i+2+(c<<1)+z|0)>>>2&65535;b[g+((d|1)<<1)>>1]=E;b[g+(w<<1)>>1]=E;E=(c+2+(z<<1)+B|0)>>>2&65535;b[g+(y+1<<1)>>1]=E;b[g+(n<<1)>>1]=E;E=((f<<1)+2+i+C|0)>>>2&65535;b[g+(d+2<<1)>>1]=E;b[g+((w|1)<<1)>>1]=E;b[g+(v<<1)>>1]=E;E=(f+2+(i<<1)+c|0)>>>2&65535;b[g+(y+2<<1)>>1]=E;b[g+(n+1<<1)>>1]=E;b[g+(u<<1)>>1]=E;E=l+2|0;c=(E+f+(C<<1)|0)>>>2&65535;b[g+(y+3<<1)>>1]=c;b[g+(n+2<<1)>>1]=c;b[g+(u+1<<1)>>1]=c;b[g+(h<<1)>>1]=c;c=l+1|0;f=(c+C|0)>>>1&65535;b[g+(d+3<<1)>>1]=f;b[g+((w|2)<<1)>>1]=f;b[g+((v|1)<<1)>>1]=f;b[g>>1]=f;f=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+4<<1)>>1]=f;b[g+(n+3<<1)>>1]=f;b[g+(u+2<<1)>>1]=f;b[g+(h+1<<1)>>1]=f;f=(c+m|0)>>>1&65535;b[g+(d+4<<1)>>1]=f;b[g+((w|3)<<1)>>1]=f;b[g+(v+2<<1)>>1]=f;b[a+2>>1]=f;f=(E+(m<<1)+o|0)>>>2&65535;b[g+(y+5<<1)>>1]=f;b[g+(n+4<<1)>>1]=f;b[g+(u+3<<1)>>1]=f;b[g+(h+2<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[g+(d+5<<1)>>1]=f;b[g+(w+4<<1)>>1]=f;b[g+(v+3<<1)>>1]=f;b[a+4>>1]=f;f=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(y+6<<1)>>1]=f;b[g+(n+5<<1)>>1]=f;b[g+(u+4<<1)>>1]=f;b[g+(h+3<<1)>>1]=f;f=(o+1+p|0)>>>1&65535;b[g+(d+6<<1)>>1]=f;b[g+(w+5<<1)>>1]=f;b[g+(v+4<<1)>>1]=f;b[a+6>>1]=f;f=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(y+7<<1)>>1]=f;b[g+(n+6<<1)>>1]=f;b[g+(u+5<<1)>>1]=f;b[g+(h+4<<1)>>1]=f;f=(p+1+q|0)>>>1&65535;b[g+(d+7<<1)>>1]=f;b[g+(w+6<<1)>>1]=f;b[g+(v+5<<1)>>1]=f;b[a+8>>1]=f;f=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(n+7<<1)>>1]=f;b[g+(u+6<<1)>>1]=f;b[g+(h+5<<1)>>1]=f;f=(q+1+r|0)>>>1&65535;b[g+(w+7<<1)>>1]=f;b[g+(v+6<<1)>>1]=f;b[a+10>>1]=f;f=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(u+7<<1)>>1]=f;b[g+(h+6<<1)>>1]=f;f=(r+1+t|0)>>>1&65535;b[g+(v+7<<1)>>1]=f;b[a+12>>1]=f;b[g+(h+7<<1)>>1]=(r+2+(t<<1)+k|0)>>>2;b[a+14>>1]=(t+1+k|0)>>>1;return}function zoa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=a;g=f>>1;f=(c|0)!=0;c=-g|0;h=~g;i=e[d+(c<<1)>>1]|0;j=e[d+(1-g<<1)>>1]|0;k=((e[d+((f?h:c)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;c=e[d+(2-g<<1)>>1]|0;l=(i+2+(j<<1)+c|0)>>>2;m=e[d+(3-g<<1)>>1]|0;n=(j+2+(c<<1)+m|0)>>>2;j=e[d+(4-g<<1)>>1]|0;o=(c+2+(m<<1)+j|0)>>>2;c=e[d+(5-g<<1)>>1]|0;p=(m+2+(j<<1)+c|0)>>>2;m=e[d+(6-g<<1)>>1]|0;q=(j+2+(c<<1)+m|0)>>>2;j=(c+2+(m<<1)+(e[d+(7-g<<1)>>1]|0)|0)>>>2;if(f){f=d+(h<<1)|0;r=f;s=a-2|0;t=f}else{f=a-2|0;r=f;s=f;t=d+(h<<1)|0}h=e[s>>1]|0;s=e[d+(g-1<<1)>>1]|0;f=((e[r>>1]|0)+2+(h<<1)+s|0)>>>2;r=g<<1;m=e[d+(r-1<<1)>>1]|0;c=h+2|0;h=(c+(s<<1)+m|0)>>>2;u=g*3|0;v=e[d+(u-1<<1)>>1]|0;w=(s+2+(m<<1)+v|0)>>>2;s=g<<2;x=e[d+(s-1<<1)>>1]|0;y=(m+2+(v<<1)+x|0)>>>2;m=g*5|0;z=e[d+(m-1<<1)>>1]|0;A=(v+2+(x<<1)+z|0)>>>2;v=g*6|0;B=e[d+(v-1<<1)>>1]|0;C=(x+2+(z<<1)+B|0)>>>2;x=g*7|0;D=e[d+(x-1<<1)>>1]|0;E=(z+2+(B<<1)+D|0)>>>2;z=(B+2+(D*3|0)|0)>>>2;D=(c+((e[t>>1]|0)<<1)+i|0)>>>2;b[d+(x<<1)>>1]=(z+1+E|0)>>>1;b[d+(x+1<<1)>>1]=(C+2+z+(E<<1)|0)>>>2;z=(C+1+E|0)>>>1&65535;b[d+(x+2<<1)>>1]=z;b[d+(v<<1)>>1]=z;z=(A+2+(C<<1)+E|0)>>>2&65535;b[d+(x+3<<1)>>1]=z;b[d+((v|1)<<1)>>1]=z;z=(A+1+C|0)>>>1&65535;b[d+(x+4<<1)>>1]=z;b[d+(v+2<<1)>>1]=z;b[d+(m<<1)>>1]=z;z=(y+2+(A<<1)+C|0)>>>2&65535;b[d+(x+5<<1)>>1]=z;b[d+(v+3<<1)>>1]=z;b[d+(m+1<<1)>>1]=z;z=(y+1+A|0)>>>1&65535;b[d+(x+6<<1)>>1]=z;b[d+(v+4<<1)>>1]=z;b[d+(m+2<<1)>>1]=z;b[d+(s<<1)>>1]=z;z=(w+2+(y<<1)+A|0)>>>2&65535;b[d+(x+7<<1)>>1]=z;b[d+(v+5<<1)>>1]=z;b[d+(m+3<<1)>>1]=z;b[d+((s|1)<<1)>>1]=z;z=(w+1+y|0)>>>1&65535;b[d+(v+6<<1)>>1]=z;b[d+(m+4<<1)>>1]=z;b[d+((s|2)<<1)>>1]=z;b[d+(u<<1)>>1]=z;z=(h+2+(w<<1)+y|0)>>>2&65535;b[d+(v+7<<1)>>1]=z;b[d+(m+5<<1)>>1]=z;b[d+((s|3)<<1)>>1]=z;b[d+(u+1<<1)>>1]=z;z=(h+1+w|0)>>>1&65535;b[d+(m+6<<1)>>1]=z;b[d+(s+4<<1)>>1]=z;b[d+(u+2<<1)>>1]=z;b[d+(r<<1)>>1]=z;z=(f+2+(h<<1)+w|0)>>>2&65535;b[d+(m+7<<1)>>1]=z;b[d+(s+5<<1)>>1]=z;b[d+(u+3<<1)>>1]=z;b[d+((r|1)<<1)>>1]=z;z=f+1|0;m=(z+h|0)>>>1&65535;b[d+(s+6<<1)>>1]=m;b[d+(u+4<<1)>>1]=m;b[d+(r+2<<1)>>1]=m;b[d+(g<<1)>>1]=m;m=((f<<1)+2+h+D|0)>>>2&65535;b[d+(s+7<<1)>>1]=m;b[d+(u+5<<1)>>1]=m;b[d+(r+3<<1)>>1]=m;b[d+(g+1<<1)>>1]=m;m=(z+D|0)>>>1&65535;b[d+(u+6<<1)>>1]=m;b[d+(r+4<<1)>>1]=m;b[d+(g+2<<1)>>1]=m;b[d>>1]=m;m=k+2|0;z=(m+f+(D<<1)|0)>>>2&65535;b[d+(u+7<<1)>>1]=z;b[d+(r+5<<1)>>1]=z;b[d+(g+3<<1)>>1]=z;b[a+2>>1]=z;z=((k<<1)+2+l+D|0)>>>2&65535;b[d+(r+6<<1)>>1]=z;b[d+(g+4<<1)>>1]=z;b[a+4>>1]=z;z=(m+(l<<1)+n|0)>>>2&65535;b[d+(r+7<<1)>>1]=z;b[d+(g+5<<1)>>1]=z;b[a+6>>1]=z;z=(l+2+(n<<1)+o|0)>>>2&65535;b[d+(g+6<<1)>>1]=z;b[a+8>>1]=z;z=(n+2+(o<<1)+p|0)>>>2&65535;b[d+(g+7<<1)>>1]=z;b[a+10>>1]=z;b[a+12>>1]=(o+2+(p<<1)+q|0)>>>2;b[a+14>>1]=(p+2+(q<<1)+j|0)>>>2;return}function Aoa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;f=e[g+(2-h<<1)>>1]|0;c=(i+2+(j<<1)+f|0)>>>2;i=e[g+(3-h<<1)>>1]|0;l=(j+2+(f<<1)+i|0)>>>2;j=e[g+(4-h<<1)>>1]|0;m=(f+2+(i<<1)+j|0)>>>2;f=e[g+(5-h<<1)>>1]|0;n=(i+2+(j<<1)+f|0)>>>2;i=e[g+(6-h<<1)>>1]|0;o=(j+2+(f<<1)+i|0)>>>2;j=b[g+(7-h<<1)>>1]|0;p=j&65535;q=(f+2+(i<<1)+p|0)>>>2;if((d|0)==0){r=p;s=p;t=p;u=p;v=p;w=(j&65535)+2+(p<<1)|0}else{j=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;f=e[g+(10-h<<1)>>1]|0;x=e[g+(11-h<<1)>>1]|0;y=e[g+(12-h<<1)>>1]|0;r=(x+2+(y<<1)+(e[g+(13-h<<1)>>1]|0)|0)>>>2;s=(f+2+(x<<1)+y|0)>>>2;t=(d+2+(f<<1)+x|0)>>>2;u=(j+2+(d<<1)+f|0)>>>2;v=(p+2+(j<<1)+d|0)>>>2;w=(e[g+(8-h<<1)>>1]|0)+2+(p<<1)|0}p=(w+i|0)>>>2;b[g>>1]=(k+1+c|0)>>>1;b[g+(h<<1)>>1]=(k+2+(c<<1)+l|0)>>>2;k=(c+1+l|0)>>>1&65535;b[a+2>>1]=k;i=h<<1;b[g+(i<<1)>>1]=k;k=(c+2+(l<<1)+m|0)>>>2&65535;b[g+(h+1<<1)>>1]=k;c=h*3|0;b[g+(c<<1)>>1]=k;k=(l+1+m|0)>>>1&65535;b[a+4>>1]=k;b[g+((i|1)<<1)>>1]=k;w=h<<2;b[g+(w<<1)>>1]=k;k=(l+2+(m<<1)+n|0)>>>2&65535;b[g+(h+2<<1)>>1]=k;b[g+(c+1<<1)>>1]=k;l=h*5|0;b[g+(l<<1)>>1]=k;k=(m+1+n|0)>>>1&65535;b[a+6>>1]=k;b[g+(i+2<<1)>>1]=k;b[g+((w|1)<<1)>>1]=k;d=h*6|0;b[g+(d<<1)>>1]=k;k=(m+2+(n<<1)+o|0)>>>2&65535;b[g+(h+3<<1)>>1]=k;b[g+(c+2<<1)>>1]=k;b[g+(l+1<<1)>>1]=k;m=h*7|0;b[g+(m<<1)>>1]=k;k=(n+1+o|0)>>>1&65535;b[a+8>>1]=k;b[g+(i+3<<1)>>1]=k;b[g+((w|2)<<1)>>1]=k;b[g+((d|1)<<1)>>1]=k;k=(n+2+(o<<1)+q|0)>>>2&65535;b[g+(h+4<<1)>>1]=k;b[g+(c+3<<1)>>1]=k;b[g+(l+2<<1)>>1]=k;b[g+(m+1<<1)>>1]=k;k=(o+1+q|0)>>>1&65535;b[a+10>>1]=k;b[g+(i+4<<1)>>1]=k;b[g+((w|3)<<1)>>1]=k;b[g+(d+2<<1)>>1]=k;k=(o+2+(q<<1)+p|0)>>>2&65535;b[g+(h+5<<1)>>1]=k;b[g+(c+4<<1)>>1]=k;b[g+(l+3<<1)>>1]=k;b[g+(m+2<<1)>>1]=k;k=(q+1+p|0)>>>1&65535;b[a+12>>1]=k;b[g+(i+5<<1)>>1]=k;b[g+(w+4<<1)>>1]=k;b[g+(d+3<<1)>>1]=k;k=(q+2+(p<<1)+v|0)>>>2&65535;b[g+(h+6<<1)>>1]=k;b[g+(c+5<<1)>>1]=k;b[g+(l+4<<1)>>1]=k;b[g+(m+3<<1)>>1]=k;k=(p+1+v|0)>>>1&65535;b[a+14>>1]=k;b[g+(i+6<<1)>>1]=k;b[g+(w+5<<1)>>1]=k;b[g+(d+4<<1)>>1]=k;k=(p+2+(v<<1)+u|0)>>>2&65535;b[g+(h+7<<1)>>1]=k;b[g+(c+6<<1)>>1]=k;b[g+(l+5<<1)>>1]=k;b[g+(m+4<<1)>>1]=k;k=(v+1+u|0)>>>1&65535;b[g+(i+7<<1)>>1]=k;b[g+(w+6<<1)>>1]=k;b[g+(d+5<<1)>>1]=k;k=(v+2+(u<<1)+t|0)>>>2&65535;b[g+(c+7<<1)>>1]=k;b[g+(l+6<<1)>>1]=k;b[g+(m+5<<1)>>1]=k;k=(u+1+t|0)>>>1&65535;b[g+(w+7<<1)>>1]=k;b[g+(d+6<<1)>>1]=k;k=(u+2+(t<<1)+s|0)>>>2&65535;b[g+(l+7<<1)>>1]=k;b[g+(m+6<<1)>>1]=k;b[g+(d+7<<1)>>1]=(t+1+s|0)>>>1;b[g+(m+7<<1)>>1]=(t+2+(s<<1)+r|0)>>>2;return}function Boa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a;g=f>>1;if((c|0)==0){c=a-2|0;h=c;i=c}else{h=d+(~g<<1)|0;i=a-2|0}c=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=((e[h>>1]|0)+2+(c<<1)+i|0)>>>2;h=g<<1;j=e[d+(h-1<<1)>>1]|0;k=(c+2+(i<<1)+j|0)>>>2;c=g*3|0;l=e[d+(c-1<<1)>>1]|0;m=(i+2+(j<<1)+l|0)>>>2;i=g<<2;n=e[d+(i-1<<1)>>1]|0;o=(j+2+(l<<1)+n|0)>>>2;j=g*5|0;p=e[d+(j-1<<1)>>1]|0;q=(l+2+(n<<1)+p|0)>>>2;l=g*6|0;r=e[d+(l-1<<1)>>1]|0;s=(n+2+(p<<1)+r|0)>>>2;n=g*7|0;t=e[d+(n-1<<1)>>1]|0;u=(p+2+(r<<1)+t|0)>>>2;p=(r+2+(t*3|0)|0)>>>2;b[d>>1]=(f+1+k|0)>>>1;b[a+2>>1]=(f+2+(k<<1)+m|0)>>>2;f=(k+1+m|0)>>>1&65535;b[a+4>>1]=f;b[d+(g<<1)>>1]=f;f=(k+2+(m<<1)+o|0)>>>2&65535;b[a+6>>1]=f;b[d+(g+1<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[a+8>>1]=f;b[d+(g+2<<1)>>1]=f;b[d+(h<<1)>>1]=f;f=(m+2+(o<<1)+q|0)>>>2&65535;b[a+10>>1]=f;b[d+(g+3<<1)>>1]=f;b[d+((h|1)<<1)>>1]=f;f=(o+1+q|0)>>>1&65535;b[a+12>>1]=f;b[d+(g+4<<1)>>1]=f;b[d+(h+2<<1)>>1]=f;b[d+(c<<1)>>1]=f;f=(o+2+(q<<1)+s|0)>>>2&65535;b[a+14>>1]=f;b[d+(g+5<<1)>>1]=f;b[d+(h+3<<1)>>1]=f;b[d+(c+1<<1)>>1]=f;f=(q+1+s|0)>>>1&65535;b[d+(g+6<<1)>>1]=f;b[d+(h+4<<1)>>1]=f;b[d+(c+2<<1)>>1]=f;b[d+(i<<1)>>1]=f;f=(q+2+(s<<1)+u|0)>>>2&65535;b[d+(g+7<<1)>>1]=f;b[d+(h+5<<1)>>1]=f;b[d+(c+3<<1)>>1]=f;b[d+((i|1)<<1)>>1]=f;f=(s+1+u|0)>>>1&65535;b[d+(h+6<<1)>>1]=f;b[d+(c+4<<1)>>1]=f;b[d+((i|2)<<1)>>1]=f;b[d+(j<<1)>>1]=f;f=(s+2+p+(u<<1)|0)>>>2&65535;b[d+(h+7<<1)>>1]=f;b[d+(c+5<<1)>>1]=f;b[d+((i|3)<<1)>>1]=f;b[d+(j+1<<1)>>1]=f;f=(p+1+u|0)>>>1&65535;b[d+(c+6<<1)>>1]=f;b[d+(i+4<<1)>>1]=f;b[d+(j+2<<1)>>1]=f;b[d+(l<<1)>>1]=f;f=(u+2+(p*3|0)|0)>>>2&65535;b[d+(c+7<<1)>>1]=f;b[d+(i+5<<1)>>1]=f;b[d+(j+3<<1)>>1]=f;b[d+((l|1)<<1)>>1]=f;f=p&65535;b[d+(n+7<<1)>>1]=f;b[d+(l+7<<1)>>1]=f;b[d+(j+7<<1)>>1]=f;b[d+(i+7<<1)>>1]=f;b[d+(n+6<<1)>>1]=f;b[d+(l+6<<1)>>1]=f;b[d+(j+6<<1)>>1]=f;b[d+(i+6<<1)>>1]=f;b[d+(n+5<<1)>>1]=f;b[d+(l+5<<1)>>1]=f;b[d+(j+5<<1)>>1]=f;b[d+(n+4<<1)>>1]=f;b[d+(l+4<<1)>>1]=f;b[d+(j+4<<1)>>1]=f;b[d+(n+3<<1)>>1]=f;b[d+(l+3<<1)>>1]=f;b[d+(n+2<<1)>>1]=f;b[d+(l+2<<1)>>1]=f;b[d+(n+1<<1)>>1]=f;b[d+(n<<1)>>1]=f;return}function Coa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=e[d+((g<<1)-1<<1)>>1]|0;j=e[d+((g*3|0)-1<<1)>>1]|0;k=e[d+((g<<2)-1<<1)>>1]|0;l=e[d+((g*5|0)-1<<1)>>1]|0;m=e[d+((g*6|0)-1<<1)>>1]|0;n=e[d+((g*7|0)-1<<1)>>1]|0;o=(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2)+4+((b+2+(i<<1)+f|0)>>>2)+((i+2+(f<<1)+j|0)>>>2)+((f+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n*3|0)|0)>>>2)>>3;n=Erc(o,(o|0)<0|0?-1:0,65537,65537)|0;o=G;m=a;c[m>>2]=n;c[m+4>>2]=o;m=a+8|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=g<<1;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;g=d+(a<<1)|0;c[g>>2]=n;c[g+4>>2]=o;g=d+(a+4<<1)|0;c[g>>2]=n;c[g+4>>2]=o;return}function Doa(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}q=(((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2)+4+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+r|0)>>>2)+(((s&65535)+2+(r<<1)+p|0)>>>2)>>3;p=Erc(q,(q|0)<0|0?-1:0,65537,65537)|0;q=G;r=a;c[r>>2]=p;c[r+4>>2]=q;r=a+8|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=i<<1;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;i=h+(a<<1)|0;c[i>>2]=p;c[i+4>>2]=q;i=h+(a+4<<1)|0;c[i>>2]=p;c[i+4>>2]=q;return}function Eoa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;b=e>>1;e=a;c[e>>2]=33554944;c[e+4>>2]=33554944;e=a+8|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(b<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(b+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=b<<1;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e+b|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;return}function Foa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Goa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=Erc(e[a-2>>1]|0,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=a+8|0;c[h>>2]=b;c[h+4>>2]=g;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;b=d+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(f+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f<<1;b=Erc(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=G;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*3|0;a=Erc(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;b=G;h=d+(g<<1)|0;c[h>>2]=a;c[h+4>>2]=b;h=d+(g+4<<1)|0;c[h>>2]=a;c[h+4>>2]=b;b=f<<2;h=Erc(e[d+(b-1<<1)>>1]|0,0,65537,65537)|0;a=G;g=d+(b<<1)|0;c[g>>2]=h;c[g+4>>2]=a;g=d+(b+4<<1)|0;c[g>>2]=h;c[g+4>>2]=a;a=f*5|0;g=Erc(e[d+(a-1<<1)>>1]|0,0,65537,65537)|0;h=G;b=d+(a<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(a+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f*6|0;b=Erc(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=G;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*7|0;f=Erc(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;a=G;b=d+(g<<1)|0;c[b>>2]=f;c[b+4>>2]=a;b=d+(g+4<<1)|0;c[b>>2]=f;c[b+4>>2]=a;return}



function Hoa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<3;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+((b|4)<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*9|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*10|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*11|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*12|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*13|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*14|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*15|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Ioa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ca(b,a)|0;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Joa(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a;f=c>>1;c=a+6|0;g=(f<<2)-1|0;h=g-(f<<1)|0;i=g+f|0;j=h-f|0;k=i+f|0;l=j-f|0;m=e[d+(k+f<<1)>>1]|0;n=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=(((m-(e[d+(l-f<<1)>>1]|0)<<2)+((((e[d+(k<<1)>>1]|0)-(e[d+(l<<1)>>1]|0)|0)*3|0)+(((e[d+(i<<1)>>1]|0)-(e[d+(j<<1)>>1]|0)<<1)+((e[d+(g<<1)>>1]|0)-(e[d+(h<<1)>>1]|0))))|0)*17|0)+16>>5;h=n<<1;g=n*3|0;j=n<<2;i=n*5|0;l=n*6|0;k=n*7|0;o=d;d=((c+n|0)*-3|0)+16+((e[a-2+(8-f<<1)>>1]|0)+m<<4)|0;m=8;while(1){a=d>>5;if(a>>>0<1024>>>0){p=a&65535}else{p=-a>>31&1023}b[o>>1]=p;a=d+n>>5;if(a>>>0<1024>>>0){q=a&65535}else{q=-a>>31&1023}b[o+2>>1]=q;a=d+h>>5;if(a>>>0<1024>>>0){r=a&65535}else{r=-a>>31&1023}b[o+4>>1]=r;a=d+g>>5;if(a>>>0<1024>>>0){s=a&65535}else{s=-a>>31&1023}b[o+6>>1]=s;a=d+j>>5;if(a>>>0<1024>>>0){t=a&65535}else{t=-a>>31&1023}b[o+8>>1]=t;a=d+i>>5;if(a>>>0<1024>>>0){u=a&65535}else{u=-a>>31&1023}b[o+10>>1]=u;a=d+l>>5;if(a>>>0<1024>>>0){v=a&65535}else{v=-a>>31&1023}b[o+12>>1]=v;a=d+k>>5;if(a>>>0<1024>>>0){w=a&65535}else{w=-a>>31&1023}b[o+14>>1]=w;a=m-1|0;if((a|0)>0){o=o+(f<<1)|0;d=d+c|0;m=a}else{break}}return}function Koa(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a;f=c>>1;c=a+6|0;g=-f|0;h=(f<<3)-1|0;i=h-(f<<1)|0;j=h+f|0;k=i-f|0;l=j+f|0;m=k-f|0;n=a+((f*6|0)-2)|0;o=a+((f*22|0)-2)|0;p=f<<1;q=g<<1;r=p+f|0;s=q-f|0;t=b[o+(r+f<<1)>>1]|0;u=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=((((t&65535)-(e[n+(s-f<<1)>>1]|0)<<3)+((((e[o+(r<<1)>>1]|0)-(e[n+(s<<1)>>1]|0)|0)*7|0)+((((e[o+(p<<1)>>1]|0)-(e[n+(q<<1)>>1]|0)|0)*6|0)+((((e[o+(f<<1)>>1]|0)-(e[n+(g<<1)>>1]|0)|0)*5|0)+(((e[d+(l+f<<1)>>1]|0)-(e[d+(m-f<<1)>>1]|0)<<2)+((((e[d+(l<<1)>>1]|0)-(e[d+(m<<1)>>1]|0)|0)*3|0)+(((e[d+(j<<1)>>1]|0)-(e[d+(k<<1)>>1]|0)<<1)+((e[d+(h<<1)>>1]|0)-(e[d+(i<<1)>>1]|0))))))))|0)*5|0)+32>>6;i=u*3|0;h=u<<1;k=u<<2;j=u*5|0;m=u*6|0;l=u*7|0;g=d;d=16-i+(c*-7|0)+((e[a+(-2-(f<<1)+16)>>1]|0)+(t&65535)<<4)|0;t=16;while(1){a=d>>5;if(a>>>0<1024>>>0){v=a&65535}else{v=-a>>31&1023}b[g>>1]=v;a=d+u>>5;if(a>>>0<1024>>>0){w=a&65535}else{w=-a>>31&1023}b[g+2>>1]=w;a=d+h>>5;if(a>>>0<1024>>>0){x=a&65535}else{x=-a>>31&1023}b[g+4>>1]=x;a=d+i>>5;if(a>>>0<1024>>>0){y=a&65535}else{y=-a>>31&1023}b[g+6>>1]=y;a=d+k>>5;if(a>>>0<1024>>>0){z=a&65535}else{z=-a>>31&1023}b[g+8>>1]=z;a=d+j>>5;if(a>>>0<1024>>>0){A=a&65535}else{A=-a>>31&1023}b[g+10>>1]=A;a=d+m>>5;if(a>>>0<1024>>>0){B=a&65535}else{B=-a>>31&1023}b[g+12>>1]=B;a=d+l>>5;if(a>>>0<1024>>>0){C=a&65535}else{C=-a>>31&1023}b[g+14>>1]=C;a=t-1|0;if((a|0)>0){g=g+(f<<1)|0;d=d+c|0;t=a}else{break}}return}function Loa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=(e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+(e[d+(4-f<<1)>>1]|0)))|0;l=f*7|0;m=(e[d+(l-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;n=(e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+((e[a-2>>1]|0)+(e[d+(-f<<1)>>1]|0))+(e[d+(1-f<<1)>>1]|0))+(e[d+(2-f<<1)>>1]|0))+(e[d+(3-f<<1)>>1]|0)+4>>3;o=Erc(n,(n|0)<0|0?-1:0,65537,65537)|0;n=G;p=Erc((k+2|0)>>>2,0,65537,65537)|0;q=G;r=m+4+k>>3;k=a;c[k>>2]=o;c[k+4>>2]=n;k=a+8|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(f<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(f+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(h<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(h+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(j<<1)|0;c[k>>2]=o;c[k+4>>2]=n;n=d+(j+4<<1)|0;c[n>>2]=p;c[n+4>>2]=q;q=Erc((m+2|0)>>>2,0,65537,65537)|0;m=G;n=Erc(r,(r|0)<0|0?-1:0,65537,65537)|0;r=G;p=d+(b<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(b+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(g<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(g+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(i<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(i+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(l<<1)|0;c[p>>2]=q;c[p+4>>2]=m;m=d+(l+4<<1)|0;c[m>>2]=n;c[m+4>>2]=r;return}function Moa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=f*7|0;l=(e[d+(k-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;m=Erc(((e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))+2|0)>>>2,0,65537,65537)|0;n=G;o=a;c[o>>2]=m;c[o+4>>2]=n;o=a+8|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;n=Erc((l+2|0)>>>2,0,65537,65537)|0;l=G;o=d+(b<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(b+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;return}function Noa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=Erc(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=G;i=Erc((g+2|0)>>>2,0,65537,65537)|0;g=G;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function Ooa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;Noa(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Poa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;Loa(a,b);d=a;f=b>>1;b=Erc(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function Qoa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;Moa(a,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=33554944;c[b+4>>2]=33554944;b=f+(g<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=g<<1;e=f+(b<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=33554944;c[h+4>>2]=33554944;h=a+(d+8)|0;d=h;a=h;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(g<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;return}function Roa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Moa(a,b);d=a;e=b>>1;b=a;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<1;f=d+(b<<1)|0;c[f>>2]=33554944;c[f+4>>2]=33554944;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=33554944;c[g+4>>2]=33554944;g=a+8|0;a=g;d=g;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(e<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(b<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(f<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;return}function Soa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=0;g=0;h=0;i=0;j=0;k=0;do{l=e[d+((ca(k,f)|0)-1<<1)>>1]|0;j=l+j+(e[d+(k-f<<1)>>1]|0)|0;l=k+4|0;i=(e[d+(l-f<<1)>>1]|0)+i|0;h=(e[d+((ca(l,f)|0)-1<<1)>>1]|0)+h|0;g=(e[d+((ca(k+8|0,f)|0)-1<<1)>>1]|0)+g|0;b=(e[d+((ca(k+12|0,f)|0)-1<<1)>>1]|0)+b|0;k=k+1|0;}while((k|0)<4);k=j+4>>3;j=Erc(k,(k|0)<0|0?-1:0,65537,65537)|0;k=G;l=i+2>>2;m=Erc(l,(l|0)<0|0?-1:0,65537,65537)|0;l=G;n=h+2>>2;o=h+4+i>>3;h=g+2>>2;p=g+4+i>>3;g=b+2>>2;q=b+4+i>>3;i=a;c[i>>2]=j;c[i+4>>2]=k;i=a+8|0;c[i>>2]=m;c[i+4>>2]=l;i=d+(f<<1)|0;c[i>>2]=j;c[i+4>>2]=k;i=d+(f+4<<1)|0;c[i>>2]=m;c[i+4>>2]=l;i=f<<1;a=d+(i<<1)|0;c[a>>2]=j;c[a+4>>2]=k;a=d+(i+4<<1)|0;c[a>>2]=m;c[a+4>>2]=l;a=f*3|0;i=d+(a<<1)|0;c[i>>2]=j;c[i+4>>2]=k;k=d+(a+4<<1)|0;c[k>>2]=m;c[k+4>>2]=l;l=Erc(n,(n|0)<0|0?-1:0,65537,65537)|0;n=G;k=Erc(o,(o|0)<0|0?-1:0,65537,65537)|0;o=G;m=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;a=Erc(p,(p|0)<0|0?-1:0,65537,65537)|0;p=G;i=Erc(g,(g|0)<0|0?-1:0,65537,65537)|0;g=G;j=Erc(q,(q|0)<0|0?-1:0,65537,65537)|0;q=G;b=f<<2;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*5|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;b=d+(r+4<<1)|0;c[b>>2]=k;c[b+4>>2]=o;b=f*6|0;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*7|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;n=d+(r+4<<1)|0;c[n>>2]=k;c[n+4>>2]=o;o=f<<3;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+((o|4)<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*9|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;o=d+(n+4<<1)|0;c[o>>2]=a;c[o+4>>2]=p;o=f*10|0;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+(o+4<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*11|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;h=d+(n+4<<1)|0;c[h>>2]=a;c[h+4>>2]=p;p=f*12|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*13|0;p=d+(h<<1)|0;c[p>>2]=i;c[p+4>>2]=g;p=d+(h+4<<1)|0;c[p>>2]=j;c[p+4>>2]=q;p=f*14|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*15|0;f=d+(h<<1)|0;c[f>>2]=i;c[f+4>>2]=g;g=d+(h+4<<1)|0;c[g>>2]=j;c[g+4>>2]=q;return}function Toa(a,b){a=a|0;b=b|0;Moa(a,b);Moa(a+(b<<3)|0,b);return}function Uoa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=Erc(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=G;i=Erc((g+2|0)>>>2,0,65537,65537)|0;g=G;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<3;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+((j|4)<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*9|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*10|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*11|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*12|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*13|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*14|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*15|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function Voa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;Uoa(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Woa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;Soa(a,b);d=a;f=b>>1;b=Erc(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function Xoa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;Moa(a,b);Moa(a+(b<<3)|0,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=33554944;c[b+4>>2]=33554944;b=f+(g<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=g<<1;e=f+(b<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=33554944;c[h+4>>2]=33554944;h=a+(d+8)|0;d=h;a=h;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(g<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(e<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;return}function Yoa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Moa(a,b);Moa(a+(b<<3)|0,b);d=a;e=b>>1;b=a;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<1;f=d+(b<<1)|0;c[f>>2]=33554944;c[f+4>>2]=33554944;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=33554944;c[g+4>>2]=33554944;g=a+8|0;a=g;d=g;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(e<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(b<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;d=a+(f<<1)|0;c[d>>2]=33554944;c[d+4>>2]=33554944;return}function Zoa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+8|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=e<<2;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;e=d+(a+4<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;return}function _oa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+8|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=e<<2;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;e=d+(a+4<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;return}function $oa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+8|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<2;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;return}function apa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=b>>1;f=a;c[f>>2]=33554944;c[f+4>>2]=33554944;f=a+8|0;c[f>>2]=33554944;c[f+4>>2]=33554944;f=d+(e<<1)|0;c[f>>2]=33554944;c[f+4>>2]=33554944;f=e+4|0;g=d+(f<<1)|0;c[g>>2]=33554944;c[g+4>>2]=33554944;g=e<<1;h=d+(g<<1)|0;c[h>>2]=33554944;c[h+4>>2]=33554944;h=g+4|0;i=d+(h<<1)|0;c[i>>2]=33554944;c[i+4>>2]=33554944;i=e*3|0;j=d+(i<<1)|0;c[j>>2]=33554944;c[j+4>>2]=33554944;j=i+4|0;k=d+(j<<1)|0;c[k>>2]=33554944;c[k+4>>2]=33554944;k=e<<2;l=d+(k<<1)|0;c[l>>2]=33554944;c[l+4>>2]=33554944;l=k+4|0;m=d+(l<<1)|0;c[m>>2]=33554944;c[m+4>>2]=33554944;m=e*5|0;n=d+(m<<1)|0;c[n>>2]=33554944;c[n+4>>2]=33554944;n=m+4|0;o=d+(n<<1)|0;c[o>>2]=33554944;c[o+4>>2]=33554944;o=e*6|0;p=d+(o<<1)|0;c[p>>2]=33554944;c[p+4>>2]=33554944;p=o+4|0;q=d+(p<<1)|0;c[q>>2]=33554944;c[q+4>>2]=33554944;q=e*7|0;r=d+(q<<1)|0;c[r>>2]=33554944;c[r+4>>2]=33554944;r=q+4|0;s=d+(r<<1)|0;c[s>>2]=33554944;c[s+4>>2]=33554944;s=b<<3;b=a+s|0;d=b;t=b;c[t>>2]=33554944;c[t+4>>2]=33554944;t=a+(s+8)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(e<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(f<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(g<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(h<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(i<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(j<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(k<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(l<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(m<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(n<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(o<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(p<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(q<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;t=d+(r<<1)|0;c[t>>2]=33554944;c[t+4>>2]=33554944;return}function bpa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+((e[d+(-f<<1)>>1]|0)+((e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))))))))))))))))))+16>>5;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function cpa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a;a=b>>1;b=d+(-a<<1)|0;e=c[b>>2]|0;f=c[b+4>>2]|0;b=d+(4-a<<1)|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=d+(8-a<<1)|0;i=c[b>>2]|0;j=c[b+4>>2]|0;b=d+(12-a<<1)|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=0;do{m=ca(b,a)|0;n=d+(m<<1)|0;c[n>>2]=e;c[n+4>>2]=f;n=d+(m+4<<1)|0;c[n>>2]=g;c[n+4>>2]=h;n=d+(m+8<<1)|0;c[n>>2]=i;c[n+4>>2]=j;n=d+(m+12<<1)|0;c[n>>2]=k;c[n+4>>2]=l;b=b+1|0;}while((b|0)<16);return}function dpa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ca(b,a)|0;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+8<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+12<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function epa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+8|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+16|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+24|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(e+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+4<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+8<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=d+(a+12<<1)|0;c[b>>2]=33489407;c[b+4>>2]=33489407;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+4<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+8<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=d+(b+12<<1)|0;c[a>>2]=33489407;c[a+4>>2]=33489407;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;e=d+(a+4<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;e=d+(a+8<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;e=d+(a+12<<1)|0;c[e>>2]=33489407;c[e+4>>2]=33489407;return}function fpa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+8|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+16|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+24|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(e+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+4<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+8<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=d+(a+12<<1)|0;c[b>>2]=33620481;c[b+4>>2]=33620481;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+4<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+8<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=d+(b+12<<1)|0;c[a>>2]=33620481;c[a+4>>2]=33620481;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;e=d+(a+4<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;e=d+(a+8<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;e=d+(a+12<<1)|0;c[e>>2]=33620481;c[e+4>>2]=33620481;return}function gpa(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a;f=c>>1;c=a+14|0;g=-f|0;h=(f<<3)-1|0;i=d+(h<<1)|0;j=d+(h-(f<<1)<<1)|0;h=a+((f*30|0)-2)|0;k=2;l=i;m=j;n=(e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0)|0;o=(e[i>>1]|0)-(e[j>>1]|0)|0;do{l=l+(f<<1)|0;m=m+(g<<1)|0;n=(ca((e[c+(k-f<<1)>>1]|0)-(e[c+(-(f+k|0)<<1)>>1]|0)|0,k)|0)+n|0;o=(ca((e[l>>1]|0)-(e[m>>1]|0)|0,k)|0)+o|0;k=k+1|0;}while((k|0)<9);k=(n*5|0)+32>>6;n=(o*5|0)+32>>6;o=k<<1;m=k*3|0;l=k<<2;c=((n+k|0)*-7|0)+16+((e[a-2+(16-f<<1)>>1]|0)+(e[h>>1]|0)<<4)|0;h=d;d=16;while(1){a=-16;g=c;while(1){j=g>>5;if(j>>>0<1024>>>0){p=j&65535}else{p=-j>>31&1023}b[h+(a+16<<1)>>1]=p;j=g+k>>5;if(j>>>0<1024>>>0){q=j&65535}else{q=-j>>31&1023}b[h+(a+17<<1)>>1]=q;j=g+o>>5;if(j>>>0<1024>>>0){r=j&65535}else{r=-j>>31&1023}b[h+(a+18<<1)>>1]=r;j=g+m>>5;if(j>>>0<1024>>>0){s=j&65535}else{s=-j>>31&1023}b[h+(a+19<<1)>>1]=s;j=a+4|0;if((j|0)<0){a=j;g=g+l|0}else{break}}g=d-1|0;if((g|0)>0){c=c+n|0;h=h+(f<<1)|0;d=g}else{break}}return}function hpa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))+8>>4;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function ipa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))))))))))))))+8>>4;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function jpa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+8|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+16|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+24|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(e+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=e<<1;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+4<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+8<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=d+(a+12<<1)|0;c[b>>2]=33554944;c[b+4>>2]=33554944;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+4<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+8<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=d+(b+12<<1)|0;c[a>>2]=33554944;c[a+4>>2]=33554944;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+4<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+8<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;e=d+(a+12<<1)|0;c[e>>2]=33554944;c[e+4>>2]=33554944;return}function kpa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a;h=f>>1;f=h<<1;i=h*3|0;j=h<<2;k=(e[g+(-h<<1)>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=k;l=k+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=l;k=l+(c[d+32>>2]|0)|0;b[g+(i-h<<1)>>1]=k;b[g+(j-h<<1)>>1]=k+(c[d+48>>2]|0);k=1-h|0;h=(e[g+(k<<1)>>1]|0)+(c[d+4>>2]|0)|0;b[a+2>>1]=h;l=h+(c[d+20>>2]|0)|0;b[g+(k+f<<1)>>1]=l;h=l+(c[d+36>>2]|0)|0;b[g+(k+i<<1)>>1]=h;b[g+(k+j<<1)>>1]=h+(c[d+52>>2]|0);h=k+1|0;l=(e[g+(h<<1)>>1]|0)+(c[d+8>>2]|0)|0;b[a+4>>1]=l;m=l+(c[d+24>>2]|0)|0;b[g+(h+f<<1)>>1]=m;l=m+(c[d+40>>2]|0)|0;b[g+(h+i<<1)>>1]=l;b[g+(h+j<<1)>>1]=l+(c[d+56>>2]|0);l=k+2|0;k=(e[g+(l<<1)>>1]|0)+(c[d+12>>2]|0)|0;b[a+6>>1]=k;a=k+(c[d+28>>2]|0)|0;b[g+(l+f<<1)>>1]=a;f=a+(c[d+44>>2]|0)|0;b[g+(l+i<<1)>>1]=f;b[g+(l+j<<1)>>1]=f+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function lpa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=a;h=f>>1;f=(e[a-2>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=f;i=f+(c[d+4>>2]|0)|0;b[a+2>>1]=i;f=i+(c[d+8>>2]|0)|0;b[a+4>>1]=f;b[a+6>>1]=f+(c[d+12>>2]|0);f=(e[g+(h-1<<1)>>1]|0)+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=f;a=f+(c[d+20>>2]|0)|0;b[g+(h+1<<1)>>1]=a;f=a+(c[d+24>>2]|0)|0;b[g+(h+2<<1)>>1]=f;b[g+(h+3<<1)>>1]=f+(c[d+28>>2]|0);f=h<<1;a=(e[g+(f-1<<1)>>1]|0)+(c[d+32>>2]|0)|0;b[g+(f<<1)>>1]=a;i=a+(c[d+36>>2]|0)|0;b[g+((f|1)<<1)>>1]=i;a=i+(c[d+40>>2]|0)|0;b[g+(f+2<<1)>>1]=a;b[g+(f+3<<1)>>1]=a+(c[d+44>>2]|0);a=f+h|0;h=(e[g+(a-1<<1)>>1]|0)+(c[d+48>>2]|0)|0;b[g+(a<<1)>>1]=h;f=h+(c[d+52>>2]|0)|0;b[g+(a+1<<1)>>1]=f;h=f+(c[d+56>>2]|0)|0;b[g+(a+2<<1)>>1]=h;b[g+(a+3<<1)>>1]=h+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function mpa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=g<<1;h=g*3|0;i=g<<2;j=g*5|0;k=g*6|0;l=g*7|0;m=g<<3;n=0;o=a+(-g<<1)|0;a=d;while(1){p=(e[o>>1]|0)+(c[a>>2]|0)|0;b[o+(g<<1)>>1]=p;q=p+(c[a+32>>2]|0)|0;b[o+(f<<1)>>1]=q;p=q+(c[a+64>>2]|0)|0;b[o+(h<<1)>>1]=p;q=p+(c[a+96>>2]|0)|0;b[o+(i<<1)>>1]=q;p=q+(c[a+128>>2]|0)|0;b[o+(j<<1)>>1]=p;q=p+(c[a+160>>2]|0)|0;b[o+(k<<1)>>1]=q;p=q+(c[a+192>>2]|0)|0;b[o+(l<<1)>>1]=p;b[o+(m<<1)>>1]=p+(c[a+224>>2]|0);p=n+1|0;if((p|0)<8){n=p;o=o+2|0;a=a+4|0}else{break}}mrc(d|0,0,256)|0;return}function npa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>1;f=0;h=a;a=d;while(1){i=(e[h-2>>1]|0)+(c[a>>2]|0)|0;b[h>>1]=i;j=i+(c[a+4>>2]|0)|0;b[h+2>>1]=j;i=j+(c[a+8>>2]|0)|0;b[h+4>>1]=i;j=i+(c[a+12>>2]|0)|0;b[h+6>>1]=j;i=j+(c[a+16>>2]|0)|0;b[h+8>>1]=i;j=i+(c[a+20>>2]|0)|0;b[h+10>>1]=j;i=j+(c[a+24>>2]|0)|0;b[h+12>>1]=i;b[h+14>>1]=i+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}mrc(d|0,0,256)|0;return}function opa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;kpa(a+(c[b>>2]|0)|0,d,e);kpa(a+(c[b+4>>2]|0)|0,d+64|0,e);kpa(a+(c[b+8>>2]|0)|0,d+128|0,e);kpa(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function ppa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;lpa(a+(c[b>>2]|0)|0,d,e);lpa(a+(c[b+4>>2]|0)|0,d+64|0,e);lpa(a+(c[b+8>>2]|0)|0,d+128|0,e);lpa(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function qpa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;kpa(a+(c[b>>2]|0)|0,d,e);kpa(a+(c[b+4>>2]|0)|0,d+64|0,e);kpa(a+(c[b+8>>2]|0)|0,d+128|0,e);kpa(a+(c[b+12>>2]|0)|0,d+192|0,e);kpa(a+(c[b+32>>2]|0)|0,d+256|0,e);kpa(a+(c[b+36>>2]|0)|0,d+320|0,e);kpa(a+(c[b+40>>2]|0)|0,d+384|0,e);kpa(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function rpa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;lpa(a+(c[b>>2]|0)|0,d,e);lpa(a+(c[b+4>>2]|0)|0,d+64|0,e);lpa(a+(c[b+8>>2]|0)|0,d+128|0,e);lpa(a+(c[b+12>>2]|0)|0,d+192|0,e);lpa(a+(c[b+32>>2]|0)|0,d+256|0,e);lpa(a+(c[b+36>>2]|0)|0,d+320|0,e);lpa(a+(c[b+40>>2]|0)|0,d+384|0,e);lpa(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function spa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{kpa(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function tpa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{lpa(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function upa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=a;e=d>>1;d=b+(-e<<1)|0;f=c[d>>2]|0;g=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+((e*3|0)<<1)|0;c[d>>2]=f;c[d+4>>2]=g;return}function vpa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0;b=a;f=d>>1;d=Erc(e[a-2>>1]|0,0,65537,65537)|0;g=a;c[g>>2]=d;c[g+4>>2]=G;g=Erc(e[b+(f-1<<1)>>1]|0,0,65537,65537)|0;d=b+(f<<1)|0;c[d>>2]=g;c[d+4>>2]=G;d=f<<1;g=Erc(e[b+(d-1<<1)>>1]|0,0,65537,65537)|0;a=b+(d<<1)|0;c[a>>2]=g;c[a+4>>2]=G;a=f*3|0;f=Erc(e[b+(a-1<<1)>>1]|0,0,65537,65537)|0;g=b+(a<<1)|0;c[g>>2]=f;c[g+4>>2]=G;return}function wpa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=(e[b+(-f<<1)>>1]|0)+4+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=b+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(d<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function xpa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=d>>1;d=e[f+(1-g<<1)>>1]|0;h=e[f+(2-g<<1)>>1]|0;i=e[f+(3-g<<1)>>1]|0;j=e[c>>1]|0;k=e[c+2>>1]|0;l=e[c+4>>1]|0;m=e[c+6>>1]|0;b[f>>1]=((e[f+(-g<<1)>>1]|0)+2+h+(d<<1)|0)>>>2;c=(d+2+i+(h<<1)|0)>>>2&65535;b[f+(g<<1)>>1]=c;b[a+2>>1]=c;c=(h+2+j+(i<<1)|0)>>>2&65535;h=g<<1;b[f+(h<<1)>>1]=c;b[f+(g+1<<1)>>1]=c;b[a+4>>1]=c;c=(i+2+k+(j<<1)|0)>>>2&65535;i=g*3|0;b[f+(i<<1)>>1]=c;b[f+((h|1)<<1)>>1]=c;b[f+(g+2<<1)>>1]=c;b[a+6>>1]=c;c=(j+2+l+(k<<1)|0)>>>2&65535;b[f+(i+1<<1)>>1]=c;b[f+(h+2<<1)>>1]=c;b[f+(g+3<<1)>>1]=c;c=(k+2+m+(l<<1)|0)>>>2&65535;b[f+(i+2<<1)>>1]=c;b[f+(h+3<<1)>>1]=c;b[f+(i+3<<1)>>1]=(l+2+(m*3|0)|0)>>>2;return}function ypa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;b[c+(o<<1)>>1]=(l+2+(n<<1)+(e[c+(o-1<<1)>>1]|0)|0)>>>2;p=(k+2+(l<<1)+n|0)>>>2&65535;b[c+(o+1<<1)>>1]=p;b[c+(m<<1)>>1]=p;p=d+2|0;n=(p+(k<<1)+l|0)>>>2&65535;b[c+(o+2<<1)>>1]=n;b[c+((m|1)<<1)>>1]=n;b[c+(f<<1)>>1]=n;n=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+3<<1)>>1]=n;b[c+(m+2<<1)>>1]=n;b[c+(f+1<<1)>>1]=n;b[c>>1]=n;n=(p+(g<<1)+h|0)>>>2&65535;b[c+(m+3<<1)>>1]=n;b[c+(f+2<<1)>>1]=n;b[a+2>>1]=n;n=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(f+3<<1)>>1]=n;b[a+4>>1]=n;b[a+6>>1]=(h+2+(i<<1)+j|0)>>>2;return}function zpa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;p=(d+1+g|0)>>>1&65535;b[c+((m|1)<<1)>>1]=p;b[c>>1]=p;p=(g+1+h|0)>>>1&65535;b[c+(m+2<<1)>>1]=p;b[a+2>>1]=p;p=(h+1+i|0)>>>1&65535;b[c+(m+3<<1)>>1]=p;b[a+4>>1]=p;b[a+6>>1]=(i+1+j|0)>>>1;a=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+1<<1)>>1]=a;b[c+(f<<1)>>1]=a;a=d+2|0;d=(a+(g<<1)+h|0)>>>2&65535;b[c+(o+2<<1)>>1]=d;b[c+(f+1<<1)>>1]=d;d=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(o+3<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;b[c+(f+3<<1)>>1]=(h+2+(i<<1)+j|0)>>>2;b[c+(m<<1)>>1]=(a+(k<<1)+l|0)>>>2;b[c+(o<<1)>>1]=(k+2+(l<<1)+n|0)>>>2;return}function Apa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[a-2>>1]|0;k=e[c+(f-1<<1)>>1]|0;l=f<<1;m=e[c+(l-1<<1)>>1]|0;n=f*3|0;o=e[c+(n-1<<1)>>1]|0;p=(d+1+j|0)>>>1&65535;b[c+(f+2<<1)>>1]=p;b[c>>1]=p;p=((d<<1)+2+g+j|0)>>>2&65535;b[c+(f+3<<1)>>1]=p;b[a+2>>1]=p;p=d+2|0;b[a+4>>1]=(p+(g<<1)+h|0)>>>2;b[a+6>>1]=(g+2+(h<<1)+i|0)>>>2;i=(j+1+k|0)>>>1&65535;b[c+(l+2<<1)>>1]=i;b[c+(f<<1)>>1]=i;i=(p+(j<<1)+k|0)>>>2&65535;b[c+(l+3<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;i=(k+1+m|0)>>>1&65535;b[c+(n+2<<1)>>1]=i;b[c+(l<<1)>>1]=i;i=(j+2+(k<<1)+m|0)>>>2&65535;b[c+(n+3<<1)>>1]=i;b[c+((l|1)<<1)>>1]=i;b[c+(n<<1)>>1]=(m+1+o|0)>>>1;b[c+(n+1<<1)>>1]=(k+2+(m<<1)+o|0)>>>2;return}function Bpa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a;g=d>>1;d=e[f+(-g<<1)>>1]|0;h=e[f+(1-g<<1)>>1]|0;i=e[f+(2-g<<1)>>1]|0;j=e[f+(3-g<<1)>>1]|0;k=e[c>>1]|0;l=e[c+2>>1]|0;m=e[c+4>>1]|0;b[f>>1]=(d+1+h|0)>>>1;c=(h+1+i|0)>>>1&65535;n=g<<1;b[f+(n<<1)>>1]=c;b[a+2>>1]=c;c=(i+1+j|0)>>>1&65535;b[f+((n|1)<<1)>>1]=c;b[a+4>>1]=c;c=(j+1+k|0)>>>1&65535;b[f+(n+2<<1)>>1]=c;b[a+6>>1]=c;b[f+(n+3<<1)>>1]=(k+1+l|0)>>>1;b[f+(g<<1)>>1]=(d+2+(h<<1)+i|0)>>>2;d=(h+2+(i<<1)+j|0)>>>2&65535;h=g*3|0;b[f+(h<<1)>>1]=d;b[f+(g+1<<1)>>1]=d;d=(i+2+(j<<1)+k|0)>>>2&65535;b[f+(h+1<<1)>>1]=d;b[f+(g+2<<1)>>1]=d;d=(j+2+(k<<1)+l|0)>>>2&65535;b[f+(h+2<<1)>>1]=d;b[f+(g+3<<1)>>1]=d;b[f+(h+3<<1)>>1]=(k+2+(l<<1)+m|0)>>>2;return}function Cpa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a;f=d>>1;d=e[a-2>>1]|0;g=e[c+(f-1<<1)>>1]|0;h=f<<1;i=e[c+(h-1<<1)>>1]|0;j=f*3|0;k=b[c+(j-1<<1)>>1]|0;l=k&65535;b[c>>1]=(d+1+g|0)>>>1;b[a+2>>1]=(d+2+(g<<1)+i|0)>>>2;d=(g+1+i|0)>>>1&65535;b[c+(f<<1)>>1]=d;b[a+4>>1]=d;d=(g+2+(i<<1)+l|0)>>>2&65535;b[c+(f+1<<1)>>1]=d;b[a+6>>1]=d;d=(i+1+l|0)>>>1&65535;b[c+(h<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;d=(i+2+l+(l<<1)|0)>>>2&65535;b[c+((h|1)<<1)>>1]=d;b[c+(f+3<<1)>>1]=d;b[c+(j+3<<1)>>1]=k;b[c+(j+2<<1)>>1]=k;b[c+(h+2<<1)>>1]=k;b[c+(j<<1)>>1]=k;b[c+(j+1<<1)>>1]=k;b[c+(h+3<<1)>>1]=k;return}function Dpa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=Erc(((e[a-2>>1]|0)+2+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;i=G;j=a;c[j>>2]=h;c[j+4>>2]=i;j=b+(f<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(d<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(g<<1)|0;c[j>>2]=h;c[j+4>>2]=i;return}function Epa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;b=a;f=d>>1;d=Erc(((e[b+(-f<<1)>>1]|0)+2+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+((f*3|0)<<1)|0;c[h>>2]=d;c[h+4>>2]=g;return}function Fpa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=134219776;c[d+4>>2]=134219776;d=b+(e<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=b+(e<<1<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=b+((e*3|0)<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;return}function Gpa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=134154239;c[d+4>>2]=134154239;d=b+(e<<1)|0;c[d>>2]=134154239;c[d+4>>2]=134154239;d=b+(e<<1<<1)|0;c[d>>2]=134154239;c[d+4>>2]=134154239;d=b+((e*3|0)<<1)|0;c[d>>2]=134154239;c[d+4>>2]=134154239;return}function Hpa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=134285313;c[d+4>>2]=134285313;d=b+(e<<1)|0;c[d>>2]=134285313;c[d+4>>2]=134285313;d=b+(e<<1<<1)|0;c[d>>2]=134285313;c[d+4>>2]=134285313;d=b+((e*3|0)<<1)|0;c[d>>2]=134285313;c[d+4>>2]=134285313;return}function Ipa(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}b[h>>1]=((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;b[a+2>>1]=(j+2+(k<<1)+l|0)>>>2;b[a+4>>1]=(k+2+(l<<1)+m|0)>>>2;b[a+6>>1]=(l+2+(m<<1)+n|0)>>>2;l=a+8|0;b[l>>1]=(m+2+(n<<1)+o|0)>>>2;b[a+10>>1]=(n+2+(o<<1)+p|0)>>>2;b[a+12>>1]=(o+2+(p<<1)+r|0)>>>2;b[a+14>>1]=((s&65535)+2+(r<<1)+p|0)>>>2;p=a;a=c[p>>2]|0;r=c[p+4>>2]|0;p=l;l=c[p>>2]|0;s=c[p+4>>2]|0;p=h+(i<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(i+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<1;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*3|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<2;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*5|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i*6|0;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*7|0;i=h+(o<<1)|0;c[i>>2]=a;c[i+4>>2]=r;r=h+(o+4<<1)|0;c[r>>2]=l;c[r+4>>2]=s;return}function Jpa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=g<<1;j=e[d+(f-1<<1)>>1]|0;k=g*3|0;l=e[d+(k-1<<1)>>1]|0;m=g<<2;n=e[d+(m-1<<1)>>1]|0;o=g*5|0;p=e[d+(o-1<<1)>>1]|0;q=g*6|0;r=e[d+(q-1<<1)>>1]|0;s=g*7|0;t=e[d+(s-1<<1)>>1]|0;u=Erc(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2,0,65537,65537)|0;h=G;v=a;c[v>>2]=u;c[v+4>>2]=h;v=a+8|0;c[v>>2]=u;c[v+4>>2]=h;h=Erc((b+2+(i<<1)+j|0)>>>2,0,65537,65537)|0;b=G;v=d+(g<<1)|0;c[v>>2]=h;c[v+4>>2]=b;v=d+(g+4<<1)|0;c[v>>2]=h;c[v+4>>2]=b;b=Erc((i+2+(j<<1)+l|0)>>>2,0,65537,65537)|0;i=G;v=d+(f<<1)|0;c[v>>2]=b;c[v+4>>2]=i;v=d+(f+4<<1)|0;c[v>>2]=b;c[v+4>>2]=i;i=Erc((j+2+(l<<1)+n|0)>>>2,0,65537,65537)|0;j=G;v=d+(k<<1)|0;c[v>>2]=i;c[v+4>>2]=j;v=d+(k+4<<1)|0;c[v>>2]=i;c[v+4>>2]=j;j=Erc((l+2+(n<<1)+p|0)>>>2,0,65537,65537)|0;l=G;v=d+(m<<1)|0;c[v>>2]=j;c[v+4>>2]=l;v=d+(m+4<<1)|0;c[v>>2]=j;c[v+4>>2]=l;l=Erc((n+2+(p<<1)+r|0)>>>2,0,65537,65537)|0;n=G;v=d+(o<<1)|0;c[v>>2]=l;c[v+4>>2]=n;v=d+(o+4<<1)|0;c[v>>2]=l;c[v+4>>2]=n;n=Erc((p+2+(r<<1)+t|0)>>>2,0,65537,65537)|0;p=G;v=d+(q<<1)|0;c[v>>2]=n;c[v+4>>2]=p;v=d+(q+4<<1)|0;c[v>>2]=n;c[v+4>>2]=p;p=Erc((r+2+(t*3|0)|0)>>>2,0,65537,65537)|0;t=G;r=d+(s<<1)|0;c[r>>2]=p;c[r+4>>2]=t;r=d+(s+4<<1)|0;c[r>>2]=p;c[r+4>>2]=t;return}function Kpa(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=g>>1;g=(d|0)!=0;if(g){d=~i;j=h+(d<<1)|0;k=a-2|0;l=d}else{d=a-2|0;j=d;k=d;l=~i}d=e[k>>1]|0;k=e[h+(i-1<<1)>>1]|0;m=e[h+((i<<1)-1<<1)>>1]|0;n=e[h+((i*3|0)-1<<1)>>1]|0;o=e[h+((i<<2)-1<<1)>>1]|0;p=e[h+((i*5|0)-1<<1)>>1]|0;q=e[h+((i*6|0)-1<<1)>>1]|0;r=e[h+((i*7|0)-1<<1)>>1]|0;s=-i|0;t=e[h+(s<<1)>>1]|0;u=e[h+(1-i<<1)>>1]|0;v=e[h+(2-i<<1)>>1]|0;w=e[h+(3-i<<1)>>1]|0;x=e[h+(4-i<<1)>>1]|0;y=e[h+(5-i<<1)>>1]|0;z=e[h+(6-i<<1)>>1]|0;A=b[h+(7-i<<1)>>1]|0;B=A&65535;if((f|0)==0){C=A}else{C=b[h+(8-i<<1)>>1]|0}A=(((e[j>>1]|0)+2+(d<<1)+k|0)>>>2)+8+((d+2+(k<<1)+m|0)>>>2)+((k+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q<<1)+r|0)>>>2)+((q+2+(r*3|0)|0)>>>2)+(((e[h+((g?l:s)<<1)>>1]|0)+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+z|0)>>>2)+((y+2+(z<<1)+B|0)>>>2)+(((C&65535)+2+(B<<1)+z|0)>>>2)>>4;z=Erc(A,(A|0)<0|0?-1:0,65537,65537)|0;A=G;B=a;c[B>>2]=z;c[B+4>>2]=A;B=a+8|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=i<<1;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;i=h+(a<<1)|0;c[i>>2]=z;c[i+4>>2]=A;i=h+(a+4<<1)|0;c[i>>2]=z;c[i+4>>2]=A;return}function Lpa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=e[g+(2-h<<1)>>1]|0;l=(i+2+(j<<1)+k|0)>>>2;m=e[g+(3-h<<1)>>1]|0;n=(j+2+(k<<1)+m|0)>>>2;o=e[g+(4-h<<1)>>1]|0;p=(k+2+(m<<1)+o|0)>>>2;k=e[g+(5-h<<1)>>1]|0;q=(m+2+(o<<1)+k|0)>>>2;m=e[g+(6-h<<1)>>1]|0;r=(o+2+(k<<1)+m|0)>>>2;o=b[g+(7-h<<1)>>1]|0;s=o&65535;t=(k+2+(m<<1)+s|0)>>>2;if((d|0)==0){u=s;v=s;w=s;x=s;y=s;z=s;A=s;B=s;C=(o&65535)+2+(s<<1)|0}else{o=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;k=e[g+(10-h<<1)>>1]|0;D=e[g+(11-h<<1)>>1]|0;E=e[g+(12-h<<1)>>1]|0;F=e[g+(13-h<<1)>>1]|0;G=e[g+(14-h<<1)>>1]|0;H=e[g+(15-h<<1)>>1]|0;u=(G+2+(H*3|0)|0)>>>2;v=(F+2+(G<<1)+H|0)>>>2;w=(E+2+(F<<1)+G|0)>>>2;x=(D+2+(E<<1)+F|0)>>>2;y=(k+2+(D<<1)+E|0)>>>2;z=(d+2+(k<<1)+D|0)>>>2;A=(o+2+(d<<1)+k|0)>>>2;B=(s+2+(o<<1)+d|0)>>>2;C=(e[g+(8-h<<1)>>1]|0)+2+(s<<1)|0}s=(C+m|0)>>>2;b[g>>1]=((((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2)+2+(l<<1)+n|0)>>>2;j=(l+2+(n<<1)+p|0)>>>2&65535;b[a+2>>1]=j;b[g+(h<<1)>>1]=j;j=(n+2+(p<<1)+q|0)>>>2&65535;b[a+4>>1]=j;b[g+(h+1<<1)>>1]=j;n=h<<1;b[g+(n<<1)>>1]=j;j=(p+2+(q<<1)+r|0)>>>2&65535;b[a+6>>1]=j;b[g+(h+2<<1)>>1]=j;b[g+((n|1)<<1)>>1]=j;p=h*3|0;b[g+(p<<1)>>1]=j;j=(q+2+(r<<1)+t|0)>>>2&65535;b[a+8>>1]=j;b[g+(h+3<<1)>>1]=j;b[g+(n+2<<1)>>1]=j;b[g+(p+1<<1)>>1]=j;q=h<<2;b[g+(q<<1)>>1]=j;j=(r+2+(t<<1)+s|0)>>>2&65535;b[a+10>>1]=j;b[g+(h+4<<1)>>1]=j;b[g+(n+3<<1)>>1]=j;b[g+(p+2<<1)>>1]=j;b[g+((q|1)<<1)>>1]=j;r=h*5|0;b[g+(r<<1)>>1]=j;j=(t+2+(s<<1)+B|0)>>>2&65535;b[a+12>>1]=j;b[g+(h+5<<1)>>1]=j;b[g+(n+4<<1)>>1]=j;b[g+(p+3<<1)>>1]=j;b[g+((q|2)<<1)>>1]=j;b[g+(r+1<<1)>>1]=j;t=h*6|0;b[g+(t<<1)>>1]=j;j=(s+2+(B<<1)+A|0)>>>2&65535;b[a+14>>1]=j;b[g+(h+6<<1)>>1]=j;b[g+(n+5<<1)>>1]=j;b[g+(p+4<<1)>>1]=j;b[g+((q|3)<<1)>>1]=j;b[g+(r+2<<1)>>1]=j;b[g+((t|1)<<1)>>1]=j;a=h*7|0;b[g+(a<<1)>>1]=j;j=(B+2+(A<<1)+z|0)>>>2&65535;b[g+(h+7<<1)>>1]=j;b[g+(n+6<<1)>>1]=j;b[g+(p+5<<1)>>1]=j;b[g+(q+4<<1)>>1]=j;b[g+(r+3<<1)>>1]=j;b[g+(t+2<<1)>>1]=j;b[g+(a+1<<1)>>1]=j;j=(A+2+(z<<1)+y|0)>>>2&65535;b[g+(n+7<<1)>>1]=j;b[g+(p+6<<1)>>1]=j;b[g+(q+5<<1)>>1]=j;b[g+(r+4<<1)>>1]=j;b[g+(t+3<<1)>>1]=j;b[g+(a+2<<1)>>1]=j;j=(z+2+(y<<1)+x|0)>>>2&65535;b[g+(p+7<<1)>>1]=j;b[g+(q+6<<1)>>1]=j;b[g+(r+5<<1)>>1]=j;b[g+(t+4<<1)>>1]=j;b[g+(a+3<<1)>>1]=j;j=(y+2+(x<<1)+w|0)>>>2&65535;b[g+(q+7<<1)>>1]=j;b[g+(r+6<<1)>>1]=j;b[g+(t+5<<1)>>1]=j;b[g+(a+4<<1)>>1]=j;j=(x+2+(w<<1)+v|0)>>>2&65535;b[g+(r+7<<1)>>1]=j;b[g+(t+6<<1)>>1]=j;b[g+(a+5<<1)>>1]=j;j=(w+2+(v<<1)+u|0)>>>2&65535;b[g+(t+7<<1)>>1]=j;b[g+(a+6<<1)>>1]=j;b[g+(a+7<<1)>>1]=(v+2+(u*3|0)|0)>>>2;return}function Mpa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;k=e[g+(v-1<<1)>>1]|0;d=i+2|0;i=(d+(w<<1)+k|0)>>>2;c=h*3|0;y=e[g+(c-1<<1)>>1]|0;z=(w+2+(k<<1)+y|0)>>>2;w=h<<2;A=e[g+(w-1<<1)>>1]|0;B=(k+2+(y<<1)+A|0)>>>2;k=h*5|0;C=e[g+(k-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*6|0;E=e[g+(y-1<<1)>>1]|0;F=(A+2+(C<<1)+E|0)>>>2;A=h*7|0;G=e[g+(A-1<<1)>>1]|0;H=(C+2+(E<<1)+G|0)>>>2;C=(d+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(A<<1)>>1]=(F+2+((E+2+(G*3|0)|0)>>>2)+(H<<1)|0)>>>2;G=(D+2+(F<<1)+H|0)>>>2&65535;b[g+(A+1<<1)>>1]=G;b[g+(y<<1)>>1]=G;G=(B+2+(D<<1)+F|0)>>>2&65535;b[g+(A+2<<1)>>1]=G;b[g+((y|1)<<1)>>1]=G;b[g+(k<<1)>>1]=G;G=(z+2+(B<<1)+D|0)>>>2&65535;b[g+(A+3<<1)>>1]=G;b[g+(y+2<<1)>>1]=G;b[g+(k+1<<1)>>1]=G;b[g+(w<<1)>>1]=G;G=(i+2+(z<<1)+B|0)>>>2&65535;b[g+(A+4<<1)>>1]=G;b[g+(y+3<<1)>>1]=G;b[g+(k+2<<1)>>1]=G;b[g+((w|1)<<1)>>1]=G;b[g+(c<<1)>>1]=G;G=(f+2+(i<<1)+z|0)>>>2&65535;b[g+(A+5<<1)>>1]=G;b[g+(y+4<<1)>>1]=G;b[g+(k+3<<1)>>1]=G;b[g+((w|2)<<1)>>1]=G;b[g+(c+1<<1)>>1]=G;b[g+(v<<1)>>1]=G;G=((f<<1)+2+i+C|0)>>>2&65535;b[g+(A+6<<1)>>1]=G;b[g+(y+5<<1)>>1]=G;b[g+(k+4<<1)>>1]=G;b[g+((w|3)<<1)>>1]=G;b[g+(c+2<<1)>>1]=G;b[g+((v|1)<<1)>>1]=G;b[g+(h<<1)>>1]=G;G=l+2|0;i=(G+f+(C<<1)|0)>>>2&65535;b[g+(A+7<<1)>>1]=i;b[g+(y+6<<1)>>1]=i;b[g+(k+5<<1)>>1]=i;b[g+(w+4<<1)>>1]=i;b[g+(c+3<<1)>>1]=i;b[g+(v+2<<1)>>1]=i;b[g+(h+1<<1)>>1]=i;b[g>>1]=i;i=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+7<<1)>>1]=i;b[g+(k+6<<1)>>1]=i;b[g+(w+5<<1)>>1]=i;b[g+(c+4<<1)>>1]=i;b[g+(v+3<<1)>>1]=i;b[g+(h+2<<1)>>1]=i;b[a+2>>1]=i;i=(G+(m<<1)+o|0)>>>2&65535;b[g+(k+7<<1)>>1]=i;b[g+(w+6<<1)>>1]=i;b[g+(c+5<<1)>>1]=i;b[g+(v+4<<1)>>1]=i;b[g+(h+3<<1)>>1]=i;b[a+4>>1]=i;i=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(w+7<<1)>>1]=i;b[g+(c+6<<1)>>1]=i;b[g+(v+5<<1)>>1]=i;b[g+(h+4<<1)>>1]=i;b[a+6>>1]=i;i=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(c+7<<1)>>1]=i;b[g+(v+6<<1)>>1]=i;b[g+(h+5<<1)>>1]=i;b[a+8>>1]=i;i=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(v+7<<1)>>1]=i;b[g+(h+6<<1)>>1]=i;b[a+10>>1]=i;i=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(h+7<<1)>>1]=i;b[a+12>>1]=i;b[a+14>>1]=(r+2+(t<<1)+(((u&65535)+2+(s<<1)+n|0)>>>2)|0)>>>2;return}function Npa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}k=((u&65535)+2+(s<<1)+n|0)>>>2;if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;n=e[g+(v-1<<1)>>1]|0;s=i+2|0;i=(s+(w<<1)+n|0)>>>2;u=h*3|0;d=e[g+(u-1<<1)>>1]|0;c=(w+2+(n<<1)+d|0)>>>2;w=h<<2;y=e[g+(w-1<<1)>>1]|0;z=(n+2+(d<<1)+y|0)>>>2;n=h*5|0;A=e[g+(n-1<<1)>>1]|0;B=(d+2+(y<<1)+A|0)>>>2;d=h*6|0;C=e[g+(d-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*7|0;E=(A+2+(C<<1)+(e[g+(y-1<<1)>>1]|0)|0)>>>2;C=(s+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(d<<1)>>1]=(z+2+(B<<1)+D|0)>>>2;b[g+(y<<1)>>1]=(B+2+(D<<1)+E|0)>>>2;E=(i+2+(c<<1)+z|0)>>>2&65535;b[g+((d|1)<<1)>>1]=E;b[g+(w<<1)>>1]=E;E=(c+2+(z<<1)+B|0)>>>2&65535;b[g+(y+1<<1)>>1]=E;b[g+(n<<1)>>1]=E;E=((f<<1)+2+i+C|0)>>>2&65535;b[g+(d+2<<1)>>1]=E;b[g+((w|1)<<1)>>1]=E;b[g+(v<<1)>>1]=E;E=(f+2+(i<<1)+c|0)>>>2&65535;b[g+(y+2<<1)>>1]=E;b[g+(n+1<<1)>>1]=E;b[g+(u<<1)>>1]=E;E=l+2|0;c=(E+f+(C<<1)|0)>>>2&65535;b[g+(y+3<<1)>>1]=c;b[g+(n+2<<1)>>1]=c;b[g+(u+1<<1)>>1]=c;b[g+(h<<1)>>1]=c;c=l+1|0;f=(c+C|0)>>>1&65535;b[g+(d+3<<1)>>1]=f;b[g+((w|2)<<1)>>1]=f;b[g+((v|1)<<1)>>1]=f;b[g>>1]=f;f=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+4<<1)>>1]=f;b[g+(n+3<<1)>>1]=f;b[g+(u+2<<1)>>1]=f;b[g+(h+1<<1)>>1]=f;f=(c+m|0)>>>1&65535;b[g+(d+4<<1)>>1]=f;b[g+((w|3)<<1)>>1]=f;b[g+(v+2<<1)>>1]=f;b[a+2>>1]=f;f=(E+(m<<1)+o|0)>>>2&65535;b[g+(y+5<<1)>>1]=f;b[g+(n+4<<1)>>1]=f;b[g+(u+3<<1)>>1]=f;b[g+(h+2<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[g+(d+5<<1)>>1]=f;b[g+(w+4<<1)>>1]=f;b[g+(v+3<<1)>>1]=f;b[a+4>>1]=f;f=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(y+6<<1)>>1]=f;b[g+(n+5<<1)>>1]=f;b[g+(u+4<<1)>>1]=f;b[g+(h+3<<1)>>1]=f;f=(o+1+p|0)>>>1&65535;b[g+(d+6<<1)>>1]=f;b[g+(w+5<<1)>>1]=f;b[g+(v+4<<1)>>1]=f;b[a+6>>1]=f;f=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(y+7<<1)>>1]=f;b[g+(n+6<<1)>>1]=f;b[g+(u+5<<1)>>1]=f;b[g+(h+4<<1)>>1]=f;f=(p+1+q|0)>>>1&65535;b[g+(d+7<<1)>>1]=f;b[g+(w+6<<1)>>1]=f;b[g+(v+5<<1)>>1]=f;b[a+8>>1]=f;f=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(n+7<<1)>>1]=f;b[g+(u+6<<1)>>1]=f;b[g+(h+5<<1)>>1]=f;f=(q+1+r|0)>>>1&65535;b[g+(w+7<<1)>>1]=f;b[g+(v+6<<1)>>1]=f;b[a+10>>1]=f;f=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(u+7<<1)>>1]=f;b[g+(h+6<<1)>>1]=f;f=(r+1+t|0)>>>1&65535;b[g+(v+7<<1)>>1]=f;b[a+12>>1]=f;b[g+(h+7<<1)>>1]=(r+2+(t<<1)+k|0)>>>2;b[a+14>>1]=(t+1+k|0)>>>1;return}function Opa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=a;g=f>>1;f=(c|0)!=0;c=-g|0;h=~g;i=e[d+(c<<1)>>1]|0;j=e[d+(1-g<<1)>>1]|0;k=((e[d+((f?h:c)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;c=e[d+(2-g<<1)>>1]|0;l=(i+2+(j<<1)+c|0)>>>2;m=e[d+(3-g<<1)>>1]|0;n=(j+2+(c<<1)+m|0)>>>2;j=e[d+(4-g<<1)>>1]|0;o=(c+2+(m<<1)+j|0)>>>2;c=e[d+(5-g<<1)>>1]|0;p=(m+2+(j<<1)+c|0)>>>2;m=e[d+(6-g<<1)>>1]|0;q=(j+2+(c<<1)+m|0)>>>2;j=(c+2+(m<<1)+(e[d+(7-g<<1)>>1]|0)|0)>>>2;if(f){f=d+(h<<1)|0;r=f;s=a-2|0;t=f}else{f=a-2|0;r=f;s=f;t=d+(h<<1)|0}h=e[s>>1]|0;s=e[d+(g-1<<1)>>1]|0;f=((e[r>>1]|0)+2+(h<<1)+s|0)>>>2;r=g<<1;m=e[d+(r-1<<1)>>1]|0;c=h+2|0;h=(c+(s<<1)+m|0)>>>2;u=g*3|0;v=e[d+(u-1<<1)>>1]|0;w=(s+2+(m<<1)+v|0)>>>2;s=g<<2;x=e[d+(s-1<<1)>>1]|0;y=(m+2+(v<<1)+x|0)>>>2;m=g*5|0;z=e[d+(m-1<<1)>>1]|0;A=(v+2+(x<<1)+z|0)>>>2;v=g*6|0;B=e[d+(v-1<<1)>>1]|0;C=(x+2+(z<<1)+B|0)>>>2;x=g*7|0;D=e[d+(x-1<<1)>>1]|0;E=(z+2+(B<<1)+D|0)>>>2;z=(B+2+(D*3|0)|0)>>>2;D=(c+((e[t>>1]|0)<<1)+i|0)>>>2;b[d+(x<<1)>>1]=(z+1+E|0)>>>1;b[d+(x+1<<1)>>1]=(C+2+z+(E<<1)|0)>>>2;z=(C+1+E|0)>>>1&65535;b[d+(x+2<<1)>>1]=z;b[d+(v<<1)>>1]=z;z=(A+2+(C<<1)+E|0)>>>2&65535;b[d+(x+3<<1)>>1]=z;b[d+((v|1)<<1)>>1]=z;z=(A+1+C|0)>>>1&65535;b[d+(x+4<<1)>>1]=z;b[d+(v+2<<1)>>1]=z;b[d+(m<<1)>>1]=z;z=(y+2+(A<<1)+C|0)>>>2&65535;b[d+(x+5<<1)>>1]=z;b[d+(v+3<<1)>>1]=z;b[d+(m+1<<1)>>1]=z;z=(y+1+A|0)>>>1&65535;b[d+(x+6<<1)>>1]=z;b[d+(v+4<<1)>>1]=z;b[d+(m+2<<1)>>1]=z;b[d+(s<<1)>>1]=z;z=(w+2+(y<<1)+A|0)>>>2&65535;b[d+(x+7<<1)>>1]=z;b[d+(v+5<<1)>>1]=z;b[d+(m+3<<1)>>1]=z;b[d+((s|1)<<1)>>1]=z;z=(w+1+y|0)>>>1&65535;b[d+(v+6<<1)>>1]=z;b[d+(m+4<<1)>>1]=z;b[d+((s|2)<<1)>>1]=z;b[d+(u<<1)>>1]=z;z=(h+2+(w<<1)+y|0)>>>2&65535;b[d+(v+7<<1)>>1]=z;b[d+(m+5<<1)>>1]=z;b[d+((s|3)<<1)>>1]=z;b[d+(u+1<<1)>>1]=z;z=(h+1+w|0)>>>1&65535;b[d+(m+6<<1)>>1]=z;b[d+(s+4<<1)>>1]=z;b[d+(u+2<<1)>>1]=z;b[d+(r<<1)>>1]=z;z=(f+2+(h<<1)+w|0)>>>2&65535;b[d+(m+7<<1)>>1]=z;b[d+(s+5<<1)>>1]=z;b[d+(u+3<<1)>>1]=z;b[d+((r|1)<<1)>>1]=z;z=f+1|0;m=(z+h|0)>>>1&65535;b[d+(s+6<<1)>>1]=m;b[d+(u+4<<1)>>1]=m;b[d+(r+2<<1)>>1]=m;b[d+(g<<1)>>1]=m;m=((f<<1)+2+h+D|0)>>>2&65535;b[d+(s+7<<1)>>1]=m;b[d+(u+5<<1)>>1]=m;b[d+(r+3<<1)>>1]=m;b[d+(g+1<<1)>>1]=m;m=(z+D|0)>>>1&65535;b[d+(u+6<<1)>>1]=m;b[d+(r+4<<1)>>1]=m;b[d+(g+2<<1)>>1]=m;b[d>>1]=m;m=k+2|0;z=(m+f+(D<<1)|0)>>>2&65535;b[d+(u+7<<1)>>1]=z;b[d+(r+5<<1)>>1]=z;b[d+(g+3<<1)>>1]=z;b[a+2>>1]=z;z=((k<<1)+2+l+D|0)>>>2&65535;b[d+(r+6<<1)>>1]=z;b[d+(g+4<<1)>>1]=z;b[a+4>>1]=z;z=(m+(l<<1)+n|0)>>>2&65535;b[d+(r+7<<1)>>1]=z;b[d+(g+5<<1)>>1]=z;b[a+6>>1]=z;z=(l+2+(n<<1)+o|0)>>>2&65535;b[d+(g+6<<1)>>1]=z;b[a+8>>1]=z;z=(n+2+(o<<1)+p|0)>>>2&65535;b[d+(g+7<<1)>>1]=z;b[a+10>>1]=z;b[a+12>>1]=(o+2+(p<<1)+q|0)>>>2;b[a+14>>1]=(p+2+(q<<1)+j|0)>>>2;return}function Ppa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;f=e[g+(2-h<<1)>>1]|0;c=(i+2+(j<<1)+f|0)>>>2;i=e[g+(3-h<<1)>>1]|0;l=(j+2+(f<<1)+i|0)>>>2;j=e[g+(4-h<<1)>>1]|0;m=(f+2+(i<<1)+j|0)>>>2;f=e[g+(5-h<<1)>>1]|0;n=(i+2+(j<<1)+f|0)>>>2;i=e[g+(6-h<<1)>>1]|0;o=(j+2+(f<<1)+i|0)>>>2;j=b[g+(7-h<<1)>>1]|0;p=j&65535;q=(f+2+(i<<1)+p|0)>>>2;if((d|0)==0){r=p;s=p;t=p;u=p;v=p;w=(j&65535)+2+(p<<1)|0}else{j=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;f=e[g+(10-h<<1)>>1]|0;x=e[g+(11-h<<1)>>1]|0;y=e[g+(12-h<<1)>>1]|0;r=(x+2+(y<<1)+(e[g+(13-h<<1)>>1]|0)|0)>>>2;s=(f+2+(x<<1)+y|0)>>>2;t=(d+2+(f<<1)+x|0)>>>2;u=(j+2+(d<<1)+f|0)>>>2;v=(p+2+(j<<1)+d|0)>>>2;w=(e[g+(8-h<<1)>>1]|0)+2+(p<<1)|0}p=(w+i|0)>>>2;b[g>>1]=(k+1+c|0)>>>1;b[g+(h<<1)>>1]=(k+2+(c<<1)+l|0)>>>2;k=(c+1+l|0)>>>1&65535;b[a+2>>1]=k;i=h<<1;b[g+(i<<1)>>1]=k;k=(c+2+(l<<1)+m|0)>>>2&65535;b[g+(h+1<<1)>>1]=k;c=h*3|0;b[g+(c<<1)>>1]=k;k=(l+1+m|0)>>>1&65535;b[a+4>>1]=k;b[g+((i|1)<<1)>>1]=k;w=h<<2;b[g+(w<<1)>>1]=k;k=(l+2+(m<<1)+n|0)>>>2&65535;b[g+(h+2<<1)>>1]=k;b[g+(c+1<<1)>>1]=k;l=h*5|0;b[g+(l<<1)>>1]=k;k=(m+1+n|0)>>>1&65535;b[a+6>>1]=k;b[g+(i+2<<1)>>1]=k;b[g+((w|1)<<1)>>1]=k;d=h*6|0;b[g+(d<<1)>>1]=k;k=(m+2+(n<<1)+o|0)>>>2&65535;b[g+(h+3<<1)>>1]=k;b[g+(c+2<<1)>>1]=k;b[g+(l+1<<1)>>1]=k;m=h*7|0;b[g+(m<<1)>>1]=k;k=(n+1+o|0)>>>1&65535;b[a+8>>1]=k;b[g+(i+3<<1)>>1]=k;b[g+((w|2)<<1)>>1]=k;b[g+((d|1)<<1)>>1]=k;k=(n+2+(o<<1)+q|0)>>>2&65535;b[g+(h+4<<1)>>1]=k;b[g+(c+3<<1)>>1]=k;b[g+(l+2<<1)>>1]=k;b[g+(m+1<<1)>>1]=k;k=(o+1+q|0)>>>1&65535;b[a+10>>1]=k;b[g+(i+4<<1)>>1]=k;b[g+((w|3)<<1)>>1]=k;b[g+(d+2<<1)>>1]=k;k=(o+2+(q<<1)+p|0)>>>2&65535;b[g+(h+5<<1)>>1]=k;b[g+(c+4<<1)>>1]=k;b[g+(l+3<<1)>>1]=k;b[g+(m+2<<1)>>1]=k;k=(q+1+p|0)>>>1&65535;b[a+12>>1]=k;b[g+(i+5<<1)>>1]=k;b[g+(w+4<<1)>>1]=k;b[g+(d+3<<1)>>1]=k;k=(q+2+(p<<1)+v|0)>>>2&65535;b[g+(h+6<<1)>>1]=k;b[g+(c+5<<1)>>1]=k;b[g+(l+4<<1)>>1]=k;b[g+(m+3<<1)>>1]=k;k=(p+1+v|0)>>>1&65535;b[a+14>>1]=k;b[g+(i+6<<1)>>1]=k;b[g+(w+5<<1)>>1]=k;b[g+(d+4<<1)>>1]=k;k=(p+2+(v<<1)+u|0)>>>2&65535;b[g+(h+7<<1)>>1]=k;b[g+(c+6<<1)>>1]=k;b[g+(l+5<<1)>>1]=k;b[g+(m+4<<1)>>1]=k;k=(v+1+u|0)>>>1&65535;b[g+(i+7<<1)>>1]=k;b[g+(w+6<<1)>>1]=k;b[g+(d+5<<1)>>1]=k;k=(v+2+(u<<1)+t|0)>>>2&65535;b[g+(c+7<<1)>>1]=k;b[g+(l+6<<1)>>1]=k;b[g+(m+5<<1)>>1]=k;k=(u+1+t|0)>>>1&65535;b[g+(w+7<<1)>>1]=k;b[g+(d+6<<1)>>1]=k;k=(u+2+(t<<1)+s|0)>>>2&65535;b[g+(l+7<<1)>>1]=k;b[g+(m+6<<1)>>1]=k;b[g+(d+7<<1)>>1]=(t+1+s|0)>>>1;b[g+(m+7<<1)>>1]=(t+2+(s<<1)+r|0)>>>2;return}function Qpa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a;g=f>>1;if((c|0)==0){c=a-2|0;h=c;i=c}else{h=d+(~g<<1)|0;i=a-2|0}c=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=((e[h>>1]|0)+2+(c<<1)+i|0)>>>2;h=g<<1;j=e[d+(h-1<<1)>>1]|0;k=(c+2+(i<<1)+j|0)>>>2;c=g*3|0;l=e[d+(c-1<<1)>>1]|0;m=(i+2+(j<<1)+l|0)>>>2;i=g<<2;n=e[d+(i-1<<1)>>1]|0;o=(j+2+(l<<1)+n|0)>>>2;j=g*5|0;p=e[d+(j-1<<1)>>1]|0;q=(l+2+(n<<1)+p|0)>>>2;l=g*6|0;r=e[d+(l-1<<1)>>1]|0;s=(n+2+(p<<1)+r|0)>>>2;n=g*7|0;t=e[d+(n-1<<1)>>1]|0;u=(p+2+(r<<1)+t|0)>>>2;p=(r+2+(t*3|0)|0)>>>2;b[d>>1]=(f+1+k|0)>>>1;b[a+2>>1]=(f+2+(k<<1)+m|0)>>>2;f=(k+1+m|0)>>>1&65535;b[a+4>>1]=f;b[d+(g<<1)>>1]=f;f=(k+2+(m<<1)+o|0)>>>2&65535;b[a+6>>1]=f;b[d+(g+1<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[a+8>>1]=f;b[d+(g+2<<1)>>1]=f;b[d+(h<<1)>>1]=f;f=(m+2+(o<<1)+q|0)>>>2&65535;b[a+10>>1]=f;b[d+(g+3<<1)>>1]=f;b[d+((h|1)<<1)>>1]=f;f=(o+1+q|0)>>>1&65535;b[a+12>>1]=f;b[d+(g+4<<1)>>1]=f;b[d+(h+2<<1)>>1]=f;b[d+(c<<1)>>1]=f;f=(o+2+(q<<1)+s|0)>>>2&65535;b[a+14>>1]=f;b[d+(g+5<<1)>>1]=f;b[d+(h+3<<1)>>1]=f;b[d+(c+1<<1)>>1]=f;f=(q+1+s|0)>>>1&65535;b[d+(g+6<<1)>>1]=f;b[d+(h+4<<1)>>1]=f;b[d+(c+2<<1)>>1]=f;b[d+(i<<1)>>1]=f;f=(q+2+(s<<1)+u|0)>>>2&65535;b[d+(g+7<<1)>>1]=f;b[d+(h+5<<1)>>1]=f;b[d+(c+3<<1)>>1]=f;b[d+((i|1)<<1)>>1]=f;f=(s+1+u|0)>>>1&65535;b[d+(h+6<<1)>>1]=f;b[d+(c+4<<1)>>1]=f;b[d+((i|2)<<1)>>1]=f;b[d+(j<<1)>>1]=f;f=(s+2+p+(u<<1)|0)>>>2&65535;b[d+(h+7<<1)>>1]=f;b[d+(c+5<<1)>>1]=f;b[d+((i|3)<<1)>>1]=f;b[d+(j+1<<1)>>1]=f;f=(p+1+u|0)>>>1&65535;b[d+(c+6<<1)>>1]=f;b[d+(i+4<<1)>>1]=f;b[d+(j+2<<1)>>1]=f;b[d+(l<<1)>>1]=f;f=(u+2+(p*3|0)|0)>>>2&65535;b[d+(c+7<<1)>>1]=f;b[d+(i+5<<1)>>1]=f;b[d+(j+3<<1)>>1]=f;b[d+((l|1)<<1)>>1]=f;f=p&65535;b[d+(n+7<<1)>>1]=f;b[d+(l+7<<1)>>1]=f;b[d+(j+7<<1)>>1]=f;b[d+(i+7<<1)>>1]=f;b[d+(n+6<<1)>>1]=f;b[d+(l+6<<1)>>1]=f;b[d+(j+6<<1)>>1]=f;b[d+(i+6<<1)>>1]=f;b[d+(n+5<<1)>>1]=f;b[d+(l+5<<1)>>1]=f;b[d+(j+5<<1)>>1]=f;b[d+(n+4<<1)>>1]=f;b[d+(l+4<<1)>>1]=f;b[d+(j+4<<1)>>1]=f;b[d+(n+3<<1)>>1]=f;b[d+(l+3<<1)>>1]=f;b[d+(n+2<<1)>>1]=f;b[d+(l+2<<1)>>1]=f;b[d+(n+1<<1)>>1]=f;b[d+(n<<1)>>1]=f;return}function Rpa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=e[d+((g<<1)-1<<1)>>1]|0;j=e[d+((g*3|0)-1<<1)>>1]|0;k=e[d+((g<<2)-1<<1)>>1]|0;l=e[d+((g*5|0)-1<<1)>>1]|0;m=e[d+((g*6|0)-1<<1)>>1]|0;n=e[d+((g*7|0)-1<<1)>>1]|0;o=(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2)+4+((b+2+(i<<1)+f|0)>>>2)+((i+2+(f<<1)+j|0)>>>2)+((f+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n*3|0)|0)>>>2)>>3;n=Erc(o,(o|0)<0|0?-1:0,65537,65537)|0;o=G;m=a;c[m>>2]=n;c[m+4>>2]=o;m=a+8|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=g<<1;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;g=d+(a<<1)|0;c[g>>2]=n;c[g+4>>2]=o;g=d+(a+4<<1)|0;c[g>>2]=n;c[g+4>>2]=o;return}function Spa(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}q=(((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2)+4+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+r|0)>>>2)+(((s&65535)+2+(r<<1)+p|0)>>>2)>>3;p=Erc(q,(q|0)<0|0?-1:0,65537,65537)|0;q=G;r=a;c[r>>2]=p;c[r+4>>2]=q;r=a+8|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=i<<1;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;i=h+(a<<1)|0;c[i>>2]=p;c[i+4>>2]=q;i=h+(a+4<<1)|0;c[i>>2]=p;c[i+4>>2]=q;return}function Tpa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;b=e>>1;e=a;c[e>>2]=134219776;c[e+4>>2]=134219776;e=a+8|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(b<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(b+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=b<<1;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e+b|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;return}function Upa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Vpa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=Erc(e[a-2>>1]|0,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=a+8|0;c[h>>2]=b;c[h+4>>2]=g;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;b=d+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(f+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f<<1;b=Erc(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=G;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*3|0;a=Erc(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;b=G;h=d+(g<<1)|0;c[h>>2]=a;c[h+4>>2]=b;h=d+(g+4<<1)|0;c[h>>2]=a;c[h+4>>2]=b;b=f<<2;h=Erc(e[d+(b-1<<1)>>1]|0,0,65537,65537)|0;a=G;g=d+(b<<1)|0;c[g>>2]=h;c[g+4>>2]=a;g=d+(b+4<<1)|0;c[g>>2]=h;c[g+4>>2]=a;a=f*5|0;g=Erc(e[d+(a-1<<1)>>1]|0,0,65537,65537)|0;h=G;b=d+(a<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(a+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f*6|0;b=Erc(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=G;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*7|0;f=Erc(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;a=G;b=d+(g<<1)|0;c[b>>2]=f;c[b+4>>2]=a;b=d+(g+4<<1)|0;c[b>>2]=f;c[b+4>>2]=a;return}function Wpa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<3;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+((b|4)<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*9|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*10|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*11|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*12|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*13|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*14|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*15|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function Xpa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ca(b,a)|0;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Ypa(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a;f=c>>1;c=a+6|0;g=(f<<2)-1|0;h=g-(f<<1)|0;i=g+f|0;j=h-f|0;k=i+f|0;l=j-f|0;m=e[d+(k+f<<1)>>1]|0;n=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=(((m-(e[d+(l-f<<1)>>1]|0)<<2)+((((e[d+(k<<1)>>1]|0)-(e[d+(l<<1)>>1]|0)|0)*3|0)+(((e[d+(i<<1)>>1]|0)-(e[d+(j<<1)>>1]|0)<<1)+((e[d+(g<<1)>>1]|0)-(e[d+(h<<1)>>1]|0))))|0)*17|0)+16>>5;h=n<<1;g=n*3|0;j=n<<2;i=n*5|0;l=n*6|0;k=n*7|0;o=d;d=((c+n|0)*-3|0)+16+((e[a-2+(8-f<<1)>>1]|0)+m<<4)|0;m=8;while(1){a=d>>5;if(a>>>0<4096>>>0){p=a&65535}else{p=-a>>31&4095}b[o>>1]=p;a=d+n>>5;if(a>>>0<4096>>>0){q=a&65535}else{q=-a>>31&4095}b[o+2>>1]=q;a=d+h>>5;if(a>>>0<4096>>>0){r=a&65535}else{r=-a>>31&4095}b[o+4>>1]=r;a=d+g>>5;if(a>>>0<4096>>>0){s=a&65535}else{s=-a>>31&4095}b[o+6>>1]=s;a=d+j>>5;if(a>>>0<4096>>>0){t=a&65535}else{t=-a>>31&4095}b[o+8>>1]=t;a=d+i>>5;if(a>>>0<4096>>>0){u=a&65535}else{u=-a>>31&4095}b[o+10>>1]=u;a=d+l>>5;if(a>>>0<4096>>>0){v=a&65535}else{v=-a>>31&4095}b[o+12>>1]=v;a=d+k>>5;if(a>>>0<4096>>>0){w=a&65535}else{w=-a>>31&4095}b[o+14>>1]=w;a=m-1|0;if((a|0)>0){o=o+(f<<1)|0;d=d+c|0;m=a}else{break}}return}function Zpa(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a;f=c>>1;c=a+6|0;g=-f|0;h=(f<<3)-1|0;i=h-(f<<1)|0;j=h+f|0;k=i-f|0;l=j+f|0;m=k-f|0;n=a+((f*6|0)-2)|0;o=a+((f*22|0)-2)|0;p=f<<1;q=g<<1;r=p+f|0;s=q-f|0;t=b[o+(r+f<<1)>>1]|0;u=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=((((t&65535)-(e[n+(s-f<<1)>>1]|0)<<3)+((((e[o+(r<<1)>>1]|0)-(e[n+(s<<1)>>1]|0)|0)*7|0)+((((e[o+(p<<1)>>1]|0)-(e[n+(q<<1)>>1]|0)|0)*6|0)+((((e[o+(f<<1)>>1]|0)-(e[n+(g<<1)>>1]|0)|0)*5|0)+(((e[d+(l+f<<1)>>1]|0)-(e[d+(m-f<<1)>>1]|0)<<2)+((((e[d+(l<<1)>>1]|0)-(e[d+(m<<1)>>1]|0)|0)*3|0)+(((e[d+(j<<1)>>1]|0)-(e[d+(k<<1)>>1]|0)<<1)+((e[d+(h<<1)>>1]|0)-(e[d+(i<<1)>>1]|0))))))))|0)*5|0)+32>>6;i=u*3|0;h=u<<1;k=u<<2;j=u*5|0;m=u*6|0;l=u*7|0;g=d;d=16-i+(c*-7|0)+((e[a+(-2-(f<<1)+16)>>1]|0)+(t&65535)<<4)|0;t=16;while(1){a=d>>5;if(a>>>0<4096>>>0){v=a&65535}else{v=-a>>31&4095}b[g>>1]=v;a=d+u>>5;if(a>>>0<4096>>>0){w=a&65535}else{w=-a>>31&4095}b[g+2>>1]=w;a=d+h>>5;if(a>>>0<4096>>>0){x=a&65535}else{x=-a>>31&4095}b[g+4>>1]=x;a=d+i>>5;if(a>>>0<4096>>>0){y=a&65535}else{y=-a>>31&4095}b[g+6>>1]=y;a=d+k>>5;if(a>>>0<4096>>>0){z=a&65535}else{z=-a>>31&4095}b[g+8>>1]=z;a=d+j>>5;if(a>>>0<4096>>>0){A=a&65535}else{A=-a>>31&4095}b[g+10>>1]=A;a=d+m>>5;if(a>>>0<4096>>>0){B=a&65535}else{B=-a>>31&4095}b[g+12>>1]=B;a=d+l>>5;if(a>>>0<4096>>>0){C=a&65535}else{C=-a>>31&4095}b[g+14>>1]=C;a=t-1|0;if((a|0)>0){g=g+(f<<1)|0;d=d+c|0;t=a}else{break}}return}function _pa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=(e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+(e[d+(4-f<<1)>>1]|0)))|0;l=f*7|0;m=(e[d+(l-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;n=(e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+((e[a-2>>1]|0)+(e[d+(-f<<1)>>1]|0))+(e[d+(1-f<<1)>>1]|0))+(e[d+(2-f<<1)>>1]|0))+(e[d+(3-f<<1)>>1]|0)+4>>3;o=Erc(n,(n|0)<0|0?-1:0,65537,65537)|0;n=G;p=Erc((k+2|0)>>>2,0,65537,65537)|0;q=G;r=m+4+k>>3;k=a;c[k>>2]=o;c[k+4>>2]=n;k=a+8|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(f<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(f+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(h<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(h+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(j<<1)|0;c[k>>2]=o;c[k+4>>2]=n;n=d+(j+4<<1)|0;c[n>>2]=p;c[n+4>>2]=q;q=Erc((m+2|0)>>>2,0,65537,65537)|0;m=G;n=Erc(r,(r|0)<0|0?-1:0,65537,65537)|0;r=G;p=d+(b<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(b+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(g<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(g+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(i<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(i+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(l<<1)|0;c[p>>2]=q;c[p+4>>2]=m;m=d+(l+4<<1)|0;c[m>>2]=n;c[m+4>>2]=r;return}function $pa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=f*7|0;l=(e[d+(k-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;m=Erc(((e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))+2|0)>>>2,0,65537,65537)|0;n=G;o=a;c[o>>2]=m;c[o+4>>2]=n;o=a+8|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;n=Erc((l+2|0)>>>2,0,65537,65537)|0;l=G;o=d+(b<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(b+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;return}function aqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=Erc(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=G;i=Erc((g+2|0)>>>2,0,65537,65537)|0;g=G;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function bqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;aqa(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function cqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;_pa(a,b);d=a;f=b>>1;b=Erc(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function dqa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;$pa(a,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=134219776;c[b+4>>2]=134219776;b=f+(g<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=g<<1;e=f+(b<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=134219776;c[h+4>>2]=134219776;h=a+(d+8)|0;d=h;a=h;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(g<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;return}function eqa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;$pa(a,b);d=a;e=b>>1;b=a;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<1;f=d+(b<<1)|0;c[f>>2]=134219776;c[f+4>>2]=134219776;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=134219776;c[g+4>>2]=134219776;g=a+8|0;a=g;d=g;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(e<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(b<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(f<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;return}function fqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=0;g=0;h=0;i=0;j=0;k=0;do{l=e[d+((ca(k,f)|0)-1<<1)>>1]|0;j=l+j+(e[d+(k-f<<1)>>1]|0)|0;l=k+4|0;i=(e[d+(l-f<<1)>>1]|0)+i|0;h=(e[d+((ca(l,f)|0)-1<<1)>>1]|0)+h|0;g=(e[d+((ca(k+8|0,f)|0)-1<<1)>>1]|0)+g|0;b=(e[d+((ca(k+12|0,f)|0)-1<<1)>>1]|0)+b|0;k=k+1|0;}while((k|0)<4);k=j+4>>3;j=Erc(k,(k|0)<0|0?-1:0,65537,65537)|0;k=G;l=i+2>>2;m=Erc(l,(l|0)<0|0?-1:0,65537,65537)|0;l=G;n=h+2>>2;o=h+4+i>>3;h=g+2>>2;p=g+4+i>>3;g=b+2>>2;q=b+4+i>>3;i=a;c[i>>2]=j;c[i+4>>2]=k;i=a+8|0;c[i>>2]=m;c[i+4>>2]=l;i=d+(f<<1)|0;c[i>>2]=j;c[i+4>>2]=k;i=d+(f+4<<1)|0;c[i>>2]=m;c[i+4>>2]=l;i=f<<1;a=d+(i<<1)|0;c[a>>2]=j;c[a+4>>2]=k;a=d+(i+4<<1)|0;c[a>>2]=m;c[a+4>>2]=l;a=f*3|0;i=d+(a<<1)|0;c[i>>2]=j;c[i+4>>2]=k;k=d+(a+4<<1)|0;c[k>>2]=m;c[k+4>>2]=l;l=Erc(n,(n|0)<0|0?-1:0,65537,65537)|0;n=G;k=Erc(o,(o|0)<0|0?-1:0,65537,65537)|0;o=G;m=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;a=Erc(p,(p|0)<0|0?-1:0,65537,65537)|0;p=G;i=Erc(g,(g|0)<0|0?-1:0,65537,65537)|0;g=G;j=Erc(q,(q|0)<0|0?-1:0,65537,65537)|0;q=G;b=f<<2;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*5|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;b=d+(r+4<<1)|0;c[b>>2]=k;c[b+4>>2]=o;b=f*6|0;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*7|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;n=d+(r+4<<1)|0;c[n>>2]=k;c[n+4>>2]=o;o=f<<3;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+((o|4)<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*9|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;o=d+(n+4<<1)|0;c[o>>2]=a;c[o+4>>2]=p;o=f*10|0;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+(o+4<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*11|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;h=d+(n+4<<1)|0;c[h>>2]=a;c[h+4>>2]=p;p=f*12|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*13|0;p=d+(h<<1)|0;c[p>>2]=i;c[p+4>>2]=g;p=d+(h+4<<1)|0;c[p>>2]=j;c[p+4>>2]=q;p=f*14|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*15|0;f=d+(h<<1)|0;c[f>>2]=i;c[f+4>>2]=g;g=d+(h+4<<1)|0;c[g>>2]=j;c[g+4>>2]=q;return}function gqa(a,b){a=a|0;b=b|0;$pa(a,b);$pa(a+(b<<3)|0,b);return}function hqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=Erc(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=G;i=Erc((g+2|0)>>>2,0,65537,65537)|0;g=G;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<3;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+((j|4)<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*9|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*10|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*11|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*12|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*13|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*14|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*15|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function iqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;hqa(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function jqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;fqa(a,b);d=a;f=b>>1;b=Erc(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function kqa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;$pa(a,b);$pa(a+(b<<3)|0,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=134219776;c[b+4>>2]=134219776;b=f+(g<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=g<<1;e=f+(b<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=134219776;c[h+4>>2]=134219776;h=a+(d+8)|0;d=h;a=h;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(g<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(e<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;return}function lqa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;$pa(a,b);$pa(a+(b<<3)|0,b);d=a;e=b>>1;b=a;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<1;f=d+(b<<1)|0;c[f>>2]=134219776;c[f+4>>2]=134219776;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=134219776;c[g+4>>2]=134219776;g=a+8|0;a=g;d=g;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(e<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(b<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;d=a+(f<<1)|0;c[d>>2]=134219776;c[d+4>>2]=134219776;return}function mqa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+8|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=e<<2;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;e=d+(a+4<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;return}function nqa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+8|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=e<<2;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;e=d+(a+4<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;return}function oqa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+8|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<2;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;return}function pqa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=b>>1;f=a;c[f>>2]=134219776;c[f+4>>2]=134219776;f=a+8|0;c[f>>2]=134219776;c[f+4>>2]=134219776;f=d+(e<<1)|0;c[f>>2]=134219776;c[f+4>>2]=134219776;f=e+4|0;g=d+(f<<1)|0;c[g>>2]=134219776;c[g+4>>2]=134219776;g=e<<1;h=d+(g<<1)|0;c[h>>2]=134219776;c[h+4>>2]=134219776;h=g+4|0;i=d+(h<<1)|0;c[i>>2]=134219776;c[i+4>>2]=134219776;i=e*3|0;j=d+(i<<1)|0;c[j>>2]=134219776;c[j+4>>2]=134219776;j=i+4|0;k=d+(j<<1)|0;c[k>>2]=134219776;c[k+4>>2]=134219776;k=e<<2;l=d+(k<<1)|0;c[l>>2]=134219776;c[l+4>>2]=134219776;l=k+4|0;m=d+(l<<1)|0;c[m>>2]=134219776;c[m+4>>2]=134219776;m=e*5|0;n=d+(m<<1)|0;c[n>>2]=134219776;c[n+4>>2]=134219776;n=m+4|0;o=d+(n<<1)|0;c[o>>2]=134219776;c[o+4>>2]=134219776;o=e*6|0;p=d+(o<<1)|0;c[p>>2]=134219776;c[p+4>>2]=134219776;p=o+4|0;q=d+(p<<1)|0;c[q>>2]=134219776;c[q+4>>2]=134219776;q=e*7|0;r=d+(q<<1)|0;c[r>>2]=134219776;c[r+4>>2]=134219776;r=q+4|0;s=d+(r<<1)|0;c[s>>2]=134219776;c[s+4>>2]=134219776;s=b<<3;b=a+s|0;d=b;t=b;c[t>>2]=134219776;c[t+4>>2]=134219776;t=a+(s+8)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(e<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(f<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(g<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(h<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(i<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(j<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(k<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(l<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(m<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(n<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(o<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(p<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(q<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;t=d+(r<<1)|0;c[t>>2]=134219776;c[t+4>>2]=134219776;return}function qqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+((e[d+(-f<<1)>>1]|0)+((e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))))))))))))))))))+16>>5;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function rqa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a;a=b>>1;b=d+(-a<<1)|0;e=c[b>>2]|0;f=c[b+4>>2]|0;b=d+(4-a<<1)|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=d+(8-a<<1)|0;i=c[b>>2]|0;j=c[b+4>>2]|0;b=d+(12-a<<1)|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=0;do{m=ca(b,a)|0;n=d+(m<<1)|0;c[n>>2]=e;c[n+4>>2]=f;n=d+(m+4<<1)|0;c[n>>2]=g;c[n+4>>2]=h;n=d+(m+8<<1)|0;c[n>>2]=i;c[n+4>>2]=j;n=d+(m+12<<1)|0;c[n>>2]=k;c[n+4>>2]=l;b=b+1|0;}while((b|0)<16);return}function sqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ca(b,a)|0;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+8<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+12<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function tqa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+8|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+16|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+24|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(e+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+4<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+8<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=d+(a+12<<1)|0;c[b>>2]=134154239;c[b+4>>2]=134154239;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+4<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+8<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=d+(b+12<<1)|0;c[a>>2]=134154239;c[a+4>>2]=134154239;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;e=d+(a+4<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;e=d+(a+8<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;e=d+(a+12<<1)|0;c[e>>2]=134154239;c[e+4>>2]=134154239;return}function uqa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+8|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+16|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+24|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(e+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+4<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+8<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=d+(a+12<<1)|0;c[b>>2]=134285313;c[b+4>>2]=134285313;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+4<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+8<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=d+(b+12<<1)|0;c[a>>2]=134285313;c[a+4>>2]=134285313;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;e=d+(a+4<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;e=d+(a+8<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;e=d+(a+12<<1)|0;c[e>>2]=134285313;c[e+4>>2]=134285313;return}function vqa(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a;f=c>>1;c=a+14|0;g=-f|0;h=(f<<3)-1|0;i=d+(h<<1)|0;j=d+(h-(f<<1)<<1)|0;h=a+((f*30|0)-2)|0;k=2;l=i;m=j;n=(e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0)|0;o=(e[i>>1]|0)-(e[j>>1]|0)|0;do{l=l+(f<<1)|0;m=m+(g<<1)|0;n=(ca((e[c+(k-f<<1)>>1]|0)-(e[c+(-(f+k|0)<<1)>>1]|0)|0,k)|0)+n|0;o=(ca((e[l>>1]|0)-(e[m>>1]|0)|0,k)|0)+o|0;k=k+1|0;}while((k|0)<9);k=(n*5|0)+32>>6;n=(o*5|0)+32>>6;o=k<<1;m=k*3|0;l=k<<2;c=((n+k|0)*-7|0)+16+((e[a-2+(16-f<<1)>>1]|0)+(e[h>>1]|0)<<4)|0;h=d;d=16;while(1){a=-16;g=c;while(1){j=g>>5;if(j>>>0<4096>>>0){p=j&65535}else{p=-j>>31&4095}b[h+(a+16<<1)>>1]=p;j=g+k>>5;if(j>>>0<4096>>>0){q=j&65535}else{q=-j>>31&4095}b[h+(a+17<<1)>>1]=q;j=g+o>>5;if(j>>>0<4096>>>0){r=j&65535}else{r=-j>>31&4095}b[h+(a+18<<1)>>1]=r;j=g+m>>5;if(j>>>0<4096>>>0){s=j&65535}else{s=-j>>31&4095}b[h+(a+19<<1)>>1]=s;j=a+4|0;if((j|0)<0){a=j;g=g+l|0}else{break}}g=d-1|0;if((g|0)>0){c=c+n|0;h=h+(f<<1)|0;d=g}else{break}}return}function wqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))+8>>4;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function xqa(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))))))))))))))+8>>4;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function yqa(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+8|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+16|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+24|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(e+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=e<<1;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+4<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+8<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=d+(a+12<<1)|0;c[b>>2]=134219776;c[b+4>>2]=134219776;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+4<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+8<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=d+(b+12<<1)|0;c[a>>2]=134219776;c[a+4>>2]=134219776;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+4<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+8<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;e=d+(a+12<<1)|0;c[e>>2]=134219776;c[e+4>>2]=134219776;return}function zqa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a;h=f>>1;f=h<<1;i=h*3|0;j=h<<2;k=(e[g+(-h<<1)>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=k;l=k+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=l;k=l+(c[d+32>>2]|0)|0;b[g+(i-h<<1)>>1]=k;b[g+(j-h<<1)>>1]=k+(c[d+48>>2]|0);k=1-h|0;h=(e[g+(k<<1)>>1]|0)+(c[d+4>>2]|0)|0;b[a+2>>1]=h;l=h+(c[d+20>>2]|0)|0;b[g+(k+f<<1)>>1]=l;h=l+(c[d+36>>2]|0)|0;b[g+(k+i<<1)>>1]=h;b[g+(k+j<<1)>>1]=h+(c[d+52>>2]|0);h=k+1|0;l=(e[g+(h<<1)>>1]|0)+(c[d+8>>2]|0)|0;b[a+4>>1]=l;m=l+(c[d+24>>2]|0)|0;b[g+(h+f<<1)>>1]=m;l=m+(c[d+40>>2]|0)|0;b[g+(h+i<<1)>>1]=l;b[g+(h+j<<1)>>1]=l+(c[d+56>>2]|0);l=k+2|0;k=(e[g+(l<<1)>>1]|0)+(c[d+12>>2]|0)|0;b[a+6>>1]=k;a=k+(c[d+28>>2]|0)|0;b[g+(l+f<<1)>>1]=a;f=a+(c[d+44>>2]|0)|0;b[g+(l+i<<1)>>1]=f;b[g+(l+j<<1)>>1]=f+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function Aqa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=a;h=f>>1;f=(e[a-2>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=f;i=f+(c[d+4>>2]|0)|0;b[a+2>>1]=i;f=i+(c[d+8>>2]|0)|0;b[a+4>>1]=f;b[a+6>>1]=f+(c[d+12>>2]|0);f=(e[g+(h-1<<1)>>1]|0)+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=f;a=f+(c[d+20>>2]|0)|0;b[g+(h+1<<1)>>1]=a;f=a+(c[d+24>>2]|0)|0;b[g+(h+2<<1)>>1]=f;b[g+(h+3<<1)>>1]=f+(c[d+28>>2]|0);f=h<<1;a=(e[g+(f-1<<1)>>1]|0)+(c[d+32>>2]|0)|0;b[g+(f<<1)>>1]=a;i=a+(c[d+36>>2]|0)|0;b[g+((f|1)<<1)>>1]=i;a=i+(c[d+40>>2]|0)|0;b[g+(f+2<<1)>>1]=a;b[g+(f+3<<1)>>1]=a+(c[d+44>>2]|0);a=f+h|0;h=(e[g+(a-1<<1)>>1]|0)+(c[d+48>>2]|0)|0;b[g+(a<<1)>>1]=h;f=h+(c[d+52>>2]|0)|0;b[g+(a+1<<1)>>1]=f;h=f+(c[d+56>>2]|0)|0;b[g+(a+2<<1)>>1]=h;b[g+(a+3<<1)>>1]=h+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function Bqa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=g<<1;h=g*3|0;i=g<<2;j=g*5|0;k=g*6|0;l=g*7|0;m=g<<3;n=0;o=a+(-g<<1)|0;a=d;while(1){p=(e[o>>1]|0)+(c[a>>2]|0)|0;b[o+(g<<1)>>1]=p;q=p+(c[a+32>>2]|0)|0;b[o+(f<<1)>>1]=q;p=q+(c[a+64>>2]|0)|0;b[o+(h<<1)>>1]=p;q=p+(c[a+96>>2]|0)|0;b[o+(i<<1)>>1]=q;p=q+(c[a+128>>2]|0)|0;b[o+(j<<1)>>1]=p;q=p+(c[a+160>>2]|0)|0;b[o+(k<<1)>>1]=q;p=q+(c[a+192>>2]|0)|0;b[o+(l<<1)>>1]=p;b[o+(m<<1)>>1]=p+(c[a+224>>2]|0);p=n+1|0;if((p|0)<8){n=p;o=o+2|0;a=a+4|0}else{break}}mrc(d|0,0,256)|0;return}function Cqa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>1;f=0;h=a;a=d;while(1){i=(e[h-2>>1]|0)+(c[a>>2]|0)|0;b[h>>1]=i;j=i+(c[a+4>>2]|0)|0;b[h+2>>1]=j;i=j+(c[a+8>>2]|0)|0;b[h+4>>1]=i;j=i+(c[a+12>>2]|0)|0;b[h+6>>1]=j;i=j+(c[a+16>>2]|0)|0;b[h+8>>1]=i;j=i+(c[a+20>>2]|0)|0;b[h+10>>1]=j;i=j+(c[a+24>>2]|0)|0;b[h+12>>1]=i;b[h+14>>1]=i+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}mrc(d|0,0,256)|0;return}function Dqa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;zqa(a+(c[b>>2]|0)|0,d,e);zqa(a+(c[b+4>>2]|0)|0,d+64|0,e);zqa(a+(c[b+8>>2]|0)|0,d+128|0,e);zqa(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function Eqa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Aqa(a+(c[b>>2]|0)|0,d,e);Aqa(a+(c[b+4>>2]|0)|0,d+64|0,e);Aqa(a+(c[b+8>>2]|0)|0,d+128|0,e);Aqa(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function Fqa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;zqa(a+(c[b>>2]|0)|0,d,e);zqa(a+(c[b+4>>2]|0)|0,d+64|0,e);zqa(a+(c[b+8>>2]|0)|0,d+128|0,e);zqa(a+(c[b+12>>2]|0)|0,d+192|0,e);zqa(a+(c[b+32>>2]|0)|0,d+256|0,e);zqa(a+(c[b+36>>2]|0)|0,d+320|0,e);zqa(a+(c[b+40>>2]|0)|0,d+384|0,e);zqa(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function Gqa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Aqa(a+(c[b>>2]|0)|0,d,e);Aqa(a+(c[b+4>>2]|0)|0,d+64|0,e);Aqa(a+(c[b+8>>2]|0)|0,d+128|0,e);Aqa(a+(c[b+12>>2]|0)|0,d+192|0,e);Aqa(a+(c[b+32>>2]|0)|0,d+256|0,e);Aqa(a+(c[b+36>>2]|0)|0,d+320|0,e);Aqa(a+(c[b+40>>2]|0)|0,d+384|0,e);Aqa(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function Hqa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{zqa(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Iqa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Aqa(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Jqa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=a;e=d>>1;d=b+(-e<<1)|0;f=c[d>>2]|0;g=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+(e<<1<<1)|0;c[d>>2]=f;c[d+4>>2]=g;d=b+((e*3|0)<<1)|0;c[d>>2]=f;c[d+4>>2]=g;return}function Kqa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0;b=a;f=d>>1;d=Erc(e[a-2>>1]|0,0,65537,65537)|0;g=a;c[g>>2]=d;c[g+4>>2]=G;g=Erc(e[b+(f-1<<1)>>1]|0,0,65537,65537)|0;d=b+(f<<1)|0;c[d>>2]=g;c[d+4>>2]=G;d=f<<1;g=Erc(e[b+(d-1<<1)>>1]|0,0,65537,65537)|0;a=b+(d<<1)|0;c[a>>2]=g;c[a+4>>2]=G;a=f*3|0;f=Erc(e[b+(a-1<<1)>>1]|0,0,65537,65537)|0;g=b+(a<<1)|0;c[g>>2]=f;c[g+4>>2]=G;return}function Lqa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=(e[b+(-f<<1)>>1]|0)+4+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=b+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(d<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=b+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function Mqa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=d>>1;d=e[f+(1-g<<1)>>1]|0;h=e[f+(2-g<<1)>>1]|0;i=e[f+(3-g<<1)>>1]|0;j=e[c>>1]|0;k=e[c+2>>1]|0;l=e[c+4>>1]|0;m=e[c+6>>1]|0;b[f>>1]=((e[f+(-g<<1)>>1]|0)+2+h+(d<<1)|0)>>>2;c=(d+2+i+(h<<1)|0)>>>2&65535;b[f+(g<<1)>>1]=c;b[a+2>>1]=c;c=(h+2+j+(i<<1)|0)>>>2&65535;h=g<<1;b[f+(h<<1)>>1]=c;b[f+(g+1<<1)>>1]=c;b[a+4>>1]=c;c=(i+2+k+(j<<1)|0)>>>2&65535;i=g*3|0;b[f+(i<<1)>>1]=c;b[f+((h|1)<<1)>>1]=c;b[f+(g+2<<1)>>1]=c;b[a+6>>1]=c;c=(j+2+l+(k<<1)|0)>>>2&65535;b[f+(i+1<<1)>>1]=c;b[f+(h+2<<1)>>1]=c;b[f+(g+3<<1)>>1]=c;c=(k+2+m+(l<<1)|0)>>>2&65535;b[f+(i+2<<1)>>1]=c;b[f+(h+3<<1)>>1]=c;b[f+(i+3<<1)>>1]=(l+2+(m*3|0)|0)>>>2;return}function Nqa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;b[c+(o<<1)>>1]=(l+2+(n<<1)+(e[c+(o-1<<1)>>1]|0)|0)>>>2;p=(k+2+(l<<1)+n|0)>>>2&65535;b[c+(o+1<<1)>>1]=p;b[c+(m<<1)>>1]=p;p=d+2|0;n=(p+(k<<1)+l|0)>>>2&65535;b[c+(o+2<<1)>>1]=n;b[c+((m|1)<<1)>>1]=n;b[c+(f<<1)>>1]=n;n=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+3<<1)>>1]=n;b[c+(m+2<<1)>>1]=n;b[c+(f+1<<1)>>1]=n;b[c>>1]=n;n=(p+(g<<1)+h|0)>>>2&65535;b[c+(m+3<<1)>>1]=n;b[c+(f+2<<1)>>1]=n;b[a+2>>1]=n;n=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(f+3<<1)>>1]=n;b[a+4>>1]=n;b[a+6>>1]=(h+2+(i<<1)+j|0)>>>2;return}function Oqa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[c+(3-f<<1)>>1]|0;k=e[a-2>>1]|0;l=e[c+(f-1<<1)>>1]|0;m=f<<1;n=e[c+(m-1<<1)>>1]|0;o=f*3|0;p=(d+1+g|0)>>>1&65535;b[c+((m|1)<<1)>>1]=p;b[c>>1]=p;p=(g+1+h|0)>>>1&65535;b[c+(m+2<<1)>>1]=p;b[a+2>>1]=p;p=(h+1+i|0)>>>1&65535;b[c+(m+3<<1)>>1]=p;b[a+4>>1]=p;b[a+6>>1]=(i+1+j|0)>>>1;a=((d<<1)+2+g+k|0)>>>2&65535;b[c+(o+1<<1)>>1]=a;b[c+(f<<1)>>1]=a;a=d+2|0;d=(a+(g<<1)+h|0)>>>2&65535;b[c+(o+2<<1)>>1]=d;b[c+(f+1<<1)>>1]=d;d=(g+2+(h<<1)+i|0)>>>2&65535;b[c+(o+3<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;b[c+(f+3<<1)>>1]=(h+2+(i<<1)+j|0)>>>2;b[c+(m<<1)>>1]=(a+(k<<1)+l|0)>>>2;b[c+(o<<1)>>1]=(k+2+(l<<1)+n|0)>>>2;return}function Pqa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=a;f=d>>1;d=e[c+(~f<<1)>>1]|0;g=e[c+(-f<<1)>>1]|0;h=e[c+(1-f<<1)>>1]|0;i=e[c+(2-f<<1)>>1]|0;j=e[a-2>>1]|0;k=e[c+(f-1<<1)>>1]|0;l=f<<1;m=e[c+(l-1<<1)>>1]|0;n=f*3|0;o=e[c+(n-1<<1)>>1]|0;p=(d+1+j|0)>>>1&65535;b[c+(f+2<<1)>>1]=p;b[c>>1]=p;p=((d<<1)+2+g+j|0)>>>2&65535;b[c+(f+3<<1)>>1]=p;b[a+2>>1]=p;p=d+2|0;b[a+4>>1]=(p+(g<<1)+h|0)>>>2;b[a+6>>1]=(g+2+(h<<1)+i|0)>>>2;i=(j+1+k|0)>>>1&65535;b[c+(l+2<<1)>>1]=i;b[c+(f<<1)>>1]=i;i=(p+(j<<1)+k|0)>>>2&65535;b[c+(l+3<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;i=(k+1+m|0)>>>1&65535;b[c+(n+2<<1)>>1]=i;b[c+(l<<1)>>1]=i;i=(j+2+(k<<1)+m|0)>>>2&65535;b[c+(n+3<<1)>>1]=i;b[c+((l|1)<<1)>>1]=i;b[c+(n<<1)>>1]=(m+1+o|0)>>>1;b[c+(n+1<<1)>>1]=(k+2+(m<<1)+o|0)>>>2;return}function Qqa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a;g=d>>1;d=e[f+(-g<<1)>>1]|0;h=e[f+(1-g<<1)>>1]|0;i=e[f+(2-g<<1)>>1]|0;j=e[f+(3-g<<1)>>1]|0;k=e[c>>1]|0;l=e[c+2>>1]|0;m=e[c+4>>1]|0;b[f>>1]=(d+1+h|0)>>>1;c=(h+1+i|0)>>>1&65535;n=g<<1;b[f+(n<<1)>>1]=c;b[a+2>>1]=c;c=(i+1+j|0)>>>1&65535;b[f+((n|1)<<1)>>1]=c;b[a+4>>1]=c;c=(j+1+k|0)>>>1&65535;b[f+(n+2<<1)>>1]=c;b[a+6>>1]=c;b[f+(n+3<<1)>>1]=(k+1+l|0)>>>1;b[f+(g<<1)>>1]=(d+2+(h<<1)+i|0)>>>2;d=(h+2+(i<<1)+j|0)>>>2&65535;h=g*3|0;b[f+(h<<1)>>1]=d;b[f+(g+1<<1)>>1]=d;d=(i+2+(j<<1)+k|0)>>>2&65535;b[f+(h+1<<1)>>1]=d;b[f+(g+2<<1)>>1]=d;d=(j+2+(k<<1)+l|0)>>>2&65535;b[f+(h+2<<1)>>1]=d;b[f+(g+3<<1)>>1]=d;b[f+(h+3<<1)>>1]=(k+2+(l<<1)+m|0)>>>2;return}function Rqa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a;f=d>>1;d=e[a-2>>1]|0;g=e[c+(f-1<<1)>>1]|0;h=f<<1;i=e[c+(h-1<<1)>>1]|0;j=f*3|0;k=b[c+(j-1<<1)>>1]|0;l=k&65535;b[c>>1]=(d+1+g|0)>>>1;b[a+2>>1]=(d+2+(g<<1)+i|0)>>>2;d=(g+1+i|0)>>>1&65535;b[c+(f<<1)>>1]=d;b[a+4>>1]=d;d=(g+2+(i<<1)+l|0)>>>2&65535;b[c+(f+1<<1)>>1]=d;b[a+6>>1]=d;d=(i+1+l|0)>>>1&65535;b[c+(h<<1)>>1]=d;b[c+(f+2<<1)>>1]=d;d=(i+2+l+(l<<1)|0)>>>2&65535;b[c+((h|1)<<1)>>1]=d;b[c+(f+3<<1)>>1]=d;b[c+(j+3<<1)>>1]=k;b[c+(j+2<<1)>>1]=k;b[c+(h+2<<1)>>1]=k;b[c+(j<<1)>>1]=k;b[c+(j+1<<1)>>1]=k;b[c+(h+3<<1)>>1]=k;return}function Sqa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;b=a;f=d>>1;d=f<<1;g=f*3|0;h=Erc(((e[a-2>>1]|0)+2+(e[b+(f-1<<1)>>1]|0)+(e[b+(d-1<<1)>>1]|0)+(e[b+(g-1<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;i=G;j=a;c[j>>2]=h;c[j+4>>2]=i;j=b+(f<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(d<<1)|0;c[j>>2]=h;c[j+4>>2]=i;j=b+(g<<1)|0;c[j>>2]=h;c[j+4>>2]=i;return}function Tqa(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;b=a;f=d>>1;d=Erc(((e[b+(-f<<1)>>1]|0)+2+(e[b+(1-f<<1)>>1]|0)+(e[b+(2-f<<1)>>1]|0)+(e[b+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+(f<<1<<1)|0;c[h>>2]=d;c[h+4>>2]=g;h=b+((f*3|0)<<1)|0;c[h>>2]=d;c[h+4>>2]=g;return}function Uqa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=536879104;c[d+4>>2]=536879104;d=b+(e<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=b+(e<<1<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=b+((e*3|0)<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;return}function Vqa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=536813567;c[d+4>>2]=536813567;d=b+(e<<1)|0;c[d>>2]=536813567;c[d+4>>2]=536813567;d=b+(e<<1<<1)|0;c[d>>2]=536813567;c[d+4>>2]=536813567;d=b+((e*3|0)<<1)|0;c[d>>2]=536813567;c[d+4>>2]=536813567;return}function Wqa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=a;e=d>>1;d=a;c[d>>2]=536944641;c[d+4>>2]=536944641;d=b+(e<<1)|0;c[d>>2]=536944641;c[d+4>>2]=536944641;d=b+(e<<1<<1)|0;c[d>>2]=536944641;c[d+4>>2]=536944641;d=b+((e*3|0)<<1)|0;c[d>>2]=536944641;c[d+4>>2]=536944641;return}function Xqa(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}b[h>>1]=((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;b[a+2>>1]=(j+2+(k<<1)+l|0)>>>2;b[a+4>>1]=(k+2+(l<<1)+m|0)>>>2;b[a+6>>1]=(l+2+(m<<1)+n|0)>>>2;l=a+8|0;b[l>>1]=(m+2+(n<<1)+o|0)>>>2;b[a+10>>1]=(n+2+(o<<1)+p|0)>>>2;b[a+12>>1]=(o+2+(p<<1)+r|0)>>>2;b[a+14>>1]=((s&65535)+2+(r<<1)+p|0)>>>2;p=a;a=c[p>>2]|0;r=c[p+4>>2]|0;p=l;l=c[p>>2]|0;s=c[p+4>>2]|0;p=h+(i<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(i+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<1;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*3|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i<<2;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*5|0;p=h+(o<<1)|0;c[p>>2]=a;c[p+4>>2]=r;p=h+(o+4<<1)|0;c[p>>2]=l;c[p+4>>2]=s;p=i*6|0;o=h+(p<<1)|0;c[o>>2]=a;c[o+4>>2]=r;o=h+(p+4<<1)|0;c[o>>2]=l;c[o+4>>2]=s;o=i*7|0;i=h+(o<<1)|0;c[i>>2]=a;c[i+4>>2]=r;r=h+(o+4<<1)|0;c[r>>2]=l;c[r+4>>2]=s;return}function Yqa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=g<<1;j=e[d+(f-1<<1)>>1]|0;k=g*3|0;l=e[d+(k-1<<1)>>1]|0;m=g<<2;n=e[d+(m-1<<1)>>1]|0;o=g*5|0;p=e[d+(o-1<<1)>>1]|0;q=g*6|0;r=e[d+(q-1<<1)>>1]|0;s=g*7|0;t=e[d+(s-1<<1)>>1]|0;u=Erc(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2,0,65537,65537)|0;h=G;v=a;c[v>>2]=u;c[v+4>>2]=h;v=a+8|0;c[v>>2]=u;c[v+4>>2]=h;h=Erc((b+2+(i<<1)+j|0)>>>2,0,65537,65537)|0;b=G;v=d+(g<<1)|0;c[v>>2]=h;c[v+4>>2]=b;v=d+(g+4<<1)|0;c[v>>2]=h;c[v+4>>2]=b;b=Erc((i+2+(j<<1)+l|0)>>>2,0,65537,65537)|0;i=G;v=d+(f<<1)|0;c[v>>2]=b;c[v+4>>2]=i;v=d+(f+4<<1)|0;c[v>>2]=b;c[v+4>>2]=i;i=Erc((j+2+(l<<1)+n|0)>>>2,0,65537,65537)|0;j=G;v=d+(k<<1)|0;c[v>>2]=i;c[v+4>>2]=j;v=d+(k+4<<1)|0;c[v>>2]=i;c[v+4>>2]=j;j=Erc((l+2+(n<<1)+p|0)>>>2,0,65537,65537)|0;l=G;v=d+(m<<1)|0;c[v>>2]=j;c[v+4>>2]=l;v=d+(m+4<<1)|0;c[v>>2]=j;c[v+4>>2]=l;l=Erc((n+2+(p<<1)+r|0)>>>2,0,65537,65537)|0;n=G;v=d+(o<<1)|0;c[v>>2]=l;c[v+4>>2]=n;v=d+(o+4<<1)|0;c[v>>2]=l;c[v+4>>2]=n;n=Erc((p+2+(r<<1)+t|0)>>>2,0,65537,65537)|0;p=G;v=d+(q<<1)|0;c[v>>2]=n;c[v+4>>2]=p;v=d+(q+4<<1)|0;c[v>>2]=n;c[v+4>>2]=p;p=Erc((r+2+(t*3|0)|0)>>>2,0,65537,65537)|0;t=G;r=d+(s<<1)|0;c[r>>2]=p;c[r+4>>2]=t;r=d+(s+4<<1)|0;c[r>>2]=p;c[r+4>>2]=t;return}function Zqa(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=g>>1;g=(d|0)!=0;if(g){d=~i;j=h+(d<<1)|0;k=a-2|0;l=d}else{d=a-2|0;j=d;k=d;l=~i}d=e[k>>1]|0;k=e[h+(i-1<<1)>>1]|0;m=e[h+((i<<1)-1<<1)>>1]|0;n=e[h+((i*3|0)-1<<1)>>1]|0;o=e[h+((i<<2)-1<<1)>>1]|0;p=e[h+((i*5|0)-1<<1)>>1]|0;q=e[h+((i*6|0)-1<<1)>>1]|0;r=e[h+((i*7|0)-1<<1)>>1]|0;s=-i|0;t=e[h+(s<<1)>>1]|0;u=e[h+(1-i<<1)>>1]|0;v=e[h+(2-i<<1)>>1]|0;w=e[h+(3-i<<1)>>1]|0;x=e[h+(4-i<<1)>>1]|0;y=e[h+(5-i<<1)>>1]|0;z=e[h+(6-i<<1)>>1]|0;A=b[h+(7-i<<1)>>1]|0;B=A&65535;if((f|0)==0){C=A}else{C=b[h+(8-i<<1)>>1]|0}A=(((e[j>>1]|0)+2+(d<<1)+k|0)>>>2)+8+((d+2+(k<<1)+m|0)>>>2)+((k+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q<<1)+r|0)>>>2)+((q+2+(r*3|0)|0)>>>2)+(((e[h+((g?l:s)<<1)>>1]|0)+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+z|0)>>>2)+((y+2+(z<<1)+B|0)>>>2)+(((C&65535)+2+(B<<1)+z|0)>>>2)>>4;z=Erc(A,(A|0)<0|0?-1:0,65537,65537)|0;A=G;B=a;c[B>>2]=z;c[B+4>>2]=A;B=a+8|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(i+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=i<<1;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;B=h+(a<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=h+(a+4<<1)|0;c[B>>2]=z;c[B+4>>2]=A;B=a+i|0;a=h+(B<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=h+(B+4<<1)|0;c[a>>2]=z;c[a+4>>2]=A;a=B+i|0;i=h+(a<<1)|0;c[i>>2]=z;c[i+4>>2]=A;i=h+(a+4<<1)|0;c[i>>2]=z;c[i+4>>2]=A;return}function _qa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=e[g+(2-h<<1)>>1]|0;l=(i+2+(j<<1)+k|0)>>>2;m=e[g+(3-h<<1)>>1]|0;n=(j+2+(k<<1)+m|0)>>>2;o=e[g+(4-h<<1)>>1]|0;p=(k+2+(m<<1)+o|0)>>>2;k=e[g+(5-h<<1)>>1]|0;q=(m+2+(o<<1)+k|0)>>>2;m=e[g+(6-h<<1)>>1]|0;r=(o+2+(k<<1)+m|0)>>>2;o=b[g+(7-h<<1)>>1]|0;s=o&65535;t=(k+2+(m<<1)+s|0)>>>2;if((d|0)==0){u=s;v=s;w=s;x=s;y=s;z=s;A=s;B=s;C=(o&65535)+2+(s<<1)|0}else{o=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;k=e[g+(10-h<<1)>>1]|0;D=e[g+(11-h<<1)>>1]|0;E=e[g+(12-h<<1)>>1]|0;F=e[g+(13-h<<1)>>1]|0;G=e[g+(14-h<<1)>>1]|0;H=e[g+(15-h<<1)>>1]|0;u=(G+2+(H*3|0)|0)>>>2;v=(F+2+(G<<1)+H|0)>>>2;w=(E+2+(F<<1)+G|0)>>>2;x=(D+2+(E<<1)+F|0)>>>2;y=(k+2+(D<<1)+E|0)>>>2;z=(d+2+(k<<1)+D|0)>>>2;A=(o+2+(d<<1)+k|0)>>>2;B=(s+2+(o<<1)+d|0)>>>2;C=(e[g+(8-h<<1)>>1]|0)+2+(s<<1)|0}s=(C+m|0)>>>2;b[g>>1]=((((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2)+2+(l<<1)+n|0)>>>2;j=(l+2+(n<<1)+p|0)>>>2&65535;b[a+2>>1]=j;b[g+(h<<1)>>1]=j;j=(n+2+(p<<1)+q|0)>>>2&65535;b[a+4>>1]=j;b[g+(h+1<<1)>>1]=j;n=h<<1;b[g+(n<<1)>>1]=j;j=(p+2+(q<<1)+r|0)>>>2&65535;b[a+6>>1]=j;b[g+(h+2<<1)>>1]=j;b[g+((n|1)<<1)>>1]=j;p=h*3|0;b[g+(p<<1)>>1]=j;j=(q+2+(r<<1)+t|0)>>>2&65535;b[a+8>>1]=j;b[g+(h+3<<1)>>1]=j;b[g+(n+2<<1)>>1]=j;b[g+(p+1<<1)>>1]=j;q=h<<2;b[g+(q<<1)>>1]=j;j=(r+2+(t<<1)+s|0)>>>2&65535;b[a+10>>1]=j;b[g+(h+4<<1)>>1]=j;b[g+(n+3<<1)>>1]=j;b[g+(p+2<<1)>>1]=j;b[g+((q|1)<<1)>>1]=j;r=h*5|0;b[g+(r<<1)>>1]=j;j=(t+2+(s<<1)+B|0)>>>2&65535;b[a+12>>1]=j;b[g+(h+5<<1)>>1]=j;b[g+(n+4<<1)>>1]=j;b[g+(p+3<<1)>>1]=j;b[g+((q|2)<<1)>>1]=j;b[g+(r+1<<1)>>1]=j;t=h*6|0;b[g+(t<<1)>>1]=j;j=(s+2+(B<<1)+A|0)>>>2&65535;b[a+14>>1]=j;b[g+(h+6<<1)>>1]=j;b[g+(n+5<<1)>>1]=j;b[g+(p+4<<1)>>1]=j;b[g+((q|3)<<1)>>1]=j;b[g+(r+2<<1)>>1]=j;b[g+((t|1)<<1)>>1]=j;a=h*7|0;b[g+(a<<1)>>1]=j;j=(B+2+(A<<1)+z|0)>>>2&65535;b[g+(h+7<<1)>>1]=j;b[g+(n+6<<1)>>1]=j;b[g+(p+5<<1)>>1]=j;b[g+(q+4<<1)>>1]=j;b[g+(r+3<<1)>>1]=j;b[g+(t+2<<1)>>1]=j;b[g+(a+1<<1)>>1]=j;j=(A+2+(z<<1)+y|0)>>>2&65535;b[g+(n+7<<1)>>1]=j;b[g+(p+6<<1)>>1]=j;b[g+(q+5<<1)>>1]=j;b[g+(r+4<<1)>>1]=j;b[g+(t+3<<1)>>1]=j;b[g+(a+2<<1)>>1]=j;j=(z+2+(y<<1)+x|0)>>>2&65535;b[g+(p+7<<1)>>1]=j;b[g+(q+6<<1)>>1]=j;b[g+(r+5<<1)>>1]=j;b[g+(t+4<<1)>>1]=j;b[g+(a+3<<1)>>1]=j;j=(y+2+(x<<1)+w|0)>>>2&65535;b[g+(q+7<<1)>>1]=j;b[g+(r+6<<1)>>1]=j;b[g+(t+5<<1)>>1]=j;b[g+(a+4<<1)>>1]=j;j=(x+2+(w<<1)+v|0)>>>2&65535;b[g+(r+7<<1)>>1]=j;b[g+(t+6<<1)>>1]=j;b[g+(a+5<<1)>>1]=j;j=(w+2+(v<<1)+u|0)>>>2&65535;b[g+(t+7<<1)>>1]=j;b[g+(a+6<<1)>>1]=j;b[g+(a+7<<1)>>1]=(v+2+(u*3|0)|0)>>>2;return}function $qa(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;k=e[g+(v-1<<1)>>1]|0;d=i+2|0;i=(d+(w<<1)+k|0)>>>2;c=h*3|0;y=e[g+(c-1<<1)>>1]|0;z=(w+2+(k<<1)+y|0)>>>2;w=h<<2;A=e[g+(w-1<<1)>>1]|0;B=(k+2+(y<<1)+A|0)>>>2;k=h*5|0;C=e[g+(k-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*6|0;E=e[g+(y-1<<1)>>1]|0;F=(A+2+(C<<1)+E|0)>>>2;A=h*7|0;G=e[g+(A-1<<1)>>1]|0;H=(C+2+(E<<1)+G|0)>>>2;C=(d+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(A<<1)>>1]=(F+2+((E+2+(G*3|0)|0)>>>2)+(H<<1)|0)>>>2;G=(D+2+(F<<1)+H|0)>>>2&65535;b[g+(A+1<<1)>>1]=G;b[g+(y<<1)>>1]=G;G=(B+2+(D<<1)+F|0)>>>2&65535;b[g+(A+2<<1)>>1]=G;b[g+((y|1)<<1)>>1]=G;b[g+(k<<1)>>1]=G;G=(z+2+(B<<1)+D|0)>>>2&65535;b[g+(A+3<<1)>>1]=G;b[g+(y+2<<1)>>1]=G;b[g+(k+1<<1)>>1]=G;b[g+(w<<1)>>1]=G;G=(i+2+(z<<1)+B|0)>>>2&65535;b[g+(A+4<<1)>>1]=G;b[g+(y+3<<1)>>1]=G;b[g+(k+2<<1)>>1]=G;b[g+((w|1)<<1)>>1]=G;b[g+(c<<1)>>1]=G;G=(f+2+(i<<1)+z|0)>>>2&65535;b[g+(A+5<<1)>>1]=G;b[g+(y+4<<1)>>1]=G;b[g+(k+3<<1)>>1]=G;b[g+((w|2)<<1)>>1]=G;b[g+(c+1<<1)>>1]=G;b[g+(v<<1)>>1]=G;G=((f<<1)+2+i+C|0)>>>2&65535;b[g+(A+6<<1)>>1]=G;b[g+(y+5<<1)>>1]=G;b[g+(k+4<<1)>>1]=G;b[g+((w|3)<<1)>>1]=G;b[g+(c+2<<1)>>1]=G;b[g+((v|1)<<1)>>1]=G;b[g+(h<<1)>>1]=G;G=l+2|0;i=(G+f+(C<<1)|0)>>>2&65535;b[g+(A+7<<1)>>1]=i;b[g+(y+6<<1)>>1]=i;b[g+(k+5<<1)>>1]=i;b[g+(w+4<<1)>>1]=i;b[g+(c+3<<1)>>1]=i;b[g+(v+2<<1)>>1]=i;b[g+(h+1<<1)>>1]=i;b[g>>1]=i;i=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+7<<1)>>1]=i;b[g+(k+6<<1)>>1]=i;b[g+(w+5<<1)>>1]=i;b[g+(c+4<<1)>>1]=i;b[g+(v+3<<1)>>1]=i;b[g+(h+2<<1)>>1]=i;b[a+2>>1]=i;i=(G+(m<<1)+o|0)>>>2&65535;b[g+(k+7<<1)>>1]=i;b[g+(w+6<<1)>>1]=i;b[g+(c+5<<1)>>1]=i;b[g+(v+4<<1)>>1]=i;b[g+(h+3<<1)>>1]=i;b[a+4>>1]=i;i=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(w+7<<1)>>1]=i;b[g+(c+6<<1)>>1]=i;b[g+(v+5<<1)>>1]=i;b[g+(h+4<<1)>>1]=i;b[a+6>>1]=i;i=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(c+7<<1)>>1]=i;b[g+(v+6<<1)>>1]=i;b[g+(h+5<<1)>>1]=i;b[a+8>>1]=i;i=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(v+7<<1)>>1]=i;b[g+(h+6<<1)>>1]=i;b[a+10>>1]=i;i=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(h+7<<1)>>1]=i;b[a+12>>1]=i;b[a+14>>1]=(r+2+(t<<1)+(((u&65535)+2+(s<<1)+n|0)>>>2)|0)>>>2;return}function ara(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=a;h=f>>1;f=(c|0)!=0;c=-h|0;i=~h;j=e[g+(c<<1)>>1]|0;k=e[g+(1-h<<1)>>1]|0;l=((e[g+((f?i:c)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2;c=e[g+(2-h<<1)>>1]|0;m=(j+2+(k<<1)+c|0)>>>2;n=e[g+(3-h<<1)>>1]|0;o=(k+2+(c<<1)+n|0)>>>2;k=e[g+(4-h<<1)>>1]|0;p=(c+2+(n<<1)+k|0)>>>2;c=e[g+(5-h<<1)>>1]|0;q=(n+2+(k<<1)+c|0)>>>2;n=e[g+(6-h<<1)>>1]|0;r=(k+2+(c<<1)+n|0)>>>2;k=b[g+(7-h<<1)>>1]|0;s=k&65535;t=(c+2+(n<<1)+s|0)>>>2;if((d|0)==0){u=k}else{u=b[g+(8-h<<1)>>1]|0}k=((u&65535)+2+(s<<1)+n|0)>>>2;if(f){f=g+(i<<1)|0;v=f;w=a-2|0;x=f}else{f=a-2|0;v=f;w=f;x=g+(i<<1)|0}i=e[w>>1]|0;w=e[g+(h-1<<1)>>1]|0;f=((e[v>>1]|0)+2+(i<<1)+w|0)>>>2;v=h<<1;n=e[g+(v-1<<1)>>1]|0;s=i+2|0;i=(s+(w<<1)+n|0)>>>2;u=h*3|0;d=e[g+(u-1<<1)>>1]|0;c=(w+2+(n<<1)+d|0)>>>2;w=h<<2;y=e[g+(w-1<<1)>>1]|0;z=(n+2+(d<<1)+y|0)>>>2;n=h*5|0;A=e[g+(n-1<<1)>>1]|0;B=(d+2+(y<<1)+A|0)>>>2;d=h*6|0;C=e[g+(d-1<<1)>>1]|0;D=(y+2+(A<<1)+C|0)>>>2;y=h*7|0;E=(A+2+(C<<1)+(e[g+(y-1<<1)>>1]|0)|0)>>>2;C=(s+((e[x>>1]|0)<<1)+j|0)>>>2;b[g+(d<<1)>>1]=(z+2+(B<<1)+D|0)>>>2;b[g+(y<<1)>>1]=(B+2+(D<<1)+E|0)>>>2;E=(i+2+(c<<1)+z|0)>>>2&65535;b[g+((d|1)<<1)>>1]=E;b[g+(w<<1)>>1]=E;E=(c+2+(z<<1)+B|0)>>>2&65535;b[g+(y+1<<1)>>1]=E;b[g+(n<<1)>>1]=E;E=((f<<1)+2+i+C|0)>>>2&65535;b[g+(d+2<<1)>>1]=E;b[g+((w|1)<<1)>>1]=E;b[g+(v<<1)>>1]=E;E=(f+2+(i<<1)+c|0)>>>2&65535;b[g+(y+2<<1)>>1]=E;b[g+(n+1<<1)>>1]=E;b[g+(u<<1)>>1]=E;E=l+2|0;c=(E+f+(C<<1)|0)>>>2&65535;b[g+(y+3<<1)>>1]=c;b[g+(n+2<<1)>>1]=c;b[g+(u+1<<1)>>1]=c;b[g+(h<<1)>>1]=c;c=l+1|0;f=(c+C|0)>>>1&65535;b[g+(d+3<<1)>>1]=f;b[g+((w|2)<<1)>>1]=f;b[g+((v|1)<<1)>>1]=f;b[g>>1]=f;f=((l<<1)+2+m+C|0)>>>2&65535;b[g+(y+4<<1)>>1]=f;b[g+(n+3<<1)>>1]=f;b[g+(u+2<<1)>>1]=f;b[g+(h+1<<1)>>1]=f;f=(c+m|0)>>>1&65535;b[g+(d+4<<1)>>1]=f;b[g+((w|3)<<1)>>1]=f;b[g+(v+2<<1)>>1]=f;b[a+2>>1]=f;f=(E+(m<<1)+o|0)>>>2&65535;b[g+(y+5<<1)>>1]=f;b[g+(n+4<<1)>>1]=f;b[g+(u+3<<1)>>1]=f;b[g+(h+2<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[g+(d+5<<1)>>1]=f;b[g+(w+4<<1)>>1]=f;b[g+(v+3<<1)>>1]=f;b[a+4>>1]=f;f=(m+2+(o<<1)+p|0)>>>2&65535;b[g+(y+6<<1)>>1]=f;b[g+(n+5<<1)>>1]=f;b[g+(u+4<<1)>>1]=f;b[g+(h+3<<1)>>1]=f;f=(o+1+p|0)>>>1&65535;b[g+(d+6<<1)>>1]=f;b[g+(w+5<<1)>>1]=f;b[g+(v+4<<1)>>1]=f;b[a+6>>1]=f;f=(o+2+(p<<1)+q|0)>>>2&65535;b[g+(y+7<<1)>>1]=f;b[g+(n+6<<1)>>1]=f;b[g+(u+5<<1)>>1]=f;b[g+(h+4<<1)>>1]=f;f=(p+1+q|0)>>>1&65535;b[g+(d+7<<1)>>1]=f;b[g+(w+6<<1)>>1]=f;b[g+(v+5<<1)>>1]=f;b[a+8>>1]=f;f=(p+2+(q<<1)+r|0)>>>2&65535;b[g+(n+7<<1)>>1]=f;b[g+(u+6<<1)>>1]=f;b[g+(h+5<<1)>>1]=f;f=(q+1+r|0)>>>1&65535;b[g+(w+7<<1)>>1]=f;b[g+(v+6<<1)>>1]=f;b[a+10>>1]=f;f=(q+2+(r<<1)+t|0)>>>2&65535;b[g+(u+7<<1)>>1]=f;b[g+(h+6<<1)>>1]=f;f=(r+1+t|0)>>>1&65535;b[g+(v+7<<1)>>1]=f;b[a+12>>1]=f;b[g+(h+7<<1)>>1]=(r+2+(t<<1)+k|0)>>>2;b[a+14>>1]=(t+1+k|0)>>>1;return}function bra(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=a;g=f>>1;f=(c|0)!=0;c=-g|0;h=~g;i=e[d+(c<<1)>>1]|0;j=e[d+(1-g<<1)>>1]|0;k=((e[d+((f?h:c)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;c=e[d+(2-g<<1)>>1]|0;l=(i+2+(j<<1)+c|0)>>>2;m=e[d+(3-g<<1)>>1]|0;n=(j+2+(c<<1)+m|0)>>>2;j=e[d+(4-g<<1)>>1]|0;o=(c+2+(m<<1)+j|0)>>>2;c=e[d+(5-g<<1)>>1]|0;p=(m+2+(j<<1)+c|0)>>>2;m=e[d+(6-g<<1)>>1]|0;q=(j+2+(c<<1)+m|0)>>>2;j=(c+2+(m<<1)+(e[d+(7-g<<1)>>1]|0)|0)>>>2;if(f){f=d+(h<<1)|0;r=f;s=a-2|0;t=f}else{f=a-2|0;r=f;s=f;t=d+(h<<1)|0}h=e[s>>1]|0;s=e[d+(g-1<<1)>>1]|0;f=((e[r>>1]|0)+2+(h<<1)+s|0)>>>2;r=g<<1;m=e[d+(r-1<<1)>>1]|0;c=h+2|0;h=(c+(s<<1)+m|0)>>>2;u=g*3|0;v=e[d+(u-1<<1)>>1]|0;w=(s+2+(m<<1)+v|0)>>>2;s=g<<2;x=e[d+(s-1<<1)>>1]|0;y=(m+2+(v<<1)+x|0)>>>2;m=g*5|0;z=e[d+(m-1<<1)>>1]|0;A=(v+2+(x<<1)+z|0)>>>2;v=g*6|0;B=e[d+(v-1<<1)>>1]|0;C=(x+2+(z<<1)+B|0)>>>2;x=g*7|0;D=e[d+(x-1<<1)>>1]|0;E=(z+2+(B<<1)+D|0)>>>2;z=(B+2+(D*3|0)|0)>>>2;D=(c+((e[t>>1]|0)<<1)+i|0)>>>2;b[d+(x<<1)>>1]=(z+1+E|0)>>>1;b[d+(x+1<<1)>>1]=(C+2+z+(E<<1)|0)>>>2;z=(C+1+E|0)>>>1&65535;b[d+(x+2<<1)>>1]=z;b[d+(v<<1)>>1]=z;z=(A+2+(C<<1)+E|0)>>>2&65535;b[d+(x+3<<1)>>1]=z;b[d+((v|1)<<1)>>1]=z;z=(A+1+C|0)>>>1&65535;b[d+(x+4<<1)>>1]=z;b[d+(v+2<<1)>>1]=z;b[d+(m<<1)>>1]=z;z=(y+2+(A<<1)+C|0)>>>2&65535;b[d+(x+5<<1)>>1]=z;b[d+(v+3<<1)>>1]=z;b[d+(m+1<<1)>>1]=z;z=(y+1+A|0)>>>1&65535;b[d+(x+6<<1)>>1]=z;b[d+(v+4<<1)>>1]=z;b[d+(m+2<<1)>>1]=z;b[d+(s<<1)>>1]=z;z=(w+2+(y<<1)+A|0)>>>2&65535;b[d+(x+7<<1)>>1]=z;b[d+(v+5<<1)>>1]=z;b[d+(m+3<<1)>>1]=z;b[d+((s|1)<<1)>>1]=z;z=(w+1+y|0)>>>1&65535;b[d+(v+6<<1)>>1]=z;b[d+(m+4<<1)>>1]=z;b[d+((s|2)<<1)>>1]=z;b[d+(u<<1)>>1]=z;z=(h+2+(w<<1)+y|0)>>>2&65535;b[d+(v+7<<1)>>1]=z;b[d+(m+5<<1)>>1]=z;b[d+((s|3)<<1)>>1]=z;b[d+(u+1<<1)>>1]=z;z=(h+1+w|0)>>>1&65535;b[d+(m+6<<1)>>1]=z;b[d+(s+4<<1)>>1]=z;b[d+(u+2<<1)>>1]=z;b[d+(r<<1)>>1]=z;z=(f+2+(h<<1)+w|0)>>>2&65535;b[d+(m+7<<1)>>1]=z;b[d+(s+5<<1)>>1]=z;b[d+(u+3<<1)>>1]=z;b[d+((r|1)<<1)>>1]=z;z=f+1|0;m=(z+h|0)>>>1&65535;b[d+(s+6<<1)>>1]=m;b[d+(u+4<<1)>>1]=m;b[d+(r+2<<1)>>1]=m;b[d+(g<<1)>>1]=m;m=((f<<1)+2+h+D|0)>>>2&65535;b[d+(s+7<<1)>>1]=m;b[d+(u+5<<1)>>1]=m;b[d+(r+3<<1)>>1]=m;b[d+(g+1<<1)>>1]=m;m=(z+D|0)>>>1&65535;b[d+(u+6<<1)>>1]=m;b[d+(r+4<<1)>>1]=m;b[d+(g+2<<1)>>1]=m;b[d>>1]=m;m=k+2|0;z=(m+f+(D<<1)|0)>>>2&65535;b[d+(u+7<<1)>>1]=z;b[d+(r+5<<1)>>1]=z;b[d+(g+3<<1)>>1]=z;b[a+2>>1]=z;z=((k<<1)+2+l+D|0)>>>2&65535;b[d+(r+6<<1)>>1]=z;b[d+(g+4<<1)>>1]=z;b[a+4>>1]=z;z=(m+(l<<1)+n|0)>>>2&65535;b[d+(r+7<<1)>>1]=z;b[d+(g+5<<1)>>1]=z;b[a+6>>1]=z;z=(l+2+(n<<1)+o|0)>>>2&65535;b[d+(g+6<<1)>>1]=z;b[a+8>>1]=z;z=(n+2+(o<<1)+p|0)>>>2&65535;b[d+(g+7<<1)>>1]=z;b[a+10>>1]=z;b[a+12>>1]=(o+2+(p<<1)+q|0)>>>2;b[a+14>>1]=(p+2+(q<<1)+j|0)>>>2;return}function cra(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=a;h=f>>1;f=-h|0;i=e[g+(f<<1)>>1]|0;j=e[g+(1-h<<1)>>1]|0;k=((e[g+(((c|0)==0?f:~h)<<1)>>1]|0)+2+(i<<1)+j|0)>>>2;f=e[g+(2-h<<1)>>1]|0;c=(i+2+(j<<1)+f|0)>>>2;i=e[g+(3-h<<1)>>1]|0;l=(j+2+(f<<1)+i|0)>>>2;j=e[g+(4-h<<1)>>1]|0;m=(f+2+(i<<1)+j|0)>>>2;f=e[g+(5-h<<1)>>1]|0;n=(i+2+(j<<1)+f|0)>>>2;i=e[g+(6-h<<1)>>1]|0;o=(j+2+(f<<1)+i|0)>>>2;j=b[g+(7-h<<1)>>1]|0;p=j&65535;q=(f+2+(i<<1)+p|0)>>>2;if((d|0)==0){r=p;s=p;t=p;u=p;v=p;w=(j&65535)+2+(p<<1)|0}else{j=e[g+(8-h<<1)>>1]|0;d=e[g+(9-h<<1)>>1]|0;f=e[g+(10-h<<1)>>1]|0;x=e[g+(11-h<<1)>>1]|0;y=e[g+(12-h<<1)>>1]|0;r=(x+2+(y<<1)+(e[g+(13-h<<1)>>1]|0)|0)>>>2;s=(f+2+(x<<1)+y|0)>>>2;t=(d+2+(f<<1)+x|0)>>>2;u=(j+2+(d<<1)+f|0)>>>2;v=(p+2+(j<<1)+d|0)>>>2;w=(e[g+(8-h<<1)>>1]|0)+2+(p<<1)|0}p=(w+i|0)>>>2;b[g>>1]=(k+1+c|0)>>>1;b[g+(h<<1)>>1]=(k+2+(c<<1)+l|0)>>>2;k=(c+1+l|0)>>>1&65535;b[a+2>>1]=k;i=h<<1;b[g+(i<<1)>>1]=k;k=(c+2+(l<<1)+m|0)>>>2&65535;b[g+(h+1<<1)>>1]=k;c=h*3|0;b[g+(c<<1)>>1]=k;k=(l+1+m|0)>>>1&65535;b[a+4>>1]=k;b[g+((i|1)<<1)>>1]=k;w=h<<2;b[g+(w<<1)>>1]=k;k=(l+2+(m<<1)+n|0)>>>2&65535;b[g+(h+2<<1)>>1]=k;b[g+(c+1<<1)>>1]=k;l=h*5|0;b[g+(l<<1)>>1]=k;k=(m+1+n|0)>>>1&65535;b[a+6>>1]=k;b[g+(i+2<<1)>>1]=k;b[g+((w|1)<<1)>>1]=k;d=h*6|0;b[g+(d<<1)>>1]=k;k=(m+2+(n<<1)+o|0)>>>2&65535;b[g+(h+3<<1)>>1]=k;b[g+(c+2<<1)>>1]=k;b[g+(l+1<<1)>>1]=k;m=h*7|0;b[g+(m<<1)>>1]=k;k=(n+1+o|0)>>>1&65535;b[a+8>>1]=k;b[g+(i+3<<1)>>1]=k;b[g+((w|2)<<1)>>1]=k;b[g+((d|1)<<1)>>1]=k;k=(n+2+(o<<1)+q|0)>>>2&65535;b[g+(h+4<<1)>>1]=k;b[g+(c+3<<1)>>1]=k;b[g+(l+2<<1)>>1]=k;b[g+(m+1<<1)>>1]=k;k=(o+1+q|0)>>>1&65535;b[a+10>>1]=k;b[g+(i+4<<1)>>1]=k;b[g+((w|3)<<1)>>1]=k;b[g+(d+2<<1)>>1]=k;k=(o+2+(q<<1)+p|0)>>>2&65535;b[g+(h+5<<1)>>1]=k;b[g+(c+4<<1)>>1]=k;b[g+(l+3<<1)>>1]=k;b[g+(m+2<<1)>>1]=k;k=(q+1+p|0)>>>1&65535;b[a+12>>1]=k;b[g+(i+5<<1)>>1]=k;b[g+(w+4<<1)>>1]=k;b[g+(d+3<<1)>>1]=k;k=(q+2+(p<<1)+v|0)>>>2&65535;b[g+(h+6<<1)>>1]=k;b[g+(c+5<<1)>>1]=k;b[g+(l+4<<1)>>1]=k;b[g+(m+3<<1)>>1]=k;k=(p+1+v|0)>>>1&65535;b[a+14>>1]=k;b[g+(i+6<<1)>>1]=k;b[g+(w+5<<1)>>1]=k;b[g+(d+4<<1)>>1]=k;k=(p+2+(v<<1)+u|0)>>>2&65535;b[g+(h+7<<1)>>1]=k;b[g+(c+6<<1)>>1]=k;b[g+(l+5<<1)>>1]=k;b[g+(m+4<<1)>>1]=k;k=(v+1+u|0)>>>1&65535;b[g+(i+7<<1)>>1]=k;b[g+(w+6<<1)>>1]=k;b[g+(d+5<<1)>>1]=k;k=(v+2+(u<<1)+t|0)>>>2&65535;b[g+(c+7<<1)>>1]=k;b[g+(l+6<<1)>>1]=k;b[g+(m+5<<1)>>1]=k;k=(u+1+t|0)>>>1&65535;b[g+(w+7<<1)>>1]=k;b[g+(d+6<<1)>>1]=k;k=(u+2+(t<<1)+s|0)>>>2&65535;b[g+(l+7<<1)>>1]=k;b[g+(m+6<<1)>>1]=k;b[g+(d+7<<1)>>1]=(t+1+s|0)>>>1;b[g+(m+7<<1)>>1]=(t+2+(s<<1)+r|0)>>>2;return}function dra(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a;g=f>>1;if((c|0)==0){c=a-2|0;h=c;i=c}else{h=d+(~g<<1)|0;i=a-2|0}c=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=((e[h>>1]|0)+2+(c<<1)+i|0)>>>2;h=g<<1;j=e[d+(h-1<<1)>>1]|0;k=(c+2+(i<<1)+j|0)>>>2;c=g*3|0;l=e[d+(c-1<<1)>>1]|0;m=(i+2+(j<<1)+l|0)>>>2;i=g<<2;n=e[d+(i-1<<1)>>1]|0;o=(j+2+(l<<1)+n|0)>>>2;j=g*5|0;p=e[d+(j-1<<1)>>1]|0;q=(l+2+(n<<1)+p|0)>>>2;l=g*6|0;r=e[d+(l-1<<1)>>1]|0;s=(n+2+(p<<1)+r|0)>>>2;n=g*7|0;t=e[d+(n-1<<1)>>1]|0;u=(p+2+(r<<1)+t|0)>>>2;p=(r+2+(t*3|0)|0)>>>2;b[d>>1]=(f+1+k|0)>>>1;b[a+2>>1]=(f+2+(k<<1)+m|0)>>>2;f=(k+1+m|0)>>>1&65535;b[a+4>>1]=f;b[d+(g<<1)>>1]=f;f=(k+2+(m<<1)+o|0)>>>2&65535;b[a+6>>1]=f;b[d+(g+1<<1)>>1]=f;f=(m+1+o|0)>>>1&65535;b[a+8>>1]=f;b[d+(g+2<<1)>>1]=f;b[d+(h<<1)>>1]=f;f=(m+2+(o<<1)+q|0)>>>2&65535;b[a+10>>1]=f;b[d+(g+3<<1)>>1]=f;b[d+((h|1)<<1)>>1]=f;f=(o+1+q|0)>>>1&65535;b[a+12>>1]=f;b[d+(g+4<<1)>>1]=f;b[d+(h+2<<1)>>1]=f;b[d+(c<<1)>>1]=f;f=(o+2+(q<<1)+s|0)>>>2&65535;b[a+14>>1]=f;b[d+(g+5<<1)>>1]=f;b[d+(h+3<<1)>>1]=f;b[d+(c+1<<1)>>1]=f;f=(q+1+s|0)>>>1&65535;b[d+(g+6<<1)>>1]=f;b[d+(h+4<<1)>>1]=f;b[d+(c+2<<1)>>1]=f;b[d+(i<<1)>>1]=f;f=(q+2+(s<<1)+u|0)>>>2&65535;b[d+(g+7<<1)>>1]=f;b[d+(h+5<<1)>>1]=f;b[d+(c+3<<1)>>1]=f;b[d+((i|1)<<1)>>1]=f;f=(s+1+u|0)>>>1&65535;b[d+(h+6<<1)>>1]=f;b[d+(c+4<<1)>>1]=f;b[d+((i|2)<<1)>>1]=f;b[d+(j<<1)>>1]=f;f=(s+2+p+(u<<1)|0)>>>2&65535;b[d+(h+7<<1)>>1]=f;b[d+(c+5<<1)>>1]=f;b[d+((i|3)<<1)>>1]=f;b[d+(j+1<<1)>>1]=f;f=(p+1+u|0)>>>1&65535;b[d+(c+6<<1)>>1]=f;b[d+(i+4<<1)>>1]=f;b[d+(j+2<<1)>>1]=f;b[d+(l<<1)>>1]=f;f=(u+2+(p*3|0)|0)>>>2&65535;b[d+(c+7<<1)>>1]=f;b[d+(i+5<<1)>>1]=f;b[d+(j+3<<1)>>1]=f;b[d+((l|1)<<1)>>1]=f;f=p&65535;b[d+(n+7<<1)>>1]=f;b[d+(l+7<<1)>>1]=f;b[d+(j+7<<1)>>1]=f;b[d+(i+7<<1)>>1]=f;b[d+(n+6<<1)>>1]=f;b[d+(l+6<<1)>>1]=f;b[d+(j+6<<1)>>1]=f;b[d+(i+6<<1)>>1]=f;b[d+(n+5<<1)>>1]=f;b[d+(l+5<<1)>>1]=f;b[d+(j+5<<1)>>1]=f;b[d+(n+4<<1)>>1]=f;b[d+(l+4<<1)>>1]=f;b[d+(j+4<<1)>>1]=f;b[d+(n+3<<1)>>1]=f;b[d+(l+3<<1)>>1]=f;b[d+(n+2<<1)>>1]=f;b[d+(l+2<<1)>>1]=f;b[d+(n+1<<1)>>1]=f;b[d+(n<<1)>>1]=f;return}function era(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;g=f>>1;if((b|0)==0){b=a-2|0;h=b;i=b}else{h=d+(~g<<1)|0;i=a-2|0}b=e[i>>1]|0;i=e[d+(g-1<<1)>>1]|0;f=e[d+((g<<1)-1<<1)>>1]|0;j=e[d+((g*3|0)-1<<1)>>1]|0;k=e[d+((g<<2)-1<<1)>>1]|0;l=e[d+((g*5|0)-1<<1)>>1]|0;m=e[d+((g*6|0)-1<<1)>>1]|0;n=e[d+((g*7|0)-1<<1)>>1]|0;o=(((e[h>>1]|0)+2+(b<<1)+i|0)>>>2)+4+((b+2+(i<<1)+f|0)>>>2)+((i+2+(f<<1)+j|0)>>>2)+((f+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n*3|0)|0)>>>2)>>3;n=Erc(o,(o|0)<0|0?-1:0,65537,65537)|0;o=G;m=a;c[m>>2]=n;c[m+4>>2]=o;m=a+8|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(g+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=g<<1;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;m=d+(a<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=d+(a+4<<1)|0;c[m>>2]=n;c[m+4>>2]=o;m=a+g|0;a=d+(m<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=d+(m+4<<1)|0;c[a>>2]=n;c[a+4>>2]=o;a=m+g|0;g=d+(a<<1)|0;c[g>>2]=n;c[g+4>>2]=o;g=d+(a+4<<1)|0;c[g>>2]=n;c[g+4>>2]=o;return}function fra(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a;i=g>>1;g=-i|0;j=e[h+(g<<1)>>1]|0;k=e[h+(1-i<<1)>>1]|0;l=e[h+(2-i<<1)>>1]|0;m=e[h+(3-i<<1)>>1]|0;n=e[h+(4-i<<1)>>1]|0;o=e[h+(5-i<<1)>>1]|0;p=e[h+(6-i<<1)>>1]|0;q=b[h+(7-i<<1)>>1]|0;r=q&65535;if((f|0)==0){s=q}else{s=b[h+(8-i<<1)>>1]|0}q=(((e[h+(((d|0)==0?g:~i)<<1)>>1]|0)+2+(j<<1)+k|0)>>>2)+4+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+r|0)>>>2)+(((s&65535)+2+(r<<1)+p|0)>>>2)>>3;p=Erc(q,(q|0)<0|0?-1:0,65537,65537)|0;q=G;r=a;c[r>>2]=p;c[r+4>>2]=q;r=a+8|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(i+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=i<<1;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;r=h+(a<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=h+(a+4<<1)|0;c[r>>2]=p;c[r+4>>2]=q;r=a+i|0;a=h+(r<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=h+(r+4<<1)|0;c[a>>2]=p;c[a+4>>2]=q;a=r+i|0;i=h+(a<<1)|0;c[i>>2]=p;c[i+4>>2]=q;i=h+(a+4<<1)|0;c[i>>2]=p;c[i+4>>2]=q;return}function gra(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;b=e>>1;e=a;c[e>>2]=536879104;c[e+4>>2]=536879104;e=a+8|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(b<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(b+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=b<<1;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e+b|0;e=d+(a<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=a+b|0;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e+b|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;return}function hra(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function ira(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=Erc(e[a-2>>1]|0,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=a+8|0;c[h>>2]=b;c[h+4>>2]=g;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;b=d+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(f+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f<<1;b=Erc(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=G;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*3|0;a=Erc(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;b=G;h=d+(g<<1)|0;c[h>>2]=a;c[h+4>>2]=b;h=d+(g+4<<1)|0;c[h>>2]=a;c[h+4>>2]=b;b=f<<2;h=Erc(e[d+(b-1<<1)>>1]|0,0,65537,65537)|0;a=G;g=d+(b<<1)|0;c[g>>2]=h;c[g+4>>2]=a;g=d+(b+4<<1)|0;c[g>>2]=h;c[g+4>>2]=a;a=f*5|0;g=Erc(e[d+(a-1<<1)>>1]|0,0,65537,65537)|0;h=G;b=d+(a<<1)|0;c[b>>2]=g;c[b+4>>2]=h;b=d+(a+4<<1)|0;c[b>>2]=g;c[b+4>>2]=h;h=f*6|0;b=Erc(e[d+(h-1<<1)>>1]|0,0,65537,65537)|0;g=G;a=d+(h<<1)|0;c[a>>2]=b;c[a+4>>2]=g;a=d+(h+4<<1)|0;c[a>>2]=b;c[a+4>>2]=g;g=f*7|0;f=Erc(e[d+(g-1<<1)>>1]|0,0,65537,65537)|0;a=G;b=d+(g<<1)|0;c[b>>2]=f;c[b+4>>2]=a;b=d+(g+4<<1)|0;c[b>>2]=f;c[b+4>>2]=a;return}function jra(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a;e=b>>1;b=d+(-e<<1)|0;f=c[b>>2]|0;g=c[b+4>>2]|0;b=d+(4-e<<1)|0;h=c[b>>2]|0;i=c[b+4>>2]|0;b=a;c[b>>2]=f;c[b+4>>2]=g;b=a+8|0;c[b>>2]=h;c[b+4>>2]=i;b=d+(e<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(e+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<1;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<2;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*7|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e<<3;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+((b|4)<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*9|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*10|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*11|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*12|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*13|0;b=d+(a<<1)|0;c[b>>2]=f;c[b+4>>2]=g;b=d+(a+4<<1)|0;c[b>>2]=h;c[b+4>>2]=i;b=e*14|0;a=d+(b<<1)|0;c[a>>2]=f;c[a+4>>2]=g;a=d+(b+4<<1)|0;c[a>>2]=h;c[a+4>>2]=i;a=e*15|0;e=d+(a<<1)|0;c[e>>2]=f;c[e+4>>2]=g;g=d+(a+4<<1)|0;c[g>>2]=h;c[g+4>>2]=i;return}function kra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ca(b,a)|0;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function lra(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a;f=c>>1;c=a+6|0;g=(f<<2)-1|0;h=g-(f<<1)|0;i=g+f|0;j=h-f|0;k=i+f|0;l=j-f|0;m=e[d+(k+f<<1)>>1]|0;n=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=(((m-(e[d+(l-f<<1)>>1]|0)<<2)+((((e[d+(k<<1)>>1]|0)-(e[d+(l<<1)>>1]|0)|0)*3|0)+(((e[d+(i<<1)>>1]|0)-(e[d+(j<<1)>>1]|0)<<1)+((e[d+(g<<1)>>1]|0)-(e[d+(h<<1)>>1]|0))))|0)*17|0)+16>>5;h=n<<1;g=n*3|0;j=n<<2;i=n*5|0;l=n*6|0;k=n*7|0;o=d;d=((c+n|0)*-3|0)+16+((e[a-2+(8-f<<1)>>1]|0)+m<<4)|0;m=8;while(1){a=d>>5;if(a>>>0<16384>>>0){p=a&65535}else{p=-a>>31&16383}b[o>>1]=p;a=d+n>>5;if(a>>>0<16384>>>0){q=a&65535}else{q=-a>>31&16383}b[o+2>>1]=q;a=d+h>>5;if(a>>>0<16384>>>0){r=a&65535}else{r=-a>>31&16383}b[o+4>>1]=r;a=d+g>>5;if(a>>>0<16384>>>0){s=a&65535}else{s=-a>>31&16383}b[o+6>>1]=s;a=d+j>>5;if(a>>>0<16384>>>0){t=a&65535}else{t=-a>>31&16383}b[o+8>>1]=t;a=d+i>>5;if(a>>>0<16384>>>0){u=a&65535}else{u=-a>>31&16383}b[o+10>>1]=u;a=d+l>>5;if(a>>>0<16384>>>0){v=a&65535}else{v=-a>>31&16383}b[o+12>>1]=v;a=d+k>>5;if(a>>>0<16384>>>0){w=a&65535}else{w=-a>>31&16383}b[o+14>>1]=w;a=m-1|0;if((a|0)>0){o=o+(f<<1)|0;d=d+c|0;m=a}else{break}}return}function mra(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=a;f=c>>1;c=a+6|0;g=-f|0;h=(f<<3)-1|0;i=h-(f<<1)|0;j=h+f|0;k=i-f|0;l=j+f|0;m=k-f|0;n=a+((f*6|0)-2)|0;o=a+((f*22|0)-2)|0;p=f<<1;q=g<<1;r=p+f|0;s=q-f|0;t=b[o+(r+f<<1)>>1]|0;u=((((e[c+(4-f<<1)>>1]|0)-(e[c+(-4-f<<1)>>1]|0)<<2)+((((e[c+(3-f<<1)>>1]|0)-(e[c+(-3-f<<1)>>1]|0)|0)*3|0)+(((e[c+(2-f<<1)>>1]|0)-(e[c+(-2-f<<1)>>1]|0)<<1)+((e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0))))|0)*17|0)+16>>5;c=((((t&65535)-(e[n+(s-f<<1)>>1]|0)<<3)+((((e[o+(r<<1)>>1]|0)-(e[n+(s<<1)>>1]|0)|0)*7|0)+((((e[o+(p<<1)>>1]|0)-(e[n+(q<<1)>>1]|0)|0)*6|0)+((((e[o+(f<<1)>>1]|0)-(e[n+(g<<1)>>1]|0)|0)*5|0)+(((e[d+(l+f<<1)>>1]|0)-(e[d+(m-f<<1)>>1]|0)<<2)+((((e[d+(l<<1)>>1]|0)-(e[d+(m<<1)>>1]|0)|0)*3|0)+(((e[d+(j<<1)>>1]|0)-(e[d+(k<<1)>>1]|0)<<1)+((e[d+(h<<1)>>1]|0)-(e[d+(i<<1)>>1]|0))))))))|0)*5|0)+32>>6;i=u*3|0;h=u<<1;k=u<<2;j=u*5|0;m=u*6|0;l=u*7|0;g=d;d=16-i+(c*-7|0)+((e[a+(-2-(f<<1)+16)>>1]|0)+(t&65535)<<4)|0;t=16;while(1){a=d>>5;if(a>>>0<16384>>>0){v=a&65535}else{v=-a>>31&16383}b[g>>1]=v;a=d+u>>5;if(a>>>0<16384>>>0){w=a&65535}else{w=-a>>31&16383}b[g+2>>1]=w;a=d+h>>5;if(a>>>0<16384>>>0){x=a&65535}else{x=-a>>31&16383}b[g+4>>1]=x;a=d+i>>5;if(a>>>0<16384>>>0){y=a&65535}else{y=-a>>31&16383}b[g+6>>1]=y;a=d+k>>5;if(a>>>0<16384>>>0){z=a&65535}else{z=-a>>31&16383}b[g+8>>1]=z;a=d+j>>5;if(a>>>0<16384>>>0){A=a&65535}else{A=-a>>31&16383}b[g+10>>1]=A;a=d+m>>5;if(a>>>0<16384>>>0){B=a&65535}else{B=-a>>31&16383}b[g+12>>1]=B;a=d+l>>5;if(a>>>0<16384>>>0){C=a&65535}else{C=-a>>31&16383}b[g+14>>1]=C;a=t-1|0;if((a|0)>0){g=g+(f<<1)|0;d=d+c|0;t=a}else{break}}return}function nra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=(e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+(e[d+(4-f<<1)>>1]|0)))|0;l=f*7|0;m=(e[d+(l-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;n=(e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+((e[a-2>>1]|0)+(e[d+(-f<<1)>>1]|0))+(e[d+(1-f<<1)>>1]|0))+(e[d+(2-f<<1)>>1]|0))+(e[d+(3-f<<1)>>1]|0)+4>>3;o=Erc(n,(n|0)<0|0?-1:0,65537,65537)|0;n=G;p=Erc((k+2|0)>>>2,0,65537,65537)|0;q=G;r=m+4+k>>3;k=a;c[k>>2]=o;c[k+4>>2]=n;k=a+8|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(f<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(f+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(h<<1)|0;c[k>>2]=o;c[k+4>>2]=n;k=d+(h+4<<1)|0;c[k>>2]=p;c[k+4>>2]=q;k=d+(j<<1)|0;c[k>>2]=o;c[k+4>>2]=n;n=d+(j+4<<1)|0;c[n>>2]=p;c[n+4>>2]=q;q=Erc((m+2|0)>>>2,0,65537,65537)|0;m=G;n=Erc(r,(r|0)<0|0?-1:0,65537,65537)|0;r=G;p=d+(b<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(b+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(g<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(g+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(i<<1)|0;c[p>>2]=q;c[p+4>>2]=m;p=d+(i+4<<1)|0;c[p>>2]=n;c[p+4>>2]=r;p=d+(l<<1)|0;c[p>>2]=q;c[p+4>>2]=m;m=d+(l+4<<1)|0;c[m>>2]=n;c[m+4>>2]=r;return}function ora(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a;f=b>>1;b=f<<2;g=f*5|0;h=f<<1;i=f*6|0;j=f*3|0;k=f*7|0;l=(e[d+(k-1<<1)>>1]|0)+((e[d+(i-1<<1)>>1]|0)+((e[d+(g-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)))|0;m=Erc(((e[d+(j-1<<1)>>1]|0)+((e[d+(h-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))+2|0)>>>2,0,65537,65537)|0;n=G;o=a;c[o>>2]=m;c[o+4>>2]=n;o=a+8|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(f+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(h+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j<<1)|0;c[o>>2]=m;c[o+4>>2]=n;o=d+(j+4<<1)|0;c[o>>2]=m;c[o+4>>2]=n;n=Erc((l+2|0)>>>2,0,65537,65537)|0;l=G;o=d+(b<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(b+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(g+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(i+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k<<1)|0;c[o>>2]=n;c[o+4>>2]=l;o=d+(k+4<<1)|0;c[o>>2]=n;c[o+4>>2]=l;return}function pra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=Erc(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=G;i=Erc((g+2|0)>>>2,0,65537,65537)|0;g=G;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function qra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;pra(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function rra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;nra(a,b);d=a;f=b>>1;b=Erc(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function sra(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;ora(a,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=536879104;c[b+4>>2]=536879104;b=f+(g<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=g<<1;e=f+(b<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=536879104;c[h+4>>2]=536879104;h=a+(d+8)|0;d=h;a=h;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(g<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;return}function tra(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;ora(a,b);d=a;e=b>>1;b=a;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<1;f=d+(b<<1)|0;c[f>>2]=536879104;c[f+4>>2]=536879104;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=536879104;c[g+4>>2]=536879104;g=a+8|0;a=g;d=g;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(e<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(b<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(f<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;return}function ura(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a;f=b>>1;b=0;g=0;h=0;i=0;j=0;k=0;do{l=e[d+((ca(k,f)|0)-1<<1)>>1]|0;j=l+j+(e[d+(k-f<<1)>>1]|0)|0;l=k+4|0;i=(e[d+(l-f<<1)>>1]|0)+i|0;h=(e[d+((ca(l,f)|0)-1<<1)>>1]|0)+h|0;g=(e[d+((ca(k+8|0,f)|0)-1<<1)>>1]|0)+g|0;b=(e[d+((ca(k+12|0,f)|0)-1<<1)>>1]|0)+b|0;k=k+1|0;}while((k|0)<4);k=j+4>>3;j=Erc(k,(k|0)<0|0?-1:0,65537,65537)|0;k=G;l=i+2>>2;m=Erc(l,(l|0)<0|0?-1:0,65537,65537)|0;l=G;n=h+2>>2;o=h+4+i>>3;h=g+2>>2;p=g+4+i>>3;g=b+2>>2;q=b+4+i>>3;i=a;c[i>>2]=j;c[i+4>>2]=k;i=a+8|0;c[i>>2]=m;c[i+4>>2]=l;i=d+(f<<1)|0;c[i>>2]=j;c[i+4>>2]=k;i=d+(f+4<<1)|0;c[i>>2]=m;c[i+4>>2]=l;i=f<<1;a=d+(i<<1)|0;c[a>>2]=j;c[a+4>>2]=k;a=d+(i+4<<1)|0;c[a>>2]=m;c[a+4>>2]=l;a=f*3|0;i=d+(a<<1)|0;c[i>>2]=j;c[i+4>>2]=k;k=d+(a+4<<1)|0;c[k>>2]=m;c[k+4>>2]=l;l=Erc(n,(n|0)<0|0?-1:0,65537,65537)|0;n=G;k=Erc(o,(o|0)<0|0?-1:0,65537,65537)|0;o=G;m=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;a=Erc(p,(p|0)<0|0?-1:0,65537,65537)|0;p=G;i=Erc(g,(g|0)<0|0?-1:0,65537,65537)|0;g=G;j=Erc(q,(q|0)<0|0?-1:0,65537,65537)|0;q=G;b=f<<2;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*5|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;b=d+(r+4<<1)|0;c[b>>2]=k;c[b+4>>2]=o;b=f*6|0;r=d+(b<<1)|0;c[r>>2]=l;c[r+4>>2]=n;r=d+(b+4<<1)|0;c[r>>2]=k;c[r+4>>2]=o;r=f*7|0;b=d+(r<<1)|0;c[b>>2]=l;c[b+4>>2]=n;n=d+(r+4<<1)|0;c[n>>2]=k;c[n+4>>2]=o;o=f<<3;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+((o|4)<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*9|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;o=d+(n+4<<1)|0;c[o>>2]=a;c[o+4>>2]=p;o=f*10|0;n=d+(o<<1)|0;c[n>>2]=m;c[n+4>>2]=h;n=d+(o+4<<1)|0;c[n>>2]=a;c[n+4>>2]=p;n=f*11|0;o=d+(n<<1)|0;c[o>>2]=m;c[o+4>>2]=h;h=d+(n+4<<1)|0;c[h>>2]=a;c[h+4>>2]=p;p=f*12|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*13|0;p=d+(h<<1)|0;c[p>>2]=i;c[p+4>>2]=g;p=d+(h+4<<1)|0;c[p>>2]=j;c[p+4>>2]=q;p=f*14|0;h=d+(p<<1)|0;c[h>>2]=i;c[h+4>>2]=g;h=d+(p+4<<1)|0;c[h>>2]=j;c[h+4>>2]=q;h=f*15|0;f=d+(h<<1)|0;c[f>>2]=i;c[f+4>>2]=g;g=d+(h+4<<1)|0;c[g>>2]=j;c[g+4>>2]=q;return}function vra(a,b){a=a|0;b=b|0;ora(a,b);ora(a+(b<<3)|0,b);return}function wra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=a;f=b>>1;b=4-f|0;g=(e[d+(b+3<<1)>>1]|0)+((e[d+(b+2<<1)>>1]|0)+((e[d+(b+1<<1)>>1]|0)+(e[d+(b<<1)>>1]|0)))|0;b=Erc(((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))+2|0)>>>2,0,65537,65537)|0;h=G;i=Erc((g+2|0)>>>2,0,65537,65537)|0;g=G;j=a;c[j>>2]=b;c[j+4>>2]=h;j=a+8|0;c[j>>2]=i;c[j+4>>2]=g;j=d+(f<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(f+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<1;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*3|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<2;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*5|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*6|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*7|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f<<3;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+((j|4)<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*9|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*10|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*11|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*12|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*13|0;j=d+(a<<1)|0;c[j>>2]=b;c[j+4>>2]=h;j=d+(a+4<<1)|0;c[j>>2]=i;c[j+4>>2]=g;j=f*14|0;a=d+(j<<1)|0;c[a>>2]=b;c[a+4>>2]=h;a=d+(j+4<<1)|0;c[a>>2]=i;c[a+4>>2]=g;a=f*15|0;f=d+(a<<1)|0;c[f>>2]=b;c[f+4>>2]=h;h=d+(a+4<<1)|0;c[h>>2]=i;c[h+4>>2]=g;return}function xra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;wra(a,b);d=a;f=b>>1;b=f<<1;g=f*3|0;h=(e[d+(-f<<1)>>1]|0)+4+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)+(e[a-2>>1]|0)+(e[d+(f-1<<1)>>1]|0)+(e[d+(b-1<<1)>>1]|0)+(e[d+(g-1<<1)>>1]|0)>>3;i=Erc(h,(h|0)<0|0?-1:0,65537,65537)|0;h=G;j=a;c[j>>2]=i;c[j+4>>2]=h;j=d+(f<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(b<<1)|0;c[j>>2]=i;c[j+4>>2]=h;j=d+(g<<1)|0;c[j>>2]=i;c[j+4>>2]=h;return}function yra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;ura(a,b);d=a;f=b>>1;b=Erc(((e[d+(-f<<1)>>1]|0)+2+(e[d+(1-f<<1)>>1]|0)+(e[d+(2-f<<1)>>1]|0)+(e[d+(3-f<<1)>>1]|0)|0)>>>2,0,65537,65537)|0;g=G;h=a;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+(f<<1<<1)|0;c[h>>2]=b;c[h+4>>2]=g;h=d+((f*3|0)<<1)|0;c[h>>2]=b;c[h+4>>2]=g;return}function zra(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;ora(a,b);ora(a+(b<<3)|0,b);d=b<<2;e=a+d|0;f=e;g=b>>1;b=e;c[b>>2]=536879104;c[b+4>>2]=536879104;b=f+(g<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=g<<1;e=f+(b<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=g*3|0;h=f+(e<<1)|0;c[h>>2]=536879104;c[h+4>>2]=536879104;h=a+(d+8)|0;d=h;a=h;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(g<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(e<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;return}function Ara(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;ora(a,b);ora(a+(b<<3)|0,b);d=a;e=b>>1;b=a;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<1;f=d+(b<<1)|0;c[f>>2]=536879104;c[f+4>>2]=536879104;f=e*3|0;g=d+(f<<1)|0;c[g>>2]=536879104;c[g+4>>2]=536879104;g=a+8|0;a=g;d=g;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(e<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(b<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;d=a+(f<<1)|0;c[d>>2]=536879104;c[d+4>>2]=536879104;return}function Bra(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+8|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=e<<2;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;e=d+(a+4<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;return}function Cra(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+8|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=e<<2;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;e=d+(a+4<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;return}function Dra(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+8|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e*3|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<2;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e*5|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e*6|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=e*7|0;e=d+(a<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;return}function Era(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=a;e=b>>1;f=a;c[f>>2]=536879104;c[f+4>>2]=536879104;f=a+8|0;c[f>>2]=536879104;c[f+4>>2]=536879104;f=d+(e<<1)|0;c[f>>2]=536879104;c[f+4>>2]=536879104;f=e+4|0;g=d+(f<<1)|0;c[g>>2]=536879104;c[g+4>>2]=536879104;g=e<<1;h=d+(g<<1)|0;c[h>>2]=536879104;c[h+4>>2]=536879104;h=g+4|0;i=d+(h<<1)|0;c[i>>2]=536879104;c[i+4>>2]=536879104;i=e*3|0;j=d+(i<<1)|0;c[j>>2]=536879104;c[j+4>>2]=536879104;j=i+4|0;k=d+(j<<1)|0;c[k>>2]=536879104;c[k+4>>2]=536879104;k=e<<2;l=d+(k<<1)|0;c[l>>2]=536879104;c[l+4>>2]=536879104;l=k+4|0;m=d+(l<<1)|0;c[m>>2]=536879104;c[m+4>>2]=536879104;m=e*5|0;n=d+(m<<1)|0;c[n>>2]=536879104;c[n+4>>2]=536879104;n=m+4|0;o=d+(n<<1)|0;c[o>>2]=536879104;c[o+4>>2]=536879104;o=e*6|0;p=d+(o<<1)|0;c[p>>2]=536879104;c[p+4>>2]=536879104;p=o+4|0;q=d+(p<<1)|0;c[q>>2]=536879104;c[q+4>>2]=536879104;q=e*7|0;r=d+(q<<1)|0;c[r>>2]=536879104;c[r+4>>2]=536879104;r=q+4|0;s=d+(r<<1)|0;c[s>>2]=536879104;c[s+4>>2]=536879104;s=b<<3;b=a+s|0;d=b;t=b;c[t>>2]=536879104;c[t+4>>2]=536879104;t=a+(s+8)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(e<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(f<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(g<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(h<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(i<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(j<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(k<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(l<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(m<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(n<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(o<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(p<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(q<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;t=d+(r<<1)|0;c[t>>2]=536879104;c[t+4>>2]=536879104;return}function Fra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+((e[d+(-f<<1)>>1]|0)+((e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))))))))))))))))))+16>>5;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Gra(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a;a=b>>1;b=d+(-a<<1)|0;e=c[b>>2]|0;f=c[b+4>>2]|0;b=d+(4-a<<1)|0;g=c[b>>2]|0;h=c[b+4>>2]|0;b=d+(8-a<<1)|0;i=c[b>>2]|0;j=c[b+4>>2]|0;b=d+(12-a<<1)|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=0;do{m=ca(b,a)|0;n=d+(m<<1)|0;c[n>>2]=e;c[n+4>>2]=f;n=d+(m+4<<1)|0;c[n>>2]=g;c[n+4>>2]=h;n=d+(m+8<<1)|0;c[n>>2]=i;c[n+4>>2]=j;n=d+(m+12<<1)|0;c[n>>2]=k;c[n+4>>2]=l;b=b+1|0;}while((b|0)<16);return}function Hra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0;d=a;a=b>>1;b=0;do{f=ca(b,a)|0;g=Erc(e[d+(f-1<<1)>>1]|0,0,65537,65537)|0;h=G;i=d+(f<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+4<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+8<<1)|0;c[i>>2]=g;c[i+4>>2]=h;i=d+(f+12<<1)|0;c[i>>2]=g;c[i+4>>2]=h;b=b+1|0;}while((b|0)<16);return}function Ira(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+8|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+16|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+24|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(e+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+4<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+8<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=d+(a+12<<1)|0;c[b>>2]=536813567;c[b+4>>2]=536813567;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+4<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+8<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=d+(b+12<<1)|0;c[a>>2]=536813567;c[a+4>>2]=536813567;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;e=d+(a+4<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;e=d+(a+8<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;e=d+(a+12<<1)|0;c[e>>2]=536813567;c[e+4>>2]=536813567;return}function Jra(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+8|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+16|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+24|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(e+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+4<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+8<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=d+(a+12<<1)|0;c[b>>2]=536944641;c[b+4>>2]=536944641;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+4<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+8<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=d+(b+12<<1)|0;c[a>>2]=536944641;c[a+4>>2]=536944641;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;e=d+(a+4<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;e=d+(a+8<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;e=d+(a+12<<1)|0;c[e>>2]=536944641;c[e+4>>2]=536944641;return}function Kra(a,c){a=a|0;c=c|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a;f=c>>1;c=a+14|0;g=-f|0;h=(f<<3)-1|0;i=d+(h<<1)|0;j=d+(h-(f<<1)<<1)|0;h=a+((f*30|0)-2)|0;k=2;l=i;m=j;n=(e[c+(1-f<<1)>>1]|0)-(e[c+(~f<<1)>>1]|0)|0;o=(e[i>>1]|0)-(e[j>>1]|0)|0;do{l=l+(f<<1)|0;m=m+(g<<1)|0;n=(ca((e[c+(k-f<<1)>>1]|0)-(e[c+(-(f+k|0)<<1)>>1]|0)|0,k)|0)+n|0;o=(ca((e[l>>1]|0)-(e[m>>1]|0)|0,k)|0)+o|0;k=k+1|0;}while((k|0)<9);k=(n*5|0)+32>>6;n=(o*5|0)+32>>6;o=k<<1;m=k*3|0;l=k<<2;c=((n+k|0)*-7|0)+16+((e[a-2+(16-f<<1)>>1]|0)+(e[h>>1]|0)<<4)|0;h=d;d=16;while(1){a=-16;g=c;while(1){j=g>>5;if(j>>>0<16384>>>0){p=j&65535}else{p=-j>>31&16383}b[h+(a+16<<1)>>1]=p;j=g+k>>5;if(j>>>0<16384>>>0){q=j&65535}else{q=-j>>31&16383}b[h+(a+17<<1)>>1]=q;j=g+o>>5;if(j>>>0<16384>>>0){r=j&65535}else{r=-j>>31&16383}b[h+(a+18<<1)>>1]=r;j=g+m>>5;if(j>>>0<16384>>>0){s=j&65535}else{s=-j>>31&16383}b[h+(a+19<<1)>>1]=s;j=a+4|0;if((j|0)<0){a=j;g=g+l|0}else{break}}g=d-1|0;if((g|0)>0){c=c+n|0;h=h+(f<<1)|0;d=g}else{break}}return}function Lra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+((f*15|0)-1<<1)>>1]|0)+((e[d+((f*14|0)-1<<1)>>1]|0)+((e[d+((f*13|0)-1<<1)>>1]|0)+((e[d+((f*12|0)-1<<1)>>1]|0)+((e[d+((f*11|0)-1<<1)>>1]|0)+((e[d+((f*10|0)-1<<1)>>1]|0)+((e[d+((f*9|0)-1<<1)>>1]|0)+((e[d+((f<<3)-1<<1)>>1]|0)+((e[d+((f*7|0)-1<<1)>>1]|0)+((e[d+((f*6|0)-1<<1)>>1]|0)+((e[d+((f*5|0)-1<<1)>>1]|0)+((e[d+((f<<2)-1<<1)>>1]|0)+((e[d+((f*3|0)-1<<1)>>1]|0)+((e[d+((f<<1)-1<<1)>>1]|0)+((e[d+(f-1<<1)>>1]|0)+(e[a-2>>1]|0)))))))))))))))+8>>4;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Mra(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=a;f=b>>1;b=(e[d+(15-f<<1)>>1]|0)+((e[d+(14-f<<1)>>1]|0)+((e[d+(13-f<<1)>>1]|0)+((e[d+(12-f<<1)>>1]|0)+((e[d+(11-f<<1)>>1]|0)+((e[d+(10-f<<1)>>1]|0)+((e[d+(9-f<<1)>>1]|0)+((e[d+(8-f<<1)>>1]|0)+((e[d+(7-f<<1)>>1]|0)+((e[d+(6-f<<1)>>1]|0)+((e[d+(5-f<<1)>>1]|0)+((e[d+(4-f<<1)>>1]|0)+((e[d+(3-f<<1)>>1]|0)+((e[d+(2-f<<1)>>1]|0)+((e[d+(1-f<<1)>>1]|0)+(e[d+(-f<<1)>>1]|0)))))))))))))))+8>>4;g=Erc(b,(b|0)<0|0?-1:0,65537,65537)|0;b=G;h=a;c[h>>2]=g;c[h+4>>2]=b;h=a+8|0;c[h>>2]=g;c[h+4>>2]=b;h=a+16|0;c[h>>2]=g;c[h+4>>2]=b;h=a+24|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(f+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=f<<1;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;h=d+(a<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+4<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+8<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=d+(a+12<<1)|0;c[h>>2]=g;c[h+4>>2]=b;h=a+f|0;a=d+(h<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+4<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+8<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=d+(h+12<<1)|0;c[a>>2]=g;c[a+4>>2]=b;a=h+f|0;f=d+(a<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+4<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+8<<1)|0;c[f>>2]=g;c[f+4>>2]=b;f=d+(a+12<<1)|0;c[f>>2]=g;c[f+4>>2]=b;return}function Nra(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;e=b>>1;b=a;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+8|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+16|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+24|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(e+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=e<<1;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;b=d+(a<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+4<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+8<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=d+(a+12<<1)|0;c[b>>2]=536879104;c[b+4>>2]=536879104;b=a+e|0;a=d+(b<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+4<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+8<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=d+(b+12<<1)|0;c[a>>2]=536879104;c[a+4>>2]=536879104;a=b+e|0;e=d+(a<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+4<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+8<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;e=d+(a+12<<1)|0;c[e>>2]=536879104;c[e+4>>2]=536879104;return}function Ora(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=a;h=f>>1;f=h<<1;i=h*3|0;j=h<<2;k=(e[g+(-h<<1)>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=k;l=k+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=l;k=l+(c[d+32>>2]|0)|0;b[g+(i-h<<1)>>1]=k;b[g+(j-h<<1)>>1]=k+(c[d+48>>2]|0);k=1-h|0;h=(e[g+(k<<1)>>1]|0)+(c[d+4>>2]|0)|0;b[a+2>>1]=h;l=h+(c[d+20>>2]|0)|0;b[g+(k+f<<1)>>1]=l;h=l+(c[d+36>>2]|0)|0;b[g+(k+i<<1)>>1]=h;b[g+(k+j<<1)>>1]=h+(c[d+52>>2]|0);h=k+1|0;l=(e[g+(h<<1)>>1]|0)+(c[d+8>>2]|0)|0;b[a+4>>1]=l;m=l+(c[d+24>>2]|0)|0;b[g+(h+f<<1)>>1]=m;l=m+(c[d+40>>2]|0)|0;b[g+(h+i<<1)>>1]=l;b[g+(h+j<<1)>>1]=l+(c[d+56>>2]|0);l=k+2|0;k=(e[g+(l<<1)>>1]|0)+(c[d+12>>2]|0)|0;b[a+6>>1]=k;a=k+(c[d+28>>2]|0)|0;b[g+(l+f<<1)>>1]=a;f=a+(c[d+44>>2]|0)|0;b[g+(l+i<<1)>>1]=f;b[g+(l+j<<1)>>1]=f+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function Pra(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=a;h=f>>1;f=(e[a-2>>1]|0)+(c[d>>2]|0)|0;b[g>>1]=f;i=f+(c[d+4>>2]|0)|0;b[a+2>>1]=i;f=i+(c[d+8>>2]|0)|0;b[a+4>>1]=f;b[a+6>>1]=f+(c[d+12>>2]|0);f=(e[g+(h-1<<1)>>1]|0)+(c[d+16>>2]|0)|0;b[g+(h<<1)>>1]=f;a=f+(c[d+20>>2]|0)|0;b[g+(h+1<<1)>>1]=a;f=a+(c[d+24>>2]|0)|0;b[g+(h+2<<1)>>1]=f;b[g+(h+3<<1)>>1]=f+(c[d+28>>2]|0);f=h<<1;a=(e[g+(f-1<<1)>>1]|0)+(c[d+32>>2]|0)|0;b[g+(f<<1)>>1]=a;i=a+(c[d+36>>2]|0)|0;b[g+((f|1)<<1)>>1]=i;a=i+(c[d+40>>2]|0)|0;b[g+(f+2<<1)>>1]=a;b[g+(f+3<<1)>>1]=a+(c[d+44>>2]|0);a=f+h|0;h=(e[g+(a-1<<1)>>1]|0)+(c[d+48>>2]|0)|0;b[g+(a<<1)>>1]=h;f=h+(c[d+52>>2]|0)|0;b[g+(a+1<<1)>>1]=f;h=f+(c[d+56>>2]|0)|0;b[g+(a+2<<1)>>1]=h;b[g+(a+3<<1)>>1]=h+(c[d+60>>2]|0);mrc(d|0,0,64)|0;return}function Qra(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f>>1;f=g<<1;h=g*3|0;i=g<<2;j=g*5|0;k=g*6|0;l=g*7|0;m=g<<3;n=0;o=a+(-g<<1)|0;a=d;while(1){p=(e[o>>1]|0)+(c[a>>2]|0)|0;b[o+(g<<1)>>1]=p;q=p+(c[a+32>>2]|0)|0;b[o+(f<<1)>>1]=q;p=q+(c[a+64>>2]|0)|0;b[o+(h<<1)>>1]=p;q=p+(c[a+96>>2]|0)|0;b[o+(i<<1)>>1]=q;p=q+(c[a+128>>2]|0)|0;b[o+(j<<1)>>1]=p;q=p+(c[a+160>>2]|0)|0;b[o+(k<<1)>>1]=q;p=q+(c[a+192>>2]|0)|0;b[o+(l<<1)>>1]=p;b[o+(m<<1)>>1]=p+(c[a+224>>2]|0);p=n+1|0;if((p|0)<8){n=p;o=o+2|0;a=a+4|0}else{break}}mrc(d|0,0,256)|0;return}function Rra(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>1;f=0;h=a;a=d;while(1){i=(e[h-2>>1]|0)+(c[a>>2]|0)|0;b[h>>1]=i;j=i+(c[a+4>>2]|0)|0;b[h+2>>1]=j;i=j+(c[a+8>>2]|0)|0;b[h+4>>1]=i;j=i+(c[a+12>>2]|0)|0;b[h+6>>1]=j;i=j+(c[a+16>>2]|0)|0;b[h+8>>1]=i;j=i+(c[a+20>>2]|0)|0;b[h+10>>1]=j;i=j+(c[a+24>>2]|0)|0;b[h+12>>1]=i;b[h+14>>1]=i+(c[a+28>>2]|0);i=f+1|0;if((i|0)<8){f=i;h=h+(g<<1)|0;a=a+32|0}else{break}}mrc(d|0,0,256)|0;return}function Sra(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Ora(a+(c[b>>2]|0)|0,d,e);Ora(a+(c[b+4>>2]|0)|0,d+64|0,e);Ora(a+(c[b+8>>2]|0)|0,d+128|0,e);Ora(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function Tra(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Pra(a+(c[b>>2]|0)|0,d,e);Pra(a+(c[b+4>>2]|0)|0,d+64|0,e);Pra(a+(c[b+8>>2]|0)|0,d+128|0,e);Pra(a+(c[b+12>>2]|0)|0,d+192|0,e);return}function Ura(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Ora(a+(c[b>>2]|0)|0,d,e);Ora(a+(c[b+4>>2]|0)|0,d+64|0,e);Ora(a+(c[b+8>>2]|0)|0,d+128|0,e);Ora(a+(c[b+12>>2]|0)|0,d+192|0,e);Ora(a+(c[b+32>>2]|0)|0,d+256|0,e);Ora(a+(c[b+36>>2]|0)|0,d+320|0,e);Ora(a+(c[b+40>>2]|0)|0,d+384|0,e);Ora(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function Vra(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;Pra(a+(c[b>>2]|0)|0,d,e);Pra(a+(c[b+4>>2]|0)|0,d+64|0,e);Pra(a+(c[b+8>>2]|0)|0,d+128|0,e);Pra(a+(c[b+12>>2]|0)|0,d+192|0,e);Pra(a+(c[b+32>>2]|0)|0,d+256|0,e);Pra(a+(c[b+36>>2]|0)|0,d+320|0,e);Pra(a+(c[b+40>>2]|0)|0,d+384|0,e);Pra(a+(c[b+44>>2]|0)|0,d+448|0,e);return}function Wra(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Ora(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Xra(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{Pra(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<5<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function Yra(a,b,d){a=a|0;b=b|0;d=d|0;b=c[a+(-d|0)>>2]|0;c[a>>2]=b;c[a+d>>2]=b;c[a+(d<<1)>>2]=b;c[a+(d*3|0)>>2]=b;return}function Zra(a,b,e){a=a|0;b=b|0;e=e|0;c[a>>2]=ca(d[a-1|0]|0,16843009)|0;c[a+e>>2]=ca(d[a+(e-1)|0]|0,16843009)|0;b=e<<1;c[a+b>>2]=ca(d[a+(b-1)|0]|0,16843009)|0;b=e*3|0;c[a+b>>2]=ca(d[a+(b-1)|0]|0,16843009)|0;return}function _ra(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;b=e<<1;f=e*3|0;g=ca((d[a+(-e|0)|0]|0)+4+(d[a+(1-e)|0]|0)+(d[a+(2-e)|0]|0)+(d[a+(3-e)|0]|0)+(d[a-1|0]|0)+(d[a+(e-1)|0]|0)+(d[a+(b-1)|0]|0)+(d[a+(f-1)|0]|0)>>3,16843009)|0;c[a>>2]=g;c[a+e>>2]=g;c[a+b>>2]=g;c[a+f>>2]=g;return}function $ra(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d[b+(1-e)|0]|0;g=d[b+(2-e)|0]|0;h=d[b+(3-e)|0]|0;i=d[c]|0;j=d[c+1|0]|0;k=d[c+2|0]|0;l=d[c+3|0]|0;a[b]=((d[b+(-e|0)|0]|0)+2+g+(f<<1)|0)>>>2;c=(f+2+h+(g<<1)|0)>>>2&255;a[b+e|0]=c;a[b+1|0]=c;c=(g+2+i+(h<<1)|0)>>>2&255;g=e<<1;a[b+g|0]=c;a[b+(e+1)|0]=c;a[b+2|0]=c;c=(h+2+j+(i<<1)|0)>>>2&255;h=e*3|0;a[b+h|0]=c;a[b+(g|1)|0]=c;a[b+(e+2)|0]=c;a[b+3|0]=c;c=(i+2+k+(j<<1)|0)>>>2&255;a[b+(h+1)|0]=c;a[b+(g+2)|0]=c;a[b+(e+3)|0]=c;c=(j+2+l+(k<<1)|0)>>>2&255;a[b+(h+2)|0]=c;a[b+(g+3)|0]=c;a[b+(h+3)|0]=(k+2+(l*3|0)|0)>>>2;return}function asa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=d[b+~e|0]|0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b+(3-e)|0]|0;j=d[b-1|0]|0;k=d[b+(e-1)|0]|0;l=e<<1;m=d[b+(l-1)|0]|0;n=e*3|0;a[b+n|0]=(k+2+(m<<1)+(d[b+(n-1)|0]|0)|0)>>>2;o=(j+2+(k<<1)+m|0)>>>2&255;a[b+(n+1)|0]=o;a[b+l|0]=o;o=c+2|0;m=(o+(j<<1)+k|0)>>>2&255;a[b+(n+2)|0]=m;a[b+(l|1)|0]=m;a[b+e|0]=m;m=((c<<1)+2+f+j|0)>>>2&255;a[b+(n+3)|0]=m;a[b+(l+2)|0]=m;a[b+(e+1)|0]=m;a[b]=m;m=(o+(f<<1)+g|0)>>>2&255;a[b+(l+3)|0]=m;a[b+(e+2)|0]=m;a[b+1|0]=m;m=(f+2+(g<<1)+h|0)>>>2&255;a[b+(e+3)|0]=m;a[b+2|0]=m;a[b+3|0]=(g+2+(h<<1)+i|0)>>>2;return}function bsa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=d[b+~e|0]|0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b+(3-e)|0]|0;j=d[b-1|0]|0;k=d[b+(e-1)|0]|0;l=e<<1;m=d[b+(l-1)|0]|0;n=e*3|0;o=(c+1+f|0)>>>1&255;a[b+(l|1)|0]=o;a[b]=o;o=(f+1+g|0)>>>1&255;a[b+(l+2)|0]=o;a[b+1|0]=o;o=(g+1+h|0)>>>1&255;a[b+(l+3)|0]=o;a[b+2|0]=o;a[b+3|0]=(h+1+i|0)>>>1;o=((c<<1)+2+f+j|0)>>>2&255;a[b+(n+1)|0]=o;a[b+e|0]=o;o=c+2|0;c=(o+(f<<1)+g|0)>>>2&255;a[b+(n+2)|0]=c;a[b+(e+1)|0]=c;c=(f+2+(g<<1)+h|0)>>>2&255;a[b+(n+3)|0]=c;a[b+(e+2)|0]=c;a[b+(e+3)|0]=(g+2+(h<<1)+i|0)>>>2;a[b+l|0]=(o+(j<<1)+k|0)>>>2;a[b+n|0]=(j+2+(k<<1)+m|0)>>>2;return}function csa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=d[b+~e|0]|0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b-1|0]|0;j=d[b+(e-1)|0]|0;k=e<<1;l=d[b+(k-1)|0]|0;m=e*3|0;n=d[b+(m-1)|0]|0;o=(c+1+i|0)>>>1&255;a[b+(e+2)|0]=o;a[b]=o;o=((c<<1)+2+f+i|0)>>>2&255;a[b+(e+3)|0]=o;a[b+1|0]=o;o=c+2|0;a[b+2|0]=(o+(f<<1)+g|0)>>>2;a[b+3|0]=(f+2+(g<<1)+h|0)>>>2;h=(i+1+j|0)>>>1&255;a[b+(k+2)|0]=h;a[b+e|0]=h;h=(o+(i<<1)+j|0)>>>2&255;a[b+(k+3)|0]=h;a[b+(e+1)|0]=h;h=(j+1+l|0)>>>1&255;a[b+(m+2)|0]=h;a[b+k|0]=h;h=(i+2+(j<<1)+l|0)>>>2&255;a[b+(m+3)|0]=h;a[b+(k|1)|0]=h;a[b+m|0]=(l+1+n|0)>>>1;a[b+(m+1)|0]=(j+2+(l<<1)+n|0)>>>2;return}function dsa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[b+(-e|0)|0]|0;g=d[b+(1-e)|0]|0;h=d[b+(2-e)|0]|0;i=d[b+(3-e)|0]|0;j=d[c]|0;k=d[c+1|0]|0;l=d[c+2|0]|0;a[b]=(f+1+g|0)>>>1;c=(g+1+h|0)>>>1&255;m=e<<1;a[b+m|0]=c;a[b+1|0]=c;c=(h+1+i|0)>>>1&255;a[b+(m|1)|0]=c;a[b+2|0]=c;c=(i+1+j|0)>>>1&255;a[b+(m+2)|0]=c;a[b+3|0]=c;a[b+(m+3)|0]=(j+1+k|0)>>>1;a[b+e|0]=(f+2+(g<<1)+h|0)>>>2;f=(g+2+(h<<1)+i|0)>>>2&255;g=e*3|0;a[b+g|0]=f;a[b+(e+1)|0]=f;f=(h+2+(i<<1)+j|0)>>>2&255;a[b+(g+1)|0]=f;a[b+(e+2)|0]=f;f=(i+2+(j<<1)+k|0)>>>2&255;a[b+(g+2)|0]=f;a[b+(e+3)|0]=f;a[b+(g+3)|0]=(j+2+(k<<1)+l|0)>>>2;return}function esa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;c=d[b-1|0]|0;f=d[b+(e-1)|0]|0;g=e<<1;h=d[b+(g-1)|0]|0;i=e*3|0;j=a[b+(i-1)|0]|0;k=j&255;a[b]=(c+1+f|0)>>>1;a[b+1|0]=(c+2+(f<<1)+h|0)>>>2;c=(f+1+h|0)>>>1&255;a[b+e|0]=c;a[b+2|0]=c;c=(f+2+(h<<1)+k|0)>>>2&255;a[b+(e+1)|0]=c;a[b+3|0]=c;c=(h+1+k|0)>>>1&255;a[b+g|0]=c;a[b+(e+2)|0]=c;c=(h+2+k+(k<<1)|0)>>>2&255;a[b+(g|1)|0]=c;a[b+(e+3)|0]=c;a[b+(i+3)|0]=j;a[b+(i+2)|0]=j;a[b+(g+2)|0]=j;a[b+i|0]=j;a[b+(i+1)|0]=j;a[b+(g+3)|0]=j;return}function fsa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;b=e<<1;f=e*3|0;g=ca(((d[a-1|0]|0)+2+(d[a+(e-1)|0]|0)+(d[a+(b-1)|0]|0)+(d[a+(f-1)|0]|0)|0)>>>2,16843009)|0;c[a>>2]=g;c[a+e>>2]=g;c[a+b>>2]=g;c[a+f>>2]=g;return}function gsa(a,b,e){a=a|0;b=b|0;e=e|0;b=ca(((d[a+(-e|0)|0]|0)+2+(d[a+(1-e)|0]|0)+(d[a+(2-e)|0]|0)+(d[a+(3-e)|0]|0)|0)>>>2,16843009)|0;c[a>>2]=b;c[a+e>>2]=b;c[a+(e<<1)>>2]=b;c[a+(e*3|0)>>2]=b;return}function hsa(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=-2139062144;c[a+d>>2]=-2139062144;c[a+(d<<1)>>2]=-2139062144;c[a+(d*3|0)>>2]=-2139062144;return}function isa(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=2139062143;c[a+d>>2]=2139062143;c[a+(d<<1)>>2]=2139062143;c[a+(d*3|0)>>2]=2139062143;return}function jsa(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=-2122219135;c[a+d>>2]=-2122219135;c[a+(d<<1)>>2]=-2122219135;c[a+(d*3|0)>>2]=-2122219135;return}function ksa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=-g|0;i=d[b+h|0]|0;j=d[b+(1-g)|0]|0;k=d[b+(2-g)|0]|0;l=d[b+(3-g)|0]|0;m=d[b+(4-g)|0]|0;n=d[b+(5-g)|0]|0;o=d[b+(6-g)|0]|0;p=a[b+(7-g)|0]|0;q=p&255;if((f|0)==0){r=p}else{r=a[b+(8-g)|0]|0}a[b]=((d[b+((e|0)==0?h:~g)|0]|0)+2+(i<<1)+j|0)>>>2;a[b+1|0]=(i+2+(j<<1)+k|0)>>>2;a[b+2|0]=(j+2+(k<<1)+l|0)>>>2;a[b+3|0]=(k+2+(l<<1)+m|0)>>>2;k=b+4|0;a[k]=(l+2+(m<<1)+n|0)>>>2;a[b+5|0]=(m+2+(n<<1)+o|0)>>>2;a[b+6|0]=(n+2+(o<<1)+q|0)>>>2;a[b+7|0]=((r&255)+2+(q<<1)+o|0)>>>2;o=c[b>>2]|0;q=c[k>>2]|0;c[b+g>>2]=o;c[b+(g+4)>>2]=q;k=g<<1;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g*3|0;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g<<2;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g*5|0;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g*6|0;c[b+k>>2]=o;c[b+(k+4)>>2]=q;k=g*7|0;c[b+k>>2]=o;c[b+(k+4)>>2]=q;return}function lsa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((b|0)==0){b=a-1|0;g=b;h=b}else{g=a+~f|0;h=a-1|0}b=d[h]|0;h=d[a+(f-1)|0]|0;e=f<<1;i=d[a+(e-1)|0]|0;j=f*3|0;k=d[a+(j-1)|0]|0;l=f<<2;m=d[a+(l-1)|0]|0;n=f*5|0;o=d[a+(n-1)|0]|0;p=f*6|0;q=d[a+(p-1)|0]|0;r=f*7|0;s=d[a+(r-1)|0]|0;t=ca(((d[g]|0)+2+(b<<1)+h|0)>>>2,16843009)|0;c[a>>2]=t;c[a+4>>2]=t;t=ca((b+2+(h<<1)+i|0)>>>2,16843009)|0;c[a+f>>2]=t;c[a+(f+4)>>2]=t;t=ca((h+2+(i<<1)+k|0)>>>2,16843009)|0;c[a+e>>2]=t;c[a+(e+4)>>2]=t;t=ca((i+2+(k<<1)+m|0)>>>2,16843009)|0;c[a+j>>2]=t;c[a+(j+4)>>2]=t;t=ca((k+2+(m<<1)+o|0)>>>2,16843009)|0;c[a+l>>2]=t;c[a+(l+4)>>2]=t;t=ca((m+2+(o<<1)+q|0)>>>2,16843009)|0;c[a+n>>2]=t;c[a+(n+4)>>2]=t;t=ca((o+2+(q<<1)+s|0)>>>2,16843009)|0;c[a+p>>2]=t;c[a+(p+4)>>2]=t;t=ca((q+2+(s*3|0)|0)>>>2,16843009)|0;c[a+r>>2]=t;c[a+(r+4)>>2]=t;return}function msa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=(e|0)!=0;if(h){e=~g;i=b+e|0;j=b-1|0;k=e}else{e=b-1|0;i=e;j=e;k=~g}e=d[j]|0;j=d[b+(g-1)|0]|0;l=d[b+((g<<1)-1)|0]|0;m=d[b+((g*3|0)-1)|0]|0;n=d[b+((g<<2)-1)|0]|0;o=d[b+((g*5|0)-1)|0]|0;p=d[b+((g*6|0)-1)|0]|0;q=d[b+((g*7|0)-1)|0]|0;r=-g|0;s=d[b+r|0]|0;t=d[b+(1-g)|0]|0;u=d[b+(2-g)|0]|0;v=d[b+(3-g)|0]|0;w=d[b+(4-g)|0]|0;x=d[b+(5-g)|0]|0;y=d[b+(6-g)|0]|0;z=a[b+(7-g)|0]|0;A=z&255;if((f|0)==0){B=z}else{B=a[b+(8-g)|0]|0}z=ca((((d[i]|0)+2+(e<<1)+j|0)>>>2)+8+((e+2+(j<<1)+l|0)>>>2)+((j+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+p|0)>>>2)+((o+2+(p<<1)+q|0)>>>2)+((p+2+(q*3|0)|0)>>>2)+(((d[b+(h?k:r)|0]|0)+2+(s<<1)+t|0)>>>2)+((s+2+(t<<1)+u|0)>>>2)+((t+2+(u<<1)+v|0)>>>2)+((u+2+(v<<1)+w|0)>>>2)+((v+2+(w<<1)+x|0)>>>2)+((w+2+(x<<1)+y|0)>>>2)+((x+2+(y<<1)+A|0)>>>2)+(((B&255)+2+(A<<1)+y|0)>>>2)>>4,16843009)|0;c[b>>2]=z;c[b+4>>2]=z;c[b+g>>2]=z;c[b+(g+4)>>2]=z;y=g<<1;c[b+y>>2]=z;c[b+(y+4)>>2]=z;A=y+g|0;c[b+A>>2]=z;c[b+(A+4)>>2]=z;y=A+g|0;c[b+y>>2]=z;c[b+(y+4)>>2]=z;A=y+g|0;c[b+A>>2]=z;c[b+(A+4)>>2]=z;y=A+g|0;c[b+y>>2]=z;c[b+(y+4)>>2]=z;A=y+g|0;c[b+A>>2]=z;c[b+(A+4)>>2]=z;return}function nsa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=-f|0;h=d[b+g|0]|0;i=d[b+(1-f)|0]|0;j=d[b+(2-f)|0]|0;k=(h+2+(i<<1)+j|0)>>>2;l=d[b+(3-f)|0]|0;m=(i+2+(j<<1)+l|0)>>>2;n=d[b+(4-f)|0]|0;o=(j+2+(l<<1)+n|0)>>>2;j=d[b+(5-f)|0]|0;p=(l+2+(n<<1)+j|0)>>>2;l=d[b+(6-f)|0]|0;q=(n+2+(j<<1)+l|0)>>>2;n=a[b+(7-f)|0]|0;r=n&255;s=(j+2+(l<<1)+r|0)>>>2;if((e|0)==0){t=r;u=r;v=r;w=r;x=r;y=r;z=r;A=r;B=(n&255)+2+(r<<1)|0}else{n=d[b+(8-f)|0]|0;e=d[b+(9-f)|0]|0;j=d[b+(10-f)|0]|0;C=d[b+(11-f)|0]|0;D=d[b+(12-f)|0]|0;E=d[b+(13-f)|0]|0;F=d[b+(14-f)|0]|0;G=d[b+(15-f)|0]|0;t=(F+2+(G*3|0)|0)>>>2;u=(E+2+(F<<1)+G|0)>>>2;v=(D+2+(E<<1)+F|0)>>>2;w=(C+2+(D<<1)+E|0)>>>2;x=(j+2+(C<<1)+D|0)>>>2;y=(e+2+(j<<1)+C|0)>>>2;z=(n+2+(e<<1)+j|0)>>>2;A=(r+2+(n<<1)+e|0)>>>2;B=(d[b+(8-f)|0]|0)+2+(r<<1)|0}r=(B+l|0)>>>2;a[b]=((((d[b+((c|0)==0?g:~f)|0]|0)+2+(h<<1)+i|0)>>>2)+2+(k<<1)+m|0)>>>2;i=(k+2+(m<<1)+o|0)>>>2&255;a[b+1|0]=i;a[b+f|0]=i;i=(m+2+(o<<1)+p|0)>>>2&255;a[b+2|0]=i;a[b+(f+1)|0]=i;m=f<<1;a[b+m|0]=i;i=(o+2+(p<<1)+q|0)>>>2&255;a[b+3|0]=i;a[b+(f+2)|0]=i;a[b+(m|1)|0]=i;o=f*3|0;a[b+o|0]=i;i=(p+2+(q<<1)+s|0)>>>2&255;a[b+4|0]=i;a[b+(f+3)|0]=i;a[b+(m+2)|0]=i;a[b+(o+1)|0]=i;p=f<<2;a[b+p|0]=i;i=(q+2+(s<<1)+r|0)>>>2&255;a[b+5|0]=i;a[b+(f+4)|0]=i;a[b+(m+3)|0]=i;a[b+(o+2)|0]=i;a[b+(p|1)|0]=i;q=f*5|0;a[b+q|0]=i;i=(s+2+(r<<1)+A|0)>>>2&255;a[b+6|0]=i;a[b+(f+5)|0]=i;a[b+(m+4)|0]=i;a[b+(o+3)|0]=i;a[b+(p|2)|0]=i;a[b+(q+1)|0]=i;s=f*6|0;a[b+s|0]=i;i=(r+2+(A<<1)+z|0)>>>2&255;a[b+7|0]=i;a[b+(f+6)|0]=i;a[b+(m+5)|0]=i;a[b+(o+4)|0]=i;a[b+(p|3)|0]=i;a[b+(q+2)|0]=i;a[b+(s|1)|0]=i;r=f*7|0;a[b+r|0]=i;i=(A+2+(z<<1)+y|0)>>>2&255;a[b+(f+7)|0]=i;a[b+(m+6)|0]=i;a[b+(o+5)|0]=i;a[b+(p+4)|0]=i;a[b+(q+3)|0]=i;a[b+(s+2)|0]=i;a[b+(r+1)|0]=i;i=(z+2+(y<<1)+x|0)>>>2&255;a[b+(m+7)|0]=i;a[b+(o+6)|0]=i;a[b+(p+5)|0]=i;a[b+(q+4)|0]=i;a[b+(s+3)|0]=i;a[b+(r+2)|0]=i;i=(y+2+(x<<1)+w|0)>>>2&255;a[b+(o+7)|0]=i;a[b+(p+6)|0]=i;a[b+(q+5)|0]=i;a[b+(s+4)|0]=i;a[b+(r+3)|0]=i;i=(x+2+(w<<1)+v|0)>>>2&255;a[b+(p+7)|0]=i;a[b+(q+6)|0]=i;a[b+(s+5)|0]=i;a[b+(r+4)|0]=i;i=(w+2+(v<<1)+u|0)>>>2&255;a[b+(q+7)|0]=i;a[b+(s+6)|0]=i;a[b+(r+5)|0]=i;i=(v+2+(u<<1)+t|0)>>>2&255;a[b+(s+7)|0]=i;a[b+(r+6)|0]=i;a[b+(r+7)|0]=(u+2+(t*3|0)|0)>>>2;return}function osa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=(c|0)!=0;c=-f|0;h=~f;i=d[b+c|0]|0;j=d[b+(1-f)|0]|0;k=((d[b+(g?h:c)|0]|0)+2+(i<<1)+j|0)>>>2;c=d[b+(2-f)|0]|0;l=(i+2+(j<<1)+c|0)>>>2;m=d[b+(3-f)|0]|0;n=(j+2+(c<<1)+m|0)>>>2;j=d[b+(4-f)|0]|0;o=(c+2+(m<<1)+j|0)>>>2;c=d[b+(5-f)|0]|0;p=(m+2+(j<<1)+c|0)>>>2;m=d[b+(6-f)|0]|0;q=(j+2+(c<<1)+m|0)>>>2;j=a[b+(7-f)|0]|0;r=j&255;s=(c+2+(m<<1)+r|0)>>>2;if((e|0)==0){t=j}else{t=a[b+(8-f)|0]|0}if(g){g=b+h|0;u=g;v=b-1|0;w=g}else{g=b-1|0;u=g;v=g;w=b+h|0}h=d[v]|0;v=d[b+(f-1)|0]|0;g=((d[u]|0)+2+(h<<1)+v|0)>>>2;u=f<<1;j=d[b+(u-1)|0]|0;e=h+2|0;h=(e+(v<<1)+j|0)>>>2;c=f*3|0;x=d[b+(c-1)|0]|0;y=(v+2+(j<<1)+x|0)>>>2;v=f<<2;z=d[b+(v-1)|0]|0;A=(j+2+(x<<1)+z|0)>>>2;j=f*5|0;B=d[b+(j-1)|0]|0;C=(x+2+(z<<1)+B|0)>>>2;x=f*6|0;D=d[b+(x-1)|0]|0;E=(z+2+(B<<1)+D|0)>>>2;z=f*7|0;F=d[b+(z-1)|0]|0;G=(B+2+(D<<1)+F|0)>>>2;B=(e+((d[w]|0)<<1)+i|0)>>>2;a[b+z|0]=(E+2+((D+2+(F*3|0)|0)>>>2)+(G<<1)|0)>>>2;F=(C+2+(E<<1)+G|0)>>>2&255;a[b+(z+1)|0]=F;a[b+x|0]=F;F=(A+2+(C<<1)+E|0)>>>2&255;a[b+(z+2)|0]=F;a[b+(x|1)|0]=F;a[b+j|0]=F;F=(y+2+(A<<1)+C|0)>>>2&255;a[b+(z+3)|0]=F;a[b+(x+2)|0]=F;a[b+(j+1)|0]=F;a[b+v|0]=F;F=(h+2+(y<<1)+A|0)>>>2&255;a[b+(z+4)|0]=F;a[b+(x+3)|0]=F;a[b+(j+2)|0]=F;a[b+(v|1)|0]=F;a[b+c|0]=F;F=(g+2+(h<<1)+y|0)>>>2&255;a[b+(z+5)|0]=F;a[b+(x+4)|0]=F;a[b+(j+3)|0]=F;a[b+(v|2)|0]=F;a[b+(c+1)|0]=F;a[b+u|0]=F;F=((g<<1)+2+h+B|0)>>>2&255;a[b+(z+6)|0]=F;a[b+(x+5)|0]=F;a[b+(j+4)|0]=F;a[b+(v|3)|0]=F;a[b+(c+2)|0]=F;a[b+(u|1)|0]=F;a[b+f|0]=F;F=k+2|0;h=(F+g+(B<<1)|0)>>>2&255;a[b+(z+7)|0]=h;a[b+(x+6)|0]=h;a[b+(j+5)|0]=h;a[b+(v+4)|0]=h;a[b+(c+3)|0]=h;a[b+(u+2)|0]=h;a[b+(f+1)|0]=h;a[b]=h;h=((k<<1)+2+l+B|0)>>>2&255;a[b+(x+7)|0]=h;a[b+(j+6)|0]=h;a[b+(v+5)|0]=h;a[b+(c+4)|0]=h;a[b+(u+3)|0]=h;a[b+(f+2)|0]=h;a[b+1|0]=h;h=(F+(l<<1)+n|0)>>>2&255;a[b+(j+7)|0]=h;a[b+(v+6)|0]=h;a[b+(c+5)|0]=h;a[b+(u+4)|0]=h;a[b+(f+3)|0]=h;a[b+2|0]=h;h=(l+2+(n<<1)+o|0)>>>2&255;a[b+(v+7)|0]=h;a[b+(c+6)|0]=h;a[b+(u+5)|0]=h;a[b+(f+4)|0]=h;a[b+3|0]=h;h=(n+2+(o<<1)+p|0)>>>2&255;a[b+(c+7)|0]=h;a[b+(u+6)|0]=h;a[b+(f+5)|0]=h;a[b+4|0]=h;h=(o+2+(p<<1)+q|0)>>>2&255;a[b+(u+7)|0]=h;a[b+(f+6)|0]=h;a[b+5|0]=h;h=(p+2+(q<<1)+s|0)>>>2&255;a[b+(f+7)|0]=h;a[b+6|0]=h;a[b+7|0]=(q+2+(s<<1)+(((t&255)+2+(r<<1)+m|0)>>>2)|0)>>>2;return}function psa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=(c|0)!=0;c=-f|0;h=~f;i=d[b+c|0]|0;j=d[b+(1-f)|0]|0;k=((d[b+(g?h:c)|0]|0)+2+(i<<1)+j|0)>>>2;c=d[b+(2-f)|0]|0;l=(i+2+(j<<1)+c|0)>>>2;m=d[b+(3-f)|0]|0;n=(j+2+(c<<1)+m|0)>>>2;j=d[b+(4-f)|0]|0;o=(c+2+(m<<1)+j|0)>>>2;c=d[b+(5-f)|0]|0;p=(m+2+(j<<1)+c|0)>>>2;m=d[b+(6-f)|0]|0;q=(j+2+(c<<1)+m|0)>>>2;j=a[b+(7-f)|0]|0;r=j&255;s=(c+2+(m<<1)+r|0)>>>2;if((e|0)==0){t=j}else{t=a[b+(8-f)|0]|0}j=((t&255)+2+(r<<1)+m|0)>>>2;if(g){g=b+h|0;u=g;v=b-1|0;w=g}else{g=b-1|0;u=g;v=g;w=b+h|0}h=d[v]|0;v=d[b+(f-1)|0]|0;g=((d[u]|0)+2+(h<<1)+v|0)>>>2;u=f<<1;m=d[b+(u-1)|0]|0;r=h+2|0;h=(r+(v<<1)+m|0)>>>2;t=f*3|0;e=d[b+(t-1)|0]|0;c=(v+2+(m<<1)+e|0)>>>2;v=f<<2;x=d[b+(v-1)|0]|0;y=(m+2+(e<<1)+x|0)>>>2;m=f*5|0;z=d[b+(m-1)|0]|0;A=(e+2+(x<<1)+z|0)>>>2;e=f*6|0;B=d[b+(e-1)|0]|0;C=(x+2+(z<<1)+B|0)>>>2;x=f*7|0;D=(z+2+(B<<1)+(d[b+(x-1)|0]|0)|0)>>>2;B=(r+((d[w]|0)<<1)+i|0)>>>2;a[b+e|0]=(y+2+(A<<1)+C|0)>>>2;a[b+x|0]=(A+2+(C<<1)+D|0)>>>2;D=(h+2+(c<<1)+y|0)>>>2&255;a[b+(e|1)|0]=D;a[b+v|0]=D;D=(c+2+(y<<1)+A|0)>>>2&255;a[b+(x+1)|0]=D;a[b+m|0]=D;D=((g<<1)+2+h+B|0)>>>2&255;a[b+(e+2)|0]=D;a[b+(v|1)|0]=D;a[b+u|0]=D;D=(g+2+(h<<1)+c|0)>>>2&255;a[b+(x+2)|0]=D;a[b+(m+1)|0]=D;a[b+t|0]=D;D=k+2|0;c=(D+g+(B<<1)|0)>>>2&255;a[b+(x+3)|0]=c;a[b+(m+2)|0]=c;a[b+(t+1)|0]=c;a[b+f|0]=c;c=k+1|0;g=(c+B|0)>>>1&255;a[b+(e+3)|0]=g;a[b+(v|2)|0]=g;a[b+(u|1)|0]=g;a[b]=g;g=((k<<1)+2+l+B|0)>>>2&255;a[b+(x+4)|0]=g;a[b+(m+3)|0]=g;a[b+(t+2)|0]=g;a[b+(f+1)|0]=g;g=(c+l|0)>>>1&255;a[b+(e+4)|0]=g;a[b+(v|3)|0]=g;a[b+(u+2)|0]=g;a[b+1|0]=g;g=(D+(l<<1)+n|0)>>>2&255;a[b+(x+5)|0]=g;a[b+(m+4)|0]=g;a[b+(t+3)|0]=g;a[b+(f+2)|0]=g;g=(l+1+n|0)>>>1&255;a[b+(e+5)|0]=g;a[b+(v+4)|0]=g;a[b+(u+3)|0]=g;a[b+2|0]=g;g=(l+2+(n<<1)+o|0)>>>2&255;a[b+(x+6)|0]=g;a[b+(m+5)|0]=g;a[b+(t+4)|0]=g;a[b+(f+3)|0]=g;g=(n+1+o|0)>>>1&255;a[b+(e+6)|0]=g;a[b+(v+5)|0]=g;a[b+(u+4)|0]=g;a[b+3|0]=g;g=(n+2+(o<<1)+p|0)>>>2&255;a[b+(x+7)|0]=g;a[b+(m+6)|0]=g;a[b+(t+5)|0]=g;a[b+(f+4)|0]=g;g=(o+1+p|0)>>>1&255;a[b+(e+7)|0]=g;a[b+(v+6)|0]=g;a[b+(u+5)|0]=g;a[b+4|0]=g;g=(o+2+(p<<1)+q|0)>>>2&255;a[b+(m+7)|0]=g;a[b+(t+6)|0]=g;a[b+(f+5)|0]=g;g=(p+1+q|0)>>>1&255;a[b+(v+7)|0]=g;a[b+(u+6)|0]=g;a[b+5|0]=g;g=(p+2+(q<<1)+s|0)>>>2&255;a[b+(t+7)|0]=g;a[b+(f+6)|0]=g;g=(q+1+s|0)>>>1&255;a[b+(u+7)|0]=g;a[b+6|0]=g;a[b+(f+7)|0]=(q+2+(s<<1)+j|0)>>>2;a[b+7|0]=(s+1+j|0)>>>1;return}function qsa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=(c|0)!=0;c=-f|0;g=~f;h=d[b+c|0]|0;i=d[b+(1-f)|0]|0;j=((d[b+(e?g:c)|0]|0)+2+(h<<1)+i|0)>>>2;c=d[b+(2-f)|0]|0;k=(h+2+(i<<1)+c|0)>>>2;l=d[b+(3-f)|0]|0;m=(i+2+(c<<1)+l|0)>>>2;i=d[b+(4-f)|0]|0;n=(c+2+(l<<1)+i|0)>>>2;c=d[b+(5-f)|0]|0;o=(l+2+(i<<1)+c|0)>>>2;l=d[b+(6-f)|0]|0;p=(i+2+(c<<1)+l|0)>>>2;i=(c+2+(l<<1)+(d[b+(7-f)|0]|0)|0)>>>2;if(e){e=b+g|0;q=e;r=b-1|0;s=e}else{e=b-1|0;q=e;r=e;s=b+g|0}g=d[r]|0;r=d[b+(f-1)|0]|0;e=((d[q]|0)+2+(g<<1)+r|0)>>>2;q=f<<1;l=d[b+(q-1)|0]|0;c=g+2|0;g=(c+(r<<1)+l|0)>>>2;t=f*3|0;u=d[b+(t-1)|0]|0;v=(r+2+(l<<1)+u|0)>>>2;r=f<<2;w=d[b+(r-1)|0]|0;x=(l+2+(u<<1)+w|0)>>>2;l=f*5|0;y=d[b+(l-1)|0]|0;z=(u+2+(w<<1)+y|0)>>>2;u=f*6|0;A=d[b+(u-1)|0]|0;B=(w+2+(y<<1)+A|0)>>>2;w=f*7|0;C=d[b+(w-1)|0]|0;D=(y+2+(A<<1)+C|0)>>>2;y=(A+2+(C*3|0)|0)>>>2;C=(c+((d[s]|0)<<1)+h|0)>>>2;a[b+w|0]=(y+1+D|0)>>>1;a[b+(w+1)|0]=(B+2+y+(D<<1)|0)>>>2;y=(B+1+D|0)>>>1&255;a[b+(w+2)|0]=y;a[b+u|0]=y;y=(z+2+(B<<1)+D|0)>>>2&255;a[b+(w+3)|0]=y;a[b+(u|1)|0]=y;y=(z+1+B|0)>>>1&255;a[b+(w+4)|0]=y;a[b+(u+2)|0]=y;a[b+l|0]=y;y=(x+2+(z<<1)+B|0)>>>2&255;a[b+(w+5)|0]=y;a[b+(u+3)|0]=y;a[b+(l+1)|0]=y;y=(x+1+z|0)>>>1&255;a[b+(w+6)|0]=y;a[b+(u+4)|0]=y;a[b+(l+2)|0]=y;a[b+r|0]=y;y=(v+2+(x<<1)+z|0)>>>2&255;a[b+(w+7)|0]=y;a[b+(u+5)|0]=y;a[b+(l+3)|0]=y;a[b+(r|1)|0]=y;y=(v+1+x|0)>>>1&255;a[b+(u+6)|0]=y;a[b+(l+4)|0]=y;a[b+(r|2)|0]=y;a[b+t|0]=y;y=(g+2+(v<<1)+x|0)>>>2&255;a[b+(u+7)|0]=y;a[b+(l+5)|0]=y;a[b+(r|3)|0]=y;a[b+(t+1)|0]=y;y=(g+1+v|0)>>>1&255;a[b+(l+6)|0]=y;a[b+(r+4)|0]=y;a[b+(t+2)|0]=y;a[b+q|0]=y;y=(e+2+(g<<1)+v|0)>>>2&255;a[b+(l+7)|0]=y;a[b+(r+5)|0]=y;a[b+(t+3)|0]=y;a[b+(q|1)|0]=y;y=e+1|0;l=(y+g|0)>>>1&255;a[b+(r+6)|0]=l;a[b+(t+4)|0]=l;a[b+(q+2)|0]=l;a[b+f|0]=l;l=((e<<1)+2+g+C|0)>>>2&255;a[b+(r+7)|0]=l;a[b+(t+5)|0]=l;a[b+(q+3)|0]=l;a[b+(f+1)|0]=l;l=(y+C|0)>>>1&255;a[b+(t+6)|0]=l;a[b+(q+4)|0]=l;a[b+(f+2)|0]=l;a[b]=l;l=j+2|0;y=(l+e+(C<<1)|0)>>>2&255;a[b+(t+7)|0]=y;a[b+(q+5)|0]=y;a[b+(f+3)|0]=y;a[b+1|0]=y;y=((j<<1)+2+k+C|0)>>>2&255;a[b+(q+6)|0]=y;a[b+(f+4)|0]=y;a[b+2|0]=y;y=(l+(k<<1)+m|0)>>>2&255;a[b+(q+7)|0]=y;a[b+(f+5)|0]=y;a[b+3|0]=y;y=(k+2+(m<<1)+n|0)>>>2&255;a[b+(f+6)|0]=y;a[b+4|0]=y;y=(m+2+(n<<1)+o|0)>>>2&255;a[b+(f+7)|0]=y;a[b+5|0]=y;a[b+6|0]=(n+2+(o<<1)+p|0)>>>2;a[b+7|0]=(o+2+(p<<1)+i|0)>>>2;return}function rsa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=-f|0;h=d[b+g|0]|0;i=d[b+(1-f)|0]|0;j=((d[b+((c|0)==0?g:~f)|0]|0)+2+(h<<1)+i|0)>>>2;g=d[b+(2-f)|0]|0;c=(h+2+(i<<1)+g|0)>>>2;h=d[b+(3-f)|0]|0;k=(i+2+(g<<1)+h|0)>>>2;i=d[b+(4-f)|0]|0;l=(g+2+(h<<1)+i|0)>>>2;g=d[b+(5-f)|0]|0;m=(h+2+(i<<1)+g|0)>>>2;h=d[b+(6-f)|0]|0;n=(i+2+(g<<1)+h|0)>>>2;i=a[b+(7-f)|0]|0;o=i&255;p=(g+2+(h<<1)+o|0)>>>2;if((e|0)==0){q=o;r=o;s=o;t=o;u=o;v=(i&255)+2+(o<<1)|0}else{i=d[b+(8-f)|0]|0;e=d[b+(9-f)|0]|0;g=d[b+(10-f)|0]|0;w=d[b+(11-f)|0]|0;x=d[b+(12-f)|0]|0;q=(w+2+(x<<1)+(d[b+(13-f)|0]|0)|0)>>>2;r=(g+2+(w<<1)+x|0)>>>2;s=(e+2+(g<<1)+w|0)>>>2;t=(i+2+(e<<1)+g|0)>>>2;u=(o+2+(i<<1)+e|0)>>>2;v=(d[b+(8-f)|0]|0)+2+(o<<1)|0}o=(v+h|0)>>>2;a[b]=(j+1+c|0)>>>1;a[b+f|0]=(j+2+(c<<1)+k|0)>>>2;j=(c+1+k|0)>>>1&255;a[b+1|0]=j;h=f<<1;a[b+h|0]=j;j=(c+2+(k<<1)+l|0)>>>2&255;a[b+(f+1)|0]=j;c=f*3|0;a[b+c|0]=j;j=(k+1+l|0)>>>1&255;a[b+2|0]=j;a[b+(h|1)|0]=j;v=f<<2;a[b+v|0]=j;j=(k+2+(l<<1)+m|0)>>>2&255;a[b+(f+2)|0]=j;a[b+(c+1)|0]=j;k=f*5|0;a[b+k|0]=j;j=(l+1+m|0)>>>1&255;a[b+3|0]=j;a[b+(h+2)|0]=j;a[b+(v|1)|0]=j;e=f*6|0;a[b+e|0]=j;j=(l+2+(m<<1)+n|0)>>>2&255;a[b+(f+3)|0]=j;a[b+(c+2)|0]=j;a[b+(k+1)|0]=j;l=f*7|0;a[b+l|0]=j;j=(m+1+n|0)>>>1&255;a[b+4|0]=j;a[b+(h+3)|0]=j;a[b+(v|2)|0]=j;a[b+(e|1)|0]=j;j=(m+2+(n<<1)+p|0)>>>2&255;a[b+(f+4)|0]=j;a[b+(c+3)|0]=j;a[b+(k+2)|0]=j;a[b+(l+1)|0]=j;j=(n+1+p|0)>>>1&255;a[b+5|0]=j;a[b+(h+4)|0]=j;a[b+(v|3)|0]=j;a[b+(e+2)|0]=j;j=(n+2+(p<<1)+o|0)>>>2&255;a[b+(f+5)|0]=j;a[b+(c+4)|0]=j;a[b+(k+3)|0]=j;a[b+(l+2)|0]=j;j=(p+1+o|0)>>>1&255;a[b+6|0]=j;a[b+(h+5)|0]=j;a[b+(v+4)|0]=j;a[b+(e+3)|0]=j;j=(p+2+(o<<1)+u|0)>>>2&255;a[b+(f+6)|0]=j;a[b+(c+5)|0]=j;a[b+(k+4)|0]=j;a[b+(l+3)|0]=j;j=(o+1+u|0)>>>1&255;a[b+7|0]=j;a[b+(h+6)|0]=j;a[b+(v+5)|0]=j;a[b+(e+4)|0]=j;j=(o+2+(u<<1)+t|0)>>>2&255;a[b+(f+7)|0]=j;a[b+(c+6)|0]=j;a[b+(k+5)|0]=j;a[b+(l+4)|0]=j;j=(u+1+t|0)>>>1&255;a[b+(h+7)|0]=j;a[b+(v+6)|0]=j;a[b+(e+5)|0]=j;j=(u+2+(t<<1)+s|0)>>>2&255;a[b+(c+7)|0]=j;a[b+(k+6)|0]=j;a[b+(l+5)|0]=j;j=(t+1+s|0)>>>1&255;a[b+(v+7)|0]=j;a[b+(e+6)|0]=j;j=(t+2+(s<<1)+r|0)>>>2&255;a[b+(k+7)|0]=j;a[b+(l+6)|0]=j;a[b+(e+7)|0]=(s+1+r|0)>>>1;a[b+(l+7)|0]=(s+2+(r<<1)+q|0)>>>2;return}function ssa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c|0)==0){c=b-1|0;g=c;h=c}else{g=b+~f|0;h=b-1|0}c=d[h]|0;h=d[b+(f-1)|0]|0;e=((d[g]|0)+2+(c<<1)+h|0)>>>2;g=f<<1;i=d[b+(g-1)|0]|0;j=(c+2+(h<<1)+i|0)>>>2;c=f*3|0;k=d[b+(c-1)|0]|0;l=(h+2+(i<<1)+k|0)>>>2;h=f<<2;m=d[b+(h-1)|0]|0;n=(i+2+(k<<1)+m|0)>>>2;i=f*5|0;o=d[b+(i-1)|0]|0;p=(k+2+(m<<1)+o|0)>>>2;k=f*6|0;q=d[b+(k-1)|0]|0;r=(m+2+(o<<1)+q|0)>>>2;m=f*7|0;s=d[b+(m-1)|0]|0;t=(o+2+(q<<1)+s|0)>>>2;o=(q+2+(s*3|0)|0)>>>2;a[b]=(e+1+j|0)>>>1;a[b+1|0]=(e+2+(j<<1)+l|0)>>>2;e=(j+1+l|0)>>>1&255;a[b+2|0]=e;a[b+f|0]=e;e=(j+2+(l<<1)+n|0)>>>2&255;a[b+3|0]=e;a[b+(f+1)|0]=e;e=(l+1+n|0)>>>1&255;a[b+4|0]=e;a[b+(f+2)|0]=e;a[b+g|0]=e;e=(l+2+(n<<1)+p|0)>>>2&255;a[b+5|0]=e;a[b+(f+3)|0]=e;a[b+(g|1)|0]=e;e=(n+1+p|0)>>>1&255;a[b+6|0]=e;a[b+(f+4)|0]=e;a[b+(g+2)|0]=e;a[b+c|0]=e;e=(n+2+(p<<1)+r|0)>>>2&255;a[b+7|0]=e;a[b+(f+5)|0]=e;a[b+(g+3)|0]=e;a[b+(c+1)|0]=e;e=(p+1+r|0)>>>1&255;a[b+(f+6)|0]=e;a[b+(g+4)|0]=e;a[b+(c+2)|0]=e;a[b+h|0]=e;e=(p+2+(r<<1)+t|0)>>>2&255;a[b+(f+7)|0]=e;a[b+(g+5)|0]=e;a[b+(c+3)|0]=e;a[b+(h|1)|0]=e;e=(r+1+t|0)>>>1&255;a[b+(g+6)|0]=e;a[b+(c+4)|0]=e;a[b+(h|2)|0]=e;a[b+i|0]=e;e=(r+2+o+(t<<1)|0)>>>2&255;a[b+(g+7)|0]=e;a[b+(c+5)|0]=e;a[b+(h|3)|0]=e;a[b+(i+1)|0]=e;e=(o+1+t|0)>>>1&255;a[b+(c+6)|0]=e;a[b+(h+4)|0]=e;a[b+(i+2)|0]=e;a[b+k|0]=e;e=(t+2+(o*3|0)|0)>>>2&255;a[b+(c+7)|0]=e;a[b+(h+5)|0]=e;a[b+(i+3)|0]=e;a[b+(k|1)|0]=e;e=o&255;a[b+(m+7)|0]=e;a[b+(k+7)|0]=e;a[b+(i+7)|0]=e;a[b+(h+7)|0]=e;a[b+(m+6)|0]=e;a[b+(k+6)|0]=e;a[b+(i+6)|0]=e;a[b+(h+6)|0]=e;a[b+(m+5)|0]=e;a[b+(k+5)|0]=e;a[b+(i+5)|0]=e;a[b+(m+4)|0]=e;a[b+(k+4)|0]=e;a[b+(i+4)|0]=e;a[b+(m+3)|0]=e;a[b+(k+3)|0]=e;a[b+(m+2)|0]=e;a[b+(k+2)|0]=e;a[b+(m+1)|0]=e;a[b+m|0]=e;return}function tsa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((b|0)==0){b=a-1|0;g=b;h=b}else{g=a+~f|0;h=a-1|0}b=d[h]|0;h=d[a+(f-1)|0]|0;e=d[a+((f<<1)-1)|0]|0;i=d[a+((f*3|0)-1)|0]|0;j=d[a+((f<<2)-1)|0]|0;k=d[a+((f*5|0)-1)|0]|0;l=d[a+((f*6|0)-1)|0]|0;m=d[a+((f*7|0)-1)|0]|0;n=ca((((d[g]|0)+2+(b<<1)+h|0)>>>2)+4+((b+2+(h<<1)+e|0)>>>2)+((h+2+(e<<1)+i|0)>>>2)+((e+2+(i<<1)+j|0)>>>2)+((i+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m*3|0)|0)>>>2)>>3,16843009)|0;c[a>>2]=n;c[a+4>>2]=n;c[a+f>>2]=n;c[a+(f+4)>>2]=n;m=f<<1;c[a+m>>2]=n;c[a+(m+4)>>2]=n;l=m+f|0;c[a+l>>2]=n;c[a+(l+4)>>2]=n;m=l+f|0;c[a+m>>2]=n;c[a+(m+4)>>2]=n;l=m+f|0;c[a+l>>2]=n;c[a+(l+4)>>2]=n;m=l+f|0;c[a+m>>2]=n;c[a+(m+4)>>2]=n;l=m+f|0;c[a+l>>2]=n;c[a+(l+4)>>2]=n;return}function usa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=-g|0;i=d[b+h|0]|0;j=d[b+(1-g)|0]|0;k=d[b+(2-g)|0]|0;l=d[b+(3-g)|0]|0;m=d[b+(4-g)|0]|0;n=d[b+(5-g)|0]|0;o=d[b+(6-g)|0]|0;p=a[b+(7-g)|0]|0;q=p&255;if((f|0)==0){r=p}else{r=a[b+(8-g)|0]|0}p=ca((((d[b+((e|0)==0?h:~g)|0]|0)+2+(i<<1)+j|0)>>>2)+4+((i+2+(j<<1)+k|0)>>>2)+((j+2+(k<<1)+l|0)>>>2)+((k+2+(l<<1)+m|0)>>>2)+((l+2+(m<<1)+n|0)>>>2)+((m+2+(n<<1)+o|0)>>>2)+((n+2+(o<<1)+q|0)>>>2)+(((r&255)+2+(q<<1)+o|0)>>>2)>>3,16843009)|0;c[b>>2]=p;c[b+4>>2]=p;c[b+g>>2]=p;c[b+(g+4)>>2]=p;o=g<<1;c[b+o>>2]=p;c[b+(o+4)>>2]=p;q=o+g|0;c[b+q>>2]=p;c[b+(q+4)>>2]=p;o=q+g|0;c[b+o>>2]=p;c[b+(o+4)>>2]=p;q=o+g|0;c[b+q>>2]=p;c[b+(q+4)>>2]=p;o=q+g|0;c[b+o>>2]=p;c[b+(o+4)>>2]=p;q=o+g|0;c[b+q>>2]=p;c[b+(q+4)>>2]=p;return}function vsa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;d=e<<1;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;b=d+e|0;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;d=b+e|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;b=d+e|0;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;d=b+e|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;b=d+e|0;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;return}function wsa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+(-b|0)>>2]|0;e=c[a+(4-b)>>2]|0;c[a>>2]=d;c[a+4>>2]=e;c[a+b>>2]=d;c[a+(b+4)>>2]=e;f=b<<1;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*3|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b<<2;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*5|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*6|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*7|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;return}function xsa(a,b){a=a|0;b=b|0;var e=0,f=0;e=ca(d[a-1|0]|0,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;e=ca(d[a+(b-1)|0]|0,16843009)|0;c[a+b>>2]=e;c[a+(b+4)>>2]=e;e=b<<1;f=ca(d[a+(e-1)|0]|0,16843009)|0;c[a+e>>2]=f;c[a+(e+4)>>2]=f;f=b*3|0;e=ca(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;e=b<<2;f=ca(d[a+(e-1)|0]|0,16843009)|0;c[a+e>>2]=f;c[a+(e+4)>>2]=f;f=b*5|0;e=ca(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;e=b*6|0;f=ca(d[a+(e-1)|0]|0,16843009)|0;c[a+e>>2]=f;c[a+(e+4)>>2]=f;f=b*7|0;b=ca(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=b;c[a+(f+4)>>2]=b;return}function ysa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+(-b|0)>>2]|0;e=c[a+(4-b)>>2]|0;c[a>>2]=d;c[a+4>>2]=e;c[a+b>>2]=d;c[a+(b+4)>>2]=e;f=b<<1;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*3|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b<<2;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*5|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*6|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*7|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b<<3;c[a+f>>2]=d;c[a+(f|4)>>2]=e;f=b*9|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*10|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*11|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*12|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*13|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*14|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;f=b*15|0;c[a+f>>2]=d;c[a+(f+4)>>2]=e;return}function zsa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=0;do{f=ca(e,b)|0;g=ca(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=g;c[a+(f+4)>>2]=g;e=e+1|0;}while((e|0)<16);return}function Asa(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=3-c|0;f=(c<<2)-1|0;g=f-(c<<1)|0;h=f+c|0;i=g-c|0;j=h+c|0;k=i-c|0;l=d[b+(j+c)|0]|0;m=((((d[b+(e+4)|0]|0)-(d[b+(e-4)|0]|0)<<2)+((((d[b+(e+3)|0]|0)-(d[b+(e-3)|0]|0)|0)*3|0)+(((d[b+(e+2)|0]|0)-(d[b+(e-2)|0]|0)<<1)+((d[b+(e+1)|0]|0)-(d[b+(e-1)|0]|0))))|0)*17|0)+16>>5;e=(((l-(d[b+(k-c)|0]|0)<<2)+((((d[b+j|0]|0)-(d[b+k|0]|0)|0)*3|0)+(((d[b+h|0]|0)-(d[b+i|0]|0)<<1)+((d[b+f|0]|0)-(d[b+g|0]|0))))|0)*17|0)+16>>5;g=m<<1;f=m*3|0;i=m<<2;h=m*5|0;k=m*6|0;j=m*7|0;n=b;o=((e+m|0)*-3|0)+16+((d[b+(8-c-1)|0]|0)+l<<4)|0;l=8;while(1){b=o>>5;if(b>>>0>255>>>0){p=-b>>31&255}else{p=b&255}a[n]=p;b=o+m>>5;if(b>>>0>255>>>0){q=-b>>31&255}else{q=b&255}a[n+1|0]=q;b=o+g>>5;if(b>>>0>255>>>0){r=-b>>31&255}else{r=b&255}a[n+2|0]=r;b=o+f>>5;if(b>>>0>255>>>0){s=-b>>31&255}else{s=b&255}a[n+3|0]=s;b=o+i>>5;if(b>>>0>255>>>0){t=-b>>31&255}else{t=b&255}a[n+4|0]=t;b=o+h>>5;if(b>>>0>255>>>0){u=-b>>31&255}else{u=b&255}a[n+5|0]=u;b=o+k>>5;if(b>>>0>255>>>0){v=-b>>31&255}else{v=b&255}a[n+6|0]=v;b=o+j>>5;if(b>>>0>255>>>0){w=-b>>31&255}else{w=b&255}a[n+7|0]=w;b=l-1|0;if((b|0)>0){n=n+c|0;o=o+e|0;l=b}else{break}}return}function Bsa(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=3-c|0;f=(c<<3)-1|0;g=f-(c<<1)|0;h=f+c|0;i=g-c|0;j=h+c|0;k=i-c|0;l=(c*11|0)-1+c|0;m=(c*3|0)-1-c|0;n=l+c|0;o=m-c|0;p=n+c|0;q=o-c|0;r=a[b+(p+c)|0]|0;s=((((d[b+(e+4)|0]|0)-(d[b+(e-4)|0]|0)<<2)+((((d[b+(e+3)|0]|0)-(d[b+(e-3)|0]|0)|0)*3|0)+(((d[b+(e+2)|0]|0)-(d[b+(e-2)|0]|0)<<1)+((d[b+(e+1)|0]|0)-(d[b+(e-1)|0]|0))))|0)*17|0)+16>>5;e=((((r&255)-(d[b+(q-c)|0]|0)<<3)+((((d[b+p|0]|0)-(d[b+q|0]|0)|0)*7|0)+((((d[b+n|0]|0)-(d[b+o|0]|0)|0)*6|0)+((((d[b+l|0]|0)-(d[b+m|0]|0)|0)*5|0)+(((d[b+(j+c)|0]|0)-(d[b+(k-c)|0]|0)<<2)+((((d[b+j|0]|0)-(d[b+k|0]|0)|0)*3|0)+(((d[b+h|0]|0)-(d[b+i|0]|0)<<1)+((d[b+f|0]|0)-(d[b+g|0]|0))))))))|0)*5|0)+32>>6;g=s*3|0;f=s<<1;i=s<<2;h=s*5|0;k=s*6|0;j=s*7|0;m=b;l=16-g+(e*-7|0)+((d[b+(7-c)|0]|0)+(r&255)<<4)|0;r=16;while(1){b=l>>5;if(b>>>0>255>>>0){t=-b>>31&255}else{t=b&255}a[m]=t;b=l+s>>5;if(b>>>0>255>>>0){u=-b>>31&255}else{u=b&255}a[m+1|0]=u;b=l+f>>5;if(b>>>0>255>>>0){v=-b>>31&255}else{v=b&255}a[m+2|0]=v;b=l+g>>5;if(b>>>0>255>>>0){w=-b>>31&255}else{w=b&255}a[m+3|0]=w;b=l+i>>5;if(b>>>0>255>>>0){x=-b>>31&255}else{x=b&255}a[m+4|0]=x;b=l+h>>5;if(b>>>0>255>>>0){y=-b>>31&255}else{y=b&255}a[m+5|0]=y;b=l+k>>5;if(b>>>0>255>>>0){z=-b>>31&255}else{z=b&255}a[m+6|0]=z;b=l+j>>5;if(b>>>0>255>>>0){A=-b>>31&255}else{A=b&255}a[m+7|0]=A;b=r-1|0;if((b|0)>0){m=m+c|0;l=l+e|0;r=b}else{break}}return}function Csa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b<<2;f=b*5|0;g=b<<1;h=b*6|0;i=b*3|0;j=(d[a+(7-b)|0]|0)+((d[a+(6-b)|0]|0)+((d[a+(5-b)|0]|0)+(d[a+(4-b)|0]|0)))|0;k=b*7|0;l=(d[a+(k-1)|0]|0)+((d[a+(h-1)|0]|0)+((d[a+(f-1)|0]|0)+(d[a+(e-1)|0]|0)))|0;m=ca((d[a+(i-1)|0]|0)+((d[a+(g-1)|0]|0)+((d[a+(b-1)|0]|0)+((d[a-1|0]|0)+(d[a+(-b|0)|0]|0))+(d[a+(1-b)|0]|0))+(d[a+(2-b)|0]|0))+(d[a+(3-b)|0]|0)+4>>3,16843009)|0;n=ca((j+2|0)>>>2,16843009)|0;c[a>>2]=m;c[a+4>>2]=n;c[a+b>>2]=m;c[a+(b+4)>>2]=n;c[a+g>>2]=m;c[a+(g+4)>>2]=n;c[a+i>>2]=m;c[a+(i+4)>>2]=n;n=ca((l+2|0)>>>2,16843009)|0;i=ca(l+4+j>>3,16843009)|0;c[a+e>>2]=n;c[a+(e+4)>>2]=i;c[a+f>>2]=n;c[a+(f+4)>>2]=i;c[a+h>>2]=n;c[a+(h+4)>>2]=i;c[a+k>>2]=n;c[a+(k+4)>>2]=i;return}function Dsa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b<<2;f=b*5|0;g=b<<1;h=b*6|0;i=b*3|0;j=b*7|0;k=ca(((d[a+(i-1)|0]|0)+((d[a+(g-1)|0]|0)+((d[a+(b-1)|0]|0)+(d[a-1|0]|0)))+2|0)>>>2,16843009)|0;l=((d[a+(j-1)|0]|0)+((d[a+(h-1)|0]|0)+((d[a+(f-1)|0]|0)+(d[a+(e-1)|0]|0)))+2|0)>>>2;c[a>>2]=k;c[a+4>>2]=k;c[a+b>>2]=k;c[a+(b+4)>>2]=k;c[a+g>>2]=k;c[a+(g+4)>>2]=k;c[a+i>>2]=k;c[a+(i+4)>>2]=k;k=ca(l,16843009)|0;c[a+e>>2]=k;c[a+(e+4)>>2]=k;c[a+f>>2]=k;c[a+(f+4)>>2]=k;c[a+h>>2]=k;c[a+(h+4)>>2]=k;c[a+j>>2]=k;c[a+(j+4)>>2]=k;return}function Esa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=4-b|0;f=ca(((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+(d[a+(-b|0)|0]|0)))+2|0)>>>2,16843009)|0;g=ca(((d[a+(e+3)|0]|0)+((d[a+(e+2)|0]|0)+((d[a+(e+1)|0]|0)+(d[a+e|0]|0)))+2|0)>>>2,16843009)|0;c[a>>2]=f;c[a+4>>2]=g;c[a+b>>2]=f;c[a+(b+4)>>2]=g;e=b<<1;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*3|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b<<2;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*5|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*6|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*7|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;return}function Fsa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;Esa(a,b);e=b<<1;f=b*3|0;g=ca((d[a+(-b|0)|0]|0)+4+(d[a+(1-b)|0]|0)+(d[a+(2-b)|0]|0)+(d[a+(3-b)|0]|0)+(d[a-1|0]|0)+(d[a+(b-1)|0]|0)+(d[a+(e-1)|0]|0)+(d[a+(f-1)|0]|0)>>3,16843009)|0;c[a>>2]=g;c[a+b>>2]=g;c[a+e>>2]=g;c[a+f>>2]=g;return}function Gsa(a,b){a=a|0;b=b|0;var e=0;Csa(a,b);e=ca(((d[a+(-b|0)|0]|0)+2+(d[a+(1-b)|0]|0)+(d[a+(2-b)|0]|0)+(d[a+(3-b)|0]|0)|0)>>>2,16843009)|0;c[a>>2]=e;c[a+b>>2]=e;c[a+(b<<1)>>2]=e;c[a+(b*3|0)>>2]=e;return}function Hsa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Dsa(a,b);d=b<<2;c[a+d>>2]=-2139062144;c[a+(d+b)>>2]=-2139062144;e=b<<1;c[a+(d+e)>>2]=-2139062144;f=b*3|0;c[a+(d+f)>>2]=-2139062144;g=d+4|0;c[a+g>>2]=-2139062144;c[a+(g+b)>>2]=-2139062144;c[a+(g+e)>>2]=-2139062144;c[a+(g+f)>>2]=-2139062144;return}function Isa(a,b){a=a|0;b=b|0;var d=0,e=0;Dsa(a,b);c[a>>2]=-2139062144;c[a+b>>2]=-2139062144;d=b<<1;c[a+d>>2]=-2139062144;e=b*3|0;c[a+e>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;return}function Jsa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=0;f=0;g=0;h=0;i=0;j=0;do{k=d[a+((ca(j,b)|0)-1)|0]|0;i=k+i+(d[a+(j-b)|0]|0)|0;k=j+4|0;h=(d[a+(k-b)|0]|0)+h|0;g=(d[a+((ca(k,b)|0)-1)|0]|0)+g|0;f=(d[a+((ca(j+8|0,b)|0)-1)|0]|0)+f|0;e=(d[a+((ca(j+12|0,b)|0)-1)|0]|0)+e|0;j=j+1|0;}while((j|0)<4);j=ca(i+4>>3,16843009)|0;i=ca(h+2>>2,16843009)|0;c[a>>2]=j;c[a+4>>2]=i;c[a+b>>2]=j;c[a+(b+4)>>2]=i;k=b<<1;c[a+k>>2]=j;c[a+(k+4)>>2]=i;k=b*3|0;c[a+k>>2]=j;c[a+(k+4)>>2]=i;i=ca(g+2>>2,16843009)|0;k=ca(g+4+h>>3,16843009)|0;g=ca(f+2>>2,16843009)|0;j=ca(f+4+h>>3,16843009)|0;f=ca(e+2>>2,16843009)|0;l=ca(e+4+h>>3,16843009)|0;h=b<<2;c[a+h>>2]=i;c[a+(h+4)>>2]=k;h=b*5|0;c[a+h>>2]=i;c[a+(h+4)>>2]=k;h=b*6|0;c[a+h>>2]=i;c[a+(h+4)>>2]=k;h=b*7|0;c[a+h>>2]=i;c[a+(h+4)>>2]=k;k=b<<3;c[a+k>>2]=g;c[a+(k|4)>>2]=j;k=b*9|0;c[a+k>>2]=g;c[a+(k+4)>>2]=j;k=b*10|0;c[a+k>>2]=g;c[a+(k+4)>>2]=j;k=b*11|0;c[a+k>>2]=g;c[a+(k+4)>>2]=j;j=b*12|0;c[a+j>>2]=f;c[a+(j+4)>>2]=l;j=b*13|0;c[a+j>>2]=f;c[a+(j+4)>>2]=l;j=b*14|0;c[a+j>>2]=f;c[a+(j+4)>>2]=l;j=b*15|0;c[a+j>>2]=f;c[a+(j+4)>>2]=l;return}function Ksa(a,b){a=a|0;b=b|0;Dsa(a,b);Dsa(a+(b<<3)|0,b);return}function Lsa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=4-b|0;f=ca(((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+(d[a+(-b|0)|0]|0)))+2|0)>>>2,16843009)|0;g=ca(((d[a+(e+3)|0]|0)+((d[a+(e+2)|0]|0)+((d[a+(e+1)|0]|0)+(d[a+e|0]|0)))+2|0)>>>2,16843009)|0;c[a>>2]=f;c[a+4>>2]=g;c[a+b>>2]=f;c[a+(b+4)>>2]=g;e=b<<1;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*3|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b<<2;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*5|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*6|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*7|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b<<3;c[a+e>>2]=f;c[a+(e|4)>>2]=g;e=b*9|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*10|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*11|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*12|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*13|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*14|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;e=b*15|0;c[a+e>>2]=f;c[a+(e+4)>>2]=g;return}function Msa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;Lsa(a,b);e=b<<1;f=b*3|0;g=ca((d[a+(-b|0)|0]|0)+4+(d[a+(1-b)|0]|0)+(d[a+(2-b)|0]|0)+(d[a+(3-b)|0]|0)+(d[a-1|0]|0)+(d[a+(b-1)|0]|0)+(d[a+(e-1)|0]|0)+(d[a+(f-1)|0]|0)>>3,16843009)|0;c[a>>2]=g;c[a+b>>2]=g;c[a+e>>2]=g;c[a+f>>2]=g;return}function Nsa(a,b){a=a|0;b=b|0;var e=0;Jsa(a,b);e=ca(((d[a+(-b|0)|0]|0)+2+(d[a+(1-b)|0]|0)+(d[a+(2-b)|0]|0)+(d[a+(3-b)|0]|0)|0)>>>2,16843009)|0;c[a>>2]=e;c[a+b>>2]=e;c[a+(b<<1)>>2]=e;c[a+(b*3|0)>>2]=e;return}function Osa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;Dsa(a,b);Dsa(a+(b<<3)|0,b);d=b<<2;c[a+d>>2]=-2139062144;c[a+(d+b)>>2]=-2139062144;e=b<<1;c[a+(d+e)>>2]=-2139062144;f=b*3|0;c[a+(d+f)>>2]=-2139062144;g=d+4|0;c[a+g>>2]=-2139062144;c[a+(g+b)>>2]=-2139062144;c[a+(g+e)>>2]=-2139062144;c[a+(g+f)>>2]=-2139062144;return}function Psa(a,b){a=a|0;b=b|0;var d=0,e=0;Dsa(a,b);Dsa(a+(b<<3)|0,b);c[a>>2]=-2139062144;c[a+b>>2]=-2139062144;d=b<<1;c[a+d>>2]=-2139062144;e=b*3|0;c[a+e>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;return}function Qsa(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=2139062143;c[a+4>>2]=2139062143;c[a+b>>2]=2139062143;c[a+(b+4)>>2]=2139062143;d=b<<1;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b*3|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b<<2;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b*5|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b*6|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;d=b*7|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;return}function Rsa(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=-2122219135;c[a+4>>2]=-2122219135;c[a+b>>2]=-2122219135;c[a+(b+4)>>2]=-2122219135;d=b<<1;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b*3|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b<<2;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b*5|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b*6|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;d=b*7|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;return}function Ssa(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;d=b<<1;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b*3|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b<<2;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b*5|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b*6|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;d=b*7|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;return}function Tsa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[a>>2]=-2139062144;c[a+4>>2]=-2139062144;c[a+b>>2]=-2139062144;d=b+4|0;c[a+d>>2]=-2139062144;e=b<<1;c[a+e>>2]=-2139062144;f=e+4|0;c[a+f>>2]=-2139062144;g=b*3|0;c[a+g>>2]=-2139062144;h=g+4|0;c[a+h>>2]=-2139062144;i=b<<2;c[a+i>>2]=-2139062144;j=i+4|0;c[a+j>>2]=-2139062144;k=b*5|0;c[a+k>>2]=-2139062144;l=k+4|0;c[a+l>>2]=-2139062144;m=b*6|0;c[a+m>>2]=-2139062144;n=m+4|0;c[a+n>>2]=-2139062144;o=b*7|0;c[a+o>>2]=-2139062144;p=o+4|0;c[a+p>>2]=-2139062144;q=b<<3;c[a+q>>2]=-2139062144;c[a+(q|4)>>2]=-2139062144;c[a+(q+b)>>2]=-2139062144;c[a+(q+d)>>2]=-2139062144;c[a+(q+e)>>2]=-2139062144;c[a+(f+q)>>2]=-2139062144;c[a+(q+g)>>2]=-2139062144;c[a+(h+q)>>2]=-2139062144;c[a+(q+i)>>2]=-2139062144;c[a+(j+q)>>2]=-2139062144;c[a+(q+k)>>2]=-2139062144;c[a+(l+q)>>2]=-2139062144;c[a+(q+m)>>2]=-2139062144;c[a+(n+q)>>2]=-2139062144;c[a+(q+o)>>2]=-2139062144;c[a+(p+q)>>2]=-2139062144;return}function Usa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=ca((d[a+(15-b)|0]|0)+((d[a+(14-b)|0]|0)+((d[a+(13-b)|0]|0)+((d[a+(12-b)|0]|0)+((d[a+(11-b)|0]|0)+((d[a+(10-b)|0]|0)+((d[a+(9-b)|0]|0)+((d[a+(8-b)|0]|0)+((d[a+(7-b)|0]|0)+((d[a+(6-b)|0]|0)+((d[a+(5-b)|0]|0)+((d[a+(4-b)|0]|0)+((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+((d[a+(-b|0)|0]|0)+((d[a+((b*15|0)-1)|0]|0)+((d[a+((b*14|0)-1)|0]|0)+((d[a+((b*13|0)-1)|0]|0)+((d[a+((b*12|0)-1)|0]|0)+((d[a+((b*11|0)-1)|0]|0)+((d[a+((b*10|0)-1)|0]|0)+((d[a+((b*9|0)-1)|0]|0)+((d[a+((b<<3)-1)|0]|0)+((d[a+((b*7|0)-1)|0]|0)+((d[a+((b*6|0)-1)|0]|0)+((d[a+((b*5|0)-1)|0]|0)+((d[a+((b<<2)-1)|0]|0)+((d[a+((b*3|0)-1)|0]|0)+((d[a+((b<<1)-1)|0]|0)+((d[a+(b-1)|0]|0)+(d[a-1|0]|0)))))))))))))))))))))))))))))))+16>>5,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+8>>2]=e;c[a+12>>2]=e;c[a+b>>2]=e;c[a+(b+4)>>2]=e;c[a+(b+8)>>2]=e;c[a+(b+12)>>2]=e;f=b<<1;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;return}function Vsa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+(-b|0)>>2]|0;e=c[a+(4-b)>>2]|0;f=c[a+(8-b)>>2]|0;g=c[a+(12-b)>>2]|0;h=0;do{i=ca(h,b)|0;c[a+i>>2]=d;c[a+(i+4)>>2]=e;c[a+(i+8)>>2]=f;c[a+(i+12)>>2]=g;h=h+1|0;}while((h|0)<16);return}function Wsa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=0;do{f=ca(e,b)|0;g=ca(d[a+(f-1)|0]|0,16843009)|0;c[a+f>>2]=g;c[a+(f+4)>>2]=g;c[a+(f+8)>>2]=g;c[a+(f+12)>>2]=g;e=e+1|0;}while((e|0)<16);return}function Xsa(a,b){a=a|0;b=b|0;var d=0,e=0;mrc(a|0,127,16)|0;c[a+b>>2]=2139062143;c[a+(b+4)>>2]=2139062143;c[a+(b+8)>>2]=2139062143;c[a+(b+12)>>2]=2139062143;d=b<<1;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;d=e+b|0;c[a+d>>2]=2139062143;c[a+(d+4)>>2]=2139062143;c[a+(d+8)>>2]=2139062143;c[a+(d+12)>>2]=2139062143;e=d+b|0;c[a+e>>2]=2139062143;c[a+(e+4)>>2]=2139062143;c[a+(e+8)>>2]=2139062143;c[a+(e+12)>>2]=2139062143;return}function Ysa(a,b){a=a|0;b=b|0;var d=0,e=0;mrc(a|0,-127|0,16)|0;c[a+b>>2]=-2122219135;c[a+(b+4)>>2]=-2122219135;c[a+(b+8)>>2]=-2122219135;c[a+(b+12)>>2]=-2122219135;d=b<<1;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;d=e+b|0;c[a+d>>2]=-2122219135;c[a+(d+4)>>2]=-2122219135;c[a+(d+8)>>2]=-2122219135;c[a+(d+12)>>2]=-2122219135;e=d+b|0;c[a+e>>2]=-2122219135;c[a+(e+4)>>2]=-2122219135;c[a+(e+8)>>2]=-2122219135;c[a+(e+12)>>2]=-2122219135;return}function Zsa(a,b){a=a|0;b=b|0;lta(a,b,0,0);return}function _sa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=ca((d[a+((b*15|0)-1)|0]|0)+((d[a+((b*14|0)-1)|0]|0)+((d[a+((b*13|0)-1)|0]|0)+((d[a+((b*12|0)-1)|0]|0)+((d[a+((b*11|0)-1)|0]|0)+((d[a+((b*10|0)-1)|0]|0)+((d[a+((b*9|0)-1)|0]|0)+((d[a+((b<<3)-1)|0]|0)+((d[a+((b*7|0)-1)|0]|0)+((d[a+((b*6|0)-1)|0]|0)+((d[a+((b*5|0)-1)|0]|0)+((d[a+((b<<2)-1)|0]|0)+((d[a+((b*3|0)-1)|0]|0)+((d[a+((b<<1)-1)|0]|0)+((d[a+(b-1)|0]|0)+(d[a-1|0]|0)))))))))))))))+8>>4,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+8>>2]=e;c[a+12>>2]=e;c[a+b>>2]=e;c[a+(b+4)>>2]=e;c[a+(b+8)>>2]=e;c[a+(b+12)>>2]=e;f=b<<1;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;return}function $sa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=ca((d[a+(15-b)|0]|0)+((d[a+(14-b)|0]|0)+((d[a+(13-b)|0]|0)+((d[a+(12-b)|0]|0)+((d[a+(11-b)|0]|0)+((d[a+(10-b)|0]|0)+((d[a+(9-b)|0]|0)+((d[a+(8-b)|0]|0)+((d[a+(7-b)|0]|0)+((d[a+(6-b)|0]|0)+((d[a+(5-b)|0]|0)+((d[a+(4-b)|0]|0)+((d[a+(3-b)|0]|0)+((d[a+(2-b)|0]|0)+((d[a+(1-b)|0]|0)+(d[a+(-b|0)|0]|0)))))))))))))))+8>>4,16843009)|0;c[a>>2]=e;c[a+4>>2]=e;c[a+8>>2]=e;c[a+12>>2]=e;c[a+b>>2]=e;c[a+(b+4)>>2]=e;c[a+(b+8)>>2]=e;c[a+(b+12)>>2]=e;f=b<<1;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;f=g+b|0;c[a+f>>2]=e;c[a+(f+4)>>2]=e;c[a+(f+8)>>2]=e;c[a+(f+12)>>2]=e;g=f+b|0;c[a+g>>2]=e;c[a+(g+4)>>2]=e;c[a+(g+8)>>2]=e;c[a+(g+12)>>2]=e;return}function ata(a,b){a=a|0;b=b|0;var d=0,e=0;mrc(a|0,-128|0,16)|0;c[a+b>>2]=-2139062144;c[a+(b+4)>>2]=-2139062144;c[a+(b+8)>>2]=-2139062144;c[a+(b+12)>>2]=-2139062144;d=b<<1;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;d=e+b|0;c[a+d>>2]=-2139062144;c[a+(d+4)>>2]=-2139062144;c[a+(d+8)>>2]=-2139062144;c[a+(d+12)>>2]=-2139062144;e=d+b|0;c[a+e>>2]=-2139062144;c[a+(e+4)>>2]=-2139062144;c[a+(e+8)>>2]=-2139062144;c[a+(e+12)>>2]=-2139062144;return}function bta(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=e<<1;g=e*3|0;h=e<<2;i=(b[d>>1]&255)+(a[c+(-e|0)|0]|0)&255;a[c]=i;j=i+(b[d+8>>1]&255)&255;a[c+e|0]=j;i=j+(b[d+16>>1]&255)&255;a[c+(g-e)|0]=i;a[c+(h-e)|0]=i+(b[d+24>>1]&255);i=1-e|0;e=(b[d+2>>1]&255)+(a[c+i|0]|0)&255;a[c+1|0]=e;j=e+(b[d+10>>1]&255)&255;a[c+(i+f)|0]=j;e=j+(b[d+18>>1]&255)&255;a[c+(i+g)|0]=e;a[c+(i+h)|0]=e+(b[d+26>>1]&255);e=i+1|0;j=(b[d+4>>1]&255)+(a[c+e|0]|0)&255;a[c+2|0]=j;k=j+(b[d+12>>1]&255)&255;a[c+(e+f)|0]=k;j=k+(b[d+20>>1]&255)&255;a[c+(e+g)|0]=j;a[c+(e+h)|0]=j+(b[d+28>>1]&255);j=i+2|0;i=(b[d+6>>1]&255)+(a[c+j|0]|0)&255;a[c+3|0]=i;e=i+(b[d+14>>1]&255)&255;a[c+(j+f)|0]=e;f=e+(b[d+22>>1]&255)&255;a[c+(j+g)|0]=f;a[c+(j+h)|0]=f+(b[d+30>>1]&255);mrc(d|0,0,32)|0;return}function cta(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=(b[d>>1]&255)+(a[c-1|0]|0)&255;a[c]=f;g=f+(b[d+2>>1]&255)&255;a[c+1|0]=g;f=g+(b[d+4>>1]&255)&255;a[c+2|0]=f;a[c+3|0]=f+(b[d+6>>1]&255);f=(b[d+8>>1]&255)+(a[c+(e-1)|0]|0)&255;a[c+e|0]=f;g=f+(b[d+10>>1]&255)&255;a[c+(e+1)|0]=g;f=g+(b[d+12>>1]&255)&255;a[c+(e+2)|0]=f;a[c+(e+3)|0]=f+(b[d+14>>1]&255);f=e<<1;g=(b[d+16>>1]&255)+(a[c+(f-1)|0]|0)&255;a[c+f|0]=g;h=g+(b[d+18>>1]&255)&255;a[c+(f|1)|0]=h;g=h+(b[d+20>>1]&255)&255;a[c+(f+2)|0]=g;a[c+(f+3)|0]=g+(b[d+22>>1]&255);g=f+e|0;e=(b[d+24>>1]&255)+(a[c+(g-1)|0]|0)&255;a[c+g|0]=e;f=e+(b[d+26>>1]&255)&255;a[c+(g+1)|0]=f;e=f+(b[d+28>>1]&255)&255;a[c+(g+2)|0]=e;a[c+(g+3)|0]=e+(b[d+30>>1]&255);mrc(d|0,0,32)|0;return}function dta(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=e<<1;g=e*3|0;h=e<<2;i=e*5|0;j=e*6|0;k=e*7|0;l=e<<3;m=0;n=c+(-e|0)|0;c=d;while(1){o=(b[c>>1]&255)+(a[n]|0)&255;a[n+e|0]=o;p=o+(b[c+16>>1]&255)&255;a[n+f|0]=p;o=p+(b[c+32>>1]&255)&255;a[n+g|0]=o;p=o+(b[c+48>>1]&255)&255;a[n+h|0]=p;o=p+(b[c+64>>1]&255)&255;a[n+i|0]=o;p=o+(b[c+80>>1]&255)&255;a[n+j|0]=p;o=p+(b[c+96>>1]&255)&255;a[n+k|0]=o;a[n+l|0]=o+(b[c+112>>1]&255);o=m+1|0;if((o|0)<8){m=o;n=n+1|0;c=c+2|0}else{break}}mrc(d|0,0,128)|0;return}function eta(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=0;g=c;c=d;while(1){h=(b[c>>1]&255)+(a[g-1|0]|0)&255;a[g]=h;i=h+(b[c+2>>1]&255)&255;a[g+1|0]=i;h=i+(b[c+4>>1]&255)&255;a[g+2|0]=h;i=h+(b[c+6>>1]&255)&255;a[g+3|0]=i;h=i+(b[c+8>>1]&255)&255;a[g+4|0]=h;i=h+(b[c+10>>1]&255)&255;a[g+5|0]=i;h=i+(b[c+12>>1]&255)&255;a[g+6|0]=h;a[g+7|0]=h+(b[c+14>>1]&255);h=f+1|0;if((h|0)<8){f=h;g=g+e|0;c=c+16|0}else{break}}mrc(d|0,0,128)|0;return}function fta(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;bta(a+(c[b>>2]|0)|0,d,e);bta(a+(c[b+4>>2]|0)|0,d+32|0,e);bta(a+(c[b+8>>2]|0)|0,d+64|0,e);bta(a+(c[b+12>>2]|0)|0,d+96|0,e);return}function gta(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;cta(a+(c[b>>2]|0)|0,d,e);cta(a+(c[b+4>>2]|0)|0,d+32|0,e);cta(a+(c[b+8>>2]|0)|0,d+64|0,e);cta(a+(c[b+12>>2]|0)|0,d+96|0,e);return}function hta(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;bta(a+(c[b>>2]|0)|0,d,e);bta(a+(c[b+4>>2]|0)|0,d+32|0,e);bta(a+(c[b+8>>2]|0)|0,d+64|0,e);bta(a+(c[b+12>>2]|0)|0,d+96|0,e);bta(a+(c[b+32>>2]|0)|0,d+128|0,e);bta(a+(c[b+36>>2]|0)|0,d+160|0,e);bta(a+(c[b+40>>2]|0)|0,d+192|0,e);bta(a+(c[b+44>>2]|0)|0,d+224|0,e);return}function ita(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;cta(a+(c[b>>2]|0)|0,d,e);cta(a+(c[b+4>>2]|0)|0,d+32|0,e);cta(a+(c[b+8>>2]|0)|0,d+64|0,e);cta(a+(c[b+12>>2]|0)|0,d+96|0,e);cta(a+(c[b+32>>2]|0)|0,d+128|0,e);cta(a+(c[b+36>>2]|0)|0,d+160|0,e);cta(a+(c[b+40>>2]|0)|0,d+192|0,e);cta(a+(c[b+44>>2]|0)|0,d+224|0,e);return}function jta(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{bta(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<4<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function kta(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=0;do{cta(a+(c[b+(f<<2)>>2]|0)|0,d+(f<<4<<1)|0,e);f=f+1|0;}while((f|0)<16);return}function lta(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=-c|0;h=7-c|0;i=(c<<3)-1|0;j=b+i|0;k=b+(i-(c<<1))|0;i=b+((c*15|0)-1)|0;l=2;m=j;n=k;o=(d[b+(h+1)|0]|0)-(d[b+(h-1)|0]|0)|0;p=(d[j]|0)-(d[k]|0)|0;do{m=m+c|0;n=n+g|0;o=(ca((d[b+(l+h)|0]|0)-(d[b+(h-l)|0]|0)|0,l)|0)+o|0;p=(ca((d[m]|0)-(d[n]|0)|0,l)|0)+p|0;l=l+1|0;}while((l|0)<9);do{if((e|0)==0){if((f|0)==0){q=(p*5|0)+32>>6;r=(o*5|0)+32>>6;break}else{q=(p>>2)+p>>4;r=(o>>2)+o>>4;break}}else{q=(((o|0)/4|0)*5|0|0)/16|0;r=(((p|0)/4|0)*5|0|0)/16|0}}while(0);p=r<<1;o=r*3|0;f=r<<2;e=((q+r|0)*-7|0)+16+((d[b+(16-c-1)|0]|0)+(d[i]|0)<<4)|0;i=b;b=16;while(1){l=-16;n=e;while(1){m=n>>5;if(m>>>0>255>>>0){s=-m>>31&255}else{s=m&255}a[i+(l+16)|0]=s;m=n+r>>5;if(m>>>0>255>>>0){t=-m>>31&255}else{t=m&255}a[i+(l+17)|0]=t;m=n+p>>5;if(m>>>0>255>>>0){u=-m>>31&255}else{u=m&255}a[i+(l+18)|0]=u;m=n+o>>5;if(m>>>0>255>>>0){v=-m>>31&255}else{v=m&255}a[i+(l+19)|0]=v;m=l+4|0;if((m|0)<0){l=m;n=n+f|0}else{break}}n=b-1|0;if((n|0)>0){e=e+q|0;i=i+c|0;b=n}else{break}}return}function mta(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;l=d[b+(-g|0)|0]|0;m=d[b+(1-g)|0]|0;n=d[b+(2-g)|0]|0;o=d[b+(3-g)|0]|0;p=c&255;c=e&255;e=m<<1;a[b]=(h+4+j+e+(l+i<<1)|0)>>>3;h=(m+1+n|0)>>>1&255;q=g<<1;a[b+q|0]=h;a[b+1|0]=h;h=(n+1+o|0)>>>1&255;a[b+(q|1)|0]=h;a[b+2|0]=h;h=p+1|0;r=(h+o|0)>>>1&255;a[b+(q+2)|0]=r;a[b+3|0]=r;a[b+(q+3)|0]=(h+c|0)>>>1;a[b+g|0]=(i+4+(j<<1)+k+l+e+n|0)>>>3;e=(m+2+(n<<1)+o|0)>>>2&255;m=g*3|0;a[b+m|0]=e;a[b+(g+1)|0]=e;e=p+2|0;l=(e+n+(o<<1)|0)>>>2&255;a[b+(m+1)|0]=l;a[b+(g+2)|0]=l;l=((p<<1)+2+c+o|0)>>>2&255;a[b+(m+2)|0]=l;a[b+(g+3)|0]=l;a[b+(m+3)|0]=(e+(c<<1)+(f&255)|0)>>>2;return}function nta(a,b){a=a|0;b=b|0;if((b|0)==10){c[a>>2]=930;c[a+4>>2]=462;c[a+8>>2]=150;c[a+12>>2]=198;c[a+16>>2]=1284;c[a+20>>2]=1964;c[a+24>>2]=950;c[a+28>>2]=2398;c[a+32>>2]=1118;c[a+36>>2]=1222;c[a+40>>2]=472;c[a+44>>2]=1386;c[a+48>>2]=922;c[a+52>>2]=1770;c[a+56>>2]=908;c[a+60>>2]=2076;c[a+64>>2]=144;c[a+68>>2]=438;c[a+72>>2]=2146;c[a+76>>2]=1622;c[a+80>>2]=1214;c[a+84>>2]=1476;c[a+88>>2]=1932;c[a+92>>2]=2414;c[a+96>>2]=1460;c[a+100>>2]=1966;c[a+104>>2]=340;c[a+108>>2]=1922;c[a+112>>2]=1572;c[a+116>>2]=1702;c[a+120>>2]=552;c[a+124>>2]=1410;c[a+128>>2]=294;c[a+132>>2]=1362;c[a+136>>2]=1006;c[a+140>>2]=992;c[a+144>>2]=986;c[a+148>>2]=670;c[a+152>>2]=1174;c[a+156>>2]=1670;c[a+160>>2]=1498;c[a+164>>2]=2336;c[a+168>>2]=1862;c[a+172>>2]=258;c[a+176>>2]=1292;c[a+180>>2]=720;c[a+184>>2]=2378;c[a+188>>2]=398;c[a+192>>2]=1732;c[a+196>>2]=1942;c[a+200>>2]=414;c[a+204>>2]=788;c[a+208>>2]=684;c[a+212>>2]=24;c[a+216>>2]=666;c[a+220>>2]=688;c[a+224>>2]=1918;c[a+228>>2]=1096;c[a+232>>2]=1794;c[a+236>>2]=2270;c[a+240>>2]=1766;c[a+244>>2]=1444;c[a+248>>2]=2352;c[a+252>>2]=1768;c[a+256>>2]=826;c[a+260>>2]=1178;c[a+264>>2]=226;c[a+268>>2]=2304;c[a+272>>2]=1604;c[a+276>>2]=1596;c[a+280>>2]=2412;c[a+284>>2]=336;c[a+288>>2]=1018;c[a+292>>2]=200;c[a+296>>2]=1142;c[a+300>>2]=1632;c[a+304>>2]=644;c[a+308>>2]=988;c[a+312>>2]=2252;c[a+316>>2]=1808;c[a+320>>2]=2406;c[a+324>>2]=2426;c[a+328>>2]=1458;c[a+332>>2]=188;c[a+336>>2]=1684;c[a+340>>2]=1658;c[a+344>>2]=1276;c[a+348>>2]=550;c[a+352>>2]=2074;c[a+356>>2]=1630;c[a+360>>2]=1290;c[a+364>>2]=1378;c[a+368>>2]=1308;c[a+372>>2]=814;c[a+376>>2]=1652;c[a+380>>2]=2070;c[a+384>>2]=1726;c[a+388>>2]=642;c[a+392>>2]=996;c[a+396>>2]=1132;c[a+400>>2]=1950;c[a+404>>2]=2272;c[a+408>>2]=2038;c[a+412>>2]=304;c[a+416>>2]=1426;c[a+420>>2]=604;c[a+424>>2]=616;c[a+428>>2]=1680;c[a+432>>2]=732;c[a+436>>2]=1272;c[a+440>>2]=2362;c[a+444>>2]=334;return}else if((b|0)==9){c[a>>2]=366;c[a+4>>2]=1594;c[a+8>>2]=1638;c[a+12>>2]=1306;c[a+16>>2]=1974;c[a+20>>2]=2050;c[a+24>>2]=400;c[a+28>>2]=680;c[a+32>>2]=594;c[a+36>>2]=2004;c[a+40>>2]=2026;c[a+44>>2]=1266;c[a+48>>2]=838;c[a+52>>2]=2386;c[a+56>>2]=172;c[a+60>>2]=1812;c[a+64>>2]=766;c[a+68>>2]=2434;c[a+72>>2]=754;c[a+76>>2]=1158;c[a+80>>2]=1280;c[a+84>>2]=870;c[a+88>>2]=142;c[a+92>>2]=2122;c[a+96>>2]=1634;c[a+100>>2]=1244;c[a+104>>2]=1678;c[a+108>>2]=868;c[a+112>>2]=1304;c[a+116>>2]=1156;c[a+120>>2]=392;c[a+124>>2]=1746;c[a+128>>2]=98;c[a+132>>2]=612;c[a+136>>2]=1570;c[a+140>>2]=1494;c[a+144>>2]=624;c[a+148>>2]=1834;c[a+152>>2]=1412;c[a+156>>2]=978;c[a+160>>2]=156;c[a+164>>2]=572;c[a+168>>2]=982;c[a+172>>2]=520;c[a+176>>2]=1958;c[a+180>>2]=502;c[a+184>>2]=2206;c[a+188>>2]=1090;c[a+192>>2]=1062;c[a+196>>2]=1838;c[a+200>>2]=158;c[a+204>>2]=632;c[a+208>>2]=208;c[a+212>>2]=2198;c[a+216>>2]=242;c[a+220>>2]=966;c[a+224>>2]=2322;c[a+228>>2]=1512;c[a+232>>2]=2284;c[a+236>>2]=614;c[a+240>>2]=1760;c[a+244>>2]=1848;c[a+248>>2]=1404;c[a+252>>2]=118;c[a+256>>2]=48;c[a+260>>2]=2018;c[a+264>>2]=914;c[a+268>>2]=774;c[a+272>>2]=546;c[a+276>>2]=872;c[a+280>>2]=2062;c[a+284>>2]=1358;c[a+288>>2]=768;c[a+292>>2]=1334;c[a+296>>2]=924;c[a+300>>2]=2042;c[a+304>>2]=404;c[a+308>>2]=136;c[a+312>>2]=2072;c[a+316>>2]=202;c[a+320>>2]=480;c[a+324>>2]=1778;c[a+328>>2]=1030;c[a+332>>2]=2250;c[a+336>>2]=2092;c[a+340>>2]=82;c[a+344>>2]=536;c[a+348>>2]=968;c[a+352>>2]=1748;c[a+356>>2]=2134;c[a+360>>2]=74;c[a+364>>2]=1242;c[a+368>>2]=1722;c[a+372>>2]=120;c[a+376>>2]=1682;c[a+380>>2]=606;c[a+384>>2]=382;c[a+388>>2]=692;c[a+392>>2]=1648;c[a+396>>2]=1980;c[a+400>>2]=674;c[a+404>>2]=764;c[a+408>>2]=1590;c[a+412>>2]=2008;c[a+416>>2]=658;c[a+420>>2]=2022;c[a+424>>2]=1120;c[a+428>>2]=2282;c[a+432>>2]=640;c[a+436>>2]=802;c[a+440>>2]=2384;c[a+444>>2]=1650;return}else if((b|0)==12){c[a>>2]=1544;c[a+4>>2]=1106;c[a+8>>2]=1960;c[a+12>>2]=2028;c[a+16>>2]=696;c[a+20>>2]=1352;c[a+24>>2]=1558;c[a+28>>2]=566;c[a+32>>2]=478;c[a+36>>2]=620;c[a+40>>2]=1772;c[a+44>>2]=2002;c[a+48>>2]=1530;c[a+52>>2]=2366;c[a+56>>2]=308;c[a+60>>2]=1488;c[a+64>>2]=742;c[a+68>>2]=1072;c[a+72>>2]=1998;c[a+76>>2]=1002;c[a+80>>2]=4;c[a+84>>2]=52;c[a+88>>2]=126;c[a+92>>2]=556;c[a+96>>2]=862;c[a+100>>2]=1356;c[a+104>>2]=952;c[a+108>>2]=114;c[a+112>>2]=2162;c[a+116>>2]=2326;c[a+120>>2]=2388;c[a+124>>2]=798;c[a+128>>2]=888;c[a+132>>2]=1972;c[a+136>>2]=1870;c[a+140>>2]=380;c[a+144>>2]=384;c[a+148>>2]=64;c[a+152>>2]=1786;c[a+156>>2]=2294;c[a+160>>2]=592;c[a+164>>2]=1714;c[a+168>>2]=38;c[a+172>>2]=850;c[a+176>>2]=1706;c[a+180>>2]=1322;c[a+184>>2]=1448;c[a+188>>2]=2240;c[a+192>>2]=1128;c[a+196>>2]=1316;c[a+200>>2]=1040;c[a+204>>2]=1402;c[a+208>>2]=1302;c[a+212>>2]=622;c[a+216>>2]=372;c[a+220>>2]=88;c[a+224>>2]=108;c[a+228>>2]=1696;c[a+232>>2]=1186;c[a+236>>2]=1654;c[a+240>>2]=2088;c[a+244>>2]=834;c[a+248>>2]=2218;c[a+252>>2]=2380;c[a+256>>2]=2348;c[a+260>>2]=564;c[a+264>>2]=810;c[a+268>>2]=446;c[a+272>>2]=2214;c[a+276>>2]=958;c[a+280>>2]=2102;c[a+284>>2]=762;c[a+288>>2]=1636;c[a+292>>2]=786;c[a+296>>2]=530;c[a+300>>2]=1012;c[a+304>>2]=1522;c[a+308>>2]=374;c[a+312>>2]=412;c[a+316>>2]=2424;c[a+320>>2]=574;c[a+324>>2]=588;c[a+328>>2]=860;c[a+332>>2]=2184;c[a+336>>2]=1100;c[a+340>>2]=1050;c[a+344>>2]=1894;c[a+348>>2]=1898;c[a+352>>2]=1492;c[a+356>>2]=1010;c[a+360>>2]=1906;c[a+364>>2]=1978;c[a+368>>2]=1928;c[a+372>>2]=1424;c[a+376>>2]=1066;c[a+380>>2]=1478;c[a+384>>2]=2354;c[a+388>>2]=1246;c[a+392>>2]=2382;c[a+396>>2]=728;c[a+400>>2]=1360;c[a+404>>2]=1656;c[a+408>>2]=238;c[a+412>>2]=880;c[a+416>>2]=832;c[a+420>>2]=8;c[a+424>>2]=1216;c[a+428>>2]=1286;c[a+432>>2]=1330;c[a+436>>2]=1890;c[a+440>>2]=2220;c[a+444>>2]=1326;return}else if((b|0)==14){c[a>>2]=2140;c[a+4>>2]=1700;c[a+8>>2]=796;c[a+12>>2]=1408;c[a+16>>2]=96;c[a+20>>2]=746;c[a+24>>2]=2152;c[a+28>>2]=1172;c[a+32>>2]=2356;c[a+36>>2]=20;c[a+40>>2]=1708;c[a+44>>2]=178;c[a+48>>2]=2138;c[a+52>>2]=544;c[a+56>>2]=2124;c[a+60>>2]=1196;c[a+64>>2]=1338;c[a+68>>2]=1374;c[a+72>>2]=1366;c[a+76>>2]=396;c[a+80>>2]=2132;c[a+84>>2]=2180;c[a+88>>2]=714;c[a+92>>2]=1170;c[a+96>>2]=558;c[a+100>>2]=1054;c[a+104>>2]=1552;c[a+108>>2]=738;c[a+112>>2]=1288;c[a+116>>2]=488;c[a+120>>2]=1762;c[a+124>>2]=1114;c[a+128>>2]=1470;c[a+132>>2]=174;c[a+136>>2]=1254;c[a+140>>2]=2222;c[a+144>>2]=102;c[a+148>>2]=1892;c[a+152>>2]=1450;c[a+156>>2]=162;c[a+160>>2]=312;c[a+164>>2]=192;c[a+168>>2]=638;c[a+172>>2]=1456;c[a+176>>2]=80;c[a+180>>2]=1944;c[a+184>>2]=848;c[a+188>>2]=1606;c[a+192>>2]=518;c[a+196>>2]=716;c[a+200>>2]=1664;c[a+204>>2]=496;c[a+208>>2]=1908;c[a+212>>2]=1226;c[a+216>>2]=2200;c[a+220>>2]=2228;c[a+224>>2]=734;c[a+228>>2]=2308;c[a+232>>2]=894;c[a+236>>2]=1364;c[a+240>>2]=542;c[a+244>>2]=260;c[a+248>>2]=86;c[a+252>>2]=538;c[a+256>>2]=1724;c[a+260>>2]=2400;c[a+264>>2]=1420;c[a+268>>2]=1088;c[a+272>>2]=70;c[a+276>>2]=1850;c[a+280>>2]=1182;c[a+284>>2]=1542;c[a+288>>2]=2226;c[a+292>>2]=1400;c[a+296>>2]=2364;c[a+300>>2]=132;c[a+304>>2]=932;c[a+308>>2]=2210;c[a+312>>2]=1028;c[a+316>>2]=586;c[a+320>>2]=1496;c[a+324>>2]=1200;c[a+328>>2]=278;c[a+332>>2]=990;c[a+336>>2]=1432;c[a+340>>2]=1392;c[a+344>>2]=66;c[a+348>>2]=76;c[a+352>>2]=554;c[a+356>>2]=92;c[a+360>>2]=78;c[a+364>>2]=184;c[a+368>>2]=100;c[a+372>>2]=2350;c[a+376>>2]=436;c[a+380>>2]=864;c[a+384>>2]=494;c[a+388>>2]=1866;c[a+392>>2]=1082;c[a+396>>2]=140;c[a+400>>2]=752;c[a+404>>2]=1080;c[a+408>>2]=482;c[a+412>>2]=1818;c[a+416>>2]=522;c[a+420>>2]=1826;c[a+424>>2]=1328;c[a+428>>2]=1902;c[a+432>>2]=1916;c[a+436>>2]=84;c[a+440>>2]=1612;c[a+444>>2]=122;return}else{c[a>>2]=1298;c[a+4>>2]=1822;c[a+8>>2]=168;c[a+12>>2]=1666;c[a+16>>2]=1014;c[a+20>>2]=936;c[a+24>>2]=1900;c[a+28>>2]=364;c[a+32>>2]=984;c[a+36>>2]=2332;c[a+40>>2]=506;c[a+44>>2]=22;c[a+48>>2]=2330;c[a+52>>2]=2054;c[a+56>>2]=448;c[a+60>>2]=330;c[a+64>>2]=2262;c[a+68>>2]=944;c[a+72>>2]=1086;c[a+76>>2]=2108;c[a+80>>2]=2234;c[a+84>>2]=2368;c[a+88>>2]=2216;c[a+92>>2]=2260;c[a+96>>2]=1976;c[a+100>>2]=920;c[a+104>>2]=2024;c[a+108>>2]=1814;c[a+112>>2]=970;c[a+116>>2]=1518;c[a+120>>2]=1354;c[a+124>>2]=812;c[a+128>>2]=1270;c[a+132>>2]=1566;c[a+136>>2]=2150;c[a+140>>2]=14;c[a+144>>2]=1578;c[a+148>>2]=884;c[a+152>>2]=1068;c[a+156>>2]=44;c[a+160>>2]=454;c[a+164>>2]=266;c[a+168>>2]=50;c[a+172>>2]=224;c[a+176>>2]=1614;c[a+180>>2]=528;c[a+184>>2]=1020;c[a+188>>2]=186;c[a+192>>2]=434;c[a+196>>2]=1490;c[a+200>>2]=456;c[a+204>>2]=320;c[a+208>>2]=1124;c[a+212>>2]=112;c[a+216>>2]=2318;c[a+220>>2]=1294;c[a+224>>2]=1380;c[a+228>>2]=1176;c[a+232>>2]=1340;c[a+236>>2]=1568;c[a+240>>2]=1416;c[a+244>>2]=2166;c[a+248>>2]=2338;c[a+252>>2]=1592;c[a+256>>2]=1528;c[a+260>>2]=498;c[a+264>>2]=310;c[a+268>>2]=1710;c[a+272>>2]=1500;c[a+276>>2]=442;c[a+280>>2]=568;c[a+284>>2]=342;c[a+288>>2]=56;c[a+292>>2]=1464;c[a+296>>2]=2420;c[a+300>>2]=1698;c[a+304>>2]=1484;c[a+308>>2]=1600;c[a+312>>2]=1740;c[a+316>>2]=1988;c[a+320>>2]=1440;c[a+324>>2]=2114;c[a+328>>2]=694;c[a+332>>2]=1300;c[a+336>>2]=1154;c[a+340>>2]=1016;c[a+344>>2]=2046;c[a+348>>2]=630;c[a+352>>2]=1258;c[a+356>>2]=46;c[a+360>>2]=1008;c[a+364>>2]=2212;c[a+368>>2]=792;c[a+372>>2]=2202;c[a+376>>2]=750;c[a+380>>2]=292;c[a+384>>2]=2156;c[a+388>>2]=736;c[a+392>>2]=596;c[a+396>>2]=2310;c[a+400>>2]=1038;c[a+404>>2]=416;c[a+408>>2]=1910;c[a+412>>2]=484;c[a+416>>2]=598;c[a+420>>2]=1076;c[a+424>>2]=2052;c[a+428>>2]=194;c[a+432>>2]=1224;c[a+436>>2]=1734;c[a+440>>2]=302;c[a+444>>2]=1628;return}}function ota(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e+4|0;g=b+f|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=e<<1;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;h=b+g|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+8|0;c[a+8>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+12|0;c[a+12>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=e+8|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=e+12|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+4|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=g+e|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+4|0;f=b+g|0;c[a+g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=h+e|0;h=b+f|0;c[a+f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+4|0;g=b+h|0;c[a+h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;e=b+g|0;c[a+g>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=g+4|0;g=b+e|0;c[a+e>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;return}function pta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;FEa(g|0,b,16,e);FEa(g+8|0,b+8|0,16,e);h=e<<3;FEa(g+128|0,b+h|0,16,e);FEa(g+136|0,b+(h+8)|0,16,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ca(o,e)|0;n=h+8|0;k=b+n|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=o<<4;j=g+(k|8)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+n>>2]=(m|l)-((m^l)>>>1&2139062143);l=h+12|0;h=b+l|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(k|12)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+l>>2]=(k|m)-((k^m)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function qta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;FEa(a,b,c,c);FEa(a+8|0,b+8|0,c,c);d=c<<3;FEa(a+d|0,b+d|0,c,c);e=d+8|0;FEa(a+e|0,b+e|0,c,c);return}function rta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+256|0;g=f|0;FEa(g|0,b,16,e);FEa(g+8|0,b+8|0,16,e);h=e<<3;FEa(g+128|0,b+h|0,16,e);FEa(g+136|0,b+(h+8)|0,16,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{o=0;break}}do{h=ca(o,e)|0;n=b+(h+9)|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o<<4;j=g+(n|8)|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(h+8)>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(n|12)|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[a+(h+12)>>2]=(n|l)-((n^l)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function sta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+592|0;h=g|0;j=g+336|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=e;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+4|0;m=e+4|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+8|0;n=e+8|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+12|0;m=e+12|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=l+1|0;if((m|0)<21){k=k+f|0;e=e+16|0;l=m}else{break}}GEa(j|0,h+32|0,16,16);GEa(j+8|0,h+40|0,16,16);GEa(j+128|0,h+160|0,16,16);GEa(j+136|0,h+168|0,16,16);l=0;while(1){e=l<<4;k=h+(e+32)|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+e|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(l,f)|0;c[b+k>>2]=(n|m)-((n^m)>>>1&2139062143);m=e|4;e=h+(m+32)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+m|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(k+4)>>2]=(m|n)-((m^n)>>>1&2139062143);n=l+1|0;if((n|0)<16){l=n}else{o=0;break}}do{l=o<<4;n=l|8;m=h+(n+32)|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+n|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(o,f)|0;c[b+(m+8)>>2]=(n|k)-((n^k)>>>1&2139062143);k=l|12;l=h+(k+32)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+k|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(m+12)>>2]=(k|n)-((k^n)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=g;return}function tta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;FEa(j|0,e,16,f);FEa(j+8|0,e+8|0,16,f);l=f<<3;FEa(j+128|0,e+l|0,16,f);FEa(j+136|0,e+(l+8)|0,16,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=e;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+4|0;n=e+4|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+8|0;o=e+8|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+12|0;n=e+12|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+1|0;if((n|0)<21){l=l+f|0;e=e+16|0;m=n}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=0;while(1){m=h<<4;e=j+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(h,f)|0;c[b+e>>2]=(n|l)-((n^l)>>>1&2139062143);l=m|4;m=j+l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[b+(e+4)>>2]=(l|n)-((l^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{p=0;break}}do{h=p<<4;n=h|8;l=j+n|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+n|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(p,f)|0;c[b+(l+8)>>2]=(n|e)-((n^e)>>>1&2139062143);e=h|12;h=j+e|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(l+12)>>2]=(e|n)-((e^n)>>>1&2139062143);p=p+1|0;}while((p|0)<16);i=g;return}function uta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+1184|0;g=f|0;h=f+672|0;j=f+928|0;FEa(h|0,b,16,e);k=b+8|0;FEa(h+8|0,k,16,e);l=e<<3;m=b+l|0;FEa(h+128|0,m,16,e);n=b+(l+8)|0;FEa(h+136|0,n,16,e);l=g|0;HEa(j|0,l,b,16,16,e);b=g+16|0;HEa(j+8|0,b,k,16,16,e);HEa(j+128|0,l,m,16,16,e);HEa(j+136|0,b,n,16,16,e);n=0;while(1){b=n<<4;m=h+b|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+b|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(n,e)|0;c[a+m>>2]=(k|l)-((k^l)>>>1&2139062143);l=b|4;b=h+l|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+l|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(m+4)>>2]=(l|k)-((l^k)>>>1&2139062143);k=n+1|0;if((k|0)<16){n=k}else{o=0;break}}do{n=o<<4;k=n|8;l=h+k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+k|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(o,e)|0;c[a+(l+8)>>2]=(k|m)-((k^m)>>>1&2139062143);m=n|12;n=h+m|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+m|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[a+(l+12)>>2]=(m|k)-((m^k)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function vta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;FEa(j|0,e,16,f);FEa(j+8|0,e+8|0,16,f);l=f<<3;FEa(j+128|0,e+l|0,16,f);FEa(j+136|0,e+(l+8)|0,16,f);l=e+(-(f<<1)|1)|0;e=h|0;m=0;while(1){n=l;o=e;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+4|0;n=e+4|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+8|0;o=e+8|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+12|0;n=e+12|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+1|0;if((n|0)<21){l=l+f|0;e=e+16|0;m=n}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=0;while(1){m=h<<4;e=j+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(h,f)|0;c[b+e>>2]=(n|l)-((n^l)>>>1&2139062143);l=m|4;m=j+l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[b+(e+4)>>2]=(l|n)-((l^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{p=0;break}}do{h=p<<4;n=h|8;l=j+n|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+n|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(p,f)|0;c[b+(l+8)>>2]=(n|e)-((n^e)>>>1&2139062143);e=h|12;h=j+e|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(l+12)>>2]=(e|n)-((e^n)>>>1&2139062143);p=p+1|0;}while((p|0)<16);i=g;return}function wta(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+336|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=c;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+4|0;k=c+4|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+8|0;l=c+8|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+12|0;k=c+12|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+1|0;if((k|0)<21){h=h+e|0;c=c+16|0;j=k}else{break}}GEa(b,g+32|0,e,16);GEa(b+8|0,g+40|0,e,16);j=e<<3;GEa(b+j|0,g+160|0,e,16);GEa(b+(j+8)|0,g+168|0,e,16);i=f;return}function xta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1520|0;h=g|0;j=g+336|0;k=g+1008|0;l=g+1264|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=n;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+4|0;p=n+4|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+8|0;q=n+8|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+12|0;p=n+12|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+1|0;if((p|0)<21){m=m+f|0;n=n+16|0;o=p}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=j|0;HEa(l|0,h,e,16,16,f);o=j+16|0;HEa(l+8|0,o,e+8|0,16,16,f);j=f<<3;HEa(l+128|0,h,e+j|0,16,16,f);HEa(l+136|0,o,e+(j+8)|0,16,16,f);j=0;while(1){e=j<<4;o=k+e|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+e|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(j,f)|0;c[b+o>>2]=(n|h)-((n^h)>>>1&2139062143);h=e|4;e=k+h|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+4)>>2]=(h|n)-((h^n)>>>1&2139062143);n=j+1|0;if((n|0)<16){j=n}else{r=0;break}}do{j=r<<4;n=j|8;h=k+n|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+n|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(r,f)|0;c[b+(h+8)>>2]=(n|o)-((n^o)>>>1&2139062143);o=j|12;j=k+o|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[b+(h+12)>>2]=(o|n)-((o^n)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function yta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+672|0;e=d|0;f=e|0;HEa(a,f,b,c,16,c);g=e+16|0;HEa(a+8|0,g,b+8|0,c,16,c);e=c<<3;HEa(a+e|0,f,b+e|0,c,16,c);f=e+8|0;HEa(a+f|0,g,b+f|0,c,16,c);i=d;return}function zta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1520|0;h=g|0;j=g+336|0;k=g+1008|0;l=g+1264|0;m=e+(-(f<<1)|1)|0;n=h|0;o=0;while(1){p=m;q=n;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+4|0;p=n+4|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+8|0;q=n+8|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+12|0;p=n+12|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+1|0;if((p|0)<21){m=m+f|0;n=n+16|0;o=p}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=j|0;HEa(l|0,h,e,16,16,f);o=j+16|0;HEa(l+8|0,o,e+8|0,16,16,f);j=f<<3;HEa(l+128|0,h,e+j|0,16,16,f);HEa(l+136|0,o,e+(j+8)|0,16,16,f);j=0;while(1){e=j<<4;o=k+e|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+e|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(j,f)|0;c[b+o>>2]=(n|h)-((n^h)>>>1&2139062143);h=e|4;e=k+h|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+h|0;h=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(o+4)>>2]=(h|n)-((h^n)>>>1&2139062143);n=j+1|0;if((n|0)<16){j=n}else{r=0;break}}do{j=r<<4;n=j|8;h=k+n|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+n|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=ca(r,f)|0;c[b+(h+8)>>2]=(n|o)-((n^o)>>>1&2139062143);o=j|12;j=k+o|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[b+(h+12)>>2]=(o|n)-((o^n)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Ata(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+592|0;h=g|0;j=g+336|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=e;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+4|0;m=e+4|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+8|0;n=e+8|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+12|0;m=e+12|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=l+1|0;if((m|0)<21){k=k+f|0;e=e+16|0;l=m}else{break}}GEa(j|0,h+32|0,16,16);GEa(j+8|0,h+40|0,16,16);GEa(j+128|0,h+160|0,16,16);GEa(j+136|0,h+168|0,16,16);l=0;while(1){e=l<<4;k=h+(e+48)|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+e|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(l,f)|0;c[b+k>>2]=(n|m)-((n^m)>>>1&2139062143);m=e|4;e=h+(m+48)|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+m|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[b+(k+4)>>2]=(m|n)-((m^n)>>>1&2139062143);n=l+1|0;if((n|0)<16){l=n}else{o=0;break}}do{l=o<<4;n=l|8;m=h+(n+48)|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+n|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(o,f)|0;c[b+(m+8)>>2]=(n|k)-((n^k)>>>1&2139062143);k=l|12;l=h+(k+48)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+k|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(m+12)>>2]=(k|n)-((k^n)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=g;return}function Bta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;FEa(j|0,e+f|0,16,f);l=f+8|0;FEa(j+8|0,e+l|0,16,f);m=f<<3;FEa(j+128|0,e+(m+f)|0,16,f);FEa(j+136|0,e+(l+m)|0,16,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=e;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+4|0;n=e+4|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+8|0;o=e+8|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+12|0;n=e+12|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+1|0;if((n|0)<21){m=m+f|0;e=e+16|0;l=n}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=0;while(1){l=h<<4;e=j+l|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+l|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(h,f)|0;c[b+e>>2]=(n|m)-((n^m)>>>1&2139062143);m=l|4;l=j+m|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(e+4)>>2]=(m|n)-((m^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{p=0;break}}do{h=p<<4;n=h|8;m=j+n|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(p,f)|0;c[b+(m+8)>>2]=(n|e)-((n^e)>>>1&2139062143);e=h|12;h=j+e|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(m+12)>>2]=(e|n)-((e^n)>>>1&2139062143);p=p+1|0;}while((p|0)<16);i=g;return}function Cta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+1184|0;g=f|0;h=f+672|0;j=f+928|0;FEa(h|0,b+e|0,16,e);FEa(h+8|0,b+(e+8)|0,16,e);k=e<<3;FEa(h+128|0,b+(k+e)|0,16,e);l=k+8|0;FEa(h+136|0,b+(l+e)|0,16,e);m=g|0;HEa(j|0,m,b,16,16,e);n=g+16|0;HEa(j+8|0,n,b+8|0,16,16,e);HEa(j+128|0,m,b+k|0,16,16,e);HEa(j+136|0,n,b+l|0,16,16,e);l=0;while(1){b=l<<4;n=h+b|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+b|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(l,e)|0;c[a+n>>2]=(m|k)-((m^k)>>>1&2139062143);k=b|4;b=h+k|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+k|0;k=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(n+4)>>2]=(k|m)-((k^m)>>>1&2139062143);m=l+1|0;if((m|0)<16){l=m}else{o=0;break}}do{l=o<<4;m=l|8;k=h+m|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+m|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(o,e)|0;c[a+(k+8)>>2]=(m|n)-((m^n)>>>1&2139062143);n=l|12;l=h+n|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+n|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(k+12)>>2]=(n|m)-((n^m)>>>1&2139062143);o=o+1|0;}while((o|0)<16);i=f;return}function Dta(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;FEa(j|0,e+f|0,16,f);l=f+8|0;FEa(j+8|0,e+l|0,16,f);m=f<<3;FEa(j+128|0,e+(m+f)|0,16,f);FEa(j+136|0,e+(l+m)|0,16,f);m=e+(-(f<<1)|1)|0;e=h|0;l=0;while(1){n=m;o=e;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+4|0;n=e+4|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+8|0;o=e+8|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+12|0;n=e+12|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+1|0;if((n|0)<21){m=m+f|0;e=e+16|0;l=n}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=0;while(1){l=h<<4;e=j+l|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+l|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(h,f)|0;c[b+e>>2]=(n|m)-((n^m)>>>1&2139062143);m=l|4;l=j+m|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[b+(e+4)>>2]=(m|n)-((m^n)>>>1&2139062143);n=h+1|0;if((n|0)<16){h=n}else{p=0;break}}do{h=p<<4;n=h|8;m=j+n|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(p,f)|0;c[b+(m+8)>>2]=(n|e)-((n^e)>>>1&2139062143);e=h|12;h=j+e|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+e|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[b+(m+12)>>2]=(e|n)-((e^n)>>>1&2139062143);p=p+1|0;}while((p|0)<16);i=g;return}function Eta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+4|0;c[a+4>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(e+4)|0;c[a+(e+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=e<<1;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;f=b+g|0;c[a+h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+(g+4)|0;c[a+(h+4)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=g+e|0;g=h+e|0;h=b+f|0;c[a+g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=b+(f+4)|0;c[a+(g+4)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;h=f+e|0;f=g+e|0;g=b+h|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=b+(h+4)|0;c[a+(f+4)>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=h+e|0;h=f+e|0;e=b+g|0;c[a+h>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;e=b+(g+4)|0;c[a+(h+4)>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function Fta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;FEa(g|0,b,8,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=j+4|0;j=b+l|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+l>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function Gta(a,b,c){a=a|0;b=b|0;c=c|0;FEa(a,b,c,c);return}function Hta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+64|0;g=f|0;FEa(g|0,b,8,e);h=0;do{j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[a+j>>2]=(n|l)-((n^l)>>>1&2139062143);l=b+(j+5)|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+(k|4)|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(j+4)>>2]=(k|n)-((k^n)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function Ita(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=g+16|0;k=j;l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=4-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e-l)|0;c[g+8>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4-l)|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+4|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;j=b+(n-l)|0;c[g+32>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+36>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+48>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+52>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+64>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+68>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+80>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+84>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+96>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+100>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;GEa(h|0,k,8,8);j=0;do{g=j<<3;n=c[k+g>>2]|0;m=h+g|0;b=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,e)|0;c[a+m>>2]=(b|n)-((b^n)>>>1&2139062143);n=g|4;g=c[k+n>>2]|0;b=h+n|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;c[a+(m+4)>>2]=(n|g)-((n^g)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function Jta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;FEa(h|0,b,8,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=4-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e-l)|0;c[g+8>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4-l)|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+4|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;GEa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(k,e)|0;c[a+g>>2]=(m|n)-((m^n)>>>1&2139062143);n=o|4;o=h+n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+n|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[a+(g+4)>>2]=(n|m)-((n^m)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function Kta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+336|0;g=f+208|0;h=f+272|0;FEa(g|0,b,8,e);HEa(h|0,f|0,b,8,8,e);b=0;do{j=b<<3;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(b,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=j|4;j=g+l|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+l|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Lta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;FEa(h|0,b,8,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+4|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+e)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4+m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+4+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(m+o)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(o+4+m)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;GEa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(k,e)|0;c[a+g>>2]=(n|l)-((n^l)>>>1&2139062143);l=o|4;o=h+l|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+l|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[a+(g+4)>>2]=(l|n)-((l^n)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function Mta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+104|0;g=f|0;h=g+16|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=4-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e-j)|0;c[g+8>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e+4-j)|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+4|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e+4)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+32>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+36>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+48>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+52>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+64>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+68>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+80>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+84>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+96>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+100>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;GEa(a,h,e,8);i=f;return}function Nta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+208|0;j=i;i=i+64|0;k=i;i=i+64|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=4-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e-m)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4-m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+4|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+36>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+40>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+44>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+48>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+52>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+56>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+60>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+64>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+68>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+76>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+80>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+84>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+88>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+92>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+96>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+100>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;GEa(j|0,l,8,8);HEa(k|0,h|0,b,8,8,e);b=0;do{h=b<<3;l=j+h|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+h|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(b,e)|0;c[a+l>>2]=(g|p)-((g^p)>>>1&2139062143);p=h|4;h=j+p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+(l+4)>>2]=(p|g)-((p^g)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Ota(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+208|0;HEa(a,d|0,b,c,8,c);i=d;return}function Pta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+208|0;j=i;i=i+64|0;k=i;i=i+64|0;l=g+16|0;m=e<<1;n=-m|1;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+4|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+e)|0;c[g+8>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+4+n)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+m)|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(m+4+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(n+p)|0;c[g+24>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(p+4+n)|0;c[g+28>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+36>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+40>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+44>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+48>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+52>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+56>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+60>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+64>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+68>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+72>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+76>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+80>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+84>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+88>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+92>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+96>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+100>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;GEa(j|0,l,8,8);HEa(k|0,h|0,b,8,8,e);b=0;do{h=b<<3;l=j+h|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+h|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(b,e)|0;c[a+l>>2]=(g|p)-((g^p)>>>1&2139062143);p=h|4;h=j+p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[a+(l+4)>>2]=(p|g)-((p^g)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Qta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=4-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(e-k)|0;c[g+8>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(e+4-k)|0;c[g+12>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+4|0;c[g+20>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+24|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;GEa(h|0,j,8,8);j=m;m=0;do{o=m<<3;g=c[j+o>>2]|0;n=h+o|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(m,e)|0;c[a+n>>2]=(l|g)-((l^g)>>>1&2139062143);g=o|4;o=c[j+g>>2]|0;l=h+g|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(n+4)>>2]=(g|o)-((g^o)>>>1&2139062143);m=m+1|0;}while((m|0)<8);i=f;return}function Rta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;l=b+e|0;FEa(h|0,l,8,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=4-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e-m)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4-m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+4|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+32>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+36>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+40>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+44>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+48>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+52>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+56>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+60>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+64>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+68>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+76>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+80>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+84>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+88>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+92>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+96>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+100>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;GEa(j|0,k,8,8);k=0;do{l=k<<3;g=h+l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+l|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(k,e)|0;c[a+g>>2]=(n|o)-((n^o)>>>1&2139062143);o=l|4;l=h+o|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+o|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[a+(g+4)>>2]=(o|n)-((o^n)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function Sta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+336|0;g=f+208|0;h=f+272|0;FEa(g|0,b+e|0,8,e);HEa(h|0,f|0,b,8,8,e);b=0;do{j=b<<3;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(b,e)|0;c[a+k>>2]=(m|l)-((m^l)>>>1&2139062143);l=j|4;j=g+l|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+l|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+(k+4)>>2]=(l|m)-((l^m)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Tta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;FEa(h|0,b+e|0,8,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+4|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+e)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4+m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+4+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(m+o)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(o+4+m)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;GEa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(k,e)|0;c[a+g>>2]=(n|l)-((n^l)>>>1&2139062143);l=o|4;o=h+l|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+l|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[a+(g+4)>>2]=(l|n)-((l^n)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function Uta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e<<1;g=b+f|0;c[a+f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;g=f+e|0;e=b+g|0;c[a+g>>2]=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24;return}function Vta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+16|0;g=f|0;CEa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2139062143);j=b+e|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|h)-((j^h)>>>1&2139062143);h=e<<1;j=b+h|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+8>>2]|0;c[a+h>>2]=(j|k)-((j^k)>>>1&2139062143);k=e*3|0;e=b+k|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=c[g+12>>2]|0;c[a+k>>2]=(e|b)-((e^b)>>>1&2139062143);i=f;return}function Wta(a,b,c){a=a|0;b=b|0;c=c|0;CEa(a,b,c,c);return}function Xta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+16|0;g=f|0;CEa(g,b,4,e);h=b+1|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2139062143);j=b+(e+1)|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|h)-((j^h)>>>1&2139062143);h=e<<1;j=b+(h|1)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+8>>2]|0;c[a+h>>2]=(j|k)-((j^k)>>>1&2139062143);k=e*3|0;e=b+(k+1)|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=c[g+12>>2]|0;c[a+k>>2]=(e|b)-((e^b)>>>1&2139062143);i=f;return}function Yta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=g+20|0;q=o+e|0;o=b+(q-k)|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=q+e|0;q=b+(o-k)|0;c[g+24>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=o+e|0;o=b+(q-k)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+q)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;DEa(h,j,4);o=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|o)-((j^o)>>>1&2139062143);o=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|o)-((m^o)>>>1&2139062143);o=c[n>>2]|0;n=c[h+8>>2]|0;c[a+k>>2]=(n|o)-((n^o)>>>1&2139062143);o=c[p>>2]|0;p=c[h+12>>2]|0;c[a+(e*3|0)>>2]=(p|o)-((p^o)>>>1&2139062143);i=f;return}function Zta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;CEa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+32>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;DEa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2139062143);k=c[h+4>>2]|0;n=c[j+4>>2]|0;c[a+e>>2]=(n|k)-((n^k)>>>1&2139062143);k=c[h+8>>2]|0;n=c[j+8>>2]|0;c[a+l>>2]=(n|k)-((n^k)>>>1&2139062143);k=c[h+12>>2]|0;h=c[j+12>>2]|0;c[a+(e*3|0)>>2]=(h|k)-((h^k)>>>1&2139062143);i=f;return}function _ta(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+88|0;f=e+72|0;g=i;i=i+16|0;CEa(f,b,4,d);EEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+4>>2]|0;h=c[g+4>>2]|0;c[a+d>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+8>>2]|0;h=c[g+8>>2]|0;c[a+(d<<1)>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+12>>2]|0;f=c[g+12>>2]|0;c[a+(d*3|0)>>2]=(f|b)-((f^b)>>>1&2139062143);i=e;return}function $ta(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;CEa(h,b,4,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;p=b+(m+o)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+28>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;DEa(j,k,4);k=c[h>>2]|0;p=c[j>>2]|0;c[a>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+4>>2]|0;p=c[j+4>>2]|0;c[a+e>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+8>>2]|0;p=c[j+8>>2]|0;c[a+l>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+12>>2]|0;h=c[j+12>>2]|0;c[a+(e*3|0)>>2]=(h|k)-((h^k)>>>1&2139062143);i=f;return}function aua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+40|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+24>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+32>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;DEa(a,h,e);i=f;return}function bua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+72|0;j=i;i=i+16|0;k=i;i=i+16|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;DEa(j,l,4);EEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+4>>2]|0;h=c[k+4>>2]|0;c[a+e>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+8>>2]|0;h=c[k+8>>2]|0;c[a+m>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+12>>2]|0;j=c[k+12>>2]|0;c[a+(e*3|0)>>2]=(j|b)-((j^b)>>>1&2139062143);i=f;return}function cua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+72|0;EEa(a,d|0,b,c,c);i=d;return}function dua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+40|0;g=f|0;h=i;i=i+72|0;j=i;i=i+16|0;k=i;i=i+16|0;l=g+8|0;m=e<<1;n=-m|1;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+m)|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;q=b+(n+p)|0;c[g+12>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=p+e|0;p=b+(q+n)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=q+e|0;q=b+(p+n)|0;c[g+20>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=p+e|0;p=b+(q+n)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=q+e|0;q=b+(p+n)|0;c[g+28>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=b+(o+p)|0;c[g+32>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;DEa(j,l,4);EEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+4>>2]|0;h=c[k+4>>2]|0;c[a+e>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+8>>2]|0;h=c[k+8>>2]|0;c[a+m>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+12>>2]|0;j=c[k+12>>2]|0;c[a+(e*3|0)>>2]=(j|b)-((j^b)>>>1&2139062143);i=f;return}function eua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=g+20|0;q=o+e|0;o=b+(q-k)|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=g+24|0;r=q+e|0;q=b+(r-k)|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=r+e|0;r=b+(q-k)|0;c[g+28>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;r=b+(l+q)|0;c[g+32>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;DEa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2139062143);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2139062143);j=c[p>>2]|0;p=c[h+8>>2]|0;c[a+k>>2]=(p|j)-((p^j)>>>1&2139062143);j=c[o>>2]|0;o=c[h+12>>2]|0;c[a+(e*3|0)>>2]=(o|j)-((o^j)>>>1&2139062143);i=f;return}function fua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;l=b+e|0;CEa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;DEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2139062143);k=c[h+4>>2]|0;o=c[j+4>>2]|0;c[a+e>>2]=(o|k)-((o^k)>>>1&2139062143);k=c[h+8>>2]|0;o=c[j+8>>2]|0;c[a+m>>2]=(o|k)-((o^k)>>>1&2139062143);k=c[h+12>>2]|0;h=c[j+12>>2]|0;c[a+(e*3|0)>>2]=(h|k)-((h^k)>>>1&2139062143);i=f;return}function gua(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+88|0;f=e+72|0;g=i;i=i+16|0;CEa(f,b+d|0,4,d);EEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+4>>2]|0;h=c[g+4>>2]|0;c[a+d>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+8>>2]|0;h=c[g+8>>2]|0;c[a+(d<<1)>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+12>>2]|0;f=c[g+12>>2]|0;c[a+(d*3|0)>>2]=(f|b)-((f^b)>>>1&2139062143);i=e;return}function hua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;CEa(h,b+e|0,4,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;p=b+(m+o)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+28>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;DEa(j,k,4);k=c[h>>2]|0;p=c[j>>2]|0;c[a>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+4>>2]|0;p=c[j+4>>2]|0;c[a+e>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+8>>2]|0;p=c[j+8>>2]|0;c[a+l>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+12>>2]|0;h=c[j+12>>2]|0;c[a+(e*3|0)>>2]=(h|k)-((h^k)>>>1&2139062143);i=f;return}function iua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0;f=c;b[a>>1]=(d[f]|d[f+1|0]<<8)<<16>>16;f=c+e|0;b[a+e>>1]=(d[f]|d[f+1|0]<<8)<<16>>16;return}function jua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;LEa(g,c,2,e);h=c;j=(d[h]|d[h+1|0]<<8)<<16>>16;h=b[g>>1]|0;b[a>>1]=(h|j)-(((h^j)&65535)>>>1&32639);j=c+e|0;c=(d[j]|d[j+1|0]<<8)<<16>>16;j=b[g+2>>1]|0;b[a+e>>1]=(j|c)-(((j^c)&65535)>>>1&32639);i=f;return}function kua(a,b,c){a=a|0;b=b|0;c=c|0;LEa(a,b,c,c);return}function lua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;LEa(g,c,2,e);h=c+1|0;j=(d[h]|d[h+1|0]<<8)<<16>>16;h=b[g>>1]|0;b[a>>1]=(h|j)-(((h^j)&65535)>>>1&32639);j=c+(e+1)|0;c=(d[j]|d[j+1|0]<<8)<<16>>16;j=b[g+2>>1]|0;b[a+e>>1]=(j|c)-(((j^c)&65535)>>>1&32639);i=f;return}function mua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=g+4|0;k=e<<1;l=c+(-k|0)|0;b[g>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=e-k|0;m=c+l|0;b[g+2>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=c;b[j>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=g+6|0;n=c+e|0;b[m>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=k+e+e|0;o=c+(n-k)|0;b[g+8>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=n+e|0;n=c+(o-k)|0;b[g+10>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=c+(l+o)|0;b[g+12>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;MEa(h,j,2);n=b[j>>1]|0;j=b[h>>1]|0;b[a>>1]=(j|n)-(((j^n)&65535)>>>1&32639);n=b[m>>1]|0;m=b[h+2>>1]|0;b[a+e>>1]=(m|n)-(((m^n)&65535)>>>1&32639);i=f;return}function nua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=g+4|0;LEa(h,c,2,e);l=e<<1;m=c+(-l|0)|0;b[g>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=e-l|0;n=c+m|0;b[g+2>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=c;b[k>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=c+e|0;b[g+6>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=l+e+e|0;o=c+(n-l)|0;b[g+8>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=n+e|0;n=c+(o-l)|0;b[g+10>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=c+(m+o)|0;b[g+12>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;MEa(j,k,2);k=b[h>>1]|0;n=b[j>>1]|0;b[a>>1]=(n|k)-(((n^k)&65535)>>>1&32639);k=b[h+2>>1]|0;h=b[j+2>>1]|0;b[a+e>>1]=(h|k)-(((h^k)&65535)>>>1&32639);i=f;return}function oua(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+40|0;f=e+32|0;g=i;i=i+4|0;i=i+7&-8;LEa(f,c,2,d);NEa(g,e|0,c,2,d);c=b[f>>1]|0;h=b[g>>1]|0;b[a>>1]=(h|c)-(((h^c)&65535)>>>1&32639);c=b[f+2>>1]|0;f=b[g+2>>1]|0;b[a+d>>1]=(f|c)-(((f^c)&65535)>>>1&32639);i=e;return}function pua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=g+4|0;LEa(h,c,2,e);l=e<<1;m=-l|1;n=c+m|0;b[g>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=m+e|0;o=c+n|0;b[g+2>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(m+l)|0;b[k>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l+e|0;l=c+(m+o)|0;b[g+6>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=o+e|0;o=c+(l+m)|0;b[g+8>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l+e|0;l=c+(o+m)|0;b[g+10>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c+(n+o)|0;b[g+12>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;MEa(j,k,2);k=b[h>>1]|0;l=b[j>>1]|0;b[a>>1]=(l|k)-(((l^k)&65535)>>>1&32639);k=b[h+2>>1]|0;h=b[j+2>>1]|0;b[a+e>>1]=(h|k)-(((h^k)&65535)>>>1&32639);i=f;return}function qua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;h=g+4|0;j=e<<1;k=c+(-j|0)|0;b[g>>1]=(d[k]|d[k+1|0]<<8)<<16>>16;k=e-j|0;l=c+k|0;b[g+2>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c;b[h>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c+e|0;b[g+6>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=j+e+e|0;m=c+(l-j)|0;b[g+8>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=l+e|0;l=c+(m-j)|0;b[g+10>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c+(k+m)|0;b[g+12>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;MEa(a,h,e);i=f;return}function rua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f|0;h=i;i=i+28|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=i;i=i+4|0;i=i+7&-8;l=g+4|0;m=e<<1;n=c+(-m|0)|0;b[g>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=e-m|0;o=c+n|0;b[g+2>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c;b[l>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+e|0;b[g+6>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=m+e+e|0;p=c+(o-m)|0;b[g+8>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=o+e|0;o=c+(p-m)|0;b[g+10>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(n+p)|0;b[g+12>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;MEa(j,l,2);NEa(k,h|0,c,2,e);c=b[j>>1]|0;h=b[k>>1]|0;b[a>>1]=(h|c)-(((h^c)&65535)>>>1&32639);c=b[j+2>>1]|0;j=b[k+2>>1]|0;b[a+e>>1]=(j|c)-(((j^c)&65535)>>>1&32639);i=f;return}function sua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+32|0;NEa(a,d|0,b,c,c);i=d;return}function tua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f|0;h=i;i=i+28|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=i;i=i+4|0;i=i+7&-8;l=g+4|0;m=e<<1;n=-m|1;o=c+n|0;b[g>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=n+e|0;p=c+o|0;b[g+2>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=c+(n+m)|0;b[l>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=m+e|0;m=c+(n+p)|0;b[g+6>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=p+e|0;p=c+(m+n)|0;b[g+8>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=m+e|0;m=c+(p+n)|0;b[g+10>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=c+(o+p)|0;b[g+12>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;MEa(j,l,2);NEa(k,h|0,c,2,e);c=b[j>>1]|0;h=b[k>>1]|0;b[a>>1]=(h|c)-(((h^c)&65535)>>>1&32639);c=b[j+2>>1]|0;j=b[k+2>>1]|0;b[a+e>>1]=(j|c)-(((j^c)&65535)>>>1&32639);i=f;return}function uua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=g+4|0;k=e<<1;l=c+(-k|0)|0;b[g>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=e-k|0;m=c+l|0;b[g+2>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=c;b[j>>1]=(d[m]|d[m+1|0]<<8)<<16>>16;m=g+6|0;n=c+e|0;b[m>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=g+8|0;o=k+e+e|0;p=c+(o-k)|0;b[n>>1]=(d[p]|d[p+1|0]<<8)<<16>>16;p=o+e|0;o=c+(p-k)|0;b[g+10>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(l+p)|0;b[g+12>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;MEa(h,j,2);j=b[m>>1]|0;m=b[h>>1]|0;b[a>>1]=(m|j)-(((m^j)&65535)>>>1&32639);j=b[n>>1]|0;n=b[h+2>>1]|0;b[a+e>>1]=(n|j)-(((n^j)&65535)>>>1&32639);i=f;return}function vua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=g+4|0;l=c+e|0;LEa(h,l,2,e);m=e<<1;n=c+(-m|0)|0;b[g>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=e-m|0;o=c+n|0;b[g+2>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c;b[k>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l;b[g+6>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=m+e+e|0;l=c+(o-m)|0;b[g+8>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=o+e|0;o=c+(l-m)|0;b[g+10>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(n+l)|0;b[g+12>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;MEa(j,k,2);k=b[h>>1]|0;o=b[j>>1]|0;b[a>>1]=(o|k)-(((o^k)&65535)>>>1&32639);k=b[h+2>>1]|0;h=b[j+2>>1]|0;b[a+e>>1]=(h|k)-(((h^k)&65535)>>>1&32639);i=f;return}function wua(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+40|0;f=e+32|0;g=i;i=i+4|0;i=i+7&-8;LEa(f,c+d|0,2,d);NEa(g,e|0,c,2,d);c=b[f>>1]|0;h=b[g>>1]|0;b[a>>1]=(h|c)-(((h^c)&65535)>>>1&32639);c=b[f+2>>1]|0;f=b[g+2>>1]|0;b[a+d>>1]=(f|c)-(((f^c)&65535)>>>1&32639);i=e;return}function xua(a,c,e){a=a|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=g+4|0;LEa(h,c+e|0,2,e);l=e<<1;m=-l|1;n=c+m|0;b[g>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=m+e|0;o=c+n|0;b[g+2>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=c+(m+l)|0;b[k>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l+e|0;l=c+(m+o)|0;b[g+6>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=o+e|0;o=c+(l+m)|0;b[g+8>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;o=l+e|0;l=c+(o+m)|0;b[g+10>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;l=c+(n+o)|0;b[g+12>>1]=(d[l]|d[l+1|0]<<8)<<16>>16;MEa(j,k,2);k=b[h>>1]|0;l=b[j>>1]|0;b[a>>1]=(l|k)-(((l^k)&65535)>>>1&32639);k=b[h+2>>1]|0;h=b[j+2>>1]|0;b[a+e>>1]=(h|k)-(((h^k)&65535)>>>1&32639);i=f;return}function yua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=f;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[i>>2]=(l|j)-((l^j)>>>1&2139062143);j=g+4|0;l=c[j>>2]|0;i=f+4|0;k=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[j>>2]=(k|l)-((k^l)>>>1&2139062143);l=h+1|0;if((l|0)<16){f=f+e|0;g=g+e|0;h=l}else{break}}h=b+8|0;b=a+8|0;a=0;while(1){g=b;f=c[g>>2]|0;l=h;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;c[g>>2]=(k|f)-((k^f)>>>1&2139062143);f=b+4|0;k=c[f>>2]|0;g=h+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[f>>2]=(l|k)-((l^k)>>>1&2139062143);k=a+1|0;if((k|0)<16){h=h+e|0;b=b+e|0;a=k}else{break}}return}function zua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;FEa(g|0,b,16,e);FEa(g+8|0,b+8|0,16,e);h=e<<3;FEa(g+128|0,b+h|0,16,e);FEa(g+136|0,b+(h+8)|0,16,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=j+4|0;j=b+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+o|0;o=c[j>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[j>>2]=(m|o)-((m^o)>>>1&2139062143);o=h+1|0;if((o|0)<16){h=o}else{q=0;break}}do{h=ca(q,e)|0;o=h+8|0;m=b+o|0;j=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q<<4;p=g+(m|8)|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+o|0;o=c[p>>2]|0;l=(k|j)-((k^j)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=h+12|0;h=b+o|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+(m|12)|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+o|0;o=c[h>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[h>>2]=(p|o)-((p^o)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function Aua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;KEa(a,b,c,c);KEa(a+8|0,b+8|0,c,c);d=c<<3;KEa(a+d|0,b+d|0,c,c);e=d+8|0;KEa(a+e|0,b+e|0,c,c);return}function Bua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;FEa(g|0,b,16,e);FEa(g+8|0,b+8|0,16,e);h=e<<3;FEa(g+128|0,b+h|0,16,e);FEa(g+136|0,b+(h+8)|0,16,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<4;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=b+(j+5)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+(k|4)|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(j+4)|0;j=c[o>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[o>>2]=(m|j)-((m^j)>>>1&2139062143);j=h+1|0;if((j|0)<16){h=j}else{q=0;break}}do{h=ca(q,e)|0;j=b+(h+9)|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=q<<4;o=g+(j|8)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(h+8)|0;k=c[o>>2]|0;l=(p|m)-((p^m)>>>1&2139062143)|0;c[o>>2]=(l|k)-((l^k)>>>1&2139062143);k=b+(h+13)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+(j|12)|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=a+(h+12)|0;h=c[k>>2]|0;o=(j|l)-((j^l)>>>1&2139062143)|0;c[k>>2]=(o|h)-((o^h)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function Cua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+592|0;h=g|0;j=g+336|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=e;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+4|0;m=e+4|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+8|0;n=e+8|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+12|0;m=e+12|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=l+1|0;if((m|0)<21){k=k+f|0;e=e+16|0;l=m}else{break}}GEa(j|0,h+32|0,16,16);GEa(j+8|0,h+40|0,16,16);GEa(j+128|0,h+160|0,16,16);GEa(j+136|0,h+168|0,16,16);l=0;while(1){e=l<<4;k=h+(e+32)|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+e|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(l,f)|0;o=b+k|0;p=c[o>>2]|0;q=(n|m)-((n^m)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=e|4;e=h+(p+32)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(k+4)|0;k=c[e>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[e>>2]=(o|k)-((o^k)>>>1&2139062143);k=l+1|0;if((k|0)<16){l=k}else{r=0;break}}do{l=r<<4;k=h+(l+40)|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+(l|8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(r,f)|0;q=b+(k+8)|0;p=c[q>>2]|0;m=(e|o)-((e^o)>>>1&2139062143)|0;c[q>>2]=(m|p)-((m^p)>>>1&2139062143);p=h+((l|4)+40)|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+(l|12)|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(k+12)|0;k=c[p>>2]|0;q=(l|m)-((l^m)>>>1&2139062143)|0;c[p>>2]=(q|k)-((q^k)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Dua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;FEa(j|0,e,16,f);FEa(j+8|0,e+8|0,16,f);l=f<<3;FEa(j+128|0,e+l|0,16,f);FEa(j+136|0,e+(l+8)|0,16,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=e;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+4|0;n=e+4|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+8|0;o=e+8|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+12|0;n=e+12|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+1|0;if((n|0)<21){l=l+f|0;e=e+16|0;m=n}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=0;while(1){m=h<<4;e=j+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(h,f)|0;o=b+e|0;p=c[o>>2]|0;q=(n|l)-((n^l)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=m|4;m=j+p|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(e+4)|0;e=c[m>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[m>>2]=(o|e)-((o^e)>>>1&2139062143);e=h+1|0;if((e|0)<16){h=e}else{r=0;break}}do{h=r<<4;e=h|8;o=j+e|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+e|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(r,f)|0;q=b+(o+8)|0;p=c[q>>2]|0;l=(e|m)-((e^m)>>>1&2139062143)|0;c[q>>2]=(l|p)-((l^p)>>>1&2139062143);p=h|12;h=j+p|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(o+12)|0;o=c[h>>2]|0;q=(p|l)-((p^l)>>>1&2139062143)|0;c[h>>2]=(q|o)-((q^o)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Eua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+1184|0;g=f|0;h=f+672|0;j=f+928|0;FEa(h|0,b,16,e);k=b+8|0;FEa(h+8|0,k,16,e);l=e<<3;m=b+l|0;FEa(h+128|0,m,16,e);n=b+(l+8)|0;FEa(h+136|0,n,16,e);l=g|0;HEa(j|0,l,b,16,16,e);b=g+16|0;HEa(j+8|0,b,k,16,16,e);HEa(j+128|0,l,m,16,16,e);HEa(j+136|0,b,n,16,16,e);n=0;while(1){b=n<<4;m=h+b|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+b|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(n,e)|0;g=a+m|0;o=c[g>>2]|0;p=(k|l)-((k^l)>>>1&2139062143)|0;c[g>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=h+o|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(m+4)|0;m=c[b>>2]|0;g=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(g|m)-((g^m)>>>1&2139062143);m=n+1|0;if((m|0)<16){n=m}else{q=0;break}}do{n=q<<4;m=n|8;g=h+m|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(q,e)|0;p=a+(g+8)|0;o=c[p>>2]|0;l=(m|b)-((m^b)>>>1&2139062143)|0;c[p>>2]=(l|o)-((l^o)>>>1&2139062143);o=n|12;n=h+o|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+o|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(g+12)|0;g=c[n>>2]|0;p=(o|l)-((o^l)>>>1&2139062143)|0;c[n>>2]=(p|g)-((p^g)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function Fua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;FEa(j|0,e,16,f);FEa(j+8|0,e+8|0,16,f);l=f<<3;FEa(j+128|0,e+l|0,16,f);FEa(j+136|0,e+(l+8)|0,16,f);l=e+(-(f<<1)|1)|0;e=h|0;m=0;while(1){n=l;o=e;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+4|0;n=e+4|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+8|0;o=e+8|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+12|0;n=e+12|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+1|0;if((n|0)<21){l=l+f|0;e=e+16|0;m=n}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=0;while(1){m=h<<4;e=j+m|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+m|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(h,f)|0;o=b+e|0;p=c[o>>2]|0;q=(n|l)-((n^l)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=m|4;m=j+p|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=b+(e+4)|0;e=c[m>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[m>>2]=(o|e)-((o^e)>>>1&2139062143);e=h+1|0;if((e|0)<16){h=e}else{r=0;break}}do{h=r<<4;e=h|8;o=j+e|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+e|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(r,f)|0;q=b+(o+8)|0;p=c[q>>2]|0;l=(e|m)-((e^m)>>>1&2139062143)|0;c[q>>2]=(l|p)-((l^p)>>>1&2139062143);p=h|12;h=j+p|0;l=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(o+12)|0;o=c[h>>2]|0;q=(p|l)-((p^l)>>>1&2139062143)|0;c[h>>2]=(q|o)-((q^o)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Gua(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+336|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=c;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+4|0;k=c+4|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+8|0;l=c+8|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+12|0;k=c+12|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+1|0;if((k|0)<21){h=h+e|0;c=c+16|0;j=k}else{break}}JEa(b,g+32|0,e,16);JEa(b+8|0,g+40|0,e,16);j=e<<3;JEa(b+j|0,g+160|0,e,16);JEa(b+(j+8)|0,g+168|0,e,16);i=f;return}function Hua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1520|0;h=g|0;j=g+336|0;k=g+1008|0;l=g+1264|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=n;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+4|0;p=n+4|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+8|0;q=n+8|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+12|0;p=n+12|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+1|0;if((p|0)<21){m=m+f|0;n=n+16|0;o=p}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=j|0;HEa(l|0,h,e,16,16,f);o=j+16|0;HEa(l+8|0,o,e+8|0,16,16,f);j=f<<3;HEa(l+128|0,h,e+j|0,16,16,f);HEa(l+136|0,o,e+(j+8)|0,16,16,f);j=0;while(1){e=j<<4;o=k+e|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+e|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(j,f)|0;m=b+o|0;p=c[m>>2]|0;q=(n|h)-((n^h)>>>1&2139062143)|0;c[m>>2]=(q|p)-((q^p)>>>1&2139062143);p=e|4;e=k+p|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(o+4)|0;o=c[e>>2]|0;m=(p|q)-((p^q)>>>1&2139062143)|0;c[e>>2]=(m|o)-((m^o)>>>1&2139062143);o=j+1|0;if((o|0)<16){j=o}else{r=0;break}}do{j=r<<4;o=j|8;m=k+o|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+o|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(r,f)|0;q=b+(m+8)|0;p=c[q>>2]|0;h=(o|e)-((o^e)>>>1&2139062143)|0;c[q>>2]=(h|p)-((h^p)>>>1&2139062143);p=j|12;j=k+p|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+p|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(m+12)|0;m=c[j>>2]|0;q=(p|h)-((p^h)>>>1&2139062143)|0;c[j>>2]=(q|m)-((q^m)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Iua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+672|0;e=d|0;f=e|0;IEa(a,f,b,c,16,c);g=e+16|0;IEa(a+8|0,g,b+8|0,c,16,c);e=c<<3;IEa(a+e|0,f,b+e|0,c,16,c);f=e+8|0;IEa(a+f|0,g,b+f|0,c,16,c);i=d;return}function Jua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1520|0;h=g|0;j=g+336|0;k=g+1008|0;l=g+1264|0;m=e+(-(f<<1)|1)|0;n=h|0;o=0;while(1){p=m;q=n;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+4|0;p=n+4|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+8|0;q=n+8|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+12|0;p=n+12|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+1|0;if((p|0)<21){m=m+f|0;n=n+16|0;o=p}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=j|0;HEa(l|0,h,e,16,16,f);o=j+16|0;HEa(l+8|0,o,e+8|0,16,16,f);j=f<<3;HEa(l+128|0,h,e+j|0,16,16,f);HEa(l+136|0,o,e+(j+8)|0,16,16,f);j=0;while(1){e=j<<4;o=k+e|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+e|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(j,f)|0;m=b+o|0;p=c[m>>2]|0;q=(n|h)-((n^h)>>>1&2139062143)|0;c[m>>2]=(q|p)-((q^p)>>>1&2139062143);p=e|4;e=k+p|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(o+4)|0;o=c[e>>2]|0;m=(p|q)-((p^q)>>>1&2139062143)|0;c[e>>2]=(m|o)-((m^o)>>>1&2139062143);o=j+1|0;if((o|0)<16){j=o}else{r=0;break}}do{j=r<<4;o=j|8;m=k+o|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+o|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(r,f)|0;q=b+(m+8)|0;p=c[q>>2]|0;h=(o|e)-((o^e)>>>1&2139062143)|0;c[q>>2]=(h|p)-((h^p)>>>1&2139062143);p=j|12;j=k+p|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=l+p|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(m+12)|0;m=c[j>>2]|0;q=(p|h)-((p^h)>>>1&2139062143)|0;c[j>>2]=(q|m)-((q^m)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Kua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+592|0;h=g|0;j=g+336|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=e;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+4|0;m=e+4|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+8|0;n=e+8|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+12|0;m=e+12|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=l+1|0;if((m|0)<21){k=k+f|0;e=e+16|0;l=m}else{break}}GEa(j|0,h+32|0,16,16);GEa(j+8|0,h+40|0,16,16);GEa(j+128|0,h+160|0,16,16);GEa(j+136|0,h+168|0,16,16);l=0;while(1){e=l<<4;k=h+(e+48)|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+e|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(l,f)|0;o=b+k|0;p=c[o>>2]|0;q=(n|m)-((n^m)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=e|4;e=h+(p+48)|0;q=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+p|0;p=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=b+(k+4)|0;k=c[e>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[e>>2]=(o|k)-((o^k)>>>1&2139062143);k=l+1|0;if((k|0)<16){l=k}else{r=0;break}}do{l=r<<4;k=h+(l+56)|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+(l|8)|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(r,f)|0;q=b+(k+8)|0;p=c[q>>2]|0;m=(e|o)-((e^o)>>>1&2139062143)|0;c[q>>2]=(m|p)-((m^p)>>>1&2139062143);p=h+((l|4)+56)|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+(l|12)|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(k+12)|0;k=c[p>>2]|0;q=(l|m)-((l^m)>>>1&2139062143)|0;c[p>>2]=(q|k)-((q^k)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Lua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;FEa(j|0,e+f|0,16,f);l=f+8|0;FEa(j+8|0,e+l|0,16,f);m=f<<3;FEa(j+128|0,e+(m+f)|0,16,f);FEa(j+136|0,e+(l+m)|0,16,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=e;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+4|0;n=e+4|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+8|0;o=e+8|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+12|0;n=e+12|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+1|0;if((n|0)<21){m=m+f|0;e=e+16|0;l=n}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=0;while(1){l=h<<4;e=j+l|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+l|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(h,f)|0;o=b+e|0;p=c[o>>2]|0;q=(n|m)-((n^m)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=l|4;l=j+p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(e+4)|0;e=c[l>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[l>>2]=(o|e)-((o^e)>>>1&2139062143);e=h+1|0;if((e|0)<16){h=e}else{r=0;break}}do{h=r<<4;e=h|8;o=j+e|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+e|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(r,f)|0;q=b+(o+8)|0;p=c[q>>2]|0;m=(e|l)-((e^l)>>>1&2139062143)|0;c[q>>2]=(m|p)-((m^p)>>>1&2139062143);p=h|12;h=j+p|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(o+12)|0;o=c[h>>2]|0;q=(p|m)-((p^m)>>>1&2139062143)|0;c[h>>2]=(q|o)-((q^o)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Mua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+1184|0;g=f|0;h=f+672|0;j=f+928|0;FEa(h|0,b+e|0,16,e);FEa(h+8|0,b+(e+8)|0,16,e);k=e<<3;FEa(h+128|0,b+(k+e)|0,16,e);l=k+8|0;FEa(h+136|0,b+(l+e)|0,16,e);m=g|0;HEa(j|0,m,b,16,16,e);n=g+16|0;HEa(j+8|0,n,b+8|0,16,16,e);HEa(j+128|0,m,b+k|0,16,16,e);HEa(j+136|0,n,b+l|0,16,16,e);l=0;while(1){b=l<<4;n=h+b|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+b|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(l,e)|0;g=a+n|0;o=c[g>>2]|0;p=(m|k)-((m^k)>>>1&2139062143)|0;c[g>>2]=(p|o)-((p^o)>>>1&2139062143);o=b|4;b=h+o|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(n+4)|0;n=c[b>>2]|0;g=(o|p)-((o^p)>>>1&2139062143)|0;c[b>>2]=(g|n)-((g^n)>>>1&2139062143);n=l+1|0;if((n|0)<16){l=n}else{q=0;break}}do{l=q<<4;n=l|8;g=h+n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+n|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(q,e)|0;p=a+(g+8)|0;o=c[p>>2]|0;k=(n|b)-((n^b)>>>1&2139062143)|0;c[p>>2]=(k|o)-((k^o)>>>1&2139062143);o=l|12;l=h+o|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+o|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(g+12)|0;g=c[l>>2]|0;p=(o|k)-((o^k)>>>1&2139062143)|0;c[l>>2]=(p|g)-((p^g)>>>1&2139062143);q=q+1|0;}while((q|0)<16);i=f;return}function Nua(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+848|0;h=g|0;j=g+336|0;k=g+592|0;FEa(j|0,e+f|0,16,f);l=f+8|0;FEa(j+8|0,e+l|0,16,f);m=f<<3;FEa(j+128|0,e+(m+f)|0,16,f);FEa(j+136|0,e+(l+m)|0,16,f);m=e+(-(f<<1)|1)|0;e=h|0;l=0;while(1){n=m;o=e;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+4|0;n=e+4|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+8|0;o=e+8|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+12|0;n=e+12|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+1|0;if((n|0)<21){m=m+f|0;e=e+16|0;l=n}else{break}}GEa(k|0,h+32|0,16,16);GEa(k+8|0,h+40|0,16,16);GEa(k+128|0,h+160|0,16,16);GEa(k+136|0,h+168|0,16,16);h=0;while(1){l=h<<4;e=j+l|0;m=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=k+l|0;n=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=ca(h,f)|0;o=b+e|0;p=c[o>>2]|0;q=(n|m)-((n^m)>>>1&2139062143)|0;c[o>>2]=(q|p)-((q^p)>>>1&2139062143);p=l|4;l=j+p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(e+4)|0;e=c[l>>2]|0;o=(p|q)-((p^q)>>>1&2139062143)|0;c[l>>2]=(o|e)-((o^e)>>>1&2139062143);e=h+1|0;if((e|0)<16){h=e}else{r=0;break}}do{h=r<<4;e=h|8;o=j+e|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+e|0;e=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(r,f)|0;q=b+(o+8)|0;p=c[q>>2]|0;m=(e|l)-((e^l)>>>1&2139062143)|0;c[q>>2]=(m|p)-((m^p)>>>1&2139062143);p=h|12;h=j+p|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+p|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=b+(o+12)|0;o=c[h>>2]|0;q=(p|m)-((p^m)>>>1&2139062143)|0;c[h>>2]=(q|o)-((q^o)>>>1&2139062143);r=r+1|0;}while((r|0)<16);i=g;return}function Oua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=f;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[g>>2]=(j|h)-((j^h)>>>1&2139062143);h=b+4|0;j=c[h>>2]|0;g=f+4|0;i=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;c[h>>2]=(i|j)-((i^j)>>>1&2139062143);j=a+1|0;if((j|0)<8){f=f+e|0;b=b+e|0;a=j}else{break}}return}function Pua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;FEa(g|0,b,8,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=j+4|0;j=b+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+(k|4)|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+o|0;o=c[j>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[j>>2]=(m|o)-((m^o)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function Qua(a,b,c){a=a|0;b=b|0;c=c|0;KEa(a,b,c,c);return}function Rua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+64|0;g=f|0;FEa(g|0,b,8,e);h=0;do{j=ca(h,e)|0;k=b+(j+1)|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h<<3;m=g+k|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+j|0;o=c[m>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[m>>2]=(p|o)-((p^o)>>>1&2139062143);o=b+(j+5)|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+(k|4)|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(j+4)|0;j=c[o>>2]|0;m=(k|p)-((k^p)>>>1&2139062143)|0;c[o>>2]=(m|j)-((m^j)>>>1&2139062143);h=h+1|0;}while((h|0)<8);i=f;return}function Sua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=g+16|0;k=j;l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=4-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e-l)|0;c[g+8>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4-l)|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[j>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+4|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;j=b+(n-l)|0;c[g+32>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+36>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+48>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+52>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+64>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+68>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+80>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+84>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=n+e|0;n=b+(j-l)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+j)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=j+e|0;j=b+(n-l)|0;c[g+96>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=b+(m+n)|0;c[g+100>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;GEa(h|0,k,8,8);j=0;do{g=j<<3;n=c[k+g>>2]|0;m=h+g|0;b=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,e)|0;l=a+m|0;o=c[l>>2]|0;p=(b|n)-((b^n)>>>1&2139062143)|0;c[l>>2]=(p|o)-((p^o)>>>1&2139062143);o=g|4;g=c[k+o>>2]|0;p=h+o|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(m+4)|0;m=c[p>>2]|0;l=(o|g)-((o^g)>>>1&2139062143)|0;c[p>>2]=(l|m)-((l^m)>>>1&2139062143);j=j+1|0;}while((j|0)<8);i=f;return}function Tua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;FEa(h|0,b,8,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=4-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e-l)|0;c[g+8>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4-l)|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+4|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+n)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;GEa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(k,e)|0;b=a+g|0;l=c[b>>2]|0;p=(m|n)-((m^n)>>>1&2139062143)|0;c[b>>2]=(p|l)-((p^l)>>>1&2139062143);l=o|4;o=h+l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+l|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(g+4)|0;g=c[o>>2]|0;b=(l|p)-((l^p)>>>1&2139062143)|0;c[o>>2]=(b|g)-((b^g)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function Uua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+336|0;g=f+208|0;h=f+272|0;FEa(g|0,b,8,e);HEa(h|0,f|0,b,8,8,e);b=0;do{j=b<<3;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(b,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=j|4;j=g+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+(k+4)|0;k=c[j>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[j>>2]=(n|k)-((n^k)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Vua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;FEa(h|0,b,8,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+4|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+e)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4+m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+4+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(m+o)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(o+4+m)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;GEa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(k,e)|0;b=a+g|0;m=c[b>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[b>>2]=(p|m)-((p^m)>>>1&2139062143);m=o|4;o=h+m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(g+4)|0;g=c[o>>2]|0;b=(m|p)-((m^p)>>>1&2139062143)|0;c[o>>2]=(b|g)-((b^g)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function Wua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+104|0;g=f|0;h=g+16|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=4-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e-j)|0;c[g+8>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e+4-j)|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+4|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(e+4)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+32>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+36>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+48>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+52>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+64>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+68>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+80>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+84>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=m+e|0;m=b+(l-j)|0;c[g+96>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(k+l)|0;c[g+100>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;JEa(a,h,e,8);i=f;return}function Xua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+208|0;j=i;i=i+64|0;k=i;i=i+64|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=4-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e-m)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4-m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+4|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+36>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+40>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+44>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+48>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+52>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+56>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+60>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+64>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+68>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+76>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+80>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+84>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+88>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+92>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+96>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+100>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;GEa(j|0,l,8,8);HEa(k|0,h|0,b,8,8,e);b=0;do{h=b<<3;l=j+h|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+h|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(b,e)|0;o=a+l|0;n=c[o>>2]|0;m=(g|p)-((g^p)>>>1&2139062143)|0;c[o>>2]=(m|n)-((m^n)>>>1&2139062143);n=h|4;h=j+n|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(l+4)|0;l=c[h>>2]|0;o=(n|m)-((n^m)>>>1&2139062143)|0;c[h>>2]=(o|l)-((o^l)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function Yua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+208|0;IEa(a,d|0,b,c,8,c);i=d;return}function Zua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+208|0;j=i;i=i+64|0;k=i;i=i+64|0;l=g+16|0;m=e<<1;n=-m|1;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+4|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+e)|0;c[g+8>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+4+n)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+m)|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(m+4+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(n+p)|0;c[g+24>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(p+4+n)|0;c[g+28>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+36>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+40>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+44>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+48>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+52>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+56>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+60>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+64>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+68>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+72>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+76>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+80>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+84>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;m=b+(p+n)|0;c[g+88>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(o+p)|0;c[g+92>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+96>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+100>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;GEa(j|0,l,8,8);HEa(k|0,h|0,b,8,8,e);b=0;do{h=b<<3;l=j+h|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+h|0;g=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=ca(b,e)|0;m=a+l|0;o=c[m>>2]|0;n=(g|p)-((g^p)>>>1&2139062143)|0;c[m>>2]=(n|o)-((n^o)>>>1&2139062143);o=h|4;h=j+o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+o|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(l+4)|0;l=c[h>>2]|0;m=(o|n)-((o^n)>>>1&2139062143)|0;c[h>>2]=(m|l)-((m^l)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function _ua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=4-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(e-k)|0;c[g+8>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+(e+4-k)|0;c[g+12>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b+4|0;c[g+20>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+24|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(e+4)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+40>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+44>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+56>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+60>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+72>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+76>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+88>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+92>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-k)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+n)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;GEa(h|0,j,8,8);j=m;m=0;do{o=m<<3;g=c[j+o>>2]|0;n=h+o|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(m,e)|0;b=a+n|0;k=c[b>>2]|0;p=(l|g)-((l^g)>>>1&2139062143)|0;c[b>>2]=(p|k)-((p^k)>>>1&2139062143);k=o|4;o=c[j+k>>2]|0;p=h+k|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+4)|0;n=c[p>>2]|0;b=(k|o)-((k^o)>>>1&2139062143)|0;c[p>>2]=(b|n)-((b^n)>>>1&2139062143);m=m+1|0;}while((m|0)<8);i=f;return}function $ua(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;l=b+e|0;FEa(h|0,l,8,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=4-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e-m)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4-m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+4|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+32>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+36>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+40>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+44>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+48>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+52>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+56>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+60>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+64>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+68>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+72>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+76>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+80>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+84>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+88>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+92>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+96>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+100>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;GEa(j|0,k,8,8);k=0;do{l=k<<3;g=h+l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+l|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(k,e)|0;b=a+g|0;m=c[b>>2]|0;p=(n|o)-((n^o)>>>1&2139062143)|0;c[b>>2]=(p|m)-((p^m)>>>1&2139062143);m=l|4;l=h+m|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+m|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(g+4)|0;g=c[l>>2]|0;b=(m|p)-((m^p)>>>1&2139062143)|0;c[l>>2]=(b|g)-((b^g)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function ava(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+336|0;g=f+208|0;h=f+272|0;FEa(g|0,b+e|0,8,e);HEa(h|0,f|0,b,8,8,e);b=0;do{j=b<<3;k=g+j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+j|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=ca(b,e)|0;n=a+k|0;o=c[n>>2]|0;p=(m|l)-((m^l)>>>1&2139062143)|0;c[n>>2]=(p|o)-((p^o)>>>1&2139062143);o=j|4;j=g+o|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+o|0;o=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+(k+4)|0;k=c[j>>2]|0;n=(o|p)-((o^p)>>>1&2139062143)|0;c[j>>2]=(n|k)-((n^k)>>>1&2139062143);b=b+1|0;}while((b|0)<8);i=f;return}function bva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+104|0;g=f|0;h=i;i=i+64|0;j=i;i=i+64|0;k=g+16|0;FEa(h|0,b+e|0,8,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+4|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+e)|0;c[g+8>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+4+m)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+4+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(m+o)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(o+4+m)|0;c[g+28>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+36>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+40>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+44>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+48>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+52>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+56>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+60>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+64>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+68>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+72>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+76>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+80>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+84>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o+m)|0;c[g+88>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(n+o)|0;c[g+92>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+96>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+100>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;GEa(j|0,k,8,8);k=0;do{o=k<<3;g=h+o|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+o|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(k,e)|0;b=a+g|0;m=c[b>>2]|0;p=(n|l)-((n^l)>>>1&2139062143)|0;c[b>>2]=(p|m)-((p^m)>>>1&2139062143);m=o|4;o=h+m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+(g+4)|0;g=c[o>>2]|0;b=(m|p)-((m^p)>>>1&2139062143)|0;c[o>>2]=(b|g)-((b^g)>>>1&2139062143);k=k+1|0;}while((k|0)<8);i=f;return}function cva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a;g=c[f>>2]|0;h=b;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[f>>2]=(i|g)-((i^g)>>>1&2139062143);g=a+e|0;i=c[g>>2]|0;f=b+e|0;h=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[g>>2]=(h|i)-((h^i)>>>1&2139062143);i=e<<1;h=a+i|0;g=c[h>>2]|0;f=b+i|0;j=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;c[h>>2]=(j|g)-((j^g)>>>1&2139062143);g=i+e|0;e=a+g|0;a=c[e>>2]|0;i=b+g|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[e>>2]=(g|a)-((g^a)>>>1&2139062143);return}function dva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;CEa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;k=a;l=c[k>>2]|0;m=(h|j)-((h^j)>>>1&2139062143)|0;c[k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b+e|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=c[g+4>>2]|0;k=a+e|0;j=c[k>>2]|0;h=(l|m)-((l^m)>>>1&2139062143)|0;c[k>>2]=(h|j)-((h^j)>>>1&2139062143);j=e<<1;h=b+j|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g+8>>2]|0;m=a+j|0;j=c[m>>2]|0;l=(h|k)-((h^k)>>>1&2139062143)|0;c[m>>2]=(l|j)-((l^j)>>>1&2139062143);j=e*3|0;e=b+j|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=c[g+12>>2]|0;g=a+j|0;j=c[g>>2]|0;a=(e|b)-((e^b)>>>1&2139062143)|0;c[g>>2]=(a|j)-((a^j)>>>1&2139062143);i=f;return}function eva(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=0;g=b;b=c;while(1){c=b+1|0;h=b-1|0;i=b+2|0;j=b+3|0;k=(((d[c]|0)+(d[b]|0)|0)*20|0)+16+(d[b-2|0]|0)+(((d[i]|0)+(d[h]|0)|0)*-5|0)+(d[j]|0)>>5;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[g]=((d[g]|0)+1+(l&255)|0)>>>1;k=g+1|0;m=b+4|0;n=(((d[i]|0)+(d[c]|0)|0)*20|0)+16+(d[h]|0)+(((d[j]|0)+(d[b]|0)|0)*-5|0)+(d[m]|0)>>5;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[k]=((d[k]|0)+1+(o&255)|0)>>>1;k=g+2|0;n=b+5|0;h=(((d[j]|0)+(d[i]|0)|0)*20|0)+16+(d[b]|0)+(((d[m]|0)+(d[c]|0)|0)*-5|0)+(d[n]|0)>>5;if(h>>>0>255>>>0){p=-h>>31&255}else{p=h&255}a[k]=((d[k]|0)+1+(p&255)|0)>>>1;k=g+3|0;h=(((d[m]|0)+(d[j]|0)|0)*20|0)+16+(d[c]|0)+(((d[n]|0)+(d[i]|0)|0)*-5|0)+(d[b+6|0]|0)>>5;if(h>>>0>255>>>0){q=-h>>31&255}else{q=h&255}a[k]=((d[k]|0)+1+(q&255)|0)>>>1;k=f+1|0;if((k|0)<4){f=k;g=g+e|0;b=b+e|0}else{break}}return}function fva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;CEa(g,b,4,e);h=b+1|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;k=a;l=c[k>>2]|0;m=(h|j)-((h^j)>>>1&2139062143)|0;c[k>>2]=(m|l)-((m^l)>>>1&2139062143);l=b+(e+1)|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=c[g+4>>2]|0;k=a+e|0;j=c[k>>2]|0;h=(l|m)-((l^m)>>>1&2139062143)|0;c[k>>2]=(h|j)-((h^j)>>>1&2139062143);j=e<<1;h=b+(j|1)|0;k=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g+8>>2]|0;m=a+j|0;j=c[m>>2]|0;l=(h|k)-((h^k)>>>1&2139062143)|0;c[m>>2]=(l|j)-((l^j)>>>1&2139062143);j=e*3|0;e=b+(j+1)|0;b=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=c[g+12>>2]|0;g=a+j|0;j=c[g>>2]|0;a=(e|b)-((e^b)>>>1&2139062143)|0;c[g>>2]=(a|j)-((a^j)>>>1&2139062143);i=f;return}function gva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=g+20|0;q=o+e|0;o=b+(q-k)|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=q+e|0;q=b+(o-k)|0;c[g+24>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=o+e|0;o=b+(q-k)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+q)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;DEa(h,j,4);o=c[j>>2]|0;j=c[h>>2]|0;g=a;q=c[g>>2]|0;l=(j|o)-((j^o)>>>1&2139062143)|0;c[g>>2]=(l|q)-((l^q)>>>1&2139062143);q=c[m>>2]|0;m=c[h+4>>2]|0;l=a+e|0;g=c[l>>2]|0;o=(m|q)-((m^q)>>>1&2139062143)|0;c[l>>2]=(o|g)-((o^g)>>>1&2139062143);g=c[n>>2]|0;n=c[h+8>>2]|0;o=a+k|0;k=c[o>>2]|0;l=(n|g)-((n^g)>>>1&2139062143)|0;c[o>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[p>>2]|0;p=c[h+12>>2]|0;h=a+(e*3|0)|0;e=c[h>>2]|0;a=(p|k)-((p^k)>>>1&2139062143)|0;c[h>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function hva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;CEa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=o+e|0;o=b+(n-l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+28>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+32>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;DEa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;g=a;o=c[g>>2]|0;m=(n|k)-((n^k)>>>1&2139062143)|0;c[g>>2]=(m|o)-((m^o)>>>1&2139062143);o=c[h+4>>2]|0;m=c[j+4>>2]|0;g=a+e|0;k=c[g>>2]|0;n=(m|o)-((m^o)>>>1&2139062143)|0;c[g>>2]=(n|k)-((n^k)>>>1&2139062143);k=c[h+8>>2]|0;n=c[j+8>>2]|0;g=a+l|0;l=c[g>>2]|0;o=(n|k)-((n^k)>>>1&2139062143)|0;c[g>>2]=(o|l)-((o^l)>>>1&2139062143);l=c[h+12>>2]|0;h=c[j+12>>2]|0;j=a+(e*3|0)|0;e=c[j>>2]|0;a=(h|l)-((h^l)>>>1&2139062143)|0;c[j>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function iva(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+88|0;f=e+72|0;g=i;i=i+16|0;CEa(f,b,4,d);EEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;j=a;k=c[j>>2]|0;l=(h|b)-((h^b)>>>1&2139062143)|0;c[j>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[f+4>>2]|0;l=c[g+4>>2]|0;j=a+d|0;b=c[j>>2]|0;h=(l|k)-((l^k)>>>1&2139062143)|0;c[j>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+8>>2]|0;h=c[g+8>>2]|0;j=a+(d<<1)|0;k=c[j>>2]|0;l=(h|b)-((h^b)>>>1&2139062143)|0;c[j>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[f+12>>2]|0;f=c[g+12>>2]|0;g=a+(d*3|0)|0;d=c[g>>2]|0;a=(f|k)-((f^k)>>>1&2139062143)|0;c[g>>2]=(a|d)-((a^d)>>>1&2139062143);i=e;return}function jva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;CEa(h,b,4,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;p=b+(m+o)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+28>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;DEa(j,k,4);k=c[h>>2]|0;p=c[j>>2]|0;g=a;o=c[g>>2]|0;n=(p|k)-((p^k)>>>1&2139062143)|0;c[g>>2]=(n|o)-((n^o)>>>1&2139062143);o=c[h+4>>2]|0;n=c[j+4>>2]|0;g=a+e|0;k=c[g>>2]|0;p=(n|o)-((n^o)>>>1&2139062143)|0;c[g>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+8>>2]|0;p=c[j+8>>2]|0;g=a+l|0;l=c[g>>2]|0;o=(p|k)-((p^k)>>>1&2139062143)|0;c[g>>2]=(o|l)-((o^l)>>>1&2139062143);l=c[h+12>>2]|0;h=c[j+12>>2]|0;j=a+(e*3|0)|0;e=c[j>>2]|0;a=(h|l)-((h^l)>>>1&2139062143)|0;c[j>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function kva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+40|0;h=g|0;j=h+8|0;k=f<<1;l=e+(-k|0)|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=f-k|0;m=e+l|0;c[h+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;c[j>>2]=n;m=e+f|0;c[h+12>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=k+f+f|0;o=e+(m-k)|0;c[h+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+f|0;m=e+(o-k)|0;c[h+20>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=o+f|0;o=e+(m-k)|0;c[h+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+f|0;m=e+(o-k)|0;c[h+28>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e+(l+o)|0;c[h+32>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=f*3|0;h=j;j=b;b=1;o=n&255;while(1){n=d[h-4|0]|0;l=o&255;e=d[h+4|0]|0;p=d[h+8|0]|0;q=d[h+12|0]|0;r=d[h+16|0]|0;s=d[h+20|0]|0;t=d[h+24|0]|0;u=(d[h-8|0]|0)+16+((e+l|0)*20|0)+q+((p+n|0)*-5|0)>>5;if(u>>>0>255>>>0){v=-u>>31&255}else{v=u&255}a[j]=((d[j]|0)+1+(v&255)|0)>>>1;u=j+f|0;w=n+16+((p+e|0)*20|0)+r+((q+l|0)*-5|0)>>5;if(w>>>0>255>>>0){x=-w>>31&255}else{x=w&255}a[u]=((d[u]|0)+1+(x&255)|0)>>>1;u=j+k|0;w=l+16+((q+p|0)*20|0)+s+((r+e|0)*-5|0)>>5;if(w>>>0>255>>>0){y=-w>>31&255}else{y=w&255}a[u]=((d[u]|0)+1+(y&255)|0)>>>1;u=j+m|0;w=e+16+((r+q|0)*20|0)+t+((s+p|0)*-5|0)>>5;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[u]=((d[u]|0)+1+(z&255)|0)>>>1;u=h+1|0;if((b|0)>=4){break}h=u;j=j+1|0;b=b+1|0;o=a[u]|0}i=g;return}function lva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+72|0;j=i;i=i+16|0;k=i;i=i+16|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o-m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;DEa(j,l,4);EEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;l=a;o=c[l>>2]|0;g=(h|b)-((h^b)>>>1&2139062143)|0;c[l>>2]=(g|o)-((g^o)>>>1&2139062143);o=c[j+4>>2]|0;g=c[k+4>>2]|0;l=a+e|0;b=c[l>>2]|0;h=(g|o)-((g^o)>>>1&2139062143)|0;c[l>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+8>>2]|0;h=c[k+8>>2]|0;l=a+m|0;m=c[l>>2]|0;o=(h|b)-((h^b)>>>1&2139062143)|0;c[l>>2]=(o|m)-((o^m)>>>1&2139062143);m=c[j+12>>2]|0;j=c[k+12>>2]|0;k=a+(e*3|0)|0;e=c[k>>2]|0;a=(j|m)-((j^m)>>>1&2139062143)|0;c[k>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function mva(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+72|0;h=g|0;j=f<<1;k=e+(-j|0)|0;e=0;l=h|0;while(1){m=d[k]|0;n=d[k+1|0]|0;o=d[k-1|0]|0;p=d[k+2|0]|0;q=d[k+3|0]|0;b[l>>1]=(((d[k-2|0]|0)+((n+m&65535)*20&65535)&65535)+((p+o&65535)*-5&65535)&65535)+q;r=d[k+4|0]|0;b[l+2>>1]=((o+((p+n&65535)*20&65535)&65535)+((q+m&65535)*-5&65535)&65535)+r;o=d[k+5|0]|0;b[l+4>>1]=((m+((q+p&65535)*20&65535)&65535)+((r+n&65535)*-5&65535)&65535)+o;b[l+6>>1]=((n+((r+q&65535)*20&65535)&65535)+((o+p&65535)*-5&65535)&65535)+(d[k+6|0]|0);p=e+1|0;if((p|0)<9){k=k+f|0;e=p;l=l+8|0}else{break}}l=f*3|0;e=c;c=0;k=h+16|0;while(1){h=b[k-8>>1]|0;p=b[k>>1]|0;o=b[k+8>>1]|0;q=b[k+16>>1]|0;r=b[k+24>>1]|0;n=b[k+32>>1]|0;m=b[k+40>>1]|0;s=b[k+48>>1]|0;t=(b[k-16>>1]|0)+512+((o+p|0)*20|0)+r+((q+h|0)*-5|0)>>10;if(t>>>0>255>>>0){u=-t>>31&255}else{u=t&255}a[e]=((d[e]|0)+1+(u&255)|0)>>>1;t=e+f|0;v=h+512+((q+o|0)*20|0)+n+((r+p|0)*-5|0)>>10;if(v>>>0>255>>>0){w=-v>>31&255}else{w=v&255}a[t]=((d[t]|0)+1+(w&255)|0)>>>1;t=e+j|0;v=p+512+((r+q|0)*20|0)+m+((n+o|0)*-5|0)>>10;if(v>>>0>255>>>0){x=-v>>31&255}else{x=v&255}a[t]=((d[t]|0)+1+(x&255)|0)>>>1;t=e+l|0;v=o+512+((n+r|0)*20|0)+s+((m+q|0)*-5|0)>>10;if(v>>>0>255>>>0){y=-v>>31&255}else{y=v&255}a[t]=((d[t]|0)+1+(y&255)|0)>>>1;t=c+1|0;if((t|0)<4){e=e+1|0;c=t;k=k+2|0}else{break}}i=g;return}function nva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+40|0;g=f|0;h=i;i=i+72|0;j=i;i=i+16|0;k=i;i=i+16|0;l=g+8|0;m=e<<1;n=-m|1;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+m)|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e|0;q=b+(n+p)|0;c[g+12>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=p+e|0;p=b+(q+n)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=q+e|0;q=b+(p+n)|0;c[g+20>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=p+e|0;p=b+(q+n)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=q+e|0;q=b+(p+n)|0;c[g+28>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=b+(o+p)|0;c[g+32>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;DEa(j,l,4);EEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;l=a;q=c[l>>2]|0;g=(h|b)-((h^b)>>>1&2139062143)|0;c[l>>2]=(g|q)-((g^q)>>>1&2139062143);q=c[j+4>>2]|0;g=c[k+4>>2]|0;l=a+e|0;b=c[l>>2]|0;h=(g|q)-((g^q)>>>1&2139062143)|0;c[l>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[j+8>>2]|0;h=c[k+8>>2]|0;l=a+m|0;m=c[l>>2]|0;q=(h|b)-((h^b)>>>1&2139062143)|0;c[l>>2]=(q|m)-((q^m)>>>1&2139062143);m=c[j+12>>2]|0;j=c[k+12>>2]|0;k=a+(e*3|0)|0;e=c[k>>2]|0;a=(j|m)-((j^m)>>>1&2139062143)|0;c[k>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function ova(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=g+20|0;q=o+e|0;o=b+(q-k)|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=g+24|0;r=q+e|0;q=b+(r-k)|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;q=r+e|0;r=b+(q-k)|0;c[g+28>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;r=b+(l+q)|0;c[g+32>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;DEa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;r=a;g=c[r>>2]|0;q=(m|j)-((m^j)>>>1&2139062143)|0;c[r>>2]=(q|g)-((q^g)>>>1&2139062143);g=c[n>>2]|0;n=c[h+4>>2]|0;q=a+e|0;r=c[q>>2]|0;j=(n|g)-((n^g)>>>1&2139062143)|0;c[q>>2]=(j|r)-((j^r)>>>1&2139062143);r=c[p>>2]|0;p=c[h+8>>2]|0;j=a+k|0;k=c[j>>2]|0;q=(p|r)-((p^r)>>>1&2139062143)|0;c[j>>2]=(q|k)-((q^k)>>>1&2139062143);k=c[o>>2]|0;o=c[h+12>>2]|0;h=a+(e*3|0)|0;e=c[h>>2]|0;a=(o|k)-((o^k)>>>1&2139062143)|0;c[h>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function pva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;l=b+e|0;CEa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;l=b+(o-m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+28>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+32>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;DEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;g=a;l=c[g>>2]|0;n=(o|k)-((o^k)>>>1&2139062143)|0;c[g>>2]=(n|l)-((n^l)>>>1&2139062143);l=c[h+4>>2]|0;n=c[j+4>>2]|0;g=a+e|0;k=c[g>>2]|0;o=(n|l)-((n^l)>>>1&2139062143)|0;c[g>>2]=(o|k)-((o^k)>>>1&2139062143);k=c[h+8>>2]|0;o=c[j+8>>2]|0;g=a+m|0;m=c[g>>2]|0;l=(o|k)-((o^k)>>>1&2139062143)|0;c[g>>2]=(l|m)-((l^m)>>>1&2139062143);m=c[h+12>>2]|0;h=c[j+12>>2]|0;j=a+(e*3|0)|0;e=c[j>>2]|0;a=(h|m)-((h^m)>>>1&2139062143)|0;c[j>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function qva(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+88|0;f=e+72|0;g=i;i=i+16|0;CEa(f,b+d|0,4,d);EEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;j=a;k=c[j>>2]|0;l=(h|b)-((h^b)>>>1&2139062143)|0;c[j>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[f+4>>2]|0;l=c[g+4>>2]|0;j=a+d|0;b=c[j>>2]|0;h=(l|k)-((l^k)>>>1&2139062143)|0;c[j>>2]=(h|b)-((h^b)>>>1&2139062143);b=c[f+8>>2]|0;h=c[g+8>>2]|0;j=a+(d<<1)|0;k=c[j>>2]|0;l=(h|b)-((h^b)>>>1&2139062143)|0;c[j>>2]=(l|k)-((l^k)>>>1&2139062143);k=c[f+12>>2]|0;f=c[g+12>>2]|0;g=a+(d*3|0)|0;d=c[g>>2]|0;a=(f|k)-((f^k)>>>1&2139062143)|0;c[g>>2]=(a|d)-((a^d)>>>1&2139062143);i=e;return}function rva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+40|0;g=f|0;h=i;i=i+16|0;j=i;i=i+16|0;k=g+8|0;CEa(h,b+e|0,4,e);l=e<<1;m=-l|1;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(m+l)|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e|0;p=b+(m+o)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p+m)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=p+e|0;p=b+(o+m)|0;c[g+28>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(n+o)|0;c[g+32>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;DEa(j,k,4);k=c[h>>2]|0;p=c[j>>2]|0;g=a;o=c[g>>2]|0;n=(p|k)-((p^k)>>>1&2139062143)|0;c[g>>2]=(n|o)-((n^o)>>>1&2139062143);o=c[h+4>>2]|0;n=c[j+4>>2]|0;g=a+e|0;k=c[g>>2]|0;p=(n|o)-((n^o)>>>1&2139062143)|0;c[g>>2]=(p|k)-((p^k)>>>1&2139062143);k=c[h+8>>2]|0;p=c[j+8>>2]|0;g=a+l|0;l=c[g>>2]|0;o=(p|k)-((p^k)>>>1&2139062143)|0;c[g>>2]=(o|l)-((o^l)>>>1&2139062143);l=c[h+12>>2]|0;h=c[j+12>>2]|0;j=a+(e*3|0)|0;e=c[j>>2]|0;a=(h|l)-((h^l)>>>1&2139062143)|0;c[j>>2]=(a|e)-((a^e)>>>1&2139062143);i=f;return}function sva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=e+8|0;h=b+f|0;g=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=h;h=e<<1;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;j=b+g|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+g|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=b+16|0;h=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+16|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=j;j=b+24|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+24|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=e+16|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=e+24|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;e=b+h|0;f=e|0;g=e+4|0;e=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+h|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=e;e=h+8|0;h=b+e|0;b=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[g+4>>2]=h;return}function tva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;tEa(g|0,b,32,e);tEa(g+16|0,b+16|0,32,e);h=e<<3;tEa(g+256|0,b+h|0,32,e);tEa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=xrc(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ca(r,e)|0;l=h+16|0;k=b+l|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r<<5;p=g+(o|16)|0;j=p|0;q=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p+4|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p^k;n=xrc(q|m,p|k,((q^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+l|0;c[j>>2]=n;c[j+4>>2]=G;j=h+24|0;h=b+j|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+(o|24)|0;o=n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^h;q=xrc(m|l,n|h,((m^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;r=r+1|0;}while((r|0)<16);i=f;return}function uva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;tEa(a,b,c,c);tEa(a+16|0,b+16|0,c,c);d=c<<3;tEa(a+d|0,b+d|0,c,c);e=d+16|0;tEa(a+e|0,b+e|0,c,c);return}function vva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;tEa(g|0,b,32,e);tEa(g+16|0,b+16|0,32,e);h=e<<3;tEa(g+256|0,b+h|0,32,e);tEa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=xrc(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ca(r,e)|0;l=b+(h+18)|0;k=l|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=r<<5;m=g+(k|16)|0;p=m|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^l;q=xrc(o|j,m|l,((o^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(h+16)|0;c[p>>2]=q;c[p+4>>2]=G;p=b+(h+26)|0;q=p|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(k|24)|0;k=q|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q^p;l=xrc(o|j,q|p,((o^j)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(h+24)|0;c[k>>2]=l;c[k+4>>2]=G;r=r+1|0;}while((r|0)<16);i=f;return}function wva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}uEa(j|0,h+64|0,32,32);uEa(j+16|0,h+80|0,32,32);uEa(j+256|0,h+320|0,32,32);uEa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=xrc(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=G;m=e|8;e=h+(m+64)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=xrc(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+64)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=xrc(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=G;n=l|24;l=h+(n+64)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=xrc(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function xva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;tEa(j|0,e,32,f);tEa(j+16|0,e+16|0,32,f);l=f<<3;tEa(j+256|0,e+l|0,32,f);tEa(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=xrc(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=xrc(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=xrc(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=G;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=xrc(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function yva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;tEa(h|0,b,32,e);k=b+16|0;tEa(h+16|0,k,32,e);l=e<<3;m=b+l|0;tEa(h+256|0,m,32,e);n=b+(l+16)|0;tEa(h+272|0,n,32,e);l=g|0;vEa(j|0,l,b,32,32,e);b=g+16|0;vEa(j+16|0,b,k,32,32,e);vEa(j+256|0,l,m,32,32,e);vEa(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l^m;p=xrc(o|k,l|m,((o^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ca(n,e)|0;k=a+g|0;c[k>>2]=p;c[k+4>>2]=G;k=b|8;b=h+k|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+k|0;k=p|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p+4|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p^b;l=xrc(m|o,p|b,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(g+8)|0;c[k>>2]=l;c[k+4>>2]=G;k=n+1|0;if((k|0)<16){n=k}else{q=0;break}}do{n=q<<5;k=n|16;l=h+k|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+k|0;k=g|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^l;b=xrc(m|o,g|l,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=ca(q,e)|0;o=a+(k+16)|0;c[o>>2]=b;c[o+4>>2]=G;o=n|24;n=h+o|0;b=n|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=n+4|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^n;g=xrc(l|m,b|n,((l^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(k+24)|0;c[o>>2]=g;c[o+4>>2]=G;q=q+1|0;}while((q|0)<16);i=f;return}function zva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;tEa(j|0,e,32,f);tEa(j+16|0,e+16|0,32,f);l=f<<3;tEa(j+256|0,e+l|0,32,f);tEa(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=xrc(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=xrc(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=xrc(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=G;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=xrc(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Ava(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m+4|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}uEa(b,g+64|0,e,32);uEa(b+16|0,g+80|0,e,32);j=e<<3;uEa(b+j|0,g+320|0,e,32);uEa(b+(j+16)|0,g+336|0,e,32);i=f;return}function Bva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=j|0;vEa(l|0,h,e,32,32,f);o=j+16|0;vEa(l+16|0,o,e+16|0,32,32,f);j=f<<3;vEa(l+256|0,h,e+j|0,32,32,f);vEa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=xrc(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=G;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=xrc(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=G;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=xrc(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=G;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=xrc(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=G;t=t+1|0;}while((t|0)<16);i=g;return}function Cva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+1344|0;e=d|0;f=e|0;vEa(a,f,b,c,32,c);g=e+16|0;vEa(a+16|0,g,b+16|0,c,32,c);e=c<<3;vEa(a+e|0,f,b+e|0,c,32,c);f=e+16|0;vEa(a+f|0,g,b+f|0,c,32,c);i=d;return}function Dva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=j|0;vEa(l|0,h,e,32,32,f);o=j+16|0;vEa(l+16|0,o,e+16|0,32,32,f);j=f<<3;vEa(l+256|0,h,e+j|0,32,32,f);vEa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=xrc(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=G;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=xrc(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=G;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=xrc(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=G;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=xrc(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=G;t=t+1|0;}while((t|0)<16);i=g;return}function Eva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}uEa(j|0,h+64|0,32,32);uEa(j+16|0,h+80|0,32,32);uEa(j+256|0,h+320|0,32,32);uEa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=xrc(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=G;m=e|8;e=h+(m+96)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=xrc(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+96)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=xrc(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=G;n=l|24;l=h+(n+96)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=xrc(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Fva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;tEa(j|0,e+f|0,32,f);l=f+16|0;tEa(j+16|0,e+l|0,32,f);m=f<<3;tEa(j+256|0,e+(m+f)|0,32,f);tEa(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=xrc(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=xrc(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=xrc(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=G;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=xrc(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Gva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;tEa(h|0,b+e|0,32,e);tEa(h+16|0,b+(e+16)|0,32,e);k=e<<3;tEa(h+256|0,b+(k+e)|0,32,e);l=k+16|0;tEa(h+272|0,b+(l+e)|0,32,e);m=g|0;vEa(j|0,m,b,32,32,e);n=g+16|0;vEa(j+16|0,n,b+16|0,32,32,e);vEa(j+256|0,m,b+k|0,32,32,e);vEa(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k^n;p=xrc(o|m,k|n,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ca(l,e)|0;m=a+g|0;c[m>>2]=p;c[m+4>>2]=G;m=b|8;b=h+m|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+m|0;m=p|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^b;k=xrc(n|o,p|b,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(g+8)|0;c[m>>2]=k;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{q=0;break}}do{l=q<<5;m=l|16;k=h+m|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=g|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+4|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g^k;b=xrc(n|o,g|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(q,e)|0;o=a+(m+16)|0;c[o>>2]=b;c[o+4>>2]=G;o=l|24;l=h+o|0;b=l|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=l+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^l;g=xrc(k|n,b|l,((k^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(m+24)|0;c[o>>2]=g;c[o+4>>2]=G;q=q+1|0;}while((q|0)<16);i=f;return}function Hva(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;tEa(j|0,e+f|0,32,f);l=f+16|0;tEa(j+16|0,e+l|0,32,f);m=f<<3;tEa(j+256|0,e+(m+f)|0,32,f);tEa(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=xrc(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=xrc(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=xrc(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=G;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=xrc(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Iva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+(e+8)|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+(e+8)|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=e<<1;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=b+(g+8)|0;j=f|0;i=f+4|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(h+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=f;f=g+e|0;g=h+e|0;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;e=b+g|0;f=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=e;e=b+(g+8)|0;g=e|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(h+8)|0;c[b>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[b+4>>2]=e;return}function Jva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;tEa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=xrc(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Kva(a,b,c){a=a|0;b=b|0;c=c|0;tEa(a,b,c,c);return}function Lva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;tEa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=xrc(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Mva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;uEa(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k^b;h=xrc(m|g,k|b,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(p,e)|0;g=a+o|0;c[g>>2]=h;c[g+4>>2]=G;g=n|8;n=l+g|0;h=c[n>>2]|0;m=c[n+4>>2]|0;n=j+g|0;g=n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^m;k=xrc(b|h,n|m,((b^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(o+8)|0;c[g>>2]=k;c[g+4>>2]=G;p=p+1|0;}while((p|0)<8);i=f;return}function Nva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;tEa(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;uEa(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o^n;m=xrc(h|g,o|n,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=m;c[g+4>>2]=G;g=p|8;p=j+g|0;m=p|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+g|0;g=m|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m+4|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m^p;o=xrc(n|h,m|p,((n^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=o;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Ova(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;tEa(g|0,b,16,e);vEa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=xrc(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=G;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=xrc(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Pva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;tEa(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;uEa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=xrc(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=xrc(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Qva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;uEa(a,j,e,16);i=f;return}function Rva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;uEa(k|0,m,16,16);vEa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q^m;h=xrc(g|o,q|m,((g^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=ca(b,e)|0;o=a+p|0;c[o>>2]=h;c[o+4>>2]=G;o=j|8;j=k+o|0;h=j|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+o|0;o=h|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h^j;q=xrc(m|g,h|j,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(p+8)|0;c[o>>2]=q;c[o+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Sva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+416|0;vEa(a,d|0,b,c,16,c);i=d;return}function Tva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;uEa(k|0,m,16,16);vEa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h^m;n=xrc(g|p,h|m,((g^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(b,e)|0;p=a+q|0;c[p>>2]=n;c[p+4>>2]=G;p=j|8;j=k+p|0;n=j|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^j;h=xrc(m|g,n|j,((m^g)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(q+8)|0;c[p>>2]=h;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Uva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;uEa(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^g;l=xrc(h|p,m|g,((h^p)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(o,e)|0;p=a+b|0;c[p>>2]=l;c[p+4>>2]=G;p=n|8;n=k+p|0;l=c[n>>2]|0;h=c[n+4>>2]|0;n=j+p|0;p=n|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^h;m=xrc(g|l,n|h,((g^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(b+8)|0;c[p>>2]=m;c[p+4>>2]=G;o=o+1|0;}while((o|0)<8);i=f;return}function Vva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;tEa(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;uEa(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^o;n=xrc(h|g,m|o,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=q|8;q=j+g|0;n=q|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^q;m=xrc(o|h,n|q,((o^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=m;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Wva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;tEa(g|0,b+e|0,16,e);vEa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=xrc(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=G;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=xrc(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Xva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;tEa(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;uEa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=xrc(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=xrc(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Yva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+e|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=b+f|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=f+e|0;e=b+g|0;b=e|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[f+4>>2]=e;return}function Zva(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;qEa(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=xrc(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=G;h=b+e|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=xrc(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=G;n=e<<1;m=b+n|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=xrc(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=G;l=e*3|0;e=b+l|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=xrc(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=G;i=f;return}function _va(a,b,c){a=a|0;b=b|0;c=c|0;qEa(a,b,c,c);return}function $va(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;qEa(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=xrc(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=G;h=b+(e+2)|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=xrc(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=G;n=e<<1;m=b+(n+2)|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=xrc(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=G;l=e*3|0;e=b+(l+2)|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=xrc(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=G;i=f;return}function awa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;rEa(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=p^s;h=xrc(l|g,p|s,((l^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=h;c[k+4>>2]=G;k=c[o>>2]|0;h=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;l=c[o+4>>2]|0;o=l^h;s=xrc(g|k,l|h,((g^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+e|0;c[o>>2]=s;c[o+4>>2]=G;o=c[n>>2]|0;s=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;g=c[n+4>>2]|0;n=g^s;h=xrc(k|o,g|s,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+m|0;c[n>>2]=h;c[n+4>>2]=G;n=c[q>>2]|0;h=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;m=c[q+4>>2]|0;q=m^h;o=xrc(j|n,m|h,((j^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+(e*3|0)|0;c[q>>2]=o;c[q+4>>2]=G;i=f;return}function bwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;qEa(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;rEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=r^g;q=xrc(k|n,r|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=q;c[m+4>>2]=G;m=j+8|0;q=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;r=xrc(k|q,g|n,((k^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^q;g=xrc(k|r,n|q,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=r;c[m+4>>2]=G;i=f;return}function cwa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;qEa(f,b,8,d);sEa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=xrc(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=G;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=xrc(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=G;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=xrc(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=xrc(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=G;i=e;return}function dwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;qEa(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;rEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=xrc(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=G;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=G;i=f;return}function ewa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+72|0;g=f|0;h=g|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=g+8|0;h=e-k|0;m=b+h|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=m;m=b;l=m|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=m;m=g+24|0;l=b+e|0;n=l|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=l;l=g+32|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=n;n=g+40|0;l=m+e|0;m=b+(l-k)|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;m=g+48|0;n=l+e|0;l=b+(n-k)|0;o=l|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=l;l=g+56|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[l+4>>2]=n;n=g+64|0;g=b+(h+m)|0;m=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=g;rEa(a,j,e);i=f;return}function fwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;rEa(k,o,8);sEa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=xrc(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=G;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=xrc(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=G;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=xrc(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=xrc(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=G;i=f;return}function gwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+144|0;sEa(a,d|0,b,c,c);i=d;return}function hwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;rEa(k,o,8);sEa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=xrc(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=G;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=xrc(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=G;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=xrc(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=xrc(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=G;i=f;return}function iwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;rEa(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=s^g;t=xrc(o|l,s|g,((o^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=t;c[k+4>>2]=G;k=c[n>>2]|0;t=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^t;g=xrc(l|k,o|t,((l^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=g;c[n+4>>2]=G;n=c[q>>2]|0;g=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;l=c[q+4>>2]|0;q=l^g;t=xrc(k|n,l|g,((k^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+m|0;c[q>>2]=t;c[q+4>>2]=G;q=c[p>>2]|0;t=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;m=c[p+4>>2]|0;p=m^t;n=xrc(j|q,m|t,((j^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(e*3|0)|0;c[p>>2]=n;c[p+4>>2]=G;i=f;return}function jwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;qEa(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;rEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=xrc(k|n,o|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;o=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=o;c[m+4>>2]=G;m=j+16|0;o=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|o,n|r,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+p|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;p=c[m+4>>2]|0;m=p^g;o=xrc(l|j,p|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=o;c[m+4>>2]=G;i=f;return}function kwa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;qEa(f,b+d|0,8,d);sEa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=xrc(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=G;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=xrc(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=G;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=xrc(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=xrc(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=G;i=e;return}function lwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;qEa(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;rEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=xrc(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=G;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=G;i=f;return}function mwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;return}function nwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;zEa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+e|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function owa(a,b,c){a=a|0;b=b|0;c=c|0;zEa(a,b,c,c);return}function pwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;zEa(g,b,4,e);h=b+2|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+(e+2)|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function qwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;AEa(h,j,4);n=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|n)-((j^n)>>>1&2147450879);n=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|n)-((m^n)>>>1&2147450879);i=f;return}function rwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;zEa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;AEa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function swa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+64|0;f=e+56|0;g=i;i=i+8|0;zEa(f,b,4,d);BEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function twa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;zEa(h,b,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;AEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function uwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+32|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;AEa(a,h,e);i=f;return}function vwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+56|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;AEa(j,l,4);BEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function wwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+56|0;BEa(a,d|0,b,c,c);i=d;return}function xwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+56|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=2-m|0;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+2|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+2)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e+e|0;m=b+(p+n)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;AEa(j,l,4);BEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function ywa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-k)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;AEa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2147450879);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2147450879);i=f;return}function zwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;l=b+e|0;zEa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;AEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function Awa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+64|0;f=e+56|0;g=i;i=i+8|0;zEa(f,b+d|0,4,d);BEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function Bwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;zEa(h,b+e|0,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;AEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function Cwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=c[i+4>>2]|0;l=f;m=l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l^k;o=xrc(n|j,l|k,((n^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[i>>2]=o;c[i+4>>2]=G;i=g+8|0;o=c[i>>2]|0;m=c[i+4>>2]|0;j=f+8|0;n=j|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j^m;l=xrc(k|o,j|m,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[i>>2]=l;c[i+4>>2]=G;i=h+1|0;if((i|0)<16){f=f+e|0;g=g+e|0;h=i}else{break}}h=b+16|0;b=a+16|0;a=0;while(1){g=b;f=c[g>>2]|0;i=c[g+4>>2]|0;l=h;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^i;k=xrc(o|f,l|i,((o^f)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[g>>2]=k;c[g+4>>2]=G;g=b+8|0;k=c[g>>2]|0;n=c[g+4>>2]|0;f=h+8|0;o=f|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f+4|0;f=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f^n;l=xrc(i|k,f|n,((i^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[g>>2]=l;c[g+4>>2]=G;g=a+1|0;if((g|0)<16){h=h+e|0;b=b+e|0;a=g}else{break}}return}function Dwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;tEa(g|0,b,32,e);tEa(g+16|0,b+16|0,32,e);h=e<<3;tEa(g+256|0,b+h|0,32,e);tEa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=xrc(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ca(u,e)|0;l=h+16|0;q=b+l|0;m=q|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=u<<5;s=g+(m|16)|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+l|0;l=c[t>>2]|0;j=c[t+4>>2]|0;p=s^q;k=xrc(r|o,s|q,((r^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;o=p^j;r=xrc(k|l,p|j,((k^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;t=h+24|0;h=b+t|0;r=h|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+(m|24)|0;m=r|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r+4|0;r=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+t|0;t=c[m>>2]|0;k=c[m+4>>2]|0;j=r^h;p=xrc(l|o,r|h,((l^o)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;o=j^k;l=xrc(p|t,j|k,((p^t)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function Ewa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;yEa(a,b,c,c);yEa(a+16|0,b+16|0,c,c);d=c<<3;yEa(a+d|0,b+d|0,c,c);e=d+16|0;yEa(a+e|0,b+e|0,c,c);return}function Fwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;tEa(g|0,b,32,e);tEa(g+16|0,b+16|0,32,e);h=e<<3;tEa(g+256|0,b+h|0,32,e);tEa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=xrc(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ca(u,e)|0;l=b+(h+18)|0;q=l|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=u<<5;j=g+(q|16)|0;s=j|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=a+(h+16)|0;r=c[s>>2]|0;o=c[s+4>>2]|0;p=j^l;k=xrc(t|m,j|l,((t^m)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;m=p^o;t=xrc(k|r,p|o,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[s>>2]=t;c[s+4>>2]=G;s=b+(h+26)|0;t=s|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=g+(q|24)|0;q=t|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=t+4|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=a+(h+24)|0;h=c[q>>2]|0;k=c[q+4>>2]|0;o=t^s;p=xrc(r|m,t|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;m=o^k;r=xrc(p|h,o|k,((p^h)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function Gwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}uEa(j|0,h+64|0,32,32);uEa(j+16|0,h+80|0,32,32);uEa(j+256|0,h+320|0,32,32);uEa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=xrc(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;m=t^s;n=xrc(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=G;q=e|8;e=h+(q+64)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=xrc(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^u;r=xrc(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+80)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=xrc(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=G;m=n^e;t=xrc(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h+((l|8)+80)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=xrc(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^k;s=xrc(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Hwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;tEa(j|0,e,32,f);tEa(j+16|0,e+16|0,32,f);l=f<<3;tEa(j+256|0,e+l|0,32,f);tEa(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=xrc(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=xrc(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^m;t=xrc(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=xrc(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^e;s=xrc(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Iwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;tEa(h|0,b,32,e);k=b+16|0;tEa(h+16|0,k,32,e);l=e<<3;m=b+l|0;tEa(h+256|0,m,32,e);n=b+(l+16)|0;tEa(h+272|0,n,32,e);l=g|0;vEa(j|0,l,b,32,32,e);b=g+16|0;vEa(j+16|0,b,k,32,32,e);vEa(j+256|0,l,m,32,32,e);vEa(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(n,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^m;t=xrc(o|k,l|m,((o^k)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;k=s^r;o=xrc(t|q,s|r,((t^q)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=b|8;b=h+p|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=xrc(q|k,o|b,((q^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;k=r^t;q=xrc(s|g,r|t,((s^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;p=n+1|0;if((p|0)<16){n=p}else{u=0;break}}do{n=u<<5;p=n|16;q=h+p|0;k=q|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+p|0;p=k|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=k^q;m=xrc(s|g,k|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;g=o^b;s=xrc(m|r,o|b,((m^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=G;t=n|24;n=h+t|0;s=n|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;m=c[t+4>>2]|0;b=s^n;o=xrc(r|g,s|n,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;g=b^m;r=xrc(o|p,b|m,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function Jwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;tEa(j|0,e,32,f);tEa(j+16|0,e+16|0,32,f);l=f<<3;tEa(j+256|0,e+l|0,32,f);tEa(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=xrc(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=xrc(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^m;t=xrc(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=xrc(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^e;s=xrc(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Kwa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m+4|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}xEa(b,g+64|0,e,32);xEa(b+16|0,g+80|0,e,32);j=e<<3;xEa(b+j|0,g+320|0,e,32);xEa(b+(j+16)|0,g+336|0,e,32);i=f;return}function Lwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=j|0;vEa(l|0,h,e,32,32,f);o=j+16|0;vEa(l+16|0,o,e+16|0,32,32,f);j=f<<3;vEa(l+256|0,h,e+j|0,32,32,f);vEa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=xrc(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;n=t^q;s=xrc(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=G;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=xrc(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=G;n=q^u;r=xrc(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=G;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=xrc(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^e;t=xrc(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=xrc(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^o;q=xrc(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Mwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+1344|0;e=d|0;f=e|0;wEa(a,f,b,c,32,c);g=e+16|0;wEa(a+16|0,g,b+16|0,c,32,c);e=c<<3;wEa(a+e|0,f,b+e|0,c,32,c);f=e+16|0;wEa(a+f|0,g,b+f|0,c,32,c);i=d;return}function Nwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=j|0;vEa(l|0,h,e,32,32,f);o=j+16|0;vEa(l+16|0,o,e+16|0,32,32,f);j=f<<3;vEa(l+256|0,h,e+j|0,32,32,f);vEa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=xrc(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;n=t^q;s=xrc(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=G;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=xrc(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=G;n=q^u;r=xrc(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=G;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=xrc(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^e;t=xrc(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=xrc(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^o;q=xrc(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Owa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}uEa(j|0,h+64|0,32,32);uEa(j+16|0,h+80|0,32,32);uEa(j+256|0,h+320|0,32,32);uEa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=xrc(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;m=t^s;n=xrc(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=G;q=e|8;e=h+(q+96)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=xrc(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^u;r=xrc(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+112)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=xrc(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=G;m=n^e;t=xrc(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h+((l|8)+112)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=xrc(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^k;s=xrc(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Pwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;tEa(j|0,e+f|0,32,f);l=f+16|0;tEa(j+16|0,e+l|0,32,f);m=f<<3;tEa(j+256|0,e+(m+f)|0,32,f);tEa(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=xrc(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=xrc(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^l;t=xrc(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=xrc(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=G;n=l^e;s=xrc(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Qwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;tEa(h|0,b+e|0,32,e);tEa(h+16|0,b+(e+16)|0,32,e);k=e<<3;tEa(h+256|0,b+(k+e)|0,32,e);l=k+16|0;tEa(h+272|0,b+(l+e)|0,32,e);m=g|0;vEa(j|0,m,b,32,32,e);n=g+16|0;vEa(j+16|0,n,b+16|0,32,32,e);vEa(j+256|0,m,b+k|0,32,32,e);vEa(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(l,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=k^n;t=xrc(o|m,k|n,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=b|8;b=h+p|0;o=b|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=xrc(q|m,o|b,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|g,r|t,((s^g)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;p=l+1|0;if((p|0)<16){l=p}else{u=0;break}}do{l=u<<5;p=l|16;q=h+p|0;m=q|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+p|0;p=m|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=m^q;n=xrc(s|g,m|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;g=o^b;s=xrc(n|r,o|b,((n^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=G;t=l|24;l=h+t|0;s=l|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+4|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;n=c[t+4>>2]|0;b=s^l;o=xrc(r|g,s|l,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;g=b^n;r=xrc(o|p,b|n,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function Rwa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;tEa(j|0,e+f|0,32,f);l=f+16|0;tEa(j+16|0,e+l|0,32,f);m=f<<3;tEa(j+256|0,e+(m+f)|0,32,f);tEa(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}uEa(k|0,h+64|0,32,32);uEa(k+16|0,h+80|0,32,32);uEa(k+256|0,h+320|0,32,32);uEa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=xrc(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=xrc(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^l;t=xrc(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=xrc(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=G;n=l^e;s=xrc(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Swa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;j=f;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j^i;m=xrc(l|h,j|i,((l^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[g>>2]=m;c[g+4>>2]=G;g=b+8|0;m=c[g>>2]|0;k=c[g+4>>2]|0;h=f+8|0;l=h|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h^k;j=xrc(i|m,h|k,((i^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[g>>2]=j;c[g+4>>2]=G;g=a+1|0;if((g|0)<8){f=f+e|0;b=b+e|0;a=g}else{break}}return}function Twa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;tEa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=xrc(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Uwa(a,b,c){a=a|0;b=b|0;c=c|0;yEa(a,b,c,c);return}function Vwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;tEa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=xrc(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Wwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;uEa(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(p,e)|0;h=a+o|0;q=c[h>>2]|0;r=c[h+4>>2]|0;s=k^b;t=xrc(m|g,k|b,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[h>>2]=m;c[h+4>>2]=G;h=n|8;n=l+h|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=j+h|0;h=n|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(o+8)|0;o=c[h>>2]|0;t=c[h+4>>2]|0;r=n^g;s=xrc(q|m,n|g,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[h>>2]=q;c[h+4>>2]=G;p=p+1|0;}while((p|0)<8);i=f;return}function Xwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;tEa(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;uEa(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;m=a+b|0;q=c[m>>2]|0;r=c[m+4>>2]|0;s=o^n;t=xrc(h|g,o|n,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;h=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=p|8;p=j+m|0;h=p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+m|0;m=h|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+(b+8)|0;b=c[m>>2]|0;t=c[m+4>>2]|0;r=h^p;s=xrc(q|g,h|p,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Ywa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;tEa(g|0,b,16,e);vEa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=xrc(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=xrc(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Zwa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;tEa(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;uEa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=xrc(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=xrc(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function _wa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;xEa(a,j,e,16);i=f;return}function $wa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;uEa(k|0,m,16,16);vEa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(b,e)|0;h=a+p|0;n=c[h>>2]|0;r=c[h+4>>2]|0;s=q^m;t=xrc(g|o,q|m,((g^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;o=s^r;g=xrc(t|n,s|r,((t^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=g;c[h+4>>2]=G;h=j|8;j=k+h|0;g=j|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+h|0;h=g|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(p+8)|0;p=c[h>>2]|0;t=c[h+4>>2]|0;r=g^j;s=xrc(n|o,g|j,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;o=r^t;n=xrc(s|p,r|t,((s^p)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=n;c[h+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function axa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+416|0;wEa(a,d|0,b,c,16,c);i=d;return}function bxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;uEa(k|0,m,16,16);vEa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=ca(b,e)|0;n=a+q|0;o=c[n>>2]|0;r=c[n+4>>2]|0;s=h^m;t=xrc(g|p,h|m,((g^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;p=s^r;g=xrc(t|o,s|r,((t^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=j|8;j=k+n|0;g=j|0;p=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+n|0;n=g|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+4|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(q+8)|0;q=c[n>>2]|0;t=c[n+4>>2]|0;r=g^j;s=xrc(o|p,g|j,((o^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;p=r^t;o=xrc(s|q,r|t,((s^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=o;c[n+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function cxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;uEa(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(o,e)|0;l=a+b|0;q=c[l>>2]|0;r=c[l+4>>2]|0;s=m^g;t=xrc(h|p,m|g,((h^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;p=s^r;h=xrc(t|q,s|r,((t^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[l>>2]=h;c[l+4>>2]=G;l=n|8;n=k+l|0;h=c[n>>2]|0;p=c[n+4>>2]|0;n=j+l|0;l=n|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(b+8)|0;b=c[l>>2]|0;t=c[l+4>>2]|0;r=n^p;s=xrc(q|h,n|p,((q^h)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;h=r^t;q=xrc(s|b,r|t,((s^b)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;o=o+1|0;}while((o|0)<8);i=f;return}function dxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;tEa(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;uEa(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;p=c[n>>2]|0;r=c[n+4>>2]|0;s=m^o;t=xrc(h|g,m|o,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;h=xrc(t|p,s|r,((t^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=h;c[n+4>>2]=G;n=q|8;q=j+n|0;h=q|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=h^q;s=xrc(p|g,h|q,((p^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;p=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=p;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function exa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;tEa(g|0,b+e|0,16,e);vEa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=xrc(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=xrc(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function fxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;tEa(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;uEa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=xrc(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=xrc(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function gxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=c[f>>2]|0;h=c[f+4>>2]|0;i=b;j=i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i^h;l=xrc(k|g,i|h,((k^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[f>>2]=l;c[f+4>>2]=G;f=a+e|0;l=c[f>>2]|0;j=c[f+4>>2]|0;g=b+e|0;k=g|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^j;i=xrc(h|l,g|j,((h^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[f>>2]=i;c[f+4>>2]=G;f=e<<1;i=a+f|0;k=c[i>>2]|0;l=c[i+4>>2]|0;h=b+f|0;j=h|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h^l;m=xrc(g|k,h|l,((g^k)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[i>>2]=m;c[i+4>>2]=G;i=f+e|0;e=a+i|0;a=c[e>>2]|0;f=c[e+4>>2]|0;m=b+i|0;i=m|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m^f;j=xrc(b|a,m|f,((b^a)>>>1|i<<31)&2147450879,(i>>>1|0<<31)&2147450879)|0;c[e>>2]=j;c[e+4>>2]=G;return}function hxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;qEa(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=xrc(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;l=p^o;k=xrc(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=G;h=b+e|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=xrc(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^p;n=xrc(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=G;k=e<<1;n=b+k|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=xrc(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;o=h^j;m=xrc(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=G;l=e*3|0;e=b+l|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=xrc(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;m=k^a;g=xrc(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=G;i=f;return}function ixa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d>>1;d=0;g=a;a=c;while(1){c=a+2|0;h=a-2|0;i=a+4|0;j=a+6|0;k=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[i>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<512>>>0){l=k}else{l=-k>>31&511}b[g>>1]=((e[g>>1]|0)+1+l|0)>>>1;k=g+2|0;m=a+8|0;n=(((e[i>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[h>>1]|0)+(((e[j>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[m>>1]|0)>>5;if(n>>>0<512>>>0){o=n}else{o=-n>>31&511}b[k>>1]=((e[k>>1]|0)+1+o|0)>>>1;k=g+4|0;n=a+10|0;h=(((e[j>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[m>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(h>>>0<512>>>0){p=h}else{p=-h>>31&511}b[k>>1]=((e[k>>1]|0)+1+p|0)>>>1;k=g+6|0;h=(((e[m>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(h>>>0<512>>>0){q=h}else{q=-h>>31&511}b[k>>1]=((e[k>>1]|0)+1+q|0)>>>1;k=d+1|0;if((k|0)<4){d=k;g=g+(f<<1)|0;a=a+(f<<1)|0}else{break}}return}function jxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;qEa(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=xrc(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;l=p^o;k=xrc(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=G;h=b+(e+2)|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=xrc(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^p;n=xrc(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=G;k=e<<1;n=b+(k+2)|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=xrc(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;o=h^j;m=xrc(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=G;l=e*3|0;e=b+(l+2)|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=xrc(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;m=k^a;g=xrc(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=G;i=f;return}function kxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;rEa(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=a;h=c[k>>2]|0;b=c[k+4>>2]|0;r=p^s;t=xrc(l|g,p|s,((l^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^b;l=xrc(t|h,r|b,((t^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[k>>2]=l;c[k+4>>2]=G;k=c[o>>2]|0;l=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;h=c[o+4>>2]|0;o=a+e|0;t=c[o>>2]|0;b=c[o+4>>2]|0;r=h^l;s=xrc(g|k,h|l,((g^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;k=r^b;g=xrc(s|t,r|b,((s^t)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[o>>2]=g;c[o+4>>2]=G;o=c[n>>2]|0;g=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=a+m|0;m=c[n>>2]|0;s=c[n+4>>2]|0;b=t^g;r=xrc(k|o,t|g,((k^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;o=b^s;k=xrc(r|m,b|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[n>>2]=k;c[n+4>>2]=G;n=c[q>>2]|0;k=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;o=c[q+4>>2]|0;q=a+(e*3|0)|0;e=c[q>>2]|0;a=c[q+4>>2]|0;m=o^k;r=xrc(j|n,o|k,((j^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^a;j=xrc(r|e,m|a,((r^e)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=j;c[q+4>>2]=G;i=f;return}function lxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;qEa(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;rEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=a;q=c[m>>2]|0;h=c[m+4>>2]|0;b=r^g;p=xrc(k|n,r|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(p|q,b|h,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;q=c[m>>2]|0;p=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=p^n;r=xrc(q|k,p|n,((q^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;q=xrc(r|h,g|b,((r^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=G;m=j+16|0;q=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;r=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=r^k;n=xrc(h|q,r|k,((h^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;q=g^b;h=xrc(n|o,g|b,((n^o)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;q=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=q^h;n=xrc(l|j,q|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function mxa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;qEa(f,b,8,d);sEa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=xrc(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;b=o^n;g=xrc(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=G;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=xrc(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;g=k^o;m=xrc(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=G;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=xrc(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;m=b^k;n=xrc(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=xrc(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;f=o^a;h=xrc(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=G;i=e;return}function nxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;qEa(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;rEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=xrc(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=xrc(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=xrc(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function oxa(a,f,g){a=a|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=j|0;l=j+16|0;m=g<<1;n=f+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=n;n=j+8|0;k=g-m|0;o=f+k|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=f;n=o|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=p;c[l+4>>2]=o;o=j+24|0;n=f+g|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=n;n=j+32|0;o=m+g+g|0;q=f+(o-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=j+40|0;n=o+g|0;o=f+(n-m)|0;r=o|0;s=o+4|0;o=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=o;o=j+48|0;q=n+g|0;n=f+(q-m)|0;r=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=n;n=j+56|0;o=q+g|0;q=f+(o-m)|0;m=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=q;q=j+64|0;j=f+(k+o)|0;o=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=j;j=g>>1;g=j<<1;q=j*3|0;o=l;l=a;a=1;k=p&65535;while(1){p=e[o-8>>1]|0;f=k&65535;n=e[o+8>>1]|0;m=e[o+16>>1]|0;r=e[o+24>>1]|0;s=e[o+32>>1]|0;t=e[o+40>>1]|0;u=e[o+48>>1]|0;v=(e[o-16>>1]|0)+16+((n+f|0)*20|0)+r+((m+p|0)*-5|0)>>5;if(v>>>0<512>>>0){w=v}else{w=-v>>31&511}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;v=l+(j<<1)|0;x=p+16+((m+n|0)*20|0)+s+((r+f|0)*-5|0)>>5;if(x>>>0<512>>>0){y=x}else{y=-x>>31&511}b[v>>1]=((e[v>>1]|0)+1+y|0)>>>1;v=l+(g<<1)|0;x=f+16+((r+m|0)*20|0)+t+((s+n|0)*-5|0)>>5;if(x>>>0<512>>>0){z=x}else{z=-x>>31&511}b[v>>1]=((e[v>>1]|0)+1+z|0)>>>1;v=l+(q<<1)|0;x=n+16+((s+r|0)*20|0)+u+((t+m|0)*-5|0)>>5;if(x>>>0<512>>>0){A=x}else{A=-x>>31&511}b[v>>1]=((e[v>>1]|0)+1+A|0)>>>1;v=o+2|0;if((a|0)>=4){break}o=v;l=l+2|0;a=a+1|0;k=b[v>>1]|0}i=h;return}function pxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;rEa(k,o,8);sEa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;s=c[n+4>>2]|0;r=o^j;h=xrc(l|b,o|j,((l^b)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;b=r^s;l=xrc(h|g,r|s,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;s=c[n>>2]|0;r=c[n+4>>2]|0;j=h^b;o=xrc(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^r;g=xrc(o|s,j|r,((o^s)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;s=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;r=c[n+4>>2]|0;j=o^l;b=xrc(s|g,o|l,((s^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;g=j^r;s=xrc(b|p,j|r,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=s;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;s=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^s;b=xrc(m|k,g|s,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;k=p^a;m=xrc(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;i=f;return}function qxa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+144|0;g=f|0;h=d>>1;d=h<<1;j=c+(-d<<1)|0;c=0;k=g|0;while(1){l=b[j>>1]|0;m=b[j+2>>1]|0;n=b[j-2>>1]|0;o=b[j+4>>1]|0;p=b[j+6>>1]|0;b[k>>1]=(((b[j-4>>1]|0)+((m+l&65535)*20&65535)&65535)+((o+n&65535)*-5&65535)&65535)+p;q=b[j+8>>1]|0;b[k+2>>1]=((n+((o+m&65535)*20&65535)&65535)+((p+l&65535)*-5&65535)&65535)+q;n=b[j+10>>1]|0;b[k+4>>1]=((l+((p+o&65535)*20&65535)&65535)+((q+m&65535)*-5&65535)&65535)+n;b[k+6>>1]=((m+((q+p&65535)*20&65535)&65535)+((n+o&65535)*-5&65535)&65535)+(b[j+12>>1]|0);o=c+1|0;if((o|0)<9){j=j+(h<<1)|0;c=o;k=k+16|0}else{break}}k=h*3|0;c=a;a=0;j=g+32|0;while(1){g=b[j-16>>1]|0;o=b[j>>1]|0;n=b[j+16>>1]|0;p=b[j+32>>1]|0;q=b[j+48>>1]|0;m=b[j+64>>1]|0;l=b[j+80>>1]|0;r=b[j+96>>1]|0;s=(b[j-32>>1]|0)+512+((n+o|0)*20|0)+q+((p+g|0)*-5|0)>>10;if(s>>>0<512>>>0){t=s}else{t=-s>>31&511}b[c>>1]=((e[c>>1]|0)+1+t|0)>>>1;s=c+(h<<1)|0;u=g+512+((p+n|0)*20|0)+m+((q+o|0)*-5|0)>>10;if(u>>>0<512>>>0){v=u}else{v=-u>>31&511}b[s>>1]=((e[s>>1]|0)+1+v|0)>>>1;s=c+(d<<1)|0;u=o+512+((q+p|0)*20|0)+l+((m+n|0)*-5|0)>>10;if(u>>>0<512>>>0){w=u}else{w=-u>>31&511}b[s>>1]=((e[s>>1]|0)+1+w|0)>>>1;s=c+(k<<1)|0;u=n+512+((m+q|0)*20|0)+r+((l+p|0)*-5|0)>>10;if(u>>>0<512>>>0){x=u}else{x=-u>>31&511}b[s>>1]=((e[s>>1]|0)+1+x|0)>>>1;s=a+1|0;if((s|0)<4){c=c+2|0;a=s;j=j+2|0}else{break}}i=f;return}function rxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;rEa(k,o,8);sEa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;t=c[n+4>>2]|0;s=o^j;h=xrc(l|b,o|j,((l^b)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;b=s^t;l=xrc(h|g,s|t,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;t=c[n>>2]|0;s=c[n+4>>2]|0;j=h^b;o=xrc(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^s;g=xrc(o|t,j|s,((o^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;t=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;s=c[n+4>>2]|0;j=o^l;b=xrc(t|g,o|l,((t^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;g=j^s;t=xrc(b|p,j|s,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=t;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^t;b=xrc(m|k,g|t,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;k=p^a;m=xrc(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;i=f;return}function sxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;rEa(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=a;t=c[k>>2]|0;h=c[k+4>>2]|0;b=s^g;r=xrc(o|l,s|g,((o^l)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;l=b^h;o=xrc(r|t,b|h,((r^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=o;c[k+4>>2]=G;k=c[n>>2]|0;o=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;t=c[n+4>>2]|0;n=a+e|0;r=c[n>>2]|0;h=c[n+4>>2]|0;b=t^o;g=xrc(l|k,t|o,((l^k)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;k=b^h;l=xrc(g|r,b|h,((g^r)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=c[q>>2]|0;l=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;r=c[q+4>>2]|0;q=a+m|0;m=c[q>>2]|0;g=c[q+4>>2]|0;h=r^l;b=xrc(k|n,r|l,((k^n)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;n=h^g;k=xrc(b|m,h|g,((b^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=k;c[q+4>>2]=G;q=c[p>>2]|0;k=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;n=c[p+4>>2]|0;p=a+(e*3|0)|0;e=c[p>>2]|0;a=c[p+4>>2]|0;m=n^k;b=xrc(j|q,n|k,((j^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;q=m^a;j=xrc(b|e,m|a,((b^e)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[p>>2]=j;c[p+4>>2]=G;i=f;return}function txa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;qEa(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;rEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=o^g;q=xrc(k|n,o|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;o=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(o|h,g|b,((o^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;o=c[m+4>>2]|0;m=a+p|0;p=c[m>>2]|0;b=c[m+4>>2]|0;g=o^k;n=xrc(h|r,o|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|p,g|b,((n^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;p=r^h;n=xrc(l|j,r|h,((l^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;j=p^a;l=xrc(n|e,p|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function uxa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;qEa(f,b+d|0,8,d);sEa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=xrc(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;b=o^n;g=xrc(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=G;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=xrc(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;g=k^o;m=xrc(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=G;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=xrc(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;m=b^k;n=xrc(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=xrc(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;f=o^a;h=xrc(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=G;i=e;return}function vxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;qEa(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;rEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=xrc(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=xrc(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=xrc(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function wxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=e+8|0;h=b+f|0;g=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=h;h=e<<1;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;j=b+g|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+g|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=b+16|0;h=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+16|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=j;j=b+24|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+24|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=e+16|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=e+24|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;e=b+h|0;f=e|0;g=e+4|0;e=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+h|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=e;e=h+8|0;h=b+e|0;b=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[g+4>>2]=h;return}function xxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;hEa(g|0,b,32,e);hEa(g+16|0,b+16|0,32,e);h=e<<3;hEa(g+256|0,b+h|0,32,e);hEa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=xrc(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ca(r,e)|0;l=h+16|0;k=b+l|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r<<5;p=g+(o|16)|0;j=p|0;q=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p+4|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p^k;n=xrc(q|m,p|k,((q^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+l|0;c[j>>2]=n;c[j+4>>2]=G;j=h+24|0;h=b+j|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+(o|24)|0;o=n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^h;q=xrc(m|l,n|h,((m^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;r=r+1|0;}while((r|0)<16);i=f;return}function yxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;hEa(a,b,c,c);hEa(a+16|0,b+16|0,c,c);d=c<<3;hEa(a+d|0,b+d|0,c,c);e=d+16|0;hEa(a+e|0,b+e|0,c,c);return}function zxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;hEa(g|0,b,32,e);hEa(g+16|0,b+16|0,32,e);h=e<<3;hEa(g+256|0,b+h|0,32,e);hEa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=xrc(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ca(r,e)|0;l=b+(h+18)|0;k=l|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=r<<5;m=g+(k|16)|0;p=m|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^l;q=xrc(o|j,m|l,((o^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(h+16)|0;c[p>>2]=q;c[p+4>>2]=G;p=b+(h+26)|0;q=p|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(k|24)|0;k=q|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q^p;l=xrc(o|j,q|p,((o^j)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(h+24)|0;c[k>>2]=l;c[k+4>>2]=G;r=r+1|0;}while((r|0)<16);i=f;return}function Axa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}iEa(j|0,h+64|0,32,32);iEa(j+16|0,h+80|0,32,32);iEa(j+256|0,h+320|0,32,32);iEa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=xrc(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=G;m=e|8;e=h+(m+64)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=xrc(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+64)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=xrc(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=G;n=l|24;l=h+(n+64)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=xrc(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Bxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;hEa(j|0,e,32,f);hEa(j+16|0,e+16|0,32,f);l=f<<3;hEa(j+256|0,e+l|0,32,f);hEa(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=xrc(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=xrc(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=xrc(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=G;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=xrc(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Cxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;hEa(h|0,b,32,e);k=b+16|0;hEa(h+16|0,k,32,e);l=e<<3;m=b+l|0;hEa(h+256|0,m,32,e);n=b+(l+16)|0;hEa(h+272|0,n,32,e);l=g|0;jEa(j|0,l,b,32,32,e);b=g+16|0;jEa(j+16|0,b,k,32,32,e);jEa(j+256|0,l,m,32,32,e);jEa(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l^m;p=xrc(o|k,l|m,((o^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ca(n,e)|0;k=a+g|0;c[k>>2]=p;c[k+4>>2]=G;k=b|8;b=h+k|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+k|0;k=p|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p+4|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p^b;l=xrc(m|o,p|b,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(g+8)|0;c[k>>2]=l;c[k+4>>2]=G;k=n+1|0;if((k|0)<16){n=k}else{q=0;break}}do{n=q<<5;k=n|16;l=h+k|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+k|0;k=g|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^l;b=xrc(m|o,g|l,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=ca(q,e)|0;o=a+(k+16)|0;c[o>>2]=b;c[o+4>>2]=G;o=n|24;n=h+o|0;b=n|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=n+4|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^n;g=xrc(l|m,b|n,((l^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(k+24)|0;c[o>>2]=g;c[o+4>>2]=G;q=q+1|0;}while((q|0)<16);i=f;return}function Dxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;hEa(j|0,e,32,f);hEa(j+16|0,e+16|0,32,f);l=f<<3;hEa(j+256|0,e+l|0,32,f);hEa(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=xrc(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=xrc(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=xrc(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=G;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=xrc(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Exa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m+4|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}iEa(b,g+64|0,e,32);iEa(b+16|0,g+80|0,e,32);j=e<<3;iEa(b+j|0,g+320|0,e,32);iEa(b+(j+16)|0,g+336|0,e,32);i=f;return}function Fxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=j|0;jEa(l|0,h,e,32,32,f);o=j+16|0;jEa(l+16|0,o,e+16|0,32,32,f);j=f<<3;jEa(l+256|0,h,e+j|0,32,32,f);jEa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=xrc(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=G;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=xrc(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=G;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=xrc(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=G;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=xrc(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=G;t=t+1|0;}while((t|0)<16);i=g;return}function Gxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+1344|0;e=d|0;f=e|0;jEa(a,f,b,c,32,c);g=e+16|0;jEa(a+16|0,g,b+16|0,c,32,c);e=c<<3;jEa(a+e|0,f,b+e|0,c,32,c);f=e+16|0;jEa(a+f|0,g,b+f|0,c,32,c);i=d;return}function Hxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=j|0;jEa(l|0,h,e,32,32,f);o=j+16|0;jEa(l+16|0,o,e+16|0,32,32,f);j=f<<3;jEa(l+256|0,h,e+j|0,32,32,f);jEa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=xrc(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=G;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=xrc(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=G;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=xrc(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=G;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=xrc(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=G;t=t+1|0;}while((t|0)<16);i=g;return}function Ixa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}iEa(j|0,h+64|0,32,32);iEa(j+16|0,h+80|0,32,32);iEa(j+256|0,h+320|0,32,32);iEa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=xrc(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=G;m=e|8;e=h+(m+96)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=xrc(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+96)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=xrc(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=G;n=l|24;l=h+(n+96)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=xrc(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Jxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;hEa(j|0,e+f|0,32,f);l=f+16|0;hEa(j+16|0,e+l|0,32,f);m=f<<3;hEa(j+256|0,e+(m+f)|0,32,f);hEa(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=xrc(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=xrc(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=xrc(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=G;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=xrc(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Kxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;hEa(h|0,b+e|0,32,e);hEa(h+16|0,b+(e+16)|0,32,e);k=e<<3;hEa(h+256|0,b+(k+e)|0,32,e);l=k+16|0;hEa(h+272|0,b+(l+e)|0,32,e);m=g|0;jEa(j|0,m,b,32,32,e);n=g+16|0;jEa(j+16|0,n,b+16|0,32,32,e);jEa(j+256|0,m,b+k|0,32,32,e);jEa(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k^n;p=xrc(o|m,k|n,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ca(l,e)|0;m=a+g|0;c[m>>2]=p;c[m+4>>2]=G;m=b|8;b=h+m|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+m|0;m=p|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^b;k=xrc(n|o,p|b,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(g+8)|0;c[m>>2]=k;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{q=0;break}}do{l=q<<5;m=l|16;k=h+m|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=g|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+4|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g^k;b=xrc(n|o,g|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(q,e)|0;o=a+(m+16)|0;c[o>>2]=b;c[o+4>>2]=G;o=l|24;l=h+o|0;b=l|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=l+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^l;g=xrc(k|n,b|l,((k^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(m+24)|0;c[o>>2]=g;c[o+4>>2]=G;q=q+1|0;}while((q|0)<16);i=f;return}function Lxa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;hEa(j|0,e+f|0,32,f);l=f+16|0;hEa(j+16|0,e+l|0,32,f);m=f<<3;hEa(j+256|0,e+(m+f)|0,32,f);hEa(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=xrc(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=xrc(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=xrc(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=G;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=xrc(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Mxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+(e+8)|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+(e+8)|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=e<<1;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=b+(g+8)|0;j=f|0;i=f+4|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(h+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=f;f=g+e|0;g=h+e|0;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;e=b+g|0;f=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=e;e=b+(g+8)|0;g=e|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(h+8)|0;c[b>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[b+4>>2]=e;return}function Nxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;hEa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=xrc(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Oxa(a,b,c){a=a|0;b=b|0;c=c|0;hEa(a,b,c,c);return}function Pxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;hEa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=xrc(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Qxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;iEa(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k^b;h=xrc(m|g,k|b,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(p,e)|0;g=a+o|0;c[g>>2]=h;c[g+4>>2]=G;g=n|8;n=l+g|0;h=c[n>>2]|0;m=c[n+4>>2]|0;n=j+g|0;g=n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^m;k=xrc(b|h,n|m,((b^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(o+8)|0;c[g>>2]=k;c[g+4>>2]=G;p=p+1|0;}while((p|0)<8);i=f;return}function Rxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;hEa(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;iEa(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o^n;m=xrc(h|g,o|n,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=m;c[g+4>>2]=G;g=p|8;p=j+g|0;m=p|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+g|0;g=m|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m+4|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m^p;o=xrc(n|h,m|p,((n^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=o;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Sxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;hEa(g|0,b,16,e);jEa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=xrc(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=G;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=xrc(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Txa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;hEa(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;iEa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=xrc(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=xrc(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Uxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;iEa(a,j,e,16);i=f;return}function Vxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;iEa(k|0,m,16,16);jEa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q^m;h=xrc(g|o,q|m,((g^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=ca(b,e)|0;o=a+p|0;c[o>>2]=h;c[o+4>>2]=G;o=j|8;j=k+o|0;h=j|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+o|0;o=h|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h^j;q=xrc(m|g,h|j,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(p+8)|0;c[o>>2]=q;c[o+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Wxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+416|0;jEa(a,d|0,b,c,16,c);i=d;return}function Xxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;iEa(k|0,m,16,16);jEa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h^m;n=xrc(g|p,h|m,((g^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(b,e)|0;p=a+q|0;c[p>>2]=n;c[p+4>>2]=G;p=j|8;j=k+p|0;n=j|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^j;h=xrc(m|g,n|j,((m^g)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(q+8)|0;c[p>>2]=h;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Yxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;iEa(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^g;l=xrc(h|p,m|g,((h^p)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(o,e)|0;p=a+b|0;c[p>>2]=l;c[p+4>>2]=G;p=n|8;n=k+p|0;l=c[n>>2]|0;h=c[n+4>>2]|0;n=j+p|0;p=n|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^h;m=xrc(g|l,n|h,((g^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(b+8)|0;c[p>>2]=m;c[p+4>>2]=G;o=o+1|0;}while((o|0)<8);i=f;return}function Zxa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;hEa(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;iEa(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^o;n=xrc(h|g,m|o,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=q|8;q=j+g|0;n=q|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^q;m=xrc(o|h,n|q,((o^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=m;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function _xa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;hEa(g|0,b+e|0,16,e);jEa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=xrc(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=G;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=xrc(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function $xa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;hEa(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;iEa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=xrc(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=xrc(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function aya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+e|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=b+f|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=f+e|0;e=b+g|0;b=e|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[f+4>>2]=e;return}function bya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;eEa(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=xrc(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=G;h=b+e|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=xrc(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=G;n=e<<1;m=b+n|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=xrc(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=G;l=e*3|0;e=b+l|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=xrc(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=G;i=f;return}function cya(a,b,c){a=a|0;b=b|0;c=c|0;eEa(a,b,c,c);return}function dya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;eEa(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=xrc(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=G;h=b+(e+2)|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=xrc(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=G;n=e<<1;m=b+(n+2)|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=xrc(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=G;l=e*3|0;e=b+(l+2)|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=xrc(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=G;i=f;return}function eya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;fEa(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=p^s;h=xrc(l|g,p|s,((l^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=h;c[k+4>>2]=G;k=c[o>>2]|0;h=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;l=c[o+4>>2]|0;o=l^h;s=xrc(g|k,l|h,((g^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+e|0;c[o>>2]=s;c[o+4>>2]=G;o=c[n>>2]|0;s=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;g=c[n+4>>2]|0;n=g^s;h=xrc(k|o,g|s,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+m|0;c[n>>2]=h;c[n+4>>2]=G;n=c[q>>2]|0;h=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;m=c[q+4>>2]|0;q=m^h;o=xrc(j|n,m|h,((j^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+(e*3|0)|0;c[q>>2]=o;c[q+4>>2]=G;i=f;return}function fya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;eEa(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;fEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=r^g;q=xrc(k|n,r|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=q;c[m+4>>2]=G;m=j+8|0;q=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;r=xrc(k|q,g|n,((k^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^q;g=xrc(k|r,n|q,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=r;c[m+4>>2]=G;i=f;return}function gya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;eEa(f,b,8,d);gEa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=xrc(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=G;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=xrc(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=G;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=xrc(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=xrc(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=G;i=e;return}function hya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;eEa(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;fEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=xrc(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=G;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=G;i=f;return}function iya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+72|0;g=f|0;h=g|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=g+8|0;h=e-k|0;m=b+h|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=m;m=b;l=m|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=m;m=g+24|0;l=b+e|0;n=l|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=l;l=g+32|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=n;n=g+40|0;l=m+e|0;m=b+(l-k)|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;m=g+48|0;n=l+e|0;l=b+(n-k)|0;o=l|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=l;l=g+56|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[l+4>>2]=n;n=g+64|0;g=b+(h+m)|0;m=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=g;fEa(a,j,e);i=f;return}function jya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;fEa(k,o,8);gEa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=xrc(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=G;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=xrc(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=G;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=xrc(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=xrc(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=G;i=f;return}function kya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+144|0;gEa(a,d|0,b,c,c);i=d;return}function lya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;fEa(k,o,8);gEa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=xrc(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=G;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=xrc(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=G;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=xrc(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=xrc(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=G;i=f;return}function mya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;fEa(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=s^g;t=xrc(o|l,s|g,((o^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=t;c[k+4>>2]=G;k=c[n>>2]|0;t=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^t;g=xrc(l|k,o|t,((l^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=g;c[n+4>>2]=G;n=c[q>>2]|0;g=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;l=c[q+4>>2]|0;q=l^g;t=xrc(k|n,l|g,((k^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+m|0;c[q>>2]=t;c[q+4>>2]=G;q=c[p>>2]|0;t=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;m=c[p+4>>2]|0;p=m^t;n=xrc(j|q,m|t,((j^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(e*3|0)|0;c[p>>2]=n;c[p+4>>2]=G;i=f;return}function nya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;eEa(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;fEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=xrc(k|n,o|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;o=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=o;c[m+4>>2]=G;m=j+16|0;o=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|o,n|r,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+p|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;p=c[m+4>>2]|0;m=p^g;o=xrc(l|j,p|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=o;c[m+4>>2]=G;i=f;return}function oya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;eEa(f,b+d|0,8,d);gEa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=xrc(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=G;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=xrc(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=G;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=xrc(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=xrc(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=G;i=e;return}function pya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;eEa(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;fEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=xrc(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=G;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=G;i=f;return}function qya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;return}function rya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;nEa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+e|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function sya(a,b,c){a=a|0;b=b|0;c=c|0;nEa(a,b,c,c);return}function tya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;nEa(g,b,4,e);h=b+2|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+(e+2)|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function uya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;oEa(h,j,4);n=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|n)-((j^n)>>>1&2147450879);n=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|n)-((m^n)>>>1&2147450879);i=f;return}function vya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;nEa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;oEa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function wya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+64|0;f=e+56|0;g=i;i=i+8|0;nEa(f,b,4,d);pEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function xya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;nEa(h,b,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;oEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function yya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+32|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;oEa(a,h,e);i=f;return}function zya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+56|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;oEa(j,l,4);pEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function Aya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+56|0;pEa(a,d|0,b,c,c);i=d;return}function Bya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+56|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=2-m|0;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+2|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+2)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e+e|0;m=b+(p+n)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;oEa(j,l,4);pEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function Cya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-k)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;oEa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2147450879);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2147450879);i=f;return}function Dya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;l=b+e|0;nEa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;oEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function Eya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+64|0;f=e+56|0;g=i;i=i+8|0;nEa(f,b+d|0,4,d);pEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function Fya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;nEa(h,b+e|0,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;oEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function Gya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=c[i+4>>2]|0;l=f;m=l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l^k;o=xrc(n|j,l|k,((n^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[i>>2]=o;c[i+4>>2]=G;i=g+8|0;o=c[i>>2]|0;m=c[i+4>>2]|0;j=f+8|0;n=j|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j^m;l=xrc(k|o,j|m,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[i>>2]=l;c[i+4>>2]=G;i=h+1|0;if((i|0)<16){f=f+e|0;g=g+e|0;h=i}else{break}}h=b+16|0;b=a+16|0;a=0;while(1){g=b;f=c[g>>2]|0;i=c[g+4>>2]|0;l=h;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^i;k=xrc(o|f,l|i,((o^f)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[g>>2]=k;c[g+4>>2]=G;g=b+8|0;k=c[g>>2]|0;n=c[g+4>>2]|0;f=h+8|0;o=f|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f+4|0;f=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f^n;l=xrc(i|k,f|n,((i^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[g>>2]=l;c[g+4>>2]=G;g=a+1|0;if((g|0)<16){h=h+e|0;b=b+e|0;a=g}else{break}}return}function Hya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;hEa(g|0,b,32,e);hEa(g+16|0,b+16|0,32,e);h=e<<3;hEa(g+256|0,b+h|0,32,e);hEa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=xrc(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ca(u,e)|0;l=h+16|0;q=b+l|0;m=q|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=u<<5;s=g+(m|16)|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+l|0;l=c[t>>2]|0;j=c[t+4>>2]|0;p=s^q;k=xrc(r|o,s|q,((r^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;o=p^j;r=xrc(k|l,p|j,((k^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;t=h+24|0;h=b+t|0;r=h|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+(m|24)|0;m=r|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r+4|0;r=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+t|0;t=c[m>>2]|0;k=c[m+4>>2]|0;j=r^h;p=xrc(l|o,r|h,((l^o)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;o=j^k;l=xrc(p|t,j|k,((p^t)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function Iya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;mEa(a,b,c,c);mEa(a+16|0,b+16|0,c,c);d=c<<3;mEa(a+d|0,b+d|0,c,c);e=d+16|0;mEa(a+e|0,b+e|0,c,c);return}function Jya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;hEa(g|0,b,32,e);hEa(g+16|0,b+16|0,32,e);h=e<<3;hEa(g+256|0,b+h|0,32,e);hEa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=xrc(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ca(u,e)|0;l=b+(h+18)|0;q=l|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=u<<5;j=g+(q|16)|0;s=j|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=a+(h+16)|0;r=c[s>>2]|0;o=c[s+4>>2]|0;p=j^l;k=xrc(t|m,j|l,((t^m)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;m=p^o;t=xrc(k|r,p|o,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[s>>2]=t;c[s+4>>2]=G;s=b+(h+26)|0;t=s|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=g+(q|24)|0;q=t|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=t+4|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=a+(h+24)|0;h=c[q>>2]|0;k=c[q+4>>2]|0;o=t^s;p=xrc(r|m,t|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;m=o^k;r=xrc(p|h,o|k,((p^h)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function Kya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}iEa(j|0,h+64|0,32,32);iEa(j+16|0,h+80|0,32,32);iEa(j+256|0,h+320|0,32,32);iEa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=xrc(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;m=t^s;n=xrc(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=G;q=e|8;e=h+(q+64)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=xrc(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^u;r=xrc(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+80)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=xrc(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=G;m=n^e;t=xrc(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h+((l|8)+80)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=xrc(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^k;s=xrc(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Lya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;hEa(j|0,e,32,f);hEa(j+16|0,e+16|0,32,f);l=f<<3;hEa(j+256|0,e+l|0,32,f);hEa(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=xrc(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=xrc(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^m;t=xrc(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=xrc(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^e;s=xrc(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Mya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;hEa(h|0,b,32,e);k=b+16|0;hEa(h+16|0,k,32,e);l=e<<3;m=b+l|0;hEa(h+256|0,m,32,e);n=b+(l+16)|0;hEa(h+272|0,n,32,e);l=g|0;jEa(j|0,l,b,32,32,e);b=g+16|0;jEa(j+16|0,b,k,32,32,e);jEa(j+256|0,l,m,32,32,e);jEa(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(n,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^m;t=xrc(o|k,l|m,((o^k)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;k=s^r;o=xrc(t|q,s|r,((t^q)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=b|8;b=h+p|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=xrc(q|k,o|b,((q^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;k=r^t;q=xrc(s|g,r|t,((s^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;p=n+1|0;if((p|0)<16){n=p}else{u=0;break}}do{n=u<<5;p=n|16;q=h+p|0;k=q|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+p|0;p=k|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=k^q;m=xrc(s|g,k|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;g=o^b;s=xrc(m|r,o|b,((m^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=G;t=n|24;n=h+t|0;s=n|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;m=c[t+4>>2]|0;b=s^n;o=xrc(r|g,s|n,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;g=b^m;r=xrc(o|p,b|m,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function Nya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;hEa(j|0,e,32,f);hEa(j+16|0,e+16|0,32,f);l=f<<3;hEa(j+256|0,e+l|0,32,f);hEa(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=xrc(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=xrc(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^m;t=xrc(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=xrc(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^e;s=xrc(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Oya(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m+4|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}lEa(b,g+64|0,e,32);lEa(b+16|0,g+80|0,e,32);j=e<<3;lEa(b+j|0,g+320|0,e,32);lEa(b+(j+16)|0,g+336|0,e,32);i=f;return}function Pya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=j|0;jEa(l|0,h,e,32,32,f);o=j+16|0;jEa(l+16|0,o,e+16|0,32,32,f);j=f<<3;jEa(l+256|0,h,e+j|0,32,32,f);jEa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=xrc(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;n=t^q;s=xrc(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=G;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=xrc(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=G;n=q^u;r=xrc(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=G;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=xrc(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^e;t=xrc(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=xrc(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^o;q=xrc(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Qya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+1344|0;e=d|0;f=e|0;kEa(a,f,b,c,32,c);g=e+16|0;kEa(a+16|0,g,b+16|0,c,32,c);e=c<<3;kEa(a+e|0,f,b+e|0,c,32,c);f=e+16|0;kEa(a+f|0,g,b+f|0,c,32,c);i=d;return}function Rya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+3040|0;h=g|0;j=g+672|0;k=g+2016|0;l=g+2528|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=j|0;jEa(l|0,h,e,32,32,f);o=j+16|0;jEa(l+16|0,o,e+16|0,32,32,f);j=f<<3;jEa(l+256|0,h,e+j|0,32,32,f);jEa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=xrc(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;n=t^q;s=xrc(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=G;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=xrc(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=G;n=q^u;r=xrc(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=G;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=xrc(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^e;t=xrc(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=xrc(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^o;q=xrc(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Sya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}iEa(j|0,h+64|0,32,32);iEa(j+16|0,h+80|0,32,32);iEa(j+256|0,h+320|0,32,32);iEa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=xrc(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;m=t^s;n=xrc(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=G;q=e|8;e=h+(q+96)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=xrc(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^u;r=xrc(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+112)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=xrc(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=G;m=n^e;t=xrc(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h+((l|8)+112)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=xrc(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^k;s=xrc(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Tya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;hEa(j|0,e+f|0,32,f);l=f+16|0;hEa(j+16|0,e+l|0,32,f);m=f<<3;hEa(j+256|0,e+(m+f)|0,32,f);hEa(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=xrc(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=xrc(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^l;t=xrc(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=xrc(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=G;n=l^e;s=xrc(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Uya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+2368|0;g=f|0;h=f+1344|0;j=f+1856|0;hEa(h|0,b+e|0,32,e);hEa(h+16|0,b+(e+16)|0,32,e);k=e<<3;hEa(h+256|0,b+(k+e)|0,32,e);l=k+16|0;hEa(h+272|0,b+(l+e)|0,32,e);m=g|0;jEa(j|0,m,b,32,32,e);n=g+16|0;jEa(j+16|0,n,b+16|0,32,32,e);jEa(j+256|0,m,b+k|0,32,32,e);jEa(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(l,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=k^n;t=xrc(o|m,k|n,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=b|8;b=h+p|0;o=b|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=xrc(q|m,o|b,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|g,r|t,((s^g)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;p=l+1|0;if((p|0)<16){l=p}else{u=0;break}}do{l=u<<5;p=l|16;q=h+p|0;m=q|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+p|0;p=m|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=m^q;n=xrc(s|g,m|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;g=o^b;s=xrc(n|r,o|b,((n^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=G;t=l|24;l=h+t|0;s=l|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+4|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;n=c[t+4>>2]|0;b=s^l;o=xrc(r|g,s|l,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;g=b^n;r=xrc(o|p,b|n,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function Vya(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;hEa(j|0,e+f|0,32,f);l=f+16|0;hEa(j+16|0,e+l|0,32,f);m=f<<3;hEa(j+256|0,e+(m+f)|0,32,f);hEa(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}iEa(k|0,h+64|0,32,32);iEa(k+16|0,h+80|0,32,32);iEa(k+256|0,h+320|0,32,32);iEa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=xrc(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=xrc(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^l;t=xrc(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=xrc(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=G;n=l^e;s=xrc(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function Wya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;j=f;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j^i;m=xrc(l|h,j|i,((l^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[g>>2]=m;c[g+4>>2]=G;g=b+8|0;m=c[g>>2]|0;k=c[g+4>>2]|0;h=f+8|0;l=h|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h^k;j=xrc(i|m,h|k,((i^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[g>>2]=j;c[g+4>>2]=G;g=a+1|0;if((g|0)<8){f=f+e|0;b=b+e|0;a=g}else{break}}return}function Xya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;hEa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=xrc(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Yya(a,b,c){a=a|0;b=b|0;c=c|0;mEa(a,b,c,c);return}function Zya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;hEa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=xrc(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function _ya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;iEa(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(p,e)|0;h=a+o|0;q=c[h>>2]|0;r=c[h+4>>2]|0;s=k^b;t=xrc(m|g,k|b,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[h>>2]=m;c[h+4>>2]=G;h=n|8;n=l+h|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=j+h|0;h=n|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(o+8)|0;o=c[h>>2]|0;t=c[h+4>>2]|0;r=n^g;s=xrc(q|m,n|g,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[h>>2]=q;c[h+4>>2]=G;p=p+1|0;}while((p|0)<8);i=f;return}function $ya(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;hEa(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;iEa(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;m=a+b|0;q=c[m>>2]|0;r=c[m+4>>2]|0;s=o^n;t=xrc(h|g,o|n,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;h=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=p|8;p=j+m|0;h=p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+m|0;m=h|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+(b+8)|0;b=c[m>>2]|0;t=c[m+4>>2]|0;r=h^p;s=xrc(q|g,h|p,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function aza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;hEa(g|0,b,16,e);jEa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=xrc(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=xrc(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function bza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;hEa(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;iEa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=xrc(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=xrc(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function cza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;lEa(a,j,e,16);i=f;return}function dza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;iEa(k|0,m,16,16);jEa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(b,e)|0;h=a+p|0;n=c[h>>2]|0;r=c[h+4>>2]|0;s=q^m;t=xrc(g|o,q|m,((g^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;o=s^r;g=xrc(t|n,s|r,((t^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=g;c[h+4>>2]=G;h=j|8;j=k+h|0;g=j|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+h|0;h=g|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(p+8)|0;p=c[h>>2]|0;t=c[h+4>>2]|0;r=g^j;s=xrc(n|o,g|j,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;o=r^t;n=xrc(s|p,r|t,((s^p)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=n;c[h+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function eza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+416|0;kEa(a,d|0,b,c,16,c);i=d;return}function fza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+416|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;iEa(k|0,m,16,16);jEa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=ca(b,e)|0;n=a+q|0;o=c[n>>2]|0;r=c[n+4>>2]|0;s=h^m;t=xrc(g|p,h|m,((g^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;p=s^r;g=xrc(t|o,s|r,((t^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=j|8;j=k+n|0;g=j|0;p=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+n|0;n=g|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+4|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(q+8)|0;q=c[n>>2]|0;t=c[n+4>>2]|0;r=g^j;s=xrc(o|p,g|j,((o^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;p=r^t;o=xrc(s|q,r|t,((s^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=o;c[n+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function gza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;iEa(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(o,e)|0;l=a+b|0;q=c[l>>2]|0;r=c[l+4>>2]|0;s=m^g;t=xrc(h|p,m|g,((h^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;p=s^r;h=xrc(t|q,s|r,((t^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[l>>2]=h;c[l+4>>2]=G;l=n|8;n=k+l|0;h=c[n>>2]|0;p=c[n+4>>2]|0;n=j+l|0;l=n|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(b+8)|0;b=c[l>>2]|0;t=c[l+4>>2]|0;r=n^p;s=xrc(q|h,n|p,((q^h)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;h=r^t;q=xrc(s|b,r|t,((s^b)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;o=o+1|0;}while((o|0)<8);i=f;return}function hza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;hEa(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;iEa(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;p=c[n>>2]|0;r=c[n+4>>2]|0;s=m^o;t=xrc(h|g,m|o,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;h=xrc(t|p,s|r,((t^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=h;c[n+4>>2]=G;n=q|8;q=j+n|0;h=q|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=h^q;s=xrc(p|g,h|q,((p^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;p=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=p;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function iza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+672|0;g=f+416|0;h=f+544|0;hEa(g|0,b+e|0,16,e);jEa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=xrc(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=xrc(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function jza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;hEa(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;iEa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=xrc(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=xrc(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function kza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=c[f>>2]|0;h=c[f+4>>2]|0;i=b;j=i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i^h;l=xrc(k|g,i|h,((k^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[f>>2]=l;c[f+4>>2]=G;f=a+e|0;l=c[f>>2]|0;j=c[f+4>>2]|0;g=b+e|0;k=g|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^j;i=xrc(h|l,g|j,((h^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[f>>2]=i;c[f+4>>2]=G;f=e<<1;i=a+f|0;k=c[i>>2]|0;l=c[i+4>>2]|0;h=b+f|0;j=h|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h^l;m=xrc(g|k,h|l,((g^k)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[i>>2]=m;c[i+4>>2]=G;i=f+e|0;e=a+i|0;a=c[e>>2]|0;f=c[e+4>>2]|0;m=b+i|0;i=m|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m^f;j=xrc(b|a,m|f,((b^a)>>>1|i<<31)&2147450879,(i>>>1|0<<31)&2147450879)|0;c[e>>2]=j;c[e+4>>2]=G;return}function lza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;eEa(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=xrc(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;l=p^o;k=xrc(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=G;h=b+e|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=xrc(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^p;n=xrc(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=G;k=e<<1;n=b+k|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=xrc(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;o=h^j;m=xrc(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=G;l=e*3|0;e=b+l|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=xrc(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;m=k^a;g=xrc(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=G;i=f;return}function mza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d>>1;d=0;g=a;a=c;while(1){c=a+2|0;h=a-2|0;i=a+4|0;j=a+6|0;k=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[i>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<1024>>>0){l=k}else{l=-k>>31&1023}b[g>>1]=((e[g>>1]|0)+1+l|0)>>>1;k=g+2|0;m=a+8|0;n=(((e[i>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[h>>1]|0)+(((e[j>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[m>>1]|0)>>5;if(n>>>0<1024>>>0){o=n}else{o=-n>>31&1023}b[k>>1]=((e[k>>1]|0)+1+o|0)>>>1;k=g+4|0;n=a+10|0;h=(((e[j>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[m>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(h>>>0<1024>>>0){p=h}else{p=-h>>31&1023}b[k>>1]=((e[k>>1]|0)+1+p|0)>>>1;k=g+6|0;h=(((e[m>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(h>>>0<1024>>>0){q=h}else{q=-h>>31&1023}b[k>>1]=((e[k>>1]|0)+1+q|0)>>>1;k=d+1|0;if((k|0)<4){d=k;g=g+(f<<1)|0;a=a+(f<<1)|0}else{break}}return}function nza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;eEa(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=xrc(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;l=p^o;k=xrc(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=G;h=b+(e+2)|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=xrc(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^p;n=xrc(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=G;k=e<<1;n=b+(k+2)|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=xrc(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;o=h^j;m=xrc(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=G;l=e*3|0;e=b+(l+2)|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=xrc(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;m=k^a;g=xrc(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=G;i=f;return}function oza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;fEa(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=a;h=c[k>>2]|0;b=c[k+4>>2]|0;r=p^s;t=xrc(l|g,p|s,((l^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^b;l=xrc(t|h,r|b,((t^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[k>>2]=l;c[k+4>>2]=G;k=c[o>>2]|0;l=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;h=c[o+4>>2]|0;o=a+e|0;t=c[o>>2]|0;b=c[o+4>>2]|0;r=h^l;s=xrc(g|k,h|l,((g^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;k=r^b;g=xrc(s|t,r|b,((s^t)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[o>>2]=g;c[o+4>>2]=G;o=c[n>>2]|0;g=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=a+m|0;m=c[n>>2]|0;s=c[n+4>>2]|0;b=t^g;r=xrc(k|o,t|g,((k^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;o=b^s;k=xrc(r|m,b|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[n>>2]=k;c[n+4>>2]=G;n=c[q>>2]|0;k=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;o=c[q+4>>2]|0;q=a+(e*3|0)|0;e=c[q>>2]|0;a=c[q+4>>2]|0;m=o^k;r=xrc(j|n,o|k,((j^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^a;j=xrc(r|e,m|a,((r^e)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=j;c[q+4>>2]=G;i=f;return}function pza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;eEa(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;fEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=a;q=c[m>>2]|0;h=c[m+4>>2]|0;b=r^g;p=xrc(k|n,r|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(p|q,b|h,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;q=c[m>>2]|0;p=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=p^n;r=xrc(q|k,p|n,((q^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;q=xrc(r|h,g|b,((r^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=G;m=j+16|0;q=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;r=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=r^k;n=xrc(h|q,r|k,((h^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;q=g^b;h=xrc(n|o,g|b,((n^o)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;q=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=q^h;n=xrc(l|j,q|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function qza(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;eEa(f,b,8,d);gEa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=xrc(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;b=o^n;g=xrc(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=G;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=xrc(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;g=k^o;m=xrc(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=G;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=xrc(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;m=b^k;n=xrc(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=xrc(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;f=o^a;h=xrc(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=G;i=e;return}function rza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;eEa(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;fEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=xrc(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=xrc(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=xrc(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function sza(a,f,g){a=a|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=j|0;l=j+16|0;m=g<<1;n=f+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=n;n=j+8|0;k=g-m|0;o=f+k|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=f;n=o|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=p;c[l+4>>2]=o;o=j+24|0;n=f+g|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=n;n=j+32|0;o=m+g+g|0;q=f+(o-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=j+40|0;n=o+g|0;o=f+(n-m)|0;r=o|0;s=o+4|0;o=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=o;o=j+48|0;q=n+g|0;n=f+(q-m)|0;r=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=n;n=j+56|0;o=q+g|0;q=f+(o-m)|0;m=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=q;q=j+64|0;j=f+(k+o)|0;o=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=j;j=g>>1;g=j<<1;q=j*3|0;o=l;l=a;a=1;k=p&65535;while(1){p=e[o-8>>1]|0;f=k&65535;n=e[o+8>>1]|0;m=e[o+16>>1]|0;r=e[o+24>>1]|0;s=e[o+32>>1]|0;t=e[o+40>>1]|0;u=e[o+48>>1]|0;v=(e[o-16>>1]|0)+16+((n+f|0)*20|0)+r+((m+p|0)*-5|0)>>5;if(v>>>0<1024>>>0){w=v}else{w=-v>>31&1023}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;v=l+(j<<1)|0;x=p+16+((m+n|0)*20|0)+s+((r+f|0)*-5|0)>>5;if(x>>>0<1024>>>0){y=x}else{y=-x>>31&1023}b[v>>1]=((e[v>>1]|0)+1+y|0)>>>1;v=l+(g<<1)|0;x=f+16+((r+m|0)*20|0)+t+((s+n|0)*-5|0)>>5;if(x>>>0<1024>>>0){z=x}else{z=-x>>31&1023}b[v>>1]=((e[v>>1]|0)+1+z|0)>>>1;v=l+(q<<1)|0;x=n+16+((s+r|0)*20|0)+u+((t+m|0)*-5|0)>>5;if(x>>>0<1024>>>0){A=x}else{A=-x>>31&1023}b[v>>1]=((e[v>>1]|0)+1+A|0)>>>1;v=o+2|0;if((a|0)>=4){break}o=v;l=l+2|0;a=a+1|0;k=b[v>>1]|0}i=h;return}function tza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;fEa(k,o,8);gEa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;s=c[n+4>>2]|0;r=o^j;h=xrc(l|b,o|j,((l^b)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;b=r^s;l=xrc(h|g,r|s,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;s=c[n>>2]|0;r=c[n+4>>2]|0;j=h^b;o=xrc(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^r;g=xrc(o|s,j|r,((o^s)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;s=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;r=c[n+4>>2]|0;j=o^l;b=xrc(s|g,o|l,((s^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;g=j^r;s=xrc(b|p,j|r,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=s;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;s=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^s;b=xrc(m|k,g|s,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;k=p^a;m=xrc(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;i=f;return}function uza(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+144|0;g=f|0;h=d>>1;d=h<<1;j=c+(-d<<1)|0;c=0;k=g|0;while(1){l=b[j>>1]|0;m=b[j+2>>1]|0;n=b[j-2>>1]|0;o=b[j+4>>1]|0;p=b[j+6>>1]|0;b[k>>1]=(((((m+l&65535)*20&65535)-10230&65535)+(b[j-4>>1]|0)&65535)+((o+n&65535)*-5&65535)&65535)+p;q=b[j+8>>1]|0;b[k+2>>1]=(((((o+m&65535)*20&65535)-10230&65535)+n&65535)+((p+l&65535)*-5&65535)&65535)+q;n=b[j+10>>1]|0;b[k+4>>1]=(((((p+o&65535)*20&65535)-10230&65535)+l&65535)+((q+m&65535)*-5&65535)&65535)+n;b[k+6>>1]=(((((q+p&65535)*20&65535)-10230&65535)+m&65535)+((n+o&65535)*-5&65535)&65535)+(b[j+12>>1]|0);o=c+1|0;if((o|0)<9){j=j+(h<<1)|0;c=o;k=k+16|0}else{break}}k=h*3|0;c=a;a=0;j=g+32|0;while(1){g=b[j-16>>1]|0;o=b[j>>1]|0;n=o+10230|0;m=b[j+16>>1]|0;p=m+10230|0;q=(b[j+32>>1]|0)+10230|0;l=(b[j+48>>1]|0)+10230|0;r=(b[j+64>>1]|0)+10230|0;s=(b[j+80>>1]|0)+10230|0;t=b[j+96>>1]|0;u=(b[j-32>>1]|0)+10742+((p+n|0)*20|0)+l+((g+10230+q|0)*-5|0)>>10;if(u>>>0<1024>>>0){v=u}else{v=-u>>31&1023}b[c>>1]=((e[c>>1]|0)+1+v|0)>>>1;u=c+(h<<1)|0;w=g+10742+((q+p|0)*20|0)+r+((l+n|0)*-5|0)>>10;if(w>>>0<1024>>>0){x=w}else{x=-w>>31&1023}b[u>>1]=((e[u>>1]|0)+1+x|0)>>>1;u=c+(d<<1)|0;w=o+10742+((l+q|0)*20|0)+s+((r+p|0)*-5|0)>>10;if(w>>>0<1024>>>0){y=w}else{y=-w>>31&1023}b[u>>1]=((e[u>>1]|0)+1+y|0)>>>1;u=c+(k<<1)|0;w=m+20972+t+((r+l|0)*20|0)+((s+q|0)*-5|0)>>10;if(w>>>0<1024>>>0){z=w}else{z=-w>>31&1023}b[u>>1]=((e[u>>1]|0)+1+z|0)>>>1;u=a+1|0;if((u|0)<4){c=c+2|0;a=u;j=j+2|0}else{break}}i=f;return}function vza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+144|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;fEa(k,o,8);gEa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;t=c[n+4>>2]|0;s=o^j;h=xrc(l|b,o|j,((l^b)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;b=s^t;l=xrc(h|g,s|t,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;t=c[n>>2]|0;s=c[n+4>>2]|0;j=h^b;o=xrc(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^s;g=xrc(o|t,j|s,((o^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;t=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;s=c[n+4>>2]|0;j=o^l;b=xrc(t|g,o|l,((t^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;g=j^s;t=xrc(b|p,j|s,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=t;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^t;b=xrc(m|k,g|t,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;k=p^a;m=xrc(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;i=f;return}function wza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;fEa(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=a;t=c[k>>2]|0;h=c[k+4>>2]|0;b=s^g;r=xrc(o|l,s|g,((o^l)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;l=b^h;o=xrc(r|t,b|h,((r^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=o;c[k+4>>2]=G;k=c[n>>2]|0;o=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;t=c[n+4>>2]|0;n=a+e|0;r=c[n>>2]|0;h=c[n+4>>2]|0;b=t^o;g=xrc(l|k,t|o,((l^k)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;k=b^h;l=xrc(g|r,b|h,((g^r)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=c[q>>2]|0;l=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;r=c[q+4>>2]|0;q=a+m|0;m=c[q>>2]|0;g=c[q+4>>2]|0;h=r^l;b=xrc(k|n,r|l,((k^n)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;n=h^g;k=xrc(b|m,h|g,((b^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=k;c[q+4>>2]=G;q=c[p>>2]|0;k=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;n=c[p+4>>2]|0;p=a+(e*3|0)|0;e=c[p>>2]|0;a=c[p+4>>2]|0;m=n^k;b=xrc(j|q,n|k,((j^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;q=m^a;j=xrc(b|e,m|a,((b^e)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[p>>2]=j;c[p+4>>2]=G;i=f;return}function xza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;eEa(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;fEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=o^g;q=xrc(k|n,o|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;o=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(o|h,g|b,((o^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;o=c[m+4>>2]|0;m=a+p|0;p=c[m>>2]|0;b=c[m+4>>2]|0;g=o^k;n=xrc(h|r,o|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|p,g|b,((n^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;p=r^h;n=xrc(l|j,r|h,((l^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;j=p^a;l=xrc(n|e,p|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function yza(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+176|0;f=e+144|0;g=f|0;h=i;i=i+32|0;j=h|0;eEa(f,b+d|0,8,d);gEa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=xrc(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;b=o^n;g=xrc(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=G;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=xrc(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;g=k^o;m=xrc(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=G;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=xrc(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;m=b^k;n=xrc(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=xrc(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;f=o^a;h=xrc(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=G;i=e;return}function zza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;eEa(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;fEa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=xrc(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=xrc(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=xrc(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function Aza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=e+8|0;h=b+f|0;g=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=h;h=e<<1;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;i=b+g|0;h=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=i;i=j+e|0;j=b+i|0;f=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+i|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=j;j=i+8|0;h=b+j|0;f=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=h;h=i+e|0;i=b+h|0;g=i|0;f=i+4|0;i=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[f+4>>2]=i;i=h+8|0;f=b+i|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+i|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+e|0;h=b+f|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+f|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+8|0;g=b+h|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=g+8|0;j=b+f|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=g+e|0;g=b+j|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+j|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=j+8|0;j=b+g|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+g|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=b+16|0;h=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+16|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=j;j=b+24|0;i=j|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+24|0;c[h>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[h+4>>2]=j;j=e+16|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=e+24|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;f=b+h|0;g=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[j+4>>2]=f;f=h+8|0;j=b+f|0;g=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[i+4>>2]=j;j=h+e|0;h=b+j|0;i=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+j|0;c[g>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[g+4>>2]=h;h=j+8|0;g=b+h|0;i=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+h|0;c[f>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[f+4>>2]=g;g=j+e|0;j=b+g|0;f=j|0;i=j+4|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+g|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=j;j=g+8|0;i=b+j|0;f=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+j|0;c[h>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[h+4>>2]=i;i=g+e|0;g=b+i|0;h=g|0;f=g+4|0;g=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+i|0;c[f>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[f+4>>2]=g;g=i+8|0;f=b+g|0;h=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[j+4>>2]=f;f=i+e|0;i=b+f|0;j=i|0;h=i+4|0;i=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+f|0;c[h>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[h+4>>2]=i;i=f+8|0;h=b+i|0;j=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+i|0;c[g>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[g+4>>2]=h;h=f+e|0;e=b+h|0;f=e|0;g=e+4|0;e=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+h|0;c[g>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[g+4>>2]=e;e=h+8|0;h=b+e|0;b=h|0;g=h+4|0;h=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[g+4>>2]=h;return}function Bza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;XDa(g|0,b,32,e);XDa(g+16|0,b+16|0,32,e);h=e<<3;XDa(g+256|0,b+h|0,32,e);XDa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=xrc(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ca(r,e)|0;l=h+16|0;k=b+l|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r<<5;p=g+(o|16)|0;j=p|0;q=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p+4|0;p=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=p^k;n=xrc(q|m,p|k,((q^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+l|0;c[j>>2]=n;c[j+4>>2]=G;j=h+24|0;h=b+j|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+(o|24)|0;o=n|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^h;q=xrc(m|l,n|h,((m^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;r=r+1|0;}while((r|0)<16);i=f;return}function Cza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;XDa(a,b,c,c);XDa(a+16|0,b+16|0,c,c);d=c<<3;XDa(a+d|0,b+d|0,c,c);e=d+16|0;XDa(a+e|0,b+e|0,c,c);return}function Dza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+512|0;g=f|0;XDa(g|0,b,32,e);XDa(g+16|0,b+16|0,32,e);h=e<<3;XDa(g+256|0,b+h|0,32,e);XDa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=xrc(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{r=0;break}}do{h=ca(r,e)|0;l=b+(h+18)|0;k=l|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=l+4|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=r<<5;m=g+(k|16)|0;p=m|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^l;q=xrc(o|j,m|l,((o^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(h+16)|0;c[p>>2]=q;c[p+4>>2]=G;p=b+(h+26)|0;q=p|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(k|24)|0;k=q|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q^p;l=xrc(o|j,q|p,((o^j)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(h+24)|0;c[k>>2]=l;c[k+4>>2]=G;r=r+1|0;}while((r|0)<16);i=f;return}function Eza(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}YDa(j|0,h+64|0,32,32);YDa(j+16|0,h+80|0,32,32);YDa(j+256|0,h+320|0,32,32);YDa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=xrc(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=G;m=e|8;e=h+(m+64)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=xrc(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+64)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=xrc(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=G;n=l|24;l=h+(n+64)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=xrc(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Fza(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;XDa(j|0,e,32,f);XDa(j+16|0,e+16|0,32,f);l=f<<3;XDa(j+256|0,e+l|0,32,f);XDa(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=xrc(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=xrc(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=xrc(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=G;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=xrc(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Gza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;XDa(h|0,b,32,e);k=b+16|0;XDa(h+16|0,k,32,e);l=e<<3;m=b+l|0;XDa(h+256|0,m,32,e);n=b+(l+16)|0;XDa(h+272|0,n,32,e);l=g|0;ZDa(j|0,l,b,32,32,e);b=g+32|0;ZDa(j+16|0,b,k,32,32,e);ZDa(j+256|0,l,m,32,32,e);ZDa(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l^m;p=xrc(o|k,l|m,((o^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ca(n,e)|0;k=a+g|0;c[k>>2]=p;c[k+4>>2]=G;k=b|8;b=h+k|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+k|0;k=p|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p+4|0;p=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=p^b;l=xrc(m|o,p|b,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a+(g+8)|0;c[k>>2]=l;c[k+4>>2]=G;k=n+1|0;if((k|0)<16){n=k}else{q=0;break}}do{n=q<<5;k=n|16;l=h+k|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+k|0;k=g|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^l;b=xrc(m|o,g|l,((m^o)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=ca(q,e)|0;o=a+(k+16)|0;c[o>>2]=b;c[o+4>>2]=G;o=n|24;n=h+o|0;b=n|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=n+4|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^n;g=xrc(l|m,b|n,((l^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(k+24)|0;c[o>>2]=g;c[o+4>>2]=G;q=q+1|0;}while((q|0)<16);i=f;return}function Hza(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;XDa(j|0,e,32,f);XDa(j+16|0,e+16|0,32,f);l=f<<3;XDa(j+256|0,e+l|0,32,f);XDa(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^e;o=xrc(p|q,l|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=m|8;m=j+q|0;o=m|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^m;l=xrc(e|p,o|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=l;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;l=j+q|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^l;m=xrc(e|p,n|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=m;c[p+4>>2]=G;p=h|24;h=j+p|0;m=h|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+p|0;p=m|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m^h;n=xrc(l|e,m|h,((l^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Iza(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m+4|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}YDa(b,g+64|0,e,32);YDa(b+16|0,g+80|0,e,32);j=e<<3;YDa(b+j|0,g+320|0,e,32);YDa(b+(j+16)|0,g+336|0,e,32);i=f;return}function Jza(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=j|0;ZDa(l|0,h,e,32,32,f);o=j+32|0;ZDa(l+16|0,o,e+16|0,32,32,f);j=f<<3;ZDa(l+256|0,h,e+j|0,32,32,f);ZDa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=xrc(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=G;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=xrc(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=G;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=xrc(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=G;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=xrc(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=G;t=t+1|0;}while((t|0)<16);i=g;return}function Kza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+2688|0;e=d|0;f=e|0;ZDa(a,f,b,c,32,c);g=e+32|0;ZDa(a+16|0,g,b+16|0,c,32,c);e=c<<3;ZDa(a+e|0,f,b+e|0,c,32,c);f=e+16|0;ZDa(a+f|0,g,b+f|0,c,32,c);i=d;return}function Lza(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=j|0;ZDa(l|0,h,e,32,32,f);o=j+32|0;ZDa(l+16|0,o,e+16|0,32,32,f);j=f<<3;ZDa(l+256|0,h,e+j|0,32,32,f);ZDa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h^o;p=xrc(s|n,h|o,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(j,f)|0;n=b+m|0;c[n>>2]=p;c[n+4>>2]=G;n=e|8;e=k+n|0;p=e|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+4|0;e=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+n|0;n=p|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=p^e;h=xrc(o|s,p|e,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+8)|0;c[n>>2]=h;c[n+4>>2]=G;n=j+1|0;if((n|0)<16){j=n}else{t=0;break}}do{j=t<<5;n=j|16;h=k+n|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+n|0;n=m|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^h;e=xrc(o|s,m|h,((o^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(t,f)|0;s=b+(n+16)|0;c[s>>2]=e;c[s+4>>2]=G;s=j|24;j=k+s|0;e=j|0;o=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+s|0;s=e|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e^j;m=xrc(h|o,e|j,((h^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=b+(n+24)|0;c[s>>2]=m;c[s+4>>2]=G;t=t+1|0;}while((t|0)<16);i=g;return}function Mza(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}YDa(j|0,h+64|0,32,32);YDa(j+16|0,h+80|0,32,32);YDa(j+256|0,h+320|0,32,32);YDa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p^k;q=xrc(n|m,p|k,((n^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(l,f)|0;m=b+o|0;c[m>>2]=q;c[m+4>>2]=G;m=e|8;e=h+(m+96)|0;q=e|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=e+4|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+m|0;m=q|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q^e;p=xrc(k|n,q|e,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=b+(o+8)|0;c[m>>2]=p;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{r=0;break}}do{l=r<<5;m=l|16;p=h+(m+96)|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+m|0;m=o|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o^p;e=xrc(k|n,o|p,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(r,f)|0;n=b+(m+16)|0;c[n>>2]=e;c[n+4>>2]=G;n=l|24;l=h+(n+96)|0;e=l|0;k=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=l+4|0;l=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=j+n|0;n=e|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e^l;o=xrc(p|k,e|l,((p^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=b+(m+24)|0;c[n>>2]=o;c[n+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Nza(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;XDa(j|0,e+f|0,32,f);l=f+16|0;XDa(j+16|0,e+l|0,32,f);m=f<<3;XDa(j+256|0,e+(m+f)|0,32,f);XDa(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=xrc(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=xrc(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=xrc(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=G;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=xrc(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Oza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;XDa(h|0,b+e|0,32,e);XDa(h+16|0,b+(e+16)|0,32,e);k=e<<3;XDa(h+256|0,b+(k+e)|0,32,e);l=k+16|0;XDa(h+272|0,b+(l+e)|0,32,e);m=g|0;ZDa(j|0,m,b,32,32,e);n=g+32|0;ZDa(j+16|0,n,b+16|0,32,32,e);ZDa(j+256|0,m,b+k|0,32,32,e);ZDa(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k^n;p=xrc(o|m,k|n,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=ca(l,e)|0;m=a+g|0;c[m>>2]=p;c[m+4>>2]=G;m=b|8;b=h+m|0;p=b|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+4|0;b=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+m|0;m=p|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^b;k=xrc(n|o,p|b,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(g+8)|0;c[m>>2]=k;c[m+4>>2]=G;m=l+1|0;if((m|0)<16){l=m}else{q=0;break}}do{l=q<<5;m=l|16;k=h+m|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+m|0;m=g|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+4|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g^k;b=xrc(n|o,g|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=ca(q,e)|0;o=a+(m+16)|0;c[o>>2]=b;c[o+4>>2]=G;o=l|24;l=h+o|0;b=l|0;n=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=l+4|0;l=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=j+o|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b^l;g=xrc(k|n,b|l,((k^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(m+24)|0;c[o>>2]=g;c[o+4>>2]=G;q=q+1|0;}while((q|0)<16);i=f;return}function Pza(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;XDa(j|0,e+f|0,32,f);l=f+16|0;XDa(j+16|0,e+l|0,32,f);m=f<<3;XDa(j+256|0,e+(m+f)|0,32,f);XDa(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m^e;o=xrc(p|q,m|e,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(h,f)|0;q=b+n|0;c[q>>2]=o;c[q+4>>2]=G;q=l|8;l=j+q|0;o=l|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+q|0;q=o|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o^l;m=xrc(e|p,o|l,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=b+(n+8)|0;c[q>>2]=m;c[q+4>>2]=G;q=h+1|0;if((q|0)<16){h=q}else{r=0;break}}do{h=r<<5;q=h|16;m=j+q|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+q|0;q=n|0;e=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n^m;l=xrc(e|p,n|m,((e^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(r,f)|0;p=b+(q+16)|0;c[p>>2]=l;c[p+4>>2]=G;p=h|24;h=j+p|0;l=h|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+p|0;p=l|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l^h;n=xrc(m|e,l|h,((m^e)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=b+(q+24)|0;c[p>>2]=n;c[p+4>>2]=G;r=r+1|0;}while((r|0)<16);i=g;return}function Qza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+8|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+8|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=b+e|0;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+e|0;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+(e+8)|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+(e+8)|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=e<<1;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;f=b+g|0;i=f|0;j=f+4|0;f=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+h|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=f;f=b+(g+8)|0;j=f|0;i=f+4|0;f=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(h+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=f;f=g+e|0;g=h+e|0;h=b+f|0;i=h|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+g|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=h;h=b+(f+8)|0;j=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(g+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=h;h=f+e|0;f=g+e|0;g=b+h|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=a+f|0;c[j>>2]=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24;c[j+4>>2]=g;g=b+(h+8)|0;j=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+(f+8)|0;c[i>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;c[i+4>>2]=g;g=h+e|0;h=f+e|0;e=b+g|0;f=e|0;i=e+4|0;e=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+h|0;c[i>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;c[i+4>>2]=e;e=b+(g+8)|0;g=e|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a+(h+8)|0;c[b>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[b+4>>2]=e;return}function Rza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;XDa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=j+8|0;j=b+o|0;q=j|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=j+4|0;j=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^j;k=xrc(p|m,q|j,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+o|0;c[l>>2]=k;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Sza(a,b,c){a=a|0;b=b|0;c=c|0;XDa(a,b,c,c);return}function Tza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;XDa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n^k;q=xrc(p|m,n|k,((p^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+j|0;c[o>>2]=q;c[o+4>>2]=G;o=b+(j+10)|0;q=o|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+(l|8)|0;l=q|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q+4|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=q^o;k=xrc(p|m,q|o,((p^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+(j+8)|0;c[l>>2]=k;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function Uza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;YDa(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k^b;h=xrc(m|g,k|b,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=ca(p,e)|0;g=a+o|0;c[g>>2]=h;c[g+4>>2]=G;g=n|8;n=l+g|0;h=c[n>>2]|0;m=c[n+4>>2]|0;n=j+g|0;g=n|0;b=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^m;k=xrc(b|h,n|m,((b^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(o+8)|0;c[g>>2]=k;c[g+4>>2]=G;p=p+1|0;}while((p|0)<8);i=f;return}function Vza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;XDa(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;YDa(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o^n;m=xrc(h|g,o|n,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=m;c[g+4>>2]=G;g=p|8;p=j+g|0;m=p|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+g|0;g=m|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m+4|0;m=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=m^p;o=xrc(n|h,m|p,((n^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=o;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Wza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;XDa(g|0,b,16,e);ZDa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=xrc(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=G;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=xrc(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function Xza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;XDa(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;YDa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=xrc(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=xrc(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function Yza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;YDa(a,j,e,16);i=f;return}function Zza(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;YDa(k|0,m,16,16);ZDa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q^m;h=xrc(g|o,q|m,((g^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=ca(b,e)|0;o=a+p|0;c[o>>2]=h;c[o+4>>2]=G;o=j|8;j=k+o|0;h=j|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=j+4|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+o|0;o=h|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h^j;q=xrc(m|g,h|j,((m^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+(p+8)|0;c[o>>2]=q;c[o+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function _za(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+832|0;ZDa(a,d|0,b,c,16,c);i=d;return}function $za(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;YDa(k|0,m,16,16);ZDa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h^m;n=xrc(g|p,h|m,((g^p)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=ca(b,e)|0;p=a+q|0;c[p>>2]=n;c[p+4>>2]=G;p=j|8;j=k+p|0;n=j|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^j;h=xrc(m|g,n|j,((m^g)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(q+8)|0;c[p>>2]=h;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function aAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;YDa(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^g;l=xrc(h|p,m|g,((h^p)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(o,e)|0;p=a+b|0;c[p>>2]=l;c[p+4>>2]=G;p=n|8;n=k+p|0;l=c[n>>2]|0;h=c[n+4>>2]|0;n=j+p|0;p=n|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n^h;m=xrc(g|l,n|h,((g^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(b+8)|0;c[p>>2]=m;c[p+4>>2]=G;o=o+1|0;}while((o|0)<8);i=f;return}function bAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;XDa(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;YDa(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m^o;n=xrc(h|g,m|o,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=q|8;q=j+g|0;n=q|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^q;m=xrc(o|h,n|q,((o^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=m;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function cAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;XDa(g|0,b+e|0,16,e);ZDa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^k;p=xrc(o|m,l|k,((o^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=ca(b,e)|0;m=a+n|0;c[m>>2]=p;c[m+4>>2]=G;m=j|8;j=g+m|0;p=j|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=h+m|0;m=p|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=p^j;l=xrc(k|o,p|j,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(n+8)|0;c[m>>2]=l;c[m+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function dAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;XDa(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;YDa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p^o;n=xrc(m|g,p|o,((m^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=ca(l,e)|0;g=a+b|0;c[g>>2]=n;c[g+4>>2]=G;g=h|8;h=j+g|0;n=h|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k+g|0;g=n|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n+4|0;n=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=n^h;p=xrc(o|m,n|h,((o^m)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=a+(b+8)|0;c[g>>2]=p;c[g+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function eAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b;g=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a;c[h>>2]=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24;c[h+4>>2]=f;f=b+e|0;h=f|0;g=f+4|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=a+e|0;c[g>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[g+4>>2]=f;f=e<<1;g=b+f|0;h=g|0;i=g+4|0;g=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=a+f|0;c[i>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[i+4>>2]=g;g=f+e|0;e=b+g|0;b=e|0;f=e+4|0;e=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=a+g|0;c[f>>2]=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24;c[f+4>>2]=e;return}function fAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;UDa(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=xrc(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=G;h=b+e|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=xrc(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=G;n=e<<1;m=b+n|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=xrc(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=G;l=e*3|0;e=b+l|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=xrc(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=G;i=f;return}function gAa(a,b,c){a=a|0;b=b|0;c=c|0;UDa(a,b,c,c);return}function hAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=g|0;UDa(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=m^j;n=xrc(k|l,m|j,((k^l)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=a;c[h>>2]=n;c[h+4>>2]=G;h=b+(e+2)|0;n=h|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=j^h;m=xrc(k|l,j|h,((k^l)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=m;c[n+4>>2]=G;n=e<<1;m=b+(n+2)|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;h=c[l>>2]|0;j=c[l+4>>2]|0;l=j^m;o=xrc(h|k,j|m,((h^k)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=a+n|0;c[l>>2]=o;c[l+4>>2]=G;l=e*3|0;e=b+(l+2)|0;b=e|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;n=c[b+4>>2]|0;b=n^e;k=xrc(g|o,n|e,((g^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=a+l|0;c[b>>2]=k;c[b+4>>2]=G;i=f;return}function iAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;VDa(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=p^s;h=xrc(l|g,p|s,((l^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=h;c[k+4>>2]=G;k=c[o>>2]|0;h=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;l=c[o+4>>2]|0;o=l^h;s=xrc(g|k,l|h,((g^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=a+e|0;c[o>>2]=s;c[o+4>>2]=G;o=c[n>>2]|0;s=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;g=c[n+4>>2]|0;n=g^s;h=xrc(k|o,g|s,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+m|0;c[n>>2]=h;c[n+4>>2]=G;n=c[q>>2]|0;h=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;m=c[q+4>>2]|0;q=m^h;o=xrc(j|n,m|h,((j^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+(e*3|0)|0;c[q>>2]=o;c[q+4>>2]=G;i=f;return}function jAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;UDa(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;VDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=r^g;q=xrc(k|n,r|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=q;c[m+4>>2]=G;m=j+8|0;q=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;r=xrc(k|q,g|n,((k^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^q;g=xrc(k|r,n|q,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=r;c[m+4>>2]=G;i=f;return}function kAa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;UDa(f,b,8,d);WDa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=xrc(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=G;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=xrc(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=G;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=xrc(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=xrc(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=G;i=e;return}function lAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;UDa(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;VDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=xrc(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=G;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=G;i=f;return}function mAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+72|0;g=f|0;h=g|0;j=g+16|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=g+8|0;h=e-k|0;m=b+h|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=m;m=b;l=m|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[j>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[j+4>>2]=m;m=g+24|0;l=b+e|0;n=l|0;o=l+4|0;l=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=l;l=g+32|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=n;n=g+40|0;l=m+e|0;m=b+(l-k)|0;o=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=m;m=g+48|0;n=l+e|0;l=b+(n-k)|0;o=l|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=l;l=g+56|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[l>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[l+4>>2]=n;n=g+64|0;g=b+(h+m)|0;m=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=g;VDa(a,j,e);i=f;return}function nAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;VDa(k,o,8);WDa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=xrc(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=G;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=xrc(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=G;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=xrc(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=xrc(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=G;i=f;return}function oAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+288|0;WDa(a,d|0,b,c,c);i=d;return}function pAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;VDa(k,o,8);WDa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^j;g=xrc(l|b,o|j,((l^b)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a;c[n>>2]=g;c[n+4>>2]=G;n=k+8|0;g=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;l=c[n>>2]|0;j=c[n+4>>2]|0;n=j^b;o=xrc(l|g,j|b,((l^g)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=o;c[n+4>>2]=G;n=k+16|0;o=c[n>>2]|0;g=c[n+4>>2]|0;n=m+16|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=b^g;j=xrc(l|o,b|g,((l^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+p|0;c[n>>2]=j;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;j=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;p=c[n+4>>2]|0;n=p^j;o=xrc(m|k,p|j,((m^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+(e*3|0)|0;c[n>>2]=o;c[n+4>>2]=G;i=f;return}function qAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;VDa(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=s^g;t=xrc(o|l,s|g,((o^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=a;c[k>>2]=t;c[k+4>>2]=G;k=c[n>>2]|0;t=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=o^t;g=xrc(l|k,o|t,((l^k)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=a+e|0;c[n>>2]=g;c[n+4>>2]=G;n=c[q>>2]|0;g=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;l=c[q+4>>2]|0;q=l^g;t=xrc(k|n,l|g,((k^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=a+m|0;c[q>>2]=t;c[q+4>>2]=G;q=c[p>>2]|0;t=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;m=c[p+4>>2]|0;p=m^t;n=xrc(j|q,m|t,((j^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=a+(e*3|0)|0;c[p>>2]=n;c[p+4>>2]=G;i=f;return}function rAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;UDa(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;VDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;r=xrc(k|n,o|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;o=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=o;c[m+4>>2]=G;m=j+16|0;o=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|o,n|r,((k^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+p|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;p=c[m+4>>2]|0;m=p^g;o=xrc(l|j,p|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=o;c[m+4>>2]=G;i=f;return}function sAa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;UDa(f,b+d|0,8,d);WDa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;m=xrc(g|b,l|k,((g^b)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a;c[j>>2]=m;c[j+4>>2]=G;j=f+8|0;m=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;g=c[j>>2]|0;k=c[j+4>>2]|0;j=k^b;l=xrc(g|m,k|b,((g^m)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+d|0;c[j>>2]=l;c[j+4>>2]=G;j=f+16|0;l=c[j>>2]|0;m=c[j+4>>2]|0;j=h+16|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=b^m;k=xrc(g|l,b|m,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d<<1)|0;c[j>>2]=k;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;k=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;l=c[j+4>>2]|0;j=l^k;g=xrc(h|f,l|k,((h^f)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=a+(d*3|0)|0;c[j>>2]=g;c[j+4>>2]=G;i=e;return}function tAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;UDa(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;VDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=s^g;r=xrc(k|n,s|g,((k^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a;c[m>>2]=r;c[m+4>>2]=G;m=j+8|0;r=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;k=c[m>>2]|0;g=c[m+4>>2]|0;m=g^n;s=xrc(k|r,g|n,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+e|0;c[m>>2]=s;c[m+4>>2]=G;m=j+16|0;s=c[m>>2]|0;r=c[m+4>>2]|0;m=l+16|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=n^r;g=xrc(k|s,n|r,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+o|0;c[m>>2]=g;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;g=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;o=c[m+4>>2]|0;m=o^g;s=xrc(l|j,o|g,((l^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=a+(e*3|0)|0;c[m>>2]=s;c[m+4>>2]=G;i=f;return}function uAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0;f=b;c[a>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=b+e|0;c[a+e>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;return}function vAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;bEa(g,b,4,e);h=b;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+e|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function wAa(a,b,c){a=a|0;b=b|0;c=c|0;bEa(a,b,c,c);return}function xAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;bEa(g,b,4,e);h=b+2|0;j=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=c[g>>2]|0;c[a>>2]=(h|j)-((h^j)>>>1&2147450879);j=b+(e+2)|0;b=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=c[g+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function yAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=k+e+e|0;o=b+(n-k)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-k)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(l+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;cEa(h,j,4);n=c[j>>2]|0;j=c[h>>2]|0;c[a>>2]=(j|n)-((j^n)>>>1&2147450879);n=c[m>>2]|0;m=c[h+4>>2]|0;c[a+e>>2]=(m|n)-((m^n)>>>1&2147450879);i=f;return}function zAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;bEa(h,b,4,e);l=e<<1;m=b+(-l|0)|0;c[g>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=e-l|0;n=b+m|0;c[g+4>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+e|0;c[g+12>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=l+e+e|0;o=b+(n-l)|0;c[g+16>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;n=b+(o-l)|0;c[g+20>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=b+(m+o)|0;c[g+24>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;cEa(j,k,4);k=c[h>>2]|0;n=c[j>>2]|0;c[a>>2]=(n|k)-((n^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function AAa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+120|0;f=e+112|0;g=i;i=i+8|0;bEa(f,b,4,d);dEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function BAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;bEa(h,b,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;cEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function CAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+32|0;g=f|0;h=g+8|0;j=e<<1;k=b+(-j|0)|0;c[g>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=e-j|0;l=b+k|0;c[g+4>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+e|0;c[g+12>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=j+e+e|0;m=b+(l-j)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=l+e|0;l=b+(m-j)|0;c[g+20>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=b+(k+m)|0;c[g+24>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;cEa(a,h,e);i=f;return}function DAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+112|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+e|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;p=b+(o-m)|0;c[g+16>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;cEa(j,l,4);dEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function EAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+112|0;dEa(a,d|0,b,c,c);i=d;return}function FAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+112|0;j=i;i=i+8|0;k=i;i=i+8|0;l=g+8|0;m=e<<1;n=2-m|0;o=b+n|0;c[g>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+e|0;p=b+o|0;c[g+4>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+2|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(e+2)|0;c[g+12>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=m+e+e|0;m=b+(p+n)|0;c[g+16>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=p+e|0;p=b+(m+n)|0;c[g+20>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=b+(o+m)|0;c[g+24>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;cEa(j,l,4);dEa(k,h|0,b,4,e);b=c[j>>2]|0;h=c[k>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[j+4>>2]|0;j=c[k+4>>2]|0;c[a+e>>2]=(j|b)-((j^b)>>>1&2147450879);i=f;return}function GAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=g+8|0;k=e<<1;l=b+(-k|0)|0;c[g>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=e-k|0;m=b+l|0;c[g+4>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=b;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;m=g+12|0;n=b+e|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=g+16|0;o=k+e+e|0;p=b+(o-k)|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;p=o+e|0;o=b+(p-k)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(l+p)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;cEa(h,j,4);j=c[m>>2]|0;m=c[h>>2]|0;c[a>>2]=(m|j)-((m^j)>>>1&2147450879);j=c[n>>2]|0;n=c[h+4>>2]|0;c[a+e>>2]=(n|j)-((n^j)>>>1&2147450879);i=f;return}function HAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;l=b+e|0;bEa(h,l,4,e);m=e<<1;n=b+(-m|0)|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=e-m|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=m+e+e|0;l=b+(o-m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l-m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;cEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function IAa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+120|0;f=e+112|0;g=i;i=i+8|0;bEa(f,b+d|0,4,d);dEa(g,e|0,b,4,d);b=c[f>>2]|0;h=c[g>>2]|0;c[a>>2]=(h|b)-((h^b)>>>1&2147450879);b=c[f+4>>2]|0;f=c[g+4>>2]|0;c[a+d>>2]=(f|b)-((f^b)>>>1&2147450879);i=e;return}function JAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+32|0;g=f|0;h=i;i=i+8|0;j=i;i=i+8|0;k=g+8|0;bEa(h,b+e|0,4,e);l=e<<1;m=2-l|0;n=b+m|0;c[g>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;n=m+e|0;o=b+n|0;c[g+4>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+2|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(e+2)|0;c[g+12>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=l+e+e|0;l=b+(o+m)|0;c[g+16>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=o+e|0;o=b+(l+m)|0;c[g+20>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=b+(n+l)|0;c[g+24>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;cEa(j,k,4);k=c[h>>2]|0;o=c[j>>2]|0;c[a>>2]=(o|k)-((o^k)>>>1&2147450879);k=c[h+4>>2]|0;h=c[j+4>>2]|0;c[a+e>>2]=(h|k)-((h^k)>>>1&2147450879);i=f;return}function KAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b;g=a;h=0;while(1){i=g;j=c[i>>2]|0;k=c[i+4>>2]|0;l=f;m=l|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l^k;o=xrc(n|j,l|k,((n^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[i>>2]=o;c[i+4>>2]=G;i=g+8|0;o=c[i>>2]|0;m=c[i+4>>2]|0;j=f+8|0;n=j|0;k=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+4|0;j=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j^m;l=xrc(k|o,j|m,((k^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[i>>2]=l;c[i+4>>2]=G;i=h+1|0;if((i|0)<16){f=f+e|0;g=g+e|0;h=i}else{break}}h=b+16|0;b=a+16|0;a=0;while(1){g=b;f=c[g>>2]|0;i=c[g+4>>2]|0;l=h;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l^i;k=xrc(o|f,l|i,((o^f)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[g>>2]=k;c[g+4>>2]=G;g=b+8|0;k=c[g>>2]|0;n=c[g+4>>2]|0;f=h+8|0;o=f|0;i=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f+4|0;f=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=f^n;l=xrc(i|k,f|n,((i^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[g>>2]=l;c[g+4>>2]=G;g=a+1|0;if((g|0)<16){h=h+e|0;b=b+e|0;a=g}else{break}}return}function LAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;XDa(g|0,b,32,e);XDa(g+16|0,b+16|0,32,e);h=e<<3;XDa(g+256|0,b+h|0,32,e);XDa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=xrc(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ca(u,e)|0;l=h+16|0;q=b+l|0;m=q|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=u<<5;s=g+(m|16)|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+l|0;l=c[t>>2]|0;j=c[t+4>>2]|0;p=s^q;k=xrc(r|o,s|q,((r^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;o=p^j;r=xrc(k|l,p|j,((k^l)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;t=h+24|0;h=b+t|0;r=h|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+(m|24)|0;m=r|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=r+4|0;r=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+t|0;t=c[m>>2]|0;k=c[m+4>>2]|0;j=r^h;p=xrc(l|o,r|h,((l^o)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;o=j^k;l=xrc(p|t,j|k,((p^t)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function MAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;aEa(a,b,c,c);aEa(a+16|0,b+16|0,c,c);d=c<<3;aEa(a+d|0,b+d|0,c,c);e=d+16|0;aEa(a+e|0,b+e|0,c,c);return}function NAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+512|0;g=f|0;XDa(g|0,b,32,e);XDa(g+16|0,b+16|0,32,e);h=e<<3;XDa(g+256|0,b+h|0,32,e);XDa(g+272|0,b+(h+16)|0,32,e);h=0;while(1){j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<5;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=xrc(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;l=h+1|0;if((l|0)<16){h=l}else{u=0;break}}do{h=ca(u,e)|0;l=b+(h+18)|0;q=l|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=u<<5;j=g+(q|16)|0;s=j|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+4|0;j=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=a+(h+16)|0;r=c[s>>2]|0;o=c[s+4>>2]|0;p=j^l;k=xrc(t|m,j|l,((t^m)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;m=p^o;t=xrc(k|r,p|o,((k^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[s>>2]=t;c[s+4>>2]=G;s=b+(h+26)|0;t=s|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=g+(q|24)|0;q=t|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=t+4|0;t=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=a+(h+24)|0;h=c[q>>2]|0;k=c[q+4>>2]|0;o=t^s;p=xrc(r|m,t|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;m=o^k;r=xrc(p|h,o|k,((p^h)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function OAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}YDa(j|0,h+64|0,32,32);YDa(j+16|0,h+80|0,32,32);YDa(j+256|0,h+320|0,32,32);YDa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+64)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=xrc(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;m=t^s;n=xrc(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=G;q=e|8;e=h+(q+64)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=xrc(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^u;r=xrc(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+80)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=xrc(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=G;m=n^e;t=xrc(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h+((l|8)+80)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=xrc(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^k;s=xrc(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function PAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;XDa(j|0,e,32,f);XDa(j+16|0,e+16|0,32,f);l=f<<3;XDa(j+256|0,e+l|0,32,f);XDa(j+272|0,e+(l+16)|0,32,f);l=e+(-(f<<1)|0)|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=xrc(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=xrc(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^m;t=xrc(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=xrc(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^e;s=xrc(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function QAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;XDa(h|0,b,32,e);k=b+16|0;XDa(h+16|0,k,32,e);l=e<<3;m=b+l|0;XDa(h+256|0,m,32,e);n=b+(l+16)|0;XDa(h+272|0,n,32,e);l=g|0;ZDa(j|0,l,b,32,32,e);b=g+32|0;ZDa(j+16|0,b,k,32,32,e);ZDa(j+256|0,l,m,32,32,e);ZDa(j+272|0,b,n,32,32,e);n=0;while(1){b=n<<5;m=h+b|0;l=m|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=j+b|0;g=l|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+4|0;l=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(n,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^m;t=xrc(o|k,l|m,((o^k)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;k=s^r;o=xrc(t|q,s|r,((t^q)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=b|8;b=h+p|0;o=b|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=xrc(q|k,o|b,((q^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;k=r^t;q=xrc(s|g,r|t,((s^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;p=n+1|0;if((p|0)<16){n=p}else{u=0;break}}do{n=u<<5;p=n|16;q=h+p|0;k=q|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=q+4|0;q=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+p|0;p=k|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=k^q;m=xrc(s|g,k|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;g=o^b;s=xrc(m|r,o|b,((m^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=G;t=n|24;n=h+t|0;s=n|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;m=c[t+4>>2]|0;b=s^n;o=xrc(r|g,s|n,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;g=b^m;r=xrc(o|p,b|m,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function RAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;XDa(j|0,e,32,f);XDa(j+16|0,e+16|0,32,f);l=f<<3;XDa(j+256|0,e+l|0,32,f);XDa(j+272|0,e+(l+16)|0,32,f);l=e+(2-(f<<1))|0;e=h|0;m=0;while(1){n=l;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=l+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=l+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+1|0;if((q|0)<21){l=l+f|0;e=e+32|0;m=q}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=0;while(1){m=h<<5;e=j+m|0;l=e|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=e+4|0;e=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+m|0;n=l|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=l^e;u=xrc(p|q,l|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=m|8;m=j+o|0;p=m|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^m;t=xrc(r|q,p|m,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;m=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^m;t=xrc(e|s,p|m,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;m=t^h;p=xrc(s|n,t|h,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^e;s=xrc(p|o,m|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function SAa(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+672|0;g=f|0;h=c+(-(e<<1)|0)|0;c=g|0;j=0;while(1){k=h;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=h+8|0;k=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+8|0;l=m|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=m+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+16|0;n=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+16|0;k=m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=m+4|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+24|0;l=k|0;m=k+4|0;k=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=c+24|0;n=m|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+1|0;if((n|0)<21){h=h+e|0;c=c+32|0;j=n}else{break}}$Da(b,g+64|0,e,32);$Da(b+16|0,g+80|0,e,32);j=e<<3;$Da(b+j|0,g+320|0,e,32);$Da(b+(j+16)|0,g+336|0,e,32);i=f;return}function TAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(-(f<<1)|0)|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=j|0;ZDa(l|0,h,e,32,32,f);o=j+32|0;ZDa(l+16|0,o,e+16|0,32,32,f);j=f<<3;ZDa(l+256|0,h,e+j|0,32,32,f);ZDa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=xrc(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;n=t^q;s=xrc(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=G;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=xrc(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=G;n=q^u;r=xrc(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=G;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=xrc(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^e;t=xrc(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=xrc(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^o;q=xrc(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function UAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+2688|0;e=d|0;f=e|0;_Da(a,f,b,c,32,c);g=e+32|0;_Da(a+16|0,g,b+16|0,c,32,c);e=c<<3;_Da(a+e|0,f,b+e|0,c,32,c);f=e+16|0;_Da(a+f|0,g,b+f|0,c,32,c);i=d;return}function VAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+4384|0;h=g|0;j=g+672|0;k=g+3360|0;l=g+3872|0;m=e+(2-(f<<1))|0;n=h|0;o=0;while(1){p=m;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=m+8|0;p=s|0;r=s+4|0;s=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+8|0;q=r|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=r+4|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+16|0;s=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+16|0;p=r|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=r+4|0;y=q;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=m+24|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=n+24|0;s=r|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=r+4|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=o+1|0;if((s|0)<21){m=m+f|0;n=n+32|0;o=s}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=j|0;ZDa(l|0,h,e,32,32,f);o=j+32|0;ZDa(l+16|0,o,e+16|0,32,32,f);j=f<<3;ZDa(l+256|0,h,e+j|0,32,32,f);ZDa(l+272|0,o,e+(j+16)|0,32,32,f);j=0;while(1){e=j<<5;o=k+e|0;h=o|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+e|0;m=h|0;s=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=ca(j,f)|0;p=b+m|0;r=c[p>>2]|0;q=c[p+4>>2]|0;t=h^o;u=xrc(s|n,h|o,((s^n)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;n=t^q;s=xrc(u|r,t|q,((u^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=s;c[p+4>>2]=G;p=e|8;e=k+p|0;s=e|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=e+4|0;e=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+p|0;p=s|0;r=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=s+4|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=b+(m+8)|0;m=c[p>>2]|0;u=c[p+4>>2]|0;q=s^e;t=xrc(r|n,s|e,((r^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;q=G;n=q^u;r=xrc(t|m,q|u,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[p>>2]=r;c[p+4>>2]=G;p=j+1|0;if((p|0)<16){j=p}else{v=0;break}}do{j=v<<5;p=j|16;r=k+p|0;n=r|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=r+4|0;r=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+p|0;p=n|0;t=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(v,f)|0;u=b+(p+16)|0;q=c[u>>2]|0;e=c[u+4>>2]|0;s=n^r;o=xrc(t|m,n|r,((t^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^e;t=xrc(o|q,s|e,((o^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=j|24;j=k+u|0;t=j|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+4|0;j=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=l+u|0;u=t|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(p+24)|0;p=c[u>>2]|0;o=c[u+4>>2]|0;e=t^j;s=xrc(q|m,t|j,((q^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^o;q=xrc(s|p,e|o,((s^p)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=q;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function WAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1184|0;h=g|0;j=g+672|0;k=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){m=k;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+8|0;m=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+8|0;n=o|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;y=p;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+16|0;p=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+16|0;m=o|0;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=o+4|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+24|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=e+24|0;p=o|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=m;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+1|0;if((p|0)<21){k=k+f|0;e=e+32|0;l=p}else{break}}YDa(j|0,h+64|0,32,32);YDa(j+16|0,h+80|0,32,32);YDa(j+256|0,h+320|0,32,32);YDa(j+272|0,h+336|0,32,32);l=0;while(1){e=l<<5;k=h+(e+96)|0;p=k|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+4|0;k=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+e|0;o=p|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(l,f)|0;q=b+o|0;r=c[q>>2]|0;s=c[q+4>>2]|0;t=p^k;u=xrc(n|m,p|k,((n^m)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;m=t^s;n=xrc(u|r,t|s,((u^r)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=n;c[q+4>>2]=G;q=e|8;e=h+(q+96)|0;n=e|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=e+4|0;e=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j+q|0;q=n|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=b+(o+8)|0;o=c[q>>2]|0;u=c[q+4>>2]|0;s=n^e;t=xrc(r|m,n|e,((r^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^u;r=xrc(t|o,s|u,((t^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[q>>2]=r;c[q+4>>2]=G;q=l+1|0;if((q|0)<16){l=q}else{v=0;break}}do{l=v<<5;q=h+(l+112)|0;r=q|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=j+(l|16)|0;o=r|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=r+4|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;e=c[u+4>>2]|0;n=r^q;k=xrc(t|m,r|q,((t^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;n=G;m=n^e;t=xrc(k|s,n|e,((k^s)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h+((l|8)+112)|0;t=u|0;m=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=u+4|0;u=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=j+(l|24)|0;l=t|0;s=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=t+4|0;t=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(o+24)|0;o=c[l>>2]|0;k=c[l+4>>2]|0;e=t^u;n=xrc(s|m,t|u,((s^m)>>>1|e<<31)&2147450879,(e>>>1|0<<31)&2147450879)|0;e=G;m=e^k;s=xrc(n|o,e|k,((n^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=s;c[l+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function XAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;XDa(j|0,e+f|0,32,f);l=f+16|0;XDa(j+16|0,e+l|0,32,f);m=f<<3;XDa(j+256|0,e+(m+f)|0,32,f);XDa(j+272|0,e+(l+m)|0,32,f);m=e+(-(f<<1)|0)|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=xrc(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=xrc(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^l;t=xrc(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=xrc(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=G;n=l^e;s=xrc(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function YAa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+3712|0;g=f|0;h=f+2688|0;j=f+3200|0;XDa(h|0,b+e|0,32,e);XDa(h+16|0,b+(e+16)|0,32,e);k=e<<3;XDa(h+256|0,b+(k+e)|0,32,e);l=k+16|0;XDa(h+272|0,b+(l+e)|0,32,e);m=g|0;ZDa(j|0,m,b,32,32,e);n=g+32|0;ZDa(j+16|0,n,b+16|0,32,32,e);ZDa(j+256|0,m,b+k|0,32,32,e);ZDa(j+272|0,n,b+l|0,32,32,e);l=0;while(1){b=l<<5;n=h+b|0;k=n|0;m=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=n+4|0;n=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+b|0;g=k|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=k+4|0;k=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=ca(l,e)|0;p=a+g|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=k^n;t=xrc(o|m,k|n,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=b|8;b=h+p|0;o=b|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+4|0;b=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(g+8)|0;g=c[p>>2]|0;t=c[p+4>>2]|0;r=o^b;s=xrc(q|m,o|b,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|g,r|t,((s^g)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;p=l+1|0;if((p|0)<16){l=p}else{u=0;break}}do{l=u<<5;p=l|16;q=h+p|0;m=q|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q+4|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=j+p|0;p=m|0;s=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(u,e)|0;t=a+(p+16)|0;r=c[t>>2]|0;b=c[t+4>>2]|0;o=m^q;n=xrc(s|g,m|q,((s^g)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;g=o^b;s=xrc(n|r,o|b,((n^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=s;c[t+4>>2]=G;t=l|24;l=h+t|0;s=l|0;g=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=l+4|0;l=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=j+t|0;t=s|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=a+(p+24)|0;p=c[t>>2]|0;n=c[t+4>>2]|0;b=s^l;o=xrc(r|g,s|l,((r^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;g=b^n;r=xrc(o|p,b|n,((o^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[t>>2]=r;c[t+4>>2]=G;u=u+1|0;}while((u|0)<16);i=f;return}function ZAa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+1696|0;h=g|0;j=g+672|0;k=g+1184|0;XDa(j|0,e+f|0,32,f);l=f+16|0;XDa(j+16|0,e+l|0,32,f);m=f<<3;XDa(j+256|0,e+(m+f)|0,32,f);XDa(j+272|0,e+(l+m)|0,32,f);m=e+(2-(f<<1))|0;e=h|0;l=0;while(1){n=m;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+8|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+8|0;o=p|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=p+4|0;y=q;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=m+16|0;q=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+16|0;n=p|0;y=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=p+4|0;y=o;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=m+24|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=e+24|0;q=p|0;y=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=n;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+1|0;if((q|0)<21){m=m+f|0;e=e+32|0;l=q}else{break}}YDa(k|0,h+64|0,32,32);YDa(k+16|0,h+80|0,32,32);YDa(k+256|0,h+320|0,32,32);YDa(k+272|0,h+336|0,32,32);h=0;while(1){l=h<<5;e=j+l|0;m=e|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=e+4|0;e=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+l|0;n=m|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(h,f)|0;o=b+n|0;r=c[o>>2]|0;s=c[o+4>>2]|0;t=m^e;u=xrc(p|q,m|e,((p^q)>>>1|t<<31)&2147450879,(t>>>1|0<<31)&2147450879)|0;t=G;q=t^s;p=xrc(u|r,t|s,((u^r)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=l|8;l=j+o|0;p=l|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=l+4|0;l=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+o|0;o=p|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=b+(n+8)|0;n=c[o>>2]|0;u=c[o+4>>2]|0;s=p^l;t=xrc(r|q,p|l,((r^q)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;q=s^u;r=xrc(t|n,s|u,((t^n)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[o>>2]=r;c[o+4>>2]=G;o=h+1|0;if((o|0)<16){h=o}else{v=0;break}}do{h=v<<5;o=h|16;r=j+o|0;q=r|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=k+o|0;o=q|0;t=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(v,f)|0;u=b+(o+16)|0;s=c[u>>2]|0;l=c[u+4>>2]|0;p=q^r;e=xrc(t|n,q|r,((t^n)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;n=p^l;t=xrc(e|s,p|l,((e^s)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=t;c[u+4>>2]=G;u=h|24;h=j+u|0;t=h|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=h+4|0;h=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=k+u|0;u=t|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=b+(o+24)|0;o=c[u>>2]|0;e=c[u+4>>2]|0;l=t^h;p=xrc(s|n,t|h,((s^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;l=G;n=l^e;s=xrc(p|o,l|e,((p^o)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[u>>2]=s;c[u+4>>2]=G;v=v+1|0;}while((v|0)<16);i=g;return}function _Aa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;b=a;a=0;while(1){g=b;h=c[g>>2]|0;i=c[g+4>>2]|0;j=f;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j^i;m=xrc(l|h,j|i,((l^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[g>>2]=m;c[g+4>>2]=G;g=b+8|0;m=c[g>>2]|0;k=c[g+4>>2]|0;h=f+8|0;l=h|0;i=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h^k;j=xrc(i|m,h|k,((i^m)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[g>>2]=j;c[g+4>>2]=G;g=a+1|0;if((g|0)<8){f=f+e|0;b=b+e|0;a=g}else{break}}return}function $Aa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;XDa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=j+8|0;j=b+o|0;p=j|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=j+4|0;j=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+o|0;o=c[l>>2]|0;t=c[l+4>>2]|0;r=p^j;s=xrc(q|m,p|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function aBa(a,b,c){a=a|0;b=b|0;c=c|0;aEa(a,b,c,c);return}function bBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+128|0;g=f|0;XDa(g|0,b,16,e);h=0;do{j=ca(h,e)|0;k=b+(j+2)|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h<<4;n=g+l|0;o=n|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=a+j|0;q=c[o>>2]|0;r=c[o+4>>2]|0;s=n^k;t=xrc(p|m,n|k,((p^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;p=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[o>>2]=p;c[o+4>>2]=G;o=b+(j+10)|0;p=o|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+(l|8)|0;l=p|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p+4|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(j+8)|0;j=c[l>>2]|0;t=c[l+4>>2]|0;r=p^o;s=xrc(q|m,p|o,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|j,r|t,((s^j)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;h=h+1|0;}while((h|0)<8);i=f;return}function cBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=k;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=p;p=b+8|0;k=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+40|0;c[o>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[o+4>>2]=p;p=g+48|0;o=b+e|0;k=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=o;o=b+(e+8)|0;p=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+56|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=o;o=g+64|0;k=m+e+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+72|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+80|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+88|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+96|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+112|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+120|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+128|0;k=p+e|0;p=b+(k-m)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+136|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+144|0;h=k+e|0;k=b+(h-m)|0;o=k|0;q=k+4|0;k=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=k;k=b+(n+h)|0;p=k|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+152|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=k;k=g+160|0;o=h+e|0;h=b+(o-m)|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[k>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[k+4>>2]=h;h=b+(n+o)|0;k=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[p+4>>2]=h;h=g+176|0;p=o+e|0;o=b+(p-m)|0;k=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=o;o=b+(n+p)|0;h=o|0;k=o+4|0;o=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+184|0;c[k>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[k+4>>2]=o;o=g+192|0;k=p+e|0;p=b+(k-m)|0;m=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=p;p=b+(n+k)|0;k=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[n+4>>2]=p;YDa(j|0,l,16,16);p=0;do{n=p<<4;k=l+n|0;g=c[k>>2]|0;b=c[k+4>>2]|0;k=j+n|0;o=k|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+4|0;k=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=ca(p,e)|0;h=a+o|0;q=c[h>>2]|0;r=c[h+4>>2]|0;s=k^b;t=xrc(m|g,k|b,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[h>>2]=m;c[h+4>>2]=G;h=n|8;n=l+h|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=j+h|0;h=n|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(o+8)|0;o=c[h>>2]|0;t=c[h+4>>2]|0;r=n^g;s=xrc(q|m,n|g,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|o,r|t,((s^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[h>>2]=q;c[h+4>>2]=G;p=p+1|0;}while((p|0)<8);i=f;return}function dBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;XDa(j|0,b,16,e);m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=8-m|0;h=b+n|0;o=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+8|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=g+16|0;p=b+(e-m)|0;o=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=b+(e+8-m)|0;h=p|0;o=p+4|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+24|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=p;p=b;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[l+4>>2]=p;p=b+8|0;o=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=p;p=g+48|0;h=b+e|0;o=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=h;h=b+(e+8)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+56|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;h=g+64|0;o=m+e+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+80|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+96|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+104|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+112|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+120|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+128|0;o=p+e|0;p=b+(o-m)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;h=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=g+144|0;q=o+e|0;o=b+(q-m)|0;h=o|0;r=o+4|0;o=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=o;o=b+(n+q)|0;p=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=g+160|0;h=q+e|0;q=b+(h-m)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;q=b+(n+h)|0;o=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+168|0;c[p>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[p+4>>2]=q;q=g+176|0;p=h+e|0;h=b+(p-m)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=h;h=b+(n+p)|0;q=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+184|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=h;h=g+192|0;o=p+e|0;p=b+(o-m)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(n+o)|0;o=p|0;n=p+4|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+200|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=p;YDa(k|0,l,16,16);l=0;do{p=l<<4;n=j+p|0;o=n|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=k+p|0;b=o|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=o+4|0;o=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;m=a+b|0;q=c[m>>2]|0;r=c[m+4>>2]|0;s=o^n;t=xrc(h|g,o|n,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;h=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=p|8;p=j+m|0;h=p|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+m|0;m=h|0;q=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=a+(b+8)|0;b=c[m>>2]|0;t=c[m+4>>2]|0;r=h^p;s=xrc(q|g,h|p,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function eBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;XDa(g|0,b,16,e);ZDa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=xrc(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=xrc(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function fBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;XDa(j|0,b,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;YDa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=xrc(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=xrc(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function gBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+208|0;g=f|0;h=g|0;j=g+32|0;k=e<<1;l=b+(-k|0)|0;m=l|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=l;l=8-k|0;h=b+l|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+8|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=g+16|0;n=b+(e-k)|0;m=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=b+(e+8-k)|0;h=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+24|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=n;n=b;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[j>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[j+4>>2]=n;n=b+8|0;m=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=n;n=g+48|0;h=b+e|0;m=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=h;h=b+(e+8)|0;n=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=k+e+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+72|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+80|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+112|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=n+e|0;n=b+(m-k)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;h=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+136|0;c[o>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[o+4>>2]=n;n=g+144|0;o=m+e|0;m=b+(o-k)|0;h=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=m;m=b+(l+o)|0;n=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=o+e|0;o=b+(h-k)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=o;o=b+(l+h)|0;m=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=o;o=g+176|0;n=h+e|0;h=b+(n-k)|0;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=h;h=b+(l+n)|0;o=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=n+e|0;n=b+(m-k)|0;k=n|0;o=n+4|0;n=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;c[h+4>>2]=n;n=b+(l+m)|0;m=n|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+200|0;c[l>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[l+4>>2]=n;$Da(a,j,e,16);i=f;return}function hBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=b+e|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=n+e+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+80|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+112|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=q+e|0;q=b+(p-n)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[r+4>>2]=q;q=g+144|0;r=p+e|0;p=b+(r-n)|0;h=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=p;p=b+(o+r)|0;q=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=r+e|0;r=b+(h-n)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=r;r=b+(o+h)|0;p=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=r;r=g+176|0;q=h+e|0;h=b+(q-n)|0;p=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[r+4>>2]=h;h=b+(o+q)|0;r=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=q+e|0;q=b+(p-n)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+p)|0;p=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=q;YDa(k|0,m,16,16);ZDa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;q=m|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l+j|0;p=q|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=ca(b,e)|0;h=a+p|0;n=c[h>>2]|0;r=c[h+4>>2]|0;s=q^m;t=xrc(g|o,q|m,((g^o)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;o=s^r;g=xrc(t|n,s|r,((t^n)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=g;c[h+4>>2]=G;h=j|8;j=k+h|0;g=j|0;o=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+h|0;h=g|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=a+(p+8)|0;p=c[h>>2]|0;t=c[h+4>>2]|0;r=g^j;s=xrc(n|o,g|j,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;o=r^t;n=xrc(s|p,r|t,((s^p)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[h>>2]=n;c[h+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function iBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;i=i+832|0;_Da(a,d|0,b,c,16,c);i=d;return}function jBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+832|0;k=i;i=i+128|0;l=i;i=i+128|0;m=g+32|0;n=e<<1;o=2-n|0;p=b+o|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=o+8|0;h=b+p|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+8|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=h;h=g+16|0;r=b+(o+e)|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=b+(e+8+o)|0;h=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=r;r=b+10|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+48|0;h=n+e|0;n=b+(e+2)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(h+8+o)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+56|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+64|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+72|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+80|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+88|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+96|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+112|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+120|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+128|0;q=h+e|0;h=b+(q+o)|0;r=h|0;s=h+4|0;h=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;n=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=g+136|0;c[r>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[r+4>>2]=h;h=g+144|0;r=q+e|0;q=b+(r+o)|0;n=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(p+r)|0;h=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+152|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=q;q=g+160|0;n=r+e|0;r=b+(n+o)|0;h=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=r;r=b+(p+n)|0;q=r|0;h=r+4|0;r=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=r;r=g+176|0;h=n+e|0;n=b+(h+o)|0;q=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=n;n=b+(p+h)|0;r=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+184|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=n;n=g+192|0;q=h+e|0;h=b+(q+o)|0;o=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[n+4>>2]=h;h=b+(p+q)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+200|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;YDa(k|0,m,16,16);ZDa(l|0,j|0,b,16,16,e);b=0;do{j=b<<4;m=k+j|0;h=m|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=l+j|0;q=h|0;g=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=ca(b,e)|0;n=a+q|0;o=c[n>>2]|0;r=c[n+4>>2]|0;s=h^m;t=xrc(g|p,h|m,((g^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;p=s^r;g=xrc(t|o,s|r,((t^o)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=j|8;j=k+n|0;g=j|0;p=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=j+4|0;j=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=l+n|0;n=g|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+4|0;g=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(q+8)|0;q=c[n>>2]|0;t=c[n+4>>2]|0;r=g^j;s=xrc(o|p,g|j,((o^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;p=r^t;o=xrc(s|q,r|t,((s^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[n>>2]=o;c[n+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function kBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=g+32|0;l=e<<1;m=b+(-l|0)|0;n=m|0;o=m+4|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=m;m=8-l|0;h=b+m|0;n=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+8|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=g+16|0;o=b+(e-l)|0;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=b+(e+8-l)|0;h=o|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[k+4>>2]=o;o=b+8|0;n=o|0;h=o+4|0;o=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=o;o=g+48|0;h=b+e|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[o>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[o+4>>2]=h;h=b+(e+8)|0;n=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=h;h=g+64|0;p=l+e+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+80|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+96|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+104|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+112|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+128|0;p=n+e|0;n=b+(p-l)|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;h=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=n;n=g+144|0;q=p+e|0;p=b+(q-l)|0;h=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[n+4>>2]=p;p=b+(m+q)|0;n=p|0;h=p+4|0;p=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=p;p=g+160|0;h=q+e|0;q=b+(h-l)|0;n=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[p+4>>2]=q;q=b+(m+h)|0;p=q|0;n=q+4|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+168|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+176|0;n=h+e|0;h=b+(n-l)|0;p=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=b+(m+n)|0;q=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=h;h=g+192|0;p=n+e|0;n=b+(p-l)|0;l=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;c[h+4>>2]=n;n=b+(m+p)|0;p=n|0;m=n+4|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+200|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=n;YDa(j|0,k,16,16);k=o;o=0;do{n=o<<4;m=k+n|0;p=c[m>>2]|0;g=c[m+4>>2]|0;m=j+n|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(o,e)|0;l=a+b|0;q=c[l>>2]|0;r=c[l+4>>2]|0;s=m^g;t=xrc(h|p,m|g,((h^p)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;p=s^r;h=xrc(t|q,s|r,((t^q)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;c[l>>2]=h;c[l+4>>2]=G;l=n|8;n=k+l|0;h=c[n>>2]|0;p=c[n+4>>2]|0;n=j+l|0;l=n|0;q=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=a+(b+8)|0;b=c[l>>2]|0;t=c[l+4>>2]|0;r=n^p;s=xrc(q|h,n|p,((q^h)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;h=r^t;q=xrc(s|b,r|t,((s^b)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;c[l>>2]=q;c[l+4>>2]=G;o=o+1|0;}while((o|0)<8);i=f;return}function lBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;m=b+e|0;XDa(j|0,m,16,e);n=e<<1;o=b+(-n|0)|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=8-n|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(e-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8-n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+8|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m;m=h|0;p=h+4|0;h=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=b+(e+8)|0;q=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+56|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=g+64|0;m=n+e+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+72|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+80|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+88|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+96|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+104|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+112|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+120|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+128|0;m=q+e|0;q=b+(m-n)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+136|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=g+144|0;p=m+e|0;m=b+(p-n)|0;h=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[q+4>>2]=m;m=b+(o+p)|0;q=m|0;h=m+4|0;m=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+152|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=m;m=g+160|0;h=p+e|0;p=b+(h-n)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=p;p=b+(o+h)|0;m=p|0;q=p+4|0;p=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+168|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=p;p=g+176|0;q=h+e|0;h=b+(q-n)|0;m=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[p+4>>2]=h;h=b+(o+q)|0;p=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+184|0;c[m>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[m+4>>2]=h;h=g+192|0;m=q+e|0;q=b+(m-n)|0;n=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[h+4>>2]=q;q=b+(o+m)|0;m=q|0;o=q+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[o+4>>2]=q;YDa(k|0,l,16,16);l=0;do{q=l<<4;o=j+q|0;m=o|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=o+4|0;o=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+q|0;b=m|0;h=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=m+4|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;p=c[n>>2]|0;r=c[n+4>>2]|0;s=m^o;t=xrc(h|g,m|o,((h^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;h=xrc(t|p,s|r,((t^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=h;c[n+4>>2]=G;n=q|8;q=j+n|0;h=q|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=k+n|0;n=h|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=h^q;s=xrc(p|g,h|q,((p^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;p=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=p;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function mBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+1088|0;g=f+832|0;h=f+960|0;XDa(g|0,b+e|0,16,e);ZDa(h|0,f|0,b,16,16,e);b=0;do{j=b<<4;k=g+j|0;l=k|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=k+4|0;k=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=h+j|0;n=l|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=l+4|0;l=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=ca(b,e)|0;p=a+n|0;q=c[p>>2]|0;r=c[p+4>>2]|0;s=l^k;t=xrc(o|m,l|k,((o^m)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;m=s^r;o=xrc(t|q,s|r,((t^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=o;c[p+4>>2]=G;p=j|8;j=g+p|0;o=j|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=j+4|0;j=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h+p|0;p=o|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=a+(n+8)|0;n=c[p>>2]|0;t=c[p+4>>2]|0;r=o^j;s=xrc(q|m,o|j,((q^m)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;m=r^t;q=xrc(s|n,r|t,((s^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[p>>2]=q;c[p+4>>2]=G;b=b+1|0;}while((b|0)<8);i=f;return}function nBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+208|0;g=f|0;h=g|0;j=i;i=i+128|0;k=i;i=i+128|0;l=g+32|0;XDa(j|0,b+e|0,16,e);m=e<<1;n=2-m|0;o=b+n|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=o;o=n+8|0;h=b+o|0;p=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+8|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=h;h=g+16|0;q=b+(n+e)|0;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=b+(e+8+n)|0;h=q|0;p=q+4|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+2|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[l>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[l+4>>2]=q;q=b+10|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+40|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+48|0;h=m+e|0;m=b+(e+2)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(h+8+n)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+56|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+64|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+72|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+80|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+88|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+96|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+104|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+112|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+120|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+128|0;p=h+e|0;h=b+(p+n)|0;q=h|0;r=h+4|0;h=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[m>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;m=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=g+136|0;c[q>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[q+4>>2]=h;h=g+144|0;q=p+e|0;p=b+(q+n)|0;m=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[h+4>>2]=p;p=b+(o+q)|0;h=p|0;m=p+4|0;p=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=g+152|0;c[m>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[m+4>>2]=p;p=g+160|0;m=q+e|0;q=b+(m+n)|0;h=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[p>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24;c[p+4>>2]=q;q=b+(o+m)|0;p=q|0;h=q+4|0;q=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=g+168|0;c[h>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[h+4>>2]=q;q=g+176|0;h=m+e|0;m=b+(h+n)|0;p=m|0;r=m+4|0;m=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=m;m=b+(o+h)|0;q=m|0;p=m+4|0;m=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=g+184|0;c[p>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[p+4>>2]=m;m=g+192|0;p=h+e|0;h=b+(p+n)|0;n=h|0;q=h+4|0;h=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[m>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[m+4>>2]=h;h=b+(o+p)|0;p=h|0;o=h+4|0;h=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=g+200|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=h;YDa(k|0,l,16,16);l=0;do{h=l<<4;o=j+h|0;p=o|0;g=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=k+h|0;b=p|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=p+4|0;p=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=ca(l,e)|0;n=a+b|0;q=c[n>>2]|0;r=c[n+4>>2]|0;s=p^o;t=xrc(m|g,p|o,((m^g)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;g=s^r;m=xrc(t|q,s|r,((t^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;n=h|8;h=j+n|0;m=h|0;g=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=k+n|0;n=m|0;q=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=m+4|0;m=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=a+(b+8)|0;b=c[n>>2]|0;t=c[n+4>>2]|0;r=m^h;s=xrc(q|g,m|h,((q^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^t;q=xrc(s|b,r|t,((s^b)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=q;c[n+4>>2]=G;l=l+1|0;}while((l|0)<8);i=f;return}function oBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a;g=c[f>>2]|0;h=c[f+4>>2]|0;i=b;j=i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i+4|0;i=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=i^h;l=xrc(k|g,i|h,((k^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[f>>2]=l;c[f+4>>2]=G;f=a+e|0;l=c[f>>2]|0;j=c[f+4>>2]|0;g=b+e|0;k=g|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+4|0;g=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g^j;i=xrc(h|l,g|j,((h^l)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[f>>2]=i;c[f+4>>2]=G;f=e<<1;i=a+f|0;k=c[i>>2]|0;l=c[i+4>>2]|0;h=b+f|0;j=h|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h+4|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h^l;m=xrc(g|k,h|l,((g^k)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[i>>2]=m;c[i+4>>2]=G;i=f+e|0;e=a+i|0;a=c[e>>2]|0;f=c[e+4>>2]|0;m=b+i|0;i=m|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m+4|0;m=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=m^f;j=xrc(b|a,m|f,((b^a)>>>1|i<<31)&2147450879,(i>>>1|0<<31)&2147450879)|0;c[e>>2]=j;c[e+4>>2]=G;return}function pBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;UDa(g,b,8,e);j=b;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=xrc(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;l=p^o;k=xrc(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=G;h=b+e|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=xrc(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^p;n=xrc(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=G;k=e<<1;n=b+k|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=xrc(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;o=h^j;m=xrc(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=G;l=e*3|0;e=b+l|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=xrc(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;m=k^a;g=xrc(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=G;i=f;return}function qBa(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d>>1;d=0;g=a;a=c;while(1){c=a+2|0;h=a-2|0;i=a+4|0;j=a+6|0;k=(((e[c>>1]|0)+(e[a>>1]|0)|0)*20|0)+16+(e[a-4>>1]|0)+(((e[i>>1]|0)+(e[h>>1]|0)|0)*-5|0)+(e[j>>1]|0)>>5;if(k>>>0<4096>>>0){l=k}else{l=-k>>31&4095}b[g>>1]=((e[g>>1]|0)+1+l|0)>>>1;k=g+2|0;m=a+8|0;n=(((e[i>>1]|0)+(e[c>>1]|0)|0)*20|0)+16+(e[h>>1]|0)+(((e[j>>1]|0)+(e[a>>1]|0)|0)*-5|0)+(e[m>>1]|0)>>5;if(n>>>0<4096>>>0){o=n}else{o=-n>>31&4095}b[k>>1]=((e[k>>1]|0)+1+o|0)>>>1;k=g+4|0;n=a+10|0;h=(((e[j>>1]|0)+(e[i>>1]|0)|0)*20|0)+16+(e[a>>1]|0)+(((e[m>>1]|0)+(e[c>>1]|0)|0)*-5|0)+(e[n>>1]|0)>>5;if(h>>>0<4096>>>0){p=h}else{p=-h>>31&4095}b[k>>1]=((e[k>>1]|0)+1+p|0)>>>1;k=g+6|0;h=(((e[m>>1]|0)+(e[j>>1]|0)|0)*20|0)+16+(e[c>>1]|0)+(((e[n>>1]|0)+(e[i>>1]|0)|0)*-5|0)+(e[a+12>>1]|0)>>5;if(h>>>0<4096>>>0){q=h}else{q=-h>>31&4095}b[k>>1]=((e[k>>1]|0)+1+q|0)>>>1;k=d+1|0;if((k|0)<4){d=k;g=g+(f<<1)|0;a=a+(f<<1)|0}else{break}}return}function rBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=g|0;UDa(g,b,8,e);j=b+2|0;k=j|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=c[h>>2]|0;m=c[h+4>>2]|0;h=a;n=c[h>>2]|0;o=c[h+4>>2]|0;p=m^j;q=xrc(k|l,m|j,((k^l)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;l=p^o;k=xrc(q|n,p|o,((q^n)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[h>>2]=k;c[h+4>>2]=G;h=b+(e+2)|0;k=h|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h+4|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=g+8|0;n=c[k>>2]|0;q=c[k+4>>2]|0;k=a+e|0;o=c[k>>2]|0;p=c[k+4>>2]|0;j=q^h;m=xrc(n|l,q|h,((n^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^p;n=xrc(m|o,j|p,((m^o)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=n;c[k+4>>2]=G;k=e<<1;n=b+(k+2)|0;l=n|0;o=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+4|0;n=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=g+16|0;m=c[l>>2]|0;p=c[l+4>>2]|0;l=a+k|0;k=c[l>>2]|0;j=c[l+4>>2]|0;h=p^n;q=xrc(m|o,p|n,((m^o)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;o=h^j;m=xrc(q|k,h|j,((q^k)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[l>>2]=m;c[l+4>>2]=G;l=e*3|0;e=b+(l+2)|0;b=e|0;m=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+24|0;g=c[b>>2]|0;o=c[b+4>>2]|0;b=a+l|0;l=c[b>>2]|0;a=c[b+4>>2]|0;k=o^e;q=xrc(g|m,o|e,((g^m)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;m=k^a;g=xrc(q|l,k|a,((q^l)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[b>>2]=g;c[b+4>>2]=G;i=f;return}function sBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;p=s+e|0;s=b+(p-m)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+p)|0;p=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[s+4>>2]=g;VDa(j,l,8);g=c[l>>2]|0;s=c[l+4>>2]|0;l=c[k>>2]|0;p=c[k+4>>2]|0;k=a;h=c[k>>2]|0;b=c[k+4>>2]|0;r=p^s;t=xrc(l|g,p|s,((l^g)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;g=r^b;l=xrc(t|h,r|b,((t^h)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[k>>2]=l;c[k+4>>2]=G;k=c[o>>2]|0;l=c[o+4>>2]|0;o=j+8|0;g=c[o>>2]|0;h=c[o+4>>2]|0;o=a+e|0;t=c[o>>2]|0;b=c[o+4>>2]|0;r=h^l;s=xrc(g|k,h|l,((g^k)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;k=r^b;g=xrc(s|t,r|b,((s^t)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[o>>2]=g;c[o+4>>2]=G;o=c[n>>2]|0;g=c[n+4>>2]|0;n=j+16|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=a+m|0;m=c[n>>2]|0;s=c[n+4>>2]|0;b=t^g;r=xrc(k|o,t|g,((k^o)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;o=b^s;k=xrc(r|m,b|s,((r^m)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;c[n>>2]=k;c[n+4>>2]=G;n=c[q>>2]|0;k=c[q+4>>2]|0;q=j+24|0;j=c[q>>2]|0;o=c[q+4>>2]|0;q=a+(e*3|0)|0;e=c[q>>2]|0;a=c[q+4>>2]|0;m=o^k;r=xrc(j|n,o|k,((j^n)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;n=m^a;j=xrc(r|e,m|a,((r^e)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=j;c[q+4>>2]=G;i=f;return}function tBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;UDa(j,b,8,e);o=e<<1;p=b+(-o|0)|0;q=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[h>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[h+4>>2]=p;p=g+8|0;h=e-o|0;q=b+h|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[p>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[p+4>>2]=q;q=b;p=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=q;q=g+24|0;p=b+e|0;r=p|0;s=p+4|0;p=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=p;p=g+32|0;q=o+e+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+40|0;p=q+e|0;q=b+(p-o)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+48|0;r=p+e|0;p=b+(r-o)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+56|0;q=r+e|0;r=b+(q-o)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[p>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[p+4>>2]=r;r=g+64|0;g=b+(h+q)|0;q=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=g;VDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;r=c[m+4>>2]|0;m=a;q=c[m>>2]|0;h=c[m+4>>2]|0;b=r^g;p=xrc(k|n,r|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(p|q,b|h,((p^q)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;q=c[m>>2]|0;p=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=p^n;r=xrc(q|k,p|n,((q^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;q=xrc(r|h,g|b,((r^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=q;c[m+4>>2]=G;m=j+16|0;q=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;r=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=r^k;n=xrc(h|q,r|k,((h^q)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;q=g^b;h=xrc(n|o,g|b,((n^o)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;q=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=q^h;n=xrc(l|j,q|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function uBa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;UDa(f,b,8,d);WDa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=xrc(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;b=o^n;g=xrc(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=G;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=xrc(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;g=k^o;m=xrc(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=G;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=xrc(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;m=b^k;n=xrc(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=xrc(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;f=o^a;h=xrc(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=G;i=e;return}function vBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;UDa(j,b,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;VDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=xrc(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=xrc(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=xrc(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function wBa(a,f,g){a=a|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=j|0;l=j+16|0;m=g<<1;n=f+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[k>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[k+4>>2]=n;n=j+8|0;k=g-m|0;o=f+k|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=f;n=o|0;p=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=o+4|0;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;c[l>>2]=p;c[l+4>>2]=o;o=j+24|0;n=f+g|0;q=n|0;r=n+4|0;n=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=n;n=j+32|0;o=m+g+g|0;q=f+(o-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=j+40|0;n=o+g|0;o=f+(n-m)|0;r=o|0;s=o+4|0;o=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[q>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[q+4>>2]=o;o=j+48|0;q=n+g|0;n=f+(q-m)|0;r=n|0;s=n+4|0;n=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=n;n=j+56|0;o=q+g|0;q=f+(o-m)|0;m=q|0;r=q+4|0;q=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;c[n>>2]=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24;c[n+4>>2]=q;q=j+64|0;j=f+(k+o)|0;o=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[q>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[q+4>>2]=j;j=g>>1;g=j<<1;q=j*3|0;o=l;l=a;a=1;k=p&65535;while(1){p=e[o-8>>1]|0;f=k&65535;n=e[o+8>>1]|0;m=e[o+16>>1]|0;r=e[o+24>>1]|0;s=e[o+32>>1]|0;t=e[o+40>>1]|0;u=e[o+48>>1]|0;v=(e[o-16>>1]|0)+16+((n+f|0)*20|0)+r+((m+p|0)*-5|0)>>5;if(v>>>0<4096>>>0){w=v}else{w=-v>>31&4095}b[l>>1]=((e[l>>1]|0)+1+w|0)>>>1;v=l+(j<<1)|0;x=p+16+((m+n|0)*20|0)+s+((r+f|0)*-5|0)>>5;if(x>>>0<4096>>>0){y=x}else{y=-x>>31&4095}b[v>>1]=((e[v>>1]|0)+1+y|0)>>>1;v=l+(g<<1)|0;x=f+16+((r+m|0)*20|0)+t+((s+n|0)*-5|0)>>5;if(x>>>0<4096>>>0){z=x}else{z=-x>>31&4095}b[v>>1]=((e[v>>1]|0)+1+z|0)>>>1;v=l+(q<<1)|0;x=n+16+((s+r|0)*20|0)+u+((t+m|0)*-5|0)>>5;if(x>>>0<4096>>>0){A=x}else{A=-x>>31&4095}b[v>>1]=((e[v>>1]|0)+1+A|0)>>>1;v=o+2|0;if((a|0)>=4){break}o=v;l=l+2|0;a=a+1|0;k=b[v>>1]|0}i=h;return}function xBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[o>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[o+4>>2]=r;r=g+24|0;q=b+e|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q-p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s-p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r-p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;VDa(k,o,8);WDa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;s=c[n+4>>2]|0;r=o^j;h=xrc(l|b,o|j,((l^b)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;r=G;b=r^s;l=xrc(h|g,r|s,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;s=c[n>>2]|0;r=c[n+4>>2]|0;j=h^b;o=xrc(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^r;g=xrc(o|s,j|r,((o^s)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;s=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;r=c[n+4>>2]|0;j=o^l;b=xrc(s|g,o|l,((s^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;g=j^r;s=xrc(b|p,j|r,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=s;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;s=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^s;b=xrc(m|k,g|s,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;k=p^a;m=xrc(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;i=f;return}function yBa(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+288|0;h=g|0;j=f>>1;f=j<<1;k=d+(-f<<1)|0;d=0;l=h|0;while(1){m=e[k>>1]|0;n=e[k+2>>1]|0;o=e[k-2>>1]|0;p=e[k+4>>1]|0;q=e[k+6>>1]|0;c[l>>2]=(e[k-4>>1]|0)+((n+m|0)*20|0)+((p+o|0)*-5|0)+q;r=e[k+8>>1]|0;c[l+4>>2]=((p+n|0)*20|0)+o+r+((q+m|0)*-5|0);o=e[k+10>>1]|0;c[l+8>>2]=((q+p|0)*20|0)+m+o+((r+n|0)*-5|0);c[l+12>>2]=((r+q|0)*20|0)+n+(e[k+12>>1]|0)+((o+p|0)*-5|0);p=d+1|0;if((p|0)<9){k=k+(j<<1)|0;d=p;l=l+32|0}else{break}}l=j*3|0;d=a;a=0;k=h+64|0;while(1){h=c[k-32>>2]|0;p=c[k>>2]|0;o=c[k+32>>2]|0;n=c[k+64>>2]|0;q=c[k+96>>2]|0;r=c[k+128>>2]|0;m=c[k+160>>2]|0;s=c[k+192>>2]|0;t=(c[k-64>>2]|0)+512+((o+p|0)*20|0)+q+((n+h|0)*-5|0)>>10;if(t>>>0<4096>>>0){u=t}else{u=-t>>31&4095}b[d>>1]=((e[d>>1]|0)+1+u|0)>>>1;t=d+(j<<1)|0;v=h+512+((n+o|0)*20|0)+r+((q+p|0)*-5|0)>>10;if(v>>>0<4096>>>0){w=v}else{w=-v>>31&4095}b[t>>1]=((e[t>>1]|0)+1+w|0)>>>1;t=d+(f<<1)|0;v=p+512+((q+n|0)*20|0)+m+((r+o|0)*-5|0)>>10;if(v>>>0<4096>>>0){x=v}else{x=-v>>31&4095}b[t>>1]=((e[t>>1]|0)+1+x|0)>>>1;t=d+(l<<1)|0;v=o+512+((r+q|0)*20|0)+s+((m+n|0)*-5|0)>>10;if(v>>>0<4096>>>0){y=v}else{y=-v>>31&4095}b[t>>1]=((e[t>>1]|0)+1+y|0)>>>1;t=a+1|0;if((t|0)<4){d=d+2|0;a=t;k=k+4|0}else{break}}i=g;return}function zBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+288|0;k=i;i=i+32|0;l=k|0;m=i;i=i+32|0;n=m|0;o=g+16|0;p=e<<1;q=2-p|0;r=b+q|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[h>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[h+4>>2]=r;r=g+8|0;h=q+e|0;s=b+h|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=s;s=b+2|0;r=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=s;s=g+24|0;r=b+(e+2)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+32|0;s=p+e+e|0;t=b+(s+q)|0;u=t|0;v=t+4|0;t=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=t;t=g+40|0;r=s+e|0;s=b+(r+q)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[t>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[t+4>>2]=s;s=g+48|0;t=r+e|0;r=b+(t+q)|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[s>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[s+4>>2]=r;r=g+56|0;s=t+e|0;t=b+(s+q)|0;q=t|0;u=t+4|0;t=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[r+4>>2]=t;t=g+64|0;g=b+(h+s)|0;s=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[t>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[t+4>>2]=g;VDa(k,o,8);WDa(m,j|0,b,8,e);b=c[l>>2]|0;j=c[l+4>>2]|0;l=c[n>>2]|0;o=c[n+4>>2]|0;n=a;g=c[n>>2]|0;t=c[n+4>>2]|0;s=o^j;h=xrc(l|b,o|j,((l^b)>>>1|s<<31)&2147450879,(s>>>1|0<<31)&2147450879)|0;s=G;b=s^t;l=xrc(h|g,s|t,((h^g)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=k+8|0;l=c[n>>2]|0;b=c[n+4>>2]|0;n=m+8|0;g=c[n>>2]|0;h=c[n+4>>2]|0;n=a+e|0;t=c[n>>2]|0;s=c[n+4>>2]|0;j=h^b;o=xrc(g|l,h|b,((g^l)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;l=j^s;g=xrc(o|t,j|s,((o^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[n>>2]=g;c[n+4>>2]=G;n=k+16|0;g=c[n>>2]|0;l=c[n+4>>2]|0;n=m+16|0;t=c[n>>2]|0;o=c[n+4>>2]|0;n=a+p|0;p=c[n>>2]|0;s=c[n+4>>2]|0;j=o^l;b=xrc(t|g,o|l,((t^g)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;j=G;g=j^s;t=xrc(b|p,j|s,((b^p)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[n>>2]=t;c[n+4>>2]=G;n=k+24|0;k=c[n>>2]|0;t=c[n+4>>2]|0;n=m+24|0;m=c[n>>2]|0;g=c[n+4>>2]|0;n=a+(e*3|0)|0;e=c[n>>2]|0;a=c[n+4>>2]|0;p=g^t;b=xrc(m|k,g|t,((m^k)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;k=p^a;m=xrc(b|e,p|a,((b^e)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=m;c[n+4>>2]=G;i=f;return}function ABa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=g+16|0;m=e<<1;n=b+(-m|0)|0;o=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[h>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[h+4>>2]=n;n=g+8|0;h=e-m|0;o=b+h|0;p=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[n>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[n+4>>2]=o;o=b;n=o|0;p=o+4|0;o=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;c[l>>2]=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24;c[l+4>>2]=o;o=g+24|0;n=b+e|0;p=n|0;q=n+4|0;n=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;c[o>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[o+4>>2]=n;n=g+32|0;p=m+e+e|0;q=b+(p-m)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[n+4>>2]=q;q=g+40|0;r=p+e|0;p=b+(r-m)|0;s=p|0;t=p+4|0;p=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=p;p=g+48|0;s=r+e|0;r=b+(s-m)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[p>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[p+4>>2]=r;r=g+56|0;t=s+e|0;s=b+(t-m)|0;u=s|0;v=s+4|0;s=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[r>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[r+4>>2]=s;s=g+64|0;g=b+(h+t)|0;t=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=g;VDa(j,l,8);l=c[o>>2]|0;g=c[o+4>>2]|0;o=c[k>>2]|0;s=c[k+4>>2]|0;k=a;t=c[k>>2]|0;h=c[k+4>>2]|0;b=s^g;r=xrc(o|l,s|g,((o^l)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;l=b^h;o=xrc(r|t,b|h,((r^t)>>>1|l<<31)&2147450879,(l>>>1|0<<31)&2147450879)|0;c[k>>2]=o;c[k+4>>2]=G;k=c[n>>2]|0;o=c[n+4>>2]|0;n=j+8|0;l=c[n>>2]|0;t=c[n+4>>2]|0;n=a+e|0;r=c[n>>2]|0;h=c[n+4>>2]|0;b=t^o;g=xrc(l|k,t|o,((l^k)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;k=b^h;l=xrc(g|r,b|h,((g^r)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[n>>2]=l;c[n+4>>2]=G;n=c[q>>2]|0;l=c[q+4>>2]|0;q=j+16|0;k=c[q>>2]|0;r=c[q+4>>2]|0;q=a+m|0;m=c[q>>2]|0;g=c[q+4>>2]|0;h=r^l;b=xrc(k|n,r|l,((k^n)>>>1|h<<31)&2147450879,(h>>>1|0<<31)&2147450879)|0;h=G;n=h^g;k=xrc(b|m,h|g,((b^m)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[q>>2]=k;c[q+4>>2]=G;q=c[p>>2]|0;k=c[p+4>>2]|0;p=j+24|0;j=c[p>>2]|0;n=c[p+4>>2]|0;p=a+(e*3|0)|0;e=c[p>>2]|0;a=c[p+4>>2]|0;m=n^k;b=xrc(j|q,n|k,((j^q)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;m=G;q=m^a;j=xrc(b|e,m|a,((b^e)>>>1|q<<31)&2147450879,(q>>>1|0<<31)&2147450879)|0;c[p>>2]=j;c[p+4>>2]=G;i=f;return}function BBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;o=b+e|0;UDa(j,o,8,e);p=e<<1;q=b+(-p|0)|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=e-p|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=o;o=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[r>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=p+e+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+40|0;q=r+e|0;r=b+(q-p)|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[o>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[o+4>>2]=r;r=g+48|0;o=q+e|0;q=b+(o-p)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=o+e|0;o=b+(r-p)|0;s=o|0;t=o+4|0;o=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=o;o=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[o>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[o+4>>2]=g;VDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;o=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=o^g;q=xrc(k|n,o|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;o=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(o|h,g|b,((o^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;o=c[m+4>>2]|0;m=a+p|0;p=c[m>>2]|0;b=c[m+4>>2]|0;g=o^k;n=xrc(h|r,o|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|p,g|b,((n^p)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;p=r^h;n=xrc(l|j,r|h,((l^j)>>>1|p<<31)&2147450879,(p>>>1|0<<31)&2147450879)|0;p=G;j=p^a;l=xrc(n|e,p|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}function CBa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+320|0;f=e+288|0;g=f|0;h=i;i=i+32|0;j=h|0;UDa(f,b+d|0,8,d);WDa(h,e|0,b,8,d);b=c[g>>2]|0;k=c[g+4>>2]|0;g=c[j>>2]|0;l=c[j+4>>2]|0;j=a;m=c[j>>2]|0;n=c[j+4>>2]|0;o=l^k;p=xrc(g|b,l|k,((g^b)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;b=o^n;g=xrc(p|m,o|n,((p^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;c[j>>2]=g;c[j+4>>2]=G;j=f+8|0;g=c[j>>2]|0;b=c[j+4>>2]|0;j=h+8|0;m=c[j>>2]|0;p=c[j+4>>2]|0;j=a+d|0;n=c[j>>2]|0;o=c[j+4>>2]|0;k=p^b;l=xrc(m|g,p|b,((m^g)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;k=G;g=k^o;m=xrc(l|n,k|o,((l^n)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;c[j>>2]=m;c[j+4>>2]=G;j=f+16|0;m=c[j>>2]|0;g=c[j+4>>2]|0;j=h+16|0;n=c[j>>2]|0;l=c[j+4>>2]|0;j=a+(d<<1)|0;o=c[j>>2]|0;k=c[j+4>>2]|0;b=l^g;p=xrc(n|m,l|g,((n^m)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;m=b^k;n=xrc(p|o,b|k,((p^o)>>>1|m<<31)&2147450879,(m>>>1|0<<31)&2147450879)|0;c[j>>2]=n;c[j+4>>2]=G;j=f+24|0;f=c[j>>2]|0;n=c[j+4>>2]|0;j=h+24|0;h=c[j>>2]|0;m=c[j+4>>2]|0;j=a+(d*3|0)|0;d=c[j>>2]|0;a=c[j+4>>2]|0;o=m^n;p=xrc(h|f,m|n,((h^f)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;f=o^a;h=xrc(p|d,o|a,((p^d)>>>1|f<<31)&2147450879,(f>>>1|0<<31)&2147450879)|0;c[j>>2]=h;c[j+4>>2]=G;i=e;return}function DBa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+72|0;g=f|0;h=g|0;j=i;i=i+32|0;k=j|0;l=i;i=i+32|0;m=l|0;n=g+16|0;UDa(j,b+e|0,8,e);o=e<<1;p=2-o|0;q=b+p|0;r=q|0;s=q+4|0;q=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[h>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[h+4>>2]=q;q=g+8|0;h=p+e|0;r=b+h|0;s=r|0;t=r+4|0;r=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[q+4>>2]=r;r=b+2|0;q=r|0;s=r+4|0;r=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;c[n>>2]=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24;c[n+4>>2]=r;r=g+24|0;q=b+(e+2)|0;s=q|0;t=q+4|0;q=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[r>>2]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;c[r+4>>2]=q;q=g+32|0;r=o+e+e|0;s=b+(r+p)|0;t=s|0;u=s+4|0;s=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[q>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[q+4>>2]=s;s=g+40|0;q=r+e|0;r=b+(q+p)|0;t=r|0;u=r+4|0;r=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[s>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[s+4>>2]=r;r=g+48|0;s=q+e|0;q=b+(s+p)|0;t=q|0;u=q+4|0;q=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;c[r>>2]=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24;c[r+4>>2]=q;q=g+56|0;r=s+e|0;s=b+(r+p)|0;p=s|0;t=s+4|0;s=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;c[q>>2]=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24;c[q+4>>2]=s;s=g+64|0;g=b+(h+r)|0;r=g|0;h=g+4|0;g=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[s>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[s+4>>2]=g;VDa(l,n,8);n=c[k>>2]|0;g=c[k+4>>2]|0;k=c[m>>2]|0;s=c[m+4>>2]|0;m=a;r=c[m>>2]|0;h=c[m+4>>2]|0;b=s^g;q=xrc(k|n,s|g,((k^n)>>>1|b<<31)&2147450879,(b>>>1|0<<31)&2147450879)|0;b=G;n=b^h;k=xrc(q|r,b|h,((q^r)>>>1|n<<31)&2147450879,(n>>>1|0<<31)&2147450879)|0;c[m>>2]=k;c[m+4>>2]=G;m=j+8|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=l+8|0;r=c[m>>2]|0;q=c[m+4>>2]|0;m=a+e|0;h=c[m>>2]|0;b=c[m+4>>2]|0;g=q^n;s=xrc(r|k,q|n,((r^k)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;k=g^b;r=xrc(s|h,g|b,((s^h)>>>1|k<<31)&2147450879,(k>>>1|0<<31)&2147450879)|0;c[m>>2]=r;c[m+4>>2]=G;m=j+16|0;r=c[m>>2]|0;k=c[m+4>>2]|0;m=l+16|0;h=c[m>>2]|0;s=c[m+4>>2]|0;m=a+o|0;o=c[m>>2]|0;b=c[m+4>>2]|0;g=s^k;n=xrc(h|r,s|k,((h^r)>>>1|g<<31)&2147450879,(g>>>1|0<<31)&2147450879)|0;g=G;r=g^b;h=xrc(n|o,g|b,((n^o)>>>1|r<<31)&2147450879,(r>>>1|0<<31)&2147450879)|0;c[m>>2]=h;c[m+4>>2]=G;m=j+24|0;j=c[m>>2]|0;h=c[m+4>>2]|0;m=l+24|0;l=c[m>>2]|0;r=c[m+4>>2]|0;m=a+(e*3|0)|0;e=c[m>>2]|0;a=c[m+4>>2]|0;o=r^h;n=xrc(l|j,r|h,((l^j)>>>1|o<<31)&2147450879,(o>>>1|0<<31)&2147450879)|0;o=G;j=o^a;l=xrc(n|e,o|a,((n^e)>>>1|j<<31)&2147450879,(j>>>1|0<<31)&2147450879)|0;c[m>>2]=l;c[m+4>>2]=G;i=f;return}



function Q8a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=c[e+60>>2]|0;m=h+4|0;n=N4a(e,c[m>>2]|0)|0;if((n|0)<0){o=n;i=j;return o|0}if(!((l|0)>-1)){KIb(0,0,2612864,(p=i,i=i+24|0,c[p>>2]=2586136,c[p+8>>2]=2565272,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}n=h+796|0;c[n>>2]=k;c[h+804>>2]=k;q=k+l|0;r=h+800|0;c[r>>2]=q;s=c[m>>2]|0;c[s+84>>2]=0;c[s+88>>2]=2;t=h+840|0;u=t;v=c[u>>2]|0;do{if((v|0)==0){w=q;x=k}else{y=h+808|0;z=c[y>>2]|0;A=c[h+788>>2]|0;B=c[h+816>>2]|0;C=c[h+812>>2]|0;D=c[h+792>>2]|0;E=c[h+820>>2]|0;F=(B|0)<0;H=((A|0)<(B+z|0)?A-B|0:z)+(F?B:0)|0;A=(E|0)<0;I=((D|0)<(E+C|0)?D-E|0:C)+(A?E:0)|0;if(!((H|0)>0&(I|0)>0)){w=q;x=k;break}C=h+12|0;D=c[C>>2]|0;J=(ca(c[s+32>>2]|0,A?0:E)|0)+(ca(D,F?0:B)|0)|0;B=(c[s>>2]|0)+J|0;J=0;F=v;E=z;z=D;while(1){nrc(B|0,F+(ca(ca(E,J)|0,z)|0)|0,ca(z,H)|0)|0;D=J+1|0;if((D|0)>=(I|0)){break}B=B+(c[(c[m>>2]|0)+32>>2]|0)|0;J=D;F=c[u>>2]|0;E=c[y>>2]|0;z=c[C>>2]|0}w=c[r>>2]|0;x=c[n>>2]|0}}while(0);v=w;s=v-x|0;k=s>>>0>2>>>0?2:s;s=x+k|0;c[n>>2]=s;a:do{if((v-s|0)>=2){q=x+(k+2)|0;c[n>>2]=q;C=s;z=(d[C]|d[C+1|0]<<8)<<16>>16;if(z<<16>>16==0){break}C=h+12|0;y=e;E=h+808|0;F=h+812|0;J=h+824|0;B=h+828|0;I=h+832|0;H=h+836|0;D=I;A=h+16|0;K=H;L=h+816|0;M=h+820|0;N=h+8|0;O=h+788|0;P=h+792|0;Q=(he(z|0)|0)&65535;z=q;q=w;b:while(1){R=Q-1|0;S=q;T=S-z|0;if(T>>>0<12>>>0){U=14;break}if((T|0)<2){V=0;W=z}else{T=z+2|0;c[n>>2]=T;X=z;V=(he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;W=T}if((S-W|0)<2){Y=0;Z=W}else{T=W+2|0;c[n>>2]=T;X=W;Y=(he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;Z=T}if((S-Z|0)<2){_=0;$=Z}else{T=Z+2|0;c[n>>2]=T;X=Z;_=(he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;$=T}if((S-$|0)<2){aa=0;ba=$}else{T=$+2|0;c[n>>2]=T;X=$;aa=(he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;ba=T}do{if((S-ba|0)<4){T=c[m>>2]|0;X=c[C>>2]|0;da=ca(X,V)|0;ea=c[T+32>>2]|0;fa=X;ga=ea;ha=(c[T>>2]|0)+((ca(ea,Y)|0)+da)|0;ia=S-ba|0;U=109}else{da=ba+4|0;c[n>>2]=da;ea=ba;ja=je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0;ea=c[m>>2]|0;T=c[C>>2]|0;X=ca(T,V)|0;ka=c[ea+32>>2]|0;la=(c[ea>>2]|0)+((ca(ka,Y)|0)+X)|0;ma=S-da|0;if((ja|0)==1464686180){X=Erc(aa,0,_,0)|0;na=Erc(X,G,T,(T|0)<0|0?-1:0)|0;X=G;oa=0;if((X|0)>(oa|0)|(X|0)==(oa|0)&na>>>0>1073741821>>>0){U=27;break b}pa=(ca(ca(_<<1,aa)|0,T)|0)+2|0;if((ma|0)<(pa|0)){U=29;break b}c[n>>2]=ba+(ma>>>0>2>>>0?6:ma+4|0);c[E>>2]=_;c[F>>2]=aa;c[J>>2]=V;c[B>>2]=Y;if(V>>>0>_>>>0|Y>>>0>aa>>>0){KIb(y,16,2241328,(p=i,i=i+32|0,c[p>>2]=V,c[p+8>>2]=Y,c[p+16>>2]=_,c[p+24>>2]=aa,p)|0);i=p;c[B>>2]=0;c[J>>2]=0;qa=c[E>>2]|0;ra=c[F>>2]|0;sa=c[C>>2]|0}else{qa=_;ra=aa;sa=T}na=ca(ra,qa)|0;if((na|0)>=(2147483647/(sa|0)|0|0)){U=33;break b}oa=ca(na,sa)|0;na=lJb(I,oa)|0;if((na|0)<0){ta=na;U=37;break b}na=lJb(H,oa)|0;if((na|0)<0){ta=na;U=37;break b}na=lJb(t,oa)|0;if((na|0)<0){ta=na;U=37;break b}na=c[C>>2]|0;oa=c[D>>2]|0;X=c[F>>2]|0;if((X|0)<=0){break}ua=na<<1;va=c[E>>2]|0;wa=0;xa=oa;ya=oa;za=oa;oa=va;Aa=X;X=va;while(1){if((oa|0)>0){va=1;Ba=xa;Ca=ya;Da=za;while(1){c:do{switch((c[A>>2]|0)+ua|0){case 2:case 3:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<1){Fa=0;break c}c[n>>2]=Ea+1;Fa=d[Ea]|0;break};case 8:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<4){Fa=0;break c}c[n>>2]=Ea+4;Ga=Ea;Fa=d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0;break};case 5:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<2){Fa=0;break c}c[n>>2]=Ga+2;Ea=Ga;Fa=(he((d[Ea]|d[Ea+1|0]<<8)<<16>>16|0)|0)&65535;break};case 4:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<2){Fa=0;break c}c[n>>2]=Ea+2;Ga=Ea;Fa=(d[Ga]|d[Ga+1|0]<<8)<<16>>16&65535;break};case 9:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<4){Fa=0;break c}c[n>>2]=Ga+4;Ea=Ga;Fa=je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0;break};default:{Fa=0}}}while(0);if((na|0)==1){a[Ba]=Fa;Ha=Da;Ia=Ba+1|0;Ja=Ca}else if((na|0)==2){b[Ca>>1]=Fa;Ha=Da;Ia=Ba;Ja=Ca+2|0}else if((na|0)==4){c[Da>>2]=Fa;Ha=Da+4|0;Ia=Ba;Ja=Ca}else{Ha=Da;Ia=Ba;Ja=Ca}Ka=c[E>>2]|0;if((va|0)>=(Ka|0)){break}va=va+1|0;Ba=Ia;Ca=Ja;Da=Ha}La=Ia;Ma=Ja;Na=Ha;Oa=Ka;Pa=c[F>>2]|0;Qa=Ka}else{La=xa;Ma=ya;Na=za;Oa=oa;Pa=Aa;Qa=X}Da=wa+1|0;if((Da|0)<(Pa|0)){wa=Da;xa=La;ya=Ma;za=Na;oa=Oa;Aa=Pa;X=Qa}else{break}}X=c[K>>2]|0;if((Pa|0)<=0){break}Aa=(na|0)==1;oa=0;za=X;ya=X;xa=X;X=Qa;wa=Pa;while(1){if((X|0)>0){d:do{if(Aa){Da=1;Ca=za;while(1){e:do{switch((c[A>>2]|0)+ua|0){case 5:{Ba=c[n>>2]|0;if(((c[r>>2]|0)-Ba|0)<2){Ra=0;break e}c[n>>2]=Ba+2;va=Ba;Ra=((d[va]|d[va+1|0]<<8)<<16>>16&65535)>>>8&255;break};case 2:case 3:{va=c[n>>2]|0;if(((c[r>>2]|0)-va|0)<1){Ra=0;break e}c[n>>2]=va+1;Ra=a[va]|0;break};case 8:{va=c[n>>2]|0;if(((c[r>>2]|0)-va|0)<4){Ra=0;break e}c[n>>2]=va+4;Ba=va;Ra=(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24)&255;break};case 9:{Ba=c[n>>2]|0;if(((c[r>>2]|0)-Ba|0)<4){Ra=0;break e}c[n>>2]=Ba+4;va=Ba;Ra=(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)>>>24&255;break};case 4:{va=c[n>>2]|0;if(((c[r>>2]|0)-va|0)<2){Ra=0;break e}c[n>>2]=va+2;Ba=va;Ra=(d[Ba]|d[Ba+1|0]<<8)<<16>>16&255;break};default:{Ra=0}}}while(0);Ba=Ca+1|0;a[Ca]=Ra;va=c[E>>2]|0;if((Da|0)>=(va|0)){Sa=Ba;Ta=ya;Ua=xa;Va=va;break d}Da=Da+1|0;Ca=Ba}}else{Ca=1;Da=ya;Ba=xa;va=X;while(1){f:do{switch((c[A>>2]|0)+ua|0){case 9:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<4){Wa=0;break f}c[n>>2]=Ea+4;Ga=Ea;Wa=je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0;break};case 2:case 3:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<1){Wa=0;break f}c[n>>2]=Ga+1;Wa=d[Ga]|0;break};case 4:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<2){Wa=0;break f}c[n>>2]=Ga+2;Ea=Ga;Wa=(d[Ea]|d[Ea+1|0]<<8)<<16>>16&65535;break};case 5:{Ea=c[n>>2]|0;if(((c[r>>2]|0)-Ea|0)<2){Wa=0;break f}c[n>>2]=Ea+2;Ga=Ea;Wa=(he((d[Ga]|d[Ga+1|0]<<8)<<16>>16|0)|0)&65535;break};case 8:{Ga=c[n>>2]|0;if(((c[r>>2]|0)-Ga|0)<4){Wa=0;break f}c[n>>2]=Ga+4;Ea=Ga;Wa=d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0;break};default:{Wa=0}}}while(0);if((na|0)==2){b[Da>>1]=Wa;Xa=Ba;Ya=Da+2|0;Za=va}else if((na|0)==4){c[Ba>>2]=Wa;Xa=Ba+4|0;Ya=Da;Za=c[E>>2]|0}else{Xa=Ba;Ya=Da;Za=va}if((Ca|0)>=(Za|0)){Sa=za;Ta=Ya;Ua=Xa;Va=Za;break d}Ca=Ca+1|0;Da=Ya;Ba=Xa;va=Za}}}while(0);_a=Sa;$a=Ta;ab=Ua;bb=Va;cb=c[F>>2]|0}else{_a=za;$a=ya;ab=xa;bb=X;cb=wa}va=oa+1|0;if((va|0)<(cb|0)){oa=va;za=_a;ya=$a;xa=ab;X=bb;wa=cb}else{break}}}else if((ja|0)==1464686183){c[n>>2]=ba+(ma>>>0>10>>>0?14:ma+4|0);break}else if((ja|0)==1464686184){c[n>>2]=ba+(ma>>>0>4>>>0?8:ma+4|0);break}else if((ja|0)==1464686185){c[ea+84>>2]=1;c[ea+88>>2]=1;if((ma|0)<1){db=0;eb=da}else{wa=ba+5|0;c[n>>2]=wa;db=d[da]|0;eb=wa}wa=c[N>>2]|0;if((db|0)==(wa|0)){fb=q;gb=eb}else{KIb(y,32,2200320,(p=i,i=i+16|0,c[p>>2]=wa,c[p+8>>2]=db,p)|0);i=p;fb=c[r>>2]|0;gb=c[n>>2]|0}wa=fb;X=wa-gb|0;xa=X>>>0>1>>>0?1:X;X=gb+xa|0;c[n>>2]=X;if((wa-X|0)<1){c[A>>2]=0;hb=X}else{ya=gb+(xa+1)|0;c[n>>2]=ya;xa=a[X]|0;ib=xa&255;c[A>>2]=ib;if((xa&255)>>>0>1>>>0){U=106;break b}else{hb=ya}}ya=wa-hb|0;c[n>>2]=hb+(ya>>>0>13>>>0?13:ya);break}else if((ja|0)==5){jb=c[O>>2]|0;if((_+V|0)>(jb|0)){U=137;break b}ya=c[P>>2]|0;if((aa+Y|0)>(ya|0)){kb=ya;U=139;break b}if((aa|0)==0){break}ya=(_|0)==0;wa=ka<<4;xa=T<<1;X=T<<4;za=0;oa=0;na=0;ua=la;Aa=16;while(1){va=na+16|0;Ba=aa-na|0;Da=(va|0)>(aa|0)?Ba:Aa;g:do{if(ya){lb=za;mb=oa}else{Ca=(Da|0)>0;Ea=ca(Da,T)|0;Ga=c[n>>2]|0;nb=c[r>>2]|0;if((nb|0)==(Ga|0)){U=144;break b}else{ob=16;pb=ua;qb=0;rb=oa;sb=za;tb=Ga;ub=nb}while(1){nb=qb+16|0;Ga=_-qb|0;vb=(nb|0)>(_|0)?Ga:ob;wb=ub;h:do{if((wb-tb|0)<1){xb=0;yb=sb;zb=0;Ab=rb;Bb=tb;U=197}else{Cb=tb+1|0;c[n>>2]=Cb;Db=d[tb]|0;if((Db&1|0)!=0){if((wb-Cb|0)>>>0<(ca(Ea,vb)|0)>>>0){U=148;break b}if(!Ca){Eb=rb;Fb=sb;break}Gb=(vb|0)>0;Hb=(c[A>>2]|0)+xa|0;Ib=0;Jb=pb;while(1){i:do{if(Gb){Kb=Jb;Lb=Jb;Mb=0;while(1){j:do{switch(Hb|0){case 9:{Nb=c[n>>2]|0;if(((c[r>>2]|0)-Nb|0)<4){Ob=0;break j}c[n>>2]=Nb+4;Pb=Nb;Ob=je(d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)|0;break};case 2:case 3:{Pb=c[n>>2]|0;if(((c[r>>2]|0)-Pb|0)<1){Ob=0;break j}c[n>>2]=Pb+1;Ob=d[Pb]|0;break};case 4:{Pb=c[n>>2]|0;if(((c[r>>2]|0)-Pb|0)<2){Ob=0;break j}c[n>>2]=Pb+2;Nb=Pb;Ob=(d[Nb]|d[Nb+1|0]<<8)<<16>>16&65535;break};case 5:{Nb=c[n>>2]|0;if(((c[r>>2]|0)-Nb|0)<2){Ob=0;break j}c[n>>2]=Nb+2;Pb=Nb;Ob=(he((d[Pb]|d[Pb+1|0]<<8)<<16>>16|0)|0)&65535;break};case 8:{Pb=c[n>>2]|0;if(((c[r>>2]|0)-Pb|0)<4){Ob=0;break j}c[n>>2]=Pb+4;Nb=Pb;Ob=d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0;break};default:{Ob=0}}}while(0);if((T|0)==1){a[Jb+Mb|0]=Ob}else if((T|0)==2){b[Kb+(Mb<<1)>>1]=Ob}else if((T|0)==4){c[Lb+(Mb<<2)>>2]=Ob}Mb=Mb+1|0;if((Mb|0)>=(vb|0)){break i}}}}while(0);Mb=Ib+1|0;if((Mb|0)<(Da|0)){Ib=Mb;Jb=Jb+ka|0}else{Eb=rb;Fb=sb;break h}}}k:do{if((Db&2|0)==0){Qb=sb;Rb=Cb}else{switch((c[A>>2]|0)+xa|0){case 9:{if((wb-Cb|0)<4){Qb=0;Rb=Cb;break k}Jb=tb+5|0;c[n>>2]=Jb;Ib=Cb;Qb=je(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)|0;Rb=Jb;break k;break};case 2:case 3:{if((wb-Cb|0)<1){Qb=0;Rb=Cb;break k}Jb=tb+2|0;c[n>>2]=Jb;Qb=d[Cb]|0;Rb=Jb;break k;break};case 4:{if((wb-Cb|0)<2){Qb=0;Rb=Cb;break k}Jb=tb+3|0;c[n>>2]=Jb;Ib=Cb;Qb=(d[Ib]|d[Ib+1|0]<<8)<<16>>16&65535;Rb=Jb;break k;break};case 5:{if((wb-Cb|0)<2){Qb=0;Rb=Cb;break k}Jb=tb+3|0;c[n>>2]=Jb;Ib=Cb;Qb=(he((d[Ib]|d[Ib+1|0]<<8)<<16>>16|0)|0)&65535;Rb=Jb;break k;break};case 8:{if((wb-Cb|0)<4){Qb=0;Rb=Cb;break k}Jb=tb+5|0;c[n>>2]=Jb;Ib=Cb;Qb=d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0;Rb=Jb;break k;break};default:{Qb=0;Rb=Cb;break k}}}}while(0);l:do{if((Db&4|0)==0){Sb=rb;Tb=Rb}else{switch((c[A>>2]|0)+xa|0){case 2:case 3:{if((wb-Rb|0)<1){Sb=0;Tb=Rb;break l}Cb=Rb+1|0;c[n>>2]=Cb;Sb=d[Rb]|0;Tb=Cb;break l;break};case 4:{if((wb-Rb|0)<2){Sb=0;Tb=Rb;break l}Cb=Rb+2|0;c[n>>2]=Cb;Jb=Rb;Sb=(d[Jb]|d[Jb+1|0]<<8)<<16>>16&65535;Tb=Cb;break l;break};case 5:{if((wb-Rb|0)<2){Sb=0;Tb=Rb;break l}Cb=Rb+2|0;c[n>>2]=Cb;Jb=Rb;Sb=(he((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535;Tb=Cb;break l;break};case 8:{if((wb-Rb|0)<4){Sb=0;Tb=Rb;break l}Cb=Rb+4|0;c[n>>2]=Cb;Jb=Rb;Sb=d[Jb]|d[Jb+1|0]<<8|d[Jb+2|0]<<16|d[Jb+3|0]<<24|0;Tb=Cb;break l;break};case 9:{if((wb-Rb|0)<4){Sb=0;Tb=Rb;break l}Cb=Rb+4|0;c[n>>2]=Cb;Jb=Rb;Sb=je(d[Jb]|d[Jb+1|0]<<8|d[Jb+2|0]<<16|d[Jb+3|0]<<24|0)|0;Tb=Cb;break l;break};default:{Sb=0;Tb=Rb;break l}}}}while(0);if((Db&8|0)==0){xb=0;yb=Qb;zb=Db;Ab=Sb;Bb=Tb;U=197;break}if((wb-Tb|0)<1){xb=0;yb=Qb;zb=Db;Ab=Sb;Bb=Tb;U=197;break}Cb=Tb+1|0;c[n>>2]=Cb;xb=d[Tb]|0;yb=Qb;zb=Db;Ab=Sb;Bb=Cb;U=197}}while(0);do{if((U|0)==197){U=0;wb=zb&16;Cb=(wb|0)==0;Jb=wb>>>4;do{if((T|0)==4){if(Ca&(vb|0)>0){Ub=0;Vb=pb}else{Wb=Bb;Xb=ub;break}while(1){wb=Vb;Ib=0;do{c[wb+(Ib<<2)>>2]=yb;Ib=Ib+1|0;}while((Ib|0)<(vb|0));Ib=Ub+1|0;if((Ib|0)<(Da|0)){Ub=Ib;Vb=Vb+ka|0}else{Wb=Bb;Xb=ub;break}}}else if((T|0)==2){if(!Ca){Wb=Bb;Xb=ub;break}Ib=yb&65535;if((vb|0)>0){Yb=0;Zb=pb}else{Wb=Bb;Xb=ub;break}while(1){wb=0;Hb=Zb;while(1){b[Hb>>1]=Ib;Gb=wb+1|0;if((Gb|0)<(vb|0)){wb=Gb;Hb=Hb+2|0}else{break}}Hb=Yb+1|0;if((Hb|0)<(Da|0)){Yb=Hb;Zb=Zb+ka|0}else{Wb=Bb;Xb=ub;break}}}else if((T|0)==1){if(!Ca){Wb=Bb;Xb=ub;break}Ib=yb&255;Hb=0;wb=pb;while(1){mrc(wb|0,Ib|0,vb|0)|0;Gb=Hb+1|0;if((Gb|0)<(Da|0)){Hb=Gb;wb=wb+ka|0}else{break}}Wb=c[n>>2]|0;Xb=c[r>>2]|0}else{Wb=Bb;Xb=ub}}while(0);if((Xb-Wb|0)>>>0<(ca((T&-Jb)+2|0,xb)|0)>>>0){U=213;break b}if((xb|0)==0){Eb=Ab;Fb=yb;break}else{_b=Ab;$b=0}while(1){m:do{if(Cb){ac=_b}else{switch((c[A>>2]|0)+xa|0){case 9:{Db=c[n>>2]|0;if(((c[r>>2]|0)-Db|0)<4){ac=0;break m}c[n>>2]=Db+4;wb=Db;ac=je(d[wb]|d[wb+1|0]<<8|d[wb+2|0]<<16|d[wb+3|0]<<24|0)|0;break m;break};case 2:case 3:{wb=c[n>>2]|0;if(((c[r>>2]|0)-wb|0)<1){ac=0;break m}c[n>>2]=wb+1;ac=d[wb]|0;break m;break};case 4:{wb=c[n>>2]|0;if(((c[r>>2]|0)-wb|0)<2){ac=0;break m}c[n>>2]=wb+2;Db=wb;ac=(d[Db]|d[Db+1|0]<<8)<<16>>16&65535;break m;break};case 5:{Db=c[n>>2]|0;if(((c[r>>2]|0)-Db|0)<2){ac=0;break m}c[n>>2]=Db+2;wb=Db;ac=(he((d[wb]|d[wb+1|0]<<8)<<16>>16|0)|0)&65535;break m;break};case 8:{wb=c[n>>2]|0;if(((c[r>>2]|0)-wb|0)<4){ac=0;break m}c[n>>2]=wb+4;Db=wb;ac=d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0;break m;break};default:{ac=0;break m}}}}while(0);Db=c[n>>2]|0;wb=c[r>>2]|0;if((wb-Db|0)<1){bc=0;cc=Db}else{Hb=Db+1|0;c[n>>2]=Hb;bc=d[Db]|0;cc=Hb}if((wb-cc|0)<1){dc=0}else{c[n>>2]=cc+1;dc=d[cc]|0}wb=bc>>>4;Hb=dc>>>4;if((wb+1+Hb|0)>(Ga|0)){U=232;break b}Db=bc&15;Ib=dc&15;if((Db+1+Ib|0)>(Ba|0)){U=232;break b}Gb=Hb+1|0;Hb=Ib+1|0;Ib=pb+((ca(Db,ka)|0)+(ca(wb,T)|0))|0;if((T|0)==4){wb=0;Db=Ib;while(1){Mb=Db;Lb=0;do{c[Mb+(Lb<<2)>>2]=ac;Lb=Lb+1|0;}while((Lb|0)<(Gb|0));Lb=wb+1|0;if((Lb|0)<(Hb|0)){wb=Lb;Db=Db+ka|0}else{break}}}else if((T|0)==2){Db=ac&65535;wb=0;Lb=Ib;while(1){Mb=0;Kb=Lb;while(1){b[Kb>>1]=Db;Nb=Mb+1|0;if((Nb|0)<(Gb|0)){Mb=Nb;Kb=Kb+2|0}else{break}}Kb=wb+1|0;if((Kb|0)<(Hb|0)){wb=Kb;Lb=Lb+ka|0}else{break}}}else if((T|0)==1){Lb=ac&255;wb=0;Db=Ib;while(1){mrc(Db|0,Lb|0,Gb|0)|0;Kb=wb+1|0;if((Kb|0)<(Hb|0)){wb=Kb;Db=Db+ka|0}else{break}}}Db=$b+1|0;if((Db|0)<(xb|0)){_b=ac;$b=Db}else{Eb=ac;Fb=yb;break}}}}while(0);if((nb|0)>=(_|0)){lb=Fb;mb=Eb;break g}Ga=c[n>>2]|0;Cb=c[r>>2]|0;if((Cb|0)==(Ga|0)){U=144;break b}else{ob=vb;pb=pb+X|0;qb=nb;rb=Eb;sb=Fb;tb=Ga;ub=Cb}}}}while(0);if((va|0)<(aa|0)){za=lb;oa=mb;na=va;ua=ua+wa|0;Aa=Da}else{break}}}else if((ja|0)==1464686186){c[n>>2]=ba+(ma>>>0>2>>>0?6:ma+4|0);break}else if((ja|0)==0){fa=T;ga=ka;ha=la;ia=ma;U=109;break}else if((ja|0)==1464686181){c[n>>2]=ba+(ma>>>0>2>>>0?6:ma+4|0);break}else if((ja|0)==1464686182){c[L>>2]=V-(c[J>>2]|0);c[M>>2]=Y-(c[B>>2]|0);break}else{U=247;break b}}}while(0);do{if((U|0)==109){U=0;ec=c[O>>2]|0;if((_+V|0)>(ec|0)){U=110;break b}S=c[P>>2]|0;if((aa+Y|0)>(S|0)){fc=S;U=112;break b}gc=ca(ca(aa,_)|0,fa)|0;if((ia|0)<(gc|0)){U=114;break b}if((aa|0)==0){break}S=(_|0)==0;Aa=(c[A>>2]|0)+(fa<<1)|0;wa=0;ua=ha;while(1){n:do{if(!S){na=ua;oa=ua;za=0;while(1){o:do{switch(Aa|0){case 2:case 3:{X=c[n>>2]|0;if(((c[r>>2]|0)-X|0)<1){hc=0;break o}c[n>>2]=X+1;hc=d[X]|0;break};case 4:{X=c[n>>2]|0;if(((c[r>>2]|0)-X|0)<2){hc=0;break o}c[n>>2]=X+2;xa=X;hc=(d[xa]|d[xa+1|0]<<8)<<16>>16&65535;break};case 5:{xa=c[n>>2]|0;if(((c[r>>2]|0)-xa|0)<2){hc=0;break o}c[n>>2]=xa+2;X=xa;hc=(he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535;break};case 8:{X=c[n>>2]|0;if(((c[r>>2]|0)-X|0)<4){hc=0;break o}c[n>>2]=X+4;xa=X;hc=d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0;break};case 9:{xa=c[n>>2]|0;if(((c[r>>2]|0)-xa|0)<4){hc=0;break o}c[n>>2]=xa+4;X=xa;hc=je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0;break};default:{hc=0}}}while(0);if((fa|0)==2){b[na+(za<<1)>>1]=hc}else if((fa|0)==4){c[oa+(za<<2)>>2]=hc}else if((fa|0)==1){a[ua+za|0]=hc}za=za+1|0;if((za|0)>=(_|0)){break n}}}}while(0);Da=wa+1|0;if((Da|0)<(aa|0)){wa=Da;ua=ua+ga|0}else{break}}}}while(0);if((R|0)==0){break a}Q=R;z=c[n>>2]|0;q=c[r>>2]|0}if((U|0)==14){KIb(y,16,2442744,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1;i=j;return o|0}else if((U|0)==27){KIb(y,16,2354456,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==29){KIb(y,16,2292224,(p=i,i=i+16|0,c[p>>2]=pa,c[p+8>>2]=ma,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==33){mJb(I);mJb(H);mJb(t);c[F>>2]=0;c[E>>2]=0;c[B>>2]=0;c[J>>2]=0;o=-22;i=j;return o|0}else if((U|0)==37){mJb(I);mJb(H);mJb(t);c[F>>2]=0;c[E>>2]=0;c[B>>2]=0;c[J>>2]=0;o=ta;i=j;return o|0}else if((U|0)==106){KIb(y,32,2168528,(p=i,i=i+8|0,c[p>>2]=ib,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==110){fc=c[P>>2]|0;U=112}else if((U|0)==114){KIb(y,16,2292224,(p=i,i=i+16|0,c[p>>2]=gc,c[p+8>>2]=ia,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==137){kb=c[P>>2]|0;U=139}else if((U|0)==144){KIb(c[h>>2]|0,16,2442744,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==148){KIb(c[h>>2]|0,16,2442744,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==213){KIb(c[h>>2]|0,16,2442744,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==232){KIb(c[h>>2]|0,16,2636232,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==247){KIb(y,16,2118328,(p=i,i=i+8|0,c[p>>2]=ja,p)|0);i=p;break}if((U|0)==112){KIb(y,16,2141760,(p=i,i=i+48|0,c[p>>2]=_,c[p+8>>2]=aa,c[p+16>>2]=V,c[p+24>>2]=Y,c[p+32>>2]=ec,c[p+40>>2]=fc,p)|0);i=p;o=-1094995529;i=j;return o|0}else if((U|0)==139){KIb(y,16,2141760,(p=i,i=i+48|0,c[p>>2]=_,c[p+8>>2]=aa,c[p+16>>2]=V,c[p+24>>2]=Y,c[p+32>>2]=jb,c[p+40>>2]=kb,p)|0);i=p;o=-1094995529;i=j;return o|0}}}while(0);p=c[u>>2]|0;do{if((p|0)!=0){kb=h+808|0;jb=c[kb>>2]|0;Y=h+788|0;V=c[Y>>2]|0;aa=h+816|0;_=c[aa>>2]|0;U=h+812|0;fc=c[U>>2]|0;ec=h+792|0;ja=c[ec>>2]|0;ia=h+820|0;gc=c[ia>>2]|0;ib=(_|0)<0;ta=((V|0)<(_+jb|0)?V-_|0:jb)+(ib?_:0)|0;V=(gc|0)<0;t=((ja|0)<(gc+fc|0)?ja-gc|0:fc)+(V?gc:0)|0;if(!((ta|0)>0&(t|0)>0)){break}fc=c[m>>2]|0;ja=h+12|0;ma=c[ja>>2]|0;pa=(ca(c[fc+32>>2]|0,V?0:gc)|0)+(ca(ma,ib?0:_)|0)|0;_=(c[fc>>2]|0)+pa|0;pa=0;fc=p;ib=jb;jb=ma;while(1){nrc(fc+(ca(ca(ib,pa)|0,jb)|0)|0,_|0,ca(jb,ta)|0)|0;ic=c[m>>2]|0;jc=c[ic+32>>2]|0;ma=pa+1|0;if((ma|0)>=(t|0)){break}_=_+jc|0;pa=ma;fc=c[u>>2]|0;ib=c[kb>>2]|0;jb=c[ja>>2]|0}jb=c[kb>>2]|0;ib=c[Y>>2]|0;fc=c[aa>>2]|0;pa=c[U>>2]|0;_=c[ec>>2]|0;t=c[ia>>2]|0;ta=(fc|0)<0;y=((ib|0)<(fc+jb|0)?ib-fc|0:jb)+(ta?fc:0)|0;ib=(t|0)<0;P=((_|0)<(t+pa|0)?_-t|0:pa)+(ib?t:0)|0;if((y|0)<1|(P|0)<1){break}pa=c[ja>>2]|0;_=(c[ic>>2]|0)+((ca(pa,ta?0:fc)|0)+(ca(ib?0:t,jc)|0))|0;if((pa|0)==1){if((P|0)<=0){break}t=(y|0)>0;ib=0;fc=c[h+832>>2]|0;ta=c[h+836>>2]|0;J=_;B=jb;while(1){if(t){E=0;do{F=J+E|0;a[F]=a[fc+E|0]&a[F]^a[ta+E|0];E=E+1|0;}while((E|0)<(y|0));kc=c[kb>>2]|0}else{kc=B}E=ib+1|0;if((E|0)<(P|0)){ib=E;fc=fc+kc|0;ta=ta+kc|0;J=J+jc|0;B=kc}else{break}}}else if((pa|0)==2){if((P|0)<=0){break}B=(y|0)>0;J=0;ta=c[h+832>>2]|0;fc=c[h+836>>2]|0;ib=_;while(1){t=ib;if(B){ja=0;do{ia=t+(ja<<1)|0;b[ia>>1]=b[ta+(ja<<1)>>1]&b[ia>>1]^b[fc+(ja<<1)>>1];ja=ja+1|0;}while((ja|0)<(y|0))}ja=J+1|0;if((ja|0)<(P|0)){J=ja;ta=ta+(jb<<1)|0;fc=fc+(jb<<1)|0;ib=ib+jc|0}else{break}}}else if((pa|0)==4){if((P|0)<=0){break}ib=(y|0)>0;fc=0;ta=c[h+832>>2]|0;J=c[h+836>>2]|0;B=_;ja=jb;while(1){t=B;if(ib){ia=0;do{ec=t+(ia<<2)|0;c[ec>>2]=c[ta+(ia<<2)>>2]&c[ec>>2]^c[J+(ia<<2)>>2];ia=ia+1|0;}while((ia|0)<(y|0));lc=c[kb>>2]|0}else{lc=ja}ia=fc+1|0;if((ia|0)<(P|0)){fc=ia;ta=ta+(lc<<2)|0;J=J+(lc<<2)|0;B=B+jc|0;ja=lc}else{break}}}else{break}}}while(0);c[g>>2]=1;g=YHb(f,c[m>>2]|0)|0;o=(g|0)<0?g:l;i=j;return o|0}function R8a(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+832|0);mJb(b+836|0);mJb(b+840|0);return 0}function S8a(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+32|0;g=f|0;h=f+16|0;c[e>>2]=b;c[e+4>>2]=1;j=g|0;k=h|0;l=oib(c[b+96>>2]|0,c[b+100>>2]|0,30,j,k)|0;if((l|0)<0){KIb(b,16,2451144,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=l;i=f;return n|0}l=c[j>>2]|0;if((c[k>>2]|0)<30){KIb(b,16,2612840,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((a[l]|0)!=1){KIb(b,16,2586104,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((grc(l+1|0,2241320,6)|0)!=0){KIb(b,16,2565232,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((a[l+29|0]&1)==0){KIb(b,16,2547104,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}k=l+28|0;c[e+12>>2]=1<<(a[k]&15);c[e+16>>2]=1<<((d[k]|0)>>>4);k=c[g+8>>2]|0;g=c[h+8>>2]|0;if((g|0)<7){KIb(b,16,2354352,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((a[k]|0)!=5){KIb(b,16,2292144,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}if((grc(k+1|0,2241320,6)|0)!=0){KIb(b,16,2200272,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=f;return n|0}h=hJb(g)|0;if((h|0)==0){KIb(b,16,2168512,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-12;i=f;return n|0}if((g|0)>0){l=g-1|0;j=0;do{a[h+j|0]=a[k+(l-j)|0]|0;j=j+1|0;}while((j|0)<(g|0))}j=g<<3;g=j>>>0>2147483639>>>0;l=g?0:h;k=g?0:j;j=k+8|0;g=0;while(1){if((k-g|0)<=97){o=27;break}p=((g|0)<(j|0))+g|0;if((d[l+(g>>>3)|0]&128>>>((g&7)>>>0)|0)==0){g=p}else{o=25;break}}a:do{if((o|0)==25){if((p|0)==0){o=27;break}do{if((k-p|0)>96){g=p;q=1;r=0;s=0;while(1){t=l+(g>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(g&7);t=g+8|0;v=j>>>0>t>>>0?t:j;if(u>>>0>1073741823>>>0){w=r;x=s;break}u=l+(v>>>3)|0;t=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=v+16|0;y=j>>>0>u>>>0?u:j;if((t&-65536>>>((v&7)>>>0)|0)!=0){w=r;x=s;break}v=l+(y>>>3)|0;t=y+16|0;if(((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)&-65536>>>((y&7)>>>0)|0)!=0){w=r;x=s;break}y=(j>>>0>t>>>0?t:j)+1|0;t=j>>>0>y>>>0?y:j;if((q|0)>64){w=r;x=s;break}y=l+(t>>>3)|0;v=(((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(t&7)>>>26)+1|0)==(q|0);y=v?1:r;u=v?q:s;if((k-t|0)>96){g=t;q=q+1|0;r=y;s=u}else{w=y;x=u;break}}if((w|0)==0){break}do{if((x|0)>2){s=b;QIb(s,2118256,(m=i,i=i+8|0,c[m>>2]=x,m)|0);i=m;if((x|0)<=63){break}KIb(s,16,2636200,(m=i,i=i+8|0,c[m>>2]=x,m)|0);i=m;break a}}while(0);c[e+280>>2]=x;s=x-1|0;r=s>>>0>65535>>>0;q=r?s>>>16:s;g=r?16:0;if((q&65280|0)==0){z=g;A=q}else{z=g|8;A=q>>>8}q=(2<<z+1+(d[1359664+A|0]|0))-2|0;c[e+284>>2]=q;c[e+288>>2]=(q|1)+1;if((p|0)<0){B=0}else{B=(j|0)<(p|0)?j:p}if((x|0)>0){q=B;g=s;while(1){s=-q|0;r=j-q|0;if((s|0)>40){C=s}else{C=(r|0)<40?r:40}r=C+q|0;c[e+24+(g<<2)>>2]=d[l+(r>>>3)|0]<<(r&7)>>>7&1;if((g|0)>0){q=((r|0)<(j|0))+r|0;g=g-1|0}else{break}}}kJb(h);c[e+8>>2]=1;c[e+20>>2]=c[e+12+(c[e+24>>2]<<2)>>2];n=0;i=f;return n|0}}while(0);KIb(b,16,2141736,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);if((o|0)==27){KIb(b,16,2141736,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}kJb(h);n=-1094995529;i=f;return n|0}function T8a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;if(!((c[b+8>>2]|0)!=0&(e|0)>0)){h=0;i=g;return h|0}e=b+20|0;j=c[e>>2]|0;k=a[d]|0;d=k&255;if((d&1|0)!=0){do{if((f|0)!=0){if((k<<24>>24|0)==1){l=c[f>>2]|1}else if((k<<24>>24|0)==3){l=c[f>>2]|2}else{break}c[f>>2]=l;h=0;i=g;return h|0}}while(0);KIb(c[b>>2]|0,16,2589104,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=g;return h|0}l=c[b+280>>2]|0;if((l|0)==1){n=0}else{n=(c[b+284>>2]&d)>>>1}if((n|0)>=(l|0)){KIb(c[b>>2]|0,16,2442640,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;h=-1094995529;i=g;return h|0}m=c[b+24+(n<<2)>>2]|0;if((m|0)==0){o=j}else{o=c[b+12+(((d&c[b+288>>2]|0)!=0)<<2)>>2]|0}d=c[b+12+(m<<2)>>2]|0;c[e>>2]=d;h=d+o>>2;i=g;return h|0}function U8a(a){a=a|0;if((c[a+8>>2]|0)==0){return}c[a+20>>2]=c[a+12>>2];return}function V8a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0,i=0.0,j=0;if((c|0)>0){d=0}else{return}do{e=a+(d<<2)|0;f=+g[e>>2];h=b+(d<<2)|0;i=+g[h>>2];j=i>0.0;do{if(f>0.0){if(j){g[h>>2]=f-i;break}else{g[h>>2]=f;g[e>>2]=i+ +g[e>>2];break}}else{if(j){g[h>>2]=f+i;break}else{g[h>>2]=f;g[e>>2]=+g[e>>2]-i;break}}}while(0);d=d+1|0;}while((d|0)<(c|0));return}function W8a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+32|0;f=e|0;g=e+16|0;h=c[b+60>>2]|0;j=h;k=c[b+96>>2]|0;l=c[b+100>>2]|0;c[h>>2]=b;d9a(h+24|0);qHb(h+28|0,c[b+88>>2]&8388608);yfa(h+64|0,b);c[b+420>>2]=8;if((l|0)==0){KIb(b,16,2222800,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}o=f|0;p=g|0;q=oib(k,l,30,o,p)|0;if((q|0)<0){KIb(b,16,2219080,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=q;i=e;return n|0}q=c[o>>2]|0;o=c[p>>2]<<3;p=o>>>0>2147483639>>>0|(q|0)==0;l=p?0:q;q=p?0:o;o=h+4|0;c[o>>2]=l;p=h+16|0;c[p>>2]=q;k=q+8|0;r=h+20|0;c[r>>2]=k;s=h+8|0;c[s>>2]=l+(q>>3);q=h+12|0;c[q>>2]=0;t=l;l=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24)&255;c[q>>2]=k>>>0>8>>>0?8:k;if((l|0)!=1){KIb(b,16,2216104,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=e;return n|0}l=$8a(j)|0;if((l|0)!=0){KIb(b,16,2442568,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;_8a(j);n=l;i=e;return n|0}l=c[f+8>>2]|0;f=c[g+8>>2]<<3;g=f>>>0>2147483639>>>0|(l|0)==0;k=g?0:l;l=g?0:f;c[o>>2]=k;c[p>>2]=l;p=l+8|0;c[r>>2]=p;c[s>>2]=k+(l>>3);c[q>>2]=0;l=k;k=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)&255;c[q>>2]=p>>>0>8>>>0?8:p;if((k|0)!=5){KIb(b,16,2213504,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;_8a(j);n=-1094995529;i=e;return n|0}k=a9a(j)|0;if((k|0)!=0){KIb(b,16,2292016,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;_8a(j);n=k;i=e;return n|0}k=h+220|0;j=a[k]|0;if((j&255)>>>0>8>>>0){m=b+448|0;c[m>>2]=0;c[m+4>>2]=0}else{m=1254952+((j&255)-1<<3)|0;j=c[m+4>>2]|0;p=b+448|0;c[p>>2]=c[m>>2];c[p+4>>2]=j}c[b+416>>2]=d[k]|0;c[b+412>>2]=c[h+224>>2];n=0;i=e;return n|0}function X8a(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0;l=i;i=i+1792|0;m=l|0;n=l+256|0;o=l+512|0;p=l+768|0;q=c[k+24>>2]|0;r=c[k+28>>2]|0;k=c[f+60>>2]|0;s=k;t=h;u=k+4|0;v=a[q]|0;w=(r|0)>7;if(v<<24>>24==1&w){x=q+1|0;y=(r<<3)-8|0;z=y>>>0>2147483639>>>0|(x|0)==0;A=z?0:x;x=z?0:y;c[u>>2]=A;c[k+16>>2]=x;c[k+20>>2]=x+8;c[k+8>>2]=A+(x>>3);c[k+12>>2]=0;_8a(s);x=$8a(s)|0;if((x|0)!=0){KIb(f,16,2442568,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;_8a(s);C=x;i=l;return C|0}x=k+220|0;A=a[x]|0;if((A&255)>>>0>8>>>0){y=f+448|0;c[y>>2]=0;c[y+4>>2]=0}else{y=1254952+((A&255)-1<<3)|0;A=c[y+4>>2]|0;z=f+448|0;c[z>>2]=c[y>>2];c[z+4>>2]=A}c[f+416>>2]=d[x]|0;c[f+412>>2]=c[k+224>>2];C=r;i=l;return C|0}if(v<<24>>24==3&w){KIb(f,48,2354256,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=r;i=l;return C|0}x=c[k+300>>2]|0;do{if(v<<24>>24==5&w){if((x|0)==0){break}if((c[k+292>>2]|0)!=0){D=17;break}A=q+1|0;z=(r<<3)-8|0;y=z>>>0>2147483639>>>0|(A|0)==0;E=y?0:A;A=y?0:z;c[u>>2]=E;c[k+16>>2]=A;c[k+20>>2]=A+8;c[k+8>>2]=E+(A>>3);c[k+12>>2]=0;A=a9a(s)|0;if((A|0)==0){C=r;i=l;return C|0}KIb(f,16,2292016,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;_8a(s);C=A;i=l;return C|0}else{if((x|0)!=0){D=17}}}while(0);do{if((D|0)==17){x=k+300|0;w=k+292|0;if((c[w>>2]|0)==0){break}v=k+244|0;A=h+76|0;c[A>>2]=(c[v>>2]|0)>>>1;E=M4a(f,t,0)|0;if((E|0)<0){C=E;i=l;return C|0}E=k+220|0;z=a[E]|0;do{if((z&255)>>>0>8>>>0){y=c[h+64>>2]|0;F=z&255;H=0;while(1){c[p+(H<<2)>>2]=c[y+(H<<2)>>2];I=H+1|0;if((I|0)<(F|0)){H=I}else{J=z;break}}}else{if(z<<24>>24==0){J=0;break}H=z&255;F=c[h+64>>2]|0;y=0;while(1){c[p+(d[1255024+(H-1<<3)+y|0]<<2)>>2]=c[F+(y<<2)>>2];I=y+1|0;if((I|0)<(H|0)){y=I}else{J=z;break}}}}while(0);z=r<<3;y=z>>>0>2147483639>>>0|(q|0)==0;H=y?0:q;F=y?0:z;z=u;c[z>>2]=H;c[k+16>>2]=F;y=F+8|0;I=k+20|0;c[I>>2]=y;c[k+8>>2]=H+(F>>3);F=k+12|0;c[F>>2]=0;K=n|0;L=k+297|0;M=a[L]|0;N=M<<24>>24;O=c[x>>2]|0;P=J&255;Q=a[H]|0;R=(y|0)>0|0;c[F>>2]=R;a:do{if((Q&1)==0){S=a[k+288|0]|0;do{if(S<<24>>24==1){T=0;U=R}else{V=S&255;W=(V<<1)-2|0;X=W>>>0>65535>>>0;Y=X?W>>>16:W;W=X?16:0;if((Y&65280|0)==0){Z=W;_=Y}else{Z=W|8;_=Y>>>8}Y=(d[1359664+_|0]|0)+Z|0;W=H;X=32-Y|0;$=(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)>>>(R>>>0)<<X>>>(X>>>0);X=Y+R|0;Y=y>>>0>X>>>0?X:y;c[F>>2]=Y;if($>>>0<V>>>0){T=$;U=Y;break}KIb(c[k>>2]|0,16,1076504,(B=i,i=i+40|0,c[B>>2]=$,c[B+8>>2]=V-1,c[B+16>>2]=2168432,c[B+24>>2]=2141688,c[B+32>>2]=1572,B)|0);i=B;aa=-1094995529;break a}}while(0);a[k+296|0]=T;S=c[w>>2]|0;V=d[S+(T<<3)+6|0]|0;$=c[k+284>>2]|0;Y=$+(V*48|0)|0;X=a[S+(T<<3)|0]|0;S=X&255;W=c[s+240+(S<<2)>>2]|0;ba=W>>>1;if(X<<24>>24==0){da=M<<24>>24<0?0:N}else{ea=H+(U>>>3)|0;fa=(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)>>>((U&7)>>>0);ea=U+2|0;c[F>>2]=y>>>0>ea>>>0?ea:y;da=M<<24>>24<0?fa>>>1&1:N}fa=ba<<2;mrc(O|0,0,ca(fa,P)|0)|0;b:do{if((a[E]|0)==0){ga=0}else{ea=0;do{mrc(c[p+(ea<<2)>>2]|0,0,fa|0)|0;ea=ea+1|0;ha=a[E]|0;}while((ea|0)<(ha&255|0));if(ha<<24>>24==0){ga=0;break}ea=Y|0;ia=$+(V*48|0)+12|0;ja=k+268|0;ka=$+(V*48|0)+16|0;la=0;while(1){if((d[ea]|0)>>>0>1>>>0){ma=(c[ja>>2]|0)+((d[(d[(c[ia>>2]|0)+la|0]|0)+($+(V*48|0)+16)|0]|0)*356|0)|0}else{ma=(c[ja>>2]|0)+((d[ka]|0)*356|0)|0}na=Ee[c[ma+4>>2]&511](s,ma+8|0,c[p+(la<<2)>>2]|0)|0;if((na|0)<0){break}a[m+la|0]=na;na=la+1|0;oa=a[E]|0;if((na|0)<(oa&255|0)){la=na}else{ga=oa;break b}}KIb(c[k>>2]|0,16,2118104,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}}while(0);fa=$+(V*48|0)+2|0;la=b[fa>>1]|0;if(!(la<<16>>16==0)){ka=c[$+(V*48|0)+4>>2]|0;ja=c[$+(V*48|0)+8>>2]|0;ia=la&65535;do{ia=ia-1|0;la=m+(d[ka+ia|0]|0)|0;ea=m+(d[ja+ia|0]|0)|0;if((a[ea]&a[la])<<24>>24==0){a[la]=0;a[ea]=0}}while((ia|0)>0)}ia=Y|0;ja=a[ia]|0;c:do{if(ja<<24>>24==0){pa=P}else{ka=k+276|0;ea=k+260|0;la=$+(V*48|0)+12|0;oa=P;na=0;qa=O;ra=0;sa=ja;ta=ga;d:while(1){if(ta<<24>>24==0){ua=0;va=na}else{wa=sa<<24>>24==1;xa=ta&255;ya=0;za=na;Aa=0;while(1){if(wa){D=57}else{if((ra|0)==(d[(c[la>>2]|0)+Aa|0]|0)){D=57}else{Ba=za;Ca=ya}}if((D|0)==57){D=0;a[o+Aa|0]=za;a[n+ya|0]=(a[m+Aa|0]|0)!=0|0;Ba=za+1|0;Ca=ya+1|0}Da=Aa+1|0;if((Da|0)<(xa|0)){ya=Ca;za=Ba;Aa=Da}else{ua=Ca;va=Ba;break}}}Aa=d[$+(V*48|0)+32+ra|0]|0;za=c[ka>>2]|0;if(oa>>>0<ua>>>0){D=60;break}do{if((ua|0)!=0){ya=b[za+(Aa*1052|0)>>1]|0;if((ya<<16>>16|0)==1){xa=za+(Aa*1052|0)+17|0;wa=a[(c[ea>>2]|0)+(d[xa]<<5)|0]|0;Da=wa&255;Ea=za+(Aa*1052|0)+1048|0;Fa=c[Ea>>2]|0;Ga=ca(ua-1|0,ba)|0;Ha=za+(Aa*1052|0)+1044|0;Ia=b[Ha>>1]|0;Ja=Ia&65535;if(((c[za+(Aa*1052|0)+8>>2]|0)+Ga|0)>>>0>(ca(oa,ba)|0)>>>0){D=131;break d}Ga=za+(Aa*1052|0)+1042|0;Ka=za+(Aa*1052|0)+4|0;La=Ia<<16>>16==0;Ia=za+(Aa*1052|0)+16|0;Ma=wa<<24>>24!=0;wa=za+(Aa*1052|0)+12|0;Na=-Da|0;Oa=0;do{if(!La){Pa=(Oa|0)==0;Qa=c[Ka>>2]|0;Ra=0;while(1){e:do{if(Pa){Sa=Ra-1+(d[(c[ea>>2]|0)+(d[xa]<<5)|0]|0)|0;Ta=(Sa|0)<(Ra|0);Ua=c[1367848+(d[Ia]<<2)>>2]|0;Va=0;Wa=0;Xa=0;while(1){f:do{if((a[n+Wa|0]|0)==0){Ya=d[xa]|0;Za=c[ea>>2]|0;_a=c[Za+(Ya<<5)+8>>2]|0;$a=c[Za+(Ya<<5)+28>>2]|0;Ya=c[F>>2]|0;Za=c[I>>2]|0;ab=c[z>>2]|0;bb=ab+(Ya>>>3)|0;cb=32-$a|0;db=(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)>>>((Ya&7)>>>0)<<cb>>>(cb>>>0);cb=b[_a+(db<<2)>>1]|0;bb=b[_a+(db<<2)+2>>1]|0;db=bb<<16>>16;do{if(bb<<16>>16<0){eb=Ya+$a|0;fb=Za>>>0>eb>>>0?eb:Za;eb=ab+(fb>>>3)|0;gb=db+32|0;hb=((d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((fb&7)>>>0)<<gb>>>(gb>>>0))+cb|0;gb=b[_a+(hb<<2)>>1]|0;eb=b[_a+(hb<<2)+2>>1]|0;hb=eb<<16>>16;if(!(eb<<16>>16<0)){ib=hb;jb=gb;kb=fb;break}eb=fb-db|0;fb=Za>>>0>eb>>>0?eb:Za;eb=ab+(fb>>>3)|0;lb=hb+32|0;hb=((d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((fb&7)>>>0)<<lb>>>(lb>>>0))+gb|0;ib=b[_a+(hb<<2)+2>>1]|0;jb=b[_a+(hb<<2)>>1]|0;kb=fb}else{ib=db;jb=cb;kb=Ya}}while(0);Ya=ib+kb|0;c[F>>2]=Za>>>0>Ya>>>0?Ya:Za;if((jb|0)<0){aa=jb;break a}Ya=a[Ia]|0;if(!((Ya&255)>>>0>1>>>0)){D=144;break d}if(jb>>>0<65537>>>0){if(Ta){break}else{mb=Sa;nb=jb}while(1){Erc(nb,0,Ua,Va)|0;cb=G;if((mb|0)<(e[Ha>>1]|0)){db=nb-(ca(d[Ia]|0,cb)|0)&255;a[(c[Ea>>2]|0)+(mb+Xa)|0]=db}db=mb-1|0;if((db|0)<(Ra|0)){break f}else{mb=db;nb=cb}}}if(Ta){break}else{ob=Sa;pb=jb;qb=Ya}while(1){Za=qb&255;cb=(pb>>>0)/(Za>>>0)|0;if((ob|0)<(e[Ha>>1]|0)){db=pb-(ca(cb,Za)|0)&255;a[(c[Ea>>2]|0)+(ob+Xa)|0]=db}db=ob-1|0;if((db|0)<(Ra|0)){break f}ob=db;pb=cb;qb=a[Ia]|0}}}while(0);Ya=Wa+1|0;if(!(Ya>>>0<ua>>>0)){break e}Wa=Ya;Xa=(e[Ha>>1]|0)+Xa|0}}}while(0);if(Ma&(Ra|0)<(Ja|0)){Xa=Qa;Wa=Ra;Sa=0;do{Ta=0;Va=0;while(1){do{if((a[n+Va|0]|0)==0){Ua=b[za+(Aa*1052|0)+18+(d[Fa+(Ta+Wa)|0]<<4)+(Oa<<1)>>1]|0;if(!(Ua<<16>>16>-1)){break}Ya=Ua<<16>>16;Ua=c[ea>>2]|0;cb=c[Ua+(Ya<<5)+24>>2]|0;if((cb|0)==0){break}db=a[Ua+(Ya<<5)|0]|0;Za=db&255;_a=c[wa>>2]|0;Erc(_a<<1|0>>>31,0<<1|_a>>>31,c[1367848+(Za<<1<<2)>>2]|0,0)|0;_a=G;ab=c[Ua+(Ya<<5)+8>>2]|0;$a=c[Ua+(Ya<<5)+28>>2]|0;if((_a|0)==0){break}Ya=(ca(Va,ba)|0)+Xa|0;Ua=32-$a|0;bb=db<<24>>24==0;db=c[I>>2]|0;fb=c[z>>2]|0;hb=Ya;Ya=0;gb=c[F>>2]|0;while(1){lb=fb+(gb>>>3)|0;eb=(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)>>>((gb&7)>>>0)<<Ua>>>(Ua>>>0);lb=b[ab+(eb<<2)>>1]|0;rb=b[ab+(eb<<2)+2>>1]|0;eb=rb<<16>>16;do{if(rb<<16>>16<0){sb=gb+$a|0;tb=db>>>0>sb>>>0?sb:db;sb=fb+(tb>>>3)|0;ub=eb+32|0;vb=((d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)>>>((tb&7)>>>0)<<ub>>>(ub>>>0))+lb|0;ub=b[ab+(vb<<2)>>1]|0;sb=b[ab+(vb<<2)+2>>1]|0;vb=sb<<16>>16;if(!(sb<<16>>16<0)){wb=vb;xb=ub;yb=tb;break}sb=tb-eb|0;tb=db>>>0>sb>>>0?sb:db;sb=fb+(tb>>>3)|0;zb=vb+32|0;vb=((d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)>>>((tb&7)>>>0)<<zb>>>(zb>>>0))+ub|0;wb=b[ab+(vb<<2)+2>>1]|0;xb=b[ab+(vb<<2)>>1]|0;yb=tb}else{wb=eb;xb=lb;yb=gb}}while(0);lb=wb+yb|0;eb=db>>>0>lb>>>0?lb:db;c[F>>2]=eb;lb=ca(xb,Za)|0;if(bb){Ab=hb}else{rb=hb;tb=0;while(1){vb=qa+(rb<<2)|0;g[vb>>2]=+g[cb+(tb+lb<<2)>>2]+ +g[vb>>2];vb=tb+1|0;if(vb>>>0<Za>>>0){rb=rb+1|0;tb=vb}else{break}}Ab=hb+Za|0}tb=Ya+1|0;if(tb>>>0<_a>>>0){hb=Ab;Ya=tb;gb=eb}else{break}}}}while(0);gb=Va+1|0;if(!(gb>>>0<ua>>>0)){break}Ta=Ta+Ja|0;Va=gb}Wa=Wa+1|0;Xa=(c[wa>>2]|0)+Xa|0;Sa=Sa+1|0;}while(Sa>>>0<Da>>>0&(Wa|0)<(Ja|0));Wa=Ra-Ja|0;Bb=Xa;Cb=Ra-(Wa>>>0<Na>>>0?Na:Wa)|0}else{Bb=Qa;Cb=Ra}if((Cb|0)<(Ja|0)){Qa=Bb;Ra=Cb}else{break}}}Oa=Oa+1|0;}while(!(Oa>>>0>(d[Ga]|0)>>>0))}else if((ya<<16>>16|0)==0){Ga=za+(Aa*1052|0)+17|0;Oa=a[(c[ea>>2]|0)+(d[Ga]<<5)|0]|0;Ja=Oa&255;Na=za+(Aa*1052|0)+1048|0;Da=c[Na>>2]|0;wa=ca(ua-1|0,ba)|0;Fa=za+(Aa*1052|0)+1044|0;Ma=b[Fa>>1]|0;Ha=Ma&65535;if(((c[za+(Aa*1052|0)+8>>2]|0)+wa|0)>>>0>(ca(oa,ba)|0)>>>0){D=177;break d}wa=za+(Aa*1052|0)+1042|0;Ia=za+(Aa*1052|0)+4|0;Ea=Ma<<16>>16==0;Ma=za+(Aa*1052|0)+16|0;xa=Oa<<24>>24!=0;Oa=za+(Aa*1052|0)+12|0;Ka=-Ja|0;La=0;do{if(!Ea){Ra=(La|0)==0;Qa=c[Ia>>2]|0;Pa=0;while(1){g:do{if(Ra){Wa=Pa-1+(d[(c[ea>>2]|0)+(d[Ga]<<5)|0]|0)|0;Sa=(Wa|0)<(Pa|0);Va=c[1367848+(d[Ma]<<2)>>2]|0;Ta=0;gb=0;Ya=0;while(1){h:do{if((a[n+gb|0]|0)==0){hb=d[Ga]|0;_a=c[ea>>2]|0;Za=c[_a+(hb<<5)+8>>2]|0;cb=c[_a+(hb<<5)+28>>2]|0;hb=c[F>>2]|0;_a=c[I>>2]|0;bb=c[z>>2]|0;db=bb+(hb>>>3)|0;ab=32-cb|0;fb=(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)>>>((hb&7)>>>0)<<ab>>>(ab>>>0);ab=b[Za+(fb<<2)>>1]|0;db=b[Za+(fb<<2)+2>>1]|0;fb=db<<16>>16;do{if(db<<16>>16<0){$a=hb+cb|0;Ua=_a>>>0>$a>>>0?$a:_a;$a=bb+(Ua>>>3)|0;tb=fb+32|0;rb=((d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)>>>((Ua&7)>>>0)<<tb>>>(tb>>>0))+ab|0;tb=b[Za+(rb<<2)>>1]|0;$a=b[Za+(rb<<2)+2>>1]|0;rb=$a<<16>>16;if(!($a<<16>>16<0)){Db=rb;Eb=tb;Fb=Ua;break}$a=Ua-fb|0;Ua=_a>>>0>$a>>>0?$a:_a;$a=bb+(Ua>>>3)|0;lb=rb+32|0;rb=((d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)>>>((Ua&7)>>>0)<<lb>>>(lb>>>0))+tb|0;Db=b[Za+(rb<<2)+2>>1]|0;Eb=b[Za+(rb<<2)>>1]|0;Fb=Ua}else{Db=fb;Eb=ab;Fb=hb}}while(0);hb=Db+Fb|0;c[F>>2]=_a>>>0>hb>>>0?hb:_a;if((Eb|0)<0){aa=Eb;break a}hb=a[Ma]|0;if(!((hb&255)>>>0>1>>>0)){D=190;break d}if(Eb>>>0<65537>>>0){if(Sa){break}else{Gb=Wa;Hb=Eb}while(1){Erc(Hb,0,Va,Ta)|0;ab=G;if((Gb|0)<(e[Fa>>1]|0)){fb=Hb-(ca(d[Ma]|0,ab)|0)&255;a[(c[Na>>2]|0)+(Gb+Ya)|0]=fb}fb=Gb-1|0;if((fb|0)<(Pa|0)){break h}else{Gb=fb;Hb=ab}}}if(Sa){break}else{Ib=Wa;Jb=Eb;Kb=hb}while(1){_a=Kb&255;ab=(Jb>>>0)/(_a>>>0)|0;if((Ib|0)<(e[Fa>>1]|0)){fb=Jb-(ca(ab,_a)|0)&255;a[(c[Na>>2]|0)+(Ib+Ya)|0]=fb}fb=Ib-1|0;if((fb|0)<(Pa|0)){break h}Ib=fb;Jb=ab;Kb=a[Ma]|0}}}while(0);hb=gb+1|0;if(!(hb>>>0<ua>>>0)){break g}gb=hb;Ya=(e[Fa>>1]|0)+Ya|0}}}while(0);if(xa&(Pa|0)<(Ha|0)){Xa=Qa;Ya=Pa;gb=0;do{Wa=0;Sa=0;while(1){do{if((a[n+Sa|0]|0)==0){Ta=b[za+(Aa*1052|0)+18+(d[Da+(Wa+Ya)|0]<<4)+(La<<1)>>1]|0;if(!(Ta<<16>>16>-1)){break}Va=Ta<<16>>16;Ta=c[ea>>2]|0;hb=c[Ta+(Va<<5)+24>>2]|0;if((hb|0)==0){break}ab=a[Ta+(Va<<5)|0]|0;fb=ab&255;_a=c[Oa>>2]|0;Erc(_a<<1|0>>>31,0<<1|_a>>>31,c[1367848+(fb<<1<<2)>>2]|0,0)|0;_a=G;Za=c[Ta+(Va<<5)+8>>2]|0;bb=c[Ta+(Va<<5)+28>>2]|0;Va=(ca(Sa,ba)|0)+Xa|0;if((_a|0)==0){break}Ta=32-bb|0;cb=ab<<24>>24==0;ab=c[I>>2]|0;db=c[z>>2]|0;Ua=0;rb=c[F>>2]|0;do{tb=db+(rb>>>3)|0;lb=(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)>>>((rb&7)>>>0)<<Ta>>>(Ta>>>0);tb=b[Za+(lb<<2)>>1]|0;$a=b[Za+(lb<<2)+2>>1]|0;lb=$a<<16>>16;do{if($a<<16>>16<0){vb=rb+bb|0;ub=ab>>>0>vb>>>0?vb:ab;vb=db+(ub>>>3)|0;zb=lb+32|0;sb=((d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((ub&7)>>>0)<<zb>>>(zb>>>0))+tb|0;zb=b[Za+(sb<<2)>>1]|0;vb=b[Za+(sb<<2)+2>>1]|0;sb=vb<<16>>16;if(!(vb<<16>>16<0)){Lb=sb;Mb=zb;Nb=ub;break}vb=ub-lb|0;ub=ab>>>0>vb>>>0?vb:ab;vb=db+(ub>>>3)|0;Ob=sb+32|0;sb=((d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((ub&7)>>>0)<<Ob>>>(Ob>>>0))+zb|0;Lb=b[Za+(sb<<2)+2>>1]|0;Mb=b[Za+(sb<<2)>>1]|0;Nb=ub}else{Lb=lb;Mb=tb;Nb=rb}}while(0);tb=Lb+Nb|0;rb=ab>>>0>tb>>>0?tb:ab;c[F>>2]=rb;tb=ca(Mb,fb)|0;if(!cb){lb=Va+Ua|0;$a=0;do{eb=qa+(lb+(ca($a,_a)|0)<<2)|0;g[eb>>2]=+g[hb+($a+tb<<2)>>2]+ +g[eb>>2];$a=$a+1|0;}while($a>>>0<fb>>>0)}Ua=Ua+1|0;}while(Ua>>>0<_a>>>0)}}while(0);_a=Sa+1|0;if(!(_a>>>0<ua>>>0)){break}Wa=Wa+Ha|0;Sa=_a}Ya=Ya+1|0;Xa=(c[Oa>>2]|0)+Xa|0;gb=gb+1|0;}while(gb>>>0<Ja>>>0&(Ya|0)<(Ha|0));Ya=Pa-Ha|0;Pb=Xa;Qb=Pa-(Ya>>>0<Ka>>>0?Ka:Ya)|0}else{Pb=Qa;Qb=Pa}if((Qb|0)<(Ha|0)){Qa=Pb;Pa=Qb}else{break}}}La=La+1|0;}while(!(La>>>0>(d[wa]|0)>>>0))}else if((ya<<16>>16|0)==2){wa=za+(Aa*1052|0)+17|0;La=a[(c[ea>>2]|0)+(d[wa]<<5)|0]|0;Ha=La&255;Ka=za+(Aa*1052|0)+1048|0;Ja=c[Ka>>2]|0;Oa=ca(ua-1|0,ba)|0;Da=za+(Aa*1052|0)+1044|0;xa=b[Da>>1]|0;Fa=xa&65535;Ma=a[K]|0;if(ua>>>0>1>>>0){Na=1;Ga=Ma;while(1){Ia=a[n+Na|0]&Ga;a[K]=Ia;Ea=Na+1|0;if(Ea>>>0<ua>>>0){Na=Ea;Ga=Ia}else{Rb=Ia;break}}}else{Rb=Ma}if(!(Rb<<24>>24==0)){break}if(((((c[za+(Aa*1052|0)+8>>2]|0)>>>0)/(ua>>>0)|0)+Oa|0)>>>0>(ca(oa,ba)|0)>>>0){D=68;break d}Ga=za+(Aa*1052|0)+1042|0;Na=za+(Aa*1052|0)+4|0;ya=xa<<16>>16==0;Ia=za+(Aa*1052|0)+16|0;Ea=La<<24>>24!=0;Pa=za+(Aa*1052|0)+12|0;Qa=1367848+(ua<<1<<2)|0;Ra=-Ha|0;Ya=(ua|0)!=2;gb=0;do{if(!ya){Sa=(gb|0)==0;Wa=c[Na>>2]|0;_a=0;while(1){i:do{if(Sa){Ua=c[ea>>2]|0;fb=d[wa]|0;hb=_a-1+(d[Ua+(fb<<5)|0]|0)|0;Va=(hb|0)<(_a|0);cb=c[1367848+(d[Ia]<<2)>>2]|0;rb=0;if((a[K]|0)!=0){break}ab=c[Ua+(fb<<5)+8>>2]|0;Za=c[Ua+(fb<<5)+28>>2]|0;fb=c[F>>2]|0;Ua=c[I>>2]|0;db=c[z>>2]|0;bb=db+(fb>>>3)|0;Ta=32-Za|0;$a=(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)>>>((fb&7)>>>0)<<Ta>>>(Ta>>>0);Ta=b[ab+($a<<2)>>1]|0;bb=b[ab+($a<<2)+2>>1]|0;$a=bb<<16>>16;do{if(bb<<16>>16<0){tb=fb+Za|0;lb=Ua>>>0>tb>>>0?tb:Ua;tb=db+(lb>>>3)|0;eb=$a+32|0;ub=((d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)>>>((lb&7)>>>0)<<eb>>>(eb>>>0))+Ta|0;eb=b[ab+(ub<<2)>>1]|0;tb=b[ab+(ub<<2)+2>>1]|0;ub=tb<<16>>16;if(!(tb<<16>>16<0)){Sb=ub;Tb=eb;Ub=lb;break}tb=lb-$a|0;lb=Ua>>>0>tb>>>0?tb:Ua;tb=db+(lb>>>3)|0;sb=ub+32|0;ub=((d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)>>>((lb&7)>>>0)<<sb>>>(sb>>>0))+eb|0;Sb=b[ab+(ub<<2)+2>>1]|0;Tb=b[ab+(ub<<2)>>1]|0;Ub=lb}else{Sb=$a;Tb=Ta;Ub=fb}}while(0);fb=Sb+Ub|0;c[F>>2]=Ua>>>0>fb>>>0?fb:Ua;if((Tb|0)<0){aa=Tb;break a}fb=a[Ia]|0;if(!((fb&255)>>>0>1>>>0)){D=80;break d}if(Tb>>>0<65537>>>0){if(Va){break}else{Vb=hb;Wb=Tb}while(1){Erc(Wb,0,cb,rb)|0;Ta=G;if((Vb|0)<(e[Da>>1]|0)){$a=Wb-(ca(d[Ia]|0,Ta)|0)&255;a[(c[Ka>>2]|0)+Vb|0]=$a}$a=Vb-1|0;if(($a|0)<(_a|0)){break i}else{Vb=$a;Wb=Ta}}}if(Va){break}else{Xb=hb;Yb=Tb;Zb=fb}while(1){rb=Zb&255;cb=(Yb>>>0)/(rb>>>0)|0;if((Xb|0)<(e[Da>>1]|0)){Ua=Yb-(ca(cb,rb)|0)&255;a[(c[Ka>>2]|0)+Xb|0]=Ua}Ua=Xb-1|0;if((Ua|0)<(_a|0)){break i}Xb=Ua;Yb=cb;Zb=a[Ia]|0}}}while(0);if(Ea&(_a|0)<(Fa|0)){Xa=Wa;fb=_a;hb=1;while(1){Va=Xa&1;cb=Xa>>1;Ua=Xa;rb=Ua<<1|0>>>31;Ta=((Xa|0)<0|0?-1:0)<<1|Ua>>>31;j:do{if((a[K]|0)==0){Ua=b[za+(Aa*1052|0)+18+(d[Ja+fb|0]<<4)+(gb<<1)>>1]|0;if(!(Ua<<16>>16>-1)){break}$a=Ua<<16>>16;Ua=c[ea>>2]|0;ab=c[Ua+($a<<5)+24>>2]|0;if((ab|0)==0){break}db=a[Ua+($a<<5)|0]|0;Za=db&255;bb=c[Pa>>2]|0;Erc(bb<<1|0>>>31,0<<1|bb>>>31,c[1367848+(Za<<1<<2)>>2]|0,0)|0;bb=G;lb=c[Ua+($a<<5)+8>>2]|0;ub=c[Ua+($a<<5)+28>>2]|0;do{if(!((Va|0)!=0|Ya)){if((Za&1|0)!=0){break}if((db<<24>>24|0)==2){if((bb|0)==0){break j}$a=32-ub|0;Ua=c[I>>2]|0;eb=c[z>>2]|0;sb=0;tb=c[F>>2]|0;while(1){zb=eb+(tb>>>3)|0;Ob=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((tb&7)>>>0)<<$a>>>($a>>>0);zb=b[lb+(Ob<<2)>>1]|0;vb=b[lb+(Ob<<2)+2>>1]|0;Ob=vb<<16>>16;do{if(vb<<16>>16<0){_b=tb+ub|0;$b=Ua>>>0>_b>>>0?_b:Ua;_b=eb+($b>>>3)|0;ac=Ob+32|0;bc=((d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)>>>(($b&7)>>>0)<<ac>>>(ac>>>0))+zb|0;ac=b[lb+(bc<<2)>>1]|0;_b=b[lb+(bc<<2)+2>>1]|0;bc=_b<<16>>16;if(!(_b<<16>>16<0)){cc=bc;dc=ac;ec=$b;break}_b=$b-Ob|0;$b=Ua>>>0>_b>>>0?_b:Ua;_b=eb+($b>>>3)|0;fc=bc+32|0;bc=((d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)>>>(($b&7)>>>0)<<fc>>>(fc>>>0))+ac|0;cc=b[lb+(bc<<2)+2>>1]|0;dc=b[lb+(bc<<2)>>1]|0;ec=$b}else{cc=Ob;dc=zb;ec=tb}}while(0);zb=cc+ec|0;tb=Ua>>>0>zb>>>0?zb:Ua;c[F>>2]=tb;zb=dc<<1;Ob=sb+cb|0;vb=qa+(Ob<<2)|0;g[vb>>2]=+g[ab+(zb<<2)>>2]+ +g[vb>>2];vb=qa+(Ob+ba<<2)|0;g[vb>>2]=+g[ab+((zb|1)<<2)>>2]+ +g[vb>>2];sb=sb+1|0;if(!(sb>>>0<bb>>>0)){break j}}}else if((db<<24>>24|0)==4){if((bb|0)==0){break j}sb=32-ub|0;tb=c[I>>2]|0;Ua=c[z>>2]|0;eb=cb;$a=0;vb=c[F>>2]|0;while(1){zb=Ua+(vb>>>3)|0;Ob=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((vb&7)>>>0)<<sb>>>(sb>>>0);zb=b[lb+(Ob<<2)>>1]|0;$b=b[lb+(Ob<<2)+2>>1]|0;Ob=$b<<16>>16;do{if($b<<16>>16<0){bc=vb+ub|0;ac=tb>>>0>bc>>>0?bc:tb;bc=Ua+(ac>>>3)|0;fc=Ob+32|0;_b=((d[bc]|d[bc+1|0]<<8|d[bc+2|0]<<16|d[bc+3|0]<<24|0)>>>((ac&7)>>>0)<<fc>>>(fc>>>0))+zb|0;fc=b[lb+(_b<<2)>>1]|0;bc=b[lb+(_b<<2)+2>>1]|0;_b=bc<<16>>16;if(!(bc<<16>>16<0)){gc=_b;hc=fc;ic=ac;break}bc=ac-Ob|0;ac=tb>>>0>bc>>>0?bc:tb;bc=Ua+(ac>>>3)|0;jc=_b+32|0;_b=((d[bc]|d[bc+1|0]<<8|d[bc+2|0]<<16|d[bc+3|0]<<24|0)>>>((ac&7)>>>0)<<jc>>>(jc>>>0))+fc|0;gc=b[lb+(_b<<2)+2>>1]|0;hc=b[lb+(_b<<2)>>1]|0;ic=ac}else{gc=Ob;hc=zb;ic=vb}}while(0);zb=gc+ic|0;Ob=tb>>>0>zb>>>0?zb:tb;c[F>>2]=Ob;zb=hc<<2;$b=qa+(eb<<2)|0;g[$b>>2]=+g[ab+(zb<<2)>>2]+ +g[$b>>2];$b=qa+(eb+1<<2)|0;g[$b>>2]=+g[ab+((zb|2)<<2)>>2]+ +g[$b>>2];$b=eb+ba|0;ac=qa+($b<<2)|0;g[ac>>2]=+g[ab+((zb|1)<<2)>>2]+ +g[ac>>2];ac=qa+($b+1<<2)|0;g[ac>>2]=+g[ab+((zb|3)<<2)>>2]+ +g[ac>>2];ac=$a+1|0;if(ac>>>0<bb>>>0){eb=eb+2|0;$a=ac;vb=Ob}else{break j}}}else{if((bb|0)==0){break j}vb=32-ub|0;$a=db<<24>>24==0;eb=c[I>>2]|0;tb=c[z>>2]|0;Ua=cb;sb=0;Ob=c[F>>2]|0;while(1){ac=tb+(Ob>>>3)|0;zb=(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)>>>((Ob&7)>>>0)<<vb>>>(vb>>>0);ac=b[lb+(zb<<2)>>1]|0;$b=b[lb+(zb<<2)+2>>1]|0;zb=$b<<16>>16;do{if($b<<16>>16<0){_b=Ob+ub|0;fc=eb>>>0>_b>>>0?_b:eb;_b=tb+(fc>>>3)|0;jc=zb+32|0;bc=((d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)>>>((fc&7)>>>0)<<jc>>>(jc>>>0))+ac|0;jc=b[lb+(bc<<2)>>1]|0;_b=b[lb+(bc<<2)+2>>1]|0;bc=_b<<16>>16;if(!(_b<<16>>16<0)){kc=bc;lc=jc;mc=fc;break}_b=fc-zb|0;fc=eb>>>0>_b>>>0?_b:eb;_b=tb+(fc>>>3)|0;nc=bc+32|0;bc=((d[_b]|d[_b+1|0]<<8|d[_b+2|0]<<16|d[_b+3|0]<<24|0)>>>((fc&7)>>>0)<<nc>>>(nc>>>0))+jc|0;kc=b[lb+(bc<<2)+2>>1]|0;lc=b[lb+(bc<<2)>>1]|0;mc=fc}else{kc=zb;lc=ac;mc=Ob}}while(0);ac=kc+mc|0;zb=eb>>>0>ac>>>0?ac:eb;c[F>>2]=zb;ac=ca(lc,Za)|0;if($a){oc=Ua}else{$b=Ua;fc=0;while(1){bc=fc+ac|0;jc=qa+($b<<2)|0;g[jc>>2]=+g[ab+(bc<<2)>>2]+ +g[jc>>2];jc=qa+($b+ba<<2)|0;g[jc>>2]=+g[ab+(bc+1<<2)>>2]+ +g[jc>>2];jc=fc+2|0;bc=$b+1|0;if(jc>>>0<Za>>>0){$b=bc;fc=jc}else{oc=bc;break}}}fc=sb+1|0;if(fc>>>0<bb>>>0){Ua=oc;sb=fc;Ob=zb}else{break j}}}}}while(0);Erc(rb,Ta,c[Qa>>2]|0,0)|0;Ob=G;if((bb|0)==0){break}sb=Xa-(ca(Ob,ua)|0)|0;Ua=32-ub|0;$a=db<<24>>24==0;eb=c[I>>2]|0;tb=c[z>>2]|0;vb=0;fc=Ob;Ob=sb;sb=c[F>>2]|0;while(1){$b=tb+(sb>>>3)|0;ac=(d[$b]|d[$b+1|0]<<8|d[$b+2|0]<<16|d[$b+3|0]<<24|0)>>>((sb&7)>>>0)<<Ua>>>(Ua>>>0);$b=b[lb+(ac<<2)>>1]|0;bc=b[lb+(ac<<2)+2>>1]|0;ac=bc<<16>>16;do{if(bc<<16>>16<0){jc=sb+ub|0;nc=eb>>>0>jc>>>0?jc:eb;jc=tb+(nc>>>3)|0;_b=ac+32|0;pc=((d[jc]|d[jc+1|0]<<8|d[jc+2|0]<<16|d[jc+3|0]<<24|0)>>>((nc&7)>>>0)<<_b>>>(_b>>>0))+$b|0;_b=b[lb+(pc<<2)>>1]|0;jc=b[lb+(pc<<2)+2>>1]|0;pc=jc<<16>>16;if(!(jc<<16>>16<0)){qc=pc;rc=_b;sc=nc;break}jc=nc-ac|0;nc=eb>>>0>jc>>>0?jc:eb;jc=tb+(nc>>>3)|0;tc=pc+32|0;pc=((d[jc]|d[jc+1|0]<<8|d[jc+2|0]<<16|d[jc+3|0]<<24|0)>>>((nc&7)>>>0)<<tc>>>(tc>>>0))+_b|0;qc=b[lb+(pc<<2)+2>>1]|0;rc=b[lb+(pc<<2)>>1]|0;sc=nc}else{qc=ac;rc=$b;sc=sb}}while(0);$b=qc+sc|0;ac=eb>>>0>$b>>>0?$b:eb;c[F>>2]=ac;$b=ca(rc,Za)|0;if($a){uc=fc;vc=Ob}else{bc=0;nc=fc;pc=Ob;while(1){_b=qa+((ca(pc,ba)|0)+nc<<2)|0;g[_b>>2]=+g[ab+(bc+$b<<2)>>2]+ +g[_b>>2];_b=pc+1|0;tc=(_b|0)==(ua|0);jc=(tc&1)+nc|0;wc=tc?0:_b;_b=bc+1|0;if(_b>>>0<Za>>>0){bc=_b;nc=jc;pc=wc}else{uc=jc;vc=wc;break}}}pc=vb+1|0;if(pc>>>0<bb>>>0){vb=pc;fc=uc;Ob=vc;sb=ac}else{break}}}}while(0);Ta=fb+1|0;xc=(c[Pa>>2]|0)+Xa|0;if(!(hb>>>0<Ha>>>0&(Ta|0)<(Fa|0))){break}Xa=xc;fb=Ta;hb=hb+1|0}hb=_a-Fa|0;yc=xc;zc=_a-(hb>>>0<Ra>>>0?Ra:hb)|0}else{yc=Wa;zc=_a}if((zc|0)<(Fa|0)){Wa=yc;_a=zc}else{break}}}gb=gb+1|0;}while(!(gb>>>0>(d[Ga]|0)>>>0))}else{D=221;break d}}}while(0);Aa=oa-ua|0;za=ra+1|0;Ga=a[ia]|0;if((za|0)>=(Ga&255|0)){pa=Aa;break c}gb=qa+((ca(ua,ba)|0)<<2)|0;oa=Aa;na=va;qa=gb;ra=za;sa=Ga;ta=a[E]|0}if((D|0)==60){KIb(c[k>>2]|0,16,2636128,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}else if((D|0)==68){KIb(c[k>>2]|0,16,2586016,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}else if((D|0)==80){KIb(0,0,2565128,(B=i,i=i+24|0,c[B>>2]=2547032,c[B+8>>2]=2141688,c[B+16>>2]=1334,B)|0);i=B;Hd();return 0}else if((D|0)==131){KIb(c[k>>2]|0,16,2586016,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}else if((D|0)==144){KIb(0,0,2565128,(B=i,i=i+24|0,c[B>>2]=2547032,c[B+8>>2]=2141688,c[B+16>>2]=1334,B)|0);i=B;Hd();return 0}else if((D|0)==177){KIb(c[k>>2]|0,16,2586016,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}else if((D|0)==190){KIb(0,0,2565128,(B=i,i=i+24|0,c[B>>2]=2547032,c[B+8>>2]=2141688,c[B+16>>2]=1334,B)|0);i=B;Hd();return 0}else if((D|0)==221){KIb(c[k>>2]|0,16,2612704,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529;break a}}}while(0);if((pa|0)!=0){aa=-1094995529;break}ia=b[fa>>1]|0;if(!(ia<<16>>16==0)){ja=$+(V*48|0)+4|0;Y=$+(V*48|0)+8|0;ta=k+24|0;sa=ia&65535;do{sa=sa-1|0;ia=c[x>>2]|0;ra=ia+((ca(d[o+(d[(c[ja>>2]|0)+sa|0]|0)|0]|0,W)|0)>>>1<<2)|0;qa=ia+((ca(d[o+(d[(c[Y>>2]|0)+sa|0]|0)|0]|0,W)|0)>>>1<<2)|0;ef[c[ta>>2]&4095](ra,qa,ba);}while((sa|0)>0)}sa=s+84+(S<<6)|0;ta=a[E]|0;do{if(ta<<24>>24==0){Ac=((c[s+240+(da<<2)>>2]|0)+W|0)>>>2}else{Y=k+28|0;ja=s+84+(S<<6)+44|0;V=ta&255;do{V=V-1|0;$=(c[x>>2]|0)+((ca(d[o+V|0]|0,W)|0)>>>1<<2)|0;fa=c[p+(V<<2)>>2]|0;mf[c[Y>>2]&2047](fa,fa,$,ba);ef[c[ja>>2]&4095](sa,$,fa);}while((V|0)>0);V=((c[s+240+(da<<2)>>2]|0)+W|0)>>>2;if((a[E]|0)==0){Ac=V;break}ja=k+240|0;Y=k+304|0;fa=s+248+((da&S)<<2)|0;$=(S|0)==(da|0);qa=k+44|0;ra=W>>>2;ia=ra<<2;na=S>>>0>da>>>0;oa=0;while(1){ea=c[ja>>2]|0;ka=c[v>>2]|0;la=c[x>>2]|0;Ga=(ca(d[o+oa|0]|0,W)|0)>>>1;za=la+(Ga<<2)|0;gb=c[Y>>2]|0;Aa=(ca(ka,oa)|0)>>>2;Fa=gb+(Aa<<2)|0;Ra=c[p+(oa<<2)>>2]|0;Ha=c[fa>>2]|0;do{if($){pe[c[qa>>2]&1023](Ra,Fa,za,Ha,ra)}else{if(na){Pa=ea>>>2;pe[c[qa>>2]&1023](Ra,Fa,za,Ha,Pa);nrc(Ra+(ea>>>1<<2)|0,la+(Ga+Pa<<2)|0,ka-ea&-4)|0;break}else{Pa=(ka-ea|0)>>>2;nrc(Ra|0,Fa|0,Pa<<2)|0;pe[c[qa>>2]&1023](Ra+(Pa<<2)|0,gb+(Aa+Pa<<2)|0,za,Ha,ea>>>2);break}}}while(0);nrc(Fa|0,la+(Ga+ra<<2)|0,ia)|0;ea=oa+1|0;if((ea|0)<(d[E]|0)){oa=ea}else{Ac=V;break}}}}while(0);a[L]=X;aa=Ac}else{KIb(c[k>>2]|0,16,2200208,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;aa=-1094995529}}while(0);if((aa|0)<1){C=aa;i=l;return C|0}L=k+212|0;if((a[L]|0)==0){a[L]=1;c[j>>2]=0;WHb(t);C=r;i=l;return C|0}else{c[A>>2]=aa;c[j>>2]=1;C=r;i=l;return C|0}}}while(0);KIb(f,16,2241208,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=l;return C|0}function Y8a(a){a=a|0;_8a(c[a+60>>2]|0);return 0}function Z8a(b){b=b|0;var e=0,f=0;e=c[b+60>>2]|0;b=c[e+304>>2]|0;if((b|0)==0){f=e+297|0;a[f]=-1;return}mrc(b|0,0,ca(c[e+244>>2]&-4,d[e+220|0]|0)|0)|0;f=e+297|0;a[f]=-1;return}function _8a(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;mJb(f+300|0);mJb(f+304|0);g=f+276|0;h=c[g>>2]|0;a:do{if((h|0)!=0){i=f+272|0;if((a[i]|0)==0){break}else{j=0;k=h}while(1){kJb(c[k+(j*1052|0)+1048>>2]|0);l=j+1|0;if((l|0)>=(d[i]|0)){break a}j=l;k=c[g>>2]|0}}}while(0);mJb(g);mJb(f+292|0);PPa(f+84|0);PPa(f+148|0);g=f+260|0;k=c[g>>2]|0;b:do{if((k|0)!=0){j=f+256|0;if((b[j>>1]|0)==0){break}else{m=0;n=k}while(1){kJb(c[n+(m<<5)+24>>2]|0);c3((c[g>>2]|0)+(m<<5)+4|0);h=m+1|0;if((h|0)>=(e[j>>1]|0)){break b}m=h;n=c[g>>2]|0}}}while(0);mJb(g);g=f+268|0;n=c[g>>2]|0;c:do{if((n|0)!=0){m=f+264|0;if((a[m]|0)==0){break}else{o=0;p=n}while(1){if((a[p+(o*356|0)|0]|0)==0){kJb(c[p+(o*356|0)+16>>2]|0);kJb(c[(c[g>>2]|0)+(o*356|0)+20>>2]|0);kJb(c[(c[g>>2]|0)+(o*356|0)+36>>2]|0);kJb(c[(c[g>>2]|0)+(o*356|0)+40>>2]|0)}else{kJb(c[p+(o*356|0)+352>>2]|0)}k=o+1|0;if((k|0)>=(d[m]|0)){break c}o=k;p=c[g>>2]|0}}}while(0);mJb(g);g=f+284|0;p=c[g>>2]|0;if((p|0)==0){q=g;mJb(q);return}o=f+280|0;if((a[o]|0)==0){q=g;mJb(q);return}else{r=0;s=p}while(1){kJb(c[s+(r*48|0)+4>>2]|0);kJb(c[(c[g>>2]|0)+(r*48|0)+8>>2]|0);kJb(c[(c[g>>2]|0)+(r*48|0)+12>>2]|0);p=r+1|0;if((p|0)>=(d[o]|0)){break}r=p;s=c[g>>2]|0}q=g;mJb(q);return}function $8a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;f=b+12|0;g=c[f>>2]|0;h=c[b+20>>2]|0;j=c[b+4>>2]|0;k=j+(g>>>3)|0;l=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((g&7)>>>0)&255;k=g+8|0;g=h>>>0>k>>>0?k:h;c[f>>2]=g;do{if((l|0)==118){k=j+(g>>>3)|0;m=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((g&7)>>>0)&255;k=g+8|0;n=h>>>0>k>>>0?k:h;c[f>>2]=n;if((m|0)!=111){break}m=j+(n>>>3)|0;k=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&255;m=n+8|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;if((k|0)!=114){break}k=j+(n>>>3)|0;m=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((n&7)>>>0)&255;k=n+8|0;n=h>>>0>k>>>0?k:h;c[f>>2]=n;if((m|0)!=98){break}m=j+(n>>>3)|0;k=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&255;m=n+8|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;if((k|0)!=105){break}k=j+(n>>>3)|0;m=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((n&7)>>>0)&255;k=n+8|0;n=h>>>0>k>>>0?k:h;c[f>>2]=n;if((m|0)!=115){break}m=j+(n>>>3)|0;k=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&65535;m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=j+(n>>>3)|0;o=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0);m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;c[b+216>>2]=o<<16|k;k=j+(n>>>3)|0;o=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((n&7)>>>0);k=n+8|0;n=h>>>0>k>>>0?k:h;c[f>>2]=n;k=b+220|0;a[k]=o;if((o&255|0)==0){KIb(c[b>>2]|0,16,2240200,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}m=j+(n>>>3)|0;r=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&65535;m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=j+(n>>>3)|0;s=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0);m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=s<<16|r;c[b+224>>2]=m;if((m|0)==0){KIb(c[b>>2]|0,16,2234936,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}m=j+(n>>>3)|0;r=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&65535;m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=j+(n>>>3)|0;s=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0);m=n+16|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;c[b+228>>2]=s<<16|r;r=j+(n>>>3)|0;s=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((n&7)>>>0)&65535;r=n+16|0;n=h>>>0>r>>>0?r:h;c[f>>2]=n;r=j+(n>>>3)|0;m=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((n&7)>>>0);r=n+16|0;n=h>>>0>r>>>0?r:h;c[f>>2]=n;c[b+232>>2]=m<<16|s;s=j+(n>>>3)|0;m=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((n&7)>>>0)&65535;s=n+16|0;n=h>>>0>s>>>0?s:h;c[f>>2]=n;s=j+(n>>>3)|0;r=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((n&7)>>>0);s=n+16|0;n=h>>>0>s>>>0?s:h;c[f>>2]=n;c[b+236>>2]=r<<16|m;m=j+(n>>>3)|0;r=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&15;m=n+4|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=j+(n>>>3)|0;s=(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)>>>((n&7)>>>0)&15;m=n+4|0;n=h>>>0>m>>>0?m:h;c[f>>2]=n;m=r-6|0;do{if(!(m>>>0>7>>>0)){t=s-6|0;if(t>>>0>7>>>0|s>>>0<r>>>0){break}c[b+240>>2]=1<<r;u=1<<s;v=b+244|0;c[v>>2]=u;c[b+248>>2]=c[1253648+(m<<2)>>2];c[b+252>>2]=c[1253648+(t<<2)>>2];t=d[j+(n>>>3)|0]|0;c[f>>2]=((n|0)<(h|0))+n;if((t&1<<(n&7)|0)==0){KIb(c[b>>2]|0,16,2227448,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}t=b+300|0;c[t>>2]=hJb(ca(u>>>1<<2,o&255)|0)|0;u=pJb(ca(c[v>>2]&-4,d[k]|0)|0)|0;c[b+304>>2]=u;if((c[t>>2]|0)==0|(u|0)==0){q=-12;i=e;return q|0}a[b+297|0]=-1;OPa(b+84|0,r,1,-1.0)|0;OPa(b+148|0,s,1,-1.0)|0;q=0;i=e;return q|0}}while(0);KIb(c[b>>2]|0,16,2231248,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}}while(0);KIb(c[b>>2]|0,16,2250536,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=e;return q|0}function a9a(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0.0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0.0,va=0.0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0;h=i;i=i+64|0;j=h|0;k=f+12|0;l=c[k>>2]|0;m=f+20|0;n=c[m>>2]|0;o=f+4|0;p=c[o>>2]|0;q=p+(l>>>3)|0;r=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((l&7)>>>0)&255;q=l+8|0;l=n>>>0>q>>>0?q:n;c[k>>2]=l;do{if((r|0)==118){q=p+(l>>>3)|0;s=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((l&7)>>>0)&255;q=l+8|0;t=n>>>0>q>>>0?q:n;c[k>>2]=t;if((s|0)!=111){break}s=p+(t>>>3)|0;q=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((t&7)>>>0)&255;s=t+8|0;t=n>>>0>s>>>0?s:n;c[k>>2]=t;if((q|0)!=114){break}q=p+(t>>>3)|0;s=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((t&7)>>>0)&255;q=t+8|0;t=n>>>0>q>>>0?q:n;c[k>>2]=t;if((s|0)!=98){break}s=p+(t>>>3)|0;q=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((t&7)>>>0)&255;s=t+8|0;t=n>>>0>s>>>0?s:n;c[k>>2]=t;if((q|0)!=105){break}q=p+(t>>>3)|0;s=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((t&7)>>>0)&255;q=t+8|0;t=n>>>0>q>>>0?q:n;c[k>>2]=t;if((s|0)!=115){break}s=p+(t>>>3)|0;q=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((t&7)>>>0)&255;s=t+8|0;c[k>>2]=n>>>0>s>>>0?s:n;s=q+1|0;q=f+256|0;b[q>>1]=s;t=f+260|0;c[t>>2]=pJb(s<<5&2097120)|0;s=pJb(65536)|0;u=pJb(262144)|0;v=u;w=hJb(131072)|0;x=w;do{if((c[t>>2]|0)==0|(s|0)==0|(u|0)==0|(w|0)==0){y=-12;z=75}else{A=0;a:while(1){if(!(A>>>0<(e[q>>1]|0)>>>0)){z=74;break}B=c[t>>2]|0;C=c[k>>2]|0;D=c[m>>2]|0;E=c[o>>2]|0;F=E+(C>>>3)|0;G=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((C&7)>>>0)&16777215;F=C+24|0;C=D>>>0>F>>>0?F:D;c[k>>2]=C;if((G|0)!=5653314){z=11;break}G=E+(C>>>3)|0;E=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((C&7)>>>0);G=C+16|0;c[k>>2]=D>>>0>G>>>0?G:D;D=B+(A<<5)|0;a[D]=E;H=E&255;if(H>>>0>16>>>0|(H|0)==0){z=13;break}E=c[k>>2]|0;G=c[m>>2]|0;C=c[o>>2]|0;F=C+(E>>>3)|0;I=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((E&7)>>>0)&16777215;F=E+24|0;E=G>>>0>F>>>0?F:G;c[k>>2]=E;if(I>>>0>65536>>>0){z=15;break}F=d[C+(E>>>3)|0]|0;J=((E|0)<(G|0))+E|0;c[k>>2]=J;K=C+(J>>>3)|0;b:do{if((F&1<<(E&7)|0)==0){L=d[K]|0;M=((J|0)<(G|0))+J|0;c[k>>2]=M;N=(I|0)==0;if((L&1<<(J&7)|0)==0){if(N){O=0;P=M;break}else{R=0;S=M}while(1){L=C+(S>>>3)|0;T=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((S&7)>>>0)&31;L=S+5|0;U=G>>>0>L>>>0?L:G;c[k>>2]=U;a[s+R|0]=T+1;T=R+1|0;if(T>>>0<I>>>0){R=T;S=U}else{O=I;P=U;break b}}}if(N){O=0;P=M;break}else{V=0;W=0;X=M}while(1){U=d[C+(X>>>3)|0]|0;T=((X|0)<(G|0))+X|0;c[k>>2]=T;if((U&1<<(X&7)|0)==0){a[s+V|0]=0;Y=W;_=T}else{U=C+(T>>>3)|0;L=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((T&7)>>>0)&31;U=T+5|0;T=G>>>0>U>>>0?U:G;c[k>>2]=T;a[s+V|0]=L+1;Y=W+1|0;_=T}T=V+1|0;if(T>>>0<I>>>0){V=T;W=Y;X=_}else{O=Y;P=_;break}}}else{M=K;N=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((J&7)>>>0)&31;M=J+5|0;T=G>>>0>M>>>0?M:G;c[k>>2]=T;M=N+1|0;if((I|0)!=0&M>>>0<33>>>0){$=0;aa=M;ba=T}else{O=I;P=T;break}while(1){T=I-$|0;M=T<<1;N=M>>>0>65535>>>0;L=N?T>>>15&65535:M;M=N?16:0;if((L&65280|0)==0){da=M;ea=L}else{da=M|8;ea=L>>>8}L=(d[1359664+ea|0]|0)+da|0;M=C+(ba>>>3)|0;N=32-L|0;T=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((ba&7)>>>0)<<N>>>(N>>>0);N=L+ba|0;fa=G>>>0>N>>>0?N:G;c[k>>2]=fa;ga=T+$|0;if($>>>0<ga>>>0){T=aa&255;N=$;do{if(N>>>0<I>>>0){a[s+N|0]=T}N=N+1|0;}while(N>>>0<ga>>>0)}N=aa+1|0;if(ga>>>0<I>>>0&N>>>0<33>>>0){$=ga;aa=N;ba=fa}else{break}}if(ga>>>0>I>>>0){z=35;break a}else{O=I;P=fa}}}while(0);J=C+(P>>>3)|0;K=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((P&7)>>>0);J=P+4|0;c[k>>2]=G>>>0>J>>>0?J:G;a[B+(A<<5)+1|0]=K&15;J=K&15;if((J|0)==1){K=Ntb(I,d[D]|0)|0;E=c[k>>2]|0;F=c[m>>2]|0;N=c[o>>2]|0;T=N+(E>>>3)|0;L=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((E&7)>>>0)&65535;T=E+16|0;E=F>>>0>T>>>0?T:F;c[k>>2]=E;T=N+(E>>>3)|0;N=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((E&7)>>>0);T=E+16|0;c[k>>2]=F>>>0>T>>>0?T:F;F=N<<16|L;ha=+((F&2097151)>>>0>>>0);if((F|0)<0){ia=-0.0-ha}else{ia=ha}ha=+Jqc(ia,(N>>>5&1023)-788|0);N=c[k>>2]|0;F=c[m>>2]|0;L=c[o>>2]|0;T=L+(N>>>3)|0;E=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((N&7)>>>0)&65535;T=N+16|0;N=F>>>0>T>>>0?T:F;c[k>>2]=N;T=L+(N>>>3)|0;L=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((N&7)>>>0);T=N+16|0;c[k>>2]=F>>>0>T>>>0?T:F;F=L<<16|E;ja=+((F&2097151)>>>0>>>0);if((F|0)<0){ka=-0.0-ja}else{ka=ja}ja=+Jqc(ka,(L>>>5&1023)-788|0);L=c[k>>2]|0;F=c[m>>2]|0;E=c[o>>2]|0;T=E+(L>>>3)|0;N=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((L&7)>>>0)&15;T=L+4|0;L=F>>>0>T>>>0?T:F;c[k>>2]=L;T=N+1|0;M=L&7;U=d[E+(L>>>3)|0]|0;la=((L|0)<(F|0))+L|0;c[k>>2]=la;if((K|0)!=0){L=N^31;N=0;ma=la;do{la=E+(ma>>>3)|0;na=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ma&7)>>>0)<<L>>>(L>>>0);la=T+ma|0;ma=F>>>0>la>>>0?la:F;c[k>>2]=ma;b[x+(N<<1)>>1]=na;N=N+1|0;}while(N>>>0<K>>>0)}if((O|0)==0){oa=0}else{oa=pJb(ca(O<<2,d[D]|0)|0)|0}N=B+(A<<5)+24|0;c[N>>2]=oa;if((I|0)==0){pa=0}else{if((U&1<<M|0)==0){ma=0;F=0;while(1){T=a[D]|0;L=T&255;E=s+ma|0;G=a[E]|0;if(G<<24>>24==0){qa=F}else{if(T<<24>>24==0){ra=G}else{G=ca(L,F)|0;T=c[N>>2]|0;C=0;na=ma;while(1){g[T+(C+G<<2)>>2]=ha+ja*+(e[x+(((na>>>0)%(K>>>0)|0)<<1)>>1]|0)+0.0;la=C+1|0;if(la>>>0<L>>>0){C=la;na=(na>>>0)/(K>>>0)|0}else{break}}ra=a[E]|0}a[s+F|0]=ra;qa=F+1|0}na=ma+1|0;if(na>>>0<I>>>0){ma=na;F=qa}else{pa=qa;break}}}else{F=0;ma=0;while(1){M=a[D]|0;U=M&255;na=s+F|0;C=a[na]|0;if(C<<24>>24==0){sa=ma}else{if(M<<24>>24==0){ta=C}else{C=ca(U,ma)|0;M=c[N>>2]|0;L=0;ua=0.0;G=F;while(1){va=ua+(ha+ja*+(e[x+(((G>>>0)%(K>>>0)|0)<<1)>>1]|0));g[M+(L+C<<2)>>2]=va;T=L+1|0;if(T>>>0<U>>>0){L=T;ua=va;G=(G>>>0)/(K>>>0)|0}else{break}}ta=a[na]|0}a[s+ma|0]=ta;sa=ma+1|0}G=F+1|0;if(G>>>0<I>>>0){F=G;ma=sa}else{pa=sa;break}}}}if((pa|0)==(O|0)){wa=O}else{z=63;break}}else{if(J>>>0>1>>>0){z=65;break}else{wa=I}}if((Otb(s,v,wa)|0)!=0){z=67;break}ma=B+(A<<5)+2|0;a[ma]=0;if((wa|0)==0){xa=0}else{F=0;K=0;while(1){N=a[s+F|0]|0;if((N&255)>>>0<(K&255)>>>0){ya=K}else{a[ma]=N;ya=N}N=F+1|0;if(N>>>0<wa>>>0){F=N;K=ya}else{xa=ya;break}}}K=(xa&255)>>>0>24>>>0?11:8;c[B+(A<<5)+28>>2]=K;a[ma]=(((xa&255)-1+K|0)>>>0)/(K>>>0)|0;za=$2(B+(A<<5)+4|0,K,wa,s,1,1,u,4,4,0,0,0,2)|0;if((za|0)==0){A=A+1|0}else{z=73;break}}if((z|0)==11){KIb(c[f>>2]|0,16,2284384,(Aa=i,i=i+8|0,c[Aa>>2]=A,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==13){KIb(c[f>>2]|0,16,2280664,(Aa=i,i=i+16|0,c[Aa>>2]=A,c[Aa+8>>2]=H,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==15){KIb(c[f>>2]|0,16,2276392,(Aa=i,i=i+16|0,c[Aa>>2]=A,c[Aa+8>>2]=I,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==35){KIb(c[f>>2]|0,16,2272008,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==63){KIb(c[f>>2]|0,16,2267136,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==65){KIb(c[f>>2]|0,16,2263712,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==67){KIb(c[f>>2]|0,16,2259760,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=-1094995529;z=75;break}else if((z|0)==73){KIb(c[f>>2]|0,16,2255440,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;y=za;z=75;break}else if((z|0)==74){kJb(s);kJb(u);kJb(w);break}}}while(0);do{if((z|0)==75){kJb(s);kJb(u);kJb(w);if((y|0)==0){break}KIb(c[f>>2]|0,16,2514120,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=y;i=h;return Ba|0}}while(0);w=c[k>>2]|0;u=c[m>>2]|0;s=c[o>>2]|0;v=s+(w>>>3)|0;x=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)>>>((w&7)>>>0)&63;v=w+6|0;w=u>>>0>v>>>0?v:u;c[k>>2]=w;v=x+1|0;x=0;K=w;while(1){w=s+(K>>>3)|0;Ca=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;Da=K&7;if(!(x>>>0<v>>>0)){break}w=K+16|0;F=u>>>0>w>>>0?w:u;c[k>>2]=F;if((Ca&65535<<Da|0)==0){x=x+1|0;K=F}else{z=80;break}}if((z|0)==80){x=f|0;KIb(c[x>>2]|0,16,2290784,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;KIb(c[x>>2]|0,16,2500432,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=-1094995529;i=h;return Ba|0}x=K+6|0;c[k>>2]=u>>>0>x>>>0?x:u;x=(Ca>>>(Da>>>0)&63)+1|0;v=f+264|0;a[v]=x;s=pJb((x&255)*356|0)|0;x=s;F=f+268|0;c[F>>2]=x;c:do{if((s|0)==0){Ea=-12;Fa=f|0}else{d:do{if((a[v]|0)!=0){w=f+244|0;J=f|0;N=0;D=x;e:while(1){G=c[k>>2]|0;L=c[m>>2]|0;U=(c[o>>2]|0)+(G>>>3)|0;C=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((G&7)>>>0);U=G+16|0;c[k>>2]=L>>>0>U>>>0?U:L;a[D+(N*356|0)|0]=C;L=C&255;if((L|0)==0){c[D+(N*356|0)+4>>2]=432;C=c[k>>2]|0;U=c[m>>2]|0;G=(c[o>>2]|0)+(C>>>3)|0;M=(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)>>>((C&7)>>>0);G=C+8|0;c[k>>2]=U>>>0>G>>>0?G:U;U=M&255;M=D+(N*356|0)+8|0;a[M]=U;if(U<<24>>24==0){z=114;break}U=c[k>>2]|0;G=c[m>>2]|0;C=c[o>>2]|0;E=C+(U>>>3)|0;T=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((U&7)>>>0);E=U+16|0;U=G>>>0>E>>>0?E:G;c[k>>2]=U;E=T&65535;b[D+(N*356|0)+10>>1]=E;if(E<<16>>16==0){z=116;break}E=C+(U>>>3)|0;T=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((U&7)>>>0);E=U+16|0;U=G>>>0>E>>>0?E:G;c[k>>2]=U;E=T&65535;b[D+(N*356|0)+12>>1]=E;if(E<<16>>16==0){z=118;break}E=C+(U>>>3)|0;C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((U&7)>>>0);E=U+6|0;c[k>>2]=G>>>0>E>>>0?E:G;a[D+(N*356|0)+32|0]=C&63;C=c[k>>2]|0;G=c[m>>2]|0;E=(c[o>>2]|0)+(C>>>3)|0;U=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((C&7)>>>0);E=C+8|0;c[k>>2]=G>>>0>E>>>0?E:G;a[D+(N*356|0)+33|0]=U;U=c[k>>2]|0;G=c[m>>2]|0;E=(c[o>>2]|0)+(U>>>3)|0;C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((U&7)>>>0)&15;E=U+4|0;c[k>>2]=G>>>0>E>>>0?E:G;G=C+1|0;C=D+(N*356|0)+34|0;a[C]=G;E=hJb(G&255)|0;G=D+(N*356|0)+36|0;c[G>>2]=E;if((E|0)==0){Ea=-12;Fa=J;break c}if((a[C]|0)==0){Ga=1}else{E=0;U=0;do{T=c[k>>2]|0;la=c[m>>2]|0;Ha=(c[o>>2]|0)+(T>>>3)|0;Ia=(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)>>>((T&7)>>>0);Ja=Ia&255;Ha=T+8|0;c[k>>2]=la>>>0>Ha>>>0?Ha:la;Ka=e[q>>1]|0;if(!(Ja>>>0<Ka>>>0)){z=122;break e}a[(c[G>>2]|0)+U|0]=Ia;Ia=d[(c[t>>2]|0)+(Ja<<5)|0]|0;E=Ia>>>0>E>>>0?Ia:E;U=U+1|0;}while((U|0)<(d[C]|0));Ga=E+1|0}C=c[F>>2]|0;U=C+(N*356|0)+16|0;G=C+(N*356|0)+24|0;na=C+(N*356|0)+10|0;Ia=C+(N*356|0)+12|0;C=0;do{la=(c[f+240+(C<<2)>>2]|0)>>>1;Ha=hJb((la<<2)+4|0)|0;T=Ha;c[U+(C<<2)>>2]=T;if((Ha|0)==0){Ea=-12;Fa=J;break c}if((la|0)!=0){Ha=e[na>>1]|0;ja=+(la|0)*2.0;La=e[Ia>>1]|0;ha=+(Ha|0)*.5;ua=+(La|0)/(ha*9999999747378752.0e-20+(+Z(ha*.0007399999885819852)*13.100000381469727+ +Z(ha*ha*1.8499999754340024e-8)*2.240000009536743));Ma=La-1|0;La=0;do{ha=+(ca(La,Ha)|0)/ja;Na=~~+Q(ua*(ha*9999999747378752.0e-20+(+Z(ha*.0007399999885819852)*13.100000381469727+ +Z(ha*ha*1.8499999754340024e-8)*2.240000009536743)));c[T+(La<<2)>>2]=(Ma|0)<(Na|0)?Ma:Na;La=La+1|0;}while((La|0)<(la|0))}c[T+(la<<2)>>2]=-1;c[G+(C<<2)>>2]=la;C=C+1|0;}while((C|0)<2);C=hJb((d[M]|0)+Ga<<2)|0;c[D+(N*356|0)+40>>2]=C;if((C|0)==0){Ea=-12;Fa=J;break c}}else if((L|0)==1){c[D+(N*356|0)+4>>2]=30;C=c[k>>2]|0;G=c[m>>2]|0;Ia=(c[o>>2]|0)+(C>>>3)|0;na=(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)>>>((C&7)>>>0);Ia=C+5|0;c[k>>2]=G>>>0>Ia>>>0?Ia:G;G=na&31;na=D+(N*356|0)+8|0;a[na]=G;if(G<<24>>24==0){Oa=-1}else{G=-1;Ia=0;while(1){C=c[k>>2]|0;U=c[m>>2]|0;E=(c[o>>2]|0)+(C>>>3)|0;La=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((C&7)>>>0);E=C+4|0;c[k>>2]=U>>>0>E>>>0?E:U;a[D+(N*356|0)+9+Ia|0]=La&15;U=La&15;La=(U|0)>(G|0)?U:G;U=Ia+1|0;if((U|0)<(d[na]|0)){G=La;Ia=U}else{Oa=La;break}}}Ia=c[k>>2]|0;G=c[m>>2]|0;L=(c[o>>2]|0)+(Ia>>>3)|0;M=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((Ia&7)>>>0);if((Oa|0)<0){Pa=Ia;Qa=G;Ra=M}else{L=0;La=Ia;Ia=G;G=M;while(1){M=La+3|0;c[k>>2]=Ia>>>0>M>>>0?M:Ia;a[D+(N*356|0)+41+L|0]=(G&7)+1;M=c[k>>2]|0;U=c[m>>2]|0;E=(c[o>>2]|0)+(M>>>3)|0;C=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((M&7)>>>0);E=M+2|0;c[k>>2]=U>>>0>E>>>0?E:U;U=C&3;C=D+(N*356|0)+57+L|0;a[C]=U;if(U<<24>>24==0){Sa=0}else{U=c[k>>2]|0;E=c[m>>2]|0;M=(c[o>>2]|0)+(U>>>3)|0;Ma=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((U&7)>>>0);M=U+8|0;c[k>>2]=E>>>0>M>>>0?M:E;a[D+(N*356|0)+73+L|0]=Ma;Ta=Ma&255;Ua=e[q>>1]|0;if(!(Ta>>>0<Ua>>>0)){z=93;break e}Sa=d[C]|0}Ma=c[k>>2]|0;E=c[m>>2]|0;M=c[o>>2]|0;if((1<<Sa|0)>0){U=0;Ha=Ma;while(1){Na=M+(Ha>>>3)|0;Va=(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)>>>((Ha&7)>>>0)&255;Na=Ha+8|0;Wa=E>>>0>Na>>>0?Na:E;c[k>>2]=Wa;Na=Va+65535&65535;Xa=Na<<16>>16;if(!(Na<<16>>16==-1)){Ya=e[q>>1]|0;if((Xa|0)>=(Ya|0)){z=96;break e}}b[D+(N*356|0)+90+(L<<4)+(U<<1)>>1]=Na;Na=U+1|0;if((Na|0)<(1<<d[C]|0)){U=Na;Ha=Wa}else{Za=Wa;break}}}else{Za=Ma}Ha=L+1|0;U=M+(Za>>>3)|0;C=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((Za&7)>>>0);if((Ha|0)>(Oa|0)){Pa=Za;Qa=E;Ra=C;break}else{L=Ha;La=Za;Ia=E;G=C}}}G=Pa+2|0;c[k>>2]=Qa>>>0>G>>>0?G:Qa;a[D+(N*356|0)+346|0]=(Ra&3)+1;G=D+(N*356|0)+348|0;b[G>>1]=2;Ia=a[na]|0;if(Ia<<24>>24==0){_a=16}else{La=Ia&255;Ia=0;L=2;do{L=(d[(d[D+(N*356|0)+9+Ia|0]|0)+(D+(N*356|0)+41)|0]|0)+L&65535;b[G>>1]=L;Ia=Ia+1|0;}while((Ia|0)<(La|0));_a=(L&65535)<<3}La=pJb(_a)|0;Ia=La;c[D+(N*356|0)+352>>2]=Ia;if((La|0)==0){Ea=-12;Fa=J;break c}C=c[k>>2]|0;Ha=c[m>>2]|0;U=c[o>>2]|0;la=U+(C>>>3)|0;T=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((C&7)>>>0)&15;la=C+4|0;C=Ha>>>0>la>>>0?la:Ha;c[k>>2]=C;$a=1<<T;ab=(c[w>>2]|0)>>>1;if($a>>>0>ab>>>0){z=105;break}b[La>>1]=0;b[La+8>>1]=$a;La=a[na]|0;if(!(La<<24>>24==0)){la=32-T|0;Wa=0;Na=2;Va=La;La=C;while(1){C=D+(N*356|0)+9+Wa|0;if((a[(d[C]|0)+(D+(N*356|0)+41)|0]|0)==0){bb=Na;cb=Va;db=La}else{eb=0;fb=Na;gb=La;do{hb=U+(gb>>>3)|0;ib=(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)>>>((gb&7)>>>0)<<la>>>(la>>>0);hb=gb+T|0;gb=Ha>>>0>hb>>>0?hb:Ha;c[k>>2]=gb;b[Ia+(fb<<3)>>1]=ib;eb=eb+1|0;fb=fb+1|0;}while((eb|0)<(d[(d[C]|0)+(D+(N*356|0)+41)|0]|0));bb=fb;cb=a[na]|0;db=gb}C=Wa+1|0;if((C|0)<(cb&255|0)){Wa=C;Na=bb;Va=cb;La=db}else{break}}}if((Ptb(c[J>>2]|0,Ia,e[G>>1]|0)|0)!=0){Ea=-1094995529;Fa=J;break c}}else{z=132;break}La=N+1|0;if((La|0)>=(d[v]|0)){break d}N=La;D=c[F>>2]|0}if((z|0)==93){KIb(c[J>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=Ta,c[Aa+8>>2]=Ua-1,c[Aa+16>>2]=2344648,c[Aa+24>>2]=2141688,c[Aa+32>>2]=543,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==96){KIb(c[J>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=Xa,c[Aa+8>>2]=Ya-1,c[Aa+16>>2]=2338664,c[Aa+24>>2]=2141688,c[Aa+32>>2]=551,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==105){KIb(c[J>>2]|0,16,2332984,(Aa=i,i=i+16|0,c[Aa>>2]=$a,c[Aa+8>>2]=ab,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==114){KIb(c[J>>2]|0,16,2327576,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==116){KIb(c[J>>2]|0,16,2321768,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==118){KIb(c[J>>2]|0,16,2316736,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==122){KIb(c[J>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=Ja,c[Aa+8>>2]=Ka-1,c[Aa+16>>2]=2312176,c[Aa+24>>2]=2141688,c[Aa+32>>2]=630,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}else if((z|0)==132){KIb(c[J>>2]|0,16,2307632,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ea=-1094995529;Fa=J;break c}}}while(0);A=c[k>>2]|0;D=c[m>>2]|0;N=(c[o>>2]|0)+(A>>>3)|0;w=(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)>>>((A&7)>>>0)&63;N=A+6|0;c[k>>2]=D>>>0>N>>>0?N:D;D=w+1|0;w=f+272|0;a[w]=D;N=pJb((D&255)*1052|0)|0;D=N;A=f+276|0;c[A>>2]=D;f:do{if((N|0)==0){jb=-12}else{g:do{if((a[w]|0)!=0){B=f+220|0;ma=f+244|0;La=0;Va=D;h:while(1){Na=c[k>>2]|0;Wa=c[m>>2]|0;na=c[o>>2]|0;Ha=na+(Na>>>3)|0;kb=(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)>>>((Na&7)>>>0);Ha=Na+16|0;Na=Wa>>>0>Ha>>>0?Ha:Wa;c[k>>2]=Na;Ha=kb&65535;b[Va+(La*1052|0)>>1]=Ha;T=na+(Na>>>3)|0;la=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((Na&7)>>>0)&16777215;T=Na+24|0;c[k>>2]=Wa>>>0>T>>>0?T:Wa;Wa=Va+(La*1052|0)+4|0;c[Wa>>2]=la;la=c[k>>2]|0;T=c[m>>2]|0;Na=na+(la>>>3)|0;U=(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)>>>((la&7)>>>0)&16777215;Na=la+24|0;c[k>>2]=T>>>0>Na>>>0?Na:T;T=Va+(La*1052|0)+8|0;c[T>>2]=U;U=c[k>>2]|0;Na=c[m>>2]|0;la=na+(U>>>3)|0;L=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((U&7)>>>0)&16777215;la=U+24|0;c[k>>2]=Na>>>0>la>>>0?la:Na;lb=L+1|0;L=Va+(La*1052|0)+12|0;c[L>>2]=lb;mb=c[Wa>>2]|0;nb=c[T>>2]|0;if(mb>>>0>nb>>>0){z=140;break}if(Ha<<16>>16==2){ob=d[B]|0}else{ob=1}Ha=c[ma>>2]|0;if(nb>>>0>(ca(Ha,ob)|0)>>>1>>>0){pb=Ha;break}if((((nb-mb|0)>>>0)/(lb>>>0)|0)>>>0>1048576>>>0){pb=Ha;break}Ha=c[k>>2]|0;Na=c[m>>2]|0;la=na+(Ha>>>3)|0;na=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((Ha&7)>>>0)&63;la=Ha+6|0;c[k>>2]=Na>>>0>la>>>0?la:Na;Na=Va+(La*1052|0)+16|0;a[Na]=na+1;na=c[k>>2]|0;la=c[m>>2]|0;Ha=(c[o>>2]|0)+(na>>>3)|0;U=(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)>>>((na&7)>>>0);Ha=na+8|0;c[k>>2]=la>>>0>Ha>>>0?Ha:la;a[Va+(La*1052|0)+17|0]=U;qb=U&255;rb=e[q>>1]|0;if(!(qb>>>0<rb>>>0)){z=147;break}U=(((c[T>>2]|0)-(c[Wa>>2]|0)|0)>>>0)/((c[L>>2]|0)>>>0)|0;b[Va+(La*1052|0)+1044>>1]=U;L=hJb(ca(d[B]|0,U&65535)|0)|0;c[Va+(La*1052|0)+1048>>2]=L;if((L|0)==0){jb=-12;break f}do{if((a[Na]|0)==0){a[Va+(La*1052|0)+1042|0]=0}else{L=c[m>>2]|0;U=c[o>>2]|0;Wa=0;T=c[k>>2]|0;while(1){la=U+(T>>>3)|0;Ha=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((T&7)>>>0)&7;la=T+3|0;na=L>>>0>la>>>0?la:L;c[k>>2]=na;la=d[U+(na>>>3)|0]|0;C=((na|0)<(L|0))+na|0;c[k>>2]=C;if((1<<(na&7)&la|0)==0){sb=0;tb=C}else{la=U+(C>>>3)|0;na=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((C&7)>>>0);la=C+5|0;C=L>>>0>la>>>0?la:L;c[k>>2]=C;sb=na<<3&248;tb=C}a[j+Wa|0]=sb|Ha;Ha=Wa+1|0;ub=a[Na]|0;if(Ha>>>0<(ub&255)>>>0){Wa=Ha;T=tb}else{break}}T=Va+(La*1052|0)+1042|0;a[T]=0;if(ub<<24>>24==0){break}else{vb=0}do{Wa=d[j+vb|0]|0;L=0;do{do{if((1<<L&Wa|0)==0){b[Va+(La*1052|0)+18+(vb<<4)+(L<<1)>>1]=-1}else{U=c[k>>2]|0;Ha=c[m>>2]|0;C=(c[o>>2]|0)+(U>>>3)|0;na=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((U&7)>>>0);C=U+8|0;c[k>>2]=Ha>>>0>C>>>0?C:Ha;wb=na&255;b[Va+(La*1052|0)+18+(vb<<4)+(L<<1)>>1]=wb;xb=b[q>>1]|0;if(!((wb&65535)>>>0<(xb&65535)>>>0)){z=159;break h}if(!(L>>>0>(d[T]|0)>>>0)){break}a[T]=L}}while(0);L=L+1|0;}while(L>>>0<8>>>0);vb=vb+1|0;}while(vb>>>0<(d[Na]|0)>>>0)}}while(0);Na=La+1|0;if(!(Na>>>0<(d[w]|0)>>>0)){break g}La=Na;Va=c[A>>2]|0}if((z|0)==140){pb=c[ma>>2]|0}else if((z|0)==147){KIb(c[f>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=qb,c[Aa+8>>2]=rb-1,c[Aa+16>>2]=2367592,c[Aa+24>>2]=2141688,c[Aa+32>>2]=714,Aa)|0);i=Aa;jb=-1094995529;break f}else if((z|0)==159){KIb(c[f>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=wb&65535,c[Aa+8>>2]=(xb&65535)-1,c[Aa+16>>2]=2353032,c[Aa+24>>2]=2141688,c[Aa+32>>2]=742,Aa)|0);i=Aa;jb=-1094995529;break f}KIb(c[f>>2]|0,16,2374720,(Aa=i,i=i+40|0,c[Aa>>2]=kb&65535,c[Aa+8>>2]=mb,c[Aa+16>>2]=nb,c[Aa+24>>2]=lb,c[Aa+32>>2]=pb>>>1,Aa)|0);i=Aa;jb=-1094995529;break f}}while(0);J=c[k>>2]|0;Va=c[m>>2]|0;La=(c[o>>2]|0)+(J>>>3)|0;B=(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0)>>>((J&7)>>>0)&63;La=J+6|0;c[k>>2]=Va>>>0>La>>>0?La:Va;Va=B+1|0;B=f+280|0;a[B]=Va;La=pJb((Va&255)*48|0)|0;Va=La;J=f+284|0;c[J>>2]=Va;i:do{if((La|0)==0){yb=-12}else{j:do{if((a[B]|0)!=0){G=f+220|0;Ia=c[k>>2]|0;Na=c[m>>2]|0;gb=c[o>>2]|0;fb=gb+(Ia>>>3)|0;T=d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0;fb=Ia+16|0;L=Na>>>0>fb>>>0?fb:Na;c[k>>2]=L;k:do{if((T&65535<<(Ia&7)|0)==0){fb=Va;Wa=0;na=Va;Ha=Na;C=gb;U=L;l:while(1){la=d[C+(U>>>3)|0]|0;eb=((U|0)<(Ha|0))+U|0;c[k>>2]=eb;if((la&1<<(U&7)|0)==0){a[na|0]=1}else{la=C+(eb>>>3)|0;E=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((eb&7)>>>0)&15;la=eb+4|0;c[k>>2]=Ha>>>0>la>>>0?la:Ha;a[na|0]=E+1}E=c[k>>2]|0;la=c[o>>2]|0;eb=d[la+(E>>>3)|0]|0;M=c[m>>2]|0;Ma=((E|0)<(M|0))+E|0;c[k>>2]=Ma;if((eb&1<<(E&7)|0)==0){b[fb+(Wa*48|0)+2>>1]=0;zb=Ma;Ab=M;Bb=la}else{E=la+(Ma>>>3)|0;la=(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)>>>((Ma&7)>>>0)&255;E=Ma+8|0;c[k>>2]=M>>>0>E>>>0?E:M;M=la+1|0;la=fb+(Wa*48|0)+2|0;b[la>>1]=M;E=fb+(Wa*48|0)+4|0;c[E>>2]=pJb(M&65535)|0;M=pJb(e[la>>1]|0)|0;Ma=fb+(Wa*48|0)+8|0;c[Ma>>2]=M;if((M|0)==0){yb=-12;break i}if((c[E>>2]|0)==0){yb=-12;break i}else{Cb=0}while(1){if(!(Cb>>>0<(e[la>>1]|0)>>>0)){break}M=(d[G]<<1)-2|0;eb=M>>>0>65535>>>0;ib=eb?M>>>16:M;M=eb?16:0;if((ib&65280|0)==0){Db=M;Eb=ib}else{Db=M|8;Eb=ib>>>8}ib=(d[1359664+Eb|0]|0)+Db|0;M=c[k>>2]|0;eb=c[m>>2]|0;hb=(c[o>>2]|0)+(M>>>3)|0;Fb=32-ib|0;Gb=(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)>>>((M&7)>>>0)<<Fb>>>(Fb>>>0);Fb=ib+M|0;c[k>>2]=eb>>>0>Fb>>>0?Fb:eb;a[(c[E>>2]|0)+Cb|0]=Gb;Hb=a[(c[E>>2]|0)+Cb|0]|0;Gb=a[G]|0;Ib=Gb&255;if(!((Hb&255)>>>0<(Gb&255)>>>0)){z=182;break l}Gb=(Ib<<1)-2|0;eb=Gb>>>0>65535>>>0;Fb=eb?Gb>>>16:Gb;Gb=eb?16:0;if((Fb&65280|0)==0){Jb=Gb;Kb=Fb}else{Jb=Gb|8;Kb=Fb>>>8}Fb=(d[1359664+Kb|0]|0)+Jb|0;Gb=c[k>>2]|0;eb=c[m>>2]|0;M=(c[o>>2]|0)+(Gb>>>3)|0;ib=32-Fb|0;hb=(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)>>>((Gb&7)>>>0)<<ib>>>(ib>>>0);ib=Fb+Gb|0;c[k>>2]=eb>>>0>ib>>>0?ib:eb;a[(c[Ma>>2]|0)+Cb|0]=hb;Lb=a[(c[Ma>>2]|0)+Cb|0]|0;Mb=a[G]|0;if((Lb&255)>>>0<(Mb&255)>>>0){Cb=Cb+1|0}else{z=186;break l}}zb=c[k>>2]|0;Ab=c[m>>2]|0;Bb=c[o>>2]|0}Ma=Bb+(zb>>>3)|0;E=d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0;Ma=zb+2|0;c[k>>2]=Ab>>>0>Ma>>>0?Ma:Ab;if((3<<(zb&7)&E|0)!=0){z=190;break}E=na|0;m:do{if((d[E]|0)>>>0>1>>>0){Ma=pJb(d[G]|0)|0;la=fb+(Wa*48|0)+12|0;c[la>>2]=Ma;if((Ma|0)==0){yb=-12;break i}if((a[G]|0)==0){Nb=0;break}else{Ob=0;Pb=Ma}while(1){Ma=c[k>>2]|0;hb=c[m>>2]|0;eb=(c[o>>2]|0)+(Ma>>>3)|0;ib=(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)>>>((Ma&7)>>>0);eb=Ma+4|0;c[k>>2]=hb>>>0>eb>>>0?eb:hb;a[Pb+Ob|0]=ib&15;ib=Ob+1|0;if(!(ib>>>0<(d[G]|0)>>>0)){Nb=0;break m}Ob=ib;Pb=c[la>>2]|0}}else{Nb=0}}while(0);while(1){if(!(Nb>>>0<(d[E]|0)>>>0)){break}la=c[m>>2]|0;ib=(c[k>>2]|0)+8|0;hb=la>>>0>ib>>>0?ib:la;c[k>>2]=hb;ib=(c[o>>2]|0)+(hb>>>3)|0;eb=(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)>>>((hb&7)>>>0);ib=hb+8|0;c[k>>2]=la>>>0>ib>>>0?ib:la;a[fb+(Wa*48|0)+16+Nb|0]=eb;Qb=eb&255;Rb=d[v]|0;if(!(Qb>>>0<Rb>>>0)){z=198;break l}eb=c[k>>2]|0;la=c[m>>2]|0;ib=(c[o>>2]|0)+(eb>>>3)|0;hb=(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)>>>((eb&7)>>>0);ib=eb+8|0;c[k>>2]=la>>>0>ib>>>0?ib:la;a[fb+(Wa*48|0)+32+Nb|0]=hb;Sb=hb&255;Tb=d[w]|0;if(!(Sb>>>0<Tb>>>0)){z=201;break l}Nb=Nb+1|0}E=Wa+1|0;if(!(E>>>0<(d[B]|0)>>>0)){break j}hb=c[J>>2]|0;la=c[k>>2]|0;ib=c[m>>2]|0;eb=c[o>>2]|0;Ma=eb+(la>>>3)|0;Gb=d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0;Ma=la+16|0;Fb=ib>>>0>Ma>>>0?Ma:ib;c[k>>2]=Fb;if((Gb&65535<<(la&7)|0)==0){fb=hb;Wa=E;na=hb+(E*48|0)|0;Ha=ib;C=eb;U=Fb}else{break k}}if((z|0)==182){KIb(c[f>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=Hb&255,c[Aa+8>>2]=Ib-1,c[Aa+16>>2]=2409720,c[Aa+24>>2]=2141688,c[Aa+32>>2]=795,Aa)|0);i=Aa;yb=-1094995529;break i}else if((z|0)==186){KIb(c[f>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=Lb&255,c[Aa+8>>2]=(Mb&255)-1,c[Aa+16>>2]=2401960,c[Aa+24>>2]=2141688,c[Aa+32>>2]=796,Aa)|0);i=Aa;yb=-1094995529;break i}else if((z|0)==190){KIb(c[f>>2]|0,16,2395216,(Aa=i,i=i+8|0,c[Aa>>2]=Wa,Aa)|0);i=Aa;yb=-1094995529;break i}else if((z|0)==198){KIb(c[f>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=Qb,c[Aa+8>>2]=Rb-1,c[Aa+16>>2]=2388064,c[Aa+24>>2]=2141688,c[Aa+32>>2]=822,Aa)|0);i=Aa;yb=-1094995529;break i}else if((z|0)==201){KIb(c[f>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=Sb,c[Aa+8>>2]=Tb-1,c[Aa+16>>2]=2381112,c[Aa+24>>2]=2141688,c[Aa+32>>2]=823,Aa)|0);i=Aa;yb=-1094995529;break i}}}while(0);KIb(c[f>>2]|0,16,2418640,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;yb=-1094995529;break i}}while(0);ma=c[k>>2]|0;G=c[m>>2]|0;L=(c[o>>2]|0)+(ma>>>3)|0;gb=(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)>>>((ma&7)>>>0)&63;L=ma+6|0;c[k>>2]=G>>>0>L>>>0?L:G;G=gb+1|0;gb=f+288|0;a[gb]=G;L=pJb(G<<3&2040)|0;G=f+292|0;c[G>>2]=L;do{if((L|0)==0){Ub=-12;Vb=f|0}else{ma=0;while(1){if(!(ma>>>0<(d[gb]|0)>>>0)){break}Na=c[G>>2]|0;Ia=c[k>>2]|0;T=(d[(c[o>>2]|0)+(Ia>>>3)|0]|0)>>>((Ia&7)>>>0);c[k>>2]=((Ia|0)<(c[m>>2]|0))+Ia;a[Na+(ma<<3)|0]=T&1;T=c[k>>2]|0;Ia=c[m>>2]|0;U=c[o>>2]|0;C=U+(T>>>3)|0;Ha=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((T&7)>>>0);C=T+16|0;T=Ia>>>0>C>>>0?C:Ia;c[k>>2]=T;b[Na+(ma<<3)+2>>1]=Ha;Ha=U+(T>>>3)|0;C=(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)>>>((T&7)>>>0);Ha=T+16|0;T=Ia>>>0>Ha>>>0?Ha:Ia;c[k>>2]=T;b[Na+(ma<<3)+4>>1]=C;C=U+(T>>>3)|0;U=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((T&7)>>>0);C=T+8|0;c[k>>2]=Ia>>>0>C>>>0?C:Ia;a[Na+(ma<<3)+6|0]=U;Wb=U&255;Xb=d[B]|0;if(Wb>>>0<Xb>>>0){ma=ma+1|0}else{z=209;break}}if((z|0)==209){ma=f|0;KIb(c[ma>>2]|0,16,1076504,(Aa=i,i=i+40|0,c[Aa>>2]=Wb,c[Aa+8>>2]=Xb-1,c[Aa+16>>2]=2429176,c[Aa+24>>2]=2141688,c[Aa+32>>2]=888,Aa)|0);i=Aa;Ub=-1094995529;Vb=ma;break}ma=c[k>>2]|0;U=d[(c[o>>2]|0)+(ma>>>3)|0]|0;c[k>>2]=((ma|0)<(c[m>>2]|0))+ma;if((U&1<<(ma&7)|0)!=0){Ba=0;i=h;return Ba|0}KIb(c[f>>2]|0,16,2440816,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=-1094995529;i=h;return Ba|0}}while(0);KIb(c[Vb>>2]|0,16,2457496,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=Ub;i=h;return Ba|0}}while(0);KIb(c[f>>2]|0,16,2467320,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=yb;i=h;return Ba|0}}while(0);KIb(c[f>>2]|0,16,2476592,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=jb;i=h;return Ba|0}}while(0);KIb(c[Fa>>2]|0,16,2487728,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=Ea;i=h;return Ba|0}}while(0);KIb(c[f>>2]|0,16,2529368,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Ba=-1094995529;i=h;return Ba|0}function b9a(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;j=i;i=i+2072|0;k=j|0;l=j+520|0;m=j+1040|0;n=g+338|0;o=e[253408+((d[n]|0)-1<<1)>>1]|0;p=f+12|0;q=c[p>>2]|0;r=c[f+4>>2]|0;s=d[r+(q>>>3)|0]|0;t=c[f+20>>2]|0;u=((q|0)<(t|0))+q|0;c[p>>2]=u;if((s&1<<(q&7)|0)==0){v=1;i=j;return v|0}q=(o<<1)-2|0;s=q>>>0>65535>>>0;w=s?q>>>16:q;q=s?16:0;if((w&65280|0)==0){x=q;y=w}else{x=q|8;y=w>>>8}w=(d[1359664+y|0]|0)+x|0;x=r+(u>>>3)|0;y=32-w|0;q=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((u&7)>>>0)<<y>>>(y>>>0);x=w+u|0;u=t>>>0>x>>>0?x:t;c[p>>2]=u;x=q&65535;q=k|0;b[q>>1]=x;s=r+(u>>>3)|0;z=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)>>>((u&7)>>>0)<<y>>>(y>>>0);y=u+w|0;w=t>>>0>y>>>0?y:t;c[p>>2]=w;y=z&65535;z=k+2|0;b[z>>1]=y;u=g|0;do{if((a[u]|0)==0){A=x;B=y}else{s=f+260|0;C=0;D=2;E=w;a:while(1){F=d[g+1+C|0]|0;G=a[g+33+F|0]|0;H=G&255;I=a[g+49+F|0]|0;J=I&255;K=(1<<J)-1|0;if(I<<24>>24==0){L=0;M=E}else{I=d[g+65+F|0]|0;N=c[s>>2]|0;O=c[N+(I<<5)+8>>2]|0;P=c[N+(I<<5)+28>>2]|0;I=r+(E>>>3)|0;N=32-P|0;Q=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((E&7)>>>0)<<N>>>(N>>>0);N=b[O+(Q<<2)>>1]|0;I=b[O+(Q<<2)+2>>1]|0;Q=I<<16>>16;do{if(I<<16>>16<0){R=E+P|0;S=t>>>0>R>>>0?R:t;R=r+(S>>>3)|0;T=Q+32|0;U=((d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((S&7)>>>0)<<T>>>(T>>>0))+N|0;T=b[O+(U<<2)>>1]|0;R=b[O+(U<<2)+2>>1]|0;U=R<<16>>16;if(!(R<<16>>16<0)){V=U;W=T;X=S;break}R=S-Q|0;S=t>>>0>R>>>0?R:t;R=r+(S>>>3)|0;Y=U+32|0;U=((d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((S&7)>>>0)<<Y>>>(Y>>>0))+T|0;V=b[O+(U<<2)+2>>1]|0;W=b[O+(U<<2)>>1]|0;X=S}else{V=Q;W=N;X=E}}while(0);N=V+X|0;Q=t>>>0>N>>>0?N:t;c[p>>2]=Q;L=W;M=Q}if(G<<24>>24==0){Z=M}else{Q=0;N=L;O=M;while(1){P=b[g+82+(F<<4)+((N&K)<<1)>>1]|0;I=N>>>(J>>>0);if(P<<16>>16>-1){S=P<<16>>16;P=c[s>>2]|0;U=c[P+(S<<5)+8>>2]|0;T=c[P+(S<<5)+28>>2]|0;S=r+(O>>>3)|0;P=32-T|0;Y=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((O&7)>>>0)<<P>>>(P>>>0);P=b[U+(Y<<2)>>1]|0;S=b[U+(Y<<2)+2>>1]|0;Y=S<<16>>16;do{if(S<<16>>16<0){R=O+T|0;_=t>>>0>R>>>0?R:t;R=r+(_>>>3)|0;$=Y+32|0;aa=((d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((_&7)>>>0)<<$>>>($>>>0))+P|0;$=b[U+(aa<<2)>>1]|0;R=b[U+(aa<<2)+2>>1]|0;aa=R<<16>>16;if(!(R<<16>>16<0)){ba=aa;da=$;ea=_;break}R=_-Y|0;_=t>>>0>R>>>0?R:t;R=r+(_>>>3)|0;fa=aa+32|0;aa=((d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((_&7)>>>0)<<fa>>>(fa>>>0))+$|0;ba=b[U+(aa<<2)+2>>1]|0;da=b[U+(aa<<2)>>1]|0;ea=_}else{ba=Y;da=P;ea=O}}while(0);P=ba+ea|0;Y=t>>>0>P>>>0?P:t;c[p>>2]=Y;if((da|0)<0){v=-1094995529;ga=42;break a}b[k+(Q+D<<1)>>1]=da;ha=Y}else{b[k+(Q+D<<1)>>1]=0;ha=O}Y=Q+1|0;if(Y>>>0<H>>>0){Q=Y;N=I;O=ha}else{Z=ha;break}}}O=C+1|0;if(O>>>0<(d[u]|0)>>>0){C=O;D=H+D|0;E=Z}else{ga=21;break}}if((ga|0)==21){A=b[q>>1]|0;B=b[z>>1]|0;break}else if((ga|0)==42){i=j;return v|0}}}while(0);ga=m|0;c[ga>>2]=1;c[m+4>>2]=1;z=l|0;b[z>>1]=A;b[l+2>>1]=B;B=b[g+340>>1]|0;A=B&65535;q=c[g+344>>2]|0;if((B&65535)>>>0>2>>>0){B=2;do{g=e[q+(B<<3)+4>>1]|0;Z=e[q+(B<<3)+6>>1]|0;u=e[l+(g<<1)>>1]|0;ha=(e[l+(Z<<1)>>1]|0)-u|0;da=e[q+(g<<3)>>1]|0;p=(ca((e[q+(B<<3)>>1]|0)-da|0,(ha|0)>-1?ha:-ha|0)|0)/((e[q+(Z<<3)>>1]|0)-da|0)|0;da=((ha|0)<0?-p|0:p)+u|0;u=b[k+(B<<1)>>1]|0;p=u&65535;ha=o-da|0;do{if(u<<16>>16==0){c[m+(B<<2)>>2]=0;if(da>>>0>65535>>>0){ia=-da>>31&65535}else{ia=da&65535}b[l+(B<<1)>>1]=ia}else{c[m+(g<<2)>>2]=1;c[m+(Z<<2)>>2]=1;c[m+(B<<2)>>2]=1;if(!(p>>>0<(ha>>>0<da>>>0?ha:da)<<1>>>0)){if(ha>>>0>da>>>0){b[l+(B<<1)>>1]=u;break}t=da-p+ha|0;ea=t-1|0;if(ea>>>0>65535>>>0){ja=1-t>>31&65535}else{ja=ea&65535}b[l+(B<<1)>>1]=ja;break}if((p&1|0)==0){ea=(p>>>1)+da|0;if(ea>>>0>65535>>>0){ka=-ea>>31&65535}else{ka=ea&65535}b[l+(B<<1)>>1]=ka;break}else{ea=da-((p+1|0)>>>1)|0;if(ea>>>0>65535>>>0){la=-ea>>31&65535}else{la=ea&65535}b[l+(B<<1)>>1]=la;break}}}while(0);B=B+1|0;}while(B>>>0<A>>>0)}Qtb(q,A,z,ga,d[n]|0,h,e[q+8>>1]|0);v=0;i=j;return v|0}function c9a(f,h,j){f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0.0,T=0.0,V=0.0,W=0.0,X=0.0,Y=0,Z=0.0,_=0.0,aa=0.0,ba=0.0,da=0;k=i;l=c[h+32>>2]|0;m=d[(c[f+292>>2]|0)+(d[f+296|0]<<3)|0]|0;n=h+24|0;o=a[n]|0;if(o<<24>>24==0){p=1;i=k;return p|0}q=o&255;o=f+12|0;r=c[o>>2]|0;s=f+20|0;t=c[s>>2]|0;u=f+4|0;v=c[u>>2]|0;w=v+(r>>>3)|0;x=32-q|0;y=(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)>>>((r&7)>>>0)<<x>>>(x>>>0);x=r+q|0;q=t>>>0>x>>>0?x:t;c[o>>2]=q;if((y|0)==0){p=1;i=k;return p|0}x=h+26|0;r=d[x]|0;w=r<<1;z=w&256;A=(z>>>5)+(d[1359664+((z|0)==0?w:r>>>7)|0]|0)|0;r=v+(q>>>3)|0;v=32-A|0;w=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)>>>((q&7)>>>0)<<v>>>(v>>>0);v=A+q|0;c[o>>2]=t>>>0>v>>>0?v:t;if(w>>>0<(d[x]|0)>>>0){B=w}else{KIb(c[f>>2]|0,16,2301984,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;B=0}w=d[(c[h+28>>2]|0)+B|0]|0;B=c[f+260>>2]|0;f=a[B+(w<<5)|0]|0;x=a[B+(w<<5)+2|0]|0;t=c[B+(w<<5)+8>>2]|0;v=c[B+(w<<5)+24>>2]|0;q=c[B+(w<<5)+28>>2]|0;if((v|0)==0){p=-1094995529;i=k;return p|0}w=h|0;if((a[w]|0)==0){C=0}else{B=32-q|0;A=(x&255)>>>0>1>>>0;r=(x&255)>>>0>2>>>0;x=f&255;z=f<<24>>24==0;f=c[s>>2]|0;s=c[u>>2]|0;u=0;D=0.0;E=c[o>>2]|0;while(1){F=s+(E>>>3)|0;G=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((E&7)>>>0)<<B>>>(B>>>0);F=b[t+(G<<2)>>1]|0;H=b[t+(G<<2)+2>>1]|0;G=H<<16>>16;do{if(A&H<<16>>16<0){I=E+q|0;J=f>>>0>I>>>0?I:f;I=s+(J>>>3)|0;K=G+32|0;L=((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((J&7)>>>0)<<K>>>(K>>>0))+F|0;K=b[t+(L<<2)>>1]|0;I=b[t+(L<<2)+2>>1]|0;L=I<<16>>16;if(!(r&I<<16>>16<0)){M=L;N=K;O=J;break}I=J-G|0;J=f>>>0>I>>>0?I:f;I=s+(J>>>3)|0;P=L+32|0;L=((d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((J&7)>>>0)<<P>>>(P>>>0))+K|0;M=b[t+(L<<2)+2>>1]|0;N=b[t+(L<<2)>>1]|0;O=J}else{M=G;N=F;O=E}}while(0);F=M+O|0;G=f>>>0>F>>>0?F:f;c[o>>2]=G;F=ca(N,x)|0;if(z){Q=0}else{H=0;while(1){g[l+(H+u<<2)>>2]=D+ +g[v+(H+F<<2)>>2];J=H+1|0;if(J>>>0<x>>>0){H=J}else{Q=x;break}}}R=+g[l+(u-1+Q<<2)>>2];H=u+x|0;F=a[w]|0;if(H>>>0<(F&255)>>>0){u=H;D=R;E=G}else{C=F;break}}}E=C&255;D=3.141592653589793/+(e[h+4>>1]|0);if(!(C<<24>>24==0)){u=0;do{w=l+(u<<2)|0;g[w>>2]=+U(+g[w>>2])*2.0;u=u+1|0;}while((u|0)<(E|0))}u=c[h+16+(m<<2)>>2]|0;if((u|0)==0){p=0;i=k;return p|0}w=(C&255)>>>0>1>>>0;x=h+25|0;Q=(C&255)>>>0>3>>>0?E&254:2;C=c[h+8+(m<<2)>>2]|0;m=0;h=c[C>>2]|0;while(1){R=+U(D*+(h|0))*2.0;if(w){v=0;T=.5;V=.5;z=1;while(1){W=V*(+g[l+(v<<2)>>2]-R);X=T*(+g[l+(z<<2)>>2]-R);N=v+2|0;o=N|1;if((o|0)<(E|0)){v=N;T=X;V=W;z=o}else{Y=Q;Z=X;_=W;break}}}else{Y=0;Z=.5;_=.5}if((Y|0)==(E|0)){aa=_*(R+2.0)*_;ba=2.0-R}else{V=_*(R- +g[l+(Y<<2)>>2]);aa=V*V;ba=4.0-R*R}z=d[x]|0;V=+((ca(z,y)|0)>>>0>>>0);T=+$((V/(+S(aa+Z*Z*ba)*+((1<<d[n])-1|0))- +(z|0))*.1151292473077774);z=m;do{g[j+(z<<2)>>2]=T;z=z+1|0;da=c[C+(z<<2)>>2]|0;}while((da|0)==(h|0));if(z>>>0<u>>>0){m=z;h=da}else{p=0;break}}i=k;return p|0}function d9a(a){a=a|0;c[a>>2]=654;return}function e9a(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0.0,aa=0.0,ba=0,da=0,ea=0.0,fa=0.0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0;h=i;i=i+50024|0;j=h|0;k=h+24|0;l=c[f+60>>2]|0;if((c[f+416>>2]|0)!=2){KIb(f,16,2612640,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1;i=h;return n|0}o=l;c[o>>2]=2;p=l+4|0;c[p>>2]=c[f+412>>2];q=l+12|0;c[q>>2]=11;r=l+8|0;c[r>>2]=11;s=l+176|0;c[s>>2]=29;t=hJb(1276)|0;u=t;v=l+180|0;c[v>>2]=u;a:do{if((t|0)==0){w=-12}else{b:do{if((c[s>>2]|0)>0){x=0;z=u;while(1){A=z+(x*44|0)+12|0;c[A>>2]=c[1622320+(x<<5)>>2];B=c[1622328+(x<<5)>>2]|0;C=z+(x*44|0)|0;c[C>>2]=B;D=z+(x*44|0)+16|0;g[D>>2]=+g[1622340+(x<<5)>>2];E=z+(x*44|0)+20|0;g[E>>2]=+g[1622344+(x<<5)>>2];F=z+(x*44|0)+28|0;c[F>>2]=c[1622336+(x<<5)>>2];G=z+(x*44|0)+24|0;c[G>>2]=0;H=z+(x*44|0)+4|0;c[H>>2]=hJb(B)|0;B=hJb(c[C>>2]<<2)|0;I=z+(x*44|0)+8|0;c[I>>2]=B;J=c[H>>2]|0;if((J|0)==0|(B|0)==0){w=-12;break a}B=c[1622324+(x<<5)>>2]|0;nrc(J|0,c[1622332+(x<<5)>>2]|0,B)|0;mrc((c[H>>2]|0)+B|0,0,(c[C>>2]|0)-B|0)|0;B=c[F>>2]|0;do{if((B|0)==0){c[z+(x*44|0)+32>>2]=0}else{J=c[A>>2]|0;K=c[C>>2]|0;if((B|0)==2){L=ca(K,J)|0}else if((B|0)==1){L=Ntb(K,J)|0}else{L=0}J=hJb(L<<2)|0;K=J;c[z+(x*44|0)+32>>2]=K;if((J|0)==0){w=-12;break a}if((L|0)<=0){break}J=c[1622348+(x<<5)>>2]|0;M=0;do{c[K+(M<<2)>>2]=d[J+M|0]|0;M=M+1|0;}while((M|0)<(L|0))}}while(0);Otb(c[H>>2]|0,c[I>>2]|0,c[C>>2]|0)|0;B=c[F>>2]|0;do{if((B|0)==0){c[z+(x*44|0)+36>>2]=0;c[z+(x*44|0)+40>>2]=0}else{M=c[A>>2]|0;J=c[C>>2]|0;if((B|0)==1){K=Ntb(J,M)|0;N=K;O=c[C>>2]|0;P=c[A>>2]|0}else if((B|0)==2){N=ca(J,M)|0;O=J;P=M}else{N=0;O=J;P=M}M=z+(x*44|0)+36|0;c[M>>2]=hJb(ca(P<<2,O)|0)|0;J=pJb(c[C>>2]<<2)|0;K=J;c[z+(x*44|0)+40>>2]=K;Q=c[M>>2]|0;if((Q|0)==0|(J|0)==0){w=-12;break a}J=c[C>>2]|0;if((J|0)<=0){break}M=c[A>>2]|0;S=(M|0)>0;T=z+(x*44|0)+32|0;U=0;do{if(S){V=c[T>>2]|0;W=ca(U,M)|0;X=(c[G>>2]|0)==0;Y=K+(U<<2)|0;if((c[F>>2]|0)==1){if(X){Z=0;_=1;while(1){$=+g[D>>2]+0.0+ +(c[V+((((U|0)/(_|0)|0|0)%(N|0)|0)<<2)>>2]|0)*+g[E>>2];g[Q+(Z+W<<2)>>2]=$;aa=+g[Y>>2]+$*$;g[Y>>2]=aa;ba=ca(_,N)|0;da=Z+1|0;if((da|0)<(M|0)){Z=da;_=ba}else{ea=aa;break}}}else{aa=0.0;_=0;Z=1;while(1){$=aa+ +g[D>>2]+ +(c[V+((((U|0)/(Z|0)|0|0)%(N|0)|0)<<2)>>2]|0)*+g[E>>2];g[Q+(_+W<<2)>>2]=$;fa=+g[Y>>2]+$*$;g[Y>>2]=fa;ba=ca(Z,N)|0;da=_+1|0;if((da|0)<(M|0)){aa=$;_=da;Z=ba}else{ea=fa;break}}}}else{if(X){Z=0;while(1){_=Z+W|0;aa=+g[D>>2]+0.0+ +(c[V+(_<<2)>>2]|0)*+g[E>>2];g[Q+(_<<2)>>2]=aa;fa=+g[Y>>2]+aa*aa;g[Y>>2]=fa;_=Z+1|0;if((_|0)<(M|0)){Z=_}else{ea=fa;break}}}else{fa=0.0;Z=0;while(1){X=Z+W|0;aa=fa+ +g[D>>2]+ +(c[V+(X<<2)>>2]|0)*+g[E>>2];g[Q+(X<<2)>>2]=aa;$=+g[Y>>2]+aa*aa;g[Y>>2]=$;X=Z+1|0;if((X|0)<(M|0)){fa=aa;Z=X}else{ea=$;break}}}}}else{ea=+g[K+(U<<2)>>2]}g[K+(U<<2)>>2]=ea*.5;U=U+1|0;}while((U|0)<(J|0))}}while(0);E=x+1|0;if((E|0)>=(c[s>>2]|0)){break b}x=E;z=c[v>>2]|0}}}while(0);z=l+184|0;c[z>>2]=1;x=hJb(32)|0;E=l+188|0;c[E>>2]=x;if((x|0)==0){w=-12;break}D=x;c[D>>2]=8;F=hJb(32)|0;G=x+4|0;c[G>>2]=F;if((F|0)==0){w=-12;break}A=x+8|0;c[A>>2]=0;C=c[D>>2]|0;if((C|0)>0){nrc(F|0,1626072,C<<2)|0;F=0;B=0;do{I=c[1626072+(F<<2)>>2]|0;B=(B|0)>(I|0)?B:I;F=F+1|0;}while((F|0)<(C|0));c[A>>2]=B;ga=B+1|0}else{ga=1}c[A>>2]=ga;C=hJb(ga<<4)|0;F=C;I=x+12|0;c[I>>2]=F;if((C|0)==0){w=-12;break}c:do{if((c[A>>2]|0)>0){C=0;H=F;while(1){c[H+(C<<4)>>2]=c[1212520+(C*28|0)>>2];J=c[1212524+(C*28|0)>>2]|0;c[H+(C<<4)+4>>2]=J;c[H+(C<<4)+8>>2]=c[1212528+(C*28|0)>>2];U=1<<J;J=hJb(U<<2)|0;c[H+(C<<4)+12>>2]=J;if((J|0)==0){w=-12;break a}if((U|0)>0){nrc(J|0,1212532+(C*28|0)|0,U<<2)|0}U=C+1|0;if((U|0)>=(c[A>>2]|0)){break c}C=U;H=c[I>>2]|0}}}while(0);c[x+16>>2]=2;A=x+20|0;c[A>>2]=(c[r>>2]|0)-1;F=x+24|0;c[F>>2]=2;B=c[D>>2]|0;if((B|0)>0){H=c[G>>2]|0;C=c[I>>2]|0;U=0;J=2;do{J=(c[C+(c[H+(U<<2)>>2]<<4)>>2]|0)+J|0;c[F>>2]=J;U=U+1|0;}while((U|0)<(B|0));ha=J<<3}else{ha=16}B=hJb(ha)|0;U=B;c[x+28>>2]=U;if((B|0)==0){w=-12;break}b[B>>1]=0;b[B+8>>1]=1<<c[A>>2];B=c[F>>2]|0;if((B|0)>2){H=2;do{b[U+(H<<3)>>1]=c[1625960+(H-2<<2)>>2];H=H+1|0;}while((H|0)<(B|0))}if((Ptb(f,U,B)|0)!=0){w=-558323010;break}H=l+192|0;c[H>>2]=1;F=hJb(32)|0;A=l+196|0;c[A>>2]=F;if((F|0)==0){w=-12;break}x=F;c[x>>2]=2;c[F+4>>2]=0;c[F+8>>2]=1600;c[F+12>>2]=32;J=F+16|0;c[J>>2]=10;c[F+20>>2]=15;C=hJb(80)|0;I=F+24|0;c[I>>2]=C;if((C|0)==0){w=-12;break}nrc(C|0,1625880,80)|0;if((c[x>>2]|0)!=2){KIb(0,0,2354128,(m=i,i=i+24|0,c[m>>2]=2291872,c[m+8>>2]=2241112,c[m+16>>2]=201,m)|0);i=m;Hd();return 0}x=pJb(c[J>>2]<<3)|0;C=x;c[F+28>>2]=C;if((x|0)==0){w=-12;break}x=c[J>>2]|0;if((x|0)>0){J=0;d:while(1){F=0;while(1){if((F|0)>=8){break}if((a[(c[I>>2]|0)+(J<<3)+F|0]|0)==-1){F=F+1|0}else{break}}do{if((F|0)!=8){G=a[(c[I>>2]|0)+(J<<3)+F|0]|0;D=c[v>>2]|0;K=c[D+(G*44|0)+12>>2]|0;if((K|0)<=1){ia=67;break d}if((c[D+(G*44|0)+28>>2]|0)==0){ia=71;break d}M=c[D+(G*44|0)>>2]|0;if((M|0)<=0){break}Q=D+(G*44|0)+36|0;T=c[D+(G*44|0)+4>>2]|0;G=C+(J<<3)|0;D=C+(J<<3)+4|0;S=0;do{do{if((a[T+S|0]|0)!=0){Z=ca(S,K)|0;Y=c[Q>>2]|0;fa=+R(+(+g[Y+(Z<<2)>>2]));if(fa>+g[G>>2]){g[G>>2]=fa}fa=+R(+(+g[Y+(Z+1<<2)>>2]));if(!(fa>+g[D>>2])){break}g[D>>2]=fa}}while(0);S=S+1|0;}while((S|0)<(M|0))}}while(0);F=J+1|0;if((F|0)<(x|0)){J=F}else{ja=0;ia=79;break}}if((ia|0)==67){Cd(2547008,2241112,214,2651432);return 0}else if((ia|0)==71){Cd(2529352,2241112,215,2651432);return 0}else if((ia|0)==79){while(1){ia=0;J=C+(ja<<3)|0;g[J>>2]=+g[J>>2]+.8;J=C+(ja<<3)+4|0;g[J>>2]=+g[J>>2]+.8;J=ja+1|0;if((J|0)<(x|0)){ja=J;ia=79}else{break}}}}x=l+200|0;c[x>>2]=1;C=hJb(28)|0;J=l+204|0;c[J>>2]=C;if((C|0)==0){w=-12;break}I=C;c[I>>2]=1;B=hJb(c[o>>2]<<2)|0;c[C+4>>2]=B;if((B|0)==0){w=-12;break}U=c[o>>2]|0;if((U|0)>0){mrc(B|0,0,U<<2|0)|0}U=C+8|0;c[U>>2]=hJb(c[I>>2]<<2)|0;B=hJb(c[I>>2]<<2)|0;F=B;c[C+12>>2]=F;M=c[U>>2]|0;if((M|0)==0|(B|0)==0){w=-12;break}if((c[I>>2]|0)>0){B=0;do{c[M+(B<<2)>>2]=0;c[F+(B<<2)>>2]=0;B=B+1|0;}while((B|0)<(c[I>>2]|0))}I=(c[o>>2]|0)==2|0;B=C+16|0;c[B>>2]=I;F=C+20|0;c[F>>2]=hJb(I<<2)|0;I=hJb(c[B>>2]<<2)|0;M=I;c[C+24>>2]=M;U=c[F>>2]|0;if((U|0)==0|(I|0)==0){w=-12;break}if((c[B>>2]|0)!=0){c[U>>2]=0;c[M>>2]=1}M=l+208|0;c[M>>2]=1;U=hJb(8)|0;B=l+212|0;c[B>>2]=U;if((U|0)==0){w=-12;break}c[U>>2]=0;c[U+4>>2]=0;c[l+152>>2]=0;U=l+156|0;c[U>>2]=hJb(c[o>>2]<<2<<c[q>>2]>>>1)|0;I=l+160|0;c[I>>2]=hJb(c[o>>2]<<2<<c[q>>2])|0;F=l+164|0;c[F>>2]=hJb(c[o>>2]<<2<<c[q>>2]>>>1)|0;S=hJb(c[o>>2]<<2<<c[q>>2]>>>1)|0;c[l+168>>2]=S;if((c[U>>2]|0)==0){w=-12;break}if((c[I>>2]|0)==0){w=-12;break}if((c[F>>2]|0)==0|(S|0)==0){w=-12;break}S=c[r>>2]|0;c[l+144>>2]=c[1253648+(S-6<<2)>>2];c[l+148>>2]=c[1253648+((c[q>>2]|0)-6<<2)>>2];F=OPa(l+16|0,S,0,1.0)|0;if((F|0)<0){w=F;break}F=OPa(l+80|0,c[q>>2]|0,0,1.0)|0;S=(F|0)<0;if(S){w=S?F:0;break}c[f+72>>2]=0;if((c[f+88>>2]&2|0)==0){g[l+172>>2]=8.0;ka=8.0}else{fa=+(c[f+80>>2]|0)/118.0;g[l+172>>2]=fa;ka=fa}g[l+172>>2]=ka*ka;F=k;mrc(F|0,0,5e4)|0;S=j+8|0;I=j+12|0;U=j+4|0;D=j|0;c[k>>2]=1919907329;c[k+4>>2]=7563618;G=c[o>>2]|0;c[k+8>>2]=G<<24;c[k+12>>2]=c[p>>2]|G>>>8;c[k+16>>2]=0;c[k+20>>2]=0;G=k+24|0;c[G>>2]=0;Q=k+28|0;K=c[q>>2]<<4|c[r>>2];a[Q]=K;a[Q+1|0]=K>>>8|1;K=f+96|0;Q=k;T=G+6-k<<3>>3;G=5e4-T|0;Z=Q+T|0;Y=(G|0)<0?0:Z;V=Y;y=1919907331;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=Y+4|0;y=7563618;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=Y+8|0;y=0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;a[Y+12|0]=0;a[Y+13|0]=0;a[Y+14|0]=0;a[Y+15|0]=1;Y=G-16|0;G=T+16|0;V=Q+G|0;Q=(Y|0)<0;W=Q?0:V;X=Q?0:Y;c[j+20>>2]=X<<3;c[S>>2]=W;c[j+16>>2]=W+X;X=W;y=1919907333;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=(c[s>>2]|0)-1|0;Y=W+4|0;y=X<<24|7563618;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[I>>2]=W+8;W=X>>>8;X=c[s>>2]|0;c[D>>2]=W;c[U>>2]=32;do{if((X|0)>0){Y=0;Q=W;_=32;while(1){ba=c[v>>2]|0;da=5653314<<32-_|Q;if((_|0)>24){la=_;ma=da}else{na=c[I>>2]|0;oa=na;y=da;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;c[I>>2]=na+4;la=_+32|0;ma=5653314>>>(_>>>0)}na=la-24|0;c[D>>2]=ma;c[U>>2]=na;oa=ba+(Y*44|0)+12|0;da=c[oa>>2]|0;pa=da<<56-la|ma;if((na|0)>16){qa=na;ra=pa}else{sa=c[I>>2]|0;ta=sa;y=pa;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;c[I>>2]=sa+4;qa=la+8|0;ra=da>>>(na>>>0)}na=qa-16|0;c[D>>2]=ra;c[U>>2]=na;da=ba+(Y*44|0)|0;sa=c[da>>2]|0;ta=sa<<48-qa|ra;if((na|0)>24){ua=na;va=ta;wa=sa}else{pa=c[I>>2]|0;xa=pa;y=ta;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[I>>2]=pa+4;ua=qa+16|0;va=sa>>>(na>>>0);wa=c[da>>2]|0}na=ua-24|0;c[D>>2]=va;c[U>>2]=na;sa=ba+(Y*44|0)+4|0;pa=1;while(1){if((pa|0)>=(wa|0)){break}xa=c[sa>>2]|0;if((d[xa+pa|0]|0)>>>0<(d[xa+(pa-1)|0]|0)>>>0){break}else{pa=pa+1|0}}xa=(pa|0)==(wa|0);ta=xa&1;ya=ta<<56-ua|va;if((na|0)>1){za=na;Aa=ya}else{Ba=c[I>>2]|0;Ca=Ba;y=ya;a[Ca]=y;y=y>>8;a[Ca+1|0]=y;y=y>>8;a[Ca+2|0]=y;y=y>>8;a[Ca+3|0]=y;c[I>>2]=Ba+4;za=ua+8|0;Aa=ta>>>(na>>>0)}ta=za-1|0;c[D>>2]=Aa;c[U>>2]=ta;do{if(xa){Ba=d[c[sa>>2]|0]|0;Ca=Ba-1|0;ya=Ca<<33-za|Aa;if((ta|0)>5){Da=ta;Ea=ya}else{Fa=c[I>>2]|0;Ga=Fa;y=ya;a[Ga]=y;y=y>>8;a[Ga+1|0]=y;y=y>>8;a[Ga+2|0]=y;y=y>>8;a[Ga+3|0]=y;c[I>>2]=Fa+4;Da=za+31|0;Ea=Ca>>>(ta>>>0)}Ca=Da-5|0;c[D>>2]=Ea;c[U>>2]=Ca;Fa=c[da>>2]|0;if((Fa|0)>0){Ha=Ba;Ia=0;Ja=Fa;Ka=Ea;La=Ca}else{Ma=Ea;Na=Ca;break}while(1){Ca=0;while(1){Oa=Ca+Ia|0;if((Oa|0)>=(Ja|0)){break}if((d[(c[sa>>2]|0)+Oa|0]|0)==(Ha|0)){Ca=Ca+1|0}else{break}}Fa=Ja-Ia|0;Ba=Fa<<1;Ga=Ba>>>0>65535>>>0;ya=Ga?Fa>>>15&65535:Ba;Ba=Ga?16:0;if((ya&65280|0)==0){Pa=Ba;Qa=ya}else{Pa=Ba|8;Qa=ya>>>8}ya=(d[1359664+Qa|0]|0)+Pa|0;Ba=Ca<<32-La|Ka;if((La|0)>(ya|0)){Ra=La;Sa=Ba;Ta=Ja}else{Ga=c[I>>2]|0;Fa=Ga;y=Ba;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;c[I>>2]=Ga+4;Ra=La+32|0;Sa=(La|0)==32?0:Ca>>>(La>>>0);Ta=c[da>>2]|0}Ua=Ra-ya|0;if((Oa|0)<(Ta|0)){Ha=Ha+1|0;Ia=Oa;Ja=Ta;Ka=Sa;La=Ua}else{break}}c[D>>2]=Sa;c[U>>2]=Ua;Ma=Sa;Na=Ua}else{ya=c[da>>2]|0;Ga=0;while(1){if((Ga|0)>=(ya|0)){break}if((a[(c[sa>>2]|0)+Ga|0]|0)==0){break}else{Ga=Ga+1|0}}Fa=(Ga|0)==(ya|0);Ba=Fa&1^1;Va=Ba<<33-za|Aa;if((ta|0)>1){Wa=ta;Xa=Va;Ya=ya}else{Za=c[I>>2]|0;_a=Za;y=Va;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;c[I>>2]=Za+4;Wa=za+31|0;Xa=Ba>>>(ta>>>0);Ya=c[da>>2]|0}Ba=Wa-1|0;c[D>>2]=Xa;c[U>>2]=Ba;if((Ya|0)>0){$a=0;ab=Xa;bb=Ba}else{Ma=Xa;Na=Ba;break}while(1){if(Fa){cb=ab;db=bb}else{Ba=(a[(c[sa>>2]|0)+$a|0]|0)!=0|0;Za=Ba<<32-bb|ab;if((bb|0)>1){eb=bb;fb=Za}else{_a=c[I>>2]|0;Va=_a;y=Za;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;c[I>>2]=_a+4;eb=bb+32|0;fb=Ba>>>(bb>>>0)}Ba=eb-1|0;c[D>>2]=fb;c[U>>2]=Ba;cb=fb;db=Ba}Ba=a[(c[sa>>2]|0)+$a|0]|0;if(Ba<<24>>24==0){gb=cb;hb=db}else{_a=(Ba&255)-1|0;Ba=_a<<32-db|cb;if((db|0)>5){ib=db;jb=Ba}else{Va=c[I>>2]|0;Za=Va;y=Ba;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;c[I>>2]=Va+4;ib=db+32|0;jb=_a>>>(db>>>0)}_a=ib-5|0;c[D>>2]=jb;c[U>>2]=_a;gb=jb;hb=_a}_a=$a+1|0;if((_a|0)<(c[da>>2]|0)){$a=_a;ab=gb;bb=hb}else{Ma=gb;Na=hb;break}}}}while(0);sa=ba+(Y*44|0)+28|0;ta=c[sa>>2]|0;xa=ta<<32-Na|Ma;if((Na|0)>4){kb=Na;lb=xa;mb=ta}else{na=c[I>>2]|0;pa=na;y=xa;a[pa]=y;y=y>>8;a[pa+1|0]=y;y=y>>8;a[pa+2|0]=y;y=y>>8;a[pa+3|0]=y;c[I>>2]=na+4;kb=Na+32|0;lb=ta>>>(Na>>>0);mb=c[sa>>2]|0}sa=kb-4|0;c[D>>2]=lb;c[U>>2]=sa;do{if((mb|0)==0){nb=lb;ob=sa}else{ta=c[oa>>2]|0;na=c[da>>2]|0;if((mb|0)==1){pb=Ntb(na,ta)|0}else if((mb|0)==2){pb=ca(na,ta)|0}else{pb=0}ta=ba+(Y*44|0)+32|0;na=c[ta>>2]|0;pa=c[na>>2]|0;xa=pa<<1;Fa=xa>>>0>65535>>>0;ya=Fa?pa>>>15&65535:xa;xa=Fa?16:0;if((ya&65280|0)==0){qb=xa;rb=ya}else{qb=xa|8;rb=ya>>>8}ya=(d[1359664+rb|0]|0)+qb|0;if((pb|0)>1){xa=1;Fa=ya;while(1){pa=c[na+(xa<<2)>>2]|0;Ga=pa<<1;_a=Ga>>>0>65535>>>0;Va=_a?pa>>>15&65535:Ga;Ga=_a?16:0;if((Va&65280|0)==0){sb=Ga;tb=Va}else{sb=Ga|8;tb=Va>>>8}Va=(d[1359664+tb|0]|0)+sb|0;Ga=(Fa|0)>(Va|0)?Fa:Va;Va=xa+1|0;if((Va|0)<(pb|0)){xa=Va;Fa=Ga}else{ub=Ga;break}}}else{ub=ya}i9a(j,+g[ba+(Y*44|0)+16>>2]);i9a(j,+g[ba+(Y*44|0)+20>>2]);Fa=ub-1|0;xa=c[U>>2]|0;na=Fa<<32-xa|c[D>>2];if((xa|0)>4){vb=xa;wb=na}else{Ga=c[I>>2]|0;Va=Ga;y=na;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;c[I>>2]=Ga+4;vb=xa+32|0;wb=Fa>>>(xa>>>0)}xa=vb-4|0;c[D>>2]=wb;c[U>>2]=xa;Fa=c[ba+(Y*44|0)+24>>2]|0;Ga=Fa<<36-vb|wb;if((xa|0)>1){xb=xa;yb=Ga}else{Va=c[I>>2]|0;na=Va;y=Ga;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[I>>2]=Va+4;xb=vb+28|0;yb=Fa>>>(xa>>>0)}xa=xb-1|0;c[D>>2]=yb;c[U>>2]=xa;if((pb|0)>0){zb=0;Ab=yb;Bb=xa}else{nb=yb;ob=xa;break}while(1){xa=c[(c[ta>>2]|0)+(zb<<2)>>2]|0;Fa=xa<<32-Bb|Ab;if((Bb|0)>(ub|0)){Cb=Bb;Db=Fa}else{Va=c[I>>2]|0;na=Va;y=Fa;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[I>>2]=Va+4;Cb=Bb+32|0;Db=(Bb|0)==32?0:xa>>>(Bb>>>0)}Eb=Cb-ub|0;xa=zb+1|0;if((xa|0)<(pb|0)){zb=xa;Ab=Db;Bb=Eb}else{break}}c[D>>2]=Db;c[U>>2]=Eb;nb=Db;ob=Eb}}while(0);ba=Y+1|0;if((ba|0)<(c[s>>2]|0)){Y=ba;Q=nb;_=ob}else{break}}if((ob|0)>6){Fb=ob;Gb=nb}else{_=c[I>>2]|0;Q=_;y=nb;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[I>>2]=_+4;Fb=ob+32|0;Gb=0}_=Fb-6|0;c[D>>2]=Gb;c[U>>2]=_;if((_|0)>16){Hb=_;Ib=Gb;break}_=c[I>>2]|0;Q=_;y=Gb;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[I>>2]=_+4;Hb=Fb+26|0;Ib=0}else{c[D>>2]=W;c[U>>2]=26;Hb=26;Ib=W}}while(0);W=Hb-16|0;c[D>>2]=Ib;c[U>>2]=W;X=c[z>>2]|0;C=X-1|0;_=C<<48-Hb|Ib;if((W|0)>6){Jb=W;Kb=_;Lb=X}else{X=c[I>>2]|0;Q=X;y=_;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[I>>2]=X+4;Jb=Hb+16|0;Kb=C>>>(W>>>0);Lb=c[z>>2]|0}W=Jb-6|0;c[D>>2]=Kb;c[U>>2]=W;if((Lb|0)>0){C=0;X=Kb;Q=W;while(1){_=c[E>>2]|0;Y=1<<32-Q|X;if((Q|0)>16){Mb=Q;Nb=Y}else{ba=c[I>>2]|0;da=ba;y=Y;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[I>>2]=ba+4;Mb=Q+32|0;Nb=1>>>(Q>>>0)}ba=Mb-16|0;c[D>>2]=Nb;c[U>>2]=ba;da=_+(C<<5)|0;Y=c[da>>2]|0;oa=Y<<48-Mb|Nb;if((ba|0)>5){Ob=ba;Pb=oa;Qb=Y}else{sa=c[I>>2]|0;ta=sa;y=oa;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;c[I>>2]=sa+4;Ob=Mb+16|0;Pb=Y>>>(ba>>>0);Qb=c[da>>2]|0}ba=Ob-5|0;c[D>>2]=Pb;c[U>>2]=ba;if((Qb|0)>0){Y=_+(C<<5)+4|0;sa=0;ta=Pb;oa=ba;ya=Qb;while(1){xa=c[(c[Y>>2]|0)+(sa<<2)>>2]|0;Va=xa<<32-oa|ta;if((oa|0)>4){Rb=oa;Sb=Va;Tb=ya}else{na=c[I>>2]|0;Fa=na;y=Va;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;c[I>>2]=na+4;Rb=oa+32|0;Sb=xa>>>(oa>>>0);Tb=c[da>>2]|0}Ub=Rb-4|0;xa=sa+1|0;if((xa|0)<(Tb|0)){sa=xa;ta=Sb;oa=Ub;ya=Tb}else{break}}c[D>>2]=Sb;c[U>>2]=Ub;Vb=Sb;Wb=Ub}else{Vb=Pb;Wb=ba}ya=_+(C<<5)+8|0;if((c[ya>>2]|0)>0){oa=_+(C<<5)+12|0;ta=0;sa=Vb;da=Wb;while(1){Y=c[oa>>2]|0;xa=(c[Y+(ta<<4)>>2]|0)-1|0;na=xa<<32-da|sa;if((da|0)>3){Xb=da;Yb=na;Zb=Y}else{Y=c[I>>2]|0;Fa=Y;y=na;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;c[I>>2]=Y+4;Xb=da+32|0;Yb=xa>>>(da>>>0);Zb=c[oa>>2]|0}xa=Xb-3|0;c[D>>2]=Yb;c[U>>2]=xa;Y=c[Zb+(ta<<4)+4>>2]|0;Fa=Y<<35-Xb|Yb;if((xa|0)>2){_b=xa;$b=Fa;ac=Zb}else{na=c[I>>2]|0;Va=na;y=Fa;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;c[I>>2]=na+4;_b=Xb+29|0;$b=Y>>>(xa>>>0);ac=c[oa>>2]|0}xa=_b-2|0;c[D>>2]=$b;c[U>>2]=xa;if((c[ac+(ta<<4)+4>>2]|0)==0){bc=$b;cc=xa;dc=ac;ec=0}else{Y=c[ac+(ta<<4)+8>>2]|0;na=Y<<34-_b|$b;if((xa|0)>8){fc=xa;gc=na;hc=ac}else{Va=c[I>>2]|0;Fa=Va;y=na;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;c[I>>2]=Va+4;fc=_b+30|0;gc=Y>>>(xa>>>0);hc=c[oa>>2]|0}xa=fc-8|0;c[D>>2]=gc;c[U>>2]=xa;bc=gc;cc=xa;dc=hc;ec=c[hc+(ta<<4)+4>>2]|0}xa=1<<ec;if((xa|0)>0){Y=0;Va=bc;Fa=cc;na=dc;while(1){Ga=(c[(c[na+(ta<<4)+12>>2]|0)+(Y<<2)>>2]|0)+1|0;_a=Ga<<32-Fa|Va;if((Fa|0)>8){ic=Fa;jc=_a}else{pa=c[I>>2]|0;Za=pa;y=_a;a[Za]=y;y=y>>8;a[Za+1|0]=y;y=y>>8;a[Za+2|0]=y;y=y>>8;a[Za+3|0]=y;c[I>>2]=pa+4;ic=Fa+32|0;jc=Ga>>>(Fa>>>0)}kc=ic-8|0;Ga=Y+1|0;if((Ga|0)>=(xa|0)){break}Y=Ga;Va=jc;Fa=kc;na=c[oa>>2]|0}c[D>>2]=jc;c[U>>2]=kc;lc=jc;mc=kc}else{lc=bc;mc=cc}na=ta+1|0;if((na|0)<(c[ya>>2]|0)){ta=na;sa=lc;da=mc}else{nc=lc;oc=mc;break}}}else{nc=Vb;oc=Wb}da=(c[_+(C<<5)+16>>2]|0)-1|0;sa=da<<32-oc|nc;if((oc|0)>2){pc=oc;qc=sa}else{ta=c[I>>2]|0;ya=ta;y=sa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[I>>2]=ta+4;pc=oc+32|0;qc=da>>>(oc>>>0)}da=pc-2|0;c[D>>2]=qc;c[U>>2]=da;ta=_+(C<<5)+20|0;ya=c[ta>>2]|0;sa=ya<<34-pc|qc;if((da|0)>4){rc=da;sc=sa}else{oa=c[I>>2]|0;ba=oa;y=sa;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;c[I>>2]=oa+4;rc=pc+30|0;sc=ya>>>(da>>>0)}da=rc-4|0;c[D>>2]=sc;c[U>>2]=da;ya=_+(C<<5)+24|0;oa=c[ya>>2]|0;if((oa|0)>2){ba=_+(C<<5)+28|0;sa=2;na=sc;Fa=da;Va=oa;while(1){oa=c[ta>>2]|0;Y=e[(c[ba>>2]|0)+(sa<<3)>>1]|0;xa=Y<<32-Fa|na;if((Fa|0)>(oa|0)){tc=Fa;uc=xa;vc=Va}else{Ga=c[I>>2]|0;pa=Ga;y=xa;a[pa]=y;y=y>>8;a[pa+1|0]=y;y=y>>8;a[pa+2|0]=y;y=y>>8;a[pa+3|0]=y;c[I>>2]=Ga+4;tc=Fa+32|0;uc=(Fa|0)==32?0:Y>>>(Fa>>>0);vc=c[ya>>2]|0}wc=tc-oa|0;oa=sa+1|0;if((oa|0)<(vc|0)){sa=oa;na=uc;Fa=wc;Va=vc}else{break}}c[D>>2]=uc;c[U>>2]=wc;xc=uc;yc=wc}else{xc=sc;yc=da}Va=C+1|0;if((Va|0)<(c[z>>2]|0)){C=Va;X=xc;Q=yc}else{zc=xc;Ac=yc;break}}}else{zc=Kb;Ac=W}Q=c[H>>2]|0;X=Q-1|0;C=X<<32-Ac|zc;if((Ac|0)>6){Bc=Ac;Cc=C;Dc=Q}else{Q=c[I>>2]|0;z=Q;y=C;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[I>>2]=Q+4;Bc=Ac+32|0;Cc=X>>>(Ac>>>0);Dc=c[H>>2]|0}X=Bc-6|0;c[D>>2]=Cc;c[U>>2]=X;if((Dc|0)>0){Q=0;z=Cc;C=X;while(1){E=c[A>>2]|0;Va=c[E+(Q<<5)>>2]|0;Fa=Va<<32-C|z;if((C|0)>16){Ec=C;Fc=Fa}else{na=c[I>>2]|0;sa=na;y=Fa;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;c[I>>2]=na+4;Ec=C+32|0;Fc=Va>>>(C>>>0)}Va=Ec-16|0;na=c[E+(Q<<5)+4>>2]|0;sa=na<<48-Ec|Fc;if((Va|0)>24){Gc=Va;Hc=sa}else{Fa=c[I>>2]|0;ya=Fa;y=sa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[I>>2]=Fa+4;Gc=Ec+16|0;Hc=na>>>(Va>>>0)}Va=Gc-24|0;na=c[E+(Q<<5)+8>>2]|0;Fa=na<<56-Gc|Hc;if((Va|0)>24){Ic=Va;Jc=Fa}else{ya=c[I>>2]|0;sa=ya;y=Fa;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;c[I>>2]=ya+4;Ic=Gc+8|0;Jc=na>>>(Va>>>0)}Va=Ic-24|0;na=(c[E+(Q<<5)+12>>2]|0)-1|0;ya=na<<56-Ic|Jc;if((Va|0)>24){Kc=Va;Lc=ya}else{sa=c[I>>2]|0;Fa=sa;y=ya;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;c[I>>2]=sa+4;Kc=Ic+8|0;Lc=na>>>(Va>>>0)}Va=Kc-24|0;na=E+(Q<<5)+16|0;sa=(c[na>>2]|0)-1|0;Fa=sa<<56-Kc|Lc;if((Va|0)>6){Mc=Va;Nc=Fa}else{ya=c[I>>2]|0;ba=ya;y=Fa;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;c[I>>2]=ya+4;Mc=Kc+8|0;Nc=sa>>>(Va>>>0)}Va=Mc-6|0;sa=c[E+(Q<<5)+20>>2]|0;ya=sa<<38-Mc|Nc;if((Va|0)>8){Oc=Va;Pc=ya}else{ba=c[I>>2]|0;Fa=ba;y=ya;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;c[I>>2]=ba+4;Oc=Mc+26|0;Pc=sa>>>(Va>>>0)}Va=Oc-8|0;do{if((c[na>>2]|0)>0){sa=E+(Q<<5)+24|0;ba=0;Fa=Pc;ya=Va;while(1){ta=c[sa>>2]|0;_=((a[ta+(ba<<3)+1|0]|0)!=-1)<<1|(a[ta+(ba<<3)|0]|0)!=-1|((a[ta+(ba<<3)+2|0]|0)!=-1)<<2;oa=((a[ta+(ba<<3)+3|0]|0)!=-1)<<3|_|((a[ta+(ba<<3)+4|0]|0)!=-1)<<4|((a[ta+(ba<<3)+5|0]|0)!=-1)<<5|((a[ta+(ba<<3)+6|0]|0)!=-1)<<6|((a[ta+(ba<<3)+7|0]|0)!=-1)<<7;ta=_<<32-ya|Fa;if((ya|0)>3){Qc=ya;Rc=ta}else{Y=c[I>>2]|0;Ga=Y;y=ta;a[Ga]=y;y=y>>8;a[Ga+1|0]=y;y=y>>8;a[Ga+2|0]=y;y=y>>8;a[Ga+3|0]=y;c[I>>2]=Y+4;Qc=ya+32|0;Rc=_>>>(ya>>>0)}_=Qc-3|0;Y=(oa|0)>7;Ga=Y&1;ta=Ga<<35-Qc|Rc;if((_|0)>1){Sc=_;Tc=ta}else{pa=c[I>>2]|0;xa=pa;y=ta;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[I>>2]=pa+4;Sc=Qc+29|0;Tc=Ga>>>(_>>>0)}_=Sc-1|0;if(Y){Y=oa>>3;oa=Y<<33-Sc|Tc;if((_|0)>5){Uc=_;Vc=oa}else{Ga=c[I>>2]|0;pa=Ga;y=oa;a[pa]=y;y=y>>8;a[pa+1|0]=y;y=y>>8;a[pa+2|0]=y;y=y>>8;a[pa+3|0]=y;c[I>>2]=Ga+4;Uc=Sc+31|0;Vc=Y>>>(_>>>0)}Wc=Vc;Xc=Uc-5|0}else{Wc=Tc;Xc=_}_=ba+1|0;Yc=c[na>>2]|0;if((_|0)<(Yc|0)){ba=_;Fa=Wc;ya=Xc}else{break}}if((Yc|0)>0){Zc=0;_c=Wc;$c=Xc;ad=Wc;bd=Xc}else{cd=Wc;dd=Xc;break}while(1){ya=0;Fa=_c;ba=$c;_=ad;Y=bd;while(1){Ga=a[(c[sa>>2]|0)+(Zc<<3)+ya|0]|0;if(Ga<<24>>24==-1){ed=Fa;fd=ba;gd=_;hd=Y}else{pa=Ga<<24>>24;Ga=pa<<32-ba|Fa;if((ba|0)>8){id=ba;jd=Ga}else{oa=c[I>>2]|0;xa=oa;y=Ga;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[I>>2]=oa+4;id=ba+32|0;jd=pa>>>(ba>>>0)}pa=id-8|0;ed=jd;fd=pa;gd=jd;hd=pa}pa=ya+1|0;if((pa|0)<8){ya=pa;Fa=ed;ba=fd;_=gd;Y=hd}else{break}}Y=Zc+1|0;if((Y|0)<(c[na>>2]|0)){Zc=Y;_c=ed;$c=fd;ad=gd;bd=hd}else{cd=gd;dd=hd;break}}}else{cd=Pc;dd=Va}}while(0);Va=Q+1|0;if((Va|0)<(c[H>>2]|0)){Q=Va;z=cd;C=dd}else{break}}c[D>>2]=cd;c[U>>2]=dd;kd=cd;ld=dd}else{kd=Cc;ld=X}C=c[x>>2]|0;z=C-1|0;Q=z<<32-ld|kd;if((ld|0)>6){md=ld;nd=Q;od=C}else{C=c[I>>2]|0;H=C;y=Q;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[I>>2]=C+4;md=ld+32|0;nd=z>>>(ld>>>0);od=c[x>>2]|0}z=md-6|0;c[D>>2]=nd;c[U>>2]=z;if((od|0)>0){C=0;H=nd;Q=z;while(1){A=c[J>>2]|0;if((Q|0)>16){pd=Q;qd=H}else{W=c[I>>2]|0;Va=W;y=H;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;c[I>>2]=W+4;pd=Q+32|0;qd=0}W=pd-16|0;Va=A+(C*28|0)|0;na=c[Va>>2]|0;E=(na|0)>1|0;da=E<<48-pd|qd;if((W|0)>1){rd=W;sd=da;td=na}else{na=c[I>>2]|0;sa=na;y=da;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;c[I>>2]=na+4;rd=pd+16|0;sd=E>>>(W>>>0);td=c[Va>>2]|0}W=rd-1|0;if((td|0)>1){E=td-1|0;na=E<<33-rd|sd;if((W|0)>4){ud=W;vd=na}else{sa=c[I>>2]|0;da=sa;y=na;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[I>>2]=sa+4;ud=rd+31|0;vd=E>>>(W>>>0)}wd=ud-4|0;xd=vd}else{wd=W;xd=sd}W=A+(C*28|0)+16|0;E=c[W>>2]|0;sa=(E|0)!=0|0;da=sa<<32-wd|xd;if((wd|0)>1){yd=wd;zd=da;Ad=E}else{E=c[I>>2]|0;na=E;y=da;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[I>>2]=E+4;yd=wd+32|0;zd=sa>>>(wd>>>0);Ad=c[W>>2]|0}sa=yd-1|0;do{if((Ad|0)==0){Bd=sa;Dd=zd}else{E=Ad-1|0;na=E<<33-yd|zd;if((sa|0)>8){Ed=sa;Fd=na;Gd=Ad}else{da=c[I>>2]|0;Y=da;y=na;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[I>>2]=da+4;Ed=yd+31|0;Fd=E>>>(sa>>>0);Gd=c[W>>2]|0}E=Ed-8|0;if((Gd|0)<=0){Bd=E;Dd=Fd;break}da=A+(C*28|0)+20|0;Y=A+(C*28|0)+24|0;na=0;_=Fd;ba=E;while(1){E=c[o>>2]|0;Fa=(E<<1)-2|0;ya=Fa>>>0>65535>>>0;pa=ya?Fa>>>16:Fa;Fa=ya?16:0;if((pa&65280|0)==0){Id=Fa;Jd=pa}else{Id=Fa|8;Jd=pa>>>8}pa=(d[1359664+Jd|0]|0)+Id|0;Fa=c[(c[da>>2]|0)+(na<<2)>>2]|0;ya=Fa<<32-ba|_;if((ba|0)>(pa|0)){Kd=ba;Ld=ya;Md=E}else{E=c[I>>2]|0;oa=E;y=ya;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;c[I>>2]=E+4;Kd=ba+32|0;Ld=(ba|0)==32?0:Fa>>>(ba>>>0);Md=c[o>>2]|0}Fa=Kd-pa|0;pa=(Md<<1)-2|0;E=pa>>>0>65535>>>0;oa=E?pa>>>16:pa;pa=E?16:0;if((oa&65280|0)==0){Nd=pa;Od=oa}else{Nd=pa|8;Od=oa>>>8}oa=(d[1359664+Od|0]|0)+Nd|0;pa=c[(c[Y>>2]|0)+(na<<2)>>2]|0;E=pa<<32-Fa|Ld;if((Fa|0)>(oa|0)){Pd=Fa;Qd=E}else{ya=c[I>>2]|0;xa=ya;y=E;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[I>>2]=ya+4;Pd=Fa+32|0;Qd=(Fa|0)==32?0:pa>>>(Fa>>>0)}Fa=Pd-oa|0;oa=na+1|0;if((oa|0)<(c[W>>2]|0)){na=oa;_=Qd;ba=Fa}else{Bd=Fa;Dd=Qd;break}}}}while(0);if((Bd|0)>2){Rd=Bd;Sd=Dd}else{W=c[I>>2]|0;sa=W;y=Dd;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;c[I>>2]=W+4;Rd=Bd+32|0;Sd=0}W=Rd-2|0;sa=c[Va>>2]|0;do{if((sa|0)>1){ba=c[o>>2]|0;if((ba|0)<=0){Td=W;Ud=Sd;ia=280;break}_=A+(C*28|0)+4|0;na=0;Y=Sd;da=W;Fa=ba;while(1){ba=c[(c[_>>2]|0)+(na<<2)>>2]|0;oa=ba<<32-da|Y;if((da|0)>4){Vd=da;Wd=oa;Xd=Fa}else{pa=c[I>>2]|0;ya=pa;y=oa;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[I>>2]=pa+4;Vd=da+32|0;Wd=ba>>>(da>>>0);Xd=c[o>>2]|0}Yd=Vd-4|0;ba=na+1|0;if((ba|0)<(Xd|0)){na=ba;Y=Wd;da=Yd;Fa=Xd}else{break}}Zd=Wd;_d=Yd;$d=c[Va>>2]|0;ia=279}else{Zd=Sd;_d=W;$d=sa;ia=279}}while(0);if((ia|0)==279){ia=0;if(($d|0)>0){Td=_d;Ud=Zd;ia=280}else{ae=Zd;be=_d}}if((ia|0)==280){ia=0;sa=A+(C*28|0)+8|0;W=A+(C*28|0)+12|0;Fa=0;da=Ud;Y=Td;while(1){if((Y|0)>8){ce=Y;de=da}else{na=c[I>>2]|0;_=na;y=da;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;c[I>>2]=na+4;ce=Y+32|0;de=0}na=ce-8|0;_=c[(c[sa>>2]|0)+(Fa<<2)>>2]|0;ba=_<<40-ce|de;if((na|0)>8){ee=na;fe=ba}else{pa=c[I>>2]|0;ya=pa;y=ba;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[I>>2]=pa+4;ee=ce+24|0;fe=_>>>(na>>>0)}na=ee-8|0;_=c[(c[W>>2]|0)+(Fa<<2)>>2]|0;pa=_<<40-ee|fe;if((na|0)>8){ge=na;he=pa}else{ya=c[I>>2]|0;ba=ya;y=pa;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;c[I>>2]=ya+4;ge=ee+24|0;he=_>>>(na>>>0)}na=ge-8|0;_=Fa+1|0;if((_|0)<(c[Va>>2]|0)){Fa=_;da=he;Y=na}else{ae=he;be=na;break}}}Y=C+1|0;if((Y|0)<(c[x>>2]|0)){C=Y;H=ae;Q=be}else{break}}c[D>>2]=ae;c[U>>2]=be;ie=ae;je=be}else{ie=nd;je=z}Q=c[M>>2]|0;H=Q-1|0;C=H<<32-je|ie;if((je|0)>6){ke=je;le=C;me=Q}else{Q=c[I>>2]|0;x=Q;y=C;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[I>>2]=Q+4;ke=je+32|0;le=H>>>(je>>>0);me=c[M>>2]|0}H=ke-6|0;c[D>>2]=le;c[U>>2]=H;if((me|0)>0){Q=0;x=le;C=H;while(1){J=c[(c[B>>2]|0)+(Q<<3)>>2]|0;X=J<<32-C|x;if((C|0)>1){ne=C;oe=X}else{Y=c[I>>2]|0;da=Y;y=X;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[I>>2]=Y+4;ne=C+32|0;oe=J>>>(C>>>0)}J=ne-1|0;if((J|0)>16){pe=J;qe=oe}else{J=c[I>>2]|0;Y=J;y=oe;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[I>>2]=J+4;pe=ne+31|0;qe=0}J=pe-16|0;if((J|0)>16){re=J;se=qe}else{J=c[I>>2]|0;Y=J;y=qe;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[I>>2]=J+4;re=pe+16|0;se=0}J=re-16|0;Y=c[(c[B>>2]|0)+(Q<<3)+4>>2]|0;da=Y<<48-re|se;if((J|0)>8){te=J;ue=da}else{X=c[I>>2]|0;Fa=X;y=da;a[Fa]=y;y=y>>8;a[Fa+1|0]=y;y=y>>8;a[Fa+2|0]=y;y=y>>8;a[Fa+3|0]=y;c[I>>2]=X+4;te=re+16|0;ue=Y>>>(J>>>0)}ve=te-8|0;J=Q+1|0;if((J|0)<(c[M>>2]|0)){Q=J;x=ue;C=ve}else{break}}c[D>>2]=ue;c[U>>2]=ve;we=ue;xe=ve}else{we=le;xe=H}C=1<<32-xe|we;if((xe|0)>1){ye=xe;ze=C}else{x=c[I>>2]|0;Q=x;y=C;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[I>>2]=x+4;ye=xe+32|0;ze=1>>>(xe>>>0)}x=ye-1|0;c[D>>2]=ze;c[U>>2]=x;if((x|0)<32){Q=c[I>>2]|0;C=ye+7|0;M=(((C|0)>32?ye+6|0:31)-x|0)>>>3;B=M<<3;z=ze&255;J=Q;Y=ze;X=x;while(1){a[J]=z;Ae=Y>>>8;x=X+8|0;if((x|0)<32){z=Ae&255;J=J+1|0;Y=Ae;X=x}else{break}}X=Q+(M+1)|0;c[I>>2]=X;c[D>>2]=Ae;c[U>>2]=C+B;Be=X}else{Be=c[I>>2]|0}c[U>>2]=32;c[D>>2]=0;X=Be-(c[S>>2]|0)<<3>>3;Y=X+G|0;J=pJb(((Y|0)/255|0)+64+Y|0)|0;c[K>>2]=J;if((J|0)==0){w=-12;break}a[J]=2;Y=(C5a(J+1|0,T)|0)+1|0;z=(C5a(J+Y|0,16)|0)+Y|0;nrc(J+z|0,F|0,T)|0;Y=z+T|0;nrc(J+Y|0,Z|0,16)|0;z=Y+16|0;nrc(J+z|0,V|0,X)|0;Y=J+(z+X)-(c[K>>2]|0)|0;if((Y|0)<0){w=Y;break}c[f+100>>2]=Y;c[f+424>>2]=1<<(c[r>>2]|0)-1;n=0;i=h;return n|0}}while(0);g9a(f)|0;n=w;i=h;return n|0}function f9a(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0.0,za=0.0,Aa=0.0,Ba=0.0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0.0,$b=0.0,ac=0.0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0;l=i;i=i+816|0;m=l|0;n=l+136|0;o=l+272|0;p=l+672|0;q=l+704|0;r=l+712|0;s=l+720|0;t=l+744|0;u=c[f+60>>2]|0;v=(j|0)!=0;if(v){w=c[j+76>>2]|0;x=c[j+64>>2]|0}else{w=0;x=0}z=c[u+144>>2]|0;A=u+8|0;B=c[A>>2]|0;C=B-1|0;D=1<<C;E=+(1<<B|0)*.25;B=u+152|0;F=c[B>>2]|0;if((F|w|0)==0){H=0;i=l;return H|0}I=u;J=c[I>>2]|0;K=(J|0)>0;do{if((F|0)==0){if(!K){L=J;break}M=u+160|0;N=D<<2;O=0;while(1){mrc((c[M>>2]|0)+(O<<C<<1<<2)|0,0,N|0)|0;P=O+1|0;Q=c[I>>2]|0;if((P|0)<(Q|0)){O=P}else{L=Q;break}}}else{if(!K){L=J;break}O=u+160|0;N=u+156|0;M=D<<2;Q=0;while(1){P=Q<<C;nrc((c[O>>2]|0)+(P<<1<<2)|0,(c[N>>2]|0)+(P<<2)|0,M)|0;P=Q+1|0;U=c[I>>2]|0;if((P|0)<(U|0)){Q=P}else{L=U;break}}}}while(0);J=(w|0)!=0;K=(L|0)>0;do{if(J){if(!K){V=1;break}F=c[u+160>>2]|0;Q=(w|0)>0;M=D-1|0;N=0;while(1){O=(N<<C<<1)+D|0;if(Q){U=c[x+(N<<2)>>2]|0;P=0;do{g[F+(O+P<<2)>>2]=+g[U+(P<<2)>>2]/E*+g[z+(M-P<<2)>>2];P=P+1|0;}while((P|0)<(w|0))}P=N+1|0;if((P|0)<(L|0)){N=P}else{W=L;X=16;break}}}else{if(!K){V=0;break}N=u+160|0;M=D<<2;F=0;while(1){mrc((c[N>>2]|0)+((F<<C<<1)+D<<2)|0,0,M|0)|0;Q=F+1|0;P=c[I>>2]|0;if((Q|0)<(P|0)){F=Q}else{W=P;X=16;break}}}}while(0);do{if((X|0)==16){if((W|0)>0){D=u+16|0;K=u+64|0;L=u+168|0;F=u+160|0;M=0;while(1){N=M<<C;ef[c[K>>2]&4095](D,(c[L>>2]|0)+(N<<2)|0,(c[F>>2]|0)+(N<<1<<2)|0);N=M+1|0;P=c[I>>2]|0;if((N|0)<(P|0)){M=N}else{Y=P;break}}}else{Y=W}if(!J){V=0;break}if((Y|0)<=0){V=1;break}M=c[u+156>>2]|0;F=(w|0)>0;L=0;while(1){D=L<<C;if(F){K=c[x+(L<<2)>>2]|0;P=0;do{g[M+(P+D<<2)>>2]=+g[K+(P<<2)>>2]/E*+g[z+(P<<2)>>2];P=P+1|0;}while((P|0)<(w|0))}P=L+1|0;if((P|0)<(Y|0)){L=P}else{V=1;break}}}}while(0);c[B>>2]=V;V=(c[A>>2]|0)-1|0;A=1<<V;B=d5a(f,h,8192,0)|0;if((B|0)<0){H=B;i=l;return H|0}B=h+28|0;Y=c[B>>2]|0;w=(Y|0)<0;z=w?0:c[h+24>>2]|0;x=w?0:Y;Y=x<<3;w=s+20|0;c[w>>2]=Y;C=s+8|0;c[C>>2]=z;c[s+16>>2]=z+x;x=s+12|0;c[x>>2]=z;J=s+4|0;c[J>>2]=32;W=s|0;c[W>>2]=0;L=c[u+208>>2]|0;M=(L<<1)-2|0;F=M>>>0>65535>>>0;P=F?M>>>16:M;M=F?16:0;if((P&65280|0)==0){Z=M;_=P}else{Z=M|8;_=P>>>8}if((Y|0)<(Z+1+(d[1359664+_|0]|0)|0)){KIb(f,16,2442400,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;H=-22;i=l;return H|0}c[W>>2]=0;c[J>>2]=31;_=(L<<1)-2|0;L=_>>>0>65535>>>0;Z=L?_>>>16:_;_=L?16:0;if((Z&65280|0)==0){aa=_;ba=Z}else{aa=_|8;ba=Z>>>8}Z=(d[1359664+ba|0]|0)+aa|0;if((Z|0)<31){da=31;ea=z}else{aa=z;y=0;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;aa=z+4|0;c[x>>2]=aa;da=63;ea=aa}aa=da-Z|0;c[W>>2]=0;c[J>>2]=aa;Z=c[u+212>>2]|0;da=c[Z+4>>2]|0;z=c[u+204>>2]|0;if((c[Z>>2]|0)==0){fa=aa;ga=ea}else{if((aa|0)>1){ha=aa;ia=ea}else{Z=ea;y=0;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;Z=(c[x>>2]|0)+4|0;c[x>>2]=Z;ha=aa+32|0;ia=Z}Z=ha-1|0;c[W>>2]=0;c[J>>2]=Z;if((Z|0)>1){ja=Z;ka=ia}else{Z=ia;y=0;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;Z=(c[x>>2]|0)+4|0;c[x>>2]=Z;ja=ha+31|0;ka=Z}Z=ja-1|0;c[W>>2]=0;c[J>>2]=Z;fa=Z;ga=ka}ka=c[I>>2]|0;a:do{if((ka|0)>0){Z=z+(da*28|0)+4|0;ja=z+(da*28|0)+8|0;ha=u+188|0;ia=u+168|0;aa=t|0;ea=u+172|0;ba=u+164|0;_=t+2|0;L=m+4|0;Y=m|0;P=u+180|0;M=0;F=fa;K=ga;D=0;b:while(1){N=c[(c[ja>>2]|0)+(c[(c[Z>>2]|0)+(M<<2)>>2]<<2)>>2]|0;Q=c[ha>>2]|0;U=M<<V;O=c[ia>>2]|0;la=Q+(N<<5)+16|0;ma=c[la>>2]|0;na=255/(ma|0)|0;oa=Q+(N<<5)+24|0;pa=c[oa>>2]|0;if((pa|0)>0){qa=c[Q+(N<<5)+28>>2]|0;ra=pa-1|0;E=0.0;sa=0;while(1){ta=sa-1|0;ua=b[qa+((e[qa+(((ta|0)>0?ta:0)<<3)+2>>1]|0)<<3)>>1]|0;ta=ua&65535;va=sa+1|0;wa=b[qa+((e[qa+(((va|0)>(ra|0)?ra:va)<<3)+2>>1]|0)<<3)>>1]|0;xa=wa&65535;if((ua&65535)>>>0<(wa&65535)>>>0){wa=ta;ya=0.0;while(1){za=ya+ +R(+(+g[O+(wa+U<<2)>>2]));ua=wa+1|0;if((ua|0)<(xa|0)){wa=ua;ya=za}else{Aa=za;break}}}else{Aa=0.0}ya=Aa/+(xa-ta|0);g[n+(sa<<2)>>2]=ya;Ba=E+ya;if((va|0)<(pa|0)){E=Ba;sa=va}else{break}}E=Ba/+(pa|0)/+g[ea>>2];sa=0;do{O=e[qa+(sa<<3)+2>>1]|0;ya=+S(E*+g[n+(sa<<2)>>2])*+T(1.25,+(+(e[qa+(O<<3)>>1]|0|0)*.004999999888241291));ra=0;while(1){if((ra|0)>=(na|0)){break}if(+g[1253680+((ca(ra,ma)|0)<<2)>>2]>ya){break}else{ra=ra+1|0}}b[t+(O<<1)>>1]=ra;sa=sa+1|0;}while((sa|0)<(pa|0))}pa=(c[ba>>2]|0)+(U<<2)|0;sa=na+1|0;ma=na<<1;qa=ma>>>0>65535>>>0;va=qa?na>>>15&65535:ma;ma=qa?16:0;if((va&65280|0)==0){Ca=ma;Da=va}else{Ca=ma|8;Da=va>>>8}va=(d[1359664+Da|0]|0)+Ca|0;if(((c[w>>2]|0)-32+F-(K-(c[C>>2]|0)<<3)|0)<(va<<1|1|0)){break}ma=D|1<<32-F;if((F|0)>1){Ea=F;Fa=ma;Ga=K}else{qa=K;y=ma;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;qa=(c[x>>2]|0)+4|0;c[x>>2]=qa;Ea=F+32|0;Fa=1>>>(F>>>0);Ga=qa}qa=Ea-1|0;c[W>>2]=Fa;c[J>>2]=qa;ma=e[aa>>1]|0;ta=ma<<33-Ea|Fa;if((qa|0)>(va|0)){Ha=qa;Ia=ta;Ja=Ga}else{xa=Ga;y=ta;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=(c[x>>2]|0)+4|0;c[x>>2]=xa;Ha=Ea+31|0;Ia=(qa|0)==32?0:ma>>>(qa>>>0);Ja=xa}xa=Ha-va|0;c[W>>2]=Ia;c[J>>2]=xa;qa=e[_>>1]|0;ma=qa<<32-xa|Ia;if((xa|0)>(va|0)){Ka=xa;La=ma;Ma=Ja}else{ta=Ja;y=ma;a[ta]=y;y=y>>8;a[ta+1|0]=y;y=y>>8;a[ta+2|0]=y;y=y>>8;a[ta+3|0]=y;ta=(c[x>>2]|0)+4|0;c[x>>2]=ta;Ka=xa+32|0;La=(xa|0)==32?0:qa>>>(xa>>>0);Ma=ta}ta=Ka-va|0;c[W>>2]=La;c[J>>2]=ta;c[L>>2]=1;c[Y>>2]=1;va=c[oa>>2]|0;if((va|0)>2){xa=c[Q+(N<<5)+28>>2]|0;qa=2;do{ma=e[xa+(qa<<3)+4>>1]|0;wa=e[xa+(ma<<3)>>1]|0;ua=e[t+(ma<<1)>>1]|0;Na=e[xa+(qa<<3)+6>>1]|0;Oa=((ca((e[xa+(qa<<3)>>1]|0)-wa|0,(e[t+(Na<<1)>>1]|0)-ua|0)|0)/((e[xa+(Na<<3)>>1]|0)-wa|0)|0)+ua|0;ua=sa-Oa|0;wa=(ua|0)>(Oa|0)?Oa:ua;Pa=e[t+(qa<<1)>>1]|0;do{if((Oa|0)==(Pa|0)){c[m+(qa<<2)>>2]=0}else{Qa=m+(ma<<2)|0;if((c[Qa>>2]|0)==0){c[Qa>>2]=-1}Qa=m+(Na<<2)|0;if((c[Qa>>2]|0)==0){c[Qa>>2]=-1}if((Pa|0)>(Oa|0)){Qa=Pa-Oa|0;if((Qa|0)>(wa|0)){c[m+(qa<<2)>>2]=Pa;break}else{c[m+(qa<<2)>>2]=Qa<<1;break}}else{Qa=Oa-Pa|0;if((Qa|0)>(wa|0)){c[m+(qa<<2)>>2]=ua-1+Qa;break}else{c[m+(qa<<2)>>2]=(Qa<<1)-1;break}}}}while(0);qa=qa+1|0;}while((qa|0)<(va|0))}qa=Q+(N<<5)|0;if((c[qa>>2]|0)>0){sa=Q+(N<<5)+4|0;xa=Q+(N<<5)+12|0;na=2;U=0;ua=ta;wa=Ma;Pa=La;Oa=ta;Na=Ma;ma=La;while(1){ra=c[(c[sa>>2]|0)+(U<<2)>>2]|0;O=c[xa>>2]|0;Qa=O+(ra<<4)|0;Ra=O+(ra<<4)+4|0;Sa=c[Ra>>2]|0;Ta=1<<Sa;if((Sa|0)==0){Ua=0;Va=ua;Wa=wa;Xa=Pa;Ya=Qa|0;Za=Oa;_a=Na;$a=ma}else{ab=c[O+(ra<<4)+8>>2]|0;bb=c[P>>2]|0;cb=Qa|0;Qa=c[cb>>2]|0;if((Qa|0)>0){db=O+(ra<<4)+12|0;eb=0;fb=0;gb=0;while(1){hb=m+(eb+na<<2)|0;ib=0;while(1){if((ib|0)>=(Ta|0)){break}jb=c[(c[db>>2]|0)+(ib<<2)>>2]|0;if((jb|0)==-1){kb=1}else{kb=c[bb+(jb*44|0)>>2]|0}if((c[hb>>2]|0)<(kb|0)){break}else{ib=ib+1|0}}if((ib|0)==(Ta|0)){X=97;break b}hb=ib<<gb|fb;jb=eb+1|0;if((jb|0)<(Qa|0)){eb=jb;fb=hb;gb=gb+Sa|0}else{lb=hb;break}}}else{lb=0}Sa=d[(c[bb+(ab*44|0)+4>>2]|0)+lb|0]|0;if((ua-32+(c[w>>2]|0)-(wa-(c[C>>2]|0)<<3)|0)<(Sa|0)){break b}gb=c[(c[bb+(ab*44|0)+8>>2]|0)+(lb<<2)>>2]|0;fb=gb<<32-ua|Pa;if((ua|0)>(Sa|0)){mb=ua;nb=fb;ob=wa;pb=Na}else{eb=wa;y=fb;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;eb=(c[x>>2]|0)+4|0;c[x>>2]=eb;mb=ua+32|0;nb=(ua|0)==32?0:gb>>>(ua>>>0);ob=eb;pb=eb}eb=mb-Sa|0;c[W>>2]=nb;c[J>>2]=eb;Ua=lb;Va=eb;Wa=ob;Xa=nb;Ya=cb;Za=eb;_a=pb;$a=nb}eb=c[Ya>>2]|0;c:do{if((eb|0)>0){Sa=Ta-1|0;gb=O+(ra<<4)+12|0;fb=1;Qa=Ua;db=na;hb=Va;jb=Wa;qb=Xa;rb=eb;sb=Za;tb=_a;ub=$a;while(1){vb=c[(c[gb>>2]|0)+((Qa&Sa)<<2)>>2]|0;wb=db+1|0;xb=c[m+(db<<2)>>2]|0;yb=Qa>>c[Ra>>2];if((vb|0)==-1){zb=hb;Ab=jb;Bb=qb;Cb=rb;Db=sb;Eb=tb;Fb=ub}else{Gb=(xb|0)==-1?0:xb;xb=c[P>>2]|0;Hb=d[(c[xb+(vb*44|0)+4>>2]|0)+Gb|0]|0;if((hb-32+(c[w>>2]|0)-(jb-(c[C>>2]|0)<<3)|0)<(Hb|0)){break b}Ib=c[(c[xb+(vb*44|0)+8>>2]|0)+(Gb<<2)>>2]|0;Gb=Ib<<32-hb|qb;if((hb|0)>(Hb|0)){Jb=hb;Kb=Gb;Lb=jb;Mb=tb;Nb=rb}else{vb=jb;y=Gb;a[vb]=y;y=y>>8;a[vb+1|0]=y;y=y>>8;a[vb+2|0]=y;y=y>>8;a[vb+3|0]=y;vb=(c[x>>2]|0)+4|0;c[x>>2]=vb;Jb=hb+32|0;Kb=(hb|0)==32?0:Ib>>>(hb>>>0);Lb=vb;Mb=vb;Nb=c[Ya>>2]|0}vb=Jb-Hb|0;c[W>>2]=Kb;c[J>>2]=vb;zb=vb;Ab=Lb;Bb=Kb;Cb=Nb;Db=vb;Eb=Mb;Fb=Kb}if((fb|0)>=(Cb|0)){Ob=wb;Pb=zb;Qb=Ab;Rb=Bb;Sb=Db;Tb=Eb;Ub=Fb;break c}fb=fb+1|0;Qa=yb;db=wb;hb=zb;jb=Ab;qb=Bb;rb=Cb;sb=Db;tb=Eb;ub=Fb}}else{Ob=na;Pb=Va;Qb=Wa;Rb=Xa;Sb=Za;Tb=_a;Ub=$a}}while(0);Ra=U+1|0;if((Ra|0)<(c[qa>>2]|0)){na=Ob;U=Ra;ua=Pb;wa=Qb;Pa=Rb;Oa=Sb;Na=Tb;ma=Ub}else{break}}Vb=c[oa>>2]|0;Wb=Sb;Xb=Tb;Yb=Ub}else{Vb=va;Wb=ta;Xb=Ma;Yb=La}Qtb(c[Q+(N<<5)+28>>2]|0,Vb,aa,Y,c[la>>2]|0,pa,A);ma=M+1|0;Na=c[I>>2]|0;if((ma|0)<(Na|0)){M=ma;F=Wb;K=Xb;D=Yb}else{Zb=Na;break a}}if((X|0)==97){Cd(2636072,2241112,821,2652656);return 0}KIb(f,16,2442400,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;H=-22;i=l;return H|0}else{Zb=ka}}while(0);ka=Zb<<V;if((ka|0)>0){Yb=c[u+164>>2]|0;Xb=c[u+168>>2]|0;Wb=0;do{I=Xb+(Wb<<2)|0;g[I>>2]=+g[I>>2]/+g[Yb+(Wb<<2)>>2];Wb=Wb+1|0;}while((Wb|0)<(ka|0))}ka=c[z+(da*28|0)+16>>2]|0;Wb=c[u+168>>2]|0;if((ka|0)>0){Yb=c[z+(da*28|0)+20>>2]|0;Xb=c[z+(da*28|0)+24>>2]|0;I=(A|0)>0;Vb=0;do{La=c[Yb+(Vb<<2)>>2]<<V;Ma=c[Xb+(Vb<<2)>>2]<<V;if(I){Ub=0;do{Tb=Wb+(Ub+Ma<<2)|0;Ba=+g[Tb>>2];Sb=Wb+(Ub+La<<2)|0;Aa=Ba- +g[Sb>>2];g[Tb>>2]=Aa;if(+g[Sb>>2]>0.0){E=-0.0-Aa;g[Tb>>2]=E;_b=E}else{_b=Aa}if(_b<0.0){g[Sb>>2]=Ba}Ub=Ub+1|0;}while((Ub|0)<(A|0))}Vb=Vb+1|0;}while((Vb|0)<(ka|0))}ka=c[(c[z+(da*28|0)+12>>2]|0)+(c[c[z+(da*28|0)+4>>2]>>2]<<2)>>2]|0;da=c[u+196>>2]|0;z=c[da+(ka<<5)+12>>2]|0;Vb=da+(ka<<5)+4|0;I=c[Vb>>2]|0;Xb=((c[da+(ka<<5)+8>>2]|0)-I|0)/(z|0)|0;Yb=da+(ka<<5)|0;Ub=(c[Yb>>2]|0)==2;La=Ub?1:Zb;Ma=da+(ka<<5)+20|0;Sb=u+180|0;Tb=c[(c[Sb>>2]|0)+((c[Ma>>2]|0)*44|0)+12>>2]|0;if(!Ub){KIb(0,0,2354128,($=i,i=i+24|0,c[$>>2]=2291872,c[$+8>>2]=2241112,c[$+16>>2]=881,$)|0);i=$;Hd();return 0}if((Zb|0)!=2){KIb(0,0,2354128,($=i,i=i+24|0,c[$>>2]=2200168,c[$+8>>2]=2241112,c[$+16>>2]=882,$)|0);i=$;Hd();return 0}Zb=(Xb|0)>0;Ub=da+(ka<<5)+16|0;if(Zb){Rb=(c[Ub>>2]|0)-1|0;Qb=(Rb|0)>0;Pb=da+(ka<<5)+28|0;Ob=(z|0)>0;$a=0;do{_a=(ca($a,z)|0)+I|0;Za=_a+z|0;if(Ob){_b=0.0;Ba=0.0;Xa=_a;while(1){_a=(Xa|0)/2|0;Aa=+R(+(+g[Wb+(_a<<2)>>2]));E=_b>Aa?_b:Aa;Aa=+R(+(+g[Wb+(_a+A<<2)>>2]));ya=Ba>Aa?Ba:Aa;_a=Xa+2|0;if((_a|0)<(Za|0)){_b=E;Ba=ya;Xa=_a}else{$b=E;ac=ya;break}}}else{$b=0.0;ac=0.0}d:do{if(Qb){Xa=c[Pb>>2]|0;Za=0;while(1){if($b<+g[Xa+(Za<<3)>>2]){if(ac<+g[Xa+(Za<<3)+4>>2]){bc=Za;break d}}_a=Za+1|0;if((_a|0)<(Rb|0)){Za=_a}else{bc=_a;break}}}else{bc=0}}while(0);c[o+($a<<2)>>2]=bc;$a=$a+1|0;}while(($a|0)<(Xb|0))}$a=(La|0)>0;bc=(Tb|0)>0;Rb=da+(ka<<5)+24|0;ka=A<<1;da=(z|0)>0;Pb=p|0;p=$a^1;Qb=0;e:while(1){if(Zb){Ob=(Qb|0)!=0|p;I=0;while(1){if(!Ob){Za=c[C>>2]|0;Xa=(c[w>>2]|0)-32|0;pa=0;do{la=c[Ma>>2]|0;N=c[Sb>>2]|0;if(bc){Q=c[Ub>>2]|0;ta=0;va=0;while(1){oa=ca(ta,Q)|0;_a=oa+(c[o+(pa*200|0)+(va+I<<2)>>2]|0)|0;oa=va+1|0;if((oa|0)<(Tb|0)){ta=_a;va=oa}else{cc=_a;break}}}else{cc=0}va=c[J>>2]|0;ta=c[x>>2]|0;Q=d[(c[N+(la*44|0)+4>>2]|0)+cc|0]|0;if((Xa+va-(ta-Za<<3)|0)<(Q|0)){X=178;break e}_a=c[(c[N+(la*44|0)+8>>2]|0)+(cc<<2)>>2]|0;oa=_a<<32-va|c[W>>2];if((va|0)>(Q|0)){dc=va;ec=oa}else{Wa=ta;y=oa;a[Wa]=y;y=y>>8;a[Wa+1|0]=y;y=y>>8;a[Wa+2|0]=y;y=y>>8;a[Wa+3|0]=y;c[x>>2]=ta+4;dc=va+32|0;ec=(va|0)==32?0:_a>>>(va>>>0)}c[W>>2]=ec;c[J>>2]=dc-Q;pa=pa+1|0;}while((pa|0)<(La|0))}if(bc&(I|0)<(Xb|0)){pa=I;Za=0;while(1){if($a){Xa=ca(pa,z)|0;Q=0;do{va=a[(c[Rb>>2]|0)+(c[o+(Q*200|0)+(pa<<2)>>2]<<3)+Qb|0]|0;_a=va<<24>>24;ta=c[Sb>>2]|0;Wa=ta+(_a*44|0)|0;oa=c[Vb>>2]|0;Va=(Q<<V)+Xa+oa|0;f:do{if(!(va<<24>>24==-1)){Fb=c[Yb>>2]|0;if(!((Fb|0)==0|(Fb|0)==2)){X=158;break e}Eb=ta+(_a*44|0)+12|0;Db=c[Eb>>2]|0;if(((z|0)%(Db|0)|0|0)!=0){X=160;break e}if((Fb|0)==0){if(da){fc=0}else{break}while(1){Fb=Va+fc|0;Cb=h9a(Wa,s,Wb+(Fb<<2)|0)|0;if((Cb|0)==0){X=178;break e}Bb=c[Eb>>2]|0;if((Bb|0)>0){Ab=0;do{zb=Wb+(Ab+Fb<<2)|0;g[zb>>2]=+g[zb>>2]- +g[Cb+(Ab<<2)>>2];Ab=Ab+1|0;}while((Ab|0)<(Bb|0))}fc=Bb+fc|0;if((fc|0)>=(z|0)){break f}}}Ab=oa+Xa|0;if(!da){break}Cb=0;Fb=((Ab|0)%2|0)<<V;zb=(Ab|0)/2|0;Ab=Db;while(1){if((Ab|0)!=0){Kb=Ab;Mb=Fb;Nb=zb;Lb=Pb;while(1){Jb=Kb-1|0;g[Lb>>2]=+g[Wb+(Mb+Nb<<2)>>2];Ya=Mb+A|0;m=(Ya|0)==(ka|0);if((Jb|0)==0){break}else{Kb=Jb;Mb=m?0:Ya;Nb=(m&1)+Nb|0;Lb=Lb+4|0}}}Lb=h9a(Wa,s,Pb)|0;if((Lb|0)==0){X=178;break e}Nb=c[Eb>>2]|0;if((Nb|0)==0){gc=Fb;hc=zb}else{Mb=Fb;Kb=zb;Bb=Nb;m=Lb;while(1){Lb=Bb-1|0;Ya=Wb+(Mb+Kb<<2)|0;g[Ya>>2]=+g[Ya>>2]- +g[m>>2];Ya=Mb+A|0;Jb=(Ya|0)==(ka|0);Ua=Jb?0:Ya;Ya=(Jb&1)+Kb|0;if((Lb|0)==0){gc=Ua;hc=Ya;break}else{Mb=Ua;Kb=Ya;Bb=Lb;m=m+4|0}}}m=Nb+Cb|0;if((m|0)<(z|0)){Cb=m;Fb=gc;zb=hc;Ab=Nb}else{break}}}}while(0);Q=Q+1|0;}while((Q|0)<(La|0))}Q=Za+1|0;Xa=pa+1|0;if((Q|0)<(Tb|0)&(Xa|0)<(Xb|0)){pa=Xa;Za=Q}else{ic=Xa;break}}}else{ic=I}if((ic|0)<(Xb|0)){I=ic}else{break}}}I=Qb+1|0;if((I|0)<8){Qb=I}else{X=179;break}}if((X|0)==158){Cd(2168360,2241112,919,2651384);return 0}else if((X|0)==160){Cd(2141616,2241112,920,2651384);return 0}else if((X|0)==178){KIb(f,16,2442400,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;H=-22;i=l;return H|0}else if((X|0)==179){X=c[J>>2]|0;if((X|0)<32){$=c[W>>2]|0;Qb=c[x>>2]|0;ic=(((X+8|0)>32?X+7|0:31)-X|0)>>>3;Xb=X+(ic<<3)|0;Tb=ic+1|0;ic=$&255;La=Qb;hc=$;$=X;while(1){a[La]=ic;jc=hc>>>8;X=$+8|0;if((X|0)<32){ic=jc&255;La=La+1|0;hc=jc;$=X}else{break}}$=Qb+Tb|0;c[x>>2]=$;c[W>>2]=jc;c[J>>2]=Xb+8;kc=$}else{kc=c[x>>2]|0}c[J>>2]=32;c[W>>2]=0;c[B>>2]=kc-(c[C>>2]|0)<<3>>3;C=c[f+424>>2]|0;c[q>>2]=1;kc=f+412|0;c[q+4>>2]=c[kc>>2];B=f+104|0;f=XIb(C,(C|0)<0|0?-1:0,q,B)|0;q=h+48|0;c[q>>2]=f;do{if(v){f=j+136|0;C=c[f>>2]|0;W=c[f+4>>2]|0;if((C|0)==0&(W|0)==(-2147483648|0)){f=h+8|0;lc=c[f+4>>2]|0;mc=c[f>>2]|0;break}else{c[r>>2]=1;c[r+4>>2]=c[kc>>2];f=XIb(C,W,r,B)|0;W=G;C=h+8|0;c[C>>2]=f;c[C+4>>2]=W;lc=W;mc=f;break}}else{f=u+216|0;W=c[f>>2]|0;C=c[f+4>>2]|0;f=h+8|0;c[f>>2]=W;c[f+4>>2]=C;lc=C;mc=W}}while(0);if(!((mc|0)==0&(lc|0)==(-2147483648|0))){h=c[q>>2]|0;q=wrc(h,(h|0)<0|0?-1:0,mc,lc)|0;lc=u+216|0;c[lc>>2]=q;c[lc+4>>2]=G}c[k>>2]=1;H=0;i=l;return H|0}return 0}function g9a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[a+60>>2]|0;d=b+180|0;e=d;f=c[e>>2]|0;a:do{if((f|0)!=0){g=b+176|0;if((c[g>>2]|0)>0){h=0;i=f}else{break}while(1){mJb(i+(h*44|0)+4|0);mJb((c[e>>2]|0)+(h*44|0)+8|0);mJb((c[e>>2]|0)+(h*44|0)+32|0);mJb((c[e>>2]|0)+(h*44|0)+36|0);mJb((c[e>>2]|0)+(h*44|0)+40|0);j=h+1|0;if((j|0)>=(c[g>>2]|0)){break a}h=j;i=c[e>>2]|0}}}while(0);mJb(d);d=b+188|0;e=d;i=c[e>>2]|0;b:do{if((i|0)!=0){h=b+184|0;if((c[h>>2]|0)>0){k=0;l=i}else{break}while(1){f=c[l+(k<<5)+12>>2]|0;c:do{if((f|0)==0){m=l}else{if((c[l+(k<<5)+8>>2]|0)>0){n=0;o=f}else{m=l;break}while(1){mJb(o+(n<<4)+12|0);g=n+1|0;j=c[e>>2]|0;if((g|0)>=(c[j+(k<<5)+8>>2]|0)){m=j;break c}n=g;o=c[j+(k<<5)+12>>2]|0}}}while(0);mJb(m+(k<<5)+12|0);mJb((c[e>>2]|0)+(k<<5)+4|0);mJb((c[e>>2]|0)+(k<<5)+28|0);f=k+1|0;if((f|0)>=(c[h>>2]|0)){break b}k=f;l=c[e>>2]|0}}}while(0);mJb(d);d=b+196|0;e=d;l=c[e>>2]|0;d:do{if((l|0)!=0){k=b+192|0;if((c[k>>2]|0)>0){p=0;q=l}else{break}while(1){mJb(q+(p<<5)+24|0);mJb((c[e>>2]|0)+(p<<5)+28|0);m=p+1|0;if((m|0)>=(c[k>>2]|0)){break d}p=m;q=c[e>>2]|0}}}while(0);mJb(d);d=b+204|0;e=d;q=c[e>>2]|0;e:do{if((q|0)!=0){p=b+200|0;if((c[p>>2]|0)>0){r=0;s=q}else{break}while(1){mJb(s+(r*28|0)+4|0);mJb((c[e>>2]|0)+(r*28|0)+8|0);mJb((c[e>>2]|0)+(r*28|0)+12|0);mJb((c[e>>2]|0)+(r*28|0)+20|0);mJb((c[e>>2]|0)+(r*28|0)+24|0);l=r+1|0;if((l|0)>=(c[p>>2]|0)){break e}r=l;s=c[e>>2]|0}}}while(0);mJb(d);mJb(b+212|0);mJb(b+156|0);mJb(b+160|0);mJb(b+164|0);mJb(b+168|0);PPa(b+16|0);PPa(b+80|0);mJb(a+96|0);return 0}function h9a(b,e,f){b=b|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0.0,s=0,t=0.0,u=0.0,v=0,w=0.0,x=0,z=0.0,A=0,B=0,C=0,D=0,E=0,F=0;h=b+36|0;i=c[h>>2]|0;if((i|0)==0){Cd(2118040,2241112,852,2651648);return 0}j=c[b>>2]|0;if((j|0)>0){k=c[b+12>>2]|0;l=c[b+4>>2]|0;m=b+40|0;n=0;o=-1;p=3.4028234663852886e+38;while(1){q=ca(k,n)|0;do{if((a[l+n|0]|0)==0){r=p;s=o}else{t=+g[(c[m>>2]|0)+(n<<2)>>2];if((k|0)>0){u=t;v=0;while(1){w=u- +g[i+(v+q<<2)>>2]*+g[f+(v<<2)>>2];x=v+1|0;if((x|0)<(k|0)){u=w;v=x}else{z=w;break}}}else{z=t}if(!(p>z)){r=p;s=o;break}r=z;s=n}}while(0);q=n+1|0;if((q|0)<(j|0)){n=q;o=s;p=r}else{A=s;B=l;break}}}else{A=-1;B=c[b+4>>2]|0}l=e+4|0;s=c[l>>2]|0;o=e+12|0;n=c[o>>2]|0;j=d[B+A|0]|0;if(((c[e+20>>2]|0)-32+s-(n-(c[e+8>>2]|0)<<3)|0)<(j|0)){C=0;return C|0}B=c[(c[b+8>>2]|0)+(A<<2)>>2]|0;k=e|0;e=B<<32-s|c[k>>2];if((s|0)>(j|0)){D=s;E=e;F=i}else{i=n;y=e;a[i]=y;y=y>>8;a[i+1|0]=y;y=y>>8;a[i+2|0]=y;y=y>>8;a[i+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;D=s+32|0;E=(s|0)==32?0:B>>>(s>>>0);F=c[h>>2]|0}c[k>>2]=E;c[l>>2]=D-j;C=F+((ca(c[b+12>>2]|0,A)|0)<<2)|0;return C|0}function i9a(b,d){b=b|0;d=+d;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=~~+Jqc(+Wc(+d,f|0),20);h=(c[f>>2]|0)+768|0;c[f>>2]=h;f=(g|0)<0?-g|0:g;j=f&65535;k=(h<<21|g&-2147483648|f)>>>16;f=b|0;g=b+4|0;h=c[g>>2]|0;l=j<<32-h|c[f>>2];if((h|0)>16){m=h;n=l}else{o=b+12|0;p=c[o>>2]|0;y=l;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;m=h+32|0;n=j>>>(h>>>0)}h=m-16|0;c[f>>2]=n;c[g>>2]=h;j=k<<48-m|n;if((h|0)>16){q=h;r=j;s=q-16|0;c[f>>2]=r;c[g>>2]=s;i=e;return}n=b+12|0;b=c[n>>2]|0;y=j;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;q=m+16|0;r=k>>>(h>>>0);s=q-16|0;c[f>>2]=r;c[g>>2]=s;i=e;return}function j9a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;i=i+56|0;e=b|0;f=b+24|0;g=b+40|0;h=c[a+60>>2]|0;c[a+140>>2]=0;j=h+4|0;c[j>>2]=1;h=c[a+100>>2]|0;if((h|0)==0){KIb(a,16,2321744,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}if((oib(c[a+96>>2]|0,h,42,f|0,g|0)|0)<0){KIb(a,16,2316712,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1;i=b;return l|0}h=e|0;m=e+12|0;n=e+16|0;o=e+4|0;p=e+8|0;q=a;r=0;while(1){s=g+(r<<2)|0;t=c[s>>2]|0;if((t|0)>=1){u=c[f+(r<<2)>>2]|0;v=t<<3;t=v>>>0>2147483639>>>0|(u|0)==0;w=t?0:u;u=t?0:v;c[h>>2]=w;c[m>>2]=u;v=u+8|0;c[n>>2]=v;c[o>>2]=w+(u>>3);c[p>>2]=0;u=w;w=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=w&255;t=v>>>0>8>>>0?8:v;c[p>>2]=t;if((w&128|0)==0){KIb(q,16,2312152,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;x=c[p>>2]|0;y=c[n>>2]|0}else{x=t;y=v}v=-x|0;t=y-x|0;if((v|0)>48){z=v}else{z=(t|0)<48?t:48}c[p>>2]=z+x;if((u|0)==128){if((o9a(a,e)|0)<0){l=-1;A=20;break}else{A=15}}else if((u|0)==130){if((p9a(a,e)|0)==0){A=15}else{l=-1;A=20;break}}else if((u|0)!=129){KIb(q,16,2307592,(k=i,i=i+8|0,c[k>>2]=w&127,k)|0);i=k;A=15}do{if((A|0)==15){A=0;w=c[s>>2]<<3;t=c[p>>2]|0;if((w|0)==(t|0)){break}KIb(q,24,2301928,(k=i,i=i+16|0,c[k>>2]=w-t,c[k+8>>2]=u,k)|0);i=k}}while(0);if((c[j>>2]|0)<197120){A=19;break}}u=r+1|0;if((u|0)<3){r=u}else{A=19;break}}if((A|0)==19){l=n9a(a)|0;i=b;return l|0}else if((A|0)==20){i=b;return l|0}return 0}function k9a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0;k=i;i=i+616|0;l=k|0;m=k+256|0;n=k+512|0;o=k+528|0;p=k+544|0;q=k+560|0;r=k+592|0;s=c[j+24>>2]|0;t=c[j+28>>2]|0;j=f+60|0;u=c[j>>2]|0;v=u;w=t<<3;x=w>>>0>2147483639>>>0|(s|0)==0;y=x?0:s;s=x?0:w;w=r|0;c[w>>2]=y;x=r+12|0;c[x>>2]=s;z=s+8|0;A=r+16|0;c[A>>2]=z;c[r+4>>2]=y+(s>>3);s=r+8|0;c[s>>2]=0;B=u+4|0;do{if((c[B>>2]|0)==0){C=0}else{D=a[y]|0;E=(z|0)>0;F=E&1;c[s>>2]=F;if(D<<24>>24>-1){C=F;break}D=y;G=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<F>>>25;F=E?8:7;E=z>>>0>F>>>0?F:z;c[s>>2]=E;F=-E|0;D=z-E|0;if((F|0)>48){H=F}else{H=(D|0)<48?D:48}c[s>>2]=H+E;if((c[(c[u>>2]|0)+816>>2]&1|0)!=0){KIb(f,16,2241016,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-1163346256;i=k;return J|0}if((G|0)==0){l9a(f)|0;E=o9a(f,r)|0;if((E|0)<0){l9a(f)|0;J=E;i=k;return J|0}else{J=n9a(f)|0;i=k;return J|0}}else if((G|0)==2){G=p9a(f,r)|0;if((G|0)<0){l9a(f)|0;J=G;i=k;return J|0}else{J=n9a(f)|0;i=k;return J|0}}else{KIb(f,16,2200056,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-1;i=k;return J|0}}}while(0);H=d[y]<<C;c[s>>2]=((C|0)<(z|0))+C;C=u+68|0;c[C>>2]=H>>>7&1^1;H=u+688|0;if((c[H>>2]|0)==0){KIb(f,16,2168280,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;J=-1;i=k;return J|0}if((c[B>>2]|0)==0){z=c[A>>2]|0;G=(c[s>>2]|0)+1|0;c[s>>2]=z>>>0>G>>>0?G:z}z=u+588|0;G=z;E=u+604|0;D=E;c[E>>2]=c[z>>2];c[u+608>>2]=c[u+592>>2];c[u+612>>2]=c[u+596>>2];F=u+600|0;c[F>>2]=0;K=c[s>>2]|0;L=c[A>>2]|0;while(1){M=y+(K>>>3)|0;N=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>26;M=K+6|0;c[s>>2]=L>>>0>M>>>0?M:L;M=c[F>>2]|0;c[F>>2]=M+1;c[G+(M<<2)>>2]=N;if((c[B>>2]|0)<=197119){O=23;break}if((c[F>>2]|0)>=3){break}N=c[s>>2]|0;M=d[y+(N>>>3)|0]|0;P=c[A>>2]|0;Q=((N|0)<(P|0))+N|0;c[s>>2]=Q;if((M&128>>>((N&7)>>>0)|0)==0){O=23;break}else{K=Q;L=P}}do{if((O|0)==23){L=c[F>>2]|0;if((L|0)>=3){break}K=L<<2;mrc(u+(K+588)|0,-1|0,12-K|0)|0}}while(0);K=u;L=c[K>>2]|0;if((c[L+688>>2]&1|0)==0){R=z}else{y=(c[f+428>>2]|0)+1|0;P=z;z=c[P>>2]|0;KIb(L,32,2141552,(I=i,i=i+24|0,c[I>>2]=(c[C>>2]|0)!=0?2118008:10230760,c[I+8>>2]=y,c[I+16>>2]=z,I)|0);i=I;R=P}P=c[R>>2]|0;if((a[u+(P+52892)|0]|0)==0){S=1}else{S=(c[f+848>>2]|0)>=(((c[C>>2]|0)!=0?48:32)|0)|0}z=u+584|0;c[z>>2]=S;S=E;if((P|0)!=(c[S>>2]|0)){E=a[v+52892+P|0]|0;P=E&255;if(!(E<<24>>24>-1)){KIb(0,0,2401920,(I=i,i=i+24|0,c[I>>2]=2395184,c[I+8>>2]=2388032,c[I+16>>2]=407,I)|0);i=I;Hd();return 0}mrc(u+52960|0,0,1024)|0;do{if(E<<24>>24==0){T=P}else{y=0;do{c[v+52960+(127-y<<2)>>2]=-y;c[v+52960+(y+127<<2)>>2]=y;y=y+1|0;}while((y|0)<(P|0));if(!(E<<24>>24>0)){T=P;break}y=-P|0;L=P+1|0;Q=P-(L>>>0>128>>>0?L:128)|0;L=Q>>>0<y>>>0;N=P;M=P;do{c[v+52960+(N+127<<2)>>2]=M;c[v+52960+(127-N<<2)>>2]=-M;N=N+1|0;M=M-1|0;}while((N|0)<128&(M|0)!=0);T=(L?y:Q)+P|0}}while(0);if((T|0)!=0){c[u+53980>>2]=T}T=ca(P,33686018)|0;c[u+53988>>2]=T;c[u+53984>>2]=T}T=c[F>>2]|0;if((T|0)>0){P=0;E=T;while(1){T=c[G+(P<<2)>>2]|0;if((T|0)==(c[D+(P<<2)>>2]|0)){if((c[R>>2]|0)==(c[S>>2]|0)){U=E}else{O=45}}else{O=45}if((O|0)==45){O=0;M=v+588+(P<<2)|0;N=c[v+852+(T<<2)>>2]|0;V=e[v+724+(T<<1)>>1]|0;T=0;do{W=0;do{X=d[v+25684+(T*3|0)+W|0]|0;Y=0;Z=0;while(1){_=v+25690+(T*192|0)+(W<<6)+Z|0;$=a[_]|0;if((Z|0)>=(X|0)){O=49;break}aa=$&255;ba=aa+Y|0;da=Z+1|0;if((c[M>>2]|0)>(ba|0)){Y=ba;Z=da}else{ea=ba;fa=da;ga=aa;break}}if((O|0)==49){O=0;ea=Y;fa=Z+1|0;ga=$&255}X=ea-ga|0;aa=e[v+26074+(T*384|0)+(W<<7)+(Z<<1)>>1]|0;da=e[v+26074+(T*384|0)+(W<<7)+(fa<<1)>>1]|0;ba=0;ha=$;while(1){ia=c[M>>2]|0;ja=ca(ea-ia<<1,d[v+1108+(aa<<6)+ba|0]|0)|0;ka=ha&255;la=(ja-(ca(X-ia<<1,d[v+1108+(da<<6)+ba|0]|0)|0)+ka|0)/(ka<<1|0)|0;ka=(ba|0)!=0;ia=8<<(ka&1^1)+T;ja=((ca(la,ka?N:V)|0)/100|0)<<2;if((ja|0)<(ia|0)){ma=ia&65535}else{ma=(ja|0)>4096?4096:ja&65535}b[v+30080+(P*768|0)+(T*384|0)+(W<<7)+(d[v+72+ba|0]<<1)>>1]=ma;ja=ba+1|0;if((ja|0)>=64){break}ba=ja;ha=a[_]|0}b[v+30080+(P*768|0)+(T*384|0)+(W<<7)>>1]=b[v+30080+(T*384|0)+(W<<7)>>1]|0;W=W+1|0;}while((W|0)<3);T=T+1|0;}while((T|0)<2);U=c[F>>2]|0}T=P+1|0;if((T|0)<(U|0)){P=T;E=U}else{break}}}U=c[C>>2]|0;if((c[f+856>>2]|0)>31&(U|0)==0){J=t;i=k;return J|0}E=u+56|0;P=E;_=E;E=c[_>>2]|0;c[E+88>>2]=(U|0)!=0?1:2;c[E+84>>2]=U;a:do{if((J5a(f,P,1)|0)>=0){U=u+32392|0;if((c[U>>2]|0)==0){E=c[(c[_>>2]|0)+32>>2]|0;c[U>>2]=hJb(((E|0)>-1?E:-E|0)*9|0)|0}do{if((c[C>>2]|0)==0){E=u+32|0;ma=E;ea=E;if((c[c[ea>>2]>>2]|0)!=0){break}KIb(c[K>>2]|0,24,2565056,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;c[(c[ea>>2]|0)+88>>2]=1;if((J5a(f,ma,1)|0)<0){break a}ea=u+44|0;H5a(f,ea);if((G5a(ea,ma)|0)<0){break a}L5a(ea,2147483647,0)}else{do{if((c[B>>2]|0)==0){ea=c[A>>2]|0;ma=(c[s>>2]|0)+4|0;E=(ea>>>0>ma>>>0?ma:ea)+4|0;ma=ea>>>0>E>>>0?E:ea;c[s>>2]=ma;E=u+12|0;if((c[E>>2]|0)==0){na=E;break}$=(c[w>>2]|0)+(ma>>>3)|0;fa=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ma&7)>>>27;$=ma+5|0;c[s>>2]=ea>>>0>$>>>0?$:ea;c[E>>2]=fa;if((c[f+428>>2]|0)!=0){na=E;break}KIb(c[K>>2]|0,48,2612616,(I=i,i=i+8|0,c[I>>2]=fa,I)|0);i=I;na=E}else{na=u+12|0}}while(0);if((c[na>>2]|0)==0){if((c[B>>2]|0)==0){break}}E=c[s>>2]|0;fa=d[(c[w>>2]|0)+(E>>>3)|0]|0;ea=c[A>>2]|0;$=((E|0)<(ea|0))+E|0;c[s>>2]=$;if((fa&128>>>((E&7)>>>0)|0)==0){oa=$;pa=ea}else{KIb(c[K>>2]|0,16,2585920,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;oa=c[s>>2]|0;pa=c[A>>2]|0}ea=oa+2|0;c[s>>2]=pa>>>0>ea>>>0?ea:pa}}while(0);ea=u+668|0;mrc(c[H>>2]|0,0,c[ea>>2]<<2|0)|0;K5a(f);c[p>>2]=0;c[p+4>>2]=c[u+644>>2];c[p+8>>2]=c[u+648>>2];b:do{if((c[C>>2]|0)==0){$=c[s>>2]|0;E=d[(c[w>>2]|0)+($>>>3)|0]<<($&7)>>>7;fa=(($|0)<(c[A>>2]|0))+$|0;c[s>>2]=fa;$=E&1^1;E=u+616|0;ma=c[E>>2]|0;c:do{if((ma|0)>0){ga=u+30004|0;S=u+652|0;if(((c[x>>2]|0)-fa|0)>0){qa=fa;ra=$;sa=0;ta=0;ua=0}else{va=0;wa=0;xa=$;ya=ma;O=94;break}while(1){if((c[B>>2]|0)!=0&(ua|0)==4129){R=c[w>>2]|0;D=d[R+(qa>>>3)|0]<<(qa&7)>>>7;G=c[A>>2]|0;T=((qa|0)<(G|0))+qa|0;c[s>>2]=T;za=D&1;Aa=T;Ba=G;Ca=R}else{za=ra^1;Aa=qa;Ba=c[A>>2]|0;Ca=c[w>>2]|0}R=c[ga>>2]|0;G=Ca+(Aa>>>3)|0;T=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(Aa&7)>>>26;G=b[R+(T<<2)>>1]|0;D=b[R+(T<<2)+2>>1]|0;T=D<<16>>16;if(D<<16>>16<0){D=Aa+6|0;V=Ba>>>0>D>>>0?D:Ba;D=Ca+(V>>>3)|0;N=((je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(V&7)>>>((T+32|0)>>>0))+G|0;Da=b[R+(N<<2)+2>>1]|0;Ea=b[R+(N<<2)>>1]|0;Fa=V}else{Da=T;Ea=G;Fa=Aa}G=Da+Fa|0;T=Ba>>>0>G>>>0?G:Ba;c[s>>2]=T;G=Ea+1|0;if((G|0)==34){V=Ca+(T>>>3)|0;N=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>20;V=T+12|0;c[s>>2]=Ba>>>0>V>>>0?V:Ba;Ga=N+34|0}else{Ga=G}G=Ga+sa|0;if((G|0)>(c[E>>2]|0)){break}mrc((c[S>>2]|0)+sa|0,za&255|0,Ga|0)|0;N=((za|0)==0?0:Ga)+ta|0;V=c[E>>2]|0;if((G|0)>=(V|0)){va=Ga;wa=N;xa=za;ya=V;O=94;break c}T=c[s>>2]|0;if(((c[x>>2]|0)-T|0)>0){qa=T;ra=za;sa=G;ta=N;ua=Ga}else{va=Ga;wa=N;xa=za;ya=V;O=94;break c}}KIb(c[K>>2]|0,16,2418592,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}else{va=0;wa=0;xa=$;ya=ma;O=94}}while(0);d:do{if((O|0)==94){e:do{if((wa|0)<(ya|0)){ma=c[s>>2]|0;$=d[(c[w>>2]|0)+(ma>>>3)|0]<<(ma&7)>>>7;fa=((ma|0)<(c[A>>2]|0))+ma|0;c[s>>2]=fa;ma=$&1^1;if(((c[E>>2]|0)-wa|0)<=0){Ha=ma;Ia=0;break}$=u+30004|0;S=u+652|0;if(((c[x>>2]|0)-fa|0)>0){Ja=fa;Ka=ma;La=0;Ma=0;Na=0}else{Ha=ma;Ia=0;break}f:while(1){if((c[B>>2]|0)!=0&(Na|0)==4129){ma=c[w>>2]|0;fa=d[ma+(Ja>>>3)|0]<<(Ja&7)>>>7;ga=c[A>>2]|0;V=((Ja|0)<(ga|0))+Ja|0;c[s>>2]=V;Oa=fa&1;Pa=V;Qa=ga;Ra=ma}else{Oa=Ka^1;Pa=Ja;Qa=c[A>>2]|0;Ra=c[w>>2]|0}ma=c[$>>2]|0;ga=Ra+(Pa>>>3)|0;V=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(Pa&7)>>>26;ga=b[ma+(V<<2)>>1]|0;fa=b[ma+(V<<2)+2>>1]|0;V=fa<<16>>16;if(fa<<16>>16<0){fa=Pa+6|0;N=Qa>>>0>fa>>>0?fa:Qa;fa=Ra+(N>>>3)|0;G=((je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(N&7)>>>((V+32|0)>>>0))+ga|0;Sa=b[ma+(G<<2)+2>>1]|0;Ta=b[ma+(G<<2)>>1]|0;Ua=N}else{Sa=V;Ta=ga;Ua=Pa}ga=Sa+Ua|0;V=Qa>>>0>ga>>>0?ga:Qa;c[s>>2]=V;ga=Ta+1|0;if((ga|0)==34){N=Ra+(V>>>3)|0;G=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(V&7)>>>20;N=V+12|0;c[s>>2]=Qa>>>0>N>>>0?N:Qa;Va=G+34|0}else{Va=ga}if((Va|0)>0){ga=Oa<<1&255;G=0;N=Ma;while(1){if((N|0)>=(c[E>>2]|0)){break f}V=(c[S>>2]|0)+N|0;if((a[V]|0)==0){a[V]=ga;Wa=G+1|0}else{Wa=G}V=N+1|0;if((Wa|0)<(Va|0)){G=Wa;N=V}else{Xa=V;break}}}else{Xa=Ma}N=Va+La|0;if((N|0)>=((c[E>>2]|0)-wa|0)){Ha=Oa;Ia=Va;break e}G=c[s>>2]|0;if(((c[x>>2]|0)-G|0)>0){Ja=G;Ka=Oa;La=N;Ma=Xa;Na=Va}else{Ha=Oa;Ia=Va;break e}}KIb(c[K>>2]|0,16,2409664,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break d}else{Ha=xa;Ia=va}}while(0);if((wa|0)==0){Ya=Ha;Za=Ia;break b}S=c[s>>2]|0;$=d[(c[w>>2]|0)+(S>>>3)|0]<<(S&7)>>>7;c[s>>2]=((S|0)<(c[A>>2]|0))+S;Ya=$&1^1;Za=0;break b}}while(0);KIb(c[K>>2]|0,16,2546944,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break a}else{mrc(c[u+652>>2]|0,2,c[u+616>>2]|0)|0;Ya=0;Za=0}}while(0);E=u+28384|0;c[E>>2]=0;$=u+32388|0;mrc(c[$>>2]|0,8,c[u+656>>2]|0)|0;S=u+640|0;N=u+628|0;G=u+32384|0;ga=u+652|0;V=u+30024|0;ma=Za;fa=0;T=Ya;R=0;while(1){D=c[((fa|0)==0?N:S)>>2]|0;M=D+R|0;g:do{if((D|0)>0){Q=v+28388+(fa<<2)|0;y=ma;L=R;W=T;ha=0;while(1){if(((c[x>>2]|0)-(c[s>>2]|0)|0)<=0){_a=y;$a=W;ab=ha;break g}ba=L<<4;da=y;X=0;aa=W;Z=ha;while(1){Y=c[(c[G>>2]|0)+(X+ba<<2)>>2]|0;do{if((Y|0)==-1){bb=Z;cb=aa;db=da}else{ja=a[(c[ga>>2]|0)+L|0]|0;ia=ja&255;do{if(ja<<24>>24==1){if((da|0)!=0){eb=aa;fb=aa;gb=da-1|0;break}ka=aa^1;la=c[V>>2]|0;hb=c[s>>2]|0;ib=c[A>>2]|0;jb=c[w>>2]|0;kb=jb+(hb>>>3)|0;lb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(hb&7)>>>27;kb=b[la+(lb<<2)>>1]|0;mb=b[la+(lb<<2)+2>>1]|0;lb=mb<<16>>16;if(mb<<16>>16<0){mb=hb+5|0;nb=ib>>>0>mb>>>0?mb:ib;mb=jb+(nb>>>3)|0;jb=((je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(nb&7)>>>((lb+32|0)>>>0))+kb|0;ob=b[la+(jb<<2)+2>>1]|0;pb=b[la+(jb<<2)>>1]|0;qb=nb}else{ob=lb;pb=kb;qb=hb}hb=ob+qb|0;c[s>>2]=ib>>>0>hb>>>0?hb:ib;eb=ka;fb=ka;gb=pb}else{eb=ia;fb=aa;gb=da}}while(0);ia=(c[H>>2]|0)+(Y<<2)+2|0;if((eb|0)==0){a[ia]=8;bb=Z;cb=fb;db=gb;break}else{a[ia]=0;c[(c[Q>>2]|0)+(Z<<2)>>2]=Y;bb=Z+1|0;cb=fb;db=gb;break}}}while(0);Y=X+1|0;if((Y|0)<16){da=db;X=Y;aa=cb;Z=bb}else{break}}Z=L+1|0;if((Z|0)<(M|0)){y=db;L=Z;W=cb;ha=bb}else{_a=db;$a=cb;ab=bb;break}}}else{_a=ma;$a=T;ab=0}}while(0);c[E>>2]=(c[E>>2]|0)+ab;M=0;do{c[v+27616+(fa<<8)+(M<<2)>>2]=ab;M=M+1|0;}while((M|0)<64);if((fa|0)<2){M=fa+1|0;c[v+28388+(M<<2)>>2]=(c[v+28388+(fa<<2)>>2]|0)+(ab<<2);rb=M}else{rb=fa+1|0}if((rb|0)>=3){break}ma=_a;fa=rb;T=$a;R=c[p+(rb<<2)>>2]|0}R=q;h:do{if((c[C>>2]|0)==0){T=c[s>>2]|0;fa=c[A>>2]|0;ma=c[w>>2]|0;V=ma+(T>>>3)|0;ga=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;if((ga|0)==0){mrc(R|0,0,32)|0;V=ma+(T>>>3)|0;G=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;c[q+(G<<2)>>2]=0;G=ma+(T>>>3)|0;V=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(T&7)>>>29;G=T+3|0;T=fa>>>0>G>>>0?G:fa;c[s>>2]=T;c[q+(V<<2)>>2]=1;V=ma+(T>>>3)|0;G=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;c[q+(G<<2)>>2]=2;G=ma+(T>>>3)|0;V=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(T&7)>>>29;G=T+3|0;T=fa>>>0>G>>>0?G:fa;c[s>>2]=T;c[q+(V<<2)>>2]=3;V=ma+(T>>>3)|0;G=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;c[q+(G<<2)>>2]=4;G=ma+(T>>>3)|0;V=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(T&7)>>>29;G=T+3|0;T=fa>>>0>G>>>0?G:fa;c[s>>2]=T;c[q+(V<<2)>>2]=5;V=ma+(T>>>3)|0;G=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(T&7)>>>29;V=T+3|0;T=fa>>>0>V>>>0?V:fa;c[s>>2]=T;c[q+(G<<2)>>2]=6;G=ma+(T>>>3)|0;ma=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(T&7)>>>29;G=T+3|0;c[s>>2]=fa>>>0>G>>>0?G:fa;c[q+(ma<<2)>>2]=7;sb=q|0}else{sb=2656864+(ga-1<<5)|0}ma=u+624|0;fa=c[ma>>2]|0;if((fa|0)<=0){break}G=u+620|0;T=u+660|0;V=u+664|0;S=u+672|0;N=(ga|0)==7;ga=u+28|0;M=u+24|0;D=u+676|0;ha=u+696|0;W=u+700|0;L=u+30044|0;y=0;Q=c[G>>2]|0;Z=fa;i:while(1){if((Q|0)>0){fa=y<<1;aa=0;do{if(((c[x>>2]|0)-(c[s>>2]|0)|0)<1){break i}X=aa<<1;da=0;do{ba=da>>1;Y=ba+X|0;ia=ba+da&1|fa;ba=c[T>>2]|0;ja=(ca(ia,ba)|0)+Y|0;do{if((Y|0)<(ba|0)){if((ia|0)>=(c[V>>2]|0)){break}ka=ia<<1;ib=Y<<1;hb=0;while(1){if((hb|0)>=4){break}kb=(ca(c[S>>2]|0,(hb>>1)+ka|0)|0)+(hb&1|ib)|0;if((a[(c[H>>2]|0)+(kb<<2)+2|0]|0)==8){hb=hb+1|0}else{break}}if((hb|0)==4){a[(c[$>>2]|0)+ja|0]=0;break}if(N){kb=c[s>>2]|0;lb=c[A>>2]|0;nb=(c[w>>2]|0)+(kb>>>3)|0;jb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(kb&7)>>>29;nb=kb+3|0;c[s>>2]=lb>>>0>nb>>>0?nb:lb;tb=jb&255}else{jb=c[L>>2]|0;lb=c[s>>2]|0;nb=c[A>>2]|0;kb=c[w>>2]|0;la=kb+(lb>>>3)|0;mb=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(lb&7)>>>29;la=b[jb+(mb<<2)>>1]|0;ub=b[jb+(mb<<2)+2>>1]|0;mb=ub<<16>>16;do{if(ub<<16>>16<0){vb=lb+3|0;wb=nb>>>0>vb>>>0?vb:nb;vb=kb+(wb>>>3)|0;xb=((je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(wb&7)>>>((mb+32|0)>>>0))+la|0;vb=b[jb+(xb<<2)>>1]|0;yb=b[jb+(xb<<2)+2>>1]|0;xb=yb<<16>>16;if(!(yb<<16>>16<0)){zb=xb;Ab=vb;Bb=wb;break}yb=wb-mb|0;wb=nb>>>0>yb>>>0?yb:nb;yb=kb+(wb>>>3)|0;Cb=((je(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(wb&7)>>>((xb+32|0)>>>0))+vb|0;zb=b[jb+(Cb<<2)+2>>1]|0;Ab=b[jb+(Cb<<2)>>1]|0;Bb=wb}else{zb=mb;Ab=la;Bb=lb}}while(0);lb=zb+Bb|0;c[s>>2]=nb>>>0>lb>>>0?lb:nb;tb=c[sb+(Ab<<2)>>2]&255}a[(c[$>>2]|0)+ja|0]=tb;lb=c[H>>2]|0;la=c[S>>2]|0;mb=lb+((ca(la,ka)|0)+ib<<2)+2|0;if((a[mb]|0)==8){Db=lb;Eb=la}else{a[mb]=tb;Db=c[H>>2]|0;Eb=c[S>>2]|0}mb=ib|1;la=Db+((ca(Eb,ka)|0)+mb<<2)+2|0;if((a[la]|0)==8){Fb=Db;Gb=Eb}else{a[la]=tb;Fb=c[H>>2]|0;Gb=c[S>>2]|0}la=ka|1;lb=Fb+((ca(Gb,la)|0)+ib<<2)+2|0;if((a[lb]|0)==8){Hb=Fb;Ib=Gb}else{a[lb]=tb;Hb=c[H>>2]|0;Ib=c[S>>2]|0}lb=Hb+((ca(Ib,la)|0)+mb<<2)+2|0;if((a[lb]|0)!=8){a[lb]=tb}if((c[ga>>2]|0)!=0){lb=c[H>>2]|0;jb=(ca(c[D>>2]|0,ia)|0)+Y|0;kb=lb+(jb+(c[ha>>2]|0)<<2)+2|0;if((a[kb]|0)!=8){a[kb]=tb}kb=lb+((c[W>>2]|0)+jb<<2)+2|0;if((a[kb]|0)==8){break}a[kb]=tb;break}kb=c[H>>2]|0;jb=ca(c[D>>2]|0,ka)|0;if((c[M>>2]|0)!=0){lb=jb+Y|0;ub=kb+((c[ha>>2]|0)+lb<<2)+2|0;if((a[ub]|0)!=8){a[ub]=tb}ub=kb+((c[W>>2]|0)+lb<<2)+2|0;if((a[ub]|0)!=8){a[ub]=tb}ub=(c[D>>2]|0)+lb|0;lb=kb+(ub+(c[ha>>2]|0)<<2)+2|0;if((a[lb]|0)!=8){a[lb]=tb}lb=kb+((c[W>>2]|0)+ub<<2)+2|0;if((a[lb]|0)==8){break}a[lb]=tb;break}lb=jb+ib|0;jb=kb+((c[ha>>2]|0)+lb<<2)+2|0;if((a[jb]|0)!=8){a[jb]=tb}jb=kb+((c[W>>2]|0)+lb<<2)+2|0;if((a[jb]|0)!=8){a[jb]=tb}jb=c[H>>2]|0;lb=(ca(c[D>>2]|0,ka)|0)+mb|0;kb=jb+(lb+(c[ha>>2]|0)<<2)+2|0;if((a[kb]|0)!=8){a[kb]=tb}kb=jb+((c[W>>2]|0)+lb<<2)+2|0;if((a[kb]|0)!=8){a[kb]=tb}kb=c[H>>2]|0;lb=(ca(c[D>>2]|0,la)|0)+ib|0;jb=kb+(lb+(c[ha>>2]|0)<<2)+2|0;if((a[jb]|0)!=8){a[jb]=tb}jb=kb+((c[W>>2]|0)+lb<<2)+2|0;if((a[jb]|0)!=8){a[jb]=tb}jb=c[H>>2]|0;lb=(ca(c[D>>2]|0,la)|0)+mb|0;mb=jb+(lb+(c[ha>>2]|0)<<2)+2|0;if((a[mb]|0)!=8){a[mb]=tb}mb=jb+((c[W>>2]|0)+lb<<2)+2|0;if((a[mb]|0)==8){break}a[mb]=tb}}while(0);da=da+1|0;}while((da|0)<4);aa=aa+1|0;Jb=c[G>>2]|0;}while((aa|0)<(Jb|0));Kb=Jb;Lb=c[ma>>2]|0}else{Kb=Q;Lb=Z}aa=y+1|0;if((aa|0)<(Lb|0)){y=aa;Q=Kb;Z=Lb}else{break h}}KIb(c[K>>2]|0,16,2529296,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break a}else{if((c[ea>>2]|0)>0){Mb=0}else{break}do{a[(c[H>>2]|0)+(Mb<<2)+2|0]=1;Mb=Mb+1|0;}while((Mb|0)<(c[ea>>2]|0))}}while(0);j:do{if((c[C>>2]|0)==0){ea=c[s>>2]|0;R=a[(c[w>>2]|0)+(ea>>>3)|0]|0;c[s>>2]=((ea|0)<(c[A>>2]|0))+ea;Z=u+624|0;Q=c[Z>>2]|0;if((Q|0)<=0){break}y=u+620|0;ma=u+660|0;G=u+664|0;W=n|0;ha=o|0;D=u+672|0;M=u+716|0;ga=u+28|0;S=u+24|0;L=n+4|0;N=o+4|0;V=n+8|0;T=n+12|0;aa=o+8|0;fa=o+12|0;da=u+676|0;X=u+720|0;Y=(R&255&128>>>((ea&7)>>>0)|0)==0;ea=u+30064|0;R=0;ia=0;ja=0;ba=0;mb=0;lb=c[y>>2]|0;jb=Q;k:while(1){if((lb|0)>0){Q=R<<1;la=0;kb=ia;ub=ja;hb=ba;wb=mb;while(1){if(((c[x>>2]|0)-(c[s>>2]|0)|0)<1){break k}Cb=la<<1;vb=kb;xb=ub;yb=hb;Nb=wb;Ob=0;while(1){Pb=Ob>>1;Qb=Pb+Cb|0;Rb=Pb+Ob&1|Q;Pb=c[ma>>2]|0;Sb=(ca(Pb,Rb)|0)+Qb|0;do{if((Qb|0)<(Pb|0)){if((Rb|0)>=(c[G>>2]|0)){Tb=Nb;Ub=yb;Vb=xb;Wb=vb;break}Xb=c[$>>2]|0;Yb=Xb+Sb|0;Zb=a[Yb]|0;if(Zb<<24>>24==8){Tb=Nb;Ub=yb;Vb=xb;Wb=vb;break}switch(Zb&255|0){case 3:{c[W>>2]=vb;c[ha>>2]=xb;_b=Nb;$b=yb;ac=xb;bc=vb;cc=vb;dc=xb;break};case 4:{c[W>>2]=yb;c[ha>>2]=Nb;_b=xb;$b=vb;ac=Nb;bc=yb;cc=yb;dc=Nb;break};case 7:{Zb=Rb<<1;ec=Qb<<1;fc=c[H>>2]|0;gc=vb;hc=xb;ic=0;while(1){do{if((a[fc+((ca(c[D>>2]|0,(ic>>1)+Zb|0)|0)+(ic&1|ec)<<2)+2|0]|0)==8){c[n+(ic<<2)>>2]=0;c[o+(ic<<2)>>2]=0;jc=hc;kc=gc}else{if(!Y){lc=c[s>>2]|0;mc=c[A>>2]|0;nc=c[w>>2]|0;oc=nc+(lc>>>3)|0;pc=(je(d[oc]|d[oc+1|0]<<8|d[oc+2|0]<<16|d[oc+3|0]<<24|0)|0)<<(lc&7)>>>26;oc=lc+6|0;lc=mc>>>0>oc>>>0?oc:mc;c[s>>2]=lc;oc=a[1215352+pc|0]|0;c[n+(ic<<2)>>2]=oc;pc=nc+(lc>>>3)|0;nc=(je(d[pc]|d[pc+1|0]<<8|d[pc+2|0]<<16|d[pc+3|0]<<24|0)|0)<<(lc&7)>>>26;pc=lc+6|0;c[s>>2]=mc>>>0>pc>>>0?pc:mc;mc=a[1215352+nc|0]|0;c[o+(ic<<2)>>2]=mc;jc=mc;kc=oc;break}oc=c[ea>>2]|0;mc=c[s>>2]|0;nc=c[A>>2]|0;pc=c[w>>2]|0;lc=pc+(mc>>>3)|0;qc=(je(d[lc]|d[lc+1|0]<<8|d[lc+2|0]<<16|d[lc+3|0]<<24|0)|0)<<(mc&7)>>>26;lc=b[oc+(qc<<2)>>1]|0;rc=b[oc+(qc<<2)+2>>1]|0;qc=rc<<16>>16;if(rc<<16>>16<0){rc=mc+6|0;sc=nc>>>0>rc>>>0?rc:nc;rc=pc+(sc>>>3)|0;tc=((je(d[rc]|d[rc+1|0]<<8|d[rc+2|0]<<16|d[rc+3|0]<<24|0)|0)<<(sc&7)>>>((qc+32|0)>>>0))+lc|0;uc=b[oc+(tc<<2)+2>>1]|0;vc=b[oc+(tc<<2)>>1]|0;wc=sc}else{uc=qc;vc=lc;wc=mc}mc=uc+wc|0;lc=nc>>>0>mc>>>0?mc:nc;c[s>>2]=lc;mc=c[826944+(vc<<2)>>2]|0;c[n+(ic<<2)>>2]=mc;qc=pc+(lc>>>3)|0;sc=(je(d[qc]|d[qc+1|0]<<8|d[qc+2|0]<<16|d[qc+3|0]<<24|0)|0)<<(lc&7)>>>26;qc=b[oc+(sc<<2)>>1]|0;tc=b[oc+(sc<<2)+2>>1]|0;sc=tc<<16>>16;if(tc<<16>>16<0){tc=lc+6|0;rc=nc>>>0>tc>>>0?tc:nc;tc=pc+(rc>>>3)|0;pc=((je(d[tc]|d[tc+1|0]<<8|d[tc+2|0]<<16|d[tc+3|0]<<24|0)|0)<<(rc&7)>>>((sc+32|0)>>>0))+qc|0;xc=b[oc+(pc<<2)+2>>1]|0;yc=b[oc+(pc<<2)>>1]|0;zc=rc}else{xc=sc;yc=qc;zc=lc}lc=xc+zc|0;c[s>>2]=nc>>>0>lc>>>0?lc:nc;nc=c[826944+(yc<<2)>>2]|0;c[o+(ic<<2)>>2]=nc;jc=nc;kc=mc}}while(0);mc=ic+1|0;if((mc|0)<4){gc=kc;hc=jc;ic=mc}else{break}}_b=xb;$b=vb;ac=jc;bc=kc;cc=c[W>>2]|0;dc=c[ha>>2]|0;break};case 2:case 6:{if(Y){ic=c[ea>>2]|0;hc=c[s>>2]|0;gc=c[A>>2]|0;ec=c[w>>2]|0;Zb=ec+(hc>>>3)|0;fc=(je(d[Zb]|d[Zb+1|0]<<8|d[Zb+2|0]<<16|d[Zb+3|0]<<24|0)|0)<<(hc&7)>>>26;Zb=b[ic+(fc<<2)>>1]|0;ib=b[ic+(fc<<2)+2>>1]|0;fc=ib<<16>>16;if(ib<<16>>16<0){ib=hc+6|0;ka=gc>>>0>ib>>>0?ib:gc;ib=ec+(ka>>>3)|0;nb=((je(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(ka&7)>>>((fc+32|0)>>>0))+Zb|0;Ac=b[ic+(nb<<2)+2>>1]|0;Bc=b[ic+(nb<<2)>>1]|0;Cc=ka}else{Ac=fc;Bc=Zb;Cc=hc}hc=Ac+Cc|0;Zb=gc>>>0>hc>>>0?hc:gc;c[s>>2]=Zb;hc=c[826944+(Bc<<2)>>2]|0;c[W>>2]=hc;fc=ec+(Zb>>>3)|0;ka=(je(d[fc]|d[fc+1|0]<<8|d[fc+2|0]<<16|d[fc+3|0]<<24|0)|0)<<(Zb&7)>>>26;fc=b[ic+(ka<<2)>>1]|0;nb=b[ic+(ka<<2)+2>>1]|0;ka=nb<<16>>16;if(nb<<16>>16<0){nb=Zb+6|0;ib=gc>>>0>nb>>>0?nb:gc;nb=ec+(ib>>>3)|0;ec=((je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(ib&7)>>>((ka+32|0)>>>0))+fc|0;Dc=b[ic+(ec<<2)+2>>1]|0;Ec=b[ic+(ec<<2)>>1]|0;Fc=ib}else{Dc=ka;Ec=fc;Fc=Zb}Zb=Dc+Fc|0;c[s>>2]=gc>>>0>Zb>>>0?Zb:gc;Gc=hc;Hc=c[826944+(Ec<<2)>>2]|0}else{hc=c[s>>2]|0;gc=c[A>>2]|0;Zb=c[w>>2]|0;fc=Zb+(hc>>>3)|0;ka=(je(d[fc]|d[fc+1|0]<<8|d[fc+2|0]<<16|d[fc+3|0]<<24|0)|0)<<(hc&7)>>>26;fc=hc+6|0;hc=gc>>>0>fc>>>0?fc:gc;c[s>>2]=hc;fc=a[1215352+ka|0]|0;c[W>>2]=fc;ka=Zb+(hc>>>3)|0;Zb=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(hc&7)>>>26;ka=hc+6|0;c[s>>2]=gc>>>0>ka>>>0?ka:gc;Gc=fc;Hc=a[1215352+Zb|0]|0}c[ha>>2]=Hc;Zb=(a[Yb]|0)==2;_b=Zb?xb:Nb;$b=Zb?vb:yb;ac=Zb?Hc:xb;bc=Zb?Gc:vb;cc=Gc;dc=Hc;break};default:{c[W>>2]=0;c[ha>>2]=0;_b=Nb;$b=yb;ac=xb;bc=vb;cc=0;dc=0}}Zb=Rb<<1;fc=Qb<<1;gc=cc&255;ka=dc&255;hc=0;ib=Xb;while(1){ec=(ca((hc>>1)+Zb|0,c[D>>2]|0)|0)+(hc&1|fc)|0;if((a[ib+Sb|0]|0)==7){a[(c[M>>2]|0)+(ec<<1)|0]=c[n+(hc<<2)>>2];a[(c[M>>2]|0)+(ec<<1)+1|0]=c[o+(hc<<2)>>2]}else{a[(c[M>>2]|0)+(ec<<1)|0]=gc;a[(c[M>>2]|0)+(ec<<1)+1|0]=ka}ec=hc+1|0;if((ec|0)>=4){break}hc=ec;ib=c[$>>2]|0}if((c[ga>>2]|0)!=0){if((a[(c[$>>2]|0)+Sb|0]|0)==7){ib=(c[L>>2]|0)+cc+(c[V>>2]|0)+(c[T>>2]|0)|0;hc=((ib|0)>0?2:1)+ib>>2;c[W>>2]=hc;ib=(c[N>>2]|0)+dc+(c[aa>>2]|0)+(c[fa>>2]|0)|0;Xb=((ib|0)>0?2:1)+ib>>2;c[ha>>2]=Xb;Ic=hc;Jc=Xb}else{Ic=cc;Jc=dc}Xb=Ic>>1|Ic&1;c[W>>2]=Xb;hc=Jc>>1|Jc&1;c[ha>>2]=hc;ib=(ca(c[da>>2]|0,Rb)|0)+Qb|0;a[(c[X>>2]|0)+(ib<<1)|0]=Xb;a[(c[X>>2]|0)+(ib<<1)+1|0]=hc;Tb=_b;Ub=$b;Vb=ac;Wb=bc;break}if((c[S>>2]|0)!=0){if((a[(c[$>>2]|0)+Sb|0]|0)==7){hc=(c[L>>2]|0)+cc|0;ib=((hc|0)>0)+hc>>1;c[W>>2]=ib;hc=(c[N>>2]|0)+dc|0;Xb=((hc|0)>0)+hc>>1;c[ha>>2]=Xb;hc=(c[T>>2]|0)+(c[V>>2]|0)|0;Yb=((hc|0)>0)+hc>>1;c[L>>2]=Yb;hc=(c[fa>>2]|0)+(c[aa>>2]|0)|0;ec=((hc|0)>0)+hc>>1;Kc=ib;Lc=Yb;Mc=ec&255;Nc=ec;Oc=Xb&255}else{c[L>>2]=cc;Kc=cc;Lc=cc;Mc=ka;Nc=dc;Oc=ka}c[N>>2]=Nc;Xb=Kc>>1|Kc&1;c[W>>2]=Xb;ec=Lc>>1|Lc&1;c[L>>2]=ec;Yb=(ca(c[da>>2]|0,Zb)|0)+Qb|0;a[(c[X>>2]|0)+(Yb<<1)|0]=Xb;a[(c[X>>2]|0)+(Yb<<1)+1|0]=Oc;Xb=(c[da>>2]|0)+Yb|0;a[(c[X>>2]|0)+(Xb<<1)|0]=ec;a[(c[X>>2]|0)+(Xb<<1)+1|0]=Mc;Tb=_b;Ub=$b;Vb=ac;Wb=bc;break}Xb=(ca(Zb,c[da>>2]|0)|0)+fc|0;a[(c[X>>2]|0)+(Xb<<1)|0]=gc;a[(c[X>>2]|0)+(Xb<<1)+1|0]=ka;Xb=fc|1;ec=(ca(Zb,c[da>>2]|0)|0)+Xb|0;if((a[(c[$>>2]|0)+Sb|0]|0)==7){a[(c[X>>2]|0)+(ec<<1)|0]=c[L>>2];a[(c[X>>2]|0)+(ec<<1)+1|0]=c[N>>2]}else{a[(c[X>>2]|0)+(ec<<1)|0]=gc;a[(c[X>>2]|0)+(ec<<1)+1|0]=ka}ec=Zb|1;Yb=(ca(ec,c[da>>2]|0)|0)+fc|0;if((a[(c[$>>2]|0)+Sb|0]|0)==7){a[(c[X>>2]|0)+(Yb<<1)|0]=c[V>>2];a[(c[X>>2]|0)+(Yb<<1)+1|0]=c[aa>>2]}else{a[(c[X>>2]|0)+(Yb<<1)|0]=gc;a[(c[X>>2]|0)+(Yb<<1)+1|0]=ka}Yb=(ca(ec,c[da>>2]|0)|0)+Xb|0;if((a[(c[$>>2]|0)+Sb|0]|0)==7){a[(c[X>>2]|0)+(Yb<<1)|0]=c[T>>2];a[(c[X>>2]|0)+(Yb<<1)+1|0]=c[fa>>2];Tb=_b;Ub=$b;Vb=ac;Wb=bc;break}else{a[(c[X>>2]|0)+(Yb<<1)|0]=gc;a[(c[X>>2]|0)+(Yb<<1)+1|0]=ka;Tb=_b;Ub=$b;Vb=ac;Wb=bc;break}}else{Tb=Nb;Ub=yb;Vb=xb;Wb=vb}}while(0);Sb=Ob+1|0;if((Sb|0)<4){vb=Wb;xb=Vb;yb=Ub;Nb=Tb;Ob=Sb}else{break}}Ob=la+1|0;Pc=c[y>>2]|0;if((Ob|0)<(Pc|0)){la=Ob;kb=Wb;ub=Vb;hb=Ub;wb=Tb}else{break}}Qc=Wb;Rc=Vb;Sc=Ub;Tc=Tb;Uc=Pc;Vc=c[Z>>2]|0}else{Qc=ia;Rc=ja;Sc=ba;Tc=mb;Uc=lb;Vc=jb}wb=R+1|0;if((wb|0)<(Vc|0)){R=wb;ia=Qc;ja=Rc;ba=Sc;mb=Tc;lb=Uc;jb=Vc}else{break j}}KIb(c[K>>2]|0,16,2514056,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break a}}while(0);$=c[E>>2]|0;l:do{if(((c[F>>2]|0)-1|0)>0&($|0)>0){jb=u+30004|0;lb=u+28388|0;mb=0;ba=$;m:while(1){ja=c[s>>2]|0;ia=d[(c[w>>2]|0)+(ja>>>3)|0]<<(ja&7)>>>7;R=((ja|0)<(c[A>>2]|0))+ja|0;c[s>>2]=R;ja=0;Z=0;y=0;X=ia&1^1;ia=0;fa=R;while(1){if((y|0)==4129){R=c[w>>2]|0;T=d[R+(fa>>>3)|0]<<(fa&7)>>>7;da=c[A>>2]|0;aa=((fa|0)<(da|0))+fa|0;c[s>>2]=aa;Wc=T&1;Xc=aa;Yc=da;Zc=R}else{Wc=X^1;Xc=fa;Yc=c[A>>2]|0;Zc=c[w>>2]|0}R=c[jb>>2]|0;da=Zc+(Xc>>>3)|0;aa=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Xc&7)>>>26;da=b[R+(aa<<2)>>1]|0;T=b[R+(aa<<2)+2>>1]|0;aa=T<<16>>16;if(T<<16>>16<0){T=Xc+6|0;V=Yc>>>0>T>>>0?T:Yc;T=Zc+(V>>>3)|0;N=((je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(V&7)>>>((aa+32|0)>>>0))+da|0;_c=b[R+(N<<2)+2>>1]|0;$c=b[R+(N<<2)>>1]|0;ad=V}else{_c=aa;$c=da;ad=Xc}da=_c+ad|0;aa=Yc>>>0>da>>>0?da:Yc;c[s>>2]=aa;da=$c+1|0;if((da|0)==34){V=Zc+(aa>>>3)|0;N=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(aa&7)>>>20;V=aa+12|0;c[s>>2]=Yc>>>0>V>>>0?V:Yc;bd=N+34|0}else{bd=da}da=bd+Z|0;cd=((Wc|0)==0?bd:0)+ja|0;if((bd|0)>0){N=Wc+mb&255;V=ia;aa=0;while(1){if((V|0)>=(c[E>>2]|0)){break m}R=(c[H>>2]|0)+(c[(c[lb>>2]|0)+(V<<2)>>2]<<2)+3|0;if((d[R]|0)==(mb|0)){a[R]=N;dd=aa+1|0}else{dd=aa}R=V+1|0;if((dd|0)<(bd|0)){V=R;aa=dd}else{ed=R;break}}}else{ed=ia}if((da|0)>=(ba|0)){break}aa=c[s>>2]|0;if(((c[x>>2]|0)-aa|0)>0){ja=cd;Z=da;y=bd;X=Wc;ia=ed;fa=aa}else{break}}ba=ba-cd|0;mb=mb+1|0;if(!((mb|0)<((c[F>>2]|0)-1|0)&(ba|0)>0)){break l}}KIb(c[K>>2]|0,16,2500352,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I;break a}}while(0);c[u+26844>>2]=c[u+27612>>2];E=c[s>>2]|0;$=c[A>>2]|0;ba=c[w>>2]|0;mb=ba+(E>>>3)|0;lb=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(E&7)>>>28;mb=E+4|0;E=$>>>0>mb>>>0?mb:$;c[s>>2]=E;mb=ba+(E>>>3)|0;ba=d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0;mb=E+4|0;c[s>>2]=$>>>0>mb>>>0?mb:$;$=r9a(v,r,c[v+28400+(lb*20|0)+4>>2]|0,0,0,0)|0;n:do{if(($|0)>=0){lb=(je(ba|0)|0)<<(E&7)>>>28;s9a(v,0,c[u+672>>2]|0,c[u+680>>2]|0);mb=v+28400+(lb*20|0)+4|0;lb=r9a(v,r,c[mb>>2]|0,0,1,$)|0;if((lb|0)<0){break}jb=r9a(v,r,c[mb>>2]|0,0,2,lb)|0;if((jb|0)<0){break}if((c[(c[K>>2]|0)+88>>2]&8192|0)==0){lb=u+676|0;mb=u+684|0;s9a(v,c[u+696>>2]|0,c[lb>>2]|0,c[mb>>2]|0);s9a(v,c[u+700>>2]|0,c[lb>>2]|0,c[mb>>2]|0)}mb=c[s>>2]|0;lb=c[A>>2]|0;fa=c[w>>2]|0;ia=fa+(mb>>>3)|0;X=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(mb&7)>>>28;ia=mb+4|0;mb=lb>>>0>ia>>>0?ia:lb;c[s>>2]=mb;ia=fa+(mb>>>3)|0;fa=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(mb&7)>>>28;ia=mb+4|0;c[s>>2]=lb>>>0>ia>>>0?ia:lb;lb=v+28720+(X*20|0)|0;ia=v+28720+(fa*20|0)|0;c[l+4>>2]=lb;c[m+4>>2]=ia;c[l+8>>2]=lb;c[m+8>>2]=ia;c[l+12>>2]=lb;c[m+12>>2]=ia;c[l+16>>2]=lb;c[m+16>>2]=ia;c[l+20>>2]=lb;c[m+20>>2]=ia;ia=v+29040+(X*20|0)|0;lb=v+29040+(fa*20|0)|0;c[l+24>>2]=ia;c[m+24>>2]=lb;c[l+28>>2]=ia;c[m+28>>2]=lb;c[l+32>>2]=ia;c[m+32>>2]=lb;c[l+36>>2]=ia;c[m+36>>2]=lb;c[l+40>>2]=ia;c[m+40>>2]=lb;c[l+44>>2]=ia;c[m+44>>2]=lb;c[l+48>>2]=ia;c[m+48>>2]=lb;c[l+52>>2]=ia;c[m+52>>2]=lb;c[l+56>>2]=ia;c[m+56>>2]=lb;lb=v+29360+(X*20|0)|0;ia=v+29360+(fa*20|0)|0;c[l+60>>2]=lb;c[m+60>>2]=ia;c[l+64>>2]=lb;c[m+64>>2]=ia;c[l+68>>2]=lb;c[m+68>>2]=ia;c[l+72>>2]=lb;c[m+72>>2]=ia;c[l+76>>2]=lb;c[m+76>>2]=ia;c[l+80>>2]=lb;c[m+80>>2]=ia;c[l+84>>2]=lb;c[m+84>>2]=ia;c[l+88>>2]=lb;c[m+88>>2]=ia;c[l+92>>2]=lb;c[m+92>>2]=ia;c[l+96>>2]=lb;c[m+96>>2]=ia;c[l+100>>2]=lb;c[m+100>>2]=ia;c[l+104>>2]=lb;c[m+104>>2]=ia;c[l+108>>2]=lb;c[m+108>>2]=ia;ia=v+29680+(X*20|0)|0;X=v+29680+(fa*20|0)|0;fa=28;while(1){c[l+(fa<<2)>>2]=ia;c[m+(fa<<2)>>2]=X;lb=fa+1|0;if((lb|0)<64){fa=lb}else{fd=jb;gd=1;break}}while(1){if((gd|0)>=64){break}jb=r9a(v,r,c[(c[l+(gd<<2)>>2]|0)+4>>2]|0,gd,0,fd)|0;if((jb|0)<0){break n}fa=m+(gd<<2)|0;X=r9a(v,r,c[(c[fa>>2]|0)+4>>2]|0,gd,1,jb)|0;if((X|0)<0){break n}jb=r9a(v,r,c[(c[fa>>2]|0)+4>>2]|0,gd,2,X)|0;if((jb|0)<0){break n}else{fd=jb;gd=gd+1|0}}jb=u+20|0;X=u+576|0;fa=u+704|0;ia=u+28|0;lb=c[jb>>2]|0;if((c[X>>2]|0)==0){c[fa>>2]=ca(c[(c[_>>2]|0)+32>>2]|0,lb-1|0)|0;c[u+708>>2]=ca(c[(c[_>>2]|0)+36>>2]|0,(lb>>((c[ia>>2]|0)!=0))-1|0)|0;c[u+712>>2]=ca(c[(c[_>>2]|0)+40>>2]|0,(lb>>((c[ia>>2]|0)!=0))-1|0)|0}else{c[fa>>2]=0;c[u+708>>2]=0;c[u+712>>2]=0}fa=u+580|0;c[fa>>2]=0;mb=u+636|0;y=c[mb>>2]|0;if((y|0)>0){Z=u+448|0;ja=u+44|0;aa=u+32|0;V=u+16|0;N=u+24|0;R=u+632|0;T=u+620|0;L=u+408|0;W=u+428|0;ha=u+424|0;S=u+420|0;ga=u+416|0;M=u+216|0;D=q|0;ea=q+4|0;Y=q+8|0;G=q+12|0;ma=0;wb=y;while(1){do{if((wb|0)>(ma|0)){y=0;hb=-559038737;ub=-559038737;while(1){kb=c[_>>2]|0;la=c[kb+(y<<2)>>2]|0;Q=c[v+704+(y<<2)>>2]|0;Ob=c[(c[ja>>2]|0)+(y<<2)>>2]|0;Nb=c[(c[aa>>2]|0)+(y<<2)>>2]|0;yb=c[kb+32+(y<<2)>>2]|0;kb=c[V>>2]|0;xb=(y|0)!=0;if(xb){hd=0;id=c[jb>>2]>>((c[ia>>2]|0)!=0);jd=kb>>((c[N>>2]|0)!=0);kd=ma}else{vb=(c[ia>>2]|0)!=0|0;hd=vb;id=c[jb>>2]|0;jd=kb;kd=ma<<vb}vb=xb&1;kb=c[v+716+(vb<<2)>>2]|0;Cb=kd+1+hd|0;Sb=c[(xb?R:T)>>2]|0;xb=c[v+672+(vb<<2)>>2]|0;Qb=c[v+680+(vb<<2)>>2]|0;vb=c[v+692+(y<<2)>>2]|0;Rb=(c[X>>2]|0)==0?-yb|0:yb;if((kd|0)<(Cb|0)){yb=(Sb|0)>0;Pb=Qb-1|0;Yb=(Rb|0)<0;Xb=-(Rb<<3)|0;ec=v+30464+(y<<7)|0;ib=v+30080+(y<<7)|0;hc=Rb+1|0;ic=kd;nb=hb;mc=ub;while(1){if(yb){nc=ic<<2;lc=0;qc=nb;sc=mc;while(1){rc=lc<<2;pc=qc;oc=sc;tc=0;while(1){ld=(d[1103800+(tc<<1)|0]|0)+rc|0;md=(d[1103801+(tc<<1)|0]|0)+nc|0;nd=(ca(md,xb)|0)+ld|0;od=nd+vb|0;o:do{if((ld|0)<(xb|0)&(md|0)<(Qb|0)){pd=md<<3;qd=ld<<3;rd=(ca(pd,Rb)|0)+qd|0;sd=a[(c[H>>2]|0)+(od<<2)+2|0]|0;if((sd<<24>>24|0)==8){td=rd+Q|0;mf[c[M>>2]&2047](la+td|0,Ob+td|0,Rb,8);ud=oc;vd=pc;break}else if((sd<<24>>24|0)==5|(sd<<24>>24|0)==6){wd=Nb}else{wd=Ob}td=rd+Q|0;do{if((sd<<24>>24|0)==5|(sd<<24>>24|0)==1|(sd<<24>>24|0)==0){xd=oc;yd=pc;zd=0;Ad=wd+td|0;Bd=sd;O=315}else{rd=a[kb+(nd<<1)|0]|0;Cd=a[kb+(nd<<1)+1|0]|0;Dd=rd>>1;Ed=Dd+qd|0;Fd=Cd>>1;Gd=Fd+pd|0;Id=Cd<<1&2|rd&1;Jd=wd+(Dd+td+(ca(Fd,Rb)|0))|0;if((Gd|Ed|0)>-1&(Ed+9|0)<(jd|0)&(Gd+9|0)<(id|0)){Kd=Jd;Ld=Id;Md=Cd;Nd=rd;O=316;break}Fd=c[U>>2]|0;if(Yb){Od=Fd+Xb|0}else{Od=Fd}Ve[c[L>>2]&127](Od,Jd,Rb,Rb,9,9,Ed,Gd,jd,id);xd=rd;yd=Cd;zd=Id;Ad=Od;Bd=a[(c[H>>2]|0)+(od<<2)+2|0]|0;O=315}}while(0);if((O|0)==315){O=0;if(Bd<<24>>24==1){Pd=yd;Qd=xd}else{Kd=Ad;Ld=zd;Md=yd;Nd=xd;O=316}}do{if((O|0)==316){O=0;if((Ld|0)==3){pd=Md^Nd;pe[c[ga>>2]&1023](la+td|0,Kd+(pd>>>31)|0,Kd+(hc+(pd>>31))|0,Rb,8);Pd=Md;Qd=Nd;break}else{mf[c[v+344+(Ld<<2)>>2]&2047](la+td|0,Kd,Rb,8);Pd=Md;Qd=Nd;break}}}while(0);pd=c[H>>2]|0;qd=pd+(od<<2)|0;sd=d[pd+(od<<2)+3|0]|0;if((a[pd+(od<<2)+2|0]|0)==1){pd=0;while(1){Rd=v+26844+(y<<8)+(pd<<2)|0;Sd=c[Rd>>2]|0;Td=b[Sd>>1]|0;Id=Td&3;if((Id|0)==0){O=321;break}else if((Id|0)==1){c[Rd>>2]=Sd+2;Cd=(Td>>>2&127)+pd|0;if((Cd|0)>63){O=325;break}rd=d[v+136+Cd|0]|0;b[v+448+(rd<<1)>>1]=ca(b[v+30080+(sd*768|0)+(y<<7)+(rd<<1)>>1]|0,Td>>9)|0;Ud=Cd}else if((Id|0)==2){Id=d[v+136+pd|0]|0;b[v+448+(Id<<1)>>1]=ca(b[v+30080+(sd*768|0)+(y<<7)+(Id<<1)>>1]|0,Td>>2)|0;c[Rd>>2]=Sd+2;Ud=pd}else{break}Id=Ud+1|0;if((Id|0)<64){pd=Id}else{O=329;break}}do{if((O|0)==321){O=0;pd=Td-1|0;if((pd|0)<4){c[Rd>>2]=Sd+2;O=329;break}else{b[Sd>>1]=pd&65535&-4;O=329;break}}else if((O|0)==325){O=0;KIb(c[K>>2]|0,16,2476560,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}}while(0);if((O|0)==329){O=0;b[Z>>1]=ca(b[ib>>1]|0,b[qd>>1]|0)|0}ef[c[S>>2]&4095](la+td|0,Rb,Z);ud=Qd;vd=Pd;break}else{Vd=0}while(1){Wd=v+26844+(y<<8)+(Vd<<2)|0;Xd=c[Wd>>2]|0;Yd=b[Xd>>1]|0;pd=Yd&3;if((pd|0)==0){O=332;break}else if((pd|0)==1){c[Wd>>2]=Xd+2;Id=(Yd>>>2&127)+Vd|0;if((Id|0)>63){O=336;break}Cd=d[v+136+Id|0]|0;b[v+448+(Cd<<1)>>1]=ca(b[v+30080+(sd*768|0)+384+(y<<7)+(Cd<<1)>>1]|0,Yd>>9)|0;Zd=Id}else if((pd|0)==2){pd=d[v+136+Vd|0]|0;b[v+448+(pd<<1)>>1]=ca(b[v+30080+(sd*768|0)+384+(y<<7)+(pd<<1)>>1]|0,Yd>>2)|0;c[Wd>>2]=Xd+2;Zd=Vd}else{_d=Vd;O=341;break}pd=Zd+1|0;if((pd|0)<64){Vd=pd}else{$d=Zd;O=340;break}}do{if((O|0)==332){O=0;sd=Yd-1|0;if((sd|0)<4){c[Wd>>2]=Xd+2;$d=Vd;O=340;break}else{b[Xd>>1]=sd&65535&-4;$d=Vd;O=340;break}}else if((O|0)==336){O=0;KIb(c[K>>2]|0,16,2476560,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}}while(0);if((O|0)==340){O=0;b[Z>>1]=ca(b[ec>>1]|0,b[qd>>1]|0)|0;_d=$d;O=341}do{if((O|0)==341){O=0;if((_d|0)!=0){break}ef[c[W>>2]&4095](la+td|0,Rb,Z);ud=Qd;vd=Pd;break o}}while(0);ef[c[ha>>2]&4095](la+td|0,Rb,Z);ud=Qd;vd=Pd}else{ud=oc;vd=pc}}while(0);od=tc+1|0;if((od|0)<16){pc=vd;oc=ud;tc=od}else{break}}tc=lc+1|0;if((tc|0)<(Sb|0)){lc=tc;qc=vd;sc=ud}else{ae=vd;be=ud;break}}}else{ae=nb;be=mc}if((c[z>>2]|0)==0){sc=ic<<2;qc=sc|3;q9a(v,y,sc-((ic|0)!=0)|0,(qc|0)>(Pb|0)?Pb:qc)}qc=ic+1|0;if((qc|0)<(Cb|0)){ic=qc;nb=ae;mc=be}else{ce=ae;de=be;break}}}else{ce=hb;de=ub}mc=y+1|0;if((mc|0)<3){y=mc;hb=ce;ub=de}else{break}}ub=c[ia>>2]|0;hb=ma+1|0;y=ca(32<<ub,hb)|0;da=c[jb>>2]|0;mc=((y|0)>(da|0)?da:y)-16|0;y=c[K>>2]|0;da=y+148|0;if((c[da>>2]|0)==0){ee=hb;break}nb=c[fa>>2]|0;c[fa>>2]=mc;if((c[X>>2]|0)==0){fe=(c[y+124>>2]|0)-mc|0}else{fe=nb}ic=fe>>ub;ub=c[_>>2]|0;c[D>>2]=ca(c[ub+32>>2]|0,fe)|0;c[ea>>2]=ca(c[ub+36>>2]|0,ic)|0;c[Y>>2]=ca(c[ub+40>>2]|0,ic)|0;mrc(G|0,0,20)|0;_e[c[da>>2]&511](y,ub,D,fe,3,mc-nb|0);ee=hb}else{ee=ma+1|0}}while(0);hb=c[mb>>2]|0;if((ee|0)<(hb|0)){ma=ee;wb=hb}else{break}}ge=c[jb>>2]|0}else{ge=lb}wb=ge>>3;q9a(v,0,wb-1|0,wb);wb=c[jb>>2]>>((c[ia>>2]|0)!=0?4:3);q9a(v,1,wb-1|0,wb);wb=c[jb>>2]>>((c[ia>>2]|0)!=0?4:3);q9a(v,2,wb-1|0,wb);wb=c[K>>2]|0;ma=wb+124|0;mb=c[ma>>2]|0;D=wb+148|0;if((c[D>>2]|0)!=0){G=c[fa>>2]|0;c[fa>>2]=mb;if((c[X>>2]|0)==0){he=(c[ma>>2]|0)-mb|0}else{he=G}ma=he>>c[ia>>2];Y=c[_>>2]|0;ea=q|0;c[ea>>2]=ca(c[Y+32>>2]|0,he)|0;c[q+4>>2]=ca(c[Y+36>>2]|0,ma)|0;c[q+8>>2]=ca(c[Y+40>>2]|0,ma)|0;mrc(q+12|0,0,20)|0;_e[c[D>>2]&511](wb,Y,ea,he,3,mb-G|0)}G=YHb(g,c[_>>2]|0)|0;if((G|0)<0){J=G;i=k;return J|0}c[h>>2]=1;G=c[j>>2]|0;mb=G+44|0;H5a(f,mb);ea=G+56|0;Y=G5a(mb,ea)|0;do{if((Y|0)<0){ie=Y}else{if((c[G+68>>2]|0)==0){ie=Y;break}mb=G+32|0;H5a(f,mb);ie=G5a(mb,ea)|0}}while(0);H5a(f,ea);J=(ie|0)<0?ie:t;i=k;return J|0}}while(0);KIb(c[K>>2]|0,16,2487696,(I=i,i=i+1|0,i=i+7&-8,c[I>>2]=0,I)|0);i=I}}while(0);L5a(P,2147483647,0);WHb(c[_>>2]|0);J=-1;i=k;return J|0}function l9a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+60|0;d=c[b>>2]|0;mJb(d+652|0);mJb(d+688|0);mJb(d+28388|0);mJb(d+27612|0);mJb(d+32384|0);mJb(d+32388|0);mJb(d+716|0);mJb(d+720|0);mJb(d+32392|0);c[d+8>>2]=0;e=c[b>>2]|0;b=e+32|0;if((c[b>>2]|0)!=0){H5a(a,b)}b=e+44|0;if((c[b>>2]|0)!=0){H5a(a,b)}b=e+56|0;if((c[b>>2]|0)!=0){H5a(a,b)}VHb(d+56|0);VHb(d+44|0);VHb(d+32|0);if((c[c[a+64>>2]>>2]|0)!=0){return 0}a=d+28400|0;b=d+28720|0;e=d+29040|0;f=d+29360|0;g=d+29680|0;h=0;do{c3(a+(h*20|0)|0);c3(b+(h*20|0)|0);c3(e+(h*20|0)|0);c3(f+(h*20|0)|0);c3(g+(h*20|0)|0);h=h+1|0;}while((h|0)<16);c3(d+3e4|0);c3(d+30020|0);c3(d+30040|0);c3(d+30060|0);return 0}function m9a(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;d=b+32|0;if((c[d>>2]|0)!=0){H5a(a,d)}d=b+44|0;if((c[d>>2]|0)!=0){H5a(a,d)}d=b+56|0;if((c[d>>2]|0)==0){return}H5a(a,d);return}function n9a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;g=e+60|0;h=c[g>>2]|0;j=h+56|0;c[j>>2]=UHb()|0;k=h+44|0;c[k>>2]=UHb()|0;l=UHb()|0;m=h+32|0;c[m>>2]=l;do{if((c[j>>2]|0)!=0){if((c[k>>2]|0)==0|(l|0)==0){break}c[(c[e+64>>2]|0)+4>>2]=1;c[h+12>>2]=(c[e+52>>2]|0)!=808669270;c[h>>2]=e;n=h+16|0;c[n>>2]=(c[e+120>>2]|0)+15&-16;o=h+20|0;c[o>>2]=(c[e+124>>2]|0)+15&-16;if((c[e+48>>2]|0)!=31){c[e+140>>2]=0}c[e+400>>2]=2;p=e+88|0;YJa(h+200|0,c[p>>2]|8388608);G8a(h+408|0,8);u9a(h+416|0,c[p>>2]|0);p=0;do{a[h+(p+72)|0]=p<<3&56|p>>>3;q=a[1242080+p|0]|0;a[h+(p+136)|0]=q<<3&56|(q&255)>>>3;p=p+1|0;}while((p|0)<64);mrc(h+588|0,-1|0,12)|0;p=h+24|0;q=h+28|0;vLa(c[e+140>>2]|0,p,q);r=c[n>>2]|0;s=(r+31|0)/32|0;c[h+620>>2]=s;t=c[o>>2]|0;u=(t+31|0)/32|0;c[h+624>>2]=u;v=ca(s,u)|0;c[h+628>>2]=v;u=c[p>>2]|0;p=c[q>>2]|0;q=((r>>u)+31|0)/32|0;c[h+632>>2]=q;s=((t>>p)+31|0)/32|0;c[h+636>>2]=s;w=ca(q,s)|0;c[h+640>>2]=w;c[h+616>>2]=(w<<1)+v;c[h+644>>2]=v;c[h+648>>2]=w+v;v=(r+15|0)/16|0;c[h+660>>2]=v;w=(t+15|0)/16|0;c[h+664>>2]=w;c[h+656>>2]=ca(v,w)|0;w=(r|0)/8|0;c[h+672>>2]=w;r=(t|0)/8|0;c[h+680>>2]=r;t=w>>u;c[h+676>>2]=t;u=r>>p;c[h+684>>2]=u;p=ca(r,w)|0;w=ca(t,u)|0;c[h+668>>2]=(w<<1)+p;c[h+696>>2]=p;c[h+700>>2]=w+p;a:do{if((c[h+8>>2]|0)==0){p=h+724|0;w=h+852|0;u=0;do{b[p+(u<<1)>>1]=b[253024+(u<<1)>>1]|0;c[w+(u<<2)>>2]=c[253152+(u<<2)>>2];a[h+(u+1108)|0]=b[252576+(u<<1)>>1];a[h+(u+1172)|0]=b[252704+(u<<1)>>1];a[h+(u+1236)|0]=b[252832+(u<<1)>>1];a[h+(u+52892)|0]=a[252960+u|0]|0;u=u+1|0;}while((u|0)<64);a[h+25684|0]=1;a[h+25690|0]=63;b[h+26076>>1]=0;b[h+26074>>1]=0;a[h+25685|0]=1;a[h+25754|0]=63;b[h+26204>>1]=1;b[h+26202>>1]=1;a[h+25686|0]=1;a[h+25818|0]=63;b[h+26332>>1]=1;b[h+26330>>1]=1;a[h+25687|0]=1;a[h+25882|0]=63;b[h+26460>>1]=2;b[h+26458>>1]=2;a[h+25688|0]=1;a[h+25946|0]=63;b[h+26588>>1]=2;b[h+26586>>1]=2;a[h+25689|0]=1;a[h+26010|0]=63;b[h+26716>>1]=2;b[h+26714>>1]=2;u=h+28400|0;w=h+28720|0;p=h+29040|0;t=h+29360|0;r=h+29680|0;v=0;do{$2(u+(v*20|0)|0,11,32,1615466+(v<<7)|0,4,2,1615464+(v<<7)|0,4,2,0,0,0,0)|0;$2(w+(v*20|0)|0,11,32,2093642+(v<<7)|0,4,2,2093640+(v<<7)|0,4,2,0,0,0,0)|0;$2(p+(v*20|0)|0,11,32,2091594+(v<<7)|0,4,2,2091592+(v<<7)|0,4,2,0,0,0,0)|0;$2(t+(v*20|0)|0,11,32,2089546+(v<<7)|0,4,2,2089544+(v<<7)|0,4,2,0,0,0,0)|0;$2(r+(v*20|0)|0,11,32,2087498+(v<<7)|0,4,2,2087496+(v<<7)|0,4,2,0,0,0,0)|0;v=v+1|0;}while((v|0)<16)}else{v=h+28400|0;r=h+32412|0;t=h+28720|0;p=h+29040|0;w=h+29360|0;u=h+29680|0;s=0;while(1){if((s|0)>=16){break a}if(($2(v+(s*20|0)|0,11,32,r+(s<<8)+4|0,8,4,r+(s<<8)|0,8,4,0,0,0,0)|0)<0){break}q=s+16|0;if(($2(t+(s*20|0)|0,11,32,r+(q<<8)+4|0,8,4,r+(q<<8)|0,8,4,0,0,0,0)|0)<0){break}q=s+32|0;if(($2(p+(s*20|0)|0,11,32,r+(q<<8)+4|0,8,4,r+(q<<8)|0,8,4,0,0,0,0)|0)<0){break}q=s+48|0;if(($2(w+(s*20|0)|0,11,32,r+(q<<8)+4|0,8,4,r+(q<<8)|0,8,4,0,0,0,0)|0)<0){break}q=s+64|0;if(($2(u+(s*20|0)|0,11,32,r+(q<<8)+4|0,8,4,r+(q<<8)|0,8,4,0,0,0,0)|0)<0){break}else{s=s+1|0}}KIb(e,8,2291768,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;x=-1;i=f;return x|0}}while(0);$2(h+3e4|0,6,34,551978,4,2,551976,4,2,0,0,0,0)|0;$2(h+30020|0,5,30,1210642,4,2,1210640,4,2,0,0,0,0)|0;$2(h+30040|0,3,8,828977,2,1,828976,2,1,0,0,0,0)|0;$2(h+30060|0,6,63,826817,2,1,826816,2,1,0,0,0,0)|0;o=c[g>>2]|0;n=o;s=c[o+672>>2]|0;r=c[o+680>>2]|0;u=c[o+676>>2]|0;w=c[o+684>>2]|0;p=o+616|0;t=o+652|0;c[t>>2]=pJb(c[p>>2]|0)|0;v=o+668|0;q=o+688|0;c[q>>2]=pJb(c[v>>2]<<2)|0;y=o+28388|0;c[y>>2]=pJb(c[v>>2]<<2)|0;z=o+27612|0;c[z>>2]=pJb(c[v>>2]<<7)|0;v=o+716|0;c[v>>2]=pJb(ca(s<<1,r)|0)|0;r=o+720|0;c[r>>2]=pJb(ca(u<<1,w)|0)|0;w=o+32384|0;c[w>>2]=pJb(c[p>>2]<<6)|0;p=pJb((c[o+656>>2]|0)+1|0)|0;c[o+32388>>2]=p;do{if((c[t>>2]|0)!=0){if((c[q>>2]|0)==0){break}if((c[z>>2]|0)==0){break}if((c[y>>2]|0)==0){break}u=c[w>>2]|0;if((u|0)==0|(p|0)==0){break}if((c[v>>2]|0)==0){break}if((c[r>>2]|0)==0){break}s=o+632|0;A=o+620|0;B=o+636|0;C=o+624|0;D=0;E=0;while(1){F=(E|0)!=0;G=c[(F?s:A)>>2]|0;H=c[(F?B:C)>>2]|0;I=F&1;F=c[n+672+(I<<2)>>2]|0;J=c[n+680+(I<<2)>>2]|0;do{if((H|0)>0){I=n+692+(E<<2)|0;if((G|0)<=0){K=D;break}L=G<<4;M=D;N=0;while(1){O=N<<2;P=M;Q=0;while(1){R=Q<<2;S=P;T=0;while(1){U=(d[1103800+(T<<1)|0]|0)+R|0;V=(d[1103801+(T<<1)|0]|0)+O|0;if((U|0)<(F|0)&(V|0)<(J|0)){c[u+(S<<2)>>2]=(ca(V,F)|0)+U+(c[I>>2]|0)}else{c[u+(S<<2)>>2]=-1}U=T+1|0;if((U|0)<16){S=S+1|0;T=U}else{break}}T=Q+1|0;if((T|0)<(G|0)){P=P+16|0;Q=T}else{break}}Q=N+1|0;if((Q|0)<(H|0)){M=M+L|0;N=Q}else{break}}K=(ca(L,H)|0)+D|0}else{K=D}}while(0);H=E+1|0;if((H|0)<3){D=K;E=H}else{x=0;break}}i=f;return x|0}}while(0);l9a(e)|0;x=-1;i=f;return x|0}}while(0);VHb(j);VHb(k);VHb(m);x=-12;i=f;return x|0}function o9a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;f=c[a+60>>2]|0;g=b+8|0;h=c[g>>2]|0;j=b+16|0;k=c[j>>2]|0;l=b|0;b=(c[l>>2]|0)+(h>>>3)|0;m=(je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(h&7)>>>8;b=h+24|0;c[g>>2]=k>>>0>b>>>0?b:k;k=f+4|0;c[k>>2]=m;b=a;KIb(b,48,2344608,(h=i,i=i+8|0,c[h>>2]=m,h)|0);i=h;if((c[k>>2]|0)<197120){c[f+576>>2]=1;KIb(b,48,2338608,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}m=c[g>>2]|0;n=c[j>>2]|0;o=c[l>>2]|0;p=o+(m>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(m&7)>>>16;p=m+16|0;c[g>>2]=n>>>0>p>>>0?p:n;n=q<<4;q=f+16|0;c[q>>2]=n;p=c[g>>2]|0;m=c[j>>2]|0;r=o+(p>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(p&7)>>>16;r=p+16|0;c[g>>2]=m>>>0>r>>>0?r:m;m=s<<4;s=f+20|0;c[s>>2]=m;f=c[g>>2]|0;r=c[j>>2]|0;if((c[k>>2]|0)>197119){p=o+(f>>>3)|0;t=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(f&7)>>>8;p=f+24|0;u=r>>>0>p>>>0?p:r;c[g>>2]=u;p=o+(u>>>3)|0;v=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>8;p=u+24|0;u=r>>>0>p>>>0?p:r;c[g>>2]=u;p=o+(u>>>3)|0;w=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>24;p=u+8|0;u=r>>>0>p>>>0?p:r;c[g>>2]=u;p=o+(u>>>3)|0;x=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(u&7)>>>24;p=u+8|0;u=r>>>0>p>>>0?p:r;c[g>>2]=u;y=t;z=v;A=w;B=x;C=u}else{y=n;z=m;A=0;B=0;C=f}f=o+(C>>>3)|0;m=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(C&7);f=C+16|0;C=r>>>0>f>>>0?f:r;c[g>>2]=C;f=o+(C>>>3)|0;n=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(C&7)>>>16;f=C+16|0;C=r>>>0>f>>>0?f:r;c[g>>2]=C;f=n|m&-65536;n=o+(C>>>3)|0;u=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7);n=C+16|0;C=r>>>0>n>>>0?n:r;c[g>>2]=C;n=o+(C>>>3)|0;x=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(C&7)>>>16;n=C+16|0;C=r>>>0>n>>>0?n:r;c[g>>2]=C;n=x|u&-65536;do{if((f|0)==0|(n|0)==0){D=C;E=r;F=o}else{if((u|m|0)>=0){xKb(a+104|0,a+108|0,n,(n|0)<0|0?-1:0,f,(f|0)<0|0?-1:0,1073741824,0)|0;D=c[g>>2]|0;E=c[j>>2]|0;F=c[l>>2]|0;break}KIb(b,16,2332960,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;G=-1094995529;i=e;return G|0}}while(0);f=F+(D>>>3)|0;n=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(D&7)>>>8;f=D+24|0;D=E>>>0>f>>>0?f:E;c[g>>2]=D;f=F+(D>>>3)|0;F=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(D&7)>>>8;f=D+24|0;c[g>>2]=E>>>0>f>>>0?f:E;if(!((n|0)==0|(F|0)==0)){xKb(a+224|0,a+228|0,n,0,F,0,1073741824,0)|0}F=c[g>>2]|0;n=c[j>>2]|0;if((c[k>>2]|0)<197120){j=F+5|0;E=n>>>0>j>>>0?j:n;c[g>>2]=E;H=E}else{H=F}F=c[l>>2]|0;l=F+(H>>>3)|0;E=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(H&7)>>>24;l=H+8|0;H=(n>>>0>l>>>0?l:n)+24|0;l=(n>>>0>H>>>0?H:n)+6|0;H=n>>>0>l>>>0?l:n;c[g>>2]=H;do{if((c[k>>2]|0)>197119){l=H+5|0;j=n>>>0>l>>>0?l:n;c[g>>2]=j;l=F+(j>>>3)|0;f=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(j&7)>>>30;l=j+2|0;j=n>>>0>l>>>0?l:n;c[g>>2]=j;c[a+140>>2]=c[310056+(f<<2)>>2];if((f|0)!=1){f=j+3|0;c[g>>2]=n>>>0>f>>>0?f:n;break}KIb(b,16,2327520,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;G=-1094995529;i=e;return G|0}}while(0);h=c[q>>2]|0;q=c[s>>2]|0;do{if((y|0)<=(h|0)&(y|0)>(h-16|0)){if(!((z|0)<=(q|0)&(z|0)>(q-16|0)&(A|0)==0&(B|0)==(q-z|0))){I=20;break}J=H4a(a,y,z)|0}else{I=20}}while(0);if((I|0)==20){J=H4a(a,h,q)|0}if((J|0)<0){G=J;i=e;return G|0}do{if((E|0)==1){c[a+384>>2]=4}else if((E|0)==2){c[a+384>>2]=5}else{if((E-1|0)>>>0<2>>>0){break}else{G=0}i=e;return G|0}}while(0);c[a+392>>2]=5;c[a+388>>2]=1;G=0;i=e;return G|0}function p9a(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;g=i;h=c[e+60>>2]|0;j=h+4|0;k=f+8|0;do{if((c[j>>2]|0)>197119){l=c[k>>2]|0;m=f+16|0;n=c[m>>2]|0;o=f|0;p=c[o>>2]|0;q=p+(l>>>3)|0;r=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(l&7)>>>29;q=l+3|0;l=n>>>0>q>>>0?q:n;c[k>>2]=l;a:do{if((r|0)!=0){q=32-r|0;s=0;t=l;u=n;v=p;while(1){w=v+(t>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(t&7)>>>(q>>>0);w=t+r|0;c[k>>2]=u>>>0>w>>>0?w:u;a[h+(s+52892)|0]=x;x=s+1|0;if((x|0)>=64){break a}s=x;t=c[k>>2]|0;u=c[m>>2]|0;v=c[o>>2]|0}}}while(0);if((c[j>>2]|0)<=197119){y=16;z=m;A=o;break}r=c[k>>2]|0;p=c[m>>2]|0;n=(c[o>>2]|0)+(r>>>3)|0;l=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(r&7)>>>28;n=r+4|0;c[k>>2]=p>>>0>n>>>0?n:p;y=l+1|0;z=m;A=o}else{y=16;z=f+16|0;A=f|0}}while(0);l=32-y|0;p=h+852|0;n=c[A>>2]|0;r=0;do{v=c[k>>2]|0;u=c[z>>2]|0;t=n+(v>>>3)|0;s=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>(l>>>0);t=v+y|0;c[k>>2]=u>>>0>t>>>0?t:u;c[p+(r<<2)>>2]=s;r=r+1|0;}while((r|0)<64);r=c[k>>2]|0;p=c[z>>2]|0;if((c[j>>2]|0)>197119){y=n+(r>>>3)|0;l=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(r&7)>>>28;y=r+4|0;s=p>>>0>y>>>0?y:p;c[k>>2]=s;B=l+1|0;C=s}else{B=16;C=r}r=32-B|0;s=h+724|0;l=0;y=C;do{C=n+(y>>>3)|0;u=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(y&7)>>>(r>>>0);C=y+B|0;y=p>>>0>C>>>0?C:p;c[k>>2]=y;b[s+(l<<1)>>1]=u;l=l+1|0;}while((l|0)<64);do{if((c[j>>2]|0)>197119){l=n+(y>>>3)|0;s=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(y&7)>>>23;l=y+9|0;c[k>>2]=p>>>0>l>>>0?l:p;l=s+1|0;if(!(l>>>0>384>>>0)){if(1){D=l;E=17;break}else{F=0;break}}KIb(e,16,2381064,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-1;i=g;return H|0}else{D=3;E=17}}while(0);if((E|0)==17){p=h+1108|0;y=0;while(1){n=0;do{j=c[k>>2]|0;l=c[z>>2]|0;s=(c[A>>2]|0)+(j>>>3)|0;B=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(j&7)>>>24;s=j+8|0;c[k>>2]=l>>>0>s>>>0?s:l;a[p+(y<<6)+n|0]=B;n=n+1|0;}while((n|0)<64);n=y+1|0;if((n|0)<(D|0)){y=n}else{F=D;break}}}D=h+25684|0;y=h+25690|0;p=h+26074|0;n=F-1|0;o=n>>>0>65535>>>0;m=o?n>>>16:n;n=o?16:0;o=(m&65280|0)==0;B=m>>>8;l=n|8;s=0;b:while(1){j=(s|0)!=0;r=(s*3|0)-1|0;u=0;do{do{if(j|(u|0)>0){C=c[k>>2]|0;t=c[A>>2]|0;v=d[t+(C>>>3)|0]|0;q=c[z>>2]|0;x=((C|0)<(q|0))+C|0;c[k>>2]=x;if((v&128>>>((C&7)>>>0)|0)!=0){E=27;break}if(j){C=d[t+(x>>>3)|0]|0;c[k>>2]=((x|0)<(q|0))+x;if((C&128>>>((x&7)>>>0)|0)==0){E=35}else{I=u;J=0}}else{E=35}if((E|0)==35){E=0;I=(u+2|0)%3|0;J=(r+u|0)/3|0}a[D+(s*3|0)+u|0]=a[D+(J*3|0)+I|0]|0;nrc(y+(s*192|0)+(u<<6)|0,y+(J*192|0)+(I<<6)|0,64)|0;nrc(p+(s*384|0)+(u<<7)|0,p+(J*384|0)+(I<<7)|0,128)|0}else{E=27}}while(0);if((E|0)==27){E=0;c:do{if(o){x=0;C=0;while(1){q=(d[1359664+m|0]|0)+n|0;t=c[k>>2]|0;v=c[z>>2]|0;w=c[A>>2]|0;K=w+(t>>>3)|0;L=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(t&7)>>>((31-q|0)>>>0);K=t+1+q|0;q=v>>>0>K>>>0?K:v;c[k>>2]=q;if((L|0)>=(F|0)){E=38;break b}b[p+(s*384|0)+(u<<7)+(C<<1)>>1]=L;if((x|0)>62){M=x;N=C&255;break c}L=63-x|0;K=L>>>0>65535>>>0;t=K?L>>>16:L;L=K?16:0;if((t&65280|0)==0){O=L;P=t}else{O=L|8;P=t>>>8}t=(d[1359664+P|0]|0)+O|0;L=w+(q>>>3)|0;w=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(q&7)>>>((31-t|0)>>>0);L=q+1+t|0;c[k>>2]=v>>>0>L>>>0?L:v;v=w+1|0;a[y+(s*192|0)+(u<<6)+C|0]=v;x=v+x|0;C=C+1|0}}else{C=0;x=0;while(1){v=(d[1359664+B|0]|0)+l|0;w=c[k>>2]|0;L=c[z>>2]|0;t=c[A>>2]|0;q=t+(w>>>3)|0;K=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(w&7)>>>((31-v|0)>>>0);q=w+1+v|0;v=L>>>0>q>>>0?q:L;c[k>>2]=v;if((K|0)>=(F|0)){E=38;break b}b[p+(s*384|0)+(u<<7)+(x<<1)>>1]=K;if((C|0)>62){M=C;N=x&255;break c}K=63-C|0;q=K>>>0>65535>>>0;w=q?K>>>16:K;K=q?16:0;if((w&65280|0)==0){Q=K;R=w}else{Q=K|8;R=w>>>8}w=(d[1359664+R|0]|0)+Q|0;K=t+(v>>>3)|0;t=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(v&7)>>>((31-w|0)>>>0);K=v+1+w|0;c[k>>2]=L>>>0>K>>>0?K:L;L=t+1|0;a[y+(s*192|0)+(u<<6)+x|0]=L;C=L+C|0;x=x+1|0}}}while(0);if((M|0)>63){E=44;break b}a[D+(s*3|0)+u|0]=N}u=u+1|0;}while((u|0)<3);u=s+1|0;if((u|0)<2){s=u}else{E=48;break}}if((E|0)==38){KIb(e,16,2374680,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;H=-1;i=g;return H|0}else if((E|0)==44){KIb(e,16,2367536,(G=i,i=i+8|0,c[G>>2]=M,G)|0);i=G;H=-1;i=g;return H|0}else if((E|0)==48){G=h+32396|0;c[G>>2]=0;M=h+32404|0;s=h+32408|0;N=h+32400|0;while(1){c[M>>2]=0;c[s>>2]=1;D=c[k>>2]|0;y=d[(c[A>>2]|0)+(D>>>3)|0]|0;c[k>>2]=((D|0)<(c[z>>2]|0))+D;if((y&128>>>((D&7)>>>0)|0)==0){c[N>>2]=0;if((t9a(e,f)|0)!=0){H=-1;E=54;break}c[N>>2]=1;if((t9a(e,f)|0)!=0){H=-1;E=54;break}}D=(c[G>>2]|0)+1|0;c[G>>2]=D;if((D|0)>=80){E=53;break}}if((E|0)==53){c[h+8>>2]=1;H=0;i=g;return H|0}else if((E|0)==54){i=g;return H|0}}return 0}function q9a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=b+53468|0;h=(d|0)!=0|0;i=c[b+672+(h<<2)>>2]|0;j=c[b+56>>2]|0;k=c[j+32+(d<<2)>>2]|0;l=(c[b+576>>2]|0)==0?-k|0:k;if((e|0)>=(f|0)){return}k=ca(e<<3,l)|0;m=ca(i,e)|0;n=(i|0)>0;o=l<<3;p=b+688|0;q=b+436|0;r=b+432|0;s=i-1|0;t=(c[b+680+(h<<2)>>2]|0)-1|0;h=e;e=(c[b+692+(d<<2)>>2]|0)+m|0;m=(c[j+(d<<2)>>2]|0)+(k+(c[b+704+(d<<2)>>2]|0))|0;while(1){if(n){d=(h|0)>0;b=(h|0)<(t|0);k=0;j=e;while(1){do{if((a[(c[p>>2]|0)+(j<<2)+2|0]|0)!=8){if((k|0)>0){ef[c[q>>2]&4095](m+(k<<3)|0,l,g)}if(d){ef[c[r>>2]&4095](m+(k<<3)|0,l,g)}do{if((k|0)<(s|0)){if((a[(c[p>>2]|0)+(j+1<<2)+2|0]|0)!=8){break}ef[c[q>>2]&4095](m+((k<<3)+8)|0,l,g)}}while(0);if(!b){break}if((a[(c[p>>2]|0)+(j+i<<2)+2|0]|0)!=8){break}ef[c[r>>2]&4095](m+(k+l<<3)|0,l,g)}}while(0);u=k+1|0;if((u|0)>=(i|0)){break}k=u;j=j+1|0}v=i+e|0}else{v=e}j=h+1|0;if((j|0)<(f|0)){h=j;e=v;m=m+o|0}else{break}}return}function r9a(a,e,f,g,h,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;k=i;l=a+27616+(h<<8)+(g<<2)|0;m=c[l>>2]|0;n=c[a+26844+(h<<8)+(g<<2)>>2]|0;o=c[a+28388+(h<<2)>>2]|0;p=c[a+688>>2]|0;if((m|0)<0){KIb(c[a>>2]|0,16,2467272,(q=i,i=i+8|0,c[q>>2]=g,q)|0);i=q}r=(m|0)<(j|0);s=r?m:j;t=r?j-m|0:0;if((s|0)==0){u=0;v=0}else{b[n>>1]=s<<2;u=1;v=s}a:do{if((v|0)<(m|0)){s=e+8|0;j=e+12|0;r=e+16|0;w=e|0;x=(g|0)==0;y=a|0;z=64-g|0;A=g+1|0;B=v;C=v;D=u;E=t;b:while(1){F=C;G=D;while(1){H=c[s>>2]|0;if(((c[j>>2]|0)-H|0)<=0){I=G;J=B;K=E;break a}L=c[r>>2]|0;M=c[w>>2]|0;N=M+(H>>>3)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(H&7)>>>21;N=b[f+(O<<2)>>1]|0;P=b[f+(O<<2)+2>>1]|0;O=P<<16>>16;do{if(P<<16>>16<0){Q=H+11|0;R=L>>>0>Q>>>0?Q:L;Q=M+(R>>>3)|0;S=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(R&7)>>>((O+32|0)>>>0))+N|0;Q=b[f+(S<<2)>>1]|0;T=b[f+(S<<2)+2>>1]|0;S=T<<16>>16;if(!(T<<16>>16<0)){U=S;V=Q;W=R;break}T=R-O|0;R=L>>>0>T>>>0?T:L;T=M+(R>>>3)|0;X=((je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(R&7)>>>((S+32|0)>>>0))+Q|0;U=b[f+(X<<2)+2>>1]|0;V=b[f+(X<<2)>>1]|0;W=R}else{U=O;V=N;W=H}}while(0);H=U+W|0;Y=L>>>0>H>>>0?H:L;c[s>>2]=Y;if(V>>>0<7>>>0){break}if(!((V|0)>-1)){break b}H=c[1648464+(V<<2)>>2]|0;if((V-13|0)>>>0<19>>>0){N=M+(Y>>>3)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Y&7)>>>((32-H|0)>>>0);N=H+Y|0;P=L>>>0>N>>>0?N:L;c[s>>2]=P;Z=O;_=P}else{Z=H;_=Y}H=b[(c[1645760+(V<<2)>>2]|0)+(Z<<1)>>1]|0;P=c[296+(V<<2)>>2]|0;if((-1342176896>>>(V>>>0)&1|0)==0){$=P}else{O=c[168+(V<<2)>>2]|0;N=M+(_>>>3)|0;R=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(_&7)>>>((32-O|0)>>>0);N=_+O|0;c[s>>2]=L>>>0>N>>>0?N:L;$=R+P|0}if(($|0)==0){if(x){b[p+(c[o+(F<<2)>>2]<<2)>>1]=H}b[n+(G<<1)>>1]=H<<2|2}else{b[n+(G<<1)>>1]=($<<2)+(H<<16>>16<<9)|1}H=G+1|0;if(($+g|0)>64){KIb(c[y>>2]|0,48,2457432,(q=i,i=i+16|0,c[q>>2]=$,c[q+8>>2]=z,q)|0);i=q;aa=z}else{aa=$}P=aa+g|0;if((A|0)<=(P|0)){R=A;do{N=a+27616+(h<<8)+(R<<2)|0;c[N>>2]=(c[N>>2]|0)-1;R=R+1|0;}while((R|0)<=(P|0))}P=F+1|0;if((P|0)<(m|0)){F=P;G=H}else{I=H;J=B;K=E;break a}}P=c[1510768+(V<<2)>>2]|0;if((V-3|0)>>>0<4>>>0){R=c[1510736+(V<<2)>>2]|0;N=M+(Y>>>3)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(Y&7)>>>((32-R|0)>>>0);N=R+Y|0;c[s>>2]=L>>>0>N>>>0?N:L;ba=O+P|0}else{ba=P}ca=m-F|0;if((ba|0)>(ca|0)){da=16;break}b[n+(G<<1)>>1]=ba<<2;P=ba+F|0;O=G+1|0;N=ba+B|0;if((P|0)<(m|0)){B=N;C=P;D=O;E=0}else{I=O;J=N;K=0;break a}}if((da|0)==16){b[n+(G<<1)>>1]=ca<<2;I=G+1|0;J=ca+B|0;K=ba-ca|0;break}KIb(c[y>>2]|0,16,2440768,(q=i,i=i+8|0,c[q>>2]=V,q)|0);i=q;ea=-1;i=k;return ea|0}else{I=u;J=v;K=t}}while(0);if((J|0)>(c[l>>2]|0)){KIb(c[a>>2]|0,16,2429144,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}do{if((J|0)!=0){q=g+1|0;if((q|0)<64){fa=q}else{break}do{q=a+27616+(h<<8)+(fa<<2)|0;c[q>>2]=(c[q>>2]|0)-J;fa=fa+1|0;}while((fa|0)<64)}}while(0);if((h|0)<2){c[a+26844+(h+1<<8)+(g<<2)>>2]=n+(I<<1);ea=K;i=k;return ea|0}if((g|0)>=63){ea=K;i=k;return ea|0}c[a+26844+(g+1<<2)>>2]=n+(I<<1);ea=K;i=k;return ea|0}function s9a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;k=i;i=i+8|0;l=k|0;b[l+4>>1]=0;b[l+2>>1]=0;b[l>>1]=0;if((j|0)<=0){i=k;return}m=(h|0)>0;n=f+688|0;f=0;o=0;p=0;q=0;r=g;g=0;while(1){if(m){s=(g|0)==0;t=c[n>>2]|0;u=f;v=o;w=p;x=q;y=r;z=0;while(1){A=a[t+(y<<2)+2|0]|0;if(A<<24>>24==8){B=x;C=w;D=v;E=u}else{F=a[679904+(A&255)|0]|0;A=F&255;G=(z|0)!=0;if(G){H=y-1|0;I=(a[679904+(d[t+(H<<2)+2|0]|0)|0]|0)==F<<24>>24|0;J=b[t+(H<<2)>>1]|0}else{I=0;J=x}do{if(s){K=I;L=w;M=v;N=u}else{H=y-h|0;O=b[t+(H<<2)>>1]|0;P=(a[679904+(d[t+(H<<2)+2|0]|0)|0]|0)==F<<24>>24?I|4:I;if(G){Q=H-1|0;R=(a[679904+(d[t+(Q<<2)+2|0]|0)|0]|0)==F<<24>>24?P|8:P;S=b[t+(Q<<2)>>1]|0}else{R=P;S=u}if((z+1|0)>=(h|0)){K=R;L=w;M=O;N=S;break}P=H+1|0;K=(a[679904+(d[t+(P<<2)+2|0]|0)|0]|0)==F<<24>>24?R|2:R;L=b[t+(P<<2)>>1]|0;M=O;N=S}}while(0);do{if((K|0)==0){T=b[l+(A<<1)>>1]|0}else{F=ca(c[679648+(K<<4)>>2]|0,N)|0;G=(ca(c[679652+(K<<4)>>2]|0,M)|0)+F|0;F=G+(ca(c[679656+(K<<4)>>2]|0,L)|0)|0;G=(F+(ca(c[679660+(K<<4)>>2]|0,J)|0)|0)/128|0;if(!((K|0)==15|(K|0)==13)){T=G;break}F=G-M|0;if((((F|0)>-1?F:-F|0)|0)>128){T=M;break}F=G-J|0;if((((F|0)>-1?F:-F|0)|0)>128){T=J;break}F=G-N|0;T=(((F|0)>-1?F:-F|0)|0)>128?N:G}}while(0);G=t+(y<<2)|0;F=(e[G>>1]|0)+T&65535;b[G>>1]=F;b[l+(A<<1)>>1]=F;B=J;C=L;D=M;E=N}F=z+1|0;if((F|0)<(h|0)){u=E;v=D;w=C;x=B;y=y+1|0;z=F}else{break}}U=E;V=D;W=C;X=B;Y=r+h|0}else{U=f;V=o;W=p;X=q;Y=r}z=g+1|0;if((z|0)<(j|0)){f=U;o=V;p=W;q=X;r=Y;g=z}else{break}}i=k;return}function t9a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[a+60>>2]|0;g=b+8|0;h=c[g>>2]|0;j=c[b>>2]|0;k=d[j+(h>>>3)|0]|0;l=c[b+16>>2]|0;m=((h|0)<(l|0))+h|0;c[g>>2]=m;if((k&128>>>((h&7)>>>0)|0)!=0){h=f+32404|0;if((c[h>>2]|0)>31){KIb(a,16,2352976,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=e;return o|0}else{k=j+(m>>>3)|0;j=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(m&7)>>>27;k=m+5|0;c[g>>2]=l>>>0>k>>>0?k:l;l=f+32396|0;k=f+32412|0;c[k+(c[l>>2]<<8)+(j<<3)>>2]=c[f+32400>>2];c[k+(c[l>>2]<<8)+(j<<3)+4>>2]=c[f+32408>>2];c[h>>2]=(c[h>>2]|0)+1;o=0;i=e;return o|0}}h=f+32408|0;j=c[h>>2]|0;if((j|0)>31){KIb(a,16,2352976,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1;i=e;return o|0}c[h>>2]=j+1;j=f+32400|0;c[j>>2]=c[j>>2]<<1;if((t9a(a,b)|0)!=0){o=-1;i=e;return o|0}c[j>>2]=c[j>>2]|1;if((t9a(a,b)|0)!=0){o=-1;i=e;return o|0}c[j>>2]=(c[j>>2]|0)>>>1;c[h>>2]=(c[h>>2]|0)-1;o=0;i=e;return o|0}function u9a(a,b){a=a|0;b=b|0;c[a>>2]=18;c[a+4>>2]=2328;c[a+8>>2]=1792;c[a+12>>2]=160;c[a+16>>2]=402;c[a+20>>2]=54;return}function v9a(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((g|0)>0){h=0}else{return}do{i=ca(h,f)|0;j=b+i|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=e+i|0;l=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[a+i>>2]=((l^k)>>>1&2139062143)+(l&k);k=i+4|0;i=b+k|0;l=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=e+k|0;j=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;c[a+k>>2]=((j^l)>>>1&2139062143)+(j&l);h=h+1|0;}while((h|0)<(g|0));return}function w9a(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=e;g=0;while(1){h=b[f>>1]|0;i=h<<16>>16;j=f+16|0;k=b[j>>1]|0;l=k<<16>>16;m=f+32|0;n=b[m>>1]|0;o=n<<16>>16;p=f+48|0;q=b[p>>1]|0;r=q<<16>>16;s=f+64|0;t=b[s>>1]|0;u=t<<16>>16;v=f+80|0;w=b[v>>1]|0;x=w<<16>>16;y=f+96|0;z=b[y>>1]|0;A=z<<16>>16;B=f+112|0;C=b[B>>1]|0;D=C<<16>>16;if(!((k|h|n|q|t|w|z|C)<<16>>16==0)){C=((D*12785|0)>>16)+((l*64277|0)>>16)|0;z=((l*12785|0)>>16)-((D*64277|0)>>16)|0;D=((x*36410|0)>>16)+((r*54491|0)>>16)|0;l=((x*54491|0)>>16)-((r*36410|0)>>16)|0;r=((C-D|0)*46341|0)>>16;x=((z-l|0)*46341|0)>>16;w=C+D|0;D=z+l|0;l=((u+i|0)*46341|0)>>16;z=((i-u|0)*46341|0)>>16;u=((A*25080|0)>>16)+((o*60547|0)>>16)|0;i=((o*25080|0)>>16)-((A*60547|0)>>16)|0;A=l-u|0;o=u+l|0;l=r+z|0;u=x-i|0;C=z-r|0;r=x+i|0;b[f>>1]=w+o;b[B>>1]=o-w;b[j>>1]=l+r;b[m>>1]=l-r;b[p>>1]=D+A;b[s>>1]=A-D;b[v>>1]=C+u;b[y>>1]=C-u}u=g+1|0;if((u|0)<8){f=f+2|0;g=u}else{break}}g=d*7|0;f=d*6|0;u=d*5|0;C=d<<2;y=d*3|0;v=d<<1;D=e;A=0;s=c;while(1){c=b[D+2>>1]|0;p=c<<16>>16;r=b[D+4>>1]|0;l=b[D+6>>1]|0;m=l<<16>>16;j=b[D+8>>1]|0;w=j<<16>>16;o=b[D+10>>1]|0;B=o<<16>>16;i=b[D+12>>1]|0;x=b[D+14>>1]|0;z=x<<16>>16;if((r|c|l|j|o|i|x)<<16>>16==0){x=((b[D>>1]|0)*46341|0)+524288>>20;o=x+128|0;if(o>>>0>255>>>0){E=-128-x>>31&255}else{E=o&255}a[s+g|0]=E;a[s+f|0]=E;a[s+u|0]=E;a[s+C|0]=E;a[s+y|0]=E;a[s+v|0]=E;a[s+d|0]=E;a[s]=E}else{o=((z*12785|0)>>16)+((p*64277|0)>>16)|0;x=((p*12785|0)>>16)-((z*64277|0)>>16)|0;z=((B*36410|0)>>16)+((m*54491|0)>>16)|0;p=((B*54491|0)>>16)-((m*36410|0)>>16)|0;m=((o-z|0)*46341|0)>>16;B=((x-p|0)*46341|0)>>16;j=o+z|0;z=x+p|0;p=b[D>>1]|0;x=(((p+w|0)*46341|0)>>16)+2056|0;o=(((p-w|0)*46341|0)>>16)+2056|0;w=r<<16>>16;r=i<<16>>16;i=((r*25080|0)>>16)+((w*60547|0)>>16)|0;p=((w*25080|0)>>16)-((r*60547|0)>>16)|0;r=x-i|0;w=x+i|0;i=o+m|0;x=B-p|0;l=o-m|0;m=B+p|0;p=w+j>>4;if(p>>>0>255>>>0){F=-p>>31&255}else{F=p&255}a[s]=F;p=w-j>>4;if(p>>>0>255>>>0){G=-p>>31&255}else{G=p&255}a[s+g|0]=G;p=i+m>>4;if(p>>>0>255>>>0){H=-p>>31&255}else{H=p&255}a[s+d|0]=H;p=i-m>>4;if(p>>>0>255>>>0){I=-p>>31&255}else{I=p&255}a[s+v|0]=I;p=r+z>>4;if(p>>>0>255>>>0){J=-p>>31&255}else{J=p&255}a[s+y|0]=J;p=r-z>>4;if(p>>>0>255>>>0){K=-p>>31&255}else{K=p&255}a[s+C|0]=K;p=l+x>>4;if(p>>>0>255>>>0){L=-p>>31&255}else{L=p&255}a[s+u|0]=L;p=l-x>>4;if(p>>>0>255>>>0){M=-p>>31&255}else{M=p&255}a[s+f|0]=M}p=A+1|0;if((p|0)<8){D=D+16|0;A=p;s=s+1|0}else{break}}mrc(e|0,0,128)|0;return}function x9a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=f;h=0;while(1){i=b[g>>1]|0;j=i<<16>>16;k=g+16|0;l=b[k>>1]|0;m=l<<16>>16;n=g+32|0;o=b[n>>1]|0;p=o<<16>>16;q=g+48|0;r=b[q>>1]|0;s=r<<16>>16;t=g+64|0;u=b[t>>1]|0;v=u<<16>>16;w=g+80|0;x=b[w>>1]|0;y=x<<16>>16;z=g+96|0;A=b[z>>1]|0;B=A<<16>>16;C=g+112|0;D=b[C>>1]|0;E=D<<16>>16;if(!((l|i|o|r|u|x|A|D)<<16>>16==0)){D=((E*12785|0)>>16)+((m*64277|0)>>16)|0;A=((m*12785|0)>>16)-((E*64277|0)>>16)|0;E=((y*36410|0)>>16)+((s*54491|0)>>16)|0;m=((y*54491|0)>>16)-((s*36410|0)>>16)|0;s=((D-E|0)*46341|0)>>16;y=((A-m|0)*46341|0)>>16;x=D+E|0;E=A+m|0;m=((v+j|0)*46341|0)>>16;A=((j-v|0)*46341|0)>>16;v=((B*25080|0)>>16)+((p*60547|0)>>16)|0;j=((p*25080|0)>>16)-((B*60547|0)>>16)|0;B=m-v|0;p=v+m|0;m=s+A|0;v=y-j|0;D=A-s|0;s=y+j|0;b[g>>1]=x+p;b[C>>1]=p-x;b[k>>1]=m+s;b[n>>1]=m-s;b[q>>1]=E+B;b[t>>1]=B-E;b[w>>1]=D+v;b[z>>1]=D-v}v=h+1|0;if((v|0)<8){g=g+2|0;h=v}else{break}}h=e*7|0;g=e*6|0;v=e*5|0;D=e<<2;z=e*3|0;w=e<<1;E=f;B=0;t=c;while(1){c=b[E+2>>1]|0;q=c<<16>>16;s=b[E+4>>1]|0;m=b[E+6>>1]|0;n=m<<16>>16;k=b[E+8>>1]|0;x=k<<16>>16;p=b[E+10>>1]|0;C=p<<16>>16;j=b[E+12>>1]|0;y=b[E+14>>1]|0;A=y<<16>>16;do{if((s|c|m|k|p|j|y)<<16>>16==0){u=b[E>>1]|0;if(u<<16>>16==0){break}r=((u<<16>>16)*46341|0)+524288>>20;u=(d[t]|0)+r|0;if(u>>>0>255>>>0){F=-u>>31&255}else{F=u&255}a[t]=F;u=t+e|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){G=-o>>31&255}else{G=o&255}a[u]=G;u=t+w|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){H=-o>>31&255}else{H=o&255}a[u]=H;u=t+z|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){I=-o>>31&255}else{I=o&255}a[u]=I;u=t+D|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){J=-o>>31&255}else{J=o&255}a[u]=J;u=t+v|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){K=-o>>31&255}else{K=o&255}a[u]=K;u=t+g|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){L=-o>>31&255}else{L=o&255}a[u]=L;u=t+h|0;o=(d[u]|0)+r|0;if(o>>>0>255>>>0){M=-o>>31&255}else{M=o&255}a[u]=M}else{u=((A*12785|0)>>16)+((q*64277|0)>>16)|0;o=((q*12785|0)>>16)-((A*64277|0)>>16)|0;r=((C*36410|0)>>16)+((n*54491|0)>>16)|0;i=((C*54491|0)>>16)-((n*36410|0)>>16)|0;l=((u-r|0)*46341|0)>>16;N=((o-i|0)*46341|0)>>16;O=u+r|0;r=o+i|0;i=b[E>>1]|0;o=(((i+x|0)*46341|0)>>16)+8|0;u=(((i-x|0)*46341|0)>>16)+8|0;i=s<<16>>16;P=j<<16>>16;Q=((P*25080|0)>>16)+((i*60547|0)>>16)|0;R=((i*25080|0)>>16)-((P*60547|0)>>16)|0;P=o-Q|0;i=o+Q|0;Q=u+l|0;o=N-R|0;S=u-l|0;l=N+R|0;R=(i+O>>4)+(d[t]|0)|0;if(R>>>0>255>>>0){T=-R>>31&255}else{T=R&255}a[t]=T;R=t+h|0;N=(d[R]|0)+(i-O>>4)|0;if(N>>>0>255>>>0){U=-N>>31&255}else{U=N&255}a[R]=U;R=t+e|0;N=(d[R]|0)+(Q+l>>4)|0;if(N>>>0>255>>>0){V=-N>>31&255}else{V=N&255}a[R]=V;R=t+w|0;N=(d[R]|0)+(Q-l>>4)|0;if(N>>>0>255>>>0){W=-N>>31&255}else{W=N&255}a[R]=W;R=t+z|0;N=(d[R]|0)+(P+r>>4)|0;if(N>>>0>255>>>0){X=-N>>31&255}else{X=N&255}a[R]=X;R=t+D|0;N=(d[R]|0)+(P-r>>4)|0;if(N>>>0>255>>>0){Y=-N>>31&255}else{Y=N&255}a[R]=Y;R=t+v|0;N=(d[R]|0)+(S+o>>4)|0;if(N>>>0>255>>>0){Z=-N>>31&255}else{Z=N&255}a[R]=Z;R=t+g|0;N=(d[R]|0)+(S-o>>4)|0;if(N>>>0>255>>>0){_=-N>>31&255}else{_=N&255}a[R]=_}}while(0);j=B+1|0;if((j|0)<8){E=E+16|0;B=j;t=t+1|0}else{break}}mrc(f|0,0,128)|0;return}function y9a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=(b[f>>1]|0)+15>>5;h=0;i=c;while(1){c=(d[i]|0)+g|0;if(c>>>0>255>>>0){j=-c>>31&255}else{j=c&255}a[i]=j;c=i+1|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){l=-k>>31&255}else{l=k&255}a[c]=l;c=i+2|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){m=-k>>31&255}else{m=k&255}a[c]=m;c=i+3|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){n=-k>>31&255}else{n=k&255}a[c]=n;c=i+4|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){o=-k>>31&255}else{o=k&255}a[c]=o;c=i+5|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){p=-k>>31&255}else{p=k&255}a[c]=p;c=i+6|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){q=-k>>31&255}else{q=k&255}a[c]=q;c=i+7|0;k=(d[c]|0)+g|0;if(k>>>0>255>>>0){r=-k>>31&255}else{r=k&255}a[c]=r;c=h+1|0;if((c|0)<8){h=c;i=i+e|0}else{break}}b[f>>1]=0;return}function z9a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=-e|0;h=b+8|0;i=g<<1;j=b;do{b=j+g|0;k=d[b]|0;l=c[f+((d[j+i|0]|0)+4-(d[j+e|0]|0)+(((d[j]|0)-k|0)*3|0)>>3<<2)>>2]|0;m=k+l|0;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[b]=n;b=(d[j]|0)-l|0;if(b>>>0>255>>>0){o=-b>>31&255}else{o=b&255}a[j]=o;j=j+1|0;}while(j>>>0<h>>>0);return}function A9a(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=e<<3;h=b+g|0;if((g|0)==0){return}else{i=b}do{b=d[i]|0;g=i-1|0;j=d[g]|0;k=c[f+((d[i-2|0]|0)+4-(d[i+1|0]|0)+((b-j|0)*3|0)>>3<<2)>>2]|0;l=j+k|0;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[g]=m;g=b-k|0;if(g>>>0>255>>>0){n=-g>>31&255}else{n=g&255}a[i]=n;i=i+e|0;}while((i|0)!=(h|0));return}function B9a(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=L9a(a,1,0)|0;if((d|0)<0){e=d;return e|0}c[b+1728>>2]=252504;c[b+1732>>2]=284;c[b+1740>>2]=198;c[b+1744>>2]=380;c[b+1748>>2]=568;c[b+1752>>2]=1264;c[b+1756>>2]=454;e=0;return e|0}function C9a(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;g=c[e+1764>>2]|0;h=e+376|0;i=e+380|0;j=e+392|0;k=e+384|0;l=e+388|0;e=a[1251752]|0;m=e<<24>>24>0;n=f|0;o=f+2|0;f=0;p=c[h>>2]|0;q=c[i>>2]|0;r=c[j>>2]|0;while(1){s=a[g+130+f|0]|0;t=d[1252840+p|0]|0;u=p<<t;c[h>>2]=u;v=r<<t;w=q+t|0;do{if((w|0)>-1){t=c[k>>2]|0;if(!(t>>>0<(c[l>>2]|0)>>>0)){x=v;y=w;break}c[k>>2]=t+2;z=t;x=((he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<w|v;y=w-16|0}else{x=v;y=w}}while(0);c[i>>2]=y;w=((ca(u-1|0,s&255)|0)>>8)+1|0;v=w<<16;z=x>>>0>=v>>>0;t=z?u-w|0:w;c[h>>2]=t;w=x-(z?v:0)|0;c[j>>2]=w;if(z){z=a[g+128+f|0]|0;v=d[1252840+t|0]|0;A=t<<v;c[h>>2]=A;B=w<<v;C=y+v|0;do{if((C|0)>-1){v=c[k>>2]|0;if(!(v>>>0<(c[l>>2]|0)>>>0)){D=B;E=C;break}c[k>>2]=v+2;F=v;D=((he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<C|B;E=C-16|0}else{D=B;E=C}}while(0);c[i>>2]=E;C=((ca(A-1|0,z&255)|0)>>8)+1|0;B=C<<16;u=D>>>0>=B>>>0;s=u&1;F=u?A-C|0:C;c[h>>2]=F;C=D-(u?B:0)|0;c[j>>2]=C;B=a[g+132+(f<<1)|0]|0;u=d[1252840+F|0]|0;v=F<<u;c[h>>2]=v;F=C<<u;C=E+u|0;do{if((C|0)>-1){u=c[k>>2]|0;if(!(u>>>0<(c[l>>2]|0)>>>0)){G=F;H=C;break}c[k>>2]=u+2;I=u;G=((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)<<C|F;H=C-16|0}else{G=F;H=C}}while(0);c[i>>2]=H;C=((ca(v-1|0,B&255)|0)>>8)+1|0;F=C<<16;A=G>>>0>=F>>>0;z=A&1;I=A?v-C|0:C;c[h>>2]=I;C=G-(A?F:0)|0;c[j>>2]=C;F=a[g+132+(f<<1)+1|0]|0;A=d[1252840+I|0]|0;u=I<<A;c[h>>2]=u;I=C<<A;C=H+A|0;do{if((C|0)>-1){A=c[k>>2]|0;if(!(A>>>0<(c[l>>2]|0)>>>0)){J=I;K=C;break}c[k>>2]=A+2;L=A;J=((he((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<C|I;K=C-16|0}else{J=I;K=C}}while(0);c[i>>2]=K;C=((ca(u-1|0,F&255)|0)>>8)+1|0;I=C<<16;v=J>>>0>=I>>>0;B=v?u-C|0:C;c[h>>2]=B;C=J-(v?I:0)|0;c[j>>2]=C;I=(v&1)<<1|z;if(m){v=1251752;L=1251752;A=B;M=K;N=C;while(1){O=a[(a[v+1|0]|0)+(g+136+(f*7|0))|0]|0;P=d[1252840+A|0]|0;Q=A<<P;c[h>>2]=Q;R=N<<P;S=P+M|0;do{if((S|0)>-1){P=c[k>>2]|0;if(!(P>>>0<(c[l>>2]|0)>>>0)){T=R;U=S;break}c[k>>2]=P+2;V=P;T=((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<S|R;U=S-16|0}else{T=R;U=S}}while(0);c[i>>2]=U;S=((ca(Q-1|0,O&255)|0)>>8)+1|0;R=S<<16;V=T>>>0>=R>>>0;P=V?Q-S|0:S;c[h>>2]=P;S=T-(V?R:0)|0;c[j>>2]=S;if(V){W=v+(a[L]<<1)|0}else{W=v+2|0}V=W|0;R=a[V]|0;if(R<<24>>24>0){v=W;L=V;A=P;M=U;N=S}else{X=R;Y=P;Z=U;_=S;break}}}else{X=e;Y=B;Z=K;_=C}$=((I|-(X<<24>>24)<<2)^-s)+s&65535;aa=Y;ba=Z;da=_}else{$=0;aa=t;ba=y;da=w}if((f|0)==0){b[n>>1]=$;f=f+1|0;p=aa;q=ba;r=da;continue}else{b[o>>1]=$;N=f+1|0;if((N|0)<2){f=N;p=aa;q=ba;r=da;continue}else{break}}}return}function D9a(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;g=c[f+1764>>2]|0;h=f+500|0;i=f+376|0;j=f+380|0;k=f+392|0;l=f+384|0;m=f+388|0;n=a[1252816]|0;o=n<<24>>24>0;p=f+498|0;q=0;r=0;do{r=(q|0)>3?1:r;s=a[1253416+q|0]|0;t=s&255;u=f+1436+(t<<6)|0;v=f+552+(q<<2)|0;w=1;x=g+166+(r*11|0)|0;y=g+1124+(r*180|0)+(((d[(c[h>>2]|0)+((c[v>>2]|0)*12|0)|0]|0)+((d[u]|0)*6|0)|0)*5|0)|0;z=0;while(1){A=a[y]|0;B=c[i>>2]|0;C=d[1252840+B|0]|0;D=c[j>>2]|0;E=c[k>>2]|0;F=B<<C;c[i>>2]=F;B=E<<C;E=D+C|0;do{if((E|0)>-1){C=c[l>>2]|0;if(!(C>>>0<(c[m>>2]|0)>>>0)){G=B;H=E;break}c[l>>2]=C+2;D=C;G=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<E|B;H=E-16|0}else{G=B;H=E}}while(0);c[j>>2]=H;E=((ca(F-1|0,A&255)|0)>>8)+1|0;B=E<<16;D=G>>>0>=B>>>0;C=D?F-E|0:E;c[i>>2]=C;E=G-(D?B:0)|0;c[k>>2]=E;if(D){D=a[y+2|0]|0;B=d[1252840+C|0]|0;I=C<<B;c[i>>2]=I;J=E<<B;K=H+B|0;do{if((K|0)>-1){B=c[l>>2]|0;if(!(B>>>0<(c[m>>2]|0)>>>0)){L=J;M=K;break}c[l>>2]=B+2;N=B;L=((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<K|J;M=K-16|0}else{L=J;M=K}}while(0);c[j>>2]=M;K=((ca(I-1|0,D&255)|0)>>8)+1|0;J=K<<16;F=L>>>0>=J>>>0;A=F?I-K|0:K;c[i>>2]=A;K=L-(F?J:0)|0;c[k>>2]=K;do{if(F){J=a[y+3|0]|0;N=d[1252840+A|0]|0;B=A<<N;c[i>>2]=B;O=K<<N;P=M+N|0;do{if((P|0)>-1){N=c[l>>2]|0;if(!(N>>>0<(c[m>>2]|0)>>>0)){Q=O;R=P;break}c[l>>2]=N+2;S=N;Q=((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)<<P|O;R=P-16|0}else{Q=O;R=P}}while(0);c[j>>2]=R;P=((ca(B-1|0,J&255)|0)>>8)+1|0;O=P<<16;S=Q>>>0>=O>>>0;N=S?B-P|0:P;c[i>>2]=N;P=Q-(S?O:0)|0;c[k>>2]=P;if(!S){S=a[y+4|0]|0;O=d[1252840+N|0]|0;T=N<<O;c[i>>2]=T;N=P<<O;P=R+O|0;do{if((P|0)>-1){O=c[l>>2]|0;if(!(O>>>0<(c[m>>2]|0)>>>0)){U=N;V=P;break}c[l>>2]=O+2;W=O;U=((he((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<P|N;V=P-16|0}else{U=N;V=P}}while(0);c[j>>2]=V;P=((ca(T-1|0,S&255)|0)>>8)+1|0;N=P<<16;B=U>>>0>=N>>>0;J=B?T-P|0:P;c[i>>2]=J;P=U-(B?N:0)|0;c[k>>2]=P;if(B){B=a[x+5|0]|0;N=d[1252840+J|0]|0;W=J<<N;c[i>>2]=W;J=P<<N;P=V+N|0;do{if((P|0)>-1){N=c[l>>2]|0;if(!(N>>>0<(c[m>>2]|0)>>>0)){X=J;Y=P;break}c[l>>2]=N+2;O=N;X=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<P|J;Y=P-16|0}else{X=J;Y=P}}while(0);c[j>>2]=Y;P=((ca(W-1|0,B&255)|0)>>8)+1|0;J=P<<16;T=X>>>0>=J>>>0;c[i>>2]=T?W-P|0:P;c[k>>2]=X-(T?J:0);a[f+1436+((s&255)<<6)+z|0]=3;Z=T?4:3}else{a[f+1436+((s&255)<<6)+z|0]=2;Z=2}T=c[i>>2]|0;J=d[1252840+T|0]|0;P=c[j>>2]|0;S=c[k>>2]|0;O=T<<J;c[i>>2]=O;T=S<<J;S=P+J|0;do{if((S|0)>-1){J=c[l>>2]|0;if(!(J>>>0<(c[m>>2]|0)>>>0)){_=T;$=S;break}c[l>>2]=J+2;P=J;_=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<S|T;$=S-16|0}else{_=T;$=S}}while(0);c[j>>2]=$;S=O+1>>1;T=S<<16;W=_>>>0>=T>>>0;if(W){c[i>>2]=O-S;aa=_-T|0}else{c[i>>2]=S;aa=_}c[k>>2]=aa;ba=2;da=Z;ea=W;break}a[f+1436+((s&255)<<6)+z|0]=4;W=c[i>>2]|0;S=c[j>>2]|0;T=c[k>>2]|0;if(o){B=1252816;P=1252816;J=W;N=S;fa=T;while(1){ga=a[x+(a[B+1|0]|0)|0]|0;ha=d[1252840+J|0]|0;ia=J<<ha;c[i>>2]=ia;ja=fa<<ha;ka=ha+N|0;do{if((ka|0)>-1){ha=c[l>>2]|0;if(!(ha>>>0<(c[m>>2]|0)>>>0)){la=ja;ma=ka;break}c[l>>2]=ha+2;na=ha;la=((he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ka|ja;ma=ka-16|0}else{la=ja;ma=ka}}while(0);c[j>>2]=ma;ka=((ca(ia-1|0,ga&255)|0)>>8)+1|0;ja=ka<<16;na=la>>>0>=ja>>>0;ha=na?ia-ka|0:ka;c[i>>2]=ha;ka=la-(na?ja:0)|0;c[k>>2]=ka;if(na){oa=B+(a[P]<<1)|0}else{oa=B+2|0}na=oa|0;ja=a[na]|0;if(ja<<24>>24>0){B=oa;P=na;J=ha;N=ma;fa=ka}else{pa=ja;qa=ha;ra=ma;sa=ka;break}}}else{pa=n;qa=W;ra=S;sa=T}fa=pa<<24>>24;N=-fa|0;J=d[1252840+qa|0]|0;P=qa<<J;c[i>>2]=P;B=sa<<J;O=ra+J|0;do{if((O|0)>-1){J=c[l>>2]|0;if(!(J>>>0<(c[m>>2]|0)>>>0)){ta=B;ua=O;break}c[l>>2]=J+2;ka=J;ta=((he((d[ka]|d[ka+1|0]<<8)<<16>>16|0)|0)&65535)<<O|B;ua=O-16|0}else{ta=B;ua=O}}while(0);c[j>>2]=ua;O=P+1>>1;B=O<<16;T=ta>>>0>=B>>>0;if(T){S=P-O|0;c[i>>2]=S;va=ta-B|0;wa=S}else{c[i>>2]=O;va=ta;wa=O}c[k>>2]=va;O=d[1253368+N|0]|0;S=d[1253376+(5-fa)|0]|0;B=wa;W=ua;ka=va;while(1){J=a[1253296+(N*11|0)+O|0]|0;ha=d[1252840+B|0]|0;ja=B<<ha;c[i>>2]=ja;na=ka<<ha;xa=W+ha|0;do{if((xa|0)>-1){ha=c[l>>2]|0;if(!(ha>>>0<(c[m>>2]|0)>>>0)){ya=na;za=xa;break}c[l>>2]=ha+2;Aa=ha;ya=((he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<xa|na;za=xa-16|0}else{ya=na;za=xa}}while(0);c[j>>2]=za;xa=((ca(ja-1|0,J&255)|0)>>8)+1|0;na=xa<<16;ia=ya>>>0>=na>>>0;ga=ia?ja-xa|0:xa;c[i>>2]=ga;xa=ya-(ia?na:0)|0;c[k>>2]=xa;na=((ia&1)<<O)+S|0;if((O|0)>0){O=O-1|0;S=na;B=ga;W=za;ka=xa}else{ba=2;da=na;ea=T;break}}}else{a[f+1436+((s&255)<<6)+z|0]=1;T=c[i>>2]|0;ka=d[1252840+T|0]|0;W=c[j>>2]|0;B=c[k>>2]|0;S=T<<ka;c[i>>2]=S;T=B<<ka;B=W+ka|0;do{if((B|0)>-1){ka=c[l>>2]|0;if(!(ka>>>0<(c[m>>2]|0)>>>0)){Ba=T;Ca=B;break}c[l>>2]=ka+2;W=ka;Ba=((he((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<B|T;Ca=B-16|0}else{Ba=T;Ca=B}}while(0);c[j>>2]=Ca;B=S+1>>1;T=B<<16;W=Ba>>>0>=T>>>0;if(W){c[i>>2]=S-B;Da=Ba-T|0}else{c[i>>2]=B;Da=Ba}c[k>>2]=Da;ba=1;da=1;ea=W}}while(0);K=ea&1;A=(da^-K)+K|0;if((z|0)==0){Ea=A&65535}else{Ea=(ca(e[p>>1]|0,A)|0)&65535}b[f+608+(q<<7)+(d[f+288+z|0]<<1)>>1]=Ea;Fa=ba}else{if((w|0)!=0){A=a[y+1|0]|0;K=d[1252840+C|0]|0;F=C<<K;c[i>>2]=F;I=E<<K;D=H+K|0;do{if((D|0)>-1){K=c[l>>2]|0;if(!(K>>>0<(c[m>>2]|0)>>>0)){Ga=I;Ha=D;break}c[l>>2]=K+2;W=K;Ga=((he((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<D|I;Ha=D-16|0}else{Ga=I;Ha=D}}while(0);c[j>>2]=Ha;D=((ca(F-1|0,A&255)|0)>>8)+1|0;I=D<<16;E=Ga>>>0>=I>>>0;c[i>>2]=E?F-D|0:D;c[k>>2]=Ga-(E?I:0);if(!E){Ia=z;break}}a[f+1436+(t<<6)+z|0]=0;Fa=0}E=z+1|0;if((E|0)>63){Ia=E;break}I=d[252512+E|0]|0;D=g+188+(r*198|0)+(Fa*66|0)+(I*11|0)|0;if(z>>>0>22>>>0){w=Fa;x=D;y=D;z=E;continue}w=Fa;x=D;y=g+584+(r*270|0)+(Fa*90|0)+(I*30|0)+((d[f+1436+(t<<6)+E|0]|0)*5|0)|0;z=E}z=f+1692+t|0;y=a[z]|0;x=(y&255)>>>0>24>>>0?24:y&255;a[z]=Ia;if((Ia|0)<(x|0)){mrc(Ia+(t<<6)+(f+1436)|0,5,x+1-Ia|0)|0}a[(c[h>>2]|0)+((c[v>>2]|0)*12|0)|0]=a[u]|0;q=q+1|0;}while((q|0)<6);return}function E9a(b){b=b|0;var d=0;d=c[b+1764>>2]|0;a[d+128|0]=-128;a[d+130|0]=-128;a[d+132|0]=85;a[d+133|0]=-128;a[d+129|0]=-128;a[d+131|0]=-128;a[d+134|0]=85;a[d+135|0]=-128;nrc(d+1812|0,1253168,60)|0;mrc(d+136|0,-128|0,14)|0;return}function F9a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;e=c[b+1764>>2]|0;f=b+376|0;g=b+380|0;h=b+392|0;i=b+384|0;j=b+388|0;b=0;while(1){k=a[250256+(b*11|0)|0]|0;l=c[f>>2]|0;m=d[1252840+l|0]|0;n=c[g>>2]|0;o=c[h>>2]|0;p=l<<m;c[f>>2]=p;l=o<<m;o=n+m|0;do{if((o|0)>-1){m=c[i>>2]|0;if(!(m>>>0<(c[j>>2]|0)>>>0)){q=l;r=o;break}c[i>>2]=m+2;n=m;q=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<o|l;r=o-16|0}else{q=l;r=o}}while(0);c[g>>2]=r;o=((ca(p-1|0,k&255)|0)>>8)+1|0;l=o<<16;n=q>>>0>=l>>>0;m=n?p-o|0:o;c[f>>2]=m;o=q-(n?l:0)|0;c[h>>2]=o;if(n){n=7;l=0;s=m;t=r;u=o;while(1){v=n-1|0;w=l<<1;x=d[1252840+s|0]|0;y=s<<x;c[f>>2]=y;z=u<<x;A=x+t|0;do{if((A|0)>-1){x=c[i>>2]|0;if(!(x>>>0<(c[j>>2]|0)>>>0)){B=z;C=A;break}c[i>>2]=x+2;D=x;B=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<A|z;C=A-16|0}else{B=z;C=A}}while(0);c[g>>2]=C;A=y+1>>1;z=A<<16;D=B>>>0>=z>>>0;if(D){x=y-A|0;c[f>>2]=x;E=B-z|0;F=x}else{c[f>>2]=A;E=B;F=A}c[h>>2]=E;G=D&1|w;if((v|0)==0){break}else{n=v;l=G;s=F;t=C;u=E}}u=G<<1;a[e+130+b|0]=(u|0)==0|u;H=c[f>>2]|0;I=c[g>>2]|0;J=c[h>>2]|0}else{H=m;I=r;J=o}u=a[250257+(b*11|0)|0]|0;t=d[1252840+H|0]|0;s=H<<t;c[f>>2]=s;l=J<<t;n=I+t|0;do{if((n|0)>-1){t=c[i>>2]|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){K=l;L=n;break}c[i>>2]=t+2;p=t;K=((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)<<n|l;L=n-16|0}else{K=l;L=n}}while(0);c[g>>2]=L;n=((ca(s-1|0,u&255)|0)>>8)+1|0;l=n<<16;o=K>>>0>=l>>>0;m=o?s-n|0:n;c[f>>2]=m;n=K-(o?l:0)|0;c[h>>2]=n;if(o){o=7;l=0;p=m;t=L;k=n;while(1){D=o-1|0;A=l<<1;x=d[1252840+p|0]|0;z=p<<x;c[f>>2]=z;M=k<<x;N=x+t|0;do{if((N|0)>-1){x=c[i>>2]|0;if(!(x>>>0<(c[j>>2]|0)>>>0)){O=M;P=N;break}c[i>>2]=x+2;Q=x;O=((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<N|M;P=N-16|0}else{O=M;P=N}}while(0);c[g>>2]=P;N=z+1>>1;M=N<<16;v=O>>>0>=M>>>0;if(v){w=z-N|0;c[f>>2]=w;R=O-M|0;S=w}else{c[f>>2]=N;R=O;S=N}c[h>>2]=R;T=v&1|A;if((D|0)==0){break}else{o=D;l=T;p=S;t=P;k=R}}k=T<<1;a[e+128+b|0]=(k|0)==0|k;U=c[f>>2]|0;V=c[g>>2]|0;W=c[h>>2]|0}else{U=m;V=L;W=n}k=a[250258+(b*11|0)|0]|0;t=d[1252840+U|0]|0;p=U<<t;c[f>>2]=p;l=W<<t;o=V+t|0;do{if((o|0)>-1){t=c[i>>2]|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){X=l;Y=o;break}c[i>>2]=t+2;s=t;X=((he((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<o|l;Y=o-16|0}else{X=l;Y=o}}while(0);c[g>>2]=Y;o=((ca(p-1|0,k&255)|0)>>8)+1|0;l=o<<16;n=X>>>0>=l>>>0;m=n?p-o|0:o;c[f>>2]=m;o=X-(n?l:0)|0;c[h>>2]=o;if(n){n=7;l=0;s=m;t=Y;u=o;while(1){v=n-1|0;N=l<<1;w=d[1252840+s|0]|0;M=s<<w;c[f>>2]=M;y=u<<w;Q=w+t|0;do{if((Q|0)>-1){w=c[i>>2]|0;if(!(w>>>0<(c[j>>2]|0)>>>0)){Z=y;_=Q;break}c[i>>2]=w+2;x=w;Z=((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<Q|y;_=Q-16|0}else{Z=y;_=Q}}while(0);c[g>>2]=_;Q=M+1>>1;y=Q<<16;D=Z>>>0>=y>>>0;if(D){A=M-Q|0;c[f>>2]=A;$=Z-y|0;aa=A}else{c[f>>2]=Q;$=Z;aa=Q}c[h>>2]=$;ba=D&1|N;if((v|0)==0){break}else{n=v;l=ba;s=aa;t=_;u=$}}u=ba<<1;a[e+132+(b<<1)|0]=(u|0)==0|u;da=c[f>>2]|0;ea=c[g>>2]|0;fa=c[h>>2]|0}else{da=m;ea=Y;fa=o}u=a[250259+(b*11|0)|0]|0;t=d[1252840+da|0]|0;s=da<<t;c[f>>2]=s;l=fa<<t;n=ea+t|0;do{if((n|0)>-1){t=c[i>>2]|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){ga=l;ha=n;break}c[i>>2]=t+2;p=t;ga=((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)<<n|l;ha=n-16|0}else{ga=l;ha=n}}while(0);c[g>>2]=ha;n=((ca(s-1|0,u&255)|0)>>8)+1|0;l=n<<16;o=ga>>>0>=l>>>0;m=o?s-n|0:n;c[f>>2]=m;n=ga-(o?l:0)|0;c[h>>2]=n;if(o){o=7;l=0;p=m;m=ha;t=n;while(1){n=o-1|0;k=l<<1;D=d[1252840+p|0]|0;Q=p<<D;c[f>>2]=Q;A=t<<D;y=D+m|0;do{if((y|0)>-1){D=c[i>>2]|0;if(!(D>>>0<(c[j>>2]|0)>>>0)){ia=A;ja=y;break}c[i>>2]=D+2;z=D;ia=((he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<y|A;ja=y-16|0}else{ia=A;ja=y}}while(0);c[g>>2]=ja;y=Q+1>>1;A=y<<16;v=ia>>>0>=A>>>0;if(v){N=Q-y|0;c[f>>2]=N;ka=ia-A|0;la=N}else{c[f>>2]=y;ka=ia;la=y}c[h>>2]=ka;ma=v&1|k;if((n|0)==0){break}else{o=n;l=ma;p=la;m=ja;t=ka}}t=ma<<1;a[e+132+(b<<1)+1|0]=(t|0)==0|t}t=b+1|0;if((t|0)<2){b=t}else{na=0;break}}do{b=0;do{ma=a[b+4+(250256+(na*11|0))|0]|0;ka=c[f>>2]|0;ja=d[1252840+ka|0]|0;la=c[g>>2]|0;ia=c[h>>2]|0;ha=ka<<ja;c[f>>2]=ha;ka=ia<<ja;ia=la+ja|0;do{if((ia|0)>-1){ja=c[i>>2]|0;if(!(ja>>>0<(c[j>>2]|0)>>>0)){oa=ka;pa=ia;break}c[i>>2]=ja+2;la=ja;oa=((he((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535)<<ia|ka;pa=ia-16|0}else{oa=ka;pa=ia}}while(0);c[g>>2]=pa;ia=((ca(ha-1|0,ma&255)|0)>>8)+1|0;ka=ia<<16;n=oa>>>0>=ka>>>0;k=n?ha-ia|0:ia;c[f>>2]=k;ia=oa-(n?ka:0)|0;c[h>>2]=ia;if(n){n=7;ka=0;Q=k;k=pa;la=ia;while(1){ia=n-1|0;ja=ka<<1;ga=d[1252840+Q|0]|0;ea=Q<<ga;c[f>>2]=ea;fa=la<<ga;da=ga+k|0;do{if((da|0)>-1){ga=c[i>>2]|0;if(!(ga>>>0<(c[j>>2]|0)>>>0)){qa=fa;ra=da;break}c[i>>2]=ga+2;Y=ga;qa=((he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<da|fa;ra=da-16|0}else{qa=fa;ra=da}}while(0);c[g>>2]=ra;da=ea+1>>1;fa=da<<16;Y=qa>>>0>=fa>>>0;if(Y){ga=ea-da|0;c[f>>2]=ga;sa=qa-fa|0;ta=ga}else{c[f>>2]=da;sa=qa;ta=da}c[h>>2]=sa;ua=Y&1|ja;if((ia|0)==0){break}else{n=ia;ka=ua;Q=ta;k=ra;la=sa}}la=ua<<1;a[e+136+(na*7|0)+b|0]=(la|0)==0|la}b=b+1|0;}while((b|0)<7);na=na+1|0;}while((na|0)<2);return}function G9a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;f=i;i=i+16|0;g=f|0;h=c[e+1764>>2]|0;mrc(g|0,-128|0,11)|0;j=e+376|0;k=e+380|0;l=e+392|0;m=e+384|0;n=e+388|0;o=e+352|0;e=0;while(1){p=0;do{q=a[251760+(e*11|0)+p|0]|0;r=c[j>>2]|0;s=d[1252840+r|0]|0;t=c[k>>2]|0;u=c[l>>2]|0;v=r<<s;c[j>>2]=v;r=u<<s;u=t+s|0;do{if((u|0)>-1){s=c[m>>2]|0;if(!(s>>>0<(c[n>>2]|0)>>>0)){w=r;x=u;break}c[m>>2]=s+2;t=s;w=((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<u|r;x=u-16|0}else{w=r;x=u}}while(0);c[k>>2]=x;u=((ca(v-1|0,q&255)|0)>>8)+1|0;r=u<<16;t=w>>>0>=r>>>0;s=t?v-u|0:u;c[j>>2]=s;u=w-(t?r:0)|0;c[l>>2]=u;do{if(t){r=7;y=0;z=s;A=x;B=u;while(1){C=r-1|0;D=y<<1;E=d[1252840+z|0]|0;F=z<<E;c[j>>2]=F;G=B<<E;H=E+A|0;do{if((H|0)>-1){E=c[m>>2]|0;if(!(E>>>0<(c[n>>2]|0)>>>0)){I=G;J=H;break}c[m>>2]=E+2;K=E;I=((he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535)<<H|G;J=H-16|0}else{I=G;J=H}}while(0);c[k>>2]=J;H=F+1>>1;G=H<<16;K=I>>>0>=G>>>0;if(K){E=F-H|0;c[j>>2]=E;L=I-G|0;M=E}else{c[j>>2]=H;L=I;M=H}c[l>>2]=L;N=K&1|D;if((C|0)==0){break}else{r=C;y=N;z=M;A=J;B=L}}B=N<<1;A=((B|0)==0|B)&255;a[g+p|0]=A;a[h+166+(e*11|0)+p|0]=A}else{if((c[(c[o>>2]|0)+84>>2]|0)==0){break}a[h+166+(e*11|0)+p|0]=a[g+p|0]|0}}while(0);p=p+1|0;}while((p|0)<11);p=e+1|0;if((p|0)<2){e=p}else{O=0;break}}while(1){e=0;do{N=0;do{L=0;do{J=a[250280+(O*132|0)+(e*66|0)+(N*11|0)+L|0]|0;M=c[j>>2]|0;I=d[1252840+M|0]|0;x=c[k>>2]|0;w=c[l>>2]|0;p=M<<I;c[j>>2]=p;M=w<<I;w=x+I|0;do{if((w|0)>-1){I=c[m>>2]|0;if(!(I>>>0<(c[n>>2]|0)>>>0)){P=M;Q=w;break}c[m>>2]=I+2;x=I;P=((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<w|M;Q=w-16|0}else{P=M;Q=w}}while(0);c[k>>2]=Q;w=((ca(p-1|0,J&255)|0)>>8)+1|0;M=w<<16;C=P>>>0>=M>>>0;D=C?p-w|0:w;c[j>>2]=D;w=P-(C?M:0)|0;c[l>>2]=w;do{if(C){M=7;F=0;x=D;I=Q;u=w;while(1){s=M-1|0;t=F<<1;v=d[1252840+x|0]|0;q=x<<v;c[j>>2]=q;A=u<<v;B=v+I|0;do{if((B|0)>-1){v=c[m>>2]|0;if(!(v>>>0<(c[n>>2]|0)>>>0)){R=A;S=B;break}c[m>>2]=v+2;z=v;R=((he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<B|A;S=B-16|0}else{R=A;S=B}}while(0);c[k>>2]=S;B=q+1>>1;A=B<<16;z=R>>>0>=A>>>0;if(z){v=q-B|0;c[j>>2]=v;T=R-A|0;U=v}else{c[j>>2]=B;T=R;U=B}c[l>>2]=T;V=z&1|t;if((s|0)==0){break}else{M=s;F=V;x=U;I=S;u=T}}u=V<<1;I=((u|0)==0|u)&255;a[g+L|0]=I;a[h+188+(e*198|0)+(O*66|0)+(N*11|0)+L|0]=I}else{if((c[(c[o>>2]|0)+84>>2]|0)==0){break}a[h+188+(e*198|0)+(O*66|0)+(N*11|0)+L|0]=a[g+L|0]|0}}while(0);L=L+1|0;}while((L|0)<11);N=N+1|0;}while((N|0)<6);e=e+1|0;}while((e|0)<2);e=O+1|0;if((e|0)<3){O=e}else{W=0;break}}while(1){O=0;do{g=(ca(b[251784+(O<<2)>>1]|0,d[h+166+(W*11|0)|0]|0)|0)+128>>8;o=g+(b[251786+(O<<2)>>1]|0)|0;if((o|0)<1){X=1}else{X=(o|0)>254?-2:o&255}a[h+1124+(W*180|0)+(O*5|0)|0]=X;o=(ca(b[251928+(O<<2)>>1]|0,d[h+166+(W*11|0)+1|0]|0)|0)+128>>8;g=o+(b[251930+(O<<2)>>1]|0)|0;if((g|0)<1){Y=1}else{Y=(g|0)>254?-2:g&255}a[h+1124+(W*180|0)+(O*5|0)+1|0]=Y;g=(ca(b[252072+(O<<2)>>1]|0,d[h+166+(W*11|0)+2|0]|0)|0)+128>>8;o=g+(b[252074+(O<<2)>>1]|0)|0;if((o|0)<1){Z=1}else{Z=(o|0)>254?-2:o&255}a[h+1124+(W*180|0)+(O*5|0)+2|0]=Z;o=(ca(b[252216+(O<<2)>>1]|0,d[h+166+(W*11|0)+3|0]|0)|0)+128>>8;g=o+(b[252218+(O<<2)>>1]|0)|0;if((g|0)<1){_=1}else{_=(g|0)>254?-2:g&255}a[h+1124+(W*180|0)+(O*5|0)+3|0]=_;g=(ca(b[252360+(O<<2)>>1]|0,d[h+166+(W*11|0)+4|0]|0)|0)+128>>8;o=g+(b[252362+(O<<2)>>1]|0)|0;if((o|0)<1){$=1}else{$=(o|0)>254?-2:o&255}a[h+1124+(W*180|0)+(O*5|0)+4|0]=$;O=O+1|0;}while((O|0)<36);O=W+1|0;if((O|0)<2){W=O}else{aa=0;break}}do{W=0;do{$=0;do{_=0;do{Z=(ca(b[250680+(aa*360|0)+($*120|0)+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)|0]|0)|0)+128>>8;Y=Z+(b[250680+(aa*360|0)+($*120|0)+(_<<2)+2>>1]|0)|0;if((Y|0)<1){ba=1}else{ba=(Y|0)>254?-2:Y&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)|0]=ba;Y=(ca(b[250680+(aa*360|0)+($*120|0)+24+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)+1|0]|0)|0)+128>>8;Z=Y+(b[250680+(aa*360|0)+($*120|0)+24+(_<<2)+2>>1]|0)|0;if((Z|0)<1){da=1}else{da=(Z|0)>254?-2:Z&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)+1|0]=da;Z=(ca(b[250680+(aa*360|0)+($*120|0)+48+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)+2|0]|0)|0)+128>>8;Y=Z+(b[250680+(aa*360|0)+($*120|0)+48+(_<<2)+2>>1]|0)|0;if((Y|0)<1){ea=1}else{ea=(Y|0)>254?-2:Y&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)+2|0]=ea;Y=(ca(b[250680+(aa*360|0)+($*120|0)+72+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)+3|0]|0)|0)+128>>8;Z=Y+(b[250680+(aa*360|0)+($*120|0)+72+(_<<2)+2>>1]|0)|0;if((Z|0)<1){fa=1}else{fa=(Z|0)>254?-2:Z&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)+3|0]=fa;Z=(ca(b[250680+(aa*360|0)+($*120|0)+96+(_<<2)>>1]|0,d[h+188+(W*198|0)+(aa*66|0)+($*11|0)+4|0]|0)|0)+128>>8;Y=Z+(b[250680+(aa*360|0)+($*120|0)+96+(_<<2)+2>>1]|0)|0;if((Y|0)<1){ga=1}else{ga=(Y|0)>254?-2:Y&255}a[h+584+(W*270|0)+(aa*90|0)+($*30|0)+(_*5|0)+4|0]=ga;_=_+1|0;}while((_|0)<6);$=$+1|0;}while(($|0)<3);W=W+1|0;}while((W|0)<2);aa=aa+1|0;}while((aa|0)<3);i=f;return 0}function H9a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;f=i;g=a+376|0;V9a(g,b,e);e=g|0;g=c[e>>2]|0;b=d[1252840+g|0]|0;h=a+380|0;j=c[h>>2]|0;k=a+392|0;l=c[k>>2]|0;m=g<<b;c[e>>2]=m;g=l<<b;l=j+b|0;do{if((l|0)>-1){b=a+384|0;j=c[b>>2]|0;if(!(j>>>0<(c[a+388>>2]|0)>>>0)){n=g;o=l;break}c[b>>2]=j+2;b=j;n=((he((d[b]|d[b+1|0]<<8)<<16>>16|0)|0)&65535)<<l|g;o=l-16|0}else{n=g;o=l}}while(0);c[h>>2]=o;o=m+1>>1;l=o<<16;g=n>>>0>=l>>>0;if(g){c[e>>2]=m-o;p=n-l|0}else{c[e>>2]=o;p=n}c[k>>2]=p;p=a+352|0;c[(c[p>>2]|0)+84>>2]=g&1^1;g=c[e>>2]|0;n=d[1252840+g|0]|0;o=c[h>>2]|0;l=c[k>>2]|0;m=g<<n;c[e>>2]=m;g=l<<n;l=o+n|0;do{if((l|0)>-1){n=a+384|0;o=c[n>>2]|0;if(!(o>>>0<(c[a+388>>2]|0)>>>0)){q=g;r=l;break}c[n>>2]=o+2;n=o;q=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<l|g;r=l-16|0}else{q=g;r=l}}while(0);c[h>>2]=r;l=m+1>>1;g=l<<16;if(q>>>0<g>>>0){c[e>>2]=l;s=q;t=l}else{n=m-l|0;c[e>>2]=n;s=q-g|0;t=n}c[k>>2]=s;n=a+384|0;g=a+388|0;q=6;l=0;m=t;t=r;r=s;while(1){s=q-1|0;o=l<<1;b=d[1252840+m|0]|0;j=m<<b;c[e>>2]=j;u=r<<b;v=b+t|0;do{if((v|0)>-1){b=c[n>>2]|0;if(!(b>>>0<(c[g>>2]|0)>>>0)){w=u;x=v;break}c[n>>2]=b+2;y=b;w=((he((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535)<<v|u;x=v-16|0}else{w=u;x=v}}while(0);c[h>>2]=x;v=j+1>>1;u=v<<16;y=w>>>0>=u>>>0;if(y){b=j-v|0;c[e>>2]=b;z=w-u|0;A=b}else{c[e>>2]=v;z=w;A=v}c[k>>2]=z;B=y&1|o;if((s|0)==0){break}else{q=s;l=B;m=A;t=x;r=z}}I9a(a,B);a:do{if((c[(c[p>>2]|0)+84>>2]|0)==0){if((c[a+600>>2]|0)==0){C=-1094995529}else{break}i=f;return C|0}else{B=8;z=c[e>>2]|0;r=c[h>>2]|0;x=c[k>>2]|0;while(1){t=B-1|0;A=d[1252840+z|0]|0;m=z<<A;c[e>>2]=m;l=x<<A;q=A+r|0;do{if((q|0)>-1){A=c[n>>2]|0;if(!(A>>>0<(c[g>>2]|0)>>>0)){D=l;E=q;break}c[n>>2]=A+2;w=A;D=((he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<q|l;E=q-16|0}else{D=l;E=q}}while(0);c[h>>2]=E;q=m+1>>1;l=q<<16;if(D>>>0<l>>>0){c[e>>2]=q;F=D;G=q}else{w=m-q|0;c[e>>2]=w;F=D-l|0;G=w}c[k>>2]=F;if((t|0)==0){H=5;I=0;J=G;K=E;L=F;break}else{B=t;z=G;r=E;x=F}}while(1){x=H-1|0;r=I<<1;z=d[1252840+J|0]|0;B=J<<z;c[e>>2]=B;s=L<<z;o=z+K|0;do{if((o|0)>-1){z=c[n>>2]|0;if(!(z>>>0<(c[g>>2]|0)>>>0)){M=s;N=o;break}c[n>>2]=z+2;j=z;M=((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)<<o|s;N=o-16|0}else{M=s;N=o}}while(0);c[h>>2]=N;o=B+1>>1;s=o<<16;t=M>>>0>=s>>>0;if(t){m=B-o|0;c[e>>2]=m;O=M-s|0;P=m}else{c[e>>2]=o;O=M;P=o}c[k>>2]=O;Q=t&1|r;if((x|0)==0){break}else{H=x;I=Q;J=P;K=N;L=O}}if((Q|0)>5){C=-1094995529;i=f;return C|0}t=d[1252840+P|0]|0;o=P<<t;c[e>>2]=o;m=O<<t;s=t+N|0;do{if((s|0)>-1){t=c[n>>2]|0;if(!(t>>>0<(c[g>>2]|0)>>>0)){R=m;S=s;break}c[n>>2]=t+2;j=t;R=((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)<<s|m;S=s-16|0}else{R=m;S=s}}while(0);c[h>>2]=S;s=o+1>>1;m=s<<16;if(R>>>0<m>>>0){c[e>>2]=s;T=R;U=s}else{j=o-s|0;c[e>>2]=j;T=R-m|0;U=j}c[k>>2]=T;j=d[1252840+U|0]|0;m=U<<j;c[e>>2]=m;s=T<<j;t=j+S|0;do{if((t|0)>-1){j=c[n>>2]|0;if(!(j>>>0<(c[g>>2]|0)>>>0)){V=s;W=t;break}c[n>>2]=j+2;z=j;V=((he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<t|s;W=t-16|0}else{V=s;W=t}}while(0);c[h>>2]=W;t=m+1>>1;s=t<<16;if(V>>>0<s>>>0){c[e>>2]=t;X=V;Y=t}else{o=m-t|0;c[e>>2]=o;X=V-s|0;Y=o}c[k>>2]=X;o=d[1252840+Y|0]|0;s=Y<<o;c[e>>2]=s;t=X<<o;z=W+o|0;do{if((z|0)>-1){o=c[n>>2]|0;if(!(o>>>0<(c[g>>2]|0)>>>0)){Z=t;_=z;break}c[n>>2]=o+2;j=o;Z=((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)<<z|t;_=z-16|0}else{Z=t;_=z}}while(0);c[h>>2]=_;z=s+1>>1;t=z<<16;if(!(Z>>>0<t>>>0)){c[e>>2]=s-z;c[k>>2]=Z-t;KIb(c[a>>2]|0,16,2441976,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;C=-1163346256;i=f;return C|0}c[e>>2]=z;c[k>>2]=Z;t=8;m=0;j=z;z=_;o=Z;while(1){w=t-1|0;l=m<<1;q=d[1252840+j|0]|0;A=j<<q;c[e>>2]=A;y=o<<q;v=q+z|0;do{if((v|0)>-1){q=c[n>>2]|0;if(!(q>>>0<(c[g>>2]|0)>>>0)){aa=y;ba=v;break}c[n>>2]=q+2;b=q;aa=((he((d[b]|d[b+1|0]<<8)<<16>>16|0)|0)&65535)<<v|y;ba=v-16|0}else{aa=y;ba=v}}while(0);c[h>>2]=ba;v=A+1>>1;y=v<<16;x=aa>>>0>=y>>>0;if(x){r=A-v|0;c[e>>2]=r;ca=aa-y|0;da=r}else{c[e>>2]=v;ca=aa;da=v}c[k>>2]=ca;ea=x&1|l;if((w|0)==0){fa=8;ga=0;ha=da;ia=ba;ja=ca;break}else{t=w;m=ea;j=da;z=ba;o=ca}}while(1){o=fa-1|0;z=ga<<1;j=d[1252840+ha|0]|0;m=ha<<j;c[e>>2]=m;t=ja<<j;s=j+ia|0;do{if((s|0)>-1){j=c[n>>2]|0;if(!(j>>>0<(c[g>>2]|0)>>>0)){ka=t;la=s;break}c[n>>2]=j+2;x=j;ka=((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<s|t;la=s-16|0}else{ka=t;la=s}}while(0);c[h>>2]=la;s=m+1>>1;t=s<<16;w=ka>>>0>=t>>>0;if(w){l=m-s|0;c[e>>2]=l;ma=ka-t|0;na=l}else{c[e>>2]=s;ma=ka;na=s}c[k>>2]=ma;oa=w&1|z;if((o|0)==0){break}else{fa=o;ga=oa;ha=na;ia=la;ja=ma}}if((ea|0)==0|(oa|0)==0){KIb(c[a>>2]|0,16,2353872,($=i,i=i+16|0,c[$>>2]=oa<<4,c[$+8>>2]=ea<<4,$)|0);i=$;C=-1094995529;i=f;return C|0}else{pa=8;qa=na;ra=la;sa=ma}while(1){w=pa-1|0;s=d[1252840+qa|0]|0;l=qa<<s;c[e>>2]=l;t=sa<<s;A=s+ra|0;do{if((A|0)>-1){s=c[n>>2]|0;if(!(s>>>0<(c[g>>2]|0)>>>0)){ta=t;ua=A;break}c[n>>2]=s+2;x=s;ta=((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<A|t;ua=A-16|0}else{ta=t;ua=A}}while(0);c[h>>2]=ua;A=l+1>>1;t=A<<16;if(ta>>>0<t>>>0){c[e>>2]=A;va=ta;wa=A}else{o=l-A|0;c[e>>2]=o;va=ta-t|0;wa=o}c[k>>2]=va;if((w|0)==0){xa=8;ya=wa;za=ua;Aa=va;break}else{pa=w;qa=wa;ra=ua;sa=va}}while(1){o=xa-1|0;t=d[1252840+ya|0]|0;A=ya<<t;c[e>>2]=A;z=Aa<<t;m=t+za|0;do{if((m|0)>-1){t=c[n>>2]|0;if(!(t>>>0<(c[g>>2]|0)>>>0)){Ba=z;Ca=m;break}c[n>>2]=t+2;x=t;Ba=((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<m|z;Ca=m-16|0}else{Ba=z;Ca=m}}while(0);c[h>>2]=Ca;m=A+1>>1;z=m<<16;if(Ba>>>0<z>>>0){c[e>>2]=m;Da=Ba;Ea=m}else{w=A-m|0;c[e>>2]=w;Da=Ba-z|0;Ea=w}c[k>>2]=Da;if((o|0)==0){break}else{xa=o;ya=Ea;za=Ca;Aa=Da}}w=d[1252840+Ea|0]|0;z=Ea<<w;c[e>>2]=z;m=Da<<w;l=w+Ca|0;do{if((l|0)>-1){w=c[n>>2]|0;if(!(w>>>0<(c[g>>2]|0)>>>0)){Fa=m;Ga=l;break}c[n>>2]=w+2;x=w;Fa=((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<l|m;Ga=l-16|0}else{Fa=m;Ga=l}}while(0);c[h>>2]=Ga;l=z+1>>1;m=l<<16;if(Fa>>>0<m>>>0){c[e>>2]=l;Ha=Fa;Ia=l}else{x=z-l|0;c[e>>2]=x;Ha=Fa-m|0;Ia=x}c[k>>2]=Ha;x=d[1252840+Ia|0]|0;m=Ia<<x;c[e>>2]=m;l=Ha<<x;w=x+Ga|0;do{if((w|0)>-1){x=c[n>>2]|0;if(!(x>>>0<(c[g>>2]|0)>>>0)){Ja=l;Ka=w;break}c[n>>2]=x+2;t=x;Ja=((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<w|l;Ka=w-16|0}else{Ja=l;Ka=w}}while(0);c[h>>2]=Ka;w=m+1>>1;l=w<<16;if(Ja>>>0<l>>>0){c[e>>2]=w;La=Ja}else{c[e>>2]=m-w;La=Ja-l|0}c[k>>2]=La;do{if((c[a+600>>2]|0)==0){Ma=c[a>>2]|0;Na=oa<<4}else{l=oa<<4;w=c[a>>2]|0;if((l|0)!=(c[w+128>>2]|0)){Ma=w;Na=l;break}if((ea<<4|0)==(c[w+132>>2]|0)){break a}else{Ma=w;Na=l}}}while(0);m=H4a(Ma,Na,ea<<4)|0;C=(m|0)<0?m:1;i=f;return C|0}}while(0);C=0;i=f;return C|0}function I9a(a,e){a=a|0;e=e|0;c[a+492>>2]=e;b[a+496>>1]=(d[1253232+e|0]|0)<<2;b[a+498>>1]=(d[1253440+e|0]|0)<<2;return}function J9a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;h=c[f+24>>2]|0;j=c[a+60>>2]|0;k=j;l=j+352|0;m=c[l>>2]|0;n=f+28|0;f=c[n>>2]|0;do{if((c[j+1696>>2]|0)==0){o=f;p=0;q=h}else{if((f|0)<3){r=-1;i=g;return r|0}s=(d[h+1|0]|0)<<8|(d[h]|0)<<16|(d[h+2|0]|0);t=f-3|0;if((t|0)<(s|0)){r=-1}else{o=t;p=s;q=h+3|0;break}i=g;return r|0}}while(0);h=Ee[c[j+1756>>2]&511](k,q,o)|0;if((h|0)<0){r=h;i=g;return r|0}f=(h|0)==1;do{if(f){h=j+1760|0;WHb(c[l>>2]|0);s=c[h>>2]|0;if((s|0)!=0){WHb(c[s+352>>2]|0)}WHb(c[j+356>>2]|0);s=c[h>>2]|0;if((s|0)!=0){WHb(c[s+356>>2]|0)}WHb(c[j+360>>2]|0);s=c[h>>2]|0;if((s|0)!=0){WHb(c[s+360>>2]|0)}WHb(c[j+364>>2]|0);s=c[h>>2]|0;if((s|0)==0){break}WHb(c[s+364>>2]|0)}}while(0);if((M4a(a,m,1)|0)<0){r=-1;i=g;return r|0}l=a+140|0;do{if((c[l>>2]|0)==35){s=j+1760|0;WHb(c[(c[s>>2]|0)+352>>2]|0);h=YHb(c[(c[s>>2]|0)+352>>2]|0,m)|0;if((h|0)>=0){break}WHb(m);r=h;i=g;return r|0}}while(0);a:do{if(f){h=k;while(1){u=c[h>>2]|0;s=c[h+352>>2]|0;t=s+32|0;v=c[t>>2]|0;w=u+128|0;x=c[w>>2]|0;c[h+440>>2]=x;c[h+428>>2]=x;x=(c[w>>2]|0)/2|0;c[h+436>>2]=x;c[h+432>>2]=x;x=u+132|0;y=c[x>>2]|0;c[h+456>>2]=y;c[h+444>>2]=y;y=(c[x>>2]|0)/2|0;c[h+452>>2]=y;c[h+448>>2]=y;y=h+1700|0;z=c[y>>2]|0;c[h+1712>>2]=ca(c[t>>2]|0,z)|0;c[h+1716>>2]=ca(c[s+36>>2]|0,z)|0;c[h+1720>>2]=ca(c[s+40>>2]|0,z)|0;c[h+1724>>2]=ca(c[s+44>>2]|0,z)|0;z=(c[w>>2]|0)+15|0;w=(z|0)/16|0;s=h+460|0;c[s>>2]=w;t=(c[x>>2]|0)+15|0;x=h+464|0;c[x>>2]=(t|0)/16|0;if((z|0)>16015|(t|0)>16015){A=15;break}t=h+500|0;oJb(t,(w<<2)+6|0,12)|0;w=h+600|0;oJb(w,ca(c[x>>2]|0,c[s>>2]|0)|0,8)|0;s=h+368|0;kJb(c[s>>2]|0);x=hJb(v<<4)|0;c[s>>2]=x;s=h+372|0;c[s>>2]=x;if((c[t>>2]|0)==0){break}if((c[w>>2]|0)==0|(x|0)==0){break}if((c[y>>2]|0)<0){c[s>>2]=x+(v*15|0)}h=c[h+1760>>2]|0;if((h|0)==0){break a}}if((A|0)==15){H4a(u,0,0)|0;KIb(u,16,2588520,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}WHb(m);r=-1;i=g;return r|0}}while(0);u=c[l>>2]|0;do{if((u|0)==35){A=a+120|0;k=c[A>>2]|0;f=a+124|0;h=c[f>>2]|0;v=a+128|0;x=c[v>>2]|0;s=a+132|0;y=c[s>>2]|0;w=c[j+1760>>2]|0;t=Ee[c[w+1756>>2]&511](w,q+p|0,o-p|0)|0;if((t|0)==0){C=c[l>>2]|0;break}else if((t|0)==1){KIb(a,16,2449528,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;c[A>>2]=k;c[f>>2]=h;c[v>>2]=x;c[s>>2]=y}WHb(m);r=-1;i=g;return r|0}else{C=u}}while(0);Xe[c[a+828>>2]&511](a,602,0,0,(C|0)==35?2:1)|0;C=YHb(b,m)|0;if((C|0)<0){r=C;i=g;return r|0}c[e>>2]=1;r=c[n>>2]|0;i=g;return r|0}function K9a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0;j=i;i=i+64|0;g=j|0;k=j+16|0;l=j+24|0;m=c[f+60>>2]|0;f=(h|0)==1;h=f&1;if(f){n=c[m+1760>>2]|0}else{n=m}m=n+352|0;o=c[m>>2]|0;p=o+84|0;q=o+88|0;do{if((c[p>>2]|0)==0){c[q>>2]=2;r=c[n+1764>>2]|0;s=n+376|0;t=n+380|0;u=n+392|0;v=n+384|0;w=n+388|0;x=a[1252744]|0;z=x<<24>>24>0;A=0;do{B=c[s>>2]|0;C=d[1252840+B|0]|0;D=c[t>>2]|0;E=c[u>>2]|0;F=B<<C;c[s>>2]=F;B=E<<C;E=D+C|0;do{if((E|0)>-1){C=c[v>>2]|0;if(!(C>>>0<(c[w>>2]|0)>>>0)){G=B;H=E;break}c[v>>2]=C+2;D=C;G=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<E|B;H=E-16|0}else{G=B;H=E}}while(0);c[t>>2]=H;E=((F*174|0)-174>>8)+1|0;B=E<<16;D=G>>>0>=B>>>0;C=D?F-E|0:E;c[s>>2]=C;E=G-(D?B:0)|0;c[u>>2]=E;if(D){D=4;B=0;I=C;J=H;K=E;while(1){L=D-1|0;M=B<<1;N=d[1252840+I|0]|0;O=I<<N;c[s>>2]=O;P=K<<N;Q=N+J|0;do{if((Q|0)>-1){N=c[v>>2]|0;if(!(N>>>0<(c[w>>2]|0)>>>0)){R=P;S=Q;break}c[v>>2]=N+2;T=N;R=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<Q|P;S=Q-16|0}else{R=P;S=Q}}while(0);c[t>>2]=S;Q=O+1>>1;P=Q<<16;T=R>>>0>=P>>>0;if(T){N=O-Q|0;c[s>>2]=N;U=R-P|0;V=N}else{c[s>>2]=Q;U=R;V=Q}c[u>>2]=U;W=T&1|M;if((L|0)==0){break}else{D=L;B=W;I=V;J=S;K=U}}nrc(r+1812+(A*20|0)|0,1251784+(W*60|0)+(A*20|0)|0,20)|0;X=c[s>>2]|0;Y=c[t>>2]|0;Z=c[u>>2]|0}else{X=C;Y=H;Z=E}K=d[1252840+X|0]|0;J=X<<K;c[s>>2]=J;I=Z<<K;B=K+Y|0;do{if((B|0)>-1){K=c[v>>2]|0;if(!(K>>>0<(c[w>>2]|0)>>>0)){_=I;$=B;break}c[v>>2]=K+2;D=K;_=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<B|I;$=B-16|0}else{_=I;$=B}}while(0);c[t>>2]=$;B=((J*254|0)-254>>8)+1|0;I=B<<16;E=_>>>0>=I>>>0;c[s>>2]=E?J-B|0:B;c[u>>2]=_-(E?I:0);if(E){E=0;do{I=0;do{B=c[s>>2]|0;C=d[1252840+B|0]|0;D=c[t>>2]|0;K=c[u>>2]|0;F=B<<C;c[s>>2]=F;B=K<<C;K=D+C|0;do{if((K|0)>-1){C=c[v>>2]|0;if(!(C>>>0<(c[w>>2]|0)>>>0)){aa=B;ba=K;break}c[v>>2]=C+2;D=C;aa=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<K|B;ba=K-16|0}else{aa=B;ba=K}}while(0);c[t>>2]=ba;K=((F*205|0)-205>>8)+1|0;B=K<<16;D=aa>>>0>=B>>>0;C=D?F-K|0:K;c[s>>2]=C;K=aa-(D?B:0)|0;c[u>>2]=K;if(D){D=d[1252840+C|0]|0;B=C<<D;c[s>>2]=B;C=K<<D;K=D+ba|0;do{if((K|0)>-1){D=c[v>>2]|0;if(!(D>>>0<(c[w>>2]|0)>>>0)){da=C;ea=K;break}c[v>>2]=D+2;T=D;da=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<K|C;ea=K-16|0}else{da=C;ea=K}}while(0);c[t>>2]=ea;K=B+1>>1;C=K<<16;F=da>>>0>=C>>>0;T=F&1;if(F){F=B-K|0;c[s>>2]=F;fa=da-C|0;ga=F}else{c[s>>2]=K;fa=da;ga=K}c[u>>2]=fa;if(z){K=1252744;F=1252744;C=ga;D=ea;Q=fa;while(1){N=a[1253096+(a[K+1|0]|0)|0]|0;P=d[1252840+C|0]|0;ha=C<<P;c[s>>2]=ha;ia=Q<<P;ja=P+D|0;do{if((ja|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){ka=ia;la=ja;break}c[v>>2]=P+2;ma=P;ka=((he((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<ja|ia;la=ja-16|0}else{ka=ia;la=ja}}while(0);c[t>>2]=la;ja=((ca(ha-1|0,N&255)|0)>>8)+1|0;ia=ja<<16;ma=ka>>>0>=ia>>>0;P=ma?ha-ja|0:ja;c[s>>2]=P;ja=ka-(ma?ia:0)|0;c[u>>2]=ja;if(ma){na=K+(a[F]<<1)|0}else{na=K+2|0}ma=na|0;ia=a[ma]|0;if(ia<<24>>24>0){K=na;F=ma;C=P;D=la;Q=ja}else{oa=ia;pa=P;qa=la;ra=ja;break}}}else{oa=x;pa=ga;qa=ea;ra=fa}Q=-(oa<<24>>24)|0;if(oa<<24>>24==0){D=7;C=0;F=pa;K=qa;B=ra;while(1){ja=D-1|0;P=C<<1;ia=d[1252840+F|0]|0;ma=F<<ia;c[s>>2]=ma;sa=B<<ia;ta=ia+K|0;do{if((ta|0)>-1){ia=c[v>>2]|0;if(!(ia>>>0<(c[w>>2]|0)>>>0)){ua=sa;va=ta;break}c[v>>2]=ia+2;wa=ia;ua=((he((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)<<ta|sa;va=ta-16|0}else{ua=sa;va=ta}}while(0);c[t>>2]=va;ta=ma+1>>1;sa=ta<<16;ha=ua>>>0>=sa>>>0;if(ha){N=ma-ta|0;c[s>>2]=N;xa=ua-sa|0;ya=N}else{c[s>>2]=ta;xa=ua;ya=ta}c[u>>2]=xa;za=ha&1|P;if((ja|0)==0){break}else{D=ja;C=za;F=ya;K=va;B=xa}}Aa=za<<2}else{Aa=Q}B=r+1812+(A*20|0)+(E<<1)+I|0;a[B]=(Aa^-T)+T+(d[B]|0)}I=I+1|0;}while((I|0)<2);E=E+1|0;}while((E|0)<10)}A=A+1|0;}while((A|0)<3);A=l|0;u=l+8|0;s=l+12|0;t=l+16|0;v=l+4|0;w=l+28|0;x=l+20|0;z=l+24|0;E=l+32|0;J=l+36|0;I=0;do{L=a[r+1812+(I*20|0)+1|0]|0;c[A>>2]=(L&255)*100|0;c[v>>2]=(d[r+1812+(I*20|0)+3|0]|0)*100|0;c[u>>2]=(d[r+1812+(I*20|0)+5|0]|0)*100|0;c[s>>2]=(d[r+1812+(I*20|0)+7|0]|0)*100|0;c[t>>2]=(d[r+1812+(I*20|0)+9|0]|0)*100|0;c[x>>2]=(d[r+1812+(I*20|0)+11|0]|0)*100|0;c[z>>2]=(d[r+1812+(I*20|0)+13|0]|0)*100|0;c[w>>2]=(d[r+1812+(I*20|0)+15|0]|0)*100|0;c[E>>2]=(d[r+1812+(I*20|0)+17|0]|0)*100|0;c[J>>2]=(d[r+1812+(I*20|0)+19|0]|0)*100|0;M=0;O=L;while(1){L=d[r+1812+(I*20|0)+(M<<1)|0]|0;a[r+1512+(I*100|0)+(M*10|0)|0]=255-(((L*255|0)>>>0)/(((O&255)+1+L|0)>>>0)|0);L=l+(M<<2)|0;c[L>>2]=0;B=c[A>>2]|0;K=(c[u>>2]|0)+B|0;F=c[s>>2]|0;C=(c[t>>2]|0)+F|0;D=C+K|0;ha=c[v>>2]|0;ta=(c[w>>2]|0)+ha|0;N=c[x>>2]|0;sa=(c[z>>2]|0)+N|0;wa=c[E>>2]|0;ia=(c[J>>2]|0)+wa|0;Ba=ia+sa|0;Ca=Ba+ta|0;Da=D+1|0;a[r+1512+(I*100|0)+(M*10|0)+1|0]=((D*255|0|0)/(Ca+Da|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+2|0]=((K*255|0|0)/(Da|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+3|0]=((ta*255|0|0)/(Ca+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+4|0]=((B*255|0|0)/(K+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+5|0]=((F*255|0|0)/(C+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+6|0]=((ha*255|0|0)/(ta+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+7|0]=((sa*255|0|0)/(Ba+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+8|0]=((N*255|0|0)/(sa+1|0)|0)+1;a[r+1512+(I*100|0)+(M*10|0)+9|0]=((wa*255|0|0)/(ia+1|0)|0)+1;c[L>>2]=(d[r+1812+(I*20|0)+(M<<1)+1|0]|0)*100|0;L=M+1|0;if((L|0)>=10){break}M=L;O=a[r+1812+(I*20|0)+(L<<1)+1|0]|0}I=I+1|0;}while((I|0)<3);qe[c[n+1748>>2]&1023](n);c[n+596>>2]=0}else{c[q>>2]=1;qe[c[n+1744>>2]&1023](n);I=n+464|0;r=n+460|0;if((ca(c[r>>2]|0,c[I>>2]|0)|0)<=0){break}J=n+600|0;E=0;do{a[(c[J>>2]|0)+(E<<3)|0]=1;E=E+1|0;}while((E|0)<(ca(c[r>>2]|0,c[I>>2]|0)|0))}}while(0);a:do{if((ve[c[n+1752>>2]&4095](n)|0)==0){mrc(n+576|0,0,18)|0;b[n+582>>1]=128;b[n+588>>1]=128;q=n+460|0;l=c[q>>2]|0;Aa=n+500|0;if(((l<<2)+6|0)>0){za=0;while(1){c[(c[Aa>>2]|0)+(za*12|0)+4>>2]=-1;xa=c[Aa>>2]|0;b[xa+(za*12|0)+8>>1]=0;a[xa+(za*12|0)|0]=0;xa=za+1|0;va=c[q>>2]|0;if((xa|0)<((va<<2)+6|0)){za=xa}else{Ea=va;break}}}else{Ea=l}c[(c[Aa>>2]|0)+(((Ea<<1)+2|0)*12|0)+4>>2]=0;c[(c[Aa>>2]|0)+((((c[q>>2]|0)*3|0)+4|0)*12|0)+4>>2]=0;za=c[o+32>>2]|0;va=c[o+36>>2]|0;xa=n+1700|0;ya=c[xa>>2]|0;ua=ya>>31&7;ra=n+464|0;qa=c[ra>>2]|0;if((qa|0)<=0){break}pa=n+1436|0;oa=n+1692|0;fa=n+552|0;ea=n+556|0;ga=n+560|0;la=n+564|0;na=n+568|0;ka=n+572|0;da=n+1704|0;ba=za<<3;aa=n+1708|0;_=n+468|0;$=n+472|0;Y=n+476|0;Z=n+480|0;X=n+484|0;H=n+488|0;W=k;U=n+596|0;S=n+1764|0;V=n+376|0;R=n+380|0;G=n+392|0;I=n+384|0;r=n+388|0;E=n+600|0;J=n+1376|0;z=J;x=n+1380|0;w=x;v=n+1384|0;t=v;s=n+1388|0;u=s;A=n+1392|0;O=n+1396|0;M=n+1400|0;L=n+1404|0;ia=n+1732|0;wa=M;sa=L;N=g|0;Ba=n+1376|0;ta=n+1378|0;ha=g+4|0;C=n+1380|0;F=n+1382|0;K=g+8|0;B=n+1384|0;Ca=n+1386|0;Da=g+12|0;D=n+1388|0;Fa=n+1390|0;Ga=n|0;Ha=n+1396|0;Ia=n+1392|0;Ja=n+1398|0;Ka=n+1394|0;La=a[1252776]|0;Ma=La<<24>>24>0;Na=n+1740|0;Oa=n+288|0;Pa=n+496|0;Qa=-h&6;Ra=6-(h<<1)|0;Sa=n+256|0;Ta=n+1120|0;Ua=n+1248|0;Va=n+52|0;Wa=n+260|0;Xa=n+1728|0;Ya=n+1416|0;Za=n+244|0;_a=n+372|0;$a=n+492|0;ab=n+280|0;bb=n+276|0;cb=n+1736|0;db=n+252|0;eb=n+1420|0;fb=n+36|0;gb=0;hb=qa;qa=ya;while(1){if((qa|0)<0){ib=hb+~gb|0}else{ib=gb}c[n+508>>2]=-1;b[n+512>>1]=0;a[n+504|0]=0;c[n+520>>2]=-1;b[n+524>>1]=0;a[n+516|0]=0;c[n+532>>2]=-1;b[n+536>>1]=0;a[n+528|0]=0;c[n+544>>2]=-1;b[n+548>>1]=0;a[n+540|0]=0;mrc(pa|0,0,256)|0;y=404232216;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;c[fa>>2]=1;c[ea>>2]=2;c[ga>>2]=1;c[la>>2]=2;ya=c[q>>2]|0;c[na>>2]=(ya<<1)+3;c[ka>>2]=(ya*3|0)+5;ya=ca(ib<<4|ua,za)|0;c[n+468+(c[da>>2]<<2)>>2]=ya;c[n+468+(c[aa>>2]<<2)>>2]=(c[n+468+(c[da>>2]<<2)>>2]|0)+ba;c[$>>2]=(c[_>>2]|0)+8;c[Z>>2]=(c[Y>>2]|0)+8;ya=ca(ib<<3|ua,va)|0;c[X>>2]=ya;c[H>>2]=ya;if((c[q>>2]|0)>0){ya=gb<<4;jb=0;do{if((c[(c[m>>2]|0)+84>>2]|0)==0){c[k>>2]=0;kb=P9a(n,gb,jb,1)|0;lb=c[U>>2]|0;mb=c[S>>2]|0;nb=a[mb+1512+(kb*100|0)+(lb*10|0)|0]|0;ob=c[V>>2]|0;pb=d[1252840+ob|0]|0;qb=c[R>>2]|0;rb=c[G>>2]|0;sb=ob<<pb;c[V>>2]=sb;ob=rb<<pb;rb=qb+pb|0;do{if((rb|0)>-1){pb=c[I>>2]|0;if(!(pb>>>0<(c[r>>2]|0)>>>0)){tb=ob;ub=rb;break}c[I>>2]=pb+2;qb=pb;tb=((he((d[qb]|d[qb+1|0]<<8)<<16>>16|0)|0)&65535)<<rb|ob;ub=rb-16|0}else{tb=ob;ub=rb}}while(0);c[R>>2]=ub;rb=((ca(sb-1|0,nb&255)|0)>>8)+1|0;ob=rb<<16;qb=tb>>>0>=ob>>>0;pb=qb?sb-rb|0:rb;c[V>>2]=pb;rb=tb-(qb?ob:0)|0;c[G>>2]=rb;if(qb){vb=lb}else{if(Ma){qb=1252776;ob=1252776;wb=pb;pb=ub;xb=rb;while(1){rb=a[(a[qb+1|0]|0)+(mb+1512+(kb*100|0)+(lb*10|0))|0]|0;yb=d[1252840+wb|0]|0;zb=wb<<yb;c[V>>2]=zb;Ab=xb<<yb;Bb=yb+pb|0;do{if((Bb|0)>-1){yb=c[I>>2]|0;if(!(yb>>>0<(c[r>>2]|0)>>>0)){Cb=Ab;Db=Bb;break}c[I>>2]=yb+2;Eb=yb;Cb=((he((d[Eb]|d[Eb+1|0]<<8)<<16>>16|0)|0)&65535)<<Bb|Ab;Db=Bb-16|0}else{Cb=Ab;Db=Bb}}while(0);c[R>>2]=Db;Bb=((ca(zb-1|0,rb&255)|0)>>8)+1|0;Ab=Bb<<16;T=Cb>>>0>=Ab>>>0;Q=T?zb-Bb|0:Bb;c[V>>2]=Q;Bb=Cb-(T?Ab:0)|0;c[G>>2]=Bb;if(T){Fb=qb+(a[ob]<<1)|0}else{Fb=qb+2|0}T=Fb|0;Ab=a[T]|0;if(Ab<<24>>24>0){qb=Fb;ob=T;wb=Q;pb=Db;xb=Bb}else{Gb=Ab;break}}}else{Gb=La}vb=-(Gb<<24>>24)|0}c[U>>2]=vb;xb=(ca(c[q>>2]|0,gb)|0)+jb|0;a[(c[E>>2]|0)+(xb<<3)|0]=vb;b:do{switch(c[U>>2]|0){case 6:{P9a(n,gb,jb,2)|0;re[c[ia>>2]&1023](n,W);Hb=W;Ib=129;break};case 7:{xb=0;pb=c[V>>2]|0;wb=c[R>>2]|0;ob=c[G>>2]|0;while(1){qb=d[1252840+pb|0]|0;lb=pb<<qb;c[V>>2]=lb;kb=ob<<qb;mb=qb+wb|0;do{if((mb|0)>-1){qb=c[I>>2]|0;if(!(qb>>>0<(c[r>>2]|0)>>>0)){Jb=kb;Kb=mb;break}c[I>>2]=qb+2;sb=qb;Jb=((he((d[sb]|d[sb+1|0]<<8)<<16>>16|0)|0)&65535)<<mb|kb;Kb=mb-16|0}else{Jb=kb;Kb=mb}}while(0);c[R>>2]=Kb;mb=lb+1>>1;kb=mb<<16;ja=Jb>>>0>=kb>>>0;if(ja){P=lb-mb|0;c[V>>2]=P;Lb=Jb-kb|0;Mb=P}else{c[V>>2]=mb;Lb=Jb;Mb=mb}c[G>>2]=Lb;mb=(ja&1)<<1;ja=d[1252840+Mb|0]|0;P=Mb<<ja;c[V>>2]=P;kb=Lb<<ja;ma=ja+Kb|0;do{if((ma|0)>-1){ja=c[I>>2]|0;if(!(ja>>>0<(c[r>>2]|0)>>>0)){Nb=kb;Ob=ma;break}c[I>>2]=ja+2;sb=ja;Nb=((he((d[sb]|d[sb+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|kb;Ob=ma-16|0}else{Nb=kb;Ob=ma}}while(0);c[R>>2]=Ob;ma=P+1>>1;kb=ma<<16;lb=Nb>>>0>=kb>>>0;if(lb){sb=P-ma|0;c[V>>2]=sb;Pb=Nb-kb|0;Qb=sb}else{c[V>>2]=ma;Pb=Nb;Qb=ma}c[G>>2]=Pb;ma=lb&1|mb;c[g+(xb<<2)>>2]=(ma|0)==0?0:ma+1|0;ma=xb+1|0;if((ma|0)<4){xb=ma;pb=Qb;wb=Ob;ob=Pb}else{break}}ob=c[N>>2]|0;if((ob|0)==2){re[c[ia>>2]&1023](n,J)}else if((ob|0)==3){c[z>>2]=c[wa>>2]}else if((ob|0)==4){c[z>>2]=c[sa>>2]}else if((ob|0)==0){b[Ba>>1]=0;b[ta>>1]=0}ob=e[Ba>>1]|0;wb=e[ta>>1]|0;pb=c[ha>>2]|0;if((pb|0)==2){re[c[ia>>2]&1023](n,x)}else if((pb|0)==0){b[C>>1]=0;b[F>>1]=0}else if((pb|0)==4){c[w>>2]=c[sa>>2]}else if((pb|0)==3){c[w>>2]=c[wa>>2]}pb=(e[C>>1]|0)+ob|0;ob=(e[F>>1]|0)+wb|0;wb=c[K>>2]|0;if((wb|0)==3){c[t>>2]=c[wa>>2]}else if((wb|0)==2){re[c[ia>>2]&1023](n,v)}else if((wb|0)==0){b[B>>1]=0;b[Ca>>1]=0}else if((wb|0)==4){c[t>>2]=c[sa>>2]}wb=e[B>>1]|0;xb=e[Ca>>1]|0;zb=c[Da>>2]|0;if((zb|0)==4){c[u>>2]=c[sa>>2]}else if((zb|0)==3){c[u>>2]=c[wa>>2]}else if((zb|0)==2){re[c[ia>>2]&1023](n,s)}else if((zb|0)==0){b[D>>1]=0;b[Fa>>1]=0}zb=(e[D>>1]<<16)+(pb+wb<<16)|0;wb=zb>>16;pb=(e[Fa>>1]<<16)+(ob+xb<<16)|0;xb=pb>>16;ob=(ca(c[q>>2]|0,gb)|0)+jb|0;c[(c[E>>2]|0)+(ob<<3)+4>>2]=c[u>>2];if((c[(c[(c[Ga>>2]|0)+12>>2]|0)+12>>2]|0)==91){ob=(((zb|0)>0?2:1)+wb|0)>>>2&65535;b[Ha>>1]=ob;b[Ia>>1]=ob;ob=(((pb|0)>0?2:1)+xb|0)>>>2&65535;b[Ja>>1]=ob;b[Ka>>1]=ob;break b}else{b[Ha>>1]=(wb|0)/4|0;b[Ja>>1]=(xb|0)/4|0;c[A>>2]=c[O>>2];break b}break};case 8:{P9a(n,gb,jb,2)|0;Hb=M;Ib=129;break};case 9:{P9a(n,gb,jb,2)|0;Hb=L;Ib=129;break};case 2:{re[c[ia>>2]&1023](n,W);Hb=W;Ib=129;break};case 3:{Hb=M;Ib=129;break};case 4:{Hb=L;Ib=129;break};default:{Hb=W;Ib=129}}}while(0);if((Ib|0)==129){Ib=0;xb=(ca(c[q>>2]|0,gb)|0)+jb|0;wb=Hb;c[(c[E>>2]|0)+(xb<<3)+4>>2]=c[wb>>2];xb=c[wb>>2]|0;c[z>>2]=xb;c[w>>2]=xb;c[t>>2]=xb;c[u>>2]=xb;c[A>>2]=xb;c[O>>2]=xb}Rb=c[U>>2]|0}else{Rb=1}xb=c[1251712+(Rb<<2)>>2]|0;qe[c[Na>>2]&1023](n);wb=d[Oa]|0;ob=0;do{pb=c[n+552+(ob<<2)>>2]|0;zb=c[Aa>>2]|0;rb=d[1253416+ob|0]|0;ma=n+504+(rb*12|0)+4|0;if((c[ma>>2]|0)==(xb|0)){Sb=b[n+504+(rb*12|0)+8>>1]|0;Tb=1}else{Sb=0;Tb=0}lb=zb+(pb*12|0)+4|0;if((c[lb>>2]|0)==(xb|0)){Ub=(b[zb+(pb*12|0)+8>>1]|0)+Sb|0;Vb=Tb+1|0}else{Ub=Sb;Vb=Tb}do{if((c[(c[(c[Ga>>2]|0)+12>>2]|0)+12>>2]|0)==91){sb=pb-1|0;if((Vb|0)>=2){Wb=Ub;Xb=Vb;break}if((c[zb+(sb*12|0)+4>>2]|0)==(xb|0)){Yb=(b[zb+(sb*12|0)+8>>1]|0)+Ub|0;Zb=Vb+1|0}else{Yb=Ub;Zb=Vb}if((Zb|0)>=2){Wb=Yb;Xb=Zb;break}sb=pb+1|0;if((c[zb+(sb*12|0)+4>>2]|0)!=(xb|0)){Wb=Yb;Xb=Zb;break}Wb=(b[zb+(sb*12|0)+8>>1]|0)+Yb|0;Xb=Zb+1|0}else{Wb=Ub;Xb=Vb}}while(0);if((Xb|0)==2){_b=(Wb|0)/2|0}else if((Xb|0)==0){_b=b[n+576+((d[1253424+ob|0]|0)*6|0)+(xb<<1)>>1]|0}else{_b=Wb}sb=n+608+(ob<<7)+(wb<<1)|0;kb=(e[sb>>1]|0)+_b&65535;b[sb>>1]=kb;b[n+576+((d[1253424+ob|0]|0)*6|0)+(xb<<1)>>1]=kb;b[zb+(pb*12|0)+8>>1]=b[sb>>1]|0;c[lb>>2]=xb;b[n+504+(rb*12|0)+8>>1]=b[sb>>1]|0;c[ma>>2]=xb;b[sb>>1]=ca(b[sb>>1]|0,b[Pa>>1]|0)|0;ob=ob+1|0;}while((ob|0)<6);ob=c[m>>2]|0;wb=c[n+352+(xb<<2)>>2]|0;c:do{if((Rb|0)==1){$b=0;Ib=151}else{if((c[wb>>2]|0)==0){break}switch(Rb|0){case 2:case 3:case 4:case 6:case 7:case 8:case 9:{break};case 1:{$b=0;Ib=151;break c;break};case 0:case 5:{sb=0;while(1){kb=d[1253424+(sb+Qa)|0]|0;ja=c[n+468+(sb<<2)>>2]|0;qb=ob+(kb<<2)|0;nb=n+1712+(kb<<2)|0;mf[c[Va>>2]&2047]((c[qb>>2]|0)+ja|0,(c[wb+(kb<<2)>>2]|0)+ja|0,c[nb>>2]|0,8);ef[c[Wa>>2]&4095]((c[qb>>2]|0)+ja|0,c[nb>>2]|0,n+608+(sb<<7)|0);nb=sb+1|0;if((nb|0)<(Ra|0)){sb=nb}else{Ib=185;break c}}break};default:{Ib=185;break c}}sb=jb<<4;ma=0;while(1){if((ma|0)==1){ac=8;Ib=155}else{rb=(ma|0)==3?8:0;if((ma|0)==2){bc=8;cc=rb}else{ac=rb;Ib=155}}if((Ib|0)==155){Ib=0;bc=(ma|0)==3?8:0;cc=ac}rb=d[1253424+(ma+Qa)|0]|0;lb=c[wb+(rb<<2)>>2]|0;pb=n+1712+(rb<<2)|0;zb=c[pb>>2]|0;nb=cc|sb;ja=bc|ya;qb=c[m>>2]|0;kb=n+468+(ma<<2)|0;Ab=c[kb>>2]|0;Bb=(c[qb+(rb<<2)>>2]|0)+Ab|0;Q=d[(c[Xa>>2]|0)+ma|0]|0;T=Q-1|0;Eb=c[Ya>>2]|0;yb=c[(c[Ga>>2]|0)+848>>2]|0;do{if((yb|0)>47){Ib=159}else{if((yb|0)<=31){dc=Eb;break}if((c[qb+84>>2]|0)==0){Ib=159}else{dc=Eb}}}while(0);if((Ib|0)==159){Ib=0;dc=0}Eb=n+1376+(ma<<2)|0;qb=Eb|0;yb=(b[qb>>1]|0)/(Q|0)|0;mb=n+1376+(ma<<2)+2|0;P=(b[mb>>1]|0)/(Q|0)|0;if((ma|0)>3){ec=(nb|0)/2|0;fc=(ja|0)/2|0}else{ec=nb;fc=ja}gc=yb-2|0;hc=ec+gc|0;ic=P-2|0;jc=fc+ic|0;do{if((hc|0)<0){kc=c[n+428+(rb<<2)>>2]|0;Ib=166}else{lc=c[n+428+(rb<<2)>>2]|0;if((hc+12|0)>=(lc|0)|(jc|0)<0){kc=lc;Ib=166;break}if((jc+12|0)>=(c[n+444+(rb<<2)>>2]|0)){kc=lc;Ib=166;break}if((dc|0)==0){mc=yb+Ab+(ca(P,zb)|0)|0;nc=lb;break}else{lc=lb+(gc+Ab+(ca(ic,zb)|0))|0;mf[c[fb>>2]&2047](c[_a>>2]|0,lc,zb,12);Ib=170;break}}}while(0);if((Ib|0)==166){Ib=0;ja=lb+(gc+Ab+(ca(ic,zb)|0))|0;Ve[c[Za>>2]&127](c[_a>>2]|0,ja,zb,zb,12,12,hc,jc,kc,c[n+444+(rb<<2)>>2]|0);Ib=170}do{if((Ib|0)==170){Ib=0;ja=c[_a>>2]|0;nb=(zb<<1)+2|0;if((dc|0)==0){mc=nb;nc=ja;break}Q=yb&7;lc=P&7;oc=d[1253104+(c[$a>>2]|0)|0]|0;if((Q|0)!=0){ef[c[bb>>2]&4095](ja+(10-Q)|0,zb,oc)}if((lc|0)==0){mc=nb;nc=ja;break}Q=ja+(ca(10-lc|0,zb)|0)|0;ef[c[ab>>2]&4095](Q,zb,oc);mc=nb;nc=ja}}while(0);P=b[qb>>1]|0;if((P<<16>>16&T|0)==0){pc=0}else{pc=P<<16>>16>0?1:-1}P=b[mb>>1]|0;if((P<<16>>16&T|0)==0){qc=pc}else{qc=(P<<16>>16>0?zb:-zb|0)+pc|0}do{if((qc|0)==0){mf[c[Va>>2]&2047](Bb,nc+mc|0,zb,8)}else{P=c[cb>>2]|0;if((P|0)==0){pe[c[db>>2]&1023](Bb,nc+mc|0,nc+(qc+mc)|0,zb,8);break}else{Ve[P&127](n,Bb,nc,mc,qc+mc|0,zb,Eb,T,c[eb>>2]|0,(ma|0)<4|0);break}}}while(0);ef[c[Wa>>2]&4095]((c[ob+(rb<<2)>>2]|0)+(c[kb>>2]|0)|0,c[pb>>2]|0,n+608+(ma<<7)|0);T=ma+1|0;if((T|0)<(Ra|0)){ma=T}else{Ib=185;break}}}}while(0);if((Ib|0)==151){while(1){Ib=0;wb=d[1253424+($b+Qa)|0]|0;ef[c[Sa>>2]&4095]((c[ob+(wb<<2)>>2]|0)+(c[n+468+($b<<2)>>2]|0)|0,c[n+1712+(wb<<2)>>2]|0,n+608+($b<<7)|0);wb=$b+1|0;if((wb|0)<(Ra|0)){$b=wb;Ib=151}else{Ib=185;break}}}do{if((Ib|0)==185){Ib=0;if(!f){break}b[Ta>>1]=0;b[Ua>>1]=0}}while(0);c[fa>>2]=(c[fa>>2]|0)+2;c[_>>2]=(c[_>>2]|0)+16;c[ea>>2]=(c[ea>>2]|0)+2;c[$>>2]=(c[$>>2]|0)+16;c[ga>>2]=(c[ga>>2]|0)+2;c[Y>>2]=(c[Y>>2]|0)+16;c[la>>2]=(c[la>>2]|0)+2;c[Z>>2]=(c[Z>>2]|0)+16;c[na>>2]=(c[na>>2]|0)+1;c[X>>2]=(c[X>>2]|0)+8;c[ka>>2]=(c[ka>>2]|0)+1;c[H>>2]=(c[H>>2]|0)+8;jb=jb+1|0;}while((jb|0)<(c[q>>2]|0))}jb=gb+1|0;ya=c[ra>>2]|0;if((jb|0)>=(ya|0)){break a}gb=jb;hb=ya;qa=c[xa>>2]|0}}}while(0);if((c[p>>2]|0)==0){if((c[n+424>>2]|0)!=0){Ib=192}}else{Ib=192}do{if((Ib|0)==192){p=n+360|0;WHb(c[p>>2]|0);f=YHb(c[p>>2]|0,o)|0;if((f|0)<0){rc=f}else{break}i=j;return rc|0}}while(0);o=n+356|0;WHb(c[o>>2]|0);n=c[o>>2]|0;c[o>>2]=c[m>>2];c[m>>2]=n;rc=0;i=j;return rc|0}function L9a(a,b,d){a=a|0;b=b|0;d=d|0;return M9a(a,c[a+60>>2]|0,b,d)|0}function M9a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c[d>>2]=b;g=b+140|0;c[g>>2]=(f|0)!=0?35:0;if((c[b+944>>2]|0)!=0){c[g>>2]=0}Mia(d+4|0,8);g=b+88|0;YJa(d+36|0,c[g>>2]|0);G8a(d+244|0,8);u9a(d+252|0,c[g>>2]|0);Q9a(d+276|0,c[(c[b+12>>2]|0)+12>>2]|0);g=0;while(1){h=a[1242080+g|0]|0;a[d+288+g|0]=h<<3&56|(h&255)>>>3;h=g+1|0;if((h|0)<64){g=h}else{i=0;break}}while(1){if(!(i>>>0<4>>>0)){break}g=UHb()|0;c[d+352+(i<<2)>>2]=g;if((g|0)==0){j=7;break}else{i=i+1|0}}if((j|0)==7){j=c[b+60>>2]|0;mJb(j+500|0);mJb(j+600|0);mJb(j+368|0);VHb(j+352|0);VHb(j+356|0);VHb(j+360|0);VHb(j+364|0);k=-12;return k|0}c[d+368>>2]=0;c[d+500>>2]=0;c[d+600>>2]=0;c[d+492>>2]=-1;c[d+1416>>2]=1;c[d+424>>2]=0;c[d+1736>>2]=0;c[d+1696>>2]=f;c[d+1764>>2]=d+1768;f=d+1700|0;if((e|0)==0){c[f>>2]=1;c[d+1704>>2]=0;c[d+1708>>2]=2;k=0;return k|0}else{c[f>>2]=-1;c[d+1704>>2]=2;c[d+1708>>2]=0;k=0;return k|0}return 0}function N9a(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+500|0);mJb(b+600|0);mJb(b+368|0);VHb(b+352|0);VHb(b+356|0);VHb(b+360|0);VHb(b+364|0);return 0}function O9a(a){a=a|0;mJb(a+500|0);mJb(a+600|0);mJb(a+368|0);VHb(a+352|0);VHb(a+356|0);VHb(a+360|0);VHb(a+364|0);return 0}function P9a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=i;i=i+8|0;k=j|0;l=k;c[k>>2]=0;c[k+4>>2]=0;m=e+460|0;n=e+464|0;o=e+600|0;p=k;q=k+2|0;r=e+1408|0;s=0;t=0;a:while(1){u=(a[1253393+(s<<1)|0]|0)+f|0;v=(a[1253392+(s<<1)|0]|0)+g<<16;w=v>>16;do{if((v|0)<0){x=t}else{y=c[m>>2]|0;if((w|0)>=(y|0)){x=t;break}z=u<<16;A=z>>16;if((z|0)<0){x=t;break}if((A|0)>=(c[n>>2]|0)){x=t;break}z=(ca(y,A)|0)+w|0;A=c[o>>2]|0;if((c[1251712+(d[A+(z<<3)|0]<<2)>>2]|0)!=(h|0)){x=t;break}y=b[A+(z<<3)+4>>1]|0;if(y<<16>>16==(b[p>>1]|0)){if((b[A+(z<<3)+6>>1]|0)==(b[q>>1]|0)){x=t;break}}if(y<<16>>16==0){if((b[A+(z<<3)+6>>1]|0)==0){x=t;break}}c[l+(t<<2)>>2]=c[A+(z<<3)+4>>2];if((t|0)>0){B=-1;C=14;break a}c[r>>2]=s;x=t+1|0}}while(0);w=s+1|0;if((w|0)<12){s=w;t=x}else{B=x;C=14;break}}if((C|0)==14){c[e+1400>>2]=c[k>>2];c[e+1404>>2]=c[l+4>>2];i=j;return B+1|0}return 0}function Q9a(a,b){a=a|0;b=b|0;var d=0;d=a|0;if((b|0)==91){c[d>>2]=508;c[a+4>>2]=900;return}else{c[d>>2]=326;c[a+4>>2]=1324;c[a+8>>2]=534;return}}function R9a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=e<<1;g=0;h=b;while(1){b=d[h]|0;i=h-1|0;j=d[i]|0;k=(d[h-2|0]|0)+4-(d[h+1|0]|0)+((b-j|0)*3|0)|0;l=k>>31;m=(l^k>>3)-l|0;k=(m&-((m|0)<(f|0)|0))-e|0;m=k>>31;n=l+e+m-(m^k)^l;l=n+j|0;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[i]=o;i=b-n|0;if(i>>>0>255>>>0){p=-i>>31&255}else{p=i&255}a[h]=p;i=g+1|0;if((i|0)<12){g=i;h=h+c|0}else{break}}return}function S9a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=-(c<<1)|0;g=-c|0;h=e<<1;i=0;j=b;while(1){b=j+g|0;k=d[b]|0;l=(d[j+f|0]|0)+4-(d[j+c|0]|0)+(((d[j]|0)-k|0)*3|0)|0;m=l>>31;n=(m^l>>3)-m|0;l=(n&-((n|0)<(h|0)|0))-e|0;n=l>>31;o=m+e+n-(n^l)^m;m=o+k|0;if(m>>>0>255>>>0){p=-m>>31&255}else{p=m&255}a[b]=p;b=(d[j]|0)-o|0;if(b>>>0>255>>>0){q=-b>>31&255}else{q=b&255}a[j]=q;b=i+1|0;if((b|0)<12){i=b;j=j+1|0}else{break}}return}function T9a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=~e;g=e-1|0;h=e<<1;e=0;i=b;while(1){b=d[i]|0;j=i-1|0;k=d[j]|0;l=(d[i-2|0]|0)+4-(d[i+1|0]|0)+((b-k|0)*3|0)|0;m=l>>3;n=l>>31;l=(n^m)-n|0;if((l+f|0)>>>0<g>>>0){o=n+h-l^n}else{o=m}m=k+o|0;if(m>>>0>255>>>0){p=-m>>31&255}else{p=m&255}a[j]=p;j=b-o|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[i]=q;j=e+1|0;if((j|0)<12){e=j;i=i+c|0}else{break}}return}function U9a(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=-(c<<1)|0;g=-c|0;h=~e;i=e-1|0;j=e<<1;e=0;k=b;while(1){b=k+g|0;l=d[b]|0;m=(d[k+f|0]|0)+4-(d[k+c|0]|0)+(((d[k]|0)-l|0)*3|0)|0;n=m>>3;o=m>>31;m=(o^n)-o|0;if((m+h|0)>>>0<i>>>0){p=o+j-m^o}else{p=n}n=l+p|0;if(n>>>0>255>>>0){q=-n>>31&255}else{q=n&255}a[b]=q;b=(d[k]|0)-p|0;if(b>>>0>255>>>0){r=-b>>31&255}else{r=b&255}a[k]=r;b=e+1|0;if((b|0)<12){e=b;k=k+1|0}else{break}}return}function V9a(a,b,e){a=a|0;b=b|0;e=e|0;c[a>>2]=255;c[a+4>>2]=-16;c[a+12>>2]=b+e;c[a+8>>2]=b+3;c[a+16>>2]=(d[b+1|0]|0)<<8|(d[b]|0)<<16|(d[b+2|0]|0);return}function W9a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+60>>2]|0;d=c[(c[a+12>>2]|0)+12>>2]|0;e=L9a(a,(d|0)==92|0,(d|0)==107|0)|0;if((e|0)<0){f=e;return f|0}c[b+1416>>2]=0;c[b+1728>>2]=249032;c[b+1732>>2]=110;c[b+1736>>2]=42;c[b+1744>>2]=278;c[b+1748>>2]=272;c[b+1752>>2]=438;c[b+1756>>2]=330;e=b+1696|0;if((c[e>>2]|0)==0){f=0;return f|0}d=pJb(4480)|0;g=b+1760|0;c[g>>2]=d;M9a(a,d,(c[b+1700>>2]|0)==-1|0,c[e>>2]|0)|0;e=c[g>>2]|0;c[e+1416>>2]=0;c[e+1728>>2]=249032;c[e+1732>>2]=110;c[e+1736>>2]=42;c[e+1744>>2]=278;c[e+1748>>2]=272;c[e+1752>>2]=438;c[e+1756>>2]=330;f=0;return f|0}function X9a(a){a=a|0;var b=0;b=c[a+60>>2]|0;N9a(a)|0;Y9a(b);a=b+1760|0;b=c[a>>2]|0;if((b|0)==0){return 0}O9a(b)|0;Y9a(c[a>>2]|0);kJb(c[a>>2]|0);return 0}function Y9a(a){a=a|0;c3(a+3664|0);c3(a+3704|0);c3(a+3744|0);c3(a+3764|0);c3(a+3784|0);c3(a+3804|0);c3(a+3824|0);c3(a+3844|0);c3(a+3864|0);c3(a+3884|0);c3(a+3904|0);c3(a+3924|0);c3(a+3944|0);c3(a+3964|0);c3(a+3984|0);c3(a+4004|0);c3(a+4024|0);c3(a+4044|0);c3(a+4064|0);c3(a+4084|0);c3(a+3684|0);c3(a+3724|0);c3(a+4104|0);c3(a+4124|0);c3(a+4144|0);c3(a+4164|0);c3(a+4184|0);c3(a+4204|0);c3(a+4224|0);c3(a+4244|0);c3(a+4264|0);c3(a+4284|0);c3(a+4304|0);c3(a+4324|0);c3(a+4344|0);c3(a+4364|0);c3(a+4384|0);c3(a+4404|0);c3(a+4424|0);c3(a+4444|0);return}function Z9a(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;g=c[e+1764>>2]|0;h=f|0;b[h>>1]=0;i=f+2|0;b[i>>1]=0;if((c[e+1408>>2]|0)<2){j=c[e+1400>>2]|0;c[f>>2]=j;k=j&65535;l=j>>>16&65535}else{k=0;l=0}j=e+376|0;f=e+380|0;m=e+392|0;n=e+384|0;o=e+388|0;e=a[1251752]|0;p=e<<24>>24>0;q=0;r=c[j>>2]|0;s=c[f>>2]|0;t=c[m>>2]|0;u=k;k=l;while(1){l=a[g+130+q|0]|0;v=d[1252840+r|0]|0;w=r<<v;c[j>>2]=w;x=t<<v;y=s+v|0;do{if((y|0)>-1){v=c[n>>2]|0;if(!(v>>>0<(c[o>>2]|0)>>>0)){z=x;A=y;break}c[n>>2]=v+2;B=v;z=((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)<<y|x;A=y-16|0}else{z=x;A=y}}while(0);c[f>>2]=A;y=((ca(w-1|0,l&255)|0)>>8)+1|0;x=y<<16;B=z>>>0>=x>>>0;v=B?w-y|0:y;c[j>>2]=v;y=z-(B?x:0)|0;c[m>>2]=y;do{if(B){x=0;C=0;D=v;E=A;F=y;while(1){G=d[248696+x|0]|0;H=a[g+150+(q<<3)+G|0]|0;I=d[1252840+D|0]|0;J=D<<I;c[j>>2]=J;K=F<<I;L=E+I|0;do{if((L|0)>-1){I=c[n>>2]|0;if(!(I>>>0<(c[o>>2]|0)>>>0)){M=K;N=L;break}c[n>>2]=I+2;O=I;M=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<L|K;N=L-16|0}else{M=K;N=L}}while(0);c[f>>2]=N;L=((ca(J-1|0,H&255)|0)>>8)+1|0;K=L<<16;O=M>>>0>=K>>>0;P=O?J-L|0:L;c[j>>2]=P;Q=M-(O?K:0)|0;c[m>>2]=Q;R=(O&1)<<G|C;O=x+1|0;if(O>>>0<7>>>0){x=O;C=R;D=P;E=N;F=Q}else{break}}if((R&240|0)==0){S=R|8;T=P;U=N;V=Q;W=28;break}F=a[g+150+(q<<3)+3|0]|0;E=d[1252840+P|0]|0;D=P<<E;c[j>>2]=D;C=Q<<E;x=N+E|0;do{if((x|0)>-1){E=c[n>>2]|0;if(!(E>>>0<(c[o>>2]|0)>>>0)){X=C;Y=x;break}c[n>>2]=E+2;O=E;X=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<x|C;Y=x-16|0}else{X=C;Y=x}}while(0);c[f>>2]=Y;x=((ca(D-1|0,F&255)|0)>>8)+1|0;C=x<<16;O=X>>>0>=C>>>0;E=O?D-x|0:x;c[j>>2]=E;x=X-(O?C:0)|0;c[m>>2]=x;Z=(O&1)<<3|R;_=E;$=Y;aa=x;W=27}else{if(p){x=1251752;E=1251752;O=v;C=A;K=y;while(1){L=a[(a[x+1|0]|0)+(g+136+(q*7|0))|0]|0;I=d[1252840+O|0]|0;ba=O<<I;c[j>>2]=ba;da=K<<I;ea=I+C|0;do{if((ea|0)>-1){I=c[n>>2]|0;if(!(I>>>0<(c[o>>2]|0)>>>0)){fa=da;ga=ea;break}c[n>>2]=I+2;ha=I;fa=((he((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535)<<ea|da;ga=ea-16|0}else{fa=da;ga=ea}}while(0);c[f>>2]=ga;ea=((ca(ba-1|0,L&255)|0)>>8)+1|0;da=ea<<16;G=fa>>>0>=da>>>0;J=G?ba-ea|0:ea;c[j>>2]=J;ea=fa-(G?da:0)|0;c[m>>2]=ea;if(G){ia=x+(a[E]<<1)|0}else{ia=x+2|0}G=ia|0;da=a[G]|0;if(da<<24>>24>0){x=ia;E=G;O=J;C=ga;K=ea}else{ja=da;ka=J;la=ga;ma=ea;break}}}else{ja=e;ka=v;la=A;ma=y}Z=-(ja<<24>>24)|0;_=ka;$=la;aa=ma;W=27}}while(0);if((W|0)==27){W=0;if((Z|0)==0){na=0;oa=_;pa=$;qa=aa}else{S=Z;T=_;U=$;V=aa;W=28}}if((W|0)==28){W=0;y=a[g+128+q|0]|0;v=d[1252840+T|0]|0;B=T<<v;c[j>>2]=B;w=V<<v;l=U+v|0;do{if((l|0)>-1){v=c[n>>2]|0;if(!(v>>>0<(c[o>>2]|0)>>>0)){ra=w;sa=l;break}c[n>>2]=v+2;K=v;ra=((he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535)<<l|w;sa=l-16|0}else{ra=w;sa=l}}while(0);c[f>>2]=sa;l=((ca(B-1|0,y&255)|0)>>8)+1|0;w=l<<16;K=ra>>>0>=w>>>0;v=K?B-l|0:l;c[j>>2]=v;l=ra-(K?w:0)|0;c[m>>2]=l;na=K?-S|0:S;oa=v;pa=sa;qa=l}if((q|0)==0){l=(u&65535)+na&65535;b[h>>1]=l;q=q+1|0;r=oa;s=pa;t=qa;u=l;k=k;continue}else{l=(k&65535)+na&65535;b[i>>1]=l;v=q+1|0;if((v|0)<2){q=v;r=oa;s=pa;t=qa;u=u;k=l;continue}else{break}}}return}function _9a(e,f,g,h,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;p=i;q=l;l=i;i=i+4|0;i=i+7&-8;c[l>>2]=c[q>>2];q=b[l>>1]|0;r=q<<16>>16;s=r&m;t=b[l+2>>1]|0;l=t<<16>>16;u=l&m;do{if((o|0)==0){v=u;w=s;x=0}else{m=s<<1;y=u<<1;z=c[e+1424>>2]|0;if((z|0)!=2){v=y;w=m;x=z;break}z=c[e+1428>>2]|0;if((z|0)!=0){if(((q<<16>>16>-1?r:-r|0)|0)>(z|0)){v=y;w=m;x=0;break}if(((t<<16>>16>-1?l:-l|0)|0)>(z|0)){v=y;w=m;x=0;break}}z=c[e+1432>>2]|0;if((z|0)==0){v=y;w=m;x=2;break}A=k<<1;B=d[g+h|0]|0;C=ca(B,B)|0;D=h+2|0;E=d[g+D|0]|0;F=(ca(E,E)|0)+C|0;C=h+4|0;G=d[g+C|0]|0;H=F+(ca(G,G)|0)|0;F=h+6|0;I=d[g+F|0]|0;J=H+(ca(I,I)|0)|0;H=d[g+(A+h)|0]|0;K=J+(ca(H,H)|0)|0;J=d[g+(D+A)|0]|0;L=K+(ca(J,J)|0)|0;K=d[g+(C+A)|0]|0;M=L+(ca(K,K)|0)|0;L=d[g+(F+A)|0]|0;N=M+(ca(L,L)|0)|0;M=k<<2;O=d[g+(M+h)|0]|0;P=N+(ca(O,O)|0)|0;N=d[g+((M|2)+h)|0]|0;Q=P+(ca(N,N)|0)|0;P=d[g+(C+M)|0]|0;R=Q+(ca(P,P)|0)|0;Q=d[g+(F+M)|0]|0;S=R+(ca(Q,Q)|0)|0;R=M+A|0;A=d[g+(R+h)|0]|0;M=S+(ca(A,A)|0)|0;S=d[g+(D+R)|0]|0;D=M+(ca(S,S)|0)|0;M=d[g+(C+R)|0]|0;C=D+(ca(M,M)|0)|0;D=d[g+(F+R)|0]|0;R=E+B+G+I+H+J+K+L+O+N+P+Q+A+S+M+D|0;M=((C+(ca(D,D)|0)<<4)-(ca(R,R)|0)>>8|0)<(z|0);v=y;w=m;x=M?0:2}}while(0);l=(v|0)!=0;if(l){if((ca(c[e+1700>>2]|0,j-h|0)|0)<0){T=11}else{U=h}}else{if((h|0)>(j|0)){T=11}else{U=h}}if((T|0)==11){U=j}if((x|0)==0){if((w|0)==0|l^1){_e[c[e+4>>2]&511](f,g+U|0,k,8,w,v);i=p;return}else{x=(c[e+372>>2]|0)+16|0;j=e+4|0;_e[c[j>>2]&511](x,g+(((t^q)<<16>>16>>31)+U)|0,k,9,w,0);_e[c[j>>2]&511](f,x,k,8,0,v);i=p;return}}if(!l){l=b[249168+(n<<6)+(w<<3)>>1]|0;x=b[249168+(n<<6)+(w<<3)+2>>1]|0;j=b[249168+(n<<6)+(w<<3)+4>>1]|0;T=b[249168+(n<<6)+(w<<3)+6>>1]|0;h=g+U|0;r=f;u=0;while(1){s=0;while(1){o=ca(l,d[h+(s-1)|0]|0)|0;M=ca(x,d[h+s|0]|0)|0;m=s+1|0;y=ca(j,d[h+m|0]|0)|0;z=o+64+M+y+(ca(T,d[h+(s+2)|0]|0)|0)>>7;if(z>>>0>255>>>0){V=-z>>31&255}else{V=z&255}a[r+s|0]=V;if((m|0)<8){s=m}else{break}}s=u+1|0;if((s|0)<8){h=h+k|0;r=r+k|0;u=s}else{break}}i=p;return}if((w|0)!=0){pe[c[e+284>>2]&1023](f,g+(((t^q)<<16>>16>>31)+U)|0,k,249168+(n<<6)+(w<<3)|0,249168+(n<<6)+(v<<3)|0);i=p;return}w=k<<1;q=b[249168+(n<<6)+(v<<3)>>1]|0;t=b[249168+(n<<6)+(v<<3)+2>>1]|0;e=b[249168+(n<<6)+(v<<3)+4>>1]|0;u=b[249168+(n<<6)+(v<<3)+6>>1]|0;v=g+U|0;U=f;f=0;while(1){g=0;do{n=ca(q,d[v+(g-k)|0]|0)|0;r=ca(t,d[v+g|0]|0)|0;h=ca(e,d[v+(g+k)|0]|0)|0;V=n+64+r+h+(ca(u,d[v+(g+w)|0]|0)|0)>>7;if(V>>>0>255>>>0){W=-V>>31&255}else{W=V&255}a[U+g|0]=W;g=g+1|0;}while((g|0)<8);g=f+1|0;if((g|0)<8){v=v+k|0;U=U+k|0;f=g}else{break}}i=p;return}function $9a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+1764|0;b=c[e>>2]|0;a[b+130|0]=-94;a[b+131|0]=-92;a[b+128|0]=-128;a[b+129|0]=-128;nrc(b+1812|0,1253168,60)|0;nrc(b+150|0,248808,16)|0;nrc(b+136|0,248792,14)|0;nrc(b+1484|0,248760,28)|0;nrc(b|0,248824,64)|0;a[(c[e>>2]|0)+64|0]=0;b=0;f=1;while(1){g=1;h=f;while(1){i=c[e>>2]|0;if((d[i+g|0]|0|0)==(b|0)){a[i+64+h|0]=g;j=h+1|0}else{j=h}i=g+1|0;if((i|0)<64){g=i;h=j}else{break}}h=b+1|0;if((h|0)<16){b=h;f=j}else{break}}return}function aab(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;e=c[b+1764>>2]|0;f=b+376|0;g=b+380|0;h=b+392|0;i=b+384|0;j=b+388|0;b=0;while(1){k=a[248200+(b<<1)|0]|0;l=c[f>>2]|0;m=d[1252840+l|0]|0;n=c[g>>2]|0;o=c[h>>2]|0;p=l<<m;c[f>>2]=p;l=o<<m;o=n+m|0;do{if((o|0)>-1){m=c[i>>2]|0;if(!(m>>>0<(c[j>>2]|0)>>>0)){q=l;r=o;break}c[i>>2]=m+2;n=m;q=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<o|l;r=o-16|0}else{q=l;r=o}}while(0);c[g>>2]=r;o=((ca(p-1|0,k&255)|0)>>8)+1|0;l=o<<16;n=q>>>0>=l>>>0;m=n?p-o|0:o;c[f>>2]=m;o=q-(n?l:0)|0;c[h>>2]=o;if(n){n=7;l=0;s=m;t=r;u=o;while(1){v=n-1|0;w=l<<1;x=d[1252840+s|0]|0;y=s<<x;c[f>>2]=y;z=u<<x;A=x+t|0;do{if((A|0)>-1){x=c[i>>2]|0;if(!(x>>>0<(c[j>>2]|0)>>>0)){B=z;C=A;break}c[i>>2]=x+2;D=x;B=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<A|z;C=A-16|0}else{B=z;C=A}}while(0);c[g>>2]=C;A=y+1>>1;z=A<<16;D=B>>>0>=z>>>0;if(D){x=y-A|0;c[f>>2]=x;E=B-z|0;F=x}else{c[f>>2]=A;E=B;F=A}c[h>>2]=E;G=D&1|w;if((v|0)==0){break}else{n=v;l=G;s=F;t=C;u=E}}u=G<<1;a[e+130+b|0]=(u|0)==0|u;H=c[f>>2]|0;I=c[g>>2]|0;J=c[h>>2]|0}else{H=m;I=r;J=o}u=a[248201+(b<<1)|0]|0;t=d[1252840+H|0]|0;s=H<<t;c[f>>2]=s;l=J<<t;n=I+t|0;do{if((n|0)>-1){t=c[i>>2]|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){K=l;L=n;break}c[i>>2]=t+2;p=t;K=((he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535)<<n|l;L=n-16|0}else{K=l;L=n}}while(0);c[g>>2]=L;n=((ca(s-1|0,u&255)|0)>>8)+1|0;l=n<<16;o=K>>>0>=l>>>0;m=o?s-n|0:n;c[f>>2]=m;n=K-(o?l:0)|0;c[h>>2]=n;if(o){o=7;l=0;p=m;m=L;t=n;while(1){n=o-1|0;k=l<<1;D=d[1252840+p|0]|0;A=p<<D;c[f>>2]=A;x=t<<D;z=D+m|0;do{if((z|0)>-1){D=c[i>>2]|0;if(!(D>>>0<(c[j>>2]|0)>>>0)){M=x;N=z;break}c[i>>2]=D+2;O=D;M=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<z|x;N=z-16|0}else{M=x;N=z}}while(0);c[g>>2]=N;z=A+1>>1;x=z<<16;v=M>>>0>=x>>>0;if(v){w=A-z|0;c[f>>2]=w;P=M-x|0;Q=w}else{c[f>>2]=z;P=M;Q=z}c[h>>2]=P;R=v&1|k;if((n|0)==0){break}else{o=n;l=R;p=Q;m=N;t=P}}t=R<<1;a[e+128+b|0]=(t|0)==0|t}t=b+1|0;if((t|0)<2){b=t}else{S=0;break}}while(1){b=0;do{R=a[248640+(S*7|0)+b|0]|0;P=c[f>>2]|0;N=d[1252840+P|0]|0;Q=c[g>>2]|0;M=c[h>>2]|0;L=P<<N;c[f>>2]=L;P=M<<N;M=Q+N|0;do{if((M|0)>-1){N=c[i>>2]|0;if(!(N>>>0<(c[j>>2]|0)>>>0)){T=P;U=M;break}c[i>>2]=N+2;Q=N;T=((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<M|P;U=M-16|0}else{T=P;U=M}}while(0);c[g>>2]=U;M=((ca(L-1|0,R&255)|0)>>8)+1|0;P=M<<16;n=T>>>0>=P>>>0;k=n?L-M|0:M;c[f>>2]=k;M=T-(n?P:0)|0;c[h>>2]=M;if(n){n=7;P=0;A=k;k=U;Q=M;while(1){M=n-1|0;N=P<<1;K=d[1252840+A|0]|0;I=A<<K;c[f>>2]=I;J=Q<<K;H=K+k|0;do{if((H|0)>-1){K=c[i>>2]|0;if(!(K>>>0<(c[j>>2]|0)>>>0)){V=J;W=H;break}c[i>>2]=K+2;r=K;V=((he((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535)<<H|J;W=H-16|0}else{V=J;W=H}}while(0);c[g>>2]=W;H=I+1>>1;J=H<<16;r=V>>>0>=J>>>0;if(r){K=I-H|0;c[f>>2]=K;X=V-J|0;Y=K}else{c[f>>2]=H;X=V;Y=H}c[h>>2]=X;Z=r&1|N;if((M|0)==0){break}else{n=M;P=Z;A=Y;k=W;Q=X}}Q=Z<<1;a[e+136+(S*7|0)+b|0]=(Q|0)==0|Q}b=b+1|0;}while((b|0)<7);b=S+1|0;if((b|0)<2){S=b}else{_=0;break}}do{S=0;do{Z=a[248744+(_<<3)+S|0]|0;X=c[f>>2]|0;W=d[1252840+X|0]|0;Y=c[g>>2]|0;V=c[h>>2]|0;U=X<<W;c[f>>2]=U;X=V<<W;V=Y+W|0;do{if((V|0)>-1){W=c[i>>2]|0;if(!(W>>>0<(c[j>>2]|0)>>>0)){$=X;aa=V;break}c[i>>2]=W+2;Y=W;$=((he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<V|X;aa=V-16|0}else{$=X;aa=V}}while(0);c[g>>2]=aa;V=((ca(U-1|0,Z&255)|0)>>8)+1|0;X=V<<16;Y=$>>>0>=X>>>0;W=Y?U-V|0:V;c[f>>2]=W;V=$-(Y?X:0)|0;c[h>>2]=V;if(Y){Y=7;X=0;T=W;W=aa;b=V;while(1){V=Y-1|0;Q=X<<1;k=d[1252840+T|0]|0;A=T<<k;c[f>>2]=A;P=b<<k;n=k+W|0;do{if((n|0)>-1){k=c[i>>2]|0;if(!(k>>>0<(c[j>>2]|0)>>>0)){ba=P;da=n;break}c[i>>2]=k+2;L=k;ba=((he((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<n|P;da=n-16|0}else{ba=P;da=n}}while(0);c[g>>2]=da;n=A+1>>1;P=n<<16;M=ba>>>0>=P>>>0;if(M){N=A-n|0;c[f>>2]=N;ea=ba-P|0;fa=N}else{c[f>>2]=n;ea=ba;fa=n}c[h>>2]=ea;ga=M&1|Q;if((V|0)==0){break}else{Y=V;X=ga;T=fa;W=da;b=ea}}b=ga<<1;a[e+150+(_<<3)+S|0]=(b|0)==0|b}S=S+1|0;}while((S|0)<8);_=_+1|0;}while((_|0)<2);return}function bab(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;e=i;i=i+240|0;f=e|0;g=e+192|0;h=b+1764|0;j=c[h>>2]|0;mrc(g|0,-128|0,44)|0;k=b+376|0;l=b+380|0;m=b+392|0;n=b+384|0;o=b+388|0;p=b+352|0;q=0;do{r=0;do{s=a[248888+(q*11|0)+r|0]|0;t=c[k>>2]|0;u=d[1252840+t|0]|0;v=c[l>>2]|0;w=c[m>>2]|0;x=t<<u;c[k>>2]=x;t=w<<u;w=v+u|0;do{if((w|0)>-1){u=c[n>>2]|0;if(!(u>>>0<(c[o>>2]|0)>>>0)){y=t;z=w;break}c[n>>2]=u+2;v=u;y=((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)<<w|t;z=w-16|0}else{y=t;z=w}}while(0);c[l>>2]=z;w=((ca(x-1|0,s&255)|0)>>8)+1|0;t=w<<16;v=y>>>0>=t>>>0;u=v?x-w|0:w;c[k>>2]=u;w=y-(v?t:0)|0;c[m>>2]=w;do{if(v){t=7;A=0;B=u;C=z;D=w;while(1){E=t-1|0;F=A<<1;G=d[1252840+B|0]|0;H=B<<G;c[k>>2]=H;I=D<<G;J=G+C|0;do{if((J|0)>-1){G=c[n>>2]|0;if(!(G>>>0<(c[o>>2]|0)>>>0)){K=I;L=J;break}c[n>>2]=G+2;M=G;K=((he((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535)<<J|I;L=J-16|0}else{K=I;L=J}}while(0);c[l>>2]=L;J=H+1>>1;I=J<<16;M=K>>>0>=I>>>0;if(M){G=H-J|0;c[k>>2]=G;N=K-I|0;O=G}else{c[k>>2]=J;N=K;O=J}c[m>>2]=N;P=M&1|F;if((E|0)==0){break}else{t=E;A=P;B=O;C=L;D=N}}D=P<<1;C=(D|0)==0|D;c[g+(r<<2)>>2]=C;a[j+166+(q*11|0)+r|0]=C}else{if((c[(c[p>>2]|0)+84>>2]|0)==0){break}a[j+166+(q*11|0)+r|0]=c[g+(r<<2)>>2]}}while(0);r=r+1|0;}while((r|0)<11);q=q+1|0;}while((q|0)<2);q=c[k>>2]|0;P=d[1252840+q|0]|0;N=c[l>>2]|0;L=c[m>>2]|0;O=q<<P;c[k>>2]=O;q=L<<P;L=N+P|0;do{if((L|0)>-1){P=c[n>>2]|0;if(!(P>>>0<(c[o>>2]|0)>>>0)){Q=q;R=L;break}c[n>>2]=P+2;N=P;Q=((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<L|q;R=L-16|0}else{Q=q;R=L}}while(0);c[l>>2]=R;L=O+1>>1;q=L<<16;if(Q>>>0<q>>>0){c[k>>2]=L;c[m>>2]=Q;S=0}else{N=O-L|0;c[k>>2]=N;L=Q-q|0;c[m>>2]=L;q=1;Q=N;N=R;R=L;while(1){L=a[249040+q|0]|0;O=d[1252840+Q|0]|0;P=Q<<O;c[k>>2]=P;K=R<<O;z=N+O|0;do{if((z|0)>-1){O=c[n>>2]|0;if(!(O>>>0<(c[o>>2]|0)>>>0)){T=K;U=z;break}c[n>>2]=O+2;y=O;T=((he((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535)<<z|K;U=z-16|0}else{T=K;U=z}}while(0);c[l>>2]=U;z=((ca(P-1|0,L&255)|0)>>8)+1|0;K=z<<16;y=T>>>0>=K>>>0;O=y?P-z|0:z;c[k>>2]=O;z=T-(y?K:0)|0;c[m>>2]=z;if(y){y=4;K=0;r=O;O=U;w=z;while(1){z=y-1|0;u=K<<1;v=d[1252840+r|0]|0;x=r<<v;c[k>>2]=x;s=w<<v;C=v+O|0;do{if((C|0)>-1){v=c[n>>2]|0;if(!(v>>>0<(c[o>>2]|0)>>>0)){V=s;W=C;break}c[n>>2]=v+2;D=v;V=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<C|s;W=C-16|0}else{V=s;W=C}}while(0);c[l>>2]=W;C=x+1>>1;s=C<<16;D=V>>>0>=s>>>0;if(D){v=x-C|0;c[k>>2]=v;X=V-s|0;Y=v}else{c[k>>2]=C;X=V;Y=C}c[m>>2]=X;Z=D&1|u;if((z|0)==0){break}else{y=z;K=Z;r=Y;O=W;w=X}}a[j+q|0]=Z}w=q+1|0;if((w|0)>=64){break}q=w;Q=c[k>>2]|0;N=c[l>>2]|0;R=c[m>>2]|0}a[(c[h>>2]|0)+64|0]=0;R=0;N=1;while(1){Q=1;q=N;while(1){Z=c[h>>2]|0;if((d[Z+Q|0]|0|0)==(R|0)){a[Z+64+q|0]=Q;_=q+1|0}else{_=q}Z=Q+1|0;if((Z|0)<64){Q=Z;q=_}else{break}}q=R+1|0;if((q|0)<16){R=q;N=_}else{S=0;break}}}while(1){_=0;do{N=a[248208+(S*14|0)+_|0]|0;R=c[k>>2]|0;h=d[1252840+R|0]|0;q=c[l>>2]|0;Q=c[m>>2]|0;Z=R<<h;c[k>>2]=Z;R=Q<<h;Q=q+h|0;do{if((Q|0)>-1){h=c[n>>2]|0;if(!(h>>>0<(c[o>>2]|0)>>>0)){$=R;aa=Q;break}c[n>>2]=h+2;q=h;$=((he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<Q|R;aa=Q-16|0}else{$=R;aa=Q}}while(0);c[l>>2]=aa;Q=((ca(Z-1|0,N&255)|0)>>8)+1|0;R=Q<<16;z=$>>>0>=R>>>0;u=z?Z-Q|0:Q;c[k>>2]=u;Q=$-(z?R:0)|0;c[m>>2]=Q;if(z){z=7;R=0;x=u;u=aa;q=Q;while(1){Q=z-1|0;h=R<<1;X=d[1252840+x|0]|0;W=x<<X;c[k>>2]=W;Y=q<<X;V=X+u|0;do{if((V|0)>-1){X=c[n>>2]|0;if(!(X>>>0<(c[o>>2]|0)>>>0)){ba=Y;da=V;break}c[n>>2]=X+2;U=X;ba=((he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)<<V|Y;da=V-16|0}else{ba=Y;da=V}}while(0);c[l>>2]=da;V=W+1>>1;Y=V<<16;U=ba>>>0>=Y>>>0;if(U){X=W-V|0;c[k>>2]=X;ea=ba-Y|0;fa=X}else{c[k>>2]=V;ea=ba;fa=V}c[m>>2]=ea;ga=U&1|h;if((Q|0)==0){break}else{z=Q;R=ga;x=fa;u=da;q=ea}}q=ga<<1;a[j+1484+(S*14|0)+_|0]=(q|0)==0|q}_=_+1|0;}while((_|0)<14);_=S+1|0;if((_|0)<2){S=_}else{ha=0;break}}do{S=0;do{ga=0;do{ea=0;do{da=a[248240+(ha*132|0)+(S*66|0)+(ga*11|0)+ea|0]|0;fa=c[k>>2]|0;ba=d[1252840+fa|0]|0;aa=c[l>>2]|0;$=c[m>>2]|0;_=fa<<ba;c[k>>2]=_;fa=$<<ba;$=aa+ba|0;do{if(($|0)>-1){ba=c[n>>2]|0;if(!(ba>>>0<(c[o>>2]|0)>>>0)){ia=fa;ja=$;break}c[n>>2]=ba+2;aa=ba;ia=((he((d[aa]|d[aa+1|0]<<8)<<16>>16|0)|0)&65535)<<$|fa;ja=$-16|0}else{ia=fa;ja=$}}while(0);c[l>>2]=ja;$=((ca(_-1|0,da&255)|0)>>8)+1|0;fa=$<<16;E=ia>>>0>=fa>>>0;F=E?_-$|0:$;c[k>>2]=F;$=ia-(E?fa:0)|0;c[m>>2]=$;do{if(E){fa=7;H=0;aa=F;ba=ja;q=$;while(1){u=fa-1|0;x=H<<1;R=d[1252840+aa|0]|0;z=aa<<R;c[k>>2]=z;Z=q<<R;N=R+ba|0;do{if((N|0)>-1){R=c[n>>2]|0;if(!(R>>>0<(c[o>>2]|0)>>>0)){ka=Z;la=N;break}c[n>>2]=R+2;U=R;ka=((he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)<<N|Z;la=N-16|0}else{ka=Z;la=N}}while(0);c[l>>2]=la;N=z+1>>1;Z=N<<16;U=ka>>>0>=Z>>>0;if(U){R=z-N|0;c[k>>2]=R;ma=ka-Z|0;na=R}else{c[k>>2]=N;ma=ka;na=N}c[m>>2]=ma;oa=U&1|x;if((u|0)==0){break}else{fa=u;H=oa;aa=na;ba=la;q=ma}}q=oa<<1;ba=(q|0)==0|q;c[g+(ea<<2)>>2]=ba;a[j+188+(S*198|0)+(ha*66|0)+(ga*11|0)+ea|0]=ba}else{if((c[(c[p>>2]|0)+84>>2]|0)==0){break}a[j+188+(S*198|0)+(ha*66|0)+(ga*11|0)+ea|0]=c[g+(ea<<2)>>2]}}while(0);ea=ea+1|0;}while((ea|0)<11);ga=ga+1|0;}while((ga|0)<6);S=S+1|0;}while((S|0)<2);ha=ha+1|0;}while((ha|0)<3);if((c[b+3640>>2]|0)==0){ha=0;while(1){g=0;do{p=(ca(d[j+166+(ha*11|0)|0]|0,c[248912+(g*40|0)>>2]|0)|0)+128>>8;oa=p+(c[248916+(g*40|0)>>2]|0)|0;if((oa|0)<1){pa=1}else{pa=(oa|0)>255?-1:oa&255}a[j+1124+(ha*180|0)+(g*5|0)|0]=pa;oa=(ca(d[j+166+(ha*11|0)+1|0]|0,c[248920+(g*40|0)>>2]|0)|0)+128>>8;p=oa+(c[248924+(g*40|0)>>2]|0)|0;if((p|0)<1){qa=1}else{qa=(p|0)>255?-1:p&255}a[j+1124+(ha*180|0)+(g*5|0)+1|0]=qa;p=(ca(d[j+166+(ha*11|0)+2|0]|0,c[248928+(g*40|0)>>2]|0)|0)+128>>8;oa=p+(c[248932+(g*40|0)>>2]|0)|0;if((oa|0)<1){ra=1}else{ra=(oa|0)>255?-1:oa&255}a[j+1124+(ha*180|0)+(g*5|0)+2|0]=ra;oa=(ca(d[j+166+(ha*11|0)+3|0]|0,c[248936+(g*40|0)>>2]|0)|0)+128>>8;p=oa+(c[248940+(g*40|0)>>2]|0)|0;if((p|0)<1){sa=1}else{sa=(p|0)>255?-1:p&255}a[j+1124+(ha*180|0)+(g*5|0)+3|0]=sa;p=(ca(d[j+166+(ha*11|0)+4|0]|0,c[248944+(g*40|0)>>2]|0)|0)+128>>8;oa=p+(c[248948+(g*40|0)>>2]|0)|0;if((oa|0)<1){ta=1}else{ta=(oa|0)>255?-1:oa&255}a[j+1124+(ha*180|0)+(g*5|0)+4|0]=ta;g=g+1|0;}while((g|0)<3);g=ha+1|0;if((g|0)<2){ha=g}else{ua=0;break}}i=e;return ua|0}ha=f+100|0;ta=b|0;sa=f|0;ra=f+76|0;qa=0;a:while(1){c[ha>>2]=256;pa=0;do{g=c[f+(pa+12<<3)+4>>2]|0;oa=d[j+166+(qa*11|0)+pa|0]|0;p=(ca(oa,g)|0)>>>8;ma=(ca(oa^255,g)|0)>>>8;g=pa<<1;c[f+((d[248720+g|0]|0)<<3)+4>>2]=((p|0)==0)+p;c[f+((d[248720+(g|1)|0]|0)<<3)+4>>2]=((ma|0)==0)+ma;pa=pa+1|0;}while(pa>>>0<11>>>0);pa=b+3664+(qa*20|0)|0;c3(pa);if((QKa(c[ta>>2]|0,pa,12,10,sa,36,1)|0)!=0){ua=-1;va=102;break}c[ra>>2]=256;pa=0;do{ma=c[f+(pa+9<<3)+4>>2]|0;g=d[j+1484+(qa*14|0)+pa|0]|0;p=(ca(g,ma)|0)>>>8;oa=(ca(g^255,ma)|0)>>>8;ma=pa<<1;c[f+((d[248704+ma|0]|0)<<3)+4>>2]=((p|0)==0)+p;c[f+((d[248704+(ma|1)|0]|0)<<3)+4>>2]=((oa|0)==0)+oa;pa=pa+1|0;}while(pa>>>0<8>>>0);pa=b+3704+(qa*20|0)|0;c3(pa);if((QKa(c[ta>>2]|0,pa,9,10,sa,36,1)|0)==0){wa=0}else{ua=-1;va=102;break}do{pa=0;while(1){if((pa|0)>=6){break}c[ha>>2]=256;oa=0;do{ma=c[f+(oa+12<<3)+4>>2]|0;p=d[j+188+(qa*198|0)+(wa*66|0)+(pa*11|0)+oa|0]|0;g=(ca(p,ma)|0)>>>8;la=(ca(p^255,ma)|0)>>>8;ma=oa<<1;c[f+((d[248720+ma|0]|0)<<3)+4>>2]=((g|0)==0)+g;c[f+((d[248720+(ma|1)|0]|0)<<3)+4>>2]=((la|0)==0)+la;oa=oa+1|0;}while(oa>>>0<11>>>0);oa=b+3744+(qa*360|0)+(wa*120|0)+(pa*20|0)|0;c3(oa);if((QKa(c[ta>>2]|0,oa,12,10,sa,36,1)|0)==0){pa=pa+1|0}else{ua=-1;va=102;break a}}wa=wa+1|0;}while((wa|0)<3);pa=qa+1|0;if((pa|0)<2){qa=pa}else{va=96;break}}if((va|0)==96){mrc(b+4464|0,0,16)|0;ua=0;i=e;return ua|0}else if((va|0)==102){i=e;return ua|0}return 0}function cab(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0;g=i;h=b+376|0;j=d[e]|0;k=j&1;l=b+352|0;c[(c[l>>2]|0)+84>>2]=j>>>7^1;I9a(b,(d[e]|0)>>>1&63);do{if((c[(c[l>>2]|0)+84>>2]|0)==0){j=b+420|0;if((c[j>>2]|0)==0){m=-1094995529;i=g;return m|0}n=c[b>>2]|0;if((c[n+128>>2]|0)==0){m=-1094995529;i=g;return m|0}if((c[n+132>>2]|0)==0){m=-1094995529;i=g;return m|0}if((k|0)==0){if((c[b+1412>>2]|0)==0){o=33}else{p=e;q=f;r=0}}else{o=33}if((o|0)==33){n=e+1|0;p=e+2|0;q=f-2|0;r=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)-2|0}V9a(h,p+1|0,q-1|0);n=h|0;s=c[n>>2]|0;t=d[1252840+s|0]|0;u=b+380|0;v=c[u>>2]|0;w=b+392|0;x=c[w>>2]|0;y=s<<t;c[n>>2]=y;s=x<<t;x=v+t|0;do{if((x|0)>-1){t=b+384|0;v=c[t>>2]|0;if(!(v>>>0<(c[b+388>>2]|0)>>>0)){z=s;A=x;break}c[t>>2]=v+2;t=v;z=((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<x|s;A=x-16|0}else{z=s;A=x}}while(0);c[u>>2]=A;x=y+1>>1;s=x<<16;t=z>>>0>=s>>>0;if(t){v=y-x|0;c[n>>2]=v;B=z-s|0;C=v}else{c[n>>2]=x;B=z;C=x}c[w>>2]=B;c[b+424>>2]=t&1;if((c[b+1412>>2]|0)==0){D=r;E=q;F=0;G=p;H=C;I=A;J=B;K=n;L=u;M=w;break}t=d[1252840+C|0]|0;x=C<<t;c[n>>2]=x;v=B<<t;s=A+t|0;do{if((s|0)>-1){t=b+384|0;N=c[t>>2]|0;if(!(N>>>0<(c[b+388>>2]|0)>>>0)){O=v;P=s;break}c[t>>2]=N+2;t=N;O=((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<s|v;P=s-16|0}else{O=v;P=s}}while(0);c[u>>2]=P;s=x+1>>1;v=s<<16;y=O>>>0>=v>>>0;t=y&1;if(y){y=x-s|0;N=O-v|0;c[w>>2]=N;c[b+1416>>2]=t;v=d[1252840+y|0]|0;Q=y<<v;c[n>>2]=Q;y=N<<v;N=P+v|0;do{if((N|0)>-1){v=b+384|0;R=c[v>>2]|0;if(!(R>>>0<(c[b+388>>2]|0)>>>0)){S=y;T=N;break}c[v>>2]=R+2;v=R;S=((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)<<N|y;T=N-16|0}else{S=y;T=N}}while(0);c[u>>2]=T;N=Q+1>>1;y=N<<16;if(S>>>0<y>>>0){c[n>>2]=N;U=S;V=N}else{x=Q-N|0;c[n>>2]=x;U=S-y|0;V=x}c[w>>2]=U;W=V;X=T;Y=U}else{c[n>>2]=s;c[w>>2]=O;c[b+1416>>2]=t;W=s;X=P;Y=O}x=c[j>>2]|0;if((x|0)<=7){D=r;E=q;F=0;G=p;H=W;I=X;J=Y;K=n;L=u;M=w;break}y=d[1252840+W|0]|0;N=W<<y;c[n>>2]=N;v=Y<<y;R=X+y|0;do{if((R|0)>-1){y=b+384|0;Z=c[y>>2]|0;if(!(Z>>>0<(c[b+388>>2]|0)>>>0)){_=v;$=R;break}c[y>>2]=Z+2;y=Z;_=((he((d[y]|d[y+1|0]<<8)<<16>>16|0)|0)&65535)<<R|v;$=R-16|0}else{_=v;$=R}}while(0);c[u>>2]=$;R=N+1>>1;v=R<<16;j=_>>>0>=v>>>0;if(j){s=N-R|0;c[n>>2]=s;aa=_-v|0;ba=s}else{c[n>>2]=R;aa=_;ba=R}c[w>>2]=aa;ca=p;da=0;ea=q;fa=j&1;ga=r;ha=0;ia=ba;ja=$;ka=aa;la=x;o=61}else{j=e+1|0;R=a[j]|0;s=R&255;v=s>>>3;if((R&255)>>>0>71>>>0){m=-1094995529;i=g;return m|0}t=s&6;s=b+1412|0;c[s>>2]=t;if(!((a[j]&1)==0)){RIb(c[b>>2]|0,2199872,(ma=i,i=i+1|0,i=i+7&-8,c[ma>>2]=0,ma)|0);i=ma;m=-1163346256;i=g;return m|0}if((k|0)!=0|(t|0)==0){t=e+2|0;j=t;na=t;oa=f-2|0;pa=((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)-2|0}else{na=e;oa=f;pa=0}j=a[na+2|0]|0;t=j&255;Q=a[na+3|0]|0;y=Q&255;if(j<<24>>24==0|Q<<24>>24==0){KIb(c[b>>2]|0,16,2168184,(ma=i,i=i+16|0,c[ma>>2]=y<<4,c[ma+8>>2]=t<<4,ma)|0);i=ma;m=-1094995529;i=g;return m|0}do{if((c[b+600>>2]|0)==0){qa=c[b>>2]|0;o=13}else{Q=c[b>>2]|0;if((y<<4|0)!=(c[Q+128>>2]|0)){qa=Q;o=13;break}if((t<<4|0)==(c[Q+132>>2]|0)){ra=0}else{qa=Q;o=13}}}while(0);a:do{if((o|0)==13){x=b|0;do{if((c[qa+100>>2]|0)==0){w=y<<4;if(((c[qa+120>>2]|0)+15&-16|0)!=(w|0)){sa=w;break}n=t<<4;if(((c[qa+124>>2]|0)+15&-16|0)!=(n|0)){sa=w;break}c[qa+128>>2]=w;c[qa+132>>2]=n;ra=1;break a}else{sa=y<<4}}while(0);n=H4a(qa,sa,t<<4)|0;if((n|0)<0){m=n;i=g;return m|0}n=c[x>>2]|0;if((c[n+100>>2]|0)!=1){ra=1;break}w=c[n+96>>2]|0;N=n+120|0;c[N>>2]=(c[N>>2]|0)-((d[w]|0)>>>4);N=n+124|0;c[N>>2]=(c[N>>2]|0)-(a[w]&15);ra=1}}while(0);V9a(h,na+6|0,oa-6|0);t=h|0;y=b+380|0;w=b+392|0;N=b+384|0;n=b+388|0;u=c[t>>2]|0;Q=c[y>>2]|0;j=c[w>>2]|0;Z=d[1252840+u|0]|0;ta=u<<Z;c[t>>2]=ta;u=j<<Z;j=Z+Q|0;do{if((j|0)>-1){Q=c[N>>2]|0;if(!(Q>>>0<(c[n>>2]|0)>>>0)){ua=u;va=j;break}c[N>>2]=Q+2;Z=Q;ua=((he((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0)&65535)<<j|u;va=j-16|0}else{ua=u;va=j}}while(0);c[y>>2]=va;j=ta+1>>1;u=j<<16;if(ua>>>0<u>>>0){c[t>>2]=j;wa=ua;xa=j}else{Z=ta-j|0;c[t>>2]=Z;wa=ua-u|0;xa=Z}c[w>>2]=wa;Z=d[1252840+xa|0]|0;u=xa<<Z;c[t>>2]=u;j=wa<<Z;Q=Z+va|0;do{if((Q|0)>-1){Z=c[N>>2]|0;if(!(Z>>>0<(c[n>>2]|0)>>>0)){ya=j;za=Q;break}c[N>>2]=Z+2;Aa=Z;ya=((he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<Q|j;za=Q-16|0}else{ya=j;za=Q}}while(0);c[y>>2]=za;Q=u+1>>1;j=Q<<16;if(ya>>>0<j>>>0){c[t>>2]=Q;Ba=ya;Ca=Q}else{N=u-Q|0;c[t>>2]=N;Ba=ya-j|0;Ca=N}c[w>>2]=Ba;N=c[s>>2]|0;c[b+420>>2]=v;c[b+424>>2]=0;ca=na;da=ra;ea=oa;fa=N;ga=pa;ha=(R&255)>>>0<64>>>0?5:0;ia=Ca;ja=za;ka=Ba;la=v;o=61}}while(0);do{if((o|0)==61){Ba=h|0;if((fa|0)==0){D=ga;E=ea;F=da;G=ca;H=ia;I=ja;J=ka;K=Ba;L=b+380|0;M=b+392|0;break}za=d[1252840+ia|0]|0;Ca=b+380|0;pa=b+392|0;oa=ia<<za;c[Ba>>2]=oa;ra=ka<<za;na=ja+za|0;do{if((na|0)>-1){za=b+384|0;ya=c[za>>2]|0;if(!(ya>>>0<(c[b+388>>2]|0)>>>0)){Da=ra;Ea=na;break}c[za>>2]=ya+2;za=ya;Da=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<na|ra;Ea=na-16|0}else{Da=ra;Ea=na}}while(0);c[Ca>>2]=Ea;na=oa+1>>1;ra=na<<16;do{if(Da>>>0<ra>>>0){c[pa>>2]=Da;v=d[1252840+na|0]|0;R=na<<v;c[Ba>>2]=R;s=Da<<v;w=Ea+v|0;do{if((w|0)>-1){v=b+384|0;t=c[v>>2]|0;if(!(t>>>0<(c[b+388>>2]|0)>>>0)){Fa=s;Ga=w;break}c[v>>2]=t+2;v=t;Fa=((he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535)<<w|s;Ga=w-16|0}else{Fa=s;Ga=w}}while(0);c[Ca>>2]=Ga;w=R+1>>1;s=w<<16;if(Fa>>>0<s>>>0){c[Ba>>2]=w;c[pa>>2]=Fa;c[b+1424>>2]=0;Ha=w;Ia=Ga;Ja=Fa;break}else{x=R-w|0;c[Ba>>2]=x;w=Fa-s|0;c[pa>>2]=w;c[b+1424>>2]=1;Ha=x;Ia=Ga;Ja=w;break}}else{w=oa-na|0;c[Ba>>2]=w;x=Da-ra|0;c[pa>>2]=x;c[b+1424>>2]=2;s=b+384|0;v=b+388|0;t=5;u=0;y=w;w=Ea;za=x;while(1){x=t-1|0;ya=u<<1;va=d[1252840+y|0]|0;wa=y<<va;c[Ba>>2]=wa;xa=za<<va;ua=va+w|0;do{if((ua|0)>-1){va=c[s>>2]|0;if(!(va>>>0<(c[v>>2]|0)>>>0)){Ka=xa;La=ua;break}c[s>>2]=va+2;sa=va;Ka=((he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<ua|xa;La=ua-16|0}else{Ka=xa;La=ua}}while(0);c[Ca>>2]=La;ua=wa+1>>1;xa=ua<<16;sa=Ka>>>0>=xa>>>0;if(sa){va=wa-ua|0;c[Ba>>2]=va;Ma=Ka-xa|0;Na=va}else{c[Ba>>2]=ua;Ma=Ka;Na=ua}c[pa>>2]=Ma;Oa=sa&1|ya;if((x|0)==0){break}else{t=x;u=Oa;y=Na;w=La;za=Ma}}c[b+1432>>2]=Oa<<ha;za=d[1252840+Na|0]|0;w=Na<<za;c[Ba>>2]=w;y=Ma<<za;u=za+La|0;do{if((u|0)>-1){za=c[s>>2]|0;if(!(za>>>0<(c[v>>2]|0)>>>0)){Pa=y;Qa=u;break}c[s>>2]=za+2;t=za;Pa=((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<u|y;Qa=u-16|0}else{Pa=y;Qa=u}}while(0);c[Ca>>2]=Qa;u=w+1>>1;y=u<<16;t=Pa>>>0>=y>>>0;if(t){za=w-u|0;c[Ba>>2]=za;Ra=Pa-y|0;Sa=za}else{c[Ba>>2]=u;Ra=Pa;Sa=u}c[pa>>2]=Ra;u=(t&1)<<1;t=d[1252840+Sa|0]|0;za=Sa<<t;c[Ba>>2]=za;y=Ra<<t;R=t+Qa|0;do{if((R|0)>-1){t=c[s>>2]|0;if(!(t>>>0<(c[v>>2]|0)>>>0)){Ta=y;Ua=R;break}c[s>>2]=t+2;sa=t;Ta=((he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<R|y;Ua=R-16|0}else{Ta=y;Ua=R}}while(0);c[Ca>>2]=Ua;R=za+1>>1;y=R<<16;w=Ta>>>0>=y>>>0;if(w){sa=za-R|0;c[Ba>>2]=sa;Va=Ta-y|0;Wa=sa}else{c[Ba>>2]=R;Va=Ta;Wa=R}c[pa>>2]=Va;R=(w&1|u)<<1;w=d[1252840+Wa|0]|0;sa=Wa<<w;c[Ba>>2]=sa;y=Va<<w;t=w+Ua|0;do{if((t|0)>-1){w=c[s>>2]|0;if(!(w>>>0<(c[v>>2]|0)>>>0)){Xa=y;Ya=t;break}c[s>>2]=w+2;ua=w;Xa=((he((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<t|y;Ya=t-16|0}else{Xa=y;Ya=t}}while(0);c[Ca>>2]=Ya;t=sa+1>>1;y=t<<16;s=Xa>>>0>=y>>>0;if(s){v=sa-t|0;c[Ba>>2]=v;Za=Xa-y|0;_a=v}else{c[Ba>>2]=t;Za=Xa;_a=t}c[pa>>2]=Za;c[b+1428>>2]=2<<(s&1|R);Ha=_a;Ia=Ya;Ja=Za}}while(0);if((la|0)<=7){c[b+1420>>2]=16;D=ga;E=ea;F=da;G=ca;H=Ha;I=Ia;J=Ja;K=Ba;L=Ca;M=pa;break}ra=b+384|0;na=b+388|0;oa=4;s=0;t=Ha;v=Ia;y=Ja;while(1){u=oa-1|0;za=s<<1;ua=d[1252840+t|0]|0;w=t<<ua;c[Ba>>2]=w;va=y<<ua;xa=ua+v|0;do{if((xa|0)>-1){ua=c[ra>>2]|0;if(!(ua>>>0<(c[na>>2]|0)>>>0)){$a=va;ab=xa;break}c[ra>>2]=ua+2;qa=ua;$a=((he((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<xa|va;ab=xa-16|0}else{$a=va;ab=xa}}while(0);c[Ca>>2]=ab;xa=w+1>>1;va=xa<<16;R=$a>>>0>=va>>>0;if(R){sa=w-xa|0;c[Ba>>2]=sa;bb=$a-va|0;cb=sa}else{c[Ba>>2]=xa;bb=$a;cb=xa}c[pa>>2]=bb;db=R&1|za;if((u|0)==0){break}else{oa=u;s=db;t=cb;v=ab;y=bb}}c[b+1420>>2]=db;D=ga;E=ea;F=da;G=ca;H=cb;I=ab;J=bb;K=Ba;L=Ca;M=pa}}while(0);bb=d[1252840+H|0]|0;ab=H<<bb;c[K>>2]=ab;H=J<<bb;J=I+bb|0;do{if((J|0)>-1){bb=b+384|0;I=c[bb>>2]|0;if(!(I>>>0<(c[b+388>>2]|0)>>>0)){eb=H;fb=J;break}c[bb>>2]=I+2;bb=I;eb=((he((d[bb]|d[bb+1|0]<<8)<<16>>16|0)|0)&65535)<<J|H;fb=J-16|0}else{eb=H;fb=J}}while(0);c[L>>2]=fb;fb=ab+1>>1;L=fb<<16;J=eb>>>0>=L>>>0;if(J){c[K>>2]=ab-fb;gb=eb-L|0}else{c[K>>2]=fb;gb=eb}c[M>>2]=gb;c[b+3640>>2]=J&1;gb=b+1740|0;c[gb>>2]=400;if((D|0)==0){c[b+416>>2]=h;m=F;i=g;return m|0}h=G+D|0;G=E-D|0;if((G|0)<0){if((c[(c[l>>2]|0)+84>>2]|0)==0){m=-1094995529;i=g;return m|0}H4a(c[b>>2]|0,0,0)|0;m=-1094995529;i=g;return m|0}if(J){c[gb>>2]=452;gb=G<<3;J=gb>>>0>2147483639>>>0|(h|0)==0;l=J?0:h;D=J?0:gb;c[b+3644>>2]=l;c[b+3656>>2]=D;c[b+3660>>2]=D+8;c[b+3648>>2]=l+(D>>3);c[b+3652>>2]=0;m=F;i=g;return m|0}else{D=b+396|0;V9a(D,h,G);c[b+416>>2]=D;m=F;i=g;return m|0}return 0}function dab(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0;g=c[f+416>>2]|0;h=c[f+1764>>2]|0;i=f+500|0;j=g|0;k=g+4|0;l=g+16|0;m=g+8|0;n=g+12|0;g=a[1252816]|0;o=g<<24>>24>0;p=f+498|0;q=0;r=0;do{r=(q|0)>3?1:r;s=f+504+((d[1253416+q|0]|0)*12|0)|0;t=f+552+(q<<2)|0;u=1;v=1;w=h+166+(r*11|0)|0;x=h+1124+(r*180|0)+(((d[(c[i>>2]|0)+((c[t>>2]|0)*12|0)|0]|0)+(d[s]|0)|0)*5|0)|0;y=0;a:while(1){do{if((y|0)>1&(v|0)==0){z=c[j>>2]|0;A=c[k>>2]|0;B=c[l>>2]|0;C=9}else{D=a[x]|0;E=c[j>>2]|0;F=d[1252840+E|0]|0;G=c[k>>2]|0;H=c[l>>2]|0;I=E<<F;c[j>>2]=I;E=H<<F;H=G+F|0;do{if((H|0)>-1){F=c[m>>2]|0;if(!(F>>>0<(c[n>>2]|0)>>>0)){J=E;K=H;break}c[m>>2]=F+2;G=F;J=((he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535)<<H|E;K=H-16|0}else{J=E;K=H}}while(0);c[k>>2]=K;H=((ca(I-1|0,D&255)|0)>>8)+1|0;E=H<<16;G=J>>>0>=E>>>0;F=G?I-H|0:H;c[j>>2]=F;H=J-(G?E:0)|0;c[l>>2]=H;if(G){z=F;A=K;B=H;C=9;break}if((y|0)<=0){L=u;M=0;break}G=a[x+1|0]|0;E=d[1252840+F|0]|0;N=F<<E;c[j>>2]=N;F=H<<E;H=K+E|0;do{if((H|0)>-1){E=c[m>>2]|0;if(!(E>>>0<(c[n>>2]|0)>>>0)){O=F;P=H;break}c[m>>2]=E+2;Q=E;O=((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<H|F;P=H-16|0}else{O=F;P=H}}while(0);c[k>>2]=P;H=((ca(N-1|0,G&255)|0)>>8)+1|0;F=H<<16;I=O>>>0>=F>>>0;D=I?N-H|0:H;c[j>>2]=D;H=O-(I?F:0)|0;c[l>>2]=H;if(!I){break a}I=(y|0)>5|0;F=248656;Q=248656;E=D;D=P;R=H;while(1){H=a[(a[F+1|0]|0)+(h+1484+(I*14|0))|0]|0;S=d[1252840+E|0]|0;T=E<<S;c[j>>2]=T;U=R<<S;V=S+D|0;do{if((V|0)>-1){S=c[m>>2]|0;if(!(S>>>0<(c[n>>2]|0)>>>0)){W=U;X=V;break}c[m>>2]=S+2;Y=S;W=((he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<V|U;X=V-16|0}else{W=U;X=V}}while(0);c[k>>2]=X;V=((ca(T-1|0,H&255)|0)>>8)+1|0;U=V<<16;Y=W>>>0>=U>>>0;Z=Y?T-V|0:V;c[j>>2]=Z;_=W-(Y?U:0)|0;c[l>>2]=_;if(Y){$=F+(a[Q]<<1)|0}else{$=F+2|0}Y=$|0;aa=a[Y]|0;if(aa<<24>>24>0){F=$;Q=Y;E=Z;D=X;R=_}else{break}}if(aa<<24>>24==0){ba=0;da=9;ea=Z;fa=X;ga=_}else{L=-(aa<<24>>24)|0;M=0;break}while(1){R=a[ba+8+(h+1484+(I*14|0))|0]|0;D=d[1252840+ea|0]|0;E=ea<<D;c[j>>2]=E;Q=ga<<D;F=fa+D|0;do{if((F|0)>-1){D=c[m>>2]|0;if(!(D>>>0<(c[n>>2]|0)>>>0)){ha=Q;ia=F;break}c[m>>2]=D+2;N=D;ha=((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<F|Q;ia=F-16|0}else{ha=Q;ia=F}}while(0);c[k>>2]=ia;F=((ca(E-1|0,R&255)|0)>>8)+1|0;Q=F<<16;T=ha>>>0>=Q>>>0;H=T?E-F|0:F;c[j>>2]=H;F=ha-(T?Q:0)|0;c[l>>2]=F;Q=((T&1)<<ba)+da|0;T=ba+1|0;if((T|0)<6){ba=T;da=Q;ea=H;fa=ia;ga=F}else{L=Q;M=0;break}}}}while(0);if((C|0)==9){C=0;I=a[x+2|0]|0;Q=d[1252840+z|0]|0;F=z<<Q;c[j>>2]=F;H=B<<Q;T=A+Q|0;do{if((T|0)>-1){Q=c[m>>2]|0;if(!(Q>>>0<(c[n>>2]|0)>>>0)){ja=H;ka=T;break}c[m>>2]=Q+2;N=Q;ja=((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<T|H;ka=T-16|0}else{ja=H;ka=T}}while(0);c[k>>2]=ka;T=((ca(F-1|0,I&255)|0)>>8)+1|0;H=T<<16;N=ja>>>0>=H>>>0;Q=N?F-T|0:T;c[j>>2]=Q;T=ja-(N?H:0)|0;c[l>>2]=T;do{if(N){H=a[x+3|0]|0;D=d[1252840+Q|0]|0;G=Q<<D;c[j>>2]=G;Y=T<<D;U=ka+D|0;do{if((U|0)>-1){D=c[m>>2]|0;if(!(D>>>0<(c[n>>2]|0)>>>0)){la=Y;ma=U;break}c[m>>2]=D+2;V=D;la=((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<U|Y;ma=U-16|0}else{la=Y;ma=U}}while(0);c[k>>2]=ma;U=((ca(G-1|0,H&255)|0)>>8)+1|0;Y=U<<16;V=la>>>0>=Y>>>0;D=V?G-U|0:U;c[j>>2]=D;U=la-(V?Y:0)|0;c[l>>2]=U;if(!V){V=a[x+4|0]|0;Y=d[1252840+D|0]|0;S=D<<Y;c[j>>2]=S;na=U<<Y;oa=ma+Y|0;do{if((oa|0)>-1){Y=c[m>>2]|0;if(!(Y>>>0<(c[n>>2]|0)>>>0)){pa=na;qa=oa;break}c[m>>2]=Y+2;ra=Y;pa=((he((d[ra]|d[ra+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|na;qa=oa-16|0}else{pa=na;qa=oa}}while(0);c[k>>2]=qa;oa=((ca(S-1|0,V&255)|0)>>8)+1|0;na=oa<<16;G=pa>>>0>=na>>>0;H=G?S-oa|0:oa;c[j>>2]=H;oa=pa-(G?na:0)|0;c[l>>2]=oa;if(!G){sa=2;ta=2;ua=H;va=qa;wa=oa;break}G=a[w+5|0]|0;na=d[1252840+H|0]|0;ra=H<<na;c[j>>2]=ra;H=oa<<na;oa=qa+na|0;do{if((oa|0)>-1){na=c[m>>2]|0;if(!(na>>>0<(c[n>>2]|0)>>>0)){xa=H;ya=oa;break}c[m>>2]=na+2;Y=na;xa=((he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|H;ya=oa-16|0}else{xa=H;ya=oa}}while(0);c[k>>2]=ya;oa=((ca(ra-1|0,G&255)|0)>>8)+1|0;H=oa<<16;S=xa>>>0>=H>>>0;V=S?ra-oa|0:oa;c[j>>2]=V;oa=xa-(S?H:0)|0;c[l>>2]=oa;sa=2;ta=S?4:3;ua=V;va=ya;wa=oa;break}if(o){oa=1252816;V=1252816;S=D;H=ma;Y=U;while(1){na=a[w+(a[oa+1|0]|0)|0]|0;za=d[1252840+S|0]|0;Aa=S<<za;c[j>>2]=Aa;Ba=Y<<za;Ca=za+H|0;do{if((Ca|0)>-1){za=c[m>>2]|0;if(!(za>>>0<(c[n>>2]|0)>>>0)){Da=Ba;Ea=Ca;break}c[m>>2]=za+2;Fa=za;Da=((he((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)&65535)<<Ca|Ba;Ea=Ca-16|0}else{Da=Ba;Ea=Ca}}while(0);c[k>>2]=Ea;Ca=((ca(Aa-1|0,na&255)|0)>>8)+1|0;Ba=Ca<<16;E=Da>>>0>=Ba>>>0;R=E?Aa-Ca|0:Ca;c[j>>2]=R;Ca=Da-(E?Ba:0)|0;c[l>>2]=Ca;if(E){Ga=oa+(a[V]<<1)|0}else{Ga=oa+2|0}E=Ga|0;Ba=a[E]|0;if(Ba<<24>>24>0){oa=Ga;V=E;S=R;H=Ea;Y=Ca}else{Ha=Ba;Ia=R;Ja=Ea;Ka=Ca;break}}}else{Ha=g;Ia=D;Ja=ma;Ka=U}Y=Ha<<24>>24;H=-Y|0;S=d[1253376+(5-Y)|0]|0;Y=d[1253368+H|0]|0;V=Ia;oa=Ja;ra=Ka;while(1){G=a[1253296+(H*11|0)+Y|0]|0;Ca=d[1252840+V|0]|0;R=V<<Ca;c[j>>2]=R;Ba=ra<<Ca;E=oa+Ca|0;do{if((E|0)>-1){Ca=c[m>>2]|0;if(!(Ca>>>0<(c[n>>2]|0)>>>0)){La=Ba;Ma=E;break}c[m>>2]=Ca+2;Fa=Ca;La=((he((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)&65535)<<E|Ba;Ma=E-16|0}else{La=Ba;Ma=E}}while(0);c[k>>2]=Ma;E=((ca(R-1|0,G&255)|0)>>8)+1|0;Ba=E<<16;Aa=La>>>0>=Ba>>>0;na=Aa?R-E|0:E;c[j>>2]=na;E=La-(Aa?Ba:0)|0;c[l>>2]=E;Ba=((Aa&1)<<Y)+S|0;if((Y|0)>0){S=Ba;Y=Y-1|0;V=na;oa=Ma;ra=E}else{sa=2;ta=Ba;ua=na;va=Ma;wa=E;break}}}else{sa=1;ta=1;ua=Q;va=ka;wa=T}}while(0);T=d[1252840+ua|0]|0;Q=ua<<T;c[j>>2]=Q;N=wa<<T;F=va+T|0;do{if((F|0)>-1){T=c[m>>2]|0;if(!(T>>>0<(c[n>>2]|0)>>>0)){Na=N;Oa=F;break}c[m>>2]=T+2;I=T;Na=((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)<<F|N;Oa=F-16|0}else{Na=N;Oa=F}}while(0);c[k>>2]=Oa;F=Q+1>>1;N=F<<16;I=Na>>>0>=N>>>0;T=I&1;if(I){c[j>>2]=Q-F;Pa=Na-N|0}else{c[j>>2]=F;Pa=Na}c[l>>2]=Pa;F=(ta^-T)+T|0;if((y|0)==0){Qa=F&65535}else{Qa=(ca(e[p>>1]|0,F)|0)&65535}b[f+608+(q<<7)+(d[(d[h+64+y|0]|0)+(f+288)|0]<<1)>>1]=Qa;L=1;M=sa}F=L+y|0;if((F|0)>63){break}T=h+188+(r*198|0)+(M*66|0)+((d[249104+F|0]|0)*11|0)|0;u=L;v=M;w=T;x=T;y=F}y=(b[f+608+(q<<7)>>1]|0)!=0|0;a[(c[i>>2]|0)+((c[t>>2]|0)*12|0)|0]=y;a[s]=y;q=q+1|0;}while((q|0)<6);return}function eab(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+1764>>2]|0;g=a+3652|0;h=a+3656|0;i=a+3660|0;j=a+3644|0;k=a+498|0;l=0;m=0;a:while(1){n=(l|0)>3?1:m;o=a+4464+(n<<2)|0;p=a+3664+(n*20|0)|0;q=0;r=0;b:while(1){do{if((r|0)<2){s=a+4464+(r<<3)+(n<<2)|0;t=c[s>>2]|0;if((t|0)==0){u=6;break}c[s>>2]=t-1;if((r|0)==0){v=1;w=q}else{break b}}else{u=6}}while(0);do{if((u|0)==6){u=0;t=c[g>>2]|0;if(((c[h>>2]|0)-t|0)<1){u=36;break a}s=c[p+4>>2]|0;x=c[i>>2]|0;y=c[j>>2]|0;z=y+(t>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(t&7)>>>22;z=b[s+(A<<2)>>1]|0;B=b[s+(A<<2)+2>>1]|0;A=B<<16>>16;do{if(B<<16>>16<0){C=t+10|0;D=x>>>0>C>>>0?C:x;C=y+(D>>>3)|0;E=((je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(D&7)>>>((A+32|0)>>>0))+z|0;C=b[s+(E<<2)>>1]|0;F=b[s+(E<<2)+2>>1]|0;E=F<<16>>16;if(!(F<<16>>16<0)){G=E;H=C;I=D;break}F=D-A|0;D=x>>>0>F>>>0?F:x;F=y+(D>>>3)|0;J=((je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>((E+32|0)>>>0))+C|0;G=b[s+(J<<2)+2>>1]|0;H=b[s+(J<<2)>>1]|0;I=D}else{G=A;H=z;I=t}}while(0);t=G+I|0;K=x>>>0>t>>>0?t:x;c[g>>2]=K;if((H|0)==11){u=21;break b}else if((H|0)!=0){t=d[1253376+H|0]|0;if((H|0)>4){z=(H|0)<10?H-4|0:11;A=y+(K>>>3)|0;s=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(K&7)>>>((32-z|0)>>>0);A=K+z|0;z=x>>>0>A>>>0?A:x;c[g>>2]=z;L=s+t|0;M=z}else{L=t;M=K}t=d[y+(M>>>3)|0]<<(M&7)>>>7;c[g>>2]=((M|0)<(x|0))+M;z=t&1;t=(L^-z)+z|0;if((r|0)==0){N=t&65535}else{N=(ca(e[k>>1]|0,t)|0)&65535}b[a+608+(l<<7)+(d[(d[f+64+r|0]|0)+(a+288)|0]<<1)>>1]=N;v=1;w=(L|0)>1?2:1;break}if((r|0)==0){t=y+(K>>>3)|0;z=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(K&7)>>>30;t=K+2|0;s=x>>>0>t>>>0?t:x;c[g>>2]=s;if((z|0)==2){t=y+(s>>>3)|0;A=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(s&7)>>>30;t=s+2|0;c[g>>2]=x>>>0>t>>>0?t:x;O=A+2|0}else if((z|0)==3){A=d[y+(s>>>3)|0]<<(s&7)>>>7;t=((s|0)<(x|0))+s|0;c[g>>2]=t;s=A<<2&4;A=s|2;B=y+(t>>>3)|0;D=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(t&7)>>>((32-A|0)>>>0);B=A+t|0;c[g>>2]=x>>>0>B>>>0?B:x;O=s+6+D|0}else{O=z}c[o>>2]=O;v=1;w=0;break}z=c[a+3704+(((r|0)>5|0)*20|0)+4>>2]|0;D=y+(K>>>3)|0;s=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(K&7)>>>22;D=b[z+(s<<2)>>1]|0;B=b[z+(s<<2)+2>>1]|0;s=B<<16>>16;do{if(B<<16>>16<0){t=K+10|0;A=x>>>0>t>>>0?t:x;t=y+(A>>>3)|0;J=((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(A&7)>>>((s+32|0)>>>0))+D|0;t=b[z+(J<<2)>>1]|0;C=b[z+(J<<2)+2>>1]|0;J=C<<16>>16;if(!(C<<16>>16<0)){P=J;Q=t;R=A;break}C=A-s|0;A=x>>>0>C>>>0?C:x;C=y+(A>>>3)|0;E=((je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>>((J+32|0)>>>0))+t|0;P=b[z+(E<<2)+2>>1]|0;Q=b[z+(E<<2)>>1]|0;R=A}else{P=s;Q=D;R=K}}while(0);D=P+R|0;s=x>>>0>D>>>0?D:x;c[g>>2]=s;D=Q+1|0;if((D|0)<=8){v=D;w=0;break}z=y+(s>>>3)|0;B=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(s&7)>>>26;z=s+6|0;c[g>>2]=x>>>0>z>>>0?z:x;v=B+D|0;w=0}}while(0);D=v+r|0;if((D|0)>63){break}if((D-22|0)>>>0<42>>>0){S=3}else{S=d[249104+D|0]|0}p=a+3744+(n*360|0)+(w*120|0)+(S*20|0)|0;q=w;r=D}do{if((u|0)==21){u=0;if((r|0)!=1){break}q=y+(K>>>3)|0;p=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(K&7)>>>30;q=K+2|0;o=x>>>0>q>>>0?q:x;c[g>>2]=o;if((p|0)==2){q=y+(o>>>3)|0;D=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(o&7)>>>30;q=o+2|0;c[g>>2]=x>>>0>q>>>0?q:x;T=D+2|0}else if((p|0)==3){D=d[y+(o>>>3)|0]<<(o&7)>>>7;q=((o|0)<(x|0))+o|0;c[g>>2]=q;o=D<<2&4;D=o|2;B=y+(q>>>3)|0;z=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(q&7)>>>((32-D|0)>>>0);B=D+q|0;c[g>>2]=x>>>0>B>>>0?B:x;T=o+6+z|0}else{T=p}c[a+4472+(n<<2)>>2]=T}}while(0);r=l+1|0;if((r|0)<6){l=r;m=n}else{u=36;break}}if((u|0)==36){return}}function fab(a,d){a=a|0;d=d|0;return((c[a+4>>2]|0)-(c[d+4>>2]|0)<<4)+(b[d>>1]|0)-(b[a>>1]|0)|0}function gab(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=i;i=i+352|0;k=j|0;l=b[g>>1]|0;m=b[g+2>>1]|0;n=b[g+4>>1]|0;o=b[g+6>>1]|0;g=e+(-f|0)|0;e=0;p=k|0;while(1){q=0;r=a[g-1|0]|0;s=a[g]|0;t=a[g+1|0]|0;while(1){u=ca(l,r&255)|0;v=ca(m,s&255)|0;w=q+1|0;x=ca(n,t&255)|0;y=a[g+(q+2)|0]|0;z=u+64+v+x+(ca(o,y&255)|0)>>7;if(z>>>0>255>>>0){A=-z>>31&255}else{A=z&255}c[p+(q<<2)>>2]=A&255;if((w|0)<8){q=w;r=s;s=t;t=y}else{break}}t=e+1|0;if((t|0)<11){g=g+f|0;e=t;p=p+32|0}else{break}}p=h+2|0;e=h+4|0;g=h+6|0;A=d;d=0;o=k+32|0;while(1){k=0;do{n=ca(b[h>>1]|0,c[o+(k-8<<2)>>2]|0)|0;m=ca(b[p>>1]|0,c[o+(k<<2)>>2]|0)|0;l=ca(b[e>>1]|0,c[o+(k+8<<2)>>2]|0)|0;t=n+64+m+l+(ca(b[g>>1]|0,c[o+(k+16<<2)>>2]|0)|0)>>7;if(t>>>0>255>>>0){B=-t>>31&255}else{B=t&255}a[A+k|0]=B;k=k+1|0;}while((k|0)<8);k=d+1|0;if((k|0)<8){A=A+f|0;d=k;o=o+32|0}else{break}}i=j;return}function hab(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0;k=i;i=i+24|0;l=k|0;m=k+16|0;n=f+60|0;o=c[n>>2]|0;p=o;q=c[j+24>>2]|0;r=j+28|0;j=c[r>>2]|0;s=o+188|0;t=s;u=o+4|0;v=c[u>>2]|0;w=c[v+120>>2]|0;x=c[v+124>>2]|0;z=o+60|0;a[z]=a[q]&1^1;A=(d[q]|0)>>>1&7;B=o+63|0;a[B]=A;C=o+4540|0;c[C>>2]=((d[q]|0)>>>4&1^1)&255;D=(d[q+1|0]<<8|d[q+2|0]<<16|d[q])>>>5;E=q+3|0;F=j-3|0;if((A&255)>>>0>3>>>0){KIb(v,24,2291600,(G=i,i=i+8|0,c[G>>2]=A&255,G)|0);i=G;H=a[B]|0}else{H=A}A=o+5240|0;if(H<<24>>24==0){nrc(A|0,o+4796|0,108)|0}else{nrc(A|0,o+4904|0,108)|0}A=a[z]|0;a:do{if((D|0)>(((A&255)*-7|0)+F|0)){KIb(c[u>>2]|0,16,2240792,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;I=-1094995529}else{if(A<<24>>24==0){J=x;K=w;L=E;M=F}else{H=d[q+4|0]<<8|d[q+5|0]<<16|d[E];if((H|0)!=2752925){KIb(c[u>>2]|0,16,2199840,(G=i,i=i+8|0,c[G>>2]=H,G)|0);i=G;I=-1094995529;break}H=q+6|0;B=(d[H]|d[H+1|0]<<8)<<16>>16&16383;H=q+8|0;v=(d[H]|d[H+1|0]<<8)<<16>>16&16383;H=q+10|0;N=j-10|0;if((d[q+7|0]|0)>>>0>63>>>0){O=13}else{if((d[q+9|0]|0)>>>0>63>>>0){O=13}}if((O|0)==13){QIb(c[u>>2]|0,2168168,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G}c[o+4552>>2]=0;c[o+4548>>2]=0;P=0;do{nrc(p+222+(P*528|0)|0,237288+(P*264|0)|0,33)|0;nrc(p+222+(P*528|0)+33|0,237321+(P*264|0)|0,33)|0;nrc(p+222+(P*528|0)+66|0,237354+(P*264|0)|0,33)|0;nrc(p+222+(P*528|0)+99|0,237387+(P*264|0)|0,33)|0;Q=237486+(P*264|0)|0;nrc(p+222+(P*528|0)+132|0,Q|0,33)|0;nrc(p+222+(P*528|0)+165|0,237420+(P*264|0)|0,33)|0;nrc(p+222+(P*528|0)+198|0,237453+(P*264|0)|0,33)|0;nrc(p+222+(P*528|0)+231|0,Q|0,33)|0;nrc(p+222+(P*528|0)+264|0,Q|0,33)|0;nrc(p+222+(P*528|0)+297|0,Q|0,33)|0;nrc(p+222+(P*528|0)+330|0,Q|0,33)|0;nrc(p+222+(P*528|0)+363|0,Q|0,33)|0;nrc(p+222+(P*528|0)+396|0,Q|0,33)|0;nrc(p+222+(P*528|0)+429|0,Q|0,33)|0;nrc(p+222+(P*528|0)+462|0,Q|0,33)|0;nrc(p+222+(P*528|0)+495|0,237519+(P*264|0)|0,33)|0;P=P+1|0;}while((P|0)<4);P=o+215|0;y=629954160;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;P=o+219|0;a[P]=a[239808]|0;a[P+1|0]=a[239809]|0;a[P+2|0]=a[239810]|0;nrc(o+2334|0,242552,38)|0;mrc(o+88|0,0,11)|0;mrc(o+164|0,0,13)|0;J=v;K=B;L=H;M=N}V9a(t,L,D);P=M-D|0;Q=s;R=c[Q>>2]|0;if((a[z]|0)==0){S=R;T=c[o+192>>2]|0;U=c[o+204>>2]|0}else{V=d[1252840+R|0]|0;W=o+192|0;X=c[W>>2]|0;Y=o+204|0;Z=c[Y>>2]|0;_=R<<V;c[Q>>2]=_;R=Z<<V;Z=X+V|0;do{if((Z|0)>-1){V=o+196|0;X=c[V>>2]|0;if(!(X>>>0<(c[o+200>>2]|0)>>>0)){$=R;aa=Z;break}c[V>>2]=X+2;V=X;$=((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<Z|R;aa=Z-16|0}else{$=R;aa=Z}}while(0);c[W>>2]=aa;Z=((_<<7)-128>>8)+1|0;R=Z<<16;N=$>>>0>=R>>>0;H=N?_-Z|0:Z;c[Q>>2]=H;Z=$-(N?R:0)|0;c[Y>>2]=Z;if(N){KIb(c[u>>2]|0,24,2141512,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;ba=c[Q>>2]|0;da=c[W>>2]|0;ea=c[Y>>2]|0}else{ba=H;da=aa;ea=Z}Z=d[1252840+ba|0]|0;H=ba<<Z;c[Q>>2]=H;N=ea<<Z;R=Z+da|0;do{if((R|0)>-1){Z=o+196|0;B=c[Z>>2]|0;if(!(B>>>0<(c[o+200>>2]|0)>>>0)){fa=N;ga=R;break}c[Z>>2]=B+2;Z=B;fa=((he((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0)&65535)<<R|N;ga=R-16|0}else{fa=N;ga=R}}while(0);c[W>>2]=ga;R=((H<<7)-128>>8)+1|0;N=R<<16;_=fa>>>0>=N>>>0;Z=_?H-R|0:R;c[Q>>2]=Z;R=fa-(_?N:0)|0;c[Y>>2]=R;S=Z;T=ga;U=R}R=d[1252840+S|0]|0;Z=o+192|0;N=o+204|0;_=S<<R;c[Q>>2]=_;B=U<<R;v=R+T|0;do{if((v|0)>-1){R=o+196|0;V=c[R>>2]|0;if(!(V>>>0<(c[o+200>>2]|0)>>>0)){ha=B;ia=v;break}c[R>>2]=V+2;R=V;ha=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<v|B;ia=v-16|0}else{ha=B;ia=v}}while(0);c[Z>>2]=ia;v=((_<<7)-128>>8)+1|0;B=v<<16;Y=ha>>>0>=B>>>0;H=Y?_-v|0:v;c[Q>>2]=H;v=ha-(Y?B:0)|0;c[N>>2]=v;B=o+88|0;a[B]=Y&1;do{if(Y){W=d[1252840+H|0]|0;R=H<<W;c[Q>>2]=R;V=v<<W;X=W+ia|0;do{if((X|0)>-1){W=o+196|0;ja=c[W>>2]|0;if(!(ja>>>0<(c[o+200>>2]|0)>>>0)){ka=V;la=X;break}c[W>>2]=ja+2;W=ja;ka=((he((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<X|V;la=X-16|0}else{ka=V;la=X}}while(0);c[Z>>2]=la;X=((R<<7)-128>>8)+1|0;V=X<<16;W=ka>>>0>=V>>>0;ja=W?R-X|0:X;X=ka-(W?V:0)|0;c[N>>2]=X;V=W&1;W=o+90|0;a[W]=V;ma=d[1252840+ja|0]|0;na=ja<<ma;c[Q>>2]=na;ja=X<<ma;X=ma+la|0;do{if((X|0)>-1){ma=o+196|0;oa=c[ma>>2]|0;if(!(oa>>>0<(c[o+200>>2]|0)>>>0)){pa=ja;qa=X;break}c[ma>>2]=oa+2;ma=oa;pa=((he((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<X|ja;qa=X-16|0}else{pa=ja;qa=X}}while(0);c[Z>>2]=qa;X=((na<<7)-128>>8)+1|0;ja=X<<16;R=pa>>>0>=ja>>>0;ma=R?na-X|0:X;c[Q>>2]=ma;X=pa-(R?ja:0)|0;c[N>>2]=X;if(R){R=d[1252840+ma|0]|0;ja=ma<<R;c[Q>>2]=ja;ma=X<<R;X=R+qa|0;do{if((X|0)>-1){R=o+196|0;oa=c[R>>2]|0;if(!(oa>>>0<(c[o+200>>2]|0)>>>0)){ra=ma;sa=X;break}c[R>>2]=oa+2;R=oa;ra=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<X|ma;sa=X-16|0}else{ra=ma;sa=X}}while(0);c[Z>>2]=sa;X=((ja<<7)-128>>8)+1|0;ma=X<<16;na=ra>>>0>=ma>>>0;c[Q>>2]=na?ja-X|0:X;c[N>>2]=ra-(na?ma:0);a[o+89|0]=na&1;a[o+91|0]=qab(t,7)|0;a[o+92|0]=qab(t,7)|0;a[o+93|0]=qab(t,7)|0;a[o+94|0]=qab(t,7)|0;a[o+95|0]=qab(t,6)|0;a[o+96|0]=qab(t,6)|0;a[o+97|0]=qab(t,6)|0;a[o+98|0]=qab(t,6)|0;ta=a[W]|0}else{ta=V}if(ta<<24>>24==0){break}na=o+196|0;ma=o+200|0;X=0;do{R=c[Q>>2]|0;oa=d[1252840+R|0]|0;ua=c[Z>>2]|0;va=c[N>>2]|0;wa=R<<oa;c[Q>>2]=wa;R=va<<oa;va=ua+oa|0;do{if((va|0)>-1){oa=c[na>>2]|0;if(!(oa>>>0<(c[ma>>2]|0)>>>0)){xa=R;ya=va;break}c[na>>2]=oa+2;ua=oa;xa=((he((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<va|R;ya=va-16|0}else{xa=R;ya=va}}while(0);c[Z>>2]=ya;va=((wa<<7)-128>>8)+1|0;R=va<<16;ua=xa>>>0>=R>>>0;oa=ua?wa-va|0:va;c[Q>>2]=oa;va=xa-(ua?R:0)|0;c[N>>2]=va;if(ua){ua=8;R=0;za=oa;oa=ya;Aa=va;while(1){va=ua-1|0;Ba=R<<1;Ca=d[1252840+za|0]|0;Da=za<<Ca;c[Q>>2]=Da;Ea=Aa<<Ca;Fa=Ca+oa|0;do{if((Fa|0)>-1){Ca=c[na>>2]|0;if(!(Ca>>>0<(c[ma>>2]|0)>>>0)){Ga=Ea;Ha=Fa;break}c[na>>2]=Ca+2;Ia=Ca;Ga=((he((d[Ia]|d[Ia+1|0]<<8)<<16>>16|0)|0)&65535)<<Fa|Ea;Ha=Fa-16|0}else{Ga=Ea;Ha=Fa}}while(0);c[Z>>2]=Ha;Fa=((Da<<7)-128>>8)+1|0;Ea=Fa<<16;Ia=Ga>>>0>=Ea>>>0;Ca=Ia?Da-Fa|0:Fa;c[Q>>2]=Ca;Fa=Ga-(Ia?Ea:0)|0;c[N>>2]=Fa;Ja=Ia&1|Ba;if((va|0)==0){break}else{ua=va;R=Ja;za=Ca;oa=Ha;Aa=Fa}}Ka=Ja&255}else{Ka=-1}a[p+208+X|0]=Ka;X=X+1|0;}while((X|0)<3)}else{a[o+90|0]=0}}while(0);v=c[Q>>2]|0;H=d[1252840+v|0]|0;Y=c[Z>>2]|0;_=c[N>>2]|0;X=v<<H;c[Q>>2]=X;v=_<<H;_=Y+H|0;H=o+196|0;do{if((_|0)>-1){Y=c[H>>2]|0;na=o+200|0;if(!(Y>>>0<(c[na>>2]|0)>>>0)){La=v;Ma=_;Na=na;break}c[H>>2]=Y+2;ma=Y;La=((he((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<_|v;Ma=_-16|0;Na=na}else{La=v;Ma=_;Na=o+200|0}}while(0);c[Z>>2]=Ma;_=((X<<7)-128>>8)+1|0;v=_<<16;na=La>>>0>=v>>>0;ma=na?X-_|0:_;c[Q>>2]=ma;_=La-(na?v:0)|0;c[N>>2]=_;a[o+99|0]=na&1;na=6;v=0;Y=ma;ma=Ma;V=_;while(1){_=na-1|0;W=v<<1;ja=d[1252840+Y|0]|0;Aa=Y<<ja;c[Q>>2]=Aa;oa=V<<ja;za=ja+ma|0;do{if((za|0)>-1){ja=c[H>>2]|0;if(!(ja>>>0<(c[Na>>2]|0)>>>0)){Oa=oa;Pa=za;break}c[H>>2]=ja+2;R=ja;Oa=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<za|oa;Pa=za-16|0}else{Oa=oa;Pa=za}}while(0);c[Z>>2]=Pa;za=((Aa<<7)-128>>8)+1|0;oa=za<<16;R=Oa>>>0>=oa>>>0;Qa=R?Aa-za|0:za;c[Q>>2]=Qa;Ra=Oa-(R?oa:0)|0;c[N>>2]=Ra;Sa=R&1|W;if((_|0)==0){break}else{na=_;v=Sa;Y=Qa;ma=Pa;V=Ra}}V=o+100|0;a[V]=Sa;ma=d[1252840+Qa|0]|0;Y=Qa<<ma;c[Q>>2]=Y;v=Ra<<ma;na=ma+Pa|0;do{if((na|0)>-1){ma=c[H>>2]|0;if(!(ma>>>0<(c[Na>>2]|0)>>>0)){Ta=v;Ua=na;break}c[H>>2]=ma+2;X=ma;Ta=((he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0)&65535)<<na|v;Ua=na-16|0}else{Ta=v;Ua=na}}while(0);c[Z>>2]=Ua;na=((Y<<7)-128>>8)+1|0;v=na<<16;X=Ta>>>0>=v>>>0;ma=X?Y-na|0:na;na=Ta-(X?v:0)|0;c[N>>2]=na;v=(X&1)<<1;X=d[1252840+ma|0]|0;R=ma<<X;c[Q>>2]=R;ma=na<<X;na=X+Ua|0;do{if((na|0)>-1){X=c[H>>2]|0;if(!(X>>>0<(c[Na>>2]|0)>>>0)){Va=ma;Wa=na;break}c[H>>2]=X+2;oa=X;Va=((he((d[oa]|d[oa+1|0]<<8)<<16>>16|0)|0)&65535)<<na|ma;Wa=na-16|0}else{Va=ma;Wa=na}}while(0);c[Z>>2]=Wa;na=((R<<7)-128>>8)+1|0;ma=na<<16;Y=Va>>>0>=ma>>>0;oa=Y?R-na|0:na;na=Va-(Y?ma:0)|0;c[N>>2]=na;ma=(Y&1|v)<<1;Y=d[1252840+oa|0]|0;X=oa<<Y;c[Q>>2]=X;oa=na<<Y;na=Y+Wa|0;do{if((na|0)>-1){Y=c[H>>2]|0;if(!(Y>>>0<(c[Na>>2]|0)>>>0)){Xa=oa;Ya=na;break}c[H>>2]=Y+2;za=Y;Xa=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<na|oa;Ya=na-16|0}else{Xa=oa;Ya=na}}while(0);c[Z>>2]=Ya;na=((X<<7)-128>>8)+1|0;oa=na<<16;v=Xa>>>0>=oa>>>0;R=v?X-na|0:na;na=Xa-(v?oa:0)|0;c[N>>2]=na;a[o+101|0]=v&1|ma;v=d[1252840+R|0]|0;oa=R<<v;c[Q>>2]=oa;R=na<<v;na=v+Ya|0;do{if((na|0)>-1){v=c[H>>2]|0;if(!(v>>>0<(c[Na>>2]|0)>>>0)){Za=R;_a=na;break}c[H>>2]=v+2;za=v;Za=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<na|R;_a=na-16|0}else{Za=R;_a=na}}while(0);c[Z>>2]=_a;na=((oa<<7)-128>>8)+1|0;R=na<<16;ma=Za>>>0>=R>>>0;X=ma?oa-na|0:na;c[Q>>2]=X;na=Za-(ma?R:0)|0;c[N>>2]=na;a[o+164|0]=ma&1;do{if(ma){R=d[1252840+X|0]|0;za=X<<R;c[Q>>2]=za;v=na<<R;Y=R+_a|0;do{if((Y|0)>-1){R=c[H>>2]|0;if(!(R>>>0<(c[Na>>2]|0)>>>0)){$a=v;ab=Y;break}c[H>>2]=R+2;ja=R;$a=((he((d[ja]|d[ja+1|0]<<8)<<16>>16|0)|0)&65535)<<Y|v;ab=Y-16|0}else{$a=v;ab=Y}}while(0);c[Z>>2]=ab;Y=((za<<7)-128>>8)+1|0;v=Y<<16;_=$a>>>0>=v>>>0;W=_?za-Y|0:Y;c[Q>>2]=W;Y=$a-(_?v:0)|0;c[N>>2]=Y;if(_){bb=0;cb=W;db=ab;eb=Y}else{fb=W;gb=ab;hb=Y;break}while(1){Y=d[1252840+cb|0]|0;W=cb<<Y;c[Q>>2]=W;_=eb<<Y;v=Y+db|0;do{if((v|0)>-1){Y=c[H>>2]|0;if(!(Y>>>0<(c[Na>>2]|0)>>>0)){ib=_;jb=v;break}c[H>>2]=Y+2;Aa=Y;ib=((he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<v|_;jb=v-16|0}else{ib=_;jb=v}}while(0);c[Z>>2]=jb;v=((W<<7)-128>>8)+1|0;_=v<<16;Aa=ib>>>0>=_>>>0;Y=Aa?W-v|0:v;c[Q>>2]=Y;v=ib-(Aa?_:0)|0;c[N>>2]=v;do{if(Aa){_=6;ja=0;R=Y;ua=jb;wa=v;while(1){Fa=_-1|0;Ca=ja<<1;Ia=d[1252840+R|0]|0;Ea=R<<Ia;c[Q>>2]=Ea;kb=wa<<Ia;lb=Ia+ua|0;do{if((lb|0)>-1){Ia=c[H>>2]|0;if(!(Ia>>>0<(c[Na>>2]|0)>>>0)){mb=kb;nb=lb;break}c[H>>2]=Ia+2;ob=Ia;mb=((he((d[ob]|d[ob+1|0]<<8)<<16>>16|0)|0)&65535)<<lb|kb;nb=lb-16|0}else{mb=kb;nb=lb}}while(0);c[Z>>2]=nb;lb=((Ea<<7)-128>>8)+1|0;kb=lb<<16;ob=mb>>>0>=kb>>>0;Ia=ob?Ea-lb|0:lb;c[Q>>2]=Ia;lb=mb-(ob?kb:0)|0;c[N>>2]=lb;pb=ob&1|Ca;if((Fa|0)==0){break}else{_=Fa;ja=pb;R=Ia;ua=nb;wa=lb}}wa=p+173+bb|0;a[wa]=pb;ua=c[Q>>2]|0;R=d[1252840+ua|0]|0;ja=c[Z>>2]|0;_=c[N>>2]|0;va=ua<<R;c[Q>>2]=va;ua=_<<R;_=ja+R|0;do{if((_|0)>-1){R=c[H>>2]|0;if(!(R>>>0<(c[Na>>2]|0)>>>0)){qb=ua;rb=_;break}c[H>>2]=R+2;ja=R;qb=((he((d[ja]|d[ja+1|0]<<8)<<16>>16|0)|0)&65535)<<_|ua;rb=_-16|0}else{qb=ua;rb=_}}while(0);c[Z>>2]=rb;_=((va<<7)-128>>8)+1|0;ua=_<<16;ja=qb>>>0>=ua>>>0;c[Q>>2]=ja?va-_|0:_;c[N>>2]=qb-(ja?ua:0);if(!ja){break}a[wa]=-(a[wa]|0)}}while(0);v=bb+1|0;if((v|0)>=4){sb=4;break}bb=v;cb=c[Q>>2]|0;db=c[Z>>2]|0;eb=c[N>>2]|0}do{za=c[Q>>2]|0;v=d[1252840+za|0]|0;Y=c[Z>>2]|0;Aa=c[N>>2]|0;W=za<<v;c[Q>>2]=W;za=Aa<<v;Aa=Y+v|0;do{if((Aa|0)>-1){v=c[H>>2]|0;if(!(v>>>0<(c[Na>>2]|0)>>>0)){tb=za;ub=Aa;break}c[H>>2]=v+2;Y=v;tb=((he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<Aa|za;ub=Aa-16|0}else{tb=za;ub=Aa}}while(0);c[Z>>2]=ub;Aa=((W<<7)-128>>8)+1|0;za=Aa<<16;Y=tb>>>0>=za>>>0;v=Y?W-Aa|0:Aa;c[Q>>2]=v;Aa=tb-(Y?za:0)|0;c[N>>2]=Aa;do{if(Y){za=6;ja=0;ua=v;_=ub;R=Aa;while(1){Ba=za-1|0;Da=ja<<1;lb=d[1252840+ua|0]|0;Ia=ua<<lb;c[Q>>2]=Ia;ob=R<<lb;kb=lb+_|0;do{if((kb|0)>-1){lb=c[H>>2]|0;if(!(lb>>>0<(c[Na>>2]|0)>>>0)){vb=ob;wb=kb;break}c[H>>2]=lb+2;xb=lb;vb=((he((d[xb]|d[xb+1|0]<<8)<<16>>16|0)|0)&65535)<<kb|ob;wb=kb-16|0}else{vb=ob;wb=kb}}while(0);c[Z>>2]=wb;kb=((Ia<<7)-128>>8)+1|0;ob=kb<<16;Fa=vb>>>0>=ob>>>0;Ca=Fa?Ia-kb|0:kb;c[Q>>2]=Ca;kb=vb-(Fa?ob:0)|0;c[N>>2]=kb;yb=Fa&1|Da;if((Ba|0)==0){break}else{za=Ba;ja=yb;ua=Ca;_=wb;R=kb}}R=p+165+sb|0;a[R]=yb;_=c[Q>>2]|0;ua=d[1252840+_|0]|0;ja=c[Z>>2]|0;za=c[N>>2]|0;wa=_<<ua;c[Q>>2]=wa;_=za<<ua;za=ja+ua|0;do{if((za|0)>-1){ua=c[H>>2]|0;if(!(ua>>>0<(c[Na>>2]|0)>>>0)){zb=_;Ab=za;break}c[H>>2]=ua+2;ja=ua;zb=((he((d[ja]|d[ja+1|0]<<8)<<16>>16|0)|0)&65535)<<za|_;Ab=za-16|0}else{zb=_;Ab=za}}while(0);c[Z>>2]=Ab;za=((wa<<7)-128>>8)+1|0;_=za<<16;ja=zb>>>0>=_>>>0;c[Q>>2]=ja?wa-za|0:za;c[N>>2]=zb-(ja?_:0);if(!ja){break}a[R]=-(a[R]|0)}}while(0);sb=sb+1|0;}while((sb|0)<8);fb=c[Q>>2]|0;gb=c[Z>>2]|0;hb=c[N>>2]|0}else{fb=X;gb=_a;hb=na}}while(0);na=d[1252840+fb|0]|0;X=fb<<na;c[Q>>2]=X;ma=hb<<na;oa=na+gb|0;do{if((oa|0)>-1){na=c[H>>2]|0;if(!(na>>>0<(c[Na>>2]|0)>>>0)){Bb=ma;Cb=oa;break}c[H>>2]=na+2;Aa=na;Bb=((he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|ma;Cb=oa-16|0}else{Bb=ma;Cb=oa}}while(0);c[Z>>2]=Cb;oa=((X<<7)-128>>8)+1|0;ma=oa<<16;Aa=Bb>>>0>=ma>>>0;na=Aa?X-oa|0:oa;oa=Bb-(Aa?ma:0)|0;c[N>>2]=oa;ma=(Aa&1)<<1;Aa=d[1252840+na|0]|0;v=na<<Aa;c[Q>>2]=v;na=oa<<Aa;oa=Aa+Cb|0;do{if((oa|0)>-1){Aa=c[H>>2]|0;if(!(Aa>>>0<(c[Na>>2]|0)>>>0)){Db=na;Eb=oa;break}c[H>>2]=Aa+2;Y=Aa;Db=((he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|na;Eb=oa-16|0}else{Db=na;Eb=oa}}while(0);c[Z>>2]=Eb;oa=((v<<7)-128>>8)+1|0;na=oa<<16;X=Db>>>0>=na>>>0;c[Q>>2]=X?v-oa|0:oa;c[N>>2]=Db-(X?na:0);na=X&1|ma;X=1<<na;oa=o+4560|0;c[oa>>2]=X;Y=3<<na;na=3-Y+P|0;b:do{if((na|0)>=0){Aa=L+(D-3+Y)|0;if((X-1|0)>0){W=D+2|0;ja=D+1|0;_=na;za=Aa;ua=0;while(1){va=ua*3|0;kb=d[L+(ja+va)|0]<<8|d[L+(W+va)|0]<<16|d[L+(va+D)|0];va=_-kb|0;if((va|0)<0){break b}V9a(p+4564+(ua*20|0)|0,za,kb);Ca=za+kb|0;kb=ua+1|0;if((kb|0)<((c[oa>>2]|0)-1|0)){_=va;za=Ca;ua=kb}else{Fb=va;Gb=Ca;Hb=kb;break}}}else{Fb=na;Gb=Aa;Hb=0}V9a(p+4564+(Hb*20|0)|0,Gb,Fb);ua=o+4536|0;za=(c[ua>>2]|0)==0;_=c[u>>2]|0;W=(K|0)==(c[_+120>>2]|0);do{if(W&(za^1)){if((J|0)!=(c[_+124>>2]|0)){O=123;break}if(((K+15|0)/16|0|0)!=(e[o+48>>1]|0)){O=123;break}if(((J+15|0)/16|0|0)!=(e[o+50>>1]|0)){O=123}}else{if(W){O=123}else{O=127}}}while(0);do{if((O|0)==123){W=o+48|0;if(((K+15|0)/16|0|0)==(e[W>>1]|0)){if(!(((J+15|0)/16|0|0)==(e[o+50>>1]|0)|za)){O=127;break}}else{if(!za){O=127;break}}if((c[_+124>>2]|0)==(J|0)){Ib=_;Jb=W;O=129}else{O=127}}}while(0);if((O|0)==127){kab(c[_+60>>2]|0,1);za=H4a(c[u>>2]|0,K,J)|0;if((za|0)<0){I=za;break a}Ib=c[u>>2]|0;Jb=o+48|0;O=129}if((O|0)==129){za=((c[Ib+128>>2]|0)+15|0)/16|0;b[Jb>>1]=za;W=((c[Ib+132>>2]|0)+15|0)/16|0;b[o+50>>1]=W;do{if((c[_+816>>2]|0)==2){Aa=c[oa>>2]|0;ja=c[_+808>>2]|0;kb=(((Aa|0)>(ja|0)?ja:Aa)|0)>1;Aa=o+5432|0;c[Aa>>2]=kb&1;ja=za&65535;if(!kb){Kb=Aa;Lb=ja;O=132;break}c[ua>>2]=pJb(ca((W&65535)+2|0,(ja*96|0)+192|0)|0)|0;Mb=Aa}else{Aa=o+5432|0;c[Aa>>2]=0;Kb=Aa;Lb=za&65535;O=132}}while(0);if((O|0)==132){c[ua>>2]=pJb(((Lb+(W<<1&131070)|0)*96|0)+96|0)|0;c[o+108>>2]=pJb(e[Jb>>1]<<2)|0;Mb=Kb}za=o+184|0;c[za>>2]=pJb((e[Jb>>1]|0)*9|0)|0;_=o+180|0;c[_>>2]=pJb((e[Jb>>1]<<5)+32|0)|0;Aa=o;c[Aa>>2]=pJb(12288)|0;ja=pJb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+1520>>2]=ja;ja=pJb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+3056>>2]=ja;ja=pJb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+4592>>2]=ja;ja=pJb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+6128>>2]=ja;ja=pJb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+7664>>2]=ja;ja=pJb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+9200>>2]=ja;ja=pJb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+10736>>2]=ja;ja=pJb((e[Jb>>1]|0)*3|0)|0;c[(c[Aa>>2]|0)+12272>>2]=ja;ja=c[ua>>2]|0;if((ja|0)==0){I=-12;break a}if((c[za>>2]|0)==0){I=-12;break a}if((c[_>>2]|0)==0){I=-12;break a}if((c[o+108>>2]|0)==0){if((c[Mb>>2]|0)==0){I=-12;break a}}c[o+104>>2]=ja+96}ja=7;_=0;za=c[Q>>2]|0;Aa=c[Z>>2]|0;kb=c[N>>2]|0;while(1){Ca=ja-1|0;va=_<<1;Fa=d[1252840+za|0]|0;ob=za<<Fa;c[Q>>2]=ob;Ea=kb<<Fa;xb=Fa+Aa|0;do{if((xb|0)>-1){Fa=c[H>>2]|0;if(!(Fa>>>0<(c[Na>>2]|0)>>>0)){Nb=Ea;Ob=xb;break}c[H>>2]=Fa+2;lb=Fa;Nb=((he((d[lb]|d[lb+1|0]<<8)<<16>>16|0)|0)&65535)<<xb|Ea;Ob=xb-16|0}else{Nb=Ea;Ob=xb}}while(0);c[Z>>2]=Ob;xb=((ob<<7)-128>>8)+1|0;Ea=xb<<16;lb=Nb>>>0>=Ea>>>0;Fa=lb?ob-xb|0:xb;c[Q>>2]=Fa;xb=Nb-(lb?Ea:0)|0;c[N>>2]=xb;Pb=lb&1|va;if((Ca|0)==0){break}else{ja=Ca;_=Pb;za=Fa;Aa=Ob;kb=xb}}kb=qab(t,4)|0;Aa=qab(t,4)|0;za=qab(t,4)|0;_=qab(t,4)|0;ja=qab(t,4)|0;ua=o+89|0;W=0;do{do{if((a[B]|0)==0){Qb=Pb}else{xb=a[p+91+W|0]|0;if((a[ua]|0)!=0){Qb=xb;break}Qb=xb+Pb|0}}while(0);Ca=Qb+kb|0;if(Ca>>>0<128>>>0){Rb=Ca}else{Rb=-Ca>>31&127}b[p+116+(W*12|0)>>1]=d[245208+Rb|0]|0;if(Qb>>>0<128>>>0){Sb=Qb}else{Sb=-Qb>>31&127}b[p+116+(W*12|0)+2>>1]=b[247944+(Sb<<1)>>1]|0;Ca=Qb+Aa|0;if(Ca>>>0<128>>>0){Tb=Ca}else{Tb=-Ca>>31&127}b[p+116+(W*12|0)+4>>1]=d[245208+Tb|0]<<1;Ca=Qb+za|0;if(Ca>>>0<128>>>0){Ub=Ca}else{Ub=-Ca>>31&127}Ca=((e[247944+(Ub<<1)>>1]|0)*101581|0)>>>16&65535;va=p+116+(W*12|0)+6|0;b[va>>1]=Ca;ob=Qb+_|0;if(ob>>>0<128>>>0){Vb=ob}else{Vb=-ob>>31&127}ob=d[245208+Vb|0]|0;xb=p+116+(W*12|0)+8|0;b[xb>>1]=ob;Fa=Qb+ja|0;if(Fa>>>0<128>>>0){Wb=Fa}else{Wb=-Fa>>31&127}b[p+116+(W*12|0)+10>>1]=b[247944+(Wb<<1)>>1]|0;b[va>>1]=(Ca&65535)>>>0>8>>>0?Ca:8;b[xb>>1]=(ob&65535)>>>0>132>>>0?132:ob;W=W+1|0;}while((W|0)<4);W=c[Q>>2]|0;if((a[z]|0)==0){ja=d[1252840+W|0]|0;_=c[Z>>2]|0;za=c[N>>2]|0;Aa=W<<ja;c[Q>>2]=Aa;kb=za<<ja;za=_+ja|0;do{if((za|0)>-1){ja=c[H>>2]|0;if(!(ja>>>0<(c[Na>>2]|0)>>>0)){Xb=kb;Yb=za;break}c[H>>2]=ja+2;_=ja;Xb=((he((d[_]|d[_+1|0]<<8)<<16>>16|0)|0)&65535)<<za|kb;Yb=za-16|0}else{Xb=kb;Yb=za}}while(0);c[Z>>2]=Yb;za=((Aa<<7)-128>>8)+1|0;kb=za<<16;_=Xb>>>0>=kb>>>0;ja=_&1;ua=_?Aa-za|0:za;za=Xb-(_?kb:0)|0;c[N>>2]=za;kb=d[1252840+ua|0]|0;_=ua<<kb;c[Q>>2]=_;ua=za<<kb;za=kb+Yb|0;do{if((za|0)>-1){kb=c[H>>2]|0;if(!(kb>>>0<(c[Na>>2]|0)>>>0)){Zb=ua;_b=za;break}c[H>>2]=kb+2;ob=kb;Zb=((he((d[ob]|d[ob+1|0]<<8)<<16>>16|0)|0)&65535)<<za|ua;_b=za-16|0}else{Zb=ua;_b=za}}while(0);c[Z>>2]=_b;za=((_<<7)-128>>8)+1|0;ua=za<<16;Aa=Zb>>>0>=ua>>>0;c[Q>>2]=Aa?_-za|0:za;c[N>>2]=Zb-(Aa?ua:0);c[o+4548>>2]=pab(p,ja,2)|0;c[o+4552>>2]=pab(p,Aa&1,3)|0;Aa=c[Q>>2]|0;ua=d[1252840+Aa|0]|0;za=c[Z>>2]|0;ob=c[N>>2]|0;kb=Aa<<ua;c[Q>>2]=kb;Aa=ob<<ua;ob=za+ua|0;do{if((ob|0)>-1){ua=c[H>>2]|0;if(!(ua>>>0<(c[Na>>2]|0)>>>0)){$b=Aa;ac=ob;break}c[H>>2]=ua+2;za=ua;$b=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<ob|Aa;ac=ob-16|0}else{$b=Aa;ac=ob}}while(0);c[Z>>2]=ac;ob=((kb<<7)-128>>8)+1|0;Aa=ob<<16;ja=$b>>>0>=Aa>>>0;_=ja?kb-ob|0:ob;ob=$b-(ja?Aa:0)|0;c[N>>2]=ob;a[o+74|0]=ja&1;ja=d[1252840+_|0]|0;Aa=_<<ja;c[Q>>2]=Aa;_=ob<<ja;ob=ja+ac|0;do{if((ob|0)>-1){ja=c[H>>2]|0;if(!(ja>>>0<(c[Na>>2]|0)>>>0)){bc=_;cc=ob;break}c[H>>2]=ja+2;za=ja;bc=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<ob|_;cc=ob-16|0}else{bc=_;cc=ob}}while(0);c[Z>>2]=cc;ob=((Aa<<7)-128>>8)+1|0;_=ob<<16;kb=bc>>>0>=_>>>0;za=kb?Aa-ob|0:ob;c[Q>>2]=za;ob=bc-(kb?_:0)|0;c[N>>2]=ob;a[o+75|0]=kb&1;dc=za;ec=cc;fc=ob}else{dc=W;ec=c[Z>>2]|0;fc=c[N>>2]|0}ob=d[1252840+dc|0]|0;za=dc<<ob;c[Q>>2]=za;kb=fc<<ob;_=ob+ec|0;do{if((_|0)>-1){ob=c[H>>2]|0;if(!(ob>>>0<(c[Na>>2]|0)>>>0)){gc=kb;hc=_;break}c[H>>2]=ob+2;ja=ob;gc=((he((d[ja]|d[ja+1|0]<<8)<<16>>16|0)|0)&65535)<<_|kb;hc=_-16|0}else{gc=kb;hc=_}}while(0);c[Z>>2]=hc;_=((za<<7)-128>>8)+1|0;kb=_<<16;W=gc>>>0>=kb>>>0;Aa=W?za-_|0:_;c[Q>>2]=Aa;_=gc-(W?kb:0)|0;c[N>>2]=_;kb=o+4556|0;c[kb>>2]=W&1;if(!W){nrc(o+2372|0,o+208|0,2164)|0}if((a[z]|0)==0){W=d[1252840+Aa|0]|0;ja=Aa<<W;c[Q>>2]=ja;Aa=_<<W;_=W+hc|0;do{if((_|0)>-1){W=c[H>>2]|0;if(!(W>>>0<(c[Na>>2]|0)>>>0)){ic=Aa;jc=_;break}c[H>>2]=W+2;ob=W;ic=((he((d[ob]|d[ob+1|0]<<8)<<16>>16|0)|0)&65535)<<_|Aa;jc=_-16|0}else{ic=Aa;jc=_}}while(0);c[Z>>2]=jc;_=((ja<<7)-128>>8)+1|0;Aa=_<<16;za=ic>>>0>=Aa>>>0;c[Q>>2]=za?ja-_|0:_;c[N>>2]=ic-(za?Aa:0);kc=za&1}else{kc=1}za=o+4544|0;c[za>>2]=kc;Aa=0;do{_=0;do{ob=245432+(_*10|0)|0;W=0;do{ua=0;do{xb=d[236232+(Aa*264|0)+(_*33|0)+(W*11|0)+ua|0]|0;Ca=c[Q>>2]|0;va=d[1252840+Ca|0]|0;Fa=c[Z>>2]|0;lb=c[N>>2]|0;Ea=Ca<<va;c[Q>>2]=Ea;Ca=lb<<va;lb=Fa+va|0;do{if((lb|0)>-1){va=c[H>>2]|0;if(!(va>>>0<(c[Na>>2]|0)>>>0)){lc=Ca;mc=lb;break}c[H>>2]=va+2;Fa=va;lc=((he((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)&65535)<<lb|Ca;mc=lb-16|0}else{lc=Ca;mc=lb}}while(0);c[Z>>2]=mc;lb=((ca(Ea-1|0,xb)|0)>>8)+1|0;Ca=lb<<16;if(lc>>>0<Ca>>>0){c[Q>>2]=lb;c[N>>2]=lc}else{Fa=Ea-lb|0;c[Q>>2]=Fa;lb=lc-Ca|0;c[N>>2]=lb;Ca=8;va=0;nc=Fa;Fa=mc;oc=lb;while(1){lb=Ca-1|0;pc=va<<1;qc=d[1252840+nc|0]|0;rc=nc<<qc;c[Q>>2]=rc;sc=oc<<qc;tc=qc+Fa|0;do{if((tc|0)>-1){qc=c[H>>2]|0;if(!(qc>>>0<(c[Na>>2]|0)>>>0)){uc=sc;vc=tc;break}c[H>>2]=qc+2;wc=qc;uc=((he((d[wc]|d[wc+1|0]<<8)<<16>>16|0)|0)&65535)<<tc|sc;vc=tc-16|0}else{uc=sc;vc=tc}}while(0);c[Z>>2]=vc;tc=((rc<<7)-128>>8)+1|0;sc=tc<<16;wc=uc>>>0>=sc>>>0;qc=wc?rc-tc|0:tc;c[Q>>2]=qc;tc=uc-(wc?sc:0)|0;c[N>>2]=tc;xc=wc&1|pc;if((lb|0)==0){break}else{Ca=lb;va=xc;nc=qc;Fa=vc;oc=tc}}oc=xc&255;Fa=0;nc=a[ob]|0;do{a[p+222+(Aa*528|0)+((nc<<24>>24)*33|0)+(W*11|0)+ua|0]=oc;Fa=Fa+1|0;nc=a[245432+(_*10|0)+Fa|0]|0;}while(nc<<24>>24>-1)}ua=ua+1|0;}while((ua|0)<11);W=W+1|0;}while((W|0)<3);_=_+1|0;}while((_|0)<8);Aa=Aa+1|0;}while((Aa|0)<4);Aa=c[Q>>2]|0;ja=d[1252840+Aa|0]|0;_=c[Z>>2]|0;W=c[N>>2]|0;ob=Aa<<ja;c[Q>>2]=ob;Aa=W<<ja;W=_+ja|0;do{if((W|0)>-1){ja=c[H>>2]|0;if(!(ja>>>0<(c[Na>>2]|0)>>>0)){yc=Aa;zc=W;break}c[H>>2]=ja+2;_=ja;yc=((he((d[_]|d[_+1|0]<<8)<<16>>16|0)|0)&65535)<<W|Aa;zc=W-16|0}else{yc=Aa;zc=W}}while(0);c[Z>>2]=zc;W=((ob<<7)-128>>8)+1|0;Aa=W<<16;_=yc>>>0>=Aa>>>0;ja=_?ob-W|0:W;c[Q>>2]=ja;W=yc-(_?Aa:0)|0;c[N>>2]=W;a[o+62|0]=_&1;if(_){_=8;Aa=0;R=ja;wa=zc;ua=W;while(1){Ba=_-1|0;Da=Aa<<1;Ia=d[1252840+R|0]|0;nc=R<<Ia;c[Q>>2]=nc;Fa=ua<<Ia;oc=Ia+wa|0;do{if((oc|0)>-1){Ia=c[H>>2]|0;if(!(Ia>>>0<(c[Na>>2]|0)>>>0)){Ac=Fa;Bc=oc;break}c[H>>2]=Ia+2;va=Ia;Ac=((he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)&65535)<<oc|Fa;Bc=oc-16|0}else{Ac=Fa;Bc=oc}}while(0);c[Z>>2]=Bc;oc=((nc<<7)-128>>8)+1|0;Fa=oc<<16;va=Ac>>>0>=Fa>>>0;Cc=va?nc-oc|0:oc;c[Q>>2]=Cc;Dc=Ac-(va?Fa:0)|0;c[N>>2]=Dc;Ec=va&1|Da;if((Ba|0)==0){break}else{_=Ba;Aa=Ec;R=Cc;wa=Bc;ua=Dc}}a[o+211|0]=Ec;Fc=Cc;Gc=Bc;Hc=Dc}else{Fc=ja;Gc=zc;Hc=W}if((a[z]|0)==0){ua=8;wa=0;R=Fc;Aa=Gc;_=Hc;while(1){ob=ua-1|0;va=wa<<1;Fa=d[1252840+R|0]|0;oc=R<<Fa;c[Q>>2]=oc;Ia=_<<Fa;Ca=Fa+Aa|0;do{if((Ca|0)>-1){Fa=c[H>>2]|0;if(!(Fa>>>0<(c[Na>>2]|0)>>>0)){Ic=Ia;Jc=Ca;break}c[H>>2]=Fa+2;Ea=Fa;Ic=((he((d[Ea]|d[Ea+1|0]<<8)<<16>>16|0)|0)&65535)<<Ca|Ia;Jc=Ca-16|0}else{Ic=Ia;Jc=Ca}}while(0);c[Z>>2]=Jc;Ca=((oc<<7)-128>>8)+1|0;Ia=Ca<<16;Ba=Ic>>>0>=Ia>>>0;Kc=Ba?oc-Ca|0:Ca;c[Q>>2]=Kc;Lc=Ic-(Ba?Ia:0)|0;c[N>>2]=Lc;Mc=Ba&1|va;if((ob|0)==0){break}else{ua=ob;wa=Mc;R=Kc;Aa=Jc;_=Lc}}a[o+212|0]=Mc;_=8;Aa=0;R=Kc;wa=Jc;ua=Lc;while(1){W=_-1|0;ja=Aa<<1;Ba=d[1252840+R|0]|0;Ia=R<<Ba;c[Q>>2]=Ia;Ca=ua<<Ba;Da=Ba+wa|0;do{if((Da|0)>-1){Ba=c[H>>2]|0;if(!(Ba>>>0<(c[Na>>2]|0)>>>0)){Nc=Ca;Oc=Da;break}c[H>>2]=Ba+2;nc=Ba;Nc=((he((d[nc]|d[nc+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|Ca;Oc=Da-16|0}else{Nc=Ca;Oc=Da}}while(0);c[Z>>2]=Oc;Da=((Ia<<7)-128>>8)+1|0;Ca=Da<<16;ob=Nc>>>0>=Ca>>>0;Pc=ob?Ia-Da|0:Da;c[Q>>2]=Pc;Qc=Nc-(ob?Ca:0)|0;c[N>>2]=Qc;Rc=ob&1|ja;if((W|0)==0){break}else{_=W;Aa=Rc;R=Pc;wa=Oc;ua=Qc}}a[o+213|0]=Rc;ua=8;wa=0;R=Pc;Aa=Oc;_=Qc;while(1){ob=ua-1|0;Ca=wa<<1;Da=d[1252840+R|0]|0;va=R<<Da;c[Q>>2]=va;oc=_<<Da;nc=Da+Aa|0;do{if((nc|0)>-1){Da=c[H>>2]|0;if(!(Da>>>0<(c[Na>>2]|0)>>>0)){Sc=oc;Tc=nc;break}c[H>>2]=Da+2;Ba=Da;Sc=((he((d[Ba]|d[Ba+1|0]<<8)<<16>>16|0)|0)&65535)<<nc|oc;Tc=nc-16|0}else{Sc=oc;Tc=nc}}while(0);c[Z>>2]=Tc;nc=((va<<7)-128>>8)+1|0;oc=nc<<16;W=Sc>>>0>=oc>>>0;Uc=W?va-nc|0:nc;c[Q>>2]=Uc;Vc=Sc-(W?oc:0)|0;c[N>>2]=Vc;Wc=W&1|Ca;if((ob|0)==0){break}else{ua=ob;wa=Wc;R=Uc;Aa=Tc;_=Vc}}a[o+214|0]=Wc;_=d[1252840+Uc|0]|0;Aa=Uc<<_;c[Q>>2]=Aa;R=Vc<<_;wa=_+Tc|0;do{if((wa|0)>-1){_=c[H>>2]|0;if(!(_>>>0<(c[Na>>2]|0)>>>0)){Xc=R;Yc=wa;break}c[H>>2]=_+2;ua=_;Xc=((he((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<wa|R;Yc=wa-16|0}else{Xc=R;Yc=wa}}while(0);c[Z>>2]=Yc;wa=((Aa<<7)-128>>8)+1|0;R=wa<<16;ua=Xc>>>0>=R>>>0;_=ua?Aa-wa|0:wa;c[Q>>2]=_;wa=Xc-(ua?R:0)|0;c[N>>2]=wa;if(ua){ua=0;R=_;W=Yc;oc=wa;while(1){nc=8;ja=0;Ia=R;Ba=W;Da=oc;while(1){Ea=nc-1|0;Fa=ja<<1;xb=d[1252840+Ia|0]|0;tc=Ia<<xb;c[Q>>2]=tc;qc=Da<<xb;wc=xb+Ba|0;do{if((wc|0)>-1){xb=c[H>>2]|0;if(!(xb>>>0<(c[Na>>2]|0)>>>0)){Zc=qc;_c=wc;break}c[H>>2]=xb+2;sc=xb;Zc=((he((d[sc]|d[sc+1|0]<<8)<<16>>16|0)|0)&65535)<<wc|qc;_c=wc-16|0}else{Zc=qc;_c=wc}}while(0);c[Z>>2]=_c;wc=((tc<<7)-128>>8)+1|0;qc=wc<<16;sc=Zc>>>0>=qc>>>0;xb=sc?tc-wc|0:wc;c[Q>>2]=xb;wc=Zc-(sc?qc:0)|0;c[N>>2]=wc;$c=sc&1|Fa;if((Ea|0)==0){break}else{nc=Ea;ja=$c;Ia=xb;Ba=_c;Da=wc}}a[p+215+ua|0]=$c;Da=ua+1|0;Ba=c[Q>>2]|0;Ia=c[Z>>2]|0;ja=c[N>>2]|0;if((Da|0)<4){ua=Da;R=Ba;W=Ia;oc=ja}else{ad=Ba;bd=Ia;cd=ja;break}}}else{ad=_;bd=Yc;cd=wa}oc=d[1252840+ad|0]|0;W=ad<<oc;c[Q>>2]=W;R=cd<<oc;ua=oc+bd|0;do{if((ua|0)>-1){oc=c[H>>2]|0;if(!(oc>>>0<(c[Na>>2]|0)>>>0)){dd=R;ed=ua;break}c[H>>2]=oc+2;Aa=oc;dd=((he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<ua|R;ed=ua-16|0}else{dd=R;ed=ua}}while(0);c[Z>>2]=ed;ua=((W<<7)-128>>8)+1|0;R=ua<<16;wa=dd>>>0>=R>>>0;_=wa?W-ua|0:ua;c[Q>>2]=_;ua=dd-(wa?R:0)|0;c[N>>2]=ua;if(wa){wa=8;R=0;Aa=_;_=ed;oc=ua;while(1){ua=wa-1|0;ja=R<<1;Ia=d[1252840+Aa|0]|0;Ba=Aa<<Ia;c[Q>>2]=Ba;Da=oc<<Ia;nc=Ia+_|0;do{if((nc|0)>-1){Ia=c[H>>2]|0;if(!(Ia>>>0<(c[Na>>2]|0)>>>0)){fd=Da;gd=nc;break}c[H>>2]=Ia+2;ob=Ia;fd=((he((d[ob]|d[ob+1|0]<<8)<<16>>16|0)|0)&65535)<<nc|Da;gd=nc-16|0}else{fd=Da;gd=nc}}while(0);c[Z>>2]=gd;nc=((Ba<<7)-128>>8)+1|0;Da=nc<<16;ob=fd>>>0>=Da>>>0;hd=ob?Ba-nc|0:nc;c[Q>>2]=hd;id=fd-(ob?Da:0)|0;c[N>>2]=id;jd=ob&1|ja;if((ua|0)==0){break}else{wa=ua;R=jd;Aa=hd;_=gd;oc=id}}a[o+219|0]=jd;oc=8;_=0;Aa=hd;R=gd;wa=id;while(1){W=oc-1|0;ob=_<<1;Da=d[1252840+Aa|0]|0;nc=Aa<<Da;c[Q>>2]=nc;Ia=wa<<Da;Ca=Da+R|0;do{if((Ca|0)>-1){Da=c[H>>2]|0;if(!(Da>>>0<(c[Na>>2]|0)>>>0)){kd=Ia;ld=Ca;break}c[H>>2]=Da+2;va=Da;kd=((he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)&65535)<<Ca|Ia;ld=Ca-16|0}else{kd=Ia;ld=Ca}}while(0);c[Z>>2]=ld;Ca=((nc<<7)-128>>8)+1|0;Ia=Ca<<16;ua=kd>>>0>=Ia>>>0;md=ua?nc-Ca|0:Ca;c[Q>>2]=md;nd=kd-(ua?Ia:0)|0;c[N>>2]=nd;od=ua&1|ob;if((W|0)==0){break}else{oc=W;_=od;Aa=md;R=ld;wa=nd}}a[o+220|0]=od;wa=8;R=0;Aa=md;_=ld;oc=nd;while(1){ua=wa-1|0;Ia=R<<1;Ca=d[1252840+Aa|0]|0;ja=Aa<<Ca;c[Q>>2]=ja;Ba=oc<<Ca;va=Ca+_|0;do{if((va|0)>-1){Ca=c[H>>2]|0;if(!(Ca>>>0<(c[Na>>2]|0)>>>0)){pd=Ba;qd=va;break}c[H>>2]=Ca+2;Da=Ca;pd=((he((d[Da]|d[Da+1|0]<<8)<<16>>16|0)|0)&65535)<<va|Ba;qd=va-16|0}else{pd=Ba;qd=va}}while(0);c[Z>>2]=qd;va=((ja<<7)-128>>8)+1|0;Ba=va<<16;W=pd>>>0>=Ba>>>0;ob=W?ja-va|0:va;c[Q>>2]=ob;va=pd-(W?Ba:0)|0;c[N>>2]=va;rd=W&1|Ia;if((ua|0)==0){break}else{wa=ua;R=rd;Aa=ob;_=qd;oc=va}}a[o+221|0]=rd;sd=0}else{sd=0}do{oc=0;do{_=d[242464+(sd*19|0)+oc|0]|0;Aa=c[Q>>2]|0;R=d[1252840+Aa|0]|0;wa=c[Z>>2]|0;va=c[N>>2]|0;ob=Aa<<R;c[Q>>2]=ob;Aa=va<<R;va=wa+R|0;do{if((va|0)>-1){R=c[H>>2]|0;if(!(R>>>0<(c[Na>>2]|0)>>>0)){td=Aa;ud=va;break}c[H>>2]=R+2;wa=R;td=((he((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)<<va|Aa;ud=va-16|0}else{td=Aa;ud=va}}while(0);c[Z>>2]=ud;va=((ca(ob-1|0,_)|0)>>8)+1|0;Aa=va<<16;if(td>>>0<Aa>>>0){c[Q>>2]=va;c[N>>2]=td}else{Ea=ob-va|0;c[Q>>2]=Ea;va=td-Aa|0;c[N>>2]=va;Aa=7;Fa=0;tc=Ea;Ea=ud;wa=va;while(1){va=Aa-1|0;R=Fa<<1;W=d[1252840+tc|0]|0;Ba=tc<<W;c[Q>>2]=Ba;nc=wa<<W;Da=W+Ea|0;do{if((Da|0)>-1){W=c[H>>2]|0;if(!(W>>>0<(c[Na>>2]|0)>>>0)){vd=nc;wd=Da;break}c[H>>2]=W+2;Ca=W;vd=((he((d[Ca]|d[Ca+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|nc;wd=Da-16|0}else{vd=nc;wd=Da}}while(0);c[Z>>2]=wd;Da=((Ba<<7)-128>>8)+1|0;nc=Da<<16;Ca=vd>>>0>=nc>>>0;W=Ca?Ba-Da|0:Da;c[Q>>2]=W;Da=vd-(Ca?nc:0)|0;c[N>>2]=Da;xd=Ca&1|R;if((va|0)==0){break}else{Aa=va;Fa=xd;tc=W;Ea=wd;wa=Da}}wa=xd<<1;a[p+2334+(sd*19|0)+oc|0]=(wa|0)==0|wa}oc=oc+1|0;}while((oc|0)<19);sd=sd+1|0;}while((sd|0)<2)}oc=o+8|0;ua=oc;Ia=oc;ja=c[Ia>>2]|0;do{if((c[za>>2]|0)==0){if((c[o+4548>>2]|0)==0){O=283;break}if((c[o+4552>>2]|0)==0){O=283}else{yd=8;zd=0}}else{O=283}}while(0);if((O|0)==283){yd=(a[z]|0)==0?32:48;zd=1}if((c[f+856>>2]|0)<(yd|0)){if((a[V]|0)==0){Ad=0}else{Ad=(c[f+848>>2]|0)<(yd|0)|0}a[o+61|0]=Ad;wa=o+5348|0;Ea=o+12|0;tc=o+16|0;Fa=o+20|0;Aa=wa;ob=(Aa|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|ob)){if((Aa|0)==(c[Ea>>2]|0)){break}if((Aa|0)==(c[tc>>2]|0)){break}if((Aa|0)==(c[Fa>>2]|0)){break}fGb(o+5360|0);H5a(c[u>>2]|0,wa)}}while(0);wa=o+5364|0;_=wa;Da=(_|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|Da)){if((_|0)==(c[Ea>>2]|0)){break}if((_|0)==(c[tc>>2]|0)){break}if((_|0)==(c[Fa>>2]|0)){break}fGb(o+5376|0);H5a(c[u>>2]|0,wa)}}while(0);wa=o+5380|0;W=wa;Ca=(W|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|Ca)){if((W|0)==(c[Ea>>2]|0)){break}if((W|0)==(c[tc>>2]|0)){break}if((W|0)==(c[Fa>>2]|0)){break}fGb(o+5392|0);H5a(c[u>>2]|0,wa)}}while(0);wa=o+5396|0;nc=wa;wc=(nc|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|wc)){if((nc|0)==(c[Ea>>2]|0)){break}if((nc|0)==(c[tc>>2]|0)){break}if((nc|0)==(c[Fa>>2]|0)){break}fGb(o+5408|0);H5a(c[u>>2]|0,wa)}}while(0);wa=o+5412|0;xb=wa;sc=(xb|0)==(ja|0);do{if(!((c[c[wa>>2]>>2]|0)==0|sc)){if((xb|0)==(c[Ea>>2]|0)){break}if((xb|0)==(c[tc>>2]|0)){break}if((xb|0)==(c[Fa>>2]|0)){break}fGb(o+5424|0);H5a(c[u>>2]|0,wa)}}while(0);do{if(ob){O=297}else{if((Aa|0)==(c[Ea>>2]|0)){O=297;break}if((Aa|0)==(c[tc>>2]|0)){O=297;break}if((Aa|0)==(c[Fa>>2]|0)){O=297}else{Bd=Aa}}}while(0);c:do{if((O|0)==297){do{if(!Da){if((_|0)==(c[Ea>>2]|0)){break}if((_|0)==(c[tc>>2]|0)){break}if((_|0)!=(c[Fa>>2]|0)){Bd=_;break c}}}while(0);do{if(!Ca){if((W|0)==(c[Ea>>2]|0)){break}if((W|0)==(c[tc>>2]|0)){break}if((W|0)!=(c[Fa>>2]|0)){Bd=W;break c}}}while(0);do{if(!wc){if((nc|0)==(c[Ea>>2]|0)){break}if((nc|0)==(c[tc>>2]|0)){break}if((nc|0)!=(c[Fa>>2]|0)){Bd=nc;break c}}}while(0);if(sc){Cd=f;KIb(Cd,8,2448768,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Hd();return 0}if((xb|0)==(c[Ea>>2]|0)){Cd=f;KIb(Cd,8,2448768,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Hd();return 0}if((xb|0)==(c[tc>>2]|0)){Cd=f;KIb(Cd,8,2448768,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Hd();return 0}if((xb|0)!=(c[Fa>>2]|0)){Bd=xb;break}Cd=f;KIb(Cd,8,2448768,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;Hd();return 0}}while(0);c[Ia>>2]=Bd;xb=Bd|0;sc=Bd|0;if((c[c[sc>>2]>>2]|0)!=0){fGb(Bd+12|0);H5a(c[u>>2]|0,xb)}nc=a[z]|0;d:do{if(nc<<24>>24==0){do{if((c[Ea>>2]|0)!=0){if((c[tc>>2]|0)==0){break}if((c[Fa>>2]|0)!=0){break d}}}while(0);KIb(f,24,2588280,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;I=-1094995529;break a}}while(0);Ia=c[sc>>2]|0;c[Ia+84>>2]=nc&255;c[Ia+88>>2]=(a[z]|0)!=0?1:2;Ia=J5a(c[u>>2]|0,xb,zd)|0;if((Ia|0)<0){I=Ia;break a}Ia=o+48|0;wc=o+50|0;W=dGb(ca(e[wc>>1]|0,e[Ia>>1]|0)|0)|0;Ca=Bd+12|0;c[Ca>>2]=W;if((W|0)==0){H5a(c[u>>2]|0,xb);I=-12;break a}W=c[o+4552>>2]|0;if((W|0)==-1){c[o+36>>2]=c[Fa>>2]}else{c[o+36>>2]=c[ua+(W<<2)>>2]}W=c[o+4548>>2]|0;if((W|0)==-1){c[o+32>>2]=c[tc>>2]}else{c[o+32>>2]=c[ua+(W<<2)>>2]}if((c[za>>2]|0)==0){c[o+28>>2]=c[Ea>>2]}else{c[o+28>>2]=Bd}W=o+24|0;c[W>>2]=Bd;K5a(f);_=c[sc>>2]|0;c[o+52>>2]=c[_+32>>2];c[o+56>>2]=c[_+36>>2];mrc(c[o+184>>2]|0,0,(e[Ia>>1]|0)*9|0|0)|0;_=o+5432|0;Da=c[_>>2]|0;do{if((Da|0)==0){mrc((c[o+104>>2]|0)+(((e[wc>>1]<<1)-1|0)*96|0)|0,0,((e[Ia>>1]|0)*96|0)+96|0)|0;Aa=c[_>>2]|0;if((Aa|0)!=0){Dd=Aa;O=323;break}if((a[z]|0)==0){mrc(o+76|0,0,12)|0;break}else{mrc(c[o+108>>2]|0,2,e[Ia>>1]<<2|0)|0;Dd=c[_>>2]|0;O=323;break}}else{Dd=Da;O=323}}while(0);do{if((O|0)==323){mrc(o+76|0,0,12)|0;if((Dd|0)!=1){break}Da=(ja|0)==0;do{if(!Da){if((a[B]|0)==0){break}if((a[o+90|0]|0)!=0){break}M5a(ja|0,1,0)}}while(0);_=c[n>>2]|0;Ia=_;sc=_+66|0;b[sc>>1]=-64;Ea=_+50|0;za=b[Ea>>1]|0;ua=za<<6;tc=_+70|0;b[tc>>1]=ua;if(za<<16>>16==0){break}Fa=_+4536|0;nc=_+48|0;Aa=_+112|0;ob=_+64|0;wa=_+68|0;qc=_+188|0;Ed=qc;Fd=_+90|0;Gd=_+88|0;Id=_+62|0;Jd=_+60|0;Kd=_+212|0;Ld=qc;qc=_+192|0;Md=_+204|0;Nd=_+196|0;Od=_+200|0;Pd=_+213|0;Qd=m;Rd=l;Sd=m;Td=l|0;Ud=l+4|0;Vd=Ud|0;Wd=l+8|0;Xd=Wd|0;Yd=Sd+3|0;Zd=Sd+2|0;_d=Sd+1|0;$d=Ud;ae=Ud+2|0;Ud=Wd;be=Wd+2|0;Wd=_+2334|0;ce=_+2353|0;de=l+12|0;ee=_+214|0;fe=_+5432|0;ge=_+108|0;ie=_+211|0;je=_+208|0;_=ja+12|0;ke=0;le=b[nc>>1]|0;me=-64;ne=ua;ua=za;while(1){za=c[Fa>>2]|0;oe=le&65535;pe=ke+1|0;c[Aa>>2]=33686018;b[ob>>1]=-64;b[wa>>1]=le<<6;if(le<<16>>16==0){qe=0;re=me;se=ne;te=ua}else{ue=(ke|0)==0;ve=0;we=za+(((ca(oe+1|0,pe)|0)+1|0)*96|0)|0;za=ca(oe,ke)|0;xe=oe;while(1){if(ue){c[we+(~xe*96|0)+22>>2]=33686018}oe=(c[(c[Ca>>2]|0)+4>>2]|0)+za|0;do{if(Da){ye=0}else{ze=c[_>>2]|0;if((ze|0)==0){ye=0;break}ye=(c[ze+4>>2]|0)+za|0}}while(0);do{if((a[Fd]|0)==0){if((a[Gd]|0)==0){Ae=a[oe]|0;break}else{va=a[(ye|0)==0?oe:ye]|0;a[oe]=va;Ae=va;break}}else{va=a[je]|0;R=c[Ld>>2]|0;Ba=d[1252840+R|0]|0;ze=c[qc>>2]|0;Be=c[Md>>2]|0;Ce=R<<Ba;c[Ld>>2]=Ce;R=Be<<Ba;Be=ze+Ba|0;do{if((Be|0)>-1){Ba=c[Nd>>2]|0;if(!(Ba>>>0<(c[Od>>2]|0)>>>0)){De=R;Ee=Be;break}c[Nd>>2]=Ba+2;ze=Ba;De=((he((d[ze]|d[ze+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|R;Ee=Be-16|0}else{De=R;Ee=Be}}while(0);c[qc>>2]=Ee;Be=((ca(Ce-1|0,va&255)|0)>>8)+1|0;R=Be<<16;ze=De>>>0>=R>>>0;Ba=ze&1;Fe=ze?Ce-Be|0:Be;c[Ld>>2]=Fe;Be=De-(ze?R:0)|0;c[Md>>2]=Be;R=a[(ze?2:1)+(Ia+208)|0]|0;ze=d[1252840+Fe|0]|0;Ge=Fe<<ze;c[Ld>>2]=Ge;Fe=Be<<ze;Be=ze+Ee|0;do{if((Be|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){He=Fe;Ie=Be;break}c[Nd>>2]=ze+2;Je=ze;He=((he((d[Je]|d[Je+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|Fe;Ie=Be-16|0}else{He=Fe;Ie=Be}}while(0);c[qc>>2]=Ie;Be=((ca(Ge-1|0,R&255)|0)>>8)+1|0;Fe=Be<<16;Ce=He>>>0>=Fe>>>0;c[Ld>>2]=Ce?Ge-Be|0:Be;c[Md>>2]=He-(Ce?Fe:0);Fe=Ce&1|Ba<<1;a[oe]=Fe;Ae=Fe}}while(0);a[we+5|0]=Ae;if((a[Id]|0)==0){Ke=0}else{oe=a[ie]|0;Fe=c[Ld>>2]|0;Ce=d[1252840+Fe|0]|0;Be=c[qc>>2]|0;va=c[Md>>2]|0;Je=Fe<<Ce;c[Ld>>2]=Je;Fe=va<<Ce;va=Be+Ce|0;do{if((va|0)>-1){Ce=c[Nd>>2]|0;if(!(Ce>>>0<(c[Od>>2]|0)>>>0)){Le=Fe;Me=va;break}c[Nd>>2]=Ce+2;Be=Ce;Le=((he((d[Be]|d[Be+1|0]<<8)<<16>>16|0)|0)&65535)<<va|Fe;Me=va-16|0}else{Le=Fe;Me=va}}while(0);c[qc>>2]=Me;va=((ca(Je-1|0,oe&255)|0)>>8)+1|0;Fe=va<<16;Be=Le>>>0>=Fe>>>0;c[Ld>>2]=Be?Je-va|0:va;c[Md>>2]=Le-(Be?Fe:0);Ke=Be&1}a[we|0]=Ke;do{if((a[Jd]|0)==0){Be=d[Kd]|0;Fe=c[Ld>>2]|0;va=d[1252840+Fe|0]|0;Ce=c[qc>>2]|0;ze=c[Md>>2]|0;Ne=Fe<<va;c[Ld>>2]=Ne;Fe=ze<<va;ze=Ce+va|0;do{if((ze|0)>-1){va=c[Nd>>2]|0;if(!(va>>>0<(c[Od>>2]|0)>>>0)){Oe=Fe;Pe=ze;break}c[Nd>>2]=va+2;Ce=va;Oe=((he((d[Ce]|d[Ce+1|0]<<8)<<16>>16|0)|0)&65535)<<ze|Fe;Pe=ze-16|0}else{Oe=Fe;Pe=ze}}while(0);c[qc>>2]=Pe;ze=((ca(Ne-1|0,Be)|0)>>8)+1|0;Fe=ze<<16;if(Oe>>>0<Fe>>>0){c[Ld>>2]=ze;c[Md>>2]=Oe;Ba=0;Ge=ze;R=Pe;Ce=Oe;while(1){va=a[Ia+215+Ba|0]|0;Qe=d[1252840+Ge|0]|0;Re=Ge<<Qe;c[Ld>>2]=Re;Se=Ce<<Qe;Te=Qe+R|0;do{if((Te|0)>-1){Qe=c[Nd>>2]|0;if(!(Qe>>>0<(c[Od>>2]|0)>>>0)){Ue=Se;Ve=Te;break}c[Nd>>2]=Qe+2;We=Qe;Ue=((he((d[We]|d[We+1|0]<<8)<<16>>16|0)|0)&65535)<<Te|Se;Ve=Te-16|0}else{Ue=Se;Ve=Te}}while(0);c[qc>>2]=Ve;Te=((ca(Re-1|0,va&255)|0)>>8)+1|0;Se=Te<<16;lb=Ue>>>0>=Se>>>0;pc=lb?Re-Te|0:Te;c[Ld>>2]=pc;Te=Ue-(lb?Se:0)|0;c[Md>>2]=Te;Se=a[(lb&1)+(240776+(Ba<<1))|0]|0;Ye=Se<<24>>24;if(Se<<24>>24>0){Ba=Ye;Ge=pc;R=Ve;Ce=Te}else{break}}Ce=-Ye|0;a[we+1|0]=Ce;if((Ce&255|0)==4){Ce=we+(~e[nc>>1]*96|0)+22|0;R=we+22|0;y=d[Ce]|d[Ce+1|0]<<8|d[Ce+2|0]<<16|d[Ce+3|0]<<24|0;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;R=0;do{Ce=0;Ge=c[Ld>>2]|0;Ba=c[qc>>2]|0;Be=c[Md>>2]|0;while(1){Te=a[240744+Ce|0]|0;pc=d[1252840+Ge|0]|0;Se=Ge<<pc;c[Ld>>2]=Se;lb=Be<<pc;rc=pc+Ba|0;do{if((rc|0)>-1){pc=c[Nd>>2]|0;if(!(pc>>>0<(c[Od>>2]|0)>>>0)){Ze=lb;_e=rc;break}c[Nd>>2]=pc+2;We=pc;Ze=((he((d[We]|d[We+1|0]<<8)<<16>>16|0)|0)&65535)<<rc|lb;_e=rc-16|0}else{Ze=lb;_e=rc}}while(0);c[qc>>2]=_e;rc=((ca(Se-1|0,Te&255)|0)>>8)+1|0;lb=rc<<16;We=Ze>>>0>=lb>>>0;pc=We?Se-rc|0:rc;c[Ld>>2]=pc;rc=Ze-(We?lb:0)|0;c[Md>>2]=rc;$e=a[(We&1)+(239816+(Ce<<1))|0]|0;if($e<<24>>24>0){Ce=$e<<24>>24;Ge=pc;Ba=_e;Be=rc}else{break}}a[we+6+R|0]=-$e;R=R+1|0;}while((R|0)<16)}R=0;Be=c[Ld>>2]|0;Ba=c[qc>>2]|0;Ge=c[Md>>2]|0;while(1){Ce=a[Ia+219+R|0]|0;Re=d[1252840+Be|0]|0;va=Be<<Re;c[Ld>>2]=va;rc=Ge<<Re;pc=Re+Ba|0;do{if((pc|0)>-1){Re=c[Nd>>2]|0;if(!(Re>>>0<(c[Od>>2]|0)>>>0)){af=rc;bf=pc;break}c[Nd>>2]=Re+2;We=Re;af=((he((d[We]|d[We+1|0]<<8)<<16>>16|0)|0)&65535)<<pc|rc;bf=pc-16|0}else{af=rc;bf=pc}}while(0);c[qc>>2]=bf;pc=((ca(va-1|0,Ce&255)|0)>>8)+1|0;rc=pc<<16;We=af>>>0>=rc>>>0;Re=We?va-pc|0:pc;c[Ld>>2]=Re;pc=af-(We?rc:0)|0;c[Md>>2]=pc;cf=a[(We&1)+(239792+(R<<1))|0]|0;if(cf<<24>>24>0){R=cf<<24>>24;Be=Re;Ba=bf;Ge=pc}else{break}}a[we+4|0]=-cf;a[we+2|0]=0;a[we+3|0]=4;c[we+32>>2]=0;break}Ge=Ne-ze|0;Ba=Oe-Fe|0;c[Md>>2]=Ba;Be=d[Pd]|0;R=d[1252840+Ge|0]|0;pc=Ge<<R;c[Ld>>2]=pc;Ge=Ba<<R;Ba=R+Pe|0;do{if((Ba|0)>-1){R=c[Nd>>2]|0;if(!(R>>>0<(c[Od>>2]|0)>>>0)){df=Ge;ef=Ba;break}c[Nd>>2]=R+2;Re=R;df=((he((d[Re]|d[Re+1|0]<<8)<<16>>16|0)|0)&65535)<<Ba|Ge;ef=Ba-16|0}else{df=Ge;ef=Ba}}while(0);c[qc>>2]=ef;Ba=((ca(pc-1|0,Be)|0)>>8)+1|0;Ge=Ba<<16;if(df>>>0<Ge>>>0){c[Ld>>2]=Ba;c[Md>>2]=df;a[we+2|0]=1;ff=0}else{Fe=pc-Ba|0;Ba=df-Ge|0;c[Md>>2]=Ba;Ge=a[ee]|0;ze=d[1252840+Fe|0]|0;Ne=Fe<<ze;c[Ld>>2]=Ne;Fe=Ba<<ze;Ba=ze+ef|0;do{if((Ba|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){gf=Fe;hf=Ba;break}c[Nd>>2]=ze+2;Re=ze;gf=((he((d[Re]|d[Re+1|0]<<8)<<16>>16|0)|0)&65535)<<Ba|Fe;hf=Ba-16|0}else{gf=Fe;hf=Ba}}while(0);c[qc>>2]=hf;Ba=((ca(Ne-1|0,Ge&255)|0)>>8)+1|0;Fe=Ba<<16;pc=gf>>>0>=Fe>>>0;c[Ld>>2]=pc?Ne-Ba|0:Ba;c[Md>>2]=gf-(pc?Fe:0);Fe=pc?3:2;a[we+2|0]=Fe;ff=(Fe&255)-1|0}Fe=Ia+76+(ff<<2)|0;c[Fe>>2]=(c[Fe>>2]|0)+1;Fe=a[(d[we+2|0]|0)+(Ia+72)|0]|0;c[m>>2]=0;pc=e[nc>>1]|0;Ba=~pc;Be=-2-pc|0;c[Td>>2]=0;c[Vd>>2]=0;c[Xd>>2]=0;pc=a[we+(Ba*96|0)+2|0]|0;Re=pc&255;do{if(pc<<24>>24==0){jf=0;kf=2}else{ze=c[we+(Ba*96|0)+28>>2]|0;if((ze|0)==0){a[Qd]=2;jf=0;kf=4;break}if(Fe<<24>>24==(a[Ia+72+Re|0]|0)){lf=ze}else{R=~ze;lf=(R&2147450879)+65537^R&-2147450880}c[Vd>>2]=lf;a[_d]=2;jf=1;kf=2}}while(0);Re=a[we-96+2|0]|0;pc=Re&255;do{if(Re<<24>>24==0){mf=jf}else{Ne=c[we-96+28>>2]|0;if((Ne|0)==0){a[Qd]=kf;mf=jf;break}if(Fe<<24>>24==(a[Ia+72+pc|0]|0)){nf=Ne}else{Ge=~Ne;nf=(Ge&2147450879)+65537^Ge&-2147450880}if((nf|0)==(c[Rd+(jf<<2)>>2]|0)){of=jf}else{Ge=jf+1|0;c[Rd+(Ge<<2)>>2]=nf;of=Ge}Ge=Sd+of|0;a[Ge]=(a[Ge]|0)+2;mf=of}}while(0);pc=a[we+(Be*96|0)+2|0]|0;Re=pc&255;do{if(!(pc<<24>>24==0)){Ge=c[we+(Be*96|0)+28>>2]|0;if((Ge|0)==0){a[Qd]=(a[Qd]|0)+1;break}if(Fe<<24>>24==(a[Ia+72+Re|0]|0)){pf=Ge}else{Ne=~Ge;pf=(Ne&2147450879)+65537^Ne&-2147450880}if((pf|0)==(c[Rd+(mf<<2)>>2]|0)){qf=mf}else{Ne=mf+1|0;c[Rd+(Ne<<2)>>2]=pf;qf=Ne}Ne=Sd+qf|0;a[Ne]=(a[Ne]|0)+1}}while(0);Re=we+3|0;a[Re]=4;Fe=a[Qd]|0;pc=c[242672+((Fe&255)<<4)>>2]|0;Ne=c[Ld>>2]|0;Ge=d[1252840+Ne|0]|0;R=c[qc>>2]|0;ze=c[Md>>2]|0;We=Ne<<Ge;c[Ld>>2]=We;Ne=ze<<Ge;ze=R+Ge|0;do{if((ze|0)>-1){Ge=c[Nd>>2]|0;if(!(Ge>>>0<(c[Od>>2]|0)>>>0)){rf=Ne;sf=ze;break}c[Nd>>2]=Ge+2;R=Ge;rf=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<ze|Ne;sf=ze-16|0}else{rf=Ne;sf=ze}}while(0);c[qc>>2]=sf;ze=((ca(We-1|0,pc)|0)>>8)+1|0;Ne=ze<<16;if(rf>>>0<Ne>>>0){c[Ld>>2]=ze;c[Md>>2]=rf;a[we+1|0]=5;c[we+28>>2]=0;c[we+32>>2]=0;break}c[Ld>>2]=We-ze;c[Md>>2]=rf-Ne;Ne=we+1|0;a[Ne]=6;do{if((a[Yd]|0)!=0){if((c[Vd>>2]|0)!=(c[de>>2]|0)){break}a[_d]=(a[_d]|0)+1}}while(0);We=a[Zd]|0;pc=a[_d]|0;if((We&255)>>>0>(pc&255)>>>0){a[Zd]=pc;a[_d]=We;ze=c[Xd>>2]|0;c[Xd>>2]=c[Vd>>2];c[Vd>>2]=ze;tf=We;uf=pc}else{tf=pc;uf=We}We=c[242676+((tf&255)<<4)>>2]|0;pc=c[Ld>>2]|0;ze=d[1252840+pc|0]|0;R=c[qc>>2]|0;Ge=c[Md>>2]|0;rc=pc<<ze;c[Ld>>2]=rc;pc=Ge<<ze;Ge=R+ze|0;do{if((Ge|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){vf=pc;wf=Ge;break}c[Nd>>2]=ze+2;R=ze;vf=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|pc;wf=Ge-16|0}else{vf=pc;wf=Ge}}while(0);c[qc>>2]=wf;Ge=((ca(rc-1|0,We)|0)>>8)+1|0;pc=Ge<<16;if(vf>>>0<pc>>>0){c[Ld>>2]=Ge;c[Md>>2]=vf;R=we+28|0;ze=b[$d>>1]|0;lb=b[ob>>1]|0;Qe=b[wa>>1]|0;if(ze<<16>>16<lb<<16>>16){xf=lb}else{xf=ze<<16>>16>Qe<<16>>16?Qe:ze}b[R>>1]=xf;ze=b[ae>>1]|0;Qe=b[sc>>1]|0;lb=b[tc>>1]|0;if(ze<<16>>16<Qe<<16>>16){yf=Qe}else{yf=ze<<16>>16>lb<<16>>16?lb:ze}b[we+30>>1]=yf;c[we+32>>2]=c[R>>2];break}R=rc-Ge|0;Ge=vf-pc|0;c[Md>>2]=Ge;pc=c[242680+((uf&255)<<4)>>2]|0;ze=d[1252840+R|0]|0;lb=R<<ze;c[Ld>>2]=lb;R=Ge<<ze;Ge=ze+wf|0;do{if((Ge|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){zf=R;Af=Ge;break}c[Nd>>2]=ze+2;Qe=ze;zf=((he((d[Qe]|d[Qe+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|R;Af=Ge-16|0}else{zf=R;Af=Ge}}while(0);c[qc>>2]=Af;Ge=((ca(lb-1|0,pc)|0)>>8)+1|0;R=Ge<<16;if(zf>>>0<R>>>0){c[Ld>>2]=Ge;c[Md>>2]=zf;rc=we+28|0;We=b[Ud>>1]|0;Qe=b[ob>>1]|0;ze=b[wa>>1]|0;if(We<<16>>16<Qe<<16>>16){Bf=Qe}else{Bf=We<<16>>16>ze<<16>>16?ze:We}b[rc>>1]=Bf;We=b[be>>1]|0;ze=b[sc>>1]|0;Qe=b[tc>>1]|0;if(We<<16>>16<ze<<16>>16){Cf=ze}else{Cf=We<<16>>16>Qe<<16>>16?Qe:We}b[we+30>>1]=Cf;c[we+32>>2]=c[rc>>2];break}rc=lb-Ge|0;c[Ld>>2]=rc;Ge=zf-R|0;c[Md>>2]=Ge;R=we+28|0;We=(tf&255)>>>0>=(Fe&255)>>>0|0;Qe=b[Rd+(We<<2)>>1]|0;ze=b[ob>>1]|0;Df=b[wa>>1]|0;if(Qe<<16>>16<ze<<16>>16){Ef=ze}else{Ef=Qe<<16>>16>Df<<16>>16?Df:Qe}Qe=R|0;b[Qe>>1]=Ef;Df=b[Rd+(We<<2)+2>>1]|0;We=b[sc>>1]|0;ze=b[tc>>1]|0;if(Df<<16>>16<We<<16>>16){Ff=We}else{Ff=Df<<16>>16>ze<<16>>16?ze:Df}Df=we+30|0;b[Df>>1]=Ff;ze=(((a[we+(Ba*96|0)+1|0]|0)==7)+((a[we-96+1|0]|0)==7)&255)<<1|(a[we+(Be*96|0)+1|0]|0)==7;a[Yd]=ze;We=c[242684+((ze&255)<<4)>>2]|0;ze=d[1252840+rc|0]|0;Gf=rc<<ze;c[Ld>>2]=Gf;rc=Ge<<ze;Ge=ze+Af|0;do{if((Ge|0)>-1){ze=c[Nd>>2]|0;if(!(ze>>>0<(c[Od>>2]|0)>>>0)){Hf=rc;If=Ge;break}c[Nd>>2]=ze+2;Jf=ze;Hf=((he((d[Jf]|d[Jf+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|rc;If=Ge-16|0}else{Hf=rc;If=Ge}}while(0);c[qc>>2]=If;Ge=((ca(Gf-1|0,We)|0)>>8)+1|0;rc=Ge<<16;if(Hf>>>0<rc>>>0){c[Ld>>2]=Ge;c[Md>>2]=Hf;Be=oab(Ed,Wd)|0;b[Df>>1]=(e[Df>>1]|0)+Be;Be=oab(Ed,ce)|0;b[Qe>>1]=(e[Qe>>1]|0)+Be;c[we+32>>2]=c[R>>2];break}c[Ld>>2]=Gf-Ge;c[Md>>2]=Hf-rc;a[Ne]=7;rc=d[we-96+3|0]|0;Ge=~e[nc>>1];Be=d[we+(Ge*96|0)+3|0]|0;Ba=c[Ld>>2]|0;Fe=d[1252840+Ba|0]|0;lb=c[qc>>2]|0;pc=c[Md>>2]|0;Jf=Ba<<Fe;c[Ld>>2]=Jf;Ba=pc<<Fe;pc=lb+Fe|0;do{if((pc|0)>-1){Fe=c[Nd>>2]|0;if(!(Fe>>>0<(c[Od>>2]|0)>>>0)){Kf=Ba;Lf=pc;break}c[Nd>>2]=Fe+2;lb=Fe;Kf=((he((d[lb]|d[lb+1|0]<<8)<<16>>16|0)|0)&65535)<<pc|Ba;Lf=pc-16|0}else{Kf=Ba;Lf=pc}}while(0);c[qc>>2]=Lf;pc=((Jf*110|0)-110>>8)+1|0;Ba=pc<<16;do{if(Kf>>>0<Ba>>>0){c[Ld>>2]=pc;c[Md>>2]=Kf;Mf=3}else{Ne=Jf-pc|0;Gf=Kf-Ba|0;c[Md>>2]=Gf;Qe=d[1252840+Ne|0]|0;We=Ne<<Qe;c[Ld>>2]=We;Ne=Gf<<Qe;Gf=Qe+Lf|0;do{if((Gf|0)>-1){Qe=c[Nd>>2]|0;if(!(Qe>>>0<(c[Od>>2]|0)>>>0)){Nf=Ne;Of=Gf;break}c[Nd>>2]=Qe+2;lb=Qe;Nf=((he((d[lb]|d[lb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gf|Ne;Of=Gf-16|0}else{Nf=Ne;Of=Gf}}while(0);c[qc>>2]=Of;Gf=((We*111|0)-111>>8)+1|0;Ne=Gf<<16;if(Nf>>>0<Ne>>>0){c[Ld>>2]=Gf;c[Md>>2]=Nf;Mf=2;break}va=We-Gf|0;Gf=Nf-Ne|0;c[Md>>2]=Gf;Ne=d[1252840+va|0]|0;Ce=va<<Ne;c[Ld>>2]=Ce;va=Gf<<Ne;Gf=Ne+Of|0;do{if((Gf|0)>-1){Ne=c[Nd>>2]|0;if(!(Ne>>>0<(c[Od>>2]|0)>>>0)){Pf=va;Qf=Gf;break}c[Nd>>2]=Ne+2;lb=Ne;Pf=((he((d[lb]|d[lb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gf|va;Qf=Gf-16|0}else{Pf=va;Qf=Gf}}while(0);c[qc>>2]=Qf;Gf=((Ce*150|0)-150>>8)+1|0;va=Gf<<16;We=Pf>>>0>=va>>>0;c[Ld>>2]=We?Ce-Gf|0:Gf;c[Md>>2]=Pf-(We?va:0);Mf=We&1}}while(0);Ba=d[243216+Mf|0]|0;a[Re]=Mf;pc=we+28|0;Jf=0;do{We=a[243240+(Mf<<4)+Jf|0]|0;va=We&255;if((va&3|0)==0){Rf=we-96+32+(d[va+3+(242768+(rc<<4))|0]<<2)|0}else{Rf=we+32+(d[va-1+(242768+(Mf<<4))|0]<<2)|0}Gf=c[Rf>>2]|0;if((We&255)>>>0<4>>>0){Sf=we+(Ge*96|0)+32+(d[va+12+(242768+(Be<<4))|0]<<2)|0}else{Sf=we+32+(d[va-4+(242768+(Mf<<4))|0]<<2)|0}va=c[Sf>>2]|0;do{if((Gf|0)==(va|0)){Tf=238344+((4-((Gf|0)!=0)|0)*3|0)|0}else{if((va|0)==0){Tf=238350;break}Tf=238344+(((Gf|0)==0|0)*3|0)|0}}while(0);Ce=d[Tf]|0;We=c[Ld>>2]|0;lb=d[1252840+We|0]|0;Ne=c[qc>>2]|0;Qe=c[Md>>2]|0;Fe=We<<lb;c[Ld>>2]=Fe;We=Qe<<lb;Qe=Ne+lb|0;do{if((Qe|0)>-1){lb=c[Nd>>2]|0;if(!(lb>>>0<(c[Od>>2]|0)>>>0)){Uf=We;Vf=Qe;break}c[Nd>>2]=lb+2;Ne=lb;Uf=((he((d[Ne]|d[Ne+1|0]<<8)<<16>>16|0)|0)&65535)<<Qe|We;Vf=Qe-16|0}else{Uf=We;Vf=Qe}}while(0);c[qc>>2]=Vf;Qe=((ca(Fe-1|0,Ce)|0)>>8)+1|0;We=Qe<<16;do{if(Uf>>>0<We>>>0){c[Ld>>2]=Qe;c[Md>>2]=Uf;c[we+32+(Jf<<2)>>2]=Gf}else{Ne=Fe-Qe|0;c[Ld>>2]=Ne;lb=Uf-We|0;c[Md>>2]=lb;ze=d[Tf+1|0]|0;Wf=d[1252840+Ne|0]|0;Xf=Ne<<Wf;c[Ld>>2]=Xf;Ne=lb<<Wf;lb=Wf+Vf|0;do{if((lb|0)>-1){Wf=c[Nd>>2]|0;if(!(Wf>>>0<(c[Od>>2]|0)>>>0)){Yf=Ne;Zf=lb;break}c[Nd>>2]=Wf+2;_f=Wf;Yf=((he((d[_f]|d[_f+1|0]<<8)<<16>>16|0)|0)&65535)<<lb|Ne;Zf=lb-16|0}else{Yf=Ne;Zf=lb}}while(0);c[qc>>2]=Zf;lb=((ca(Xf-1|0,ze)|0)>>8)+1|0;Ne=lb<<16;if(Yf>>>0<Ne>>>0){c[Ld>>2]=lb;c[Md>>2]=Yf;c[we+32+(Jf<<2)>>2]=va;break}Se=Xf-lb|0;c[Ld>>2]=Se;lb=Yf-Ne|0;c[Md>>2]=lb;Ne=d[Tf+2|0]|0;Te=d[1252840+Se|0]|0;_f=Se<<Te;c[Ld>>2]=_f;Se=lb<<Te;lb=Te+Zf|0;do{if((lb|0)>-1){Te=c[Nd>>2]|0;if(!(Te>>>0<(c[Od>>2]|0)>>>0)){$f=Se;ag=lb;break}c[Nd>>2]=Te+2;Wf=Te;$f=((he((d[Wf]|d[Wf+1|0]<<8)<<16>>16|0)|0)&65535)<<lb|Se;ag=lb-16|0}else{$f=Se;ag=lb}}while(0);c[qc>>2]=ag;lb=((ca(_f-1|0,Ne)|0)>>8)+1|0;Se=lb<<16;if($f>>>0<Se>>>0){c[Ld>>2]=lb;c[Md>>2]=$f;c[we+32+(Jf<<2)>>2]=0;break}else{c[Ld>>2]=_f-lb;c[Md>>2]=$f-Se;Se=e[Df>>1]|0;b[we+32+(Jf<<2)+2>>1]=Se+(oab(Ed,Wd)|0);Se=e[pc>>1]|0;b[we+32+(Jf<<2)>>1]=Se+(oab(Ed,ce)|0);break}}}while(0);Jf=Jf+1|0;}while((Jf|0)<(Ba|0));c[R>>2]=c[we+32+(Ba-1<<2)>>2]}else{Jf=0;pc=c[Ld>>2]|0;Df=c[qc>>2]|0;Be=c[Md>>2]|0;while(1){Ge=a[240784+Jf|0]|0;rc=d[1252840+pc|0]|0;Re=pc<<rc;c[Ld>>2]=Re;va=Be<<rc;We=rc+Df|0;do{if((We|0)>-1){rc=c[Nd>>2]|0;if(!(rc>>>0<(c[Od>>2]|0)>>>0)){bg=va;cg=We;break}c[Nd>>2]=rc+2;Qe=rc;bg=((he((d[Qe]|d[Qe+1|0]<<8)<<16>>16|0)|0)&65535)<<We|va;cg=We-16|0}else{bg=va;cg=We}}while(0);c[qc>>2]=cg;We=((ca(Re-1|0,Ge&255)|0)>>8)+1|0;va=We<<16;Qe=bg>>>0>=va>>>0;rc=Qe?Re-We|0:We;c[Ld>>2]=rc;We=bg-(Qe?va:0)|0;c[Md>>2]=We;va=a[(Qe&1)+(240768+(Jf<<1))|0]|0;dg=va<<24>>24;if(va<<24>>24>0){Jf=dg;pc=rc;Df=cg;Be=We}else{break}}Be=-dg|0;a[we+1|0]=Be;Df=Be&255;if((Df|0)==4){Be=we+(~e[nc>>1]*96|0)+22|0;pc=we+22|0;y=d[Be]|d[Be+1|0]<<8|d[Be+2|0]<<16|d[Be+3|0]<<24|0;a[pc]=y;y=y>>8;a[pc+1|0]=y;y=y>>8;a[pc+2|0]=y;y=y>>8;a[pc+3|0]=y;pc=0;Be=we+6|0;while(1){Jf=Ia+112+pc|0;Ba=0;R=Be;We=a[Jf]|0;while(1){rc=We&255;va=we+22+Ba|0;Qe=d[va]|0;Fe=0;Gf=c[Ld>>2]|0;Ce=c[qc>>2]|0;Se=c[Md>>2]|0;while(1){lb=a[239840+(Qe*90|0)+(rc*9|0)+Fe|0]|0;Xf=d[1252840+Gf|0]|0;ze=Gf<<Xf;c[Ld>>2]=ze;Wf=Se<<Xf;Te=Xf+Ce|0;do{if((Te|0)>-1){Xf=c[Nd>>2]|0;if(!(Xf>>>0<(c[Od>>2]|0)>>>0)){eg=Wf;fg=Te;break}c[Nd>>2]=Xf+2;gg=Xf;eg=((he((d[gg]|d[gg+1|0]<<8)<<16>>16|0)|0)&65535)<<Te|Wf;fg=Te-16|0}else{eg=Wf;fg=Te}}while(0);c[qc>>2]=fg;Te=((ca(ze-1|0,lb&255)|0)>>8)+1|0;Wf=Te<<16;gg=eg>>>0>=Wf>>>0;Xf=gg?ze-Te|0:Te;c[Ld>>2]=Xf;Te=eg-(gg?Wf:0)|0;c[Md>>2]=Te;hg=a[(gg&1)+(239816+(Fe<<1))|0]|0;if(hg<<24>>24>0){Fe=hg<<24>>24;Gf=Xf;Ce=fg;Se=Te}else{break}}Se=-hg&255;a[R]=Se;a[va]=Se;a[Jf]=Se;Ce=Ba+1|0;if((Ce|0)>=4){break}Ba=Ce;R=R+1|0;We=Se}We=pc+1|0;if((We|0)<4){pc=We;Be=Be+4|0}else{break}}}else{Be=ca(d[240760+Df|0]|0,16843009)|0;if((c[fe>>2]|0)==0){c[(c[ge>>2]|0)+(ve<<2)>>2]=Be}else{c[we+22>>2]=Be}c[Aa>>2]=Be}Be=0;pc=c[Ld>>2]|0;We=c[qc>>2]|0;R=c[Md>>2]|0;while(1){Ba=a[239800+Be|0]|0;Jf=d[1252840+pc|0]|0;Re=pc<<Jf;c[Ld>>2]=Re;Ge=R<<Jf;Se=Jf+We|0;do{if((Se|0)>-1){Jf=c[Nd>>2]|0;if(!(Jf>>>0<(c[Od>>2]|0)>>>0)){ig=Ge;jg=Se;break}c[Nd>>2]=Jf+2;Ce=Jf;ig=((he((d[Ce]|d[Ce+1|0]<<8)<<16>>16|0)|0)&65535)<<Se|Ge;jg=Se-16|0}else{ig=Ge;jg=Se}}while(0);c[qc>>2]=jg;Se=((ca(Re-1|0,Ba&255)|0)>>8)+1|0;Ge=Se<<16;Ce=ig>>>0>=Ge>>>0;Jf=Ce?Re-Se|0:Se;c[Ld>>2]=Jf;Se=ig-(Ce?Ge:0)|0;c[Md>>2]=Se;kg=a[(Ce&1)+(239792+(Be<<1))|0]|0;if(kg<<24>>24>0){Be=kg<<24>>24;pc=Jf;We=jg;R=Se}else{break}}a[we+4|0]=-kg;a[we+2|0]=0}}while(0);b[ob>>1]=(b[ob>>1]|0)-64;b[wa>>1]=(b[wa>>1]|0)-64;Je=ve+1|0;lg=b[nc>>1]|0;oe=lg&65535;if((Je|0)<(oe|0)){ve=Je;we=we+96|0;za=za+1|0;xe=oe}else{break}}qe=lg;re=b[sc>>1]|0;se=b[tc>>1]|0;te=b[Ea>>1]|0}xe=re-64&65535;b[sc>>1]=xe;za=se-64&65535;b[tc>>1]=za;if((pe|0)<(te&65535|0)){ke=pe;le=qe;me=xe;ne=za;ua=te}else{break}}}}while(0);if((c[f+816>>2]|0)==1){mg=1}else{Ca=c[oa>>2]|0;ua=c[f+808>>2]|0;mg=(Ca|0)>(ua|0)?ua:Ca}c[o+5428>>2]=mg;c[o+40>>2]=Bd;c[o+44>>2]=ja;b[o+66>>1]=-64;b[o+70>>1]=b[wc>>1]<<6;Ca=c[o>>2]|0;c[Ca+840>>2]=0;c[Ca+844>>2]=2147483647;c[Ca+2376>>2]=0;c[Ca+2380>>2]=2147483647;c[Ca+3912>>2]=0;c[Ca+3916>>2]=2147483647;c[Ca+5448>>2]=0;c[Ca+5452>>2]=2147483647;c[Ca+6984>>2]=0;c[Ca+6988>>2]=2147483647;c[Ca+8520>>2]=0;c[Ca+8524>>2]=2147483647;c[Ca+10056>>2]=0;c[Ca+10060>>2]=2147483647;c[Ca+11592>>2]=0;c[Ca+11596>>2]=2147483647;Xe[c[f+828>>2]&511](f,38,Ca,0,mg)|0;L5a(xb,2147483647,0);c[oc>>2]=c[W>>2];c[oc+4>>2]=c[W+4>>2];c[oc+8>>2]=c[W+8>>2];c[oc+12>>2]=c[W+12>>2];ng=Bd}else{c[C>>2]=1;Ca=o+24|0;c[Ca>>2]=c[oc>>2];c[Ca+4>>2]=c[oc+4>>2];c[Ca+8>>2]=c[oc+8>>2];c[Ca+12>>2]=c[oc+12>>2];ng=0}if((c[kb>>2]|0)==0){nrc(o+208|0,o+2372|0,2164)|0}do{if((c[C>>2]|0)==0){Ca=YHb(g,c[ng>>2]|0)|0;if((Ca|0)<0){og=Ca;i=k;return og|0}else{c[h>>2]=1;break}}}while(0);og=c[r>>2]|0;i=k;return og|0}}while(0);KIb(c[u>>2]|0,16,2117944,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;I=-1094995529}}while(0);G=o+24|0;u=o+8|0;c[G>>2]=c[u>>2];c[G+4>>2]=c[u+4>>2];c[G+8>>2]=c[u+8>>2];c[G+12>>2]=c[u+12>>2];og=I;i=k;return og|0}function iab(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;g=f+60|0;j=c[g>>2]|0;k=c[j>>2]|0;l=c[j+40>>2]|0;m=c[j+5428>>2]|0;c[k+(h*1536|0)+836>>2]=i;n=j+50|0;if((e[n>>1]|0)<=(h|0)){return 0}o=k+(h*1536|0)+840|0;k=j+61|0;p=j+66|0;q=j+70|0;r=f+816|0;f=l|0;l=h;s=j;while(1){c[o>>2]=l<<16;nab(s,h,i);a:do{if((a[k]|0)!=0){j=c[g>>2]|0;t=c[j>>2]|0;u=c[t+(i*1536|0)+840>>2]>>16;v=c[c[j+40>>2]>>2]|0;w=j+52|0;x=j+56|0;y=ca(c[x>>2]|0,u<<3)|0;z=j+48|0;if((b[z>>1]|0)==0){break}A=ca(u<<4,c[w>>2]|0)|0;B=t+(i*1536|0)+1520|0;t=(c[j+5428>>2]|0)==1;C=j+99|0;D=j+180|0;E=j+60|0;F=j+4776|0;G=j+4784|0;H=(u|0)==0;u=j+4772|0;I=j+4780|0;J=j+4756|0;K=j+4764|0;L=j+4760|0;M=j+4768|0;N=j+4792|0;O=j+4788|0;j=(c[v+8>>2]|0)+y|0;P=(c[v+4>>2]|0)+y|0;y=(c[v>>2]|0)+A|0;A=0;while(1){v=c[B>>2]|0;do{if(t){Q=A+1|0;R=c[D>>2]|0;S=R+(Q<<5)|0;T=c[w>>2]|0;if((a[C]|0)==0){U=c[x>>2]|0;V=T*15|0;W=y+V|0;X=c[W+4>>2]|0;Y=S;c[Y>>2]=c[W>>2];c[Y+4>>2]=X;X=y+(V+8)|0;V=c[X+4>>2]|0;Y=R+(Q<<5)+8|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=V;V=U*7|0;U=P+V|0;Y=c[U+4>>2]|0;X=R+(Q<<5)+16|0;c[X>>2]=c[U>>2];c[X+4>>2]=Y;Y=j+V|0;V=c[Y+4>>2]|0;X=R+(Q<<5)+24|0;c[X>>2]=c[Y>>2];c[X+4>>2]=V;break}else{V=T*15|0;T=y+V|0;X=c[T+4>>2]|0;Y=S;c[Y>>2]=c[T>>2];c[Y+4>>2]=X;X=y+(V+8)|0;V=c[X+4>>2]|0;Y=R+(Q<<5)+8|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=V;break}}}while(0);V=a[v+(A*3|0)|0]|0;do{if((a[C]|0)==0){Y=a[v+(A*3|0)+2|0]|0;X=V&255;Q=d[v+(A*3|0)+1|0]|0;R=c[w>>2]|0;T=c[x>>2]|0;if(V<<24>>24==0){break}S=Q+(X<<1)|0;U=S+4|0;W=d[1226200+(d[E]<<6)+X|0]|0;if((A|0)!=0){pe[c[L>>2]&1023](y,R,U,Q,W);_e[c[M>>2]&511](P,j,T,U,Q,W)}X=Y<<24>>24!=0;if(X){pe[c[F>>2]&1023](y+4|0,R,S,Q,W);pe[c[F>>2]&1023](y+8|0,R,S,Q,W);pe[c[F>>2]&1023](y+12|0,R,S,Q,W);_e[c[G>>2]&511](P+4|0,j+4|0,T,S,Q,W)}if(!H){pe[c[J>>2]&1023](y,R,U,Q,W);_e[c[K>>2]&511](P,j,T,U,Q,W)}if(!X){break}pe[c[u>>2]&1023](y+(R<<2)|0,R,S,Q,W);pe[c[u>>2]&1023](y+(R<<3)|0,R,S,Q,W);pe[c[u>>2]&1023](y+(R*12|0)|0,R,S,Q,W);R=T<<2;_e[c[I>>2]&511](P+R|0,j+R|0,T,S,Q,W)}else{W=a[v+(A*3|0)+2|0]|0;Q=c[w>>2]|0;if(V<<24>>24==0){break}S=(d[v+(A*3|0)+1|0]|0)+((V&255)<<1)|0;T=S+4|0;if((A|0)!=0){ef[c[N>>2]&4095](y,Q,T)}R=W<<24>>24!=0;if(R){ef[c[N>>2]&4095](y+4|0,Q,S);ef[c[N>>2]&4095](y+8|0,Q,S);ef[c[N>>2]&4095](y+12|0,Q,S)}if(!H){ef[c[O>>2]&4095](y,Q,T)}if(!R){break}ef[c[O>>2]&4095](y+(Q<<2)|0,Q,S);ef[c[O>>2]&4095](y+(Q<<3)|0,Q,S);ef[c[O>>2]&4095](y+(Q*12|0)|0,Q,S)}}while(0);V=A+1|0;if((V|0)>=(e[z>>1]|0)){break a}j=j+8|0;P=P+8|0;y=y+16|0;A=V}}}while(0);b[p>>1]=(b[p>>1]|0)-64;b[q>>1]=(b[q>>1]|0)-64;if((c[r>>2]|0)==1){L5a(f,l,0)}A=l+m|0;if((A|0)>=(e[n>>1]|0)){break}l=A;s=c[g>>2]|0}return 0}function jab(a){a=a|0;var b=0;b=c[a+60>>2]|0;kab(b,1);VHb(b+5348|0);VHb(b+5364|0);VHb(b+5380|0);VHb(b+5396|0);VHb(b+5412|0);return 0}function kab(a,b){a=a|0;b=b|0;var d=0;d=a+4|0;fGb(a+5360|0);H5a(c[d>>2]|0,a+5348|0);fGb(a+5376|0);H5a(c[d>>2]|0,a+5364|0);fGb(a+5392|0);H5a(c[d>>2]|0,a+5380|0);fGb(a+5408|0);H5a(c[d>>2]|0,a+5396|0);fGb(a+5424|0);H5a(c[d>>2]|0,a+5412|0);mrc(a+8|0,0,16)|0;if((b|0)==0){return}b=a;d=c[b>>2]|0;if((d|0)!=0){mJb(d+1520|0);mJb((c[b>>2]|0)+3056|0);mJb((c[b>>2]|0)+4592|0);mJb((c[b>>2]|0)+6128|0);mJb((c[b>>2]|0)+7664|0);mJb((c[b>>2]|0)+9200|0);mJb((c[b>>2]|0)+10736|0);mJb((c[b>>2]|0)+12272|0)}mJb(a);mJb(a+4536|0);mJb(a+108|0);mJb(a+184|0);mJb(a+180|0);c[a+104>>2]=0;return}function lab(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+60|0;d=c[b>>2]|0;e=d;c[d+4>>2]=a;c[a+140>>2]=0;c[(c[a+64>>2]|0)+4>>2]=1;G8a(d+4724|0,8);zma(d+5012|0,141,8,1);rab(d+4732|0,0);d=0;while(1){if(!(d>>>0<5>>>0)){f=0;g=5;break}a=UHb()|0;c[e+5348+(d<<4)>>2]=a;if((a|0)==0){break}else{d=d+1|0}}if((g|0)==5){return f|0}g=c[b>>2]|0;kab(g,1);VHb(g+5348|0);VHb(g+5364|0);VHb(g+5380|0);VHb(g+5396|0);VHb(g+5412|0);f=-12;return f|0}function mab(a){a=a|0;var b=0;b=c[a+60>>2]|0;a=b+4|0;fGb(b+5360|0);H5a(c[a>>2]|0,b+5348|0);fGb(b+5376|0);H5a(c[a>>2]|0,b+5364|0);fGb(b+5392|0);H5a(c[a>>2]|0,b+5380|0);fGb(b+5408|0);H5a(c[a>>2]|0,b+5396|0);fGb(b+5424|0);H5a(c[a>>2]|0,b+5412|0);mrc(b+8|0,0,16)|0;return}function nab(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Te=0,Ue=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0,Ig=0,Jg=0,Kg=0,Lg=0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0,$i=0,aj=0,bj=0,cj=0,dj=0,ej=0,fj=0,gj=0,hj=0,ij=0,jj=0,kj=0,lj=0,mj=0,nj=0,oj=0,pj=0,qj=0,rj=0,sj=0,tj=0,uj=0,vj=0;g=i;i=i+96|0;j=g|0;k=g+8|0;l=g+16|0;m=g+56|0;n=g+72|0;o=g+80|0;p=f;q=c[f>>2]|0;r=c[q+(h*1536|0)+840>>2]>>16;s=f+48|0;t=e[s>>1]|0;u=ca(t,r)|0;v=c[f+5428>>2]|0;w=c[f+40>>2]|0;x=c[f+44>>2]|0;z=(c[f+4560>>2]|0)-1&r;A=f+4564|0;B=o|0;C=c[w>>2]|0;D=r<<4;E=f+52|0;F=(c[C>>2]|0)+(ca(D,c[E>>2]|0)|0)|0;c[B>>2]=F;G=o+4|0;H=r<<3;I=f+56|0;J=ca(c[I>>2]|0,H)|0;K=(c[C+4>>2]|0)+J|0;c[G>>2]=K;L=o+8|0;M=(c[C+8>>2]|0)+J|0;c[L>>2]=M;J=f+50|0;C=f+5432|0;if((c[C>>2]|0)==1){N=(c[f+4536>>2]|0)+(((ca(t+1|0,r+1|0)|0)+1|0)*96|0)|0}else{do{if((x|0)!=0){if((a[f+88|0]|0)==0){break}if((a[f+90|0]|0)!=0){break}M5a(x|0,r,0)}}while(0);t=c[f+104>>2]|0;O=(e[J>>1]|0)-r<<1;mrc(t+((O-3|0)*96|0)|0,0,96)|0;c[f+112>>2]=33686018;N=t+((O-2|0)*96|0)|0}O=q+(h*1536|0)+824|0;mrc(O|0,0,9)|0;t=f+64|0;b[t>>1]=-64;P=b[s>>1]|0;Q=f+68|0;b[Q>>1]=P<<6;if(P<<16>>16==0){i=g;return}P=f+4728|0;R=w+12|0;w=(x|0)==0;S=f+188|0;T=S;U=f+90|0;V=f+88|0;W=f+62|0;X=f+60|0;Y=f+212|0;Z=S;S=f+192|0;_=f+204|0;$=f+196|0;aa=f+200|0;ba=f+213|0;da=n;ea=m;fa=n;ga=m|0;ha=m+4|0;ia=ha|0;ja=m+8|0;ka=ja|0;la=fa+3|0;ma=fa+2|0;na=fa+1|0;oa=ha;pa=ha+2|0;ha=f+66|0;qa=f+70|0;ra=ja;sa=ja+2|0;ja=f+2334|0;ta=f+2353|0;ua=m+12|0;m=f+214|0;va=f+108|0;wa=f+112|0;xa=f+211|0;ya=f+208|0;za=x+12|0;x=f+76|0;Aa=f+12|0;Ba=f+184|0;Ca=q+(h*1536|0)+832|0;Da=q+(h*1536|0)+768|0;Ea=A+(z*20|0)|0;Fa=A+(z*20|0)+4|0;Ga=A+(z*20|0)+16|0;Ha=A+(z*20|0)+8|0;Ia=A+(z*20|0)+12|0;z=f+4736|0;A=q+(h*1536|0)|0;Ja=f+4732|0;Ka=j;La=k;Ma=(r|0)!=0;Na=f+61|0;Oa=q+(h*1536|0)+836|0;Pa=f+180|0;Qa=f+99|0;Ra=Ma?5:6;Sa=Ma?0:4;Ta=Ma?2:7;Ua=Ma?2:8;Va=Ma?3:1;Wa=(r|0)==0;Xa=f+4740|0;Ya=f+4744|0;Za=l+12|0;_a=l+4|0;$a=l+3|0;ab=l+11|0;bb=l+19|0;cb=l+27|0;db=l+35|0;eb=Za;fb=l+20|0;gb=l+28|0;hb=l+36|0;l=q+(h*1536|0)+800|0;ib=f+80|0;jb=f+16|0;kb=f+4752|0;lb=f+4748|0;mb=(v|0)!=1;nb=(v-1|0)==(h|0);v=f+84|0;ob=f+20|0;pb=q+(h*1536|0)+1520|0;qb=f+100|0;rb=f+164|0;sb=f+101|0;tb=f+89|0;ub=O;O=(D|3)+16>>4;vb=f+5240|0;wb=f+63|0;xb=(H|3)+8>>3;yb=f+5276|0;zb=f+4724|0;Ab=q+(h*1536|0)+848|0;Bb=f+5312|0;f=D|8;Cb=(D|11)+8>>4;Db=H|4;Eb=(H|7)+4>>3;Fb=u;u=0;Gb=N;N=F;F=K;K=M;while(1){M=u<<2;Hb=M&12;Ib=c[E>>2]|0;Jb=N+((ca(Ib,Hb)|0)+64)|0;ef[c[P>>2]&4095](Jb,Ib,4);Ib=u&7;Jb=F+((ca(c[I>>2]|0,Ib)|0)+64)|0;ef[c[P>>2]&4095](Jb,K-F|0,2);do{if((c[C>>2]|0)==0){Jb=(c[(c[R>>2]|0)+4>>2]|0)+Fb|0;do{if(w){Kb=0}else{Lb=c[za>>2]|0;if((Lb|0)==0){Kb=0;break}Kb=(c[Lb+4>>2]|0)+Fb|0}}while(0);do{if((a[U]|0)==0){if((a[V]|0)==0){Mb=a[Jb]|0;break}else{Lb=a[(Kb|0)==0?Jb:Kb]|0;a[Jb]=Lb;Mb=Lb;break}}else{Lb=a[ya]|0;Nb=c[Z>>2]|0;Ob=d[1252840+Nb|0]|0;Pb=c[S>>2]|0;Qb=c[_>>2]|0;Rb=Nb<<Ob;c[Z>>2]=Rb;Nb=Qb<<Ob;Qb=Pb+Ob|0;do{if((Qb|0)>-1){Ob=c[$>>2]|0;if(!(Ob>>>0<(c[aa>>2]|0)>>>0)){Sb=Nb;Tb=Qb;break}c[$>>2]=Ob+2;Pb=Ob;Sb=((he((d[Pb]|d[Pb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Nb;Tb=Qb-16|0}else{Sb=Nb;Tb=Qb}}while(0);c[S>>2]=Tb;Qb=((ca(Rb-1|0,Lb&255)|0)>>8)+1|0;Nb=Qb<<16;Pb=Sb>>>0>=Nb>>>0;Ob=Pb&1;Ub=Pb?Rb-Qb|0:Qb;c[Z>>2]=Ub;Qb=Sb-(Pb?Nb:0)|0;c[_>>2]=Qb;Nb=a[(Pb?2:1)+(p+208)|0]|0;Pb=d[1252840+Ub|0]|0;Vb=Ub<<Pb;c[Z>>2]=Vb;Ub=Qb<<Pb;Qb=Pb+Tb|0;do{if((Qb|0)>-1){Pb=c[$>>2]|0;if(!(Pb>>>0<(c[aa>>2]|0)>>>0)){Wb=Ub;Xb=Qb;break}c[$>>2]=Pb+2;Yb=Pb;Wb=((he((d[Yb]|d[Yb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Ub;Xb=Qb-16|0}else{Wb=Ub;Xb=Qb}}while(0);c[S>>2]=Xb;Qb=((ca(Vb-1|0,Nb&255)|0)>>8)+1|0;Ub=Qb<<16;Rb=Wb>>>0>=Ub>>>0;c[Z>>2]=Rb?Vb-Qb|0:Qb;c[_>>2]=Wb-(Rb?Ub:0);Ub=Rb&1|Ob<<1;a[Jb]=Ub;Mb=Ub}}while(0);a[Gb+5|0]=Mb;if((a[W]|0)==0){Zb=0}else{Jb=a[xa]|0;Ub=c[Z>>2]|0;Rb=d[1252840+Ub|0]|0;Qb=c[S>>2]|0;Lb=c[_>>2]|0;Yb=Ub<<Rb;c[Z>>2]=Yb;Ub=Lb<<Rb;Lb=Qb+Rb|0;do{if((Lb|0)>-1){Rb=c[$>>2]|0;if(!(Rb>>>0<(c[aa>>2]|0)>>>0)){_b=Ub;$b=Lb;break}c[$>>2]=Rb+2;Qb=Rb;_b=((he((d[Qb]|d[Qb+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Ub;$b=Lb-16|0}else{_b=Ub;$b=Lb}}while(0);c[S>>2]=$b;Lb=((ca(Yb-1|0,Jb&255)|0)>>8)+1|0;Ub=Lb<<16;Qb=_b>>>0>=Ub>>>0;c[Z>>2]=Qb?Yb-Lb|0:Lb;c[_>>2]=_b-(Qb?Ub:0);Zb=Qb&1}a[Gb|0]=Zb;if((a[X]|0)!=0){Qb=0;Ub=c[Z>>2]|0;Lb=c[S>>2]|0;Rb=c[_>>2]|0;while(1){Pb=a[240784+Qb|0]|0;ac=d[1252840+Ub|0]|0;bc=Ub<<ac;c[Z>>2]=bc;cc=Rb<<ac;dc=ac+Lb|0;do{if((dc|0)>-1){ac=c[$>>2]|0;if(!(ac>>>0<(c[aa>>2]|0)>>>0)){ec=cc;fc=dc;break}c[$>>2]=ac+2;gc=ac;ec=((he((d[gc]|d[gc+1|0]<<8)<<16>>16|0)|0)&65535)<<dc|cc;fc=dc-16|0}else{ec=cc;fc=dc}}while(0);c[S>>2]=fc;dc=((ca(bc-1|0,Pb&255)|0)>>8)+1|0;cc=dc<<16;Ob=ec>>>0>=cc>>>0;Vb=Ob?bc-dc|0:dc;c[Z>>2]=Vb;dc=ec-(Ob?cc:0)|0;c[_>>2]=dc;cc=a[(Ob&1)+(240768+(Qb<<1))|0]|0;hc=cc<<24>>24;if(cc<<24>>24>0){Qb=hc;Ub=Vb;Lb=fc;Rb=dc}else{break}}Rb=-hc|0;a[Gb+1|0]=Rb;Lb=Rb&255;if((Lb|0)==4){Rb=c[va>>2]|0;Ub=0;Qb=Gb+6|0;while(1){Yb=p+112+Ub|0;Jb=0;dc=Qb;Vb=a[Yb]|0;while(1){cc=Vb&255;Ob=Rb+(Jb+M)|0;Nb=d[Ob]|0;gc=0;ac=c[Z>>2]|0;ic=c[S>>2]|0;jc=c[_>>2]|0;while(1){kc=a[239840+(Nb*90|0)+(cc*9|0)+gc|0]|0;lc=d[1252840+ac|0]|0;mc=ac<<lc;c[Z>>2]=mc;nc=jc<<lc;oc=lc+ic|0;do{if((oc|0)>-1){lc=c[$>>2]|0;if(!(lc>>>0<(c[aa>>2]|0)>>>0)){pc=nc;qc=oc;break}c[$>>2]=lc+2;rc=lc;pc=((he((d[rc]|d[rc+1|0]<<8)<<16>>16|0)|0)&65535)<<oc|nc;qc=oc-16|0}else{pc=nc;qc=oc}}while(0);c[S>>2]=qc;oc=((ca(mc-1|0,kc&255)|0)>>8)+1|0;nc=oc<<16;rc=pc>>>0>=nc>>>0;lc=rc?mc-oc|0:oc;c[Z>>2]=lc;oc=pc-(rc?nc:0)|0;c[_>>2]=oc;sc=a[(rc&1)+(239816+(gc<<1))|0]|0;if(sc<<24>>24>0){gc=sc<<24>>24;ac=lc;ic=qc;jc=oc}else{break}}jc=-sc&255;a[dc]=jc;a[Ob]=jc;a[Yb]=jc;ic=Jb+1|0;if((ic|0)<4){Jb=ic;dc=dc+1|0;Vb=jc}else{break}}Vb=Ub+1|0;if((Vb|0)<4){Ub=Vb;Qb=Qb+4|0}else{break}}}else{Qb=ca(d[240760+Lb|0]|0,16843009)|0;if((c[C>>2]|0)==0){c[(c[va>>2]|0)+M>>2]=Qb}else{c[Gb+22>>2]=Qb}c[wa>>2]=Qb}Qb=0;Ub=c[Z>>2]|0;Rb=c[S>>2]|0;Vb=c[_>>2]|0;while(1){dc=a[239800+Qb|0]|0;Jb=d[1252840+Ub|0]|0;Yb=Ub<<Jb;c[Z>>2]=Yb;bc=Vb<<Jb;Pb=Jb+Rb|0;do{if((Pb|0)>-1){Jb=c[$>>2]|0;if(!(Jb>>>0<(c[aa>>2]|0)>>>0)){tc=bc;uc=Pb;break}c[$>>2]=Jb+2;jc=Jb;tc=((he((d[jc]|d[jc+1|0]<<8)<<16>>16|0)|0)&65535)<<Pb|bc;uc=Pb-16|0}else{tc=bc;uc=Pb}}while(0);c[S>>2]=uc;Pb=((ca(Yb-1|0,dc&255)|0)>>8)+1|0;bc=Pb<<16;jc=tc>>>0>=bc>>>0;Jb=jc?Yb-Pb|0:Pb;c[Z>>2]=Jb;Pb=tc-(jc?bc:0)|0;c[_>>2]=Pb;vc=a[(jc&1)+(239792+(Qb<<1))|0]|0;if(vc<<24>>24>0){Qb=vc<<24>>24;Ub=Jb;Rb=uc;Vb=Pb}else{break}}a[Gb+4|0]=-vc;a[Gb+2|0]=0;break}Vb=d[Y]|0;Rb=c[Z>>2]|0;Ub=d[1252840+Rb|0]|0;Qb=c[S>>2]|0;Lb=c[_>>2]|0;Pb=Rb<<Ub;c[Z>>2]=Pb;Rb=Lb<<Ub;Lb=Qb+Ub|0;do{if((Lb|0)>-1){Ub=c[$>>2]|0;if(!(Ub>>>0<(c[aa>>2]|0)>>>0)){wc=Rb;xc=Lb;break}c[$>>2]=Ub+2;Qb=Ub;wc=((he((d[Qb]|d[Qb+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Rb;xc=Lb-16|0}else{wc=Rb;xc=Lb}}while(0);c[S>>2]=xc;Lb=((ca(Pb-1|0,Vb)|0)>>8)+1|0;Rb=Lb<<16;if(wc>>>0<Rb>>>0){c[Z>>2]=Lb;c[_>>2]=wc;Qb=0;Ub=Lb;Jb=xc;jc=wc;while(1){bc=a[p+215+Qb|0]|0;ic=d[1252840+Ub|0]|0;ac=Ub<<ic;c[Z>>2]=ac;gc=jc<<ic;cc=ic+Jb|0;do{if((cc|0)>-1){ic=c[$>>2]|0;if(!(ic>>>0<(c[aa>>2]|0)>>>0)){yc=gc;zc=cc;break}c[$>>2]=ic+2;Nb=ic;yc=((he((d[Nb]|d[Nb+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|gc;zc=cc-16|0}else{yc=gc;zc=cc}}while(0);c[S>>2]=zc;cc=((ca(ac-1|0,bc&255)|0)>>8)+1|0;gc=cc<<16;Yb=yc>>>0>=gc>>>0;dc=Yb?ac-cc|0:cc;c[Z>>2]=dc;cc=yc-(Yb?gc:0)|0;c[_>>2]=cc;gc=a[(Yb&1)+(240776+(Qb<<1))|0]|0;Ac=gc<<24>>24;if(gc<<24>>24>0){Qb=Ac;Ub=dc;Jb=zc;jc=cc}else{break}}jc=-Ac|0;a[Gb+1|0]=jc;if((jc&255|0)==4){jc=0;do{Jb=0;Ub=c[Z>>2]|0;Qb=c[S>>2]|0;Vb=c[_>>2]|0;while(1){cc=a[240744+Jb|0]|0;dc=d[1252840+Ub|0]|0;gc=Ub<<dc;c[Z>>2]=gc;Yb=Vb<<dc;Nb=dc+Qb|0;do{if((Nb|0)>-1){dc=c[$>>2]|0;if(!(dc>>>0<(c[aa>>2]|0)>>>0)){Bc=Yb;Cc=Nb;break}c[$>>2]=dc+2;ic=dc;Bc=((he((d[ic]|d[ic+1|0]<<8)<<16>>16|0)|0)&65535)<<Nb|Yb;Cc=Nb-16|0}else{Bc=Yb;Cc=Nb}}while(0);c[S>>2]=Cc;Nb=((ca(gc-1|0,cc&255)|0)>>8)+1|0;Yb=Nb<<16;Ob=Bc>>>0>=Yb>>>0;ic=Ob?gc-Nb|0:Nb;c[Z>>2]=ic;Nb=Bc-(Ob?Yb:0)|0;c[_>>2]=Nb;Dc=a[(Ob&1)+(239816+(Jb<<1))|0]|0;if(Dc<<24>>24>0){Jb=Dc<<24>>24;Ub=ic;Qb=Cc;Vb=Nb}else{break}}a[Gb+6+jc|0]=-Dc;jc=jc+1|0;}while((jc|0)<16)}jc=0;Vb=c[Z>>2]|0;Qb=c[S>>2]|0;Ub=c[_>>2]|0;while(1){Jb=a[p+219+jc|0]|0;ac=d[1252840+Vb|0]|0;bc=Vb<<ac;c[Z>>2]=bc;Nb=Ub<<ac;ic=ac+Qb|0;do{if((ic|0)>-1){ac=c[$>>2]|0;if(!(ac>>>0<(c[aa>>2]|0)>>>0)){Ec=Nb;Fc=ic;break}c[$>>2]=ac+2;Ob=ac;Ec=((he((d[Ob]|d[Ob+1|0]<<8)<<16>>16|0)|0)&65535)<<ic|Nb;Fc=ic-16|0}else{Ec=Nb;Fc=ic}}while(0);c[S>>2]=Fc;ic=((ca(bc-1|0,Jb&255)|0)>>8)+1|0;Nb=ic<<16;Ob=Ec>>>0>=Nb>>>0;ac=Ob?bc-ic|0:ic;c[Z>>2]=ac;ic=Ec-(Ob?Nb:0)|0;c[_>>2]=ic;Gc=a[(Ob&1)+(239792+(jc<<1))|0]|0;if(Gc<<24>>24>0){jc=Gc<<24>>24;Vb=ac;Qb=Fc;Ub=ic}else{break}}a[Gb+4|0]=-Gc;a[Gb+2|0]=0;a[Gb+3|0]=4;c[Gb+32>>2]=0;break}Ub=Pb-Lb|0;Qb=wc-Rb|0;c[_>>2]=Qb;Vb=d[ba]|0;jc=d[1252840+Ub|0]|0;ic=Ub<<jc;c[Z>>2]=ic;Ub=Qb<<jc;Qb=jc+xc|0;do{if((Qb|0)>-1){jc=c[$>>2]|0;if(!(jc>>>0<(c[aa>>2]|0)>>>0)){Hc=Ub;Ic=Qb;break}c[$>>2]=jc+2;ac=jc;Hc=((he((d[ac]|d[ac+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Ub;Ic=Qb-16|0}else{Hc=Ub;Ic=Qb}}while(0);c[S>>2]=Ic;Qb=((ca(ic-1|0,Vb)|0)>>8)+1|0;Ub=Qb<<16;if(Hc>>>0<Ub>>>0){c[Z>>2]=Qb;c[_>>2]=Hc;a[Gb+2|0]=1;Jc=0}else{Rb=ic-Qb|0;Qb=Hc-Ub|0;c[_>>2]=Qb;Ub=a[m]|0;Lb=d[1252840+Rb|0]|0;Pb=Rb<<Lb;c[Z>>2]=Pb;Rb=Qb<<Lb;Qb=Lb+Ic|0;do{if((Qb|0)>-1){Lb=c[$>>2]|0;if(!(Lb>>>0<(c[aa>>2]|0)>>>0)){Kc=Rb;Lc=Qb;break}c[$>>2]=Lb+2;ac=Lb;Kc=((he((d[ac]|d[ac+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Rb;Lc=Qb-16|0}else{Kc=Rb;Lc=Qb}}while(0);c[S>>2]=Lc;Qb=((ca(Pb-1|0,Ub&255)|0)>>8)+1|0;Rb=Qb<<16;ic=Kc>>>0>=Rb>>>0;c[Z>>2]=ic?Pb-Qb|0:Qb;c[_>>2]=Kc-(ic?Rb:0);Rb=ic?3:2;a[Gb+2|0]=Rb;Jc=(Rb&255)-1|0}Rb=p+76+(Jc<<2)|0;c[Rb>>2]=(c[Rb>>2]|0)+1;Rb=a[(d[Gb+2|0]|0)+(p+72)|0]|0;c[n>>2]=0;c[ga>>2]=0;c[ia>>2]=0;c[ka>>2]=0;ic=a[Gb+194|0]|0;Qb=ic&255;do{if(ic<<24>>24==0){Mc=0;Nc=2}else{Vb=c[Gb+220>>2]|0;if((Vb|0)==0){a[da]=2;Mc=0;Nc=4;break}if(Rb<<24>>24==(a[p+72+Qb|0]|0)){Oc=Vb}else{ac=~Vb;Oc=(ac&2147450879)+65537^ac&-2147450880}c[ia>>2]=Oc;a[na]=2;Mc=1;Nc=2}}while(0);Qb=a[Gb-96+2|0]|0;ic=Qb&255;do{if(Qb<<24>>24==0){Pc=Mc}else{Pb=c[Gb-96+28>>2]|0;if((Pb|0)==0){a[da]=Nc;Pc=Mc;break}if(Rb<<24>>24==(a[p+72+ic|0]|0)){Qc=Pb}else{Ub=~Pb;Qc=(Ub&2147450879)+65537^Ub&-2147450880}if((Qc|0)==(c[ea+(Mc<<2)>>2]|0)){Rc=Mc}else{Ub=Mc+1|0;c[ea+(Ub<<2)>>2]=Qc;Rc=Ub}Ub=fa+Rc|0;a[Ub]=(a[Ub]|0)+2;Pc=Rc}}while(0);ic=a[Gb+98|0]|0;Qb=ic&255;do{if(!(ic<<24>>24==0)){Ub=c[Gb+124>>2]|0;if((Ub|0)==0){a[da]=(a[da]|0)+1;break}if(Rb<<24>>24==(a[p+72+Qb|0]|0)){Sc=Ub}else{Pb=~Ub;Sc=(Pb&2147450879)+65537^Pb&-2147450880}if((Sc|0)==(c[ea+(Pc<<2)>>2]|0)){Tc=Pc}else{Pb=Pc+1|0;c[ea+(Pb<<2)>>2]=Sc;Tc=Pb}Pb=fa+Tc|0;a[Pb]=(a[Pb]|0)+1}}while(0);Qb=Gb+3|0;a[Qb]=4;Rb=a[da]|0;ic=c[242672+((Rb&255)<<4)>>2]|0;Pb=c[Z>>2]|0;Ub=d[1252840+Pb|0]|0;ac=c[S>>2]|0;Vb=c[_>>2]|0;Lb=Pb<<Ub;c[Z>>2]=Lb;Pb=Vb<<Ub;Vb=ac+Ub|0;do{if((Vb|0)>-1){Ub=c[$>>2]|0;if(!(Ub>>>0<(c[aa>>2]|0)>>>0)){Uc=Pb;Vc=Vb;break}c[$>>2]=Ub+2;ac=Ub;Uc=((he((d[ac]|d[ac+1|0]<<8)<<16>>16|0)|0)&65535)<<Vb|Pb;Vc=Vb-16|0}else{Uc=Pb;Vc=Vb}}while(0);c[S>>2]=Vc;Vb=((ca(Lb-1|0,ic)|0)>>8)+1|0;Pb=Vb<<16;if(Uc>>>0<Pb>>>0){c[Z>>2]=Vb;c[_>>2]=Uc;a[Gb+1|0]=5;c[Gb+28>>2]=0;c[Gb+32>>2]=0;break}c[Z>>2]=Lb-Vb;c[_>>2]=Uc-Pb;Pb=Gb+1|0;a[Pb]=6;do{if((a[la]|0)!=0){if((c[ia>>2]|0)!=(c[ua>>2]|0)){break}a[na]=(a[na]|0)+1}}while(0);Lb=a[ma]|0;ic=a[na]|0;if((Lb&255)>>>0>(ic&255)>>>0){a[ma]=ic;a[na]=Lb;Vb=c[ka>>2]|0;c[ka>>2]=c[ia>>2];c[ia>>2]=Vb;Wc=Lb;Xc=ic}else{Wc=ic;Xc=Lb}Lb=c[242676+((Wc&255)<<4)>>2]|0;ic=c[Z>>2]|0;Vb=d[1252840+ic|0]|0;ac=c[S>>2]|0;Ub=c[_>>2]|0;jc=ic<<Vb;c[Z>>2]=jc;ic=Ub<<Vb;Ub=ac+Vb|0;do{if((Ub|0)>-1){Vb=c[$>>2]|0;if(!(Vb>>>0<(c[aa>>2]|0)>>>0)){Yc=ic;Zc=Ub;break}c[$>>2]=Vb+2;ac=Vb;Yc=((he((d[ac]|d[ac+1|0]<<8)<<16>>16|0)|0)&65535)<<Ub|ic;Zc=Ub-16|0}else{Yc=ic;Zc=Ub}}while(0);c[S>>2]=Zc;Ub=((ca(jc-1|0,Lb)|0)>>8)+1|0;ic=Ub<<16;if(Yc>>>0<ic>>>0){c[Z>>2]=Ub;c[_>>2]=Yc;ac=Gb+28|0;Vb=b[oa>>1]|0;Ob=b[t>>1]|0;Nb=b[Q>>1]|0;if(Vb<<16>>16<Ob<<16>>16){_c=Ob}else{_c=Vb<<16>>16>Nb<<16>>16?Nb:Vb}b[ac>>1]=_c;Vb=b[pa>>1]|0;Nb=b[ha>>1]|0;Ob=b[qa>>1]|0;if(Vb<<16>>16<Nb<<16>>16){$c=Nb}else{$c=Vb<<16>>16>Ob<<16>>16?Ob:Vb}b[Gb+30>>1]=$c;c[Gb+32>>2]=c[ac>>2];break}ac=jc-Ub|0;Ub=Yc-ic|0;c[_>>2]=Ub;ic=c[242680+((Xc&255)<<4)>>2]|0;Vb=d[1252840+ac|0]|0;Ob=ac<<Vb;c[Z>>2]=Ob;ac=Ub<<Vb;Ub=Vb+Zc|0;do{if((Ub|0)>-1){Vb=c[$>>2]|0;if(!(Vb>>>0<(c[aa>>2]|0)>>>0)){ad=ac;bd=Ub;break}c[$>>2]=Vb+2;Nb=Vb;ad=((he((d[Nb]|d[Nb+1|0]<<8)<<16>>16|0)|0)&65535)<<Ub|ac;bd=Ub-16|0}else{ad=ac;bd=Ub}}while(0);c[S>>2]=bd;Ub=((ca(Ob-1|0,ic)|0)>>8)+1|0;ac=Ub<<16;if(ad>>>0<ac>>>0){c[Z>>2]=Ub;c[_>>2]=ad;jc=Gb+28|0;Lb=b[ra>>1]|0;Nb=b[t>>1]|0;Vb=b[Q>>1]|0;if(Lb<<16>>16<Nb<<16>>16){cd=Nb}else{cd=Lb<<16>>16>Vb<<16>>16?Vb:Lb}b[jc>>1]=cd;Lb=b[sa>>1]|0;Vb=b[ha>>1]|0;Nb=b[qa>>1]|0;if(Lb<<16>>16<Vb<<16>>16){dd=Vb}else{dd=Lb<<16>>16>Nb<<16>>16?Nb:Lb}b[Gb+30>>1]=dd;c[Gb+32>>2]=c[jc>>2];break}jc=Ob-Ub|0;c[Z>>2]=jc;Ub=ad-ac|0;c[_>>2]=Ub;ac=Gb+28|0;Lb=(Wc&255)>>>0>=(Rb&255)>>>0|0;Nb=b[ea+(Lb<<2)>>1]|0;Vb=b[t>>1]|0;Yb=b[Q>>1]|0;if(Nb<<16>>16<Vb<<16>>16){ed=Vb}else{ed=Nb<<16>>16>Yb<<16>>16?Yb:Nb}Nb=ac|0;b[Nb>>1]=ed;Yb=b[ea+(Lb<<2)+2>>1]|0;Lb=b[ha>>1]|0;Vb=b[qa>>1]|0;if(Yb<<16>>16<Lb<<16>>16){fd=Lb}else{fd=Yb<<16>>16>Vb<<16>>16?Vb:Yb}Yb=Gb+30|0;b[Yb>>1]=fd;Vb=(((a[Gb+193|0]|0)==7)+((a[Gb-96+1|0]|0)==7)&255)<<1|(a[Gb+97|0]|0)==7;a[la]=Vb;Lb=c[242684+((Vb&255)<<4)>>2]|0;Vb=d[1252840+jc|0]|0;dc=jc<<Vb;c[Z>>2]=dc;jc=Ub<<Vb;Ub=Vb+bd|0;do{if((Ub|0)>-1){Vb=c[$>>2]|0;if(!(Vb>>>0<(c[aa>>2]|0)>>>0)){gd=jc;hd=Ub;break}c[$>>2]=Vb+2;oc=Vb;gd=((he((d[oc]|d[oc+1|0]<<8)<<16>>16|0)|0)&65535)<<Ub|jc;hd=Ub-16|0}else{gd=jc;hd=Ub}}while(0);c[S>>2]=hd;Ub=((ca(dc-1|0,Lb)|0)>>8)+1|0;jc=Ub<<16;if(gd>>>0<jc>>>0){c[Z>>2]=Ub;c[_>>2]=gd;Rb=oab(T,ja)|0;b[Yb>>1]=(e[Yb>>1]|0)+Rb;Rb=oab(T,ta)|0;b[Nb>>1]=(e[Nb>>1]|0)+Rb;c[Gb+32>>2]=c[ac>>2];break}c[Z>>2]=dc-Ub;c[_>>2]=gd-jc;a[Pb]=7;jc=d[Gb-96+3|0]|0;Ub=d[Gb+195|0]|0;Rb=c[Z>>2]|0;Ob=d[1252840+Rb|0]|0;ic=c[S>>2]|0;oc=c[_>>2]|0;Vb=Rb<<Ob;c[Z>>2]=Vb;Rb=oc<<Ob;oc=ic+Ob|0;do{if((oc|0)>-1){Ob=c[$>>2]|0;if(!(Ob>>>0<(c[aa>>2]|0)>>>0)){id=Rb;jd=oc;break}c[$>>2]=Ob+2;ic=Ob;id=((he((d[ic]|d[ic+1|0]<<8)<<16>>16|0)|0)&65535)<<oc|Rb;jd=oc-16|0}else{id=Rb;jd=oc}}while(0);c[S>>2]=jd;oc=((Vb*110|0)-110>>8)+1|0;Rb=oc<<16;do{if(id>>>0<Rb>>>0){c[Z>>2]=oc;c[_>>2]=id;kd=3}else{Pb=Vb-oc|0;dc=id-Rb|0;c[_>>2]=dc;Nb=d[1252840+Pb|0]|0;Lb=Pb<<Nb;c[Z>>2]=Lb;Pb=dc<<Nb;dc=Nb+jd|0;do{if((dc|0)>-1){Nb=c[$>>2]|0;if(!(Nb>>>0<(c[aa>>2]|0)>>>0)){ld=Pb;md=dc;break}c[$>>2]=Nb+2;ic=Nb;ld=((he((d[ic]|d[ic+1|0]<<8)<<16>>16|0)|0)&65535)<<dc|Pb;md=dc-16|0}else{ld=Pb;md=dc}}while(0);c[S>>2]=md;dc=((Lb*111|0)-111>>8)+1|0;Pb=dc<<16;if(ld>>>0<Pb>>>0){c[Z>>2]=dc;c[_>>2]=ld;kd=2;break}bc=Lb-dc|0;dc=ld-Pb|0;c[_>>2]=dc;Pb=d[1252840+bc|0]|0;Jb=bc<<Pb;c[Z>>2]=Jb;bc=dc<<Pb;dc=Pb+md|0;do{if((dc|0)>-1){Pb=c[$>>2]|0;if(!(Pb>>>0<(c[aa>>2]|0)>>>0)){nd=bc;od=dc;break}c[$>>2]=Pb+2;ic=Pb;nd=((he((d[ic]|d[ic+1|0]<<8)<<16>>16|0)|0)&65535)<<dc|bc;od=dc-16|0}else{nd=bc;od=dc}}while(0);c[S>>2]=od;dc=((Jb*150|0)-150>>8)+1|0;bc=dc<<16;Lb=nd>>>0>=bc>>>0;c[Z>>2]=Lb?Jb-dc|0:dc;c[_>>2]=nd-(Lb?bc:0);kd=Lb&1}}while(0);Rb=d[243216+kd|0]|0;a[Qb]=kd;oc=Gb+28|0;Vb=0;do{Lb=a[243240+(kd<<4)+Vb|0]|0;bc=Lb&255;if((bc&3|0)==0){pd=Gb-96+32+(d[bc+3+(242768+(jc<<4))|0]<<2)|0}else{pd=Gb+32+(d[bc-1+(242768+(kd<<4))|0]<<2)|0}dc=c[pd>>2]|0;if((Lb&255)>>>0<4>>>0){qd=Gb+224+(d[bc+12+(242768+(Ub<<4))|0]<<2)|0}else{qd=Gb+32+(d[bc-4+(242768+(kd<<4))|0]<<2)|0}bc=c[qd>>2]|0;do{if((dc|0)==(bc|0)){rd=238344+((4-((dc|0)!=0)|0)*3|0)|0}else{if((bc|0)==0){rd=238350;break}rd=238344+(((dc|0)==0|0)*3|0)|0}}while(0);Jb=d[rd]|0;Lb=c[Z>>2]|0;ic=d[1252840+Lb|0]|0;Pb=c[S>>2]|0;Nb=c[_>>2]|0;Ob=Lb<<ic;c[Z>>2]=Ob;Lb=Nb<<ic;Nb=Pb+ic|0;do{if((Nb|0)>-1){ic=c[$>>2]|0;if(!(ic>>>0<(c[aa>>2]|0)>>>0)){sd=Lb;td=Nb;break}c[$>>2]=ic+2;Pb=ic;sd=((he((d[Pb]|d[Pb+1|0]<<8)<<16>>16|0)|0)&65535)<<Nb|Lb;td=Nb-16|0}else{sd=Lb;td=Nb}}while(0);c[S>>2]=td;Nb=((ca(Ob-1|0,Jb)|0)>>8)+1|0;Lb=Nb<<16;do{if(sd>>>0<Lb>>>0){c[Z>>2]=Nb;c[_>>2]=sd;c[Gb+32+(Vb<<2)>>2]=dc}else{Pb=Ob-Nb|0;c[Z>>2]=Pb;ic=sd-Lb|0;c[_>>2]=ic;lc=d[rd+1|0]|0;rc=d[1252840+Pb|0]|0;nc=Pb<<rc;c[Z>>2]=nc;Pb=ic<<rc;ic=rc+td|0;do{if((ic|0)>-1){rc=c[$>>2]|0;if(!(rc>>>0<(c[aa>>2]|0)>>>0)){ud=Pb;vd=ic;break}c[$>>2]=rc+2;wd=rc;ud=((he((d[wd]|d[wd+1|0]<<8)<<16>>16|0)|0)&65535)<<ic|Pb;vd=ic-16|0}else{ud=Pb;vd=ic}}while(0);c[S>>2]=vd;ic=((ca(nc-1|0,lc)|0)>>8)+1|0;Pb=ic<<16;if(ud>>>0<Pb>>>0){c[Z>>2]=ic;c[_>>2]=ud;c[Gb+32+(Vb<<2)>>2]=bc;break}gc=nc-ic|0;c[Z>>2]=gc;ic=ud-Pb|0;c[_>>2]=ic;Pb=d[rd+2|0]|0;cc=d[1252840+gc|0]|0;wd=gc<<cc;c[Z>>2]=wd;gc=ic<<cc;ic=cc+vd|0;do{if((ic|0)>-1){cc=c[$>>2]|0;if(!(cc>>>0<(c[aa>>2]|0)>>>0)){xd=gc;yd=ic;break}c[$>>2]=cc+2;rc=cc;xd=((he((d[rc]|d[rc+1|0]<<8)<<16>>16|0)|0)&65535)<<ic|gc;yd=ic-16|0}else{xd=gc;yd=ic}}while(0);c[S>>2]=yd;ic=((ca(wd-1|0,Pb)|0)>>8)+1|0;gc=ic<<16;if(xd>>>0<gc>>>0){c[Z>>2]=ic;c[_>>2]=xd;c[Gb+32+(Vb<<2)>>2]=0;break}else{c[Z>>2]=wd-ic;c[_>>2]=xd-gc;gc=e[Yb>>1]|0;b[Gb+32+(Vb<<2)+2>>1]=gc+(oab(T,ja)|0);gc=e[oc>>1]|0;b[Gb+32+(Vb<<2)>>1]=gc+(oab(T,ta)|0);break}}}while(0);Vb=Vb+1|0;}while((Vb|0)<(Rb|0));c[ac>>2]=c[Gb+32+(Rb-1<<2)>>2]}}while(0);M=Fb>>5;if((c[x>>2]|0)>(M|0)){Vb=(b[Gb+28>>1]>>2)+(u<<4|8)|0;oc=(b[Gb+30>>1]>>2)+D|0;Yb=c[c[Aa>>2]>>2]|0;Ub=c[E>>2]|0;jc=Vb+64+(ca(oc+Hb|0,Ub)|0)|0;ef[c[P>>2]&4095]((c[Yb>>2]|0)+jc|0,Ub,4);Ub=(Vb>>1)+64+(ca(c[I>>2]|0,(oc>>1)+Ib|0)|0)|0;oc=c[Yb+4>>2]|0;ef[c[P>>2]&4095](oc+Ub|0,(c[Yb+8>>2]|0)-oc|0,2)}oc=Gb|0;do{if((a[oc]|0)==0){Yb=c[Ba>>2]|0;Ub=d[Gb+5|0]|0;Vb=Gb+1|0;jc=a[Vb]|0;do{if((jc<<24>>24|0)==4|(jc<<24>>24|0)==7){zd=0;Ad=0;Bd=3;Cd=0}else{Qb=Yb+(u*9|0)+8|0;bc=p+750+(((d[Ca]|0)+(d[Qb]|0)|0)*11|0)|0;Lb=d[bc]|0;Nb=c[Ea>>2]|0;Ob=d[1252840+Nb|0]|0;dc=c[Fa>>2]|0;Jb=c[Ga>>2]|0;gc=Nb<<Ob;c[Ea>>2]=gc;Nb=Jb<<Ob;Jb=dc+Ob|0;do{if((Jb|0)>-1){Ob=c[Ha>>2]|0;if(!(Ob>>>0<(c[Ia>>2]|0)>>>0)){Dd=Nb;Ed=Jb;break}c[Ha>>2]=Ob+2;dc=Ob;Dd=((he((d[dc]|d[dc+1|0]<<8)<<16>>16|0)|0)&65535)<<Jb|Nb;Ed=Jb-16|0}else{Dd=Nb;Ed=Jb}}while(0);c[Fa>>2]=Ed;Jb=((ca(gc-1|0,Lb)|0)>>8)+1|0;Nb=Jb<<16;if(Dd>>>0<Nb>>>0){c[Ea>>2]=Jb;c[Ga>>2]=Dd;a[Qb]=0;a[Ca]=0;zd=0;Ad=0;Bd=0;Cd=1;break}dc=gc-Jb|0;c[Ea>>2]=dc;Jb=Dd-Nb|0;c[Ga>>2]=Jb;Nb=c[Ia>>2]|0;Ob=0;ic=bc;nc=dc;dc=Ed;lc=c[Ha>>2]|0;rc=Jb;while(1){Jb=d[ic+1|0]|0;cc=d[1252840+nc|0]|0;Fd=nc<<cc;Gd=rc<<cc;Hd=cc+dc|0;if((Hd|0)>-1&lc>>>0<Nb>>>0){cc=lc;Id=((he((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Gd;Jd=Hd-16|0;Kd=lc+2|0}else{Id=Gd;Jd=Hd;Kd=lc}Hd=((ca(Fd-1|0,Jb)|0)>>8)+1|0;Jb=Hd<<16;if(Id>>>0<Jb>>>0){Gd=Ob+1|0;if((Gd|0)==16){Ld=16;Md=Hd;Nd=Jd;Od=Kd;Pd=Id;break}Ob=Gd;ic=p+750+(Gd*33|0)|0;nc=Hd;dc=Jd;lc=Kd;rc=Id;continue}Gd=Fd-Hd|0;Hd=d[ic+2|0]|0;Fd=d[1252840+Gd|0]|0;cc=Gd<<Fd;Gd=Id-Jb<<Fd;Jb=Fd+Jd|0;if((Jb|0)>-1&Kd>>>0<Nb>>>0){Fd=Kd;Qd=((he((d[Fd]|d[Fd+1|0]<<8)<<16>>16|0)|0)&65535)<<Jb|Gd;Rd=Jb-16|0;Sd=Kd+2|0}else{Qd=Gd;Rd=Jb;Sd=Kd}Jb=((ca(cc-1|0,Hd)|0)>>8)+1|0;Hd=Jb<<16;if(Qd>>>0<Hd>>>0){Td=p+750+((Ob+1|0)*33|0)+11|0;Ud=1;Vd=Jb;Wd=Rd;Xd=Sd;Yd=Qd}else{Gd=cc-Jb|0;Jb=d[ic+3|0]|0;cc=d[1252840+Gd|0]|0;Fd=Gd<<cc;Gd=Qd-Hd<<cc;Hd=cc+Rd|0;if((Hd|0)>-1&Sd>>>0<Nb>>>0){cc=Sd;Zd=((he((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Gd;_d=Hd-16|0;$d=Sd+2|0}else{Zd=Gd;_d=Hd;$d=Sd}Hd=((ca(Fd-1|0,Jb)|0)>>8)+1|0;Jb=Hd<<16;do{if(Zd>>>0<Jb>>>0){Gd=d[ic+4|0]|0;cc=d[1252840+Hd|0]|0;ae=Hd<<cc;be=Zd<<cc;ce=cc+_d|0;if((ce|0)>-1&$d>>>0<Nb>>>0){cc=$d;de=((he((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<ce|be;ee=ce-16|0;fe=$d+2|0}else{de=be;ee=ce;fe=$d}ce=((ca(ae-1|0,Gd)|0)>>8)+1|0;Gd=ce<<16;if(de>>>0<Gd>>>0){ge=2;ie=ce;je=ee;ke=fe;le=de;break}be=ae-ce|0;ce=a[ic+5|0]|0;ae=d[1252840+be|0]|0;cc=be<<ae;be=de-Gd<<ae;Gd=ae+ee|0;if((Gd|0)>-1&fe>>>0<Nb>>>0){ae=fe;me=((he((d[ae]|d[ae+1|0]<<8)<<16>>16|0)|0)&65535)<<Gd|be;ne=Gd-16|0;oe=fe+2|0}else{me=be;ne=Gd;oe=fe}Gd=((ca(cc-1|0,ce&255)|0)>>8)+1|0;ce=Gd<<16;be=me>>>0>=ce>>>0;ge=be?4:3;ie=be?cc-Gd|0:Gd;je=ne;ke=oe;le=me-(be?ce:0)|0}else{ce=Fd-Hd|0;be=d[ic+6|0]|0;Gd=d[1252840+ce|0]|0;cc=ce<<Gd;ce=Zd-Jb<<Gd;ae=Gd+_d|0;if((ae|0)>-1&$d>>>0<Nb>>>0){Gd=$d;pe=((he((d[Gd]|d[Gd+1|0]<<8)<<16>>16|0)|0)&65535)<<ae|ce;qe=ae-16|0;se=$d+2|0}else{pe=ce;qe=ae;se=$d}ae=((ca(cc-1|0,be)|0)>>8)+1|0;be=ae<<16;if(!(pe>>>0<be>>>0)){ce=cc-ae|0;cc=a[ic+8|0]|0;Gd=d[1252840+ce|0]|0;te=ce<<Gd;ce=pe-be<<Gd;be=Gd+qe|0;if((be|0)>-1&se>>>0<Nb>>>0){Gd=se;ue=((he((d[Gd]|d[Gd+1|0]<<8)<<16>>16|0)|0)&65535)<<be|ce;ve=be-16|0;we=se+2|0}else{ue=ce;ve=be;we=se}be=((ca(te-1|0,cc&255)|0)>>8)+1|0;cc=be<<16;ce=ue>>>0>=cc>>>0;Gd=ce?te-be|0:be;be=a[ic+(ce?10:9)|0]|0;te=d[1252840+Gd|0]|0;xe=Gd<<te;Gd=ue-(ce?cc:0)<<te;cc=te+ve|0;if((cc|0)>-1&we>>>0<Nb>>>0){te=we;ye=((he((d[te]|d[te+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|Gd;ze=cc-16|0;Ae=we+2|0}else{ye=Gd;ze=cc;Ae=we}cc=((ca(xe-1|0,be&255)|0)>>8)+1|0;be=cc<<16;Gd=ye>>>0>=be>>>0;te=Gd&1|(ce&1)<<1;ce=c[1251240+(te<<2)>>2]|0;Be=0;Ce=ce;De=a[ce]|0;ce=Gd?xe-cc|0:cc;cc=ze;xe=ye-(Gd?be:0)|0;be=Ae;while(1){Gd=Ce+1|0;Ee=d[1252840+ce|0]|0;Fe=ce<<Ee;Ge=xe<<Ee;He=Ee+cc|0;if((He|0)>-1&be>>>0<Nb>>>0){Ee=be;Ie=((he((d[Ee]|d[Ee+1|0]<<8)<<16>>16|0)|0)&65535)<<He|Ge;Je=He-16|0;Ke=be+2|0}else{Ie=Ge;Je=He;Ke=be}He=((ca(Fe-1|0,De&255)|0)>>8)+1|0;Ge=He<<16;Ee=Ie>>>0>=Ge>>>0;Le=Ee?Fe-He|0:He;Me=Ie-(Ee?Ge:0)|0;Ne=Ee&1|Be<<1;Ee=a[Gd]|0;if(Ee<<24>>24==0){break}else{Be=Ne;Ce=Gd;De=Ee;ce=Le;cc=Je;xe=Me;be=Ke}}ge=(8<<te)+3+Ne|0;ie=Le;je=Je;ke=Ke;le=Me;break}be=d[ic+7|0]|0;xe=d[1252840+ae|0]|0;cc=ae<<xe;ce=pe<<xe;De=xe+qe|0;if((De|0)>-1&se>>>0<Nb>>>0){xe=se;Oe=((he((d[xe]|d[xe+1|0]<<8)<<16>>16|0)|0)&65535)<<De|ce;Pe=De-16|0;Qe=se+2|0}else{Oe=ce;Pe=De;Qe=se}De=((ca(cc-1|0,be)|0)>>8)+1|0;be=De<<16;if(Oe>>>0<be>>>0){ce=d[1252840+De|0]|0;xe=De<<ce;Ce=Oe<<ce;Be=ce+Pe|0;if((Be|0)>-1&Qe>>>0<Nb>>>0){ce=Qe;Re=((he((d[ce]|d[ce+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|Ce;Te=Be-16|0;Ue=Qe+2|0}else{Re=Ce;Te=Be;Ue=Qe}Be=((xe*159|0)-159>>8)+1|0;Ce=Be<<16;ce=Re>>>0>=Ce>>>0;ge=ce?6:5;ie=ce?xe-Be|0:Be;je=Te;ke=Ue;le=Re-(ce?Ce:0)|0;break}Ce=cc-De|0;De=d[1252840+Ce|0]|0;cc=Ce<<De;Ce=Oe-be<<De;be=De+Pe|0;if((be|0)>-1&Qe>>>0<Nb>>>0){De=Qe;We=((he((d[De]|d[De+1|0]<<8)<<16>>16|0)|0)&65535)<<be|Ce;Xe=be-16|0;Ye=Qe+2|0}else{We=Ce;Xe=be;Ye=Qe}be=((cc*165|0)-165>>8)+1|0;Ce=be<<16;De=We>>>0>=Ce>>>0;ce=De?cc-be|0:be;be=d[1252840+ce|0]|0;cc=ce<<be;ce=We-(De?Ce:0)<<be;Ce=be+Xe|0;if((Ce|0)>-1&Ye>>>0<Nb>>>0){be=Ye;Ze=((he((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Ce|ce;_e=Ce-16|0;$e=Ye+2|0}else{Ze=ce;_e=Ce;$e=Ye}Ce=((cc*145|0)-145>>8)+1|0;ce=Ce<<16;be=Ze>>>0>=ce>>>0;ge=((De&1)<<1)+7+(be&1)|0;ie=be?cc-Ce|0:Ce;je=_e;ke=$e;le=Ze-(be?ce:0)|0}}while(0);Td=p+750+((Ob+1|0)*33|0)+22|0;Ud=ge;Vd=ie;Wd=je;Xd=ke;Yd=le}Jb=d[1252840+Vd|0]|0;Hd=Vd<<Jb;Fd=Yd<<Jb;wd=Jb+Wd|0;if((wd|0)>-1&Xd>>>0<Nb>>>0){Jb=Xd;af=((he((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535)<<wd|Fd;bf=wd-16|0;cf=Xd+2|0}else{af=Fd;bf=wd;cf=Xd}wd=((Hd<<7)-128>>8)+1|0;Fd=wd<<16;Jb=af>>>0>=Fd>>>0;Pb=Jb?Hd-wd|0:wd;wd=af-(Jb?Fd:0)|0;Fd=(ca(Jb?-Ud|0:Ud,b[p+116+(Ub*12|0)+4+(((Ob|0)!=0)<<1)>>1]|0)|0)&65535;b[q+(h*1536|0)+768+(d[80+Ob|0]<<1)>>1]=Fd;Fd=Ob+1|0;if((Fd|0)>=16){Ld=Fd;Md=Pb;Nd=bf;Od=cf;Pd=wd;break}Jb=d[Td]|0;Hd=d[1252840+Pb|0]|0;ce=Pb<<Hd;Pb=wd<<Hd;wd=Hd+bf|0;if((wd|0)>-1&cf>>>0<Nb>>>0){Hd=cf;df=((he((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<wd|Pb;ff=wd-16|0;gf=cf+2|0}else{df=Pb;ff=wd;gf=cf}wd=((ca(ce-1|0,Jb)|0)>>8)+1|0;Jb=wd<<16;if(df>>>0<Jb>>>0){Ld=Fd;Md=wd;Nd=ff;Od=gf;Pd=df;break}Ob=Fd;ic=Td;nc=ce-wd|0;dc=ff;lc=gf;rc=df-Jb|0}c[Ea>>2]=Md;c[Fa>>2]=Nd;c[Ha>>2]=Od;c[Ia>>2]=Nb;c[Ga>>2]=Pd;rc=(Ld|0)!=0;lc=rc&1;a[Qb]=lc;a[Ca]=lc;if(!rc){zd=0;Ad=0;Bd=0;Cd=1;break}if((Ld|0)==1){re[c[z>>2]&1023](A,Da);zd=1;Ad=1;Bd=0;Cd=1;break}else{re[c[Ja>>2]&1023](A,Da);zd=1;Ad=Ld;Bd=0;Cd=1;break}}}while(0);jc=0;Rb=Ad;while(1){ac=q+(h*1536|0)+824+jc|0;rc=0;lc=Rb;do{dc=Yb+(u*9|0)+rc|0;nc=p+222+(Bd*528|0)+(Cd*33|0)+(((d[dc]|0)+(d[ac]|0)|0)*11|0)|0;ic=d[nc]|0;Ob=c[Ea>>2]|0;bc=d[1252840+Ob|0]|0;gc=c[Fa>>2]|0;Lb=c[Ga>>2]|0;Jb=Ob<<bc;c[Ea>>2]=Jb;Ob=Lb<<bc;Lb=gc+bc|0;do{if((Lb|0)>-1){bc=c[Ha>>2]|0;if(!(bc>>>0<(c[Ia>>2]|0)>>>0)){hf=Ob;jf=Lb;break}c[Ha>>2]=bc+2;gc=bc;hf=((he((d[gc]|d[gc+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Ob;jf=Lb-16|0}else{hf=Ob;jf=Lb}}while(0);c[Fa>>2]=jf;Lb=((ca(Jb-1|0,ic)|0)>>8)+1|0;Ob=Lb<<16;if(hf>>>0<Ob>>>0){c[Ea>>2]=Lb;kf=0;lf=hf}else{gc=Jb-Lb|0;c[Ea>>2]=gc;Lb=hf-Ob|0;c[Ga>>2]=Lb;Ob=c[Ia>>2]|0;bc=Cd;wd=nc;ce=gc;gc=jf;Fd=c[Ha>>2]|0;Pb=Lb;while(1){Lb=d[wd+1|0]|0;Hd=d[1252840+ce|0]|0;be=ce<<Hd;Ce=Pb<<Hd;cc=Hd+gc|0;if((cc|0)>-1&Fd>>>0<Ob>>>0){Hd=Fd;mf=((he((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|Ce;nf=cc-16|0;of=Fd+2|0}else{mf=Ce;nf=cc;of=Fd}cc=((ca(be-1|0,Lb)|0)>>8)+1|0;Lb=cc<<16;if(mf>>>0<Lb>>>0){Ce=bc+1|0;if((Ce|0)==16){pf=16;qf=cc;rf=nf;sf=of;tf=mf;break}bc=Ce;wd=p+222+(Bd*528|0)+(Ce*33|0)|0;ce=cc;gc=nf;Fd=of;Pb=mf;continue}Ce=be-cc|0;cc=d[wd+2|0]|0;be=d[1252840+Ce|0]|0;Hd=Ce<<be;Ce=mf-Lb<<be;Lb=be+nf|0;if((Lb|0)>-1&of>>>0<Ob>>>0){be=of;uf=((he((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Ce;vf=Lb-16|0;wf=of+2|0}else{uf=Ce;vf=Lb;wf=of}Lb=((ca(Hd-1|0,cc)|0)>>8)+1|0;cc=Lb<<16;if(uf>>>0<cc>>>0){xf=p+222+(Bd*528|0)+((bc+1|0)*33|0)+11|0;yf=1;zf=Lb;Af=vf;Bf=wf;Cf=uf}else{Ce=Hd-Lb|0;Lb=d[wd+3|0]|0;Hd=d[1252840+Ce|0]|0;be=Ce<<Hd;Ce=uf-cc<<Hd;cc=Hd+vf|0;if((cc|0)>-1&wf>>>0<Ob>>>0){Hd=wf;Df=((he((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|Ce;Ef=cc-16|0;Ff=wf+2|0}else{Df=Ce;Ef=cc;Ff=wf}cc=((ca(be-1|0,Lb)|0)>>8)+1|0;Lb=cc<<16;do{if(Df>>>0<Lb>>>0){Ce=d[wd+4|0]|0;Hd=d[1252840+cc|0]|0;De=cc<<Hd;Be=Df<<Hd;xe=Hd+Ef|0;if((xe|0)>-1&Ff>>>0<Ob>>>0){Hd=Ff;Gf=((he((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<xe|Be;Hf=xe-16|0;If=Ff+2|0}else{Gf=Be;Hf=xe;If=Ff}xe=((ca(De-1|0,Ce)|0)>>8)+1|0;Ce=xe<<16;if(Gf>>>0<Ce>>>0){Jf=2;Kf=xe;Lf=Hf;Mf=If;Nf=Gf;break}Be=De-xe|0;xe=a[wd+5|0]|0;De=d[1252840+Be|0]|0;Hd=Be<<De;Be=Gf-Ce<<De;Ce=De+Hf|0;if((Ce|0)>-1&If>>>0<Ob>>>0){De=If;Of=((he((d[De]|d[De+1|0]<<8)<<16>>16|0)|0)&65535)<<Ce|Be;Pf=Ce-16|0;Qf=If+2|0}else{Of=Be;Pf=Ce;Qf=If}Ce=((ca(Hd-1|0,xe&255)|0)>>8)+1|0;xe=Ce<<16;Be=Of>>>0>=xe>>>0;Jf=Be?4:3;Kf=Be?Hd-Ce|0:Ce;Lf=Pf;Mf=Qf;Nf=Of-(Be?xe:0)|0}else{xe=be-cc|0;Be=d[wd+6|0]|0;Ce=d[1252840+xe|0]|0;Hd=xe<<Ce;xe=Df-Lb<<Ce;De=Ce+Ef|0;if((De|0)>-1&Ff>>>0<Ob>>>0){Ce=Ff;Rf=((he((d[Ce]|d[Ce+1|0]<<8)<<16>>16|0)|0)&65535)<<De|xe;Sf=De-16|0;Tf=Ff+2|0}else{Rf=xe;Sf=De;Tf=Ff}De=((ca(Hd-1|0,Be)|0)>>8)+1|0;Be=De<<16;if(!(Rf>>>0<Be>>>0)){xe=Hd-De|0;Hd=a[wd+8|0]|0;Ce=d[1252840+xe|0]|0;mc=xe<<Ce;xe=Rf-Be<<Ce;Be=Ce+Sf|0;if((Be|0)>-1&Tf>>>0<Ob>>>0){Ce=Tf;Uf=((he((d[Ce]|d[Ce+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|xe;Vf=Be-16|0;Wf=Tf+2|0}else{Uf=xe;Vf=Be;Wf=Tf}Be=((ca(mc-1|0,Hd&255)|0)>>8)+1|0;Hd=Be<<16;xe=Uf>>>0>=Hd>>>0;Ce=xe?mc-Be|0:Be;Be=a[wd+(xe?10:9)|0]|0;mc=d[1252840+Ce|0]|0;kc=Ce<<mc;Ce=Uf-(xe?Hd:0)<<mc;Hd=mc+Vf|0;if((Hd|0)>-1&Wf>>>0<Ob>>>0){mc=Wf;Xf=((he((d[mc]|d[mc+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Ce;Yf=Hd-16|0;Zf=Wf+2|0}else{Xf=Ce;Yf=Hd;Zf=Wf}Hd=((ca(kc-1|0,Be&255)|0)>>8)+1|0;Be=Hd<<16;Ce=Xf>>>0>=Be>>>0;mc=Ce&1|(xe&1)<<1;xe=c[1251240+(mc<<2)>>2]|0;Ee=0;Gd=xe;Ge=a[xe]|0;xe=Ce?kc-Hd|0:Hd;Hd=Yf;kc=Xf-(Ce?Be:0)|0;Be=Zf;while(1){Ce=Gd+1|0;He=d[1252840+xe|0]|0;Fe=xe<<He;_f=kc<<He;$f=He+Hd|0;if(($f|0)>-1&Be>>>0<Ob>>>0){He=Be;ag=((he((d[He]|d[He+1|0]<<8)<<16>>16|0)|0)&65535)<<$f|_f;bg=$f-16|0;cg=Be+2|0}else{ag=_f;bg=$f;cg=Be}$f=((ca(Fe-1|0,Ge&255)|0)>>8)+1|0;_f=$f<<16;He=ag>>>0>=_f>>>0;dg=He?Fe-$f|0:$f;eg=ag-(He?_f:0)|0;fg=He&1|Ee<<1;He=a[Ce]|0;if(He<<24>>24==0){break}else{Ee=fg;Gd=Ce;Ge=He;xe=dg;Hd=bg;kc=eg;Be=cg}}Jf=(8<<mc)+3+fg|0;Kf=dg;Lf=bg;Mf=cg;Nf=eg;break}Be=d[wd+7|0]|0;kc=d[1252840+De|0]|0;Hd=De<<kc;xe=Rf<<kc;Ge=kc+Sf|0;if((Ge|0)>-1&Tf>>>0<Ob>>>0){kc=Tf;gg=((he((d[kc]|d[kc+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|xe;hg=Ge-16|0;ig=Tf+2|0}else{gg=xe;hg=Ge;ig=Tf}Ge=((ca(Hd-1|0,Be)|0)>>8)+1|0;Be=Ge<<16;if(gg>>>0<Be>>>0){xe=d[1252840+Ge|0]|0;kc=Ge<<xe;Gd=gg<<xe;Ee=xe+hg|0;if((Ee|0)>-1&ig>>>0<Ob>>>0){xe=ig;jg=((he((d[xe]|d[xe+1|0]<<8)<<16>>16|0)|0)&65535)<<Ee|Gd;kg=Ee-16|0;lg=ig+2|0}else{jg=Gd;kg=Ee;lg=ig}Ee=((kc*159|0)-159>>8)+1|0;Gd=Ee<<16;xe=jg>>>0>=Gd>>>0;Jf=xe?6:5;Kf=xe?kc-Ee|0:Ee;Lf=kg;Mf=lg;Nf=jg-(xe?Gd:0)|0;break}Gd=Hd-Ge|0;Ge=d[1252840+Gd|0]|0;Hd=Gd<<Ge;Gd=gg-Be<<Ge;Be=Ge+hg|0;if((Be|0)>-1&ig>>>0<Ob>>>0){Ge=ig;mg=((he((d[Ge]|d[Ge+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|Gd;ng=Be-16|0;og=ig+2|0}else{mg=Gd;ng=Be;og=ig}Be=((Hd*165|0)-165>>8)+1|0;Gd=Be<<16;Ge=mg>>>0>=Gd>>>0;xe=Ge?Hd-Be|0:Be;Be=d[1252840+xe|0]|0;Hd=xe<<Be;xe=mg-(Ge?Gd:0)<<Be;Gd=Be+ng|0;if((Gd|0)>-1&og>>>0<Ob>>>0){Be=og;pg=((he((d[Be]|d[Be+1|0]<<8)<<16>>16|0)|0)&65535)<<Gd|xe;qg=Gd-16|0;rg=og+2|0}else{pg=xe;qg=Gd;rg=og}Gd=((Hd*145|0)-145>>8)+1|0;xe=Gd<<16;Be=pg>>>0>=xe>>>0;Jf=((Ge&1)<<1)+7+(Be&1)|0;Kf=Be?Hd-Gd|0:Gd;Lf=qg;Mf=rg;Nf=pg-(Be?xe:0)|0}}while(0);xf=p+222+(Bd*528|0)+((bc+1|0)*33|0)+22|0;yf=Jf;zf=Kf;Af=Lf;Bf=Mf;Cf=Nf}Lb=d[1252840+zf|0]|0;cc=zf<<Lb;be=Cf<<Lb;ae=Lb+Af|0;if((ae|0)>-1&Bf>>>0<Ob>>>0){Lb=Bf;sg=((he((d[Lb]|d[Lb+1|0]<<8)<<16>>16|0)|0)&65535)<<ae|be;tg=ae-16|0;ug=Bf+2|0}else{sg=be;tg=ae;ug=Bf}ae=((cc<<7)-128>>8)+1|0;be=ae<<16;Lb=sg>>>0>=be>>>0;te=Lb?cc-ae|0:ae;ae=sg-(Lb?be:0)|0;be=(ca(Lb?-yf|0:yf,b[p+116+(Ub*12|0)+(((bc|0)!=0)<<1)>>1]|0)|0)&65535;b[q+(h*1536|0)+(jc<<7)+(rc<<5)+(d[80+bc|0]<<1)>>1]=be;be=bc+1|0;if((be|0)>=16){pf=be;qf=te;rf=tg;sf=ug;tf=ae;break}Lb=d[xf]|0;cc=d[1252840+te|0]|0;xe=te<<cc;te=ae<<cc;ae=cc+tg|0;if((ae|0)>-1&ug>>>0<Ob>>>0){cc=ug;vg=((he((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<ae|te;wg=ae-16|0;xg=ug+2|0}else{vg=te;wg=ae;xg=ug}ae=((ca(xe-1|0,Lb)|0)>>8)+1|0;Lb=ae<<16;if(vg>>>0<Lb>>>0){pf=be;qf=ae;rf=wg;sf=xg;tf=vg;break}bc=be;wd=xf;ce=xe-ae|0;gc=wg;Fd=xg;Pb=vg-Lb|0}c[Ea>>2]=qf;c[Fa>>2]=rf;c[Ha>>2]=sf;c[Ia>>2]=Ob;kf=pf;lf=tf}c[Ga>>2]=lf;a[q+(h*1536|0)+800+(jc<<2)+rc|0]=kf+zd;Pb=(kf|0)!=0|0;a[ac]=Pb;a[dc]=Pb;lc=kf+lc|0;rc=rc+1|0;}while((rc|0)<4);rc=jc+1|0;if((rc|0)<4){jc=rc;Rb=lc}else{yg=lc;zg=4;break}}while(1){Rb=0;jc=yg;while(1){rc=Rb<<1;ac=rc+zg+(q+(h*1536|0)+824)|0;Qb=0;Ag=jc;do{Nb=(Qb<<1)+zg+(Yb+(u*9|0))|0;Pb=Qb+rc|0;Fd=p+1278+(((d[Nb]|0)+(d[ac]|0)|0)*11|0)|0;gc=d[Fd]|0;ce=c[Ea>>2]|0;wd=d[1252840+ce|0]|0;bc=c[Fa>>2]|0;nc=c[Ga>>2]|0;Jb=ce<<wd;c[Ea>>2]=Jb;ce=nc<<wd;nc=bc+wd|0;do{if((nc|0)>-1){wd=c[Ha>>2]|0;if(!(wd>>>0<(c[Ia>>2]|0)>>>0)){Bg=ce;Cg=nc;break}c[Ha>>2]=wd+2;bc=wd;Bg=((he((d[bc]|d[bc+1|0]<<8)<<16>>16|0)|0)&65535)<<nc|ce;Cg=nc-16|0}else{Bg=ce;Cg=nc}}while(0);c[Fa>>2]=Cg;nc=((ca(Jb-1|0,gc)|0)>>8)+1|0;ce=nc<<16;if(Bg>>>0<ce>>>0){c[Ea>>2]=nc;Dg=0;Eg=Bg}else{bc=Jb-nc|0;c[Ea>>2]=bc;nc=Bg-ce|0;c[Ga>>2]=nc;ce=c[Ia>>2]|0;wd=0;ic=Fd;Lb=bc;bc=Cg;ae=c[Ha>>2]|0;xe=nc;while(1){nc=d[ic+1|0]|0;be=d[1252840+Lb|0]|0;te=Lb<<be;cc=xe<<be;Be=be+bc|0;if((Be|0)>-1&ae>>>0<ce>>>0){be=ae;Fg=((he((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|cc;Gg=Be-16|0;Hg=ae+2|0}else{Fg=cc;Gg=Be;Hg=ae}Be=((ca(te-1|0,nc)|0)>>8)+1|0;nc=Be<<16;if(Fg>>>0<nc>>>0){cc=wd+1|0;if((cc|0)==16){Ig=16;Jg=Be;Kg=Gg;Lg=Hg;Mg=Fg;break}wd=cc;ic=p+1278+(cc*33|0)|0;Lb=Be;bc=Gg;ae=Hg;xe=Fg;continue}cc=te-Be|0;Be=d[ic+2|0]|0;te=d[1252840+cc|0]|0;be=cc<<te;cc=Fg-nc<<te;nc=te+Gg|0;if((nc|0)>-1&Hg>>>0<ce>>>0){te=Hg;Ng=((he((d[te]|d[te+1|0]<<8)<<16>>16|0)|0)&65535)<<nc|cc;Og=nc-16|0;Pg=Hg+2|0}else{Ng=cc;Og=nc;Pg=Hg}nc=((ca(be-1|0,Be)|0)>>8)+1|0;Be=nc<<16;if(Ng>>>0<Be>>>0){Qg=p+1278+((wd+1|0)*33|0)+11|0;Rg=1;Sg=nc;Tg=Og;Ug=Pg;Vg=Ng}else{cc=be-nc|0;nc=d[ic+3|0]|0;be=d[1252840+cc|0]|0;te=cc<<be;cc=Ng-Be<<be;Be=be+Og|0;if((Be|0)>-1&Pg>>>0<ce>>>0){be=Pg;Wg=((he((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Be|cc;Xg=Be-16|0;Yg=Pg+2|0}else{Wg=cc;Xg=Be;Yg=Pg}Be=((ca(te-1|0,nc)|0)>>8)+1|0;nc=Be<<16;do{if(Wg>>>0<nc>>>0){cc=d[ic+4|0]|0;be=d[1252840+Be|0]|0;Gd=Be<<be;Hd=Wg<<be;Ge=be+Xg|0;if((Ge|0)>-1&Yg>>>0<ce>>>0){be=Yg;Zg=((he((d[be]|d[be+1|0]<<8)<<16>>16|0)|0)&65535)<<Ge|Hd;_g=Ge-16|0;$g=Yg+2|0}else{Zg=Hd;_g=Ge;$g=Yg}Ge=((ca(Gd-1|0,cc)|0)>>8)+1|0;cc=Ge<<16;if(Zg>>>0<cc>>>0){ah=2;bh=Ge;ch=_g;dh=$g;eh=Zg;break}Hd=Gd-Ge|0;Ge=a[ic+5|0]|0;Gd=d[1252840+Hd|0]|0;be=Hd<<Gd;Hd=Zg-cc<<Gd;cc=Gd+_g|0;if((cc|0)>-1&$g>>>0<ce>>>0){Gd=$g;fh=((he((d[Gd]|d[Gd+1|0]<<8)<<16>>16|0)|0)&65535)<<cc|Hd;gh=cc-16|0;hh=$g+2|0}else{fh=Hd;gh=cc;hh=$g}cc=((ca(be-1|0,Ge&255)|0)>>8)+1|0;Ge=cc<<16;Hd=fh>>>0>=Ge>>>0;ah=Hd?4:3;bh=Hd?be-cc|0:cc;ch=gh;dh=hh;eh=fh-(Hd?Ge:0)|0}else{Ge=te-Be|0;Hd=d[ic+6|0]|0;cc=d[1252840+Ge|0]|0;be=Ge<<cc;Ge=Wg-nc<<cc;Gd=cc+Xg|0;if((Gd|0)>-1&Yg>>>0<ce>>>0){cc=Yg;ih=((he((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<Gd|Ge;jh=Gd-16|0;kh=Yg+2|0}else{ih=Ge;jh=Gd;kh=Yg}Gd=((ca(be-1|0,Hd)|0)>>8)+1|0;Hd=Gd<<16;if(!(ih>>>0<Hd>>>0)){Ge=be-Gd|0;be=a[ic+8|0]|0;cc=d[1252840+Ge|0]|0;Ee=Ge<<cc;Ge=ih-Hd<<cc;Hd=cc+jh|0;if((Hd|0)>-1&kh>>>0<ce>>>0){cc=kh;lh=((he((d[cc]|d[cc+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Ge;mh=Hd-16|0;nh=kh+2|0}else{lh=Ge;mh=Hd;nh=kh}Hd=((ca(Ee-1|0,be&255)|0)>>8)+1|0;be=Hd<<16;Ge=lh>>>0>=be>>>0;cc=Ge?Ee-Hd|0:Hd;Hd=a[ic+(Ge?10:9)|0]|0;Ee=d[1252840+cc|0]|0;kc=cc<<Ee;cc=lh-(Ge?be:0)<<Ee;be=Ee+mh|0;if((be|0)>-1&nh>>>0<ce>>>0){Ee=nh;oh=((he((d[Ee]|d[Ee+1|0]<<8)<<16>>16|0)|0)&65535)<<be|cc;ph=be-16|0;qh=nh+2|0}else{oh=cc;ph=be;qh=nh}be=((ca(kc-1|0,Hd&255)|0)>>8)+1|0;Hd=be<<16;cc=oh>>>0>=Hd>>>0;Ee=cc&1|(Ge&1)<<1;Ge=c[1251240+(Ee<<2)>>2]|0;He=0;Ce=Ge;_f=a[Ge]|0;Ge=cc?kc-be|0:be;be=ph;kc=oh-(cc?Hd:0)|0;Hd=qh;while(1){cc=Ce+1|0;$f=d[1252840+Ge|0]|0;Fe=Ge<<$f;rh=kc<<$f;sh=$f+be|0;if((sh|0)>-1&Hd>>>0<ce>>>0){$f=Hd;th=((he((d[$f]|d[$f+1|0]<<8)<<16>>16|0)|0)&65535)<<sh|rh;uh=sh-16|0;vh=Hd+2|0}else{th=rh;uh=sh;vh=Hd}sh=((ca(Fe-1|0,_f&255)|0)>>8)+1|0;rh=sh<<16;$f=th>>>0>=rh>>>0;wh=$f?Fe-sh|0:sh;xh=th-($f?rh:0)|0;yh=$f&1|He<<1;$f=a[cc]|0;if($f<<24>>24==0){break}else{He=yh;Ce=cc;_f=$f;Ge=wh;be=uh;kc=xh;Hd=vh}}ah=(8<<Ee)+3+yh|0;bh=wh;ch=uh;dh=vh;eh=xh;break}Hd=d[ic+7|0]|0;kc=d[1252840+Gd|0]|0;be=Gd<<kc;Ge=ih<<kc;_f=kc+jh|0;if((_f|0)>-1&kh>>>0<ce>>>0){kc=kh;zh=((he((d[kc]|d[kc+1|0]<<8)<<16>>16|0)|0)&65535)<<_f|Ge;Ah=_f-16|0;Bh=kh+2|0}else{zh=Ge;Ah=_f;Bh=kh}_f=((ca(be-1|0,Hd)|0)>>8)+1|0;Hd=_f<<16;if(zh>>>0<Hd>>>0){Ge=d[1252840+_f|0]|0;kc=_f<<Ge;Ce=zh<<Ge;He=Ge+Ah|0;if((He|0)>-1&Bh>>>0<ce>>>0){Ge=Bh;Ch=((he((d[Ge]|d[Ge+1|0]<<8)<<16>>16|0)|0)&65535)<<He|Ce;Dh=He-16|0;Eh=Bh+2|0}else{Ch=Ce;Dh=He;Eh=Bh}He=((kc*159|0)-159>>8)+1|0;Ce=He<<16;Ge=Ch>>>0>=Ce>>>0;ah=Ge?6:5;bh=Ge?kc-He|0:He;ch=Dh;dh=Eh;eh=Ch-(Ge?Ce:0)|0;break}Ce=be-_f|0;_f=d[1252840+Ce|0]|0;be=Ce<<_f;Ce=zh-Hd<<_f;Hd=_f+Ah|0;if((Hd|0)>-1&Bh>>>0<ce>>>0){_f=Bh;Fh=((he((d[_f]|d[_f+1|0]<<8)<<16>>16|0)|0)&65535)<<Hd|Ce;Gh=Hd-16|0;Hh=Bh+2|0}else{Fh=Ce;Gh=Hd;Hh=Bh}Hd=((be*165|0)-165>>8)+1|0;Ce=Hd<<16;_f=Fh>>>0>=Ce>>>0;Ge=_f?be-Hd|0:Hd;Hd=d[1252840+Ge|0]|0;be=Ge<<Hd;Ge=Fh-(_f?Ce:0)<<Hd;Ce=Hd+Gh|0;if((Ce|0)>-1&Hh>>>0<ce>>>0){Hd=Hh;Ih=((he((d[Hd]|d[Hd+1|0]<<8)<<16>>16|0)|0)&65535)<<Ce|Ge;Jh=Ce-16|0;Kh=Hh+2|0}else{Ih=Ge;Jh=Ce;Kh=Hh}Ce=((be*145|0)-145>>8)+1|0;Ge=Ce<<16;Hd=Ih>>>0>=Ge>>>0;ah=((_f&1)<<1)+7+(Hd&1)|0;bh=Hd?be-Ce|0:Ce;ch=Jh;dh=Kh;eh=Ih-(Hd?Ge:0)|0}}while(0);Qg=p+1278+((wd+1|0)*33|0)+22|0;Rg=ah;Sg=bh;Tg=ch;Ug=dh;Vg=eh}nc=d[1252840+Sg|0]|0;Be=Sg<<nc;te=Vg<<nc;De=nc+Tg|0;if((De|0)>-1&Ug>>>0<ce>>>0){nc=Ug;Lh=((he((d[nc]|d[nc+1|0]<<8)<<16>>16|0)|0)&65535)<<De|te;Mh=De-16|0;Nh=Ug+2|0}else{Lh=te;Mh=De;Nh=Ug}De=((Be<<7)-128>>8)+1|0;te=De<<16;nc=Lh>>>0>=te>>>0;mc=nc?Be-De|0:De;De=Lh-(nc?te:0)|0;te=(ca(nc?-Rg|0:Rg,b[p+116+(Ub*12|0)+8+(((wd|0)!=0)<<1)>>1]|0)|0)&65535;b[q+(h*1536|0)+(zg<<7)+(Pb<<5)+(d[80+wd|0]<<1)>>1]=te;te=wd+1|0;if((te|0)>=16){Ig=te;Jg=mc;Kg=Mh;Lg=Nh;Mg=De;break}nc=d[Qg]|0;Be=d[1252840+mc|0]|0;Ge=mc<<Be;mc=De<<Be;De=Be+Mh|0;if((De|0)>-1&Nh>>>0<ce>>>0){Be=Nh;Oh=((he((d[Be]|d[Be+1|0]<<8)<<16>>16|0)|0)&65535)<<De|mc;Ph=De-16|0;Qh=Nh+2|0}else{Oh=mc;Ph=De;Qh=Nh}De=((ca(Ge-1|0,nc)|0)>>8)+1|0;nc=De<<16;if(Oh>>>0<nc>>>0){Ig=te;Jg=De;Kg=Ph;Lg=Qh;Mg=Oh;break}wd=te;ic=Qg;Lb=Ge-De|0;bc=Ph;ae=Qh;xe=Oh-nc|0}c[Ea>>2]=Jg;c[Fa>>2]=Kg;c[Ha>>2]=Lg;c[Ia>>2]=ce;Dg=Ig;Eg=Mg}c[Ga>>2]=Eg;a[q+(h*1536|0)+800+(zg<<2)+Pb|0]=Dg;xe=(Dg|0)!=0|0;a[ac]=xe;a[Nb]=xe;Ag=Dg+Ag|0;Qb=Qb+1|0;}while((Qb|0)<2);Qb=Rb+1|0;if((Qb|0)<2){Rb=Qb;jc=Ag}else{break}}jc=zg+1|0;if((jc|0)<6){yg=Ag;zg=jc}else{break}}if((Ag|0)!=0){Rh=Vb;break}a[oc]=1;Rh=Vb}else{Rh=Gb+1|0}}while(0);a:do{if((d[Rh]|0)>>>0<5>>>0){do{if(Ma){if((a[Na]|0)==0){break}if((c[Oa>>2]|0)!=0){break}Ub=u+1|0;Yb=c[Pa>>2]|0;jc=c[B>>2]|0;Rb=c[G>>2]|0;lc=c[L>>2]|0;Qb=c[E>>2]|0;ac=c[I>>2]|0;rc=e[s>>1]|0;dc=a[Qa]|0;Ob=-ac|0;xe=Yb+(Ub<<5)-24|0;ae=c[xe>>2]|0;bc=c[xe+4>>2]|0;Lb=jc+(-8-Qb)|0;ic=c[Lb+4>>2]|0;c[xe>>2]=c[Lb>>2];c[xe+4>>2]=ic;c[Lb>>2]=ae;c[Lb+4>>2]=bc;bc=Yb+(Ub<<5)|0;Lb=c[bc>>2]|0;ae=c[bc+4>>2]|0;ic=jc+(-Qb|0)|0;xe=c[ic+4>>2]|0;c[bc>>2]=c[ic>>2];c[bc+4>>2]=xe;c[ic>>2]=Lb;c[ic+4>>2]=ae;ae=Yb+(Ub<<5)+8|0;ic=c[ae>>2]|0;Lb=c[ae+4>>2]|0;xe=jc+(8-Qb)|0;bc=c[xe+4>>2]|0;c[ae>>2]=c[xe>>2];c[ae+4>>2]=bc;c[xe>>2]=ic;c[xe+4>>2]=Lb;if((rc-1|0)>(u|0)){rc=Yb+(Ub<<5)+32|0;Lb=c[rc>>2]|0;xe=c[rc+4>>2]|0;ic=jc+(16-Qb)|0;Qb=c[ic+4>>2]|0;c[rc>>2]=c[ic>>2];c[rc+4>>2]=Qb;c[ic>>2]=Lb;c[ic+4>>2]=xe}if(!(dc<<24>>24==0)){break}dc=Yb+(Ub<<5)-16|0;xe=c[dc>>2]|0;ic=c[dc+4>>2]|0;Lb=-8-ac|0;ac=Rb+Lb|0;Qb=c[ac+4>>2]|0;c[dc>>2]=c[ac>>2];c[dc+4>>2]=Qb;c[ac>>2]=xe;c[ac+4>>2]=ic;ic=Yb+(Ub<<5)-8|0;ac=c[ic>>2]|0;xe=c[ic+4>>2]|0;Qb=lc+Lb|0;Lb=c[Qb+4>>2]|0;c[ic>>2]=c[Qb>>2];c[ic+4>>2]=Lb;c[Qb>>2]=ac;c[Qb+4>>2]=xe;xe=Yb+(Ub<<5)+16|0;Qb=c[xe>>2]|0;ac=c[xe+4>>2]|0;Lb=Rb+Ob|0;Rb=c[Lb+4>>2]|0;c[xe>>2]=c[Lb>>2];c[xe+4>>2]=Rb;c[Lb>>2]=Qb;c[Lb+4>>2]=ac;ac=Yb+(Ub<<5)+24|0;Ub=c[ac>>2]|0;Yb=c[ac+4>>2]|0;Lb=lc+Ob|0;Ob=c[Lb+4>>2]|0;c[ac>>2]=c[Lb>>2];c[ac+4>>2]=Ob;c[Lb>>2]=Ub;c[Lb+4>>2]=Yb}}while(0);Vb=a[Rh]|0;if((Vb&255)>>>0<4>>>0){Yb=Vb&255;if((Yb|0)==0){Sh=(u|0)==0?Ra:Sa}else if((Yb|0)==2){Sh=Ta}else if((Yb|0)==1){Sh=(u|0)!=0?1:8}else if((Yb|0)==3){Sh=(u|0)==0?Ua:Va}else{Sh=Yb}re[c[p+5164+(Sh<<2)>>2]&1023](c[B>>2]|0,c[E>>2]|0)}else{Yb=c[B>>2]|0;Vb=Gb+6|0;c[k>>2]=2139062143;Lb=c[E>>2]|0;Ub=16-Lb|0;Ob=Yb+Ub|0;do{if(Ma){if(((e[s>>1]|0)-1|0)!=(u|0)){Th=Ob;break}c[j>>2]=ca(d[Yb+(Ub-1)|0]|0,16843009)|0;Th=Ka}else{Th=Ob}}while(0);if((a[oc]|0)==0){Uh=0;Vh=Yb;Wh=Vb;Xh=Lb}else{mrc(l|0,0,16)|0;Uh=0;Vh=Yb;Wh=Vb;Xh=c[E>>2]|0}while(1){Ob=(Uh|0)==0;Ub=Uh+r|0;ac=(Ub|0)==0;lc=(Ub|0)!=0;Ub=lc?10:13;Qb=lc?9:14;Rb=0;xe=Vh+(4-Xh)|0;ic=Xh;while(1){dc=Rb<<2;rc=Vh+dc|0;jc=(Rb|0)==3;if((Ob|jc)&Wa){Yh=La}else{Yh=jc?Th:xe}jc=d[Wh+Rb|0]|0;bc=Rb+u|0;switch(jc|0){case 0:{if((bc|0)!=0|ac){Zh=401}else{_h=0;Zh=406}break};case 3:case 7:{Zh=401;break};case 1:{if(ac){$h=1;Zh=407}else{Zh=403}break};case 8:{Zh=403;break};case 9:{ai=(bc|0)==0?Ub:Qb;Zh=414;break};case 2:case 4:case 5:case 6:{if(ac|(bc|0)==0){_h=jc;Zh=406}else{ai=jc;Zh=414}break};default:{ai=jc;Zh=414}}do{if((Zh|0)==401){Zh=0;ai=lc?jc:12;Zh=414}else if((Zh|0)==403){Zh=0;ai=(bc|0)!=0?jc:13;Zh=414}else if((Zh|0)==406){Zh=0;if(ac){$h=_h;Zh=407;break}c[_a>>2]=c[Vh+(dc-ic)>>2];if((bc|0)==0){a[$a]=-127;bi=_h;Zh=412;break}else{a[$a]=a[Vh+(dc+~ic)|0]|0;ci=_h;Zh=411;break}}}while(0);if((Zh|0)==407){Zh=0;a[$a]=127;c[_a>>2]=2139062143;ci=$h;Zh=411}else if((Zh|0)==414){Zh=0;ef[c[p+5012+(ai<<2)>>2]&4095](rc,Yh,ic)}do{if((Zh|0)==411){Zh=0;if((bc|0)==0){bi=ci;Zh=412;break}jc=dc-1|0;a[ab]=a[Vh+jc|0]|0;a[bb]=a[Vh+(jc+ic)|0]|0;a[cb]=a[Vh+(jc+(ic<<1))|0]|0;a[db]=a[Vh+(jc+(ic*3|0))|0]|0;di=ci;Zh=415}}while(0);if((Zh|0)==412){Zh=0;a[db]=-127;a[cb]=-127;a[bb]=-127;a[ab]=-127;di=bi;Zh=415}if((Zh|0)==415){Zh=0;ef[c[p+5012+(di<<2)>>2]&4095](Za,Yh,8);c[rc>>2]=c[eb>>2];c[Vh+((c[E>>2]|0)+dc)>>2]=c[fb>>2];c[Vh+((c[E>>2]<<1)+dc)>>2]=c[gb>>2];c[Vh+(((c[E>>2]|0)*3|0)+dc)>>2]=c[hb>>2]}bc=a[q+(h*1536|0)+800+(Uh<<2)+Rb|0]|0;if((bc<<24>>24|0)==1){ef[c[Ya>>2]&4095](rc,q+(h*1536|0)+(Uh<<7)+(Rb<<5)|0,c[E>>2]|0)}else if((bc<<24>>24|0)!=0){ef[c[Xa>>2]&4095](rc,q+(h*1536|0)+(Uh<<7)+(Rb<<5)|0,c[E>>2]|0)}bc=Rb+1|0;ei=c[E>>2]|0;if((bc|0)<4){Rb=bc;xe=Yh+4|0;ic=ei}else{break}}ic=Uh+1|0;if((ic|0)<4){Uh=ic;Vh=Vh+(ei<<2)|0;Wh=Wh+4|0;Xh=ei}else{break}}}Vb=d[Gb+4|0]|0;if((Vb|0)==0){fi=(u|0)==0?Ra:Sa}else if((Vb|0)==2){fi=Ta}else if((Vb|0)==1){fi=(u|0)!=0?1:8}else if((Vb|0)==3){fi=(u|0)==0?Ua:Va}else{fi=Vb}Vb=p+5120+(fi<<2)|0;Yb=c[G>>2]|0;re[c[Vb>>2]&1023](Yb,c[I>>2]|0);Lb=c[L>>2]|0;re[c[Vb>>2]&1023](Lb,c[I>>2]|0);if(!Ma){break}if((a[Na]|0)==0){break}if((c[Oa>>2]|0)!=0){break}Vb=u+1|0;ic=c[Pa>>2]|0;xe=c[B>>2]|0;Rb=c[E>>2]|0;ac=c[I>>2]|0;lc=e[s>>1]|0;Qb=a[Qa]|0;Ub=-ac|0;Ob=ic+(Vb<<5)-24|0;bc=c[Ob+4>>2]|0;jc=xe+(-8-Rb)|0;c[jc>>2]=c[Ob>>2];c[jc+4>>2]=bc;bc=ic+(Vb<<5)|0;jc=c[bc+4>>2]|0;Ob=xe+(-Rb|0)|0;c[Ob>>2]=c[bc>>2];c[Ob+4>>2]=jc;jc=ic+(Vb<<5)+8|0;Ob=c[jc>>2]|0;bc=c[jc+4>>2]|0;ae=xe+(8-Rb)|0;wd=c[ae+4>>2]|0;c[jc>>2]=c[ae>>2];c[jc+4>>2]=wd;c[ae>>2]=Ob;c[ae+4>>2]=bc;if((lc-1|0)>(u|0)){lc=ic+(Vb<<5)+32|0;bc=c[lc>>2]|0;ae=c[lc+4>>2]|0;Ob=xe+(16-Rb)|0;Rb=c[Ob+4>>2]|0;c[lc>>2]=c[Ob>>2];c[lc+4>>2]=Rb;c[Ob>>2]=bc;c[Ob+4>>2]=ae}if(!(Qb<<24>>24==0)){break}Qb=ic+(Vb<<5)-16|0;ae=c[Qb+4>>2]|0;Ob=-8-ac|0;ac=Yb+Ob|0;c[ac>>2]=c[Qb>>2];c[ac+4>>2]=ae;ae=ic+(Vb<<5)-8|0;ac=c[ae+4>>2]|0;Qb=Lb+Ob|0;c[Qb>>2]=c[ae>>2];c[Qb+4>>2]=ac;ac=ic+(Vb<<5)+16|0;Qb=c[ac>>2]|0;ae=c[ac+4>>2]|0;Ob=Yb+Ub|0;Yb=c[Ob+4>>2]|0;c[ac>>2]=c[Ob>>2];c[ac+4>>2]=Yb;c[Ob>>2]=Qb;c[Ob+4>>2]=ae;ae=ic+(Vb<<5)+24|0;Vb=c[ae>>2]|0;ic=c[ae+4>>2]|0;Ob=Lb+Ub|0;Ub=c[Ob+4>>2]|0;c[ae>>2]=c[Ob>>2];c[ae+4>>2]=Ub;c[Ob>>2]=Vb;c[Ob+4>>2]=ic}else{ic=u<<4;Ob=e[s>>1]|0;Vb=Ob<<4;Ub=e[J>>1]|0;ae=Ub<<4;Lb=c[p+8+(d[Gb+2|0]<<2)>>2]|0;Qb=Lb|0;Yb=Gb+32|0;switch(d[Gb+3|0]|0){case 3:{ac=Lb|0;bc=Vb-4|0;Rb=ae-4|0;lc=c[B>>2]|0;xe=0;do{wd=xe<<2;jc=wd+D|0;Fd=(jc|3)+4>>4;Jb=0;do{gc=c[E>>2]|0;nc=Jb<<2;De=lc+((ca(gc,wd)|0)+nc)|0;Ge=Jb+wd|0;te=nc+ic|0;nc=c[c[ac>>2]>>2]|0;mc=c[Gb+32+(Ge<<2)>>2]|0;if((mc|0)==0){M5a(Qb,Fd,0);Be=nc+((ca(gc,jc)|0)+te)|0;Se[c[Bb>>2]&1023](De,gc,Be,gc,4,0,0)}else{Be=mc<<1&6;Hd=d[552672+Be|0]|0;Ce=b[Gb+32+(Ge<<2)+2>>1]|0;Ge=Ce<<1&6;be=d[552672+Ge|0]|0;_f=(mc<<16>>18)+te|0;te=(Ce>>2)+jc|0;Ce=d[552688+Ge|0]|0;M5a(Qb,te+7+Ce>>4,0);mc=(ca(te,gc)|0)+_f|0;He=nc+mc|0;do{if((_f|0)<(Hd|0)){Zh=456}else{if((_f|0)>=(bc-(d[552688+Be|0]|0)|0)|(te|0)<(be|0)){Zh=456;break}if((te|0)<(Rb-Ce|0)){gi=He;hi=gc}else{Zh=456}}}while(0);if((Zh|0)==456){Zh=0;He=nc+(mc-((ca(be,gc)|0)+Hd))|0;Ve[c[zb>>2]&127](Ab,He,32,gc,(d[552680+Be|0]|0)+4|0,(d[552680+Ge|0]|0)+4|0,_f-Hd|0,te-be|0,Vb,ae);gi=(be<<5)+Hd+(q+(h*1536|0)+848)|0;hi=32}Se[c[p+5312+(be*12|0)+(Hd<<2)>>2]&1023](De,gc,gi,hi,4,Be,Ge)}Jb=Jb+1|0;}while((Jb|0)<4);xe=xe+1|0;}while((xe|0)<4);xe=ic>>1;Rb=Ob<<3;bc=Ub<<3;lc=Rb-4|0;Jb=bc-4|0;jc=c[G>>2]|0;Fd=c[L>>2]|0;wd=0;do{He=wd<<3;Ce=He|4;rc=wd<<2;dc=rc+H|0;kc=(dc|3)+4>>3;$f=0;do{cc=$f<<1;rh=cc+He|0;sh=rh|1;Fe=cc+Ce|0;cc=Fe|1;ii=((((b[Gb+32+(sh<<2)>>1]|0)+(b[Gb+32+(rh<<2)>>1]|0)&65535)+(b[Gb+32+(Fe<<2)>>1]|0)&65535)+(b[Gb+32+(cc<<2)>>1]|0)&65535)<<16>>16;ji=(ii+2+(ii>>31)|0)>>>2&65535;ii=((((b[Gb+32+(sh<<2)+2>>1]|0)+(b[Gb+32+(rh<<2)+2>>1]|0)&65535)+(b[Gb+32+(Fe<<2)+2>>1]|0)&65535)+(b[Gb+32+(cc<<2)+2>>1]|0)&65535)<<16>>16;cc=(ii+2+(ii>>31)|0)>>>2&65535;if((a[wb]|0)==3){ki=ji&-8;li=cc&-8}else{ki=ji;li=cc}cc=c[I>>2]|0;ji=$f<<2;ii=(ca(cc,rc)|0)+ji|0;Fe=jc+ii|0;rh=Fd+ii|0;ii=ji+xe|0;ji=c[ac>>2]|0;sh=c[ji+4>>2]|0;mi=c[ji+8>>2]|0;ji=ki&65535;b:do{if(((li&65535)<<16|ji|0)==0){M5a(Qb,kc,0);ni=(ca(cc,dc)|0)+ii|0;Se[c[Bb>>2]&1023](Fe,cc,sh+ni|0,cc,4,0,0);Se[c[Bb>>2]&1023](rh,cc,mi+ni|0,cc,4,0,0)}else{ni=ji&7;oi=d[552672+ni|0]|0;pi=li<<16>>16;qi=pi&7;ri=d[552672+qi|0]|0;si=(ji<<16>>19)+ii|0;ti=(pi>>3)+dc|0;pi=si+(ca(ti,cc)|0)|0;ui=sh+pi|0;vi=mi+pi|0;wi=d[552688+qi|0]|0;M5a(Qb,ti+7+wi>>3,0);do{if((si|0)>=(oi|0)){if((si|0)>=(lc-(d[552688+ni|0]|0)|0)|(ti|0)<(ri|0)){break}if((ti|0)>=(Jb-wi|0)){break}xi=p+5312+(ri*12|0)+(oi<<2)|0;Se[c[xi>>2]&1023](Fe,cc,ui,cc,4,ni,qi);Se[c[xi>>2]&1023](rh,cc,vi,cc,4,ni,qi);break b}}while(0);vi=pi-(ca(ri,cc)|0)-oi|0;ui=(d[552680+ni|0]|0)+4|0;wi=(d[552680+qi|0]|0)+4|0;Nb=si-oi|0;Pb=ti-ri|0;Ve[c[zb>>2]&127](Ab,sh+vi|0,32,cc,ui,wi,Nb,Pb,Rb,bc);ce=(ri<<5)+oi+(q+(h*1536|0)+848)|0;xi=p+5312+(ri*12|0)+(oi<<2)|0;Se[c[xi>>2]&1023](Fe,cc,ce,32,4,ni,qi);Ve[c[zb>>2]&127](Ab,mi+vi|0,32,cc,ui,wi,Nb,Pb,Rb,bc);Se[c[xi>>2]&1023](rh,cc,ce,32,4,ni,qi)}}while(0);$f=$f+1|0;}while(($f|0)<2);wd=wd+1|0;}while((wd|0)<2);break};case 4:{wd=c[Gb+28>>2]|0;bc=wd&65535;Rb=wd>>>16&65535;Jb=c[B>>2]|0;lc=c[E>>2]|0;ac=Lb|0;xe=c[c[ac>>2]>>2]|0;if((wd|0)==0){M5a(Qb,O,0);Fd=xe+((ca(lc,D)|0)+ic)|0;Se[c[vb>>2]&1023](Jb,lc,Fd,lc,16,0,0)}else{Fd=wd<<1&6;jc=d[552672+Fd|0]|0;$f=b[Gb+30>>1]|0;dc=$f<<1&6;kc=d[552672+dc|0]|0;rc=(wd<<16>>18)+ic|0;wd=($f>>2)+D|0;$f=d[552688+dc|0]|0;M5a(Qb,wd+19+$f>>4,0);Ce=(ca(wd,lc)|0)+rc|0;He=xe+Ce|0;do{if((rc|0)<(jc|0)){Zh=439}else{if((rc|0)>=(Vb-16-(d[552688+Fd|0]|0)|0)|(wd|0)<(kc|0)){Zh=439;break}if((wd|0)<(ae-16-$f|0)){yi=He;zi=lc}else{Zh=439}}}while(0);if((Zh|0)==439){Zh=0;He=xe+(Ce-((ca(kc,lc)|0)+jc))|0;Ve[c[zb>>2]&127](Ab,He,32,lc,(d[552680+Fd|0]|0)+16|0,(d[552680+dc|0]|0)+16|0,rc-jc|0,wd-kc|0,Vb,ae);yi=(kc<<5)+jc+(q+(h*1536|0)+848)|0;zi=32}Se[c[p+5240+(kc*12|0)+(jc<<2)>>2]&1023](Jb,lc,yi,zi,16,Fd,dc)}if((a[wb]|0)==3){Ai=bc&-8;Bi=Rb&-8}else{Ai=bc;Bi=Rb}He=ic>>1;$f=Ob<<3;cc=Ub<<3;rh=c[G>>2]|0;mi=c[I>>2]|0;Fe=c[L>>2]|0;sh=c[ac>>2]|0;ii=c[sh+4>>2]|0;ji=c[sh+8>>2]|0;sh=Ai&65535;if(((Bi&65535)<<16|sh|0)==0){M5a(Qb,xb,0);Ge=(ca(mi,H)|0)+He|0;Se[c[yb>>2]&1023](rh,mi,ii+Ge|0,mi,8,0,0);Se[c[yb>>2]&1023](Fe,mi,ji+Ge|0,mi,8,0,0);break a}Ge=sh&7;Be=d[552672+Ge|0]|0;gc=Bi<<16>>16;De=gc&7;Hd=d[552672+De|0]|0;be=(sh<<16>>19)+He|0;He=(gc>>3)+H|0;gc=be+(ca(He,mi)|0)|0;sh=ii+gc|0;te=ji+gc|0;_f=d[552688+De|0]|0;M5a(Qb,He+11+_f>>3,0);do{if((be|0)>=(Be|0)){if((be|0)>=($f-8-(d[552688+Ge|0]|0)|0)|(He|0)<(Hd|0)){break}if((He|0)>=(cc-8-_f|0)){break}mc=p+5276+(Hd*12|0)+(Be<<2)|0;Se[c[mc>>2]&1023](rh,mi,sh,mi,8,Ge,De);Se[c[mc>>2]&1023](Fe,mi,te,mi,8,Ge,De);break a}}while(0);te=gc-(ca(Hd,mi)|0)-Be|0;sh=(d[552680+Ge|0]|0)+8|0;_f=(d[552680+De|0]|0)+8|0;ac=be-Be|0;Rb=He-Hd|0;Ve[c[zb>>2]&127](Ab,ii+te|0,32,mi,sh,_f,ac,Rb,$f,cc);bc=(Hd<<5)+Be+(q+(h*1536|0)+848)|0;dc=p+5276+(Hd*12|0)+(Be<<2)|0;Se[c[dc>>2]&1023](rh,mi,bc,32,8,Ge,De);Ve[c[zb>>2]&127](Ab,ji+te|0,32,mi,sh,_f,ac,Rb,$f,cc);Se[c[dc>>2]&1023](Fe,mi,bc,32,8,Ge,De);break a;break};case 0:{bc=c[Yb>>2]|0;dc=bc&65535;Rb=bc>>>16&65535;ac=c[B>>2]|0;_f=c[E>>2]|0;sh=Lb|0;te=c[c[sh>>2]>>2]|0;if((bc|0)==0){M5a(Qb,r,0);Fd=te+((ca(_f,D)|0)+ic)|0;Se[c[vb>>2]&1023](ac,_f,Fd,_f,8,0,0)}else{Fd=bc<<1&6;lc=d[552672+Fd|0]|0;Jb=b[Gb+34>>1]|0;jc=Jb<<1&6;kc=d[552672+jc|0]|0;wd=(bc<<16>>18)+ic|0;bc=(Jb>>2)+D|0;Jb=d[552688+jc|0]|0;M5a(Qb,bc+11+Jb>>4,0);rc=(ca(bc,_f)|0)+wd|0;Ce=te+rc|0;do{if((wd|0)<(lc|0)){Zh=478}else{if((wd|0)>=(Vb-16-(d[552688+Fd|0]|0)|0)|(bc|0)<(kc|0)){Zh=478;break}if((bc|0)<(ae-8-Jb|0)){Ci=Ce;Di=_f}else{Zh=478}}}while(0);if((Zh|0)==478){Zh=0;Ce=te+(rc-((ca(kc,_f)|0)+lc))|0;Ve[c[zb>>2]&127](Ab,Ce,32,_f,(d[552680+Fd|0]|0)+16|0,(d[552680+jc|0]|0)+8|0,wd-lc|0,bc-kc|0,Vb,ae);Ci=(kc<<5)+lc+(q+(h*1536|0)+848)|0;Di=32}Se[c[p+5240+(kc*12|0)+(lc<<2)>>2]&1023](ac,_f,Ci,Di,8,Fd,jc)}if((a[wb]|0)==3){Ei=dc&-8;Fi=Rb&-8}else{Ei=dc;Fi=Rb}Ce=ic>>1;Jb=Ob<<3;De=Ub<<3;Ge=c[G>>2]|0;mi=c[I>>2]|0;Fe=c[L>>2]|0;cc=c[sh>>2]|0;$f=c[cc+4>>2]|0;ji=c[cc+8>>2]|0;cc=Ei&65535;c:do{if(((Fi&65535)<<16|cc|0)==0){M5a(Qb,r,0);rh=(ca(mi,H)|0)+Ce|0;Se[c[yb>>2]&1023](Ge,mi,$f+rh|0,mi,4,0,0);Se[c[yb>>2]&1023](Fe,mi,ji+rh|0,mi,4,0,0)}else{rh=cc&7;Be=d[552672+rh|0]|0;Hd=Fi<<16>>16;ii=Hd&7;He=d[552672+ii|0]|0;be=(cc<<16>>19)+Ce|0;gc=(Hd>>3)+H|0;Hd=be+(ca(gc,mi)|0)|0;xe=$f+Hd|0;mc=ji+Hd|0;nc=d[552688+ii|0]|0;M5a(Qb,gc+7+nc>>3,0);do{if((be|0)>=(Be|0)){if((be|0)>=(Jb-8-(d[552688+rh|0]|0)|0)|(gc|0)<(He|0)){break}if((gc|0)>=(De-4-nc|0)){break}ce=p+5276+(He*12|0)+(Be<<2)|0;Se[c[ce>>2]&1023](Ge,mi,xe,mi,4,rh,ii);Se[c[ce>>2]&1023](Fe,mi,mc,mi,4,rh,ii);break c}}while(0);mc=Hd-(ca(He,mi)|0)-Be|0;xe=(d[552680+rh|0]|0)+8|0;nc=(d[552680+ii|0]|0)+4|0;ce=be-Be|0;xi=gc-He|0;Ve[c[zb>>2]&127](Ab,$f+mc|0,32,mi,xe,nc,ce,xi,Jb,De);Pb=(He<<5)+Be+(q+(h*1536|0)+848)|0;Nb=p+5276+(He*12|0)+(Be<<2)|0;Se[c[Nb>>2]&1023](Ge,mi,Pb,32,4,rh,ii);Ve[c[zb>>2]&127](Ab,ji+mc|0,32,mi,xe,nc,ce,xi,Jb,De);Se[c[Nb>>2]&1023](Fe,mi,Pb,32,4,rh,ii)}}while(0);mi=c[Gb+36>>2]|0;ji=mi&65535;$f=mi>>>16&65535;cc=c[E>>2]|0;Rb=ac+(cc<<3)|0;dc=c[c[sh>>2]>>2]|0;if((mi|0)==0){M5a(Qb,Cb,0);jc=dc+((ca(cc,f)|0)+ic)|0;Se[c[vb>>2]&1023](Rb,cc,jc,cc,8,0,0)}else{jc=mi<<1&6;Fd=d[552672+jc|0]|0;_f=b[Gb+38>>1]|0;lc=_f<<1&6;kc=d[552672+lc|0]|0;bc=(mi<<16>>18)+ic|0;mi=(_f>>2)+f|0;_f=d[552688+lc|0]|0;M5a(Qb,mi+11+_f>>4,0);wd=(ca(mi,cc)|0)+bc|0;rc=dc+wd|0;do{if((bc|0)<(Fd|0)){Zh=494}else{if((bc|0)>=(Vb-16-(d[552688+jc|0]|0)|0)|(mi|0)<(kc|0)){Zh=494;break}if((mi|0)<(ae-8-_f|0)){Gi=rc;Hi=cc}else{Zh=494}}}while(0);if((Zh|0)==494){Zh=0;rc=dc+(wd-((ca(kc,cc)|0)+Fd))|0;Ve[c[zb>>2]&127](Ab,rc,32,cc,(d[552680+jc|0]|0)+16|0,(d[552680+lc|0]|0)+8|0,bc-Fd|0,mi-kc|0,Vb,ae);Gi=(kc<<5)+Fd+(q+(h*1536|0)+848)|0;Hi=32}Se[c[p+5240+(kc*12|0)+(Fd<<2)>>2]&1023](Rb,cc,Gi,Hi,8,jc,lc)}if((a[wb]|0)==3){Ii=ji&-8;Ji=$f&-8}else{Ii=ji;Ji=$f}rc=c[I>>2]|0;_f=rc<<2;ac=Ge+_f|0;te=Fe+_f|0;_f=c[sh>>2]|0;Pb=c[_f+4>>2]|0;Nb=c[_f+8>>2]|0;_f=Ii&65535;if(((Ji&65535)<<16|_f|0)==0){M5a(Qb,Eb,0);xi=(ca(rc,Db)|0)+Ce|0;Se[c[yb>>2]&1023](ac,rc,Pb+xi|0,rc,4,0,0);Se[c[yb>>2]&1023](te,rc,Nb+xi|0,rc,4,0,0);break a}xi=_f&7;ce=d[552672+xi|0]|0;nc=Ji<<16>>16;xe=nc&7;mc=d[552672+xe|0]|0;wi=(_f<<16>>19)+Ce|0;_f=(nc>>3)+Db|0;nc=wi+(ca(_f,rc)|0)|0;ui=Pb+nc|0;vi=Nb+nc|0;Ki=d[552688+xe|0]|0;M5a(Qb,_f+7+Ki>>3,0);do{if((wi|0)>=(ce|0)){if((wi|0)>=(Jb-8-(d[552688+xi|0]|0)|0)|(_f|0)<(mc|0)){break}if((_f|0)>=(De-4-Ki|0)){break}Li=p+5276+(mc*12|0)+(ce<<2)|0;Se[c[Li>>2]&1023](ac,rc,ui,rc,4,xi,xe);Se[c[Li>>2]&1023](te,rc,vi,rc,4,xi,xe);break a}}while(0);vi=nc-(ca(mc,rc)|0)-ce|0;ui=(d[552680+xi|0]|0)+8|0;Ki=(d[552680+xe|0]|0)+4|0;Ce=wi-ce|0;sh=_f-mc|0;Ve[c[zb>>2]&127](Ab,Pb+vi|0,32,rc,ui,Ki,Ce,sh,Jb,De);Fe=(mc<<5)+ce+(q+(h*1536|0)+848)|0;Ge=p+5276+(mc*12|0)+(ce<<2)|0;Se[c[Ge>>2]&1023](ac,rc,Fe,32,4,xi,xe);Ve[c[zb>>2]&127](Ab,Nb+vi|0,32,rc,ui,Ki,Ce,sh,Jb,De);Se[c[Ge>>2]&1023](te,rc,Fe,32,4,xi,xe);break a;break};case 2:{Fe=c[Yb>>2]|0;Ge=Fe&65535;sh=Fe>>>16&65535;Ce=c[B>>2]|0;Ki=c[E>>2]|0;ui=Lb|0;vi=c[c[ui>>2]>>2]|0;if((Fe|0)==0){M5a(Qb,r,0);$f=vi+((ca(Ki,D)|0)+ic)|0;Se[c[yb>>2]&1023](Ce,Ki,$f,Ki,8,0,0)}else{$f=Fe<<1&6;ji=d[552672+$f|0]|0;lc=b[Gb+34>>1]|0;jc=lc<<1&6;cc=d[552672+jc|0]|0;Rb=(Fe<<16>>18)+ic|0;Fe=(lc>>2)+D|0;lc=d[552688+jc|0]|0;M5a(Qb,Fe+11+lc>>4,0);Fd=(ca(Fe,Ki)|0)+Rb|0;kc=vi+Fd|0;do{if((Rb|0)<(ji|0)){Zh=542}else{if((Rb|0)>=(Vb-8-(d[552688+$f|0]|0)|0)|(Fe|0)<(cc|0)){Zh=542;break}if((Fe|0)<(ae-8-lc|0)){Mi=kc;Ni=Ki}else{Zh=542}}}while(0);if((Zh|0)==542){Zh=0;kc=vi+(Fd-((ca(cc,Ki)|0)+ji))|0;Ve[c[zb>>2]&127](Ab,kc,32,Ki,(d[552680+$f|0]|0)+8|0,(d[552680+jc|0]|0)+8|0,Rb-ji|0,Fe-cc|0,Vb,ae);Mi=(cc<<5)+ji+(q+(h*1536|0)+848)|0;Ni=32}Se[c[p+5276+(cc*12|0)+(ji<<2)>>2]&1023](Ce,Ki,Mi,Ni,8,$f,jc)}if((a[wb]|0)==3){Oi=Ge&-8;Pi=sh&-8}else{Oi=Ge;Pi=sh}kc=ic>>1;lc=Ob<<3;xe=Ub<<3;xi=c[G>>2]|0;rc=c[I>>2]|0;te=c[L>>2]|0;De=c[ui>>2]|0;Jb=c[De+4>>2]|0;Nb=c[De+8>>2]|0;De=Oi&65535;d:do{if(((Pi&65535)<<16|De|0)==0){M5a(Qb,r,0);ac=(ca(rc,H)|0)+kc|0;Se[c[Bb>>2]&1023](xi,rc,Jb+ac|0,rc,4,0,0);Se[c[Bb>>2]&1023](te,rc,Nb+ac|0,rc,4,0,0)}else{ac=De&7;ce=d[552672+ac|0]|0;mc=Pi<<16>>16;Pb=mc&7;_f=d[552672+Pb|0]|0;wi=(De<<16>>19)+kc|0;nc=(mc>>3)+H|0;mc=wi+(ca(nc,rc)|0)|0;mi=Jb+mc|0;bc=Nb+mc|0;wd=d[552688+Pb|0]|0;M5a(Qb,nc+7+wd>>3,0);do{if((wi|0)>=(ce|0)){if((wi|0)>=(lc-4-(d[552688+ac|0]|0)|0)|(nc|0)<(_f|0)){break}if((nc|0)>=(xe-4-wd|0)){break}dc=p+5312+(_f*12|0)+(ce<<2)|0;Se[c[dc>>2]&1023](xi,rc,mi,rc,4,ac,Pb);Se[c[dc>>2]&1023](te,rc,bc,rc,4,ac,Pb);break d}}while(0);bc=mc-(ca(_f,rc)|0)-ce|0;mi=(d[552680+ac|0]|0)+4|0;wd=(d[552680+Pb|0]|0)+4|0;ii=wi-ce|0;rh=nc-_f|0;Ve[c[zb>>2]&127](Ab,Jb+bc|0,32,rc,mi,wd,ii,rh,lc,xe);Be=(_f<<5)+ce+(q+(h*1536|0)+848)|0;He=p+5312+(_f*12|0)+(ce<<2)|0;Se[c[He>>2]&1023](xi,rc,Be,32,4,ac,Pb);Ve[c[zb>>2]&127](Ab,Nb+bc|0,32,rc,mi,wd,ii,rh,lc,xe);Se[c[He>>2]&1023](te,rc,Be,32,4,ac,Pb)}}while(0);rc=c[Gb+36>>2]|0;Nb=rc&65535;Jb=rc>>>16&65535;De=c[E>>2]|0;sh=Ce+8|0;Ge=ic|8;jc=c[c[ui>>2]>>2]|0;if((rc|0)==0){M5a(Qb,r,0);$f=jc+((ca(De,D)|0)+Ge)|0;Se[c[yb>>2]&1023](sh,De,$f,De,8,0,0)}else{$f=rc<<1&6;Ki=d[552672+$f|0]|0;ji=b[Gb+38>>1]|0;cc=ji<<1&6;Fe=d[552672+cc|0]|0;Rb=(rc<<16>>18)+Ge|0;rc=(ji>>2)+D|0;ji=d[552688+cc|0]|0;M5a(Qb,rc+11+ji>>4,0);Fd=(ca(rc,De)|0)+Rb|0;vi=jc+Fd|0;do{if((Rb|0)<(Ki|0)){Zh=558}else{if((Rb|0)>=(Vb-8-(d[552688+$f|0]|0)|0)|(rc|0)<(Fe|0)){Zh=558;break}if((rc|0)<(ae-8-ji|0)){Qi=vi;Ri=De}else{Zh=558}}}while(0);if((Zh|0)==558){Zh=0;vi=jc+(Fd-((ca(Fe,De)|0)+Ki))|0;Ve[c[zb>>2]&127](Ab,vi,32,De,(d[552680+$f|0]|0)+8|0,(d[552680+cc|0]|0)+8|0,Rb-Ki|0,rc-Fe|0,Vb,ae);Qi=(Fe<<5)+Ki+(q+(h*1536|0)+848)|0;Ri=32}Se[c[p+5276+(Fe*12|0)+(Ki<<2)>>2]&1023](sh,De,Qi,Ri,8,$f,cc)}if((a[wb]|0)==3){Si=Nb&-8;Ti=Jb&-8}else{Si=Nb;Ti=Jb}vi=c[I>>2]|0;ji=xi+4|0;Be=te+4|0;He=kc|4;rh=c[ui>>2]|0;ii=c[rh+4>>2]|0;wd=c[rh+8>>2]|0;rh=Si&65535;e:do{if(((Ti&65535)<<16|rh|0)==0){M5a(Qb,r,0);mi=(ca(vi,H)|0)+He|0;Se[c[Bb>>2]&1023](ji,vi,ii+mi|0,vi,4,0,0);Se[c[Bb>>2]&1023](Be,vi,wd+mi|0,vi,4,0,0)}else{mi=rh&7;bc=d[552672+mi|0]|0;gc=Ti<<16>>16;be=gc&7;Hd=d[552672+be|0]|0;dc=(rh<<16>>19)+He|0;Li=(gc>>3)+H|0;gc=dc+(ca(Li,vi)|0)|0;Ui=ii+gc|0;Vi=wd+gc|0;Wi=d[552688+be|0]|0;M5a(Qb,Li+7+Wi>>3,0);do{if((dc|0)>=(bc|0)){if((dc|0)>=(lc-4-(d[552688+mi|0]|0)|0)|(Li|0)<(Hd|0)){break}if((Li|0)>=(xe-4-Wi|0)){break}Xi=p+5312+(Hd*12|0)+(bc<<2)|0;Se[c[Xi>>2]&1023](ji,vi,Ui,vi,4,mi,be);Se[c[Xi>>2]&1023](Be,vi,Vi,vi,4,mi,be);break e}}while(0);Vi=gc-(ca(Hd,vi)|0)-bc|0;Ui=(d[552680+mi|0]|0)+4|0;Wi=(d[552680+be|0]|0)+4|0;Pb=dc-bc|0;ac=Li-Hd|0;Ve[c[zb>>2]&127](Ab,ii+Vi|0,32,vi,Ui,Wi,Pb,ac,lc,xe);ce=(Hd<<5)+bc+(q+(h*1536|0)+848)|0;_f=p+5312+(Hd*12|0)+(bc<<2)|0;Se[c[_f>>2]&1023](ji,vi,ce,32,4,mi,be);Ve[c[zb>>2]&127](Ab,wd+Vi|0,32,vi,Ui,Wi,Pb,ac,lc,xe);Se[c[_f>>2]&1023](Be,vi,ce,32,4,mi,be)}}while(0);vi=c[Gb+40>>2]|0;Be=vi&65535;wd=vi>>>16&65535;ji=c[E>>2]|0;ii=Ce+(ji<<3)|0;rh=c[c[ui>>2]>>2]|0;if((vi|0)==0){M5a(Qb,Cb,0);Jb=rh+((ca(ji,f)|0)+ic)|0;Se[c[yb>>2]&1023](ii,ji,Jb,ji,8,0,0)}else{Jb=vi<<1&6;Nb=d[552672+Jb|0]|0;cc=b[Gb+42>>1]|0;$f=cc<<1&6;De=d[552672+$f|0]|0;sh=(vi<<16>>18)+ic|0;vi=(cc>>2)+f|0;cc=d[552688+$f|0]|0;M5a(Qb,vi+11+cc>>4,0);Ki=(ca(vi,ji)|0)+sh|0;Fe=rh+Ki|0;do{if((sh|0)<(Nb|0)){Zh=574}else{if((sh|0)>=(Vb-8-(d[552688+Jb|0]|0)|0)|(vi|0)<(De|0)){Zh=574;break}if((vi|0)<(ae-8-cc|0)){Yi=Fe;Zi=ji}else{Zh=574}}}while(0);if((Zh|0)==574){Zh=0;Fe=rh+(Ki-((ca(De,ji)|0)+Nb))|0;Ve[c[zb>>2]&127](Ab,Fe,32,ji,(d[552680+Jb|0]|0)+8|0,(d[552680+$f|0]|0)+8|0,sh-Nb|0,vi-De|0,Vb,ae);Yi=(De<<5)+Nb+(q+(h*1536|0)+848)|0;Zi=32}Se[c[p+5276+(De*12|0)+(Nb<<2)>>2]&1023](ii,ji,Yi,Zi,8,Jb,$f)}if((a[wb]|0)==3){_i=Be&-8;$i=wd&-8}else{_i=Be;$i=wd}Fe=c[I>>2]|0;cc=Fe<<2;rc=xi+cc|0;Rb=te+cc|0;cc=c[ui>>2]|0;Fd=c[cc+4>>2]|0;jc=c[cc+8>>2]|0;cc=_i&65535;f:do{if((($i&65535)<<16|cc|0)==0){M5a(Qb,Eb,0);ce=(ca(Fe,Db)|0)+kc|0;Se[c[Bb>>2]&1023](rc,Fe,Fd+ce|0,Fe,4,0,0);Se[c[Bb>>2]&1023](Rb,Fe,jc+ce|0,Fe,4,0,0)}else{ce=cc&7;_f=d[552672+ce|0]|0;ac=$i<<16>>16;Pb=ac&7;Wi=d[552672+Pb|0]|0;Ui=(cc<<16>>19)+kc|0;Vi=(ac>>3)+Db|0;ac=Ui+(ca(Vi,Fe)|0)|0;nc=Fd+ac|0;wi=jc+ac|0;mc=d[552688+Pb|0]|0;M5a(Qb,Vi+7+mc>>3,0);do{if((Ui|0)>=(_f|0)){if((Ui|0)>=(lc-4-(d[552688+ce|0]|0)|0)|(Vi|0)<(Wi|0)){break}if((Vi|0)>=(xe-4-mc|0)){break}Xi=p+5312+(Wi*12|0)+(_f<<2)|0;Se[c[Xi>>2]&1023](rc,Fe,nc,Fe,4,ce,Pb);Se[c[Xi>>2]&1023](Rb,Fe,wi,Fe,4,ce,Pb);break f}}while(0);wi=ac-(ca(Wi,Fe)|0)-_f|0;nc=(d[552680+ce|0]|0)+4|0;mc=(d[552680+Pb|0]|0)+4|0;be=Ui-_f|0;mi=Vi-Wi|0;Ve[c[zb>>2]&127](Ab,Fd+wi|0,32,Fe,nc,mc,be,mi,lc,xe);bc=(Wi<<5)+_f+(q+(h*1536|0)+848)|0;Hd=p+5312+(Wi*12|0)+(_f<<2)|0;Se[c[Hd>>2]&1023](rc,Fe,bc,32,4,ce,Pb);Ve[c[zb>>2]&127](Ab,jc+wi|0,32,Fe,nc,mc,be,mi,lc,xe);Se[c[Hd>>2]&1023](Rb,Fe,bc,32,4,ce,Pb)}}while(0);Fe=c[Gb+44>>2]|0;Rb=Fe&65535;jc=Fe>>>16&65535;rc=c[E>>2]|0;Fd=Ce+((rc<<3)+8)|0;kc=c[c[ui>>2]>>2]|0;if((Fe|0)==0){M5a(Qb,Cb,0);cc=kc+((ca(rc,f)|0)+Ge)|0;Se[c[yb>>2]&1023](Fd,rc,cc,rc,8,0,0)}else{cc=Fe<<1&6;wd=d[552672+cc|0]|0;Be=b[Gb+46>>1]|0;$f=Be<<1&6;Jb=d[552672+$f|0]|0;ji=(Fe<<16>>18)+Ge|0;Fe=(Be>>2)+f|0;Be=d[552688+$f|0]|0;M5a(Qb,Fe+11+Be>>4,0);ii=(ca(Fe,rc)|0)+ji|0;Nb=kc+ii|0;do{if((ji|0)<(wd|0)){Zh=590}else{if((ji|0)>=(Vb-8-(d[552688+cc|0]|0)|0)|(Fe|0)<(Jb|0)){Zh=590;break}if((Fe|0)<(ae-8-Be|0)){aj=Nb;bj=rc}else{Zh=590}}}while(0);if((Zh|0)==590){Zh=0;Nb=kc+(ii-((ca(Jb,rc)|0)+wd))|0;Ve[c[zb>>2]&127](Ab,Nb,32,rc,(d[552680+cc|0]|0)+8|0,(d[552680+$f|0]|0)+8|0,ji-wd|0,Fe-Jb|0,Vb,ae);aj=(Jb<<5)+wd+(q+(h*1536|0)+848)|0;bj=32}Se[c[p+5276+(Jb*12|0)+(wd<<2)>>2]&1023](Fd,rc,aj,bj,8,cc,$f)}if((a[wb]|0)==3){cj=Rb&-8;dj=jc&-8}else{cj=Rb;dj=jc}Nb=c[I>>2]|0;Be=(Nb<<2)+4|0;Ge=xi+Be|0;Ce=te+Be|0;Be=c[ui>>2]|0;De=c[Be+4>>2]|0;vi=c[Be+8>>2]|0;Be=cj&65535;if(((dj&65535)<<16|Be|0)==0){M5a(Qb,Eb,0);sh=(ca(Nb,Db)|0)+He|0;Se[c[Bb>>2]&1023](Ge,Nb,De+sh|0,Nb,4,0,0);Se[c[Bb>>2]&1023](Ce,Nb,vi+sh|0,Nb,4,0,0);break a}sh=Be&7;Ki=d[552672+sh|0]|0;rh=dj<<16>>16;bc=rh&7;Hd=d[552672+bc|0]|0;mi=(Be<<16>>19)+He|0;Be=(rh>>3)+Db|0;rh=mi+(ca(Be,Nb)|0)|0;be=De+rh|0;mc=vi+rh|0;nc=d[552688+bc|0]|0;M5a(Qb,Be+7+nc>>3,0);do{if((mi|0)>=(Ki|0)){if((mi|0)>=(lc-4-(d[552688+sh|0]|0)|0)|(Be|0)<(Hd|0)){break}if((Be|0)>=(xe-4-nc|0)){break}wi=p+5312+(Hd*12|0)+(Ki<<2)|0;Se[c[wi>>2]&1023](Ge,Nb,be,Nb,4,sh,bc);Se[c[wi>>2]&1023](Ce,Nb,mc,Nb,4,sh,bc);break a}}while(0);mc=rh-(ca(Hd,Nb)|0)-Ki|0;be=(d[552680+sh|0]|0)+4|0;nc=(d[552680+bc|0]|0)+4|0;He=mi-Ki|0;ui=Be-Hd|0;Ve[c[zb>>2]&127](Ab,De+mc|0,32,Nb,be,nc,He,ui,lc,xe);te=(Hd<<5)+Ki+(q+(h*1536|0)+848)|0;xi=p+5312+(Hd*12|0)+(Ki<<2)|0;Se[c[xi>>2]&1023](Ge,Nb,te,32,4,sh,bc);Ve[c[zb>>2]&127](Ab,vi+mc|0,32,Nb,be,nc,He,ui,lc,xe);Se[c[xi>>2]&1023](Ce,Nb,te,32,4,sh,bc);break a;break};case 1:{te=c[Yb>>2]|0;xi=te&65535;ui=te>>>16&65535;He=c[B>>2]|0;nc=c[E>>2]|0;be=Lb|0;mc=c[c[be>>2]>>2]|0;if((te|0)==0){M5a(Qb,O,0);jc=mc+((ca(nc,D)|0)+ic)|0;Se[c[yb>>2]&1023](He,nc,jc,nc,16,0,0)}else{jc=te<<1&6;Rb=d[552672+jc|0]|0;$f=b[Gb+34>>1]|0;cc=$f<<1&6;rc=d[552672+cc|0]|0;Fd=(te<<16>>18)+ic|0;te=($f>>2)+D|0;$f=d[552688+cc|0]|0;M5a(Qb,te+19+$f>>4,0);wd=(ca(te,nc)|0)+Fd|0;Jb=mc+wd|0;do{if((Fd|0)<(Rb|0)){Zh=510}else{if((Fd|0)>=(Vb-8-(d[552688+jc|0]|0)|0)|(te|0)<(rc|0)){Zh=510;break}if((te|0)<(ae-16-$f|0)){ej=Jb;fj=nc}else{Zh=510}}}while(0);if((Zh|0)==510){Zh=0;Jb=mc+(wd-((ca(rc,nc)|0)+Rb))|0;Ve[c[zb>>2]&127](Ab,Jb,32,nc,(d[552680+jc|0]|0)+8|0,(d[552680+cc|0]|0)+16|0,Fd-Rb|0,te-rc|0,Vb,ae);ej=(rc<<5)+Rb+(q+(h*1536|0)+848)|0;fj=32}Se[c[p+5276+(rc*12|0)+(Rb<<2)>>2]&1023](He,nc,ej,fj,16,jc,cc)}if((a[wb]|0)==3){gj=xi&-8;hj=ui&-8}else{gj=xi;hj=ui}Jb=ic>>1;$f=Ob<<3;Lb=Ub<<3;Yb=c[G>>2]|0;bc=c[I>>2]|0;sh=c[L>>2]|0;Nb=c[be>>2]|0;Ce=c[Nb+4>>2]|0;xe=c[Nb+8>>2]|0;Nb=gj&65535;g:do{if(((hj&65535)<<16|Nb|0)==0){M5a(Qb,xb,0);lc=(ca(bc,H)|0)+Jb|0;Se[c[Bb>>2]&1023](Yb,bc,Ce+lc|0,bc,8,0,0);Se[c[Bb>>2]&1023](sh,bc,xe+lc|0,bc,8,0,0)}else{lc=Nb&7;vi=d[552672+lc|0]|0;Ge=hj<<16>>16;Ki=Ge&7;Hd=d[552672+Ki|0]|0;De=(Nb<<16>>19)+Jb|0;Be=(Ge>>3)+H|0;Ge=De+(ca(Be,bc)|0)|0;mi=Ce+Ge|0;rh=xe+Ge|0;Fe=d[552688+Ki|0]|0;M5a(Qb,Be+11+Fe>>3,0);do{if((De|0)>=(vi|0)){if((De|0)>=($f-4-(d[552688+lc|0]|0)|0)|(Be|0)<(Hd|0)){break}if((Be|0)>=(Lb-8-Fe|0)){break}ji=p+5312+(Hd*12|0)+(vi<<2)|0;Se[c[ji>>2]&1023](Yb,bc,mi,bc,8,lc,Ki);Se[c[ji>>2]&1023](sh,bc,rh,bc,8,lc,Ki);break g}}while(0);rh=Ge-(ca(Hd,bc)|0)-vi|0;mi=(d[552680+lc|0]|0)+4|0;Fe=(d[552680+Ki|0]|0)+8|0;Pb=De-vi|0;ce=Be-Hd|0;Ve[c[zb>>2]&127](Ab,Ce+rh|0,32,bc,mi,Fe,Pb,ce,$f,Lb);_f=(Hd<<5)+vi+(q+(h*1536|0)+848)|0;Wi=p+5312+(Hd*12|0)+(vi<<2)|0;Se[c[Wi>>2]&1023](Yb,bc,_f,32,8,lc,Ki);Ve[c[zb>>2]&127](Ab,xe+rh|0,32,bc,mi,Fe,Pb,ce,$f,Lb);Se[c[Wi>>2]&1023](sh,bc,_f,32,8,lc,Ki)}}while(0);bc=c[Gb+36>>2]|0;xe=bc&65535;Ce=bc>>>16&65535;Nb=c[E>>2]|0;Ub=He+8|0;Ob=ic|8;ui=c[c[be>>2]>>2]|0;if((bc|0)==0){M5a(Qb,O,0);xi=ui+((ca(Nb,D)|0)+Ob)|0;Se[c[yb>>2]&1023](Ub,Nb,xi,Nb,16,0,0)}else{xi=bc<<1&6;cc=d[552672+xi|0]|0;jc=b[Gb+38>>1]|0;nc=jc<<1&6;Rb=d[552672+nc|0]|0;rc=(bc<<16>>18)+Ob|0;Ob=(jc>>2)+D|0;jc=d[552688+nc|0]|0;M5a(Qb,Ob+19+jc>>4,0);bc=(ca(Ob,Nb)|0)+rc|0;te=ui+bc|0;do{if((rc|0)<(cc|0)){Zh=526}else{if((rc|0)>=(Vb-8-(d[552688+xi|0]|0)|0)|(Ob|0)<(Rb|0)){Zh=526;break}if((Ob|0)<(ae-16-jc|0)){ij=te;jj=Nb}else{Zh=526}}}while(0);if((Zh|0)==526){Zh=0;te=ui+(bc-((ca(Rb,Nb)|0)+cc))|0;Ve[c[zb>>2]&127](Ab,te,32,Nb,(d[552680+xi|0]|0)+8|0,(d[552680+nc|0]|0)+16|0,rc-cc|0,Ob-Rb|0,Vb,ae);ij=(Rb<<5)+cc+(q+(h*1536|0)+848)|0;jj=32}Se[c[p+5276+(Rb*12|0)+(cc<<2)>>2]&1023](Ub,Nb,ij,jj,16,xi,nc)}if((a[wb]|0)==3){kj=xe&-8;lj=Ce&-8}else{kj=xe;lj=Ce}te=c[I>>2]|0;jc=Yb+4|0;ic=sh+4|0;He=Jb|4;Fd=c[be>>2]|0;wd=c[Fd+4>>2]|0;mc=c[Fd+8>>2]|0;Fd=kj&65535;if(((lj&65535)<<16|Fd|0)==0){M5a(Qb,xb,0);_f=(ca(te,H)|0)+He|0;Se[c[Bb>>2]&1023](jc,te,wd+_f|0,te,8,0,0);Se[c[Bb>>2]&1023](ic,te,mc+_f|0,te,8,0,0);break a}_f=Fd&7;Wi=d[552672+_f|0]|0;ce=lj<<16>>16;Pb=ce&7;Fe=d[552672+Pb|0]|0;mi=(Fd<<16>>19)+He|0;He=(ce>>3)+H|0;ce=mi+(ca(He,te)|0)|0;Fd=wd+ce|0;rh=mc+ce|0;Vi=d[552688+Pb|0]|0;M5a(Qb,He+11+Vi>>3,0);do{if((mi|0)>=(Wi|0)){if((mi|0)>=($f-4-(d[552688+_f|0]|0)|0)|(He|0)<(Fe|0)){break}if((He|0)>=(Lb-8-Vi|0)){break}Ui=p+5312+(Fe*12|0)+(Wi<<2)|0;Se[c[Ui>>2]&1023](jc,te,Fd,te,8,_f,Pb);Se[c[Ui>>2]&1023](ic,te,rh,te,8,_f,Pb);break a}}while(0);rh=ce-(ca(Fe,te)|0)-Wi|0;Fd=(d[552680+_f|0]|0)+4|0;Vi=(d[552680+Pb|0]|0)+8|0;Qb=mi-Wi|0;be=He-Fe|0;Ve[c[zb>>2]&127](Ab,wd+rh|0,32,te,Fd,Vi,Qb,be,$f,Lb);Jb=(Fe<<5)+Wi+(q+(h*1536|0)+848)|0;sh=p+5312+(Fe*12|0)+(Wi<<2)|0;Se[c[sh>>2]&1023](jc,te,Jb,32,8,_f,Pb);Ve[c[zb>>2]&127](Ab,mc+rh|0,32,te,Fd,Vi,Qb,be,$f,Lb);Se[c[sh>>2]&1023](ic,te,Jb,32,8,_f,Pb);break a;break};default:{break a}}}}while(0);if((c[ib>>2]|0)>(M|0)){Jb=(b[Gb+28>>1]>>2)+(u<<4|8)|0;sh=(b[Gb+30>>1]>>2)+D|0;be=c[c[jb>>2]>>2]|0;Qb=c[E>>2]|0;Vi=Jb+64+(ca(sh+Hb|0,Qb)|0)|0;ef[c[P>>2]&4095]((c[be>>2]|0)+Vi|0,Qb,4);Qb=(Jb>>1)+64+(ca(c[I>>2]|0,(sh>>1)+Ib|0)|0)|0;sh=c[be+4>>2]|0;ef[c[P>>2]&4095](sh+Qb|0,(c[be+8>>2]|0)-sh|0,2)}do{if((a[oc]|0)==0){if((a[Rh]|0)==4){mj=0}else{sh=0;be=c[B>>2]|0;while(1){Qb=q+(h*1536|0)+800+(sh<<2)|0;Jb=d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0;h:do{if((Jb|0)!=0){if((Jb&-16843010|0)==0){ef[c[lb>>2]&4095](be,q+(h*1536|0)+(sh<<7)|0,c[E>>2]|0);break}else{nj=Jb;oj=0}while(1){if((oj|0)>=4){break h}Qb=nj&255;do{if((Qb|0)==1){ef[c[Ya>>2]&4095](be+(oj<<2)|0,q+(h*1536|0)+(sh<<7)+(oj<<5)|0,c[E>>2]|0)}else{if(!(Qb>>>0>1>>>0)){break}ef[c[Xa>>2]&4095](be+(oj<<2)|0,q+(h*1536|0)+(sh<<7)+(oj<<5)|0,c[E>>2]|0)}}while(0);Qb=nj>>>8;if((Qb|0)==0){break}else{nj=Qb;oj=oj+1|0}}}}while(0);Jb=sh+1|0;if((Jb|0)<4){sh=Jb;be=be+(c[E>>2]<<2)|0}else{mj=0;break}}}do{be=mj+4|0;sh=q+(h*1536|0)+800+(be<<2)|0;Pb=d[sh]|d[sh+1|0]<<8|d[sh+2|0]<<16|d[sh+3|0]<<24|0;mj=mj+1|0;i:do{if((Pb|0)!=0){sh=c[o+(mj<<2)>>2]|0;if((Pb&-16843010|0)==0){ef[c[kb>>2]&4095](sh,q+(h*1536|0)+(be<<7)|0,c[I>>2]|0);break}else{pj=Pb;qj=0}while(1){if((qj|0)>=2){break}_f=pj&255;do{if((_f|0)==1){ef[c[Ya>>2]&4095](sh+(qj<<2)|0,q+(h*1536|0)+(be<<7)+(qj<<5)|0,c[I>>2]|0)}else{if(!(_f>>>0>1>>>0)){break}ef[c[Xa>>2]&4095](sh+(qj<<2)|0,q+(h*1536|0)+(be<<7)+(qj<<5)|0,c[I>>2]|0)}}while(0);_f=pj>>>8;if((_f|0)==0){break i}else{pj=_f;qj=qj+1|0}}_f=c[I>>2]<<2;te=pj;ic=0;while(1){if((ic|0)>=2){break i}Lb=te&255;do{if((Lb|0)==1){ef[c[Ya>>2]&4095](sh+((ic<<2)+_f)|0,q+(h*1536|0)+(be<<7)+(ic+2<<5)|0,c[I>>2]|0)}else{if(!(Lb>>>0>1>>>0)){break}ef[c[Xa>>2]&4095](sh+((ic<<2)+_f)|0,q+(h*1536|0)+(be<<7)+(ic+2<<5)|0,c[I>>2]|0)}}while(0);Lb=te>>>8;if((Lb|0)==0){break}else{te=Lb;ic=ic+1|0}}}}while(0);}while((mj|0)<2)}else{c[ub>>2]=0;c[ub+4>>2]=0;be=(c[Ba>>2]|0)+(u*9|0)|0;Pb=be|0;y=0;a[Pb]=y;y=y>>8;a[Pb+1|0]=y;y=y>>8;a[Pb+2|0]=y;y=y>>8;a[Pb+3|0]=y;Pb=be+4|0;y=0;a[Pb]=y;y=y>>8;a[Pb+1|0]=y;y=y>>8;a[Pb+2|0]=y;y=y>>8;a[Pb+3|0]=y;Pb=a[Rh]|0;if((Pb<<24>>24|0)==4|(Pb<<24>>24|0)==7){break}a[Ca]=0;a[(c[Ba>>2]|0)+(u*9|0)+8|0]=0}}while(0);do{if((a[Na]|0)!=0){Pb=c[pb>>2]|0;do{if((a[V]|0)==0){rj=d[qb]|0}else{be=a[(d[Gb+5|0]|0)+(p+95)|0]|0;if((a[tb]|0)!=0){rj=be;break}rj=(d[qb]|0)+be|0}}while(0);if((a[rb]|0)==0){sj=rj}else{sj=(a[(d[Gb+2|0]|0)+(p+173)|0]|0)+rj+(a[(d[Rh]|0)+(p+165)|0]|0)|0}if(sj>>>0<64>>>0){tj=sj}else{tj=-sj>>31&63}be=a[sb]|0;if(be<<24>>24==0){uj=tj}else{ic=be&255;be=tj>>((ic+3|0)>>>2);te=9-ic|0;uj=(be|0)>(te|0)?te:be}a[Pb+(u*3|0)|0]=tj;a[Pb+(u*3|0)+1|0]=(uj|0)>1?uj&255:1;do{if((a[oc]|0)==0){vj=1}else{be=a[Rh]|0;if(be<<24>>24==4){vj=1;break}vj=be<<24>>24==7|0}}while(0);a[Pb+(u*3|0)+2|0]=vj;if(!(mb&(a[Na]|0)!=0&nb)){break}be=u+1|0;te=c[Pa>>2]|0;ic=te+(be<<5)|0;_f=c[B>>2]|0;if((a[Qa]|0)==0){sh=c[G>>2]|0;Lb=c[L>>2]|0;$f=c[I>>2]|0;mc=(c[E>>2]|0)*15|0;jc=_f+mc|0;Wi=c[jc+4>>2]|0;Fe=ic;c[Fe>>2]=c[jc>>2];c[Fe+4>>2]=Wi;Wi=_f+(mc+8)|0;mc=c[Wi+4>>2]|0;Fe=te+(be<<5)+8|0;c[Fe>>2]=c[Wi>>2];c[Fe+4>>2]=mc;mc=$f*7|0;$f=sh+mc|0;sh=c[$f+4>>2]|0;Fe=te+(be<<5)+16|0;c[Fe>>2]=c[$f>>2];c[Fe+4>>2]=sh;sh=Lb+mc|0;mc=c[sh+4>>2]|0;Lb=te+(be<<5)+24|0;c[Lb>>2]=c[sh>>2];c[Lb+4>>2]=mc;break}else{mc=(c[E>>2]|0)*15|0;Lb=_f+mc|0;sh=c[Lb+4>>2]|0;Fe=ic;c[Fe>>2]=c[Lb>>2];c[Fe+4>>2]=sh;sh=_f+(mc+8)|0;mc=c[sh+4>>2]|0;_f=te+(be<<5)+8|0;c[_f>>2]=c[sh>>2];c[_f+4>>2]=mc;break}}}while(0);if((c[v>>2]|0)>(M|0)){oc=(b[Gb+28>>1]>>2)+(u<<4|8)|0;mc=(b[Gb+30>>1]>>2)+D|0;_f=c[c[ob>>2]>>2]|0;sh=c[E>>2]|0;be=oc+64+(ca(mc+Hb|0,sh)|0)|0;ef[c[P>>2]&4095]((c[_f>>2]|0)+be|0,sh,4);sh=(oc>>1)+64+(ca(c[I>>2]|0,(mc>>1)+Ib|0)|0)|0;mc=c[_f+4>>2]|0;ef[c[P>>2]&4095](mc+sh|0,(c[_f+8>>2]|0)-mc|0,2)}mc=(c[B>>2]|0)+16|0;c[B>>2]=mc;_f=(c[G>>2]|0)+8|0;c[G>>2]=_f;sh=(c[L>>2]|0)+8|0;c[L>>2]=sh;b[t>>1]=(b[t>>1]|0)-64;b[Q>>1]=(b[Q>>1]|0)-64;oc=u+1|0;if((oc|0)>=(e[s>>1]|0)){break}Fb=Fb+1|0;u=oc;Gb=Gb+96|0;N=mc;F=_f;K=sh}i=g;return}function oab(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0;f=d[e]|0;g=b|0;h=c[g>>2]|0;i=d[1252840+h|0]|0;j=b+4|0;k=c[j>>2]|0;l=b+16|0;m=c[l>>2]|0;n=h<<i;c[g>>2]=n;h=m<<i;m=k+i|0;do{if((m|0)>-1){i=b+8|0;k=c[i>>2]|0;if(!(k>>>0<(c[b+12>>2]|0)>>>0)){o=h;p=m;break}c[i>>2]=k+2;i=k;o=((he((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535)<<m|h;p=m-16|0}else{o=h;p=m}}while(0);c[j>>2]=p;m=((ca(n-1|0,f)|0)>>8)+1|0;f=m<<16;do{if(o>>>0<f>>>0){c[g>>2]=m;c[l>>2]=o;h=a[e+2|0]|0;i=d[1252840+m|0]|0;k=m<<i;c[g>>2]=k;q=o<<i;r=p+i|0;do{if((r|0)>-1){i=b+8|0;s=c[i>>2]|0;if(!(s>>>0<(c[b+12>>2]|0)>>>0)){t=q;u=r;break}c[i>>2]=s+2;i=s;t=((he((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535)<<r|q;u=r-16|0}else{t=q;u=r}}while(0);c[j>>2]=u;r=((ca(k-1|0,h&255)|0)>>8)+1|0;q=r<<16;i=t>>>0>=q>>>0;s=i&1;v=i?k-r|0:r;c[g>>2]=v;r=t-(i?q:0)|0;c[l>>2]=r;q=(-s&3)+3|0;i=s<<2;s=a[e+q|0]|0;w=d[1252840+v|0]|0;x=v<<w;c[g>>2]=x;v=r<<w;r=u+w|0;do{if((r|0)>-1){w=b+8|0;y=c[w>>2]|0;if(!(y>>>0<(c[b+12>>2]|0)>>>0)){z=v;A=r;break}c[w>>2]=y+2;w=y;z=((he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<r|v;A=r-16|0}else{z=v;A=r}}while(0);c[j>>2]=A;r=((ca(x-1|0,s&255)|0)>>8)+1|0;v=r<<16;k=z>>>0>=v>>>0;h=k?x-r|0:r;c[g>>2]=h;r=z-(k?v:0)|0;c[l>>2]=r;v=(k&1)<<1|i;w=a[e+((k?2:1)+q)|0]|0;k=d[1252840+h|0]|0;y=h<<k;c[g>>2]=y;h=r<<k;r=A+k|0;do{if((r|0)>-1){k=b+8|0;B=c[k>>2]|0;if(!(B>>>0<(c[b+12>>2]|0)>>>0)){C=h;D=r;break}c[k>>2]=B+2;k=B;C=((he((d[k]|d[k+1|0]<<8)<<16>>16|0)|0)&65535)<<r|h;D=r-16|0}else{C=h;D=r}}while(0);c[j>>2]=D;r=((ca(y-1|0,w&255)|0)>>8)+1|0;h=r<<16;q=C>>>0>=h>>>0;i=q?y-r|0:r;c[g>>2]=i;r=C-(q?h:0)|0;c[l>>2]=r;E=v|q&1;F=i;G=D;H=r}else{r=n-m|0;c[g>>2]=r;i=o-f|0;c[l>>2]=i;q=b+8|0;h=b+12|0;x=a[e+9|0]|0;s=d[1252840+r|0]|0;k=r<<s;c[g>>2]=k;r=i<<s;i=p+s|0;do{if((i|0)>-1){s=c[q>>2]|0;if(!(s>>>0<(c[h>>2]|0)>>>0)){I=r;J=i;break}c[q>>2]=s+2;B=s;I=((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)<<i|r;J=i-16|0}else{I=r;J=i}}while(0);c[j>>2]=J;i=((ca(k-1|0,x&255)|0)>>8)+1|0;r=i<<16;v=I>>>0>=r>>>0;y=v&1;w=v?k-i|0:i;c[g>>2]=w;i=I-(v?r:0)|0;c[l>>2]=i;r=a[e+10|0]|0;v=d[1252840+w|0]|0;B=w<<v;c[g>>2]=B;w=i<<v;i=J+v|0;do{if((i|0)>-1){v=c[q>>2]|0;if(!(v>>>0<(c[h>>2]|0)>>>0)){K=w;L=i;break}c[q>>2]=v+2;s=v;K=((he((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<i|w;L=i-16|0}else{K=w;L=i}}while(0);c[j>>2]=L;i=((ca(B-1|0,r&255)|0)>>8)+1|0;w=i<<16;k=K>>>0>=w>>>0;x=k?B-i|0:i;c[g>>2]=x;i=K-(k?w:0)|0;c[l>>2]=i;w=(k&1)<<1|y;k=a[e+11|0]|0;s=d[1252840+x|0]|0;v=x<<s;c[g>>2]=v;x=i<<s;i=L+s|0;do{if((i|0)>-1){s=c[q>>2]|0;if(!(s>>>0<(c[h>>2]|0)>>>0)){M=x;N=i;break}c[q>>2]=s+2;O=s;M=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<i|x;N=i-16|0}else{M=x;N=i}}while(0);c[j>>2]=N;i=((ca(v-1|0,k&255)|0)>>8)+1|0;x=i<<16;y=M>>>0>=x>>>0;B=y?v-i|0:i;c[g>>2]=B;i=M-(y?x:0)|0;c[l>>2]=i;x=9;r=(y&1)<<2|w;y=B;B=N;O=i;while(1){i=a[e+(x+9)|0]|0;s=d[1252840+y|0]|0;P=y<<s;c[g>>2]=P;Q=O<<s;R=B+s|0;do{if((R|0)>-1){s=c[q>>2]|0;if(!(s>>>0<(c[h>>2]|0)>>>0)){S=Q;T=R;break}c[q>>2]=s+2;U=s;S=((he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)<<R|Q;T=R-16|0}else{S=Q;T=R}}while(0);c[j>>2]=T;R=((ca(P-1|0,i&255)|0)>>8)+1|0;Q=R<<16;U=S>>>0>=Q>>>0;V=U?P-R|0:R;c[g>>2]=V;W=S-(U?Q:0)|0;c[l>>2]=W;X=((U&1)<<x)+r|0;U=x-1|0;if((U|0)>3){x=U;r=X;y=V;B=T;O=W}else{break}}if((X&65520|0)==0){Y=V;Z=T;_=W}else{O=a[e+12|0]|0;B=d[1252840+V|0]|0;y=V<<B;c[g>>2]=y;r=W<<B;x=T+B|0;do{if((x|0)>-1){B=c[q>>2]|0;if(!(B>>>0<(c[h>>2]|0)>>>0)){$=r;aa=x;break}c[q>>2]=B+2;w=B;$=((he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<x|r;aa=x-16|0}else{$=r;aa=x}}while(0);c[j>>2]=aa;x=((ca(y-1|0,O&255)|0)>>8)+1|0;r=x<<16;q=$>>>0>=r>>>0;h=q?y-x|0:x;c[g>>2]=h;x=$-(q?r:0)|0;c[l>>2]=x;if(q){Y=h;Z=aa;_=x}else{E=X;F=h;G=aa;H=x;break}}E=X+8|0;F=Y;G=Z;H=_}}while(0);if((E|0)==0){return 0}_=a[e+1|0]|0;e=d[1252840+F|0]|0;Z=F<<e;c[g>>2]=Z;F=H<<e;H=G+e|0;if(!((H|0)>-1)){ba=F;da=H;c[j>>2]=da;ea=Z-1|0;fa=_&255;ga=ca(ea,fa)|0;ha=ga>>8;ia=ha+1|0;ja=ia<<16;ka=ba>>>0>=ja>>>0;la=Z-ia|0;ma=ka?la:ia;c[g>>2]=ma;na=ka?ja:0;oa=ba-na|0;c[l>>2]=oa;pa=-E|0;qa=ka?pa:E;return qa|0}e=b+8|0;G=c[e>>2]|0;if(!(G>>>0<(c[b+12>>2]|0)>>>0)){ba=F;da=H;c[j>>2]=da;ea=Z-1|0;fa=_&255;ga=ca(ea,fa)|0;ha=ga>>8;ia=ha+1|0;ja=ia<<16;ka=ba>>>0>=ja>>>0;la=Z-ia|0;ma=ka?la:ia;c[g>>2]=ma;na=ka?ja:0;oa=ba-na|0;c[l>>2]=oa;pa=-E|0;qa=ka?pa:E;return qa|0}c[e>>2]=G+2;e=G;ba=((he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535)<<H|F;da=H-16|0;c[j>>2]=da;ea=Z-1|0;fa=_&255;ga=ca(ea,fa)|0;ha=ga>>8;ia=ha+1|0;ja=ia<<16;ka=ba>>>0>=ja>>>0;la=Z-ia|0;ma=ka?la:ia;c[g>>2]=ma;na=ka?ja:0;oa=ba-na|0;c[l>>2]=oa;pa=-E|0;qa=ka?pa:E;return qa|0}function pab(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((b|0)!=0){f=0;return f|0}b=a+188|0;g=a+192|0;h=a+204|0;i=a+196|0;j=a+200|0;a=c[b>>2]|0;k=c[g>>2]|0;l=c[h>>2]|0;m=d[1252840+a|0]|0;n=a<<m;c[b>>2]=n;a=l<<m;l=m+k|0;do{if((l|0)>-1){k=c[i>>2]|0;if(!(k>>>0<(c[j>>2]|0)>>>0)){o=a;p=l;break}c[i>>2]=k+2;m=k;o=((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535)<<l|a;p=l-16|0}else{o=a;p=l}}while(0);c[g>>2]=p;l=((n<<7)-128>>8)+1|0;a=l<<16;m=o>>>0>=a>>>0;k=m?n-l|0:l;l=o-(m?a:0)|0;c[h>>2]=l;a=(m&1)<<1;m=d[1252840+k|0]|0;o=k<<m;c[b>>2]=o;k=l<<m;l=m+p|0;do{if((l|0)>-1){p=c[i>>2]|0;if(!(p>>>0<(c[j>>2]|0)>>>0)){q=k;r=l;break}c[i>>2]=p+2;m=p;q=((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535)<<l|k;r=l-16|0}else{q=k;r=l}}while(0);c[g>>2]=r;r=((o<<7)-128>>8)+1|0;g=r<<16;l=q>>>0>=g>>>0;c[b>>2]=l?o-r|0:r;c[h>>2]=q-(l?g:0);g=l&1|a;if((g|0)==2){f=(e|0)==2?3:2;return f|0}else if((g|0)==1){f=1;return f|0}else{f=-1;return f|0}return 0}function qab(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=a|0;f=c[e>>2]|0;g=d[1252840+f|0]|0;h=a+4|0;i=c[h>>2]|0;j=a+16|0;k=c[j>>2]|0;l=f<<g;c[e>>2]=l;f=k<<g;k=i+g|0;do{if((k|0)>-1){g=a+8|0;i=c[g>>2]|0;if(!(i>>>0<(c[a+12>>2]|0)>>>0)){m=f;n=k;break}c[g>>2]=i+2;g=i;m=((he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535)<<k|f;n=k-16|0}else{m=f;n=k}}while(0);c[h>>2]=n;k=((l<<7)-128>>8)+1|0;f=k<<16;g=m>>>0>=f>>>0;i=g?l-k|0:k;c[e>>2]=i;k=m-(g?f:0)|0;c[j>>2]=k;if(!g){o=0;return o|0}if((b|0)==0){p=0;q=i;r=n;s=k}else{g=a+8|0;f=a+12|0;m=b;b=0;l=i;i=n;n=k;while(1){k=m-1|0;t=b<<1;u=d[1252840+l|0]|0;v=l<<u;c[e>>2]=v;w=n<<u;x=u+i|0;do{if((x|0)>-1){u=c[g>>2]|0;if(!(u>>>0<(c[f>>2]|0)>>>0)){y=w;z=x;break}c[g>>2]=u+2;A=u;y=((he((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535)<<x|w;z=x-16|0}else{y=w;z=x}}while(0);c[h>>2]=z;x=((v<<7)-128>>8)+1|0;w=x<<16;A=y>>>0>=w>>>0;u=A?v-x|0:x;c[e>>2]=u;x=y-(A?w:0)|0;c[j>>2]=x;w=A&1|t;if((k|0)==0){p=w;q=u;r=z;s=x;break}else{m=k;b=w;l=u;i=z;n=x}}}n=d[1252840+q|0]|0;z=q<<n;c[e>>2]=z;q=s<<n;s=r+n|0;do{if((s|0)>-1){n=a+8|0;r=c[n>>2]|0;if(!(r>>>0<(c[a+12>>2]|0)>>>0)){B=q;C=s;break}c[n>>2]=r+2;n=r;B=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<s|q;C=s-16|0}else{B=q;C=s}}while(0);c[h>>2]=C;C=((z<<7)-128>>8)+1|0;h=C<<16;s=B>>>0>=h>>>0;c[e>>2]=s?z-C|0:C;c[j>>2]=B-(s?h:0);o=s?-p|0:p;return o|0}function rab(a,b){a=a|0;b=b|0;c[a>>2]=258;c[a+4>>2]=468;c[a+8>>2]=32;c[a+12>>2]=1742;c[a+16>>2]=1110;c[a+20>>2]=1372;c[a+24>>2]=90;c[a+28>>2]=230;c[a+32>>2]=340;c[a+36>>2]=236;c[a+40>>2]=6;c[a+44>>2]=440;c[a+48>>2]=282;c[a+52>>2]=298;c[a+56>>2]=254;c[a+60>>2]=1218;c[a+64>>2]=628;c[a+68>>2]=674;c[a+72>>2]=170;c[a+76>>2]=158;c[a+80>>2]=308;c[a+84>>2]=578;c[a+88>>2]=518;c[a+92>>2]=146;c[a+96>>2]=58;c[a+100>>2]=570;c[a+104>>2]=504;c[a+108>>2]=328;c[a+112>>2]=144;c[a+116>>2]=636;c[a+120>>2]=98;c[a+124>>2]=306;c[a+128>>2]=122;c[a+132>>2]=540;c[a+136>>2]=152;c[a+140>>2]=526;c[a+144>>2]=354;c[a+148>>2]=348;c[a+152>>2]=212;c[a+156>>2]=604;c[a+160>>2]=522;c[a+164>>2]=392;c[a+168>>2]=452;c[a+172>>2]=628;c[a+176>>2]=124;c[a+180>>2]=124;c[a+184>>2]=640;c[a+188>>2]=610;c[a+192>>2]=610;c[a+196>>2]=640;c[a+200>>2]=610;c[a+204>>2]=610;c[a+208>>2]=570;c[a+212>>2]=344;c[a+216>>2]=344;c[a+220>>2]=182;c[a+224>>2]=286;c[a+228>>2]=286;c[a+232>>2]=182;c[a+236>>2]=286;c[a+240>>2]=286;c[a+244>>2]=152;c[a+248>>2]=450;c[a+252>>2]=450;c[a+256>>2]=608;c[a+260>>2]=626;c[a+264>>2]=626;c[a+268>>2]=608;c[a+272>>2]=626;c[a+276>>2]=626;return}function sab(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[d>>1]|0;f=d+24|0;g=b[f>>1]|0;h=g+e|0;i=d+8|0;j=b[i>>1]|0;k=d+16|0;l=b[k>>1]|0;m=l+j|0;n=j-l|0;l=e-g|0;b[d>>1]=m+h;b[i>>1]=n+l;b[k>>1]=h-m;b[f>>1]=l-n;n=d+2|0;l=b[n>>1]|0;f=d+26|0;m=b[f>>1]|0;h=m+l|0;k=d+10|0;i=b[k>>1]|0;g=d+18|0;e=b[g>>1]|0;j=e+i|0;o=i-e|0;e=l-m|0;b[n>>1]=j+h;b[k>>1]=o+e;b[g>>1]=h-j;b[f>>1]=e-o;o=d+4|0;e=b[o>>1]|0;f=d+28|0;j=b[f>>1]|0;h=j+e|0;g=d+12|0;k=b[g>>1]|0;n=d+20|0;m=b[n>>1]|0;l=m+k|0;i=k-m|0;m=e-j|0;b[o>>1]=l+h;b[g>>1]=i+m;b[n>>1]=h-l;b[f>>1]=m-i;i=d+6|0;m=b[i>>1]|0;f=d+30|0;l=b[f>>1]|0;h=l+m|0;n=d+14|0;g=b[n>>1]|0;o=d+22|0;j=b[o>>1]|0;e=j+g|0;k=g-j|0;j=m-l|0;b[i>>1]=e+h;b[n>>1]=k+j;b[o>>1]=h-e;b[f>>1]=j-k;k=0;do{j=k<<2;f=d+(j<<1)|0;e=b[f>>1]|0;h=b[d+((j|3)<<1)>>1]|0;o=e+3+h|0;n=b[d+((j|1)<<1)>>1]|0;i=b[d+((j|2)<<1)>>1]|0;j=i+n|0;l=n-i|0;i=e-h+3|0;h=f;c[h>>2]=0;c[h+4>>2]=0;b[a+(k<<7)>>1]=(j+o|0)>>>3;b[a+(k<<7)+32>>1]=(l+i|0)>>>3;b[a+(k<<7)+64>>1]=(o-j|0)>>>3;b[a+(k<<7)+96>>1]=(i-l|0)>>>3;k=k+1|0;}while((k|0)<4);return}function tab(a,c){a=a|0;c=c|0;var d=0;d=((b[c>>1]|0)+3|0)>>>3;b[c>>1]=0;c=d&65535;b[a>>1]=c;b[a+32>>1]=c;b[a+64>>1]=c;b[a+96>>1]=c;b[a+128>>1]=c;b[a+160>>1]=c;b[a+192>>1]=c;b[a+224>>1]=c;b[a+256>>1]=c;b[a+288>>1]=c;b[a+320>>1]=c;b[a+352>>1]=c;b[a+384>>1]=c;b[a+416>>1]=c;b[a+448>>1]=c;b[a+480>>1]=c;return}function uab(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+32|0;h=g|0;j=0;while(1){k=e+(j<<1)|0;l=b[k>>1]|0;m=e+(j+8<<1)|0;n=b[m>>1]|0;o=n+l|0;p=l-n|0;n=e+(j+4<<1)|0;l=b[n>>1]|0;q=e+(j+12<<1)|0;r=b[q>>1]|0;s=((l*35468|0)>>16)-r-((r*20091|0)>>16)|0;t=((l*20091|0)>>16)+l+((r*35468|0)>>16)|0;b[k>>1]=0;b[n>>1]=0;b[m>>1]=0;b[q>>1]=0;q=j<<2;b[h+(q<<1)>>1]=t+o;b[h+((q|1)<<1)>>1]=s+p;b[h+((q|2)<<1)>>1]=p-s;b[h+((q|3)<<1)>>1]=o-t;t=j+1|0;if((t|0)<4){j=t}else{u=c;v=0;break}}while(1){c=b[h+(v<<1)>>1]|0;j=b[h+(v+8<<1)>>1]|0;e=b[h+(v+4<<1)>>1]|0;t=b[h+(v+12<<1)>>1]|0;o=((e*35468|0)>>16)-t-((t*20091|0)>>16)|0;q=((e*20091|0)>>16)+e+((t*35468|0)>>16)|0;t=j+c+4|0;e=(t+q>>3)+(d[u]|0)|0;if(e>>>0>255>>>0){w=-e>>31&255}else{w=e&255}a[u]=w;e=u+1|0;s=c-j+4|0;j=(d[e]|0)+(s+o>>3)|0;if(j>>>0>255>>>0){x=-j>>31&255}else{x=j&255}a[e]=x;e=u+2|0;j=(d[e]|0)+(s-o>>3)|0;if(j>>>0>255>>>0){y=-j>>31&255}else{y=j&255}a[e]=y;e=u+3|0;j=(d[e]|0)+(t-q>>3)|0;if(j>>>0>255>>>0){z=-j>>31&255}else{z=j&255}a[e]=z;e=v+1|0;if((e|0)<4){u=u+f|0;v=e}else{break}}i=g;return}function vab(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=(b[e>>1]|0)+4>>3;b[e>>1]=0;e=0;h=c;while(1){c=(d[h]|0)+g|0;if(c>>>0>255>>>0){i=-c>>31&255}else{i=c&255}a[h]=i;c=h+1|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[c]=k;c=h+2|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[c]=l;c=h+3|0;j=(d[c]|0)+g|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[c]=m;c=e+1|0;if((c|0)<4){e=c;h=h+f|0}else{break}}return}function wab(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=e|0;h=(b[g>>1]|0)+4>>3;b[g>>1]=0;g=0;i=c;while(1){j=(d[i]|0)+h|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i]=k;j=i+1|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[j]=m;j=i+2|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){n=-l>>31&255}else{n=l&255}a[j]=n;j=i+3|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[j]=o;j=g+1|0;if((j|0)<4){g=j;i=i+f|0}else{break}}i=e+32|0;g=(b[i>>1]|0)+4>>3;b[i>>1]=0;i=0;o=c+4|0;while(1){h=(d[o]|0)+g|0;if(h>>>0>255>>>0){p=-h>>31&255}else{p=h&255}a[o]=p;h=o+1|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){q=-n>>31&255}else{q=n&255}a[h]=q;h=o+2|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){r=-n>>31&255}else{r=n&255}a[h]=r;h=o+3|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){s=-n>>31&255}else{s=n&255}a[h]=s;h=i+1|0;if((h|0)<4){i=h;o=o+f|0}else{break}}o=e+64|0;i=(b[o>>1]|0)+4>>3;b[o>>1]=0;o=0;s=c+8|0;while(1){g=(d[s]|0)+i|0;if(g>>>0>255>>>0){t=-g>>31&255}else{t=g&255}a[s]=t;g=s+1|0;r=(d[g]|0)+i|0;if(r>>>0>255>>>0){u=-r>>31&255}else{u=r&255}a[g]=u;g=s+2|0;r=(d[g]|0)+i|0;if(r>>>0>255>>>0){v=-r>>31&255}else{v=r&255}a[g]=v;g=s+3|0;r=(d[g]|0)+i|0;if(r>>>0>255>>>0){w=-r>>31&255}else{w=r&255}a[g]=w;g=o+1|0;if((g|0)<4){o=g;s=s+f|0}else{break}}s=e+96|0;e=(b[s>>1]|0)+4>>3;b[s>>1]=0;s=0;o=c+12|0;while(1){c=(d[o]|0)+e|0;if(c>>>0>255>>>0){x=-c>>31&255}else{x=c&255}a[o]=x;c=o+1|0;w=(d[c]|0)+e|0;if(w>>>0>255>>>0){y=-w>>31&255}else{y=w&255}a[c]=y;c=o+2|0;w=(d[c]|0)+e|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[c]=z;c=o+3|0;w=(d[c]|0)+e|0;if(w>>>0>255>>>0){A=-w>>31&255}else{A=w&255}a[c]=A;c=s+1|0;if((c|0)<4){s=c;o=o+f|0}else{break}}return}function xab(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=e|0;h=(b[g>>1]|0)+4>>3;b[g>>1]=0;g=0;i=c;while(1){j=(d[i]|0)+h|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[i]=k;j=i+1|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){m=-l>>31&255}else{m=l&255}a[j]=m;j=i+2|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){n=-l>>31&255}else{n=l&255}a[j]=n;j=i+3|0;l=(d[j]|0)+h|0;if(l>>>0>255>>>0){o=-l>>31&255}else{o=l&255}a[j]=o;j=g+1|0;if((j|0)<4){g=j;i=i+f|0}else{break}}i=e+32|0;g=(b[i>>1]|0)+4>>3;b[i>>1]=0;i=0;o=c+4|0;while(1){h=(d[o]|0)+g|0;if(h>>>0>255>>>0){p=-h>>31&255}else{p=h&255}a[o]=p;h=o+1|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){q=-n>>31&255}else{q=n&255}a[h]=q;h=o+2|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){r=-n>>31&255}else{r=n&255}a[h]=r;h=o+3|0;n=(d[h]|0)+g|0;if(n>>>0>255>>>0){s=-n>>31&255}else{s=n&255}a[h]=s;h=i+1|0;if((h|0)<4){i=h;o=o+f|0}else{break}}o=f<<2;i=e+64|0;s=(b[i>>1]|0)+4>>3;b[i>>1]=0;i=0;g=c+o|0;while(1){r=(d[g]|0)+s|0;if(r>>>0>255>>>0){t=-r>>31&255}else{t=r&255}a[g]=t;r=g+1|0;q=(d[r]|0)+s|0;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[r]=u;r=g+2|0;q=(d[r]|0)+s|0;if(q>>>0>255>>>0){v=-q>>31&255}else{v=q&255}a[r]=v;r=g+3|0;q=(d[r]|0)+s|0;if(q>>>0>255>>>0){w=-q>>31&255}else{w=q&255}a[r]=w;r=i+1|0;if((r|0)<4){i=r;g=g+f|0}else{break}}g=e+96|0;e=(b[g>>1]|0)+4>>3;b[g>>1]=0;g=0;i=c+(o+4)|0;while(1){o=(d[i]|0)+e|0;if(o>>>0>255>>>0){x=-o>>31&255}else{x=o&255}a[i]=x;o=i+1|0;c=(d[o]|0)+e|0;if(c>>>0>255>>>0){y=-c>>31&255}else{y=c&255}a[o]=y;o=i+2|0;c=(d[o]|0)+e|0;if(c>>>0>255>>>0){z=-c>>31&255}else{z=c&255}a[o]=z;o=i+3|0;c=(d[o]|0)+e|0;if(c>>>0>255>>>0){A=-c>>31&255}else{A=c&255}a[o]=A;o=g+1|0;if((o|0)<4){g=o;i=i+f|0}else{break}}return}function yab(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=c*-3|0;i=c*-2|0;j=c<<1;k=c*3|0;l=c*-4|0;m=0;do{n=b+m|0;o=b+(m+h)|0;p=d[o]|0;q=b+(m+i)|0;r=d[q]|0;s=b+(m-c)|0;t=d[s]|0;u=d[n]|0;v=b+(m+c)|0;w=d[v]|0;x=b+(m+j)|0;y=d[x]|0;z=d[b+(m+k)|0]|0;A=t-u|0;B=r-w|0;do{if(((((B|0)>-1?B:-B|0)>>1)+(((A|0)>-1?A:-A|0)<<1)|0)<=(e|0)){C=(d[b+(m+l)|0]|0)-p|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=p-r|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=r-t|0;D=(C|0)>-1?C:-C|0;if((D|0)>(f|0)){break}C=z-y|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=y-w|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=w-u|0;E=(C|0)>-1?C:-C|0;if((E|0)>(f|0)){break}if((D|0)>(g|0)|(E|0)>(g|0)){E=d[1403376+(((u-t|0)*3|0)+1024+(d[1403376+(r+1152-w)|0]|0))|0]|0;D=E-124|0;C=E-125|0;a[s]=a[1403376+(((C|0)>127?15:C>>3)+(t|1024))|0]|0;a[n]=a[1403376+((u|1024)-((D|0)>127?15:D>>3))|0]|0;break}else{D=(d[1403376+(((u-t|0)*3|0)+1024+(d[1403376+(r+1152-w)|0]|0))|0]|0)-128|0;C=(D*27|0)+63>>7;E=(D*18|0)+63>>7;F=(D*9|0)+63>>7;a[o]=a[1403376+(F+(p|1024))|0]|0;a[q]=a[1403376+(E+(r|1024))|0]|0;a[s]=a[1403376+(C+(t|1024))|0]|0;a[n]=a[1403376+((u|1024)-C)|0]|0;a[v]=a[1403376+((w|1024)-E)|0]|0;a[x]=a[1403376+((y|1024)-F)|0]|0;break}}}while(0);m=m+1|0;}while((m|0)<16);return}function zab(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=0;do{i=ca(h,c)|0;j=b+i|0;k=b+(i-3)|0;l=d[k]|0;m=b+(i-2)|0;n=d[m]|0;o=b+(i-1)|0;p=d[o]|0;q=d[j]|0;r=b+(i+1)|0;s=d[r]|0;t=b+(i+2)|0;u=d[t]|0;v=d[b+(i+3)|0]|0;w=p-q|0;x=n-s|0;do{if(((((x|0)>-1?x:-x|0)>>1)+(((w|0)>-1?w:-w|0)<<1)|0)<=(e|0)){y=(d[b+(i-4)|0]|0)-l|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=l-n|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=n-p|0;z=(y|0)>-1?y:-y|0;if((z|0)>(f|0)){break}y=v-u|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=u-s|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=s-q|0;A=(y|0)>-1?y:-y|0;if((A|0)>(f|0)){break}if((z|0)>(g|0)|(A|0)>(g|0)){A=d[1403376+(((q-p|0)*3|0)+1024+(d[1403376+(n+1152-s)|0]|0))|0]|0;z=A-124|0;y=A-125|0;a[o]=a[1403376+(((y|0)>127?15:y>>3)+(p|1024))|0]|0;a[j]=a[1403376+((q|1024)-((z|0)>127?15:z>>3))|0]|0;break}else{z=(d[1403376+(((q-p|0)*3|0)+1024+(d[1403376+(n+1152-s)|0]|0))|0]|0)-128|0;y=(z*27|0)+63>>7;A=(z*18|0)+63>>7;B=(z*9|0)+63>>7;a[k]=a[1403376+(B+(l|1024))|0]|0;a[m]=a[1403376+(A+(n|1024))|0]|0;a[o]=a[1403376+(y+(p|1024))|0]|0;a[j]=a[1403376+((q|1024)-y)|0]|0;a[r]=a[1403376+((s|1024)-A)|0]|0;a[t]=a[1403376+((u|1024)-B)|0]|0;break}}}while(0);h=h+1|0;}while((h|0)<16);return}function Aab(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;i=e*-3|0;j=e*-2|0;k=e<<1;l=e*3|0;m=e*-4|0;n=0;while(1){o=b+n|0;p=b+(n+i)|0;q=d[p]|0;r=b+(n+j)|0;s=d[r]|0;t=b+(n-e)|0;u=d[t]|0;v=d[o]|0;w=b+(n+e)|0;x=d[w]|0;y=b+(n+k)|0;z=d[y]|0;A=d[b+(n+l)|0]|0;B=u-v|0;C=s-x|0;do{if(((((C|0)>-1?C:-C|0)>>1)+(((B|0)>-1?B:-B|0)<<1)|0)<=(f|0)){D=(d[b+(n+m)|0]|0)-q|0;if((((D|0)>-1?D:-D|0)|0)>(g|0)){break}D=q-s|0;if((((D|0)>-1?D:-D|0)|0)>(g|0)){break}D=s-u|0;E=(D|0)>-1?D:-D|0;if((E|0)>(g|0)){break}D=A-z|0;if((((D|0)>-1?D:-D|0)|0)>(g|0)){break}D=z-x|0;if((((D|0)>-1?D:-D|0)|0)>(g|0)){break}D=x-v|0;F=(D|0)>-1?D:-D|0;if((F|0)>(g|0)){break}if((E|0)>(h|0)|(F|0)>(h|0)){F=d[1403376+(((v-u|0)*3|0)+1024+(d[1403376+(s+1152-x)|0]|0))|0]|0;E=F-124|0;D=F-125|0;a[t]=a[1403376+(((D|0)>127?15:D>>3)+(u|1024))|0]|0;a[o]=a[1403376+((v|1024)-((E|0)>127?15:E>>3))|0]|0;break}else{E=(d[1403376+(((v-u|0)*3|0)+1024+(d[1403376+(s+1152-x)|0]|0))|0]|0)-128|0;D=(E*27|0)+63>>7;F=(E*18|0)+63>>7;G=(E*9|0)+63>>7;a[p]=a[1403376+(G+(q|1024))|0]|0;a[r]=a[1403376+(F+(s|1024))|0]|0;a[t]=a[1403376+(D+(u|1024))|0]|0;a[o]=a[1403376+((v|1024)-D)|0]|0;a[w]=a[1403376+((x|1024)-F)|0]|0;a[y]=a[1403376+((z|1024)-G)|0]|0;break}}}while(0);z=n+1|0;if((z|0)<8){n=z}else{H=0;break}}do{n=c+H|0;b=c+(H+i)|0;z=d[b]|0;y=c+(H+j)|0;x=d[y]|0;w=c+(H-e)|0;v=d[w]|0;o=d[n]|0;u=c+(H+e)|0;t=d[u]|0;s=c+(H+k)|0;r=d[s]|0;q=d[c+(H+l)|0]|0;p=v-o|0;A=x-t|0;do{if(((((A|0)>-1?A:-A|0)>>1)+(((p|0)>-1?p:-p|0)<<1)|0)<=(f|0)){B=(d[c+(H+m)|0]|0)-z|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=z-x|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=x-v|0;C=(B|0)>-1?B:-B|0;if((C|0)>(g|0)){break}B=q-r|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=r-t|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=t-o|0;G=(B|0)>-1?B:-B|0;if((G|0)>(g|0)){break}if((C|0)>(h|0)|(G|0)>(h|0)){G=d[1403376+(((o-v|0)*3|0)+1024+(d[1403376+(x+1152-t)|0]|0))|0]|0;C=G-124|0;B=G-125|0;a[w]=a[1403376+(((B|0)>127?15:B>>3)+(v|1024))|0]|0;a[n]=a[1403376+((o|1024)-((C|0)>127?15:C>>3))|0]|0;break}else{C=(d[1403376+(((o-v|0)*3|0)+1024+(d[1403376+(x+1152-t)|0]|0))|0]|0)-128|0;B=(C*27|0)+63>>7;G=(C*18|0)+63>>7;F=(C*9|0)+63>>7;a[b]=a[1403376+(F+(z|1024))|0]|0;a[y]=a[1403376+(G+(x|1024))|0]|0;a[w]=a[1403376+(B+(v|1024))|0]|0;a[n]=a[1403376+((o|1024)-B)|0]|0;a[u]=a[1403376+((t|1024)-G)|0]|0;a[s]=a[1403376+((r|1024)-F)|0]|0;break}}}while(0);H=H+1|0;}while((H|0)<8);return}function Bab(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=0;while(1){j=ca(i,e)|0;k=b+j|0;l=b+(j-3)|0;m=d[l]|0;n=b+(j-2)|0;o=d[n]|0;p=b+(j-1)|0;q=d[p]|0;r=d[k]|0;s=b+(j+1)|0;t=d[s]|0;u=b+(j+2)|0;v=d[u]|0;w=d[b+(j+3)|0]|0;x=q-r|0;y=o-t|0;do{if(((((y|0)>-1?y:-y|0)>>1)+(((x|0)>-1?x:-x|0)<<1)|0)<=(f|0)){z=(d[b+(j-4)|0]|0)-m|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=m-o|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=o-q|0;A=(z|0)>-1?z:-z|0;if((A|0)>(g|0)){break}z=w-v|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=v-t|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=t-r|0;B=(z|0)>-1?z:-z|0;if((B|0)>(g|0)){break}if((A|0)>(h|0)|(B|0)>(h|0)){B=d[1403376+(((r-q|0)*3|0)+1024+(d[1403376+(o+1152-t)|0]|0))|0]|0;A=B-124|0;z=B-125|0;a[p]=a[1403376+(((z|0)>127?15:z>>3)+(q|1024))|0]|0;a[k]=a[1403376+((r|1024)-((A|0)>127?15:A>>3))|0]|0;break}else{A=(d[1403376+(((r-q|0)*3|0)+1024+(d[1403376+(o+1152-t)|0]|0))|0]|0)-128|0;z=(A*27|0)+63>>7;B=(A*18|0)+63>>7;C=(A*9|0)+63>>7;a[l]=a[1403376+(C+(m|1024))|0]|0;a[n]=a[1403376+(B+(o|1024))|0]|0;a[p]=a[1403376+(z+(q|1024))|0]|0;a[k]=a[1403376+((r|1024)-z)|0]|0;a[s]=a[1403376+((t|1024)-B)|0]|0;a[u]=a[1403376+((v|1024)-C)|0]|0;break}}}while(0);v=i+1|0;if((v|0)<8){i=v}else{D=0;break}}do{i=ca(D,e)|0;b=c+i|0;v=c+(i-3)|0;u=d[v]|0;t=c+(i-2)|0;s=d[t]|0;r=c+(i-1)|0;k=d[r]|0;q=d[b]|0;p=c+(i+1)|0;o=d[p]|0;n=c+(i+2)|0;m=d[n]|0;l=d[c+(i+3)|0]|0;w=k-q|0;j=s-o|0;do{if(((((j|0)>-1?j:-j|0)>>1)+(((w|0)>-1?w:-w|0)<<1)|0)<=(f|0)){x=(d[c+(i-4)|0]|0)-u|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=u-s|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=s-k|0;y=(x|0)>-1?x:-x|0;if((y|0)>(g|0)){break}x=l-m|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=m-o|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=o-q|0;C=(x|0)>-1?x:-x|0;if((C|0)>(g|0)){break}if((y|0)>(h|0)|(C|0)>(h|0)){C=d[1403376+(((q-k|0)*3|0)+1024+(d[1403376+(s+1152-o)|0]|0))|0]|0;y=C-124|0;x=C-125|0;a[r]=a[1403376+(((x|0)>127?15:x>>3)+(k|1024))|0]|0;a[b]=a[1403376+((q|1024)-((y|0)>127?15:y>>3))|0]|0;break}else{y=(d[1403376+(((q-k|0)*3|0)+1024+(d[1403376+(s+1152-o)|0]|0))|0]|0)-128|0;x=(y*27|0)+63>>7;C=(y*18|0)+63>>7;B=(y*9|0)+63>>7;a[v]=a[1403376+(B+(u|1024))|0]|0;a[t]=a[1403376+(C+(s|1024))|0]|0;a[r]=a[1403376+(x+(k|1024))|0]|0;a[b]=a[1403376+((q|1024)-x)|0]|0;a[p]=a[1403376+((o|1024)-C)|0]|0;a[n]=a[1403376+((m|1024)-B)|0]|0;break}}}while(0);D=D+1|0;}while((D|0)<8);return}function Cab(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=c*-3|0;i=c*-2|0;j=c<<1;k=c*3|0;l=c*-4|0;m=0;do{n=b+m|0;o=d[b+(m+h)|0]|0;p=b+(m+i)|0;q=d[p]|0;r=b+(m-c)|0;s=d[r]|0;t=d[n]|0;u=b+(m+c)|0;v=d[u]|0;w=d[b+(m+j)|0]|0;x=d[b+(m+k)|0]|0;y=s-t|0;z=q-v|0;do{if(((((z|0)>-1?z:-z|0)>>1)+(((y|0)>-1?y:-y|0)<<1)|0)<=(e|0)){A=(d[b+(m+l)|0]|0)-o|0;if((((A|0)>-1?A:-A|0)|0)>(f|0)){break}A=o-q|0;if((((A|0)>-1?A:-A|0)|0)>(f|0)){break}A=q-s|0;B=(A|0)>-1?A:-A|0;if((B|0)>(f|0)){break}A=x-w|0;if((((A|0)>-1?A:-A|0)|0)>(f|0)){break}A=w-v|0;if((((A|0)>-1?A:-A|0)|0)>(f|0)){break}A=v-t|0;C=(A|0)>-1?A:-A|0;if((C|0)>(f|0)){break}A=(t-s|0)*3|0;if((B|0)>(g|0)|(C|0)>(g|0)){C=d[1403376+(A+1024+(d[1403376+(q+1152-v)|0]|0))|0]|0;B=C-124|0;D=C-125|0;a[r]=a[1403376+(((D|0)>127?15:D>>3)+(s|1024))|0]|0;a[n]=a[1403376+((t|1024)-((B|0)>127?15:B>>3))|0]|0;break}else{B=d[A+1404528|0]|0;A=B-124|0;D=(A|0)>127?15:A>>3;A=B-125|0;a[r]=a[1403376+(((A|0)>127?15:A>>3)+(s|1024))|0]|0;a[n]=a[1403376+((t|1024)-D)|0]|0;A=D+1>>1;a[p]=a[1403376+(A+(q|1024))|0]|0;a[u]=a[1403376+((v|1024)-A)|0]|0;break}}}while(0);m=m+1|0;}while((m|0)<16);return}function Dab(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=0;do{i=ca(h,c)|0;j=b+i|0;k=d[b+(i-3)|0]|0;l=b+(i-2)|0;m=d[l]|0;n=b+(i-1)|0;o=d[n]|0;p=d[j]|0;q=b+(i+1)|0;r=d[q]|0;s=d[b+(i+2)|0]|0;t=d[b+(i+3)|0]|0;u=o-p|0;v=m-r|0;do{if(((((v|0)>-1?v:-v|0)>>1)+(((u|0)>-1?u:-u|0)<<1)|0)<=(e|0)){w=(d[b+(i-4)|0]|0)-k|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=k-m|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=m-o|0;x=(w|0)>-1?w:-w|0;if((x|0)>(f|0)){break}w=t-s|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=s-r|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=r-p|0;y=(w|0)>-1?w:-w|0;if((y|0)>(f|0)){break}w=(p-o|0)*3|0;if((x|0)>(g|0)|(y|0)>(g|0)){y=d[1403376+(w+1024+(d[1403376+(m+1152-r)|0]|0))|0]|0;x=y-124|0;z=y-125|0;a[n]=a[1403376+(((z|0)>127?15:z>>3)+(o|1024))|0]|0;a[j]=a[1403376+((p|1024)-((x|0)>127?15:x>>3))|0]|0;break}else{x=d[w+1404528|0]|0;w=x-124|0;z=(w|0)>127?15:w>>3;w=x-125|0;a[n]=a[1403376+(((w|0)>127?15:w>>3)+(o|1024))|0]|0;a[j]=a[1403376+((p|1024)-z)|0]|0;w=z+1>>1;a[l]=a[1403376+(w+(m|1024))|0]|0;a[q]=a[1403376+((r|1024)-w)|0]|0;break}}}while(0);h=h+1|0;}while((h|0)<16);return}function Eab(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;i=e*-3|0;j=e*-2|0;k=e<<1;l=e*3|0;m=e*-4|0;n=0;while(1){o=b+n|0;p=d[b+(n+i)|0]|0;q=b+(n+j)|0;r=d[q]|0;s=b+(n-e)|0;t=d[s]|0;u=d[o]|0;v=b+(n+e)|0;w=d[v]|0;x=d[b+(n+k)|0]|0;y=d[b+(n+l)|0]|0;z=t-u|0;A=r-w|0;do{if(((((A|0)>-1?A:-A|0)>>1)+(((z|0)>-1?z:-z|0)<<1)|0)<=(f|0)){B=(d[b+(n+m)|0]|0)-p|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=p-r|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=r-t|0;C=(B|0)>-1?B:-B|0;if((C|0)>(g|0)){break}B=y-x|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=x-w|0;if((((B|0)>-1?B:-B|0)|0)>(g|0)){break}B=w-u|0;D=(B|0)>-1?B:-B|0;if((D|0)>(g|0)){break}B=(u-t|0)*3|0;if((C|0)>(h|0)|(D|0)>(h|0)){D=d[1403376+(B+1024+(d[1403376+(r+1152-w)|0]|0))|0]|0;C=D-124|0;E=D-125|0;a[s]=a[1403376+(((E|0)>127?15:E>>3)+(t|1024))|0]|0;a[o]=a[1403376+((u|1024)-((C|0)>127?15:C>>3))|0]|0;break}else{C=d[B+1404528|0]|0;B=C-124|0;E=(B|0)>127?15:B>>3;B=C-125|0;a[s]=a[1403376+(((B|0)>127?15:B>>3)+(t|1024))|0]|0;a[o]=a[1403376+((u|1024)-E)|0]|0;B=E+1>>1;a[q]=a[1403376+(B+(r|1024))|0]|0;a[v]=a[1403376+((w|1024)-B)|0]|0;break}}}while(0);w=n+1|0;if((w|0)<8){n=w}else{F=0;break}}do{n=c+F|0;b=d[c+(F+i)|0]|0;w=c+(F+j)|0;v=d[w]|0;r=c+(F-e)|0;q=d[r]|0;u=d[n]|0;o=c+(F+e)|0;t=d[o]|0;s=d[c+(F+k)|0]|0;x=d[c+(F+l)|0]|0;y=q-u|0;p=v-t|0;do{if(((((p|0)>-1?p:-p|0)>>1)+(((y|0)>-1?y:-y|0)<<1)|0)<=(f|0)){z=(d[c+(F+m)|0]|0)-b|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=b-v|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=v-q|0;A=(z|0)>-1?z:-z|0;if((A|0)>(g|0)){break}z=x-s|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=s-t|0;if((((z|0)>-1?z:-z|0)|0)>(g|0)){break}z=t-u|0;B=(z|0)>-1?z:-z|0;if((B|0)>(g|0)){break}z=(u-q|0)*3|0;if((A|0)>(h|0)|(B|0)>(h|0)){B=d[1403376+(z+1024+(d[1403376+(v+1152-t)|0]|0))|0]|0;A=B-124|0;E=B-125|0;a[r]=a[1403376+(((E|0)>127?15:E>>3)+(q|1024))|0]|0;a[n]=a[1403376+((u|1024)-((A|0)>127?15:A>>3))|0]|0;break}else{A=d[z+1404528|0]|0;z=A-124|0;E=(z|0)>127?15:z>>3;z=A-125|0;a[r]=a[1403376+(((z|0)>127?15:z>>3)+(q|1024))|0]|0;a[n]=a[1403376+((u|1024)-E)|0]|0;z=E+1>>1;a[w]=a[1403376+(z+(v|1024))|0]|0;a[o]=a[1403376+((t|1024)-z)|0]|0;break}}}while(0);F=F+1|0;}while((F|0)<8);return}function Fab(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;i=0;while(1){j=ca(i,e)|0;k=b+j|0;l=d[b+(j-3)|0]|0;m=b+(j-2)|0;n=d[m]|0;o=b+(j-1)|0;p=d[o]|0;q=d[k]|0;r=b+(j+1)|0;s=d[r]|0;t=d[b+(j+2)|0]|0;u=d[b+(j+3)|0]|0;v=p-q|0;w=n-s|0;do{if(((((w|0)>-1?w:-w|0)>>1)+(((v|0)>-1?v:-v|0)<<1)|0)<=(f|0)){x=(d[b+(j-4)|0]|0)-l|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=l-n|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=n-p|0;y=(x|0)>-1?x:-x|0;if((y|0)>(g|0)){break}x=u-t|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=t-s|0;if((((x|0)>-1?x:-x|0)|0)>(g|0)){break}x=s-q|0;z=(x|0)>-1?x:-x|0;if((z|0)>(g|0)){break}x=(q-p|0)*3|0;if((y|0)>(h|0)|(z|0)>(h|0)){z=d[1403376+(x+1024+(d[1403376+(n+1152-s)|0]|0))|0]|0;y=z-124|0;A=z-125|0;a[o]=a[1403376+(((A|0)>127?15:A>>3)+(p|1024))|0]|0;a[k]=a[1403376+((q|1024)-((y|0)>127?15:y>>3))|0]|0;break}else{y=d[x+1404528|0]|0;x=y-124|0;A=(x|0)>127?15:x>>3;x=y-125|0;a[o]=a[1403376+(((x|0)>127?15:x>>3)+(p|1024))|0]|0;a[k]=a[1403376+((q|1024)-A)|0]|0;x=A+1>>1;a[m]=a[1403376+(x+(n|1024))|0]|0;a[r]=a[1403376+((s|1024)-x)|0]|0;break}}}while(0);s=i+1|0;if((s|0)<8){i=s}else{B=0;break}}do{i=ca(B,e)|0;b=c+i|0;s=d[c+(i-3)|0]|0;r=c+(i-2)|0;n=d[r]|0;m=c+(i-1)|0;q=d[m]|0;k=d[b]|0;p=c+(i+1)|0;o=d[p]|0;t=d[c+(i+2)|0]|0;u=d[c+(i+3)|0]|0;l=q-k|0;j=n-o|0;do{if(((((j|0)>-1?j:-j|0)>>1)+(((l|0)>-1?l:-l|0)<<1)|0)<=(f|0)){v=(d[c+(i-4)|0]|0)-s|0;if((((v|0)>-1?v:-v|0)|0)>(g|0)){break}v=s-n|0;if((((v|0)>-1?v:-v|0)|0)>(g|0)){break}v=n-q|0;w=(v|0)>-1?v:-v|0;if((w|0)>(g|0)){break}v=u-t|0;if((((v|0)>-1?v:-v|0)|0)>(g|0)){break}v=t-o|0;if((((v|0)>-1?v:-v|0)|0)>(g|0)){break}v=o-k|0;x=(v|0)>-1?v:-v|0;if((x|0)>(g|0)){break}v=(k-q|0)*3|0;if((w|0)>(h|0)|(x|0)>(h|0)){x=d[1403376+(v+1024+(d[1403376+(n+1152-o)|0]|0))|0]|0;w=x-124|0;A=x-125|0;a[m]=a[1403376+(((A|0)>127?15:A>>3)+(q|1024))|0]|0;a[b]=a[1403376+((k|1024)-((w|0)>127?15:w>>3))|0]|0;break}else{w=d[v+1404528|0]|0;v=w-124|0;A=(v|0)>127?15:v>>3;v=w-125|0;a[m]=a[1403376+(((v|0)>127?15:v>>3)+(q|1024))|0]|0;a[b]=a[1403376+((k|1024)-A)|0]|0;v=A+1>>1;a[r]=a[1403376+(v+(n|1024))|0]|0;a[p]=a[1403376+((o|1024)-v)|0]|0;break}}}while(0);B=B+1|0;}while((B|0)<8);return}function Gab(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c*-2|0;g=0;do{h=b+g|0;i=d[b+(g+f)|0]|0;j=b+(g-c)|0;k=d[j]|0;l=d[h]|0;m=d[b+(g+c)|0]|0;n=k-l|0;o=i-m|0;if(((((o|0)>-1?o:-o|0)>>1)+(((n|0)>-1?n:-n|0)<<1)|0)<=(e|0)){n=d[1403376+(((l-k|0)*3|0)+1024+(d[1403376+(i+1152-m)|0]|0))|0]|0;m=n-124|0;i=n-125|0;a[j]=a[1403376+(((i|0)>127?15:i>>3)+(k|1024))|0]|0;a[h]=a[1403376+((l|1024)-((m|0)>127?15:m>>3))|0]|0}g=g+1|0;}while((g|0)<16);return}function Hab(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=0;do{g=ca(f,c)|0;h=b+g|0;i=d[b+(g-2)|0]|0;j=b+(g-1)|0;k=d[j]|0;l=d[h]|0;m=d[b+(g+1)|0]|0;g=k-l|0;n=i-m|0;if(((((n|0)>-1?n:-n|0)>>1)+(((g|0)>-1?g:-g|0)<<1)|0)<=(e|0)){g=d[1403376+(((l-k|0)*3|0)+1024+(d[1403376+(i+1152-m)|0]|0))|0]|0;m=g-124|0;i=g-125|0;a[j]=a[1403376+(((i|0)>127?15:i>>3)+(k|1024))|0]|0;a[h]=a[1403376+((l|1024)-((m|0)>127?15:m>>3))|0]|0}f=f+1|0;}while((f|0)<16);return}function Iab(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)>0){h=c;i=a;j=0}else{return}while(1){nrc(i|0,h|0,16)|0;a=j+1|0;if((a|0)<(e|0)){h=h+d|0;i=i+b|0;j=a}else{break}}return}function Jab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=h-1|0;if((g|0)<=0){return}h=d[552698+(i*6|0)|0]|0;j=d[552697+(i*6|0)|0]|0;k=d[552699+(i*6|0)|0]|0;l=d[552700+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){m=0;while(1){n=ca(d[i+m|0]|0,h)|0;o=ca(d[i+(m-1)|0]|0,j)|0;p=m+1|0;q=ca(d[i+p|0]|0,k)|0;a[e+m|0]=a[(n+64-o+q-(ca(d[i+(m+2)|0]|0,l)|0)>>7)+1404400|0]|0;if((p|0)<16){m=p}else{break}}m=b+1|0;if((m|0)<(g|0)){i=i+f|0;e=e+c|0;b=m}else{break}}return}function Kab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=h-1|0;if((g|0)<=0){return}h=d[552698+(i*6|0)|0]|0;j=d[552697+(i*6|0)|0]|0;k=d[552696+(i*6|0)|0]|0;l=d[552699+(i*6|0)|0]|0;m=d[552700+(i*6|0)|0]|0;n=d[552701+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){o=0;while(1){p=ca(d[i+o|0]|0,h)|0;q=ca(d[i+(o-1)|0]|0,j)|0;r=ca(d[i+(o-2)|0]|0,k)|0;s=o+1|0;t=ca(d[i+s|0]|0,l)|0;u=ca(d[i+(o+2)|0]|0,m)|0;a[e+o|0]=a[(p+64-q+r+t-u+(ca(d[i+(o+3)|0]|0,n)|0)>>7)+1404400|0]|0;if((s|0)<16){o=s}else{break}}o=b+1|0;if((o|0)<(g|0)){i=i+f|0;e=e+c|0;b=o}else{break}}return}function Lab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i-1|0;if((g|0)<=0){return}i=d[552698+(h*6|0)|0]|0;j=d[552697+(h*6|0)|0]|0;k=d[552699+(h*6|0)|0]|0;l=d[552700+(h*6|0)|0]|0;h=f<<1;m=e;e=b;b=0;while(1){n=0;do{o=ca(d[m+n|0]|0,i)|0;p=ca(d[m+(n-f)|0]|0,j)|0;q=ca(d[m+(n+f)|0]|0,k)|0;a[e+n|0]=a[(o+64-p+q-(ca(d[m+(n+h)|0]|0,l)|0)>>7)+1404400|0]|0;n=n+1|0;}while((n|0)<16);n=b+1|0;if((n|0)<(g|0)){m=m+f|0;e=e+c|0;b=n}else{break}}return}function Mab(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+560|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552699+(m*6|0)|0]|0;q=d[552700+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;r=l|0;while(1){s=0;t=a[m]|0;u=a[m+1|0]|0;while(1){v=ca(t&255,n)|0;w=ca(d[m+(s-1)|0]|0,o)|0;x=s+1|0;y=ca(u&255,p)|0;z=a[m+(s+2)|0]|0;a[r+s|0]=a[(v+64-w+y-(ca(z&255,q)|0)>>7)+1404400|0]|0;if((x|0)<16){s=x;t=u;u=z}else{break}}u=e+1|0;if((u|0)<(h|0)){m=m+f|0;e=u;r=r+16|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(r*6|0)|0]|0;e=d[552697+(r*6|0)|0]|0;f=d[552699+(r*6|0)|0]|0;m=d[552700+(r*6|0)|0]|0;r=b;b=0;h=l+16|0;while(1){l=0;do{q=ca(d[h+l|0]|0,j)|0;p=ca(d[h+(l-16)|0]|0,e)|0;o=ca(d[h+(l+16)|0]|0,f)|0;a[r+l|0]=a[(q+64-p+o-(ca(d[h+(l+32)|0]|0,m)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<16);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;h=h+16|0}else{break}}i=k;return}function Nab(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+560|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552696+(m*6|0)|0]|0;q=d[552699+(m*6|0)|0]|0;r=d[552700+(m*6|0)|0]|0;s=d[552701+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ca(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ca(A&255,o)|0;C=ca(w&255,p)|0;D=u+1|0;E=ca(x&255,q)|0;F=ca(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ca(G&255,s)|0)>>7)+1404400|0]|0;if((D|0)<16){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+16|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(t*6|0)|0]|0;e=d[552697+(t*6|0)|0]|0;f=d[552699+(t*6|0)|0]|0;m=d[552700+(t*6|0)|0]|0;t=b;b=0;h=l+16|0;while(1){l=0;do{s=ca(d[h+l|0]|0,j)|0;r=ca(d[h+(l-16)|0]|0,e)|0;q=ca(d[h+(l+16)|0]|0,f)|0;a[t+l|0]=a[(s+64-r+q-(ca(d[h+(l+32)|0]|0,m)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<16);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;h=h+16|0}else{break}}i=k;return}function Oab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i-1|0;if((g|0)<=0){return}i=d[552698+(h*6|0)|0]|0;j=d[552697+(h*6|0)|0]|0;k=d[552696+(h*6|0)|0]|0;l=f<<1;m=d[552699+(h*6|0)|0]|0;n=d[552700+(h*6|0)|0]|0;o=d[552701+(h*6|0)|0]|0;h=f*3|0;p=e;e=b;b=0;while(1){q=0;do{r=ca(d[p+q|0]|0,i)|0;s=ca(d[p+(q-f)|0]|0,j)|0;t=ca(d[p+(q-l)|0]|0,k)|0;u=ca(d[p+(q+f)|0]|0,m)|0;v=ca(d[p+(q+l)|0]|0,n)|0;a[e+q|0]=a[(r+64-s+t+u-v+(ca(d[p+(q+h)|0]|0,o)|0)>>7)+1404400|0]|0;q=q+1|0;}while((q|0)<16);q=b+1|0;if((q|0)<(g|0)){p=p+f|0;e=e+c|0;b=q}else{break}}return}function Pab(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+592|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552699+(m*6|0)|0]|0;q=d[552700+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;r=l|0;while(1){s=0;t=a[m]|0;u=a[m+1|0]|0;while(1){v=ca(t&255,n)|0;w=ca(d[m+(s-1)|0]|0,o)|0;x=s+1|0;y=ca(u&255,p)|0;z=a[m+(s+2)|0]|0;a[r+s|0]=a[(v+64-w+y-(ca(z&255,q)|0)>>7)+1404400|0]|0;if((x|0)<16){s=x;t=u;u=z}else{break}}u=e+1|0;if((u|0)<(h|0)){m=m+f|0;e=u;r=r+16|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(r*6|0)|0]|0;e=d[552697+(r*6|0)|0]|0;f=d[552696+(r*6|0)|0]|0;m=d[552699+(r*6|0)|0]|0;h=d[552700+(r*6|0)|0]|0;q=d[552701+(r*6|0)|0]|0;r=b;b=0;p=l+32|0;while(1){l=0;do{o=ca(d[p+l|0]|0,j)|0;n=ca(d[p+(l-16)|0]|0,e)|0;u=ca(d[p+(l-32)|0]|0,f)|0;t=ca(d[p+(l+16)|0]|0,m)|0;s=ca(d[p+(l+32)|0]|0,h)|0;a[r+l|0]=a[(o+64-n+u+t-s+(ca(d[p+(l+48)|0]|0,q)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<16);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;p=p+16|0}else{break}}i=k;return}function Qab(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+592|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552696+(m*6|0)|0]|0;q=d[552699+(m*6|0)|0]|0;r=d[552700+(m*6|0)|0]|0;s=d[552701+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ca(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ca(A&255,o)|0;C=ca(w&255,p)|0;D=u+1|0;E=ca(x&255,q)|0;F=ca(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ca(G&255,s)|0)>>7)+1404400|0]|0;if((D|0)<16){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+16|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(t*6|0)|0]|0;e=d[552697+(t*6|0)|0]|0;f=d[552696+(t*6|0)|0]|0;m=d[552699+(t*6|0)|0]|0;h=d[552700+(t*6|0)|0]|0;s=d[552701+(t*6|0)|0]|0;t=b;b=0;r=l+32|0;while(1){l=0;do{q=ca(d[r+l|0]|0,j)|0;p=ca(d[r+(l-16)|0]|0,e)|0;o=ca(d[r+(l-32)|0]|0,f)|0;n=ca(d[r+(l+16)|0]|0,m)|0;y=ca(d[r+(l+32)|0]|0,h)|0;a[t+l|0]=a[(q+64-p+o+n-y+(ca(d[r+(l+48)|0]|0,s)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<16);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;r=r+16|0}else{break}}i=k;return}function Rab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=j;e=k;i=b|0;h=b+4|0;b=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=e|0;y=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=e+4|0;y=b;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=l+1|0;if((h|0)<(g|0)){j=j+f|0;k=k+c|0;l=h}else{break}}return}function Sab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=h-1|0;if((g|0)<=0){return}h=d[552698+(i*6|0)|0]|0;j=d[552697+(i*6|0)|0]|0;k=d[552699+(i*6|0)|0]|0;l=d[552700+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){m=0;while(1){n=ca(d[i+m|0]|0,h)|0;o=ca(d[i+(m-1)|0]|0,j)|0;p=m+1|0;q=ca(d[i+p|0]|0,k)|0;a[e+m|0]=a[(n+64-o+q-(ca(d[i+(m+2)|0]|0,l)|0)>>7)+1404400|0]|0;if((p|0)<8){m=p}else{break}}m=b+1|0;if((m|0)<(g|0)){i=i+f|0;e=e+c|0;b=m}else{break}}return}function Tab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=h-1|0;if((g|0)<=0){return}h=d[552698+(i*6|0)|0]|0;j=d[552697+(i*6|0)|0]|0;k=d[552696+(i*6|0)|0]|0;l=d[552699+(i*6|0)|0]|0;m=d[552700+(i*6|0)|0]|0;n=d[552701+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){o=0;while(1){p=ca(d[i+o|0]|0,h)|0;q=ca(d[i+(o-1)|0]|0,j)|0;r=ca(d[i+(o-2)|0]|0,k)|0;s=o+1|0;t=ca(d[i+s|0]|0,l)|0;u=ca(d[i+(o+2)|0]|0,m)|0;a[e+o|0]=a[(p+64-q+r+t-u+(ca(d[i+(o+3)|0]|0,n)|0)>>7)+1404400|0]|0;if((s|0)<8){o=s}else{break}}o=b+1|0;if((o|0)<(g|0)){i=i+f|0;e=e+c|0;b=o}else{break}}return}function Uab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i-1|0;if((g|0)<=0){return}i=d[552698+(h*6|0)|0]|0;j=d[552697+(h*6|0)|0]|0;k=d[552699+(h*6|0)|0]|0;l=d[552700+(h*6|0)|0]|0;h=f<<1;m=e;e=b;b=0;while(1){n=0;do{o=ca(d[m+n|0]|0,i)|0;p=ca(d[m+(n-f)|0]|0,j)|0;q=ca(d[m+(n+f)|0]|0,k)|0;a[e+n|0]=a[(o+64-p+q-(ca(d[m+(n+h)|0]|0,l)|0)>>7)+1404400|0]|0;n=n+1|0;}while((n|0)<8);n=b+1|0;if((n|0)<(g|0)){m=m+f|0;e=e+c|0;b=n}else{break}}return}function Vab(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+152|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552699+(m*6|0)|0]|0;q=d[552700+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;r=l|0;while(1){s=0;t=a[m]|0;u=a[m+1|0]|0;while(1){v=ca(t&255,n)|0;w=ca(d[m+(s-1)|0]|0,o)|0;x=s+1|0;y=ca(u&255,p)|0;z=a[m+(s+2)|0]|0;a[r+s|0]=a[(v+64-w+y-(ca(z&255,q)|0)>>7)+1404400|0]|0;if((x|0)<8){s=x;t=u;u=z}else{break}}u=e+1|0;if((u|0)<(h|0)){m=m+f|0;e=u;r=r+8|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(r*6|0)|0]|0;e=d[552697+(r*6|0)|0]|0;f=d[552699+(r*6|0)|0]|0;m=d[552700+(r*6|0)|0]|0;r=b;b=0;h=l+8|0;while(1){l=0;do{q=ca(d[h+l|0]|0,j)|0;p=ca(d[h+(l-8)|0]|0,e)|0;o=ca(d[h+(l+8)|0]|0,f)|0;a[r+l|0]=a[(q+64-p+o-(ca(d[h+(l+16)|0]|0,m)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<8);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;h=h+8|0}else{break}}i=k;return}function Wab(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+152|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552696+(m*6|0)|0]|0;q=d[552699+(m*6|0)|0]|0;r=d[552700+(m*6|0)|0]|0;s=d[552701+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ca(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ca(A&255,o)|0;C=ca(w&255,p)|0;D=u+1|0;E=ca(x&255,q)|0;F=ca(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ca(G&255,s)|0)>>7)+1404400|0]|0;if((D|0)<8){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+8|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(t*6|0)|0]|0;e=d[552697+(t*6|0)|0]|0;f=d[552699+(t*6|0)|0]|0;m=d[552700+(t*6|0)|0]|0;t=b;b=0;h=l+8|0;while(1){l=0;do{s=ca(d[h+l|0]|0,j)|0;r=ca(d[h+(l-8)|0]|0,e)|0;q=ca(d[h+(l+8)|0]|0,f)|0;a[t+l|0]=a[(s+64-r+q-(ca(d[h+(l+16)|0]|0,m)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<8);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;h=h+8|0}else{break}}i=k;return}function Xab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i-1|0;if((g|0)<=0){return}i=d[552698+(h*6|0)|0]|0;j=d[552697+(h*6|0)|0]|0;k=d[552696+(h*6|0)|0]|0;l=f<<1;m=d[552699+(h*6|0)|0]|0;n=d[552700+(h*6|0)|0]|0;o=d[552701+(h*6|0)|0]|0;h=f*3|0;p=e;e=b;b=0;while(1){q=0;do{r=ca(d[p+q|0]|0,i)|0;s=ca(d[p+(q-f)|0]|0,j)|0;t=ca(d[p+(q-l)|0]|0,k)|0;u=ca(d[p+(q+f)|0]|0,m)|0;v=ca(d[p+(q+l)|0]|0,n)|0;a[e+q|0]=a[(r+64-s+t+u-v+(ca(d[p+(q+h)|0]|0,o)|0)>>7)+1404400|0]|0;q=q+1|0;}while((q|0)<8);q=b+1|0;if((q|0)<(g|0)){p=p+f|0;e=e+c|0;b=q}else{break}}return}function Yab(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;i=i+168|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552699+(m*6|0)|0]|0;q=d[552700+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;r=l|0;while(1){s=0;t=a[m]|0;u=a[m+1|0]|0;while(1){v=ca(t&255,n)|0;w=ca(d[m+(s-1)|0]|0,o)|0;x=s+1|0;y=ca(u&255,p)|0;z=a[m+(s+2)|0]|0;a[r+s|0]=a[(v+64-w+y-(ca(z&255,q)|0)>>7)+1404400|0]|0;if((x|0)<8){s=x;t=u;u=z}else{break}}u=e+1|0;if((u|0)<(h|0)){m=m+f|0;e=u;r=r+8|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(r*6|0)|0]|0;e=d[552697+(r*6|0)|0]|0;f=d[552696+(r*6|0)|0]|0;m=d[552699+(r*6|0)|0]|0;h=d[552700+(r*6|0)|0]|0;q=d[552701+(r*6|0)|0]|0;r=b;b=0;p=l+16|0;while(1){l=0;do{o=ca(d[p+l|0]|0,j)|0;n=ca(d[p+(l-8)|0]|0,e)|0;u=ca(d[p+(l-16)|0]|0,f)|0;t=ca(d[p+(l+8)|0]|0,m)|0;s=ca(d[p+(l+16)|0]|0,h)|0;a[r+l|0]=a[(o+64-n+u+t-s+(ca(d[p+(l+24)|0]|0,q)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<8);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;p=p+8|0}else{break}}i=k;return}function Zab(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+168|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552696+(m*6|0)|0]|0;q=d[552699+(m*6|0)|0]|0;r=d[552700+(m*6|0)|0]|0;s=d[552701+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ca(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ca(A&255,o)|0;C=ca(w&255,p)|0;D=u+1|0;E=ca(x&255,q)|0;F=ca(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ca(G&255,s)|0)>>7)+1404400|0]|0;if((D|0)<8){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+8|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(t*6|0)|0]|0;e=d[552697+(t*6|0)|0]|0;f=d[552696+(t*6|0)|0]|0;m=d[552699+(t*6|0)|0]|0;h=d[552700+(t*6|0)|0]|0;s=d[552701+(t*6|0)|0]|0;t=b;b=0;r=l+16|0;while(1){l=0;do{q=ca(d[r+l|0]|0,j)|0;p=ca(d[r+(l-8)|0]|0,e)|0;o=ca(d[r+(l-16)|0]|0,f)|0;n=ca(d[r+(l+8)|0]|0,m)|0;y=ca(d[r+(l+16)|0]|0,h)|0;a[t+l|0]=a[(q+64-p+o+n-y+(ca(d[r+(l+24)|0]|0,s)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<8);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;r=r+8|0}else{break}}i=k;return}function _ab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=j;e=k;y=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;e=l+1|0;if((e|0)<(g|0)){j=j+f|0;k=k+c|0;l=e}else{break}}return}function $ab(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=h-1|0;if((g|0)<=0){return}h=d[552698+(i*6|0)|0]|0;j=d[552697+(i*6|0)|0]|0;k=d[552699+(i*6|0)|0]|0;l=d[552700+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){m=ca(d[i]|0,h)|0;n=ca(d[i-1|0]|0,j)|0;o=i+1|0;p=ca(d[o]|0,k)|0;q=i+2|0;a[e]=a[(m+64-n+p-(ca(d[q]|0,l)|0)>>7)+1404400|0]|0;p=ca(d[o]|0,h)|0;n=ca(d[i]|0,j)|0;m=ca(d[q]|0,k)|0;r=i+3|0;a[e+1|0]=a[(p+64-n+m-(ca(d[r]|0,l)|0)>>7)+1404400|0]|0;m=ca(d[q]|0,h)|0;n=ca(d[o]|0,j)|0;o=ca(d[r]|0,k)|0;p=i+4|0;a[e+2|0]=a[(m+64-n+o-(ca(d[p]|0,l)|0)>>7)+1404400|0]|0;o=ca(d[r]|0,h)|0;r=ca(d[q]|0,j)|0;q=ca(d[p]|0,k)|0;a[e+3|0]=a[(o+64-r+q-(ca(d[i+5|0]|0,l)|0)>>7)+1404400|0]|0;q=b+1|0;if((q|0)<(g|0)){i=i+f|0;e=e+c|0;b=q}else{break}}return}function abb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=h-1|0;if((g|0)<=0){return}h=d[552698+(i*6|0)|0]|0;j=d[552697+(i*6|0)|0]|0;k=d[552696+(i*6|0)|0]|0;l=d[552699+(i*6|0)|0]|0;m=d[552700+(i*6|0)|0]|0;n=d[552701+(i*6|0)|0]|0;i=e;e=b;b=0;while(1){o=0;while(1){p=ca(d[i+o|0]|0,h)|0;q=ca(d[i+(o-1)|0]|0,j)|0;r=ca(d[i+(o-2)|0]|0,k)|0;s=o+1|0;t=ca(d[i+s|0]|0,l)|0;u=ca(d[i+(o+2)|0]|0,m)|0;a[e+o|0]=a[(p+64-q+r+t-u+(ca(d[i+(o+3)|0]|0,n)|0)>>7)+1404400|0]|0;if((s|0)<4){o=s}else{break}}o=b+1|0;if((o|0)<(g|0)){i=i+f|0;e=e+c|0;b=o}else{break}}return}function bbb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i-1|0;if((g|0)<=0){return}i=d[552698+(h*6|0)|0]|0;j=d[552697+(h*6|0)|0]|0;k=d[552699+(h*6|0)|0]|0;l=d[552700+(h*6|0)|0]|0;h=f<<1;m=e;e=b;b=0;while(1){n=ca(d[m]|0,i)|0;o=ca(d[m+(-f|0)|0]|0,j)|0;p=m+f|0;q=ca(d[p]|0,k)|0;a[e]=a[(n+64-o+q-(ca(d[m+h|0]|0,l)|0)>>7)+1404400|0]|0;q=ca(d[m+1|0]|0,i)|0;o=ca(d[m+(1-f)|0]|0,j)|0;n=ca(d[m+(f+1)|0]|0,k)|0;a[e+1|0]=a[(q+64-o+n-(ca(d[m+(h|1)|0]|0,l)|0)>>7)+1404400|0]|0;n=ca(d[m+2|0]|0,i)|0;o=ca(d[m+(2-f)|0]|0,j)|0;q=ca(d[m+(f+2)|0]|0,k)|0;a[e+2|0]=a[(n+64-o+q-(ca(d[m+(h+2)|0]|0,l)|0)>>7)+1404400|0]|0;q=ca(d[m+3|0]|0,i)|0;o=ca(d[m+(3-f)|0]|0,j)|0;n=ca(d[m+(f+3)|0]|0,k)|0;a[e+3|0]=a[(q+64-o+n-(ca(d[m+(h+3)|0]|0,l)|0)>>7)+1404400|0]|0;n=b+1|0;if((n|0)<(g|0)){m=p;e=e+c|0;b=n}else{break}}return}function cbb(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;k=i;i=i+48|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552699+(m*6|0)|0]|0;q=d[552700+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;r=l|0;while(1){s=d[m]|0;t=ca(s,n)|0;u=ca(d[m-1|0]|0,o)|0;v=d[m+1|0]|0;w=ca(v,p)|0;x=d[m+2|0]|0;a[r]=a[(t+64-u+w-(ca(x,q)|0)>>7)+1404400|0]|0;w=ca(v,n)|0;u=ca(s,o)|0;s=ca(x,p)|0;t=d[m+3|0]|0;a[r+1|0]=a[(w+64-u+s-(ca(t,q)|0)>>7)+1404400|0]|0;s=ca(x,n)|0;u=ca(v,o)|0;v=ca(t,p)|0;w=d[m+4|0]|0;a[r+2|0]=a[(s+64-u+v-(ca(w,q)|0)>>7)+1404400|0]|0;v=ca(t,n)|0;t=ca(x,o)|0;x=ca(w,p)|0;a[r+3|0]=a[(v+64-t+x-(ca(d[m+5|0]|0,q)|0)>>7)+1404400|0]|0;x=e+1|0;if((x|0)<(h|0)){m=m+f|0;e=x;r=r+4|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=l+4|0;l=d[552698+(r*6|0)|0]|0;e=d[552697+(r*6|0)|0]|0;f=d[552699+(r*6|0)|0]|0;m=d[552700+(r*6|0)|0]|0;r=b;b=0;h=j;q=a[j]|0;while(1){j=ca(q&255,l)|0;p=ca(d[h-4|0]|0,e)|0;o=h+4|0;n=a[o]|0;x=ca(n&255,f)|0;a[r]=a[(j+64-p+x-(ca(d[h+8|0]|0,m)|0)>>7)+1404400|0]|0;x=ca(d[h+1|0]|0,l)|0;p=ca(d[h-3|0]|0,e)|0;j=ca(d[h+5|0]|0,f)|0;a[r+1|0]=a[(x+64-p+j-(ca(d[h+9|0]|0,m)|0)>>7)+1404400|0]|0;j=ca(d[h+2|0]|0,l)|0;p=ca(d[h-2|0]|0,e)|0;x=ca(d[h+6|0]|0,f)|0;a[r+2|0]=a[(j+64-p+x-(ca(d[h+10|0]|0,m)|0)>>7)+1404400|0]|0;x=ca(d[h+3|0]|0,l)|0;p=ca(d[h-1|0]|0,e)|0;j=ca(d[h+7|0]|0,f)|0;a[r+3|0]=a[(x+64-p+j-(ca(d[h+11|0]|0,m)|0)>>7)+1404400|0]|0;j=b+1|0;if((j|0)<(g|0)){r=r+c|0;b=j;h=o;q=n}else{break}}i=k;return}function dbb(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+48|0;l=k|0;m=h-1|0;h=g+3|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552696+(m*6|0)|0]|0;q=d[552699+(m*6|0)|0]|0;r=d[552700+(m*6|0)|0]|0;s=d[552701+(m*6|0)|0]|0;m=e+(-f|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ca(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ca(A&255,o)|0;C=ca(w&255,p)|0;D=u+1|0;E=ca(x&255,q)|0;F=ca(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ca(G&255,s)|0)>>7)+1404400|0]|0;if((D|0)<4){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+4|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=l+4|0;l=d[552698+(t*6|0)|0]|0;e=d[552697+(t*6|0)|0]|0;f=d[552699+(t*6|0)|0]|0;m=d[552700+(t*6|0)|0]|0;t=b;b=0;h=j;s=a[j]|0;while(1){j=ca(s&255,l)|0;r=ca(d[h-4|0]|0,e)|0;q=h+4|0;p=a[q]|0;o=ca(p&255,f)|0;a[t]=a[(j+64-r+o-(ca(d[h+8|0]|0,m)|0)>>7)+1404400|0]|0;o=ca(d[h+1|0]|0,l)|0;r=ca(d[h-3|0]|0,e)|0;j=ca(d[h+5|0]|0,f)|0;a[t+1|0]=a[(o+64-r+j-(ca(d[h+9|0]|0,m)|0)>>7)+1404400|0]|0;j=ca(d[h+2|0]|0,l)|0;r=ca(d[h-2|0]|0,e)|0;o=ca(d[h+6|0]|0,f)|0;a[t+2|0]=a[(j+64-r+o-(ca(d[h+10|0]|0,m)|0)>>7)+1404400|0]|0;o=ca(d[h+3|0]|0,l)|0;r=ca(d[h-1|0]|0,e)|0;j=ca(d[h+7|0]|0,f)|0;a[t+3|0]=a[(o+64-r+j-(ca(d[h+11|0]|0,m)|0)>>7)+1404400|0]|0;j=b+1|0;if((j|0)<(g|0)){t=t+c|0;b=j;h=q;s=p}else{break}}i=k;return}function ebb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i-1|0;if((g|0)<=0){return}i=d[552698+(h*6|0)|0]|0;j=d[552697+(h*6|0)|0]|0;k=d[552696+(h*6|0)|0]|0;l=f<<1;m=d[552699+(h*6|0)|0]|0;n=d[552700+(h*6|0)|0]|0;o=d[552701+(h*6|0)|0]|0;h=f*3|0;p=e;e=b;b=0;while(1){q=0;do{r=ca(d[p+q|0]|0,i)|0;s=ca(d[p+(q-f)|0]|0,j)|0;t=ca(d[p+(q-l)|0]|0,k)|0;u=ca(d[p+(q+f)|0]|0,m)|0;v=ca(d[p+(q+l)|0]|0,n)|0;a[e+q|0]=a[(r+64-s+t+u-v+(ca(d[p+(q+h)|0]|0,o)|0)>>7)+1404400|0]|0;q=q+1|0;}while((q|0)<4);q=b+1|0;if((q|0)<(g|0)){p=p+f|0;e=e+c|0;b=q}else{break}}return}function fbb(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;k=i;i=i+56|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552699+(m*6|0)|0]|0;q=d[552700+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;r=l|0;while(1){s=d[m]|0;t=ca(s,n)|0;u=ca(d[m-1|0]|0,o)|0;v=d[m+1|0]|0;w=ca(v,p)|0;x=d[m+2|0]|0;a[r]=a[(t+64-u+w-(ca(x,q)|0)>>7)+1404400|0]|0;w=ca(v,n)|0;u=ca(s,o)|0;s=ca(x,p)|0;t=d[m+3|0]|0;a[r+1|0]=a[(w+64-u+s-(ca(t,q)|0)>>7)+1404400|0]|0;s=ca(x,n)|0;u=ca(v,o)|0;v=ca(t,p)|0;w=d[m+4|0]|0;a[r+2|0]=a[(s+64-u+v-(ca(w,q)|0)>>7)+1404400|0]|0;v=ca(t,n)|0;t=ca(x,o)|0;x=ca(w,p)|0;a[r+3|0]=a[(v+64-t+x-(ca(d[m+5|0]|0,q)|0)>>7)+1404400|0]|0;x=e+1|0;if((x|0)<(h|0)){m=m+f|0;e=x;r=r+4|0}else{break}}}r=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(r*6|0)|0]|0;e=d[552697+(r*6|0)|0]|0;f=d[552696+(r*6|0)|0]|0;m=d[552699+(r*6|0)|0]|0;h=d[552700+(r*6|0)|0]|0;q=d[552701+(r*6|0)|0]|0;r=b;b=0;p=l+8|0;while(1){l=0;do{o=ca(d[p+l|0]|0,j)|0;n=ca(d[p+(l-4)|0]|0,e)|0;x=ca(d[p+(l-8)|0]|0,f)|0;t=ca(d[p+(l+4)|0]|0,m)|0;v=ca(d[p+(l+8)|0]|0,h)|0;a[r+l|0]=a[(o+64-n+x+t-v+(ca(d[p+(l+12)|0]|0,q)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<4);l=b+1|0;if((l|0)<(g|0)){r=r+c|0;b=l;p=p+4|0}else{break}}i=k;return}function gbb(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;k=i;i=i+56|0;l=k|0;m=h-1|0;h=g+5|0;if((h|0)>0){n=d[552698+(m*6|0)|0]|0;o=d[552697+(m*6|0)|0]|0;p=d[552696+(m*6|0)|0]|0;q=d[552699+(m*6|0)|0]|0;r=d[552700+(m*6|0)|0]|0;s=d[552701+(m*6|0)|0]|0;m=e+(-(f<<1)|0)|0;e=0;t=l|0;while(1){u=0;v=a[m]|0;w=a[m-2|0]|0;x=a[m+1|0]|0;y=a[m+2|0]|0;while(1){z=ca(v&255,n)|0;A=a[m+(u-1)|0]|0;B=ca(A&255,o)|0;C=ca(w&255,p)|0;D=u+1|0;E=ca(x&255,q)|0;F=ca(y&255,r)|0;G=a[m+(u+3)|0]|0;a[t+u|0]=a[(z+64-B+C+E-F+(ca(G&255,s)|0)>>7)+1404400|0]|0;if((D|0)<4){u=D;v=x;w=A;x=y;y=G}else{break}}y=e+1|0;if((y|0)<(h|0)){m=m+f|0;e=y;t=t+4|0}else{break}}}t=j-1|0;if((g|0)<=0){i=k;return}j=d[552698+(t*6|0)|0]|0;e=d[552697+(t*6|0)|0]|0;f=d[552696+(t*6|0)|0]|0;m=d[552699+(t*6|0)|0]|0;h=d[552700+(t*6|0)|0]|0;s=d[552701+(t*6|0)|0]|0;t=b;b=0;r=l+8|0;while(1){l=0;do{q=ca(d[r+l|0]|0,j)|0;p=ca(d[r+(l-4)|0]|0,e)|0;o=ca(d[r+(l-8)|0]|0,f)|0;n=ca(d[r+(l+4)|0]|0,m)|0;y=ca(d[r+(l+8)|0]|0,h)|0;a[t+l|0]=a[(q+64-p+o+n-y+(ca(d[r+(l+12)|0]|0,s)|0)>>7)+1404400|0]|0;l=l+1|0;}while((l|0)<4);l=b+1|0;if((l|0)<(g|0)){t=t+c|0;b=l;r=r+4|0}else{break}}i=k;return}function hbb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;i=8-h|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=0;while(1){e=ca(d[j+b|0]|0,i)|0;m=b+1|0;a[k+b|0]=(e+4+(ca(d[j+m|0]|0,h)|0)|0)>>>3;if((m|0)<16){b=m}else{break}}b=l+1|0;if((b|0)<(g|0)){j=j+f|0;k=k+c|0;l=b}else{break}}return}function ibb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;h=8-i|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=0;do{e=ca(d[j+b|0]|0,h)|0;a[k+b|0]=(e+4+(ca(d[j+(b+f)|0]|0,i)|0)|0)>>>3;b=b+1|0;}while((b|0)<16);b=l+1|0;if((b|0)<(g|0)){j=j+f|0;k=k+c|0;l=b}else{break}}return}function jbb(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+528|0;l=8-h|0;m=8-j|0;n=k|0;o=g+1|0;if((o|0)>0){p=e;e=0;q=n;while(1){r=0;s=a[p]|0;while(1){t=ca(s&255,l)|0;u=r+1|0;v=a[p+u|0]|0;a[q+r|0]=(t+4+(ca(v&255,h)|0)|0)>>>3;if((u|0)<16){r=u;s=v}else{break}}s=e+1|0;if((s|0)<(o|0)){p=p+f|0;e=s;q=q+16|0}else{break}}}if((g|0)>0){w=b;x=0;y=n}else{i=k;return}while(1){n=0;do{b=ca(d[y+n|0]|0,m)|0;a[w+n|0]=(b+4+(ca(d[y+(n+16)|0]|0,j)|0)|0)>>>3;n=n+1|0;}while((n|0)<16);n=x+1|0;if((n|0)<(g|0)){w=w+c|0;x=n;y=y+16|0}else{break}}i=k;return}function kbb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=8-h|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=ca(d[j]|0,i)|0;e=j+1|0;a[k]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;e=j+2|0;a[k+1|0]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;e=j+3|0;a[k+2|0]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;e=j+4|0;a[k+3|0]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;e=j+5|0;a[k+4|0]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;e=j+6|0;a[k+5|0]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;e=j+7|0;a[k+6|0]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;a[k+7|0]=(b+4+(ca(d[j+8|0]|0,h)|0)|0)>>>3;b=l+1|0;if((b|0)<(g|0)){j=j+f|0;k=k+c|0;l=b}else{break}}return}function lbb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;h=8-i|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=ca(d[j]|0,h)|0;e=j+f|0;a[k]=(b+4+(ca(d[e]|0,i)|0)|0)>>>3;b=ca(d[j+1|0]|0,h)|0;a[k+1|0]=(b+4+(ca(d[j+(f+1)|0]|0,i)|0)|0)>>>3;b=ca(d[j+2|0]|0,h)|0;a[k+2|0]=(b+4+(ca(d[j+(f+2)|0]|0,i)|0)|0)>>>3;b=ca(d[j+3|0]|0,h)|0;a[k+3|0]=(b+4+(ca(d[j+(f+3)|0]|0,i)|0)|0)>>>3;b=ca(d[j+4|0]|0,h)|0;a[k+4|0]=(b+4+(ca(d[j+(f+4)|0]|0,i)|0)|0)>>>3;b=ca(d[j+5|0]|0,h)|0;a[k+5|0]=(b+4+(ca(d[j+(f+5)|0]|0,i)|0)|0)>>>3;b=ca(d[j+6|0]|0,h)|0;a[k+6|0]=(b+4+(ca(d[j+(f+6)|0]|0,i)|0)|0)>>>3;b=ca(d[j+7|0]|0,h)|0;a[k+7|0]=(b+4+(ca(d[j+(f+7)|0]|0,i)|0)|0)>>>3;b=l+1|0;if((b|0)<(g|0)){j=e;k=k+c|0;l=b}else{break}}return}function mbb(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+136|0;l=8-h|0;m=8-j|0;n=k|0;o=g+1|0;if((o|0)>0){p=e;e=0;q=n;while(1){r=ca(d[p]|0,l)|0;s=d[p+1|0]|0;a[q]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;s=d[p+2|0]|0;a[q+1|0]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;s=d[p+3|0]|0;a[q+2|0]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;s=d[p+4|0]|0;a[q+3|0]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;s=d[p+5|0]|0;a[q+4|0]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;s=d[p+6|0]|0;a[q+5|0]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;s=d[p+7|0]|0;a[q+6|0]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;a[q+7|0]=(r+4+(ca(d[p+8|0]|0,h)|0)|0)>>>3;r=e+1|0;if((r|0)<(o|0)){p=p+f|0;e=r;q=q+8|0}else{break}}}if((g|0)<=0){i=k;return}q=b;b=0;e=n;f=a[n]|0;while(1){n=ca(f&255,m)|0;p=e+8|0;o=a[p]|0;a[q]=(n+4+(ca(o&255,j)|0)|0)>>>3;n=ca(d[e+1|0]|0,m)|0;a[q+1|0]=(n+4+(ca(d[e+9|0]|0,j)|0)|0)>>>3;n=ca(d[e+2|0]|0,m)|0;a[q+2|0]=(n+4+(ca(d[e+10|0]|0,j)|0)|0)>>>3;n=ca(d[e+3|0]|0,m)|0;a[q+3|0]=(n+4+(ca(d[e+11|0]|0,j)|0)|0)>>>3;n=ca(d[e+4|0]|0,m)|0;a[q+4|0]=(n+4+(ca(d[e+12|0]|0,j)|0)|0)>>>3;n=ca(d[e+5|0]|0,m)|0;a[q+5|0]=(n+4+(ca(d[e+13|0]|0,j)|0)|0)>>>3;n=ca(d[e+6|0]|0,m)|0;a[q+6|0]=(n+4+(ca(d[e+14|0]|0,j)|0)|0)>>>3;n=ca(d[e+7|0]|0,m)|0;a[q+7|0]=(n+4+(ca(d[e+15|0]|0,j)|0)|0)>>>3;n=b+1|0;if((n|0)<(g|0)){q=q+c|0;b=n;e=p;f=o}else{break}}i=k;return}function nbb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=8-h|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=ca(d[j]|0,i)|0;e=j+1|0;a[k]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;e=j+2|0;a[k+1|0]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;e=j+3|0;a[k+2|0]=(b+4+(ca(d[e]|0,h)|0)|0)>>>3;b=ca(d[e]|0,i)|0;a[k+3|0]=(b+4+(ca(d[j+4|0]|0,h)|0)|0)>>>3;b=l+1|0;if((b|0)<(g|0)){j=j+f|0;k=k+c|0;l=b}else{break}}return}function obb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;h=8-i|0;if((g|0)>0){j=e;k=b;l=0}else{return}while(1){b=ca(d[j]|0,h)|0;e=j+f|0;a[k]=(b+4+(ca(d[e]|0,i)|0)|0)>>>3;b=ca(d[j+1|0]|0,h)|0;a[k+1|0]=(b+4+(ca(d[j+(f+1)|0]|0,i)|0)|0)>>>3;b=ca(d[j+2|0]|0,h)|0;a[k+2|0]=(b+4+(ca(d[j+(f+2)|0]|0,i)|0)|0)>>>3;b=ca(d[j+3|0]|0,h)|0;a[k+3|0]=(b+4+(ca(d[j+(f+3)|0]|0,i)|0)|0)>>>3;b=l+1|0;if((b|0)<(g|0)){j=e;k=k+c|0;l=b}else{break}}return}function pbb(b,c,e,f,g,h,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+40|0;l=8-h|0;m=8-j|0;n=k|0;o=g+1|0;if((o|0)>0){p=e;e=0;q=n;while(1){r=ca(d[p]|0,l)|0;s=d[p+1|0]|0;a[q]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;s=d[p+2|0]|0;a[q+1|0]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;s=d[p+3|0]|0;a[q+2|0]=(r+4+(ca(s,h)|0)|0)>>>3;r=ca(s,l)|0;a[q+3|0]=(r+4+(ca(d[p+4|0]|0,h)|0)|0)>>>3;r=e+1|0;if((r|0)<(o|0)){p=p+f|0;e=r;q=q+4|0}else{break}}}if((g|0)<=0){i=k;return}q=b;b=0;e=n;f=a[n]|0;while(1){n=ca(f&255,m)|0;p=e+4|0;o=a[p]|0;a[q]=(n+4+(ca(o&255,j)|0)|0)>>>3;n=ca(d[e+1|0]|0,m)|0;a[q+1|0]=(n+4+(ca(d[e+5|0]|0,j)|0)|0)>>>3;n=ca(d[e+2|0]|0,m)|0;a[q+2|0]=(n+4+(ca(d[e+6|0]|0,j)|0)|0)>>>3;n=ca(d[e+3|0]|0,m)|0;a[q+3|0]=(n+4+(ca(d[e+7|0]|0,j)|0)|0)>>>3;n=b+1|0;if((n|0)<(g|0)){q=q+c|0;b=n;e=p;f=o}else{break}}i=k;return}function qbb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=b+60|0;f=c[e>>2]|0;c[(c[b+64>>2]|0)+4>>2]=1;c[b+140>>2]=0;Ebb(f);G8a(f+1024|0,8);a[f+1409|0]=-1;f=c[e>>2]|0;e=f+1360|0;g=0;while(1){if((g|0)>=2){break}h=UHb()|0;c[e+(g*24|0)>>2]=h;if((h|0)==0){j=5;break}else{g=g+1|0}}if((j|0)==5){sbb(b)|0;KIb(b,16,2476472,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;l=-12;i=d;return l|0}g=f+1168|0;e=f+1264|0;f=0;while(1){if((f|0)>=8){l=0;j=9;break}h=g+(f*12|0)|0;c[h>>2]=UHb()|0;m=UHb()|0;c[e+(f*12|0)>>2]=m;if((c[h>>2]|0)==0|(m|0)==0){break}else{f=f+1|0}}if((j|0)==9){i=d;return l|0}sbb(b)|0;KIb(b,16,2476472,(k=i,i=i+8|0,c[k>>2]=f,k)|0);i=k;l=-12;i=d;return l|0}function rbb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0;h=i;i=i+8|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=b+60|0;m=c[g>>2]|0;n=m;o=ubb(b,k,l,j)|0;if((o|0)<0){p=o;i=h;return p|0}if((o|0)==0){q=c[j>>2]|0;j=c[m+1168+(q*12|0)>>2]|0;if((c[j>>2]|0)==0){KIb(b,16,2441832,(r=i,i=i+8|0,c[r>>2]=q,r)|0);i=r;p=-1094995529;i=h;return p|0}q=YHb(e,j)|0;if((q|0)<0){p=q;i=h;return p|0}c[f>>2]=1;p=0;i=h;return p|0}q=k+o|0;k=l-o|0;o=m+1360|0;l=m+1384|0;if((c[c[l>>2]>>2]|0)!=0){H5a(b,l);fGb(m+1396|0)}j=m+1137|0;s=o;do{if((a[j]|0)==0){if((c[c[s>>2]>>2]|0)==0){break}t=l;u=G5a(t,o)|0;if((u|0)<0){p=u;i=h;return p|0}u=eGb(c[m+1372>>2]|0)|0;v=m+1396|0;c[v>>2]=u;if((u|0)!=0){c[m+1400>>2]=c[m+1376>>2];c[m+1404>>2]=c[m+1380>>2];break}H5a(b,t);fGb(v);p=-12;i=h;return p|0}}while(0);l=o;if((c[c[s>>2]>>2]|0)!=0){H5a(b,l);fGb(m+1372|0)}o=c[g>>2]|0;v=J5a(b,l,1)|0;if((v|0)<0){p=v;i=h;return p|0}v=ca(c[o+1796>>2]<<6,c[o+1800>>2]|0)|0;t=dGb(v*13|0)|0;c[m+1372>>2]=t;if((t|0)==0){H5a(b,l);p=-12;i=h;return p|0}u=t+4|0;t=c[u>>2]|0;c[m+1376>>2]=t;c[m+1380>>2]=(c[u>>2]|0)+v;do{if((a[o+1550|0]|0)!=0){if((a[o+1553|0]|0)!=0){break}if((a[o+1144|0]|0)!=0){break}if((a[o+1137|0]|0)!=0){break}nrc(t|0,c[o+1400>>2]|0,v)|0}}while(0);v=c[s>>2]|0;c[v+84>>2]=d[j]|0;c[v+88>>2]=(a[j]|0)!=0?1:2;o=c[v+32>>2]|0;t=c[v+36>>2]|0;u=m+1264|0;w=u;x=m+1146|0;z=m+1168|0;A=z;B=0;while(1){if((B|0)>=8){break}C=w+(B*12|0)|0;if((c[c[C>>2]>>2]|0)!=0){H5a(b,C)}if((d[x]&1<<B|0)==0){D=G5a(C,A+(B*12|0)|0)|0}else{D=G5a(C,l)|0}if((D|0)<0){p=D;E=507;break}else{B=B+1|0}}if((E|0)==507){i=h;return p|0}B=m+1808|0;mrc(c[m+30096>>2]|0,0,c[B>>2]|0)|0;mrc(c[m+30116>>2]|0,0,c[B>>2]|0)|0;do{if((a[j]|0)==0){if((a[m+1144|0]|0)!=0){E=35;break}mrc(c[m+30100>>2]|0,10,c[B>>2]|0)|0}else{E=35}}while(0);if((E|0)==35){mrc(c[m+30100>>2]|0,2,c[B>>2]<<1|0)|0}D=m+1796|0;mrc(c[m+30104>>2]|0,0,c[D>>2]<<4|0)|0;mrc(c[m+30108>>2]|0,0,c[D>>2]<<3|0)|0;mrc(c[m+30112>>2]|0,0,c[D>>2]<<3|0)|0;mrc(c[m+30124>>2]|0,0,c[B>>2]|0)|0;do{if((c[b+816>>2]|0)==1){if((a[m+1154|0]|0)==0){F=0;break}F=(a[m+1155|0]|0)==0|0}else{F=0}}while(0);c[m+1092>>2]=F;A=m+1088|0;c[A>>2]=F;F=c[g>>2]|0;x=F+1080|0;w=c[x>>2]|0;C=F+35860|0;do{if((w|0)==0){E=43}else{if((c[C>>2]|0)==0){E=43;break}if((c[F+35856>>2]|0)!=(c[F+1092>>2]|0)){E=43}}}while(0);do{if((E|0)==43){kJb(w|0);kJb(c[C>>2]|0);H=F+1092|0;do{if((c[H>>2]|0)==0){c[x>>2]=hJb(68)|0;I=pJb(12672)|0;c[C>>2]=I;if((c[x>>2]|0)==0|(I|0)==0){break}c[F+35868>>2]=I+8192;c[F+35872>>2]=I+10240;c[F+35884>>2]=I+12288;c[F+35888>>2]=I+12544;c[F+35892>>2]=I+12608;E=48}else{I=ca(c[F+1800>>2]|0,c[F+1796>>2]|0)|0;c[x>>2]=hJb(ca((c[F+1808>>2]|0)*68|0,c[F+1804>>2]|0)|0)|0;J=pJb(I*12672|0)|0;K=J;c[C>>2]=K;if((c[x>>2]|0)==0|(J|0)==0){break}J=I<<12;c[F+35868>>2]=K+(J<<1);L=I<<10;M=J+L|0;c[F+35872>>2]=K+(M<<1);J=M+L|0;c[F+35884>>2]=K+(J<<1);L=J+(I<<7)|0;c[F+35888>>2]=K+(L<<1);c[F+35892>>2]=K+(L+(I<<5)<<1);E=48}}while(0);if((E|0)==48){c[F+35856>>2]=c[H>>2];break}KIb(b,16,2353624,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=-12;i=h;return p|0}}while(0);r=m+1154|0;F=m+1155|0;do{if((a[r]|0)!=0){if((a[F]|0)==0){break}x=m+29836|0;C=m+1156|0;w=m+1812|0;I=m+10279|0;L=0;while(1){if((L|0)<4){N=0}else{break}while(1){K=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)|0;J=I+(L*1584|0)+(N*66|0)|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+3|0;K=I+(L*1584|0)+(N*66|0)+11|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+6|0;J=I+(L*1584|0)+(N*66|0)+22|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+9|0;K=I+(L*1584|0)+(N*66|0)+33|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+12|0;J=I+(L*1584|0)+(N*66|0)+44|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+(N*18|0)+15|0;K=I+(L*1584|0)+(N*66|0)+55|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=N+1|0;if((K|0)<6){N=K}else{O=0;break}}while(1){K=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)|0;J=I+(L*1584|0)+396+(O*66|0)|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+3|0;K=I+(L*1584|0)+396+(O*66|0)+11|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+6|0;J=I+(L*1584|0)+396+(O*66|0)+22|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+9|0;K=I+(L*1584|0)+396+(O*66|0)+33|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+12|0;J=I+(L*1584|0)+396+(O*66|0)+44|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+108+(O*18|0)+15|0;K=I+(L*1584|0)+396+(O*66|0)+55|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=O+1|0;if((K|0)<6){O=K}else{P=0;break}}while(1){K=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)|0;J=I+(L*1584|0)+792+(P*66|0)|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+3|0;K=I+(L*1584|0)+792+(P*66|0)+11|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+6|0;J=I+(L*1584|0)+792+(P*66|0)+22|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+9|0;K=I+(L*1584|0)+792+(P*66|0)+33|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+12|0;J=I+(L*1584|0)+792+(P*66|0)+44|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+216+(P*18|0)+15|0;K=I+(L*1584|0)+792+(P*66|0)+55|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=P+1|0;if((K|0)<6){P=K}else{Q=0;break}}do{K=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)|0;J=I+(L*1584|0)+1188+(Q*66|0)|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+3|0;K=I+(L*1584|0)+1188+(Q*66|0)+11|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+6|0;J=I+(L*1584|0)+1188+(Q*66|0)+22|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+9|0;K=I+(L*1584|0)+1188+(Q*66|0)+33|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;K=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+12|0;J=I+(L*1584|0)+1188+(Q*66|0)+44|0;a[K]=a[J]|0;a[K+1|0]=a[J+1|0]|0;a[K+2|0]=a[J+2|0]|0;J=w+((d[C]|0)*2039|0)+311+(L*432|0)+324+(Q*18|0)+15|0;K=I+(L*1584|0)+1188+(Q*66|0)+55|0;a[J]=a[K]|0;a[J+1|0]=a[K+1|0]|0;a[J+2|0]=a[K+2|0]|0;Q=Q+1|0;}while((Q|0)<6);if((c[x>>2]|0)==(L|0)){break}else{L=L+1|0}}nrc(w+((d[C]|0)*2039|0)|0,m+9968|0,311)|0;K5a(b)}}while(0);Q=m+1080|0;P=m+1084|0;O=m+35860|0;N=m+35864|0;L=m+35868|0;x=m+35876|0;I=m+35872|0;H=m+35880|0;K=m+35884|0;J=m+35896|0;M=m+35888|0;R=m+35900|0;S=m+35892|0;T=m+35904|0;U=m+1776|0;V=m+1156|0;W=m+1144|0;X=m+1138|0;Y=c[341986]|0;Z=0;_=c[341982]|0;$=0;aa=m+17612|0;ba=m+17616|0;da=m+17620|0;ea=m+17624|0;fa=m+17628|0;ga=m+17632|0;ha=m+17348|0;ia=m+17352|0;ja=m+17356|0;ka=m+17360|0;la=m+17364|0;ma=m+17368|0;na=m+17372|0;oa=m+17376|0;pa=m+29840|0;qa=m+29836|0;ra=m+1148|0;sa=m+17636|0;ta=m+17640|0;ua=m+17644|0;va=m+17648|0;wa=m+1147|0;xa=m+10159|0;ya=m+10147|0;za=m+10153|0;Aa=m+10157|0;Ba=m+1780|0;Ca=m+1784|0;Da=m+1768|0;Ea=m+1800|0;Fa=m+30160|0;Ga=m+1772|0;Ha=o<<6;Ia=t<<5;Ja=m+1804|0;Ka=m+30148|0;La=v|0;Ma=o*63|0;o=m+30152|0;Na=v+4|0;Oa=t*31|0;t=m+30156|0;Pa=v+8|0;v=m+1408|0;Qa=m+1788|0;Ra=m+1792|0;Sa=m+1764|0;Ta=m+1072|0;Ua=m+1052|0;Va=m+30032|0;Wa=m+29872|0;Xa=Wa;Ya=m+29856|0;Za=m+30016|0;_a=m+30056|0;$a=q;q=k;a:while(1){c[P>>2]=c[Q>>2];c[N>>2]=c[O>>2];c[x>>2]=c[L>>2];c[H>>2]=c[I>>2];c[J>>2]=c[K>>2];c[R>>2]=c[M>>2];c[T>>2]=c[S>>2];if((c[U>>2]|0)==0){ab=q;bb=$a}else{k=0;cb=0;db=0;eb=q;fb=$a;while(1){gb=c[Da>>2]|0;hb=c[Ea>>2]|0;ib=(ca(hb,k)|0)>>gb;jb=k+1|0;kb=(ca(hb,jb)|0)>>gb;gb=((ib|0)>(hb|0)?hb:ib)<<3;c[Ba>>2]=gb;ib=((kb|0)>(hb|0)?hb:kb)<<3;c[Ca>>2]=ib;do{if((c[A>>2]|0)==2){lb=fb;mb=eb;nb=gb;ob=ib}else{kb=c[Ga>>2]|0;if((kb|0)==0){lb=fb;mb=eb;nb=gb;ob=ib;break}else{pb=0;qb=eb;rb=fb;sb=kb}do{if((pb|0)==(sb-1|0)){if((k|0)==((c[U>>2]|0)-1|0)){tb=qb;ub=rb;vb=qb}else{E=63}}else{E=63}if((E|0)==63){E=0;kb=rb;hb=je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0;kb=qb-4|0;if(hb>>>0>kb>>>0){E=65;break a}tb=kb;ub=rb+4|0;vb=hb}V9a((c[Ta>>2]|0)+(pb*20|0)|0,ub,vb);hb=c[Ta>>2]|0;wb=hb+(pb*20|0)|0;kb=c[wb>>2]|0;xb=d[1252840+kb|0]|0;yb=hb+(pb*20|0)+4|0;zb=c[yb>>2]|0;Ab=hb+(pb*20|0)+16|0;Bb=c[Ab>>2]|0;Cb=kb<<xb;c[wb>>2]=Cb;kb=Bb<<xb;Bb=zb+xb|0;do{if((Bb|0)>-1){xb=hb+(pb*20|0)+8|0;zb=c[xb>>2]|0;if(!(zb>>>0<(c[hb+(pb*20|0)+12>>2]|0)>>>0)){Db=kb;Eb=Bb;break}c[xb>>2]=zb+2;xb=zb;Db=((he((d[xb]|d[xb+1|0]<<8)<<16>>16|0)|0)&65535)<<Bb|kb;Eb=Bb-16|0}else{Db=kb;Eb=Bb}}while(0);c[yb>>2]=Eb;Fb=((Cb<<7)-128>>8)+1|0;Gb=Fb<<16;if(!(Db>>>0<Gb>>>0)){E=70;break a}c[wb>>2]=Fb;c[Ab>>2]=Db;rb=ub+vb|0;qb=tb-vb|0;pb=pb+1|0;sb=c[Ga>>2]|0;}while(pb>>>0<sb>>>0);lb=rb;mb=qb;nb=c[Ba>>2]|0;ob=c[Ca>>2]|0}}while(0);if(nb>>>0<ob>>>0){ib=nb;gb=cb;Bb=db;while(1){if((c[Ga>>2]|0)!=0){kb=0;hb=c[Fa>>2]|0;xb=gb;zb=Bb;while(1){Hb=c[Sa>>2]|0;Ib=c[D>>2]|0;Jb=(ca(Ib,kb)|0)>>Hb;Kb=kb+1|0;Lb=(ca(Ib,Kb)|0)>>Hb;Hb=((Jb|0)>(Ib|0)?Ib:Jb)<<3;c[Qa>>2]=Hb;Jb=((Lb|0)>(Ib|0)?Ib:Lb)<<3;c[Ra>>2]=Jb;Lb=c[A>>2]|0;if((Lb|0)!=2){mrc(Va|0,0,16)|0;do{if((a[j]|0)==0){if((a[W]|0)!=0){E=79;break}c[Xa>>2]=168430090;c[Xa+4>>2]=168430090}else{E=79}}while(0);if((E|0)==79){E=0;mrc(Wa|0,2,16)|0}mrc(Ya|0,0,16)|0;mrc(Za|0,0,16)|0;c[_a>>2]=0;c[_a+4>>2]=0;yb=(c[Ta>>2]|0)+(kb*20|0)|0;c[Ua>>2]=c[yb>>2];c[Ua+4>>2]=c[yb+4>>2];c[Ua+8>>2]=c[yb+8>>2];c[Ua+12>>2]=c[yb+12>>2];c[Ua+16>>2]=c[yb+16>>2]}if(Hb>>>0<Jb>>>0){yb=Hb;Ib=hb;Mb=xb;Nb=zb;Ob=Lb;while(1){do{if((Ob|0)==1){E=86}else{mrc(Ib+64|0,0,128)|0;if((c[A>>2]|0)!=2){E=86;break}vbb(b,ib,yb,Ib,Mb,Nb,0)}}while(0);if((E|0)==86){E=0;wbb(b,ib,yb,Ib,Mb,Nb,0)}Pb=yb+8|0;Qb=Mb+64|0;Rb=Nb+32|0;Sb=Ib+192|0;Tb=c[A>>2]|0;if(Pb>>>0<(c[Ra>>2]|0)>>>0){yb=Pb;Ib=Sb;Mb=Qb;Nb=Rb;Ob=Tb}else{Ub=Sb;Vb=Qb;Wb=Rb;Xb=Tb;break}}}else{Ub=hb;Vb=xb;Wb=zb;Xb=Lb}if((Xb|0)!=2){Ob=(c[Ta>>2]|0)+(kb*20|0)|0;c[Ob>>2]=c[Ua>>2];c[Ob+4>>2]=c[Ua+4>>2];c[Ob+8>>2]=c[Ua+8>>2];c[Ob+12>>2]=c[Ua+12>>2];c[Ob+16>>2]=c[Ua+16>>2]}if(Kb>>>0<(c[Ga>>2]|0)>>>0){kb=Kb;hb=Ub;xb=Vb;zb=Wb}else{break}}}zb=ib+8|0;if((c[A>>2]|0)!=1){if(zb>>>0<(c[Ja>>2]|0)>>>0){nrc(c[Ka>>2]|0,(c[La>>2]|0)+(gb+Ma)|0,c[B>>2]<<3)|0;xb=Bb+Oa|0;nrc(c[o>>2]|0,(c[Na>>2]|0)+xb|0,c[B>>2]<<2)|0;nrc(c[t>>2]|0,(c[Pa>>2]|0)+xb|0,c[B>>2]<<2)|0}b:do{if((a[v]|0)!=0){if((c[B>>2]|0)==0){break}xb=0;hb=c[Fa>>2]|0;kb=gb;Ob=Bb;while(1){Nb=c[g>>2]|0;Mb=c[Nb+1360>>2]|0;Ib=Mb|0;yb=hb|0;Hb=c[Mb+32>>2]|0;Jb=c[Mb+36>>2]|0;Tb=Hb<<4;Rb=(xb|0)!=0;Qb=Nb+320|0;Sb=Qb;Pb=Hb<<3;Yb=Qb;Qb=Pb|4;Zb=Nb+352|0;_b=Zb;$b=Zb;Zb=Nb+336|0;ac=Nb+344|0;bc=0;cc=yb;dc=(c[Ib>>2]|0)+kb|0;while(1){ec=hb+64+(bc<<2)|0;fc=bc|1;gc=hb+64+(fc<<2)|0;hc=hb+64+(bc<<2)+1|0;ic=a[hc]|a[ec]|a[hb+64+(bc<<2)+2|0];jc=ic&255;kc=a[hb+64+(bc<<2)+3|0]|0;lc=kc&255;mc=hb+64+(fc<<2)+1|0;nc=a[hb+64+(fc<<2)+2|0]|a[mc];oc=nc&255;pc=a[hb+64+(fc<<2)+3|0]|0;fc=pc&255;qc=kc|ic|nc|pc;pc=qc&255;if(!(qc<<24>>24==0)){qc=cc;nc=dc;ic=1;while(1){do{if((ic&jc|0)==0){if((ic&oc|0)==0){break}kc=d[qc+8|0]|0;if(!(Rb|(ic|0)>1)){break}pe[c[Sb+(((a[mc]&255&ic|0)!=0)<<3)>>2]&1023](nc+Pb|0,Hb,d[Nb+(kc+1474)|0]|0,d[Nb+(kc+1410)|0]|0,kc>>>4)}else{kc=d[qc]|0;rc=kc>>>4;sc=d[Nb+(kc+1474)|0]|0;tc=d[Nb+(kc+1410)|0]|0;if(!(Rb|(ic|0)>1)){break}if((d[ec]&ic|0)==0){if((ic&oc|0)==0){pe[c[Sb+(((a[hc]&255&ic|0)!=0)<<3)>>2]&1023](nc,Hb,sc,tc,rc);break}else{kc=d[qc+8|0]|0;pe[c[$b+(((a[hc]&255&ic|0)!=0)<<4)+(((a[mc]&255&ic|0)!=0)<<3)>>2]&1023](nc,Hb,d[Nb+(kc+1474)|0]<<8|sc,d[Nb+(kc+1410)|0]<<8|tc,kc>>>4<<8|rc);break}}else{if((d[gc]&ic|0)==0){pe[c[Zb>>2]&1023](nc,Hb,sc,tc,rc);break}else{pe[c[ac>>2]&1023](nc,Hb,sc,tc,rc);break}}}}while(0);do{if((ic&lc|0)==0){if((ic&fc|0)==0){break}rc=d[qc+8|0]|0;pe[c[Yb>>2]&1023](nc+Qb|0,Hb,d[Nb+(rc+1474)|0]|0,d[Nb+(rc+1410)|0]|0,rc>>>4)}else{rc=d[qc]|0;tc=rc>>>4;sc=d[Nb+(rc+1474)|0]|0;kc=d[Nb+(rc+1410)|0]|0;if((ic&fc|0)==0){pe[c[Yb>>2]&1023](nc+4|0,Hb,sc,kc,tc);break}else{rc=d[qc+8|0]|0;pe[c[_b>>2]&1023](nc+4|0,Hb,d[Nb+(rc+1474)|0]<<8|sc,d[Nb+(rc+1410)|0]<<8|kc,rc>>>4<<8|tc);break}}}while(0);tc=ic<<1;if((pc&-tc|0)==0){break}else{qc=qc+1|0;nc=nc+8|0;ic=tc}}}ic=bc+2|0;if((ic|0)<8){bc=ic;cc=cc+16|0;dc=dc+Tb|0}else{break}}Tb=Nb+324|0;dc=Hb<<2;cc=dc+8|0;bc=Nb+356|0;_b=Nb+340|0;Yb=Nb+348|0;Qb=0;ic=yb;nc=(c[Ib>>2]|0)+kb|0;while(1){qc=hb+96+(Qb<<2)|0;pc=hb+96+(Qb<<2)+1|0;fc=a[pc]|a[qc]|a[hb+96+(Qb<<2)+2|0];lc=fc&255;gc=d[hb+96+(Qb<<2)+3|0]|0;if(!(fc<<24>>24==0)){fc=(Qb|ib|0)==0;mc=ic;hc=nc;oc=1;while(1){do{if(!fc){if((oc&lc|0)==0){ec=oc<<1;if((ec&lc|0)==0){break}jc=d[mc+1|0]|0;pe[c[Sb+(((a[pc]&255&ec|0)!=0)<<3)+4>>2]&1023](hc+8|0,Hb,d[Nb+(jc+1474)|0]|0,d[Nb+(jc+1410)|0]|0,jc>>>4);break}jc=d[mc]|0;ec=jc>>>4;tc=d[Nb+(jc+1474)|0]|0;rc=d[Nb+(jc+1410)|0]|0;jc=d[qc]|0;kc=oc<<1;if((jc&oc|0)==0){if((kc&lc|0)==0){pe[c[Sb+(((a[pc]&255&oc|0)!=0)<<3)+4>>2]&1023](hc,Hb,tc,rc,ec);break}else{sc=d[mc+1|0]|0;uc=d[pc]|0;pe[c[$b+(((uc&oc|0)!=0)<<4)+(((uc&kc|0)!=0)<<3)+4>>2]&1023](hc,Hb,d[Nb+(sc+1474)|0]<<8|tc,d[Nb+(sc+1410)|0]<<8|rc,sc>>>4<<8|ec);break}}else{if((jc&kc|0)==0){pe[c[_b>>2]&1023](hc,Hb,tc,rc,ec);break}else{pe[c[Yb>>2]&1023](hc,Hb,tc,rc,ec);break}}}}while(0);do{if((oc&gc|0)==0){if((oc<<1&gc|0)==0){break}ec=d[mc+1|0]|0;pe[c[Tb>>2]&1023](hc+cc|0,Hb,d[Nb+(ec+1474)|0]|0,d[Nb+(ec+1410)|0]|0,ec>>>4)}else{ec=d[mc]|0;rc=ec>>>4;tc=d[Nb+(ec+1474)|0]|0;kc=d[Nb+(ec+1410)|0]|0;if((oc<<1&gc|0)==0){pe[c[Tb>>2]&1023](hc+dc|0,Hb,tc,kc,rc);break}else{ec=d[mc+1|0]|0;pe[c[bc>>2]&1023](hc+dc|0,Hb,d[Nb+(ec+1474)|0]<<8|tc,d[Nb+(ec+1410)|0]<<8|kc,ec>>>4<<8|rc);break}}}while(0);rc=oc<<2;if((lc&-rc|0)==0){break}else{mc=mc+2|0;hc=hc+16|0;oc=rc}}}oc=Qb+1|0;if((oc|0)<8){Qb=oc;ic=ic+8|0;nc=nc+Pb|0}else{break}}Pb=Jb<<4;nc=Jb<<3;ic=Jb<<2;Qb=0;do{Qb=Qb+1|0;Hb=Mb+(Qb<<2)|0;dc=0;bc=yb;Tb=(c[Hb>>2]|0)+Ob|0;while(1){cc=hb+128+(dc<<2)|0;Ib=dc|2;oc=hb+128+(Ib<<2)|0;hc=hb+128+(dc<<2)+1|0;mc=a[hc]|a[cc]|a[hb+128+(dc<<2)+2|0];lc=mc&255;gc=hb+128+(Ib<<2)+1|0;pc=a[hb+128+(Ib<<2)+2|0]|a[gc];Ib=pc&255;qc=pc|mc;mc=qc&255;if(!(qc<<24>>24==0)){qc=Tb;pc=bc;fc=1;while(1){do{if(Rb|(fc|0)>1){if((fc&lc|0)==0){if((fc&Ib|0)==0){break}rc=d[pc+16|0]|0;pe[c[Sb+(((a[gc]&255&fc|0)!=0)<<3)>>2]&1023](qc+nc|0,Jb,d[Nb+(rc+1474)|0]|0,d[Nb+(rc+1410)|0]|0,rc>>>4);break}rc=d[pc]|0;ec=rc>>>4;kc=d[Nb+(rc+1474)|0]|0;tc=d[Nb+(rc+1410)|0]|0;if((d[cc]&fc|0)==0){if((fc&Ib|0)==0){pe[c[Sb+(((a[hc]&255&fc|0)!=0)<<3)>>2]&1023](qc,Jb,kc,tc,ec);break}else{rc=d[pc+16|0]|0;pe[c[$b+(((a[hc]&255&fc|0)!=0)<<4)+(((a[gc]&255&fc|0)!=0)<<3)>>2]&1023](qc,Jb,d[Nb+(rc+1474)|0]<<8|kc,d[Nb+(rc+1410)|0]<<8|tc,rc>>>4<<8|ec);break}}else{if((d[oc]&fc|0)==0){pe[c[Zb>>2]&1023](qc,Jb,kc,tc,ec);break}else{pe[c[ac>>2]&1023](qc,Jb,kc,tc,ec);break}}}}while(0);ec=fc<<1;if((mc&-ec|0)==0){break}else{qc=qc+4|0;pc=(fc&170|0)==0?pc:pc+2|0;fc=ec}}}fc=dc+4|0;if((fc|0)<8){dc=fc;bc=bc+32|0;Tb=Tb+Pb|0}else{break}}Tb=0;bc=yb;dc=(c[Hb>>2]|0)+Ob|0;while(1){fc=hb+160+(Tb<<2)|0;pc=hb+160+(Tb<<2)+1|0;qc=a[pc]|a[fc]|a[hb+160+(Tb<<2)+2|0];mc=qc&255;if(!(qc<<24>>24==0)){qc=(Tb|ib|0)==0;oc=dc;gc=bc;hc=1;while(1){do{if(!qc){if((hc&mc|0)==0){Ib=hc<<2;if((Ib&mc|0)==0){break}cc=d[gc+2|0]|0;pe[c[Sb+(((a[pc]&255&Ib|0)!=0)<<3)+4>>2]&1023](oc+8|0,Jb,d[Nb+(cc+1474)|0]|0,d[Nb+(cc+1410)|0]|0,cc>>>4);break}cc=d[gc]|0;Ib=cc>>>4;lc=d[Nb+(cc+1474)|0]|0;ec=d[Nb+(cc+1410)|0]|0;cc=d[fc]|0;tc=hc<<2;if((cc&hc|0)==0){if((tc&mc|0)==0){pe[c[Sb+(((a[pc]&255&hc|0)!=0)<<3)+4>>2]&1023](oc,Jb,lc,ec,Ib);break}else{kc=d[gc+2|0]|0;rc=d[pc]|0;pe[c[$b+(((rc&hc|0)!=0)<<4)+(((rc&tc|0)!=0)<<3)+4>>2]&1023](oc,Jb,d[Nb+(kc+1474)|0]<<8|lc,d[Nb+(kc+1410)|0]<<8|ec,kc>>>4<<8|Ib);break}}else{if((cc&tc|0)==0){pe[c[_b>>2]&1023](oc,Jb,lc,ec,Ib);break}else{pe[c[Yb>>2]&1023](oc,Jb,lc,ec,Ib);break}}}}while(0);Ib=hc<<4;if((mc&-Ib|0)==0){break}else{oc=oc+16|0;gc=gc+4|0;hc=Ib}}}hc=(Tb&1|0)==0?bc:bc+16|0;gc=Tb+1|0;if((gc|0)<8){Tb=gc;bc=hc;dc=dc+ic|0}else{break}}}while((Qb|0)<2);Qb=xb+8|0;if(!(Qb>>>0<(c[B>>2]|0)>>>0)){break b}xb=Qb;hb=hb+192|0;kb=kb+64|0;Ob=Ob+32|0}}}while(0);L5a(l,ib>>3,0)}Ob=gb+Ha|0;kb=Bb+Ia|0;if(zb>>>0<(c[Ca>>2]|0)>>>0){ib=zb;gb=Ob;Bb=kb}else{vc=Ob;wc=kb;break}}}else{vc=cb;wc=db}if(jb>>>0<(c[U>>2]|0)>>>0){k=jb;cb=vc;db=wc;eb=mb;fb=lb}else{ab=mb;bb=lb;break}}}xc=c[A>>2]|0;if((xc|0)>=2){E=179;break}do{if((a[r]|0)==0){yc=xc}else{if((a[F]|0)!=0){yc=xc;break}fb=d[V]|0;do{if((a[j]|0)==0){if((a[W]|0)!=0){zc=0;Ac=112;break}eb=(a[X]|0)==0;zc=eb?0:0;Ac=eb?112:128}else{zc=0;Ac=112}}while(0);jb=Erc(Y,Z,Ac,zc)|0;eb=G;db=0;do{cb=0;do{k=0;do{C=0;do{w=(C|0)==0;Bb=0;do{gb=d[V]|0;ib=n+1812+(gb*2039|0)+311+(db*432|0)+(cb*216|0)+(k*108|0)+(C*18|0)+(Bb*3|0)|0;kb=n+18316+(db*1728|0)+(cb*864|0)+(k*432|0)+(C*72|0)+(Bb*12|0)|0;if(w&(Bb|0)>2){break}Ob=c[n+25228+(db*1152|0)+(cb*576|0)+(k*288|0)+(C*48|0)+(Bb<<3)>>2]|0;hb=(c[n+25228+(db*1152|0)+(cb*576|0)+(k*288|0)+(C*48|0)+(Bb<<3)+4>>2]|0)+Ob|0;if((hb|0)!=0){xb=d[ib]|0;Kb=(((hb>>>1)+(Ob<<8)|0)>>>0)/(hb>>>0)|0;if((Kb|0)<1){Bc=1}else{Bc=(Kb|0)>255?255:Kb}Kb=hb>>>0>24>>>0;Erc(jb,eb,Kb?24:hb,Kb?0:0)|0;a[ib]=(((ca(Bc-xb|0,G)|0)+128|0)>>>8)+xb}xb=n+1812+(gb*2039|0)+311+(db*432|0)+(cb*216|0)+(k*108|0)+(C*18|0)+(Bb*3|0)+1|0;ib=c[kb>>2]|0;kb=n+18316+(db*1728|0)+(cb*864|0)+(k*432|0)+(C*72|0)+(Bb*12|0)+4|0;Kb=c[kb>>2]|0;hb=n+18316+(db*1728|0)+(cb*864|0)+(k*432|0)+(C*72|0)+(Bb*12|0)+8|0;Ob=c[hb>>2]|0;Lb=Kb+ib+Ob|0;if((Lb|0)==0){Cc=Kb;Dc=Ob}else{Ob=d[xb]|0;Kb=(((Lb>>>1)+(ib<<8)|0)>>>0)/(Lb>>>0)|0;if((Kb|0)<1){Ec=1}else{Ec=(Kb|0)>255?255:Kb}Kb=Lb>>>0>24>>>0;Erc(jb,eb,Kb?24:Lb,Kb?0:0)|0;a[xb]=(((ca(Ec-Ob|0,G)|0)+128|0)>>>8)+Ob;Cc=c[kb>>2]|0;Dc=c[hb>>2]|0}hb=n+1812+(gb*2039|0)+311+(db*432|0)+(cb*216|0)+(k*108|0)+(C*18|0)+(Bb*3|0)+2|0;gb=Cc+Dc|0;if((gb|0)!=0){kb=d[hb]|0;Ob=(((gb>>>1)+(Cc<<8)|0)>>>0)/(gb>>>0)|0;if((Ob|0)<1){Fc=1}else{Fc=(Ob|0)>255?255:Ob}Ob=gb>>>0>24>>>0;Erc(jb,eb,Ob?24:gb,Ob?0:0)|0;a[hb]=(((ca(Fc-kb|0,G)|0)+128|0)>>>8)+kb}Bb=Bb+1|0;}while((Bb|0)<6);C=C+1|0;}while((C|0)<6);k=k+1|0;}while((k|0)<2);cb=cb+1|0;}while((cb|0)<2);db=db+1|0;}while((db|0)<4);do{if((a[j]|0)==0){if((a[W]|0)!=0){E=211;break}db=n+1812+(fb*2039|0)+191|0;eb=c[aa>>2]|0;jb=(c[ba>>2]|0)+eb|0;if((jb|0)!=0){cb=d[db]|0;zb=(((jb>>>1)+(eb<<8)|0)>>>0)/(jb>>>0)|0;if((zb|0)<1){Gc=1}else{Gc=(zb|0)>255?255:zb}zb=jb>>>0>20>>>0;eb=jb;Erc(zb?2560:eb<<7|0>>>25,zb?0:0<<7|eb>>>25,_,$)|0;a[db]=(((ca(Gc-cb|0,G)|0)+128|0)>>>8)+cb}cb=n+1812+(fb*2039|0)+192|0;db=c[da>>2]|0;eb=(c[ea>>2]|0)+db|0;if((eb|0)!=0){zb=d[cb]|0;jb=(((eb>>>1)+(db<<8)|0)>>>0)/(eb>>>0)|0;if((jb|0)<1){Hc=1}else{Hc=(jb|0)>255?255:jb}jb=eb>>>0>20>>>0;db=eb;Erc(jb?2560:db<<7|0>>>25,jb?0:0<<7|db>>>25,_,$)|0;a[cb]=(((ca(Hc-zb|0,G)|0)+128|0)>>>8)+zb}zb=n+1812+(fb*2039|0)+193|0;cb=c[fa>>2]|0;db=(c[ga>>2]|0)+cb|0;if((db|0)!=0){jb=d[zb]|0;eb=(((db>>>1)+(cb<<8)|0)>>>0)/(db>>>0)|0;if((eb|0)<1){Ic=1}else{Ic=(eb|0)>255?255:eb}eb=db>>>0>20>>>0;cb=db;Erc(eb?2560:cb<<7|0>>>25,eb?0:0<<7|cb>>>25,_,$)|0;a[zb]=(((ca(Ic-jb|0,G)|0)+128|0)>>>8)+jb}jb=n+1812+(fb*2039|0)+155|0;zb=c[ha>>2]|0;cb=(c[ia>>2]|0)+zb|0;if((cb|0)!=0){eb=d[jb]|0;db=(((cb>>>1)+(zb<<8)|0)>>>0)/(cb>>>0)|0;if((db|0)<1){Jc=1}else{Jc=(db|0)>255?255:db}db=cb>>>0>20>>>0;zb=cb;Erc(db?2560:zb<<7|0>>>25,db?0:0<<7|zb>>>25,_,$)|0;a[jb]=(((ca(Jc-eb|0,G)|0)+128|0)>>>8)+eb}eb=n+1812+(fb*2039|0)+156|0;jb=c[ja>>2]|0;zb=(c[ka>>2]|0)+jb|0;if((zb|0)!=0){db=d[eb]|0;cb=(((zb>>>1)+(jb<<8)|0)>>>0)/(zb>>>0)|0;if((cb|0)<1){Kc=1}else{Kc=(cb|0)>255?255:cb}cb=zb>>>0>20>>>0;jb=zb;Erc(cb?2560:jb<<7|0>>>25,cb?0:0<<7|jb>>>25,_,$)|0;a[eb]=(((ca(Kc-db|0,G)|0)+128|0)>>>8)+db}db=n+1812+(fb*2039|0)+157|0;eb=c[la>>2]|0;jb=(c[ma>>2]|0)+eb|0;if((jb|0)!=0){cb=d[db]|0;zb=(((jb>>>1)+(eb<<8)|0)>>>0)/(jb>>>0)|0;if((zb|0)<1){Lc=1}else{Lc=(zb|0)>255?255:zb}zb=jb>>>0>20>>>0;eb=jb;Erc(zb?2560:eb<<7|0>>>25,zb?0:0<<7|eb>>>25,_,$)|0;a[db]=(((ca(Lc-cb|0,G)|0)+128|0)>>>8)+cb}cb=n+1812+(fb*2039|0)+158|0;db=c[na>>2]|0;eb=(c[oa>>2]|0)+db|0;if((eb|0)!=0){zb=d[cb]|0;jb=(((eb>>>1)+(db<<8)|0)>>>0)/(eb>>>0)|0;if((jb|0)<1){Mc=1}else{Mc=(jb|0)>255?255:jb}jb=eb>>>0>20>>>0;db=eb;Erc(jb?2560:db<<7|0>>>25,jb?0:0<<7|db>>>25,_,$)|0;a[cb]=(((ca(Mc-zb|0,G)|0)+128|0)>>>8)+zb}zb=c[pa>>2]|0;if((zb|0)==2){cb=0;do{db=n+1812+(fb*2039|0)+159+cb|0;jb=c[n+17380+(cb<<3)>>2]|0;eb=(c[n+17380+(cb<<3)+4>>2]|0)+jb|0;if((eb|0)!=0){k=d[db]|0;C=(((eb>>>1)+(jb<<8)|0)>>>0)/(eb>>>0)|0;if((C|0)<1){Nc=1}else{Nc=(C|0)>255?255:C}C=eb>>>0>20>>>0;jb=eb;Erc(C?2560:jb<<7|0>>>25,C?0:0<<7|jb>>>25,_,$)|0;a[db]=(((ca(Nc-k|0,G)|0)+128|0)>>>8)+k}cb=cb+1|0;}while((cb|0)<5);Oc=c[pa>>2]|0}else{Oc=zb}if((Oc|0)==0){Pc=0;E=233}else{cb=0;do{k=n+1812+(fb*2039|0)+174+cb|0;db=c[n+17500+(cb<<3)>>2]|0;jb=(c[n+17500+(cb<<3)+4>>2]|0)+db|0;if((jb|0)!=0){C=d[k]|0;eb=(((jb>>>1)+(db<<8)|0)>>>0)/(jb>>>0)|0;if((eb|0)<1){Qc=1}else{Qc=(eb|0)>255?255:eb}eb=jb>>>0>20>>>0;db=jb;Erc(eb?2560:db<<7|0>>>25,eb?0:0<<7|db>>>25,_,$)|0;a[k]=(((ca(Qc-C|0,G)|0)+128|0)>>>8)+C}cb=cb+1|0;}while((cb|0)<5);if((c[pa>>2]|0)==1){Rc=0}else{Pc=0;E=233}}if((E|0)==233){while(1){E=0;cb=n+1812+(fb*2039|0)+164+(Pc<<1)|0;zb=c[n+17420+(Pc<<4)>>2]|0;C=(c[n+17420+(Pc<<4)+4>>2]|0)+zb|0;if((C|0)!=0){k=d[cb]|0;db=(((C>>>1)+(zb<<8)|0)>>>0)/(C>>>0)|0;if((db|0)<1){Sc=1}else{Sc=(db|0)>255?255:db}db=C>>>0>20>>>0;zb=C;Erc(db?2560:zb<<7|0>>>25,db?0:0<<7|zb>>>25,_,$)|0;a[cb]=(((ca(Sc-k|0,G)|0)+128|0)>>>8)+k}k=n+1812+(fb*2039|0)+164+(Pc<<1)+1|0;cb=c[n+17420+(Pc<<4)+8>>2]|0;zb=(c[n+17420+(Pc<<4)+12>>2]|0)+cb|0;if((zb|0)!=0){db=d[k]|0;C=(((zb>>>1)+(cb<<8)|0)>>>0)/(zb>>>0)|0;if((C|0)<1){Tc=1}else{Tc=(C|0)>255?255:C}C=zb>>>0>20>>>0;cb=zb;Erc(C?2560:cb<<7|0>>>25,C?0:0<<7|cb>>>25,_,$)|0;a[k]=(((ca(Tc-db|0,G)|0)+128|0)>>>8)+db}db=Pc+1|0;if((db|0)<5){Pc=db;E=233}else{Rc=0;break}}}do{db=0;do{k=n+1812+(fb*2039|0)+263+(Rc*12|0)+(db*3|0)|0;cb=c[n+18060+(Rc<<6)+(db<<4)>>2]|0;C=n+18060+(Rc<<6)+(db<<4)+4|0;zb=c[C>>2]|0;eb=n+18060+(Rc<<6)+(db<<4)+8|0;jb=c[eb>>2]|0;Bb=n+18060+(Rc<<6)+(db<<4)+12|0;w=c[Bb>>2]|0;kb=zb+cb+jb+w|0;if((kb|0)==0){Uc=zb;Vc=jb;Wc=w}else{w=d[k]|0;jb=(((kb>>>1)+(cb<<8)|0)>>>0)/(kb>>>0)|0;if((jb|0)<1){Xc=1}else{Xc=(jb|0)>255?255:jb}jb=kb>>>0>20>>>0;cb=kb;Erc(jb?2560:cb<<7|0>>>25,jb?0:0<<7|cb>>>25,_,$)|0;a[k]=(((ca(Xc-w|0,G)|0)+128|0)>>>8)+w;Uc=c[C>>2]|0;Vc=c[eb>>2]|0;Wc=c[Bb>>2]|0}C=n+1812+(fb*2039|0)+263+(Rc*12|0)+(db*3|0)+1|0;w=Vc+Wc+Uc|0;if((w|0)==0){Yc=Vc;Zc=Wc}else{k=d[C]|0;cb=(((w>>>1)+(Uc<<8)|0)>>>0)/(w>>>0)|0;if((cb|0)<1){_c=1}else{_c=(cb|0)>255?255:cb}cb=w>>>0>20>>>0;jb=w;Erc(cb?2560:jb<<7|0>>>25,cb?0:0<<7|jb>>>25,_,$)|0;a[C]=(((ca(_c-k|0,G)|0)+128|0)>>>8)+k;Yc=c[eb>>2]|0;Zc=c[Bb>>2]|0}Bb=n+1812+(fb*2039|0)+263+(Rc*12|0)+(db*3|0)+2|0;eb=Yc+Zc|0;if((eb|0)!=0){k=d[Bb]|0;C=(((eb>>>1)+(Yc<<8)|0)>>>0)/(eb>>>0)|0;if((C|0)<1){$c=1}else{$c=(C|0)>255?255:C}C=eb>>>0>20>>>0;jb=eb;Erc(C?2560:jb<<7|0>>>25,C?0:0<<7|jb>>>25,_,$)|0;a[Bb]=(((ca($c-k|0,G)|0)+128|0)>>>8)+k}db=db+1|0;}while((db|0)<4);Rc=Rc+1|0;}while((Rc|0)<4);if((c[qa>>2]|0)==4){db=0;do{k=n+17572+(db*12|0)|0;Bb=n+17540+(db<<4)|0;jb=n+1812+(fb*2039|0)+189+db|0;C=c[n+17596+(db<<3)>>2]|0;eb=(c[n+17596+(db<<3)+4>>2]|0)+C|0;if((eb|0)!=0){cb=d[jb]|0;w=(((eb>>>1)+(C<<8)|0)>>>0)/(eb>>>0)|0;if((w|0)<1){ad=1}else{ad=(w|0)>255?255:w}w=eb>>>0>20>>>0;C=eb;Erc(w?2560:C<<7|0>>>25,w?0:0<<7|C>>>25,_,$)|0;a[jb]=(((ca(ad-cb|0,G)|0)+128|0)>>>8)+cb}cb=n+1812+(fb*2039|0)+185+(db<<1)|0;jb=c[k>>2]|0;k=n+17572+(db*12|0)+4|0;C=c[k>>2]|0;w=n+17572+(db*12|0)+8|0;eb=c[w>>2]|0;kb=C+jb+eb|0;if((kb|0)==0){bd=C;cd=eb}else{eb=d[cb]|0;C=(((kb>>>1)+(jb<<8)|0)>>>0)/(kb>>>0)|0;if((C|0)<1){dd=1}else{dd=(C|0)>255?255:C}C=kb>>>0>20>>>0;jb=kb;Erc(C?2560:jb<<7|0>>>25,C?0:0<<7|jb>>>25,_,$)|0;a[cb]=(((ca(dd-eb|0,G)|0)+128|0)>>>8)+eb;bd=c[k>>2]|0;cd=c[w>>2]|0}w=n+1812+(fb*2039|0)+185+(db<<1)+1|0;k=bd+cd|0;if((k|0)!=0){eb=d[w]|0;cb=(((k>>>1)+(bd<<8)|0)>>>0)/(k>>>0)|0;if((cb|0)<1){ed=1}else{ed=(cb|0)>255?255:cb}cb=k>>>0>20>>>0;jb=k;Erc(cb?2560:jb<<7|0>>>25,cb?0:0<<7|jb>>>25,_,$)|0;a[w]=(((ca(ed-eb|0,G)|0)+128|0)>>>8)+eb}eb=n+1812+(fb*2039|0)+179+(db*3|0)|0;w=c[Bb>>2]|0;Bb=n+17540+(db<<4)+4|0;jb=c[Bb>>2]|0;cb=n+17540+(db<<4)+8|0;k=c[cb>>2]|0;C=n+17540+(db<<4)+12|0;kb=c[C>>2]|0;zb=jb+w+k+kb|0;if((zb|0)==0){fd=jb;gd=k;hd=kb}else{kb=d[eb]|0;k=(((zb>>>1)+(w<<8)|0)>>>0)/(zb>>>0)|0;if((k|0)<1){id=1}else{id=(k|0)>255?255:k}k=zb>>>0>20>>>0;w=zb;Erc(k?2560:w<<7|0>>>25,k?0:0<<7|w>>>25,_,$)|0;a[eb]=(((ca(id-kb|0,G)|0)+128|0)>>>8)+kb;fd=c[Bb>>2]|0;gd=c[cb>>2]|0;hd=c[C>>2]|0}Bb=n+1812+(fb*2039|0)+179+(db*3|0)+1|0;kb=gd+hd+fd|0;if((kb|0)==0){jd=gd;kd=hd}else{eb=d[Bb]|0;w=(((kb>>>1)+(fd<<8)|0)>>>0)/(kb>>>0)|0;if((w|0)<1){ld=1}else{ld=(w|0)>255?255:w}w=kb>>>0>20>>>0;k=kb;Erc(w?2560:k<<7|0>>>25,w?0:0<<7|k>>>25,_,$)|0;a[Bb]=(((ca(ld-eb|0,G)|0)+128|0)>>>8)+eb;jd=c[cb>>2]|0;kd=c[C>>2]|0}C=n+1812+(fb*2039|0)+179+(db*3|0)+2|0;cb=jd+kd|0;if((cb|0)!=0){eb=d[C]|0;Bb=(((cb>>>1)+(jd<<8)|0)>>>0)/(cb>>>0)|0;if((Bb|0)<1){md=1}else{md=(Bb|0)>255?255:Bb}Bb=cb>>>0>20>>>0;k=cb;Erc(Bb?2560:k<<7|0>>>25,Bb?0:0<<7|k>>>25,_,$)|0;a[C]=(((ca(md-eb|0,G)|0)+128|0)>>>8)+eb}db=db+1|0;}while((db|0)<2)}if((c[ra>>2]|0)==4){db=0;while(1){eb=n+1812+(fb*2039|0)+126+(db<<1)|0;C=c[n+17188+(db*12|0)>>2]|0;k=n+17188+(db*12|0)+4|0;Bb=c[k>>2]|0;cb=n+17188+(db*12|0)+8|0;w=c[cb>>2]|0;kb=Bb+C+w|0;if((kb|0)==0){nd=Bb;od=w}else{w=d[eb]|0;Bb=(((kb>>>1)+(C<<8)|0)>>>0)/(kb>>>0)|0;if((Bb|0)<1){pd=1}else{pd=(Bb|0)>255?255:Bb}Bb=kb>>>0>20>>>0;C=kb;Erc(Bb?2560:C<<7|0>>>25,Bb?0:0<<7|C>>>25,_,$)|0;a[eb]=(((ca(pd-w|0,G)|0)+128|0)>>>8)+w;nd=c[k>>2]|0;od=c[cb>>2]|0}cb=n+1812+(fb*2039|0)+126+(db<<1)+1|0;k=nd+od|0;if((k|0)!=0){w=d[cb]|0;eb=(((k>>>1)+(nd<<8)|0)>>>0)/(k>>>0)|0;if((eb|0)<1){qd=1}else{qd=(eb|0)>255?255:eb}eb=k>>>0>20>>>0;C=k;Erc(eb?2560:C<<7|0>>>25,eb?0:0<<7|C>>>25,_,$)|0;a[cb]=(((ca(qd-w|0,G)|0)+128|0)>>>8)+w}w=db+1|0;if((w|0)<4){db=w}else{rd=0;break}}}else{rd=0}do{db=n+1812+(fb*2039|0)+134+(rd*3|0)|0;w=n+17236+(rd<<4)|0;cb=c[n+17236+(rd<<4)+8>>2]|0;C=n+17236+(rd<<4)+4|0;eb=c[C>>2]|0;k=c[w>>2]|0;Bb=n+17236+(rd<<4)+12|0;kb=c[Bb>>2]|0;zb=eb+cb+k+kb|0;if((zb|0)==0){sd=k;td=eb;ud=kb}else{kb=d[db]|0;eb=(((zb>>>1)+(cb<<8)|0)>>>0)/(zb>>>0)|0;if((eb|0)<1){vd=1}else{vd=(eb|0)>255?255:eb}eb=zb>>>0>20>>>0;cb=zb;Erc(eb?2560:cb<<7|0>>>25,eb?0:0<<7|cb>>>25,_,$)|0;a[db]=(((ca(vd-kb|0,G)|0)+128|0)>>>8)+kb;sd=c[w>>2]|0;td=c[C>>2]|0;ud=c[Bb>>2]|0}w=n+1812+(fb*2039|0)+134+(rd*3|0)+1|0;kb=td+ud+sd|0;if((kb|0)==0){wd=td;xd=ud}else{db=d[w]|0;cb=(((kb>>>1)+(sd<<8)|0)>>>0)/(kb>>>0)|0;if((cb|0)<1){yd=1}else{yd=(cb|0)>255?255:cb}cb=kb>>>0>20>>>0;eb=kb;Erc(cb?2560:eb<<7|0>>>25,cb?0:0<<7|eb>>>25,_,$)|0;a[w]=(((ca(yd-db|0,G)|0)+128|0)>>>8)+db;wd=c[C>>2]|0;xd=c[Bb>>2]|0}Bb=n+1812+(fb*2039|0)+134+(rd*3|0)+2|0;C=wd+xd|0;if((C|0)!=0){db=d[Bb]|0;w=(((C>>>1)+(wd<<8)|0)>>>0)/(C>>>0)|0;if((w|0)<1){zd=1}else{zd=(w|0)>255?255:w}w=C>>>0>20>>>0;eb=C;Erc(w?2560:eb<<7|0>>>25,w?0:0<<7|eb>>>25,_,$)|0;a[Bb]=(((ca(zd-db|0,G)|0)+128|0)>>>8)+db}rd=rd+1|0;}while((rd|0)<7);db=n+1812+(fb*2039|0)+194|0;Bb=c[sa>>2]|0;eb=c[ta>>2]|0;w=c[ua>>2]|0;C=c[va>>2]|0;cb=eb+Bb+w+C|0;if((cb|0)==0){Ad=eb;Bd=w;Cd=C}else{C=d[db]|0;w=(((cb>>>1)+(Bb<<8)|0)>>>0)/(cb>>>0)|0;if((w|0)<1){Dd=1}else{Dd=(w|0)>255?255:w}w=cb>>>0>20>>>0;Bb=cb;Erc(w?2560:Bb<<7|0>>>25,w?0:0<<7|Bb>>>25,_,$)|0;a[db]=(((ca(Dd-C|0,G)|0)+128|0)>>>8)+C;Ad=c[ta>>2]|0;Bd=c[ua>>2]|0;Cd=c[va>>2]|0}C=n+1812+(fb*2039|0)+195|0;db=Bd+Cd+Ad|0;if((db|0)==0){Ed=Bd;Fd=Cd}else{Bb=d[C]|0;w=(((db>>>1)+(Ad<<8)|0)>>>0)/(db>>>0)|0;if((w|0)<1){Gd=1}else{Gd=(w|0)>255?255:w}w=db>>>0>20>>>0;cb=db;Erc(w?2560:cb<<7|0>>>25,w?0:0<<7|cb>>>25,_,$)|0;a[C]=(((ca(Gd-Bb|0,G)|0)+128|0)>>>8)+Bb;Ed=c[ua>>2]|0;Fd=c[va>>2]|0}Bb=n+1812+(fb*2039|0)+196|0;C=Ed+Fd|0;if((C|0)==0){Hd=0}else{cb=d[Bb]|0;w=(((C>>>1)+(Ed<<8)|0)>>>0)/(C>>>0)|0;if((w|0)<1){Id=1}else{Id=(w|0)>255?255:w}w=C>>>0>20>>>0;db=C;Erc(w?2560:db<<7|0>>>25,w?0:0<<7|db>>>25,_,$)|0;a[Bb]=(((ca(Id-cb|0,G)|0)+128|0)>>>8)+cb;Hd=0}while(1){cb=n+1812+(fb*2039|0)+197+(Hd*33|0)|0;Bb=c[n+17652+(Hd*204|0)>>2]|0;db=(c[n+17652+(Hd*204|0)+4>>2]|0)+Bb|0;if((db|0)!=0){w=d[cb]|0;C=(((db>>>1)+(Bb<<8)|0)>>>0)/(db>>>0)|0;if((C|0)<1){Jd=1}else{Jd=(C|0)>255?255:C}C=db>>>0>20>>>0;Bb=db;Erc(C?2560:Bb<<7|0>>>25,C?0:0<<7|Bb>>>25,_,$)|0;a[cb]=(((ca(Jd-w|0,G)|0)+128|0)>>>8)+w}w=n+1812+(fb*2039|0)+197+(Hd*33|0)+1|0;cb=n+17652+(Hd*204|0)+12|0;Bb=c[cb>>2]|0;C=n+17652+(Hd*204|0)+16|0;db=n+17652+(Hd*204|0)+20|0;eb=n+17652+(Hd*204|0)+24|0;kb=n+17652+(Hd*204|0)+28|0;zb=n+17652+(Hd*204|0)+32|0;k=n+17652+(Hd*204|0)+36|0;jb=n+17652+(Hd*204|0)+40|0;hb=n+17652+(Hd*204|0)+44|0;Ob=n+17652+(Hd*204|0)+48|0;gb=(c[C>>2]|0)+Bb+(c[db>>2]|0)+(c[eb>>2]|0)+(c[kb>>2]|0)+(c[zb>>2]|0)+(c[k>>2]|0)+(c[jb>>2]|0)+(c[hb>>2]|0)+(c[Ob>>2]|0)|0;xb=c[n+17652+(Hd*204|0)+8>>2]|0;Kb=gb+xb|0;if((Kb|0)==0){Kd=Bb}else{Bb=d[w]|0;Lb=(((Kb>>>1)+(xb<<8)|0)>>>0)/(Kb>>>0)|0;if((Lb|0)<1){Ld=1}else{Ld=(Lb|0)>255?255:Lb}Lb=Kb>>>0>20>>>0;xb=Kb;Erc(Lb?2560:xb<<7|0>>>25,Lb?0:0<<7|xb>>>25,_,$)|0;a[w]=(((ca(Ld-Bb|0,G)|0)+128|0)>>>8)+Bb;Kd=c[cb>>2]|0}cb=gb-Kd|0;Bb=n+1812+(fb*2039|0)+197+(Hd*33|0)+2|0;if((gb|0)!=0){w=d[Bb]|0;xb=(((Kd<<8)+(gb>>>1)|0)>>>0)/(gb>>>0)|0;if((xb|0)<1){Md=1}else{Md=(xb|0)>255?255:xb}xb=gb>>>0>20>>>0;Lb=gb;Erc(xb?2560:Lb<<7|0>>>25,xb?0:0<<7|Lb>>>25,_,$)|0;a[Bb]=(((ca(Md-w|0,G)|0)+128|0)>>>8)+w}w=c[C>>2]|0;Bb=c[db>>2]|0;Lb=Bb+w|0;xb=cb-Lb|0;Kb=n+1812+(fb*2039|0)+197+(Hd*33|0)+3|0;if((gb|0)==(Kd|0)){Nd=w;Od=Bb}else{Bb=d[Kb]|0;w=(((Lb<<8)+(cb>>>1)|0)>>>0)/(cb>>>0)|0;if((w|0)<1){Pd=1}else{Pd=(w|0)>255?255:w}w=cb>>>0>20>>>0;gb=cb;Erc(w?2560:gb<<7|0>>>25,w?0:0<<7|gb>>>25,_,$)|0;a[Kb]=(((ca(Pd-Bb|0,G)|0)+128|0)>>>8)+Bb;Nd=c[C>>2]|0;Od=c[db>>2]|0}db=n+1812+(fb*2039|0)+197+(Hd*33|0)+4|0;C=Nd+Od|0;if((C|0)!=0){Bb=d[db]|0;Kb=(((C>>>1)+(Nd<<8)|0)>>>0)/(C>>>0)|0;if((Kb|0)<1){Qd=1}else{Qd=(Kb|0)>255?255:Kb}Kb=C>>>0>20>>>0;gb=C;Erc(Kb?2560:gb<<7|0>>>25,Kb?0:0<<7|gb>>>25,_,$)|0;a[db]=(((ca(Qd-Bb|0,G)|0)+128|0)>>>8)+Bb}Bb=c[eb>>2]|0;db=c[kb>>2]|0;gb=db+Bb|0;Kb=xb-gb|0;C=n+1812+(fb*2039|0)+197+(Hd*33|0)+5|0;if((cb|0)==(Lb|0)){Rd=Bb;Sd=db}else{db=d[C]|0;Bb=(((gb<<8)+(xb>>>1)|0)>>>0)/(xb>>>0)|0;if((Bb|0)<1){Td=1}else{Td=(Bb|0)>255?255:Bb}Bb=xb>>>0>20>>>0;Lb=xb;Erc(Bb?2560:Lb<<7|0>>>25,Bb?0:0<<7|Lb>>>25,_,$)|0;a[C]=(((ca(Td-db|0,G)|0)+128|0)>>>8)+db;Rd=c[eb>>2]|0;Sd=c[kb>>2]|0}kb=n+1812+(fb*2039|0)+197+(Hd*33|0)+6|0;eb=Rd+Sd|0;if((eb|0)!=0){db=d[kb]|0;C=(((eb>>>1)+(Rd<<8)|0)>>>0)/(eb>>>0)|0;if((C|0)<1){Ud=1}else{Ud=(C|0)>255?255:C}C=eb>>>0>20>>>0;Lb=eb;Erc(C?2560:Lb<<7|0>>>25,C?0:0<<7|Lb>>>25,_,$)|0;a[kb]=(((ca(Ud-db|0,G)|0)+128|0)>>>8)+db}db=n+1812+(fb*2039|0)+197+(Hd*33|0)+7|0;if((xb|0)!=(gb|0)){gb=d[db]|0;xb=(((c[zb>>2]<<8)+(Kb>>>1)|0)>>>0)/(Kb>>>0)|0;if((xb|0)<1){Vd=1}else{Vd=(xb|0)>255?255:xb}xb=Kb>>>0>20>>>0;zb=Kb;Erc(xb?2560:zb<<7|0>>>25,xb?0:0<<7|zb>>>25,_,$)|0;a[db]=(((ca(Vd-gb|0,G)|0)+128|0)>>>8)+gb}gb=n+1812+(fb*2039|0)+197+(Hd*33|0)+8|0;db=c[k>>2]|0;zb=c[jb>>2]|0;xb=zb+db|0;Kb=xb+(c[hb>>2]|0)+(c[Ob>>2]|0)|0;if((Kb|0)==0){Wd=db;Xd=zb}else{zb=d[gb]|0;db=(((Kb>>>1)+(xb<<8)|0)>>>0)/(Kb>>>0)|0;if((db|0)<1){Yd=1}else{Yd=(db|0)>255?255:db}db=Kb>>>0>20>>>0;xb=Kb;Erc(db?2560:xb<<7|0>>>25,db?0:0<<7|xb>>>25,_,$)|0;a[gb]=(((ca(Yd-zb|0,G)|0)+128|0)>>>8)+zb;Wd=c[k>>2]|0;Xd=c[jb>>2]|0}jb=n+1812+(fb*2039|0)+197+(Hd*33|0)+9|0;k=Wd+Xd|0;if((k|0)!=0){zb=d[jb]|0;gb=(((k>>>1)+(Wd<<8)|0)>>>0)/(k>>>0)|0;if((gb|0)<1){Zd=1}else{Zd=(gb|0)>255?255:gb}gb=k>>>0>20>>>0;xb=k;Erc(gb?2560:xb<<7|0>>>25,gb?0:0<<7|xb>>>25,_,$)|0;a[jb]=(((ca(Zd-zb|0,G)|0)+128|0)>>>8)+zb}zb=n+1812+(fb*2039|0)+197+(Hd*33|0)+10|0;jb=c[hb>>2]|0;hb=(c[Ob>>2]|0)+jb|0;if((hb|0)!=0){Ob=d[zb]|0;xb=(((hb>>>1)+(jb<<8)|0)>>>0)/(hb>>>0)|0;if((xb|0)<1){_d=1}else{_d=(xb|0)>255?255:xb}xb=hb>>>0>20>>>0;jb=hb;Erc(xb?2560:jb<<7|0>>>25,xb?0:0<<7|jb>>>25,_,$)|0;a[zb]=(((ca(_d-Ob|0,G)|0)+128|0)>>>8)+Ob}Ob=n+1812+(fb*2039|0)+197+(Hd*33|0)+11|0;zb=c[n+17652+(Hd*204|0)+52>>2]|0;jb=(c[n+17652+(Hd*204|0)+56>>2]|0)+zb|0;if((jb|0)==0){$d=0}else{xb=d[Ob]|0;hb=(((jb>>>1)+(zb<<8)|0)>>>0)/(jb>>>0)|0;if((hb|0)<1){ae=1}else{ae=(hb|0)>255?255:hb}hb=jb>>>0>20>>>0;zb=jb;Erc(hb?2560:zb<<7|0>>>25,hb?0:0<<7|zb>>>25,_,$)|0;a[Ob]=(((ca(ae-xb|0,G)|0)+128|0)>>>8)+xb;$d=0}while(1){xb=n+1812+(fb*2039|0)+197+(Hd*33|0)+12+$d|0;Ob=c[n+17652+(Hd*204|0)+60+($d<<3)>>2]|0;zb=(c[n+17652+(Hd*204|0)+60+($d<<3)+4>>2]|0)+Ob|0;if((zb|0)!=0){hb=d[xb]|0;jb=(((zb>>>1)+(Ob<<8)|0)>>>0)/(zb>>>0)|0;if((jb|0)<1){be=1}else{be=(jb|0)>255?255:jb}jb=zb>>>0>20>>>0;Ob=zb;Erc(jb?2560:Ob<<7|0>>>25,jb?0:0<<7|Ob>>>25,_,$)|0;a[xb]=(((ca(be-hb|0,G)|0)+128|0)>>>8)+hb}hb=$d+1|0;if((hb|0)<10){$d=hb}else{ce=0;break}}do{hb=n+1812+(fb*2039|0)+197+(Hd*33|0)+22+(ce*3|0)|0;xb=c[n+17652+(Hd*204|0)+140+(ce<<4)>>2]|0;Ob=n+17652+(Hd*204|0)+140+(ce<<4)+4|0;jb=c[Ob>>2]|0;zb=n+17652+(Hd*204|0)+140+(ce<<4)+8|0;gb=c[zb>>2]|0;k=n+17652+(Hd*204|0)+140+(ce<<4)+12|0;db=c[k>>2]|0;Kb=jb+xb+gb+db|0;if((Kb|0)==0){de=jb;ee=gb;fe=db}else{db=d[hb]|0;gb=(((Kb>>>1)+(xb<<8)|0)>>>0)/(Kb>>>0)|0;if((gb|0)<1){ge=1}else{ge=(gb|0)>255?255:gb}gb=Kb>>>0>20>>>0;xb=Kb;Erc(gb?2560:xb<<7|0>>>25,gb?0:0<<7|xb>>>25,_,$)|0;a[hb]=(((ca(ge-db|0,G)|0)+128|0)>>>8)+db;de=c[Ob>>2]|0;ee=c[zb>>2]|0;fe=c[k>>2]|0}Ob=n+1812+(fb*2039|0)+197+(Hd*33|0)+22+(ce*3|0)+1|0;db=ee+fe+de|0;if((db|0)==0){ie=ee;ke=fe}else{hb=d[Ob]|0;xb=(((db>>>1)+(de<<8)|0)>>>0)/(db>>>0)|0;if((xb|0)<1){le=1}else{le=(xb|0)>255?255:xb}xb=db>>>0>20>>>0;gb=db;Erc(xb?2560:gb<<7|0>>>25,xb?0:0<<7|gb>>>25,_,$)|0;a[Ob]=(((ca(le-hb|0,G)|0)+128|0)>>>8)+hb;ie=c[zb>>2]|0;ke=c[k>>2]|0}k=n+1812+(fb*2039|0)+197+(Hd*33|0)+22+(ce*3|0)+2|0;zb=ie+ke|0;if((zb|0)!=0){hb=d[k]|0;Ob=(((zb>>>1)+(ie<<8)|0)>>>0)/(zb>>>0)|0;if((Ob|0)<1){me=1}else{me=(Ob|0)>255?255:Ob}Ob=zb>>>0>20>>>0;gb=zb;Erc(Ob?2560:gb<<7|0>>>25,Ob?0:0<<7|gb>>>25,_,$)|0;a[k]=(((ca(me-hb|0,G)|0)+128|0)>>>8)+hb}ce=ce+1|0;}while((ce|0)<2);hb=n+1812+(fb*2039|0)+197+(Hd*33|0)+28|0;k=c[n+17652+(Hd*204|0)+172>>2]|0;gb=n+17652+(Hd*204|0)+176|0;Ob=c[gb>>2]|0;zb=n+17652+(Hd*204|0)+180|0;xb=c[zb>>2]|0;db=n+17652+(Hd*204|0)+184|0;Kb=c[db>>2]|0;jb=Ob+k+xb+Kb|0;if((jb|0)==0){ne=Ob;oe=xb;qe=Kb}else{Kb=d[hb]|0;xb=(((jb>>>1)+(k<<8)|0)>>>0)/(jb>>>0)|0;if((xb|0)<1){re=1}else{re=(xb|0)>255?255:xb}xb=jb>>>0>20>>>0;k=jb;Erc(xb?2560:k<<7|0>>>25,xb?0:0<<7|k>>>25,_,$)|0;a[hb]=(((ca(re-Kb|0,G)|0)+128|0)>>>8)+Kb;ne=c[gb>>2]|0;oe=c[zb>>2]|0;qe=c[db>>2]|0}gb=n+1812+(fb*2039|0)+197+(Hd*33|0)+29|0;Kb=oe+qe+ne|0;if((Kb|0)==0){se=oe;te=qe}else{hb=d[gb]|0;k=(((Kb>>>1)+(ne<<8)|0)>>>0)/(Kb>>>0)|0;if((k|0)<1){ue=1}else{ue=(k|0)>255?255:k}k=Kb>>>0>20>>>0;xb=Kb;Erc(k?2560:xb<<7|0>>>25,k?0:0<<7|xb>>>25,_,$)|0;a[gb]=(((ca(ue-hb|0,G)|0)+128|0)>>>8)+hb;se=c[zb>>2]|0;te=c[db>>2]|0}db=n+1812+(fb*2039|0)+197+(Hd*33|0)+30|0;zb=se+te|0;if((zb|0)!=0){hb=d[db]|0;gb=(((zb>>>1)+(se<<8)|0)>>>0)/(zb>>>0)|0;if((gb|0)<1){ve=1}else{ve=(gb|0)>255?255:gb}gb=zb>>>0>20>>>0;xb=zb;Erc(gb?2560:xb<<7|0>>>25,gb?0:0<<7|xb>>>25,_,$)|0;a[db]=(((ca(ve-hb|0,G)|0)+128|0)>>>8)+hb}do{if((a[wa]|0)!=0){hb=n+1812+(fb*2039|0)+197+(Hd*33|0)+31|0;db=c[n+17652+(Hd*204|0)+188>>2]|0;xb=(c[n+17652+(Hd*204|0)+192>>2]|0)+db|0;if((xb|0)!=0){gb=d[hb]|0;zb=(((xb>>>1)+(db<<8)|0)>>>0)/(xb>>>0)|0;if((zb|0)<1){we=1}else{we=(zb|0)>255?255:zb}zb=xb>>>0>20>>>0;db=xb;Erc(zb?2560:db<<7|0>>>25,zb?0:0<<7|db>>>25,_,$)|0;a[hb]=(((ca(we-gb|0,G)|0)+128|0)>>>8)+gb}gb=n+1812+(fb*2039|0)+197+(Hd*33|0)+32|0;hb=c[n+17652+(Hd*204|0)+196>>2]|0;db=(c[n+17652+(Hd*204|0)+200>>2]|0)+hb|0;if((db|0)==0){break}zb=d[gb]|0;xb=(((db>>>1)+(hb<<8)|0)>>>0)/(db>>>0)|0;if((xb|0)<1){xe=1}else{xe=(xb|0)>255?255:xb}xb=db>>>0>20>>>0;hb=db;Erc(xb?2560:hb<<7|0>>>25,xb?0:0<<7|hb>>>25,_,$)|0;a[gb]=(((ca(xe-zb|0,G)|0)+128|0)>>>8)+zb}}while(0);zb=Hd+1|0;if((zb|0)<2){Hd=zb}else{ye=0;break}}while(1){zb=n+1812+(fb*2039|0)+(ye*9|0)|0;gb=n+16628+(ye*40|0)|0;hb=n+16628+(ye*40|0)+4|0;xb=n+16628+(ye*40|0)+12|0;db=n+16628+(ye*40|0)+16|0;k=n+16628+(ye*40|0)+20|0;Kb=n+16628+(ye*40|0)+24|0;jb=n+16628+(ye*40|0)+28|0;Ob=n+16628+(ye*40|0)+32|0;kb=n+16628+(ye*40|0)+36|0;Lb=c[kb>>2]|0;C=(c[hb>>2]|0)+(c[gb>>2]|0)+(c[xb>>2]|0)+(c[db>>2]|0)+(c[k>>2]|0)+(c[Kb>>2]|0)+(c[jb>>2]|0)+(c[Ob>>2]|0)+Lb|0;eb=c[n+16628+(ye*40|0)+8>>2]|0;Bb=C+eb|0;if((Bb|0)==0){ze=Lb}else{Lb=d[zb]|0;cb=(((Bb>>>1)+(eb<<8)|0)>>>0)/(Bb>>>0)|0;if((cb|0)<1){Ae=1}else{Ae=(cb|0)>255?255:cb}cb=Bb>>>0>20>>>0;eb=Bb;Erc(cb?2560:eb<<7|0>>>25,cb?0:0<<7|eb>>>25,_,$)|0;a[zb]=(((ca(Ae-Lb|0,G)|0)+128|0)>>>8)+Lb;ze=c[kb>>2]|0}kb=C-ze|0;Lb=n+1812+(fb*2039|0)+(ye*9|0)+1|0;if((C|0)!=0){zb=d[Lb]|0;eb=(((ze<<8)+(C>>>1)|0)>>>0)/(C>>>0)|0;if((eb|0)<1){Be=1}else{Be=(eb|0)>255?255:eb}eb=C>>>0>20>>>0;cb=C;Erc(eb?2560:cb<<7|0>>>25,eb?0:0<<7|cb>>>25,_,$)|0;a[Lb]=(((ca(Be-zb|0,G)|0)+128|0)>>>8)+zb}zb=c[gb>>2]|0;gb=kb-zb|0;Lb=n+1812+(fb*2039|0)+(ye*9|0)+2|0;if((C|0)!=(ze|0)){C=d[Lb]|0;cb=(((zb<<8)+(kb>>>1)|0)>>>0)/(kb>>>0)|0;if((cb|0)<1){Ce=1}else{Ce=(cb|0)>255?255:cb}cb=kb>>>0>20>>>0;eb=kb;Erc(cb?2560:eb<<7|0>>>25,cb?0:0<<7|eb>>>25,_,$)|0;a[Lb]=(((ca(Ce-C|0,G)|0)+128|0)>>>8)+C}C=(c[db>>2]|0)+(c[hb>>2]|0)+(c[k>>2]|0)|0;Lb=gb-C|0;eb=n+1812+(fb*2039|0)+(ye*9|0)+3|0;if((kb|0)!=(zb|0)){zb=d[eb]|0;kb=(((C<<8)+(gb>>>1)|0)>>>0)/(gb>>>0)|0;if((kb|0)<1){De=1}else{De=(kb|0)>255?255:kb}kb=gb>>>0>20>>>0;cb=gb;Erc(kb?2560:cb<<7|0>>>25,kb?0:0<<7|cb>>>25,_,$)|0;a[eb]=(((ca(De-zb|0,G)|0)+128|0)>>>8)+zb}zb=n+1812+(fb*2039|0)+(ye*9|0)+4|0;if((C|0)!=0){eb=d[zb]|0;cb=(((c[hb>>2]<<8)+(C>>>1)|0)>>>0)/(C>>>0)|0;if((cb|0)<1){Ee=1}else{Ee=(cb|0)>255?255:cb}cb=C>>>0>20>>>0;hb=C;Erc(cb?2560:hb<<7|0>>>25,cb?0:0<<7|hb>>>25,_,$)|0;a[zb]=(((ca(Ee-eb|0,G)|0)+128|0)>>>8)+eb}eb=n+1812+(fb*2039|0)+(ye*9|0)+5|0;zb=c[db>>2]|0;db=(c[k>>2]|0)+zb|0;if((db|0)!=0){k=d[eb]|0;hb=(((db>>>1)+(zb<<8)|0)>>>0)/(db>>>0)|0;if((hb|0)<1){Fe=1}else{Fe=(hb|0)>255?255:hb}hb=db>>>0>20>>>0;zb=db;Erc(hb?2560:zb<<7|0>>>25,hb?0:0<<7|zb>>>25,_,$)|0;a[eb]=(((ca(Fe-k|0,G)|0)+128|0)>>>8)+k}k=c[xb>>2]|0;xb=Lb-k|0;eb=n+1812+(fb*2039|0)+(ye*9|0)+6|0;if((gb|0)!=(C|0)){C=d[eb]|0;gb=(((k<<8)+(Lb>>>1)|0)>>>0)/(Lb>>>0)|0;if((gb|0)<1){Ge=1}else{Ge=(gb|0)>255?255:gb}gb=Lb>>>0>20>>>0;zb=Lb;Erc(gb?2560:zb<<7|0>>>25,gb?0:0<<7|zb>>>25,_,$)|0;a[eb]=(((ca(Ge-C|0,G)|0)+128|0)>>>8)+C}C=n+1812+(fb*2039|0)+(ye*9|0)+7|0;if((Lb|0)!=(k|0)){k=d[C]|0;Lb=(((c[jb>>2]<<8)+(xb>>>1)|0)>>>0)/(xb>>>0)|0;if((Lb|0)<1){He=1}else{He=(Lb|0)>255?255:Lb}Lb=xb>>>0>20>>>0;jb=xb;Erc(Lb?2560:jb<<7|0>>>25,Lb?0:0<<7|jb>>>25,_,$)|0;a[C]=(((ca(He-k|0,G)|0)+128|0)>>>8)+k}k=n+1812+(fb*2039|0)+(ye*9|0)+8|0;C=c[Kb>>2]|0;Kb=(c[Ob>>2]|0)+C|0;if((Kb|0)!=0){Ob=d[k]|0;jb=(((Kb>>>1)+(C<<8)|0)>>>0)/(Kb>>>0)|0;if((jb|0)<1){Ie=1}else{Ie=(jb|0)>255?255:jb}jb=Kb>>>0>20>>>0;C=Kb;Erc(jb?2560:C<<7|0>>>25,jb?0:0<<7|C>>>25,_,$)|0;a[k]=(((ca(Ie-Ob|0,G)|0)+128|0)>>>8)+Ob}Ob=ye+1|0;if((Ob|0)<4){ye=Ob}else{Je=0;break}}do{Ob=n+1812+(fb*2039|0)+36+(Je*9|0)|0;k=n+16788+(Je*40|0)|0;C=n+16788+(Je*40|0)+4|0;jb=n+16788+(Je*40|0)+12|0;Kb=n+16788+(Je*40|0)+16|0;Lb=n+16788+(Je*40|0)+20|0;xb=n+16788+(Je*40|0)+24|0;eb=n+16788+(Je*40|0)+28|0;zb=n+16788+(Je*40|0)+32|0;gb=n+16788+(Je*40|0)+36|0;hb=c[gb>>2]|0;db=(c[C>>2]|0)+(c[k>>2]|0)+(c[jb>>2]|0)+(c[Kb>>2]|0)+(c[Lb>>2]|0)+(c[xb>>2]|0)+(c[eb>>2]|0)+(c[zb>>2]|0)+hb|0;cb=c[n+16788+(Je*40|0)+8>>2]|0;kb=db+cb|0;if((kb|0)==0){Ke=hb}else{hb=d[Ob]|0;Bb=(((kb>>>1)+(cb<<8)|0)>>>0)/(kb>>>0)|0;if((Bb|0)<1){Le=1}else{Le=(Bb|0)>255?255:Bb}Bb=kb>>>0>20>>>0;cb=kb;Erc(Bb?2560:cb<<7|0>>>25,Bb?0:0<<7|cb>>>25,_,$)|0;a[Ob]=(((ca(Le-hb|0,G)|0)+128|0)>>>8)+hb;Ke=c[gb>>2]|0}gb=db-Ke|0;hb=n+1812+(fb*2039|0)+36+(Je*9|0)+1|0;if((db|0)!=0){Ob=d[hb]|0;cb=(((Ke<<8)+(db>>>1)|0)>>>0)/(db>>>0)|0;if((cb|0)<1){Me=1}else{Me=(cb|0)>255?255:cb}cb=db>>>0>20>>>0;Bb=db;Erc(cb?2560:Bb<<7|0>>>25,cb?0:0<<7|Bb>>>25,_,$)|0;a[hb]=(((ca(Me-Ob|0,G)|0)+128|0)>>>8)+Ob}Ob=c[k>>2]|0;k=gb-Ob|0;hb=n+1812+(fb*2039|0)+36+(Je*9|0)+2|0;if((db|0)!=(Ke|0)){db=d[hb]|0;Bb=(((Ob<<8)+(gb>>>1)|0)>>>0)/(gb>>>0)|0;if((Bb|0)<1){Ne=1}else{Ne=(Bb|0)>255?255:Bb}Bb=gb>>>0>20>>>0;cb=gb;Erc(Bb?2560:cb<<7|0>>>25,Bb?0:0<<7|cb>>>25,_,$)|0;a[hb]=(((ca(Ne-db|0,G)|0)+128|0)>>>8)+db}db=(c[Kb>>2]|0)+(c[C>>2]|0)+(c[Lb>>2]|0)|0;hb=k-db|0;cb=n+1812+(fb*2039|0)+36+(Je*9|0)+3|0;if((gb|0)!=(Ob|0)){Ob=d[cb]|0;gb=(((db<<8)+(k>>>1)|0)>>>0)/(k>>>0)|0;if((gb|0)<1){Oe=1}else{Oe=(gb|0)>255?255:gb}gb=k>>>0>20>>>0;Bb=k;Erc(gb?2560:Bb<<7|0>>>25,gb?0:0<<7|Bb>>>25,_,$)|0;a[cb]=(((ca(Oe-Ob|0,G)|0)+128|0)>>>8)+Ob}Ob=n+1812+(fb*2039|0)+36+(Je*9|0)+4|0;if((db|0)!=0){cb=d[Ob]|0;Bb=(((c[C>>2]<<8)+(db>>>1)|0)>>>0)/(db>>>0)|0;if((Bb|0)<1){Pe=1}else{Pe=(Bb|0)>255?255:Bb}Bb=db>>>0>20>>>0;C=db;Erc(Bb?2560:C<<7|0>>>25,Bb?0:0<<7|C>>>25,_,$)|0;a[Ob]=(((ca(Pe-cb|0,G)|0)+128|0)>>>8)+cb}cb=n+1812+(fb*2039|0)+36+(Je*9|0)+5|0;Ob=c[Kb>>2]|0;Kb=(c[Lb>>2]|0)+Ob|0;if((Kb|0)!=0){Lb=d[cb]|0;C=(((Kb>>>1)+(Ob<<8)|0)>>>0)/(Kb>>>0)|0;if((C|0)<1){Qe=1}else{Qe=(C|0)>255?255:C}C=Kb>>>0>20>>>0;Ob=Kb;Erc(C?2560:Ob<<7|0>>>25,C?0:0<<7|Ob>>>25,_,$)|0;a[cb]=(((ca(Qe-Lb|0,G)|0)+128|0)>>>8)+Lb}Lb=c[jb>>2]|0;jb=hb-Lb|0;cb=n+1812+(fb*2039|0)+36+(Je*9|0)+6|0;if((k|0)!=(db|0)){db=d[cb]|0;k=(((Lb<<8)+(hb>>>1)|0)>>>0)/(hb>>>0)|0;if((k|0)<1){Re=1}else{Re=(k|0)>255?255:k}k=hb>>>0>20>>>0;Ob=hb;Erc(k?2560:Ob<<7|0>>>25,k?0:0<<7|Ob>>>25,_,$)|0;a[cb]=(((ca(Re-db|0,G)|0)+128|0)>>>8)+db}db=n+1812+(fb*2039|0)+36+(Je*9|0)+7|0;if((hb|0)!=(Lb|0)){Lb=d[db]|0;hb=(((c[eb>>2]<<8)+(jb>>>1)|0)>>>0)/(jb>>>0)|0;if((hb|0)<1){Se=1}else{Se=(hb|0)>255?255:hb}hb=jb>>>0>20>>>0;eb=jb;Erc(hb?2560:eb<<7|0>>>25,hb?0:0<<7|eb>>>25,_,$)|0;a[db]=(((ca(Se-Lb|0,G)|0)+128|0)>>>8)+Lb}Lb=n+1812+(fb*2039|0)+36+(Je*9|0)+8|0;db=c[xb>>2]|0;xb=(c[zb>>2]|0)+db|0;if((xb|0)!=0){zb=d[Lb]|0;eb=(((xb>>>1)+(db<<8)|0)>>>0)/(xb>>>0)|0;if((eb|0)<1){Te=1}else{Te=(eb|0)>255?255:eb}eb=xb>>>0>20>>>0;db=xb;Erc(eb?2560:db<<7|0>>>25,eb?0:0<<7|db>>>25,_,$)|0;a[Lb]=(((ca(Te-zb|0,G)|0)+128|0)>>>8)+zb}Je=Je+1|0;}while((Je|0)<10)}else{E=211}}while(0);if((E|0)==211){E=0;zb=n+1812+(fb*2039|0)+191|0;a[zb]=a[xa]|0;a[zb+1|0]=a[xa+1|0]|0;a[zb+2|0]=a[xa+2|0]|0;zb=n+1812+(fb*2039|0)+179|0;a[zb]=a[ya]|0;a[zb+1|0]=a[ya+1|0]|0;a[zb+2|0]=a[ya+2|0]|0;a[zb+3|0]=a[ya+3|0]|0;a[zb+4|0]=a[ya+4|0]|0;a[zb+5|0]=a[ya+5|0]|0;zb=n+1812+(fb*2039|0)+185|0;y=d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0;a[zb]=y;y=y>>8;a[zb+1|0]=y;y=y>>8;a[zb+2|0]=y;y=y>>8;a[zb+3|0]=y;zb=n+1812+(fb*2039|0)+189|0;y=(d[Aa]|d[Aa+1|0]<<8)<<16>>16;a[zb]=y;y=y>>8;a[zb+1|0]=y}K5a(b);yc=c[A>>2]|0}}while(0);c[A>>2]=yc+1;if((yc|0)==1){$a=bb;q=ab}else{break}}if((E|0)==65){L5a(l,2147483647,0);p=-1094995529;i=h;return p|0}else if((E|0)==70){c[wb>>2]=Cb-Fb;c[Ab>>2]=Db-Gb;L5a(l,2147483647,0);p=-1094995529;i=h;return p|0}else if((E|0)==179){c[A>>2]=xc+1}L5a(l,2147483647,0);l=z;if((c[c[z>>2]>>2]|0)!=0){H5a(b,l)}G5a(l,u)|0;u=m+1180|0;l=u;if((c[c[u>>2]>>2]|0)!=0){H5a(b,l)}G5a(l,m+1276|0)|0;l=m+1192|0;u=l;if((c[c[l>>2]>>2]|0)!=0){H5a(b,u)}G5a(u,m+1288|0)|0;u=m+1204|0;l=u;if((c[c[u>>2]>>2]|0)!=0){H5a(b,l)}G5a(l,m+1300|0)|0;l=m+1216|0;u=l;if((c[c[l>>2]>>2]|0)!=0){H5a(b,u)}G5a(u,m+1312|0)|0;u=m+1228|0;l=u;if((c[c[u>>2]>>2]|0)!=0){H5a(b,l)}G5a(l,m+1324|0)|0;l=m+1240|0;u=l;if((c[c[l>>2]>>2]|0)!=0){H5a(b,u)}G5a(u,m+1336|0)|0;u=m+1252|0;l=u;if((c[c[u>>2]>>2]|0)!=0){H5a(b,l)}G5a(l,m+1348|0)|0;if((a[m+1139|0]|0)!=0){p=0;i=h;return p|0}m=YHb(e,c[s>>2]|0)|0;if((m|0)<0){p=m;i=h;return p|0}c[f>>2]=1;p=0;i=h;return p|0}function sbb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;d=b+1360|0;e=d;if((c[c[e>>2]>>2]|0)!=0){H5a(a,d);fGb(b+1372|0)}VHb(e);e=b+1384|0;d=e;if((c[c[d>>2]>>2]|0)!=0){H5a(a,e);fGb(b+1396|0)}VHb(d);d=b+1168|0;e=b+1264|0;f=0;do{g=d+(f*12|0)|0;h=g|0;if((c[c[h>>2]>>2]|0)!=0){H5a(a,g)}VHb(h);h=e+(f*12|0)|0;g=h|0;if((c[c[g>>2]>>2]|0)!=0){H5a(a,h)}VHb(g);f=f+1|0;}while((f|0)<8);mJb(b+30148|0);mJb(b+1080|0);mJb(b+35860|0);mJb(b+1072|0);c[b+1076>>2]=0;return 0}function tbb(a){a=a|0;var b=0;b=c[a+60>>2]|0;H5a(a,b+1360|0);fGb(b+1372|0);H5a(a,b+1384|0);fGb(b+1396|0);H5a(a,b+1168|0);H5a(a,b+1180|0);H5a(a,b+1192|0);H5a(a,b+1204|0);H5a(a,b+1216|0);H5a(a,b+1228|0);H5a(a,b+1240|0);H5a(a,b+1252|0);return}function ubb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0;j=i;k=e+60|0;l=c[k>>2]|0;m=g>>>0>268435455>>>0?-8:g<<3;n=m>>>0>2147483639>>>0|(f|0)==0;o=n?0:f;p=n?0:m;m=l+1032|0;c[m>>2]=o;c[l+1044>>2]=p;q=p+8|0;r=l+1048|0;c[r>>2]=q;c[l+1036>>2]=o+(p>>3);p=l+1040|0;c[p>>2]=0;if(n){KIb(e,16,2168128,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}n=o;u=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24)&192;n=q>>>0>2>>>0?2:q;c[p>>2]=n;if((u|0)!=128){KIb(e,16,2141488,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}u=d[o+(n>>>3)|0]<<(n&2)>>>7;v=(n|0)<(q|0)|n;c[p>>2]=v;a[l+1136|0]=u&1;u=d[o+(n>>>3)|0]|0;n=((v|0)<(q|0))+v|0;c[p>>2]=n;if((u&128>>>((v&7)>>>0)|0)!=0){KIb(e,16,2117912,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}v=d[o+(n>>>3)|0]|0;u=((n|0)<(q|0))+n|0;c[p>>2]=u;if((v&128>>>((n&7)>>>0)|0)!=0){n=o+(u>>>3)|0;v=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(u&7)>>>29;n=u+3|0;c[p>>2]=q>>>0>n>>>0?n:q;c[h>>2]=v;t=0;i=j;return t|0}c[l+1096>>2]=c[l+1092>>2];v=l+1137|0;a[l+1138|0]=a[v]|0;h=d[o+(u>>>3)|0]<<(u&7);n=((u|0)<(q|0))+u|0;c[p>>2]=n;u=(h>>>7&1^1)&255;a[v]=u;h=l+1139|0;w=a[h]|0;x=d[o+(n>>>3)|0]<<(n&7);z=((n|0)<(q|0))+n|0;c[p>>2]=z;n=(x>>>7&1^1)&255;a[h]=n;h=d[o+(z>>>3)|0]<<(z&7)>>>7;x=((z|0)<(q|0))+z|0;c[p>>2]=x;z=h&1;h=l+1141|0;a[h]=z;A=z<<24>>24==0;if(A){B=w<<24>>24==0|0}else{B=0}w=l+1140|0;a[w]=B;a:do{if(u<<24>>24==0){if(n<<24>>24==0){C=0;D=x}else{z=d[o+(x>>>3)|0]<<(x&7)>>>7;E=((x|0)<(q|0))+x|0;c[p>>2]=E;C=z&1;D=E}a[l+1144|0]=C;if(A){E=o+(D>>>3)|0;z=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>30;E=D+2|0;F=q>>>0>E>>>0?E:q;c[p>>2]=F;G=z&255;H=F}else{G=0;H=D}a[l+1145|0]=G;F=o+(H>>>3)|0;z=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(H&7);if(!(C<<24>>24==0)){F=H+24|0;E=q>>>0>F>>>0?F:q;c[p>>2]=E;if((z&-256|0)==1233338880){F=o+(E>>>3)|0;I=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>24;F=E+8|0;E=q>>>0>F>>>0?F:q;c[p>>2]=E;a[l+1146|0]=I;I=o+(E>>>3)|0;F=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(E&7)>>>16;I=E+16|0;E=q>>>0>I>>>0?I:q;c[p>>2]=E;I=F+1|0;F=o+(E>>>3)|0;J=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>16;F=E+16|0;E=q>>>0>F>>>0?F:q;c[p>>2]=E;F=J+1|0;J=d[o+(E>>>3)|0]|0;K=((E|0)<(q|0))+E|0;c[p>>2]=K;if((J&128>>>((E&7)>>>0)|0)==0){L=I;M=F;N=K;break}E=K+32|0;K=q>>>0>E>>>0?E:q;c[p>>2]=K;L=I;M=F;N=K;break}else{KIb(e,16,2635976,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}}K=H+8|0;F=q>>>0>K>>>0?K:q;c[p>>2]=F;a[l+1146|0]=z>>>24;z=o+(F>>>3)|0;K=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(F&7)>>>29;z=F+3|0;F=q>>>0>z>>>0?z:q;c[p>>2]=F;a[l+1157|0]=K;z=d[o+(F>>>3)|0]<<(F&7)>>>7;I=((F|0)<(q|0))+F|0;c[p>>2]=I;F=z&1;a[l+1160|0]=F;z=o+(I>>>3)|0;E=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(I&7)>>>29;z=I+3|0;I=q>>>0>z>>>0?z:q;c[p>>2]=I;a[l+1158|0]=E;z=d[o+(I>>>3)|0]<<(I&7)>>>7;J=((I|0)<(q|0))+I|0;c[p>>2]=J;I=z&1;a[l+1161|0]=I;z=o+(J>>>3)|0;O=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(J&7)>>>29;z=J+3|0;J=q>>>0>z>>>0?z:q;c[p>>2]=J;a[l+1159|0]=O;z=d[o+(J>>>3)|0]<<(J&7)>>>7;P=((J|0)<(q|0))+J|0;c[p>>2]=P;J=z&1;a[l+1162|0]=J;z=l+1168|0;Q=z+(K*12|0)|0;do{if((c[c[Q>>2]>>2]|0)!=0){K=z+(E*12|0)|0;if((c[c[K>>2]>>2]|0)==0){break}R=z+(O*12|0)|0;if((c[c[R>>2]>>2]|0)==0){break}S=d[o+(P>>>3)|0]|0;T=((P|0)<(q|0))+P|0;c[p>>2]=T;do{if((S&128>>>((P&7)>>>0)|0)==0){U=d[o+(T>>>3)|0]|0;V=((T|0)<(q|0))+T|0;c[p>>2]=V;if((U&128>>>((T&7)>>>0)|0)!=0){U=c[K>>2]|0;W=c[U+68>>2]|0;X=c[U+72>>2]|0;Y=V;break}U=d[o+(V>>>3)|0]|0;Z=((V|0)<(q|0))+V|0;c[p>>2]=Z;if((U&128>>>((V&7)>>>0)|0)==0){V=o+(Z>>>3)|0;U=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(Z&7)>>>16;V=Z+16|0;_=q>>>0>V>>>0?V:q;c[p>>2]=_;V=o+(_>>>3)|0;$=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(_&7)>>>16;V=_+16|0;_=q>>>0>V>>>0?V:q;c[p>>2]=_;W=U+1|0;X=$+1|0;Y=_;break}else{_=c[R>>2]|0;W=c[_+68>>2]|0;X=c[_+72>>2]|0;Y=Z;break}}else{Z=c[Q>>2]|0;W=c[Z+68>>2]|0;X=c[Z+72>>2]|0;Y=T}}while(0);T=c[l+1360>>2]|0;if((c[T+68>>2]|0)==(W|0)){aa=(c[T+72>>2]|0)==(X|0)|0}else{aa=0}a[w]=B&aa;T=((Y|0)<(q|0))+Y|0;if((d[o+(Y>>>3)|0]&128>>>((Y&7)>>>0)|0)==0){ba=T}else{R=T+32|0;ba=q>>>0>R>>>0?R:q}c[p>>2]=ba;R=d[o+(ba>>>3)|0]<<(ba&7)>>>7;T=((ba|0)<(q|0))+ba|0;c[p>>2]=T;a[l+1147|0]=R&1;R=d[o+(T>>>3)|0]|0;K=((T|0)<(q|0))+T|0;c[p>>2]=K;if((R&128>>>((T&7)>>>0)|0)==0){T=o+(K>>>3)|0;R=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(K&7)>>>30;T=K+2|0;S=q>>>0>T>>>0?T:q;c[p>>2]=S;ca=R;da=S}else{ca=4;da=K}c[l+1148>>2]=ca;if(F<<24>>24==I<<24>>24){a[l+1152|0]=F^J;if(F<<24>>24==J<<24>>24){L=W;M=X;N=da;break a}a[l+1153|0]=2;a[l+1163|0]=0;a[l+1164|0]=1;L=W;M=X;N=da;break a}a[l+1152|0]=1;K=l+1153|0;if(F<<24>>24==J<<24>>24){a[K]=1;a[l+1163|0]=0;a[l+1164|0]=2;L=W;M=X;N=da;break a}else{a[K]=0;a[l+1163|0]=1;a[l+1164|0]=2;L=W;M=X;N=da;break a}}}while(0);KIb(e,16,2585840,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}else{J=o+(x>>>3)|0;F=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(x&7);J=x+24|0;I=q>>>0>J>>>0?J:q;c[p>>2]=I;if((F&-256|0)!=1233338880){KIb(e,16,2635976,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}F=o+(I>>>3)|0;J=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(I&7)>>>29;F=I+3|0;I=q>>>0>F>>>0?F:q;c[p>>2]=I;a[l+1142|0]=J;if((J|0)==7){KIb(e,16,2612552,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}else{J=d[o+(I>>>3)|0]<<(I&7)>>>7;F=((I|0)<(q|0))+I|0;c[p>>2]=F;a[l+1143|0]=J&1;a[l+1146|0]=-1;J=o+(F>>>3)|0;I=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(F&7)>>>16;J=F+16|0;F=q>>>0>J>>>0?J:q;c[p>>2]=F;J=I+1|0;I=o+(F>>>3)|0;Q=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(F&7)>>>16;I=F+16|0;F=q>>>0>I>>>0?I:q;c[p>>2]=F;I=Q+1|0;Q=d[o+(F>>>3)|0]|0;P=((F|0)<(q|0))+F|0;c[p>>2]=P;if((Q&128>>>((F&7)>>>0)|0)==0){L=J;M=I;N=P;break}F=P+32|0;P=q>>>0>F>>>0?F:q;c[p>>2]=P;L=J;M=I;N=P;break}}}while(0);if(A){A=d[o+(N>>>3)|0]<<(N&7)>>>7;x=((N|0)<(q|0))+N|0;c[p>>2]=x;a[l+1154|0]=A&1;A=d[o+(x>>>3)|0]<<(x&7)>>>7;da=((x|0)<(q|0))+x|0;c[p>>2]=da;ea=A&1;fa=da}else{a[l+1154|0]=0;ea=1;fa=N}a[l+1155|0]=ea;ea=o+(fa>>>3)|0;N=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(fa&7)>>>30;ea=fa+2|0;fa=q>>>0>ea>>>0?ea:q;c[p>>2]=fa;a[l+1156|0]=N;ea=o+(fa>>>3)|0;da=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(fa&7)>>>26;ea=fa+6|0;fa=q>>>0>ea>>>0?ea:q;c[p>>2]=fa;ea=l+1408|0;a[ea]=da;da=o+(fa>>>3)|0;A=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(fa&7)>>>29;da=fa+3|0;fa=q>>>0>da>>>0?da:q;c[p>>2]=fa;da=l+1409|0;if((a[da]|0)!=(A|0)){mrc(l+1410|0,0,64)|0}a[da]=A;A=d[o+(fa>>>3)|0]<<(fa&7)>>>7;da=((fa|0)<(q|0))+fa|0;c[p>>2]=da;fa=A&1;A=l+1538|0;a[A]=fa;do{if(fa<<24>>24==0){mrc(A|0,0,7)|0;ga=da;ha=o;ia=q}else{x=d[o+(da>>>3)|0]|0;X=((da|0)<(q|0))+da|0;c[p>>2]=X;if((x&128>>>((da&7)>>>0)|0)==0){ga=X;ha=o;ia=q;break}else{ja=0;ka=X;la=o;ma=q}while(1){X=d[la+(ka>>>3)|0]|0;x=((ka|0)<(ma|0))+ka|0;c[p>>2]=x;if((X&128>>>((ka&7)>>>0)|0)!=0){X=la+(x>>>3)|0;W=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(x&7)>>>26;X=x+6|0;x=ma>>>0>X>>>0?X:ma;c[p>>2]=x;X=d[la+(x>>>3)|0]|0;c[p>>2]=((x|0)<(ma|0))+x;a[l+(ja+1541)|0]=(X&128>>>((x&7)>>>0)|0)!=0?-W|0:W}W=ja+1|0;na=c[p>>2]|0;if((W|0)>=4){break}ja=W;ka=na;la=c[m>>2]|0;ma=c[r>>2]|0}W=c[m>>2]|0;x=d[W+(na>>>3)|0]|0;X=c[r>>2]|0;ca=((na|0)<(X|0))+na|0;c[p>>2]=ca;if((x&128>>>((na&7)>>>0)|0)==0){oa=ca}else{x=W+(ca>>>3)|0;ba=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(ca&7)>>>26;x=ca+6|0;ca=X>>>0>x>>>0?x:X;c[p>>2]=ca;x=d[W+(ca>>>3)|0]|0;Y=((ca|0)<(X|0))+ca|0;c[p>>2]=Y;a[l+1539|0]=(x&128>>>((ca&7)>>>0)|0)!=0?-ba|0:ba;oa=Y}Y=d[W+(oa>>>3)|0]|0;ba=((oa|0)<(X|0))+oa|0;c[p>>2]=ba;if((Y&128>>>((oa&7)>>>0)|0)==0){ga=ba;ha=W;ia=X;break}Y=W+(ba>>>3)|0;ca=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(ba&7)>>>26;Y=ba+6|0;ba=X>>>0>Y>>>0?Y:X;c[p>>2]=ba;Y=d[W+(ba>>>3)|0]|0;x=((ba|0)<(X|0))+ba|0;c[p>>2]=x;a[l+1540|0]=(Y&128>>>((ba&7)>>>0)|0)!=0?-ca|0:ca;ga=x;ha=W;ia=X}}while(0);oa=ha+(ga>>>3)|0;na=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ga&7)>>>24;oa=ga+8|0;ga=ia>>>0>oa>>>0?oa:ia;c[p>>2]=ga;oa=na&255;na=l+1545|0;a[na]=oa;ma=d[ha+(ga>>>3)|0]|0;la=((ga|0)<(ia|0))+ga|0;c[p>>2]=la;if((ma&128>>>((ga&7)>>>0)|0)==0){pa=0;qa=la}else{ga=ha+(la>>>3)|0;ma=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(la&7)>>>28;ga=la+4|0;la=ia>>>0>ga>>>0?ga:ia;c[p>>2]=la;ga=d[ha+(la>>>3)|0]|0;ka=((la|0)<(ia|0))+la|0;c[p>>2]=ka;pa=((ga&128>>>((la&7)>>>0)|0)!=0?-ma|0:ma)&255;qa=ka}ka=l+1546|0;a[ka]=pa;ma=d[ha+(qa>>>3)|0]|0;la=((qa|0)<(ia|0))+qa|0;c[p>>2]=la;if((ma&128>>>((qa&7)>>>0)|0)==0){ra=0;sa=la}else{qa=ha+(la>>>3)|0;ma=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(la&7)>>>28;qa=la+4|0;la=ia>>>0>qa>>>0?qa:ia;c[p>>2]=la;qa=d[ha+(la>>>3)|0]|0;ga=((la|0)<(ia|0))+la|0;c[p>>2]=ga;ra=((qa&128>>>((la&7)>>>0)|0)!=0?-ma|0:ma)&255;sa=ga}ga=l+1547|0;a[ga]=ra;ma=d[ha+(sa>>>3)|0]|0;la=((sa|0)<(ia|0))+sa|0;c[p>>2]=la;if((ma&128>>>((sa&7)>>>0)|0)==0){ta=0;ua=la}else{sa=ha+(la>>>3)|0;ma=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(la&7)>>>28;sa=la+4|0;la=ia>>>0>sa>>>0?sa:ia;c[p>>2]=la;sa=d[ha+(la>>>3)|0]|0;qa=((la|0)<(ia|0))+la|0;c[p>>2]=qa;ta=((sa&128>>>((la&7)>>>0)|0)!=0?-ma|0:ma)&255;ua=qa}qa=l+1548|0;a[qa]=ta;if((oa|pa|ra)<<24>>24==0){va=ta<<24>>24==0|0}else{va=0}ta=l+1549|0;a[ta]=va;va=d[ha+(ua>>>3)|0]<<(ua&7)>>>7;ra=((ua|0)<(ia|0))+ua|0;c[p>>2]=ra;ua=va&1;va=l+1550|0;a[va]=ua;b:do{if(ua<<24>>24==0){pa=l+1554|0;oa=pa;y=0;a[oa]=y;y=y>>8;a[oa+1|0]=y;y=y>>8;a[oa+2|0]=y;y=y>>8;a[oa+3|0]=y;wa=pa}else{pa=d[ha+(ra>>>3)|0]<<(ra&7)>>>7;oa=((ra|0)<(ia|0))+ra|0;c[p>>2]=oa;ma=pa&1;pa=l+1553|0;a[pa]=ma;do{if(ma<<24>>24==0){xa=0;ya=oa;za=ha;Aa=ia;Ba=86}else{la=d[ha+(oa>>>3)|0]<<(oa&7)>>>7;sa=((oa|0)<(ia|0))+oa|0;c[p>>2]=sa;ja=0;q=sa;sa=la&1;la=ia;o=ha;do{if((sa|0)==0){Ca=-1}else{da=o+(q>>>3)|0;A=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(q&7)>>>24;da=q+8|0;c[p>>2]=la>>>0>da>>>0?da:la;Ca=A&255}a[l+(ja+16615)|0]=Ca;ja=ja+1|0;A=c[p>>2]|0;o=c[m>>2]|0;da=d[o+(A>>>3)|0]<<(A&7)>>>7;la=c[r>>2]|0;q=((A|0)<(la|0))+A|0;c[p>>2]=q;sa=da&1}while((ja|0)<7);ja=sa&255;a[l+1551|0]=ja;da=ja<<24>>24==0;if(da){Da=q}else{ja=d[o+(q>>>3)|0]|0;A=((q|0)<(la|0))+q|0;c[p>>2]=A;if((ja&128>>>((q&7)>>>0)|0)==0){Ea=-1;Fa=A}else{ja=o+(A>>>3)|0;fa=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(A&7)>>>24;ja=A+8|0;A=la>>>0>ja>>>0?ja:la;c[p>>2]=A;Ea=fa&255;Fa=A}a[l+16622|0]=Ea;A=d[o+(Fa>>>3)|0]|0;fa=((Fa|0)<(la|0))+Fa|0;c[p>>2]=fa;if((A&128>>>((Fa&7)>>>0)|0)==0){Ga=-1;Ha=fa}else{A=o+(fa>>>3)|0;ja=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(fa&7)>>>24;A=fa+8|0;fa=la>>>0>A>>>0?A:la;c[p>>2]=fa;Ga=ja&255;Ha=fa}a[l+16623|0]=Ga;fa=d[o+(Ha>>>3)|0]|0;ja=((Ha|0)<(la|0))+Ha|0;c[p>>2]=ja;if((fa&128>>>((Ha&7)>>>0)|0)==0){Ia=-1;Ja=ja}else{fa=o+(ja>>>3)|0;A=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ja&7)>>>24;fa=ja+8|0;ja=la>>>0>fa>>>0?fa:la;c[p>>2]=ja;Ia=A&255;Ja=ja}a[l+16624|0]=Ia;Da=Ja}ja=a[pa]|0;if(ja<<24>>24==0){xa=0;ya=Da;za=o;Aa=la;Ba=86;break}if(da){Ka=Da;La=o;Ma=la;break}xa=ja&255;ya=Da;za=o;Aa=la;Ba=86}}while(0);do{if((Ba|0)==86){pa=c[l+1360>>2]|0;if((L|0)==(c[pa+68>>2]|0)){if((M|0)==(c[pa+72>>2]|0)){Ka=ya;La=za;Ma=Aa;break}}KIb(e,16,2564952,(s=i,i=i+16|0,c[s>>2]=d[l+1551|0]|0,c[s+8>>2]=xa,s)|0);i=s;t=-1094995529;i=j;return t|0}}while(0);pa=d[La+(Ka>>>3)|0]|0;oa=((Ka|0)<(Ma|0))+Ka|0;c[p>>2]=oa;if((pa&128>>>((Ka&7)>>>0)|0)==0){wa=l+1554|0;break}pa=d[La+(oa>>>3)|0]<<(oa&7)>>>7;ma=((oa|0)<(Ma|0))+oa|0;c[p>>2]=ma;a[l+1552|0]=pa&1;pa=l+1554|0;oa=pa;ja=0;da=ma;ma=La;A=Ma;while(1){fa=d[ma+(da>>>3)|0]<<(da&7)>>>7;c[p>>2]=((da|0)<(A|0))+da;X=fa&1;a[oa+(ja*26|0)|0]=X;if(!(X<<24>>24==0)){X=c[p>>2]|0;fa=c[r>>2]|0;W=c[m>>2]|0;x=W+(X>>>3)|0;ca=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(X&7)>>>24;x=X+8|0;X=fa>>>0>x>>>0?x:fa;c[p>>2]=X;x=d[W+(X>>>3)|0]|0;c[p>>2]=((X|0)<(fa|0))+X;b[oa+(ja*26|0)+6>>1]=(x&128>>>((X&7)>>>0)|0)!=0?-ca|0:ca}ca=c[p>>2]|0;X=d[(c[m>>2]|0)+(ca>>>3)|0]<<(ca&7)>>>7;c[p>>2]=((ca|0)<(c[r>>2]|0))+ca;ca=X&1;a[oa+(ja*26|0)+1|0]=ca;if(!(ca<<24>>24==0)){ca=c[p>>2]|0;X=c[r>>2]|0;x=c[m>>2]|0;fa=x+(ca>>>3)|0;W=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ca&7)>>>26;fa=ca+6|0;ca=X>>>0>fa>>>0?fa:X;c[p>>2]=ca;fa=d[x+(ca>>>3)|0]|0;c[p>>2]=((ca|0)<(X|0))+ca;a[oa+(ja*26|0)+8|0]=(fa&128>>>((ca&7)>>>0)|0)!=0?-W|0:W}W=c[p>>2]|0;ca=d[(c[m>>2]|0)+(W>>>3)|0]<<(W&7)>>>7;c[p>>2]=((W|0)<(c[r>>2]|0))+W;W=ca&1;a[oa+(ja*26|0)+2|0]=W;if(!(W<<24>>24==0)){W=c[p>>2]|0;ca=c[r>>2]|0;fa=(c[m>>2]|0)+(W>>>3)|0;X=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(W&7)>>>30;fa=W+2|0;c[p>>2]=ca>>>0>fa>>>0?fa:ca;a[oa+(ja*26|0)+4|0]=X}X=c[p>>2]|0;ca=d[(c[m>>2]|0)+(X>>>3)|0]<<(X&7)>>>7;c[p>>2]=((X|0)<(c[r>>2]|0))+X;a[oa+(ja*26|0)+3|0]=ca&1;ca=ja+1|0;if((ca|0)>=8){wa=pa;break b}ja=ca;da=c[p>>2]|0;ma=c[m>>2]|0;A=c[r>>2]|0}}}while(0);Ma=wa;wa=l+1541|0;La=l+1539|0;Ka=l+1540|0;xa=l+1552|0;Aa=0;do{do{if((a[Ma+(Aa*26|0)|0]|0)==0){Na=d[na]|0}else{if((a[xa]|0)==0){Na=(b[Ma+(Aa*26|0)+6>>1]|0)+(d[na]|0)|0;break}else{Na=b[Ma+(Aa*26|0)+6>>1]|0;break}}}while(0);za=(a[ka]|0)+Na|0;if(za>>>0<256>>>0){Oa=za}else{Oa=-za>>31&255}za=(a[ga]|0)+Na|0;if(za>>>0<256>>>0){Pa=za}else{Pa=-za>>31&255}za=(a[qa]|0)+Na|0;if(za>>>0<256>>>0){Qa=za}else{Qa=-za>>31&255}if(Na>>>0<256>>>0){Ra=Na}else{Ra=-Na>>31&255}b[Ma+(Aa*26|0)+10>>1]=b[230032+(Oa<<1)>>1]|0;b[Ma+(Aa*26|0)+12>>1]=b[234304+(Ra<<1)>>1]|0;b[Ma+(Aa*26|0)+14>>1]=b[230032+(Pa<<1)>>1]|0;b[Ma+(Aa*26|0)+16>>1]=b[234304+(Qa<<1)>>1]|0;za=a[ea]|0;ya=za&255;Da=(za&255)>>>0>31>>>0|0;do{if((a[Ma+(Aa*26|0)+1|0]|0)==0){Sa=ya}else{za=a[Ma+(Aa*26|0)+8|0]|0;if((a[xa]|0)!=0){Sa=za;break}Sa=za+ya|0}}while(0);ya=(a[wa]<<Da)+Sa|0;if(ya>>>0<64>>>0){Ta=ya&255}else{Ta=-ya>>31&63}a[Ma+(Aa*26|0)+19|0]=Ta;a[Ma+(Aa*26|0)+18|0]=Ta;ya=l+1542|0;za=((a[La]|0)+(a[ya]|0)<<Da)+Sa|0;if(za>>>0<64>>>0){Ua=za&255}else{Ua=-za>>31&63}a[Ma+(Aa*26|0)+20|0]=Ua;za=((a[Ka]|0)+(a[ya]|0)<<Da)+Sa|0;if(za>>>0<64>>>0){Va=za&255}else{Va=-za>>31&63}a[Ma+(Aa*26|0)+21|0]=Va;za=a[l+1543|0]|0;ya=((a[La]|0)+za<<Da)+Sa|0;if(ya>>>0<64>>>0){Wa=ya&255}else{Wa=-ya>>31&63}a[Ma+(Aa*26|0)+22|0]=Wa;ya=((a[Ka]|0)+za<<Da)+Sa|0;if(ya>>>0<64>>>0){Xa=ya&255}else{Xa=-ya>>31&63}a[Ma+(Aa*26|0)+23|0]=Xa;ya=l+1544|0;za=((a[La]|0)+(a[ya]|0)<<Da)+Sa|0;if(za>>>0<64>>>0){Ya=za&255}else{Ya=-za>>31&63}a[Ma+(Aa*26|0)+24|0]=Ya;za=((a[Ka]|0)+(a[ya]|0)<<Da)+Sa|0;if(za>>>0<64>>>0){Za=za&255}else{Za=-za>>31&63}a[Ma+(Aa*26|0)+25|0]=Za;Aa=Aa+1|0;}while((Aa|0)<(((a[va]|0)!=0?8:1)|0));va=c[k>>2]|0;if(!((L|0)>0&(M|0)>0)){KIb(0,0,2291568,(s=i,i=i+24|0,c[s>>2]=2487640,c[s+8>>2]=2199816,c[s+16>>2]=316,s)|0);i=s;Hd();return 0}k=va+30148|0;Aa=k;Za=e+120|0;do{if((c[Aa>>2]|0)==0){Ba=130}else{if((c[Za>>2]|0)!=(L|0)){Ba=130;break}if((c[e+124>>2]|0)!=(M|0)){Ba=130}}}while(0);do{if((Ba|0)==130){c[Za>>2]=L;c[e+124>>2]=M;Ma=va+1796|0;c[Ma>>2]=L+63>>6;c[va+1800>>2]=M+63>>6;c[va+1808>>2]=L+7>>3;c[va+1804>>2]=M+7>>3;mJb(k);Sa=hJb((c[Ma>>2]|0)*560|0)|0;if((Sa|0)!=0){c[Aa>>2]=Sa;Ka=c[Ma>>2]|0;Ma=Ka<<6;c[va+30152>>2]=Sa+Ma;Ya=Ka<<5;La=Ya+Ma|0;c[va+30156>>2]=Sa+La;Ma=La+Ya|0;c[va+30104>>2]=Sa+Ma;Ya=Ka<<4;La=Ma+Ya|0;c[va+30100>>2]=Sa+La;Ma=La+Ya|0;c[va+30144>>2]=Sa+Ma;Ya=Ma+(Ka<<7)|0;c[va+30096>>2]=Sa+Ya;Ma=Ka<<3;Ka=Ya+Ma|0;c[va+30116>>2]=Sa+Ka;Ya=Ka+Ma|0;c[va+30120>>2]=Sa+Ya;Ka=Ya+Ma|0;c[va+30108>>2]=Sa+Ka;Ya=Ka+Ma|0;c[va+30112>>2]=Sa+Ya;Ka=Ya+Ma|0;c[va+30124>>2]=Sa+Ka;Ya=Ka+Ma|0;c[va+30128>>2]=Sa+Ya;Ka=Ya+Ma|0;c[va+30132>>2]=Sa+Ka;Ya=Ka+Ma|0;c[va+30136>>2]=Sa+Ya;Ka=Ya+Ma|0;c[va+30140>>2]=Sa+Ka;c[va+30160>>2]=Sa+(Ka+Ma);mJb(va+1080|0);mJb(va+35860|0);break}KIb(e,16,2546864,(s=i,i=i+16|0,c[s>>2]=L,c[s+8>>2]=M,s)|0);i=s;t=-12;i=j;return t|0}}while(0);M=l+1764|0;L=c[l+1796>>2]|0;va=0;while(1){if(L>>>(va>>>0)>>>0>64>>>0){va=va+1|0}else{break}}Aa=M;c[Aa>>2]=va;M=0;while(1){if(L>>>(M>>>0)>>>0>3>>>0){M=M+1|0}else{break}}L=M-1|0;M=(L|0)<0?0:L;L=c[p>>2]|0;c:do{if(M>>>0>va>>>0){k=c[m>>2]|0;Za=c[r>>2]|0;Ma=va;Ka=L;while(1){Sa=d[k+(Ka>>>3)|0]|0;Ya=((Ka|0)<(Za|0))+Ka|0;c[p>>2]=Ya;if((Sa&128>>>((Ka&7)>>>0)|0)==0){_a=Ma;$a=Ya;break c}Sa=Ma+1|0;c[Aa>>2]=Sa;if(M>>>0>Sa>>>0){Ma=Sa;Ka=Ya}else{_a=Sa;$a=Ya;break}}}else{_a=va;$a=L}}while(0);L=c[m>>2]|0;va=d[L+($a>>>3)|0]|0;M=c[r>>2]|0;Aa=(($a|0)<(M|0))+$a|0;c[p>>2]=Aa;if((va&128>>>(($a&7)>>>0)|0)==0){ab=0}else{$a=d[L+(Aa>>>3)|0]<<(Aa&7)>>>7;c[p>>2]=((Aa|0)<(M|0))+Aa;ab=($a&1)+1|0}c[l+1768>>2]=ab;c[l+1776>>2]=1<<ab;ab=l+1772|0;$a=1<<_a;do{if((c[ab>>2]|0)!=($a|0)){c[ab>>2]=$a;Aa=l+1072|0;M=wJb(c[Aa>>2]|0,l+1076|0,20<<_a)|0;c[Aa>>2]=M;if((M|0)!=0){break}KIb(e,16,2529232,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-12;i=j;return t|0}}while(0);do{if((a[v]|0)==0){if((a[h]|0)!=0){Ba=149;break}if((a[l+1144|0]|0)!=0){Ba=149}}else{Ba=149}}while(0);if((Ba|0)==149){h=l+5890|0;nrc(l+7929|0,226944,311)|0;nrc(h|0,226944,311)|0;nrc(l+3851|0,h|0,311)|0;nrc(l+1812|0,h|0,311)|0;nrc(l+2123|0,228304,1728)|0;nrc(l+4162|0,228304,1728)|0;nrc(l+6201|0,228304,1728)|0;nrc(l+8240|0,228304,1728)|0}h=c[p>>2]|0;_a=c[r>>2]|0;r=c[m>>2]|0;m=r+(h>>>3)|0;$a=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(h&7)>>>16;m=h+16|0;h=_a>>>0>m>>>0?m:_a;m=-h&7;if((m|0)==0){bb=h}else{ab=m+h|0;bb=_a>>>0>ab>>>0?ab:_a}c[p>>2]=bb;p=r+(bb>>3)|0;bb=p-f|0;if(($a|0)>(g-bb|0)){KIb(e,16,2514016,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}g=l+1052|0;f=g;V9a(f,p,$a);p=g;g=c[p>>2]|0;r=d[1252840+g|0]|0;_a=l+1056|0;ab=c[_a>>2]|0;h=l+1068|0;m=c[h>>2]|0;M=g<<r;c[p>>2]=M;g=m<<r;m=ab+r|0;do{if((m|0)>-1){r=l+1060|0;ab=c[r>>2]|0;if(!(ab>>>0<(c[l+1064>>2]|0)>>>0)){cb=g;db=m;break}c[r>>2]=ab+2;r=ab;cb=((he((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535)<<m|g;db=m-16|0}else{cb=g;db=m}}while(0);c[_a>>2]=db;m=((M<<7)-128>>8)+1|0;g=m<<16;if(!(cb>>>0<g>>>0)){c[p>>2]=M-m;c[h>>2]=cb-g;KIb(e,16,2500312,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}c[p>>2]=m;c[h>>2]=cb;do{if((a[v]|0)==0){if((a[l+1144|0]|0)!=0){Ba=161;break}mrc(l+16628|0,0,13208)|0}else{Ba=161}}while(0);if((Ba|0)==161){mrc(l+18316|0,0,11520)|0}s=l+9968|0;e=l+1812|0;nrc(s|0,e+(N*2039|0)|0,311)|0;do{if((a[ta]|0)==0){g=l+1060|0;M=l+1064|0;r=d[1252840+m|0]|0;ab=m<<r;c[p>>2]=ab;Aa=cb<<r;L=r+db|0;do{if((L|0)>-1){r=c[g>>2]|0;if(!(r>>>0<(c[M>>2]|0)>>>0)){eb=Aa;fb=L;break}c[g>>2]=r+2;va=r;eb=((he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)&65535)<<L|Aa;fb=L-16|0}else{eb=Aa;fb=L}}while(0);c[_a>>2]=fb;L=((ab<<7)-128>>8)+1|0;Aa=L<<16;va=eb>>>0>=Aa>>>0;r=va?ab-L|0:L;L=eb-(va?Aa:0)|0;c[h>>2]=L;Aa=(va&1)<<1;va=d[1252840+r|0]|0;Ka=r<<va;c[p>>2]=Ka;r=L<<va;L=va+fb|0;do{if((L|0)>-1){va=c[g>>2]|0;if(!(va>>>0<(c[M>>2]|0)>>>0)){gb=r;hb=L;break}c[g>>2]=va+2;Ma=va;gb=((he((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<L|r;hb=L-16|0}else{gb=r;hb=L}}while(0);c[_a>>2]=hb;L=((Ka<<7)-128>>8)+1|0;r=L<<16;ab=gb>>>0>=r>>>0;Ma=ab?Ka-L|0:L;c[p>>2]=Ma;L=gb-(ab?r:0)|0;c[h>>2]=L;r=ab&1|Aa;ab=l+29836|0;c[ab>>2]=r;if((r|0)==3){va=d[1252840+Ma|0]|0;Za=Ma<<va;c[p>>2]=Za;k=L<<va;Da=hb+va|0;do{if((Da|0)>-1){va=c[g>>2]|0;if(!(va>>>0<(c[M>>2]|0)>>>0)){ib=k;jb=Da;break}c[g>>2]=va+2;Ya=va;ib=((he((d[Ya]|d[Ya+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|k;jb=Da-16|0}else{ib=k;jb=Da}}while(0);c[_a>>2]=jb;Da=((Za<<7)-128>>8)+1|0;k=Da<<16;Aa=ib>>>0>=k>>>0;Ka=Aa?Za-Da|0:Da;c[p>>2]=Ka;Da=ib-(Aa?k:0)|0;c[h>>2]=Da;k=Aa?4:3;c[ab>>2]=k;kb=k;lb=Ka;mb=jb;nb=Da}else{kb=r;lb=Ma;mb=hb;nb=L}if((kb|0)!=4){ob=g;pb=M;break}Da=d[1252840+lb|0]|0;Ka=lb<<Da;c[p>>2]=Ka;k=nb<<Da;Aa=mb+Da|0;do{if((Aa|0)>-1){Da=c[g>>2]|0;if(!(Da>>>0<(c[M>>2]|0)>>>0)){qb=k;rb=Aa;break}c[g>>2]=Da+2;Ya=Da;qb=((he((d[Ya]|d[Ya+1|0]<<8)<<16>>16|0)|0)&65535)<<Aa|k;rb=Aa-16|0}else{qb=k;rb=Aa}}while(0);c[_a>>2]=rb;Aa=((Ka*252|0)-252>>8)+1|0;k=Aa<<16;if(qb>>>0<k>>>0){c[p>>2]=Aa;c[h>>2]=qb;sb=Aa;tb=rb;ub=qb}else{c[p>>2]=Ka-Aa;c[h>>2]=qb-k;k=l+10157|0;a[k]=Dbb(f,d[k]|0)|0;sb=c[p>>2]|0;tb=c[_a>>2]|0;ub=c[h>>2]|0}k=d[1252840+sb|0]|0;Aa=sb<<k;c[p>>2]=Aa;L=ub<<k;Ma=tb+k|0;do{if((Ma|0)>-1){k=c[g>>2]|0;if(!(k>>>0<(c[M>>2]|0)>>>0)){vb=L;wb=Ma;break}c[g>>2]=k+2;r=k;vb=((he((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|L;wb=Ma-16|0}else{vb=L;wb=Ma}}while(0);c[_a>>2]=wb;Ma=((Aa*252|0)-252>>8)+1|0;L=Ma<<16;if(vb>>>0<L>>>0){c[p>>2]=Ma;c[h>>2]=vb}else{c[p>>2]=Aa-Ma;c[h>>2]=vb-L;L=l+10158|0;a[L]=Dbb(f,d[L]|0)|0}L=l+10153|0;Ma=0;do{Ka=c[p>>2]|0;r=d[1252840+Ka|0]|0;k=c[_a>>2]|0;ab=c[h>>2]|0;Za=Ka<<r;c[p>>2]=Za;Ka=ab<<r;ab=k+r|0;do{if((ab|0)>-1){r=c[g>>2]|0;if(!(r>>>0<(c[M>>2]|0)>>>0)){xb=Ka;yb=ab;break}c[g>>2]=r+2;k=r;xb=((he((d[k]|d[k+1|0]<<8)<<16>>16|0)|0)&65535)<<ab|Ka;yb=ab-16|0}else{xb=Ka;yb=ab}}while(0);c[_a>>2]=yb;ab=((Za*252|0)-252>>8)+1|0;Ka=ab<<16;if(xb>>>0<Ka>>>0){c[p>>2]=ab;c[h>>2]=xb;zb=ab;Ab=yb;Bb=xb}else{c[p>>2]=Za-ab;c[h>>2]=xb-Ka;Ka=L+(Ma<<1)|0;a[Ka]=Dbb(f,d[Ka]|0)|0;zb=c[p>>2]|0;Ab=c[_a>>2]|0;Bb=c[h>>2]|0}Ka=d[1252840+zb|0]|0;ab=zb<<Ka;c[p>>2]=ab;la=Bb<<Ka;o=Ab+Ka|0;do{if((o|0)>-1){Ka=c[g>>2]|0;if(!(Ka>>>0<(c[M>>2]|0)>>>0)){Cb=la;Db=o;break}c[g>>2]=Ka+2;q=Ka;Cb=((he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<o|la;Db=o-16|0}else{Cb=la;Db=o}}while(0);c[_a>>2]=Db;o=((ab*252|0)-252>>8)+1|0;la=o<<16;if(Cb>>>0<la>>>0){c[p>>2]=o;c[h>>2]=Cb}else{c[p>>2]=ab-o;c[h>>2]=Cb-la;la=L+(Ma<<1)+1|0;a[la]=Dbb(f,d[la]|0)|0}Ma=Ma+1|0;}while((Ma|0)<2);Ma=l+10147|0;L=0;while(1){Aa=c[p>>2]|0;la=d[1252840+Aa|0]|0;o=c[_a>>2]|0;Za=c[h>>2]|0;q=Aa<<la;c[p>>2]=q;Aa=Za<<la;Za=o+la|0;do{if((Za|0)>-1){la=c[g>>2]|0;if(!(la>>>0<(c[M>>2]|0)>>>0)){Eb=Aa;Fb=Za;break}c[g>>2]=la+2;o=la;Eb=((he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<Za|Aa;Fb=Za-16|0}else{Eb=Aa;Fb=Za}}while(0);c[_a>>2]=Fb;Za=((q*252|0)-252>>8)+1|0;Aa=Za<<16;if(Eb>>>0<Aa>>>0){c[p>>2]=Za;c[h>>2]=Eb}else{c[p>>2]=q-Za;c[h>>2]=Eb-Aa;Aa=Ma+L|0;a[Aa]=Dbb(f,d[Aa]|0)|0}Aa=L+1|0;if((Aa|0)<3){L=Aa}else{Gb=0;break}}while(1){L=c[p>>2]|0;Aa=d[1252840+L|0]|0;Za=c[_a>>2]|0;ab=c[h>>2]|0;o=L<<Aa;c[p>>2]=o;L=ab<<Aa;ab=Za+Aa|0;do{if((ab|0)>-1){Aa=c[g>>2]|0;if(!(Aa>>>0<(c[M>>2]|0)>>>0)){Hb=L;Ib=ab;break}c[g>>2]=Aa+2;Za=Aa;Hb=((he((d[Za]|d[Za+1|0]<<8)<<16>>16|0)|0)&65535)<<ab|L;Ib=ab-16|0}else{Hb=L;Ib=ab}}while(0);c[_a>>2]=Ib;ab=((o*252|0)-252>>8)+1|0;L=ab<<16;if(Hb>>>0<L>>>0){c[p>>2]=ab;c[h>>2]=Hb}else{c[p>>2]=o-ab;c[h>>2]=Hb-L;L=Ma+3+Gb|0;a[L]=Dbb(f,d[L]|0)|0}L=Gb+1|0;if((L|0)<3){Gb=L}else{ob=g;pb=M;break}}}else{c[l+29836>>2]=0;ob=l+1060|0;pb=l+1064|0}}while(0);Gb=l+29836|0;Hb=l+10279|0;Ib=0;while(1){if((Ib|0)>=4){Jb=0;break}Eb=c[p>>2]|0;Fb=d[1252840+Eb|0]|0;Cb=c[_a>>2]|0;Db=c[h>>2]|0;Ab=Eb<<Fb;c[p>>2]=Ab;Eb=Db<<Fb;Db=Cb+Fb|0;do{if((Db|0)>-1){Fb=c[ob>>2]|0;if(!(Fb>>>0<(c[pb>>2]|0)>>>0)){Kb=Eb;Lb=Db;break}c[ob>>2]=Fb+2;Cb=Fb;Kb=((he((d[Cb]|d[Cb+1|0]<<8)<<16>>16|0)|0)&65535)<<Db|Eb;Lb=Db-16|0}else{Kb=Eb;Lb=Db}}while(0);c[_a>>2]=Lb;Db=((Ab<<7)-128>>8)+1|0;Eb=Db<<16;Cb=Kb>>>0>=Eb>>>0;c[p>>2]=Cb?Ab-Db|0:Db;c[h>>2]=Kb-(Cb?Eb:0);if(Cb){Cb=0;do{Eb=0;do{Db=0;do{d:do{if((Db|0)==0){Fb=0;do{if((Fb|0)>2){break d}else{Mb=0}do{Bb=c[p>>2]|0;zb=d[1252840+Bb|0]|0;xb=c[_a>>2]|0;yb=c[h>>2]|0;vb=Bb<<zb;c[p>>2]=vb;Bb=yb<<zb;yb=xb+zb|0;do{if((yb|0)>-1){zb=c[ob>>2]|0;if(!(zb>>>0<(c[pb>>2]|0)>>>0)){Nb=Bb;Ob=yb;break}c[ob>>2]=zb+2;xb=zb;Nb=((he((d[xb]|d[xb+1|0]<<8)<<16>>16|0)|0)&65535)<<yb|Bb;Ob=yb-16|0}else{Nb=Bb;Ob=yb}}while(0);c[_a>>2]=Ob;yb=((vb*252|0)-252>>8)+1|0;Bb=yb<<16;if(Nb>>>0<Bb>>>0){c[p>>2]=yb;c[h>>2]=Nb;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Fb*11|0)+Mb|0]=a[e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Eb*108|0)+(Fb*3|0)+Mb|0]|0}else{c[p>>2]=vb-yb;c[h>>2]=Nb-Bb;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Fb*11|0)+Mb|0]=Dbb(f,d[e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Eb*108|0)+(Fb*3|0)+Mb|0]|0)|0}Mb=Mb+1|0;}while((Mb|0)<3);a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Fb*11|0)+3|0]=0;Fb=Fb+1|0;}while((Fb|0)<6)}else{Fb=0;do{Bb=0;do{yb=c[p>>2]|0;xb=d[1252840+yb|0]|0;zb=c[_a>>2]|0;wb=c[h>>2]|0;tb=yb<<xb;c[p>>2]=tb;yb=wb<<xb;wb=zb+xb|0;do{if((wb|0)>-1){xb=c[ob>>2]|0;if(!(xb>>>0<(c[pb>>2]|0)>>>0)){Pb=yb;Qb=wb;break}c[ob>>2]=xb+2;zb=xb;Pb=((he((d[zb]|d[zb+1|0]<<8)<<16>>16|0)|0)&65535)<<wb|yb;Qb=wb-16|0}else{Pb=yb;Qb=wb}}while(0);c[_a>>2]=Qb;wb=((tb*252|0)-252>>8)+1|0;yb=wb<<16;if(Pb>>>0<yb>>>0){c[p>>2]=wb;c[h>>2]=Pb;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Db*66|0)+(Fb*11|0)+Bb|0]=a[e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Eb*108|0)+(Db*18|0)+(Fb*3|0)+Bb|0]|0}else{c[p>>2]=tb-wb;c[h>>2]=Pb-yb;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Db*66|0)+(Fb*11|0)+Bb|0]=Dbb(f,d[e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Eb*108|0)+(Db*18|0)+(Fb*3|0)+Bb|0]|0)|0}Bb=Bb+1|0;}while((Bb|0)<3);a[Hb+(Ib*1584|0)+(Cb*792|0)+(Eb*396|0)+(Db*66|0)+(Fb*11|0)+3|0]=0;Fb=Fb+1|0;}while((Fb|0)<6)}}while(0);Db=Db+1|0;}while((Db|0)<6);Eb=Eb+1|0;}while((Eb|0)<2);Cb=Cb+1|0;}while((Cb|0)<2)}else{Cb=0;do{Ab=0;do{Eb=0;do{if((Eb|0)==0){o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+3|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+3|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+11|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+14|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+6|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+22|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+25|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+9|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+33|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+36|0]=0}else{o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+3|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+3|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+11|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+14|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+6|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+22|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+25|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+9|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+33|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+36|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+12|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+44|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+47|0]=0;o=e+(N*2039|0)+311+(Ib*432|0)+(Cb*216|0)+(Ab*108|0)+(Eb*18|0)+15|0;Db=Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+55|0;a[Db]=a[o]|0;a[Db+1|0]=a[o+1|0]|0;a[Db+2|0]=a[o+2|0]|0;a[Hb+(Ib*1584|0)+(Cb*792|0)+(Ab*396|0)+(Eb*66|0)+58|0]=0}Eb=Eb+1|0;}while((Eb|0)<6);Ab=Ab+1|0;}while((Ab|0)<2);Cb=Cb+1|0;}while((Cb|0)<2)}if((c[Gb>>2]|0)==(Ib|0)){Jb=0;break}else{Ib=Ib+1|0}}do{Ib=c[p>>2]|0;Gb=d[1252840+Ib|0]|0;Hb=c[_a>>2]|0;N=c[h>>2]|0;e=Ib<<Gb;c[p>>2]=e;Ib=N<<Gb;N=Hb+Gb|0;do{if((N|0)>-1){Gb=c[ob>>2]|0;if(!(Gb>>>0<(c[pb>>2]|0)>>>0)){Rb=Ib;Sb=N;break}c[ob>>2]=Gb+2;Hb=Gb;Rb=((he((d[Hb]|d[Hb+1|0]<<8)<<16>>16|0)|0)&65535)<<N|Ib;Sb=N-16|0}else{Rb=Ib;Sb=N}}while(0);c[_a>>2]=Sb;N=((e*252|0)-252>>8)+1|0;Ib=N<<16;if(Rb>>>0<Ib>>>0){c[p>>2]=N;c[h>>2]=Rb}else{c[p>>2]=e-N;c[h>>2]=Rb-Ib;Ib=l+(Jb+10159)|0;a[Ib]=Dbb(f,d[Ib]|0)|0}Jb=Jb+1|0;}while((Jb|0)<3);do{if((a[v]|0)==0){if((a[l+1144|0]|0)!=0){break}Jb=l+10102|0;Rb=0;do{Sb=0;do{Ib=c[p>>2]|0;N=d[1252840+Ib|0]|0;Hb=c[_a>>2]|0;Gb=c[h>>2]|0;Pb=Ib<<N;c[p>>2]=Pb;Ib=Gb<<N;Gb=Hb+N|0;do{if((Gb|0)>-1){N=c[ob>>2]|0;if(!(N>>>0<(c[pb>>2]|0)>>>0)){Tb=Ib;Ub=Gb;break}c[ob>>2]=N+2;Hb=N;Tb=((he((d[Hb]|d[Hb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Ib;Ub=Gb-16|0}else{Tb=Ib;Ub=Gb}}while(0);c[_a>>2]=Ub;Gb=((Pb*252|0)-252>>8)+1|0;Ib=Gb<<16;if(Tb>>>0<Ib>>>0){c[p>>2]=Gb;c[h>>2]=Tb}else{c[p>>2]=Pb-Gb;c[h>>2]=Tb-Ib;Ib=Jb+(Rb*3|0)+Sb|0;a[Ib]=Dbb(f,d[Ib]|0)|0}Sb=Sb+1|0;}while((Sb|0)<3);Rb=Rb+1|0;}while((Rb|0)<7);if((c[l+1148>>2]|0)==4){Rb=l+10094|0;Jb=0;while(1){e=c[p>>2]|0;Sb=d[1252840+e|0]|0;Ib=c[_a>>2]|0;Gb=c[h>>2]|0;Hb=e<<Sb;c[p>>2]=Hb;e=Gb<<Sb;Gb=Ib+Sb|0;do{if((Gb|0)>-1){Sb=c[ob>>2]|0;if(!(Sb>>>0<(c[pb>>2]|0)>>>0)){Vb=e;Wb=Gb;break}c[ob>>2]=Sb+2;Ib=Sb;Vb=((he((d[Ib]|d[Ib+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|e;Wb=Gb-16|0}else{Vb=e;Wb=Gb}}while(0);c[_a>>2]=Wb;Gb=((Hb*252|0)-252>>8)+1|0;e=Gb<<16;if(Vb>>>0<e>>>0){c[p>>2]=Gb;c[h>>2]=Vb;Xb=Gb;Yb=Wb;Zb=Vb}else{c[p>>2]=Hb-Gb;c[h>>2]=Vb-e;e=Rb+(Jb<<1)|0;a[e]=Dbb(f,d[e]|0)|0;Xb=c[p>>2]|0;Yb=c[_a>>2]|0;Zb=c[h>>2]|0}e=d[1252840+Xb|0]|0;Gb=Xb<<e;c[p>>2]=Gb;Ib=Zb<<e;Sb=Yb+e|0;do{if((Sb|0)>-1){e=c[ob>>2]|0;if(!(e>>>0<(c[pb>>2]|0)>>>0)){_b=Ib;$b=Sb;break}c[ob>>2]=e+2;N=e;_b=((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<Sb|Ib;$b=Sb-16|0}else{_b=Ib;$b=Sb}}while(0);c[_a>>2]=$b;Sb=((Gb*252|0)-252>>8)+1|0;Ib=Sb<<16;if(_b>>>0<Ib>>>0){c[p>>2]=Sb;c[h>>2]=_b}else{c[p>>2]=Gb-Sb;c[h>>2]=_b-Ib;Ib=Rb+(Jb<<1)+1|0;a[Ib]=Dbb(f,d[Ib]|0)|0}Ib=Jb+1|0;if((Ib|0)<4){Jb=Ib}else{ac=0;break}}}else{ac=0}do{Jb=c[p>>2]|0;Rb=d[1252840+Jb|0]|0;Ib=c[_a>>2]|0;Sb=c[h>>2]|0;Hb=Jb<<Rb;c[p>>2]=Hb;Jb=Sb<<Rb;Sb=Ib+Rb|0;do{if((Sb|0)>-1){Rb=c[ob>>2]|0;if(!(Rb>>>0<(c[pb>>2]|0)>>>0)){bc=Jb;cc=Sb;break}c[ob>>2]=Rb+2;Ib=Rb;bc=((he((d[Ib]|d[Ib+1|0]<<8)<<16>>16|0)|0)&65535)<<Sb|Jb;cc=Sb-16|0}else{bc=Jb;cc=Sb}}while(0);c[_a>>2]=cc;Sb=((Hb*252|0)-252>>8)+1|0;Jb=Sb<<16;if(bc>>>0<Jb>>>0){c[p>>2]=Sb;c[h>>2]=bc}else{c[p>>2]=Hb-Sb;c[h>>2]=bc-Jb;Jb=l+(ac+10123)|0;a[Jb]=Dbb(f,d[Jb]|0)|0}ac=ac+1|0;}while((ac|0)<4);if((a[l+1152|0]|0)==0){c[l+29840>>2]=0;Ba=288}else{Jb=c[p>>2]|0;Sb=d[1252840+Jb|0]|0;Gb=c[_a>>2]|0;Ib=c[h>>2]|0;Rb=Jb<<Sb;c[p>>2]=Rb;Jb=Ib<<Sb;Ib=Gb+Sb|0;do{if((Ib|0)>-1){Sb=c[ob>>2]|0;if(!(Sb>>>0<(c[pb>>2]|0)>>>0)){dc=Jb;ec=Ib;break}c[ob>>2]=Sb+2;Gb=Sb;dc=((he((d[Gb]|d[Gb+1|0]<<8)<<16>>16|0)|0)&65535)<<Ib|Jb;ec=Ib-16|0}else{dc=Jb;ec=Ib}}while(0);c[_a>>2]=ec;Ib=((Rb<<7)-128>>8)+1|0;Jb=Ib<<16;Gb=dc>>>0>=Jb>>>0;Sb=Gb&1;N=Gb?Rb-Ib|0:Ib;c[p>>2]=N;Ib=dc-(Gb?Jb:0)|0;c[h>>2]=Ib;Jb=l+29840|0;c[Jb>>2]=Sb;do{if(Gb){e=d[1252840+N|0]|0;Qb=N<<e;c[p>>2]=Qb;Mb=Ib<<e;Nb=ec+e|0;do{if((Nb|0)>-1){e=c[ob>>2]|0;if(!(e>>>0<(c[pb>>2]|0)>>>0)){fc=Mb;gc=Nb;break}c[ob>>2]=e+2;Ob=e;fc=((he((d[Ob]|d[Ob+1|0]<<8)<<16>>16|0)|0)&65535)<<Nb|Mb;gc=Nb-16|0}else{fc=Mb;gc=Nb}}while(0);c[_a>>2]=gc;Nb=((Qb<<7)-128>>8)+1|0;Mb=Nb<<16;Hb=fc>>>0>=Mb>>>0;Ob=Hb?Qb-Nb|0:Nb;c[p>>2]=Ob;Nb=fc-(Hb?Mb:0)|0;c[h>>2]=Nb;Mb=(Hb&1)+Sb|0;c[Jb>>2]=Mb;if((Mb|0)==2){hc=0;ic=Ob;jc=gc;kc=Nb}else{lc=Mb;break}while(1){Mb=d[1252840+ic|0]|0;Nb=ic<<Mb;c[p>>2]=Nb;Ob=kc<<Mb;Hb=jc+Mb|0;do{if((Hb|0)>-1){Mb=c[ob>>2]|0;if(!(Mb>>>0<(c[pb>>2]|0)>>>0)){mc=Ob;nc=Hb;break}c[ob>>2]=Mb+2;e=Mb;mc=((he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535)<<Hb|Ob;nc=Hb-16|0}else{mc=Ob;nc=Hb}}while(0);c[_a>>2]=nc;Hb=((Nb*252|0)-252>>8)+1|0;Ob=Hb<<16;if(mc>>>0<Ob>>>0){c[p>>2]=Hb;c[h>>2]=mc}else{c[p>>2]=Nb-Hb;c[h>>2]=mc-Ob;Ob=l+(hc+10127)|0;a[Ob]=Dbb(f,d[Ob]|0)|0}Ob=hc+1|0;if((Ob|0)>=5){break}hc=Ob;ic=c[p>>2]|0;jc=c[_a>>2]|0;kc=c[h>>2]|0}lc=c[Jb>>2]|0}else{lc=Sb}}while(0);if((lc|0)==1){oc=0;Ba=304}else{Ba=288}}if((Ba|0)==288){Sb=l+29840|0;Jb=l+10132|0;Ib=0;do{N=c[p>>2]|0;Gb=d[1252840+N|0]|0;Rb=c[_a>>2]|0;Qb=c[h>>2]|0;Ob=N<<Gb;c[p>>2]=Ob;N=Qb<<Gb;Qb=Rb+Gb|0;do{if((Qb|0)>-1){Gb=c[ob>>2]|0;if(!(Gb>>>0<(c[pb>>2]|0)>>>0)){pc=N;qc=Qb;break}c[ob>>2]=Gb+2;Rb=Gb;pc=((he((d[Rb]|d[Rb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|N;qc=Qb-16|0}else{pc=N;qc=Qb}}while(0);c[_a>>2]=qc;Qb=((Ob*252|0)-252>>8)+1|0;N=Qb<<16;if(pc>>>0<N>>>0){c[p>>2]=Qb;c[h>>2]=pc;rc=Qb;sc=qc;tc=pc}else{c[p>>2]=Ob-Qb;c[h>>2]=pc-N;N=Jb+(Ib<<1)|0;a[N]=Dbb(f,d[N]|0)|0;rc=c[p>>2]|0;sc=c[_a>>2]|0;tc=c[h>>2]|0}N=d[1252840+rc|0]|0;Qb=rc<<N;c[p>>2]=Qb;Rb=tc<<N;Gb=sc+N|0;do{if((Gb|0)>-1){N=c[ob>>2]|0;if(!(N>>>0<(c[pb>>2]|0)>>>0)){uc=Rb;vc=Gb;break}c[ob>>2]=N+2;Hb=N;uc=((he((d[Hb]|d[Hb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Rb;vc=Gb-16|0}else{uc=Rb;vc=Gb}}while(0);c[_a>>2]=vc;Gb=((Qb*252|0)-252>>8)+1|0;Rb=Gb<<16;if(uc>>>0<Rb>>>0){c[p>>2]=Gb;c[h>>2]=uc}else{c[p>>2]=Qb-Gb;c[h>>2]=uc-Rb;Rb=Jb+(Ib<<1)+1|0;a[Rb]=Dbb(f,d[Rb]|0)|0}Ib=Ib+1|0;}while((Ib|0)<5);if((c[Sb>>2]|0)!=0){oc=0;Ba=304}}if((Ba|0)==304){while(1){Ba=0;Ib=c[p>>2]|0;Jb=d[1252840+Ib|0]|0;Rb=c[_a>>2]|0;Gb=c[h>>2]|0;Ob=Ib<<Jb;c[p>>2]=Ob;Ib=Gb<<Jb;Gb=Rb+Jb|0;do{if((Gb|0)>-1){Jb=c[ob>>2]|0;if(!(Jb>>>0<(c[pb>>2]|0)>>>0)){wc=Ib;xc=Gb;break}c[ob>>2]=Jb+2;Rb=Jb;wc=((he((d[Rb]|d[Rb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Ib;xc=Gb-16|0}else{wc=Ib;xc=Gb}}while(0);c[_a>>2]=xc;Gb=((Ob*252|0)-252>>8)+1|0;Ib=Gb<<16;if(wc>>>0<Ib>>>0){c[p>>2]=Gb;c[h>>2]=wc}else{c[p>>2]=Ob-Gb;c[h>>2]=wc-Ib;Ib=l+(oc+10142)|0;a[Ib]=Dbb(f,d[Ib]|0)|0}Ib=oc+1|0;if((Ib|0)<5){oc=Ib;Ba=304}else{break}}}Sb=s;Ib=0;do{Gb=0;do{Qb=c[p>>2]|0;Rb=d[1252840+Qb|0]|0;Jb=c[_a>>2]|0;Hb=c[h>>2]|0;N=Qb<<Rb;c[p>>2]=N;Qb=Hb<<Rb;Hb=Jb+Rb|0;do{if((Hb|0)>-1){Rb=c[ob>>2]|0;if(!(Rb>>>0<(c[pb>>2]|0)>>>0)){yc=Qb;zc=Hb;break}c[ob>>2]=Rb+2;Jb=Rb;yc=((he((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535)<<Hb|Qb;zc=Hb-16|0}else{yc=Qb;zc=Hb}}while(0);c[_a>>2]=zc;Hb=((N*252|0)-252>>8)+1|0;Qb=Hb<<16;if(yc>>>0<Qb>>>0){c[p>>2]=Hb;c[h>>2]=yc}else{c[p>>2]=N-Hb;c[h>>2]=yc-Qb;Qb=Sb+(Ib*9|0)+Gb|0;a[Qb]=Dbb(f,d[Qb]|0)|0}Gb=Gb+1|0;}while((Gb|0)<9);Ib=Ib+1|0;}while((Ib|0)<4);Ib=l+10231|0;Sb=0;while(1){Gb=3-Sb|0;Ob=0;do{Qb=0;do{Hb=c[p>>2]|0;Nb=d[1252840+Hb|0]|0;Jb=c[_a>>2]|0;Rb=c[h>>2]|0;Pb=Hb<<Nb;c[p>>2]=Pb;Hb=Rb<<Nb;Rb=Jb+Nb|0;do{if((Rb|0)>-1){Nb=c[ob>>2]|0;if(!(Nb>>>0<(c[pb>>2]|0)>>>0)){Ac=Hb;Bc=Rb;break}c[ob>>2]=Nb+2;Jb=Nb;Ac=((he((d[Jb]|d[Jb+1|0]<<8)<<16>>16|0)|0)&65535)<<Rb|Hb;Bc=Rb-16|0}else{Ac=Hb;Bc=Rb}}while(0);c[_a>>2]=Bc;Rb=((Pb*252|0)-252>>8)+1|0;Hb=Rb<<16;if(Ac>>>0<Hb>>>0){c[p>>2]=Rb;c[h>>2]=Ac}else{c[p>>2]=Pb-Rb;c[h>>2]=Ac-Hb;Hb=Ib+(Gb*12|0)+(Ob*3|0)+Qb|0;a[Hb]=Dbb(f,d[Hb]|0)|0}Qb=Qb+1|0;}while((Qb|0)<3);Ob=Ob+1|0;}while((Ob|0)<4);Ob=Sb+1|0;if((Ob|0)<4){Sb=Ob}else{Cc=0;break}}do{Sb=c[p>>2]|0;Ib=d[1252840+Sb|0]|0;Ob=c[_a>>2]|0;Gb=c[h>>2]|0;Qb=Sb<<Ib;c[p>>2]=Qb;Sb=Gb<<Ib;Gb=Ob+Ib|0;do{if((Gb|0)>-1){Ib=c[ob>>2]|0;if(!(Ib>>>0<(c[pb>>2]|0)>>>0)){Dc=Sb;Ec=Gb;break}c[ob>>2]=Ib+2;Ob=Ib;Dc=((he((d[Ob]|d[Ob+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Sb;Ec=Gb-16|0}else{Dc=Sb;Ec=Gb}}while(0);c[_a>>2]=Ec;Gb=((Qb*252|0)-252>>8)+1|0;Sb=Gb<<16;if(Dc>>>0<Sb>>>0){c[p>>2]=Gb;c[h>>2]=Dc}else{Ob=Qb-Gb|0;c[p>>2]=Ob;Gb=Dc-Sb|0;c[h>>2]=Gb;Sb=7;Ib=0;N=Ob;Ob=Ec;Hb=Gb;while(1){Gb=Sb-1|0;Rb=Ib<<1;Jb=d[1252840+N|0]|0;Nb=N<<Jb;c[p>>2]=Nb;e=Hb<<Jb;Mb=Jb+Ob|0;do{if((Mb|0)>-1){Jb=c[ob>>2]|0;if(!(Jb>>>0<(c[pb>>2]|0)>>>0)){Fc=e;Gc=Mb;break}c[ob>>2]=Jb+2;Kb=Jb;Fc=((he((d[Kb]|d[Kb+1|0]<<8)<<16>>16|0)|0)&65535)<<Mb|e;Gc=Mb-16|0}else{Fc=e;Gc=Mb}}while(0);c[_a>>2]=Gc;Mb=((Nb<<7)-128>>8)+1|0;e=Mb<<16;Kb=Fc>>>0>=e>>>0;Jb=Kb?Nb-Mb|0:Mb;c[p>>2]=Jb;Mb=Fc-(Kb?e:0)|0;c[h>>2]=Mb;Hc=Kb&1|Rb;if((Gb|0)==0){break}else{Sb=Gb;Ib=Hc;N=Jb;Ob=Gc;Hb=Mb}}a[l+(Cc+10162)|0]=Hc<<1|1}Cc=Cc+1|0;}while((Cc|0)<3);Hb=l+10165|0;Ob=0;while(1){N=c[p>>2]|0;Ib=d[1252840+N|0]|0;Sb=c[_a>>2]|0;Qb=c[h>>2]|0;Mb=N<<Ib;c[p>>2]=Mb;N=Qb<<Ib;Qb=Sb+Ib|0;do{if((Qb|0)>-1){Ib=c[ob>>2]|0;if(!(Ib>>>0<(c[pb>>2]|0)>>>0)){Ic=N;Jc=Qb;break}c[ob>>2]=Ib+2;Sb=Ib;Ic=((he((d[Sb]|d[Sb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|N;Jc=Qb-16|0}else{Ic=N;Jc=Qb}}while(0);c[_a>>2]=Jc;Qb=((Mb*252|0)-252>>8)+1|0;N=Qb<<16;if(Ic>>>0<N>>>0){c[p>>2]=Qb;c[h>>2]=Ic;Kc=0}else{Sb=Mb-Qb|0;c[p>>2]=Sb;Qb=Ic-N|0;c[h>>2]=Qb;N=7;Ib=0;Jb=Sb;Sb=Jc;Kb=Qb;while(1){Qb=N-1|0;e=Ib<<1;Lb=d[1252840+Jb|0]|0;Cb=Jb<<Lb;c[p>>2]=Cb;Ab=Kb<<Lb;Eb=Lb+Sb|0;do{if((Eb|0)>-1){Lb=c[ob>>2]|0;if(!(Lb>>>0<(c[pb>>2]|0)>>>0)){Lc=Ab;Mc=Eb;break}c[ob>>2]=Lb+2;o=Lb;Lc=((he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<Eb|Ab;Mc=Eb-16|0}else{Lc=Ab;Mc=Eb}}while(0);c[_a>>2]=Mc;Eb=((Cb<<7)-128>>8)+1|0;Ab=Eb<<16;Gb=Lc>>>0>=Ab>>>0;Rb=Gb?Cb-Eb|0:Eb;c[p>>2]=Rb;Eb=Lc-(Gb?Ab:0)|0;c[h>>2]=Eb;Nc=Gb&1|e;if((Qb|0)==0){break}else{N=Qb;Ib=Nc;Jb=Rb;Sb=Mc;Kb=Eb}}a[Hb+(Ob*33|0)|0]=Nc<<1|1;Kc=0}while(1){Kb=(Kc|0)<10;Sb=c[p>>2]|0;Jb=d[1252840+Sb|0]|0;Ib=c[_a>>2]|0;N=c[h>>2]|0;Mb=Sb<<Jb;c[p>>2]=Mb;Sb=N<<Jb;N=Ib+Jb|0;do{if((N|0)>-1){Jb=c[ob>>2]|0;if(!(Jb>>>0<(c[pb>>2]|0)>>>0)){Oc=Sb;Pc=N;break}c[ob>>2]=Jb+2;Ib=Jb;Oc=((he((d[Ib]|d[Ib+1|0]<<8)<<16>>16|0)|0)&65535)<<N|Sb;Pc=N-16|0}else{Oc=Sb;Pc=N}}while(0);c[_a>>2]=Pc;N=((Mb*252|0)-252>>8)+1|0;Sb=N<<16;if(Oc>>>0<Sb>>>0){c[p>>2]=N;Qc=0;Rc=Oc;Sc=N}else{Qb=Mb-N|0;c[p>>2]=Qb;Qc=1;Rc=Oc-Sb|0;Sc=Qb}c[h>>2]=Rc;if(!Kb){break}if(Qc){Qb=7;Sb=0;N=Sc;e=Pc;Cb=Rc;while(1){Ib=Qb-1|0;Jb=Sb<<1;Eb=d[1252840+N|0]|0;Rb=N<<Eb;c[p>>2]=Rb;Gb=Cb<<Eb;Ab=Eb+e|0;do{if((Ab|0)>-1){Eb=c[ob>>2]|0;if(!(Eb>>>0<(c[pb>>2]|0)>>>0)){Tc=Gb;Uc=Ab;break}c[ob>>2]=Eb+2;Nb=Eb;Tc=((he((d[Nb]|d[Nb+1|0]<<8)<<16>>16|0)|0)&65535)<<Ab|Gb;Uc=Ab-16|0}else{Tc=Gb;Uc=Ab}}while(0);c[_a>>2]=Uc;Ab=((Rb<<7)-128>>8)+1|0;Gb=Ab<<16;Pb=Tc>>>0>=Gb>>>0;Nb=Pb?Rb-Ab|0:Ab;c[p>>2]=Nb;Ab=Tc-(Pb?Gb:0)|0;c[h>>2]=Ab;Vc=Pb&1|Jb;if((Ib|0)==0){break}else{Qb=Ib;Sb=Vc;N=Nb;e=Uc;Cb=Ab}}a[Hb+(Ob*33|0)+1+Kc|0]=Vc<<1|1}Kc=Kc+1|0}if(Qc){Cb=7;e=0;N=Sc;Sb=Pc;Qb=Rc;while(1){Kb=Cb-1|0;Mb=e<<1;Ab=d[1252840+N|0]|0;Nb=N<<Ab;c[p>>2]=Nb;Pb=Qb<<Ab;Gb=Ab+Sb|0;do{if((Gb|0)>-1){Ab=c[ob>>2]|0;if(!(Ab>>>0<(c[pb>>2]|0)>>>0)){Wc=Pb;Xc=Gb;break}c[ob>>2]=Ab+2;Eb=Ab;Wc=((he((d[Eb]|d[Eb+1|0]<<8)<<16>>16|0)|0)&65535)<<Gb|Pb;Xc=Gb-16|0}else{Wc=Pb;Xc=Gb}}while(0);c[_a>>2]=Xc;Gb=((Nb<<7)-128>>8)+1|0;Pb=Gb<<16;Eb=Wc>>>0>=Pb>>>0;Ab=Eb?Nb-Gb|0:Gb;c[p>>2]=Ab;Gb=Wc-(Eb?Pb:0)|0;c[h>>2]=Gb;Yc=Eb&1|Mb;if((Kb|0)==0){break}else{Cb=Kb;e=Yc;N=Ab;Sb=Xc;Qb=Gb}}a[Hb+(Ob*33|0)+11|0]=Yc<<1|1;Zc=0}else{Zc=0}do{Qb=c[p>>2]|0;Sb=d[1252840+Qb|0]|0;N=c[_a>>2]|0;e=c[h>>2]|0;Cb=Qb<<Sb;c[p>>2]=Cb;Qb=e<<Sb;e=N+Sb|0;do{if((e|0)>-1){Sb=c[ob>>2]|0;if(!(Sb>>>0<(c[pb>>2]|0)>>>0)){_c=Qb;$c=e;break}c[ob>>2]=Sb+2;N=Sb;_c=((he((d[N]|d[N+1|0]<<8)<<16>>16|0)|0)&65535)<<e|Qb;$c=e-16|0}else{_c=Qb;$c=e}}while(0);c[_a>>2]=$c;e=((Cb*252|0)-252>>8)+1|0;Qb=e<<16;if(_c>>>0<Qb>>>0){c[p>>2]=e;c[h>>2]=_c}else{Kb=Cb-e|0;c[p>>2]=Kb;e=_c-Qb|0;c[h>>2]=e;Qb=7;Mb=0;Nb=Kb;Kb=$c;N=e;while(1){e=Qb-1|0;Sb=Mb<<1;Gb=d[1252840+Nb|0]|0;Ab=Nb<<Gb;c[p>>2]=Ab;Eb=N<<Gb;Pb=Gb+Kb|0;do{if((Pb|0)>-1){Gb=c[ob>>2]|0;if(!(Gb>>>0<(c[pb>>2]|0)>>>0)){ad=Eb;bd=Pb;break}c[ob>>2]=Gb+2;o=Gb;ad=((he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<Pb|Eb;bd=Pb-16|0}else{ad=Eb;bd=Pb}}while(0);c[_a>>2]=bd;Pb=((Ab<<7)-128>>8)+1|0;Eb=Pb<<16;Ib=ad>>>0>=Eb>>>0;Jb=Ib?Ab-Pb|0:Pb;c[p>>2]=Jb;Pb=ad-(Ib?Eb:0)|0;c[h>>2]=Pb;cd=Ib&1|Sb;if((e|0)==0){break}else{Qb=e;Mb=cd;Nb=Jb;Kb=bd;N=Pb}}a[Hb+(Ob*33|0)+12+Zc|0]=cd<<1|1}Zc=Zc+1|0;}while((Zc|0)<10);N=Ob+1|0;if((N|0)<2){Ob=N}else{dd=0;break}}do{Ob=0;while(1){N=0;do{Kb=c[p>>2]|0;Nb=d[1252840+Kb|0]|0;Mb=c[_a>>2]|0;Qb=c[h>>2]|0;Cb=Kb<<Nb;c[p>>2]=Cb;Kb=Qb<<Nb;Qb=Mb+Nb|0;do{if((Qb|0)>-1){Nb=c[ob>>2]|0;if(!(Nb>>>0<(c[pb>>2]|0)>>>0)){ed=Kb;fd=Qb;break}c[ob>>2]=Nb+2;Mb=Nb;ed=((he((d[Mb]|d[Mb+1|0]<<8)<<16>>16|0)|0)&65535)<<Qb|Kb;fd=Qb-16|0}else{ed=Kb;fd=Qb}}while(0);c[_a>>2]=fd;Qb=((Cb*252|0)-252>>8)+1|0;Kb=Qb<<16;if(ed>>>0<Kb>>>0){c[p>>2]=Qb;c[h>>2]=ed}else{e=Cb-Qb|0;c[p>>2]=e;Qb=ed-Kb|0;c[h>>2]=Qb;Kb=7;Sb=0;Ab=e;e=fd;Mb=Qb;while(1){Qb=Kb-1|0;Nb=Sb<<1;Pb=d[1252840+Ab|0]|0;Jb=Ab<<Pb;c[p>>2]=Jb;Ib=Mb<<Pb;Eb=Pb+e|0;do{if((Eb|0)>-1){Pb=c[ob>>2]|0;if(!(Pb>>>0<(c[pb>>2]|0)>>>0)){gd=Ib;hd=Eb;break}c[ob>>2]=Pb+2;Rb=Pb;gd=((he((d[Rb]|d[Rb+1|0]<<8)<<16>>16|0)|0)&65535)<<Eb|Ib;hd=Eb-16|0}else{gd=Ib;hd=Eb}}while(0);c[_a>>2]=hd;Eb=((Jb<<7)-128>>8)+1|0;Ib=Eb<<16;Rb=gd>>>0>=Ib>>>0;Pb=Rb?Jb-Eb|0:Eb;c[p>>2]=Pb;Eb=gd-(Rb?Ib:0)|0;c[h>>2]=Eb;id=Rb&1|Nb;if((Qb|0)==0){break}else{Kb=Qb;Sb=id;Ab=Pb;e=hd;Mb=Eb}}a[Hb+(dd*33|0)+22+(Ob*3|0)+N|0]=id<<1|1}N=N+1|0;}while((N|0)<3);N=Ob+1|0;if((N|0)<2){Ob=N}else{jd=0;break}}do{Ob=c[p>>2]|0;N=d[1252840+Ob|0]|0;Mb=c[_a>>2]|0;e=c[h>>2]|0;Ab=Ob<<N;c[p>>2]=Ab;Ob=e<<N;e=Mb+N|0;do{if((e|0)>-1){N=c[ob>>2]|0;if(!(N>>>0<(c[pb>>2]|0)>>>0)){kd=Ob;ld=e;break}c[ob>>2]=N+2;Mb=N;kd=((he((d[Mb]|d[Mb+1|0]<<8)<<16>>16|0)|0)&65535)<<e|Ob;ld=e-16|0}else{kd=Ob;ld=e}}while(0);c[_a>>2]=ld;e=((Ab*252|0)-252>>8)+1|0;Ob=e<<16;if(kd>>>0<Ob>>>0){c[p>>2]=e;c[h>>2]=kd}else{Mb=Ab-e|0;c[p>>2]=Mb;e=kd-Ob|0;c[h>>2]=e;Ob=7;N=0;Sb=Mb;Mb=ld;Kb=e;while(1){e=Ob-1|0;Cb=N<<1;Eb=d[1252840+Sb|0]|0;Pb=Sb<<Eb;c[p>>2]=Pb;Rb=Kb<<Eb;Ib=Eb+Mb|0;do{if((Ib|0)>-1){Eb=c[ob>>2]|0;if(!(Eb>>>0<(c[pb>>2]|0)>>>0)){md=Rb;nd=Ib;break}c[ob>>2]=Eb+2;o=Eb;md=((he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535)<<Ib|Rb;nd=Ib-16|0}else{md=Rb;nd=Ib}}while(0);c[_a>>2]=nd;Ib=((Pb<<7)-128>>8)+1|0;Rb=Ib<<16;o=md>>>0>=Rb>>>0;Eb=o?Pb-Ib|0:Ib;c[p>>2]=Eb;Ib=md-(o?Rb:0)|0;c[h>>2]=Ib;od=o&1|Cb;if((e|0)==0){break}else{Ob=e;N=od;Sb=Eb;Mb=nd;Kb=Ib}}a[Hb+(dd*33|0)+28+jd|0]=od<<1|1}jd=jd+1|0;}while((jd|0)<3);dd=dd+1|0;}while((dd|0)<2);if((a[l+1147|0]|0)==0){break}else{pd=0}do{Kb=c[p>>2]|0;Mb=d[1252840+Kb|0]|0;Sb=c[_a>>2]|0;N=c[h>>2]|0;Ob=Kb<<Mb;c[p>>2]=Ob;Kb=N<<Mb;N=Sb+Mb|0;do{if((N|0)>-1){Mb=c[ob>>2]|0;if(!(Mb>>>0<(c[pb>>2]|0)>>>0)){qd=Kb;rd=N;break}c[ob>>2]=Mb+2;Sb=Mb;qd=((he((d[Sb]|d[Sb+1|0]<<8)<<16>>16|0)|0)&65535)<<N|Kb;rd=N-16|0}else{qd=Kb;rd=N}}while(0);c[_a>>2]=rd;N=((Ob*252|0)-252>>8)+1|0;Kb=N<<16;if(qd>>>0<Kb>>>0){c[p>>2]=N;c[h>>2]=qd;sd=N;td=rd;ud=qd}else{Sb=Ob-N|0;c[p>>2]=Sb;N=qd-Kb|0;c[h>>2]=N;Kb=7;Mb=0;Ab=Sb;Sb=rd;Ib=N;while(1){N=Kb-1|0;Eb=Mb<<1;o=d[1252840+Ab|0]|0;Rb=Ab<<o;c[p>>2]=Rb;Gb=Ib<<o;Lb=o+Sb|0;do{if((Lb|0)>-1){o=c[ob>>2]|0;if(!(o>>>0<(c[pb>>2]|0)>>>0)){vd=Gb;wd=Lb;break}c[ob>>2]=o+2;Db=o;vd=((he((d[Db]|d[Db+1|0]<<8)<<16>>16|0)|0)&65535)<<Lb|Gb;wd=Lb-16|0}else{vd=Gb;wd=Lb}}while(0);c[_a>>2]=wd;Lb=((Rb<<7)-128>>8)+1|0;Gb=Lb<<16;Db=vd>>>0>=Gb>>>0;o=Db?Rb-Lb|0:Lb;c[p>>2]=o;Lb=vd-(Db?Gb:0)|0;c[h>>2]=Lb;xd=Db&1|Eb;if((N|0)==0){break}else{Kb=N;Mb=xd;Ab=o;Sb=wd;Ib=Lb}}a[Hb+(pd*33|0)+31|0]=xd<<1|1;sd=c[p>>2]|0;td=c[_a>>2]|0;ud=c[h>>2]|0}Ib=d[1252840+sd|0]|0;Sb=sd<<Ib;c[p>>2]=Sb;Ab=ud<<Ib;Mb=td+Ib|0;do{if((Mb|0)>-1){Ib=c[ob>>2]|0;if(!(Ib>>>0<(c[pb>>2]|0)>>>0)){yd=Ab;zd=Mb;break}c[ob>>2]=Ib+2;Kb=Ib;yd=((he((d[Kb]|d[Kb+1|0]<<8)<<16>>16|0)|0)&65535)<<Mb|Ab;zd=Mb-16|0}else{yd=Ab;zd=Mb}}while(0);c[_a>>2]=zd;Mb=((Sb*252|0)-252>>8)+1|0;Ab=Mb<<16;if(yd>>>0<Ab>>>0){c[p>>2]=Mb;c[h>>2]=yd}else{Kb=Sb-Mb|0;c[p>>2]=Kb;Mb=yd-Ab|0;c[h>>2]=Mb;Ab=7;Ib=0;Ob=Kb;Kb=zd;Lb=Mb;while(1){Mb=Ab-1|0;o=Ib<<1;Db=d[1252840+Ob|0]|0;Gb=Ob<<Db;c[p>>2]=Gb;Fb=Lb<<Db;Bb=Db+Kb|0;do{if((Bb|0)>-1){Db=c[ob>>2]|0;if(!(Db>>>0<(c[pb>>2]|0)>>>0)){Ad=Fb;Bd=Bb;break}c[ob>>2]=Db+2;yb=Db;Ad=((he((d[yb]|d[yb+1|0]<<8)<<16>>16|0)|0)&65535)<<Bb|Fb;Bd=Bb-16|0}else{Ad=Fb;Bd=Bb}}while(0);c[_a>>2]=Bd;Bb=((Gb<<7)-128>>8)+1|0;Fb=Bb<<16;N=Ad>>>0>=Fb>>>0;Eb=N?Gb-Bb|0:Bb;c[p>>2]=Eb;Bb=Ad-(N?Fb:0)|0;c[h>>2]=Bb;Cd=N&1|o;if((Mb|0)==0){break}else{Ab=Mb;Ib=Cd;Ob=Eb;Kb=Bd;Lb=Bb}}a[Hb+(pd*33|0)+32|0]=Cd<<1|1}pd=pd+1|0;}while((pd|0)<2)}}while(0);t=bb+$a|0;i=j;return t|0}function vbb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;i=a+60|0;j=c[i>>2]|0;k=c[j+1084>>2]|0;l=k+60|0;m=c[l>>2]|0;a:do{if((h|0)==3){n=b;o=f;p=g;q=k;r=m;s=d}else{t=b;u=d;v=f;w=g;x=j;y=k;z=h;A=j;B=l;C=m;b:while(1){D=t;E=v;F=w;G=x;H=y;I=z;J=A;K=B;L=C;while(1){M=c[J+1360>>2]|0;N=4>>>(I>>>0);O=c[M+32>>2]|0;P=c[M+36>>2]|0;if((L|0)==(I|0)){Q=5;break b}R=I+1|0;vbb(a,D,u,e,E,F,R);S=N+u|0;T=N+D|0;U=T>>>0<(c[G+1804>>2]|0)>>>0;if(S>>>0<(c[G+1808>>2]|0)>>>0){break}if(!U){Q=15;break b}M=(ca(N<<3,O)|0)+E|0;V=(ca(N<<2,P)|0)+F|0;W=c[i>>2]|0;X=c[W+1084>>2]|0;Y=X+60|0;Z=c[Y>>2]|0;if((R|0)==3){n=T;o=M;p=V;q=X;r=Z;s=u;break a}else{D=T;E=M;F=V;G=W;H=X;I=R;J=W;K=Y;L=Z}}J=N<<3;I=N<<2;vbb(a,D,S,e,J+E|0,I+F|0,R);if(!U){Q=15;break}Z=(ca(O,J)|0)+E|0;Y=(ca(P,I)|0)+F|0;vbb(a,T,u,e,Z,Y,R);W=Z+J|0;J=Y+I|0;I=c[i>>2]|0;Y=c[I+1084>>2]|0;Z=Y+60|0;X=c[Z>>2]|0;if((R|0)==3){n=T;o=W;p=J;q=Y;r=X;s=S;break a}else{t=T;u=S;v=W;w=J;x=I;y=Y;z=R;A=I;B=Z;C=X}}if((Q|0)==5){C=H+64|0;xbb(a,D,u,e,E,F,L,c[C>>2]|0);B=c[C>>2]|0;if((B|0)==1){C=N+D|0;if(!(C>>>0<(c[G+1804>>2]|0)>>>0)){return}A=(ca(N<<3,O)|0)+E|0;z=(ca(N<<2,P)|0)+F|0;xbb(a,C,u,e,A,z,c[K>>2]|0,1);return}else if((B|0)==2){B=N+u|0;if(!(B>>>0<(c[G+1808>>2]|0)>>>0)){return}xbb(a,D,B,e,(N<<3)+E|0,(N<<2)+F|0,c[K>>2]|0,2);return}else{return}}else if((Q|0)==15){return}}}while(0);xbb(a,n,s,e,o,p,r,c[q+64>>2]|0);return}function wbb(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;l=i;m=c[b+60>>2]|0;n=3-k|0;o=(d[m+(e&7|30032)|0]|0)>>>(n>>>0)<<1&2|(d[(c[m+30096>>2]|0)+f|0]|0)>>>(n>>>0)&1;if((a[m+1137|0]|0)==0){p=m+10231|0}else{p=228256}n=4>>>(k>>>0);q=c[m+1360>>2]|0;r=c[q+32>>2]|0;s=c[q+36>>2]|0;if((k|0)==3){q=m+1052|0;t=m+1056|0;u=m+1068|0;v=m+1060|0;w=m+1064|0;x=0;y=c[q>>2]|0;z=c[t>>2]|0;A=c[u>>2]|0;while(1){B=a[p+36+(o*3|0)+x|0]|0;C=d[1252840+y|0]|0;D=y<<C;c[q>>2]=D;E=A<<C;F=C+z|0;do{if((F|0)>-1){C=c[v>>2]|0;if(!(C>>>0<(c[w>>2]|0)>>>0)){G=E;H=F;break}c[v>>2]=C+2;I=C;G=((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)<<F|E;H=F-16|0}else{G=E;H=F}}while(0);c[t>>2]=H;F=((ca(D-1|0,B&255)|0)>>8)+1|0;E=F<<16;I=G>>>0>=E>>>0;C=I?D-F|0:F;c[q>>2]=C;F=G-(I?E:0)|0;c[u>>2]=F;E=a[(I&1)+(207976+(x<<1))|0]|0;J=E<<24>>24;if(E<<24>>24>0){x=J;y=C;z=H;A=F}else{break}}A=-J|0;xbb(b,e,f,g,h,j,3,A);K=A;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}A=n+f|0;J=n+e|0;H=J>>>0<(c[m+1804>>2]|0)>>>0;if(!(A>>>0<(c[m+1808>>2]|0)>>>0)){if(!H){wbb(b,e,f,g,h,j,k+1|0);K=3;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}z=d[p+(k*12|0)+(o*3|0)+2|0]|0;y=m+1052|0;x=c[y>>2]|0;u=d[1252840+x|0]|0;G=m+1056|0;q=c[G>>2]|0;t=m+1068|0;v=c[t>>2]|0;w=x<<u;c[y>>2]=w;x=v<<u;v=q+u|0;do{if((v|0)>-1){u=m+1060|0;q=c[u>>2]|0;if(!(q>>>0<(c[m+1064>>2]|0)>>>0)){Q=x;R=v;break}c[u>>2]=q+2;u=q;Q=((he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535)<<v|x;R=v-16|0}else{Q=x;R=v}}while(0);c[G>>2]=R;R=((ca(w-1|0,z)|0)>>8)+1|0;z=R<<16;if(Q>>>0<z>>>0){c[y>>2]=R;c[t>>2]=Q;xbb(b,e,f,g,h,j,k,2);K=2;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else{c[y>>2]=w-R;c[t>>2]=Q-z;z=k+1|0;wbb(b,e,f,g,h,j,z);wbb(b,J,f,g,(ca(n<<3,r)|0)+h|0,(ca(n<<2,s)|0)+j|0,z);K=3;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}}z=m+1052|0;if(!H){H=d[p+(k*12|0)+(o*3|0)+1|0]|0;Q=z;t=c[Q>>2]|0;R=d[1252840+t|0]|0;w=m+1056|0;y=c[w>>2]|0;G=m+1068|0;v=c[G>>2]|0;x=t<<R;c[Q>>2]=x;t=v<<R;v=y+R|0;do{if((v|0)>-1){R=m+1060|0;y=c[R>>2]|0;if(!(y>>>0<(c[m+1064>>2]|0)>>>0)){S=t;T=v;break}c[R>>2]=y+2;R=y;S=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<v|t;T=v-16|0}else{S=t;T=v}}while(0);c[w>>2]=T;T=((ca(x-1|0,H)|0)>>8)+1|0;H=T<<16;if(S>>>0<H>>>0){c[Q>>2]=T;c[G>>2]=S;xbb(b,e,f,g,h,j,k,1);K=1;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else{c[Q>>2]=x-T;c[G>>2]=S-H;H=k+1|0;wbb(b,e,f,g,h,j,H);wbb(b,e,A,g,(n<<3)+h|0,(n<<2)+j|0,H);K=3;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}}H=z;z=m+1056|0;S=m+1068|0;G=m+1060|0;T=m+1064|0;x=0;Q=c[H>>2]|0;w=c[z>>2]|0;v=c[S>>2]|0;while(1){t=a[p+(k*12|0)+(o*3|0)+x|0]|0;R=d[1252840+Q|0]|0;y=Q<<R;c[H>>2]=y;u=v<<R;q=R+w|0;do{if((q|0)>-1){R=c[G>>2]|0;if(!(R>>>0<(c[T>>2]|0)>>>0)){U=u;V=q;break}c[G>>2]=R+2;F=R;U=((he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<q|u;V=q-16|0}else{U=u;V=q}}while(0);c[z>>2]=V;q=((ca(y-1|0,t&255)|0)>>8)+1|0;u=q<<16;D=U>>>0>=u>>>0;B=D?y-q|0:q;c[H>>2]=B;q=U-(D?u:0)|0;c[S>>2]=q;u=a[(D&1)+(207976+(x<<1))|0]|0;W=u<<24>>24;if(u<<24>>24>0){x=W;Q=B;w=V;v=q}else{break}}v=-W|0;if((v|0)==0){xbb(b,e,f,g,h,j,k,0);K=0;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else if((v|0)==1){xbb(b,e,f,g,h,j,k,1);xbb(b,J,f,g,(ca(n<<3,r)|0)+h|0,(ca(n<<2,s)|0)+j|0,k,1);K=1;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else if((v|0)==2){xbb(b,e,f,g,h,j,k,2);xbb(b,e,A,g,(n<<3)+h|0,(n<<2)+j|0,k,2);K=2;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else if((v|0)==3){v=k+1|0;wbb(b,e,f,g,h,j,v);W=n<<3;V=n<<2;wbb(b,e,A,g,W+h|0,V+j|0,v);e=(ca(r,W)|0)+h|0;h=(ca(s,V)|0)+j|0;wbb(b,J,f,g,e,h,v);wbb(b,J,A,g,e+W|0,h+V|0,v);K=3;L=m+18060|0;M=L;N=M+(k<<6)+(o<<4)+(K<<2)|0;O=c[N>>2]|0;P=O+1|0;c[N>>2]=P;i=l;return}else{KIb(0,0,2291568,(l=i,i=i+24|0,c[l>>2]=2240784,c[l+8>>2]=2199816,c[l+16>>2]=3131,l)|0);i=l;Hd()}}function xbb(f,g,h,j,k,l,m,n){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0;o=i;i=i+80|0;p=o|0;q=o+48|0;r=f+60|0;f=c[r>>2]|0;s=f+1084|0;t=c[s>>2]|0;u=(m*3|0)+n|0;v=d[1898778+(u<<1)|0]|0;w=d[1898779+(u<<1)|0]|0;x=c[f+1360>>2]|0;c[f+1100>>2]=g;y=f+1104|0;c[y>>2]=g&7;c[f+1108>>2]=h;z=f+1112|0;c[z>>2]=h&7;c[f+35908>>2]=-128-(h<<6);c[f+35912>>2]=-128-(g<<6);A=f+1808|0;B=v+h|0;c[f+35916>>2]=((c[A>>2]|0)-B<<6)+128;C=f+1804|0;D=w+g|0;c[f+35920>>2]=((c[C>>2]|0)-D<<6)+128;E=f+1088|0;do{if((c[E>>2]|0)<2){c[t+48>>2]=u;c[t+60>>2]=m;c[t+64>>2]=n;ybb(f);F=c[t+52>>2]|0;G=1<<F;if((v<<1|0)==(G|0)){H=1}else{H=(w<<1|0)==(G|0)|0}c[t+56>>2]=F-H;a:do{if((a[t+10|0]|0)==0){F=c[r>>2]|0;G=c[F+1084>>2]|0;I=c[F+1100>>2]|0;J=c[F+1108>>2]|0;K=G+1|0;L=(a[K]|0)==0|0;M=c[G+52>>2]|0;N=F+10279|0;O=N+(M*1584|0)+(L*396|0)|0;P=F+18316|0;Q=P+(M*1728|0)+(L*432|0)|0;R=F+25228|0;S=R+(M*1152|0)+(L*288|0)|0;L=G+48|0;T=c[L>>2]|0;U=a[1898778+(T<<1)|0]|0;V=U&255;W=V<<1;X=a[1898779+(T<<1)|0]|0;T=X&255;Y=T<<1;Z=(c[F+1808>>2]|0)-J<<1;_=Z>>>0>W>>>0?W:Z;$=(c[F+1804>>2]|0)-I<<1;aa=$>>>0>Y>>>0?Y:$;$=d[G|0]|0;ba=F+1554|0;da=ba+($*26|0)+10|0;ea=(d[F+1549|0]<<2)+M|0;fa=G+56|0;ga=c[fa>>2]|0;ha=c[204408+(ga<<4)>>2]|0;ia=c[204328+(ga<<4)>>2]|0;ja=J<<1;ka=c[F+30104>>2]|0;la=I&7;I=la<<1|29856;ma=1585248+(M<<4)|0;na=1585248+(ga<<4)|0;do{if((M|0)==2){ga=(aa|0)>0;if(ga){oa=0;do{pa=F+(oa+I)|0;a[pa]=(c[pa>>2]|0)!=0|0;oa=oa+4|0;}while((oa|0)<(aa|0))}oa=(_|0)>0;if(oa){pa=0;do{qa=ka+(pa+ja)|0;a[qa]=(c[qa>>2]|0)!=0|0;pa=pa+4|0;}while((pa|0)<(_|0))}if(ga){pa=G+5|0;qa=F+1052|0;ra=F+35864|0;sa=da|0;ta=F+35896|0;ua=0;va=0;while(1){if(oa){wa=F+(ua+I)|0;xa=0;ya=va;while(1){za=c[215400+(d[pa]<<2)>>2]|0;Aa=ka+(xa+ja)|0;Ba=zbb(qa,(c[ra>>2]|0)+(ya<<4<<1)|0,256,Q,S,O,(d[wa]|0)+(d[Aa]|0)|0,c[204408+(ea<<4)+(za<<2)>>2]|0,c[204328+(ea<<4)+(za<<2)>>2]|0,ma,sa)|0;za=(Ba|0)!=0|0;a[wa]=za;a[Aa]=za;b[(c[ta>>2]|0)+ya>>1]=Ba;Ba=xa+4|0;za=ya+16|0;if((Ba|0)<(_|0)){xa=Ba;ya=za}else{Ca=za;break}}}else{Ca=va}ya=ua+4|0;if((ya|0)<(aa|0)){ua=ya;va=Ca}else{break}}}do{if((_|0)==(W|0)){if(U<<24>>24==0){break}else{Da=0}do{va=ka+(Da+ja)|0;c[va>>2]=ca(d[va]|0,16843009)|0;Da=Da+4|0;}while((Da|0)<(W|0))}else{if(oa){Ea=0}else{break}do{va=_-Ea-1|0;mrc(ka+((Ea|1)+ja)|0,a[ka+(Ea+ja)|0]|0,((va|0)>3?3:va)|0)|0;Ea=Ea+4|0;}while((Ea|0)<(_|0))}}while(0);if((aa|0)==(Y|0)){if(X<<24>>24==0){break}else{Fa=0}do{oa=F+(Fa+I)|0;c[oa>>2]=ca(d[oa]|0,16843009)|0;Fa=Fa+4|0;}while((Fa|0)<(Y|0))}else{if(ga){Ga=0}else{break}do{oa=aa-Ga-1|0;mrc(F+((Ga|1)+I)|0,a[F+(Ga+I)|0]|0,((oa|0)>3?3:oa)|0)|0;Ga=Ga+4|0;}while((Ga|0)<(aa|0))}}else if((M|0)==0){if((aa|0)<=0){break}ga=(_|0)>0;oa=F+1052|0;va=F+35864|0;ua=da|0;ta=F+35896|0;sa=~Z;ra=~W;qa=~(sa>>>0>ra>>>0?sa:ra);ra=0;sa=0;while(1){if(ga){pa=F+(ra+I)|0;ya=0;xa=sa;while(1){wa=c[215400+(d[((c[L>>2]|0)>>>0>9>>>0?xa:0)+(G+5)|0]<<2)>>2]|0;za=ka+(ya+ja)|0;Ba=zbb(oa,(c[va>>2]|0)+(xa<<4<<1)|0,16,Q,S,O,(d[pa]|0)+(d[za]|0)|0,c[204408+(ea<<4)+(wa<<2)>>2]|0,c[204328+(ea<<4)+(wa<<2)>>2]|0,ma,ua)|0;wa=(Ba|0)!=0|0;a[pa]=wa;a[za]=wa;a[(c[ta>>2]|0)+xa|0]=Ba;Ba=ya+1|0;if((Ba|0)>=(_|0)){break}ya=Ba;xa=xa+1|0}Ha=sa+qa|0}else{Ha=sa}xa=ra+1|0;if((xa|0)<(aa|0)){ra=xa;sa=Ha}else{break}}}else if((M|0)==3){sa=(aa|0)>0;if(sa){ra=0;do{qa=F+(ra+I)|0;ta=qa;a[qa]=((c[ta>>2]|0)!=0|(c[ta+4>>2]|0)!=0)&1;ra=ra+8|0;}while((ra|0)<(aa|0))}ra=(_|0)>0;if(ra){ta=0;do{qa=ka+(ta+ja)|0;ua=qa;a[qa]=((c[ua>>2]|0)!=0|(c[ua+4>>2]|0)!=0)&1;ta=ta+8|0;}while((ta|0)<(_|0))}if(sa){ta=G+5|0;ua=F+1052|0;qa=F+35864|0;va=da|0;oa=F+35896|0;ga=0;xa=0;while(1){if(ra){ya=F+(ga+I)|0;pa=0;Ba=xa;while(1){wa=c[215400+(d[ta]<<2)>>2]|0;za=ka+(pa+ja)|0;Aa=Abb(ua,(c[qa>>2]|0)+(Ba<<4<<1)|0,Q,S,O,(d[ya]|0)+(d[za]|0)|0,c[204408+(ea<<4)+(wa<<2)>>2]|0,c[204328+(ea<<4)+(wa<<2)>>2]|0,ma,va)|0;wa=(Aa|0)!=0|0;a[ya]=wa;a[za]=wa;b[(c[oa>>2]|0)+Ba>>1]=Aa;Aa=pa+8|0;wa=Ba+64|0;if((Aa|0)<(_|0)){pa=Aa;Ba=wa}else{Ia=wa;break}}}else{Ia=xa}Ba=ga+8|0;if((Ba|0)<(aa|0)){ga=Ba;xa=Ia}else{break}}}do{if((_|0)==(W|0)){if(U<<24>>24==0){break}else{Ja=0}do{xa=ka+(Ja+ja)|0;ga=ca(d[xa]|0,16843009)|0;c[xa>>2]=ga;c[ka+((Ja|4)+ja)>>2]=ga;Ja=Ja+8|0;}while((Ja|0)<(W|0))}else{if(ra){Ka=0}else{break}do{ga=_-Ka-1|0;mrc(ka+((Ka|1)+ja)|0,a[ka+(Ka+ja)|0]|0,((ga|0)>7?7:ga)|0)|0;Ka=Ka+8|0;}while((Ka|0)<(_|0))}}while(0);if((aa|0)==(Y|0)){if(X<<24>>24==0){break}else{La=0}do{ra=F+(La+I)|0;ga=ca(d[ra]|0,16843009)|0;c[ra>>2]=ga;c[F+((La|4)+I)>>2]=ga;La=La+8|0;}while((La|0)<(Y|0))}else{if(sa){Ma=0}else{break}do{ga=aa-Ma-1|0;mrc(F+((Ma|1)+I)|0,a[F+(Ma+I)|0]|0,((ga|0)>7?7:ga)|0)|0;Ma=Ma+8|0;}while((Ma|0)<(aa|0))}}else if((M|0)==1){sa=(aa|0)>0;if(sa){ga=0;do{ra=F+(ga+I)|0;a[ra]=(b[ra>>1]|0)!=0|0;ga=ga+2|0;}while((ga|0)<(aa|0))}ga=(_|0)>0;if(ga){ra=0;do{xa=ka+(ra+ja)|0;a[xa]=(b[xa>>1]|0)!=0|0;ra=ra+2|0;}while((ra|0)<(_|0))}if(sa){ra=G+5|0;xa=F+1052|0;oa=F+35864|0;va=da|0;qa=F+35896|0;ua=0;ta=0;while(1){if(ga){Ba=F+(ua+I)|0;pa=0;ya=ta;while(1){wa=c[215400+(d[ra]<<2)>>2]|0;Aa=ka+(pa+ja)|0;za=zbb(xa,(c[oa>>2]|0)+(ya<<4<<1)|0,64,Q,S,O,(d[Ba]|0)+(d[Aa]|0)|0,c[204408+(ea<<4)+(wa<<2)>>2]|0,c[204328+(ea<<4)+(wa<<2)>>2]|0,ma,va)|0;wa=(za|0)!=0|0;a[Ba]=wa;a[Aa]=wa;a[(c[qa>>2]|0)+ya|0]=za;za=pa+2|0;wa=ya+4|0;if((za|0)<(_|0)){pa=za;ya=wa}else{Na=wa;break}}}else{Na=ta}ya=ua+2|0;if((ya|0)<(aa|0)){ua=ya;ta=Na}else{break}}}if((_|0)>1){ta=ja-1|0;ua=1;do{a[ka+(ua+ja)|0]=a[ka+(ta+ua)|0]|0;ua=ua+2|0;}while((ua|0)<(_|0))}if((aa|0)<=1){break}ua=I-1|0;ta=1;do{a[F+(ta+I)|0]=a[F+(ua+ta)|0]|0;ta=ta+2|0;}while((ta|0)<(aa|0))}}while(0);I=(a[K]|0)==0|0;ka=c[fa>>2]|0;ja=N+(ka*1584|0)+792+(I*396|0)|0;ma=P+(ka*1728|0)+864+(I*432|0)|0;ea=R+(ka*1152|0)+576+(I*288|0)|0;I=_>>1;O=aa>>1;S=F+30108|0;Q=F+30016|0;da=(aa|0)>0;G=(_|0)>0;M=F+1052|0;Y=F+35876|0;X=ba+($*26|0)+14|0;W=F+35900|0;U=(I|0)==(V|0);L=(O|0)==(T|0);Z=(_|0)>2;ta=(aa|0)>2;ua=la-1|0;qa=J-1|0;va=(_|0)>8?((I+1073741823|0)>>>2<<4)+16|0:16;oa=(_|0)>4?((I+2147483647|0)>>>1<<2)+4|0:4;xa=(I|0)>1?I:1;ra=0;ga=ka;while(1){ka=c[S+(ra<<2)>>2]|0;sa=ka+J|0;ya=Q+(ra<<3)+la|0;do{if((ga|0)==0){if(!da){break}pa=Y+(ra<<2)|0;Ba=W+(ra<<2)|0;wa=0;za=0;while(1){if(G){Aa=wa+la+(Q+(ra<<3))|0;Oa=0;Pa=za;while(1){Qa=ka+(Oa+J)|0;Ra=zbb(M,(c[pa>>2]|0)+(Pa<<4<<1)|0,16,ma,ea,ja,(d[Aa]|0)+(d[Qa]|0)|0,ha,ia,na,X)|0;Sa=(Ra|0)!=0|0;a[Aa]=Sa;a[Qa]=Sa;a[(c[Ba>>2]|0)+Pa|0]=Ra;Ra=Oa+1|0;if((Ra|0)<(I|0)){Oa=Ra;Pa=Pa+1|0}else{break}}Ta=za+xa|0}else{Ta=za}Pa=wa+1|0;if((Pa|0)<(O|0)){wa=Pa;za=Ta}else{break}}}else if((ga|0)==1){if(da){za=0;do{wa=za+la+(Q+(ra<<3))|0;a[wa]=(b[wa>>1]|0)!=0|0;za=za+2|0;}while((za|0)<(O|0))}if(G){za=0;do{wa=ka+(za+J)|0;a[wa]=(b[wa>>1]|0)!=0|0;za=za+2|0;}while((za|0)<(I|0))}if(da){za=Y+(ra<<2)|0;wa=W+(ra<<2)|0;Ba=0;pa=0;while(1){if(G){Pa=Ba+la+(Q+(ra<<3))|0;Oa=0;Aa=pa;while(1){Ra=ka+(Oa+J)|0;Sa=zbb(M,(c[za>>2]|0)+(Aa<<4<<1)|0,64,ma,ea,ja,(d[Pa]|0)+(d[Ra]|0)|0,ha,ia,na,X)|0;Qa=(Sa|0)!=0|0;a[Pa]=Qa;a[Ra]=Qa;a[(c[wa>>2]|0)+Aa|0]=Sa;Sa=Oa+2|0;if((Sa|0)<(I|0)){Oa=Sa;Aa=Aa+4|0}else{break}}Ua=pa+oa|0}else{Ua=pa}Aa=Ba+2|0;if((Aa|0)<(O|0)){Ba=Aa;pa=Ua}else{break}}}if(Z){pa=1;do{a[ka+(pa+J)|0]=a[ka+(qa+pa)|0]|0;pa=pa+2|0;}while((pa|0)<(I|0))}if(ta){Va=1}else{break}do{a[Va+la+(Q+(ra<<3))|0]=a[ua+Va+(Q+(ra<<3))|0]|0;Va=Va+2|0;}while((Va|0)<(O|0))}else if((ga|0)==2){if(da){pa=0;do{Ba=pa+la+(Q+(ra<<3))|0;a[Ba]=(c[Ba>>2]|0)!=0|0;pa=pa+4|0;}while((pa|0)<(O|0))}if(G){pa=0;do{Ba=ka+(pa+J)|0;a[Ba]=(c[Ba>>2]|0)!=0|0;pa=pa+4|0;}while((pa|0)<(I|0))}if(da){pa=Y+(ra<<2)|0;Ba=W+(ra<<2)|0;wa=0;za=0;while(1){if(G){Aa=wa+la+(Q+(ra<<3))|0;Oa=0;Pa=za;while(1){Sa=ka+(Oa+J)|0;Qa=zbb(M,(c[pa>>2]|0)+(Pa<<4<<1)|0,256,ma,ea,ja,(d[Aa]|0)+(d[Sa]|0)|0,ha,ia,na,X)|0;Ra=(Qa|0)!=0|0;a[Aa]=Ra;a[Sa]=Ra;a[(c[Ba>>2]|0)+Pa|0]=Qa;Qa=Oa+4|0;if((Qa|0)<(I|0)){Oa=Qa;Pa=Pa+16|0}else{break}}Wa=za+va|0}else{Wa=za}Pa=wa+4|0;if((Pa|0)<(O|0)){wa=Pa;za=Wa}else{break}}}do{if(U){if(G){Xa=0}else{break}do{za=ka+(Xa+J)|0;c[za>>2]=ca(d[za]|0,16843009)|0;Xa=Xa+4|0;}while((Xa|0)<(V|0))}else{if(G){Ya=0}else{break}do{za=I-Ya-1|0;mrc(ka+((Ya|1)+J)|0,a[ka+(Ya+J)|0]|0,((za|0)>3?3:za)|0)|0;Ya=Ya+4|0;}while((Ya|0)<(I|0))}}while(0);if(L){if(da){Za=0}else{break}do{za=Za+la+(Q+(ra<<3))|0;c[za>>2]=ca(d[za]|0,16843009)|0;Za=Za+4|0;}while((Za|0)<(T|0))}else{if(da){_a=0}else{break}do{za=O-_a-1|0;mrc((_a|1)+la+(Q+(ra<<3))|0,a[_a+la+(Q+(ra<<3))|0]|0,((za|0)>3?3:za)|0)|0;_a=_a+4|0;}while((_a|0)<(O|0))}}else if((ga|0)==3){if(da){za=0;do{wa=(za|la)+(Q+(ra<<3))|0;Ba=wa;a[wa]=((c[Ba>>2]|0)!=0|(c[Ba+4>>2]|0)!=0)&1;za=za+8|0;}while((za|0)<(O|0))}if(G){za=0;do{Ba=ka+(za+J)|0;wa=Ba;a[Ba]=((c[wa>>2]|0)!=0|(c[wa+4>>2]|0)!=0)&1;za=za+8|0;}while((za|0)<(I|0))}za=Abb(M,c[Y+(ra<<2)>>2]|0,ma,ea,ja,(d[ya]|0)+(d[sa]|0)|0,ha,ia,na,X)|0;wa=(za|0)!=0|0;a[ya]=wa;a[sa]=wa;b[c[W+(ra<<2)>>2]>>1]=za;do{if(U){if(G){$a=0}else{break}do{za=ka+($a+J)|0;wa=ca(d[za]|0,16843009)|0;c[za>>2]=wa;c[ka+(($a|4)+J)>>2]=wa;$a=$a+8|0;}while(($a|0)<(V|0))}else{if(G){ab=0}else{break}do{wa=I-ab-1|0;mrc(ka+((ab|1)+J)|0,a[ka+(ab+J)|0]|0,((wa|0)>7?7:wa)|0)|0;ab=ab+8|0;}while((ab|0)<(I|0))}}while(0);if(L){if(da){bb=0}else{break}do{wa=(bb|la)+(Q+(ra<<3))|0;za=ca(d[wa]|0,16843009)|0;c[wa>>2]=za;c[(bb|4)+la+(Q+(ra<<3))>>2]=za;bb=bb+8|0;}while((bb|0)<(T|0))}else{if(da){cb=0}else{break}do{za=O-cb-1|0;mrc((cb|1)+la+(Q+(ra<<3))|0,a[(cb|la)+(Q+(ra<<3))|0]|0,((za|0)>7?7:za)|0)|0;cb=cb+8|0;}while((cb|0)<(O|0))}}}while(0);ka=ra+1|0;if((ka|0)>=2){break a}ra=ka;ga=c[fa>>2]|0}}else{fa=c[y>>2]|0;if((v|0)==1){b[(c[f+30104>>2]|0)+(h<<1)>>1]=0;a[(c[f+30108>>2]|0)+h|0]=0;a[(c[f+30112>>2]|0)+h|0]=0}else if((v|0)==2){c[(c[f+30104>>2]|0)+(h<<1)>>2]=0;b[(c[f+30108>>2]|0)+h>>1]=0;b[(c[f+30112>>2]|0)+h>>1]=0}else if((v|0)==4){ga=(c[f+30104>>2]|0)+(h<<1)|0;c[ga>>2]=0;c[ga+4>>2]=0;c[(c[f+30108>>2]|0)+h>>2]=0;c[(c[f+30112>>2]|0)+h>>2]=0}else if((v|0)==8){ga=h<<1;ra=f+30104|0;O=(c[ra>>2]|0)+ga|0;c[O>>2]=0;c[O+4>>2]=0;O=(c[ra>>2]|0)+(ga+8)|0;c[O>>2]=0;c[O+4>>2]=0;O=(c[f+30108>>2]|0)+h|0;c[O>>2]=0;c[O+4>>2]=0;O=(c[f+30112>>2]|0)+h|0;c[O>>2]=0;c[O+4>>2]=0}if((w|0)==8){O=fa<<1;ga=f+(O+29856)|0;c[ga>>2]=0;c[ga+4>>2]=0;ga=f+(O+29864)|0;c[ga>>2]=0;c[ga+4>>2]=0;ga=f+(fa+30016)|0;c[ga>>2]=0;c[ga+4>>2]=0;ga=f+(fa+30024)|0;c[ga>>2]=0;c[ga+4>>2]=0;break}else if((w|0)==1){b[f+((fa<<1)+29856)>>1]=0;a[f+(fa+30016)|0]=0;a[f+(fa+30024)|0]=0;break}else if((w|0)==2){c[f+((fa<<1)+29856)>>2]=0;b[f+(fa+30016)>>1]=0;b[f+(fa+30024)>>1]=0;break}else if((w|0)==4){ga=f+((fa<<1)+29856)|0;c[ga>>2]=0;c[ga+4>>2]=0;c[f+(fa+30016)>>2]=0;c[f+(fa+30024)>>2]=0;break}else{break}}}while(0);if((c[E>>2]|0)!=1){break}c[s>>2]=(c[s>>2]|0)+68;fa=ca(w,v)|0;ga=f+35864|0;c[ga>>2]=(c[ga>>2]|0)+(fa<<6<<1);ga=fa<<4;O=f+35876|0;c[O>>2]=(c[O>>2]|0)+(ga<<1);O=f+35880|0;c[O>>2]=(c[O>>2]|0)+(ga<<1);ga=ca(v<<2,w)|0;O=f+35896|0;c[O>>2]=(c[O>>2]|0)+ga;ga=f+35900|0;c[ga>>2]=(c[ga>>2]|0)+fa;ga=f+35904|0;c[ga>>2]=(c[ga>>2]|0)+fa;i=o;return}}while(0);cb=x+32|0;bb=c[cb>>2]|0;if((B<<3|0)>(bb|0)){db=1}else{db=D>>>0>(c[C>>2]|0)>>>0}ab=x+36|0;if((B<<2|0)>(c[ab>>2]|0)){eb=1}else{eb=D>>>0>(c[C>>2]|0)>>>0}if(db){c[f+1116>>2]=f+35936;c[f+1128>>2]=64}else{c[f+1116>>2]=(c[x>>2]|0)+k;c[f+1128>>2]=bb}if(eb){c[f+1120>>2]=f+40032;c[f+1124>>2]=f+41056;c[f+1132>>2]=32}else{c[f+1120>>2]=(c[x+4>>2]|0)+l;c[f+1124>>2]=(c[x+8>>2]|0)+l;c[f+1132>>2]=c[ab>>2]}bb=t+1|0;$a=c[r>>2]|0;do{if((a[bb]|0)==0){r=$a;_a=c[$a+1084>>2]|0;Za=c[$a+1100>>2]|0;Ya=c[$a+1108>>2]|0;Xa=$a+1168|0;Wa=Xa+((d[$a+((d[_a+3|0]|0)+1157)|0]|0)*12|0)|0;Va=c[Wa>>2]|0;Ua=c[Va+68>>2]|0;Ta=c[Va+72>>2]|0;Na=$a+1128|0;Ma=c[Na>>2]|0;La=$a+1132|0;Ka=c[La>>2]|0;Ja=_a+2|0;if((a[Ja]|0)==0){fb=0;gb=0;hb=0;ib=0}else{Ia=Xa+((d[$a+((d[_a+4|0]|0)+1157)|0]|0)*12|0)|0;Xa=c[Ia>>2]|0;fb=Ia;gb=Xa;hb=c[Xa+68>>2]|0;ib=c[Xa+72>>2]|0}Xa=_a+48|0;Ia=c[Xa>>2]|0;do{if(Ia>>>0>9>>>0){if((Ia|0)==10){Ha=_a+12|0;Ga=c[Ha>>2]|0;Fa=$a+768|0;Ea=$a+1116|0;Da=c[Ea>>2]|0;Ca=Va|0;H=c[Ca>>2]|0;n=Va+32|0;m=c[n>>2]|0;u=Za<<3;fa=Ya<<3;ga=b[_a+16>>1]|0;O=b[_a+18>>1]|0;ra=(O>>3)+u|0;Q=(ga>>3)+fa|0;la=(ca(ra,m)|0)+Q|0;da=H+la|0;T=ga&7;ga=O&7;O=(ga|0)!=0|0;L=O<<2;I=ra+11+L>>6;M5a(Wa,(I|0)>0?I:0,0);I=(T|0)!=0|0;J=-I|0;G=J&3;V=-O|0;U=V&3;do{if((Q|0)<(G|0)|(ra|0)<(U|0)){jb=288}else{if(((I<<2)+Q|0)>(Ua-8|0)){jb=288;break}if((L+ra|0)>(Ta-4|0)){jb=288}else{kb=da;lb=m}}}while(0);if((jb|0)==288){da=H+(la-G-(ca(U,m)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,da,80,m,J&7|8,(V&7)+4|0,Q-G|0,ra-U|0,Ua,Ta);kb=(U*80|0|G)+(r+30176)|0;lb=80}Se[c[Fa+(Ga<<5)+(I<<3)+(O<<2)>>2]&1023](Da,Ma,kb,lb,4,T<<1,ga<<1);da=c[Ha>>2]|0;L=Ma<<2;W=(c[Ea>>2]|0)+L|0;X=c[Ca>>2]|0;na=c[n>>2]|0;ia=u|4;ha=b[_a+32>>1]|0;ja=b[_a+34>>1]|0;ea=(ja>>3)+ia|0;ma=(ha>>3)+fa|0;Y=(ca(ea,na)|0)+ma|0;M=X+Y|0;va=ha&7;ha=ja&7;ja=(ha|0)!=0|0;ua=ja<<2;ta=ea+11+ua>>6;M5a(Wa,(ta|0)>0?ta:0,0);ta=(va|0)!=0|0;qa=-ta|0;Z=qa&3;oa=-ja|0;xa=oa&3;do{if((ma|0)<(Z|0)|(ea|0)<(xa|0)){jb=292}else{if(((ta<<2)+ma|0)>(Ua-8|0)){jb=292;break}if((ua+ea|0)>(Ta-4|0)){jb=292}else{mb=M;nb=na}}}while(0);if((jb|0)==292){M=X+(Y-Z-(ca(xa,na)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,M,80,na,qa&7|8,(oa&7)+4|0,ma-Z|0,ea-xa|0,Ua,Ta);mb=(xa*80|0|Z)+(r+30176)|0;nb=80}Se[c[Fa+(da<<5)+(ta<<3)+(ja<<2)>>2]&1023](W,Ma,mb,nb,4,va<<1,ha<<1);if((a[Ja]|0)==0){break}M=c[Ha>>2]|0;ua=c[Ea>>2]|0;n=gb|0;Ca=c[n>>2]|0;ga=gb+32|0;T=c[ga>>2]|0;Da=b[_a+20>>1]|0;O=b[_a+22>>1]|0;I=(O>>3)+u|0;Ga=(Da>>3)+fa|0;G=(ca(I,T)|0)+Ga|0;U=Ca+G|0;ra=Da&7;Da=O&7;O=(Da|0)!=0|0;Q=O<<2;V=I+11+Q>>6;M5a(fb,(V|0)>0?V:0,0);V=(ra|0)!=0|0;J=-V|0;m=J&3;la=-O|0;H=la&3;do{if((Ga|0)<(m|0)|(I|0)<(H|0)){jb=297}else{if(((V<<2)+Ga|0)>(hb-8|0)){jb=297;break}if((Q+I|0)>(ib-4|0)){jb=297}else{ob=U;pb=T}}}while(0);if((jb|0)==297){U=Ca+(G-m-(ca(H,T)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,U,80,T,J&7|8,(la&7)+4|0,Ga-m|0,I-H|0,hb,ib);ob=(H*80|0|m)+(r+30176)|0;pb=80}Se[c[Fa+(M<<5)+16+(V<<3)+(O<<2)>>2]&1023](ua,Ma,ob,pb,4,ra<<1,Da<<1);U=c[Ha>>2]|0;Q=(c[Ea>>2]|0)+L|0;u=c[n>>2]|0;ha=c[ga>>2]|0;va=b[_a+36>>1]|0;W=b[_a+38>>1]|0;ja=(W>>3)+ia|0;ta=(va>>3)+fa|0;da=(ca(ja,ha)|0)+ta|0;Z=u+da|0;xa=va&7;va=W&7;W=(va|0)!=0|0;ea=W<<2;ma=ja+11+ea>>6;M5a(fb,(ma|0)>0?ma:0,0);ma=(xa|0)!=0|0;oa=-ma|0;qa=oa&3;na=-W|0;Y=na&3;do{if((ta|0)<(qa|0)|(ja|0)<(Y|0)){jb=301}else{if(((ma<<2)+ta|0)>(hb-8|0)){jb=301;break}if((ea+ja|0)>(ib-4|0)){jb=301}else{qb=Z;rb=ha}}}while(0);if((jb|0)==301){Z=u+(da-qa-(ca(Y,ha)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,Z,80,ha,oa&7|8,(na&7)+4|0,ta-qa|0,ja-Y|0,hb,ib);qb=(Y*80|0|qa)+(r+30176)|0;rb=80}Se[c[Fa+(U<<5)+16+(ma<<3)+(W<<2)>>2]&1023](Q,Ma,qb,rb,4,xa<<1,va<<1);break}Z=_a+12|0;ea=c[Z>>2]|0;fa=$a+896|0;ia=$a+1116|0;ga=c[ia>>2]|0;n=Va|0;L=c[n>>2]|0;Ea=Va+32|0;Ha=c[Ea>>2]|0;Da=Za<<3;ra=Ya<<3;ua=b[_a+16>>1]|0;O=b[_a+18>>1]|0;V=(O>>3)+Da|0;M=(ua>>3)+ra|0;m=(ca(V,Ha)|0)+M|0;H=L+m|0;I=ua&7;ua=O&7;O=(ua|0)!=0|0;Ga=O<<2;if((Ia|0)==11){la=V+15+Ga>>6;M5a(Wa,(la|0)>0?la:0,0);la=(I|0)!=0|0;J=-la|0;T=J&3;G=-O|0;Ca=G&3;do{if((M|0)<(T|0)|(V|0)<(Ca|0)){jb=307}else{if(((la<<2)+M|0)>(Ua-4|0)){jb=307;break}if((Ga+V|0)>(Ta-8|0)){jb=307}else{sb=H;tb=Ha}}}while(0);if((jb|0)==307){va=L+(m-T-(ca(Ca,Ha)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,va,80,Ha,(J&7)+4|0,G&7|8,M-T|0,V-Ca|0,Ua,Ta);sb=(Ca*80|0|T)+(r+30176)|0;tb=80}Se[c[fa+(ea<<5)+(la<<3)+(O<<2)>>2]&1023](ga,Ma,sb,tb,8,I<<1,ua<<1);va=c[Z>>2]|0;xa=(c[ia>>2]|0)+4|0;Q=c[n>>2]|0;W=c[Ea>>2]|0;ma=ra|4;U=b[_a+24>>1]|0;Fa=b[_a+26>>1]|0;qa=(Fa>>3)+Da|0;Y=(U>>3)+ma|0;ja=(ca(qa,W)|0)+Y|0;ta=Q+ja|0;na=U&7;U=Fa&7;Fa=(U|0)!=0|0;oa=Fa<<2;ha=qa+15+oa>>6;M5a(Wa,(ha|0)>0?ha:0,0);ha=(na|0)!=0|0;da=-ha|0;u=da&3;X=-Fa|0;S=X&3;do{if((Y|0)<(u|0)|(qa|0)<(S|0)){jb=311}else{if(((ha<<2)+Y|0)>(Ua-4|0)){jb=311;break}if((oa+qa|0)>(Ta-8|0)){jb=311}else{ub=ta;vb=W}}}while(0);if((jb|0)==311){ta=Q+(ja-u-(ca(S,W)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,ta,80,W,(da&7)+4|0,X&7|8,Y-u|0,qa-S|0,Ua,Ta);ub=(S*80|0|u)+(r+30176)|0;vb=80}Se[c[fa+(va<<5)+(ha<<3)+(Fa<<2)>>2]&1023](xa,Ma,ub,vb,8,na<<1,U<<1);if((a[Ja]|0)==0){break}ta=c[Z>>2]|0;oa=c[ia>>2]|0;la=gb|0;T=c[la>>2]|0;Ca=gb+32|0;G=c[Ca>>2]|0;J=b[_a+20>>1]|0;_=b[_a+22>>1]|0;aa=(_>>3)+Da|0;F=(J>>3)+ra|0;$=(ca(aa,G)|0)+F|0;ba=T+$|0;R=J&7;J=_&7;_=(J|0)!=0|0;P=_<<2;N=aa+15+P>>6;M5a(fb,(N|0)>0?N:0,0);N=(R|0)!=0|0;K=-N|0;ka=K&3;sa=-_|0;ya=sa&3;do{if((F|0)<(ka|0)|(aa|0)<(ya|0)){jb=316}else{if(((N<<2)+F|0)>(hb-4|0)){jb=316;break}if((P+aa|0)>(ib-8|0)){jb=316}else{wb=ba;xb=G}}}while(0);if((jb|0)==316){ba=T+($-ka-(ca(ya,G)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,ba,80,G,(K&7)+4|0,sa&7|8,F-ka|0,aa-ya|0,hb,ib);wb=(ya*80|0|ka)+(r+30176)|0;xb=80}Se[c[fa+(ta<<5)+16+(N<<3)+(_<<2)>>2]&1023](oa,Ma,wb,xb,8,R<<1,J<<1);ba=c[Z>>2]|0;P=(c[ia>>2]|0)+4|0;U=c[la>>2]|0;na=c[Ca>>2]|0;xa=b[_a+28>>1]|0;Fa=b[_a+30>>1]|0;ha=(Fa>>3)+Da|0;va=(xa>>3)+ma|0;u=(ca(ha,na)|0)+va|0;S=U+u|0;qa=xa&7;xa=Fa&7;Fa=(xa|0)!=0|0;Y=Fa<<2;X=ha+15+Y>>6;M5a(fb,(X|0)>0?X:0,0);X=(qa|0)!=0|0;da=-X|0;W=da&3;ja=-Fa|0;Q=ja&3;do{if((va|0)<(W|0)|(ha|0)<(Q|0)){jb=320}else{if(((X<<2)+va|0)>(hb-4|0)){jb=320;break}if((Y+ha|0)>(ib-8|0)){jb=320}else{yb=S;zb=na}}}while(0);if((jb|0)==320){S=U+(u-W-(ca(Q,na)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,S,80,na,(da&7)+4|0,ja&7|8,va-W|0,ha-Q|0,hb,ib);yb=(Q*80|0|W)+(r+30176)|0;zb=80}Se[c[fa+(ba<<5)+16+(X<<3)+(Fa<<2)>>2]&1023](P,Ma,yb,zb,8,qa<<1,xa<<1);break}S=V+11+Ga>>6;M5a(Wa,(S|0)>0?S:0,0);S=(I|0)!=0|0;Y=-S|0;ma=Y&3;Ca=-O|0;la=Ca&3;do{if((M|0)<(ma|0)|(V|0)<(la|0)){jb=325}else{if(((S<<2)+M|0)>(Ua-4|0)){jb=325;break}if((Ga+V|0)>(Ta-4|0)){jb=325}else{Ab=H;Bb=Ha}}}while(0);if((jb|0)==325){H=L+(m-ma-(ca(la,Ha)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,H,80,Ha,(Y&7)+4|0,(Ca&7)+4|0,M-ma|0,V-la|0,Ua,Ta);Ab=(la*80|0|ma)+(r+30176)|0;Bb=80}Se[c[fa+(ea<<5)+(S<<3)+(O<<2)>>2]&1023](ga,Ma,Ab,Bb,4,I<<1,ua<<1);H=c[Z>>2]|0;Ga=(c[ia>>2]|0)+4|0;xa=c[n>>2]|0;qa=c[Ea>>2]|0;P=ra|4;Fa=b[_a+24>>1]|0;X=b[_a+26>>1]|0;ba=(X>>3)+Da|0;W=(Fa>>3)+P|0;Q=(ca(ba,qa)|0)+W|0;ha=xa+Q|0;va=Fa&7;Fa=X&7;X=(Fa|0)!=0|0;ja=X<<2;da=ba+11+ja>>6;M5a(Wa,(da|0)>0?da:0,0);da=(va|0)!=0|0;na=-da|0;u=na&3;U=-X|0;J=U&3;do{if((W|0)<(u|0)|(ba|0)<(J|0)){jb=329}else{if(((da<<2)+W|0)>(Ua-4|0)){jb=329;break}if((ja+ba|0)>(Ta-4|0)){jb=329}else{Cb=ha;Db=qa}}}while(0);if((jb|0)==329){ha=xa+(Q-u-(ca(J,qa)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,ha,80,qa,(na&7)+4|0,(U&7)+4|0,W-u|0,ba-J|0,Ua,Ta);Cb=(J*80|0|u)+(r+30176)|0;Db=80}Se[c[fa+(H<<5)+(da<<3)+(X<<2)>>2]&1023](Ga,Ma,Cb,Db,4,va<<1,Fa<<1);ha=c[Z>>2]|0;ja=Ma<<2;ua=(c[ia>>2]|0)+ja|0;I=c[n>>2]|0;ga=c[Ea>>2]|0;O=Da|4;S=b[_a+32>>1]|0;ea=b[_a+34>>1]|0;ma=(ea>>3)+O|0;la=(S>>3)+ra|0;V=(ca(ma,ga)|0)+la|0;M=I+V|0;Ca=S&7;S=ea&7;ea=(S|0)!=0|0;Y=ea<<2;Ha=ma+11+Y>>6;M5a(Wa,(Ha|0)>0?Ha:0,0);Ha=(Ca|0)!=0|0;m=-Ha|0;L=m&3;R=-ea|0;oa=R&3;do{if((la|0)<(L|0)|(ma|0)<(oa|0)){jb=333}else{if(((Ha<<2)+la|0)>(Ua-4|0)){jb=333;break}if((Y+ma|0)>(Ta-4|0)){jb=333}else{Eb=M;Fb=ga}}}while(0);if((jb|0)==333){M=I+(V-L-(ca(oa,ga)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,M,80,ga,(m&7)+4|0,(R&7)+4|0,la-L|0,ma-oa|0,Ua,Ta);Eb=(oa*80|0|L)+(r+30176)|0;Fb=80}Se[c[fa+(ha<<5)+(Ha<<3)+(ea<<2)>>2]&1023](ua,Ma,Eb,Fb,4,Ca<<1,S<<1);M=c[Z>>2]|0;Y=ja+4|0;Fa=(c[ia>>2]|0)+Y|0;va=c[n>>2]|0;Ga=c[Ea>>2]|0;X=b[_a+40>>1]|0;da=b[_a+42>>1]|0;H=(da>>3)+O|0;u=(X>>3)+P|0;J=(ca(H,Ga)|0)+u|0;ba=va+J|0;W=X&7;X=da&7;da=(X|0)!=0|0;U=da<<2;na=H+11+U>>6;M5a(Wa,(na|0)>0?na:0,0);na=(W|0)!=0|0;qa=-na|0;Q=qa&3;xa=-da|0;_=xa&3;do{if((u|0)<(Q|0)|(H|0)<(_|0)){jb=337}else{if(((na<<2)+u|0)>(Ua-4|0)){jb=337;break}if((U+H|0)>(Ta-4|0)){jb=337}else{Gb=ba;Hb=Ga}}}while(0);if((jb|0)==337){ba=va+(J-Q-(ca(_,Ga)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,ba,80,Ga,(qa&7)+4|0,(xa&7)+4|0,u-Q|0,H-_|0,Ua,Ta);Gb=(_*80|0|Q)+(r+30176)|0;Hb=80}Se[c[fa+(M<<5)+(na<<3)+(da<<2)>>2]&1023](Fa,Ma,Gb,Hb,4,W<<1,X<<1);if((a[Ja]|0)==0){break}ba=c[Z>>2]|0;U=c[ia>>2]|0;Ea=gb|0;n=c[Ea>>2]|0;S=gb+32|0;Ca=c[S>>2]|0;ua=b[_a+20>>1]|0;ea=b[_a+22>>1]|0;Ha=(ea>>3)+Da|0;ha=(ua>>3)+ra|0;L=(ca(Ha,Ca)|0)+ha|0;oa=n+L|0;ma=ua&7;ua=ea&7;ea=(ua|0)!=0|0;la=ea<<2;R=Ha+11+la>>6;M5a(fb,(R|0)>0?R:0,0);R=(ma|0)!=0|0;m=-R|0;ga=m&3;V=-ea|0;I=V&3;do{if((ha|0)<(ga|0)|(Ha|0)<(I|0)){jb=342}else{if(((R<<2)+ha|0)>(hb-4|0)){jb=342;break}if((la+Ha|0)>(ib-4|0)){jb=342}else{Ib=oa;Jb=Ca}}}while(0);if((jb|0)==342){oa=n+(L-ga-(ca(I,Ca)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,oa,80,Ca,(m&7)+4|0,(V&7)+4|0,ha-ga|0,Ha-I|0,hb,ib);Ib=(I*80|0|ga)+(r+30176)|0;Jb=80}Se[c[fa+(ba<<5)+16+(R<<3)+(ea<<2)>>2]&1023](U,Ma,Ib,Jb,4,ma<<1,ua<<1);oa=c[Z>>2]|0;la=(c[ia>>2]|0)+4|0;X=c[Ea>>2]|0;W=c[S>>2]|0;Fa=b[_a+28>>1]|0;da=b[_a+30>>1]|0;na=(da>>3)+Da|0;M=(Fa>>3)+P|0;Q=(ca(na,W)|0)+M|0;_=X+Q|0;H=Fa&7;Fa=da&7;da=(Fa|0)!=0|0;u=da<<2;xa=na+11+u>>6;M5a(fb,(xa|0)>0?xa:0,0);xa=(H|0)!=0|0;qa=-xa|0;Ga=qa&3;J=-da|0;va=J&3;do{if((M|0)<(Ga|0)|(na|0)<(va|0)){jb=346}else{if(((xa<<2)+M|0)>(hb-4|0)){jb=346;break}if((u+na|0)>(ib-4|0)){jb=346}else{Kb=_;Lb=W}}}while(0);if((jb|0)==346){_=X+(Q-Ga-(ca(va,W)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,_,80,W,(qa&7)+4|0,(J&7)+4|0,M-Ga|0,na-va|0,hb,ib);Kb=(va*80|0|Ga)+(r+30176)|0;Lb=80}Se[c[fa+(oa<<5)+16+(xa<<3)+(da<<2)>>2]&1023](la,Ma,Kb,Lb,4,H<<1,Fa<<1);_=c[Z>>2]|0;u=(c[ia>>2]|0)+ja|0;Da=c[Ea>>2]|0;ua=c[S>>2]|0;ma=b[_a+36>>1]|0;U=b[_a+38>>1]|0;ea=(U>>3)+O|0;R=(ma>>3)+ra|0;ba=(ca(ea,ua)|0)+R|0;ga=Da+ba|0;I=ma&7;ma=U&7;U=(ma|0)!=0|0;Ha=U<<2;ha=ea+11+Ha>>6;M5a(fb,(ha|0)>0?ha:0,0);ha=(I|0)!=0|0;V=-ha|0;m=V&3;Ca=-U|0;L=Ca&3;do{if((R|0)<(m|0)|(ea|0)<(L|0)){jb=350}else{if(((ha<<2)+R|0)>(hb-4|0)){jb=350;break}if((Ha+ea|0)>(ib-4|0)){jb=350}else{Mb=ga;Nb=ua}}}while(0);if((jb|0)==350){ga=Da+(ba-m-(ca(L,ua)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,ga,80,ua,(V&7)+4|0,(Ca&7)+4|0,R-m|0,ea-L|0,hb,ib);Mb=(L*80|0|m)+(r+30176)|0;Nb=80}Se[c[fa+(_<<5)+16+(ha<<3)+(U<<2)>>2]&1023](u,Ma,Mb,Nb,4,I<<1,ma<<1);ga=c[Z>>2]|0;Ha=(c[ia>>2]|0)+Y|0;ra=c[Ea>>2]|0;ja=c[S>>2]|0;Fa=b[_a+44>>1]|0;H=b[_a+46>>1]|0;la=(H>>3)+O|0;da=(Fa>>3)+P|0;xa=(ca(la,ja)|0)+da|0;oa=ra+xa|0;Ga=Fa&7;Fa=H&7;H=(Fa|0)!=0|0;va=H<<2;na=la+11+va>>6;M5a(fb,(na|0)>0?na:0,0);na=(Ga|0)!=0|0;M=-na|0;J=M&3;qa=-H|0;W=qa&3;do{if((da|0)<(J|0)|(la|0)<(W|0)){jb=354}else{if(((na<<2)+da|0)>(hb-4|0)){jb=354;break}if((va+la|0)>(ib-4|0)){jb=354}else{Ob=oa;Pb=ja}}}while(0);if((jb|0)==354){oa=ra+(xa-J-(ca(W,ja)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,oa,80,ja,(M&7)+4|0,(qa&7)+4|0,da-J|0,la-W|0,hb,ib);Ob=(W*80|0|J)+(r+30176)|0;Pb=80}Se[c[fa+(ga<<5)+16+(na<<3)+(H<<2)>>2]&1023](Ha,Ma,Ob,Pb,4,Ga<<1,Fa<<1)}else{oa=d[1068632+Ia|0]|0;va=d[1898752+(Ia<<1)|0]<<2;P=d[1898753+(Ia<<1)|0]<<2;O=_a+12|0;S=c[O>>2]|0;Ea=$a+384|0;Y=$a+1116|0;ia=c[Y>>2]|0;Z=c[Va>>2]|0;ma=c[Va+32>>2]|0;I=Za<<3;u=Ya<<3;U=b[_a+16>>1]|0;ha=b[_a+18>>1]|0;_=(ha>>3)+I|0;m=(U>>3)+u|0;L=(ca(_,ma)|0)+m|0;ea=Z+L|0;R=U&7;U=ha&7;ha=(U|0)!=0|0;Ca=ha<<2;V=P+7|0;ua=_+V+Ca>>6;M5a(Wa,(ua|0)>0?ua:0,0);ua=(R|0)!=0|0;ba=-ua|0;Da=ba&3;Q=-ha|0;X=Q&3;do{if((m|0)<(Da|0)|(_|0)<(X|0)){jb=359}else{if(((ua<<2)+m|0)>(Ua-va|0)){jb=359;break}if((Ca+_|0)>(Ta-P|0)){jb=359}else{Qb=ea;Rb=ma}}}while(0);if((jb|0)==359){ea=Z+(L-Da-(ca(X,ma)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,ea,80,ma,(ba&7)+va|0,(Q&7)+P|0,m-Da|0,_-X|0,Ua,Ta);Qb=(X*80|0|Da)+(r+30176)|0;Rb=80}Se[c[Ea+(oa<<7)+(S<<5)+(ua<<3)+(ha<<2)>>2]&1023](ia,Ma,Qb,Rb,P,R<<1,U<<1);if((a[Ja]|0)==0){break}ea=c[O>>2]|0;Ca=c[Y>>2]|0;Fa=c[gb>>2]|0;Ga=c[gb+32>>2]|0;Ha=b[_a+20>>1]|0;H=b[_a+22>>1]|0;na=(H>>3)+I|0;ga=(Ha>>3)+u|0;fa=(ca(na,Ga)|0)+ga|0;J=Fa+fa|0;W=Ha&7;Ha=H&7;H=(Ha|0)!=0|0;la=H<<2;da=na+V+la>>6;M5a(fb,(da|0)>0?da:0,0);da=(W|0)!=0|0;qa=-da|0;M=qa&3;ja=-H|0;xa=ja&3;do{if((ga|0)<(M|0)|(na|0)<(xa|0)){jb=364}else{if(((da<<2)+ga|0)>(hb-va|0)){jb=364;break}if((la+na|0)>(ib-P|0)){jb=364}else{Sb=J;Tb=Ga}}}while(0);if((jb|0)==364){J=Fa+(fa-M-(ca(xa,Ga)|0))|0;Ve[c[$a+1024>>2]&127]($a+30176|0,J,80,Ga,(qa&7)+va|0,(ja&7)+P|0,ga-M|0,na-xa|0,hb,ib);Sb=(xa*80|0|M)+(r+30176)|0;Tb=80}Se[c[Ea+(oa<<7)+(ea<<5)+16+(da<<3)+(H<<2)>>2]&1023](Ca,Ma,Sb,Tb,P,W<<1,Ha<<1)}}while(0);Ma=c[Xa>>2]|0;Ia=d[1068645+Ma|0]|0;J=d[1898778+(Ma<<1)|0]<<2;la=d[1898779+(Ma<<1)|0]<<2;V=Ua+1>>1;u=Ta+1>>1;if((a[Ja]|0)==0){Ub=hb;Vb=ib}else{Ub=hb+1>>1;Vb=ib+1>>1}I=_a+16|0;if(Ma>>>0>9>>>0){Ma=(b[_a+24>>1]|0)+(b[I>>1]|0)+(b[_a+32>>1]|0)+(b[_a+40>>1]|0)|0;Y=(b[_a+26>>1]|0)+(b[_a+18>>1]|0)+(b[_a+34>>1]|0)+(b[_a+42>>1]|0)|0;Wb=((((Ma|0)>0?2:-2)+Ma|0)/4|0)&65535;Xb=((((Y|0)>0?2:-2)+Y|0)/4|0)&65535}else{Y=c[I>>2]|0;Wb=Y&65535;Xb=Y>>>16&65535}Y=_a+12|0;I=c[Y>>2]|0;Ma=$a+384|0;O=$a+1116|0;U=$a+1120|0;R=c[U>>2]|0;ia=$a+1124|0;ha=c[ia>>2]|0;ua=c[Va+4>>2]|0;S=c[Va+36>>2]|0;Da=c[Va+8>>2]|0;X=c[Va+40>>2]|0;_=Za<<2;m=Ya<<2;Q=Wb<<16>>16;ba=Xb<<16>>16;ma=(ba>>4)+_|0;L=(Q>>4)+m|0;Z=(ca(S,ma)|0)+L|0;ra=ua+Z|0;n=(ca(X,ma)|0)+L|0;N=Da+n|0;ta=Q&15;Q=ba&15;ba=(Q|0)!=0|0;ka=ba<<2;ya=la+7|0;aa=ma+ya+ka>>5;M5a(Wa,(aa|0)>0?aa:0,0);aa=(ta|0)!=0|0;F=-aa|0;sa=F&3;K=-ba|0;G=K&3;do{if((L|0)<(sa|0)|(ma|0)<(G|0)){jb=374}else{if(((aa<<2)+L|0)>(V-J|0)){jb=374;break}if((ka+ma|0)>(u-la|0)){jb=374;break}$=Ma+(Ia<<7)+(I<<5)+(aa<<3)+(ba<<2)|0;Se[c[$>>2]&1023](R,Ka,ra,S,la,ta,Q);Se[c[$>>2]&1023](ha,Ka,N,X,la,ta,Q)}}while(0);if((jb|0)==374){N=$a+1024|0;ra=$a+30176|0;ka=ua+(Z-((ca(G,S)|0)+sa))|0;Wa=(F&7)+J|0;Va=(K&7)+la|0;Ta=L-sa|0;Ua=ma-G|0;Ve[c[N>>2]&127](ra,ka,80,S,Wa,Va,Ta,Ua,V,u);ka=(G*80|0|sa)+(r+30176)|0;$=Ma+(Ia<<7)+(I<<5)+(aa<<3)+(ba<<2)|0;Se[c[$>>2]&1023](R,Ka,ka,80,la,ta,Q);T=Da+(n-((ca(X,G)|0)+sa))|0;Ve[c[N>>2]&127](ra,T,80,X,Wa,Va,Ta,Ua,V,u);Se[c[$>>2]&1023](ha,Ka,ka,80,la,ta,Q)}b:do{if((a[Ja]|0)!=0){ka=_a+20|0;if((c[Xa>>2]|0)>>>0>9>>>0){$=(b[_a+28>>1]|0)+(b[ka>>1]|0)+(b[_a+36>>1]|0)+(b[_a+44>>1]|0)|0;Ua=(b[_a+30>>1]|0)+(b[_a+22>>1]|0)+(b[_a+38>>1]|0)+(b[_a+46>>1]|0)|0;Yb=(((($|0)>0?2:-2)+$|0)/4|0)&65535;Zb=((((Ua|0)>0?2:-2)+Ua|0)/4|0)&65535}else{Ua=c[ka>>2]|0;Yb=Ua&65535;Zb=Ua>>>16&65535}Ua=c[Y>>2]|0;ka=c[U>>2]|0;$=c[ia>>2]|0;Ta=c[gb+4>>2]|0;Va=c[gb+36>>2]|0;Wa=c[gb+8>>2]|0;T=c[gb+40>>2]|0;ra=Yb<<16>>16;N=Zb<<16>>16;za=(N>>4)+_|0;wa=(ra>>4)+m|0;Ba=(ca(Va,za)|0)+wa|0;pa=Ta+Ba|0;Pa=(ca(T,za)|0)+wa|0;Oa=Wa+Pa|0;Aa=ra&15;ra=N&15;N=(ra|0)!=0|0;Qa=N<<2;Ra=za+ya+Qa>>5;M5a(fb,(Ra|0)>0?Ra:0,0);Ra=(Aa|0)!=0|0;Sa=-Ra|0;_b=Sa&3;$b=-N|0;ac=$b&3;do{if(!((wa|0)<(_b|0)|(za|0)<(ac|0))){if(((Ra<<2)+wa|0)>(Ub-J|0)){break}if((Qa+za|0)>(Vb-la|0)){break}bc=Ma+(Ia<<7)+(Ua<<5)+16+(Ra<<3)+(N<<2)|0;Se[c[bc>>2]&1023](ka,Ka,pa,Va,la,Aa,ra);Se[c[bc>>2]&1023]($,Ka,Oa,T,la,Aa,ra);break b}}while(0);Oa=$a+1024|0;pa=$a+30176|0;Qa=Ta+(Ba-((ca(ac,Va)|0)+_b))|0;Ha=(Sa&7)+J|0;W=($b&7)+la|0;P=wa-_b|0;Ca=za-ac|0;Ve[c[Oa>>2]&127](pa,Qa,80,Va,Ha,W,P,Ca,Ub,Vb);Qa=(ac*80|0|_b)+(r+30176)|0;H=Ma+(Ia<<7)+(Ua<<5)+16+(Ra<<3)+(N<<2)|0;Se[c[H>>2]&1023](ka,Ka,Qa,80,la,Aa,ra);da=Wa+(Pa-((ca(T,ac)|0)+_b))|0;Ve[c[Oa>>2]&127](pa,da,80,T,Ha,W,P,Ca,Ub,Vb);Se[c[H>>2]&1023]($,Ka,Qa,80,la,Aa,ra)}}while(0);if((a[_a+10|0]|0)!=0){break}la=c[Xa>>2]|0;Ka=d[1898778+(la<<1)|0]<<1;Ia=_a+52|0;Ma=c[Ia>>2]|0;r=1<<Ma;J=d[1898779+(la<<1)|0]<<1;la=1<<(Ma<<1);ya=(c[$a+1808>>2]|0)-Ya<<1;m=ya>>>0>Ka>>>0?Ka:ya;ya=(c[$a+1804>>2]|0)-Za<<1;Ka=ya>>>0>J>>>0?J:ya;ya=d[$a+1549|0]<<2;J=_a+56|0;_=c[J>>2]|0;Y=ya+_|0;Ja=1<<_;Q=(Ka|0)>0;if(Q){ta=(m|0)>0;ha=$a+35896|0;u=r<<2;V=$a+240|0;X=V+(ya+Ma<<4)|0;ya=$a+35864|0;sa=0;G=0;n=c[O>>2]|0;while(1){c:do{if(ta){Da=sa;R=0;ba=n;while(1){aa=(c[ha>>2]|0)+Da|0;if((c[Ia>>2]|0)>>>0>1>>>0){cc=e[aa>>1]|0}else{cc=d[aa]|0}if((cc|0)!=0){mf[c[X>>2]&2047](ba,c[Na>>2]|0,(c[ya>>2]|0)+(Da<<4<<1)|0,cc)}aa=R+r|0;I=Da+la|0;if((aa|0)>=(m|0)){dc=I;break c}Da=I;R=aa;ba=ba+u|0}}else{dc=sa}}while(0);ra=G+r|0;if((ra|0)<(Ka|0)){sa=dc;G=ra;n=n+(c[Na>>2]<<2<<Ma)|0}else{break}}ec=c[J>>2]|0;fc=V}else{ec=_;fc=$a+240|0}Ma=m>>1;Na=Ka>>1;n=1<<(ec<<1);G=(m|0)>0;sa=Ja<<2;r=fc+(Y<<4)|0;if(!Q){break}u=$a+35900|0;la=$a+35876|0;ya=0;X=0;Ia=c[U>>2]|0;while(1){d:do{if(G){ha=ya;ta=0;O=Ia;while(1){_a=(c[u>>2]|0)+ha|0;if((c[J>>2]|0)>>>0>1>>>0){gc=e[_a>>1]|0}else{gc=d[_a]|0}if((gc|0)!=0){mf[c[r>>2]&2047](O,c[La>>2]|0,(c[la>>2]|0)+(ha<<4<<1)|0,gc)}_a=ta+Ja|0;Za=ha+n|0;if((_a|0)>=(Ma|0)){hc=Za;break d}ha=Za;ta=_a;O=O+sa|0}}else{hc=ya}}while(0);ic=c[La>>2]|0;O=Ia+(ca(ic,sa)|0)|0;ta=X+Ja|0;if((ta|0)<(Na|0)){ya=hc;X=ta;Ia=O}else{break}}Ia=$a+35904|0;X=$a+35880|0;ya=0;la=0;u=c[ia>>2]|0;U=ic;while(1){if(G){Q=ya;Y=0;m=u;while(1){Ka=(c[Ia>>2]|0)+Q|0;if((c[J>>2]|0)>>>0>1>>>0){jc=e[Ka>>1]|0}else{jc=d[Ka]|0}if((jc|0)!=0){mf[c[r>>2]&2047](m,c[La>>2]|0,(c[X>>2]|0)+(Q<<4<<1)|0,jc)}Ka=Y+Ja|0;kc=Q+n|0;if((Ka|0)>=(Ma|0)){break}Q=kc;Y=Ka;m=m+sa|0}lc=kc;mc=c[La>>2]|0}else{lc=ya;mc=U}m=u+(ca(mc,sa)|0)|0;Y=la+Ja|0;if((Y|0)<(Na|0)){ya=lc;la=Y;u=m;U=mc}else{break}}}else{U=q|0;u=$a;la=c[$a+1084>>2]|0;ya=c[$a+1100>>2]|0;Na=c[$a+1108>>2]|0;Ja=la+48|0;sa=c[Ja>>2]|0;La=d[1898778+(sa<<1)|0]|0;Ma=La<<1;n=la+52|0;X=c[n>>2]|0;r=1<<X;J=d[1898779+(sa<<1)|0]<<1;sa=1<<(X<<1);Ia=$a+1808|0;G=(c[Ia>>2]|0)-Na<<1;ia=G>>>0>Ma>>>0?Ma:G;G=$a+1804|0;m=(c[G>>2]|0)-ya<<1;Y=m>>>0>J>>>0?J:m;m=d[$a+1549|0]<<2;J=m+X|0;X=la+56|0;Q=c[X>>2]|0;Ka=m+Q|0;m=1<<Q;_=$a+1116|0;V=_;O=$a+1360|0;ta=(Y|0)>0;if(ta){ha=c[O>>2]|0;_a=(ia|0)>0;Za=r<<2;Ya=$a+1128|0;Xa=p+16|0;ra=la+10|0;Aa=$a+35896|0;$=(ya|0)>0;T=$a+1788|0;_b=Ma-1|0;Ma=$a;ac=$a+240|0;Pa=$a+35864|0;Wa=ya&7;ka=$a+30148|0;N=Na<<3;Ra=p+20|0;Ua=Ra;Va=p+19|0;za=p+15|0;wa=c[_>>2]|0;_=(c[ha>>2]|0)+k|0;$b=0;Sa=0;Ba=ha;while(1){if(_a){ha=$b<<1;Ta=$|($b|0)>0;ba=Ta&1;R=($b|0)==0;Da=($b|Wa|0)==0;aa=Ta?-127:127;I=0;S=wa;ma=_;L=Sa;while(1){K=c[n>>2]|0;if((c[Ja>>2]|0)>>>0>9>>>0){nc=(K|0)==0?I+ha|0:0}else{nc=0}F=d[la+5+nc|0]|0;Z=c[215400+(F<<2)>>2]|0;do{if((a[ra]|0)==0){ua=(c[Aa>>2]|0)+L|0;if(K>>>0>1>>>0){oc=e[ua>>1]|0;break}else{oc=d[ua]|0;break}}else{oc=0}}while(0);ua=c[(c[O>>2]|0)+32>>2]|0;Qa=c[Ya>>2]|0;H=(c[T>>2]|0)>>>0<Na>>>0|(I|0)>0;Ca=(_b|0)>(I|0);P=a[1707448+(F<<2)+((H&1)<<1)+ba|0]|0;W=P&255;e:do{if((2813>>>(W>>>0)&1|0)==0){pc=Xa}else{Ha=4<<K;da=((c[Ia>>2]|0)-Na<<1)-I<<2;pa=(K|0)==0;do{if(pa){if(!((P<<24>>24|0)==7|(P<<24>>24|0)==3)){qc=0;break}qc=Ca?4:0}else{qc=0}}while(0);do{if(Ta){do{if(Da){rc=(c[ka>>2]|0)+((I<<2)+N)|0}else{if(R){rc=ma+(-ua|0)|0;break}else{rc=S+(-Qa|0)|0;break}}}while(0);do{if(H){if(Da){sc=(c[ka>>2]|0)+((I<<2)+N)|0;break}if(R|(I|0)==0){sc=ma+(-ua|0)|0;break}else{sc=S+(-Qa|0)|0;break}}else{sc=0}}while(0);Oa=624>>>(W>>>0)&1;if((Oa|0)==0){jb=183}else{if(H&(rc|0)==(sc|0)){jb=183}}f:do{if((jb|0)==183){jb=0;do{if(pa){if(!((P<<24>>24|0)==7|(P<<24>>24|0)==3)){break}if(!Ca){break f}}}while(0);if((qc+Ha|0)<=(da|0)){pc=rc;break e}}}while(0);if((Ha|0)>(da|0)){nrc(Xa|0,rc|0,da)|0;mrc(p+(da+16)|0,a[p+(da+15)|0]|0,Ha-da|0)|0;tc=sc;uc=rc;vc=Oa;break}else{nrc(Xa|0,rc|0,Ha)|0;tc=sc;uc=rc;vc=Oa;break}}else{mrc(Xa|0,127,Ha|0)|0;tc=0;uc=0;vc=624>>>(W>>>0)&1}}while(0);do{if((vc|0)!=0){if(H&Ta){a[za]=a[tc-1|0]|0;break}else{a[za]=aa;break}}}while(0);if(!pa){pc=Xa;break}if(!((P<<24>>24|0)==7|(P<<24>>24|0)==3)){pc=Xa;break}do{if(Ta&Ca){if((qc+Ha|0)>(da|0)){break}ea=uc+4|0;c[Ua>>2]=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24;pc=Xa;break e}}while(0);mrc(Ra|0,a[Va]|0,4)|0;pc=Xa}}while(0);g:do{if((1910>>>(W>>>0)&1|0)!=0){Ca=4<<K;if(!H){mrc(U|0,-127|0,Ca|0)|0;break}P=((c[G>>2]|0)-ya<<1)-$b<<2;F=(I|0)==0;da=F?ma:S;Ha=F?ua:Qa;if((Ca|0)<=(P|0)){if((Ca|0)<=0){break}F=Ca-1|0;pa=0;while(1){a[q+(F-pa)|0]=a[da+((ca(pa,Ha)|0)-1)|0]|0;pa=pa+1|0;if((pa|0)>=(Ca|0)){break g}}}if((P|0)>0){pa=Ca-1|0;F=0;do{a[q+(pa-F)|0]=a[da+((ca(F,Ha)|0)-1)|0]|0;F=F+1|0;}while((F|0)<(P|0))}F=Ca-P|0;mrc(U|0,a[q+F|0]|0,F|0)|0}}while(0);mf[c[Ma+((c[n>>2]|0)*60|0)+(W<<2)>>2]&2047](S,Qa,U,pc);if((oc|0)!=0){mf[c[ac+(J<<4)+(Z<<2)>>2]&2047](S,c[Ya>>2]|0,(c[Pa>>2]|0)+(L<<4<<1)|0,oc)}ua=I+r|0;wc=L+sa|0;if((ua|0)>=(ia|0)){break}I=ua;S=S+Za|0;ma=ma+Za|0;L=wc}xc=wc;yc=c[O>>2]|0}else{xc=Sa;yc=Ba}L=_+(ca(c[yc+32>>2]|0,Za)|0)|0;ma=wa+(ca(c[Ya>>2]|0,Za)|0)|0;S=$b+r|0;if((S|0)<(Y|0)){wa=ma;_=L;$b=S;Sa=xc;Ba=yc}else{break}}zc=c[X>>2]|0;Ac=Xa;Bc=ra;Cc=T;Dc=Ma;Ec=ac;Fc=Wa;Gc=Ra;Hc=Ua;Ic=Va;Jc=za}else{Ba=p+20|0;zc=Q;Ac=p+16|0;Bc=la+10|0;Cc=$a+1788|0;Dc=$a;Ec=$a+240|0;Fc=ya&7;Gc=Ba;Hc=Ba;Ic=p+19|0;Jc=p+15|0}Ba=ia>>1;Sa=Y>>1;$b=1<<(zc<<1);_=(ia|0)>0;wa=m<<2;r=$a+1132|0;Za=la+9|0;Ya=$a+35900|0;sa=(ya|0)>0;Pa=La-1|0;J=Ec+(Ka<<4)|0;n=$a+35876|0;N=Na<<2;ka=0;while(1){_b=ka+1|0;if(ta){Aa=c[O>>2]|0;Ja=Ya+(ka<<2)|0;$=n+(ka<<2)|0;_a=u+30148+(_b<<2)|0;S=c[V+(_b<<2)>>2]|0;L=(c[Aa+(_b<<2)>>2]|0)+l|0;ma=0;I=0;Ta=Aa;while(1){if(_){Aa=sa|(ma|0)>0;aa=Aa&1;R=(ma|0)==0;Da=(ma|Fc|0)==0;ba=Aa?-127:127;ha=ma+ya|0;ua=0;H=I;K=S;F=L;while(1){Ha=d[Za]|0;da=c[X>>2]|0;do{if((a[Bc]|0)==0){pa=(c[Ja>>2]|0)+H|0;if(da>>>0>1>>>0){Kc=e[pa>>1]|0;break}else{Kc=d[pa]|0;break}}else{Kc=0}}while(0);P=c[(c[O>>2]|0)+36>>2]|0;Ca=c[r>>2]|0;pa=(c[Cc>>2]|0)>>>0<Na>>>0|(ua|0)>0;ea=(Pa|0)>(ua|0);oa=a[1707448+(Ha<<2)+((pa&1)<<1)+aa|0]|0;Ea=oa&255;h:do{if((2813>>>(Ea>>>0)&1|0)==0){Lc=Ac}else{M=4<<da;xa=(c[Ia>>2]|0)-(ua+Na)<<2;na=(da|0)==0;do{if(na){if(!((oa<<24>>24|0)==7|(oa<<24>>24|0)==3)){Mc=0;break}Mc=ea?4:0}else{Mc=0}}while(0);do{if(Aa){do{if(Da){Nc=(c[_a>>2]|0)+((ua<<2)+N)|0}else{if(R){Nc=F+(-P|0)|0;break}else{Nc=K+(-Ca|0)|0;break}}}while(0);do{if(pa){if(Da){Oc=(c[_a>>2]|0)+((ua<<2)+N)|0;break}if(R|(ua|0)==0){Oc=F+(-P|0)|0;break}else{Oc=K+(-Ca|0)|0;break}}else{Oc=0}}while(0);Oa=624>>>(Ea>>>0)&1;if((Oa|0)==0){jb=247}else{if(pa&(Nc|0)==(Oc|0)){jb=247}}i:do{if((jb|0)==247){jb=0;do{if(na){if(!((oa<<24>>24|0)==7|(oa<<24>>24|0)==3)){break}if(!ea){break i}}}while(0);if((Mc+M|0)<=(xa|0)){Lc=Nc;break h}}}while(0);if((M|0)>(xa|0)){nrc(Ac|0,Nc|0,xa)|0;mrc(p+(xa+16)|0,a[p+(xa+15)|0]|0,M-xa|0)|0;Pc=Oc;Qc=Nc;Rc=Oa;break}else{nrc(Ac|0,Nc|0,M)|0;Pc=Oc;Qc=Nc;Rc=Oa;break}}else{mrc(Ac|0,127,M|0)|0;Pc=0;Qc=0;Rc=624>>>(Ea>>>0)&1}}while(0);do{if((Rc|0)!=0){if(pa&Aa){a[Jc]=a[Pc-1|0]|0;break}else{a[Jc]=ba;break}}}while(0);if(!na){Lc=Ac;break}if(!((oa<<24>>24|0)==7|(oa<<24>>24|0)==3)){Lc=Ac;break}do{if(Aa&ea){if((Mc+M|0)>(xa|0)){break}ga=Qc+4|0;c[Hc>>2]=d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24;Lc=Ac;break h}}while(0);mrc(Gc|0,a[Ic]|0,4)|0;Lc=Ac}}while(0);j:do{if((1910>>>(Ea>>>0)&1|0)!=0){ea=4<<da;if(!pa){mrc(U|0,-127|0,ea|0)|0;break}oa=(c[G>>2]|0)-ha<<2;Ha=(ua|0)==0;xa=Ha?F:K;M=Ha?P:Ca;if((ea|0)<=(oa|0)){if((ea|0)<=0){break}Ha=ea-1|0;na=0;while(1){a[q+(Ha-na)|0]=a[xa+((ca(na,M)|0)-1)|0]|0;na=na+1|0;if((na|0)>=(ea|0)){break j}}}if((oa|0)>0){na=ea-1|0;Ha=0;do{a[q+(na-Ha)|0]=a[xa+((ca(Ha,M)|0)-1)|0]|0;Ha=Ha+1|0;}while((Ha|0)<(oa|0))}Ha=ea-oa|0;mrc(U|0,a[q+Ha|0]|0,Ha|0)|0}}while(0);mf[c[Dc+((c[X>>2]|0)*60|0)+(Ea<<2)>>2]&2047](K,Ca,U,Lc);if((Kc|0)!=0){mf[c[J>>2]&2047](K,c[r>>2]|0,(c[$>>2]|0)+(H<<4<<1)|0,Kc)}P=ua+m|0;Sc=H+$b|0;if((P|0)<(Ba|0)){ua=P;H=Sc;K=K+wa|0;F=F+wa|0}else{break}}Tc=Sc;Uc=c[O>>2]|0}else{Tc=I;Uc=Ta}F=L+(ca(c[Uc+36>>2]|0,wa)|0)|0;K=S+(ca(c[r>>2]|0,wa)|0)|0;H=ma+m|0;if((H|0)<(Sa|0)){S=K;L=F;ma=H;I=Tc;Ta=Uc}else{break}}}if((_b|0)<2){ka=_b}else{break}}}}while(0);do{if(db){Uc=(c[A>>2]|0)-h|0;Tc=(Uc>>>0>v>>>0?v:Uc)<<3;Uc=(c[C>>2]|0)-g|0;Sc=(Uc>>>0>w>>>0?w:Uc)<<3;if((Tc|0)<=0){break}Uc=f+384|0;Kc=x|0;Lc=0;Dc=0;while(1){q=64>>>(Dc>>>0);if((q&Tc|0)==0){Vc=Lc}else{Se[c[Uc+(Dc<<7)>>2]&1023]((c[Kc>>2]|0)+(Lc+k)|0,c[cb>>2]|0,f+(Lc+35936)|0,64,Sc,0,0);Vc=q+Lc|0}if((Vc|0)<(Tc|0)){Lc=Vc;Dc=Dc+1|0}else{break}}}}while(0);do{if(eb){Vc=(c[A>>2]|0)-h|0;cb=(Vc>>>0>v>>>0?v:Vc)<<2;Vc=(c[C>>2]|0)-g|0;k=(Vc>>>0>w>>>0?w:Vc)<<2;if((cb|0)<=0){break}Vc=f+384|0;db=x+4|0;Dc=x+8|0;Lc=x+40|0;Tc=0;Sc=1;while(1){Kc=64>>>(Sc>>>0);if((Kc&cb|0)==0){Wc=Tc}else{Uc=Vc+(Sc<<7)|0;q=Tc+l|0;Se[c[Uc>>2]&1023]((c[db>>2]|0)+q|0,c[ab>>2]|0,f+(Tc+40032)|0,32,k,0,0);Se[c[Uc>>2]&1023]((c[Dc>>2]|0)+q|0,c[Lc>>2]|0,f+(Tc+41056)|0,32,k,0,0);Wc=Kc+Tc|0}if((Wc|0)<(cb|0)){Tc=Wc;Sc=Sc+1|0}else{break}}}}while(0);do{if((a[f+1408|0]|0)!=0){Wc=(a[bb]|0)==0;if(Wc){Xc=(d[t+3|0]|0)+1|0}else{Xc=0}ab=a[((a[t+8|0]|0)!=12)+(f+1554+((d[t|0]|0)*26|0)+18+(Xc<<1))|0]|0;l=ab&255;if(ab<<24>>24==0){break}x=(c[A>>2]|0)-h|0;eb=x>>>0>v>>>0?v:x;x=(c[C>>2]|0)-g|0;Sc=x>>>0>w>>>0?w:x;if(Wc){Yc=(a[t+10|0]|0)!=0|0}else{Yc=0}Wc=c[z>>2]|0;x=c[y>>2]|0;Tc=j+((x<<3)+Wc)|0;if((v|0)==1){cb=Tc;k=w;while(1){a[cb]=ab;Lc=k-1|0;if((Lc|0)==0){break}else{cb=cb+8|0;k=Lc}}}else if((v|0)==2){k=(l*257|0)&65535;cb=Tc;ab=w;while(1){b[cb>>1]=k;Lc=ab-1|0;if((Lc|0)==0){break}else{cb=cb+8|0;ab=Lc}}}else if((v|0)==4){ab=ca(l,16843009)|0;cb=Tc;k=w;while(1){c[cb>>2]=ab;Lc=k-1|0;if((Lc|0)==0){break}else{cb=cb+8|0;k=Lc}}}else if((v|0)==8){k=ca(l,16843009)|0;cb=Tc;ab=w;while(1){c[cb>>2]=k;c[cb+4>>2]=k;Lc=ab-1|0;if((Lc|0)==0){break}else{cb=cb+8|0;ab=Lc}}}ab=c[t+52>>2]|0;cb=1<<Wc;k=(cb<<eb)-cb|0;k:do{if((ab|Yc|0)==0){Tc=k&17;Lc=k-Tc|0;Dc=x+Sc|0;if((Sc|0)>0){Zc=x}else{break}do{db=j+64+(Zc<<2)+1|0;a[db]=d[db]|Tc;db=j+64+(Zc<<2)+2|0;a[db]=d[db]|Lc;db=2-((Zc&3|0)==0)+(j+96+(Zc<<2))|0;a[db]=d[db]|k;db=j+64+(Zc<<2)+3|0;a[db]=d[db]|k;db=j+96+(Zc<<2)+3|0;a[db]=d[db]|k;Zc=Zc+1|0;}while((Zc|0)<(Dc|0))}else{if((Yc|0)==0){Dc=(ab|0)==1|0;Lc=ab-1|0;Tc=1<<Lc;_b=c[838264+(Lc<<2)>>2]&k;Lc=x+Sc|0;if((Sc|0)>0){_c=x}else{break}while(1){db=j+64+(_c<<2)+Dc|0;a[db]=d[db]|_b;db=_c+1|0;if((db|0)<(Lc|0)){_c=db}else{$c=x;break}}while(1){_b=j+96+($c<<2)+Dc|0;a[_b]=d[_b]|k;$c=$c+Tc|0;if(($c|0)>=(Lc|0)){break k}}}if((ab|0)==1){Lc=j+96+(x<<2)+1|0;a[Lc]=d[Lc]|k;ad=1}else if((ab|0)==0){Lc=cb&17;Tc=cb-Lc|0;Dc=x+Sc|0;if((Sc|0)>0){_b=x;do{db=j+64+(_b<<2)+2|0;a[db]=d[db]|Tc;db=j+64+(_b<<2)+1|0;a[db]=d[db]|Lc;_b=_b+1|0;}while((_b|0)<(Dc|0))}Dc=2-((x&3|0)==0)+(j+96+(x<<2))|0;a[Dc]=d[Dc]|k;break}else{Dc=j+96+(x<<2)|0;a[Dc]=d[Dc]|k;ad=0}Dc=x+Sc|0;if((Sc|0)>0){bd=x}else{break}do{_b=j+64+(bd<<2)+ad|0;a[_b]=d[_b]|cb;bd=bd+1|0;}while((bd|0)<(Dc|0))}}while(0);k=c[A>>2]|0;ab=(k&1|0)==0|B>>>0<k>>>0?0:k&7;k=c[C>>2]|0;if((k&1|0)==0){cd=0}else{cd=D>>>0<k>>>0?0:k&7}k=c[t+56>>2]|0;Dc=(k|0)==0;do{if(Dc){if((Sc|0)==1){if((x&1|0)!=0){break}dd=(cd|0)==0?2:1}else{dd=Sc}if((eb|0)!=1){ed=eb;fd=dd;jb=471;break}if((Wc&1|0)!=0){break}ed=(ab|0)==0?2:1;fd=dd;jb=471}else{ed=eb;fd=Sc;jb=471}}while(0);l:do{if((jb|0)==471){Sc=(cb<<ed)-cb|0;if((k|Yc|0)==0){eb=(cb<<ed-1)-cb|0;_b=Sc&1;Lc=Sc-_b|0;Tc=fd+x|0;if((fd|0)<=0){break}db=(ab&1|0)==0;Vc=x;while(1){Kc=2-((Vc&7|0)==0)|0;q=j+128+(Vc<<2)+1|0;a[q]=d[q]|_b;q=j+128+(Vc<<2)+2|0;a[q]=d[q]|Lc;do{if(db){jb=477}else{if((Vc&1|0)==0){jb=477;break}q=j+160+(Vc<<2)+Kc|0;a[q]=d[q]|eb}}while(0);if((jb|0)==477){jb=0;q=j+160+(Vc<<2)+Kc|0;a[q]=d[q]|Sc}Vc=Vc+1|0;if((Vc|0)>=(Tc|0)){break l}}}if((Yc|0)!=0){if(Dc){Tc=(Wc|0)==0|0;Vc=cb-Tc|0;eb=fd+x|0;if((fd|0)>0){db=x;do{Lc=j+128+(db<<2)+2|0;a[Lc]=d[Lc]|Vc;Lc=j+128+(db<<2)+1|0;a[Lc]=d[Lc]|Tc;db=db+1|0;}while((db|0)<(eb|0))}eb=2-((x&7|0)==0)+(j+160+(x<<2))|0;a[eb]=d[eb]|Sc;break}if((k|0)==1){eb=j+160+(x<<2)+1|0;a[eb]=d[eb]|Sc;gd=1}else{eb=((fd|0)==1)+(j+160+(x<<2))|0;a[eb]=d[eb]|Sc;gd=(ed|0)==1|0}eb=fd+x|0;if((fd|0)>0){hd=x}else{break}while(1){db=j+128+(hd<<2)+gd|0;a[db]=d[db]|cb;hd=hd+1|0;if((hd|0)>=(eb|0)){break l}}}eb=(k|0)==1|0;db=1<<k;Tc=c[838264+(k<<2)>>2]|0;Vc=Tc&Sc;Lc=k>>>0>1>>>0;do{if(Lc){_b=ed-1|0;if((_b^ed|0)!=1){jb=481;break}q=Tc&(cb<<_b)-cb;_b=Vc-q|0;Uc=fd+x|0;if((fd|0)>0){id=x}else{jb=488;break}while(1){Ac=j+128+(id<<2)|0;a[Ac]=d[Ac]|q;Ac=j+128+(id<<2)+1|0;a[Ac]=d[Ac]|_b;Ac=id+1|0;if((Ac|0)<(Uc|0)){id=Ac}else{jb=486;break}}}else{jb=481}}while(0);do{if((jb|0)==481){Tc=fd+x|0;if((fd|0)>0){jd=x}else{jb=486;break}while(1){Uc=j+128+(jd<<2)+eb|0;a[Uc]=d[Uc]|Vc;Uc=jd+1|0;if((Uc|0)<(Tc|0)){jd=Uc}else{jb=486;break}}}}while(0);if((jb|0)==486){if(Lc){jb=488}}do{if((jb|0)==488){Vc=fd-1|0;if((Vc^fd|0)!=1){break}Tc=x-1+fd|0;if((Tc|0)>(x|0)){Uc=x;while(1){_b=j+160+(Uc<<2)|0;a[_b]=d[_b]|Sc;_b=Uc+db|0;if((_b|0)<(Tc|0)){Uc=_b}else{kd=_b;break}}}else{kd=x}if((kd-x|0)!=(Vc|0)){break l}Uc=j+160+(kd<<2)+1|0;a[Uc]=d[Uc]|Sc;break l}}while(0);Lc=fd+x|0;if((fd|0)>0){ld=x}else{break}do{Uc=j+160+(ld<<2)+eb|0;a[Uc]=d[Uc]|Sc;ld=ld+db|0;}while((ld|0)<(Lc|0))}}while(0);x=f+(l+1410)|0;if((a[x]|0)!=0){break}cb=a[f+1409|0]|0;k=cb<<24>>24;if(cb<<24>>24>0){cb=l>>>(k+3>>2>>>0);Wc=9-k|0;md=(cb|0)>(Wc|0)?Wc:cb}else{md=l}cb=(md|0)>1?md:1;a[x]=cb;a[f+(l+1474)|0]=(l<<1)+4+cb}}while(0);if((c[E>>2]|0)!=2){i=o;return}c[s>>2]=(c[s>>2]|0)+68;s=ca(w,v)|0;E=f+35864|0;c[E>>2]=(c[E>>2]|0)+(s<<6<<1);E=s<<4;md=f+35876|0;c[md>>2]=(c[md>>2]|0)+(E<<1);md=f+35880|0;c[md>>2]=(c[md>>2]|0)+(E<<1);E=ca(v<<2,w)|0;w=f+35896|0;c[w>>2]=(c[w>>2]|0)+E;E=f+35900|0;c[E>>2]=(c[E>>2]|0)+s;E=f+35904|0;c[E>>2]=(c[E>>2]|0)+s;i=o;return}function ybb(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0;f=e;g=c[e+1084>>2]|0;h=c[e+1100>>2]|0;i=c[e+1108>>2]|0;j=c[e+1104>>2]|0;k=g+48|0;l=c[k>>2]|0;m=d[1584880+l|0]|0;n=(c[e+1808>>2]|0)-i|0;o=d[1898778+(l<<1)|0]|0;p=n>>>0>o>>>0?o:n;n=(c[e+1804>>2]|0)-h|0;o=d[1898779+(l<<1)|0]|0;l=n>>>0>o>>>0?o:n;n=(h|0)>0;o=i>>>0>(c[e+1788>>2]|0)>>>0;q=e+1550|0;a:do{if((a[q]|0)==0){a[g|0]=0}else{do{if((a[e+1137|0]|0)==0){if((a[e+1144|0]|0)!=0){break}b:do{if((a[e+1553|0]|0)!=0){r=e+1052|0;do{if((a[e+1551|0]|0)==0){s=c[r>>2]|0;t=c[e+1056>>2]|0;u=c[e+1068>>2]|0}else{v=d[e+((d[(c[e+30124>>2]|0)+i|0]|0)+16622+(d[e+(j+30056)|0]|0))|0]|0;w=r;x=c[w>>2]|0;z=d[1252840+x|0]|0;A=e+1056|0;B=c[A>>2]|0;C=e+1068|0;D=c[C>>2]|0;E=x<<z;c[w>>2]=E;x=D<<z;D=B+z|0;do{if((D|0)>-1){z=e+1060|0;B=c[z>>2]|0;if(!(B>>>0<(c[e+1064>>2]|0)>>>0)){F=x;G=D;break}c[z>>2]=B+2;z=B;F=((he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<D|x;G=D-16|0}else{F=x;G=D}}while(0);c[A>>2]=G;D=((ca(E-1|0,v)|0)>>8)+1|0;x=D<<16;if(F>>>0<x>>>0){c[w>>2]=D;c[C>>2]=F;s=D;t=G;u=F;break}else{c[w>>2]=E-D;c[C>>2]=F-x;break b}}}while(0);r=e+1052|0;x=e+1056|0;D=e+1068|0;z=e+1060|0;B=e+1064|0;H=0;I=s;J=t;K=u;while(1){L=a[e+(H+16615)|0]|0;M=d[1252840+I|0]|0;N=I<<M;c[r>>2]=N;O=K<<M;P=M+J|0;do{if((P|0)>-1){M=c[z>>2]|0;if(!(M>>>0<(c[B>>2]|0)>>>0)){Q=O;R=P;break}c[z>>2]=M+2;S=M;Q=((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)<<P|O;R=P-16|0}else{Q=O;R=P}}while(0);c[x>>2]=R;P=((ca(N-1|0,L&255)|0)>>8)+1|0;O=P<<16;C=Q>>>0>=O>>>0;E=C?N-P|0:P;c[r>>2]=E;P=Q-(C?O:0)|0;c[D>>2]=P;T=a[(C&1)+(204296+(H<<1))|0]|0;if(T<<24>>24>0){H=T<<24>>24;I=E;J=R;K=P}else{break}}a[g|0]=-T;mrc((c[e+30124>>2]|0)+i|0,0,p|0)|0;mrc(e+(j+30056)|0,0,l|0)|0;break a}}while(0);K=c[e+1400>>2]|0;if((c[e+1096>>2]|0)==0){M5a(e+1384|0,h>>3,0)}do{if((l|0)>0){J=e+1796|0;if((p|0)>0){U=8;V=0}else{W=8;break}while(1){I=ca(V+h<<3,c[J>>2]|0)|0;H=0;X=U;do{D=d[K+(H+i+I)|0]|0;X=(X|0)>(D|0)?D:X;H=H+1|0;}while((H|0)<(p|0));H=V+1|0;if((H|0)<(l|0)){U=X;V=H}else{break}}W=X&255}else{W=8}}while(0);a[g|0]=W;mrc((c[e+30124>>2]|0)+i|0,1,p|0)|0;mrc(e+(j+30056)|0,1,l|0)|0;break a}}while(0);K=e+1052|0;J=e+1056|0;H=e+1068|0;I=e+1060|0;N=e+1064|0;L=0;D=c[K>>2]|0;r=c[J>>2]|0;x=c[H>>2]|0;while(1){z=a[e+(L+16615)|0]|0;B=d[1252840+D|0]|0;P=D<<B;c[K>>2]=P;E=x<<B;C=B+r|0;do{if((C|0)>-1){B=c[I>>2]|0;if(!(B>>>0<(c[N>>2]|0)>>>0)){Y=E;Z=C;break}c[I>>2]=B+2;O=B;Y=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<C|E;Z=C-16|0}else{Y=E;Z=C}}while(0);c[J>>2]=Z;C=((ca(P-1|0,z&255)|0)>>8)+1|0;E=C<<16;O=Y>>>0>=E>>>0;B=O?P-C|0:C;c[K>>2]=B;C=Y-(O?E:0)|0;c[H>>2]=C;_=a[(O&1)+(204296+(L<<1))|0]|0;if(_<<24>>24>0){L=_<<24>>24;D=B;r=Z;x=C}else{break}}a[g|0]=-_}}while(0);do{if((a[q]|0)==0){$=48}else{do{if((a[e+1553|0]|0)==0){if((a[e+1137|0]|0)!=0){$=39;break}if((a[e+1144|0]|0)!=0){$=39}}else{$=39}}while(0);do{if(($|0)==39){_=c[e+1796>>2]|0;Z=(ca(h<<3,_)|0)+i|0;Y=(c[e+1376>>2]|0)+Z|0;Z=_<<3;_=a[g|0]|0;W=_&255;if((p|0)==1){X=Y;V=l;while(1){a[X]=_;U=V-1|0;if((U|0)==0){break}else{X=X+Z|0;V=U}}}else if((p|0)==2){V=(W*257|0)&65535;X=Y;_=l;while(1){b[X>>1]=V;P=_-1|0;if((P|0)==0){break}else{X=X+Z|0;_=P}}}else if((p|0)==4){_=ca(W,16843009)|0;X=Y;V=l;while(1){c[X>>2]=_;P=V-1|0;if((P|0)==0){break}else{X=X+Z|0;V=P}}}else if((p|0)==8){V=ca(W,16843009)|0;X=Y;_=l;while(1){c[X>>2]=V;c[X+4>>2]=V;P=_-1|0;if((P|0)==0){break}else{X=X+Z|0;_=P}}}else{break}}}while(0);if((a[q]|0)==0){$=48;break}_=(a[e+1554+((d[g|0]|0)*26|0)+3|0]|0)!=0;Z=g+10|0;a[Z]=_&1;if(_){aa=Z}else{ba=Z;$=50}}}while(0);if(($|0)==48){q=g+10|0;a[q]=0;ba=q;$=50}if(($|0)==50){q=(d[(c[e+30116>>2]|0)+i|0]|0)+(d[e+(j+30040)|0]|0)|0;Z=a[e+(q+10159)|0]|0;_=e+1052|0;X=c[_>>2]|0;V=d[1252840+X|0]|0;Y=e+1056|0;W=c[Y>>2]|0;P=e+1068|0;z=c[P>>2]|0;U=X<<V;c[_>>2]=U;X=z<<V;z=W+V|0;do{if((z|0)>-1){V=e+1060|0;W=c[V>>2]|0;if(!(W>>>0<(c[e+1064>>2]|0)>>>0)){da=X;ea=z;break}c[V>>2]=W+2;V=W;da=((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<z|X;ea=z-16|0}else{da=X;ea=z}}while(0);c[Y>>2]=ea;ea=((ca(U-1|0,Z&255)|0)>>8)+1|0;Z=ea<<16;Y=da>>>0>=Z>>>0;c[_>>2]=Y?U-ea|0:ea;c[P>>2]=da-(Y?Z:0);a[ba]=Y&1;Z=e+17612+(q<<3)+((Y&1)<<2)|0;c[Z>>2]=(c[Z>>2]|0)+1;aa=ba}ba=e+1137|0;do{if((a[ba]|0)==0){if((a[e+1144|0]|0)!=0){$=56;break}Z=d[g|0]|0;Y=e+1554|0;if((a[Y+(Z*26|0)+2|0]|0)==0){do{if(n&o){q=(d[e+(j+30064)|0]|0)+(d[(c[e+30128>>2]|0)+i|0]|0)|0;fa=((q|0)==2)+q|0}else{if(n){fa=d[(c[e+30128>>2]|0)+i|0]<<1;break}if(!o){fa=0;break}fa=d[e+(j+30064)|0]<<1}}while(0);q=a[e+(fa+10123)|0]|0;da=e+1052|0;P=c[da>>2]|0;ea=d[1252840+P|0]|0;U=e+1056|0;_=c[U>>2]|0;z=e+1068|0;X=c[z>>2]|0;V=P<<ea;c[da>>2]=V;P=X<<ea;X=_+ea|0;do{if((X|0)>-1){ea=e+1060|0;_=c[ea>>2]|0;if(!(_>>>0<(c[e+1064>>2]|0)>>>0)){ga=P;ha=X;break}c[ea>>2]=_+2;ea=_;ga=((he((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<X|P;ha=X-16|0}else{ga=P;ha=X}}while(0);c[U>>2]=ha;X=((ca(V-1|0,q&255)|0)>>8)+1|0;P=X<<16;ea=ga>>>0>=P>>>0;c[da>>2]=ea?V-X|0:X;c[z>>2]=ga-(ea?P:0);P=e+17348+(fa<<3)+((ea&1)<<2)|0;c[P>>2]=(c[P>>2]|0)+1;P=ea&1^1;a[g+1|0]=P;ia=P}else{P=(a[Y+(Z*26|0)+4|0]|0)==0|0;a[g+1|0]=P;ia=P}P=g+1|0;if(!(ia<<24>>24==0)){ja=P;$=72;break}if((a[aa]|0)==0){ja=P;$=72;break}ka=c[e+29836>>2]|0;la=P;$=113}else{$=56}}while(0);if(($|0)==56){a[g+1|0]=1;ja=g+1|0;$=72}do{if(($|0)==72){ia=c[e+29836>>2]|0;if((ia|0)!=4){ka=ia;la=ja;$=113;break}do{if(n){ia=(a[(c[e+30116>>2]|0)+i|0]|0)!=0;if(!o){if(ia){ma=1;break}ma=d[(c[e+30120>>2]|0)+i|0]<<1>>>0>m>>>0|0;break}if(ia){na=m}else{na=d[(c[e+30120>>2]|0)+i|0]|0}if((a[e+(j+30040)|0]|0)==0){oa=d[e+(j+30048)|0]|0}else{oa=m}ma=(oa+na|0)>>>0>m>>>0|0}else{if(!o){ma=1;break}if((a[e+(j+30040)|0]|0)!=0){ma=1;break}ma=d[e+(j+30048)|0]<<1>>>0>m>>>0|0}}while(0);if((m|0)==3){Z=e+10147|0;Y=a[Z+(ma*3|0)|0]|0;z=e+1052|0;V=c[z>>2]|0;da=d[1252840+V|0]|0;q=e+1056|0;U=c[q>>2]|0;ia=e+1068|0;fa=c[ia>>2]|0;ga=V<<da;c[z>>2]=ga;V=fa<<da;fa=U+da|0;do{if((fa|0)>-1){da=e+1060|0;U=c[da>>2]|0;if(!(U>>>0<(c[e+1064>>2]|0)>>>0)){pa=V;qa=fa;break}c[da>>2]=U+2;da=U;pa=((he((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|V;qa=fa-16|0}else{pa=V;qa=fa}}while(0);c[q>>2]=qa;fa=((ca(ga-1|0,Y&255)|0)>>8)+1|0;V=fa<<16;da=pa>>>0>=V>>>0;U=da&1;ha=da?ga-fa|0:fa;c[z>>2]=ha;fa=pa-(da?V:0)|0;c[ia>>2]=fa;V=g+52|0;c[V>>2]=U;do{if(da){P=a[Z+(ma*3|0)+1|0]|0;ea=d[1252840+ha|0]|0;X=ha<<ea;c[z>>2]=X;_=fa<<ea;W=qa+ea|0;do{if((W|0)>-1){ea=e+1060|0;T=c[ea>>2]|0;if(!(T>>>0<(c[e+1064>>2]|0)>>>0)){ra=_;sa=W;break}c[ea>>2]=T+2;ea=T;ra=((he((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<W|_;sa=W-16|0}else{ra=_;sa=W}}while(0);c[q>>2]=sa;W=((ca(X-1|0,P&255)|0)>>8)+1|0;_=W<<16;ea=ra>>>0>=_>>>0;T=ea?X-W|0:W;c[z>>2]=T;W=ra-(ea?_:0)|0;c[ia>>2]=W;_=(ea&1)+U|0;c[V>>2]=_;if((_|0)!=2){ta=_;break}_=a[Z+(ma*3|0)+2|0]|0;ea=d[1252840+T|0]|0;R=T<<ea;c[z>>2]=R;T=W<<ea;W=sa+ea|0;do{if((W|0)>-1){ea=e+1060|0;Q=c[ea>>2]|0;if(!(Q>>>0<(c[e+1064>>2]|0)>>>0)){ua=T;va=W;break}c[ea>>2]=Q+2;ea=Q;ua=((he((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<W|T;va=W-16|0}else{ua=T;va=W}}while(0);c[q>>2]=va;W=((ca(R-1|0,_&255)|0)>>8)+1|0;T=W<<16;X=ua>>>0>=T>>>0;c[z>>2]=X?R-W|0:W;c[ia>>2]=ua-(X?T:0);T=X&1|2;c[V>>2]=T;ta=T}else{ta=U}}while(0);U=e+17540+(ma<<4)+(ta<<2)|0;c[U>>2]=(c[U>>2]|0)+1;wa=ja;break}else if((m|0)==2){U=e+10153|0;V=a[U+(ma<<1)|0]|0;ia=e+1052|0;z=c[ia>>2]|0;q=d[1252840+z|0]|0;Z=e+1056|0;fa=c[Z>>2]|0;ha=e+1068|0;da=c[ha>>2]|0;ga=z<<q;c[ia>>2]=ga;z=da<<q;da=fa+q|0;do{if((da|0)>-1){q=e+1060|0;fa=c[q>>2]|0;if(!(fa>>>0<(c[e+1064>>2]|0)>>>0)){xa=z;ya=da;break}c[q>>2]=fa+2;q=fa;xa=((he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<da|z;ya=da-16|0}else{xa=z;ya=da}}while(0);c[Z>>2]=ya;da=((ca(ga-1|0,V&255)|0)>>8)+1|0;z=da<<16;q=xa>>>0>=z>>>0;fa=q&1;Y=q?ga-da|0:da;c[ia>>2]=Y;da=xa-(q?z:0)|0;c[ha>>2]=da;z=g+52|0;c[z>>2]=fa;if(q){q=a[U+(ma<<1)+1|0]|0;T=d[1252840+Y|0]|0;X=Y<<T;c[ia>>2]=X;Y=da<<T;da=ya+T|0;do{if((da|0)>-1){T=e+1060|0;W=c[T>>2]|0;if(!(W>>>0<(c[e+1064>>2]|0)>>>0)){za=Y;Aa=da;break}c[T>>2]=W+2;T=W;za=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<da|Y;Aa=da-16|0}else{za=Y;Aa=da}}while(0);c[Z>>2]=Aa;da=((ca(X-1|0,q&255)|0)>>8)+1|0;Y=da<<16;U=za>>>0>=Y>>>0;c[ia>>2]=U?X-da|0:da;c[ha>>2]=za-(U?Y:0);Y=(U&1)+fa|0;c[z>>2]=Y;Ba=Y}else{Ba=fa}Y=e+17572+(ma*12|0)+(Ba<<2)|0;c[Y>>2]=(c[Y>>2]|0)+1;wa=ja;break}else if((m|0)==1){Y=a[e+(ma+10157)|0]|0;U=e+1052|0;da=c[U>>2]|0;ga=d[1252840+da|0]|0;V=e+1056|0;T=c[V>>2]|0;W=e+1068|0;P=c[W>>2]|0;ea=da<<ga;c[U>>2]=ea;da=P<<ga;P=T+ga|0;do{if((P|0)>-1){ga=e+1060|0;T=c[ga>>2]|0;if(!(T>>>0<(c[e+1064>>2]|0)>>>0)){Ca=da;Da=P;break}c[ga>>2]=T+2;ga=T;Ca=((he((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)<<P|da;Da=P-16|0}else{Ca=da;Da=P}}while(0);c[V>>2]=Da;P=((ca(ea-1|0,Y&255)|0)>>8)+1|0;da=P<<16;fa=Ca>>>0>=da>>>0;z=fa&1;c[U>>2]=fa?ea-P|0:P;c[W>>2]=Ca-(fa?da:0);c[g+52>>2]=z;da=e+17596+(ma<<3)+(z<<2)|0;c[da>>2]=(c[da>>2]|0)+1;wa=ja;break}else if((m|0)==0){c[g+52>>2]=0;wa=ja;break}else{wa=ja;break}}}while(0);if(($|0)==113){c[g+52>>2]=m>>>0>ka>>>0?ka:m;wa=la}do{if((a[ba]|0)==0){if((a[e+1144|0]|0)!=0){$=116;break}if((a[wa]|0)!=0){a[g+2|0]=0;la=c[k>>2]|0;c:do{if(la>>>0>9>>>0){m=e+1052|0;ka=e+1056|0;ja=e+1068|0;ma=e+1060|0;Ca=e+1064|0;Da=0;Ba=c[m>>2]|0;za=c[ka>>2]|0;Aa=c[ja>>2]|0;while(1){ya=a[e+(Da+9968)|0]|0;xa=d[1252840+Ba|0]|0;ta=Ba<<xa;c[m>>2]=ta;ua=Aa<<xa;va=xa+za|0;do{if((va|0)>-1){xa=c[ma>>2]|0;if(!(xa>>>0<(c[Ca>>2]|0)>>>0)){Ea=ua;Fa=va;break}c[ma>>2]=xa+2;sa=xa;Ea=((he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<va|ua;Fa=va-16|0}else{Ea=ua;Fa=va}}while(0);c[ka>>2]=Fa;va=((ca(ta-1|0,ya&255)|0)>>8)+1|0;ua=va<<16;sa=Ea>>>0>=ua>>>0;xa=sa?ta-va|0:va;c[m>>2]=xa;va=Ea-(sa?ua:0)|0;c[ja>>2]=va;ua=a[(sa&1)+(215376+(Da<<1))|0]|0;Ga=ua<<24>>24;if(ua<<24>>24>0){Da=Ga;Ba=xa;za=Fa;Aa=va}else{break}}Aa=-Ga|0;za=g+5|0;a[za]=Aa;Ba=e+16628|0;Da=Ba+((Aa&255)<<2)|0;c[Da>>2]=(c[Da>>2]|0)+1;Da=(la|0)==10;do{if(Da){a[g+6|0]=a[za]|0}else{Aa=0;R=c[m>>2]|0;_=c[ka>>2]|0;va=c[ja>>2]|0;while(1){xa=a[e+(Aa+9968)|0]|0;ua=d[1252840+R|0]|0;sa=R<<ua;c[m>>2]=sa;ra=va<<ua;qa=ua+_|0;do{if((qa|0)>-1){ua=c[ma>>2]|0;if(!(ua>>>0<(c[Ca>>2]|0)>>>0)){Ha=ra;Ia=qa;break}c[ma>>2]=ua+2;pa=ua;Ha=((he((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<qa|ra;Ia=qa-16|0}else{Ha=ra;Ia=qa}}while(0);c[ka>>2]=Ia;qa=((ca(sa-1|0,xa&255)|0)>>8)+1|0;ra=qa<<16;pa=Ha>>>0>=ra>>>0;ua=pa?sa-qa|0:qa;c[m>>2]=ua;qa=Ha-(pa?ra:0)|0;c[ja>>2]=qa;ra=a[(pa&1)+(215376+(Aa<<1))|0]|0;Ja=ra<<24>>24;if(ra<<24>>24>0){Aa=Ja;R=ua;_=Ia;va=qa}else{break}}va=-Ja|0;a[g+6|0]=va;_=Ba+((va&255)<<2)|0;c[_>>2]=(c[_>>2]|0)+1;if((la|0)!=11){break}a[g+7|0]=a[za]|0;a[g+8|0]=a[g+6|0]|0;break c}}while(0);za=0;_=c[m>>2]|0;va=c[ka>>2]|0;R=c[ja>>2]|0;while(1){Aa=a[e+(za+9968)|0]|0;ta=d[1252840+_|0]|0;ya=_<<ta;c[m>>2]=ya;qa=R<<ta;ua=ta+va|0;do{if((ua|0)>-1){ta=c[ma>>2]|0;if(!(ta>>>0<(c[Ca>>2]|0)>>>0)){Ka=qa;La=ua;break}c[ma>>2]=ta+2;ra=ta;Ka=((he((d[ra]|d[ra+1|0]<<8)<<16>>16|0)|0)&65535)<<ua|qa;La=ua-16|0}else{Ka=qa;La=ua}}while(0);c[ka>>2]=La;ua=((ca(ya-1|0,Aa&255)|0)>>8)+1|0;qa=ua<<16;ra=Ka>>>0>=qa>>>0;ta=ra?ya-ua|0:ua;c[m>>2]=ta;ua=Ka-(ra?qa:0)|0;c[ja>>2]=ua;qa=a[(ra&1)+(215376+(za<<1))|0]|0;Ma=qa<<24>>24;if(qa<<24>>24>0){za=Ma;_=ta;va=La;R=ua}else{break}}R=-Ma|0;va=g+7|0;a[va]=R;_=Ba+((R&255)<<2)|0;c[_>>2]=(c[_>>2]|0)+1;if(Da){a[g+8|0]=a[va]|0;break}va=0;_=c[m>>2]|0;R=c[ka>>2]|0;za=c[ja>>2]|0;while(1){ua=a[e+(va+9968)|0]|0;ta=d[1252840+_|0]|0;qa=_<<ta;c[m>>2]=qa;ra=za<<ta;pa=ta+R|0;do{if((pa|0)>-1){ta=c[ma>>2]|0;if(!(ta>>>0<(c[Ca>>2]|0)>>>0)){Na=ra;Oa=pa;break}c[ma>>2]=ta+2;na=ta;Na=((he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|ra;Oa=pa-16|0}else{Na=ra;Oa=pa}}while(0);c[ka>>2]=Oa;pa=((ca(qa-1|0,ua&255)|0)>>8)+1|0;ra=pa<<16;ya=Na>>>0>=ra>>>0;Aa=ya?qa-pa|0:pa;c[m>>2]=Aa;pa=Na-(ya?ra:0)|0;c[ja>>2]=pa;ra=a[(ya&1)+(215376+(va<<1))|0]|0;Pa=ra<<24>>24;if(ra<<24>>24>0){va=Pa;_=Aa;R=Oa;za=pa}else{break}}za=-Pa|0;a[g+8|0]=za;R=Ba+((za&255)<<2)|0;c[R>>2]=(c[R>>2]|0)+1}else{R=d[1584848+la|0]|0;za=e+9968|0;_=e+1052|0;va=e+1056|0;ja=e+1068|0;m=e+1060|0;ka=e+1064|0;ma=0;Ca=c[_>>2]|0;Da=c[va>>2]|0;pa=c[ja>>2]|0;while(1){Aa=a[za+(R*9|0)+ma|0]|0;ra=d[1252840+Ca|0]|0;ya=Ca<<ra;c[_>>2]=ya;na=pa<<ra;ta=ra+Da|0;do{if((ta|0)>-1){ra=c[m>>2]|0;if(!(ra>>>0<(c[ka>>2]|0)>>>0)){Qa=na;Ra=ta;break}c[m>>2]=ra+2;oa=ra;Qa=((he((d[oa]|d[oa+1|0]<<8)<<16>>16|0)|0)&65535)<<ta|na;Ra=ta-16|0}else{Qa=na;Ra=ta}}while(0);c[va>>2]=Ra;ta=((ca(ya-1|0,Aa&255)|0)>>8)+1|0;na=ta<<16;qa=Qa>>>0>=na>>>0;ua=qa?ya-ta|0:ta;c[_>>2]=ua;ta=Qa-(qa?na:0)|0;c[ja>>2]=ta;Sa=a[(qa&1)+(215376+(ma<<1))|0]|0;if(Sa<<24>>24>0){ma=Sa<<24>>24;Ca=ua;Da=Ra;pa=ta}else{break}}pa=-Sa&255;Da=e+16628+(R*40|0)+((pa&255)<<2)|0;mrc(g+5|0,pa|0,4)|0;c[Da>>2]=(c[Da>>2]|0)+1}}while(0);la=g+8|0;W=d[la]|0;ea=e+10004|0;U=e+1052|0;Y=e+1056|0;V=e+1068|0;Da=e+1060|0;pa=e+1064|0;Ca=0;ma=c[U>>2]|0;ja=c[Y>>2]|0;_=c[V>>2]|0;while(1){va=a[ea+(W*9|0)+Ca|0]|0;m=d[1252840+ma|0]|0;ka=ma<<m;c[U>>2]=ka;za=_<<m;Ba=m+ja|0;do{if((Ba|0)>-1){m=c[Da>>2]|0;if(!(m>>>0<(c[pa>>2]|0)>>>0)){Ta=za;Ua=Ba;break}c[Da>>2]=m+2;ta=m;Ta=((he((d[ta]|d[ta+1|0]<<8)<<16>>16|0)|0)&65535)<<Ba|za;Ua=Ba-16|0}else{Ta=za;Ua=Ba}}while(0);c[Y>>2]=Ua;Ba=((ca(ka-1|0,va&255)|0)>>8)+1|0;za=Ba<<16;R=Ta>>>0>=za>>>0;ta=R?ka-Ba|0:Ba;c[U>>2]=ta;Ba=Ta-(R?za:0)|0;c[V>>2]=Ba;za=a[(R&1)+(215376+(Ca<<1))|0]|0;Va=za<<24>>24;if(za<<24>>24>0){Ca=Va;ma=ta;ja=Ua;_=Ba}else{break}}_=-Va|0;a[g+9|0]=_;ja=e+16788+((d[la]|0)*40|0)+((_&255)<<2)|0;c[ja>>2]=(c[ja>>2]|0)+1;Wa=0;Xa=0;break}ja=g|0;_=d[ja]|0;ma=e+1554|0;do{if((a[ma+(_*26|0)+2|0]|0)==0){Ca=c[e+29840>>2]|0;if((Ca|0)==2){d:do{if(n){V=a[(c[e+30132>>2]|0)+i|0]|0;U=V<<24>>24!=0;if(!o){if(U){Ya=3;break}if((a[(c[e+30128>>2]|0)+i|0]|0)!=0){Ya=0;break}Ya=(a[(c[e+30136>>2]|0)+i|0]|0)==(a[e+1153|0]|0)|0;break}do{if(U){if((a[e+(j+30072)|0]|0)!=0){Ya=4;break d}if(V<<24>>24==0){break}if((a[e+(j+30064)|0]|0)!=0){Ya=3;break d}Ya=(a[e+(j+30080)|0]|0)==(a[e+1153|0]|0)|2;break d}}while(0);V=(a[(c[e+30128>>2]|0)+i|0]|0)==0;if((a[e+(j+30072)|0]|0)!=0){if(!V){Ya=3;break}Ya=(a[(c[e+30136>>2]|0)+i|0]|0)==(a[e+1153|0]|0)|2;break}if(V){Za=(a[(c[e+30136>>2]|0)+i|0]|0)==(a[e+1153|0]|0)|0}else{Za=0}if((a[e+(j+30064)|0]|0)==0){_a=(a[e+(h&7|30080)|0]|0)==(a[e+1153|0]|0)|0}else{_a=0}Ya=_a^Za}else{if(!o){Ya=1;break}if((a[e+(j+30072)|0]|0)!=0){Ya=3;break}if((a[e+(j+30064)|0]|0)!=0){Ya=0;break}Ya=(a[e+(j+30080)|0]|0)==(a[e+1153|0]|0)|0}}while(0);ka=a[e+(Ya+10127)|0]|0;va=e+1052|0;V=c[va>>2]|0;U=d[1252840+V|0]|0;ya=e+1056|0;Aa=c[ya>>2]|0;Y=e+1068|0;Da=c[Y>>2]|0;pa=V<<U;c[va>>2]=pa;V=Da<<U;Da=Aa+U|0;do{if((Da|0)>-1){U=e+1060|0;Aa=c[U>>2]|0;if(!(Aa>>>0<(c[e+1064>>2]|0)>>>0)){$a=V;ab=Da;break}c[U>>2]=Aa+2;U=Aa;$a=((he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|V;ab=Da-16|0}else{$a=V;ab=Da}}while(0);c[ya>>2]=ab;Da=((ca(pa-1|0,ka&255)|0)>>8)+1|0;V=Da<<16;U=$a>>>0>=V>>>0;c[va>>2]=U?pa-Da|0:Da;c[Y>>2]=$a-(U?V:0);V=g+2|0;a[V]=U&1;Da=e+17380+(Ya<<3)+((U&1)<<2)|0;c[Da>>2]=(c[Da>>2]|0)+1;bb=a[V]|0}else{V=(Ca|0)==1|0;a[g+2|0]=V;bb=V}if(!(bb<<24>>24==0)){V=e+1153|0;Da=a[V]|0;U=a[e+((Da&255)+1160)|0]|0;Aa=U<<24>>24==0|0;a[(U&255)+(g+3)|0]=Da;do{if(n){Da=(a[(c[e+30128>>2]|0)+i|0]|0)!=0;if(!o){if(Da){cb=2;break}U=(a[(c[e+30136>>2]|0)+i|0]|0)!=(a[e+1164|0]|0)|0;if((a[(c[e+30132>>2]|0)+i|0]|0)==0){cb=-U&3;break}else{cb=U<<2;break}}U=(a[e+(j+30064)|0]|0)!=0;if(Da){if(U){cb=2;break}cb=((a[e+(j+30080)|0]|0)!=(a[e+1164|0]|0))<<1|1;break}if(U){cb=((a[(c[e+30136>>2]|0)+i|0]|0)!=(a[e+1164|0]|0))<<1|1;break}U=a[e+(j+30080)|0]|0;Da=a[(c[e+30136>>2]|0)+i|0]|0;W=U<<24>>24==Da<<24>>24;if(W){if(U<<24>>24==(a[e+1164|0]|0)){cb=0;break}}ea=(a[(c[e+30132>>2]|0)+i|0]|0)==0;if((a[e+(j+30072)|0]|0)!=0){if(!ea){cb=W?4:2;break}Ba=a[e+1164|0]|0;ta=U<<24>>24!=Ba<<24>>24;za=Da<<24>>24==Ba<<24>>24;if(!za){cb=ta|za?4:1;break}cb=ta?2:4;break}if(!ea){ea=a[e+1164|0]|0;ta=Da<<24>>24!=ea<<24>>24;za=U<<24>>24==ea<<24>>24;if(!za){cb=ta|za?4:1;break}cb=ta?2:4;break}ta=a[V]|0;if(Da<<24>>24==ta<<24>>24){if(U<<24>>24==(a[e+1163|0]|0)){cb=4;break}}if(U<<24>>24==ta<<24>>24){if(Da<<24>>24==(a[e+1163|0]|0)){cb=4;break}}cb=W?3:1}else{if(!o){cb=2;break}if((a[e+(j+30064)|0]|0)!=0){cb=2;break}W=(a[e+(j+30080)|0]|0)!=(a[e+1164|0]|0)|0;if((a[e+(j+30072)|0]|0)==0){cb=-W&3;break}else{cb=W<<2;break}}}while(0);V=a[e+(cb+10142)|0]|0;Ca=e+1052|0;Y=c[Ca>>2]|0;pa=d[1252840+Y|0]|0;va=e+1056|0;ka=c[va>>2]|0;ya=e+1068|0;W=c[ya>>2]|0;Da=Y<<pa;c[Ca>>2]=Da;Y=W<<pa;W=ka+pa|0;do{if((W|0)>-1){pa=e+1060|0;ka=c[pa>>2]|0;if(!(ka>>>0<(c[e+1064>>2]|0)>>>0)){db=Y;eb=W;break}c[pa>>2]=ka+2;pa=ka;db=((he((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<W|Y;eb=W-16|0}else{db=Y;eb=W}}while(0);c[va>>2]=eb;W=((ca(Da-1|0,V&255)|0)>>8)+1|0;Y=W<<16;pa=db>>>0>=Y>>>0;c[Ca>>2]=pa?Da-W|0:W;c[ya>>2]=db-(pa?Y:0);a[g+3+Aa|0]=a[e+(pa?1164:1163)|0]|0;Y=e+17500+(cb<<3)+((pa&1)<<2)|0;c[Y>>2]=(c[Y>>2]|0)+1;break}e:do{if(n){if((a[(c[e+30128>>2]|0)+i|0]|0)!=0){$=280;break}do{if(o){if((a[e+(j+30064)|0]|0)!=0){break}Y=(a[(c[e+30132>>2]|0)+i|0]|0)!=0;if((a[e+(j+30072)|0]|0)==0){pa=(a[e+(j+30080)|0]|0)==0|0;if(!Y){fb=((a[(c[e+30136>>2]|0)+i|0]|0)==0)+pa<<1;break e}if((a[e+1153|0]|0)==0){gb=1}else{gb=(a[(c[e+30136>>2]|0)+i|0]|0)==0|0}fb=gb+(-pa&3)|0;break e}if(Y){if((a[e+1153|0]|0)==0){fb=2;break e}if((a[e+(j+30080)|0]|0)==0){fb=2;break e}fb=(a[(c[e+30136>>2]|0)+i|0]|0)!=0?1:2;break e}else{if((a[e+1153|0]|0)==0){hb=1}else{hb=(a[e+(j+30080)|0]|0)==0|0}fb=hb+(-((a[(c[e+30136>>2]|0)+i|0]|0)==0|0)&3)|0;break e}}}while(0);if((a[(c[e+30132>>2]|0)+i|0]|0)==0){fb=((a[(c[e+30136>>2]|0)+i|0]|0)==0)<<2;break}if((a[e+1153|0]|0)==0){fb=2;break}fb=(a[(c[e+30136>>2]|0)+i|0]|0)!=0?1:2}else{$=280}}while(0);do{if(($|0)==280){if(!o){fb=2;break}if((a[e+(j+30064)|0]|0)!=0){fb=2;break}if((a[e+(j+30072)|0]|0)==0){fb=((a[e+(j+30080)|0]|0)==0)<<2;break}if((a[e+1153|0]|0)==0){fb=2;break}fb=(a[e+(j+30080)|0]|0)!=0?1:2}}while(0);Aa=e+10132|0;ya=a[Aa+(fb<<1)|0]|0;Da=e+1052|0;Ca=c[Da>>2]|0;V=d[1252840+Ca|0]|0;va=e+1056|0;Y=c[va>>2]|0;pa=e+1068|0;W=c[pa>>2]|0;ka=Ca<<V;c[Da>>2]=ka;Ca=W<<V;W=Y+V|0;do{if((W|0)>-1){V=e+1060|0;Y=c[V>>2]|0;if(!(Y>>>0<(c[e+1064>>2]|0)>>>0)){ib=Ca;jb=W;break}c[V>>2]=Y+2;V=Y;ib=((he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535)<<W|Ca;jb=W-16|0}else{ib=Ca;jb=W}}while(0);c[va>>2]=jb;W=((ca(ka-1|0,ya&255)|0)>>8)+1|0;Ca=W<<16;V=ib>>>0>=Ca>>>0;c[Da>>2]=V?ka-W|0:W;c[pa>>2]=ib-(V?Ca:0);Ca=e+17420|0;W=Ca+(fb<<4)+((V&1)<<2)|0;c[W>>2]=(c[W>>2]|0)+1;if(!V){a[g+3|0]=0;break}do{if(n){if(!o){if((a[(c[e+30128>>2]|0)+i|0]|0)!=0){kb=2;break}if((a[(c[e+30132>>2]|0)+i|0]|0)==0){if((a[(c[e+30136>>2]|0)+i|0]|0)==0){kb=2;break}kb=((a[(c[e+30136>>2]|0)+i|0]|0)==1)<<2;break}else{if((a[e+1153|0]|0)==1){kb=3;break}kb=-((a[(c[e+30136>>2]|0)+i|0]|0)==1|0)&3;break}}V=(a[(c[e+30128>>2]|0)+i|0]|0)!=0;if((a[e+(j+30064)|0]|0)!=0){if(V){kb=2;break}if((a[(c[e+30132>>2]|0)+i|0]|0)==0){W=a[(c[e+30136>>2]|0)+i|0]|0;if(W<<24>>24==0){kb=3;break}kb=(W<<24>>24==1)<<2;break}else{if((a[e+1153|0]|0)==1){kb=3;break}kb=((a[(c[e+30136>>2]|0)+i|0]|0)==1)<<1|1;break}}if(V){if((a[e+(j+30072)|0]|0)==0){V=a[e+(j+30080)|0]|0;if(V<<24>>24==0){kb=3;break}kb=(V<<24>>24==1)<<2;break}else{if((a[e+1153|0]|0)==1){kb=3;break}kb=((a[e+(j+30080)|0]|0)==1)<<1|1;break}}V=(a[e+(j+30072)|0]|0)!=0;if((a[(c[e+30132>>2]|0)+i|0]|0)!=0){W=a[e+(j+30080)|0]|0;if(V){if(!(W<<24>>24==(a[(c[e+30136>>2]|0)+i|0]|0))){kb=2;break}if((a[e+1153|0]|0)==1){kb=3;break}kb=-(W<<24>>24==1|0)&3;break}if(W<<24>>24==0){if((a[e+1153|0]|0)==1){kb=3;break}kb=((a[(c[e+30136>>2]|0)+i|0]|0)==1)<<1|1;break}if((a[e+1153|0]|0)==1){lb=1}else{lb=(a[(c[e+30136>>2]|0)+i|0]|0)==1|0}kb=lb+(-(W<<24>>24==1|0)&3)|0;break}W=a[(c[e+30136>>2]|0)+i|0]|0;Y=W<<24>>24!=0;if(V){if(!Y){if((a[e+1153|0]|0)==1){kb=3;break}kb=((a[e+(j+30080)|0]|0)==1)<<1|1;break}if((a[e+1153|0]|0)==1){mb=1}else{mb=(a[e+(j+30080)|0]|0)==1|0}kb=mb+(-(W<<24>>24==1|0)&3)|0;break}else{V=a[e+(j+30080)|0]|0;ta=V<<24>>24!=0;if(!Y){if(!ta){kb=3;break}kb=(V<<24>>24==1)<<2;break}if(ta){kb=(V<<24>>24==1)+(W<<24>>24==1)<<1;break}else{kb=(W<<24>>24==1)<<2;break}}}else{if(!o){kb=2;break}if((a[e+(j+30064)|0]|0)!=0){kb=2;break}if((a[e+(j+30072)|0]|0)==0){W=a[e+(j+30080)|0]|0;if(W<<24>>24==0){kb=2;break}kb=(W<<24>>24==1)<<2;break}else{if((a[e+1153|0]|0)==1){kb=3;break}kb=-((a[e+(j+30080)|0]|0)==1|0)&3;break}}}while(0);ka=a[Aa+(kb<<1)+1|0]|0;ya=c[Da>>2]|0;W=d[1252840+ya|0]|0;V=c[va>>2]|0;ta=c[pa>>2]|0;Y=ya<<W;c[Da>>2]=Y;ya=ta<<W;ta=V+W|0;do{if((ta|0)>-1){W=e+1060|0;V=c[W>>2]|0;if(!(V>>>0<(c[e+1064>>2]|0)>>>0)){nb=ya;ob=ta;break}c[W>>2]=V+2;W=V;nb=((he((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)<<ta|ya;ob=ta-16|0}else{nb=ya;ob=ta}}while(0);c[va>>2]=ob;ta=((ca(Y-1|0,ka&255)|0)>>8)+1|0;ya=ta<<16;Aa=nb>>>0>=ya>>>0;c[Da>>2]=Aa?Y-ta|0:ta;c[pa>>2]=nb-(Aa?ya:0);ya=Ca+(kb<<4)+8+((Aa&1)<<2)|0;c[ya>>2]=(c[ya>>2]|0)+1;a[g+3|0]=Aa?2:1}else{a[g+2|0]=0;a[g+3|0]=(a[ma+(_*26|0)+4|0]|0)-1}}while(0);_=c[k>>2]|0;do{if(_>>>0<10>>>0){if((a[ma+((d[ja]|0)*26|0)+3|0]|0)!=0){la=g+5|0;y=202116108;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;break}la=d[1584864+_|0]|0;Aa=d[(d[e+(j+29872+la)|0]|0)+(1584912+((d[(c[e+30100>>2]|0)+(la+i)|0]|0)*14|0))|0]|0;la=e+10102|0;ya=e+1052|0;ta=e+1056|0;W=e+1068|0;V=e+1060|0;U=e+1064|0;za=0;ea=c[ya>>2]|0;Ba=c[ta>>2]|0;R=c[W>>2]|0;while(1){m=a[la+(Aa*3|0)+za|0]|0;ua=d[1252840+ea|0]|0;qa=ea<<ua;c[ya>>2]=qa;na=R<<ua;oa=ua+Ba|0;do{if((oa|0)>-1){ua=c[V>>2]|0;if(!(ua>>>0<(c[U>>2]|0)>>>0)){pb=na;qb=oa;break}c[V>>2]=ua+2;ra=ua;pb=((he((d[ra]|d[ra+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|na;qb=oa-16|0}else{pb=na;qb=oa}}while(0);c[ta>>2]=qb;oa=((ca(qa-1|0,m&255)|0)>>8)+1|0;na=oa<<16;ra=pb>>>0>=na>>>0;ua=ra?qa-oa|0:oa;c[ya>>2]=ua;oa=pb-(ra?na:0)|0;c[W>>2]=oa;rb=a[(ra&1)+(215480+(za<<1))|0]|0;if(rb<<24>>24>0){za=rb<<24>>24;ea=ua;Ba=qb;R=oa}else{break}}R=-rb&255;Ba=e+17236+(Aa<<4)+((R&255)-10<<2)|0;mrc(g+5|0,R|0,4)|0;c[Ba>>2]=(c[Ba>>2]|0)+1}}while(0);ja=c[e+1148>>2]|0;if((ja|0)==4){f:do{if(n){if(!((d[(c[e+30100>>2]|0)+i|0]|0)>>>0>9>>>0)){$=363;break}do{if(o){if(!((d[e+(j+29872)|0]|0)>>>0>9>>>0)){break}ma=a[e+(j+30088)|0]|0;sb=(a[(c[e+30140>>2]|0)+i|0]|0)==ma<<24>>24?ma&255:3;break f}}while(0);sb=d[(c[e+30140>>2]|0)+i|0]|0}else{$=363}}while(0);do{if(($|0)==363){if(!o){sb=3;break}if(!((d[e+(j+29872)|0]|0)>>>0>9>>>0)){sb=3;break}sb=d[e+(j+30088)|0]|0}}while(0);Aa=e+10094|0;ma=e+1052|0;Ba=e+1056|0;R=e+1068|0;ea=e+1060|0;za=e+1064|0;W=0;ya=c[ma>>2]|0;ta=c[Ba>>2]|0;V=c[R>>2]|0;while(1){U=a[Aa+(sb<<1)+W|0]|0;la=d[1252840+ya|0]|0;Ca=ya<<la;c[ma>>2]=Ca;pa=V<<la;Y=la+ta|0;do{if((Y|0)>-1){la=c[ea>>2]|0;if(!(la>>>0<(c[za>>2]|0)>>>0)){tb=pa;ub=Y;break}c[ea>>2]=la+2;Da=la;tb=((he((d[Da]|d[Da+1|0]<<8)<<16>>16|0)|0)&65535)<<Y|pa;ub=Y-16|0}else{tb=pa;ub=Y}}while(0);c[Ba>>2]=ub;Y=((ca(Ca-1|0,U&255)|0)>>8)+1|0;pa=Y<<16;Da=tb>>>0>=pa>>>0;la=Da?Ca-Y|0:Y;c[ma>>2]=la;Y=tb-(Da?pa:0)|0;c[R>>2]=Y;pa=a[(Da&1)+(218488+(W<<1))|0]|0;vb=pa<<24>>24;if(pa<<24>>24>0){W=vb;ya=la;ta=ub;V=Y}else{break}}V=-vb|0;ta=e+17188+(sb*12|0)+(V<<2)|0;c[ta>>2]=(c[ta>>2]|0)+1;c[g+12>>2]=c[218496+(V<<2)>>2];wb=V}else{c[g+12>>2]=ja;wb=0}g:do{if(_>>>0>9>>>0){V=d[(d[e+(j+29872)|0]|0)+(1584912+((d[(c[e+30100>>2]|0)+i|0]|0)*14|0))|0]|0;ta=e+10102|0;ya=e+1052|0;W=e+1056|0;R=e+1068|0;ma=e+1060|0;Ba=e+1064|0;ea=0;za=c[ya>>2]|0;Aa=c[W>>2]|0;Y=c[R>>2]|0;while(1){la=a[ta+(V*3|0)+ea|0]|0;pa=d[1252840+za|0]|0;Da=za<<pa;c[ya>>2]=Da;ka=Y<<pa;va=pa+Aa|0;do{if((va|0)>-1){pa=c[ma>>2]|0;if(!(pa>>>0<(c[Ba>>2]|0)>>>0)){xb=ka;yb=va;break}c[ma>>2]=pa+2;oa=pa;xb=((he((d[oa]|d[oa+1|0]<<8)<<16>>16|0)|0)&65535)<<va|ka;yb=va-16|0}else{xb=ka;yb=va}}while(0);c[W>>2]=yb;va=((ca(Da-1|0,la&255)|0)>>8)+1|0;ka=va<<16;qa=xb>>>0>=ka>>>0;m=qa?Da-va|0:va;c[ya>>2]=m;va=xb-(qa?ka:0)|0;c[R>>2]=va;ka=a[(qa&1)+(215480+(ea<<1))|0]|0;zb=ka<<24>>24;if(ka<<24>>24>0){ea=zb;za=m;Aa=yb;Y=va}else{break}}Y=-zb|0;Aa=g+5|0;a[Aa]=Y;za=e+17236|0;ea=za+(V<<4)+((Y&255)-10<<2)|0;c[ea>>2]=(c[ea>>2]|0)+1;ea=g+16|0;Bbb(f,ea|0,d[Aa]|0,0);do{if((c[k>>2]|0)==10){a[g+6|0]=a[Aa]|0;c[g+24>>2]=c[ea>>2];c[g+28>>2]=c[g+20>>2]}else{Y=0;Ca=c[ya>>2]|0;U=c[W>>2]|0;va=c[R>>2]|0;while(1){m=a[ta+(V*3|0)+Y|0]|0;ka=d[1252840+Ca|0]|0;qa=Ca<<ka;c[ya>>2]=qa;oa=va<<ka;pa=ka+U|0;do{if((pa|0)>-1){ka=c[ma>>2]|0;if(!(ka>>>0<(c[Ba>>2]|0)>>>0)){Ab=oa;Bb=pa;break}c[ma>>2]=ka+2;ua=ka;Ab=((he((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|oa;Bb=pa-16|0}else{Ab=oa;Bb=pa}}while(0);c[W>>2]=Bb;pa=((ca(qa-1|0,m&255)|0)>>8)+1|0;oa=pa<<16;sa=Ab>>>0>=oa>>>0;xa=sa?qa-pa|0:pa;c[ya>>2]=xa;pa=Ab-(sa?oa:0)|0;c[R>>2]=pa;oa=a[(sa&1)+(215480+(Y<<1))|0]|0;Cb=oa<<24>>24;if(oa<<24>>24>0){Y=Cb;Ca=xa;U=Bb;va=pa}else{break}}va=-Cb|0;U=g+6|0;a[U]=va;Ca=za+(V<<4)+((va&255)-10<<2)|0;c[Ca>>2]=(c[Ca>>2]|0)+1;Bbb(f,g+24|0,d[U]|0,1);if((c[k>>2]|0)!=11){break}a[g+7|0]=a[Aa]|0;c[g+32>>2]=c[ea>>2];c[g+36>>2]=c[g+20>>2];a[g+8|0]=a[g+6|0]|0;c[g+40>>2]=c[g+24>>2];c[g+44>>2]=c[g+28>>2];break g}}while(0);ea=0;Aa=c[ya>>2]|0;U=c[W>>2]|0;Ca=c[R>>2]|0;while(1){va=a[ta+(V*3|0)+ea|0]|0;Y=d[1252840+Aa|0]|0;Da=Aa<<Y;c[ya>>2]=Da;la=Ca<<Y;pa=Y+U|0;do{if((pa|0)>-1){Y=c[ma>>2]|0;if(!(Y>>>0<(c[Ba>>2]|0)>>>0)){Db=la;Eb=pa;break}c[ma>>2]=Y+2;xa=Y;Db=((he((d[xa]|d[xa+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|la;Eb=pa-16|0}else{Db=la;Eb=pa}}while(0);c[W>>2]=Eb;pa=((ca(Da-1|0,va&255)|0)>>8)+1|0;la=pa<<16;xa=Db>>>0>=la>>>0;Y=xa?Da-pa|0:pa;c[ya>>2]=Y;pa=Db-(xa?la:0)|0;c[R>>2]=pa;la=a[(xa&1)+(215480+(ea<<1))|0]|0;Fb=la<<24>>24;if(la<<24>>24>0){ea=Fb;Aa=Y;U=Eb;Ca=pa}else{break}}Ca=-Fb|0;U=g+7|0;a[U]=Ca;Aa=za+(V<<4)+((Ca&255)-10<<2)|0;c[Aa>>2]=(c[Aa>>2]|0)+1;Aa=g+32|0;Bbb(f,Aa|0,d[U]|0,2);if((c[k>>2]|0)==10){a[g+8|0]=a[U]|0;c[g+40>>2]=c[Aa>>2];c[g+44>>2]=c[g+36>>2];break}Aa=0;U=c[ya>>2]|0;Ca=c[W>>2]|0;ea=c[R>>2]|0;while(1){pa=a[ta+(V*3|0)+Aa|0]|0;Y=d[1252840+U|0]|0;la=U<<Y;c[ya>>2]=la;xa=ea<<Y;oa=Y+Ca|0;do{if((oa|0)>-1){Y=c[ma>>2]|0;if(!(Y>>>0<(c[Ba>>2]|0)>>>0)){Gb=xa;Hb=oa;break}c[ma>>2]=Y+2;sa=Y;Gb=((he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<oa|xa;Hb=oa-16|0}else{Gb=xa;Hb=oa}}while(0);c[W>>2]=Hb;oa=((ca(la-1|0,pa&255)|0)>>8)+1|0;xa=oa<<16;Da=Gb>>>0>=xa>>>0;va=Da?la-oa|0:oa;c[ya>>2]=va;oa=Gb-(Da?xa:0)|0;c[R>>2]=oa;xa=a[(Da&1)+(215480+(Aa<<1))|0]|0;Ib=xa<<24>>24;if(xa<<24>>24>0){Aa=Ib;U=va;Ca=Hb;ea=oa}else{break}}ea=-Ib|0;Ca=g+8|0;a[Ca]=ea;U=za+(V<<4)+((ea&255)-10<<2)|0;c[U>>2]=(c[U>>2]|0)+1;Bbb(f,g+40|0,d[Ca]|0,3)}else{Ca=g+16|0;Bbb(f,Ca|0,d[g+5|0]|0,-1);U=c[Ca>>2]|0;c[g+24>>2]=U;c[g+32>>2]=U;c[g+40>>2]=U;U=c[g+20>>2]|0;c[g+28>>2]=U;c[g+36>>2]=U;c[g+44>>2]=U}}while(0);if((a[g+2|0]|0)==0){Jb=0}else{Jb=d[e+((d[e+1163|0]|0)+1160)|0]|0}Wa=d[g+3+Jb|0]|0;Xa=wb}else{$=116}}while(0);if(($|0)==116){wb=i<<1;Jb=c[e+30100>>2]|0;f=Jb+wb|0;Ib=j<<1;Hb=e+(Ib+29872)|0;a[g+2|0]=0;Gb=c[k>>2]|0;Fb=d[Hb]|0;Eb=d[f]|0;Db=e+1052|0;Cb=e+1056|0;Bb=e+1068|0;Ab=e+1060|0;zb=e+1064|0;yb=0;xb=c[Db>>2]|0;sb=c[Cb>>2]|0;vb=c[Bb>>2]|0;while(1){ub=a[227256+(Eb*90|0)+(Fb*9|0)+yb|0]|0;tb=d[1252840+xb|0]|0;o=xb<<tb;c[Db>>2]=o;n=vb<<tb;rb=tb+sb|0;do{if((rb|0)>-1){tb=c[Ab>>2]|0;if(!(tb>>>0<(c[zb>>2]|0)>>>0)){Kb=n;Lb=rb;break}c[Ab>>2]=tb+2;qb=tb;Kb=((he((d[qb]|d[qb+1|0]<<8)<<16>>16|0)|0)&65535)<<rb|n;Lb=rb-16|0}else{Kb=n;Lb=rb}}while(0);c[Cb>>2]=Lb;rb=((ca(o-1|0,ub&255)|0)>>8)+1|0;n=rb<<16;qb=Kb>>>0>=n>>>0;tb=qb?o-rb|0:rb;c[Db>>2]=tb;rb=Kb-(qb?n:0)|0;c[Bb>>2]=rb;n=a[(qb&1)+(215376+(yb<<1))|0]|0;Mb=n<<24>>24;if(n<<24>>24>0){yb=Mb;xb=tb;sb=Lb;vb=rb}else{break}}vb=-Mb|0;Mb=vb&255;do{if(Gb>>>0>9>>>0){a[f]=Mb;Lb=g+5|0;a[Lb]=Mb;if((c[k>>2]|0)==10){a[g+6|0]=Mb;a[Jb+(wb|1)|0]=Mb;Nb=Mb}else{sb=vb&255;xb=Jb+(wb|1)|0;yb=d[xb]|0;Kb=0;Fb=c[Db>>2]|0;Eb=c[Cb>>2]|0;rb=c[Bb>>2]|0;while(1){tb=a[227256+(yb*90|0)+(sb*9|0)+Kb|0]|0;n=d[1252840+Fb|0]|0;qb=Fb<<n;c[Db>>2]=qb;pb=rb<<n;kb=n+Eb|0;do{if((kb|0)>-1){n=c[Ab>>2]|0;if(!(n>>>0<(c[zb>>2]|0)>>>0)){Ob=pb;Pb=kb;break}c[Ab>>2]=n+2;nb=n;Ob=((he((d[nb]|d[nb+1|0]<<8)<<16>>16|0)|0)&65535)<<kb|pb;Pb=kb-16|0}else{Ob=pb;Pb=kb}}while(0);c[Cb>>2]=Pb;kb=((ca(qb-1|0,tb&255)|0)>>8)+1|0;pb=kb<<16;V=Ob>>>0>=pb>>>0;za=V?qb-kb|0:kb;c[Db>>2]=za;kb=Ob-(V?pb:0)|0;c[Bb>>2]=kb;Qb=a[(V&1)+(215376+(Kb<<1))|0]|0;if(Qb<<24>>24>0){Kb=Qb<<24>>24;Fb=za;Eb=Pb;rb=kb}else{break}}rb=-Qb&255;a[g+6|0]=rb;a[xb]=rb;Nb=rb}a[Hb]=Nb;if((c[k>>2]|0)==11){a[g+7|0]=a[Lb]|0;rb=a[g+6|0]|0;a[g+8|0]=rb;a[Jb+(wb|1)|0]=rb;a[e+(Ib+29873)|0]=rb;break}rb=e+(Ib+29873)|0;Eb=d[rb]|0;Fb=d[f]|0;Kb=0;sb=c[Db>>2]|0;yb=c[Cb>>2]|0;o=c[Bb>>2]|0;while(1){ub=a[227256+(Fb*90|0)+(Eb*9|0)+Kb|0]|0;kb=d[1252840+sb|0]|0;za=sb<<kb;c[Db>>2]=za;V=o<<kb;pb=kb+yb|0;do{if((pb|0)>-1){kb=c[Ab>>2]|0;if(!(kb>>>0<(c[zb>>2]|0)>>>0)){Rb=V;Sb=pb;break}c[Ab>>2]=kb+2;nb=kb;Rb=((he((d[nb]|d[nb+1|0]<<8)<<16>>16|0)|0)&65535)<<pb|V;Sb=pb-16|0}else{Rb=V;Sb=pb}}while(0);c[Cb>>2]=Sb;pb=((ca(za-1|0,ub&255)|0)>>8)+1|0;V=pb<<16;qb=Rb>>>0>=V>>>0;tb=qb?za-pb|0:pb;c[Db>>2]=tb;pb=Rb-(qb?V:0)|0;c[Bb>>2]=pb;V=a[(qb&1)+(215376+(Kb<<1))|0]|0;Tb=V<<24>>24;if(V<<24>>24>0){Kb=Tb;sb=tb;yb=Sb;o=pb}else{break}}o=-Tb|0;yb=o&255;a[f]=yb;a[g+7|0]=yb;if((c[k>>2]|0)==10){a[g+8|0]=yb;a[Jb+(wb|1)|0]=yb;a[rb]=yb;break}yb=o&255;o=Jb+(wb|1)|0;sb=d[o]|0;Kb=0;Eb=c[Db>>2]|0;Fb=c[Cb>>2]|0;Lb=c[Bb>>2]|0;while(1){xb=a[227256+(sb*90|0)+(yb*9|0)+Kb|0]|0;pb=d[1252840+Eb|0]|0;tb=Eb<<pb;c[Db>>2]=tb;V=Lb<<pb;qb=pb+Fb|0;do{if((qb|0)>-1){pb=c[Ab>>2]|0;if(!(pb>>>0<(c[zb>>2]|0)>>>0)){Ub=V;Vb=qb;break}c[Ab>>2]=pb+2;nb=pb;Ub=((he((d[nb]|d[nb+1|0]<<8)<<16>>16|0)|0)&65535)<<qb|V;Vb=qb-16|0}else{Ub=V;Vb=qb}}while(0);c[Cb>>2]=Vb;qb=((ca(tb-1|0,xb&255)|0)>>8)+1|0;V=qb<<16;za=Ub>>>0>=V>>>0;ub=za?tb-qb|0:qb;c[Db>>2]=ub;qb=Ub-(za?V:0)|0;c[Bb>>2]=qb;Wb=a[(za&1)+(215376+(Kb<<1))|0]|0;if(Wb<<24>>24>0){Kb=Wb<<24>>24;Eb=ub;Fb=Vb;Lb=qb}else{break}}Lb=-Wb&255;a[g+8|0]=Lb;a[o]=Lb;a[rb]=Lb}else{Lb=g+5|0;mrc(Lb|0,Mb|0,4)|0;mrc(f|0,Mb|0,d[1898752+(Gb<<1)|0]|0)|0;mrc(Hb|0,a[Lb]|0,d[1898753+(c[k>>2]<<1)|0]|0)|0}}while(0);Hb=d[g+8|0]|0;Gb=0;Mb=c[Db>>2]|0;f=c[Cb>>2]|0;Wb=c[Bb>>2]|0;while(1){Vb=a[228160+(Hb*9|0)+Gb|0]|0;Ub=d[1252840+Mb|0]|0;wb=Mb<<Ub;c[Db>>2]=wb;Jb=Wb<<Ub;Tb=Ub+f|0;do{if((Tb|0)>-1){Ub=c[Ab>>2]|0;if(!(Ub>>>0<(c[zb>>2]|0)>>>0)){Xb=Jb;Yb=Tb;break}c[Ab>>2]=Ub+2;Sb=Ub;Xb=((he((d[Sb]|d[Sb+1|0]<<8)<<16>>16|0)|0)&65535)<<Tb|Jb;Yb=Tb-16|0}else{Xb=Jb;Yb=Tb}}while(0);c[Cb>>2]=Yb;Tb=((ca(wb-1|0,Vb&255)|0)>>8)+1|0;Jb=Tb<<16;rb=Xb>>>0>=Jb>>>0;o=rb?wb-Tb|0:Tb;c[Db>>2]=o;Tb=Xb-(rb?Jb:0)|0;c[Bb>>2]=Tb;Zb=a[(rb&1)+(215376+(Gb<<1))|0]|0;if(Zb<<24>>24>0){Gb=Zb<<24>>24;Mb=o;f=Yb;Wb=Tb}else{break}}a[g+9|0]=-Zb;Wa=0;Xa=0}Zb=d[1898778+(c[k>>2]<<1)|0]|0;do{if((Zb|0)==8){Wb=ca(d[aa]|0,16843009)|0;Yb=e+30116|0;c[(c[Yb>>2]|0)+i>>2]=Wb;f=i+4|0;c[(c[Yb>>2]|0)+f>>2]=Wb;Wb=ca(c[g+52>>2]|0,16843009)|0;Yb=e+30120|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;Wb=ca(d[1585112+(c[k>>2]|0)|0]|0,16843009)|0;Yb=e+30096|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}Wb=ca(d[wa]|0,16843009)|0;Yb=e+30128|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;Wb=ca(d[g+2|0]|0,16843009)|0;Yb=e+30132|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;Wb=ca(d[g+8|0]|0,16843009)|0;Yb=e+30100|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;if((a[wa]|0)!=0){break}Wb=ca(Wa,16843009)|0;Yb=e+30136|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb;if((c[e+1148>>2]|0)!=4){break}Wb=ca(Xa,16843009)|0;Yb=e+30140|0;c[(c[Yb>>2]|0)+i>>2]=Wb;c[(c[Yb>>2]|0)+f>>2]=Wb}else if((Zb|0)==2){b[(c[e+30116>>2]|0)+i>>1]=(d[aa]|0)*257;b[(c[e+30120>>2]|0)+i>>1]=(c[g+52>>2]|0)*257|0;b[(c[e+30096>>2]|0)+i>>1]=(d[1585112+(c[k>>2]|0)|0]|0)*257;if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}b[(c[e+30128>>2]|0)+i>>1]=(d[wa]|0)*257;b[(c[e+30132>>2]|0)+i>>1]=(d[g+2|0]|0)*257;b[(c[e+30100>>2]|0)+i>>1]=(d[g+8|0]|0)*257;if((a[wa]|0)!=0){break}b[(c[e+30136>>2]|0)+i>>1]=Wa*257|0;if((c[e+1148>>2]|0)!=4){break}b[(c[e+30140>>2]|0)+i>>1]=Xa*257|0}else if((Zb|0)==4){Wb=ca(d[aa]|0,16843009)|0;c[(c[e+30116>>2]|0)+i>>2]=Wb;Wb=ca(c[g+52>>2]|0,16843009)|0;c[(c[e+30120>>2]|0)+i>>2]=Wb;Wb=ca(d[1585112+(c[k>>2]|0)|0]|0,16843009)|0;c[(c[e+30096>>2]|0)+i>>2]=Wb;if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}Wb=ca(d[wa]|0,16843009)|0;c[(c[e+30128>>2]|0)+i>>2]=Wb;Wb=ca(d[g+2|0]|0,16843009)|0;c[(c[e+30132>>2]|0)+i>>2]=Wb;Wb=ca(d[g+8|0]|0,16843009)|0;c[(c[e+30100>>2]|0)+i>>2]=Wb;if((a[wa]|0)!=0){break}Wb=ca(Wa,16843009)|0;c[(c[e+30136>>2]|0)+i>>2]=Wb;if((c[e+1148>>2]|0)!=4){break}Wb=ca(Xa,16843009)|0;c[(c[e+30140>>2]|0)+i>>2]=Wb}else if((Zb|0)==1){a[(c[e+30116>>2]|0)+i|0]=a[aa]|0;a[(c[e+30120>>2]|0)+i|0]=c[g+52>>2];a[(c[e+30096>>2]|0)+i|0]=a[1585112+(c[k>>2]|0)|0]|0;if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}a[(c[e+30128>>2]|0)+i|0]=a[wa]|0;a[(c[e+30132>>2]|0)+i|0]=a[g+2|0]|0;a[(c[e+30100>>2]|0)+i|0]=a[g+8|0]|0;if((a[wa]|0)!=0){break}a[(c[e+30136>>2]|0)+i|0]=Wa;if((c[e+1148>>2]|0)!=4){break}a[(c[e+30140>>2]|0)+i|0]=Xa}}while(0);Zb=d[1898779+(c[k>>2]<<1)|0]|0;do{if((Zb|0)==8){Wb=ca(d[aa]|0,16843009)|0;c[e+(j+30040)>>2]=Wb;c[e+(j+30044)>>2]=Wb;Wb=ca(c[g+52>>2]|0,16843009)|0;c[e+(j+30048)>>2]=Wb;c[e+(j+30052)>>2]=Wb;Wb=ca(d[1584896+(c[k>>2]|0)|0]|0,16843009)|0;c[e+(j+30032)>>2]=Wb;c[e+(j+30036)>>2]=Wb;if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){$=449;break}Wb=ca(d[wa]|0,16843009)|0;c[e+(j+30064)>>2]=Wb;c[e+(j+30068)>>2]=Wb;Wb=ca(d[g+2|0]|0,16843009)|0;c[e+(j+30072)>>2]=Wb;c[e+(j+30076)>>2]=Wb;Wb=ca(d[g+8|0]|0,16843009)|0;c[e+(j+29872)>>2]=Wb;c[e+(j+29876)>>2]=Wb;if((a[wa]|0)!=0){$=449;break}Wb=ca(Wa,16843009)|0;c[e+(j+30080)>>2]=Wb;c[e+(j+30084)>>2]=Wb;if((c[e+1148>>2]|0)!=4){$=449;break}Wb=ca(Xa,16843009)|0;c[e+(j+30088)>>2]=Wb;c[e+(j+30092)>>2]=Wb;$=449}else if((Zb|0)==2){b[e+(j+30040)>>1]=(d[aa]|0)*257;b[e+(j+30048)>>1]=(c[g+52>>2]|0)*257|0;b[e+(j+30032)>>1]=(d[1584896+(c[k>>2]|0)|0]|0)*257;if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){$=449;break}b[e+(j+30064)>>1]=(d[wa]|0)*257;b[e+(j+30072)>>1]=(d[g+2|0]|0)*257;b[e+(j+29872)>>1]=(d[g+8|0]|0)*257;if((a[wa]|0)!=0){$=449;break}b[e+(j+30080)>>1]=Wa*257|0;if((c[e+1148>>2]|0)!=4){$=449;break}b[e+(j+30088)>>1]=Xa*257|0;$=449}else if((Zb|0)==4){c[e+(j+30040)>>2]=ca(d[aa]|0,16843009)|0;c[e+(j+30048)>>2]=ca(c[g+52>>2]|0,16843009)|0;c[e+(j+30032)>>2]=ca(d[1584896+(c[k>>2]|0)|0]|0,16843009)|0;if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){$=449;break}c[e+(j+30064)>>2]=ca(d[wa]|0,16843009)|0;c[e+(j+30072)>>2]=ca(d[g+2|0]|0,16843009)|0;c[e+(j+29872)>>2]=ca(d[g+8|0]|0,16843009)|0;if((a[wa]|0)!=0){$=449;break}c[e+(j+30080)>>2]=ca(Wa,16843009)|0;if((c[e+1148>>2]|0)!=4){$=449;break}c[e+(j+30088)>>2]=ca(Xa,16843009)|0;$=449}else if((Zb|0)==1){a[e+(j+30040)|0]=a[aa]|0;a[e+(j+30048)|0]=c[g+52>>2];a[e+(j+30032)|0]=a[1584896+(c[k>>2]|0)|0]|0;if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){$=449;break}a[e+(j+30064)|0]=a[wa]|0;a[e+(j+30072)|0]=a[g+2|0]|0;a[e+(j+29872)|0]=a[g+8|0]|0;if((a[wa]|0)!=0){$=449;break}a[e+(j+30080)|0]=Wa;if((c[e+1148>>2]|0)!=4){$=449;break}a[e+(j+30088)|0]=Xa;$=449}else{$=449}}while(0);do{if(($|0)==449){if((a[ba]|0)!=0){break}if((a[e+1144|0]|0)!=0){break}Xa=c[g+40>>2]|0;Wa=c[g+44>>2]|0;if((c[k>>2]|0)>>>0>9>>>0){aa=j<<1;Zb=e+29888|0;c[Zb+(aa<<3)>>2]=c[g+24>>2];c[Zb+(aa<<3)+4>>2]=c[g+28>>2];Wb=aa|1;c[Zb+(Wb<<3)>>2]=Xa;c[Zb+(Wb<<3)+4>>2]=Wa;Wb=i<<1;Zb=e+30144|0;c[(c[Zb>>2]|0)+(Wb<<3)>>2]=c[g+32>>2];c[(c[Zb>>2]|0)+(Wb<<3)+4>>2]=c[g+36>>2];aa=Wb|1;c[(c[Zb>>2]|0)+(aa<<3)>>2]=Xa;c[(c[Zb>>2]|0)+(aa<<3)+4>>2]=Wa;break}aa=p<<1;if((aa|0)>0){Zb=i<<1;Wb=e+30144|0;f=0;do{Yb=f+Zb|0;c[(c[Wb>>2]|0)+(Yb<<3)>>2]=Xa;c[(c[Wb>>2]|0)+(Yb<<3)+4>>2]=Wa;f=f+1|0;}while((f|0)<(aa|0))}aa=l<<1;if((aa|0)<=0){break}f=j<<1;Wb=e+29888|0;Zb=0;do{wb=Zb+f|0;c[Wb+(wb<<3)>>2]=Xa;c[Wb+(wb<<3)+4>>2]=Wa;Zb=Zb+1|0;}while((Zb|0)<(aa|0))}}while(0);if((l|0)<=0){return}j=e+1796|0;k=e+1380|0;e=g+2|0;ba=(p|0)>0;$=g+3|0;aa=g+4|0;Zb=g+40|0;Wa=g+44|0;Wb=g+40|0;g=0;do{Xa=(ca(g+h<<3,c[j>>2]|0)|0)+i|0;f=c[k>>2]|0;do{if((a[wa]|0)==0){if((a[e]|0)==0){if(ba){_b=0}else{break}do{wb=_b+Xa|0;a[f+(wb*12|0)+8|0]=a[$]|0;a[f+(wb*12|0)+9|0]=-1;c[f+(wb*12|0)>>2]=c[Wb>>2];_b=_b+1|0;}while((_b|0)<(p|0))}else{if(ba){$b=0}else{break}do{tb=$b+Xa|0;a[f+(tb*12|0)+8|0]=a[$]|0;a[f+(tb*12|0)+9|0]=a[aa]|0;c[f+(tb*12|0)>>2]=c[Zb>>2];c[f+(tb*12|0)+4>>2]=c[Wa>>2];$b=$b+1|0;}while(($b|0)<(p|0))}}else{if(ba){ac=0}else{break}do{tb=ac+Xa|0;a[f+(tb*12|0)+9|0]=-1;a[f+(tb*12|0)+8|0]=-1;ac=ac+1|0;}while((ac|0)<(p|0))}}while(0);g=g+1|0;}while((g|0)<(l|0));return}function zbb(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0;q=i;i=i+1024|0;r=q|0;s=e|0;t=e+4|0;u=e+16|0;v=e+8|0;w=e+12|0;e=l;x=k+(l*11|0)|0;l=b[o>>1]|0;z=0;A=0;B=c[s>>2]|0;C=c[t>>2]|0;D=c[u>>2]|0;a:while(1){E=d[x]|0;F=d[1252840+B|0]|0;G=B<<F;c[s>>2]=G;H=D<<F;I=F+C|0;do{if((I|0)>-1){F=c[v>>2]|0;if(!(F>>>0<(c[w>>2]|0)>>>0)){J=H;K=I;break}c[v>>2]=F+2;L=F;J=((he((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<I|H;K=I-16|0}else{J=H;K=I}}while(0);c[t>>2]=K;M=((ca(G-1|0,E)|0)>>8)+1|0;I=M<<16;if(J>>>0<I>>>0){N=6;break}c[s>>2]=G-M;c[u>>2]=J-I;I=j+(z*48|0)+(e<<3)+4|0;c[I>>2]=(c[I>>2]|0)+1;I=e;H=x;L=l;F=z;O=A;while(1){P=d[H+1|0]|0;Q=c[s>>2]|0;R=d[1252840+Q|0]|0;S=c[t>>2]|0;T=c[u>>2]|0;U=Q<<R;c[s>>2]=U;Q=T<<R;T=S+R|0;do{if((T|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){V=Q;W=T;break}c[v>>2]=R+2;S=R;V=((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)<<T|Q;W=T-16|0}else{V=Q;W=T}}while(0);c[t>>2]=W;X=((ca(U-1|0,P)|0)>>8)+1|0;Y=X<<16;if(!(V>>>0<Y>>>0)){break}c[s>>2]=X;c[u>>2]=V;T=h+(F*72|0)+(I*12|0)|0;c[T>>2]=(c[T>>2]|0)+1;T=L-1|0;if((T|0)==0){Q=F+1|0;Z=b[o+(Q<<1)>>1]|0;_=Q}else{Z=T;_=F}a[r+(b[m+(O<<1)>>1]|0)|0]=0;T=((d[r+(b[n+(O<<2)>>1]|0)|0]|0)+1+(d[r+(b[n+(O<<2)+2>>1]|0)|0]|0)|0)>>>1;Q=O+1|0;if((Q|0)==(g|0)){$=g;N=154;break a}else{I=T;H=k+(_*66|0)+(T*11|0)|0;L=Z;F=_;O=Q}}G=U-X|0;c[s>>2]=G;E=V-Y|0;c[u>>2]=E;Q=b[m+(O<<1)>>1]|0;T=H+2|0;S=d[T]|0;R=d[1252840+G|0]|0;aa=G<<R;c[s>>2]=aa;G=E<<R;E=R+W|0;do{if((E|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){ba=G;da=E;break}c[v>>2]=R+2;ea=R;ba=((he((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<E|G;da=E-16|0}else{ba=G;da=E}}while(0);c[t>>2]=da;E=((ca(aa-1|0,S)|0)>>8)+1|0;G=E<<16;do{if(ba>>>0<G>>>0){c[s>>2]=E;c[u>>2]=ba;ea=h+(F*72|0)+(I*12|0)+4|0;c[ea>>2]=(c[ea>>2]|0)+1;a[r+Q|0]=1;fa=1}else{c[s>>2]=aa-E;c[u>>2]=ba-G;ea=H+3|0;if((a[ea]|0)==0){R=211920+(d[T]<<3)|0;ga=ea;ha=R|0;ia=R+4|0;R=d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0;ia=ga|0;y=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y;ia=ga+4|0;y=R;a[ia]=y;y=y>>8;a[ia+1|0]=y;y=y>>8;a[ia+2|0]=y;y=y>>8;a[ia+3|0]=y}ia=h+(F*72|0)+(I*12|0)+8|0;c[ia>>2]=(c[ia>>2]|0)+1;ia=d[ea]|0;ea=c[s>>2]|0;R=d[1252840+ea|0]|0;ga=c[t>>2]|0;ha=c[u>>2]|0;ja=ea<<R;c[s>>2]=ja;ea=ha<<R;ha=ga+R|0;do{if((ha|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){ka=ea;la=ha;break}c[v>>2]=R+2;ga=R;ka=((he((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)<<ha|ea;la=ha-16|0}else{ka=ea;la=ha}}while(0);c[t>>2]=la;ha=((ca(ja-1|0,ia)|0)>>8)+1|0;ea=ha<<16;if(ka>>>0<ea>>>0){c[s>>2]=ha;c[u>>2]=ka;P=d[H+4|0]|0;ga=d[1252840+ha|0]|0;R=ha<<ga;c[s>>2]=R;ma=ka<<ga;na=ga+la|0;do{if((na|0)>-1){ga=c[v>>2]|0;if(!(ga>>>0<(c[w>>2]|0)>>>0)){oa=ma;pa=na;break}c[v>>2]=ga+2;qa=ga;oa=((he((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<na|ma;pa=na-16|0}else{oa=ma;pa=na}}while(0);c[t>>2]=pa;na=((ca(R-1|0,P)|0)>>8)+1|0;ma=na<<16;if(oa>>>0<ma>>>0){c[s>>2]=na;c[u>>2]=oa;a[r+Q|0]=2;fa=2;break}ia=R-na|0;c[s>>2]=ia;na=oa-ma|0;c[u>>2]=na;ma=a[H+5|0]|0;qa=d[1252840+ia|0]|0;ga=ia<<qa;c[s>>2]=ga;ia=na<<qa;na=qa+pa|0;do{if((na|0)>-1){qa=c[v>>2]|0;if(!(qa>>>0<(c[w>>2]|0)>>>0)){ra=ia;sa=na;break}c[v>>2]=qa+2;ta=qa;ra=((he((d[ta]|d[ta+1|0]<<8)<<16>>16|0)|0)&65535)<<na|ia;sa=na-16|0}else{ra=ia;sa=na}}while(0);c[t>>2]=sa;na=((ca(ga-1|0,ma&255)|0)>>8)+1|0;ia=na<<16;R=ra>>>0>=ia>>>0;c[s>>2]=R?ga-na|0:na;c[u>>2]=ra-(R?ia:0);a[r+Q|0]=3;fa=R?4:3;break}R=ja-ha|0;c[s>>2]=R;ia=ka-ea|0;c[u>>2]=ia;na=d[H+6|0]|0;P=d[1252840+R|0]|0;ta=R<<P;c[s>>2]=ta;R=ia<<P;ia=P+la|0;do{if((ia|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){ua=R;va=ia;break}c[v>>2]=P+2;qa=P;ua=((he((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ia|R;va=ia-16|0}else{ua=R;va=ia}}while(0);c[t>>2]=va;ia=((ca(ta-1|0,na)|0)>>8)+1|0;R=ia<<16;if(ua>>>0<R>>>0){c[s>>2]=ia;c[u>>2]=ua;a[r+Q|0]=4;ea=d[H+7|0]|0;ha=d[1252840+ia|0]|0;ja=ia<<ha;c[s>>2]=ja;ga=ua<<ha;ma=ha+va|0;do{if((ma|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){wa=ga;xa=ma;break}c[v>>2]=ha+2;qa=ha;wa=((he((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|ga;xa=ma-16|0}else{wa=ga;xa=ma}}while(0);c[t>>2]=xa;ma=((ca(ja-1|0,ea)|0)>>8)+1|0;ga=ma<<16;if(wa>>>0<ga>>>0){c[u>>2]=wa;na=d[1252840+ma|0]|0;qa=ma<<na;c[s>>2]=qa;ha=wa<<na;P=na+xa|0;do{if((P|0)>-1){na=c[v>>2]|0;if(!(na>>>0<(c[w>>2]|0)>>>0)){ya=ha;za=P;break}c[v>>2]=na+2;Aa=na;ya=((he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ha;za=P-16|0}else{ya=ha;za=P}}while(0);c[t>>2]=za;P=((qa*159|0)-159>>8)+1|0;ha=P<<16;ea=ya>>>0>=ha>>>0;c[s>>2]=ea?qa-P|0:P;c[u>>2]=ya-(ea?ha:0);fa=ea?6:5;break}ea=ja-ma|0;ha=wa-ga|0;c[u>>2]=ha;P=d[1252840+ea|0]|0;Aa=ea<<P;c[s>>2]=Aa;ea=ha<<P;ha=P+xa|0;do{if((ha|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){Ba=ea;Ca=ha;break}c[v>>2]=P+2;na=P;Ba=((he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ha|ea;Ca=ha-16|0}else{Ba=ea;Ca=ha}}while(0);c[t>>2]=Ca;ha=((Aa*165|0)-165>>8)+1|0;ea=ha<<16;ga=Ba>>>0>=ea>>>0;ma=ga?Aa-ha|0:ha;ha=Ba-(ga?ea:0)|0;c[u>>2]=ha;ea=((ga&1)<<1)+7|0;ga=d[1252840+ma|0]|0;ja=ma<<ga;c[s>>2]=ja;ma=ha<<ga;ha=ga+Ca|0;do{if((ha|0)>-1){ga=c[v>>2]|0;if(!(ga>>>0<(c[w>>2]|0)>>>0)){Da=ma;Ea=ha;break}c[v>>2]=ga+2;qa=ga;Da=((he((d[qa]|d[qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ha|ma;Ea=ha-16|0}else{Da=ma;Ea=ha}}while(0);c[t>>2]=Ea;ha=((ja*145|0)-145>>8)+1|0;ma=ha<<16;Aa=Da>>>0>=ma>>>0;c[s>>2]=Aa?ja-ha|0:ha;c[u>>2]=Da-(Aa?ma:0);fa=ea+(Aa&1)|0;break}Aa=ta-ia|0;c[s>>2]=Aa;ma=ua-R|0;c[u>>2]=ma;a[r+Q|0]=5;ha=d[H+8|0]|0;qa=d[1252840+Aa|0]|0;ga=Aa<<qa;c[s>>2]=ga;Aa=ma<<qa;ma=qa+va|0;do{if((ma|0)>-1){qa=c[v>>2]|0;if(!(qa>>>0<(c[w>>2]|0)>>>0)){Fa=Aa;Ga=ma;break}c[v>>2]=qa+2;na=qa;Fa=((he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|Aa;Ga=ma-16|0}else{Fa=Aa;Ga=ma}}while(0);c[t>>2]=Ga;ma=((ca(ga-1|0,ha)|0)>>8)+1|0;Aa=ma<<16;if(Fa>>>0<Aa>>>0){c[s>>2]=ma;c[u>>2]=Fa;R=d[H+9|0]|0;ia=d[1252840+ma|0]|0;ta=ma<<ia;c[s>>2]=ta;ea=Fa<<ia;ja=ia+Ga|0;do{if((ja|0)>-1){ia=c[v>>2]|0;if(!(ia>>>0<(c[w>>2]|0)>>>0)){Ha=ea;Ia=ja;break}c[v>>2]=ia+2;na=ia;Ha=((he((d[na]|d[na+1|0]<<8)<<16>>16|0)|0)&65535)<<ja|ea;Ia=ja-16|0}else{Ha=ea;Ia=ja}}while(0);c[t>>2]=Ia;ja=((ca(ta-1|0,R)|0)>>8)+1|0;ea=ja<<16;if(Ha>>>0<ea>>>0){c[u>>2]=Ha;ha=d[1252840+ja|0]|0;na=ja<<ha;c[s>>2]=na;ia=Ha<<ha;qa=ha+Ia|0;do{if((qa|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){Ja=ia;Ka=qa;break}c[v>>2]=ha+2;P=ha;Ja=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<qa|ia;Ka=qa-16|0}else{Ja=ia;Ka=qa}}while(0);c[t>>2]=Ka;qa=((na*173|0)-173>>8)+1|0;ia=qa<<16;R=Ja>>>0>=ia>>>0;P=R?na-qa|0:qa;qa=Ja-(R?ia:0)|0;c[u>>2]=qa;ia=(R&1)<<2|11;R=d[1252840+P|0]|0;ha=P<<R;c[s>>2]=ha;P=qa<<R;qa=R+Ka|0;do{if((qa|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){La=P;Ma=qa;break}c[v>>2]=R+2;Na=R;La=((he((d[Na]|d[Na+1|0]<<8)<<16>>16|0)|0)&65535)<<qa|P;Ma=qa-16|0}else{La=P;Ma=qa}}while(0);c[t>>2]=Ma;qa=((ha*148|0)-148>>8)+1|0;P=qa<<16;na=La>>>0>=P>>>0;Na=na?ha-qa|0:qa;qa=La-(na?P:0)|0;c[u>>2]=qa;P=((na&1)<<1)+ia|0;na=d[1252840+Na|0]|0;R=Na<<na;c[s>>2]=R;Na=qa<<na;qa=na+Ma|0;do{if((qa|0)>-1){na=c[v>>2]|0;if(!(na>>>0<(c[w>>2]|0)>>>0)){Oa=Na;Pa=qa;break}c[v>>2]=na+2;Qa=na;Oa=((he((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<qa|Na;Pa=qa-16|0}else{Oa=Na;Pa=qa}}while(0);c[t>>2]=Pa;qa=((R*140|0)-140>>8)+1|0;Na=qa<<16;ia=Oa>>>0>=Na>>>0;c[s>>2]=ia?R-qa|0:qa;c[u>>2]=Oa-(ia?Na:0);fa=P+(ia&1)|0;break}ia=ta-ja|0;Na=Ha-ea|0;c[u>>2]=Na;qa=d[1252840+ia|0]|0;ha=ia<<qa;c[s>>2]=ha;ia=Na<<qa;Na=qa+Ia|0;do{if((Na|0)>-1){qa=c[v>>2]|0;if(!(qa>>>0<(c[w>>2]|0)>>>0)){Ra=ia;Sa=Na;break}c[v>>2]=qa+2;Qa=qa;Ra=((he((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<Na|ia;Sa=Na-16|0}else{Ra=ia;Sa=Na}}while(0);c[t>>2]=Sa;Na=((ha*176|0)-176>>8)+1|0;ia=Na<<16;ea=Ra>>>0>=ia>>>0;ja=ea?ha-Na|0:Na;Na=Ra-(ea?ia:0)|0;c[u>>2]=Na;ia=(ea&1)<<3;ea=d[1252840+ja|0]|0;ta=ja<<ea;c[s>>2]=ta;ja=Na<<ea;Na=ea+Sa|0;do{if((Na|0)>-1){ea=c[v>>2]|0;if(!(ea>>>0<(c[w>>2]|0)>>>0)){Ta=ja;Ua=Na;break}c[v>>2]=ea+2;P=ea;Ta=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<Na|ja;Ua=Na-16|0}else{Ta=ja;Ua=Na}}while(0);c[t>>2]=Ua;Na=((ta*155|0)-155>>8)+1|0;ja=Na<<16;ha=Ta>>>0>=ja>>>0;P=ha?ta-Na|0:Na;Na=Ta-(ha?ja:0)|0;c[u>>2]=Na;ja=ia|(ha&1)<<2|19;ha=d[1252840+P|0]|0;ea=P<<ha;c[s>>2]=ea;P=Na<<ha;Na=ha+Ua|0;do{if((Na|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){Va=P;Wa=Na;break}c[v>>2]=ha+2;R=ha;Va=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<Na|P;Wa=Na-16|0}else{Va=P;Wa=Na}}while(0);c[t>>2]=Wa;Na=((ea*140|0)-140>>8)+1|0;P=Na<<16;ia=Va>>>0>=P>>>0;ta=ia?ea-Na|0:Na;Na=Va-(ia?P:0)|0;c[u>>2]=Na;P=((ia&1)<<1)+ja|0;ia=d[1252840+ta|0]|0;R=ta<<ia;c[s>>2]=R;ta=Na<<ia;Na=ia+Wa|0;do{if((Na|0)>-1){ia=c[v>>2]|0;if(!(ia>>>0<(c[w>>2]|0)>>>0)){Xa=ta;Ya=Na;break}c[v>>2]=ia+2;ha=ia;Xa=((he((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535)<<Na|ta;Ya=Na-16|0}else{Xa=ta;Ya=Na}}while(0);c[t>>2]=Ya;Na=((R*135|0)-135>>8)+1|0;ta=Na<<16;ja=Xa>>>0>=ta>>>0;c[s>>2]=ja?R-Na|0:Na;c[u>>2]=Xa-(ja?ta:0);fa=P+(ja&1)|0;break}ja=ga-ma|0;c[s>>2]=ja;ta=Fa-Aa|0;c[u>>2]=ta;Na=d[H+10|0]|0;ea=d[1252840+ja|0]|0;ha=ja<<ea;c[s>>2]=ha;ja=ta<<ea;ta=ea+Ga|0;do{if((ta|0)>-1){ea=c[v>>2]|0;if(!(ea>>>0<(c[w>>2]|0)>>>0)){Za=ja;_a=ta;break}c[v>>2]=ea+2;ia=ea;Za=((he((d[ia]|d[ia+1|0]<<8)<<16>>16|0)|0)&65535)<<ta|ja;_a=ta-16|0}else{Za=ja;_a=ta}}while(0);c[t>>2]=_a;ta=((ca(ha-1|0,Na)|0)>>8)+1|0;ja=ta<<16;if(Za>>>0<ja>>>0){c[u>>2]=Za;Aa=d[1252840+ta|0]|0;ma=ta<<Aa;c[s>>2]=ma;ga=Za<<Aa;P=Aa+_a|0;do{if((P|0)>-1){Aa=c[v>>2]|0;if(!(Aa>>>0<(c[w>>2]|0)>>>0)){$a=ga;ab=P;break}c[v>>2]=Aa+2;R=Aa;$a=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ga;ab=P-16|0}else{$a=ga;ab=P}}while(0);c[t>>2]=ab;P=((ma*180|0)-180>>8)+1|0;ga=P<<16;Na=$a>>>0>=ga>>>0;R=Na?ma-P|0:P;P=$a-(Na?ga:0)|0;c[u>>2]=P;ga=(Na&1)<<4;Na=d[1252840+R|0]|0;Aa=R<<Na;c[s>>2]=Aa;R=P<<Na;P=Na+ab|0;do{if((P|0)>-1){Na=c[v>>2]|0;if(!(Na>>>0<(c[w>>2]|0)>>>0)){bb=R;cb=P;break}c[v>>2]=Na+2;ia=Na;bb=((he((d[ia]|d[ia+1|0]<<8)<<16>>16|0)|0)&65535)<<P|R;cb=P-16|0}else{bb=R;cb=P}}while(0);c[t>>2]=cb;P=((Aa*157|0)-157>>8)+1|0;R=P<<16;ma=bb>>>0>=R>>>0;ia=ma?Aa-P|0:P;P=bb-(ma?R:0)|0;c[u>>2]=P;R=(ma&1)<<3;ma=d[1252840+ia|0]|0;Na=ia<<ma;c[s>>2]=Na;ia=P<<ma;P=ma+cb|0;do{if((P|0)>-1){ma=c[v>>2]|0;if(!(ma>>>0<(c[w>>2]|0)>>>0)){db=ia;eb=P;break}c[v>>2]=ma+2;ea=ma;db=((he((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ia;eb=P-16|0}else{db=ia;eb=P}}while(0);c[t>>2]=eb;P=((Na*141|0)-141>>8)+1|0;ia=P<<16;Aa=db>>>0>=ia>>>0;ea=Aa?Na-P|0:P;P=db-(Aa?ia:0)|0;c[u>>2]=P;ia=ga|R|(Aa&1)<<2|35;Aa=d[1252840+ea|0]|0;ma=ea<<Aa;c[s>>2]=ma;ea=P<<Aa;P=Aa+eb|0;do{if((P|0)>-1){Aa=c[v>>2]|0;if(!(Aa>>>0<(c[w>>2]|0)>>>0)){fb=ea;gb=P;break}c[v>>2]=Aa+2;Qa=Aa;fb=((he((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ea;gb=P-16|0}else{fb=ea;gb=P}}while(0);c[t>>2]=gb;P=((ma*134|0)-134>>8)+1|0;ea=P<<16;R=fb>>>0>=ea>>>0;ga=R?ma-P|0:P;P=fb-(R?ea:0)|0;c[u>>2]=P;ea=((R&1)<<1)+ia|0;R=d[1252840+ga|0]|0;Na=ga<<R;c[s>>2]=Na;ga=P<<R;P=R+gb|0;do{if((P|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){hb=ga;ib=P;break}c[v>>2]=R+2;Qa=R;hb=((he((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<P|ga;ib=P-16|0}else{hb=ga;ib=P}}while(0);c[t>>2]=ib;P=((Na*130|0)-130>>8)+1|0;ga=P<<16;ia=hb>>>0>=ga>>>0;c[s>>2]=ia?Na-P|0:P;c[u>>2]=hb-(ia?ga:0);fa=ea+(ia&1)|0;break}ia=ha-ta|0;ga=Za-ja|0;c[u>>2]=ga;P=d[1252840+ia|0]|0;ma=ia<<P;c[s>>2]=ma;ia=ga<<P;ga=P+_a|0;do{if((ga|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){jb=ia;kb=ga;break}c[v>>2]=P+2;Qa=P;jb=((he((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ia;kb=ga-16|0}else{jb=ia;kb=ga}}while(0);c[t>>2]=kb;ga=((ma*254|0)-254>>8)+1|0;ia=ga<<16;ja=jb>>>0>=ia>>>0;ta=ja?ma-ga|0:ga;ga=jb-(ja?ia:0)|0;c[u>>2]=ga;ia=(ja&1)<<13;ja=d[1252840+ta|0]|0;ha=ta<<ja;c[s>>2]=ha;ta=ga<<ja;ga=ja+kb|0;do{if((ga|0)>-1){ja=c[v>>2]|0;if(!(ja>>>0<(c[w>>2]|0)>>>0)){lb=ta;mb=ga;break}c[v>>2]=ja+2;ea=ja;lb=((he((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ta;mb=ga-16|0}else{lb=ta;mb=ga}}while(0);c[t>>2]=mb;ga=((ha*254|0)-254>>8)+1|0;ta=ga<<16;ma=lb>>>0>=ta>>>0;ea=ma?ha-ga|0:ga;ga=lb-(ma?ta:0)|0;c[u>>2]=ga;ta=(ma&1)<<12;ma=d[1252840+ea|0]|0;ja=ea<<ma;c[s>>2]=ja;ea=ga<<ma;ga=ma+mb|0;do{if((ga|0)>-1){ma=c[v>>2]|0;if(!(ma>>>0<(c[w>>2]|0)>>>0)){nb=ea;ob=ga;break}c[v>>2]=ma+2;Na=ma;nb=((he((d[Na]|d[Na+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ea;ob=ga-16|0}else{nb=ea;ob=ga}}while(0);c[t>>2]=ob;ga=((ja*254|0)-254>>8)+1|0;ea=ga<<16;ha=nb>>>0>=ea>>>0;Na=ha?ja-ga|0:ga;ga=nb-(ha?ea:0)|0;c[u>>2]=ga;ea=(ha&1)<<11;ha=d[1252840+Na|0]|0;ma=Na<<ha;c[s>>2]=ma;Na=ga<<ha;ga=ha+ob|0;do{if((ga|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){pb=Na;qb=ga;break}c[v>>2]=ha+2;Qa=ha;pb=((he((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|Na;qb=ga-16|0}else{pb=Na;qb=ga}}while(0);c[t>>2]=qb;ga=((ma*252|0)-252>>8)+1|0;Na=ga<<16;ja=pb>>>0>=Na>>>0;Qa=ja?ma-ga|0:ga;ga=pb-(ja?Na:0)|0;c[u>>2]=ga;Na=(ja&1)<<10;ja=d[1252840+Qa|0]|0;ha=Qa<<ja;c[s>>2]=ha;Qa=ga<<ja;ga=ja+qb|0;do{if((ga|0)>-1){ja=c[v>>2]|0;if(!(ja>>>0<(c[w>>2]|0)>>>0)){rb=Qa;sb=ga;break}c[v>>2]=ja+2;P=ja;rb=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|Qa;sb=ga-16|0}else{rb=Qa;sb=ga}}while(0);c[t>>2]=sb;ga=((ha*249|0)-249>>8)+1|0;Qa=ga<<16;ma=rb>>>0>=Qa>>>0;P=ma?ha-ga|0:ga;ga=rb-(ma?Qa:0)|0;c[u>>2]=ga;Qa=(ma&1)<<9;ma=d[1252840+P|0]|0;ja=P<<ma;c[s>>2]=ja;P=ga<<ma;ga=ma+sb|0;do{if((ga|0)>-1){ma=c[v>>2]|0;if(!(ma>>>0<(c[w>>2]|0)>>>0)){tb=P;ub=ga;break}c[v>>2]=ma+2;R=ma;tb=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|P;ub=ga-16|0}else{tb=P;ub=ga}}while(0);c[t>>2]=ub;ga=((ja*243|0)-243>>8)+1|0;P=ga<<16;ha=tb>>>0>=P>>>0;R=ha?ja-ga|0:ga;ga=tb-(ha?P:0)|0;c[u>>2]=ga;P=ia|ta|ea|Na|Qa|(ha&1)<<8|67;ha=d[1252840+R|0]|0;ma=R<<ha;c[s>>2]=ma;R=ga<<ha;ga=ha+ub|0;do{if((ga|0)>-1){ha=c[v>>2]|0;if(!(ha>>>0<(c[w>>2]|0)>>>0)){vb=R;wb=ga;break}c[v>>2]=ha+2;Aa=ha;vb=((he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|R;wb=ga-16|0}else{vb=R;wb=ga}}while(0);c[t>>2]=wb;ga=((ma*230|0)-230>>8)+1|0;R=ga<<16;Qa=vb>>>0>=R>>>0;Na=Qa?ma-ga|0:ga;ga=vb-(Qa?R:0)|0;c[u>>2]=ga;R=((Qa&1)<<7)+P|0;Qa=d[1252840+Na|0]|0;ea=Na<<Qa;c[s>>2]=ea;Na=ga<<Qa;ga=Qa+wb|0;do{if((ga|0)>-1){Qa=c[v>>2]|0;if(!(Qa>>>0<(c[w>>2]|0)>>>0)){xb=Na;yb=ga;break}c[v>>2]=Qa+2;ta=Qa;xb=((he((d[ta]|d[ta+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|Na;yb=ga-16|0}else{xb=Na;yb=ga}}while(0);c[t>>2]=yb;ga=((ea*196|0)-196>>8)+1|0;Na=ga<<16;P=xb>>>0>=Na>>>0;ma=P?ea-ga|0:ga;ga=xb-(P?Na:0)|0;c[u>>2]=ga;Na=R+((P&1)<<6)|0;P=d[1252840+ma|0]|0;ta=ma<<P;c[s>>2]=ta;ma=ga<<P;ga=P+yb|0;do{if((ga|0)>-1){P=c[v>>2]|0;if(!(P>>>0<(c[w>>2]|0)>>>0)){zb=ma;Ab=ga;break}c[v>>2]=P+2;Qa=P;zb=((he((d[Qa]|d[Qa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ma;Ab=ga-16|0}else{zb=ma;Ab=ga}}while(0);c[t>>2]=Ab;ga=((ta*177|0)-177>>8)+1|0;ma=ga<<16;R=zb>>>0>=ma>>>0;ea=R?ta-ga|0:ga;ga=zb-(R?ma:0)|0;c[u>>2]=ga;ma=Na+((R&1)<<5)|0;R=d[1252840+ea|0]|0;Qa=ea<<R;c[s>>2]=Qa;ea=ga<<R;ga=R+Ab|0;do{if((ga|0)>-1){R=c[v>>2]|0;if(!(R>>>0<(c[w>>2]|0)>>>0)){Bb=ea;Cb=ga;break}c[v>>2]=R+2;P=R;Bb=((he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ea;Cb=ga-16|0}else{Bb=ea;Cb=ga}}while(0);c[t>>2]=Cb;ga=((Qa*153|0)-153>>8)+1|0;ea=ga<<16;Na=Bb>>>0>=ea>>>0;ta=Na?Qa-ga|0:ga;ga=Bb-(Na?ea:0)|0;c[u>>2]=ga;ea=ma+((Na&1)<<4)|0;Na=d[1252840+ta|0]|0;P=ta<<Na;c[s>>2]=P;ta=ga<<Na;ga=Na+Cb|0;do{if((ga|0)>-1){Na=c[v>>2]|0;if(!(Na>>>0<(c[w>>2]|0)>>>0)){Db=ta;Eb=ga;break}c[v>>2]=Na+2;R=Na;Db=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|ta;Eb=ga-16|0}else{Db=ta;Eb=ga}}while(0);c[t>>2]=Eb;ga=((P*140|0)-140>>8)+1|0;ta=ga<<16;ma=Db>>>0>=ta>>>0;Qa=ma?P-ga|0:ga;ga=Db-(ma?ta:0)|0;c[u>>2]=ga;ta=ea+((ma&1)<<3)|0;ma=d[1252840+Qa|0]|0;R=Qa<<ma;c[s>>2]=R;Qa=ga<<ma;ga=ma+Eb|0;do{if((ga|0)>-1){ma=c[v>>2]|0;if(!(ma>>>0<(c[w>>2]|0)>>>0)){Fb=Qa;Gb=ga;break}c[v>>2]=ma+2;Na=ma;Fb=((he((d[Na]|d[Na+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|Qa;Gb=ga-16|0}else{Fb=Qa;Gb=ga}}while(0);c[t>>2]=Gb;ga=((R*133|0)-133>>8)+1|0;Qa=ga<<16;ea=Fb>>>0>=Qa>>>0;P=ea?R-ga|0:ga;ga=Fb-(ea?Qa:0)|0;c[u>>2]=ga;Qa=ta+((ea&1)<<2)|0;ea=d[1252840+P|0]|0;Na=P<<ea;c[s>>2]=Na;P=ga<<ea;ga=ea+Gb|0;do{if((ga|0)>-1){ea=c[v>>2]|0;if(!(ea>>>0<(c[w>>2]|0)>>>0)){Hb=P;Ib=ga;break}c[v>>2]=ea+2;ma=ea;Hb=((he((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|P;Ib=ga-16|0}else{Hb=P;Ib=ga}}while(0);c[t>>2]=Ib;ga=((Na*130|0)-130>>8)+1|0;P=ga<<16;ta=Hb>>>0>=P>>>0;R=ta?Na-ga|0:ga;ga=Hb-(ta?P:0)|0;c[u>>2]=ga;P=Qa+((ta&1)<<1)|0;ta=d[1252840+R|0]|0;ma=R<<ta;c[s>>2]=ma;R=ga<<ta;ga=ta+Ib|0;do{if((ga|0)>-1){ta=c[v>>2]|0;if(!(ta>>>0<(c[w>>2]|0)>>>0)){Jb=R;Kb=ga;break}c[v>>2]=ta+2;ea=ta;Jb=((he((d[ea]|d[ea+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|R;Kb=ga-16|0}else{Jb=R;Kb=ga}}while(0);c[t>>2]=Kb;ga=((ma*129|0)-129>>8)+1|0;R=ga<<16;Qa=Jb>>>0>=R>>>0;c[s>>2]=Qa?ma-ga|0:ga;c[u>>2]=Jb-(Qa?R:0);fa=P+(Qa&1)|0}}while(0);H=L-1|0;if((H|0)==0){I=F+1|0;Lb=b[o+(I<<1)>>1]|0;Mb=I}else{Lb=H;Mb=F}H=c[s>>2]|0;I=d[1252840+H|0]|0;T=c[t>>2]|0;G=c[u>>2]|0;E=H<<I;c[s>>2]=E;H=G<<I;G=T+I|0;do{if((G|0)>-1){I=c[v>>2]|0;if(!(I>>>0<(c[w>>2]|0)>>>0)){Nb=H;Ob=G;break}c[v>>2]=I+2;T=I;Nb=((he((d[T]|d[T+1|0]<<8)<<16>>16|0)|0)&65535)<<G|H;Ob=G-16|0}else{Nb=H;Ob=G}}while(0);c[t>>2]=Ob;G=((E<<7)-128>>8)+1|0;H=G<<16;F=Nb>>>0>=H>>>0;L=F?E-G|0:G;c[s>>2]=L;G=Nb-(F?H:0)|0;c[u>>2]=G;b[f+(Q<<1)>>1]=ca(F?-fa|0:fa,b[p+(((O|0)!=0)<<1)>>1]|0)|0;F=((d[r+(b[n+(O<<2)>>1]|0)|0]|0)+1+(d[r+(b[n+(O<<2)+2>>1]|0)|0]|0)|0)>>>1;H=O+1|0;if((H|0)<(g|0)){e=F;x=k+(Mb*66|0)+(F*11|0)|0;l=Lb;z=Mb;A=H;B=L;C=Ob;D=G}else{$=H;N=154;break}}if((N|0)==6){c[s>>2]=M;c[u>>2]=J;J=j+(z*48|0)+(e<<3)|0;c[J>>2]=(c[J>>2]|0)+1;$=A;i=q;return $|0}else if((N|0)==154){i=q;return $|0}return 0}function Abb(e,f,g,h,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0;p=i;i=i+1024|0;q=p|0;r=e|0;s=e+4|0;t=e+16|0;u=e+8|0;v=e+12|0;e=k;w=j+(k*11|0)|0;k=b[n>>1]|0;x=0;z=0;A=c[r>>2]|0;B=c[s>>2]|0;C=c[t>>2]|0;a:while(1){D=d[w]|0;E=d[1252840+A|0]|0;F=A<<E;c[r>>2]=F;G=C<<E;H=E+B|0;do{if((H|0)>-1){E=c[u>>2]|0;if(!(E>>>0<(c[v>>2]|0)>>>0)){I=G;J=H;break}c[u>>2]=E+2;K=E;I=((he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535)<<H|G;J=H-16|0}else{I=G;J=H}}while(0);c[s>>2]=J;L=((ca(F-1|0,D)|0)>>8)+1|0;H=L<<16;if(I>>>0<H>>>0){M=6;break}c[r>>2]=F-L;c[t>>2]=I-H;H=h+(x*48|0)+(e<<3)+4|0;c[H>>2]=(c[H>>2]|0)+1;H=e;G=w;K=k;E=x;N=z;while(1){O=d[G+1|0]|0;P=c[r>>2]|0;Q=d[1252840+P|0]|0;R=c[s>>2]|0;S=c[t>>2]|0;T=P<<Q;c[r>>2]=T;P=S<<Q;S=R+Q|0;do{if((S|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){U=P;V=S;break}c[u>>2]=Q+2;R=Q;U=((he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0)&65535)<<S|P;V=S-16|0}else{U=P;V=S}}while(0);c[s>>2]=V;W=((ca(T-1|0,O)|0)>>8)+1|0;X=W<<16;if(!(U>>>0<X>>>0)){break}c[r>>2]=W;c[t>>2]=U;S=g+(E*72|0)+(H*12|0)|0;c[S>>2]=(c[S>>2]|0)+1;S=K-1|0;if((S|0)==0){P=E+1|0;Y=b[n+(P<<1)>>1]|0;Z=P}else{Y=S;Z=E}a[q+(b[l+(N<<1)>>1]|0)|0]=0;S=((d[q+(b[m+(N<<2)>>1]|0)|0]|0)+1+(d[q+(b[m+(N<<2)+2>>1]|0)|0]|0)|0)>>>1;P=N+1|0;if((P|0)==1024){_=1024;M=154;break a}else{H=S;G=j+(Z*66|0)+(S*11|0)|0;K=Y;E=Z;N=P}}F=T-W|0;c[r>>2]=F;D=U-X|0;c[t>>2]=D;P=b[l+(N<<1)>>1]|0;S=G+2|0;R=d[S]|0;Q=d[1252840+F|0]|0;$=F<<Q;c[r>>2]=$;F=D<<Q;D=Q+V|0;do{if((D|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){aa=F;ba=D;break}c[u>>2]=Q+2;da=Q;aa=((he((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<D|F;ba=D-16|0}else{aa=F;ba=D}}while(0);c[s>>2]=ba;D=((ca($-1|0,R)|0)>>8)+1|0;F=D<<16;do{if(aa>>>0<F>>>0){c[r>>2]=D;c[t>>2]=aa;da=g+(E*72|0)+(H*12|0)+4|0;c[da>>2]=(c[da>>2]|0)+1;a[q+P|0]=1;ea=1}else{c[r>>2]=$-D;c[t>>2]=aa-F;da=G+3|0;if((a[da]|0)==0){Q=211920+(d[S]<<3)|0;fa=da;ga=Q|0;ha=Q+4|0;Q=d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0;ha=fa|0;y=d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;ha=fa+4|0;y=Q;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y}ha=g+(E*72|0)+(H*12|0)+8|0;c[ha>>2]=(c[ha>>2]|0)+1;ha=d[da]|0;da=c[r>>2]|0;Q=d[1252840+da|0]|0;fa=c[s>>2]|0;ga=c[t>>2]|0;ia=da<<Q;c[r>>2]=ia;da=ga<<Q;ga=fa+Q|0;do{if((ga|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){ja=da;ka=ga;break}c[u>>2]=Q+2;fa=Q;ja=((he((d[fa]|d[fa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|da;ka=ga-16|0}else{ja=da;ka=ga}}while(0);c[s>>2]=ka;ga=((ca(ia-1|0,ha)|0)>>8)+1|0;da=ga<<16;if(ja>>>0<da>>>0){c[r>>2]=ga;c[t>>2]=ja;O=d[G+4|0]|0;fa=d[1252840+ga|0]|0;Q=ga<<fa;c[r>>2]=Q;la=ja<<fa;ma=fa+ka|0;do{if((ma|0)>-1){fa=c[u>>2]|0;if(!(fa>>>0<(c[v>>2]|0)>>>0)){na=la;oa=ma;break}c[u>>2]=fa+2;pa=fa;na=((he((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|la;oa=ma-16|0}else{na=la;oa=ma}}while(0);c[s>>2]=oa;ma=((ca(Q-1|0,O)|0)>>8)+1|0;la=ma<<16;if(na>>>0<la>>>0){c[r>>2]=ma;c[t>>2]=na;a[q+P|0]=2;ea=2;break}ha=Q-ma|0;c[r>>2]=ha;ma=na-la|0;c[t>>2]=ma;la=a[G+5|0]|0;pa=d[1252840+ha|0]|0;fa=ha<<pa;c[r>>2]=fa;ha=ma<<pa;ma=pa+oa|0;do{if((ma|0)>-1){pa=c[u>>2]|0;if(!(pa>>>0<(c[v>>2]|0)>>>0)){qa=ha;ra=ma;break}c[u>>2]=pa+2;sa=pa;qa=((he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<ma|ha;ra=ma-16|0}else{qa=ha;ra=ma}}while(0);c[s>>2]=ra;ma=((ca(fa-1|0,la&255)|0)>>8)+1|0;ha=ma<<16;Q=qa>>>0>=ha>>>0;c[r>>2]=Q?fa-ma|0:ma;c[t>>2]=qa-(Q?ha:0);a[q+P|0]=3;ea=Q?4:3;break}Q=ia-ga|0;c[r>>2]=Q;ha=ja-da|0;c[t>>2]=ha;ma=d[G+6|0]|0;O=d[1252840+Q|0]|0;sa=Q<<O;c[r>>2]=sa;Q=ha<<O;ha=O+ka|0;do{if((ha|0)>-1){O=c[u>>2]|0;if(!(O>>>0<(c[v>>2]|0)>>>0)){ta=Q;ua=ha;break}c[u>>2]=O+2;pa=O;ta=((he((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<ha|Q;ua=ha-16|0}else{ta=Q;ua=ha}}while(0);c[s>>2]=ua;ha=((ca(sa-1|0,ma)|0)>>8)+1|0;Q=ha<<16;if(ta>>>0<Q>>>0){c[r>>2]=ha;c[t>>2]=ta;a[q+P|0]=4;da=d[G+7|0]|0;ga=d[1252840+ha|0]|0;ia=ha<<ga;c[r>>2]=ia;fa=ta<<ga;la=ga+ua|0;do{if((la|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){va=fa;wa=la;break}c[u>>2]=ga+2;pa=ga;va=((he((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<la|fa;wa=la-16|0}else{va=fa;wa=la}}while(0);c[s>>2]=wa;la=((ca(ia-1|0,da)|0)>>8)+1|0;fa=la<<16;if(va>>>0<fa>>>0){c[t>>2]=va;ma=d[1252840+la|0]|0;pa=la<<ma;c[r>>2]=pa;ga=va<<ma;O=ma+wa|0;do{if((O|0)>-1){ma=c[u>>2]|0;if(!(ma>>>0<(c[v>>2]|0)>>>0)){xa=ga;ya=O;break}c[u>>2]=ma+2;za=ma;xa=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<O|ga;ya=O-16|0}else{xa=ga;ya=O}}while(0);c[s>>2]=ya;O=((pa*159|0)-159>>8)+1|0;ga=O<<16;da=xa>>>0>=ga>>>0;c[r>>2]=da?pa-O|0:O;c[t>>2]=xa-(da?ga:0);ea=da?6:5;break}da=ia-la|0;ga=va-fa|0;c[t>>2]=ga;O=d[1252840+da|0]|0;za=da<<O;c[r>>2]=za;da=ga<<O;ga=O+wa|0;do{if((ga|0)>-1){O=c[u>>2]|0;if(!(O>>>0<(c[v>>2]|0)>>>0)){Aa=da;Ba=ga;break}c[u>>2]=O+2;ma=O;Aa=((he((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|da;Ba=ga-16|0}else{Aa=da;Ba=ga}}while(0);c[s>>2]=Ba;ga=((za*165|0)-165>>8)+1|0;da=ga<<16;fa=Aa>>>0>=da>>>0;la=fa?za-ga|0:ga;ga=Aa-(fa?da:0)|0;c[t>>2]=ga;da=((fa&1)<<1)+7|0;fa=d[1252840+la|0]|0;ia=la<<fa;c[r>>2]=ia;la=ga<<fa;ga=fa+Ba|0;do{if((ga|0)>-1){fa=c[u>>2]|0;if(!(fa>>>0<(c[v>>2]|0)>>>0)){Ca=la;Da=ga;break}c[u>>2]=fa+2;pa=fa;Ca=((he((d[pa]|d[pa+1|0]<<8)<<16>>16|0)|0)&65535)<<ga|la;Da=ga-16|0}else{Ca=la;Da=ga}}while(0);c[s>>2]=Da;ga=((ia*145|0)-145>>8)+1|0;la=ga<<16;za=Ca>>>0>=la>>>0;c[r>>2]=za?ia-ga|0:ga;c[t>>2]=Ca-(za?la:0);ea=da+(za&1)|0;break}za=sa-ha|0;c[r>>2]=za;la=ta-Q|0;c[t>>2]=la;a[q+P|0]=5;ga=d[G+8|0]|0;pa=d[1252840+za|0]|0;fa=za<<pa;c[r>>2]=fa;za=la<<pa;la=pa+ua|0;do{if((la|0)>-1){pa=c[u>>2]|0;if(!(pa>>>0<(c[v>>2]|0)>>>0)){Ea=za;Fa=la;break}c[u>>2]=pa+2;ma=pa;Ea=((he((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<la|za;Fa=la-16|0}else{Ea=za;Fa=la}}while(0);c[s>>2]=Fa;la=((ca(fa-1|0,ga)|0)>>8)+1|0;za=la<<16;if(Ea>>>0<za>>>0){c[r>>2]=la;c[t>>2]=Ea;Q=d[G+9|0]|0;ha=d[1252840+la|0]|0;sa=la<<ha;c[r>>2]=sa;da=Ea<<ha;ia=ha+Fa|0;do{if((ia|0)>-1){ha=c[u>>2]|0;if(!(ha>>>0<(c[v>>2]|0)>>>0)){Ga=da;Ha=ia;break}c[u>>2]=ha+2;ma=ha;Ga=((he((d[ma]|d[ma+1|0]<<8)<<16>>16|0)|0)&65535)<<ia|da;Ha=ia-16|0}else{Ga=da;Ha=ia}}while(0);c[s>>2]=Ha;ia=((ca(sa-1|0,Q)|0)>>8)+1|0;da=ia<<16;if(Ga>>>0<da>>>0){c[t>>2]=Ga;ga=d[1252840+ia|0]|0;ma=ia<<ga;c[r>>2]=ma;ha=Ga<<ga;pa=ga+Ha|0;do{if((pa|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){Ia=ha;Ja=pa;break}c[u>>2]=ga+2;O=ga;Ia=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|ha;Ja=pa-16|0}else{Ia=ha;Ja=pa}}while(0);c[s>>2]=Ja;pa=((ma*173|0)-173>>8)+1|0;ha=pa<<16;Q=Ia>>>0>=ha>>>0;O=Q?ma-pa|0:pa;pa=Ia-(Q?ha:0)|0;c[t>>2]=pa;ha=(Q&1)<<2|11;Q=d[1252840+O|0]|0;ga=O<<Q;c[r>>2]=ga;O=pa<<Q;pa=Q+Ja|0;do{if((pa|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){Ka=O;La=pa;break}c[u>>2]=Q+2;Ma=Q;Ka=((he((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|O;La=pa-16|0}else{Ka=O;La=pa}}while(0);c[s>>2]=La;pa=((ga*148|0)-148>>8)+1|0;O=pa<<16;ma=Ka>>>0>=O>>>0;Ma=ma?ga-pa|0:pa;pa=Ka-(ma?O:0)|0;c[t>>2]=pa;O=((ma&1)<<1)+ha|0;ma=d[1252840+Ma|0]|0;Q=Ma<<ma;c[r>>2]=Q;Ma=pa<<ma;pa=ma+La|0;do{if((pa|0)>-1){ma=c[u>>2]|0;if(!(ma>>>0<(c[v>>2]|0)>>>0)){Na=Ma;Oa=pa;break}c[u>>2]=ma+2;Pa=ma;Na=((he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<pa|Ma;Oa=pa-16|0}else{Na=Ma;Oa=pa}}while(0);c[s>>2]=Oa;pa=((Q*140|0)-140>>8)+1|0;Ma=pa<<16;ha=Na>>>0>=Ma>>>0;c[r>>2]=ha?Q-pa|0:pa;c[t>>2]=Na-(ha?Ma:0);ea=O+(ha&1)|0;break}ha=sa-ia|0;Ma=Ga-da|0;c[t>>2]=Ma;pa=d[1252840+ha|0]|0;ga=ha<<pa;c[r>>2]=ga;ha=Ma<<pa;Ma=pa+Ha|0;do{if((Ma|0)>-1){pa=c[u>>2]|0;if(!(pa>>>0<(c[v>>2]|0)>>>0)){Qa=ha;Ra=Ma;break}c[u>>2]=pa+2;Pa=pa;Qa=((he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|ha;Ra=Ma-16|0}else{Qa=ha;Ra=Ma}}while(0);c[s>>2]=Ra;Ma=((ga*176|0)-176>>8)+1|0;ha=Ma<<16;da=Qa>>>0>=ha>>>0;ia=da?ga-Ma|0:Ma;Ma=Qa-(da?ha:0)|0;c[t>>2]=Ma;ha=(da&1)<<3;da=d[1252840+ia|0]|0;sa=ia<<da;c[r>>2]=sa;ia=Ma<<da;Ma=da+Ra|0;do{if((Ma|0)>-1){da=c[u>>2]|0;if(!(da>>>0<(c[v>>2]|0)>>>0)){Sa=ia;Ta=Ma;break}c[u>>2]=da+2;O=da;Sa=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|ia;Ta=Ma-16|0}else{Sa=ia;Ta=Ma}}while(0);c[s>>2]=Ta;Ma=((sa*155|0)-155>>8)+1|0;ia=Ma<<16;ga=Sa>>>0>=ia>>>0;O=ga?sa-Ma|0:Ma;Ma=Sa-(ga?ia:0)|0;c[t>>2]=Ma;ia=ha|(ga&1)<<2|19;ga=d[1252840+O|0]|0;da=O<<ga;c[r>>2]=da;O=Ma<<ga;Ma=ga+Ta|0;do{if((Ma|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){Ua=O;Va=Ma;break}c[u>>2]=ga+2;Q=ga;Ua=((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|O;Va=Ma-16|0}else{Ua=O;Va=Ma}}while(0);c[s>>2]=Va;Ma=((da*140|0)-140>>8)+1|0;O=Ma<<16;ha=Ua>>>0>=O>>>0;sa=ha?da-Ma|0:Ma;Ma=Ua-(ha?O:0)|0;c[t>>2]=Ma;O=((ha&1)<<1)+ia|0;ha=d[1252840+sa|0]|0;Q=sa<<ha;c[r>>2]=Q;sa=Ma<<ha;Ma=ha+Va|0;do{if((Ma|0)>-1){ha=c[u>>2]|0;if(!(ha>>>0<(c[v>>2]|0)>>>0)){Wa=sa;Xa=Ma;break}c[u>>2]=ha+2;ga=ha;Wa=((he((d[ga]|d[ga+1|0]<<8)<<16>>16|0)|0)&65535)<<Ma|sa;Xa=Ma-16|0}else{Wa=sa;Xa=Ma}}while(0);c[s>>2]=Xa;Ma=((Q*135|0)-135>>8)+1|0;sa=Ma<<16;ia=Wa>>>0>=sa>>>0;c[r>>2]=ia?Q-Ma|0:Ma;c[t>>2]=Wa-(ia?sa:0);ea=O+(ia&1)|0;break}ia=fa-la|0;c[r>>2]=ia;sa=Ea-za|0;c[t>>2]=sa;Ma=d[G+10|0]|0;da=d[1252840+ia|0]|0;ga=ia<<da;c[r>>2]=ga;ia=sa<<da;sa=da+Fa|0;do{if((sa|0)>-1){da=c[u>>2]|0;if(!(da>>>0<(c[v>>2]|0)>>>0)){Ya=ia;Za=sa;break}c[u>>2]=da+2;ha=da;Ya=((he((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535)<<sa|ia;Za=sa-16|0}else{Ya=ia;Za=sa}}while(0);c[s>>2]=Za;sa=((ca(ga-1|0,Ma)|0)>>8)+1|0;ia=sa<<16;if(Ya>>>0<ia>>>0){c[t>>2]=Ya;za=d[1252840+sa|0]|0;la=sa<<za;c[r>>2]=la;fa=Ya<<za;O=za+Za|0;do{if((O|0)>-1){za=c[u>>2]|0;if(!(za>>>0<(c[v>>2]|0)>>>0)){_a=fa;$a=O;break}c[u>>2]=za+2;Q=za;_a=((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<O|fa;$a=O-16|0}else{_a=fa;$a=O}}while(0);c[s>>2]=$a;O=((la*180|0)-180>>8)+1|0;fa=O<<16;Ma=_a>>>0>=fa>>>0;Q=Ma?la-O|0:O;O=_a-(Ma?fa:0)|0;c[t>>2]=O;fa=(Ma&1)<<4;Ma=d[1252840+Q|0]|0;za=Q<<Ma;c[r>>2]=za;Q=O<<Ma;O=Ma+$a|0;do{if((O|0)>-1){Ma=c[u>>2]|0;if(!(Ma>>>0<(c[v>>2]|0)>>>0)){ab=Q;bb=O;break}c[u>>2]=Ma+2;ha=Ma;ab=((he((d[ha]|d[ha+1|0]<<8)<<16>>16|0)|0)&65535)<<O|Q;bb=O-16|0}else{ab=Q;bb=O}}while(0);c[s>>2]=bb;O=((za*157|0)-157>>8)+1|0;Q=O<<16;la=ab>>>0>=Q>>>0;ha=la?za-O|0:O;O=ab-(la?Q:0)|0;c[t>>2]=O;Q=(la&1)<<3;la=d[1252840+ha|0]|0;Ma=ha<<la;c[r>>2]=Ma;ha=O<<la;O=la+bb|0;do{if((O|0)>-1){la=c[u>>2]|0;if(!(la>>>0<(c[v>>2]|0)>>>0)){cb=ha;db=O;break}c[u>>2]=la+2;da=la;cb=((he((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<O|ha;db=O-16|0}else{cb=ha;db=O}}while(0);c[s>>2]=db;O=((Ma*141|0)-141>>8)+1|0;ha=O<<16;za=cb>>>0>=ha>>>0;da=za?Ma-O|0:O;O=cb-(za?ha:0)|0;c[t>>2]=O;ha=fa|Q|(za&1)<<2|35;za=d[1252840+da|0]|0;la=da<<za;c[r>>2]=la;da=O<<za;O=za+db|0;do{if((O|0)>-1){za=c[u>>2]|0;if(!(za>>>0<(c[v>>2]|0)>>>0)){eb=da;fb=O;break}c[u>>2]=za+2;Pa=za;eb=((he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<O|da;fb=O-16|0}else{eb=da;fb=O}}while(0);c[s>>2]=fb;O=((la*134|0)-134>>8)+1|0;da=O<<16;Q=eb>>>0>=da>>>0;fa=Q?la-O|0:O;O=eb-(Q?da:0)|0;c[t>>2]=O;da=((Q&1)<<1)+ha|0;Q=d[1252840+fa|0]|0;Ma=fa<<Q;c[r>>2]=Ma;fa=O<<Q;O=Q+fb|0;do{if((O|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){gb=fa;hb=O;break}c[u>>2]=Q+2;Pa=Q;gb=((he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<O|fa;hb=O-16|0}else{gb=fa;hb=O}}while(0);c[s>>2]=hb;O=((Ma*130|0)-130>>8)+1|0;fa=O<<16;ha=gb>>>0>=fa>>>0;c[r>>2]=ha?Ma-O|0:O;c[t>>2]=gb-(ha?fa:0);ea=da+(ha&1)|0;break}ha=ga-sa|0;fa=Ya-ia|0;c[t>>2]=fa;O=d[1252840+ha|0]|0;la=ha<<O;c[r>>2]=la;ha=fa<<O;fa=O+Za|0;do{if((fa|0)>-1){O=c[u>>2]|0;if(!(O>>>0<(c[v>>2]|0)>>>0)){ib=ha;jb=fa;break}c[u>>2]=O+2;Pa=O;ib=((he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|ha;jb=fa-16|0}else{ib=ha;jb=fa}}while(0);c[s>>2]=jb;fa=((la*254|0)-254>>8)+1|0;ha=fa<<16;ia=ib>>>0>=ha>>>0;sa=ia?la-fa|0:fa;fa=ib-(ia?ha:0)|0;c[t>>2]=fa;ha=(ia&1)<<13;ia=d[1252840+sa|0]|0;ga=sa<<ia;c[r>>2]=ga;sa=fa<<ia;fa=ia+jb|0;do{if((fa|0)>-1){ia=c[u>>2]|0;if(!(ia>>>0<(c[v>>2]|0)>>>0)){kb=sa;lb=fa;break}c[u>>2]=ia+2;da=ia;kb=((he((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|sa;lb=fa-16|0}else{kb=sa;lb=fa}}while(0);c[s>>2]=lb;fa=((ga*254|0)-254>>8)+1|0;sa=fa<<16;la=kb>>>0>=sa>>>0;da=la?ga-fa|0:fa;fa=kb-(la?sa:0)|0;c[t>>2]=fa;sa=(la&1)<<12;la=d[1252840+da|0]|0;ia=da<<la;c[r>>2]=ia;da=fa<<la;fa=la+lb|0;do{if((fa|0)>-1){la=c[u>>2]|0;if(!(la>>>0<(c[v>>2]|0)>>>0)){mb=da;nb=fa;break}c[u>>2]=la+2;Ma=la;mb=((he((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|da;nb=fa-16|0}else{mb=da;nb=fa}}while(0);c[s>>2]=nb;fa=((ia*254|0)-254>>8)+1|0;da=fa<<16;ga=mb>>>0>=da>>>0;Ma=ga?ia-fa|0:fa;fa=mb-(ga?da:0)|0;c[t>>2]=fa;da=(ga&1)<<11;ga=d[1252840+Ma|0]|0;la=Ma<<ga;c[r>>2]=la;Ma=fa<<ga;fa=ga+nb|0;do{if((fa|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){ob=Ma;pb=fa;break}c[u>>2]=ga+2;Pa=ga;ob=((he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Ma;pb=fa-16|0}else{ob=Ma;pb=fa}}while(0);c[s>>2]=pb;fa=((la*252|0)-252>>8)+1|0;Ma=fa<<16;ia=ob>>>0>=Ma>>>0;Pa=ia?la-fa|0:fa;fa=ob-(ia?Ma:0)|0;c[t>>2]=fa;Ma=(ia&1)<<10;ia=d[1252840+Pa|0]|0;ga=Pa<<ia;c[r>>2]=ga;Pa=fa<<ia;fa=ia+pb|0;do{if((fa|0)>-1){ia=c[u>>2]|0;if(!(ia>>>0<(c[v>>2]|0)>>>0)){qb=Pa;rb=fa;break}c[u>>2]=ia+2;O=ia;qb=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Pa;rb=fa-16|0}else{qb=Pa;rb=fa}}while(0);c[s>>2]=rb;fa=((ga*249|0)-249>>8)+1|0;Pa=fa<<16;la=qb>>>0>=Pa>>>0;O=la?ga-fa|0:fa;fa=qb-(la?Pa:0)|0;c[t>>2]=fa;Pa=(la&1)<<9;la=d[1252840+O|0]|0;ia=O<<la;c[r>>2]=ia;O=fa<<la;fa=la+rb|0;do{if((fa|0)>-1){la=c[u>>2]|0;if(!(la>>>0<(c[v>>2]|0)>>>0)){sb=O;tb=fa;break}c[u>>2]=la+2;Q=la;sb=((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|O;tb=fa-16|0}else{sb=O;tb=fa}}while(0);c[s>>2]=tb;fa=((ia*243|0)-243>>8)+1|0;O=fa<<16;ga=sb>>>0>=O>>>0;Q=ga?ia-fa|0:fa;fa=sb-(ga?O:0)|0;c[t>>2]=fa;O=ha|sa|da|Ma|Pa|(ga&1)<<8|67;ga=d[1252840+Q|0]|0;la=Q<<ga;c[r>>2]=la;Q=fa<<ga;fa=ga+tb|0;do{if((fa|0)>-1){ga=c[u>>2]|0;if(!(ga>>>0<(c[v>>2]|0)>>>0)){ub=Q;vb=fa;break}c[u>>2]=ga+2;za=ga;ub=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Q;vb=fa-16|0}else{ub=Q;vb=fa}}while(0);c[s>>2]=vb;fa=((la*230|0)-230>>8)+1|0;Q=fa<<16;Pa=ub>>>0>=Q>>>0;Ma=Pa?la-fa|0:fa;fa=ub-(Pa?Q:0)|0;c[t>>2]=fa;Q=((Pa&1)<<7)+O|0;Pa=d[1252840+Ma|0]|0;da=Ma<<Pa;c[r>>2]=da;Ma=fa<<Pa;fa=Pa+vb|0;do{if((fa|0)>-1){Pa=c[u>>2]|0;if(!(Pa>>>0<(c[v>>2]|0)>>>0)){wb=Ma;xb=fa;break}c[u>>2]=Pa+2;sa=Pa;wb=((he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Ma;xb=fa-16|0}else{wb=Ma;xb=fa}}while(0);c[s>>2]=xb;fa=((da*196|0)-196>>8)+1|0;Ma=fa<<16;O=wb>>>0>=Ma>>>0;la=O?da-fa|0:fa;fa=wb-(O?Ma:0)|0;c[t>>2]=fa;Ma=Q+((O&1)<<6)|0;O=d[1252840+la|0]|0;sa=la<<O;c[r>>2]=sa;la=fa<<O;fa=O+xb|0;do{if((fa|0)>-1){O=c[u>>2]|0;if(!(O>>>0<(c[v>>2]|0)>>>0)){yb=la;zb=fa;break}c[u>>2]=O+2;Pa=O;yb=((he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|la;zb=fa-16|0}else{yb=la;zb=fa}}while(0);c[s>>2]=zb;fa=((sa*177|0)-177>>8)+1|0;la=fa<<16;Q=yb>>>0>=la>>>0;da=Q?sa-fa|0:fa;fa=yb-(Q?la:0)|0;c[t>>2]=fa;la=Ma+((Q&1)<<5)|0;Q=d[1252840+da|0]|0;Pa=da<<Q;c[r>>2]=Pa;da=fa<<Q;fa=Q+zb|0;do{if((fa|0)>-1){Q=c[u>>2]|0;if(!(Q>>>0<(c[v>>2]|0)>>>0)){Ab=da;Bb=fa;break}c[u>>2]=Q+2;O=Q;Ab=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|da;Bb=fa-16|0}else{Ab=da;Bb=fa}}while(0);c[s>>2]=Bb;fa=((Pa*153|0)-153>>8)+1|0;da=fa<<16;Ma=Ab>>>0>=da>>>0;sa=Ma?Pa-fa|0:fa;fa=Ab-(Ma?da:0)|0;c[t>>2]=fa;da=la+((Ma&1)<<4)|0;Ma=d[1252840+sa|0]|0;O=sa<<Ma;c[r>>2]=O;sa=fa<<Ma;fa=Ma+Bb|0;do{if((fa|0)>-1){Ma=c[u>>2]|0;if(!(Ma>>>0<(c[v>>2]|0)>>>0)){Cb=sa;Db=fa;break}c[u>>2]=Ma+2;Q=Ma;Cb=((he((d[Q]|d[Q+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|sa;Db=fa-16|0}else{Cb=sa;Db=fa}}while(0);c[s>>2]=Db;fa=((O*140|0)-140>>8)+1|0;sa=fa<<16;la=Cb>>>0>=sa>>>0;Pa=la?O-fa|0:fa;fa=Cb-(la?sa:0)|0;c[t>>2]=fa;sa=da+((la&1)<<3)|0;la=d[1252840+Pa|0]|0;Q=Pa<<la;c[r>>2]=Q;Pa=fa<<la;fa=la+Db|0;do{if((fa|0)>-1){la=c[u>>2]|0;if(!(la>>>0<(c[v>>2]|0)>>>0)){Eb=Pa;Fb=fa;break}c[u>>2]=la+2;Ma=la;Eb=((he((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Pa;Fb=fa-16|0}else{Eb=Pa;Fb=fa}}while(0);c[s>>2]=Fb;fa=((Q*133|0)-133>>8)+1|0;Pa=fa<<16;da=Eb>>>0>=Pa>>>0;O=da?Q-fa|0:fa;fa=Eb-(da?Pa:0)|0;c[t>>2]=fa;Pa=sa+((da&1)<<2)|0;da=d[1252840+O|0]|0;Ma=O<<da;c[r>>2]=Ma;O=fa<<da;fa=da+Fb|0;do{if((fa|0)>-1){da=c[u>>2]|0;if(!(da>>>0<(c[v>>2]|0)>>>0)){Gb=O;Hb=fa;break}c[u>>2]=da+2;la=da;Gb=((he((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|O;Hb=fa-16|0}else{Gb=O;Hb=fa}}while(0);c[s>>2]=Hb;fa=((Ma*130|0)-130>>8)+1|0;O=fa<<16;sa=Gb>>>0>=O>>>0;Q=sa?Ma-fa|0:fa;fa=Gb-(sa?O:0)|0;c[t>>2]=fa;O=Pa+((sa&1)<<1)|0;sa=d[1252840+Q|0]|0;la=Q<<sa;c[r>>2]=la;Q=fa<<sa;fa=sa+Hb|0;do{if((fa|0)>-1){sa=c[u>>2]|0;if(!(sa>>>0<(c[v>>2]|0)>>>0)){Ib=Q;Jb=fa;break}c[u>>2]=sa+2;da=sa;Ib=((he((d[da]|d[da+1|0]<<8)<<16>>16|0)|0)&65535)<<fa|Q;Jb=fa-16|0}else{Ib=Q;Jb=fa}}while(0);c[s>>2]=Jb;fa=((la*129|0)-129>>8)+1|0;Q=fa<<16;Pa=Ib>>>0>=Q>>>0;c[r>>2]=Pa?la-fa|0:fa;c[t>>2]=Ib-(Pa?Q:0);ea=O+(Pa&1)|0}}while(0);G=K-1|0;if((G|0)==0){H=E+1|0;Kb=b[n+(H<<1)>>1]|0;Lb=H}else{Kb=G;Lb=E}G=c[r>>2]|0;H=d[1252840+G|0]|0;S=c[s>>2]|0;F=c[t>>2]|0;D=G<<H;c[r>>2]=D;G=F<<H;F=S+H|0;do{if((F|0)>-1){H=c[u>>2]|0;if(!(H>>>0<(c[v>>2]|0)>>>0)){Mb=G;Nb=F;break}c[u>>2]=H+2;S=H;Mb=((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535)<<F|G;Nb=F-16|0}else{Mb=G;Nb=F}}while(0);c[s>>2]=Nb;F=((D<<7)-128>>8)+1|0;G=F<<16;E=Mb>>>0>=G>>>0;K=E?D-F|0:F;c[r>>2]=K;F=Mb-(E?G:0)|0;c[t>>2]=F;b[f+(P<<1)>>1]=(ca(E?-ea|0:ea,b[o+(((N|0)!=0)<<1)>>1]|0)|0)/2|0;E=((d[q+(b[m+(N<<2)>>1]|0)|0]|0)+1+(d[q+(b[m+(N<<2)+2>>1]|0)|0]|0)|0)>>>1;G=N+1|0;if((G|0)<1024){e=E;w=j+(Lb*66|0)+(E*11|0)|0;k=Kb;x=Lb;z=G;A=K;B=Nb;C=F}else{_=G;M=154;break}}if((M|0)==6){c[r>>2]=L;c[t>>2]=I;I=h+(x*48|0)+(e<<3)|0;c[I>>2]=(c[I>>2]|0)+1;_=z;i=p;return _|0}else if((M|0)==154){i=p;return _|0}return 0}function Bbb(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0;j=c[f+1084>>2]|0;if((h|0)==12){k=g;c[k>>2]=0;c[k+4>>2]=0;return}k=(h|0)==11|0;l=(h|0)==13;h=l?-1:i;Cbb(f,g,d[j+3|0]|0,0,k,h);m=l|(i|0)==-1;a:do{if(m){do{if((a[f+1147|0]|0)==0){n=0}else{i=b[g>>1]|0;o=i<<16>>16;if(((i<<16>>16>-1?o:-o|0)|0)>=64){n=0;break}o=b[g+2>>1]|0;i=o<<16>>16;p=((o<<16>>16>-1?i:-i|0)|0)<64;i=p&1;if(p){q=i;break a}else{n=i}}}while(0);i=g+2|0;p=b[i>>1]|0;do{if(!((p&1)==0)){if(p<<16>>16<0){b[i>>1]=p+1;break}else{b[i>>1]=p-1;break}}}while(0);p=g|0;i=b[p>>1]|0;if((i&1)==0){q=n;break}if(i<<16>>16<0){b[p>>1]=i+1;q=n;break}else{b[p>>1]=i-1;q=n;break}}else{q=0}}while(0);do{if(l){n=f+1052|0;i=f+1056|0;p=f+1068|0;o=f+1060|0;r=f+1064|0;s=0;t=c[n>>2]|0;u=c[i>>2]|0;v=c[p>>2]|0;while(1){w=a[f+10162+s|0]|0;x=d[1252840+t|0]|0;y=t<<x;c[n>>2]=y;z=v<<x;A=x+u|0;do{if((A|0)>-1){x=c[o>>2]|0;if(!(x>>>0<(c[r>>2]|0)>>>0)){B=z;C=A;break}c[o>>2]=x+2;D=x;B=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<A|z;C=A-16|0}else{B=z;C=A}}while(0);c[i>>2]=C;A=((ca(y-1|0,w&255)|0)>>8)+1|0;z=A<<16;D=B>>>0>=z>>>0;x=D?y-A|0:A;c[n>>2]=x;A=B-(D?z:0)|0;c[p>>2]=A;z=a[(D&1)+(211832+(s<<1))|0]|0;E=z<<24>>24;if(z<<24>>24>0){s=E;t=x;u=C;v=A}else{break}}v=-E|0;u=f+17636+(v<<2)|0;c[u>>2]=(c[u>>2]|0)+1;if(v>>>0>1>>>0){u=a[f+10165|0]|0;t=c[n>>2]|0;s=d[1252840+t|0]|0;A=c[i>>2]|0;x=c[p>>2]|0;z=t<<s;c[n>>2]=z;t=x<<s;x=A+s|0;do{if((x|0)>-1){s=c[o>>2]|0;if(!(s>>>0<(c[r>>2]|0)>>>0)){F=t;G=x;break}c[o>>2]=s+2;A=s;F=((he((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535)<<x|t;G=x-16|0}else{F=t;G=x}}while(0);c[i>>2]=G;x=((ca(z-1|0,u&255)|0)>>8)+1|0;t=x<<16;A=F>>>0>=t>>>0;s=A?z-x|0:x;c[n>>2]=s;x=F-(A?t:0)|0;c[p>>2]=x;t=0;D=s;s=G;H=x;while(1){x=a[f+10166+t|0]|0;I=d[1252840+D|0]|0;J=D<<I;c[n>>2]=J;K=H<<I;L=I+s|0;do{if((L|0)>-1){I=c[o>>2]|0;if(!(I>>>0<(c[r>>2]|0)>>>0)){M=K;N=L;break}c[o>>2]=I+2;O=I;M=((he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535)<<L|K;N=L-16|0}else{M=K;N=L}}while(0);c[i>>2]=N;L=((ca(J-1|0,x&255)|0)>>8)+1|0;K=L<<16;y=M>>>0>=K>>>0;w=y?J-L|0:L;c[n>>2]=w;L=M-(y?K:0)|0;c[p>>2]=L;P=a[(y&1)+(211864+(t<<1))|0]|0;Q=P<<24>>24;if(P<<24>>24>0){t=Q;D=w;s=N;H=L}else{break}}H=-Q|0;s=f+17652+((A&1)<<2)|0;c[s>>2]=(c[s>>2]|0)+1;s=f+17660+(H<<2)|0;c[s>>2]=(c[s>>2]|0)+1;do{if(P<<24>>24==0){s=a[f+10176|0]|0;D=c[n>>2]|0;t=d[1252840+D|0]|0;z=c[i>>2]|0;u=c[p>>2]|0;L=D<<t;c[n>>2]=L;D=u<<t;u=z+t|0;do{if((u|0)>-1){t=c[o>>2]|0;if(!(t>>>0<(c[r>>2]|0)>>>0)){R=D;S=u;break}c[o>>2]=t+2;z=t;R=((he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535)<<u|D;S=u-16|0}else{R=D;S=u}}while(0);c[i>>2]=S;u=((ca(L-1|0,s&255)|0)>>8)+1|0;D=u<<16;J=R>>>0>=D>>>0;x=J&1;c[n>>2]=J?L-u|0:u;c[p>>2]=R-(J?D:0);D=f+17704+(x<<2)|0;c[D>>2]=(c[D>>2]|0)+1;D=0;J=c[n>>2]|0;u=c[i>>2]|0;z=c[p>>2]|0;while(1){t=a[f+10187+(x*3|0)+D|0]|0;w=d[1252840+J|0]|0;y=J<<w;c[n>>2]=y;K=z<<w;O=w+u|0;do{if((O|0)>-1){w=c[o>>2]|0;if(!(w>>>0<(c[r>>2]|0)>>>0)){T=K;U=O;break}c[o>>2]=w+2;I=w;T=((he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535)<<O|K;U=O-16|0}else{T=K;U=O}}while(0);c[i>>2]=U;O=((ca(y-1|0,t&255)|0)>>8)+1|0;K=O<<16;I=T>>>0>=K>>>0;w=I?y-O|0:O;c[n>>2]=w;O=T-(I?K:0)|0;c[p>>2]=O;K=a[(I&1)+(211848+(D<<1))|0]|0;V=K<<24>>24;if(K<<24>>24>0){D=V;J=w;u=U;z=O}else{break}}z=-V|0;u=f+17792+(x<<4)+(z<<2)|0;c[u>>2]=(c[u>>2]|0)+1;u=z<<1|x<<3;if((q|0)==0){z=f+17844|0;c[z>>2]=(c[z>>2]|0)+1;W=u|1;break}z=a[f+10196|0]|0;J=c[n>>2]|0;D=d[1252840+J|0]|0;L=c[i>>2]|0;s=c[p>>2]|0;O=J<<D;c[n>>2]=O;J=s<<D;s=L+D|0;do{if((s|0)>-1){D=c[o>>2]|0;if(!(D>>>0<(c[r>>2]|0)>>>0)){X=J;Y=s;break}c[o>>2]=D+2;L=D;X=((he((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<s|J;Y=s-16|0}else{X=J;Y=s}}while(0);c[i>>2]=Y;s=((ca(O-1|0,z&255)|0)>>8)+1|0;J=s<<16;x=X>>>0>=J>>>0;L=x&1;c[n>>2]=x?O-s|0:s;c[p>>2]=X-(x?J:0);J=f+17840+(L<<2)|0;c[J>>2]=(c[J>>2]|0)+1;W=L|u}else{L=0;J=0;do{x=a[f+10177+J|0]|0;s=c[n>>2]|0;D=d[1252840+s|0]|0;w=c[i>>2]|0;K=c[p>>2]|0;I=s<<D;c[n>>2]=I;s=K<<D;K=w+D|0;do{if((K|0)>-1){D=c[o>>2]|0;if(!(D>>>0<(c[r>>2]|0)>>>0)){Z=s;_=K;break}c[o>>2]=D+2;w=D;Z=((he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<K|s;_=K-16|0}else{Z=s;_=K}}while(0);c[i>>2]=_;K=((ca(I-1|0,x&255)|0)>>8)+1|0;s=K<<16;y=Z>>>0>=s>>>0;t=y&1;c[n>>2]=y?I-K|0:K;c[p>>2]=Z-(y?s:0);L=t<<J|L;s=f+17712+(J<<3)+(t<<2)|0;c[s>>2]=(c[s>>2]|0)+1;J=J+1|0;}while((J|0)<(H|0));J=0;u=c[n>>2]|0;O=c[i>>2]|0;z=c[p>>2]|0;while(1){s=a[f+10193+J|0]|0;t=d[1252840+u|0]|0;y=u<<t;c[n>>2]=y;K=z<<t;w=t+O|0;do{if((w|0)>-1){t=c[o>>2]|0;if(!(t>>>0<(c[r>>2]|0)>>>0)){$=K;aa=w;break}c[o>>2]=t+2;D=t;$=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<w|K;aa=w-16|0}else{$=K;aa=w}}while(0);c[i>>2]=aa;w=((ca(y-1|0,s&255)|0)>>8)+1|0;K=w<<16;I=$>>>0>=K>>>0;x=I?y-w|0:w;c[n>>2]=x;w=$-(I?K:0)|0;c[p>>2]=w;K=a[(I&1)+(211848+(J<<1))|0]|0;ba=K<<24>>24;if(K<<24>>24>0){J=ba;u=x;O=aa;z=w}else{break}}z=-ba|0;O=z<<1|L<<3;u=f+17824+(z<<2)|0;c[u>>2]=(c[u>>2]|0)+1;if((q|0)==0){u=f+17852|0;c[u>>2]=(c[u>>2]|0)+1;da=1}else{u=a[f+10197|0]|0;z=c[n>>2]|0;J=d[1252840+z|0]|0;w=c[i>>2]|0;x=c[p>>2]|0;K=z<<J;c[n>>2]=K;z=x<<J;x=w+J|0;do{if((x|0)>-1){J=c[o>>2]|0;if(!(J>>>0<(c[r>>2]|0)>>>0)){ea=z;fa=x;break}c[o>>2]=J+2;w=J;ea=((he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535)<<x|z;fa=x-16|0}else{ea=z;fa=x}}while(0);c[i>>2]=fa;x=((ca(K-1|0,u&255)|0)>>8)+1|0;z=x<<16;L=ea>>>0>=z>>>0;w=L&1;c[n>>2]=L?K-x|0:x;c[p>>2]=ea-(L?z:0);z=f+17848+(w<<2)|0;c[z>>2]=(c[z>>2]|0)+1;da=w}W=(O|da)+(8<<H)|0}}while(0);H=g+2|0;b[H>>1]=(e[H>>1]|0)+(A?W^65535:W+1|0)}if((v&1|0)==0){break}H=a[f+10198|0]|0;w=c[n>>2]|0;z=d[1252840+w|0]|0;L=c[i>>2]|0;x=c[p>>2]|0;J=w<<z;c[n>>2]=J;w=x<<z;x=L+z|0;do{if((x|0)>-1){z=c[o>>2]|0;if(!(z>>>0<(c[r>>2]|0)>>>0)){ga=w;ha=x;break}c[o>>2]=z+2;L=z;ga=((he((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<x|w;ha=x-16|0}else{ga=w;ha=x}}while(0);c[i>>2]=ha;x=((ca(J-1|0,H&255)|0)>>8)+1|0;w=x<<16;v=ga>>>0>=w>>>0;A=v?J-x|0:x;c[n>>2]=A;x=ga-(v?w:0)|0;c[p>>2]=x;w=0;L=A;A=ha;z=x;while(1){x=a[f+10199+w|0]|0;I=d[1252840+L|0]|0;D=L<<I;c[n>>2]=D;t=z<<I;ia=I+A|0;do{if((ia|0)>-1){I=c[o>>2]|0;if(!(I>>>0<(c[r>>2]|0)>>>0)){ja=t;ka=ia;break}c[o>>2]=I+2;la=I;ja=((he((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535)<<ia|t;ka=ia-16|0}else{ja=t;ka=ia}}while(0);c[i>>2]=ka;ia=((ca(D-1|0,x&255)|0)>>8)+1|0;t=ia<<16;O=ja>>>0>=t>>>0;K=O?D-ia|0:ia;c[n>>2]=K;ia=ja-(O?t:0)|0;c[p>>2]=ia;ma=a[(O&1)+(211864+(w<<1))|0]|0;na=ma<<24>>24;if(ma<<24>>24>0){w=na;L=K;A=ka;z=ia}else{break}}z=-na|0;A=f+17856+((v&1)<<2)|0;c[A>>2]=(c[A>>2]|0)+1;A=f+17864+(z<<2)|0;c[A>>2]=(c[A>>2]|0)+1;do{if(ma<<24>>24==0){A=a[f+10209|0]|0;L=c[n>>2]|0;w=d[1252840+L|0]|0;J=c[i>>2]|0;H=c[p>>2]|0;ia=L<<w;c[n>>2]=ia;L=H<<w;H=J+w|0;do{if((H|0)>-1){w=c[o>>2]|0;if(!(w>>>0<(c[r>>2]|0)>>>0)){oa=L;pa=H;break}c[o>>2]=w+2;J=w;oa=((he((d[J]|d[J+1|0]<<8)<<16>>16|0)|0)&65535)<<H|L;pa=H-16|0}else{oa=L;pa=H}}while(0);c[i>>2]=pa;H=((ca(ia-1|0,A&255)|0)>>8)+1|0;L=H<<16;D=oa>>>0>=L>>>0;x=D&1;c[n>>2]=D?ia-H|0:H;c[p>>2]=oa-(D?L:0);L=f+17908+(x<<2)|0;c[L>>2]=(c[L>>2]|0)+1;L=0;D=c[n>>2]|0;H=c[i>>2]|0;J=c[p>>2]|0;while(1){w=a[f+10220+(x*3|0)+L|0]|0;K=d[1252840+D|0]|0;O=D<<K;c[n>>2]=O;t=J<<K;u=K+H|0;do{if((u|0)>-1){K=c[o>>2]|0;if(!(K>>>0<(c[r>>2]|0)>>>0)){qa=t;ra=u;break}c[o>>2]=K+2;la=K;qa=((he((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535)<<u|t;ra=u-16|0}else{qa=t;ra=u}}while(0);c[i>>2]=ra;u=((ca(O-1|0,w&255)|0)>>8)+1|0;t=u<<16;y=qa>>>0>=t>>>0;s=y?O-u|0:u;c[n>>2]=s;u=qa-(y?t:0)|0;c[p>>2]=u;t=a[(y&1)+(211848+(L<<1))|0]|0;sa=t<<24>>24;if(t<<24>>24>0){L=sa;D=s;H=ra;J=u}else{break}}J=-sa|0;H=f+17996+(x<<4)+(J<<2)|0;c[H>>2]=(c[H>>2]|0)+1;H=J<<1|x<<3;if((q|0)==0){J=f+18048|0;c[J>>2]=(c[J>>2]|0)+1;ta=H|1;break}J=a[f+10229|0]|0;D=c[n>>2]|0;L=d[1252840+D|0]|0;ia=c[i>>2]|0;A=c[p>>2]|0;u=D<<L;c[n>>2]=u;D=A<<L;A=ia+L|0;do{if((A|0)>-1){L=c[o>>2]|0;if(!(L>>>0<(c[r>>2]|0)>>>0)){ua=D;va=A;break}c[o>>2]=L+2;ia=L;ua=((he((d[ia]|d[ia+1|0]<<8)<<16>>16|0)|0)&65535)<<A|D;va=A-16|0}else{ua=D;va=A}}while(0);c[i>>2]=va;A=((ca(u-1|0,J&255)|0)>>8)+1|0;D=A<<16;x=ua>>>0>=D>>>0;ia=x&1;c[n>>2]=x?u-A|0:A;c[p>>2]=ua-(x?D:0);D=f+18044+(ia<<2)|0;c[D>>2]=(c[D>>2]|0)+1;ta=ia|H}else{ia=0;D=0;do{x=a[f+10210+D|0]|0;A=c[n>>2]|0;L=d[1252840+A|0]|0;s=c[i>>2]|0;t=c[p>>2]|0;y=A<<L;c[n>>2]=y;A=t<<L;t=s+L|0;do{if((t|0)>-1){L=c[o>>2]|0;if(!(L>>>0<(c[r>>2]|0)>>>0)){wa=A;xa=t;break}c[o>>2]=L+2;s=L;wa=((he((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<t|A;xa=t-16|0}else{wa=A;xa=t}}while(0);c[i>>2]=xa;t=((ca(y-1|0,x&255)|0)>>8)+1|0;A=t<<16;O=wa>>>0>=A>>>0;w=O&1;c[n>>2]=O?y-t|0:t;c[p>>2]=wa-(O?A:0);ia=w<<D|ia;A=f+17916+(D<<3)+(w<<2)|0;c[A>>2]=(c[A>>2]|0)+1;D=D+1|0;}while((D|0)<(z|0));D=0;H=c[n>>2]|0;u=c[i>>2]|0;J=c[p>>2]|0;while(1){A=a[f+10226+D|0]|0;w=d[1252840+H|0]|0;O=H<<w;c[n>>2]=O;t=J<<w;s=w+u|0;do{if((s|0)>-1){w=c[o>>2]|0;if(!(w>>>0<(c[r>>2]|0)>>>0)){ya=t;za=s;break}c[o>>2]=w+2;L=w;ya=((he((d[L]|d[L+1|0]<<8)<<16>>16|0)|0)&65535)<<s|t;za=s-16|0}else{ya=t;za=s}}while(0);c[i>>2]=za;s=((ca(O-1|0,A&255)|0)>>8)+1|0;t=s<<16;y=ya>>>0>=t>>>0;x=y?O-s|0:s;c[n>>2]=x;s=ya-(y?t:0)|0;c[p>>2]=s;t=a[(y&1)+(211848+(D<<1))|0]|0;Aa=t<<24>>24;if(t<<24>>24>0){D=Aa;H=x;u=za;J=s}else{break}}J=-Aa|0;u=J<<1|ia<<3;H=f+18028+(J<<2)|0;c[H>>2]=(c[H>>2]|0)+1;if((q|0)==0){H=f+18056|0;c[H>>2]=(c[H>>2]|0)+1;Ba=1}else{H=a[f+10230|0]|0;J=c[n>>2]|0;D=d[1252840+J|0]|0;s=c[i>>2]|0;x=c[p>>2]|0;t=J<<D;c[n>>2]=t;J=x<<D;x=s+D|0;do{if((x|0)>-1){D=c[o>>2]|0;if(!(D>>>0<(c[r>>2]|0)>>>0)){Ca=J;Da=x;break}c[o>>2]=D+2;s=D;Ca=((he((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<x|J;Da=x-16|0}else{Ca=J;Da=x}}while(0);c[i>>2]=Da;x=((ca(t-1|0,H&255)|0)>>8)+1|0;J=x<<16;ia=Ca>>>0>=J>>>0;s=ia&1;c[n>>2]=ia?t-x|0:x;c[p>>2]=Ca-(ia?J:0);J=f+18052+(s<<2)|0;c[J>>2]=(c[J>>2]|0)+1;Ba=s}ta=(u|Ba)+(8<<z)|0}}while(0);z=g|0;b[z>>1]=(e[z>>1]|0)+(v?ta^65535:ta+1|0)}}while(0);if((a[j+2|0]|0)==0){return}ta=g+4|0;Cbb(f,ta,d[j+4|0]|0,1,k,h);b:do{if(m){do{if((a[f+1147|0]|0)==0){Ea=0}else{h=b[ta>>1]|0;k=h<<16>>16;if(((h<<16>>16>-1?k:-k|0)|0)>=64){Ea=0;break}k=b[g+6>>1]|0;h=k<<16>>16;j=((k<<16>>16>-1?h:-h|0)|0)<64;h=j&1;if(j){Fa=h;break b}else{Ea=h}}}while(0);v=g+6|0;h=b[v>>1]|0;do{if(!((h&1)==0)){if(h<<16>>16<0){b[v>>1]=h+1;break}else{b[v>>1]=h-1;break}}}while(0);h=ta|0;v=b[h>>1]|0;if((v&1)==0){Fa=Ea;break}if(v<<16>>16<0){b[h>>1]=v+1;Fa=Ea;break}else{b[h>>1]=v-1;Fa=Ea;break}}else{Fa=q}}while(0);if(!l){return}l=f+1052|0;q=f+1056|0;Ea=f+1068|0;m=f+1060|0;v=f+1064|0;h=0;j=c[l>>2]|0;k=c[q>>2]|0;Ba=c[Ea>>2]|0;while(1){Ca=a[f+10162+h|0]|0;Da=d[1252840+j|0]|0;Aa=j<<Da;c[l>>2]=Aa;za=Ba<<Da;ya=Da+k|0;do{if((ya|0)>-1){Da=c[m>>2]|0;if(!(Da>>>0<(c[v>>2]|0)>>>0)){Ga=za;Ha=ya;break}c[m>>2]=Da+2;wa=Da;Ga=((he((d[wa]|d[wa+1|0]<<8)<<16>>16|0)|0)&65535)<<ya|za;Ha=ya-16|0}else{Ga=za;Ha=ya}}while(0);c[q>>2]=Ha;ya=((ca(Aa-1|0,Ca&255)|0)>>8)+1|0;za=ya<<16;wa=Ga>>>0>=za>>>0;Da=wa?Aa-ya|0:ya;c[l>>2]=Da;ya=Ga-(wa?za:0)|0;c[Ea>>2]=ya;za=a[(wa&1)+(211832+(h<<1))|0]|0;Ia=za<<24>>24;if(za<<24>>24>0){h=Ia;j=Da;k=Ha;Ba=ya}else{break}}Ba=-Ia|0;Ia=f+17636+(Ba<<2)|0;c[Ia>>2]=(c[Ia>>2]|0)+1;if(Ba>>>0>1>>>0){Ia=a[f+10165|0]|0;Ha=c[l>>2]|0;k=d[1252840+Ha|0]|0;j=c[q>>2]|0;h=c[Ea>>2]|0;Ga=Ha<<k;c[l>>2]=Ga;Ha=h<<k;h=j+k|0;do{if((h|0)>-1){k=c[m>>2]|0;if(!(k>>>0<(c[v>>2]|0)>>>0)){Ja=Ha;Ka=h;break}c[m>>2]=k+2;j=k;Ja=((he((d[j]|d[j+1|0]<<8)<<16>>16|0)|0)&65535)<<h|Ha;Ka=h-16|0}else{Ja=Ha;Ka=h}}while(0);c[q>>2]=Ka;h=((ca(Ga-1|0,Ia&255)|0)>>8)+1|0;Ia=h<<16;Ha=Ja>>>0>=Ia>>>0;j=Ha?Ga-h|0:h;c[l>>2]=j;h=Ja-(Ha?Ia:0)|0;c[Ea>>2]=h;Ia=0;Ja=j;j=Ka;Ka=h;while(1){h=a[f+10166+Ia|0]|0;Ga=d[1252840+Ja|0]|0;k=Ja<<Ga;c[l>>2]=k;ya=Ka<<Ga;Da=Ga+j|0;do{if((Da|0)>-1){Ga=c[m>>2]|0;if(!(Ga>>>0<(c[v>>2]|0)>>>0)){La=ya;Ma=Da;break}c[m>>2]=Ga+2;za=Ga;La=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<Da|ya;Ma=Da-16|0}else{La=ya;Ma=Da}}while(0);c[q>>2]=Ma;Da=((ca(k-1|0,h&255)|0)>>8)+1|0;ya=Da<<16;Aa=La>>>0>=ya>>>0;Ca=Aa?k-Da|0:Da;c[l>>2]=Ca;Da=La-(Aa?ya:0)|0;c[Ea>>2]=Da;Na=a[(Aa&1)+(211864+(Ia<<1))|0]|0;Oa=Na<<24>>24;if(Na<<24>>24>0){Ia=Oa;Ja=Ca;j=Ma;Ka=Da}else{break}}Ka=-Oa|0;Oa=f+17652+((Ha&1)<<2)|0;c[Oa>>2]=(c[Oa>>2]|0)+1;Oa=f+17660+(Ka<<2)|0;c[Oa>>2]=(c[Oa>>2]|0)+1;do{if(Na<<24>>24==0){Oa=a[f+10176|0]|0;Ma=c[l>>2]|0;j=d[1252840+Ma|0]|0;Ja=c[q>>2]|0;Ia=c[Ea>>2]|0;La=Ma<<j;c[l>>2]=La;Ma=Ia<<j;Ia=Ja+j|0;do{if((Ia|0)>-1){j=c[m>>2]|0;if(!(j>>>0<(c[v>>2]|0)>>>0)){Pa=Ma;Qa=Ia;break}c[m>>2]=j+2;Ja=j;Pa=((he((d[Ja]|d[Ja+1|0]<<8)<<16>>16|0)|0)&65535)<<Ia|Ma;Qa=Ia-16|0}else{Pa=Ma;Qa=Ia}}while(0);c[q>>2]=Qa;Ia=((ca(La-1|0,Oa&255)|0)>>8)+1|0;Ma=Ia<<16;k=Pa>>>0>=Ma>>>0;h=k&1;c[l>>2]=k?La-Ia|0:Ia;c[Ea>>2]=Pa-(k?Ma:0);Ma=f+17704+(h<<2)|0;c[Ma>>2]=(c[Ma>>2]|0)+1;Ma=0;k=c[l>>2]|0;Ia=c[q>>2]|0;Ja=c[Ea>>2]|0;while(1){j=a[f+10187+(h*3|0)+Ma|0]|0;Da=d[1252840+k|0]|0;Ca=k<<Da;c[l>>2]=Ca;Aa=Ja<<Da;ya=Da+Ia|0;do{if((ya|0)>-1){Da=c[m>>2]|0;if(!(Da>>>0<(c[v>>2]|0)>>>0)){Ra=Aa;Sa=ya;break}c[m>>2]=Da+2;za=Da;Ra=((he((d[za]|d[za+1|0]<<8)<<16>>16|0)|0)&65535)<<ya|Aa;Sa=ya-16|0}else{Ra=Aa;Sa=ya}}while(0);c[q>>2]=Sa;ya=((ca(Ca-1|0,j&255)|0)>>8)+1|0;Aa=ya<<16;u=Ra>>>0>=Aa>>>0;t=u?Ca-ya|0:ya;c[l>>2]=t;ya=Ra-(u?Aa:0)|0;c[Ea>>2]=ya;Aa=a[(u&1)+(211848+(Ma<<1))|0]|0;Ta=Aa<<24>>24;if(Aa<<24>>24>0){Ma=Ta;k=t;Ia=Sa;Ja=ya}else{break}}Ja=-Ta|0;Ia=f+17792+(h<<4)+(Ja<<2)|0;c[Ia>>2]=(c[Ia>>2]|0)+1;Ia=Ja<<1|h<<3;if((Fa|0)==0){Ja=f+17844|0;c[Ja>>2]=(c[Ja>>2]|0)+1;Ua=Ia|1;break}Ja=a[f+10196|0]|0;k=c[l>>2]|0;Ma=d[1252840+k|0]|0;La=c[q>>2]|0;Oa=c[Ea>>2]|0;ya=k<<Ma;c[l>>2]=ya;k=Oa<<Ma;Oa=La+Ma|0;do{if((Oa|0)>-1){Ma=c[m>>2]|0;if(!(Ma>>>0<(c[v>>2]|0)>>>0)){Va=k;Wa=Oa;break}c[m>>2]=Ma+2;La=Ma;Va=((he((d[La]|d[La+1|0]<<8)<<16>>16|0)|0)&65535)<<Oa|k;Wa=Oa-16|0}else{Va=k;Wa=Oa}}while(0);c[q>>2]=Wa;Oa=((ca(ya-1|0,Ja&255)|0)>>8)+1|0;k=Oa<<16;h=Va>>>0>=k>>>0;La=h&1;c[l>>2]=h?ya-Oa|0:Oa;c[Ea>>2]=Va-(h?k:0);k=f+17840+(La<<2)|0;c[k>>2]=(c[k>>2]|0)+1;Ua=La|Ia}else{La=0;k=0;do{h=a[f+10177+k|0]|0;Oa=c[l>>2]|0;Ma=d[1252840+Oa|0]|0;t=c[q>>2]|0;Aa=c[Ea>>2]|0;u=Oa<<Ma;c[l>>2]=u;Oa=Aa<<Ma;Aa=t+Ma|0;do{if((Aa|0)>-1){Ma=c[m>>2]|0;if(!(Ma>>>0<(c[v>>2]|0)>>>0)){Xa=Oa;Ya=Aa;break}c[m>>2]=Ma+2;t=Ma;Xa=((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<Aa|Oa;Ya=Aa-16|0}else{Xa=Oa;Ya=Aa}}while(0);c[q>>2]=Ya;Aa=((ca(u-1|0,h&255)|0)>>8)+1|0;Oa=Aa<<16;Ca=Xa>>>0>=Oa>>>0;j=Ca&1;c[l>>2]=Ca?u-Aa|0:Aa;c[Ea>>2]=Xa-(Ca?Oa:0);La=j<<k|La;Oa=f+17712+(k<<3)+(j<<2)|0;c[Oa>>2]=(c[Oa>>2]|0)+1;k=k+1|0;}while((k|0)<(Ka|0));k=0;Ia=c[l>>2]|0;ya=c[q>>2]|0;Ja=c[Ea>>2]|0;while(1){Oa=a[f+10193+k|0]|0;j=d[1252840+Ia|0]|0;Ca=Ia<<j;c[l>>2]=Ca;Aa=Ja<<j;t=j+ya|0;do{if((t|0)>-1){j=c[m>>2]|0;if(!(j>>>0<(c[v>>2]|0)>>>0)){Za=Aa;_a=t;break}c[m>>2]=j+2;Ma=j;Za=((he((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0)&65535)<<t|Aa;_a=t-16|0}else{Za=Aa;_a=t}}while(0);c[q>>2]=_a;t=((ca(Ca-1|0,Oa&255)|0)>>8)+1|0;Aa=t<<16;u=Za>>>0>=Aa>>>0;h=u?Ca-t|0:t;c[l>>2]=h;t=Za-(u?Aa:0)|0;c[Ea>>2]=t;Aa=a[(u&1)+(211848+(k<<1))|0]|0;$a=Aa<<24>>24;if(Aa<<24>>24>0){k=$a;Ia=h;ya=_a;Ja=t}else{break}}Ja=-$a|0;ya=Ja<<1|La<<3;Ia=f+17824+(Ja<<2)|0;c[Ia>>2]=(c[Ia>>2]|0)+1;if((Fa|0)==0){Ia=f+17852|0;c[Ia>>2]=(c[Ia>>2]|0)+1;ab=1}else{Ia=a[f+10197|0]|0;Ja=c[l>>2]|0;k=d[1252840+Ja|0]|0;t=c[q>>2]|0;h=c[Ea>>2]|0;Aa=Ja<<k;c[l>>2]=Aa;Ja=h<<k;h=t+k|0;do{if((h|0)>-1){k=c[m>>2]|0;if(!(k>>>0<(c[v>>2]|0)>>>0)){bb=Ja;cb=h;break}c[m>>2]=k+2;t=k;bb=((he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535)<<h|Ja;cb=h-16|0}else{bb=Ja;cb=h}}while(0);c[q>>2]=cb;h=((ca(Aa-1|0,Ia&255)|0)>>8)+1|0;Ja=h<<16;La=bb>>>0>=Ja>>>0;t=La&1;c[l>>2]=La?Aa-h|0:h;c[Ea>>2]=bb-(La?Ja:0);Ja=f+17848+(t<<2)|0;c[Ja>>2]=(c[Ja>>2]|0)+1;ab=t}Ua=(ya|ab)+(8<<Ka)|0}}while(0);Ka=g+6|0;b[Ka>>1]=(e[Ka>>1]|0)+(Ha?Ua^65535:Ua+1|0)}if((Ba&1|0)==0){return}Ba=a[f+10198|0]|0;Ua=c[l>>2]|0;Ha=d[1252840+Ua|0]|0;Ka=c[q>>2]|0;g=c[Ea>>2]|0;ab=Ua<<Ha;c[l>>2]=ab;Ua=g<<Ha;g=Ka+Ha|0;do{if((g|0)>-1){Ha=c[m>>2]|0;if(!(Ha>>>0<(c[v>>2]|0)>>>0)){db=Ua;eb=g;break}c[m>>2]=Ha+2;Ka=Ha;db=((he((d[Ka]|d[Ka+1|0]<<8)<<16>>16|0)|0)&65535)<<g|Ua;eb=g-16|0}else{db=Ua;eb=g}}while(0);c[q>>2]=eb;g=((ca(ab-1|0,Ba&255)|0)>>8)+1|0;Ba=g<<16;Ua=db>>>0>=Ba>>>0;Ka=Ua?ab-g|0:g;c[l>>2]=Ka;g=db-(Ua?Ba:0)|0;c[Ea>>2]=g;Ba=0;db=Ka;Ka=eb;eb=g;while(1){g=a[f+10199+Ba|0]|0;ab=d[1252840+db|0]|0;Ha=db<<ab;c[l>>2]=Ha;bb=eb<<ab;cb=ab+Ka|0;do{if((cb|0)>-1){ab=c[m>>2]|0;if(!(ab>>>0<(c[v>>2]|0)>>>0)){fb=bb;gb=cb;break}c[m>>2]=ab+2;$a=ab;fb=((he((d[$a]|d[$a+1|0]<<8)<<16>>16|0)|0)&65535)<<cb|bb;gb=cb-16|0}else{fb=bb;gb=cb}}while(0);c[q>>2]=gb;cb=((ca(Ha-1|0,g&255)|0)>>8)+1|0;bb=cb<<16;ya=fb>>>0>=bb>>>0;Aa=ya?Ha-cb|0:cb;c[l>>2]=Aa;cb=fb-(ya?bb:0)|0;c[Ea>>2]=cb;hb=a[(ya&1)+(211864+(Ba<<1))|0]|0;ib=hb<<24>>24;if(hb<<24>>24>0){Ba=ib;db=Aa;Ka=gb;eb=cb}else{break}}eb=-ib|0;ib=f+17856+((Ua&1)<<2)|0;c[ib>>2]=(c[ib>>2]|0)+1;ib=f+17864+(eb<<2)|0;c[ib>>2]=(c[ib>>2]|0)+1;do{if(hb<<24>>24==0){ib=a[f+10209|0]|0;gb=c[l>>2]|0;Ka=d[1252840+gb|0]|0;db=c[q>>2]|0;Ba=c[Ea>>2]|0;fb=gb<<Ka;c[l>>2]=fb;gb=Ba<<Ka;Ba=db+Ka|0;do{if((Ba|0)>-1){Ka=c[m>>2]|0;if(!(Ka>>>0<(c[v>>2]|0)>>>0)){jb=gb;kb=Ba;break}c[m>>2]=Ka+2;db=Ka;jb=((he((d[db]|d[db+1|0]<<8)<<16>>16|0)|0)&65535)<<Ba|gb;kb=Ba-16|0}else{jb=gb;kb=Ba}}while(0);c[q>>2]=kb;Ba=((ca(fb-1|0,ib&255)|0)>>8)+1|0;gb=Ba<<16;Ha=jb>>>0>=gb>>>0;g=Ha&1;c[l>>2]=Ha?fb-Ba|0:Ba;c[Ea>>2]=jb-(Ha?gb:0);gb=f+17908+(g<<2)|0;c[gb>>2]=(c[gb>>2]|0)+1;gb=0;Ha=c[l>>2]|0;Ba=c[q>>2]|0;db=c[Ea>>2]|0;while(1){Ka=a[f+10220+(g*3|0)+gb|0]|0;cb=d[1252840+Ha|0]|0;Aa=Ha<<cb;c[l>>2]=Aa;ya=db<<cb;bb=cb+Ba|0;do{if((bb|0)>-1){cb=c[m>>2]|0;if(!(cb>>>0<(c[v>>2]|0)>>>0)){lb=ya;mb=bb;break}c[m>>2]=cb+2;Ia=cb;lb=((he((d[Ia]|d[Ia+1|0]<<8)<<16>>16|0)|0)&65535)<<bb|ya;mb=bb-16|0}else{lb=ya;mb=bb}}while(0);c[q>>2]=mb;bb=((ca(Aa-1|0,Ka&255)|0)>>8)+1|0;ya=bb<<16;Ca=lb>>>0>=ya>>>0;Oa=Ca?Aa-bb|0:bb;c[l>>2]=Oa;bb=lb-(Ca?ya:0)|0;c[Ea>>2]=bb;ya=a[(Ca&1)+(211848+(gb<<1))|0]|0;nb=ya<<24>>24;if(ya<<24>>24>0){gb=nb;Ha=Oa;Ba=mb;db=bb}else{break}}db=-nb|0;Ba=f+17996+(g<<4)+(db<<2)|0;c[Ba>>2]=(c[Ba>>2]|0)+1;Ba=db<<1|g<<3;if((Fa|0)==0){db=f+18048|0;c[db>>2]=(c[db>>2]|0)+1;ob=Ba|1;break}db=a[f+10229|0]|0;Ha=c[l>>2]|0;gb=d[1252840+Ha|0]|0;fb=c[q>>2]|0;ib=c[Ea>>2]|0;bb=Ha<<gb;c[l>>2]=bb;Ha=ib<<gb;ib=fb+gb|0;do{if((ib|0)>-1){gb=c[m>>2]|0;if(!(gb>>>0<(c[v>>2]|0)>>>0)){pb=Ha;qb=ib;break}c[m>>2]=gb+2;fb=gb;pb=((he((d[fb]|d[fb+1|0]<<8)<<16>>16|0)|0)&65535)<<ib|Ha;qb=ib-16|0}else{pb=Ha;qb=ib}}while(0);c[q>>2]=qb;ib=((ca(bb-1|0,db&255)|0)>>8)+1|0;Ha=ib<<16;g=pb>>>0>=Ha>>>0;fb=g&1;c[l>>2]=g?bb-ib|0:ib;c[Ea>>2]=pb-(g?Ha:0);Ha=f+18044+(fb<<2)|0;c[Ha>>2]=(c[Ha>>2]|0)+1;ob=fb|Ba}else{fb=0;Ha=0;do{g=a[f+10210+Ha|0]|0;ib=c[l>>2]|0;gb=d[1252840+ib|0]|0;Oa=c[q>>2]|0;ya=c[Ea>>2]|0;Ca=ib<<gb;c[l>>2]=Ca;ib=ya<<gb;ya=Oa+gb|0;do{if((ya|0)>-1){gb=c[m>>2]|0;if(!(gb>>>0<(c[v>>2]|0)>>>0)){rb=ib;sb=ya;break}c[m>>2]=gb+2;Oa=gb;rb=((he((d[Oa]|d[Oa+1|0]<<8)<<16>>16|0)|0)&65535)<<ya|ib;sb=ya-16|0}else{rb=ib;sb=ya}}while(0);c[q>>2]=sb;ya=((ca(Ca-1|0,g&255)|0)>>8)+1|0;ib=ya<<16;Aa=rb>>>0>=ib>>>0;Ka=Aa&1;c[l>>2]=Aa?Ca-ya|0:ya;c[Ea>>2]=rb-(Aa?ib:0);fb=Ka<<Ha|fb;ib=f+17916+(Ha<<3)+(Ka<<2)|0;c[ib>>2]=(c[ib>>2]|0)+1;Ha=Ha+1|0;}while((Ha|0)<(eb|0));Ha=0;Ba=c[l>>2]|0;bb=c[q>>2]|0;db=c[Ea>>2]|0;while(1){ib=a[f+10226+Ha|0]|0;Ka=d[1252840+Ba|0]|0;Aa=Ba<<Ka;c[l>>2]=Aa;ya=db<<Ka;Oa=Ka+bb|0;do{if((Oa|0)>-1){Ka=c[m>>2]|0;if(!(Ka>>>0<(c[v>>2]|0)>>>0)){tb=ya;ub=Oa;break}c[m>>2]=Ka+2;gb=Ka;tb=((he((d[gb]|d[gb+1|0]<<8)<<16>>16|0)|0)&65535)<<Oa|ya;ub=Oa-16|0}else{tb=ya;ub=Oa}}while(0);c[q>>2]=ub;Oa=((ca(Aa-1|0,ib&255)|0)>>8)+1|0;ya=Oa<<16;Ca=tb>>>0>=ya>>>0;g=Ca?Aa-Oa|0:Oa;c[l>>2]=g;Oa=tb-(Ca?ya:0)|0;c[Ea>>2]=Oa;ya=a[(Ca&1)+(211848+(Ha<<1))|0]|0;vb=ya<<24>>24;if(ya<<24>>24>0){Ha=vb;Ba=g;bb=ub;db=Oa}else{break}}db=-vb|0;bb=db<<1|fb<<3;Ba=f+18028+(db<<2)|0;c[Ba>>2]=(c[Ba>>2]|0)+1;if((Fa|0)==0){Ba=f+18056|0;c[Ba>>2]=(c[Ba>>2]|0)+1;wb=1}else{Ba=a[f+10230|0]|0;db=c[l>>2]|0;Ha=d[1252840+db|0]|0;Oa=c[q>>2]|0;g=c[Ea>>2]|0;ya=db<<Ha;c[l>>2]=ya;db=g<<Ha;g=Oa+Ha|0;do{if((g|0)>-1){Ha=c[m>>2]|0;if(!(Ha>>>0<(c[v>>2]|0)>>>0)){xb=db;yb=g;break}c[m>>2]=Ha+2;Oa=Ha;xb=((he((d[Oa]|d[Oa+1|0]<<8)<<16>>16|0)|0)&65535)<<g|db;yb=g-16|0}else{xb=db;yb=g}}while(0);c[q>>2]=yb;g=((ca(ya-1|0,Ba&255)|0)>>8)+1|0;db=g<<16;fb=xb>>>0>=db>>>0;Oa=fb&1;c[l>>2]=fb?ya-g|0:g;c[Ea>>2]=xb-(fb?db:0);db=f+18052+(Oa<<2)|0;c[db>>2]=(c[db>>2]|0)+1;wb=Oa}ob=(bb|wb)+(8<<eb)|0}}while(0);eb=ta|0;b[eb>>1]=(e[eb>>1]|0)+(Ua?ob^65535:ob+1|0);return}function Cbb(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0;j=c[d+1084>>2]|0;k=c[d+1100>>2]|0;l=c[d+1108>>2]|0;m=c[d+1104>>2]|0;n=c[j+48>>2]|0;do{if((i|0)>-1){do{if((i-1|0)>>>0<2>>>0){o=c[j+16+(g<<2)>>2]|0;if((h|0)!=0){p=o;break}c[e>>2]=o;return}else{if((i|0)!=3){p=-2147450880;break}o=c[j+32+(g<<2)>>2]|0;if((h|0)==0){c[e>>2]=o;return}q=c[j+24+(g<<2)>>2]|0;do{if((o|0)==-2147450880){r=q}else{if((q|0)==(o|0)){r=o;break}c[e>>2]=q;return}}while(0);q=c[j+16+(g<<2)>>2]|0;if((r|0)==-2147450880){p=q;break}if((q|0)==(r|0)){p=r;break}c[e>>2]=q;return}}while(0);do{if((k|0)>0){q=(ca((k<<3)-8|0,c[d+1796>>2]|0)|0)+l|0;o=c[d+1380>>2]|0;if((a[o+(q*12|0)+8|0]|0)==(f|0)){s=l<<1|i&1;t=c[d+30144>>2]|0;u=t+(s<<3)|0;if((i|0)>0){v=b[u>>1]|0;w=c[d+35908>>2]|0;x=c[d+35916>>2]|0;if((v|0)<(w|0)){y=w&65535}else{y=((v|0)>(x|0)?x:v)&65535}v=b[t+(s<<3)+2>>1]|0;x=c[d+35912>>2]|0;w=c[d+35920>>2]|0;if((v|0)<(x|0)){z=x&65535}else{z=((v|0)>(w|0)?w:v)&65535}v=(z&65535)<<16|y&65535;if((h|0)==0){c[e>>2]=v;return}if((p|0)==-2147450880){A=v;break}if((v|0)==(p|0)){A=p;break}c[e>>2]=v;return}v=c[u>>2]|0;u=v&65535;if((h|0)==0){w=u<<16>>16;x=c[d+35908>>2]|0;B=c[d+35916>>2]|0;if((w|0)<(x|0)){C=x&65535}else{C=((w|0)>(B|0)?B:w)&65535}b[e>>1]=C;w=b[t+(s<<3)+2>>1]|0;B=c[d+35912>>2]|0;x=c[d+35920>>2]|0;if((w|0)<(B|0)){D=B&65535}else{D=((w|0)>(x|0)?x:w)&65535}b[e+2>>1]=D;return}if((p|0)==-2147450880){A=v;break}if((v|0)==(p|0)){A=p;break}v=u<<16>>16;u=c[d+35908>>2]|0;w=c[d+35916>>2]|0;if((v|0)<(u|0)){E=u&65535}else{E=((v|0)>(w|0)?w:v)&65535}b[e>>1]=E;v=b[t+(s<<3)+2>>1]|0;s=c[d+35912>>2]|0;t=c[d+35920>>2]|0;if((v|0)<(s|0)){F=s&65535}else{F=((v|0)>(t|0)?t:v)&65535}b[e+2>>1]=F;return}if((a[o+(q*12|0)+9|0]|0)!=(f|0)){A=p;break}q=l<<1|i&1;o=c[d+30144>>2]|0;v=o+(q<<3)+4|0;if((i|0)>0){t=b[v>>1]|0;s=c[d+35908>>2]|0;w=c[d+35916>>2]|0;if((t|0)<(s|0)){G=s&65535}else{G=((t|0)>(w|0)?w:t)&65535}t=b[o+(q<<3)+6>>1]|0;w=c[d+35912>>2]|0;s=c[d+35920>>2]|0;if((t|0)<(w|0)){H=w&65535}else{H=((t|0)>(s|0)?s:t)&65535}t=(H&65535)<<16|G&65535;if((h|0)==0){c[e>>2]=t;return}if((p|0)==-2147450880){A=t;break}if((t|0)==(p|0)){A=p;break}c[e>>2]=t;return}t=c[v>>2]|0;v=t&65535;if((h|0)==0){s=v<<16>>16;w=c[d+35908>>2]|0;u=c[d+35916>>2]|0;if((s|0)<(w|0)){I=w&65535}else{I=((s|0)>(u|0)?u:s)&65535}b[e>>1]=I;s=b[o+(q<<3)+6>>1]|0;u=c[d+35912>>2]|0;w=c[d+35920>>2]|0;if((s|0)<(u|0)){J=u&65535}else{J=((s|0)>(w|0)?w:s)&65535}b[e+2>>1]=J;return}if((p|0)==-2147450880){A=t;break}if((t|0)==(p|0)){A=p;break}t=v<<16>>16;v=c[d+35908>>2]|0;s=c[d+35916>>2]|0;if((t|0)<(v|0)){K=v&65535}else{K=((t|0)>(s|0)?s:t)&65535}b[e>>1]=K;t=b[o+(q<<3)+6>>1]|0;q=c[d+35912>>2]|0;o=c[d+35920>>2]|0;if((t|0)<(q|0)){L=q&65535}else{L=((t|0)>(o|0)?o:t)&65535}b[e+2>>1]=L;return}else{A=p}}while(0);t=c[d+1788>>2]|0;if(!(l>>>0>t>>>0)){M=A;N=2;O=t;break}o=l-1+(ca(k<<3,c[d+1796>>2]|0)|0)|0;q=c[d+1380>>2]|0;if((a[q+(o*12|0)+8|0]|0)==(f|0)){s=(m<<1)+(i>>1)|0;v=d+29888+(s<<3)|0;if((i|0)>0){w=b[v>>1]|0;u=c[d+35908>>2]|0;x=c[d+35916>>2]|0;if((w|0)<(u|0)){P=u&65535}else{P=((w|0)>(x|0)?x:w)&65535}w=b[d+29888+(s<<3)+2>>1]|0;x=c[d+35912>>2]|0;u=c[d+35920>>2]|0;if((w|0)<(x|0)){Q=x&65535}else{Q=((w|0)>(u|0)?u:w)&65535}w=(Q&65535)<<16|P&65535;if((h|0)==0){c[e>>2]=w;return}if((A|0)==-2147450880){M=w;N=2;O=t;break}if((w|0)==(A|0)){M=A;N=2;O=t;break}c[e>>2]=w;return}w=c[v>>2]|0;v=w&65535;if((h|0)==0){u=v<<16>>16;x=c[d+35908>>2]|0;B=c[d+35916>>2]|0;if((u|0)<(x|0)){R=x&65535}else{R=((u|0)>(B|0)?B:u)&65535}b[e>>1]=R;u=b[d+29888+(s<<3)+2>>1]|0;B=c[d+35912>>2]|0;x=c[d+35920>>2]|0;if((u|0)<(B|0)){S=B&65535}else{S=((u|0)>(x|0)?x:u)&65535}b[e+2>>1]=S;return}if((A|0)==-2147450880){M=w;N=2;O=t;break}if((w|0)==(A|0)){M=A;N=2;O=t;break}w=v<<16>>16;v=c[d+35908>>2]|0;u=c[d+35916>>2]|0;if((w|0)<(v|0)){T=v&65535}else{T=((w|0)>(u|0)?u:w)&65535}b[e>>1]=T;w=b[d+29888+(s<<3)+2>>1]|0;s=c[d+35912>>2]|0;u=c[d+35920>>2]|0;if((w|0)<(s|0)){U=s&65535}else{U=((w|0)>(u|0)?u:w)&65535}b[e+2>>1]=U;return}if((a[q+(o*12|0)+9|0]|0)!=(f|0)){M=A;N=2;O=t;break}o=(m<<1)+(i>>1)|0;q=d+29888+(o<<3)+4|0;if((i|0)>0){w=b[q>>1]|0;u=c[d+35908>>2]|0;s=c[d+35916>>2]|0;if((w|0)<(u|0)){V=u&65535}else{V=((w|0)>(s|0)?s:w)&65535}w=b[d+29888+(o<<3)+6>>1]|0;s=c[d+35912>>2]|0;u=c[d+35920>>2]|0;if((w|0)<(s|0)){W=s&65535}else{W=((w|0)>(u|0)?u:w)&65535}w=(W&65535)<<16|V&65535;if((h|0)==0){c[e>>2]=w;return}if((A|0)==-2147450880){M=w;N=2;O=t;break}if((w|0)==(A|0)){M=A;N=2;O=t;break}c[e>>2]=w;return}w=c[q>>2]|0;q=w&65535;if((h|0)==0){u=q<<16>>16;s=c[d+35908>>2]|0;v=c[d+35916>>2]|0;if((u|0)<(s|0)){X=s&65535}else{X=((u|0)>(v|0)?v:u)&65535}b[e>>1]=X;u=b[d+29888+(o<<3)+6>>1]|0;v=c[d+35912>>2]|0;s=c[d+35920>>2]|0;if((u|0)<(v|0)){Y=v&65535}else{Y=((u|0)>(s|0)?s:u)&65535}b[e+2>>1]=Y;return}if((A|0)==-2147450880){M=w;N=2;O=t;break}if((w|0)==(A|0)){M=A;N=2;O=t;break}t=q<<16>>16;q=c[d+35908>>2]|0;w=c[d+35916>>2]|0;if((t|0)<(q|0)){Z=q&65535}else{Z=((t|0)>(w|0)?w:t)&65535}b[e>>1]=Z;t=b[d+29888+(o<<3)+6>>1]|0;o=c[d+35912>>2]|0;w=c[d+35920>>2]|0;if((t|0)<(o|0)){_=o&65535}else{_=((t|0)>(w|0)?w:t)&65535}b[e+2>>1]=_;return}else{M=-2147450880;N=0;O=c[d+1788>>2]|0}}while(0);_=d+1788|0;Z=d+1808|0;A=d+1804|0;Y=d+1796|0;X=d+1380|0;V=(i|0)>0;i=d+35908|0;W=d+35916|0;m=d+35912|0;U=d+35920|0;T=(h|0)==0;h=N;N=M;a:while(1){M=(a[1223704+(n<<4)+(h<<1)|0]|0)+l|0;S=(a[1223704+(n<<4)+(h<<1)+1|0]|0)+k|0;do{if(M>>>0<O>>>0){$=N}else{if(!(M>>>0<(c[Z>>2]|0)>>>0&(S|0)>-1)){$=N;break}if(!(S>>>0<(c[A>>2]|0)>>>0)){$=N;break}aa=(ca(S<<3,c[Y>>2]|0)|0)+M|0;ba=c[X>>2]|0;if((a[ba+(aa*12|0)+8|0]|0)==(f|0)){R=ba+(aa*12|0)|0;if(!V){P=c[R>>2]|0;da=P&65535;if(T){ea=129;break a}if((N|0)==-2147450880){$=P;break}if((P|0)==(N|0)){$=N;break}else{ea=136;break a}}P=b[R>>1]|0;R=c[i>>2]|0;Q=c[W>>2]|0;if((P|0)<(R|0)){fa=R&65535}else{fa=((P|0)>(Q|0)?Q:P)&65535}P=b[ba+(aa*12|0)+2>>1]|0;Q=c[m>>2]|0;R=c[U>>2]|0;if((P|0)<(Q|0)){ga=Q&65535}else{ga=((P|0)>(R|0)?R:P)&65535}ha=(ga&65535)<<16|fa&65535;if(T){ea=124;break a}if((N|0)==-2147450880){$=ha;break}if((ha|0)==(N|0)){$=N;break}else{ea=127;break a}}if((a[ba+(aa*12|0)+9|0]|0)!=(f|0)){$=N;break}P=ba+(aa*12|0)+4|0;if(!V){R=c[P>>2]|0;ia=R&65535;if(T){ea=153;break a}if((N|0)==-2147450880){$=R;break}if((R|0)==(N|0)){$=N;break}else{ea=160;break a}}R=b[P>>1]|0;P=c[i>>2]|0;Q=c[W>>2]|0;if((R|0)<(P|0)){ja=P&65535}else{ja=((R|0)>(Q|0)?Q:R)&65535}R=b[ba+(aa*12|0)+6>>1]|0;Q=c[m>>2]|0;P=c[U>>2]|0;if((R|0)<(Q|0)){ka=Q&65535}else{ka=((R|0)>(P|0)?P:R)&65535}la=(ka&65535)<<16|ja&65535;if(T){ea=148;break a}if((N|0)==-2147450880){$=la;break}if((la|0)==(N|0)){$=N}else{ea=151;break a}}}while(0);M=h+1|0;if((M|0)<8){h=M;N=$}else{ea=166;break}}if((ea|0)==124){c[e>>2]=ha;return}else if((ea|0)==127){c[e>>2]=ha;return}else if((ea|0)==129){ha=da<<16>>16;N=c[i>>2]|0;h=c[W>>2]|0;if((ha|0)<(N|0)){ma=N&65535}else{ma=((ha|0)>(h|0)?h:ha)&65535}b[e>>1]=ma;ma=b[ba+(aa*12|0)+2>>1]|0;ha=c[m>>2]|0;h=c[U>>2]|0;if((ma|0)<(ha|0)){na=ha&65535}else{na=((ma|0)>(h|0)?h:ma)&65535}b[e+2>>1]=na;return}else if((ea|0)==136){na=da<<16>>16;da=c[i>>2]|0;ma=c[W>>2]|0;if((na|0)<(da|0)){oa=da&65535}else{oa=((na|0)>(ma|0)?ma:na)&65535}b[e>>1]=oa;oa=b[ba+(aa*12|0)+2>>1]|0;na=c[m>>2]|0;ma=c[U>>2]|0;if((oa|0)<(na|0)){pa=na&65535}else{pa=((oa|0)>(ma|0)?ma:oa)&65535}b[e+2>>1]=pa;return}else if((ea|0)==148){c[e>>2]=la;return}else if((ea|0)==151){c[e>>2]=la;return}else if((ea|0)==153){la=ia<<16>>16;pa=c[i>>2]|0;oa=c[W>>2]|0;if((la|0)<(pa|0)){qa=pa&65535}else{qa=((la|0)>(oa|0)?oa:la)&65535}b[e>>1]=qa;qa=b[ba+(aa*12|0)+6>>1]|0;la=c[m>>2]|0;oa=c[U>>2]|0;if((qa|0)<(la|0)){ra=la&65535}else{ra=((qa|0)>(oa|0)?oa:qa)&65535}b[e+2>>1]=ra;return}else if((ea|0)==160){ra=ia<<16>>16;ia=c[i>>2]|0;qa=c[W>>2]|0;if((ra|0)<(ia|0)){sa=ia&65535}else{sa=((ra|0)>(qa|0)?qa:ra)&65535}b[e>>1]=sa;sa=b[ba+(aa*12|0)+6>>1]|0;aa=c[m>>2]|0;ba=c[U>>2]|0;if((sa|0)<(aa|0)){ta=aa&65535}else{ta=((sa|0)>(ba|0)?ba:sa)&65535}b[e+2>>1]=ta;return}else if((ea|0)==166){ta=d+1140|0;do{if((a[ta]|0)==0){ua=$}else{sa=(ca(k<<3,c[Y>>2]|0)|0)+l|0;ba=c[d+1404>>2]|0;if((c[d+1096>>2]|0)==0){M5a(d+1384|0,k>>3,0)}if((a[ba+(sa*12|0)+8|0]|0)==(f|0)){aa=ba+(sa*12|0)|0;if(V){ra=b[aa>>1]|0;qa=c[i>>2]|0;ia=c[W>>2]|0;if((ra|0)<(qa|0)){va=qa&65535}else{va=((ra|0)>(ia|0)?ia:ra)&65535}ra=b[ba+(sa*12|0)+2>>1]|0;ia=c[m>>2]|0;qa=c[U>>2]|0;if((ra|0)<(ia|0)){wa=ia&65535}else{wa=((ra|0)>(qa|0)?qa:ra)&65535}ra=(wa&65535)<<16|va&65535;if(T){c[e>>2]=ra;return}if(($|0)==-2147450880){ua=ra;break}if((ra|0)==($|0)){ua=$;break}c[e>>2]=ra;return}ra=c[aa>>2]|0;aa=ra&65535;if(T){qa=aa<<16>>16;ia=c[i>>2]|0;oa=c[W>>2]|0;if((qa|0)<(ia|0)){xa=ia&65535}else{xa=((qa|0)>(oa|0)?oa:qa)&65535}b[e>>1]=xa;qa=b[ba+(sa*12|0)+2>>1]|0;oa=c[m>>2]|0;ia=c[U>>2]|0;if((qa|0)<(oa|0)){ya=oa&65535}else{ya=((qa|0)>(ia|0)?ia:qa)&65535}b[e+2>>1]=ya;return}if(($|0)==-2147450880){ua=ra;break}if((ra|0)==($|0)){ua=$;break}ra=aa<<16>>16;aa=c[i>>2]|0;qa=c[W>>2]|0;if((ra|0)<(aa|0)){za=aa&65535}else{za=((ra|0)>(qa|0)?qa:ra)&65535}b[e>>1]=za;ra=b[ba+(sa*12|0)+2>>1]|0;qa=c[m>>2]|0;aa=c[U>>2]|0;if((ra|0)<(qa|0)){Aa=qa&65535}else{Aa=((ra|0)>(aa|0)?aa:ra)&65535}b[e+2>>1]=Aa;return}if((a[ba+(sa*12|0)+9|0]|0)!=(f|0)){ua=$;break}ra=ba+(sa*12|0)+4|0;if(V){aa=b[ra>>1]|0;qa=c[i>>2]|0;ia=c[W>>2]|0;if((aa|0)<(qa|0)){Ba=qa&65535}else{Ba=((aa|0)>(ia|0)?ia:aa)&65535}aa=b[ba+(sa*12|0)+6>>1]|0;ia=c[m>>2]|0;qa=c[U>>2]|0;if((aa|0)<(ia|0)){Ca=ia&65535}else{Ca=((aa|0)>(qa|0)?qa:aa)&65535}aa=(Ca&65535)<<16|Ba&65535;if(T){c[e>>2]=aa;return}if(($|0)==-2147450880){ua=aa;break}if((aa|0)==($|0)){ua=$;break}c[e>>2]=aa;return}aa=c[ra>>2]|0;ra=aa&65535;if(T){qa=ra<<16>>16;ia=c[i>>2]|0;oa=c[W>>2]|0;if((qa|0)<(ia|0)){Da=ia&65535}else{Da=((qa|0)>(oa|0)?oa:qa)&65535}b[e>>1]=Da;qa=b[ba+(sa*12|0)+6>>1]|0;oa=c[m>>2]|0;ia=c[U>>2]|0;if((qa|0)<(oa|0)){Ea=oa&65535}else{Ea=((qa|0)>(ia|0)?ia:qa)&65535}b[e+2>>1]=Ea;return}if(($|0)==-2147450880){ua=aa;break}if((aa|0)==($|0)){ua=$;break}aa=ra<<16>>16;ra=c[i>>2]|0;qa=c[W>>2]|0;if((aa|0)<(ra|0)){Fa=ra&65535}else{Fa=((aa|0)>(qa|0)?qa:aa)&65535}b[e>>1]=Fa;aa=b[ba+(sa*12|0)+6>>1]|0;sa=c[m>>2]|0;ba=c[U>>2]|0;if((aa|0)<(sa|0)){Ga=sa&65535}else{Ga=((aa|0)>(ba|0)?ba:aa)&65535}b[e+2>>1]=Ga;return}}while(0);Ga=c[_>>2]|0;_=d+1160+f|0;Fa=0;$=ua;b:while(1){ua=(a[1223704+(n<<4)+(Fa<<1)|0]|0)+l|0;Ea=(a[1223704+(n<<4)+(Fa<<1)+1|0]|0)+k|0;do{if(ua>>>0<Ga>>>0){Ha=$}else{if(!(ua>>>0<(c[Z>>2]|0)>>>0&(Ea|0)>-1)){Ha=$;break}if(!(Ea>>>0<(c[A>>2]|0)>>>0)){Ha=$;break}Ia=(ca(Ea<<3,c[Y>>2]|0)|0)+ua|0;Ja=c[X>>2]|0;Da=Ja+(Ia*12|0)|0;Ba=a[Ja+(Ia*12|0)+8|0]|0;Ca=Ba<<24>>24;do{if((Ca|0)!=(f|0)&Ba<<24>>24>-1){if((a[d+1160+Ca|0]|0)==(a[_]|0)){if(!V){Aa=c[Da>>2]|0;Ka=Aa&65535;if(T){ea=257;break b}if(($|0)==-2147450880){La=Aa;break}if((Aa|0)==($|0)){La=$;break}else{ea=264;break b}}Aa=b[Da>>1]|0;za=c[i>>2]|0;ya=c[W>>2]|0;if((Aa|0)<(za|0)){Ma=za&65535}else{Ma=((Aa|0)>(ya|0)?ya:Aa)&65535}Aa=b[Ja+(Ia*12|0)+2>>1]|0;ya=c[m>>2]|0;za=c[U>>2]|0;if((Aa|0)<(ya|0)){Na=ya&65535}else{Na=((Aa|0)>(za|0)?za:Aa)&65535}Oa=(Na&65535)<<16|Ma&65535;if(T){ea=252;break b}if(($|0)==-2147450880){La=Oa;break}if((Oa|0)==($|0)){La=$;break}else{ea=255;break b}}else{Pa=-(b[Da>>1]|0)&65535;Qa=-(b[Ja+(Ia*12|0)+2>>1]|0)&65535;if(!V){Aa=(Qa&65535)<<16|Pa&65535;if(T){ea=234;break b}if(($|0)==-2147450880){La=Aa;break}if((Aa|0)==($|0)){La=$;break}else{ea=241;break b}}Aa=Pa<<16>>16;za=c[i>>2]|0;ya=c[W>>2]|0;if((Aa|0)<(za|0)){Ra=za&65535}else{Ra=((Aa|0)>(ya|0)?ya:Aa)&65535}Aa=Qa<<16>>16;ya=c[m>>2]|0;za=c[U>>2]|0;if((Aa|0)<(ya|0)){Sa=ya&65535}else{Sa=((Aa|0)>(za|0)?za:Aa)&65535}Ta=(Sa&65535)<<16|Ra&65535;if(T){ea=229;break b}if(($|0)==-2147450880){La=Ta;break}if((Ta|0)==($|0)){La=$;break}else{ea=232;break b}}}else{La=$}}while(0);Ca=a[Ja+(Ia*12|0)+9|0]|0;Ba=Ca<<24>>24;if(!((Ba|0)!=(f|0)&Ca<<24>>24>-1)){Ha=La;break}Ca=c[Ja+(Ia*12|0)+4>>2]|0;Ua=Ca&65535;if((c[Da>>2]|0)==(Ca|0)){Ha=La;break}if((a[d+1160+Ba|0]|0)==(a[_]|0)){if(!V){if(T){ea=306;break b}if((La|0)==-2147450880){Ha=Ca;break}if((Ca|0)==(La|0)){Ha=La;break}else{ea=313;break b}}Ca=Ua<<16>>16;Ba=c[i>>2]|0;Aa=c[W>>2]|0;if((Ca|0)<(Ba|0)){Va=Ba&65535}else{Va=((Ca|0)>(Aa|0)?Aa:Ca)&65535}Ca=b[Ja+(Ia*12|0)+6>>1]|0;Aa=c[m>>2]|0;Ba=c[U>>2]|0;if((Ca|0)<(Aa|0)){Wa=Aa&65535}else{Wa=((Ca|0)>(Ba|0)?Ba:Ca)&65535}Xa=(Wa&65535)<<16|Va&65535;if(T){ea=301;break b}if((La|0)==-2147450880){Ha=Xa;break}if((Xa|0)==(La|0)){Ha=La;break}else{ea=304;break b}}else{Ya=-Ua&65535;Za=-(b[Ja+(Ia*12|0)+6>>1]|0)&65535;if(!V){Ca=(Za&65535)<<16|Ya&65535;if(T){ea=283;break b}if((La|0)==-2147450880){Ha=Ca;break}if((Ca|0)==(La|0)){Ha=La;break}else{ea=290;break b}}Ca=Ya<<16>>16;Ba=c[i>>2]|0;Aa=c[W>>2]|0;if((Ca|0)<(Ba|0)){_a=Ba&65535}else{_a=((Ca|0)>(Aa|0)?Aa:Ca)&65535}Ca=Za<<16>>16;Aa=c[m>>2]|0;Ba=c[U>>2]|0;if((Ca|0)<(Aa|0)){$a=Aa&65535}else{$a=((Ca|0)>(Ba|0)?Ba:Ca)&65535}ab=($a&65535)<<16|_a&65535;if(T){ea=278;break b}if((La|0)==-2147450880){Ha=ab;break}if((ab|0)==(La|0)){Ha=La;break}else{ea=281;break b}}}}while(0);ua=Fa+1|0;if((ua|0)<8){Fa=ua;$=Ha}else{ea=319;break}}if((ea|0)==229){c[e>>2]=Ta;return}else if((ea|0)==232){c[e>>2]=Ta;return}else if((ea|0)==234){Ta=Pa<<16>>16;$=c[i>>2]|0;Fa=c[W>>2]|0;if((Ta|0)<($|0)){bb=$&65535}else{bb=((Ta|0)>(Fa|0)?Fa:Ta)&65535}b[e>>1]=bb;bb=Qa<<16>>16;Ta=c[m>>2]|0;Fa=c[U>>2]|0;if((bb|0)<(Ta|0)){cb=Ta&65535}else{cb=((bb|0)>(Fa|0)?Fa:bb)&65535}b[e+2>>1]=cb;return}else if((ea|0)==241){cb=Pa<<16>>16;Pa=c[i>>2]|0;bb=c[W>>2]|0;if((cb|0)<(Pa|0)){db=Pa&65535}else{db=((cb|0)>(bb|0)?bb:cb)&65535}b[e>>1]=db;db=Qa<<16>>16;Qa=c[m>>2]|0;cb=c[U>>2]|0;if((db|0)<(Qa|0)){eb=Qa&65535}else{eb=((db|0)>(cb|0)?cb:db)&65535}b[e+2>>1]=eb;return}else if((ea|0)==252){c[e>>2]=Oa;return}else if((ea|0)==255){c[e>>2]=Oa;return}else if((ea|0)==257){Oa=Ka<<16>>16;eb=c[i>>2]|0;db=c[W>>2]|0;if((Oa|0)<(eb|0)){fb=eb&65535}else{fb=((Oa|0)>(db|0)?db:Oa)&65535}b[e>>1]=fb;fb=b[Ja+(Ia*12|0)+2>>1]|0;Oa=c[m>>2]|0;db=c[U>>2]|0;if((fb|0)<(Oa|0)){gb=Oa&65535}else{gb=((fb|0)>(db|0)?db:fb)&65535}b[e+2>>1]=gb;return}else if((ea|0)==264){gb=Ka<<16>>16;Ka=c[i>>2]|0;fb=c[W>>2]|0;if((gb|0)<(Ka|0)){hb=Ka&65535}else{hb=((gb|0)>(fb|0)?fb:gb)&65535}b[e>>1]=hb;hb=b[Ja+(Ia*12|0)+2>>1]|0;gb=c[m>>2]|0;fb=c[U>>2]|0;if((hb|0)<(gb|0)){ib=gb&65535}else{ib=((hb|0)>(fb|0)?fb:hb)&65535}b[e+2>>1]=ib;return}else if((ea|0)==278){c[e>>2]=ab;return}else if((ea|0)==281){c[e>>2]=ab;return}else if((ea|0)==283){ab=Ya<<16>>16;ib=c[i>>2]|0;hb=c[W>>2]|0;if((ab|0)<(ib|0)){jb=ib&65535}else{jb=((ab|0)>(hb|0)?hb:ab)&65535}b[e>>1]=jb;jb=Za<<16>>16;ab=c[m>>2]|0;hb=c[U>>2]|0;if((jb|0)<(ab|0)){kb=ab&65535}else{kb=((jb|0)>(hb|0)?hb:jb)&65535}b[e+2>>1]=kb;return}else if((ea|0)==290){kb=Ya<<16>>16;Ya=c[i>>2]|0;jb=c[W>>2]|0;if((kb|0)<(Ya|0)){lb=Ya&65535}else{lb=((kb|0)>(jb|0)?jb:kb)&65535}b[e>>1]=lb;lb=Za<<16>>16;Za=c[m>>2]|0;kb=c[U>>2]|0;if((lb|0)<(Za|0)){mb=Za&65535}else{mb=((lb|0)>(kb|0)?kb:lb)&65535}b[e+2>>1]=mb;return}else if((ea|0)==301){c[e>>2]=Xa;return}else if((ea|0)==304){c[e>>2]=Xa;return}else if((ea|0)==306){Xa=Ua<<16>>16;mb=c[i>>2]|0;lb=c[W>>2]|0;if((Xa|0)<(mb|0)){nb=mb&65535}else{nb=((Xa|0)>(lb|0)?lb:Xa)&65535}b[e>>1]=nb;nb=b[Ja+(Ia*12|0)+6>>1]|0;Xa=c[m>>2]|0;lb=c[U>>2]|0;if((nb|0)<(Xa|0)){ob=Xa&65535}else{ob=((nb|0)>(lb|0)?lb:nb)&65535}b[e+2>>1]=ob;return}else if((ea|0)==313){ob=Ua<<16>>16;Ua=c[i>>2]|0;nb=c[W>>2]|0;if((ob|0)<(Ua|0)){pb=Ua&65535}else{pb=((ob|0)>(nb|0)?nb:ob)&65535}b[e>>1]=pb;pb=b[Ja+(Ia*12|0)+6>>1]|0;Ia=c[m>>2]|0;Ja=c[U>>2]|0;if((pb|0)<(Ia|0)){qb=Ia&65535}else{qb=((pb|0)>(Ja|0)?Ja:pb)&65535}b[e+2>>1]=qb;return}else if((ea|0)==319){do{if((a[ta]|0)!=0){ea=(ca(k<<3,c[Y>>2]|0)|0)+l|0;qb=c[d+1404>>2]|0;pb=qb+(ea*12|0)|0;Ja=a[qb+(ea*12|0)+8|0]|0;Ia=Ja<<24>>24;do{if((Ia|0)!=(f|0)&Ja<<24>>24>-1){if((a[d+1160+Ia|0]|0)==(a[_]|0)){if(V){ob=b[pb>>1]|0;nb=c[i>>2]|0;Ua=c[W>>2]|0;if((ob|0)<(nb|0)){rb=nb&65535}else{rb=((ob|0)>(Ua|0)?Ua:ob)&65535}ob=b[qb+(ea*12|0)+2>>1]|0;Ua=c[m>>2]|0;nb=c[U>>2]|0;if((ob|0)<(Ua|0)){sb=Ua&65535}else{sb=((ob|0)>(nb|0)?nb:ob)&65535}ob=(sb&65535)<<16|rb&65535;if(T){c[e>>2]=ob;return}if((Ha|0)==-2147450880){tb=ob;break}if((ob|0)==(Ha|0)){tb=Ha;break}c[e>>2]=ob;return}ob=c[pb>>2]|0;nb=ob&65535;if(T){Ua=nb<<16>>16;lb=c[i>>2]|0;Xa=c[W>>2]|0;if((Ua|0)<(lb|0)){ub=lb&65535}else{ub=((Ua|0)>(Xa|0)?Xa:Ua)&65535}b[e>>1]=ub;Ua=b[qb+(ea*12|0)+2>>1]|0;Xa=c[m>>2]|0;lb=c[U>>2]|0;if((Ua|0)<(Xa|0)){vb=Xa&65535}else{vb=((Ua|0)>(lb|0)?lb:Ua)&65535}b[e+2>>1]=vb;return}if((Ha|0)==-2147450880){tb=ob;break}if((ob|0)==(Ha|0)){tb=Ha;break}ob=nb<<16>>16;nb=c[i>>2]|0;Ua=c[W>>2]|0;if((ob|0)<(nb|0)){wb=nb&65535}else{wb=((ob|0)>(Ua|0)?Ua:ob)&65535}b[e>>1]=wb;ob=b[qb+(ea*12|0)+2>>1]|0;Ua=c[m>>2]|0;nb=c[U>>2]|0;if((ob|0)<(Ua|0)){xb=Ua&65535}else{xb=((ob|0)>(nb|0)?nb:ob)&65535}b[e+2>>1]=xb;return}else{ob=-(b[pb>>1]|0)&65535;nb=-(b[qb+(ea*12|0)+2>>1]|0)&65535;if(V){Ua=ob<<16>>16;lb=c[i>>2]|0;Xa=c[W>>2]|0;if((Ua|0)<(lb|0)){yb=lb&65535}else{yb=((Ua|0)>(Xa|0)?Xa:Ua)&65535}Ua=nb<<16>>16;Xa=c[m>>2]|0;lb=c[U>>2]|0;if((Ua|0)<(Xa|0)){zb=Xa&65535}else{zb=((Ua|0)>(lb|0)?lb:Ua)&65535}Ua=(zb&65535)<<16|yb&65535;if(T){c[e>>2]=Ua;return}if((Ha|0)==-2147450880){tb=Ua;break}if((Ua|0)==(Ha|0)){tb=Ha;break}c[e>>2]=Ua;return}Ua=(nb&65535)<<16|ob&65535;if(T){lb=ob<<16>>16;Xa=c[i>>2]|0;mb=c[W>>2]|0;if((lb|0)<(Xa|0)){Ab=Xa&65535}else{Ab=((lb|0)>(mb|0)?mb:lb)&65535}b[e>>1]=Ab;lb=nb<<16>>16;mb=c[m>>2]|0;Xa=c[U>>2]|0;if((lb|0)<(mb|0)){Bb=mb&65535}else{Bb=((lb|0)>(Xa|0)?Xa:lb)&65535}b[e+2>>1]=Bb;return}if((Ha|0)==-2147450880){tb=Ua;break}if((Ua|0)==(Ha|0)){tb=Ha;break}Ua=ob<<16>>16;ob=c[i>>2]|0;lb=c[W>>2]|0;if((Ua|0)<(ob|0)){Cb=ob&65535}else{Cb=((Ua|0)>(lb|0)?lb:Ua)&65535}b[e>>1]=Cb;Ua=nb<<16>>16;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ua|0)<(nb|0)){Db=nb&65535}else{Db=((Ua|0)>(lb|0)?lb:Ua)&65535}b[e+2>>1]=Db;return}}else{tb=Ha}}while(0);Ia=a[qb+(ea*12|0)+9|0]|0;Ja=Ia<<24>>24;if(!((Ja|0)!=(f|0)&Ia<<24>>24>-1)){break}Ia=c[qb+(ea*12|0)+4>>2]|0;Ua=Ia&65535;if((c[pb>>2]|0)==(Ia|0)){break}if((a[d+1160+Ja|0]|0)==(a[_]|0)){if(V){Ja=Ua<<16>>16;lb=c[i>>2]|0;nb=c[W>>2]|0;if((Ja|0)<(lb|0)){Eb=lb&65535}else{Eb=((Ja|0)>(nb|0)?nb:Ja)&65535}Ja=b[qb+(ea*12|0)+6>>1]|0;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(nb|0)){Fb=nb&65535}else{Fb=((Ja|0)>(lb|0)?lb:Ja)&65535}Ja=(Fb&65535)<<16|Eb&65535;if(T){c[e>>2]=Ja;return}if((tb|0)==-2147450880|(Ja|0)==(tb|0)){break}c[e>>2]=Ja;return}if(T){Ja=Ua<<16>>16;lb=c[i>>2]|0;nb=c[W>>2]|0;if((Ja|0)<(lb|0)){Gb=lb&65535}else{Gb=((Ja|0)>(nb|0)?nb:Ja)&65535}b[e>>1]=Gb;Ja=b[qb+(ea*12|0)+6>>1]|0;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(nb|0)){Hb=nb&65535}else{Hb=((Ja|0)>(lb|0)?lb:Ja)&65535}b[e+2>>1]=Hb;return}if((tb|0)==-2147450880|(Ia|0)==(tb|0)){break}Ia=Ua<<16>>16;Ja=c[i>>2]|0;lb=c[W>>2]|0;if((Ia|0)<(Ja|0)){Ib=Ja&65535}else{Ib=((Ia|0)>(lb|0)?lb:Ia)&65535}b[e>>1]=Ib;Ia=b[qb+(ea*12|0)+6>>1]|0;lb=c[m>>2]|0;Ja=c[U>>2]|0;if((Ia|0)<(lb|0)){Jb=lb&65535}else{Jb=((Ia|0)>(Ja|0)?Ja:Ia)&65535}b[e+2>>1]=Jb;return}else{Ia=-Ua&65535;Ua=-(b[qb+(ea*12|0)+6>>1]|0)&65535;if(V){Ja=Ia<<16>>16;lb=c[i>>2]|0;nb=c[W>>2]|0;if((Ja|0)<(lb|0)){Kb=lb&65535}else{Kb=((Ja|0)>(nb|0)?nb:Ja)&65535}Ja=Ua<<16>>16;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(nb|0)){Lb=nb&65535}else{Lb=((Ja|0)>(lb|0)?lb:Ja)&65535}Ja=(Lb&65535)<<16|Kb&65535;if(T){c[e>>2]=Ja;return}if((tb|0)==-2147450880|(Ja|0)==(tb|0)){break}c[e>>2]=Ja;return}if(T){Ja=Ia<<16>>16;lb=c[i>>2]|0;nb=c[W>>2]|0;if((Ja|0)<(lb|0)){Mb=lb&65535}else{Mb=((Ja|0)>(nb|0)?nb:Ja)&65535}b[e>>1]=Mb;Ja=Ua<<16>>16;nb=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(nb|0)){Nb=nb&65535}else{Nb=((Ja|0)>(lb|0)?lb:Ja)&65535}b[e+2>>1]=Nb;return}if((tb|0)==-2147450880|((Ua&65535)<<16|Ia&65535|0)==(tb|0)){break}Ja=Ia<<16>>16;Ia=c[i>>2]|0;lb=c[W>>2]|0;if((Ja|0)<(Ia|0)){Ob=Ia&65535}else{Ob=((Ja|0)>(lb|0)?lb:Ja)&65535}b[e>>1]=Ob;Ja=Ua<<16>>16;Ua=c[m>>2]|0;lb=c[U>>2]|0;if((Ja|0)<(Ua|0)){Pb=Ua&65535}else{Pb=((Ja|0)>(lb|0)?lb:Ja)&65535}b[e+2>>1]=Pb;return}}}while(0);c[e>>2]=0;return}}}function Dbb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;e=a|0;f=c[e>>2]|0;g=d[1252840+f|0]|0;h=a+4|0;i=c[h>>2]|0;j=a+16|0;k=c[j>>2]|0;l=f<<g;c[e>>2]=l;f=k<<g;k=i+g|0;do{if((k|0)>-1){g=a+8|0;i=c[g>>2]|0;if(!(i>>>0<(c[a+12>>2]|0)>>>0)){m=f;n=k;break}c[g>>2]=i+2;g=i;m=((he((d[g]|d[g+1|0]<<8)<<16>>16|0)|0)&65535)<<k|f;n=k-16|0}else{m=f;n=k}}while(0);c[h>>2]=n;k=((l<<7)-128>>8)+1|0;f=k<<16;g=m>>>0>=f>>>0;i=g?l-k|0:k;c[e>>2]=i;k=m-(g?f:0)|0;c[j>>2]=k;do{if(g){f=d[1252840+i|0]|0;m=i<<f;c[e>>2]=m;l=k<<f;o=n+f|0;do{if((o|0)>-1){f=a+8|0;p=c[f>>2]|0;if(!(p>>>0<(c[a+12>>2]|0)>>>0)){q=l;r=o;break}c[f>>2]=p+2;f=p;q=((he((d[f]|d[f+1|0]<<8)<<16>>16|0)|0)&65535)<<o|l;r=o-16|0}else{q=l;r=o}}while(0);c[h>>2]=r;o=((m<<7)-128>>8)+1|0;l=o<<16;f=q>>>0>=l>>>0;p=f?m-o|0:o;c[e>>2]=p;o=q-(f?l:0)|0;c[j>>2]=o;if(!f){f=a+8|0;l=a+12|0;s=4;t=0;u=p;v=r;w=o;while(1){x=s-1|0;y=t<<1;z=d[1252840+u|0]|0;A=u<<z;c[e>>2]=A;B=w<<z;C=z+v|0;do{if((C|0)>-1){z=c[f>>2]|0;if(!(z>>>0<(c[l>>2]|0)>>>0)){D=B;E=C;break}c[f>>2]=z+2;F=z;D=((he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<C|B;E=C-16|0}else{D=B;E=C}}while(0);c[h>>2]=E;C=((A<<7)-128>>8)+1|0;B=C<<16;F=D>>>0>=B>>>0;z=F?A-C|0:C;c[e>>2]=z;C=D-(F?B:0)|0;c[j>>2]=C;G=F&1|y;if((x|0)==0){break}else{s=x;t=G;u=z;v=E;w=C}}H=G+16|0;break}w=d[1252840+p|0]|0;v=p<<w;c[e>>2]=v;u=o<<w;t=r+w|0;w=a+8|0;do{if((t|0)>-1){s=c[w>>2]|0;f=a+12|0;if(!(s>>>0<(c[f>>2]|0)>>>0)){I=u;J=t;K=f;break}c[w>>2]=s+2;l=s;I=((he((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&65535)<<t|u;J=t-16|0;K=f}else{I=u;J=t;K=a+12|0}}while(0);c[h>>2]=J;t=((v<<7)-128>>8)+1|0;u=t<<16;o=I>>>0>=u>>>0;p=o?v-t|0:t;c[e>>2]=p;t=I-(o?u:0)|0;c[j>>2]=t;if(o){L=7;M=0;N=p;O=J;P=t}else{o=5;u=0;f=p;p=J;l=t;while(1){t=o-1|0;s=u<<1;m=d[1252840+f|0]|0;C=f<<m;c[e>>2]=C;z=l<<m;F=m+p|0;do{if((F|0)>-1){m=c[w>>2]|0;if(!(m>>>0<(c[K>>2]|0)>>>0)){Q=z;R=F;break}c[w>>2]=m+2;B=m;Q=((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)<<F|z;R=F-16|0}else{Q=z;R=F}}while(0);c[h>>2]=R;F=((C<<7)-128>>8)+1|0;z=F<<16;x=Q>>>0>=z>>>0;y=x?C-F|0:F;c[e>>2]=y;F=Q-(x?z:0)|0;c[j>>2]=F;S=x&1|s;if((t|0)==0){break}else{o=t;u=S;f=y;p=R;l=F}}H=S+32|0;break}while(1){l=L-1|0;p=M<<1;f=d[1252840+N|0]|0;u=N<<f;c[e>>2]=u;o=P<<f;v=f+O|0;do{if((v|0)>-1){f=c[w>>2]|0;if(!(f>>>0<(c[K>>2]|0)>>>0)){T=o;U=v;break}c[w>>2]=f+2;F=f;T=((he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<v|o;U=v-16|0}else{T=o;U=v}}while(0);c[h>>2]=U;v=((u<<7)-128>>8)+1|0;o=v<<16;t=T>>>0>=o>>>0;V=t?u-v|0:v;c[e>>2]=V;W=T-(t?o:0)|0;c[j>>2]=W;X=t&1|p;if((l|0)==0){break}else{L=l;M=X;N=V;O=U;P=W}}if((X|0)>64){t=(X<<1)-65|0;o=d[1252840+V|0]|0;v=V<<o;c[e>>2]=v;s=W<<o;C=U+o|0;do{if((C|0)>-1){o=c[w>>2]|0;if(!(o>>>0<(c[K>>2]|0)>>>0)){Y=s;Z=C;break}c[w>>2]=o+2;F=o;Y=((he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535)<<C|s;Z=C-16|0}else{Y=s;Z=C}}while(0);c[h>>2]=Z;C=((v<<7)-128>>8)+1|0;s=C<<16;w=Y>>>0>=s>>>0;c[e>>2]=w?v-C|0:C;c[j>>2]=Y-(w?s:0);_=t+(w&1)|0}else{_=X}H=_+64|0}else{w=a+8|0;s=a+12|0;C=4;F=0;o=i;f=n;y=k;while(1){x=C-1|0;z=F<<1;A=d[1252840+o|0]|0;B=o<<A;c[e>>2]=B;m=y<<A;$=A+f|0;do{if(($|0)>-1){A=c[w>>2]|0;if(!(A>>>0<(c[s>>2]|0)>>>0)){aa=m;ba=$;break}c[w>>2]=A+2;ca=A;aa=((he((d[ca]|d[ca+1|0]<<8)<<16>>16|0)|0)&65535)<<$|m;ba=$-16|0}else{aa=m;ba=$}}while(0);c[h>>2]=ba;$=((B<<7)-128>>8)+1|0;m=$<<16;l=aa>>>0>=m>>>0;p=l?B-$|0:$;c[e>>2]=p;$=aa-(l?m:0)|0;c[j>>2]=$;m=l&1|z;if((x|0)==0){H=m;break}else{C=x;F=m;o=p;f=ba;y=$}}}}while(0);ba=c[282744+(H<<2)>>2]|0;if((b|0)<129){H=b-1|0;do{if((H<<1|0)<(ba|0)){da=ba}else{if((ba&1|0)==0){da=(ba>>1)+H|0;break}else{da=H-(ba+1>>1)|0;break}}}while(0);ea=da+1|0;return ea|0}else{da=255-b|0;do{if((da<<1|0)<(ba|0)){fa=ba}else{if((ba&1|0)==0){fa=(ba>>1)+da|0;break}else{fa=da-(ba+1>>1)|0;break}}}while(0);ea=255-fa|0;return ea|0}return 0}function Ebb(a){a=a|0;c[a>>2]=708;c[a+4>>2]=512;c[a+8>>2]=346;c[a+12>>2]=1006;c[a+16>>2]=510;c[a+20>>2]=1018;c[a+24>>2]=618;c[a+28>>2]=992;c[a+32>>2]=684;c[a+36>>2]=774;c[a+40>>2]=314;c[a+44>>2]=906;c[a+48>>2]=380;c[a+52>>2]=482;c[a+56>>2]=848;c[a+60>>2]=12;c[a+64>>2]=120;c[a+68>>2]=460;c[a+72>>2]=226;c[a+76>>2]=756;c[a+80>>2]=796;c[a+84>>2]=190;c[a+88>>2]=874;c[a+92>>2]=924;c[a+96>>2]=892;c[a+100>>2]=134;c[a+104>>2]=798;c[a+108>>2]=454;c[a+112>>2]=104;c[a+116>>2]=574;c[a+120>>2]=734;c[a+124>>2]=898;c[a+128>>2]=426;c[a+132>>2]=212;c[a+136>>2]=876;c[a+140>>2]=686;c[a+144>>2]=436;c[a+148>>2]=308;c[a+152>>2]=664;c[a+156>>2]=558;c[a+160>>2]=394;c[a+164>>2]=20;c[a+168>>2]=936;c[a+172>>2]=728;c[a+176>>2]=344;c[a+180>>2]=496;c[a+184>>2]=976;c[a+188>>2]=1016;c[a+192>>2]=294;c[a+196>>2]=326;c[a+200>>2]=996;c[a+204>>2]=744;c[a+208>>2]=412;c[a+212>>2]=778;c[a+216>>2]=180;c[a+220>>2]=462;c[a+224>>2]=36;c[a+228>>2]=1010;c[a+232>>2]=138;c[a+236>>2]=910;c[a+240>>2]=358;c[a+244>>2]=962;c[a+248>>2]=926;c[a+252>>2]=856;c[a+256>>2]=374;c[a+260>>2]=984;c[a+264>>2]=940;c[a+268>>2]=288;c[a+272>>2]=654;c[a+276>>2]=954;c[a+280>>2]=788;c[a+284>>2]=402;c[a+300>>2]=920;c[a+292>>2]=920;c[a+296>>2]=920;c[a+288>>2]=920;c[a+316>>2]=884;c[a+308>>2]=884;c[a+312>>2]=884;c[a+304>>2]=884;c[a+320>>2]=54;c[a+324>>2]=478;c[a+328>>2]=482;c[a+332>>2]=112;c[a+336>>2]=466;c[a+340>>2]=2;c[a+344>>2]=342;c[a+348>>2]=326;c[a+352>>2]=30;c[a+356>>2]=606;c[a+360>>2]=688;c[a+364>>2]=542;c[a+368>>2]=420;c[a+372>>2]=618;c[a+376>>2]=452;c[a+380>>2]=314;c[a+384>>2]=356;c[a+416>>2]=356;c[a+448>>2]=356;c[a+480>>2]=356;c[a+400>>2]=612;c[a+432>>2]=612;c[a+464>>2]=612;c[a+496>>2]=612;c[a+512>>2]=220;c[a+544>>2]=220;c[a+576>>2]=220;c[a+608>>2]=220;c[a+528>>2]=434;c[a+560>>2]=434;c[a+592>>2]=434;c[a+624>>2]=434;c[a+640>>2]=80;c[a+672>>2]=80;c[a+704>>2]=80;c[a+736>>2]=80;c[a+656>>2]=120;c[a+688>>2]=120;c[a+720>>2]=120;c[a+752>>2]=120;c[a+768>>2]=60;c[a+800>>2]=60;c[a+832>>2]=60;c[a+864>>2]=60;c[a+784>>2]=364;c[a+816>>2]=364;c[a+848>>2]=364;c[a+880>>2]=364;c[a+896>>2]=424;c[a+928>>2]=424;c[a+960>>2]=424;c[a+992>>2]=424;c[a+912>>2]=18;c[a+944>>2]=18;c[a+976>>2]=18;c[a+1008>>2]=18;c[a+396>>2]=458;c[a+428>>2]=384;c[a+460>>2]=562;c[a+492>>2]=156;c[a+524>>2]=682;c[a+556>>2]=406;c[a+588>>2]=178;c[a+620>>2]=118;c[a+652>>2]=462;c[a+684>>2]=200;c[a+716>>2]=130;c[a+748>>2]=388;c[a+780>>2]=222;c[a+812>>2]=638;c[a+844>>2]=74;c[a+876>>2]=362;c[a+908>>2]=206;c[a+940>>2]=592;c[a+972>>2]=586;c[a+1004>>2]=440;c[a+388>>2]=498;c[a+420>>2]=666;c[a+452>>2]=14;c[a+484>>2]=64;c[a+516>>2]=268;c[a+548>>2]=40;c[a+580>>2]=186;c[a+612>>2]=290;c[a+644>>2]=466;c[a+676>>2]=684;c[a+708>>2]=622;c[a+740>>2]=672;c[a+772>>2]=484;c[a+804>>2]=36;c[a+836>>2]=552;c[a+868>>2]=128;c[a+900>>2]=106;c[a+932>>2]=132;c[a+964>>2]=126;c[a+996>>2]=330;c[a+392>>2]=664;c[a+424>>2]=166;c[a+456>>2]=190;c[a+488>>2]=574;c[a+520>>2]=114;c[a+552>>2]=568;c[a+584>>2]=4;c[a+616>>2]=476;c[a+648>>2]=270;c[a+680>>2]=180;c[a+712>>2]=108;c[a+744>>2]=164;c[a+776>>2]=624;c[a+808>>2]=576;c[a+840>>2]=16;c[a+872>>2]=310;c[a+904>>2]=536;c[a+936>>2]=644;c[a+968>>2]=614;c[a+1e3>>2]=236;c[a+412>>2]=244;c[a+444>>2]=248;c[a+476>>2]=676;c[a+508>>2]=408;c[a+540>>2]=456;c[a+572>>2]=448;c[a+604>>2]=12;c[a+636>>2]=454;c[a+668>>2]=378;c[a+700>>2]=588;c[a+732>>2]=76;c[a+764>>2]=368;c[a+796>>2]=224;c[a+828>>2]=414;c[a+860>>2]=314;c[a+892>>2]=486;c[a+924>>2]=316;c[a+956>>2]=474;c[a+988>>2]=546;c[a+1020>>2]=20;c[a+404>>2]=512;c[a+436>>2]=174;c[a+468>>2]=2;c[a+500>>2]=464;c[a+532>>2]=572;c[a+564>>2]=172;c[a+596>>2]=216;c[a+628>>2]=538;c[a+660>>2]=420;c[a+692>>2]=52;c[a+724>>2]=140;c[a+756>>2]=6;c[a+788>>2]=528;c[a+820>>2]=352;c[a+852>>2]=234;c[a+884>>2]=302;c[a+916>>2]=84;c[a+948>>2]=372;c[a+980>>2]=416;c[a+1012>>2]=150;c[a+408>>2]=260;c[a+440>>2]=668;c[a+472>>2]=390;c[a+504>>2]=350;c[a+536>>2]=38;c[a+568>>2]=324;c[a+600>>2]=30;c[a+632>>2]=116;c[a+664>>2]=560;c[a+696>>2]=422;c[a+728>>2]=394;c[a+760>>2]=532;c[a+792>>2]=360;c[a+824>>2]=524;c[a+856>>2]=418;c[a+888>>2]=138;c[a+920>>2]=600;c[a+952>>2]=534;c[a+984>>2]=214;c[a+1016>>2]=656;return}function Fbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;g=e;e=a;a=c;while(1){nrc(e|0,a|0,64)|0;c=g-1|0;if((c|0)==0){break}else{g=c;e=e+b|0;a=a+d|0}}return}function Gbb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;i=g;g=a;a=e;while(1){e=0;do{h=g+e|0;j=c[h>>2]|0;k=a+e|0;l=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[h>>2]=(l|j)-((l^j)>>>1&2139062143);e=e+4|0;}while((e|0)<64);e=i-1|0;if((e|0)==0){break}else{i=e;g=g+b|0;a=a+f|0}}return}function Hbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;g=e;e=a;a=c;while(1){nrc(e|0,a|0,32)|0;c=g-1|0;if((c|0)==0){break}else{g=c;e=e+b|0;a=a+d|0}}return}function Ibb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=a;a=e;while(1){e=g;h=c[e>>2]|0;j=a;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=g+4|0;k=c[h>>2]|0;e=a+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);k=g+8|0;j=c[k>>2]|0;h=a+8|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=(e|j)-((e^j)>>>1&2139062143);j=g+12|0;e=c[j>>2]|0;k=a+12|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[j>>2]=(h|e)-((h^e)>>>1&2139062143);e=g+16|0;h=c[e>>2]|0;j=a+16|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=g+20|0;k=c[h>>2]|0;e=a+20|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);k=g+24|0;j=c[k>>2]|0;h=a+24|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=(e|j)-((e^j)>>>1&2139062143);j=g+28|0;e=c[j>>2]|0;k=a+28|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[j>>2]=(h|e)-((h^e)>>>1&2139062143);e=i-1|0;if((e|0)==0){break}else{i=e;g=g+b|0;a=a+f|0}}return}function Jbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;g=e;e=a;a=c;while(1){nrc(e|0,a|0,16)|0;c=g-1|0;if((c|0)==0){break}else{g=c;e=e+b|0;a=a+d|0}}return}function Kbb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=a;a=e;while(1){e=g;h=c[e>>2]|0;j=a;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=g+4|0;k=c[h>>2]|0;e=a+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);k=g+8|0;j=c[k>>2]|0;h=a+8|0;e=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;c[k>>2]=(e|j)-((e^j)>>>1&2139062143);j=g+12|0;e=c[j>>2]|0;k=a+12|0;h=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;c[j>>2]=(h|e)-((h^e)>>>1&2139062143);e=i-1|0;if((e|0)==0){break}else{i=e;g=g+b|0;a=a+f|0}}return}function Lbb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=b;b=e;while(1){e=b;h=g;j=e|0;k=e+4|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=h|0;y=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=h+4|0;y=e;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=i-1|0;if((k|0)==0){break}else{i=k;g=g+c|0;b=b+f|0}}return}function Mbb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=a;a=e;while(1){e=g;h=c[e>>2]|0;j=a;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=g+4|0;k=c[h>>2]|0;e=a+4|0;j=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;c[h>>2]=(j|k)-((j^k)>>>1&2139062143);k=i-1|0;if((k|0)==0){break}else{i=k;g=g+b|0;a=a+f|0}}return}function Nbb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;i=g;g=b;b=e;while(1){e=b;h=g;y=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=i-1|0;if((h|0)==0){break}else{i=h;g=g+c|0;b=b+f|0}}return}function Obb(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;i=g;g=a;a=e;while(1){e=g;h=c[e>>2]|0;j=a;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[e>>2]=(k|h)-((k^h)>>>1&2139062143);h=i-1|0;if((h|0)==0){break}else{i=h;g=g+b|0;a=a+f|0}}return}function Pbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,64,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function Qbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,64,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function Rbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,64,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function Sbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;jeb(a,b,c,d,64,e,f,g);return}function Tbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,32,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function Ubb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,32,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function Vbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,32,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function Wbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;jeb(a,b,c,d,32,e,f,g);return}function Xbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,16,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function Ybb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,16,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function Zbb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,16,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function _bb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;jeb(a,b,c,d,16,e,f,g);return}function $bb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,8,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function acb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,8,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function bcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,8,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function ccb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;jeb(a,b,c,d,8,e,f,g);return}function dcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,4,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function ecb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,4,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function fcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;keb(a,b,c,d,4,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function gcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;jeb(a,b,c,d,4,e,f,g);return}function hcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,64,e,202688+(g-1<<3)|0);return}function icb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,64,e,202808+(g-1<<3)|0);return}function jcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,64,e,202928+(g-1<<3)|0);return}function kcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;heb(a,b,c,d,64,e,g);return}function lcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,32,e,202688+(g-1<<3)|0);return}function mcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,32,e,202808+(g-1<<3)|0);return}function ncb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,32,e,202928+(g-1<<3)|0);return}function ocb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;heb(a,b,c,d,32,e,g);return}function pcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,16,e,202688+(g-1<<3)|0);return}function qcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,16,e,202808+(g-1<<3)|0);return}function rcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,16,e,202928+(g-1<<3)|0);return}function scb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;heb(a,b,c,d,16,e,g);return}function tcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,8,e,202688+(g-1<<3)|0);return}function ucb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,8,e,202808+(g-1<<3)|0);return}function vcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,8,e,202928+(g-1<<3)|0);return}function wcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;heb(a,b,c,d,8,e,g);return}function xcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,4,e,202688+(g-1<<3)|0);return}function ycb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,4,e,202808+(g-1<<3)|0);return}function zcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ieb(a,b,c,d,4,e,202928+(g-1<<3)|0);return}function Acb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;heb(a,b,c,d,4,e,g);return}function Bcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,64,e,202688+(f-1<<3)|0);return}function Ccb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,64,e,202808+(f-1<<3)|0);return}function Dcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,64,e,202928+(f-1<<3)|0);return}function Ecb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;feb(a,b,c,d,64,e,f);return}function Fcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,32,e,202688+(f-1<<3)|0);return}function Gcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,32,e,202808+(f-1<<3)|0);return}function Hcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,32,e,202928+(f-1<<3)|0);return}function Icb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;feb(a,b,c,d,32,e,f);return}function Jcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,16,e,202688+(f-1<<3)|0);return}function Kcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,16,e,202808+(f-1<<3)|0);return}function Lcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,16,e,202928+(f-1<<3)|0);return}function Mcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;feb(a,b,c,d,16,e,f);return}function Ncb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,8,e,202688+(f-1<<3)|0);return}function Ocb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,8,e,202808+(f-1<<3)|0);return}function Pcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,8,e,202928+(f-1<<3)|0);return}function Qcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;feb(a,b,c,d,8,e,f);return}function Rcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,4,e,202688+(f-1<<3)|0);return}function Scb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,4,e,202808+(f-1<<3)|0);return}function Tcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;geb(a,b,c,d,4,e,202928+(f-1<<3)|0);return}function Ucb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;feb(a,b,c,d,4,e,f);return}function Vcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,64,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function Wcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,64,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function Xcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,64,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function Ycb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;deb(a,b,c,d,64,e,f,g);return}function Zcb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,32,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function _cb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,32,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function $cb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,32,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function adb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;deb(a,b,c,d,32,e,f,g);return}function bdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,16,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function cdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,16,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function ddb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,16,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function edb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;deb(a,b,c,d,16,e,f,g);return}function fdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,8,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function gdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,8,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function hdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,8,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function idb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;deb(a,b,c,d,8,e,f,g);return}function jdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,4,e,202688+(f-1<<3)|0,202688+(g-1<<3)|0);return}function kdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,4,e,202808+(f-1<<3)|0,202808+(g-1<<3)|0);return}function ldb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eeb(a,b,c,d,4,e,202928+(f-1<<3)|0,202928+(g-1<<3)|0);return}function mdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;deb(a,b,c,d,4,e,f,g);return}function ndb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,64,e,202688+(g-1<<3)|0);return}function odb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,64,e,202808+(g-1<<3)|0);return}function pdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,64,e,202928+(g-1<<3)|0);return}function qdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;beb(a,b,c,d,64,e,g);return}function rdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,32,e,202688+(g-1<<3)|0);return}function sdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,32,e,202808+(g-1<<3)|0);return}function tdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,32,e,202928+(g-1<<3)|0);return}function udb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;beb(a,b,c,d,32,e,g);return}function vdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,16,e,202688+(g-1<<3)|0);return}function wdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,16,e,202808+(g-1<<3)|0);return}function xdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,16,e,202928+(g-1<<3)|0);return}function ydb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;beb(a,b,c,d,16,e,g);return}function zdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,8,e,202688+(g-1<<3)|0);return}function Adb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,8,e,202808+(g-1<<3)|0);return}function Bdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,8,e,202928+(g-1<<3)|0);return}function Cdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;beb(a,b,c,d,8,e,g);return}function Ddb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,4,e,202688+(g-1<<3)|0);return}function Edb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,4,e,202808+(g-1<<3)|0);return}function Fdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ceb(a,b,c,d,4,e,202928+(g-1<<3)|0);return}function Gdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;beb(a,b,c,d,4,e,g);return}function Hdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,64,e,202688+(f-1<<3)|0);return}function Idb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,64,e,202808+(f-1<<3)|0);return}function Jdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,64,e,202928+(f-1<<3)|0);return}function Kdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;$db(a,b,c,d,64,e,f);return}function Ldb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,32,e,202688+(f-1<<3)|0);return}function Mdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,32,e,202808+(f-1<<3)|0);return}function Ndb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,32,e,202928+(f-1<<3)|0);return}function Odb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;$db(a,b,c,d,32,e,f);return}function Pdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,16,e,202688+(f-1<<3)|0);return}function Qdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,16,e,202808+(f-1<<3)|0);return}function Rdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,16,e,202928+(f-1<<3)|0);return}function Sdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;$db(a,b,c,d,16,e,f);return}function Tdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,8,e,202688+(f-1<<3)|0);return}function Udb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,8,e,202808+(f-1<<3)|0);return}function Vdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,8,e,202928+(f-1<<3)|0);return}function Wdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;$db(a,b,c,d,8,e,f);return}function Xdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,4,e,202688+(f-1<<3)|0);return}function Ydb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,4,e,202808+(f-1<<3)|0);return}function Zdb(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;aeb(a,b,c,d,4,e,202928+(f-1<<3)|0);return}function _db(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;$db(a,b,c,d,4,e,f);return}function $db(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=(g|0)>0;k=b;b=e;e=h;while(1){if(j){h=0;do{l=k+h|0;m=d[b+h|0]|0;h=h+1|0;a[l]=((d[l]|0)+1+m+(((ca((d[b+h|0]|0)-m|0,i)|0)+8|0)>>>4)|0)>>>1;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{k=k+c|0;b=b+f|0;e=h}}return}function aeb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=(g|0)>0;k=i+1|0;l=i+2|0;m=i+3|0;n=i+4|0;o=i+5|0;p=i+6|0;q=i+7|0;r=b;b=e;e=h;while(1){if(j){h=0;while(1){s=r+h|0;t=ca(d[b+(h-3)|0]|0,a[i]|0)|0;u=ca(d[b+(h-2)|0]|0,a[k]|0)|0;v=ca(d[b+(h-1)|0]|0,a[l]|0)|0;w=ca(d[b+h|0]|0,a[m]|0)|0;x=h+1|0;y=ca(d[b+x|0]|0,a[n]|0)|0;z=ca(d[b+(h+2)|0]|0,a[o]|0)|0;A=ca(d[b+(h+3)|0]|0,a[p]|0)|0;B=t+64+u+v+w+y+z+A+(ca(d[b+(h+4)|0]|0,a[q]|0)|0)>>7;if(B>>>0>255>>>0){C=-B>>31&255}else{C=B&255}a[s]=((d[s]|0)+1+(C&255)|0)>>>1;if((x|0)<(g|0)){h=x}else{break}}}h=e-1|0;if((h|0)==0){break}else{r=r+c|0;b=b+f|0;e=h}}return}function beb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=(g|0)>0;k=b;b=e;e=h;while(1){if(j){h=0;do{l=k+h|0;m=d[b+h|0]|0;a[l]=((d[l]|0)+1+m+(((ca((d[b+(h+f)|0]|0)-m|0,i)|0)+8|0)>>>4)|0)>>>1;h=h+1|0;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{k=k+c|0;b=b+f|0;e=h}}return}function ceb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;j=(g|0)>0;k=f*-3|0;l=i+1|0;m=f*-2|0;n=i+2|0;o=i+3|0;p=i+4|0;q=i+5|0;r=f<<1;s=i+6|0;t=f*3|0;u=i+7|0;v=f<<2;w=b;b=e;e=h;while(1){if(j){h=0;do{x=w+h|0;y=ca(d[b+(h+k)|0]|0,a[i]|0)|0;z=ca(d[b+(h+m)|0]|0,a[l]|0)|0;A=ca(d[b+(h-f)|0]|0,a[n]|0)|0;B=ca(d[b+h|0]|0,a[o]|0)|0;C=ca(d[b+(h+f)|0]|0,a[p]|0)|0;D=ca(d[b+(h+r)|0]|0,a[q]|0)|0;E=ca(d[b+(h+t)|0]|0,a[s]|0)|0;F=y+64+z+A+B+C+D+E+(ca(d[b+(h+v)|0]|0,a[u]|0)|0)>>7;if(F>>>0>255>>>0){G=-F>>31&255}else{G=F&255}a[x]=((d[x]|0)+1+(G&255)|0)>>>1;h=h+1|0;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{w=w+c|0;b=b+f|0;e=h}}return}function deb(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=i;i=i+4160|0;m=l|0;n=(g|0)>0;o=h+1|0;p=m;q=e;while(1){if(n){e=0;r=a[q]|0;while(1){s=r&255;t=e+1|0;u=a[q+t|0]|0;a[p+e|0]=(((ca((u&255)-s|0,j)|0)+8|0)>>>4)+s;if((t|0)<(g|0)){e=t;r=u}else{break}}}r=o-1|0;if((r|0)==0){v=m;w=b;x=h;break}else{o=r;p=p+64|0;q=q+f|0}}while(1){if(n){f=0;do{q=w+f|0;p=d[v+f|0]|0;a[q]=((d[q]|0)+1+p+(((ca((d[v+(f+64)|0]|0)-p|0,k)|0)+8|0)>>>4)|0)>>>1;f=f+1|0;}while((f|0)<(g|0))}f=x-1|0;if((f|0)==0){break}else{v=v+64|0;w=w+c|0;x=f}}i=l;return}function eeb(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;l=i;i=i+4544|0;m=l|0;n=(g|0)>0;o=j+1|0;p=j+2|0;q=j+3|0;r=j+4|0;s=j+5|0;t=j+6|0;u=j+7|0;if(n){v=m|0;w=h+7|0;x=e+(f*-3|0)|0;while(1){e=0;y=a[x-3|0]|0;z=a[x-2|0]|0;A=a[x-1|0]|0;B=a[x]|0;C=a[x+1|0]|0;D=a[x+2|0]|0;E=a[x+3|0]|0;while(1){F=ca(a[j]|0,y&255)|0;G=ca(a[o]|0,z&255)|0;H=ca(a[p]|0,A&255)|0;I=ca(a[q]|0,B&255)|0;J=e+1|0;K=ca(a[r]|0,C&255)|0;L=ca(a[s]|0,D&255)|0;M=ca(a[t]|0,E&255)|0;N=a[x+(e+4)|0]|0;O=F+64+G+H+I+K+L+M+(ca(N&255,a[u]|0)|0)>>7;if(O>>>0>255>>>0){P=-O>>31&255}else{P=O&255}a[v+e|0]=P;if((J|0)<(g|0)){e=J;y=z;z=A;A=B;B=C;C=D;D=E;E=N}else{break}}E=w-1|0;if((E|0)==0){break}else{v=v+64|0;w=E;x=x+f|0}}}f=k+1|0;x=k+2|0;w=k+3|0;v=k+4|0;P=k+5|0;u=k+6|0;t=k+7|0;s=m+192|0;m=b;b=h;while(1){if(n){h=0;do{r=m+h|0;q=ca(d[s+(h-192)|0]|0,a[k]|0)|0;p=ca(d[s+(h-128)|0]|0,a[f]|0)|0;o=ca(d[s+(h-64)|0]|0,a[x]|0)|0;j=ca(d[s+h|0]|0,a[w]|0)|0;E=ca(d[s+(h+64)|0]|0,a[v]|0)|0;D=ca(d[s+(h+128)|0]|0,a[P]|0)|0;C=ca(d[s+(h+192)|0]|0,a[u]|0)|0;B=q+64+p+o+j+E+D+C+(ca(d[s+(h+256)|0]|0,a[t]|0)|0)>>7;if(B>>>0>255>>>0){Q=-B>>31&255}else{Q=B&255}a[r]=((d[r]|0)+1+(Q&255)|0)>>>1;h=h+1|0;}while((h|0)<(g|0))}h=b-1|0;if((h|0)==0){break}else{s=s+64|0;m=m+c|0;b=h}}i=l;return}function feb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=(g|0)>0;k=b;b=e;e=h;while(1){if(j){h=0;while(1){l=d[b+h|0]|0;m=h+1|0;a[k+h|0]=(((ca((d[b+m|0]|0)-l|0,i)|0)+8|0)>>>4)+l;if((m|0)<(g|0)){h=m}else{break}}}h=e-1|0;if((h|0)==0){break}else{k=k+c|0;b=b+f|0;e=h}}return}function geb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=(g|0)>0;k=i+1|0;l=i+2|0;m=i+3|0;n=i+4|0;o=i+5|0;p=i+6|0;q=i+7|0;r=b;b=e;e=h;while(1){if(j){h=0;while(1){s=ca(d[b+(h-3)|0]|0,a[i]|0)|0;t=ca(d[b+(h-2)|0]|0,a[k]|0)|0;u=ca(d[b+(h-1)|0]|0,a[l]|0)|0;v=ca(d[b+h|0]|0,a[m]|0)|0;w=h+1|0;x=ca(d[b+w|0]|0,a[n]|0)|0;y=ca(d[b+(h+2)|0]|0,a[o]|0)|0;z=ca(d[b+(h+3)|0]|0,a[p]|0)|0;A=s+64+t+u+v+x+y+z+(ca(d[b+(h+4)|0]|0,a[q]|0)|0)>>7;if(A>>>0>255>>>0){B=-A>>31&255}else{B=A&255}a[r+h|0]=B;if((w|0)<(g|0)){h=w}else{break}}}h=e-1|0;if((h|0)==0){break}else{r=r+c|0;b=b+f|0;e=h}}return}function heb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=(g|0)>0;k=b;b=e;e=h;while(1){if(j){h=0;do{l=d[b+h|0]|0;a[k+h|0]=(((ca((d[b+(h+f)|0]|0)-l|0,i)|0)+8|0)>>>4)+l;h=h+1|0;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{k=k+c|0;b=b+f|0;e=h}}return}function ieb(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=(g|0)>0;k=f*-3|0;l=i+1|0;m=f*-2|0;n=i+2|0;o=i+3|0;p=i+4|0;q=i+5|0;r=f<<1;s=i+6|0;t=f*3|0;u=i+7|0;v=f<<2;w=b;b=e;e=h;while(1){if(j){h=0;do{x=ca(d[b+(h+k)|0]|0,a[i]|0)|0;y=ca(d[b+(h+m)|0]|0,a[l]|0)|0;z=ca(d[b+(h-f)|0]|0,a[n]|0)|0;A=ca(d[b+h|0]|0,a[o]|0)|0;B=ca(d[b+(h+f)|0]|0,a[p]|0)|0;C=ca(d[b+(h+r)|0]|0,a[q]|0)|0;D=ca(d[b+(h+t)|0]|0,a[s]|0)|0;E=x+64+y+z+A+B+C+D+(ca(d[b+(h+v)|0]|0,a[u]|0)|0)>>7;if(E>>>0>255>>>0){F=-E>>31&255}else{F=E&255}a[w+h|0]=F;h=h+1|0;}while((h|0)<(g|0))}h=e-1|0;if((h|0)==0){break}else{w=w+c|0;b=b+f|0;e=h}}return}function jeb(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=i;i=i+4160|0;m=l|0;n=(g|0)>0;o=h+1|0;p=m;q=e;while(1){if(n){e=0;r=a[q]|0;while(1){s=r&255;t=e+1|0;u=a[q+t|0]|0;a[p+e|0]=(((ca((u&255)-s|0,j)|0)+8|0)>>>4)+s;if((t|0)<(g|0)){e=t;r=u}else{break}}}r=o-1|0;if((r|0)==0){v=m;w=b;x=h;break}else{o=r;p=p+64|0;q=q+f|0}}while(1){if(n){f=0;do{q=d[v+f|0]|0;a[w+f|0]=(((ca((d[v+(f+64)|0]|0)-q|0,k)|0)+8|0)>>>4)+q;f=f+1|0;}while((f|0)<(g|0))}f=x-1|0;if((f|0)==0){break}else{v=v+64|0;w=w+c|0;x=f}}i=l;return}function keb(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;l=i;i=i+4544|0;m=l|0;n=(g|0)>0;o=j+1|0;p=j+2|0;q=j+3|0;r=j+4|0;s=j+5|0;t=j+6|0;u=j+7|0;if(n){v=m|0;w=h+7|0;x=e+(f*-3|0)|0;while(1){e=0;y=a[x-3|0]|0;z=a[x-2|0]|0;A=a[x-1|0]|0;B=a[x]|0;C=a[x+1|0]|0;D=a[x+2|0]|0;E=a[x+3|0]|0;while(1){F=ca(a[j]|0,y&255)|0;G=ca(a[o]|0,z&255)|0;H=ca(a[p]|0,A&255)|0;I=ca(a[q]|0,B&255)|0;J=e+1|0;K=ca(a[r]|0,C&255)|0;L=ca(a[s]|0,D&255)|0;M=ca(a[t]|0,E&255)|0;N=a[x+(e+4)|0]|0;O=F+64+G+H+I+K+L+M+(ca(N&255,a[u]|0)|0)>>7;if(O>>>0>255>>>0){P=-O>>31&255}else{P=O&255}a[v+e|0]=P;if((J|0)<(g|0)){e=J;y=z;z=A;A=B;B=C;C=D;D=E;E=N}else{break}}E=w-1|0;if((E|0)==0){break}else{v=v+64|0;w=E;x=x+f|0}}}f=k+1|0;x=k+2|0;w=k+3|0;v=k+4|0;P=k+5|0;u=k+6|0;t=k+7|0;s=m+192|0;m=b;b=h;while(1){if(n){h=0;do{r=ca(d[s+(h-192)|0]|0,a[k]|0)|0;q=ca(d[s+(h-128)|0]|0,a[f]|0)|0;p=ca(d[s+(h-64)|0]|0,a[x]|0)|0;o=ca(d[s+h|0]|0,a[w]|0)|0;j=ca(d[s+(h+64)|0]|0,a[v]|0)|0;E=ca(d[s+(h+128)|0]|0,a[P]|0)|0;D=ca(d[s+(h+192)|0]|0,a[u]|0)|0;C=r+64+q+p+o+j+E+D+(ca(d[s+(h+256)|0]|0,a[t]|0)|0)>>7;if(C>>>0>255>>>0){Q=-C>>31&255}else{Q=C&255}a[m+h|0]=Q;h=h+1|0;}while((h|0)<(g|0))}h=b-1|0;if((h|0)==0){break}else{s=s+64|0;m=m+c|0;b=h}}i=l;return}function leb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=0;i=b;while(1){b=d[i-3|0]|0;j=i-2|0;k=d[j]|0;l=i-1|0;m=d[l]|0;n=d[i]|0;o=i+1|0;p=d[o]|0;q=d[i+2|0]|0;r=d[i+3|0]|0;s=(d[i-4|0]|0)-b|0;a:do{if((((s|0)>-1?s:-s|0)|0)<=(f|0)){t=b-k|0;if((((t|0)>-1?t:-t|0)|0)>(f|0)){break}t=k-m|0;u=(t|0)>-1?t:-t|0;if((u|0)>(f|0)){break}t=p-n|0;v=(t|0)>-1?t:-t|0;if((v|0)>(f|0)){break}t=q-p|0;if((((t|0)>-1?t:-t|0)|0)>(f|0)){break}t=r-q|0;if((((t|0)>-1?t:-t|0)|0)>(f|0)){break}t=m-n|0;w=k-p|0;if(((((w|0)>-1?w:-w|0)>>1)+(((t|0)>-1?t:-t|0)<<1)|0)>(e|0)){break}do{if((u|0)>(g|0)){x=(n-m|0)*3|0}else{t=(n-m|0)*3|0;if((v|0)>(g|0)){x=t;break}if((t+128|0)>>>0>255>>>0){y=(t>>31^127)&255}else{y=t&255}t=y<<24>>24;z=t+4|0;A=(z|0)>127?15:z>>3;z=t+3|0;t=((z|0)>127?15:z>>3)+m|0;if(t>>>0>255>>>0){B=-t>>31&255}else{B=t&255}a[l]=B;t=n-A|0;if(t>>>0>255>>>0){C=-t>>31&255}else{C=t&255}a[i]=C;t=A+1>>1;A=t+k|0;if(A>>>0>255>>>0){D=-A>>31&255}else{D=A&255}a[j]=D;A=p-t|0;if(A>>>0>255>>>0){E=-A>>31&255}else{E=A&255}a[o]=E;break a}}while(0);if((w+128|0)>>>0>255>>>0){F=(w>>31^127)&255}else{F=w&255}v=(F<<24>>24)+x|0;if((v+128|0)>>>0>255>>>0){G=(v>>31^127)&255}else{G=v&255}v=G<<24>>24;u=v+4|0;A=v+3|0;v=((A|0)>127?15:A>>3)+m|0;if(v>>>0>255>>>0){H=-v>>31&255}else{H=v&255}a[l]=H;v=n-((u|0)>127?15:u>>3)|0;if(v>>>0>255>>>0){I=-v>>31&255}else{I=v&255}a[i]=I}}while(0);n=h+1|0;if((n|0)<8){h=n;i=i+c|0}else{break}}return}function meb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=c*-4|0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=c*3|0;n=0;o=b;while(1){b=d[o+i|0]|0;p=o+j|0;q=d[p]|0;r=o+k|0;s=d[r]|0;t=d[o]|0;u=o+c|0;v=d[u]|0;w=d[o+l|0]|0;x=d[o+m|0]|0;y=(d[o+h|0]|0)-b|0;a:do{if((((y|0)>-1?y:-y|0)|0)<=(f|0)){z=b-q|0;if((((z|0)>-1?z:-z|0)|0)>(f|0)){break}z=q-s|0;A=(z|0)>-1?z:-z|0;if((A|0)>(f|0)){break}z=v-t|0;B=(z|0)>-1?z:-z|0;if((B|0)>(f|0)){break}z=w-v|0;if((((z|0)>-1?z:-z|0)|0)>(f|0)){break}z=x-w|0;if((((z|0)>-1?z:-z|0)|0)>(f|0)){break}z=s-t|0;C=q-v|0;if(((((C|0)>-1?C:-C|0)>>1)+(((z|0)>-1?z:-z|0)<<1)|0)>(e|0)){break}do{if((A|0)>(g|0)){D=(t-s|0)*3|0}else{z=(t-s|0)*3|0;if((B|0)>(g|0)){D=z;break}if((z+128|0)>>>0>255>>>0){E=(z>>31^127)&255}else{E=z&255}z=E<<24>>24;F=z+4|0;G=(F|0)>127?15:F>>3;F=z+3|0;z=((F|0)>127?15:F>>3)+s|0;if(z>>>0>255>>>0){H=-z>>31&255}else{H=z&255}a[r]=H;z=t-G|0;if(z>>>0>255>>>0){I=-z>>31&255}else{I=z&255}a[o]=I;z=G+1>>1;G=z+q|0;if(G>>>0>255>>>0){J=-G>>31&255}else{J=G&255}a[p]=J;G=v-z|0;if(G>>>0>255>>>0){K=-G>>31&255}else{K=G&255}a[u]=K;break a}}while(0);if((C+128|0)>>>0>255>>>0){L=(C>>31^127)&255}else{L=C&255}B=(L<<24>>24)+D|0;if((B+128|0)>>>0>255>>>0){M=(B>>31^127)&255}else{M=B&255}B=M<<24>>24;A=B+4|0;G=B+3|0;B=((G|0)>127?15:G>>3)+s|0;if(B>>>0>255>>>0){N=-B>>31&255}else{N=B&255}a[r]=N;B=t-((A|0)>127?15:A>>3)|0;if(B>>>0>255>>>0){O=-B>>31&255}else{O=B&255}a[o]=O}}while(0);t=n+1|0;if((t|0)<8){n=t;o=o+1|0}else{break}}return}function neb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=0;i=b;while(1){b=d[i-4|0]|0;j=i-3|0;k=d[j]|0;l=i-2|0;m=d[l]|0;n=i-1|0;o=d[n]|0;p=d[i]|0;q=i+1|0;r=d[q]|0;s=i+2|0;t=d[s]|0;u=d[i+3|0]|0;v=b-k|0;a:do{if((((v|0)>-1?v:-v|0)|0)<=(f|0)){w=k-m|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=m-o|0;x=(w|0)>-1?w:-w|0;if((x|0)>(f|0)){break}w=r-p|0;y=(w|0)>-1?w:-w|0;if((y|0)>(f|0)){break}w=t-r|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=u-t|0;if((((w|0)>-1?w:-w|0)|0)>(f|0)){break}w=o-p|0;z=m-r|0;if(((((z|0)>-1?z:-z|0)>>1)+(((w|0)>-1?w:-w|0)<<1)|0)>(e|0)){break}w=b-o|0;do{if((((w|0)>-1?w:-w|0)|0)<2){A=k-o|0;if(!((((A|0)>-1?A:-A|0)|0)<2&(x|0)<2&(y|0)<2)){break}A=t-p|0;if((((A|0)>-1?A:-A|0)|0)>=2){break}A=u-p|0;if((((A|0)>-1?A:-A|0)|0)>=2){break}A=b<<1;B=b+4|0;a[j]=(B+A+(k<<1)+m+o+p|0)>>>3;C=k+4|0;a[l]=(C+A+(m<<1)+o+p+r|0)>>>3;a[n]=(B+k+m+(o<<1)+p+r+t|0)>>>3;a[i]=(C+m+o+(p<<1)+r+t+u|0)>>>3;a[q]=(m+4+o+p+t+(u+r<<1)|0)>>>3;a[s]=(o+4+p+r+(t<<1)+(u*3|0)|0)>>>3;break a}}while(0);do{if((x|0)>(g|0)){D=(p-o|0)*3|0}else{w=(p-o|0)*3|0;if((y|0)>(g|0)){D=w;break}if((w+128|0)>>>0>255>>>0){E=(w>>31^127)&255}else{E=w&255}w=E<<24>>24;C=w+4|0;B=(C|0)>127?15:C>>3;C=w+3|0;w=((C|0)>127?15:C>>3)+o|0;if(w>>>0>255>>>0){F=-w>>31&255}else{F=w&255}a[n]=F;w=p-B|0;if(w>>>0>255>>>0){G=-w>>31&255}else{G=w&255}a[i]=G;w=B+1>>1;B=w+m|0;if(B>>>0>255>>>0){H=-B>>31&255}else{H=B&255}a[l]=H;B=r-w|0;if(B>>>0>255>>>0){I=-B>>31&255}else{I=B&255}a[q]=I;break a}}while(0);if((z+128|0)>>>0>255>>>0){J=(z>>31^127)&255}else{J=z&255}y=(J<<24>>24)+D|0;if((y+128|0)>>>0>255>>>0){K=(y>>31^127)&255}else{K=y&255}y=K<<24>>24;x=y+4|0;B=y+3|0;y=((B|0)>127?15:B>>3)+o|0;if(y>>>0>255>>>0){L=-y>>31&255}else{L=y&255}a[n]=L;y=p-((x|0)>127?15:x>>3)|0;if(y>>>0>255>>>0){M=-y>>31&255}else{M=y&255}a[i]=M}}while(0);p=h+1|0;if((p|0)<8){h=p;i=i+c|0}else{break}}return}function oeb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=c*-4|0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=c*3|0;n=0;o=b;while(1){b=d[o+h|0]|0;p=o+i|0;q=d[p]|0;r=o+j|0;s=d[r]|0;t=o+k|0;u=d[t]|0;v=d[o]|0;w=o+c|0;x=d[w]|0;y=o+l|0;z=d[y]|0;A=d[o+m|0]|0;B=b-q|0;a:do{if((((B|0)>-1?B:-B|0)|0)<=(f|0)){C=q-s|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=s-u|0;D=(C|0)>-1?C:-C|0;if((D|0)>(f|0)){break}C=x-v|0;E=(C|0)>-1?C:-C|0;if((E|0)>(f|0)){break}C=z-x|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=A-z|0;if((((C|0)>-1?C:-C|0)|0)>(f|0)){break}C=u-v|0;F=s-x|0;if(((((F|0)>-1?F:-F|0)>>1)+(((C|0)>-1?C:-C|0)<<1)|0)>(e|0)){break}C=b-u|0;do{if((((C|0)>-1?C:-C|0)|0)<2){G=q-u|0;if(!((((G|0)>-1?G:-G|0)|0)<2&(D|0)<2&(E|0)<2)){break}G=z-v|0;if((((G|0)>-1?G:-G|0)|0)>=2){break}G=A-v|0;if((((G|0)>-1?G:-G|0)|0)>=2){break}G=b<<1;H=b+4|0;a[p]=(H+G+(q<<1)+s+u+v|0)>>>3;I=q+4|0;a[r]=(I+G+(s<<1)+u+v+x|0)>>>3;a[t]=(H+q+s+(u<<1)+v+x+z|0)>>>3;a[o]=(I+s+u+(v<<1)+x+z+A|0)>>>3;a[w]=(s+4+u+v+z+(A+x<<1)|0)>>>3;a[y]=(u+4+v+x+(z<<1)+(A*3|0)|0)>>>3;break a}}while(0);do{if((D|0)>(g|0)){J=(v-u|0)*3|0}else{C=(v-u|0)*3|0;if((E|0)>(g|0)){J=C;break}if((C+128|0)>>>0>255>>>0){K=(C>>31^127)&255}else{K=C&255}C=K<<24>>24;I=C+4|0;H=(I|0)>127?15:I>>3;I=C+3|0;C=((I|0)>127?15:I>>3)+u|0;if(C>>>0>255>>>0){L=-C>>31&255}else{L=C&255}a[t]=L;C=v-H|0;if(C>>>0>255>>>0){M=-C>>31&255}else{M=C&255}a[o]=M;C=H+1>>1;H=C+s|0;if(H>>>0>255>>>0){N=-H>>31&255}else{N=H&255}a[r]=N;H=x-C|0;if(H>>>0>255>>>0){O=-H>>31&255}else{O=H&255}a[w]=O;break a}}while(0);if((F+128|0)>>>0>255>>>0){P=(F>>31^127)&255}else{P=F&255}E=(P<<24>>24)+J|0;if((E+128|0)>>>0>255>>>0){Q=(E>>31^127)&255}else{Q=E&255}E=Q<<24>>24;D=E+4|0;H=E+3|0;E=((H|0)>127?15:H>>3)+u|0;if(E>>>0>255>>>0){R=-E>>31&255}else{R=E&255}a[t]=R;E=v-((D|0)>127?15:D>>3)|0;if(E>>>0>255>>>0){S=-E>>31&255}else{S=E&255}a[o]=S}}while(0);v=n+1|0;if((v|0)<8){n=v;o=o+1|0}else{break}}return}function peb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;h=0;i=b;while(1){b=i-4|0;j=d[b]|0;k=i-3|0;l=d[k]|0;m=i-2|0;n=d[m]|0;o=i-1|0;p=d[o]|0;q=d[i]|0;r=i+1|0;s=d[r]|0;t=i+2|0;u=d[t]|0;v=i+3|0;w=d[v]|0;x=j-l|0;a:do{if((((x|0)>-1?x:-x|0)|0)<=(f|0)){y=l-n|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=n-p|0;z=(y|0)>-1?y:-y|0;if((z|0)>(f|0)){break}y=s-q|0;A=(y|0)>-1?y:-y|0;if((A|0)>(f|0)){break}y=u-s|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=w-u|0;if((((y|0)>-1?y:-y|0)|0)>(f|0)){break}y=p-q|0;B=n-s|0;if(((((B|0)>-1?B:-B|0)>>1)+(((y|0)>-1?y:-y|0)<<1)|0)>(e|0)){break}y=d[i-8|0]|0;C=i-7|0;D=d[C]|0;E=i-6|0;F=d[E]|0;G=i-5|0;H=d[G]|0;I=i+4|0;J=d[I]|0;K=i+5|0;L=d[K]|0;M=i+6|0;N=d[M]|0;O=d[i+7|0]|0;P=y-p|0;do{if((((P|0)>-1?P:-P|0)|0)<2){Q=D-p|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=F-p|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=H-p|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=J-q|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=L-q|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=N-q|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){R=0;break}Q=O-q|0;R=(((Q|0)>-1?Q:-Q|0)|0)<2|0}else{R=0}}while(0);P=j-p|0;do{if((((P|0)>-1?P:-P|0)|0)<2){Q=l-p|0;if(!((((Q|0)>-1?Q:-Q|0)|0)<2&(z|0)<2&(A|0)<2)){break}Q=u-q|0;if((((Q|0)>-1?Q:-Q|0)|0)>=2){break}Q=w-q|0;S=(((Q|0)>-1?Q:-Q|0)|0)<2;if(!((R|0)==0|S^1)){Q=y<<1;T=Q+y|0;U=T+y|0;V=U+y|0;W=V+y|0;X=j+8|0;Y=X+l|0;Z=Y+n|0;_=Z+p|0;$=_+q|0;a[C]=(y+$+F+(D<<1)+H+W|0)>>>4;aa=$+s|0;a[E]=(D+aa+H+(F<<1)+W|0)>>>4;W=aa+u|0;a[G]=(D+W+F+(H<<1)+V|0)>>>4;a[b]=((j<<1)+8+l+n+p+q+s+u+w+D+F+H+U|0)>>>4;a[k]=((l<<1)+X+n+p+q+s+u+w+D+F+T+H+J|0)>>>4;a[m]=((n<<1)+Y+p+q+s+u+w+D+Q+F+H+J+L|0)>>>4;a[o]=((p<<1)+Z+q+s+u+w+y+D+F+H+J+L+N|0)>>>4;a[i]=((q<<1)+_+s+u+w+D+F+H+J+L+N+O|0)>>>4;a[r]=(u+$+w+F+H+J+L+N+(O+s<<1)|0)>>>4;a[t]=((u<<1)+aa+w+H+J+L+N+(O*3|0)|0)>>>4;a[v]=((w<<1)+W+J+L+N+(O<<2)|0)>>>4;a[I]=(l+8+n+p+q+s+u+w+L+(J<<1)+N+(O*5|0)|0)>>>4;a[K]=(n+8+p+q+s+u+w+J+(L<<1)+N+(O*6|0)|0)>>>4;a[M]=(p+8+q+s+u+w+J+L+(N<<1)+(O*7|0)|0)>>>4;break a}if(!S){break}S=j<<1;W=j+4|0;a[k]=(W+S+(l<<1)+n+p+q|0)>>>3;aa=l+4|0;a[m]=(aa+S+(n<<1)+p+q+s|0)>>>3;a[o]=(W+l+n+(p<<1)+q+s+u|0)>>>3;a[i]=(aa+n+p+(q<<1)+s+u+w|0)>>>3;a[r]=(n+4+p+q+u+(w+s<<1)|0)>>>3;a[t]=(p+4+q+s+(u<<1)+(w*3|0)|0)>>>3;break a}}while(0);do{if((z|0)>(g|0)){ba=(q-p|0)*3|0}else{O=(q-p|0)*3|0;if((A|0)>(g|0)){ba=O;break}if((O+128|0)>>>0>255>>>0){ca=(O>>31^127)&255}else{ca=O&255}O=ca<<24>>24;N=O+4|0;L=(N|0)>127?15:N>>3;N=O+3|0;O=((N|0)>127?15:N>>3)+p|0;if(O>>>0>255>>>0){da=-O>>31&255}else{da=O&255}a[o]=da;O=q-L|0;if(O>>>0>255>>>0){ea=-O>>31&255}else{ea=O&255}a[i]=ea;O=L+1>>1;L=O+n|0;if(L>>>0>255>>>0){fa=-L>>31&255}else{fa=L&255}a[m]=fa;L=s-O|0;if(L>>>0>255>>>0){ga=-L>>31&255}else{ga=L&255}a[r]=ga;break a}}while(0);if((B+128|0)>>>0>255>>>0){ha=(B>>31^127)&255}else{ha=B&255}A=(ha<<24>>24)+ba|0;if((A+128|0)>>>0>255>>>0){ia=(A>>31^127)&255}else{ia=A&255}A=ia<<24>>24;z=A+4|0;L=A+3|0;A=((L|0)>127?15:L>>3)+p|0;if(A>>>0>255>>>0){ja=-A>>31&255}else{ja=A&255}a[o]=ja;A=q-((z|0)>127?15:z>>3)|0;if(A>>>0>255>>>0){ka=-A>>31&255}else{ka=A&255}a[i]=ka}}while(0);q=h+1|0;if((q|0)<8){h=q;i=i+c|0}else{break}}return}function qeb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;h=c*-4|0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=c*3|0;n=c*-8|0;o=c*-7|0;p=c*-6|0;q=c*-5|0;r=c<<2;s=c*5|0;t=c*6|0;u=c*7|0;v=0;w=b;while(1){b=w+h|0;x=d[b]|0;y=w+i|0;z=d[y]|0;A=w+j|0;B=d[A]|0;C=w+k|0;D=d[C]|0;E=d[w]|0;F=w+c|0;G=d[F]|0;H=w+l|0;I=d[H]|0;J=w+m|0;K=d[J]|0;L=x-z|0;a:do{if((((L|0)>-1?L:-L|0)|0)<=(f|0)){M=z-B|0;if((((M|0)>-1?M:-M|0)|0)>(f|0)){break}M=B-D|0;N=(M|0)>-1?M:-M|0;if((N|0)>(f|0)){break}M=G-E|0;O=(M|0)>-1?M:-M|0;if((O|0)>(f|0)){break}M=I-G|0;if((((M|0)>-1?M:-M|0)|0)>(f|0)){break}M=K-I|0;if((((M|0)>-1?M:-M|0)|0)>(f|0)){break}M=D-E|0;P=B-G|0;if(((((P|0)>-1?P:-P|0)>>1)+(((M|0)>-1?M:-M|0)<<1)|0)>(e|0)){break}M=d[w+n|0]|0;Q=w+o|0;R=d[Q]|0;S=w+p|0;T=d[S]|0;U=w+q|0;V=d[U]|0;W=w+r|0;X=d[W]|0;Y=w+s|0;Z=d[Y]|0;_=w+t|0;$=d[_]|0;aa=d[w+u|0]|0;ba=M-D|0;do{if((((ba|0)>-1?ba:-ba|0)|0)<2){ca=R-D|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=T-D|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=V-D|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=X-E|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=Z-E|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=$-E|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){da=0;break}ca=aa-E|0;da=(((ca|0)>-1?ca:-ca|0)|0)<2|0}else{da=0}}while(0);ba=x-D|0;do{if((((ba|0)>-1?ba:-ba|0)|0)<2){ca=z-D|0;if(!((((ca|0)>-1?ca:-ca|0)|0)<2&(N|0)<2&(O|0)<2)){break}ca=I-E|0;if((((ca|0)>-1?ca:-ca|0)|0)>=2){break}ca=K-E|0;ea=(((ca|0)>-1?ca:-ca|0)|0)<2;if(!((da|0)==0|ea^1)){ca=M<<1;fa=ca+M|0;ga=fa+M|0;ha=ga+M|0;ia=ha+M|0;ja=x+8|0;ka=ja+z|0;la=ka+B|0;ma=la+D|0;na=ma+E|0;a[Q]=(M+na+T+(R<<1)+V+ia|0)>>>4;oa=na+G|0;a[S]=(R+oa+V+(T<<1)+ia|0)>>>4;ia=oa+I|0;a[U]=(R+ia+T+(V<<1)+ha|0)>>>4;a[b]=((x<<1)+8+z+B+D+E+G+I+K+R+T+V+ga|0)>>>4;a[y]=((z<<1)+ja+B+D+E+G+I+K+R+T+fa+V+X|0)>>>4;a[A]=((B<<1)+ka+D+E+G+I+K+R+ca+T+V+X+Z|0)>>>4;a[C]=((D<<1)+la+E+G+I+K+M+R+T+V+X+Z+$|0)>>>4;a[w]=((E<<1)+ma+G+I+K+R+T+V+X+Z+$+aa|0)>>>4;a[F]=(I+na+K+T+V+X+Z+$+(aa+G<<1)|0)>>>4;a[H]=((I<<1)+oa+K+V+X+Z+$+(aa*3|0)|0)>>>4;a[J]=((K<<1)+ia+X+Z+$+(aa<<2)|0)>>>4;a[W]=(z+8+B+D+E+G+I+K+Z+(X<<1)+$+(aa*5|0)|0)>>>4;a[Y]=(B+8+D+E+G+I+K+X+(Z<<1)+$+(aa*6|0)|0)>>>4;a[_]=(D+8+E+G+I+K+X+Z+($<<1)+(aa*7|0)|0)>>>4;break a}if(!ea){break}ea=x<<1;ia=x+4|0;a[y]=(ia+ea+(z<<1)+B+D+E|0)>>>3;oa=z+4|0;a[A]=(oa+ea+(B<<1)+D+E+G|0)>>>3;a[C]=(ia+z+B+(D<<1)+E+G+I|0)>>>3;a[w]=(oa+B+D+(E<<1)+G+I+K|0)>>>3;a[F]=(B+4+D+E+I+(K+G<<1)|0)>>>3;a[H]=(D+4+E+G+(I<<1)+(K*3|0)|0)>>>3;break a}}while(0);do{if((N|0)>(g|0)){pa=(E-D|0)*3|0}else{aa=(E-D|0)*3|0;if((O|0)>(g|0)){pa=aa;break}if((aa+128|0)>>>0>255>>>0){qa=(aa>>31^127)&255}else{qa=aa&255}aa=qa<<24>>24;$=aa+4|0;Z=($|0)>127?15:$>>3;$=aa+3|0;aa=(($|0)>127?15:$>>3)+D|0;if(aa>>>0>255>>>0){ra=-aa>>31&255}else{ra=aa&255}a[C]=ra;aa=E-Z|0;if(aa>>>0>255>>>0){sa=-aa>>31&255}else{sa=aa&255}a[w]=sa;aa=Z+1>>1;Z=aa+B|0;if(Z>>>0>255>>>0){ta=-Z>>31&255}else{ta=Z&255}a[A]=ta;Z=G-aa|0;if(Z>>>0>255>>>0){ua=-Z>>31&255}else{ua=Z&255}a[F]=ua;break a}}while(0);if((P+128|0)>>>0>255>>>0){va=(P>>31^127)&255}else{va=P&255}O=(va<<24>>24)+pa|0;if((O+128|0)>>>0>255>>>0){wa=(O>>31^127)&255}else{wa=O&255}O=wa<<24>>24;N=O+4|0;Z=O+3|0;O=((Z|0)>127?15:Z>>3)+D|0;if(O>>>0>255>>>0){xa=-O>>31&255}else{xa=O&255}a[C]=xa;O=E-((N|0)>127?15:N>>3)|0;if(O>>>0>255>>>0){ya=-O>>31&255}else{ya=O&255}a[w]=ya}}while(0);E=v+1|0;if((E|0)<8){v=E;w=w+1|0}else{break}}return}function reb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;peb(a,b,c,d,e);peb(a+(b<<3)|0,b,c,d,e);return}function seb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;qeb(a,b,c,d,e);qeb(a+8|0,b,c,d,e);return}function teb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;leb(a,b,c&255,d&255,e&255);leb(a+(b<<3)|0,b,c>>8,d>>8,e>>8);return}function ueb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;meb(a,b,c&255,d&255,e&255);meb(a+8|0,b,c>>8,d>>8,e>>8);return}function veb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;leb(a,b,c&255,d&255,e&255);neb(a+(b<<3)|0,b,c>>8,d>>8,e>>8);return}function web(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;meb(a,b,c&255,d&255,e&255);oeb(a+8|0,b,c>>8,d>>8,e>>8);return}function xeb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;neb(a,b,c&255,d&255,e&255);leb(a+(b<<3)|0,b,c>>8,d>>8,e>>8);return}function yeb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;oeb(a,b,c&255,d&255,e&255);meb(a+8|0,b,c>>8,d>>8,e>>8);return}function zeb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;neb(a,b,c&255,d&255,e&255);neb(a+(b<<3)|0,b,c>>8,d>>8,e>>8);return}function Aeb(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;oeb(a,b,c&255,d&255,e&255);oeb(a+8|0,b,c>>8,d>>8,e>>8);return}function Beb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+40|0;j=h|0;k=h+32|0;if((g|0)==1){g=((((b[f>>1]|0)*11585|0)+8192>>14)*11585|0)+8192>>14;b[f>>1]=0;l=g+8>>4;g=0;m=c;while(1){n=(d[m]|0)+l|0;if(n>>>0>255>>>0){o=-n>>31&255}else{o=n&255}a[m]=o;n=m+e|0;p=(d[n]|0)+l|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[n]=q;n=m+(e<<1)|0;p=(d[n]|0)+l|0;if(p>>>0>255>>>0){r=-p>>31&255}else{r=p&255}a[n]=r;n=m+(e*3|0)|0;p=(d[n]|0)+l|0;if(p>>>0>255>>>0){s=-p>>31&255}else{s=p&255}a[n]=s;n=g+1|0;if((n|0)<4){g=n;m=m+1|0}else{break}}i=h;return}else{t=0}do{m=t<<2;g=b[f+(t<<1)>>1]|0;s=b[f+(t+8<<1)>>1]|0;l=((s+g|0)*11585|0)+8192>>14;r=((g-s|0)*11585|0)+8192>>14;s=b[f+(t+4<<1)>>1]|0;g=b[f+(t+12<<1)>>1]|0;q=(s*6270|0)+8192+(g*-15137|0)>>14;o=(s*15137|0)+8192+(g*6270|0)>>14;b[j+(m<<1)>>1]=o+l;b[j+((m|1)<<1)>>1]=q+r;b[j+((m|2)<<1)>>1]=r-q;b[j+((m|3)<<1)>>1]=l-o;t=t+1|0;}while((t|0)<4);mrc(f|0,0,32)|0;f=k|0;t=k+2|0;o=k+4|0;l=k+6|0;k=0;m=c;while(1){c=b[j+(k<<1)>>1]|0;q=b[j+(k+8<<1)>>1]|0;r=((q+c|0)*11585|0)+8192>>14;g=((c-q|0)*11585|0)+8192>>14;q=b[j+(k+4<<1)>>1]|0;c=b[j+(k+12<<1)>>1]|0;s=(q*6270|0)+8192+(c*-15137|0)>>14;n=(q*15137|0)+8192+(c*6270|0)>>14;c=n+r&65535;b[f>>1]=c;b[t>>1]=s+g;b[o>>1]=g-s;b[l>>1]=r-n;n=((c<<16>>16)+8>>4)+(d[m]|0)|0;if(n>>>0>255>>>0){u=-n>>31&255}else{u=n&255}a[m]=u;n=m+e|0;c=((b[t>>1]|0)+8>>4)+(d[n]|0)|0;if(c>>>0>255>>>0){v=-c>>31&255}else{v=c&255}a[n]=v;n=m+(e<<1)|0;c=((b[o>>1]|0)+8>>4)+(d[n]|0)|0;if(c>>>0>255>>>0){w=-c>>31&255}else{w=c&255}a[n]=w;n=m+(e*3|0)|0;c=((b[l>>1]|0)+8>>4)+(d[n]|0)|0;if(c>>>0>255>>>0){x=-c>>31&255}else{x=c&255}a[n]=x;n=k+1|0;if((n|0)<4){k=n;m=m+1|0}else{break}}i=h;return}function Ceb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+40|0;h=g|0;j=g+32|0;k=0;do{l=k<<2;m=b[f+(k<<1)>>1]|0;n=b[f+(k+8<<1)>>1]|0;o=b[f+(k+12<<1)>>1]|0;p=(n*15212|0)+(m*5283|0)+(o*9929|0)|0;q=(n*-5283|0)+(m*9929|0)+(o*-15212|0)|0;r=(b[f+(k+4<<1)>>1]|0)*13377|0;s=r+8192|0;b[h+(l<<1)>>1]=(s+p|0)>>>14;b[h+((l|1)<<1)>>1]=(s+q|0)>>>14;b[h+((l|2)<<1)>>1]=(((m-n+o|0)*13377|0)+8192|0)>>>14;b[h+((l|3)<<1)>>1]=(q+8192+p-r|0)>>>14;k=k+1|0;}while((k|0)<4);mrc(f|0,0,32)|0;f=j|0;k=j+2|0;r=j+4|0;p=j+6|0;j=c;c=0;while(1){q=b[h+(c<<1)>>1]|0;l=b[h+(c+8<<1)>>1]|0;o=((l+q|0)*11585|0)+8192>>14;n=((q-l|0)*11585|0)+8192>>14;l=b[h+(c+4<<1)>>1]|0;q=b[h+(c+12<<1)>>1]|0;m=(l*6270|0)+8192+(q*-15137|0)>>14;s=(l*15137|0)+8192+(q*6270|0)>>14;q=s+o&65535;b[f>>1]=q;b[k>>1]=m+n;b[r>>1]=n-m;b[p>>1]=o-s;s=((q<<16>>16)+8>>4)+(d[j]|0)|0;if(s>>>0>255>>>0){t=-s>>31&255}else{t=s&255}a[j]=t;s=j+e|0;q=((b[k>>1]|0)+8>>4)+(d[s]|0)|0;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[s]=u;s=j+(e<<1)|0;q=((b[r>>1]|0)+8>>4)+(d[s]|0)|0;if(q>>>0>255>>>0){v=-q>>31&255}else{v=q&255}a[s]=v;s=j+(e*3|0)|0;q=((b[p>>1]|0)+8>>4)+(d[s]|0)|0;if(q>>>0>255>>>0){w=-q>>31&255}else{w=q&255}a[s]=w;s=c+1|0;if((s|0)<4){j=j+1|0;c=s}else{break}}i=g;return}function Deb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+40|0;h=g|0;j=g+32|0;k=0;do{l=k<<2;m=b[f+(k<<1)>>1]|0;n=b[f+(k+8<<1)>>1]|0;o=((n+m|0)*11585|0)+8192>>14;p=((m-n|0)*11585|0)+8192>>14;n=b[f+(k+4<<1)>>1]|0;m=b[f+(k+12<<1)>>1]|0;q=(n*6270|0)+8192+(m*-15137|0)>>14;r=(n*15137|0)+8192+(m*6270|0)>>14;b[h+(l<<1)>>1]=r+o;b[h+((l|1)<<1)>>1]=q+p;b[h+((l|2)<<1)>>1]=p-q;b[h+((l|3)<<1)>>1]=o-r;k=k+1|0;}while((k|0)<4);mrc(f|0,0,32)|0;f=j|0;k=j+2|0;r=j+4|0;o=j+6|0;j=c;c=0;while(1){l=b[h+(c<<1)>>1]|0;q=b[h+(c+8<<1)>>1]|0;p=b[h+(c+12<<1)>>1]|0;m=(q*15212|0)+(l*5283|0)+(p*9929|0)|0;n=(q*-5283|0)+(l*9929|0)+(p*-15212|0)|0;s=(b[h+(c+4<<1)>>1]|0)*13377|0;t=s+8192|0;u=(t+m|0)>>>14&65535;b[f>>1]=u;b[k>>1]=(t+n|0)>>>14;b[r>>1]=(((l-q+p|0)*13377|0)+8192|0)>>>14;b[o>>1]=(n+8192+m-s|0)>>>14;s=((u<<16>>16)+8>>4)+(d[j]|0)|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[j]=v;s=j+e|0;u=((b[k>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}a[s]=w;s=j+(e<<1)|0;u=((b[r>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){x=-u>>31&255}else{x=u&255}a[s]=x;s=j+(e*3|0)|0;u=((b[o>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){y=-u>>31&255}else{y=u&255}a[s]=y;s=c+1|0;if((s|0)<4){j=j+1|0;c=s}else{break}}i=g;return}function Eeb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+40|0;h=g|0;j=g+32|0;k=0;do{l=k<<2;m=b[f+(k<<1)>>1]|0;n=b[f+(k+8<<1)>>1]|0;o=b[f+(k+12<<1)>>1]|0;p=(n*15212|0)+(m*5283|0)+(o*9929|0)|0;q=(n*-5283|0)+(m*9929|0)+(o*-15212|0)|0;r=(b[f+(k+4<<1)>>1]|0)*13377|0;s=r+8192|0;b[h+(l<<1)>>1]=(s+p|0)>>>14;b[h+((l|1)<<1)>>1]=(s+q|0)>>>14;b[h+((l|2)<<1)>>1]=(((m-n+o|0)*13377|0)+8192|0)>>>14;b[h+((l|3)<<1)>>1]=(q+8192+p-r|0)>>>14;k=k+1|0;}while((k|0)<4);mrc(f|0,0,32)|0;f=j|0;k=j+2|0;r=j+4|0;p=j+6|0;j=c;c=0;while(1){q=b[h+(c<<1)>>1]|0;l=b[h+(c+8<<1)>>1]|0;o=b[h+(c+12<<1)>>1]|0;n=(l*15212|0)+(q*5283|0)+(o*9929|0)|0;m=(l*-5283|0)+(q*9929|0)+(o*-15212|0)|0;s=(b[h+(c+4<<1)>>1]|0)*13377|0;t=s+8192|0;u=(t+n|0)>>>14&65535;b[f>>1]=u;b[k>>1]=(t+m|0)>>>14;b[r>>1]=(((q-l+o|0)*13377|0)+8192|0)>>>14;b[p>>1]=(m+8192+n-s|0)>>>14;s=((u<<16>>16)+8>>4)+(d[j]|0)|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[j]=v;s=j+e|0;u=((b[k>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){w=-u>>31&255}else{w=u&255}a[s]=w;s=j+(e<<1)|0;u=((b[r>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){x=-u>>31&255}else{x=u&255}a[s]=x;s=j+(e*3|0)|0;u=((b[p>>1]|0)+8>>4)+(d[s]|0)|0;if(u>>>0>255>>>0){y=-u>>31&255}else{y=u&255}a[s]=y;s=c+1|0;if((s|0)<4){j=j+1|0;c=s}else{break}}i=g;return}function Feb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+144|0;j=h|0;k=h+128|0;if((g|0)!=1){g=0;do{l=g<<3;m=b[f+(g<<1)>>1]|0;n=b[f+(g+32<<1)>>1]|0;o=((n+m|0)*11585|0)+8192>>14;p=((m-n|0)*11585|0)+8192>>14;n=b[f+(g+16<<1)>>1]|0;m=b[f+(g+48<<1)>>1]|0;q=(n*6270|0)+8192+(m*-15137|0)>>14;r=(n*15137|0)+8192+(m*6270|0)>>14;m=b[f+(g+8<<1)>>1]|0;n=b[f+(g+56<<1)>>1]|0;s=(m*3196|0)+8192+(n*-16069|0)>>14;t=b[f+(g+40<<1)>>1]|0;u=b[f+(g+24<<1)>>1]|0;v=(t*13623|0)+8192+(u*-9102|0)>>14;w=(t*9102|0)+8192+(u*13623|0)>>14;u=(m*16069|0)+8192+(n*3196|0)>>14;n=r+o|0;m=q+p|0;t=p-q|0;q=o-r|0;r=v+s|0;o=s-v|0;v=w+u|0;s=u-w|0;w=((s-o|0)*11585|0)+8192>>14;u=((s+o|0)*11585|0)+8192>>14;b[j+(l<<1)>>1]=v+n;b[j+((l|1)<<1)>>1]=u+m;b[j+((l|2)<<1)>>1]=w+t;b[j+((l|3)<<1)>>1]=r+q;b[j+((l|4)<<1)>>1]=q-r;b[j+((l|5)<<1)>>1]=t-w;b[j+((l|6)<<1)>>1]=m-u;b[j+((l|7)<<1)>>1]=n-v;g=g+1|0;}while((g|0)<8);mrc(f|0,0,128)|0;g=k|0;v=k+2|0;n=k+4|0;l=k+6|0;u=k+8|0;m=k+10|0;w=k+12|0;t=k+14|0;r=0;q=c;while(1){o=b[j+(r<<1)>>1]|0;s=b[j+(r+32<<1)>>1]|0;p=((s+o|0)*11585|0)+8192>>14;x=((o-s|0)*11585|0)+8192>>14;s=b[j+(r+16<<1)>>1]|0;o=b[j+(r+48<<1)>>1]|0;y=(s*6270|0)+8192+(o*-15137|0)>>14;z=(s*15137|0)+8192+(o*6270|0)>>14;o=b[j+(r+8<<1)>>1]|0;s=b[j+(r+56<<1)>>1]|0;A=(o*3196|0)+8192+(s*-16069|0)>>14;B=b[j+(r+40<<1)>>1]|0;C=b[j+(r+24<<1)>>1]|0;D=(B*13623|0)+8192+(C*-9102|0)>>14;E=(B*9102|0)+8192+(C*13623|0)>>14;C=(o*16069|0)+8192+(s*3196|0)>>14;s=z+p|0;o=y+x|0;B=x-y|0;y=p-z|0;z=D+A|0;p=A-D|0;D=E+C|0;A=C-E|0;E=((A-p|0)*11585|0)+8192>>14;C=((A+p|0)*11585|0)+8192>>14;p=D+s&65535;b[g>>1]=p;b[v>>1]=C+o;b[n>>1]=E+B;b[l>>1]=z+y;b[u>>1]=y-z;b[m>>1]=B-E;b[w>>1]=o-C;b[t>>1]=s-D;D=0;s=p;while(1){p=q+(ca(D,e)|0)|0;C=((s<<16>>16)+16>>5)+(d[p]|0)|0;if(C>>>0>255>>>0){F=-C>>31&255}else{F=C&255}a[p]=F;p=D+1|0;if((p|0)>=8){break}D=p;s=b[k+(p<<1)>>1]|0}s=r+1|0;if((s|0)<8){r=s;q=q+1|0}else{break}}i=h;return}q=((((b[f>>1]|0)*11585|0)+8192>>14)*11585|0)+8192>>14;b[f>>1]=0;f=q+16>>5;q=0;r=c;while(1){c=(d[r]|0)+f|0;if(c>>>0>255>>>0){G=-c>>31&255}else{G=c&255}a[r]=G;c=r+e|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){H=-k>>31&255}else{H=k&255}a[c]=H;c=r+(e<<1)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){I=-k>>31&255}else{I=k&255}a[c]=I;c=r+(e*3|0)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){J=-k>>31&255}else{J=k&255}a[c]=J;c=r+(e<<2)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){K=-k>>31&255}else{K=k&255}a[c]=K;c=r+(e*5|0)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){L=-k>>31&255}else{L=k&255}a[c]=L;c=r+(e*6|0)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){M=-k>>31&255}else{M=k&255}a[c]=M;c=r+(e*7|0)|0;k=(d[c]|0)+f|0;if(k>>>0>255>>>0){N=-k>>31&255}else{N=k&255}a[c]=N;c=q+1|0;if((c|0)<8){q=c;r=r+1|0}else{break}}i=h;return}function Geb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;i=i+144|0;h=g|0;j=g+128|0;k=0;do{l=k<<3;m=b[f+(k+56<<1)>>1]|0;n=b[f+(k<<1)>>1]|0;o=b[f+(k+40<<1)>>1]|0;p=b[f+(k+16<<1)>>1]|0;q=b[f+(k+24<<1)>>1]|0;r=b[f+(k+32<<1)>>1]|0;s=(r*12665|0)+(q*10394|0)|0;t=(r*-10394|0)+(q*12665|0)|0;q=b[f+(k+8<<1)>>1]|0;r=b[f+(k+48<<1)>>1]|0;u=(r*15679|0)+(q*4756|0)|0;v=(r*-4756|0)+(q*15679|0)|0;q=(m*16305|0)+8192+(n*1606|0)|0;r=s+q>>14;w=(m*1606|0)+8192+(n*-16305|0)|0;n=t+w>>14;m=(o*14449|0)+8192+(p*7723|0)|0;x=u+m>>14;y=(o*7723|0)+8192+(p*-14449|0)|0;p=v+y>>14;o=q-s>>14;s=w-t>>14;t=m-u>>14;u=y-v>>14;v=(u*15137|0)+(t*-6270|0)|0;y=(u*6270|0)+(t*15137|0)|0;b[h+(l<<1)>>1]=x+r;b[h+((l|7)<<1)>>1]=-(n+p|0);t=r-x|0;x=n-p|0;p=(s*6270|0)+8192+(o*15137|0)|0;b[h+((l|1)<<1)>>1]=-((v+p|0)>>>14);n=(s*-15137|0)+8192+(o*6270|0)|0;b[h+((l|6)<<1)>>1]=(y+n|0)>>>14;o=p-v>>14;v=n-y>>14;b[h+((l|3)<<1)>>1]=-((((t+x|0)*11585|0)+8192|0)>>>14);b[h+((l|4)<<1)>>1]=(((t-x|0)*11585|0)+8192|0)>>>14;b[h+((l|2)<<1)>>1]=(((o+v|0)*11585|0)+8192|0)>>>14;b[h+((l|5)<<1)>>1]=-((((o-v|0)*11585|0)+8192|0)>>>14);k=k+1|0;}while((k|0)<8);mrc(f|0,0,128)|0;f=j|0;k=j+2|0;v=j+4|0;o=j+6|0;l=j+8|0;x=j+10|0;t=j+12|0;y=j+14|0;n=c;c=0;while(1){p=b[h+(c<<1)>>1]|0;s=b[h+(c+32<<1)>>1]|0;r=((s+p|0)*11585|0)+8192>>14;u=((p-s|0)*11585|0)+8192>>14;s=b[h+(c+16<<1)>>1]|0;p=b[h+(c+48<<1)>>1]|0;m=(s*6270|0)+8192+(p*-15137|0)>>14;w=(s*15137|0)+8192+(p*6270|0)>>14;p=b[h+(c+8<<1)>>1]|0;s=b[h+(c+56<<1)>>1]|0;q=(p*3196|0)+8192+(s*-16069|0)>>14;z=b[h+(c+40<<1)>>1]|0;A=b[h+(c+24<<1)>>1]|0;B=(z*13623|0)+8192+(A*-9102|0)>>14;C=(z*9102|0)+8192+(A*13623|0)>>14;A=(p*16069|0)+8192+(s*3196|0)>>14;s=w+r|0;p=m+u|0;z=u-m|0;m=r-w|0;w=B+q|0;r=q-B|0;B=C+A|0;q=A-C|0;C=((q-r|0)*11585|0)+8192>>14;A=((q+r|0)*11585|0)+8192>>14;r=B+s&65535;b[f>>1]=r;b[k>>1]=A+p;b[v>>1]=C+z;b[o>>1]=w+m;b[l>>1]=m-w;b[x>>1]=z-C;b[t>>1]=p-A;b[y>>1]=s-B;B=0;s=r;while(1){r=n+(ca(B,e)|0)|0;A=((s<<16>>16)+16>>5)+(d[r]|0)|0;if(A>>>0>255>>>0){D=-A>>31&255}else{D=A&255}a[r]=D;r=B+1|0;if((r|0)>=8){break}B=r;s=b[j+(r<<1)>>1]|0}s=c+1|0;if((s|0)<8){n=n+1|0;c=s}else{break}}i=g;return}function Heb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+144|0;h=g|0;j=g+128|0;k=0;do{l=k<<3;m=b[f+(k<<1)>>1]|0;n=b[f+(k+32<<1)>>1]|0;o=((n+m|0)*11585|0)+8192>>14;p=((m-n|0)*11585|0)+8192>>14;n=b[f+(k+16<<1)>>1]|0;m=b[f+(k+48<<1)>>1]|0;q=(n*6270|0)+8192+(m*-15137|0)>>14;r=(n*15137|0)+8192+(m*6270|0)>>14;m=b[f+(k+8<<1)>>1]|0;n=b[f+(k+56<<1)>>1]|0;s=(m*3196|0)+8192+(n*-16069|0)>>14;t=b[f+(k+40<<1)>>1]|0;u=b[f+(k+24<<1)>>1]|0;v=(t*13623|0)+8192+(u*-9102|0)>>14;w=(t*9102|0)+8192+(u*13623|0)>>14;u=(m*16069|0)+8192+(n*3196|0)>>14;n=r+o|0;m=q+p|0;t=p-q|0;q=o-r|0;r=v+s|0;o=s-v|0;v=w+u|0;s=u-w|0;w=((s-o|0)*11585|0)+8192>>14;u=((s+o|0)*11585|0)+8192>>14;b[h+(l<<1)>>1]=v+n;b[h+((l|1)<<1)>>1]=u+m;b[h+((l|2)<<1)>>1]=w+t;b[h+((l|3)<<1)>>1]=r+q;b[h+((l|4)<<1)>>1]=q-r;b[h+((l|5)<<1)>>1]=t-w;b[h+((l|6)<<1)>>1]=m-u;b[h+((l|7)<<1)>>1]=n-v;k=k+1|0;}while((k|0)<8);mrc(f|0,0,128)|0;f=j|0;k=j+14|0;v=j+2|0;n=j+12|0;l=j+6|0;u=j+8|0;m=j+4|0;w=j+10|0;t=c;c=0;while(1){r=b[h+(c+56<<1)>>1]|0;q=b[h+(c<<1)>>1]|0;o=b[h+(c+40<<1)>>1]|0;s=b[h+(c+16<<1)>>1]|0;p=b[h+(c+24<<1)>>1]|0;x=b[h+(c+32<<1)>>1]|0;y=(x*12665|0)+(p*10394|0)|0;z=(x*-10394|0)+(p*12665|0)|0;p=b[h+(c+8<<1)>>1]|0;x=b[h+(c+48<<1)>>1]|0;A=(x*15679|0)+(p*4756|0)|0;B=(x*-4756|0)+(p*15679|0)|0;p=(r*16305|0)+8192+(q*1606|0)|0;x=y+p>>14;C=(r*1606|0)+8192+(q*-16305|0)|0;q=z+C>>14;r=(o*14449|0)+8192+(s*7723|0)|0;D=A+r>>14;E=(o*7723|0)+8192+(s*-14449|0)|0;s=B+E>>14;o=p-y>>14;y=C-z>>14;z=r-A>>14;A=E-B>>14;B=(A*15137|0)+(z*-6270|0)|0;E=(A*6270|0)+(z*15137|0)|0;z=D+x&65535;b[f>>1]=z;b[k>>1]=-(q+s|0);A=x-D|0;D=q-s|0;s=(y*6270|0)+8192+(o*15137|0)|0;b[v>>1]=-((B+s|0)>>>14);q=(y*-15137|0)+8192+(o*6270|0)|0;b[n>>1]=(E+q|0)>>>14;o=s-B>>14;B=q-E>>14;b[l>>1]=-((((A+D|0)*11585|0)+8192|0)>>>14);b[u>>1]=(((A-D|0)*11585|0)+8192|0)>>>14;b[m>>1]=(((o+B|0)*11585|0)+8192|0)>>>14;b[w>>1]=-((((o-B|0)*11585|0)+8192|0)>>>14);B=0;o=z;while(1){z=t+(ca(B,e)|0)|0;D=((o<<16>>16)+16>>5)+(d[z]|0)|0;if(D>>>0>255>>>0){F=-D>>31&255}else{F=D&255}a[z]=F;z=B+1|0;if((z|0)>=8){break}B=z;o=b[j+(z<<1)>>1]|0}o=c+1|0;if((o|0)<8){t=t+1|0;c=o}else{break}}i=g;return}function Ieb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+144|0;h=g|0;j=g+128|0;k=0;do{l=k<<3;m=b[f+(k+56<<1)>>1]|0;n=b[f+(k<<1)>>1]|0;o=b[f+(k+40<<1)>>1]|0;p=b[f+(k+16<<1)>>1]|0;q=b[f+(k+24<<1)>>1]|0;r=b[f+(k+32<<1)>>1]|0;s=(r*12665|0)+(q*10394|0)|0;t=(r*-10394|0)+(q*12665|0)|0;q=b[f+(k+8<<1)>>1]|0;r=b[f+(k+48<<1)>>1]|0;u=(r*15679|0)+(q*4756|0)|0;v=(r*-4756|0)+(q*15679|0)|0;q=(m*16305|0)+8192+(n*1606|0)|0;r=s+q>>14;w=(m*1606|0)+8192+(n*-16305|0)|0;n=t+w>>14;m=(o*14449|0)+8192+(p*7723|0)|0;x=u+m>>14;y=(o*7723|0)+8192+(p*-14449|0)|0;p=v+y>>14;o=q-s>>14;s=w-t>>14;t=m-u>>14;u=y-v>>14;v=(u*15137|0)+(t*-6270|0)|0;y=(u*6270|0)+(t*15137|0)|0;b[h+(l<<1)>>1]=x+r;b[h+((l|7)<<1)>>1]=-(n+p|0);t=r-x|0;x=n-p|0;p=(s*6270|0)+8192+(o*15137|0)|0;b[h+((l|1)<<1)>>1]=-((v+p|0)>>>14);n=(s*-15137|0)+8192+(o*6270|0)|0;b[h+((l|6)<<1)>>1]=(y+n|0)>>>14;o=p-v>>14;v=n-y>>14;b[h+((l|3)<<1)>>1]=-((((t+x|0)*11585|0)+8192|0)>>>14);b[h+((l|4)<<1)>>1]=(((t-x|0)*11585|0)+8192|0)>>>14;b[h+((l|2)<<1)>>1]=(((o+v|0)*11585|0)+8192|0)>>>14;b[h+((l|5)<<1)>>1]=-((((o-v|0)*11585|0)+8192|0)>>>14);k=k+1|0;}while((k|0)<8);mrc(f|0,0,128)|0;f=j|0;k=j+14|0;v=j+2|0;o=j+12|0;l=j+6|0;x=j+8|0;t=j+4|0;y=j+10|0;n=c;c=0;while(1){p=b[h+(c+56<<1)>>1]|0;s=b[h+(c<<1)>>1]|0;r=b[h+(c+40<<1)>>1]|0;u=b[h+(c+16<<1)>>1]|0;m=b[h+(c+24<<1)>>1]|0;w=b[h+(c+32<<1)>>1]|0;q=(w*12665|0)+(m*10394|0)|0;z=(w*-10394|0)+(m*12665|0)|0;m=b[h+(c+8<<1)>>1]|0;w=b[h+(c+48<<1)>>1]|0;A=(w*15679|0)+(m*4756|0)|0;B=(w*-4756|0)+(m*15679|0)|0;m=(p*16305|0)+8192+(s*1606|0)|0;w=q+m>>14;C=(p*1606|0)+8192+(s*-16305|0)|0;s=z+C>>14;p=(r*14449|0)+8192+(u*7723|0)|0;D=A+p>>14;E=(r*7723|0)+8192+(u*-14449|0)|0;u=B+E>>14;r=m-q>>14;q=C-z>>14;z=p-A>>14;A=E-B>>14;B=(A*15137|0)+(z*-6270|0)|0;E=(A*6270|0)+(z*15137|0)|0;z=D+w&65535;b[f>>1]=z;b[k>>1]=-(s+u|0);A=w-D|0;D=s-u|0;u=(q*6270|0)+8192+(r*15137|0)|0;b[v>>1]=-((B+u|0)>>>14);s=(q*-15137|0)+8192+(r*6270|0)|0;b[o>>1]=(E+s|0)>>>14;r=u-B>>14;B=s-E>>14;b[l>>1]=-((((A+D|0)*11585|0)+8192|0)>>>14);b[x>>1]=(((A-D|0)*11585|0)+8192|0)>>>14;b[t>>1]=(((r+B|0)*11585|0)+8192|0)>>>14;b[y>>1]=-((((r-B|0)*11585|0)+8192|0)>>>14);B=0;r=z;while(1){z=n+(ca(B,e)|0)|0;D=((r<<16>>16)+16>>5)+(d[z]|0)|0;if(D>>>0>255>>>0){F=-D>>31&255}else{F=D&255}a[z]=F;z=B+1|0;if((z|0)>=8){break}B=z;r=b[j+(z<<1)>>1]|0}r=c+1|0;if((r|0)<8){n=n+1|0;c=r}else{break}}i=g;return}function Jeb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;i=i+544|0;j=h|0;k=h+512|0;if((g|0)==1){g=((((b[f>>1]|0)*11585|0)+8192>>14)*11585|0)+8192>>14;b[f>>1]=0;l=g+32>>6;g=0;m=c;while(1){n=0;do{o=m+(ca(n,e)|0)|0;p=(d[o]|0)+l|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[o]=q;n=n+1|0;}while((n|0)<16);n=g+1|0;if((n|0)<16){g=n;m=m+1|0}else{break}}i=h;return}else{r=0}do{m=r<<4;g=b[f+(r<<1)>>1]|0;q=b[f+(r+128<<1)>>1]|0;l=((q+g|0)*11585|0)+8192>>14;n=((g-q|0)*11585|0)+8192>>14;q=b[f+(r+64<<1)>>1]|0;g=b[f+(r+192<<1)>>1]|0;o=(q*6270|0)+8192+(g*-15137|0)>>14;p=(q*15137|0)+8192+(g*6270|0)>>14;g=b[f+(r+32<<1)>>1]|0;q=b[f+(r+224<<1)>>1]|0;s=(g*3196|0)+8192+(q*-16069|0)>>14;t=(g*16069|0)+8192+(q*3196|0)>>14;q=b[f+(r+160<<1)>>1]|0;g=b[f+(r+96<<1)>>1]|0;u=(q*13623|0)+8192+(g*-9102|0)>>14;v=(q*9102|0)+8192+(g*13623|0)>>14;g=b[f+(r+16<<1)>>1]|0;q=b[f+(r+240<<1)>>1]|0;w=(g*1606|0)+8192+(q*-16305|0)>>14;x=(g*16305|0)+8192+(q*1606|0)>>14;q=b[f+(r+144<<1)>>1]|0;g=b[f+(r+112<<1)>>1]|0;y=(q*12665|0)+8192+(g*-10394|0)>>14;z=(q*10394|0)+8192+(g*12665|0)>>14;g=b[f+(r+80<<1)>>1]|0;q=b[f+(r+176<<1)>>1]|0;A=(g*7723|0)+8192+(q*-14449|0)>>14;B=(g*14449|0)+8192+(q*7723|0)>>14;q=b[f+(r+208<<1)>>1]|0;g=b[f+(r+48<<1)>>1]|0;C=(q*15679|0)+8192+(g*-4756|0)>>14;D=(q*4756|0)+8192+(g*15679|0)>>14;g=p+l|0;q=o+n|0;E=n-o|0;o=l-p|0;p=u+s|0;l=s-u|0;u=t-v|0;s=v+t|0;t=y+w|0;v=w-y|0;y=C-A|0;w=C+A|0;A=D+B|0;C=D-B|0;B=x-z|0;D=z+x|0;x=((u-l|0)*11585|0)+8192>>14;z=((u+l|0)*11585|0)+8192>>14;l=(v*-15137|0)+8192+(B*6270|0)>>14;u=(v*6270|0)+8192+(B*15137|0)>>14;B=(y*-6270|0)+8192+(C*-15137|0)>>14;v=(y*-15137|0)+8192+(C*6270|0)>>14;C=s+g|0;y=z+q|0;n=x+E|0;F=p+o|0;G=o-p|0;p=E-x|0;x=q-z|0;z=g-s|0;s=w+t|0;g=B+l|0;q=l-B|0;B=t-w|0;w=D-A|0;t=u-v|0;l=v+u|0;u=A+D|0;D=((t-q|0)*11585|0)+8192>>14;A=((t+q|0)*11585|0)+8192>>14;q=((w-B|0)*11585|0)+8192>>14;t=((w+B|0)*11585|0)+8192>>14;b[j+(m<<1)>>1]=u+C;b[j+((m|1)<<1)>>1]=l+y;b[j+((m|2)<<1)>>1]=A+n;b[j+((m|3)<<1)>>1]=t+F;b[j+((m|4)<<1)>>1]=q+G;b[j+((m|5)<<1)>>1]=D+p;b[j+((m|6)<<1)>>1]=g+x;b[j+((m|7)<<1)>>1]=s+z;b[j+((m|8)<<1)>>1]=z-s;b[j+((m|9)<<1)>>1]=x-g;b[j+((m|10)<<1)>>1]=p-D;b[j+((m|11)<<1)>>1]=G-q;b[j+((m|12)<<1)>>1]=F-t;b[j+((m|13)<<1)>>1]=n-A;b[j+((m|14)<<1)>>1]=y-l;b[j+((m|15)<<1)>>1]=C-u;r=r+1|0;}while((r|0)<16);mrc(f|0,0,512)|0;f=k|0;r=k+2|0;u=k+4|0;C=k+6|0;m=k+8|0;l=k+10|0;y=k+12|0;A=k+14|0;n=k+16|0;t=k+18|0;F=k+20|0;q=k+22|0;G=k+24|0;D=k+26|0;p=k+28|0;g=k+30|0;x=0;s=c;while(1){c=b[j+(x<<1)>>1]|0;z=b[j+(x+128<<1)>>1]|0;B=((z+c|0)*11585|0)+8192>>14;w=((c-z|0)*11585|0)+8192>>14;z=b[j+(x+64<<1)>>1]|0;c=b[j+(x+192<<1)>>1]|0;v=(z*6270|0)+8192+(c*-15137|0)>>14;E=(z*15137|0)+8192+(c*6270|0)>>14;c=b[j+(x+32<<1)>>1]|0;z=b[j+(x+224<<1)>>1]|0;o=(c*3196|0)+8192+(z*-16069|0)>>14;H=(c*16069|0)+8192+(z*3196|0)>>14;z=b[j+(x+160<<1)>>1]|0;c=b[j+(x+96<<1)>>1]|0;I=(z*13623|0)+8192+(c*-9102|0)>>14;J=(z*9102|0)+8192+(c*13623|0)>>14;c=b[j+(x+16<<1)>>1]|0;z=b[j+(x+240<<1)>>1]|0;K=(c*1606|0)+8192+(z*-16305|0)>>14;L=(c*16305|0)+8192+(z*1606|0)>>14;z=b[j+(x+144<<1)>>1]|0;c=b[j+(x+112<<1)>>1]|0;M=(z*12665|0)+8192+(c*-10394|0)>>14;N=(z*10394|0)+8192+(c*12665|0)>>14;c=b[j+(x+80<<1)>>1]|0;z=b[j+(x+176<<1)>>1]|0;O=(c*7723|0)+8192+(z*-14449|0)>>14;P=(c*14449|0)+8192+(z*7723|0)>>14;z=b[j+(x+208<<1)>>1]|0;c=b[j+(x+48<<1)>>1]|0;Q=(z*15679|0)+8192+(c*-4756|0)>>14;R=(z*4756|0)+8192+(c*15679|0)>>14;c=E+B|0;z=v+w|0;S=w-v|0;v=B-E|0;E=I+o|0;B=o-I|0;I=H-J|0;o=J+H|0;H=M+K|0;J=K-M|0;M=Q-O|0;K=Q+O|0;O=R+P|0;Q=R-P|0;P=L-N|0;R=N+L|0;L=((I-B|0)*11585|0)+8192>>14;N=((I+B|0)*11585|0)+8192>>14;B=(J*-15137|0)+8192+(P*6270|0)>>14;I=(J*6270|0)+8192+(P*15137|0)>>14;P=(M*-6270|0)+8192+(Q*-15137|0)>>14;J=(M*-15137|0)+8192+(Q*6270|0)>>14;Q=o+c|0;M=N+z|0;w=L+S|0;T=E+v|0;U=v-E|0;E=S-L|0;L=z-N|0;N=c-o|0;o=K+H|0;c=P+B|0;z=B-P|0;P=H-K|0;K=R-O|0;H=I-J|0;B=J+I|0;I=O+R|0;R=((H-z|0)*11585|0)+8192>>14;O=((H+z|0)*11585|0)+8192>>14;z=((K-P|0)*11585|0)+8192>>14;H=((K+P|0)*11585|0)+8192>>14;P=I+Q&65535;b[f>>1]=P;b[r>>1]=B+M;b[u>>1]=O+w;b[C>>1]=H+T;b[m>>1]=z+U;b[l>>1]=R+E;b[y>>1]=c+L;b[A>>1]=o+N;b[n>>1]=N-o;b[t>>1]=L-c;b[F>>1]=E-R;b[q>>1]=U-z;b[G>>1]=T-H;b[D>>1]=w-O;b[p>>1]=M-B;b[g>>1]=Q-I;I=0;Q=P;while(1){P=s+(ca(I,e)|0)|0;B=((Q<<16>>16)+32>>6)+(d[P]|0)|0;if(B>>>0>255>>>0){V=-B>>31&255}else{V=B&255}a[P]=V;P=I+1|0;if((P|0)>=16){break}I=P;Q=b[k+(P<<1)>>1]|0}Q=x+1|0;if((Q|0)<16){x=Q;s=s+1|0}else{break}}i=h;return}function Keb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;g=i;i=i+544|0;h=g|0;j=g+512|0;k=0;do{l=k<<4;m=b[f+(k+240<<1)>>1]|0;n=b[f+(k<<1)>>1]|0;o=b[f+(k+208<<1)>>1]|0;p=b[f+(k+32<<1)>>1]|0;q=b[f+(k+176<<1)>>1]|0;r=b[f+(k+64<<1)>>1]|0;s=b[f+(k+144<<1)>>1]|0;t=b[f+(k+96<<1)>>1]|0;u=b[f+(k+112<<1)>>1]|0;v=b[f+(k+128<<1)>>1]|0;w=(v*12140|0)+(u*11003|0)|0;x=(v*-11003|0)+(u*12140|0)|0;u=b[f+(k+80<<1)>>1]|0;v=b[f+(k+160<<1)>>1]|0;y=(v*14053|0)+(u*8423|0)|0;z=(v*-8423|0)+(u*14053|0)|0;u=b[f+(k+48<<1)>>1]|0;v=b[f+(k+192<<1)>>1]|0;A=(v*15426|0)+(u*5520|0)|0;B=(v*-5520|0)+(u*15426|0)|0;u=b[f+(k+16<<1)>>1]|0;v=b[f+(k+224<<1)>>1]|0;C=(v*16207|0)+(u*2404|0)|0;D=(v*-2404|0)+(u*16207|0)|0;u=(m*16364|0)+8192+(n*804|0)|0;v=w+u>>14;E=(m*804|0)+8192+(n*-16364|0)|0;n=x+E>>14;m=(o*15893|0)+8192+(p*3981|0)|0;F=y+m>>14;G=(o*3981|0)+8192+(p*-15893|0)|0;p=z+G>>14;o=(q*14811|0)+8192+(r*7005|0)|0;H=A+o>>14;I=(q*7005|0)+8192+(r*-14811|0)|0;r=B+I>>14;q=(s*13160|0)+8192+(t*9760|0)|0;J=C+q>>14;K=(s*9760|0)+8192+(t*-13160|0)|0;t=D+K>>14;s=u-w>>14;w=E-x>>14;x=m-y>>14;y=G-z>>14;z=o-A>>14;A=I-B>>14;B=q-C>>14;C=K-D>>14;D=(A*16069|0)+(z*-3196|0)|0;K=(A*3196|0)+(z*16069|0)|0;z=(C*9102|0)+(B*-13623|0)|0;A=(C*13623|0)+(B*9102|0)|0;B=H+v|0;C=r+n|0;q=J+F|0;I=t+p|0;o=v-H|0;H=n-r|0;r=F-J|0;J=p-t|0;t=(w*3196|0)+8192+(s*16069|0)|0;p=D+t>>14;F=(w*-16069|0)+8192+(s*3196|0)|0;s=K+F>>14;w=(y*13623|0)+8192+(x*9102|0)|0;n=z+w>>14;v=(y*-9102|0)+8192+(x*13623|0)|0;x=A+v>>14;y=t-D>>14;D=F-K>>14;K=w-z>>14;z=v-A>>14;A=(J*15137|0)+(r*-6270|0)|0;v=(J*6270|0)+(r*15137|0)|0;r=(z*15137|0)+(K*-6270|0)|0;J=(z*6270|0)+(K*15137|0)|0;b[h+(l<<1)>>1]=q+B;b[h+((l|15)<<1)>>1]=-(C+I|0);K=B-q|0;q=C-I|0;I=(H*6270|0)+8192+(o*15137|0)|0;b[h+((l|3)<<1)>>1]=-((A+I|0)>>>14);C=(H*-15137|0)+8192+(o*6270|0)|0;b[h+((l|12)<<1)>>1]=(v+C|0)>>>14;o=I-A>>14;A=C-v>>14;b[h+((l|1)<<1)>>1]=-(p+n|0);b[h+((l|14)<<1)>>1]=x+s;v=p-n|0;n=s-x|0;x=(D*6270|0)+8192+(y*15137|0)|0;b[h+((l|2)<<1)>>1]=(r+x|0)>>>14;s=(D*-15137|0)+8192+(y*6270|0)|0;b[h+((l|13)<<1)>>1]=-((J+s|0)>>>14);y=x-r>>14;r=s-J>>14;b[h+((l|7)<<1)>>1]=(((K+q|0)*-11585|0)+8192|0)>>>14;b[h+((l|8)<<1)>>1]=(((K-q|0)*11585|0)+8192|0)>>>14;b[h+((l|4)<<1)>>1]=(((A+o|0)*11585|0)+8192|0)>>>14;b[h+((l|11)<<1)>>1]=(((A-o|0)*11585|0)+8192|0)>>>14;b[h+((l|6)<<1)>>1]=(((n+v|0)*11585|0)+8192|0)>>>14;b[h+((l|9)<<1)>>1]=(((n-v|0)*11585|0)+8192|0)>>>14;b[h+((l|5)<<1)>>1]=(((y+r|0)*-11585|0)+8192|0)>>>14;b[h+((l|10)<<1)>>1]=(((y-r|0)*11585|0)+8192|0)>>>14;k=k+1|0;}while((k|0)<16);mrc(f|0,0,512)|0;f=j|0;k=j+2|0;r=j+4|0;y=j+6|0;l=j+8|0;v=j+10|0;n=j+12|0;o=j+14|0;A=j+16|0;q=j+18|0;K=j+20|0;J=j+22|0;s=j+24|0;x=j+26|0;D=j+28|0;p=j+30|0;C=c;c=0;while(1){I=b[h+(c<<1)>>1]|0;H=b[h+(c+128<<1)>>1]|0;B=((H+I|0)*11585|0)+8192>>14;z=((I-H|0)*11585|0)+8192>>14;H=b[h+(c+64<<1)>>1]|0;I=b[h+(c+192<<1)>>1]|0;w=(H*6270|0)+8192+(I*-15137|0)>>14;F=(H*15137|0)+8192+(I*6270|0)>>14;I=b[h+(c+32<<1)>>1]|0;H=b[h+(c+224<<1)>>1]|0;t=(I*3196|0)+8192+(H*-16069|0)>>14;G=(I*16069|0)+8192+(H*3196|0)>>14;H=b[h+(c+160<<1)>>1]|0;I=b[h+(c+96<<1)>>1]|0;m=(H*13623|0)+8192+(I*-9102|0)>>14;E=(H*9102|0)+8192+(I*13623|0)>>14;I=b[h+(c+16<<1)>>1]|0;H=b[h+(c+240<<1)>>1]|0;u=(I*1606|0)+8192+(H*-16305|0)>>14;L=(I*16305|0)+8192+(H*1606|0)>>14;H=b[h+(c+144<<1)>>1]|0;I=b[h+(c+112<<1)>>1]|0;M=(H*12665|0)+8192+(I*-10394|0)>>14;N=(H*10394|0)+8192+(I*12665|0)>>14;I=b[h+(c+80<<1)>>1]|0;H=b[h+(c+176<<1)>>1]|0;O=(I*7723|0)+8192+(H*-14449|0)>>14;P=(I*14449|0)+8192+(H*7723|0)>>14;H=b[h+(c+208<<1)>>1]|0;I=b[h+(c+48<<1)>>1]|0;Q=(H*15679|0)+8192+(I*-4756|0)>>14;R=(H*4756|0)+8192+(I*15679|0)>>14;I=F+B|0;H=w+z|0;S=z-w|0;w=B-F|0;F=m+t|0;B=t-m|0;m=G-E|0;t=E+G|0;G=M+u|0;E=u-M|0;M=Q-O|0;u=Q+O|0;O=R+P|0;Q=R-P|0;P=L-N|0;R=N+L|0;L=((m-B|0)*11585|0)+8192>>14;N=((m+B|0)*11585|0)+8192>>14;B=(E*-15137|0)+8192+(P*6270|0)>>14;m=(E*6270|0)+8192+(P*15137|0)>>14;P=(M*-6270|0)+8192+(Q*-15137|0)>>14;E=(M*-15137|0)+8192+(Q*6270|0)>>14;Q=t+I|0;M=N+H|0;z=L+S|0;T=F+w|0;U=w-F|0;F=S-L|0;L=H-N|0;N=I-t|0;t=u+G|0;I=P+B|0;H=B-P|0;P=G-u|0;u=R-O|0;G=m-E|0;B=E+m|0;m=O+R|0;R=((G-H|0)*11585|0)+8192>>14;O=((G+H|0)*11585|0)+8192>>14;H=((u-P|0)*11585|0)+8192>>14;G=((u+P|0)*11585|0)+8192>>14;P=m+Q&65535;b[f>>1]=P;b[k>>1]=B+M;b[r>>1]=O+z;b[y>>1]=G+T;b[l>>1]=H+U;b[v>>1]=R+F;b[n>>1]=I+L;b[o>>1]=t+N;b[A>>1]=N-t;b[q>>1]=L-I;b[K>>1]=F-R;b[J>>1]=U-H;b[s>>1]=T-G;b[x>>1]=z-O;b[D>>1]=M-B;b[p>>1]=Q-m;m=0;Q=P;while(1){P=C+(ca(m,e)|0)|0;B=((Q<<16>>16)+32>>6)+(d[P]|0)|0;if(B>>>0>255>>>0){V=-B>>31&255}else{V=B&255}a[P]=V;P=m+1|0;if((P|0)>=16){break}m=P;Q=b[j+(P<<1)>>1]|0}Q=c+1|0;if((Q|0)<16){C=C+1|0;c=Q}else{break}}i=g;return}function Leb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;g=i;i=i+544|0;h=g|0;j=g+512|0;k=0;do{l=k<<4;m=b[f+(k<<1)>>1]|0;n=b[f+(k+128<<1)>>1]|0;o=((n+m|0)*11585|0)+8192>>14;p=((m-n|0)*11585|0)+8192>>14;n=b[f+(k+64<<1)>>1]|0;m=b[f+(k+192<<1)>>1]|0;q=(n*6270|0)+8192+(m*-15137|0)>>14;r=(n*15137|0)+8192+(m*6270|0)>>14;m=b[f+(k+32<<1)>>1]|0;n=b[f+(k+224<<1)>>1]|0;s=(m*3196|0)+8192+(n*-16069|0)>>14;t=(m*16069|0)+8192+(n*3196|0)>>14;n=b[f+(k+160<<1)>>1]|0;m=b[f+(k+96<<1)>>1]|0;u=(n*13623|0)+8192+(m*-9102|0)>>14;v=(n*9102|0)+8192+(m*13623|0)>>14;m=b[f+(k+16<<1)>>1]|0;n=b[f+(k+240<<1)>>1]|0;w=(m*1606|0)+8192+(n*-16305|0)>>14;x=(m*16305|0)+8192+(n*1606|0)>>14;n=b[f+(k+144<<1)>>1]|0;m=b[f+(k+112<<1)>>1]|0;y=(n*12665|0)+8192+(m*-10394|0)>>14;z=(n*10394|0)+8192+(m*12665|0)>>14;m=b[f+(k+80<<1)>>1]|0;n=b[f+(k+176<<1)>>1]|0;A=(m*7723|0)+8192+(n*-14449|0)>>14;B=(m*14449|0)+8192+(n*7723|0)>>14;n=b[f+(k+208<<1)>>1]|0;m=b[f+(k+48<<1)>>1]|0;C=(n*15679|0)+8192+(m*-4756|0)>>14;D=(n*4756|0)+8192+(m*15679|0)>>14;m=r+o|0;n=q+p|0;E=p-q|0;q=o-r|0;r=u+s|0;o=s-u|0;u=t-v|0;s=v+t|0;t=y+w|0;v=w-y|0;y=C-A|0;w=C+A|0;A=D+B|0;C=D-B|0;B=x-z|0;D=z+x|0;x=((u-o|0)*11585|0)+8192>>14;z=((u+o|0)*11585|0)+8192>>14;o=(v*-15137|0)+8192+(B*6270|0)>>14;u=(v*6270|0)+8192+(B*15137|0)>>14;B=(y*-6270|0)+8192+(C*-15137|0)>>14;v=(y*-15137|0)+8192+(C*6270|0)>>14;C=s+m|0;y=z+n|0;p=x+E|0;F=r+q|0;G=q-r|0;r=E-x|0;x=n-z|0;z=m-s|0;s=w+t|0;m=B+o|0;n=o-B|0;B=t-w|0;w=D-A|0;t=u-v|0;o=v+u|0;u=A+D|0;D=((t-n|0)*11585|0)+8192>>14;A=((t+n|0)*11585|0)+8192>>14;n=((w-B|0)*11585|0)+8192>>14;t=((w+B|0)*11585|0)+8192>>14;b[h+(l<<1)>>1]=u+C;b[h+((l|1)<<1)>>1]=o+y;b[h+((l|2)<<1)>>1]=A+p;b[h+((l|3)<<1)>>1]=t+F;b[h+((l|4)<<1)>>1]=n+G;b[h+((l|5)<<1)>>1]=D+r;b[h+((l|6)<<1)>>1]=m+x;b[h+((l|7)<<1)>>1]=s+z;b[h+((l|8)<<1)>>1]=z-s;b[h+((l|9)<<1)>>1]=x-m;b[h+((l|10)<<1)>>1]=r-D;b[h+((l|11)<<1)>>1]=G-n;b[h+((l|12)<<1)>>1]=F-t;b[h+((l|13)<<1)>>1]=p-A;b[h+((l|14)<<1)>>1]=y-o;b[h+((l|15)<<1)>>1]=C-u;k=k+1|0;}while((k|0)<16);mrc(f|0,0,512)|0;f=j|0;k=j+30|0;u=j+6|0;C=j+24|0;l=j+2|0;o=j+28|0;y=j+4|0;A=j+26|0;p=j+14|0;t=j+16|0;F=j+8|0;n=j+22|0;G=j+12|0;D=j+18|0;r=j+10|0;m=j+20|0;x=c;c=0;while(1){s=b[h+(c+240<<1)>>1]|0;z=b[h+(c<<1)>>1]|0;B=b[h+(c+208<<1)>>1]|0;w=b[h+(c+32<<1)>>1]|0;v=b[h+(c+176<<1)>>1]|0;E=b[h+(c+64<<1)>>1]|0;q=b[h+(c+144<<1)>>1]|0;H=b[h+(c+96<<1)>>1]|0;I=b[h+(c+112<<1)>>1]|0;J=b[h+(c+128<<1)>>1]|0;K=(J*12140|0)+(I*11003|0)|0;L=(J*-11003|0)+(I*12140|0)|0;I=b[h+(c+80<<1)>>1]|0;J=b[h+(c+160<<1)>>1]|0;M=(J*14053|0)+(I*8423|0)|0;N=(J*-8423|0)+(I*14053|0)|0;I=b[h+(c+48<<1)>>1]|0;J=b[h+(c+192<<1)>>1]|0;O=(J*15426|0)+(I*5520|0)|0;P=(J*-5520|0)+(I*15426|0)|0;I=b[h+(c+16<<1)>>1]|0;J=b[h+(c+224<<1)>>1]|0;Q=(J*16207|0)+(I*2404|0)|0;R=(J*-2404|0)+(I*16207|0)|0;I=(s*16364|0)+8192+(z*804|0)|0;J=K+I>>14;S=(s*804|0)+8192+(z*-16364|0)|0;z=L+S>>14;s=(B*15893|0)+8192+(w*3981|0)|0;T=M+s>>14;U=(B*3981|0)+8192+(w*-15893|0)|0;w=N+U>>14;B=(v*14811|0)+8192+(E*7005|0)|0;V=O+B>>14;W=(v*7005|0)+8192+(E*-14811|0)|0;E=P+W>>14;v=(q*13160|0)+8192+(H*9760|0)|0;X=Q+v>>14;Y=(q*9760|0)+8192+(H*-13160|0)|0;H=R+Y>>14;q=I-K>>14;K=S-L>>14;L=s-M>>14;M=U-N>>14;N=B-O>>14;O=W-P>>14;P=v-Q>>14;Q=Y-R>>14;R=(O*16069|0)+(N*-3196|0)|0;Y=(O*3196|0)+(N*16069|0)|0;N=(Q*9102|0)+(P*-13623|0)|0;O=(Q*13623|0)+(P*9102|0)|0;P=V+J|0;Q=E+z|0;v=X+T|0;W=H+w|0;B=J-V|0;V=z-E|0;E=T-X|0;X=w-H|0;H=(K*3196|0)+8192+(q*16069|0)|0;w=R+H>>14;T=(K*-16069|0)+8192+(q*3196|0)|0;q=Y+T>>14;K=(M*13623|0)+8192+(L*9102|0)|0;z=N+K>>14;J=(M*-9102|0)+8192+(L*13623|0)|0;L=O+J>>14;M=H-R>>14;R=T-Y>>14;Y=K-N>>14;N=J-O>>14;O=(X*15137|0)+(E*-6270|0)|0;J=(X*6270|0)+(E*15137|0)|0;E=(N*15137|0)+(Y*-6270|0)|0;X=(N*6270|0)+(Y*15137|0)|0;Y=v+P&65535;b[f>>1]=Y;b[k>>1]=-(Q+W|0);N=P-v|0;v=Q-W|0;W=(V*6270|0)+8192+(B*15137|0)|0;b[u>>1]=-((O+W|0)>>>14);Q=(V*-15137|0)+8192+(B*6270|0)|0;b[C>>1]=(J+Q|0)>>>14;B=W-O>>14;O=Q-J>>14;b[l>>1]=-(w+z|0);b[o>>1]=L+q;J=w-z|0;z=q-L|0;L=(R*6270|0)+8192+(M*15137|0)|0;b[y>>1]=(E+L|0)>>>14;q=(R*-15137|0)+8192+(M*6270|0)|0;b[A>>1]=-((X+q|0)>>>14);M=L-E>>14;E=q-X>>14;b[p>>1]=(((N+v|0)*-11585|0)+8192|0)>>>14;b[t>>1]=(((N-v|0)*11585|0)+8192|0)>>>14;b[F>>1]=(((O+B|0)*11585|0)+8192|0)>>>14;b[n>>1]=(((O-B|0)*11585|0)+8192|0)>>>14;b[G>>1]=(((z+J|0)*11585|0)+8192|0)>>>14;b[D>>1]=(((z-J|0)*11585|0)+8192|0)>>>14;b[r>>1]=(((M+E|0)*-11585|0)+8192|0)>>>14;b[m>>1]=(((M-E|0)*11585|0)+8192|0)>>>14;E=0;M=Y;while(1){Y=x+(ca(E,e)|0)|0;J=((M<<16>>16)+32>>6)+(d[Y]|0)|0;if(J>>>0>255>>>0){Z=-J>>31&255}else{Z=J&255}a[Y]=Z;Y=E+1|0;if((Y|0)>=16){break}E=Y;M=b[j+(Y<<1)>>1]|0}M=c+1|0;if((M|0)<16){x=x+1|0;c=M}else{break}}i=g;return}function Meb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;g=i;i=i+544|0;h=g|0;j=g+512|0;k=0;do{l=k<<4;m=b[f+(k+240<<1)>>1]|0;n=b[f+(k<<1)>>1]|0;o=b[f+(k+208<<1)>>1]|0;p=b[f+(k+32<<1)>>1]|0;q=b[f+(k+176<<1)>>1]|0;r=b[f+(k+64<<1)>>1]|0;s=b[f+(k+144<<1)>>1]|0;t=b[f+(k+96<<1)>>1]|0;u=b[f+(k+112<<1)>>1]|0;v=b[f+(k+128<<1)>>1]|0;w=(v*12140|0)+(u*11003|0)|0;x=(v*-11003|0)+(u*12140|0)|0;u=b[f+(k+80<<1)>>1]|0;v=b[f+(k+160<<1)>>1]|0;y=(v*14053|0)+(u*8423|0)|0;z=(v*-8423|0)+(u*14053|0)|0;u=b[f+(k+48<<1)>>1]|0;v=b[f+(k+192<<1)>>1]|0;A=(v*15426|0)+(u*5520|0)|0;B=(v*-5520|0)+(u*15426|0)|0;u=b[f+(k+16<<1)>>1]|0;v=b[f+(k+224<<1)>>1]|0;C=(v*16207|0)+(u*2404|0)|0;D=(v*-2404|0)+(u*16207|0)|0;u=(m*16364|0)+8192+(n*804|0)|0;v=w+u>>14;E=(m*804|0)+8192+(n*-16364|0)|0;n=x+E>>14;m=(o*15893|0)+8192+(p*3981|0)|0;F=y+m>>14;G=(o*3981|0)+8192+(p*-15893|0)|0;p=z+G>>14;o=(q*14811|0)+8192+(r*7005|0)|0;H=A+o>>14;I=(q*7005|0)+8192+(r*-14811|0)|0;r=B+I>>14;q=(s*13160|0)+8192+(t*9760|0)|0;J=C+q>>14;K=(s*9760|0)+8192+(t*-13160|0)|0;t=D+K>>14;s=u-w>>14;w=E-x>>14;x=m-y>>14;y=G-z>>14;z=o-A>>14;A=I-B>>14;B=q-C>>14;C=K-D>>14;D=(A*16069|0)+(z*-3196|0)|0;K=(A*3196|0)+(z*16069|0)|0;z=(C*9102|0)+(B*-13623|0)|0;A=(C*13623|0)+(B*9102|0)|0;B=H+v|0;C=r+n|0;q=J+F|0;I=t+p|0;o=v-H|0;H=n-r|0;r=F-J|0;J=p-t|0;t=(w*3196|0)+8192+(s*16069|0)|0;p=D+t>>14;F=(w*-16069|0)+8192+(s*3196|0)|0;s=K+F>>14;w=(y*13623|0)+8192+(x*9102|0)|0;n=z+w>>14;v=(y*-9102|0)+8192+(x*13623|0)|0;x=A+v>>14;y=t-D>>14;D=F-K>>14;K=w-z>>14;z=v-A>>14;A=(J*15137|0)+(r*-6270|0)|0;v=(J*6270|0)+(r*15137|0)|0;r=(z*15137|0)+(K*-6270|0)|0;J=(z*6270|0)+(K*15137|0)|0;b[h+(l<<1)>>1]=q+B;b[h+((l|15)<<1)>>1]=-(C+I|0);K=B-q|0;q=C-I|0;I=(H*6270|0)+8192+(o*15137|0)|0;b[h+((l|3)<<1)>>1]=-((A+I|0)>>>14);C=(H*-15137|0)+8192+(o*6270|0)|0;b[h+((l|12)<<1)>>1]=(v+C|0)>>>14;o=I-A>>14;A=C-v>>14;b[h+((l|1)<<1)>>1]=-(p+n|0);b[h+((l|14)<<1)>>1]=x+s;v=p-n|0;n=s-x|0;x=(D*6270|0)+8192+(y*15137|0)|0;b[h+((l|2)<<1)>>1]=(r+x|0)>>>14;s=(D*-15137|0)+8192+(y*6270|0)|0;b[h+((l|13)<<1)>>1]=-((J+s|0)>>>14);y=x-r>>14;r=s-J>>14;b[h+((l|7)<<1)>>1]=(((K+q|0)*-11585|0)+8192|0)>>>14;b[h+((l|8)<<1)>>1]=(((K-q|0)*11585|0)+8192|0)>>>14;b[h+((l|4)<<1)>>1]=(((A+o|0)*11585|0)+8192|0)>>>14;b[h+((l|11)<<1)>>1]=(((A-o|0)*11585|0)+8192|0)>>>14;b[h+((l|6)<<1)>>1]=(((n+v|0)*11585|0)+8192|0)>>>14;b[h+((l|9)<<1)>>1]=(((n-v|0)*11585|0)+8192|0)>>>14;b[h+((l|5)<<1)>>1]=(((y+r|0)*-11585|0)+8192|0)>>>14;b[h+((l|10)<<1)>>1]=(((y-r|0)*11585|0)+8192|0)>>>14;k=k+1|0;}while((k|0)<16);mrc(f|0,0,512)|0;f=j|0;k=j+30|0;r=j+6|0;y=j+24|0;l=j+2|0;v=j+28|0;n=j+4|0;o=j+26|0;A=j+14|0;q=j+16|0;K=j+8|0;J=j+22|0;s=j+12|0;x=j+18|0;D=j+10|0;p=j+20|0;C=c;c=0;while(1){I=b[h+(c+240<<1)>>1]|0;H=b[h+(c<<1)>>1]|0;B=b[h+(c+208<<1)>>1]|0;z=b[h+(c+32<<1)>>1]|0;w=b[h+(c+176<<1)>>1]|0;F=b[h+(c+64<<1)>>1]|0;t=b[h+(c+144<<1)>>1]|0;G=b[h+(c+96<<1)>>1]|0;m=b[h+(c+112<<1)>>1]|0;E=b[h+(c+128<<1)>>1]|0;u=(E*12140|0)+(m*11003|0)|0;L=(E*-11003|0)+(m*12140|0)|0;m=b[h+(c+80<<1)>>1]|0;E=b[h+(c+160<<1)>>1]|0;M=(E*14053|0)+(m*8423|0)|0;N=(E*-8423|0)+(m*14053|0)|0;m=b[h+(c+48<<1)>>1]|0;E=b[h+(c+192<<1)>>1]|0;O=(E*15426|0)+(m*5520|0)|0;P=(E*-5520|0)+(m*15426|0)|0;m=b[h+(c+16<<1)>>1]|0;E=b[h+(c+224<<1)>>1]|0;Q=(E*16207|0)+(m*2404|0)|0;R=(E*-2404|0)+(m*16207|0)|0;m=(I*16364|0)+8192+(H*804|0)|0;E=u+m>>14;S=(I*804|0)+8192+(H*-16364|0)|0;H=L+S>>14;I=(B*15893|0)+8192+(z*3981|0)|0;T=M+I>>14;U=(B*3981|0)+8192+(z*-15893|0)|0;z=N+U>>14;B=(w*14811|0)+8192+(F*7005|0)|0;V=O+B>>14;W=(w*7005|0)+8192+(F*-14811|0)|0;F=P+W>>14;w=(t*13160|0)+8192+(G*9760|0)|0;X=Q+w>>14;Y=(t*9760|0)+8192+(G*-13160|0)|0;G=R+Y>>14;t=m-u>>14;u=S-L>>14;L=I-M>>14;M=U-N>>14;N=B-O>>14;O=W-P>>14;P=w-Q>>14;Q=Y-R>>14;R=(O*16069|0)+(N*-3196|0)|0;Y=(O*3196|0)+(N*16069|0)|0;N=(Q*9102|0)+(P*-13623|0)|0;O=(Q*13623|0)+(P*9102|0)|0;P=V+E|0;Q=F+H|0;w=X+T|0;W=G+z|0;B=E-V|0;V=H-F|0;F=T-X|0;X=z-G|0;G=(u*3196|0)+8192+(t*16069|0)|0;z=R+G>>14;T=(u*-16069|0)+8192+(t*3196|0)|0;t=Y+T>>14;u=(M*13623|0)+8192+(L*9102|0)|0;H=N+u>>14;E=(M*-9102|0)+8192+(L*13623|0)|0;L=O+E>>14;M=G-R>>14;R=T-Y>>14;Y=u-N>>14;N=E-O>>14;O=(X*15137|0)+(F*-6270|0)|0;E=(X*6270|0)+(F*15137|0)|0;F=(N*15137|0)+(Y*-6270|0)|0;X=(N*6270|0)+(Y*15137|0)|0;Y=w+P&65535;b[f>>1]=Y;b[k>>1]=-(Q+W|0);N=P-w|0;w=Q-W|0;W=(V*6270|0)+8192+(B*15137|0)|0;b[r>>1]=-((O+W|0)>>>14);Q=(V*-15137|0)+8192+(B*6270|0)|0;b[y>>1]=(E+Q|0)>>>14;B=W-O>>14;O=Q-E>>14;b[l>>1]=-(z+H|0);b[v>>1]=L+t;E=z-H|0;H=t-L|0;L=(R*6270|0)+8192+(M*15137|0)|0;b[n>>1]=(F+L|0)>>>14;t=(R*-15137|0)+8192+(M*6270|0)|0;b[o>>1]=-((X+t|0)>>>14);M=L-F>>14;F=t-X>>14;b[A>>1]=(((N+w|0)*-11585|0)+8192|0)>>>14;b[q>>1]=(((N-w|0)*11585|0)+8192|0)>>>14;b[K>>1]=(((O+B|0)*11585|0)+8192|0)>>>14;b[J>>1]=(((O-B|0)*11585|0)+8192|0)>>>14;b[s>>1]=(((H+E|0)*11585|0)+8192|0)>>>14;b[x>>1]=(((H-E|0)*11585|0)+8192|0)>>>14;b[D>>1]=(((M+F|0)*-11585|0)+8192|0)>>>14;b[p>>1]=(((M-F|0)*11585|0)+8192|0)>>>14;F=0;M=Y;while(1){Y=C+(ca(F,e)|0)|0;E=((M<<16>>16)+32>>6)+(d[Y]|0)|0;if(E>>>0>255>>>0){Z=-E>>31&255}else{Z=E&255}a[Y]=Z;Y=F+1|0;if((Y|0)>=16){break}F=Y;M=b[j+(Y<<1)>>1]|0}M=c+1|0;if((M|0)<16){C=C+1|0;c=M}else{break}}i=g;return}function Neb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;h=i;i=i+2112|0;j=h|0;k=h+2048|0;if((g|0)==1){g=((((b[f>>1]|0)*11585|0)+8192>>14)*11585|0)+8192>>14;b[f>>1]=0;l=g+32>>6;g=0;m=c;while(1){n=0;do{o=m+(ca(n,e)|0)|0;p=(d[o]|0)+l|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[o]=q;n=n+1|0;}while((n|0)<32);n=g+1|0;if((n|0)<32){g=n;m=m+1|0}else{break}}i=h;return}else{r=0}do{m=r<<5;g=b[f+(r<<1)>>1]|0;q=b[f+(r+512<<1)>>1]|0;l=((q+g|0)*11585|0)+8192>>14;n=((g-q|0)*11585|0)+8192>>14;q=b[f+(r+256<<1)>>1]|0;g=b[f+(r+768<<1)>>1]|0;o=(q*6270|0)+8192+(g*-15137|0)>>14;p=(q*15137|0)+8192+(g*6270|0)>>14;g=b[f+(r+128<<1)>>1]|0;q=b[f+(r+896<<1)>>1]|0;s=(g*3196|0)+8192+(q*-16069|0)>>14;t=(g*16069|0)+8192+(q*3196|0)>>14;q=b[f+(r+640<<1)>>1]|0;g=b[f+(r+384<<1)>>1]|0;u=(q*13623|0)+8192+(g*-9102|0)>>14;v=(q*9102|0)+8192+(g*13623|0)>>14;g=b[f+(r+64<<1)>>1]|0;q=b[f+(r+960<<1)>>1]|0;w=(g*1606|0)+8192+(q*-16305|0)>>14;x=(g*16305|0)+8192+(q*1606|0)>>14;q=b[f+(r+576<<1)>>1]|0;g=b[f+(r+448<<1)>>1]|0;y=(q*12665|0)+8192+(g*-10394|0)>>14;z=(q*10394|0)+8192+(g*12665|0)>>14;g=b[f+(r+320<<1)>>1]|0;q=b[f+(r+704<<1)>>1]|0;A=(g*7723|0)+8192+(q*-14449|0)>>14;B=(g*14449|0)+8192+(q*7723|0)>>14;q=b[f+(r+832<<1)>>1]|0;g=b[f+(r+192<<1)>>1]|0;C=(q*15679|0)+8192+(g*-4756|0)>>14;D=(q*4756|0)+8192+(g*15679|0)>>14;g=b[f+(r+32<<1)>>1]|0;q=b[f+(r+992<<1)>>1]|0;E=(g*804|0)+8192+(q*-16364|0)>>14;F=(g*16364|0)+8192+(q*804|0)>>14;q=b[f+(r+544<<1)>>1]|0;g=b[f+(r+480<<1)>>1]|0;G=(q*12140|0)+8192+(g*-11003|0)>>14;H=(q*11003|0)+8192+(g*12140|0)>>14;g=b[f+(r+288<<1)>>1]|0;q=b[f+(r+736<<1)>>1]|0;I=(g*7005|0)+8192+(q*-14811|0)>>14;J=(g*14811|0)+8192+(q*7005|0)>>14;q=b[f+(r+800<<1)>>1]|0;g=b[f+(r+224<<1)>>1]|0;K=(q*15426|0)+8192+(g*-5520|0)>>14;L=(q*5520|0)+8192+(g*15426|0)>>14;g=b[f+(r+160<<1)>>1]|0;q=b[f+(r+864<<1)>>1]|0;M=(g*3981|0)+8192+(q*-15893|0)>>14;N=(g*15893|0)+8192+(q*3981|0)>>14;q=b[f+(r+672<<1)>>1]|0;g=b[f+(r+352<<1)>>1]|0;O=(q*14053|0)+8192+(g*-8423|0)>>14;P=(q*8423|0)+8192+(g*14053|0)>>14;g=b[f+(r+416<<1)>>1]|0;q=b[f+(r+608<<1)>>1]|0;Q=(g*9760|0)+8192+(q*-13160|0)>>14;R=(g*13160|0)+8192+(q*9760|0)>>14;q=b[f+(r+928<<1)>>1]|0;g=b[f+(r+96<<1)>>1]|0;S=(q*16207|0)+8192+(g*-2404|0)>>14;T=(q*2404|0)+8192+(g*16207|0)>>14;g=p+l|0;q=o+n|0;U=n-o|0;o=l-p|0;p=u+s|0;l=s-u|0;u=t-v|0;s=v+t|0;t=y+w|0;v=w-y|0;y=C-A|0;w=C+A|0;A=D+B|0;C=D-B|0;B=x-z|0;D=z+x|0;x=G+E|0;z=E-G|0;G=K-I|0;E=K+I|0;I=O+M|0;K=M-O|0;O=S-Q|0;M=S+Q|0;Q=T+R|0;S=T-R|0;R=N-P|0;T=P+N|0;N=L+J|0;P=L-J|0;J=F-H|0;L=H+F|0;F=((u-l|0)*11585|0)+8192>>14;H=((u+l|0)*11585|0)+8192>>14;l=(v*-15137|0)+8192+(B*6270|0)>>14;u=(v*6270|0)+8192+(B*15137|0)>>14;B=(y*-6270|0)+8192+(C*-15137|0)>>14;v=(y*-15137|0)+8192+(C*6270|0)>>14;C=(z*-16069|0)+8192+(J*3196|0)>>14;y=(z*3196|0)+8192+(J*16069|0)>>14;J=(G*-3196|0)+8192+(P*-16069|0)>>14;z=(G*-16069|0)+8192+(P*3196|0)>>14;P=(K*-9102|0)+8192+(R*13623|0)>>14;G=(K*13623|0)+8192+(R*9102|0)>>14;R=(O*-13623|0)+8192+(S*-9102|0)>>14;K=(O*-9102|0)+8192+(S*13623|0)>>14;S=s+g|0;O=H+q|0;n=F+U|0;V=p+o|0;W=o-p|0;p=U-F|0;F=q-H|0;H=g-s|0;s=w+t|0;g=B+l|0;q=l-B|0;B=t-w|0;w=D-A|0;t=u-v|0;l=v+u|0;u=A+D|0;D=E+x|0;A=J+C|0;v=C-J|0;J=x-E|0;E=M-I|0;x=R-P|0;C=R+P|0;P=M+I|0;I=Q+T|0;M=K+G|0;R=K-G|0;G=Q-T|0;T=L-N|0;Q=y-z|0;K=z+y|0;y=N+L|0;L=((t-q|0)*11585|0)+8192>>14;N=((t+q|0)*11585|0)+8192>>14;q=((w-B|0)*11585|0)+8192>>14;t=((w+B|0)*11585|0)+8192>>14;B=(v*-15137|0)+8192+(Q*6270|0)>>14;w=(v*6270|0)+8192+(Q*15137|0)>>14;Q=(J*-15137|0)+8192+(T*6270|0)>>14;v=(J*6270|0)+8192+(T*15137|0)>>14;T=(E*-6270|0)+8192+(G*-15137|0)>>14;J=(E*-15137|0)+8192+(G*6270|0)>>14;G=(x*-6270|0)+8192+(R*-15137|0)>>14;E=(x*-15137|0)+8192+(R*6270|0)>>14;R=u+S|0;x=l+O|0;z=N+n|0;U=t+V|0;o=q+W|0;X=L+p|0;Y=g+F|0;Z=s+H|0;_=H-s|0;s=F-g|0;g=p-L|0;L=W-q|0;q=V-t|0;t=n-N|0;N=O-l|0;l=S-u|0;u=P+D|0;S=C+A|0;O=G+B|0;n=T+Q|0;V=Q-T|0;T=B-G|0;G=A-C|0;C=D-P|0;P=y-I|0;D=K-M|0;A=w-E|0;B=v-J|0;Q=J+v|0;v=E+w|0;w=M+K|0;K=I+y|0;y=((B-V|0)*11585|0)+8192>>14;I=((B+V|0)*11585|0)+8192>>14;V=((A-T|0)*11585|0)+8192>>14;B=((A+T|0)*11585|0)+8192>>14;T=((D-G|0)*11585|0)+8192>>14;A=((D+G|0)*11585|0)+8192>>14;G=((P-C|0)*11585|0)+8192>>14;D=((P+C|0)*11585|0)+8192>>14;b[j+(m<<1)>>1]=K+R;b[j+((m|1)<<1)>>1]=w+x;b[j+((m|2)<<1)>>1]=v+z;b[j+((m|3)<<1)>>1]=Q+U;b[j+((m|4)<<1)>>1]=I+o;b[j+((m|5)<<1)>>1]=B+X;b[j+((m|6)<<1)>>1]=A+Y;b[j+((m|7)<<1)>>1]=D+Z;b[j+((m|8)<<1)>>1]=G+_;b[j+((m|9)<<1)>>1]=T+s;b[j+((m|10)<<1)>>1]=V+g;b[j+((m|11)<<1)>>1]=y+L;b[j+((m|12)<<1)>>1]=n+q;b[j+((m|13)<<1)>>1]=O+t;b[j+((m|14)<<1)>>1]=S+N;b[j+((m|15)<<1)>>1]=u+l;b[j+((m|16)<<1)>>1]=l-u;b[j+((m|17)<<1)>>1]=N-S;b[j+((m|18)<<1)>>1]=t-O;b[j+((m|19)<<1)>>1]=q-n;b[j+((m|20)<<1)>>1]=L-y;b[j+((m|21)<<1)>>1]=g-V;b[j+((m|22)<<1)>>1]=s-T;b[j+((m|23)<<1)>>1]=_-G;b[j+((m|24)<<1)>>1]=Z-D;b[j+((m|25)<<1)>>1]=Y-A;b[j+((m|26)<<1)>>1]=X-B;b[j+((m|27)<<1)>>1]=o-I;b[j+((m|28)<<1)>>1]=U-Q;b[j+((m|29)<<1)>>1]=z-v;b[j+((m|30)<<1)>>1]=x-w;b[j+((m|31)<<1)>>1]=R-K;r=r+1|0;}while((r|0)<32);mrc(f|0,0,2048)|0;f=k|0;r=k+2|0;K=k+4|0;R=k+6|0;m=k+8|0;w=k+10|0;x=k+12|0;v=k+14|0;z=k+16|0;Q=k+18|0;U=k+20|0;I=k+22|0;o=k+24|0;B=k+26|0;X=k+28|0;A=k+30|0;Y=k+32|0;D=k+34|0;Z=k+36|0;G=k+38|0;_=k+40|0;T=k+42|0;s=k+44|0;V=k+46|0;g=k+48|0;y=k+50|0;L=k+52|0;n=k+54|0;q=k+56|0;O=k+58|0;t=k+60|0;S=k+62|0;N=0;u=c;while(1){c=b[j+(N<<1)>>1]|0;l=b[j+(N+512<<1)>>1]|0;C=((l+c|0)*11585|0)+8192>>14;P=((c-l|0)*11585|0)+8192>>14;l=b[j+(N+256<<1)>>1]|0;c=b[j+(N+768<<1)>>1]|0;M=(l*6270|0)+8192+(c*-15137|0)>>14;E=(l*15137|0)+8192+(c*6270|0)>>14;c=b[j+(N+128<<1)>>1]|0;l=b[j+(N+896<<1)>>1]|0;J=(c*3196|0)+8192+(l*-16069|0)>>14;W=(c*16069|0)+8192+(l*3196|0)>>14;l=b[j+(N+640<<1)>>1]|0;c=b[j+(N+384<<1)>>1]|0;p=(l*13623|0)+8192+(c*-9102|0)>>14;F=(l*9102|0)+8192+(c*13623|0)>>14;c=b[j+(N+64<<1)>>1]|0;l=b[j+(N+960<<1)>>1]|0;H=(c*1606|0)+8192+(l*-16305|0)>>14;$=(c*16305|0)+8192+(l*1606|0)>>14;l=b[j+(N+576<<1)>>1]|0;c=b[j+(N+448<<1)>>1]|0;aa=(l*12665|0)+8192+(c*-10394|0)>>14;ba=(l*10394|0)+8192+(c*12665|0)>>14;c=b[j+(N+320<<1)>>1]|0;l=b[j+(N+704<<1)>>1]|0;da=(c*7723|0)+8192+(l*-14449|0)>>14;ea=(c*14449|0)+8192+(l*7723|0)>>14;l=b[j+(N+832<<1)>>1]|0;c=b[j+(N+192<<1)>>1]|0;fa=(l*15679|0)+8192+(c*-4756|0)>>14;ga=(l*4756|0)+8192+(c*15679|0)>>14;c=b[j+(N+32<<1)>>1]|0;l=b[j+(N+992<<1)>>1]|0;ha=(c*804|0)+8192+(l*-16364|0)>>14;ia=(c*16364|0)+8192+(l*804|0)>>14;l=b[j+(N+544<<1)>>1]|0;c=b[j+(N+480<<1)>>1]|0;ja=(l*12140|0)+8192+(c*-11003|0)>>14;ka=(l*11003|0)+8192+(c*12140|0)>>14;c=b[j+(N+288<<1)>>1]|0;l=b[j+(N+736<<1)>>1]|0;la=(c*7005|0)+8192+(l*-14811|0)>>14;ma=(c*14811|0)+8192+(l*7005|0)>>14;l=b[j+(N+800<<1)>>1]|0;c=b[j+(N+224<<1)>>1]|0;na=(l*15426|0)+8192+(c*-5520|0)>>14;oa=(l*5520|0)+8192+(c*15426|0)>>14;c=b[j+(N+160<<1)>>1]|0;l=b[j+(N+864<<1)>>1]|0;pa=(c*3981|0)+8192+(l*-15893|0)>>14;qa=(c*15893|0)+8192+(l*3981|0)>>14;l=b[j+(N+672<<1)>>1]|0;c=b[j+(N+352<<1)>>1]|0;ra=(l*14053|0)+8192+(c*-8423|0)>>14;sa=(l*8423|0)+8192+(c*14053|0)>>14;c=b[j+(N+416<<1)>>1]|0;l=b[j+(N+608<<1)>>1]|0;ta=(c*9760|0)+8192+(l*-13160|0)>>14;ua=(c*13160|0)+8192+(l*9760|0)>>14;l=b[j+(N+928<<1)>>1]|0;c=b[j+(N+96<<1)>>1]|0;va=(l*16207|0)+8192+(c*-2404|0)>>14;wa=(l*2404|0)+8192+(c*16207|0)>>14;c=E+C|0;l=M+P|0;xa=P-M|0;M=C-E|0;E=p+J|0;C=J-p|0;p=W-F|0;J=F+W|0;W=aa+H|0;F=H-aa|0;aa=fa-da|0;H=fa+da|0;da=ga+ea|0;fa=ga-ea|0;ea=$-ba|0;ga=ba+$|0;$=ja+ha|0;ba=ha-ja|0;ja=na-la|0;ha=na+la|0;la=ra+pa|0;na=pa-ra|0;ra=va-ta|0;pa=va+ta|0;ta=wa+ua|0;va=wa-ua|0;ua=qa-sa|0;wa=sa+qa|0;qa=oa+ma|0;sa=oa-ma|0;ma=ia-ka|0;oa=ka+ia|0;ia=((p-C|0)*11585|0)+8192>>14;ka=((p+C|0)*11585|0)+8192>>14;C=(F*-15137|0)+8192+(ea*6270|0)>>14;p=(F*6270|0)+8192+(ea*15137|0)>>14;ea=(aa*-6270|0)+8192+(fa*-15137|0)>>14;F=(aa*-15137|0)+8192+(fa*6270|0)>>14;fa=(ba*-16069|0)+8192+(ma*3196|0)>>14;aa=(ba*3196|0)+8192+(ma*16069|0)>>14;ma=(ja*-3196|0)+8192+(sa*-16069|0)>>14;ba=(ja*-16069|0)+8192+(sa*3196|0)>>14;sa=(na*-9102|0)+8192+(ua*13623|0)>>14;ja=(na*13623|0)+8192+(ua*9102|0)>>14;ua=(ra*-13623|0)+8192+(va*-9102|0)>>14;na=(ra*-9102|0)+8192+(va*13623|0)>>14;va=J+c|0;ra=ka+l|0;P=ia+xa|0;ya=E+M|0;za=M-E|0;E=xa-ia|0;ia=l-ka|0;ka=c-J|0;J=H+W|0;c=ea+C|0;l=C-ea|0;ea=W-H|0;H=ga-da|0;W=p-F|0;C=F+p|0;p=da+ga|0;ga=ha+$|0;da=ma+fa|0;F=fa-ma|0;ma=$-ha|0;ha=pa-la|0;$=ua-sa|0;fa=ua+sa|0;sa=pa+la|0;la=ta+wa|0;pa=na+ja|0;ua=na-ja|0;ja=ta-wa|0;wa=oa-qa|0;ta=aa-ba|0;na=ba+aa|0;aa=qa+oa|0;oa=((W-l|0)*11585|0)+8192>>14;qa=((W+l|0)*11585|0)+8192>>14;l=((H-ea|0)*11585|0)+8192>>14;W=((H+ea|0)*11585|0)+8192>>14;ea=(F*-15137|0)+8192+(ta*6270|0)>>14;H=(F*6270|0)+8192+(ta*15137|0)>>14;ta=(ma*-15137|0)+8192+(wa*6270|0)>>14;F=(ma*6270|0)+8192+(wa*15137|0)>>14;wa=(ha*-6270|0)+8192+(ja*-15137|0)>>14;ma=(ha*-15137|0)+8192+(ja*6270|0)>>14;ja=($*-6270|0)+8192+(ua*-15137|0)>>14;ha=($*-15137|0)+8192+(ua*6270|0)>>14;ua=p+va|0;$=C+ra|0;ba=qa+P|0;xa=W+ya|0;M=l+za|0;Aa=oa+E|0;Ba=c+ia|0;Ca=J+ka|0;Da=ka-J|0;J=ia-c|0;c=E-oa|0;oa=za-l|0;l=ya-W|0;W=P-qa|0;qa=ra-C|0;C=va-p|0;p=sa+ga|0;va=fa+da|0;ra=ja+ea|0;P=wa+ta|0;ya=ta-wa|0;wa=ea-ja|0;ja=da-fa|0;fa=ga-sa|0;sa=aa-la|0;ga=na-pa|0;da=H-ha|0;ea=F-ma|0;ta=ma+F|0;F=ha+H|0;H=pa+na|0;na=la+aa|0;aa=((ea-ya|0)*11585|0)+8192>>14;la=((ea+ya|0)*11585|0)+8192>>14;ya=((da-wa|0)*11585|0)+8192>>14;ea=((da+wa|0)*11585|0)+8192>>14;wa=((ga-ja|0)*11585|0)+8192>>14;da=((ga+ja|0)*11585|0)+8192>>14;ja=((sa-fa|0)*11585|0)+8192>>14;ga=((sa+fa|0)*11585|0)+8192>>14;fa=na+ua&65535;b[f>>1]=fa;b[r>>1]=H+$;b[K>>1]=F+ba;b[R>>1]=ta+xa;b[m>>1]=la+M;b[w>>1]=ea+Aa;b[x>>1]=da+Ba;b[v>>1]=ga+Ca;b[z>>1]=ja+Da;b[Q>>1]=wa+J;b[U>>1]=ya+c;b[I>>1]=aa+oa;b[o>>1]=P+l;b[B>>1]=ra+W;b[X>>1]=va+qa;b[A>>1]=p+C;b[Y>>1]=C-p;b[D>>1]=qa-va;b[Z>>1]=W-ra;b[G>>1]=l-P;b[_>>1]=oa-aa;b[T>>1]=c-ya;b[s>>1]=J-wa;b[V>>1]=Da-ja;b[g>>1]=Ca-ga;b[y>>1]=Ba-da;b[L>>1]=Aa-ea;b[n>>1]=M-la;b[q>>1]=xa-ta;b[O>>1]=ba-F;b[t>>1]=$-H;b[S>>1]=ua-na;na=0;ua=fa;while(1){fa=u+(ca(na,e)|0)|0;H=((ua<<16>>16)+32>>6)+(d[fa]|0)|0;if(H>>>0>255>>>0){Ea=-H>>31&255}else{Ea=H&255}a[fa]=Ea;fa=na+1|0;if((fa|0)>=32){break}na=fa;ua=b[k+(fa<<1)>>1]|0}ua=N+1|0;if((ua|0)<32){N=ua;u=u+1|0}else{break}}i=h;return}function Oeb(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+40|0;h=g|0;j=g+32|0;k=0;do{l=k<<2;m=b[f+(k+12<<1)>>1]>>2;n=b[f+(k+4<<1)>>1]>>2;o=n+(b[f+(k<<1)>>1]>>2)|0;p=(b[f+(k+8<<1)>>1]>>2)-m|0;q=o-p>>1;r=q-m|0;m=q-n|0;b[h+(l<<1)>>1]=o-r;b[h+((l|1)<<1)>>1]=r;b[h+((l|2)<<1)>>1]=m;b[h+((l|3)<<1)>>1]=m+p;k=k+1|0;}while((k|0)<4);mrc(f|0,0,32)|0;f=j|0;k=j+2|0;p=j+4|0;m=j+6|0;j=c;c=0;while(1){l=b[h+(c+12<<1)>>1]|0;r=b[h+(c+4<<1)>>1]|0;o=r+(b[h+(c<<1)>>1]|0)|0;n=(b[h+(c+8<<1)>>1]|0)-l|0;q=o-n>>1;s=q-l|0;l=q-r|0;r=o-s&65535;b[f>>1]=r;b[k>>1]=s;b[p>>1]=l;b[m>>1]=l+n;n=(r<<16>>16)+(d[j]|0)|0;if(n>>>0>255>>>0){t=-n>>31&255}else{t=n&255}a[j]=t;n=j+e|0;r=(b[k>>1]|0)+(d[n]|0)|0;if(r>>>0>255>>>0){u=-r>>31&255}else{u=r&255}a[n]=u;n=j+(e<<1)|0;r=(b[p>>1]|0)+(d[n]|0)|0;if(r>>>0>255>>>0){v=-r>>31&255}else{v=r&255}a[n]=v;n=j+(e*3|0)|0;r=(b[m>>1]|0)+(d[n]|0)|0;if(r>>>0>255>>>0){w=-r>>31&255}else{w=r&255}a[n]=w;n=c+1|0;if((n|0)<4){j=j+1|0;c=n}else{break}}i=g;return}function Peb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=c[e>>2]|0;c[a>>2]=d;c[a+b>>2]=d;c[a+(b<<1)>>2]=d;c[a+(b*3|0)>>2]=d;return}function Qeb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;c[a>>2]=ca(d[e+3|0]|0,16843009)|0;c[a+b>>2]=ca(d[e+2|0]|0,16843009)|0;c[a+(b<<1)>>2]=ca(d[e+1|0]|0,16843009)|0;c[a+(b*3|0)>>2]=ca(d[e]|0,16843009)|0;return}function Reb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;g=ca((d[e]|0)+4+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[f]|0)+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)>>3,16843009)|0;c[a>>2]=g;c[a+b>>2]=g;c[a+(b<<1)>>2]=g;c[a+(b*3|0)>>2]=g;return}function Seb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;e=d[f+1|0]|0;g=d[f+2|0]|0;h=d[f+3|0]|0;i=d[f+4|0]|0;j=d[f+5|0]|0;k=d[f+6|0]|0;l=a[f+7|0]|0;a[b]=((d[f]|0)+2+(e<<1)+g|0)>>>2;f=(e+2+(g<<1)+h|0)>>>2&255;a[b+c|0]=f;a[b+1|0]=f;f=(g+2+(h<<1)+i|0)>>>2&255;g=c<<1;a[b+g|0]=f;a[b+(c+1)|0]=f;a[b+2|0]=f;f=(h+2+(i<<1)+j|0)>>>2&255;h=c*3|0;a[b+h|0]=f;a[b+(g|1)|0]=f;a[b+(c+2)|0]=f;a[b+3|0]=f;f=(i+2+(j<<1)+k|0)>>>2&255;a[b+(h+1)|0]=f;a[b+(g+2)|0]=f;a[b+(c+3)|0]=f;f=(j+2+(k<<1)+(l&255)|0)>>>2&255;a[b+(h+2)|0]=f;a[b+(g+3)|0]=f;a[b+(h+3)|0]=l;return}function Teb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=d[f-1|0]|0;h=d[f]|0;i=d[f+1|0]|0;j=d[f+2|0]|0;k=d[f+3|0]|0;f=d[e+3|0]|0;l=d[e+2|0]|0;m=d[e+1|0]|0;n=c*3|0;a[b+n|0]=(l+2+(m<<1)+(d[e]|0)|0)>>>2;e=(f+2+(l<<1)+m|0)>>>2&255;a[b+(n+1)|0]=e;m=c<<1;a[b+m|0]=e;e=g+2|0;o=(e+(f<<1)+l|0)>>>2&255;a[b+(n+2)|0]=o;a[b+(m|1)|0]=o;a[b+c|0]=o;o=((g<<1)+2+h+f|0)>>>2&255;a[b+(n+3)|0]=o;a[b+(m+2)|0]=o;a[b+(c+1)|0]=o;a[b]=o;o=(e+(h<<1)+i|0)>>>2&255;a[b+(m+3)|0]=o;a[b+(c+2)|0]=o;a[b+1|0]=o;o=(h+2+(i<<1)+j|0)>>>2&255;a[b+(c+3)|0]=o;a[b+2|0]=o;a[b+3|0]=(i+2+(j<<1)+k|0)>>>2;return}function Ueb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=d[f-1|0]|0;h=d[f]|0;i=d[f+1|0]|0;j=d[f+2|0]|0;k=d[f+3|0]|0;f=d[e+3|0]|0;l=d[e+2|0]|0;m=c*3|0;a[b+m|0]=(f+2+(l<<1)+(d[e+1|0]|0)|0)>>>2;e=g+2|0;n=c<<1;a[b+n|0]=(e+(f<<1)+l|0)>>>2;l=(g+1+h|0)>>>1&255;a[b+(n|1)|0]=l;a[b]=l;l=((g<<1)+2+h+f|0)>>>2&255;a[b+(m+1)|0]=l;a[b+c|0]=l;l=(h+1+i|0)>>>1&255;a[b+(n+2)|0]=l;a[b+1|0]=l;l=(e+(h<<1)+i|0)>>>2&255;a[b+(m+2)|0]=l;a[b+(c+1)|0]=l;l=(i+1+j|0)>>>1&255;a[b+(n+3)|0]=l;a[b+2|0]=l;l=(h+2+(i<<1)+j|0)>>>2&255;a[b+(m+3)|0]=l;a[b+(c+2)|0]=l;a[b+3|0]=(j+1+k|0)>>>1;a[b+(c+3)|0]=(i+2+(j<<1)+k|0)>>>2;return}function Veb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=d[e+3|0]|0;h=d[e+2|0]|0;i=d[e+1|0]|0;j=d[e]|0;e=d[f-1|0]|0;k=d[f]|0;l=d[f+1|0]|0;m=d[f+2|0]|0;a[b+2|0]=(e+2+(k<<1)+l|0)>>>2;a[b+3|0]=(k+2+(l<<1)+m|0)>>>2;m=g+1|0;l=(m+e|0)>>>1&255;a[b+(c+2)|0]=l;a[b]=l;l=g+2|0;f=(l+(e<<1)+k|0)>>>2&255;a[b+(c+3)|0]=f;a[b+1|0]=f;f=(m+h|0)>>>1&255;m=c<<1;a[b+(m+2)|0]=f;a[b+c|0]=f;f=((g<<1)+2+h+e|0)>>>2&255;a[b+(m+3)|0]=f;a[b+(c+1)|0]=f;f=(h+1+i|0)>>>1&255;e=c*3|0;a[b+(e+2)|0]=f;a[b+m|0]=f;f=(l+(h<<1)+i|0)>>>2&255;a[b+(e+3)|0]=f;a[b+(m|1)|0]=f;a[b+e|0]=(i+1+j|0)>>>1;a[b+(e+1)|0]=(h+2+(i<<1)+j|0)>>>2;return}function Web(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;e=d[f]|0;g=d[f+1|0]|0;h=d[f+2|0]|0;i=d[f+3|0]|0;j=d[f+4|0]|0;k=d[f+5|0]|0;l=d[f+6|0]|0;a[b]=(e+1+g|0)>>>1;a[b+c|0]=(e+2+(g<<1)+h|0)>>>2;e=(g+1+h|0)>>>1&255;f=c<<1;a[b+f|0]=e;a[b+1|0]=e;e=(g+2+(h<<1)+i|0)>>>2&255;g=c*3|0;a[b+g|0]=e;a[b+(c+1)|0]=e;e=(h+1+i|0)>>>1&255;a[b+(f|1)|0]=e;a[b+2|0]=e;e=(h+2+(i<<1)+j|0)>>>2&255;a[b+(g+1)|0]=e;a[b+(c+2)|0]=e;e=(i+1+j|0)>>>1&255;a[b+(f+2)|0]=e;a[b+3|0]=e;e=(i+2+(j<<1)+k|0)>>>2&255;a[b+(g+2)|0]=e;a[b+(c+3)|0]=e;a[b+(f+3)|0]=(j+1+k|0)>>>1;a[b+(g+3)|0]=(j+2+(k<<1)+l|0)>>>2;return}function Xeb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;f=d[e+3|0]|0;g=d[e+2|0]|0;h=d[e+1|0]|0;i=a[e]|0;e=i&255;a[b]=(f+1+g|0)>>>1;a[b+1|0]=(f+2+(g<<1)+h|0)>>>2;f=(g+1+h|0)>>>1&255;a[b+2|0]=f;a[b+c|0]=f;f=(g+2+(h<<1)+e|0)>>>2&255;a[b+3|0]=f;a[b+(c+1)|0]=f;f=(h+1+e|0)>>>1&255;a[b+(c+2)|0]=f;g=c<<1;a[b+g|0]=f;f=(h+2+(e*3|0)|0)>>>2&255;a[b+(c+3)|0]=f;a[b+(g|1)|0]=f;f=c*3|0;a[b+(f+3)|0]=i;a[b+(g+3)|0]=i;a[b+(f+2)|0]=i;a[b+(g+2)|0]=i;a[b+(f+1)|0]=i;a[b+f|0]=i;return}function Yeb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d[f-1|0]|0;h=f+1|0;i=f+2|0;j=f+3|0;k=0;l=b;while(1){b=(d[e+(3-k)|0]|0)-g|0;m=(d[f]|0)+b|0;if(m>>>0>255>>>0){n=-m>>31&255}else{n=m&255}a[l]=n;m=(d[h]|0)+b|0;if(m>>>0>255>>>0){o=-m>>31&255}else{o=m&255}a[l+1|0]=o;m=(d[i]|0)+b|0;if(m>>>0>255>>>0){p=-m>>31&255}else{p=m&255}a[l+2|0]=p;m=(d[j]|0)+b|0;if(m>>>0>255>>>0){q=-m>>31&255}else{q=m&255}a[l+3|0]=q;m=k+1|0;if((m|0)<4){k=m;l=l+c|0}else{break}}return}function Zeb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;f=ca(((d[e]|0)+2+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)|0)>>>2,16843009)|0;c[a>>2]=f;c[a+b>>2]=f;c[a+(b<<1)>>2]=f;c[a+(b*3|0)>>2]=f;return}function _eb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;e=ca(((d[f]|0)+2+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)|0)>>>2,16843009)|0;c[a>>2]=e;c[a+b>>2]=e;c[a+(b<<1)>>2]=e;c[a+(b*3|0)>>2]=e;return}function $eb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=-2139062144;c[a+b>>2]=-2139062144;c[a+(b<<1)>>2]=-2139062144;c[a+(b*3|0)>>2]=-2139062144;return}function afb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=2139062143;c[a+b>>2]=2139062143;c[a+(b<<1)>>2]=2139062143;c[a+(b*3|0)>>2]=2139062143;return}function bfb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=-2122219135;c[a+b>>2]=-2122219135;c[a+(b<<1)>>2]=-2122219135;c[a+(b*3|0)>>2]=-2122219135;return}function cfb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;d=e;e=c[d>>2]|0;f=c[d+4>>2]|0;d=a;c[d>>2]=e;c[d+4>>2]=f;d=a+b|0;c[d>>2]=e;c[d+4>>2]=f;d=b<<1;g=a+d|0;c[g>>2]=e;c[g+4>>2]=f;g=d+b|0;d=a+g|0;c[d>>2]=e;c[d+4>>2]=f;d=g+b|0;g=a+d|0;c[g>>2]=e;c[g+4>>2]=f;g=d+b|0;d=a+g|0;c[d>>2]=e;c[d+4>>2]=f;d=g+b|0;g=a+d|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(d+b)|0;c[g>>2]=e;c[g+4>>2]=f;return}function dfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=Erc(d[e+7|0]|0,0,16843009,16843009)|0;g=a;c[g>>2]=f;c[g+4>>2]=G;g=Erc(d[e+6|0]|0,0,16843009,16843009)|0;f=a+b|0;c[f>>2]=g;c[f+4>>2]=G;f=b<<1;g=Erc(d[e+5|0]|0,0,16843009,16843009)|0;h=a+f|0;c[h>>2]=g;c[h+4>>2]=G;h=f+b|0;f=Erc(d[e+4|0]|0,0,16843009,16843009)|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=G;g=h+b|0;h=Erc(d[e+3|0]|0,0,16843009,16843009)|0;f=a+g|0;c[f>>2]=h;c[f+4>>2]=G;f=g+b|0;g=Erc(d[e+2|0]|0,0,16843009,16843009)|0;h=a+f|0;c[h>>2]=g;c[h+4>>2]=G;h=f+b|0;f=Erc(d[e+1|0]|0,0,16843009,16843009)|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=G;g=Erc(d[e]|0,0,16843009,16843009)|0;e=a+(h+b)|0;c[e>>2]=g;c[e+4>>2]=G;return}function efb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;g=(d[e]|0)+8+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[f]|0)+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)>>4;f=Erc(g,(g|0)<0|0?-1:0,16843009,16843009)|0;g=G;e=a;c[e>>2]=f;c[e+4>>2]=g;e=a+b|0;c[e>>2]=f;c[e+4>>2]=g;e=b<<1;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+b)|0;c[h>>2]=f;c[h+4>>2]=g;return}function ffb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+8|0;g=e|0;h=d[f+1|0]|0;j=d[f+2|0]|0;k=g|0;a[k]=((d[f]|0)+2+(h<<1)+j|0)>>>2;l=d[f+3|0]|0;m=g+1|0;a[m]=(h+2+(j<<1)+l|0)>>>2;h=d[f+4|0]|0;n=g+2|0;a[n]=(j+2+(l<<1)+h|0)>>>2;j=d[f+5|0]|0;o=g+3|0;a[o]=(l+2+(h<<1)+j|0)>>>2;l=d[f+6|0]|0;p=g+4|0;a[p]=(h+2+(j<<1)+l|0)>>>2;h=f+7|0;f=d[h]|0;q=g+5|0;a[q]=(j+2+(l<<1)+f|0)>>>2;j=g+6|0;a[j]=(l+2+(f*3|0)|0)>>>2;a[b]=a[k]|0;a[b+1|0]=a[k+1|0]|0;a[b+2|0]=a[k+2|0]|0;a[b+3|0]=a[k+3|0]|0;a[b+4|0]=a[k+4|0]|0;a[b+5|0]=a[k+5|0]|0;a[b+6|0]=a[k+6|0]|0;mrc(b+7|0,a[h]|0,1)|0;k=b+c|0;a[k]=a[m]|0;a[k+1|0]=a[m+1|0]|0;a[k+2|0]=a[m+2|0]|0;a[k+3|0]=a[m+3|0]|0;a[k+4|0]=a[m+4|0]|0;a[k+5|0]=a[m+5|0]|0;mrc(b+(c+6)|0,a[h]|0,2)|0;m=c<<1;k=b+m|0;a[k]=a[n]|0;a[k+1|0]=a[n+1|0]|0;a[k+2|0]=a[n+2|0]|0;a[k+3|0]=a[n+3|0]|0;a[k+4|0]=a[n+4|0]|0;mrc(b+(m+5)|0,a[h]|0,3)|0;m=c*3|0;n=o;o=b+m|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;mrc(b+(m+4)|0,a[h]|0,4)|0;m=c<<2;o=b+m|0;a[o]=a[p]|0;a[o+1|0]=a[p+1|0]|0;a[o+2|0]=a[p+2|0]|0;mrc(b+(m|3)|0,a[h]|0,5)|0;m=c*5|0;p=q;q=b+m|0;y=(d[p]|d[p+1|0]<<8)<<16>>16;a[q]=y;y=y>>8;a[q+1|0]=y;mrc(b+(m+2)|0,a[h]|0,6)|0;m=c*6|0;a[b+m|0]=a[j]|0;mrc(b+(m|1)|0,a[h]|0,7)|0;mrc(b+(c*7|0)|0,a[h]|0,8)|0;i=e;return}function gfb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+16|0;k=j|0;l=a[h]|0;m=a[h+1|0]|0;n=0;o=a[g]|0;p=a[g+1|0]|0;q=l;r=m;while(1){s=n+1|0;t=n+2|0;u=a[g+t|0]|0;a[k+n|0]=((o&255)+2+((p&255)<<1)+(u&255)|0)>>>2;v=a[h+t|0]|0;a[k+(n+9)|0]=((q&255)+2+((r&255)<<1)+(v&255)|0)>>>2;if((s|0)<6){n=s;o=p;p=u;q=r;r=v}else{break}}r=d[g+7|0]|0;q=d[h-1|0]|0;h=k+6|0;a[h]=((d[g+6|0]|0)+2+(r<<1)+q|0)>>>2;g=l&255;l=k+7|0;a[l]=(r+2+(q<<1)+g|0)>>>2;a[k+8|0]=(q+2+(g<<1)+(m&255)|0)>>>2;m=l;l=b;g=m|0;q=m+4|0;m=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=l|0;y=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=l+4|0;y=m;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=h;h=b+f|0;m=q|0;l=q+4|0;q=e[l>>1]|e[l+2>>1]<<16;l=h|0;y=e[m>>1]|e[m+2>>1]<<16;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+4|0;y=q;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=k+5|0;q=b+(f<<1)|0;h=l|0;m=l+4|0;l=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q|0;y=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=q+4|0;y=l;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+4|0;l=b+(f*3|0)|0;q=c[m+4>>2]|0;h=l|0;y=c[m>>2]|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=l+4|0;y=q;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=k+3|0;q=b+(f<<2)|0;l=h|0;m=h+4|0;h=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=q|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=q+4|0;y=h;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+2|0;h=b+(f*5|0)|0;q=m|0;l=m+4|0;m=e[l>>1]|e[l+2>>1]<<16;l=h|0;y=e[q>>1]|e[q+2>>1]<<16;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=h+4|0;y=m;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=k+1|0;m=b+(f*6|0)|0;h=l|0;q=l+4|0;l=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=m|0;y=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=m+4|0;y=l;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=k;k=b+(f*7|0)|0;f=c[q+4>>2]|0;b=k|0;y=c[q>>2]|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=k+4|0;y=f;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;i=j;return}function hfb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;j=i;i=i+32|0;k=j|0;l=j+16|0;m=d[g+3|0]|0;n=d[g+2|0]|0;a[l|0]=(m+2+(n<<1)+(d[g+1|0]|0)|0)>>>2;o=d[g+4|0]|0;a[k|0]=(o+2+(m<<1)+n|0)>>>2;n=d[g+5|0]|0;p=l+1|0;a[p]=(n+2+(o<<1)+m|0)>>>2;m=d[g+6|0]|0;q=k+1|0;a[q]=(m+2+(n<<1)+o|0)>>>2;o=d[g+7|0]|0;g=o+2|0;r=l+2|0;a[r]=(g+(m<<1)+n|0)>>>2;n=a[h-1|0]|0;s=n&255;t=k+2|0;a[t]=(s+2+(o<<1)+m|0)>>>2;m=a[h]|0;o=m&255;u=k+3|0;a[u]=(s+1+o|0)>>>1;v=l+3|0;a[v]=(g+(s<<1)+o|0)>>>2;o=0;s=m;m=n;while(1){n=s&255;g=o+1|0;w=a[h+g|0]|0;x=w&255;z=o+4|0;a[k+z|0]=(n+1+x|0)>>>1;a[l+z|0]=((m&255)+2+(n<<1)+x|0)>>>2;if((g|0)<7){o=g;m=s;s=w}else{break}}s=u;u=b;m=s|0;o=s+4|0;s=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=u|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=u+4|0;y=s;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=v;v=b+f|0;s=o|0;u=o+4|0;o=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=v|0;y=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=v+4|0;y=o;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=t;t=b+(f<<1)|0;o=u|0;v=u+4|0;u=e[v>>1]|e[v+2>>1]<<16;v=t|0;y=e[o>>1]|e[o+2>>1]<<16;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;v=t+4|0;y=u;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;v=r;r=b+(f*3|0)|0;u=v|0;t=v+4|0;v=e[t>>1]|e[t+2>>1]<<16;t=r|0;y=e[u>>1]|e[u+2>>1]<<16;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=r+4|0;y=v;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=q;q=b+(f<<2)|0;v=t|0;r=t+4|0;t=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=q|0;y=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=q+4|0;y=t;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=p;p=b+(f*5|0)|0;t=r|0;q=r+4|0;r=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=p|0;y=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=p+4|0;y=r;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=k;k=b+(f*6|0)|0;r=c[q+4>>2]|0;p=k|0;y=c[q>>2]|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+4|0;y=r;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l;l=b+(f*7|0)|0;f=c[p+4>>2]|0;b=l|0;y=c[p>>2]|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=l+4|0;y=f;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;i=j;return}function ifb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+24|0;k=j|0;l=a[g]|0;m=a[h-1|0]|0;n=a[h]|0;o=0;p=a[g+1|0]|0;q=l;r=m;s=n;t=l;while(1){l=o+1|0;u=p&255;v=o<<1;a[k+v|0]=(u+1+(q&255)|0)>>>1;w=a[g+(o+2)|0]|0;a[k+(v|1)|0]=((w&255)+2+(u<<1)+(t&255)|0)>>>2;u=a[h+l|0]|0;a[k+(o+16)|0]=((r&255)+2+((s&255)<<1)+(u&255)|0)>>>2;if((l|0)>=6){break}o=l;q=p;p=w;r=s;s=u;t=a[g+l|0]|0}t=m&255;m=d[g+7|0]|0;s=k+14|0;a[s]=(t+1+m|0)>>>1;r=d[g+6|0]|0;g=k+12|0;a[g]=(m+1+r|0)>>>1;a[k+15|0]=((n&255)+2+(t<<1)+m|0)>>>2;a[k+13|0]=(t+2+(m<<1)+r|0)>>>2;r=s;s=b;m=r|0;t=r+4|0;r=e[t>>1]|e[t+2>>1]<<16;t=s|0;y=e[m>>1]|e[m+2>>1]<<16;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=s+4|0;y=r;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=g;g=b+f|0;r=c[t+4>>2]|0;s=g|0;y=c[t>>2]|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=g+4|0;y=r;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=k+10|0;r=b+(f<<1)|0;g=s|0;t=s+4|0;s=e[t>>1]|e[t+2>>1]<<16;t=r|0;y=e[g>>1]|e[g+2>>1]<<16;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=r+4|0;y=s;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=k+8|0;s=b+(f*3|0)|0;r=c[t+4>>2]|0;g=s|0;y=c[t>>2]|0;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;g=s+4|0;y=r;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;g=k+6|0;r=b+(f<<2)|0;s=g|0;t=g+4|0;g=e[t>>1]|e[t+2>>1]<<16;t=r|0;y=e[s>>1]|e[s+2>>1]<<16;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=r+4|0;y=g;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=k+4|0;g=b+(f*5|0)|0;r=c[t+4>>2]|0;s=g|0;y=c[t>>2]|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=g+4|0;y=r;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=k+2|0;r=b+(f*6|0)|0;g=s|0;t=s+4|0;s=e[t>>1]|e[t+2>>1]<<16;t=r|0;y=e[g>>1]|e[g+2>>1]<<16;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=r+4|0;y=s;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=k;k=b+(f*7|0)|0;f=c[t+4>>2]|0;b=k|0;y=c[t>>2]|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=k+4|0;y=f;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;i=j;return}function jfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+16|0;g=e|0;h=e+8|0;j=0;k=a[f]|0;l=a[f+1|0]|0;while(1){m=k&255;n=j+1|0;o=l&255;a[g+j|0]=(m+1+o|0)>>>1;p=a[f+(j+2)|0]|0;a[h+j|0]=(m+2+(o<<1)+(p&255)|0)>>>2;if((n|0)<6){j=n;k=l;l=p}else{break}}l=d[f+6|0]|0;k=f+7|0;f=d[k]|0;a[g+6|0]=(l+1+f|0)>>>1;a[h+6|0]=(l+2+(f*3|0)|0)>>>2;f=g|0;a[b]=a[f]|0;a[b+1|0]=a[f+1|0]|0;a[b+2|0]=a[f+2|0]|0;a[b+3|0]=a[f+3|0]|0;a[b+4|0]=a[f+4|0]|0;a[b+5|0]=a[f+5|0]|0;a[b+6|0]=a[f+6|0]|0;mrc(b+7|0,a[k]|0,1)|0;f=b+c|0;l=h|0;a[f]=a[l]|0;a[f+1|0]=a[l+1|0]|0;a[f+2|0]=a[l+2|0]|0;a[f+3|0]=a[l+3|0]|0;a[f+4|0]=a[l+4|0]|0;a[f+5|0]=a[l+5|0]|0;a[f+6|0]=a[l+6|0]|0;mrc(b+(c+7)|0,a[k]|0,1)|0;l=c<<1;f=b+l|0;j=g+1|0;a[f]=a[j]|0;a[f+1|0]=a[j+1|0]|0;a[f+2|0]=a[j+2|0]|0;a[f+3|0]=a[j+3|0]|0;a[f+4|0]=a[j+4|0]|0;a[f+5|0]=a[j+5|0]|0;mrc(b+(l+6)|0,a[k]|0,2)|0;l=c*3|0;j=b+l|0;f=h+1|0;a[j]=a[f]|0;a[j+1|0]=a[f+1|0]|0;a[j+2|0]=a[f+2|0]|0;a[j+3|0]=a[f+3|0]|0;a[j+4|0]=a[f+4|0]|0;a[j+5|0]=a[f+5|0]|0;mrc(b+(l+6)|0,a[k]|0,2)|0;l=c<<2;f=b+l|0;j=g+2|0;a[f]=a[j]|0;a[f+1|0]=a[j+1|0]|0;a[f+2|0]=a[j+2|0]|0;a[f+3|0]=a[j+3|0]|0;a[f+4|0]=a[j+4|0]|0;mrc(b+(l+5)|0,a[k]|0,3)|0;l=c*5|0;j=b+l|0;f=h+2|0;a[j]=a[f]|0;a[j+1|0]=a[f+1|0]|0;a[j+2|0]=a[f+2|0]|0;a[j+3|0]=a[f+3|0]|0;a[j+4|0]=a[f+4|0]|0;mrc(b+(l+5)|0,a[k]|0,3)|0;l=c*6|0;f=g+3|0;g=b+l|0;y=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;mrc(b+(l+4)|0,a[k]|0,4)|0;l=c*7|0;c=h+3|0;h=b+l|0;y=d[c]|d[c+1|0]<<8|d[c+2|0]<<16|d[c+3|0]<<24|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;mrc(b+(l+4)|0,a[k]|0,4)|0;i=e;return}function kfb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;j=i;i=i+16|0;k=j|0;l=0;do{m=8-l|0;n=d[h+(m-1)|0]|0;o=d[h+(m-2)|0]|0;p=l<<1;a[k+p|0]=(n+1+o|0)>>>1;a[k+(p|1)|0]=(n+2+(o<<1)+(d[h+(m-3)|0]|0)|0)>>>2;l=l+1|0;}while((l|0)<6);l=d[h+1|0]|0;m=d[h]|0;o=k+12|0;a[o]=(l+1+m|0)>>>1;a[k+13|0]=(l+2+(m*3|0)|0)>>>2;m=k;l=f;n=c[m+4>>2]|0;p=l|0;y=c[m>>2]|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=l+4|0;y=n;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=k+2|0;n=f+g|0;l=p|0;m=p+4|0;p=e[m>>1]|e[m+2>>1]<<16;m=n|0;y=e[l>>1]|e[l+2>>1]<<16;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=n+4|0;y=p;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=k+4|0;p=f+(g<<1)|0;n=c[m+4>>2]|0;l=p|0;y=c[m>>2]|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=p+4|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=k+6|0;n=f+(g*3|0)|0;p=l|0;m=l+4|0;l=e[m>>1]|e[m+2>>1]<<16;m=n|0;y=e[p>>1]|e[p+2>>1]<<16;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=n+4|0;y=l;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=g<<2;l=f+m|0;n=k+8|0;a[l]=a[n]|0;a[l+1|0]=a[n+1|0]|0;a[l+2|0]=a[n+2|0]|0;a[l+3|0]=a[n+3|0]|0;a[l+4|0]=a[n+4|0]|0;a[l+5|0]=a[n+5|0]|0;mrc(f+(m+6)|0,a[h]|0,2)|0;m=g*5|0;n=k+10|0;k=f+m|0;y=e[n>>1]|e[n+2>>1]<<16;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;mrc(f+(m+4)|0,a[h]|0,4)|0;m=g*6|0;k=f+m|0;y=b[o>>1]|0;a[k]=y;y=y>>8;a[k+1|0]=y;mrc(f+(m+2)|0,a[h]|0,6)|0;mrc(f+(g*7|0)|0,a[h]|0,8)|0;i=j;return}function lfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=d[f-1|0]|0;h=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=0;p=b;while(1){b=(d[e+(7-o)|0]|0)-g|0;q=(d[f]|0)+b|0;if(q>>>0>255>>>0){r=-q>>31&255}else{r=q&255}a[p]=r;q=(d[h]|0)+b|0;if(q>>>0>255>>>0){s=-q>>31&255}else{s=q&255}a[p+1|0]=s;q=(d[i]|0)+b|0;if(q>>>0>255>>>0){t=-q>>31&255}else{t=q&255}a[p+2|0]=t;q=(d[j]|0)+b|0;if(q>>>0>255>>>0){u=-q>>31&255}else{u=q&255}a[p+3|0]=u;q=(d[k]|0)+b|0;if(q>>>0>255>>>0){v=-q>>31&255}else{v=q&255}a[p+4|0]=v;q=(d[l]|0)+b|0;if(q>>>0>255>>>0){w=-q>>31&255}else{w=q&255}a[p+5|0]=w;q=(d[m]|0)+b|0;if(q>>>0>255>>>0){x=-q>>31&255}else{x=q&255}a[p+6|0]=x;q=(d[n]|0)+b|0;if(q>>>0>255>>>0){y=-q>>31&255}else{y=q&255}a[p+7|0]=y;q=o+1|0;if((q|0)<8){o=q;p=p+c|0}else{break}}return}function mfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=(d[e]|0)+4+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)>>3;e=Erc(f,(f|0)<0|0?-1:0,16843009,16843009)|0;f=G;g=a;c[g>>2]=e;c[g+4>>2]=f;g=a+b|0;c[g>>2]=e;c[g+4>>2]=f;g=b<<1;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+b)|0;c[h>>2]=e;c[h+4>>2]=f;return}function nfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;e=(d[f]|0)+4+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)>>3;f=Erc(e,(e|0)<0|0?-1:0,16843009,16843009)|0;e=G;g=a;c[g>>2]=f;c[g+4>>2]=e;g=a+b|0;c[g>>2]=f;c[g+4>>2]=e;g=b<<1;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+b)|0;c[h>>2]=f;c[h+4>>2]=e;return}function ofb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+b|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=b<<1;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+b)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;return}function pfb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+b|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=b<<1;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+b)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;return}function qfb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+b|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=b<<1;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+b)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;return}function rfb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;d=e;f=c[d>>2]|0;g=c[d+4>>2]|0;d=e+8|0;e=c[d>>2]|0;h=c[d+4>>2]|0;d=a;c[d>>2]=f;c[d+4>>2]=g;d=a+8|0;c[d>>2]=e;c[d+4>>2]=h;d=a+b|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(b+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=b<<1;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;d=a+i|0;c[d>>2]=f;c[d+4>>2]=g;d=a+(i+8)|0;c[d>>2]=e;c[d+4>>2]=h;d=i+b|0;i=a+d|0;c[i>>2]=f;c[i+4>>2]=g;i=a+(d+8)|0;c[i>>2]=e;c[i+4>>2]=h;i=d+b|0;b=a+i|0;c[b>>2]=f;c[b+4>>2]=g;g=a+(i+8)|0;c[g>>2]=e;c[g+4>>2]=h;return}function sfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;f=0;g=a;while(1){a=Erc(d[e+(15-f)|0]|0,0,16843009,16843009)|0;h=G;i=g;c[i>>2]=a;c[i+4>>2]=h;i=g+8|0;c[i>>2]=a;c[i+4>>2]=h;h=f+1|0;if((h|0)<16){f=h;g=g+b|0}else{break}}return}function tfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;g=(d[e]|0)+16+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[e+8|0]|0)+(d[e+9|0]|0)+(d[e+10|0]|0)+(d[e+11|0]|0)+(d[e+12|0]|0)+(d[e+13|0]|0)+(d[e+14|0]|0)+(d[e+15|0]|0)+(d[f]|0)+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)+(d[f+8|0]|0)+(d[f+9|0]|0)+(d[f+10|0]|0)+(d[f+11|0]|0)+(d[f+12|0]|0)+(d[f+13|0]|0)+(d[f+14|0]|0)+(d[f+15|0]|0)>>5;f=Erc(g,(g|0)<0|0?-1:0,16843009,16843009)|0;g=G;e=a;c[e>>2]=f;c[e+4>>2]=g;e=a+8|0;c[e>>2]=f;c[e+4>>2]=g;e=a+b|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(b+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=b<<1;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;e=a+h|0;c[e>>2]=f;c[e+4>>2]=g;e=a+(h+8)|0;c[e>>2]=f;c[e+4>>2]=g;e=h+b|0;h=a+e|0;c[h>>2]=f;c[h+4>>2]=g;h=a+(e+8)|0;c[h>>2]=f;c[h+4>>2]=g;h=e+b|0;b=a+h|0;c[b>>2]=f;c[b+4>>2]=g;b=a+(h+8)|0;c[b>>2]=f;c[b+4>>2]=g;return}function ufb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;g=e|0;h=0;j=a[f]|0;k=a[f+1|0]|0;while(1){l=h+1|0;m=a[f+(h+2)|0]|0;a[g+h|0]=((j&255)+2+((k&255)<<1)+(m&255)|0)>>>2;if((l|0)<14){h=l;j=k;k=m}else{break}}k=f+15|0;a[g+14|0]=((d[f+14|0]|0)+2+((d[k]|0)*3|0)|0)>>>2;f=0;do{j=ca(f,c)|0;h=15-f|0;nrc(b+j|0,g+f|0,h)|0;f=f+1|0;mrc(b+(h+j)|0,a[k]|0,f|0)|0;}while((f|0)<16);i=e;return}function vfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+32|0;h=g|0;j=a[f]|0;k=a[f+1|0]|0;l=0;m=a[e]|0;n=a[e+1|0]|0;o=j;p=k;while(1){q=l+1|0;r=l+2|0;s=a[e+r|0]|0;a[h+l|0]=((m&255)+2+((n&255)<<1)+(s&255)|0)>>>2;t=a[f+r|0]|0;a[h+(l+17)|0]=((o&255)+2+((p&255)<<1)+(t&255)|0)>>>2;if((q|0)<14){l=q;m=n;n=s;o=p;p=t}else{break}}p=d[e+15|0]|0;o=d[f-1|0]|0;f=h+14|0;a[f]=((d[e+14|0]|0)+2+(p<<1)+o|0)>>>2;e=j&255;j=h+15|0;a[j]=(p+2+(o<<1)+e|0)>>>2;a[h+16|0]=(o+2+(e<<1)+(k&255)|0)>>>2;nrc(b|0,j|0,16)|0;nrc(b+c|0,f|0,16)|0;nrc(b+(c<<1)|0,h+13|0,16)|0;nrc(b+(c*3|0)|0,h+12|0,16)|0;nrc(b+(c<<2)|0,h+11|0,16)|0;nrc(b+(c*5|0)|0,h+10|0,16)|0;nrc(b+(c*6|0)|0,h+9|0,16)|0;nrc(b+(c*7|0)|0,h+8|0,16)|0;nrc(b+(c<<3)|0,h+7|0,16)|0;nrc(b+(c*9|0)|0,h+6|0,16)|0;nrc(b+(c*10|0)|0,h+5|0,16)|0;nrc(b+(c*11|0)|0,h+4|0,16)|0;nrc(b+(c*12|0)|0,h+3|0,16)|0;nrc(b+(c*13|0)|0,h+2|0,16)|0;nrc(b+(c*14|0)|0,h+1|0,16)|0;nrc(b+(c*15|0)|0,h|0,16)|0;i=g;return}function wfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+48|0;h=g|0;j=g+24|0;k=0;do{l=k<<1;m=d[e+(l+3)|0]|0;n=d[e+(l+2)|0]|0;a[j+k|0]=(m+2+(n<<1)+(d[e+(l|1)|0]|0)|0)>>>2;a[h+k|0]=((d[e+(l+4)|0]|0)+2+(m<<1)+n|0)>>>2;k=k+1|0;}while((k|0)<6);k=d[e+15|0]|0;n=d[e+14|0]|0;m=k+2|0;l=j+6|0;a[l]=(m+(n<<1)+(d[e+13|0]|0)|0)>>>2;e=a[f-1|0]|0;o=e&255;p=h+6|0;a[p]=(o+2+(k<<1)+n|0)>>>2;n=a[f]|0;k=n&255;q=h+7|0;a[q]=(o+1+k|0)>>>1;r=j+7|0;a[r]=(m+(o<<1)+k|0)>>>2;k=0;o=n;n=e;while(1){e=o&255;m=k+1|0;s=a[f+m|0]|0;t=s&255;u=k+8|0;a[h+u|0]=(e+1+t|0)>>>1;a[j+u|0]=((n&255)+2+(e<<1)+t|0)>>>2;if((m|0)<15){k=m;n=o;o=s}else{break}}nrc(b|0,q|0,16)|0;nrc(b+c|0,r|0,16)|0;nrc(b+(c<<1)|0,p|0,16)|0;nrc(b+(c*3|0)|0,l|0,16)|0;nrc(b+(c<<2)|0,h+5|0,16)|0;nrc(b+(c*5|0)|0,j+5|0,16)|0;nrc(b+(c*6|0)|0,h+4|0,16)|0;nrc(b+(c*7|0)|0,j+4|0,16)|0;nrc(b+(c<<3)|0,h+3|0,16)|0;nrc(b+(c*9|0)|0,j+3|0,16)|0;nrc(b+(c*10|0)|0,h+2|0,16)|0;nrc(b+(c*11|0)|0,j+2|0,16)|0;nrc(b+(c*12|0)|0,h+1|0,16)|0;nrc(b+(c*13|0)|0,j+1|0,16)|0;nrc(b+(c*14|0)|0,h|0,16)|0;nrc(b+(c*15|0)|0,j|0,16)|0;i=g;return}function xfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+48|0;h=g|0;j=a[e]|0;k=a[f-1|0]|0;l=a[f]|0;m=0;n=a[e+1|0]|0;o=j;p=k;q=l;r=j;while(1){j=m+1|0;s=n&255;t=m<<1;a[h+t|0]=(s+1+(o&255)|0)>>>1;u=a[e+(m+2)|0]|0;a[h+(t|1)|0]=((u&255)+2+(s<<1)+(r&255)|0)>>>2;s=a[f+j|0]|0;a[h+(m+32)|0]=((p&255)+2+((q&255)<<1)+(s&255)|0)>>>2;if((j|0)>=14){break}m=j;o=n;n=u;p=q;q=s;r=a[e+j|0]|0}r=k&255;k=d[e+15|0]|0;q=h+30|0;a[q]=(r+1+k|0)>>>1;p=d[e+14|0]|0;e=h+28|0;a[e]=(k+1+p|0)>>>1;a[h+31|0]=((l&255)+2+(r<<1)+k|0)>>>2;a[h+29|0]=(r+2+(k<<1)+p|0)>>>2;nrc(b|0,q|0,16)|0;nrc(b+c|0,e|0,16)|0;nrc(b+(c<<1)|0,h+26|0,16)|0;nrc(b+(c*3|0)|0,h+24|0,16)|0;nrc(b+(c<<2)|0,h+22|0,16)|0;nrc(b+(c*5|0)|0,h+20|0,16)|0;nrc(b+(c*6|0)|0,h+18|0,16)|0;nrc(b+(c*7|0)|0,h+16|0,16)|0;nrc(b+(c<<3)|0,h+14|0,16)|0;nrc(b+(c*9|0)|0,h+12|0,16)|0;nrc(b+(c*10|0)|0,h+10|0,16)|0;nrc(b+(c*11|0)|0,h+8|0,16)|0;nrc(b+(c*12|0)|0,h+6|0,16)|0;nrc(b+(c*13|0)|0,h+4|0,16)|0;nrc(b+(c*14|0)|0,h+2|0,16)|0;nrc(b+(c*15|0)|0,h|0,16)|0;i=g;return}function yfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+32|0;g=e|0;h=e+16|0;j=0;k=a[f]|0;l=a[f+1|0]|0;while(1){m=k&255;n=j+1|0;o=l&255;a[g+j|0]=(m+1+o|0)>>>1;p=a[f+(j+2)|0]|0;a[h+j|0]=(m+2+(o<<1)+(p&255)|0)>>>2;if((n|0)<14){j=n;k=l;l=p}else{break}}l=d[f+14|0]|0;k=f+15|0;f=d[k]|0;a[g+14|0]=(l+1+f|0)>>>1;a[h+14|0]=(l+2+(f*3|0)|0)>>>2;f=0;l=0;while(1){j=f<<1;p=ca(j,c)|0;n=16-f-1|0;nrc(b+p|0,g+f|0,n)|0;o=l+15|0;m=f+1|0;mrc(b+(o+p)|0,a[k]|0,m|0)|0;p=ca(j|1,c)|0;nrc(b+p|0,h+f|0,n)|0;mrc(b+(o+p)|0,a[k]|0,m|0)|0;p=~f;if((m|0)<8){f=m;l=p}else{break}}i=e;return}function zfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+32|0;g=f|0;h=0;do{j=16-h|0;k=d[e+(j-1)|0]|0;l=d[e+(j-2)|0]|0;m=h<<1;a[g+m|0]=(k+1+l|0)>>>1;a[g+(m|1)|0]=(k+2+(l<<1)+(d[e+(j-3)|0]|0)|0)>>>2;h=h+1|0;}while((h|0)<14);h=d[e+1|0]|0;j=d[e]|0;l=g+28|0;a[l]=(h+1+j|0)>>>1;a[g+29|0]=(h+2+(j*3|0)|0)>>>2;nrc(b|0,g|0,16)|0;nrc(b+c|0,g+2|0,16)|0;nrc(b+(c<<1)|0,g+4|0,16)|0;nrc(b+(c*3|0)|0,g+6|0,16)|0;nrc(b+(c<<2)|0,g+8|0,16)|0;nrc(b+(c*5|0)|0,g+10|0,16)|0;nrc(b+(c*6|0)|0,g+12|0,16)|0;nrc(b+(c*7|0)|0,g+14|0,16)|0;j=c<<3;nrc(b+j|0,g+16|0,14)|0;mrc(b+(j+14)|0,a[e]|0,2)|0;j=c*9|0;nrc(b+j|0,g+18|0,12)|0;mrc(b+(j+12)|0,a[e]|0,4)|0;j=c*10|0;nrc(b+j|0,g+20|0,10)|0;mrc(b+(j+10)|0,a[e]|0,6)|0;j=c*11|0;h=g+22|0;k=b+j|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=k|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+4|0;y=h;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;mrc(b+(j+8)|0,a[e]|0,8)|0;j=c*12|0;n=b+j|0;h=g+24|0;a[n]=a[h]|0;a[n+1|0]=a[h+1|0]|0;a[n+2|0]=a[h+2|0]|0;a[n+3|0]=a[h+3|0]|0;a[n+4|0]=a[h+4|0]|0;a[n+5|0]=a[h+5|0]|0;mrc(b+(j+6)|0,a[e]|0,10)|0;j=c*13|0;h=g+26|0;g=b+j|0;y=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;mrc(b+(j+4)|0,a[e]|0,12)|0;j=c*14|0;g=l;l=b+j|0;y=(d[g]|d[g+1|0]<<8)<<16>>16;a[l]=y;y=y>>8;a[l+1|0]=y;mrc(b+(j+2)|0,a[e]|0,14)|0;mrc(b+(c*15|0)|0,a[e]|0,16)|0;i=f;return}function Afb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=d[f-1|0]|0;h=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=f+9|0;q=f+10|0;r=f+11|0;s=f+12|0;t=f+13|0;u=f+14|0;v=f+15|0;w=0;x=b;while(1){b=(d[e+(15-w)|0]|0)-g|0;y=(d[f]|0)+b|0;if(y>>>0>255>>>0){z=-y>>31&255}else{z=y&255}a[x]=z;y=(d[h]|0)+b|0;if(y>>>0>255>>>0){A=-y>>31&255}else{A=y&255}a[x+1|0]=A;y=(d[i]|0)+b|0;if(y>>>0>255>>>0){B=-y>>31&255}else{B=y&255}a[x+2|0]=B;y=(d[j]|0)+b|0;if(y>>>0>255>>>0){C=-y>>31&255}else{C=y&255}a[x+3|0]=C;y=(d[k]|0)+b|0;if(y>>>0>255>>>0){D=-y>>31&255}else{D=y&255}a[x+4|0]=D;y=(d[l]|0)+b|0;if(y>>>0>255>>>0){E=-y>>31&255}else{E=y&255}a[x+5|0]=E;y=(d[m]|0)+b|0;if(y>>>0>255>>>0){F=-y>>31&255}else{F=y&255}a[x+6|0]=F;y=(d[n]|0)+b|0;if(y>>>0>255>>>0){G=-y>>31&255}else{G=y&255}a[x+7|0]=G;y=(d[o]|0)+b|0;if(y>>>0>255>>>0){H=-y>>31&255}else{H=y&255}a[x+8|0]=H;y=(d[p]|0)+b|0;if(y>>>0>255>>>0){I=-y>>31&255}else{I=y&255}a[x+9|0]=I;y=(d[q]|0)+b|0;if(y>>>0>255>>>0){J=-y>>31&255}else{J=y&255}a[x+10|0]=J;y=(d[r]|0)+b|0;if(y>>>0>255>>>0){K=-y>>31&255}else{K=y&255}a[x+11|0]=K;y=(d[s]|0)+b|0;if(y>>>0>255>>>0){L=-y>>31&255}else{L=y&255}a[x+12|0]=L;y=(d[t]|0)+b|0;if(y>>>0>255>>>0){M=-y>>31&255}else{M=y&255}a[x+13|0]=M;y=(d[u]|0)+b|0;if(y>>>0>255>>>0){N=-y>>31&255}else{N=y&255}a[x+14|0]=N;y=(d[v]|0)+b|0;if(y>>>0>255>>>0){O=-y>>31&255}else{O=y&255}a[x+15|0]=O;y=w+1|0;if((y|0)<16){w=y;x=x+c|0}else{break}}return}function Bfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=(d[e]|0)+8+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[e+8|0]|0)+(d[e+9|0]|0)+(d[e+10|0]|0)+(d[e+11|0]|0)+(d[e+12|0]|0)+(d[e+13|0]|0)+(d[e+14|0]|0)+(d[e+15|0]|0)>>4;e=Erc(f,(f|0)<0|0?-1:0,16843009,16843009)|0;f=G;g=a;c[g>>2]=e;c[g+4>>2]=f;g=a+8|0;c[g>>2]=e;c[g+4>>2]=f;g=a+b|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(b+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=b<<1;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;g=a+h|0;c[g>>2]=e;c[g+4>>2]=f;g=a+(h+8)|0;c[g>>2]=e;c[g+4>>2]=f;g=h+b|0;h=a+g|0;c[h>>2]=e;c[h+4>>2]=f;h=a+(g+8)|0;c[h>>2]=e;c[h+4>>2]=f;h=g+b|0;b=a+h|0;c[b>>2]=e;c[b+4>>2]=f;b=a+(h+8)|0;c[b>>2]=e;c[b+4>>2]=f;return}function Cfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;e=(d[f]|0)+8+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)+(d[f+8|0]|0)+(d[f+9|0]|0)+(d[f+10|0]|0)+(d[f+11|0]|0)+(d[f+12|0]|0)+(d[f+13|0]|0)+(d[f+14|0]|0)+(d[f+15|0]|0)>>4;f=Erc(e,(e|0)<0|0?-1:0,16843009,16843009)|0;e=G;g=a;c[g>>2]=f;c[g+4>>2]=e;g=a+8|0;c[g>>2]=f;c[g+4>>2]=e;g=a+b|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(b+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=b<<1;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;g=a+h|0;c[g>>2]=f;c[g+4>>2]=e;g=a+(h+8)|0;c[g>>2]=f;c[g+4>>2]=e;g=h+b|0;h=a+g|0;c[h>>2]=f;c[h+4>>2]=e;h=a+(g+8)|0;c[h>>2]=f;c[h+4>>2]=e;h=g+b|0;b=a+h|0;c[b>>2]=f;c[b+4>>2]=e;b=a+(h+8)|0;c[b>>2]=f;c[b+4>>2]=e;return}function Dfb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a+b|0;mrc(a|0,-128|0,16)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(b+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=b<<1;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;e=a+d|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=a+(d+8)|0;c[e>>2]=-2139062144;c[e+4>>2]=-2139062144;e=d+b|0;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e+8)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=e+b|0;b=a+d|0;c[b>>2]=-2139062144;c[b+4>>2]=-2139062144;b=a+(d+8)|0;c[b>>2]=-2139062144;c[b+4>>2]=-2139062144;return}function Efb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a+b|0;mrc(a|0,127,16)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(b+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=b<<1;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;e=a+d|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=a+(d+8)|0;c[e>>2]=2139062143;c[e+4>>2]=2139062143;e=d+b|0;d=a+e|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=a+(e+8)|0;c[d>>2]=2139062143;c[d+4>>2]=2139062143;d=e+b|0;b=a+d|0;c[b>>2]=2139062143;c[b+4>>2]=2139062143;b=a+(d+8)|0;c[b>>2]=2139062143;c[b+4>>2]=2139062143;return}function Ffb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=a+b|0;mrc(a|0,-127|0,16)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(b+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=b<<1;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;e=a+d|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=a+(d+8)|0;c[e>>2]=-2122219135;c[e+4>>2]=-2122219135;e=d+b|0;d=a+e|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=a+(e+8)|0;c[d>>2]=-2122219135;c[d+4>>2]=-2122219135;d=e+b|0;b=a+d|0;c[b>>2]=-2122219135;c[b+4>>2]=-2122219135;b=a+(d+8)|0;c[b>>2]=-2122219135;c[b+4>>2]=-2122219135;return}function Gfb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=e;f=c[d>>2]|0;g=c[d+4>>2]|0;d=e+8|0;h=c[d>>2]|0;i=c[d+4>>2]|0;d=e+16|0;j=c[d>>2]|0;k=c[d+4>>2]|0;d=e+24|0;e=c[d>>2]|0;l=c[d+4>>2]|0;d=a;a=0;while(1){m=d;c[m>>2]=f;c[m+4>>2]=g;m=d+8|0;c[m>>2]=h;c[m+4>>2]=i;m=d+16|0;c[m>>2]=j;c[m+4>>2]=k;m=d+24|0;c[m>>2]=e;c[m+4>>2]=l;m=a+1|0;if((m|0)<32){d=d+b|0;a=m}else{break}}return}function Hfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;f=0;g=a;while(1){a=Erc(d[e+(31-f)|0]|0,0,16843009,16843009)|0;h=G;i=g;c[i>>2]=a;c[i+4>>2]=h;i=g+8|0;c[i>>2]=a;c[i+4>>2]=h;i=g+16|0;c[i>>2]=a;c[i+4>>2]=h;i=g+24|0;c[i>>2]=a;c[i+4>>2]=h;h=f+1|0;if((h|0)<32){f=h;g=g+b|0}else{break}}return}function Ifb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;g=(d[e]|0)+32+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[e+8|0]|0)+(d[e+9|0]|0)+(d[e+10|0]|0)+(d[e+11|0]|0)+(d[e+12|0]|0)+(d[e+13|0]|0)+(d[e+14|0]|0)+(d[e+15|0]|0)+(d[e+16|0]|0)+(d[e+17|0]|0)+(d[e+18|0]|0)+(d[e+19|0]|0)+(d[e+20|0]|0)+(d[e+21|0]|0)+(d[e+22|0]|0)+(d[e+23|0]|0)+(d[e+24|0]|0)+(d[e+25|0]|0)+(d[e+26|0]|0)+(d[e+27|0]|0)+(d[e+28|0]|0)+(d[e+29|0]|0)+(d[e+30|0]|0)+(d[e+31|0]|0)+(d[f]|0)+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)+(d[f+8|0]|0)+(d[f+9|0]|0)+(d[f+10|0]|0)+(d[f+11|0]|0)+(d[f+12|0]|0)+(d[f+13|0]|0)+(d[f+14|0]|0)+(d[f+15|0]|0)+(d[f+16|0]|0)+(d[f+17|0]|0)+(d[f+18|0]|0)+(d[f+19|0]|0)+(d[f+20|0]|0)+(d[f+21|0]|0)+(d[f+22|0]|0)+(d[f+23|0]|0)+(d[f+24|0]|0)+(d[f+25|0]|0)+(d[f+26|0]|0)+(d[f+27|0]|0)+(d[f+28|0]|0)+(d[f+29|0]|0)+(d[f+30|0]|0)+(d[f+31|0]|0)>>6;f=Erc(g,(g|0)<0|0?-1:0,16843009,16843009)|0;g=G;e=a;a=0;while(1){h=e;c[h>>2]=f;c[h+4>>2]=g;h=e+8|0;c[h>>2]=f;c[h+4>>2]=g;h=e+16|0;c[h>>2]=f;c[h+4>>2]=g;h=e+24|0;c[h>>2]=f;c[h+4>>2]=g;h=a+1|0;if((h|0)<32){e=e+b|0;a=h}else{break}}return}function Jfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+32|0;g=e|0;h=0;j=a[f]|0;k=a[f+1|0]|0;while(1){l=h+1|0;m=a[f+(h+2)|0]|0;a[g+h|0]=((j&255)+2+((k&255)<<1)+(m&255)|0)>>>2;if((l|0)<30){h=l;j=k;k=m}else{break}}k=f+31|0;a[g+30|0]=((d[f+30|0]|0)+2+((d[k]|0)*3|0)|0)>>>2;f=0;do{j=ca(f,c)|0;h=31-f|0;nrc(b+j|0,g+f|0,h)|0;f=f+1|0;mrc(b+(h+j)|0,a[k]|0,f|0)|0;}while((f|0)<32);i=e;return}function Kfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+64|0;h=g|0;j=a[f]|0;k=a[f+1|0]|0;l=0;m=a[e]|0;n=a[e+1|0]|0;o=j;p=k;while(1){q=l+1|0;r=l+2|0;s=a[e+r|0]|0;a[h+l|0]=((m&255)+2+((n&255)<<1)+(s&255)|0)>>>2;t=a[f+r|0]|0;a[h+(l+33)|0]=((o&255)+2+((p&255)<<1)+(t&255)|0)>>>2;if((q|0)<30){l=q;m=n;n=s;o=p;p=t}else{break}}p=d[e+31|0]|0;o=d[f-1|0]|0;a[h+30|0]=((d[e+30|0]|0)+2+(p<<1)+o|0)>>>2;e=j&255;a[h+31|0]=(p+2+(o<<1)+e|0)>>>2;a[h+32|0]=(o+2+(e<<1)+(k&255)|0)>>>2;k=0;do{nrc(b+(ca(k,c)|0)|0,h+(31-k)|0,32)|0;k=k+1|0;}while((k|0)<32);i=g;return}function Lfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+96|0;h=g|0;j=g+48|0;k=0;do{l=k<<1;m=d[e+(l+3)|0]|0;n=d[e+(l+2)|0]|0;a[j+k|0]=(m+2+(n<<1)+(d[e+(l|1)|0]|0)|0)>>>2;a[h+k|0]=((d[e+(l+4)|0]|0)+2+(m<<1)+n|0)>>>2;k=k+1|0;}while((k|0)<14);k=d[e+31|0]|0;n=d[e+30|0]|0;m=k+2|0;a[j+14|0]=(m+(n<<1)+(d[e+29|0]|0)|0)>>>2;e=a[f-1|0]|0;l=e&255;a[h+14|0]=(l+2+(k<<1)+n|0)>>>2;n=a[f]|0;k=n&255;a[h+15|0]=(l+1+k|0)>>>1;a[j+15|0]=(m+(l<<1)+k|0)>>>2;k=0;l=n;n=e;while(1){e=l&255;m=k+1|0;o=a[f+m|0]|0;p=o&255;q=k+16|0;a[h+q|0]=(e+1+p|0)>>>1;a[j+q|0]=((n&255)+2+(e<<1)+p|0)>>>2;if((m|0)<31){k=m;n=l;l=o}else{r=0;break}}do{l=r<<1;n=15-r|0;nrc(b+(ca(l,c)|0)|0,h+n|0,32)|0;nrc(b+(ca(l|1,c)|0)|0,j+n|0,32)|0;r=r+1|0;}while((r|0)<16);i=g;return}function Mfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+96|0;h=g|0;j=a[e]|0;k=a[f-1|0]|0;l=a[f]|0;m=0;n=a[e+1|0]|0;o=j;p=k;q=l;r=j;while(1){j=m+1|0;s=n&255;t=m<<1;a[h+t|0]=(s+1+(o&255)|0)>>>1;u=a[e+(m+2)|0]|0;a[h+(t|1)|0]=((u&255)+2+(s<<1)+(r&255)|0)>>>2;s=a[f+j|0]|0;a[h+(m+64)|0]=((p&255)+2+((q&255)<<1)+(s&255)|0)>>>2;if((j|0)>=30){break}m=j;o=n;n=u;p=q;q=s;r=a[e+j|0]|0}r=k&255;k=d[e+31|0]|0;a[h+62|0]=(r+1+k|0)>>>1;q=d[e+30|0]|0;a[h+60|0]=(k+1+q|0)>>>1;a[h+63|0]=((l&255)+2+(r<<1)+k|0)>>>2;a[h+61|0]=(r+2+(k<<1)+q|0)>>>2;q=0;do{nrc(b+(ca(q,c)|0)|0,h+(62-(q<<1))|0,32)|0;q=q+1|0;}while((q|0)<32);i=g;return}function Nfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+64|0;g=e|0;h=e+32|0;j=0;k=a[f]|0;l=a[f+1|0]|0;while(1){m=k&255;n=j+1|0;o=l&255;a[g+j|0]=(m+1+o|0)>>>1;p=a[f+(j+2)|0]|0;a[h+j|0]=(m+2+(o<<1)+(p&255)|0)>>>2;if((n|0)<30){j=n;k=l;l=p}else{break}}l=d[f+30|0]|0;k=f+31|0;f=d[k]|0;a[g+30|0]=(l+1+f|0)>>>1;a[h+30|0]=(l+2+(f*3|0)|0)>>>2;f=0;l=0;while(1){j=f<<1;p=ca(j,c)|0;n=32-f-1|0;nrc(b+p|0,g+f|0,n)|0;o=l+31|0;m=f+1|0;mrc(b+(o+p)|0,a[k]|0,m|0)|0;p=ca(j|1,c)|0;nrc(b+p|0,h+f|0,n)|0;mrc(b+(o+p)|0,a[k]|0,m|0)|0;p=~f;if((m|0)<16){f=m;l=p}else{break}}i=e;return}function Ofb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+64|0;g=f|0;h=0;do{j=32-h|0;k=d[e+(j-1)|0]|0;l=d[e+(j-2)|0]|0;m=h<<1;a[g+m|0]=(k+1+l|0)>>>1;a[g+(m|1)|0]=(k+2+(l<<1)+(d[e+(j-3)|0]|0)|0)>>>2;h=h+1|0;}while((h|0)<30);h=d[e+1|0]|0;j=d[e]|0;a[g+60|0]=(h+1+j|0)>>>1;a[g+61|0]=(h+2+(j*3|0)|0)>>>2;nrc(b|0,g|0,32)|0;nrc(b+c|0,g+2|0,32)|0;nrc(b+(c<<1)|0,g+4|0,32)|0;nrc(b+(c*3|0)|0,g+6|0,32)|0;nrc(b+(c<<2)|0,g+8|0,32)|0;nrc(b+(c*5|0)|0,g+10|0,32)|0;nrc(b+(c*6|0)|0,g+12|0,32)|0;nrc(b+(c*7|0)|0,g+14|0,32)|0;nrc(b+(c<<3)|0,g+16|0,32)|0;nrc(b+(c*9|0)|0,g+18|0,32)|0;nrc(b+(c*10|0)|0,g+20|0,32)|0;nrc(b+(c*11|0)|0,g+22|0,32)|0;nrc(b+(c*12|0)|0,g+24|0,32)|0;nrc(b+(c*13|0)|0,g+26|0,32)|0;nrc(b+(c*14|0)|0,g+28|0,32)|0;nrc(b+(c*15|0)|0,g+30|0,32)|0;j=16;do{h=ca(j,c)|0;l=j<<1;nrc(b+h|0,g+l|0,62-l|0)|0;mrc(b+(h+62-l)|0,a[e]|0,l-30|0)|0;j=j+1|0;}while((j|0)<32);i=f;return}function Pfb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;g=d[f-1|0]|0;h=f+1|0;i=f+2|0;j=f+3|0;k=f+4|0;l=f+5|0;m=f+6|0;n=f+7|0;o=f+8|0;p=f+9|0;q=f+10|0;r=f+11|0;s=f+12|0;t=f+13|0;u=f+14|0;v=f+15|0;w=f+16|0;x=f+17|0;y=f+18|0;z=f+19|0;A=f+20|0;B=f+21|0;C=f+22|0;D=f+23|0;E=f+24|0;F=f+25|0;G=f+26|0;H=f+27|0;I=f+28|0;J=f+29|0;K=f+30|0;L=f+31|0;M=0;N=b;while(1){b=(d[e+(31-M)|0]|0)-g|0;O=(d[f]|0)+b|0;if(O>>>0>255>>>0){P=-O>>31&255}else{P=O&255}a[N]=P;O=(d[h]|0)+b|0;if(O>>>0>255>>>0){Q=-O>>31&255}else{Q=O&255}a[N+1|0]=Q;O=(d[i]|0)+b|0;if(O>>>0>255>>>0){R=-O>>31&255}else{R=O&255}a[N+2|0]=R;O=(d[j]|0)+b|0;if(O>>>0>255>>>0){S=-O>>31&255}else{S=O&255}a[N+3|0]=S;O=(d[k]|0)+b|0;if(O>>>0>255>>>0){T=-O>>31&255}else{T=O&255}a[N+4|0]=T;O=(d[l]|0)+b|0;if(O>>>0>255>>>0){U=-O>>31&255}else{U=O&255}a[N+5|0]=U;O=(d[m]|0)+b|0;if(O>>>0>255>>>0){V=-O>>31&255}else{V=O&255}a[N+6|0]=V;O=(d[n]|0)+b|0;if(O>>>0>255>>>0){W=-O>>31&255}else{W=O&255}a[N+7|0]=W;O=(d[o]|0)+b|0;if(O>>>0>255>>>0){X=-O>>31&255}else{X=O&255}a[N+8|0]=X;O=(d[p]|0)+b|0;if(O>>>0>255>>>0){Y=-O>>31&255}else{Y=O&255}a[N+9|0]=Y;O=(d[q]|0)+b|0;if(O>>>0>255>>>0){Z=-O>>31&255}else{Z=O&255}a[N+10|0]=Z;O=(d[r]|0)+b|0;if(O>>>0>255>>>0){_=-O>>31&255}else{_=O&255}a[N+11|0]=_;O=(d[s]|0)+b|0;if(O>>>0>255>>>0){$=-O>>31&255}else{$=O&255}a[N+12|0]=$;O=(d[t]|0)+b|0;if(O>>>0>255>>>0){aa=-O>>31&255}else{aa=O&255}a[N+13|0]=aa;O=(d[u]|0)+b|0;if(O>>>0>255>>>0){ba=-O>>31&255}else{ba=O&255}a[N+14|0]=ba;O=(d[v]|0)+b|0;if(O>>>0>255>>>0){ca=-O>>31&255}else{ca=O&255}a[N+15|0]=ca;O=(d[w]|0)+b|0;if(O>>>0>255>>>0){da=-O>>31&255}else{da=O&255}a[N+16|0]=da;O=(d[x]|0)+b|0;if(O>>>0>255>>>0){ea=-O>>31&255}else{ea=O&255}a[N+17|0]=ea;O=(d[y]|0)+b|0;if(O>>>0>255>>>0){fa=-O>>31&255}else{fa=O&255}a[N+18|0]=fa;O=(d[z]|0)+b|0;if(O>>>0>255>>>0){ga=-O>>31&255}else{ga=O&255}a[N+19|0]=ga;O=(d[A]|0)+b|0;if(O>>>0>255>>>0){ha=-O>>31&255}else{ha=O&255}a[N+20|0]=ha;O=(d[B]|0)+b|0;if(O>>>0>255>>>0){ia=-O>>31&255}else{ia=O&255}a[N+21|0]=ia;O=(d[C]|0)+b|0;if(O>>>0>255>>>0){ja=-O>>31&255}else{ja=O&255}a[N+22|0]=ja;O=(d[D]|0)+b|0;if(O>>>0>255>>>0){ka=-O>>31&255}else{ka=O&255}a[N+23|0]=ka;O=(d[E]|0)+b|0;if(O>>>0>255>>>0){la=-O>>31&255}else{la=O&255}a[N+24|0]=la;O=(d[F]|0)+b|0;if(O>>>0>255>>>0){ma=-O>>31&255}else{ma=O&255}a[N+25|0]=ma;O=(d[G]|0)+b|0;if(O>>>0>255>>>0){na=-O>>31&255}else{na=O&255}a[N+26|0]=na;O=(d[H]|0)+b|0;if(O>>>0>255>>>0){oa=-O>>31&255}else{oa=O&255}a[N+27|0]=oa;O=(d[I]|0)+b|0;if(O>>>0>255>>>0){pa=-O>>31&255}else{pa=O&255}a[N+28|0]=pa;O=(d[J]|0)+b|0;if(O>>>0>255>>>0){qa=-O>>31&255}else{qa=O&255}a[N+29|0]=qa;O=(d[K]|0)+b|0;if(O>>>0>255>>>0){ra=-O>>31&255}else{ra=O&255}a[N+30|0]=ra;O=(d[L]|0)+b|0;if(O>>>0>255>>>0){sa=-O>>31&255}else{sa=O&255}a[N+31|0]=sa;O=M+1|0;if((O|0)<32){M=O;N=N+c|0}else{break}}return}function Qfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;f=(d[e]|0)+16+(d[e+1|0]|0)+(d[e+2|0]|0)+(d[e+3|0]|0)+(d[e+4|0]|0)+(d[e+5|0]|0)+(d[e+6|0]|0)+(d[e+7|0]|0)+(d[e+8|0]|0)+(d[e+9|0]|0)+(d[e+10|0]|0)+(d[e+11|0]|0)+(d[e+12|0]|0)+(d[e+13|0]|0)+(d[e+14|0]|0)+(d[e+15|0]|0)+(d[e+16|0]|0)+(d[e+17|0]|0)+(d[e+18|0]|0)+(d[e+19|0]|0)+(d[e+20|0]|0)+(d[e+21|0]|0)+(d[e+22|0]|0)+(d[e+23|0]|0)+(d[e+24|0]|0)+(d[e+25|0]|0)+(d[e+26|0]|0)+(d[e+27|0]|0)+(d[e+28|0]|0)+(d[e+29|0]|0)+(d[e+30|0]|0)+(d[e+31|0]|0)>>5;e=Erc(f,(f|0)<0|0?-1:0,16843009,16843009)|0;f=G;g=a;a=0;while(1){h=g;c[h>>2]=e;c[h+4>>2]=f;h=g+8|0;c[h>>2]=e;c[h+4>>2]=f;h=g+16|0;c[h>>2]=e;c[h+4>>2]=f;h=g+24|0;c[h>>2]=e;c[h+4>>2]=f;h=a+1|0;if((h|0)<32){g=g+b|0;a=h}else{break}}return}function Rfb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;e=(d[f]|0)+16+(d[f+1|0]|0)+(d[f+2|0]|0)+(d[f+3|0]|0)+(d[f+4|0]|0)+(d[f+5|0]|0)+(d[f+6|0]|0)+(d[f+7|0]|0)+(d[f+8|0]|0)+(d[f+9|0]|0)+(d[f+10|0]|0)+(d[f+11|0]|0)+(d[f+12|0]|0)+(d[f+13|0]|0)+(d[f+14|0]|0)+(d[f+15|0]|0)+(d[f+16|0]|0)+(d[f+17|0]|0)+(d[f+18|0]|0)+(d[f+19|0]|0)+(d[f+20|0]|0)+(d[f+21|0]|0)+(d[f+22|0]|0)+(d[f+23|0]|0)+(d[f+24|0]|0)+(d[f+25|0]|0)+(d[f+26|0]|0)+(d[f+27|0]|0)+(d[f+28|0]|0)+(d[f+29|0]|0)+(d[f+30|0]|0)+(d[f+31|0]|0)>>5;f=Erc(e,(e|0)<0|0?-1:0,16843009,16843009)|0;e=G;g=a;a=0;while(1){h=g;c[h>>2]=f;c[h+4>>2]=e;h=g+8|0;c[h>>2]=f;c[h+4>>2]=e;h=g+16|0;c[h>>2]=f;c[h+4>>2]=e;h=g+24|0;c[h>>2]=f;c[h+4>>2]=e;h=a+1|0;if((h|0)<32){g=g+b|0;a=h}else{break}}return}function Sfb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=a;a=0;while(1){c=a+1|0;mrc(d|0,-128|0,32)|0;if((c|0)<32){d=d+b|0;a=c}else{break}}return}function Tfb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=a;a=0;while(1){c=a+1|0;mrc(d|0,127,32)|0;if((c|0)<32){d=d+b|0;a=c}else{break}}return}function Ufb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=a;a=0;while(1){c=a+1|0;mrc(d|0,-127|0,32)|0;if((c|0)<32){d=d+b|0;a=c}else{break}}return}function Vfb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=c[b+60>>2]|0;g=f;c[g>>2]=b;c[b+140>>2]=11;if((c[b+100>>2]|0)!=42){KIb(b,16,2476408,(h=i,i=i+8|0,c[h>>2]=42,h)|0);i=h;j=-22;i=e;return j|0}k=c[b+96>>2]|0;l=d[k]|0;c[f+1056>>2]=l;if((l|0)==3){RIb(b,2467216,(h=i,i=i+8|0,c[h>>2]=3,h)|0);i=h;j=-1163346256;i=e;return j|0}else if((l|0)==1|(l|0)==2){m=k+6|0;n=(d[m]|d[m+1|0]<<8)<<16>>16&65535;m=f+1040|0;c[m>>2]=n;o=k+8|0;k=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=f+1044|0;c[o>>2]=k;p=b;q=tIb(n,k,0,p)|0;if((q|0)<0){c[o>>2]=0;c[m>>2]=0;j=q;i=e;return j|0}q=c[(c[g>>2]|0)+96>>2]|0;g=a[q+10|0]|0;k=f+1048|0;c[k>>2]=g&255;n=d[q+11|0]|0;r=f+1052|0;c[r>>2]=n;s=d[q+13|0]|0;c[f+1084>>2]=s;c[f+1088>>2]=s;if(!(g<<24>>24==4)){j=-1094995529;i=e;return j|0}if(!((n|0)==2|(n|0)==4)){j=-1094995529;i=e;return j|0}do{if((c[m>>2]&3|0)==0){if(((c[o>>2]|0)%(n|0)|0|0)!=0){break}g=f+1064|0;c[g>>2]=1048576;s=hJb(1048576)|0;q=f+1060|0;t=q;c[t>>2]=s;do{if((s|0)==0){u=f+1068|0}else{v=hJb(c[g>>2]|0)|0;w=f+1068|0;c[w>>2]=v;if((v|0)==0){u=w;break}v=ca(((c[m>>2]|0)/(c[k>>2]|0)|0)<<1,(c[o>>2]|0)/(c[r>>2]|0)|0)|0;c[f+1080>>2]=v;x=pJb(v)|0;c[f+1076>>2]=x;if((x|0)==0){u=w;break}if((c[r>>2]|0)==4){w=0;x=1044480;while(1){v=w&255;y=x|1;a[(c[t>>2]|0)+x|0]=v;a[(c[t>>2]|0)+y|0]=v;z=x|3;a[(c[t>>2]|0)+(y+1)|0]=v;a[(c[t>>2]|0)+z|0]=v;a[(c[t>>2]|0)+(z+1)|0]=v;a[(c[t>>2]|0)+(z+2)|0]=v;y=x|7;a[(c[t>>2]|0)+(z+3)|0]=v;a[(c[t>>2]|0)+y|0]=v;a[(c[t>>2]|0)+(y+1)|0]=v;a[(c[t>>2]|0)+(y+2)|0]=v;a[(c[t>>2]|0)+(y+3)|0]=v;a[(c[t>>2]|0)+(y+4)|0]=v;a[(c[t>>2]|0)+(y+5)|0]=v;a[(c[t>>2]|0)+(y+6)|0]=v;a[(c[t>>2]|0)+(y+7)|0]=v;a[(c[t>>2]|0)+(x|15)|0]=v;v=w+1|0;if((v|0)<256){w=v;x=x+16|0}else{break}}}else{x=0;w=30720;while(1){v=x&255;y=w|1;a[(c[t>>2]|0)+w|0]=v;a[(c[t>>2]|0)+y|0]=v;z=w|3;a[(c[t>>2]|0)+(y+1)|0]=v;a[(c[t>>2]|0)+z|0]=v;a[(c[t>>2]|0)+(z+1)|0]=v;a[(c[t>>2]|0)+(z+2)|0]=v;a[(c[t>>2]|0)+(z+3)|0]=v;a[(c[t>>2]|0)+(w|7)|0]=v;v=x+1|0;if((v|0)<256){x=v;w=w+8|0}else{break}}}c[f+1072>>2]=0;j=0;i=e;return j|0}}while(0);mJb(q);mJb(u);mJb(f+1076|0);j=-12;i=e;return j|0}}while(0);KIb(p,16,2440336,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1094995529;i=e;return j|0}else{QIb(b,2457392,(h=i,i=i+8|0,c[h>>2]=l,h)|0);i=h;j=-1163346256;i=e;return j|0}return 0}function Wfb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0;h=i;j=c[b+60>>2]|0;k=M4a(b,e,0)|0;if((k|0)<0){l=k;i=h;return l|0}k=j;b=c[g+24>>2]|0;m=g+28|0;g=c[m>>2]|0;if(!((g|0)>-1)){KIb(0,0,2513984,(n=i,i=i+24|0,c[n>>2]=2500296,c[n+8>>2]=2487616,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}o=j+4|0;c[o>>2]=b;p=j+12|0;c[p>>2]=b;q=b+g|0;r=j+8|0;c[r>>2]=q;s=j+1080|0;t=(c[s>>2]|0)/2|0;u=j;do{if(g>>>0>7>>>0){v=-1;w=-1;x=-1;y=-1;z=-1;A=-1;B=-1;C=b;D=q;E=b;while(1){F=C+4|0;c[o>>2]=F;G=C;H=je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0;G=F-E|0;I=C+8|0;c[o>>2]=I;J=F;F=je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0;if((H|0)==1129335898){K=B;L=G;M=z;N=y;O=x;P=w;Q=v;R=D;S=I}else if((H|0)==1448105050){K=G;L=A;M=z;N=y;O=x;P=w;Q=v;R=D;S=I}else if((H|0)==1129335856){K=B;L=A;M=G;N=y;O=x;P=w;Q=v;R=D;S=I}else if((H|0)==1128416816){K=B;L=A;M=z;N=y;O=x;P=w;Q=G;R=D;S=I}else if((H|0)==1128419376){K=B;L=A;M=z;N=y;O=G;P=w;Q=v;R=D;S=I}else if((H|0)==1128416858){K=B;L=A;M=z;N=y;O=x;P=G;Q=v;R=D;S=I}else if((H|0)==1128419418){K=B;L=A;M=z;N=G;O=x;P=w;Q=v;R=D;S=I}else{KIb(c[u>>2]|0,16,2441648,(n=i,i=i+40|0,c[n>>2]=H>>>24,c[n+8>>2]=H>>>16&255,c[n+16>>2]=H>>>8&255,c[n+24>>2]=H&255,c[n+32>>2]=H,n)|0);i=n;K=B;L=A;M=z;N=y;O=x;P=w;Q=v;R=c[r>>2]|0;S=c[o>>2]|0}H=(F&1)+F|0;T=R;F=T-S|0;I=S+(F>>>0>H>>>0?H:F)|0;c[o>>2]=I;if(!((T-I|0)>>>0>7>>>0)){break}v=Q;w=P;x=O;y=N;z=M;A=L;B=K;C=I;D=R;E=c[p>>2]|0}E=(M|0)!=-1;if(!((L|0)==-1|E^1)){KIb(c[u>>2]|0,16,2353552,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=-1094995529;i=h;return l|0}a:do{if(E){D=c[p>>2]|0;C=T-D|0;if((M|0)<0){U=0}else{U=(C|0)<(M|0)?C:M}C=D+U|0;c[o>>2]=C;if((T-C|0)<4){break}B=D+(U+4)|0;c[o>>2]=B;D=C;C=je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0;D=(C>>>0)/3|0;do{if(!(C>>>0>770>>>0)){if(C>>>0>(T-B|0)>>>0){break}if(C>>>0<3>>>0){break a}else{V=0;W=B}while(1){A=W+1|0;c[o>>2]=A;z=(d[W]|0)<<18;y=W+2|0;c[o>>2]=y;x=(d[A]|0)<<10;c[o>>2]=W+3;A=x&64512|z|(d[y]|0)<<2&252;c[k+16+(V<<2)>>2]=A|A>>>6&197379|-16777216;A=V+1|0;if(!(A>>>0<D>>>0)){break a}V=A;W=c[o>>2]|0}}}while(0);KIb(c[u>>2]|0,16,2291512,(n=i,i=i+8|0,c[n>>2]=D,n)|0);i=n;l=-1094995529;i=h;return l|0}}while(0);E=(Q|0)!=-1;B=(P|0)==-1;if(!(B|E^1)){KIb(c[u>>2]|0,16,2240720,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=-1094995529;i=h;return l|0}do{if(!B){C=c[p>>2]|0;A=c[r>>2]|0;y=A-C|0;if((P|0)<0){X=0}else{X=(y|0)<(P|0)?y:P}y=C+X|0;c[o>>2]=y;if((A-y|0)<4){Y=0}else{c[o>>2]=C+(X+4);C=y;Y=je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0}C=Yfb(k,Y,c[j+1060>>2]|0,c[j+1064>>2]|0,0)|0;if((C|0)<0){l=C}else{break}i=h;return l|0}}while(0);if(E){B=c[p>>2]|0;C=c[r>>2]|0;y=C-B|0;if((Q|0)<0){Z=0}else{Z=(y|0)<(Q|0)?y:Q}y=B+Z|0;c[o>>2]=y;do{if((C-y|0)<4){_=0;$=y}else{A=B+(Z+4)|0;c[o>>2]=A;z=y;x=je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0;if(!(x>>>0>1048576>>>0)){_=x;$=A;break}KIb(c[u>>2]|0,16,2199768,(n=i,i=i+8|0,c[n>>2]=x,n)|0);i=n;l=-1094995529;i=h;return l|0}}while(0);y=C-$|0;B=y>>>0>_>>>0?_:y;nrc(c[j+1060>>2]|0,$|0,B)|0;c[o>>2]=(c[o>>2]|0)+B}if((K|0)==-1){break}B=c[p>>2]|0;y=c[r>>2]|0;E=y-B|0;if((K|0)<0){aa=0}else{aa=(E|0)<(K|0)?E:K}E=B+aa|0;c[o>>2]=E;if((y-E|0)<4){ba=0}else{c[o>>2]=B+(aa+4);B=E;ba=je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0}B=j+1076|0;E=Yfb(k,ba,c[B>>2]|0,c[s>>2]|0,1)|0;if((E|0)<0){l=E;i=h;return l|0}E=j+1052|0;y=c[E>>2]|0;x=(y|0)==4?4:3;A=j+1044|0;z=c[A>>2]|0;if((z|0)>0){w=j+1040|0;v=e+32|0;I=j+1056|0;F=e;H=j+1060|0;G=0;J=0;da=0;ea=0;fa=t;ga=c[w>>2]|0;ha=y;y=z;while(1){if((ga|0)>0){z=0;ia=J;ja=da;ka=ea;la=fa;ma=c[v>>2]|0;while(1){na=z+(ca(ma,G)|0)|0;oa=c[I>>2]|0;do{if((oa|0)==3){pa=ja;qa=-1;ra=ma}else if((oa|0)==1){sa=ka<<1;ta=c[B>>2]|0;ua=a[ta+sa|0]|0;va=a[ta+(sa|1)|0]|0;sa=((va&255)<<8|ua&255)>>>3<<x;ta=c[E>>2]|0;if(!(va<<24>>24==-1)){wa=sa;xa=ta;ya=59;break}if((ta|0)==0){pa=sa;qa=-1;ra=ma;break}va=~ua;ua=ta;ta=na;while(1){za=ua-1|0;a[(c[F>>2]|0)+ta|0]=va;a[(c[F>>2]|0)+(ta+1)|0]=va;a[(c[F>>2]|0)+(ta+2)|0]=va;a[(c[F>>2]|0)+(ta+3)|0]=va;Aa=c[v>>2]|0;if((za|0)==0){pa=sa;qa=-1;ra=Aa;break}else{ua=za;ta=Aa+ta|0}}}else if((oa|0)==2){ta=c[B>>2]|0;wa=((d[ta+la|0]|0)<<8|(d[ta+ka|0]|0))<<x;xa=c[E>>2]|0;ya=59}else{wa=ja;xa=ia;ya=59}}while(0);do{if((ya|0)==59){ya=0;oa=xa-1|0;if((xa|0)==0){pa=wa;qa=oa;ra=ma;break}else{Ba=na;Ca=wa;Da=oa}while(1){a[(c[F>>2]|0)+Ba|0]=a[(c[H>>2]|0)+Ca|0]|0;a[(c[F>>2]|0)+(Ba+1)|0]=a[(c[H>>2]|0)+(Ca+1)|0]|0;a[(c[F>>2]|0)+(Ba+2)|0]=a[(c[H>>2]|0)+(Ca+2)|0]|0;a[(c[F>>2]|0)+(Ba+3)|0]=a[(c[H>>2]|0)+(Ca+3)|0]|0;Ea=c[v>>2]|0;if((Da|0)==0){break}else{Ba=Ea+Ba|0;Ca=Ca+4|0;Da=Da-1|0}}pa=wa+(xa<<2)|0;qa=-1;ra=Ea}}while(0);na=z+4|0;Fa=ka+1|0;Ga=la+1|0;Ha=c[w>>2]|0;if((na|0)<(Ha|0)){z=na;ia=qa;ja=pa;ka=Fa;la=Ga;ma=ra}else{break}}Ia=qa;Ja=pa;Ka=Fa;La=Ga;Ma=Ha;Na=c[E>>2]|0;Oa=c[A>>2]|0}else{Ia=J;Ja=da;Ka=ea;La=fa;Ma=ga;Na=ha;Oa=y}ma=Na+G|0;if((ma|0)<(Oa|0)){G=ma;J=Ia;da=Ja;ea=Ka;fa=La;ga=Ma;ha=Na;y=Oa}else{break}}}y=(O|0)!=-1;ha=(N|0)==-1;if(!(ha|y^1)){KIb(c[u>>2]|0,16,2141440,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=-1094995529;i=h;return l|0}do{if(y){ga=c[p>>2]|0;fa=c[r>>2]|0;ea=fa-ga|0;if((O|0)<0){Pa=0}else{Pa=(ea|0)<(O|0)?ea:O}ea=ga+Pa|0;c[o>>2]=ea;do{if((fa-ea|0)<4){da=j+1072|0;Qa=0;Ra=da;Sa=c[da>>2]|0;Ta=ea}else{da=ga+(Pa+4)|0;c[o>>2]=da;J=ea;G=je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0;J=j+1072|0;A=c[J>>2]|0;if(!(G>>>0>(1048576-A|0)>>>0)){Qa=G;Ra=J;Sa=A;Ta=da;break}KIb(c[u>>2]|0,16,2117872,(n=i,i=i+8|0,c[n>>2]=G,n)|0);i=n;l=-1094995529;i=h;return l|0}}while(0);ea=j+1068|0;ga=fa-Ta|0;G=ga>>>0>Qa>>>0?Qa:ga;nrc((c[ea>>2]|0)+Sa|0,Ta|0,G)|0;c[o>>2]=(c[o>>2]|0)+G;c[Ra>>2]=(c[Ra>>2]|0)+Qa;G=j+1084|0;ga=(c[G>>2]|0)-1|0;c[G>>2]=ga;if((ga|0)>=1){break}nrc(c[j+1060>>2]|0,c[ea>>2]|0,c[Ra>>2]|0)|0;c[Ra>>2]=0;c[G>>2]=c[j+1088>>2]}}while(0);do{if(!ha){y=c[p>>2]|0;G=c[r>>2]|0;ea=G-y|0;if((N|0)<0){Ua=0}else{Ua=(ea|0)<(N|0)?ea:N}ea=y+Ua|0;c[o>>2]=ea;do{if((G-ea|0)<4){ga=j+1072|0;Va=0;Wa=ga;Xa=c[ga>>2]|0;Ya=ea}else{ga=y+(Ua+4)|0;c[o>>2]=ga;da=ea;A=je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0;da=j+1072|0;J=c[da>>2]|0;if(!(A>>>0>(1048576-J|0)>>>0)){Va=A;Wa=da;Xa=J;Ya=ga;break}KIb(c[u>>2]|0,16,2635936,(n=i,i=i+8|0,c[n>>2]=A,n)|0);i=n;l=-1094995529;i=h;return l|0}}while(0);ea=j+1068|0;y=G-Ya|0;fa=y>>>0>Va>>>0?Va:y;nrc((c[ea>>2]|0)+Xa|0,Ya|0,fa)|0;c[o>>2]=(c[o>>2]|0)+fa;c[Wa>>2]=(c[Wa>>2]|0)+Va;fa=j+1084|0;y=(c[fa>>2]|0)-1|0;c[fa>>2]=y;if((y|0)>=1){break}y=c[ea>>2]|0;ea=c[Wa>>2]|0;if(!((ea|0)>-1)){KIb(0,0,2513984,(n=i,i=i+24|0,c[n>>2]=2500296,c[n+8>>2]=2487616,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}c[o>>2]=y;c[p>>2]=y;c[r>>2]=y+ea;ea=Yfb(k,c[Wa>>2]|0,c[j+1060>>2]|0,c[j+1064>>2]|0,0)|0;if((ea|0)<0){l=ea;i=h;return l|0}else{c[Wa>>2]=0;c[fa>>2]=c[j+1088>>2];break}}}while(0);nrc(c[e+4>>2]|0,j+16|0,1024)|0;c[e+304>>2]=1;c[f>>2]=1;l=c[m>>2]|0;i=h;return l|0}}while(0);KIb(c[u>>2]|0,16,2168096,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=-1094995529;i=h;return l|0}function Xfb(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+1060|0);mJb(b+1068|0);mJb(b+1076|0);return 0}function Yfb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=i;k=b+4|0;l=c[k>>2]|0;m=b+12|0;n=(c[m>>2]|0)-l|0;a:do{if((e|0)>0){o=b+8|0;p=0;q=l;b:while(1){r=c[o>>2]|0;if((r-q|0)<1){s=0;t=q}else{u=q+1|0;c[k>>2]=u;v=a[q]|0;if(v<<24>>24==-128){w=p;break a}else{s=v&255;t=u}}if((p|0)>=(g|0)){x=6;break}c:do{if((s|0)==254){if((r-t|0)<2){y=0;z=t}else{u=t+2|0;c[k>>2]=u;v=t;y=(d[v]|d[v+1|0]<<8)<<16>>16&65535;z=u}if((r-z|0)<1){A=0}else{c[k>>2]=z+1;A=a[z]|0}u=y+p|0;if((u|0)>(g|0)){x=23;break b}mrc(f+p|0,A|0,y|0)|0;B=u}else if((s|0)==255){if((r-t|0)<2){C=0;D=t}else{u=t+2|0;c[k>>2]=u;v=t;C=(d[v]|d[v+1|0]<<8)<<16>>16&65535;D=u}if((r-D|0)<2){E=0}else{c[k>>2]=D+2;u=D;E=(d[u]|d[u+1|0]<<8)<<16>>16&65535}u=C+p|0;if((u|0)>(g|0)){x=13;break b}if((E+C|0)>(g|0)){x=16;break b}if((C|0)==0){B=u;break}else{F=0}while(1){a[f+(F+p)|0]=a[f+(F+E)|0]|0;v=F+1|0;if((v|0)<(C|0)){F=v}else{B=u;break}}}else{if((s&192|0)==192){G=(s&63)+3|0;if((r-t|0)<2){H=0}else{c[k>>2]=t+2;u=t;H=(d[u]|d[u+1|0]<<8)<<16>>16&65535}u=G+p|0;if((u|0)>(g|0)){x=30;break b}if((H+G|0)>(g|0)){x=32;break b}else{I=0}while(1){a[f+(I+p)|0]=a[f+(I+H)|0]|0;v=I+1|0;if((v|0)<(G|0)){I=v}else{B=u;break c}}}if(s>>>0>128>>>0){J=s&63;u=J+p|0;if((u|0)>(g|0)){x=36;break b}v=r-t|0;K=v>>>0>J>>>0?J:v;nrc(f+p|0,t|0,K)|0;c[k>>2]=(c[k>>2]|0)+K;B=u;break}L=(s>>>4&7)+3|0;if((r-t|0)<1){M=0}else{c[k>>2]=t+1;M=d[t]|0}N=M|s<<8&3840;u=L+p|0;if((u|0)>(g|0)){x=41;break b}K=p-N|0;if((K|0)<0){x=44;break b}if((K+L|0)>(g|0)){x=44;break b}else{O=0}while(1){a[f+(O+p)|0]=a[f+(O+K)|0]|0;v=O+1|0;if((v|0)<(L|0)){O=v}else{B=u;break}}}}while(0);r=c[k>>2]|0;if((n+r-(c[m>>2]|0)|0)<(e|0)){p=B;q=r}else{w=B;break a}}if((x|0)==6){KIb(c[b>>2]|0,16,2612480,(P=i,i=i+16|0,c[P>>2]=p,c[P+8>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==13){q=b|0;KIb(c[q>>2]|0,16,2585776,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;KIb(c[q>>2]|0,16,2564896,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=C,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==16){q=b|0;KIb(c[q>>2]|0,16,2585776,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;KIb(c[q>>2]|0,16,2546808,(P=i,i=i+24|0,c[P>>2]=E,c[P+8>>2]=C,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==23){q=b|0;KIb(c[q>>2]|0,16,2585776,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;KIb(c[q>>2]|0,16,2564896,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=y,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==30){q=b|0;KIb(c[q>>2]|0,16,2585776,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;KIb(c[q>>2]|0,16,2564896,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=G,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==32){q=b|0;KIb(c[q>>2]|0,16,2585776,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;KIb(c[q>>2]|0,16,2546808,(P=i,i=i+24|0,c[P>>2]=H,c[P+8>>2]=G,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==36){q=b|0;KIb(c[q>>2]|0,16,2585776,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;KIb(c[q>>2]|0,16,2564896,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=J,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==41){q=b|0;KIb(c[q>>2]|0,16,2585776,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;KIb(c[q>>2]|0,16,2564896,(P=i,i=i+24|0,c[P>>2]=p,c[P+8>>2]=L,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}else if((x|0)==44){q=b|0;KIb(c[q>>2]|0,16,2585776,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;KIb(c[q>>2]|0,16,2546808,(P=i,i=i+24|0,c[P>>2]=N,c[P+8>>2]=L,c[P+16>>2]=g,P)|0);i=P;Q=-1094995529;i=j;return Q|0}}else{w=0}}while(0);if(!((h|0)!=0&(w|0)<(g|0))){Q=0;i=j;return Q|0}KIb(c[b>>2]|0,16,2529152,(P=i,i=i+16|0,c[P>>2]=w,c[P+8>>2]=g,P)|0);i=P;mrc(f+w|0,0,g-w|0)|0;Q=0;i=j;return Q|0}function Zfb(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+60>>2]=0;return 0}function _fb(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0;k=i;i=i+56|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+48|0;r=e+60|0;s=c[r>>2]|0;t=c[j+24>>2]|0;u=j+28|0;j=c[u>>2]|0;v=f;if((j|0)<33){w=-1094995529;i=k;return w|0}x=s+64|0;c[x>>2]=0;y=s+72|0;c[y>>2]=0;z=t+20|0;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;c[s+68>>2]=A;s=t+24|0;z=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;if((A-1|0)>>>0>131071>>>0){KIb(e,16,2441608,(B=i,i=i+8|0,c[B>>2]=A,B)|0);i=B;w=-1094995529;i=k;return w|0}do{if((z&128|0)==0){A=z&3;s=e+420|0;if(A>>>0<2>>>0){c[s>>2]=6;break}else{c[s>>2]=7;c[e+796>>2]=(A<<3)+8;break}}else{c[e+420>>2]=8}}while(0);z=q|0;A=p|0;s=p+4|0;C=p+8|0;D=e+420|0;E=e;F=e+416|0;H=e+448|0;I=q+1|0;J=q+2|0;K=q+3|0;q=e+412|0;L=f+76|0;M=f+64|0;f=e+696|0;N=j;j=t;a:while(1){t=j+4|0;O=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;P=O-12|0;t=j+20|0;Q=N-20|0;R=c[x>>2]|0;if((P|0)<1|(P|0)>(Q|0)){S=11;break}T=c[r>>2]|0;c[A>>2]=v;c[s>>2]=0;c[C>>2]=0;U=T+60|0;V=c[U>>2]|0;if((V|0)<=(R|0)){W=T;if((V|0)==14){S=18;break}V=pJb(1644)|0;c[W+4+(c[U>>2]<<2)>>2]=V;V=c[U>>2]|0;X=W+4+(V<<2)|0;if((c[X>>2]|0)==0){S=18;break}c[U>>2]=V+1;c[c[X>>2]>>2]=c[T>>2];V=c[X>>2]|0;c[V+1608>>2]=0;c[V+1640>>2]=-1;c[V+1624>>2]=-1}V=c[T+4+(R<<2)>>2]|0;if((V|0)==0){S=20;break}mrc(V+84|0,0,1408)|0;mrc(V+1552|0,0,56)|0;X=V+1504|0;U=V+1516|0;W=V+1512|0;Y=V+1508|0;Z=V+44|0;c[Z>>2]=0;mrc(X|0,0,16)|0;if(!((P|0)>-1)){S=22;break}_=j+(O+8)|0;O=_;$=t;if((P|0)<4){aa=0;ba=t}else{da=t;aa=d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0;ba=j+24|0}da=V+76|0;c[da>>2]=aa;ea=c[T+68>>2]|0;if((aa|0)!=(ea|0)){S=26;break}if((O-ba|0)<4){fa=0;ga=ba}else{t=ba;fa=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;ga=ba+4|0}t=V+4|0;c[t>>2]=fa;ha=QKb(c[D>>2]|0)|0;ia=c[t>>2]|0;ja=ia<<3&24;ka=(ia&6144|0)==6144;la=ia>>>2&1^1;ma=V+8|0;c[ma>>2]=la;na=V+12|0;c[na>>2]=(ia&1073741824|0)==0?la:0;la=V+16|0;c[la>>2]=ia&16;oa=V+1524|0;c[oa>>2]=ia&8;pa=V+1528|0;c[pa>>2]=ia&512;qa=V+1520|0;c[qa>>2]=(ha<<3)-8-ja+(ia>>>13&31);ia=ja|7;ja=yrc(1,0,ia|0)|0;ra=wrc(ja,G,-1,0)|0;ja=V+1532|0;c[ja>>2]=ra;ra=yrc(-1|0,-1|0,ia|0)|0;ia=V+1536|0;c[ia>>2]=ra;if((O-ga|0)<4){sa=0;ta=ga}else{ra=ga;sa=d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0;ta=ga+4|0}ra=V+20|0;c[ra>>2]=sa;if((_|0)==(ta|0)){S=212;break}ua=V+80|0;va=(ha|0)==4;wa=V+1540|0;xa=V+1544|0;ya=V+1548|0;za=V+1612|0;Aa=V+1616|0;Ba=V+24|0;Ca=V+36|0;Da=V+40|0;Ea=V+28|0;Fa=V+32|0;Ga=V+72|0;Ha=V+1628|0;Ia=V+1632|0;Ja=V+52|0;Ka=V+64|0;La=V+68|0;Ma=V+56|0;Na=V+60|0;Oa=V+48|0;Pa=ta;Qa=0;Ra=0;Sa=0;Ta=0;Ua=0;Va=0;Wa=0;Xa=0;Ya=0;Za=0;b:while(1){if((O-Pa|0)<1){_a=0;$a=Pa}else{_a=d[Pa]|0;$a=Pa+1|0}if((O-$a|0)<1){ab=0;bb=$a}else{ab=d[$a]|0;bb=$a+1|0}if((_a&128|0)==0){cb=ab;db=bb}else{if((O-bb|0)<1){eb=0;fb=bb}else{eb=(d[bb]|0)<<8;fb=bb+1|0}if((O-fb|0)<1){gb=0;hb=fb}else{gb=(d[fb]|0)<<16;hb=fb+1|0}cb=eb|ab|gb;db=hb}ib=cb<<1;jb=(_a&64|0)!=0;kb=ib+(jb<<31>>31)|0;if((kb|0)<0){S=44;break}lb=db;mb=O-lb|0;if(mb>>>0<ib>>>0){S=46;break}c:do{switch(_a&63|0){case 5:{nb=c[na>>2]|0;ob=(nb*6|0)+6|0;if((kb|0)!=(ob|0)){KIb(E,16,2564848,(B=i,i=i+16|0,c[B>>2]=ob,c[B+8>>2]=kb,B)|0);i=B;pb=Za;qb=Ya;rb=Xa;sb=Wa;tb=Va;ub=Ua;vb=Ta;wb=Sa;xb=Ra;yb=Qa;zb=db+(mb>>>0>ib>>>0?ib:mb)|0;break c}if((nb|0)<0){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=1;Hb=Sa;Ib=Ra;Jb=Qa;Kb=db;S=209;break c}else{Lb=db;Mb=0}while(1){if((O-Lb|0)<2){Nb=0;Ob=Lb}else{nb=Lb;Nb=(d[nb]|d[nb+1|0]<<8)<<16>>16;Ob=Lb+2|0}nb=Nb<<16>>16<0;ob=(nb?-Nb&65535:Nb)<<16>>16;Pb=d[110968+(ob&255)|0]|0|256;Qb=ob>>>8<<16;ob=Qb>>16;if((Qb|0)>589824){Rb=Pb<<ob-9}else{Rb=Pb>>>((9-ob|0)>>>0)}c[V+1552+(Mb*28|0)>>2]=nb?-Rb|0:Rb;if((O-Ob|0)<2){Sb=0;Tb=Ob}else{nb=Ob;Sb=(d[nb]|d[nb+1|0]<<8)<<16>>16;Tb=Ob+2|0}nb=Sb<<16>>16<0;ob=(nb?-Sb&65535:Sb)<<16>>16;Pb=d[110968+(ob&255)|0]|0|256;Qb=ob>>>8<<16;ob=Qb>>16;if((Qb|0)>589824){Ub=Pb<<ob-9}else{Ub=Pb>>>((9-ob|0)>>>0)}c[V+1552+(Mb*28|0)+4>>2]=nb?-Ub|0:Ub;if((O-Tb|0)<2){Vb=0;Wb=Tb}else{nb=Tb;Vb=(d[nb]|d[nb+1|0]<<8)<<16>>16;Wb=Tb+2|0}nb=Vb<<16>>16<0;ob=(nb?-Vb&65535:Vb)<<16>>16;Pb=d[110968+(ob&255)|0]|0|256;Qb=ob>>>8<<16;ob=Qb>>16;if((Qb|0)>589824){Xb=Pb<<ob-9}else{Xb=Pb>>>((9-ob|0)>>>0)}c[V+1552+(Mb*28|0)+8>>2]=nb?-Xb|0:Xb;nb=Mb+1|0;if((nb|0)>(c[na>>2]|0)){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=1;Hb=Sa;Ib=Ra;Jb=Qa;Kb=Wb;S=209;break}else{Lb=Wb;Mb=nb}}break};case 8:{if((kb|0)!=4){KIb(E,16,2529120,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;pb=Za;qb=Ya;rb=Xa;sb=Wa;tb=Va;ub=Ua;vb=Ta;wb=Sa;xb=Ra;yb=Qa;zb=db+(mb>>>0>ib>>>0?ib:mb)|0;break c}if((mb|0)<1){Yb=0;Zb=db}else{Yb=d[db]|0;Zb=db+1|0}c[wa>>2]=Yb;if((O-Zb|0)<1){_b=0;$b=Zb}else{_b=d[Zb]|0;$b=Zb+1|0}c[xa>>2]=_b;if((O-$b|0)<1){ac=0;bc=$b}else{ac=d[$b]|0;bc=$b+1|0}c[ya>>2]=ac;nb=O-bc|0;Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=1;Jb=Qa;Kb=bc+(nb>>>0>1>>>0?1:nb)|0;S=209;break};case 12:{if((kb|0)<5){KIb(E,16,2513952,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;pb=Za;qb=Ya;rb=Xa;sb=Wa;tb=Va;ub=Ua;vb=Ta;wb=Sa;xb=Ra;yb=Qa;zb=db+(mb>>>0>kb>>>0?kb:mb)|0;break c}c[Ha>>2]=lb-$;nb=kb<<3;c[Ia>>2]=nb;ob=kb>>>0>268435455>>>0?-8:nb;nb=ob>>>0>2147483639>>>0|(db|0)==0;Pb=nb?0:db;Qb=nb?0:ob;c[Ja>>2]=Pb;c[Ka>>2]=Qb;ob=Qb+8|0;c[La>>2]=ob;c[Ma>>2]=Pb+(Qb>>3);c[Na>>2]=0;if(nb){cc=nb?-1094995529:0;S=406;break b}nb=Pb;Qb=(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24)&65535;nb=ob>>>0>16>>>0?16:ob;c[Na>>2]=nb;dc=Pb+(nb>>>3)|0;Pb=d[dc]|d[dc+1|0]<<8|d[dc+2|0]<<16|d[dc+3|0]<<24|0;dc=nb+16|0;c[Na>>2]=ob>>>0>dc>>>0?dc:ob;c[Oa>>2]=Pb<<16|Qb;c[Z>>2]=1;Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=db+(mb>>>0>kb>>>0?kb:mb)|0;S=209;break};case 13:{if((kb|0)<2){S=187;break a}if((mb|0)<1){ec=0;fc=db}else{ec=d[db]|0;fc=db+1|0}switch(kb|0){case 2:{if((O-fc|0)<1){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=0;Fb=ec;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc;S=209;break c}Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=d[fc]|0;Fb=ec;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc+1|0;S=209;break c;break};case 7:{Qb=O-fc|0;Pb=Qb>>>0>1>>>0?1:Qb;Qb=fc+Pb|0;if((O-Qb|0)<1){gc=0;hc=Qb}else{gc=(d[Qb]|0)<<8&3840;hc=fc+(Pb+1)|0}Pb=gc|ec;if((O-hc|0)<2){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=0;Fb=Pb;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=hc;S=209;break c}Qb=hc;Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=(d[Qb]|d[Qb+1|0]<<8)<<16>>16&65535;Fb=Pb;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=hc+2|0;S=209;break c;break};case 5:{if((O-fc|0)<4){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=0;Fb=ec;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc;S=209;break c}Pb=fc;Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;Fb=ec;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc+4|0;S=209;break c;break};case 3:{if((O-fc|0)<2){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=0;Fb=ec;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc;S=209;break c}Pb=fc;Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=(d[Pb]|d[Pb+1|0]<<8)<<16>>16&65535;Fb=ec;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc+2|0;S=209;break c;break};case 4:{if((O-fc|0)<3){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=0;Fb=ec;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc;S=209;break c}Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=(d[fc+1|0]|0)<<8|(d[fc+2|0]|0)<<16|(d[fc]|0);Fb=ec;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc+3|0;S=209;break c;break};default:{KIb(E,16,2487584,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=c[H>>2]|0;Fb=c[F>>2]|0;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=fc;S=209;break c}}break};case 3:{if((Za|0)==0){KIb(E,16,2612368,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;pb=0;qb=Ya;rb=Xa;sb=Wa;tb=Va;ub=Ua;vb=Ta;wb=Sa;xb=Ra;yb=Qa;zb=db;break c}Pb=kb>>c[na>>2];do{if((Pb|0)<=16){if((Pb|0)>(c[ua>>2]|0)){break}if((Pb|0)>0){ic=db;jc=0;kc=0}else{Ab=Za;Bb=1;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=db;S=209;break c}while(1){do{if((O-ic|0)<1){Qb=kc-1|0;ob=(c[ua>>2]|0)+Qb|0;lc=0;mc=ic;nc=Qb;oc=ob;pc=V+84+(ob*88|0)+8|0}else{ob=ic+1|0;Qb=(d[ic]|0)<<24;dc=Qb>>21;nb=kc-1|0;qc=(c[ua>>2]|0)+nb|0;rc=V+84+(qc*88|0)+8|0;if((Qb|0)<=0){lc=dc;mc=ob;nc=nb;oc=qc;pc=rc;break}lc=(dc+64>>7)+dc|0;mc=ob;nc=nb;oc=qc;pc=rc}}while(0);c[pc>>2]=lc;do{if((c[na>>2]|0)==0){sc=mc}else{if((O-mc|0)<1){tc=0;uc=mc}else{tc=(d[mc]|0)<<24>>21;uc=mc+1|0}c[V+84+(oc*88|0)+12>>2]=tc;rc=V+84+(((c[ua>>2]|0)+nc|0)*88|0)+12|0;qc=c[rc>>2]|0;if((qc|0)<=0){sc=uc;break}c[rc>>2]=(qc+64>>7)+qc;sc=uc}}while(0);qc=jc+1|0;rc=~jc;if((qc|0)<(Pb|0)){ic=sc;jc=qc;kc=rc}else{Ab=Za;Bb=1;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=sc;S=209;break c}}}}while(0);KIb(E,16,2585720,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;pb=Za;qb=Ya;rb=Xa;sb=Wa;tb=Va;ub=Ua;vb=Ta;wb=Sa;xb=Ra;yb=Qa;zb=db+(mb>>>0>ib>>>0?ib:mb)|0;break};case 10:{c[za>>2]=lb-$;Pb=kb<<3;c[Aa>>2]=Pb;rc=kb>>>0>268435455>>>0?-8:Pb;qc=rc>>>0>2147483639>>>0|(db|0)==0;nb=qc?0:db;ob=qc?0:rc;c[Ba>>2]=nb;c[Ca>>2]=ob;c[Da>>2]=ob+8;c[Ea>>2]=nb+(ob>>3);c[Fa>>2]=0;if(qc){cc=qc?-1094995529:0;S=406;break b}c[Ga>>2]=Pb;Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=1;Ib=Ra;Jb=Qa;Kb=db+(mb>>>0>kb>>>0?kb:mb)|0;S=209;break};case 9:{if((kb|0)!=4){KIb(E,16,2546776,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;Pb=ib-4|0;pb=Za;qb=Ya;rb=Xa;sb=Wa;tb=Va;ub=Ua;vb=Ta;wb=Sa;xb=Ra;yb=Qa;zb=db+(mb>>>0>Pb>>>0?Pb:mb)|0;break c}Pb=mb>>>0>4>>>0?4:mb;nrc(z|0,db|0,Pb)|0;qc=db+Pb|0;Pb=a[z]|0;do{if(Pb<<24>>24==0){ob=a[I]|0;if(!(ob<<24>>24==0)){c[U>>2]=ob&255;break}ob=a[J]|0;if(!(ob<<24>>24==0)){c[W>>2]=1;c[Y>>2]=1;c[U>>2]=ob&255;break}ob=a[K]|0;if(ob<<24>>24==0){break}c[Y>>2]=1;c[U>>2]=ob&255}else{c[X>>2]=Pb&255}}while(0);if(!((c[oa>>2]|0)!=0&va)){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=qc;S=209;break c}Pb=c[qa>>2]|0;if((Pb|0)>=8){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=qc;S=209;break c}ob=c[U>>2]|0;if((ob|0)<=8){Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=qc;S=209;break c}c[qa>>2]=Pb+8;c[U>>2]=ob-8;c[ja>>2]=c[ja>>2]>>8;c[ia>>2]=c[ia>>2]>>8;Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=qc;S=209;break};case 2:{if((kb|0)>16){KIb(E,16,2635888,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;c[ua>>2]=0;pb=Za;qb=Ya;rb=Xa;sb=Wa;tb=Va;ub=Ua;vb=Ta;wb=Sa;xb=Ra;yb=Qa;zb=db+(mb>>>0>ib>>>0?ib:mb)|0;break c}c[ua>>2]=kb;if((kb|0)>0){vc=db;wc=0;xc=0;yc=kb}else{Ab=1;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=db;S=209;break c}while(1){if((O-vc|0)<1){zc=0;Ac=vc}else{zc=d[vc]|0;Ac=vc+1|0}ob=xc-1|0;c[V+84+((ob+yc|0)*88|0)+4>>2]=(zc&31)-5;Pb=c[ua>>2]|0;c[V+84+((Pb+ob|0)*88|0)>>2]=zc>>>5;ob=wc+1|0;nb=~wc;if((ob|0)<(Pb|0)){vc=Ac;wc=ob;xc=nb;yc=Pb}else{Ab=1;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=Ac;S=209;break}}break};case 4:{if((Za|0)==0){KIb(E,16,2612368,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;pb=0;qb=Ya;rb=Xa;sb=Wa;tb=Va;ub=Ua;vb=Ta;wb=Sa;xb=Ra;yb=Qa;zb=db;break c}qc=c[ua>>2]|0;if((qc|0)>0&(kb|0)>0){Bc=db;Cc=0;Dc=qc}else{Ab=Za;Bb=Ya;Cb=Xa;Db=1;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=db;S=209;break c}while(1){qc=Dc-1|0;Pb=V+84+(qc*88|0)+4|0;nb=c[Pb>>2]|0;do{if((nb|0)>8){if((O-Bc|0)<2){Ec=0;Fc=Bc}else{ob=Bc;Ec=(d[ob]|d[ob+1|0]<<8)<<16>>16;Fc=Bc+2|0}ob=Ec<<16>>16<0;rc=(ob?-Ec&65535:Ec)<<16>>16;dc=d[110968+(rc&255)|0]|0|256;Qb=rc>>>8<<16;rc=Qb>>16;if((Qb|0)>589824){Gc=dc<<rc-9}else{Gc=dc>>>((9-rc|0)>>>0)}c[V+84+(qc*88|0)+16>>2]=ob?-Gc|0:Gc;if((O-Fc|0)<2){Hc=0;Ic=Fc}else{ob=Fc;Hc=(d[ob]|d[ob+1|0]<<8)<<16>>16;Ic=Fc+2|0}ob=Hc<<16>>16<0;rc=(ob?-Hc&65535:Hc)<<16>>16;dc=d[110968+(rc&255)|0]|0|256;Qb=rc>>>8<<16;rc=Qb>>16;if((Qb|0)>589824){Jc=dc<<rc-9}else{Jc=dc>>>((9-rc|0)>>>0)}c[V+84+(qc*88|0)+20>>2]=ob?-Jc|0:Jc;if((c[na>>2]|0)==0){Kc=Cc;Lc=Ic}else{if((O-Ic|0)<2){Mc=0;Nc=Ic}else{ob=Ic;Mc=(d[ob]|d[ob+1|0]<<8)<<16>>16;Nc=Ic+2|0}ob=Mc<<16>>16<0;rc=(ob?-Mc&65535:Mc)<<16>>16;dc=d[110968+(rc&255)|0]|0|256;Qb=rc>>>8<<16;rc=Qb>>16;if((Qb|0)>589824){Oc=dc<<rc-9}else{Oc=dc>>>((9-rc|0)>>>0)}c[V+84+(qc*88|0)+48>>2]=ob?-Oc|0:Oc;if((O-Nc|0)<2){Pc=0;Qc=Nc}else{ob=Nc;Pc=(d[ob]|d[ob+1|0]<<8)<<16>>16;Qc=Nc+2|0}ob=Pc<<16>>16<0;rc=(ob?-Pc&65535:Pc)<<16>>16;dc=d[110968+(rc&255)|0]|0|256;Qb=rc>>>8<<16;rc=Qb>>16;if((Qb|0)>589824){Rc=dc<<rc-9}else{Rc=dc>>>((9-rc|0)>>>0)}c[V+84+(qc*88|0)+52>>2]=ob?-Rc|0:Rc;Kc=Cc+4|0;Lc=Qc}Sc=Kc+4|0;Tc=Lc}else{if((nb|0)<0){if((O-Bc|0)<2){Uc=0;Vc=Bc}else{ob=Bc;Uc=(d[ob]|d[ob+1|0]<<8)<<16>>16;Vc=Bc+2|0}ob=Uc<<16>>16<0;rc=(ob?-Uc&65535:Uc)<<16>>16;dc=d[110968+(rc&255)|0]|0|256;Qb=rc>>>8<<16;rc=Qb>>16;if((Qb|0)>589824){Wc=dc<<rc-9}else{Wc=dc>>>((9-rc|0)>>>0)}c[V+84+(qc*88|0)+16>>2]=ob?-Wc|0:Wc;if((O-Vc|0)<2){Xc=0;Yc=Vc}else{ob=Vc;Xc=(d[ob]|d[ob+1|0]<<8)<<16>>16;Yc=Vc+2|0}ob=Xc<<16>>16<0;rc=(ob?-Xc&65535:Xc)<<16>>16;dc=d[110968+(rc&255)|0]|0|256;Qb=rc>>>8<<16;rc=Qb>>16;if((Qb|0)>589824){Zc=dc<<rc-9}else{Zc=dc>>>((9-rc|0)>>>0)}c[V+84+(qc*88|0)+48>>2]=ob?-Zc|0:Zc;Sc=Cc+4|0;Tc=Yc;break}if((nb|0)>0){ob=Bc;rc=0;while(1){if((O-ob|0)<2){_c=0;$c=ob}else{dc=ob;_c=(d[dc]|d[dc+1|0]<<8)<<16>>16;$c=ob+2|0}dc=_c<<16>>16<0;Qb=(dc?-_c&65535:_c)<<16>>16;ad=d[110968+(Qb&255)|0]|0|256;bd=Qb>>>8<<16;Qb=bd>>16;if((bd|0)>589824){cd=ad<<Qb-9}else{cd=ad>>>((9-Qb|0)>>>0)}c[V+84+(qc*88|0)+16+(rc<<2)>>2]=dc?-cd|0:cd;if((c[na>>2]|0)==0){dd=$c}else{if((O-$c|0)<2){ed=0;fd=$c}else{dc=$c;ed=(d[dc]|d[dc+1|0]<<8)<<16>>16;fd=$c+2|0}dc=ed<<16>>16<0;Qb=(dc?-ed&65535:ed)<<16>>16;ad=d[110968+(Qb&255)|0]|0|256;bd=Qb>>>8<<16;Qb=bd>>16;if((bd|0)>589824){gd=ad<<Qb-9}else{gd=ad>>>((9-Qb|0)>>>0)}c[V+84+(qc*88|0)+48+(rc<<2)>>2]=dc?-gd|0:gd;dd=fd}dc=rc+1|0;hd=c[Pb>>2]|0;if((dc|0)<(hd|0)){ob=dd;rc=dc}else{break}}id=dd;jd=hd<<1}else{id=Bc;jd=0}Sc=(ca(jd,(c[na>>2]|0)+1|0)|0)+Cc|0;Tc=id}}while(0);if((qc|0)>0&(Sc|0)<(kb|0)){Bc=Tc;Cc=Sc;Dc=qc}else{Ab=Za;Bb=Ya;Cb=Xa;Db=1;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=Tc;S=209;break}}break};case 6:{Pb=c[na>>2]|0;if((c[pa>>2]|0)==0|(Pb|0)<0){kd=kb;ld=db;md=Pb}else{Pb=db;nb=0;rc=kb;while(1){if((O-Pb|0)<2){nd=0;od=Pb}else{ob=Pb;nd=(d[ob]|d[ob+1|0]<<8)<<16>>16;od=Pb+2|0}ob=nd<<16>>16<0;dc=(ob?-nd&65535:nd)<<16>>16;Qb=d[110968+(dc&255)|0]|0|256;ad=dc>>>8<<16;dc=ad>>16;if((ad|0)>589824){pd=Qb<<dc-9}else{pd=Qb>>>((9-dc|0)>>>0)}c[V+1552+(nb*28|0)+12>>2]=ob?-pd|0:pd;ob=rc-2|0;dc=nb+1|0;Qb=c[na>>2]|0;if((dc|0)>(Qb|0)){kd=ob;ld=od;md=Qb;break}else{Pb=od;nb=dc;rc=ob}}}if((md+1|0)>0){rc=ld;nb=0;Pb=kd;while(1){if((O-rc|0)<2){qd=0;rd=rc}else{ob=rc;qd=((d[ob]|d[ob+1|0]<<8)<<16>>16&65535)<<16;rd=rc+2|0}c[V+1552+(nb*28|0)+20>>2]=qd;ob=Pb-2|0;dc=nb+1|0;Qb=c[na>>2]|0;if((dc|0)<(Qb+1|0)){rc=rd;nb=dc;Pb=ob}else{sd=rd;td=ob;ud=Qb;break}}}else{sd=ld;td=kd;ud=md}Pb=(ud+1|0)>0;if((td|0)<=0){if(Pb){vd=0}else{Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=1;Kb=sd;S=209;break c}while(1){c[V+1552+(vd*28|0)+24>>2]=0;nb=vd+1|0;if((nb|0)<((c[na>>2]|0)+1|0)){vd=nb}else{Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=1;Kb=sd;S=209;break c}}}if(Pb){wd=sd;xd=0}else{Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=1;Kb=sd;S=209;break c}while(1){if((O-wd|0)<2){yd=0;zd=wd}else{nb=wd;yd=(d[nb]|d[nb+1|0]<<8)<<16>>16;zd=wd+2|0}nb=yd<<16>>16<0;rc=(nb?-yd&65535:yd)<<16>>16;Qb=d[110968+(rc&255)|0]|0|256;ob=rc>>>8<<16;rc=ob>>16;if((ob|0)>589824){Ad=Qb<<rc-9}else{Ad=Qb>>>((9-rc|0)>>>0)}c[V+1552+(xd*28|0)+24>>2]=nb?-Ad|0:Ad;nb=xd+1|0;if((nb|0)<((c[na>>2]|0)+1|0)){wd=zd;xd=nb}else{Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=1;Kb=zd;S=209;break}}break};case 39:{if((kb|0)!=3){S=205;break a}if((mb|0)<3){Ab=Za;Bb=Ya;Cb=0;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=db;S=209;break c}Ab=Za;Bb=Ya;Cb=(d[db+1|0]|0)<<8|(d[db+2|0]|0)<<16|(d[db]|0);Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=db+3|0;S=209;break};default:{Ab=Za;Bb=Ya;Cb=Xa;Db=Wa;Eb=Va;Fb=Ua;Gb=Ta;Hb=Sa;Ib=Ra;Jb=Qa;Kb=db+(mb>>>0>kb>>>0?kb:mb)|0;S=209}}}while(0);do{if((S|0)==209){S=0;if(!jb){pb=Ab;qb=Bb;rb=Cb;sb=Db;tb=Eb;ub=Fb;vb=Gb;wb=Hb;xb=Ib;yb=Jb;zb=Kb;break}mb=O-Kb|0;pb=Ab;qb=Bb;rb=Cb;sb=Db;tb=Eb;ub=Fb;vb=Gb;wb=Hb;xb=Ib;yb=Jb;zb=Kb+(mb>>>0>1>>>0?1:mb)|0}}while(0);if((_|0)==(zb|0)){Bd=yb;Cd=xb;Dd=wb;Ed=vb;Fd=ub;Gd=tb;Id=sb;Jd=rb;Kd=qb;Ld=pb;S=211;break}else{Pa=zb;Qa=yb;Ra=xb;Sa=wb;Ta=vb;Ua=ub;Va=tb;Wa=sb;Xa=rb;Ya=qb;Za=pb}}if((S|0)==44){S=0;KIb(E,16,2141376,(B=i,i=i+16|0,c[B>>2]=_a,c[B+8>>2]=kb,B)|0);i=B;Bd=Qa;Cd=Ra;Dd=Sa;Ed=Ta;Fd=Ua;Gd=Va;Id=Wa;Jd=Xa;Kd=Ya;Ld=Za;S=211}else if((S|0)==46){S=0;KIb(E,16,2117840,(B=i,i=i+8|0,c[B>>2]=kb,B)|0);i=B;Bd=Qa;Cd=Ra;Dd=Sa;Ed=Ta;Fd=Ua;Gd=Va;Id=Wa;Jd=Xa;Kd=Ya;Ld=Za;S=211}do{if((S|0)==211){S=0;if((Ld|0)==0){S=212;break a}if((Kd|0)==0){S=214;break a}if((Id|0)==0){S=216;break a}if((Ed|0)==0){S=218;break a}if((c[oa>>2]|0)!=0&(Bd|0)==0){S=220;break a}if((Dd|0)==0){S=222;break a}if((Cd|0)==0){if((c[D>>2]|0)==8){S=225;break a}}do{if((c[Z>>2]|0)!=0){if((c[D>>2]|0)==8){break}Pa=ca(c[X>>2]|0,c[da>>2]|0)|0;if(((c[Ka>>2]|0)-(c[Na>>2]|0)|0)>=(Pa<<c[na>>2]|0)){break}KIb(E,16,2395152,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;c[Z>>2]=0}}while(0);Pa=T+72|0;O=c[Pa>>2]|0;if((O|0)==0){pa=(c[t>>2]|0)>>>23&15;if((pa|0)==15){if((Jd|0)==0){S=233;break a}else{Md=Jd}}else{Md=c[109816+(pa<<2)>>2]|0}c[q>>2]=Md;do{if(ka){c[F>>2]=(c[ma>>2]|0)!=0?2:1;pa=(c[ma>>2]|0)!=0;c[H>>2]=pa?3:4;c[H+4>>2]=pa?0:0}else{if((Fd|0)!=0){c[F>>2]=Fd}if((Gd|0)==0){break}c[H>>2]=Gd;c[H+4>>2]=(Gd|0)<0|0?-1:0}}while(0);c[L>>2]=(c[da>>2]|0)+1;pa=J5a(e,p,0)|0;if((pa|0)<0){Nd=pa;break a}c[L>>2]=c[da>>2];Od=c[Pa>>2]|0}else{Od=O}pa=c[ma>>2]|0;if((pa+Od|0)>=(c[F>>2]|0)){KIb(E,24,2381008,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;cc=(c[f>>2]&8|0)!=0?-1094995529:0;S=406;break}va=c[M>>2]|0;Ga=c[va+(Od<<2)>>2]|0;Fa=Od+1|0;if((pa|0)==0){Pd=0}else{Pd=c[va+(Fa<<2)>>2]|0}c[Pa>>2]=Fa+pa;pa=V+24|0;Fa=c[D>>2]|0;if((c[na>>2]|0)==0){va=V+1608|0;Ea=c[va>>2]|0;Da=V+1624|0;Ca=c[Da>>2]|0;Ba=V+1640|0;c[o>>2]=c[Ba>>2];c[V+1500>>2]=0;c[V+1492>>2]=0;c[V+1496>>2]=0;Aa=(Fa|0)==6;$=(Fa|0)==8;za=(Fa|0)==7;Ma=Ga;Ia=Ga;Ha=Ga;ya=Ca;Ca=Ea;Ea=0;d:while(1){xa=bgb(V,pa,0,n)|0;if((c[n>>2]|0)!=0){Qd=ya;Rd=Ea;S=385;break}if((c[ua>>2]|0)>0){if(Aa){wa=xa;jb=0;while(1){mb=c[V+84+(jb*88|0)+4>>2]|0;if((mb|0)>8){ib=c[V+84+(jb*88|0)+16>>2]|0;if((mb&1|0)==0){Sd=(ib*3|0)-(c[V+84+(jb*88|0)+20>>2]|0)>>1}else{Sd=(ib<<1)-(c[V+84+(jb*88|0)+20>>2]|0)|0}c[V+84+(jb*88|0)+20>>2]=ib;Td=Sd;Ud=0}else{Td=c[V+84+(jb*88|0)+16+(Ca<<2)>>2]|0;Ud=mb+Ca&7}mb=V+84+(jb*88|0)+8|0;ib=c[mb>>2]|0;lb=((ca(ib,Td)|0)+512>>10)+wa|0;if(!((Td|0)==0|(wa|0)==0)){c[mb>>2]=ib-(ca(c[V+84+(jb*88|0)>>2]|0,((Td^wa)>>>30&2)-1|0)|0)}c[V+84+(jb*88|0)+16+(Ud<<2)>>2]=lb;ib=jb+1|0;if((ib|0)<(c[ua>>2]|0)){wa=lb;jb=ib}else{Vd=lb;break}}}else{jb=xa;wa=0;while(1){lb=c[V+84+(wa*88|0)+4>>2]|0;if((lb|0)>8){ib=c[V+84+(wa*88|0)+16>>2]|0;if((lb&1|0)==0){Wd=(ib*3|0)-(c[V+84+(wa*88|0)+20>>2]|0)>>1}else{Wd=(ib<<1)-(c[V+84+(wa*88|0)+20>>2]|0)|0}c[V+84+(wa*88|0)+20>>2]=ib;Xd=Wd;Yd=0}else{Xd=c[V+84+(wa*88|0)+16+(Ca<<2)>>2]|0;Yd=lb+Ca&7}lb=V+84+(wa*88|0)+8|0;ib=c[lb>>2]|0;mb=Erc(ib,(ib|0)<0|0?-1:0,Xd,(Xd|0)<0|0?-1:0)|0;Pb=wrc(mb,G,512,0)|0;mb=G;nb=wrc(Pb>>>10|mb<<22,mb>>>10|0<<22,jb,0)|0;mb=nb;if(!((Xd|0)==0|(jb|0)==0)){c[lb>>2]=ib-(ca(c[V+84+(wa*88|0)>>2]|0,((Xd^jb)>>>30&2)-1|0)|0)}c[V+84+(wa*88|0)+16+(Yd<<2)>>2]=mb;ib=wa+1|0;if((ib|0)<(c[ua>>2]|0)){jb=mb;wa=ib}else{Vd=mb;break}}}}else{Vd=0}wa=Ca+1&7;Zd=Vd+(ya*3|0)|0;do{if($){g[Ma>>2]=+cgb(V,o,Vd);_d=Ma+4|0;$d=Ha;S=381}else{jb=c[X>>2]|0;do{if((jb|0)==0){ae=Vd}else{xa=Vd<<jb;if((c[Z>>2]|0)==0){ae=xa;break}mb=c[Na>>2]|0;if(((c[Ka>>2]|0)-mb|0)<(jb|0)){ae=xa;break}ib=c[La>>2]|0;lb=(c[Ja>>2]|0)+(mb>>>3)|0;nb=32-jb|0;Pb=(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)>>>((mb&7)>>>0)<<nb>>>(nb>>>0);nb=mb+jb|0;c[Na>>2]=ib>>>0>nb>>>0?nb:ib;ib=Pb|xa;c[o>>2]=(ib>>>16)+((c[o>>2]|0)*9|0)+((ib&65535)*3|0);ae=ib}}while(0);jb=c[Y>>2]&ae|c[W>>2];qc=(jb+ae<<c[U>>2])-jb|0;do{if((c[oa>>2]|0)==0){be=qc}else{jb=c[ia>>2]|0;ib=c[ja>>2]|0;if((qc|0)<(jb|0)){be=jb;break}be=(qc|0)>(ib|0)?ib:qc}}while(0);qc=be<<c[qa>>2];if(za){c[Ia>>2]=qc;ib=Ea+1|0;if((c[n>>2]|0)==0){ce=Ha;de=Ia+4|0;ee=Ma;fe=ib;break}else{Qd=Zd;Rd=ib;S=385;break d}}else{b[Ha>>1]=qc;_d=Ma;$d=Ha+2|0;S=381;break}}}while(0);if((S|0)==381){S=0;ce=$d;de=Ia;ee=_d;fe=Ea+1|0}if((fe|0)<(c[da>>2]|0)){Ma=ee;Ia=de;Ha=ce;ya=Zd;Ca=wa;Ea=fe}else{S=384;break}}do{if((S|0)==384){S=0;c[va>>2]=0;c[Ba>>2]=-1;c[Da>>2]=-1;ge=Zd}else if((S|0)==385){S=0;c[va>>2]=0;c[Ba>>2]=-1;c[Da>>2]=-1;if((Rd|0)>=(c[da>>2]|0)){ge=Qd;break}Ea=QKb(Fa)|0;Ca=Ga+(ca(Ea,Rd)|0)|0;mrc(Ca|0,0,ca((c[da>>2]|0)-Rd|0,Ea)|0)|0;ge=Qd}}while(0);Da=V|0;Ba=c[Da>>2]|0;do{if((c[Ba+696>>2]&1|0)!=0){va=c[o>>2]|0;if((c[ra>>2]|0)==(ge|0)){if((c[Z>>2]|0)==0){break}if((c[Oa>>2]|0)==(va|0)){break}KIb(Ba,16,2367472,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}else{KIb(Ba,16,2374656,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B}if((c[(c[Da>>2]|0)+696>>2]&8|0)!=0){Nd=-1094995529;break a}}}while(0);if((c[ma>>2]|0)==0){break}nrc(Pd|0,Ga|0,ca(c[da>>2]|0,ha)|0)|0;break}Da=V+1608|0;Ba=c[Da>>2]|0;va=V+1624|0;Ea=c[va>>2]|0;Ca=V+1640|0;c[m>>2]=c[Ca>>2];c[V+1500>>2]=0;c[V+1492>>2]=0;c[V+1496>>2]=0;ya=(Fa|0)==8;Ha=(Fa|0)==7;Ia=(Fa|0)==6;Ma=(Fa|0)!=6;za=Pd;$=Ga;Aa=Pd;Pa=Ga;O=Pd;qc=Ga;ib=Ea;Ea=Ba;Ba=0;e:while(1){jb=bgb(V,pa,0,l)|0;if((c[l>>2]|0)!=0){he=ib;ie=Ba;S=340;break}xa=bgb(V,pa,1,l)|0;if((c[l>>2]|0)!=0){he=ib;ie=Ba;S=340;break}if((c[ua>>2]|0)>0){Pb=0;nb=jb;mb=xa;while(1){lb=V+84+(Pb*88|0)|0;rc=c[V+84+(Pb*88|0)+4>>2]|0;do{if((rc|0)>0){if((rc|0)>8){Qb=c[V+84+(Pb*88|0)+16>>2]|0;if((rc&1|0)==0){ob=c[V+84+(Pb*88|0)+48>>2]|0;je=(ob*3|0)-(c[V+84+(Pb*88|0)+52>>2]|0)>>1;ke=(Qb*3|0)-(c[V+84+(Pb*88|0)+20>>2]|0)>>1;le=ob}else{ob=c[V+84+(Pb*88|0)+48>>2]|0;je=(ob<<1)-(c[V+84+(Pb*88|0)+52>>2]|0)|0;ke=(Qb<<1)-(c[V+84+(Pb*88|0)+20>>2]|0)|0;le=ob}c[V+84+(Pb*88|0)+20>>2]=Qb;c[V+84+(Pb*88|0)+52>>2]=le;me=je;ne=ke;oe=0}else{me=c[V+84+(Pb*88|0)+48+(Ea<<2)>>2]|0;ne=c[V+84+(Pb*88|0)+16+(Ea<<2)>>2]|0;oe=rc+Ea&7}if(Ia){Qb=c[V+84+(Pb*88|0)+8>>2]|0;ob=((ca(Qb,ne)|0)+512>>10)+nb|0;dc=c[V+84+(Pb*88|0)+12>>2]|0;pe=((ca(dc,me)|0)+512>>10)+mb|0;qe=ob;re=dc;se=Qb}else{Qb=c[V+84+(Pb*88|0)+8>>2]|0;dc=Erc(Qb,(Qb|0)<0|0?-1:0,ne,(ne|0)<0|0?-1:0)|0;ob=wrc(dc,G,512,0)|0;dc=G;ad=wrc(ob>>>10|dc<<22,dc>>>10|0<<22,nb,0)|0;dc=c[V+84+(Pb*88|0)+12>>2]|0;ob=Erc(dc,(dc|0)<0|0?-1:0,me,(me|0)<0|0?-1:0)|0;bd=wrc(ob,G,512,0)|0;ob=G;te=wrc(bd>>>10|ob<<22,ob>>>10|0<<22,mb,0)|0;pe=te;qe=ad;re=dc;se=Qb}if(!((ne|0)==0|(nb|0)==0)){c[V+84+(Pb*88|0)+8>>2]=se-(ca(c[lb>>2]|0,((ne^nb)>>>30&2)-1|0)|0)}if(!((me|0)==0|(mb|0)==0)){c[V+84+(Pb*88|0)+12>>2]=re-(ca(c[lb>>2]|0,((me^mb)>>>30&2)-1|0)|0)}c[V+84+(Pb*88|0)+16+(oe<<2)>>2]=qe;c[V+84+(Pb*88|0)+48+(oe<<2)>>2]=pe;ue=pe;ve=qe}else{if((rc|0)==-1){if(Ma){Qb=c[V+84+(Pb*88|0)+8>>2]|0;dc=c[V+84+(Pb*88|0)+16>>2]|0;ad=Erc(dc,(dc|0)<0|0?-1:0,Qb,(Qb|0)<0|0?-1:0)|0;te=wrc(ad,G,512,0)|0;ad=G;ob=wrc(te>>>10|ad<<22,ad>>>10|0<<22,nb,0)|0;we=ob;xe=dc;ye=Qb}else{Qb=c[V+84+(Pb*88|0)+8>>2]|0;dc=c[V+84+(Pb*88|0)+16>>2]|0;we=((ca(dc,Qb)|0)+512>>10)+nb|0;xe=dc;ye=Qb}Qb=V+84+(Pb*88|0)+16|0;do{if(!((xe|0)==0|(nb|0)==0)){dc=c[lb>>2]|0;ob=V+84+(Pb*88|0)+8|0;if((xe^nb|0)<0){ad=ye-dc|0;c[ob>>2]=ad;if(!((ad|0)<-1024)){break}c[ob>>2]=-1024;break}else{ad=dc+ye|0;c[ob>>2]=ad;if((ad|0)<=1024){break}c[ob>>2]=1024;break}}}while(0);if(Ma){ob=c[V+84+(Pb*88|0)+12>>2]|0;ad=Erc(ob,(ob|0)<0|0?-1:0,we,(we|0)<0|0?-1:0)|0;dc=wrc(ad,G,512,0)|0;ad=G;te=wrc(dc>>>10|ad<<22,ad>>>10|0<<22,mb,0)|0;ze=te;Ae=ob}else{ob=c[V+84+(Pb*88|0)+12>>2]|0;ze=((ca(ob,we)|0)+512>>10)+mb|0;Ae=ob}do{if(!((we|0)==0|(mb|0)==0)){ob=c[lb>>2]|0;te=V+84+(Pb*88|0)+12|0;if((we^mb|0)<0){ad=Ae-ob|0;c[te>>2]=ad;if(!((ad|0)<-1024)){break}c[te>>2]=-1024;break}else{ad=ob+Ae|0;c[te>>2]=ad;if((ad|0)<=1024){break}c[te>>2]=1024;break}}}while(0);c[Qb>>2]=ze;ue=ze;ve=we;break}if(Ma){te=c[V+84+(Pb*88|0)+12>>2]|0;ad=c[V+84+(Pb*88|0)+48>>2]|0;ob=Erc(ad,(ad|0)<0|0?-1:0,te,(te|0)<0|0?-1:0)|0;dc=wrc(ob,G,512,0)|0;ob=G;bd=wrc(dc>>>10|ob<<22,ob>>>10|0<<22,mb,0)|0;Be=bd;Ce=ad;De=te}else{te=c[V+84+(Pb*88|0)+12>>2]|0;ad=c[V+84+(Pb*88|0)+48>>2]|0;Be=((ca(ad,te)|0)+512>>10)+mb|0;Ce=ad;De=te}te=V+84+(Pb*88|0)+48|0;do{if(!((Ce|0)==0|(mb|0)==0)){ad=c[lb>>2]|0;bd=V+84+(Pb*88|0)+12|0;if((Ce^mb|0)<0){ob=De-ad|0;c[bd>>2]=ob;if(!((ob|0)<-1024)){break}c[bd>>2]=-1024;break}else{ob=ad+De|0;c[bd>>2]=ob;if((ob|0)<=1024){break}c[bd>>2]=1024;break}}}while(0);if((rc|0)==-3){Qb=V+84+(Pb*88|0)+16|0;bd=c[Qb>>2]|0;c[Qb>>2]=Be;Ee=bd}else{Ee=Be}if(Ma){bd=c[V+84+(Pb*88|0)+8>>2]|0;Qb=Erc(bd,(bd|0)<0|0?-1:0,Ee,(Ee|0)<0|0?-1:0)|0;ob=wrc(Qb,G,512,0)|0;Qb=G;ad=wrc(ob>>>10|Qb<<22,Qb>>>10|0<<22,nb,0)|0;Fe=ad;Ge=bd}else{bd=c[V+84+(Pb*88|0)+8>>2]|0;Fe=((ca(bd,Ee)|0)+512>>10)+nb|0;Ge=bd}do{if(!((Ee|0)==0|(nb|0)==0)){bd=c[lb>>2]|0;ad=V+84+(Pb*88|0)+8|0;if((Ee^nb|0)<0){Qb=Ge-bd|0;c[ad>>2]=Qb;if(!((Qb|0)<-1024)){break}c[ad>>2]=-1024;break}else{Qb=bd+Ge|0;c[ad>>2]=Qb;if((Qb|0)<=1024){break}c[ad>>2]=1024;break}}}while(0);c[te>>2]=Fe;ue=Be;ve=Fe}}while(0);lb=Pb+1|0;if((lb|0)<(c[ua>>2]|0)){Pb=lb;nb=ve;mb=ue}else{He=ve;Ie=ue;break}}}else{He=jb;Ie=xa}mb=Ea+1&7;if((c[la>>2]|0)==0){Je=Ie;Ke=He}else{nb=Ie-(He>>1)|0;Je=nb;Ke=nb+He|0}Le=((Ke+(ib*3|0)|0)*3|0)+Je|0;do{if(ya){g[$>>2]=+cgb(V,m,Ke);g[za>>2]=+cgb(V,m,Je);Me=za+4|0;Ne=$+4|0;Oe=O;Pe=qc;S=336}else{nb=c[X>>2]|0;Pb=(nb|0)==0;do{if(Pb){Qe=Ke}else{wa=Ke<<nb;if((c[Z>>2]|0)==0){Qe=wa;break}lb=c[Na>>2]|0;if(((c[Ka>>2]|0)-lb|0)<(nb|0)){Qe=wa;break}rc=c[La>>2]|0;ad=(c[Ja>>2]|0)+(lb>>>3)|0;Qb=32-nb|0;bd=(d[ad]|d[ad+1|0]<<8|d[ad+2|0]<<16|d[ad+3|0]<<24|0)>>>((lb&7)>>>0)<<Qb>>>(Qb>>>0);Qb=lb+nb|0;c[Na>>2]=rc>>>0>Qb>>>0?Qb:rc;rc=bd|wa;c[m>>2]=(rc>>>16)+((c[m>>2]|0)*9|0)+((rc&65535)*3|0);Qe=rc}}while(0);rc=c[Y>>2]|0;wa=c[W>>2]|0;bd=rc&Qe|wa;Qb=c[U>>2]|0;lb=(bd+Qe<<Qb)-bd|0;bd=(c[oa>>2]|0)==0;do{if(bd){Re=lb}else{ad=c[ia>>2]|0;ob=c[ja>>2]|0;if((lb|0)<(ad|0)){Re=ad;break}Re=(lb|0)>(ob|0)?ob:lb}}while(0);lb=c[qa>>2]|0;ob=Re<<lb;if(Ha){ad=Pa+4|0;c[Pa>>2]=ob;dc=c[X>>2]|0;do{if((dc|0)==0){Se=Je}else{Te=Je<<dc;if((c[Z>>2]|0)==0){Se=Te;break}Ue=c[Na>>2]|0;if(((c[Ka>>2]|0)-Ue|0)<(dc|0)){Se=Te;break}Ve=c[La>>2]|0;We=(c[Ja>>2]|0)+(Ue>>>3)|0;Xe=32-dc|0;Ye=(d[We]|d[We+1|0]<<8|d[We+2|0]<<16|d[We+3|0]<<24|0)>>>((Ue&7)>>>0)<<Xe>>>(Xe>>>0);Xe=Ue+dc|0;c[Na>>2]=Ve>>>0>Xe>>>0?Xe:Ve;Ve=Ye|Te;c[m>>2]=(Ve>>>16)+((c[m>>2]|0)*9|0)+((Ve&65535)*3|0);Se=Ve}}while(0);dc=c[Y>>2]&Se|c[W>>2];Ve=(dc+Se<<c[U>>2])-dc|0;do{if((c[oa>>2]|0)==0){Ze=Ve}else{dc=c[ia>>2]|0;Te=c[ja>>2]|0;if((Ve|0)<(dc|0)){Ze=dc;break}Ze=(Ve|0)>(Te|0)?Te:Ve}}while(0);c[Aa>>2]=Ze<<c[qa>>2];Ve=Ba+1|0;if((c[l>>2]|0)==0){_e=qc;$e=O;af=ad;bf=Aa+4|0;cf=$;df=za;ef=Ve;break}else{he=Le;ie=Ve;S=340;break e}}else{Ve=qc+2|0;b[qc>>1]=ob;do{if(Pb){ff=Je}else{Te=Je<<nb;if((c[Z>>2]|0)==0){ff=Te;break}dc=c[Na>>2]|0;if(((c[Ka>>2]|0)-dc|0)<(nb|0)){ff=Te;break}Ye=c[La>>2]|0;Xe=(c[Ja>>2]|0)+(dc>>>3)|0;Ue=32-nb|0;We=(d[Xe]|d[Xe+1|0]<<8|d[Xe+2|0]<<16|d[Xe+3|0]<<24|0)>>>((dc&7)>>>0)<<Ue>>>(Ue>>>0);Ue=dc+nb|0;c[Na>>2]=Ye>>>0>Ue>>>0?Ue:Ye;Ye=We|Te;c[m>>2]=(Ye>>>16)+((c[m>>2]|0)*9|0)+((Ye&65535)*3|0);ff=Ye}}while(0);nb=ff&rc|wa;Pb=(nb+ff<<Qb)-nb|0;do{if(bd){gf=Pb}else{nb=c[ia>>2]|0;ob=c[ja>>2]|0;if((Pb|0)<(nb|0)){gf=nb;break}gf=(Pb|0)>(ob|0)?ob:Pb}}while(0);b[O>>1]=gf<<lb;Me=za;Ne=$;Oe=O+2|0;Pe=Ve;S=336;break}}}while(0);if((S|0)==336){S=0;_e=Pe;$e=Oe;af=Pa;bf=Aa;cf=Ne;df=Me;ef=Ba+1|0}if((ef|0)<(c[da>>2]|0)){za=df;$=cf;Aa=bf;Pa=af;O=$e;qc=_e;ib=Le;Ea=mb;Ba=ef}else{S=339;break}}do{if((S|0)==339){S=0;c[Da>>2]=0;c[Ca>>2]=-1;c[va>>2]=-1;hf=Le}else if((S|0)==340){S=0;c[Da>>2]=0;c[Ca>>2]=-1;c[va>>2]=-1;if((ie|0)>=(c[da>>2]|0)){hf=he;break}Ba=QKb(Fa)|0;Ea=ca(Ba,ie)|0;mrc(Ga+Ea|0,0,ca((c[da>>2]|0)-ie|0,Ba)|0)|0;mrc(Pd+Ea|0,0,ca((c[da>>2]|0)-ie|0,Ba)|0)|0;hf=he}}while(0);jf=c[V>>2]|0;if((c[jf+696>>2]&1|0)==0){break}if((c[ra>>2]|0)!=(hf|0)){S=344;break a}if((c[Z>>2]|0)==0){break}if((c[Oa>>2]|0)!=(c[m>>2]|0)){S=347;break a}}}while(0);if((S|0)==406){S=0;if((cc|0)<0){Nd=cc;break}}c[x>>2]=(c[x>>2]|0)+1;Oa=Q-P|0;if((Oa|0)<33){S=411;break}else{N=Oa;j=_}}if((S|0)==11){KIb(E,16,2353496,(B=i,i=i+24|0,c[B>>2]=R,c[B+8>>2]=P,c[B+16>>2]=Q,B)|0);i=B;Q=c[r>>2]|0;P=Q+60|0;if((c[P>>2]|0)<=0){w=-1094995529;i=k;return w|0}j=Q+4|0;Q=0;while(1){N=c[j+(Q<<2)>>2]|0;c[N+1608>>2]=0;c[N+1640>>2]=-1;c[N+1624>>2]=-1;N=Q+1|0;if((N|0)<(c[P>>2]|0)){Q=N}else{w=-1094995529;break}}i=k;return w|0}else if((S|0)==18){KIb(E,16,2240672,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==20){KIb(E,16,2199632,(B=i,i=i+8|0,c[B>>2]=R,B)|0);i=B;Nd=-1094995529}else if((S|0)==22){KIb(0,0,2344544,(B=i,i=i+24|0,c[B>>2]=2338552,c[B+8>>2]=2332896,c[B+16>>2]=135,B)|0);i=B;Hd();return 0}else if((S|0)==26){KIb(E,16,2168032,(B=i,i=i+16|0,c[B>>2]=ea,c[B+8>>2]=aa,B)|0);i=B;Nd=-1094995529}else if((S|0)==187){KIb(E,16,2500256,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==205){KIb(E,16,2476376,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==212){KIb(E,16,2467176,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==214){KIb(E,16,2457352,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==216){KIb(E,16,2440296,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==218){KIb(E,16,2429072,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==220){KIb(E,16,2418544,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==222){KIb(E,16,2409600,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==225){KIb(E,16,2401872,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==233){KIb(E,16,2387992,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==344){KIb(jf,16,2374656,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==347){KIb(jf,16,2367472,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;Nd=-1094995529}else if((S|0)==411){if((c[y>>2]|0)==(c[F>>2]|0)){c[h>>2]=1;w=c[u>>2]|0;i=k;return w|0}else{KIb(e,16,2291400,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;w=-1094995529;i=k;return w|0}}B=c[r>>2]|0;r=B+60|0;if((c[r>>2]|0)<=0){w=Nd;i=k;return w|0}e=B+4|0;B=0;while(1){u=c[e+(B<<2)>>2]|0;c[u+1608>>2]=0;c[u+1640>>2]=-1;c[u+1624>>2]=-1;u=B+1|0;if((u|0)<(c[r>>2]|0)){B=u}else{w=Nd;break}}i=k;return w|0}function $fb(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;a=b+60|0;if((c[a>>2]|0)<=0){c[a>>2]=0;return 0}d=b+4|0;b=0;do{mJb(d+(b<<2)|0);b=b+1|0;}while((b|0)<(c[a>>2]|0));c[a>>2]=0;return 0}function agb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b+60|0;if((c[a>>2]|0)<=0){return}d=b+4|0;b=0;do{e=c[d+(b<<2)>>2]|0;c[e+1608>>2]=0;c[e+1640>>2]=-1;c[e+1624>>2]=-1;b=b+1|0;}while((b|0)<(c[a>>2]|0));return}function bgb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=a+1552|0;l=a+1552+(e*28|0)|0;c[f>>2]=0;a:do{if((c[k>>2]|0)>>>0<2>>>0){m=a+1580|0;if(!((c[m>>2]|0)>>>0<2>>>0)){n=18;break}if((c[a+1492>>2]|0)!=0){n=18;break}if((c[a+1496>>2]|0)!=0){n=18;break}o=a+1500|0;p=c[o>>2]|0;if((p|0)!=0){q=p-1|0;c[o>>2]=q;if((q|0)==0){n=18;break}q=a+1552+(e*28|0)+12|0;p=c[q>>2]|0;c[q>>2]=p-(p+128>>8);r=0;i=g;return r|0}p=b+8|0;q=b|0;s=b+16|0;t=0;while(1){u=c[p>>2]|0;if((t|0)>=33){n=10;break}v=d[(c[q>>2]|0)+(u>>>3)|0]|0;w=((u|0)<(c[s>>2]|0))+u|0;c[p>>2]=w;if((v&1<<(u&7)|0)==0){n=12;break}else{t=t+1|0}}do{if((n|0)==10){x=(c[b+12>>2]|0)-u|0;y=u;n=13}else if((n|0)==12){v=(c[b+12>>2]|0)-w|0;if((t|0)>1){x=v;y=w;n=13;break}if((v|0)<0){break a}c[o>>2]=t;if((t|0)==0){n=18;break a}}}while(0);if((n|0)==13){v=t-1|0;if((x|0)<(v|0)){break}z=c[s>>2]|0;A=(c[q>>2]|0)+(y>>>3)|0;B=33-t|0;C=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((y&7)>>>0)<<B>>>(B>>>0);B=y+v|0;c[p>>2]=z>>>0>B>>>0?B:z;c[o>>2]=C|1<<v}mrc(k|0,0,12)|0;mrc(m|0,0,12)|0;v=a+1552+(e*28|0)+12|0;C=c[v>>2]|0;c[v>>2]=C-(C+128>>8);r=0;i=g;return r|0}else{n=18}}while(0);b:do{if((n|0)==18){k=a+1492|0;if((c[k>>2]|0)==0){y=b+8|0;x=b|0;w=b+16|0;u=0;while(1){C=c[y>>2]|0;if((u|0)>=33){D=C;break}v=d[(c[x>>2]|0)+(C>>>3)|0]|0;z=((C|0)<(c[w>>2]|0))+C|0;c[y>>2]=z;if((v&1<<(C&7)|0)==0){D=z;break}else{u=u+1|0}}m=c[b+12>>2]|0;if((m-D|0)<0){break}c:do{if((u|0)==16){o=0;p=D;while(1){if((o|0)>=33){n=25;break}t=d[(c[x>>2]|0)+(p>>>3)|0]|0;E=((p|0)<(c[w>>2]|0))+p|0;c[y>>2]=E;if((t&1<<(p&7)|0)==0){n=27;break}else{o=o+1|0;p=E}}do{if((n|0)==25){F=m-p|0;G=p}else if((n|0)==27){t=m-E|0;if((o|0)>=2){F=t;G=E;break}if((t|0)<0){break b}H=o+16|0;break c}}while(0);p=o-1|0;if((F|0)<(p|0)){break b}t=c[w>>2]|0;q=(c[x>>2]|0)+(G>>>3)|0;s=33-o|0;z=(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((G&7)>>>0)<<s>>>(s>>>0);s=G+p|0;c[y>>2]=t>>>0>s>>>0?s:t;H=(z|1<<p)+16|0}else{H=u}}while(0);u=a+1496|0;y=c[u>>2]|0;x=H&1;c[u>>2]=x;I=((y|0)!=0)+(H>>1)|0;J=x^1}else{I=0;J=0}c[k>>2]=J;do{if((c[a+1524>>2]|0)!=0&(e|0)==0){x=a+12|0;y=c[x>>2]|0;do{if((y|0)<0){K=y;n=38}else{u=0;do{w=a+1552+(u*28|0)+20|0;m=(c[w>>2]|0)+(c[a+1552+(u*28|0)+24>>2]|0)|0;c[w>>2]=m;c[h+(u<<2)>>2]=m>>16;c[j+(u<<2)>>2]=(c[a+1552+(u*28|0)+12>>2]|0)+128>>8;u=u+1|0;L=c[x>>2]|0;}while((u|0)<=(L|0));if((L|0)!=0){K=L;n=38;break}M=a+1528|0}}while(0);if((n|0)==38){y=a+1528|0;do{if((c[y>>2]|0)!=0){o=h+4|0;u=(c[j+4>>2]|0)+1-(c[j>>2]|0)+(c[o>>2]|0)>>1;m=h|0;w=c[m>>2]|0;if((u|0)>(w|0)){c[o>>2]=w<<1;c[m>>2]=0;break}if((w|0)<(-u|0)){c[m>>2]=w<<1;c[o>>2]=0;break}else{c[o>>2]=u+w;c[m>>2]=w-u;break}}}while(0);if((K|0)<0){break}else{M=y}}u=0;do{do{if((c[M>>2]|0)==0){w=c[h+(u<<2)>>2]&65535;m=w<<16>>16<0;o=(m?-w&65535:w)<<16>>16;w=d[110968+(o&255)|0]|0|256;p=o>>>8<<16;o=p>>16;if((p|0)>589824){N=w<<o-9}else{N=w>>>((9-o|0)>>>0)}c[a+1552+(u*28|0)+16>>2]=m?-N|0:N}else{m=(c[j+(u<<2)>>2]|0)-(c[h+(u<<2)>>2]|0)|0;if(!((m|0)>-256)){c[a+1552+(u*28|0)+16>>2]=0;break}o=m+256&65535;m=o<<16>>16<0;w=(m?-o&65535:o)<<16>>16;o=d[110968+(w&255)|0]|0|256;p=w>>>8<<16;w=p>>16;if((p|0)>589824){O=o<<w-9}else{O=o>>>((9-w|0)>>>0)}c[a+1552+(u*28|0)+16>>2]=m?-O|0:O}}while(0);u=u+1|0;}while((u|0)<=(c[x>>2]|0))}}while(0);do{if((I|0)==0){k=l|0;x=c[k>>2]|0;c[k>>2]=x-(((x+126|0)/128|0)<<1);P=x>>4;Q=0}else if((I|0)==1){x=l|0;k=c[x>>2]|0;u=a+1552+(e*28|0)+4|0;y=c[u>>2]|0;c[x>>2]=(((k+128|0)/128|0)*5|0)+k;c[u>>2]=y-(((y+62|0)/64|0)<<1);P=y>>4;Q=(k>>4)+1|0}else{k=l|0;y=c[k>>2]|0;u=a+1552+(e*28|0)+4|0;x=c[u>>2]|0;m=(y>>4)+2+(x>>4)|0;w=a+1552+(e*28|0)+8|0;o=c[w>>2]|0;p=o>>4;if((I|0)==2){c[k>>2]=(((y+128|0)/128|0)*5|0)+y;c[u>>2]=(((x+64|0)/64|0)*5|0)+x;c[w>>2]=o-(((o+30|0)/32|0)<<1);P=p;Q=m;break}else{z=(ca(p+1|0,I-2|0)|0)+m|0;c[k>>2]=(((y+128|0)/128|0)*5|0)+y;c[u>>2]=(((x+64|0)/64|0)*5|0)+x;c[w>>2]=(((o+32|0)/32|0)*5|0)+o;P=p;Q=z;break}}}while(0);z=a+1552+(e*28|0)+16|0;p=c[z>>2]|0;do{if((p|0)==0){if(P>>>0>33554431>>>0){KIb(c[a>>2]|0,16,2352872,(o=i,i=i+8|0,c[o>>2]=P,o)|0);i=o;break b}do{if((P|0)<1){R=0}else{o=P>>>0>65535>>>0;w=o?P>>>16:P;x=o?16:0;if((w&65280|0)==0){S=x;T=w}else{S=x|8;T=w>>>8}w=(d[1359664+T|0]|0)+S|0;x=(1<<w+1)-P|0;if((w|0)==0){U=0}else{o=b+8|0;u=c[o>>2]|0;y=c[b+16>>2]|0;k=(c[b>>2]|0)+(u>>>3)|0;m=32-w|0;t=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>((u&7)>>>0)<<m>>>(m>>>0);m=u+w|0;c[o>>2]=y>>>0>m>>>0?m:y;U=t}if((U|0)<(x-1|0)){R=U;break}t=b+8|0;y=c[t>>2]|0;m=(d[(c[b>>2]|0)+(y>>>3)|0]|0)>>>((y&7)>>>0);c[t>>2]=((y|0)<(c[b+16>>2]|0))+y;R=1-x+(U<<1)+(m&1)|0}}while(0);m=c[b+8>>2]|0;if(((c[b+12>>2]|0)-m|0)<1){break b}V=R+Q|0;W=m}else{m=(Q<<1)+P+1>>1;x=b+8|0;if((P|0)<=(p|0)){V=m;W=c[x>>2]|0;break}y=b|0;t=b+16|0;o=c[b+12>>2]|0;w=Q;u=P;k=m;m=c[x>>2]|0;while(1){if((o-m|0)<1){break b}s=d[(c[y>>2]|0)+(m>>>3)|0]|0;q=((m|0)<(c[t>>2]|0))+m|0;c[x>>2]=q;C=(s&1<<(m&7)|0)==0;s=k-w|0;v=C?w:k;B=C?s-1|0:u-s|0;s=(v<<1)+B+1>>1;if((B|0)>(c[z>>2]|0)){w=v;u=B;k=s;m=q}else{V=s;W=q;break}}}}while(0);z=W&7;p=d[(c[b>>2]|0)+(W>>>3)|0]|0;c[b+8>>2]=((W|0)<(c[b+16>>2]|0))+W;if((c[a+1528>>2]|0)!=0){do{if((V|0)==1){X=256}else if((V|0)==0){X=0}else{m=(V>>9)+V|0;k=m>>>0>65535>>>0;u=k?m>>>16:m;w=k?16:0;if((u&65280|0)==0){Y=w;Z=u}else{Y=w|8;Z=u>>>8}u=(d[1359664+Z|0]|0)+Y|0;w=u+1|0;k=w<<8;if((w|0)<9){X=d[110456+(m<<8-u&255)|0]|0|k;break}else{X=d[110456+(m>>u-8&255)|0]|0|k;break}}}while(0);k=a+1552+(e*28|0)+12|0;u=c[k>>2]|0;c[k>>2]=u+X-(u+128>>8)}r=((p&1<<z|0)!=0)<<31>>31^V;i=g;return r|0}}while(0);c[f>>2]=1;r=0;i=g;return r|0}function cgb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,h=0,i=0.0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=c[a+1548>>2]|0;h=(c[a+44>>2]|0)==0;do{if(!h){if((128-(c[a+60>>2]|0)+(c[a+64>>2]|0)|0)<33){i=0.0}else{break}return+i}}while(0);do{if((e|0)==0){if(h){j=0;l=0;m=0;break}n=c[a+1540>>2]|0;if((n&8|0)==0){j=0;l=0;m=0;break}o=a+60|0;p=c[o>>2]|0;q=c[a+52>>2]|0;r=d[q+(p>>>3)|0]|0;s=c[a+68>>2]|0;t=((p|0)<(s|0))+p|0;c[o>>2]=t;if((r&1<<(p&7)|0)==0){if((n&16|0)==0){j=0;l=0;m=0;break}n=(d[q+(t>>>3)|0]|0)>>>((t&7)>>>0);c[o>>2]=((t|0)<(s|0))+t;j=0;l=0;m=n&1;break}n=q+(t>>>3)|0;p=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((t&7)>>>0)&8388607;n=t+23|0;t=s>>>0>n>>>0?n:s;c[o>>2]=t;if((f|0)>24){n=q+(t>>>3)|0;r=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((t&7)>>>0)&255;n=t+8|0;u=s>>>0>n>>>0?n:s;c[o>>2]=u;v=r;w=u}else{v=0;w=t}t=(d[q+(w>>>3)|0]|0)>>>((w&7)>>>0);c[o>>2]=((w|0)<(s|0))+w;j=p;l=v;m=t&1}else{t=e<<c[a+1544>>2];p=t>>>31;s=(t|0)<0?-t|0:t;a:do{if((s|0)>16777215){if(h){x=0;y=255;break}t=a+60|0;o=c[t>>2]|0;q=c[a+52>>2]|0;u=d[q+(o>>>3)|0]|0;r=c[a+68>>2]|0;n=((o|0)<(r|0))+o|0;c[t>>2]=n;if((u&1<<(o&7)|0)==0){x=0;y=255;break}o=q+(n>>>3)|0;q=(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)>>>((n&7)>>>0)&8388607;o=n+23|0;c[t>>2]=r>>>0>o>>>0?o:r;x=q;y=255}else{if((f|0)==0){x=s;y=0;break}q=s>>>0>65535>>>0;r=q?s>>>16:s;o=q?16:0;if((r&65280|0)==0){z=o;A=r}else{z=o|8;A=r>>>8}r=23-z-(d[1359664+A|0]|0)|0;o=(f|0)>(r|0);q=f-1|0;t=o?r:q;r=(o?f:q)-t|0;if((t|0)==0){x=s;y=r;break}q=s<<t;o=c[a+1540>>2]|0;do{if((o&1|0)==0){if(h){x=q;y=r;break a}if((o&2|0)!=0){n=a+60|0;u=c[n>>2]|0;B=d[(c[a+52>>2]|0)+(u>>>3)|0]|0;c[n>>2]=((u|0)<(c[a+68>>2]|0))+u;if((B&1<<(u&7)|0)!=0){break}}if((o&4|0)==0){x=q;y=r;break a}u=a+60|0;B=c[u>>2]|0;n=c[a+68>>2]|0;C=(c[a+52>>2]|0)+(B>>>3)|0;D=32-t|0;E=(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)>>>((B&7)>>>0)<<D>>>(D>>>0);D=B+t|0;c[u>>2]=n>>>0>D>>>0?D:n;x=E|q;y=r;break a}}while(0);x=(1<<t)-1|q;y=r}}while(0);j=x&8388607;l=y;m=p}}while(0);c[b>>2]=(l*3|0)+m+(j*9|0)+((c[b>>2]|0)*27|0);i=(c[k>>2]=l<<23|m<<31|j,+g[k>>2]);return+i}function dgb(a){a=a|0;var b=0,d=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=c[a+60>>2]|0;c[d+4>>2]=a;f=a+424|0;h=c[f>>2]|0;do{if((h|0)==0){j=c[a+412>>2]|0;if((j&1|0)==0){k=(j|0)/2|0}else{k=j}j=c[a+416>>2]|0;if((ca(j,k)|0)>15e4){l=k;while(1){m=(l|0)/2|0;if((ca(j,m)|0)>15e4){l=m}else{n=m;break}}}else{n=k}while(1){if((ca(j,n)|0)<4e4){n=n<<1}else{break}}c[f>>2]=n}else{if(!((h-128|0)>>>0>130944>>>0)){break}KIb(a,16,2240632,(j=i,i=i+8|0,c[j>>2]=h,j)|0);i=j;o=-22;i=b;return o|0}}while(0);h=a+84|0;a=c[h>>2]|0;do{if((a|0)==-1){p=c[d+448>>2]|0}else{if((a|0)<=2){if((a|0)==1){c[d+448>>2]=1;c[d+596>>2]=2;p=1;break}else if((a|0)==2){c[d+448>>2]=2;c[d+596>>2]=4;p=2;break}else{c[d+448>>2]=0;c[d+596>>2]=0;p=0;break}}c[d+448>>2]=3;c[d+596>>2]=9;n=c[h>>2]|0;if((n|0)>7){c[d+456>>2]=4;c[d+440>>2]=31;p=3;break}if((n|0)>6){c[d+456>>2]=3;c[d+440>>2]=15;p=3;break}if((n|0)>5){c[d+456>>2]=2;c[d+440>>2]=15;p=3;break}if((n|0)>4){c[d+456>>2]=1;c[d+440>>2]=15;p=3;break}if((n|0)<=3){p=3;break}c[d+456>>2]=1;c[d+440>>2]=11;p=3}}while(0);c[d+592>>2]=e[1584544+(p<<1)>>1]|0;c[d+2016>>2]=c[1584528+(p<<2)>>2];g[d+2020>>2]=2.0;o=0;i=b;return o|0}function egb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;i=i+8|0;j=h|0;k=c[d+60>>2]|0;l=k;m=f+76|0;n=c[m>>2]|0;o=k+32|0;c[o>>2]=n;p=k+56|0;q=p;A4a(p,k+64|0,n<<2);if((c[q>>2]|0)==0){r=-12;i=h;return r|0}n=d+416|0;p=c[n>>2]|0;do{if((p|0)>1){s=k+60|0;A4a(s,k+68|0,c[o>>2]<<2);if((c[s>>2]|0)==0){r=-12;i=h;return r|0}else{t=c[n>>2]|0;break}}else{t=p}}while(0);p=ca(c[o>>2]<<3,t)|0;t=d5a(d,e,p,(p|0)<0|0?-1:0)|0;if((t|0)<0){r=t;i=h;return r|0}t=e+24|0;p=c[t>>2]|0;s=e+28|0;u=c[s>>2]|0;v=k+52|0;c[v>>2]=0;do{if((c[n>>2]|0)>0){w=k+4|0;x=k+460|0;y=f+64|0;z=k+60|0;A=u;B=p;C=0;while(1){D=0;while(1){if((D|0)>=15){E=10;break}F=c[w>>2]|0;if((c[109752+(D<<2)>>2]|0)==(c[F+412>>2]|0)){G=F;break}else{D=D+1|0}}if((E|0)==10){E=0;G=c[w>>2]|0}F=D<<23;c[x>>2]=F;H=c[G+420>>2]|0;do{if((H|0)==7){c[x>>2]=((c[G+796>>2]|0)<25|F)^3;I=c[(c[y>>2]|0)+(C<<2)>>2]|0;J=c[q>>2]|0;K=c[o>>2]|0;if((c[G+796>>2]|0)>=25){L=I;M=J;N=K;E=21;break}O=I;if((K|0)>0){P=0}else{break}do{c[J+(P<<2)>>2]=c[O+(P<<2)>>2]>>8;P=P+1|0;}while((P|0)<(K|0))}else if((H|0)==6){c[x>>2]=F|1;K=c[q>>2]|0;O=c[o>>2]|0;J=c[(c[y>>2]|0)+(C<<2)>>2]|0;if((O|0)>0){Q=0}else{break}do{c[K+(Q<<2)>>2]=b[J+(Q<<1)>>1]|0;Q=Q+1|0;}while((Q|0)<(O|0))}else if((H|0)==8){c[x>>2]=F|131;L=c[(c[y>>2]|0)+(C<<2)>>2]|0;M=c[q>>2]|0;N=c[o>>2]|0;E=21}else{O=c[(c[y>>2]|0)+(C<<2)>>2]|0;J=c[q>>2]|0;K=c[o>>2]|0;if((H|0)==5&(K|0)>0){R=0}else{break}do{c[J+(R<<2)>>2]=(a[O+R|0]|0)-128;R=R+1|0;}while((R|0)<(K|0))}}while(0);if((E|0)==21){E=0;nrc(M|0,L|0,N<<2)|0}H=c[v>>2]|0;F=c[x>>2]|0;a:do{if(((c[n>>2]|0)-H|0)==1){c[x>>2]=F|4}else{c[x>>2]=F|32;D=c[(c[y>>2]|0)+(H+1<<2)>>2]|0;K=c[z>>2]|0;O=c[o>>2]|0;J=c[w>>2]|0;I=c[J+420>>2]|0;do{if((I|0)==7){if((c[J+796>>2]|0)>=25){break}S=D;if((O|0)>0){T=0}else{break a}while(1){c[K+(T<<2)>>2]=c[S+(T<<2)>>2]>>8;T=T+1|0;if((T|0)>=(O|0)){break a}}}else if((I|0)==6){S=D;if((O|0)>0){U=0}else{break a}while(1){c[K+(U<<2)>>2]=b[S+(U<<1)>>1]|0;U=U+1|0;if((U|0)>=(O|0)){break a}}}else if((I|0)==5){if((O|0)>0){V=0}else{break a}while(1){c[K+(V<<2)>>2]=(a[D+V|0]|0)-128;V=V+1|0;if((V|0)>=(O|0)){break a}}}else if((I|0)!=8){break a}}while(0);nrc(K|0,D|0,O<<2)|0}}while(0);H=c[x>>2]|0;c[x>>2]=(H<<21&6291456|1835008)+H;H=ggb(l,c[q>>2]|0,c[z>>2]|0,B,A)|0;if((H|0)<0){r=H;E=37;break}W=B+H|0;F=c[v>>2]|0;if((F|0)<(c[n>>2]|0)){A=A-H|0;B=W;C=F}else{E=35;break}}if((E|0)==35){X=W;Y=c[t>>2]|0;break}else if((E|0)==37){i=h;return r|0}}else{X=p;Y=p}}while(0);p=k+40|0;c[p>>2]=(c[p>>2]|0)+(c[m>>2]|0);p=f+136|0;f=c[p+4>>2]|0;k=e+8|0;c[k>>2]=c[p>>2];c[k+4>>2]=f;c[s>>2]=X-Y;Y=c[m>>2]|0;c[j>>2]=1;c[j+4>>2]=c[d+412>>2];m=XIb(Y,(Y|0)<0|0?-1:0,j,d+104|0)|0;c[e+48>>2]=m;c[g>>2]=1;r=0;i=h;return r|0}function fgb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b+72|0;d=b+216|0;e=0;do{mJb(a+(e<<3)|0);mJb(a+(e<<3)+4|0);c[d+(e<<3)+4>>2]=0;c[d+(e<<3)>>2]=0;e=e+1|0;}while((e|0)<18);mJb(b+56|0);c[b+64>>2]=0;mJb(b+392|0);c[b+400>>2]=0;mJb(b+360|0);mJb(b+364|0);c[b+380>>2]=0;c[b+376>>2]=0;mJb(b+60|0);c[b+68>>2]=0;mJb(b+396|0);c[b+404>>2]=0;mJb(b+368|0);mJb(b+372|0);c[b+388>>2]=0;c[b+384>>2]=0;mJb(b+408|0);mJb(b+412|0);c[b+420>>2]=0;c[b+416>>2]=0;mJb(b+424|0);mJb(b+428|0);c[b+436>>2]=0;c[b+432>>2]=0;return 0}function ggb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0;j=i;i=i+128|0;k=j|0;l=j+32|0;m=j+64|0;n=j+96|0;o=c[b+32>>2]|0;p=b+460|0;q=c[p>>2]|0;do{if((q&4|0)==0){if((c[b+444>>2]|0)==0){r=q;break}else{s=0;t=0;u=0}while(1){if((u|0)>=(o|0)){v=s;w=t;break}x=c[e+(u<<2)>>2]|0;z=c[f+(u<<2)>>2]|0;A=x|t|z;B=x-z|s;if((A|0)==0|(B|0)==0){s=B;t=A;u=u+1|0}else{v=B;w=A;break}}if((w|0)!=0&(u|0)==(o|0)&(v|0)==0){A=q&-1073741873|1073741824;c[p>>2]=A;B=b+588|0;if((c[B>>2]|0)!=0){r=A;break}c[B>>2]=1;c[b+576>>2]=0;mrc(b+468|0,0,76)|0;r=A;break}else{A=b+588|0;if((c[A>>2]|0)==0){r=q;break}c[A>>2]=0;c[b+576>>2]=0;mrc(b+468|0,0,76)|0;r=q;break}}else{r=q}}while(0);q=r&253952;do{if((q|0)==0){C=r}else{v=q>>>13;u=r>>>18&31;w=(o|0)>0;do{if((r&1073741828|0)==0){if(w){D=0}else{break}do{t=e+(D<<2)|0;c[t>>2]=c[t>>2]>>v;t=f+(D<<2)|0;c[t>>2]=c[t>>2]>>v;D=D+1|0;}while((D|0)<(o|0))}else{if(w){E=0}else{break}do{t=e+(E<<2)|0;c[t>>2]=c[t>>2]>>v;E=E+1|0;}while((E|0)<(o|0))}}while(0);if((u-v|0)<0){w=c[p>>2]&-8126465;c[p>>2]=w;C=w;break}else{w=(c[p>>2]|0)-(q<<5)|0;c[p>>2]=w;C=w;break}}}while(0);do{if((C&128|0)!=0|(C&6291456)>>>0>6029312>>>0){q=b+424|0;E=o<<2;A4a(q,b+432|0,E);nrc(c[q>>2]|0,e|0,E)|0;q=c[p>>2]|0;if((q&1073741828|0)==0){D=b+428|0;A4a(D,b+436|0,E);nrc(c[D>>2]|0,f|0,E)|0;F=c[p>>2]|0}else{F=q}do{if((F&128|0)==0){q=b+547|0;E=b+546|0;D=b+545|0;r=b+544|0;w=r;y=0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;w=(o|0)>0;do{if((F&1073741828|0)==0){if(w){H=0;I=-1;J=-1;K=0;L=0;M=0}else{N=69;break}while(1){t=c[e+(K<<2)>>2]|0;s=c[f+(K<<2)>>2]|0;A=((s&65535)*3|0)+(s>>>16)+(((t>>>16)+(J*9|0)+((t&65535)*3|0)|0)*9|0)|0;B=t>>31^t|M|s>>31^s;z=t^-(t&1)|H|s^-(s&1);x=t&I&s;O=t|L|s;s=K+1|0;if((s|0)<(o|0)){H=z;I=x;J=A;K=s;L=O;M=B}else{P=B;Q=O;R=A;S=x;T=z;N=70;break}}}else{if(w){U=0;V=-1;W=-1;X=0;Y=0;Z=0}else{N=69;break}while(1){z=c[e+(X<<2)>>2]|0;x=(z>>>16)+(W*9|0)+((z&65535)*3|0)|0;A=z>>31^z|Z;O=z^-(z&1)|U;B=z&V;s=z|Y;z=X+1|0;if((z|0)<(o|0)){U=O;V=B;W=x;X=z;Y=s;Z=A}else{P=A;Q=s;R=x;S=B;T=O;N=70;break}}}}while(0);do{if((N|0)==69){c[b+464>>2]=-1;O=F&-8126465;c[p>>2]=O;_=O;$=0;aa=-1;ba=0}else if((N|0)==70){c[b+464>>2]=R;O=F&-8126465;c[p>>2]=O;if((P|0)==0){_=O;$=T;aa=S;ba=Q;break}else{da=P;ea=O}do{ea=ea+262144|0;da=da>>>1;}while((da|0)!=0);c[p>>2]=ea;_=ea;$=T;aa=S;ba=Q}}while(0);if((_&8126464|0)==0){c[p>>2]=_&-257;fa=0;break}do{if((ba&1|0)==0){O=ba;B=0;x=_;s=0;do{x=x-262144|0;s=s+1&255;B=B+1|0;O=O>>>1;}while((O&1|0)==0);c[p>>2]=x;a[D]=s;ga=B;ha=x}else{if((aa&1|0)!=0){O=0;A=aa;z=_;t=0;do{z=z-262144|0;t=t+1&255;O=O+1|0;A=A>>>1;}while((A&1|0)!=0);c[p>>2]=z;a[E]=t;ga=O;ha=z;break}if(($&2|0)==0){ia=0;ja=$;ka=_;la=0}else{ga=0;ha=_;break}do{ka=ka-262144|0;la=la+1&255;ia=ia+1|0;ja=ja>>>1;}while((ja&2|0)==0);c[p>>2]=ka;a[q]=la;ga=ia;ha=ka}}while(0);q=ha>>>18&31;if(q>>>0>23>>>0){E=q+233|0;a[r]=E;q=ha&-8126465|6029312;c[p>>2]=q;ma=(E&255)+ga|0;na=q}else{ma=ga;na=ha}do{if((ma|0)!=0){c[p>>2]=na|256;if((na&1073741828|0)==0){if(w){oa=0}else{break}do{q=e+(oa<<2)|0;c[q>>2]=c[q>>2]>>ma;q=f+(oa<<2)|0;c[q>>2]=c[q>>2]>>ma;oa=oa+1|0;}while((oa|0)<(o|0))}else{if(w){pa=0}else{break}do{q=e+(pa<<2)|0;c[q>>2]=c[q>>2]>>ma;pa=pa+1|0;}while((pa|0)<(o|0))}}}while(0);fa=d[r]|0}else{w=b+572|0;q=b+560|0;E=b+556|0;D=b+552|0;z=b+548|0;a[z]=0;O=b+549|0;a[O]=0;t=b+568|0;A=b+564|0;x=b+551|0;mrc(x|0,0,25)|0;B=(F&1073741828|0)==0;s=(o|0)>0;do{if(B){if(s){qa=0;ra=-1;sa=0}else{c[b+464>>2]=-1;break}while(1){ta=c[e+(qa<<2)>>2]|0;ua=ta>>>23;va=ua&255;if(va>>>0<=(sa&255)>>>0|(va|0)==255){wa=sa}else{xa=ua&255;a[x]=xa;wa=xa}xa=c[f+(qa<<2)>>2]|0;ua=xa>>>23;ya=ua&255;za=(xa>>>31)+(((ta>>>31)+(ra*27|0)+((ta&8388607)*9|0)+(va*3|0)|0)*27|0)+((xa&8388607)*9|0)+(ya*3|0)|0;if(ya>>>0<=(wa&255)>>>0|(ya|0)==255){Aa=wa}else{ya=ua&255;a[x]=ya;Aa=ya}ya=qa+1|0;if((ya|0)<(o|0)){qa=ya;ra=za;sa=Aa}else{Ba=za;N=36;break}}}else{if(s){Ca=0;Da=-1;Ea=0}else{c[b+464>>2]=-1;break}while(1){za=c[e+(Ca<<2)>>2]|0;ya=za>>>23;ua=ya&255;xa=(za>>>31)+(Da*27|0)+((za&8388607)*9|0)+(ua*3|0)|0;if(ua>>>0<=(Ea&255)>>>0|(ua|0)==255){Fa=Ea}else{ua=ya&255;a[x]=ua;Fa=ua}ua=Ca+1|0;if((ua|0)<(o|0)){Ca=ua;Da=xa;Ea=Fa}else{Ba=xa;N=36;break}}}}while(0);do{if((N|0)==36){c[b+464>>2]=Ba;if(B){if(s){Ga=0}else{break}do{Agb(b,e+(Ga<<2)|0);Agb(b,f+(Ga<<2)|0);Ga=Ga+1|0;}while((Ga|0)<(o|0))}else{if(s){Ha=0}else{break}do{Agb(b,e+(Ha<<2)|0);Ha=Ha+1|0;}while((Ha|0)<(o|0))}}}while(0);a[b+550|0]=a[x]|0;do{if((c[q>>2]|0)==0){if((c[D>>2]|0)!=0){B=a[z]|0;if((c[E>>2]|0)==0){a[z]=B|1;break}else{a[z]=B|2;break}}B=c[w>>2]|0;if(!((B|0)!=0&(B&1|0)==0)){break}r=a[O]|0;xa=B;do{r=r+1&255;xa=xa>>1;}while((xa&1|0)==0);a[O]=r;c[w>>2]=xa;B=r&255;if((c[p>>2]&1073741828|0)==0){if(s){Ia=0}else{break}do{ua=e+(Ia<<2)|0;c[ua>>2]=c[ua>>2]>>B;ua=f+(Ia<<2)|0;c[ua>>2]=c[ua>>2]>>B;Ia=Ia+1|0;}while((Ia|0)<(o|0))}else{if(s){Ja=0}else{break}do{r=e+(Ja<<2)|0;c[r>>2]=c[r>>2]>>B;Ja=Ja+1|0;}while((Ja|0)<(o|0))}}else{a[z]=a[z]|4}}while(0);s=c[p>>2]&-8126465;c[p>>2]=s;O=c[w>>2]|0;if((O|0)!=0){E=s;s=O;do{E=E+262144|0;s=s>>1;}while((s|0)!=0);c[p>>2]=E;c[w>>2]=0}s=c[t>>2]|0;do{if((c[A>>2]|0)==0){O=a[z]|0;if((s|0)==0){Ka=O;break}a[z]=O|8;La=O;N=62}else{O=a[z]|0;D=O|8;a[z]=D;if((s|0)==0){Ka=D}else{La=O;N=62}}}while(0);if((N|0)==62){s=La|24;a[z]=s;Ka=s}fa=Ka&46}}while(0);c[b+576>>2]=0;Ma=fa}else{v=b+547|0;u=b+546|0;s=b+545|0;A=b+544|0;y=0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;A=(o|0)>0;a:do{if((C&1073741828|0)==0){if(A){Na=-1;Oa=0;Pa=0;Qa=0;Ra=0}else{N=105;break}while(1){t=c[e+(Oa<<2)>>2]|0;w=c[f+(Oa<<2)>>2]|0;E=t>>31^t|Ra|w>>31^w;O=t^-(t&1)|Pa|w^-(w&1);D=t&Na&w;q=t|Qa|w;do{if((q&1|0)!=0){if((D&1|0)!=0){break}if((O&2|0)!=0){break a}}}while(0);w=Oa+1|0;if((w|0)<(o|0)){Na=D;Oa=w;Pa=O;Qa=q;Ra=E}else{Sa=E;Ta=q;Ua=O;Va=D;N=106;break}}}else{if(A){Wa=-1;Xa=0;Ya=0;Za=0;_a=0}else{N=105;break}while(1){z=c[e+(Xa<<2)>>2]|0;w=z>>31^z|_a;t=z^-(z&1)|Ya;x=z&Wa;B=z|Za;do{if((B&1|0)!=0){if((x&1|0)!=0){break}if((t&2|0)!=0){break a}}}while(0);D=Xa+1|0;if((D|0)<(o|0)){Wa=x;Xa=D;Ya=t;Za=B;_a=w}else{Sa=w;Ta=B;Ua=t;Va=x;N=106;break}}}}while(0);do{if((N|0)==105){D=C&-8126465;c[p>>2]=D;$a=D;ab=-1;bb=0;cb=0;N=109}else if((N|0)==106){D=C&-8126465;c[p>>2]=D;if((Sa|0)==0){$a=D;ab=Va;bb=Ua;cb=Ta;N=109;break}else{db=Sa;eb=D}do{eb=eb+262144|0;db=db>>>1;}while((db|0)!=0);c[p>>2]=eb;$a=eb;ab=Va;bb=Ua;cb=Ta;N=109}}while(0);b:do{if((N|0)==109){if(($a&8126464|0)==0){break}do{if((cb&1|0)==0){D=cb;O=0;q=$a;E=0;do{q=q-262144|0;E=E+1&255;O=O+1|0;D=D>>>1;}while((D&1|0)==0);c[p>>2]=q;a[s]=E;fb=O;gb=q}else{if((ab&1|0)!=0){D=0;x=ab;t=$a;B=0;do{t=t-262144|0;B=B+1&255;D=D+1|0;x=x>>>1;}while((x&1|0)!=0);c[p>>2]=t;a[u]=B;fb=D;gb=t;break}if((bb&2|0)==0){hb=bb;ib=0;jb=$a;kb=0}else{break b}do{jb=jb-262144|0;kb=kb+1&255;ib=ib+1|0;hb=hb>>>1;}while((hb&2|0)==0);c[p>>2]=jb;a[v]=kb;fb=ib;gb=jb}}while(0);if((fb|0)==0){break}c[p>>2]=gb|256;if((gb&1073741828|0)==0){if(A){lb=0}else{break}do{t=e+(lb<<2)|0;c[t>>2]=c[t>>2]>>fb;t=f+(lb<<2)|0;c[t>>2]=c[t>>2]>>fb;lb=lb+1|0;}while((lb|0)<(o|0))}else{if(A){mb=0}else{break}do{t=e+(mb<<2)|0;c[t>>2]=c[t>>2]>>fb;mb=mb+1|0;}while((mb|0)<(o|0))}}}while(0);A=b+580|0;t=(d[u]|0)+(d[s]|0)+(d[v]|0)|0;if((c[A>>2]|0)==(t|0)){Ma=0;break}c[A>>2]=t;c[b+576>>2]=0;Ma=0}}while(0);mb=b+596|0;fb=c[mb>>2]|0;do{if((fb|0)==0){if((c[b+576>>2]|0)!=0){nb=0;ob=0;break}c[mb>>2]=1;if((c[p>>2]&1073741828|0)==0){pb=igb(b,e,f,1,0)|0}else{pb=hgb(b,e,1,0)|0}c[mb>>2]=0;nb=pb;ob=0}else{nb=0;ob=fb}}while(0);fb=(o|0)>0;do{if((c[p>>2]&1073741828|0)==0){if(fb){pb=0;lb=-1;while(1){gb=c[e+(pb<<2)>>2]|0;jb=(lb*9|0)+gb+(gb<<1)+(c[f+(pb<<2)>>2]|0)|0;gb=pb+1|0;if((gb|0)<(o|0)){pb=gb;lb=jb}else{qb=jb;break}}}else{qb=-1}if((ob|0)==0){rb=qb;sb=nb;break}rb=qb;sb=igb(b,e,f,(c[b+576>>2]|0)==0|0,1)|0}else{if(fb){lb=0;pb=-1;while(1){v=(pb*3|0)+(c[e+(lb<<2)>>2]|0)|0;s=lb+1|0;if((s|0)<(o|0)){lb=s;pb=v}else{tb=v;break}}}else{tb=-1}if((ob|0)==0){rb=tb;sb=nb;break}rb=tb;sb=hgb(b,e,(c[b+576>>2]|0)==0|0,1)|0}}while(0);if((sb|0)<0){ub=sb;i=j;return ub|0}sb=b+52|0;tb=c[sb>>2]|0;nb=c[p>>2]|0;if((tb|0)==0){ob=nb|2048;c[p>>2]=ob;vb=ob}else{vb=nb}nb=2-(vb>>>2&1)+tb|0;c[sb>>2]=nb;sb=b+4|0;if((nb|0)==(c[(c[sb>>2]|0)+416>>2]|0)){c[p>>2]=vb|4096}if(!((h|0)>-1)){KIb(0,0,2441528,(vb=i,i=i+24|0,c[vb>>2]=2353432,c[vb+8>>2]=2291360,c[vb+16>>2]=145,vb)|0);i=vb;Hd();return 0}vb=g+h|0;do{if((h|0)>3){nb=g;y=1802532471;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=g+4|0;tb=vb;if((tb-nb|0)<=3){wb=nb;xb=1;break}ob=nb;y=0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=g+8|0;if((tb-ob|0)<=1){wb=ob;xb=1;break}nb=ob;y=1040;a[nb]=y;y=y>>8;a[nb+1|0]=y;nb=g+10|0;if((tb-nb|0)<=1){wb=nb;xb=1;break}ob=nb;y=0;a[ob]=y;y=y>>8;a[ob+1|0]=y;ob=g+12|0;if((tb-ob|0)<=3){wb=ob;xb=1;break}nb=ob;y=0;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=g+16|0;if((tb-nb|0)<=3){wb=nb;xb=1;break}ob=nb;y=c[b+40>>2]|0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=g+20|0;if((tb-ob|0)<=3){wb=ob;xb=1;break}nb=ob;y=o;a[nb]=y;y=y>>8;a[nb+1|0]=y;y=y>>8;a[nb+2|0]=y;y=y>>8;a[nb+3|0]=y;nb=g+24|0;if((tb-nb|0)<=3){wb=nb;xb=1;break}ob=nb;y=c[p>>2]|0;a[ob]=y;y=y>>8;a[ob+1|0]=y;y=y>>8;a[ob+2|0]=y;y=y>>8;a[ob+3|0]=y;ob=g+28|0;if((tb-ob|0)<=3){wb=ob;xb=1;break}tb=ob;y=rb;a[tb]=y;y=y>>8;a[tb+1|0]=y;y=y>>8;a[tb+2|0]=y;y=y>>8;a[tb+3|0]=y;wb=g+32|0;xb=0}else{wb=g;xb=1}}while(0);do{if((c[p>>2]&2048|0)==0){yb=wb;zb=xb}else{rb=(c[sb>>2]|0)+448|0;h=wrc(c[rb>>2]|0,c[rb+4>>2]|0,-3,-1)|0;rb=G;tb=0;if(rb>>>0<tb>>>0|rb>>>0==tb>>>0&h>>>0<2>>>0){yb=wb;zb=xb;break}if((xb|0)!=0){yb=wb;zb=1;break}h=vb;if((h-wb|0)<=0){yb=wb;zb=1;break}a[wb]=77;tb=wb+1|0;if((h-tb|0)<=0){yb=tb;zb=1;break}a[tb]=3;tb=wb+2|0;if((h-tb|0)<=0){yb=tb;zb=1;break}a[tb]=c[(c[sb>>2]|0)+416>>2];tb=wb+3|0;if((h-tb|0)<=3){yb=tb;zb=1;break}rb=tb;y=c[(c[sb>>2]|0)+448>>2]|0;a[rb]=y;y=y>>8;a[rb+1|0]=y;y=y>>8;a[rb+2|0]=y;y=y>>8;a[rb+3|0]=y;rb=wb+7|0;if((h-rb|0)<=0){yb=rb;zb=1;break}a[rb]=0;yb=wb+8|0;zb=0}}while(0);c:do{if((c[p>>2]&125829120|0)==125829120){do{if((zb|0)==0){wb=vb;if((wb-yb|0)<=0){Ab=yb;break}a[yb]=103;xb=yb+1|0;if((wb-xb|0)<=0){Ab=xb;break}a[xb]=2;xb=yb+2|0;rb=c[(c[sb>>2]|0)+412>>2]|0;if((wb-xb|0)<=2){Ab=xb;break}a[xb]=rb;a[yb+3|0]=rb>>>8;a[yb+4|0]=rb>>>16;rb=yb+5|0;if((wb-rb|0)<=0){Ab=rb;break}a[rb]=0;Bb=yb+6|0;N=176;break c}else{Ab=yb}}while(0);Cb=Ab;Db=1;Eb=b+576|0}else{Bb=yb;N=176}}while(0);do{if((N|0)==176){yb=b+576|0;Ab=c[yb>>2]|0;if((zb|0)!=0){Cb=Bb;Db=1;Eb=yb;break}sb=vb;if((sb-Bb|0)<=0){Cb=Bb;Db=1;Eb=yb;break}a[Bb]=Ab<<6&64|2;rb=Bb+1|0;if((sb-rb|0)<=0){Cb=rb;Db=1;Eb=yb;break}a[rb]=(Ab+1|0)>>>1;Cb=Bb+2|0;Db=0;Eb=yb}}while(0);Bb=c[Eb>>2]|0;if((Bb|0)>0){zb=vb;yb=Db;Ab=Cb;rb=0;sb=Bb;while(1){wb=(c[b+608+(rb*88|0)+4>>2]|0)+5&31|c[b+608+(rb*88|0)>>2]<<5;do{if((yb|0)==0){if((zb-Ab|0)<=0){Fb=Ab;Gb=1;Hb=sb;break}a[Ab]=wb;Fb=Ab+1|0;Gb=0;Hb=c[Eb>>2]|0}else{Fb=Ab;Gb=1;Hb=sb}}while(0);wb=rb+1|0;if((wb|0)<(Hb|0)){yb=Gb;Ab=Fb;rb=wb;sb=Hb}else{Ib=Gb;Jb=Fb;Kb=Hb;break}}}else{Ib=Db;Jb=Cb;Kb=Bb}do{if((Kb&1|0)==0){Lb=Jb;N=190}else{if((Ib|0)!=0){Mb=Jb;Nb=1;break}if((vb-Jb|0)<=0){Mb=Jb;Nb=1;break}a[Jb]=0;Lb=Jb+1|0;N=190}}while(0);do{if((N|0)==190){if((Ib|0)!=0){Mb=Lb;Nb=1;break}Jb=vb;if((Jb-Lb|0)<=0){Mb=Lb;Nb=1;break}a[Lb]=3;Kb=Lb+1|0;if((Jb-Kb|0)<=0){Mb=Kb;Nb=1;break}a[Kb]=0;Mb=Lb+2|0;Nb=0}}while(0);Lb=g;Ib=Mb-Lb|0;Kb=c[Eb>>2]|0;Jb=(Kb|0)>0;do{if(Jb){Bb=Kb;while(1){Cb=Bb-1|0;Db=c[b+608+(Cb*88|0)+8>>2]|0;do{if((Db|0)<-1024){Ob=-1024}else{Hb=(Db|0)>1024?1024:Db;if((Hb|0)<=0){Ob=Hb;break}Ob=Hb-(Hb+64>>7)|0}}while(0);if(!(((Ob+4|0)>>>3&255)<<24>>24==0)){Pb=Bb;break}if((c[p>>2]&1073741828|0)==0){Db=c[b+608+(Cb*88|0)+12>>2]|0;do{if((Db|0)<-1024){Qb=-1024}else{Hb=(Db|0)>1024?1024:Db;if((Hb|0)<=0){Qb=Hb;break}Qb=Hb-(Hb+64>>7)|0}}while(0);if(!(((Qb+4|0)>>>3&255)<<24>>24==0)){Pb=Bb;break}}if((Cb|0)>0){Bb=Cb}else{Pb=Cb;break}}if(!Jb){Rb=Nb;Sb=Mb;break}Bb=vb;Db=Nb;Hb=Mb;Fb=0;while(1){do{if((Fb|0)<(Pb|0)){Gb=b+608+(Fb*88|0)+8|0;sb=c[Gb>>2]|0;do{if((sb|0)<-1024){Tb=-1024}else{rb=(sb|0)>1024?1024:sb;if((rb|0)<=0){Tb=rb;break}Tb=rb-(rb+64>>7)|0}}while(0);sb=(Tb+4|0)>>>3;rb=sb<<24;do{if((Db|0)==0){if((Bb-Hb|0)<=0){Ub=Hb;Vb=1;break}a[Hb]=sb;Ub=Hb+1|0;Vb=0}else{Ub=Hb;Vb=1}}while(0);sb=rb>>21;if((rb|0)>0){Wb=(sb+64>>7)+sb|0}else{Wb=sb}c[Gb>>2]=Wb;if((c[p>>2]&1073741828|0)!=0){Xb=Ub;Yb=Vb;break}sb=b+608+(Fb*88|0)+12|0;Ab=c[sb>>2]|0;do{if((Ab|0)<-1024){Zb=-1024}else{yb=(Ab|0)>1024?1024:Ab;if((yb|0)<=0){Zb=yb;break}Zb=yb-(yb+64>>7)|0}}while(0);Ab=(Zb+4|0)>>>3;Gb=Ab<<24;do{if((Vb|0)==0){if((Bb-Ub|0)<=0){_b=Ub;$b=1;break}a[Ub]=Ab;_b=Ub+1|0;$b=0}else{_b=Ub;$b=1}}while(0);Ab=Gb>>21;if((Gb|0)>0){ac=(Ab+64>>7)+Ab|0}else{ac=Ab}c[sb>>2]=ac;Xb=_b;Yb=$b}else{c[b+608+(Fb*88|0)+12>>2]=0;c[b+608+(Fb*88|0)+8>>2]=0;Xb=Hb;Yb=Db}}while(0);Cb=Fb+1|0;if((Cb|0)<(c[Eb>>2]|0)){Db=Yb;Hb=Xb;Fb=Cb}else{Rb=Yb;Sb=Xb;break}}}else{Rb=Nb;Sb=Mb}}while(0);Mb=Sb;Nb=Mb-Lb-Ib|0;Xb=Nb&1;a[g+(Ib-2)|0]=Xb<<6|3;a[g+(Ib-1)|0]=(Nb+1|0)>>>1;do{if((Xb|0)==0){bc=Sb;N=232}else{if((Rb|0)!=0){cc=Sb;dc=1;break}if((vb-Mb|0)<=0){cc=Sb;dc=1;break}a[Sb]=0;bc=Sb+1|0;N=232}}while(0);do{if((N|0)==232){if((Rb|0)!=0){cc=bc;dc=1;break}Sb=vb;if((Sb-bc|0)<=0){cc=bc;dc=1;break}a[bc]=4;Mb=bc+1|0;if((Sb-Mb|0)<=0){cc=Mb;dc=1;break}a[Mb]=0;cc=bc+2|0;dc=0}}while(0);bc=cc;Rb=bc-Lb|0;if((c[Eb>>2]|0)>0){Mb=vb;Sb=dc;Xb=cc;Nb=0;while(1){do{if((Nb|0)==0){Ib=b+612|0;Yb=c[Ib>>2]|0;if((Yb|0)>8){$b=b+624|0;_b=(jgb(c[$b>>2]|0)|0)&65535;ac=_b<<16>>16<0;Ub=(ac?-_b&65535:_b)<<16>>16;Vb=d[110712+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){ec=Vb<<Ub-9}else{ec=Vb>>>((9-Ub|0)>>>0)}c[$b>>2]=ac?-ec|0:ec;do{if((Sb|0)==0){if((Mb-Xb|0)<=1){fc=Xb;gc=1;break}ac=Xb;y=_b;a[ac]=y;y=y>>8;a[ac+1|0]=y;fc=Xb+2|0;gc=0}else{fc=Xb;gc=1}}while(0);_b=b+628|0;ac=(jgb(c[_b>>2]|0)|0)&65535;$b=ac<<16>>16<0;Ub=($b?-ac&65535:ac)<<16>>16;Vb=d[110712+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){hc=Vb<<Ub-9}else{hc=Vb>>>((9-Ub|0)>>>0)}c[_b>>2]=$b?-hc|0:hc;do{if((gc|0)==0){if((Mb-fc|0)<=1){ic=fc;jc=1;break}$b=fc;y=ac;a[$b]=y;y=y>>8;a[$b+1|0]=y;ic=fc+2|0;jc=0}else{ic=fc;jc=1}}while(0);if((c[p>>2]&1073741828|0)!=0){kc=ic;lc=jc;break}ac=b+656|0;$b=(jgb(c[ac>>2]|0)|0)&65535;_b=$b<<16>>16<0;Ub=(_b?-$b&65535:$b)<<16>>16;Vb=d[110712+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){mc=Vb<<Ub-9}else{mc=Vb>>>((9-Ub|0)>>>0)}c[ac>>2]=_b?-mc|0:mc;do{if((jc|0)==0){if((Mb-ic|0)<=1){nc=ic;oc=1;break}_b=ic;y=$b;a[_b]=y;y=y>>8;a[_b+1|0]=y;nc=ic+2|0;oc=0}else{nc=ic;oc=1}}while(0);$b=b+660|0;_b=(jgb(c[$b>>2]|0)|0)&65535;ac=_b<<16>>16<0;Ub=(ac?-_b&65535:_b)<<16>>16;Vb=d[110712+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){pc=Vb<<Ub-9}else{pc=Vb>>>((9-Ub|0)>>>0)}c[$b>>2]=ac?-pc|0:pc;if((oc|0)!=0){kc=nc;lc=1;break}if((Mb-nc|0)<=1){kc=nc;lc=1;break}ac=nc;y=_b;a[ac]=y;y=y>>8;a[ac+1|0]=y;kc=nc+2|0;lc=0;break}if((Yb|0)<0){ac=b+624|0;_b=(jgb(c[ac>>2]|0)|0)&65535;$b=_b<<16>>16<0;Ub=($b?-_b&65535:_b)<<16>>16;Vb=d[110712+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){qc=Vb<<Ub-9}else{qc=Vb>>>((9-Ub|0)>>>0)}c[ac>>2]=$b?-qc|0:qc;do{if((Sb|0)==0){if((Mb-Xb|0)<=1){rc=Xb;sc=1;break}$b=Xb;y=_b;a[$b]=y;y=y>>8;a[$b+1|0]=y;rc=Xb+2|0;sc=0}else{rc=Xb;sc=1}}while(0);_b=b+656|0;$b=(jgb(c[_b>>2]|0)|0)&65535;ac=$b<<16>>16<0;Ub=(ac?-$b&65535:$b)<<16>>16;Vb=d[110712+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){tc=Vb<<Ub-9}else{tc=Vb>>>((9-Ub|0)>>>0)}c[_b>>2]=ac?-tc|0:tc;if((sc|0)!=0){kc=rc;lc=1;break}if((Mb-rc|0)<=1){kc=rc;lc=1;break}ac=rc;y=$b;a[ac]=y;y=y>>8;a[ac+1|0]=y;kc=rc+2|0;lc=0;break}if((Yb|0)>0){uc=Sb;vc=Xb;wc=0}else{kc=Xb;lc=Sb;break}while(1){ac=b+624+(wc<<2)|0;$b=(jgb(c[ac>>2]|0)|0)&65535;_b=$b<<16>>16<0;Ub=(_b?-$b&65535:$b)<<16>>16;Vb=d[110712+(Ub&255)|0]|0|256;Zb=Ub>>>8<<16;Ub=Zb>>16;if((Zb|0)>589824){xc=Vb<<Ub-9}else{xc=Vb>>>((9-Ub|0)>>>0)}c[ac>>2]=_b?-xc|0:xc;do{if((uc|0)==0){if((Mb-vc|0)<=1){yc=vc;zc=1;break}_b=vc;y=$b;a[_b]=y;y=y>>8;a[_b+1|0]=y;yc=vc+2|0;zc=0}else{yc=vc;zc=1}}while(0);do{if((c[p>>2]&1073741828|0)==0){$b=b+656+(wc<<2)|0;sb=(jgb(c[$b>>2]|0)|0)&65535;Gb=sb<<16>>16<0;_b=(Gb?-sb&65535:sb)<<16>>16;ac=d[110712+(_b&255)|0]|0|256;Ub=_b>>>8<<16;_b=Ub>>16;if((Ub|0)>589824){Ac=ac<<_b-9}else{Ac=ac>>>((9-_b|0)>>>0)}c[$b>>2]=Gb?-Ac|0:Ac;if((zc|0)!=0){Bc=yc;Cc=1;break}if((Mb-yc|0)<=1){Bc=yc;Cc=1;break}Gb=yc;y=sb;a[Gb]=y;y=y>>8;a[Gb+1|0]=y;Bc=yc+2|0;Cc=0}else{Bc=yc;Cc=zc}}while(0);Gb=wc+1|0;if((Gb|0)<(c[Ib>>2]|0)){uc=Cc;vc=Bc;wc=Gb}else{kc=Bc;lc=Cc;break}}}else{mrc(b+608+(Nb*88|0)+16|0,0,64)|0;kc=Xb;lc=Sb}}while(0);Ib=Nb+1|0;if((Ib|0)<(c[Eb>>2]|0)){Sb=lc;Xb=kc;Nb=Ib}else{Dc=lc;Ec=kc;break}}}else{Dc=dc;Ec=cc}cc=Ec;a[g+(Rb-1)|0]=(cc-bc|0)>>>1;bc=(c[p>>2]&1073741828|0)==0;Rb=vb;do{if((Dc|0)==0){if((Rb-cc|0)<=0){Fc=Ec;Gc=1;break}a[Ec]=5;vb=Ec+1|0;if((Rb-vb|0)<=0){Fc=vb;Gc=1;break}a[vb]=bc?6:3;Fc=Ec+2|0;Gc=0}else{Fc=Ec;Gc=1}}while(0);Ec=Gc;Gc=Fc;Fc=0;while(1){bc=b+488+(Fc<<2)|0;cc=c[bc>>2]|0;do{if((cc|0)==0){Hc=0}else if((cc|0)==1){Hc=256}else{Dc=(cc>>9)+cc|0;vb=Dc>>>0>65535>>>0;dc=vb?Dc>>>16:Dc;kc=vb?16:0;if((dc&65280|0)==0){Ic=kc;Jc=dc}else{Ic=kc|8;Jc=dc>>>8}dc=(d[1359664+Jc|0]|0)+Ic|0;kc=dc+1|0;vb=kc<<8;if((kc|0)<9){Hc=(d[110200+(Dc<<8-dc&255)|0]|0|vb)&65535;break}else{Hc=(d[110200+(Dc>>dc-8&255)|0]|0|vb)&65535;break}}}while(0);do{if((Ec|0)==0){if((Rb-Gc|0)<=1){Kc=Gc;Lc=1;break}cc=Gc;y=Hc;a[cc]=y;y=y>>8;a[cc+1|0]=y;Kc=Gc+2|0;Lc=0}else{Kc=Gc;Lc=1}}while(0);cc=Hc<<16>>16<0;vb=(cc?-Hc&65535:Hc)<<16>>16;dc=d[110712+(vb&255)|0]|0|256;Dc=vb>>>8<<16;vb=Dc>>16;if((Dc|0)>589824){Mc=dc<<vb-9}else{Mc=dc>>>((9-vb|0)>>>0)}c[bc>>2]=cc?-Mc|0:Mc;cc=Fc+1|0;if((cc|0)<3){Ec=Lc;Gc=Kc;Fc=cc}else{break}}Fc=c[p>>2]|0;if((Fc&1073741828|0)==0){Gc=Lc;Ec=Kc;Mc=0;while(1){Hc=b+516+(Mc<<2)|0;Ic=c[Hc>>2]|0;do{if((Ic|0)==1){Nc=256}else if((Ic|0)==0){Nc=0}else{Jc=(Ic>>9)+Ic|0;cc=Jc>>>0>65535>>>0;vb=cc?Jc>>>16:Jc;dc=cc?16:0;if((vb&65280|0)==0){Oc=dc;Pc=vb}else{Oc=dc|8;Pc=vb>>>8}vb=(d[1359664+Pc|0]|0)+Oc|0;dc=vb+1|0;cc=dc<<8;if((dc|0)<9){Nc=(d[110200+(Jc<<8-vb&255)|0]|0|cc)&65535;break}else{Nc=(d[110200+(Jc>>vb-8&255)|0]|0|cc)&65535;break}}}while(0);do{if((Gc|0)==0){if((Rb-Ec|0)<=1){Qc=Ec;Rc=1;break}Ic=Ec;y=Nc;a[Ic]=y;y=y>>8;a[Ic+1|0]=y;Qc=Ec+2|0;Rc=0}else{Qc=Ec;Rc=1}}while(0);Ic=Nc<<16>>16<0;bc=(Ic?-Nc&65535:Nc)<<16>>16;cc=d[110712+(bc&255)|0]|0|256;vb=bc>>>8<<16;bc=vb>>16;if((vb|0)>589824){Sc=cc<<bc-9}else{Sc=cc>>>((9-bc|0)>>>0)}c[Hc>>2]=Ic?-Sc|0:Sc;Ic=Mc+1|0;if((Ic|0)<3){Gc=Rc;Ec=Qc;Mc=Ic}else{break}}Tc=Qc;Uc=Rc;Vc=c[p>>2]|0}else{Tc=Kc;Uc=Lc;Vc=Fc}do{if((Vc&128|0)==0){Wc=Tc;Xc=Uc}else{if((Uc|0)!=0){Wc=Tc;Xc=1;break}if((Rb-Tc|0)<=0){Wc=Tc;Xc=1;break}a[Tc]=8;Fc=Tc+1|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=2;Fc=Tc+2|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=a[b+548|0]|0;Fc=Tc+3|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=a[b+549|0]|0;Fc=Tc+4|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=a[b+550|0]|0;Fc=Tc+5|0;if((Rb-Fc|0)<=0){Wc=Fc;Xc=1;break}a[Fc]=127;Wc=Tc+6|0;Xc=0}}while(0);do{if((c[p>>2]&256|0)==0){Yc=Wc;Zc=Xc}else{if((Xc|0)!=0){Yc=Wc;Zc=1;break}if((Rb-Wc|0)<=0){Yc=Wc;Zc=1;break}a[Wc]=9;Tc=Wc+1|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=2;Tc=Wc+2|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=a[b+544|0]|0;Tc=Wc+3|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=a[b+545|0]|0;Tc=Wc+4|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=a[b+546|0]|0;Tc=Wc+5|0;if((Rb-Tc|0)<=0){Yc=Tc;Zc=1;break}a[Tc]=a[b+547|0]|0;Yc=Wc+6|0;Zc=0}}while(0);Wc=c[p>>2]|0;Xc=(c[mb>>2]|0)==0;do{if((Wc&1073741828|0)==0){if(!Xc){break}if((Wc&16|0)!=0&(o|0)>0){mb=0;do{Tc=f+(mb<<2)|0;Uc=e+(mb<<2)|0;Vc=(c[Uc>>2]|0)-(c[Tc>>2]|0)|0;c[Uc>>2]=Vc;c[Tc>>2]=(Vc>>1)+(c[Tc>>2]|0);mb=mb+1|0;}while((mb|0)<(o|0))}if((c[Eb>>2]|0)<=0){break}mb=k;Hc=l;Tc=(o|0)>0;Vc=0;do{Uc=b+608+(Vc*88|0)|0;d:do{if((c[p>>2]&4194304)>>>0>3932160>>>0){N=378}else{if((c[Uc>>2]|0)!=2){N=378;break}Fc=c[b+608+(Vc*88|0)+4>>2]|0;switch(Fc|0){case 18:{if(!Tc){break d}Lc=b+608+(Vc*88|0)+16|0;Kc=b+608+(Vc*88|0)+20|0;Rc=b+608+(Vc*88|0)+8|0;Qc=b+608+(Vc*88|0)+48|0;Mc=b+608+(Vc*88|0)+52|0;Ec=b+608+(Vc*88|0)+12|0;Gc=0;do{Sc=c[Lc>>2]|0;Nc=(Sc-(c[Kc>>2]|0)>>1)+Sc|0;c[Kc>>2]=Sc;Sc=e+(Gc<<2)|0;Oc=c[Sc>>2]|0;c[Lc>>2]=Oc;Pc=(ca(Nc,c[Rc>>2]|0)|0)+512>>10;Ic=Oc-Pc|0;c[Sc>>2]=Ic;if(!((Nc|0)==0|(Oc|0)==(Pc|0))){c[Rc>>2]=(c[Rc>>2]|0)+(-((Ic^Nc)>>>29&4)|2)}Nc=c[Qc>>2]|0;Ic=(Nc-(c[Mc>>2]|0)>>1)+Nc|0;c[Mc>>2]=Nc;Nc=f+(Gc<<2)|0;Pc=c[Nc>>2]|0;c[Qc>>2]=Pc;Oc=(ca(Ic,c[Ec>>2]|0)|0)+512>>10;Sc=Pc-Oc|0;c[Nc>>2]=Sc;if(!((Ic|0)==0|(Pc|0)==(Oc|0))){c[Ec>>2]=(c[Ec>>2]|0)+(-((Sc^Ic)>>>29&4)|2)}Gc=Gc+1|0;}while((Gc|0)<(o|0));break};case 17:{if(!Tc){break d}Gc=b+608+(Vc*88|0)+16|0;Ec=b+608+(Vc*88|0)+20|0;Qc=b+608+(Vc*88|0)+8|0;Mc=b+608+(Vc*88|0)+48|0;Rc=b+608+(Vc*88|0)+52|0;Lc=b+608+(Vc*88|0)+12|0;Kc=0;do{Ic=c[Gc>>2]|0;Sc=Ic<<1;Oc=c[Ec>>2]|0;Pc=Sc-Oc|0;c[Ec>>2]=Ic;Ic=e+(Kc<<2)|0;Nc=c[Ic>>2]|0;c[Gc>>2]=Nc;bc=(ca(c[Qc>>2]|0,Pc)|0)+512>>10;cc=Nc-bc|0;c[Ic>>2]=cc;if(!((Sc|0)==(Oc|0)|(Nc|0)==(bc|0))){c[Qc>>2]=(c[Qc>>2]|0)+(-((cc^Pc)>>>29&4)|2)}Pc=c[Mc>>2]|0;cc=Pc<<1;bc=c[Rc>>2]|0;Nc=cc-bc|0;c[Rc>>2]=Pc;Pc=f+(Kc<<2)|0;Oc=c[Pc>>2]|0;c[Mc>>2]=Oc;Sc=(ca(c[Lc>>2]|0,Nc)|0)+512>>10;Ic=Oc-Sc|0;c[Pc>>2]=Ic;if(!((cc|0)==(bc|0)|(Oc|0)==(Sc|0))){c[Lc>>2]=(c[Lc>>2]|0)+(-((Ic^Nc)>>>29&4)|2)}Kc=Kc+1|0;}while((Kc|0)<(o|0));break};case-3:{if(!Tc){break d}Kc=b+608+(Vc*88|0)+16|0;Lc=b+608+(Vc*88|0)+48|0;Mc=b+608+(Vc*88|0)+12|0;Rc=b+608+(Vc*88|0)+8|0;Qc=0;do{Gc=c[Kc>>2]|0;Ec=c[Lc>>2]|0;Nc=f+(Qc<<2)|0;Ic=c[Nc>>2]|0;c[Kc>>2]=Ic;Sc=(ca(c[Mc>>2]|0,Ec)|0)+512>>10;Oc=Ic-Sc|0;c[Nc>>2]=Oc;if(!((Ec|0)==0|(Ic|0)==(Sc|0))){Sc=(Oc^Ec)>>31;Ec=(c[Mc>>2]^Sc)+(2-Sc)|0;c[Mc>>2]=(((Ec|0)>1024?1024:Ec)^Sc)-Sc}Sc=e+(Qc<<2)|0;Ec=c[Sc>>2]|0;c[Lc>>2]=Ec;Oc=(ca(c[Rc>>2]|0,Gc)|0)+512>>10;Ic=Ec-Oc|0;c[Sc>>2]=Ic;if(!((Gc|0)==0|(Ec|0)==(Oc|0))){Oc=(Ic^Gc)>>31;Gc=(c[Rc>>2]^Oc)+(2-Oc)|0;c[Rc>>2]=(((Gc|0)>1024?1024:Gc)^Oc)-Oc}Qc=Qc+1|0;}while((Qc|0)<(o|0));break};case-2:{if(!Tc){break d}Qc=b+608+(Vc*88|0)+48|0;Rc=b+608+(Vc*88|0)+12|0;Lc=b+608+(Vc*88|0)+8|0;Mc=0;do{Kc=c[Qc>>2]|0;Oc=f+(Mc<<2)|0;Gc=c[Oc>>2]|0;Ic=(ca(c[Rc>>2]|0,Kc)|0)+512>>10;Ec=Gc-Ic|0;c[Oc>>2]=Ec;if(!((Kc|0)==0|(Gc|0)==(Ic|0))){Ic=(Ec^Kc)>>31;Kc=(c[Rc>>2]^Ic)+(2-Ic)|0;c[Rc>>2]=(((Kc|0)>1024?1024:Kc)^Ic)-Ic}Ic=e+(Mc<<2)|0;Kc=c[Ic>>2]|0;c[Qc>>2]=Kc;Ec=(ca(c[Lc>>2]|0,Gc)|0)+512>>10;Oc=Kc-Ec|0;c[Ic>>2]=Oc;if(!((Gc|0)==0|(Kc|0)==(Ec|0))){Ec=(Oc^Gc)>>31;Gc=(c[Lc>>2]^Ec)+(2-Ec)|0;c[Lc>>2]=(((Gc|0)>1024?1024:Gc)^Ec)-Ec}Mc=Mc+1|0;}while((Mc|0)<(o|0));break};case-1:{if(!Tc){break d}Mc=b+608+(Vc*88|0)+16|0;Lc=b+608+(Vc*88|0)+8|0;Qc=b+608+(Vc*88|0)+12|0;Rc=0;do{Ec=c[Mc>>2]|0;Gc=e+(Rc<<2)|0;Oc=c[Gc>>2]|0;Kc=(ca(c[Lc>>2]|0,Ec)|0)+512>>10;Ic=Oc-Kc|0;c[Gc>>2]=Ic;if(!((Ec|0)==0|(Oc|0)==(Kc|0))){Kc=(Ic^Ec)>>31;Ec=(c[Lc>>2]^Kc)+(2-Kc)|0;c[Lc>>2]=(((Ec|0)>1024?1024:Ec)^Kc)-Kc}Kc=f+(Rc<<2)|0;Ec=c[Kc>>2]|0;c[Mc>>2]=Ec;Ic=(ca(c[Qc>>2]|0,Oc)|0)+512>>10;Gc=Ec-Ic|0;c[Kc>>2]=Gc;if(!((Oc|0)==0|(Ec|0)==(Ic|0))){Ic=(Gc^Oc)>>31;Oc=(c[Qc>>2]^Ic)+(2-Ic)|0;c[Qc>>2]=(((Oc|0)>1024?1024:Oc)^Ic)-Ic}Rc=Rc+1|0;}while((Rc|0)<(o|0));break};default:{if(!Tc){break d}Rc=b+608+(Vc*88|0)+8|0;Qc=b+608+(Vc*88|0)+12|0;Mc=0;Lc=0;Ic=Fc;while(1){Oc=Ic&7;Gc=c[b+608+(Vc*88|0)+16+(Mc<<2)>>2]|0;Ec=e+(Lc<<2)|0;Kc=c[Ec>>2]|0;c[b+608+(Vc*88|0)+16+(Oc<<2)>>2]=Kc;Sc=(ca(c[Rc>>2]|0,Gc)|0)+512>>10;Nc=Kc-Sc|0;c[Ec>>2]=Nc;if(!((Gc|0)==0|(Kc|0)==(Sc|0))){c[Rc>>2]=(c[Rc>>2]|0)+(-((Nc^Gc)>>>29&4)|2)}Gc=c[b+608+(Vc*88|0)+48+(Mc<<2)>>2]|0;Nc=f+(Lc<<2)|0;Sc=c[Nc>>2]|0;c[b+608+(Vc*88|0)+48+(Oc<<2)>>2]=Sc;Kc=(ca(c[Qc>>2]|0,Gc)|0)+512>>10;Ec=Sc-Kc|0;c[Nc>>2]=Ec;if(!((Gc|0)==0|(Sc|0)==(Kc|0))){c[Qc>>2]=(c[Qc>>2]|0)+(-((Ec^Gc)>>>29&4)|2)}_c=Mc+1&7;Gc=Lc+1|0;if((Gc|0)<(o|0)){Mc=_c;Lc=Gc;Ic=Oc+1|0}else{break}}if((_c|0)==0){break d}nrc(mb|0,b+608+(Vc*88|0)+16|0,32)|0;nrc(Hc|0,b+608+(Vc*88|0)+48|0,32)|0;c[b+608+(Vc*88|0)+16>>2]=c[k+(_c<<2)>>2];c[b+608+(Vc*88|0)+48>>2]=c[l+(_c<<2)>>2];Ic=Mc+2&7;c[b+608+(Vc*88|0)+20>>2]=c[k+(Ic<<2)>>2];c[b+608+(Vc*88|0)+52>>2]=c[l+(Ic<<2)>>2];Ic=Mc+3&7;c[b+608+(Vc*88|0)+24>>2]=c[k+(Ic<<2)>>2];c[b+608+(Vc*88|0)+56>>2]=c[l+(Ic<<2)>>2];Ic=Mc+4&7;c[b+608+(Vc*88|0)+28>>2]=c[k+(Ic<<2)>>2];c[b+608+(Vc*88|0)+60>>2]=c[l+(Ic<<2)>>2];Ic=Mc+5&7;c[b+608+(Vc*88|0)+32>>2]=c[k+(Ic<<2)>>2];c[b+608+(Vc*88|0)+64>>2]=c[l+(Ic<<2)>>2];Ic=Mc+6&7;c[b+608+(Vc*88|0)+36>>2]=c[k+(Ic<<2)>>2];c[b+608+(Vc*88|0)+68>>2]=c[l+(Ic<<2)>>2];Ic=Mc+7&7;c[b+608+(Vc*88|0)+40>>2]=c[k+(Ic<<2)>>2];c[b+608+(Vc*88|0)+72>>2]=c[l+(Ic<<2)>>2];c[b+608+(Vc*88|0)+44>>2]=c[k+(Mc<<2)>>2];c[b+608+(Vc*88|0)+76>>2]=c[l+(Mc<<2)>>2];break d}}}}while(0);e:do{if((N|0)==378){N=0;Ic=c[b+608+(Vc*88|0)+4>>2]|0;switch(Ic|0){case 17:{if(!Tc){break e}Lc=b+608+(Vc*88|0)+16|0;Qc=b+608+(Vc*88|0)+20|0;Rc=b+608+(Vc*88|0)+8|0;Fc=b+608+(Vc*88|0)+48|0;Oc=b+608+(Vc*88|0)+52|0;Gc=b+608+(Vc*88|0)+12|0;Ec=Uc|0;Kc=0;do{Sc=c[Lc>>2]|0;Nc=Sc<<1;bc=c[Qc>>2]|0;cc=Nc-bc|0;c[Qc>>2]=Sc;Sc=e+(Kc<<2)|0;Pc=c[Sc>>2]|0;c[Lc>>2]=Pc;if((cc|0)==(cc<<16>>16|0)){$c=(ca(c[Rc>>2]|0,cc)|0)+512>>10}else{vb=c[Rc>>2]|0;$c=(ca(vb,cc>>9&-128)|0|1)+((ca(vb,cc&65535)|0)>>9)>>1}vb=Pc-$c|0;c[Sc>>2]=vb;if(!((Nc|0)==(bc|0)|(Pc|0)==($c|0))){Pc=vb^cc;c[Rc>>2]=(c[Rc>>2]|0)+(Pc>>>31)+(c[Ec>>2]^Pc>>31)}Pc=c[Fc>>2]|0;cc=Pc<<1;vb=c[Oc>>2]|0;bc=cc-vb|0;c[Oc>>2]=Pc;Pc=f+(Kc<<2)|0;Nc=c[Pc>>2]|0;c[Fc>>2]=Nc;if((bc|0)==(bc<<16>>16|0)){ad=(ca(c[Gc>>2]|0,bc)|0)+512>>10}else{Sc=c[Gc>>2]|0;ad=(ca(Sc,bc>>9&-128)|0|1)+((ca(Sc,bc&65535)|0)>>9)>>1}Sc=Nc-ad|0;c[Pc>>2]=Sc;if(!((cc|0)==(vb|0)|(Nc|0)==(ad|0))){Nc=Sc^bc;c[Gc>>2]=(c[Gc>>2]|0)+(Nc>>>31)+(c[Ec>>2]^Nc>>31)}Kc=Kc+1|0;}while((Kc|0)<(o|0));break};case-2:{if(!Tc){break e}Kc=b+608+(Vc*88|0)+48|0;Ec=b+608+(Vc*88|0)+12|0;Gc=b+608+(Vc*88|0)+8|0;Fc=Uc|0;Oc=0;do{Rc=c[Kc>>2]|0;Lc=f+(Oc<<2)|0;Qc=c[Lc>>2]|0;if((Rc|0)==(Rc<<16>>16|0)){bd=(ca(c[Ec>>2]|0,Rc)|0)+512>>10}else{Mc=c[Ec>>2]|0;bd=(ca(Mc,Rc>>9&-128)|0|1)+((ca(Mc,Rc&65535)|0)>>9)>>1}Mc=Qc-bd|0;c[Lc>>2]=Mc;do{if(!((Rc|0)==0|(Qc|0)==(bd|0))){Lc=c[Fc>>2]|0;Nc=c[Ec>>2]|0;if((Mc^Rc|0)<0){bc=Nc-Lc|0;c[Ec>>2]=bc;if(!((bc|0)<-1024)){break}c[Ec>>2]=-1024;break}else{bc=Nc+Lc|0;c[Ec>>2]=bc;if((bc|0)<=1024){break}c[Ec>>2]=1024;break}}}while(0);Rc=e+(Oc<<2)|0;Mc=c[Rc>>2]|0;c[Kc>>2]=Mc;if((Qc|0)==(Qc<<16>>16|0)){cd=(ca(c[Gc>>2]|0,Qc)|0)+512>>10}else{bc=c[Gc>>2]|0;cd=(ca(bc,Qc>>9&-128)|0|1)+((ca(bc,Qc&65535)|0)>>9)>>1}bc=Mc-cd|0;c[Rc>>2]=bc;do{if(!((Qc|0)==0|(Mc|0)==(cd|0))){Rc=c[Fc>>2]|0;Lc=c[Gc>>2]|0;if((bc^Qc|0)<0){Nc=Lc-Rc|0;c[Gc>>2]=Nc;if(!((Nc|0)<-1024)){break}c[Gc>>2]=-1024;break}else{Nc=Lc+Rc|0;c[Gc>>2]=Nc;if((Nc|0)<=1024){break}c[Gc>>2]=1024;break}}}while(0);Oc=Oc+1|0;}while((Oc|0)<(o|0));break};case-1:{if(!Tc){break e}Oc=b+608+(Vc*88|0)+16|0;Gc=b+608+(Vc*88|0)+8|0;Fc=b+608+(Vc*88|0)+12|0;Kc=Uc|0;Ec=0;do{Qc=c[Oc>>2]|0;bc=e+(Ec<<2)|0;Mc=c[bc>>2]|0;if((Qc|0)==(Qc<<16>>16|0)){dd=(ca(c[Gc>>2]|0,Qc)|0)+512>>10}else{Nc=c[Gc>>2]|0;dd=(ca(Nc,Qc>>9&-128)|0|1)+((ca(Nc,Qc&65535)|0)>>9)>>1}Nc=Mc-dd|0;c[bc>>2]=Nc;do{if(!((Qc|0)==0|(Mc|0)==(dd|0))){bc=c[Kc>>2]|0;Rc=c[Gc>>2]|0;if((Nc^Qc|0)<0){Lc=Rc-bc|0;c[Gc>>2]=Lc;if(!((Lc|0)<-1024)){break}c[Gc>>2]=-1024;break}else{Lc=Rc+bc|0;c[Gc>>2]=Lc;if((Lc|0)<=1024){break}c[Gc>>2]=1024;break}}}while(0);Qc=f+(Ec<<2)|0;Nc=c[Qc>>2]|0;c[Oc>>2]=Nc;if((Mc|0)==(Mc<<16>>16|0)){ed=(ca(c[Fc>>2]|0,Mc)|0)+512>>10}else{Lc=c[Fc>>2]|0;ed=(ca(Lc,Mc>>9&-128)|0|1)+((ca(Lc,Mc&65535)|0)>>9)>>1}Lc=Nc-ed|0;c[Qc>>2]=Lc;do{if(!((Mc|0)==0|(Nc|0)==(ed|0))){Qc=c[Kc>>2]|0;bc=c[Fc>>2]|0;if((Lc^Mc|0)<0){Rc=bc-Qc|0;c[Fc>>2]=Rc;if(!((Rc|0)<-1024)){break}c[Fc>>2]=-1024;break}else{Rc=bc+Qc|0;c[Fc>>2]=Rc;if((Rc|0)<=1024){break}c[Fc>>2]=1024;break}}}while(0);Ec=Ec+1|0;}while((Ec|0)<(o|0));break};case-3:{if(!Tc){break e}Ec=b+608+(Vc*88|0)+16|0;Fc=b+608+(Vc*88|0)+48|0;Kc=b+608+(Vc*88|0)+12|0;Oc=b+608+(Vc*88|0)+8|0;Gc=Uc|0;Mc=0;do{Lc=c[Ec>>2]|0;Nc=c[Fc>>2]|0;Rc=f+(Mc<<2)|0;Qc=c[Rc>>2]|0;c[Ec>>2]=Qc;if((Nc|0)==(Nc<<16>>16|0)){fd=(ca(c[Kc>>2]|0,Nc)|0)+512>>10}else{bc=c[Kc>>2]|0;fd=(ca(bc,Nc>>9&-128)|0|1)+((ca(bc,Nc&65535)|0)>>9)>>1}bc=Qc-fd|0;c[Rc>>2]=bc;do{if(!((Nc|0)==0|(Qc|0)==(fd|0))){Rc=c[Gc>>2]|0;Sc=c[Kc>>2]|0;if((bc^Nc|0)<0){vb=Sc-Rc|0;c[Kc>>2]=vb;if(!((vb|0)<-1024)){break}c[Kc>>2]=-1024;break}else{vb=Sc+Rc|0;c[Kc>>2]=vb;if((vb|0)<=1024){break}c[Kc>>2]=1024;break}}}while(0);Nc=e+(Mc<<2)|0;bc=c[Nc>>2]|0;c[Fc>>2]=bc;if((Lc|0)==(Lc<<16>>16|0)){gd=(ca(c[Oc>>2]|0,Lc)|0)+512>>10}else{Qc=c[Oc>>2]|0;gd=(ca(Qc,Lc>>9&-128)|0|1)+((ca(Qc,Lc&65535)|0)>>9)>>1}Qc=bc-gd|0;c[Nc>>2]=Qc;do{if(!((Lc|0)==0|(bc|0)==(gd|0))){Nc=c[Gc>>2]|0;vb=c[Oc>>2]|0;if((Qc^Lc|0)<0){Rc=vb-Nc|0;c[Oc>>2]=Rc;if(!((Rc|0)<-1024)){break}c[Oc>>2]=-1024;break}else{Rc=vb+Nc|0;c[Oc>>2]=Rc;if((Rc|0)<=1024){break}c[Oc>>2]=1024;break}}}while(0);Mc=Mc+1|0;}while((Mc|0)<(o|0));break};case 18:{if(!Tc){break e}Mc=b+608+(Vc*88|0)+16|0;Oc=b+608+(Vc*88|0)+20|0;Gc=b+608+(Vc*88|0)+8|0;Fc=b+608+(Vc*88|0)+48|0;Kc=b+608+(Vc*88|0)+52|0;Ec=b+608+(Vc*88|0)+12|0;Lc=Uc|0;Qc=0;do{bc=c[Mc>>2]|0;Rc=(bc-(c[Oc>>2]|0)>>1)+bc|0;c[Oc>>2]=bc;bc=e+(Qc<<2)|0;Nc=c[bc>>2]|0;c[Mc>>2]=Nc;if((Rc|0)==(Rc<<16>>16|0)){hd=(ca(c[Gc>>2]|0,Rc)|0)+512>>10}else{vb=c[Gc>>2]|0;hd=(ca(vb,Rc>>9&-128)|0|1)+((ca(vb,Rc&65535)|0)>>9)>>1}vb=Nc-hd|0;c[bc>>2]=vb;if(!((Rc|0)==0|(Nc|0)==(hd|0))){Nc=vb^Rc;c[Gc>>2]=(c[Gc>>2]|0)+(Nc>>>31)+(c[Lc>>2]^Nc>>31)}Nc=c[Fc>>2]|0;Rc=(Nc-(c[Kc>>2]|0)>>1)+Nc|0;c[Kc>>2]=Nc;Nc=f+(Qc<<2)|0;vb=c[Nc>>2]|0;c[Fc>>2]=vb;if((Rc|0)==(Rc<<16>>16|0)){id=(ca(c[Ec>>2]|0,Rc)|0)+512>>10}else{bc=c[Ec>>2]|0;id=(ca(bc,Rc>>9&-128)|0|1)+((ca(bc,Rc&65535)|0)>>9)>>1}bc=vb-id|0;c[Nc>>2]=bc;if(!((Rc|0)==0|(vb|0)==(id|0))){vb=bc^Rc;c[Ec>>2]=(c[Ec>>2]|0)+(vb>>>31)+(c[Lc>>2]^vb>>31)}Qc=Qc+1|0;}while((Qc|0)<(o|0));break};default:{if(!Tc){break e}Qc=b+608+(Vc*88|0)+8|0;Lc=b+608+(Vc*88|0)+12|0;Ec=Uc|0;Fc=0;Kc=0;Gc=Ic;while(1){Mc=Gc&7;Oc=c[b+608+(Vc*88|0)+16+(Fc<<2)>>2]|0;vb=e+(Kc<<2)|0;Rc=c[vb>>2]|0;c[b+608+(Vc*88|0)+16+(Mc<<2)>>2]=Rc;if((Oc|0)==(Oc<<16>>16|0)){jd=(ca(c[Qc>>2]|0,Oc)|0)+512>>10}else{bc=c[Qc>>2]|0;jd=(ca(bc,Oc>>9&-128)|0|1)+((ca(bc,Oc&65535)|0)>>9)>>1}bc=Rc-jd|0;c[vb>>2]=bc;if(!((Oc|0)==0|(Rc|0)==(jd|0))){Rc=bc^Oc;c[Qc>>2]=(c[Qc>>2]|0)+(Rc>>>31)+(c[Ec>>2]^Rc>>31)}Rc=c[b+608+(Vc*88|0)+48+(Fc<<2)>>2]|0;Oc=f+(Kc<<2)|0;bc=c[Oc>>2]|0;c[b+608+(Vc*88|0)+48+(Mc<<2)>>2]=bc;if((Rc|0)==(Rc<<16>>16|0)){kd=(ca(c[Lc>>2]|0,Rc)|0)+512>>10}else{vb=c[Lc>>2]|0;kd=(ca(vb,Rc>>9&-128)|0|1)+((ca(vb,Rc&65535)|0)>>9)>>1}vb=bc-kd|0;c[Oc>>2]=vb;if(!((Rc|0)==0|(bc|0)==(kd|0))){bc=vb^Rc;c[Lc>>2]=(c[Lc>>2]|0)+(bc>>>31)+(c[Ec>>2]^bc>>31)}ld=Fc+1&7;bc=Kc+1|0;if((bc|0)<(o|0)){Fc=ld;Kc=bc;Gc=Mc+1|0}else{break}}if((ld|0)==0){break e}nrc(mb|0,b+608+(Vc*88|0)+16|0,32)|0;nrc(Hc|0,b+608+(Vc*88|0)+48|0,32)|0;c[b+608+(Vc*88|0)+16>>2]=c[k+(ld<<2)>>2];c[b+608+(Vc*88|0)+48>>2]=c[l+(ld<<2)>>2];Gc=Fc+2&7;c[b+608+(Vc*88|0)+20>>2]=c[k+(Gc<<2)>>2];c[b+608+(Vc*88|0)+52>>2]=c[l+(Gc<<2)>>2];Gc=Fc+3&7;c[b+608+(Vc*88|0)+24>>2]=c[k+(Gc<<2)>>2];c[b+608+(Vc*88|0)+56>>2]=c[l+(Gc<<2)>>2];Gc=Fc+4&7;c[b+608+(Vc*88|0)+28>>2]=c[k+(Gc<<2)>>2];c[b+608+(Vc*88|0)+60>>2]=c[l+(Gc<<2)>>2];Gc=Fc+5&7;c[b+608+(Vc*88|0)+32>>2]=c[k+(Gc<<2)>>2];c[b+608+(Vc*88|0)+64>>2]=c[l+(Gc<<2)>>2];Gc=Fc+6&7;c[b+608+(Vc*88|0)+36>>2]=c[k+(Gc<<2)>>2];c[b+608+(Vc*88|0)+68>>2]=c[l+(Gc<<2)>>2];Gc=Fc+7&7;c[b+608+(Vc*88|0)+40>>2]=c[k+(Gc<<2)>>2];c[b+608+(Vc*88|0)+72>>2]=c[l+(Gc<<2)>>2];c[b+608+(Vc*88|0)+44>>2]=c[k+(Fc<<2)>>2];c[b+608+(Vc*88|0)+76>>2]=c[l+(Fc<<2)>>2];break e}}}}while(0);Vc=Vc+1|0;}while((Vc|0)<(c[Eb>>2]|0))}else{if(!(Xc&(o|0)>0)){break}Vc=b+608|0;Hc=0;mb=0;do{Tc=e+(Hc<<2)|0;Uc=c[Tc>>2]|0;Gc=c[Eb>>2]|0;if((Gc|0)==0){md=Uc}else{Kc=Vc;Ec=Uc;Uc=Gc;while(1){Gc=Uc-1|0;Lc=c[Kc+4>>2]|0;if((Lc|0)>8){Qc=Kc+16|0;Ic=c[Qc>>2]|0;if((Lc&1|0)==0){nd=(Ic*3|0)-(c[Kc+20>>2]|0)>>1}else{nd=(Ic<<1)-(c[Kc+20>>2]|0)|0}c[Kc+20>>2]=Ic;c[Qc>>2]=Ec;od=nd}else{Qc=c[Kc+16+(mb<<2)>>2]|0;c[Kc+16+((Lc+mb&7)<<2)>>2]=Ec;od=Qc}if((od|0)==(od<<16>>16|0)){Qc=c[Kc+8>>2]|0;pd=(ca(Qc,od)|0)+512>>10;qd=Qc}else{Qc=c[Kc+8>>2]|0;pd=(ca(Qc,od>>9&-128)|0|1)+((ca(Qc,od&65535)|0)>>9)>>1;qd=Qc}Qc=Ec-pd|0;if(!((od|0)==0|(Ec|0)==(pd|0))){Lc=Qc^od;c[Kc+8>>2]=qd+(Lc>>>31)+(c[Kc>>2]^Lc>>31)}if((Gc|0)==0){md=Qc;break}else{Kc=Kc+88|0;Ec=Qc;Uc=Gc}}}mb=mb+1&7;c[Tc>>2]=md;Hc=Hc+1|0;}while((Hc|0)<(o|0));if((mb|0)==0){break}Hc=c[Eb>>2]|0;if((Hc|0)==0){break}Vc=m;Uc=n;Ec=b+608|0;Kc=mb;Gc=Hc;while(1){Hc=Gc-1|0;if(((c[Ec+4>>2]|0)-1|0)>>>0<8>>>0){nrc(Vc|0,Ec+16|0,32)|0;nrc(Uc|0,Ec+48|0,32)|0;c[Ec+16>>2]=c[m+(Kc<<2)>>2];c[Ec+48>>2]=c[n+(Kc<<2)>>2];Qc=Kc+1&7;c[Ec+20>>2]=c[m+(Qc<<2)>>2];c[Ec+52>>2]=c[n+(Qc<<2)>>2];Qc=Kc+2&7;c[Ec+24>>2]=c[m+(Qc<<2)>>2];c[Ec+56>>2]=c[n+(Qc<<2)>>2];Qc=Kc+3&7;c[Ec+28>>2]=c[m+(Qc<<2)>>2];c[Ec+60>>2]=c[n+(Qc<<2)>>2];Qc=Kc+4&7;c[Ec+32>>2]=c[m+(Qc<<2)>>2];c[Ec+64>>2]=c[n+(Qc<<2)>>2];Qc=Kc+5&7;c[Ec+36>>2]=c[m+(Qc<<2)>>2];c[Ec+68>>2]=c[n+(Qc<<2)>>2];Qc=Kc+6&7;c[Ec+40>>2]=c[m+(Qc<<2)>>2];c[Ec+72>>2]=c[n+(Qc<<2)>>2];Qc=Kc+7&7;c[Ec+44>>2]=c[m+(Qc<<2)>>2];c[Ec+76>>2]=c[n+(Qc<<2)>>2];rd=Kc&7}else{rd=Kc}if((Hc|0)==0){break}else{Ec=Ec+88|0;Kc=rd;Gc=Hc}}}}while(0);do{if((Zc|0)==0){if((Rb-Yc|0)<=0){sd=Yc;td=1;break}a[Yc]=-118;sd=Yc+1|0;td=0}else{sd=Yc;td=1}}while(0);Yc=sd+3|0;Zc=Rb-sd|0;rd=(Zc|0)<0;n=rd?0:Yc;m=rd?0:Zc;rd=b+28|0;c[rd>>2]=m<<3;Eb=b+16|0;c[Eb>>2]=n;md=b+24|0;c[md>>2]=n+m;m=b+20|0;c[m>>2]=n;n=b+12|0;c[n>>2]=32;qd=b+8|0;c[qd>>2]=0;od=(o|0)>0;do{if((c[p>>2]&1073741828|0)==0){if(!od){break}pd=b+488|0;nd=b+56|0;e=b+516|0;Xc=b+60|0;l=0;do{kgb(b,pd,c[(c[nd>>2]|0)+(l<<2)>>2]|0);kgb(b,e,c[(c[Xc>>2]|0)+(l<<2)>>2]|0);l=l+1|0;}while((l|0)<(o|0))}else{if(!od){break}l=b+488|0;Xc=b+56|0;e=0;do{kgb(b,l,c[(c[Xc>>2]|0)+(e<<2)>>2]|0);e=e+1|0;}while((e|0)<(o|0))}}while(0);lgb(b);if((c[n>>2]|0)<32){od=c[qd>>2]&255;while(1){e=c[m>>2]|0;c[m>>2]=e+1;a[e]=od;e=(c[qd>>2]|0)>>>8;c[qd>>2]=e;Xc=(c[n>>2]|0)+8|0;c[n>>2]=Xc;if((Xc|0)<32){od=e&255}else{break}}}c[n>>2]=32;c[qd>>2]=0;od=(c[m>>2]|0)-(c[Eb>>2]|0)<<3>>3;e=od+1>>1;if((td|0)==0&(Zc|0)>2){a[sd]=e;a[sd+1|0]=e>>>8;a[sd+2|0]=e>>>16;e=Rb-Yc|0;Yc=e>>>0>od>>>0?od:e;ud=sd+(Yc+3)|0;vd=(Yc|0)!=(od|0)|0}else{ud=sd;vd=1}do{if((od&1|0)==0){wd=ud;xd=vd}else{if((vd|0)!=0){wd=ud;xd=1;break}if((Rb-ud|0)<=0){wd=ud;xd=1;break}a[ud]=0;wd=ud+1|0;xd=0}}while(0);do{if((Ma|0)==0){yd=wd}else{do{if((xd|0)==0){if((Rb-wd|0)<=0){zd=wd;Ad=1;break}a[wd]=-116;zd=wd+1|0;Ad=0}else{zd=wd;Ad=1}}while(0);ud=zd+7|0;vd=Rb-zd|0;od=(vd|0)<0;sd=od?0:ud;Yc=od?0:vd;c[rd>>2]=Yc<<3;c[Eb>>2]=sd;c[md>>2]=sd+Yc;c[m>>2]=sd;c[n>>2]=32;c[qd>>2]=0;Yc=c[p>>2]|0;od=c[b+424>>2]|0;e=c[b+428>>2]|0;f:do{if((Yc&128|0)==0){Zc=a[b+544|0]|0;td=Zc&255;Xc=(1<<td)-1|0;l=(d[b+546|0]|0)+(d[b+545|0]|0)+(d[b+547|0]|0)|0;if(Zc<<24>>24==0){N=570;break}Zc=(o|0)>0;if((Yc&1073741828|0)!=0){if(Zc){Bd=0;Cd=0;Dd=32;Ed=sd}else{N=570;break}while(1){nd=c[od+(Bd<<2)>>2]>>l&Xc;pd=nd<<32-Dd|Cd;if((Dd|0)>(td|0)){Fd=Dd;Gd=pd;Id=Ed}else{k=Ed;y=pd;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=(c[m>>2]|0)+4|0;c[m>>2]=k;Fd=Dd+32|0;Gd=(Dd|0)==32?0:nd>>>(Dd>>>0);Id=k}k=Fd-td|0;c[qd>>2]=Gd;c[n>>2]=k;nd=Bd+1|0;if((nd|0)<(o|0)){Bd=nd;Cd=Gd;Dd=k;Ed=Id}else{Jd=k;break f}}}if(Zc){Kd=0;Ld=0;Md=32;Nd=sd}else{N=570;break}while(1){Tc=c[od+(Kd<<2)>>2]>>l&Xc;k=Tc<<32-Md|Ld;if((Md|0)>(td|0)){Od=Md;Pd=k;Qd=Nd}else{nd=Nd;y=k;a[nd]=y;y=y>>8;a[nd+1|0]=y;y=y>>8;a[nd+2|0]=y;y=y>>8;a[nd+3|0]=y;nd=(c[m>>2]|0)+4|0;c[m>>2]=nd;Od=Md+32|0;Pd=(Md|0)==32?0:Tc>>>(Md>>>0);Qd=nd}nd=Od-td|0;c[qd>>2]=Pd;c[n>>2]=nd;Tc=c[e+(Kd<<2)>>2]>>l&Xc;k=Tc<<32-nd|Pd;if((nd|0)>(td|0)){Rd=nd;Sd=k;Td=Qd}else{pd=Qd;y=k;a[pd]=y;y=y>>8;a[pd+1|0]=y;y=y>>8;a[pd+2|0]=y;y=y>>8;a[pd+3|0]=y;pd=(c[m>>2]|0)+4|0;c[m>>2]=pd;Rd=nd+32|0;Sd=(nd|0)==32?0:Tc>>>(nd>>>0);Td=pd}pd=Rd-td|0;c[qd>>2]=Sd;c[n>>2]=pd;nd=Kd+1|0;if((nd|0)<(o|0)){Kd=nd;Ld=Sd;Md=pd;Nd=Td}else{Jd=pd;break}}}else{td=(o|0)>0;if((Yc&1073741828|0)==0){if(td){Ud=0}else{N=570;break}while(1){mgb(b,od+(Ud<<2)|0);mgb(b,e+(Ud<<2)|0);Xc=Ud+1|0;if((Xc|0)<(o|0)){Ud=Xc}else{N=570;break}}}else{if(td){Vd=0}else{N=570;break}while(1){mgb(b,od+(Vd<<2)|0);Xc=Vd+1|0;if((Xc|0)<(o|0)){Vd=Xc}else{N=570;break}}}}}while(0);if((N|0)==570){Jd=c[n>>2]|0}if((Jd|0)<32){od=c[qd>>2]&255;while(1){e=c[m>>2]|0;c[m>>2]=e+1;a[e]=od;e=(c[qd>>2]|0)>>>8;c[qd>>2]=e;Yc=(c[n>>2]|0)+8|0;c[n>>2]=Yc;if((Yc|0)<32){od=e&255}else{break}}}c[n>>2]=32;c[qd>>2]=0;od=(c[m>>2]|0)-(c[Eb>>2]|0)<<3>>3;e=od+5>>1;if(!((Ad|0)==0&(vd|0)>2)){yd=zd;break}a[zd]=e;a[zd+1|0]=e>>>8;a[zd+2|0]=e>>>16;e=zd+3|0;if((Rb-e|0)<=3){yd=e;break}Yc=e;y=c[b+464>>2]|0;a[Yc]=y;y=y>>8;a[Yc+1|0]=y;y=y>>8;a[Yc+2|0]=y;y=y>>8;a[Yc+3|0]=y;Yc=Rb-ud|0;e=Yc>>>0>od>>>0?od:Yc;Yc=zd+(e+7)|0;if(!((od&1|0)!=0&(e|0)==(od|0))){yd=Yc;break}if((Rb-Yc|0)<=0){yd=Yc;break}a[Yc]=0;yd=zd+(e+8)|0}}while(0);zd=yd-Lb|0;Lb=g+4|0;y=zd-8|0;a[Lb]=y;y=y>>8;a[Lb+1|0]=y;y=y>>8;a[Lb+2|0]=y;y=y>>8;a[Lb+3|0]=y;ub=zd;i=j;return ub|0}function hgb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;j=i;i=i+2920|0;k=j|0;l=j+1424|0;m=j+1512|0;n=m;mrc(n|0,0,1408)|0;o=b+32|0;p=c[o>>2]|0;q=p<<2;r=0;while(1){if((r|0)>=(p|0)){break}if((c[e+(r<<2)>>2]|0)==0){r=r+1|0}else{break}}if((r|0)==(p|0)){mrc(b+608|0,0,1408)|0;mrc(b+468|0,0,76)|0;c[b+576>>2]=0;s=0;i=j;return s|0}r=b+460|0;t=((c[r>>2]|0)>>>18<<8&7936)+1024|0;u=t>>>0<6912>>>0?t:6912;t=ngb(b)|0;if((t|0)<0){s=t;i=j;return s|0}t=(f|0)!=0;f=c[b+596>>2]|0;if(t|(f|0)>6){c[b+604>>2]=0;c[b+600>>2]=0}v=b+596|0;a:do{if((f|0)>0){w=b+604|0;x=b+600|0;y=b+592|0;z=b+2016|0;A=b+448|0;B=b+360|0;C=e;D=(p|0)==0;E=l;F=l|0;G=l+4|0;H=(p|0)>2048?2048:p;I=l+16|0;J=l+20|0;K=l+16|0;L=b+392|0;M=b+608|0;N=b+576|0;O=0;P=-1;R=f;while(1){b:do{if((O|0)==0){S=c[x>>2]|0;T=0}else{U=c[w>>2]|0;while(1){V=(U|0)==0;W=c[x>>2]|0;if(V){X=0}else{X=W&U-1|U}if((X|0)!=(W|0)){S=X;T=1;break b}if(V){Y=1}else{Y=(c[y>>2]|0)-1&U<<1}c[w>>2]=Y;if((O|0)<(R|0)){U=Y}else{break a}}}}while(0);U=c[z>>2]|0;V=U+(S*19|0)+1|0;W=d[1584552+(c[A>>2]|0)|0]|0;c:while(1){nrc(c[B>>2]|0,C|0,q)|0;mrc(n|0,0,1408)|0;if((W|0)>0){Z=0;do{mrc(E|0,0,88)|0;c[F>>2]=a[V]|0;_=a[U+(S*19|0)+2+Z|0]|0;c[G>>2]=_<<24>>24<0?1:_<<24>>24;_=Z&1;$=b+360+(_<<3)|0;aa=b+360+((_^1)<<3)|0;wgb(c[$>>2]|0,c[aa>>2]|0,H,l,-1);d:do{if((Z|0)==0){_=c[G>>2]|0;if((_|0)<=8){if((_|0)>1){ba=0;ca=_;da=0}else{break}while(1){ea=ba&7;fa=ca+7&7;ga=l+16+(fa<<2)|0;ha=l+16+(ea<<2)|0;ia=c[ha>>2]^c[ga>>2];c[ha>>2]=ia;ja=c[ga>>2]^ia;c[ga>>2]=ja;c[ha>>2]=c[ha>>2]^ja;ja=da+1|0;if((ja|0)<((c[G>>2]|0)/2|0|0)){ba=ea+1|0;ca=fa;da=ja}else{break d}}}ja=c[I>>2]|0;if((_&1|0)==0){fa=(ja*3|0)-(c[J>>2]|0)>>1;c[J>>2]=ja;c[I>>2]=fa;ka=(fa*3|0)-ja>>1}else{fa=(ja<<1)-(c[J>>2]|0)|0;c[J>>2]=ja;c[I>>2]=fa;ka=(fa<<1)-ja|0}c[J>>2]=ka}else{mrc(K|0,0,32)|0}}while(0);nrc(m+(Z*88|0)|0,E|0,88)|0;wgb(c[$>>2]|0,c[aa>>2]|0,p,l,1);Z=Z+1|0;}while((Z|0)<(W|0));la=W&1}else{la=0}ma=b+360+(la<<3)|0;if(D){na=44;break}Z=c[ma>>2]|0;ja=p;while(1){fa=ja-1|0;ea=Z+4|0;ha=c[Z>>2]|0;ga=(ha|0)>-1?ha:-ha|0;ha=(ga>>>9)+ga|0;if(!(ha>>>0<256>>>0)){do{if(ha>>>0<65536>>>0){oa=(a[785608+(ha>>>8)|0]|0)+8|0}else{if(ha>>>0<16777216>>>0){oa=(a[785608+(ha>>>16)|0]|0)+16|0;break}else{oa=(a[785608+(ha>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[110200+(ha>>>((oa-9|0)>>>0)&255)|0]|oa<<8)>>>0<u>>>0)){break}}if((fa|0)==0){na=44;break c}else{Z=ea;ja=fa}}if((W|0)==0){pa=P;break}else{W=W>>1}}do{if((na|0)==44){na=0;if((P|0)==0){pa=P;break}nrc(c[L>>2]|0,c[ma>>2]|0,q)|0;nrc(M|0,n|0,1408)|0;c[N>>2]=W;c[x>>2]=S;pa=0}}while(0);W=O+1|0;if(T){U=c[w>>2]|0;if((U|0)==0){qa=1}else{qa=(c[y>>2]|0)-1&U<<1}c[w>>2]=qa}U=c[v>>2]|0;if((W|0)<(U|0)){O=W;P=pa;R=U}else{break}}}}while(0);pa=b+440|0;e:do{if((c[pa>>2]|0)==0){if((h|0)==0){break}nrc(e|0,c[b+392>>2]|0,q)|0}else{v=k;qa=((c[r>>2]|0)>>>18<<8&7936)+1024|0;T=k+1412|0;c[T>>2]=qa>>>0<6912>>>0?qa:6912;qa=b+576|0;S=c[qa>>2]|0;n=k+1408|0;c[n>>2]=S;ma=S+2|0;if((ma|0)>0){na=0;do{u=b+72+(na<<3)|0;A4a(u,b+216+(na<<3)|0,c[o>>2]<<2);if((c[u>>2]|0)==0){break e}if((c[r>>2]&1073741828|0)==0){u=b+72+(na<<3)+4|0;A4a(u,b+216+(na<<3)+4|0,c[o>>2]<<2);if((c[u>>2]|0)==0){break e}}na=na+1|0;}while((na|0)<(ma|0))}ma=b+608|0;na=ma;nrc(v|0,na|0,1408)|0;u=e;nrc(c[b+72>>2]|0,u|0,c[o>>2]<<2)|0;f:do{if((S|0)>0){oa=0;la=S;while(1){if((c[k+(oa*88|0)+4>>2]|0)==0){ra=oa;sa=la;break f}l=oa+1|0;wgb(c[b+72+(oa<<3)>>2]|0,c[b+72+(l<<3)>>2]|0,c[o>>2]|0,k+(oa*88|0)|0,1);m=c[n>>2]|0;if((l|0)<(m|0)){oa=l;la=m}else{ra=l;sa=m;break}}}else{ra=0;sa=S}}while(0);S=c[o>>2]|0;la=k+1420|0;c[la>>2]=0;nrc(c[b+72+(sa+1<<3)>>2]|0,c[b+72+(ra<<3)>>2]|0,S<<2)|0;S=c[pa>>2]|0;if((S&8|0)==0){ta=S}else{xgb(b,k,0,~~+Q(+g[b+2020>>2]+.5),0);ta=c[pa>>2]|0}if((ta&4|0)==0){ua=ta}else{ygb(b,k);ua=c[pa>>2]|0}g:do{if((ua&1|0)==0){va=ua}else{S=b+612|0;h:do{if((c[S>>2]|0)!=0){oa=c[ma>>2]|0;i:do{if((oa|0)>0){m=k|0;l=0;ka=oa;da=c[n>>2]|0;while(1){ca=ka-1|0;j:do{if((da|0)>0){ba=0;Y=da;while(1){X=c[b+608+(ba*88|0)+4>>2]|0;if((X|0)==0){wa=ba;xa=Y;break j}c[k+(ba*88|0)+4>>2]=X;c[k+(ba*88|0)>>2]=ca;X=ba+1|0;zgb(c[b+72+(ba<<3)>>2]|0,c[b+72+(X<<3)>>2]|0,c[o>>2]|0,m,ba);f=c[n>>2]|0;if((X|0)<(f|0)){ba=X;Y=f}else{wa=X;xa=f;break}}}else{wa=0;xa=da}}while(0);_=b+72+(wa<<3)|0;Y=c[o>>2]|0;ba=c[T>>2]|0;if(!((Y|0)==0|(ba|0)==0)){f=c[_>>2]|0;X=Y;while(1){R=X-1|0;P=f+4|0;O=c[f>>2]|0;w=(O|0)>-1?O:-O|0;O=(w>>>9)+w|0;if(!(O>>>0<256>>>0)){do{if(O>>>0<65536>>>0){ya=(a[785608+(O>>>8)|0]|0)+8|0}else{if(O>>>0<16777216>>>0){ya=(a[785608+(O>>>16)|0]|0)+16|0;break}else{ya=(a[785608+(O>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[110200+(O>>>((ya-9|0)>>>0)&255)|0]|ya<<8)>>>0<ba>>>0)){za=l;break i}}if((R|0)==0){break}else{f=P;X=R}}}if((c[la>>2]|0)==0){za=l;break i}c[la>>2]=0;mrc(na|0,0,1408)|0;nrc(na|0,v|0,wa*88|0)|0;nrc(c[b+72+(xa+1<<3)>>2]|0,c[_>>2]|0,Y<<2)|0;if((ca|0)>0){l=1;ka=ca;da=xa}else{break h}}}else{za=0}}while(0);da=oa+1|0;if(!((za|0)==0&(da|0)<8)){break}ka=k|0;l=da;da=c[n>>2]|0;while(1){k:do{if((da|0)>0){m=0;fa=da;while(1){ea=c[b+608+(m*88|0)+4>>2]|0;if((ea|0)==0){Aa=m;Ba=fa;break k}c[k+(m*88|0)+4>>2]=ea;c[k+(m*88|0)>>2]=l;ea=m+1|0;zgb(c[b+72+(m<<3)>>2]|0,c[b+72+(ea<<3)>>2]|0,c[o>>2]|0,ka,m);ha=c[n>>2]|0;if((ea|0)<(ha|0)){m=ea;fa=ha}else{Aa=ea;Ba=ha;break}}}else{Aa=0;Ba=da}}while(0);fa=b+72+(Aa<<3)|0;m=c[o>>2]|0;ca=c[T>>2]|0;if(!((m|0)==0|(ca|0)==0)){Y=c[fa>>2]|0;_=m;while(1){ha=_-1|0;ea=Y+4|0;X=c[Y>>2]|0;f=(X|0)>-1?X:-X|0;X=(f>>>9)+f|0;if(!(X>>>0<256>>>0)){do{if(X>>>0<65536>>>0){Ca=(a[785608+(X>>>8)|0]|0)+8|0}else{if(X>>>0<16777216>>>0){Ca=(a[785608+(X>>>16)|0]|0)+16|0;break}else{Ca=(a[785608+(X>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[110200+(X>>>((Ca-9|0)>>>0)&255)|0]|Ca<<8)>>>0<ca>>>0)){break h}}if((ha|0)==0){break}else{Y=ea;_=ha}}}if((c[la>>2]|0)==0){break h}c[la>>2]=0;mrc(na|0,0,1408)|0;nrc(na|0,v|0,Aa*88|0)|0;nrc(c[b+72+(Ba+1<<3)>>2]|0,c[fa>>2]|0,m<<2)|0;_=l+1|0;if((_|0)<8){l=_;da=Ba}else{break}}}}while(0);da=c[pa>>2]|0;do{if((da&2|0)!=0){if((c[S>>2]|0)==0){break}l=b+2020|0;g[l>>2]=(+g[l>>2]*2.0+ +(c[ma>>2]|0))/3.0;va=da;break g}}while(0);g[b+2020>>2]=2.0;va=da}}while(0);if((va&16|0)!=0){ygb(b,k)}ma=c[n>>2]|0;if((h|0)==0){Da=0}else{nrc(u|0,c[b+72+(ma+1<<3)>>2]|0,c[o>>2]<<2)|0;Da=0}while(1){if((Da|0)>=(ma|0)){break}if((c[b+608+(Da*88|0)+4>>2]|0)==0){break}else{Da=Da+1|0}}c[qa>>2]=Da}}while(0);do{if(!t){if((c[pa>>2]|0)==0){s=0}else{break}i=j;return s|0}}while(0);mrc(b+468|0,0,76)|0;sgb(b+488|0,c[b+392>>2]|0,p);s=0;i=j;return s|0}function igb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;j=i;i=i+1496|0;k=j|0;l=j+88|0;m=l;mrc(m|0,0,1408)|0;n=c[b+32>>2]|0;o=n<<2;p=0;while(1){if((p|0)>=(n|0)){break}if((c[e+(p<<2)>>2]|0)!=0){break}if((c[f+(p<<2)>>2]|0)==0){p=p+1|0}else{break}}q=b+460|0;r=c[q>>2]|0;if((p|0)==(n|0)){c[q>>2]=r&-17;mrc(b+608|0,0,1408)|0;mrc(b+468|0,0,76)|0;c[b+576>>2]=0;s=0;i=j;return s|0}p=(r>>>18<<8&7936)+1024|0;r=p>>>0<6912>>>0?p:6912;p=c[b+452>>2]|0;if((p|0)==0){t=0;u=0}else{t=p>>>31;u=(p|0)>0|0}p=ngb(b)|0;if((p|0)<0){s=p;i=j;return s|0}p=c[b+596>>2]|0;if((g|0)!=0|(p|0)>6){c[b+604>>2]=0;c[b+600>>2]=0}v=b+596|0;a:do{if((p|0)>0){w=b+604|0;x=b+600|0;y=b+592|0;z=b+2016|0;A=b+448|0;B=(u|0)==0;C=(t|0)==0;D=b+360|0;E=e;F=b+364|0;G=f;H=b+408|0;I=H;J=b+416|0;K=b+412|0;L=K;M=b+420|0;N=(n|0)>0;O=(n|0)==0;P=k;Q=k|0;R=k+4|0;S=(n|0)<2048?n:2048;T=k+16|0;U=b+392|0;V=b+396|0;W=b+608|0;X=b+576|0;Y=0;Z=0;_=-1;$=p;while(1){b:do{if((Z|0)==0){aa=c[x>>2]|0;ba=0}else{ca=c[w>>2]|0;while(1){da=(ca|0)==0;ea=c[x>>2]|0;if(da){fa=0}else{fa=ea&ca-1|ca}if((fa|0)!=(ea|0)){aa=fa;ba=1;break b}if(da){ga=1}else{ga=(c[y>>2]|0)-1&ca<<1}c[w>>2]=ga;if((Z|0)<($|0)){ca=ga}else{break a}}}}while(0);ca=c[z>>2]|0;da=ca+(aa*19|0)|0;ea=ca+(aa*19|0)+1|0;ha=d[1584552+(c[A>>2]|0)|0]|0;ia=Y;c:while(1){do{if(B){if((a[da]|0)!=0&C){ja=26;break}nrc(c[D>>2]|0,E|0,o)|0;nrc(c[F>>2]|0,G|0,o)|0;ka=ia}else{ja=26}}while(0);if((ja|0)==26){ja=0;do{if((ia|0)==0){A4a(I,J,o);A4a(L,M,o);nrc(c[H>>2]|0,E|0,o)|0;nrc(c[K>>2]|0,G|0,o)|0;if(!N){la=1;break}ma=c[K>>2]|0;na=c[H>>2]|0;oa=0;while(1){pa=ma+(oa<<2)|0;qa=na+(oa<<2)|0;ra=(c[qa>>2]|0)-(c[pa>>2]|0)|0;c[qa>>2]=ra;c[pa>>2]=(c[pa>>2]|0)+(ra>>1);ra=oa+1|0;if((ra|0)<(n|0)){oa=ra}else{la=1;break}}}else{la=ia}}while(0);nrc(c[D>>2]|0,c[H>>2]|0,o)|0;nrc(c[F>>2]|0,c[K>>2]|0,o)|0;ka=la}mrc(m|0,0,1408)|0;if((ha|0)>0){oa=0;do{mrc(P|0,0,88)|0;c[Q>>2]=a[ea]|0;na=a[ca+(aa*19|0)+2+oa|0]|0;c[R>>2]=na<<24>>24;do{if(na<<24>>24<0){if((c[q>>2]&32|0)!=0){break}c[R>>2]=-3}}while(0);na=oa&1;ma=b+360+(na<<3)|0;ra=b+360+(na<<3)+4|0;pa=na^1;na=b+360+(pa<<3)|0;qa=b+360+(pa<<3)+4|0;ogb(c[ma>>2]|0,c[ra>>2]|0,c[na>>2]|0,c[qa>>2]|0,S,k,-1);if((oa|0)==0){pgb(k)}else{mrc(T|0,0,64)|0}nrc(l+(oa*88|0)|0,P|0,88)|0;pa=c[ma>>2]|0;ma=c[ra>>2]|0;ra=c[na>>2]|0;na=c[qa>>2]|0;if((c[q>>2]&4194304)>>>0>3932160>>>0){ogb(pa,ma,ra,na,n,k,1)}else{qgb(pa,ma,ra,na,n,k)}oa=oa+1|0;}while((oa|0)<(ha|0));sa=ha&1}else{sa=0}ta=b+360+(sa<<3)|0;ua=b+360+(sa<<3)+4|0;if(O){ja=62;break}oa=c[ta>>2]|0;na=c[ua>>2]|0;ra=n;while(1){ma=ra-1|0;pa=c[oa>>2]|0;qa=(pa|0)>-1?pa:-pa|0;pa=(qa>>>9)+qa|0;if(!(pa>>>0<256>>>0)){do{if(pa>>>0<65536>>>0){va=(a[785608+(pa>>>8)|0]|0)+8|0}else{if(pa>>>0<16777216>>>0){va=(a[785608+(pa>>>16)|0]|0)+16|0;break}else{va=(a[785608+(pa>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[110200+(pa>>>((va-9|0)>>>0)&255)|0]|va<<8)>>>0<r>>>0)){break}}qa=oa+4|0;wa=na+4|0;xa=c[na>>2]|0;ya=(xa|0)>-1?xa:-xa|0;xa=(ya>>>9)+ya|0;if(!(xa>>>0<256>>>0)){do{if(xa>>>0<65536>>>0){za=(a[785608+(xa>>>8)|0]|0)+8|0}else{if(xa>>>0<16777216>>>0){za=(a[785608+(xa>>>16)|0]|0)+16|0;break}else{za=(a[785608+(xa>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[110200+(xa>>>((za-9|0)>>>0)&255)|0]|za<<8)>>>0<r>>>0)){break}}if((ma|0)==0){ja=62;break c}else{oa=qa;na=wa;ra=ma}}if((ha|0)==0){Aa=_;break}else{ha=ha>>1;ia=ka}}do{if((ja|0)==62){ja=0;if((_|0)==0){Aa=_;break}nrc(c[U>>2]|0,c[ta>>2]|0,o)|0;nrc(c[V>>2]|0,c[ua>>2]|0,o)|0;nrc(W|0,m|0,1408)|0;c[X>>2]=ha;c[x>>2]=aa;Aa=0}}while(0);ha=Z+1|0;if(ba){ia=c[w>>2]|0;if((ia|0)==0){Ba=1}else{Ba=(c[y>>2]|0)-1&ia<<1}c[w>>2]=Ba}ia=c[v>>2]|0;if((ha|0)<(ia|0)){Y=ka;Z=ha;_=Aa;$=ia}else{break}}}}while(0);do{if((u|0)==0){if((a[(c[b+2016>>2]|0)+((c[b+600>>2]|0)*19|0)|0]|0)!=0&(t|0)==0){ja=71;break}Ca=c[q>>2]&-17}else{ja=71}}while(0);if((ja|0)==71){Ca=c[q>>2]|16}c[q>>2]=Ca;q=b+440|0;do{if((c[q>>2]|0)==0){if((h|0)==0){break}nrc(e|0,c[b+392>>2]|0,o)|0;nrc(f|0,c[b+396>>2]|0,o)|0}else{if((Ca&16|0)==0){rgb(b,e,f,h);break}ja=b+408|0;t=b+412|0;rgb(b,c[ja>>2]|0,c[t>>2]|0,h);if((h|0)==0){break}nrc(e|0,c[ja>>2]|0,o)|0;nrc(f|0,c[t>>2]|0,o)|0}}while(0);do{if((c[q>>2]|g|0)==0){o=b+584|0;f=a[(c[b+2016>>2]|0)+((c[b+600>>2]|0)*19|0)|0]|0;if((c[o>>2]|0)==(f<<24>>24|0)){s=0}else{Da=f;Ea=o;break}i=j;return s|0}else{Da=a[(c[b+2016>>2]|0)+((c[b+600>>2]|0)*19|0)|0]|0;Ea=b+584|0}}while(0);c[Ea>>2]=Da<<24>>24;mrc(b+468|0,0,76)|0;sgb(b+488|0,c[b+392>>2]|0,n);sgb(b+516|0,c[b+396>>2]|0,n);s=0;i=j;return s|0}function jgb(a){a=a|0;var b=0,c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)<0){b=-a|0;do{if((b|0)==1){c=256}else if((b|0)==0){c=0}else{e=(b>>9)-a|0;f=e>>>0>65535>>>0;g=f?e>>>16:e;h=f?16:0;if((g&65280|0)==0){i=h;j=g}else{i=h|8;j=g>>>8}g=(d[1359664+j|0]|0)+i|0;h=g+1|0;f=h<<8;if((h|0)<9){c=d[110200+(e<<8-g&255)|0]|0|f;break}else{c=d[110200+(e>>g-8&255)|0]|0|f;break}}}while(0);k=-c|0;return k|0}if((a|0)==0){k=0;return k|0}else if((a|0)==1){k=256;return k|0}else{c=(a>>9)+a|0;a=c>>>0>65535>>>0;i=a?c>>>16:c;j=a?16:0;if((i&65280|0)==0){l=j;m=i}else{l=j|8;m=i>>>8}i=(d[1359664+m|0]|0)+l|0;l=i+1|0;m=l<<8;if((l|0)<9){k=d[110200+(c<<8-i&255)|0]|0|m;return k|0}else{k=d[110200+(c>>i-8&255)|0]|0|m;return k|0}}return 0}function kgb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0;f=b+468|0;g=e>>>31;h=b+488|0;do{if((c[h>>2]|0)<2){if((c[b+480>>2]|0)!=0){break}i=b+516|0;if((c[i>>2]|0)>=2){break}j=b+476|0;k=c[j>>2]|0;l=(e|0)!=0;if((k|0)!=0){if(l){lgb(b);break}c[j>>2]=k+1;return}if(!l){mrc(h|0,0,12)|0;mrc(i|0,0,12)|0;c[j>>2]=1;return}j=b+8|0;i=c[j>>2]|0;l=b+12|0;k=c[l>>2]|0;if((k|0)>1){m=k;n=i}else{o=b+20|0;p=c[o>>2]|0;y=i;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;m=k+32|0;n=0}c[j>>2]=n;c[l>>2]=m-1}}while(0);m=e>>31^e;e=d|0;n=c[e>>2]|0;h=n>>4;l=h+1|0;do{if((m|0)<(l|0)){c[e>>2]=n-(((n+126|0)/128|0)<<1);q=0;r=0;s=h}else{c[e>>2]=(((n+128|0)/128|0)*5|0)+n;j=d+4|0;k=c[j>>2]|0;o=k>>4;p=o+1|0;if((m-l|0)>>>0<p>>>0){c[j>>2]=k-(((k+62|0)/64|0)<<1);q=1;r=l;s=o+l|0;break}o=p+l|0;c[j>>2]=(((k+64|0)/64|0)*5|0)+k;k=m-o|0;j=d+8|0;p=c[j>>2]|0;i=p>>4;t=i+1|0;if(k>>>0<t>>>0){c[j>>2]=p-(((p+30|0)/32|0)<<1);q=2;r=o;s=i+o|0;break}else{u=(k>>>0)/(t>>>0)|0;k=(ca(u,t)|0)+o|0;c[j>>2]=(((p+32|0)/32|0)*5|0)+p;q=u+2|0;r=k;s=k+i|0;break}}}while(0);d=b+480|0;do{if((c[d>>2]|0)==0){c[d>>2]=1;v=q;w=1}else{if((q|0)==0){lgb(b);c[d>>2]=0;v=0;w=0;break}else{l=b+472|0;c[l>>2]=(c[l>>2]|0)+1;lgb(b);c[d>>2]=1;v=q-1|0;w=1;break}}}while(0);c[b+472>>2]=v<<1;do{if((s|0)==(r|0)){x=c[b+484>>2]|0;z=c[f>>2]|0}else{v=s-r|0;q=m-r|0;do{if(v>>>0<256>>>0){A=a[785608+v|0]|0}else{if(v>>>0<65536>>>0){A=(a[785608+(v>>>8)|0]|0)+8|0;break}if(v>>>0<16777216>>>0){A=(a[785608+(v>>>16)|0]|0)+16|0;break}else{A=(a[785608+(v>>>24)|0]|0)+24|0;break}}}while(0);d=(1<<A)-v-1|0;if(q>>>0<d>>>0){l=b+484|0;n=c[l>>2]|0;e=f|0;h=c[e>>2]|q<<n;c[e>>2]=h;e=A-1+n|0;c[l>>2]=e;x=e;z=h;break}else{h=d+q|0;d=b+484|0;e=c[d>>2]|0;l=f|0;n=c[l>>2]|h>>>1<<e;i=e+A|0;c[d>>2]=i;d=(h&1)<<A-1+e|n;c[l>>2]=d;x=i;z=d;break}}}while(0);c[b+484>>2]=x+1;c[f>>2]=z|g<<x;if((w|0)!=0){return}lgb(b);return}function lgb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=b+8|0;e=b+476|0;f=c[e>>2]|0;if((f|0)!=0){do{if((f|0)<256){g=a[785608+f|0]|0}else{if((f|0)<65536){g=(a[785608+(f>>8)|0]|0)+8|0;break}if((f|0)<16777216){g=(a[785608+(f>>16)|0]|0)+16|0;break}else{g=(a[785608+(f>>24)|0]|0)+24|0;break}}}while(0);f=d|0;h=b+12|0;i=b+20|0;j=g;while(1){if((j|0)<=31){k=13;break}g=c[h>>2]|0;l=2147483647<<32-g|c[f>>2];if((g|0)>31){m=g;n=l}else{o=c[i>>2]|0;y=l;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;m=g+32|0;n=2147483647>>>(g>>>0)}g=m-31|0;c[f>>2]=n;c[h>>2]=g;o=j-31|0;if((o|0)==0){p=n;q=g;break}else{j=o}}if((k|0)==13){n=(1<<j)-1|0;m=c[h>>2]|0;o=n<<32-m|c[f>>2];if((m|0)>(j|0)){r=m;s=o}else{g=c[i>>2]|0;y=o;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;r=m+32|0;s=(m|0)==32?0:n>>>(m>>>0)}m=r-j|0;c[f>>2]=s;c[h>>2]=m;p=s;q=m}if((q|0)>1){t=q;u=p}else{m=c[i>>2]|0;y=p;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;t=q+32|0;u=0}q=t-1|0;c[f>>2]=u;c[h>>2]=q;t=c[e>>2]|0;if((t|0)>1){m=t;t=u;u=q;while(1){q=m&1;p=q<<32-u|t;if((u|0)>1){v=u;w=p;x=m}else{s=c[i>>2]|0;y=p;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;v=u+32|0;w=q>>>(u>>>0);x=c[e>>2]|0}q=v-1|0;c[f>>2]=w;c[h>>2]=q;s=x>>1;c[e>>2]=s;if((s|0)>1){m=s;t=w;u=q}else{break}}}c[e>>2]=0}e=b+472|0;u=c[e>>2]|0;if((u|0)!=0){if((u|0)>15){w=d|0;t=b+12|0;m=c[t>>2]|0;x=65535<<32-m|c[w>>2];if((m|0)>16){z=m;A=x}else{h=b+20|0;f=c[h>>2]|0;y=x;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;z=m+32|0;A=65535>>>(m>>>0)}m=z-16|0;c[w>>2]=A;c[t>>2]=m;if((m|0)>1){B=m;C=A}else{m=b+20|0;h=c[m>>2]|0;y=A;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;B=z+16|0;C=0}z=B-1|0;c[w>>2]=C;c[t>>2]=z;B=(c[e>>2]|0)-16|0;c[e>>2]=B;do{if((B|0)<256){D=a[785608+B|0]|0}else{if((B|0)<65536){D=(a[785608+(B>>8)|0]|0)+8|0;break}if((B|0)<16777216){D=(a[785608+(B>>16)|0]|0)+16|0;break}else{D=(a[785608+(B>>24)|0]|0)+24|0;break}}}while(0);B=b+20|0;m=D;D=C;C=z;while(1){if((m|0)<=31){k=41;break}z=2147483647<<32-C|D;if((C|0)>31){E=C;F=z}else{h=c[B>>2]|0;y=z;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;E=C+32|0;F=2147483647>>>(C>>>0)}h=E-31|0;c[w>>2]=F;c[t>>2]=h;z=m-31|0;if((z|0)==0){G=h;H=F;break}else{m=z;D=F;C=h}}if((k|0)==41){k=(1<<m)-1|0;F=k<<32-C|D;if((C|0)>(m|0)){I=C;J=F}else{D=c[B>>2]|0;y=F;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;I=C+32|0;J=(C|0)==32?0:k>>>(C>>>0)}C=I-m|0;c[w>>2]=J;c[t>>2]=C;G=C;H=J}if((G|0)>1){K=G;L=H}else{J=c[B>>2]|0;y=H;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;K=G+32|0;L=0}G=K-1|0;c[w>>2]=L;c[t>>2]=G;K=c[e>>2]|0;if((K|0)>1){J=K;K=L;L=G;while(1){G=J&1;H=G<<32-L|K;if((L|0)>1){M=L;N=H;O=J}else{C=c[B>>2]|0;y=H;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;M=L+32|0;N=G>>>(L>>>0);O=c[e>>2]|0}G=M-1|0;c[w>>2]=N;c[t>>2]=G;C=O>>1;c[e>>2]=C;if((C|0)>1){J=C;K=N;L=G}else{break}}}c[b+480>>2]=0}else{L=(1<<u)-1|0;N=d|0;K=b+12|0;J=c[K>>2]|0;O=L<<32-J|c[N>>2];if((J|0)>(u|0)){P=J;Q=O}else{t=b+20|0;w=c[t>>2]|0;y=O;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;P=J+32|0;Q=(J|0)==32?0:L>>>(J>>>0)}c[N>>2]=Q;c[K>>2]=P-u}c[e>>2]=0}e=b+480|0;if((c[e>>2]|0)!=0){u=d|0;P=c[u>>2]|0;K=b+12|0;Q=c[K>>2]|0;if((Q|0)>1){R=Q;S=P}else{N=b+20|0;J=c[N>>2]|0;y=P;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;R=Q+32|0;S=0}c[u>>2]=S;c[K>>2]=R-1;c[e>>2]=0}e=b+484|0;R=c[e>>2]|0;if((R|0)==0){return}K=b+468|0;S=c[K>>2]|0;u=d|0;d=b+12|0;Q=c[d>>2]|0;N=S<<32-Q|c[u>>2];if((Q|0)>(R|0)){T=Q;U=N}else{J=b+20|0;b=c[J>>2]|0;y=N;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[J>>2]=(c[J>>2]|0)+4;T=Q+32|0;U=(Q|0)==32?0:S>>>(Q>>>0)}c[u>>2]=U;c[d>>2]=T-R;c[e>>2]=0;c[K>>2]=0;return}function mgb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=a[b+550|0]|0;g=f&255;h=b+8|0;i=c[e>>2]|0;j=i>>>23&255;do{if((j|0)==255){k=h|0;l=c[k>>2]|0;m=b+12|0;n=c[m>>2]|0;if((i&8388607|0)==0){if((n|0)>1){o=n;p=l}else{q=b+20|0;r=c[q>>2]|0;y=l;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;o=n+32|0;p=0}c[k>>2]=p;c[m>>2]=o-1;s=0;t=16777216;u=14;break}q=1<<32-n|l;if((n|0)>1){v=n;w=q}else{l=b+20|0;r=c[l>>2]|0;y=q;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;v=n+32|0;w=1>>>(n>>>0)}n=v-1|0;c[k>>2]=w;c[m>>2]=n;l=c[e>>2]&8388607;r=l<<33-v|w;if((n|0)>23){x=n;z=r}else{q=b+20|0;A=c[q>>2]|0;y=r;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;x=v+31|0;z=l>>>(n>>>0)}c[k>>2]=z;c[m>>2]=x-23;s=0;t=16777216;u=14}else if((j|0)==0){B=i&8388607;C=f<<24>>24==0?0:g-1|0;u=13}else{B=i&8388607|8388608;C=g-j|0;u=13}}while(0);if((u|0)==13){if((C|0)<25){s=C;t=B;u=14}}do{if((u|0)==14){if((t>>s|0)==0){break}if((s|0)==0){return}B=d[b+548|0]|0;if((B&4|0)!=0){C=(1<<s)+8388607&8388607&c[e>>2];j=h|0;g=b+12|0;i=c[g>>2]|0;x=C<<32-i|c[j>>2];if((i|0)>(s|0)){D=i;E=x}else{z=b+20|0;v=c[z>>2]|0;y=x;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;D=i+32|0;E=(i|0)==32?0:C>>>(i>>>0)}c[j>>2]=E;c[g>>2]=D-s;return}if((B&2|0)==0){return}B=c[e>>2]&1;g=h|0;j=b+12|0;i=c[j>>2]|0;C=B<<32-i|c[g>>2];if((i|0)>1){F=i;G=C}else{z=b+20|0;v=c[z>>2]|0;y=C;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;F=i+32|0;G=B>>>(i>>>0)}c[g>>2]=G;c[j>>2]=F-1;return}}while(0);F=b+548|0;G=a[F]|0;if((G&8)==0){return}s=h|0;h=c[s>>2]|0;D=b+12|0;E=c[D>>2]|0;if((c[e>>2]&2147483647|0)==0){if((E|0)>1){H=E;I=h;J=G}else{G=b+20|0;t=c[G>>2]|0;y=h;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;H=E+32|0;I=0;J=a[F]|0}F=H-1|0;c[s>>2]=I;c[D>>2]=F;if((J&16)==0){return}J=(c[e>>2]|0)>>>31;G=J<<33-H|I;if((F|0)>1){K=F;L=G}else{I=b+20|0;t=c[I>>2]|0;y=G;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;K=H+31|0;L=J>>>(F>>>0)}c[s>>2]=L;c[D>>2]=K-1;return}K=1<<32-E|h;if((E|0)>1){M=E;N=K}else{h=b+20|0;L=c[h>>2]|0;y=K;a[L]=y;y=y>>8;a[L+1|0]=y;y=y>>8;a[L+2|0]=y;y=y>>8;a[L+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;M=E+32|0;N=1>>>(E>>>0)}E=M-1|0;c[s>>2]=N;c[D>>2]=E;h=c[e>>2]&8388607;L=h<<33-M|N;if((E|0)>23){O=E;P=L}else{N=b+20|0;K=c[N>>2]|0;y=L;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;O=M+31|0;P=h>>>(E>>>0)}E=O-23|0;c[s>>2]=P;c[D>>2]=E;if((f&255)>>>0>24>>>0){f=(c[e>>2]|0)>>>23&255;h=f<<55-O|P;if((E|0)>8){Q=E;R=h}else{M=b+20|0;N=c[M>>2]|0;y=h;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[M>>2]=(c[M>>2]|0)+4;Q=O+9|0;R=f>>>(E>>>0)}f=Q-8|0;c[s>>2]=R;c[D>>2]=f;S=f;T=R}else{S=E;T=P}P=(c[e>>2]|0)>>>31;e=P<<32-S|T;if((S|0)>1){U=S;V=e}else{T=b+20|0;b=c[T>>2]|0;y=e;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[T>>2]=(c[T>>2]|0)+4;U=S+32|0;V=P>>>(S>>>0)}c[s>>2]=V;c[D>>2]=U-1;return}function ngb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+392|0;d=b|0;e=b;b=a+400|0;f=a+32|0;g=a+396|0;h=g;i=a+404|0;j=a+460|0;A4a(e,b,c[f>>2]<<2);if((c[d>>2]|0)==0){k=-12;return k|0}l=a+360|0;A4a(l,a+376|0,c[f>>2]<<2);if((c[l>>2]|0)==0){k=-12;return k|0}do{if((c[j>>2]&1073741828|0)==0){A4a(h,i,c[f>>2]<<2);if((c[g>>2]|0)==0){k=-12;return k|0}l=a+364|0;A4a(l,a+380|0,c[f>>2]<<2);if((c[l>>2]|0)==0){k=-12}else{break}return k|0}}while(0);A4a(e,b,c[f>>2]<<2);if((c[d>>2]|0)==0){k=-12;return k|0}d=a+368|0;A4a(d,a+384|0,c[f>>2]<<2);if((c[d>>2]|0)==0){k=-12;return k|0}do{if((c[j>>2]&1073741828|0)==0){A4a(h,i,c[f>>2]<<2);if((c[g>>2]|0)==0){k=-12;return k|0}d=a+372|0;A4a(d,a+388|0,c[f>>2]<<2);if((c[d>>2]|0)==0){k=-12}else{break}return k|0}}while(0);k=0;return k|0}function ogb(a,b,e,f,g,h,j){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;k=i;i=i+64|0;l=k|0;m=k+32|0;n=h+84|0;c[n>>2]=0;o=h+80|0;c[o>>2]=0;if((j|0)<0){p=g-1|0;q=a+(p<<2)|0;r=b+(p<<2)|0;s=e+(p<<2)|0;t=f+(p<<2)|0}else{q=a;r=b;s=e;t=f}f=h+8|0;e=c[f>>2]|0;do{if((e|0)<-1024){u=-1024}else{b=(e|0)>1024?1024:e;if((b|0)>0){v=b-(b+64>>7)|0}else{v=b}b=(v+4|0)>>>3<<24;a=b>>21;if((b|0)<=0){u=a;break}u=(a+64>>7)+a|0}}while(0);c[f>>2]=u;u=h+12|0;v=c[u>>2]|0;do{if((v|0)<-1024){w=-1024}else{e=(v|0)>1024?1024:v;if((e|0)>0){x=e-(e+64>>7)|0}else{x=e}e=(x+4|0)>>>3<<24;a=e>>21;if((e|0)<=0){w=a;break}w=(a+64>>7)+a|0}}while(0);c[u>>2]=w;w=0;do{x=h+16+(w<<2)|0;v=(jgb(c[x>>2]|0)|0)&65535;a=v<<16>>16<0;e=(a?-v&65535:v)<<16>>16;v=d[110712+(e&255)|0]|0|256;b=e>>>8<<16;e=b>>16;if((b|0)>589824){y=v<<e-9}else{y=v>>>((9-e|0)>>>0)}c[x>>2]=a?-y|0:y;a=h+48+(w<<2)|0;x=(jgb(c[a>>2]|0)|0)&65535;e=x<<16>>16<0;v=(e?-x&65535:x)<<16>>16;x=d[110712+(v&255)|0]|0|256;b=v>>>8<<16;v=b>>16;if((b|0)>589824){z=x<<v-9}else{z=x>>>((9-v|0)>>>0)}c[a>>2]=e?-z|0:z;w=w+1|0;}while((w|0)<8);w=c[h+4>>2]|0;switch(w|0){case-1:{if((g|0)==0){i=k;return}z=h+16|0;y=h|0;e=t;a=s;v=r;x=q;b=g;while(1){p=b-1|0;A=c[z>>2]|0;B=c[x>>2]|0;if((A|0)==(A<<16>>16|0)){C=(ca(c[f>>2]|0,A)|0)+512>>10}else{D=c[f>>2]|0;C=(ca(D,A>>9&-128)|0|1)+((ca(D,A&65535)|0)>>9)>>1}D=B-C|0;c[a>>2]=D;do{if((A|0)==0|(B|0)==(C|0)){E=c[f>>2]|0}else{F=c[y>>2]|0;G=c[f>>2]|0;if((D^A|0)<0){H=G-F|0;c[f>>2]=H;if(!((H|0)<-1024)){E=H;break}c[f>>2]=-1024;E=-1024;break}else{H=G+F|0;c[f>>2]=H;if((H|0)<=1024){E=H;break}c[f>>2]=1024;E=1024;break}}}while(0);c[o>>2]=(c[o>>2]|0)+E;A=c[v>>2]|0;c[z>>2]=A;if((B|0)==(B<<16>>16|0)){I=(ca(c[u>>2]|0,B)|0)+512>>10}else{D=c[u>>2]|0;I=(ca(D,B>>9&-128)|0|1)+((ca(D,B&65535)|0)>>9)>>1}D=A-I|0;c[e>>2]=D;do{if((B|0)==0|(A|0)==(I|0)){J=c[u>>2]|0}else{H=c[y>>2]|0;F=c[u>>2]|0;if((D^B|0)<0){G=F-H|0;c[u>>2]=G;if(!((G|0)<-1024)){J=G;break}c[u>>2]=-1024;J=-1024;break}else{G=F+H|0;c[u>>2]=G;if((G|0)<=1024){J=G;break}c[u>>2]=1024;J=1024;break}}}while(0);c[n>>2]=(c[n>>2]|0)+J;if((p|0)==0){break}else{e=e+(j<<2)|0;a=a+(j<<2)|0;v=v+(j<<2)|0;x=x+(j<<2)|0;b=p}}i=k;return};case-3:{if((g|0)==0){i=k;return}b=h+16|0;x=h+48|0;v=h|0;a=t;e=s;J=r;y=q;I=g;while(1){z=I-1|0;E=c[b>>2]|0;C=c[x>>2]|0;B=c[J>>2]|0;c[b>>2]=B;if((C|0)==(C<<16>>16|0)){K=(ca(c[u>>2]|0,C)|0)+512>>10}else{D=c[u>>2]|0;K=(ca(D,C>>9&-128)|0|1)+((ca(D,C&65535)|0)>>9)>>1}D=B-K|0;c[a>>2]=D;do{if((C|0)==0|(B|0)==(K|0)){L=c[u>>2]|0}else{A=c[v>>2]|0;G=c[u>>2]|0;if((D^C|0)<0){H=G-A|0;c[u>>2]=H;if(!((H|0)<-1024)){L=H;break}c[u>>2]=-1024;L=-1024;break}else{H=G+A|0;c[u>>2]=H;if((H|0)<=1024){L=H;break}c[u>>2]=1024;L=1024;break}}}while(0);c[n>>2]=(c[n>>2]|0)+L;C=c[y>>2]|0;c[x>>2]=C;if((E|0)==(E<<16>>16|0)){M=(ca(c[f>>2]|0,E)|0)+512>>10}else{D=c[f>>2]|0;M=(ca(D,E>>9&-128)|0|1)+((ca(D,E&65535)|0)>>9)>>1}D=C-M|0;c[e>>2]=D;do{if((E|0)==0|(C|0)==(M|0)){N=c[f>>2]|0}else{B=c[v>>2]|0;p=c[f>>2]|0;if((D^E|0)<0){H=p-B|0;c[f>>2]=H;if(!((H|0)<-1024)){N=H;break}c[f>>2]=-1024;N=-1024;break}else{H=p+B|0;c[f>>2]=H;if((H|0)<=1024){N=H;break}c[f>>2]=1024;N=1024;break}}}while(0);c[o>>2]=(c[o>>2]|0)+N;if((z|0)==0){break}else{a=a+(j<<2)|0;e=e+(j<<2)|0;J=J+(j<<2)|0;y=y+(j<<2)|0;I=z}}i=k;return};case 2:{if((g|0)==0){i=k;return}I=h+16|0;y=h+20|0;J=h+48|0;e=h+52|0;a=h|0;N=t;v=s;M=r;x=q;L=g;while(1){K=L-1|0;b=c[I>>2]|0;c[I>>2]=c[y>>2];E=c[x>>2]|0;c[y>>2]=E;if((b|0)==(b<<16>>16|0)){O=(ca(c[f>>2]|0,b)|0)+512>>10}else{D=c[f>>2]|0;O=(ca(D,b>>9&-128)|0|1)+((ca(D,b&65535)|0)>>9)>>1}D=E-O|0;c[v>>2]=D;if((b|0)==0|(E|0)==(O|0)){P=c[f>>2]|0}else{E=D^b;b=(c[f>>2]|0)+(E>>>31)+(c[a>>2]^E>>31)|0;c[f>>2]=b;P=b}c[o>>2]=(c[o>>2]|0)+P;b=c[J>>2]|0;c[J>>2]=c[e>>2];E=c[M>>2]|0;c[e>>2]=E;if((b|0)==(b<<16>>16|0)){Q=(ca(c[u>>2]|0,b)|0)+512>>10}else{D=c[u>>2]|0;Q=(ca(D,b>>9&-128)|0|1)+((ca(D,b&65535)|0)>>9)>>1}D=E-Q|0;c[N>>2]=D;if((b|0)==0|(E|0)==(Q|0)){R=c[u>>2]|0}else{E=D^b;b=(c[u>>2]|0)+(E>>>31)+(c[a>>2]^E>>31)|0;c[u>>2]=b;R=b}c[n>>2]=(c[n>>2]|0)+R;if((K|0)==0){break}else{N=N+(j<<2)|0;v=v+(j<<2)|0;M=M+(j<<2)|0;x=x+(j<<2)|0;L=K}}i=k;return};case 18:{if((g|0)==0){i=k;return}L=h+16|0;x=h+20|0;M=h+48|0;v=h+52|0;N=h|0;R=t;a=s;Q=r;e=q;J=g;while(1){P=J-1|0;O=c[L>>2]|0;y=(O-(c[x>>2]|0)>>1)+O|0;c[x>>2]=O;O=c[e>>2]|0;c[L>>2]=O;if((y|0)==(y<<16>>16|0)){S=(ca(c[f>>2]|0,y)|0)+512>>10}else{I=c[f>>2]|0;S=(ca(I,y>>9&-128)|0|1)+((ca(I,y&65535)|0)>>9)>>1}I=O-S|0;c[a>>2]=I;if((y|0)==0|(O|0)==(S|0)){T=c[f>>2]|0}else{O=I^y;y=(c[f>>2]|0)+(O>>>31)+(c[N>>2]^O>>31)|0;c[f>>2]=y;T=y}c[o>>2]=(c[o>>2]|0)+T;y=c[M>>2]|0;O=(y-(c[v>>2]|0)>>1)+y|0;c[v>>2]=y;y=c[Q>>2]|0;c[M>>2]=y;if((O|0)==(O<<16>>16|0)){U=(ca(c[u>>2]|0,O)|0)+512>>10}else{I=c[u>>2]|0;U=(ca(I,O>>9&-128)|0|1)+((ca(I,O&65535)|0)>>9)>>1}I=y-U|0;c[R>>2]=I;if((O|0)==0|(y|0)==(U|0)){V=c[u>>2]|0}else{y=I^O;O=(c[u>>2]|0)+(y>>>31)+(c[N>>2]^y>>31)|0;c[u>>2]=O;V=O}c[n>>2]=(c[n>>2]|0)+V;if((P|0)==0){break}else{R=R+(j<<2)|0;a=a+(j<<2)|0;Q=Q+(j<<2)|0;e=e+(j<<2)|0;J=P}}i=k;return};case 17:{if((g|0)==0){i=k;return}J=h+16|0;e=h+20|0;Q=h+48|0;a=h+52|0;R=h|0;V=t;N=s;U=r;M=q;v=g;while(1){T=v-1|0;S=c[J>>2]|0;L=S<<1;x=c[e>>2]|0;P=L-x|0;c[e>>2]=S;S=c[M>>2]|0;c[J>>2]=S;if((P|0)==(P<<16>>16|0)){W=(ca(c[f>>2]|0,P)|0)+512>>10}else{O=c[f>>2]|0;W=(ca(O,P>>9&-128)|0|1)+((ca(O,P&65535)|0)>>9)>>1}O=S-W|0;c[N>>2]=O;if((L|0)==(x|0)|(S|0)==(W|0)){X=c[f>>2]|0}else{S=O^P;P=(c[f>>2]|0)+(S>>>31)+(c[R>>2]^S>>31)|0;c[f>>2]=P;X=P}c[o>>2]=(c[o>>2]|0)+X;P=c[Q>>2]|0;S=P<<1;O=c[a>>2]|0;x=S-O|0;c[a>>2]=P;P=c[U>>2]|0;c[Q>>2]=P;if((x|0)==(x<<16>>16|0)){Y=(ca(c[u>>2]|0,x)|0)+512>>10}else{L=c[u>>2]|0;Y=(ca(L,x>>9&-128)|0|1)+((ca(L,x&65535)|0)>>9)>>1}L=P-Y|0;c[V>>2]=L;if((S|0)==(O|0)|(P|0)==(Y|0)){Z=c[u>>2]|0}else{P=L^x;x=(c[u>>2]|0)+(P>>>31)+(c[R>>2]^P>>31)|0;c[u>>2]=x;Z=x}c[n>>2]=(c[n>>2]|0)+Z;if((T|0)==0){break}else{V=V+(j<<2)|0;N=N+(j<<2)|0;U=U+(j<<2)|0;M=M+(j<<2)|0;v=T}}i=k;return};case-2:{if((g|0)==0){i=k;return}v=h+48|0;M=h|0;U=t;N=s;V=r;Z=q;R=g;while(1){Y=R-1|0;Q=c[v>>2]|0;a=c[V>>2]|0;if((Q|0)==(Q<<16>>16|0)){_=(ca(c[u>>2]|0,Q)|0)+512>>10}else{X=c[u>>2]|0;_=(ca(X,Q>>9&-128)|0|1)+((ca(X,Q&65535)|0)>>9)>>1}X=a-_|0;c[U>>2]=X;do{if((Q|0)==0|(a|0)==(_|0)){$=c[u>>2]|0}else{W=c[M>>2]|0;J=c[u>>2]|0;if((X^Q|0)<0){e=J-W|0;c[u>>2]=e;if(!((e|0)<-1024)){$=e;break}c[u>>2]=-1024;$=-1024;break}else{e=J+W|0;c[u>>2]=e;if((e|0)<=1024){$=e;break}c[u>>2]=1024;$=1024;break}}}while(0);c[n>>2]=(c[n>>2]|0)+$;Q=c[Z>>2]|0;c[v>>2]=Q;if((a|0)==(a<<16>>16|0)){aa=(ca(c[f>>2]|0,a)|0)+512>>10}else{X=c[f>>2]|0;aa=(ca(X,a>>9&-128)|0|1)+((ca(X,a&65535)|0)>>9)>>1}X=Q-aa|0;c[N>>2]=X;do{if((a|0)==0|(Q|0)==(aa|0)){ba=c[f>>2]|0}else{z=c[M>>2]|0;e=c[f>>2]|0;if((X^a|0)<0){W=e-z|0;c[f>>2]=W;if(!((W|0)<-1024)){ba=W;break}c[f>>2]=-1024;ba=-1024;break}else{W=e+z|0;c[f>>2]=W;if((W|0)<=1024){ba=W;break}c[f>>2]=1024;ba=1024;break}}}while(0);c[o>>2]=(c[o>>2]|0)+ba;if((Y|0)==0){break}else{U=U+(j<<2)|0;N=N+(j<<2)|0;V=V+(j<<2)|0;Z=Z+(j<<2)|0;R=Y}}i=k;return};default:{if((g|0)==0){i=k;return}R=h|0;Z=0;V=t;t=s;s=r;r=q;q=w;w=g;while(1){g=q&7;N=w-1|0;U=c[h+16+(Z<<2)>>2]|0;ba=c[r>>2]|0;c[h+16+(g<<2)>>2]=ba;if((U|0)==(U<<16>>16|0)){da=(ca(c[f>>2]|0,U)|0)+512>>10}else{M=c[f>>2]|0;da=(ca(M,U>>9&-128)|0|1)+((ca(M,U&65535)|0)>>9)>>1}M=ba-da|0;c[t>>2]=M;if((U|0)==0|(ba|0)==(da|0)){ea=c[f>>2]|0}else{ba=M^U;U=(c[f>>2]|0)+(ba>>>31)+(c[R>>2]^ba>>31)|0;c[f>>2]=U;ea=U}c[o>>2]=(c[o>>2]|0)+ea;U=c[h+48+(Z<<2)>>2]|0;ba=c[s>>2]|0;c[h+48+(g<<2)>>2]=ba;if((U|0)==(U<<16>>16|0)){fa=(ca(c[u>>2]|0,U)|0)+512>>10}else{M=c[u>>2]|0;fa=(ca(M,U>>9&-128)|0|1)+((ca(M,U&65535)|0)>>9)>>1}M=ba-fa|0;c[V>>2]=M;if((U|0)==0|(ba|0)==(fa|0)){ga=c[u>>2]|0}else{ba=M^U;U=(c[u>>2]|0)+(ba>>>31)+(c[R>>2]^ba>>31)|0;c[u>>2]=U;ga=U}c[n>>2]=(c[n>>2]|0)+ga;ha=Z+1&7;if((N|0)==0){break}else{Z=ha;V=V+(j<<2)|0;t=t+(j<<2)|0;s=s+(j<<2)|0;r=r+(j<<2)|0;q=g+1|0;w=N}}if((ha|0)==0){i=k;return}nrc(l|0,h+16|0,32)|0;nrc(m|0,h+48|0,32)|0;c[h+16>>2]=c[l+(ha<<2)>>2];c[h+48>>2]=c[m+(ha<<2)>>2];ha=Z+2&7;c[h+20>>2]=c[l+(ha<<2)>>2];c[h+52>>2]=c[m+(ha<<2)>>2];ha=Z+3&7;c[h+24>>2]=c[l+(ha<<2)>>2];c[h+56>>2]=c[m+(ha<<2)>>2];ha=Z+4&7;c[h+28>>2]=c[l+(ha<<2)>>2];c[h+60>>2]=c[m+(ha<<2)>>2];ha=Z+5&7;c[h+32>>2]=c[l+(ha<<2)>>2];c[h+64>>2]=c[m+(ha<<2)>>2];ha=Z+6&7;c[h+36>>2]=c[l+(ha<<2)>>2];c[h+68>>2]=c[m+(ha<<2)>>2];ha=Z+7&7;c[h+40>>2]=c[l+(ha<<2)>>2];c[h+72>>2]=c[m+(ha<<2)>>2];c[h+44>>2]=c[l+(Z<<2)>>2];c[h+76>>2]=c[m+(Z<<2)>>2];i=k;return}}}function pgb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a+4|0;d=c[b>>2]|0;if((d|0)<=8){if((d|0)>1){e=0;f=d;g=0}else{return}while(1){h=e&7;i=f+7&7;j=a+16+(i<<2)|0;k=a+16+(h<<2)|0;l=c[k>>2]^c[j>>2];c[k>>2]=l;m=c[j>>2]^l;c[j>>2]=m;c[k>>2]=c[k>>2]^m;m=a+48+(i<<2)|0;k=a+48+(h<<2)|0;j=c[k>>2]^c[m>>2];c[k>>2]=j;l=c[m>>2]^j;c[m>>2]=l;c[k>>2]=c[k>>2]^l;l=g+1|0;if((l|0)<((c[b>>2]|0)/2|0|0)){e=h+1|0;f=i;g=l}else{break}}return}g=(d&1|0)==0;d=a+16|0;f=c[d>>2]|0;if(g){e=c[a+48>>2]|0;n=(e*3|0)-(c[a+52>>2]|0)>>1;o=(f*3|0)-(c[a+20>>2]|0)>>1;p=e}else{e=c[a+48>>2]|0;n=(e<<1)-(c[a+52>>2]|0)|0;o=(f<<1)-(c[a+20>>2]|0)|0;p=e}e=a+20|0;c[e>>2]=f;b=a+52|0;c[b>>2]=p;c[d>>2]=o;c[a+48>>2]=n;if(g){q=(n*3|0)-p>>1;r=(o*3|0)-f>>1}else{q=(n<<1)-p|0;r=(o<<1)-f|0}c[e>>2]=r;c[b>>2]=q;return}function qgb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=i;i=i+64|0;k=j|0;l=j+32|0;m=h+8|0;n=c[m>>2]|0;do{if((n|0)<-1024){o=-1024}else{p=(n|0)>1024?1024:n;if((p|0)>0){q=p-(p+64>>7)|0}else{q=p}p=(q+4|0)>>>3<<24;r=p>>21;if((p|0)<=0){o=r;break}o=(r+64>>7)+r|0}}while(0);c[m>>2]=o;o=h+12|0;q=c[o>>2]|0;do{if((q|0)<-1024){s=-1024}else{n=(q|0)>1024?1024:q;if((n|0)>0){t=n-(n+64>>7)|0}else{t=n}n=(t+4|0)>>>3<<24;r=n>>21;if((n|0)<=0){s=r;break}s=(r+64>>7)+r|0}}while(0);c[o>>2]=s;s=0;do{t=h+16+(s<<2)|0;q=(jgb(c[t>>2]|0)|0)&65535;r=q<<16>>16<0;n=(r?-q&65535:q)<<16>>16;q=d[110712+(n&255)|0]|0|256;p=n>>>8<<16;n=p>>16;if((p|0)>589824){u=q<<n-9}else{u=q>>>((9-n|0)>>>0)}c[t>>2]=r?-u|0:u;r=h+48+(s<<2)|0;t=(jgb(c[r>>2]|0)|0)&65535;n=t<<16>>16<0;q=(n?-t&65535:t)<<16>>16;t=d[110712+(q&255)|0]|0|256;p=q>>>8<<16;q=p>>16;if((p|0)>589824){v=t<<q-9}else{v=t>>>((9-q|0)>>>0)}c[r>>2]=n?-v|0:v;s=s+1|0;}while((s|0)<8);s=c[h+4>>2]|0;switch(s|0){case 18:{if((g|0)<=0){i=j;return}v=h+16|0;u=h+20|0;n=h+48|0;r=h+52|0;q=h|0;t=0;do{p=c[v>>2]|0;w=(p-(c[u>>2]|0)>>1)+p|0;c[u>>2]=p;p=c[a+(t<<2)>>2]|0;c[v>>2]=p;x=(ca(w,c[m>>2]|0)|0)+512>>10;y=p-x|0;c[e+(t<<2)>>2]=y;if(!((w|0)==0|(p|0)==(x|0))){x=y^w;c[m>>2]=(c[m>>2]|0)+(x>>>31)+(c[q>>2]^x>>31)}x=c[n>>2]|0;w=(x-(c[r>>2]|0)>>1)+x|0;c[r>>2]=x;x=c[b+(t<<2)>>2]|0;c[n>>2]=x;y=(ca(w,c[o>>2]|0)|0)+512>>10;p=x-y|0;c[f+(t<<2)>>2]=p;if(!((w|0)==0|(x|0)==(y|0))){y=p^w;c[o>>2]=(c[o>>2]|0)+(y>>>31)+(c[q>>2]^y>>31)}t=t+1|0;}while((t|0)<(g|0));i=j;return};case-1:{if((g|0)<=0){i=j;return}t=h+16|0;q=h|0;n=0;do{r=c[t>>2]|0;v=c[a+(n<<2)>>2]|0;u=(ca(c[m>>2]|0,r)|0)+512>>10;y=v-u|0;c[e+(n<<2)>>2]=y;do{if(!((r|0)==0|(v|0)==(u|0))){w=c[q>>2]|0;p=c[m>>2]|0;if((y^r|0)<0){x=p-w|0;c[m>>2]=x;if(!((x|0)<-1024)){break}c[m>>2]=-1024;break}else{x=p+w|0;c[m>>2]=x;if((x|0)<=1024){break}c[m>>2]=1024;break}}}while(0);r=c[b+(n<<2)>>2]|0;c[t>>2]=r;y=(ca(c[o>>2]|0,v)|0)+512>>10;u=r-y|0;c[f+(n<<2)>>2]=u;do{if(!((v|0)==0|(r|0)==(y|0))){x=c[q>>2]|0;w=c[o>>2]|0;if((u^v|0)<0){p=w-x|0;c[o>>2]=p;if(!((p|0)<-1024)){break}c[o>>2]=-1024;break}else{p=w+x|0;c[o>>2]=p;if((p|0)<=1024){break}c[o>>2]=1024;break}}}while(0);n=n+1|0;}while((n|0)<(g|0));i=j;return};case-2:{if((g|0)<=0){i=j;return}n=h+48|0;q=h|0;t=0;do{v=c[n>>2]|0;u=c[b+(t<<2)>>2]|0;y=(ca(c[o>>2]|0,v)|0)+512>>10;r=u-y|0;c[f+(t<<2)>>2]=r;do{if(!((v|0)==0|(u|0)==(y|0))){p=c[q>>2]|0;x=c[o>>2]|0;if((r^v|0)<0){w=x-p|0;c[o>>2]=w;if(!((w|0)<-1024)){break}c[o>>2]=-1024;break}else{w=x+p|0;c[o>>2]=w;if((w|0)<=1024){break}c[o>>2]=1024;break}}}while(0);v=c[a+(t<<2)>>2]|0;c[n>>2]=v;r=(ca(c[m>>2]|0,u)|0)+512>>10;y=v-r|0;c[e+(t<<2)>>2]=y;do{if(!((u|0)==0|(v|0)==(r|0))){w=c[q>>2]|0;p=c[m>>2]|0;if((y^u|0)<0){x=p-w|0;c[m>>2]=x;if(!((x|0)<-1024)){break}c[m>>2]=-1024;break}else{x=p+w|0;c[m>>2]=x;if((x|0)<=1024){break}c[m>>2]=1024;break}}}while(0);t=t+1|0;}while((t|0)<(g|0));i=j;return};case 2:{if((g|0)<=0){i=j;return}t=h+16|0;q=h+20|0;n=h+48|0;u=h+52|0;y=h|0;r=0;do{v=c[t>>2]|0;c[t>>2]=c[q>>2];x=c[a+(r<<2)>>2]|0;c[q>>2]=x;w=(ca(c[m>>2]|0,v)|0)+512>>10;p=x-w|0;c[e+(r<<2)>>2]=p;if(!((v|0)==0|(x|0)==(w|0))){w=p^v;c[m>>2]=(c[m>>2]|0)+(w>>>31)+(c[y>>2]^w>>31)}w=c[n>>2]|0;c[n>>2]=c[u>>2];v=c[b+(r<<2)>>2]|0;c[u>>2]=v;p=(ca(c[o>>2]|0,w)|0)+512>>10;x=v-p|0;c[f+(r<<2)>>2]=x;if(!((w|0)==0|(v|0)==(p|0))){p=x^w;c[o>>2]=(c[o>>2]|0)+(p>>>31)+(c[y>>2]^p>>31)}r=r+1|0;}while((r|0)<(g|0));i=j;return};case 17:{if((g|0)<=0){i=j;return}r=h+16|0;y=h+20|0;u=h+48|0;n=h+52|0;q=h|0;t=0;do{p=c[r>>2]|0;w=p<<1;x=c[y>>2]|0;v=w-x|0;c[y>>2]=p;p=c[a+(t<<2)>>2]|0;c[r>>2]=p;z=(ca(c[m>>2]|0,v)|0)+512>>10;A=p-z|0;c[e+(t<<2)>>2]=A;if(!((w|0)==(x|0)|(p|0)==(z|0))){z=A^v;c[m>>2]=(c[m>>2]|0)+(z>>>31)+(c[q>>2]^z>>31)}z=c[u>>2]|0;v=z<<1;A=c[n>>2]|0;p=v-A|0;c[n>>2]=z;z=c[b+(t<<2)>>2]|0;c[u>>2]=z;x=(ca(c[o>>2]|0,p)|0)+512>>10;w=z-x|0;c[f+(t<<2)>>2]=w;if(!((v|0)==(A|0)|(z|0)==(x|0))){x=w^p;c[o>>2]=(c[o>>2]|0)+(x>>>31)+(c[q>>2]^x>>31)}t=t+1|0;}while((t|0)<(g|0));i=j;return};case-3:{if((g|0)<=0){i=j;return}t=h+16|0;q=h+48|0;u=h|0;n=0;do{r=c[t>>2]|0;y=c[q>>2]|0;x=c[b+(n<<2)>>2]|0;c[t>>2]=x;p=(ca(c[o>>2]|0,y)|0)+512>>10;w=x-p|0;c[f+(n<<2)>>2]=w;do{if(!((y|0)==0|(x|0)==(p|0))){z=c[u>>2]|0;A=c[o>>2]|0;if((w^y|0)<0){v=A-z|0;c[o>>2]=v;if(!((v|0)<-1024)){break}c[o>>2]=-1024;break}else{v=A+z|0;c[o>>2]=v;if((v|0)<=1024){break}c[o>>2]=1024;break}}}while(0);y=c[a+(n<<2)>>2]|0;c[q>>2]=y;w=(ca(c[m>>2]|0,r)|0)+512>>10;p=y-w|0;c[e+(n<<2)>>2]=p;do{if(!((r|0)==0|(y|0)==(w|0))){x=c[u>>2]|0;v=c[m>>2]|0;if((p^r|0)<0){z=v-x|0;c[m>>2]=z;if(!((z|0)<-1024)){break}c[m>>2]=-1024;break}else{z=v+x|0;c[m>>2]=z;if((z|0)<=1024){break}c[m>>2]=1024;break}}}while(0);n=n+1|0;}while((n|0)<(g|0));i=j;return};default:{if((g|0)<=0){i=j;return}n=h|0;u=0;q=0;t=s;while(1){s=t&7;r=c[h+16+(q<<2)>>2]|0;p=c[a+(u<<2)>>2]|0;c[h+16+(s<<2)>>2]=p;w=(ca(c[m>>2]|0,r)|0)+512>>10;y=p-w|0;c[e+(u<<2)>>2]=y;if(!((r|0)==0|(p|0)==(w|0))){w=y^r;c[m>>2]=(c[m>>2]|0)+(w>>>31)+(c[n>>2]^w>>31)}w=c[h+48+(q<<2)>>2]|0;r=c[b+(u<<2)>>2]|0;c[h+48+(s<<2)>>2]=r;y=(ca(c[o>>2]|0,w)|0)+512>>10;p=r-y|0;c[f+(u<<2)>>2]=p;if(!((w|0)==0|(r|0)==(y|0))){y=p^w;c[o>>2]=(c[o>>2]|0)+(y>>>31)+(c[n>>2]^y>>31)}B=q+1&7;y=u+1|0;if((y|0)<(g|0)){u=y;q=B;t=s+1|0}else{break}}if((B|0)==0){i=j;return}nrc(k|0,h+16|0,32)|0;nrc(l|0,h+48|0,32)|0;c[h+16>>2]=c[k+(B<<2)>>2];c[h+48>>2]=c[l+(B<<2)>>2];B=q+2&7;c[h+20>>2]=c[k+(B<<2)>>2];c[h+52>>2]=c[l+(B<<2)>>2];B=q+3&7;c[h+24>>2]=c[k+(B<<2)>>2];c[h+56>>2]=c[l+(B<<2)>>2];B=q+4&7;c[h+28>>2]=c[k+(B<<2)>>2];c[h+60>>2]=c[l+(B<<2)>>2];B=q+5&7;c[h+32>>2]=c[k+(B<<2)>>2];c[h+64>>2]=c[l+(B<<2)>>2];B=q+6&7;c[h+36>>2]=c[k+(B<<2)>>2];c[h+68>>2]=c[l+(B<<2)>>2];B=q+7&7;c[h+40>>2]=c[k+(B<<2)>>2];c[h+72>>2]=c[l+(B<<2)>>2];c[h+44>>2]=c[k+(q<<2)>>2];c[h+76>>2]=c[l+(q<<2)>>2];i=j;return}}}function rgb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+1424|0;k=j|0;l=b+460|0;m=c[l>>2]|0;n=k+1416|0;c[n>>2]=(m&4194304)>>>0>3932160>>>0;o=(m>>>18<<8&7936)+1024|0;m=k+1412|0;c[m>>2]=o>>>0<6912>>>0?o:6912;o=b+576|0;p=c[o>>2]|0;q=k+1408|0;c[q>>2]=p;r=p+2|0;p=b+32|0;a:do{if((r|0)>0){s=0;while(1){t=b+72+(s<<3)|0;A4a(t,b+216+(s<<3)|0,c[p>>2]<<2);if((c[t>>2]|0)==0){u=79;break}if((c[l>>2]&1073741828|0)==0){t=b+72+(s<<3)+4|0;A4a(t,b+216+(s<<3)+4|0,c[p>>2]<<2);if((c[t>>2]|0)==0){u=79;break}}s=s+1|0;if((s|0)>=(r|0)){break a}}if((u|0)==79){i=j;return}}}while(0);u=k;r=b+608|0;l=r;nrc(u|0,l|0,1408)|0;s=e;nrc(c[b+72>>2]|0,s|0,c[p>>2]<<2)|0;e=f;nrc(c[b+76>>2]|0,e|0,c[p>>2]<<2)|0;f=c[q>>2]|0;b:do{if((f|0)>0){t=0;v=f;while(1){if((c[k+(t*88|0)+4>>2]|0)==0){w=t;x=v;break b}y=c[b+72+(t<<3)>>2]|0;z=c[b+72+(t<<3)+4>>2]|0;A=t+1|0;B=c[b+72+(A<<3)>>2]|0;C=c[b+72+(A<<3)+4>>2]|0;D=c[p>>2]|0;E=k+(t*88|0)|0;if((c[n>>2]|0)==0){qgb(y,z,B,C,D,E)}else{ogb(y,z,B,C,D,E,1)}E=c[q>>2]|0;if((A|0)<(E|0)){t=A;v=E}else{w=A;x=E;break}}}else{w=0;x=f}}while(0);f=c[p>>2]|0;n=k+1420|0;c[n>>2]=0;nrc(c[b+72+(x+1<<3)>>2]|0,c[b+72+(w<<3)>>2]|0,f<<2)|0;nrc(c[b+72+((c[q>>2]|0)+1<<3)+4>>2]|0,c[b+72+(w<<3)+4>>2]|0,c[p>>2]<<2)|0;w=b+440|0;f=c[w>>2]|0;if((f&8|0)==0){F=f}else{tgb(b,k,0,~~+Q(+g[b+2020>>2]+.5),0);F=c[w>>2]|0}if((F&4|0)==0){G=F}else{ugb(b,k);G=c[w>>2]|0}c:do{if((G&1|0)==0){H=G}else{F=b+612|0;d:do{if((c[F>>2]|0)!=0){f=c[r>>2]|0;e:do{if((f|0)>0){x=0;v=f;while(1){t=v-1|0;E=c[q>>2]|0;f:do{if((E|0)>0){A=0;D=E;while(1){C=c[b+608+(A*88|0)+4>>2]|0;if((C|0)==0){I=A;J=D;break f}c[k+(A*88|0)+4>>2]=C;c[k+(A*88|0)>>2]=t;C=A+1|0;vgb(k,c[b+72+(A<<3)>>2]|0,c[b+72+(A<<3)+4>>2]|0,c[b+72+(C<<3)>>2]|0,c[b+72+(C<<3)+4>>2]|0,c[p>>2]|0,A);B=c[q>>2]|0;if((C|0)<(B|0)){A=C;D=B}else{I=C;J=B;break}}}else{I=0;J=E}}while(0);E=b+72+(I<<3)|0;D=b+72+(I<<3)+4|0;A=c[p>>2]|0;B=c[m>>2]|0;if((A|0)!=0){C=(B|0)==0;z=c[E>>2]|0;y=c[D>>2]|0;K=A;while(1){L=K-1|0;M=c[z>>2]|0;N=(M|0)>-1?M:-M|0;M=(N>>>9)+N|0;do{if(!(M>>>0<256>>>0)){do{if(M>>>0<65536>>>0){O=(a[785608+(M>>>8)|0]|0)+8|0}else{if(M>>>0<16777216>>>0){O=(a[785608+(M>>>16)|0]|0)+16|0;break}else{O=(a[785608+(M>>>24)|0]|0)+24|0;break}}}while(0);if(C){break}if(!((d[110200+(M>>>((O-9|0)>>>0)&255)|0]|O<<8)>>>0<B>>>0)){P=x;break e}}}while(0);M=z+4|0;N=y+4|0;R=c[y>>2]|0;S=(R|0)>-1?R:-R|0;R=(S>>>9)+S|0;do{if(!(R>>>0<256>>>0)){do{if(R>>>0<65536>>>0){T=(a[785608+(R>>>8)|0]|0)+8|0}else{if(R>>>0<16777216>>>0){T=(a[785608+(R>>>16)|0]|0)+16|0;break}else{T=(a[785608+(R>>>24)|0]|0)+24|0;break}}}while(0);if(C){break}if(!((d[110200+(R>>>((T-9|0)>>>0)&255)|0]|T<<8)>>>0<B>>>0)){P=x;break e}}}while(0);if((L|0)==0){break}else{z=M;y=N;K=L}}}if((c[n>>2]|0)==0){P=x;break e}c[n>>2]=0;mrc(l|0,0,1408)|0;nrc(l|0,u|0,I*88|0)|0;nrc(c[b+72+(J+1<<3)>>2]|0,c[E>>2]|0,A<<2)|0;nrc(c[b+72+((c[q>>2]|0)+1<<3)+4>>2]|0,c[D>>2]|0,c[p>>2]<<2)|0;if((t|0)>0){x=1;v=t}else{break d}}}else{P=0}}while(0);v=f+1|0;if((P|0)==0&(v|0)<8){U=v}else{break}do{v=c[q>>2]|0;g:do{if((v|0)>0){x=0;K=v;while(1){y=c[b+608+(x*88|0)+4>>2]|0;if((y|0)==0){V=x;W=K;break g}c[k+(x*88|0)+4>>2]=y;c[k+(x*88|0)>>2]=U;y=x+1|0;vgb(k,c[b+72+(x<<3)>>2]|0,c[b+72+(x<<3)+4>>2]|0,c[b+72+(y<<3)>>2]|0,c[b+72+(y<<3)+4>>2]|0,c[p>>2]|0,x);z=c[q>>2]|0;if((y|0)<(z|0)){x=y;K=z}else{V=y;W=z;break}}}else{V=0;W=v}}while(0);v=b+72+(V<<3)|0;K=b+72+(V<<3)+4|0;x=c[p>>2]|0;t=c[m>>2]|0;if((x|0)!=0){D=(t|0)==0;A=c[v>>2]|0;E=c[K>>2]|0;z=x;while(1){y=z-1|0;B=c[A>>2]|0;C=(B|0)>-1?B:-B|0;B=(C>>>9)+C|0;do{if(!(B>>>0<256>>>0)){do{if(B>>>0<65536>>>0){X=(a[785608+(B>>>8)|0]|0)+8|0}else{if(B>>>0<16777216>>>0){X=(a[785608+(B>>>16)|0]|0)+16|0;break}else{X=(a[785608+(B>>>24)|0]|0)+24|0;break}}}while(0);if(D){break}if(!((d[110200+(B>>>((X-9|0)>>>0)&255)|0]|X<<8)>>>0<t>>>0)){break d}}}while(0);B=A+4|0;L=E+4|0;N=c[E>>2]|0;M=(N|0)>-1?N:-N|0;N=(M>>>9)+M|0;do{if(!(N>>>0<256>>>0)){do{if(N>>>0<65536>>>0){Y=(a[785608+(N>>>8)|0]|0)+8|0}else{if(N>>>0<16777216>>>0){Y=(a[785608+(N>>>16)|0]|0)+16|0;break}else{Y=(a[785608+(N>>>24)|0]|0)+24|0;break}}}while(0);if(D){break}if(!((d[110200+(N>>>((Y-9|0)>>>0)&255)|0]|Y<<8)>>>0<t>>>0)){break d}}}while(0);if((y|0)==0){break}else{A=B;E=L;z=y}}}if((c[n>>2]|0)==0){break d}c[n>>2]=0;mrc(l|0,0,1408)|0;nrc(l|0,u|0,V*88|0)|0;nrc(c[b+72+(W+1<<3)>>2]|0,c[v>>2]|0,x<<2)|0;nrc(c[b+72+((c[q>>2]|0)+1<<3)+4>>2]|0,c[K>>2]|0,c[p>>2]<<2)|0;U=U+1|0;}while((U|0)<8)}}while(0);f=c[w>>2]|0;do{if((f&2|0)!=0){if((c[F>>2]|0)==0){break}z=b+2020|0;g[z>>2]=(+g[z>>2]*2.0+ +(c[r>>2]|0))/3.0;H=f;break c}}while(0);g[b+2020>>2]=2.0;H=f}}while(0);if((H&16|0)!=0){ugb(b,k)}k=c[q>>2]|0;if((h|0)==0){Z=0}else{h=k+1|0;nrc(s|0,c[b+72+(h<<3)>>2]|0,c[p>>2]<<2)|0;nrc(e|0,c[b+72+(h<<3)+4>>2]|0,c[p>>2]<<2)|0;Z=0}while(1){if((Z|0)>=(k|0)){break}if((c[b+608+(Z*88|0)+4>>2]|0)==0){break}else{Z=Z+1|0}}c[o>>2]=Z;i=j;return}function sgb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((d|0)==0){return}e=a|0;f=a+4|0;g=a+8|0;a=b+(d-1<<2)|0;b=d;d=c[e>>2]|0;while(1){h=b-1|0;i=c[a>>2]|0;j=(i|0)>-1?i:-i|0;i=d>>4;k=i+1|0;do{if(j>>>0<k>>>0){l=d-(((d+126|0)/128|0)<<1)|0;c[e>>2]=l;m=l}else{l=(((d+128|0)/128|0)*5|0)+d|0;c[e>>2]=l;n=c[f>>2]|0;o=n>>4;if((j-k|0)>>>0<(o+1|0)>>>0){c[f>>2]=n-(((n+62|0)/64|0)<<1);m=l;break}c[f>>2]=(((n+64|0)/64|0)*5|0)+n;n=c[g>>2]|0;if((j+~i+~o|0)>>>0<((n>>4)+1|0)>>>0){c[g>>2]=n-(((n+30|0)/32|0)<<1);m=l;break}else{c[g>>2]=(((n+32|0)/32|0)*5|0)+n;m=l;break}}}while(0);if((h|0)==0){break}else{a=a-4|0;b=h;d=m}}return}function tgb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;j=i;i=i+88|0;k=j|0;l=(c[b+456>>2]|0)-f|0;m=f+1|0;n=e+1408|0;if((l|0)<1){o=3}else{if((m|0)==(c[n>>2]|0)){o=3}else{p=l}}if((o|0)==3){p=1}mrc(k|0,0,88)|0;l=c[b+72+(f<<3)>>2]|0;q=c[b+72+(f<<3)+4>>2]|0;r=b+72+(m<<3)|0;s=c[r>>2]|0;t=b+72+(m<<3)+4|0;u=c[t>>2]|0;v=(p|0)==1;w=b+460|0;x=b+440|0;y=e+(f*88|0)+4|0;z=e+(f*88|0)|0;A=b+32|0;B=e+1412|0;C=e+1420|0;D=b+608|0;E=e;F=m*88|0;G=-3;do{do{if(!((G|0)==0|(G-9|0)>>>0<8>>>0)){if((G|0)==17&v){if((m|0)<(c[n>>2]|0)){break}}if(G>>>0>4294967293>>>0){if((c[w>>2]&32|0)==0){break}}if((c[x>>2]|0)==0){if((G-5|0)>>>0<12>>>0){break}}c[y>>2]=G;c[z>>2]=g;vgb(e,l,q,s,u,c[A>>2]|0,f);H=c[A>>2]|0;I=c[B>>2]|0;a:do{if((H|0)==0){o=32}else{J=(I|0)==0;K=s;L=u;M=H;while(1){N=M-1|0;O=c[K>>2]|0;P=(O|0)>-1?O:-O|0;O=(P>>>9)+P|0;do{if(!(O>>>0<256>>>0)){do{if(O>>>0<65536>>>0){Q=(a[785608+(O>>>8)|0]|0)+8|0}else{if(O>>>0<16777216>>>0){Q=(a[785608+(O>>>16)|0]|0)+16|0;break}else{Q=(a[785608+(O>>>24)|0]|0)+24|0;break}}}while(0);if(J){break}if(!((d[110200+(O>>>((Q-9|0)>>>0)&255)|0]|Q<<8)>>>0<I>>>0)){R=-1;break a}}}while(0);O=K+4|0;P=L+4|0;S=c[L>>2]|0;T=(S|0)>-1?S:-S|0;S=(T>>>9)+T|0;do{if(!(S>>>0<256>>>0)){do{if(S>>>0<65536>>>0){U=(a[785608+(S>>>8)|0]|0)+8|0}else{if(S>>>0<16777216>>>0){U=(a[785608+(S>>>16)|0]|0)+16|0;break}else{U=(a[785608+(S>>>24)|0]|0)+24|0;break}}}while(0);if(J){break}if(!((d[110200+(S>>>((U-9|0)>>>0)&255)|0]|U<<8)>>>0<I>>>0)){R=-1;break a}}}while(0);if((N|0)==0){o=32;break}else{K=O;L=P;M=N}}}}while(0);do{if((o|0)==32){o=0;if((c[C>>2]|0)==0){R=0;break}c[C>>2]=0;mrc(D|0,0,1408)|0;nrc(D|0,E|0,F)|0;nrc(c[b+72+((c[n>>2]|0)+1<<3)>>2]|0,c[r>>2]|0,c[A>>2]<<2)|0;nrc(c[b+72+((c[n>>2]|0)+1<<3)+4>>2]|0,c[t>>2]|0,c[A>>2]<<2)|0;R=0}}while(0);c[k+(G+3<<2)>>2]=R}}while(0);G=G+1|0;}while((G|0)<19);if((m|0)<(c[n>>2]|0)){V=p}else{i=j;return}while(1){p=V-1|0;if((V|0)==0){o=40;break}else{W=h;X=0;Y=0}do{G=c[k+(Y<<2)>>2]|0;R=(G|0)!=0&G>>>0<W>>>0;W=R?G:W;X=R?Y-3|0:X;Y=Y+1|0;}while((Y|0)<22);if((X|0)==0){o=40;break}c[k+(X+3<<2)>>2]=0;c[y>>2]=X;c[z>>2]=g;vgb(e,l,q,s,u,c[A>>2]|0,f);tgb(b,e,m,g,W);if((m|0)<(c[n>>2]|0)){V=p}else{o=40;break}}if((o|0)==40){i=j;return}}function ugb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=e;g=b+608|0;h=e+1408|0;i=b+32|0;j=e+1412|0;k=e+1420|0;l=c[h>>2]|0;a:while(1){nrc(f|0,g|0,1408)|0;if((l|0)>0){m=0;n=0;o=l}else{p=36;break}b:while(1){q=n;r=o;while(1){s=c[b+608+(q*88|0)+4>>2]|0;if((s|0)==0){t=r;break b}u=q+1|0;if((u|0)>=(r|0)){t=r;break b}v=c[b+608+(u*88|0)+4>>2]|0;if((v|0)==0){t=r;break b}if((s|0)==(v|0)){vgb(e,c[b+72+(q<<3)>>2]|0,c[b+72+(q<<3)+4>>2]|0,c[b+72+(u<<3)>>2]|0,c[b+72+(u<<3)+4>>2]|0,c[i>>2]|0,q)}else{v=e+(q*88|0)|0;s=b+608+(u*88|0)|0;nrc(v|0,s|0,88)|0;w=e+(u*88|0)|0;x=b+608+(q*88|0)|0;nrc(w|0,x|0,88)|0;c:do{if((q|0)<(c[h>>2]|0)){y=q;while(1){if((c[b+608+(y*88|0)+4>>2]|0)==0){z=y;break c}A=y+1|0;vgb(e,c[b+72+(y<<3)>>2]|0,c[b+72+(y<<3)+4>>2]|0,c[b+72+(A<<3)>>2]|0,c[b+72+(A<<3)+4>>2]|0,c[i>>2]|0,y);if((A|0)<(c[h>>2]|0)){y=A}else{z=A;break}}}else{z=q}}while(0);B=b+72+(z<<3)|0;C=b+72+(z<<3)+4|0;y=c[i>>2]|0;A=c[j>>2]|0;d:do{if((y|0)==0){p=32}else{D=(A|0)==0;E=c[B>>2]|0;F=c[C>>2]|0;G=y;while(1){H=G-1|0;I=c[E>>2]|0;J=(I|0)>-1?I:-I|0;I=(J>>>9)+J|0;do{if(!(I>>>0<256>>>0)){do{if(I>>>0<65536>>>0){K=(a[785608+(I>>>8)|0]|0)+8|0}else{if(I>>>0<16777216>>>0){K=(a[785608+(I>>>16)|0]|0)+16|0;break}else{K=(a[785608+(I>>>24)|0]|0)+24|0;break}}}while(0);if(D){break}if(!((d[110200+(I>>>((K-9|0)>>>0)&255)|0]|K<<8)>>>0<A>>>0)){break d}}}while(0);I=E+4|0;J=F+4|0;L=c[F>>2]|0;M=(L|0)>-1?L:-L|0;L=(M>>>9)+M|0;do{if(!(L>>>0<256>>>0)){do{if(L>>>0<65536>>>0){N=(a[785608+(L>>>8)|0]|0)+8|0}else{if(L>>>0<16777216>>>0){N=(a[785608+(L>>>16)|0]|0)+16|0;break}else{N=(a[785608+(L>>>24)|0]|0)+24|0;break}}}while(0);if(D){break}if(!((d[110200+(L>>>((N-9|0)>>>0)&255)|0]|N<<8)>>>0<A>>>0)){break d}}}while(0);if((H|0)==0){p=32;break}else{E=I;F=J;G=H}}}}while(0);if((p|0)==32){p=0;if((c[k>>2]|0)!=0){break}}nrc(v|0,x|0,88)|0;nrc(w|0,s|0,88)|0;vgb(e,c[b+72+(q<<3)>>2]|0,c[b+72+(q<<3)+4>>2]|0,c[b+72+(u<<3)>>2]|0,c[b+72+(u<<3)+4>>2]|0,c[i>>2]|0,q)}A=c[h>>2]|0;if((u|0)<(A|0)){q=u;r=A}else{t=A;break b}}c[k>>2]=0;mrc(g|0,0,1408)|0;nrc(g|0,f|0,z*88|0)|0;nrc(c[b+72+((c[h>>2]|0)+1<<3)>>2]|0,c[B>>2]|0,c[i>>2]<<2)|0;nrc(c[b+72+((c[h>>2]|0)+1<<3)+4>>2]|0,c[C>>2]|0,c[i>>2]<<2)|0;r=c[h>>2]|0;if((u|0)<(r|0)){m=1;n=u;o=r}else{l=r;continue a}}if((m|0)==0){p=36;break}else{l=t}}if((p|0)==36){return}}function vgb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=i;i=i+88|0;k=j|0;mrc(k|0,0,88)|0;l=c[a+(h*88|0)>>2]|0;if((l|0)==7){m=7}else{m=(l|0)<2?3:l+1|0}c[k+4>>2]=c[a+(h*88|0)+4>>2];n=k|0;c[n>>2]=m;ogb(b,d,e,f,(g|0)<2048?g:2048,k,-1);c[n>>2]=l;if((h|0)==0){pgb(k);o=k+16|0;p=k+48|0}else{m=k+16|0;mrc(m|0,0,64)|0;o=m;p=k+48|0}m=o;o=p;p=a+(h*88|0)+16|0;nrc(p|0,m|0,32)|0;q=a+(h*88|0)+48|0;nrc(q|0,o|0,32)|0;r=k+8|0;s=a+(h*88|0)+8|0;c[s>>2]=c[r>>2];t=k+12|0;u=a+(h*88|0)+12|0;c[u>>2]=c[t>>2];if((l|0)==0){c[n>>2]=1;ogb(b,d,e,f,g,k,1);c[n>>2]=0;nrc(m|0,p|0,32)|0;nrc(o|0,q|0,32)|0;q=(c[k+80>>2]|0)/(g|0)|0;c[r>>2]=q;c[s>>2]=q;q=(c[k+84>>2]|0)/(g|0)|0;c[t>>2]=q;c[u>>2]=q}if((c[a+1416>>2]|0)==0){qgb(b,d,e,f,g,k);i=j;return}else{ogb(b,d,e,f,g,k,1);i=j;return}}function wgb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+32|0;j=h|0;k=f+80|0;c[k>>2]=0;if((g|0)<0){l=e-1|0;m=a+(l<<2)|0;n=b+(l<<2)|0}else{m=a;n=b}b=f+8|0;a=c[b>>2]|0;do{if((a|0)<-1024){o=-1024}else{l=(a|0)>1024?1024:a;if((l|0)>0){p=l-(l+64>>7)|0}else{p=l}l=(p+4|0)>>>3<<24;q=l>>21;if((l|0)<=0){o=q;break}o=(q+64>>7)+q|0}}while(0);c[b>>2]=o;o=0;do{p=f+16+(o<<2)|0;a=(jgb(c[p>>2]|0)|0)&65535;q=a<<16>>16<0;l=(q?-a&65535:a)<<16>>16;a=d[110712+(l&255)|0]|0|256;r=l>>>8<<16;l=r>>16;if((r|0)>589824){s=a<<l-9}else{s=a>>>((9-l|0)>>>0)}c[p>>2]=q?-s|0:s;o=o+1|0;}while((o|0)<8);o=f+4|0;s=c[o>>2]|0;if((s|0)>8){if((e|0)==0){i=h;return}q=f+16|0;p=f+20|0;l=f|0;a=n;r=m;t=e;u=s;while(1){v=t-1|0;w=u&1;x=c[q>>2]|0;y=ca(w^3,x)|0;z=y-(c[p>>2]|0)>>(w^1);c[p>>2]=x;x=c[r>>2]|0;c[q>>2]=x;if((z|0)==(z<<16>>16|0)){w=c[b>>2]|0;A=(ca(w,z)|0)+512>>10;B=w}else{w=c[b>>2]|0;A=(ca(w,z>>9&-128)|0|1)+((ca(w,z&65535)|0)>>9)>>1;B=w}w=x-A|0;if((z|0)==0|(x|0)==(A|0)){C=B}else{x=w^z;z=B+(x>>>31)+(c[l>>2]^x>>31)|0;c[b>>2]=z;C=z}c[k>>2]=(c[k>>2]|0)+C;c[a>>2]=w;if((v|0)==0){break}a=a+(g<<2)|0;r=r+(g<<2)|0;t=v;u=c[o>>2]|0}i=h;return}if((s|0)<1|(e|0)==0){i=h;return}u=f|0;t=0;r=n;n=m;m=e;e=s;while(1){s=m-1|0;a=c[f+16+(t<<2)>>2]|0;C=c[n>>2]|0;c[f+16+((e+t&7)<<2)>>2]=C;D=t+1&7;if((a|0)==(a<<16>>16|0)){l=c[b>>2]|0;E=(ca(l,a)|0)+512>>10;F=l}else{l=c[b>>2]|0;E=(ca(l,a>>9&-128)|0|1)+((ca(l,a&65535)|0)>>9)>>1;F=l}l=C-E|0;if((a|0)==0|(C|0)==(E|0)){G=F}else{C=l^a;a=F+(C>>>31)+(c[u>>2]^C>>31)|0;c[b>>2]=a;G=a}c[k>>2]=(c[k>>2]|0)+G;c[r>>2]=l;if((s|0)==0){break}t=D;r=r+(g<<2)|0;n=n+(g<<2)|0;m=s;e=c[o>>2]|0}if((D|0)==0){i=h;return}if(!(((c[o>>2]|0)-1|0)>>>0<8>>>0)){i=h;return}nrc(j|0,f+16|0,32)|0;c[f+16>>2]=c[j+(D<<2)>>2];c[f+20>>2]=c[j+((t+2&7)<<2)>>2];c[f+24>>2]=c[j+((t+3&7)<<2)>>2];c[f+28>>2]=c[j+((t+4&7)<<2)>>2];c[f+32>>2]=c[j+((t+5&7)<<2)>>2];c[f+36>>2]=c[j+((t+6&7)<<2)>>2];c[f+40>>2]=c[j+((t+7&7)<<2)>>2];c[f+44>>2]=c[j+(t<<2)>>2];i=h;return}function xgb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;i=i+88|0;k=j|0;l=(c[b+456>>2]|0)-f|0;m=f+1|0;n=e+1408|0;if((l|0)<1){o=3}else{if((m|0)==(c[n>>2]|0)){o=3}else{p=l}}if((o|0)==3){p=1}mrc(k|0,0,88)|0;l=c[b+72+(f<<3)>>2]|0;q=b+72+(m<<3)|0;r=c[q>>2]|0;s=(p|0)==1;t=b+440|0;u=e+(f*88|0)+4|0;v=e+(f*88|0)|0;w=b+32|0;x=e|0;y=e+1412|0;z=e+1420|0;A=b+608|0;B=e;C=m*88|0;D=1;do{if((D|0)==17&s){if((m|0)>=(c[n>>2]|0)){o=8}}else{o=8}do{if((o|0)==8){o=0;if((D-9|0)>>>0<8>>>0){break}if((c[t>>2]|0)==0){if((D-5|0)>>>0<12>>>0){break}}c[u>>2]=D;c[v>>2]=g;zgb(l,r,c[w>>2]|0,x,f);E=c[w>>2]|0;F=c[y>>2]|0;a:do{if((E|0)==0|(F|0)==0){o=20}else{G=r;H=E;while(1){I=H-1|0;J=G+4|0;K=c[G>>2]|0;L=(K|0)>-1?K:-K|0;K=(L>>>9)+L|0;if(!(K>>>0<256>>>0)){do{if(K>>>0<65536>>>0){M=(a[785608+(K>>>8)|0]|0)+8|0}else{if(K>>>0<16777216>>>0){M=(a[785608+(K>>>16)|0]|0)+16|0;break}else{M=(a[785608+(K>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[110200+(K>>>((M-9|0)>>>0)&255)|0]|M<<8)>>>0<F>>>0)){N=-1;break a}}if((I|0)==0){o=20;break}else{G=J;H=I}}}}while(0);do{if((o|0)==20){o=0;if((c[z>>2]|0)==0){N=0;break}c[z>>2]=0;mrc(A|0,0,1408)|0;nrc(A|0,B|0,C)|0;nrc(c[b+72+((c[n>>2]|0)+1<<3)>>2]|0,c[q>>2]|0,c[w>>2]<<2)|0;N=0}}while(0);c[k+(D+3<<2)>>2]=N}}while(0);D=D+1|0;}while((D|0)<19);if((m|0)<(c[n>>2]|0)){O=p}else{i=j;return}while(1){p=O-1|0;if((O|0)==0){o=28;break}else{P=h;Q=0;R=0}do{D=c[k+(R<<2)>>2]|0;N=(D|0)!=0&D>>>0<P>>>0;P=N?D:P;Q=N?R-3|0:Q;R=R+1|0;}while((R|0)<22);if((Q|0)==0){o=28;break}c[k+(Q+3<<2)>>2]=0;c[u>>2]=Q;c[v>>2]=g;zgb(l,r,c[w>>2]|0,x,f);xgb(b,e,m,g,P);if((m|0)<(c[n>>2]|0)){O=p}else{o=28;break}}if((o|0)==28){i=j;return}}function ygb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=e;g=b+608|0;h=e+1408|0;i=b+32|0;j=e|0;k=e+1412|0;l=e+1420|0;m=c[h>>2]|0;a:while(1){nrc(f|0,g|0,1408)|0;if((m|0)>0){n=0;o=0;p=m}else{q=27;break}b:while(1){r=o;s=p;while(1){t=c[b+608+(r*88|0)+4>>2]|0;if((t|0)==0){u=s;break b}v=r+1|0;if((v|0)>=(s|0)){u=s;break b}w=c[b+608+(v*88|0)+4>>2]|0;if((w|0)==0){u=s;break b}if((t|0)==(w|0)){zgb(c[b+72+(r<<3)>>2]|0,c[b+72+(v<<3)>>2]|0,c[i>>2]|0,j,r)}else{w=e+(r*88|0)|0;t=b+608+(v*88|0)|0;nrc(w|0,t|0,88)|0;x=e+(v*88|0)|0;y=b+608+(r*88|0)|0;nrc(x|0,y|0,88)|0;c:do{if((r|0)<(c[h>>2]|0)){z=r;while(1){A=b+72+(z<<3)|0;B=c[A>>2]|0;if((c[b+608+(z*88|0)+4>>2]|0)==0){C=A;D=B;E=z;break c}A=z+1|0;zgb(B,c[b+72+(A<<3)>>2]|0,c[i>>2]|0,j,z);if((A|0)<(c[h>>2]|0)){z=A}else{F=A;q=11;break}}}else{F=r;q=11}}while(0);if((q|0)==11){q=0;z=b+72+(F<<3)|0;C=z;D=c[z>>2]|0;E=F}z=c[i>>2]|0;A=c[k>>2]|0;d:do{if((z|0)==0|(A|0)==0){q=23}else{B=D;G=z;while(1){H=G-1|0;I=B+4|0;J=c[B>>2]|0;K=(J|0)>-1?J:-J|0;J=(K>>>9)+K|0;if(!(J>>>0<256>>>0)){do{if(J>>>0<65536>>>0){L=(a[785608+(J>>>8)|0]|0)+8|0}else{if(J>>>0<16777216>>>0){L=(a[785608+(J>>>16)|0]|0)+16|0;break}else{L=(a[785608+(J>>>24)|0]|0)+24|0;break}}}while(0);if(!((d[110200+(J>>>((L-9|0)>>>0)&255)|0]|L<<8)>>>0<A>>>0)){break d}}if((H|0)==0){q=23;break}else{B=I;G=H}}}}while(0);if((q|0)==23){q=0;if((c[l>>2]|0)!=0){break}}nrc(w|0,y|0,88)|0;nrc(x|0,t|0,88)|0;zgb(c[b+72+(r<<3)>>2]|0,c[b+72+(v<<3)>>2]|0,c[i>>2]|0,j,r)}A=c[h>>2]|0;if((v|0)<(A|0)){r=v;s=A}else{u=A;break b}}c[l>>2]=0;mrc(g|0,0,1408)|0;nrc(g|0,f|0,E*88|0)|0;nrc(c[b+72+((c[h>>2]|0)+1<<3)>>2]|0,c[C>>2]|0,c[i>>2]<<2)|0;s=c[h>>2]|0;if((v|0)<(s|0)){n=1;o=v;p=s}else{m=s;continue a}}if((n|0)==0){q=27;break}else{m=u}}if((q|0)==27){return}}function zgb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+88|0;h=g|0;j=c[e+(f*88|0)>>2]|0;k=c[e+(f*88|0)+4>>2]|0;if((j|0)==7){l=7}else{l=(j|0)<2?3:j+1|0}mrc(h|0,0,88)|0;m=h+4|0;c[m>>2]=k;k=h|0;c[k>>2]=l;wgb(a,b,(d|0)<2048?d:2048,h,-1);c[k>>2]=j;a:do{if((f|0)==0){l=c[m>>2]|0;if((l|0)<=8){if((l|0)>1){n=0;o=l;p=0}else{break}while(1){q=n&7;r=o+7&7;s=h+16+(r<<2)|0;t=h+16+(q<<2)|0;u=c[t>>2]^c[s>>2];c[t>>2]=u;v=c[s>>2]^u;c[s>>2]=v;c[t>>2]=c[t>>2]^v;v=p+1|0;if((v|0)<((c[m>>2]|0)/2|0|0)){n=q+1|0;o=r;p=v}else{break a}}}v=h+16|0;r=c[v>>2]|0;if((l&1|0)==0){q=h+20|0;t=(r*3|0)-(c[q>>2]|0)>>1;c[q>>2]=r;c[v>>2]=t;w=(t*3|0)-r>>1;x=q}else{q=h+20|0;t=(r<<1)-(c[q>>2]|0)|0;c[q>>2]=r;c[v>>2]=t;w=(t<<1)-r|0;x=q}c[x>>2]=w}else{mrc(h+16|0,0,32)|0}}while(0);w=e+(f*88|0)+16|0;x=h+16|0;nrc(w|0,x|0,32)|0;p=h+8|0;o=e+(f*88|0)+8|0;c[o>>2]=c[p>>2];if((j|0)!=0){wgb(a,b,d,h,1);i=g;return}c[k>>2]=1;wgb(a,b,d,h,1);c[k>>2]=0;nrc(x|0,w|0,32)|0;w=(c[h+80>>2]|0)/(d|0)|0;c[p>>2]=w;c[o>>2]=w;wgb(a,b,d,h,1);i=g;return}function Agb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[d>>2]|0;f=e>>>23&255;do{if((f|0)==255){g=b+548|0;a[g]=a[g]|32;h=0;i=16777216}else{g=a[b+551|0]|0;j=g&255;if((f|0)==0){h=g<<24>>24==0?0:j-1|0;i=e&8388607;break}else{h=j-f|0;i=e&8388607|8388608;break}}}while(0);j=(h|0)<25?i>>h:0;do{if((j|0)==0){if((f|e&8388607|0)!=0){i=b+564|0;c[i>>2]=(c[i>>2]|0)+1;break}if((e|0)>=0){break}i=b+568|0;c[i>>2]=(c[i>>2]|0)+1}else{if((h|0)==0){break}i=(1<<h)-1|0;g=e&8388607&i;if((g|0)==0){k=b+556|0;c[k>>2]=(c[k>>2]|0)+1;break}if((g|0)==(i|0)){i=b+552|0;c[i>>2]=(c[i>>2]|0)+1;break}else{i=b+560|0;c[i>>2]=(c[i>>2]|0)+1;break}}}while(0);h=b+572|0;c[h>>2]=c[h>>2]|j;c[d>>2]=(e|0)<0?-j|0:j;return}function Bgb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0;h=i;i=i+128|0;j=h|0;k=h+8|0;l=h+88|0;m=h+96|0;n=h+104|0;o=h+112|0;p=e;q=b+60|0;r=c[q>>2]|0;c[r+5460>>2]=b;s=r+5496|0;c[s>>2]=0;t=r+5500|0;c[t>>2]=0;c[f>>2]=0;u=r+5468|0;c[u>>2]=0;v=r+5488|0;c[v>>2]=0;w=g+24|0;x=c[w>>2]|0;y=g+28|0;g=c[y>>2]|0;if(!((g|0)>-1)){KIb(0,0,2401840,(z=i,i=i+24|0,c[z>>2]=2395136,c[z+8>>2]=2387968,c[z+16>>2]=135,z)|0);i=z;Hd();return 0}A=x+g|0;B=A;C=x;if(g>>>0<12>>>0){D=-1094995529;i=h;return D|0}E=x+4|0;F=x;if((d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)!=1179011410){KIb(b,16,2441400,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1094995529;i=h;return D|0}if((g-4|0)<4){G=0;H=E}else{g=E;G=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;H=x+8|0}x=B-H|0;if(x>>>0<G>>>0){D=-1094995529;i=h;return D|0}do{if((x|0)>=4){G=H;if((d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)!=1346520407){break}G=H+4|0;g=r+5492|0;OGb(g);a:do{if((A|0)!=(G|0)){E=l|0;F=l;I=b;J=b+140|0;K=k+24|0;L=k+28|0;M=e+44|0;N=e+12|0;O=e+68|0;P=e+72|0;Q=r+5480|0;R=r+5484|0;S=r+5472|0;T=r+5476|0;U=o|0;V=o+8|0;W=o+4|0;X=G;Y=0;b:while(1){mrc(E|0,0,5)|0;if((B-X|0)<4){Z=0;_=X}else{$=X;Z=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;_=X+4|0}if((B-_|0)<4){aa=_;ba=0}else{$=_;da=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;if((da|0)==-1){D=-1094995529;ea=119;break}else{aa=_+4|0;ba=da}}da=(ba&1)+ba|0;$=aa;fa=B-$|0;if(fa>>>0<da>>>0){D=-1094995529;ea=119;break}do{if((Z|0)==1213221953){if((Y&16|0)==0){KIb(I,24,2291296,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}if((da|0)==0){ea=93;break b}if((fa|0)<1){ga=0;ha=aa}else{ga=d[aa]|0;ha=aa+1|0}ia=ha;c[Q>>2]=(c[w>>2]|0)+(ia-C);ja=da-1|0;c[R>>2]=ja;ka=B-ia|0;ia=ha+(ka>>>0>ja>>>0?ja:ka)|0;ka=ga&3;if(ka>>>0>1>>>0){KIb(I,40,2199576,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;la=Y;ma=ia;break}else{c[u>>2]=1;c[S>>2]=ka;c[T>>2]=ga>>>2&3;la=Y;ma=ia;break}}else if((Z|0)==1278758998){if((c[f>>2]|0)==0){ia=Dgb(b,p,f,(c[w>>2]|0)+($-C)|0,da,0)|0;if((ia|0)<0){D=ia;ea=119;break b}}la=Y;ma=aa+(fa>>>0>da>>>0?da:fa)|0}else if((Z|0)==1179211845){ia=$-C|0;do{if((c[v>>2]|0)==0){if((Y&8|0)==0){KIb(I,24,2141256,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}c[v>>2]=1;ka=c[w>>2]|0;ja=ka+ia|0;na=c[y>>2]|0;if(!((na-ia|0)>-1)){ea=105;break b}c[U>>2]=ja;c[V>>2]=ja;c[W>>2]=ka+na;if((B3a(o,m,n)|0)<0){KIb(I,16,2117768,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break}na=c[n>>2]|0;ka=c[V>>2]|0;ja=(c[W>>2]|0)-ka|0;if((na|0)<0){oa=0}else{oa=(ja|0)<(na|0)?ja:na}c[U>>2]=ka+oa;if((Dpb(b,o,c[m>>2]|0,0,g)|0)<0){KIb(I,16,2635832,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;break}else{ka=QHb(p)|0;PGb(ka,c[g>>2]|0,0);break}}else{KIb(I,40,2167976,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}}while(0);OGb(g);la=Y;ma=aa+(fa>>>0>da>>>0?da:fa)|0}else if((Z|0)==540561494){do{if((c[f>>2]|0)==0){ia=(c[w>>2]|0)+($-C)|0;ka=c[q>>2]|0;na=ka+5464|0;do{if((c[na>>2]|0)==0){lab(b)|0;c[na>>2]=1;if((c[ka+5468>>2]|0)==0){break}c[J>>2]=35}}while(0);c[ka+5504>>2]=0;if((da|0)<0){ea=25;break b}J1(k);c[K>>2]=ia;c[L>>2]=da;na=hab(b,e,f,k)|0;if((c[ka+5468>>2]|0)==0){if((na|0)<0){D=na;ea=119;break b}else{break}}na=c[ka+5480>>2]|0;ja=c[ka+5484>>2]|0;pa=c[q>>2]|0;qa=c[pa+5472>>2]|0;do{if((qa|0)==1){c[j>>2]=0;ra=UHb()|0;sa=pa+5456|0;c[sa>>2]=ra;if((ra|0)==0){D=-12;ea=119;break b}ta=Dgb(b,ra,j,na,ja,1)|0;if((ta|0)<0){ea=35;break b}if((c[j>>2]|0)==0){ea=39;break b}ra=pa+5500|0;ua=c[ra>>2]|0;if((ua|0)>0){va=pa+5496|0;wa=0;xa=c[va>>2]|0;ya=ua;while(1){ua=c[sa>>2]|0;if((xa|0)>0){za=ca(c[ua+32>>2]|0,wa)|0;Aa=ca(c[M>>2]|0,wa)|0;Ba=0;Ca=(c[ua>>2]|0)+(za+2)|0;za=(c[N>>2]|0)+Aa|0;while(1){a[za]=a[Ca]|0;Aa=Ba+1|0;Da=c[va>>2]|0;if((Aa|0)<(Da|0)){Ba=Aa;Ca=Ca+4|0;za=za+1|0}else{break}}Ea=Da;Fa=c[ra>>2]|0}else{Ea=xa;Fa=ya}za=wa+1|0;if((za|0)<(Fa|0)){wa=za;xa=Ea;ya=Fa}else{break}}}VHb(sa)}else if((qa|0)==0){if(!((ja|0)>-1)){ea=29;break b}ya=pa+5500|0;if((c[ya>>2]|0)<=0){break}xa=pa+5496|0;wa=na+ja|0;ra=na;va=0;while(1){za=(c[N>>2]|0)+(ca(c[M>>2]|0,va)|0)|0;Ca=c[xa>>2]|0;Ba=wa-ra|0;Aa=Ba>>>0>Ca>>>0?Ca:Ba;nrc(za|0,ra|0,Aa)|0;za=va+1|0;if((za|0)<(c[ya>>2]|0)){ra=ra+Aa|0;va=za}else{break}}}}while(0);na=c[pa+5476>>2]|0;if((na|0)==0){break}ja=c[M>>2]|0;qa=c[N>>2]|0;if((c[O>>2]|0)>1){ka=1;ia=qa;va=a[qa]|0;do{ia=ia+1|0;va=(a[ia]|0)+va&255;a[ia]=va;ka=ka+1|0;}while((ka|0)<(c[O>>2]|0));Ga=c[N>>2]|0}else{Ga=qa}ka=c[P>>2]|0;if((ka|0)>1){va=1;ia=Ga;pa=a[Ga]|0;while(1){ra=ia+ja|0;ya=(a[ra]|0)+pa&255;a[ra]=ya;wa=va+1|0;xa=c[P>>2]|0;if((wa|0)<(xa|0)){va=wa;ia=ra;pa=ya}else{Ha=xa;break}}}else{Ha=ka}if((na|0)==1){if((Ha|0)<=1){break}pa=1;ia=c[O>>2]|0;va=Ha;while(1){if((ia|0)>1){qa=(ca(pa,ja)|0)+1|0;xa=1;ya=(c[N>>2]|0)+qa|0;while(1){a[ya]=(a[ya]|0)+(a[ya-1|0]|0);qa=xa+1|0;Ia=c[O>>2]|0;if((qa|0)<(Ia|0)){xa=qa;ya=ya+1|0}else{break}}Ja=Ia;Ka=c[P>>2]|0}else{Ja=ia;Ka=va}ya=pa+1|0;if((ya|0)<(Ka|0)){pa=ya;ia=Ja;va=Ka}else{break}}}else if((na|0)==2){if((Ha|0)<=1){break}va=-ja|0;ia=1;pa=c[O>>2]|0;ka=Ha;while(1){if((pa|0)>1){ya=(ca(ia,ja)|0)+1|0;xa=1;qa=(c[N>>2]|0)+ya|0;while(1){a[qa]=(a[qa]|0)+(a[qa+va|0]|0);ya=xa+1|0;La=c[O>>2]|0;if((ya|0)<(La|0)){xa=ya;qa=qa+1|0}else{break}}Ma=La;Na=c[P>>2]|0}else{Ma=pa;Na=ka}qa=ia+1|0;if((qa|0)<(Na|0)){ia=qa;pa=Ma;ka=Na}else{break}}}else if((na|0)==3){if((Ha|0)<=1){break}ka=-ja|0;pa=~ja;ia=1;va=c[O>>2]|0;qa=Ha;while(1){if((va|0)>1){xa=(ca(ia,ja)|0)+1|0;ya=1;ra=(c[N>>2]|0)+xa|0;while(1){xa=(d[ra+ka|0]|0)+(d[ra-1|0]|0)-(d[ra+pa|0]|0)|0;if(xa>>>0>255>>>0){Oa=-xa>>31&255}else{Oa=xa&255}a[ra]=(a[ra]|0)+Oa;xa=ya+1|0;Pa=c[O>>2]|0;if((xa|0)<(Pa|0)){ya=xa;ra=ra+1|0}else{break}}Qa=Pa;Ra=c[P>>2]|0}else{Qa=va;Ra=qa}ra=ia+1|0;if((ra|0)<(Ra|0)){ia=ra;va=Qa;qa=Ra}else{break}}}else{break}}}while(0);la=Y;ma=aa+(fa>>>0>da>>>0?da:fa)|0}else if((Z|0)==1346585417|(Z|0)==1296649793|(Z|0)==1179471425|(Z|0)==542133592){c[F>>2]=Z;KIb(I,40,2612232,(z=i,i=i+8|0,c[z>>2]=E,z)|0);i=z;la=Y;ma=aa+(fa>>>0>da>>>0?da:fa)|0}else if((Z|0)==1480085590){if((fa|0)<1){Sa=0;Ta=aa}else{Sa=d[aa]|0;Ta=aa+1|0}qa=B-Ta|0;va=qa>>>0>3>>>0?3:qa;qa=Ta+va|0;if((B-qa|0)<3){Ua=1;Va=qa}else{Ua=((d[Ta+(va+1)|0]|0)<<8|(d[Ta+(va+2)|0]|0)<<16|(d[qa]|0))+1|0;Va=Ta+(va+3)|0}c[s>>2]=Ua;if((B-Va|0)<3){Wa=1;Xa=Va}else{Wa=((d[Va+1|0]|0)<<8|(d[Va+2|0]|0)<<16|(d[Va]|0))+1|0;Xa=Va+3|0}c[t>>2]=Wa;va=tIb(Ua,Wa,0,I)|0;if((va|0)<0){D=va;ea=119;break b}else{la=Sa;ma=Xa}}else{c[F>>2]=Z;KIb(I,40,2585608,(z=i,i=i+8|0,c[z>>2]=E,z)|0);i=z;la=Y;ma=aa+(fa>>>0>da>>>0?da:fa)|0}}while(0);if((A|0)==(ma|0)){break a}else{X=ma;Y=la}}if((ea|0)==25){KIb(I,16,2409576,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1163346256;i=h;return D|0}else if((ea|0)==29){KIb(0,0,2401840,(z=i,i=i+24|0,c[z>>2]=2395136,c[z+8>>2]=2387968,c[z+16>>2]=135,z)|0);i=z;Hd();return 0}else if((ea|0)==35){VHb(sa);D=ta;i=h;return D|0}else if((ea|0)==39){VHb(sa);D=-1094995529;i=h;return D|0}else if((ea|0)==93){KIb(I,16,2240600,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1094995529;i=h;return D|0}else if((ea|0)==105){KIb(0,0,2401840,(z=i,i=i+24|0,c[z>>2]=2395136,c[z+8>>2]=2387968,c[z+16>>2]=135,z)|0);i=z;Hd();return 0}else if((ea|0)==119){i=h;return D|0}}}while(0);if((c[f>>2]|0)==0){KIb(b,16,2564776,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1094995529;i=h;return D|0}else{D=c[y>>2]|0;i=h;return D|0}}}while(0);KIb(b,16,2353408,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;D=-1094995529;i=h;return D|0}function Cgb(a){a=a|0;var b=0;if((c[(c[a+60>>2]|0)+5464>>2]|0)==0){b=0;return b|0}b=jab(a)|0;return b|0}function Dgb(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;k=i;i=i+8|0;l=k|0;m=c[b+60>>2]|0;n=m;o=(j|0)!=0;if(!o){c[m+5504>>2]=1;c[b+140>>2]=27}j=h<<3;p=j>>>0>2147483639>>>0|(g|0)==0;q=p?0:g;g=p?0:j;j=p?-1094995529:0;r=m+5436|0;c[r>>2]=q;c[m+5448>>2]=g;s=g+8|0;t=m+5452|0;c[t>>2]=s;c[m+5440>>2]=q+(g>>3);g=m+5444|0;c[g>>2]=0;if(p){u=j;i=k;return u|0}do{if(o){p=c[m+5496>>2]|0;if((p|0)==0){u=-558323010;i=k;return u|0}v=c[m+5500>>2]|0;if((v|0)==0){u=-558323010}else{w=j;x=v;y=p;break}i=k;return u|0}else{p=q;v=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24)&255;p=s>>>0>8>>>0?8:s;c[g>>2]=p;if((v|0)!=47){KIb(b,16,2546712,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;u=-1094995529;i=k;return u|0}v=q+(p>>>3)|0;A=(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24)&16383;v=p+14|0;p=s>>>0>v>>>0?v:s;c[g>>2]=p;v=A+1|0;A=q+(p>>>3)|0;B=(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)>>>((p&7)>>>0)&16383;A=p+14|0;c[g>>2]=s>>>0>A>>>0?A:s;A=B+1|0;B=m+5496|0;p=c[B>>2]|0;if(!((p|0)==0|(p|0)==(v|0))){KIb(b,24,2529056,(z=i,i=i+16|0,c[z>>2]=p,c[z+8>>2]=v,z)|0);i=z}c[B>>2]=v;p=m+5500|0;C=c[p>>2]|0;if((C|0)==0|(C|0)==(A|0)){D=v}else{KIb(b,24,2513904,(z=i,i=i+16|0,c[z>>2]=v,c[z+8>>2]=v,z)|0);i=z;D=c[B>>2]|0}c[p>>2]=A;p=H4a(b,D,A)|0;if((p|0)<0){u=p;i=k;return u|0}B=c[g>>2]|0;C=c[r>>2]|0;E=(d[C+(B>>>3)|0]|0)>>>((B&7)>>>0);F=c[t>>2]|0;G=((B|0)<(F|0))+B|0;c[g>>2]=G;c[m+5468>>2]=E&1;E=C+(G>>>3)|0;C=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;E=G+3|0;c[g>>2]=F>>>0>E>>>0?E:F;if((C&7<<(G&7)|0)==0){w=p;x=A;y=v;break}KIb(b,16,2500224,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;u=-1094995529;i=k;return u|0}}while(0);b=m+5508|0;c[b>>2]=0;D=m+5528|0;c[D>>2]=0;s=m+5512|0;q=m+5496|0;j=m+5500|0;v=m+5624|0;A=m+5656|0;p=m+5688|0;G=m+5668|0;C=w;a:while(1){w=(C|0)<0;while(1){F=c[g>>2]|0;E=c[r>>2]|0;B=d[E+(F>>>3)|0]|0;H=c[t>>2]|0;I=((F|0)<(H|0))+F|0;c[g>>2]=I;if((B&1<<(F&7)|0)==0){J=34;break a}F=E+(I>>>3)|0;E=(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)>>>((I&7)>>>0)&3;F=I+2|0;c[g>>2]=H>>>0>F>>>0?F:H;H=c[b>>2]|0;c[b>>2]=H+1;c[s+(H<<2)>>2]=E;if((E|0)==0){J=20;break}else if((E|0)==3){J=24;break}else if((E|0)==1){J=22;break}if(w){K=C;break a}}if((J|0)==20){J=0;w=c[g>>2]|0;E=c[t>>2]|0;H=(c[r>>2]|0)+(w>>>3)|0;F=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((w&7)>>>0)&7;H=w+3|0;c[g>>2]=E>>>0>H>>>0?H:E;E=F+2|0;F=1<<E;H=-F|0;w=Egb(n,2,((c[q>>2]|0)-1+F&H)>>E,((c[j>>2]|0)-1+F&H)>>E)|0;if((w|0)<0){K=w;break}c[v>>2]=E;C=0;continue}else if((J|0)==22){J=0;E=c[g>>2]|0;w=c[t>>2]|0;H=(c[r>>2]|0)+(E>>>3)|0;F=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((E&7)>>>0)&7;H=E+3|0;c[g>>2]=w>>>0>H>>>0?H:w;w=F+2|0;F=1<<w;H=-F|0;E=Egb(n,3,((c[q>>2]|0)-1+F&H)>>w,((c[j>>2]|0)-1+F&H)>>w)|0;if((E|0)<0){K=E;break}c[A>>2]=w;C=0;continue}else if((J|0)==24){J=0;w=c[g>>2]|0;E=c[t>>2]|0;H=(c[r>>2]|0)+(w>>>3)|0;F=(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)>>>((w&7)>>>0)&255;H=w+8|0;c[g>>2]=E>>>0>H>>>0?H:E;E=F+1|0;do{if(E>>>0<3>>>0){L=3}else{if(E>>>0<5>>>0){L=2;break}L=E>>>0<17>>>0|0}}while(0);F=Egb(n,4,E,1)|0;if((F|0)<0){K=F;break}c[p>>2]=L;if((L|0)!=0){c[D>>2]=(1<<L)-1+(c[q>>2]|0)>>L}F=c[G>>2]|0;if((c[F+68>>2]<<2|0)<=4){C=0;continue}H=4;w=(c[F>>2]|0)+4|0;while(1){a[w]=(a[w]|0)+(a[w-4|0]|0);F=H+1|0;if((F|0)<(c[(c[G>>2]|0)+68>>2]<<2|0)){H=F;w=w+1|0}else{C=0;continue a}}}}b:do{if((J|0)==34){C=m+5540|0;c[C>>2]=e;if(o){c[m+5564>>2]=1}L=Egb(n,0,y,x)|0;if((L|0)<0){K=L;break}q=c[b>>2]|0;c:do{if((q|0)>0){D=m+5604|0;g=l|0;r=l+1|0;t=l+2|0;j=l+3|0;w=m+5636|0;H=L;E=q;d:while(1){F=E-1|0;I=c[s+(F<<2)>>2]|0;do{if((I|0)==0){B=c[C>>2]|0;if((c[B+72>>2]|0)>0){M=0;N=B}else{O=0;break}while(1){B=c[N+68>>2]|0;e:do{if((B|0)>0){P=(M|0)==0;Q=P?0:2;R=M-1|0;if(P){P=0;S=N;T=B;while(1){U=c[S>>2]|0;V=P<<2;W=U+V|0;X=V-4|0;Y=ca(c[S+32>>2]|0,R)|0;if((T-1|0)==(P|0)){Z=0}else{Z=V+4+Y|0}pe[c[1061736+(((P|0)==0?Q:1)<<2)>>2]&1023](g,U+X|0,U+(Y+X)|0,U+(Y+V)|0,U+Z|0);a[W]=(a[W]|0)+(a[g]|0);W=U+(V|1)|0;a[W]=(a[W]|0)+(a[r]|0);W=U+(V|2)|0;a[W]=(a[W]|0)+(a[t]|0);W=U+(V|3)|0;a[W]=(a[W]|0)+(a[j]|0);W=P+1|0;V=c[C>>2]|0;U=c[V+68>>2]|0;if((W|0)<(U|0)){P=W;S=V;T=U}else{_=V;break e}}}else{$=0;aa=N;ba=B}while(1){T=c[v>>2]|0;S=c[D>>2]|0;if(($|0)==0){da=Q}else{P=(ca(c[S+32>>2]|0,M>>T)|0)+($>>T<<2|2)|0;T=a[(c[S>>2]|0)+P|0]|0;ea=T&255;if((T&255)>>>0>13>>>0){J=48;break d}else{da=ea}}T=c[aa>>2]|0;P=c[aa+32>>2]|0;S=ca(P,M)|0;V=$<<2;U=S+V|0;W=T+U|0;Y=V-4|0;X=ca(P,R)|0;if((ba-1|0)==($|0)){fa=S}else{fa=V+4+X|0}pe[c[1061736+(da<<2)>>2]&1023](g,T+(S+Y)|0,T+(X+Y)|0,T+(X+V)|0,T+fa|0);a[W]=(a[W]|0)+(a[g]|0);W=T+(U+1)|0;a[W]=(a[W]|0)+(a[r]|0);W=T+(U+2)|0;a[W]=(a[W]|0)+(a[t]|0);W=T+(U+3)|0;a[W]=(a[W]|0)+(a[j]|0);W=$+1|0;U=c[C>>2]|0;T=c[U+68>>2]|0;if((W|0)<(T|0)){$=W;aa=U;ba=T}else{_=U;break}}}else{_=N}}while(0);B=M+1|0;if((B|0)<(c[_+72>>2]|0)){M=B;N=_}else{O=0;break}}}else if((I|0)==1){B=c[C>>2]|0;if((c[B+72>>2]|0)>0){ga=0;ha=B}else{O=0;break}while(1){if((c[ha+68>>2]|0)>0){B=0;R=ha;while(1){Q=c[A>>2]|0;U=c[w>>2]|0;T=c[U>>2]|0;W=(ca(c[U+32>>2]|0,ga>>Q)|0)+(B>>Q<<2)|0;Q=c[R>>2]|0;U=(ca(c[R+32>>2]|0,ga)|0)+(B<<2)|0;V=a[Q+(U+2)|0]|0;X=(ca(V,a[T+(W+3)|0]|0)|0)>>>5&255;Y=Q+(U+1)|0;S=X+(a[Y]|0)&255;a[Y]=S;Y=(ca(a[T+(W+2)|0]|0,V)|0)>>>5&255;V=(ca(S<<24>>24,a[T+(W+1)|0]|0)|0)>>>5&255;W=Q+(U+3)|0;a[W]=(Y+(a[W]|0)&255)+V;V=B+1|0;W=c[C>>2]|0;if((V|0)<(c[W+68>>2]|0)){B=V;R=W}else{ia=W;break}}}else{ia=ha}R=ga+1|0;if((R|0)<(c[ia+72>>2]|0)){ga=R;ha=ia}else{O=0;break}}}else if((I|0)==2){R=c[C>>2]|0;if((c[R+72>>2]|0)>0){ja=0;ka=R}else{O=0;break}while(1){if((c[ka+68>>2]|0)>0){R=0;B=ka;while(1){W=c[B>>2]|0;V=(ca(c[B+32>>2]|0,ja)|0)+(R<<2)|0;Y=a[W+(V+2)|0]|0;U=W+(V+1)|0;a[U]=(a[U]|0)+Y;U=W+(V+3)|0;a[U]=(a[U]|0)+Y;Y=R+1|0;U=c[C>>2]|0;if((Y|0)<(c[U+68>>2]|0)){R=Y;B=U}else{la=U;break}}}else{la=ka}B=ja+1|0;if((B|0)<(c[la+72>>2]|0)){ja=B;ka=la}else{O=0;break}}}else if((I|0)==3){B=c[p>>2]|0;if((B|0)>0){R=8>>>(B>>>0);B=hJb(c[(c[C>>2]|0)+32>>2]|0)|0;if((B|0)==0){K=-12;break b}U=c[C>>2]|0;if((c[U+72>>2]|0)>0){Y=32-R|0;V=0;W=U;while(1){U=W+32|0;Q=c[U>>2]|0;nrc(B|0,(c[W>>2]|0)+(ca(Q,V)|0)|0,Q)|0;Q=c[U>>2]|0;U=Q<<3;T=U>>>0>2147483639>>>0;S=T?0:B;X=T?8:U+8|0;f:do{if((c[W+68>>2]|0)>0){U=X>>>0>16>>>0?16:X;T=0;P=0;ma=W;na=Q;while(1){oa=ca(na,V)|0;pa=S+(U>>>3)|0;qa=U+R|0;ra=X>>>0>qa>>>0?qa:X;a[(c[ma>>2]|0)+((T<<2|2)+oa)|0]=(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)>>>((U&7)>>>0)<<Y>>>(Y>>>0);pa=P+1|0;if((pa|0)==(1<<c[p>>2]|0)){oa=ra+24|0;sa=0;ta=X>>>0>oa>>>0?oa:X}else{sa=pa;ta=ra}ra=T+1|0;pa=c[C>>2]|0;if((ra|0)>=(c[pa+68>>2]|0)){ua=pa;break f}U=ta;T=ra;P=sa;ma=pa;na=c[pa+32>>2]|0}}else{ua=W}}while(0);X=V+1|0;if((X|0)<(c[ua+72>>2]|0)){V=X;W=ua}else{break}}}kJb(B)}W=c[C>>2]|0;if((c[W+72>>2]|0)>0){va=0;wa=W}else{O=0;break}while(1){if((c[wa+68>>2]|0)>0){W=0;V=wa;while(1){Y=c[V>>2]|0;R=(ca(c[V+32>>2]|0,va)|0)+(W<<2)|0;xa=d[Y+(R+2)|0]|0;X=c[G>>2]|0;if((xa|0)>=(c[X+68>>2]|0)){J=76;break d}c[Y+R>>2]=c[(c[X>>2]|0)+(xa<<2)>>2];X=W+1|0;R=c[C>>2]|0;if((X|0)<(c[R+68>>2]|0)){W=X;V=R}else{ya=R;break}}}else{ya=wa}V=va+1|0;if((V|0)<(c[ya+72>>2]|0)){va=V;wa=ya}else{O=0;break}}}else{if((H|0)<0){K=H;break b}else{O=H}}}while(0);if((F|0)>0){H=O;E=F}else{break c}}if((J|0)==48){KIb(c[m+5460>>2]|0,16,2476344,(z=i,i=i+8|0,c[z>>2]=ea,z)|0);i=z;K=-1094995529;break b}else if((J|0)==76){KIb(c[m+5460>>2]|0,16,2487552,(z=i,i=i+8|0,c[z>>2]=xa,z)|0);i=z;K=-1094995529;break b}}}while(0);c[f>>2]=1;c[e+88>>2]=1;c[e+84>>2]=1;K=h}}while(0);h=m+5536|0;m=0;while(1){e=h+(m<<5)|0;kJb(c[h+(m<<5)+12>>2]|0);do{if((c[e>>2]|0)!=0){if((c[h+(m<<5)+28>>2]|0)!=0){break}VHb(h+(m<<5)+4|0)}}while(0);f=h+(m<<5)+20|0;z=c[f>>2]|0;if((z|0)!=0){xa=h+(m<<5)+16|0;if((c[xa>>2]|0)>0){J=0;ea=z;while(1){O=J*5|0;c3(ea+(O<<5)|0);c3((c[f>>2]|0)+(O+1<<5)|0);c3((c[f>>2]|0)+(O+2<<5)|0);c3((c[f>>2]|0)+(O+3<<5)|0);c3((c[f>>2]|0)+(O+4<<5)|0);O=J+1|0;ya=c[f>>2]|0;if((O|0)<(c[xa>>2]|0)){J=O;ea=ya}else{za=ya;break}}}else{za=z}kJb(za)}mrc(e|0,0,32)|0;ea=m+1|0;if((ea|0)<5){m=ea}else{u=K;break}}i=k;return u|0}function Egb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;k=i;i=i+128|0;l=k|0;m=k+32|0;n=k+112|0;c[f+5536+(g<<5)>>2]=g;o=f+5536+(g<<5)+4|0;p=c[o>>2]|0;do{if((p|0)==0){q=UHb()|0;c[o>>2]=q;if((q|0)==0){r=-12}else{s=q;break}i=k;return r|0}else{s=p}}while(0);c[s+80>>2]=27;c[s+68>>2]=h;c[s+72>>2]=j;j=(g|0)==0;do{if(j){if((c[f+5564>>2]|0)!=0){t=6;break}c[n>>2]=s;c[n+4>>2]=0;c[n+8>>2]=0;u=J5a(c[f+5460>>2]|0,n,0)|0}else{t=6}}while(0);if((t|0)==6){u=XHb(s,1)|0}if((u|0)<0){r=u;i=k;return r|0}u=f+5436|0;s=f+5444|0;n=c[s>>2]|0;h=u|0;p=c[h>>2]|0;q=d[p+(n>>>3)|0]|0;v=f+5452|0;w=c[v>>2]|0;x=((n|0)<(w|0))+n|0;c[s>>2]=x;do{if((q&1<<(n&7)|0)==0){c[f+5536+(g<<5)+8>>2]=0}else{z=p+(x>>>3)|0;A=(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)>>>((x&7)>>>0)&15;z=x+4|0;c[s>>2]=w>>>0>z>>>0?z:w;c[f+5536+(g<<5)+8>>2]=A;if((A|0)==0|A>>>0>11>>>0){KIb(c[f+5460>>2]|0,16,2467144,(B=i,i=i+8|0,c[B>>2]=A,B)|0);i=B;r=-1094995529;i=k;return r|0}z=1<<A;if(z>>>0<536870911>>>0){A=pJb(z<<2)|0;c[f+5536+(g<<5)+12>>2]=A;if((A|0)==0){r=-12}else{break}i=k;return r|0}else{c[f+5536+(g<<5)+12>>2]=0;r=-12;i=k;return r|0}}}while(0);w=f+5536+(g<<5)+16|0;c[w>>2]=1;a:do{if(j){x=c[s>>2]|0;p=c[h>>2]|0;n=d[p+(x>>>3)|0]|0;q=c[v>>2]|0;A=((x|0)<(q|0))+x|0;c[s>>2]=A;if((n&1<<(x&7)|0)==0){C=1;break}x=c[f+5528>>2]|0;n=(x|0)>0?x:c[f+5496>>2]|0;x=p+(A>>>3)|0;p=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>((A&7)>>>0)&7;x=A+3|0;c[s>>2]=q>>>0>x>>>0?x:q;q=p+2|0;p=1<<q;x=-p|0;A=Egb(f,1,(n-1+p&x)>>q,((c[f+5500>>2]|0)-1+p&x)>>q)|0;if((A|0)<0){r=A;i=k;return r|0}c[f+5592>>2]=q;q=c[f+5572>>2]|0;A=c[q+72>>2]|0;do{if((A|0)>0){x=c[q+68>>2]|0;if((x|0)>0){D=0;E=0}else{break}while(1){p=c[q>>2]|0;n=c[q+32>>2]|0;z=0;F=E;do{G=d[p+((z<<2|2)+(ca(n,D)|0))|0]|0;F=(F|0)>(G|0)?F:G;z=z+1|0;}while((z|0)<(x|0));z=D+1|0;if((z|0)<(A|0)){D=z;E=F}else{break}}x=F+1|0;c[f+5532>>2]=x;c[w>>2]=x;if((x*5|0)>>>0<67108863>>>0){C=x;break a}c[f+5536+(g<<5)+20>>2]=0;r=-12;i=k;return r|0}}while(0);c[f+5532>>2]=1;c[w>>2]=1;C=1}else{C=1}}while(0);F=pJb(C*160|0)|0;C=F;E=f+5536+(g<<5)+20|0;c[E>>2]=C;if((F|0)==0){r=-12;i=k;return r|0}b:do{if((c[w>>2]|0)>0){F=f+5536+(g<<5)+8|0;D=l;A=m;q=m|0;x=l|0;z=f+5460|0;n=0;p=C;c:while(1){G=n*5|0;H=0;do{I=e[2020928+(H<<1)>>1]|0;do{if((H|0)==0){J=c[F>>2]|0;if((J|0)<=0){K=I;break}K=(1<<J)+I|0}else{K=I}}while(0);I=c[s>>2]|0;J=c[h>>2]|0;L=d[J+(I>>>3)|0]|0;M=c[v>>2]|0;N=((I|0)<(M|0))+I|0;c[s>>2]=N;O=H+G|0;P=p+(O<<5)|0;if((L&1<<(I&7)|0)==0){mrc(D|0,0,32)|0;mrc(A|0,0,76)|0;I=J+(N>>>3)|0;L=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((N&7)>>>0)&15;I=N+4|0;Q=M>>>0>I>>>0?I:M;c[s>>2]=Q;I=L+4|0;if(I>>>0>19>>>0){r=-1094995529;t=101;break c}else{R=0;S=Q}do{Q=J+(S>>>3)|0;L=(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)>>>((S&7)>>>0)&7;Q=S+3|0;S=M>>>0>Q>>>0?Q:M;c[s>>2]=S;c[m+(d[1703440+R|0]<<2)>>2]=L;R=R+1|0;}while((R|0)<(I|0));I=Ugb(l,q,19)|0;d:do{if((I|0)<0){T=0;U=I}else{if(!(K>>>0<536870911>>>0)){T=0;U=-12;break}L=pJb(K<<2)|0;Q=L;if((L|0)==0){T=Q;U=-12;break}L=c[s>>2]|0;V=c[h>>2]|0;W=d[V+(L>>>3)|0]|0;X=c[v>>2]|0;Y=((L|0)<(X|0))+L|0;c[s>>2]=Y;do{if((W&1<<(L&7)|0)==0){Z=K}else{_=V+(Y>>>3)|0;$=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((Y&7)>>>0);_=Y+3|0;aa=X>>>0>_>>>0?_:X;c[s>>2]=aa;_=$<<1&14;$=V+(aa>>>3)|0;ba=30-_|0;da=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((aa&7)>>>0)<<ba>>>(ba>>>0);ba=aa+2+_|0;c[s>>2]=X>>>0>ba>>>0?ba:X;ba=da+2|0;if((ba|0)<=(K|0)){Z=ba;break}KIb(c[z>>2]|0,16,2429024,(B=i,i=i+16|0,c[B>>2]=ba,c[B+8>>2]=K,B)|0);i=B;T=Q;U=-1094995529;break d}}while(0);e:do{if((K|0)>0){X=0;V=Z;Y=8;f:while(1){ea=X;L=V;while(1){fa=L-1|0;if((L|0)==0){break e}ga=Tgb(l,u)|0;if((ga|0)<16){break}if((ga|0)==17){W=c[s>>2]|0;ba=c[v>>2]|0;da=(c[h>>2]|0)+(W>>>3)|0;_=(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((W&7)>>>0)&7;da=W+3|0;c[s>>2]=ba>>>0>da>>>0?da:ba;ha=0;ia=_+3|0}else if((ga|0)==16){_=c[s>>2]|0;ba=c[v>>2]|0;da=(c[h>>2]|0)+(_>>>3)|0;W=(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((_&7)>>>0)&3;da=_+2|0;c[s>>2]=ba>>>0>da>>>0?da:ba;ha=Y;ia=W+3|0}else if((ga|0)==18){W=c[s>>2]|0;ba=c[v>>2]|0;da=(c[h>>2]|0)+(W>>>3)|0;_=(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)>>>((W&7)>>>0)&127;da=W+7|0;c[s>>2]=ba>>>0>da>>>0?da:ba;ha=0;ia=_+11|0}else{ha=0;ia=0}_=ia+ea|0;if((_|0)>(K|0)){break f}if((ia|0)>0){ba=ea;da=ia;while(1){W=da-1|0;c[Q+(ba<<2)>>2]=ha;if((W|0)>0){ba=ba+1|0;da=W}else{ja=_;break}}}else{ja=ea}if((ja|0)<(K|0)){ea=ja;L=fa}else{break e}}L=ea+1|0;c[Q+(ea<<2)>>2]=ga;if((L|0)<(K|0)){X=L;V=fa;Y=(ga|0)==0?Y:ga}else{break e}}KIb(c[z>>2]|0,16,2418488,(B=i,i=i+24|0,c[B>>2]=ea,c[B+8>>2]=ia,c[B+16>>2]=K,B)|0);i=B;T=Q;U=-1094995529;break d}}while(0);T=Q;U=Ugb(P,Q,K)|0}}while(0);c3(x);kJb(T);if((U|0)<0){r=U;t=101;break c}}else{P=(d[J+(N>>>3)|0]|0)>>>((N&7)>>>0);c[s>>2]=((N|0)<(M|0))+N;I=p+(O<<5)+24|0;c[I>>2]=(P&1)+1;P=c[s>>2]|0;Y=d[J+(P>>>3)|0]|0;V=c[v>>2]|0;X=((P|0)<(V|0))+P|0;c[s>>2]=X;L=J+(X>>>3)|0;if((Y&1<<(P&7)|0)==0){P=(d[L]|0)>>>((X&7)>>>0);Y=((X|0)<(V|0))+X|0;c[s>>2]=Y;b[p+(O<<5)+28>>1]=P&1;ka=Y}else{Y=L;L=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((X&7)>>>0);Y=X+8|0;X=V>>>0>Y>>>0?Y:V;c[s>>2]=X;b[p+(O<<5)+28>>1]=L&255;ka=X}if((c[I>>2]|0)==2){I=J+(ka>>>3)|0;X=(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)>>>((ka&7)>>>0);I=ka+8|0;c[s>>2]=V>>>0>I>>>0?I:V;b[p+(O<<5)+30>>1]=X&255}c[p+(O<<5)+20>>2]=1}H=H+1|0;}while((H|0)<5);H=n+1|0;if((H|0)>=(c[w>>2]|0)){break b}n=H;p=c[E>>2]|0}if((t|0)==101){i=k;return r|0}}}while(0);w=c[o>>2]|0;ka=c[w+68>>2]|0;if(j){j=c[f+5528>>2]|0;la=(j|0)>0?j:ka}else{la=ka}if((c[w+72>>2]|0)<=0){r=0;i=k;return r|0}w=f+5592|0;ka=f+5572|0;j=f+5536+(g<<5)+8|0;U=f+5536+(g<<5)+12|0;g=0;T=0;g:while(1){K=c[w>>2]|0;if((K|0)>0){ia=c[ka>>2]|0;ma=(d[(c[ia>>2]|0)+((ca(c[ia+32>>2]|0,g>>K)|0)+(T>>K<<2|2))|0]|0)*5|0}else{ma=0}K=c[E>>2]|0;ia=Tgb(K+(ma<<5)|0,u)|0;h:do{if((ia|0)<256){ea=c[o>>2]|0;ga=c[ea>>2]|0;fa=(ca(c[ea+32>>2]|0,g)|0)+(T<<2)|0;ea=ga+fa|0;a[ga+(fa+2)|0]=ia;a[ga+(fa+1)|0]=Tgb(K+(ma+1<<5)|0,u)|0;a[ga+(fa+3)|0]=Tgb(K+(ma+2<<5)|0,u)|0;a[ea]=Tgb(K+(ma+3<<5)|0,u)|0;fa=c[j>>2]|0;if((fa|0)!=0){ga=ea;ea=je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0;c[(c[U>>2]|0)+((ca(ea,506832829)|0)>>>((32-fa|0)>>>0)<<2)>>2]=ea}ea=T+1|0;fa=(ea|0)==(la|0);na=fa?0:ea;oa=(fa&1)+g|0}else{if((ia|0)>=280){fa=c[o>>2]|0;ea=(c[fa>>2]|0)+((ca(c[fa+32>>2]|0,g)|0)+(T<<2))|0;fa=ia-280|0;ga=c[j>>2]|0;if((ga|0)==0){t=97;break g}if((fa|0)>=(1<<ga|0)){t=99;break g}ga=ea;y=je(c[(c[U>>2]|0)+(fa<<2)>>2]|0)|0;a[ga]=y;y=y>>8;a[ga+1|0]=y;y=y>>8;a[ga+2|0]=y;y=y>>8;a[ga+3|0]=y;ga=T+1|0;fa=(ga|0)==(la|0);na=fa?0:ga;oa=(fa&1)+g|0;break}fa=ia-256|0;if((fa|0)<4){pa=fa}else{ga=ia-258>>1;ea=c[s>>2]|0;ja=c[v>>2]|0;ha=(c[h>>2]|0)+(ea>>>3)|0;l=32-ga|0;Z=(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)>>>((ea&7)>>>0)<<l>>>(l>>>0);l=ea+ga|0;c[s>>2]=ja>>>0>l>>>0?l:ja;pa=Z+((fa&1|2)<<ga)|0}ga=pa+1|0;fa=Tgb(K+(ma+4<<5)|0,u)|0;if((fa|0)<4){qa=fa}else{Z=fa-2>>1;ja=c[s>>2]|0;l=c[v>>2]|0;ea=(c[h>>2]|0)+(ja>>>3)|0;ha=32-Z|0;R=(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)>>>((ja&7)>>>0)<<ha>>>(ha>>>0);ha=ja+Z|0;c[s>>2]=l>>>0>ha>>>0?ha:l;qa=R+((fa&1|2)<<Z)|0}if((qa+1|0)<121){Z=(ca(a[840665+(qa<<1)|0]|0,la)|0)+(a[840664+(qa<<1)|0]|0)|0;ra=(Z|0)<1?1:Z}else{ra=qa-119|0}Z=(ra|0)>(T|0);fa=Z?ra-T|0:0;R=Z?0:T-ra|0;if((fa|0)<(la|0)){sa=fa;ta=g}else{Z=fa;fa=g;while(1){l=fa-1|0;ha=Z-la|0;if((ha|0)<(la|0)){sa=ha;ta=l;break}else{Z=ha;fa=l}}}if((sa|0)>0){ua=ta-1|0;va=la-sa|0}else{ua=ta;va=R}if((ga|0)<=0){na=T;oa=g;break}fa=(va|0)<0?0:va;Z=(ua|0)<0?0:ua;l=g;ha=T;ja=0;ea=c[o>>2]|0;while(1){m=c[ea>>2]|0;S=c[ea+32>>2]|0;C=m+((ca(S,l)|0)+(ha<<2))|0;p=c[m+((ca(S,Z)|0)+(fa<<2))>>2]|0;c[C>>2]=p;C=c[j>>2]|0;if((C|0)!=0){S=je(p|0)|0;c[(c[U>>2]|0)+((ca(S,506832829)|0)>>>((32-C|0)>>>0)<<2)>>2]=S}S=ha+1|0;C=fa+1|0;p=(S|0)==(la|0);m=(p&1)+l|0;n=p?0:S;S=(C|0)==(la|0);p=(S&1)+Z|0;x=c[o>>2]|0;z=c[x+72>>2]|0;if((m|0)==(z|0)|(p|0)==(z|0)){na=n;oa=m;break h}z=ja+1|0;if((z|0)<(ga|0)){fa=S?0:C;Z=p;l=m;ha=n;ja=z;ea=x}else{na=n;oa=m;break}}}}while(0);if((oa|0)<(c[(c[o>>2]|0)+72>>2]|0)){g=oa;T=na}else{r=0;t=101;break}}if((t|0)==97){KIb(c[f+5460>>2]|0,16,2457304,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;r=-1094995529;i=k;return r|0}else if((t|0)==99){KIb(c[f+5460>>2]|0,16,2440224,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;r=-1094995529;i=k;return r|0}else if((t|0)==101){i=k;return r|0}return 0}function Fgb(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;f=b;y=255;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;return}function Ggb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a>>2]=c[b>>2];return}function Hgb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a>>2]=c[e>>2];return}function Igb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a>>2]=c[f>>2];return}function Jgb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a>>2]=c[d>>2];return}function Kgb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((((d[g]|0)+(d[c]|0)|0)>>>1)+(d[f]|0)|0)>>>1;a[b+1|0]=((((d[g+1|0]|0)+(d[c+1|0]|0)|0)>>>1)+(d[f+1|0]|0)|0)>>>1;a[b+2|0]=((((d[g+2|0]|0)+(d[c+2|0]|0)|0)>>>1)+(d[f+2|0]|0)|0)>>>1;a[b+3|0]=((((d[g+3|0]|0)+(d[c+3|0]|0)|0)>>>1)+(d[f+3|0]|0)|0)>>>1;return}function Lgb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((d[e]|0)+(d[c]|0)|0)>>>1;a[b+1|0]=((d[e+1|0]|0)+(d[c+1|0]|0)|0)>>>1;a[b+2|0]=((d[e+2|0]|0)+(d[c+2|0]|0)|0)>>>1;a[b+3|0]=((d[e+3|0]|0)+(d[c+3|0]|0)|0)>>>1;return}function Mgb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((d[f]|0)+(d[c]|0)|0)>>>1;a[b+1|0]=((d[f+1|0]|0)+(d[c+1|0]|0)|0)>>>1;a[b+2|0]=((d[f+2|0]|0)+(d[c+2|0]|0)|0)>>>1;a[b+3|0]=((d[f+3|0]|0)+(d[c+3|0]|0)|0)>>>1;return}function Ngb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((d[f]|0)+(d[e]|0)|0)>>>1;a[b+1|0]=((d[f+1|0]|0)+(d[e+1|0]|0)|0)>>>1;a[b+2|0]=((d[f+2|0]|0)+(d[e+2|0]|0)|0)>>>1;a[b+3|0]=((d[f+3|0]|0)+(d[e+3|0]|0)|0)>>>1;return}function Ogb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((d[g]|0)+(d[f]|0)|0)>>>1;a[b+1|0]=((d[g+1|0]|0)+(d[f+1|0]|0)|0)>>>1;a[b+2|0]=((d[g+2|0]|0)+(d[f+2|0]|0)|0)>>>1;a[b+3|0]=((d[g+3|0]|0)+(d[f+3|0]|0)|0)>>>1;return}function Pgb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;a[b]=((((d[g]|0)+(d[f]|0)|0)>>>1)+(((d[e]|0)+(d[c]|0)|0)>>>1)|0)>>>1;a[b+1|0]=((((d[g+1|0]|0)+(d[f+1|0]|0)|0)>>>1)+(((d[e+1|0]|0)+(d[c+1|0]|0)|0)>>>1)|0)>>>1;a[b+2|0]=((((d[g+2|0]|0)+(d[f+2|0]|0)|0)>>>1)+(((d[e+2|0]|0)+(d[c+2|0]|0)|0)>>>1)|0)>>>1;a[b+3|0]=((((d[g+3|0]|0)+(d[f+3|0]|0)|0)>>>1)+(((d[e+3|0]|0)+(d[c+3|0]|0)|0)>>>1)|0)>>>1;return}function Qgb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=d[e]|0;h=(d[b]|0)-g|0;i=(d[f]|0)-g|0;g=d[e+1|0]|0;j=(d[b+1|0]|0)-g|0;k=(d[f+1|0]|0)-g|0;g=d[e+2|0]|0;l=(d[b+2|0]|0)-g|0;m=(d[f+2|0]|0)-g|0;g=d[e+3|0]|0;e=(d[b+3|0]|0)-g|0;n=(d[f+3|0]|0)-g|0;if((((h|0)>-1?h:-h|0)-((i|0)>-1?i:-i|0)+((j|0)>-1?j:-j|0)-((k|0)>-1?k:-k|0)+((l|0)>-1?l:-l|0)-((m|0)>-1?m:-m|0)+((e|0)>-1?e:-e|0)-((n|0)>-1?n:-n|0)|0)<1){c[a>>2]=c[f>>2];return}else{c[a>>2]=c[b>>2];return}}function Rgb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;g=(d[f]|0)+(d[c]|0)-(d[e]|0)|0;if(g>>>0>255>>>0){h=-g>>31&255}else{h=g&255}a[b]=h;h=(d[f+1|0]|0)+(d[c+1|0]|0)-(d[e+1|0]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[b+1|0]=i;i=(d[f+2|0]|0)+(d[c+2|0]|0)-(d[e+2|0]|0)|0;if(i>>>0>255>>>0){j=-i>>31&255}else{j=i&255}a[b+2|0]=j;j=(d[f+3|0]|0)+(d[c+3|0]|0)-(d[e+3|0]|0)|0;if(!(j>>>0>255>>>0)){k=j&255;l=b+3|0;a[l]=k;return}k=-j>>31&255;l=b+3|0;a[l]=k;return}function Sgb(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;g=((d[f]|0)+(d[c]|0)|0)>>>1;h=g+((g-(d[e]|0)|0)/2|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[b]=i;i=((d[f+1|0]|0)+(d[c+1|0]|0)|0)>>>1;h=i+((i-(d[e+1|0]|0)|0)/2|0)|0;if(h>>>0>255>>>0){j=-h>>31&255}else{j=h&255}a[b+1|0]=j;j=((d[f+2|0]|0)+(d[c+2|0]|0)|0)>>>1;h=j+((j-(d[e+2|0]|0)|0)/2|0)|0;if(h>>>0>255>>>0){k=-h>>31&255}else{k=h&255}a[b+2|0]=k;k=((d[f+3|0]|0)+(d[c+3|0]|0)|0)>>>1;c=k+((k-(d[e+3|0]|0)|0)/2|0)|0;if(!(c>>>0>255>>>0)){l=c&255;m=b+3|0;a[m]=l;return}l=-c>>31&255;m=b+3|0;a[m]=l;return}function Tgb(a,f){a=a|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[a+20>>2]|0)==0){g=c[a+4>>2]|0;h=f+8|0;i=c[h>>2]|0;j=c[f+16>>2]|0;k=c[f>>2]|0;l=k+(i>>>3)|0;m=d[1316536+((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)>>>((i&7)>>>0)&255)|0]|0;l=b[g+(m<<2)>>1]|0;n=b[g+(m<<2)+2>>1]|0;m=n<<16>>16;if(n<<16>>16<0){n=i+8|0;o=j>>>0>n>>>0?n:j;n=k+(o>>>3)|0;k=m+32|0;p=((d[1316536+((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((o&7)>>>0)<<k>>>(k>>>0))|0]|0)>>>((m+8|0)>>>0))+l|0;q=b[g+(p<<2)+2>>1]|0;r=o;s=b[g+(p<<2)>>1]|0}else{q=m;r=i;s=l}l=q+r|0;c[h>>2]=j>>>0>l>>>0?l:j;t=s;return t|0}if((c[a+24>>2]|0)==1){t=e[a+28>>1]|0;return t|0}else{s=f+8|0;j=c[s>>2]|0;l=(d[(c[f>>2]|0)+(j>>>3)|0]|0)>>>((j&7)>>>0);c[s>>2]=((j|0)<(c[f+16>>2]|0))+j;t=e[a+28+((l&1)<<1)>>1]|0;return t|0}return 0}function Ugb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=(e|0)>0;if(f){g=0;h=0;i=0}else{j=-22;return j|0}while(1){if((c[d+(g<<2)>>2]|0)>0){k=i+1|0;l=g&65535;if((i|0)>0){m=k;n=l;break}else{o=k;p=l}}else{o=i;p=h}l=g+1|0;if((l|0)<(e|0)){g=l;h=p;i=o}else{m=o;n=p;break}}if((m|0)==1){c[a+24>>2]=1;b[a+28>>1]=n;c[a+20>>2]=1;j=0;return j|0}if(f){q=0;r=0}else{j=-22;return j|0}do{n=c[d+(q<<2)>>2]|0;r=(r|0)>(n|0)?r:n;q=q+1|0;}while((q|0)<(e|0));if((r|0)==0|(r|0)>15){j=-22;return j|0}q=hJb(e<<1)|0;n=q;if((q|0)==0){j=-12;return j|0}m=a+24|0;c[m>>2]=0;do{if(!((r|0)<1|f^1)){p=0;o=1;i=0;while(1){h=0;g=p;l=i;while(1){if((c[d+(h<<2)>>2]|0)==(o|0)){b[n+(h<<1)>>1]=g;k=l+1|0;c[m>>2]=k;s=g+1|0;t=k}else{s=g;t=l}k=h+1|0;if((k|0)<(e|0)){h=k;g=s;l=t}else{break}}l=o+1|0;if((l|0)>(r|0)){break}else{p=s<<1;o=l;i=t}}if((t|0)==0){break}i=$2(a|0,8,e,d,4,4,q,2,2,0,0,0,0)|0;if((i|0)<0){kJb(q);j=i;return j|0}else{c[a+20>>2]=0;kJb(q);j=0;return j|0}}}while(0);kJb(q);j=-1094995529;return j|0}function Vgb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;i=i+1040|0;h=g|0;j=g+1024|0;k=g+1032|0;l=d;m=c[f+24>>2]|0;SFb(h,0,-1);n=f+28|0;if((m|0)==0){o=d+12|0;p=o;q=c[p>>2]|0;r=(q|0)!=0;s=r&1;c[e>>2]=s;t=_Fb(h,0)|0;u=c[n>>2]|0;i=g;return u|0}if((c[n>>2]|0)<=0){o=d+12|0;p=o;q=c[p>>2]|0;r=(q|0)!=0;s=r&1;c[e>>2]=s;t=_Fb(h,0)|0;u=c[n>>2]|0;i=g;return u|0}v=a[m]|0;a:do{if(!(v<<24>>24==0)){w=0;x=m;y=v;while(1){z=0;while(1){if(!(z>>>0<8>>>0)){A=x;B=y;break}C=c[156256+(z<<3)>>2]|0;D=lrc(C|0)|0;if((krc(x,C,D)|0)==0){E=7;break}else{z=z+1|0}}if((E|0)==7){E=0;UFb(h,2441336,(F=i,i=i+8|0,c[F>>2]=c[156260+(z<<3)>>2],F)|0);i=F;C=x+D|0;A=C;B=a[C]|0}do{if((B<<24>>24|0)==0){break a}else if((B<<24>>24|0)==10){if((a[A+1|0]|0)==0){E=12;break}UFb(h,2353392,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;G=w}else if((B<<24>>24|0)==62){G=0}else if((B<<24>>24|0)==60){G=1}else{E=12}}while(0);do{if((E|0)==12){E=0;if((w|0)!=0){G=w;break}if(B<<24>>24==13){G=0;break}WFb(h,B,1);G=0}}while(0);z=A+1|0;C=a[z]|0;if(C<<24>>24==0){break}else{w=G;x=z;y=C}}}}while(0);UFb(h,2291280,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;F=f+8|0;G=c[F>>2]|0;A=c[F+4>>2]|0;F=b+104|0;c[j>>2]=1;c[j+4>>2]=100;b=XIb(G,A,F,j)|0;j=c[f+48>>2]|0;if((j|0)==-1){H=-1}else{c[k>>2]=1;c[k+4>>2]=100;f=XIb(j,(j|0)<0|0?-1:0,F,k)|0;H=f}fmb(l,c[h>>2]|0,b,H,0)|0;o=d+12|0;p=o;q=c[p>>2]|0;r=(q|0)!=0;s=r&1;c[e>>2]=s;t=_Fb(h,0)|0;u=c[n>>2]|0;i=g;return u|0}function Wgb(f,h){f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0.0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;j=i;k=c[f+60>>2]|0;l=f+412|0;if(((c[l>>2]|0)-1|0)>>>0>49999>>>0){m=-1;i=j;return m|0}n=f+416|0;if(((c[n>>2]|0)-1|0)>>>0>1>>>0){m=-1;i=j;return m|0}o=f+72|0;if((c[o>>2]|0)<1){m=-1;i=j;return m|0}yfa(k+159264|0,f);qHb(k+159284|0,c[f+88>>2]&8388608);p=k+48|0;q=(c[(c[f+12>>2]|0)+12>>2]|0)==86023?1:2;c[p>>2]=q;r=ahb(c[l>>2]|0,q,0)|0;q=k+1100|0;c[q>>2]=r;c[k+1116>>2]=r;c[k+1120>>2]=r;c[k+1112>>2]=r;s=k+1096|0;c[s>>2]=1<<r;if((c[k+56>>2]|0)==0){c[k+1104>>2]=1}else{t=(((c[o>>2]|0)/(c[n>>2]|0)|0|0)>31999?3:1)+(h>>>3&3)|0;h=r-7|0;c[k+1104>>2]=((t|0)>(h|0)?h:t)+1}t=k+64|0;c[t>>2]=1;h=c[l>>2]|0;u=+(h|0)*.5;do{if((c[p>>2]|0)==2){if((h|0)>44099){v=44100;break}if((h|0)>22049){v=22050;break}if((h|0)>15999){v=16e3;break}if((h|0)>11024){v=11025;break}v=(h|0)<8e3?h:8e3}else{v=h}}while(0);w=+(c[o>>2]|0)/+(ca(h,c[n>>2]|0)|0);h=~~(w*+(c[s>>2]|0)*.125+.5);o=h>>>0>65535>>>0;r=o?h>>>16:h;h=o?16:0;if((r&65280|0)==0){x=h;y=r}else{x=h|8;y=r>>>8}r=(d[1359664+y|0]|0)+x|0;x=r+2|0;c[k+68>>2]=x;if((r+5|0)>25){KIb(f,16,2445768,(f=i,i=i+8|0,c[f>>2]=x,f)|0);i=f;m=-1163346256;i=j;return m|0}if((c[n>>2]|0)==2){z=w*1.6}else{z=w}do{if((v|0)==16e3){if(w>.5){A=u*.5;break}else{A=u*.3;break}}else if((v|0)==22050){B=z;if(!(B<1.16)){c[t>>2]=0;A=u;break}C=u;if(B<.72){A=C*.6;break}else{A=C*.7;break}}else if((v|0)==11025){A=u*.7}else if((v|0)==44100){if(z<.61){A=u*.4;break}else{c[t>>2]=0;A=u;break}}else{C=w;if((v|0)==8e3){if(!(C>.625)){A=u*.5;break}if(w>.75){c[t>>2]=0;A=u;break}else{A=u*.65;break}}else{if(!(C<.8)){A=u*.75;break}if(w<.6){A=u*.5;break}else{A=u*.6;break}}}}while(0);v=c[p>>2]|0;c[k+384>>2]=(v|0)==1?3:0;n=k+1104|0;do{if((c[n>>2]|0)>0){f=k+388|0;x=k+364|0;r=k+92|0;y=r;h=k+408|0;o=k+112|0;D=o;E=k+428|0;F=o;o=r;r=0;G=v;while(1){H=c[s>>2]>>r;a:do{if((G|0)==1){I=H<<1;J=0;K=0;while(1){if((J|0)>=25){L=J;break}M=c[l>>2]|0;N=((ca(I,e[1248584+(J<<1)>>1]|0)|0)+(M>>1)|0)/(M|0)|0;M=(N|0)>(H|0)?H:N;b[F+(J<<1)>>1]=M-K;N=J+1|0;if((M|0)<(H|0)){J=N;K=M}else{L=N;break}}c[o>>2]=L;O=c[y+(r<<2)>>2]|0}else{K=-7-r+(c[q>>2]|0)|0;b:do{if((K|0)<3){J=c[l>>2]|0;do{if((J|0)>44099){P=1489672+(K*25|0)|0}else{if((J|0)>31999){P=1489752+(K*25|0)|0;break}if((J|0)<=22049){Q=0;R=0;S=0;break b}P=1489832+(K*25|0)|0}}while(0);J=a[P]|0;I=J&255;if(!(J<<24>>24==0)){J=0;while(1){N=J+1|0;b[D+(r*50|0)+(J<<1)>>1]=d[P+N|0]|0;if((N|0)<(I|0)){J=N}else{break}}}c[y+(r<<2)>>2]=I;O=I;break a}else{Q=0;R=0;S=0}}while(0);while(1){if((R|0)>=25){T=Q;break}K=c[l>>2]|0;J=(((ca(e[1248584+(R<<1)>>1]|0,H)|0)+K<<1|0)/(K<<2|0)|0)<<2;K=(J|0)>(H|0)?H:J;if((K|0)>(S|0)){b[D+(r*50|0)+(Q<<1)>>1]=K-S;U=Q+1|0}else{U=Q}if((K|0)<(H|0)){Q=U;R=R+1|0;S=K}else{T=U;break}}c[y+(r<<2)>>2]=T;O=T}}while(0);K=c[s>>2]|0;J=K-((K*9|0|0)/100|0)>>r;K=f+(r<<2)|0;c[K>>2]=J;N=~~(A*+(H<<1|0)/+(c[l>>2]|0)+.5);M=x+(r<<2)|0;c[M>>2]=N;c:do{if((O|0)>0){V=0;W=0;X=0;Y=N;Z=J;while(1){_=(e[D+(r*50|0)+(W<<1)>>1]|0)+V|0;$=(V|0)<(Y|0)?Y:V;aa=(_|0)>(Z|0)?Z:_;if((aa|0)>($|0)){c[E+(r<<6)+(X<<2)>>2]=aa-$;ba=X+1|0}else{ba=X}$=W+1|0;if(($|0)>=(O|0)){da=ba;break c}V=_;W=$;X=ba;Y=c[M>>2]|0;Z=c[K>>2]|0}}else{da=0}}while(0);c[h+(r<<2)>>2]=da;K=r+1|0;ea=c[n>>2]|0;if((K|0)>=(ea|0)){break}r=K;G=c[p>>2]|0}if((ea|0)<=0){break}G=k+67040|0;r=0;do{H0a((c[q>>2]|0)-r|0);c[G+(r<<2)>>2]=c[1305896+((c[q>>2]|0)-r<<2)>>2];r=r+1|0;}while((r|0)<(c[n>>2]|0))}}while(0);c[k+1108>>2]=1;if((c[t>>2]|0)!=0){A=(c[k+60>>2]|0)==0?.03999999910593033:.019999999552965164;g[k+149020>>2]=A;u=A*8.065490087349327e-10;t=k+116248|0;n=0;q=1;do{q=(q*314159|0)+1|0;g[t+(n<<2)>>2]=u*+(q|0);n=n+1|0;}while((n|0)<8192)}do{if((c[l>>2]|0)>31999){u=z;if(u<.72){fa=0;break}if(!(u<1.16)){fa=4;break}fa=2}else{fa=4}}while(0);l=1648752+(fa*20|0)|0;c[k+1088>>2]=l;n=k+1092|0;c[n>>2]=1648752+((fa|1)*20|0);Xgb(k+1024|0,k+1064|0,k+1072|0,k+1080|0,l);Xgb(k+1044|0,k+1068|0,k+1076|0,k+1084|0,c[n>>2]|0);m=0;i=j;return m|0}function Xgb(a,d,e,f,h){a=a|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0;i=c[h>>2]|0;j=c[h+16>>2]|0;$2(a,9,i,c[h+12>>2]|0,1,1,c[h+8>>2]|0,4,4,0,0,0,0)|0;h=i<<1;a=hJb(h)|0;k=hJb(h)|0;l=k;m=hJb(i<<2)|0;n=hJb(h)|0;if((i|0)>2){o=2;p=0;q=1}else{c[d>>2]=a;c[e>>2]=m;c[f>>2]=n;kJb(k);return}while(1){b[n+(p<<1)>>1]=o;h=p+1|0;r=b[j+(p<<1)>>1]|0;s=r&65535;if(r<<16>>16==0){t=o}else{r=q&65535;u=+(q|0);v=s>>>0>1>>>0?s:1;w=o;x=0;while(1){b[a+(w<<1)>>1]=x;b[l+(w<<1)>>1]=r;g[m+(w<<2)>>2]=u;y=x+1|0;if((y|0)<(s|0)){w=w+1|0;x=y}else{break}}t=o+v|0}if((t|0)<(i|0)){o=t;p=h;q=q+1|0}else{break}}c[d>>2]=a;c[e>>2]=m;c[f>>2]=n;kJb(k);return}function Ygb(a){a=a|0;var b=0;do{if((a|0)<15){b=13}else{if((a|0)<32){b=12;break}if((a|0)<40){b=11;break}b=(a|0)<45?10:9}}while(0);return b|0}function Zgb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;a=b+1104|0;if((c[a>>2]|0)>0){d=b+66720|0;e=0;do{PPa(d+(e<<6)|0);e=e+1|0;}while((e|0)<(c[a>>2]|0))}if((c[b+60>>2]|0)!=0){c3(b+72|0)}if((c[b+64>>2]|0)!=0){c3(b+748|0)}c3(b+1024|0);mJb(b+1064|0);mJb(b+1072|0);mJb(b+1080|0);c3(b+1044|0);mJb(b+1068|0);mJb(b+1076|0);mJb(b+1084|0);return 0}function _gb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+8|0;e=c[b>>2]|0;f=c[a>>2]|0;g=d[f+(e>>>3)|0]|0;h=c[a+16>>2]|0;a=((e|0)<(h|0))+e|0;c[b>>2]=a;do{if((g&128>>>((e&7)>>>0)|0)==0){i=8;j=a}else{k=d[f+(a>>>3)|0]|0;l=((a|0)<(h|0))+a|0;c[b>>2]=l;if((k&128>>>((a&7)>>>0)|0)==0){i=16;j=l;break}k=d[f+(l>>>3)|0]|0;m=((l|0)<(h|0))+l|0;c[b>>2]=m;i=(k&128>>>((l&7)>>>0)|0)==0?24:31;j=m}}while(0);a=f+(j>>>3)|0;e=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(j&7);if(i>>>0<26>>>0){a=j+i|0;c[b>>2]=h>>>0>a>>>0?a:h;n=e>>>((32-i|0)>>>0);return n|0}else{a=j+16|0;j=h>>>0>a>>>0?a:h;c[b>>2]=j;a=i-16|0;g=f+(j>>>3)|0;f=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(j&7)>>>((48-i|0)>>>0);i=j+a|0;c[b>>2]=h>>>0>i>>>0?i:h;n=f|e>>>16<<a;return n|0}return 0}function $gb(a,f,h,j,k,l,m,n,o,p,q,r){a=a|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;s=i;t=p-1|0;a:do{if((n|0)<(o|0)){p=h+4|0;u=f+8|0;v=f+16|0;w=f|0;x=32-r|0;y=32-q|0;if((l|0)==0){z=c[p>>2]|0;A=c[w>>2]|0;B=n;while(1){C=c[u>>2]|0;D=c[v>>2]|0;E=A+(C>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(C&7)>>>23;E=b[z+(F<<2)>>1]|0;G=b[z+(F<<2)+2>>1]|0;F=G<<16>>16;do{if(G<<16>>16<0){H=C+9|0;I=D>>>0>H>>>0?H:D;H=A+(I>>>3)|0;J=((je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(I&7)>>>((F+32|0)>>>0))+E|0;H=b[z+(J<<2)>>1]|0;K=b[z+(J<<2)+2>>1]|0;J=K<<16>>16;if(!(K<<16>>16<0)){L=J;M=H;N=I;break}K=I-F|0;I=D>>>0>K>>>0?K:D;K=A+(I>>>3)|0;O=((je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(I&7)>>>((J+32|0)>>>0))+H|0;L=b[z+(O<<2)+2>>1]|0;M=b[z+(O<<2)>>1]|0;N=I}else{L=F;M=E;N=C}}while(0);C=L+N|0;E=D>>>0>C>>>0?C:D;c[u>>2]=E;if((M|0)>1){C=(e[k+(M<<1)>>1]|0)+B|0;F=d[A+(E>>>3)|0]<<(E&7)>>>7;c[u>>2]=((E|0)<(D|0))+E;c[m+((C&t)<<2)>>2]=c[j+(M<<2)>>2]^-2147483648^F<<31;P=C}else{if((M|0)==1){Q=B;break a}C=A+(E>>>3)|0;F=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>(x>>>0);C=E+r|0;E=D>>>0>C>>>0?C:D;c[u>>2]=E;C=A+(E>>>3)|0;G=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>(y>>>0);C=E+q|0;E=D>>>0>C>>>0?C:D;c[u>>2]=E;C=G+B|0;G=d[A+(E>>>3)|0]<<(E&7)>>>7;c[u>>2]=((E|0)<(D|0))+E;E=(G&1)-1|0;g[m+((C&t)<<2)>>2]=+((E^F)-E|0);P=C}C=P+1|0;if((C|0)<(o|0)){B=C}else{Q=C;break a}}}B=n;A=c[w>>2]|0;b:while(1){x=c[p>>2]|0;z=c[u>>2]|0;C=c[v>>2]|0;E=A+(z>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(z&7)>>>23;E=b[x+(F<<2)>>1]|0;G=b[x+(F<<2)+2>>1]|0;F=G<<16>>16;do{if(G<<16>>16<0){I=z+9|0;O=C>>>0>I>>>0?I:C;I=A+(O>>>3)|0;H=((je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(O&7)>>>((F+32|0)>>>0))+E|0;I=b[x+(H<<2)>>1]|0;J=b[x+(H<<2)+2>>1]|0;H=J<<16>>16;if(!(J<<16>>16<0)){R=H;S=I;T=O;break}J=O-F|0;O=C>>>0>J>>>0?J:C;J=A+(O>>>3)|0;K=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(O&7)>>>((H+32|0)>>>0))+I|0;R=b[x+(K<<2)+2>>1]|0;S=b[x+(K<<2)>>1]|0;T=O}else{R=F;S=E;T=z}}while(0);z=R+T|0;E=C>>>0>z>>>0?z:C;c[u>>2]=E;if((S|0)>1){z=(e[k+(S<<1)>>1]|0)+B|0;F=d[A+(E>>>3)|0]<<(E&7)>>>7;c[u>>2]=((E|0)<(C|0))+E;c[m+((z&t)<<2)>>2]=c[j+(S<<2)>>2]^-2147483648^F<<31;U=z;V=A}else{if((S|0)==1){Q=B;break a}z=_gb(f)|0;F=c[u>>2]|0;E=c[w>>2]|0;x=d[E+(F>>>3)|0]|0;G=c[v>>2]|0;D=((F|0)<(G|0))+F|0;c[u>>2]=D;do{if((x&128>>>((F&7)>>>0)|0)==0){W=B;X=D}else{O=d[E+(D>>>3)|0]|0;K=((D|0)<(G|0))+D|0;c[u>>2]=K;I=E+(K>>>3)|0;if((O&128>>>((D&7)>>>0)|0)==0){O=I;H=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(K&7)>>>30;O=K+2|0;J=G>>>0>O>>>0?O:G;c[u>>2]=J;W=B+1+H|0;X=J;break}J=d[I]|0;I=((K|0)<(G|0))+K|0;c[u>>2]=I;if((J&128>>>((K&7)>>>0)|0)!=0){break b}K=E+(I>>>3)|0;J=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(I&7)>>>(y>>>0);K=I+q|0;I=G>>>0>K>>>0?K:G;c[u>>2]=I;W=B+4+J|0;X=I}}while(0);D=d[E+(X>>>3)|0]<<(X&7)>>>7;c[u>>2]=((X|0)<(G|0))+X;F=(D&1)-1|0;g[m+((W&t)<<2)>>2]=+((F^z)-F|0);U=W;V=E}F=U+1|0;if((F|0)<(o|0)){B=F;A=V}else{Q=F;break a}}KIb(a,16,2587080,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;Z=-1;i=s;return Z|0}else{Q=n}}while(0);if((Q|0)<=(o|0)){Z=0;i=s;return Z|0}KIb(a,16,2441248,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0);i=Y;Z=-1;i=s;return Z|0}function ahb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;do{if((a|0)<16001){d=9}else{if((a|0)<22051){d=10;break}if((a|0)<32001&(b|0)==1){d=10;break}if((a|0)<48001|(b|0)<3){d=11;break}d=(a|0)<96001?12:13}}while(0);do{if((b|0)==3){a=c&6;if((a|0)==6){e=d-2|0;break}else if((a|0)==2){e=d+1|0;break}else if((a|0)==4){e=d-1|0;break}else{e=d;break}}else{e=d}}while(0);return e|0}function bhb(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0.0;b=i;e=c[a+60>>2]|0;f=e;if((c[a+432>>2]|0)==0){KIb(a,16,2487472,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=b;return j|0}c[e>>2]=a;k=c[a+96>>2]|0;l=c[(c[a+12>>2]|0)+12>>2]|0;do{if((l|0)==86023){if((c[a+100>>2]|0)<=3){m=0;n=86023;break}o=k+2|0;m=(d[o]|d[o+1|0]<<8)<<16>>16&65535;n=86023}else if((l|0)==86024){if((c[a+100>>2]|0)<=5){m=0;n=86024;break}o=k+4|0;m=(d[o]|d[o+1|0]<<8)<<16>>16&65535;n=86024}else{m=0;n=l}}while(0);l=e+60|0;c[l>>2]=m&1;c[e+52>>2]=m&2;o=m&4;p=e+56|0;c[p>>2]=o;do{if((n|0)==86024){if((c[a+100>>2]|0)<=7){break}q=k+4|0;if((d[q]|d[q+1|0]<<8)<<16>>16<<16>>16!=13|(o|0)==0){break}KIb(a,24,2476168,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;c[p>>2]=0}}while(0);if((Wgb(a,m)|0)<0){j=-1;i=b;return j|0}m=e+1104|0;if((c[m>>2]|0)>0){p=e+66720|0;h=e+1100|0;o=0;do{OPa(p+(o<<6)|0,1-o+(c[h>>2]|0)|0,1,30517578125.0e-15)|0;o=o+1|0;}while((o|0)<(c[m>>2]|0))}if((c[e+64>>2]|0)!=0){$2(e+748|0,9,37,1248544,1,1,1248464,2,2,0,0,0,0)|0}if((c[l>>2]|0)==0){l=c[e+1096>>2]|0;r=3.141592653589793/+(l|0);if((l|0)>0){m=0;while(1){g[f+149024+(m<<2)>>2]=+U(r*+(m|0))*2.0;o=m+1|0;if((o|0)<(l|0)){m=o}else{s=0;break}}}else{s=0}while(1){g[f+157216+(s<<2)>>2]=+ad(+(+(s-126|0)*-.25));m=s+1|0;if((m|0)<256){s=m}else{t=127;u=1.0;break}}while(1){r=+T(+(+(t+128|0)*.00390625),+-.25);g[f+158240+(t<<2)>>2]=r*2.0-u;g[f+158752+(t<<2)>>2]=u-r;if((t|0)>0){t=t-1|0;u=r}else{break}}}else{$2(e+72|0,8,121,1446024,1,1,1445536,4,4,0,0,0,0)|0}c[a+420>>2]=8;j=0;i=b;return j|0}function chb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;j=e;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=g;if((l|0)==0){c[g+116244>>2]=0;n=0;i=h;return n|0}o=c[b+432>>2]|0;if((l|0)<(o|0)){KIb(b,16,2240504,(p=i,i=i+16|0,c[p>>2]=l,c[p+8>>2]=o,p)|0);i=p;n=-1094995529;i=h;return n|0}q=(o|0)==0?l:o;o=q<<3;l=o>>>0>2147483639>>>0|(k|0)==0;r=l?0:k;s=l?0:o;l=g+4|0;c[l>>2]=r;t=g+16|0;c[t>>2]=s;u=s+8|0;v=g+20|0;c[v>>2]=u;w=g+8|0;c[w>>2]=r+(s>>3);s=g+12|0;c[s>>2]=0;x=g+52|0;do{if((c[x>>2]|0)==0){y=1}else{z=u>>>0>4>>>0?4:u;c[s>>2]=z;A=r+(z>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&4)>>>28;A=z+4|0;c[s>>2]=u>>>0>A>>>0?A:u;A=B-((c[g+116244>>2]|0)<1)|0;if((A|0)>=1){y=A;break}KIb(b,16,2199480,(p=i,i=i+8|0,c[p>>2]=A,p)|0);i=p;n=-1094995529;i=h;return n|0}}while(0);u=g+1096|0;c[e+76>>2]=ca(c[u>>2]|0,y)|0;r=M4a(b,j,0)|0;if((r|0)<0){n=r;i=h;return n|0}r=c[e+64>>2]|0;a:do{if((c[x>>2]|0)==0){if((ehb(m,r,0)|0)<0){C=37}else{C=36}}else{e=g+68|0;j=c[e>>2]|0;A=c[s>>2]|0;B=c[v>>2]|0;z=c[l>>2]|0;D=z+(A>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(A&7)>>>((29-j|0)>>>0);D=j+3+A|0;A=B>>>0>D>>>0?D:B;c[s>>2]=A;D=(c[t>>2]|0)-A|0;if((E|0)>(D|0)){KIb(b,16,2167872,(p=i,i=i+24|0,c[p>>2]=E,c[p+8>>2]=D,c[p+16>>2]=q,p)|0);i=p;C=37;break}D=g+116244|0;F=c[D>>2]|0;if((F|0)>0){if((F+(E+7>>3)|0)>16384){C=37;break}G=g+99840|0;H=g+(F+99840)|0;if((E|0)>7){I=E-8|0;J=I>>>3;K=J<<3;L=F+J+99841|0;J=E;F=H;M=A;A=B;B=z;while(1){z=B+(M>>>3)|0;N=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(M&7)>>>24;z=M+8|0;c[s>>2]=A>>>0>z>>>0?z:A;a[F]=N;N=J-8|0;if((N|0)<=7){break}J=N;F=F+1|0;M=c[s>>2]|0;A=c[v>>2]|0;B=c[l>>2]|0}O=I-K|0;P=g+L|0}else{O=E;P=H}if((O|0)>0){B=c[s>>2]|0;A=c[v>>2]|0;M=(c[l>>2]|0)+(B>>>3)|0;F=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(B&7)>>>((32-O|0)>>>0);M=B+O|0;c[s>>2]=A>>>0>M>>>0?M:A;a[P]=F<<8-O;Q=P+1|0}else{Q=P}mrc(Q|0,0,16)|0;F=(c[D>>2]<<3)+E|0;A=F>>>0>2147483639>>>0|(G|0)==0;M=A?0:G;B=A?0:F;c[l>>2]=M;c[t>>2]=B;F=B+8|0;c[v>>2]=F;c[w>>2]=M+(B+7>>3);c[s>>2]=0;B=c[g+116240>>2]|0;if((B|0)>0){c[s>>2]=F>>>0>B>>>0?B:F}if((ehb(m,r,0)|0)<0){C=37;break}R=c[u>>2]|0;S=y-1|0;T=c[e>>2]|0}else{R=0;S=y;T=j}F=E+11|0;B=F+T|0;if((B|0)>131071|(B|0)>(o|0)){n=-1094995529;i=h;return n|0}M=B>>3;A=k+M|0;J=q-M<<3;M=J>>>0>2147483639>>>0|(A|0)==0;N=M?0:A;A=M?0:J;c[l>>2]=N;c[t>>2]=A;J=A+8|0;c[v>>2]=J;c[w>>2]=N+(A>>3);A=B&7;if((A|0)==0){U=0}else{U=J>>>0>A>>>0?A:J}c[s>>2]=U;c[g+1108>>2]=1;if((S|0)>0){J=0;A=R;while(1){if((ehb(m,r,A)|0)<0){C=37;break a}B=J+1|0;if((B|0)<(S|0)){J=B;A=(c[u>>2]|0)+A|0}else{break}}V=c[s>>2]|0;W=c[e>>2]|0}else{V=U;W=T}A=(F+W&-8)+V|0;c[g+116240>>2]=A&7;J=A>>3;A=q-J|0;if(A>>>0>16384>>>0){KIb(c[g>>2]|0,16,2141216,(p=i,i=i+8|0,c[p>>2]=A,p)|0);i=p;C=37;break}else{c[D>>2]=A;nrc(g+99840|0,k+J|0,A)|0;C=36;break}}}while(0);if((C|0)==36){c[f>>2]=1;n=q;i=h;return n|0}else if((C|0)==37){c[g+116244>>2]=0;n=-1;i=h;return n|0}return 0}function dhb(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+116244>>2]=0;c[b+116240>>2]=0;return}function ehb(f,h,j){f=f|0;h=h|0;j=j|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0.0,Cb=0.0,Db=0.0,Eb=0.0,Fb=0.0,Gb=0.0,Hb=0.0,Ib=0.0,Jb=0.0,Kb=0.0,Lb=0.0,Mb=0.0,Nb=0.0,Ob=0.0,Pb=0.0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0.0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0.0,kc=0.0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0.0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0.0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0.0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0;l=i;i=i+112|0;m=l|0;n=l+40|0;o=l+48|0;p=f+1128|0;c[p>>2]=0;q=f+1132|0;c[q>>2]=0;r=f+56|0;s=f+1100|0;t=f+1116|0;u=f+1120|0;v=f+1112|0;w=f+1104|0;x=f+1124|0;y=f+1096|0;z=f|0;A=f+12|0;B=f+4|0;C=f+20|0;D=f+1136|0;E=f+4|0;F=f+16|0;G=E|0;H=f+384|0;I=f+60|0;J=m|0;K=m+4|0;L=m+8|0;M=m+12|0;N=m+16|0;O=m+20|0;P=m+24|0;Q=m+28|0;R=m+32|0;U=m+36|0;V=f+48|0;W=f+76|0;X=f+149016|0;Y=f+149020|0;Z=f+1138|0;_=f+1137|0;$=f+33952|0;aa=f+159312|0;ba=f+33952|0;ca=f+42144|0;da=f+64|0;ea=f+752|0;fa=f+50336|0;ga=f+159304|0;ha=f+159308|0;ia=f+50336|0;ja=f+1108|0;ka=0;a:while(1){if((c[r>>2]|0)==0){la=c[s>>2]|0;c[t>>2]=la;c[u>>2]=la;c[v>>2]=la;ma=la;na=la;oa=c[w>>2]|0}else{la=c[w>>2]|0;pa=la-1|0;qa=pa>>>0>65535>>>0;ra=qa?pa>>>16:pa;pa=qa?16:0;if((ra&65280|0)==0){sa=pa;ta=ra}else{sa=pa|8;ta=ra>>>8}ra=(d[1359664+ta|0]|0)+sa|0;pa=ra+1|0;if((c[ja>>2]|0)==0){c[u>>2]=c[v>>2];qa=c[t>>2]|0;c[v>>2]=qa;ua=qa;va=c[A>>2]|0;wa=c[C>>2]|0;xa=c[B>>2]|0;ya=31-ra|0}else{c[ja>>2]=0;qa=c[A>>2]|0;za=c[C>>2]|0;Aa=c[B>>2]|0;Ba=Aa+(qa>>>3)|0;Ca=31-ra|0;Da=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(qa&7)>>>(Ca>>>0);Ba=qa+pa|0;qa=za>>>0>Ba>>>0?Ba:za;c[A>>2]=qa;if((Da|0)>=(la|0)){Ea=7;break}Fa=c[s>>2]|0;c[u>>2]=Fa-Da;Ba=Aa+(qa>>>3)|0;Ga=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(qa&7)>>>(Ca>>>0);Ba=qa+pa|0;qa=za>>>0>Ba>>>0?Ba:za;c[A>>2]=qa;if((Ga|0)>=(la|0)){Ea=9;break}Ba=Fa-Ga|0;c[v>>2]=Ba;ua=Ba;va=qa;wa=za;xa=Aa;ya=Ca}Ca=xa+(va>>>3)|0;Ha=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(va&7)>>>(ya>>>0);Ca=va+pa|0;c[A>>2]=wa>>>0>Ca>>>0?Ca:wa;if((Ha|0)>=(la|0)){Ea=13;break}Ca=c[s>>2]|0;c[t>>2]=Ca-Ha;ma=Ca;na=ua;oa=la}la=ma-na|0;if((la|0)>=(oa|0)){Ea=17;break}Ca=1<<na;c[x>>2]=Ca;Ia=c[z>>2]|0;if((ka+Ca|0)>(c[y>>2]|0)){Ea=19;break}Ca=Ia+416|0;pa=c[Ca>>2]|0;if((pa|0)==2){Aa=c[A>>2]|0;za=d[(c[B>>2]|0)+(Aa>>>3)|0]<<(Aa&7)>>>7;c[A>>2]=((Aa|0)<(c[C>>2]|0))+Aa;a[D]=za&1;Ja=c[Ca>>2]|0}else{Ja=pa}do{if((Ja|0)>0){pa=0;Ca=0;do{za=c[A>>2]|0;Aa=d[(c[B>>2]|0)+(za>>>3)|0]<<(za&7)>>>7;c[A>>2]=((za|0)<(c[C>>2]|0))+za;za=Aa&1;a[f+1137+pa|0]=za;Ca=za|Ca;pa=pa+1|0;Ka=c[z>>2]|0;}while((pa|0)<(c[Ka+416>>2]|0));pa=(c[s>>2]|0)-(c[v>>2]|0)|0;if((Ca|0)==0){La=Ka;Ma=pa;Na=Ka;break}za=c[F>>2]|0;Aa=1;qa=c[A>>2]|0;do{if((za-qa|0)<7){Ea=27;break a}Ba=c[C>>2]|0;ra=(c[G>>2]|0)+(qa>>>3)|0;Oa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(qa&7)>>>25;ra=qa+7|0;qa=Ba>>>0>ra>>>0?ra:Ba;c[A>>2]=qa;Aa=Oa+Aa|0;}while((Oa|0)==127);qa=Ygb(Aa)|0;za=f+388+(pa<<2)|0;Ca=(c[za>>2]|0)-(c[H>>2]|0)|0;Oa=c[z>>2]|0;Ba=c[Oa+416>>2]|0;do{if((Ba|0)>0){ra=0;do{c[n+(ra<<2)>>2]=Ca;ra=ra+1|0;}while((ra|0)<(Ba|0));if((c[da>>2]|0)==0){Pa=Oa;Qa=Oa;Ra=Ba;break}ra=f+408+(pa<<2)|0;Sa=0;Ta=Oa;while(1){do{if((a[f+1137+Sa|0]|0)==0){Ua=Ta}else{Va=c[ra>>2]|0;if((Va|0)<=0){Ua=Ta;break}Wa=n+(Sa<<2)|0;Xa=0;do{Ya=c[A>>2]|0;Za=d[(c[G>>2]|0)+(Ya>>>3)|0]<<(Ya&7)>>>7;c[A>>2]=((Ya|0)<(c[C>>2]|0))+Ya;Ya=Za&1;c[f+768+(Sa<<6)+(Xa<<2)>>2]=Ya;if((Ya|0)!=0){c[Wa>>2]=(c[Wa>>2]|0)-(c[f+428+(pa<<6)+(Xa<<2)>>2]|0)}Xa=Xa+1|0;}while((Xa|0)<(Va|0));Ua=c[z>>2]|0}}while(0);Va=Sa+1|0;_a=c[Ua+416>>2]|0;if((Va|0)<(_a|0)){Sa=Va;Ta=Ua}else{break}}if((_a|0)>0){$a=0;ab=Ua;bb=Ua}else{Pa=Ua;Qa=Ua;Ra=_a;break}while(1){do{if((a[f+1137+$a|0]|0)==0){cb=ab;db=bb}else{Ta=c[ra>>2]|0;if((Ta|0)>0){eb=-2147483648;fb=0}else{cb=ab;db=bb;break}while(1){if((c[f+768+($a<<6)+(fb<<2)>>2]|0)==0){gb=eb}else{if((eb|0)==-2147483648){Sa=c[A>>2]|0;Va=c[C>>2]|0;Xa=(c[G>>2]|0)+(Sa>>>3)|0;Wa=(je(d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0)|0)<<(Sa&7)>>>25;Xa=Sa+7|0;c[A>>2]=Va>>>0>Xa>>>0?Xa:Va;hb=Wa-19|0}else{Wa=c[ea>>2]|0;Va=c[A>>2]|0;Xa=c[C>>2]|0;Sa=c[G>>2]|0;Ya=Sa+(Va>>>3)|0;Za=(je(d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0)|0)<<(Va&7)>>>23;Ya=b[Wa+(Za<<2)>>1]|0;ib=b[Wa+(Za<<2)+2>>1]|0;Za=ib<<16>>16;if(ib<<16>>16<0){ib=Va+9|0;jb=Xa>>>0>ib>>>0?ib:Xa;ib=Sa+(jb>>>3)|0;Sa=((je(d[ib]|d[ib+1|0]<<8|d[ib+2|0]<<16|d[ib+3|0]<<24|0)|0)<<(jb&7)>>>((Za+32|0)>>>0))+Ya|0;kb=b[Wa+(Sa<<2)+2>>1]|0;lb=b[Wa+(Sa<<2)>>1]|0;mb=jb}else{kb=Za;lb=Ya;mb=Va}Va=kb+mb|0;c[A>>2]=Xa>>>0>Va>>>0?Va:Xa;if((lb|0)<0){Ea=50;break a}hb=eb-18+lb|0}c[f+896+($a<<6)+(fb<<2)>>2]=hb;gb=hb}Xa=fb+1|0;if((Xa|0)<(Ta|0)){eb=gb;fb=Xa}else{break}}Ta=c[z>>2]|0;cb=Ta;db=Ta}}while(0);Ta=$a+1|0;Xa=c[cb+416>>2]|0;if((Ta|0)<(Xa|0)){$a=Ta;ab=cb;bb=db}else{Pa=cb;Qa=db;Ra=Xa;break}}}else{Pa=Oa;Qa=Oa;Ra=Ba}}while(0);if((c[v>>2]|0)==(c[s>>2]|0)){nb=Ra;Ea=58}else{Ba=c[A>>2]|0;Oa=d[(c[G>>2]|0)+(Ba>>>3)|0]|0;c[A>>2]=((Ba|0)<(c[C>>2]|0))+Ba;Ca=c[Pa+416>>2]|0;if((Oa&128>>>((Ba&7)>>>0)|0)==0){ob=Pa;pb=Qa;qb=Ca;Ea=59}else{nb=Ca;Ea=58}}do{if((Ea|0)==58){Ea=0;if((nb|0)>0){rb=0;sb=Pa;tb=Qa}else{ub=nb;vb=Qa;wb=Pa;Ea=60;break}while(1){if((a[f+1137+rb|0]|0)==0){xb=sb;yb=tb}else{if((c[I>>2]|0)==0){Ca=c[C>>2]|0;Ba=c[B>>2]|0;Oa=0;ra=c[A>>2]|0;while(1){Xa=Ba+(ra>>>3)|0;Ta=(je(d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0)|0)<<(ra&7);if((Oa|0)==0|(Oa|0)>7){Xa=ra+3|0;zb=Ta>>>29;Ab=Ca>>>0>Xa>>>0?Xa:Ca}else{Xa=ra+4|0;zb=Ta>>>28;Ab=Ca>>>0>Xa>>>0?Xa:Ca}c[A>>2]=Ab;g[m+(Oa<<2)>>2]=+g[1247824+(Oa<<6)+(zb<<2)>>2];Xa=Oa+1|0;if((Xa|0)<10){Oa=Xa;ra=Ab}else{break}}ra=f+17536+(rb<<2)|0;Oa=c[x>>2]|0;if((Oa|0)>0){Bb=+g[J>>2];Cb=+g[K>>2];Db=+g[L>>2];Eb=+g[M>>2];Fb=+g[N>>2];Gb=+g[O>>2];Hb=+g[P>>2];Ib=+g[Q>>2];Jb=+g[R>>2];Kb=+g[U>>2];Ca=0;Lb=0.0;while(1){Mb=+g[f+149024+(Ca<<2)>>2];Nb=(Mb-Jb)*(Mb-Hb)*(Mb-Fb)*(Mb-Db)*(Mb-Bb)*.5;Ob=(Mb-Kb)*(Mb-Ib)*(Mb-Gb)*(Mb-Eb)*(Mb-Cb)*.5;Ba=(g[k>>2]=Nb*(Mb+2.0)*Nb+Ob*(2.0-Mb)*Ob,c[k>>2]|0);Xa=Ba>>>16&127;Ob=+g[f+157216+(Ba>>>23<<2)>>2]*(+g[f+158240+(Xa<<2)>>2]+ +g[f+158752+(Xa<<2)>>2]*(c[k>>2]=Ba<<7&8388480|1065353216,+g[k>>2]));Mb=Ob>Lb?Ob:Lb;g[f+1152+(rb<<13)+(Ca<<2)>>2]=Ob;Ba=Ca+1|0;if((Ba|0)<(Oa|0)){Ca=Ba;Lb=Mb}else{Pb=Mb;break}}}else{Pb=0.0}g[ra>>2]=Pb}else{Ca=(c[s>>2]|0)-(c[v>>2]|0)|0;Oa=f+112+(Ca*50|0)|0;Ba=f+1152+(rb<<13)|0;Xa=f+1152+(rb<<13)+(c[x>>2]<<2)|0;do{if((c[V>>2]|0)==1){Ta=c[A>>2]|0;Va=c[C>>2]|0;Ya=(c[B>>2]|0)+(Ta>>>3)|0;Za=(je(d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0)|0)<<(Ta&7)>>>27;Ya=Ta+5|0;c[A>>2]=Va>>>0>Ya>>>0?Ya:Va;Va=Za+10|0;Lb=+g[703120+(Za+70<<2)>>2];Cb=+Lb;Za=f+112+(Ca*50|0)+2|0;Ya=e[Oa>>1]|0;Ta=Ya&3;if((Ta|0)==1){Qb=Ya;Rb=Ba;Ea=68}else if((Ta|0)==0){Sb=Ya;Tb=Ba;Ea=65}else if((Ta|0)==3){Ub=Ya;Vb=Ba;Ea=66}else if((Ta|0)==2){Wb=Ya;Xb=Ba;Ea=67}else{Yb=Va;Zb=Ba;_b=Lb;$b=Za;break}while(1){if((Ea|0)==65){Ea=0;g[Tb>>2]=Cb;Ub=Sb;Vb=Tb+4|0;Ea=66;continue}else if((Ea|0)==66){Ea=0;g[Vb>>2]=Cb;Wb=Ub;Xb=Vb+4|0;Ea=67;continue}else if((Ea|0)==67){Ea=0;g[Xb>>2]=Cb;Qb=Wb;Rb=Xb+4|0;Ea=68;continue}else if((Ea|0)==68){Ea=0;Ya=Rb+4|0;g[Rb>>2]=Cb;Ta=Qb-4|0;if((Ta|0)>0){Sb=Ta;Tb=Ya;Ea=65;continue}else{Yb=Va;Zb=Ya;_b=Lb;$b=Za;break}}}}else{Yb=36;Zb=Ba;_b=0.0;$b=Oa}}while(0);if(Zb>>>0<Xa>>>0){Oa=c[B>>2]|0;Ba=c[W>>2]|0;Ca=$b;Lb=_b;ra=Zb;Za=Yb;while(1){Va=c[C>>2]|0;Ya=Za;Cb=Lb;Ta=Ca;jb=c[A>>2]|0;while(1){Sa=Oa+(jb>>>3)|0;Wa=(je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(jb&7)>>>24;Sa=b[Ba+(Wa<<2)>>1]|0;ib=b[Ba+(Wa<<2)+2>>1]|0;Wa=ib<<16>>16;do{if(ib<<16>>16<0){ac=jb+8|0;bc=Va>>>0>ac>>>0?ac:Va;ac=Oa+(bc>>>3)|0;cc=((je(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(bc&7)>>>((Wa+32|0)>>>0))+Sa|0;ac=b[Ba+(cc<<2)>>1]|0;dc=b[Ba+(cc<<2)+2>>1]|0;cc=dc<<16>>16;if(!(dc<<16>>16<0)){ec=cc;fc=ac;gc=bc;break}dc=bc-Wa|0;bc=Va>>>0>dc>>>0?dc:Va;dc=Oa+(bc>>>3)|0;hc=((je(d[dc]|d[dc+1|0]<<8|d[dc+2|0]<<16|d[dc+3|0]<<24|0)|0)<<(bc&7)>>>((cc+32|0)>>>0))+ac|0;ec=b[Ba+(hc<<2)+2>>1]|0;fc=b[Ba+(hc<<2)>>1]|0;gc=bc}else{ec=Wa;fc=Sa;gc=jb}}while(0);Sa=ec+gc|0;Wa=Va>>>0>Sa>>>0?Sa:Va;c[A>>2]=Wa;if((fc|0)<0){Ea=79;break a}ic=Ya-60+fc|0;Sa=fc+Ya|0;if(Sa>>>0>155>>>0){Ea=80;break a}Eb=+g[703120+(Sa<<2)>>2];jc=+Eb;kc=Eb>Cb?Eb:Cb;lc=Ta+2|0;Sa=e[Ta>>1]|0;ib=Sa&3;if((ib|0)==2){mc=Sa;nc=ra;Ea=83;break}else if((ib|0)==1){oc=Sa;pc=ra;Ea=84;break}else if((ib|0)==0){qc=Sa;rc=ra;Ea=81;break}else if((ib|0)==3){sc=Sa;tc=ra;Ea=82;break}else{Ya=ic;Cb=kc;Ta=lc;jb=Wa}}while(1){if((Ea|0)==81){Ea=0;g[rc>>2]=jc;sc=qc;tc=rc+4|0;Ea=82;continue}else if((Ea|0)==82){Ea=0;g[tc>>2]=jc;mc=sc;nc=tc+4|0;Ea=83;continue}else if((Ea|0)==83){Ea=0;g[nc>>2]=jc;oc=mc;pc=nc+4|0;Ea=84;continue}else if((Ea|0)==84){Ea=0;uc=pc+4|0;g[pc>>2]=jc;jb=oc-4|0;if((jb|0)>0){qc=jb;rc=uc;Ea=81;continue}else{break}}}if(uc>>>0<Xa>>>0){Ca=lc;Lb=kc;ra=uc;Za=ic}else{vc=kc;break}}}else{vc=_b}g[f+17536+(rb<<2)>>2]=vc}c[f+1140+(rb<<2)>>2]=pa;Za=c[z>>2]|0;xb=Za;yb=Za}Za=rb+1|0;ra=c[xb+416>>2]|0;if((Za|0)<(ra|0)){rb=Za;sb=xb;tb=yb}else{ob=xb;pb=yb;qb=ra;Ea=59;break}}}}while(0);do{if((Ea|0)==59){Ea=0;if((qb|0)>0){wc=0;xc=pb}else{ub=qb;vb=pb;wb=ob;Ea=60;break}while(1){if((a[f+1137+wc|0]|0)==0){yc=xc}else{ra=f+17544+(wc<<13)|0;if((wc|0)==1){zc=(a[D]|0)!=0|0}else{zc=0}mrc(ra|0,0,c[x>>2]<<2|0)|0;$gb(c[z>>2]|0,E,f+1024+(zc*20|0)|0,c[f+1072+(zc<<2)>>2]|0,c[f+1064+(zc<<2)>>2]|0,0,ra,0,c[n+(wc<<2)>>2]|0,c[x>>2]|0,c[s>>2]|0,qa)|0;yc=c[z>>2]|0}ra=c[V>>2]|0;Za=yc+416|0;do{if((ra|0)==1){if((c[Za>>2]|0)<=1){break}Ca=c[A>>2]|0;Xa=-Ca&7;if((Xa|0)==0){break}Ba=c[C>>2]|0;Oa=Xa+Ca|0;c[A>>2]=Ba>>>0>Oa>>>0?Oa:Ba}}while(0);Ba=wc+1|0;Oa=c[Za>>2]|0;if((Ba|0)<(Oa|0)){wc=Ba;xc=yc}else{Ac=yc;Bc=Oa;Cc=ra;Dc=yc;break}}}}while(0);if((Ea|0)==60){Ea=0;Ac=wb;Bc=ub;Cc=c[V>>2]|0;Dc=vb}qa=(c[x>>2]|0)/2|0;Lb=1.0/+(qa|0);if((Cc|0)==1){Ec=Lb*+S(+(qa|0))}else{Ec=Lb}if((Bc|0)>0){Lb=+(Aa|0)*.05;qa=f+408+(pa<<2)|0;Oa=f+364+(pa<<2)|0;Ba=-1<<pa;Ca=0;Xa=Ac;jb=ba;Ta=Dc;while(1){Ya=f+33952+(Ca<<13)|0;Va=Ya;Wa=jb;do{if((a[f+1137+Ca|0]|0)==0){Fc=Xa;Gc=Ta}else{Sa=f+17544+(Ca<<13)|0;ib=c[f+1140+(Ca<<2)>>2]|0;Cb=+T(+10.0,+Lb);bc=f+17536+(Ca<<2)|0;Eb=Ec*(Cb/+g[bc>>2]);hc=c[H>>2]|0;ac=(hc|0)>0;if((c[da>>2]|0)==0){if(ac){cc=(hc|0)>1?hc<<2:4;mrc(Va|0,0,cc|0)|0;Hc=Wa+cc|0}else{Hc=Ya}cc=c[n+(Ca<<2)>>2]|0;if((cc|0)>0){dc=Hc;Ic=0;while(1){g[dc>>2]=Eb*+g[f+17544+(Ca<<13)+(Ic<<2)>>2]*+g[f+1152+(Ca<<13)+(Ic<<pa>>ib<<2)>>2];Jc=Ic+1|0;if((Jc|0)<(cc|0)){dc=dc+4|0;Ic=Jc}else{break}}Kc=Hc+(cc<<2)|0}else{Kc=Hc}Ic=(c[x>>2]|0)-(c[za>>2]|0)|0;if((Ic|0)>0){mrc(Kc|0,0,Ic<<2|0)|0}Ic=c[z>>2]|0;Fc=Ic;Gc=Ic;break}if(ac){Ic=jb+(hc<<2)|0;dc=Ya;ra=0;Za=c[X>>2]|0;while(1){g[dc>>2]=Eb*+g[f+116248+(Za<<2)>>2]*+g[f+1152+(Ca<<13)+(ra<<pa>>ib<<2)>>2];Jc=Za+1&8191;c[X>>2]=Jc;Lc=ra+1|0;if((Lc|0)<(hc|0)){dc=dc+4|0;ra=Lc;Za=Jc}else{Mc=Ic;break}}}else{Mc=Ya}Ic=c[qa>>2]|0;if((Ic|0)>0){Za=(c[s>>2]|0)-(c[v>>2]|0)|0;ra=f+1152+(Ca<<13)+(c[Oa>>2]<<pa>>ib<<2)|0;dc=0;ac=0;while(1){cc=c[f+428+(Za<<6)+(dc<<2)>>2]|0;if((c[f+768+(Ca<<6)+(dc<<2)>>2]|0)==0){Nc=ac}else{if((cc|0)>0){Jc=0;Cb=0.0;while(1){Gb=+g[ra+(Jc<<pa>>ib<<2)>>2];Ib=Cb+Gb*Gb;Lc=Jc+1|0;if((Lc|0)<(cc|0)){Jc=Lc;Cb=Ib}else{Oc=Ib;break}}}else{Oc=0.0}g[o+(dc<<2)>>2]=Oc/+(cc|0);Nc=dc}Jc=dc+1|0;if((Jc|0)<(Ic|0)){ra=ra+(cc<<pa>>ib<<2)|0;dc=Jc;ac=Nc}else{Pc=Nc;break}}}else{Pc=0}ac=f+1152+(Ca<<13)+(hc<<pa>>ib<<2)|0;if((Ic|0)>-1){dc=o+(Pc<<2)|0;ra=Sa;Za=Mc;Jc=ac;Lc=-1;while(1){do{if((Lc|0)<0){Qc=(c[Oa>>2]|0)-hc|0;Ea=128}else{Rc=c[f+428+((c[s>>2]|0)-(c[v>>2]|0)<<6)+(Lc<<2)>>2]|0;if((c[f+768+(Ca<<6)+(Lc<<2)>>2]|0)==0){Qc=Rc;Ea=128;break}Cb=+S(+g[o+(Lc<<2)>>2]/+g[dc>>2]);Ib=Cb*+T(+10.0,+(+(c[f+896+(Ca<<6)+(Lc<<2)>>2]|0)*.05));Cb=Ec*(Ib/(+g[bc>>2]*+g[Y>>2]));if((Rc|0)<=0){Sc=Za;Tc=ra;Uc=Rc;break}Vc=Za;Wc=0;Xc=c[X>>2]|0;while(1){Ib=+g[f+116248+(Xc<<2)>>2];Yc=Xc+1&8191;c[X>>2]=Yc;g[Vc>>2]=Cb*Ib*+g[Jc+(Wc<<pa>>ib<<2)>>2];Zc=Wc+1|0;if((Zc|0)<(Rc|0)){Vc=Vc+4|0;Wc=Zc;Xc=Yc}else{break}}Sc=Za+(Rc<<2)|0;Tc=ra;Uc=Rc}}while(0);do{if((Ea|0)==128){Ea=0;if((Qc|0)<=0){Sc=Za;Tc=ra;Uc=Qc;break}cc=ra;Xc=Za;Wc=0;Vc=c[X>>2]|0;while(1){Cb=+g[f+116248+(Vc<<2)>>2];Yc=Vc+1&8191;c[X>>2]=Yc;g[Xc>>2]=Eb*(Cb+ +g[cc>>2])*+g[Jc+(Wc<<pa>>ib<<2)>>2];Zc=Wc+1|0;if((Zc|0)<(Qc|0)){cc=cc+4|0;Xc=Xc+4|0;Wc=Zc;Vc=Yc}else{break}}Sc=Za+(Qc<<2)|0;Tc=ra+(Qc<<2)|0;Uc=Qc}}while(0);Vc=Jc+(Uc<<pa>>ib<<2)|0;Wc=Lc+1|0;if((Wc|0)<(Ic|0)){ra=Tc;Za=Sc;Jc=Vc;Lc=Wc}else{_c=Sc;$c=Vc;break}}}else{_c=Mc;$c=ac}Lc=(c[x>>2]|0)-(c[za>>2]|0)|0;Cb=Eb*+g[$c+(Ba>>ib<<2)>>2];if((Lc|0)<=0){Fc=Xa;Gc=Ta;break}Jc=_c;Za=0;ra=c[X>>2]|0;while(1){g[Jc>>2]=Cb*+g[f+116248+(ra<<2)>>2];Ic=ra+1&8191;c[X>>2]=Ic;bc=Za+1|0;if((bc|0)<(Lc|0)){Jc=Jc+4|0;Za=bc;ra=Ic}else{Fc=Xa;Gc=Ta;break}}}}while(0);Ya=Ca+1|0;if((Ya|0)<(c[Fc+416>>2]|0)){Ca=Ya;Xa=Fc;jb=jb+8192|0;Ta=Gc}else{ad=Fc;bd=Gc;break}}}else{ad=Ac;bd=Dc}if((a[D]|0)==0){La=ad;Ma=pa;Na=bd;break}if((a[Z]|0)==0){La=ad;Ma=pa;Na=bd;break}Ta=c[x>>2]|0;if((a[_]|0)==0){mrc($|0,0,Ta<<2|0)|0;a[_]=1}ef[c[aa>>2]&4095](ba,ca,Ta);Ta=c[z>>2]|0;La=Ta;Ma=pa;Na=Ta}else{La=Ia;Ma=la;Na=Ia}}while(0);la=f+66720+(Ma<<6)|0;if((c[La+416>>2]|0)>0){Ta=f+66720+(Ma<<6)+40|0;jb=0;while(1){Xa=c[x>>2]|0;do{if((a[f+1137+jb|0]|0)==0){if((a[D]|0)!=0&(jb|0)==1){break}mrc(fa|0,0,16384)|0}else{ef[c[Ta>>2]&4095](la,ia,f+33952+(jb<<13)|0)}}while(0);pa=(c[q>>2]|0)+((c[y>>2]|0)/2|0)+((Xa|0)/-2|0)|0;Ca=f+67072+(jb<<14)+(pa<<2)|0;Ba=c[v>>2]|0;za=c[u>>2]|0;if((Ba|0)>(za|0)){Oa=1<<za;qa=((c[x>>2]|0)-Oa|0)/2|0;Aa=f+67072+(jb<<14)+(qa+pa<<2)|0;pe[c[ga>>2]&1023](Aa,f+50336+(qa<<2)|0,c[f+67040+((c[s>>2]|0)-za<<2)>>2]|0,Aa,Oa);Aa=qa+Oa|0;nrc(f+67072+(jb<<14)+(Aa+pa<<2)|0,f+50336+(Aa<<2)|0,qa<<2)|0}else{pe[c[ga>>2]&1023](Ca,ia,c[f+67040+((c[s>>2]|0)-Ba<<2)>>2]|0,Ca,c[x>>2]|0)}Ca=c[x>>2]|0;Ba=f+67072+(jb<<14)+(Ca+pa<<2)|0;qa=f+50336+(Ca<<2)|0;Aa=c[v>>2]|0;Oa=c[t>>2]|0;if((Aa|0)>(Oa|0)){za=1<<Oa;Ya=(Ca-za|0)/2|0;Wa=(c[s>>2]|0)-Oa|0;Oa=Ya<<2;nrc(Ba|0,qa|0,Oa)|0;Va=Ya+Ca|0;mf[c[ha>>2]&2047](f+67072+(jb<<14)+(Va+pa<<2)|0,f+50336+(Va<<2)|0,c[f+67040+(Wa<<2)>>2]|0,za);mrc(f+67072+(jb<<14)+(za+pa+Va<<2)|0,0,Oa|0)|0}else{mf[c[ha>>2]&2047](Ba,qa,c[f+67040+((c[s>>2]|0)-Aa<<2)>>2]|0,Ca)}Ca=jb+1|0;Aa=c[z>>2]|0;if((Ca|0)<(c[Aa+416>>2]|0)){jb=Ca}else{cd=Aa;break}}}else{cd=Na}c[p>>2]=(c[p>>2]|0)+1;jb=(c[q>>2]|0)+(c[x>>2]|0)|0;c[q>>2]=jb;dd=c[y>>2]|0;if((jb|0)<(dd|0)){ka=jb}else{Ea=167;break}}if((Ea|0)==7){KIb(c[z>>2]|0,16,2117704,(ed=i,i=i+8|0,c[ed>>2]=(c[s>>2]|0)-Da,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==9){KIb(c[z>>2]|0,16,2635776,(ed=i,i=i+8|0,c[ed>>2]=Fa-Ga,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==13){KIb(c[z>>2]|0,16,2612168,(ed=i,i=i+8|0,c[ed>>2]=(c[s>>2]|0)-Ha,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==17){KIb(c[z>>2]|0,16,2585528,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==19){KIb(Ia,16,2564704,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==27){KIb(Ka,16,2546608,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==50){KIb(c[z>>2]|0,16,2528952,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==79){KIb(sb,16,2513776,(ed=i,i=i+1|0,i=i+7&-8,c[ed>>2]=0,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==80){KIb(sb,16,2500096,(ed=i,i=i+8|0,c[ed>>2]=ic,ed)|0);i=ed;fd=-1;i=l;return fd|0}else if((Ea|0)==167){if((c[cd+416>>2]|0)>0){gd=0;hd=dd}else{fd=0;i=l;return fd|0}while(1){dd=f+67072+(gd<<14)|0;nrc((c[h+(gd<<2)>>2]|0)+(j<<2)|0,dd|0,hd<<2)|0;cd=c[y>>2]|0;orc(dd|0,f+67072+(gd<<14)+(cd<<2)|0,cd<<2|0)|0;cd=gd+1|0;if((cd|0)>=(c[(c[z>>2]|0)+416>>2]|0)){fd=0;break}gd=cd;hd=c[y>>2]|0}i=l;return fd|0}return 0}function fhb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[b+60>>2]|0;c[e>>2]=b;f=b+416|0;g=c[f>>2]|0;if((g|0)>2){KIb(b,16,2564656,(h=i,i=i+16|0,c[h>>2]=g,c[h+8>>2]=2,h)|0);i=h;j=-22;i=d;return j|0}g=b+412|0;k=c[g>>2]|0;if((k|0)>48e3){KIb(b,16,2546568,(h=i,i=i+8|0,c[h>>2]=k,h)|0);i=h;j=-22;i=d;return j|0}k=b+72|0;l=c[k>>2]|0;if((l|0)<24e3){KIb(b,16,2528904,(h=i,i=i+8|0,c[h>>2]=l,h)|0);i=h;j=-22;i=d;return j|0}l=c[(c[b+12>>2]|0)+12>>2]|0;if((l|0)==86023){m=hJb(4)|0;c[b+100>>2]=4;n=m;y=0;a[n]=y;y=y>>8;a[n+1|0]=y;n=m+2|0;y=1;a[n]=y;y=y>>8;a[n+1|0]=y;o=m}else if((l|0)==86024){l=pJb(10)|0;c[b+100>>2]=10;m=l;y=0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=l+4|0;y=1;a[m]=y;y=y>>8;a[m+1|0]=y;o=l}else{KIb(0,0,2199416,(h=i,i=i+24|0,c[h>>2]=2612136,c[h+8>>2]=2141168,c[h+16>>2]=69,h)|0);i=h;Hd();return 0}c[b+96>>2]=o;c[e+60>>2]=1;c[e+52>>2]=0;c[e+56>>2]=0;if((c[f>>2]|0)==2){a[e+1136|0]=1}Wgb(b,1)|0;f=e+1104|0;if((c[f>>2]|0)>0){o=e+66720|0;h=e+1100|0;l=0;do{OPa(o+(l<<6)|0,1-l+(c[h>>2]|0)|0,0,1.0)|0;l=l+1|0;}while((l|0)<(c[f>>2]|0))}f=c[k>>2]|0;k=e+1096|0;e=c[k>>2]|0;l=Erc(e,(e|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[g>>2]<<3;g=Crc(l,G,f,(f|0)<0|0?-1:0)|0;f=g;c[b+432>>2]=(f|0)>16384?16384:f;f=c[k>>2]|0;c[b+116>>2]=f;c[b+424>>2]=f;j=0;i=d;return j|0}function ghb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0.0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;i=i+8|0;j=h|0;k=c[b+60>>2]|0;l=k;m=c[k+1100>>2]|0;c[k+1112>>2]=m;n=1<<m;m=k+1124|0;c[m>>2]=n;o=c[e+64>>2]|0;p=c[e+76>>2]|0;q=k+66720|0;r=c[k+67040>>2]|0;s=65536.0/+(n|0);t=b+416|0;if((c[t>>2]|0)>0){u=k+50336|0;v=k+67072|0;w=n<<2;x=k+159292|0;z=k+159308|0;A=u+(n<<2)|0;n=k+159284|0;B=k+66768|0;C=k+33952|0;D=u;E=0;do{F=v+(E<<14)|0;nrc(u|0,F|0,w)|0;H=F|0;xe[c[x>>2]&7](H,c[o+(E<<2)>>2]|0,s,p);mf[c[z>>2]&2047](A,H,r,p);mf[c[n>>2]&2047](H,H,r,p);ef[c[B>>2]&4095](q,C+(E<<13)|0,D);E=E+1|0;}while((E|0)<(c[t>>2]|0))}do{if((a[k+1136|0]|0)!=0){if((c[m>>2]|0)<=0){break}t=k+33952|0;E=k+42144|0;D=0;do{C=t+(D<<2)|0;s=+g[C>>2]*.5;q=E+(D<<2)|0;I=+g[q>>2]*.5;g[C>>2]=s+I;g[q>>2]=s-I;D=D+1|0;}while((D|0)<(c[m>>2]|0))}}while(0);m=d5a(b,d,32768,0)|0;if((m|0)<0){J=m;i=h;return J|0}m=k+33952|0;D=d+24|0;E=d+28|0;t=(hhb(l,m,c[D>>2]|0,c[E>>2]|0,64)|0)<1;q=t?64:128;t=q-32|0;C=(hhb(l,m,c[D>>2]|0,c[E>>2]|0,t)|0)<1;B=C?t:q;q=B-16|0;t=(hhb(l,m,c[D>>2]|0,c[E>>2]|0,q)|0)<1;C=t?q:B;B=C-8|0;q=(hhb(l,m,c[D>>2]|0,c[E>>2]|0,B)|0)<1;t=q?B:C;C=t-4|0;B=(hhb(l,m,c[D>>2]|0,c[E>>2]|0,C)|0)<1;q=B?C:t;t=q-2|0;C=(hhb(l,m,c[D>>2]|0,c[E>>2]|0,t)|0)<1;B=C?t:q;q=B-1|0;t=hhb(l,m,c[D>>2]|0,c[E>>2]|0,q)|0;C=(t|0)<1?q:B;B=(t|0)>0;if((C|0)<129&B){t=C;while(1){C=t+1|0;q=(hhb(l,m,c[D>>2]|0,c[E>>2]|0,t)|0)>0;if((C|0)<129&q){t=C}else{K=q;break}}}else{K=B}if(K){KIb(b,16,2240416,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;c[E>>2]=0;J=-22;i=h;return J|0}K=k+28|0;B=c[K>>2]|0;t=k+32|0;D=k+36|0;m=c[D>>2]|0;l=(m-(c[t>>2]|0)<<3)+(32-B)|0;if((l&7|0)!=0){KIb(0,0,2199416,(L=i,i=i+24|0,c[L>>2]=2167824,c[L+8>>2]=2141168,c[L+16>>2]=384,L)|0);i=L;Hd();return 0}q=b+432|0;C=c[q>>2]|0;p=(l+7|0)/8|0;l=C-p|0;if(!((l|0)>-1)){KIb(0,0,2199416,(L=i,i=i+24|0,c[L>>2]=2117664,c[L+8>>2]=2141168,c[L+16>>2]=386,L)|0);i=L;Hd();return 0}r=k+24|0;if((C|0)==(p|0)){M=B;N=m}else{p=l;l=m;m=c[r>>2]|0;C=B;while(1){B=p-1|0;if((C|0)>8){O=C-8|0;P=m<<8|78;Q=l}else{k=l;y=je(78>>>((8-C|0)>>>0)|m<<C|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=(c[D>>2]|0)+4|0;c[D>>2]=k;O=C+24|0;P=78;Q=k}c[r>>2]=P;c[K>>2]=O;if((B|0)==0){M=O;N=Q;break}else{p=B;l=Q;m=P;C=O}}}if((M|0)<32){O=c[r>>2]<<M;c[r>>2]=O;M=O>>>24&255;O=N;while(1){c[D>>2]=O+1;a[O]=M;C=c[r>>2]|0;c[r>>2]=C<<8;P=(c[K>>2]|0)+8|0;c[K>>2]=P;if((P|0)>=32){break}M=C>>>16&255;O=c[D>>2]|0}R=c[D>>2]|0}else{R=N}c[K>>2]=32;c[r>>2]=0;r=R-(c[t>>2]|0)|0;if((r|0)!=(c[q>>2]|0)){KIb(0,0,2199416,(L=i,i=i+24|0,c[L>>2]=2635688,c[L+8>>2]=2141168,c[L+16>>2]=391,L)|0);i=L;Hd();return 0}L=e+136|0;e=c[L>>2]|0;t=c[L+4>>2]|0;if((e|0)==0&(t|0)==(-2147483648|0)){S=r}else{r=c[b+116>>2]|0;c[j>>2]=1;c[j+4>>2]=c[b+412>>2];L=XIb(r,(r|0)<0|0?-1:0,j,b+104|0)|0;b=xrc(e,t,L,G)|0;L=d+8|0;c[L>>2]=b;c[L+4>>2]=G;S=c[q>>2]|0}c[E>>2]=S;c[f>>2]=1;J=0;i=h;return J|0}function hhb(b,f,h,j,k){b=b|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0.0,D=0.0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0.0,R=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;l=i;i=i+8|0;m=l|0;n=b+24|0;o=(j|0)<0;p=o?0:h;h=o?0:j;c[b+44>>2]=h<<3;j=b+32|0;c[j>>2]=p;c[b+40>>2]=p+h;h=b+36|0;c[h>>2]=p;p=b+28|0;c[p>>2]=32;o=n|0;c[o>>2]=0;if((c[b+52>>2]|0)!=0){KIb(0,0,2199416,(q=i,i=i+24|0,c[q>>2]=2612136,c[q+8>>2]=2141168,c[q+16>>2]=332,q)|0);i=q;Hd();return 0}if((c[b+56>>2]|0)!=0){KIb(0,0,2199416,(q=i,i=i+24|0,c[q>>2]=2612136,c[q+8>>2]=2141168,c[q+16>>2]=171,q)|0);i=q;Hd();return 0}r=b+1100|0;s=c[r>>2]|0;c[b+1116>>2]=s;c[b+1120>>2]=s;t=b+1112|0;c[t>>2]=s;u=1<<s;s=b+1124|0;c[s>>2]=u;v=b+384|0;w=(c[b+388>>2]|0)-(c[v>>2]|0)|0;x=b|0;z=c[x>>2]|0;A=c[z+416>>2]|0;if((A|0)>0){B=0;do{c[m+(B<<2)>>2]=w;B=B+1|0;}while((B|0)<(A|0))}B=(u|0)/2|0;C=1.0/+(B|0);u=b+48|0;if((c[u>>2]|0)==1){D=C*+S(+(B|0))}else{D=C}if((A|0)==2){c[b+24>>2]=(a[b+1136|0]|0)!=0;c[p>>2]=31;E=c[z+416>>2]|0}else{E=A}a:do{if((E|0)>0){A=0;do{a[b+1137+A|0]=1;z=c[s>>2]|0;B=b+1152+(A<<13)+(z<<2)|0;if((z|0)>0){z=b+112+(((c[r>>2]|0)-(c[t>>2]|0)|0)*50|0)|0;w=b+1152+(A<<13)|0;C=0.0;F=1512760;while(1){G=+T(+10.0,+(+(c[F>>2]|0)*.0625));H=e[z>>1]|0;I=w;J=H;while(1){g[I>>2]=G;K=J-1|0;if((K|0)==0){break}else{I=I+4|0;J=K}}L=C>G?C:G;J=w+(H<<2)|0;if(J>>>0<B>>>0){z=z+2|0;w=J;C=L;F=F+4|0}else{M=L;break}}}else{M=0.0}g[b+17536+(A<<2)>>2]=M;A=A+1|0;N=c[x>>2]|0;O=c[N+416>>2]|0;}while((A|0)<(O|0));if((O|0)<=0){break}C=+(k|0)*.05;A=0;F=N;b:while(1){do{if((a[b+1137+A|0]|0)==0){P=F}else{L=+T(+10.0,+C);Q=D*(L/+g[b+17536+(A<<2)>>2]);w=c[m+(A<<2)>>2]|0;if((w|0)<=0){P=F;break}z=0;B=f+(A<<13)+(c[v>>2]<<2)|0;while(1){L=+g[B>>2]/(Q*+g[b+1152+(A<<13)+(z<<2)>>2]);if(L<-32768.0|L>32767.0){R=2147483647;U=117;break b}g[b+17544+(A<<13)+(z<<2)>>2]=+(Lc(+L)|0);J=z+1|0;if((J|0)<(w|0)){z=J;B=B+4|0}else{break}}P=c[x>>2]|0}}while(0);B=A+1|0;V=c[P+416>>2]|0;if((B|0)<(V|0)){A=B;F=P}else{break}}if((U|0)==117){i=l;return R|0}if((V|0)<=0){break}F=b+24|0;A=0;B=0;z=c[F>>2]|0;w=c[p>>2]|0;H=P;while(1){J=d[b+1137+A|0]|0;if((w|0)>1){W=w-1|0;X=J|z<<1;Y=H}else{I=je(J>>>((1-w|0)>>>0)|z<<w|0)|0;K=c[h>>2]|0;y=I;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;W=w+31|0;X=J;Y=c[x>>2]|0}c[F>>2]=X;c[p>>2]=W;Z=J|B;J=A+1|0;if((J|0)<(c[Y+416>>2]|0)){A=J;B=Z;z=X;w=W;H=Y}else{break}}if((Z|0)==0){break}H=k-1|0;w=(W|0)>7;if((H|0)>126){z=k-128|0;B=H;A=X;J=W;K=w;while(1){if(K){_=J-7|0;$=A<<7|127}else{I=je(127>>>((7-J|0)>>>0)|A<<J|0)|0;aa=c[h>>2]|0;y=I;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;_=J+25|0;$=127}c[o>>2]=$;c[p>>2]=_;aa=B-127|0;ba=(_|0)>7;if((aa|0)>126){B=aa;A=$;J=_;K=ba}else{break}}K=(z>>>0)%127|0;if(ba){ca=_;da=$;ea=K;U=42}else{fa=_;ga=$;ha=K;U=43}}else{if(w){ca=W;da=X;ea=H;U=42}else{fa=W;ga=X;ha=H;U=43}}if((U|0)==42){ia=ca-7|0;ja=da<<7|ea}else if((U|0)==43){K=je(ha>>>((7-fa|0)>>>0)|ga<<fa|0)|0;J=c[h>>2]|0;y=K;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;ia=fa+25|0;ja=ha}c[o>>2]=ja;c[p>>2]=ia;J=Ygb(k)|0;do{if((c[b+64>>2]|0)!=0){K=c[x>>2]|0;if((c[K+416>>2]|0)<=0){break}A=b+408|0;B=0;aa=K;while(1){do{if((a[b+1137+B|0]|0)==0){ka=aa}else{K=c[A>>2]|0;if((K|0)>0){la=0}else{ka=aa;break}do{c[b+768+(B<<6)+(la<<2)>>2]=0;I=c[o>>2]|0;ma=c[p>>2]|0;if((ma|0)>1){na=ma-1|0;oa=I<<1}else{pa=je(I<<ma|0)|0;I=c[h>>2]|0;y=pa;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;na=ma+31|0;oa=0}c[o>>2]=oa;c[p>>2]=na;la=la+1|0;}while((la|0)<(K|0));ka=c[x>>2]|0}}while(0);K=B+1|0;if((K|0)<(c[ka+416>>2]|0)){B=K;aa=ka}else{break}}}}while(0);if((c[t>>2]|0)!=(c[r>>2]|0)){H=c[o>>2]|0;w=c[p>>2]|0;if((w|0)>1){qa=w-1|0;ra=H<<1|1}else{z=je(1>>>((1-w|0)>>>0)|H<<w|0)|0;H=c[h>>2]|0;y=z;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;qa=w+31|0;ra=1}c[o>>2]=ra;c[p>>2]=qa}if((c[(c[x>>2]|0)+416>>2]|0)<=0){break}w=b+60|0;H=0;c:do{do{if((a[b+1137+H|0]|0)!=0){if((c[w>>2]|0)==0){U=78;break c}z=(c[r>>2]|0)-(c[t>>2]|0)|0;aa=b+112+(z*50|0)|0;B=b+1152+(H<<13)+(c[s>>2]<<2)|0;if((c[u>>2]|0)==1){A=c[F>>2]|0;K=c[p>>2]|0;if((K|0)>5){sa=K-5|0;ta=A<<5|10}else{ma=je(10>>>((5-K|0)>>>0)|A<<K|0)|0;A=c[h>>2]|0;y=ma;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;sa=K+27|0;ta=10}c[F>>2]=ta;c[p>>2]=sa;ua=1512764;va=20;wa=b+112+(z*50|0)+2|0;xa=b+1152+(H<<13)+(e[aa>>1]<<2)|0}else{ua=1512760;va=36;wa=aa;xa=b+1152+(H<<13)|0}if(!(xa>>>0<B>>>0)){break}aa=xa;z=wa;K=va;A=ua;ma=c[F>>2]|0;I=c[p>>2]|0;while(1){pa=c[A>>2]|0;ya=pa-K+60|0;za=d[1446024+ya|0]|0;Aa=c[1445536+(ya<<2)>>2]|0;if((I|0)>(za|0)){Ba=I;Ca=ma<<za|Aa}else{ya=je(Aa>>>((za-I|0)>>>0)|ma<<I|0)|0;Da=c[h>>2]|0;y=ya;a[Da]=y;y=y>>8;a[Da+1|0]=y;y=y>>8;a[Da+2|0]=y;y=y>>8;a[Da+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ba=I+32|0;Ca=Aa}Aa=Ba-za|0;c[F>>2]=Ca;c[p>>2]=Aa;za=aa+(e[z>>1]<<2)|0;if(za>>>0<B>>>0){aa=za;z=z+2|0;K=pa;A=A+4|0;ma=Ca;I=Aa}else{break}}}}while(0);H=H+1|0;Ea=c[(c[x>>2]|0)+416>>2]|0;}while((H|0)<(Ea|0));if((U|0)==78){KIb(0,0,2199416,(q=i,i=i+24|0,c[q>>2]=2612136,c[q+8>>2]=2141168,c[q+16>>2]=274,q)|0);i=q;Hd();return 0}if((Ea|0)<=0){break}H=b+1136|0;F=1<<J;w=32-J|0;I=0;d:while(1){do{if((a[b+1137+I|0]|0)!=0){if((I|0)==1){Fa=(a[H]|0)!=0|0}else{Fa=0}ma=c[m+(I<<2)>>2]|0;A=b+17544+(I<<13)+(ma<<2)|0;if((ma|0)<=0){break}ma=b+1088+(Fa<<2)|0;K=b+1080+(Fa<<2)|0;z=0;aa=b+17544+(I<<13)|0;while(1){C=+g[aa>>2];if(C!=0.0){B=~~C;Aa=(B|0)>-1?B:-B|0;pa=c[ma>>2]|0;do{if((Aa|0)>(c[pa+4>>2]|0)){Ga=0}else{za=Aa-1|0;if((z|0)>=(e[(c[pa+16>>2]|0)+(za<<1)>>1]|0)){Ga=0;break}Ga=(e[(c[K>>2]|0)+(za<<1)>>1]|0)+z|0}}while(0);za=d[(c[pa+12>>2]|0)+Ga|0]|0;Da=c[(c[pa+8>>2]|0)+(Ga<<2)>>2]|0;ya=c[o>>2]|0;Ha=c[p>>2]|0;if((Ha|0)>(za|0)){Ia=Ha-za|0;Ja=ya<<za|Da}else{Ka=je(Da>>>((za-Ha|0)>>>0)|ya<<Ha|0)|0;ya=c[h>>2]|0;y=Ka;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ia=32-za+Ha|0;Ja=Da}c[o>>2]=Ja;c[p>>2]=Ia;if((Ga|0)==0){if((F|0)<=(Aa|0)){R=2147483647;break d}if((Ia|0)>(J|0)){La=Ia-J|0;Ma=Ja<<J|Aa}else{Da=je(Aa>>>((J-Ia|0)>>>0)|Ja<<Ia|0)|0;Ha=c[h>>2]|0;y=Da;a[Ha]=y;y=y>>8;a[Ha+1|0]=y;y=y>>8;a[Ha+2|0]=y;y=y>>8;a[Ha+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;La=w+Ia|0;Ma=Aa}c[o>>2]=Ma;c[p>>2]=La;Ha=c[r>>2]|0;if((La|0)>(Ha|0)){Na=La;Oa=Ma<<Ha|z}else{Da=je(z>>>((Ha-La|0)>>>0)|Ma<<La|0)|0;za=c[h>>2]|0;y=Da;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Na=La+32|0;Oa=z}za=Na-Ha|0;c[o>>2]=Oa;c[p>>2]=za;Pa=za;Qa=Oa}else{Pa=Ia;Qa=Ja}za=B>>>31;if((Pa|0)>1){Ra=Pa-1|0;Sa=Qa<<1|za}else{Ha=je(za>>>((1-Pa|0)>>>0)|Qa<<Pa|0)|0;Da=c[h>>2]|0;y=Ha;a[Da]=y;y=y>>8;a[Da+1|0]=y;y=y>>8;a[Da+2|0]=y;y=y>>8;a[Da+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ra=Pa+31|0;Sa=za}c[o>>2]=Sa;c[p>>2]=Ra;Ta=0}else{Ta=z+1|0}za=aa+4|0;if(za>>>0<A>>>0){z=Ta;aa=za}else{break}}if((Ta|0)==0){break}aa=c[ma>>2]|0;z=d[(c[aa+12>>2]|0)+1|0]|0;A=c[(c[aa+8>>2]|0)+4>>2]|0;aa=c[o>>2]|0;K=c[p>>2]|0;if((K|0)>(z|0)){Ua=K-z|0;Va=aa<<z|A}else{za=je(A>>>((z-K|0)>>>0)|aa<<K|0)|0;aa=c[h>>2]|0;y=za;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ua=32-z+K|0;Va=A}c[o>>2]=Va;c[p>>2]=Ua}}while(0);do{if((c[u>>2]|0)==1){if((c[(c[x>>2]|0)+416>>2]|0)<=1){break}Y2(n)}}while(0);I=I+1|0;if((I|0)>=(c[(c[x>>2]|0)+416>>2]|0)){break a}}i=l;return R|0}}while(0);Y2(n);R=((32-(c[p>>2]|0)+((c[h>>2]|0)-(c[j>>2]|0)<<3)|0)/8|0)-(c[(c[x>>2]|0)+432>>2]|0)|0;i=l;return R|0}function ihb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;g=c[e+60>>2]|0;h=c[e+96>>2]|0;j=e+432|0;if((c[j>>2]|0)==0){KIb(e,16,2500072,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-22;i=f;return l|0}c[g>>2]=e;m=g+8|0;c[g+32812>>2]=262144;c[g+32800>>2]=m;c[g+32808>>2]=g+32776;c[g+32804>>2]=m;c[g+32796>>2]=32;c[g+32792>>2]=0;if((c[e+100>>2]|0)<=17){QIb(e,2466944,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=f;return l|0}m=h+14|0;n=(d[m]|d[m+1|0]<<8)<<16>>16&65535;m=g+32816|0;c[m>>2]=n;o=h+2|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=h;h=(d[o]|d[o+1|0]<<8)<<16>>16;a[g+32828|0]=h;o=h&255;if((o<<16>>16|0)==16){c[e+420>>2]=6;h=c[j>>2]|0;j=h>>>0>65535>>>0;q=j?h>>>16:h;h=j?16:0;if((q&65280|0)==0){r=h;s=q}else{r=h|8;s=q>>>8}b[g+32832>>1]=r+4+(d[1359664+s|0]|0);a[g+32981|0]=1;a[g+32884|0]=1;c[g+32820>>2]=n&64;s=1<<(ahb(c[e+412>>2]|0,3,n)|0);n=s&65535;b[g+32830>>1]=n;if(!((s&65535)>>>0<16385>>>0)){KIb(0,0,2457144,(k=i,i=i+24|0,c[k>>2]=2440120,c[k+8>>2]=2428960,c[k+16>>2]=225,k)|0);i=k;Hd();return 0}s=e+416|0;r=c[s>>2]|0;if((r|0)>0){q=g+32996|0;h=0;do{b[q+(h*144|0)>>1]=n;h=h+1|0;}while((h|0)<(r|0))}r=c[m>>2]|0;m=r>>>3&7;h=1<<m;q=h&255;a[g+32836|0]=q;a[g+32838|0]=0;a[g+32837|0]=(a[1359664+m|0]|0)+1;b[g+32840>>1]=(n&65535)/(h&65535&255)|0;c[g+32824>>2]=r&128;c[g+226880>>2]=r&256;if((q&255)>>>0>32>>>0){KIb(e,16,2418408,(k=i,i=i+8|0,c[k>>2]=h&255,k)|0);i=k;l=-1094995529;i=f;return l|0}h=c[s>>2]&255;a[g+32834|0]=h;s=g+32835|0;a[s]=-1;if((p&8|0)!=0){if((p&1|0)==0){t=-1}else{a[s]=0;t=0}if((p&2|0)==0){u=t}else{q=t+1&255;a[s]=q;u=q}if((p&4|0)==0){v=u}else{q=u+1&255;a[s]=q;v=q}a[s]=v+1}if(h<<24>>24<0){KIb(e,16,2409520,(k=i,i=i+8|0,c[k>>2]=h<<24>>24,k)|0);i=k;l=-1094995529;i=f;return l|0}if(h<<24>>24>8){QIb(e,2401792,(k=i,i=i+8|0,c[k>>2]=8,k)|0);i=k;l=-1163346256;i=f;return l|0}h=UHb()|0;c[g+4>>2]=h;if((h|0)==0){l=-12;i=f;return l|0}h=e+448|0;c[h>>2]=p;c[h+4>>2]=0;l=0;i=f;return l|0}else if((o<<16>>16|0)==24){c[e+420>>2]=7;RIb(e,2487440,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=f;return l|0}else{KIb(e,16,2476144,(k=i,i=i+8|0,c[k>>2]=o&65535,k)|0);i=k;l=-1094995529;i=f;return l|0}return 0}function jhb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;k=c[b+60>>2]|0;l=k;m=k+32844|0;n=m;o=c[h+24>>2]|0;p=h+28|0;h=c[p>>2]|0;q=k+4|0;c[(c[q>>2]|0)+76>>2]=0;r=k+32885|0;a:do{if((a[r]|0)==0){if((a[k+32884|0]|0)!=0){s=3;break}t=(c[p>>2]|0)-(c[k+32864>>2]|0)<<3;c[k+32912>>2]=t;u=t>>>0>2147483639>>>0|(o|0)==0;v=u?0:o;w=u?0:t;c[m>>2]=v;c[k+32856>>2]=w;u=w+8|0;c[k+32860>>2]=u;c[k+32848>>2]=v+(w>>3);w=d[k+32868|0]|0;x=u>>>0>w>>>0?w:u;c[k+32852>>2]=x;do{if((c[k+32820>>2]|0)==0){if((c[k+32872>>2]|0)<=(c[k+32900>>2]|0)){break}u=(nhb(l)|0)==0|0;a[r]=u;y=u;s=26;break a}else{u=t-x|0;w=e[k+32832>>1]|0;if((u|0)<=(w|0)){break}z=v+(x>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>((32-w|0)>>>0);if((A|0)==0|(A|0)>(u|0)){break}mhb(l,n,A,0);A=(nhb(l)|0)==0|0;a[r]=A;y=A;s=26;break a}}while(0);a[r]=1;B=k+32884|0;s=28}else{s=3}}while(0);if((s|0)==3){a[r]=0;if((h|0)==0){C=0;i=j;return C|0}p=b+432|0;x=c[p>>2]|0;if((h|0)<(x|0)){KIb(b,16,2441128,(D=i,i=i+8|0,c[D>>2]=h,D)|0);i=D;C=-1094995529;i=j;return C|0}c[k+32864>>2]=h-x;x=c[p>>2]<<3;p=k+32912|0;c[p>>2]=x;h=x>>>0>2147483639>>>0|(o|0)==0;v=h?0:o;o=h?0:x;x=m;c[x>>2]=v;c[k+32856>>2]=o;m=o+8|0;h=k+32860|0;c[h>>2]=m;c[k+32848>>2]=v+(o>>3);o=k+32852|0;c[o>>2]=0;t=v;A=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>4&15;t=m>>>0>4>>>0?5:m|1;u=m>>>0>t>>>0?t:m;c[o>>2]=u;t=d[v+(u>>>3)|0]|0;w=((u|0)<(m|0))+u|0;c[o>>2]=w;if((128>>>((u&7)>>>0)&t|0)==0){E=w;F=m;G=v}else{QIb(b,2353232,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;E=c[o>>2]|0;F=c[h>>2]|0;G=c[x>>2]|0}x=e[k+32832>>1]|0;h=G+(E>>>3)|0;G=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(E&7)>>>((32-x|0)>>>0);h=E+x|0;c[o>>2]=F>>>0>h>>>0?h:F;F=k+32884|0;h=k+32869|0;do{if((a[F]|0)==0){x=d[h]|0;if((x+1&15|0)==(A|0)){break}a[F]=1;KIb(b,16,2291200,(D=i,i=i+16|0,c[D>>2]=x,c[D+8>>2]=A,D)|0);i=D}}while(0);a[h]=A;do{if((G|0)>0){A=(c[p>>2]|0)-(c[o>>2]|0)|0;if((G|0)>=(A|0)){a[r]=1;mhb(l,n,A,1);s=16;break}mhb(l,n,G,1);if((a[F]|0)!=0){s=17;break}nhb(l)|0;s=16}else{s=16}}while(0);if((s|0)==16){if((a[F]|0)!=0){s=17}}if((s|0)==17){c[k+32872>>2]=0;a[F]=0;F=k+8|0;c[k+32812>>2]=262144;c[k+32800>>2]=F;c[k+32808>>2]=k+32776;c[k+32804>>2]=F;c[k+32796>>2]=32;c[k+32792>>2]=0}y=a[r]|0;s=26}do{if((s|0)==26){r=k+32884|0;if(y<<24>>24==0){H=r;break}F=k+32884|0;if((a[r]|0)==0){B=F;s=28}else{H=F}}}while(0);do{if((s|0)==28){y=(c[k+32912>>2]|0)-(c[k+32852>>2]|0)|0;if((y|0)<=0){H=B;break}mhb(l,n,y,0);H=B}}while(0);B=c[q>>2]|0;c[g>>2]=(c[B+76>>2]|0)>0;aIb(f,B);B=c[k+32852>>2]|0;a[k+32868|0]=B&7;if((a[H]|0)!=0){C=-1094995529;i=j;return C|0}C=B>>3;i=j;return C|0}function khb(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function lhb(b){b=b|0;var d=0;d=c[b+60>>2]|0;a[d+32884|0]=1;a[d+32885|0]=0;c[d+32872>>2]=0;c[d+32876>>2]=0;c[d+32864>>2]=0;c[d+41088>>2]=0;c[(c[d+4>>2]|0)+76>>2]=0;b=d+8|0;c[d+32812>>2]=262144;c[d+32800>>2]=b;c[d+32808>>2]=d+32776;c[d+32804>>2]=b;c[d+32796>>2]=32;c[d+32792>>2]=0;return}function mhb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;j=(g|0)!=0;if(j){k=c[b+32872>>2]|0}else{g=c[e+8>>2]&7;c[b+32876>>2]=g;c[b+32872>>2]=g;l=b+8|0;c[b+32812>>2]=262144;c[b+32800>>2]=l;c[b+32808>>2]=b+32776;c[b+32804>>2]=l;c[b+32796>>2]=32;c[b+32792>>2]=0;k=g}g=b+32872|0;l=k+f|0;do{if((f|0)>=1){if((l+8>>3|0)>32768){break}c[g>>2]=l;if(j){k=e+8|0;m=c[k>>2]|0;n=m&7;o=8-n|0;p=(o|0)>(f|0)?f:o;o=b+32792|0;q=e+16|0;r=c[q>>2]|0;s=e|0;t=c[s>>2]|0;u=t+(m>>>3)|0;v=32-p|0;w=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<n>>>(v>>>0);n=p+m|0;c[k>>2]=r>>>0>n>>>0?n:r;r=o|0;n=c[r>>2]|0;m=b+32796|0;u=c[m>>2]|0;if((u|0)>(p|0)){x=u-p|0;z=n<<p|w;A=t}else{t=je(w>>>((p-u|0)>>>0)|n<<u|0)|0;n=b+32804|0;B=c[n>>2]|0;y=t;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;x=v+u|0;z=w;A=c[s>>2]|0}c[r>>2]=z;c[m>>2]=x;m=f-p|0;_2(o,A+(c[k>>2]>>3)|0,m);C=m;D=q}else{_2(b+32792|0,(c[e>>2]|0)+(c[e+8>>2]>>3)|0,l);C=f;D=e+16|0}q=e+8|0;m=c[q>>2]|0;k=-m|0;o=(c[D>>2]|0)-m|0;if((C|0)<(k|0)){E=k}else{E=(o|0)<(C|0)?o:C}c[q>>2]=E+m;m=c[b+32792>>2]|0;q=m;o=c[b+32796>>2]|0;if((o|0)<32){k=m<<o;q=k;m=k>>>24&255;k=o;o=c[b+32804>>2]|0;while(1){a[o]=m;p=q;q=p<<8;r=k+8|0;if((r|0)<32){m=p>>>16&255;k=r;o=o+1|0}else{break}}}q=0;o=b+8|0;k=c[g>>2]|0;m=k>>>0>2147483639>>>0|(o|0)==0;r=m?0:o;o=m?0:k;c[b+32892>>2]=r;c[b+32904>>2]=o;k=o+8|0;c[b+32908>>2]=k;c[b+32896>>2]=r+(o+7>>3);o=c[b+32876>>2]|0;c[b+32900>>2]=k>>>0>o>>>0?o:k;i=h;return}}while(0);QIb(c[b>>2]|0,2513752,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;a[b+32884|0]=1;i=h;return}function nhb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0;g=i;i=i+56|0;h=g|0;j=g+16|0;k=g+24|0;l=k;m=f+32892|0;n=f+32830|0;o=f+4|0;p=c[o>>2]|0;c[p+76>>2]=e[n>>1]|0;q=f|0;r=M4a(c[q>>2]|0,p,0)|0;if((r|0)<0){a[f+32884|0]=1;s=r;i=g;return s|0}r=f+32834|0;p=a[r]|0;if(p<<24>>24>0){t=0;while(1){c[f+32916+(t<<2)>>2]=c[(c[(c[o>>2]|0)+64>>2]|0)+(t<<2)>>2];c[f+32948+(t<<2)>>2]=c[(c[(c[o>>2]|0)+64>>2]|0)+(t<<2)>>2];u=t+1|0;v=a[r]|0;if((u|0)<(v<<24>>24|0)){t=u}else{w=v;break}}}else{w=p}p=f+32820|0;if((c[p>>2]|0)==0){x=0}else{t=e[f+32832>>1]|0;v=f+32900|0;u=c[v>>2]|0;y=c[f+32908>>2]|0;z=(c[m>>2]|0)+(u>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(u&7)>>>((32-t|0)>>>0);z=u+t|0;c[v>>2]=y>>>0>z>>>0?z:y;x=A}mrc(h|0,0,16)|0;A=w<<24>>24;if(w<<24>>24>0){y=0;do{a[f+32996+(y*144|0)+3|0]=0;y=y+1|0;}while((y|0)<(A|0))}y=f+32900|0;z=c[y>>2]|0;v=f+32892|0;t=d[(c[v>>2]|0)+(z>>>3)|0]|0;u=f+32908|0;c[y>>2]=((z|0)<(c[u>>2]|0))+z;B=f+32836|0;C=(t&128>>>((z&7)>>>0)|0)!=0|(a[B]|0)==1;z=f+32840|0;t=A;A=0;D=w;a:while(1){if(!(D<<24>>24>0)){E=24;break}w=D<<24>>24;if(C|(t|0)==1){F=0;H=0;while(1){I=j+F|0;if((e[h+(F<<1)>>1]|0)==(A|0)){a[I]=1;J=H|1}else{a[I]=0;J=H}I=F+1|0;if((I|0)<(w|0)){F=I;H=J}else{K=J;break}}}else{H=0;F=0;while(1){if((e[h+(H<<1)>>1]|0)==(A|0)){if((A|0)==((e[n>>1]|0)-(e[z>>1]|0)|0)){a[j+H|0]=1;L=1}else{I=c[y>>2]|0;M=d[(c[v>>2]|0)+(I>>>3)|0]<<(I&7)>>>7;c[y>>2]=((I|0)<(c[u>>2]|0))+I;I=M&1;a[j+H|0]=I;L=I&255}N=L|F}else{a[j+H|0]=0;N=F}I=H+1|0;if((I|0)<(w|0)){H=I;F=N}else{K=N;break}}}if((K|0)==0){E=24;break}F=b[n>>1]|0;H=F&65535;w=e[z>>1]|0;if((H-w|0)==(A|0)){O=w}else{I=(d[B]|0)-1|0;M=I>>>0>65535>>>0;P=M?I>>>16:I;I=M?16:0;if((P&65280|0)==0){Q=I;R=P}else{Q=I|8;R=P>>>8}P=(d[1359664+R|0]|0)+Q|0;I=c[y>>2]|0;M=c[u>>2]|0;S=(c[v>>2]|0)+(I>>>3)|0;T=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(I&7)>>>((31-P|0)>>>0);S=I+1+P|0;c[y>>2]=M>>>0>S>>>0?S:M;U=ca(T+1|0,w)|0;if((U|0)<(w|0)|(U|0)>(H|0)){E=29;break}else{O=U}}if((O|0)<1){break}H=O&65535;w=O+A|0;T=0;M=t;S=F;F=D;while(1){do{if((a[j+T|0]|0)==0){P=e[h+(T<<1)>>1]|0;if((P|0)>(w|0)){V=M;W=w;X=S;Y=F;break}I=(P|0)<(w|0);V=I?1:M+1|0;W=I?P:w;X=S;Y=F}else{P=f+32996+(T*144|0)+3|0;I=a[P]|0;if((I&255)>>>0>31>>>0){E=34;break a}b[f+32996+(T*144|0)+4+((I&255)<<1)>>1]=H;I=h+(T<<1)|0;Z=(e[I>>1]|0)+O|0;_=Z&65535;b[I>>1]=_;a[P]=(a[P]|0)+1;$=b[n>>1]|0;if((_&65535)>>>0>($&65535)>>>0){E=37;break a}V=M;W=w;X=$;Y=a[r]|0}}while(0);_=T+1|0;if((_|0)<(Y<<24>>24|0)){w=W;T=_;M=V;S=X;F=Y}else{break}}if((W|0)<(X&65535|0)){t=V;A=W;D=Y}else{E=42;break}}if((E|0)==24){KIb(c[q>>2]|0,16,2585480,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==29){KIb(c[q>>2]|0,16,2528872,(aa=i,i=i+8|0,c[aa>>2]=U,aa)|0);i=aa}else if((E|0)==34){KIb(c[q>>2]|0,16,2564616,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==37){KIb(c[q>>2]|0,16,2546512,(aa=i,i=i+16|0,c[aa>>2]=Z&65535,c[aa+8>>2]=$&65535,aa)|0);i=aa}else if((E|0)==42){if(Y<<24>>24>0){$=0;Z=Y;while(1){U=f+32996+($*144|0)+3|0;if((a[U]|0)==0){ba=Z}else{D=0;W=0;do{b[f+32996+($*144|0)+68+(D<<1)>>1]=W;W=(e[f+32996+($*144|0)+4+(D<<1)>>1]|0)+W|0;D=D+1|0;}while((D|0)<(d[U]|0));ba=a[r]|0}U=$+1|0;if((U|0)<(ba<<24>>24|0)){$=U;Z=ba}else{da=ba;break}}}else{da=Y}Y=c[y>>2]|0;if((c[f+32824>>2]|0)==0){ea=Y;fa=c[m>>2]|0;ga=c[u>>2]|0}else{ba=c[u>>2]|0;Z=c[m>>2]|0;$=Z+(Y>>>3)|0;U=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(Y&7)>>>24;$=Y+8|0;Y=ba>>>0>$>>>0?$:ba;c[y>>2]=Y;a[f+32980|0]=U;ea=Y;fa=Z;ga=ba}ba=m|0;m=d[fa+(ea>>>3)|0]|0;Z=((ea|0)<(ga|0))+ea|0;c[y>>2]=Z;do{if((m&128>>>((ea&7)>>>0)|0)==0){ha=Z}else{Y=d[fa+(Z>>>3)|0]|0;U=((Z|0)<(ga|0))+Z|0;c[y>>2]=U;if((Y&128>>>((Z&7)>>>0)|0)==0){ia=U}else{Y=e[n>>1]|0;$=Y<<1;D=$>>>0>65535>>>0;W=D?Y>>>15:$;$=D?16:0;if((W&65280|0)==0){ja=$;ka=W}else{ja=$|8;ka=W>>>8}W=(d[1359664+ka|0]|0)+ja+U|0;U=ga>>>0>W>>>0?W:ga;c[y>>2]=U;ia=U}U=d[fa+(ia>>>3)|0]|0;W=((ia|0)<(ga|0))+ia|0;c[y>>2]=W;if((U&128>>>((ia&7)>>>0)|0)==0){ha=W;break}U=e[n>>1]|0;$=U<<1;D=$>>>0>65535>>>0;Y=D?U>>>15:$;$=D?16:0;if((Y&65280|0)==0){la=$;ma=Y}else{la=$|8;ma=Y>>>8}Y=(d[1359664+ma|0]|0)+la+W|0;W=ga>>>0>Y>>>0?Y:ga;c[y>>2]=W;ha=W}}while(0);ga=f+32982|0;a[ga]=0;if(da<<24>>24>0){la=da<<24>>24;ma=0;do{b[f+32996+(ma*144|0)+134>>1]=0;a[f+32996+(ma*144|0)+132|0]=0;ma=ma+1|0;}while((ma|0)<(la|0))}la=f+33130|0;ma=f+32880|0;ia=f+227012|0;fa=f+41088|0;ja=f+32828|0;ka=f+34151|0;Z=f+34150|0;ea=f+34149|0;m=f+41084|0;W=f+34154|0;Y=f+34153|0;$=f+226884|0;D=f+226888|0;U=f+34800|0;A=f+34801|0;V=f+41076|0;t=f+39026|0;X=f+40050|0;O=f+32904|0;h=f+41080|0;j=f+226880|0;Q=f+34152|0;R=f+752616|0;B=f+752620|0;z=f+752624|0;K=f+751336|0;N=f+34160|0;L=f+34802|0;J=f+34148|0;C=f+32986|0;F=da;da=ha;b:while(1){ha=b[la>>1]|0;na=ha&65535;S=e[n>>1]|0;M=F<<24>>24;T=ca(M,S)|0;c[ma>>2]=da;c:do{if(F<<24>>24>0){w=0;H=S;_=S;P=ha;while(1){I=P&65535;if((_|0)>(I|0)){oa=I;pa=e[f+32996+(w*144|0)+4+(d[f+32996+(w*144|0)+132|0]<<1)>>1]|0}else{oa=_;pa=H}I=w+1|0;if((I|0)>=(M|0)){break}w=I;H=pa;_=oa;P=b[f+32996+(I*144|0)+134>>1]|0}a[C]=0;P=0;_=T;H=F;w=ha;while(1){I=f+32996+(P*144|0)+134|0;qa=w&65535;ra=_-qa|0;do{if((oa|0)==(qa|0)){sa=b[f+32996+(P*144|0)+4+(d[f+32996+(P*144|0)+132|0]<<1)>>1]|0;if((pa|0)!=(sa&65535|0)){ta=ra;ua=H;break}b[I>>1]=sa+w;a[(a[C]|0)+(f+32987)|0]=P;a[C]=(a[C]|0)+1;ta=ra-pa|0;ua=a[r]|0}else{ta=ra;ua=H}}while(0);ra=P+1|0;if((ra|0)>=(ua<<24>>24|0)){va=ta;wa=ua;xa=pa;break c}P=ra;_=ta;H=ua;w=b[f+32996+(ra*144|0)+134>>1]|0}}else{a[C]=0;va=T;wa=F;xa=S}}while(0);if((va|0)==0){a[ga]=1}S=c[y>>2]|0;T=c[v>>2]|0;ha=d[T+(S>>>3)|0]<<(S&7)>>>7;M=c[u>>2]|0;w=((S|0)<(M|0))+S|0;c[y>>2]=w;S=ha&1;c[ia>>2]=S;do{if((S|0)==0){if((c[fa>>2]|0)==0){E=129;break b}else{ya=w;za=T;Aa=M;Ba=wa}}else{mrc(K|0,0,1280)|0;mrc(N|0,0,640)|0;mrc(L|0,0,6272)|0;if(wa<<24>>24>0){ha=0;do{H=f+226848+(ha<<2)|0;if((c[H>>2]|0)>0){_=0;while(1){P=_+1|0;mrc(f+41088+(ha*23220|0)+(_*2580|0)+16|0,0,2560)|0;if((P|0)<(c[H>>2]|0)){_=P}else{break}}}c[f+227016+(ha<<2)>>2]=0;ha=ha+1|0;}while((ha|0)<(a[r]|0));Ca=c[y>>2]|0;Da=c[v>>2]|0;Ea=c[u>>2]|0}else{Ca=w;Da=T;Ea=M}ha=d[Da+(Ca>>>3)|0]<<(Ca&7)>>>7;_=((Ca|0)<(Ea|0))+Ca|0;c[y>>2]=_;H=ha&1;a[J]=H;if(!(H<<24>>24==0)){E=85;break b}H=d[Da+(_>>>3)|0]<<(_&7)>>>7;ha=((_|0)<(Ea|0))+_|0;c[y>>2]=ha;_=H&1;a[ea]=_;H=d[Da+(ha>>>3)|0]<<(ha&7)>>>7;P=((ha|0)<(Ea|0))+ha|0;c[y>>2]=P;a[Z]=H&1;H=d[Da+(P>>>3)|0]<<(P&7)>>>7;ha=((P|0)<(Ea|0))+P|0;c[y>>2]=ha;P=H&1;a[ka]=P;do{if(_<<24>>24==0){Fa=P}else{H=Da+(ha>>>3)|0;ra=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(ha&7)>>>28;H=ha+4|0;I=Ea>>>0>H>>>0?H:Ea;c[y>>2]=I;H=ra+1&255;a[Y]=H;ra=Da+(I>>>3)|0;qa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(I&7)>>>28;ra=I+4|0;c[y>>2]=Ea>>>0>ra>>>0?ra:Ea;ra=qa&255;a[W]=ra;if(H<<24>>24==0){Fa=P;break}else{Ga=0;Ha=ra}while(1){if(Ha<<24>>24==0){Ia=0;Ja=1}else{ra=Ha<<24>>24;H=c[y>>2]|0;qa=c[u>>2]|0;I=(c[v>>2]|0)+(H>>>3)|0;sa=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(H&7)>>>((32-ra|0)>>>0);I=H+ra|0;c[y>>2]=qa>>>0>I>>>0?I:qa;Ia=0;Ja=sa+1|0}sa=f+34160+(Ga<<3)|0;c[sa>>2]=Ja;c[sa+4>>2]=Ia;sa=Ga+1|0;if((sa|0)>=(a[Y]|0)){break}Ga=sa;Ha=a[W]|0}Fa=a[ka]|0}}while(0);do{if(!(Fa<<24>>24==0)){P=c[y>>2]|0;ha=c[u>>2]|0;_=c[v>>2]|0;sa=_+(P>>>3)|0;qa=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(P&7)>>>28;sa=P+4|0;P=ha>>>0>sa>>>0?sa:ha;c[y>>2]=P;sa=(qa<<1)+2&255;a[U]=sa;qa=_+(P>>>3)|0;I=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(P&7)>>>28;qa=P+4|0;P=ha>>>0>qa>>>0?qa:ha;c[y>>2]=P;a[A]=I;qa=d[_+(P>>>3)|0]|0;ra=((P|0)<(ha|0))+P|0;c[y>>2]=ra;if((qa&128>>>((P&7)>>>0)|0)==0){break}P=I+1|0;I=(P&65280|0)==0;qa=(d[1359664+(I?P:P>>>8)|0]|0)+(I?0:8)|0;I=((1<<qa|0)<(P|0))+qa|0;if((I|0)==0){Ka=2;La=ra}else{qa=_+(ra>>>3)|0;P=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ra&7)>>>((32-I|0)>>>0);qa=I+ra|0;ra=ha>>>0>qa>>>0?qa:ha;c[y>>2]=ra;Ka=P+2|0;La=ra}ra=a[r]|0;P=ra<<24>>24;d:do{if((ca(ca(P,sa<<24>>24)|0,P)|0)>0){qa=32-Ka|0;I=0;H=La;Ma=ha;Na=_;while(1){Oa=Na+(H>>>3)|0;Pa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(H&7)>>>(qa>>>0);Oa=H+Ka|0;c[y>>2]=Ma>>>0>Oa>>>0?Oa:Ma;b[f+34802+(I<<1)>>1]=Pa;Pa=I+1|0;Oa=a[r]|0;Qa=Oa<<24>>24;if((Pa|0)>=(ca(ca(Qa,a[U]|0)|0,Qa)|0)){Ra=Oa;break d}I=Pa;H=c[y>>2]|0;Ma=c[u>>2]|0;Na=c[v>>2]|0}}else{Ra=ra}}while(0);if(!(Ra<<24>>24>0)){break}ra=32-Ka|0;_=0;ha=Ra;while(1){if((_|0)>0){P=0;sa=ha;while(1){Na=c[y>>2]|0;Ma=c[u>>2]|0;H=(c[v>>2]|0)+(Na>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(Na&7)>>>(ra>>>0);H=Na+Ka|0;c[y>>2]=Ma>>>0>H>>>0?H:Ma;b[f+38898+((ca(sa<<24>>24,_)|0)+P<<1)>>1]=I;I=P+1|0;Ma=a[r]|0;if((I|0)<(_|0)){P=I;sa=Ma}else{Sa=Ma;break}}}else{Sa=ha}sa=_+1|0;if((sa|0)<(Sa<<24>>24|0)){_=sa;ha=Sa}else{break}}}}while(0);ha=c[y>>2]|0;_=c[v>>2]|0;ra=a[_+(ha>>>3)|0]|0;sa=c[u>>2]|0;P=((ha|0)<(sa|0))+ha|0;c[y>>2]=P;Ma=a[r]|0;if(Ma<<24>>24>0){I=(ra&255&128>>>((ha&7)>>>0)|0)!=0;Ta=0;ha=P;ra=sa;H=_;while(1){Na=H+(ha>>>3)|0;qa=(je(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(ha&7)>>>29;Na=ha+3|0;c[y>>2]=ra>>>0>Na>>>0?Na:ra;Na=f+226848+(Ta<<2)|0;c[Na>>2]=qa+1;Ua=0;while(1){qa=c[y>>2]|0;Pa=c[u>>2]|0;Oa=(c[v>>2]|0)+(qa>>>3)|0;Qa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(qa&7)>>>25;Oa=qa+7|0;c[y>>2]=Pa>>>0>Oa>>>0?Oa:Pa;Va=(Qa<<3)+8|0;c[f+41088+(Ta*23220|0)+(Ua*2580|0)>>2]=Va;if(Va>>>0>256>>>0){E=123;break b}Qa=Ua+1|0;Wa=c[Na>>2]|0;if((Qa|0)<(Wa|0)){Ua=Qa}else{break}}do{if((Wa|0)>0){Qa=0;do{Pa=c[y>>2]|0;Oa=c[u>>2]|0;qa=(c[v>>2]|0)+(Pa>>>3)|0;Xa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(Pa&7)>>>28;qa=Pa+4|0;c[y>>2]=Oa>>>0>qa>>>0?qa:Oa;c[f+41088+(Ta*23220|0)+(Qa*2580|0)+4>>2]=Xa;Qa=Qa+1|0;Ya=c[Na>>2]|0;}while((Qa|0)<(Ya|0));if(I&(Ya|0)>0){Za=0}else{break}do{Qa=c[f+41088+(Ta*23220|0)+(Za*2580|0)>>2]|0;Xa=Qa>>>0>65535>>>0;Oa=Xa?Qa>>>16:Qa;qa=Xa?16:0;if((Oa&65280|0)==0){_a=qa;$a=Oa}else{_a=qa|8;$a=Oa>>>8}Oa=(d[1359664+$a|0]|0)+_a|0;qa=((1<<Oa|0)<(Qa|0))+Oa|0;Oa=c[y>>2]|0;Qa=c[u>>2]|0;Xa=(c[v>>2]|0)+(Oa>>>3)|0;Pa=(je(d[Xa]|d[Xa+1|0]<<8|d[Xa+2|0]<<16|d[Xa+3|0]<<24|0)|0)<<(Oa&7)>>>((32-qa|0)>>>0);Xa=qa+Oa|0;c[y>>2]=Qa>>>0>Xa>>>0?Xa:Qa;Qa=f+41088+(Ta*23220|0)+(Za*2580|0)+8|0;c[Qa>>2]=Pa+1;Pa=f+41088+(Ta*23220|0)+(Za*2580|0)+4|0;Xa=(c[Pa>>2]|0)+1|0;Oa=Xa>>>0>65535>>>0;qa=Oa?Xa>>>16:Xa;ab=Oa?16:0;if((qa&65280|0)==0){bb=ab;cb=qa}else{bb=ab|8;cb=qa>>>8}qa=(d[1359664+cb|0]|0)+bb|0;ab=((1<<qa|0)<(Xa|0))+qa|0;qa=c[y>>2]|0;Xa=c[u>>2]|0;Oa=(c[v>>2]|0)+(qa>>>3)|0;db=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(qa&7)>>>((32-ab|0)>>>0);Oa=ab+qa|0;c[y>>2]=Xa>>>0>Oa>>>0?Oa:Xa;Xa=db+2|0;Oa=f+41088+(Ta*23220|0)+(Za*2580|0)+12|0;c[Oa>>2]=Xa;qa=30-db|0;db=30-(c[Pa>>2]|0)|0;e:do{if((c[Qa>>2]|0)>0){Pa=0;ab=Xa;while(1){eb=c[y>>2]|0;fb=c[u>>2]|0;gb=(c[v>>2]|0)+(eb>>>3)|0;hb=(je(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(eb&7)>>>((32-ab|0)>>>0);gb=eb+ab|0;c[y>>2]=fb>>>0>gb>>>0?gb:fb;b[f+41088+(Ta*23220|0)+(Za*2580|0)+16+(Pa<<1)>>1]=hb<<qa>>>(db>>>0);hb=Pa+1|0;if((hb|0)>=(c[Qa>>2]|0)){break e}Pa=hb;ab=c[Oa>>2]|0}}}while(0);Za=Za+1|0;}while((Za|0)<(c[Na>>2]|0))}}while(0);Na=Ta+1|0;Oa=a[r]|0;Qa=c[y>>2]|0;db=c[u>>2]|0;qa=c[v>>2]|0;if((Na|0)<(Oa<<24>>24|0)){Ta=Na;ha=Qa;ra=db;H=qa}else{ib=Qa;jb=db;kb=qa;lb=Oa;break}}}else{ib=P;jb=sa;kb=_;lb=Ma}H=kb+(ib>>>3)|0;ra=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(ib&7)>>>29;H=ib+3|0;ha=jb>>>0>H>>>0?H:jb;c[y>>2]=ha;c[h>>2]=ra;ra=kb+(ha>>>3)|0;H=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(ha&7)>>>24;ra=ha+8|0;ha=jb>>>0>ra>>>0?ra:jb;c[y>>2]=ha;c[m>>2]=H+1;c[V>>2]=ca(a[U]|0,lb<<24>>24)|0;if(lb<<24>>24>0){mb=0}else{ya=ha;za=kb;Aa=jb;Ba=lb;break}do{ha=f+226848+(mb<<2)|0;if((c[ha>>2]|0)>0){H=0;do{c[f+41088+(mb*23220|0)+(H*2580|0)+2576>>2]=c[f+41088+(mb*23220|0)+(H*2580|0)>>2];H=H+1|0;}while((H|0)<(c[ha>>2]|0))}c[f+32996+(mb*144|0)+140>>2]=e[n>>1]|0;c[f+226948+(mb<<2)>>2]=1;c[f+226980+(mb<<2)>>2]=0;mb=mb+1|0;nb=a[r]|0;}while((mb|0)<(nb<<24>>24|0));ya=c[y>>2]|0;za=c[v>>2]|0;Aa=c[u>>2]|0;Ba=nb}}while(0);M=ya&7;T=d[za+(ya>>>3)|0]|0;c[y>>2]=((ya|0)<(Aa|0))+ya;if(Ba<<24>>24>0){w=0;while(1){c[f+226884+(w<<2)>>2]=1;S=w+1|0;Ma=a[r]|0;if((S|0)<(Ma<<24>>24|0)){w=S}else{ob=Ma;break}}}else{ob=Ba}w=(T&128>>>(M>>>0)|0)!=0;do{if(!w){if(ob<<24>>24>0){Ma=0;while(1){S=c[y>>2]|0;_=d[(c[v>>2]|0)+(S>>>3)|0]<<(S&7)>>>7;c[y>>2]=((S|0)<(c[u>>2]|0))+S;c[f+226884+(Ma<<2)>>2]=_&1;_=Ma+1|0;S=a[r]|0;if((_|0)<(S<<24>>24|0)){Ma=_}else{pb=S;break}}}else{pb=ob}if((c[j>>2]|0)==0){a[Q]=0;break}Ma=c[y>>2]|0;S=c[v>>2]|0;_=d[S+(Ma>>>3)|0]<<(Ma&7)>>>7;sa=c[u>>2]|0;P=((Ma|0)<(sa|0))+Ma|0;c[y>>2]=P;Ma=_&1;a[Q]=Ma;if(Ma<<24>>24==0){break}Ma=S+(P>>>3)|0;_=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(P&7)>>>27;Ma=P+5|0;P=sa>>>0>Ma>>>0?Ma:sa;c[y>>2]=P;Ma=_+1|0;c[R>>2]=Ma;_=S+(P>>>3)|0;ha=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(P&7)>>>28;_=P+4|0;P=sa>>>0>_>>>0?_:sa;c[y>>2]=P;c[B>>2]=ha;_=S+(P>>>3)|0;S=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<(P&7)>>>29;_=P+3|0;c[y>>2]=sa>>>0>_>>>0?_:sa;sa=S+1|0;c[z>>2]=sa;S=sa+ha|0;if(pb<<24>>24>0){ha=32-S|0;sa=0;_=Ma;Ma=pb;while(1){if((_|0)>0){P=0;do{H=c[y>>2]|0;ra=c[u>>2]|0;I=(c[v>>2]|0)+(H>>>3)|0;Oa=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(H&7)>>ha;I=H+S|0;c[y>>2]=ra>>>0>I>>>0?I:ra;c[f+751336+(sa*160|0)+(P<<2)>>2]=Oa;P=P+1|0;qb=c[R>>2]|0;}while((P|0)<(qb|0));rb=qb;sb=a[r]|0}else{rb=_;sb=Ma}P=sa+1|0;if((P|0)<(sb<<24>>24|0)){sa=P;_=rb;Ma=sb}else{break}}}QIb(c[q>>2]|0,2141120,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}}while(0);M=c[y>>2]|0;T=c[v>>2]|0;Ma=d[T+(M>>>3)|0]|0;_=c[u>>2]|0;sa=((M|0)<(_|0))+M|0;c[y>>2]=sa;if((Ma&128>>>((M&7)>>>0)|0)==0){tb=0}else{M=T+(sa>>>3)|0;T=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(sa&7)>>>27;M=sa+5|0;c[y>>2]=_>>>0>M>>>0?M:_;tb=T}do{if(w){T=d[ja]|0;_=T-tb|0;if((_|0)<1){E=154;break b}M=a[r]|0;if(!(M<<24>>24>0)){ub=M;break}sa=(xa|0)>0;Ma=(T|0)==(tb|0);T=32-_|0;S=(_|0)<26;ha=_-16|0;P=48-_|0;Oa=0;ra=M;while(1){if(sa){M=0;do{do{if(Ma){vb=0}else{I=c[y>>2]|0;H=c[u>>2]|0;qa=c[v>>2]|0;db=qa+(I>>>3)|0;Qa=(je(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(I&7);if(S){db=I+_|0;c[y>>2]=H>>>0>db>>>0?db:H;vb=Qa>>>(T>>>0);break}else{db=I+16|0;I=H>>>0>db>>>0?db:H;c[y>>2]=I;db=qa+(I>>>3)|0;qa=(je(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(I&7)>>>(P>>>0);db=I+ha|0;c[y>>2]=H>>>0>db>>>0?db:H;vb=qa|Qa>>>16<<ha;break}}}while(0);c[f+752628+(Oa<<16)+(M<<2)>>2]=vb<<T>>T;M=M+1|0;}while((M|0)<(xa|0));wb=a[r]|0}else{wb=ra}M=Oa+1|0;if((M|0)<(wb<<24>>24|0)){Oa=M;ra=wb}else{ub=wb;break}}}else{ra=a[r]|0;if(!(ra<<24>>24>0)){ub=ra;break}ra=xa<<2;Oa=(xa|0)>0;T=xa>>>0>65535>>>0;ha=T?xa>>>16:xa;P=T?16:0;T=(ha&65280|0)==0;_=T?P:P|8;P=1359664+(T?ha:ha>>>8)|0;ha=0;while(1){do{if((c[f+226884+(ha<<2)>>2]|0)==0){mrc(f+227048+(ha<<16)|0,0,ra|0)|0}else{T=c[y>>2]|0;S=d[(c[v>>2]|0)+(T>>>3)|0]<<(T&7)>>>7;c[y>>2]=((T|0)<(c[u>>2]|0))+T;T=S&1;S=f+226948+(ha<<2)|0;c[S>>2]=T;do{if((T|0)==0){if((c[f+32996+(ha*144|0)+140>>2]|0)==0){break}c[S>>2]=1}else{Ma=(d[P]|0)+_|0;sa=c[y>>2]|0;M=c[u>>2]|0;Qa=(c[v>>2]|0)+(sa>>>3)|0;qa=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(sa&7)>>>((32-Ma|0)>>>0);Qa=Ma+sa|0;c[y>>2]=M>>>0>Qa>>>0?Qa:M;c[f+226980+(ha<<2)>>2]=qa;if((qa|0)!=0){c[S>>2]=0}qa=f+32996+(ha*144|0)+140|0;M=c[qa>>2]|0;Qa=(e[n>>1]|0)>>>1;c[qa>>2]=(M|0)>(Qa|0)?M:Qa}}while(0);do{if((c[ia>>2]|0)==0){xb=0}else{S=d[ja]|0;T=c[y>>2]|0;Qa=c[u>>2]|0;M=(c[v>>2]|0)+(T>>>3)|0;qa=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(T&7)>>>((32-S|0)>>>0);M=T+S|0;c[y>>2]=Qa>>>0>M>>>0?M:Qa;c[f+227016+(ha<<2)>>2]=qa<<(c[h>>2]|0)+1;if((c[ia>>2]|0)==0){xb=0;break}qa=a[ja]|0;Qa=qa&255;if((a[Z]|0)!=0){M=Qa+1|0;S=c[y>>2]|0;T=c[u>>2]|0;sa=c[v>>2]|0;Ma=sa+(S>>>3)|0;H=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(S&7);if(M>>>0<26>>>0){Ma=31-Qa|0;db=S+M|0;c[y>>2]=T>>>0>db>>>0?db:T;yb=H>>>(Ma>>>0);zb=Ma}else{Ma=S+16|0;S=T>>>0>Ma>>>0?Ma:T;c[y>>2]=S;Ma=Qa-15|0;db=sa+(S>>>3)|0;sa=(je(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(S&7)>>>((47-Qa|0)>>>0);db=S+Ma|0;c[y>>2]=T>>>0>db>>>0?db:T;yb=sa|H>>>16<<Ma;zb=31-Qa|0}c[f+227048+(ha<<16)>>2]=yb<<zb>>zb;xb=1;break}do{if(qa<<24>>24==0){Ab=0}else{Ma=c[y>>2]|0;H=c[u>>2]|0;sa=c[v>>2]|0;T=sa+(Ma>>>3)|0;db=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(Ma&7);if((qa&255)>>>0<26>>>0){T=Ma+Qa|0;c[y>>2]=H>>>0>T>>>0?T:H;Ab=db>>>((32-Qa|0)>>>0);break}else{T=Ma+16|0;Ma=H>>>0>T>>>0?T:H;c[y>>2]=Ma;T=Qa-16|0;S=sa+(Ma>>>3)|0;sa=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Ma&7)>>>((48-Qa|0)>>>0);S=Ma+T|0;c[y>>2]=H>>>0>S>>>0?S:H;Ab=sa|db>>>16<<T;break}}}while(0);qa=32-Qa|0;c[f+227048+(ha<<16)>>2]=Ab<<qa>>qa;xb=1}}while(0);f:do{if((xb|0)<(xa|0)){qa=f+227016+(ha<<2)|0;T=xb;do{db=c[v>>2]|0;sa=c[u>>2]|0;H=0;S=c[y>>2]|0;while(1){Ma=d[db+(S>>>3)|0]|0;Bb=((S|0)<(sa|0))+S|0;c[y>>2]=Bb;if((Ma&128>>>((S&7)>>>0)|0)==0){break}if(((c[O>>2]|0)-Bb|0)<1){break f}else{H=H+1|0;S=Bb}}if((H|0)>31){S=db+(Bb>>>3)|0;Ma=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(Bb&7)>>>27;S=Bb+5|0;M=sa>>>0>S>>>0?S:sa;c[y>>2]=M;S=Ma+1|0;I=db+(M>>>3)|0;Na=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(M&7);if(S>>>0<26>>>0){I=S+M|0;S=sa>>>0>I>>>0?I:sa;c[y>>2]=S;Cb=Na>>>((Ma^31)>>>0);Db=S}else{S=M+16|0;M=sa>>>0>S>>>0?S:sa;c[y>>2]=M;S=Ma-15|0;I=db+(M>>>3)|0;Xa=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(M&7)>>>((47-Ma|0)>>>0);Ma=S+M|0;M=sa>>>0>Ma>>>0?Ma:sa;c[y>>2]=M;Cb=Xa|Na>>>16<<S;Db=M}Eb=Cb+H|0;Fb=Db}else{Eb=H;Fb=Bb}M=c[qa>>2]|0;S=c[h>>2]|0;Na=(1<<S)+M>>S+1;if(Na>>>0<2>>>0){Gb=Eb;Hb=M}else{M=(Na<<1)-2|0;Na=M>>>0>65535>>>0;Xa=Na?M>>>16:M;M=Na?16:0;if((Xa&65280|0)==0){Ib=M;Jb=Xa}else{Ib=M|8;Jb=Xa>>>8}Xa=(d[1359664+Jb|0]|0)+Ib|0;do{if((Xa|0)==0){Kb=0}else{M=db+(Fb>>>3)|0;Na=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Fb&7);if((Xa|0)<26){M=Xa+Fb|0;c[y>>2]=sa>>>0>M>>>0?M:sa;Kb=Na>>>((32-Xa|0)>>>0);break}else{M=Fb+16|0;Ma=sa>>>0>M>>>0?M:sa;c[y>>2]=Ma;M=Xa-16|0;I=db+(Ma>>>3)|0;ab=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(Ma&7)>>>((48-Xa|0)>>>0);I=M+Ma|0;c[y>>2]=sa>>>0>I>>>0?I:sa;Kb=ab|Na>>>16<<M;break}}}while(0);Gb=Kb+(Eb<<Xa)|0;Hb=c[qa>>2]|0}c[qa>>2]=Gb+Hb-(Hb>>S);c[f+227048+(ha<<16)+(T<<2)>>2]=Gb<<31>>31^Gb>>1;T=T+1|0;}while((T|0)<(xa|0))}}while(0);T=f+226848+(ha<<2)|0;qa=c[T>>2]|0;Qa=(qa|0)>0;sa=f+226916+(ha<<2)|0;do{if((c[ia>>2]|0)==0){if(Qa){Lb=qa}else{Mb=8;break}while(1){db=Lb-1|0;H=c[f+41088+(ha*23220|0)+(db*2580|0)+2576>>2]|0;do{if((c[sa>>2]|0)!=8){M=f+41088+(ha*23220|0)+(db*2580|0)|0;Na=(c[M>>2]|0)>0;if((c[j>>2]|0)==0){if(Na){Nb=0}else{break}do{ab=f+41088+(ha*23220|0)+(db*2580|0)+1552+(Nb<<1)|0;b[ab>>1]=(b[ab>>1]|0)/2|0;Nb=Nb+1|0;}while((Nb|0)<(c[M>>2]|0))}else{if(Na){Ob=0}else{break}do{ab=f+41088+(ha*23220|0)+(db*2580|0)+1552+(Ob+H<<1)|0;b[ab>>1]=(b[ab>>1]|0)/2|0;Ob=Ob+1|0;}while((Ob|0)<(c[M>>2]|0))}}}while(0);if((db|0)>0){Lb=db}else{Mb=8;break}}}else{if(Qa){Pb=qa}else{Mb=16;break}while(1){H=Pb-1|0;S=c[f+41088+(ha*23220|0)+(H*2580|0)+2576>>2]|0;do{if((c[sa>>2]|0)!=16){Xa=f+41088+(ha*23220|0)+(H*2580|0)|0;M=(c[Xa>>2]|0)>0;if((c[j>>2]|0)==0){if(M){Qb=0}else{break}do{Na=f+41088+(ha*23220|0)+(H*2580|0)+1552+(Qb<<1)|0;b[Na>>1]=b[Na>>1]<<1;Qb=Qb+1|0;}while((Qb|0)<(c[Xa>>2]|0))}else{if(M){Rb=0}else{break}do{Na=f+41088+(ha*23220|0)+(H*2580|0)+1552+(Rb+S<<1)|0;b[Na>>1]=b[Na>>1]<<1;Rb=Rb+1|0;}while((Rb|0)<(c[Xa>>2]|0))}}}while(0);if((H|0)>0){Pb=H}else{Mb=16;break}}}}while(0);c[sa>>2]=Mb;qa=c[T>>2]|0;if((qa|0)>0){Sb=qa}else{break}do{Sb=Sb-1|0;if(Oa){qa=f+41088+(ha*23220|0)+(Sb*2580|0)+4|0;Qa=f+41088+(ha*23220|0)+(Sb*2580|0)+2576|0;S=f+41088+(ha*23220|0)+(Sb*2580|0)|0;db=f+41088+(ha*23220|0)+(Sb*2580|0)+528|0;Xa=f+41088+(ha*23220|0)+(Sb*2580|0)+1552|0;M=0;do{Na=c[qa>>2]|0;ab=1<<Na-1;I=f+227048+(ha<<16)+(M<<2)|0;Ma=c[I>>2]|0;Pa=c[Qa>>2]|0;hb=c[S>>2]|0;fb=(hb|0)>0;if(fb){gb=0;eb=0;while(1){Tb=(ca(b[f+41088+(ha*23220|0)+(Sb*2580|0)+528+(gb+Pa<<1)>>1]|0,b[f+41088+(ha*23220|0)+(Sb*2580|0)+16+(gb<<1)>>1]|0)|0)+eb|0;Ub=gb+1|0;if((Ub|0)<(hb|0)){gb=Ub;eb=Tb}else{Vb=Tb;break}}}else{Vb=0}eb=(Vb+ab>>Na)+Ma|0;gb=1<<(d[ja]|0)-1;do{if((Ma|0)<0){if(fb){Wb=0}else{Xb=hb;break}while(1){H=f+41088+(ha*23220|0)+(Sb*2580|0)+16+(Wb<<1)|0;b[H>>1]=(b[H>>1]|0)-(b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(Wb+Pa<<1)>>1]|0);H=Wb+1|0;Tb=c[S>>2]|0;if((H|0)<(Tb|0)){Wb=H}else{Xb=Tb;break}}}else{if((Ma|0)<1|fb^1){Xb=hb;break}else{Yb=0}while(1){Tb=f+41088+(ha*23220|0)+(Sb*2580|0)+16+(Yb<<1)|0;b[Tb>>1]=(b[Tb>>1]|0)+(b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(Yb+Pa<<1)>>1]|0);Tb=Yb+1|0;H=c[S>>2]|0;if((Tb|0)<(H|0)){Yb=Tb}else{Xb=H;break}}}}while(0);if((Pa|0)==0){nrc(f+41088+(ha*23220|0)+(Sb*2580|0)+528+(Xb<<1)|0,db|0,Xb<<1)|0;hb=c[S>>2]|0;nrc(f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(hb<<1)|0,Xa|0,hb<<1)|0;Zb=c[S>>2]|0}else{Zb=Pa}hb=Zb-1|0;fb=-gb|0;Ma=gb-1|0;if((eb|0)<(fb|0)){_b=fb&65535}else{_b=((Ma|0)<(eb|0)?Ma:eb)&65535}b[f+41088+(ha*23220|0)+(Sb*2580|0)+528+(hb<<1)>>1]=_b;do{if((eb|0)==0){b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(hb<<1)>>1]=0}else{Ma=c[sa>>2]|0;if((eb|0)<0){b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(hb<<1)>>1]=-Ma;break}else{b[f+41088+(ha*23220|0)+(Sb*2580|0)+1552+(hb<<1)>>1]=Ma;break}}}while(0);gb=f+41088+(ha*23220|0)+(Sb*2580|0)+1552+((c[S>>2]>>4)+hb<<1)|0;b[gb>>1]=(b[gb>>1]|0)>>>2;gb=f+41088+(ha*23220|0)+(Sb*2580|0)+1552+((c[S>>2]>>3)+hb<<1)|0;b[gb>>1]=(b[gb>>1]|0)>>>1;c[Qa>>2]=hb;c[I>>2]=eb;M=M+1|0;}while((M|0)<(xa|0))}}while((Sb|0)>0)}}while(0);sa=ha+1|0;T=a[r]|0;if((sa|0)<(T<<24>>24|0)){ha=sa}else{ub=T;break}}}}while(0);g:do{if((a[ka]|0)!=0){mrc(l|0,0,32)|0;if((xa|0)>0){$b=0;ac=ub}else{break}while(1){w=ac<<24>>24;if(ac<<24>>24>0){ha=ca(a[U]|0,w)|0;if((ha|0)>0){Oa=0;do{_=k+(Oa<<2)|0;c[_>>2]=0;if((c[f+226884+(Oa<<2)>>2]|0)!=0){P=ca(Oa,ha)|0;ra=c[V>>2]|0;T=0;sa=0;do{sa=(ca(b[f+34802+(T+P<<1)>>1]|0,b[f+39026+(T+ra<<1)>>1]|0)|0)+sa|0;T=T+1|0;}while((T|0)<(ha|0));c[_>>2]=sa;if((Oa|0)>0){T=ca(Oa,w)|0;ra=0;P=sa;do{P=(ca(b[f+38898+(ra+T<<1)>>1]|0,c[f+227048+(ra<<16)+($b<<2)>>2]|0)|0)+P|0;ra=ra+1|0;}while((ra|0)<(Oa|0));c[_>>2]=P;bc=P}else{bc=sa}ra=a[A]|0;T=(1<<ra-1)+bc>>ra;c[_>>2]=T;ra=f+227048+(Oa<<16)+($b<<2)|0;c[ra>>2]=T+(c[ra>>2]|0)}Oa=Oa+1|0;}while((Oa|0)<(w|0))}else{Oa=0;do{ha=k+(Oa<<2)|0;c[ha>>2]=0;if((c[f+226884+(Oa<<2)>>2]|0)!=0){if((Oa|0)>0){ra=ca(Oa,w)|0;T=0;M=0;do{M=(ca(b[f+38898+(T+ra<<1)>>1]|0,c[f+227048+(T<<16)+($b<<2)>>2]|0)|0)+M|0;T=T+1|0;}while((T|0)<(Oa|0));c[ha>>2]=M;cc=M}else{cc=0}T=a[A]|0;ra=(1<<T-1)+cc>>T;c[ha>>2]=ra;T=f+227048+(Oa<<16)+($b<<2)|0;c[T>>2]=ra+(c[T>>2]|0)}Oa=Oa+1|0;}while((Oa|0)<(w|0))}dc=a[r]|0}else{dc=ac}w=a[U]|0;Oa=dc<<24>>24;T=1<<(d[ja]|0)-1;if(dc<<24>>24>0){ra=ca(w,Oa)|0;_=(ra|0)>0;sa=0;do{P=(c[f+227048+(sa<<16)+($b<<2)>>2]|0)-(c[k+(sa<<2)>>2]|0)|0;do{if((P|0)>0){if(_){Qa=ca(sa,ra)|0;S=0;do{Xa=f+34802+(S+Qa<<1)|0;b[Xa>>1]=(b[Xa>>1]|0)+(b[f+40050+((c[V>>2]|0)+S<<1)>>1]|0);S=S+1|0;}while((S|0)<(ra|0))}if((sa|0)<=0){break}S=ca(sa,Oa)|0;Qa=0;do{Xa=c[f+227048+(Qa<<16)+($b<<2)>>2]|0;do{if((Xa|0)>0){db=f+38898+(Qa+S<<1)|0;b[db>>1]=(b[db>>1]|0)+1}else{if((Xa|0)>=0){break}db=f+38898+(Qa+S<<1)|0;b[db>>1]=(b[db>>1]|0)-1}}while(0);Qa=Qa+1|0;}while((Qa|0)<(sa|0))}else{if((P|0)>=0){break}if(_){Qa=ca(sa,ra)|0;S=0;do{Xa=f+34802+(S+Qa<<1)|0;b[Xa>>1]=(b[Xa>>1]|0)-(b[f+40050+((c[V>>2]|0)+S<<1)>>1]|0);S=S+1|0;}while((S|0)<(ra|0))}if((sa|0)<=0){break}S=ca(sa,Oa)|0;Qa=0;do{Xa=c[f+227048+(Qa<<16)+($b<<2)>>2]|0;do{if((Xa|0)>0){eb=f+38898+(Qa+S<<1)|0;b[eb>>1]=(b[eb>>1]|0)-1}else{if((Xa|0)>=0){break}eb=f+38898+(Qa+S<<1)|0;b[eb>>1]=(b[eb>>1]|0)+1}}while(0);Qa=Qa+1|0;}while((Qa|0)<(sa|0))}}while(0);sa=sa+1|0;}while((sa|0)<(Oa|0));sa=T-1|0;ra=sa&65535;_=-T|0;P=_&65535;ha=Oa;M=c[V>>2]|0;while(1){Qa=ha-1|0;S=M-1|0;c[V>>2]=S;Xa=f+227048+(Qa<<16)+($b<<2)|0;b[f+39026+(S<<1)>>1]=c[Xa>>2];S=c[Xa>>2]|0;do{if((S|0)>(sa|0)){b[f+39026+(c[V>>2]<<1)>>1]=ra}else{if((S|0)>=(_|0)){break}b[f+39026+(c[V>>2]<<1)>>1]=P}}while(0);b[f+40050+(c[V>>2]<<1)>>1]=0;S=c[Xa>>2]|0;do{if((S|0)>0){b[f+40050+(c[V>>2]<<1)>>1]=1}else{if((S|0)>=0){break}b[f+40050+(c[V>>2]<<1)>>1]=-1}}while(0);S=c[V>>2]|0;if((Qa|0)>0){ha=Qa;M=S}else{ec=S;break}}}else{ec=c[V>>2]|0}if((ec|0)==0){M=ca(w,Oa)|0;ha=ca(w<<1,Oa)|0;nrc(f+39026+(M<<1)|0,t|0,ha)|0;nrc(f+40050+(M<<1)|0,X|0,ha)|0;c[V>>2]=M}M=$b+1|0;if((M|0)>=(xa|0)){break g}$b=M;ac=a[r]|0}}}while(0);do{if((a[Z]|0)!=0){if((a[r]|0)!=2){break}if((c[$>>2]|0)==0){if((c[D>>2]|0)!=0&(xa|0)>0){fc=0}else{break}}else{if((xa|0)>0){fc=0}else{break}}do{M=f+292584+(fc<<2)|0;ha=c[M>>2]|0;P=f+227048+(fc<<2)|0;_=(c[P>>2]|0)-(ha>>1)|0;c[P>>2]=_;c[M>>2]=_+ha;fc=fc+1|0;}while((fc|0)<(xa|0))}}while(0);do{if((a[ea]|0)!=0){ha=a[W]|0;_=a[Y]|0;M=_<<24>>24;if((a[r]|0)<=0){break}P=_<<24>>24>0;_=(M|0)<(xa|0);ra=xa-1|0;sa=0;do{if(P){T=0;do{S=T-1|0;Xa=0;eb=0;while(1){if((T|0)>(Xa|0)){I=c[f+227048+(sa<<16)+(S-Xa<<2)>>2]|0;hb=f+34160+(Xa<<3)|0;db=Erc(I,(I|0)<0|0?-1:0,c[hb>>2]|0,c[hb+4>>2]|0)|0;hb=wrc(db,G,eb,0)|0;gc=hb}else{hb=f+34160+(Xa<<3)|0;db=c[f+34288+(sa<<6)+(Xa-T<<2)>>2]|0;I=Erc(db,(db|0)<0|0?-1:0,c[hb>>2]|0,c[hb+4>>2]|0)|0;hb=wrc(I,G,eb,0)|0;gc=hb}hb=Xa+1|0;if((hb|0)<(M|0)){Xa=hb;eb=gc}else{break}}eb=f+227048+(sa<<16)+(T<<2)|0;c[eb>>2]=(c[eb>>2]|0)+(gc>>ha);T=T+1|0;}while((T|0)<(M|0))}if(_){T=M;do{if(P){Oa=T-1|0;w=0;eb=0;while(1){Xa=c[f+227048+(sa<<16)+(Oa-w<<2)>>2]|0;S=f+34160+(w<<3)|0;Qa=Erc(Xa,(Xa|0)<0|0?-1:0,c[S>>2]|0,c[S+4>>2]|0)|0;S=wrc(Qa,G,eb,0)|0;Qa=S;S=w+1|0;if((S|0)<(M|0)){w=S;eb=Qa}else{hc=Qa;break}}}else{hc=0}eb=f+227048+(sa<<16)+(T<<2)|0;c[eb>>2]=(c[eb>>2]|0)+(hc>>ha);T=T+1|0;}while((T|0)<(xa|0))}if(P){T=0;do{c[f+34288+(sa<<6)+(T<<2)>>2]=c[f+227048+(sa<<16)+(ra-T<<2)>>2];T=T+1|0;}while((T|0)<(M|0))}sa=sa+1|0;}while((sa|0)<(a[r]|0))}}while(0);do{if((c[m>>2]|0)!=1){sa=a[r]|0;if(!(sa<<24>>24>0)){break}M=(xa|0)>0;ra=0;P=sa;while(1){if(M){sa=0;do{ha=f+227048+(ra<<16)+(sa<<2)|0;c[ha>>2]=ca(c[ha>>2]|0,c[m>>2]|0)|0;sa=sa+1|0;}while((sa|0)<(xa|0));ic=a[r]|0}else{ic=P}sa=ra+1|0;if((sa|0)<(ic<<24>>24|0)){ra=sa;P=ic}else{break}}}}while(0);P=a[C]|0;do{if(P<<24>>24>0){ra=0;M=P;while(1){sa=a[f+32987+ra|0]|0;ha=b[f+32996+(sa*144|0)+4+(d[f+32996+(sa*144|0)+132|0]<<1)>>1]|0;_=ha&65535;if(ha<<16>>16==0){jc=M}else{ha=f+32916+(sa<<2)|0;T=f+32948+(sa<<2)|0;eb=0;do{w=c[f+227048+(sa<<16)+(eb<<2)>>2]|0;if((a[ja]|0)==16){Oa=c[ha>>2]|0;c[ha>>2]=Oa+2;b[Oa>>1]=w<<16>>16<<tb}else{Oa=c[T>>2]|0;c[T>>2]=Oa+4;c[Oa>>2]=w<<tb}eb=eb+1|0;}while((eb|0)<(_|0));jc=a[C]|0}_=ra+1|0;kc=jc<<24>>24;if((_|0)<(kc|0)){ra=_;M=jc}else{break}}if(jc<<24>>24>0){lc=0}else{break}do{M=a[f+32987+lc|0]|0;ra=f+32996+(M*144|0)+132|0;_=a[ra]|0;if(!((_&255)>>>0<(d[f+32996+(M*144|0)+3|0]|0)>>>0)){E=346;break b}a[ra]=_+1;lc=lc+1|0;}while((lc|0)<(kc|0))}}while(0);if((a[ga]|0)!=0){E=350;break}F=a[r]|0;da=c[y>>2]|0}if((E|0)==85){QIb(c[q>>2]|0,2199392,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==123){KIb(c[q>>2]|0,16,2612088,(aa=i,i=i+32|0,c[aa>>2]=Ta,c[aa+8>>2]=Ua,c[aa+16>>2]=Va,c[aa+24>>2]=256,aa)|0);i=aa;c[fa>>2]=0}else if((E|0)==129){KIb(c[q>>2]|0,48,2167792,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;WHb(c[o>>2]|0)}else if((E|0)==154){KIb(c[q>>2]|0,16,2117616,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==346){KIb(c[q>>2]|0,16,2635664,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa}else if((E|0)==350){E=f+32981|0;if((a[E]|0)!=0){a[E]=0}E=c[y>>2]|0;if((c[p>>2]|0)==0){mc=E;nc=c[u>>2]|0}else{p=c[f+32876>>2]|0;if((x|0)!=(E+2-p|0)){KIb(c[q>>2]|0,16,2240376,(aa=i,i=i+16|0,c[aa>>2]=c[f+32888>>2],c[aa+8>>2]=x-1-E+p,aa)|0);i=aa;a[f+32884|0]=1;s=0;i=g;return s|0}aa=x-1-E+p|0;p=-E|0;x=c[u>>2]|0;u=x-E|0;if((aa|0)<(p|0)){oc=p}else{oc=(u|0)<(aa|0)?u:aa}aa=oc+E|0;c[y>>2]=aa;mc=aa;nc=x}x=d[(c[ba>>2]|0)+(mc>>>3)|0]<<(mc&7)>>>7;c[y>>2]=((mc|0)<(nc|0))+mc;mc=f+32888|0;c[mc>>2]=(c[mc>>2]|0)+1;s=x&1;i=g;return s|0}a[f+32884|0]=1;x=(c[o>>2]|0)+76|0;if((c[x>>2]|0)==0){s=0;i=g;return s|0}c[x>>2]=na;s=0;i=g;return s|0}a[f+32884|0]=1;WHb(c[o>>2]|0);s=-1094995529;i=g;return s|0}function ohb(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;j=c[f+60>>2]|0;k=c[f+96>>2]|0;l=f+432|0;if((c[l>>2]|0)==0){KIb(f,16,2428936,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-22;i=h;return n|0}o=j;c[o>>2]=f;qHb(j+4|0,c[f+88>>2]&8388608);p=j+40|0;c[j+32844>>2]=262144;c[j+32832>>2]=p;c[j+32840>>2]=j+32808;c[j+32836>>2]=p;c[j+32828>>2]=32;c[j+32824>>2]=0;c[f+420>>2]=8;if((c[f+100>>2]|0)<=17){QIb(f,2418384,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1163346256;i=h;return n|0}p=k+14|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=q&65535;r=j+66176|0;c[r>>2]=p;s=k+2|0;t=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=k;k=j+66182|0;a[k]=(d[s]|d[s+1|0]<<8)<<16>>16;s=c[l>>2]|0;l=s>>>0>65535>>>0;u=l?s>>>16:s;s=l?16:0;if((u&65280|0)==0){v=s;w=u}else{v=s|8;w=u>>>8}u=v+4+(d[1359664+w|0]|0)|0;w=j+66186|0;b[w>>1]=u;if((u&65534)>>>0>25>>>0){QIb(f,2409496,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1163346256;i=h;return n|0}a[j+68613|0]=1;a[j+68580|0]=1;u=j+66180|0;a[u]=q&64;q=ahb(c[f+412>>2]|0,3,p)|0;if((q|0)>13){QIb(f,2401768,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1163346256;i=h;return n|0}p=1<<q&65535;q=j+66184|0;b[q>>1]=p;v=c[r>>2]|0;s=v>>>3&7;l=1<<s;x=l&255;y=j+66189|0;a[y]=x;z=l&255;if((z|0)==16|(z|0)==4){a[j+66191|0]=1}a[j+66190|0]=(a[1359664+s|0]|0)+1;z=s+1|0;s=(p&65535)/(l&65535&255)|0;b[j+66192>>1]=s;a[j+66181|0]=v&255&-128;if((x&255)>>>0>32>>>0){KIb(f,16,2395080,(m=i,i=i+8|0,c[m>>2]=l&255,m)|0);i=m;n=-1094995529;i=h;return n|0}if((s&65535)>>>0<64>>>0){KIb(f,16,2387880,(m=i,i=i+8|0,c[m>>2]=s&65535,m)|0);i=m;n=-1094995529;i=h;return n|0}if((c[(c[o>>2]|0)+412>>2]|0)<1){KIb(f,16,2380960,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=h;return n|0}s=c[f+416>>2]|0;if((s|0)<0){KIb(f,16,2374592,(m=i,i=i+8|0,c[m>>2]=s,m)|0);i=m;n=-1094995529;i=h;return n|0}if((s|0)>8){QIb(f,2367376,(m=i,i=i+8|0,c[m>>2]=8,m)|0);i=m;n=-1163346256;i=h;return n|0}if((s|0)>0){l=j+71200|0;x=0;do{b[l+(x*49568|0)>>1]=p;x=x+1|0;}while((x|0)<(s|0))}s=j+66188|0;a[s]=-1;if((t&8|0)!=0){if((t&1|0)==0){A=-1}else{a[s]=0;A=0}if((t&2|0)==0){B=A}else{x=A+1&255;a[s]=x;B=x}if((t&4|0)==0){C=B}else{x=B+1&255;a[s]=x;C=x}a[s]=C+1}c[1280171]=9461464;c[1280173]=616;$2(5120680,8,121,607744,1,1,607496,2,2,0,0,0,4)|0;c[1280177]=9455840;c[1280179]=1406;$2(5120704,9,120,606080,1,1,605600,4,4,0,0,0,4)|0;c[2450043]=9447408;c[2450045]=2108;$2(9800168,9,272,1676408,1,1,1672656,4,4,0,0,0,4)|0;c[2450048]=9431760;c[2450050]=3912;$2(9800188,9,244,1670216,1,1,1667016,4,4,0,0,0,4)|0;c[846985]=9429344;c[846987]=604;$2(3387936,9,127,263544,1,1,263288,2,2,0,0,0,4)|0;c[846991]=9427096;c[846993]=562;$2(3387960,9,137,263952,1,1,263672,2,2,0,0,0,4)|0;c[846997]=9424848;c[846999]=562;$2(3387984,9,101,264304,1,1,264096,2,2,0,0,0,4)|0;C=j+66202|0;s=0;while(1){if((s|0)>=(z|0)){break}x=(e[q>>1]|0)>>>(s>>>0);b[C+(s*58|0)>>1]=0;B=x<<1;A=1;p=0;while(1){l=b[C+(s*58|0)+(A-1<<1)>>1]|0;if((l|0)>=(x|0)){D=A;break}v=ca(B,e[1625824+(p<<1)>>1]|0)|0;E=((v|0)/(c[(c[o>>2]|0)+412>>2]|0)|0)+2&-4;if((E|0)>(l|0)){b[C+(s*58|0)+(A<<1)>>1]=E;F=A+1|0}else{F=A}E=p+1|0;if((E|0)<28){A=F;p=E}else{D=F;break}}p=D-1|0;b[C+(s*58|0)+(p<<1)>>1]=x;A=p&255;a[j+(s+66194)|0]=A;if(A<<24>>24<1){G=39;break}else{s=s+1|0}}if((G|0)==39){KIb(f,16,2316616,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=h;return n|0}s=j+66666|0;D=0;a:do{F=j+(D+66194)|0;if((a[F]|0)>0){A=0;while(1){p=A+1|0;B=(b[C+(D*58|0)+(A<<1)>>1]|0)-1+(b[C+(D*58|0)+(p<<1)>>1]|0)<<D>>1;E=0;do{l=0;while(1){v=l+1|0;if((b[C+(E*58|0)+(v<<1)>>1]<<E|0)>=(B|0)){break}if((v|0)<29){l=v}else{G=47;break a}}a[s+(D*232|0)+(E*29|0)+A|0]=l;E=E+1|0;}while((E|0)<(z|0));if((p|0)<(a[F]|0)){A=p}else{break}}}D=D+1|0;}while((D|0)<(z|0));if((G|0)==47){KIb(0,0,2167760,(m=i,i=i+24|0,c[m>>2]=2312112,c[m+8>>2]=2117592,c[m+16>>2]=448,m)|0);i=m;Hd();return 0}G=j+32848|0;D=0;do{OPa(G+(D<<6)|0,D+7|0,1,1.0/+(1<<D+5|0)/+(1<<(d[k]|0)-1|0))|0;D=D+1|0;}while((D|0)<8);H0a(13);c[j+66172>>2]=c[326487];H0a(12);c[j+66168>>2]=c[326486];H0a(11);c[j+66164>>2]=c[326485];H0a(10);c[j+66160>>2]=c[326484];H0a(9);c[j+66156>>2]=c[326483];H0a(8);c[j+66152>>2]=c[326482];H0a(7);c[j+66148>>2]=c[326481];H0a(6);c[j+66144>>2]=c[326480];D=j+68522|0;j=0;while(1){G=(e[q>>1]|0)>>>(j>>>0);s=c[(c[o>>2]|0)+412>>2]|0;C=((G*440|0)-1+((s>>1)*3|0)|0)/(s|0)|0;if((C|0)<4){H=4}else{H=((C|0)>(G|0)?G:C)&65535}b[D+(j<<1)>>1]=H;C=j+1|0;if((C|0)<(z|0)){j=C}else{I=0;break}}do{g[5120376+(I<<2)>>2]=+V(+(I|0)*3.141592653589793*.015625);I=I+1|0;}while((I|0)<33);if((c[f+688>>2]&4|0)!=0){I=d[k]|0;KIb(c[o>>2]|0,48,2307528,(m=i,i=i+16|0,c[m>>2]=2301784,c[m+8>>2]=I,m)|0);i=m;I=c[r>>2]|0;KIb(c[o>>2]|0,48,2290664,(m=i,i=i+16|0,c[m>>2]=2284344,c[m+8>>2]=I,m)|0);i=m;I=e[q>>1]|0;KIb(c[o>>2]|0,48,2307528,(m=i,i=i+16|0,c[m>>2]=2280592,c[m+8>>2]=I,m)|0);i=m;I=e[w>>1]|0;KIb(c[o>>2]|0,48,2307528,(m=i,i=i+16|0,c[m>>2]=2276344,c[m+8>>2]=I,m)|0);i=m;I=d[y]|0;KIb(c[o>>2]|0,48,2307528,(m=i,i=i+16|0,c[m>>2]=2271936,c[m+8>>2]=I,m)|0);i=m;I=d[u]|0;KIb(c[o>>2]|0,48,2307528,(m=i,i=i+16|0,c[m>>2]=2267064,c[m+8>>2]=I,m)|0);i=m;I=c[o>>2]|0;o=c[I+416>>2]|0;KIb(I,48,2307528,(m=i,i=i+16|0,c[m>>2]=2263544,c[m+8>>2]=o,m)|0);i=m}m=f+448|0;c[m>>2]=t;c[m+4>>2]=0;n=0;i=h;return n|0}function phb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=i;k=c[b+60>>2]|0;l=k;m=k+68540|0;n=m;o=c[h+24>>2]|0;p=h+28|0;h=c[p>>2]|0;c[g>>2]=0;q=k+68581|0;a:do{if((a[q]|0)==0){r=k+68580|0;if((a[r]|0)!=0){s=3;break}t=(c[p>>2]|0)-(c[k+68560>>2]|0)<<3;c[k+68608>>2]=t;u=t>>>0>2147483639>>>0|(o|0)==0;v=u?0:o;w=u?0:t;c[m>>2]=v;c[k+68552>>2]=w;u=w+8|0;c[k+68556>>2]=u;c[k+68544>>2]=v+(w>>3);w=d[k+68564|0]|0;x=u>>>0>w>>>0?w:u;c[k+68548>>2]=x;do{if((a[k+66180|0]|0)==0){if((c[k+68568>>2]|0)<=(c[k+68596>>2]|0)){break}u=(thb(l,f,g)|0)==0|0;a[q]=u;y=u;s=24;break a}else{u=t-x|0;w=e[k+66186>>1]|0;if((u|0)<=(w|0)){break}z=v+(x>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>((32-w|0)>>>0);if((A|0)==0|(A|0)>(u|0)){break}shb(l,n,A,0);if((a[r]|0)!=0){s=23;break a}A=(thb(l,f,g)|0)==0|0;a[q]=A;y=A;s=24;break a}}while(0);a[q]=1;B=k+68580|0;s=26}else{s=3}}while(0);do{if((s|0)==3){a[q]=0;p=b+432|0;r=c[p>>2]|0;if((h|0)<(r|0)){KIb(b,16,2441080,(C=i,i=i+16|0,c[C>>2]=h,c[C+8>>2]=r,C)|0);i=C;D=-1094995529;i=j;return D|0}c[k+68560>>2]=h-r;r=c[p>>2]<<3;p=k+68608|0;c[p>>2]=r;x=r>>>0>2147483639>>>0|(o|0)==0;v=x?0:o;t=x?0:r;c[m>>2]=v;c[k+68552>>2]=t;r=t+8|0;c[k+68556>>2]=r;c[k+68544>>2]=v+(t>>3);t=k+68548|0;c[t>>2]=0;x=v;A=(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)>>>4&15;x=r>>>0>4>>>0?6:r|2;u=r>>>0>x>>>0?x:r;c[t>>2]=u;x=e[k+66186>>1]|0;w=v+(u>>>3)|0;v=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>((32-x|0)>>>0);w=u+x|0;c[t>>2]=r>>>0>w>>>0?w:r;r=k+68580|0;w=k+68565|0;do{if((a[r]|0)==0){x=d[w]|0;if((x+1&15|0)==(A|0)){break}a[r]=1;KIb(b,16,2353192,(C=i,i=i+16|0,c[C>>2]=x,c[C+8>>2]=A,C)|0);i=C}}while(0);a[w]=A;do{if((v|0)>0){x=(c[p>>2]|0)-(c[t>>2]|0)|0;if((v|0)<(x|0)){E=v}else{a[q]=1;E=x}shb(l,n,E,1);if((a[r]|0)!=0){break}thb(l,f,g)|0;s=13}else{s=13}}while(0);if((s|0)==13){if((a[r]|0)==0){s=23;break}}c[k+68568>>2]=0;a[r]=0;s=23}}while(0);if((s|0)==23){y=a[q]|0;s=24}do{if((s|0)==24){q=k+68580|0;if(y<<24>>24==0){F=q;break}g=k+68580|0;if((a[q]|0)==0){B=g;s=26}else{F=g}}}while(0);do{if((s|0)==26){y=(c[k+68608>>2]|0)-(c[k+68548>>2]|0)|0;if((y|0)<=0){F=B;break}shb(l,n,y,0);F=B}}while(0);B=c[k+68548>>2]|0;a[k+68564|0]=B&7;if((a[F]|0)!=0){D=-1094995529;i=j;return D|0}D=B>>3;i=j;return D|0}function qhb(a){a=a|0;var b=0;b=c[a+60>>2]|0;PPa(b+32848|0);PPa(b+32912|0);PPa(b+32976|0);PPa(b+33040|0);PPa(b+33104|0);PPa(b+33168|0);PPa(b+33232|0);PPa(b+33296|0);return 0}function rhb(b){b=b|0;var d=0,f=0,g=0,h=0,i=0;d=c[b+60>>2]|0;f=b+416|0;if((c[f>>2]|0)<=0){g=d+68580|0;a[g]=1;return}b=d+71200|0;h=d+66184|0;i=0;do{mrc(b+(i*49568|0)+416|0,0,(e[h>>1]|0)<<2|0)|0;i=i+1|0;}while((i|0)<(c[f>>2]|0));g=d+68580|0;a[g]=1;return}function shb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=i;j=(g|0)!=0;if(j){k=c[b+32828>>2]|0;l=c[b+32836>>2]|0}else{g=c[e+8>>2]&7;c[b+68572>>2]=g;c[b+68568>>2]=g;g=b+40|0;c[b+32844>>2]=262144;c[b+32832>>2]=g;c[b+32840>>2]=b+32808;c[b+32836>>2]=g;c[b+32828>>2]=32;c[b+32824>>2]=0;k=32;l=g}g=b+32824|0;m=b+32828|0;n=b+32836|0;o=l;do{if((f|0)>=1){if((f+40-k+(o-(c[b+32832>>2]|0)<<3)>>3|0)>32768){break}if((k-32+((c[b+32840>>2]|0)-o<<3)|0)<(f|0)){KIb(0,0,2167760,(p=i,i=i+24|0,c[p>>2]=2440088,c[p+8>>2]=2117592,c[p+16>>2]=1485,p)|0);i=p;Hd()}q=b+68568|0;r=(c[q>>2]|0)+f|0;c[q>>2]=r;if(j){s=e+8|0;t=c[s>>2]|0;u=t&7;v=8-u|0;w=(v|0)>(f|0)?f:v;v=e+16|0;x=c[v>>2]|0;z=e|0;A=c[z>>2]|0;B=A+(t>>>3)|0;C=32-w|0;D=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<u>>>(C>>>0);u=w+t|0;c[s>>2]=x>>>0>u>>>0?u:x;x=g|0;u=c[x>>2]|0;t=c[m>>2]|0;if((t|0)>(w|0)){E=t-w|0;F=u<<w|D;G=A}else{A=l;y=je(D>>>((w-t|0)>>>0)|u<<t|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;E=C+t|0;F=D;G=c[z>>2]|0}c[x>>2]=F;c[m>>2]=E;x=f-w|0;_2(g,G+(c[s>>2]>>3)|0,x);H=x;I=v}else{_2(g,(c[e>>2]|0)+(c[e+8>>2]>>3)|0,r);H=f;I=e+16|0}r=e+8|0;v=c[r>>2]|0;x=-v|0;s=(c[I>>2]|0)-v|0;if((H|0)<(x|0)){J=x}else{J=(s|0)<(H|0)?s:H}c[r>>2]=J+v;v=c[b+32824>>2]|0;r=v;s=c[m>>2]|0;if((s|0)<32){x=v<<s;r=x;v=x>>>24&255;x=s;s=c[n>>2]|0;while(1){a[s]=v;w=r;r=w<<8;z=x+8|0;if((z|0)<32){v=w>>>16&255;x=z;s=s+1|0}else{break}}}r=0;s=b+40|0;x=c[q>>2]|0;v=x>>>0>2147483639>>>0|(s|0)==0;z=v?0:s;s=v?0:x;c[b+68588>>2]=z;c[b+68600>>2]=s;x=s+8|0;c[b+68604>>2]=x;c[b+68592>>2]=z+(s+7>>3);s=c[b+68572>>2]|0;c[b+68596>>2]=x>>>0>s>>>0?s:x;i=h;return}}while(0);QIb(c[b>>2]|0,2457120,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;a[b+68580|0]=1;i=h;return}



function iUa(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,We=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ff=0,gf=0,jf=0,kf=0,lf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0,dg=0,eg=0,fg=0,gg=0,hg=0,ig=0,jg=0,kg=0,lg=0,mg=0,ng=0,og=0,pg=0,qg=0,rg=0,sg=0,tg=0,ug=0,vg=0,wg=0,xg=0,yg=0,zg=0,Ag=0,Bg=0,Cg=0,Dg=0,Eg=0,Fg=0,Gg=0,Hg=0.0,Ig=0.0,Jg=0.0,Kg=0.0,Lg=0.0,Mg=0,Ng=0,Og=0,Pg=0,Qg=0,Rg=0,Sg=0,Tg=0,Ug=0,Vg=0,Wg=0,Xg=0,Yg=0,Zg=0,_g=0,$g=0,ah=0,bh=0,ch=0,dh=0,eh=0,fh=0,gh=0,hh=0,ih=0,jh=0,kh=0,lh=0,mh=0,nh=0,oh=0,ph=0,qh=0,rh=0,sh=0,th=0,uh=0,vh=0,wh=0,xh=0,yh=0,zh=0,Ah=0,Bh=0,Ch=0,Dh=0,Eh=0,Fh=0,Gh=0,Hh=0,Ih=0,Jh=0,Kh=0,Lh=0,Mh=0,Nh=0,Oh=0,Ph=0,Qh=0,Rh=0,Sh=0,Th=0,Uh=0,Vh=0,Wh=0,Xh=0,Yh=0,Zh=0,_h=0,$h=0,ai=0,bi=0,ci=0,di=0,ei=0,fi=0,gi=0,hi=0,ii=0,ji=0,ki=0,li=0,mi=0,ni=0,oi=0,pi=0,qi=0,ri=0,si=0,ti=0,ui=0,vi=0,wi=0,xi=0,yi=0,zi=0,Ai=0,Bi=0,Ci=0,Di=0,Ei=0,Fi=0,Gi=0,Hi=0,Ii=0,Ji=0,Ki=0,Li=0,Mi=0,Ni=0,Oi=0,Pi=0,Qi=0,Ri=0,Si=0,Ti=0,Ui=0,Vi=0,Wi=0,Xi=0,Yi=0,Zi=0,_i=0,$i=0,aj=0,bj=0,cj=0,dj=0,ej=0,fj=0,gj=0,hj=0,ij=0,jj=0,kj=0,lj=0,mj=0,nj=0,oj=0,pj=0,qj=0,rj=0,sj=0,tj=0,uj=0,vj=0,wj=0,xj=0,yj=0,zj=0,Aj=0,Bj=0,Cj=0,Dj=0,Ej=0,Fj=0,Gj=0,Hj=0,Ij=0,Jj=0,Kj=0,Lj=0,Mj=0,Nj=0,Oj=0,Pj=0,Qj=0,Rj=0,Sj=0,Tj=0,Uj=0,Vj=0,Wj=0,Xj=0,Yj=0,Zj=0,_j=0,$j=0,ak=0,bk=0,ck=0,dk=0,ek=0,fk=0,gk=0,hk=0,ik=0,jk=0,kk=0,lk=0,mk=0,nk=0,ok=0,pk=0,qk=0,rk=0,sk=0,tk=0,uk=0,vk=0,wk=0,xk=0,yk=0,zk=0,Ak=0,Bk=0,Ck=0,Dk=0,Ek=0,Fk=0,Gk=0,Hk=0,Ik=0,Jk=0,Kk=0,Lk=0,Mk=0,Nk=0,Ok=0,Pk=0,Qk=0,Rk=0,Sk=0,Tk=0,Uk=0,Vk=0,Wk=0,Xk=0,Yk=0,Zk=0,_k=0,$k=0,al=0,bl=0,cl=0,dl=0,el=0,fl=0,gl=0,hl=0,il=0,jl=0,kl=0,ll=0,ml=0,nl=0,ol=0,pl=0,ql=0,rl=0,sl=0,tl=0,ul=0,vl=0,wl=0,xl=0,yl=0,zl=0,Al=0,Bl=0,Cl=0,Dl=0;f=i;i=i+51400|0;h=f|0;j=f+8|0;k=f+16|0;l=f+24|0;m=f+32|0;n=f+160|0;o=f+288|0;p=f+552|0;q=f+2088|0;r=f+3624|0;s=f+3672|0;t=f+3680|0;u=f+18352|0;v=f+33024|0;w=f+39024|0;x=f+45024|0;z=f+51024|0;A=f+51072|0;B=f+51120|0;C=f+51168|0;D=f+51176|0;E=f+51184|0;F=f+51208|0;H=c[g>>2]|0;g=H+14220|0;I=c[g>>2]|0;k8()|0;J=v|0;c[z+20>>2]=24e3;c[z+8>>2]=J;c[z+16>>2]=v+3e3;c[z+12>>2]=J;c[z+4>>2]=32;c[z>>2]=0;J=w|0;c[A+20>>2]=24e3;c[A+8>>2]=J;c[A+16>>2]=w+3e3;c[A+12>>2]=J;c[A+4>>2]=32;c[A>>2]=0;J=x|0;c[B+20>>2]=24e3;c[B+8>>2]=J;c[B+16>>2]=x+3e3;c[B+12>>2]=J;c[B+4>>2]=32;c[B>>2]=0;J=v+3e3|0;c[z+44>>2]=24e3;c[z+32>>2]=J;c[z+40>>2]=v+6e3;c[z+36>>2]=J;c[z+28>>2]=32;c[z+24>>2]=0;J=w+3e3|0;c[A+44>>2]=24e3;c[A+32>>2]=J;c[A+40>>2]=w+6e3;c[A+36>>2]=J;c[A+28>>2]=32;c[A+24>>2]=0;J=x+3e3|0;c[B+44>>2]=24e3;c[B+32>>2]=J;c[B+40>>2]=x+6e3;c[B+36>>2]=J;c[B+28>>2]=32;c[B+24>>2]=0;J=H;K=16>>>(I>>>0);I=H+788|0;L=H+792|0;M=H+796|0;N=H+13700|0;c[N>>2]=32-(c[I>>2]|0)+((c[M>>2]|0)-(c[L>>2]|0)<<3);O=H+13664|0;c[O>>2]=0;P=H+13696|0;Q=H+13672|0;R=Q;S=H+13676|0;T=H+13680|0;V=H+13684|0;W=H+13688|0;X=H+13692|0;Y=H+9860|0;Z=H+7848|0;mrc(Q|0,0,28)|0;Q=128<<c[H+14176>>2];c[Y>>2]=Q;_=Z;c[_>>2]=0;c[_+4>>2]=0;c[H+9864>>2]=Q;_=H+7856|0;c[_>>2]=0;c[_+4>>2]=0;c[H+9868>>2]=Q;Q=H+7864|0;c[Q>>2]=0;c[Q+4>>2]=0;Q=H+784|0;_=H+48|0;$=c[_>>2]|0;do{if(($|0)==108){c[Y>>2]=78;c[H+9864>>2]=73;c[H+9868>>2]=73;aa=H+12484|0;c[aa>>2]=0;ba=H+11824|0;mrc(ba|0,0,32)|0;da=H+14144|0;c[da>>2]=0;ea=aa;fa=ba;ga=da}else{da=H+12484|0;c[da>>2]=0;ba=H+11824|0;mrc(ba|0,0,32)|0;aa=H+14144|0;c[aa>>2]=0;if(($|0)==5|($|0)==20|($|0)==22){c[H+13784>>2]=Sga(J)|0;ea=da;fa=ba;ga=aa;break}else if(($|0)!=13){ea=da;fa=ba;ga=aa;break}if((c[H+13940>>2]|0)==0){ea=da;fa=ba;ga=aa;break}kSa(J);ea=da;fa=ba;ga=aa}}while(0);$=H+13704|0;c[$>>2]=0;aa=H+13708|0;c[aa>>2]=0;ba=H+14084|0;c[ba>>2]=1;da=H+14280|0;c[da>>2]=c[L>>2];ha=H+808|0;ia=c[ha>>2]|0;ja=H+812|0;a:do{if((ia|0)<(c[ja>>2]|0)){ka=H+12476|0;la=H+12480|0;ma=H+9960|0;na=H+116|0;oa=H+124|0;pa=H+12492|0;qa=H+800|0;ra=H+13936|0;sa=H+4|0;ta=H+12496|0;ua=ta;va=H+12500|0;wa=H+12504|0;xa=H+12508|0;ya=H+12512|0;za=H+12516|0;Aa=H+12544|0;Ba=H+12548|0;Ca=H+12552|0;Da=H+14252|0;Ea=H+9924|0;Fa=H+9984|0;Ga=H+13792|0;Ha=H+14404|0;Ia=H+11740|0;Ja=H+14212|0;Ka=q;La=H+148|0;Ma=H+152|0;Na=H+10044|0;Oa=r|0;Pa=r+4|0;Qa=r+8|0;Ra=r+12|0;Sa=r+16|0;Ta=r+20|0;Ua=r+24|0;Va=r+28|0;Wa=r+32|0;Xa=r+36|0;Ya=r+40|0;Za=r+44|0;_a=H+9980|0;$a=H+5400|0;ab=H+5404|0;bb=H+5408|0;cb=H+8|0;db=H+9944|0;eb=H+14216|0;fb=H+12|0;gb=H+11540|0;hb=H+12488|0;ib=H+12472|0;jb=H+11332|0;kb=H+10680|0;lb=H+11736|0;mb=H+60|0;nb=H+10060|0;ob=H+14340|0;pb=H+9200|0;qb=H+10112|0;rb=H+14236|0;sb=H+10540|0;tb=H+3176|0;ub=H+952|0;vb=H+11396|0;wb=H+10808|0;xb=H+9992|0;yb=H+11460|0;zb=H+10936|0;Ab=H+14408|0;Bb=H+14392|0;Cb=H+13084|0;Db=H+13080|0;Eb=H+72|0;Fb=H+76|0;Gb=H+14200|0;Hb=H+200|0;Ib=H+196|0;Jb=H+172|0;Kb=H+204|0;Lb=H+208|0;Mb=H+212|0;Nb=H+216|0;Ob=H+220|0;Pb=H+224|0;Qb=H+180|0;Rb=Qb;Sb=H+13112|0;Tb=H+184|0;Ub=H+13116|0;Vb=H+188|0;Wb=H+13120|0;Xb=H+192|0;Yb=H+13124|0;Zb=H+13128|0;_b=H+13132|0;$b=H+13136|0;ac=H+13140|0;bc=H+13144|0;cc=H+13148|0;dc=H+13152|0;ec=H+13156|0;fc=n|0;gc=H+364|0;hc=H+13100|0;ic=H+13104|0;jc=H+9972|0;kc=m|0;lc=H+11256|0;mc=H+11252|0;nc=o|0;oc=H+11164|0;pc=H+228|0;qc=H+168|0;rc=H+13092|0;sc=H+13096|0;tc=p|0;uc=p+128|0;vc=p+256|0;wc=p+384|0;xc=p+512|0;yc=p+640|0;zc=p+768|0;Ac=p+896|0;Bc=H+10056|0;Cc=H+10556|0;Dc=H+9976|0;Ec=H+9968|0;Fc=H+9856|0;Gc=H+28|0;Hc=H+11744|0;Ic=Hc;Jc=H+11748|0;Kc=H+11636|0;Mc=H+11708|0;Nc=H+11808|0;Oc=H+11660|0;Pc=H+9148|0;Qc=H+11656|0;Rc=H+11648|0;Sc=H+11652|0;Tc=H+11776|0;Uc=Tc;Vc=H+11780|0;Wc=H+11644|0;Xc=H+11640|0;Yc=H+11716|0;Zc=H+11676|0;_c=Zc;$c=H+11724|0;ad=H+11816|0;bd=H+11692|0;cd=Zc;Zc=Hc;dd=H+13836|0;ed=H+10132|0;fd=Z;gd=H+7856|0;hd=H+7864|0;id=H+10136|0;jd=u+11824|0;kd=u+12484|0;ld=Y;md=u+9860|0;nd=H+9864|0;od=u+9864|0;pd=H+9868|0;qd=u+9868|0;rd=u+13664|0;sd=u+13672|0;td=u+13676|0;ud=u+13680|0;vd=u+13684|0;wd=u+13688|0;xd=u+13692|0;yd=u+13696|0;zd=u+13700|0;Ad=u+9924|0;Bd=u+9960|0;Cd=u+9984|0;Dd=H+14100|0;Ed=u+14100|0;Fd=u+784|0;Gd=Fd;Hd=t+13936|0;Id=H+13940|0;Jd=t+13940|0;Kd=t+12488|0;Ld=t+11744|0;Md=t+11736|0;Nd=t+11740|0;Od=z|0;Pd=A|0;Qd=B|0;Rd=t+9960|0;Sd=H+9136|0;Td=t+11824|0;Ud=t+12484|0;Vd=t+9860|0;Wd=t+9864|0;Xd=t+9868|0;Yd=t+13664|0;Zd=t+13672|0;_d=t+13676|0;$d=t+13680|0;ae=t+13684|0;be=t+13688|0;ce=t+13692|0;de=t+13696|0;ee=t+9924|0;fe=t+784|0;ge=t+14340|0;he=t+180|0;ie=t+184|0;je=t+188|0;ke=t+192|0;le=t+196|0;me=t+200|0;ne=t+204|0;oe=t+208|0;pe=t+14236|0;re=t+14100|0;se=Q;te=jb;ue=H+9948|0;ve=H+11348|0;we=H+13980|0;xe=H+13984|0;ye=H+13988|0;ze=H+13992|0;Ae=we;Be=u+13980|0;Ce=Be;De=H+13956|0;Ee=H+13960|0;Fe=H+13964|0;Ge=H+13968|0;He=De;Ie=u+13956|0;Je=Ie;Ke=t+13980|0;Le=t+13956|0;Me=t+11744|0;Ne=t+11748|0;Oe=t+11776|0;Pe=t+11780|0;Qe=H+9876|0;Re=H+9912|0;Se=H+32|0;Te=H+9932|0;Ue=H+13796|0;We=H+13800|0;Ye=H+13808|0;Ze=H+13804|0;_e=H+13784|0;$e=H+14592|0;af=H+108|0;bf=H+13824|0;cf=H+13996|0;df=H+13972|0;ff=ia;b:while(1){c[ka>>2]=0;c[la>>2]=ff;QTa(J,c[ma>>2]|0);NTa(J);if((c[na>>2]|0)>0){gf=(ff|0)>0;jf=0;do{kf=(ca(c[oa>>2]|0,ff)|0)+jf|0;lf=b[(c[pa>>2]|0)+(kf<<1)>>1]|0;c[C>>2]=2147483647;nf=c[L>>2]|0;if(((c[qa>>2]|0)-nf-(32-(c[I>>2]|0)+((c[M>>2]|0)-nf<<3)>>3)|0)<3e3){of=12;break b}if((c[ra>>2]|0)!=0){nf=c[ye>>2]|0;if(((c[cf>>2]|0)-nf-(32-(c[xe>>2]|0)+((c[ze>>2]|0)-nf<<3)>>3)|0)<3e3){of=16;break b}nf=c[Fe>>2]|0;if(((c[df>>2]|0)-nf-(32-(c[Ee>>2]|0)+((c[Ge>>2]|0)-nf<<3)>>3)|0)<3e3){of=16;break b}}c[ka>>2]=jf;c[la>>2]=ff;nf=8>>>((c[(c[sa>>2]|0)+800>>2]|0)>>>0);c[ua>>2]=(c[ua>>2]|0)+2;c[va>>2]=(c[va>>2]|0)+2;c[wa>>2]=(c[wa>>2]|0)+2;c[xa>>2]=(c[xa>>2]|0)+2;c[ya>>2]=(c[ya>>2]|0)+1;c[za>>2]=(c[za>>2]|0)+1;c[Aa>>2]=(c[Aa>>2]|0)+(nf<<1);c[Ba>>2]=(c[Ba>>2]|0)+nf;c[Ca>>2]=(c[Ca>>2]|0)+nf;if((c[_>>2]|0)==4){Kga(J);nf=c[la>>2]|0;pf=ca(c[oa>>2]|0,nf)|0;qf=c[ka>>2]|0;rf=pf+qf|0;sf=rf;tf=b[(c[pa>>2]|0)+(rf<<1)>>1]|0;uf=qf;vf=nf}else{sf=kf;tf=lf;uf=jf;vf=ff}lf=tf&65535;c:do{if((c[Da>>2]|0)==0){wf=uf}else{kf=c[(c[sa>>2]|0)+628>>2]|0;do{if((kf|0)==0){xf=0}else{nf=c[L>>2]|0;if((nf-(c[da>>2]|0)+(39-(c[I>>2]|0)+((c[M>>2]|0)-nf<<3)>>3)|0)<(kf|0)){xf=0;break}xf=(jf+ff|0)>0|0}}while(0);kf=(c[ha>>2]|0)==(ff|0);nf=(jf|0)==0;qf=kf&gf&nf?1:xf;d:do{switch(c[_>>2]|0){case 8:{if((uf|0)!=0){yf=qf;zf=uf;break d}yf=(vf|0)==0?qf:1;zf=0;break};case 2:{if((uf|0)!=0){Af=qf;Bf=uf;of=29;break d}Af=(vf|0)==0?qf:1;Bf=0;of=29;break};case 5:case 20:{if((c[bf>>2]|0)!=0){yf=qf;zf=uf;break d}if((uf|0)!=0){wf=uf;break c}if(((vf|0)%(c[_e>>2]|0)|0|0)==0){yf=qf;zf=0}else{wf=0;break c}break};case 1:{Af=qf;Bf=uf;of=29;break};default:{yf=qf;zf=uf}}}while(0);if((of|0)==29){of=0;yf=(c[ea>>2]|0)==0?Af:0;zf=Bf}if((yf|0)==0){wf=zf;break}do{if(!(kf&nf)){jUa(J);if((c[_>>2]|0)!=13){break}if((c[Id>>2]|0)==0){break}kSa(J)}}while(0);nf=c[da>>2]|0;kf=c[M>>2]|0;qf=kf-nf|0;rf=c[$e>>2]|0;do{if((rf|0)==0){Cf=qf}else{if(((c[aa>>2]|0)+(c[$>>2]|0)|0)<=0){Cf=qf;break}if(((((32-(c[I>>2]|0)+(kf-(c[L>>2]|0)<<3)|0)/8|0)+16+(c[af>>2]|0)+(c[ka>>2]|0)+(c[la>>2]|0)|0)%(100/(rf|0)|0|0)|0|0)!=0){Cf=qf;break}c[M>>2]=nf;Cf=0}}while(0);qf=c[sa>>2]|0;rf=c[qf+624>>2]|0;if((rf|0)!=0){kf=(ca(ff-(c[aa>>2]|0)|0,c[na>>2]|0)|0)+jf|0;mf[rf&2047](qf,nf,Cf,kf-(c[$>>2]|0)|0)}kf=c[Ga>>2]|0;if((kf|0)!=0){qf=(c[M>>2]|0)-(c[L>>2]|0)<<3;rf=32-(c[I>>2]|0)|0;if((rf-(c[Ue>>2]<<3)+qf|0)>=(kf<<3|0)){c[Ye>>2]=(c[Ye>>2]|0)+12;c[Ue>>2]=c[We>>2]}c[Ue>>2]=(qf+rf|0)/8|0}switch(c[_>>2]|0){case 13:{mSa(J);FRa(J);break};case 1:case 2:{vRa(J);iRa(J);break};case 5:case 20:{wqb(J,ff);break};default:{}}if((c[mb>>2]&512|0)!=0){rf=((c[M>>2]|0)-(c[L>>2]|0)<<3)+(32-(c[I>>2]|0))|0;c[P>>2]=(c[P>>2]|0)-(c[N>>2]|0)+rf;c[N>>2]=rf}c[da>>2]=(c[da>>2]|0)+Cf;c[ba>>2]=1;c[$>>2]=jf;c[aa>>2]=ff;wf=c[ka>>2]|0}}while(0);do{if((c[$>>2]|0)==(wf|0)){if(((c[aa>>2]|0)+1|0)!=(c[la>>2]|0)){break}c[ba>>2]=0}}while(0);c[Ea>>2]=0;c[Fa>>2]=0;rf=c[Ga>>2]|0;if((rf|0)!=0){qf=(c[M>>2]|0)-(c[L>>2]|0)<<3;kf=32-(c[I>>2]|0)|0;pf=c[Ye>>2]|0;if((kf-(c[Ue>>2]<<3)+qf|0)<(rf<<3|0)){Df=pf}else{rf=pf+12|0;c[Ye>>2]=rf;c[Ue>>2]=c[We>>2];Df=rf}rf=qf+kf|0;c[We>>2]=(rf|0)/8|0;if((Df|0)==0){c[Ye>>2]=12;Ef=12}else{Ef=Df}kf=c[Ze>>2]|0;qf=c[la>>2]|0;pf=c[_e>>2]|0;Ff=(ca((qf|0)%(pf|0)|0,c[na>>2]|0)|0)+wf|0;Rga(J,0,0,h,j)|0;Gf=kf+(Ef-12)|0;y=rf;a[Gf]=y;y=y>>8;a[Gf+1|0]=y;y=y>>8;a[Gf+2|0]=y;y=y>>8;a[Gf+3|0]=y;a[kf+(Ef-8)|0]=c[ma>>2];a[kf+(Ef-7)|0]=(qf|0)/(pf|0)|0;pf=kf+(Ef-6)|0;y=Ff&65535;a[pf]=y;y=y>>8;a[pf+1|0]=y;a[kf+(Ef-4)|0]=c[h>>2];a[kf+(Ef-3)|0]=c[j>>2];a[kf+(Ef-2)|0]=0;a[kf+(Ef-1)|0]=0}do{if((lf+65535&lf|0)==0){if((c[Ha>>2]&4|0)!=0){of=65;break}c[Ia>>2]=0;switch(lf|0){case 1:{c[lb>>2]=0;c[hb>>2]=1;c[Ic>>2]=0;c[Jc>>2]=0;Hf=0;If=0;break};case 2:{c[lb>>2]=1;c[hb>>2]=0;kf=c[Kc>>2]|0;pf=b[kf+(sf<<2)>>1]|0;c[Ic>>2]=pf;Ff=b[kf+(sf<<2)+2>>1]|0;c[Jc>>2]=Ff;Hf=Ff;If=pf;break};case 256:{c[lb>>2]=1;c[Ia>>2]=3;c[hb>>2]=0;pf=d[(c[Mc>>2]|0)+sf|0]|0;c[Nc>>2]=pf;Ff=Oc+(pf<<2)|0;c[Hc>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11712>>2]|0)+sf|0]|0;c[H+11812>>2]=Ff;pf=Oc+8+(Ff<<2)|0;c[H+11752>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;Hf=0;If=0;break};case 4:{c[lb>>2]=1;c[Ia>>2]=1;c[hb>>2]=0;pf=c[ta>>2]|0;Ff=c[Pc>>2]|0;c[Hc>>2]=b[Ff+(pf<<2)>>1]|0;c[H+11748>>2]=b[Ff+(pf<<2)+2>>1]|0;pf=c[H+12500>>2]|0;c[H+11752>>2]=b[Ff+(pf<<2)>>1]|0;c[H+11756>>2]=b[Ff+(pf<<2)+2>>1]|0;pf=c[H+12504>>2]|0;c[H+11760>>2]=b[Ff+(pf<<2)>>1]|0;c[H+11764>>2]=b[Ff+(pf<<2)+2>>1]|0;pf=c[H+12508>>2]|0;c[H+11768>>2]=b[Ff+(pf<<2)>>1]|0;c[H+11772>>2]=b[Ff+(pf<<2)+2>>1]|0;Hf=0;If=0;break};case 16:{c[lb>>2]=7;c[hb>>2]=0;pf=c[Qc>>2]|0;Ff=b[pf+(sf<<2)>>1]|0;kf=b[pf+(sf<<2)+2>>1]|0;HRa(J,Ff,kf)|0;Hf=kf;If=Ff;break};case 4096:{c[lb>>2]=7;c[hb>>2]=0;HRa(J,0,0)|0;Hf=0;If=0;break};case 128:{c[lb>>2]=3;c[hb>>2]=0;Ff=c[Rc>>2]|0;c[Ic>>2]=b[Ff+(sf<<2)>>1]|0;c[Jc>>2]=b[Ff+(sf<<2)+2>>1]|0;Ff=c[Sc>>2]|0;c[Uc>>2]=b[Ff+(sf<<2)>>1]|0;c[Vc>>2]=b[Ff+(sf<<2)+2>>1]|0;Hf=0;If=0;break};case 64:{c[lb>>2]=2;c[hb>>2]=0;Ff=c[Wc>>2]|0;kf=b[Ff+(sf<<2)>>1]|0;c[Uc>>2]=kf;pf=b[Ff+(sf<<2)+2>>1]|0;c[Vc>>2]=pf;Hf=pf;If=kf;break};case 32:{c[lb>>2]=1;c[hb>>2]=0;kf=c[Xc>>2]|0;pf=b[kf+(sf<<2)>>1]|0;c[Ic>>2]=pf;Ff=b[kf+(sf<<2)+2>>1]|0;c[Jc>>2]=Ff;Hf=Ff;If=pf;break};case 512:{c[lb>>2]=1;c[Ia>>2]=3;c[hb>>2]=0;pf=d[(c[Yc>>2]|0)+sf|0]|0;c[Nc>>2]=pf;Ff=_c+(pf<<2)|0;c[Hc>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11720>>2]|0)+sf|0]|0;c[H+11812>>2]=Ff;pf=_c+8+(Ff<<2)|0;c[H+11752>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;Hf=0;If=0;break};case 1024:{c[lb>>2]=2;c[Ia>>2]=3;c[hb>>2]=0;pf=d[(c[$c>>2]|0)+sf|0]|0;c[ad>>2]=pf;Ff=bd+(pf<<2)|0;c[Tc>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11780>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11728>>2]|0)+sf|0]|0;c[H+11820>>2]=Ff;pf=bd+8+(Ff<<2)|0;c[H+11784>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11788>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;Hf=0;If=0;break};case 2048:{c[lb>>2]=3;c[Ia>>2]=3;c[hb>>2]=0;pf=d[(c[Yc>>2]|0)+sf|0]|0;c[Nc>>2]=pf;Ff=cd+(pf<<2)|0;c[Hc>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11720>>2]|0)+sf|0]|0;c[H+11812>>2]=Ff;pf=cd+8+(Ff<<2)|0;c[H+11752>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;pf=d[(c[H+11724>>2]|0)+sf|0]|0;c[H+11816>>2]=pf;Ff=cd+16+(pf<<2)|0;c[H+11776>>2]=b[(c[Ff>>2]|0)+(sf<<2)>>1]|0;c[H+11780>>2]=b[(c[Ff>>2]|0)+(sf<<2)+2>>1]|0;Ff=d[(c[H+11728>>2]|0)+sf|0]|0;c[H+11820>>2]=Ff;pf=cd+24+(Ff<<2)|0;c[H+11784>>2]=b[(c[pf>>2]|0)+(sf<<2)>>1]|0;c[H+11788>>2]=b[(c[pf>>2]|0)+(sf<<2)+2>>1]|0;Hf=0;If=0;break};default:{KIb(c[sa>>2]|0,16,2632816,(Jf=i,i=i+1|0,i=i+7&-8,c[Jf>>2]=0,Jf)|0);i=Jf;Hf=0;If=0}}pf=c[Ja>>2]|0;e:do{if((pf|0)==2){Ff=c[ka>>2]|0;kf=c[la>>2]|0;qf=c[La>>2]|0;Gf=c[Ma>>2]|0;rf=c[Na>>2]|0;c[Oa>>2]=rf;c[Pa>>2]=rf;c[Qa>>2]=rf;c[Ra>>2]=rf;c[Sa>>2]=rf;c[Ta>>2]=rf;c[Ua>>2]=rf;c[Va>>2]=rf;Kf=qf<<3;qf=Gf<<3;do{if((c[_a>>2]|0)==0){if((c[Ha>>2]&4|0)==0){break}QTa(J,(c[Fa>>2]|0)+(c[ma>>2]|0)|0)}else{Gf=c[ma>>2]|0;Lf=(ca(c[oa>>2]|0,kf)|0)+Ff|0;Mf=c[(c[Dc>>2]|0)+(Lf<<2)>>2]|0;c[Ec>>2]=Mf;Nf=((Mf*139|0)+8192|0)>>>14;c[ma>>2]=Nf;Of=c[sa>>2]|0;Pf=c[Of+500>>2]|0;Qf=c[Of+504>>2]|0;if((Nf|0)<(Pf|0)){Rf=Pf}else{Rf=(Nf|0)>(Qf|0)?Qf:Nf}c[ma>>2]=Rf;c[jc>>2]=((ca(Mf,Mf)|0)+64|0)>>>7;do{if((c[Ha>>2]&4|0)==0){Mf=a[(c[(c[Fc>>2]|0)+1512>>2]|0)+Lf|0]|0;c[ma>>2]=Mf;Nf=Mf-Gf|0;c[Fa>>2]=Nf;if((c[Gc>>2]|0)!=2){Sf=Nf;break}if((Nf|0)<-2){Tf=-2}else{Tf=(Nf|0)>2?2:Nf}c[Fa>>2]=Tf;if((c[_>>2]|0)!=13){Sf=Tf;break}if((c[hb>>2]|0)!=0){Sf=Tf;break}do{if((c[xb>>2]|0)==3){if((Tf&1|0)==0){if((c[lb>>2]&4|0)==0){Uf=Tf;break}}c[Fa>>2]=0;Uf=0}else{Uf=Tf}}while(0);if((c[Ia>>2]|0)!=1){Sf=Uf;break}c[Fa>>2]=0;Sf=0}else{Sf=c[Fa>>2]|0}}while(0);QTa(J,Sf+Gf|0)}}while(0);Lf=c[La>>2]|0;Nf=c[Ma>>2]|0;Mf=kf<<4;Qf=Ff<<4;Pf=(c[$a>>2]|0)+((ca(Lf,Mf)|0)+Qf)|0;Of=Ff<<3;Vf=(ca(Nf,Mf)|0)+Of|0;Wf=(c[ab>>2]|0)+Vf|0;Xf=(c[bb>>2]|0)+Vf|0;Vf=c[cb>>2]|0;if((Qf+16|0)>(Vf|0)){of=421}else{if((Mf+16|0)>(c[fb>>2]|0)){of=421}else{Yf=Pf;Zf=Wf;_f=Xf}}do{if((of|0)==421){of=0;if((c[_>>2]|0)==108){Yf=Pf;Zf=Wf;_f=Xf;break}$f=c[db>>2]|0;ag=$f+32|0;bg=c[eb>>2]|0;cg=bg+Vf>>bg;bg=c[fb>>2]|0;dg=c[g>>2]|0;eg=dg+bg>>dg;Ve[c[gb>>2]&127](ag,Pf,Lf,Lf,16,16,Qf,Mf,Vf,bg);bg=Lf*18|0;dg=$f+(bg+32)|0;Ve[c[gb>>2]&127](dg,Wf,Nf,Nf,8,16,Of,Mf,cg,eg);fg=$f+(bg+48)|0;Ve[c[gb>>2]&127](fg,Xf,Nf,Nf,8,16,Of,Mf,cg,eg);Yf=ag;Zf=dg;_f=fg}}while(0);do{if((c[hb>>2]|0)==0){Mf=c[Aa>>2]|0;Of=c[Ba>>2]|0;Xf=c[Ca>>2]|0;if((c[ib>>2]|0)==0){gg=kb;hg=jb}else{Wf=(c[xb>>2]|0)==3;gg=Wf?kb:zb;hg=Wf?jb:yb}Wf=gg;Vf=hg;Qf=c[lb>>2]|0;if((Qf&1|0)==0){ig=Wf;jg=Vf;kg=Qf}else{mUa(J,Mf,Of,Xf,0,ub,Vf,Wf);ig=wb;jg=vb;kg=c[lb>>2]|0}if((kg&2|0)!=0){mUa(J,Mf,Of,Xf,1,tb,jg,ig)}do{if((c[mb>>2]&262144|0)==0){lg=Kf;mg=qf;ng=Lf;og=Nf}else{c[rb>>2]=0;Wf=Xe[c[sb>>2]&511](H,Mf,Yf,Lf,8)|0;Vf=Lf<<3;Qf=(Xe[c[sb>>2]&511](H,Mf+Vf|0,Yf+Vf|0,Lf,8)|0)+Wf|0;Wf=Qf+((c[(c[sa>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((Wf|0)<=0){lg=Kf;mg=qf;ng=Lf;og=Nf;break}Qf=Lf<<1;Vf=Xe[c[sb>>2]&511](H,Mf,Yf,Qf,8)|0;if((Wf|0)<=((Xe[c[sb>>2]&511](H,Mf+Lf|0,Yf+Lf|0,Qf,8)|0)+Vf|0)){lg=Kf;mg=qf;ng=Lf;og=Nf;break}c[rb>>2]=1;lg=Lf;mg=Nf;ng=Qf;og=Nf<<((c[Ja>>2]|0)==2)}}while(0);mf[c[nb>>2]&2047](c[ob>>2]|0,Yf,Mf,ng);Gf=Yf+8|0;Qf=Mf+8|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+128|0,Gf,Qf,ng);Vf=Yf+lg|0;Wf=Mf+lg|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+256|0,Vf,Wf,ng);Pf=lg+8|0;fg=Yf+Pf|0;dg=Mf+Pf|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+384|0,fg,dg,ng);do{if((c[mb>>2]&8192|0)==0){mf[c[nb>>2]&2047]((c[ob>>2]|0)+512|0,Zf,Of,og);mf[c[nb>>2]&2047]((c[ob>>2]|0)+640|0,_f,Xf,og);if((c[g>>2]|0)!=0){break}mf[c[nb>>2]&2047]((c[ob>>2]|0)+768|0,Zf+mg|0,Of+mg|0,og);mf[c[nb>>2]&2047]((c[ob>>2]|0)+896|0,_f+mg|0,Xf+mg|0,og)}else{c[Sa>>2]=1;c[Ta>>2]=1}}while(0);Pf=(ca(c[oa>>2]|0,kf)|0)+Ff|0;ag=c[ma>>2]|0;if((e[(c[pb>>2]|0)+(Pf<<1)>>1]|0)>=(ca(ag<<1,ag)|0)){pg=lg;qg=mg;rg=ng;sg=og;tg=rf;ug=rf;vg=rf;break}ag=Xe[c[qb>>2]&511](0,Yf,Mf,ng,8)|0;if((ag|0)<((c[ma>>2]|0)*20|0|0)){c[Oa>>2]=1;wg=1}else{wg=rf}ag=Xe[c[qb>>2]&511](0,Gf,Qf,ng,8)|0;if((ag|0)<((c[ma>>2]|0)*20|0|0)){c[Pa>>2]=1;xg=1}else{xg=rf}ag=Xe[c[qb>>2]&511](0,Vf,Wf,ng,8)|0;if((ag|0)<((c[ma>>2]|0)*20|0|0)){c[Qa>>2]=1;yg=1}else{yg=rf}ag=Xe[c[qb>>2]&511](0,fg,dg,ng,8)|0;if((ag|0)<((c[ma>>2]|0)*20|0|0)){c[Ra>>2]=1}ag=Xe[c[qb>>2]&511](0,Zf,Of,og,8)|0;if((ag|0)<((c[ma>>2]|0)*20|0|0)){c[Sa>>2]=1}ag=Xe[c[qb>>2]&511](0,_f,Xf,og,8)|0;if((ag|0)<((c[ma>>2]|0)*20|0|0)){c[Ta>>2]=1}if((c[g>>2]|0)!=0){pg=lg;qg=mg;rg=ng;sg=og;tg=wg;ug=xg;vg=yg;break}ag=Xe[c[qb>>2]&511](0,Zf+mg|0,Of+mg|0,og,8)|0;if((ag|0)<((c[ma>>2]|0)*20|0|0)){c[Ua>>2]=1}ag=Xe[c[qb>>2]&511](0,_f+mg|0,Xf+mg|0,og,8)|0;if((ag|0)>=((c[ma>>2]|0)*20|0|0)){pg=lg;qg=mg;rg=ng;sg=og;tg=wg;ug=xg;vg=yg;break}c[Va>>2]=1;pg=lg;qg=mg;rg=ng;sg=og;tg=wg;ug=xg;vg=yg}else{do{if((c[mb>>2]&262144|0)==0){zg=Kf;Ag=qf;Bg=Lf;Cg=Nf}else{c[rb>>2]=0;ag=Xe[c[Cc>>2]&511](H,Yf,0,Lf,8)|0;Pf=ag-400+(Xe[c[Cc>>2]&511](H,Yf+(Lf<<3)|0,0,Lf,8)|0)|0;if((Pf|0)<=0){zg=Kf;Ag=qf;Bg=Lf;Cg=Nf;break}ag=Lf<<1;eg=Xe[c[Cc>>2]&511](H,Yf,0,ag,8)|0;if((Pf|0)<=((Xe[c[Cc>>2]&511](H,Yf+Lf|0,0,ag,8)|0)+eg|0)){zg=Kf;Ag=qf;Bg=Lf;Cg=Nf;break}c[rb>>2]=1;zg=Lf;Ag=Nf;Bg=ag;Cg=Nf<<(((c[Ja>>2]|0)-2|0)>>>0<2>>>0)}}while(0);ef[c[Bc>>2]&4095](c[ob>>2]|0,Yf,Bg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+128|0,Yf+8|0,Bg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+256|0,Yf+zg|0,Bg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+384|0,Yf+(zg+8)|0,Bg);if((c[mb>>2]&8192|0)!=0){c[Sa>>2]=1;c[Ta>>2]=1;pg=zg;qg=Ag;rg=Bg;sg=Cg;tg=rf;ug=rf;vg=rf;break}ef[c[Bc>>2]&4095]((c[ob>>2]|0)+512|0,Zf,Cg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+640|0,_f,Cg);if((c[g>>2]|0)!=0){pg=zg;qg=Ag;rg=Bg;sg=Cg;tg=rf;ug=rf;vg=rf;break}Xf=c[Bc>>2]|0;Of=(c[ob>>2]|0)+768|0;if((c[eb>>2]|0)==0){ef[Xf&4095](Of,Zf+8|0,Cg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,_f+8|0,Cg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1024|0,Zf+Ag|0,Cg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1152|0,_f+Ag|0,Cg);dg=Ag+8|0;ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1280|0,Zf+dg|0,Cg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1408|0,_f+dg|0,Cg);pg=zg;qg=Ag;rg=Bg;sg=Cg;tg=rf;ug=rf;vg=rf;break}else{ef[Xf&4095](Of,Zf+Ag|0,Cg);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,_f+Ag|0,Cg);pg=zg;qg=Ag;rg=Bg;sg=Cg;tg=rf;ug=rf;vg=rf;break}}}while(0);if((c[Ab>>2]|0)==0){Dg=0}else{if((tg|0)==0){lUa(tc,Yf,rg)}if((ug|0)==0){lUa(uc,Yf+8|0,rg);Eg=c[Qa>>2]|0}else{Eg=vg}if((Eg|0)==0){lUa(vc,Yf+pg|0,rg)}if((c[Ra>>2]|0)==0){lUa(wc,Yf+(pg+8)|0,rg)}if((c[Sa>>2]|0)==0){lUa(xc,Zf,sg)}if((c[Ta>>2]|0)==0){lUa(yc,_f,sg)}do{if((c[g>>2]|0)==0){if((c[Ua>>2]|0)==0){lUa(zc,Zf+qg|0,sg)}if((c[Va>>2]|0)!=0){break}lUa(Ac,_f+qg|0,sg)}}while(0);nrc(Ka|0,c[ob>>2]|0,1024)|0;Dg=0}do{do{if((c[r+(Dg<<2)>>2]|0)==0){rf=Xe[c[Bb>>2]&511](J,(c[ob>>2]|0)+(Dg<<7)|0,Dg,c[ma>>2]|0,l)|0;c[J+180+(Dg<<2)>>2]=rf;if((c[l>>2]|0)==0){break}Nf=c[ob>>2]|0;Lf=c[Cb>>2]|0;qf=c[Db>>2]|0;Kf=(c[hb>>2]|0)!=0|0;if((Kf|0)>(rf|0)){break}Ff=Lf&65535;kf=qf&65535;Of=0;Xf=Kf;while(1){Kf=Nf+(Dg<<7)+(d[J+368+Xf|0]<<1)|0;dg=b[Kf>>1]|0;fg=dg<<16>>16;if((fg|0)>(Lf|0)){Fg=Ff;Gg=Of+1|0}else{Wf=(fg|0)<(qf|0);Fg=Wf?kf:dg;Gg=(Wf&1)+Of|0}b[Kf>>1]=Fg;Kf=Xf+1|0;if((Kf|0)>(rf|0)){break}else{Of=Gg;Xf=Kf}}if((Gg|0)==0){break}Xf=c[sa>>2]|0;if((c[Xf+296>>2]|0)!=0){break}KIb(Xf,32,2630632,(Jf=i,i=i+24|0,c[Jf>>2]=Gg,c[Jf+8>>2]=qf,c[Jf+16>>2]=Lf,Jf)|0);i=Jf}else{c[J+180+(Dg<<2)>>2]=-1}}while(0);Dg=Dg+1|0;}while((Dg|0)<8);if((c[Ab>>2]|0)!=0){Xf=0;do{if((c[r+(Xf<<2)>>2]|0)==0){Of=c[ob>>2]|0;rf=Of+(Xf<<7)|0;kf=p+(Xf<<7)|0;Ff=c[ma>>2]|0;Nf=c[gc>>2]|0;if((b[4945388]|0)==0){Kf=0;do{Wf=Kf<<3;Hg=(Kf|0)==0?11585.237502960395:16384.0;Ig=Hg*.7071067811865476;Jg=+(Kf|0)*.39269908169872414;dg=0;do{fg=dg+Wf+(J+11184)|0;Vf=(dg|0)==0;Kg=+(dg|0)*.39269908169872414;Qf=0;do{Lg=+U(Kg*(+(Qf|0)+.5));if(Vf){Gf=0;do{Mf=d[fg]|0;b[9890776+(Mf<<7)+((Gf<<3)+Qf<<1)>>1]=Lc(+(Lg*Ig*+U(Jg*(+(Gf|0)+.5))))|0;Gf=Gf+1|0;}while((Gf|0)<8)}else{Gf=0;do{Mf=d[fg]|0;b[9890776+(Mf<<7)+((Gf<<3)+Qf<<1)>>1]=Lc(+(Lg*Hg*+U(Jg*(+(Gf|0)+.5))))|0;Gf=Gf+1|0;}while((Gf|0)<8)}Qf=Qf+1|0;}while((Qf|0)<8);dg=dg+1|0;}while((dg|0)<8);Kf=Kf+1|0;}while((Kf|0)<8)}Kf=Ff<<1;dg=Ff-1|1;if((c[hb>>2]|0)==0){Mg=dg;Ng=0;Og=32;Pg=hc;Qg=ic;Rg=1}else{do{if((c[pc>>2]|0)==0){if((Xf|0)<4){Sg=dg;Tg=c[qc>>2]|0;break}else{Sg=dg;Tg=c[Jb>>2]|0;break}}else{Sg=0;Tg=1}}while(0);dg=Tg<<3;Mg=Sg;Ng=1;Og=(ca(b[rf>>1]|0,dg)|0)+32|0;Pg=rc;Qg=sc;Rg=dg}dg=c[Pg>>2]|0;Ff=c[Qg>>2]|0;Wf=J+180+(Xf<<2)|0;Lf=c[Wf>>2]|0;qf=0;while(1){b[m+(qf<<1)>>1]=Og-(b[q+(Xf<<7)+(qf<<1)>>1]<<6);Qf=qf+1|0;if((Qf|0)<64){qf=Qf}else{Ug=0;Vg=0;break}}do{qf=p+(Xf<<7)+(Vg<<1)|0;Qf=b[qf>>1]|0;fg=Qf<<16>>16;Vf=(Qf<<16>>16>-1?fg:-fg|0)+144|0;fg=((((Vf|0)/2|0)+6912|0)/(Vf|0)|0)+15|0;b[qf>>1]=fg;Ug=(ca(fg,fg)|0)+Ug|0;Vg=Vg+1|0;}while((Vg|0)<64);fg=Erc(c[jc>>2]|0,0,Ug,(Ug|0)<0|0?-1:0)|0;qf=fg>>>19|G<<13;fg=-Mg|0;if((Ng|0)<=(Lf|0)){Vf=0;Qf=0;Gf=Ng;while(1){Mf=d[J+368+Gf|0]|0;ag=b[Of+(Xf<<7)+(Mf<<1)>>1]|0;if(ag<<16>>16==0){Wg=Qf;Xg=Vf+1|0}else{eg=ca(ag<<16>>16,Kf)|0;c[o+(Qf<<2)>>2]=Vf;ef[c[lc>>2]&4095](kc,9890776+(Mf<<7)|0,eg+(ag<<16>>16<0?fg:Mg)|0);Wg=Qf+1|0;Xg=0}ag=Gf+1|0;if((ag|0)>(Lf|0)){break}else{Vf=Xg;Qf=Wg;Gf=ag}}}Gf=(Ng|0)==0;Qf=-Rg|0;Vf=Lf;while(1){ag=hf[c[mc>>2]&1023](kc,kf,9890776,0)|0;if((Vf|0)>2){Yg=0;of=526}else{if((c[Ab>>2]|0)>2){Yg=0;of=526}else{Zg=0}}if((of|0)==526){while(1){of=0;eg=b[p+(Xf<<7)+(Yg<<1)>>1]|0;b[n+(Yg<<1)>>1]=(ca(ca(eg,eg)|0,b[m+(Yg<<1)>>1]|0)|0)+131072>>18;eg=Yg+1|0;if((eg|0)<64){Yg=eg;of=526}else{break}}qe[c[oc>>2]&1023](fc);Zg=1}do{if(Gf){_g=ag;$g=0;ah=0}else{eg=b[rf>>1]|0;if((ca(eg-1|0,Rg)|0)>>>0>2047>>>0){bh=ag;ch=0;dh=0}else{Mf=hf[c[mc>>2]&1023](kc,kf,9890776,Qf)|0;Pf=(Mf|0)<(ag|0);bh=Pf?Mf:ag;ch=Pf<<31>>31;dh=Pf?Qf:0}if((ca(eg+1|0,Rg)|0)>>>0>2047>>>0){_g=bh;$g=ch;ah=dh;break}eg=hf[c[mc>>2]&1023](kc,kf,9890776,Rg)|0;Pf=(eg|0)<(bh|0);_g=Pf?eg:bh;$g=Pf?1:ch;ah=Pf?Rg:dh}}while(0);ag=Vf+1|0;Pf=c[nc>>2]|0;eg=ah;Mf=$g;cg=0;bg=_g;$f=0;eh=1;fh=Ng;gh=0;hh=0;while(1){ih=d[J+368+fh|0]|0;jh=b[Of+(Xf<<7)+(ih<<1)>>1]|0;kh=jh<<16>>16;lh=c[Ab>>2]|0;if((lh|0)<3&(fh|0)>(ag|0)){mh=eg;nh=Mf;oh=cg;break}ph=jh<<16>>16!=0;if(ph){qh=ca(kh,Kf)|0;rh=qh+(jh<<16>>16<0?fg:Mg)|0;sh=eh+1|0;th=c[o+(eh<<2)>>2]|0}else{rh=0;sh=eh;th=Pf-1|0}qh=jh<<16>>16>-1?kh:-kh|0;uh=(fh|0)<(Vf|0);vh=fh+1|0;wh=th+vh|0;xh=J+368+wh|0;yh=(wh|0)<(Vf|0);wh=(th+$f<<7)+128|0;zh=th<<7;Ah=$f<<7;Bh=Ah|65;Ch=dg+Bh|0;Dh=Ff+Bh|0;Bh=(gh|0)==0;Eh=(hh<<7)+gh|0;Fh=Ff+Eh|0;Gh=dg+Eh|0;Eh=9890776+(ih<<7)|0;ih=(jh+62&65535)>>>0<125>>>0;jh=Ah|64;Ah=kh+jh|0;Hh=dg+Ah|0;Ih=Ff+Ah|0;Ah=Nf+fh|0;Jh=eg;Kh=Mf;Lh=cg;Mh=bg;Nh=-1;Oh=lh;while(1){lh=Nh+kh|0;if((Oh|0)<2){if((((lh|0)>-1?lh:-lh|0)|0)>(qh|0)){Ph=Mh;Qh=Lh;Rh=Kh;Sh=Jh}else{of=540}}else{of=540}f:do{if((of|0)==540){of=0;do{if((lh|0)==0){if(!uh){Th=d[Dh]|0;if(Bh){Uh=0;Vh=-Th|0;break}Uh=0;Vh=(d[Fh]|0)-Th-(d[Gh]|0)|0;break}Th=(b[Of+(Xf<<7)+(d[xh]<<1)>>1]|0)+64|0;Wh=Th>>>0>127>>>0?0:Th;Th=Wh+wh|0;if(yh){Uh=0;Vh=(d[dg+Th|0]|0)-(d[dg+(Wh+zh)|0]|0)-(d[Ch]|0)|0;break}else{Uh=0;Vh=(d[Ff+Th|0]|0)-(d[Ff+(Wh+zh)|0]|0)-(d[Ch]|0)|0;break}}else{Wh=ca(lh,Kf)|0;Th=((lh|0)<0?fg:Mg)+Wh|0;if((Th+2047|0)>>>0>4094>>>0){Ph=Mh;Qh=Lh;Rh=Kh;Sh=Jh;break f}if(ph){if(!ih){Uh=Th;Vh=0;break}Wh=lh+jh|0;if(uh){Uh=Th;Vh=(d[dg+Wh|0]|0)-(d[Hh]|0)|0;break}else{Uh=Th;Vh=(d[Ff+Wh|0]|0)-(d[Ih]|0)|0;break}}do{if(Zg){Wh=b[n+(d[Ah]<<1)>>1]|0;if(Wh<<16>>16==0){break}if((Wh<<16>>16^lh|0)>-1){Ph=Mh;Qh=Lh;Rh=Kh;Sh=Jh;break f}}}while(0);if(!uh){Wh=d[Dh]|0;if(Bh){Uh=Th;Vh=Wh;break}Uh=Th;Vh=(d[Gh]|0)+Wh-(d[Fh]|0)|0;break}Wh=(b[Of+(Xf<<7)+(d[xh]<<1)>>1]|0)+64|0;Xh=Wh>>>0>127>>>0?0:Wh;Wh=d[Ch]|0;Yh=Xh+zh|0;if(yh){Uh=Th;Vh=(d[dg+Yh|0]|0)+Wh-(d[dg+(Xh+wh)|0]|0)|0;break}else{Uh=Th;Vh=(d[Ff+Yh|0]|0)+Wh-(d[Ff+(Xh+wh)|0]|0)|0;break}}}while(0);Xh=ca(Vh,qf)|0;Wh=Uh-rh|0;Yh=(hf[c[mc>>2]&1023](kc,kf,Eh,Wh)|0)+Xh|0;Xh=(Yh|0)<(Mh|0);Ph=Xh?Yh:Mh;Qh=Xh?fh:Lh;Rh=Xh?Nh:Kh;Sh=Xh?Wh:Jh}}while(0);if((Nh|0)>=0){break}Jh=Sh;Kh=Rh;Lh=Qh;Mh=Ph;Nh=Nh+2|0;Oh=c[Ab>>2]|0}if(ph){Oh=kh+64|0;Zh=$f;_h=Oh>>>0>127>>>0?0:Oh;$h=0}else{Zh=hh;_h=gh;$h=$f+1|0}if((vh|0)<64){Pf=th;eg=Sh;Mf=Rh;cg=Qh;bg=Ph;$f=$h;eh=sh;fh=vh;gh=_h;hh=Zh}else{mh=Sh;nh=Rh;oh=Qh;break}}if((nh|0)==0){break}hh=d[J+368+oh|0]|0;gh=Of+(Xf<<7)+(hh<<1)|0;b[gh>>1]=(e[gh>>1]|0)+nh;g:do{if((oh|0)>(Vf|0)){ai=oh}else{gh=Vf;while(1){if((gh|0)<(Ng|0)){ai=gh;break g}if((b[Of+(Xf<<7)+(d[J+368+gh|0]<<1)>>1]|0)==0){gh=gh-1|0}else{ai=gh;break}}}}while(0);if((Ng|0)<=(ai|0)){gh=0;vh=0;kh=Ng;while(1){if((b[Of+(Xf<<7)+(d[J+368+kh|0]<<1)>>1]|0)==0){bi=vh;ci=gh+1|0}else{c[o+(vh<<2)>>2]=gh;bi=vh+1|0;ci=0}ph=kh+1|0;if((ph|0)>(ai|0)){break}else{gh=ci;vh=bi;kh=ph}}}ef[c[lc>>2]&4095](kc,9890776+(hh<<7)|0,mh);Vf=ai}c[Wf>>2]=Vf}Xf=Xf+1|0;}while((Xf|0)<8)}Xf=c[Eb>>2]|0;h:do{if((Xf|0)!=0){if((c[hb>>2]|0)==0){di=0;ei=Xf}else{break}while(1){Of=c[ob>>2]|0;kf=Of+(di<<7)|0;qf=J+180+(di<<2)|0;Ff=c[qf>>2]|0;dg=ei>>>31;fg=dg^1;Kf=(ei|0)<0?-ei|0:ei;i:do{if((Ff|0)>(dg<<31>>31|0)){if((Ff|0)<0){fi=0}else{Nf=(dg|0)!=1;Qf=0;rf=0;Gf=0;while(1){Lf=b[Of+(di<<7)+(d[J+368+Qf|0]<<1)>>1]|0;kh=Lf<<16>>16;vh=Lf<<16>>16>-1?kh:-kh|0;do{if((vh|0)==1){if(Nf&(Qf|0)==0){gi=Gf;hi=rf;break}gi=(a[1611528+rf|0]|0)+Gf|0;hi=0}else{if((vh|0)>1){break i}gi=Gf;hi=rf+1|0}}while(0);vh=Qf+1|0;if((vh|0)>(Ff|0)){fi=gi;break}else{Qf=vh;rf=hi;Gf=gi}}}if((fi|0)>=(Kf|0)){break}if((fg|0)<=(Ff|0)){Gf=fg;do{b[Of+(di<<7)+(d[J+368+Gf|0]<<1)>>1]=0;Gf=Gf+1|0;}while((Gf|0)<=(Ff|0))}if((b[kf>>1]|0)==0){c[qf>>2]=-1;break}else{c[qf>>2]=0;break}}}while(0);qf=di+1|0;if((qf|0)>=4){break h}di=qf;ei=c[Eb>>2]|0}}}while(0);Xf=c[Fb>>2]|0;j:do{if((Xf|0)!=0){if((c[hb>>2]|0)==0){ii=4;ji=Xf}else{break}while(1){Vf=c[ob>>2]|0;Wf=Vf+(ii<<7)|0;qf=J+180+(ii<<2)|0;kf=c[qf>>2]|0;Ff=ji>>>31;Of=Ff^1;fg=(ji|0)<0?-ji|0:ji;k:do{if((kf|0)>(Ff<<31>>31|0)){if((kf|0)<0){ki=0}else{Kf=(Ff|0)!=1;dg=0;hh=0;Gf=0;while(1){rf=b[Vf+(ii<<7)+(d[J+368+dg|0]<<1)>>1]|0;Qf=rf<<16>>16;Nf=rf<<16>>16>-1?Qf:-Qf|0;do{if((Nf|0)==1){if(Kf&(dg|0)==0){li=Gf;mi=hh;break}li=(a[1611528+hh|0]|0)+Gf|0;mi=0}else{if((Nf|0)>1){break k}li=Gf;mi=hh+1|0}}while(0);Nf=dg+1|0;if((Nf|0)>(kf|0)){ki=li;break}else{dg=Nf;hh=mi;Gf=li}}}if((ki|0)>=(fg|0)){break}if((Of|0)<=(kf|0)){Gf=Of;do{b[Vf+(ii<<7)+(d[J+368+Gf|0]<<1)>>1]=0;Gf=Gf+1|0;}while((Gf|0)<=(kf|0))}if((b[Wf>>1]|0)==0){c[qf>>2]=-1;break}else{c[qf>>2]=0;break}}}while(0);qf=ii+1|0;if((qf|0)>=8){break j}ii=qf;ji=c[Fb>>2]|0}}}while(0);do{if((c[Ha>>2]&8|0)!=0){if((c[Rb>>2]|0)==-1){c[Sb>>2]=8388607}if((c[Tb>>2]|0)==-1){c[Ub>>2]=8388607}if((c[Vb>>2]|0)==-1){c[Wb>>2]=8388607}if((c[Xb>>2]|0)==-1){c[Yb>>2]=8388607}if((c[Ib>>2]|0)==-1){c[Zb>>2]=8388607}if((c[Hb>>2]|0)==-1){c[_b>>2]=8388607}if((c[Kb>>2]|0)==-1){c[$b>>2]=8388607}if(!((c[Lb>>2]|0)==-1)){break}c[ac>>2]=8388607}}while(0);do{if((c[mb>>2]&8192|0)!=0){if((c[hb>>2]|0)==0){break}c[Hb>>2]=0;c[Ib>>2]=0;Xf=c[Jb>>2]|0;qf=((((Xf|0)/2|0)+1024|0)/(Xf|0)|0)&65535;Xf=c[ob>>2]|0;b[Xf+640>>1]=qf;b[Xf+512>>1]=qf;if((c[g>>2]|0)!=0){break}c[Kb>>2]=0;b[Xf+768>>1]=qf;c[Lb>>2]=0;b[Xf+896>>1]=qf;c[Mb>>2]=0;b[Xf+1024>>1]=qf;c[Nb>>2]=0;b[Xf+1152>>1]=qf;c[Ob>>2]=0;b[Xf+1280>>1]=qf;c[Pb>>2]=0;b[Xf+1408>>1]=qf}}while(0);do{if((c[Gb>>2]|0)!=0){if((c[Bb>>2]|0)==4){break}else{ni=0}do{qf=J+180+(ni<<2)|0;if((c[qf>>2]|0)>0){Xf=63;while(1){if((Xf|0)<=0){break}if((b[(c[ob>>2]|0)+(ni<<7)+(d[J+368+Xf|0]<<1)>>1]|0)==0){Xf=Xf-1|0}else{break}}c[qf>>2]=Xf}ni=ni+1|0;}while((ni|0)<8)}}while(0);switch(c[_>>2]|0){case 1:case 2:{xRa(J,c[ob>>2]|0,If,Hf);break e;break};case 13:{bSa(J,c[ob>>2]|0,If,Hf);break e;break};case 16:case 17:case 18:{SUa(J,c[ob>>2]|0,If,Hf);break e;break};case 19:{Thb(J,c[ob>>2]|0,If,Hf);break e;break};case 4:{Lga(J,c[ob>>2]|0,If,Hf);break e;break};case 5:case 20:case 22:case 6:case 7:{yqb(J,c[ob>>2]|0,If,Hf);break e;break};case 8:case 108:{AQa(J,c[ob>>2]|0);break e;break};default:{break e}}}else if((pf|0)==1){Wf=c[ka>>2]|0;kf=c[la>>2]|0;Vf=c[La>>2]|0;Of=c[Ma>>2]|0;fg=c[Na>>2]|0;c[Oa>>2]=fg;c[Pa>>2]=fg;c[Qa>>2]=fg;c[Ra>>2]=fg;c[Sa>>2]=fg;c[Ta>>2]=fg;Ff=Vf<<3;Vf=Of<<3;do{if((c[_a>>2]|0)==0){if((c[Ha>>2]&4|0)==0){break}QTa(J,(c[Fa>>2]|0)+(c[ma>>2]|0)|0)}else{Of=c[ma>>2]|0;Gf=(ca(c[oa>>2]|0,kf)|0)+Wf|0;hh=c[(c[Dc>>2]|0)+(Gf<<2)>>2]|0;c[Ec>>2]=hh;dg=((hh*139|0)+8192|0)>>>14;c[ma>>2]=dg;Kf=c[sa>>2]|0;Nf=c[Kf+500>>2]|0;Qf=c[Kf+504>>2]|0;if((dg|0)<(Nf|0)){oi=Nf}else{oi=(dg|0)>(Qf|0)?Qf:dg}c[ma>>2]=oi;c[jc>>2]=((ca(hh,hh)|0)+64|0)>>>7;do{if((c[Ha>>2]&4|0)==0){hh=a[(c[(c[Fc>>2]|0)+1512>>2]|0)+Gf|0]|0;c[ma>>2]=hh;dg=hh-Of|0;c[Fa>>2]=dg;if((c[Gc>>2]|0)!=2){pi=dg;break}if((dg|0)<-2){qi=-2}else{qi=(dg|0)>2?2:dg}c[Fa>>2]=qi;if((c[_>>2]|0)!=13){pi=qi;break}if((c[hb>>2]|0)!=0){pi=qi;break}do{if((c[xb>>2]|0)==3){if((qi&1|0)==0){if((c[lb>>2]&4|0)==0){ri=qi;break}}c[Fa>>2]=0;ri=0}else{ri=qi}}while(0);if((c[Ia>>2]|0)!=1){pi=ri;break}c[Fa>>2]=0;pi=0}else{pi=c[Fa>>2]|0}}while(0);QTa(J,pi+Of|0)}}while(0);Gf=c[La>>2]|0;Xf=c[Ma>>2]|0;qf=kf<<4;dg=Wf<<4;hh=(c[$a>>2]|0)+((ca(Gf,qf)|0)+dg)|0;Qf=kf<<3;Nf=Wf<<3;Kf=(ca(Xf,Qf)|0)+Nf|0;rf=(c[ab>>2]|0)+Kf|0;vh=(c[bb>>2]|0)+Kf|0;Kf=c[cb>>2]|0;if((dg+16|0)>(Kf|0)){of=178}else{if((qf+16|0)>(c[fb>>2]|0)){of=178}else{si=hh;ti=rf;ui=vh}}do{if((of|0)==178){of=0;if((c[_>>2]|0)==108){si=hh;ti=rf;ui=vh;break}kh=c[db>>2]|0;Lf=kh+32|0;gh=c[eb>>2]|0;ph=gh+Kf>>gh;gh=c[fb>>2]|0;fh=c[g>>2]|0;eh=fh+gh>>fh;Ve[c[gb>>2]&127](Lf,hh,Gf,Gf,16,16,dg,qf,Kf,gh);gh=Gf*18|0;fh=kh+(gh+32)|0;Ve[c[gb>>2]&127](fh,rf,Xf,Xf,8,8,Nf,Qf,ph,eh);$f=kh+(gh+48)|0;Ve[c[gb>>2]&127]($f,vh,Xf,Xf,8,8,Nf,Qf,ph,eh);si=Lf;ti=fh;ui=$f}}while(0);do{if((c[hb>>2]|0)==0){Qf=c[Aa>>2]|0;Nf=c[Ba>>2]|0;vh=c[Ca>>2]|0;if((c[ib>>2]|0)==0){vi=kb;wi=jb}else{rf=(c[xb>>2]|0)==3;vi=rf?kb:zb;wi=rf?jb:yb}rf=vi;Kf=wi;qf=c[lb>>2]|0;if((qf&1|0)==0){xi=rf;yi=Kf;zi=qf}else{mUa(J,Qf,Nf,vh,0,ub,Kf,rf);xi=wb;yi=vb;zi=c[lb>>2]|0}if((zi&2|0)!=0){mUa(J,Qf,Nf,vh,1,tb,yi,xi)}do{if((c[mb>>2]&262144|0)==0){Ai=Ff;Bi=Vf;Ci=Gf;Di=Xf}else{c[rb>>2]=0;rf=Xe[c[sb>>2]&511](H,Qf,si,Gf,8)|0;Kf=Gf<<3;qf=(Xe[c[sb>>2]&511](H,Qf+Kf|0,si+Kf|0,Gf,8)|0)+rf|0;rf=qf+((c[(c[sa>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((rf|0)<=0){Ai=Ff;Bi=Vf;Ci=Gf;Di=Xf;break}qf=Gf<<1;Kf=Xe[c[sb>>2]&511](H,Qf,si,qf,8)|0;if((rf|0)<=((Xe[c[sb>>2]&511](H,Qf+Gf|0,si+Gf|0,qf,8)|0)+Kf|0)){Ai=Ff;Bi=Vf;Ci=Gf;Di=Xf;break}c[rb>>2]=1;Ai=Gf;Bi=Xf;Ci=qf;Di=Xf<<((c[Ja>>2]|0)==2)}}while(0);mf[c[nb>>2]&2047](c[ob>>2]|0,si,Qf,Ci);Of=si+8|0;qf=Qf+8|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+128|0,Of,qf,Ci);Kf=si+Ai|0;rf=Qf+Ai|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+256|0,Kf,rf,Ci);dg=Ai+8|0;hh=si+dg|0;$f=Qf+dg|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+384|0,hh,$f,Ci);do{if((c[mb>>2]&8192|0)==0){mf[c[nb>>2]&2047]((c[ob>>2]|0)+512|0,ti,Nf,Di);mf[c[nb>>2]&2047]((c[ob>>2]|0)+640|0,ui,vh,Di);if((c[g>>2]|0)!=0){break}mf[c[nb>>2]&2047]((c[ob>>2]|0)+768|0,ti+Bi|0,Nf+Bi|0,Di);mf[c[nb>>2]&2047]((c[ob>>2]|0)+896|0,ui+Bi|0,vh+Bi|0,Di)}else{c[Sa>>2]=1;c[Ta>>2]=1}}while(0);dg=(ca(c[oa>>2]|0,kf)|0)+Wf|0;fh=c[ma>>2]|0;if((e[(c[pb>>2]|0)+(dg<<1)>>1]|0)>=(ca(fh<<1,fh)|0)){Ei=Ai;Fi=Bi;Gi=Ci;Hi=Di;Ii=fg;Ji=fg;Ki=fg;break}fh=Xe[c[qb>>2]&511](0,si,Qf,Ci,8)|0;if((fh|0)<((c[ma>>2]|0)*20|0|0)){c[Oa>>2]=1;Li=1}else{Li=fg}fh=Xe[c[qb>>2]&511](0,Of,qf,Ci,8)|0;if((fh|0)<((c[ma>>2]|0)*20|0|0)){c[Pa>>2]=1;Mi=1}else{Mi=fg}fh=Xe[c[qb>>2]&511](0,Kf,rf,Ci,8)|0;if((fh|0)<((c[ma>>2]|0)*20|0|0)){c[Qa>>2]=1;Ni=1}else{Ni=fg}fh=Xe[c[qb>>2]&511](0,hh,$f,Ci,8)|0;if((fh|0)<((c[ma>>2]|0)*20|0|0)){c[Ra>>2]=1}fh=Xe[c[qb>>2]&511](0,ti,Nf,Di,8)|0;if((fh|0)<((c[ma>>2]|0)*20|0|0)){c[Sa>>2]=1}fh=Xe[c[qb>>2]&511](0,ui,vh,Di,8)|0;if((fh|0)<((c[ma>>2]|0)*20|0|0)){c[Ta>>2]=1}if((c[g>>2]|0)!=0){Ei=Ai;Fi=Bi;Gi=Ci;Hi=Di;Ii=Li;Ji=Mi;Ki=Ni;break}fh=Xe[c[qb>>2]&511](0,ti+Bi|0,Nf+Bi|0,Di,8)|0;if((fh|0)<((c[ma>>2]|0)*20|0|0)){c[Ua>>2]=1}fh=Xe[c[qb>>2]&511](0,ui+Bi|0,vh+Bi|0,Di,8)|0;if((fh|0)>=((c[ma>>2]|0)*20|0|0)){Ei=Ai;Fi=Bi;Gi=Ci;Hi=Di;Ii=Li;Ji=Mi;Ki=Ni;break}c[Va>>2]=1;Ei=Ai;Fi=Bi;Gi=Ci;Hi=Di;Ii=Li;Ji=Mi;Ki=Ni}else{do{if((c[mb>>2]&262144|0)==0){Oi=Ff;Pi=Vf;Qi=Gf;Ri=Xf}else{c[rb>>2]=0;fh=Xe[c[Cc>>2]&511](H,si,0,Gf,8)|0;dg=fh-400+(Xe[c[Cc>>2]&511](H,si+(Gf<<3)|0,0,Gf,8)|0)|0;if((dg|0)<=0){Oi=Ff;Pi=Vf;Qi=Gf;Ri=Xf;break}fh=Gf<<1;Lf=Xe[c[Cc>>2]&511](H,si,0,fh,8)|0;if((dg|0)<=((Xe[c[Cc>>2]&511](H,si+Gf|0,0,fh,8)|0)+Lf|0)){Oi=Ff;Pi=Vf;Qi=Gf;Ri=Xf;break}c[rb>>2]=1;Oi=Gf;Pi=Xf;Qi=fh;Ri=Xf<<(((c[Ja>>2]|0)-2|0)>>>0<2>>>0)}}while(0);ef[c[Bc>>2]&4095](c[ob>>2]|0,si,Qi);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+128|0,si+8|0,Qi);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+256|0,si+Oi|0,Qi);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+384|0,si+(Oi+8)|0,Qi);if((c[mb>>2]&8192|0)!=0){c[Sa>>2]=1;c[Ta>>2]=1;Ei=Oi;Fi=Pi;Gi=Qi;Hi=Ri;Ii=fg;Ji=fg;Ki=fg;break}ef[c[Bc>>2]&4095]((c[ob>>2]|0)+512|0,ti,Ri);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+640|0,ui,Ri);if((c[g>>2]|0)!=0){Ei=Oi;Fi=Pi;Gi=Qi;Hi=Ri;Ii=fg;Ji=fg;Ki=fg;break}vh=c[Bc>>2]|0;Nf=(c[ob>>2]|0)+768|0;if((c[eb>>2]|0)==0){ef[vh&4095](Nf,ti+8|0,Ri);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,ui+8|0,Ri);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1024|0,ti+Pi|0,Ri);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1152|0,ui+Pi|0,Ri);$f=Pi+8|0;ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1280|0,ti+$f|0,Ri);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1408|0,ui+$f|0,Ri);Ei=Oi;Fi=Pi;Gi=Qi;Hi=Ri;Ii=fg;Ji=fg;Ki=fg;break}else{ef[vh&4095](Nf,ti+Pi|0,Ri);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,ui+Pi|0,Ri);Ei=Oi;Fi=Pi;Gi=Qi;Hi=Ri;Ii=fg;Ji=fg;Ki=fg;break}}}while(0);if((c[Ab>>2]|0)==0){Si=0}else{if((Ii|0)==0){lUa(tc,si,Gi)}if((Ji|0)==0){lUa(uc,si+8|0,Gi);Ti=c[Qa>>2]|0}else{Ti=Ki}if((Ti|0)==0){lUa(vc,si+Ei|0,Gi)}if((c[Ra>>2]|0)==0){lUa(wc,si+(Ei+8)|0,Gi)}if((c[Sa>>2]|0)==0){lUa(xc,ti,Hi)}if((c[Ta>>2]|0)==0){lUa(yc,ui,Hi)}do{if((c[g>>2]|0)==0){if((c[Ua>>2]|0)==0){lUa(zc,ti+Fi|0,Hi)}if((c[Va>>2]|0)!=0){break}lUa(Ac,ui+Fi|0,Hi)}}while(0);nrc(Ka|0,c[ob>>2]|0,768)|0;Si=0}do{do{if((c[r+(Si<<2)>>2]|0)==0){fg=Xe[c[Bb>>2]&511](J,(c[ob>>2]|0)+(Si<<7)|0,Si,c[ma>>2]|0,s)|0;c[J+180+(Si<<2)>>2]=fg;if((c[s>>2]|0)==0){break}Xf=c[ob>>2]|0;Gf=c[Cb>>2]|0;Vf=c[Db>>2]|0;Ff=(c[hb>>2]|0)!=0|0;if((Ff|0)>(fg|0)){break}Wf=Gf&65535;kf=Vf&65535;Nf=0;vh=Ff;while(1){Ff=Xf+(Si<<7)+(d[J+368+vh|0]<<1)|0;$f=b[Ff>>1]|0;hh=$f<<16>>16;if((hh|0)>(Gf|0)){Ui=Wf;Vi=Nf+1|0}else{rf=(hh|0)<(Vf|0);Ui=rf?kf:$f;Vi=(rf&1)+Nf|0}b[Ff>>1]=Ui;Ff=vh+1|0;if((Ff|0)>(fg|0)){break}else{Nf=Vi;vh=Ff}}if((Vi|0)==0){break}vh=c[sa>>2]|0;if((c[vh+296>>2]|0)!=0){break}KIb(vh,32,2630632,(Jf=i,i=i+24|0,c[Jf>>2]=Vi,c[Jf+8>>2]=Vf,c[Jf+16>>2]=Gf,Jf)|0);i=Jf}else{c[J+180+(Si<<2)>>2]=-1}}while(0);Si=Si+1|0;}while((Si|0)<6);if((c[Ab>>2]|0)!=0){vh=0;do{if((c[r+(vh<<2)>>2]|0)==0){Nf=c[ob>>2]|0;fg=Nf+(vh<<7)|0;kf=p+(vh<<7)|0;Wf=c[ma>>2]|0;Xf=c[gc>>2]|0;if((b[4945388]|0)==0){Ff=0;do{rf=Ff<<3;Jg=(Ff|0)==0?11585.237502960395:16384.0;Hg=Jg*.7071067811865476;Ig=+(Ff|0)*.39269908169872414;$f=0;do{hh=$f+rf+(J+11184)|0;Kf=($f|0)==0;Kg=+($f|0)*.39269908169872414;qf=0;do{Lg=+U(Kg*(+(qf|0)+.5));if(Kf){Of=0;do{Qf=d[hh]|0;b[9890776+(Qf<<7)+((Of<<3)+qf<<1)>>1]=Lc(+(Lg*Hg*+U(Ig*(+(Of|0)+.5))))|0;Of=Of+1|0;}while((Of|0)<8)}else{Of=0;do{Qf=d[hh]|0;b[9890776+(Qf<<7)+((Of<<3)+qf<<1)>>1]=Lc(+(Lg*Jg*+U(Ig*(+(Of|0)+.5))))|0;Of=Of+1|0;}while((Of|0)<8)}qf=qf+1|0;}while((qf|0)<8);$f=$f+1|0;}while(($f|0)<8);Ff=Ff+1|0;}while((Ff|0)<8)}Ff=Wf<<1;$f=Wf-1|1;if((c[hb>>2]|0)==0){Wi=$f;Xi=0;Yi=32;Zi=hc;_i=ic;$i=1}else{do{if((c[pc>>2]|0)==0){if((vh|0)<4){aj=$f;bj=c[qc>>2]|0;break}else{aj=$f;bj=c[Jb>>2]|0;break}}else{aj=0;bj=1}}while(0);$f=bj<<3;Wi=aj;Xi=1;Yi=(ca(b[fg>>1]|0,$f)|0)+32|0;Zi=rc;_i=sc;$i=$f}$f=c[Zi>>2]|0;Wf=c[_i>>2]|0;rf=J+180+(vh<<2)|0;Gf=c[rf>>2]|0;Vf=0;while(1){b[m+(Vf<<1)>>1]=Yi-(b[q+(vh<<7)+(Vf<<1)>>1]<<6);qf=Vf+1|0;if((qf|0)<64){Vf=qf}else{cj=0;dj=0;break}}do{Vf=p+(vh<<7)+(dj<<1)|0;qf=b[Vf>>1]|0;hh=qf<<16>>16;Kf=(qf<<16>>16>-1?hh:-hh|0)+144|0;hh=((((Kf|0)/2|0)+6912|0)/(Kf|0)|0)+15|0;b[Vf>>1]=hh;cj=(ca(hh,hh)|0)+cj|0;dj=dj+1|0;}while((dj|0)<64);hh=Erc(c[jc>>2]|0,0,cj,(cj|0)<0|0?-1:0)|0;Vf=hh>>>19|G<<13;hh=-Wi|0;if((Xi|0)<=(Gf|0)){Kf=0;qf=0;Of=Xi;while(1){Qf=d[J+368+Of|0]|0;fh=b[Nf+(vh<<7)+(Qf<<1)>>1]|0;if(fh<<16>>16==0){ej=qf;fj=Kf+1|0}else{Lf=ca(fh<<16>>16,Ff)|0;c[o+(qf<<2)>>2]=Kf;ef[c[lc>>2]&4095](kc,9890776+(Qf<<7)|0,Lf+(fh<<16>>16<0?hh:Wi)|0);ej=qf+1|0;fj=0}fh=Of+1|0;if((fh|0)>(Gf|0)){break}else{Kf=fj;qf=ej;Of=fh}}}Of=(Xi|0)==0;qf=-$i|0;Kf=Gf;while(1){fh=hf[c[mc>>2]&1023](kc,kf,9890776,0)|0;if((Kf|0)>2){gj=0;of=283}else{if((c[Ab>>2]|0)>2){gj=0;of=283}else{hj=0}}if((of|0)==283){while(1){of=0;Lf=b[p+(vh<<7)+(gj<<1)>>1]|0;b[n+(gj<<1)>>1]=(ca(ca(Lf,Lf)|0,b[m+(gj<<1)>>1]|0)|0)+131072>>18;Lf=gj+1|0;if((Lf|0)<64){gj=Lf;of=283}else{break}}qe[c[oc>>2]&1023](fc);hj=1}do{if(Of){ij=fh;jj=0;kj=0}else{Lf=b[fg>>1]|0;if((ca(Lf-1|0,$i)|0)>>>0>2047>>>0){lj=fh;mj=0;nj=0}else{Qf=hf[c[mc>>2]&1023](kc,kf,9890776,qf)|0;dg=(Qf|0)<(fh|0);lj=dg?Qf:fh;mj=dg<<31>>31;nj=dg?qf:0}if((ca(Lf+1|0,$i)|0)>>>0>2047>>>0){ij=lj;jj=mj;kj=nj;break}Lf=hf[c[mc>>2]&1023](kc,kf,9890776,$i)|0;dg=(Lf|0)<(lj|0);ij=dg?Lf:lj;jj=dg?1:mj;kj=dg?$i:nj}}while(0);fh=Kf+1|0;dg=c[nc>>2]|0;Lf=kj;Qf=jj;eh=0;ph=ij;gh=0;kh=1;bg=Xi;cg=0;Mf=0;while(1){eg=d[J+368+bg|0]|0;Pf=b[Nf+(vh<<7)+(eg<<1)>>1]|0;ag=Pf<<16>>16;Oh=c[Ab>>2]|0;if((Oh|0)<3&(bg|0)>(fh|0)){oj=Lf;pj=Qf;qj=eh;break}Nh=Pf<<16>>16!=0;if(Nh){Mh=ca(ag,Ff)|0;rj=Mh+(Pf<<16>>16<0?hh:Wi)|0;sj=kh+1|0;tj=c[o+(kh<<2)>>2]|0}else{rj=0;sj=kh;tj=dg-1|0}Mh=Pf<<16>>16>-1?ag:-ag|0;Lh=(bg|0)<(Kf|0);Kh=bg+1|0;Jh=tj+Kh|0;Eh=J+368+Jh|0;wh=(Jh|0)<(Kf|0);Jh=(tj+gh<<7)+128|0;yh=tj<<7;zh=gh<<7;Ch=zh|65;xh=$f+Ch|0;Fh=Wf+Ch|0;Ch=(cg|0)==0;Gh=(Mf<<7)+cg|0;Bh=Wf+Gh|0;Dh=$f+Gh|0;Gh=9890776+(eg<<7)|0;eg=(Pf+62&65535)>>>0<125>>>0;Pf=zh|64;zh=ag+Pf|0;uh=$f+zh|0;Ah=Wf+zh|0;zh=Xf+bg|0;Ih=Lf;Hh=Qf;jh=eh;ih=ph;qh=-1;lh=Oh;while(1){Oh=qh+ag|0;if((lh|0)<2){if((((Oh|0)>-1?Oh:-Oh|0)|0)>(Mh|0)){uj=ih;vj=jh;wj=Hh;xj=Ih}else{of=297}}else{of=297}l:do{if((of|0)==297){of=0;do{if((Oh|0)==0){if(!Lh){Wh=d[Fh]|0;if(Ch){yj=0;zj=-Wh|0;break}yj=0;zj=(d[Bh]|0)-Wh-(d[Dh]|0)|0;break}Wh=(b[Nf+(vh<<7)+(d[Eh]<<1)>>1]|0)+64|0;Xh=Wh>>>0>127>>>0?0:Wh;Wh=Xh+Jh|0;if(wh){yj=0;zj=(d[$f+Wh|0]|0)-(d[$f+(Xh+yh)|0]|0)-(d[xh]|0)|0;break}else{yj=0;zj=(d[Wf+Wh|0]|0)-(d[Wf+(Xh+yh)|0]|0)-(d[xh]|0)|0;break}}else{Xh=ca(Oh,Ff)|0;Wh=((Oh|0)<0?hh:Wi)+Xh|0;if((Wh+2047|0)>>>0>4094>>>0){uj=ih;vj=jh;wj=Hh;xj=Ih;break l}if(Nh){if(!eg){yj=Wh;zj=0;break}Xh=Oh+Pf|0;if(Lh){yj=Wh;zj=(d[$f+Xh|0]|0)-(d[uh]|0)|0;break}else{yj=Wh;zj=(d[Wf+Xh|0]|0)-(d[Ah]|0)|0;break}}do{if(hj){Xh=b[n+(d[zh]<<1)>>1]|0;if(Xh<<16>>16==0){break}if((Xh<<16>>16^Oh|0)>-1){uj=ih;vj=jh;wj=Hh;xj=Ih;break l}}}while(0);if(!Lh){Th=d[Fh]|0;if(Ch){yj=Wh;zj=Th;break}yj=Wh;zj=(d[Dh]|0)+Th-(d[Bh]|0)|0;break}Th=(b[Nf+(vh<<7)+(d[Eh]<<1)>>1]|0)+64|0;Xh=Th>>>0>127>>>0?0:Th;Th=d[xh]|0;Yh=Xh+yh|0;if(wh){yj=Wh;zj=(d[$f+Yh|0]|0)+Th-(d[$f+(Xh+Jh)|0]|0)|0;break}else{yj=Wh;zj=(d[Wf+Yh|0]|0)+Th-(d[Wf+(Xh+Jh)|0]|0)|0;break}}}while(0);Xh=ca(zj,Vf)|0;Th=yj-rj|0;Yh=(hf[c[mc>>2]&1023](kc,kf,Gh,Th)|0)+Xh|0;Xh=(Yh|0)<(ih|0);uj=Xh?Yh:ih;vj=Xh?bg:jh;wj=Xh?qh:Hh;xj=Xh?Th:Ih}}while(0);if((qh|0)>=0){break}Ih=xj;Hh=wj;jh=vj;ih=uj;qh=qh+2|0;lh=c[Ab>>2]|0}if(Nh){lh=ag+64|0;Aj=gh;Bj=lh>>>0>127>>>0?0:lh;Cj=0}else{Aj=Mf;Bj=cg;Cj=gh+1|0}if((Kh|0)<64){dg=tj;Lf=xj;Qf=wj;eh=vj;ph=uj;gh=Cj;kh=sj;bg=Kh;cg=Bj;Mf=Aj}else{oj=xj;pj=wj;qj=vj;break}}if((pj|0)==0){break}Mf=d[J+368+qj|0]|0;cg=Nf+(vh<<7)+(Mf<<1)|0;b[cg>>1]=(e[cg>>1]|0)+pj;m:do{if((qj|0)>(Kf|0)){Dj=qj}else{cg=Kf;while(1){if((cg|0)<(Xi|0)){Dj=cg;break m}if((b[Nf+(vh<<7)+(d[J+368+cg|0]<<1)>>1]|0)==0){cg=cg-1|0}else{Dj=cg;break}}}}while(0);if((Xi|0)<=(Dj|0)){cg=0;Kh=0;ag=Xi;while(1){if((b[Nf+(vh<<7)+(d[J+368+ag|0]<<1)>>1]|0)==0){Ej=Kh;Fj=cg+1|0}else{c[o+(Kh<<2)>>2]=cg;Ej=Kh+1|0;Fj=0}Nh=ag+1|0;if((Nh|0)>(Dj|0)){break}else{cg=Fj;Kh=Ej;ag=Nh}}}ef[c[lc>>2]&4095](kc,9890776+(Mf<<7)|0,oj);Kf=Dj}c[rf>>2]=Kf}vh=vh+1|0;}while((vh|0)<6)}vh=c[Eb>>2]|0;n:do{if((vh|0)!=0){if((c[hb>>2]|0)==0){Gj=0;Hj=vh}else{break}while(1){Nf=c[ob>>2]|0;kf=Nf+(Gj<<7)|0;Vf=J+180+(Gj<<2)|0;Wf=c[Vf>>2]|0;$f=Hj>>>31;hh=$f^1;Ff=(Hj|0)<0?-Hj|0:Hj;o:do{if((Wf|0)>($f<<31>>31|0)){if((Wf|0)<0){Ij=0}else{Xf=($f|0)!=1;qf=0;fg=0;Of=0;while(1){Gf=b[Nf+(Gj<<7)+(d[J+368+qf|0]<<1)>>1]|0;ag=Gf<<16>>16;Kh=Gf<<16>>16>-1?ag:-ag|0;do{if((Kh|0)==1){if(Xf&(qf|0)==0){Jj=Of;Kj=fg;break}Jj=(a[1611528+fg|0]|0)+Of|0;Kj=0}else{if((Kh|0)>1){break o}Jj=Of;Kj=fg+1|0}}while(0);Kh=qf+1|0;if((Kh|0)>(Wf|0)){Ij=Jj;break}else{qf=Kh;fg=Kj;Of=Jj}}}if((Ij|0)>=(Ff|0)){break}if((hh|0)<=(Wf|0)){Of=hh;do{b[Nf+(Gj<<7)+(d[J+368+Of|0]<<1)>>1]=0;Of=Of+1|0;}while((Of|0)<=(Wf|0))}if((b[kf>>1]|0)==0){c[Vf>>2]=-1;break}else{c[Vf>>2]=0;break}}}while(0);Vf=Gj+1|0;if((Vf|0)>=4){break n}Gj=Vf;Hj=c[Eb>>2]|0}}}while(0);vh=c[Fb>>2]|0;p:do{if((vh|0)!=0){if((c[hb>>2]|0)==0){Lj=4;Mj=vh}else{break}while(1){Kf=c[ob>>2]|0;rf=Kf+(Lj<<7)|0;Vf=J+180+(Lj<<2)|0;kf=c[Vf>>2]|0;Wf=Mj>>>31;Nf=Wf^1;hh=(Mj|0)<0?-Mj|0:Mj;q:do{if((kf|0)>(Wf<<31>>31|0)){if((kf|0)<0){Nj=0}else{Ff=(Wf|0)!=1;$f=0;Mf=0;Of=0;while(1){fg=b[Kf+(Lj<<7)+(d[J+368+$f|0]<<1)>>1]|0;qf=fg<<16>>16;Xf=fg<<16>>16>-1?qf:-qf|0;do{if((Xf|0)==1){if(Ff&($f|0)==0){Oj=Of;Pj=Mf;break}Oj=(a[1611528+Mf|0]|0)+Of|0;Pj=0}else{if((Xf|0)>1){break q}Oj=Of;Pj=Mf+1|0}}while(0);Xf=$f+1|0;if((Xf|0)>(kf|0)){Nj=Oj;break}else{$f=Xf;Mf=Pj;Of=Oj}}}if((Nj|0)>=(hh|0)){break}if((Nf|0)<=(kf|0)){Of=Nf;do{b[Kf+(Lj<<7)+(d[J+368+Of|0]<<1)>>1]=0;Of=Of+1|0;}while((Of|0)<=(kf|0))}if((b[rf>>1]|0)==0){c[Vf>>2]=-1;break}else{c[Vf>>2]=0;break}}}while(0);Vf=Lj+1|0;if((Vf|0)>=6){break p}Lj=Vf;Mj=c[Fb>>2]|0}}}while(0);do{if((c[Ha>>2]&8|0)!=0){if((c[Rb>>2]|0)==-1){c[Sb>>2]=8388607}if((c[Tb>>2]|0)==-1){c[Ub>>2]=8388607}if((c[Vb>>2]|0)==-1){c[Wb>>2]=8388607}if((c[Xb>>2]|0)==-1){c[Yb>>2]=8388607}if((c[Ib>>2]|0)==-1){c[Zb>>2]=8388607}if(!((c[Hb>>2]|0)==-1)){break}c[_b>>2]=8388607}}while(0);do{if((c[mb>>2]&8192|0)!=0){if((c[hb>>2]|0)==0){break}c[Hb>>2]=0;c[Ib>>2]=0;vh=c[Jb>>2]|0;Vf=((((vh|0)/2|0)+1024|0)/(vh|0)|0)&65535;vh=c[ob>>2]|0;b[vh+640>>1]=Vf;b[vh+512>>1]=Vf;if((c[g>>2]|0)!=0){break}c[Kb>>2]=0;b[vh+768>>1]=Vf;c[Lb>>2]=0;b[vh+896>>1]=Vf;c[Mb>>2]=0;b[vh+1024>>1]=Vf;c[Nb>>2]=0;b[vh+1152>>1]=Vf;c[Ob>>2]=0;b[vh+1280>>1]=Vf;c[Pb>>2]=0;b[vh+1408>>1]=Vf}}while(0);do{if((c[Gb>>2]|0)!=0){if((c[Bb>>2]|0)==4){break}if((c[Rb>>2]|0)>0){Vf=63;while(1){if((Vf|0)<=0){break}if((b[(c[ob>>2]|0)+(d[J+368+Vf|0]<<1)>>1]|0)==0){Vf=Vf-1|0}else{break}}c[Rb>>2]=Vf}if((c[Tb>>2]|0)>0){vh=63;while(1){if((vh|0)<=0){break}if((b[(c[ob>>2]|0)+128+(d[J+368+vh|0]<<1)>>1]|0)==0){vh=vh-1|0}else{break}}c[Tb>>2]=vh}if((c[Vb>>2]|0)>0){Vf=63;while(1){if((Vf|0)<=0){break}if((b[(c[ob>>2]|0)+256+(d[J+368+Vf|0]<<1)>>1]|0)==0){Vf=Vf-1|0}else{break}}c[Vb>>2]=Vf}if((c[Xb>>2]|0)>0){vh=63;while(1){if((vh|0)<=0){break}if((b[(c[ob>>2]|0)+384+(d[J+368+vh|0]<<1)>>1]|0)==0){vh=vh-1|0}else{break}}c[Xb>>2]=vh}if((c[Ib>>2]|0)>0){Vf=63;while(1){if((Vf|0)<=0){break}if((b[(c[ob>>2]|0)+512+(d[J+368+Vf|0]<<1)>>1]|0)==0){Vf=Vf-1|0}else{break}}c[Ib>>2]=Vf}if((c[Hb>>2]|0)>0){Qj=63}else{break}while(1){if((Qj|0)<=0){break}if((b[(c[ob>>2]|0)+640+(d[J+368+Qj|0]<<1)>>1]|0)==0){Qj=Qj-1|0}else{break}}c[Hb>>2]=Qj}}while(0);switch(c[_>>2]|0){case 1:case 2:{xRa(J,c[ob>>2]|0,If,Hf);break e;break};case 13:{bSa(J,c[ob>>2]|0,If,Hf);break e;break};case 16:case 17:case 18:{SUa(J,c[ob>>2]|0,If,Hf);break e;break};case 19:{Thb(J,c[ob>>2]|0,If,Hf);break e;break};case 4:{Lga(J,c[ob>>2]|0,If,Hf);break e;break};case 5:case 20:case 22:case 6:case 7:{yqb(J,c[ob>>2]|0,If,Hf);break e;break};case 8:case 108:{AQa(J,c[ob>>2]|0);break e;break};default:{break e}}}else{Vf=c[ka>>2]|0;vh=c[la>>2]|0;rf=c[La>>2]|0;kf=c[Ma>>2]|0;Kf=c[Na>>2]|0;c[Oa>>2]=Kf;c[Pa>>2]=Kf;c[Qa>>2]=Kf;c[Ra>>2]=Kf;c[Sa>>2]=Kf;c[Ta>>2]=Kf;c[Ua>>2]=Kf;c[Va>>2]=Kf;c[Wa>>2]=Kf;c[Xa>>2]=Kf;c[Ya>>2]=Kf;c[Za>>2]=Kf;Nf=rf<<3;rf=kf<<3;do{if((c[_a>>2]|0)==0){if((c[Ha>>2]&4|0)==0){break}QTa(J,(c[Fa>>2]|0)+(c[ma>>2]|0)|0)}else{kf=c[ma>>2]|0;hh=(ca(c[oa>>2]|0,vh)|0)+Vf|0;Wf=c[(c[Dc>>2]|0)+(hh<<2)>>2]|0;c[Ec>>2]=Wf;Of=((Wf*139|0)+8192|0)>>>14;c[ma>>2]=Of;Mf=c[sa>>2]|0;$f=c[Mf+500>>2]|0;Ff=c[Mf+504>>2]|0;if((Of|0)<($f|0)){Rj=$f}else{Rj=(Of|0)>(Ff|0)?Ff:Of}c[ma>>2]=Rj;c[jc>>2]=((ca(Wf,Wf)|0)+64|0)>>>7;do{if((c[Ha>>2]&4|0)==0){Wf=a[(c[(c[Fc>>2]|0)+1512>>2]|0)+hh|0]|0;c[ma>>2]=Wf;Of=Wf-kf|0;c[Fa>>2]=Of;if((c[Gc>>2]|0)!=2){Sj=Of;break}if((Of|0)<-2){Tj=-2}else{Tj=(Of|0)>2?2:Of}c[Fa>>2]=Tj;if((c[_>>2]|0)!=13){Sj=Tj;break}if((c[hb>>2]|0)!=0){Sj=Tj;break}do{if((c[xb>>2]|0)==3){if((Tj&1|0)==0){if((c[lb>>2]&4|0)==0){Uj=Tj;break}}c[Fa>>2]=0;Uj=0}else{Uj=Tj}}while(0);if((c[Ia>>2]|0)!=1){Sj=Uj;break}c[Fa>>2]=0;Sj=0}else{Sj=c[Fa>>2]|0}}while(0);QTa(J,Sj+kf|0)}}while(0);hh=c[La>>2]|0;Of=c[Ma>>2]|0;Wf=vh<<4;Ff=Vf<<4;$f=(c[$a>>2]|0)+((ca(hh,Wf)|0)+Ff)|0;Mf=(ca(Of,Wf)|0)+Ff|0;Xf=(c[ab>>2]|0)+Mf|0;qf=(c[bb>>2]|0)+Mf|0;Mf=c[cb>>2]|0;if((Ff+16|0)>(Mf|0)){of=664}else{if((Wf+16|0)>(c[fb>>2]|0)){of=664}else{Vj=$f;Wj=Xf;Xj=qf}}do{if((of|0)==664){of=0;if((c[_>>2]|0)==108){Vj=$f;Wj=Xf;Xj=qf;break}fg=c[db>>2]|0;Kh=fg+32|0;ag=c[eb>>2]|0;Gf=ag+Mf>>ag;ag=c[fb>>2]|0;cg=c[g>>2]|0;Nh=cg+ag>>cg;Ve[c[gb>>2]&127](Kh,$f,hh,hh,16,16,Ff,Wf,Mf,ag);ag=hh*18|0;cg=fg+(ag+32)|0;Ve[c[gb>>2]&127](cg,Xf,Of,Of,16,16,Ff,Wf,Gf,Nh);bg=fg+(ag+48)|0;Ve[c[gb>>2]&127](bg,qf,Of,Of,16,16,Ff,Wf,Gf,Nh);Vj=Kh;Wj=cg;Xj=bg}}while(0);do{if((c[hb>>2]|0)==0){Wf=c[Aa>>2]|0;Ff=c[Ba>>2]|0;qf=c[Ca>>2]|0;if((c[ib>>2]|0)==0){Yj=kb;Zj=jb}else{Xf=(c[xb>>2]|0)==3;Yj=Xf?kb:zb;Zj=Xf?jb:yb}Xf=Yj;Mf=Zj;$f=c[lb>>2]|0;if(($f&1|0)==0){_j=Xf;$j=Mf;ak=$f}else{mUa(J,Wf,Ff,qf,0,ub,Mf,Xf);_j=wb;$j=vb;ak=c[lb>>2]|0}if((ak&2|0)!=0){mUa(J,Wf,Ff,qf,1,tb,$j,_j)}do{if((c[mb>>2]&262144|0)==0){bk=Nf;ck=rf;dk=hh;ek=Of}else{c[rb>>2]=0;Xf=Xe[c[sb>>2]&511](H,Wf,Vj,hh,8)|0;Mf=hh<<3;$f=(Xe[c[sb>>2]&511](H,Wf+Mf|0,Vj+Mf|0,hh,8)|0)+Xf|0;Xf=$f+((c[(c[sa>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((Xf|0)<=0){bk=Nf;ck=rf;dk=hh;ek=Of;break}$f=hh<<1;Mf=Xe[c[sb>>2]&511](H,Wf,Vj,$f,8)|0;if((Xf|0)<=((Xe[c[sb>>2]&511](H,Wf+hh|0,Vj+hh|0,$f,8)|0)+Mf|0)){bk=Nf;ck=rf;dk=hh;ek=Of;break}c[rb>>2]=1;bk=hh;ck=Of;dk=$f;ek=Of<<((c[Ja>>2]|0)==2)}}while(0);mf[c[nb>>2]&2047](c[ob>>2]|0,Vj,Wf,dk);kf=Vj+8|0;$f=Wf+8|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+128|0,kf,$f,dk);Mf=Vj+bk|0;Xf=Wf+bk|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+256|0,Mf,Xf,dk);bg=bk+8|0;cg=Vj+bg|0;Kh=Wf+bg|0;mf[c[nb>>2]&2047]((c[ob>>2]|0)+384|0,cg,Kh,dk);do{if((c[mb>>2]&8192|0)==0){mf[c[nb>>2]&2047]((c[ob>>2]|0)+512|0,Wj,Ff,ek);mf[c[nb>>2]&2047]((c[ob>>2]|0)+640|0,Xj,qf,ek);if((c[g>>2]|0)!=0){break}mf[c[nb>>2]&2047]((c[ob>>2]|0)+768|0,Wj+ck|0,Ff+ck|0,ek);mf[c[nb>>2]&2047]((c[ob>>2]|0)+896|0,Xj+ck|0,qf+ck|0,ek)}else{c[Sa>>2]=1;c[Ta>>2]=1}}while(0);bg=(ca(c[oa>>2]|0,vh)|0)+Vf|0;Nh=c[ma>>2]|0;if((e[(c[pb>>2]|0)+(bg<<1)>>1]|0)>=(ca(Nh<<1,Nh)|0)){fk=bk;gk=ck;hk=dk;ik=ek;jk=Kf;kk=Kf;lk=Kf;break}Nh=Xe[c[qb>>2]&511](0,Vj,Wf,dk,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Oa>>2]=1;mk=1}else{mk=Kf}Nh=Xe[c[qb>>2]&511](0,kf,$f,dk,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Pa>>2]=1;nk=1}else{nk=Kf}Nh=Xe[c[qb>>2]&511](0,Mf,Xf,dk,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Qa>>2]=1;ok=1}else{ok=Kf}Nh=Xe[c[qb>>2]&511](0,cg,Kh,dk,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Ra>>2]=1}Nh=Xe[c[qb>>2]&511](0,Wj,Ff,ek,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Sa>>2]=1}Nh=Xe[c[qb>>2]&511](0,Xj,qf,ek,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Ta>>2]=1}if((c[g>>2]|0)!=0){fk=bk;gk=ck;hk=dk;ik=ek;jk=mk;kk=nk;lk=ok;break}Nh=Xe[c[qb>>2]&511](0,Wj+ck|0,Ff+ck|0,ek,8)|0;if((Nh|0)<((c[ma>>2]|0)*20|0|0)){c[Ua>>2]=1}Nh=Xe[c[qb>>2]&511](0,Xj+ck|0,qf+ck|0,ek,8)|0;if((Nh|0)>=((c[ma>>2]|0)*20|0|0)){fk=bk;gk=ck;hk=dk;ik=ek;jk=mk;kk=nk;lk=ok;break}c[Va>>2]=1;fk=bk;gk=ck;hk=dk;ik=ek;jk=mk;kk=nk;lk=ok}else{do{if((c[mb>>2]&262144|0)==0){pk=Nf;qk=rf;rk=hh;sk=Of}else{c[rb>>2]=0;Nh=Xe[c[Cc>>2]&511](H,Vj,0,hh,8)|0;bg=Nh-400+(Xe[c[Cc>>2]&511](H,Vj+(hh<<3)|0,0,hh,8)|0)|0;if((bg|0)<=0){pk=Nf;qk=rf;rk=hh;sk=Of;break}Nh=hh<<1;Gf=Xe[c[Cc>>2]&511](H,Vj,0,Nh,8)|0;if((bg|0)<=((Xe[c[Cc>>2]&511](H,Vj+hh|0,0,Nh,8)|0)+Gf|0)){pk=Nf;qk=rf;rk=hh;sk=Of;break}c[rb>>2]=1;pk=hh;qk=Of;rk=Nh;sk=Of<<(((c[Ja>>2]|0)-2|0)>>>0<2>>>0)}}while(0);ef[c[Bc>>2]&4095](c[ob>>2]|0,Vj,rk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+128|0,Vj+8|0,rk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+256|0,Vj+pk|0,rk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+384|0,Vj+(pk+8)|0,rk);if((c[mb>>2]&8192|0)!=0){c[Sa>>2]=1;c[Ta>>2]=1;fk=pk;gk=qk;hk=rk;ik=sk;jk=Kf;kk=Kf;lk=Kf;break}ef[c[Bc>>2]&4095]((c[ob>>2]|0)+512|0,Wj,sk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+640|0,Xj,sk);if((c[g>>2]|0)!=0){fk=pk;gk=qk;hk=rk;ik=sk;jk=Kf;kk=Kf;lk=Kf;break}qf=c[Bc>>2]|0;Ff=(c[ob>>2]|0)+768|0;if((c[eb>>2]|0)==0){ef[qf&4095](Ff,Wj+8|0,sk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,Xj+8|0,sk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1024|0,Wj+qk|0,sk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1152|0,Xj+qk|0,sk);Kh=qk+8|0;ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1280|0,Wj+Kh|0,sk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+1408|0,Xj+Kh|0,sk);fk=pk;gk=qk;hk=rk;ik=sk;jk=Kf;kk=Kf;lk=Kf;break}else{ef[qf&4095](Ff,Wj+qk|0,sk);ef[c[Bc>>2]&4095]((c[ob>>2]|0)+896|0,Xj+qk|0,sk);fk=pk;gk=qk;hk=rk;ik=sk;jk=Kf;kk=Kf;lk=Kf;break}}}while(0);if((c[Ab>>2]|0)==0){tk=0}else{if((jk|0)==0){lUa(tc,Vj,hk)}if((kk|0)==0){lUa(uc,Vj+8|0,hk);uk=c[Qa>>2]|0}else{uk=lk}if((uk|0)==0){lUa(vc,Vj+fk|0,hk)}if((c[Ra>>2]|0)==0){lUa(wc,Vj+(fk+8)|0,hk)}if((c[Sa>>2]|0)==0){lUa(xc,Wj,ik)}if((c[Ta>>2]|0)==0){lUa(yc,Xj,ik)}do{if((c[g>>2]|0)==0){if((c[Ua>>2]|0)==0){lUa(zc,Wj+gk|0,ik)}if((c[Va>>2]|0)!=0){break}lUa(Ac,Xj+gk|0,ik)}}while(0);nrc(Ka|0,c[ob>>2]|0,1536)|0;tk=0}do{do{if((c[r+(tk<<2)>>2]|0)==0){Kf=Xe[c[Bb>>2]&511](J,(c[ob>>2]|0)+(tk<<7)|0,tk,c[ma>>2]|0,k)|0;c[J+180+(tk<<2)>>2]=Kf;if((c[k>>2]|0)==0){break}Of=c[ob>>2]|0;hh=c[Cb>>2]|0;rf=c[Db>>2]|0;Nf=(c[hb>>2]|0)!=0|0;if((Nf|0)>(Kf|0)){break}Vf=hh&65535;vh=rf&65535;Ff=0;qf=Nf;while(1){Nf=Of+(tk<<7)+(d[J+368+qf|0]<<1)|0;Kh=b[Nf>>1]|0;cg=Kh<<16>>16;if((cg|0)>(hh|0)){vk=Vf;wk=Ff+1|0}else{Xf=(cg|0)<(rf|0);vk=Xf?vh:Kh;wk=(Xf&1)+Ff|0}b[Nf>>1]=vk;Nf=qf+1|0;if((Nf|0)>(Kf|0)){break}else{Ff=wk;qf=Nf}}if((wk|0)==0){break}qf=c[sa>>2]|0;if((c[qf+296>>2]|0)!=0){break}KIb(qf,32,2630632,(Jf=i,i=i+24|0,c[Jf>>2]=wk,c[Jf+8>>2]=rf,c[Jf+16>>2]=hh,Jf)|0);i=Jf}else{c[J+180+(tk<<2)>>2]=-1}}while(0);tk=tk+1|0;}while((tk|0)<12);if((c[Ab>>2]|0)!=0){qf=0;do{if((c[r+(qf<<2)>>2]|0)==0){Ff=c[ob>>2]|0;Kf=Ff+(qf<<7)|0;vh=p+(qf<<7)|0;Vf=c[ma>>2]|0;Of=c[gc>>2]|0;if((b[4945388]|0)==0){Nf=0;do{Xf=Nf<<3;Ig=(Nf|0)==0?11585.237502960395:16384.0;Jg=Ig*.7071067811865476;Hg=+(Nf|0)*.39269908169872414;Kh=0;do{cg=Kh+Xf+(J+11184)|0;Mf=(Kh|0)==0;Kg=+(Kh|0)*.39269908169872414;$f=0;do{Lg=+U(Kg*(+($f|0)+.5));if(Mf){kf=0;do{Wf=d[cg]|0;b[9890776+(Wf<<7)+((kf<<3)+$f<<1)>>1]=Lc(+(Lg*Jg*+U(Hg*(+(kf|0)+.5))))|0;kf=kf+1|0;}while((kf|0)<8)}else{kf=0;do{Wf=d[cg]|0;b[9890776+(Wf<<7)+((kf<<3)+$f<<1)>>1]=Lc(+(Lg*Ig*+U(Hg*(+(kf|0)+.5))))|0;kf=kf+1|0;}while((kf|0)<8)}$f=$f+1|0;}while(($f|0)<8);Kh=Kh+1|0;}while((Kh|0)<8);Nf=Nf+1|0;}while((Nf|0)<8)}Nf=Vf<<1;Kh=Vf-1|1;if((c[hb>>2]|0)==0){xk=Kh;yk=0;zk=32;Ak=hc;Bk=ic;Ck=1}else{do{if((c[pc>>2]|0)==0){if((qf|0)<4){Dk=Kh;Ek=c[qc>>2]|0;break}else{Dk=Kh;Ek=c[Jb>>2]|0;break}}else{Dk=0;Ek=1}}while(0);Kh=Ek<<3;xk=Dk;yk=1;zk=(ca(b[Kf>>1]|0,Kh)|0)+32|0;Ak=rc;Bk=sc;Ck=Kh}Kh=c[Ak>>2]|0;Vf=c[Bk>>2]|0;Xf=J+180+(qf<<2)|0;hh=c[Xf>>2]|0;rf=0;while(1){b[m+(rf<<1)>>1]=zk-(b[q+(qf<<7)+(rf<<1)>>1]<<6);$f=rf+1|0;if(($f|0)<64){rf=$f}else{Fk=0;Gk=0;break}}do{rf=p+(qf<<7)+(Gk<<1)|0;$f=b[rf>>1]|0;cg=$f<<16>>16;Mf=($f<<16>>16>-1?cg:-cg|0)+144|0;cg=((((Mf|0)/2|0)+6912|0)/(Mf|0)|0)+15|0;b[rf>>1]=cg;Fk=(ca(cg,cg)|0)+Fk|0;Gk=Gk+1|0;}while((Gk|0)<64);cg=Erc(c[jc>>2]|0,0,Fk,(Fk|0)<0|0?-1:0)|0;rf=cg>>>19|G<<13;cg=-xk|0;if((yk|0)<=(hh|0)){Mf=0;$f=0;kf=yk;while(1){Wf=d[J+368+kf|0]|0;Nh=b[Ff+(qf<<7)+(Wf<<1)>>1]|0;if(Nh<<16>>16==0){Hk=$f;Ik=Mf+1|0}else{Gf=ca(Nh<<16>>16,Nf)|0;c[o+($f<<2)>>2]=Mf;ef[c[lc>>2]&4095](kc,9890776+(Wf<<7)|0,Gf+(Nh<<16>>16<0?cg:xk)|0);Hk=$f+1|0;Ik=0}Nh=kf+1|0;if((Nh|0)>(hh|0)){break}else{Mf=Ik;$f=Hk;kf=Nh}}}kf=(yk|0)==0;$f=-Ck|0;Mf=hh;while(1){Nh=hf[c[mc>>2]&1023](kc,vh,9890776,0)|0;if((Mf|0)>2){Jk=0;of=769}else{if((c[Ab>>2]|0)>2){Jk=0;of=769}else{Kk=0}}if((of|0)==769){while(1){of=0;Gf=b[p+(qf<<7)+(Jk<<1)>>1]|0;b[n+(Jk<<1)>>1]=(ca(ca(Gf,Gf)|0,b[m+(Jk<<1)>>1]|0)|0)+131072>>18;Gf=Jk+1|0;if((Gf|0)<64){Jk=Gf;of=769}else{break}}qe[c[oc>>2]&1023](fc);Kk=1}do{if(kf){Lk=Nh;Mk=0;Nk=0}else{Gf=b[Kf>>1]|0;if((ca(Gf-1|0,Ck)|0)>>>0>2047>>>0){Ok=Nh;Pk=0;Qk=0}else{Wf=hf[c[mc>>2]&1023](kc,vh,9890776,$f)|0;bg=(Wf|0)<(Nh|0);Ok=bg?Wf:Nh;Pk=bg<<31>>31;Qk=bg?$f:0}if((ca(Gf+1|0,Ck)|0)>>>0>2047>>>0){Lk=Ok;Mk=Pk;Nk=Qk;break}Gf=hf[c[mc>>2]&1023](kc,vh,9890776,Ck)|0;bg=(Gf|0)<(Ok|0);Lk=bg?Gf:Ok;Mk=bg?1:Pk;Nk=bg?Ck:Qk}}while(0);Nh=Mf+1|0;bg=c[nc>>2]|0;Gf=Nk;Wf=Mk;ag=0;fg=Lk;kh=0;gh=1;ph=yk;eh=0;Qf=0;while(1){Lf=d[J+368+ph|0]|0;dg=b[Ff+(qf<<7)+(Lf<<1)>>1]|0;fh=dg<<16>>16;lh=c[Ab>>2]|0;if((lh|0)<3&(ph|0)>(Nh|0)){Rk=Gf;Sk=Wf;Tk=ag;break}qh=dg<<16>>16!=0;if(qh){ih=ca(fh,Nf)|0;Uk=ih+(dg<<16>>16<0?cg:xk)|0;Vk=gh+1|0;Wk=c[o+(gh<<2)>>2]|0}else{Uk=0;Vk=gh;Wk=bg-1|0}ih=dg<<16>>16>-1?fh:-fh|0;jh=(ph|0)<(Mf|0);Hh=ph+1|0;Ih=Wk+Hh|0;Gh=J+368+Ih|0;Jh=(Ih|0)<(Mf|0);Ih=(Wk+kh<<7)+128|0;wh=Wk<<7;yh=kh<<7;xh=yh|65;Eh=Kh+xh|0;Bh=Vf+xh|0;xh=(eh|0)==0;Dh=(Qf<<7)+eh|0;Ch=Vf+Dh|0;Fh=Kh+Dh|0;Dh=9890776+(Lf<<7)|0;Lf=(dg+62&65535)>>>0<125>>>0;dg=yh|64;yh=fh+dg|0;Lh=Kh+yh|0;zh=Vf+yh|0;yh=Of+ph|0;Ah=Gf;uh=Wf;Pf=ag;eg=fg;Mh=-1;Oh=lh;while(1){lh=Mh+fh|0;if((Oh|0)<2){if((((lh|0)>-1?lh:-lh|0)|0)>(ih|0)){Xk=eg;Yk=Pf;Zk=uh;_k=Ah}else{of=783}}else{of=783}r:do{if((of|0)==783){of=0;do{if((lh|0)==0){if(!jh){Th=d[Bh]|0;if(xh){$k=0;al=-Th|0;break}$k=0;al=(d[Ch]|0)-Th-(d[Fh]|0)|0;break}Th=(b[Ff+(qf<<7)+(d[Gh]<<1)>>1]|0)+64|0;Xh=Th>>>0>127>>>0?0:Th;Th=Xh+Ih|0;if(Jh){$k=0;al=(d[Kh+Th|0]|0)-(d[Kh+(Xh+wh)|0]|0)-(d[Eh]|0)|0;break}else{$k=0;al=(d[Vf+Th|0]|0)-(d[Vf+(Xh+wh)|0]|0)-(d[Eh]|0)|0;break}}else{Xh=ca(lh,Nf)|0;Th=((lh|0)<0?cg:xk)+Xh|0;if((Th+2047|0)>>>0>4094>>>0){Xk=eg;Yk=Pf;Zk=uh;_k=Ah;break r}if(qh){if(!Lf){$k=Th;al=0;break}Xh=lh+dg|0;if(jh){$k=Th;al=(d[Kh+Xh|0]|0)-(d[Lh]|0)|0;break}else{$k=Th;al=(d[Vf+Xh|0]|0)-(d[zh]|0)|0;break}}do{if(Kk){Xh=b[n+(d[yh]<<1)>>1]|0;if(Xh<<16>>16==0){break}if((Xh<<16>>16^lh|0)>-1){Xk=eg;Yk=Pf;Zk=uh;_k=Ah;break r}}}while(0);if(!jh){Wh=d[Bh]|0;if(xh){$k=Th;al=Wh;break}$k=Th;al=(d[Fh]|0)+Wh-(d[Ch]|0)|0;break}Wh=(b[Ff+(qf<<7)+(d[Gh]<<1)>>1]|0)+64|0;Xh=Wh>>>0>127>>>0?0:Wh;Wh=d[Eh]|0;Yh=Xh+wh|0;if(Jh){$k=Th;al=(d[Kh+Yh|0]|0)+Wh-(d[Kh+(Xh+Ih)|0]|0)|0;break}else{$k=Th;al=(d[Vf+Yh|0]|0)+Wh-(d[Vf+(Xh+Ih)|0]|0)|0;break}}}while(0);Xh=ca(al,rf)|0;Wh=$k-Uk|0;Yh=(hf[c[mc>>2]&1023](kc,vh,Dh,Wh)|0)+Xh|0;Xh=(Yh|0)<(eg|0);Xk=Xh?Yh:eg;Yk=Xh?ph:Pf;Zk=Xh?Mh:uh;_k=Xh?Wh:Ah}}while(0);if((Mh|0)>=0){break}Ah=_k;uh=Zk;Pf=Yk;eg=Xk;Mh=Mh+2|0;Oh=c[Ab>>2]|0}if(qh){Oh=fh+64|0;bl=kh;cl=Oh>>>0>127>>>0?0:Oh;dl=0}else{bl=Qf;cl=eh;dl=kh+1|0}if((Hh|0)<64){bg=Wk;Gf=_k;Wf=Zk;ag=Yk;fg=Xk;kh=dl;gh=Vk;ph=Hh;eh=cl;Qf=bl}else{Rk=_k;Sk=Zk;Tk=Yk;break}}if((Sk|0)==0){break}Qf=d[J+368+Tk|0]|0;eh=Ff+(qf<<7)+(Qf<<1)|0;b[eh>>1]=(e[eh>>1]|0)+Sk;s:do{if((Tk|0)>(Mf|0)){el=Tk}else{eh=Mf;while(1){if((eh|0)<(yk|0)){el=eh;break s}if((b[Ff+(qf<<7)+(d[J+368+eh|0]<<1)>>1]|0)==0){eh=eh-1|0}else{el=eh;break}}}}while(0);if((yk|0)<=(el|0)){eh=0;Hh=0;fh=yk;while(1){if((b[Ff+(qf<<7)+(d[J+368+fh|0]<<1)>>1]|0)==0){fl=Hh;gl=eh+1|0}else{c[o+(Hh<<2)>>2]=eh;fl=Hh+1|0;gl=0}qh=fh+1|0;if((qh|0)>(el|0)){break}else{eh=gl;Hh=fl;fh=qh}}}ef[c[lc>>2]&4095](kc,9890776+(Qf<<7)|0,Rk);Mf=el}c[Xf>>2]=Mf}qf=qf+1|0;}while((qf|0)<12)}qf=c[Eb>>2]|0;t:do{if((qf|0)!=0){if((c[hb>>2]|0)==0){hl=0;il=qf}else{break}while(1){Ff=c[ob>>2]|0;vh=Ff+(hl<<7)|0;rf=J+180+(hl<<2)|0;Vf=c[rf>>2]|0;Kh=il>>>31;cg=Kh^1;Nf=(il|0)<0?-il|0:il;u:do{if((Vf|0)>(Kh<<31>>31|0)){if((Vf|0)<0){jl=0}else{Of=(Kh|0)!=1;$f=0;Kf=0;kf=0;while(1){hh=b[Ff+(hl<<7)+(d[J+368+$f|0]<<1)>>1]|0;fh=hh<<16>>16;Hh=hh<<16>>16>-1?fh:-fh|0;do{if((Hh|0)==1){if(Of&($f|0)==0){kl=kf;ll=Kf;break}kl=(a[1611528+Kf|0]|0)+kf|0;ll=0}else{if((Hh|0)>1){break u}kl=kf;ll=Kf+1|0}}while(0);Hh=$f+1|0;if((Hh|0)>(Vf|0)){jl=kl;break}else{$f=Hh;Kf=ll;kf=kl}}}if((jl|0)>=(Nf|0)){break}if((cg|0)<=(Vf|0)){kf=cg;do{b[Ff+(hl<<7)+(d[J+368+kf|0]<<1)>>1]=0;kf=kf+1|0;}while((kf|0)<=(Vf|0))}if((b[vh>>1]|0)==0){c[rf>>2]=-1;break}else{c[rf>>2]=0;break}}}while(0);rf=hl+1|0;if((rf|0)>=4){break t}hl=rf;il=c[Eb>>2]|0}}}while(0);qf=c[Fb>>2]|0;v:do{if((qf|0)!=0){if((c[hb>>2]|0)==0){ml=4;nl=qf}else{break}while(1){Mf=c[ob>>2]|0;Xf=Mf+(ml<<7)|0;rf=J+180+(ml<<2)|0;vh=c[rf>>2]|0;Vf=nl>>>31;Ff=Vf^1;cg=(nl|0)<0?-nl|0:nl;w:do{if((vh|0)>(Vf<<31>>31|0)){if((vh|0)<0){ol=0}else{Nf=(Vf|0)!=1;Kh=0;Qf=0;kf=0;while(1){Kf=b[Mf+(ml<<7)+(d[J+368+Kh|0]<<1)>>1]|0;$f=Kf<<16>>16;Of=Kf<<16>>16>-1?$f:-$f|0;do{if((Of|0)==1){if(Nf&(Kh|0)==0){pl=kf;ql=Qf;break}pl=(a[1611528+Qf|0]|0)+kf|0;ql=0}else{if((Of|0)>1){break w}pl=kf;ql=Qf+1|0}}while(0);Of=Kh+1|0;if((Of|0)>(vh|0)){ol=pl;break}else{Kh=Of;Qf=ql;kf=pl}}}if((ol|0)>=(cg|0)){break}if((Ff|0)<=(vh|0)){kf=Ff;do{b[Mf+(ml<<7)+(d[J+368+kf|0]<<1)>>1]=0;kf=kf+1|0;}while((kf|0)<=(vh|0))}if((b[Xf>>1]|0)==0){c[rf>>2]=-1;break}else{c[rf>>2]=0;break}}}while(0);rf=ml+1|0;if((rf|0)>=12){break v}ml=rf;nl=c[Fb>>2]|0}}}while(0);do{if((c[Ha>>2]&8|0)!=0){if((c[Rb>>2]|0)==-1){c[Sb>>2]=8388607}if((c[Tb>>2]|0)==-1){c[Ub>>2]=8388607}if((c[Vb>>2]|0)==-1){c[Wb>>2]=8388607}if((c[Xb>>2]|0)==-1){c[Yb>>2]=8388607}if((c[Ib>>2]|0)==-1){c[Zb>>2]=8388607}if((c[Hb>>2]|0)==-1){c[_b>>2]=8388607}if((c[Kb>>2]|0)==-1){c[$b>>2]=8388607}if((c[Lb>>2]|0)==-1){c[ac>>2]=8388607}if((c[Mb>>2]|0)==-1){c[bc>>2]=8388607}if((c[Nb>>2]|0)==-1){c[cc>>2]=8388607}if((c[Ob>>2]|0)==-1){c[dc>>2]=8388607}if(!((c[Pb>>2]|0)==-1)){break}c[ec>>2]=8388607}}while(0);do{if((c[mb>>2]&8192|0)!=0){if((c[hb>>2]|0)==0){break}c[Hb>>2]=0;c[Ib>>2]=0;qf=c[Jb>>2]|0;rf=((((qf|0)/2|0)+1024|0)/(qf|0)|0)&65535;qf=c[ob>>2]|0;b[qf+640>>1]=rf;b[qf+512>>1]=rf;if((c[g>>2]|0)!=0){break}c[Kb>>2]=0;b[qf+768>>1]=rf;c[Lb>>2]=0;b[qf+896>>1]=rf;c[Mb>>2]=0;b[qf+1024>>1]=rf;c[Nb>>2]=0;b[qf+1152>>1]=rf;c[Ob>>2]=0;b[qf+1280>>1]=rf;c[Pb>>2]=0;b[qf+1408>>1]=rf}}while(0);do{if((c[Gb>>2]|0)!=0){if((c[Bb>>2]|0)==4){break}else{rl=0}do{rf=J+180+(rl<<2)|0;if((c[rf>>2]|0)>0){qf=63;while(1){if((qf|0)<=0){break}if((b[(c[ob>>2]|0)+(rl<<7)+(d[J+368+qf|0]<<1)>>1]|0)==0){qf=qf-1|0}else{break}}c[rf>>2]=qf}rl=rl+1|0;}while((rl|0)<12)}}while(0);switch(c[_>>2]|0){case 1:case 2:{xRa(J,c[ob>>2]|0,If,Hf);break e;break};case 13:{bSa(J,c[ob>>2]|0,If,Hf);break e;break};case 16:case 17:case 18:{SUa(J,c[ob>>2]|0,If,Hf);break e;break};case 19:{Thb(J,c[ob>>2]|0,If,Hf);break e;break};case 4:{Lga(J,c[ob>>2]|0,If,Hf);break e;break};case 5:case 20:case 22:case 6:case 7:{yqb(J,c[ob>>2]|0,If,Hf);break e;break};case 8:case 108:{AQa(J,c[ob>>2]|0);break e;break};default:{break e}}}}while(0);c[ga>>2]=c[lb>>2];do{if((c[Gc>>2]|0)==2){if((c[xb>>2]|0)==3){break}Nga(J)}}while(0);KTa(J,c[ob>>2]|0)}else{of=65}}while(0);do{if((of|0)==65){of=0;c[D>>2]=0;nrc(jd|0,fa|0,32)|0;c[kd>>2]=c[ea>>2];c[md>>2]=c[ld>>2];c[od>>2]=c[nd>>2];c[qd>>2]=c[pd>>2];c[rd>>2]=c[O>>2];c[sd>>2]=c[R>>2];c[td>>2]=c[S>>2];c[ud>>2]=c[T>>2];c[vd>>2]=c[V>>2];c[wd>>2]=c[W>>2];c[xd>>2]=c[X>>2];c[yd>>2]=c[P>>2];c[zd>>2]=0;c[Ad>>2]=0;c[Bd>>2]=c[ma>>2];c[Cd>>2]=c[Fa>>2];c[Ed>>2]=c[Dd>>2];c[Gd>>2]=c[Q>>2];c[Gd+4>>2]=c[Q+4>>2];c[Gd+8>>2]=c[Q+8>>2];c[Gd+12>>2]=c[Q+12>>2];c[Gd+16>>2]=c[Q+16>>2];c[Gd+20>>2]=c[Q+20>>2];c[Hd>>2]=c[ra>>2];c[Jd>>2]=c[Id>>2];if((c[ra>>2]|0)!=0){c[Ce>>2]=c[we>>2];c[Ce+4>>2]=c[we+4>>2];c[Ce+8>>2]=c[we+8>>2];c[Ce+12>>2]=c[we+12>>2];c[Ce+16>>2]=c[we+16>>2];c[Ce+20>>2]=c[we+20>>2];c[Je>>2]=c[De>>2];c[Je+4>>2]=c[De+4>>2];c[Je+8>>2]=c[De+8>>2];c[Je+12>>2]=c[De+12>>2];c[Je+16>>2]=c[De+16>>2];c[Je+20>>2]=c[De+20>>2]}if((lf&2|0)!=0){c[lb>>2]=1;c[Ia>>2]=0;c[hb>>2]=0;pf=c[Kc>>2]|0;nf=b[pf+(sf<<2)>>1]|0;c[Ic>>2]=nf;Xf=b[pf+(sf<<2)+2>>1]|0;c[Jc>>2]=Xf;kUa(J,u,t,Od,Pd,Qd,C,D,nf,Xf)}if((lf&256|0)!=0){c[lb>>2]=1;c[Ia>>2]=3;c[hb>>2]=0;Xf=d[(c[Mc>>2]|0)+sf|0]|0;c[Nc>>2]=Xf;nf=Oc+(Xf<<2)|0;c[Hc>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11712>>2]|0)+sf|0]|0;c[H+11812>>2]=nf;Xf=Oc+8+(nf<<2)|0;c[H+11752>>2]=b[(c[Xf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[Xf>>2]|0)+(sf<<2)+2>>1]|0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((lf&8|0)!=0){c[lb>>2]=1;c[Ia>>2]=0;c[hb>>2]=0;c[Ic>>2]=0;c[Jc>>2]=0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((lf&4|0)!=0){c[lb>>2]=1;c[Ia>>2]=1;c[hb>>2]=0;Xf=c[ta>>2]|0;nf=c[Pc>>2]|0;c[Hc>>2]=b[nf+(Xf<<2)>>1]|0;c[H+11748>>2]=b[nf+(Xf<<2)+2>>1]|0;Xf=c[H+12500>>2]|0;c[H+11752>>2]=b[nf+(Xf<<2)>>1]|0;c[H+11756>>2]=b[nf+(Xf<<2)+2>>1]|0;Xf=c[H+12504>>2]|0;c[H+11760>>2]=b[nf+(Xf<<2)>>1]|0;c[H+11764>>2]=b[nf+(Xf<<2)+2>>1]|0;Xf=c[H+12508>>2]|0;c[H+11768>>2]=b[nf+(Xf<<2)>>1]|0;c[H+11772>>2]=b[nf+(Xf<<2)+2>>1]|0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((lf&32|0)!=0){c[lb>>2]=1;c[Ia>>2]=0;c[hb>>2]=0;Xf=c[Xc>>2]|0;nf=b[Xf+(sf<<2)>>1]|0;c[Ic>>2]=nf;pf=b[Xf+(sf<<2)+2>>1]|0;c[Jc>>2]=pf;kUa(J,u,t,Od,Pd,Qd,C,D,nf,pf)}if((lf&64|0)!=0){c[lb>>2]=2;c[Ia>>2]=0;c[hb>>2]=0;pf=c[Wc>>2]|0;nf=b[pf+(sf<<2)>>1]|0;c[Uc>>2]=nf;Xf=b[pf+(sf<<2)+2>>1]|0;c[Vc>>2]=Xf;kUa(J,u,t,Od,Pd,Qd,C,D,nf,Xf)}if((lf&128|0)!=0){c[lb>>2]=3;c[Ia>>2]=0;c[hb>>2]=0;Xf=c[Rc>>2]|0;c[Ic>>2]=b[Xf+(sf<<2)>>1]|0;c[Jc>>2]=b[Xf+(sf<<2)+2>>1]|0;Xf=c[Sc>>2]|0;c[Uc>>2]=b[Xf+(sf<<2)>>1]|0;c[Vc>>2]=b[Xf+(sf<<2)+2>>1]|0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((lf&512|0)!=0){c[lb>>2]=1;c[Ia>>2]=3;c[hb>>2]=0;Xf=d[(c[Yc>>2]|0)+sf|0]|0;c[Nc>>2]=Xf;nf=_c+(Xf<<2)|0;c[Hc>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11720>>2]|0)+sf|0]|0;c[H+11812>>2]=nf;Xf=_c+8+(nf<<2)|0;c[H+11752>>2]=b[(c[Xf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[Xf>>2]|0)+(sf<<2)+2>>1]|0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((lf&1024|0)!=0){c[lb>>2]=2;c[Ia>>2]=3;c[hb>>2]=0;Xf=d[(c[$c>>2]|0)+sf|0]|0;c[ad>>2]=Xf;nf=bd+(Xf<<2)|0;c[Tc>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11780>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11728>>2]|0)+sf|0]|0;c[H+11820>>2]=nf;Xf=bd+8+(nf<<2)|0;c[H+11784>>2]=b[(c[Xf>>2]|0)+(sf<<2)>>1]|0;c[H+11788>>2]=b[(c[Xf>>2]|0)+(sf<<2)+2>>1]|0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0)}if((lf&2048|0)!=0){c[lb>>2]=3;c[Ia>>2]=3;c[hb>>2]=0;Xf=d[(c[Yc>>2]|0)+sf|0]|0;c[Nc>>2]=Xf;nf=cd+(Xf<<2)|0;c[Hc>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11748>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11720>>2]|0)+sf|0]|0;c[H+11812>>2]=nf;Xf=cd+8+(nf<<2)|0;c[H+11752>>2]=b[(c[Xf>>2]|0)+(sf<<2)>>1]|0;c[H+11756>>2]=b[(c[Xf>>2]|0)+(sf<<2)+2>>1]|0;Xf=d[(c[H+11724>>2]|0)+sf|0]|0;c[H+11816>>2]=Xf;nf=cd+16+(Xf<<2)|0;c[H+11776>>2]=b[(c[nf>>2]|0)+(sf<<2)>>1]|0;c[H+11780>>2]=b[(c[nf>>2]|0)+(sf<<2)+2>>1]|0;nf=d[(c[H+11728>>2]|0)+sf|0]|0;c[H+11820>>2]=nf;Xf=cd+24+(nf<<2)|0;c[H+11784>>2]=b[(c[Xf>>2]|0)+(sf<<2)>>1]|0;c[H+11788>>2]=b[(c[Xf>>2]|0)+(sf<<2)+2>>1]|0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0)}do{if((lf&1|0)!=0){c[lb>>2]=0;c[Ia>>2]=0;c[hb>>2]=1;c[Ic>>2]=0;c[Jc>>2]=0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0);if((c[Se>>2]|0)==0){if((c[pc>>2]|0)==0){break}}if((c[Kd>>2]|0)==0){JTa(J);break}else{Xf=(ca(c[oa>>2]|0,ff)|0)+jf|0;a[(c[Te>>2]|0)+Xf|0]=1;break}}}while(0);do{if((c[Ha>>2]&4|0)!=0){if((c[C>>2]|0)==2147483647){break}if((c[Nd>>2]|0)!=0){break}Xf=c[Bd>>2]|0;nf=c[Md>>2]|0;pf=nf>>>1&1;if((c[hb>>2]|0)==0){sl=0}else{sl=(c[Qe>>2]|0)!=0}c[lb>>2]=nf;c[Ia>>2]=0;c[hb>>2]=c[Kd>>2];c[Ic>>2]=c[Me>>2];c[Jc>>2]=c[Ne>>2];c[Uc>>2]=c[Oe>>2];c[Vc>>2]=c[Pe>>2];nf=Zc+(pf<<5)|0;vh=Zc+(pf<<5)+4|0;pf=sl^1;Mf=(c[xb>>2]|0)==3?2:0;do{Ff=c[1512608+(Mf<<2)>>2]|0;cg=Ff+Xf|0;Vf=c[sa>>2]|0;do{if((cg|0)>=(c[Vf+500>>2]|0)){if((cg|0)>(c[Vf+504>>2]|0)){break}c[Cd>>2]=Ff;if(sl){kf=c[ta>>2]|0;Qf=c[Qe>>2]|0;c[E>>2]=b[Qf+(kf<<1)>>1]|0;Kh=c[Re>>2]|0;nrc(F|0,Kh+(kf<<5)|0,32)|0;kf=c[H+12500>>2]|0;c[E+4>>2]=b[Qf+(kf<<1)>>1]|0;nrc(F+32|0,Kh+(kf<<5)|0,32)|0;kf=c[H+12504>>2]|0;c[E+8>>2]=b[Qf+(kf<<1)>>1]|0;nrc(F+64|0,Kh+(kf<<5)|0,32)|0;kf=c[H+12508>>2]|0;c[E+12>>2]=b[Qf+(kf<<1)>>1]|0;nrc(F+96|0,Kh+(kf<<5)|0,32)|0;kf=c[H+12512>>2]|0;c[E+16>>2]=b[Qf+(kf<<1)>>1]|0;nrc(F+128|0,Kh+(kf<<5)|0,32)|0;kf=c[H+12516>>2]|0;c[E+20>>2]=b[Qf+(kf<<1)>>1]|0;nrc(F+160|0,Kh+(kf<<5)|0,32)|0}kUa(J,u,t,Od,Pd,Qd,C,D,c[nf>>2]|0,c[vh>>2]|0);if((c[Rd>>2]|0)==(cg|0)|pf){break}kf=c[ta>>2]|0;b[(c[Qe>>2]|0)+(kf<<1)>>1]=c[E>>2];nrc((c[Re>>2]|0)+(kf<<5)|0,F|0,32)|0;kf=c[H+12500>>2]|0;b[(c[Qe>>2]|0)+(kf<<1)>>1]=c[E+4>>2];nrc((c[Re>>2]|0)+(kf<<5)|0,F+32|0,32)|0;kf=c[H+12504>>2]|0;b[(c[Qe>>2]|0)+(kf<<1)>>1]=c[E+8>>2];nrc((c[Re>>2]|0)+(kf<<5)|0,F+64|0,32)|0;kf=c[H+12508>>2]|0;b[(c[Qe>>2]|0)+(kf<<1)>>1]=c[E+12>>2];nrc((c[Re>>2]|0)+(kf<<5)|0,F+96|0,32)|0;kf=c[H+12512>>2]|0;b[(c[Qe>>2]|0)+(kf<<1)>>1]=c[E+16>>2];nrc((c[Re>>2]|0)+(kf<<5)|0,F+128|0,32)|0;kf=c[H+12516>>2]|0;b[(c[Qe>>2]|0)+(kf<<1)>>1]=c[E+20>>2];nrc((c[Re>>2]|0)+(kf<<5)|0,F+160|0,32)|0}}while(0);Mf=Mf+1|0;}while((Mf|0)<4)}}while(0);if((lf&16|0)!=0){Mf=c[Qc>>2]|0;pf=b[Mf+(sf<<2)>>1]|0;vh=b[Mf+(sf<<2)+2>>1]|0;c[Cd>>2]=0;c[lb>>2]=7;c[hb>>2]=0;HRa(J,pf,vh)|0;kUa(J,u,t,Od,Pd,Qd,C,D,pf,vh)}if((lf&4096|0)!=0){c[Cd>>2]=0;c[lb>>2]=7;c[hb>>2]=0;HRa(J,0,0)|0;kUa(J,u,t,Od,Pd,Qd,C,D,0,0)}do{if((c[Kd>>2]|0)==0){if((c[Ha>>2]&1|0)==0){break}if((c[H+200>>2]|(c[H+196>>2]|(c[H+192>>2]|(c[H+188>>2]|(c[H+184>>2]|c[Qb>>2]))))|0)==0){break}nrc(Hc|0,Ld|0,64)|0;vh=c[Md>>2]|0;do{if((vh&4|0)==0){if((vh&2|0)==0){tl=c[Jc>>2]|0;ul=c[Ic>>2]|0;vl=vh;break}else{tl=c[Vc>>2]|0;ul=c[Uc>>2]|0;vl=vh;break}}else{HRa(J,0,0)|0;tl=0;ul=0;vl=c[Md>>2]|0}}while(0);c[lb>>2]=vl;c[Ia>>2]=c[Nd>>2];c[hb>>2]=0;c[Cd>>2]=0;c[Na>>2]=1;kUa(J,u,t,Od,Pd,Qd,C,D,ul,tl);c[Na>>2]=0}}while(0);a[(c[Sd>>2]|0)+sf|0]=c[Rd>>2];nrc(Hc|0,Ld|0,64)|0;nrc(fa|0,Td|0,32)|0;c[ea>>2]=c[Ud>>2];c[ld>>2]=c[Vd>>2];c[nd>>2]=c[Wd>>2];c[pd>>2]=c[Xd>>2];c[O>>2]=c[Yd>>2];c[R>>2]=c[Zd>>2];c[S>>2]=c[_d>>2];c[T>>2]=c[$d>>2];c[V>>2]=c[ae>>2];c[W>>2]=c[be>>2];c[X>>2]=c[ce>>2];c[P>>2]=c[de>>2];c[hb>>2]=c[Kd>>2];c[Ea>>2]=c[ee>>2];c[Ia>>2]=c[Nd>>2];c[lb>>2]=c[Md>>2];c[Q>>2]=c[fe>>2];c[Q+4>>2]=c[fe+4>>2];c[Q+8>>2]=c[fe+8>>2];c[Q+12>>2]=c[fe+12>>2];c[Q+16>>2]=c[fe+16>>2];c[Q+20>>2]=c[fe+20>>2];if((c[Hd>>2]|0)!=0){c[we>>2]=c[Ke>>2];c[we+4>>2]=c[Ke+4>>2];c[we+8>>2]=c[Ke+8>>2];c[we+12>>2]=c[Ke+12>>2];c[we+16>>2]=c[Ke+16>>2];c[we+20>>2]=c[Ke+20>>2];c[De>>2]=c[Le>>2];c[De+4>>2]=c[Le+4>>2];c[De+8>>2]=c[Le+8>>2];c[De+12>>2]=c[Le+12>>2];c[De+16>>2]=c[Le+16>>2];c[De+20>>2]=c[Le+20>>2]}c[ob>>2]=c[ge>>2];c[Rb>>2]=c[he>>2];c[Tb>>2]=c[ie>>2];c[Vb>>2]=c[je>>2];c[Xb>>2]=c[ke>>2];c[Ib>>2]=c[le>>2];c[Hb>>2]=c[me>>2];c[Kb>>2]=c[ne>>2];c[Lb>>2]=c[oe>>2];c[rb>>2]=c[pe>>2];c[ma>>2]=c[Rd>>2];c[Dd>>2]=c[re>>2];vh=c[I>>2]|0;pf=c[M>>2]|0;Mf=32-vh+(pf-(c[L>>2]|0)<<3)|0;x:do{if((vh|0)<32){nf=c[se>>2]<<vh;c[se>>2]=nf;Xf=nf>>>24&255;nf=pf;while(1){c[M>>2]=nf+1;a[nf]=Xf;cg=c[se>>2]|0;c[se>>2]=cg<<8;Ff=(c[I>>2]|0)+8|0;c[I>>2]=Ff;if((Ff|0)>=32){break x}Xf=cg>>>16&255;nf=c[M>>2]|0}}}while(0);c[I>>2]=32;c[se>>2]=0;pf=c[D>>2]|0;vh=pf^1;_2(Fd,v+(vh*3e3|0)|0,Mf);c[Q>>2]=c[Gd>>2];c[Q+4>>2]=c[Gd+4>>2];c[Q+8>>2]=c[Gd+8>>2];c[Q+12>>2]=c[Gd+12>>2];c[Q+16>>2]=c[Gd+16>>2];c[Q+20>>2]=c[Gd+20>>2];if((c[ra>>2]|0)!=0){nf=c[xe>>2]|0;Xf=c[ze>>2]|0;cg=32-nf+(Xf-(c[ye>>2]|0)<<3)|0;y:do{if((nf|0)<32){Ff=c[Ae>>2]<<nf;c[Ae>>2]=Ff;Vf=Ff>>>24&255;Ff=Xf;while(1){c[ze>>2]=Ff+1;a[Ff]=Vf;kf=c[Ae>>2]|0;c[Ae>>2]=kf<<8;Kh=(c[xe>>2]|0)+8|0;c[xe>>2]=Kh;if((Kh|0)>=32){break y}Vf=kf>>>16&255;Ff=c[ze>>2]|0}}}while(0);c[xe>>2]=32;c[Ae>>2]=0;_2(Be,w+(vh*3e3|0)|0,cg);c[we>>2]=c[Ce>>2];c[we+4>>2]=c[Ce+4>>2];c[we+8>>2]=c[Ce+8>>2];c[we+12>>2]=c[Ce+12>>2];c[we+16>>2]=c[Ce+16>>2];c[we+20>>2]=c[Ce+20>>2];Xf=c[Ee>>2]|0;nf=c[Ge>>2]|0;Mf=32-Xf+(nf-(c[Fe>>2]|0)<<3)|0;z:do{if((Xf|0)<32){Ff=c[He>>2]<<Xf;c[He>>2]=Ff;Vf=Ff>>>24&255;Ff=nf;while(1){c[Ge>>2]=Ff+1;a[Ff]=Vf;kf=c[He>>2]|0;c[He>>2]=kf<<8;Kh=(c[Ee>>2]|0)+8|0;c[Ee>>2]=Kh;if((Kh|0)>=32){break z}Vf=kf>>>16&255;Ff=c[Ge>>2]|0}}}while(0);c[Ee>>2]=32;c[He>>2]=0;_2(Ie,x+(vh*3e3|0)|0,Mf);c[De>>2]=c[Je>>2];c[De+4>>2]=c[Je+4>>2];c[De+8>>2]=c[Je+8>>2];c[De+12>>2]=c[Je+12>>2];c[De+16>>2]=c[Je+16>>2];c[De+20>>2]=c[Je+20>>2]}c[N>>2]=32-(c[I>>2]|0)+((c[M>>2]|0)-(c[L>>2]|0)<<3);do{if((c[Gc>>2]|0)==2){if((c[xb>>2]|0)==3){break}Nga(J)}}while(0);if((pf|0)==0){mf[c[te>>2]&2047](c[Aa>>2]|0,c[ue>>2]|0,c[La>>2]|0,16);mf[c[ve>>2]&2047](c[Ba>>2]|0,(c[ue>>2]|0)+(c[La>>2]<<4)|0,c[Ma>>2]|0,8);mf[c[ve>>2]&2047](c[Ca>>2]|0,(c[ue>>2]|0)+(c[La>>2]<<4|8)|0,c[Ma>>2]|0,8)}if((c[(c[sa>>2]|0)+296>>2]|0)!=1){break}KTa(J,c[ob>>2]|0)}}while(0);if((c[hb>>2]|0)!=0){lf=c[Kc>>2]|0;b[lf+(sf<<2)>>1]=0;b[lf+(sf<<2)+2>>1]=0}if((c[mb>>2]&32768|0)!=0){lf=c[ka>>2]<<4;Mf=c[cb>>2]|0;vh=(lf+16|0)>(Mf|0)?Mf-lf|0:16;Mf=c[la>>2]<<4;nf=c[fb>>2]|0;Xf=(Mf+16|0)>(nf|0)?nf-Mf|0:16;nf=c[$a>>2]|0;cg=c[La>>2]|0;Ff=(ca(Mf,cg)|0)+lf|0;lf=nf+Ff|0;Mf=c[Aa>>2]|0;do{if((vh|0)==16&(Xf|0)==16){wl=Xe[c[ed>>2]&511](0,lf,Mf,cg,16)|0}else{if((vh|0)==8&(Xf|0)==8){wl=Xe[c[id>>2]&511](0,lf,Mf,cg,8)|0;break}if((Xf|0)<=0){wl=0;break}Vf=(vh|0)>0;kf=0;Kh=0;while(1){if(Vf){Qf=ca(Kh,cg)|0;Nf=kf;Of=0;while(1){$f=Of+Qf|0;Kf=(c[6219288+((d[nf+($f+Ff)|0]|256)-(d[Mf+$f|0]|0)<<2)>>2]|0)+Nf|0;$f=Of+1|0;if(($f|0)<(vh|0)){Nf=Kf;Of=$f}else{xl=Kf;break}}}else{xl=kf}Of=Kh+1|0;if((Of|0)<(Xf|0)){kf=xl;Kh=Of}else{wl=xl;break}}}}while(0);Mf=wrc(c[fd>>2]|0,c[fd+4>>2]|0,wl,(wl|0)<0|0?-1:0)|0;c[fd>>2]=Mf;c[fd+4>>2]=G;Mf=c[ab>>2]|0;Ff=c[Ma>>2]|0;nf=(ca(ca(c[la>>2]|0,K)|0,Ff)|0)+(c[ka>>2]<<3)|0;cg=Mf+nf|0;lf=c[Ba>>2]|0;Kh=vh>>1;kf=Xf>>c[g>>2];Vf=(Kh|0)==16;do{if(Vf&(kf|0)==16){yl=Xe[c[ed>>2]&511](0,cg,lf,Ff,16)|0}else{if((Kh|0)==8&(kf|0)==8){yl=Xe[c[id>>2]&511](0,cg,lf,Ff,8)|0;break}if((kf|0)<=0){yl=0;break}pf=(Kh|0)>0;Of=0;Nf=0;while(1){if(pf){Qf=ca(Nf,Ff)|0;Kf=Of;$f=0;while(1){Hh=$f+Qf|0;fh=(c[6219288+((d[Mf+(Hh+nf)|0]|256)-(d[lf+Hh|0]|0)<<2)>>2]|0)+Kf|0;Hh=$f+1|0;if((Hh|0)<(Kh|0)){Kf=fh;$f=Hh}else{zl=fh;break}}}else{zl=Of}$f=Nf+1|0;if(($f|0)<(kf|0)){Of=zl;Nf=$f}else{yl=zl;break}}}}while(0);kf=wrc(c[gd>>2]|0,c[gd+4>>2]|0,yl,(yl|0)<0|0?-1:0)|0;c[gd>>2]=kf;c[gd+4>>2]=G;kf=c[bb>>2]|0;lf=c[Ma>>2]|0;nf=(ca(ca(c[la>>2]|0,K)|0,lf)|0)+(c[ka>>2]<<3)|0;Mf=kf+nf|0;Ff=c[Ca>>2]|0;cg=Xf>>c[g>>2];do{if(Vf&(cg|0)==16){Al=Xe[c[ed>>2]&511](0,Mf,Ff,lf,16)|0}else{if((Kh|0)==8&(cg|0)==8){Al=Xe[c[id>>2]&511](0,Mf,Ff,lf,8)|0;break}if((cg|0)<=0){Al=0;break}vh=(Kh|0)>0;Nf=0;Of=0;while(1){if(vh){pf=ca(Of,lf)|0;$f=Nf;Kf=0;while(1){Qf=Kf+pf|0;fh=(c[6219288+((d[kf+(Qf+nf)|0]|256)-(d[Ff+Qf|0]|0)<<2)>>2]|0)+$f|0;Qf=Kf+1|0;if((Qf|0)<(Kh|0)){$f=fh;Kf=Qf}else{Bl=fh;break}}}else{Bl=Nf}Kf=Of+1|0;if((Kf|0)<(cg|0)){Nf=Bl;Of=Kf}else{Al=Bl;break}}}}while(0);cg=wrc(c[hd>>2]|0,c[hd+4>>2]|0,Al,(Al|0)<0|0?-1:0)|0;c[hd>>2]=cg;c[hd+4>>2]=G}do{if((c[dd>>2]|0)!=0){if((c[Gc>>2]|0)!=2){break}Pga(J)}}while(0);jf=jf+1|0;}while((jf|0)<(c[na>>2]|0))}jf=ff+1|0;if((jf|0)<(c[ja>>2]|0)){ff=jf}else{Cl=jf;break a}}if((of|0)==12){KIb(c[sa>>2]|0,16,2642416,(Jf=i,i=i+1|0,i=i+7&-8,c[Jf>>2]=0,Jf)|0);i=Jf;Dl=-1;i=f;return Dl|0}else if((of|0)==16){KIb(c[sa>>2]|0,16,2636008,(Jf=i,i=i+1|0,i=i+7&-8,c[Jf>>2]=0,Jf)|0);i=Jf;Dl=-1;i=f;return Dl|0}}else{Cl=ia}}while(0);ia=c[H+14092>>2]|0;do{if((ia|0)!=0&(ia|0)<4){if((c[H+9992>>2]|0)!=1){break}PUa(J)}}while(0);jUa(J);J=c[H+4>>2]|0;ia=c[J+624>>2]|0;if((ia|0)==0){Dl=0;i=f;return Dl|0}Jf=ca(Cl-(c[aa>>2]|0)|0,c[H+116>>2]|0)|0;H=c[da>>2]|0;mf[ia&2047](J,H,(c[M>>2]|0)-H|0,Jf-(c[$>>2]|0)|0);Dl=0;i=f;return Dl|0}function jUa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;do{if((c[b+48>>2]|0)==13){if((c[b+13940>>2]|0)!=0){lSa(b)}fSa(b+784|0)}else{if((c[b+28>>2]|0)!=3){break}xQa(b)}}while(0);d=b+784|0;Y2(d);e=b+788|0;f=c[e>>2]|0;g=d|0;if((f|0)<32){d=c[g>>2]<<f;c[g>>2]=d;f=b+796|0;h=d>>>24&255;while(1){d=c[f>>2]|0;c[f>>2]=d+1;a[d]=h;d=c[g>>2]|0;c[g>>2]=d<<8;i=(c[e>>2]|0)+8|0;c[e>>2]=i;if((i|0)<32){h=d>>>16&255}else{break}}}c[e>>2]=32;c[g>>2]=0;if((c[b+60>>2]&512|0)==0){return}if((c[b+13940>>2]|0)!=0){return}g=(c[b+796>>2]|0)-(c[b+792>>2]|0)<<3;e=b+13700|0;h=c[e>>2]|0;c[e>>2]=g;e=b+13696|0;c[e>>2]=(c[e>>2]|0)-h+g;return}function kUa(f,g,h,j,k,l,m,n,o,p){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0.0,db=0.0,eb=0.0,fb=0,gb=0.0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Hd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,he=0,ie=0,je=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,We=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ff=0,gf=0,jf=0,kf=0,lf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0;q=i;i=i+3680|0;r=q|0;s=q+8|0;t=q+16|0;u=q+144|0;v=q+272|0;w=q+536|0;x=q+2072|0;y=q+3608|0;z=q+3656|0;A=q+3664|0;B=f+11824|0;nrc(B|0,g+11824|0,32)|0;C=f+12484|0;c[C>>2]=c[g+12484>>2];D=f+9860|0;c[D>>2]=c[g+9860>>2];E=f+9864|0;c[E>>2]=c[g+9864>>2];F=f+9868|0;c[F>>2]=c[g+9868>>2];H=f+13664|0;c[H>>2]=c[g+13664>>2];I=f+13672|0;c[I>>2]=c[g+13672>>2];J=f+13676|0;c[J>>2]=c[g+13676>>2];K=f+13680|0;c[K>>2]=c[g+13680>>2];L=f+13684|0;c[L>>2]=c[g+13684>>2];M=f+13688|0;c[M>>2]=c[g+13688>>2];N=f+13692|0;c[N>>2]=c[g+13692>>2];O=f+13696|0;c[O>>2]=c[g+13696>>2];c[f+13700>>2]=0;P=f+9924|0;c[P>>2]=0;Q=c[g+9960>>2]|0;R=f+9960|0;c[R>>2]=Q;S=c[g+9984>>2]|0;T=f+9984|0;c[T>>2]=S;V=f+14100|0;c[V>>2]=c[g+14100>>2];g=c[n>>2]|0;W=f+14340|0;c[W>>2]=(c[f+14344>>2]|0)+(g*1536|0);X=f+784|0;Y=j+(g*24|0)|0;c[X>>2]=c[Y>>2];c[X+4>>2]=c[Y+4>>2];c[X+8>>2]=c[Y+8>>2];c[X+12>>2]=c[Y+12>>2];c[X+16>>2]=c[Y+16>>2];c[X+20>>2]=c[Y+20>>2];Y=f+13936|0;if((c[Y>>2]|0)!=0){g=f+13980|0;j=k+((c[n>>2]|0)*24|0)|0;c[g>>2]=c[j>>2];c[g+4>>2]=c[j+4>>2];c[g+8>>2]=c[j+8>>2];c[g+12>>2]=c[j+12>>2];c[g+16>>2]=c[j+16>>2];c[g+20>>2]=c[j+20>>2];j=f+13956|0;g=l+((c[n>>2]|0)*24|0)|0;c[j>>2]=c[g>>2];c[j+4>>2]=c[g+4>>2];c[j+8>>2]=c[g+8>>2];c[j+12>>2]=c[g+12>>2];c[j+16>>2]=c[g+16>>2];c[j+20>>2]=c[g+20>>2]}if((c[n>>2]|0)!=0){g=A;j=f+12544|0;l=j;c[g>>2]=c[l>>2];c[g+4>>2]=c[l+4>>2];c[g+8>>2]=c[l+8>>2];l=c[f+9948>>2]|0;c[j>>2]=l;j=c[f+148>>2]<<4;c[f+12548>>2]=l+j;c[f+12552>>2]=l+(j|8)}j=f+14212|0;l=c[j>>2]|0;a:do{if((l|0)==1){g=x;k=c[f+12476>>2]|0;Z=c[f+12480>>2]|0;_=f+148|0;$=c[_>>2]|0;aa=f+152|0;ba=c[aa>>2]|0;da=c[f+10044>>2]|0;ea=y|0;c[ea>>2]=da;fa=y+4|0;c[fa>>2]=da;ga=y+8|0;c[ga>>2]=da;ha=y+12|0;c[ha>>2]=da;ia=y+16|0;c[ia>>2]=da;ja=y+20|0;c[ja>>2]=da;da=$<<3;$=ba<<3;do{if((c[f+9980>>2]|0)==0){if((c[f+14404>>2]&4|0)==0){break}QTa(f,S+Q|0)}else{ba=(ca(c[f+124>>2]|0,Z)|0)+k|0;ka=c[(c[f+9976>>2]|0)+(ba<<2)>>2]|0;c[f+9968>>2]=ka;la=((ka*139|0)+8192|0)>>>14;c[R>>2]=la;ma=c[f+4>>2]|0;na=c[ma+500>>2]|0;oa=c[ma+504>>2]|0;if((la|0)<(na|0)){pa=na}else{pa=(la|0)>(oa|0)?oa:la}c[R>>2]=pa;c[f+9972>>2]=((ca(ka,ka)|0)+64|0)>>>7;do{if((c[f+14404>>2]&4|0)==0){ka=a[(c[(c[f+9856>>2]|0)+1512>>2]|0)+ba|0]|0;c[R>>2]=ka;la=ka-Q|0;c[T>>2]=la;if((c[f+28>>2]|0)!=2){qa=la;break}if((la|0)<-2){ra=-2}else{ra=(la|0)>2?2:la}c[T>>2]=ra;if((c[f+48>>2]|0)!=13){qa=ra;break}if((c[f+12488>>2]|0)!=0){qa=ra;break}do{if((c[f+9992>>2]|0)==3){if((ra&1|0)==0){if((c[f+11736>>2]&4|0)==0){sa=ra;break}}c[T>>2]=0;sa=0}else{sa=ra}}while(0);if((c[f+11740>>2]|0)!=1){qa=sa;break}c[T>>2]=0;qa=0}else{qa=S}}while(0);QTa(f,qa+Q|0)}}while(0);ba=c[_>>2]|0;la=c[aa>>2]|0;ka=Z<<4;oa=k<<4;na=(c[f+5400>>2]|0)+((ca(ba,ka)|0)+oa)|0;ma=Z<<3;ta=k<<3;ua=(ca(la,ma)|0)+ta|0;va=(c[f+5404>>2]|0)+ua|0;wa=(c[f+5408>>2]|0)+ua|0;ua=c[f+8>>2]|0;if((oa+16|0)>(ua|0)){xa=26}else{if((ka+16|0)>(c[f+12>>2]|0)){xa=26}else{ya=na;za=va;Aa=wa}}do{if((xa|0)==26){if((c[f+48>>2]|0)==108){ya=na;za=va;Aa=wa;break}Ba=c[f+9944>>2]|0;Ca=Ba+32|0;Da=c[f+14216>>2]|0;Ea=Da+ua>>Da;Da=c[f+12>>2]|0;Fa=c[f+14220>>2]|0;Ga=Fa+Da>>Fa;Fa=f+11540|0;Ve[c[Fa>>2]&127](Ca,na,ba,ba,16,16,oa,ka,ua,Da);Da=ba*18|0;Ha=Ba+(Da+32)|0;Ve[c[Fa>>2]&127](Ha,va,la,la,8,8,ta,ma,Ea,Ga);Ia=Ba+(Da+48)|0;Ve[c[Fa>>2]&127](Ia,wa,la,la,8,8,ta,ma,Ea,Ga);ya=Ca;za=Ha;Aa=Ia}}while(0);ma=f+12488|0;do{if((c[ma>>2]|0)==0){ta=c[f+12544>>2]|0;wa=c[f+12548>>2]|0;va=c[f+12552>>2]|0;do{if((c[f+12472>>2]|0)==0){xa=41}else{if((c[f+9992>>2]|0)==3){xa=41;break}Ja=f+10936|0;Ka=f+11460|0}}while(0);if((xa|0)==41){Ja=f+10680|0;Ka=f+11332|0}ua=f+11736|0;ka=c[ua>>2]|0;if((ka&1|0)==0){La=Ja;Ma=Ka;Na=ka}else{mUa(f,ta,wa,va,0,f+952|0,Ka,Ja);La=f+10808|0;Ma=f+11396|0;Na=c[ua>>2]|0}if((Na&2|0)!=0){mUa(f,ta,wa,va,1,f+3176|0,Ma,La)}ua=f+60|0;do{if((c[ua>>2]&262144|0)==0){Oa=da;Pa=$;Qa=ba;Ra=la}else{ka=f+14236|0;c[ka>>2]=0;oa=f+10540|0;na=f;aa=Xe[c[oa>>2]&511](na,ta,ya,ba,8)|0;_=ba<<3;Ia=(Xe[c[oa>>2]&511](na,ta+_|0,ya+_|0,ba,8)|0)+aa|0;aa=Ia+((c[(c[f+4>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((aa|0)<=0){Oa=da;Pa=$;Qa=ba;Ra=la;break}Ia=ba<<1;_=Xe[c[oa>>2]&511](na,ta,ya,Ia,8)|0;if((aa|0)<=((Xe[c[oa>>2]&511](na,ta+ba|0,ya+ba|0,Ia,8)|0)+_|0)){Oa=da;Pa=$;Qa=ba;Ra=la;break}c[ka>>2]=1;Oa=ba;Pa=la;Qa=Ia;Ra=la<<((c[j>>2]|0)==2)}}while(0);Ia=f+10060|0;mf[c[Ia>>2]&2047](c[W>>2]|0,ya,ta,Qa);ka=ya+8|0;_=ta+8|0;mf[c[Ia>>2]&2047]((c[W>>2]|0)+128|0,ka,_,Qa);na=ya+Oa|0;oa=ta+Oa|0;mf[c[Ia>>2]&2047]((c[W>>2]|0)+256|0,na,oa,Qa);aa=Oa+8|0;Ha=ya+aa|0;Ca=ta+aa|0;mf[c[Ia>>2]&2047]((c[W>>2]|0)+384|0,Ha,Ca,Qa);do{if((c[ua>>2]&8192|0)==0){mf[c[Ia>>2]&2047]((c[W>>2]|0)+512|0,za,wa,Ra);mf[c[Ia>>2]&2047]((c[W>>2]|0)+640|0,Aa,va,Ra);if((c[f+14220>>2]|0)!=0){break}mf[c[Ia>>2]&2047]((c[W>>2]|0)+768|0,za+Pa|0,wa+Pa|0,Ra);mf[c[Ia>>2]&2047]((c[W>>2]|0)+896|0,Aa+Pa|0,va+Pa|0,Ra)}else{c[ia>>2]=1;c[ja>>2]=1}}while(0);Ia=(ca(c[f+124>>2]|0,Z)|0)+k|0;ua=c[R>>2]|0;if((e[(c[f+9200>>2]|0)+(Ia<<1)>>1]|0)>=(ca(ua<<1,ua)|0)){Sa=Oa;Ta=Pa;Ua=Qa;Va=Ra;break}ua=f+10112|0;Ia=Xe[c[ua>>2]&511](0,ya,ta,Qa,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ea>>2]=1}Ia=Xe[c[ua>>2]&511](0,ka,_,Qa,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[fa>>2]=1}Ia=Xe[c[ua>>2]&511](0,na,oa,Qa,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ga>>2]=1}Ia=Xe[c[ua>>2]&511](0,Ha,Ca,Qa,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ha>>2]=1}Ia=Xe[c[ua>>2]&511](0,za,wa,Ra,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ia>>2]=1}Ia=Xe[c[ua>>2]&511](0,Aa,va,Ra,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[ja>>2]=1}if((c[f+14220>>2]|0)!=0){Sa=Oa;Ta=Pa;Ua=Qa;Va=Ra;break}Ia=Xe[c[ua>>2]&511](0,za+Pa|0,wa+Pa|0,Ra,8)|0;if((Ia|0)<((c[R>>2]|0)*20|0|0)){c[y+24>>2]=1}Ia=Xe[c[ua>>2]&511](0,Aa+Pa|0,va+Pa|0,Ra,8)|0;if((Ia|0)>=((c[R>>2]|0)*20|0|0)){Sa=Oa;Ta=Pa;Ua=Qa;Va=Ra;break}c[y+28>>2]=1;Sa=Oa;Ta=Pa;Ua=Qa;Va=Ra}else{Ia=f+60|0;do{if((c[Ia>>2]&262144|0)==0){Wa=da;Xa=$;Ya=ba;Za=la}else{ua=f+14236|0;c[ua>>2]=0;aa=f+10556|0;Ga=f;Ea=Xe[c[aa>>2]&511](Ga,ya,0,ba,8)|0;Fa=Ea-400+(Xe[c[aa>>2]&511](Ga,ya+(ba<<3)|0,0,ba,8)|0)|0;if((Fa|0)<=0){Wa=da;Xa=$;Ya=ba;Za=la;break}Ea=ba<<1;Da=Xe[c[aa>>2]&511](Ga,ya,0,Ea,8)|0;if((Fa|0)<=((Xe[c[aa>>2]&511](Ga,ya+ba|0,0,Ea,8)|0)+Da|0)){Wa=da;Xa=$;Ya=ba;Za=la;break}c[ua>>2]=1;Wa=ba;Xa=la;Ya=Ea;Za=la<<(((c[j>>2]|0)-2|0)>>>0<2>>>0)}}while(0);va=f+10056|0;ef[c[va>>2]&4095](c[W>>2]|0,ya,Ya);ef[c[va>>2]&4095]((c[W>>2]|0)+128|0,ya+8|0,Ya);ef[c[va>>2]&4095]((c[W>>2]|0)+256|0,ya+Wa|0,Ya);ef[c[va>>2]&4095]((c[W>>2]|0)+384|0,ya+(Wa+8)|0,Ya);if((c[Ia>>2]&8192|0)!=0){c[ia>>2]=1;c[ja>>2]=1;Sa=Wa;Ta=Xa;Ua=Ya;Va=Za;break}ef[c[va>>2]&4095]((c[W>>2]|0)+512|0,za,Za);ef[c[va>>2]&4095]((c[W>>2]|0)+640|0,Aa,Za);if((c[f+14220>>2]|0)!=0){Sa=Wa;Ta=Xa;Ua=Ya;Va=Za;break}wa=c[va>>2]|0;Ca=(c[W>>2]|0)+768|0;if((c[f+14216>>2]|0)==0){ef[wa&4095](Ca,za+8|0,Za);ef[c[va>>2]&4095]((c[W>>2]|0)+896|0,Aa+8|0,Za);ef[c[va>>2]&4095]((c[W>>2]|0)+1024|0,za+Xa|0,Za);ef[c[va>>2]&4095]((c[W>>2]|0)+1152|0,Aa+Xa|0,Za);Ha=Xa+8|0;ef[c[va>>2]&4095]((c[W>>2]|0)+1280|0,za+Ha|0,Za);ef[c[va>>2]&4095]((c[W>>2]|0)+1408|0,Aa+Ha|0,Za);Sa=Wa;Ta=Xa;Ua=Ya;Va=Za;break}else{ef[wa&4095](Ca,za+Xa|0,Za);ef[c[va>>2]&4095]((c[W>>2]|0)+896|0,Aa+Xa|0,Za);Sa=Wa;Ta=Xa;Ua=Ya;Va=Za;break}}}while(0);la=f+14408|0;if((c[la>>2]|0)!=0){if((c[ea>>2]|0)==0){lUa(w|0,ya,Ua)}if((c[fa>>2]|0)==0){lUa(w+128|0,ya+8|0,Ua)}if((c[ga>>2]|0)==0){lUa(w+256|0,ya+Sa|0,Ua)}if((c[ha>>2]|0)==0){lUa(w+384|0,ya+(Sa+8)|0,Ua)}if((c[ia>>2]|0)==0){lUa(w+512|0,za,Va)}if((c[ja>>2]|0)==0){lUa(w+640|0,Aa,Va)}do{if((c[f+14220>>2]|0)==0){if((c[y+24>>2]|0)==0){lUa(w+768|0,za+Ta|0,Va)}if((c[y+28>>2]|0)!=0){break}lUa(w+896|0,Aa+Ta|0,Va)}}while(0);nrc(g|0,c[W>>2]|0,768)|0}ja=f+14392|0;ia=f+13084|0;ha=f+13080|0;ga=f+4|0;fa=0;do{do{if((c[y+(fa<<2)>>2]|0)==0){ea=Xe[c[ja>>2]&511](f,(c[W>>2]|0)+(fa<<7)|0,fa,c[R>>2]|0,z)|0;c[f+180+(fa<<2)>>2]=ea;if((c[z>>2]|0)==0){break}ba=c[W>>2]|0;$=c[ia>>2]|0;da=c[ha>>2]|0;k=(c[ma>>2]|0)!=0|0;if((k|0)>(ea|0)){break}Z=$&65535;va=da&65535;Ca=0;wa=k;while(1){k=ba+(fa<<7)+(d[f+368+wa|0]<<1)|0;Ha=b[k>>1]|0;oa=Ha<<16>>16;if((oa|0)>($|0)){_a=Z;$a=Ca+1|0}else{na=(oa|0)<(da|0);_a=na?va:Ha;$a=(na&1)+Ca|0}b[k>>1]=_a;k=wa+1|0;if((k|0)>(ea|0)){break}else{Ca=$a;wa=k}}if(($a|0)==0){break}wa=c[ga>>2]|0;if((c[wa+296>>2]|0)!=0){break}KIb(wa,32,2630632,(ab=i,i=i+24|0,c[ab>>2]=$a,c[ab+8>>2]=da,c[ab+16>>2]=$,ab)|0);i=ab}else{c[f+180+(fa<<2)>>2]=-1}}while(0);fa=fa+1|0;}while((fa|0)<6);if((c[la>>2]|0)!=0){fa=u|0;ga=f+364|0;ha=f+13100|0;ia=f+13104|0;g=f+9972|0;Ia=t|0;wa=f+11256|0;Ca=f+11252|0;ea=v|0;va=f+11164|0;Z=f+228|0;ba=f+168|0;k=f+172|0;na=f+13092|0;Ha=f+13096|0;oa=0;do{if((c[y+(oa<<2)>>2]|0)==0){_=c[W>>2]|0;ka=_+(oa<<7)|0;ta=w+(oa<<7)|0;Ea=c[R>>2]|0;ua=c[ga>>2]|0;if((b[4945388]|0)==0){Da=0;do{Ga=Da<<3;bb=(Da|0)==0?11585.237502960395:16384.0;cb=bb*.7071067811865476;db=+(Da|0)*.39269908169872414;aa=0;do{Fa=aa+Ga+(f+11184)|0;Ba=(aa|0)==0;eb=+(aa|0)*.39269908169872414;fb=0;do{gb=+U(eb*(+(fb|0)+.5));if(Ba){hb=0;do{ib=d[Fa]|0;b[9890776+(ib<<7)+((hb<<3)+fb<<1)>>1]=Lc(+(gb*cb*+U(db*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}else{hb=0;do{ib=d[Fa]|0;b[9890776+(ib<<7)+((hb<<3)+fb<<1)>>1]=Lc(+(gb*bb*+U(db*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}fb=fb+1|0;}while((fb|0)<8);aa=aa+1|0;}while((aa|0)<8);Da=Da+1|0;}while((Da|0)<8)}Da=Ea<<1;aa=Ea-1|1;if((c[ma>>2]|0)==0){jb=aa;kb=0;lb=32;mb=ha;nb=ia;ob=1}else{do{if((c[Z>>2]|0)==0){if((oa|0)<4){pb=aa;qb=c[ba>>2]|0;break}else{pb=aa;qb=c[k>>2]|0;break}}else{pb=0;qb=1}}while(0);aa=qb<<3;jb=pb;kb=1;lb=(ca(b[ka>>1]|0,aa)|0)+32|0;mb=na;nb=Ha;ob=aa}aa=c[mb>>2]|0;Ea=c[nb>>2]|0;Ga=f+180+(oa<<2)|0;$=c[Ga>>2]|0;da=0;while(1){b[t+(da<<1)>>1]=lb-(b[x+(oa<<7)+(da<<1)>>1]<<6);fb=da+1|0;if((fb|0)<64){da=fb}else{rb=0;sb=0;break}}do{da=w+(oa<<7)+(sb<<1)|0;fb=b[da>>1]|0;Fa=fb<<16>>16;Ba=(fb<<16>>16>-1?Fa:-Fa|0)+144|0;Fa=((((Ba|0)/2|0)+6912|0)/(Ba|0)|0)+15|0;b[da>>1]=Fa;rb=(ca(Fa,Fa)|0)+rb|0;sb=sb+1|0;}while((sb|0)<64);Fa=Erc(c[g>>2]|0,0,rb,(rb|0)<0|0?-1:0)|0;da=Fa>>>19|G<<13;Fa=-jb|0;if((kb|0)<=($|0)){Ba=0;fb=0;hb=kb;while(1){ib=d[f+368+hb|0]|0;tb=b[_+(oa<<7)+(ib<<1)>>1]|0;if(tb<<16>>16==0){ub=fb;vb=Ba+1|0}else{wb=ca(tb<<16>>16,Da)|0;c[v+(fb<<2)>>2]=Ba;ef[c[wa>>2]&4095](Ia,9890776+(ib<<7)|0,wb+(tb<<16>>16<0?Fa:jb)|0);ub=fb+1|0;vb=0}tb=hb+1|0;if((tb|0)>($|0)){break}else{Ba=vb;fb=ub;hb=tb}}}hb=(kb|0)==0;fb=-ob|0;Ba=$;while(1){tb=hf[c[Ca>>2]&1023](Ia,ta,9890776,0)|0;if((Ba|0)>2){xb=0;xa=135}else{if((c[la>>2]|0)>2){xb=0;xa=135}else{yb=0}}if((xa|0)==135){while(1){xa=0;wb=b[w+(oa<<7)+(xb<<1)>>1]|0;b[u+(xb<<1)>>1]=(ca(ca(wb,wb)|0,b[t+(xb<<1)>>1]|0)|0)+131072>>18;wb=xb+1|0;if((wb|0)<64){xb=wb;xa=135}else{break}}qe[c[va>>2]&1023](fa);yb=1}do{if(hb){zb=tb;Ab=0;Bb=0}else{wb=b[ka>>1]|0;if((ca(wb-1|0,ob)|0)>>>0>2047>>>0){Cb=tb;Db=0;Eb=0}else{ib=hf[c[Ca>>2]&1023](Ia,ta,9890776,fb)|0;Fb=(ib|0)<(tb|0);Cb=Fb?ib:tb;Db=Fb<<31>>31;Eb=Fb?fb:0}if((ca(wb+1|0,ob)|0)>>>0>2047>>>0){zb=Cb;Ab=Db;Bb=Eb;break}wb=hf[c[Ca>>2]&1023](Ia,ta,9890776,ob)|0;Fb=(wb|0)<(Cb|0);zb=Fb?wb:Cb;Ab=Fb?1:Db;Bb=Fb?ob:Eb}}while(0);tb=Ba+1|0;Fb=c[ea>>2]|0;wb=Bb;ib=Ab;Gb=0;Hb=zb;Ib=0;Jb=1;Kb=kb;Lb=0;Mb=0;while(1){Nb=d[f+368+Kb|0]|0;Ob=b[_+(oa<<7)+(Nb<<1)>>1]|0;Pb=Ob<<16>>16;Qb=c[la>>2]|0;if((Qb|0)<3&(Kb|0)>(tb|0)){Rb=wb;Sb=ib;Tb=Gb;break}Ub=Ob<<16>>16!=0;if(Ub){Vb=ca(Pb,Da)|0;Wb=Vb+(Ob<<16>>16<0?Fa:jb)|0;Xb=Jb+1|0;Yb=c[v+(Jb<<2)>>2]|0}else{Wb=0;Xb=Jb;Yb=Fb-1|0}Vb=Ob<<16>>16>-1?Pb:-Pb|0;Zb=(Kb|0)<(Ba|0);_b=Kb+1|0;$b=Yb+_b|0;ac=f+368+$b|0;bc=($b|0)<(Ba|0);$b=(Yb+Ib<<7)+128|0;cc=Yb<<7;dc=Ib<<7;ec=dc|65;fc=aa+ec|0;gc=Ea+ec|0;ec=(Lb|0)==0;hc=(Mb<<7)+Lb|0;ic=Ea+hc|0;jc=aa+hc|0;hc=9890776+(Nb<<7)|0;Nb=(Ob+62&65535)>>>0<125>>>0;Ob=dc|64;dc=Pb+Ob|0;kc=aa+dc|0;lc=Ea+dc|0;dc=ua+Kb|0;mc=wb;nc=ib;oc=Gb;pc=Hb;qc=-1;rc=Qb;while(1){Qb=qc+Pb|0;if((rc|0)<2){if((((Qb|0)>-1?Qb:-Qb|0)|0)>(Vb|0)){sc=pc;tc=oc;uc=nc;vc=mc}else{xa=149}}else{xa=149}b:do{if((xa|0)==149){xa=0;do{if((Qb|0)==0){if(!Zb){wc=d[gc]|0;if(ec){xc=0;yc=-wc|0;break}xc=0;yc=(d[ic]|0)-wc-(d[jc]|0)|0;break}wc=(b[_+(oa<<7)+(d[ac]<<1)>>1]|0)+64|0;zc=wc>>>0>127>>>0?0:wc;wc=zc+$b|0;if(bc){xc=0;yc=(d[aa+wc|0]|0)-(d[aa+(zc+cc)|0]|0)-(d[fc]|0)|0;break}else{xc=0;yc=(d[Ea+wc|0]|0)-(d[Ea+(zc+cc)|0]|0)-(d[fc]|0)|0;break}}else{zc=ca(Qb,Da)|0;wc=((Qb|0)<0?Fa:jb)+zc|0;if((wc+2047|0)>>>0>4094>>>0){sc=pc;tc=oc;uc=nc;vc=mc;break b}if(Ub){if(!Nb){xc=wc;yc=0;break}zc=Qb+Ob|0;if(Zb){xc=wc;yc=(d[aa+zc|0]|0)-(d[kc]|0)|0;break}else{xc=wc;yc=(d[Ea+zc|0]|0)-(d[lc]|0)|0;break}}do{if(yb){zc=b[u+(d[dc]<<1)>>1]|0;if(zc<<16>>16==0){break}if((zc<<16>>16^Qb|0)>-1){sc=pc;tc=oc;uc=nc;vc=mc;break b}}}while(0);if(!Zb){zc=d[gc]|0;if(ec){xc=wc;yc=zc;break}xc=wc;yc=(d[jc]|0)+zc-(d[ic]|0)|0;break}zc=(b[_+(oa<<7)+(d[ac]<<1)>>1]|0)+64|0;Ac=zc>>>0>127>>>0?0:zc;zc=d[fc]|0;Bc=Ac+cc|0;if(bc){xc=wc;yc=(d[aa+Bc|0]|0)+zc-(d[aa+(Ac+$b)|0]|0)|0;break}else{xc=wc;yc=(d[Ea+Bc|0]|0)+zc-(d[Ea+(Ac+$b)|0]|0)|0;break}}}while(0);Ac=ca(yc,da)|0;zc=xc-Wb|0;Bc=(hf[c[Ca>>2]&1023](Ia,ta,hc,zc)|0)+Ac|0;Ac=(Bc|0)<(pc|0);sc=Ac?Bc:pc;tc=Ac?Kb:oc;uc=Ac?qc:nc;vc=Ac?zc:mc}}while(0);if((qc|0)>=0){break}mc=vc;nc=uc;oc=tc;pc=sc;qc=qc+2|0;rc=c[la>>2]|0}if(Ub){rc=Pb+64|0;Cc=Ib;Dc=rc>>>0>127>>>0?0:rc;Ec=0}else{Cc=Mb;Dc=Lb;Ec=Ib+1|0}if((_b|0)<64){Fb=Yb;wb=vc;ib=uc;Gb=tc;Hb=sc;Ib=Ec;Jb=Xb;Kb=_b;Lb=Dc;Mb=Cc}else{Rb=vc;Sb=uc;Tb=tc;break}}if((Sb|0)==0){break}Mb=d[f+368+Tb|0]|0;Lb=_+(oa<<7)+(Mb<<1)|0;b[Lb>>1]=(e[Lb>>1]|0)+Sb;c:do{if((Tb|0)>(Ba|0)){Fc=Tb}else{Lb=Ba;while(1){if((Lb|0)<(kb|0)){Fc=Lb;break c}if((b[_+(oa<<7)+(d[f+368+Lb|0]<<1)>>1]|0)==0){Lb=Lb-1|0}else{Fc=Lb;break}}}}while(0);if((kb|0)<=(Fc|0)){Lb=0;_b=0;Pb=kb;while(1){if((b[_+(oa<<7)+(d[f+368+Pb|0]<<1)>>1]|0)==0){Gc=_b;Hc=Lb+1|0}else{c[v+(_b<<2)>>2]=Lb;Gc=_b+1|0;Hc=0}Ub=Pb+1|0;if((Ub|0)>(Fc|0)){break}else{Lb=Hc;_b=Gc;Pb=Ub}}}ef[c[wa>>2]&4095](Ia,9890776+(Mb<<7)|0,Rb);Ba=Fc}c[Ga>>2]=Ba}oa=oa+1|0;}while((oa|0)<6)}oa=f+72|0;Ia=c[oa>>2]|0;d:do{if((Ia|0)!=0){if((c[ma>>2]|0)==0){Ic=0;Jc=Ia}else{break}while(1){wa=c[W>>2]|0;la=wa+(Ic<<7)|0;Ca=f+180+(Ic<<2)|0;ea=c[Ca>>2]|0;fa=Jc>>>31;va=fa^1;g=(Jc|0)<0?-Jc|0:Jc;e:do{if((ea|0)>(fa<<31>>31|0)){if((ea|0)<0){Kc=0}else{Ha=(fa|0)!=1;na=0;k=0;ba=0;while(1){Z=b[wa+(Ic<<7)+(d[f+368+na|0]<<1)>>1]|0;ia=Z<<16>>16;ha=Z<<16>>16>-1?ia:-ia|0;do{if((ha|0)==1){if(Ha&(na|0)==0){Mc=ba;Nc=k;break}Mc=(a[1611528+k|0]|0)+ba|0;Nc=0}else{if((ha|0)>1){break e}Mc=ba;Nc=k+1|0}}while(0);ha=na+1|0;if((ha|0)>(ea|0)){Kc=Mc;break}else{na=ha;k=Nc;ba=Mc}}}if((Kc|0)>=(g|0)){break}if((va|0)<=(ea|0)){ba=va;do{b[wa+(Ic<<7)+(d[f+368+ba|0]<<1)>>1]=0;ba=ba+1|0;}while((ba|0)<=(ea|0))}if((b[la>>1]|0)==0){c[Ca>>2]=-1;break}else{c[Ca>>2]=0;break}}}while(0);Ca=Ic+1|0;if((Ca|0)>=4){break d}Ic=Ca;Jc=c[oa>>2]|0}}}while(0);oa=f+76|0;Ia=c[oa>>2]|0;f:do{if((Ia|0)!=0){if((c[ma>>2]|0)==0){Oc=4;Pc=Ia}else{break}while(1){Ba=c[W>>2]|0;Ga=Ba+(Oc<<7)|0;Ca=f+180+(Oc<<2)|0;la=c[Ca>>2]|0;ea=Pc>>>31;wa=ea^1;va=(Pc|0)<0?-Pc|0:Pc;g:do{if((la|0)>(ea<<31>>31|0)){if((la|0)<0){Qc=0}else{g=(ea|0)!=1;fa=0;Mb=0;ba=0;while(1){k=b[Ba+(Oc<<7)+(d[f+368+fa|0]<<1)>>1]|0;na=k<<16>>16;Ha=k<<16>>16>-1?na:-na|0;do{if((Ha|0)==1){if(g&(fa|0)==0){Rc=ba;Sc=Mb;break}Rc=(a[1611528+Mb|0]|0)+ba|0;Sc=0}else{if((Ha|0)>1){break g}Rc=ba;Sc=Mb+1|0}}while(0);Ha=fa+1|0;if((Ha|0)>(la|0)){Qc=Rc;break}else{fa=Ha;Mb=Sc;ba=Rc}}}if((Qc|0)>=(va|0)){break}if((wa|0)<=(la|0)){ba=wa;do{b[Ba+(Oc<<7)+(d[f+368+ba|0]<<1)>>1]=0;ba=ba+1|0;}while((ba|0)<=(la|0))}if((b[Ga>>1]|0)==0){c[Ca>>2]=-1;break}else{c[Ca>>2]=0;break}}}while(0);Ca=Oc+1|0;if((Ca|0)>=6){break f}Oc=Ca;Pc=c[oa>>2]|0}}}while(0);do{if((c[f+14404>>2]&8|0)!=0){if((c[f+180>>2]|0)==-1){c[f+13112>>2]=8388607}if((c[f+184>>2]|0)==-1){c[f+13116>>2]=8388607}if((c[f+188>>2]|0)==-1){c[f+13120>>2]=8388607}if((c[f+192>>2]|0)==-1){c[f+13124>>2]=8388607}if((c[f+196>>2]|0)==-1){c[f+13128>>2]=8388607}if(!((c[f+200>>2]|0)==-1)){break}c[f+13132>>2]=8388607}}while(0);do{if((c[f+60>>2]&8192|0)!=0){if((c[ma>>2]|0)==0){break}c[f+200>>2]=0;c[f+196>>2]=0;oa=c[f+172>>2]|0;Ia=((((oa|0)/2|0)+1024|0)/(oa|0)|0)&65535;oa=c[W>>2]|0;b[oa+640>>1]=Ia;b[oa+512>>1]=Ia;if((c[f+14220>>2]|0)!=0){break}c[f+204>>2]=0;b[oa+768>>1]=Ia;c[f+208>>2]=0;b[oa+896>>1]=Ia;c[f+212>>2]=0;b[oa+1024>>1]=Ia;c[f+216>>2]=0;b[oa+1152>>1]=Ia;c[f+220>>2]=0;b[oa+1280>>1]=Ia;c[f+224>>2]=0;b[oa+1408>>1]=Ia}}while(0);do{if((c[f+14200>>2]|0)!=0){if((c[ja>>2]|0)==4){break}ma=f+180|0;if((c[ma>>2]|0)>0){Ia=63;while(1){if((Ia|0)<=0){break}if((b[(c[W>>2]|0)+(d[f+368+Ia|0]<<1)>>1]|0)==0){Ia=Ia-1|0}else{break}}c[ma>>2]=Ia}oa=f+184|0;if((c[oa>>2]|0)>0){Ca=63;while(1){if((Ca|0)<=0){break}if((b[(c[W>>2]|0)+128+(d[f+368+Ca|0]<<1)>>1]|0)==0){Ca=Ca-1|0}else{break}}c[oa>>2]=Ca}Ia=f+188|0;if((c[Ia>>2]|0)>0){ma=63;while(1){if((ma|0)<=0){break}if((b[(c[W>>2]|0)+256+(d[f+368+ma|0]<<1)>>1]|0)==0){ma=ma-1|0}else{break}}c[Ia>>2]=ma}Ca=f+192|0;if((c[Ca>>2]|0)>0){oa=63;while(1){if((oa|0)<=0){break}if((b[(c[W>>2]|0)+384+(d[f+368+oa|0]<<1)>>1]|0)==0){oa=oa-1|0}else{break}}c[Ca>>2]=oa}ma=f+196|0;if((c[ma>>2]|0)>0){Ia=63;while(1){if((Ia|0)<=0){break}if((b[(c[W>>2]|0)+512+(d[f+368+Ia|0]<<1)>>1]|0)==0){Ia=Ia-1|0}else{break}}c[ma>>2]=Ia}oa=f+200|0;if((c[oa>>2]|0)>0){Tc=63}else{break}while(1){if((Tc|0)<=0){break}if((b[(c[W>>2]|0)+640+(d[f+368+Tc|0]<<1)>>1]|0)==0){Tc=Tc-1|0}else{break}}c[oa>>2]=Tc}}while(0);switch(c[f+48>>2]|0){case 19:{Thb(f,c[W>>2]|0,o,p);break a;break};case 4:{Lga(f,c[W>>2]|0,o,p);break a;break};case 5:case 20:case 22:case 6:case 7:{yqb(f,c[W>>2]|0,o,p);break a;break};case 8:case 108:{AQa(f,c[W>>2]|0);break a;break};case 1:case 2:{xRa(f,c[W>>2]|0,o,p);break a;break};case 13:{bSa(f,c[W>>2]|0,o,p);break a;break};case 16:case 17:case 18:{SUa(f,c[W>>2]|0,o,p);break a;break};default:{break a}}}else if((l|0)==2){ja=x;Ia=c[f+12476>>2]|0;ma=c[f+12480>>2]|0;Ca=f+148|0;Ga=c[Ca>>2]|0;la=f+152|0;Ba=c[la>>2]|0;wa=c[f+10044>>2]|0;va=y|0;c[va>>2]=wa;ea=y+4|0;c[ea>>2]=wa;ba=y+8|0;c[ba>>2]=wa;Mb=y+12|0;c[Mb>>2]=wa;fa=y+16|0;c[fa>>2]=wa;g=y+20|0;c[g>>2]=wa;Ha=y+24|0;c[Ha>>2]=wa;na=y+28|0;c[na>>2]=wa;wa=Ga<<3;Ga=Ba<<3;do{if((c[f+9980>>2]|0)==0){if((c[f+14404>>2]&4|0)==0){break}QTa(f,S+Q|0)}else{Ba=(ca(c[f+124>>2]|0,ma)|0)+Ia|0;k=c[(c[f+9976>>2]|0)+(Ba<<2)>>2]|0;c[f+9968>>2]=k;ha=((k*139|0)+8192|0)>>>14;c[R>>2]=ha;ia=c[f+4>>2]|0;Z=c[ia+500>>2]|0;ga=c[ia+504>>2]|0;if((ha|0)<(Z|0)){Uc=Z}else{Uc=(ha|0)>(ga|0)?ga:ha}c[R>>2]=Uc;c[f+9972>>2]=((ca(k,k)|0)+64|0)>>>7;do{if((c[f+14404>>2]&4|0)==0){k=a[(c[(c[f+9856>>2]|0)+1512>>2]|0)+Ba|0]|0;c[R>>2]=k;ha=k-Q|0;c[T>>2]=ha;if((c[f+28>>2]|0)!=2){Vc=ha;break}if((ha|0)<-2){Wc=-2}else{Wc=(ha|0)>2?2:ha}c[T>>2]=Wc;if((c[f+48>>2]|0)!=13){Vc=Wc;break}if((c[f+12488>>2]|0)!=0){Vc=Wc;break}do{if((c[f+9992>>2]|0)==3){if((Wc&1|0)==0){if((c[f+11736>>2]&4|0)==0){Xc=Wc;break}}c[T>>2]=0;Xc=0}else{Xc=Wc}}while(0);if((c[f+11740>>2]|0)!=1){Vc=Xc;break}c[T>>2]=0;Vc=0}else{Vc=S}}while(0);QTa(f,Vc+Q|0)}}while(0);Ba=c[Ca>>2]|0;oa=c[la>>2]|0;ha=ma<<4;k=Ia<<4;ga=(c[f+5400>>2]|0)+((ca(Ba,ha)|0)+k)|0;Z=Ia<<3;ia=(ca(oa,ha)|0)+Z|0;_=(c[f+5404>>2]|0)+ia|0;ta=(c[f+5408>>2]|0)+ia|0;ia=c[f+8>>2]|0;if((k+16|0)>(ia|0)){xa=272}else{if((ha+16|0)>(c[f+12>>2]|0)){xa=272}else{Yc=ga;Zc=_;_c=ta}}do{if((xa|0)==272){if((c[f+48>>2]|0)==108){Yc=ga;Zc=_;_c=ta;break}da=c[f+9944>>2]|0;Ea=da+32|0;aa=c[f+14216>>2]|0;Fa=aa+ia>>aa;aa=c[f+12>>2]|0;Da=c[f+14220>>2]|0;ua=Da+aa>>Da;Da=f+11540|0;Ve[c[Da>>2]&127](Ea,ga,Ba,Ba,16,16,k,ha,ia,aa);aa=Ba*18|0;fb=da+(aa+32)|0;Ve[c[Da>>2]&127](fb,_,oa,oa,8,16,Z,ha,Fa,ua);ka=da+(aa+48)|0;Ve[c[Da>>2]&127](ka,ta,oa,oa,8,16,Z,ha,Fa,ua);Yc=Ea;Zc=fb;_c=ka}}while(0);ha=f+12488|0;do{if((c[ha>>2]|0)==0){Z=c[f+12544>>2]|0;ta=c[f+12548>>2]|0;_=c[f+12552>>2]|0;do{if((c[f+12472>>2]|0)==0){xa=287}else{if((c[f+9992>>2]|0)==3){xa=287;break}$c=f+10936|0;ad=f+11460|0}}while(0);if((xa|0)==287){$c=f+10680|0;ad=f+11332|0}ia=f+11736|0;k=c[ia>>2]|0;if((k&1|0)==0){bd=$c;cd=ad;dd=k}else{mUa(f,Z,ta,_,0,f+952|0,ad,$c);bd=f+10808|0;cd=f+11396|0;dd=c[ia>>2]|0}if((dd&2|0)!=0){mUa(f,Z,ta,_,1,f+3176|0,cd,bd)}ia=f+60|0;do{if((c[ia>>2]&262144|0)==0){ed=wa;fd=Ga;gd=Ba;hd=oa}else{k=f+14236|0;c[k>>2]=0;ga=f+10540|0;la=f;Ca=Xe[c[ga>>2]&511](la,Z,Yc,Ba,8)|0;ka=Ba<<3;fb=(Xe[c[ga>>2]&511](la,Z+ka|0,Yc+ka|0,Ba,8)|0)+Ca|0;Ca=fb+((c[(c[f+4>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((Ca|0)<=0){ed=wa;fd=Ga;gd=Ba;hd=oa;break}fb=Ba<<1;ka=Xe[c[ga>>2]&511](la,Z,Yc,fb,8)|0;if((Ca|0)<=((Xe[c[ga>>2]&511](la,Z+Ba|0,Yc+Ba|0,fb,8)|0)+ka|0)){ed=wa;fd=Ga;gd=Ba;hd=oa;break}c[k>>2]=1;ed=Ba;fd=oa;gd=fb;hd=oa<<((c[j>>2]|0)==2)}}while(0);fb=f+10060|0;mf[c[fb>>2]&2047](c[W>>2]|0,Yc,Z,gd);k=Yc+8|0;ka=Z+8|0;mf[c[fb>>2]&2047]((c[W>>2]|0)+128|0,k,ka,gd);la=Yc+ed|0;ga=Z+ed|0;mf[c[fb>>2]&2047]((c[W>>2]|0)+256|0,la,ga,gd);Ca=ed+8|0;Ea=Yc+Ca|0;ua=Z+Ca|0;mf[c[fb>>2]&2047]((c[W>>2]|0)+384|0,Ea,ua,gd);do{if((c[ia>>2]&8192|0)==0){mf[c[fb>>2]&2047]((c[W>>2]|0)+512|0,Zc,ta,hd);mf[c[fb>>2]&2047]((c[W>>2]|0)+640|0,_c,_,hd);if((c[f+14220>>2]|0)!=0){break}mf[c[fb>>2]&2047]((c[W>>2]|0)+768|0,Zc+fd|0,ta+fd|0,hd);mf[c[fb>>2]&2047]((c[W>>2]|0)+896|0,_c+fd|0,_+fd|0,hd)}else{c[fa>>2]=1;c[g>>2]=1}}while(0);fb=(ca(c[f+124>>2]|0,ma)|0)+Ia|0;ia=c[R>>2]|0;if((e[(c[f+9200>>2]|0)+(fb<<1)>>1]|0)>=(ca(ia<<1,ia)|0)){id=ed;jd=fd;kd=gd;ld=hd;break}ia=f+10112|0;fb=Xe[c[ia>>2]&511](0,Yc,Z,gd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[va>>2]=1}fb=Xe[c[ia>>2]&511](0,k,ka,gd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[ea>>2]=1}fb=Xe[c[ia>>2]&511](0,la,ga,gd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[ba>>2]=1}fb=Xe[c[ia>>2]&511](0,Ea,ua,gd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[Mb>>2]=1}fb=Xe[c[ia>>2]&511](0,Zc,ta,hd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[fa>>2]=1}fb=Xe[c[ia>>2]&511](0,_c,_,hd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[g>>2]=1}if((c[f+14220>>2]|0)!=0){id=ed;jd=fd;kd=gd;ld=hd;break}fb=Xe[c[ia>>2]&511](0,Zc+fd|0,ta+fd|0,hd,8)|0;if((fb|0)<((c[R>>2]|0)*20|0|0)){c[Ha>>2]=1}fb=Xe[c[ia>>2]&511](0,_c+fd|0,_+fd|0,hd,8)|0;if((fb|0)>=((c[R>>2]|0)*20|0|0)){id=ed;jd=fd;kd=gd;ld=hd;break}c[na>>2]=1;id=ed;jd=fd;kd=gd;ld=hd}else{fb=f+60|0;do{if((c[fb>>2]&262144|0)==0){md=wa;nd=Ga;od=Ba;pd=oa}else{ia=f+14236|0;c[ia>>2]=0;Ca=f+10556|0;Fa=f;Da=Xe[c[Ca>>2]&511](Fa,Yc,0,Ba,8)|0;aa=Da-400+(Xe[c[Ca>>2]&511](Fa,Yc+(Ba<<3)|0,0,Ba,8)|0)|0;if((aa|0)<=0){md=wa;nd=Ga;od=Ba;pd=oa;break}Da=Ba<<1;da=Xe[c[Ca>>2]&511](Fa,Yc,0,Da,8)|0;if((aa|0)<=((Xe[c[Ca>>2]&511](Fa,Yc+Ba|0,0,Da,8)|0)+da|0)){md=wa;nd=Ga;od=Ba;pd=oa;break}c[ia>>2]=1;md=Ba;nd=oa;od=Da;pd=oa<<(((c[j>>2]|0)-2|0)>>>0<2>>>0)}}while(0);_=f+10056|0;ef[c[_>>2]&4095](c[W>>2]|0,Yc,od);ef[c[_>>2]&4095]((c[W>>2]|0)+128|0,Yc+8|0,od);ef[c[_>>2]&4095]((c[W>>2]|0)+256|0,Yc+md|0,od);ef[c[_>>2]&4095]((c[W>>2]|0)+384|0,Yc+(md+8)|0,od);if((c[fb>>2]&8192|0)!=0){c[fa>>2]=1;c[g>>2]=1;id=md;jd=nd;kd=od;ld=pd;break}ef[c[_>>2]&4095]((c[W>>2]|0)+512|0,Zc,pd);ef[c[_>>2]&4095]((c[W>>2]|0)+640|0,_c,pd);if((c[f+14220>>2]|0)!=0){id=md;jd=nd;kd=od;ld=pd;break}ta=c[_>>2]|0;ua=(c[W>>2]|0)+768|0;if((c[f+14216>>2]|0)==0){ef[ta&4095](ua,Zc+8|0,pd);ef[c[_>>2]&4095]((c[W>>2]|0)+896|0,_c+8|0,pd);ef[c[_>>2]&4095]((c[W>>2]|0)+1024|0,Zc+nd|0,pd);ef[c[_>>2]&4095]((c[W>>2]|0)+1152|0,_c+nd|0,pd);Ea=nd+8|0;ef[c[_>>2]&4095]((c[W>>2]|0)+1280|0,Zc+Ea|0,pd);ef[c[_>>2]&4095]((c[W>>2]|0)+1408|0,_c+Ea|0,pd);id=md;jd=nd;kd=od;ld=pd;break}else{ef[ta&4095](ua,Zc+nd|0,pd);ef[c[_>>2]&4095]((c[W>>2]|0)+896|0,_c+nd|0,pd);id=md;jd=nd;kd=od;ld=pd;break}}}while(0);oa=f+14408|0;if((c[oa>>2]|0)!=0){if((c[va>>2]|0)==0){lUa(w|0,Yc,kd)}if((c[ea>>2]|0)==0){lUa(w+128|0,Yc+8|0,kd)}if((c[ba>>2]|0)==0){lUa(w+256|0,Yc+id|0,kd)}if((c[Mb>>2]|0)==0){lUa(w+384|0,Yc+(id+8)|0,kd)}if((c[fa>>2]|0)==0){lUa(w+512|0,Zc,ld)}if((c[g>>2]|0)==0){lUa(w+640|0,_c,ld)}do{if((c[f+14220>>2]|0)==0){if((c[Ha>>2]|0)==0){lUa(w+768|0,Zc+jd|0,ld)}if((c[na>>2]|0)!=0){break}lUa(w+896|0,_c+jd|0,ld)}}while(0);nrc(ja|0,c[W>>2]|0,1024)|0}na=f+14392|0;Ha=f+13084|0;g=f+13080|0;fa=f+4|0;Mb=0;do{do{if((c[y+(Mb<<2)>>2]|0)==0){ba=Xe[c[na>>2]&511](f,(c[W>>2]|0)+(Mb<<7)|0,Mb,c[R>>2]|0,s)|0;c[f+180+(Mb<<2)>>2]=ba;if((c[s>>2]|0)==0){break}ea=c[W>>2]|0;va=c[Ha>>2]|0;Ba=c[g>>2]|0;Ga=(c[ha>>2]|0)!=0|0;if((Ga|0)>(ba|0)){break}wa=va&65535;Ia=Ba&65535;ma=0;_=Ga;while(1){Ga=ea+(Mb<<7)+(d[f+368+_|0]<<1)|0;ua=b[Ga>>1]|0;ta=ua<<16>>16;if((ta|0)>(va|0)){qd=wa;rd=ma+1|0}else{Ea=(ta|0)<(Ba|0);qd=Ea?Ia:ua;rd=(Ea&1)+ma|0}b[Ga>>1]=qd;Ga=_+1|0;if((Ga|0)>(ba|0)){break}else{ma=rd;_=Ga}}if((rd|0)==0){break}_=c[fa>>2]|0;if((c[_+296>>2]|0)!=0){break}KIb(_,32,2630632,(ab=i,i=i+24|0,c[ab>>2]=rd,c[ab+8>>2]=Ba,c[ab+16>>2]=va,ab)|0);i=ab}else{c[f+180+(Mb<<2)>>2]=-1}}while(0);Mb=Mb+1|0;}while((Mb|0)<8);if((c[oa>>2]|0)!=0){Mb=u|0;fa=f+364|0;g=f+13100|0;Ha=f+13104|0;ja=f+9972|0;fb=t|0;_=f+11256|0;ma=f+11252|0;ba=v|0;Ia=f+11164|0;wa=f+228|0;ea=f+168|0;Ga=f+172|0;Ea=f+13092|0;ua=f+13096|0;ta=0;do{if((c[y+(ta<<2)>>2]|0)==0){ga=c[W>>2]|0;la=ga+(ta<<7)|0;ka=w+(ta<<7)|0;k=c[R>>2]|0;Z=c[fa>>2]|0;if((b[4945388]|0)==0){Da=0;do{ia=Da<<3;db=(Da|0)==0?11585.237502960395:16384.0;bb=db*.7071067811865476;cb=+(Da|0)*.39269908169872414;da=0;do{Fa=da+ia+(f+11184)|0;Ca=(da|0)==0;eb=+(da|0)*.39269908169872414;aa=0;do{gb=+U(eb*(+(aa|0)+.5));if(Ca){hb=0;do{$=d[Fa]|0;b[9890776+($<<7)+((hb<<3)+aa<<1)>>1]=Lc(+(gb*bb*+U(cb*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}else{hb=0;do{$=d[Fa]|0;b[9890776+($<<7)+((hb<<3)+aa<<1)>>1]=Lc(+(gb*db*+U(cb*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}aa=aa+1|0;}while((aa|0)<8);da=da+1|0;}while((da|0)<8);Da=Da+1|0;}while((Da|0)<8)}Da=k<<1;da=k-1|1;if((c[ha>>2]|0)==0){sd=da;td=0;ud=32;vd=g;wd=Ha;xd=1}else{do{if((c[wa>>2]|0)==0){if((ta|0)<4){yd=da;zd=c[ea>>2]|0;break}else{yd=da;zd=c[Ga>>2]|0;break}}else{yd=0;zd=1}}while(0);da=zd<<3;sd=yd;td=1;ud=(ca(b[la>>1]|0,da)|0)+32|0;vd=Ea;wd=ua;xd=da}da=c[vd>>2]|0;k=c[wd>>2]|0;ia=f+180+(ta<<2)|0;va=c[ia>>2]|0;Ba=0;while(1){b[t+(Ba<<1)>>1]=ud-(b[x+(ta<<7)+(Ba<<1)>>1]<<6);aa=Ba+1|0;if((aa|0)<64){Ba=aa}else{Ad=0;Bd=0;break}}do{Ba=w+(ta<<7)+(Bd<<1)|0;aa=b[Ba>>1]|0;Fa=aa<<16>>16;Ca=(aa<<16>>16>-1?Fa:-Fa|0)+144|0;Fa=((((Ca|0)/2|0)+6912|0)/(Ca|0)|0)+15|0;b[Ba>>1]=Fa;Ad=(ca(Fa,Fa)|0)+Ad|0;Bd=Bd+1|0;}while((Bd|0)<64);Fa=Erc(c[ja>>2]|0,0,Ad,(Ad|0)<0|0?-1:0)|0;Ba=Fa>>>19|G<<13;Fa=-sd|0;if((td|0)<=(va|0)){Ca=0;aa=0;hb=td;while(1){$=d[f+368+hb|0]|0;Pb=b[ga+(ta<<7)+($<<1)>>1]|0;if(Pb<<16>>16==0){Cd=aa;Dd=Ca+1|0}else{_b=ca(Pb<<16>>16,Da)|0;c[v+(aa<<2)>>2]=Ca;ef[c[_>>2]&4095](fb,9890776+($<<7)|0,_b+(Pb<<16>>16<0?Fa:sd)|0);Cd=aa+1|0;Dd=0}Pb=hb+1|0;if((Pb|0)>(va|0)){break}else{Ca=Dd;aa=Cd;hb=Pb}}}hb=(td|0)==0;aa=-xd|0;Ca=va;while(1){Pb=hf[c[ma>>2]&1023](fb,ka,9890776,0)|0;if((Ca|0)>2){Ed=0;xa=381}else{if((c[oa>>2]|0)>2){Ed=0;xa=381}else{Fd=0}}if((xa|0)==381){while(1){xa=0;_b=b[w+(ta<<7)+(Ed<<1)>>1]|0;b[u+(Ed<<1)>>1]=(ca(ca(_b,_b)|0,b[t+(Ed<<1)>>1]|0)|0)+131072>>18;_b=Ed+1|0;if((_b|0)<64){Ed=_b;xa=381}else{break}}qe[c[Ia>>2]&1023](Mb);Fd=1}do{if(hb){Gd=Pb;Hd=0;Id=0}else{_b=b[la>>1]|0;if((ca(_b-1|0,xd)|0)>>>0>2047>>>0){Jd=Pb;Kd=0;Ld=0}else{$=hf[c[ma>>2]&1023](fb,ka,9890776,aa)|0;Lb=($|0)<(Pb|0);Jd=Lb?$:Pb;Kd=Lb<<31>>31;Ld=Lb?aa:0}if((ca(_b+1|0,xd)|0)>>>0>2047>>>0){Gd=Jd;Hd=Kd;Id=Ld;break}_b=hf[c[ma>>2]&1023](fb,ka,9890776,xd)|0;Lb=(_b|0)<(Jd|0);Gd=Lb?_b:Jd;Hd=Lb?1:Kd;Id=Lb?xd:Ld}}while(0);Pb=Ca+1|0;Lb=c[ba>>2]|0;_b=Id;$=Hd;Ub=0;Kb=Gd;Jb=0;Ib=1;Hb=td;Gb=0;ib=0;while(1){wb=d[f+368+Hb|0]|0;Fb=b[ga+(ta<<7)+(wb<<1)>>1]|0;tb=Fb<<16>>16;rc=c[oa>>2]|0;if((rc|0)<3&(Hb|0)>(Pb|0)){Md=_b;Nd=$;Od=Ub;break}qc=Fb<<16>>16!=0;if(qc){pc=ca(tb,Da)|0;Pd=pc+(Fb<<16>>16<0?Fa:sd)|0;Qd=Ib+1|0;Rd=c[v+(Ib<<2)>>2]|0}else{Pd=0;Qd=Ib;Rd=Lb-1|0}pc=Fb<<16>>16>-1?tb:-tb|0;oc=(Hb|0)<(Ca|0);nc=Hb+1|0;mc=Rd+nc|0;hc=f+368+mc|0;$b=(mc|0)<(Ca|0);mc=(Rd+Jb<<7)+128|0;bc=Rd<<7;cc=Jb<<7;fc=cc|65;ac=da+fc|0;ic=k+fc|0;fc=(Gb|0)==0;jc=(ib<<7)+Gb|0;ec=k+jc|0;gc=da+jc|0;jc=9890776+(wb<<7)|0;wb=(Fb+62&65535)>>>0<125>>>0;Fb=cc|64;cc=tb+Fb|0;Zb=da+cc|0;dc=k+cc|0;cc=Z+Hb|0;lc=_b;kc=$;Ob=Ub;Nb=Kb;Vb=-1;Qb=rc;while(1){rc=Vb+tb|0;if((Qb|0)<2){if((((rc|0)>-1?rc:-rc|0)|0)>(pc|0)){Sd=Nb;Td=Ob;Ud=kc;Vd=lc}else{xa=395}}else{xa=395}h:do{if((xa|0)==395){xa=0;do{if((rc|0)==0){if(!oc){zc=d[ic]|0;if(fc){Wd=0;Xd=-zc|0;break}Wd=0;Xd=(d[ec]|0)-zc-(d[gc]|0)|0;break}zc=(b[ga+(ta<<7)+(d[hc]<<1)>>1]|0)+64|0;Ac=zc>>>0>127>>>0?0:zc;zc=Ac+mc|0;if($b){Wd=0;Xd=(d[da+zc|0]|0)-(d[da+(Ac+bc)|0]|0)-(d[ac]|0)|0;break}else{Wd=0;Xd=(d[k+zc|0]|0)-(d[k+(Ac+bc)|0]|0)-(d[ac]|0)|0;break}}else{Ac=ca(rc,Da)|0;zc=((rc|0)<0?Fa:sd)+Ac|0;if((zc+2047|0)>>>0>4094>>>0){Sd=Nb;Td=Ob;Ud=kc;Vd=lc;break h}if(qc){if(!wb){Wd=zc;Xd=0;break}Ac=rc+Fb|0;if(oc){Wd=zc;Xd=(d[da+Ac|0]|0)-(d[Zb]|0)|0;break}else{Wd=zc;Xd=(d[k+Ac|0]|0)-(d[dc]|0)|0;break}}do{if(Fd){Ac=b[u+(d[cc]<<1)>>1]|0;if(Ac<<16>>16==0){break}if((Ac<<16>>16^rc|0)>-1){Sd=Nb;Td=Ob;Ud=kc;Vd=lc;break h}}}while(0);if(!oc){wc=d[ic]|0;if(fc){Wd=zc;Xd=wc;break}Wd=zc;Xd=(d[gc]|0)+wc-(d[ec]|0)|0;break}wc=(b[ga+(ta<<7)+(d[hc]<<1)>>1]|0)+64|0;Ac=wc>>>0>127>>>0?0:wc;wc=d[ac]|0;Bc=Ac+bc|0;if($b){Wd=zc;Xd=(d[da+Bc|0]|0)+wc-(d[da+(Ac+mc)|0]|0)|0;break}else{Wd=zc;Xd=(d[k+Bc|0]|0)+wc-(d[k+(Ac+mc)|0]|0)|0;break}}}while(0);Ac=ca(Xd,Ba)|0;wc=Wd-Pd|0;Bc=(hf[c[ma>>2]&1023](fb,ka,jc,wc)|0)+Ac|0;Ac=(Bc|0)<(Nb|0);Sd=Ac?Bc:Nb;Td=Ac?Hb:Ob;Ud=Ac?Vb:kc;Vd=Ac?wc:lc}}while(0);if((Vb|0)>=0){break}lc=Vd;kc=Ud;Ob=Td;Nb=Sd;Vb=Vb+2|0;Qb=c[oa>>2]|0}if(qc){Qb=tb+64|0;Yd=Jb;Zd=Qb>>>0>127>>>0?0:Qb;_d=0}else{Yd=ib;Zd=Gb;_d=Jb+1|0}if((nc|0)<64){Lb=Rd;_b=Vd;$=Ud;Ub=Td;Kb=Sd;Jb=_d;Ib=Qd;Hb=nc;Gb=Zd;ib=Yd}else{Md=Vd;Nd=Ud;Od=Td;break}}if((Nd|0)==0){break}ib=d[f+368+Od|0]|0;Gb=ga+(ta<<7)+(ib<<1)|0;b[Gb>>1]=(e[Gb>>1]|0)+Nd;i:do{if((Od|0)>(Ca|0)){$d=Od}else{Gb=Ca;while(1){if((Gb|0)<(td|0)){$d=Gb;break i}if((b[ga+(ta<<7)+(d[f+368+Gb|0]<<1)>>1]|0)==0){Gb=Gb-1|0}else{$d=Gb;break}}}}while(0);if((td|0)<=($d|0)){Gb=0;nc=0;tb=td;while(1){if((b[ga+(ta<<7)+(d[f+368+tb|0]<<1)>>1]|0)==0){ae=nc;be=Gb+1|0}else{c[v+(nc<<2)>>2]=Gb;ae=nc+1|0;be=0}qc=tb+1|0;if((qc|0)>($d|0)){break}else{Gb=be;nc=ae;tb=qc}}}ef[c[_>>2]&4095](fb,9890776+(ib<<7)|0,Md);Ca=$d}c[ia>>2]=Ca}ta=ta+1|0;}while((ta|0)<8)}ta=f+72|0;fb=c[ta>>2]|0;j:do{if((fb|0)!=0){if((c[ha>>2]|0)==0){ce=0;de=fb}else{break}while(1){_=c[W>>2]|0;oa=_+(ce<<7)|0;ma=f+180+(ce<<2)|0;ba=c[ma>>2]|0;Mb=de>>>31;Ia=Mb^1;ja=(de|0)<0?-de|0:de;k:do{if((ba|0)>(Mb<<31>>31|0)){if((ba|0)<0){ee=0}else{ua=(Mb|0)!=1;Ea=0;Ga=0;ea=0;while(1){wa=b[_+(ce<<7)+(d[f+368+Ea|0]<<1)>>1]|0;Ha=wa<<16>>16;g=wa<<16>>16>-1?Ha:-Ha|0;do{if((g|0)==1){if(ua&(Ea|0)==0){fe=ea;ge=Ga;break}fe=(a[1611528+Ga|0]|0)+ea|0;ge=0}else{if((g|0)>1){break k}fe=ea;ge=Ga+1|0}}while(0);g=Ea+1|0;if((g|0)>(ba|0)){ee=fe;break}else{Ea=g;Ga=ge;ea=fe}}}if((ee|0)>=(ja|0)){break}if((Ia|0)<=(ba|0)){ea=Ia;do{b[_+(ce<<7)+(d[f+368+ea|0]<<1)>>1]=0;ea=ea+1|0;}while((ea|0)<=(ba|0))}if((b[oa>>1]|0)==0){c[ma>>2]=-1;break}else{c[ma>>2]=0;break}}}while(0);ma=ce+1|0;if((ma|0)>=4){break j}ce=ma;de=c[ta>>2]|0}}}while(0);ta=f+76|0;fb=c[ta>>2]|0;l:do{if((fb|0)!=0){if((c[ha>>2]|0)==0){he=4;ie=fb}else{break}while(1){Ca=c[W>>2]|0;ia=Ca+(he<<7)|0;ma=f+180+(he<<2)|0;oa=c[ma>>2]|0;ba=ie>>>31;_=ba^1;Ia=(ie|0)<0?-ie|0:ie;m:do{if((oa|0)>(ba<<31>>31|0)){if((oa|0)<0){je=0}else{ja=(ba|0)!=1;Mb=0;ib=0;ea=0;while(1){Ga=b[Ca+(he<<7)+(d[f+368+Mb|0]<<1)>>1]|0;Ea=Ga<<16>>16;ua=Ga<<16>>16>-1?Ea:-Ea|0;do{if((ua|0)==1){if(ja&(Mb|0)==0){ke=ea;le=ib;break}ke=(a[1611528+ib|0]|0)+ea|0;le=0}else{if((ua|0)>1){break m}ke=ea;le=ib+1|0}}while(0);ua=Mb+1|0;if((ua|0)>(oa|0)){je=ke;break}else{Mb=ua;ib=le;ea=ke}}}if((je|0)>=(Ia|0)){break}if((_|0)<=(oa|0)){ea=_;do{b[Ca+(he<<7)+(d[f+368+ea|0]<<1)>>1]=0;ea=ea+1|0;}while((ea|0)<=(oa|0))}if((b[ia>>1]|0)==0){c[ma>>2]=-1;break}else{c[ma>>2]=0;break}}}while(0);ma=he+1|0;if((ma|0)>=8){break l}he=ma;ie=c[ta>>2]|0}}}while(0);do{if((c[f+14404>>2]&8|0)!=0){if((c[f+180>>2]|0)==-1){c[f+13112>>2]=8388607}if((c[f+184>>2]|0)==-1){c[f+13116>>2]=8388607}if((c[f+188>>2]|0)==-1){c[f+13120>>2]=8388607}if((c[f+192>>2]|0)==-1){c[f+13124>>2]=8388607}if((c[f+196>>2]|0)==-1){c[f+13128>>2]=8388607}if((c[f+200>>2]|0)==-1){c[f+13132>>2]=8388607}if((c[f+204>>2]|0)==-1){c[f+13136>>2]=8388607}if(!((c[f+208>>2]|0)==-1)){break}c[f+13140>>2]=8388607}}while(0);do{if((c[f+60>>2]&8192|0)!=0){if((c[ha>>2]|0)==0){break}c[f+200>>2]=0;c[f+196>>2]=0;ta=c[f+172>>2]|0;fb=((((ta|0)/2|0)+1024|0)/(ta|0)|0)&65535;ta=c[W>>2]|0;b[ta+640>>1]=fb;b[ta+512>>1]=fb;if((c[f+14220>>2]|0)!=0){break}c[f+204>>2]=0;b[ta+768>>1]=fb;c[f+208>>2]=0;b[ta+896>>1]=fb;c[f+212>>2]=0;b[ta+1024>>1]=fb;c[f+216>>2]=0;b[ta+1152>>1]=fb;c[f+220>>2]=0;b[ta+1280>>1]=fb;c[f+224>>2]=0;b[ta+1408>>1]=fb}}while(0);do{if((c[f+14200>>2]|0)!=0){if((c[na>>2]|0)==4){break}else{me=0}do{ha=f+180+(me<<2)|0;if((c[ha>>2]|0)>0){fb=63;while(1){if((fb|0)<=0){break}if((b[(c[W>>2]|0)+(me<<7)+(d[f+368+fb|0]<<1)>>1]|0)==0){fb=fb-1|0}else{break}}c[ha>>2]=fb}me=me+1|0;}while((me|0)<8)}}while(0);switch(c[f+48>>2]|0){case 1:case 2:{xRa(f,c[W>>2]|0,o,p);break a;break};case 13:{bSa(f,c[W>>2]|0,o,p);break a;break};case 16:case 17:case 18:{SUa(f,c[W>>2]|0,o,p);break a;break};case 19:{Thb(f,c[W>>2]|0,o,p);break a;break};case 4:{Lga(f,c[W>>2]|0,o,p);break a;break};case 5:case 20:case 22:case 6:case 7:{yqb(f,c[W>>2]|0,o,p);break a;break};case 8:case 108:{AQa(f,c[W>>2]|0);break a;break};default:{break a}}}else{na=x;ta=c[f+12476>>2]|0;ma=c[f+12480>>2]|0;ia=f+148|0;oa=c[ia>>2]|0;Ca=f+152|0;_=c[Ca>>2]|0;Ia=c[f+10044>>2]|0;ba=y|0;c[ba>>2]=Ia;ea=y+4|0;c[ea>>2]=Ia;ib=y+8|0;c[ib>>2]=Ia;Mb=y+12|0;c[Mb>>2]=Ia;ja=y+16|0;c[ja>>2]=Ia;ua=y+20|0;c[ua>>2]=Ia;Ea=y+24|0;c[Ea>>2]=Ia;Ga=y+28|0;c[Ga>>2]=Ia;c[y+32>>2]=Ia;c[y+36>>2]=Ia;c[y+40>>2]=Ia;c[y+44>>2]=Ia;Ia=oa<<3;oa=_<<3;do{if((c[f+9980>>2]|0)==0){if((c[f+14404>>2]&4|0)==0){break}QTa(f,S+Q|0)}else{_=(ca(c[f+124>>2]|0,ma)|0)+ta|0;g=c[(c[f+9976>>2]|0)+(_<<2)>>2]|0;c[f+9968>>2]=g;Ha=((g*139|0)+8192|0)>>>14;c[R>>2]=Ha;wa=c[f+4>>2]|0;fa=c[wa+500>>2]|0;ga=c[wa+504>>2]|0;if((Ha|0)<(fa|0)){ne=fa}else{ne=(Ha|0)>(ga|0)?ga:Ha}c[R>>2]=ne;c[f+9972>>2]=((ca(g,g)|0)+64|0)>>>7;do{if((c[f+14404>>2]&4|0)==0){g=a[(c[(c[f+9856>>2]|0)+1512>>2]|0)+_|0]|0;c[R>>2]=g;Ha=g-Q|0;c[T>>2]=Ha;if((c[f+28>>2]|0)!=2){oe=Ha;break}if((Ha|0)<-2){pe=-2}else{pe=(Ha|0)>2?2:Ha}c[T>>2]=pe;if((c[f+48>>2]|0)!=13){oe=pe;break}if((c[f+12488>>2]|0)!=0){oe=pe;break}do{if((c[f+9992>>2]|0)==3){if((pe&1|0)==0){if((c[f+11736>>2]&4|0)==0){re=pe;break}}c[T>>2]=0;re=0}else{re=pe}}while(0);if((c[f+11740>>2]|0)!=1){oe=re;break}c[T>>2]=0;oe=0}else{oe=S}}while(0);QTa(f,oe+Q|0)}}while(0);_=c[ia>>2]|0;fb=c[Ca>>2]|0;ha=ma<<4;Ha=ta<<4;g=(c[f+5400>>2]|0)+((ca(_,ha)|0)+Ha)|0;ga=(ca(fb,ha)|0)+Ha|0;fa=(c[f+5404>>2]|0)+ga|0;wa=(c[f+5408>>2]|0)+ga|0;ga=c[f+8>>2]|0;if((Ha+16|0)>(ga|0)){xa=518}else{if((ha+16|0)>(c[f+12>>2]|0)){xa=518}else{se=g;te=fa;ue=wa}}do{if((xa|0)==518){if((c[f+48>>2]|0)==108){se=g;te=fa;ue=wa;break}ka=c[f+9944>>2]|0;Ba=ka+32|0;k=c[f+14216>>2]|0;da=k+ga>>k;k=c[f+12>>2]|0;Fa=c[f+14220>>2]|0;Da=Fa+k>>Fa;Fa=f+11540|0;Ve[c[Fa>>2]&127](Ba,g,_,_,16,16,Ha,ha,ga,k);k=_*18|0;Z=ka+(k+32)|0;Ve[c[Fa>>2]&127](Z,fa,fb,fb,16,16,Ha,ha,da,Da);aa=ka+(k+48)|0;Ve[c[Fa>>2]&127](aa,wa,fb,fb,16,16,Ha,ha,da,Da);se=Ba;te=Z;ue=aa}}while(0);ha=f+12488|0;do{if((c[ha>>2]|0)==0){Ha=c[f+12544>>2]|0;wa=c[f+12548>>2]|0;fa=c[f+12552>>2]|0;do{if((c[f+12472>>2]|0)==0){xa=533}else{if((c[f+9992>>2]|0)==3){xa=533;break}ve=f+10936|0;we=f+11460|0}}while(0);if((xa|0)==533){ve=f+10680|0;we=f+11332|0}ga=f+11736|0;g=c[ga>>2]|0;if((g&1|0)==0){xe=ve;ye=we;ze=g}else{mUa(f,Ha,wa,fa,0,f+952|0,we,ve);xe=f+10808|0;ye=f+11396|0;ze=c[ga>>2]|0}if((ze&2|0)!=0){mUa(f,Ha,wa,fa,1,f+3176|0,ye,xe)}ga=f+60|0;do{if((c[ga>>2]&262144|0)==0){Ae=Ia;Be=oa;Ce=_;De=fb}else{g=f+14236|0;c[g>>2]=0;Ca=f+10540|0;ia=f;aa=Xe[c[Ca>>2]&511](ia,Ha,se,_,8)|0;Z=_<<3;Ba=(Xe[c[Ca>>2]&511](ia,Ha+Z|0,se+Z|0,_,8)|0)+aa|0;aa=Ba+((c[(c[f+4>>2]|0)+244>>2]|0)==9?-800:-400)|0;if((aa|0)<=0){Ae=Ia;Be=oa;Ce=_;De=fb;break}Ba=_<<1;Z=Xe[c[Ca>>2]&511](ia,Ha,se,Ba,8)|0;if((aa|0)<=((Xe[c[Ca>>2]&511](ia,Ha+_|0,se+_|0,Ba,8)|0)+Z|0)){Ae=Ia;Be=oa;Ce=_;De=fb;break}c[g>>2]=1;Ae=_;Be=fb;Ce=Ba;De=fb<<((c[j>>2]|0)==2)}}while(0);Ba=f+10060|0;mf[c[Ba>>2]&2047](c[W>>2]|0,se,Ha,Ce);g=se+8|0;Z=Ha+8|0;mf[c[Ba>>2]&2047]((c[W>>2]|0)+128|0,g,Z,Ce);ia=se+Ae|0;Ca=Ha+Ae|0;mf[c[Ba>>2]&2047]((c[W>>2]|0)+256|0,ia,Ca,Ce);aa=Ae+8|0;Da=se+aa|0;da=Ha+aa|0;mf[c[Ba>>2]&2047]((c[W>>2]|0)+384|0,Da,da,Ce);do{if((c[ga>>2]&8192|0)==0){mf[c[Ba>>2]&2047]((c[W>>2]|0)+512|0,te,wa,De);mf[c[Ba>>2]&2047]((c[W>>2]|0)+640|0,ue,fa,De);if((c[f+14220>>2]|0)!=0){break}mf[c[Ba>>2]&2047]((c[W>>2]|0)+768|0,te+Be|0,wa+Be|0,De);mf[c[Ba>>2]&2047]((c[W>>2]|0)+896|0,ue+Be|0,fa+Be|0,De)}else{c[ja>>2]=1;c[ua>>2]=1}}while(0);Ba=(ca(c[f+124>>2]|0,ma)|0)+ta|0;ga=c[R>>2]|0;if((e[(c[f+9200>>2]|0)+(Ba<<1)>>1]|0)>=(ca(ga<<1,ga)|0)){Ee=Ae;Fe=Be;Ge=Ce;He=De;break}ga=f+10112|0;Ba=Xe[c[ga>>2]&511](0,se,Ha,Ce,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ba>>2]=1}Ba=Xe[c[ga>>2]&511](0,g,Z,Ce,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ea>>2]=1}Ba=Xe[c[ga>>2]&511](0,ia,Ca,Ce,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ib>>2]=1}Ba=Xe[c[ga>>2]&511](0,Da,da,Ce,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[Mb>>2]=1}Ba=Xe[c[ga>>2]&511](0,te,wa,De,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ja>>2]=1}Ba=Xe[c[ga>>2]&511](0,ue,fa,De,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[ua>>2]=1}if((c[f+14220>>2]|0)!=0){Ee=Ae;Fe=Be;Ge=Ce;He=De;break}Ba=Xe[c[ga>>2]&511](0,te+Be|0,wa+Be|0,De,8)|0;if((Ba|0)<((c[R>>2]|0)*20|0|0)){c[Ea>>2]=1}Ba=Xe[c[ga>>2]&511](0,ue+Be|0,fa+Be|0,De,8)|0;if((Ba|0)>=((c[R>>2]|0)*20|0|0)){Ee=Ae;Fe=Be;Ge=Ce;He=De;break}c[Ga>>2]=1;Ee=Ae;Fe=Be;Ge=Ce;He=De}else{Ba=f+60|0;do{if((c[Ba>>2]&262144|0)==0){Ie=Ia;Je=oa;Ke=_;Le=fb}else{ga=f+14236|0;c[ga>>2]=0;aa=f+10556|0;Fa=f;k=Xe[c[aa>>2]&511](Fa,se,0,_,8)|0;ka=k-400+(Xe[c[aa>>2]&511](Fa,se+(_<<3)|0,0,_,8)|0)|0;if((ka|0)<=0){Ie=Ia;Je=oa;Ke=_;Le=fb;break}k=_<<1;la=Xe[c[aa>>2]&511](Fa,se,0,k,8)|0;if((ka|0)<=((Xe[c[aa>>2]&511](Fa,se+_|0,0,k,8)|0)+la|0)){Ie=Ia;Je=oa;Ke=_;Le=fb;break}c[ga>>2]=1;Ie=_;Je=fb;Ke=k;Le=fb<<(((c[j>>2]|0)-2|0)>>>0<2>>>0)}}while(0);fa=f+10056|0;ef[c[fa>>2]&4095](c[W>>2]|0,se,Ke);ef[c[fa>>2]&4095]((c[W>>2]|0)+128|0,se+8|0,Ke);ef[c[fa>>2]&4095]((c[W>>2]|0)+256|0,se+Ie|0,Ke);ef[c[fa>>2]&4095]((c[W>>2]|0)+384|0,se+(Ie+8)|0,Ke);if((c[Ba>>2]&8192|0)!=0){c[ja>>2]=1;c[ua>>2]=1;Ee=Ie;Fe=Je;Ge=Ke;He=Le;break}ef[c[fa>>2]&4095]((c[W>>2]|0)+512|0,te,Le);ef[c[fa>>2]&4095]((c[W>>2]|0)+640|0,ue,Le);if((c[f+14220>>2]|0)!=0){Ee=Ie;Fe=Je;Ge=Ke;He=Le;break}wa=c[fa>>2]|0;da=(c[W>>2]|0)+768|0;if((c[f+14216>>2]|0)==0){ef[wa&4095](da,te+8|0,Le);ef[c[fa>>2]&4095]((c[W>>2]|0)+896|0,ue+8|0,Le);ef[c[fa>>2]&4095]((c[W>>2]|0)+1024|0,te+Je|0,Le);ef[c[fa>>2]&4095]((c[W>>2]|0)+1152|0,ue+Je|0,Le);Da=Je+8|0;ef[c[fa>>2]&4095]((c[W>>2]|0)+1280|0,te+Da|0,Le);ef[c[fa>>2]&4095]((c[W>>2]|0)+1408|0,ue+Da|0,Le);Ee=Ie;Fe=Je;Ge=Ke;He=Le;break}else{ef[wa&4095](da,te+Je|0,Le);ef[c[fa>>2]&4095]((c[W>>2]|0)+896|0,ue+Je|0,Le);Ee=Ie;Fe=Je;Ge=Ke;He=Le;break}}}while(0);fb=f+14408|0;if((c[fb>>2]|0)!=0){if((c[ba>>2]|0)==0){lUa(w|0,se,Ge)}if((c[ea>>2]|0)==0){lUa(w+128|0,se+8|0,Ge)}if((c[ib>>2]|0)==0){lUa(w+256|0,se+Ee|0,Ge)}if((c[Mb>>2]|0)==0){lUa(w+384|0,se+(Ee+8)|0,Ge)}if((c[ja>>2]|0)==0){lUa(w+512|0,te,He)}if((c[ua>>2]|0)==0){lUa(w+640|0,ue,He)}do{if((c[f+14220>>2]|0)==0){if((c[Ea>>2]|0)==0){lUa(w+768|0,te+Fe|0,He)}if((c[Ga>>2]|0)!=0){break}lUa(w+896|0,ue+Fe|0,He)}}while(0);nrc(na|0,c[W>>2]|0,1536)|0}Ga=f+14392|0;Ea=f+13084|0;ua=f+13080|0;ja=f+4|0;Mb=0;do{do{if((c[y+(Mb<<2)>>2]|0)==0){ib=Xe[c[Ga>>2]&511](f,(c[W>>2]|0)+(Mb<<7)|0,Mb,c[R>>2]|0,r)|0;c[f+180+(Mb<<2)>>2]=ib;if((c[r>>2]|0)==0){break}ea=c[W>>2]|0;ba=c[Ea>>2]|0;_=c[ua>>2]|0;oa=(c[ha>>2]|0)!=0|0;if((oa|0)>(ib|0)){break}Ia=ba&65535;ta=_&65535;ma=0;fa=oa;while(1){oa=ea+(Mb<<7)+(d[f+368+fa|0]<<1)|0;da=b[oa>>1]|0;wa=da<<16>>16;if((wa|0)>(ba|0)){Me=Ia;Ne=ma+1|0}else{Da=(wa|0)<(_|0);Me=Da?ta:da;Ne=(Da&1)+ma|0}b[oa>>1]=Me;oa=fa+1|0;if((oa|0)>(ib|0)){break}else{ma=Ne;fa=oa}}if((Ne|0)==0){break}fa=c[ja>>2]|0;if((c[fa+296>>2]|0)!=0){break}KIb(fa,32,2630632,(ab=i,i=i+24|0,c[ab>>2]=Ne,c[ab+8>>2]=_,c[ab+16>>2]=ba,ab)|0);i=ab}else{c[f+180+(Mb<<2)>>2]=-1}}while(0);Mb=Mb+1|0;}while((Mb|0)<12);if((c[fb>>2]|0)!=0){Mb=u|0;ja=f+364|0;ua=f+13100|0;Ea=f+13104|0;na=f+9972|0;Ba=t|0;fa=f+11256|0;ma=f+11252|0;ib=v|0;ta=f+11164|0;Ia=f+228|0;ea=f+168|0;oa=f+172|0;Da=f+13092|0;da=f+13096|0;wa=0;do{if((c[y+(wa<<2)>>2]|0)==0){Ca=c[W>>2]|0;ia=Ca+(wa<<7)|0;Z=w+(wa<<7)|0;g=c[R>>2]|0;Ha=c[ja>>2]|0;if((b[4945388]|0)==0){k=0;do{ga=k<<3;cb=(k|0)==0?11585.237502960395:16384.0;db=cb*.7071067811865476;bb=+(k|0)*.39269908169872414;la=0;do{Fa=la+ga+(f+11184)|0;aa=(la|0)==0;eb=+(la|0)*.39269908169872414;ka=0;do{gb=+U(eb*(+(ka|0)+.5));if(aa){hb=0;do{va=d[Fa]|0;b[9890776+(va<<7)+((hb<<3)+ka<<1)>>1]=Lc(+(gb*db*+U(bb*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}else{hb=0;do{va=d[Fa]|0;b[9890776+(va<<7)+((hb<<3)+ka<<1)>>1]=Lc(+(gb*cb*+U(bb*(+(hb|0)+.5))))|0;hb=hb+1|0;}while((hb|0)<8)}ka=ka+1|0;}while((ka|0)<8);la=la+1|0;}while((la|0)<8);k=k+1|0;}while((k|0)<8)}k=g<<1;la=g-1|1;if((c[ha>>2]|0)==0){Oe=la;Pe=0;Qe=32;Re=ua;Se=Ea;Te=1}else{do{if((c[Ia>>2]|0)==0){if((wa|0)<4){Ue=la;We=c[ea>>2]|0;break}else{Ue=la;We=c[oa>>2]|0;break}}else{Ue=0;We=1}}while(0);la=We<<3;Oe=Ue;Pe=1;Qe=(ca(b[ia>>1]|0,la)|0)+32|0;Re=Da;Se=da;Te=la}la=c[Re>>2]|0;g=c[Se>>2]|0;ga=f+180+(wa<<2)|0;ba=c[ga>>2]|0;_=0;while(1){b[t+(_<<1)>>1]=Qe-(b[x+(wa<<7)+(_<<1)>>1]<<6);ka=_+1|0;if((ka|0)<64){_=ka}else{Ye=0;Ze=0;break}}do{_=w+(wa<<7)+(Ze<<1)|0;ka=b[_>>1]|0;Fa=ka<<16>>16;aa=(ka<<16>>16>-1?Fa:-Fa|0)+144|0;Fa=((((aa|0)/2|0)+6912|0)/(aa|0)|0)+15|0;b[_>>1]=Fa;Ye=(ca(Fa,Fa)|0)+Ye|0;Ze=Ze+1|0;}while((Ze|0)<64);Fa=Erc(c[na>>2]|0,0,Ye,(Ye|0)<0|0?-1:0)|0;_=Fa>>>19|G<<13;Fa=-Oe|0;if((Pe|0)<=(ba|0)){aa=0;ka=0;hb=Pe;while(1){va=d[f+368+hb|0]|0;tb=b[Ca+(wa<<7)+(va<<1)>>1]|0;if(tb<<16>>16==0){_e=ka;$e=aa+1|0}else{nc=ca(tb<<16>>16,k)|0;c[v+(ka<<2)>>2]=aa;ef[c[fa>>2]&4095](Ba,9890776+(va<<7)|0,nc+(tb<<16>>16<0?Fa:Oe)|0);_e=ka+1|0;$e=0}tb=hb+1|0;if((tb|0)>(ba|0)){break}else{aa=$e;ka=_e;hb=tb}}}hb=(Pe|0)==0;ka=-Te|0;aa=ba;while(1){tb=hf[c[ma>>2]&1023](Ba,Z,9890776,0)|0;if((aa|0)>2){af=0;xa=627}else{if((c[fb>>2]|0)>2){af=0;xa=627}else{bf=0}}if((xa|0)==627){while(1){xa=0;nc=b[w+(wa<<7)+(af<<1)>>1]|0;b[u+(af<<1)>>1]=(ca(ca(nc,nc)|0,b[t+(af<<1)>>1]|0)|0)+131072>>18;nc=af+1|0;if((nc|0)<64){af=nc;xa=627}else{break}}qe[c[ta>>2]&1023](Mb);bf=1}do{if(hb){cf=tb;df=0;ff=0}else{nc=b[ia>>1]|0;if((ca(nc-1|0,Te)|0)>>>0>2047>>>0){gf=tb;jf=0;kf=0}else{va=hf[c[ma>>2]&1023](Ba,Z,9890776,ka)|0;Gb=(va|0)<(tb|0);gf=Gb?va:tb;jf=Gb<<31>>31;kf=Gb?ka:0}if((ca(nc+1|0,Te)|0)>>>0>2047>>>0){cf=gf;df=jf;ff=kf;break}nc=hf[c[ma>>2]&1023](Ba,Z,9890776,Te)|0;Gb=(nc|0)<(gf|0);cf=Gb?nc:gf;df=Gb?1:jf;ff=Gb?Te:kf}}while(0);tb=aa+1|0;Gb=c[ib>>2]|0;nc=ff;va=df;qc=0;Hb=cf;Ib=0;Jb=1;Kb=Pe;Ub=0;$=0;while(1){_b=d[f+368+Kb|0]|0;Lb=b[Ca+(wa<<7)+(_b<<1)>>1]|0;Pb=Lb<<16>>16;Qb=c[fb>>2]|0;if((Qb|0)<3&(Kb|0)>(tb|0)){lf=nc;nf=va;of=qc;break}Vb=Lb<<16>>16!=0;if(Vb){Nb=ca(Pb,k)|0;pf=Nb+(Lb<<16>>16<0?Fa:Oe)|0;qf=Jb+1|0;rf=c[v+(Jb<<2)>>2]|0}else{pf=0;qf=Jb;rf=Gb-1|0}Nb=Lb<<16>>16>-1?Pb:-Pb|0;Ob=(Kb|0)<(aa|0);kc=Kb+1|0;lc=rf+kc|0;jc=f+368+lc|0;mc=(lc|0)<(aa|0);lc=(rf+Ib<<7)+128|0;$b=rf<<7;bc=Ib<<7;ac=bc|65;hc=la+ac|0;ec=g+ac|0;ac=(Ub|0)==0;gc=($<<7)+Ub|0;fc=g+gc|0;ic=la+gc|0;gc=9890776+(_b<<7)|0;_b=(Lb+62&65535)>>>0<125>>>0;Lb=bc|64;bc=Pb+Lb|0;oc=la+bc|0;cc=g+bc|0;bc=Ha+Kb|0;dc=nc;Zb=va;Fb=qc;wb=Hb;pc=-1;rc=Qb;while(1){Qb=pc+Pb|0;if((rc|0)<2){if((((Qb|0)>-1?Qb:-Qb|0)|0)>(Nb|0)){sf=wb;tf=Fb;uf=Zb;vf=dc}else{xa=641}}else{xa=641}n:do{if((xa|0)==641){xa=0;do{if((Qb|0)==0){if(!Ob){wc=d[ec]|0;if(ac){wf=0;xf=-wc|0;break}wf=0;xf=(d[fc]|0)-wc-(d[ic]|0)|0;break}wc=(b[Ca+(wa<<7)+(d[jc]<<1)>>1]|0)+64|0;Ac=wc>>>0>127>>>0?0:wc;wc=Ac+lc|0;if(mc){wf=0;xf=(d[la+wc|0]|0)-(d[la+(Ac+$b)|0]|0)-(d[hc]|0)|0;break}else{wf=0;xf=(d[g+wc|0]|0)-(d[g+(Ac+$b)|0]|0)-(d[hc]|0)|0;break}}else{Ac=ca(Qb,k)|0;wc=((Qb|0)<0?Fa:Oe)+Ac|0;if((wc+2047|0)>>>0>4094>>>0){sf=wb;tf=Fb;uf=Zb;vf=dc;break n}if(Vb){if(!_b){wf=wc;xf=0;break}Ac=Qb+Lb|0;if(Ob){wf=wc;xf=(d[la+Ac|0]|0)-(d[oc]|0)|0;break}else{wf=wc;xf=(d[g+Ac|0]|0)-(d[cc]|0)|0;break}}do{if(bf){Ac=b[u+(d[bc]<<1)>>1]|0;if(Ac<<16>>16==0){break}if((Ac<<16>>16^Qb|0)>-1){sf=wb;tf=Fb;uf=Zb;vf=dc;break n}}}while(0);if(!Ob){zc=d[ec]|0;if(ac){wf=wc;xf=zc;break}wf=wc;xf=(d[ic]|0)+zc-(d[fc]|0)|0;break}zc=(b[Ca+(wa<<7)+(d[jc]<<1)>>1]|0)+64|0;Ac=zc>>>0>127>>>0?0:zc;zc=d[hc]|0;Bc=Ac+$b|0;if(mc){wf=wc;xf=(d[la+Bc|0]|0)+zc-(d[la+(Ac+lc)|0]|0)|0;break}else{wf=wc;xf=(d[g+Bc|0]|0)+zc-(d[g+(Ac+lc)|0]|0)|0;break}}}while(0);Ac=ca(xf,_)|0;zc=wf-pf|0;Bc=(hf[c[ma>>2]&1023](Ba,Z,gc,zc)|0)+Ac|0;Ac=(Bc|0)<(wb|0);sf=Ac?Bc:wb;tf=Ac?Kb:Fb;uf=Ac?pc:Zb;vf=Ac?zc:dc}}while(0);if((pc|0)>=0){break}dc=vf;Zb=uf;Fb=tf;wb=sf;pc=pc+2|0;rc=c[fb>>2]|0}if(Vb){rc=Pb+64|0;yf=Ib;zf=rc>>>0>127>>>0?0:rc;Af=0}else{yf=$;zf=Ub;Af=Ib+1|0}if((kc|0)<64){Gb=rf;nc=vf;va=uf;qc=tf;Hb=sf;Ib=Af;Jb=qf;Kb=kc;Ub=zf;$=yf}else{lf=vf;nf=uf;of=tf;break}}if((nf|0)==0){break}$=d[f+368+of|0]|0;Ub=Ca+(wa<<7)+($<<1)|0;b[Ub>>1]=(e[Ub>>1]|0)+nf;o:do{if((of|0)>(aa|0)){Bf=of}else{Ub=aa;while(1){if((Ub|0)<(Pe|0)){Bf=Ub;break o}if((b[Ca+(wa<<7)+(d[f+368+Ub|0]<<1)>>1]|0)==0){Ub=Ub-1|0}else{Bf=Ub;break}}}}while(0);if((Pe|0)<=(Bf|0)){Ub=0;kc=0;Pb=Pe;while(1){if((b[Ca+(wa<<7)+(d[f+368+Pb|0]<<1)>>1]|0)==0){Cf=kc;Df=Ub+1|0}else{c[v+(kc<<2)>>2]=Ub;Cf=kc+1|0;Df=0}Vb=Pb+1|0;if((Vb|0)>(Bf|0)){break}else{Ub=Df;kc=Cf;Pb=Vb}}}ef[c[fa>>2]&4095](Ba,9890776+($<<7)|0,lf);aa=Bf}c[ga>>2]=aa}wa=wa+1|0;}while((wa|0)<12)}wa=f+72|0;Ba=c[wa>>2]|0;p:do{if((Ba|0)!=0){if((c[ha>>2]|0)==0){Ef=0;Ff=Ba}else{break}while(1){fa=c[W>>2]|0;fb=fa+(Ef<<7)|0;ma=f+180+(Ef<<2)|0;ib=c[ma>>2]|0;Mb=Ff>>>31;ta=Mb^1;na=(Ff|0)<0?-Ff|0:Ff;q:do{if((ib|0)>(Mb<<31>>31|0)){if((ib|0)<0){Gf=0}else{da=(Mb|0)!=1;Da=0;oa=0;ea=0;while(1){Ia=b[fa+(Ef<<7)+(d[f+368+Da|0]<<1)>>1]|0;Ea=Ia<<16>>16;ua=Ia<<16>>16>-1?Ea:-Ea|0;do{if((ua|0)==1){if(da&(Da|0)==0){Hf=ea;If=oa;break}Hf=(a[1611528+oa|0]|0)+ea|0;If=0}else{if((ua|0)>1){break q}Hf=ea;If=oa+1|0}}while(0);ua=Da+1|0;if((ua|0)>(ib|0)){Gf=Hf;break}else{Da=ua;oa=If;ea=Hf}}}if((Gf|0)>=(na|0)){break}if((ta|0)<=(ib|0)){ea=ta;do{b[fa+(Ef<<7)+(d[f+368+ea|0]<<1)>>1]=0;ea=ea+1|0;}while((ea|0)<=(ib|0))}if((b[fb>>1]|0)==0){c[ma>>2]=-1;break}else{c[ma>>2]=0;break}}}while(0);ma=Ef+1|0;if((ma|0)>=4){break p}Ef=ma;Ff=c[wa>>2]|0}}}while(0);wa=f+76|0;Ba=c[wa>>2]|0;r:do{if((Ba|0)!=0){if((c[ha>>2]|0)==0){Jf=4;Kf=Ba}else{break}while(1){aa=c[W>>2]|0;ga=aa+(Jf<<7)|0;ma=f+180+(Jf<<2)|0;fb=c[ma>>2]|0;ib=Kf>>>31;fa=ib^1;ta=(Kf|0)<0?-Kf|0:Kf;s:do{if((fb|0)>(ib<<31>>31|0)){if((fb|0)<0){Lf=0}else{na=(ib|0)!=1;Mb=0;$=0;ea=0;while(1){oa=b[aa+(Jf<<7)+(d[f+368+Mb|0]<<1)>>1]|0;Da=oa<<16>>16;da=oa<<16>>16>-1?Da:-Da|0;do{if((da|0)==1){if(na&(Mb|0)==0){Mf=ea;Nf=$;break}Mf=(a[1611528+$|0]|0)+ea|0;Nf=0}else{if((da|0)>1){break s}Mf=ea;Nf=$+1|0}}while(0);da=Mb+1|0;if((da|0)>(fb|0)){Lf=Mf;break}else{Mb=da;$=Nf;ea=Mf}}}if((Lf|0)>=(ta|0)){break}if((fa|0)<=(fb|0)){ea=fa;do{b[aa+(Jf<<7)+(d[f+368+ea|0]<<1)>>1]=0;ea=ea+1|0;}while((ea|0)<=(fb|0))}if((b[ga>>1]|0)==0){c[ma>>2]=-1;break}else{c[ma>>2]=0;break}}}while(0);ma=Jf+1|0;if((ma|0)>=12){break r}Jf=ma;Kf=c[wa>>2]|0}}}while(0);do{if((c[f+14404>>2]&8|0)!=0){if((c[f+180>>2]|0)==-1){c[f+13112>>2]=8388607}if((c[f+184>>2]|0)==-1){c[f+13116>>2]=8388607}if((c[f+188>>2]|0)==-1){c[f+13120>>2]=8388607}if((c[f+192>>2]|0)==-1){c[f+13124>>2]=8388607}if((c[f+196>>2]|0)==-1){c[f+13128>>2]=8388607}if((c[f+200>>2]|0)==-1){c[f+13132>>2]=8388607}if((c[f+204>>2]|0)==-1){c[f+13136>>2]=8388607}if((c[f+208>>2]|0)==-1){c[f+13140>>2]=8388607}if((c[f+212>>2]|0)==-1){c[f+13144>>2]=8388607}if((c[f+216>>2]|0)==-1){c[f+13148>>2]=8388607}if((c[f+220>>2]|0)==-1){c[f+13152>>2]=8388607}if(!((c[f+224>>2]|0)==-1)){break}c[f+13156>>2]=8388607}}while(0);do{if((c[f+60>>2]&8192|0)!=0){if((c[ha>>2]|0)==0){break}c[f+200>>2]=0;c[f+196>>2]=0;wa=c[f+172>>2]|0;Ba=((((wa|0)/2|0)+1024|0)/(wa|0)|0)&65535;wa=c[W>>2]|0;b[wa+640>>1]=Ba;b[wa+512>>1]=Ba;if((c[f+14220>>2]|0)!=0){break}c[f+204>>2]=0;b[wa+768>>1]=Ba;c[f+208>>2]=0;b[wa+896>>1]=Ba;c[f+212>>2]=0;b[wa+1024>>1]=Ba;c[f+216>>2]=0;b[wa+1152>>1]=Ba;c[f+220>>2]=0;b[wa+1280>>1]=Ba;c[f+224>>2]=0;b[wa+1408>>1]=Ba}}while(0);do{if((c[f+14200>>2]|0)!=0){if((c[Ga>>2]|0)==4){break}else{Of=0}do{ha=f+180+(Of<<2)|0;if((c[ha>>2]|0)>0){Ba=63;while(1){if((Ba|0)<=0){break}if((b[(c[W>>2]|0)+(Of<<7)+(d[f+368+Ba|0]<<1)>>1]|0)==0){Ba=Ba-1|0}else{break}}c[ha>>2]=Ba}Of=Of+1|0;}while((Of|0)<12)}}while(0);switch(c[f+48>>2]|0){case 1:case 2:{xRa(f,c[W>>2]|0,o,p);break a;break};case 13:{bSa(f,c[W>>2]|0,o,p);break a;break};case 16:case 17:case 18:{SUa(f,c[W>>2]|0,o,p);break a;break};case 19:{Thb(f,c[W>>2]|0,o,p);break a;break};case 4:{Lga(f,c[W>>2]|0,o,p);break a;break};case 5:case 20:case 22:case 6:case 7:{yqb(f,c[W>>2]|0,o,p);break a;break};case 8:case 108:{AQa(f,c[W>>2]|0);break a;break};default:{break a}}}}while(0);p=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-(c[f+788>>2]|0))|0;if((c[Y>>2]|0)==0){Pf=p}else{Pf=p+64-(c[f+13984>>2]|0)-(c[f+13960>>2]|0)+((c[f+13968>>2]|0)-(c[f+13964>>2]|0)+((c[f+13992>>2]|0)-(c[f+13988>>2]|0))<<3)|0}p=f+4|0;if((c[(c[p>>2]|0)+296>>2]|0)==2){KTa(f,c[W>>2]|0);o=ca(c[f+9972>>2]|0,Pf)|0;Of=f+12476|0;Kf=c[Of>>2]|0;Jf=Kf<<4;Lf=c[f+8>>2]|0;Mf=(Jf+16|0)>(Lf|0)?Lf-Jf|0:16;Lf=f+12480|0;Nf=c[Lf>>2]|0;Ff=Nf<<4;Ef=c[f+12>>2]|0;Gf=(Ff+16|0)>(Ef|0)?Ef-Ff|0:16;do{if((Mf|0)==16&(Gf|0)==16){if((c[(c[p>>2]|0)+240>>2]|0)==10){Ef=f;Hf=c[f+148>>2]|0;If=(c[f+5400>>2]|0)+((ca(Hf,Ff)|0)+Jf)|0;Bf=Xe[c[f+10324>>2]&511](Ef,If,c[f+12544>>2]|0,Hf,16)|0;Hf=f+10328|0;If=f+152|0;lf=c[If>>2]|0;Cf=(c[f+5404>>2]|0)+((ca(lf,c[Lf>>2]|0)|0)+(c[Of>>2]|0)<<3)|0;Df=(Xe[c[Hf>>2]&511](Ef,Cf,c[f+12548>>2]|0,lf,8)|0)+Bf|0;Bf=c[If>>2]|0;If=(c[f+5408>>2]|0)+((ca(Bf,c[Lf>>2]|0)|0)+(c[Of>>2]|0)<<3)|0;Qf=Df+(Xe[c[Hf>>2]&511](Ef,If,c[f+12552>>2]|0,Bf,8)|0)|0;break}else{Bf=c[f+148>>2]|0;If=(c[f+5400>>2]|0)+((ca(Bf,Ff)|0)+Jf)|0;Ef=Xe[c[f+10132>>2]&511](0,If,c[f+12544>>2]|0,Bf,16)|0;Bf=f+10136|0;If=f+152|0;Hf=c[If>>2]|0;Df=(c[f+5404>>2]|0)+((ca(Hf,c[Lf>>2]|0)|0)+(c[Of>>2]|0)<<3)|0;lf=(Xe[c[Bf>>2]&511](0,Df,c[f+12548>>2]|0,Hf,8)|0)+Ef|0;Ef=c[If>>2]|0;If=(c[f+5408>>2]|0)+((ca(Ef,c[Lf>>2]|0)|0)+(c[Of>>2]|0)<<3)|0;Qf=lf+(Xe[c[Bf>>2]&511](0,If,c[f+12552>>2]|0,Ef,8)|0)|0;break}}else{Ef=c[f+5400>>2]|0;If=c[f+148>>2]|0;Bf=(ca(If,Ff)|0)+Jf|0;lf=c[f+12544>>2]|0;do{if((Mf|0)==8&(Gf|0)==8){Hf=Xe[c[f+10136>>2]&511](0,Ef+Bf|0,lf,If,8)|0;Rf=Hf;Sf=c[Of>>2]|0;Tf=c[Lf>>2]|0}else{if((Gf|0)<=0){Rf=0;Sf=Kf;Tf=Nf;break}Hf=(Mf|0)>0;Df=0;Cf=0;while(1){if(Hf){v=ca(Cf,If)|0;Pe=Df;of=0;while(1){nf=of+v|0;tf=(c[6219288+((d[Ef+(nf+Bf)|0]|256)-(d[lf+nf|0]|0)<<2)>>2]|0)+Pe|0;nf=of+1|0;if((nf|0)<(Mf|0)){Pe=tf;of=nf}else{Uf=tf;break}}}else{Uf=Df}of=Cf+1|0;if((of|0)<(Gf|0)){Df=Uf;Cf=of}else{Rf=Uf;Sf=Kf;Tf=Nf;break}}}}while(0);lf=c[f+5404>>2]|0;Bf=f+152|0;Ef=c[Bf>>2]|0;If=(ca(Tf<<3,Ef)|0)+(Sf<<3)|0;Cf=lf+If|0;Df=c[f+12548>>2]|0;Hf=Mf>>1;of=Gf>>1;Pe=(Hf|0)==16&(of|0)==16;do{if(Pe){Vf=Xe[c[f+10132>>2]&511](0,Cf,Df,Ef,16)|0}else{if((Hf|0)==8&(of|0)==8){Vf=Xe[c[f+10136>>2]&511](0,Cf,Df,Ef,8)|0;break}if((of|0)<=0){Vf=0;break}v=(Hf|0)>0;Ba=0;ha=0;while(1){if(v){tf=ca(ha,Ef)|0;nf=Ba;uf=0;while(1){vf=uf+tf|0;yf=(c[6219288+((d[lf+(vf+If)|0]|256)-(d[Df+vf|0]|0)<<2)>>2]|0)+nf|0;vf=uf+1|0;if((vf|0)<(Hf|0)){nf=yf;uf=vf}else{Wf=yf;break}}}else{Wf=Ba}uf=ha+1|0;if((uf|0)<(of|0)){Ba=Wf;ha=uf}else{Vf=Wf;break}}}}while(0);Df=Vf+Rf|0;If=c[f+5408>>2]|0;lf=c[Bf>>2]|0;Ef=(ca(c[Lf>>2]<<3,lf)|0)+(c[Of>>2]<<3)|0;Cf=If+Ef|0;ha=c[f+12552>>2]|0;do{if(Pe){Xf=Xe[c[f+10132>>2]&511](0,Cf,ha,lf,16)|0}else{if((Hf|0)==8&(of|0)==8){Xf=Xe[c[f+10136>>2]&511](0,Cf,ha,lf,8)|0;break}if((of|0)<=0){Xf=0;break}Ba=(Hf|0)>0;v=0;uf=0;while(1){if(Ba){nf=ca(uf,lf)|0;tf=v;yf=0;while(1){vf=yf+nf|0;zf=(c[6219288+((d[If+(vf+Ef)|0]|256)-(d[ha+vf|0]|0)<<2)>>2]|0)+tf|0;vf=yf+1|0;if((vf|0)<(Hf|0)){tf=zf;yf=vf}else{Yf=zf;break}}}else{Yf=v}yf=uf+1|0;if((yf|0)<(of|0)){v=Yf;uf=yf}else{Xf=Yf;break}}}}while(0);Qf=Df+Xf|0}}while(0);Zf=(Qf<<7)+o|0}else{Zf=Pf}if((c[n>>2]|0)!=0){Pf=f+12544|0;o=A;c[Pf>>2]=c[o>>2];c[Pf+4>>2]=c[o+4>>2];c[Pf+8>>2]=c[o+8>>2]}if((Zf|0)>=(c[m>>2]|0)){i=q;return}c[m>>2]=Zf;c[n>>2]=c[n>>2]^1;nrc(h+11744|0,f+11744|0,64)|0;nrc(h+11824|0,B|0,32)|0;c[h+12484>>2]=c[C>>2];c[h+9860>>2]=c[D>>2];c[h+9864>>2]=c[E>>2];c[h+9868>>2]=c[F>>2];c[h+13664>>2]=c[H>>2];c[h+13672>>2]=c[I>>2];c[h+13676>>2]=c[J>>2];c[h+13680>>2]=c[K>>2];c[h+13684>>2]=c[L>>2];c[h+13688>>2]=c[M>>2];c[h+13692>>2]=c[N>>2];c[h+13696>>2]=c[O>>2];c[h+12488>>2]=c[f+12488>>2];c[h+9924>>2]=c[P>>2];c[h+11740>>2]=c[f+11740>>2];c[h+11736>>2]=c[f+11736>>2];P=h+784|0;c[P>>2]=c[X>>2];c[P+4>>2]=c[X+4>>2];c[P+8>>2]=c[X+8>>2];c[P+12>>2]=c[X+12>>2];c[P+16>>2]=c[X+16>>2];c[P+20>>2]=c[X+20>>2];if((c[Y>>2]|0)!=0){Y=h+13980|0;X=f+13980|0;c[Y>>2]=c[X>>2];c[Y+4>>2]=c[X+4>>2];c[Y+8>>2]=c[X+8>>2];c[Y+12>>2]=c[X+12>>2];c[Y+16>>2]=c[X+16>>2];c[Y+20>>2]=c[X+20>>2];X=h+13956|0;Y=f+13956|0;c[X>>2]=c[Y>>2];c[X+4>>2]=c[Y+4>>2];c[X+8>>2]=c[Y+8>>2];c[X+12>>2]=c[Y+12>>2];c[X+16>>2]=c[Y+16>>2];c[X+20>>2]=c[Y+20>>2]}c[h+14340>>2]=c[W>>2];c[h+180>>2]=c[f+180>>2];c[h+184>>2]=c[f+184>>2];c[h+188>>2]=c[f+188>>2];c[h+192>>2]=c[f+192>>2];c[h+196>>2]=c[f+196>>2];c[h+200>>2]=c[f+200>>2];c[h+204>>2]=c[f+204>>2];c[h+208>>2]=c[f+208>>2];c[h+14236>>2]=c[f+14236>>2];c[h+9960>>2]=c[R>>2];c[h+14100>>2]=c[V>>2];i=q;return}function lUa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;g=0;do{h=g-1|0;i=(h|0)>0?h:0;h=g+2|0;j=(h|0)<8?h:8;h=(i|0)<(j|0);k=g<<3;l=0;m=-3;n=-1;while(1){o=(m|0)>-9;p=(n|0)>0?n:0;do{if(h){q=l-1|0;r=(q|0)>0?q:0;q=l+2|0;s=(q|0)<8?q:8;if((r|0)>=(s|0)){t=0;u=0;v=0;break}q=(o?~m:8)-p|0;w=i;x=0;y=0;z=0;while(1){A=ca(w,f)|0;B=r;C=x;D=y;do{E=d[e+(B+A)|0]|0;C=E+C|0;D=(ca(E,E)|0)+D|0;B=B+1|0;}while((B|0)<(s|0));B=q+z|0;A=w+1|0;if((A|0)<(j|0)){w=A;x=C;y=D;z=B}else{t=C;u=D;v=B;break}}}else{t=0;u=0;v=0}}while(0);p=(ca(v,u)|0)-(ca(t,t)|0)|0;if(p>>>0<255>>>0){F=(d[p+1303321|0]|0)-1>>4}else{do{if(p>>>0<4096>>>0){H=(d[1303320+(p>>>4)|0]|0)>>>2}else{if(p>>>0<16384>>>0){H=(d[1303320+(p>>>6)|0]|0)>>>1;break}if(p>>>0<65536>>>0){H=d[1303320+(p>>>8)|0]|0;break}else{o=p>>>16;z=(o&65280|0)==0;y=((d[1359664+(z?o:p>>>24)|0]|0)+(z?0:8)|0)>>>1;z=p>>>((y+2|0)>>>0);o=d[1303320+(z>>>((y+8|0)>>>0))|0]|0;Erc(z,0,c[1367848+(o<<2)>>2]|0,0)|0;H=G+(o<<y)|0;break}}}while(0);F=H-((ca(H,H)|0)>>>0>p>>>0)|0}b[a+(l+k<<1)>>1]=((F*36|0)>>>0)/(v>>>0)|0;y=l+1|0;if((y|0)<8){l=y;m=m-1|0;n=n+1|0}else{break}}g=g+1|0;}while((g|0)<8);return}function mUa(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0;n=i;i=i+112|0;o=n|0;p=n+24|0;q=n+88|0;r=(c[e+28>>2]|0)==0;s=e+12480|0;t=c[s>>2]|0;u=e+13924|0;v=(c[u>>2]|0)!=0?2:1;w=e+11744+(j<<5)|0;x=e+12476|0;y=c[x>>2]|0;z=(y<<4|8)+(c[w>>2]>>v)|0;A=e+11744+(j<<5)+4|0;B=(c[A>>2]>>v)+(t<<4)|0;v=e+148|0;C=c[v>>2]|0;D=z+64+(ca(B+(y<<2&12)|0,C)|0)|0;y=e+11544|0;ef[c[y>>2]&4095]((c[k>>2]|0)+D|0,C,4);C=e+152|0;D=(z>>1)+64+(ca((c[x>>2]&7)+(B>>1)|0,c[C>>2]|0)|0)|0;B=k+4|0;z=c[B>>2]|0;E=k+8|0;ef[c[y>>2]&4095](z+D|0,(c[E>>2]|0)-z|0,2);if(r){r=c[e+11740>>2]|0;if((r|0)==4){z=e+14172|0;if((c[z>>2]|0)==3){D=e+11396|0;pUa(e,f,g,h,0,0,k,l,c[w>>2]|0,c[A>>2]|0,t);pUa(e,f,g,h,1,1,k,l,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,t);pUa(e,f,g,h,0,1,k,D,c[e+11744+(j<<5)+16>>2]|0,c[e+11744+(j<<5)+20>>2]|0,t);pUa(e,f,g,h,1,0,k,D,c[e+11744+(j<<5)+24>>2]|0,c[e+11744+(j<<5)+28>>2]|0,t);i=n;return}D=e+9856|0;if((c[k>>2]|0)==0){F=c[D>>2]|0}else{F=k}y=t>>1;G=e+11396|0;H=e+14240|0;I=0;J=l;K=F;a:while(1){F=I;L=J;while(1){if((F|0)>=2){break a}M=F+1|0;N=F<<1;oUa(e,f,g,h,(c[z>>2]|0)!=(M|0)|0,K,L,c[e+11744+(j<<5)+(N<<3)>>2]|0,c[e+11744+(j<<5)+(N<<3)+4>>2]|0,16,y);if((c[H>>2]|0)==0){break}else{F=M;L=G}}I=M;J=G;K=c[D>>2]|0}i=n;return}else if((r|0)==3){D=c[e+14172>>2]|0;K=c[e+11808+(j<<3)>>2]|0;if((D|0)==3){pUa(e,f,g,h,0,K,k,l,c[w>>2]|0,c[A>>2]|0,t);pUa(e,f,g,h,1,c[e+11808+(j<<3)+4>>2]|0,k,l,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,t);i=n;return}do{if((D|0)==(K+1|0)){O=35}else{if((c[e+9992>>2]|0)==3){O=35;break}if((c[e+14240>>2]|0)==0){O=36}else{O=35}}}while(0);if((O|0)==35){if((c[k>>2]|0)==0){O=36}else{P=k}}if((O|0)==36){P=c[e+9856>>2]|0}oUa(e,f,g,h,K,P,l,c[w>>2]|0,c[A>>2]|0,16,t>>1);i=n;return}else if((r|0)==2){P=e+14172|0;K=e+9856|0;D=t>>1;G=e+14220|0;J=e+9992|0;M=e+14240|0;I=c[e+11808+(j<<3)>>2]|0;do{if((c[P>>2]|0)==(I+1|0)){O=40}else{if((c[J>>2]|0)==3){O=40;break}if((c[M>>2]|0)==0){O=41}else{O=40}}}while(0);if((O|0)==40){if((c[k>>2]|0)==0){O=41}else{Q=k}}if((O|0)==41){Q=c[K>>2]|0}oUa(e,f,g,h,I,Q,l,c[w>>2]|0,c[A>>2]|0,8,D);Q=f+(c[v>>2]<<4)|0;I=ca(16>>>((c[G>>2]|0)>>>0),c[C>>2]|0)|0;G=g+I|0;H=h+I|0;I=c[e+11808+(j<<3)+4>>2]|0;do{if((c[P>>2]|0)==(I+1|0)){O=54}else{if((c[J>>2]|0)==3){O=54;break}if((c[M>>2]|0)==0){O=55}else{O=54}}}while(0);if((O|0)==54){if((c[k>>2]|0)==0){O=55}else{R=k}}if((O|0)==55){R=c[K>>2]|0}oUa(e,Q,G,H,I,R,l,c[e+11744+(j<<5)+8>>2]|0,(c[e+11744+(j<<5)+12>>2]|0)+16|0,8,D);i=n;return}else if((r|0)==0){if((c[e+13916>>2]|0)==0){oUa(e,f,g,h,0,k,l,c[w>>2]|0,c[A>>2]|0,16,t);i=n;return}if((c[e+13880>>2]|0)!=1){r=c[e+13932>>2]|0;D=c[v>>2]|0;R=c[C>>2]|0;I=c[k>>2]|0;H=e+13900|0;G=c[H>>2]|0;Q=c[x>>2]|0;K=ca(Q,G)|0;M=e+13904|0;J=c[M>>2]|0;P=c[s>>2]|0;y=((ca(P,J)|0)+K<<4)+(c[e+13884>>2]|0)|0;K=e+13908|0;z=c[K>>2]|0;L=ca(z,Q)|0;Q=e+13912|0;F=c[Q>>2]|0;N=((ca(F,P)|0)+L<<4)+(c[e+13888>>2]|0)|0;L=e+10088|0;P=r+1|0;S=1<<(r<<1|1);r=e+12472|0;T=e+136|0;U=e+140|0;Pe[c[L>>2]&3](f,I,D,16,y,N,G,J,z,F,P,S-(c[r>>2]|0)|0,c[T>>2]|0,c[U>>2]|0);F=c[H>>2]|0;z=c[K>>2]|0;Pe[c[L>>2]&3](f+8|0,I,D,16,(F<<3)+y|0,(z<<3)+N|0,F,c[M>>2]|0,z,c[Q>>2]|0,P,S-(c[r>>2]|0)|0,c[T>>2]|0,c[U>>2]|0);z=c[H>>2]|0;F=c[x>>2]|0;N=ca(F,z)|0;y=c[M>>2]|0;D=c[s>>2]|0;I=((ca(D,y)|0)+N<<3)+(c[e+13892>>2]|0)|0;N=c[K>>2]|0;J=ca(N,F)|0;F=c[Q>>2]|0;G=((ca(F,D)|0)+J<<3)+(c[e+13896>>2]|0)|0;Pe[c[L>>2]&3](g,c[B>>2]|0,R,8,I,G,z,y,N,F,P,S-(c[r>>2]|0)|0,c[T>>2]>>1,c[U>>2]>>1);Pe[c[L>>2]&3](h,c[E>>2]|0,R,8,I,G,c[H>>2]|0,c[M>>2]|0,c[K>>2]|0,c[Q>>2]|0,P,S-(c[r>>2]|0)|0,c[T>>2]>>1,c[U>>2]>>1);i=n;return}U=c[e+13884>>2]|0;T=c[e+13888>>2]|0;r=e+13932|0;S=c[r>>2]|0;P=S+1|0;Q=(U>>P)+(c[x>>2]<<4)|0;K=(c[s>>2]<<4)+(T>>P)|0;P=3-S|0;S=e+8|0;M=c[S>>2]|0;if((Q|0)<-16){V=-16}else{V=(Q|0)>(M|0)?M:Q}Q=(V|0)==(M|0)?0:U<<P;U=e+12|0;M=c[U>>2]|0;if((K|0)<-16){W=-16}else{W=(K|0)>(M|0)?M:K}K=(W|0)==(M|0)?0:T<<P;P=c[v>>2]|0;T=c[C>>2]|0;M=(c[k>>2]|0)+((ca(P,W)|0)+V)|0;H=e+136|0;G=c[H>>2]|0;I=G-17|0;R=e+140|0;L=c[R>>2]|0;if(V>>>0<((I|0)>0?I:0)>>>0){I=L-17|0;if(W>>>0<((I|0)>0?I:0)>>>0){X=M}else{O=12}}else{O=12}if((O|0)==12){I=e+9944|0;Ve[c[e+11540>>2]&127](c[I>>2]|0,M,P,P,17,17,V,W,G,L);X=c[I>>2]|0}do{if(((K|Q)&7|0)==0){I=K>>>2&2|Q>>>3&1;if((c[e+12472>>2]|0)==0){mf[c[e+11332+(I<<2)>>2]&2047](f,X,P,16);break}else{mf[c[e+11460+(I<<2)>>2]&2047](f,X,P,16);break}}else{I=e+10084|0;L=Q&15;G=K&15;W=e+12472|0;Se[c[I>>2]&1023](f,X,P,16,L,G,128-(c[W>>2]|0)|0);Se[c[I>>2]&1023](f+8|0,X+8|0,P,16,L,G,128-(c[W>>2]|0)|0)}}while(0);P=c[e+13892>>2]|0;X=c[e+13896>>2]|0;K=c[r>>2]|0;r=K+1|0;Q=(P>>r)+(c[x>>2]<<3)|0;W=(c[s>>2]<<3)+(X>>r)|0;r=3-K|0;K=P<<r;P=X<<r;r=c[S>>2]>>1;if((Q|0)<-8){Y=-8}else{Y=(Q|0)>(r|0)?r:Q}Q=(Y|0)==(r|0);r=c[U>>2]>>1;if((W|0)<-8){Z=-8}else{Z=(W|0)>(r|0)?r:W}W=(Z|0)==(r|0);r=(ca(Z,T)|0)+Y|0;U=(c[B>>2]|0)+r|0;S=c[H>>2]>>1;X=S-9|0;G=c[R>>2]>>1;if(Y>>>0<((X|0)>0?X:0)>>>0){X=G-9|0;if(Z>>>0<((X|0)>0?X:0)>>>0){_=U;$=0}else{O=24}}else{O=24}if((O|0)==24){X=e+9944|0;Ve[c[e+11540>>2]&127](c[X>>2]|0,U,T,T,9,9,Y,Z,S,G);_=c[X>>2]|0;$=1}X=e+10084|0;G=Q?0:K&15;K=W?0:P&15;P=e+12472|0;Se[c[X>>2]&1023](g,_,T,8,G,K,128-(c[P>>2]|0)|0);_=(c[E>>2]|0)+r|0;if($){$=e+9944|0;Ve[c[e+11540>>2]&127](c[$>>2]|0,_,T,T,9,9,Y,Z,c[H>>2]>>1,c[R>>2]>>1);aa=c[$>>2]|0}else{aa=_}Se[c[X>>2]&1023](h,aa,T,8,G,K,128-(c[P>>2]|0)|0);i=n;return}else{i=n;return}}do{if((c[e+13788>>2]|0)!=0){if((c[e+9992>>2]|0)==3){break}P=c[x>>2]|0;K=c[s>>2]|0;G=c[e+124>>2]|0;T=(ca(G,K)|0)+P|0;aa=c[e+128>>2]|0;X=(ca(K<<1,aa)|0)+(P<<1)|0;_=c[e+9148>>2]|0;$=c[_+(X<<2)>>2]|0;R=p+16|0;c[p+20>>2]=$;H=c[_+((X|1)<<2)>>2]|0;c[p+24>>2]=H;Z=X+aa|0;Y=_+(Z<<2)|0;r=c[Y>>2]|0;W=p+32|0;c[p+36>>2]=r;Q=_+(Z+1<<2)|0;Z=c[Q>>2]|0;c[p+40>>2]=Z;c[p+52>>2]=c[Y>>2];c[p+56>>2]=c[Q>>2];do{if((K|0)==0){O=61}else{if((c[(c[e+9160>>2]|0)+(T-G<<2)>>2]&7|0)!=0){O=61;break}Q=X-aa|0;c[p+4>>2]=c[_+(Q<<2)>>2];c[p+8>>2]=c[_+(Q+1<<2)>>2]}}while(0);if((O|0)==61){c[p+4>>2]=$;c[p+8>>2]=H}do{if((P|0)==0){O=65}else{if((c[(c[e+9160>>2]|0)+(T-1<<2)>>2]&7|0)!=0){O=65;break}G=X-1|0;c[R>>2]=c[_+(G<<2)>>2];c[W>>2]=c[_+(G+aa<<2)>>2]}}while(0);if((O|0)==65){c[R>>2]=$;c[W>>2]=r}do{if((P+1|0)<(c[e+116>>2]|0)){if((c[(c[e+9160>>2]|0)+(T+1<<2)>>2]&7|0)!=0){O=69;break}G=X+2|0;c[p+28>>2]=c[_+(G<<2)>>2];c[p+44>>2]=c[_+(G+aa<<2)>>2]}else{O=69}}while(0);if((O|0)==69){c[p+28>>2]=H;c[p+44>>2]=Z}aa=q|0;_=q+2|0;X=q+4|0;T=q+6|0;r=q+8|0;W=q+10|0;$=q+12|0;R=q+14|0;G=q+16|0;Q=q+18|0;Y=P<<4;S=K<<4;U=e+9952|0;L=e+8|0;I=e+12|0;V=e+136|0;M=e+140|0;F=e+11540|0;N=e+9944|0;y=o|0;z=o+4|0;J=o+8|0;D=o+12|0;ba=o+16|0;da=0;ea=0;fa=0;do{ga=da&1;ha=ga+1|0;ia=da>>1;ja=ia+1|0;ka=b[p+(ja<<4)+(ha<<2)>>1]|0;b[aa>>1]=ka;la=b[p+(ja<<4)+(ha<<2)+2>>1]|0;b[_>>1]=la;b[X>>1]=b[p+(ia<<4)+(ha<<2)>>1]|0;b[T>>1]=b[p+(ia<<4)+(ha<<2)+2>>1]|0;b[r>>1]=b[p+(ja<<4)+(ga<<2)>>1]|0;b[W>>1]=b[p+(ja<<4)+(ga<<2)+2>>1]|0;ma=ga|2;b[$>>1]=b[p+(ja<<4)+(ma<<2)>>1]|0;b[R>>1]=b[p+(ja<<4)+(ma<<2)+2>>1]|0;ma=ia+2|0;b[G>>1]=b[p+(ma<<4)+(ha<<2)>>1]|0;b[Q>>1]=b[p+(ma<<4)+(ha<<2)+2>>1]|0;ha=ga<<3;ga=ia<<3;ia=c[v>>2]|0;ma=c[k>>2]|0;ja=ha|Y;na=ga+S|0;oa=0;do{do{if((oa|0)==0){pa=ka;O=77}else{qa=b[q+(oa<<2)>>1]|0;if(!(qa<<16>>16==ka<<16>>16)){pa=qa;O=77;break}if(!((b[q+(oa<<2)+2>>1]|0)==la<<16>>16)){pa=ka;O=77;break}c[o+(oa<<2)>>2]=c[y>>2]}}while(0);if((O|0)==77){O=0;qa=c[v>>2]|0;ra=(c[U>>2]|0)+((ca(oa>>>1<<3,qa)|0)+(oa<<3&8))|0;c[o+(oa<<2)>>2]=ra;sa=pa<<16>>16;ta=b[q+(oa<<2)+2>>1]|0;ua=(sa>>1)+ja|0;va=na+(ta>>1)|0;wa=c[L>>2]|0;if((ua|0)<-16){xa=-16}else{xa=(ua|0)>(wa|0)?wa:ua}ua=sa&1;sa=(xa|0)==(wa|0)?0:ua;wa=c[I>>2]|0;if((va|0)<-16){ya=-16}else{ya=(va|0)>(wa|0)?wa:va}if((ya|0)==(wa|0)){za=sa}else{za=sa|ta<<1&2}sa=ma+((ca(ya,qa)|0)+xa)|0;wa=c[V>>2]|0;va=wa-ua-8|0;ua=c[M>>2]|0;if(xa>>>0>((va|0)>0?va:0)>>>0){O=85}else{va=ua-(ta&1)-8|0;if(ya>>>0>((va|0)>0?va:0)>>>0){O=85}else{Aa=sa;Ba=qa}}if((O|0)==85){O=0;Ve[c[F>>2]&127](c[N>>2]|0,sa,qa,qa,9,9,xa,ya,wa,ua);Aa=c[N>>2]|0;Ba=c[v>>2]|0}mf[c[l+16+(za<<2)>>2]&2047](ra,Aa,Ba,8)}oa=oa+1|0;}while((oa|0)<5);oa=(ca(ia,ga)|0)+ha|0;ma=c[v>>2]|0;na=c[z>>2]|0;ja=c[J>>2]|0;ka=c[y>>2]|0;la=c[D>>2]|0;ra=c[ba>>2]|0;a[f+oa|0]=((d[ka]<<2)+4+((d[ja]|0)+(d[na]|0)<<1)|0)>>>3;a[f+(oa|1)|0]=((d[ja+1|0]|0)+4+(d[na+1|0]<<1)+((d[ka+1|0]|0)*5|0)|0)>>>3;a[f+(oa|2)|0]=((d[ja+2|0]|0)+4+(d[na+2|0]<<1)+((d[ka+2|0]|0)*5|0)|0)>>>3;a[f+(oa|3)|0]=((d[ja+3|0]|0)+4+(d[na+3|0]<<1)+((d[ka+3|0]|0)*5|0)|0)>>>3;ua=ma+2|0;a[f+(ua+oa)|0]=((d[ja+ua|0]|0)+4+(d[na+ua|0]<<1)+((d[ka+ua|0]|0)*5|0)|0)>>>3;ua=ma+3|0;a[f+(ua+oa)|0]=((d[ja+ua|0]|0)+4+(d[na+ua|0]<<1)+((d[ka+ua|0]|0)*5|0)|0)>>>3;a[f+(oa|4)|0]=((d[na+4|0]<<1)+4+((d[ka+4|0]|0)*5|0)+(d[la+4|0]|0)|0)>>>3;a[f+(oa|5)|0]=((d[na+5|0]<<1)+4+((d[ka+5|0]|0)*5|0)+(d[la+5|0]|0)|0)>>>3;ua=ma+4|0;a[f+(ua+oa)|0]=((d[na+ua|0]<<1)+4+((d[ka+ua|0]|0)*5|0)+(d[la+ua|0]|0)|0)>>>3;ua=ma+5|0;a[f+(ua+oa)|0]=((d[na+ua|0]<<1)+4+((d[ka+ua|0]|0)*5|0)+(d[la+ua|0]|0)|0)>>>3;a[f+(oa|6)|0]=((d[na+6|0]<<1)+4+((d[ka+6|0]|0)*5|0)+(d[la+6|0]|0)|0)>>>3;a[f+(oa|7)|0]=((d[ka+7|0]<<2)+4+((d[la+7|0]|0)+(d[na+7|0]|0)<<1)|0)>>>3;a[f+(ma+oa)|0]=((d[na+ma|0]|0)+4+(d[ja+ma|0]<<1)+((d[ka+ma|0]|0)*5|0)|0)>>>3;ua=ma+1|0;a[f+(ua+oa)|0]=((d[na+ua|0]|0)+4+(d[ja+ua|0]<<1)+((d[ka+ua|0]|0)*5|0)|0)>>>3;ua=ma+6|0;a[f+(ua+oa)|0]=((d[na+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[la+ua|0]<<1)|0)>>>3;ua=ma+7|0;a[f+(ua+oa)|0]=((d[na+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[la+ua|0]<<1)|0)>>>3;ua=ma<<1;a[f+(ua+oa)|0]=((d[na+ua|0]|0)+4+(d[ja+ua|0]<<1)+((d[ka+ua|0]|0)*5|0)|0)>>>3;wa=ua|1;a[f+(wa+oa)|0]=((d[na+wa|0]|0)+4+(d[ja+wa|0]<<1)+((d[ka+wa|0]|0)*5|0)|0)>>>3;qa=ua+ma|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+(d[ja+qa|0]<<1)+((d[ka+qa|0]|0)*5|0)|0)>>>3;qa=wa+ma|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+(d[ja+qa|0]<<1)+((d[ka+qa|0]|0)*5|0)|0)>>>3;qa=ua+2|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+(d[ja+qa|0]|0)+((d[ka+qa|0]|0)*6|0)|0)>>>3;wa=ua+3|0;a[f+(wa+oa)|0]=((d[na+wa|0]|0)+4+(d[ja+wa|0]|0)+((d[ka+wa|0]|0)*6|0)|0)>>>3;sa=qa+ma|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+(d[ja+sa|0]|0)+((d[ka+sa|0]|0)*6|0)|0)>>>3;sa=wa+ma|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+(d[ja+sa|0]|0)+((d[ka+sa|0]|0)*6|0)|0)>>>3;sa=ua+4|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+((d[ka+sa|0]|0)*6|0)+(d[la+sa|0]|0)|0)>>>3;wa=ua+5|0;a[f+(wa+oa)|0]=((d[na+wa|0]|0)+4+((d[ka+wa|0]|0)*6|0)+(d[la+wa|0]|0)|0)>>>3;qa=sa+ma|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[la+qa|0]|0)|0)>>>3;qa=wa+ma|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[la+qa|0]|0)|0)>>>3;qa=ua+6|0;a[f+(qa+oa)|0]=((d[na+qa|0]|0)+4+((d[ka+qa|0]|0)*5|0)+(d[la+qa|0]<<1)|0)>>>3;wa=ua+7|0;a[f+(wa+oa)|0]=((d[na+wa|0]|0)+4+((d[ka+wa|0]|0)*5|0)+(d[la+wa|0]<<1)|0)>>>3;sa=qa+ma|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+((d[ka+sa|0]|0)*5|0)+(d[la+sa|0]<<1)|0)>>>3;sa=wa+ma|0;a[f+(sa+oa)|0]=((d[na+sa|0]|0)+4+((d[ka+sa|0]|0)*5|0)+(d[la+sa|0]<<1)|0)>>>3;sa=ma<<2;a[f+(sa+oa)|0]=((d[ja+sa|0]<<1)+4+((d[ka+sa|0]|0)*5|0)+(d[ra+sa|0]|0)|0)>>>3;na=sa|1;a[f+(na+oa)|0]=((d[ja+na|0]<<1)+4+((d[ka+na|0]|0)*5|0)+(d[ra+na|0]|0)|0)>>>3;wa=sa+ma|0;a[f+(wa+oa)|0]=((d[ja+wa|0]<<1)+4+((d[ka+wa|0]|0)*5|0)+(d[ra+wa|0]|0)|0)>>>3;wa=na+ma|0;a[f+(wa+oa)|0]=((d[ja+wa|0]<<1)+4+((d[ka+wa|0]|0)*5|0)+(d[ra+wa|0]|0)|0)>>>3;wa=sa|2;a[f+(wa+oa)|0]=((d[ja+wa|0]|0)+4+((d[ka+wa|0]|0)*6|0)+(d[ra+wa|0]|0)|0)>>>3;na=sa|3;a[f+(na+oa)|0]=((d[ja+na|0]|0)+4+((d[ka+na|0]|0)*6|0)+(d[ra+na|0]|0)|0)>>>3;qa=wa+ma|0;a[f+(qa+oa)|0]=((d[ja+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[ra+qa|0]|0)|0)>>>3;qa=na+ma|0;a[f+(qa+oa)|0]=((d[ja+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[ra+qa|0]|0)|0)>>>3;qa=sa+4|0;a[f+(qa+oa)|0]=((d[la+qa|0]|0)+4+((d[ka+qa|0]|0)*6|0)+(d[ra+qa|0]|0)|0)>>>3;na=sa+5|0;a[f+(na+oa)|0]=((d[la+na|0]|0)+4+((d[ka+na|0]|0)*6|0)+(d[ra+na|0]|0)|0)>>>3;wa=qa+ma|0;a[f+(wa+oa)|0]=((d[la+wa|0]|0)+4+((d[ka+wa|0]|0)*6|0)+(d[ra+wa|0]|0)|0)>>>3;wa=na+ma|0;a[f+(wa+oa)|0]=((d[la+wa|0]|0)+4+((d[ka+wa|0]|0)*6|0)+(d[ra+wa|0]|0)|0)>>>3;wa=sa+6|0;a[f+(wa+oa)|0]=(((d[ka+wa|0]|0)*5|0)+4+(d[la+wa|0]<<1)+(d[ra+wa|0]|0)|0)>>>3;na=sa+7|0;a[f+(na+oa)|0]=(((d[ka+na|0]|0)*5|0)+4+(d[la+na|0]<<1)+(d[ra+na|0]|0)|0)>>>3;qa=wa+ma|0;a[f+(qa+oa)|0]=(((d[ka+qa|0]|0)*5|0)+4+(d[la+qa|0]<<1)+(d[ra+qa|0]|0)|0)>>>3;qa=na+ma|0;a[f+(qa+oa)|0]=(((d[ka+qa|0]|0)*5|0)+4+(d[la+qa|0]<<1)+(d[ra+qa|0]|0)|0)>>>3;qa=sa+ua|0;a[f+(qa+oa)|0]=((d[ja+qa|0]<<1)+4+((d[ka+qa|0]|0)*5|0)+(d[ra+qa|0]|0)|0)>>>3;ua=qa|1;a[f+(ua+oa)|0]=((d[ja+ua|0]<<1)+4+((d[ka+ua|0]|0)*5|0)+(d[ra+ua|0]|0)|0)>>>3;ua=qa+2|0;a[f+(ua+oa)|0]=((d[ja+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[ra+ua|0]<<1)|0)>>>3;sa=qa+3|0;a[f+(sa+oa)|0]=((d[ja+sa|0]|0)+4+((d[ka+sa|0]|0)*5|0)+(d[ra+sa|0]<<1)|0)>>>3;na=ua+ma|0;a[f+(na+oa)|0]=((d[ja+na|0]|0)+4+((d[ka+na|0]|0)*5|0)+(d[ra+na|0]<<1)|0)>>>3;na=sa+ma|0;a[f+(na+oa)|0]=((d[ja+na|0]|0)+4+((d[ka+na|0]|0)*5|0)+(d[ra+na|0]<<1)|0)>>>3;na=qa+4|0;a[f+(na+oa)|0]=((d[la+na|0]|0)+4+((d[ka+na|0]|0)*5|0)+(d[ra+na|0]<<1)|0)>>>3;sa=qa+5|0;a[f+(sa+oa)|0]=((d[la+sa|0]|0)+4+((d[ka+sa|0]|0)*5|0)+(d[ra+sa|0]<<1)|0)>>>3;ua=na+ma|0;a[f+(ua+oa)|0]=((d[la+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[ra+ua|0]<<1)|0)>>>3;ua=sa+ma|0;a[f+(ua+oa)|0]=((d[la+ua|0]|0)+4+((d[ka+ua|0]|0)*5|0)+(d[ra+ua|0]<<1)|0)>>>3;ua=qa+6|0;a[f+(ua+oa)|0]=(((d[ka+ua|0]|0)*5|0)+4+(d[la+ua|0]<<1)+(d[ra+ua|0]|0)|0)>>>3;ua=qa+7|0;a[f+(ua+oa)|0]=(((d[ka+ua|0]|0)*5|0)+4+(d[la+ua|0]<<1)+(d[ra+ua|0]|0)|0)>>>3;ua=qa+ma|0;a[f+(ua+oa)|0]=((d[ka+ua|0]<<2)+4+((d[ra+ua|0]|0)+(d[ja+ua|0]|0)<<1)|0)>>>3;ma=ua+1|0;a[f+(ma+oa)|0]=((d[ja+ma|0]|0)+4+((d[ka+ma|0]|0)*5|0)+(d[ra+ma|0]<<1)|0)>>>3;ma=ua+6|0;a[f+(ma+oa)|0]=((d[la+ma|0]|0)+4+((d[ka+ma|0]|0)*5|0)+(d[ra+ma|0]<<1)|0)>>>3;ma=ua+7|0;a[f+(ma+oa)|0]=((d[ka+ma|0]<<2)+4+((d[ra+ma|0]|0)+(d[la+ma|0]|0)<<1)|0)>>>3;fa=(b[aa>>1]|0)+fa|0;ea=(b[_>>1]|0)+ea|0;da=da+1|0;}while((da|0)<4);qUa(e,g,h,k,l+16|0,fa,ea);i=n;return}}while(0);switch(c[e+11740>>2]|0){case 1:{Ba=c[x>>2]<<4;Aa=c[s>>2]<<4;za=e+8|0;ya=e+12|0;xa=e+136|0;if((c[u>>2]|0)==0){q=e+140|0;pa=e+11540|0;o=e+9944|0;p=0;da=0;_=0;while(1){aa=p<<3&8;ba=p>>1<<3;D=c[v>>2]|0;y=f+((ca(ba,D)|0)+aa)|0;J=e+11744+(j<<5)+(p<<3)|0;z=c[J>>2]|0;N=e+11744+(j<<5)+(p<<3)+4|0;F=c[N>>2]|0;M=(z>>1)+(aa|Ba)|0;aa=ba+Aa+(F>>1)|0;ba=c[za>>2]|0;if((M|0)<-16){Ca=-16}else{Ca=(M|0)>(ba|0)?ba:M}M=z&1;z=(Ca|0)==(ba|0)?0:M;ba=c[ya>>2]|0;if((aa|0)<-16){Da=-16}else{Da=(aa|0)>(ba|0)?ba:aa}if((Da|0)==(ba|0)){Ea=z}else{Ea=z|F<<1&2}z=(c[k>>2]|0)+((ca(Da,D)|0)+Ca)|0;ba=c[xa>>2]|0;aa=ba-M-8|0;M=c[q>>2]|0;if(Ca>>>0>((aa|0)>0?aa:0)>>>0){O=142}else{aa=M-(F&1)-8|0;if(Da>>>0>((aa|0)>0?aa:0)>>>0){O=142}else{Fa=z;Ga=D}}if((O|0)==142){O=0;Ve[c[pa>>2]&127](c[o>>2]|0,z,D,D,9,9,Ca,Da,ba,M);Fa=c[o>>2]|0;Ga=c[v>>2]|0}mf[c[l+16+(Ea<<2)>>2]&2047](y,Fa,Ga,8);y=(c[J>>2]|0)+_|0;J=(c[N>>2]|0)+da|0;N=p+1|0;if((N|0)<4){p=N;da=J;_=y}else{Ha=y;Ia=J;break}}}else{_=e+11540|0;da=e+9944|0;p=e+140|0;Ga=0;Fa=0;Ea=0;while(1){o=e+11744+(j<<5)+(Ga<<3)|0;Da=c[o>>2]|0;Ca=e+11744+(j<<5)+(Ga<<3)+4|0;pa=c[Ca>>2]|0;q=pa&3;J=Da&3;y=Ga<<3&8;N=(y|Ba)+(Da>>2)|0;Da=Ga>>1<<3;M=Da+Aa+(pa>>2)|0;pa=c[za>>2]|0;if((N|0)<-16){Ja=-16}else{Ja=(N|0)>(pa|0)?pa:N}N=c[ya>>2]|0;if((M|0)<-16){Ka=-16}else{Ka=(M|0)>(N|0)?N:M}M=((Ka|0)==(N|0)?0:q<<2)|((Ja|0)==(pa|0)?0:J);pa=c[v>>2]|0;N=(c[k>>2]|0)+((ca(pa,Ka)|0)+Ja)|0;ba=c[xa>>2]|0;D=ba-J-8|0;J=c[p>>2]|0;if(Ja>>>0>((D|0)>0?D:0)>>>0){O=132}else{D=J-q-8|0;if(Ka>>>0>((D|0)>0?D:0)>>>0){O=132}else{La=N;Ma=pa}}if((O|0)==132){O=0;Ve[c[_>>2]&127](c[da>>2]|0,N,pa,pa,9,9,Ja,Ka,ba,J);La=c[da>>2]|0;Ma=c[v>>2]|0}J=f+((ca(Ma,Da)|0)+y)|0;ef[c[m+64+(M<<2)>>2]&4095](J,La,Ma);J=((c[o>>2]|0)/2|0)+Ea|0;o=((c[Ca>>2]|0)/2|0)+Fa|0;Ca=Ga+1|0;if((Ca|0)<4){Ga=Ca;Fa=o;Ea=J}else{Ha=J;Ia=o;break}}}qUa(e,g,h,k,l+16|0,Ha,Ia);i=n;return};case 0:{if((c[e+13916>>2]|0)==0){if((c[u>>2]|0)!=0){nUa(e,f,g,h,0,0,0,k,l,m,c[w>>2]|0,c[A>>2]|0,16);i=n;return}do{if((c[e+14116>>2]|0)!=0){if((c[e+48>>2]|0)!=19){break}Hhb(e,f,g,h,k,l,c[w>>2]|0,c[A>>2]|0,16);i=n;return}}while(0);oUa(e,f,g,h,0,k,l,c[w>>2]|0,c[A>>2]|0,16,t);i=n;return}if((c[e+13880>>2]|0)!=1){Ia=c[e+13932>>2]|0;Ha=c[v>>2]|0;Ea=c[C>>2]|0;Fa=c[k>>2]|0;Ga=e+13900|0;Ma=c[Ga>>2]|0;La=c[x>>2]|0;da=ca(La,Ma)|0;Ka=e+13904|0;Ja=c[Ka>>2]|0;_=c[s>>2]|0;p=((ca(_,Ja)|0)+da<<4)+(c[e+13884>>2]|0)|0;da=e+13908|0;xa=c[da>>2]|0;ya=ca(xa,La)|0;La=e+13912|0;za=c[La>>2]|0;Aa=((ca(za,_)|0)+ya<<4)+(c[e+13888>>2]|0)|0;ya=e+10088|0;_=Ia+1|0;Ba=1<<(Ia<<1|1);Ia=e+12472|0;o=e+136|0;J=e+140|0;Pe[c[ya>>2]&3](f,Fa,Ha,16,p,Aa,Ma,Ja,xa,za,_,Ba-(c[Ia>>2]|0)|0,c[o>>2]|0,c[J>>2]|0);za=c[Ga>>2]|0;xa=c[da>>2]|0;Pe[c[ya>>2]&3](f+8|0,Fa,Ha,16,(za<<3)+p|0,(xa<<3)+Aa|0,za,c[Ka>>2]|0,xa,c[La>>2]|0,_,Ba-(c[Ia>>2]|0)|0,c[o>>2]|0,c[J>>2]|0);xa=c[Ga>>2]|0;za=c[x>>2]|0;Aa=ca(za,xa)|0;p=c[Ka>>2]|0;Ha=c[s>>2]|0;Fa=((ca(Ha,p)|0)+Aa<<3)+(c[e+13892>>2]|0)|0;Aa=c[da>>2]|0;Ja=ca(Aa,za)|0;za=c[La>>2]|0;Ma=((ca(za,Ha)|0)+Ja<<3)+(c[e+13896>>2]|0)|0;Pe[c[ya>>2]&3](g,c[B>>2]|0,Ea,8,Fa,Ma,xa,p,Aa,za,_,Ba-(c[Ia>>2]|0)|0,c[o>>2]>>1,c[J>>2]>>1);Pe[c[ya>>2]&3](h,c[E>>2]|0,Ea,8,Fa,Ma,c[Ga>>2]|0,c[Ka>>2]|0,c[da>>2]|0,c[La>>2]|0,_,Ba-(c[Ia>>2]|0)|0,c[o>>2]>>1,c[J>>2]>>1);i=n;return}J=c[e+13884>>2]|0;o=c[e+13888>>2]|0;Ia=e+13932|0;Ba=c[Ia>>2]|0;_=Ba+1|0;La=(J>>_)+(c[x>>2]<<4)|0;da=(c[s>>2]<<4)+(o>>_)|0;_=3-Ba|0;Ba=e+8|0;Ka=c[Ba>>2]|0;if((La|0)<-16){Na=-16}else{Na=(La|0)>(Ka|0)?Ka:La}La=(Na|0)==(Ka|0)?0:J<<_;J=e+12|0;Ka=c[J>>2]|0;if((da|0)<-16){Oa=-16}else{Oa=(da|0)>(Ka|0)?Ka:da}da=(Oa|0)==(Ka|0)?0:o<<_;_=c[v>>2]|0;o=c[C>>2]|0;Ka=(c[k>>2]|0)+((ca(_,Oa)|0)+Na)|0;Ga=e+136|0;Ma=c[Ga>>2]|0;Fa=Ma-17|0;Ea=e+140|0;ya=c[Ea>>2]|0;if(Na>>>0<((Fa|0)>0?Fa:0)>>>0){Fa=ya-17|0;if(Oa>>>0<((Fa|0)>0?Fa:0)>>>0){Pa=Ka}else{O=100}}else{O=100}if((O|0)==100){Fa=e+9944|0;Ve[c[e+11540>>2]&127](c[Fa>>2]|0,Ka,_,_,17,17,Na,Oa,Ma,ya);Pa=c[Fa>>2]|0}do{if(((da|La)&7|0)==0){Fa=da>>>2&2|La>>>3&1;if((c[e+12472>>2]|0)==0){mf[c[e+11332+(Fa<<2)>>2]&2047](f,Pa,_,16);break}else{mf[c[e+11460+(Fa<<2)>>2]&2047](f,Pa,_,16);break}}else{Fa=e+10084|0;ya=La&15;Ma=da&15;Oa=e+12472|0;Se[c[Fa>>2]&1023](f,Pa,_,16,ya,Ma,128-(c[Oa>>2]|0)|0);Se[c[Fa>>2]&1023](f+8|0,Pa+8|0,_,16,ya,Ma,128-(c[Oa>>2]|0)|0)}}while(0);_=c[e+13892>>2]|0;Pa=c[e+13896>>2]|0;da=c[Ia>>2]|0;Ia=da+1|0;La=(_>>Ia)+(c[x>>2]<<3)|0;x=(c[s>>2]<<3)+(Pa>>Ia)|0;Ia=3-da|0;da=_<<Ia;_=Pa<<Ia;Ia=c[Ba>>2]>>1;if((La|0)<-8){Qa=-8}else{Qa=(La|0)>(Ia|0)?Ia:La}La=(Qa|0)==(Ia|0);Ia=c[J>>2]>>1;if((x|0)<-8){Ra=-8}else{Ra=(x|0)>(Ia|0)?Ia:x}x=(Ra|0)==(Ia|0);Ia=(ca(Ra,o)|0)+Qa|0;J=(c[B>>2]|0)+Ia|0;B=c[Ga>>2]>>1;Ba=B-9|0;Pa=c[Ea>>2]>>1;if(Qa>>>0<((Ba|0)>0?Ba:0)>>>0){Ba=Pa-9|0;if(Ra>>>0<((Ba|0)>0?Ba:0)>>>0){Sa=J;Ta=0}else{O=112}}else{O=112}if((O|0)==112){Ba=e+9944|0;Ve[c[e+11540>>2]&127](c[Ba>>2]|0,J,o,o,9,9,Qa,Ra,B,Pa);Sa=c[Ba>>2]|0;Ta=1}Ba=e+10084|0;Pa=La?0:da&15;da=x?0:_&15;_=e+12472|0;Se[c[Ba>>2]&1023](g,Sa,o,8,Pa,da,128-(c[_>>2]|0)|0);Sa=(c[E>>2]|0)+Ia|0;if(Ta){Ta=e+9944|0;Ve[c[e+11540>>2]&127](c[Ta>>2]|0,Sa,o,o,9,9,Qa,Ra,c[Ga>>2]>>1,c[Ea>>2]>>1);Ua=c[Ta>>2]|0}else{Ua=Sa}Se[c[Ba>>2]&1023](h,Ua,o,8,Pa,da,128-(c[_>>2]|0)|0);i=n;return};case 3:{_=c[e+14172>>2]|0;if((_|0)==3){da=c[e+11808+(j<<3)>>2]|0;Pa=c[w>>2]|0;o=c[A>>2]|0;if((c[u>>2]|0)==0){pUa(e,f,g,h,0,da,k,l,Pa,o,t);pUa(e,f,g,h,1,c[e+11808+(j<<3)+4>>2]|0,k,l,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,t);i=n;return}else{nUa(e,f,g,h,1,0,da,k,l,m,Pa,o,8);nUa(e,f,g,h,1,1,c[e+11808+(j<<3)+4>>2]|0,k,l,m,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,8);i=n;return}}m=c[e+11808+(j<<3)>>2]|0;do{if((_|0)==(m+1|0)){O=152}else{if((c[e+9992>>2]|0)==3){O=152;break}if((c[e+14240>>2]|0)==0){O=153}else{O=152}}}while(0);if((O|0)==152){if((c[k>>2]|0)==0){O=153}else{Va=k}}if((O|0)==153){Va=c[e+9856>>2]|0}oUa(e,f,g,h,m,Va,l,c[w>>2]|0,c[A>>2]|0,16,t>>1);i=n;return};case 2:{Va=e+14172|0;m=e+9856|0;_=t>>1;o=e+14220|0;Pa=e+9992|0;da=e+14240|0;u=c[e+11808+(j<<3)>>2]|0;do{if((c[Va>>2]|0)==(u+1|0)){O=157}else{if((c[Pa>>2]|0)==3){O=157;break}if((c[da>>2]|0)==0){O=158}else{O=157}}}while(0);if((O|0)==157){if((c[k>>2]|0)==0){O=158}else{Wa=k}}if((O|0)==158){Wa=c[m>>2]|0}oUa(e,f,g,h,u,Wa,l,c[w>>2]|0,c[A>>2]|0,8,_);Wa=f+(c[v>>2]<<4)|0;v=ca(16>>>((c[o>>2]|0)>>>0),c[C>>2]|0)|0;C=g+v|0;o=h+v|0;v=c[e+11808+(j<<3)+4>>2]|0;do{if((c[Va>>2]|0)==(v+1|0)){O=171}else{if((c[Pa>>2]|0)==3){O=171;break}if((c[da>>2]|0)==0){O=172}else{O=171}}}while(0);if((O|0)==171){if((c[k>>2]|0)==0){O=172}else{Xa=k}}if((O|0)==172){Xa=c[m>>2]|0}oUa(e,Wa,C,o,v,Xa,l,c[e+11744+(j<<5)+8>>2]|0,(c[e+11744+(j<<5)+12>>2]|0)+16|0,8,_);i=n;return};case 4:{_=e+14172|0;if((c[_>>2]|0)==3){Xa=e+11396|0;pUa(e,f,g,h,0,0,k,l,c[w>>2]|0,c[A>>2]|0,t);pUa(e,f,g,h,1,1,k,l,c[e+11744+(j<<5)+8>>2]|0,c[e+11744+(j<<5)+12>>2]|0,t);pUa(e,f,g,h,0,1,k,Xa,c[e+11744+(j<<5)+16>>2]|0,c[e+11744+(j<<5)+20>>2]|0,t);pUa(e,f,g,h,1,0,k,Xa,c[e+11744+(j<<5)+24>>2]|0,c[e+11744+(j<<5)+28>>2]|0,t);i=n;return}Xa=e+9856|0;if((c[k>>2]|0)==0){Ya=c[Xa>>2]|0}else{Ya=k}k=t>>1;t=e+11396|0;A=e+14240|0;w=0;v=l;l=Ya;b:while(1){Ya=w;o=v;while(1){if((Ya|0)>=2){break b}Za=Ya+1|0;C=Ya<<1;oUa(e,f,g,h,(c[_>>2]|0)!=(Za|0)|0,l,o,c[e+11744+(j<<5)+(C<<3)>>2]|0,c[e+11744+(j<<5)+(C<<3)+4>>2]|0,16,k);if((c[A>>2]|0)==0){break}else{Ya=Za;o=t}}w=Za;v=t;l=c[Xa>>2]|0}i=n;return};default:{i=n;return}}}function nUa(a,b,d,e,f,g,h,i,j,k,l,m,n){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;o=m&3;p=l&3;q=o<<2|p;r=c[a+12476>>2]|0;s=(r<<4)+(l>>2)|0;t=c[a+12480>>2]|0;u=(ca(t,16>>>(f>>>0))|0)+(m>>2)|0;v=a+140|0;w=c[v>>2]|0;x=w>>f;y=a+148|0;z=c[y>>2]|0;A=z<<f;B=a+152|0;C=c[B>>2]<<f;D=(f|0)!=0;do{if(D){E=(l|0)/2|0;F=m>>1}else{G=c[a+84>>2]|0;if((G&256|0)!=0){E=(c[692096+((l&7)<<2)>>2]|0)+(l>>1)|0;F=(c[692096+((m&7)<<2)>>2]|0)+(m>>1)|0;break}if((G&64|0)==0){E=(l|0)/2|0;F=(m|0)/2|0;break}else{E=l>>1|l&1;F=m>>1|m&1;break}}}while(0);m=(E>>>1|E)&1|(F<<1|F)&2;l=(r<<3)+(E>>2)|0;E=(ca(t,8>>>(f>>>0))|0)+(F>>2)|0;F=(c[i>>2]|0)+((ca(A,u)|0)+s)|0;t=(ca(E,C)|0)+l|0;r=(c[i+4>>2]|0)+t|0;G=(c[i+8>>2]|0)+t|0;t=a+136|0;i=c[t>>2]|0;H=i-p-16|0;if(s>>>0>((H|0)>0?H:0)>>>0){I=10}else{H=x-o-n|0;if(u>>>0>((H|0)>0?H:0)>>>0){I=10}else{J=F;K=r;L=G}}if((I|0)==10){I=a+11540|0;H=a+9944|0;Ve[c[I>>2]&127](c[H>>2]|0,F,z,z,17,f+17|0,s,u<<f,i,w);w=c[H>>2]|0;H=(c[y>>2]|0)*18|0;i=w+H|0;u=c[B>>2]|0;s=f+9|0;z=E<<f;Ve[c[I>>2]&127](i,r,u,u,9,s,l,z,c[t>>2]>>1,c[v>>2]>>1);u=w+(H+16)|0;H=c[B>>2]|0;Ve[c[I>>2]&127](u,G,H,H,9,s,l,z,c[t>>2]>>1,c[v>>2]>>1);J=w;K=i;L=u}if(!D){ef[c[k+(q<<2)>>2]&4095](b,J,A);M=d;N=e;O=K;P=L;Q=j+16+(m<<2)|0;R=c[Q>>2]|0;S=n>>1;mf[R&2047](N,P,C,S);T=c[Q>>2]|0;mf[T&2047](M,O,C,S);return}if((g|0)==0){U=b;V=d;W=e}else{g=c[B>>2]|0;U=b+(c[y>>2]|0)|0;V=d+g|0;W=e+g|0}if((h|0)==0){X=J;Y=K;Z=L}else{h=c[B>>2]|0;X=J+(c[y>>2]|0)|0;Y=K+h|0;Z=L+h|0}h=k+64+(q<<2)|0;ef[c[h>>2]&4095](U,X,A);ef[c[h>>2]&4095](U+8|0,X+8|0,A);M=V;N=W;O=Y;P=Z;Q=j+16+(m<<2)|0;R=c[Q>>2]|0;S=n>>1;mf[R&2047](N,P,C,S);T=c[Q>>2]|0;mf[T&2047](M,O,C,S);return}function oUa(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;n=i;o=a+28|0;p=c[o>>2]|0;q=a+140|0;r=c[q>>2]|0;s=c[a+7656>>2]|0;t=c[a+7660>>2]|0;u=k&1;v=u<<1;w=j&1;x=v|w;y=c[a+12476>>2]|0;z=(y<<4)+(j>>1)|0;A=(m<<4)+(k>>1)|0;do{if((p|0)==2){B=A>>1;C=z>>1;D=j>>>1&1|k&2|x}else if((p|0)==1){B=((k|0)/4|0)+(m<<3)|0;C=((j|0)/4|0)+(y<<3)|0;D=0}else if((p|0)==0){E=a+14220|0;do{if((c[E>>2]|0)==0){if((c[a+14216>>2]|0)==0){F=A;G=z;H=x;break}I=(j|0)/2|0;F=A;G=(I>>1)+(y<<3)|0;H=I&1|v}else{I=(j|0)/2|0;J=(k|0)/2|0;F=(J>>1)+(m<<3)|0;G=(I>>1)+(y<<3)|0;H=J<<1&2|I&1}}while(0);I=c[g>>2]|0;J=z+(ca(s,A)|0)|0;K=c[g+4>>2]|0;L=(ca(F,t)|0)+G|0;M=c[g+8>>2]|0;N=(c[a+136>>2]|0)-w-16|0;do{if(!(z>>>0>((N|0)>0?N:0)>>>0)){O=r-u-l|0;if(A>>>0>((O|0)>0?O:0)>>>0){break}if((f|0)==0){P=J;Q=L}else{P=(c[a+148>>2]|0)+J|0;Q=(c[a+152>>2]|0)+L|0}mf[c[h+(x<<2)>>2]&2047](b,I+P|0,s,l);O=a+14216|0;mf[c[h+(c[O>>2]<<4)+(H<<2)>>2]&2047](d,K+Q|0,t,l>>c[E>>2]);mf[c[h+(c[O>>2]<<4)+(H<<2)>>2]&2047](e,M+Q|0,t,l>>c[E>>2]);i=n;return}}while(0);KIb(c[a+4>>2]|0,48,2496784,(R=i,i=i+16|0,c[R>>2]=z,c[R+8>>2]=A,R)|0);i=R;i=n;return}else{if((c[a+14220>>2]|0)!=0){E=(j|0)/2|0;M=(k|0)/2|0;B=(M>>1)+(m<<3)|0;C=(E>>1)+(y<<3)|0;D=M<<1&2|E&1;break}if((c[a+14216>>2]|0)==0){B=A;C=z;D=x;break}E=(j|0)/2|0;B=A;C=(E>>1)+(y<<3)|0;D=E&1|v}}while(0);v=(c[g>>2]|0)+(z+(ca(s,A)|0))|0;y=(ca(B,t)|0)+C|0;j=(c[g+4>>2]|0)+y|0;m=(c[g+8>>2]|0)+y|0;y=a+136|0;g=c[y>>2]|0;k=g-w-16|0;if(z>>>0>((k|0)>0?k:0)>>>0){S=20}else{k=r-u-l|0;if(A>>>0>((k|0)>0?k:0)>>>0){S=20}else{T=v;U=j;V=m}}do{if((S|0)==20){if(!(((c[a+48>>2]|0)-1|0)>>>0<2>>>0)){k=a+11540|0;u=a+9944|0;w=a+148|0;Q=c[w>>2]|0;Ve[c[k>>2]&127](c[u>>2]|0,v,Q,Q,17,17,z,A,g,r);Q=c[u>>2]|0;u=(c[w>>2]|0)*18|0;w=Q+u|0;H=a+152|0;P=c[H>>2]|0;Ve[c[k>>2]&127](w,j,P,P,9,9,C,B,c[y>>2]>>1,c[q>>2]>>1);P=Q+(u+16)|0;u=c[H>>2]|0;Ve[c[k>>2]&127](P,m,u,u,9,9,C,B,c[y>>2]>>1,c[q>>2]>>1);T=Q;U=w;V=P;break}KIb(c[a+4>>2]|0,48,2496784,(R=i,i=i+16|0,c[R>>2]=z,c[R+8>>2]=A,R)|0);i=R;i=n;return}}while(0);if((f|0)==0){W=T;X=U;Y=V}else{f=c[a+152>>2]|0;W=T+(c[a+148>>2]|0)|0;X=U+f|0;Y=V+f|0}mf[c[h+(x<<2)>>2]&2047](b,W,s,l);s=a+14216|0;W=a+14220|0;mf[c[h+(c[s>>2]<<4)+(D<<2)>>2]&2047](d,X,t,l>>c[W>>2]);mf[c[h+(c[s>>2]<<4)+(D<<2)>>2]&2047](e,Y,t,l>>c[W>>2]);if((c[o>>2]|0)!=1){i=n;return}Tpb(a);i=n;return}function pUa(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;n=i;o=a+28|0;p=c[o>>2]|0;q=a+140|0;r=c[q>>2]|0;s=r>>1;t=c[a+7656>>2]<<1;u=c[a+7660>>2]<<1;v=l&1;w=v<<1;x=k&1;y=w|x;z=c[a+12476>>2]|0;A=k>>1;B=(z<<4)+A|0;C=m<<3;D=l>>1;E=C+D|0;do{if((p|0)==1){F=((l|0)/4|0)+C|0;G=((k|0)/4|0)+(z<<3)|0;H=0}else if((p|0)==2){if((c[a+84>>2]&2048|0)==0){F=E>>1;G=B>>1;H=k>>>1&1|l&2|y;break}else{F=(m<<2)+(l>>2)|0;G=(z<<3)+(k>>2)|0;H=D<<1&2|(A|k)&1;break}}else if((p|0)==0){I=a+14220|0;do{if((c[I>>2]|0)==0){if((c[a+14216>>2]|0)==0){J=E;K=B;L=y;break}M=(k|0)/2|0;J=E;K=(M>>1)+(z<<3)|0;L=M&1|w}else{M=(k|0)/2|0;N=(l|0)/2|0;J=(N>>1)+(m<<2)|0;K=(M>>1)+(z<<3)|0;L=N<<1&2|M&1}}while(0);M=c[h>>2]|0;N=B+(ca(t,E)|0)|0;O=c[h+4>>2]|0;P=(ca(J,u)|0)+K|0;Q=c[h+8>>2]|0;R=(c[a+136>>2]|0)-x-16|0;do{if(!(B>>>0>((R|0)>0?R:0)>>>0)){S=s-v-8|0;if(E>>>0>((S|0)>0?S:0)>>>0){break}if((f|0)==0){T=b;U=d;V=e}else{S=c[a+152>>2]|0;T=b+(c[a+148>>2]|0)|0;U=d+S|0;V=e+S|0}if((g|0)==0){W=N;X=P}else{W=(c[a+148>>2]|0)+N|0;X=(c[a+152>>2]|0)+P|0}mf[c[j+(y<<2)>>2]&2047](T,M+W|0,t,8);S=a+14216|0;mf[c[j+(c[S>>2]<<4)+(L<<2)>>2]&2047](U,O+X|0,u,8>>>((c[I>>2]|0)>>>0));mf[c[j+(c[S>>2]<<4)+(L<<2)>>2]&2047](V,Q+X|0,u,8>>>((c[I>>2]|0)>>>0));i=n;return}}while(0);KIb(c[a+4>>2]|0,48,2496784,(Y=i,i=i+16|0,c[Y>>2]=B,c[Y+8>>2]=E,Y)|0);i=Y;i=n;return}else{if((c[a+14220>>2]|0)!=0){I=(k|0)/2|0;Q=(l|0)/2|0;F=(Q>>1)+(m<<2)|0;G=(I>>1)+(z<<3)|0;H=Q<<1&2|I&1;break}if((c[a+14216>>2]|0)==0){F=E;G=B;H=y;break}I=(k|0)/2|0;F=E;G=(I>>1)+(z<<3)|0;H=I&1|w}}while(0);w=(c[h>>2]|0)+(B+(ca(t,E)|0))|0;z=(ca(F,u)|0)+G|0;k=(c[h+4>>2]|0)+z|0;m=(c[h+8>>2]|0)+z|0;z=a+136|0;h=c[z>>2]|0;l=h-x-16|0;if(B>>>0>((l|0)>0?l:0)>>>0){Z=24}else{l=s-v-8|0;if(E>>>0>((l|0)>0?l:0)>>>0){Z=24}else{_=w;$=k;aa=m}}do{if((Z|0)==24){if(!(((c[a+48>>2]|0)-1|0)>>>0<2>>>0)){l=a+11540|0;v=a+9944|0;s=a+148|0;x=c[s>>2]|0;Ve[c[l>>2]&127](c[v>>2]|0,w,x,x,17,18,B,E<<1,h,r);x=c[v>>2]|0;v=(c[s>>2]|0)*18|0;s=x+v|0;X=a+152|0;V=c[X>>2]|0;L=F<<1;Ve[c[l>>2]&127](s,k,V,V,9,10,G,L,c[z>>2]>>1,c[q>>2]>>1);V=x+(v+16)|0;v=c[X>>2]|0;Ve[c[l>>2]&127](V,m,v,v,9,10,G,L,c[z>>2]>>1,c[q>>2]>>1);_=x;$=s;aa=V;break}KIb(c[a+4>>2]|0,48,2496784,(Y=i,i=i+16|0,c[Y>>2]=B,c[Y+8>>2]=E,Y)|0);i=Y;i=n;return}}while(0);if((f|0)==0){ba=b;da=d;ea=e}else{f=c[a+152>>2]|0;ba=b+(c[a+148>>2]|0)|0;da=d+f|0;ea=e+f|0}if((g|0)==0){fa=_;ga=$;ha=aa}else{g=c[a+152>>2]|0;fa=_+(c[a+148>>2]|0)|0;ga=$+g|0;ha=aa+g|0}mf[c[j+(y<<2)>>2]&2047](ba,fa,t,8);t=a+14216|0;fa=a+14220|0;mf[c[j+(c[t>>2]<<4)+(H<<2)>>2]&2047](da,ga,u,8>>>((c[fa>>2]|0)>>>0));mf[c[j+(c[t>>2]<<4)+(H<<2)>>2]&2047](ea,ha,u,8>>>((c[fa>>2]|0)>>>0));if((c[o>>2]|0)!=1){i=n;return}Tpb(a);i=n;return}function qUa(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=(d[1378496+(h&15)|0]|0)+(h>>3)|0;h=(d[1378496+(i&15)|0]|0)+(i>>3)|0;i=(c[a+12476>>2]<<3)+(j>>1)|0;k=(c[a+12480>>2]<<3)+(h>>1)|0;l=c[a+8>>2]>>1;if((i|0)<-8){m=-8}else{m=(i|0)>(l|0)?l:i}i=(m|0)==(l|0)?0:j&1;j=c[a+12>>2]>>1;if((k|0)<-8){n=-8}else{n=(k|0)>(j|0)?j:k}k=(n|0)==(j|0)?0:h<<1&2;h=k|i;j=a+152|0;l=c[j>>2]|0;o=(ca(l,n)|0)+m|0;p=(c[f+4>>2]|0)+o|0;q=a+136|0;r=c[q>>2]>>1;s=r-i-8|0;i=c[a+140>>2]|0;if(m>>>0>((s|0)>0?s:0)>>>0){t=7}else{s=(i>>1)-(k>>>1)-8|0;if(n>>>0>((s|0)>0?s:0)>>>0){t=7}else{u=p;v=0;w=l}}if((t|0)==7){t=a+9944|0;Ve[c[a+11540>>2]&127](c[t>>2]|0,p,l,l,9,9,m,n,r,i>>1);u=c[t>>2]|0;v=1;w=c[j>>2]|0}t=g+(h<<2)|0;mf[c[t>>2]&2047](b,u,w,8);w=(c[f+8>>2]|0)+o|0;if(!v){x=w;y=c[t>>2]|0;z=c[j>>2]|0;mf[y&2047](e,x,z,8);return}v=a+9944|0;o=c[j>>2]|0;Ve[c[a+11540>>2]&127](c[v>>2]|0,w,o,o,9,9,m,n,c[q>>2]>>1,c[a+140>>2]>>1);x=c[v>>2]|0;y=c[t>>2]|0;z=c[j>>2]|0;mf[y&2047](e,x,z,8);return}function rUa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+1040|0;h=g|0;j=g+1024|0;k=g+1032|0;l=d;m=c[f+24>>2]|0;n=f+8|0;o=c[n>>2]|0;p=c[n+4>>2]|0;n=b+104|0;c[j>>2]=1;c[j+4>>2]=100;b=XIb(o,p,n,j)|0;j=b;b=c[f+48>>2]|0;if((b|0)==-1){q=-1}else{c[k>>2]=1;c[k+4>>2]=100;p=XIb(b,(b|0)<0|0?-1:0,n,k)|0;q=p}SFb(h,0,-1);p=f+28|0;do{if((m|0)!=0){if((c[p>>2]|0)<=0){break}f=a[m]|0;if(f<<24>>24==0){break}k=f<<24>>24==32?m+1|0:m;f=a[k]|0;a:do{if(!(f<<24>>24==0)){n=k;b=f;do{b:do{if(b<<24>>24==0){r=n;s=0;t=0}else{o=n;u=0;v=b;while(1){if((Ob(2449520,v<<24>>24|0,4)|0)==0){r=o;s=u;t=v;break b}if((v<<24>>24|0)==92){UFb(h,2296240,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}else if((v<<24>>24|0)==95){UFb(h,2245256,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}else if((v<<24>>24|0)==47){UFb(h,2360264,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}x=o+1|0;y=a[x]|0;if(y<<24>>24==0){r=x;s=1;t=0;break}else{o=x;u=1;v=y}}}}while(0);v=r;u=t;while(1){if((u<<24>>24|0)==124){break}else if((u<<24>>24|0)==0){break a}else if(!((u<<24>>24|0)==10|(u<<24>>24|0)==13)){WFb(h,u,1)}o=v+1|0;v=o;u=a[o]|0}if((s|0)!=0){UFb(h,2203808,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}UFb(h,2171848,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;n=v+1|0;b=a[n]|0;}while(!(b<<24>>24==0))}}while(0);UFb(h,2144272,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if((c[h+4>>2]|0)>>>0<(c[h+8>>2]|0)>>>0){fmb(l,c[h>>2]|0,j,q,0)|0;break}_Fb(h,0)|0;z=-12;i=g;return z|0}}while(0);c[e>>2]=(c[d+12>>2]|0)!=0;_Fb(h,0)|0;z=c[p>>2]|0;i=g;return z|0}function sUa(){var c=0,d=0,e=0,f=0,g=0;c=0;do{d=b[1617584+(c*6|0)>>1]|0;e=c<<1;f=e|1;b[7302872+(f<<1)>>1]=d;b[7302872+(e<<1)>>1]=d;d=a[1617587+(c*6|0)|0]<<1;g=a[1617588+(c*6|0)|0]|0;a[7303160+e|0]=d+g;a[7303160+f|0]=(d|1)-g;g=a[1617586+(c*6|0)|0]<<1;a[7303064+e|0]=g;a[7303064+f|0]=g|1;c=c+1|0;}while((c|0)<47);return}function tUa(b){b=b|0;var c=0;c=b+20|0;mrc(c|0,0,18)|0;a[b+37|0]=92;a[b+38|0]=6;a[c]=8;return}function uUa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;tUa(b);f=b|0;c[f>>2]=e;g=d[e]<<16^16711680;h=b+12|0;c[h>>2]=g;i=e+1|0;do{if((a[e]|0)==-1){if((d[i]|0)>>>0>143>>>0){j=g|1;c[h>>2]=j;k=j;break}else{c[f>>2]=i;j=(g|65026)-(d[i]<<9)|0;c[h>>2]=j;k=j;break}}else{c[f>>2]=i;j=(g|65281)-(d[i]<<8)|0;c[h>>2]=j;k=j}}while(0);c[h>>2]=k<<7;c[b+8>>2]=32768;return}function vUa(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0;g=b+8|0;h=(c[g>>2]|0)-(e[7302872+((d[f]|0)<<1)>>1]|0)|0;c[g>>2]=h;g=b+12|0;i=c[g>>2]|0;if(!(i>>>16>>>0<h>>>0)){c[g>>2]=i-(h<<16);j=wUa(b,f,1)|0;return j|0}if((h&32768|0)==0){j=wUa(b,f,0)|0;return j|0}else{j=a[f]&1;return j|0}return 0}function wUa(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=b+8|0;i=a[f]|0;j=e[7302872+((i&255)<<1)>>1]|0;k=(g|0)!=0;if(((c[h>>2]|0)>>>0<j>>>0|0)==(k&1^1|0)){if(k){c[h>>2]=j;l=a[f]|0}else{l=i}g=l&255;m=g&1^1;n=7303160+g|0}else{if(k){c[h>>2]=j;o=a[f]|0}else{o=i}i=o&255;m=i&1;n=7303064+i|0}a[f]=a[n]|0;n=b+12|0;f=b|0;b=c[n>>2]|0;do{do{if((b&255|0)==0){c[n>>2]=b-256;i=c[f>>2]|0;o=i+1|0;if(!((a[i]|0)==-1)){c[f>>2]=o;i=b+65025-(d[o]<<8)|0;c[n>>2]=i;p=i;break}if((d[o]|0)>>>0>143>>>0){i=b-255|0;c[n>>2]=i;p=i;break}else{c[f>>2]=o;i=b+64770-(d[o]<<9)|0;c[n>>2]=i;p=i;break}}else{p=b}}while(0);i=c[h>>2]<<1;c[h>>2]=i;b=p<<1;c[n>>2]=b;}while((i&32768|0)==0);return m|0}function xUa(b,d){b=b|0;d=d|0;var e=0;tUa(b);c[b+8>>2]=32768;c[b+12>>2]=0;e=d-1|0;c[b>>2]=e;c[b+4>>2]=d;c[b+16>>2]=(a[e]|0)==-1|12;return}function yUa(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=e[7302872+((d[f]|0)<<1)>>1]|0;i=b+8|0;j=(c[i>>2]|0)-h|0;c[i>>2]=j;if((a[f]&1|0)!=(g|0)){if(j>>>0<h>>>0){g=b+12|0;c[g>>2]=(c[g>>2]|0)+h;k=g}else{c[i>>2]=h;k=b+12|0}a[f]=a[7303160+(d[f]|0)|0]|0;g=b+16|0;l=b|0;m=c[i>>2]|0;n=c[k>>2]|0;o=c[g>>2]|0;while(1){c[i>>2]=m<<1;p=n<<1;c[k>>2]=p;q=o-1|0;c[g>>2]=q;a:do{if((q|0)==0){r=c[l>>2]|0;s=a[r]|0;do{if(s<<24>>24==-1){t=r;u=n>>>19&255}else{v=r;w=s;x=p;while(1){if((x&134217728|0)==0){y=26;break}a[v]=w+1;z=c[k>>2]&134217727;c[k>>2]=z;A=c[l>>2]|0;B=a[A]|0;if(B<<24>>24==-1){y=22;break}else{v=A;w=B;x=z}}if((y|0)==22){y=0;t=A;u=z>>>20&255;break}else if((y|0)==26){y=0;w=v+1|0;c[l>>2]=w;a[w]=x>>>19;w=c[k>>2]&524287;c[k>>2]=w;c[g>>2]=8;C=w;D=8;break a}}}while(0);s=t+1|0;c[l>>2]=s;a[s]=u;s=c[k>>2]&1048575;c[k>>2]=s;c[g>>2]=7;C=s;D=7}else{C=p;D=q}}while(0);q=c[i>>2]|0;if((q&32768|0)==0){m=q;n=C;o=D}else{break}}return}if((j&32768|0)!=0){D=b+12|0;c[D>>2]=(c[D>>2]|0)+h;return}if(j>>>0<h>>>0){c[i>>2]=h;E=b+12|0}else{j=b+12|0;c[j>>2]=(c[j>>2]|0)+h;E=j}a[f]=a[7303064+(d[f]|0)|0]|0;f=b+16|0;j=b|0;b=c[i>>2]|0;h=c[E>>2]|0;D=c[f>>2]|0;while(1){c[i>>2]=b<<1;o=h<<1;c[E>>2]=o;C=D-1|0;c[f>>2]=C;b:do{if((C|0)==0){n=c[j>>2]|0;m=a[n]|0;do{if(m<<24>>24==-1){F=n;G=h>>>19&255}else{g=n;k=m;u=o;while(1){if((u&134217728|0)==0){y=13;break}a[g]=k+1;H=c[E>>2]&134217727;c[E>>2]=H;I=c[j>>2]|0;l=a[I]|0;if(l<<24>>24==-1){y=9;break}else{g=I;k=l;u=H}}if((y|0)==9){y=0;F=I;G=H>>>20&255;break}else if((y|0)==13){y=0;k=g+1|0;c[j>>2]=k;a[k]=u>>>19;k=c[E>>2]&524287;c[E>>2]=k;c[f>>2]=8;J=k;K=8;break b}}}while(0);m=F+1|0;c[j>>2]=m;a[m]=G;m=c[E>>2]&1048575;c[E>>2]=m;c[f>>2]=7;J=m;K=7}else{J=o;K=C}}while(0);C=c[i>>2]|0;if((C&32768|0)==0){b=C;h=J;D=K}else{break}}return}function zUa(a){a=a|0;return(c[a>>2]|0)-(c[a+4>>2]|0)|0}function AUa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=b+12|0;e=c[d>>2]|0;f=e|65535;g=b+16|0;h=(f>>>0<((c[b+8>>2]|0)+e|0)>>>0?f:f-32768|0)<<c[g>>2];c[d>>2]=h;f=b|0;e=c[f>>2]|0;i=a[e]|0;do{if(i<<24>>24==-1){j=e;k=h>>>20&255;l=3}else{m=e;n=i;o=h;while(1){if((o&134217728|0)==0){l=6;break}a[m]=n+1;p=c[d>>2]&134217727;c[d>>2]=p;q=c[f>>2]|0;r=a[q]|0;if(r<<24>>24==-1){l=2;break}else{m=q;n=r;o=p}}if((l|0)==2){j=q;k=p>>>20&255;l=3;break}else if((l|0)==6){n=m+1|0;c[f>>2]=n;a[n]=o>>>19;s=8;t=c[d>>2]&524287;break}}}while(0);if((l|0)==3){p=j+1|0;c[f>>2]=p;a[p]=k;s=7;t=c[d>>2]&1048575}c[g>>2]=s;k=t<<s;c[d>>2]=k;s=c[f>>2]|0;t=a[s]|0;do{if(t<<24>>24==-1){u=s;v=k>>>20&255;l=9}else{p=s;j=t;q=k;while(1){if((q&134217728|0)==0){l=12;break}a[p]=j+1;w=c[d>>2]&134217727;c[d>>2]=w;x=c[f>>2]|0;h=a[x]|0;if(h<<24>>24==-1){l=8;break}else{p=x;j=h;q=w}}if((l|0)==8){u=x;v=w>>>20&255;l=9;break}else if((l|0)==12){j=p+1|0;c[f>>2]=j;a[j]=q>>>19;y=8;z=c[d>>2]&524287;break}}}while(0);if((l|0)==9){l=u+1|0;c[f>>2]=l;a[l]=v;y=7;z=c[d>>2]&1048575}c[d>>2]=z;c[g>>2]=y;y=c[f>>2]|0;if((a[y]|0)==-1){A=y;B=b+4|0;C=c[B>>2]|0;D=A;E=C;F=D-E|0;return F|0}g=y+1|0;c[f>>2]=g;A=g;B=b+4|0;C=c[B>>2]|0;D=A;E=C;F=D-E|0;return F|0}function BUa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+24|0;g=f|0;h=(d|0)==0?0:520;c[g>>2]=d;c[g+12>>2]=h;c[g+16>>2]=h+8;c[g+4>>2]=d+(h>>>3);c[g+8>>2]=0;h=a+60|0;CUa(c[h>>2]|0,b,g,e);CUa(c[h>>2]|0,b+320|0,g,e);i=f;return 0}function CUa(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;i=a+240|0;j=a+660|0;k=c[j>>2]|0;l=a+596|0;m=g+8|0;n=c[m>>2]|0;o=g+16|0;p=c[o>>2]|0;q=c[g>>2]|0;g=q+(n>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((n&7)>>>0);g=n+6|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)>>2]=((r<<10&64512)*13107|0)-429473792>>15<<1;r=c[m>>2]|0;p=c[o>>2]|0;g=q+(r>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0);g=r+6|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+4>>2]=((n<<10&64512)*13107|0)-429473792>>15<<1;n=c[m>>2]|0;p=c[o>>2]|0;g=q+(n>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((n&7)>>>0);g=n+5|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+8>>2]=((r<<10&31744)*13107|0)-268414976>>15<<1;r=c[m>>2]|0;p=c[o>>2]|0;g=q+(r>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0);g=r+5|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+12>>2]=((n<<10&31744)*13107|0)-147620864>>15<<1;n=c[m>>2]|0;p=c[o>>2]|0;g=q+(n>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((n&7)>>>0);g=n+4|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+16>>2]=((r<<10&15360)*19223|0)-161072356>>15<<1;r=c[m>>2]|0;p=c[o>>2]|0;g=q+(r>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0);g=r+4|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+20>>2]=((n<<10&15360)*17476|0)-80513024>>15<<1;n=c[m>>2]|0;p=c[o>>2]|0;g=q+(n>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((n&7)>>>0);g=n+3|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+24>>2]=((r<<10&7168)*31454|0)-107367572>>15<<1;r=c[m>>2]|0;p=c[o>>2]|0;g=q+(r>>>3)|0;n=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0);g=r+3|0;c[m>>2]=p>>>0>g>>>0?g:p;c[l+(k<<5)+28>>2]=((n<<10&7168)*29708|0)-53695680>>15<<1;n=c[o>>2]|0;o=i;k=0;l=c[m>>2]|0;while(1){p=q+(l>>>3)|0;g=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((l&7)>>>0)&127;p=l+7|0;r=n>>>0>p>>>0?p:n;c[m>>2]=r;p=q+(r>>>3)|0;s=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((r&7)>>>0)&3;p=r+2|0;r=n>>>0>p>>>0?p:n;c[m>>2]=r;p=q+(r>>>3)|0;t=(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)>>>((r&7)>>>0)&3;p=r+2|0;r=n>>>0>p>>>0?p:n;c[m>>2]=r;if(g>>>0<40>>>0){u=40}else{u=g>>>0>120>>>0?120:g}g=e[1380728+(s<<1)>>1]|0;s=0;do{b[o+(s<<1)>>1]=((ca(b[o+(s-u<<1)>>1]|0,g)|0)+16384|0)>>>15;s=s+1|0;}while((s|0)<40);s=c[1381944+(h<<4)+(k<<2)>>2]|0;g=q+(r>>>3)|0;p=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((r&7)>>>0)&63;g=r+6|0;v=n>>>0>g>>>0?g:n;c[m>>2]=v;g=0;w=v;do{v=s+(g<<2)|0;x=c[v>>2]|0;y=q+(w>>>3)|0;z=32-x|0;A=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((w&7)>>>0)<<z>>>(z>>>0);z=x+w|0;w=n>>>0>z>>>0?z:n;c[m>>2]=w;z=o+((g*3|0)+t<<1)|0;b[z>>1]=(b[z>>1]|0)+(b[1380736+(p<<4)+(c[679936+(c[v>>2]<<5)+(A<<2)>>2]<<1)>>1]|0);g=g+1|0;}while((g|0)<13);g=k+1|0;if((g|0)<4){o=o+80|0;k=g;l=w}else{break}}l=a;nrc(a|0,a+320|0,240)|0;k=c[j>>2]|0;o=k^1;m=l+596+(o<<5)|0;n=c[m>>2]|0;q=l+596+(k<<5)|0;h=DUa((n>>2)+(n>>1)+(c[q>>2]>>2)|0)|0;n=l+596+(o<<5)+4|0;u=c[n>>2]|0;g=l+596+(k<<5)+4|0;p=DUa((u>>2)+(u>>1)+(c[g>>2]>>2)|0)|0;u=l+596+(o<<5)+8|0;t=c[u>>2]|0;s=l+596+(k<<5)+8|0;r=DUa((t>>2)+(t>>1)+(c[s>>2]>>2)|0)|0;t=l+596+(o<<5)+12|0;A=c[t>>2]|0;v=l+596+(k<<5)+12|0;z=DUa((A>>2)+(A>>1)+(c[v>>2]>>2)|0)|0;A=l+596+(o<<5)+16|0;x=c[A>>2]|0;y=l+596+(k<<5)+16|0;B=DUa((x>>2)+(x>>1)+(c[y>>2]>>2)|0)|0;x=l+596+(o<<5)+20|0;C=c[x>>2]|0;D=l+596+(k<<5)+20|0;E=DUa((C>>2)+(C>>1)+(c[D>>2]>>2)|0)|0;C=l+596+(o<<5)+24|0;F=c[C>>2]|0;G=l+596+(k<<5)+24|0;H=DUa((F>>2)+(F>>1)+(c[G>>2]>>2)|0)|0;F=l+596+(o<<5)+28|0;I=c[F>>2]|0;J=l+596+(k<<5)+28|0;k=DUa((I>>2)+(I>>1)+(c[J>>2]>>2)|0)|0;I=a+560|0;l=a+588|0;K=a+584|0;L=a+580|0;M=a+576|0;N=a+572|0;O=a+568|0;P=a+564|0;Q=0;R=c[l>>2]|0;S=c[K>>2]|0;T=c[L>>2]|0;U=c[M>>2]|0;V=c[N>>2]|0;W=c[O>>2]|0;X=c[P>>2]|0;Y=c[I>>2]|0;while(1){Z=(b[i+(Q<<1)>>1]|0)-((ca(R,k)|0)+16384>>15)|0;_=Z-((ca(S,H)|0)+16384>>15)|0;$=((ca(_,H)|0)+16384>>15)+S|0;aa=_-((ca(T,E)|0)+16384>>15)|0;ba=((ca(aa,E)|0)+16384>>15)+T|0;_=aa-((ca(U,B)|0)+16384>>15)|0;da=((ca(_,B)|0)+16384>>15)+U|0;aa=_-((ca(V,z)|0)+16384>>15)|0;ea=((ca(aa,z)|0)+16384>>15)+V|0;_=aa-((ca(W,r)|0)+16384>>15)|0;fa=((ca(_,r)|0)+16384>>15)+W|0;aa=_-((ca(X,p)|0)+16384>>15)|0;ga=((ca(aa,p)|0)+16384>>15)+X|0;ha=aa-((ca(Y,h)|0)+16384>>15)|0;ia=((ca(ha,h)|0)+16384>>15)+Y|0;b[f+(Q<<1)>>1]=ha;aa=Q+1|0;if((aa|0)<13){Q=aa;R=$;S=ba;T=da;U=ea;V=fa;W=ga;X=ia;Y=ha}else{break}}Y=a+592|0;X=((ca(Z,k)|0)+16384>>15)+R|0;c[l>>2]=$;c[Y>>2]=X;c[K>>2]=ba;c[L>>2]=da;c[M>>2]=ea;c[N>>2]=fa;c[O>>2]=ga;c[P>>2]=ia;c[I>>2]=ha;X=DUa((c[q>>2]>>1)+(c[m>>2]>>1)|0)|0;R=DUa((c[g>>2]>>1)+(c[n>>2]>>1)|0)|0;k=DUa((c[s>>2]>>1)+(c[u>>2]>>1)|0)|0;Z=DUa((c[v>>2]>>1)+(c[t>>2]>>1)|0)|0;W=DUa((c[y>>2]>>1)+(c[A>>2]>>1)|0)|0;V=DUa((c[D>>2]>>1)+(c[x>>2]>>1)|0)|0;U=DUa((c[G>>2]>>1)+(c[C>>2]>>1)|0)|0;T=DUa((c[J>>2]>>1)+(c[F>>2]>>1)|0)|0;S=13;Q=$;$=ba;ba=da;da=ea;ea=fa;fa=ga;ga=ia;ia=ha;while(1){ja=(b[i+(S<<1)>>1]|0)-((ca(Q,T)|0)+16384>>15)|0;ha=ja-((ca($,U)|0)+16384>>15)|0;ka=((ca(ha,U)|0)+16384>>15)+$|0;h=ha-((ca(ba,V)|0)+16384>>15)|0;la=((ca(h,V)|0)+16384>>15)+ba|0;ha=h-((ca(da,W)|0)+16384>>15)|0;ma=((ca(ha,W)|0)+16384>>15)+da|0;h=ha-((ca(ea,Z)|0)+16384>>15)|0;na=((ca(h,Z)|0)+16384>>15)+ea|0;ha=h-((ca(fa,k)|0)+16384>>15)|0;oa=((ca(ha,k)|0)+16384>>15)+fa|0;h=ha-((ca(ga,R)|0)+16384>>15)|0;pa=((ca(h,R)|0)+16384>>15)+ga|0;qa=h-((ca(ia,X)|0)+16384>>15)|0;ra=((ca(qa,X)|0)+16384>>15)+ia|0;b[f+(S<<1)>>1]=qa;h=S+1|0;if((h|0)<27){S=h;Q=ka;$=la;ba=ma;da=na;ea=oa;fa=pa;ga=ra;ia=qa}else{break}}ia=((ca(ja,T)|0)+16384>>15)+Q|0;c[l>>2]=ka;c[Y>>2]=ia;c[K>>2]=la;c[L>>2]=ma;c[M>>2]=na;c[N>>2]=oa;c[O>>2]=pa;c[P>>2]=ra;c[I>>2]=qa;ia=c[q>>2]|0;Q=DUa((ia>>1)+(c[m>>2]>>2)+(ia>>2)|0)|0;ia=c[g>>2]|0;m=DUa((ia>>1)+(c[n>>2]>>2)+(ia>>2)|0)|0;ia=c[s>>2]|0;n=DUa((ia>>1)+(c[u>>2]>>2)+(ia>>2)|0)|0;ia=c[v>>2]|0;u=DUa((ia>>1)+(c[t>>2]>>2)+(ia>>2)|0)|0;ia=c[y>>2]|0;t=DUa((ia>>1)+(c[A>>2]>>2)+(ia>>2)|0)|0;ia=c[D>>2]|0;A=DUa((ia>>1)+(c[x>>2]>>2)+(ia>>2)|0)|0;ia=c[G>>2]|0;x=DUa((ia>>1)+(c[C>>2]>>2)+(ia>>2)|0)|0;ia=c[J>>2]|0;C=DUa((ia>>1)+(c[F>>2]>>2)+(ia>>2)|0)|0;ia=27;F=ka;ka=la;la=ma;ma=na;na=oa;oa=pa;pa=ra;ra=qa;while(1){sa=(b[i+(ia<<1)>>1]|0)-((ca(F,C)|0)+16384>>15)|0;qa=sa-((ca(ka,x)|0)+16384>>15)|0;ta=((ca(qa,x)|0)+16384>>15)+ka|0;T=qa-((ca(la,A)|0)+16384>>15)|0;ua=((ca(T,A)|0)+16384>>15)+la|0;qa=T-((ca(ma,t)|0)+16384>>15)|0;va=((ca(qa,t)|0)+16384>>15)+ma|0;T=qa-((ca(na,u)|0)+16384>>15)|0;wa=((ca(T,u)|0)+16384>>15)+na|0;qa=T-((ca(oa,n)|0)+16384>>15)|0;xa=((ca(qa,n)|0)+16384>>15)+oa|0;T=qa-((ca(pa,m)|0)+16384>>15)|0;ya=((ca(T,m)|0)+16384>>15)+pa|0;za=T-((ca(ra,Q)|0)+16384>>15)|0;Aa=((ca(za,Q)|0)+16384>>15)+ra|0;b[f+(ia<<1)>>1]=za;T=ia+1|0;if((T|0)<40){ia=T;F=ta;ka=ua;la=va;ma=wa;na=xa;oa=ya;pa=Aa;ra=za}else{break}}ra=((ca(sa,C)|0)+16384>>15)+F|0;c[l>>2]=ta;c[Y>>2]=ra;c[K>>2]=ua;c[L>>2]=va;c[M>>2]=wa;c[N>>2]=xa;c[O>>2]=ya;c[P>>2]=Aa;c[I>>2]=za;ra=DUa(c[q>>2]|0)|0;q=DUa(c[g>>2]|0)|0;g=DUa(c[s>>2]|0)|0;s=DUa(c[v>>2]|0)|0;v=DUa(c[y>>2]|0)|0;y=DUa(c[D>>2]|0)|0;D=DUa(c[G>>2]|0)|0;G=DUa(c[J>>2]|0)|0;J=40;F=ta;ta=ua;ua=va;va=wa;wa=xa;xa=ya;ya=Aa;Aa=za;while(1){Ba=(b[i+(J<<1)>>1]|0)-((ca(F,G)|0)+16384>>15)|0;za=Ba-((ca(ta,D)|0)+16384>>15)|0;Ca=((ca(za,D)|0)+16384>>15)+ta|0;C=za-((ca(ua,y)|0)+16384>>15)|0;Da=((ca(C,y)|0)+16384>>15)+ua|0;za=C-((ca(va,v)|0)+16384>>15)|0;Ea=((ca(za,v)|0)+16384>>15)+va|0;C=za-((ca(wa,s)|0)+16384>>15)|0;Fa=((ca(C,s)|0)+16384>>15)+wa|0;za=C-((ca(xa,g)|0)+16384>>15)|0;Ga=((ca(za,g)|0)+16384>>15)+xa|0;C=za-((ca(ya,q)|0)+16384>>15)|0;Ha=((ca(C,q)|0)+16384>>15)+ya|0;Ia=C-((ca(Aa,ra)|0)+16384>>15)|0;Ja=((ca(Ia,ra)|0)+16384>>15)+Aa|0;b[f+(J<<1)>>1]=Ia;C=J+1|0;if((C|0)<160){J=C;F=Ca;ta=Da;ua=Ea;va=Fa;wa=Ga;xa=Ha;ya=Ja;Aa=Ia}else{break}}Aa=((ca(Ba,G)|0)+16384>>15)+F|0;c[l>>2]=Ca;c[Y>>2]=Aa;c[K>>2]=Da;c[L>>2]=Ea;c[M>>2]=Fa;c[N>>2]=Ga;c[O>>2]=Ha;c[P>>2]=Ja;c[I>>2]=Ia;c[j>>2]=o;o=a+664|0;a=c[o>>2]|0;j=0;do{Ia=f+(j<<1)|0;I=((a*28180|0)+16384>>15)+(b[Ia>>1]|0)|0;if((I+32768|0)>>>0>65535>>>0){Ka=(I>>31^32767)&65535}else{Ka=I&65535}a=Ka<<16>>16;I=a<<1;if((I+32768|0)>>>0>65535>>>0){La=(a>>30^32767)&65535}else{La=I&65535}b[Ia>>1]=La&-8;j=j+1|0;}while((j|0)<160);c[o>>2]=a;return}function DUa(a){a=a|0;var b=0,c=0;b=(a|0)>-1?a:-a|0;do{if((b|0)<11059){c=b<<1}else{if((b|0)<20070){c=b+11059|0;break}else{c=(b>>2)+26112|0;break}}}while(0);return((a|0)<0?-c|0:c)|0}function EUa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=tIb(c[a+120>>2]|0,c[a+124>>2]|0,0,a)|0;if((d|0)<0){e=d;return e|0}if((Vga(a)|0)<0){e=-1;return e|0}Crb(b);if((c[1825690]|0)==0){ATa(1314512,6216944);ATa(1314704,6217334);ATa(1314896,6217724);ATa(1315088,6218114);ATa(1315280,6218504);ATa(1315472,6218894);c[328640]=6691424;c[328642]=642;a=c[328630]|0;$2(1314556,9,(c[328628]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[328644]|0)==0){a=0;do{c[1314576+(a<<2)>>2]=7220584+(a*2568|0);a=a+1|0;}while((a|0)<32);BTa(1314512)}c[328688]=6627344;c[328690]=1104;a=c[328678]|0;$2(1314748,9,(c[328676]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[328692]|0)==0){a=0;do{c[1314768+(a<<2)>>2]=7079272+(a*4416|0);a=a+1|0;}while((a|0)<32);BTa(1314704)}c[328736]=6587072;c[328738]=554;a=c[328726]|0;$2(1314940,9,(c[328724]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[328740]|0)==0){a=0;do{c[1314960+(a<<2)>>2]=7008360+(a*2216|0);a=a+1|0;}while((a|0)<32);BTa(1314896)}c[328784]=6583312;c[328786]=940;a=c[328774]|0;$2(1315132,9,(c[328772]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[328788]|0)==0){a=0;do{c[1315152+(a<<2)>>2]=6888040+(a*3760|0);a=a+1|0;}while((a|0)<32);BTa(1315088)}c[328832]=6579464;c[328834]=962;a=c[328822]|0;$2(1315324,9,(c[328820]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[328836]|0)==0){a=0;do{c[1315344+(a<<2)>>2]=6764904+(a*3848|0);a=a+1|0;}while((a|0)<32);BTa(1315280)}c[328880]=6689208;c[328882]=554;a=c[328870]|0;$2(1315516,9,(c[328868]|0)+1|0,a+2|0,4,2,a,4,2,0,0,0,4)|0;if((c[328884]|0)==0){a=0;do{c[1315536+(a<<2)>>2]=6693992+(a*2216|0);a=a+1|0;}while((a|0)<32);BTa(1315472)}c[335049]=6674352;c[335051]=3714;$2(1340192,9,(c[335042]|0)+1|0,c[335044]|0,1,1,c[335043]|0,2,2,0,0,0,4)|0;c[335060]=6663576;c[335062]=2694;$2(1340236,9,(c[335053]|0)+1|0,c[335055]|0,1,1,c[335054]|0,2,2,0,0,0,4)|0;c[1825699]=6658944;c[1825701]=1158;$2(7302792,9,120,1295788,8,4,1295784,8,4,0,0,0,4)|0;c[1825709]=6654472;c[1825711]=1118;$2(7302832,9,120,1296748,8,4,1296744,8,4,0,0,0,4)|0;c[1825704]=6648568;c[1825706]=1476;$2(7302812,9,120,1293868,8,4,1293864,8,4,0,0,0,4)|0;c[1825714]=6643704;c[1825716]=1216;$2(7302852,9,120,1294828,8,4,1294824,8,4,0,0,0,4)|0;c[847021]=6637816;c[847023]=1472;$2(3388080,9,512,6208756,8,4,6208752,8,4,0,0,0,4)|0;c[847027]=6631792;c[847029]=1506;$2(3388104,9,512,6212852,8,4,6212848,8,4,0,0,0,4)|0;c[847015]=6631760;c[847017]=8;$2(3388056,3,4,1275305,2,1,1275304,2,1,0,0,0,4)|0;c[847009]=6626832;c[847011]=128;$2(3388032,7,8,1275289,2,1,1275288,2,1,0,0,0,4)|0;c[847003]=6624680;c[847005]=538;$2(3388008,9,33,1339809,2,1,1339808,2,1,0,0,0,4)|0;c[1924131]=6618136;c[1924133]=1636;a=c[311574]|0;$2(7696520,9,128,a+4|0,8,4,a,8,4,0,0,0,4)|0;c[1924136]=6607544;c[1924138]=2648;a=c[311575]|0;$2(7696540,9,128,a+4|0,8,4,a,8,4,0,0,0,4)|0;c[1924141]=6601416;c[1924143]=1532;a=c[311576]|0;$2(7696560,9,128,a+4|0,8,4,a,8,4,0,0,0,4)|0;c[1924146]=6591464;c[1924148]=2488;a=c[311577]|0;$2(7696580,9,128,a+4|0,8,4,a,8,4,0,0,0,4)|0;c[1825693]=6589320;c[1825695]=536;$2(7302768,9,64,1341754,4,2,1341752,4,2,0,0,0,4)|0;c[2055613]=6589288;c[2055615]=8;$2(8222448,3,4,1293753,2,1,1293752,2,1,0,0,0,4)|0;c[1825690]=1}switch(c[b+14092>>2]|0){case 1:case 2:{c[b+14348>>2]=662;break};case 5:{c[b+14348>>2]=244;break};case 3:case 4:{c[b+14348>>2]=154;break};default:{}}c[b+14080>>2]=c[b+120>>2];e=0;return e|0}function FUa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=a+12476|0;k=c[j>>2]|0;l=a+12480|0;m=c[l>>2]|0;n=(ca(c[a+124>>2]|0,m)|0)+k|0;o=(c[a+9160>>2]|0)+(n<<2)|0;n=(c[a+9992>>2]|0)==2;do{if(n){do{if((c[a+14076>>2]|0)!=0){p=a+14128|0;q=c[p>>2]|0;r=d[(c[a+14120>>2]|0)+(q>>>3)|0]|0;c[p>>2]=((q|0)<(c[a+14136>>2]|0))+q;if((r&128>>>((q&7)>>>0)|0)==0){break}c[a+12488>>2]=0;mrc(a+180|0,-1|0,24)|0;c[a+11736>>2]=1;c[a+11740>>2]=0;c[a+11744>>2]=0;c[a+11748>>2]=0;c[a+9924>>2]=1;c[o>>2]=14344;s=0;i=f;return s|0}}while(0);q=c[a+14092>>2]|0;r=a+14120|0;if((q|0)==2){p=c[847009]|0;t=a+14128|0;u=c[t>>2]|0;v=c[a+14136>>2]|0;w=c[r>>2]|0;x=w+(u>>>3)|0;y=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>25;x=b[p+(y<<2)>>1]|0;z=(b[p+(y<<2)+2>>1]|0)+u|0;u=v>>>0>z>>>0?z:v;c[t>>2]=u;A=x;B=u;C=v;D=w}else{w=c[2055821]|0;v=a+14128|0;u=c[v>>2]|0;x=c[a+14136>>2]|0;t=c[r>>2]|0;r=t+(u>>>3)|0;z=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(u&7)>>>25;r=b[w+(z<<2)>>1]|0;y=b[w+(z<<2)+2>>1]|0;z=y<<16>>16;if(y<<16>>16<0){y=u+7|0;p=x>>>0>y>>>0?y:x;y=t+(p>>>3)|0;E=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(p&7)>>>((z+32|0)>>>0))+r|0;F=b[w+(E<<2)+2>>1]|0;G=b[w+(E<<2)>>1]|0;H=p}else{F=z;G=r;H=u}u=F+H|0;r=x>>>0>u>>>0?u:x;c[v>>2]=r;A=G;B=r;C=x;D=t}if(A>>>0>7>>>0){KIb(c[a+4>>2]|0,16,2240888,(I=i,i=i+24|0,c[I>>2]=A,c[I+8>>2]=k,c[I+16>>2]=m,I)|0);i=I;s=-1;i=f;return s|0}t=A>>2;c[a+12488>>2]=t;x=A&3;if((t|0)!=0){J=q;K=D;L=C;M=B;N=x;O=24;break}t=c[2093353]|0;r=D+(B>>>3)|0;v=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(B&7)>>>26;r=b[t+(v<<2)>>1]|0;u=(b[t+(v<<2)+2>>1]|0)+B|0;c[a+14128>>2]=C>>>0>u>>>0?u:C;if(r<<16>>16<0){KIb(c[a+4>>2]|0,16,2235176,(I=i,i=i+24|0,c[I>>2]=x,c[I+8>>2]=k,c[I+16>>2]=m,I)|0);i=I;s=-1;i=f;return s|0}u=r<<16>>16<<2|x;if((q|0)==1){O=22}else{if((A&3|0)==3){P=u}else{O=22}}if((O|0)==22){P=u^60}Rga(a,0,0,g,h)|0;c[g>>2]=LUa(a,c[g>>2]|0)|0;u=LUa(a,c[h>>2]|0)|0;c[h>>2]=u;c[a+11736>>2]=1;c[a+11740>>2]=0;c[a+11744>>2]=c[g>>2];c[a+11748>>2]=u;Q=P;R=12296}else{c[a+12488>>2]=1;u=c[a+14092>>2]|0;q=a+14120|0;if((u|0)==2){x=c[847015]|0;r=a+14128|0;v=c[r>>2]|0;t=c[a+14136>>2]|0;z=c[q>>2]|0;p=z+(v>>>3)|0;E=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(v&7)>>>29;p=b[x+(E<<2)>>1]|0;w=(b[x+(E<<2)+2>>1]|0)+v|0;v=t>>>0>w>>>0?w:t;c[r>>2]=v;S=p;T=v;U=t;V=z}else{z=c[2055815]|0;t=a+14128|0;v=c[t>>2]|0;p=c[a+14136>>2]|0;r=c[q>>2]|0;q=r+(v>>>3)|0;w=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(v&7)>>>26;q=b[z+(w<<2)>>1]|0;E=(b[z+(w<<2)+2>>1]|0)+v|0;v=p>>>0>E>>>0?E:p;c[t>>2]=v;S=q;T=v;U=p;V=r}r=S<<16>>16;if(!((S&65535)>>>0>3>>>0)){J=u;K=V;L=U;M=T;N=r;O=24;break}KIb(c[a+4>>2]|0,16,2240888,(I=i,i=i+24|0,c[I>>2]=r,c[I+8>>2]=k,c[I+16>>2]=m,I)|0);i=I;s=-1;i=f;return s|0}}while(0);do{if((O|0)==24){if((J|0)==2){m=a+14128|0;k=d[K+(M>>>3)|0]<<(M&7)>>>7;T=((M|0)<(L|0))+M|0;c[m>>2]=T;c[a+176>>2]=k&1;k=c[2093353]|0;U=K+(T>>>3)|0;V=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(T&7)>>>26;U=b[k+(V<<2)>>1]|0;S=(b[k+(V<<2)+2>>1]|0)+T|0;c[m>>2]=L>>>0>S>>>0?S:L;Q=U<<2|N;R=1;break}c[a+176>>2]=0;U=c[2093353]|0;S=K+(M>>>3)|0;m=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(M&7)>>>26;S=b[U+(m<<2)>>1]|0;T=(b[U+(m<<2)+2>>1]|0)+M|0;c[a+14128>>2]=L>>>0>T>>>0?T:L;T=S<<2|N;if(!n){Q=T;R=1;break}Q=T^60;R=1}}while(0);c[o>>2]=R;qe[c[a+10096>>2]&1023](c[a+14340>>2]|0);R=0;while(1){if((R|0)>=6){s=0;O=32;break}if((JUa(a,e+(R<<7)|0,R,Q>>>((5-R|0)>>>0)&1,0)|0)<0){break}else{R=R+1|0}}if((O|0)==32){i=f;return s|0}O=c[l>>2]|0;KIb(c[a+4>>2]|0,16,2251424,(I=i,i=i+24|0,c[I>>2]=c[j>>2],c[I+8>>2]=O,c[I+16>>2]=R,I)|0);i=I;s=-1;i=f;return s|0}function GUa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=e+12476|0;m=e+12480|0;n=(ca(c[e+124>>2]|0,c[m>>2]|0)|0)+(c[l>>2]|0)|0;o=(c[e+9160>>2]|0)+(n<<2)|0;do{if((c[e+9992>>2]|0)==2){n=e+14128|0;p=c[n>>2]|0;do{if((c[e+14076>>2]|0)==0){q=p;r=c[e+14136>>2]|0;s=c[e+14120>>2]|0}else{t=c[e+14120>>2]|0;u=d[t+(p>>>3)|0]|0;v=c[e+14136>>2]|0;w=((p|0)<(v|0))+p|0;c[n>>2]=w;if((u&128>>>((p&7)>>>0)|0)==0){q=w;r=v;s=t;break}c[e+12488>>2]=0;mrc(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11744>>2]=0;c[e+11748>>2]=0;c[e+9924>>2]=1;c[o>>2]=14344;x=0;i=g;return x|0}}while(0);p=c[1924146]|0;n=e+14128|0;t=s+(q>>>3)|0;v=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(q&7)>>>23;t=b[p+(v<<2)>>1]|0;w=b[p+(v<<2)+2>>1]|0;v=w<<16>>16;do{if(w<<16>>16<0){u=q+9|0;y=r>>>0>u>>>0?u:r;u=s+(y>>>3)|0;z=((je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(y&7)>>>((v+32|0)>>>0))+t|0;u=b[p+(z<<2)>>1]|0;A=b[p+(z<<2)+2>>1]|0;z=A<<16>>16;if(!(A<<16>>16<0)){B=z;C=u;D=y;break}A=y-v|0;y=r>>>0>A>>>0?A:r;A=s+(y>>>3)|0;E=((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7)>>>((z+32|0)>>>0))+u|0;B=b[p+(E<<2)+2>>1]|0;C=b[p+(E<<2)>>1]|0;D=y}else{B=v;C=t;D=q}}while(0);t=B+D|0;c[n>>2]=r>>>0>t>>>0?t:r;if((C|0)<0){x=-1;i=g;return x|0}else{t=C>>>6&1^1;c[e+12488>>2]=t;F=C&63;G=t;break}}else{t=e+12488|0;c[t>>2]=1;v=c[1825693]|0;p=e+14128|0;w=c[p>>2]|0;y=c[e+14136>>2]|0;E=c[e+14120>>2]|0;u=E+(w>>>3)|0;z=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(w&7)>>>23;u=b[v+(z<<2)>>1]|0;A=b[v+(z<<2)+2>>1]|0;z=A<<16>>16;if(A<<16>>16<0){A=w+9|0;H=y>>>0>A>>>0?A:y;A=E+(H>>>3)|0;E=((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(H&7)>>>((z+32|0)>>>0))+u|0;I=b[v+(E<<2)+2>>1]|0;J=b[v+(E<<2)>>1]|0;K=H}else{I=z;J=u;K=w}w=I+K|0;c[p>>2]=y>>>0>w>>>0?w:y;if((J|0)<0){x=-1;i=g;return x|0}else{y=(Drb(e,0,h)|0)^J>>>5&1;a[c[h>>2]|0]=y;w=(Drb(e,1,h)|0)^J>>>4&1;a[c[h>>2]|0]=w;p=(Drb(e,2,h)|0)^J>>>3&1;a[c[h>>2]|0]=p;u=(Drb(e,3,h)|0)^J>>>2&1;a[c[h>>2]|0]=u;F=J&1|(J&2|(u<<2|(p<<3|(w<<4|y<<5))));G=c[t>>2]|0;break}}}while(0);do{if((G|0)==0){if(!((c[e+14096>>2]|0)==0|(F|0)==0)){J=e+14128|0;h=c[J>>2]|0;K=c[e+14120>>2]|0;I=d[K+(h>>>3)|0]|0;C=c[e+14136>>2]|0;r=((h|0)<(C|0))+h|0;c[J>>2]=r;if((I&128>>>((h&7)>>>0)|0)==0){L=0}else{h=d[K+(r>>>3)|0]<<(r&7)>>>7;c[J>>2]=((r|0)<(C|0))+r;L=(h&1)+1|0}c[e+14064>>2]=L;c[e+14068>>2]=L}Rga(e,0,0,j,k)|0;if((KUa(e,j,k)|0)<0){x=-1;i=g;return x|0}else{c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11744>>2]=c[j>>2];c[e+11748>>2]=c[k>>2];c[o>>2]=12296;break}}else{h=e+14128|0;r=c[h>>2]|0;C=c[e+14120>>2]|0;J=d[C+(r>>>3)|0]<<(r&7)>>>7;K=e+14136|0;c[h>>2]=((r|0)<(c[K>>2]|0))+r;c[e+176>>2]=J&1;c[o>>2]=1;if((c[e+14112>>2]|0)!=0){J=c[2055613]|0;r=c[h>>2]|0;I=c[K>>2]|0;D=C+(r>>>3)|0;B=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(r&7)>>>29;D=b[J+(B<<2)>>1]|0;q=(b[J+(B<<2)+2>>1]|0)+r|0;c[h>>2]=I>>>0>q>>>0?q:I;c[e+13820>>2]=D}if((c[e+14096>>2]|0)==0|(F|0)==0){break}D=c[h>>2]|0;I=d[C+(D>>>3)|0]|0;q=c[K>>2]|0;K=((D|0)<(q|0))+D|0;c[h>>2]=K;if((I&128>>>((D&7)>>>0)|0)==0){M=0}else{D=d[C+(K>>>3)|0]<<(K&7)>>>7;c[h>>2]=((K|0)<(q|0))+K;M=(D&1)+1|0}c[e+14064>>2]=M;c[e+14068>>2]=M}}while(0);qe[c[e+10096>>2]&1023](c[e+14340>>2]|0);M=0;while(1){if((M|0)>=6){x=0;N=31;break}if((JUa(e,f+(M<<7)|0,M,F>>>((5-M|0)>>>0)&1,0)|0)<0){break}else{M=M+1|0}}if((N|0)==31){i=g;return x|0}N=c[m>>2]|0;KIb(c[e+4>>2]|0,16,2251424,(e=i,i=i+24|0,c[e>>2]=c[l>>2],c[e+8>>2]=N,c[e+16>>2]=M,e)|0);i=e;x=-1;i=g;return x|0}function HUa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=i;e=c[a+14092>>2]|0;f=(e|0)==1;g=a+14128|0;h=c[g>>2]|0;j=c[a+14136>>2]|0;k=c[a+14120>>2]|0;do{if(f){l=k+(h>>>3)|0;m=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(h&7)&-65536;l=h+16|0;n=j>>>0>l>>>0?l:j;c[g>>2]=n;l=k+(n>>>3)|0;o=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(n&7)>>>16;l=n+16|0;n=j>>>0>l>>>0?l:j;c[g>>2]=n;if((o|m|0)==256){m=n+5|0;n=j>>>0>m>>>0?m:j;c[g>>2]=n;p=n;break}KIb(c[a+4>>2]|0,16,2496272,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1;i=b;return r|0}else{p=h}}while(0);h=a+14128|0;g=a+14136|0;n=a+14120|0;m=k+(p>>>3)|0;o=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>30;m=p+2|0;p=j>>>0>m>>>0?m:j;c[h>>2]=p;m=o+1|0;c[a+9992>>2]=m;if(!((o|0)==0|(m|0)==2)){KIb(c[a+4>>2]|0,16,2388896,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1;i=b;return r|0}m=k+(p>>>3)|0;l=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>27;m=p+5|0;p=j>>>0>m>>>0?m:j;c[h>>2]=p;m=a+9960|0;c[m>>2]=l;c[a+9964>>2]=l;if((l|0)==0){KIb(c[a+4>>2]|0,16,2381968,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1;i=b;return r|0}do{if((o|0)==0){s=k+(p>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(p&7);s=t>>>27;u=p+5|0;v=j>>>0>u>>>0?u:j;c[h>>2]=v;a:do{if(f){do{if((s|0)!=0){if((s|0)>(c[a+120>>2]|0)){break}c[a+14080>>2]=s;break a}}while(0);KIb(c[a+4>>2]|0,16,2375368,(q=i,i=i+8|0,c[q>>2]=s,q)|0);i=q;r=-1;i=b;return r|0}else{if(!(t>>>0<3087007744>>>0)){c[a+14080>>2]=(c[a+120>>2]|0)/(s-22|0)|0;break}KIb(c[a+4>>2]|0,16,2368664,(q=i,i=i+8|0,c[q>>2]=s,q)|0);i=q;r=-1;i=b;return r|0}}while(0);if((e|0)==3){s=d[k+(v>>>3)|0]|0;t=((v|0)<(j|0))+v|0;c[h>>2]=t;if((s&128>>>((v&7)>>>0)|0)==0){w=0;x=t}else{s=(d[k+(t>>>3)|0]|0)<<(t&7)>>>7;u=((t|0)<(j|0))+t|0;c[h>>2]=u;w=(s&1)+1|0;x=u}c[a+14068>>2]=w;u=d[k+(x>>>3)|0]|0;s=((x|0)<(j|0))+x|0;c[h>>2]=s;if((u&128>>>((x&7)>>>0)|0)==0){y=0;z=s}else{u=(d[k+(s>>>3)|0]|0)<<(s&7)>>>7;t=((s|0)<(j|0))+s|0;c[h>>2]=t;y=(u&1)+1|0;z=t}c[a+14064>>2]=y;t=(d[k+(z>>>3)|0]|0)<<(z&7)>>>7;c[h>>2]=((z|0)<(j|0))+z;c[a+14072>>2]=t&1}else if((e|0)==4){IUa(a,4)|0;do{if((c[a+24>>2]|0)>51200){t=c[h>>2]|0;u=(d[(c[n>>2]|0)+(t>>>3)|0]|0)<<(t&7)>>>7;c[h>>2]=((t|0)<(c[g>>2]|0))+t;t=u&1;c[a+14096>>2]=t;if((t|0)==0){A=29;break}B=c[h>>2]|0;C=c[n>>2]|0;D=c[g>>2]|0}else{c[a+14096>>2]=0;A=29}}while(0);if((A|0)==29){v=c[h>>2]|0;t=c[n>>2]|0;u=d[t+(v>>>3)|0]|0;s=c[g>>2]|0;E=((v|0)<(s|0))+v|0;c[h>>2]=E;if((u&128>>>((v&7)>>>0)|0)==0){F=0;G=E}else{v=(d[t+(E>>>3)|0]|0)<<(E&7)>>>7;u=((E|0)<(s|0))+E|0;c[h>>2]=u;F=(v&1)+1|0;G=u}c[a+14068>>2]=F;u=d[t+(G>>>3)|0]|0;v=((G|0)<(s|0))+G|0;c[h>>2]=v;if((u&128>>>((G&7)>>>0)|0)==0){H=0;I=v}else{u=(d[t+(v>>>3)|0]|0)<<(v&7)>>>7;E=((v|0)<(s|0))+v|0;c[h>>2]=E;H=(u&1)+1|0;I=E}c[a+14064>>2]=H;B=I;C=t;D=s}s=(d[C+(B>>>3)|0]|0)<<(B&7)>>>7;c[h>>2]=((B|0)<(D|0))+B;c[a+14072>>2]=s&1;c[a+14112>>2]=0}else if((e|0)==1|(e|0)==2){c[a+14068>>2]=2;c[a+14064>>2]=2;c[a+14072>>2]=0}c[a+12472>>2]=1;s=c[a+4>>2]|0;if((c[s+688>>2]&1|0)==0){break}t=c[a+14068>>2]|0;E=c[a+14064>>2]|0;u=c[a+14072>>2]|0;v=c[a+14096>>2]|0;J=c[a+14080>>2]|0;KIb(s,48,2353760,(q=i,i=i+48|0,c[q>>2]=c[m>>2],c[q+8>>2]=t,c[q+16>>2]=E,c[q+24>>2]=u,c[q+32>>2]=v,c[q+40>>2]=J,q)|0);i=q}else{if((e|0)==2){J=(d[k+(p>>>3)|0]|0)<<(p&7)>>>7;c[h>>2]=((p|0)<(j|0))+p;c[a+14076>>2]=J&1;A=40}else if((e|0)==1){c[a+14076>>2]=1;A=40}else if((e|0)==3){J=(d[k+(p>>>3)|0]|0)<<(p&7)>>>7;v=((p|0)<(j|0))+p|0;c[h>>2]=v;c[a+14076>>2]=J&1;J=d[k+(v>>>3)|0]|0;u=((v|0)<(j|0))+v|0;c[h>>2]=u;if((J&128>>>((v&7)>>>0)|0)==0){K=0;L=u}else{v=(d[k+(u>>>3)|0]|0)<<(u&7)>>>7;J=((u|0)<(j|0))+u|0;c[h>>2]=J;K=(v&1)+1|0;L=J}c[a+14064>>2]=K;c[a+14068>>2]=K;J=(d[k+(L>>>3)|0]|0)<<(L&7)>>>7;v=((L|0)<(j|0))+L|0;c[h>>2]=v;c[a+14072>>2]=J&1;J=(d[k+(v>>>3)|0]|0)<<(v&7)>>>7;c[h>>2]=((v|0)<(j|0))+v;c[a+14060>>2]=J&1}else if((e|0)==4){J=(d[k+(p>>>3)|0]|0)<<(p&7)>>>7;v=((p|0)<(j|0))+p|0;c[h>>2]=v;c[a+14076>>2]=J&1;J=c[a+24>>2]|0;if((J|0)>51200){u=(d[k+(v>>>3)|0]|0)<<(v&7)>>>7;E=((v|0)<(j|0))+v|0;c[h>>2]=E;t=u&1;c[a+14096>>2]=t;if((t|0)==0){M=E;A=47}else{N=E}}else{c[a+14096>>2]=0;M=v;A=47}if((A|0)==47){v=d[k+(M>>>3)|0]|0;E=((M|0)<(j|0))+M|0;c[h>>2]=E;if((v&128>>>((M&7)>>>0)|0)==0){O=0;P=E}else{v=(d[k+(E>>>3)|0]|0)<<(E&7)>>>7;t=((E|0)<(j|0))+E|0;c[h>>2]=t;O=(v&1)+1|0;P=t}c[a+14064>>2]=O;c[a+14068>>2]=O;N=P}t=(d[k+(N>>>3)|0]|0)<<(N&7)>>>7;v=((N|0)<(j|0))+N|0;c[h>>2]=v;c[a+14072>>2]=t&1;t=(d[k+(v>>>3)|0]|0)<<(v&7)>>>7;c[h>>2]=((v|0)<(j|0))+v;c[a+14060>>2]=t&1;if((ca(c[a+12>>2]|0,c[a+8>>2]|0)|0)<76800){Q=(J|0)<131073|0}else{Q=0}c[a+14112>>2]=Q}if((A|0)==40){c[a+14064>>2]=2;c[a+14068>>2]=2;c[a+14072>>2]=0;c[a+14060>>2]=0}J=c[a+4>>2]|0;if((c[J+688>>2]&1|0)!=0){t=c[a+14064>>2]|0;v=c[a+14068>>2]|0;E=c[a+14072>>2]|0;u=c[a+14060>>2]|0;s=c[a+14096>>2]|0;KIb(J,48,2345120,(q=i,i=i+56|0,c[q>>2]=c[a+14076>>2],c[q+8>>2]=t,c[q+16>>2]=v,c[q+24>>2]=E,c[q+32>>2]=u,c[q+40>>2]=s,c[q+48>>2]=l,q)|0);i=q}s=a+12472|0;if((c[a+14088>>2]|0)==0){c[s>>2]=0;break}else{c[s>>2]=c[s>>2]^1;break}}}while(0);c[a+14100>>2]=0;c[a+14104>>2]=0;r=0;i=b;return r|0}function IUa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=a+14128|0;g=c[f>>2]|0;h=(b<<3)-g|0;b=c[a+14092>>2]|0;j=(b|0)>2;k=j?17:16;l=(h|0)<(k|8|0);if((h|0)>=(k|0)&l){k=c[a+14136>>2]|0;m=g+5|0;g=k>>>0>m>>>0?m:k;c[f>>2]=g;m=c[a+14120>>2]|0;n=m+(g>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(g&7)>>>21;n=g+11|0;g=k>>>0>n>>>0?n:k;c[f>>2]=g;c[a+24>>2]=o<<10;if(j){j=(d[m+(g>>>3)|0]|0)<<(g&7)>>>7;c[f>>2]=((g|0)<(k|0))+g;c[a+14088>>2]=j&1;i=e;return 0}else{c[a+14088>>2]=0;i=e;return 0}}if(!l){KIb(c[a+4>>2]|0,16,2333456,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;i=e;return 0}c[a+14088>>2]=0;if((b|0)==2){i=e;return 0}KIb(c[a+4>>2]|0,16,2339096,(p=i,i=i+8|0,c[p>>2]=h,p)|0);i=p;i=e;return 0}function JUa(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=e+12488|0;do{if((c[n>>2]|0)==0){o=e+9960|0;p=c[o>>2]|0;q=(c[e+14064>>2]|0)+3|0;if((h|0)!=0){r=c[e+14092>>2]|0;s=(j|0)==0?e+236|0:j;t=-1;u=(r|0)!=2;v=1314512+(q*192|0)|0;w=p-1|1;x=p<<1;y=1314576+(q*192|0)+(p<<2)|0;z=r;A=o;B=52;break}c[e+180+(g<<2)>>2]=-1;C=0;i=k;return C|0}else{o=e+14092|0;r=c[o>>2]|0;p=(g|0)<4;q=e+14120|0;do{if((r|0)<3){if(p){D=c[847021]|0;E=e+14128|0;F=c[E>>2]|0;G=c[e+14136>>2]|0;H=c[q>>2]|0;I=H+(F>>>3)|0;J=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(F&7)>>>23;I=b[D+(J<<2)>>1]|0;K=b[D+(J<<2)+2>>1]|0;J=K<<16>>16;do{if(K<<16>>16<0){L=F+9|0;M=G>>>0>L>>>0?L:G;L=H+(M>>>3)|0;N=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>((J+32|0)>>>0))+I|0;L=b[D+(N<<2)>>1]|0;O=b[D+(N<<2)+2>>1]|0;N=O<<16>>16;if(!(O<<16>>16<0)){P=N;Q=L;R=M;break}O=M-J|0;M=G>>>0>O>>>0?O:G;O=H+(M>>>3)|0;S=((je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(M&7)>>>((N+32|0)>>>0))+L|0;P=b[D+(S<<2)+2>>1]|0;Q=b[D+(S<<2)>>1]|0;R=M}else{P=J;Q=I;R=F}}while(0);F=P+R|0;c[E>>2]=G>>>0>F>>>0?F:G;T=Q}else{F=c[847027]|0;I=e+14128|0;J=c[I>>2]|0;D=c[e+14136>>2]|0;H=c[q>>2]|0;K=H+(J>>>3)|0;M=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(J&7)>>>23;K=b[F+(M<<2)>>1]|0;S=b[F+(M<<2)+2>>1]|0;M=S<<16>>16;do{if(S<<16>>16<0){L=J+9|0;N=D>>>0>L>>>0?L:D;L=H+(N>>>3)|0;O=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(N&7)>>>((M+32|0)>>>0))+K|0;L=b[F+(O<<2)>>1]|0;U=b[F+(O<<2)+2>>1]|0;O=U<<16>>16;if(!(U<<16>>16<0)){V=O;W=L;X=N;break}U=N-M|0;N=D>>>0>U>>>0?U:D;U=H+(N>>>3)|0;Y=((je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(N&7)>>>((O+32|0)>>>0))+L|0;V=b[F+(Y<<2)+2>>1]|0;W=b[F+(Y<<2)>>1]|0;X=N}else{V=M;W=K;X=J}}while(0);J=V+X|0;c[I>>2]=D>>>0>J>>>0?J:D;T=W}if((T|0)<0){J=e+4|0;KIb(c[J>>2]|0,16,2255704,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;c[m>>2]=0;_=-1;$=J;B=36;break}else{aa=T-256|0;B=29;break}}else{J=c[e+14072>>2]|0;if(p){K=c[7302796+(J*20|0)>>2]|0;M=e+14128|0;F=c[M>>2]|0;H=c[e+14136>>2]|0;S=c[q>>2]|0;G=S+(F>>>3)|0;E=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(F&7)>>>23;G=b[K+(E<<2)>>1]|0;N=b[K+(E<<2)+2>>1]|0;E=N<<16>>16;do{if(N<<16>>16<0){Y=F+9|0;L=H>>>0>Y>>>0?Y:H;Y=S+(L>>>3)|0;O=((je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(L&7)>>>((E+32|0)>>>0))+G|0;Y=b[K+(O<<2)>>1]|0;U=b[K+(O<<2)+2>>1]|0;O=U<<16>>16;if(!(U<<16>>16<0)){ba=O;da=Y;ea=L;break}U=L-E|0;L=H>>>0>U>>>0?U:H;U=S+(L>>>3)|0;fa=((je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(L&7)>>>((O+32|0)>>>0))+Y|0;ba=b[K+(fa<<2)+2>>1]|0;da=b[K+(fa<<2)>>1]|0;ea=L}else{ba=E;da=G;ea=F}}while(0);F=ba+ea|0;G=H>>>0>F>>>0?F:H;c[M>>2]=G;ga=da;ha=G;ia=S;ja=H}else{G=c[7302836+(J*20|0)>>2]|0;F=e+14128|0;E=c[F>>2]|0;K=c[e+14136>>2]|0;N=c[q>>2]|0;D=N+(E>>>3)|0;I=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>23;D=b[G+(I<<2)>>1]|0;L=b[G+(I<<2)+2>>1]|0;I=L<<16>>16;do{if(L<<16>>16<0){fa=E+9|0;Y=K>>>0>fa>>>0?fa:K;fa=N+(Y>>>3)|0;O=((je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(Y&7)>>>((I+32|0)>>>0))+D|0;fa=b[G+(O<<2)>>1]|0;U=b[G+(O<<2)+2>>1]|0;O=U<<16>>16;if(!(U<<16>>16<0)){ka=O;la=fa;ma=Y;break}U=Y-I|0;Y=K>>>0>U>>>0?U:K;U=N+(Y>>>3)|0;na=((je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(Y&7)>>>((O+32|0)>>>0))+fa|0;ka=b[G+(na<<2)+2>>1]|0;la=b[G+(na<<2)>>1]|0;ma=Y}else{ka=I;la=D;ma=E}}while(0);E=ka+ma|0;D=K>>>0>E>>>0?E:K;c[F>>2]=D;ga=la;ha=D;ia=N;ja=K}if((ga|0)<0){D=e+4|0;KIb(c[D>>2]|0,16,2255704,(Z=i,i=i+1|0,i=i+7&-8,c[Z>>2]=0,Z)|0);i=Z;c[m>>2]=0;_=-1;$=D;B=36;break}if((ga|0)==0){aa=0;B=29;break}else if((ga|0)==119){D=e+14128|0;E=ia+(ha>>>3)|0;I=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(ha&7)>>>24;E=ha+8|0;G=ja>>>0>E>>>0?E:ja;c[D>>2]=G;E=d[ia+(G>>>3)|0]|0;c[D>>2]=((G|0)<(ja|0))+G;aa=(E&128>>>((G&7)>>>0)|0)==0?I:-I|0;B=29;break}else{I=d[ia+(ha>>>3)|0]|0;c[e+14128>>2]=((ha|0)<(ja|0))+ha;aa=(I&128>>>((ha&7)>>>0)|0)==0?ga:-ga|0;B=29;break}}}while(0);do{if((B|0)==29){do{if((r|0)==1){q=e+9860+((p?0:g-3|0)<<2)|0;I=(c[q>>2]|0)+aa|0;c[q>>2]=I;oa=I}else{I=(Erb(e,g,l,m)|0)+aa|0;if(p){q=(ca(c[e+168>>2]|0,I)|0)&65535;b[c[l>>2]>>1]=q;oa=I;break}else{q=(ca(c[e+172>>2]|0,I)|0)&65535;b[c[l>>2]>>1]=q;oa=I;break}}}while(0);if((oa|0)>=0){pa=oa;break}_=oa;$=e+4|0;B=36}}while(0);if((B|0)==36){r=c[e+9960>>2]|0;KIb(c[$>>2]|0,16,2327984,(Z=i,i=i+16|0,c[Z>>2]=g,c[Z+8>>2]=r,Z)|0);i=Z;pa=(c[e+14112>>2]|0)==0?_:0}do{if(p){r=1314512+((c[e+14064>>2]|0)*192|0)|0;if((pa|0)<=(c[e+168>>2]<<8|0)){qa=r;break}KIb(c[e+4>>2]|0,16,2322184,(Z=i,i=i+8|0,c[Z>>2]=c[e+9960>>2],Z)|0);i=Z;if((c[e+14112>>2]|0)==0){C=-1}else{qa=r;break}i=k;return C|0}else{r=1314512+(((c[e+14068>>2]|0)+3|0)*192|0)|0;if((pa|0)<=(c[e+172>>2]<<8|0)){qa=r;break}KIb(c[e+4>>2]|0,16,2317080,(Z=i,i=i+8|0,c[Z>>2]=c[e+9960>>2],Z)|0);i=Z;if((c[e+14112>>2]|0)==0){C=-1}else{qa=r;break}i=k;return C|0}}while(0);b[f>>1]=pa;p=c[o>>2]|0;r=(p|0)>3;if((h|0)==0){ra=0;break}do{if((c[e+176>>2]|0)==0){sa=e+368|0}else{if((c[m>>2]|0)==0){sa=e+632|0;break}else{sa=e+500|0;break}}}while(0);s=sa;t=0;u=r;v=qa;w=0;x=1;y=qa+64|0;z=p;A=e+9960|0;B=52}}while(0);if((B|0)==52){qa=u&1;u=c[y>>2]|0;y=e+14128|0;sa=c[y>>2]|0;h=c[e+14136>>2]|0;pa=-w|0;_=e+14100|0;$=e+14104|0;oa=c[e+14120>>2]|0;l=t;t=sa;while(1){aa=oa+(t>>>3)|0;ga=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(t&7);aa=ga>>>23;ha=b[u+(aa<<2)>>1]|0;ja=a[u+(aa<<2)+2|0]|0;ia=ja<<24>>24;if(ja<<24>>24<0){ja=ga<<9;la=t+9|0;ma=(ja>>>((ia+32|0)>>>0))+ha|0;ta=b[u+(ma<<2)>>1]|0;ua=ma;va=a[u+(ma<<2)+2|0]|0;wa=ja;xa=h>>>0>la>>>0?la:h}else{ta=ha;ua=aa;va=ia;wa=ga;xa=t}ga=wa<<va;ia=va+xa|0;aa=h>>>0>ia>>>0?ia:h;a:do{if((ta|0)==0){ia=(z|0)==1;if(!(ia|(ga|0)>-1)){ha=aa+1|0;la=h>>>0>ha>>>0?ha:h;ha=ga>>>22&511;ja=b[u+(ha<<2)>>1]|0;ma=a[u+(ha<<2)+2|0]|0;ka=ma<<24>>24;if(ma<<24>>24<0){ma=la+9|0;da=h>>>0>ma>>>0?ma:h;ma=oa+(da>>>3)|0;ea=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(da&7);ma=(ea>>>((ka+32|0)>>>0))+ja|0;ya=ma;za=a[u+(ma<<2)+2|0]|0;Aa=b[u+(ma<<2)>>1]|0;Ba=ea;Ca=da}else{ya=ha;za=ka;Aa=ja;Ba=ga<<1;Ca=la}la=d[u+(ya<<2)+3|0]|0;ja=za+Ca|0;ka=Ba<<za>>31;ha=((ca(a[(c[v+28+(la>>>7<<2)>>2]|0)+(la+63&63)|0]|0,x)|0)+Aa^ka)-ka|0;ka=(h>>>0>ja>>>0?ja:h)+1|0;Da=ha;Ea=la+l|0;Fa=h>>>0>ka>>>0?ka:h;break}do{if(ia){Ga=aa}else{if((ga&1073741824|0)==0){ka=aa+2|0;Ga=h>>>0>ka>>>0?ka:h;break}ka=aa+2|0;la=h>>>0>ka>>>0?ka:h;ka=ga>>>21&511;ha=b[u+(ka<<2)>>1]|0;ja=a[u+(ka<<2)+2|0]|0;da=ja<<24>>24;if(ja<<24>>24<0){ja=la+9|0;ea=h>>>0>ja>>>0?ja:h;ja=oa+(ea>>>3)|0;ma=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ea&7);ja=(ma>>>((da+32|0)>>>0))+ha|0;Ha=ja;Ia=b[u+(ja<<2)>>1]|0;Ja=a[u+(ja<<2)+2|0]|0;Ka=ma;La=ea}else{Ha=ka;Ia=ha;Ja=da;Ka=ga<<2;La=la}la=d[u+(Ha<<2)+3|0]|0;da=Ja+La|0;ha=Ka<<Ja>>31;ka=(h>>>0>da>>>0?da:h)+1|0;Da=(ha^Ia)-ha|0;Ea=l+qa+la+(a[(c[v+36+(la>>>7<<2)>>2]|0)+((Ia|0)/(x|0)|0)|0]|0)|0;Fa=h>>>0>ka>>>0?ka:h;break a}}while(0);ia=oa+(Ga>>>3)|0;ka=(je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0)<<(Ga&7);ia=ka<<1;do{if((z|0)<4){la=Ga+15|0;Ma=ka<<7>>24;Na=ka>>>25&63;Oa=h>>>0>la>>>0?la:h}else{la=Ga+1|0;ha=h>>>0>la>>>0?la:h;la=c[_>>2]|0;if((la|0)==0){do{if((c[A>>2]|0)<8){da=ka>>>28&7;ea=ha+3|0;ma=h>>>0>ea>>>0?ea:h;if((da|0)!=0){Pa=da;Qa=ka<<4;Ra=ma;break}da=ma+1|0;Pa=ka>>>27&1|8;Qa=ka<<5;Ra=h>>>0>da>>>0?da:h}else{if((ia|0)>-1){da=ha;ma=ia;ea=2;do{ea=ea+1|0;ma=ma<<1;ja=da+1|0;da=h>>>0>ja>>>0?ja:h;Sa=(ea|0)<8;}while(Sa&(ma|0)>-1);if(Sa){Ta=ea;Ua=ma;Va=da}else{Pa=ea;Qa=ma;Ra=da;break}}else{Ta=2;Ua=ia;Va=ha}ja=Va+1|0;Pa=Ta;Qa=Ua<<1;Ra=h>>>0>ja>>>0?ja:h}}while(0);c[_>>2]=Pa;ja=(Qa>>>30)+3|0;c[$>>2]=ja;ba=Ra+2|0;T=h>>>0>ba>>>0?ba:h;ba=oa+(T>>>3)|0;Wa=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(T&7);Xa=T;Ya=Pa;Za=ja}else{Wa=ia;Xa=ha;Ya=la;Za=c[$>>2]|0}ja=Wa>>>((32-Za|0)>>>0);T=Wa<<Za;ba=Za+Xa|0;W=(h>>>0>ba>>>0?ba:h)+1|0;ba=T<<1>>>((32-Ya|0)>>>0);X=(h>>>0>W>>>0?W:h)+Ya|0;W=h>>>0>X>>>0?X:h;if((T|0)>=0){Ma=ba;Na=ja;Oa=W;break}Ma=-ba|0;Na=ja;Oa=W}}while(0);ia=ca(Ma,x)|0;W=((Ma|0)>0?w:pa)+ia|0;ia=l+1+Na|0;if((ka|0)>=0){Da=W;Ea=ia;Fa=Oa;break}Da=W;Ea=ia+192|0;Fa=Oa}else{ia=ga>>31;W=aa+1|0;Da=(ta^ia)-ia|0;Ea=(d[u+(ua<<2)+3|0]|0)+l|0;Fa=h>>>0>W>>>0?W:h}}while(0);if((Ea|0)>62){break}b[f+(d[s+Ea|0]<<1)>>1]=Da;l=Ea;t=Fa}t=Ea-192|0;do{if(t>>>0>63>>>0){l=(c[e+14132>>2]|0)-sa|0;do{if((Ea|0)==64){if(!(((Da|0)/(x|0)|0|0)==-1)){B=87;break}if((l|0)>-1){B=89}}else{B=87}}while(0);if((B|0)==87){if((c[e+13740>>2]&131074|0)==0&(l|0)>-1){B=89}}if((B|0)==89){h=c[e+12480>>2]|0;KIb(c[e+4>>2]|0,16,2312648,(Z=i,i=i+16|0,c[Z>>2]=c[e+12476>>2],c[Z+8>>2]=h,Z)|0);i=Z;_a=63;break}h=c[e+12480>>2]|0;KIb(c[e+4>>2]|0,16,2307968,(Z=i,i=i+16|0,c[Z>>2]=c[e+12476>>2],c[Z+8>>2]=h,Z)|0);i=Z;C=-1;i=k;return C|0}else{b[f+(d[s+t|0]<<1)>>1]=Da;_a=t}}while(0);c[y>>2]=Fa;ra=_a}if((c[n>>2]|0)==0){$a=ra}else{MRa(e,f,g,c[m>>2]|0);$a=(c[e+176>>2]|0)==0?ra:63}c[e+180+(g<<2)>>2]=(c[e+14092>>2]|0)>3&($a|0)>0?63:$a;C=0;i=k;return C|0}function KUa(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[a+14060>>2]|0;j=c[1340196+(h*44|0)>>2]|0;k=a+14128|0;l=c[k>>2]|0;m=c[a+14136>>2]|0;n=c[a+14120>>2]|0;o=n+(l>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>23;o=b[j+(p<<2)>>1]|0;q=b[j+(p<<2)+2>>1]|0;p=q<<16>>16;if(q<<16>>16<0){q=l+9|0;r=m>>>0>q>>>0?q:m;q=n+(r>>>3)|0;s=((je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>((p+32|0)>>>0))+o|0;t=b[j+(s<<2)+2>>1]|0;u=b[j+(s<<2)>>1]|0;v=r}else{t=p;u=o;v=l}l=t+v|0;v=m>>>0>l>>>0?l:m;c[k>>2]=v;if((u|0)<0){l=c[a+12480>>2]|0;KIb(c[a+4>>2]|0,16,2302864,(t=i,i=i+16|0,c[t>>2]=c[a+12476>>2],c[t+8>>2]=l,t)|0);i=t;w=-1;i=g;return w|0}if((u|0)==(c[1340168+(h*44|0)>>2]|0)){t=n+(v>>>3)|0;l=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>26;t=v+6|0;v=m>>>0>t>>>0?t:m;c[k>>2]=v;t=n+(v>>>3)|0;n=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>26;t=v+6|0;c[k>>2]=m>>>0>t>>>0?t:m;x=n;y=l}else{x=d[(c[1340184+(h*44|0)>>2]|0)+u|0]|0;y=d[(c[1340180+(h*44|0)>>2]|0)+u|0]|0}u=y-32+(c[e>>2]|0)|0;y=x-32+(c[f>>2]|0)|0;if((u|0)<-63){z=u+64|0}else{z=(u|0)>63?u-64|0:u}if((y|0)<-63){A=y+64|0}else{A=(y|0)>63?y-64|0:y}c[e>>2]=z;c[f>>2]=A;w=0;i=g;return w|0}function LUa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[847003]|0;g=a+14128|0;h=c[g>>2]|0;i=c[a+14136>>2]|0;j=c[a+14120>>2]|0;a=j+(h>>>3)|0;k=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(h&7)>>>23;a=b[f+(k<<2)>>1]|0;l=b[f+(k<<2)+2>>1]|0;k=l<<16>>16;if(l<<16>>16<0){l=h+9|0;m=i>>>0>l>>>0?l:i;l=j+(m>>>3)|0;n=((je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>((k+32|0)>>>0))+a|0;o=b[f+(n<<2)+2>>1]|0;p=b[f+(n<<2)>>1]|0;q=m}else{o=k;p=a;q=h}h=o+q|0;q=i>>>0>h>>>0?h:i;c[g>>2]=q;if((p|0)<0){r=65535;return r|0}if((p|0)==0){r=e;return r|0}h=d[j+(q>>>3)|0]|0;c[g>>2]=((q|0)<(i|0))+q;i=((h&128>>>((q&7)>>>0)|0)==0?p:-p|0)+e|0;if(!((i|0)<-63)){return((i|0)>63?i-64|0:i)|0}r=i+64|0;return r|0}function MUa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b|0;f=c[e>>2]|0;g=b+4|0;h=c[g>>2]|0;i=(h|0)>1;if((d|0)==0){if(i){j=h-1|0;k=f<<1;c[e>>2]=k;c[g>>2]=j;return}else{l=je(f<<h|0)|0;m=b+12|0;n=c[m>>2]|0;y=l;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;j=h+31|0;k=0;c[e>>2]=k;c[g>>2]=j;return}}if(i){o=h-1|0;p=f<<1|1}else{i=je(1>>>((1-h|0)>>>0)|f<<h|0)|0;f=b+12|0;m=c[f>>2]|0;y=i;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;o=h+31|0;p=1}c[e>>2]=p;c[g>>2]=o;h=(d|0)>1|0;if((o|0)>1){j=o-1|0;k=p<<1|h;c[e>>2]=k;c[g>>2]=j;return}else{d=je(h>>>((1-o|0)>>>0)|p<<o|0)|0;p=b+12|0;b=c[p>>2]|0;y=d;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;j=o+31|0;k=h;c[e>>2]=k;c[g>>2]=j;return}}function NUa(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;Crb(f);if((c[f+14092>>2]|0)>3){c[f+13080>>2]=-255;c[f+13084>>2]=255}if(a[1341744]|0){return}a[1341744]=1;f=hJb(8192)|0;c[335047]=f;g=c[335042]|0;h=g&65535;i=0;do{b[f+(i<<1)>>1]=h;i=i+1|0;}while((i|0)<4096);if((g|0)>0){i=c[335045]|0;h=c[335046]|0;j=0;do{b[f+((d[h+j|0]|d[i+j|0]<<6)<<1)>>1]=j;j=j+1|0;}while((j|0)<(g|0))}g=hJb(8192)|0;c[335058]=g;j=c[335053]|0;i=j&65535;h=0;do{b[g+(h<<1)>>1]=i;h=h+1|0;}while((h|0)<4096);if((j|0)>0){h=c[335056]|0;i=c[335057]|0;f=0;do{b[g+((d[i+f|0]|d[h+f|0]<<6)<<1)>>1]=f;f=f+1|0;}while((f|0)<(j|0))}ATa(1314512,6216944);ATa(1314704,6217334);ATa(1314896,6217724);ATa(1315088,6218114);ATa(1315280,6218504);ATa(1315472,6218894);j=0;do{f=1314512+(j*192|0)|0;h=1314520+(j*192|0)|0;i=1;do{g=i-1|0;k=0;do{l=c[f>>2]|0;m=0;do{n=c[1314532+(j*192|0)+(m<<2)>>2]|0;o=d[n+k|0]|0;p=c[1314540+(j*192|0)+(m<<2)>>2]|0;q=a[p+k|0]|0;do{if((o|0)<(l|0)){if((q<<24>>24|0)<(i|0)){r=20;break}s=g+o|0;t=c[h>>2]|0;u=e[t+(s<<2)+2>>1]|0;if((s|0)==(l|0)){v=t;w=u;r=22;break}x=u+1&255}else{r=20}}while(0);if((r|0)==20){r=0;u=c[h>>2]|0;v=u;w=e[u+(l<<2)+2>>1]|0;r=22}a:do{if((r|0)==22){r=0;u=q<<24>>24;t=i-u|0;do{if((t|0)>=1){if((o|0)>=(l|0)|(u|0)<(t|0)){break}s=o-1+t|0;if((s|0)==(l|0)){break}x=w+2+(e[v+(s<<2)+2>>1]|0)&255;break a}}while(0);t=k-(a[(c[1314548+(j*192|0)+(m<<2)>>2]|0)+i|0]|0)-1|0;do{if((t|0)>=0){u=d[n+t|0]|0;if((u|0)>=(l|0)){break}if((a[p+t|0]|0)<(i|0)){break}s=g+u|0;if((s|0)==(l|0)){break}x=w+3+(e[v+(s<<2)+2>>1]|0)&255;break a}}while(0);x=w+17&255}}while(0);a[5359248+(j*8450|0)+(i*130|0)+(k<<1)+m|0]=x;m=m+1|0;}while((m|0)<2);k=k+1|0;}while((k|0)<65);i=i+1|0;}while((i|0)<65);j=j+1|0;}while((j|0)<6);return}function OUa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;e=b+14108|0;f=b+9992|0;g=2147483647;h=0;i=2147483647;j=0;k=0;while(1){l=(k|0)>0|0;m=k+3|0;n=0;o=l;p=l;while(1){l=0;q=p;r=o;while(1){if((l|0)>=65){s=q;t=r;break}u=c[e>>2]|0;v=(c[f>>2]|0)==1;w=c[u+101400+(n*520|0)+(l<<3)>>2]|0;x=ca(d[5359248+(k*8450|0)+(n*130|0)+(l<<1)|0]|0,c[u+67600+(n*520|0)+(l<<3)>>2]|0)|0;if(v){z=x;A=(ca(d[5359248+(m*8450|0)+(n*130|0)+(l<<1)|0]|0,w)|0)+r|0}else{z=(ca(d[5359248+(m*8450|0)+(n*130|0)+(l<<1)|0]|0,(c[u+33800+(n*520|0)+(l<<3)>>2]|0)+w+(c[u+(n*520|0)+(l<<3)>>2]|0)|0)|0)+x|0;A=r}x=c[u+101400+(n*520|0)+(l<<3)+4>>2]|0;w=ca(d[5359248+(k*8450|0)+(n*130|0)+(l<<1)+1|0]|0,c[u+67600+(n*520|0)+(l<<3)+4>>2]|0)|0;if(v){B=w;C=(ca(d[5359248+(m*8450|0)+(n*130|0)+(l<<1)+1|0]|0,x)|0)+A|0}else{B=(ca(d[5359248+(m*8450|0)+(n*130|0)+(l<<1)+1|0]|0,(c[u+33800+(n*520|0)+(l<<3)+4>>2]|0)+x+(c[u+(n*520|0)+(l<<3)+4>>2]|0)|0)|0)+w|0;C=A}w=z+q+B|0;if((q+r|0)==(w+C|0)){s=w;t=C;break}else{l=l+1|0;q=w;r=C}}r=n+1|0;if((r|0)<65){n=r;o=t;p=s}else{break}}p=(s|0)<(i|0);D=p?k:j;o=(t|0)<(g|0);E=o?k:h;n=k+1|0;if((n|0)<3){g=o?t:g;h=E;i=p?s:i;j=D;k=n}else{break}}k=(c[f>>2]|0)==2?D:E;mrc(c[e>>2]|0,0,135200)|0;e=b+14064|0;c[e>>2]=D;D=b+14068|0;c[D>>2]=k;k=c[f>>2]|0;do{if((k|0)!=(c[b+10004>>2]|0)){c[e>>2]=2;if((k|0)==1){c[D>>2]=1;break}else{c[D>>2]=2;break}}}while(0);k=b+784|0;Y2(k);E=(c[f>>2]|0)-1|0;j=k|0;k=c[j>>2]|0;i=b+788|0;s=c[i>>2]|0;if((s|0)>2){F=s-2|0;G=k<<2|E}else{h=je(E>>>((2-s|0)>>>0)|k<<s|0)|0;k=b+796|0;g=c[k>>2]|0;y=h;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;F=s+30|0;G=E}c[j>>2]=G;c[i>>2]=F;E=c[b+9960>>2]|0;if((F|0)>5){H=F-5|0;I=G<<5|E}else{s=je(G<<F|E>>>((5-F|0)>>>0)|0)|0;G=b+796|0;k=c[G>>2]|0;y=s;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;H=F+27|0;I=E}c[j>>2]=I;c[i>>2]=H;E=b+14092|0;F=c[E>>2]|0;if((F|0)<3){c[e>>2]=2;c[D>>2]=2}G=b+14072|0;c[G>>2]=1;k=b+14060|0;c[k>>2]=1;c[b+14076>>2]=1;s=b+14096|0;c[s>>2]=0;if((F|0)==4){do{if((ca(c[b+12>>2]|0,c[b+8>>2]|0)|0)<76800){if((c[b+24>>2]|0)>=131073){J=0;break}J=(c[f>>2]|0)==2|0}else{J=0}}while(0);c[b+14112>>2]=J}if((c[f>>2]|0)!=1){if((H|0)>1){K=H-1|0;L=I<<1|1;M=F}else{f=je(1>>>((1-H|0)>>>0)|I<<H|0)|0;J=b+796|0;g=c[J>>2]|0;y=f;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[J>>2]=(c[J>>2]|0)+4;K=H+31|0;L=1;M=c[E>>2]|0}c[j>>2]=L;c[i>>2]=K;do{if((M|0)==4){if((c[b+24>>2]|0)<=51200){N=K;O=L;break}J=c[s>>2]|0;if((K|0)>1){P=K-1|0;Q=L<<1|J;R=4}else{g=je(L<<K|J>>>((1-K|0)>>>0)|0)|0;f=b+796|0;h=c[f>>2]|0;y=g;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;P=K+31|0;Q=J;R=c[E>>2]|0}c[j>>2]=Q;c[i>>2]=P;S=R;T=Q;U=P;V=79}else{S=M;T=L;U=K;V=79}}while(0);do{if((V|0)==79){if((S|0)>2){N=U;O=T;break}W=b+14100|0;c[W>>2]=0;X=b+14104|0;c[X>>2]=0;return}}while(0);if((c[s>>2]|0)==0){T=c[e>>2]|0;U=(N|0)>1;do{if((T|0)==0){if(U){Y=N-1|0;Z=O<<1;break}else{S=je(O<<N|0)|0;V=b+796|0;K=c[V>>2]|0;y=S;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[V>>2]=(c[V>>2]|0)+4;Y=N+31|0;Z=0;break}}else{if(U){_=N-1|0;$=O<<1|1}else{V=je(1>>>((1-N|0)>>>0)|O<<N|0)|0;K=b+796|0;S=c[K>>2]|0;y=V;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;c[K>>2]=(c[K>>2]|0)+4;_=N+31|0;$=1}c[j>>2]=$;c[i>>2]=_;K=(T|0)>1|0;if((_|0)>1){Y=_-1|0;Z=$<<1|K;break}else{S=je(K>>>((1-_|0)>>>0)|$<<_|0)|0;V=b+796|0;L=c[V>>2]|0;y=S;a[L]=y;y=y>>8;a[L+1|0]=y;y=y>>8;a[L+2|0]=y;y=y>>8;a[L+3|0]=y;c[V>>2]=(c[V>>2]|0)+4;Y=_+31|0;Z=K;break}}}while(0);c[j>>2]=Z;c[i>>2]=Y;aa=Y;ba=Z}else{aa=N;ba=O}O=c[G>>2]|0;if((aa|0)>1){da=aa-1|0;ea=ba<<1|O}else{N=je(ba<<aa|O>>>((1-aa|0)>>>0)|0)|0;ba=b+796|0;Z=c[ba>>2]|0;y=N;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;c[ba>>2]=(c[ba>>2]|0)+4;da=aa+31|0;ea=O}c[j>>2]=ea;c[i>>2]=da;O=c[k>>2]|0;if((da|0)>1){fa=da-1|0;ga=ea<<1|O}else{k=je(ea<<da|O>>>((1-da|0)>>>0)|0)|0;ea=b+796|0;aa=c[ea>>2]|0;y=k;a[aa]=y;y=y>>8;a[aa+1|0]=y;y=y>>8;a[aa+2|0]=y;y=y>>8;a[aa+3|0]=y;c[ea>>2]=(c[ea>>2]|0)+4;fa=da+31|0;ga=O}c[j>>2]=ga;c[i>>2]=fa;W=b+14100|0;c[W>>2]=0;X=b+14104|0;c[X>>2]=0;return}c[b+14080>>2]=c[b+120>>2];if((H|0)>5){ha=H-5|0;ia=I<<5|23;ja=F}else{F=je(23>>>((5-H|0)>>>0)|I<<H|0)|0;I=b+796|0;fa=c[I>>2]|0;y=F;a[fa]=y;y=y>>8;a[fa+1|0]=y;y=y>>8;a[fa+2|0]=y;y=y>>8;a[fa+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;ha=H+27|0;ia=23;ja=c[E>>2]|0}c[j>>2]=ia;c[i>>2]=ha;if((ja|0)==4){PUa(b);if((c[b+24>>2]|0)>51200){ha=c[s>>2]|0;ia=c[j>>2]|0;H=c[i>>2]|0;if((H|0)>1){ka=H-1|0;la=ia<<1|ha}else{I=je(ha>>>((1-H|0)>>>0)|ia<<H|0)|0;ia=b+796|0;fa=c[ia>>2]|0;y=I;a[fa]=y;y=y>>8;a[fa+1|0]=y;y=y>>8;a[fa+2|0]=y;y=y>>8;a[fa+3|0]=y;c[ia>>2]=(c[ia>>2]|0)+4;ka=H+31|0;la=ha}c[j>>2]=la;c[i>>2]=ka}ma=c[E>>2]|0}else{ma=ja}if((ma|0)<=2){W=b+14100|0;c[W>>2]=0;X=b+14104|0;c[X>>2]=0;return}if((c[s>>2]|0)==0){s=c[D>>2]|0;D=c[j>>2]|0;ma=c[i>>2]|0;ja=(ma|0)>1;do{if((s|0)==0){if(ja){na=ma-1|0;oa=D<<1;break}else{E=je(D<<ma|0)|0;ka=b+796|0;la=c[ka>>2]|0;y=E;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;c[ka>>2]=(c[ka>>2]|0)+4;na=ma+31|0;oa=0;break}}else{if(ja){pa=ma-1|0;qa=D<<1|1}else{ka=je(1>>>((1-ma|0)>>>0)|D<<ma|0)|0;la=b+796|0;E=c[la>>2]|0;y=ka;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[la>>2]=(c[la>>2]|0)+4;pa=ma+31|0;qa=1}c[j>>2]=qa;c[i>>2]=pa;la=(s|0)>1|0;if((pa|0)>1){na=pa-1|0;oa=qa<<1|la;break}else{E=je(la>>>((1-pa|0)>>>0)|qa<<pa|0)|0;ka=b+796|0;ha=c[ka>>2]|0;y=E;a[ha]=y;y=y>>8;a[ha+1|0]=y;y=y>>8;a[ha+2|0]=y;y=y>>8;a[ha+3|0]=y;c[ka>>2]=(c[ka>>2]|0)+4;na=pa+31|0;oa=la;break}}}while(0);c[j>>2]=oa;c[i>>2]=na;pa=c[e>>2]|0;e=(na|0)>1;do{if((pa|0)==0){if(e){ra=na-1|0;sa=oa<<1;break}else{qa=je(oa<<na|0)|0;s=b+796|0;ma=c[s>>2]|0;y=qa;a[ma]=y;y=y>>8;a[ma+1|0]=y;y=y>>8;a[ma+2|0]=y;y=y>>8;a[ma+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;ra=na+31|0;sa=0;break}}else{if(e){ta=na-1|0;ua=oa<<1|1}else{s=je(oa<<na|1>>>((1-na|0)>>>0)|0)|0;ma=b+796|0;qa=c[ma>>2]|0;y=s;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;c[ma>>2]=(c[ma>>2]|0)+4;ta=na+31|0;ua=1}c[j>>2]=ua;c[i>>2]=ta;ma=(pa|0)>1|0;if((ta|0)>1){ra=ta-1|0;sa=ua<<1|ma;break}else{qa=je(ma>>>((1-ta|0)>>>0)|ua<<ta|0)|0;s=b+796|0;D=c[s>>2]|0;y=qa;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;ra=ta+31|0;sa=ma;break}}}while(0);c[j>>2]=sa;c[i>>2]=ra;va=ra;wa=sa}else{va=c[i>>2]|0;wa=c[j>>2]|0}sa=c[G>>2]|0;if((va|0)>1){xa=va-1|0;ya=wa<<1|sa}else{G=je(wa<<va|sa>>>((1-va|0)>>>0)|0)|0;wa=b+796|0;ra=c[wa>>2]|0;y=G;a[ra]=y;y=y>>8;a[ra+1|0]=y;y=y>>8;a[ra+2|0]=y;y=y>>8;a[ra+3|0]=y;c[wa>>2]=(c[wa>>2]|0)+4;xa=va+31|0;ya=sa}c[j>>2]=ya;c[i>>2]=xa;W=b+14100|0;c[W>>2]=0;X=b+14104|0;c[X>>2]=0;return}function PUa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=c[b+4>>2]|0;f=c[e+112>>2]|0;g=((c[e+108>>2]|0)/(c[e+104>>2]|0)|0|0)/(((f|0)>1?f:1)|0)|0;f=g>>>0>31>>>0?31:g;g=b+784|0;e=c[g>>2]|0;h=b+788|0;j=c[h>>2]|0;if((j|0)>5){k=j-5|0;l=e<<5|f}else{m=je(f>>>((5-j|0)>>>0)|e<<j|0)|0;e=b+796|0;n=c[e>>2]|0;y=m;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[e>>2]=(c[e>>2]|0)+4;k=j+27|0;l=f}c[g>>2]=l;c[h>>2]=k;f=c[b+24>>2]|0;if((f|0)>2097151){o=2047}else{o=(f|0)/1024|0}if((k|0)>11){p=k-11|0;q=l<<11|o}else{f=je(l<<k|o>>>((11-k|0)>>>0)|0)|0;l=b+796|0;j=c[l>>2]|0;y=f;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;p=k+21|0;q=o}c[g>>2]=q;c[h>>2]=p;o=c[b+14088>>2]|0;if((c[b+14092>>2]|0)<=2){if((o|0)==0){i=d;return}else{KIb(0,0,2495792,(k=i,i=i+24|0,c[k>>2]=2599584,c[k+8>>2]=2449472,c[k+16>>2]=284,k)|0);i=k;Hd()}}if((p|0)>1){r=p-1|0;s=q<<1|o}else{k=je(q<<p|o>>>((1-p|0)>>>0)|0)|0;q=b+796|0;b=c[q>>2]|0;y=k;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;r=p+31|0;s=o}c[g>>2]=s;c[h>>2]=r;i=d;return}function QUa(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((f|0)<-63){h=f+64|0}else{h=(f|0)>63?f-64|0:f}if((g|0)<-63){i=g+64|0}else{i=(g|0)>63?g-64|0:g}g=h+32|0;h=i+32|0;i=c[b+14060>>2]|0;f=e[(c[1340188+(i*44|0)>>2]|0)+((h|g<<6)<<1)>>1]|0;j=d[(c[1340176+(i*44|0)>>2]|0)+f|0]|0;k=e[(c[1340172+(i*44|0)>>2]|0)+(f<<1)>>1]|0;l=b+784|0;m=c[l>>2]|0;n=b+788|0;o=c[n>>2]|0;if((o|0)>(j|0)){p=o-j|0;q=m<<j|k}else{r=je(k>>>((j-o|0)>>>0)|m<<o|0)|0;m=b+796|0;s=c[m>>2]|0;y=r;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;p=32-j+o|0;q=k}c[l>>2]=q;c[n>>2]=p;if((f|0)!=(c[1340168+(i*44|0)>>2]|0)){return}if((p|0)>6){t=p-6|0;u=q<<6|g}else{i=je(q<<p|g>>>((6-p|0)>>>0)|0)|0;q=b+796|0;f=c[q>>2]|0;y=i;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;t=p+26|0;u=g}c[l>>2]=u;c[n>>2]=t;if((t|0)>6){v=t-6|0;w=u<<6|h}else{g=je(h>>>((6-t|0)>>>0)|u<<t|0)|0;u=b+796|0;b=c[u>>2]|0;y=g;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+26|0;w=h}c[l>>2]=w;c[n>>2]=v;return}function RUa(a){a=a|0;var b=0;if((c[a+12476>>2]|0)!=0){return}b=c[a+14080>>2]|0;do{if((b|0)!=0){if(((c[a+12480>>2]|0)%(b|0)|0|0)!=0){break}if((c[a+14092>>2]|0)<4){FRa(a)}c[a+14084>>2]=1;return}}while(0);c[a+14084>>2]=0;return}function SUa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;a:do{if((c[b+12476>>2]|0)==0){n=c[b+14080>>2]|0;do{if((n|0)!=0){if(((c[b+12480>>2]|0)%(n|0)|0|0)!=0){break}if((c[b+14092>>2]|0)<4){FRa(b)}c[b+14084>>2]=1;break a}}while(0);c[b+14084>>2]=0}}while(0);n=c[b+180>>2]|0;if((c[b+12488>>2]|0)==0){o=(n>>31)+32&-32;p=(c[b+184>>2]|0)>-1?o|16:o;o=(c[b+188>>2]|0)>-1?p|8:p;p=(c[b+192>>2]|0)>-1?o|4:o;o=(c[b+196>>2]|0)>-1?p|2:p;p=o|(c[b+200>>2]|0)>>>31^1;do{if((c[b+14076>>2]|0)!=0){q=b+784|0;r=c[q>>2]|0;s=b+788|0;t=c[s>>2]|0;u=(t|0)>1;if((h|g|p|0)!=0){if(u){v=t-1|0;w=r<<1}else{x=je(r<<t|0)|0;z=b+796|0;A=c[z>>2]|0;y=x;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;v=t+31|0;w=0}c[q>>2]=w;c[s>>2]=v;break}if(u){B=t-1|0;C=r<<1|1}else{u=je(1>>>((1-t|0)>>>0)|r<<t|0)|0;r=b+796|0;z=c[r>>2]|0;y=u;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;B=t+31|0;C=1}c[q>>2]=C;c[s>>2]=B;s=b+13700|0;c[s>>2]=(c[s>>2]|0)+1;s=b+13696|0;c[s>>2]=(c[s>>2]|0)+1;s=b+13692|0;c[s>>2]=(c[s>>2]|0)+1;i=j;return}}while(0);B=b+784|0;if((c[b+14092>>2]|0)<3){C=p&3;v=d[1275289+(C<<1)|0]|0;w=d[1275288+(C<<1)|0]|0;s=B|0;q=c[s>>2]|0;t=b+788|0;r=c[t>>2]|0;if((r|0)>(v|0)){D=r-v|0;E=q<<v|w}else{z=je(w>>>((v-r|0)>>>0)|q<<r|0)|0;q=b+796|0;u=c[q>>2]|0;y=z;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;D=32-v+r|0;E=w}c[s>>2]=E;c[t>>2]=D;w=((C|0)==3?o:o^60)>>2;o=d[1379529+(w<<1)|0]|0;C=d[1379528+(w<<1)|0]|0;if((D|0)>(o|0)){F=D;G=E<<o|C;H=c[b+796>>2]|0}else{w=je(C>>>((o-D|0)>>>0)|E<<D|0)|0;E=b+796|0;r=c[E>>2]|0;y=w;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=(c[E>>2]|0)+4|0;c[E>>2]=r;F=D+32|0;G=C;H=r}r=F-o|0;c[s>>2]=G;c[t>>2]=r;t=(H-(c[b+792>>2]|0)<<3)+(32-r)|0;r=b+13700|0;H=c[r>>2]|0;c[r>>2]=t;r=b+13696|0;c[r>>2]=(c[r>>2]|0)-H+t;Rga(b,0,0,k,l)|0;TUa(b,g-(c[k>>2]|0)|0);TUa(b,h-(c[l>>2]|0)|0)}else{t=p+64|0;p=c[1292732+(t<<3)>>2]|0;H=c[1292728+(t<<3)>>2]|0;t=B|0;B=c[t>>2]|0;r=b+788|0;G=c[r>>2]|0;if((G|0)>(p|0)){I=G-p|0;J=B<<p|H;K=c[b+796>>2]|0}else{s=je(H>>>((p-G|0)>>>0)|B<<G|0)|0;B=b+796|0;o=c[B>>2]|0;y=s;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;o=(c[B>>2]|0)+4|0;c[B>>2]=o;I=32-p+G|0;J=H;K=o}c[t>>2]=J;c[r>>2]=I;r=(K-(c[b+792>>2]|0)<<3)+(32-I)|0;I=b+13700|0;K=c[I>>2]|0;c[I>>2]=r;I=b+13696|0;c[I>>2]=(c[I>>2]|0)-K+r;Rga(b,0,0,k,l)|0;QUa(b,g-(c[k>>2]|0)|0,h-(c[l>>2]|0)|0)}l=b+788|0;h=b+792|0;k=b+796|0;g=((c[k>>2]|0)-(c[h>>2]|0)<<3)+(32-(c[l>>2]|0))|0;r=b+13700|0;K=c[r>>2]|0;c[r>>2]=g;I=b+13664|0;c[I>>2]=(c[I>>2]|0)-K+g;UUa(b,f|0,0);UUa(b,f+128|0,1);UUa(b,f+256|0,2);UUa(b,f+384|0,3);UUa(b,f+512|0,4);UUa(b,f+640|0,5);g=((c[k>>2]|0)-(c[h>>2]|0)<<3)+(32-(c[l>>2]|0))|0;l=c[r>>2]|0;c[r>>2]=g;r=b+13676|0;c[r>>2]=(c[r>>2]|0)-l+g;i=j;return}g=(n|0)>0;n=g&1;l=Drb(b,0,m)|0;a[c[m>>2]|0]=g&1;g=(c[b+184>>2]|0)>0;r=g&1;h=Drb(b,1,m)|0;a[c[m>>2]|0]=g&1;g=(c[b+188>>2]|0)>0;k=g&1;K=Drb(b,2,m)|0;a[c[m>>2]|0]=g&1;g=(c[b+192>>2]|0)>0;I=g&1;J=I<<2|(k<<3|(r<<4|n<<5));t=Drb(b,3,m)|0;a[c[m>>2]|0]=g&1;g=(c[b+196>>2]|0)>0|0;m=(c[b+200>>2]|0)>0|0;o=m|(g<<1|J);H=m|(g<<1|((t^I)<<2|((K^k)<<3|((h^r)<<4|(l^n)<<5))));n=(c[b+9992>>2]|0)==1;do{if((c[b+14092>>2]|0)<3){if(n){l=o&3;r=d[1275305+(l<<1)|0]|0;h=d[1275304+(l<<1)|0]|0;l=b+784|0;k=c[l>>2]|0;K=b+788|0;I=c[K>>2]|0;if((I|0)>(r|0)){L=I-r|0;M=k<<r|h}else{t=je(h>>>((r-I|0)>>>0)|k<<I|0)|0;k=b+796|0;g=c[k>>2]|0;y=t;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;L=32-r+I|0;M=h}c[l>>2]=M;c[K>>2]=L;N=M;O=L}else{K=b+784|0;l=c[K>>2]|0;h=b+788|0;I=c[h>>2]|0;if((c[b+14076>>2]|0)==0){P=l;Q=I}else{if((I|0)>1){R=I-1|0;S=l<<1}else{r=je(l<<I|0)|0;l=b+796|0;k=c[l>>2]|0;y=r;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;R=I+31|0;S=0}c[K>>2]=S;c[h>>2]=R;P=S;Q=R}h=o&3|4;K=d[1275289+(h<<1)|0]|0;I=d[1275288+(h<<1)|0]|0;if((Q|0)>(K|0)){T=Q-K|0;U=P<<K|I}else{h=je(I>>>((K-Q|0)>>>0)|P<<Q|0)|0;l=b+796|0;k=c[l>>2]|0;y=h;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;T=32-K+Q|0;U=I}c[b+784>>2]=U;c[b+788>>2]=T;N=U;O=T}I=b+784|0;K=b+788|0;if((O|0)>1){V=O-1|0;W=N<<1}else{l=je(N<<O|0)|0;k=b+796|0;h=c[k>>2]|0;y=l;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;V=O+31|0;W=0}c[I>>2]=W;c[K>>2]=V;k=J>>>2;h=d[1379529+(k<<1)|0]|0;l=d[1379528+(k<<1)|0]|0;if((V|0)>(h|0)){X=V;Y=W<<h|l}else{k=je(l>>>((h-V|0)>>>0)|W<<V|0)|0;r=b+796|0;g=c[r>>2]|0;y=k;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;X=V+32|0;Y=l}l=X-h|0;c[I>>2]=Y;c[K>>2]=l;Z=l}else{if(n){l=e[1341754+(H<<2)>>1]|0;K=e[1341752+(H<<2)>>1]|0;I=b+784|0;h=c[I>>2]|0;r=b+788|0;g=c[r>>2]|0;if((g|0)>(l|0)){_=g-l|0;$=h<<l|K}else{k=je(K>>>((l-g|0)>>>0)|h<<g|0)|0;h=b+796|0;t=c[h>>2]|0;y=k;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;_=32-l+g|0;$=K}c[I>>2]=$;c[r>>2]=_;aa=$;ba=_}else{r=b+784|0;I=c[r>>2]|0;K=b+788|0;g=c[K>>2]|0;if((c[b+14076>>2]|0)==0){ca=I;da=g}else{if((g|0)>1){ea=g-1|0;fa=I<<1}else{l=je(I<<g|0)|0;I=b+796|0;h=c[I>>2]|0;y=l;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;ea=g+31|0;fa=0}c[r>>2]=fa;c[K>>2]=ea;ca=fa;da=ea}K=c[1292732+(o<<3)>>2]|0;r=c[1292728+(o<<3)>>2]|0;if((da|0)>(K|0)){ga=da-K|0;ha=ca<<K|r}else{g=je(r>>>((K-da|0)>>>0)|ca<<da|0)|0;I=b+796|0;h=c[I>>2]|0;y=g;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;ga=32-K+da|0;ha=r}c[b+784>>2]=ha;c[b+788>>2]=ga;aa=ha;ba=ga}r=b+784|0;K=b+788|0;if((ba|0)>1){ia=ba-1|0;ja=aa<<1}else{I=je(aa<<ba|0)|0;h=b+796|0;g=c[h>>2]|0;y=I;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;ia=ba+31|0;ja=0}c[r>>2]=ja;c[K>>2]=ia;if((c[b+14112>>2]|0)==0){Z=ia;break}c[b+13820>>2]=0;h=d[1293753]|0;g=d[1293752]|0;if((ia|0)>(h|0)){ka=ia-h|0;la=ja<<h|g}else{I=je(g>>>((h-ia|0)>>>0)|ja<<ia|0)|0;l=b+796|0;t=c[l>>2]|0;y=I;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;ka=32-h+ia|0;la=g}c[r>>2]=la;c[K>>2]=ka;Z=ka}}while(0);ka=b+792|0;la=b+796|0;ia=((c[la>>2]|0)-(c[ka>>2]|0)<<3)+(32-Z)|0;Z=b+13700|0;ja=c[Z>>2]|0;c[Z>>2]=ia;ba=b+13696|0;c[ba>>2]=(c[ba>>2]|0)-ja+ia;UUa(b,f|0,0);UUa(b,f+128|0,1);UUa(b,f+256|0,2);UUa(b,f+384|0,3);UUa(b,f+512|0,4);UUa(b,f+640|0,5);f=((c[la>>2]|0)-(c[ka>>2]|0)<<3)+(32-(c[b+788>>2]|0))|0;ka=c[Z>>2]|0;c[Z>>2]=f;Z=b+13672|0;c[Z>>2]=(c[Z>>2]|0)-ka+f;f=b+13680|0;c[f>>2]=(c[f>>2]|0)+1;i=j;return}function TUa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((e|0)==0){f=d[1339809]|0;g=d[1339808]|0;h=b+784|0;i=c[h>>2]|0;j=b+788|0;k=c[j>>2]|0;if((k|0)>(f|0)){l=k-f|0;m=i<<f|g}else{n=je(g>>>((f-k|0)>>>0)|i<<k|0)|0;i=b+796|0;o=c[i>>2]|0;y=n;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=32-f+k|0;m=g}c[h>>2]=m;c[j>>2]=l;return}l=c[b+11556>>2]|0;j=l-1|0;if((e|0)<-63){p=e+64|0}else{p=(e|0)>63?e-64|0:e}e=((p|0)>-1?p:-p|0)-1|0;m=(e>>j)+1|0;h=d[1339809+(m<<1)|0]|0;g=h+1|0;k=(d[1339808+(m<<1)|0]|0)<<1|p>>>31;p=b+784|0;m=c[p>>2]|0;f=b+788|0;i=c[f>>2]|0;if((i|0)>(g|0)){q=i-g|0;r=k|m<<g}else{o=je(k>>>((g-i|0)>>>0)|m<<i|0)|0;m=b+796|0;g=c[m>>2]|0;y=o;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;q=31-h+i|0;r=k}c[p>>2]=r;c[f>>2]=q;if((j|0)<=0){return}k=e&(1<<j)-1;if((q|0)>(j|0)){s=q-j|0;t=r<<j|k}else{e=je(r<<q|k>>>((j-q|0)>>>0)|0)|0;j=b+796|0;b=c[j>>2]|0;y=e;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;s=33-l+q|0;t=k}c[p>>2]=t;c[f>>2]=s;return}function UUa(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;j=i;i=i+16|0;k=j|0;l=f+12488|0;if((c[l>>2]|0)==0){m=c[f+14092>>2]|0;n=0;o=f+236|0;p=(c[f+14064>>2]|0)+3|0;q=(m|0)>2;r=m}else{m=b[g>>1]|0;s=Erb(f,h,k,j+8|0)|0;t=(h|0)<4;if(t){u=(ca(c[f+168>>2]|0,m)|0)&65535;b[c[k>>2]>>1]=u}else{u=(ca(c[f+172>>2]|0,m)|0)&65535;b[c[k>>2]>>1]=u}u=m-s|0;s=f+14092|0;m=c[s>>2]|0;do{if((m|0)<3){k=f+784|0;v=u+256|0;if(t){w=c[6208756+(v<<3)>>2]|0;x=c[6208752+(v<<3)>>2]|0;z=k|0;A=c[z>>2]|0;B=f+788|0;C=c[B>>2]|0;if((C|0)>(w|0)){D=C-w|0;E=A<<w|x}else{F=je(x>>>((w-C|0)>>>0)|A<<C|0)|0;A=f+796|0;G=c[A>>2]|0;y=F;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;D=32-w+C|0;E=x}c[z>>2]=E;c[B>>2]=D;break}else{B=c[6212852+(v<<3)>>2]|0;z=c[6212848+(v<<3)>>2]|0;v=k|0;k=c[v>>2]|0;x=f+788|0;C=c[x>>2]|0;if((C|0)>(B|0)){H=C-B|0;I=k<<B|z}else{w=je(z>>>((B-C|0)>>>0)|k<<C|0)|0;k=f+796|0;A=c[k>>2]|0;y=w;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;H=32-B+C|0;I=z}c[v>>2]=I;c[x>>2]=H;break}}else{x=u>>>31;v=(u|0)<0?-u|0:u;do{if((v|0)>119){J=0;K=119}else{if((m|0)<=5){J=0;K=v;break}z=c[f+9960>>2]|0;if((z|0)==2){C=v+1|0;J=C&1;K=C>>1;break}else if((z|0)==1){z=v+3|0;J=z&3;K=z>>2;break}else{J=0;K=v;break}}}while(0);z=f+784|0;do{if((c[f+14072>>2]|0)==0){if(t){C=c[1295788+(K<<3)>>2]|0;B=c[1295784+(K<<3)>>2]|0;k=z|0;A=c[k>>2]|0;w=f+788|0;G=c[w>>2]|0;if((G|0)>(C|0)){L=G-C|0;M=A<<C|B}else{F=je(B>>>((C-G|0)>>>0)|A<<G|0)|0;A=f+796|0;N=c[A>>2]|0;y=F;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;L=32-C+G|0;M=B}c[k>>2]=M;c[w>>2]=L;O=M;P=L;break}else{w=c[1296748+(K<<3)>>2]|0;k=c[1296744+(K<<3)>>2]|0;B=z|0;G=c[B>>2]|0;C=f+788|0;A=c[C>>2]|0;if((A|0)>(w|0)){Q=A-w|0;R=G<<w|k}else{N=je(k>>>((w-A|0)>>>0)|G<<A|0)|0;G=f+796|0;F=c[G>>2]|0;y=N;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;Q=32-w+A|0;R=k}c[B>>2]=R;c[C>>2]=Q;O=R;P=Q;break}}else{if(t){C=c[1293868+(K<<3)>>2]|0;B=c[1293864+(K<<3)>>2]|0;k=z|0;A=c[k>>2]|0;w=f+788|0;G=c[w>>2]|0;if((G|0)>(C|0)){S=G-C|0;T=A<<C|B}else{F=je(B>>>((C-G|0)>>>0)|A<<G|0)|0;A=f+796|0;N=c[A>>2]|0;y=F;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;S=32-C+G|0;T=B}c[k>>2]=T;c[w>>2]=S;O=T;P=S;break}else{w=c[1294828+(K<<3)>>2]|0;k=c[1294824+(K<<3)>>2]|0;B=z|0;G=c[B>>2]|0;C=f+788|0;A=c[C>>2]|0;if((A|0)>(w|0)){U=A-w|0;V=G<<w|k}else{N=je(k>>>((w-A|0)>>>0)|G<<A|0)|0;G=f+796|0;F=c[G>>2]|0;y=N;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;U=32-w+A|0;V=k}c[B>>2]=V;c[C>>2]=U;O=V;P=U;break}}}while(0);if((c[s>>2]|0)>5){C=c[f+9960>>2]|0;W=(C|0)<3?3-C|0:0}else{W=0}do{if((K|0)==119){C=W+8|0;if((P|0)>(C|0)){X=P-C|0;Y=O<<C|v}else{B=je(v>>>((C-P|0)>>>0)|O<<P|0)|0;C=f+796|0;k=c[C>>2]|0;y=B;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;X=P+24-W|0;Y=v}c[z>>2]=Y;c[f+788>>2]=X;Z=Y;_=X}else{if((W|0)<=0){Z=O;_=P;break}if((P|0)>(W|0)){$=P;aa=O<<W|J}else{C=je(J>>>((W-P|0)>>>0)|O<<P|0)|0;k=f+796|0;B=c[k>>2]|0;y=C;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;$=P+32|0;aa=J}k=$-W|0;c[z>>2]=aa;c[f+788>>2]=k;Z=aa;_=k}}while(0);if((v|0)==0){break}if((_|0)>1){ba=_-1|0;da=Z<<1|x}else{k=je(x>>>((1-_|0)>>>0)|Z<<_|0)|0;B=f+796|0;C=c[B>>2]|0;y=k;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;ba=_+31|0;da=x}c[z>>2]=da;c[f+788>>2]=ba}}while(0);if(t){ea=c[f+14064>>2]|0}else{ea=(c[f+14068>>2]|0)+3|0}t=c[s>>2]|0;n=1;o=f+368|0;p=ea;q=(t|0)>3;r=t}t=q&1;q=f+14092|0;ea=f+180+(h<<2)|0;s=c[ea>>2]|0;if((r-4|0)>>>0<2>>>0&(s|0)>0){r=63;while(1){if(!((r|0)>-1)){break}if((b[g+(d[o+r|0]<<1)>>1]|0)==0){r=r-1|0}else{break}}c[ea>>2]=r;fa=r}else{fa=s}if((n|0)>(fa|0)){i=j;return}s=(h|0)>3|0;h=f+14108|0;r=1314512+(p*192|0)|0;ea=1314520+(p*192|0)|0;ba=f+784|0;da=f+788|0;_=f+14100|0;Z=f+14104|0;aa=f+9960|0;W=f+796|0;f=n-1|0;$=n;while(1){n=b[g+(d[o+$|0]<<1)>>1]|0;J=n<<16>>16;a:do{if(n<<16>>16==0){ga=f}else{P=$-f-1|0;O=($|0)==(fa|0)|0;X=(n&65535)>>>15&65535;Y=n<<16>>16<0?-J|0:J;if((Y|0)<65&(P|0)<65){K=c[h>>2]|0;U=K+((c[l>>2]|0)*67600|0)+(s*33800|0)+(Y*520|0)+(P<<3)+(O<<2)|0;c[U>>2]=(c[U>>2]|0)+1;ha=K}else{ha=c[h>>2]|0}K=ha+((c[l>>2]|0)*67600|0)+(s*33800|0)+21304|0;c[K>>2]=(c[K>>2]|0)+1;K=1314532+(p*192|0)+(O<<2)|0;U=d[(c[K>>2]|0)+P|0]|0;V=c[r>>2]|0;do{if((U|0)<(V|0)){if((a[(c[1314540+(p*192|0)+(O<<2)>>2]|0)+P|0]|0)<(Y|0)){ia=V;break}ia=Y-1+U|0}else{ia=V}}while(0);V=c[ea>>2]|0;U=e[V+(ia<<2)+2>>1]|0;S=e[V+(ia<<2)>>1]|0;V=c[ba>>2]|0;T=c[da>>2]|0;if((T|0)>(U|0)){ja=T-U|0;ka=V<<U|S}else{Q=je(S>>>((U-T|0)>>>0)|V<<T|0)|0;V=c[W>>2]|0;y=Q;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;ja=32-U+T|0;ka=S}c[ba>>2]=ka;c[da>>2]=ja;if((ia|0)!=(c[r>>2]|0)){if((ja|0)>1){la=ja-1|0;ma=ka<<1|X}else{S=je(ka<<ja|X>>>((1-ja|0)>>>0)|0)|0;T=c[W>>2]|0;y=S;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;la=ja+31|0;ma=X}c[ba>>2]=ma;c[da>>2]=la;ga=$;break}T=1314540+(p*192|0)+(O<<2)|0;S=a[(c[T>>2]|0)+P|0]|0;U=Y-S|0;do{if((U|0)>=1){V=d[(c[K>>2]|0)+P|0]|0;if((V|0)>=(ia|0)|(S|0)<(U|0)){break}Q=U-1+V|0;if((Q|0)==(ia|0)){break}if((ja|0)>1){na=ja-1|0;oa=ka<<1|1}else{V=je(1>>>((1-ja|0)>>>0)|ka<<ja|0)|0;R=c[W>>2]|0;y=V;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;na=ja+31|0;oa=1}c[ba>>2]=oa;c[da>>2]=na;R=c[ea>>2]|0;V=e[R+(Q<<2)+2>>1]|0;L=e[R+(Q<<2)>>1]|0;if((na|0)>(V|0)){pa=na;qa=oa<<V|L}else{Q=je(L>>>((V-na|0)>>>0)|oa<<na|0)|0;R=c[W>>2]|0;y=Q;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;pa=na+32|0;qa=L}L=pa-V|0;c[ba>>2]=qa;c[da>>2]=L;if((L|0)>1){ra=L-1|0;sa=qa<<1|X}else{V=je(X>>>((1-L|0)>>>0)|qa<<L|0)|0;R=c[W>>2]|0;y=V;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;ra=L+31|0;sa=X}c[ba>>2]=sa;c[da>>2]=ra;ga=$;break a}}while(0);if((ja|0)>1){ta=ja-1|0;ua=ka<<1}else{U=je(ka<<ja|0)|0;S=c[W>>2]|0;y=U;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;ta=ja+31|0;ua=0}c[ba>>2]=ua;c[da>>2]=ta;do{if((Y|0)<=64){S=P-(a[(c[1314548+(p*192|0)+(O<<2)>>2]|0)+Y|0]|0)-t|0;if((S|0)<0){break}U=S+1|0;L=c[K>>2]|0;R=d[L+U|0]|0;V=c[r>>2]|0;do{if((R|0)<(V|0)){if((a[(c[T>>2]|0)+U|0]|0)<(Y|0)){va=V;break}va=Y-1+R|0}else{va=V}}while(0);if((c[q>>2]|0)==4&(va|0)==(V|0)){break}R=d[L+S|0]|0;if((R|0)>=(V|0)){break}if((a[(c[T>>2]|0)+S|0]|0)<(Y|0)){break}U=Y-1+R|0;if((U|0)==(V|0)){break}if((ta|0)>1){wa=ta-1|0;xa=ua<<1|1}else{R=je(1>>>((1-ta|0)>>>0)|ua<<ta|0)|0;Q=c[W>>2]|0;y=R;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;wa=ta+31|0;xa=1}c[ba>>2]=xa;c[da>>2]=wa;Q=c[ea>>2]|0;R=e[Q+(U<<2)+2>>1]|0;M=e[Q+(U<<2)>>1]|0;if((wa|0)>(R|0)){ya=wa;za=xa<<R|M}else{U=je(M>>>((R-wa|0)>>>0)|xa<<wa|0)|0;Q=c[W>>2]|0;y=U;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;ya=wa+32|0;za=M}M=ya-R|0;c[ba>>2]=za;c[da>>2]=M;if((M|0)>1){Aa=M-1|0;Ba=za<<1|X}else{R=je(X>>>((1-M|0)>>>0)|za<<M|0)|0;Q=c[W>>2]|0;y=R;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Aa=M+31|0;Ba=X}c[ba>>2]=Ba;c[da>>2]=Aa;ga=$;break a}}while(0);if((ta|0)>1){Ca=ta-1|0;Da=ua<<1}else{T=je(ua<<ta|0)|0;K=c[W>>2]|0;y=T;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Ca=ta+31|0;Da=0}c[ba>>2]=Da;c[da>>2]=Ca;if((Ca|0)>1){Ea=Ca-1|0;Fa=Da<<1|O}else{K=je(O>>>((1-Ca|0)>>>0)|Da<<Ca|0)|0;T=c[W>>2]|0;y=K;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Ea=Ca+31|0;Fa=O}c[ba>>2]=Fa;c[da>>2]=Ea;T=c[q>>2]|0;if((T|0)<=3){if((Ea|0)>6){Ga=Ea-6|0;Ha=Fa<<6|P}else{K=je(Fa<<Ea|P>>>((6-Ea|0)>>>0)|0)|0;M=c[W>>2]|0;y=K;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Ga=Ea+26|0;Ha=P}c[ba>>2]=Ha;c[da>>2]=Ga;M=J&255;if((Ga|0)>8){Ia=Ga-8|0;Ja=Ha<<8|M}else{K=je(M>>>((8-Ga|0)>>>0)|Ha<<Ga|0)|0;Q=c[W>>2]|0;y=K;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Ia=Ga+24|0;Ja=M}c[ba>>2]=Ja;c[da>>2]=Ia;ga=$;break}do{if((c[_>>2]|0)==0){c[_>>2]=8;c[Z>>2]=6;if((c[aa>>2]|0)<8){M=(T|0)>5|6;if((Ea|0)>(M|0)){Ka=Ea;La=Fa<<M|3}else{Q=je(3>>>((M-Ea|0)>>>0)|Fa<<Ea|0)|0;K=c[W>>2]|0;y=Q;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Ka=Ea+32|0;La=3}K=Ka-M|0;c[ba>>2]=La;c[da>>2]=K;Ma=La;Na=K;break}else{if((Ea|0)>8){Oa=Ea-8|0;Pa=Fa<<8|3}else{K=je(3>>>((8-Ea|0)>>>0)|Fa<<Ea|0)|0;M=c[W>>2]|0;y=K;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Oa=Ea+24|0;Pa=3}c[ba>>2]=Pa;c[da>>2]=Oa;Ma=Pa;Na=Oa;break}}else{Ma=Fa;Na=Ea}}while(0);T=c[Z>>2]|0;if((Na|0)>(T|0)){Qa=Na-T|0;Ra=Ma<<T|P}else{O=je(P>>>((T-Na|0)>>>0)|Ma<<Na|0)|0;M=c[W>>2]|0;y=O;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Qa=32-T+Na|0;Ra=P}c[ba>>2]=Ra;c[da>>2]=Qa;if((Qa|0)>1){Sa=Qa-1|0;Ta=Ra<<1|X}else{T=je(X>>>((1-Qa|0)>>>0)|Ra<<Qa|0)|0;M=c[W>>2]|0;y=T;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Sa=Qa+31|0;Ta=X}c[ba>>2]=Ta;c[da>>2]=Sa;M=c[_>>2]|0;if((Sa|0)>(M|0)){Ua=Sa;Va=Ta<<M|Y}else{T=je(Y>>>((M-Sa|0)>>>0)|Ta<<Sa|0)|0;O=c[W>>2]|0;y=T;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;Ua=Sa+32|0;Va=Y}c[ba>>2]=Va;c[da>>2]=Ua-M;ga=$}}while(0);J=$+1|0;if((J|0)>(fa|0)){break}else{f=ga;$=J}}i=j;return}function VUa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=c[a+792>>2]|0;if((f|0)==4|(f|0)==8){c[a+140>>2]=11}else if((f|0)==24){c[a+140>>2]=3}else if((f|0)==1){c[a+140>>2]=9}else{KIb(a,16,2245200,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1094995529;i=b;return g|0}f=UHb()|0;c[e+4>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}f=a+100|0;h=c[f>>2]|0;if((h|0)<=3){g=0;i=b;return g|0}j=a+96|0;a=e+28|0;e=0;k=h;while(1){if((k|0)>1024){l=256}else{l=(k|0)/4|0}if((e|0)>=(l|0)){g=0;break}h=(c[j>>2]|0)+(e<<2)|0;c[a+(e<<2)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|-16777216;e=e+1|0;k=c[f>>2]|0}i=b;return g|0}function WUa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;j=g+24|0;k=c[j>>2]|0;l=g+28|0;m=c[l>>2]|0;n=c[b+60>>2]|0;o=b+120|0;p=b+792|0;q=((ca(c[p>>2]|0,c[o>>2]|0)|0)+31&-32|0)/8|0;c[n+20>>2]=k;c[n+24>>2]=m;r=n+4|0;s=N4a(b,c[r>>2]|0)|0;if((s|0)<0){t=s;i=h;return t|0}if(((c[p>>2]|0)-2|0)>>>0<7>>>0){s=V1(g,0,0)|0;g=c[r>>2]|0;if((s|0)==0){u=n+28|0}else{c[g+304>>2]=1;v=n+28|0;nrc(v|0,s|0,1024)|0;u=v}nrc(c[g+4>>2]|0,u|0,1024)|0}u=b+124|0;g=ca(c[u>>2]|0,q)|0;a:do{if((g|0)==(c[l>>2]|0)){v=oIb(c[b+140>>2]|0,c[o>>2]|0,0)|0;if((v|0)<0){t=v;i=h;return t|0}s=c[u>>2]|0;if((s|0)<=0){break}w=ca(s-1|0,q)|0;s=-q|0;x=c[c[r>>2]>>2]|0;y=(c[j>>2]|0)+w|0;w=1;while(1){do{if((c[p>>2]|0)==4){z=c[o>>2]|0;if((z-1|0)>0){A=0;while(1){B=y+(A>>1)|0;a[x+A|0]=(d[B]|0)>>>4;a[x+(A|1)|0]=a[B]&15;B=A+2|0;C=c[o>>2]|0;if((B|0)<(C-1|0)){A=B}else{D=B;E=C;break}}}else{D=0;E=z}if((E&1|0)==0){break}a[x+D|0]=(d[y+(D>>1)|0]|0)>>>4}else{nrc(x|0,y|0,v)|0}}while(0);if((w|0)>=(c[u>>2]|0)){break a}x=x+(c[(c[r>>2]|0)+32>>2]|0)|0;y=y+s|0;w=w+1|0}}else{w=n+8|0;if((m|0)>-1){c[w>>2]=k;c[n+16>>2]=k;c[n+12>>2]=k+m;YUa(b,c[r>>2]|0,c[p>>2]|0,w)|0;break}else{KIb(0,0,2449440,(w=i,i=i+24|0,c[w>>2]=2360240,c[w+8>>2]=2296216,c[w+16>>2]=135,w)|0);i=w;Hd();return 0}}}while(0);p=YHb(e,c[r>>2]|0)|0;if((p|0)<0){t=p;i=h;return t|0}c[f>>2]=1;t=m;i=h;return t|0}function XUa(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function YUa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0;j=i;switch(g|0){case 4:{k=c[f+32>>2]|0;l=c[e+124>>2]|0;m=ca(l-1|0,k)|0;n=ca(l,k)|0;l=h|0;o=c[l>>2]|0;p=h+4|0;q=c[p>>2]|0;r=(q|0)==(o|0);do{if((m|0)>-1){s=e+120|0;t=f|0;u=0;v=m;w=r;x=o;y=q;a:while(1){if(w){z=5;break}else{A=y;B=x;C=u}b:while(1){D=B+1|0;c[l>>2]=D;E=a[B]|0;F=E&255;c:do{if(E<<24>>24==0){G=A;if((G-D|0)<1){H=k;I=0;J=D;break b}K=B+2|0;c[l>>2]=K;L=d[D]|0;if((L|0)==0){H=k;I=0;J=K;break b}else if((L|0)==2){z=10;break b}else if((L|0)==1){M=0;z=107;break a}N=(L+1|0)>>>1;if((C+v+L|0)>>>0>n>>>0){z=23;break a}if((G-K|0)>>>0<N>>>0){z=23;break a}if((N|0)==0){O=C;break}d:do{if((L&1|0)==0){P=C;Q=1;while(1){if(!(P>>>0<(c[s>>2]|0)>>>0)){R=P;break d}S=c[l>>2]|0;c[l>>2]=S+1;T=a[S]|0;a[(c[t>>2]|0)+(P+v)|0]=(T&255)>>>4;S=P+1|0;if(!(S>>>0<(c[s>>2]|0)>>>0)){R=S;break d}a[(c[t>>2]|0)+(S+v)|0]=T&15;T=P+2|0;if((Q|0)>=(N|0)){R=T;break d}P=T;Q=Q+1|0}}else{Q=C;P=1;while(1){if(!(Q>>>0<(c[s>>2]|0)>>>0)){R=Q;break d}T=c[l>>2]|0;c[l>>2]=T+1;S=a[T]|0;a[(c[t>>2]|0)+(Q+v)|0]=(S&255)>>>4;T=Q+1|0;if((P|0)==(N|0)){R=T;break d}if(!(T>>>0<(c[s>>2]|0)>>>0)){R=T;break d}a[(c[t>>2]|0)+(T+v)|0]=S&15;S=Q+2|0;if((P|0)>=(N|0)){R=S;break d}Q=S;P=P+1|0}}}while(0);if((N&1|0)==0){O=R;break}L=c[l>>2]|0;P=(c[p>>2]|0)-L|0;c[l>>2]=L+(P>>>0>1>>>0?1:P);O=R}else{if((C+v+F|0)>>>0>n>>>0){z=33;break a}if((A-D|0)<1){U=0;V=0}else{c[l>>2]=B+2;P=a[D]|0;U=(P&255)>>>4;V=P&15}P=C;L=0;while(1){if(!(P>>>0<(c[s>>2]|0)>>>0)){O=P;break c}a[(c[t>>2]|0)+(P+v)|0]=(L&1|0)==0?U:V;Q=P+1|0;S=L+1|0;if((S|0)<(F|0)){P=Q;L=S}else{O=Q;break}}}}while(0);F=c[l>>2]|0;D=c[p>>2]|0;if((D|0)==(F|0)){z=5;break a}else{A=D;B=F;C=O}}if((z|0)==10){z=0;if((G-K|0)<1){W=0;X=K}else{F=B+3|0;c[l>>2]=F;W=d[K]|0;X=F}if((G-X|0)<1){Y=0;Z=X}else{F=X+1|0;c[l>>2]=F;Y=d[X]|0;Z=F}H=ca(Y,k)|0;I=W+C|0;J=Z}F=v-H|0;_=(A|0)==(J|0);if((F|0)>-1){u=I;v=F;w=_;x=J;y=A}else{z=39;break}}if((z|0)==5){KIb(e,16,2245152,($=i,i=i+8|0,c[$>>2]=v,$)|0);i=$;M=-1094995529;i=j;return M|0}else if((z|0)==23){KIb(e,16,2203736,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;M=-1094995529;i=j;return M|0}else if((z|0)==33){KIb(e,16,2171792,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;M=-1094995529;i=j;return M|0}else if((z|0)==39){if(_){M=0}else{aa=G-J|0;break}i=j;return M|0}else if((z|0)==107){i=j;return M|0}}else{if(r){M=0}else{aa=q-o|0;break}i=j;return M|0}}while(0);KIb(e,16,2144216,($=i,i=i+8|0,c[$>>2]=aa,$)|0);i=$;M=-1094995529;i=j;return M|0};case 8:case 16:case 24:case 32:{aa=(c[e+124>>2]|0)-1|0;o=f+32|0;q=c[o>>2]|0;r=(q|0)>-1?q:-q|0;J=g>>3;G=(r|0)/(J|0)|0;_=f|0;f=c[_>>2]|0;A=ca(aa,q)|0;q=h|0;I=c[q>>2]|0;H=h+4|0;h=c[H>>2]|0;e:do{if((h|0)!=(I|0)){Z=J<<1;C=(g|0)==8;W=aa;k=0;Y=f+(r+A)|0;X=f+A|0;l=I;K=h;f:while(1){B=k;O=X;p=l;V=K;g:while(1){ba=V;da=p;while(1){ea=da+1|0;c[q>>2]=ea;fa=a[da]|0;ga=fa&255;if(fa<<24>>24==0){if((ba-ea|0)<1){ha=ea;z=49;break g}ia=da+2|0;c[q>>2]=ia;ja=a[ea]|0;ka=ja&255;if((ka|0)==2){z=55;break g}else if((ka|0)==0){ha=ia;z=49;break g}else if((ka|0)==1){M=0;z=107;break f}la=ca(ka,J)|0;ma=O+la|0;na=ba-ia|0;if(!(ma>>>0>Y>>>0)){z=65;break}U=da+((na>>>0>Z>>>0?Z:na)+2)|0;c[q>>2]=U;oa=U}else{if((O+(ca(ga,J)|0)|0)>>>0>Y>>>0){oa=ea}else{z=81;break}}if((V|0)==(oa|0)){break e}else{da=oa}}do{if((z|0)==65){z=0;if(na>>>0<la>>>0){z=66;break f}if((g|0)==24|(g|0)==8){nrc(O|0,ia|0,la)|0;U=c[q>>2]|0;n=U+la|0;c[q>>2]=n;if(!C){pa=ma;qa=ka;ra=n;break}if((ka&1|0)==0){pa=ma;qa=ka;ra=n;break}R=(c[H>>2]|0)-n|0;n=U+((R>>>0>1>>>0?1:R)+la)|0;c[q>>2]=n;pa=ma;qa=ka;ra=n;break}else if((g|0)==32){if(ja<<24>>24==0){pa=O;qa=ka;ra=ia;break}n=ka<<2;R=(ja&255)>>>0>1>>>0;U=ka<<2;m=0;y=O;x=ia;while(1){w=x+4|0;c[q>>2]=w;u=x;c[y>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;u=m+1|0;if((u|0)<(ka|0)){m=u;y=y+4|0;x=w}else{break}}pa=O+((ja&255)>>>0>1>>>0?n:4)|0;qa=ka;ra=da+(R?U|2:6)|0;break}else if((g|0)==16){if(ja<<24>>24==0){pa=O;qa=ka;ra=ia;break}x=ka<<1;y=(ja&255)>>>0>1>>>0;m=ka<<1;w=0;u=O;t=ia;while(1){s=t+2|0;c[q>>2]=s;F=t;b[u>>1]=(d[F]|d[F+1|0]<<8)<<16>>16;F=w+1|0;if((F|0)<(ka|0)){w=F;u=u+2|0;t=s}else{break}}pa=O+((ja&255)>>>0>1>>>0?x:2)|0;qa=ka;ra=da+(y?m+2|0:4)|0;break}else{pa=O;qa=ka;ra=ia;break}}else if((z|0)==81){z=0;if((g|0)==16){if((ba-ea|0)<2){sa=0}else{c[q>>2]=da+3;t=ea;sa=(d[t]|d[t+1|0]<<8)<<16>>16}t=ga<<1;u=0;w=O;while(1){b[w>>1]=sa;U=u+1|0;if((U|0)<(ga|0)){u=U;w=w+2|0}else{break}}ta=O+((fa&255)>>>0>1>>>0?t:2)|0}else if((g|0)==32){if((ba-ea|0)<4){ua=0}else{c[q>>2]=da+5;w=ea;ua=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0}w=ga<<2;u=0;m=O;while(1){c[m>>2]=ua;y=u+1|0;if((y|0)<(ga|0)){u=y;m=m+4|0}else{break}}ta=O+((fa&255)>>>0>1>>>0?w:4)|0}else if((g|0)==24){if((ba-ea|0)<1){va=0;wa=ea}else{m=da+2|0;c[q>>2]=m;va=a[ea]|0;wa=m}if((ba-wa|0)<1){xa=0;ya=wa}else{m=wa+1|0;c[q>>2]=m;xa=a[wa]|0;ya=m}if((ba-ya|0)<1){za=0}else{c[q>>2]=ya+1;za=a[ya]|0}m=ga*3|0;u=0;t=O;while(1){a[t]=va;a[t+1|0]=xa;a[t+2|0]=za;y=u+1|0;if((y|0)<(ga|0)){u=y;t=t+3|0}else{break}}ta=O+((fa&255)>>>0>1>>>0?m:3)|0}else if((g|0)==8){if((ba-ea|0)<1){Aa=0}else{c[q>>2]=da+2;Aa=a[ea]|0}mrc(O|0,Aa|0,ga|0)|0;ta=O+ga|0}else{ta=O}pa=ta;qa=ga;ra=c[q>>2]|0}}while(0);t=c[H>>2]|0;if((t|0)==(ra|0)){break e}else{B=qa+B|0;O=pa;p=ra;V=t}}if((z|0)==49){z=0;p=W-1|0;if((p|0)<0){z=50;break}O=c[_>>2]|0;t=c[o>>2]|0;u=ca(t,p)|0;Ba=O+u|0;Ca=O+(((t|0)>-1?t:-t|0)+u)|0;Da=0;Ea=p;Fa=ha}else if((z|0)==55){z=0;if((ba-ia|0)<1){Ga=0;Ha=ia}else{p=da+3|0;c[q>>2]=p;Ga=d[ia]|0;Ha=p}if((ba-Ha|0)<1){Ia=0;Ja=Ha}else{p=Ha+1|0;c[q>>2]=p;Ia=d[Ha]|0;Ja=p}p=W-Ia|0;u=Ga+B|0;if(!((p|0)>-1&u>>>0<G>>>0)){z=60;break}t=c[_>>2]|0;O=c[o>>2]|0;w=ca(O,p)|0;y=t+(w+(ca(u,J)|0))|0;Ba=y;Ca=t+(((O|0)>-1?O:-O|0)+w)|0;Da=u;Ea=p;Fa=Ja}if((V|0)==(Fa|0)){break e}else{W=Ea;k=Da;Y=Ca;X=Ba;l=Fa;K=V}}if((z|0)==50){do{if((ba-ha|0)<2){Ka=ha}else{K=ha+2|0;c[q>>2]=K;l=ha;if((d[l]|d[l+1|0]<<8)<<16>>16<<16>>16==256){M=0}else{Ka=K;break}i=j;return M|0}}while(0);KIb(e,16,2599488,($=i,i=i+8|0,c[$>>2]=ba-Ka,$)|0);i=$;M=-1094995529;i=j;return M|0}else if((z|0)==60){KIb(e,16,2449384,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;M=-1;i=j;return M|0}else if((z|0)==66){KIb(e,16,2360216,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;M=-1094995529;i=j;return M|0}else if((z|0)==107){i=j;return M|0}}}while(0);KIb(e,24,2296176,($=i,i=i+1|0,i=i+7&-8,c[$>>2]=0,$)|0);i=$;M=0;i=j;return M|0};default:{KIb(e,16,2495616,($=i,i=i+8|0,c[$>>2]=g,$)|0);i=$;M=-1;i=j;return M|0}}return 0}function ZUa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;c[b>>2]=a;d=UHb()|0;c[b+1088>>2]=d;if((d|0)==0){e=-12;return e|0}d=jVa(b,0,b+1092|0,0)|0;c[a+140>>2]=11;e=d;return e|0}function _Ua(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;g=i;i=i+48|0;h=g|0;j=g+24|0;k=c[a+60>>2]|0;l=k;m=c[f+24>>2]|0;n=f+28|0;f=c[n>>2]|0;o=f>>>0>268435455>>>0?-8:f<<3;f=o>>>0>2147483639>>>0|(m|0)==0;p=f?0:m;m=f?0:o;c[h>>2]=p;c[h+12>>2]=m;o=m+8|0;c[h+16>>2]=o;c[h+4>>2]=p+(m>>3);m=h+8|0;c[m>>2]=0;if(f){q=f?-1094995529:0;i=g;return q|0}f=j|0;c[f>>2]=0;r=j+4|0;c[r>>2]=65535;s=p;p=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)>>>16;c[m>>2]=o>>>0>16>>>0?16:o;o=j+8|0;c[o>>2]=p;p=j+12|0;c[p>>2]=h;c[j+16>>2]=574;c[j+20>>2]=272;h=k+1088|0;m=N4a(a,c[h>>2]|0)|0;if((m|0)<0){q=m;i=g;return q|0}m=c[h>>2]|0;s=c[m+32>>2]|0;t=a+124|0;c[k+1028>>2]=(c[m>>2]|0)+(ca((c[t>>2]|0)-1|0,s)|0);c[k+1036>>2]=-s;s=c[r>>2]|0;u=c[f>>2]|0;v=c[o>>2]|0;w=((v<<1)-u|0)>=(s|0);x=(s+1-u>>1)+u|0;if(w){c[f>>2]=x;y=s;z=v}else{s=x-1|0;c[r>>2]=s;y=s;z=v}a:while(1){v=c[f>>2]|0;do{if((y|0)>32767){if((v|0)>=32768){s=z-32768|0;c[o>>2]=s;x=v-32768|0;c[f>>2]=x;u=y-32768|0;c[r>>2]=u;A=u;B=s;C=x;break}if(!((v|0)>16383&(y|0)<49152)){break a}x=z-16384|0;c[o>>2]=x;s=v-16384|0;c[f>>2]=s;u=y-16384|0;c[r>>2]=u;A=u;B=x;C=s}else{A=y;B=z;C=v}}while(0);c[o>>2]=B<<1;c[f>>2]=C<<1;c[r>>2]=A<<1|1;v=c[p>>2]|0;s=v+8|0;x=c[s>>2]|0;u=(d[(c[v>>2]|0)+(x>>>3)|0]|0)<<(x&7)>>>7;c[s>>2]=((x|0)<(c[v+16>>2]|0))+x;x=u&1|c[o>>2];c[o>>2]=x;y=c[r>>2]|0;z=x}c[k+1064>>2]=w&1^1;z=k+1076|0;do{if(w){if((c[z>>2]|0)==0){c[m+84>>2]=0;c[m+88>>2]=2;D=0;E=k+1092|0;break}else{q=-1094995529;i=g;return q|0}}else{c[z>>2]=0;y=k+1092|0;eVa(y);A=c[k+1060>>2]|0;if((A|0)==0){F=0}else{C=A+1|0;B=c[f>>2]|0;x=(c[r>>2]|0)-B+1|0;u=c[o>>2]|0;v=((ca(1-B+u|0,C)|0)-1|0)/(x|0)|0;s=ca(x,v)|0;G=B-1+((s+x|0)/(C|0)|0)|0;c[r>>2]=G;c[f>>2]=((s|0)/(C|0)|0)+B;B=G;G=u;b:while(1){H=c[f>>2]|0;do{if((B|0)>32767){if((H|0)>=32768){u=G-32768|0;c[o>>2]=u;C=H-32768|0;c[f>>2]=C;s=B-32768|0;c[r>>2]=s;I=s;J=u;K=C;break}if(!((H|0)>16383&(B|0)<49152)){break b}C=G-16384|0;c[o>>2]=C;u=H-16384|0;c[f>>2]=u;s=B-16384|0;c[r>>2]=s;I=s;J=C;K=u}else{I=B;J=G;K=H}}while(0);c[o>>2]=J<<1;c[f>>2]=K<<1;c[r>>2]=I<<1|1;u=c[p>>2]|0;C=u+8|0;s=c[C>>2]|0;x=(d[(c[u>>2]|0)+(s>>>3)|0]|0)<<(s&7)>>>7;c[C>>2]=((s|0)<(c[u+16>>2]|0))+s;s=x&1|c[o>>2];c[o>>2]=s;B=c[r>>2]|0;G=s}c:do{if((v|0)>0){s=1;x=l+4+(256-A<<2)|0;u=B;C=H;L=G;while(1){M=u-C+1|0;N=(L-C<<8|255|0)/(M|0)|0;O=ca(M,N)|0;P=C-1+(O+M>>8)|0;c[r>>2]=P;c[f>>2]=(O>>8)+C;O=P;P=L;d:while(1){Q=c[f>>2]|0;do{if((O|0)>32767){if((Q|0)>=32768){M=P-32768|0;c[o>>2]=M;R=Q-32768|0;c[f>>2]=R;S=O-32768|0;c[r>>2]=S;T=S;U=M;V=R;break}if(!((Q|0)>16383&(O|0)<49152)){break d}R=P-16384|0;c[o>>2]=R;M=Q-16384|0;c[f>>2]=M;S=O-16384|0;c[r>>2]=S;T=S;U=R;V=M}else{T=O;U=P;V=Q}}while(0);c[o>>2]=U<<1;c[f>>2]=V<<1;c[r>>2]=T<<1|1;M=c[p>>2]|0;R=M+8|0;S=c[R>>2]|0;W=(d[(c[M>>2]|0)+(S>>>3)|0]|0)<<(S&7)>>>7;c[R>>2]=((S|0)<(c[M+16>>2]|0))+S;S=W&1|c[o>>2];c[o>>2]=S;O=c[r>>2]|0;P=S}S=O-Q+1|0;W=(P-Q<<8|255|0)/(S|0)|0;M=ca(W,S)|0;R=Q-1+(M+S>>8)|0;c[r>>2]=R;c[f>>2]=(M>>8)+Q;M=R;R=P;e:while(1){X=c[f>>2]|0;do{if((M|0)>32767){if((X|0)>=32768){S=R-32768|0;c[o>>2]=S;Y=X-32768|0;c[f>>2]=Y;Z=M-32768|0;c[r>>2]=Z;_=Z;$=S;aa=Y;break}if(!((X|0)>16383&(M|0)<49152)){break e}Y=R-16384|0;c[o>>2]=Y;S=X-16384|0;c[f>>2]=S;Z=M-16384|0;c[r>>2]=Z;_=Z;$=Y;aa=S}else{_=M;$=R;aa=X}}while(0);c[o>>2]=$<<1;c[f>>2]=aa<<1;c[r>>2]=_<<1|1;S=c[p>>2]|0;Y=S+8|0;Z=c[Y>>2]|0;ba=(d[(c[S>>2]|0)+(Z>>>3)|0]|0)<<(Z&7)>>>7;c[Y>>2]=((Z|0)<(c[S+16>>2]|0))+Z;Z=ba&1|c[o>>2];c[o>>2]=Z;M=c[r>>2]|0;R=Z}P=M-X+1|0;O=(R-X<<8|255|0)/(P|0)|0;Z=ca(O,P)|0;ba=X-1+(Z+P>>8)|0;c[r>>2]=ba;c[f>>2]=(Z>>8)+X;Z=ba;ba=R;f:while(1){P=c[f>>2]|0;do{if((Z|0)>32767){if((P|0)>=32768){S=ba-32768|0;c[o>>2]=S;Y=P-32768|0;c[f>>2]=Y;da=Z-32768|0;c[r>>2]=da;ea=da;fa=S;ga=Y;break}if(!((P|0)>16383&(Z|0)<49152)){break f}Y=ba-16384|0;c[o>>2]=Y;S=P-16384|0;c[f>>2]=S;da=Z-16384|0;c[r>>2]=da;ea=da;fa=Y;ga=S}else{ea=Z;fa=ba;ga=P}}while(0);c[o>>2]=fa<<1;c[f>>2]=ga<<1;c[r>>2]=ea<<1|1;P=c[p>>2]|0;S=P+8|0;Y=c[S>>2]|0;da=(d[(c[P>>2]|0)+(Y>>>3)|0]|0)<<(Y&7)>>>7;c[S>>2]=((Y|0)<(c[P+16>>2]|0))+Y;Y=da&1|c[o>>2];c[o>>2]=Y;Z=c[r>>2]|0;ba=Y}c[x>>2]=N<<16|W<<8|O|-16777216;if((s|0)>=(v|0)){break c}s=s+1|0;x=x+4|0;u=c[r>>2]|0;C=c[f>>2]|0;L=c[o>>2]|0}}}while(0);F=(v|0)!=0|0}G=c[h>>2]|0;c[G+84>>2]=1;c[G+88>>2]=1;D=F;E=y}}while(0);F=hVa(E,j,0,0,c[a+120>>2]|0,c[t>>2]|0)|0;c[z>>2]=F;if((F|0)!=0){q=-1094995529;i=g;return q|0}nrc(c[(c[h>>2]|0)+4>>2]|0,k+4|0,1024)|0;k=c[h>>2]|0;c[k+304>>2]=D;D=YHb(b,k)|0;if((D|0)<0){q=D;i=g;return q|0}c[e>>2]=1;q=c[n>>2]|0;i=g;return q|0}function $Ua(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+1088|0);lVa(b)|0;return 0}function aVa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a+4|0;e=a|0;f=c[e>>2]|0;g=(c[d>>2]|0)-f+1|0;h=((ca(1-f+(c[a+8>>2]|0)|0,b)|0)-1|0)/(g|0)|0;i=ca(g,h)|0;c[d>>2]=f-1+((i+g|0)/(b|0)|0);c[e>>2]=f+((i|0)/(b|0)|0);bVa(a);return h|0}function bVa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+4|0;e=a|0;f=a+8|0;g=a+12|0;a:while(1){a=c[b>>2]|0;do{if((a|0)>32767){h=c[e>>2]|0;if((h|0)>=32768){i=(c[f>>2]|0)-32768|0;c[f>>2]=i;j=h-32768|0;c[e>>2]=j;k=a-32768|0;c[b>>2]=k;l=k;m=i;n=j;break}if(!((h|0)>16383&(a|0)<49152)){break a}j=(c[f>>2]|0)-16384|0;c[f>>2]=j;i=h-16384|0;c[e>>2]=i;h=a-16384|0;c[b>>2]=h;l=h;m=j;n=i}else{l=a;m=c[f>>2]|0;n=c[e>>2]|0}}while(0);c[f>>2]=m<<1;c[e>>2]=n<<1;c[b>>2]=l<<1|1;a=c[g>>2]|0;i=a+8|0;j=c[i>>2]|0;h=(d[(c[a>>2]|0)+(j>>>3)|0]|0)<<(j&7)>>>7;c[i>>2]=((j|0)<(c[a+16>>2]|0))+j;c[f>>2]=h&1|c[f>>2]}return}function cVa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+4|0;g=a|0;h=c[g>>2]|0;i=(c[f>>2]|0)-h+1|0;j=b[e>>1]|0;k=((ca(j,1-h+(c[a+8>>2]|0)|0)|0)-1|0)/(i|0)|0;l=1;while(1){m=b[e+(l<<1)>>1]|0;if((m|0)>(k|0)){l=l+1|0}else{break}}c[f>>2]=h-1+((ca(b[e+(l-1<<1)>>1]|0,i)|0)/(j|0)|0);c[g>>2]=((ca(m,i)|0)/(j|0)|0)+h;h=d[e+1028+l|0]|0;dVa(e,l);bVa(a);return h|0}function dVa(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[d+514+(e<<1)>>1]|0;do{if(f<<16>>16==(b[d+514+(e-1<<1)>>1]|0)){g=e;while(1){h=g-1|0;if((b[d+514+(h<<1)>>1]|0)==f<<16>>16){g=h}else{break}}if((g|0)==(e|0)){i=e;j=f;break}h=d+1028+e|0;k=a[h]|0;l=d+1028+g|0;a[h]=a[l]|0;a[l]=k;i=g;j=b[d+514+(g<<1)>>1]|0}else{i=e;j=f}}while(0);b[d+514+(i<<1)>>1]=j+1;if((i|0)>0){j=i;do{j=j-1|0;i=d+(j<<1)|0;b[i>>1]=(b[i>>1]|0)+1;}while((j|0)>0)}if((c[d+1292>>2]|0)==-1){j=(b[d+514+(c[d+1288>>2]<<1)>>1]<<1)-1|0;i=b[d>>1]|0;f=((j>>1)+(i<<16>>16<<2)|0)/(j|0)|0;j=(f|0)>16383?16383:f;c[d+1296>>2]=j;m=i;n=j}else{m=b[d>>1]|0;n=c[d+1296>>2]|0}j=d|0;i=d+1296|0;if((m<<16>>16|0)<=(n|0)){return}f=d+1288|0;e=m;m=n;while(1){n=c[f>>2]|0;if((n|0)>-1){k=n;n=0;while(1){b[d+(k<<1)>>1]=n;l=d+514+(k<<1)|0;h=((b[l>>1]|0)+1|0)>>>1&65535;b[l>>1]=h;if((k|0)>0){k=k-1|0;n=(h<<16>>16)+n|0}else{break}}o=b[j>>1]|0;p=c[i>>2]|0}else{o=e;p=m}if((o<<16>>16|0)>(p|0)){e=o;m=p}else{break}}return}function eVa(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=d+1292|0;do{if((c[e>>2]|0)<0){b[d+518>>1]=0}else{f=0;do{b[d+518+(f<<1)>>1]=1;b[d+4+(f<<1)>>1]=(c[e>>2]|0)-f;f=f+1|0;g=c[e>>2]|0;}while((f|0)<=(g|0));b[d+518>>1]=0;if((g|0)>0){h=0}else{break}while(1){f=h+1|0;a[d+1032+f|0]=h;if((f|0)<(c[e>>2]|0)){h=f}else{break}}}}while(0);h=d+2592|0;do{if((c[h>>2]|0)<0){b[d+1818>>1]=0}else{e=0;do{b[d+1818+(e<<1)>>1]=1;b[d+1304+(e<<1)>>1]=(c[h>>2]|0)-e;e=e+1|0;i=c[h>>2]|0;}while((e|0)<=(i|0));b[d+1818>>1]=0;if((i|0)>0){j=0}else{break}while(1){e=j+1|0;a[d+2332+e|0]=j;if((e|0)<(c[h>>2]|0)){j=e}else{break}}}}while(0);j=d+6492|0;do{if((c[j>>2]|0)<0){b[d+5718>>1]=0}else{h=0;do{b[d+5718+(h<<1)>>1]=1;b[d+5204+(h<<1)>>1]=(c[j>>2]|0)-h;h=h+1|0;k=c[j>>2]|0;}while((h|0)<=(k|0));b[d+5718>>1]=0;if((k|0)>0){l=0}else{break}while(1){h=l+1|0;a[d+6232+h|0]=l;if((h|0)<(c[j>>2]|0)){l=h}else{break}}}}while(0);l=d+5192|0;do{if((c[l>>2]|0)<0){b[d+4418>>1]=0}else{j=0;do{b[d+4418+(j<<1)>>1]=1;b[d+3904+(j<<1)>>1]=(c[l>>2]|0)-j;j=j+1|0;m=c[l>>2]|0;}while((j|0)<=(m|0));b[d+4418>>1]=0;if((m|0)>0){n=0}else{break}while(1){j=n+1|0;a[d+4932+j|0]=n;if((j|0)<(c[l>>2]|0)){n=j}else{break}}}}while(0);n=d+3892|0;if((c[n>>2]|0)<0){b[d+3118>>1]=0;o=d+6504|0;gVa(o);p=d+87128|0;gVa(p);return}else{q=0}do{b[d+3118+(q<<1)>>1]=1;b[d+2604+(q<<1)>>1]=(c[n>>2]|0)-q;q=q+1|0;r=c[n>>2]|0;}while((q|0)<=(r|0));b[d+3118>>1]=0;if((r|0)>0){s=0}else{o=d+6504|0;gVa(o);p=d+87128|0;gVa(p);return}while(1){r=s+1|0;a[d+3632+r|0]=s;if((r|0)<(c[n>>2]|0)){s=r}else{break}}o=d+6504|0;gVa(o);p=d+87128|0;gVa(p);return}function fVa(d){d=d|0;var e=0,f=0,g=0,h=0;e=d+1288|0;if((c[e>>2]|0)<0){b[d+514>>1]=0;return}else{f=0}do{b[d+514+(f<<1)>>1]=1;b[d+(f<<1)>>1]=(c[e>>2]|0)-f;f=f+1|0;g=c[e>>2]|0;}while((f|0)<=(g|0));b[d+514>>1]=0;if((g|0)>0){h=0}else{return}while(1){g=h+1|0;a[d+1028+g|0]=h;if((g|0)<(c[e>>2]|0)){h=g}else{break}}return}function gVa(b){b=b|0;var d=0,e=0;do{if((c[b+80620>>2]|0)==0){d=b|0;if((c[d>>2]|0)>0){e=0}else{break}do{a[b+8+e|0]=e;e=e+1|0;}while((e|0)<(c[d>>2]|0))}else{a[b+8|0]=1;a[b+9|0]=2;a[b+10|0]=4}}while(0);fVa(b+20|0);fVa(b+1320|0);e=0;do{fVa(b+2620+(e*5200|0)|0);fVa(b+2620+(e*5200|0)+1300|0);fVa(b+2620+(e*5200|0)+2600|0);fVa(b+2620+(e*5200|0)+3900|0);e=e+1|0;}while((e|0)<15);return}function hVa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;j=e+16|0;k=We[c[j>>2]&2047](e,b+5204|0)|0;do{if((k|0)==1){l=We[c[j>>2]&2047](e,b+3904|0)|0;m=(We[c[j>>2]&2047](e,b+2604|0)|0)+1|0;do{if((m|0)>2){n=((h+1|0)/2|0)-2|0;if((n|0)<1){o=-1;return o|0}else{p=(We[c[e+20>>2]&2047](e,n)|0)+3|0;break}}else{p=m}}while(0);if(!(p>>>0<h>>>0)){o=-1;return o|0}m=(l|0)==0?p:h-p|0;if((m|0)<1){o=-1;return o|0}if((hVa(b,e,f,g,m,i)|0)!=0){o=-1;return o|0}if((hVa(b,e,m+f|0,g,h-m|0,i)|0)==0){break}else{o=-1}return o|0}else if((k|0)==0){m=We[c[j>>2]&2047](e,b+3904|0)|0;n=(We[c[j>>2]&2047](e,b+2604|0)|0)+1|0;do{if((n|0)>2){q=((i+1|0)/2|0)-2|0;if((q|0)<1){o=-1;return o|0}else{r=(We[c[e+20>>2]&2047](e,q)|0)+3|0;break}}else{r=n}}while(0);if(!(r>>>0<i>>>0)){o=-1;return o|0}n=(m|0)==0?r:i-r|0;if((n|0)<1){o=-1;return o|0}if((hVa(b,e,f,g,h,n)|0)!=0){o=-1;return o|0}if((hVa(b,e,f,n+g|0,h,i-n|0)|0)==0){break}else{o=-1}return o|0}else if((k|0)==2){n=c[b>>2]|0;if((c[n+1064>>2]|0)!=0){iVa(b,e,f,g,h,i);o=0;return o|0}if((We[c[j>>2]&2047](e,b+1304|0)|0)==0){l=We[c[j>>2]&2047](e,b+87148|0)|0;a:do{if((l|0)<(c[b+87132>>2]|0)){s=d[b+87136+l|0]|0;t=l}else{q=We[c[j>>2]&2047](e,b+88448|0)|0;u=(c[b+87128>>2]|0)-1|0;v=0;while(1){if((v|0)>=(u|0)){s=q;t=v;break a}if((d[b+87136+v|0]|0|0)==(q|0)){s=q;t=v;break}else{v=v+1|0}}}}while(0);if((t|0)!=0){if((t|0)>0){l=t;while(1){m=l-1|0;a[b+87136+l|0]=a[b+87136+m|0]|0;if((m|0)>0){l=m}else{break}}}a[b+87136|0]=s}do{if((c[(c[n>>2]|0)+696>>2]&8|0)==0){w=32}else{if((c[n+1048>>2]|0)==0){if((s|0)==128){w=71;break}else if((s|0)==255){w=39;break}else{o=-1}return o|0}else{if((s-1|0)>>>0>1>>>0&(s|0)!=4){o=-1}else{w=32;break}return o|0}}}while(0);b:do{if((w|0)==32){if((s|0)==128){w=71;break}else if((s|0)==4){o=mVa(n,f,g,h,i)|0;return o|0}else if((s|0)!=2){w=39;break}l=n+1052|0;m=c[l>>2]|0;if((m|0)==0){w=71;break}v=i+g|0;if((i|0)<=0){w=71;break}q=n+1048|0;u=n+1056|0;x=f*3|0;y=h*3|0;z=n+1028|0;A=n+1036|0;B=n+1032|0;C=g;D=m;while(1){m=(ca(c[u>>2]|0,C)|0)+x|0;nrc((c[q>>2]|0)+m|0,D+m|0,y)|0;m=(ca(c[A>>2]|0,C)|0)+f|0;nrc((c[z>>2]|0)+m|0,(c[B>>2]|0)+m|0,h)|0;m=C+1|0;if((m|0)>=(v|0)){w=71;break b}C=m;D=c[l>>2]|0}}}while(0);if((w|0)==39){iVa(b,e,f,g,h,i);o=0;return o|0}else if((w|0)==71){o=0;return o|0}}l=n+1040|0;D=n+1044|0;nVa(e,c[l>>2]|0,0,f,g,h,i,c[D>>2]|0,0,b+87128|0,n+4|0);C=n+1028|0;v=n+1036|0;B=c[v>>2]|0;z=c[D>>2]|0;D=b+6504|0;A=n+1048|0;y=n+1056|0;if((i|0)<=0){o=0;return o|0}q=c[y>>2]|0;x=(ca(z,g)|0)+f|0;u=(ca(B,g)|0)+f|0;m=(ca(q,g)|0)+(f*3|0)|0;E=(h|0)>0;F=n|0;G=b+6524|0;H=b+6508|0;I=b+6512|0;J=b+7824|0;K=D|0;L=h-1|0;M=n+1052|0;N=n+1032|0;O=(c[l>>2]|0)+x|0;x=(c[C>>2]|0)+u|0;u=0;l=(c[A>>2]|0)+m|0;m=q;c:while(1){if(E){q=u+g|0;P=q+1|0;Q=0;do{do{if((c[(c[F>>2]|0)+696>>2]&8|0)==0){R=a[O+Q|0]|0}else{S=a[O+Q|0]|0;if((c[A>>2]|0)==0){if((S<<24>>24|0)==(-128|0)|(S<<24>>24|0)==(-1|0)){R=S;break}else{o=-1;w=73;break c}}else{if((S<<24>>24|0)==1|(S<<24>>24|0)==2|(S<<24>>24|0)==4){R=S;break}else{o=-1;w=73;break c}}}}while(0);d:do{if((R<<24>>24|0)==4){if((mVa(n,Q+f|0,q,1,1)|0)!=0){o=-1;w=73;break c}}else if((R<<24>>24|0)==2){S=Q+f|0;T=c[M>>2]|0;if((T|0)==0){break}U=S*3|0;V=q;W=T;while(1){T=(ca(c[y>>2]|0,V)|0)+U|0;X=(c[A>>2]|0)+T|0;Y=W+T|0;a[X]=a[Y]|0;a[X+1|0]=a[Y+1|0]|0;a[X+2|0]=a[Y+2|0]|0;Y=(ca(c[v>>2]|0,V)|0)+S|0;a[(c[C>>2]|0)+Y|0]=a[(c[N>>2]|0)+Y|0]|0;Y=V+1|0;if((Y|0)>=(P|0)){break d}V=Y;W=c[M>>2]|0}}else if((R<<24>>24|0)!=(-128|0)){do{if((Q|u|0)==0){W=We[c[j>>2]&2047](e,G)|0;e:do{if((W|0)<(c[H>>2]|0)){Z=d[b+6512+W|0]|0;_=W}else{V=We[c[j>>2]&2047](e,J)|0;S=(c[K>>2]|0)-1|0;U=0;while(1){if((U|0)>=(S|0)){Z=V;_=U;break e}if((d[b+6512+U|0]|0|0)==(V|0)){Z=V;_=U;break}else{U=U+1|0}}}}while(0);if((_|0)==0){$=Z;break}if((_|0)>0){W=_;while(1){U=W-1|0;a[b+6512+W|0]=a[b+6512+U|0]|0;if((U|0)>0){W=U}else{break}}}a[I]=Z;$=Z}else{$=oVa(e,D,x+Q|0,B,Q,u,L-Q|0)|0}}while(0);a[x+Q|0]=$;if((c[A>>2]|0)==0){break}W=n+4+($<<2)|0;U=Q*3|0;a[l+(U+2)|0]=c[W>>2];a[l+(U+1)|0]=(c[W>>2]|0)>>>8;a[l+U|0]=(c[W>>2]|0)>>>16}}while(0);Q=Q+1|0;}while((Q|0)<(h|0));aa=c[y>>2]|0}else{aa=m}Q=u+1|0;if((Q|0)<(i|0)){O=O+z|0;x=x+B|0;u=Q;l=l+aa|0;m=aa}else{o=0;w=73;break}}if((w|0)==73){return o|0}}else{o=-1;return o|0}}while(0);o=0;return o|0}function iVa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=c[b>>2]|0;k=e+16|0;if((We[c[k>>2]&2047](e,b+4|0)|0)!=0){nVa(e,c[j+1028>>2]|0,c[j+1048>>2]|0,f,g,h,i,c[j+1036>>2]|0,c[j+1056>>2]|0,b+6504|0,j+4|0);return}l=c[j+1036>>2]|0;m=c[j+1056>>2]|0;n=(c[j+1028>>2]|0)+((ca(l,g)|0)+f)|0;o=j+1048|0;p=(c[o>>2]|0)+((ca(m,g)|0)+(f*3|0))|0;f=We[c[k>>2]&2047](e,b+6524|0)|0;a:do{if((f|0)<(c[b+6508>>2]|0)){q=d[b+6512+f|0]|0;r=f}else{g=We[c[k>>2]&2047](e,b+7824|0)|0;s=(c[b+6504>>2]|0)-1|0;t=0;while(1){if((t|0)>=(s|0)){q=g;r=t;break a}if((d[b+6512+t|0]|0|0)==(g|0)){q=g;r=t;break}else{t=t+1|0}}}}while(0);if((r|0)!=0){if((r|0)>0){e=r;while(1){r=e-1|0;a[b+6512+e|0]=a[b+6512+r|0]|0;if((r|0)>0){e=r}else{break}}}a[b+6512|0]=q}b=c[j+4+(q<<2)>>2]|0;if((i|0)<=0){return}j=q&255;q=h*3|0;e=b&255;r=b>>>8&255;k=b>>>16&255;b=0;f=n;n=p;while(1){mrc(f|0,j|0,h|0)|0;if(!((c[o>>2]|0)==0|(q|0)<1)){p=0;do{a[n+(p+2)|0]=e;a[n+(p+1)|0]=r;a[n+p|0]=k;p=p+3|0;}while((p|0)<(q|0))}p=b+1|0;if((p|0)<(i|0)){b=p;f=f+l|0;n=n+m|0}else{break}}return}function jVa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0;j=i;l=c[a>>2]|0;m=l+100|0;n=c[m>>2]|0;if((n|0)<820){KIb(l,16,2495416,(o=i,i=i+8|0,c[o>>2]=n,o)|0);i=o;p=-1094995529;i=j;return p|0}q=l+96|0;r=c[q>>2]|0;s=r;t=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;if(t>>>0<n>>>0){KIb(l,16,2599392,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=n,o)|0);i=o;p=-1094995529;i=j;return p|0}n=r+20|0;t=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=l+128|0;c[n>>2]=t;s=r+24|0;u=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;s=l+132|0;c[s>>2]=u;if((t|0)>4096|(u|0)>4096){KIb(l,16,2449336,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=u,o)|0);i=o;p=-1094995529;i=j;return p|0}v=l;if((t|0)<1|(u|0)<1){KIb(v,16,2360128,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=u,o)|0);i=o;p=-1094995529;i=j;return p|0}u=r+4|0;t=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;u=r+8|0;r=je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0;KIb(v,48,2296152,(o=i,i=i+16|0,c[o>>2]=t,c[o+8>>2]=r,o)|0);i=o;r=c[q>>2]|0;t=r+4|0;if(((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)>>>0>1>>>0|0)!=(b|0)){KIb(v,16,2245112,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1;i=j;return p|0}t=r+48|0;r=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;c[a+1060>>2]=r;if(r>>>0>256>>>0){KIb(v,16,2203680,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;p=-1094995529;i=j;return p|0}KIb(v,48,2171768,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;r=c[q>>2]|0;t=r+12|0;u=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=r+16|0;r=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;KIb(v,48,2144184,(o=i,i=i+16|0,c[o>>2]=u,c[o+8>>2]=r,o)|0);i=o;r=c[s>>2]|0;KIb(v,48,2120584,(o=i,i=i+16|0,c[o>>2]=c[n>>2],c[o+8>>2]=r,o)|0);i=o;r=(c[q>>2]|0)+28|0;n=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;w=(c[k>>2]=n,+g[k>>2]);KIb(v,48,2638352,(o=i,i=i+8|0,h[o>>3]=w,o)|0);i=o;n=(c[q>>2]|0)+32|0;r=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;KIb(v,48,2615432,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;r=(c[q>>2]|0)+36|0;n=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;w=(c[k>>2]=n,+g[k>>2]);KIb(v,48,2588488,(o=i,i=i+8|0,h[o>>3]=w,o)|0);i=o;n=(c[q>>2]|0)+40|0;r=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;w=(c[k>>2]=r,+g[k>>2]);KIb(v,48,2567096,(o=i,i=i+8|0,h[o>>3]=w,o)|0);i=o;r=(c[q>>2]|0)+44|0;n=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;w=(c[k>>2]=n,+g[k>>2]);KIb(v,48,2548720,(o=i,i=i+8|0,h[o>>3]=w,o)|0);i=o;n=(b|0)!=0;do{if(n){r=c[m>>2]|0;if((r|0)<828){KIb(v,16,2530952,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;p=-1094995529;i=j;return p|0}r=(c[q>>2]|0)+52|0;s=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;c[a+1080>>2]=s;KIb(v,48,2515600,(o=i,i=i+8|0,c[o>>2]=s,o)|0);i=o;s=(c[q>>2]|0)+56|0;r=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;c[a+1084>>2]=r;if(!((r-2|0)>>>0>254>>>0)){KIb(v,48,2488760,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;break}KIb(v,16,2501720,(o=i,i=i+8|0,c[o>>2]=r,o)|0);i=o;p=-1094995529;i=j;return p|0}else{c[a+1080>>2]=0;c[a+1084>>2]=256}}while(0);m=n?60:52;n=c[q>>2]|0;q=0;do{r=(q*3|0)+m|0;c[a+4+(q<<2)>>2]=(d[n+r|0]|0)<<16|(d[n+(r+1)|0]|0)<<8|(d[n+(r+2)|0]|0)|-16777216;q=q+1|0;}while((q|0)<256);q=(c[l+120>>2]|0)+15&-16;c[a+1044>>2]=q;n=hJb(ca(q,c[l+124>>2]|0)|0)|0;c[a+1040>>2]=n;if((n|0)==0){KIb(v,16,2477824,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-12;i=j;return p|0}c[e>>2]=a;o=a+1084|0;kVa(e,b,c[o>>2]|0);if((c[a+1080>>2]|0)!=0){c[f>>2]=a;kVa(f,b,c[o>>2]|0)}c[a+1076>>2]=1;p=0;i=j;return p|0}function kVa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[a+1292>>2]=2;c[a+1296>>2]=-1;c[a+1300>>2]=-2;c[a+2592>>2]=2;c[a+2596>>2]=-1;c[a+2600>>2]=-2;c[a+6492>>2]=3;c[a+6496>>2]=50;c[a+6500>>2]=150;c[a+5192>>2]=2;c[a+5196>>2]=50;c[a+5200>>2]=100;c[a+3892>>2]=3;c[a+3896>>2]=15;c[a+3900>>2]=45;c[a+6504>>2]=12;c[a+6508>>2]=8;c[a+87124>>2]=0;c[a+7812>>2]=9;c[a+7816>>2]=15;c[a+7820>>2]=135;c[a+9112>>2]=d;c[a+9116>>2]=50;e=d*50|0;c[a+9120>>2]=e;f=0;g=0;while(1){h=f+2|0;i=(f|0)!=0?15:-1;j=ca(i,h)|0;k=c[601968+(f<<2)>>2]|0;l=(k|0)>1;m=0;n=g;while(1){c[a+9124+(n*5200|0)+1288>>2]=h;c[a+9124+(n*5200|0)+1292>>2]=i;c[a+9124+(n*5200|0)+1296>>2]=j;c[a+9124+(n*5200|0)+2588>>2]=h;c[a+9124+(n*5200|0)+2592>>2]=i;c[a+9124+(n*5200|0)+2596>>2]=j;c[a+9124+(n*5200|0)+3888>>2]=h;c[a+9124+(n*5200|0)+3892>>2]=i;c[a+9124+(n*5200|0)+3896>>2]=j;c[a+9124+(n*5200|0)+5188>>2]=h;c[a+9124+(n*5200|0)+5192>>2]=i;c[a+9124+(n*5200|0)+5196>>2]=j;o=m+1|0;if((o|0)<(k|0)){m=o;n=n+1|0}else{break}}n=f+1|0;if((n|0)<4){f=n;g=(l?k:1)+g|0}else{break}}g=(b|0)!=0;b=g?3:2;c[a+87128>>2]=b|4;c[a+87132>>2]=b;c[a+167748>>2]=g&1;g=b+1|0;c[a+88436>>2]=g;c[a+88440>>2]=15;c[a+88444>>2]=g*15|0;c[a+89736>>2]=d;c[a+89740>>2]=50;c[a+89744>>2]=e;e=0;d=0;while(1){g=e+2|0;b=(e|0)!=0?15:-1;f=ca(b,g)|0;n=c[601968+(e<<2)>>2]|0;m=(n|0)>1;j=0;i=d;while(1){c[a+89748+(i*5200|0)+1288>>2]=g;c[a+89748+(i*5200|0)+1292>>2]=b;c[a+89748+(i*5200|0)+1296>>2]=f;c[a+89748+(i*5200|0)+2588>>2]=g;c[a+89748+(i*5200|0)+2592>>2]=b;c[a+89748+(i*5200|0)+2596>>2]=f;c[a+89748+(i*5200|0)+3888>>2]=g;c[a+89748+(i*5200|0)+3892>>2]=b;c[a+89748+(i*5200|0)+3896>>2]=f;c[a+89748+(i*5200|0)+5188>>2]=g;c[a+89748+(i*5200|0)+5192>>2]=b;c[a+89748+(i*5200|0)+5196>>2]=f;h=j+1|0;if((h|0)<(n|0)){j=h;i=i+1|0}else{break}}i=e+1|0;if((i|0)<4){e=i;d=(m?n:1)+d|0}else{break}}return}function lVa(a){a=a|0;mJb(a+1040|0);return 0}function mVa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=(c[a+1068>>2]|0)+b|0;if((g|0)<0){h=-1;return h|0}i=c[a>>2]|0;if((g+e|0)>(c[i+120>>2]|0)){h=-1;return h|0}j=(c[a+1072>>2]|0)+d|0;if((j|0)<0){h=-1;return h|0}if((j+f|0)>(c[i+124>>2]|0)){h=-1;return h|0}i=c[a+1048>>2]|0;if((i|0)==0){h=-1;return h|0}k=c[a+1028>>2]|0;l=a+1036|0;m=c[l>>2]|0;n=k+((ca(m,d)|0)+b)|0;o=a+1056|0;p=c[o>>2]|0;q=i+((ca(p,d)|0)+(b*3|0))|0;b=c[a+1052>>2]|0;if((b|0)==0){r=i+((ca(p,j)|0)+(g*3|0))|0;s=k+((ca(m,j)|0)+g)|0}else{r=b+((ca(p,j)|0)+(g*3|0))|0;s=(c[a+1032>>2]|0)+((ca(m,j)|0)+g)|0}if((f|0)<=0){h=0;return h|0}g=e*3|0;j=n;n=q;q=s;s=r;r=0;while(1){orc(j|0,q|0,e|0)|0;orc(n|0,s|0,g|0)|0;m=c[l>>2]|0;a=c[o>>2]|0;p=r+1|0;if((p|0)<(f|0)){j=j+m|0;n=n+a|0;q=q+m|0;s=s+a|0;r=p}else{h=0;break}}return h|0}function nVa(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((j|0)<=0){return}o=(i|0)>0;p=b+16|0;q=m+20|0;r=m+4|0;s=m+8|0;t=m+1320|0;u=m|0;v=(f|0)==0;w=i-1|0;x=e+((ca(k,h)|0)+g)|0;e=0;y=f+((ca(l,h)|0)+(g*3|0))|0;while(1){a:do{if(o){if(v){z=0}else{g=0;while(1){do{if((g|e|0)==0){h=We[c[p>>2]&2047](b,q)|0;b:do{if((h|0)<(c[r>>2]|0)){A=d[m+8+h|0]|0;B=h}else{f=We[c[p>>2]&2047](b,t)|0;C=(c[u>>2]|0)-1|0;D=0;while(1){if((D|0)>=(C|0)){A=f;B=D;break b}if((d[m+8+D|0]|0|0)==(f|0)){A=f;B=D;break}else{D=D+1|0}}}}while(0);if((B|0)==0){E=A;break}if((B|0)>0){h=B;while(1){D=h-1|0;a[m+8+h|0]=a[m+8+D|0]|0;if((D|0)>0){h=D}else{break}}}a[s]=A;E=A}else{E=oVa(b,m,x+g|0,k,g,e,w-g|0)|0}}while(0);a[x+g|0]=E;h=n+(E<<2)|0;D=g*3|0;a[y+(D+2)|0]=c[h>>2];a[y+(D+1)|0]=(c[h>>2]|0)>>>8;a[y+D|0]=(c[h>>2]|0)>>>16;g=g+1|0;if((g|0)>=(i|0)){break a}}}do{do{if((z|e|0)==0){g=We[c[p>>2]&2047](b,q)|0;if((g|0)<(c[r>>2]|0)){F=a[m+8+g|0]|0;G=g}else{g=We[c[p>>2]&2047](b,t)|0;h=(c[u>>2]|0)-1|0;D=0;while(1){if((D|0)>=(h|0)){break}if((d[m+8+D|0]|0|0)==(g|0)){break}else{D=D+1|0}}F=g&255;G=D}if((G|0)==0){H=F;break}if((G|0)>0){h=G;while(1){f=h-1|0;a[m+8+h|0]=a[m+8+f|0]|0;if((f|0)>0){h=f}else{break}}}a[s]=F;H=F}else{H=(oVa(b,m,x+z|0,k,z,e,w-z|0)|0)&255}}while(0);a[x+z|0]=H;z=z+1|0;}while((z|0)<(i|0))}}while(0);h=e+1|0;if((h|0)<(j|0)){x=x+k|0;e=h;y=y+l|0}else{break}}return}function oVa(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;l=i;i=i+8|0;m=l|0;do{if((j|0)==0){n=a[f-1|0]|0;o=n;p=n;q=n;r=n}else{n=a[f+(-g|0)|0]|0;if((h|0)==0){s=n;t=n}else{s=a[f-1|0]|0;t=a[f+~g|0]|0}if((k|0)==0){o=s;p=n;q=t;r=n;break}o=s;p=n;q=t;r=a[f+(1-g)|0]|0}}while(0);if((h|0)>1){u=(a[f-2|0]|0)==o<<24>>24|0}else{u=0}if((j|0)>1){v=(a[f+(g*-2|0)|0]|0)==p<<24>>24?u|2:u}else{v=u}a[m|0]=q;u=0;while(1){if((u|0)>=1){break}if((a[m+u|0]|0)==p<<24>>24){break}else{u=u+1|0}}if((u|0)==1){a[m+1|0]=p;w=2}else{w=1}u=0;while(1){if((u|0)>=(w|0)){break}if((a[m+u|0]|0)==r<<24>>24){break}else{u=u+1|0}}if((u|0)==(w|0)){a[m+w|0]=r;x=w+1|0}else{x=w}w=0;while(1){if((w|0)>=(x|0)){break}if((a[m+w|0]|0)==o<<24>>24){break}else{w=w+1|0}}if((w|0)==(x|0)){a[m+x|0]=o;y=x+1|0}else{y=x}do{if((y|0)==3){if(p<<24>>24==q<<24>>24){z=8;break}if(r<<24>>24==q<<24>>24){z=9;break}if(o<<24>>24==q<<24>>24){z=10;break}if(r<<24>>24==p<<24>>24){z=11;break}z=p<<24>>24==o<<24>>24?12:13}else if((y|0)==4){z=14}else if((y|0)==2){x=r<<24>>24==q<<24>>24;if(p<<24>>24==q<<24>>24){if(x){z=1;break}z=o<<24>>24==q<<24>>24?2:3;break}w=o<<24>>24==q<<24>>24;if(x){z=w?4:5;break}else{z=w?6:7;break}}else{z=0}}while(0);q=b+16|0;o=We[c[q>>2]&2047](b,e+2620+(z*5200|0)+(v*1300|0)|0)|0;if((o|0)<(y|0)){A=d[m+o|0]|0;i=l;return A|0}o=We[c[q>>2]&2047](b,e+20|0)|0;a:do{if((o|0)<(c[e+4>>2]|0)){v=c[e>>2]|0;b:do{if((v|0)>0){z=0;p=0;while(1){r=e+8+z|0;w=0;while(1){if((w|0)>=(y|0)){break}if((a[r]|0)==(a[m+w|0]|0)){break}else{w=w+1|0}}if((w|0)==(y|0)){if((p|0)==(o|0)){B=z;break b}C=p+1|0}else{C=p}r=z+1|0;if((r|0)<(v|0)){z=r;p=C}else{B=r;break}}}else{B=0}}while(0);p=v-1|0;z=(B|0)>(p|0)?p:B;D=d[e+8+z|0]|0;E=z}else{z=We[c[q>>2]&2047](b,e+1320|0)|0;p=(c[e>>2]|0)-1|0;r=0;while(1){if((r|0)>=(p|0)){D=z;E=r;break a}if((d[e+8+r|0]|0)==(z|0)){D=z;E=r;break}else{r=r+1|0}}}}while(0);if((E|0)==0){A=D;i=l;return A|0}if((E|0)>0){b=E;while(1){E=b-1|0;a[e+8+b|0]=a[e+8+E|0]|0;if((E|0)>0){b=E}else{break}}}a[e+8|0]=D;A=D;i=l;return A|0}function pVa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a+60|0;d=c[b>>2]|0;e=d+19632|0;c[e>>2]=a;f=jVa(e,1,d+20736|0,d+188488|0)|0;if((f|0)!=0){g=f;return g|0}f=d+19628|0;c[f>>2]=UHb()|0;e=c[d+20676>>2]|0;h=d+20668|0;c[h>>2]=e;i=a+124|0;j=d+20660|0;c[j>>2]=pJb(ca(c[i>>2]|0,e)|0)|0;e=pJb(ca(c[i>>2]|0,c[h>>2]|0)|0)|0;c[d+20664>>2]=e;do{if(!((c[j>>2]|0)==0|(e|0)==0)){if((c[f>>2]|0)==0){break}h=c[b>>2]|0;i=h;c[h+4>>2]=a;k=Q6a(i)|0;do{if((k|0)<0){l=k}else{v7a(h+15332|0);c[h+15660>>2]=1;c[h+15996>>2]=1246232;c[h+16e3>>2]=1246168;c[h+15584>>2]=0;c[h+15580>>2]=0;c[h+15664>>2]=7;c[h+15668>>2]=31;c[h+15588>>2]=0;c[h+15592>>2]=0;c[h+15596>>2]=1;c[h+15680>>2]=0;c[h+15684>>2]=0;c[h+15688>>2]=1;c[h+15692>>2]=1;c[h+15600>>2]=0;c[h+15696>>2]=0;c[h+19616>>2]=0;c[h+15604>>2]=0;c[a+156>>2]=0;c[h+68>>2]=0;c[h+15700>>2]=0;c[h+15704>>2]=0;c[h+15608>>2]=1;Z6a(i);m=EUa(a)|0;if((m|0)<0){l=m;break}m=Y6a(i)|0;if((m|0)<0){l=m;break}c[h+12452>>2]=h+10680;c[h+12456>>2]=h+10808;vVa(d+20720|0);c[a+140>>2]=(c[d+20692>>2]|0)==127?46:2;g=0;return g|0}}while(0);h=c[b>>2]|0;VHb(h+19628|0);lVa(h+19632|0)|0;mJb(h+20660|0);mJb(h+20664|0);_6a(a)|0;g=l;return g|0}}while(0);l=c[b>>2]|0;VHb(l+19628|0);lVa(l+19632|0)|0;mJb(l+20660|0);mJb(l+20664|0);_6a(a)|0;g=-12;return g|0}function qVa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0;j=i;i=i+464|0;k=j|0;l=j+24|0;m=j+40|0;n=j+64|0;o=c[h+24>>2]|0;p=h+28|0;h=c[p>>2]|0;q=e+60|0;r=c[q>>2]|0;s=r+19632|0;t=f;u=h>>>0>268435455>>>0?-8:h<<3;v=u>>>0>2147483639>>>0|(o|0)==0;w=v?0:o;x=v?0:u;u=k|0;c[u>>2]=w;y=k+12|0;c[y>>2]=x;z=x+8|0;A=k+16|0;c[A>>2]=z;B=k+4|0;c[B>>2]=w+(x>>3);x=k+8|0;c[x>>2]=0;if(v){C=v?-1094995529:0;i=j;return C|0}v=(d[w]|0)>>>7;D=(z|0)>0;E=(v|0)!=0;if(E){F=D?8:7;G=z>>>0>F>>>0?F:z}else{G=D&1}c[x>>2]=G;D=(d[w+(G>>>3)|0]|0)<<(G&7)>>>7;F=((G|0)<(z|0))+G|0;c[x>>2]=F;G=D&1;if(E){H=0;I=F}else{D=(d[w+(F>>>3)|0]|0)<<(F&7)>>>7;J=((F|0)<(z|0))+F|0;c[x>>2]=J;H=D&1;I=J}J=d[w+(I>>>3)|0]|0;D=((I|0)<(z|0))+I|0;c[x>>2]=D;F=(J&128>>>((I&7)>>>0)|0)!=0;if(F){I=d[w+(D>>>3)|0]|0;J=((D|0)<(z|0))+D|0;c[x>>2]=J;K=(I&128>>>((D&7)>>>0)|0)!=0;L=J}else{K=0;L=D}D=K&1;J=r+20712|0;I=c[J>>2]|0;do{if((I|0)>0){c[r+19624>>2]=I}else{if((I|0)>=0){c[r+19624>>2]=c[e+124>>2];break}M=d[w+(L>>>3)|0]|0;N=((L|0)<(z|0))+L|0;c[x>>2]=N;if((M&128>>>((L&7)>>>0)|0)==0){if(!E){break}c[r+19624>>2]=(c[e+124>>2]|0)/2|0;break}M=d[w+(N>>>3)|0]|0;O=((N|0)<(z|0))+N|0;c[x>>2]=O;P=w+(O>>>3)|0;if((M&128>>>((N&7)>>>0)|0)==0){N=P;M=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(O&7)>>>24;N=O+8|0;c[x>>2]=z>>>0>N>>>0?N:z;c[r+19624>>2]=M<<4;break}M=d[P]|0;P=((O|0)<(z|0))+O|0;c[x>>2]=P;N=w+(P>>>3)|0;Q=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(P&7);if((M&128>>>((O&7)>>>0)|0)==0){O=P+12|0;c[x>>2]=z>>>0>O>>>0?O:z;c[r+19624>>2]=Q>>>20;break}else{O=P+16|0;c[x>>2]=z>>>0>O>>>0?O:z;c[r+19624>>2]=Q>>>16;break}}}while(0);do{if((c[J>>2]|0)!=0){z=c[r+19624>>2]|0;if((z|0)<(D^1|0)){C=-1094995529;i=j;return C|0}if((z|0)>((c[e+124>>2]|0)-1|0)){C=-1094995529}else{break}i=j;return C|0}}while(0);D=c[x>>2]|0;z=-D&7;if((z|0)==0){R=D}else{w=c[A>>2]|0;L=z+D|0;D=w>>>0>L>>>0?L:w;c[x>>2]=D;R=D}D=R>>3;R=o+D|0;w=h-D|0;if((w|0)<1){C=-1094995529;i=j;return C|0}do{if(K){if((H|G|0)!=0){C=-1094995529;i=j;return C|0}if((c[J>>2]|0)==0){break}if((c[r+19624>>2]|0)==0){break}else{C=-1094995529}i=j;return C|0}}while(0);L=K?46:2;z=e+140|0;c[z>>2]=L;I=r+19628|0;Q=c[I>>2]|0;if((c[Q+80>>2]|0)!=(L|0)){WHb(Q)}Q=(G|0)!=0;do{if(Q){if(!((w+2|0)>-1)){KIb(0,0,2296024,(S=i,i=i+24|0,c[S>>2]=2548704,c[S+8>>2]=2530880,c[S+16>>2]=135,S)|0);i=S;Hd();return 0}G=l|0;c[G>>2]=R;c[l+8>>2]=R;L=o+(h+2)|0;c[l+4>>2]=L;O=m|0;c[O>>2]=0;P=m+4|0;c[P>>2]=16777215;if((L-R|0)<3){T=0}else{c[G>>2]=o+(D+3);T=(d[o+(D+1)|0]|0)<<8|(d[R]|0)<<16|(d[o+(D+2)|0]|0)}G=m+8|0;c[G>>2]=T;c[m+12>>2]=l;c[m+16>>2]=1e3;c[m+20>>2]=804;L=(T<<1|0)>16777214;if(L){c[O>>2]=8388608;U=16777215;V=8388608}else{c[P>>2]=8388607;U=8388607;V=0}M=m+12|0;if(((U>>>15)-(V>>>15)|0)<2){N=U;W=V;X=T;while(1){if(((N^W)&65536|0)==0){Y=N;Z=W;_=X}else{$=N^32768;c[P>>2]=$;aa=X^32768;c[G>>2]=aa;ba=W^32768;c[O>>2]=ba;Y=$;Z=ba;_=aa}aa=Y<<8&16776960;ba=aa|255;c[P>>2]=ba;$=c[M>>2]|0;da=$|0;ea=c[da>>2]|0;if(((c[$+4>>2]|0)-ea|0)<1){fa=0}else{c[da>>2]=ea+1;fa=d[ea]|0}ea=fa|_<<8&16776960;c[G>>2]=ea;da=Z<<8&16776960;c[O>>2]=da;if(((aa>>>15)-(da>>>15)|0)<2){N=ba;W=da;X=ea}else{ga=ba;ha=da;ia=ea;break}}}else{ga=U;ha=V;ia=T}X=L&1^1;W=e+120|0;N=e+124|0;ea=0;da=ga;ba=ha;aa=ia;while(1){$=((aa<<1)-ba|0)>=(da|0);ja=(da+1-ba>>1)+ba|0;if($){c[O>>2]=ja;ka=da;la=ja}else{ma=ja-1|0;c[P>>2]=ma;ka=ma;la=ba}if(((ka>>15)-(la>>15)|0)<2){ma=ka;ja=la;na=aa;while(1){if(((ma^ja)&65536|0)==0){oa=ma;pa=ja;qa=na}else{ra=ma^32768;c[P>>2]=ra;sa=na^32768;c[G>>2]=sa;ta=ja^32768;c[O>>2]=ta;oa=ra;pa=ta;qa=sa}sa=oa<<8&16776960;ta=sa|255;c[P>>2]=ta;ra=c[M>>2]|0;ua=ra|0;va=c[ua>>2]|0;if(((c[ra+4>>2]|0)-va|0)<1){wa=0}else{c[ua>>2]=va+1;wa=d[va]|0}va=wa|qa<<8&16776960;c[G>>2]=va;ua=pa<<8&16776960;c[O>>2]=ua;if(((sa>>>15)-(ua>>>15)|0)<2){ma=ta;ja=ua;na=va}else{xa=ta;ya=ua;break}}}else{xa=ka;ya=la}if(!$){break}if((ea|0)==20){C=-1094995529;za=254;break}na=c[W>>2]|0;if((ea|0)==0){ja=sVa(m,na)|0;c[n+4>>2]=ja;Aa=ja}else{ja=c[n+((ea-1|0)*20|0)+4>>2]|0;ma=ja+(sVa(m,na-ja|0)|0)|0;c[n+(ea*20|0)+4>>2]=ma;Aa=ma}ma=sVa(m,c[N>>2]|0)|0;c[n+(ea*20|0)+8>>2]=ma;c[n+(ea*20|0)+12>>2]=(sVa(m,(c[W>>2]|0)-Aa|0)|0)+1;c[n+(ea*20|0)+16>>2]=(sVa(m,(c[N>>2]|0)-ma|0)|0)+1;ea=ea+1|0;da=c[P>>2]|0;ba=c[O>>2]|0;aa=c[G>>2]|0}if((za|0)==254){i=j;return C|0}if(!(L|(ea|0)==0)){KIb(e,16,2449296,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}if(L){if((ea|0)>0){Ba=ea;za=67}else{Ca=0;Da=xa;Ea=ya;Fa=ea}}else{c[n+4>>2]=0;c[n+8>>2]=0;c[n+12>>2]=c[W>>2];c[n+16>>2]=c[N>>2];Ba=1;za=67}do{if((za|0)==67){aa=0;ba=0;while(1){if(L){da=c[P>>2]|0;ma=c[O>>2]|0;ja=c[G>>2]|0;na=((ja<<1)-ma|0)>=(da|0);ua=(da+1-ma>>1)+ma|0;if(na){c[O>>2]=ua;Ga=da;Ha=ua}else{da=ua-1|0;c[P>>2]=da;Ga=da;Ha=ma}if(((Ga>>15)-(Ha>>15)|0)<2){ma=Ga;da=Ha;ua=ja;do{if(((ma^da)&65536|0)==0){Ia=ma;Ja=da;Ka=ua}else{ja=ma^32768;c[P>>2]=ja;ta=ua^32768;c[G>>2]=ta;va=da^32768;c[O>>2]=va;Ia=ja;Ja=va;Ka=ta}ta=Ia<<8&16776960;ma=ta|255;c[P>>2]=ma;va=c[M>>2]|0;ja=va|0;sa=c[ja>>2]|0;if(((c[va+4>>2]|0)-sa|0)<1){La=0}else{c[ja>>2]=sa+1;La=d[sa]|0}ua=La|Ka<<8&16776960;c[G>>2]=ua;da=Ja<<8&16776960;c[O>>2]=da;}while(((ta>>>15)-(da>>>15)|0)<2)}if(na){break}}do{if((aa|0)==0){da=c[P>>2]|0;ua=c[O>>2]|0;ma=c[G>>2]|0;ta=((ma<<1)-ua|0)>=(da|0);sa=(da+1-ua>>1)+ua|0;if(ta){c[O>>2]=sa;Ma=da;Na=sa}else{da=sa-1|0;c[P>>2]=da;Ma=da;Na=ua}if(((Ma>>15)-(Na>>15)|0)<2){ua=Ma;da=Na;sa=ma;do{if(((ua^da)&65536|0)==0){Oa=ua;Pa=da;Qa=sa}else{ma=ua^32768;c[P>>2]=ma;ja=sa^32768;c[G>>2]=ja;va=da^32768;c[O>>2]=va;Oa=ma;Pa=va;Qa=ja}ja=Oa<<8&16776960;ua=ja|255;c[P>>2]=ua;va=c[M>>2]|0;ma=va|0;ra=c[ma>>2]|0;if(((c[va+4>>2]|0)-ra|0)<1){Ra=0}else{c[ma>>2]=ra+1;Ra=d[ra]|0}sa=Ra|Qa<<8&16776960;c[G>>2]=sa;da=Pa<<8&16776960;c[O>>2]=da;}while(((ja>>>15)-(da>>>15)|0)<2)}if(!ta){Sa=(ta^1)<<31>>31;break}Sa=sVa(m,256)|0}else{Sa=ba}}while(0);c[n+(aa*20|0)>>2]=sVa(m,2)|0;na=aa+1|0;if((na|0)<(Ba|0)){aa=na;ba=Sa}else{za=93;break}}if((za|0)==93){Ca=Sa;Da=c[P>>2]|0;Ea=c[O>>2]|0;Fa=Ba;break}KIb(e,16,2360088,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}}while(0);O=Da>>16;P=Ea>>16;G=O-P|0;L=c[M>>2]|0;N=(c[L>>2]|0)-(c[L+8>>2]|0)<<3;L=(G&128|0)==0;if(L){W=G;ea=1;while(1){ba=ea+1|0;aa=W<<1;if((aa&128|0)==0){W=aa;ea=ba}else{Ta=ba;break}}}else{Ta=1}ea=N-17|0;W=(P+1|0)==(O|0)|0;M=o+(W+D+(ea+Ta>>3))|0;if(L){ba=G;aa=1;while(1){$=aa+1|0;na=ba<<1;if((na&128|0)==0){ba=na;aa=$}else{Ua=$;break}}}else{Ua=1}aa=w-W-(ea+Ua>>3)|0;if((aa|0)<1){C=-1094995529}else{Va=M;Wa=aa;Xa=Fa;Ya=Ca;Za=X;break}i=j;return C|0}else{Va=R;Wa=w;Xa=0;Ya=0;Za=0}}while(0);w=r+20704|0;c[w>>2]=0;R=r+20700|0;c[R>>2]=0;do{if(K|E^1){if((H|0)==0){_a=Wa;$a=Va;za=112;break}Ca=Wa-4|0;if((Ca|0)<1){C=-1094995529;i=j;return C|0}else{Fa=Va;Ua=(he((d[Fa]|d[Fa+1|0]<<8)<<16>>16|0)|0)&65535;Fa=Ua-(c[e+120>>2]|0)|0;c[R>>2]=Fa;Ua=Va+2|0;Ta=(he((d[Ua]|d[Ua+1|0]<<8)<<16>>16|0)|0)&65535;c[w>>2]=Ta-(c[e+124>>2]|0);ab=Va+4|0;bb=Ca;cb=Fa;za=111;break}}else{Fa=c[r+20692>>2]|0;Ca=s+4+(256-Fa<<2)|0;if((Fa|0)==0){db=0;eb=0}else{Ta=a[Va]|0;Ua=Ta&255;if((Ua|0)>(Fa|0)){C=-1094995529;i=j;return C|0}Fa=Ua*3|0;if((Fa+2|0)>(Wa|0)){C=-1094995529;i=j;return C|0}if(Ta<<24>>24==0){fb=0}else{Ta=0;D=Ca;while(1){Ca=Ta*3|0;c[D>>2]=(d[Va+(Ca+2)|0]|0)<<8|(d[Va+(Ca+1)|0]|0)<<16|(d[Va+(Ca+3)|0]|0);Ca=Ta+1|0;if((Ca|0)<(Ua|0)){Ta=Ca;D=D+4|0}else{break}}fb=c[R>>2]|0}db=Fa+1|0;eb=fb}ab=Va+db|0;bb=Wa-db|0;cb=eb;za=111}}while(0);if((za|0)==111){if((cb|0)<0){gb=bb;hb=ab;za=113}else{_a=bb;$a=ab;za=112}}do{if((za|0)==112){if((c[w>>2]|0)<0){gb=_a;hb=$a;za=113;break}ab=N4a(e,c[I>>2]|0)|0;if((ab|0)<0){C=ab;i=j;return C|0}ab=YHb(t,c[I>>2]|0)|0;if((ab|0)<0){C=ab;i=j;return C|0}else{c[r+20684>>2]=0;ib=c[e+124>>2]|0;jb=c[f+32>>2]|0;kb=_a;lb=$a;break}}}while(0);do{if((za|0)==113){$a=r+20664|0;_a=c[$a>>2]|0;ab=r+20660|0;c[$a>>2]=c[ab>>2];c[ab>>2]=_a;_a=M4a(e,t,1)|0;if((_a|0)<0){C=_a;i=j;return C|0}_a=c[I>>2]|0;ab=c[_a>>2]|0;if((ab|0)==0){KIb(e,16,2171696,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}$a=c[f+32>>2]|0;if(($a|0)==(c[_a+32>>2]|0)){_a=c[e+124>>2]|0;c[r+20684>>2]=ab+(ca(_a-1|0,$a)|0);ib=_a;jb=$a;kb=gb;lb=hb;break}else{KIb(0,0,2296024,(S=i,i=i+24|0,c[S>>2]=2245040,c[S+8>>2]=2203536,c[S+16>>2]=600,S)|0);i=S;Hd();return 0}}}while(0);hb=e+124|0;gb=r+20680|0;c[gb>>2]=(c[f>>2]|0)+(ca(ib-1|0,jb)|0);ib=r+20688|0;c[ib>>2]=-jb;c[f+84>>2]=v;c[f+88>>2]=E?1:2;do{if(K){if(!((kb|0)>-1)){KIb(0,0,2296024,(S=i,i=i+24|0,c[S>>2]=2548704,c[S+8>>2]=2530880,c[S+16>>2]=135,S)|0);i=S;Hd();return 0}f=l|0;c[f>>2]=lb;c[l+8>>2]=lb;jb=lb+kb|0;c[l+4>>2]=jb;$a=c[gb>>2]|0;_a=c[ib>>2]>>1;ab=c[e+120>>2]|0;bb=c[hb>>2]|0;do{if((v|0)==0){cb=jb;if((kb|0)<1){mb=0;nb=lb}else{eb=lb+1|0;c[f>>2]=eb;mb=(d[lb]|0)<<4;nb=eb}if((cb-nb|0)<1){ob=0;pb=nb}else{eb=nb+1|0;c[f>>2]=eb;ob=d[nb]|0;pb=eb}eb=ob>>>4|mb;if((cb-pb|0)<1){qb=0;rb=pb}else{db=pb+1|0;c[f>>2]=db;qb=d[pb]|0;rb=db}db=qb|ob<<8&3840;if((cb-rb|0)<1){sb=0;tb=rb}else{Wa=rb+1|0;c[f>>2]=Wa;sb=(d[rb]|0)<<4;tb=Wa}if((cb-tb|0)<1){ub=0;vb=tb}else{Wa=tb+1|0;c[f>>2]=Wa;ub=d[tb]|0;vb=Wa}Wa=ub>>>4|sb;if((cb-vb|0)<1){wb=0;xb=vb}else{cb=vb+1|0;c[f>>2]=cb;wb=d[vb]|0;xb=cb}cb=wb|ub<<8&3840;if((cb|0)>=(bb|0)|(db|0)>=(ab|0)|(eb|0)>(db|0)|(Wa|0)>(cb|0)){C=-1094995529;i=j;return C|0}else{yb=$a+((ca(Wa,_a)|0)+eb<<1)|0;zb=(Wa|0)!=0|0;Ab=1-Wa+cb|0;Bb=1-eb+db|0;Cb=xb;break}}else{yb=$a;zb=0;Ab=bb;Bb=ab;Cb=lb}}while(0);ab=-_a|0;bb=yb;$a=zb;Fa=0;db=0;eb=Ab;cb=Cb;while(1){Wa=bb+(Bb<<1)|0;Va=Wa;if(($a|0)==0){fb=bb;s=Fa;H=db;D=cb;while(1){Ta=s-1|0;a:do{if((s|0)<1){Ua=jb;do{if((Ua-D|0)<1){Db=0;Eb=D}else{X=D+1|0;c[f>>2]=X;M=a[D]|0;ea=M&255;if(M<<24>>24>-1){Db=ea;Eb=X;break}if(!((M&255)>>>0>129>>>0)){Fb=Ta;Gb=127-ea|0;Hb=X;za=155;break a}if((M&255)>>>0>130>>>0){M=0;W=ea;ea=X;while(1){Ca=W-1|0;if((Ua-ea|0)<1){Ib=0;Jb=ea}else{o=ea+1|0;c[f>>2]=o;Ib=d[ea]|0;Jb=o}o=(Ib|M<<8)+1|0;if((Ca|0)>130){M=o;W=Ca;ea=Jb}else{Kb=o;Lb=Jb;break}}}else{Kb=0;Lb=X}if(!((H|0)==-2)){Fb=Kb;Gb=H;Hb=Lb;za=155;break a}ea=Va-fb>>1;W=Kb>>>0>ea>>>0?ea:Kb;Mb=-2;Nb=Kb-W|0;Ob=fb+(W<<1)|0;Pb=Lb;break a}}while(0);if((Ua-Eb|0)<1){Qb=0;Rb=Eb}else{ta=Eb+1|0;c[f>>2]=ta;Qb=d[Eb]|0;Rb=ta}Fb=Ta;Gb=Qb|Db<<8;Hb=Rb;za=155}else{Fb=Ta;Gb=H;Hb=D;za=155}}while(0);do{if((za|0)==155){za=0;if(!((Gb|0)>-1)){Mb=Gb;Nb=Fb;Ob=fb;Pb=Hb;break}b[fb>>1]=Gb;Mb=Gb;Nb=Fb;Ob=fb;Pb=Hb}}while(0);Ta=Ob+2|0;if(Ta>>>0<Wa>>>0){fb=Ta;s=Nb;H=Mb;D=Pb}else{Sb=Nb;Tb=Mb;Ub=Pb;break}}}else{D=bb;H=Fa;s=db;fb=cb;while(1){Ta=H-1|0;b:do{if((H|0)<1){ta=jb;do{if((ta-fb|0)<1){Vb=0;Wb=fb}else{W=fb+1|0;c[f>>2]=W;ea=a[fb]|0;M=ea&255;if(ea<<24>>24>-1){Vb=M;Wb=W;break}if(!((ea&255)>>>0>129>>>0)){Xb=Ta;Yb=127-M|0;Zb=W;za=173;break b}if((ea&255)>>>0>130>>>0){ea=0;o=M;M=W;while(1){Ca=o-1|0;if((ta-M|0)<1){_b=0;$b=M}else{Ea=M+1|0;c[f>>2]=Ea;_b=d[M]|0;$b=Ea}Ea=(_b|ea<<8)+1|0;if((Ca|0)>130){ea=Ea;o=Ca;M=$b}else{ac=Ea;bc=$b;break}}}else{ac=0;bc=W}if(!((s|0)==-2)){Xb=ac;Yb=s;Zb=bc;za=173;break b}M=Va-D>>1;o=ac>>>0>M>>>0?M:ac;cc=-2;dc=ac-o|0;ec=D+(o<<1)|0;fc=bc;break b}}while(0);if((ta-Wb|0)<1){gc=0;hc=Wb}else{Ua=Wb+1|0;c[f>>2]=Ua;gc=d[Wb]|0;hc=Ua}Xb=Ta;Yb=gc|Vb<<8;Zb=hc;za=173}else{Xb=Ta;Yb=s;Zb=fb;za=173}}while(0);do{if((za|0)==173){za=0;if((Yb|0)>-1){b[D>>1]=Yb;cc=Yb;dc=Xb;ec=D;fc=Zb;break}if(!((Yb|0)==-1)){cc=Yb;dc=Xb;ec=D;fc=Zb;break}b[D>>1]=b[D+(ab<<1)>>1]|0;cc=-1;dc=Xb;ec=D;fc=Zb}}while(0);Ta=ec+2|0;if(Ta>>>0<Wa>>>0){D=Ta;H=dc;s=cc;fb=fc}else{Sb=dc;Tb=cc;Ub=fc;break}}}fb=eb-1|0;if((fb|0)==0){break}else{bb=bb+(_a<<1)|0;$a=1;Fa=Sb;db=Tb;eb=fb;cb=Ub}}ic=lb;jc=kb-Ub+lb|0}else{do{if(E){c[r+20708>>2]=0;eVa(r+20736|0);if((c[J>>2]|0)==0){break}eVa(r+188488|0)}}while(0);if(F){cb=kb>>>0>268435455>>>0?-8:kb<<3;eb=cb>>>0>2147483639>>>0|(lb|0)==0;db=eb?0:lb;Fa=eb?0:cb;c[u>>2]=db;c[y>>2]=Fa;c[A>>2]=Fa+8;c[B>>2]=db+(Fa>>3);c[x>>2]=0;if(eb){C=eb?-1094995529:0;i=j;return C|0}eb=r+20660|0;Fa=r+20668|0;db=r+19636|0;cb=r+19624|0;$a=e+120|0;_a=tVa(k,c[eb>>2]|0,c[Fa>>2]|0,c[gb>>2]|0,c[ib>>2]|0,db,v,c[cb>>2]|0,0,c[$a>>2]|0,c[hb>>2]|0)|0;if((_a|0)!=0){C=_a;i=j;return C|0}_a=c[x>>2]|0;bb=-_a&7;if((bb|0)==0){kc=_a}else{ab=c[A>>2]|0;f=bb+_a|0;_a=ab>>>0>f>>>0?f:ab;c[x>>2]=_a;kc=_a}do{if((c[J>>2]|0)==0){lc=kc}else{_a=tVa(k,c[eb>>2]|0,c[Fa>>2]|0,c[gb>>2]|0,c[ib>>2]|0,db,v,c[cb>>2]|0,1,c[$a>>2]|0,c[hb>>2]|0)|0;if((_a|0)==0){lc=c[x>>2]|0;break}else{C=_a;i=j;return C|0}}}while(0);$a=-lc&7;if(($a|0)==0){mc=lc}else{cb=c[A>>2]|0;db=$a+lc|0;$a=cb>>>0>db>>>0?db:cb;c[x>>2]=$a;mc=$a}$a=mc>>3;ic=lb+$a|0;jc=kb-$a|0;break}if((Za|0)!=0&(Ya|0)==-1){mrc(c[r+20660>>2]|0,0,ca(c[hb>>2]|0,c[r+20668>>2]|0)|0)|0;ic=lb;jc=kb;break}$a=r+20708|0;if((c[$a>>2]|0)!=0){C=-1094995529;i=j;return C|0}cb=kb+2|0;if(!((cb|0)>-1)){KIb(0,0,2296024,(S=i,i=i+24|0,c[S>>2]=2548704,c[S+8>>2]=2530880,c[S+16>>2]=135,S)|0);i=S;Hd();return 0}db=l|0;c[db>>2]=lb;Fa=l+8|0;c[Fa>>2]=lb;eb=l+4|0;c[eb>>2]=lb+cb;cb=m|0;c[cb>>2]=0;_a=m+4|0;c[_a>>2]=16777215;if((kb+2|0)<3){nc=0}else{c[db>>2]=lb+3;nc=(d[lb+1|0]|0)<<8|(d[lb]|0)<<16|(d[lb+2|0]|0)}ab=m+8|0;c[ab>>2]=nc;f=m+12|0;bb=l;c[f>>2]=bb;jb=m+16|0;c[jb>>2]=1e3;fb=m+20|0;c[fb>>2]=804;c[r+20696>>2]=v;s=e+120|0;H=r+19624|0;D=hVa(r+20736|0,m,0,0,c[s>>2]|0,c[H>>2]|0)|0;c[$a>>2]=D;if((D|0)!=0){C=-1094995529;i=j;return C|0}D=c[_a>>2]>>16;Wa=c[cb>>2]>>16;Va=D-Wa|0;Ta=m+12|0;Ua=c[Ta>>2]|0;o=(c[Ua>>2]|0)-(c[Ua+8>>2]|0)<<3;Ua=(Va&128|0)==0;if(Ua){M=Va;ea=1;while(1){X=ea+1|0;Ea=M<<1;if((Ea&128|0)==0){M=Ea;ea=X}else{oc=X;break}}}else{oc=1}ea=o-17|0;M=(Wa+1|0)==(D|0)|0;X=(ea+oc>>3)+M|0;Ea=lb+X|0;if(Ua){Ca=Va;Da=1;while(1){Ba=Da+1|0;Sa=Ca<<1;if((Sa&128|0)==0){Ca=Sa;Da=Ba}else{pc=Ba;break}}}else{pc=1}Da=kb-M-(ea+pc>>3)|0;if((c[J>>2]|0)==0){ic=Ea;jc=Da;break}if((Da|0)<1){C=-1094995529;i=j;return C|0}Ca=Da+2|0;if(!((Ca|0)>-1)){KIb(0,0,2296024,(S=i,i=i+24|0,c[S>>2]=2548704,c[S+8>>2]=2530880,c[S+16>>2]=135,S)|0);i=S;Hd();return 0}c[db>>2]=Ea;c[Fa>>2]=Ea;Va=lb+(Ca+X)|0;c[eb>>2]=Va;c[cb>>2]=0;c[_a>>2]=16777215;if((Va-Ea|0)<3){qc=0}else{c[db>>2]=lb+(X+3);qc=(d[lb+(X+1)|0]|0)<<8|(d[Ea]|0)<<16|(d[lb+(X+2)|0]|0)}c[ab>>2]=qc;c[f>>2]=bb;c[jb>>2]=1e3;c[fb>>2]=804;Va=c[H>>2]|0;Ca=hVa(r+188488|0,m,0,Va,c[s>>2]|0,(c[hb>>2]|0)-Va|0)|0;c[$a>>2]=Ca;if((Ca|0)!=0){C=-1094995529;i=j;return C|0}Ca=c[_a>>2]>>16;Va=c[cb>>2]>>16;Ua=Ca-Va|0;D=c[Ta>>2]|0;Wa=(c[D>>2]|0)-(c[D+8>>2]|0)<<3;D=(Ua&128|0)==0;if(D){o=Ua;Ba=1;while(1){Sa=Ba+1|0;Pa=o<<1;if((Pa&128|0)==0){o=Pa;Ba=Sa}else{rc=Sa;break}}}else{rc=1}Ba=Wa-17|0;o=(Va+1|0)==(Ca|0)|0;Ta=lb+(o+X+(Ba+rc>>3))|0;if(D){cb=Ua;_a=1;while(1){$a=_a+1|0;s=cb<<1;if((s&128|0)==0){cb=s;_a=$a}else{sc=$a;break}}}else{sc=1}ic=Ta;jc=Da-o-(Ba+sc>>3)|0}}while(0);c:do{if(Q&(Xa|0)>0){sc=(Ya|0)==-1;rc=r+20728|0;lb=r+20660|0;hb=r+20668|0;m=e+848|0;qc=0;J=jc;pc=ic;d:while(1){kb=c[n+(qc*20|0)+4>>2]|0;oc=c[n+(qc*20|0)+8>>2]|0;v=c[n+(qc*20|0)+12>>2]|0;l=c[n+(qc*20|0)+16>>2]|0;do{if((c[n+(qc*20|0)>>2]|0)==0){nc=c[ib>>2]|0;Za=(c[gb>>2]|0)+((ca(nc,oc)|0)+(kb*3|0))|0;if(!sc){mc=c[hb>>2]|0;x=(c[lb>>2]|0)+((ca(mc,oc)|0)+kb)|0;Se[c[rc>>2]&1023](Za,nc,Ya,x,mc,v,l);tc=pc;uc=J;break}mc=v*3|0;x=Za;Za=l;while(1){mrc(x|0,-128|0,mc|0)|0;nc=Za-1|0;if((nc|0)==0){tc=pc;uc=J;break}else{x=x+(c[ib>>2]|0)|0;Za=nc}}}else{if((J|0)<4){C=-1094995529;za=254;break d}Za=(d[pc+1|0]|0)<<8|(d[pc+2|0]|0)<<16|(d[pc]|0);if((Za|0)==0){C=-1094995529;za=254;break d}x=pc+3|0;mc=J-3|0;vc=c[q>>2]|0;nc=vc;lc=vc;PTa(e);A=vc+14120|0;k=mc<<3;kc=mc>>>0>268435455>>>0?-8:k;mc=kc>>>0>2147483639>>>0|(x|0)==0;B=mc?0:x;x=mc?0:kc;c[A>>2]=B;c[vc+14132>>2]=x;c[vc+14136>>2]=x+8;c[vc+14124>>2]=B+(x>>3);c[vc+14128>>2]=0;if(mc){C=-1094995529;za=254;break d}c[vc+13836>>2]=(c[m>>2]|0)<48;if((M6a(nc,A)|0)<0){za=225;break d}if((c[vc+9992>>2]|0)!=1){za=227;break d}c[z>>2]=0;wc=DTa(lc,e)|0;if((wc|0)<0){za=229;break d}STa(lc);c[vc+15576>>2]=k;k=v+15>>4;A=vc+19608|0;c[A>>2]=k;mc=l+15>>4;x=vc+812|0;c[x>>2]=mc;B=vc+16073|0;kc=a[B]|0;if(!((kc&1)==0)){c[A>>2]=k+1>>1}if(!((kc&2)==0)){c[x>>2]=mc+1>>1}T6a(nc);zpb(vc+14424|0);ETa(lc);lc=vc+7624|0;nc=a[B]|0;if((nc<<24>>24|0)==3){B=vc+20732|0;mf[c[B>>2]&2047](c[lc>>2]|0,c[vc+7656>>2]|0,v,l);mc=v+1>>1;x=l+1>>1;mf[c[B>>2]&2047](c[vc+7628>>2]|0,c[vc+7660>>2]|0,mc,x);mf[c[B>>2]&2047](c[vc+7632>>2]|0,c[vc+7664>>2]|0,mc,x)}else if((nc<<24>>24|0)!=0){QIb(c[vc+4>>2]|0,2588448,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}nc=vc+7656|0;x=c[vc+7660>>2]|0;if((x|0)!=(c[vc+7664>>2]|0)){za=238;break d}if(sc){mc=c[vc+20688>>2]|0;B=(c[vc+20680>>2]|0)+((ca(mc,oc)|0)+(kb*3|0))|0;Te[c[vc+20720>>2]&255](B,mc,c[lc>>2]|0,c[nc>>2]|0,c[vc+7628>>2]|0,c[vc+7632>>2]|0,x,v,l)}else{mc=c[vc+20688>>2]|0;B=(c[vc+20680>>2]|0)+((ca(mc,oc)|0)+(kb*3|0))|0;kc=c[vc+20668>>2]|0;k=(c[vc+20660>>2]|0)+((ca(kc,oc)|0)+kb)|0;af[c[vc+20724>>2]&127](B,mc,Ya,k,kc,c[lc>>2]|0,c[nc>>2]|0,c[vc+7628>>2]|0,c[vc+7632>>2]|0,x,v,l)}c[z>>2]=2;x=Za+3|0;tc=pc+x|0;uc=J-x|0}}while(0);l=qc+1|0;if((l|0)<(Xa|0)){qc=l;J=uc;pc=tc}else{xc=uc;break c}}if((za|0)==225){KIb(c[vc+4>>2]|0,16,2120568,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}else if((za|0)==227){KIb(c[vc+4>>2]|0,16,2638328,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;C=-1094995529;i=j;return C|0}else if((za|0)==229){KIb(c[vc+4>>2]|0,16,2615400,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;c[z>>2]=2;C=wc;i=j;return C|0}else if((za|0)==238){KIb(0,0,2296024,(S=i,i=i+24|0,c[S>>2]=2567056,c[S+8>>2]=2203536,c[S+16>>2]=430,S)|0);i=S;Hd();return 0}else if((za|0)==254){i=j;return C|0}}else{xc=jc}}while(0);if((xc|0)!=0){KIb(e,24,2144152,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}if((c[R>>2]|0)<0){za=252}else{if((c[w>>2]|0)<0){za=252}}do{if((za|0)==252){WHb(c[I>>2]|0);w=YHb(c[I>>2]|0,t)|0;if((w|0)<0){C=w}else{break}i=j;return C|0}}while(0);c[g>>2]=1;C=c[p>>2]|0;i=j;return C|0}function rVa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+19628|0);lVa(b+19632|0)|0;mJb(b+20660|0);mJb(b+20664|0);_6a(a)|0;return 0}function sVa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=a+4|0;f=a|0;g=c[f>>2]|0;h=(c[e>>2]|0)-g+1|0;i=h>>>0>65535>>>0;j=i?h>>>16:h;k=i?16:0;if((j&65280|0)==0){l=k;m=j}else{l=k|8;m=j>>>8}j=b>>>0>65535>>>0;k=j?b>>>16:b;i=j?16:0;if((k&65280|0)==0){n=i;o=k}else{n=i|8;o=k>>>8}k=(d[1359664+m|0]|0)+l-n-(d[1359664+o|0]|0)|0;o=(((b<<k|0)>(h|0))<<31>>31)+k|0;k=a+8|0;n=c[k>>2]|0;l=n-g|0;m=(b<<o<<1)-h|0;if((m|0)<(l|0)){p=(l-m>>1)+m|0}else{p=l}l=p>>o;p=l<<o;h=l+1<<o;if((m|0)<(h|0)){q=(h-m<<1)+m|0}else{q=h}h=q-1+g|0;c[e>>2]=h;if((m|0)<(p|0)){r=(p-m<<1)+m+g|0}else{r=g+p|0}c[f>>2]=r;if(((h>>15)-(r>>15)|0)>=2){return l|0}p=a+12|0;a=h;h=r;r=n;do{if(((a^h)&65536|0)==0){s=a;t=h;u=r}else{n=a^32768;c[e>>2]=n;g=r^32768;c[k>>2]=g;m=h^32768;c[f>>2]=m;s=n;t=m;u=g}g=s<<8&16776960;a=g|255;c[e>>2]=a;m=c[p>>2]|0;n=m|0;q=c[n>>2]|0;if(((c[m+4>>2]|0)-q|0)<1){v=0}else{c[n>>2]=q+1;v=d[q]|0}r=v|u<<8&16776960;c[k>>2]=r;h=t<<8&16776960;c[f>>2]=h;}while(((g>>>15)-(h>>>15)|0)<2);return l|0}function tVa(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;q=i;i=i+1376|0;r=q|0;s=q+272|0;t=q+1352|0;u=r|0;mrc(u|0,0,270)|0;v=270-l|0;do{if((l|0)==0){w=e+8|0;x=c[w>>2]|0;y=c[e+16>>2]|0;z=c[e>>2]|0;A=z+(x>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(x&7)>>>20;A=x+12|0;x=y>>>0>A>>>0?A:y;c[w>>2]=x;A=z+(x>>>3)|0;C=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(x&7)>>>20;A=x+12|0;x=y>>>0>A>>>0?A:y;c[w>>2]=x;A=z+(x>>>3)|0;D=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(x&7)>>>20;A=x+12|0;x=y>>>0>A>>>0?A:y;c[w>>2]=x;A=D+1|0;D=z+(x>>>3)|0;z=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(x&7)>>>20;D=x+12|0;c[w>>2]=y>>>0>D>>>0?D:y;y=z+1|0;if((A+B|0)>(o|0)){E=-1094995529;i=q;return E|0}if((y+C|0)>(p|0)){E=-1094995529;i=q;return E|0}else{F=f+((ca(C,g)|0)+B)|0;G=h+((ca(C,j)|0)+(B*3|0))|0;H=A;I=y;J=(C|0)!=0|0;break}}else{if((n|0)<=0){F=f;G=h;H=o;I=m;J=0;break}F=f+(ca(m,g)|0)|0;G=h+(ca(m,j)|0)|0;H=o;I=p-m|0;J=1}}while(0);m=e+8|0;p=e+16|0;o=e|0;e=204-l|0;h=14-l|0;l=0;f=0;n=0;C=0;a:while(1){y=l;A=f;B=n;while(1){K=A-1|0;if((A|0)!=0){break}L=y+1|0;M=B<<1;z=(1<<L)-M|0;D=z<<1;w=D>>>0>65535>>>0;x=w?z>>>15&65535:D;D=w?16:0;if((x&65280|0)==0){N=D;O=x}else{N=D|8;O=x>>>8}x=(d[1359664+O|0]|0)+N|0;D=c[m>>2]|0;w=c[p>>2]|0;P=(c[o>>2]|0)+(D>>>3)|0;Q=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(D&7)>>>((32-x|0)>>>0);P=x+D|0;c[m>>2]=w>>>0>P>>>0?P:w;if((L|0)>22|(Q|0)>(z|0)){E=-1094995529;R=51;break a}if((Q|0)==(z|0)){R=20;break a}else{y=L;A=Q;B=M}}A=c[m>>2]|0;Q=c[p>>2]|0;z=c[o>>2]|0;w=z+(A>>>3)|0;P=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(A&7);w=P>>>24;D=A+8|0;A=Q>>>0>D>>>0?D:Q;c[m>>2]=A;do{if((w|0)<(e|0)){if(!(P>>>0>3187671039>>>0)){S=w;break}D=d[z+(A>>>3)|0]<<(A&7)>>>7;c[m>>2]=((A|0)<(Q|0))+A;S=(D&1|w<<1)-190|0}else{S=h+w|0}}while(0);w=r+S|0;if((a[w]|0)!=0){E=-1094995529;R=51;break}a[w]=y;c[s+(S<<2)>>2]=B;l=y;f=K;n=B+1|0;C=C+1|0}if((R|0)==20){n=C-v|0;C=L;L=M;while(1){M=L<<1;T=(2<<C)-M+n|0;if((T|0)<0){C=C+1|0;L=M}else{break}}if((v|0)>0){n=L;M=T;T=0;K=C;while(1){f=r+T|0;if((a[f]|0)==0){if((M|0)==0){U=K+1|0;V=n<<1}else{U=K;V=n}a[f]=U;c[s+(T<<2)>>2]=V;W=U;X=M-1|0;Y=V+1|0}else{W=K;X=M;Y=n}f=T+1|0;if((f|0)<(v|0)){n=Y;M=X;T=f;K=W}else{Z=Y;_=W;break}}}else{Z=L;_=C}if((Z|0)!=(1<<_|0)){E=-1094995529;i=q;return E|0}_=$2(t,9,v,u,1,1,s,4,4,0,0,0,0)|0;if((_|0)!=0){E=_;i=q;return E|0}_=t+4|0;s=-g|0;u=-j|0;v=F;F=G;G=I;I=J;J=0;Z=0;while(1){C=v+H|0;L=C;W=(I|0)==0;Y=F;K=v;T=J;X=Z;while(1){M=T-1|0;do{if((T|0)<1){n=c[_>>2]|0;V=c[m>>2]|0;U=c[p>>2]|0;r=c[o>>2]|0;f=r+(V>>>3)|0;l=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(V&7)>>>23;f=b[n+(l<<2)>>1]|0;S=b[n+(l<<2)+2>>1]|0;l=S<<16>>16;do{if(S<<16>>16<0){h=V+9|0;e=U>>>0>h>>>0?h:U;h=r+(e>>>3)|0;N=((je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(e&7)>>>((l+32|0)>>>0))+f|0;h=b[n+(N<<2)>>1]|0;O=b[n+(N<<2)+2>>1]|0;N=O<<16>>16;if(!(O<<16>>16<0)){$=N;aa=h;ba=e;break}O=e-l|0;e=U>>>0>O>>>0?O:U;O=r+(e>>>3)|0;w=((je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(e&7)>>>((N+32|0)>>>0))+h|0;$=b[n+(w<<2)+2>>1]|0;aa=b[n+(w<<2)>>1]|0;ba=e}else{$=l;aa=f;ba=V}}while(0);V=$+ba|0;f=U>>>0>V>>>0?V:U;c[m>>2]=f;if((aa|0)<256){da=M;ea=aa;R=44;break}if((aa|0)>=268){da=M;ea=267-aa|0;R=44;break}V=aa-256|0;if((aa|0)==256){fa=0;ga=0}else if((aa|0)==267){l=r+(f>>>3)|0;n=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(f&7)>>>28;l=f+4|0;S=U>>>0>l>>>0?l:U;c[m>>2]=S;ha=n+10|0;ia=S;R=40}else{ha=V;ia=f;R=40}if((R|0)==40){R=0;f=r+(ia>>>3)|0;V=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(ia&7)>>>((32-ha|0)>>>0);f=ia+ha|0;c[m>>2]=U>>>0>f>>>0?f:U;fa=V;ga=ha}V=(1<<ga)-1+fa|0;if(!((X|0)==-2)){da=V;ea=X;R=44;break}f=L-K|0;S=(V|0)>(f|0)?f:V;ja=-2;ka=V-S|0;la=K+S|0;ma=Y+(S*3|0)|0}else{da=M;ea=X;R=44}}while(0);do{if((R|0)==44){R=0;if((ea|0)>-1){a[K]=ea;M=k+(ea<<2)|0;a[Y+2|0]=c[M>>2];a[Y+1|0]=(c[M>>2]|0)>>>8;a[Y]=(c[M>>2]|0)>>>16;ja=ea;ka=da;la=K;ma=Y;break}if((ea|0)!=-1|W){ja=ea;ka=da;la=K;ma=Y;break}a[K]=a[K+s|0]|0;M=Y+u|0;a[Y]=a[M]|0;a[Y+1|0]=a[M+1|0]|0;a[Y+2|0]=a[M+2|0]|0;ja=-1;ka=da;la=K;ma=Y}}while(0);M=la+1|0;if(M>>>0<C>>>0){Y=ma+3|0;K=M;T=ka;X=ja}else{break}}X=G-1|0;if((X|0)==0){break}else{v=v+g|0;F=F+j|0;G=X;I=1;J=ka;Z=ja}}c3(t);E=0;i=q;return E|0}else if((R|0)==51){i=q;return E|0}return 0}function uVa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=a+4|0;g=a|0;h=c[g>>2]|0;i=(c[f>>2]|0)-h+1|0;j=b[e>>1]|0;k=j<<16>>16;l=i>>>0>65535>>>0;m=l?i>>>16:i;n=l?16:0;if((m&65280|0)==0){o=n;p=m}else{o=n|8;p=m>>>8}m=j<<16>>16<0;j=m?k>>>16:k;n=m?16:0;if((j&65280|0)==0){q=n;r=j}else{q=n|8;r=j>>>8}j=(d[1359664+p|0]|0)+o-q-(d[1359664+r|0]|0)|0;r=(((k<<j|0)>(i|0))<<31>>31)+j|0;j=a+8|0;q=(c[j>>2]|0)-h|0;o=(k<<r<<1)-i|0;if((o|0)<(q|0)){s=(q-o>>1)+o|0}else{s=q}q=s>>r;s=0;while(1){t=s+1|0;u=b[e+(t<<1)>>1]|0;if((u|0)>(q|0)){s=t}else{break}}q=u<<r;u=b[e+(s<<1)>>1]<<r;if((o|0)<(u|0)){v=(u-o<<1)+o|0}else{v=u}c[f>>2]=h-1+v;if((o|0)<(q|0)){w=o+h+(q-o<<1)|0}else{w=q+h|0}c[g>>2]=w;w=d[e+1028+t|0]|0;dVa(e,t);t=c[f>>2]|0;e=c[g>>2]|0;if(((t>>15)-(e>>15)|0)>=2){return w|0}h=a+12|0;a=t;t=e;do{if(((a^t)&65536|0)==0){x=a;y=t;z=c[j>>2]|0}else{e=a^32768;c[f>>2]=e;q=c[j>>2]^32768;c[j>>2]=q;o=t^32768;c[g>>2]=o;x=e;y=o;z=q}q=x<<8&16776960;a=q|255;c[f>>2]=a;o=c[h>>2]|0;e=o|0;v=c[e>>2]|0;if(((c[o+4>>2]|0)-v|0)<1){A=0}else{c[e>>2]=v+1;A=d[v]|0}c[j>>2]=A|z<<8&16776960;t=y<<8&16776960;c[g>>2]=t;}while(((q>>>15)-(t>>>15)|0)<2);return w|0}function vVa(a){a=a|0;c[a>>2]=30;c[a+4>>2]=86;c[a+8>>2]=264;c[a+12>>2]=944;return}function wVa(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((k|0)<=0){return}l=(j|0)>0;m=h;h=g;g=0;n=e;e=b;while(1){if(l){b=0;o=0;p=0;while(1){q=d[n+b|0]|0;r=(d[h+o|0]|0)-128|0;s=(d[m+o|0]|0)-128|0;t=((s*91881|0)+32768>>16)+q|0;if(t>>>0>255>>>0){u=-t>>31&255}else{u=t&255}a[e+p|0]=u;t=((r*-22554|0)+32768+(s*-46802|0)>>16)+q|0;if(t>>>0>255>>>0){v=-t>>31&255}else{v=t&255}a[e+(p+1)|0]=v;t=((r*116130|0)+32768>>16)+q|0;if(t>>>0>255>>>0){w=-t>>31&255}else{w=t&255}a[e+(p+2)|0]=w;t=(b&1)+o|0;q=b+1|0;if((q|0)<(j|0)){b=q;o=t;p=p+3|0}else{break}}}p=-(g&1)&i;o=g+1|0;if((o|0)<(k|0)){m=m+p|0;h=h+p|0;g=o;n=n+f|0;e=e+c|0}else{break}}return}function xVa(b,c,e,f,g,h,i,j,k,l,m,n){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((n|0)<=0){return}o=(m|0)>0;p=k;k=j;j=0;q=h;h=f;f=b;while(1){if(o){b=0;r=0;s=0;while(1){if((d[h+b|0]|0|0)==(e|0)){t=d[q+b|0]|0;u=(d[k+r|0]|0)-128|0;v=(d[p+r|0]|0)-128|0;w=((v*91881|0)+32768>>16)+t|0;if(w>>>0>255>>>0){x=-w>>31&255}else{x=w&255}a[f+s|0]=x;w=((u*-22554|0)+32768+(v*-46802|0)>>16)+t|0;if(w>>>0>255>>>0){y=-w>>31&255}else{y=w&255}a[f+(s+1)|0]=y;w=((u*116130|0)+32768>>16)+t|0;if(w>>>0>255>>>0){z=-w>>31&255}else{z=w&255}a[f+(s+2)|0]=z}w=(b&1)+r|0;t=b+1|0;if((t|0)<(m|0)){b=t;r=w;s=s+3|0}else{break}}}s=-(j&1)&l;r=j+1|0;if((r|0)<(n|0)){p=p+s|0;k=k+s|0;j=r;q=q+i|0;h=h+g|0;f=f+c|0}else{break}}return}function yVa(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((i|0)>0&(h|0)>0){j=0;k=f;l=b}else{return}while(1){b=0;f=0;while(1){if((d[k+b|0]|0|0)==(e|0)){a[l+(f+2)|0]=-128;a[l+(f+1)|0]=-128;a[l+f|0]=-128}m=b+1|0;if((m|0)<(h|0)){b=m;f=f+3|0}else{break}}f=j+1|0;if((f|0)<(i|0)){j=f;k=k+g|0;l=l+c|0}else{break}}return}function zVa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((e|0)==0|(f|0)==0){return}g=(e&1)+e|0;e=f-1+(f&1)|0;nrc(b+(ca(e,c)|0)|0,b+(ca(e>>1,c)|0)|0,g)|0;f=e-2|0;if((f|0)>0){h=g-1>>1;i=(h|0)>-1;j=e;k=f;while(1){f=j-1|0;l=ca(f,c)|0;m=ca(k,c)|0;n=ca(f>>1,c)|0;f=ca(k>>1,c)|0;if(i){o=h;while(1){p=d[b+(o+n)|0]|0;q=d[b+(o+f)|0]|0;a[b+(o+l)|0]=(q+2+(p*3|0)|0)>>>2;a[b+(o+m)|0]=(p+2+(q*3|0)|0)>>>2;if((o|0)>0){o=o-1|0}else{break}}}o=k-2|0;if((o|0)>0){j=k;k=o}else{break}}}if(!((e|0)>-1)){return}k=g-1|0;j=k>>1;h=g-3|0;g=(h|0)>0;i=e;while(1){e=ca(i,c)|0;a[b+(e+k)|0]=a[b+(e+j)|0]|0;if(g){o=k;m=h;while(1){l=o-1|0;f=d[b+((m>>1)+e)|0]|0;n=d[b+((l>>1)+e)|0]|0;a[b+(m+e)|0]=(n+1+(f*3|0)|0)>>>2;a[b+(l+e)|0]=(f+1+(n*3|0)|0)>>>2;n=m-2|0;if((n|0)>0){o=m;m=n}else{break}}}if((i|0)>0){i=i-1|0}else{break}}return}function AVa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;d=a+60|0;e=c[d>>2]|0;f=e;c[e>>2]=a;g=a+120|0;do{if((c[g>>2]&15|0)==0){h=a+124|0;if((c[h>>2]&15|0)!=0){break}c[e+8>>2]=0;j=e+72704|0;k=0;while(1){if((k|0)>=3){break}l=(k|0)!=0|2;m=c[g>>2]>>l;n=c[h>>2]>>l;c[j+(k*2656|0)+4>>2]=m;c[j+(k*2656|0)+8>>2]=n;l=hJb(ca(m<<2,n)|0)|0;c[j+(k*2656|0)>>2]=l;if((l|0)==0){o=7;break}else{k=k+1|0}}if((o|0)==7){KIb(a,16,2588424,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;VHb(e+4|0);if((k|0)>-1){q=k}else{r=-12;i=b;return r|0}while(1){mJb(j+(q*2656|0)|0);if((q|0)>0){q=q-1|0}else{r=-12;break}}i=b;return r|0}j=UHb()|0;c[e+4>>2]=j;if((j|0)==0){j=c[d>>2]|0;VHb(j+4|0);mJb(j+72704|0);mJb(j+75360|0);mJb(j+78016|0);r=-12;i=b;return r|0}c[a+140>>2]=0;j=0;while(1){k=0;do{h=f+32+(j*744|0)+4+(k*148|0)+128|0;c[h>>2]=5;c[f+32+(j*744|0)+4+(k*148|0)+140>>2]=88;c[f+32+(j*744|0)+4+(k*148|0)+132>>2]=0;l=0;do{c[f+32+(j*744|0)+4+(k*148|0)+(l<<2)>>2]=1;l=l+1|0;s=(c[h>>2]|0)-1|0;}while((l|0)<(s|0));c[f+32+(j*744|0)+4+(k*148|0)+(s<<2)>>2]=0;l=c[h>>2]|0;n=f+32+(j*744|0)+4+(k*148|0)+136|0;c[n>>2]=l;m=f+32+(j*744|0)+4+(k*148|0)+144|0;c[m>>2]=1;FVa(f+32+(j*744|0)+4+(k*148|0)|0,l-1|0);l=(c[h>>2]|0)+6>>1;c[n>>2]=l;c[m>>2]=l;k=k+1|0;}while((k|0)<5);k=f+2264+(j*152|0)+132|0;c[k>>2]=12;c[f+2264+(j*152|0)+144>>2]=144;c[f+2264+(j*152|0)+136>>2]=0;l=0;do{c[f+2264+(j*152|0)+4+(l<<2)>>2]=1;l=l+1|0;t=(c[k>>2]|0)-1|0;}while((l|0)<(t|0));c[f+2264+(j*152|0)+4+(t<<2)>>2]=0;l=c[k>>2]|0;m=f+2264+(j*152|0)+140|0;c[m>>2]=l;n=f+2264+(j*152|0)+148|0;c[n>>2]=1;FVa(f+2264+(j*152|0)+4|0,l-1|0);l=(c[k>>2]|0)+6>>1;c[m>>2]=l;c[n>>2]=l;c[f+2720+(j*23328|0)+2332>>2]=2096;c[f+2720+(j*23328|0)+2324>>2]=66;l=0;do{c[f+2720+(j*23328|0)+(l<<2)>>2]=1;l=l+1|0;}while((l|0)<255);c[f+2720+(j*23328|0)+1020>>2]=0;c[f+2720+(j*23328|0)+2048>>2]=0;l=f+2720+(j*23328|0)+2328|0;c[l>>2]=256;k=f+2720+(j*23328|0)+2336|0;c[k>>2]=1;GVa(f+2720+(j*23328|0)|0,255);c[l>>2]=131;c[k>>2]=131;c[f+2720+(j*23328|0)+4672>>2]=2096;c[f+2720+(j*23328|0)+4664>>2]=66;k=0;do{c[f+2720+(j*23328|0)+2340+(k<<2)>>2]=1;k=k+1|0;}while((k|0)<255);c[f+2720+(j*23328|0)+3360>>2]=0;c[f+2720+(j*23328|0)+4388>>2]=0;k=f+2720+(j*23328|0)+4668|0;c[k>>2]=256;l=f+2720+(j*23328|0)+4676|0;c[l>>2]=1;GVa(f+2720+(j*23328|0)+2340|0,255);c[k>>2]=131;c[l>>2]=131;l=f+2720+(j*23328|0)+4808|0;c[l>>2]=3;c[f+2720+(j*23328|0)+4820>>2]=72;c[f+2720+(j*23328|0)+4812>>2]=0;k=0;do{c[f+2720+(j*23328|0)+4680+(k<<2)>>2]=1;k=k+1|0;u=(c[l>>2]|0)-1|0;}while((k|0)<(u|0));c[f+2720+(j*23328|0)+4680+(u<<2)>>2]=0;k=c[l>>2]|0;n=f+2720+(j*23328|0)+4816|0;c[n>>2]=k;m=f+2720+(j*23328|0)+4824|0;c[m>>2]=1;FVa(f+2720+(j*23328|0)+4680|0,k-1|0);k=(c[l>>2]|0)+6>>1;c[n>>2]=k;c[m>>2]=k;k=0;do{m=f+2720+(j*23328|0)+4828+(k*148|0)+128|0;c[m>>2]=5;c[f+2720+(j*23328|0)+4828+(k*148|0)+140>>2]=88;c[f+2720+(j*23328|0)+4828+(k*148|0)+132>>2]=0;n=0;do{c[f+2720+(j*23328|0)+4828+(k*148|0)+(n<<2)>>2]=1;n=n+1|0;v=(c[m>>2]|0)-1|0;}while((n|0)<(v|0));c[f+2720+(j*23328|0)+4828+(k*148|0)+(v<<2)>>2]=0;n=c[m>>2]|0;h=f+2720+(j*23328|0)+4828+(k*148|0)+136|0;c[h>>2]=n;w=f+2720+(j*23328|0)+4828+(k*148|0)+144|0;c[w>>2]=1;FVa(f+2720+(j*23328|0)+4828+(k*148|0)|0,n-1|0);n=(c[m>>2]|0)+6>>1;c[h>>2]=n;c[w>>2]=n;k=k+1|0;}while((k|0)<125);k=f+72704+(j*2656|0)+272|0;c[k>>2]=12;c[f+72704+(j*2656|0)+284>>2]=144;c[f+72704+(j*2656|0)+276>>2]=0;l=0;do{c[f+72704+(j*2656|0)+144+(l<<2)>>2]=1;l=l+1|0;x=(c[k>>2]|0)-1|0;}while((l|0)<(x|0));c[f+72704+(j*2656|0)+144+(x<<2)>>2]=0;l=c[k>>2]|0;n=f+72704+(j*2656|0)+280|0;c[n>>2]=l;w=f+72704+(j*2656|0)+288|0;c[w>>2]=1;FVa(f+72704+(j*2656|0)+144|0,l-1|0);l=(c[k>>2]|0)+6>>1;c[n>>2]=l;c[w>>2]=l;c[f+72704+(j*2656|0)+2648>>2]=2096;c[f+72704+(j*2656|0)+2640>>2]=66;l=0;do{c[f+72704+(j*2656|0)+316+(l<<2)>>2]=1;l=l+1|0;}while((l|0)<255);c[f+72704+(j*2656|0)+1336>>2]=0;c[f+72704+(j*2656|0)+2364>>2]=0;l=f+72704+(j*2656|0)+2644|0;c[l>>2]=256;k=f+72704+(j*2656|0)+2652|0;c[k>>2]=1;GVa(f+72704+(j*2656|0)+316|0,255);c[l>>2]=131;c[k>>2]=131;k=f+80672+(j*2496|0)+2476|0;c[k>>2]=12;c[f+80672+(j*2496|0)+2488>>2]=144;c[f+80672+(j*2496|0)+2480>>2]=0;l=0;do{c[f+80672+(j*2496|0)+2348+(l<<2)>>2]=1;l=l+1|0;y=(c[k>>2]|0)-1|0;}while((l|0)<(y|0));c[f+80672+(j*2496|0)+2348+(y<<2)>>2]=0;l=c[k>>2]|0;w=f+80672+(j*2496|0)+2484|0;c[w>>2]=l;n=f+80672+(j*2496|0)+2492|0;c[n>>2]=1;FVa(f+80672+(j*2496|0)+2348|0,l-1|0);l=(c[k>>2]|0)+6>>1;c[w>>2]=l;c[n>>2]=l;c[f+80672+(j*2496|0)+2340>>2]=2096;c[f+80672+(j*2496|0)+2332>>2]=66;l=0;do{c[f+80672+(j*2496|0)+8+(l<<2)>>2]=1;l=l+1|0;}while((l|0)<255);c[f+80672+(j*2496|0)+1028>>2]=0;c[f+80672+(j*2496|0)+2056>>2]=0;l=f+80672+(j*2496|0)+2336|0;c[l>>2]=256;k=f+80672+(j*2496|0)+2344|0;c[k>>2]=1;GVa(f+80672+(j*2496|0)+8|0,255);c[l>>2]=131;c[k>>2]=131;k=j+1|0;if((k|0)<3){j=k}else{r=0;break}}i=b;return r|0}}while(0);KIb(a,16,2615352,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;r=-1094995529;i=b;return r|0}function BVa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0;j=i;i=i+96|0;k=j|0;l=j+16|0;m=j+80|0;n=c[h+24>>2]|0;o=c[h+28>>2]|0;h=c[b+60>>2]|0;p=h;q=h+12|0;r=q;if((o|0)<27){KIb(b,16,2449240,(s=i,i=i+16|0,c[s>>2]=27,c[s+8>>2]=o,s)|0);i=s;t=-1094995529;i=j;return t|0}u=n+o|0;v=u;w=n;x=je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;if((x&-770|0)!=0){KIb(b,16,2360064,(s=i,i=i+8|0,c[s>>2]=x,s)|0);i=s;t=-1094995529;i=j;return t|0}w=x&1;x=(w|0)==0;y=w^1;z=v-(n+4)|0;A=z>>>0>6>>>0?6:z;z=n+(A+4)|0;if((v-z|0)<2){B=0;C=z}else{D=z;B=(he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;C=n+(A+6)|0}if((v-C|0)<2){E=0;F=C}else{A=C;E=(he((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535;F=C+2|0}if((v-F|0)<2){G=0;H=F}else{C=F;G=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;H=F+2|0}if((v-H|0)<2){I=0;J=H}else{F=H;I=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;J=H+2|0}do{if((G+B|0)<=(c[b+120>>2]|0)){if((I+E|0)>(c[b+124>>2]|0)){break}if(((I|G)&15|0)!=0){break}H=v-J|0;F=H>>>0>4>>>0?4:H;H=J+F|0;do{if((v-H|0)<1){K=0}else{C=F+1|0;A=d[H]|0;if((A-1|0)>>>0>99>>>0){K=A;break}D=v-(J+C)|0;z=J+((D>>>0>4>>>0?4:D)+C)|0;do{if(x){if((u|0)!=(z|0)){L=h+8|0;break}KIb(b,16,2203440,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=j;return t|0}else{C=h+8|0;if((c[C>>2]|0)==0){L=C;break}else{t=o}i=j;return t|0}}while(0);c[L>>2]=0;C=h+4|0;D=N4a(b,c[C>>2]|0)|0;if((D|0)<0){t=D;i=j;return t|0}D=c[C>>2]|0;c[D+84>>2]=y;c[D+88>>2]=w+1;if((u|0)==(z|0)){M=YHb(f,D)|0;if((M|0)<0){t=M;i=j;return t|0}c[g>>2]=1;t=o;i=j;return t|0}M=17-(((A*7|0)>>>0)/50|0)|0;D=0;do{c[p+32+(D*744|0)>>2]=4;N=0;do{O=p+32+(D*744|0)+4+(N*148|0)|0;c[p+32+(D*744|0)+4+(N*148|0)+132>>2]=0;P=p+32+(D*744|0)+4+(N*148|0)+128|0;Q=(c[P>>2]|0)-1|0;if((Q|0)>0){R=0;while(1){c[p+32+(D*744|0)+4+(N*148|0)+(R<<2)>>2]=1;S=R+1|0;T=(c[P>>2]|0)-1|0;if((S|0)<(T|0)){R=S}else{U=T;break}}}else{U=Q}c[p+32+(D*744|0)+4+(N*148|0)+(U<<2)>>2]=0;R=c[P>>2]|0;T=p+32+(D*744|0)+4+(N*148|0)+136|0;c[T>>2]=R;S=p+32+(D*744|0)+4+(N*148|0)+144|0;c[S>>2]=1;FVa(O,R-1|0);R=(c[P>>2]|0)+6>>1;c[T>>2]=R;c[S>>2]=R;N=N+1|0;}while((N|0)<5);c[p+2264+(D*152|0)>>2]=0;N=p+2264+(D*152|0)+4|0;c[p+2264+(D*152|0)+136>>2]=0;R=p+2264+(D*152|0)+132|0;S=(c[R>>2]|0)-1|0;if((S|0)>0){T=0;while(1){c[p+2264+(D*152|0)+4+(T<<2)>>2]=1;V=T+1|0;W=(c[R>>2]|0)-1|0;if((V|0)<(W|0)){T=V}else{X=W;break}}}else{X=S}c[p+2264+(D*152|0)+4+(X<<2)>>2]=0;T=c[R>>2]|0;W=p+2264+(D*152|0)+140|0;c[W>>2]=T;V=p+2264+(D*152|0)+148|0;c[V>>2]=1;FVa(N,T-1|0);T=(c[R>>2]|0)+6>>1;c[W>>2]=T;c[V>>2]=T;T=0;do{c[p+2720+(D*23328|0)+(T<<2)>>2]=1;T=T+1|0;}while((T|0)<255);c[p+2720+(D*23328|0)+1020>>2]=0;c[p+2720+(D*23328|0)+2048>>2]=0;T=p+2720+(D*23328|0)+2328|0;c[T>>2]=256;R=p+2720+(D*23328|0)+2336|0;c[R>>2]=1;GVa(p+2720+(D*23328|0)|0,255);c[T>>2]=131;c[R>>2]=131;R=0;do{c[p+2720+(D*23328|0)+2340+(R<<2)>>2]=1;R=R+1|0;}while((R|0)<255);c[p+2720+(D*23328|0)+3360>>2]=0;c[p+2720+(D*23328|0)+4388>>2]=0;R=p+2720+(D*23328|0)+4668|0;c[R>>2]=256;T=p+2720+(D*23328|0)+4676|0;c[T>>2]=1;GVa(p+2720+(D*23328|0)+2340|0,255);c[R>>2]=131;c[T>>2]=131;T=p+2720+(D*23328|0)+4680|0;c[p+2720+(D*23328|0)+4812>>2]=0;R=p+2720+(D*23328|0)+4808|0;N=(c[R>>2]|0)-1|0;if((N|0)>0){S=0;while(1){c[p+2720+(D*23328|0)+4680+(S<<2)>>2]=1;V=S+1|0;W=(c[R>>2]|0)-1|0;if((V|0)<(W|0)){S=V}else{Y=W;break}}}else{Y=N}c[p+2720+(D*23328|0)+4680+(Y<<2)>>2]=0;S=c[R>>2]|0;W=p+2720+(D*23328|0)+4816|0;c[W>>2]=S;V=p+2720+(D*23328|0)+4824|0;c[V>>2]=1;FVa(T,S-1|0);S=(c[R>>2]|0)+6>>1;c[W>>2]=S;c[V>>2]=S;S=0;do{V=p+2720+(D*23328|0)+4828+(S*148|0)|0;c[p+2720+(D*23328|0)+4828+(S*148|0)+132>>2]=0;W=p+2720+(D*23328|0)+4828+(S*148|0)+128|0;Z=(c[W>>2]|0)-1|0;if((Z|0)>0){_=0;while(1){c[p+2720+(D*23328|0)+4828+(S*148|0)+(_<<2)>>2]=1;$=_+1|0;aa=(c[W>>2]|0)-1|0;if(($|0)<(aa|0)){_=$}else{ba=aa;break}}}else{ba=Z}c[p+2720+(D*23328|0)+4828+(S*148|0)+(ba<<2)>>2]=0;_=c[W>>2]|0;P=p+2720+(D*23328|0)+4828+(S*148|0)+136|0;c[P>>2]=_;O=p+2720+(D*23328|0)+4828+(S*148|0)+144|0;c[O>>2]=1;FVa(V,_-1|0);_=(c[W>>2]|0)+6>>1;c[P>>2]=_;c[O>>2]=_;S=S+1|0;}while((S|0)<125);S=p+72704+(D*2656|0)+12|0;if((c[S>>2]|0)!=(A|0)){c[S>>2]=A;HVa(p+72704+(D*2656|0)+16|0,A,(D|0)==0|0)}mrc(c[p+72704+(D*2656|0)>>2]|0,0,ca(c[p+72704+(D*2656|0)+4>>2]<<2,c[p+72704+(D*2656|0)+8>>2]|0)|0)|0;S=p+72704+(D*2656|0)+144|0;c[p+72704+(D*2656|0)+276>>2]=0;R=p+72704+(D*2656|0)+272|0;T=(c[R>>2]|0)-1|0;if((T|0)>0){N=0;while(1){c[p+72704+(D*2656|0)+144+(N<<2)>>2]=1;_=N+1|0;O=(c[R>>2]|0)-1|0;if((_|0)<(O|0)){N=_}else{da=O;break}}}else{da=T}c[p+72704+(D*2656|0)+144+(da<<2)>>2]=0;N=c[R>>2]|0;O=p+72704+(D*2656|0)+280|0;c[O>>2]=N;_=p+72704+(D*2656|0)+288|0;c[_>>2]=1;FVa(S,N-1|0);N=(c[R>>2]|0)+6>>1;c[O>>2]=N;c[_>>2]=N;c[p+72704+(D*2656|0)+304>>2]=1;c[p+72704+(D*2656|0)+312>>2]=2;c[p+72704+(D*2656|0)+300>>2]=4096;c[p+72704+(D*2656|0)+308>>2]=8192;c[p+72704+(D*2656|0)+292>>2]=4;c[p+72704+(D*2656|0)+296>>2]=4;N=0;do{c[p+72704+(D*2656|0)+316+(N<<2)>>2]=1;N=N+1|0;}while((N|0)<255);c[p+72704+(D*2656|0)+1336>>2]=0;c[p+72704+(D*2656|0)+2364>>2]=0;N=p+72704+(D*2656|0)+2644|0;c[N>>2]=256;R=p+72704+(D*2656|0)+2652|0;c[R>>2]=1;GVa(p+72704+(D*2656|0)+316|0,255);c[N>>2]=131;c[R>>2]=131;R=p+80672+(D*2496|0)|0;if((c[R>>2]|0)!=(A|0)){c[R>>2]=A;c[p+80672+(D*2496|0)+4>>2]=M}R=p+80672+(D*2496|0)+2348|0;c[p+80672+(D*2496|0)+2480>>2]=0;N=p+80672+(D*2496|0)+2476|0;S=(c[N>>2]|0)-1|0;if((S|0)>0){T=0;while(1){c[p+80672+(D*2496|0)+2348+(T<<2)>>2]=1;_=T+1|0;O=(c[N>>2]|0)-1|0;if((_|0)<(O|0)){T=_}else{ea=O;break}}}else{ea=S}c[p+80672+(D*2496|0)+2348+(ea<<2)>>2]=0;T=c[N>>2]|0;O=p+80672+(D*2496|0)+2484|0;c[O>>2]=T;_=p+80672+(D*2496|0)+2492|0;c[_>>2]=1;FVa(R,T-1|0);T=(c[N>>2]|0)+6>>1;c[O>>2]=T;c[_>>2]=T;T=0;do{c[p+80672+(D*2496|0)+8+(T<<2)>>2]=1;T=T+1|0;}while((T|0)<255);c[p+80672+(D*2496|0)+1028>>2]=0;c[p+80672+(D*2496|0)+2056>>2]=0;T=p+80672+(D*2496|0)+2336|0;c[T>>2]=256;N=p+80672+(D*2496|0)+2344|0;c[N>>2]=1;GVa(p+80672+(D*2496|0)+8|0,255);c[T>>2]=131;c[N>>2]=131;D=D+1|0;}while((D|0)<3);D=n+27|0;M=o-27|0;A=q;c[A>>2]=D;z=h+16|0;c[z>>2]=u;N=h+24|0;c[N>>2]=0;T=(M|0)>4?4:M;if((T|0)>0){M=0;R=0;S=D;while(1){D=S+1|0;c[A>>2]=D;_=d[S]|0|R<<8;c[N>>2]=_;O=M+1|0;if((O|0)<(T|0)){M=O;R=_;S=D}else{break}}}S=h+20|0;c[S>>2]=-1;R=h+28|0;c[R>>2]=0;M=G>>>4;T=I>>>4;D=c[C>>2]|0;_=(c[D>>2]|0)+((ca(c[D+32>>2]|0,E)|0)+B)|0;O=m|0;c[O>>2]=_;P=B>>>1;Q=E>>>1;aa=(c[D+4>>2]|0)+((ca(c[D+36>>2]|0,Q)|0)+P)|0;$=m+4|0;c[$>>2]=aa;fa=(c[D+8>>2]|0)+((ca(c[D+40>>2]|0,Q)|0)+P)|0;P=m+8|0;c[P>>2]=fa;a:do{if((T|0)==0){ga=D}else{Q=(M|0)==0;ha=h+32|0;ia=h+2264|0;ja=h+2720|0;ka=l;la=h+72704|0;ma=h+88160|0;na=ma;oa=h+80672|0;pa=h+88416|0;qa=0;ra=D;sa=_;ta=aa;ua=fa;b:while(1){if(Q){va=ra;wa=sa;xa=ta;ya=ua}else{za=0;while(1){Aa=0;while(1){if((Aa|0)>=3){break}Ba=(Aa|0)==0|0;Ca=ha+(Aa*744|0)|0;Da=c[Ca>>2]|0;Ea=c[S>>2]|0;Fa=Ea>>>15;c[S>>2]=Fa;Ga=c[ha+(Aa*744|0)+4+(Da*148|0)+128>>2]|0;Ha=c[N>>2]|0;Ia=Ga;Ja=Ga>>1;Ga=0;Ka=0;La=Ea;do{Ea=ca(c[ha+(Aa*744|0)+4+(Da*148|0)+64+(Ja<<2)>>2]|0,Fa)|0;Ma=Ea>>>0>Ha>>>0;La=Ma?Ea:La;Ka=Ma?Ka:Ea;Ga=Ma?Ga:Ja;Ia=Ma?Ja:Ia;Ja=Ia+Ga>>1;}while((Ja|0)!=(Ga|0));Ja=8<<Ba;Ia=ha+(Aa*744|0)+4+(Da*148|0)|0;Fa=Ha-Ka|0;c[N>>2]=Fa;Ma=La-Ka|0;c[S>>2]=Ma;if(Ma>>>0<16777216>>>0){Ea=c[z>>2]|0;Na=Ma;Ma=Fa;Fa=c[A>>2]|0;while(1){Oa=Na<<8;c[S>>2]=Oa;Pa=Ma<<8;c[N>>2]=Pa;do{if(Fa>>>0<Ea>>>0){Qa=Fa+1|0;c[A>>2]=Qa;Ra=d[Fa]|0|Pa;c[N>>2]=Ra;Sa=Ra;Ta=Qa}else{if((Pa|0)!=0){Sa=Pa;Ta=Fa;break}c[R>>2]=1;c[N>>2]=1;Sa=1;Ta=Fa}}while(0);if(Oa>>>0>16777215>>>0){break}else{Na=Oa;Ma=Sa;Fa=Ta}}}FVa(Ia,Ga);c[Ca>>2]=Ga;c:do{if((Ga|0)==0){Fa=c[m+(Aa<<2)>>2]|0;Ma=c[(c[C>>2]|0)+32+(Aa<<2)>>2]|0;Na=EVa(r,ia+(Aa*152|0)+4|0)|0;Ea=ia+(Aa*152|0)|0;Ka=(c[Ea>>2]|0)+Na|0;c[Ea>>2]=Ka;if((Ja|0)<=0){break}Na=Fa+(ca(Ja,za)|0)|0;mrc(Na|0,Ka&255|0,Ja|0)|0;if((Ja|0)>1){Ua=1;Va=Na}else{break}do{Va=Va+Ma|0;Ua=Ua+1|0;mrc(Va|0,c[Ea>>2]&255|0,Ja|0)|0;}while((Ua|0)<(Ja|0))}else if((Ga|0)==2){Ea=c[(c[C>>2]|0)+32+(Aa<<2)>>2]|0;Ma=Ja>>3;Oa=ca(Ma,za)|0;Na=ca(Ma,qa)|0;if((Ma|0)<=0){break}Ka=ca(Ja,za)|0;Fa=Ea<<3;La=la+(Aa*2656|0)+4|0;Ha=la+(Aa*2656|0)+144|0;Da=la+(Aa*2656|0)|0;Ba=la+(Aa*2656|0)+16|0;Pa=la+(Aa*2656|0)+316|0;Qa=la+(Aa*2656|0)+300|0;Ra=la+(Aa*2656|0)+296|0;Wa=la+(Aa*2656|0)+292|0;Xa=la+(Aa*2656|0)+312|0;Ya=la+(Aa*2656|0)+304|0;Za=la+(Aa*2656|0)+308|0;_a=0;$a=(c[m+(Aa<<2)>>2]|0)+Ka|0;d:while(1){Ka=_a+Na|0;ab=(Ka|0)==0;bb=0;do{cb=bb+Oa|0;db=(ca(c[La>>2]|0,Ka)|0)+cb|0;mrc(ma|0,0,256)|0;eb=EVa(r,Ha)|0;fb=(cb|0)!=0;do{if(ab){if(fb){gb=c[Da>>2]|0;hb=(c[gb+(cb-1<<2)>>2]|0)+eb|0;ib=gb;break}else{hb=eb;ib=c[Da>>2]|0;break}}else{if(!fb){gb=c[Da>>2]|0;hb=(c[gb+(db-(c[La>>2]|0)<<2)>>2]|0)+eb|0;ib=gb;break}gb=db-1|0;jb=c[Da>>2]|0;kb=c[jb+(gb<<2)>>2]|0;lb=c[La>>2]|0;mb=c[jb+(gb-lb<<2)>>2]|0;gb=c[jb+(db-lb<<2)>>2]|0;lb=gb-mb|0;nb=kb-mb|0;if((((lb|0)>-1?lb:-lb|0)|0)>(((nb|0)>-1?nb:-nb|0)|0)){hb=gb+eb|0;ib=jb;break}else{hb=kb+eb|0;ib=jb;break}}}while(0);c[ib+(db<<2)>>2]=hb;c[na>>2]=ca(e[Ba>>1]|0,hb)|0;eb=1;while(1){fb=DVa(r,Pa)|0;if((fb|0)==0){break}else if((fb|0)==240){ob=eb+16|0}else{cb=fb&15;if((cb|0)==0){break d}jb=(fb>>4)+eb|0;if((jb|0)>63){break d}fb=c[S>>2]|0;kb=ca(fb>>>13,c[Qa>>2]|0)|0;gb=c[N>>2]|0;nb=gb>>>0>=kb>>>0;if(nb){lb=gb-kb|0;c[N>>2]=lb;pb=fb-kb|0;qb=lb}else{pb=kb;qb=gb}c[S>>2]=pb;if(pb>>>0<16777216>>>0){gb=c[z>>2]|0;kb=pb;lb=qb;fb=c[A>>2]|0;while(1){mb=kb<<8;c[S>>2]=mb;rb=lb<<8;c[N>>2]=rb;do{if(fb>>>0<gb>>>0){sb=fb+1|0;c[A>>2]=sb;tb=d[fb]|0|rb;c[N>>2]=tb;ub=tb;vb=sb}else{if((rb|0)!=0){ub=rb;vb=fb;break}c[R>>2]=1;c[N>>2]=1;ub=1;vb=fb}}while(0);if(mb>>>0>16777215>>>0){break}else{kb=mb;lb=ub;fb=vb}}}if(!nb){c[Ya>>2]=(c[Ya>>2]|0)+1}fb=(c[Ra>>2]|0)-1|0;c[Ra>>2]=fb;if((fb|0)==0){fb=c[Wa>>2]|0;lb=(c[Xa>>2]|0)+fb|0;c[Xa>>2]=lb;do{if(lb>>>0>8192>>>0){kb=(lb+1|0)>>>1;c[Xa>>2]=kb;gb=((c[Ya>>2]|0)+1|0)>>>1;c[Ya>>2]=gb;if((kb|0)!=(gb|0)){wb=kb;xb=gb;break}gb=kb+1|0;c[Xa>>2]=gb;wb=gb;xb=kb}else{wb=lb;xb=c[Ya>>2]|0}}while(0);lb=(fb*5|0)>>2;kb=(lb|0)>64?64:lb;c[Wa>>2]=kb;lb=2147483648/(wb>>>0)|0;c[Qa>>2]=(ca(lb,xb)|0)>>>18;c[Za>>2]=(ca(lb,wb)|0)>>>18;c[Ra>>2]=kb}if(cb>>>0>1>>>0){kb=cb-1|0;lb=1<<kb;gb=(c[S>>2]|0)>>>(kb>>>0);c[S>>2]=gb;kb=c[N>>2]|0;rb=(kb>>>0)/(gb>>>0)|0;sb=kb-(ca(rb,gb)|0)|0;c[N>>2]=sb;if(gb>>>0<16777216>>>0){kb=c[z>>2]|0;tb=gb;gb=sb;sb=c[A>>2]|0;while(1){yb=tb<<8;c[S>>2]=yb;zb=gb<<8;c[N>>2]=zb;do{if(sb>>>0<kb>>>0){Ab=sb+1|0;c[A>>2]=Ab;Bb=d[sb]|0|zb;c[N>>2]=Bb;Cb=Bb;Db=Ab}else{if((zb|0)!=0){Cb=zb;Db=sb;break}c[R>>2]=1;c[N>>2]=1;Cb=1;Db=sb}}while(0);if(yb>>>0>16777215>>>0){break}else{tb=yb;gb=Cb;sb=Db}}}Eb=rb+lb|0}else{Eb=cb}sb=d[1242080+jb|0]|0;c[na+(sb<<2)>>2]=ca(e[la+(Aa*2656|0)+16+(sb<<1)>>1]|0,nb?Eb:-Eb|0)|0;ob=jb+1|0}if((ob|0)<64){eb=ob}else{Fb=155;break}}if((Fb|0)==155){Fb=0;if((ob|0)!=64){break d}}IVa($a+(bb<<3)|0,Ea,na);bb=bb+1|0;}while((bb|0)<(Ma|0));bb=_a+1|0;if((bb|0)<(Ma|0)){_a=bb;$a=$a+Fa|0}else{break c}}c[R>>2]=1}else if((Ga|0)==1){Fa=c[m+(Aa<<2)>>2]|0;$a=ca(Ja,za)|0;_a=c[(c[C>>2]|0)+32+(Aa<<2)>>2]|0;Ma=c[S>>2]|0;Ea=Ma>>>15;c[S>>2]=Ea;Ra=c[ja+(Aa*23328|0)+4808>>2]|0;Za=c[N>>2]|0;Qa=Ra;Wa=Ra>>1;Ra=0;Ya=0;Xa=Ma;do{Ma=ca(c[ja+(Aa*23328|0)+4744+(Wa<<2)>>2]|0,Ea)|0;Pa=Ma>>>0>Za>>>0;Xa=Pa?Ma:Xa;Ya=Pa?Ya:Ma;Ra=Pa?Ra:Wa;Qa=Pa?Wa:Qa;Wa=Qa+Ra>>1;}while((Wa|0)!=(Ra|0));Wa=Fa+$a|0;Qa=ja+(Aa*23328|0)+4680|0;Ea=Za-Ya|0;c[N>>2]=Ea;Pa=Xa-Ya|0;c[S>>2]=Pa;if(Pa>>>0<16777216>>>0){Ma=c[z>>2]|0;Ba=Pa;Pa=Ea;Ea=c[A>>2]|0;while(1){La=Ba<<8;c[S>>2]=La;Da=Pa<<8;c[N>>2]=Da;do{if(Ea>>>0<Ma>>>0){Ha=Ea+1|0;c[A>>2]=Ha;Oa=d[Ea]|0|Da;c[N>>2]=Oa;Gb=Oa;Hb=Ha}else{if((Da|0)!=0){Gb=Da;Hb=Ea;break}c[R>>2]=1;c[N>>2]=1;Gb=1;Hb=Ea}}while(0);if(La>>>0>16777215>>>0){break}else{Ba=La;Pa=Gb;Ea=Hb}}}FVa(Qa,Ra);Ea=Ra+2|0;if((Ea|0)>0){Pa=ja+(Aa*23328|0)+2340|0;Ba=0;do{c[k+(Ba<<2)>>2]=DVa(r,Pa)|0;Ba=Ba+1|0;}while((Ba|0)<(Ea|0));if((Ea|0)<4){Ib=Ea;Fb=91}}else{Ib=0;Fb=91}if((Fb|0)==91){Fb=0;mrc(k+(Ib<<2)|0,0,16-(Ib<<2)|0)|0}mrc(ka|0,0,64)|0;if((Ja|0)<=0){break}Ba=ja+(Aa*23328|0)|0;Pa=0;Ra=Wa;while(1){Qa=0;Ma=0;Ya=0;while(1){Xa=l+(Qa<<2)|0;Za=c[Xa>>2]|0;$a=Ma+Ya+(Za*5|0)|0;Fa=c[S>>2]|0;Da=Fa>>>15;c[S>>2]=Da;Ha=c[ja+(Aa*23328|0)+4828+($a*148|0)+128>>2]|0;Oa=c[N>>2]|0;Na=Ha;bb=Ha>>1;Ha=0;ab=0;Ka=Fa;do{Fa=ca(c[ja+(Aa*23328|0)+4828+($a*148|0)+64+(bb<<2)>>2]|0,Da)|0;eb=Fa>>>0>Oa>>>0;Ka=eb?Fa:Ka;ab=eb?ab:Fa;Ha=eb?Ha:bb;Na=eb?bb:Na;bb=Na+Ha>>1;}while((bb|0)!=(Ha|0));bb=ja+(Aa*23328|0)+4828+($a*148|0)|0;Na=Oa-ab|0;c[N>>2]=Na;Da=Ka-ab|0;c[S>>2]=Da;if(Da>>>0<16777216>>>0){eb=c[z>>2]|0;Fa=Da;Da=Na;Na=c[A>>2]|0;while(1){db=Fa<<8;c[S>>2]=db;sb=Da<<8;c[N>>2]=sb;do{if(Na>>>0<eb>>>0){gb=Na+1|0;c[A>>2]=gb;tb=d[Na]|0|sb;c[N>>2]=tb;Jb=tb;Kb=gb}else{if((sb|0)!=0){Jb=sb;Kb=Na;break}c[R>>2]=1;c[N>>2]=1;Jb=1;Kb=Na}}while(0);if(db>>>0>16777215>>>0){break}else{Fa=db;Da=Jb;Na=Kb}}}FVa(bb,Ha);c[Xa>>2]=Ha;if((Ha|0)<4){a[Ra+Qa|0]=c[k+(Ha<<2)>>2]}else{a[Ra+Qa|0]=DVa(r,Ba)|0}Na=Qa+1|0;if((Na|0)<(Ja|0)){Qa=Na;Ma=Ha;Ya=Za*25|0}else{break}}Ya=Pa+1|0;if((Ya|0)<(Ja|0)){Pa=Ya;Ra=Ra+_a|0}else{break}}}else if((Ga|0)==3){_a=(c[m+(Aa<<2)>>2]|0)+(ca(Ja,za)|0)|0;Ra=c[(c[C>>2]|0)+32+(Aa<<2)>>2]|0;Pa=Ja>>1;if((Ja|0)>0){Ba=oa+(Aa*2496|0)+8|0;Wa=oa+(Aa*2496|0)+4|0;Ea=oa+(Aa*2496|0)+2348|0;Ya=pa;Ma=0;while(1){Qa=(Ma|0)<(Pa|0);La=0;do{if((La|0)<(Pa|0)&Qa){Na=DVa(r,Ba)|0;c[Ya+(La<<2)>>2]=Na;Lb=Na}else{Na=EVa(r,Ea)|0;c[Ya+(La<<2)>>2]=Na;Lb=Na}c[Ya+(La<<2)>>2]=ca(c[Wa>>2]|0,Lb)|0;La=La+1|0;}while((La|0)<(Ja|0));La=Ma+1|0;if((La|0)<(Ja|0)){Ya=Ya+(Ja<<2)|0;Ma=La}else{break}}Mb=pa+((ca(Ja,Ja)|0)<<2)|0}else{Mb=pa}if((Pa|0)<=0){break}Ma=Ra<<1;Ya=ca(Pa,Ja)|0;Wa=Mb+((ca(Ja,-Ja|0)|0)<<2)|0;Ea=_a;Ba=0;while(1){La=0;do{Qa=c[Wa+(La<<2)>>2]|0;Na=c[Wa+(La+Pa<<2)>>2]|0;Da=La+Ya|0;Fa=c[Wa+(Da<<2)>>2]|0;eb=c[Wa+(Da+Pa<<2)>>2]|0;Da=Qa-Na|0;ab=Fa-eb|0;Ka=Na+Qa|0;Qa=eb+Fa|0;Fa=Da-ab|0;if(Fa>>>0>255>>>0){Nb=-Fa>>31&255}else{Nb=Fa&255}Fa=La<<1;a[Ea+Fa|0]=Nb;eb=ab+Da|0;if(eb>>>0>255>>>0){Ob=-eb>>31&255}else{Ob=eb&255}a[Ea+(Fa+Ra)|0]=Ob;eb=Ka-Qa|0;if(eb>>>0>255>>>0){Pb=-eb>>31&255}else{Pb=eb&255}eb=Fa|1;a[Ea+eb|0]=Pb;Fa=Qa+Ka|0;if(Fa>>>0>255>>>0){Qb=-Fa>>31&255}else{Qb=Fa&255}a[Ea+(eb+Ra)|0]=Qb;La=La+1|0;}while((La|0)<(Pa|0));La=Ba+1|0;if((La|0)<(Pa|0)){Wa=Wa+(Ja<<2)|0;Ea=Ea+Ma|0;Ba=La}else{break}}}}while(0);if((c[L>>2]|0)!=0){break b}if((c[R>>2]|0)==0){Aa=Aa+1|0}else{break b}}Aa=za+1|0;if((Aa|0)<(M|0)){za=Aa}else{break}}va=c[C>>2]|0;wa=c[O>>2]|0;xa=c[$>>2]|0;ya=c[P>>2]|0}W=wa+(c[va+32>>2]<<4)|0;c[O>>2]=W;V=xa+(c[va+36>>2]<<3)|0;c[$>>2]=V;Z=ya+(c[va+40>>2]<<3)|0;c[P>>2]=Z;Aa=qa+1|0;if((Aa|0)<(T|0)){qa=Aa;ra=va;sa=W;ta=V;ua=Z}else{ga=va;break a}}KIb(b,16,2171648,(s=i,i=i+16|0,c[s>>2]=za,c[s+8>>2]=qa,s)|0);i=s;c[L>>2]=1;t=-1094995529;i=j;return t|0}}while(0);T=YHb(f,ga)|0;if((T|0)<0){t=T;i=j;return t|0}c[g>>2]=1;t=o;i=j;return t|0}}while(0);KIb(b,16,2245e3,(s=i,i=i+8|0,c[s>>2]=K,s)|0);i=s;t=-1094995529;i=j;return t|0}}while(0);KIb(b,16,2295984,(s=i,i=i+32|0,c[s>>2]=G,c[s+8>>2]=I,c[s+16>>2]=B,c[s+24>>2]=E,s)|0);i=s;t=-1094995529;i=j;return t|0}function CVa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+72704|0);mJb(b+75360|0);mJb(b+78016|0);return 0}function DVa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=a+8|0;f=c[e>>2]|0;g=f>>>15;c[e>>2]=g;h=a+12|0;i=c[h>>2]|0;j=(i>>>0)/(g>>>0)|0;k=j>>9;l=c[b+2052+(k<<2)>>2]|0;m=(c[b+2052+(k+1<<2)>>2]|0)+1|0;k=l+1|0;if((m|0)>(k|0)){n=l;o=m;while(1){m=o+n>>1;p=(c[b+1024+(m<<2)>>2]|0)>(j|0);q=p?n:m;r=p?m:o;m=q+1|0;if((r|0)>(m|0)){n=q;o=r}else{s=q;t=m;break}}}else{s=l;t=k}k=ca(g,c[b+1024+(s<<2)>>2]|0)|0;if((s|0)==255){u=f}else{u=ca(c[b+1024+(t<<2)>>2]|0,g)|0}g=i-k|0;c[h>>2]=g;i=u-k|0;c[e>>2]=i;if(!(i>>>0<16777216>>>0)){GVa(b,s);return s|0}k=a|0;u=a+16|0;t=c[a+4>>2]|0;a=i;i=g;g=c[k>>2]|0;while(1){f=a<<8;c[e>>2]=f;l=i<<8;c[h>>2]=l;do{if(g>>>0<t>>>0){o=g+1|0;c[k>>2]=o;n=d[g]|0|l;c[h>>2]=n;v=n;w=o}else{if((l|0)!=0){v=l;w=g;break}c[u>>2]=1;c[h>>2]=1;v=1;w=g}}while(0);if(f>>>0>16777215>>>0){break}else{a=f;i=v;g=w}}GVa(b,s);return s|0}function EVa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=a+8|0;f=c[e>>2]|0;g=f>>>15;c[e>>2]=g;h=c[b+128>>2]|0;i=a+12|0;j=c[i>>2]|0;k=h;l=h>>1;h=0;m=0;n=f;do{f=ca(c[b+64+(l<<2)>>2]|0,g)|0;o=f>>>0>j>>>0;n=o?f:n;m=o?m:f;h=o?h:l;k=o?l:k;l=k+h>>1;}while((l|0)!=(h|0));l=j-m|0;c[i>>2]=l;j=n-m|0;c[e>>2]=j;if(j>>>0<16777216>>>0){m=a|0;n=a+16|0;k=c[a+4>>2]|0;g=j;j=l;l=c[m>>2]|0;while(1){o=g<<8;c[e>>2]=o;f=j<<8;c[i>>2]=f;do{if(l>>>0<k>>>0){p=l+1|0;c[m>>2]=p;q=d[l]|0|f;c[i>>2]=q;r=q;s=p}else{if((f|0)!=0){r=f;s=l;break}c[n>>2]=1;c[i>>2]=1;r=1;s=l}}while(0);if(o>>>0>16777215>>>0){break}else{g=o;j=r;l=s}}}FVa(b,h);if((h|0)==0){t=0;return t|0}b=c[e>>2]|0;s=b>>>1;c[e>>2]=s;l=c[i>>2]|0;r=s>>>0<=l>>>0;if(r){j=l-s|0;c[i>>2]=j;u=j}else{u=l}if(b>>>0<33554432>>>0){b=a|0;l=a+16|0;j=c[a+4>>2]|0;g=s;n=u;m=c[b>>2]|0;while(1){k=g<<8;c[e>>2]=k;f=n<<8;c[i>>2]=f;do{if(m>>>0<j>>>0){p=m+1|0;c[b>>2]=p;q=d[m]|0|f;c[i>>2]=q;v=q;w=p}else{if((f|0)!=0){v=f;w=m;break}c[l>>2]=1;c[i>>2]=1;v=1;w=m}}while(0);if(k>>>0>16777215>>>0){x=k;y=v;break}else{g=k;n=v;m=w}}}else{x=s;y=u}if((h|0)>1){u=h-1|0;s=1<<u;w=x>>>(u>>>0);c[e>>2]=w;u=(y>>>0)/(w>>>0)|0;x=y-(ca(u,w)|0)|0;c[i>>2]=x;if(w>>>0<16777216>>>0){y=a|0;m=a+16|0;v=c[a+4>>2]|0;a=w;w=x;x=c[y>>2]|0;while(1){n=a<<8;c[e>>2]=n;g=w<<8;c[i>>2]=g;do{if(x>>>0<v>>>0){l=x+1|0;c[y>>2]=l;b=d[x]|0|g;c[i>>2]=b;z=b;A=l}else{if((g|0)!=0){z=g;A=x;break}c[m>>2]=1;c[i>>2]=1;z=1;A=x}}while(0);if(n>>>0>16777215>>>0){break}else{a=n;w=z;x=A}}}B=u+s|0}else{B=h}if(r){t=B;return t|0}t=-B|0;return t|0}function FVa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a+(b<<2)|0;c[d>>2]=(c[d>>2]|0)+1;d=a+144|0;b=(c[d>>2]|0)-1|0;c[d>>2]=b;if((b|0)!=0){return}b=a+136|0;e=a+132|0;f=(c[e>>2]|0)+(c[b>>2]|0)|0;c[e>>2]=f;do{if((f|0)>32768){c[e>>2]=0;g=a+128|0;if((c[g>>2]|0)>0){h=0}else{break}while(1){i=a+(h<<2)|0;j=(c[i>>2]|0)+1>>1;c[i>>2]=j;i=j+(c[e>>2]|0)|0;c[e>>2]=i;j=h+1|0;k=c[g>>2]|0;if((j|0)<(k|0)){h=j}else{l=i;m=k;n=6;break}}}else{l=f;m=c[a+128>>2]|0;n=6}}while(0);do{if((n|0)==6){f=2147483648/(l>>>0)|0;h=a+128|0;if((m|0)>0){o=0;p=0}else{break}while(1){c[a+64+(p<<2)>>2]=(ca(o,f)|0)>>>16;e=p+1|0;if((e|0)<(c[h>>2]|0)){o=(c[a+(p<<2)>>2]|0)+o|0;p=e}else{break}}}}while(0);p=((c[b>>2]|0)*5|0)>>2;c[b>>2]=p;o=c[a+140>>2]|0;if((p|0)>(o|0)){c[b>>2]=o;q=o}else{q=p}c[d>>2]=q;return}function GVa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a+(b<<2)|0;c[d>>2]=(c[d>>2]|0)+1;d=a+2336|0;b=(c[d>>2]|0)-1|0;c[d>>2]=b;if((b|0)!=0){return}b=a+2328|0;e=a+2048|0;f=(c[e>>2]|0)+(c[b>>2]|0)|0;c[e>>2]=f;if((f|0)>32768){c[e>>2]=0;g=0;while(1){h=a+(g<<2)|0;i=(c[h>>2]|0)+1>>1;c[h>>2]=i;h=i+(c[e>>2]|0)|0;c[e>>2]=h;i=g+1|0;if((i|0)<256){g=i}else{j=h;break}}}else{j=f}f=2147483648/(j>>>0)|0;c[a+2052>>2]=0;j=0;g=0;e=1;while(1){h=ca(j,f)|0;c[a+1024+(g<<2)>>2]=h>>>16;i=(c[a+(g<<2)>>2]|0)+j|0;k=h>>>25;if((e|0)>(k|0)){l=e}else{h=g-1|0;m=e;while(1){n=m+1|0;c[a+2052+(m<<2)>>2]=h;if((n|0)>(k|0)){break}else{m=n}}l=k+1|0}m=g+1|0;if((m|0)<256){j=i;g=m;e=l}else{break}}e=a+2324|0;if((l|0)<(c[e>>2]|0)){g=l;while(1){l=g+1|0;c[a+2052+(g<<2)>>2]=255;if((l|0)<(c[e>>2]|0)){g=l}else{break}}}g=((c[b>>2]|0)*5|0)>>2;c[b>>2]=g;e=c[a+2332>>2]|0;if((g|0)>(e|0)){c[b>>2]=e;o=e}else{o=g}c[d>>2]=o;return}function HVa(a,c,e){a=a|0;c=c|0;e=e|0;var f=0;f=(e|0)!=0?841720:1705072;if((c|0)<=49){e=0;do{b[a+(e<<1)>>1]=((((d[f+e|0]|0)*5e3|0|0)/(c|0)|0)+50|0)/100|0;e=e+1|0;}while((e|0)<64);return}e=200-(c<<1)|0;c=0;do{b[a+(c<<1)>>1]=((ca(d[f+c|0]|0,e)|0)+50|0)/100|0;c=c+1|0;}while((c|0)<64);return}function IVa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=e;g=0;while(1){h=f+28|0;i=c[h>>2]|0;j=f+4|0;k=c[j>>2]|0;l=f+20|0;m=c[l>>2]|0;n=f+12|0;o=c[n>>2]|0;p=o+i|0;q=m+k|0;r=(p*77062|0)+(q*51491|0)|0;s=(p*-51491|0)+(q*77062|0)|0;q=f+8|0;p=c[q>>2]|0;t=f+24|0;u=c[t>>2]|0;v=(u*-85623|0)+(p*35470|0)|0;w=(u*35470|0)+(p*85623|0)|0;p=c[f>>2]|0;u=f+16|0;x=c[u>>2]|0;y=p-x<<16|8192;z=x+p<<16|8192;p=(k*39410|0)+(i*-58980|0)+r|0;c[f>>2]=p+w+z>>13;x=(o*33410|0)+(m*-167963|0)+s|0;c[j>>2]=x+v+y>>13;j=(o*-167963|0)+(m*-33410|0)+r|0;c[q>>2]=j-v+y>>13;q=(k*-58980|0)+(i*-39409|0)+s|0;c[n>>2]=q-w+z>>13;c[u>>2]=z-(q+w)>>13;c[l>>2]=y-(j+v)>>13;c[t>>2]=v-x+y>>13;c[h>>2]=w-p+z>>13;z=g+1|0;if((z|0)<8){f=f+32|0;g=z}else{A=e;B=0;break}}while(1){g=A+224|0;f=c[g>>2]|0;z=A+32|0;p=c[z>>2]|0;w=A+160|0;h=c[w>>2]|0;y=A+96|0;x=c[y>>2]|0;v=x+f|0;t=h+p|0;j=(v*77062|0)+(t*51491|0)|0;l=(v*-51491|0)+(t*77062|0)|0;t=A+64|0;v=c[t>>2]|0;q=A+192|0;u=c[q>>2]|0;n=(u*-85623|0)+(v*35470|0)|0;s=(u*35470|0)+(v*85623|0)|0;v=c[A>>2]|0;u=A+128|0;i=c[u>>2]|0;k=(v-i<<16)+2097152|0;r=(i+v<<16)+2097152|0;v=(p*39410|0)+(f*-58980|0)+j|0;c[A>>2]=v+s+r>>22;i=(x*33410|0)+(h*-167963|0)+l|0;c[z>>2]=i+n+k>>22;z=(x*-167963|0)+(h*-33410|0)+j|0;c[t>>2]=z-n+k>>22;t=(p*-58980|0)+(f*-39409|0)+l|0;c[y>>2]=t-s+r>>22;c[u>>2]=r-(t+s)>>22;c[w>>2]=k-(z+n)>>22;c[q>>2]=n-i+k>>22;c[g>>2]=s-v+r>>22;r=B+1|0;if((r|0)<8){A=A+4|0;B=r}else{C=e;D=0;E=b;break}}while(1){b=c[C>>2]|0;e=b+128|0;if(e>>>0>255>>>0){F=-128-b>>31&255}else{F=e&255}a[E]=F;e=c[C+4>>2]|0;b=e+128|0;if(b>>>0>255>>>0){G=-128-e>>31&255}else{G=b&255}a[E+1|0]=G;b=c[C+8>>2]|0;e=b+128|0;if(e>>>0>255>>>0){H=-128-b>>31&255}else{H=e&255}a[E+2|0]=H;e=c[C+12>>2]|0;b=e+128|0;if(b>>>0>255>>>0){I=-128-e>>31&255}else{I=b&255}a[E+3|0]=I;b=c[C+16>>2]|0;e=b+128|0;if(e>>>0>255>>>0){J=-128-b>>31&255}else{J=e&255}a[E+4|0]=J;e=c[C+20>>2]|0;b=e+128|0;if(b>>>0>255>>>0){K=-128-e>>31&255}else{K=b&255}a[E+5|0]=K;b=c[C+24>>2]|0;e=b+128|0;if(e>>>0>255>>>0){L=-128-b>>31&255}else{L=e&255}a[E+6|0]=L;e=c[C+28>>2]|0;b=e+128|0;if(b>>>0>255>>>0){M=-128-e>>31&255}else{M=b&255}a[E+7|0]=M;b=D+1|0;if((b|0)<8){C=C+32|0;D=b;E=E+d|0}else{break}}return}function JVa(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+496|0;f=e|0;g=e+168|0;h=d+60|0;j=c[h>>2]|0;k=j;l=f|0;m=g;n=0;while(1){if((n|0)<2){o=0;p=0;q=0;r=0}else{break}while(1){s=a[792712+(n<<4)+o|0]|0;t=o+1|0;if(s<<24>>24==0){u=p;v=q;w=r}else{x=s&255;s=x>>>0>1>>>0?x:1;mrc(f+r|0,t&255|0,s|0)|0;y=0;z=p;A=r;while(1){b[g+(A<<1)>>1]=z;B=y+1|0;if((B|0)<(x|0)){y=B;z=z+1|0;A=A+1|0}else{break}}u=s+p|0;v=t;w=s+r|0}if((t|0)<16){o=t;p=u<<1;q=v;r=w}else{break}}if(($2(k+4+(n*20|0)|0,(v|0)>9?9:v,12,l,1,1,m,2,2,0,1,1,0)|0)==0){C=0;D=0;E=0;F=0}else{G=22;break}while(1){A=a[793072+(n<<4)+C|0]|0;z=C+1|0;if(A<<24>>24==0){H=D;I=E;J=F}else{y=A&255;A=y>>>0>1>>>0?y:1;mrc(f+F|0,z&255|0,A|0)|0;x=0;B=D;K=F;while(1){b[g+(K<<1)>>1]=B;L=x+1|0;if((L|0)<(y|0)){x=L;B=B+1|0;K=K+1|0}else{break}}H=A+D|0;I=z;J=A+F|0}if((z|0)<16){C=z;D=H<<1;E=I;F=J}else{break}}if(($2(k+44+(n*20|0)|0,(I|0)>9?9:I,162,l,1,1,m,2,2,792744+(n*162|0)|0,1,1,0)|0)==0){M=0;N=0;O=0;P=0}else{G=22;break}while(1){K=a[792680+(n<<4)+M|0]|0;B=M+1|0;if(K<<24>>24==0){Q=N;R=O;S=P}else{x=K&255;K=x>>>0>1>>>0?x:1;mrc(f+P|0,B&255|0,K|0)|0;y=0;t=N;s=P;while(1){b[g+(s<<1)>>1]=t;L=y+1|0;if((L|0)<(x|0)){y=L;t=t+1|0;s=s+1|0}else{break}}Q=K+N|0;R=B;S=K+P|0}if((B|0)<16){M=B;N=Q<<1;O=R;P=S}else{break}}if(($2(k+84+(n*20|0)|0,(R|0)>9?9:R,9,l,1,1,m,2,2,792656+(n*9|0)|0,1,1,0)|0)==0){n=n+1|0}else{G=22;break}}if((G|0)==22){KIb(d,16,2567032,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;c3(j+4|0);c3(j+44|0);c3(j+84|0);c3(j+24|0);c3(j+64|0);c3(j+104|0);U=-12;i=e;return U|0}n=d+120|0;m=j+1420|0;l=j+1408|0;R=0;while(1){if((R|0)>=3){break}k=((c[n>>2]|0)+15&-16)>>((R|0)!=0|2);c[m+(R<<2)>>2]=k;S=hJb(k<<2)|0;c[l+(R<<2)>>2]=S;if((S|0)==0){G=25;break}else{R=R+1|0}}if((G|0)==25){KIb(d,16,2548680,(T=i,i=i+1|0,i=i+7&-8,c[T>>2]=0,T)|0);i=T;c3(j+4|0);c3(j+44|0);c3(j+84|0);c3(j+24|0);c3(j+64|0);c3(j+104|0);U=-12;i=e;return U|0}T=UHb()|0;c[j>>2]=T;if((T|0)==0){T=c[h>>2]|0;VHb(T);mJb(T+1408|0);mJb(T+1412|0);mJb(T+1416|0);c3(T+4|0);c3(T+44|0);c3(T+84|0);c3(T+24|0);c3(T+64|0);c3(T+104|0);U=-12;i=e;return U|0}else{c[d+140>>2]=5;U=0;i=e;return U|0}return 0}function KVa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0;j=i;i=i+216|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=j+64|0;p=j+80|0;q=j+96|0;r=j+160|0;s=j+176|0;t=j+200|0;u=c[h+24>>2]|0;v=c[h+28>>2]|0;h=c[e+60>>2]|0;w=h;if((v|0)<8){KIb(e,16,2449184,(x=i,i=i+16|0,c[x>>2]=8,c[x+8>>2]=v,x)|0);i=x;y=-1094995529;i=j;return y|0}z=u+v|0;A=z;B=u+2|0;C=u;D=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;if((A-B|0)<2){E=0;F=B}else{C=B;E=(he((d[C]|d[C+1|0]<<8)<<16>>16|0)|0)&65535;F=u+4|0}C=A-F|0;B=C>>>0>2>>>0?2:C;C=F+B|0;if((A-C|0)<1){G=0;H=C}else{G=d[C]|0;H=F+(B+1)|0}if((A-H|0)<1){I=0;J=H}else{I=d[H]|0;J=H+1|0}do{if((D|0)<=(c[e+120>>2]|0)){if((E|0)!=(c[e+124>>2]|0)){break}if((G-1|0)>>>0>99>>>0){KIb(e,16,2295952,(x=i,i=i+8|0,c[x>>2]=G,x)|0);i=x;y=-1094995529;i=j;return y|0}if(I>>>0>2>>>0){KIb(e,16,2244976,(x=i,i=i+8|0,c[x>>2]=I,x)|0);i=x;y=-1094995529;i=j;return y|0}H=(I|0)==2;if((z|0)==(J|0)&(H^1)){KIb(e,16,2203392,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=j;return y|0}A=h;B=N4a(e,c[A>>2]|0)|0;if((B|0)<0){y=B;i=j;return y|0}B=(I|0)==0;F=c[A>>2]|0;c[F+84>>2]=B&1;c[F+88>>2]=B?1:2;if(H){c[g>>2]=1;H=YHb(f,F)|0;y=(H|0)<0?H:v;i=j;return y|0}H=h+1148|0;if((c[H>>2]|0)==(G|0)){K=F}else{c[H>>2]=G;HVa(h+1152|0,G,1);HVa(h+1280|0,G,0);K=c[A>>2]|0}F=u+8|0;C=v-8|0;L=C>>>0>268435455>>>0?-8:C<<3;C=L>>>0>2147483639>>>0|(F|0)==0;M=C?0:F;F=C?0:L;L=s|0;c[L>>2]=M;c[s+12>>2]=F;C=s+16|0;c[C>>2]=F+8;c[s+4>>2]=M+(F>>3);F=s+8|0;c[F>>2]=0;M=(D+15|0)>>>4;N=(E+15|0)>>>4;O=c[K>>2]|0;P=t|0;c[P>>2]=O;Q=c[K+4>>2]|0;R=t+4|0;c[R>>2]=Q;S=c[K+8>>2]|0;T=t+8|0;c[T>>2]=S;mrc(h+1496|0,0,48)|0;a:do{if((N|0)==0){U=K}else{V=h+1432|0;W=(M|0)==0;X=h+1408|0;Y=h+1440|0;Z=V;_=h+1456|0;$=h+1448|0;aa=h+1412|0;ba=h+1472|0;da=h+1464|0;ea=h+1416|0;fa=h+1488|0;ga=h+1480|0;ha=h+4|0;ia=h+44|0;ja=h+124|0;ka=h+1152|0;la=h+1436|0;ma=h+1452|0;na=h+24|0;oa=h+64|0;pa=h+1280|0;qa=o;ra=p;sa=q;ta=h+380|0;ua=r|0;va=h+636|0;wa=r+4|0;xa=h+892|0;ya=r+8|0;za=o|0;Aa=o+4|0;Ba=o+8|0;Ca=n|0;Da=m|0;Ea=q|0;Fa=0;Ga=K;Ha=O;Ia=Q;Ja=S;b:while(1){mrc(V|0,0,64)|0;if(W){Ka=Ga;La=Ha;Ma=Ia;Na=Ja}else{Oa=Fa<<1;Pa=Oa|1;Qa=0;while(1){Ra=c[F>>2]|0;Sa=c[L>>2]|0;Ta=d[Sa+(Ra>>>3)|0]|0;Ua=c[C>>2]|0;Va=((Ra|0)<(Ua|0))+Ra|0;c[F>>2]=Va;c:do{if((Ta&128>>>((Ra&7)>>>0)|0)==0){if(B){Wa=117;break b}else{Wa=119}}else{Xa=d[Sa+(Va>>>3)|0]<<(Va&7)>>>7;Ya=((Va|0)<(Ua|0))+Va|0;c[F>>2]=Ya;Za=Xa&1;d:do{if((Za|0)==0){Xa=c[P>>2]|0;_a=Qa<<1;c[la>>2]=c[Y>>2];c[Y>>2]=c[(c[X>>2]|0)+(_a<<2)>>2];$a=QVa(s,ha,ia,ja,Z,_a,Oa,ka)|0;e:do{if(($a|0)==0){c[(c[X>>2]|0)+(_a<<2)>>2]=c[Z>>2];ab=Qa<<4;IVa(Xa+ab|0,c[(c[A>>2]|0)+32>>2]|0,ja);bb=_a|1;c[la>>2]=c[Y>>2];c[Y>>2]=c[(c[X>>2]|0)+(bb<<2)>>2];cb=QVa(s,ha,ia,ja,Z,bb,Oa,ka)|0;if((cb|0)!=0){db=cb;break}c[(c[X>>2]|0)+(bb<<2)>>2]=c[Z>>2];cb=bb<<3;IVa(Xa+cb|0,c[(c[A>>2]|0)+32>>2]|0,ja);eb=c[(c[A>>2]|0)+32>>2]<<3;c[ma>>2]=c[_>>2];c[_>>2]=c[(c[X>>2]|0)+(_a<<2)>>2];fb=QVa(s,ha,ia,ja,$,_a,Pa,ka)|0;if((fb|0)!=0){db=fb;break}c[(c[X>>2]|0)+(_a<<2)>>2]=c[$>>2];IVa(Xa+(eb+ab)|0,c[(c[A>>2]|0)+32>>2]|0,ja);c[ma>>2]=c[_>>2];c[_>>2]=c[(c[X>>2]|0)+(bb<<2)>>2];fb=QVa(s,ha,ia,ja,$,bb,Pa,ka)|0;if((fb|0)!=0){db=fb;break}c[(c[X>>2]|0)+(bb<<2)>>2]=c[$>>2];IVa(Xa+(eb+cb)|0,c[(c[A>>2]|0)+32>>2]|0,ja);cb=1;while(1){eb=cb+1|0;bb=w+1432+(eb<<4)+8|0;c[w+1432+(eb<<4)+4>>2]=c[bb>>2];fb=w+1408+(cb<<2)|0;c[bb>>2]=c[(c[fb>>2]|0)+(Qa<<2)>>2];bb=w+1432+(eb<<4)|0;gb=QVa(s,na,oa,ja,bb,Qa,Fa,pa)|0;if((gb|0)!=0){db=gb;break e}c[(c[fb>>2]|0)+(Qa<<2)>>2]=c[bb>>2];IVa(w+380+(cb<<8)|0,8,ja);bb=0;fb=(c[t+(cb<<2)>>2]|0)+ab|0;while(1){gb=bb<<2;hb=gb&-8;b[fb>>1]=(d[w+380+(cb<<8)+hb|0]|0)*257;b[fb+2>>1]=(d[(hb|1)+(w+380+(cb<<8))|0]|0)*257;b[fb+4>>1]=(d[(hb|2)+(w+380+(cb<<8))|0]|0)*257;b[fb+6>>1]=(d[(hb|3)+(w+380+(cb<<8))|0]|0)*257;b[fb+8>>1]=(d[(gb|4)+(w+380+(cb<<8))|0]|0)*257;b[fb+10>>1]=(d[(gb|5)+(w+380+(cb<<8))|0]|0)*257;b[fb+12>>1]=(d[(gb|6)+(w+380+(cb<<8))|0]|0)*257;b[fb+14>>1]=(d[(gb|7)+(w+380+(cb<<8))|0]|0)*257;gb=bb+1|0;if((gb|0)<16){bb=gb;fb=fb+(c[(c[A>>2]|0)+32+(cb<<2)>>2]|0)|0}else{break}}if((eb|0)<3){cb=eb}else{break d}}}else{db=$a}}while(0);if((db|0)<0){Wa=39;break b}}else if((Za|0)==1){mrc(qa|0,0,12)|0;mrc(ra|0,0,12)|0;mrc(sa|0,0,64)|0;$a=c[H>>2]|0;c[ua>>2]=ta;c[wa>>2]=va;c[ya>>2]=xa;Xa=0;_a=Ya;while(1){cb=0;ab=_a;while(1){if((cb|0)>=3){ib=ab;break}fb=d[Sa+(ab>>>3)|0]|0;bb=((ab|0)<(Ua|0))+ab|0;c[F>>2]=bb;if((fb&128>>>((ab&7)>>>0)|0)==0){ib=bb;break}else{cb=cb+1|0;ab=bb}}ab=(Xa|0)!=0|0;bb=a[263280+(ab<<2)+cb|0]|0;fb=bb&255;c[l+(Xa<<2)>>2]=fb;if(bb<<24>>24==0){jb=ib}else{gb=w+84+(ab*20|0)|0;hb=w+84+(ab*20|0)+4|0;ab=0;kb=ib;while(1){lb=c[gb>>2]|0;mb=c[hb>>2]|0;nb=Sa+(kb>>>3)|0;ob=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(kb&7)>>>((32-lb|0)>>>0);nb=b[mb+(ob<<2)>>1]|0;pb=b[mb+(ob<<2)+2>>1]|0;ob=pb<<16>>16;if(pb<<16>>16<0){pb=kb+lb|0;lb=Ua>>>0>pb>>>0?pb:Ua;pb=Sa+(lb>>>3)|0;qb=((je(d[pb]|d[pb+1|0]<<8|d[pb+2|0]<<16|d[pb+3|0]<<24|0)|0)<<(lb&7)>>>((ob+32|0)>>>0))+nb|0;rb=b[mb+(qb<<2)+2>>1]|0;sb=b[mb+(qb<<2)>>1]|0;tb=lb}else{rb=ob;sb=nb;tb=kb}nb=rb+tb|0;ob=Ua>>>0>nb>>>0?nb:Ua;do{if((sb|0)==0){ub=0;vb=ob}else{nb=Sa+(ob>>>3)|0;lb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(ob&7)>>>((32-sb|0)>>>0);nb=ob+sb|0;qb=Ua>>>0>nb>>>0?nb:Ua;if((lb|0)>=(1<<sb-1|0)){ub=lb;vb=qb;break}ub=(-1<<sb)+1+lb|0;vb=qb}}while(0);ob=w+1496+(Xa<<4)+(ab<<2)|0;eb=(c[ob>>2]|0)+ub|0;a[k+(Xa<<2)+ab|0]=eb;c[ob>>2]=eb&255;eb=ab+1|0;if((eb|0)<(fb|0)){ab=eb;kb=vb}else{break}}c[F>>2]=vb;jb=vb}c[n+(Xa<<2)>>2]=(bb&255)>>>0>1>>>0;c[m+(Xa<<2)>>2]=(bb&255)>>>0>2>>>0?fb-2|0:0;kb=Xa+1|0;if((kb|0)<3){Xa=kb;_a=jb}else{break}}_a=($a|0)==100?0:2;Xa=8-_a|0;kb=32-Xa|0;ab=1;hb=0;gb=0;cb=jb;eb=Sa;ob=Ua;while(1){qb=((cb|0)<(ob|0))+cb|0;lb=(d[eb+(cb>>>3)|0]&128>>>((cb&7)>>>0)|0)==0;nb=d[eb+(qb>>>3)|0]|0;mb=((qb|0)<(ob|0))+qb|0;c[F>>2]=mb;pb=(128>>>((qb&7)>>>0)&nb|0)==0;f:do{if(lb){if(pb){wb=gb;xb=mb}else{nb=eb+(mb>>>3)|0;qb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(mb&7)>>>28;nb=mb+4|0;yb=ob>>>0>nb>>>0?nb:ob;c[F>>2]=yb;wb=((qb|0)>=(gb|0))+qb|0;xb=yb}if((wb|0)==0){zb=xb;Ab=eb;Bb=ob}else{yb=c[Ea>>2]|0;c[za>>2]=yb&7;c[Aa>>2]=yb>>>3&7;c[Ba>>2]=yb>>6;yb=(wb|0)>0;qb=0;do{if(yb){nb=o+(qb<<2)|0;Cb=c[l+(qb<<2)>>2]|0;Db=r+(qb<<2)|0;Eb=p+(qb<<2)|0;Fb=c[Db>>2]|0;Gb=0;Hb=Fb;while(1){Ib=c[nb>>2]|0;do{if((Ib|0)<(Cb|0)){Jb=a[k+(qb<<2)+Ib|0]|0}else{Kb=c[F>>2]|0;Lb=c[L>>2]|0;Mb=d[Lb+(Kb>>>3)|0]|0;Nb=c[C>>2]|0;Ob=((Kb|0)<(Nb|0))+Kb|0;c[F>>2]=Ob;if((Mb&128>>>((Kb&7)>>>0)|0)==0){Jb=c[Eb>>2]&255;break}else{Kb=Lb+(Ob>>>3)|0;Lb=(je(d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)|0)<<(Ob&7)>>>(kb>>>0);Kb=Ob+Xa|0;c[F>>2]=Nb>>>0>Kb>>>0?Kb:Nb;Nb=Lb<<_a;c[Eb>>2]=Nb;Jb=Nb&255;break}}}while(0);a[Hb]=Jb;c[q+(Gb<<2)>>2]=c[Aa>>2]<<3|c[za>>2]|c[Ba>>2]<<6;Ib=Gb+1|0;if((Ib|0)>=(wb|0)){break}Gb=Ib;Hb=Hb+1|0}c[Db>>2]=Fb+wb}qb=qb+1|0;}while((qb|0)<3);if((wb|0)==16){Pb=16;Qb=hb;break}zb=c[F>>2]|0;Ab=c[L>>2]|0;Bb=c[C>>2]|0}c[za>>2]=hb&7;c[Aa>>2]=hb>>>3&7;c[Ba>>2]=hb>>6;qb=d[Ab+(zb>>>3)|0]|0;c[F>>2]=((zb|0)<(Bb|0))+zb;if((qb&128>>>((zb&7)>>>0)|0)==0){Rb=hb}else{PVa(s,za,Ca,Da,za);Rb=c[Aa>>2]<<3|c[za>>2]|c[Ba>>2]<<6}qb=16-wb|0;yb=(qb|0)>0;Hb=0;while(1){if(yb){Gb=o+(Hb<<2)|0;Eb=c[l+(Hb<<2)>>2]|0;Cb=r+(Hb<<2)|0;nb=p+(Hb<<2)|0;Ib=c[Cb>>2]|0;Nb=0;Lb=Ib;while(1){Kb=c[Gb>>2]|0;do{if((Kb|0)<(Eb|0)){Sb=a[k+(Hb<<2)+Kb|0]|0}else{Ob=c[F>>2]|0;Mb=c[L>>2]|0;Tb=d[Mb+(Ob>>>3)|0]|0;Ub=c[C>>2]|0;Vb=((Ob|0)<(Ub|0))+Ob|0;c[F>>2]=Vb;if((Tb&128>>>((Ob&7)>>>0)|0)==0){Sb=c[nb>>2]&255;break}else{Ob=Mb+(Vb>>>3)|0;Mb=(je(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Vb&7)>>>(kb>>>0);Ob=Vb+Xa|0;c[F>>2]=Ub>>>0>Ob>>>0?Ob:Ub;Ub=Mb<<_a;c[nb>>2]=Ub;Sb=Ub&255;break}}}while(0);a[Lb]=Sb;c[q+(Nb+wb<<2)>>2]=c[Aa>>2]<<3|c[za>>2]|c[Ba>>2]<<6;Kb=Nb+1|0;if((Kb|0)>=(qb|0)){break}Nb=Kb;Lb=Lb+1|0}c[Cb>>2]=Ib+qb}Lb=Hb+1|0;if((Lb|0)<3){Hb=Lb}else{Pb=wb;Qb=Rb;break}}}else{if(!pb){c[Ea>>2]=0;c[Ba>>2]=0;c[Aa>>2]=0;c[za>>2]=0;Hb=0;qb=eb;yb=ob;Lb=0;Nb=mb;while(1){nb=d[qb+(Nb>>>3)|0]|0;c[F>>2]=((Nb|0)<(yb|0))+Nb;if((nb&128>>>((Nb&7)>>>0)|0)==0){Wb=qb;Xb=yb;Yb=Lb}else{PVa(s,za,Ca,Da,za);Wb=c[L>>2]|0;Xb=c[C>>2]|0;Yb=c[za>>2]|0}do{if((Yb|0)<(c[l>>2]|0)){Zb=a[k+Yb|0]|0}else{nb=c[F>>2]|0;Eb=d[Wb+(nb>>>3)|0]|0;Gb=((nb|0)<(Xb|0))+nb|0;c[F>>2]=Gb;if((Eb&128>>>((nb&7)>>>0)|0)==0){Zb=c[p>>2]&255;break}else{nb=Wb+(Gb>>>3)|0;Eb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Gb&7)>>>(kb>>>0);nb=Gb+Xa|0;c[F>>2]=Xb>>>0>nb>>>0?nb:Xb;nb=Eb<<_a;c[p>>2]=nb;Zb=nb&255;break}}}while(0);Ib=c[ua>>2]|0;c[ua>>2]=Ib+1;a[Ib]=Zb;Ib=c[Aa>>2]|0;do{if((Ib|0)<(c[l+4>>2]|0)){_b=a[k+4+Ib|0]|0}else{Cb=c[F>>2]|0;nb=d[Wb+(Cb>>>3)|0]|0;Eb=((Cb|0)<(Xb|0))+Cb|0;c[F>>2]=Eb;if((nb&128>>>((Cb&7)>>>0)|0)==0){_b=c[p+4>>2]&255;break}else{Cb=Wb+(Eb>>>3)|0;nb=(je(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0)<<(Eb&7)>>>(kb>>>0);Cb=Eb+Xa|0;c[F>>2]=Xb>>>0>Cb>>>0?Cb:Xb;Cb=nb<<_a;c[p+4>>2]=Cb;_b=Cb&255;break}}}while(0);Cb=c[wa>>2]|0;c[wa>>2]=Cb+1;a[Cb]=_b;Cb=c[Ba>>2]|0;do{if((Cb|0)<(c[l+8>>2]|0)){$b=a[k+8+Cb|0]|0}else{nb=c[F>>2]|0;Eb=d[Wb+(nb>>>3)|0]|0;Gb=((nb|0)<(Xb|0))+nb|0;c[F>>2]=Gb;if((Eb&128>>>((nb&7)>>>0)|0)==0){$b=c[p+8>>2]&255;break}else{nb=Wb+(Gb>>>3)|0;Eb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Gb&7)>>>(kb>>>0);nb=Gb+Xa|0;c[F>>2]=Xb>>>0>nb>>>0?nb:Xb;nb=Eb<<_a;c[p+8>>2]=nb;$b=nb&255;break}}}while(0);nb=c[ya>>2]|0;c[ya>>2]=nb+1;a[nb]=$b;c[q+(Hb<<2)>>2]=Ib<<3|Yb|Cb<<6;nb=Hb+1|0;if((nb|0)>=16){Pb=gb;Qb=hb;break f}Hb=nb;qb=Wb;yb=Xb;Lb=Yb;Nb=c[F>>2]|0}}Nb=d[eb+(mb>>>3)|0]|0;Lb=((mb|0)<(ob|0))+mb|0;c[F>>2]=Lb;if((Nb&128>>>((mb&7)>>>0)|0)==0){ac=0;bc=0}else{Nb=eb+(Lb>>>3)|0;yb=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(Lb&7)>>>28;Nb=Lb+4|0;c[F>>2]=ob>>>0>Nb>>>0?Nb:ob;ac=yb;bc=1}yb=0;Nb=eb;Lb=ob;while(1){qb=q+(yb<<2)|0;Hb=c[qb>>2]|0;nb=Hb&7;c[za>>2]=nb;c[Aa>>2]=Hb>>>3&7;c[Ba>>2]=Hb>>6;if(bc&(yb|0)==(ac|0)){PVa(s,za,Ca,Da,za);cc=c[L>>2]|0;dc=c[C>>2]|0;ec=c[za>>2]|0}else{cc=Nb;dc=Lb;ec=nb}do{if((ec|0)<(c[l>>2]|0)){fc=a[k+ec|0]|0}else{nb=c[F>>2]|0;Hb=d[cc+(nb>>>3)|0]|0;Eb=((nb|0)<(dc|0))+nb|0;c[F>>2]=Eb;if((Hb&128>>>((nb&7)>>>0)|0)==0){fc=c[p>>2]&255;break}else{nb=cc+(Eb>>>3)|0;Hb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Eb&7)>>>(kb>>>0);nb=Eb+Xa|0;c[F>>2]=dc>>>0>nb>>>0?nb:dc;nb=Hb<<_a;c[p>>2]=nb;fc=nb&255;break}}}while(0);Cb=c[ua>>2]|0;c[ua>>2]=Cb+1;a[Cb]=fc;Cb=c[Aa>>2]|0;do{if((Cb|0)<(c[l+4>>2]|0)){gc=a[k+4+Cb|0]|0}else{Ib=c[F>>2]|0;nb=d[cc+(Ib>>>3)|0]|0;Hb=((Ib|0)<(dc|0))+Ib|0;c[F>>2]=Hb;if((nb&128>>>((Ib&7)>>>0)|0)==0){gc=c[p+4>>2]&255;break}else{Ib=cc+(Hb>>>3)|0;nb=(je(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)|0)<<(Hb&7)>>>(kb>>>0);Ib=Hb+Xa|0;c[F>>2]=dc>>>0>Ib>>>0?Ib:dc;Ib=nb<<_a;c[p+4>>2]=Ib;gc=Ib&255;break}}}while(0);Ib=c[wa>>2]|0;c[wa>>2]=Ib+1;a[Ib]=gc;Ib=c[Ba>>2]|0;do{if((Ib|0)<(c[l+8>>2]|0)){hc=a[k+8+Ib|0]|0}else{nb=c[F>>2]|0;Hb=d[cc+(nb>>>3)|0]|0;Eb=((nb|0)<(dc|0))+nb|0;c[F>>2]=Eb;if((Hb&128>>>((nb&7)>>>0)|0)==0){hc=c[p+8>>2]&255;break}else{nb=cc+(Eb>>>3)|0;Hb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(Eb&7)>>>(kb>>>0);nb=Eb+Xa|0;c[F>>2]=dc>>>0>nb>>>0?nb:dc;nb=Hb<<_a;c[p+8>>2]=nb;hc=nb&255;break}}}while(0);nb=c[ya>>2]|0;c[ya>>2]=nb+1;a[nb]=hc;c[qb>>2]=Cb<<3|ec|Ib<<6;nb=yb+1|0;if((nb|0)<16){yb=nb;Nb=cc;Lb=dc}else{Pb=gb;Qb=hb;break}}}}while(0);if((ab|0)>=16){break}ab=ab+1|0;hb=Qb;gb=Pb;cb=c[F>>2]|0;eb=c[L>>2]|0;ob=c[C>>2]|0}ob=Qa<<4;eb=c[P>>2]|0;cb=0;do{nrc(eb+((ca(c[(c[A>>2]|0)+32>>2]|0,cb)|0)+ob)|0,(cb<<4)+(w+380)|0,16)|0;cb=cb+1|0;}while((cb|0)<16);cb=c[R>>2]|0;eb=0;do{nrc(cb+((ca(c[(c[A>>2]|0)+36>>2]|0,eb)|0)+ob)|0,(eb<<4)+(w+636)|0,16)|0;eb=eb+1|0;}while((eb|0)<16);eb=c[T>>2]|0;cb=0;do{nrc(eb+((ca(c[(c[A>>2]|0)+40>>2]|0,cb)|0)+ob)|0,(cb<<4)+(w+892)|0,16)|0;cb=cb+1|0;}while((cb|0)<16)}else{Wa=119;break c}}while(0);if((Za|0)!=0){Wa=119}}}while(0);if((Wa|0)==119){Wa=0;Ua=Qa<<1;Sa=c[X>>2]|0;c[Y>>2]=c[Sa+((Ua|1)<<2)>>2];c[Z>>2]=0;c[_>>2]=0;c[$>>2]=0;Va=Sa+(Ua<<2)|0;c[Va>>2]=0;c[Va+4>>2]=0;Va=(c[aa>>2]|0)+(Qa<<2)|0;c[ba>>2]=c[Va>>2];c[da>>2]=0;c[Va>>2]=0;Va=(c[ea>>2]|0)+(Qa<<2)|0;c[fa>>2]=c[Va>>2];c[ga>>2]=0;c[Va>>2]=0}Va=Qa+1|0;if((Va|0)<(M|0)){Qa=Va}else{break}}Ka=c[A>>2]|0;La=c[P>>2]|0;Ma=c[R>>2]|0;Na=c[T>>2]|0}Pa=La+(c[Ka+32>>2]<<4)|0;c[P>>2]=Pa;Oa=Ma+(c[Ka+36>>2]<<4)|0;c[R>>2]=Oa;Va=Na+(c[Ka+40>>2]<<4)|0;c[T>>2]=Va;Ua=Fa+1|0;if((Ua|0)<(N|0)){Fa=Ua;Ga=Ka;Ha=Pa;Ia=Oa;Ja=Va}else{U=Ka;break a}}if((Wa|0)==39){KIb(e,16,2171616,(x=i,i=i+16|0,c[x>>2]=Qa,c[x+8>>2]=Fa,x)|0);i=x;y=-1094995529;i=j;return y|0}else if((Wa|0)==117){KIb(e,16,2120528,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=j;return y|0}}}while(0);N=YHb(f,U)|0;if((N|0)<0){y=N;i=j;return y|0}c[g>>2]=1;y=v;i=j;return y|0}}while(0);KIb(e,16,2360032,(x=i,i=i+16|0,c[x>>2]=D,c[x+8>>2]=E,x)|0);i=x;y=-1094995529;i=j;return y|0}function LVa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b);mJb(b+1408|0);mJb(b+1412|0);mJb(b+1416|0);MVa(b);return 0}function MVa(a){a=a|0;c3(a+4|0);c3(a+44|0);c3(a+84|0);c3(a+24|0);c3(a+64|0);c3(a+104|0);return}function NVa(a){a=a|0;var b=0,e=0,f=0;b=a+8|0;e=c[b>>2]|0;f=(d[(c[a>>2]|0)+(e>>>3)|0]|0)<<(e&7)>>>7;c[b>>2]=((e|0)<(c[a+16>>2]|0))+e;return f&1|0}function OVa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(f>>>3)|0;a=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(f&7)>>>((32-b|0)>>>0);h=f+b|0;c[e>>2]=g>>>0>h>>>0?h:g;return a|0}function PVa(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;do{if((c[d+8>>2]|0)==0){c[b+8>>2]=0;g=0}else{if((NVa(a)|0)==0){c[b+8>>2]=c[f+8>>2];g=0;break}h=c[e+8>>2]|0;i=c[f+8>>2]|0;if((h|0)<=0){c[b+8>>2]=(i|0)==0;g=1;break}j=OVa(a,h)|0;h=b+8|0;c[h>>2]=j;if((j|0)<(i|0)){g=1;break}c[h>>2]=j+1;g=1}}while(0);do{if((c[d+4>>2]|0)==0){c[b+4>>2]=0;k=g}else{if((NVa(a)|0)==0){c[b+4>>2]=c[f+4>>2];k=g;break}j=c[e+4>>2]|0;h=c[f+4>>2]|0;if((j|0)<=0){c[b+4>>2]=(h|0)==0;k=1;break}i=OVa(a,j)|0;j=b+4|0;c[j>>2]=i;if((i|0)<(h|0)){k=1;break}c[j>>2]=i+1;k=1}}while(0);if((c[d>>2]|0)==0){c[b>>2]=0;return}do{if((k|0)!=0){if((NVa(a)|0)!=0){break}c[b>>2]=c[f>>2];return}}while(0);k=c[e>>2]|0;e=c[f>>2]|0;if((k|0)<=0){c[b>>2]=(e|0)==0;return}f=OVa(a,k)|0;c[b>>2]=f;if((f|0)<(e|0)){return}c[b>>2]=f+1;return}function QVa(a,f,g,h,i,j,k,l){a=a|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;mrc(h|0,0,256)|0;m=c[f>>2]|0;n=c[f+4>>2]|0;f=a+8|0;o=c[f>>2]|0;p=a+16|0;q=c[p>>2]|0;r=c[a>>2]|0;a=r+(o>>>3)|0;s=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(o&7)>>>((32-m|0)>>>0);a=b[n+(s<<2)>>1]|0;t=b[n+(s<<2)+2>>1]|0;s=t<<16>>16;if(t<<16>>16<0){t=o+m|0;m=q>>>0>t>>>0?t:q;t=r+(m>>>3)|0;u=((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(m&7)>>>((s+32|0)>>>0))+a|0;v=b[n+(u<<2)+2>>1]|0;w=b[n+(u<<2)>>1]|0;x=m}else{v=s;w=a;x=o}o=v+x|0;x=q>>>0>o>>>0?o:q;c[f>>2]=x;do{if((w|0)==0){y=0}else{o=r+(x>>>3)|0;v=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(x&7)>>>((32-w|0)>>>0);o=x+w|0;c[f>>2]=q>>>0>o>>>0?o:q;if((v|0)>=(1<<w-1|0)){y=v;break}y=(-1<<w)+1+v|0}}while(0);w=(j|0)!=0;do{if((k|0)==0){if(!w){z=y;break}z=(c[i>>2]|0)+y|0}else{if(!w){z=(c[i+8>>2]|0)+y|0;break}j=c[i>>2]|0;q=c[i+4>>2]|0;x=c[i+8>>2]|0;v=x-q|0;o=j-q|0;if((((v|0)>-1?v:-v|0)|0)>(((o|0)>-1?o:-o|0)|0)){z=x+y|0;break}else{z=j+y|0;break}}}while(0);c[i>>2]=z;c[h>>2]=ca(e[l>>1]|0,z)|0;z=c[g+4>>2]|0;g=1;while(1){i=c[f>>2]|0;y=c[p>>2]|0;w=r+(i>>>3)|0;k=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(i&7)>>>23;w=b[z+(k<<2)>>1]|0;j=b[z+(k<<2)+2>>1]|0;k=j<<16>>16;if(j<<16>>16<0){j=i+9|0;x=y>>>0>j>>>0?j:y;j=r+(x>>>3)|0;o=((je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(x&7)>>>((k+32|0)>>>0))+w|0;A=b[z+(o<<2)+2>>1]|0;B=b[z+(o<<2)>>1]|0;C=x}else{A=k;B=w;C=i}i=A+C|0;w=y>>>0>i>>>0?i:y;c[f>>2]=w;if((B|0)==(-1|0)){D=-1;E=27;break}else if((B|0)==240){F=g+16|0}else if((B|0)==0){G=0;E=26;break}else{i=B>>4;k=B&15;do{if((k|0)==0){H=0}else{x=r+(w>>>3)|0;o=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(w&7)>>>((32-k|0)>>>0);x=w+k|0;c[f>>2]=y>>>0>x>>>0?x:y;if((o|0)>=(1<<k-1|0)){H=o;break}H=(-1<<k)+1+o|0}}while(0);k=i+g|0;if((k|0)>63){G=-1;E=26;break}y=d[1242080+k|0]|0;c[h+(y<<2)>>2]=ca(e[l+(y<<1)>>1]|0,H)|0;F=k+1|0}if((F|0)<64){g=F}else{E=25;break}}if((E|0)==25){D=((F|0)!=64)<<31>>31;return D|0}else if((E|0)==26){D=G;return D|0}else if((E|0)==27){return D|0}return 0}function RVa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[b>>2]=a;d=b+16|0;do{if((c[a+792>>2]|0)==8){c[d>>2]=1;c[a+140>>2]=11;if((c[a+100>>2]|0)<=1023){break}nrc(b+20|0,c[a+96>>2]|0,1024)|0}else{c[d>>2]=0;c[a+140>>2]=46}}while(0);a=UHb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function SVa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;j=i;i=i+24|0;k=j|0;l=j+16|0;m=c[h+28>>2]|0;n=c[e+60>>2]|0;o=n+8|0;c[o>>2]=c[h+24>>2];p=n+12|0;c[p>>2]=m;q=n+4|0;r=N4a(e,c[q>>2]|0)|0;if((r|0)<0){s=r;i=j;return s|0}r=n+16|0;a:do{if((c[r>>2]|0)==0){t=33}else{e=V1(h,0,0)|0;if((e|0)!=0){nrc(n+20|0,e|0,1024)|0;c[(c[q>>2]|0)+304>>2]=1}if((c[r>>2]|0)==0){t=33;break}e=l;u=l;v=c[q>>2]|0;w=c[v>>2]|0;x=c[v+32>>2]|0;v=n;y=c[v>>2]|0;z=c[y+120>>2]|0;A=(z|0)/4|0;B=c[y+124>>2]|0;C=(B|0)/4|0;do{if((B|0)>3){D=(z|0)>3;E=u+1|0;F=-4-x+4|0;G=x*-2|0;H=x*-3|0;I=C;J=0;K=ca(C,A)|0;L=0;M=0;b:while(1){if(D){N=ca((C-M<<2)-1|0,x)|0;O=A;P=J;Q=K;R=L;S=ca((I<<2)-1|0,x)|0;T=0;while(1){U=N+(T<<2)|0;c:do{if((R|0)==0){V=P+2|0;W=c[p>>2]|0;if((V|0)>(W|0)){t=13;break b}X=c[o>>2]|0;Y=a[X+P|0]|0;Z=a[X+(P+1)|0]|0;_=Y&255;if((Z|Y)<<24>>24==0&(Q|0)==0){break a}$=Z&255;if(($&252|0)==132){aa=(($<<8)-33792|_)-1|0;ba=V;break}if(Z<<24>>24>-1){da=P+4|0;if((da|0)>(W|0)){t=19;break b}a[e]=a[X+V|0]|0;a[E]=a[X+(P+3)|0]|0;ea=0;fa=($<<8|_)&65535;ga=S;while(1){a[w+ga|0]=a[u+(fa&1^1)|0]|0;a[w+(ga+1)|0]=a[u+((fa&65535)>>>1&1^1)|0]|0;a[w+(ga+2)|0]=a[u+((fa&65535)>>>2&1^1)|0]|0;a[w+(ga+3)|0]=a[u+((fa&65535)>>>3&1^1)|0]|0;ha=ea+1|0;if((ha|0)<4){ea=ha;fa=(fa&65535)>>>4;ga=F+ga|0}else{aa=0;ba=da;break c}}}if(!((Z&255)>>>0>143>>>0)){a[e]=Y;mrc(w+U|0,Y|0,4)|0;mrc(w+(U-x)|0,Y|0,4)|0;mrc(w+(U+G)|0,Y|0,4)|0;mrc(w+(U+H)|0,Y|0,4)|0;aa=0;ba=V;break}ia=P+10|0;if((ia|0)>(W|0)){t=24;break b}ga=X+V|0;fa=ga|0;ea=ga+4|0;ga=d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0;c[l>>2]=d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24;c[l+4>>2]=ga;ga=0;fa=($<<8|_)&65535;ea=S;while(1){ha=ga<<1&4;a[w+ea|0]=a[u+((ha|fa&1)^1)|0]|0;a[w+(ea+1)|0]=a[u+((ha|(fa&65535)>>>1&1)^1)|0]|0;ja=ha|2;a[w+(ea+2)|0]=a[u+((ja|(fa&65535)>>>2&1)^1)|0]|0;a[w+(ea+3)|0]=a[u+((ja|(fa&65535)>>>3&1)^1)|0]|0;ja=ga+1|0;if((ja|0)<4){ga=ja;fa=(fa&65535)>>>4;ea=F+ea|0}else{aa=0;ba=ia;break}}}else{aa=R-1|0;ba=P}}while(0);U=Q-1|0;ea=O-1|0;if((ea|0)>0){O=ea;P=ba;Q=U;R=aa;S=S+4|0;T=T+1|0}else{ka=ba;la=U;ma=aa;break}}}else{ka=J;la=K;ma=L}T=I-1|0;if((T|0)>0){I=T;J=ka;K=la;L=ma;M=M+1|0}else{t=30;break}}if((t|0)==13){KIb(c[v>>2]|0,16,2449120,(na=i,i=i+16|0,c[na>>2]=V,c[na+8>>2]=W,na)|0);i=na;break a}else if((t|0)==19){KIb(c[v>>2]|0,16,2449120,(na=i,i=i+16|0,c[na>>2]=da,c[na+8>>2]=W,na)|0);i=na;break a}else if((t|0)==24){KIb(c[v>>2]|0,16,2449120,(na=i,i=i+16|0,c[na>>2]=ia,c[na+8>>2]=W,na)|0);i=na;break a}else if((t|0)==30){oa=c[v>>2]|0;break}}else{oa=y}}while(0);if((c[oa+140>>2]|0)!=11){break}nrc(c[(c[q>>2]|0)+4>>2]|0,n+20|0,1024)|0}}while(0);d:do{if((t|0)==33){oa=c[q>>2]|0;W=c[oa>>2]|0;ia=(c[oa+32>>2]|0)/2|0;oa=c[n>>2]|0;da=c[oa+120>>2]|0;V=(da|0)/4|0;ma=c[oa+124>>2]|0;la=(ma|0)/4|0;if((ma|0)<=3){break}ma=(da|0)>3;da=k|0;ka=k+2|0;aa=k+4|0;ba=k+6|0;l=k+8|0;r=k+10|0;h=k+12|0;y=k+14|0;v=-4-ia+4|0;u=la;w=0;x=ca(la,V)|0;la=0;e:while(1){if(ma){e=V;A=w;C=x;z=la;B=ca((u<<2)-1|0,ia)|0;while(1){f:do{if((z|0)==0){pa=A+2|0;qa=c[p>>2]|0;if((pa|0)>(qa|0)){t=40;break e}M=c[o>>2]|0;L=a[M+A|0]|0;K=a[M+(A+1)|0]|0;J=L&255;if((K|L)<<24>>24==0&(C|0)==0){break d}L=K&255;if((L&252|0)==132){ra=((L<<8)-33792|J)-1|0;sa=pa;break}I=(L<<8|J)&65535;if(!(K<<24>>24>-1)){b[da>>1]=I;b[W+(B<<1)>>1]=I;b[W+(B+1<<1)>>1]=I;b[W+(B+2<<1)>>1]=I;b[W+(B+3<<1)>>1]=I;K=v+B|0;b[W+(K<<1)>>1]=I;b[W+(K+1<<1)>>1]=I;b[W+(K+2<<1)>>1]=I;b[W+(K+3<<1)>>1]=I;J=v+K|0;b[W+(J<<1)>>1]=I;b[W+(J+1<<1)>>1]=I;b[W+(J+2<<1)>>1]=I;b[W+(J+3<<1)>>1]=I;K=v+J|0;b[W+(K<<1)>>1]=I;b[W+(K+1<<1)>>1]=I;b[W+(K+2<<1)>>1]=I;b[W+(K+3<<1)>>1]=I;ra=0;sa=pa;break}ta=A+6|0;if((ta|0)>(qa|0)){t=46;break e}K=M+pa|0;J=(d[K]|d[K+1|0]<<8)<<16>>16;b[da>>1]=J;K=M+(A+4)|0;b[ka>>1]=(d[K]|d[K+1|0]<<8)<<16>>16;if(!(J<<16>>16<0)){J=0;K=I;L=B;while(1){b[W+(L<<1)>>1]=b[k+((K&1^1)<<1)>>1]|0;b[W+(L+1<<1)>>1]=b[k+(((K&65535)>>>1&1^1)<<1)>>1]|0;b[W+(L+2<<1)>>1]=b[k+(((K&65535)>>>2&1^1)<<1)>>1]|0;b[W+(L+3<<1)>>1]=b[k+(((K&65535)>>>3&1^1)<<1)>>1]|0;F=J+1|0;if((F|0)<4){J=F;K=(K&65535)>>>4;L=v+L|0}else{ra=0;sa=ta;break f}}}ua=A+18|0;if((ua|0)>(qa|0)){t=49;break e}L=M+ta|0;b[aa>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+8)|0;b[ba>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+10)|0;b[l>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+12)|0;b[r>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+14)|0;b[h>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=M+(A+16)|0;b[y>>1]=(d[L]|d[L+1|0]<<8)<<16>>16;L=0;K=I;J=B;while(1){F=L<<1&4;b[W+(J<<1)>>1]=b[k+(((F|K&1)^1)<<1)>>1]|0;b[W+(J+1<<1)>>1]=b[k+(((F|(K&65535)>>>1&1)^1)<<1)>>1]|0;H=F|2;b[W+(J+2<<1)>>1]=b[k+(((H|(K&65535)>>>2&1)^1)<<1)>>1]|0;b[W+(J+3<<1)>>1]=b[k+(((H|(K&65535)>>>3&1)^1)<<1)>>1]|0;H=L+1|0;if((H|0)<4){L=H;K=(K&65535)>>>4;J=v+J|0}else{ra=0;sa=ua;break}}}else{ra=z-1|0;sa=A}}while(0);J=C-1|0;K=e-1|0;if((K|0)>0){e=K;A=sa;C=J;z=ra;B=B+4|0}else{va=sa;wa=J;xa=ra;break}}}else{va=w;wa=x;xa=la}B=u-1|0;if((B|0)>0){u=B;w=va;x=wa;la=xa}else{break d}}if((t|0)==40){KIb(oa,16,2449120,(na=i,i=i+16|0,c[na>>2]=pa,c[na+8>>2]=qa,na)|0);i=na;break}else if((t|0)==46){KIb(oa,16,2449120,(na=i,i=i+16|0,c[na>>2]=ta,c[na+8>>2]=qa,na)|0);i=na;break}else if((t|0)==49){KIb(oa,16,2449120,(na=i,i=i+16|0,c[na>>2]=ua,c[na+8>>2]=qa,na)|0);i=na;break}}}while(0);na=YHb(f,c[q>>2]|0)|0;if((na|0)<0){s=na;i=j;return s|0}c[g>>2]=1;s=m;i=j;return s|0}function TVa(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function UVa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;e=a+120|0;f=a+124|0;g=a;if((tIb(c[e>>2]|0,c[f>>2]|0,0,g)|0)<0){h=-1;i=b;return h|0}do{if((c[e>>2]&3|0)==0){if((c[f>>2]&3|0)!=0){break}c[a+792>>2]=16;c[d+1244>>2]=c[a+360>>2];AIb(d+4|0,1);h=0;i=b;return h|0}}while(0);KIb(g,16,2449072,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=-1;i=b;return h|0}function VVa(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;i=c[b+60>>2]|0;j=b+120|0;k=b+124|0;l=(ca((c[j>>2]|0)*9|0,c[k>>2]|0)|0)+16384|0;m=d5a(b,f,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){n=m;return n|0}m=c[f+24>>2]|0;l=i+264|0;o=c[l>>2]|0;if((o|0)==0){p=hJb(ca((c[j>>2]|0)*3|0,(c[k>>2]|0)+3|0)|0)|0;c[l>>2]=p;q=p}else{q=o}o=c[k>>2]|0;p=(o+3&-4)-1|0;l=g+32|0;r=i+1244|0;s=(c[r>>2]|0)<(c[b+360>>2]|0);b=s&1^1;do{if((o|0)>0){t=c[l>>2]|0;u=c[j>>2]|0;v=ca(p,t)|0;w=i+460|0;x=w;z=i+268|0;A=z;B=z;z=i+1228|0;C=z;D=i+844|0;E=D;F=D;G=i+4|0;H=i+652|0;I=H;J=H;K=i+904|0;L=w;w=i+748|0;M=w;N=i+1036|0;O=N;P=N;N=i+1096|0;Q=w;w=i+1232|0;R=i+1236|0;S=i+752|0;T=i+756|0;U=i+656|0;V=i+660|0;W=i+664|0;X=i+668|0;Y=i+672|0;Z=m;_=0;$=0;aa=1;ba=q+(ca(u*3|0,p)|0)|0;da=(c[g>>2]|0)+v|0;v=u;u=t;t=o;while(1){if((v|0)>0){ea=Z;fa=0;ga=$;ha=aa;while(1){ia=0;do{ja=ia<<2;ka=0;do{la=e[da+(ka+fa+((ca(c[l>>2]|0,ia)|0)/-2|0)<<1)>>1]|0;ma=ka+ja|0;na=(c[681928+(ma<<2)>>2]|0)*3|0;oa=ma*3|0;ma=la>>>10&31;c[x+(na<<2)>>2]=ma;c[A+(oa<<2)>>2]=ma;ma=la>>>5&31;c[x+(na+1<<2)>>2]=ma;c[A+(oa+1<<2)>>2]=ma;ma=la&31;c[x+(na+2<<2)>>2]=ma;c[A+(oa+2<<2)>>2]=ma;ka=ka+1|0;}while((ka|0)<4);ia=ia+1|0;}while((ia|0)<4);if(s){ia=fa*3|0;ka=c[j>>2]|0;ja=0;ma=0;while(1){oa=(d[ba+(ma+ia)|0]|0)-(c[A+(ma<<2)>>2]|0)|0;na=(ca(oa,oa)|0)+ja|0;oa=ma+1|0;if((oa|0)<12){ja=na;ma=oa}else{pa=na;qa=0;break}}while(1){ma=(d[ba+(qa+ia+(ka*-3|0))|0]|0)-(c[A+(qa+12<<2)>>2]|0)|0;ja=(ca(ma,ma)|0)+pa|0;ma=qa+1|0;if((ma|0)<12){pa=ja;qa=ma}else{ra=ja;sa=0;break}}while(1){ja=(d[ba+(sa+ia+(ka*-6|0))|0]|0)-(c[A+(sa+24<<2)>>2]|0)|0;ma=(ca(ja,ja)|0)+ra|0;ja=sa+1|0;if((ja|0)<12){ra=ma;sa=ja}else{ta=ma;ua=0;break}}do{ma=(d[ba+(ua+ia+(ka*-9|0))|0]|0)-(c[A+(ua+36<<2)>>2]|0)|0;ta=(ca(ma,ma)|0)+ta|0;ua=ua+1|0;}while((ua|0)<12);va=(ta|0)/24|0}else{va=2147483647}Tca(B,3,16,C,1,1,F,G);Uca(B,3,16,C,1,1,F,G);ka=c[C>>2]|0;if((ka|0)==1){c[C>>2]=0;wa=0}else{wa=ka}ka=i+1232|0;ia=c[ka>>2]|0;ma=i+1236|0;ja=c[ma>>2]|0;na=0;oa=0;do{la=oa<<2;xa=z;ya=oa*12|0;za=wa-(c[A+(ya<<2)>>2]|0)|0;Aa=(ca(za,za)|0)+na|0;za=ia-(c[A+((ya|1)<<2)>>2]|0)|0;Ba=(ca(za,za)|0)+Aa|0;Aa=ja-(c[A+((ya|2)<<2)>>2]|0)|0;ya=(ca(Aa,Aa)|0)+Ba|0;Ba=(la|1)*3|0;Aa=wa-(c[A+(Ba<<2)>>2]|0)|0;za=(ca(Aa,Aa)|0)+ya|0;ya=ia-(c[A+(Ba+1<<2)>>2]|0)|0;Aa=(ca(ya,ya)|0)+za|0;za=ja-(c[A+(Ba+2<<2)>>2]|0)|0;Ba=(ca(za,za)|0)+Aa|0;Aa=(la|2)*3|0;za=wa-(c[A+(Aa<<2)>>2]|0)|0;ya=(ca(za,za)|0)+Ba|0;Ba=ia-(c[A+((Aa|1)<<2)>>2]|0)|0;za=(ca(Ba,Ba)|0)+ya|0;ya=ja-(c[A+(Aa+2<<2)>>2]|0)|0;Aa=(ca(ya,ya)|0)+za|0;za=(la|3)*3|0;la=wa-(c[A+(za<<2)>>2]|0)|0;ya=(ca(la,la)|0)+Aa|0;Aa=ia-(c[A+(za+1<<2)>>2]|0)|0;la=(ca(Aa,Aa)|0)+ya|0;ya=ja-(c[A+(za+2<<2)>>2]|0)|0;na=(ca(ya,ya)|0)+la|0;oa=oa+1|0;}while((oa|0)<4);oa=((na|0)/24|0)+2|0;ja=(oa|0)<(va|0);ia=ja&1;la=ja?oa:va;Tca(B,3,16,J,2,1,F,G);Uca(B,3,16,J,2,1,F,G);if((c[K>>2]|0)==0){oa=i+664|0;ja=c[oa>>2]|0;ya=H;c[oa>>2]=c[ya>>2];c[ya>>2]=ja&255;ja=i+668|0;ya=c[ja>>2]|0;oa=i+656|0;c[ja>>2]=c[oa>>2];c[oa>>2]=ya&255;ya=i+672|0;oa=c[ya>>2]|0;ja=i+660|0;c[ya>>2]=c[ja>>2];c[ja>>2]=oa&255;oa=D;c[oa>>2]=c[oa>>2]^1;oa=i+848|0;c[oa>>2]=c[oa>>2]^1;oa=i+852|0;c[oa>>2]=c[oa>>2]^1;oa=i+856|0;c[oa>>2]=c[oa>>2]^1;oa=i+860|0;c[oa>>2]=c[oa>>2]^1;oa=i+864|0;c[oa>>2]=c[oa>>2]^1;oa=i+868|0;c[oa>>2]=c[oa>>2]^1;oa=i+872|0;c[oa>>2]=c[oa>>2]^1;oa=i+876|0;c[oa>>2]=c[oa>>2]^1;oa=i+880|0;c[oa>>2]=c[oa>>2]^1;oa=i+884|0;c[oa>>2]=c[oa>>2]^1;oa=i+888|0;c[oa>>2]=c[oa>>2]^1;oa=i+892|0;c[oa>>2]=c[oa>>2]^1;oa=i+896|0;c[oa>>2]=c[oa>>2]^1;oa=i+900|0;c[oa>>2]=c[oa>>2]^1;c[i+904>>2]=1;Ca=0;Da=0}else{Ca=0;Da=0}do{oa=Da<<2;ja=Da*12|0;ya=(c[E+(oa<<2)>>2]|0)*3|0;za=(c[I+(ya<<2)>>2]|0)-(c[A+(ja<<2)>>2]|0)|0;Aa=(ca(za,za)|0)+Ca|0;za=(c[I+(ya+1<<2)>>2]|0)-(c[A+((ja|1)<<2)>>2]|0)|0;Ba=(ca(za,za)|0)+Aa|0;Aa=(c[I+(ya+2<<2)>>2]|0)-(c[A+((ja|2)<<2)>>2]|0)|0;ya=(ca(Aa,Aa)|0)+Ba|0;Ba=(c[E+((oa|1)<<2)>>2]|0)*3|0;Aa=ja|3;za=(c[I+(Ba<<2)>>2]|0)-(c[A+(Aa<<2)>>2]|0)|0;Ea=(ca(za,za)|0)+ya|0;ya=(c[I+(Ba+1<<2)>>2]|0)-(c[A+(Aa+1<<2)>>2]|0)|0;za=(ca(ya,ya)|0)+Ea|0;Ea=(c[I+(Ba+2<<2)>>2]|0)-(c[A+(Aa+2<<2)>>2]|0)|0;Aa=(ca(Ea,Ea)|0)+za|0;za=(c[E+((oa|2)<<2)>>2]|0)*3|0;Ea=(c[I+(za<<2)>>2]|0)-(c[A+(ja+6<<2)>>2]|0)|0;Ba=(ca(Ea,Ea)|0)+Aa|0;Aa=(c[I+(za+1<<2)>>2]|0)-(c[A+(ja+7<<2)>>2]|0)|0;Ea=(ca(Aa,Aa)|0)+Ba|0;Ba=(c[I+(za+2<<2)>>2]|0)-(c[A+(ja+8<<2)>>2]|0)|0;za=(ca(Ba,Ba)|0)+Ea|0;Ea=(c[E+((oa|3)<<2)>>2]|0)*3|0;oa=(c[I+(Ea<<2)>>2]|0)-(c[A+(ja+9<<2)>>2]|0)|0;Ba=(ca(oa,oa)|0)+za|0;za=(c[I+(Ea+1<<2)>>2]|0)-(c[A+(ja+10<<2)>>2]|0)|0;oa=(ca(za,za)|0)+Ba|0;Ba=(c[I+(Ea+2<<2)>>2]|0)-(c[A+(ja+11<<2)>>2]|0)|0;Ca=(ca(Ba,Ba)|0)+oa|0;Da=Da+1|0;}while((Da|0)<4);na=((Ca|0)/24|0)+6|0;oa=(na|0)<(la|0);Ba=oa?2:ia;Tca(L,3,4,M,2,1,O,G);Uca(L,3,4,M,2,1,O,G);ja=i+508|0;Ea=i+772|0;za=i+1052|0;Tca(ja,3,4,Ea,2,1,za,G);Uca(ja,3,4,Ea,2,1,za,G);za=i+556|0;Ea=i+796|0;ja=i+1068|0;Tca(za,3,4,Ea,2,1,ja,G);Uca(za,3,4,Ea,2,1,ja,G);ja=i+604|0;Ea=i+820|0;za=i+1084|0;Tca(ja,3,4,Ea,2,1,za,G);Uca(ja,3,4,Ea,2,1,za,G);za=oa?na:la;if((c[N>>2]|0)==0){na=i+832|0;oa=c[na>>2]|0;Ea=i+820|0;c[na>>2]=c[Ea>>2];c[Ea>>2]=oa&255;oa=i+836|0;Ea=c[oa>>2]|0;na=i+824|0;c[oa>>2]=c[na>>2];c[na>>2]=Ea&255;Ea=i+840|0;na=c[Ea>>2]|0;oa=i+828|0;c[Ea>>2]=c[oa>>2];c[oa>>2]=na&255;na=i+1084|0;c[na>>2]=c[na>>2]^1;na=i+1088|0;c[na>>2]=c[na>>2]^1;na=i+1092|0;c[na>>2]=c[na>>2]^1;c[i+1096>>2]=1;Fa=0;Ga=0}else{Fa=0;Ga=0}while(1){na=Ga<<2;oa=Ga<<1&4;Ea=Ga*12|0;Ha=Fa;ja=0;do{Aa=((ja&2|oa)+(c[P+(c[681928+(ja+na<<2)>>2]<<2)>>2]|0)|0)*3|0;ya=(ja*3|0)+Ea|0;Ia=(c[Q+(Aa<<2)>>2]|0)-(c[A+(ya<<2)>>2]|0)|0;Ja=(ca(Ia,Ia)|0)+Ha|0;Ia=(c[Q+(Aa+1<<2)>>2]|0)-(c[A+(ya+1<<2)>>2]|0)|0;Ka=(ca(Ia,Ia)|0)+Ja|0;Ja=(c[Q+(Aa+2<<2)>>2]|0)-(c[A+(ya+2<<2)>>2]|0)|0;Ha=(ca(Ja,Ja)|0)+Ka|0;ja=ja+1|0;}while((ja|0)<4);ja=Ga+1|0;if((ja|0)<4){Fa=Ha;Ga=ja}else{break}}la=(((Ha|0)/24|0)+18|0)<(za|0)?3:Ba;ia=(la|0)==0;ja=(ia&1)+ga|0;La=ia?0:ha;if(ia){if((ja|0)==1023){Ma=29}else{Na=ea;Oa=ja}}else{if((ja|0)==0){Pa=ea;Ma=30}else{Ma=29}}if((Ma|0)==29){Ma=0;ia=ea;y=(ja|33792)&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;Pa=ea+2|0;Ma=30}do{if((Ma|0)==30){Ma=0;if((la|0)==1){ia=Pa;y=(c[C>>2]<<10|c[w>>2]<<5|c[R>>2]|32768)&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=0;do{ja=ia*3|0;Ea=fa*3|0;a[ba+(Ea-(ca(ja,c[j>>2]|0)|0))|0]=c[xa>>2];a[ba+((Ea|1)-(ca(ja,c[j>>2]|0)|0))|0]=c[ka>>2];a[ba+((Ea|2)-(ca(ja,c[j>>2]|0)|0))|0]=c[ma>>2];Ea=(fa|1)*3|0;a[ba+(Ea-(ca(ja,c[j>>2]|0)|0))|0]=c[xa>>2];a[ba+(Ea+1-(ca(ja,c[j>>2]|0)|0))|0]=c[ka>>2];a[ba+(Ea+2-(ca(ja,c[j>>2]|0)|0))|0]=c[ma>>2];Ea=(fa|2)*3|0;a[ba+(Ea-(ca(ja,c[j>>2]|0)|0))|0]=c[xa>>2];a[ba+((Ea|1)-(ca(ja,c[j>>2]|0)|0))|0]=c[ka>>2];a[ba+(Ea+2-(ca(ja,c[j>>2]|0)|0))|0]=c[ma>>2];Ea=(fa|3)*3|0;a[ba+(Ea-(ca(ja,c[j>>2]|0)|0))|0]=c[xa>>2];a[ba+(Ea+1-(ca(ja,c[j>>2]|0)|0))|0]=c[ka>>2];a[ba+(Ea+2-(ca(ja,c[j>>2]|0)|0))|0]=c[ma>>2];ia=ia+1|0;}while((ia|0)<4);Na=Pa+2|0;Oa=0;break}else if((la|0)==2){ia=0;ja=0;while(1){Ea=ja<<2;na=ja*3|0;Qa=ia;oa=0;do{Ka=oa+Ea|0;Ja=E+(Ka<<2)|0;ya=c[Ja>>2]|0;Aa=(oa+fa|0)*3|0;a[ba+(Aa-(ca(na,c[j>>2]|0)|0))|0]=c[I+((ya*3|0)<<2)>>2];a[ba+(Aa+1-(ca(na,c[j>>2]|0)|0))|0]=c[I+(((c[Ja>>2]|0)*3|0)+1<<2)>>2];a[ba+(Aa+2-(ca(na,c[j>>2]|0)|0))|0]=c[I+(((c[Ja>>2]|0)*3|0)+2<<2)>>2];Qa=(ya^1)<<Ka|Qa;oa=oa+1|0;}while((oa|0)<4);oa=ja+1|0;if((oa|0)<4){ia=Qa;ja=oa}else{break}}ja=Pa;y=Qa&65535;a[ja]=y;y=y>>8;a[ja+1|0]=y;ja=Pa+2|0;y=(c[U>>2]<<5|c[J>>2]<<10|c[V>>2])&65535;a[ja]=y;y=y>>8;a[ja+1|0]=y;ja=Pa+4|0;y=(c[X>>2]<<5|c[W>>2]<<10|c[Y>>2])&65535;a[ja]=y;y=y>>8;a[ja+1|0]=y;Na=Pa+6|0;Oa=0;break}else if((la|0)==3){ja=0;ia=0;while(1){oa=ia<<2;na=ia<<1&4;Ea=ia*3|0;Ra=ja;Ka=0;do{ya=Ka+oa|0;Ja=P+(c[681928+(ya<<2)>>2]<<2)|0;Aa=c[Ja>>2]|0;Ia=Ka&2|na;Sa=(Ka+fa|0)*3|0;a[ba+(Sa-(ca(Ea,c[j>>2]|0)|0))|0]=c[Q+(((Ia+Aa|0)*3|0)<<2)>>2];a[ba+(Sa+1-(ca(Ea,c[j>>2]|0)|0))|0]=c[Q+(((Ia+(c[Ja>>2]|0)|0)*3|0)+1<<2)>>2];a[ba+(Sa+2-(ca(Ea,c[j>>2]|0)|0))|0]=c[Q+(((Ia+(c[Ja>>2]|0)|0)*3|0)+2<<2)>>2];Ra=(Aa^1)<<ya|Ra;Ka=Ka+1|0;}while((Ka|0)<4);Ka=ia+1|0;if((Ka|0)<4){ja=Ra;ia=Ka}else{break}}ia=Pa;y=Ra&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=Pa+2|0;y=(c[M>>2]<<10|c[S>>2]<<5|c[T>>2]|32768)&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=Pa+4|0;y=(c[i+764>>2]<<5|c[i+760>>2]<<10|c[i+768>>2])&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=Pa+6|0;y=(c[i+776>>2]<<5|c[i+772>>2]<<10|c[i+780>>2])&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=Pa+8|0;y=(c[i+788>>2]<<5|c[i+784>>2]<<10|c[i+792>>2])&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=Pa+10|0;y=(c[i+800>>2]<<5|c[i+796>>2]<<10|c[i+804>>2])&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=Pa+12|0;y=(c[i+812>>2]<<5|c[i+808>>2]<<10|c[i+816>>2])&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=Pa+14|0;y=(c[i+824>>2]<<5|c[i+820>>2]<<10|c[i+828>>2])&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;ia=Pa+16|0;y=(c[i+836>>2]<<5|c[i+832>>2]<<10|c[i+840>>2])&65535;a[ia]=y;y=y>>8;a[ia+1|0]=y;Na=Pa+18|0;Oa=0;break}else{Na=Pa;Oa=0;break}}}while(0);la=fa+4|0;Ta=c[j>>2]|0;if((la|0)<(Ta|0)){ea=Na;fa=la;ga=Oa;ha=La}else{break}}Ua=Na;Va=Oa;Wa=La;Xa=Ta;Ya=c[l>>2]|0;Za=c[k>>2]|0}else{Ua=Z;Va=$;Wa=aa;Xa=v;Ya=u;Za=t}ha=_+4|0;if((ha|0)<(Za|0)){Z=Ua;_=ha;$=Va;aa=Wa;ba=ba+(Xa*-12|0)|0;da=da+(-(Ya<<1)<<1)|0;v=Xa;u=Ya;t=Za}else{break}}if((Va|0)==0){_a=Ua;$a=Wa;break}t=Ua;y=(Va|33792)&65535;a[t]=y;y=y>>8;a[t+1|0]=y;_a=Ua+2|0;$a=Wa}else{_a=m;$a=1}}while(0);a[_a]=0;a[_a+1|0]=0;if(($a|b|0)==0){c[r>>2]=(c[r>>2]|0)+1}else{c[r>>2]=0;r=f+36|0;c[r>>2]=c[r>>2]|1}c[f+28>>2]=_a+2-m;c[h>>2]=1;n=0;return n|0}function WVa(a){a=a|0;mJb((c[a+60>>2]|0)+264|0);return 0}function XVa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+60>>2]|0;d=c[a+120>>2]|0;e=c[a+124>>2]|0;f=a+48|0;if((c[f>>2]|0)==1297498929){g=e+3|0;h=d+3|0}else{g=e;h=d}d=H4a(a,h&-4,g&-4)|0;if((d|0)<0){i=d;return i|0}c[a+140>>2]=(c[f>>2]|0)==1297498929?46:30;f=UHb()|0;c[b>>2]=f;if((f|0)==0){i=-12;return i|0}f=c[a+100>>2]|0;if((f|0)>8){j=(grc((c[a+96>>2]|0)+(f-9)|0,2638296,9)|0)==0|0}else{j=0}c[b+4>>2]=j;i=0;return i|0}function YVa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;j=i;i=i+528|0;k=j|0;l=j+512|0;m=c[e+60>>2]|0;n=m;o=N4a(e,c[n>>2]|0)|0;if((o|0)<0){p=o;i=j;return p|0}o=c[h+24>>2]|0;q=h+28|0;h=c[q>>2]|0;if(!((h|0)>-1)){KIb(0,0,2171584,(r=i,i=i+24|0,c[r>>2]=2144080,c[r+8>>2]=2120504,c[r+16>>2]=135,r)|0);i=r;Hd();return 0}s=o+h|0;t=c[n>>2]|0;u=c[t>>2]|0;v=c[e+120>>2]|0;w=c[e+124>>2]|0;x=c[t+32>>2]|0;a:do{if((c[e+48>>2]|0)==1297498929){t=l|0;y=l+2|0;z=l+12|0;A=l+8|0;B=l+4|0;C=l+14|0;D=l+10|0;E=l+6|0;F=s;G=0;H=o;b:while(1){I=ca(G,x)|0;J=ca(G|1,x)|0;K=ca(G|2,x)|0;L=ca(G|3,x)|0;M=0;N=H;while(1){if(!((F-N|0)>>>0>5>>>0)){break a}O=N;P=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)&65535;O=N+2|0;Q=he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0;b[t>>1]=Q;O=N+6|0;R=N+4|0;S=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;b[y>>1]=S;if(Q<<16>>16<0){if((F-O|0)>>>0<12>>>0){break b}R=O;b[B>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+8|0;b[E>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+10|0;b[A>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+12|0;b[D>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+14|0;b[z>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=N+16|0;b[C>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;T=N+18|0}else{b[z>>1]=Q;b[A>>1]=Q;b[B>>1]=Q;b[C>>1]=S;b[D>>1]=S;b[E>>1]=S;T=O}O=M<<1;S=O+I|0;b[u+S>>1]=b[l+((P&1^1)<<1)>>1]&32767;b[u+(S|2)>>1]=b[l+((P>>>1&1^1)<<1)>>1]&32767;b[u+(S+4)>>1]=b[l+((P>>>2&1^3)<<1)>>1]&32767;b[u+(S+6)>>1]=b[l+((P>>>3&1^3)<<1)>>1]&32767;S=O+J|0;b[u+S>>1]=b[l+((P>>>4&1^1)<<1)>>1]&32767;b[u+(S+2)>>1]=b[l+((P>>>5&1^1)<<1)>>1]&32767;b[u+(S+4)>>1]=b[l+((P>>>6&1^3)<<1)>>1]&32767;b[u+(S+6)>>1]=b[l+((P>>>7&1^3)<<1)>>1]&32767;S=O+K|0;b[u+S>>1]=b[l+((P>>>8&1^5)<<1)>>1]&32767;b[u+(S+2)>>1]=b[l+((P>>>9&1^5)<<1)>>1]&32767;b[u+(S+4)>>1]=b[l+((P>>>10&1^7)<<1)>>1]&32767;b[u+(S+6)>>1]=b[l+((P>>>11&1^7)<<1)>>1]&32767;S=O+L|0;b[u+S>>1]=b[l+((P>>>12&1^5)<<1)>>1]&32767;b[u+(S+2)>>1]=b[l+((P>>>13&1^5)<<1)>>1]&32767;b[u+(S+4)>>1]=b[l+((P>>>14&1^7)<<1)>>1]&32767;b[u+(S+6)>>1]=b[l+((P>>>15^7)<<1)>>1]&32767;P=M+4|0;if((P|0)<(v|0)){M=P;N=T}else{break}}N=G+4|0;if((N|0)<(w|0)){G=N;H=T}else{break a}}KIb(e,24,2203368,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=-1094995529;i=j;return p|0}else{H=c[m+4>>2]|0;G=s;if(h>>>0<6>>>0){p=-1094995529;i=j;return p|0}E=o;D=o+4|0;if(((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65532|0)==(v|0)){E=o+2|0;if(((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65532|0)!=(w|0)){U=18}}else{U=18}if((U|0)==18){KIb(e,24,2295928,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}if((a[D]|0)!=0){QIb(e,2244960,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=-1163346256;i=j;return p|0}D=o+6|0;E=a[o+5|0]|0;C=E&255;B=C*3|0;if((G-D|0)>>>0<B>>>0){p=-1094995529;i=j;return p|0}A=(E&255)>>>0>128>>>0;E=A?128:C;if((E|0)==0){V=D}else{C=E>>>0>1>>>0?(E*3|0)+6|0:9;z=0;F=D;while(1){c[k+(z<<2)>>2]=d[F]<<16|d[F+1|0]<<8|d[F+2|0]|-16777216;D=z+1|0;if((D|0)<(E|0)){z=D;F=F+3|0}else{break}}V=o+C|0}if(A){F=B-384|0;z=G-V|0;W=V+(z>>>0>F>>>0?F:z)|0}else{W=V}if((H|0)==0){X=u;Y=x}else{X=u+(ca(w-1|0,x)|0)|0;Y=-x|0}z=Y+4|0;F=Y+8|0;E=Y+12|0;D=Y<<1;y=D+4|0;t=D+8|0;N=D+12|0;M=Y*3|0;L=M+4|0;K=M+8|0;J=M+12|0;I=0;P=W;c:while(1){S=ca(I,Y)|0;O=ca(I|1,Y)|0;Q=ca(I|2,Y)|0;R=ca(I|3,Y)|0;Z=0;_=P;while(1){if((s|0)==(_|0)){break a}$=_+1|0;aa=d[_]|0;do{if((aa&128|0)==0){if((s|0)==($|0)){p=-1094995529;U=50;break c}ba=_+2|0;da=d[$]|0;if((da&128|0)==0){if((G-ba|0)>>>0<8>>>0){p=-1094995529;U=50;break c}ea=c[k+((aa&127)<<2)>>2]|0;fa=c[k+((da&127)<<2)>>2]|0;ga=c[k+((a[ba]&127)<<2)>>2]|0;ha=c[k+((a[_+3|0]&127)<<2)>>2]|0;ia=c[k+((a[_+4|0]&127)<<2)>>2]|0;ja=c[k+((a[_+5|0]&127)<<2)>>2]|0;ka=c[k+((a[_+6|0]&127)<<2)>>2]|0;la=c[k+((a[_+7|0]&127)<<2)>>2]|0;ma=_+8|0;na=(d[ma]|d[ma+1|0]<<8)<<16>>16&65535;ma=Z<<2;oa=ma+S|0;c[X+oa>>2]=(na&1|0)==0?ea:fa;c[X+(oa+4)>>2]=(na&2|0)==0?ea:fa;c[X+(oa+8)>>2]=(na&4|0)==0?ga:ha;c[X+(oa+12)>>2]=(na&8|0)==0?ga:ha;oa=ma+O|0;c[X+oa>>2]=(na&16|0)==0?ea:fa;c[X+(oa+4)>>2]=(na&32|0)==0?ea:fa;c[X+(oa+8)>>2]=(na&64|0)==0?ga:ha;c[X+(oa+12)>>2]=(na&128|0)==0?ga:ha;ha=ma+Q|0;c[X+ha>>2]=(na&256|0)==0?ia:ja;c[X+(ha+4)>>2]=(na&512|0)==0?ia:ja;c[X+(ha+8)>>2]=(na&1024|0)==0?ka:la;c[X+(ha+12)>>2]=(na&2048|0)==0?ka:la;ha=ma+R|0;c[X+ha>>2]=(na&4096|0)==0?ia:ja;c[X+(ha+4)>>2]=(na&8192|0)==0?ia:ja;c[X+(ha+8)>>2]=(na&16384|0)==0?ka:la;c[X+(ha+12)>>2]=(na&32768|0)==0?ka:la;pa=_+10|0;break}la=aa&127;ka=da&127;if((la|0)==(ka|0)){da=(Z<<2)+S|0;na=c[k+(la<<2)>>2]|0;c[X+da>>2]=na;c[X+(da+4)>>2]=na;c[X+(da+8)>>2]=na;c[X+(da+12)>>2]=na;c[X+(da+Y)>>2]=na;c[X+(da+z)>>2]=na;c[X+(da+F)>>2]=na;c[X+(da+E)>>2]=na;c[X+(da+D)>>2]=na;c[X+(da+y)>>2]=na;c[X+(da+t)>>2]=na;c[X+(da+N)>>2]=na;c[X+(da+M)>>2]=na;c[X+(da+L)>>2]=na;c[X+(da+K)>>2]=na;c[X+(da+J)>>2]=na;pa=ba;break}if((G-ba|0)>>>0<2>>>0){p=-1094995529;U=50;break c}na=c[k+(la<<2)>>2]|0;la=c[k+(ka<<2)>>2]|0;ka=ba;ba=(d[ka]|d[ka+1|0]<<8)<<16>>16&65535;ka=Z<<2;da=ka+S|0;c[X+da>>2]=(ba&1|0)==0?na:la;c[X+(da+4)>>2]=(ba&2|0)==0?na:la;c[X+(da+8)>>2]=(ba&4|0)==0?na:la;c[X+(da+12)>>2]=(ba&8|0)==0?na:la;da=ka+O|0;c[X+da>>2]=(ba&16|0)==0?na:la;c[X+(da+4)>>2]=(ba&32|0)==0?na:la;c[X+(da+8)>>2]=(ba&64|0)==0?na:la;c[X+(da+12)>>2]=(ba&128|0)==0?na:la;da=ka+Q|0;c[X+da>>2]=(ba&256|0)==0?na:la;c[X+(da+4)>>2]=(ba&512|0)==0?na:la;c[X+(da+8)>>2]=(ba&1024|0)==0?na:la;c[X+(da+12)>>2]=(ba&2048|0)==0?na:la;da=ka+R|0;c[X+da>>2]=(ba&4096|0)==0?na:la;c[X+(da+4)>>2]=(ba&8192|0)==0?na:la;c[X+(da+8)>>2]=(ba&16384|0)==0?na:la;c[X+(da+12)>>2]=(ba&32768|0)==0?na:la;pa=_+4|0}else{la=aa&63;na=la<<2|la>>>4;if((aa&64|0)!=0){la=(Z<<2)+S|0;ba=na|na<<8|na<<16|-16777216;c[X+la>>2]=ba;c[X+(la+4)>>2]=ba;c[X+(la+8)>>2]=ba;c[X+(la+12)>>2]=ba;c[X+(la+Y)>>2]=ba;c[X+(la+z)>>2]=ba;c[X+(la+F)>>2]=ba;c[X+(la+E)>>2]=ba;c[X+(la+D)>>2]=ba;c[X+(la+y)>>2]=ba;c[X+(la+t)>>2]=ba;c[X+(la+N)>>2]=ba;c[X+(la+M)>>2]=ba;c[X+(la+L)>>2]=ba;c[X+(la+K)>>2]=ba;c[X+(la+J)>>2]=ba;pa=$;break}if((G-$|0)>>>0<2>>>0){p=-1094995529;U=50;break c}ba=(Z<<2)+S|0;la=na|d[$]<<8|d[_+2|0]<<16|-16777216;c[X+ba>>2]=la;c[X+(ba+4)>>2]=la;c[X+(ba+8)>>2]=la;c[X+(ba+12)>>2]=la;c[X+(ba+Y)>>2]=la;c[X+(ba+z)>>2]=la;c[X+(ba+F)>>2]=la;c[X+(ba+E)>>2]=la;c[X+(ba+D)>>2]=la;c[X+(ba+y)>>2]=la;c[X+(ba+t)>>2]=la;c[X+(ba+N)>>2]=la;c[X+(ba+M)>>2]=la;c[X+(ba+L)>>2]=la;c[X+(ba+K)>>2]=la;c[X+(ba+J)>>2]=la;pa=_+3|0}}while(0);$=Z+4|0;if(($|0)<(v|0)){Z=$;_=pa}else{break}}_=I+4|0;if((_|0)<(w|0)){I=_;P=pa}else{break a}}if((U|0)==50){i=j;return p|0}}}while(0);c[g>>2]=1;g=YHb(f,c[n>>2]|0)|0;if((g|0)<0){p=g;i=j;return p|0}p=c[q>>2]|0;i=j;return p|0}function ZVa(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function _Va(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+60|0;d=c[b>>2]|0;e=d+3008|0;c[e>>2]=UHb()|0;f=UHb()|0;c[d+3012>>2]=f;g=c[e>>2]|0;if((g|0)==0|(f|0)==0){f=c[b>>2]|0;c[f+1140>>2]=0;oQa(a)|0;VHb(f+3008|0);VHb(f+3012|0);c[f+3032>>2]=0;mJb(f+3028|0);mJb(f+3040|0);h=-12;return h|0}else{c[d+1140>>2]=g;h=gQa(a)|0;return h|0}return 0}function $Va(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[b+60>>2]|0;o=g;c[j>>2]=m;p=m+n|0;q=g+1144|0;c[q>>2]=0;r=g+3024|0;c[r>>2]=0;a:do{if((n|0)>0){s=g+8|0;t=g+20|0;u=g+24|0;v=g+12|0;w=g+16|0;x=g+3044|0;y=g+3048|0;z=g+4|0;A=g+3032|0;B=g+3028|0;C=B;D=g+3036|0;E=g+3040|0;F=E;G=g+3020|0;H=g+816|0;I=b;J=g+812|0;K=g+1140|0;L=b+696|0;M=g+3016|0;N=g+3008|0;O=g+900|0;P=g+904|0;b:while(1){Q=mQa(o,j,p,k,l)|0;if((Q|0)<0){R=62;break a}S=c[k>>2]|0;T=c[l>>2]<<3;U=T>>>0>2147483639>>>0|(S|0)==0;V=U?0:S;S=U?0:T;c[s>>2]=V;c[t>>2]=S;T=S+8|0;c[u>>2]=T;c[v>>2]=V+(S>>3);c[w>>2]=0;do{if((Q-224|0)>>>0<16>>>0){S=c[l>>2]|0;if((S|0)<2){break}V=c[k>>2]|0;U=(he((d[V]|d[V+1|0]<<8)<<16>>16|0)|0)&65535;V=((U|0)>(S|0)?S:U)<<3;c[w>>2]=T>>>0>V>>>0?V:T}}while(0);c:do{switch(Q|0){case 218:{if((c[G>>2]|0)==0){KIb(I,24,2203320,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;break c}if((c[q>>2]|0)==0){if((c[J>>2]|0)!=0){KIb(I,24,2171544,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;break c}if((c[r>>2]|0)==0){KIb(I,24,2144040,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;break c}WHb(c[K>>2]|0);T=M4a(b,c[K>>2]|0,1)|0;if((T|0)<0){X=T;R=70;break b}T=c[K>>2]|0;c[T+88>>2]=2;c[T+84>>2]=0;c[q>>2]=1;Y=T}else{T=c[K>>2]|0;c[T+88>>2]=1;c[T+84>>2]=1;Y=T}if((c[r>>2]|0)==0){T=lQa(o,0,0,0)|0;if((T|0)>=0){break c}if((c[L>>2]&8|0)==0){break c}else{X=T;R=70;break b}}T=c[N+((c[M>>2]^1)<<2)>>2]|0;do{if(((c[O>>2]|0)+15>>4|0)==(c[x>>2]|0)){if(((c[P>>2]|0)+15>>4|0)!=(c[y>>2]|0)){break}V=(c[T>>2]|0)==0;do{if(V){R=56}else{U=0;while(1){if((U|0)>=4){R=55;break}if((c[T+(U<<2)>>2]|0)==0^(c[Y+(U<<2)>>2]|0)==0){R=54;break}if((c[T+32+(U<<2)>>2]|0)==(c[Y+32+(U<<2)>>2]|0)){U=U+1|0}else{R=54;break}}if((R|0)==54){R=0;KIb(c[z>>2]|0,16,2638240,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;break c}else if((R|0)==55){R=0;if(V){R=56;break}else{break}}}}while(0);if((R|0)==56){R=0;V=M4a(b,T,1)|0;if((V|0)<0){X=V;R=70;break b}}V=lQa(o,c[C>>2]|0,c[A>>2]|0,T)|0;if((V|0)>=0){break c}if((c[L>>2]&8|0)==0){break c}else{X=V;R=70;break b}}}while(0);KIb(c[z>>2]|0,16,2120448,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;break};case 219:{Z=iQa(o)|0;if((Z|0)<0){R=10;break b}break};case 192:{c[G>>2]=0;_=kQa(o)|0;if((_|0)<0){R=32;break b}if((c[H>>2]|0)!=0){R=34;break b}c[G>>2]=1;break};case 217:{R=62;break a;break};case 216:{if((c[q>>2]|0)!=0){$=K;R=64;break a}break};case 196:{aa=hQa(o)|0;if((aa|0)<0){R=12;break b}break};case 254:{T=c[k>>2]|0;V=c[l>>2]|0;if((V|0)<2){break c}U=T;S=he((d[U]|d[U+1|0]<<8)<<16>>16|0)|0;U=S&65535;ba=(U|0)>(V|0);d:do{if((S&65535)>>>0<15>>>0|ba){da=0}else{if((krc(T+2|0,2615312,3)|0)!=0){da=0;break}ea=T+6|0;fa=(d[ea]|d[ea+1|0]<<8)<<16>>16&65535;c[x>>2]=fa;ea=T+8|0;ga=(d[ea]|d[ea+1|0]<<8)<<16>>16&65535;c[y>>2]=ga;ea=((ca(ga,fa)|0)+7|0)>>>3;if(ea>>>0>(U-14|0)>>>0){KIb(c[z>>2]|0,16,2588376,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;da=-22;break}do{if((c[A>>2]|0)!=(ea|0)){c[A>>2]=0;mJb(B);fa=hJb(ea)|0;c[C>>2]=fa;if((fa|0)==0){KIb(c[z>>2]|0,16,2566920,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;da=-12;break d}mJb(E);fa=pJb(ea)|0;c[F>>2]=fa;if((fa|0)==0){KIb(c[z>>2]|0,16,2548616,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;da=-12;break d}else{c[A>>2]=ea;break}}}while(0);nrc(c[C>>2]|0,T+14|0,ea)|0;c[r>>2]=1;if((c[D>>2]|0)!=0){da=0;break}if((ea|0)==0){ha=1}else{fa=0;ga=255;ia=c[F>>2]|0;do{ja=ia+fa|0;a[ja]=a[ja]|a[(c[C>>2]|0)+fa|0];ia=c[F>>2]|0;ga=(d[ia+fa|0]|0)&ga;fa=fa+1|0;}while(fa>>>0<ea>>>0);ha=(ga|0)==255|0}c[D>>2]=ha;da=0}}while(0);T=c[u>>2]|0;S=(c[w>>2]|0)+((ba?V:U)<<3)|0;c[w>>2]=T>>>0>S>>>0?S:T;if((da|0)<0){X=da;R=70;break b}break};default:{}}}while(0);Q=(c[j>>2]|0)+((c[w>>2]|0)+7>>3)|0;c[j>>2]=Q;if(!(Q>>>0<p>>>0)){R=62;break a}}if((R|0)==10){KIb(I,16,2449024,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;X=Z;i=h;return X|0}else if((R|0)==12){KIb(I,16,2359952,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;X=aa;i=h;return X|0}else if((R|0)==32){KIb(I,16,2295904,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;X=_;i=h;return X|0}else if((R|0)==34){KIb(I,16,2244920,(W=i,i=i+1|0,i=i+7&-8,c[W>>2]=0,W)|0);i=W;X=-22;i=h;return X|0}else if((R|0)==70){i=h;return X|0}}else{R=62}}while(0);do{if((R|0)==62){if((c[q>>2]|0)==0){break}$=g+1140|0;R=64}}while(0);do{if((R|0)==64){q=YHb(e,c[$>>2]|0)|0;if((q|0)<0){X=q;i=h;return X|0}c[f>>2]=1;q=g+3016|0;W=c[q>>2]^1;c[q>>2]=W;c[$>>2]=c[g+3008+(W<<2)>>2];W=g+3036|0;if((c[W>>2]|0)!=0){break}if((c[r>>2]|0)==0){c[W>>2]=1;break}else{c[f>>2]=0;break}}}while(0);X=(c[j>>2]|0)-m|0;i=h;return X|0}function aWa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+1140>>2]=0;oQa(a)|0;VHb(b+3008|0);VHb(b+3012|0);c[b+3032>>2]=0;mJb(b+3028|0);mJb(b+3040|0);return 0}function bWa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+1440>>2]=b+416;c[b+1444>>2]=b+928;AIb(b+4|0,0);OPa(b+324|0,8,1,1.0)|0;qHb(b+288|0,c[a+88>>2]&8388608);g[b+284>>2]=3814697265625.0e-18;c[a+420>>2]=3;if(!(+g[1570661]!=0.0)){H0a(7)}c[a+416>>2]=1;b=a+448|0;c[b>>2]=4;c[b+4>>2]=0;return 0}function cWa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0,U=0.0,V=0.0,W=0,X=0,Y=0,Z=0,_=0;l=i;i=i+1504|0;m=l|0;n=l+496|0;o=l+992|0;p=h;q=c[k+24>>2]|0;r=V1(k,70,0)|0;s=c[k+28>>2]|0;k=c[f+60>>2]|0;t=k;u=(s|0)/64|0;if((s|0)<64){KIb(f,16,2449e3,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=l;return w|0}x=(s|0)%64|0;if((x|0)!=0){KIb(f,24,2359928,(v=i,i=i+8|0,c[v>>2]=x,v)|0);i=v}do{if((r|0)!=0&(s|0)>127){v=f+412|0;if(((c[v>>2]|0)%11025|0|0)!=0){break}if((1<<((d[r]|0)>>>2&3)|0)!=(u|0)){break}c[v>>2]=((s|0)/128|0)*11025|0}}while(0);c[h+76>>2]=u<<8;r=M4a(f,p,0)|0;if((r|0)<0){w=r;i=l;return w|0}if((s|0)>63){r=k+264|0;p=k+276|0;f=k+280|0;v=k+268|0;x=k+272|0;y=m|0;m=n|0;z=k+284|0;A=o|0;B=k+260|0;C=k+324|0;D=k+368|0;E=k+1440|0;F=k+304|0;G=k+1444|0;k=q;q=0;H=c[h>>2]|0;while(1){h=(k|0)==0?0:512;c[r>>2]=k;c[p>>2]=h;I=h|8;c[f>>2]=I;J=k+(h>>>3)|0;c[v>>2]=J;c[x>>2]=0;K=k;L=(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24)&63;c[x>>2]=6;K=m;M=+((e[1337672+(L<<1)>>1]|0)>>>0);L=y;N=0;O=6;while(1){if((N|0)>0){P=k+(O>>>3)|0;Q=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((O&7)>>>0)&31;P=O+5|0;R=I>>>0>P>>>0?P:I;c[x>>2]=R;S=M+ +(b[1338312+(Q<<1)>>1]|0);T=R}else{S=M;T=O}U=-0.0- +ad(+(S*.00048828125));V=+g[z>>2]*U;R=a[1338376+N|0]|0;if(R<<24>>24==0){W=K;X=L}else{Q=R&255;R=Q>>>0>1>>>0?Q:1;P=K;Y=L;Z=0;while(1){g[Y>>2]=S;g[P>>2]=V;_=Z+1|0;if((_|0)<(Q|0)){P=P+4|0;Y=Y+4|0;Z=_}else{break}}W=K+(R<<2)|0;X=L+(R<<2)|0}Z=N+1|0;if((Z|0)<23){K=W;M=S;L=X;N=Z;O=T}else{break}}Frb(y,A);O=0;do{N=O<<7;c[r>>2]=k;c[p>>2]=h;c[f>>2]=I;c[v>>2]=J;L=(O*198|0)+116|0;c[x>>2]=(I|0)<(L|0)?I:L;L=0;do{K=c[o+(L<<2)>>2]|0;do{if((K|0)<1){M=+g[n+(L<<2)>>2]*.7071067811865476;Z=H+(L+N<<2)|0;g[Z>>2]=M;Y=c[B>>2]|0;c[t+4+((Y&63)<<2)>>2]=(c[t+4+((Y+9&63)<<2)>>2]|0)+(c[t+4+((Y+40&63)<<2)>>2]|0);Y=c[B>>2]|0;c[B>>2]=Y+1;if((c[t+4+((Y&63)<<2)>>2]&1|0)==0){break}g[Z>>2]=M*-1.0}else{Z=c[x>>2]|0;Y=c[f>>2]|0;P=(c[r>>2]|0)+(Z>>>3)|0;Q=32-K|0;_=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((Z&7)>>>0)<<Q>>>(Q>>>0);Q=Z+K|0;c[x>>2]=Y>>>0>Q>>>0?Q:Y;g[H+(L+N<<2)>>2]=+g[1337800+((1<<K)-1+(_&255)<<2)>>2]*+g[n+(L<<2)>>2]}}while(0);L=L+1|0;}while((L|0)<124);L=H+(N<<2)|0;mrc(H+((N|124)<<2)|0,0,16)|0;ef[c[D>>2]&4095](C,c[E>>2]|0,L);pe[c[F>>2]&1023](L,(c[G>>2]|0)+256|0,c[E>>2]|0,6282136,64);L=c[G>>2]|0;c[G>>2]=c[E>>2];c[E>>2]=L;O=O+1|0;}while((O|0)<2);O=q+1|0;if((O|0)<(u|0)){k=k+64|0;q=O;H=H+1024|0}else{break}}}c[j>>2]=1;w=s;i=l;return w|0}function dWa(a){a=a|0;PPa((c[a+60>>2]|0)+324|0);return 0}function eWa(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a+60|0;e=c[d>>2]|0;if((c[a+416>>2]|0)!=1){KIb(a,16,2448960,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;h=-22;i=b;return h|0}j=c[a+412>>2]|0;do{if(!((j|0)==8e3|(j|0)==16e3|(j|0)==11025|(j|0)==22050|(j|0)==44100)){if(!((c[a+680>>2]|0)>-1)){break}KIb(a,16,2359848,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;h=-22;i=b;return h|0}}while(0);c[a+424>>2]=256;c[a+116>>2]=128;Dmb(a,e+108|0);f=e;c[f>>2]=a;j=OPa(e+44|0,8,0,32768.0)|0;do{if((j|0)<0){k=j}else{qHb(e+8|0,c[a+88>>2]&8388608);H0a(7);l=0;do{g[5453808+(l<<2)>>2]=-0.0- +ad(+(+(-l|0)*.00048828125+-3.0+3.0));l=l+1|0;}while((l|0)<2048);if((c[(c[f>>2]|0)+600>>2]|0)==0){h=0;i=b;return h|0}l=e+3744|0;c[l>>2]=hJb(3290656)|0;m=hJb(822664)|0;c[e+3748>>2]=m;if((c[l>>2]|0)==0|(m|0)==0){k=-12;break}else{h=0}i=b;return h|0}}while(0);e=c[d>>2]|0;PPa(e+44|0);if((c[(c[e>>2]|0)+600>>2]|0)!=0){kJb(c[e+3744>>2]|0);kJb(c[e+3748>>2]|0)}Emb(e+108|0);h=k;i=b;return h|0}function fWa(f,h,j,l){f=f|0;h=h|0;j=j|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0.0,Z=0,_=0,$=0,ba=0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0.0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0;m=i;i=i+1200|0;n=m|0;o=m+496|0;p=m+1008|0;q=m+1104|0;r=c[f+60>>2]|0;t=r;u=r+4|0;if((c[u>>2]|0)!=0){v=0;i=m;return v|0}w=r+2208|0;x=r+3232|0;nrc(w|0,x|0,512)|0;z=r+2720|0;A=z;do{if((j|0)==0){mrc(z|0,0,1024)|0;c[u>>2]=1}else{B=j+76|0;nrc(z|0,c[j>>2]|0,c[B>>2]<<2)|0;C=c[B>>2]|0;do{if((C|0)<256){mrc(A+(C<<2)|0,0,256-C<<2|0)|0;if((c[B>>2]|0)<=127){break}c[u>>2]=1}}while(0);B=Fmb(r+108|0,j)|0;if((B|0)<0){v=B}else{break}i=m;return v|0}}while(0);j=d5a(f,h,64,0)|0;if((j|0)<0){v=j;i=m;return v|0}j=c[h+24>>2]|0;u=c[h+28>>2]|0;z=r+8|0;B=r+1184|0;mf[c[z>>2]&2047](B,w,6282136,128);w=r+32|0;C=r+1696|0;mf[c[w>>2]&2047](C,A,6282136,128);D=r+44|0;E=r+92|0;ef[c[E>>2]&4095](D,r+160|0,B);mf[c[z>>2]&2047](B,A,6282136,128);mf[c[w>>2]&2047](C,x,6282136,128);ef[c[E>>2]&4095](D,r+672|0,B);B=u&268435456;D=0;E=0;while(1){x=a[1338376+D|0]|0;C=x&255;if(x<<24>>24==0){F=0.0;G=E}else{x=C>>>0>1>>>0;w=0;H=0.0;A=E;while(1){I=+g[t+160+(A<<2)>>2];J=+g[t+160+(A+128<<2)>>2];K=H+(I*I+J*J);z=w+1|0;if((z|0)<(C|0)){w=z;H=K;A=A+1|0}else{break}}F=K;G=(x?C:1)+E|0}H=F/+(C<<7|0);if(H<1.0){L=1.0}else{L=H}g[q+(D<<2)>>2]=+aa(L)*1024.0/.6931471805599453;A=D+1|0;if((A|0)<23){D=A;E=G}else{break}}G=(B|0)!=0?0:j;B=q|0;E=p|0;a:do{if((c[(c[r>>2]|0)+600>>2]|0)==0){L=+g[B>>2];D=((Lc(+L)|0)>>8)-20|0;if((D|0)<0){M=0}else{M=(D|0)>95?95:D}D=d[599168+M|0]|0;F=+R(+(L- +(e[1337672+(D<<1)>>1]|0)));A=D+1|0;w=F>+R(+(L- +(e[1337672+(A<<1)>>1]|0)));z=w?A:D;c[E>>2]=z;D=e[1337672+(z<<1)>>1]|0;z=1;while(1){L=+g[q+(z<<2)>>2]- +(D|0);A=((Lc(+L)|0)>>8)+37|0;if((A|0)<0){N=0}else{N=(A|0)>77?77:A}A=d[599264+N|0]|0;F=+R(+(L- +(b[1338312+(A<<1)>>1]|0)));w=A+1|0;O=F>+R(+(L- +(b[1338312+(w<<1)>>1]|0)));P=O?w:A;c[p+(z<<2)>>2]=P;A=z+1|0;if((A|0)<23){D=(b[1338312+(P<<1)>>1]|0)+D|0;z=A}else{Q=G;S=32;T=0;U=0;V=0;W=0;break}}}else{z=c[r+3744>>2]|0;D=c[r+3748>>2]|0;C=0;do{g[z+(C<<2)>>2]=s;C=C+1|0;}while((C|0)<822664);L=+g[B>>2];C=0;while(1){x=b[1337672+(C<<1)>>1]|0;F=L- +((x&65535)>>>0);A=x&65535;g[z+(A<<2)>>2]=F*F;a[D+A|0]=C;A=C+1|0;if((A|0)<64){C=A}else{X=1;Y=L;break}}while(1){L=+g[q+(X<<2)>>2];C=X-1|0;A=q+(C<<2)|0;x=1e3;do{F=+(x|0);K=L-F;if(K<0.0){Z=0}else{Z=~~K}K=Y+F;P=K<35768.0;if(P){_=~~K}else{_=35768}H=Y-F;if(H<0.0){$=0}else{$=~~H}if(+($|0)<(P?K:35768.0)){P=0;w=$;K=Y;while(1){O=z+(C*143072|0)+(w<<2)|0;if(((g[k>>2]=+g[O>>2],c[k>>2]|0)&2147483647|0)==2139095040){ba=P;ca=K}else{da=P;ea=0;while(1){fa=(b[1338312+(ea<<1)>>1]|0)+w|0;if((fa|0)>(_|0)){ga=da;break}do{if((fa|0)<(Z|0)){ha=da}else{H=+(fa|0)-L;J=H*H+ +g[O>>2];ia=z+(X*143072|0)+(fa<<2)|0;if(!(+g[ia>>2]>J)){ha=da;break}g[ia>>2]=J;a[D+(X*35768|0)+fa|0]=ea;ha=1}}while(0);fa=ea+1|0;if((fa|0)<32){da=ha;ea=fa}else{ga=ha;break}}ba=ga;ca=+g[A>>2]}ea=w+1|0;J=F+ca;if(+(ea|0)<(J<35768.0?J:35768.0)){P=ba;w=ea;K=ca}else{ja=ba;break}}}else{ja=0}x=x<<2;}while((ja|0)==0&(x|0)<35768);x=X+1|0;if((x|0)<23){X=x;Y=L}else{ka=s;la=-1;ma=0;break}}while(1){K=+g[z+3147584+(ma<<2)>>2];x=ka>K;A=x?ma:la;C=ma+1|0;if((C|0)<35768){ka=x?K:ka;la=A;ma=C}else{na=A;oa=22;break}}while(1){z=d[D+(oa*35768|0)+na|0]|0;c[p+(oa<<2)>>2]=z;if((oa|0)==0){Q=G;S=32;T=0;U=0;V=0;W=0;break a}if((oa|0)>0){na=na-(b[1338312+(z<<1)>>1]|0)|0;oa=oa-1|0}else{Q=G;S=32;T=0;U=0;V=0;W=0;break}}}}while(0);while(1){if((V|0)==0){oa=c[E>>2]|0;na=e[1337672+(oa<<1)>>1]|0;ma=oa<<32-S|T;if((S|0)>6){pa=S;qa=ma;ra=Q}else{la=Q;y=ma;a[la]=y;y=y>>8;a[la+1|0]=y;y=y>>8;a[la+2|0]=y;y=y>>8;a[la+3|0]=y;pa=S+32|0;qa=oa>>>(S>>>0);ra=Q+4|0}sa=na;ta=qa;ua=pa-6|0;va=ra}else{na=c[p+(V<<2)>>2]|0;oa=(b[1338312+(na<<1)>>1]|0)+U|0;la=na<<32-S|T;if((S|0)>5){wa=S;xa=la;ya=Q}else{ma=Q;y=la;a[ma]=y;y=y>>8;a[ma+1|0]=y;y=y>>8;a[ma+2|0]=y;y=y>>8;a[ma+3|0]=y;wa=S+32|0;xa=na>>>(S>>>0);ya=Q+4|0}sa=oa;ta=xa;ua=wa-5|0;va=ya}ka=+g[5453808+((sa&2047)<<2)>>2]/+(1<<(sa>>11)+3|0);oa=a[1338376+V|0]|0;if(oa<<24>>24==0){za=W}else{Y=+(sa|0);na=oa&255;oa=na>>>0>1>>>0;ma=0;la=W;while(1){X=t+160+(la<<2)|0;g[X>>2]=ka*+g[X>>2];X=t+160+(la+128<<2)|0;g[X>>2]=ka*+g[X>>2];g[n+(la<<2)>>2]=Y;X=ma+1|0;if((X|0)<(na|0)){ma=X;la=la+1|0}else{break}}za=(oa?na:1)+W|0}la=V+1|0;if((la|0)<23){Q=va;S=ua;T=ta;U=sa;V=la;W=za}else{break}}Frb(n|0,o|0);n=G;G=va;va=ua;ua=ta;ta=0;while(1){za=ta<<7;W=G;V=va;sa=ua;U=0;while(1){T=c[o+(U<<2)>>2]|0;if((T|0)>0){S=1<<T;Y=+g[t+160+(U+za<<2)>>2];Q=~~(Y*+g[687896+(T<<2)>>2]+ +g[687928+(T<<2)>>2]);ya=d[687888+T|0]|0;wa=(d[T+687889|0]|0)-1|0;if((Q|0)<(ya|0)){Aa=ya}else{Aa=(Q|0)>(wa|0)?wa:Q}Q=d[687960+Aa|0]|0;ka=+R(+(Y- +g[1337800+(S-1+Q<<2)>>2]));wa=(ka>+R(+(Y- +g[1337800+(Q+S<<2)>>2])))+Q|0;Q=wa<<32-V|sa;if((V|0)>(T|0)){Ba=V;Ca=Q;Da=W}else{S=W;y=Q;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;Ba=V+32|0;Ca=(V|0)==32?0:wa>>>(V>>>0);Da=W+4|0}Ea=Ca;Fa=Ba-T|0;Ga=Da}else{Ea=sa;Fa=V;Ga=W}T=U+1|0;if((T|0)<124){W=Ga;V=Fa;sa=Ea;U=T}else{break}}if((ta|0)==0){U=Fa+282-(Ga-n<<3)|0;if((Fa|0)>(U|0)){Ha=Fa;Ia=Ea;Ja=Ga}else{sa=Ga;y=Ea;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;Ha=Fa+32|0;Ia=0;Ja=Ga+4|0}Ka=Ia;La=Ha-U|0;Ma=Ja}else{Ka=Ea;La=Fa;Ma=Ga}U=ta+1|0;if((U|0)<2){G=Ma;va=La;ua=Ka;ta=U}else{break}}if((La|0)<32){ta=31-La|0;ua=Ka&255;va=Ka;Ka=La;La=Ma;while(1){a[La]=ua;G=va>>>8;Ga=Ka+8|0;if((Ga|0)<32){ua=G&255;va=G;Ka=Ga;La=La+1|0}else{break}}Na=Ma+((ta>>>3)+1)|0}else{Na=Ma}mrc(Na|0,0,j+u-Na|0)|0;Gmb(r+108|0,c[f+424>>2]|0,h+8|0,h+48|0);c[l>>2]=1;v=0;i=m;return v|0}function gWa(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;PPa(b+44|0);if((c[(c[b>>2]|0)+600>>2]|0)==0){d=b+108|0;e=d;Emb(e);return 0}kJb(c[b+3744>>2]|0);kJb(c[b+3748>>2]|0);d=b+108|0;e=d;Emb(e);return 0}function hWa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=c[a+60>>2]|0;f=e;g=UHb()|0;c[e>>2]=g;if((g|0)==0){h=-12;i=b;return h|0}c[a+140>>2]=0;c[e+24>>2]=0;c[e+8>>2]=-1;c[e+12>>2]=0;c[e+16>>2]=0;c[e+4>>2]=(c[a+52>>2]|0)==1196444242;g=c[a+100>>2]|0;do{if((g|0)!=0){j=c[a+96>>2]|0;if((g|0)<512){KIb(a,16,2638208,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;break}else{l=j;m=0}while(1){k=l;c[f+28+(m<<2)>>2]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=m+1|0;if((k|0)<64){l=l+4|0;m=k}else{break}}k=j+256|0;n=0;while(1){o=k;c[f+284+(n<<2)>>2]=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24;o=n+1|0;if((o|0)<64){k=k+4|0;n=o}else{break}}}}while(0);l8(e+1264|0,a);e=kWa(a,c[a+120>>2]|0,c[a+124>>2]|0,-1)|0;h=(e|0)<0?e:0;i=b;return h|0}function iWa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;i=i+80|0;j=h|0;k=h+64|0;l=h+72|0;m=g+24|0;n=c[m>>2]|0;o=g+28|0;g=c[o>>2]|0;p=c[b+60>>2]|0;q=p;r=e;e=(c[b+428>>2]|0)==0|0;if((g|0)<12){KIb(b,16,2448936,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}u=a[n]|0;do{if((u<<24>>24|0)==86){v=a[n+1|0]|0;w=v&255;if((w|0)==76){x=0}else if((w|0)==50|(w|0)==49){x=(a[n+2|0]|0)==0|0}else{x=1}y=p+20|0;z=p+24|0;A=p+4|0;a:do{if((v-50&255)>>>0<2>>>0){B=n;C=g;D=0;while(1){c[k>>2]=(c[y>>2]|0)-16;c[l>>2]=C-12;if((SIb(c[z>>2]|0,k,B+12|0,l)|0)!=0){break}E=c[z>>2]|0;F=(c[y>>2]|0)-16-(c[k>>2]|0)|0;mrc(E+F|0,0,16)|0;if((c[A>>2]|0)==0){G=E;H=F;I=D;break a}if((F|0)<12){J=28;break a}if((a[E]|0)!=86){K=E+4|0;if(!((d[K]|d[K+1|0]<<8)<<16>>16<<16>>16==12)){J=31;break a}}K=E+6|0;L=E+8|0;M=kWa(b,(d[K]|d[K+1|0]<<8)<<16>>16&65535,(d[L]|d[L+1|0]<<8)<<16>>16&65535,d[E+10|0]|0)|0;if((M|0)<0){t=M;J=51;break}if((M|0)==0){N=D;O=F;P=E;J=35;break a}B=c[m>>2]|0;C=c[o>>2]|0;D=1}if((J|0)==51){i=h;return t|0}KIb(b,16,2295872,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else{D=n;C=g;B=0;while(1){E=D+12|0;F=C-12|0;if((c[A>>2]|0)==0){G=E;H=F;I=B;break a}if((F|0)<12){J=28;break a}if((a[E]|0)!=86){M=D+16|0;if(!((d[M]|d[M+1|0]<<8)<<16>>16<<16>>16==12)){J=31;break a}}M=D+18|0;L=D+20|0;K=kWa(b,(d[M]|d[M+1|0]<<8)<<16>>16&65535,(d[L]|d[L+1|0]<<8)<<16>>16&65535,d[D+22|0]|0)|0;if((K|0)<0){t=K;break}if((K|0)==0){N=B;O=F;P=E;J=35;break a}D=c[m>>2]|0;C=c[o>>2]|0;B=1}i=h;return t|0}}while(0);if((J|0)==28){KIb(b,16,2244888,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else if((J|0)==31){KIb(b,16,2203264,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else if((J|0)==35){G=P+12|0;H=O-12|0;I=N}A=p;if((x|I|0)==0){Q=e}else{WHb(c[A>>2]|0);Q=1}y=N4a(b,c[A>>2]|0)|0;if((y|0)<0){t=y;i=h;return t|0}if((Q|0)!=0){y=c[A>>2]|0;z=b+124|0;mrc(c[y>>2]|0,0,ca(c[y+32>>2]|0,c[z>>2]|0)|0)|0;y=c[A>>2]|0;mrc(c[y+4>>2]|0,-128|0,(ca(c[y+36>>2]|0,c[z>>2]|0)|0)/2|0|0)|0;y=c[A>>2]|0;mrc(c[y+8>>2]|0,-128|0,(ca(c[y+40>>2]|0,c[z>>2]|0)|0)/2|0|0)|0}z=c[A>>2]|0;c[z+88>>2]=(x|0)!=0?1:2;c[z+84>>2]=x;b:do{switch(w|0){case 50:case 49:{y=LZa(p+544|0,z,G,H)|0;if((y|0)<0){t=y}else{break b}i=h;return t|0};case 78:{y=p+12|0;v=p+16|0;mrc(c[z>>2]|0,0,ca(c[v>>2]|0,c[y>>2]|0)|0)|0;mrc(c[(c[A>>2]|0)+4>>2]|0,-128|0,(ca(c[v>>2]|0,c[y>>2]|0)|0)/4|0|0)|0;mrc(c[(c[A>>2]|0)+8>>2]|0,-128|0,(ca(c[v>>2]|0,c[y>>2]|0)|0)/4|0|0)|0;break};case 51:case 48:{y=c[p+16>>2]|0;v=p+12|0;B=c[v>>2]|0;if((H|0)<((ca(y*3|0,B)|0)/2|0|0)){KIb(b,16,2171512,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;C=c[v>>2]|0;R=(((H|0)/(C|0)|0|0)/3|0)<<1;S=C}else{R=y;S=B}if((R|0)<=0){break b}B=c[A>>2]|0;a2(j,G,0,S,R)|0;f2(B,j,0,S,R);break};case 76:{break};default:{KIb(b,16,2144016,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}}}while(0);z=YHb(r,c[A>>2]|0)|0;if((z|0)<0){t=z;i=h;return t|0}c[f>>2]=1;t=g;i=h;return t|0}else if((u<<24>>24|0)==68){if((a[n+1|0]|0)!=82){break}if((g-12|0)<512){KIb(b,16,2638208,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}z=n+12|0;w=0;while(1){B=z;c[q+28+(w<<2)>>2]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24;B=w+1|0;if((B|0)<64){z=z+4|0;w=B}else{break}}w=n+268|0;z=0;while(1){A=w;c[q+284+(z<<2)>>2]=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24;A=z+1|0;if((A|0)<64){w=w+4|0;z=A}else{break}}NZa(p+544|0,p+1264|0,c[p+12>>2]|0,c[p+16>>2]|0,p+28|0,p+284|0);t=g;i=h;return t|0}}while(0);KIb(b,16,2359824,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}function jWa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+24|0);VHb(b);return 0}function kWa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=c[a+60>>2]|0;j=b+1&-2;b=e+1&-2;if((f|0)>-1){e=h;k=(f|0)>1?f:1;l=0;do{c[e+28+(l<<2)>>2]=((d[1485944+l|0]|0)<<7|0)/(k|0)|0;c[e+284+(l<<2)>>2]=((d[1486008+l|0]|0)<<7|0)/(k|0)|0;l=l+1|0;}while((l|0)<64)}l=h+12|0;do{if((j|0)==(c[l>>2]|0)){if((b|0)!=(c[h+16>>2]|0)){break}if((c[h+8>>2]|0)==(f|0)){m=0;i=g;return m|0}NZa(h+544|0,h+1264|0,j,b,h+28|0,h+284|0);m=0;i=g;return m|0}}while(0);f=((ca(j*3|0,b)|0)/2|0)+28|0;if((f|0)>268435455){m=-1;i=g;return m|0}k=a;e=tIb(b,j,0,k)|0;if((e|0)<0){m=e;i=g;return m|0}c[l>>2]=j;c[a+120>>2]=j;j=h+16|0;c[j>>2]=b;c[a+124>>2]=b;b=h+24|0;xJb(b,h+20|0,f);if((c[b>>2]|0)==0){KIb(k,16,2120408,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;m=-12;i=g;return m|0}else{NZa(h+544|0,h+1264|0,c[l>>2]|0,c[j>>2]|0,h+28|0,h+284|0);WHb(c[h>>2]|0);m=1;i=g;return m|0}return 0}function lWa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;mrc(e|0,0,960)|0;c[a>>2]=2004256;f=(b|0)!=0;do{if(f){g=c[b+8>>2]|0;c[a+8>>2]=g;c[a+48>>2]=c[b+12>>2];if((g|0)==1){h=8;break}else if((g|0)!=0){j=g;k=5;break}h=16}else{c[a+8>>2]=-1;j=-1;k=5}}while(0);if((k|0)==5){h=(j|0)==3?32:0}TJb(e,h,h);c[a+104>>2]=0;c[a+108>>2]=1;c[a+484>>2]=74;c[a+152>>2]=158;c[a+824>>2]=38;c[a+828>>2]=68;c[a+224>>2]=0;c[a+228>>2]=1;c[a+140>>2]=-1;c[a+420>>2]=-1;h=a+616|0;c[h>>2]=-1;c[h+4>>2]=-1;h=a+704|0;c[h>>2]=0;c[h+4>>2]=-2147483648;if(!f){l=0;i=d;return l|0}f=c[b+52>>2]|0;do{if((f|0)!=0){h=a+60|0;j=c[h>>2]|0;do{if((j|0)==0){g=pJb(f)|0;c[h>>2]=g;if((g|0)==0){l=-12}else{m=g;break}i=d;return l|0}else{m=j}}while(0);j=c[b+44>>2]|0;if((j|0)==0){break}c[m>>2]=j;SJb(c[h>>2]|0)}}while(0);m=c[b+68>>2]|0;if((m|0)==0){l=0;i=d;return l|0}else{n=m}while(1){m=c[n>>2]|0;if((m|0)==0){l=0;k=16;break}if((EJb(e,m,c[n+4>>2]|0,0)|0)>-1){n=n+8|0}else{k=15;break}}if((k|0)==15){KIb(0,0,2493760,(n=i,i=i+24|0,c[n>>2]=2599032,c[n+8>>2]=2448904,c[n+16>>2]=136,n)|0);i=n;Hd();return 0}else if((k|0)==16){i=d;return l|0}return 0}function mWa(a){a=a|0;var b=0,c=0,d=0;b=hJb(960)|0;c=b;do{if((b|0)==0){d=0}else{if((lWa(c,a)|0)>=0){d=c;break}kJb(b);d=0}}while(0);return d|0}function nWa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;f=b;if((a5a(b)|0)!=0){KIb(f,16,2359760,(g=i,i=i+16|0,c[g>>2]=d,c[g+8>>2]=b,g)|0);i=g;h=-22;i=e;return h|0}WJb(f);g=b+60|0;kJb(c[g>>2]|0);nrc(f|0,d|0,960)|0;c[g>>2]=0;c[b+12>>2]=0;c[b+220>>2]=0;c[b+712>>2]=0;c[b+64>>2]=0;g=b+536|0;c[g>>2]=0;f=b+96|0;c[f>>2]=0;j=b+300|0;c[j>>2]=0;k=b+304|0;c[k>>2]=0;l=b+532|0;c[l>>2]=0;m=c[d+536>>2]|0;do{if((m|0)!=0){n=rJb(m)|0;c[g>>2]=n;if((n|0)==0){h=-12}else{break}i=e;return h|0}}while(0);m=d+96|0;do{if((c[m>>2]|0)==0){o=9}else{n=d+100|0;p=c[n>>2]|0;if((p|0)<=0){o=9;break}q=hJb(p+16|0)|0;c[f>>2]=q;if((q|0)==0){break}p=c[n>>2]|0;nrc(q|0,c[m>>2]|0,p)|0;mrc(q+p|0,0,16)|0;o=9}}while(0);a:do{if((o|0)==9){m=d+300|0;if((c[m>>2]|0)!=0){p=hJb(128)|0;c[j>>2]=p;if((p|0)==0){break}nrc(p|0,c[m>>2]|0,128)|0}m=d+304|0;if((c[m>>2]|0)!=0){p=hJb(128)|0;c[k>>2]=p;if((p|0)==0){break}nrc(p|0,c[m>>2]|0,128)|0}m=d+532|0;do{if((c[m>>2]|0)!=0){p=d+528|0;q=c[p>>2]<<4;if((q|0)==0){break}n=hJb(q)|0;c[l>>2]=n;if((n|0)==0){break a}nrc(n|0,c[m>>2]|0,c[p>>2]<<4)|0}}while(0);m=d+860|0;if((c[m>>2]|0)==0){h=0;i=e;return h|0}p=d+864|0;n=c[p>>2]|0;if((n|0)<=0){h=0;i=e;return h|0}q=hJb(n+1|0)|0;c[b+860>>2]=q;if((q|0)==0){break}n=c[p>>2]|0;nrc(q|0,c[m>>2]|0,n)|0;a[q+n|0]=0;h=0;i=e;return h|0}}while(0);mJb(l);mJb(j);mJb(k);mJb(f);mJb(g);h=-12;i=e;return h|0}function oWa(){return 2004256}function pWa(){return 2004008}function qWa(a){a=a|0;var b=0,d=0,e=0;do{if((a|0)!=0){b=c[a+12>>2]|0;if((b|0)==0){break}d=c[b>>2]|0;if((d|0)==0){break}else{e=d}return e|0}}while(0);e=2223872;return e|0}function rWa(a,b){a=a|0;b=b|0;var d=0,e=0;do{if((b|0)==0){d=c[a+12>>2]|0;if((d|0)==0){break}if((c[d+44>>2]|0)==0){break}d=c[a+60>>2]|0;if((d|0)==0){break}else{e=d}return e|0}}while(0);e=0;return e|0}function sWa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;a:do{if((a|0)==0){b=0}else{d=0;while(1){e=C4a(d)|0;if((e|0)==0){b=0;break a}if((c[e+44>>2]|0)==(a|0)){b=e;break}else{d=e}}}}while(0);while(1){a=C4a(b)|0;if((a|0)==0){f=0;g=6;break}d=c[a+44>>2]|0;if((d|0)==0){b=a}else{f=d;g=6;break}}if((g|0)==6){return f|0}return 0}function tWa(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;do{if((b|0)!=0){if((c[b+88>>2]|0)==0){break}else{d=6}return d|0}}while(0);d=5;return d|0}function uWa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a+60|0;e=c[d>>2]|0;f=a+124|0;do{if((c[f>>2]&3|0)==0){g=a+120|0;if((c[g>>2]&3|0)!=0){break}c[a+140>>2]=11;h=UHb()|0;c[e>>2]=h;if((h|0)==0){j=-12;i=b;return j|0}h=e+36|0;c[h>>2]=ca((c[f>>2]|0)+255&-256,c[g>>2]|0)|0;c[e+40>>2]=ca(c[g>>2]|0,c[f>>2]|0)|0;g=e+20|0;k=0;while(1){if((k|0)>=4){j=0;l=9;break}m=pJb(c[h>>2]|0)|0;c[g+(k<<2)>>2]=m;if((m|0)==0){break}else{k=k+1|0}}if((l|0)==9){i=b;return j|0}k=c[d>>2]|0;VHb(k);mJb(k+20|0);mJb(k+24|0);mJb(k+28|0);mJb(k+32|0);j=-12;i=b;return j|0}}while(0);KIb(a,16,2120224,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-1094995529;i=b;return j|0}function vWa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;h=i;j=b+60|0;k=c[j>>2]|0;l=k;m=N4a(b,c[l>>2]|0)|0;if((m|0)<0){n=m;i=h;return n|0}m=g+24|0;o=c[m>>2]|0;p=g+28|0;g=c[p>>2]|0;if(!((g|0)>-1)){KIb(0,0,2203016,(q=i,i=i+24|0,c[q>>2]=2171320,c[q+8>>2]=2143848,c[q+16>>2]=135,q)|0);i=q;Hd();return 0}r=k+4|0;c[r>>2]=o;c[k+12>>2]=o;s=k+8|0;c[s>>2]=o+g;do{if((g|0)<1){t=0;u=0;v=7}else{c[r>>2]=o+1;w=a[o]|0;x=w&255;if((x&32|0)==0){t=x;u=w;v=7;break}z=k+36|0;mrc(c[k+20>>2]|0,0,c[z>>2]|0)|0;mrc(c[k+24>>2]|0,0,c[z>>2]|0)|0;mrc(c[k+28>>2]|0,0,c[z>>2]|0)|0;mrc(c[k+32>>2]|0,0,c[z>>2]|0)|0;mrc(c[(c[l>>2]|0)+4>>2]|0,0,1024)|0;c[k+16>>2]=0;z=c[l>>2]|0;c[z+84>>2]=1;c[z+88>>2]=1;A=x;B=w;C=z}}while(0);if((v|0)==7){o=c[l>>2]|0;c[o+84>>2]=0;c[o+88>>2]=2;A=t;B=u;C=o}if((A&64|0)!=0){o=c[C+4>>2]|0;u=c[r>>2]|0;t=c[s>>2]|0;if((t-u|0)<1){D=0;E=u}else{g=u+1|0;c[r>>2]=g;D=d[u]|0;E=g}if((t-E|0)<1){F=1;G=E}else{g=E+1|0;c[r>>2]=g;F=(d[E]|0)+1|0;G=g}if((F+D|0)>256){n=-1094995529;i=h;return n|0}if((t-G|0)>>>0<(F*3|0)>>>0){n=-1094995529;i=h;return n|0}if((F|0)>0){t=o+(D<<2)|0;D=0;o=G;while(1){G=o+1|0;c[r>>2]=G;g=d[o]|0;E=o+2|0;c[r>>2]=E;u=d[G]|0;G=o+3|0;c[r>>2]=G;z=d[E]|0;c[t>>2]=(g<<2|g>>>4)<<16|z>>>4|z<<2|(u<<2|u>>>4)<<8|-16777216;u=D+1|0;if((u|0)<(F|0)){t=t+4|0;D=u;o=G}else{break}}}c[C+304>>2]=1}C=A&15;a:do{if((C|0)==2){A=c[r>>2]|0;do{if(((c[s>>2]|0)-A|0)<1){H=0}else{c[r>>2]=A+1;o=a[A]|0;if((o&255)>>>0>3>>>0){n=-1094995529}else{H=o&255;break}i=h;return n|0}}while(0);A=c[k+16>>2]|0;if((H|0)==(A|0)){break}o=k+20|0;nrc(c[o+(A<<2)>>2]|0,c[o+(H<<2)>>2]|0,c[k+36>>2]|0)|0}else if((C|0)==1){o=c[k+20+(c[k+16>>2]<<2)>>2]|0;A=c[r>>2]|0;D=c[s>>2]|0;t=D-A|0;F=A+(t>>>0>2>>>0?2:t)|0;c[r>>2]=F;t=c[k+40>>2]|0;if((D-F|0)>>>0<t>>>0){n=-1094995529;i=h;return n|0}else{nrc(o|0,F|0,t)|0;c[r>>2]=(c[r>>2]|0)+t;break}}else if((C|0)==0){t=c[m>>2]|0;F=c[j>>2]|0;o=F+8|0;D=c[o>>2]|0;A=F+4|0;G=c[A>>2]|0;u=D;b:do{if((u-G|0)>=1){z=G+1|0;c[A>>2]=z;g=a[G]|0;E=g&255;if(g<<24>>24==0){break}do{if((B&16)==0){I=z}else{g=z;w=g-(c[F+12>>2]|0)&3;if((w|0)==0){I=z;break}x=4-w|0;w=u-g|0;g=G+((w>>>0>x>>>0?x:w)+1)|0;c[A>>2]=g;I=g}}while(0);z=F+20|0;g=b+120|0;w=F+36|0;x=E;J=D;K=I;c:while(1){L=J;if((L-K|0)<1){M=0;N=K}else{O=K+1|0;c[A>>2]=O;M=d[K]|0;N=O}if((L-N|0)<1){P=0;Q=N}else{O=N+1|0;c[A>>2]=O;P=d[N]|0;Q=O}O=c[z+(M>>>6<<2)>>2]|0;R=c[g>>2]|0;S=P<<1&254;T=(ca(R<<1,P>>>7|M<<1&126)|0)+S|0;U=c[w>>2]|0;V=O+U|0;if((L-Q|0)<2){W=0}else{c[A>>2]=Q+2;L=Q;W=(d[L]|d[L+1|0]<<8)<<16>>16&65535}L=W+S|0;if((T+((R*3|0)+4)|0)>(U|0)){n=-1094995529;v=135;break}U=O+T|0;T=S|1;while(1){S=c[j>>2]|0;O=S+8|0;R=S+4|0;S=c[R>>2]|0;X=(c[O>>2]|0)-S|0;Y=X>>>0>4>>>0?4:X;nrc(U|0,S|0,Y)|0;S=(c[R>>2]|0)+Y|0;c[R>>2]=S;Y=c[g>>2]|0;X=(c[O>>2]|0)-S|0;Z=X>>>0>4>>>0?4:X;nrc(U+Y|0,S|0,Z)|0;S=(c[R>>2]|0)+Z|0;c[R>>2]=S;Z=(c[g>>2]|0)+Y|0;Y=(c[O>>2]|0)-S|0;X=Y>>>0>4>>>0?4:Y;nrc(U+Z|0,S|0,X)|0;S=(c[R>>2]|0)+X|0;c[R>>2]=S;X=(c[O>>2]|0)-S|0;O=X>>>0>4>>>0?4:X;nrc(U+((c[g>>2]|0)+Z)|0,S|0,O)|0;c[R>>2]=(c[R>>2]|0)+O;if((T&63|0)==0){_=U+((c[g>>2]|0)*3|0)|0}else{_=U}if(!(T>>>0<L>>>0)){break}if((_+(((c[g>>2]|0)*3|0)+8)|0)>>>0>V>>>0){n=-1094995529;v=135;break c}else{U=_+4|0;T=T+1|0}}T=x-1|0;if((T|0)==0){break b}x=T;J=c[o>>2]|0;K=c[A>>2]|0}if((v|0)==135){i=h;return n|0}}}while(0);D=F+16|0;G=F+20|0;u=c[G+(c[D>>2]<<2)>>2]|0;K=F+36|0;J=u+(c[K>>2]|0)|0;x=b+120|0;g=F+40|0;w=1;z=u;while(1){u=c[A>>2]|0;E=c[o>>2]|0;if((E-u|0)<1){$=0;aa=u}else{T=u+1|0;c[A>>2]=T;$=d[u]|0;aa=T}if((E-aa|0)<1){ba=0}else{c[A>>2]=aa+1;ba=d[aa]|0}E=c[G+($>>>6<<2)>>2]|0;T=c[x>>2]|0;u=T<<1;U=(ca(u,ba>>>7|$<<1&126)|0)+(ba<<1&254)|0;da=E+U|0;V=c[K>>2]|0;ea=E+V|0;L=(T*3|0)+4|0;if((U+L|0)>(V|0)){n=-1094995529;v=135;break}if((z+L|0)>>>0>J>>>0){n=-1094995529;v=135;break}L=da;V=z;y=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=E+(U+T)|0;L=z+T|0;y=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;a[L]=y;y=y>>8;a[L+1|0]=y;y=y>>8;a[L+2|0]=y;y=y>>8;a[L+3|0]=y;L=E+(U+u)|0;V=z+u|0;y=d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=u+T|0;T=E+(U+V)|0;U=z+V|0;y=d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;if((w&63|0)==0){fa=z+((c[x>>2]|0)*3|0)|0}else{fa=z}if((w|0)>=((c[g>>2]|0)/16|0|0)){v=51;break}w=w+1|0;z=fa+4|0}if((v|0)==51){z=c[A>>2]|0;w=c[o>>2]|0;if((w-z|0)<2){ga=0;ha=z}else{g=z+2|0;c[A>>2]=g;J=z;ga=(d[J]|d[J+1|0]<<8)<<16>>16&65535;ha=g}g=w-ha|0;J=g>>>0>2>>>0?2:g;g=ha+J|0;c[A>>2]=g;z=g;if((w-z|0)>>>0<ga>>>0){n=-1094995529;i=h;return n|0}w=z-(c[F+12>>2]|0)|0;c[A>>2]=ha+(J+ga);J=b+124|0;z=c[J>>2]|0;if((z|0)<=0){break}g=c[G+(c[D>>2]<<2)>>2]|0;U=0;T=da;V=ea;E=0;u=0;L=c[x>>2]|0;O=z;d:while(1){if((L|0)>0){z=g;R=U;S=T;Z=V;X=0;Y=u;while(1){if(Y>>>0>ga>>>0){n=-1094995529;v=135;break d}ia=d[t+(w+Y)|0]|0;if((X&4|0)==0){ja=ia>>>4;ka=Y}else{ja=ia&15;ka=Y+1|0}ia=0;la=Z;ma=S;na=R;e:while(1){oa=ia;pa=la;qa=ma;f:while(1){ra=oa;g:while(1){sa=a[1900904+(ja<<3)+ra|0]|0;if(sa<<24>>24==0){break e}ta=c[x>>2]|0;ua=ta<<1;va=ra+1|0;switch(sa&255|0){case 7:{wa=pa;xa=qa;ya=ua;break g;break};case 2:{v=66;break f;break};case 3:{za=ua;v=67;break f;break};case 5:{v=87;break g;break};case 4:{v=69;break f;break};case 6:{Aa=ua;v=88;break g;break};default:{ra=va}}}if((v|0)==87){v=0;Aa=0;v=88}if((v|0)==88){v=0;ra=c[A>>2]|0;sa=c[o>>2]|0;if((sa-ra|0)<1){Ba=0;Ca=ra}else{Da=ra+1|0;c[A>>2]=Da;Ba=d[ra]|0;Ca=Da}if((sa-Ca|0)<1){Ea=0}else{c[A>>2]=Ca+1;Ea=d[Ca]|0}sa=c[G+(Ba>>>6<<2)>>2]|0;Da=sa+((ca(Ea>>>7|Ba<<1&126,ua)|0)+(Ea<<1&254))|0;wa=sa+(c[K>>2]|0)|0;xa=Da;ya=Aa}if((xa+(ta+4+ya)|0)>>>0>wa>>>0){n=-1094995529;v=135;break d}Da=c[A>>2]|0;if(((c[o>>2]|0)-Da|0)<1){oa=va;pa=wa;qa=xa;continue}c[A>>2]=Da+1;sa=d[Da]|0;Da=sa>>>4;if((Da&8|0)!=0){a[z+ya|0]=a[xa+ya|0]|0}if((sa&8|0)!=0){ra=(c[x>>2]|0)+ya|0;a[z+ra|0]=a[xa+ra|0]|0}if((Da&4|0)!=0){ra=ya+1|0;a[z+ra|0]=a[xa+ra|0]|0}if((sa&4|0)!=0){ra=ya+1+(c[x>>2]|0)|0;a[z+ra|0]=a[xa+ra|0]|0}if((Da&2|0)!=0){ra=ya+2|0;a[z+ra|0]=a[xa+ra|0]|0}if((sa&2|0)!=0){ra=ya+2+(c[x>>2]|0)|0;a[z+ra|0]=a[xa+ra|0]|0}if((Da&1|0)!=0){Da=ya+3|0;a[z+Da|0]=a[xa+Da|0]|0}if((sa&1|0)==0){oa=va;pa=wa;qa=xa;continue}sa=ya+3+(c[x>>2]|0)|0;a[z+sa|0]=a[xa+sa|0]|0;oa=va;pa=wa;qa=xa}if((v|0)==66){v=0;za=0;v=67}else if((v|0)==69){v=0;Fa=na;Ga=ua;Ha=c[o>>2]|0;Ia=c[A>>2]|0}do{if((v|0)==67){v=0;oa=c[o>>2]|0;sa=c[A>>2]|0;if((oa-sa|0)<1){Fa=0;Ga=za;Ha=oa;Ia=sa;break}Da=sa+1|0;c[A>>2]=Da;Fa=a[sa]|0;Ga=za;Ha=oa;Ia=Da}}while(0);if((Ha-Ia|0)<1){ia=va;la=pa;ma=qa;na=Fa;continue}c[A>>2]=Ia+1;Da=d[Ia]|0;oa=Da>>>4;if((oa&8|0)!=0){a[z+Ga|0]=Fa}if((Da&8|0)!=0){a[z+((c[x>>2]|0)+Ga)|0]=Fa}if((oa&4|0)!=0){a[z+(Ga+1)|0]=Fa}if((Da&4|0)!=0){a[z+(Ga+1+(c[x>>2]|0))|0]=Fa}if((oa&2|0)!=0){a[z+(Ga+2)|0]=Fa}if((Da&2|0)!=0){a[z+(Ga+2+(c[x>>2]|0))|0]=Fa}if((oa&1|0)!=0){a[z+(Ga+3)|0]=Fa}if((Da&1|0)==0){ia=va;la=pa;ma=qa;na=Fa;continue}a[z+(Ga+3+(c[x>>2]|0))|0]=Fa;ia=va;la=pa;ma=qa;na=Fa}ma=X+4|0;Ja=z+4|0;Ka=c[x>>2]|0;if((ma|0)<(Ka|0)){z=Ja;R=na;S=qa;Z=pa;X=ma;Y=ka}else{break}}La=Ja;Ma=na;Na=qa;Oa=pa;Pa=ka;Qa=Ka;Ra=c[J>>2]|0}else{La=g;Ma=U;Na=T;Oa=V;Pa=u;Qa=L;Ra=O}Y=E+4|0;if((Y|0)<(Ra|0)){g=La+(Qa*3|0)|0;U=Ma;T=Na;V=Oa;E=Y;u=Pa;L=Qa;O=Ra}else{break a}}if((v|0)==135){i=h;return n|0}}else if((v|0)==135){i=h;return n|0}}else if((C|0)==4){O=c[k+20+(c[k+16>>2]<<2)>>2]|0;L=c[k+40>>2]|0;u=O+L|0;E=c[s>>2]|0;V=c[r>>2]|0;T=E-V|0;U=V+(T>>>0>2>>>0?2:T)|0;c[r>>2]=U;if((L|0)>0){Sa=O;Ta=U;Ua=E}else{break}while(1){E=Ua;if((E-Ta|0)>>>0<2>>>0){n=-1094995529;v=135;break}U=Ta+1|0;c[r>>2]=U;O=a[Ta]|0;L=(O&255)<<24;T=O<<24>>24;O=((L|0)>-16777216?T:-T|0)+1|0;T=Sa+O|0;if(T>>>0>u>>>0){n=-1094995529;v=135;break}if((L|0)<0){c[r>>2]=Ta+2;mrc(Sa|0,a[U]|0,O|0)|0}else{L=E-U|0;E=L>>>0>O>>>0?O:L;nrc(Sa|0,U|0,E)|0;c[r>>2]=(c[r>>2]|0)+E}if(!(T>>>0<u>>>0)){break a}Sa=T;Ta=c[r>>2]|0;Ua=c[s>>2]|0}if((v|0)==135){i=h;return n|0}}else{QIb(b,2244568,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=-1094995529;i=h;return n|0}}while(0);q=k+16|0;v=b+124|0;if((c[v>>2]|0)>0){s=b+120|0;b=0;Ua=c[k+20+(c[q>>2]<<2)>>2]|0;k=c[c[l>>2]>>2]|0;r=c[s>>2]|0;while(1){nrc(k|0,Ua|0,r)|0;Ta=c[l>>2]|0;Sa=c[s>>2]|0;C=b+1|0;if((C|0)<(c[v>>2]|0)){b=C;Ua=Ua+Sa|0;k=k+(c[Ta+32>>2]|0)|0;r=Sa}else{Va=Ta;break}}}else{Va=c[l>>2]|0}c[q>>2]=(c[q>>2]|0)+1&3;q=YHb(e,Va)|0;if((q|0)<0){n=q;i=h;return n|0}c[f>>2]=1;n=c[p>>2]|0;i=h;return n|0}function wWa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b);mJb(b+20|0);mJb(b+24|0);mJb(b+28|0);mJb(b+32|0);return 0}function xWa(a){a=a|0;var b=0,d=0,e=0;b=i;if((c[a+416>>2]|0)==2){d=a+448|0;c[d>>2]=3;c[d+4>>2]=0;c[a+420>>2]=1;e=0;i=b;return e|0}else{KIb(a,16,2295616,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1094995529;i=b;return e|0}return 0}function yWa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=c[g+24>>2]|0;i=g+28|0;g=c[i>>2]|0;j=(g|0)/4922|0;if((g|0)<4922){k=-1094995529;return k|0}c[e+76>>2]=j*2205|0;g=M4a(a,e,0)|0;if((g|0)<0){k=g;return k|0}g=c[e>>2]|0;e=h;h=0;while(1){a=g;l=e+512|0;m=0;while(1){n=e+((d[l]|0)<<1)|0;b[a>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=e+((d[l+1|0]|0)<<1)|0;b[a+2>>1]=(d[n]|d[n+1|0]<<8)<<16>>16;n=m+1|0;if((n|0)<2205){a=a+4|0;l=l+2|0;m=n}else{break}}m=h+1|0;if((m|0)<(j|0)){g=g+8820|0;e=e+4922|0;h=m}else{break}}c[f>>2]=1;k=c[i>>2]|0;return k|0}function zWa(a){a=a|0;var b=0,d=0;b=UHb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+88>>2]=1;c[b+84>>2]=1;d=0;return d|0}function AWa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=i;j=c[b+124>>2]|0;k=c[b+120>>2]|0;l=b+140|0;switch(c[l>>2]|0){case 2:{m=2244560;n=255;o=3;p=k*3|0;break};case 31:{m=2359408;n=65535;o=1;p=k<<1;break};case 10:{m=2448528;n=1;o=1;p=k;break};case 291:{m=2203e3;n=65535;o=4;p=k<<3;break};case 8:{m=2359408;n=255;o=1;p=k;break};case 66:{m=2295600;n=255;o=2;p=k<<1;break};case 41:{m=2244560;n=65535;o=3;p=k*6|0;break};case 28:{m=2203e3;n=255;o=4;p=k<<2;break};default:{q=-1;i=h;return q|0}}r=ca(p,j)|0;s=r+200|0;t=d5a(b,e,s,(s|0)<0|0?-1:0)|0;if((t|0)<0){q=t;i=h;return q|0}t=c[e+24>>2]|0;s=e+28|0;b=t;Rb(t|0,c[s>>2]|0,2171256,(u=i,i=i+40|0,c[u>>2]=k,c[u+8>>2]=j,c[u+16>>2]=o,c[u+24>>2]=n,c[u+32>>2]=m,u)|0)|0;i=u;u=lrc(t|0)|0;m=t+u|0;n=c[f>>2]|0;o=c[f+32>>2]|0;f=(j|0)>0;do{if((c[l>>2]|0)==10){if(f&(k|0)>0){v=0;w=m;x=n}else{y=m;break}while(1){z=w;A=0;while(1){a[z]=(d[x+(A>>3)|0]|0)>>>((7-A&7)>>>0)&1;B=A+1|0;if((B|0)<(k|0)){z=z+1|0;A=B}else{break}}A=w+k|0;z=v+1|0;if((z|0)<(j|0)){v=z;w=A;x=x+o|0}else{y=A;break}}}else{if(!f){y=m;break}A=u+r|0;z=0;B=m;C=n;while(1){nrc(B|0,C|0,p)|0;D=z+1|0;if((D|0)<(j|0)){z=D;B=B+p|0;C=C+o|0}else{break}}y=t+A|0}}while(0);c[s>>2]=y-b;b=e+36|0;c[b>>2]=c[b>>2]|1;c[g>>2]=1;q=0;i=h;return q|0}function BWa(a){a=a|0;VHb(a+804|0);return 0}function CWa(a){a=a|0;var b=0,d=0;b=a+40|0;d=a;do{a=c[2477028]|0;c[b>>2]=a;}while((a|0)!=((E=c[2477028]|0,(c[2477028]|0)==(a|0)?(c[2477028]=d)|0:0,E)|0));return}function DWa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((a|0)==0){b=0;return b|0}else{d=9908112}while(1){e=c[d>>2]|0;if((e|0)==0){b=0;f=15;break}if((c[e>>2]|0)==(a|0)){break}if((c[e+4>>2]|0)==(a|0)){break}if((c[e+8>>2]|0)==(a|0)){break}if((c[e+12>>2]|0)==(a|0)){break}if((c[e+16>>2]|0)==(a|0)){break}else{d=e+40|0}}if((f|0)==15){return b|0}f=pJb(320)|0;d=f;if((f|0)!=0){c[f+4>>2]=e;a=pJb(c[e+20>>2]|0)|0;c[f>>2]=a;do{if((a|0)!=0){c[f+72>>2]=1;c[f+32>>2]=1;g=c[e+24>>2]|0;if((g|0)!=0){if((ve[g&4095](d)|0)!=0){break}}c[f+224>>2]=-1;g=f+232|0;c[g>>2]=0;c[g+4>>2]=0;c[f+240>>2]=-2147483648;c[f+244>>2]=-2147483648;c[f+248>>2]=-2147483648;b=d;return b|0}}while(0);mJb(f)}kJb(f);b=0;return b|0}function EWa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=a+40|0;c[e>>2]=0;c[e+4>>2]=-2147483648;f=a+48|0;c[f>>2]=0;c[f+4>>2]=-2147483648;g=a+288|0;c[g>>2]=-1;c[g+4>>2]=-1;h=a+184|0;c[h>>2]=0;c[h+4>>2]=0;i=a+16|0;j=b;k=(b|0)<0|0?-1:0;b=a+8|0;l=a+24|0;m=c[i>>2]|0;n=c[i+4>>2]|0;if((d|0)==0){d=0;a:while(1){o=wrc(m,n,j,k)|0;p=G;q=a+80+(d<<3)|0;r=c[q>>2]|0;s=c[q+4>>2]|0;do{if(!((p|0)<(s|0)|(p|0)==(s|0)&o>>>0<r>>>0)){t=c[b>>2]|0;u=c[b+4>>2]|0;if(!((u|0)<(s|0)|(u|0)==(s|0)&t>>>0<r>>>0)){if(!((t|0)==0&(u|0)==0)){break}if(!((c[l>>2]|0)==0&(c[l+4>>2]|0)==0)){break}}u=a+192+(d<<3)|0;if((c[u>>2]|0)==0&(c[u+4>>2]|0)==0){break}t=a+144+(d<<3)|0;v=c[t+4>>2]|0;c[f>>2]=c[t>>2];c[f+4>>2]=v;v=a+112+(d<<3)|0;t=c[v+4>>2]|0;c[e>>2]=c[v>>2];c[e+4>>2]=t;t=a+256+(d<<3)|0;v=c[t+4>>2]|0;c[g>>2]=c[t>>2];c[g+4>>2]=v;v=xrc(c[l>>2]|0,c[l+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[h>>2]=v;c[h+4>>2]=G;v=c[u+4>>2]|0;if((p|0)<(v|0)|(p|0)==(v|0)&o>>>0<(c[u>>2]|0)>>>0){w=16;break a}}}while(0);o=d+1|0;if((o|0)<4){d=o}else{w=16;break}}if((w|0)==16){return}}else{d=0;o=n;n=m;b:while(1){m=wrc(n,o,j,k)|0;p=G;q=a+80+(d<<3)|0;r=c[q>>2]|0;s=c[q+4>>2]|0;do{if((p|0)<(s|0)|(p|0)==(s|0)&m>>>0<r>>>0){x=o;y=n}else{u=c[b>>2]|0;v=c[b+4>>2]|0;if(!((v|0)<(s|0)|(v|0)==(s|0)&u>>>0<r>>>0)){if(!((u|0)==0&(v|0)==0)){x=o;y=n;break}if(!((c[l>>2]|0)==0&(c[l+4>>2]|0)==0)){x=o;y=n;break}}v=a+192+(d<<3)|0;if((c[v>>2]|0)==0&(c[v+4>>2]|0)==0){x=o;y=n;break}u=a+144+(d<<3)|0;t=c[u+4>>2]|0;c[f>>2]=c[u>>2];c[f+4>>2]=t;t=a+112+(d<<3)|0;u=c[t+4>>2]|0;c[e>>2]=c[t>>2];c[e+4>>2]=u;u=a+256+(d<<3)|0;t=c[u+4>>2]|0;c[g>>2]=c[u>>2];c[g+4>>2]=t;t=xrc(c[l>>2]|0,c[l+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[h>>2]=t;c[h+4>>2]=G;c[q>>2]=-1;c[q+4>>2]=2147483647;t=c[i>>2]|0;u=c[i+4>>2]|0;z=wrc(t,u,j,k)|0;A=G;B=c[v+4>>2]|0;if((A|0)<(B|0)|(A|0)==(B|0)&z>>>0<(c[v>>2]|0)>>>0){w=16;break b}else{x=u;y=t}}}while(0);q=d+1|0;if((q|0)<4){d=q;o=x;n=y}else{w=16;break}}if((w|0)==16){return}}}function FWa(a,b,d,e,f,g,h,j,k,l,m,n){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;o=i;i=i+16|0;p=a+176|0;q=c[p>>2]|0;if((q&4|0)==0){r=a+16|0;c[r>>2]=m;c[r+4>>2]=n;r=a+24|0;c[r>>2]=m;c[r+4>>2]=n;c[p>>2]=q|4}do{if((g|0)==0){q=o|0;mrc(q|0,0,16)|0;s=q}else{q=a+16|0;p=c[q>>2]|0;r=c[q+4>>2]|0;t=g;u=(g|0)<0|0?-1:0;v=wrc(p,r,t,u)|0;w=a+76|0;x=c[w>>2]|0;y=a+192+(x<<3)|0;if((v|0)==(c[y>>2]|0)&(G|0)==(c[y+4>>2]|0)){s=f;break}y=x+1&3;c[w>>2]=y;w=a+80+(y<<3)|0;c[w>>2]=p;c[w+4>>2]=r;r=wrc(c[q>>2]|0,c[q+4>>2]|0,t,u)|0;u=a+192+(y<<3)|0;c[u>>2]=r;c[u+4>>2]=G;u=a+112+(y<<3)|0;c[u>>2]=h;c[u+4>>2]=j;u=a+144+(y<<3)|0;c[u>>2]=k;c[u+4>>2]=l;u=a+256+(y<<3)|0;c[u>>2]=m;c[u+4>>2]=n;s=f}}while(0);f=a+72|0;a:do{if((c[f>>2]|0)!=0){c[f>>2]=0;n=a+40|0;m=c[n+4>>2]|0;l=a+56|0;c[l>>2]=c[n>>2];c[l+4>>2]=m;m=a+48|0;l=c[m+4>>2]|0;k=a+64|0;c[k>>2]=c[m>>2];c[k+4>>2]=l;l=a+288|0;k=c[l+4>>2]|0;j=a+296|0;c[j>>2]=c[l>>2];c[j+4>>2]=k;c[n>>2]=0;c[n+4>>2]=-2147483648;c[m>>2]=0;c[m+4>>2]=-2147483648;c[l>>2]=-1;c[l+4>>2]=-1;k=a+184|0;c[k>>2]=0;c[k+4>>2]=0;j=a+16|0;h=a+8|0;u=a+24|0;y=c[j>>2]|0;r=c[j+4>>2]|0;j=a+80|0;t=c[j>>2]|0;q=c[j+4>>2]|0;do{if(!((r|0)<(q|0)|(r|0)==(q|0)&y>>>0<t>>>0)){j=c[h>>2]|0;w=c[h+4>>2]|0;if(!((w|0)<(q|0)|(w|0)==(q|0)&j>>>0<t>>>0)){if(!((j|0)==0&(w|0)==0)){break}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){break}}w=a+192|0;j=c[w>>2]|0;p=c[w+4>>2]|0;if((j|0)==0&(p|0)==0){break}w=a+144|0;x=c[w+4>>2]|0;c[m>>2]=c[w>>2];c[m+4>>2]=x;x=a+112|0;w=c[x+4>>2]|0;c[n>>2]=c[x>>2];c[n+4>>2]=w;w=a+256|0;x=c[w+4>>2]|0;c[l>>2]=c[w>>2];c[l+4>>2]=x;x=xrc(c[u>>2]|0,c[u+4>>2]|0,t,q)|0;c[k>>2]=x;c[k+4>>2]=G;if((r|0)<(p|0)|(r|0)==(p|0)&y>>>0<j>>>0){break a}}}while(0);q=a+88|0;t=c[q>>2]|0;j=c[q+4>>2]|0;do{if(!((r|0)<(j|0)|(r|0)==(j|0)&y>>>0<t>>>0)){q=c[h>>2]|0;p=c[h+4>>2]|0;if(!((p|0)<(j|0)|(p|0)==(j|0)&q>>>0<t>>>0)){if(!((q|0)==0&(p|0)==0)){break}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){break}}p=a+200|0;q=c[p>>2]|0;x=c[p+4>>2]|0;if((q|0)==0&(x|0)==0){break}p=a+152|0;w=c[p+4>>2]|0;c[m>>2]=c[p>>2];c[m+4>>2]=w;w=a+120|0;p=c[w+4>>2]|0;c[n>>2]=c[w>>2];c[n+4>>2]=p;p=a+264|0;w=c[p+4>>2]|0;c[l>>2]=c[p>>2];c[l+4>>2]=w;w=xrc(c[u>>2]|0,c[u+4>>2]|0,t,j)|0;c[k>>2]=w;c[k+4>>2]=G;if((r|0)<(x|0)|(r|0)==(x|0)&y>>>0<q>>>0){break a}}}while(0);j=a+96|0;t=c[j>>2]|0;q=c[j+4>>2]|0;do{if(!((r|0)<(q|0)|(r|0)==(q|0)&y>>>0<t>>>0)){j=c[h>>2]|0;x=c[h+4>>2]|0;if(!((x|0)<(q|0)|(x|0)==(q|0)&j>>>0<t>>>0)){if(!((j|0)==0&(x|0)==0)){break}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){break}}x=a+208|0;j=c[x>>2]|0;w=c[x+4>>2]|0;if((j|0)==0&(w|0)==0){break}x=a+160|0;p=c[x+4>>2]|0;c[m>>2]=c[x>>2];c[m+4>>2]=p;p=a+128|0;x=c[p+4>>2]|0;c[n>>2]=c[p>>2];c[n+4>>2]=x;x=a+272|0;p=c[x+4>>2]|0;c[l>>2]=c[x>>2];c[l+4>>2]=p;p=xrc(c[u>>2]|0,c[u+4>>2]|0,t,q)|0;c[k>>2]=p;c[k+4>>2]=G;if((r|0)<(w|0)|(r|0)==(w|0)&y>>>0<j>>>0){break a}}}while(0);q=a+104|0;t=c[q>>2]|0;j=c[q+4>>2]|0;if((r|0)<(j|0)|(r|0)==(j|0)&y>>>0<t>>>0){break}q=c[h>>2]|0;w=c[h+4>>2]|0;if(!((w|0)<(j|0)|(w|0)==(j|0)&q>>>0<t>>>0)){if(!((q|0)==0&(w|0)==0)){break}if(!((c[u>>2]|0)==0&(c[u+4>>2]|0)==0)){break}}w=a+216|0;if((c[w>>2]|0)==0&(c[w+4>>2]|0)==0){break}w=a+168|0;q=c[w+4>>2]|0;c[m>>2]=c[w>>2];c[m+4>>2]=q;q=a+136|0;w=c[q+4>>2]|0;c[n>>2]=c[q>>2];c[n+4>>2]=w;w=a+280|0;q=c[w+4>>2]|0;c[l>>2]=c[w>>2];c[l+4>>2]=q;q=xrc(c[u>>2]|0,c[u+4>>2]|0,t,j)|0;c[k>>2]=q;c[k+4>>2]=G}}while(0);q=se[c[(c[a+4>>2]|0)+28>>2]&127](a,b,d,e,s,g)|0;if((c[e>>2]|0)==0){e=a+16|0;z=c[e+4>>2]|0;A=c[e>>2]|0;B=(q|0)<0;C=B?0:q;D=C;E=(C|0)<0|0?-1:0;F=a+16|0;H=wrc(A,z,D,E)|0;I=G;J=F|0;c[J>>2]=H;K=F+4|0;c[K>>2]=I;i=o;return C|0}else{e=a+24|0;g=c[e+4>>2]|0;s=a+8|0;c[s>>2]=c[e>>2];c[s+4>>2]=g;g=a+16|0;s=c[g>>2]|0;d=c[g+4>>2]|0;g=wrc(s,d,q,(q|0)<0|0?-1:0)|0;c[e>>2]=g;c[e+4>>2]=G;c[f>>2]=1;z=d;A=s;B=(q|0)<0;C=B?0:q;D=C;E=(C|0)<0|0?-1:0;F=a+16|0;H=wrc(A,z,D,E)|0;I=G;J=F|0;c[J>>2]=H;K=F+4|0;c[K>>2]=I;i=o;return C|0}return 0}function GWa(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;do{if((a|0)==0){i=f;j=g}else{k=c[(c[a+4>>2]|0)+36>>2]|0;if((k|0)==0){i=f;j=g;break}if((c[b+88>>2]&4194304|0)==0){if((c[b+92>>2]&8|0)==0){i=f;j=g;break}}l=Ee[k&511](b,f,g)|0;i=f+l|0;j=g-l|0}}while(0);c[d>>2]=i;c[e>>2]=j;g=b+96|0;if((c[g>>2]|0)==0|(h|0)==0){m=0;return m|0}if((c[b+92>>2]&8|0)==0){m=0;return m|0}h=b+100|0;b=(c[h>>2]|0)+j|0;c[e>>2]=b;e=hJb(b+16|0)|0;c[d>>2]=e;d=c[h>>2]|0;nrc(e|0,c[g>>2]|0,d)|0;nrc(e+d|0,i|0,j+16|0)|0;m=1;return m|0}function HWa(a){a=a|0;var b=0;if((a|0)==0){return}b=c[(c[a+4>>2]|0)+32>>2]|0;if((b|0)!=0){qe[b&1023](a)}kJb(c[a>>2]|0);kJb(a);return}function IWa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=b+24|0;if((c[h>>2]|0)>0){i=b+28|0;j=b|0;k=b+4|0;while(1){l=c[i>>2]|0;c[i>>2]=l+1;m=c[j>>2]|0;n=a[m+l|0]|0;l=c[k>>2]|0;c[k>>2]=l+1;a[m+l|0]=n;n=(c[h>>2]|0)-1|0;c[h>>2]=n;if((n|0)<=0){o=k;break}}}else{o=b+4|0}k=(c[g>>2]|0)==0&(e|0)==-100?0:e;e=c[o>>2]|0;j=b+8|0;c[j>>2]=e;if((k|0)==-100){i=b|0;n=wJb(c[i>>2]|0,b+12|0,(c[g>>2]|0)+16+e|0)|0;if((n|0)==0){c[o>>2]=0;p=-12;return p|0}else{c[i>>2]=n;nrc(n+(c[o>>2]|0)|0,c[f>>2]|0,c[g>>2]|0)|0;c[o>>2]=(c[o>>2]|0)+(c[g>>2]|0);p=-1;return p|0}}n=e+k|0;e=b+28|0;c[e>>2]=n;c[g>>2]=n;n=c[o>>2]|0;if((n|0)!=0){g=b|0;i=k+16|0;l=wJb(c[g>>2]|0,b+12|0,i+n|0)|0;if((l|0)==0){c[o>>2]=0;c[e>>2]=0;p=-12;return p|0}c[g>>2]=l;if((k|0)>-16){nrc(l+(c[o>>2]|0)|0,c[f>>2]|0,i)|0;q=c[g>>2]|0}else{q=l}c[o>>2]=0;c[f>>2]=q}if((k|0)>=0){p=0;return p|0}q=b+16|0;f=b+32|0;o=c[j>>2]|0;j=c[b>>2]|0;b=k;k=c[q>>2]|0;l=c[f+4>>2]|0;g=c[f>>2]|0;i=c[h>>2]|0;while(1){e=j+(o+b)|0;n=d[e]|0|k<<8;c[q>>2]=n;m=d[e]|0|(g<<8|0>>>24);e=l<<8|g>>>24|0;c[f>>2]=m;c[f+4>>2]=e;r=i+1|0;c[h>>2]=r;s=b+1|0;if((s|0)<0){b=s;k=n;l=e;g=m;i=r}else{p=0;break}}return p|0}function JWa(a){a=a|0;mJb(c[a>>2]|0);return}function KWa(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0;if((c|0)>0){e=0;f=-256}else{g=0;return g|0}while(1){a=d[b+e|0]|0|f;if((a|0)==438|(a|0)==435){break}h=e+1|0;if((h|0)<(c|0)){e=h;f=a<<8}else{g=0;i=5;break}}if((i|0)==5){return g|0}g=e-3|0;return g|0}function LWa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;k=f;l=c[h+24>>2]|0;m=c[h+28>>2]|0;if((m|0)<4){KIb(e,16,2448496,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=j;return o|0}h=l+2|0;p=(d[h]|0)>>>4;q=(d[l+3|0]|0)>>>6;r=d[732568+q|0]|0;c[e+792>>2]=r;if(!((q|0)==1|(q|0)==3)){KIb(e,16,2202968,(n=i,i=i+8|0,c[n>>2]=r,n)|0);i=n;o=-1094995529;i=j;return o|0}s=(q|0)==1;q=e+420|0;c[q>>2]=s?1:2;if(!s){c[e+796>>2]=r}t=a[h]&15;if((t|0)==5){c[e+412>>2]=192e3;u=192e3}else if((t|0)==1){c[e+412>>2]=48e3;u=48e3}else if((t|0)==4){c[e+412>>2]=96e3;u=96e3}else{c[e+412>>2]=0;KIb(e,16,2171224,(n=i,i=i+8|0,c[n>>2]=a[h]&15,n)|0);i=n;o=-1094995529;i=j;return o|0}h=p&255;p=e+448|0;c[p>>2]=c[732504+(h<<2)>>2];c[p+4>>2]=0;t=d[732488+h|0]|0;v=e+416|0;c[v>>2]=t;if((4090>>>(h>>>0)&1|0)==0){KIb(e,16,2143808,(n=i,i=i+8|0,c[n>>2]=h,n)|0);i=n;o=-1094995529;i=j;return o|0}h=t+1|0;c[e+72>>2]=ca(ca(u,r)|0,h&510)|0;r=l+4|0;u=m-4|0;if(!((u|0)>-1)){KIb(0,0,2359360,(n=i,i=i+24|0,c[n>>2]=2295584,c[n+8>>2]=2244536,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}n=l+m|0;m=h&2147483646;h=(u|0)/((ca(s?16:24,m)|0)>>>3|0)|0;c[f+76>>2]=h;s=M4a(e,k,0)|0;if((s|0)<0){o=s;i=j;return o|0}s=c[f>>2]|0;f=s;k=s;a:do{if((h|0)==0){w=r}else{s=c[p>>2]|0;e=c[p+4>>2]|0;u=1591;t=0;x=1551;y=0;z=1543;A=0;B=259;C=0;D=7;E=0;F=4;G=0;H=1539;I=0;J=263;K=0;L=3;M=0;if((s|0)==1599&(e|0)==0){if((c[q>>2]|0)==1){N=h<<4|4;O=f;P=h;Q=r;while(1){R=Q;b[O>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+2|0;b[O+2>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+4|0;b[O+4>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+6|0;b[O+12>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+8|0;b[O+8>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+10|0;b[O+10>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+12|0;b[O+14>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=Q+14|0;b[O+6>>1]=he((d[R]|d[R+1|0]<<8)<<16>>16|0)|0;R=P-1|0;if((R|0)==0){break}else{O=O+16|0;P=R;Q=Q+16|0}}w=l+N|0;break}else{Q=h*24|0|4;P=k;O=h;R=r;while(1){c[P>>2]=((d[R+1|0]|0)<<8|(d[R]|0)<<16|(d[R+2|0]|0))<<8;c[P+4>>2]=((d[R+4|0]|0)<<8|(d[R+3|0]|0)<<16|(d[R+5|0]|0))<<8;c[P+8>>2]=((d[R+7|0]|0)<<8|(d[R+6|0]|0)<<16|(d[R+8|0]|0))<<8;c[P+24>>2]=((d[R+10|0]|0)<<8|(d[R+9|0]|0)<<16|(d[R+11|0]|0))<<8;c[P+16>>2]=((d[R+13|0]|0)<<8|(d[R+12|0]|0)<<16|(d[R+14|0]|0))<<8;c[P+20>>2]=((d[R+16|0]|0)<<8|(d[R+15|0]|0)<<16|(d[R+17|0]|0))<<8;c[P+28>>2]=((d[R+19|0]|0)<<8|(d[R+18|0]|0)<<16|(d[R+20|0]|0))<<8;c[P+12>>2]=((d[R+22|0]|0)<<8|(d[R+21|0]|0)<<16|(d[R+23|0]|0))<<8;S=O-1|0;if((S|0)==0){break}else{P=P+32|0;O=S;R=R+24|0}}w=l+Q|0;break}}else if((s|0)==(x|0)&(e|0)==(y|0)){if((c[q>>2]|0)==1){R=(h*12|0)+4|0;O=f;P=h;N=r;while(1){S=N;b[O>>1]=he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=N+2|0;b[O+2>>1]=he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=N+4|0;b[O+4>>1]=he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=N+6|0;b[O+8>>1]=he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=N+8|0;b[O+10>>1]=he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=N+10|0;b[O+6>>1]=he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0;S=P-1|0;if((S|0)==0){break}else{O=O+12|0;P=S;N=N+12|0}}w=l+R|0;break}else{N=(h*18|0)+4|0;P=k;O=h;y=r;while(1){c[P>>2]=((d[y+1|0]|0)<<8|(d[y]|0)<<16|(d[y+2|0]|0))<<8;c[P+4>>2]=((d[y+4|0]|0)<<8|(d[y+3|0]|0)<<16|(d[y+5|0]|0))<<8;c[P+8>>2]=((d[y+7|0]|0)<<8|(d[y+6|0]|0)<<16|(d[y+8|0]|0))<<8;c[P+16>>2]=((d[y+10|0]|0)<<8|(d[y+9|0]|0)<<16|(d[y+11|0]|0))<<8;c[P+20>>2]=((d[y+13|0]|0)<<8|(d[y+12|0]|0)<<16|(d[y+14|0]|0))<<8;c[P+12>>2]=((d[y+16|0]|0)<<8|(d[y+15|0]|0)<<16|(d[y+17|0]|0))<<8;x=O-1|0;if((x|0)==0){break}else{P=P+24|0;O=x;y=y+18|0}}w=l+N|0;break}}else if((s|0)==(u|0)&(e|0)==(t|0)){y=n;if((c[q>>2]|0)==1){O=f;P=h;R=r;while(1){x=R;b[O>>1]=he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0;x=R+2|0;b[O+2>>1]=he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0;x=R+4|0;b[O+4>>1]=he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0;x=R+6|0;b[O+10>>1]=he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0;x=R+8|0;b[O+6>>1]=he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0;x=R+10|0;b[O+8>>1]=he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0;x=R+12|0;b[O+12>>1]=he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0;x=y-(R+14)|0;Q=R+(x>>>0>2>>>0?16:x+14|0)|0;x=P-1|0;if((x|0)==0){w=Q;break}else{O=O+14|0;P=x;R=Q}}}else{R=k;P=h;O=r;while(1){c[R>>2]=((d[O+1|0]|0)<<8|(d[O]|0)<<16|(d[O+2|0]|0))<<8;c[R+4>>2]=((d[O+4|0]|0)<<8|(d[O+3|0]|0)<<16|(d[O+5|0]|0))<<8;c[R+8>>2]=((d[O+7|0]|0)<<8|(d[O+6|0]|0)<<16|(d[O+8|0]|0))<<8;c[R+20>>2]=((d[O+10|0]|0)<<8|(d[O+9|0]|0)<<16|(d[O+11|0]|0))<<8;c[R+12>>2]=((d[O+13|0]|0)<<8|(d[O+12|0]|0)<<16|(d[O+14|0]|0))<<8;c[R+16>>2]=((d[O+16|0]|0)<<8|(d[O+15|0]|0)<<16|(d[O+17|0]|0))<<8;c[R+24>>2]=((d[O+19|0]|0)<<8|(d[O+18|0]|0)<<16|(d[O+20|0]|0))<<8;t=y-(O+21)|0;u=O+(t>>>0>3>>>0?24:t+21|0)|0;t=P-1|0;if((t|0)==0){w=u;break}else{R=R+28|0;P=t;O=u}}}}else if((s|0)==(L|0)&(e|0)==(M|0)|(s|0)==(J|0)&(e|0)==(K|0)|(s|0)==(H|0)&(e|0)==(I|0)){O=ca(h,m)|0;if((c[q>>2]|0)==1){P=(O<<1)+4|0;R=f;y=O;u=r;while(1){t=u;b[R>>1]=he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0;t=y-1|0;if((t|0)==0){break}else{R=R+2|0;y=t;u=u+2|0}}w=l+P|0;break}else{u=(O*3|0)+4|0;y=k;R=O;I=r;while(1){c[y>>2]=((d[I+1|0]|0)<<8|(d[I]|0)<<16|(d[I+2|0]|0))<<8;H=R-1|0;if((H|0)==0){break}else{y=y+4|0;R=H;I=I+3|0}}w=l+u|0;break}}else if((s|0)==(F|0)&(e|0)==(G|0)|(s|0)==(D|0)&(e|0)==(E|0)|(s|0)==(B|0)&(e|0)==(C|0)|(s|0)==(z|0)&(e|0)==(A|0)){I=n;if((c[q>>2]|0)!=1){R=k;y=h;O=r;while(1){P=c[v>>2]|0;H=P*3|0;K=R;J=P;M=O;while(1){c[K>>2]=((d[M+1|0]|0)<<8|(d[M]|0)<<16|(d[M+2|0]|0))<<8;L=J-1|0;if((L|0)==0){break}else{K=K+4|0;J=L;M=M+3|0}}M=I-(O+H)|0;J=O+(H-3+(M>>>0>3>>>0?6:M+3|0))|0;M=y-1|0;if((M|0)==0){w=J;break a}else{R=R+(P<<2)|0;y=M;O=J}}}O=c[v>>2]|0;y=f;R=h;A=r;while(1){e=O<<1;z=y;s=O;C=A;while(1){B=C;b[z>>1]=he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0;B=s-1|0;if((B|0)==0){break}else{z=z+2|0;s=B;C=C+2|0}}C=I-(A+e)|0;s=A+(e-2+(C>>>0>2>>>0?4:C+2|0))|0;C=R-1|0;if((C|0)==0){w=s;break}else{y=y+(O<<1)|0;R=C;A=s}}}else{w=r;break}}}while(0);c[g>>2]=1;o=4-r+w|0;i=j;return o|0}function MWa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=-1;a=hJb(96)|0;c[b+20>>2]=a;return((a|0)==0?-12:0)|0}function NWa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;j=e;k=c[g+24>>2]|0;l=g+28|0;g=c[l>>2]|0;m=c[b+60>>2]|0;if((g|0)<3){KIb(b,16,2448472,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=h;return o|0}p=k+1|0;q=(d[p]|0)<<8|a[k]&224|(d[k+2|0]|0)<<16;r=m;if((c[r>>2]|0)!=(q|0)){c[r>>2]=-1;c[m+24>>2]=0;s=(d[p]|0)>>>6<<2|16;c[b+792>>2]=s;if((s|0)==28){KIb(b,16,2171184,(n=i,i=i+8|0,c[n>>2]=28,n)|0);i=n;o=-1094995529;i=h;return o|0}t=(s|0)==16;c[b+420>>2]=t?1:2;c[b+796>>2]=s;u=c[732472+(((d[p]|0)>>>4&3)<<2)>>2]|0;c[b+412>>2]=u;v=a[p]&7;p=v+1|0;w=b+416|0;c[w>>2]=p;c[b+72>>2]=ca(ca(u,s)|0,p)|0;do{if(t){c[m+12>>2]=1;c[m+4>>2]=c[w>>2]<<1}else{if((v|0)==7){c[m+4>>2]=s;c[m+12>>2]=1;c[m+16>>2]=2;break}else if((v|0)==0|(v|0)==1|(v|0)==3){c[m+4>>2]=s>>>1;c[m+12>>2]=4/(c[w>>2]|0)|0;c[m+16>>2]=1;break}else{c[m+4>>2]=(ca(s<<2,p)|0)/8|0;c[m+12>>2]=4;c[m+16>>2]=c[w>>2];break}}}while(0);c[r>>2]=q}q=m+8|0;r=c[q>>2]|0;w=m+4|0;do{if((r|0)!=0){p=c[w>>2]|0;if((r|0)==(p|0)){break}KIb(b,24,2359320,(n=i,i=i+16|0,c[n>>2]=r,c[n+8>>2]=p,n)|0);i=n;c[m+24>>2]=0}}while(0);n=c[w>>2]|0;c[q>>2]=n;q=k+3|0;r=g-3|0;g=m+24|0;p=((c[g>>2]|0)+r|0)/(n|0)|0;c[e+76>>2]=ca(c[m+12>>2]|0,p)|0;n=M4a(b,j,0)|0;if((n|0)<0){o=n;i=h;return o|0}n=c[e>>2]|0;e=c[g>>2]|0;do{if((e|0)==0){x=n;y=p;z=q;A=r}else{j=(c[w>>2]|0)-e|0;s=m+20|0;v=(c[s>>2]|0)+e|0;if((r|0)>=(j|0)){nrc(v|0,q|0,j)|0;t=PWa(b,c[s>>2]|0,n,1)|0;c[g>>2]=0;x=t;y=p-1|0;z=k+(j+3)|0;A=r-j|0;break}nrc(v|0,q|0,r)|0;c[g>>2]=(c[g>>2]|0)+r;o=c[l>>2]|0;i=h;return o|0}}while(0);if((y|0)==0){B=A}else{PWa(b,z,x,y)|0;B=A-(ca(c[w>>2]|0,y)|0)|0}if((B|0)!=0){A=z+(ca(c[w>>2]|0,y)|0)|0;nrc(c[m+20>>2]|0,A|0,B)|0;c[g>>2]=B}c[f>>2]=1;o=c[l>>2]|0;i=h;return o|0}function OWa(a){a=a|0;mJb((c[a+60>>2]|0)+20|0);return 0}function PWa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=i;j=c[a+60>>2]|0;k=f;if(!((ca(c[j+4>>2]|0,g)|0)>-1)){KIb(0,0,2295528,(l=i,i=i+24|0,c[l>>2]=2244488,c[l+8>>2]=2202944,c[l+16>>2]=135,l)|0);i=l;Hd();return 0}l=c[a+792>>2]|0;if((l|0)==20){if((c[a+416>>2]|0)==1){m=f+(g<<4)|0;n=k;o=g;p=e;while(1){q=p;r=((he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[n>>2]=r;q=p+2|0;s=((he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<16;q=n+4|0;c[q>>2]=s;t=d[p+4|0]|0;c[n>>2]=t<<8&61440|r;r=n+8|0;c[q>>2]=t<<12&61440|s;s=p+5|0;t=((he((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[r>>2]=t;s=p+7|0;q=((he((d[s]|d[s+1|0]<<8)<<16>>16|0)|0)&65535)<<16;s=n+12|0;c[s>>2]=q;u=d[p+9|0]|0;c[r>>2]=u<<8&61440|t;c[s>>2]=u<<12&61440|q;q=o-1|0;if((q|0)==0){break}else{n=n+16|0;o=q;p=p+10|0}}v=m}else{m=j+16|0;p=k;o=g;n=e;while(1){q=c[m>>2]|0;if((q|0)==0){w=n;x=p}else{u=q<<2;s=q*10|0;t=n;r=p;y=q;while(1){q=t;z=((he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[r>>2]=z;q=t+2|0;A=((he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)<<16;q=r+4|0;c[q>>2]=A;B=t+4|0;C=((he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535)<<16;B=r+8|0;c[B>>2]=C;D=t+6|0;E=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<16;D=r+12|0;c[D>>2]=E;F=d[t+8|0]|0;c[r>>2]=F<<8&61440|z;c[q>>2]=F<<12&61440|A;A=d[t+9|0]|0;c[B>>2]=A<<8&61440|C;c[D>>2]=A<<12&61440|E;E=y-1|0;if((E|0)==0){break}else{t=t+10|0;r=r+16|0;y=E}}w=n+s|0;x=p+(u<<2)|0}y=o-1|0;if((y|0)==0){v=x;break}else{p=x;o=y;n=w}}}G=v;i=h;return G|0}else if((l|0)==24){if((c[a+416>>2]|0)==1){v=f+(g<<4)|0;w=k;n=g;o=e;while(1){x=o;p=((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[w>>2]=p;x=o+2|0;m=((he((d[x]|d[x+1|0]<<8)<<16>>16|0)|0)&65535)<<16;x=w+4|0;c[x>>2]=m;c[w>>2]=(d[o+4|0]|0)<<8|p;p=w+8|0;c[x>>2]=(d[o+5|0]|0)<<8|m;m=o+6|0;x=((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[p>>2]=x;m=o+8|0;y=((he((d[m]|d[m+1|0]<<8)<<16>>16|0)|0)&65535)<<16;m=w+12|0;c[m>>2]=y;c[p>>2]=(d[o+10|0]|0)<<8|x;c[m>>2]=(d[o+11|0]|0)<<8|y;y=n-1|0;if((y|0)==0){break}else{w=w+16|0;n=y;o=o+12|0}}H=v}else{v=j+16|0;j=k;k=g;o=e;while(1){n=c[v>>2]|0;if((n|0)==0){I=o;J=j}else{w=n<<2;y=n*12|0;m=o;x=j;p=n;while(1){n=m;r=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<16;c[x>>2]=r;n=m+2|0;t=((he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0)&65535)<<16;n=x+4|0;c[n>>2]=t;E=m+4|0;A=((he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535)<<16;E=x+8|0;c[E>>2]=A;D=m+6|0;C=((he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535)<<16;D=x+12|0;c[D>>2]=C;c[x>>2]=(d[m+8|0]|0)<<8|r;c[n>>2]=(d[m+9|0]|0)<<8|t;c[E>>2]=(d[m+10|0]|0)<<8|A;c[D>>2]=(d[m+11|0]|0)<<8|C;C=p-1|0;if((C|0)==0){break}else{m=m+12|0;x=x+16|0;p=C}}I=o+y|0;J=j+(w<<2)|0}p=k-1|0;if((p|0)==0){H=J;break}else{j=J;k=p;o=I}}}G=H;i=h;return G|0}else if((l|0)==16){l=ca(c[a+416>>2]|0,g)|0;g=f+(l<<1)|0;a=l;l=f;f=e;while(1){e=f;b[l>>1]=he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0;e=a-1|0;if((e|0)==0){G=g;break}else{a=e;l=l+2|0;f=f+2|0}}i=h;return G|0}else{G=0;i=h;return G|0}return 0}function QWa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[b+424>>2]=0;d=b+12|0;e=c[(c[d>>2]|0)+12>>2]|0;if((e|0)==65542){f=0;g=0;while(1){if((g|0)==127){h=8192}else{i=~((g^255)&255)&255;j=(i<<3&120|132)<<(i>>>4&7);k=~((g+1^255)&255)&255;l=(k<<3&120|132)<<(k>>>4&7);h=((i&128|0)!=0?132-j|0:j-132|0)+4+((k&128|0)!=0?132-l|0:l-132|0)>>3}if((f|0)<(h|0)){l=(g^255)&255;k=(g^127)&255;j=f;while(1){a[j+5800544|0]=l;if((j|0)>0){a[5792352+(8192-j)|0]=k}i=j+1|0;if((i|0)<(h|0)){j=i}else{m=h;break}}}else{m=f}j=g+1|0;if((j|0)<128){f=m;g=j}else{break}}a[5792352]=a[5792353]|0}else if((e|0)==65543){e=0;g=0;while(1){if((g|0)==127){n=8192}else{m=((g^213)&255^85)&255;f=m>>>4&7;h=m<<1&30;if((f|0)==0){o=h<<3|8}else{o=(h|33)<<f+2}f=((g+1^213)&255^85)&255;h=f>>>4&7;j=f<<1&30;if((h|0)==0){p=j<<3|8}else{p=(j|33)<<h+2}n=((m&128|0)!=0?o:-o|0)+4+((f&128|0)!=0?p:-p|0)>>3}if((e|0)<(n|0)){f=(g^213)&255;m=(g^85)&255;h=e;while(1){a[h+5816928|0]=f;if((h|0)>0){a[5808736+(8192-h)|0]=m}j=h+1|0;if((j|0)<(n|0)){h=j}else{q=n;break}}}else{q=e}h=g+1|0;if((h|0)<128){e=q;g=h}else{break}}a[5808736]=a[5808737]|0}g=g5a(c[(c[d>>2]|0)+12>>2]|0)|0;c[b+792>>2]=g;d=(ca(c[b+416>>2]|0,g)|0)/8|0;c[b+432>>2]=d;c[b+72>>2]=ca(d<<3,c[b+412>>2]|0)|0;return 0}function RWa(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;h=d+12|0;i=(g5a(c[(c[h>>2]|0)+12>>2]|0)|0)/8|0;j=d+416|0;k=ca(c[j>>2]|0,c[f+76>>2]|0)|0;l=c[f>>2]|0;m=l;n=ca(k,i)|0;o=d5a(d,e,n,(n|0)<0|0?-1:0)|0;if((o|0)<0){p=o;return p|0}o=c[e+24>>2]|0;e=c[(c[h>>2]|0)+12>>2]|0;a:do{if((e|0)==65537){if((k|0)>0){q=o;r=m;s=k}else{break}while(1){h=q;y=he(b[r>>1]|0)|0;a[h]=y;y=y>>8;a[h+1|0]=y;h=s-1|0;if((h|0)>0){q=q+2|0;r=r+2|0;s=h}else{break}}}else if((e|0)==65556|(e|0)==65545){if((k|0)<=0){break}h=o;d=l;t=k;while(1){u=h;y=je(c[d>>2]|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=t-1|0;if((u|0)>0){h=h+4|0;d=d+4|0;t=u}else{break}}}else if((e|0)==65558){if((k|0)<=0){break}t=o;d=l;h=k;while(1){u=c[d+4>>2]|0;v=je(c[d>>2]|0)|0;w=t;x=w|0;y=je(u|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=w+4|0;y=v|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=h-1|0;if((x|0)>0){t=t+8|0;d=d+8|0;h=x}else{break}}}else if((e|0)==65547){if((k|0)<=0){break}h=o;d=l;t=k;while(1){x=h;y=je(c[d>>2]^-2147483648|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=t-1|0;if((x|0)>0){h=h+4|0;d=d+4|0;t=x}else{break}}}else if((e|0)==65546){if((k|0)<=0){break}t=o;d=l;h=k;while(1){x=t;y=c[d>>2]^-2147483648;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=h-1|0;if((x|0)>0){t=t+4|0;d=d+4|0;h=x}else{break}}}else if((e|0)==65552){if((k|0)>0){z=o;A=m;B=k}else{break}while(1){h=b[A>>1]|0;d=a[1316536+(h>>>8&255)|0]|0;t=a[1316536+(h&255)|0]|0;a[z+2|0]=d<<4;a[z+1|0]=((t&255)<<8|d&255)>>>4;a[z]=(t&255)>>>4;t=B-1|0;if((t|0)>0){z=z+3|0;A=A+2|0;B=t}else{break}}}else if((e|0)==65538){if((k|0)>0){C=o;D=m;E=k}else{break}while(1){t=C;y=b[D>>1]^-32768;a[t]=y;y=y>>8;a[t+1|0]=y;t=E-1|0;if((t|0)>0){C=C+2|0;D=D+2|0;E=t}else{break}}}else if((e|0)==65539){if((k|0)>0){F=o;G=m;H=k}else{break}while(1){t=F;y=he(b[G>>1]^-32768|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;t=H-1|0;if((t|0)>0){F=F+2|0;G=G+2|0;H=t}else{break}}}else if((e|0)==65542){if((k|0)>0){I=o;J=m;K=k}else{break}while(1){a[I]=a[5792352+((b[J>>1]|0)+32768>>2)|0]|0;t=K-1|0;if((t|0)>0){I=I+1|0;J=J+2|0;K=t}else{break}}}else if((e|0)==65559|(e|0)==65557|(e|0)==65544|(e|0)==65536|(e|0)==65541){nrc(o|0,l|0,n)|0}else if((e|0)==65563){t=c[j>>2]|0;d=(k|0)/(t|0)|0;if((t|0)<=0){break}h=f+64|0;if((d|0)>0){L=o;M=0}else{x=0;while(1){x=x+1|0;if((x|0)>=(t|0)){break a}}}while(1){t=L;x=d;v=c[(c[h>>2]|0)+(M<<2)>>2]|0;while(1){a[t]=a[v]^-128;w=x-1|0;if((w|0)>0){t=t+1|0;x=w;v=v+1|0}else{break}}v=M+1|0;if((v|0)<(c[j>>2]|0)){L=L+d|0;M=v}else{break}}}else if((e|0)==65550){if((k|0)<=0){break}d=o;h=l;v=k;while(1){x=((c[h>>2]|0)>>>8)+8388608|0;a[d]=x;a[d+1|0]=x>>>8;a[d+2|0]=x>>>16;x=v-1|0;if((x|0)>0){d=d+3|0;h=h+4|0;v=x}else{break}}}else if((e|0)==65549){if((k|0)<=0){break}v=o;h=l;d=k;while(1){x=c[h>>2]>>8;a[v+2|0]=x;a[v+1|0]=x>>>8;a[v]=x>>>16;x=d-1|0;if((x|0)>0){v=v+3|0;h=h+4|0;d=x}else{break}}}else if((e|0)==407917392){d=c[j>>2]|0;h=(k|0)/(d|0)|0;if((d|0)<=0){break}v=f+64|0;if((h|0)<=0){x=0;while(1){x=x+1|0;if((x|0)>=(d|0)){break a}}}d=h*3|0;x=o;t=0;while(1){w=x;u=h;N=c[(c[v>>2]|0)+(t<<2)>>2]|0;while(1){O=c[N>>2]>>8;a[w]=O;a[w+1|0]=O>>>8;a[w+2|0]=O>>>16;O=u-1|0;if((O|0)>0){w=w+3|0;u=O;N=N+4|0}else{break}}N=t+1|0;if((N|0)<(c[j>>2]|0)){x=x+d|0;t=N}else{break}}}else if((e|0)==65540){if((k|0)>0){P=o;Q=l;R=k}else{break}while(1){a[P]=a[Q]^-128;t=R-1|0;if((t|0)>0){P=P+1|0;Q=Q+1|0;R=t}else{break}}}else if((e|0)==1347637264){t=c[j>>2]|0;d=(k|0)/(t|0)|0;if((t|0)<=0){break}x=f+64|0;if((d|0)<=0){v=0;while(1){v=v+1|0;if((v|0)>=(t|0)){break a}}}t=d<<1;v=o;h=0;while(1){N=v;u=c[(c[x>>2]|0)+(h<<2)>>2]|0;w=d;while(1){O=N;y=he(b[u>>1]|0)|0;a[O]=y;y=y>>8;a[O+1|0]=y;O=w-1|0;if((O|0)>0){N=N+2|0;u=u+2|0;w=O}else{break}}w=h+1|0;if((w|0)<(c[j>>2]|0)){v=v+t|0;h=w}else{break}}}else if((e|0)==65543){if((k|0)>0){S=o;T=m;U=k}else{break}while(1){a[S]=a[5808736+((b[T>>1]|0)+32768>>2)|0]|0;h=U-1|0;if((h|0)>0){S=S+1|0;T=T+2|0;U=h}else{break}}}else if((e|0)==65548){if((k|0)<=0){break}h=o;t=l;v=k;while(1){d=c[t>>2]>>8;a[h]=d;a[h+1|0]=d>>>8;a[h+2|0]=d>>>16;d=v-1|0;if((d|0)>0){h=h+3|0;t=t+4|0;v=d}else{break}}}else if((e|0)==65551){if((k|0)<=0){break}v=o;t=l;h=k;while(1){d=((c[t>>2]|0)>>>8)+8388608|0;a[v+2|0]=d;a[v+1|0]=d>>>8;a[v]=d>>>16;d=h-1|0;if((d|0)>0){v=v+3|0;t=t+4|0;h=d}else{break}}}else if((e|0)==65554|(e|0)==542135120){h=c[j>>2]|0;if((h|0)<=0){break}t=f+64|0;v=ca((k|0)/(h|0)|0,i)|0;h=o;d=0;while(1){nrc(h|0,c[(c[t>>2]|0)+(d<<2)>>2]|0,v)|0;x=d+1|0;if((x|0)<(c[j>>2]|0)){h=h+v|0;d=x}else{break}}}else{p=-1;return p|0}}while(0);c[g>>2]=1;p=0;return p|0}function SWa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a+60>>2]|0;if((c[a+416>>2]|0)<1){KIb(a,16,2608968,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-22;i=d;return g|0}f=c[a+48>>2]|0;if((f|0)==65543){h=e;j=0;do{k=(j&255^85)&255;l=k>>>4&7;m=k<<1&30;if((l|0)==0){n=m<<3|8}else{n=(m|33)<<l+2}b[h+(j<<1)>>1]=(k&128|0)!=0?n:-n|0;j=j+1|0;}while((j|0)<256)}else if((f|0)==65542){j=e;e=0;do{n=~(e&255)&255;h=(n<<3&120|132)<<(n>>>4&7);b[j+(e<<1)>>1]=(n&128|0)!=0?132-h|0:h+65404|0;e=e+1|0;}while((e|0)<256)}e=c[c[(c[a+12>>2]|0)+32>>2]>>2]|0;c[a+420>>2]=e;if((e|0)!=2){g=0;i=d;return g|0}c[a+796>>2]=g5a(f)|0;g=0;i=d;return g|0}function TWa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=c[e+60>>2]|0;m=f;n=e+48|0;o=(g5a(c[n>>2]|0)|0)/8|0;p=c[n>>2]|0;q=(p|0)==65561;r=q?2:1;s=q?5:o;if((s|0)==0){KIb(e,16,2623080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-22;i=j;return u|0}o=e+416|0;q=c[o>>2]|0;if((q|0)==0){KIb(e,16,2621592,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-22;i=j;return u|0}if((p|0)!=(c[(c[e+12>>2]|0)+12>>2]|0)){KIb(e,16,2619088,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-22;i=j;return u|0}p=ca(q,s)|0;do{if((p|0)==0){v=l}else{w=(l|0)%(p|0)|0;if((w|0)==0){v=l;break}if((l|0)>=(p|0)){v=l-w|0;break}KIb(e,16,2612400,(t=i,i=i+16|0,c[t>>2]=l,c[t+8>>2]=p,t)|0);i=t;u=-1094995529;i=j;return u|0}}while(0);t=(v|0)/(s|0)|0;c[f+76>>2]=(ca(t,r)|0)/(q|0)|0;q=M4a(e,m,0)|0;if((q|0)<0){u=q;i=j;return u|0}q=c[f>>2]|0;m=c[n>>2]|0;a:do{if((m|0)==65556|(m|0)==65545){if((t|0)>0){x=k;y=q;z=t}else{break}while(1){n=x;c[y>>2]=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=z-1|0;if((n|0)>0){x=x+4|0;y=y+4|0;z=n}else{break}}}else if((m|0)==407917392){n=c[o>>2]|0;e=(t|0)/(n|0)|0;if((n|0)<=0){break}r=f+64|0;if((e|0)<=0){p=0;while(1){p=p+1|0;if((p|0)>=(n|0)){break a}}}n=e*3|0;p=k;l=0;while(1){w=p;A=e;B=c[(c[r>>2]|0)+(l<<2)>>2]|0;while(1){c[B>>2]=((d[w+1|0]|0)<<8|(d[w+2|0]|0)<<16|(d[w]|0))<<8;C=A-1|0;if((C|0)>0){w=w+3|0;A=C;B=B+4|0}else{break}}B=l+1|0;if((B|0)<(c[o>>2]|0)){p=p+n|0;l=B}else{break}}}else if((m|0)==65563){l=c[o>>2]|0;n=(t|0)/(l|0)|0;if((l|0)<=0){break}p=f+64|0;if((n|0)>0){D=k;E=0}else{r=0;while(1){r=r+1|0;if((r|0)>=(l|0)){break a}}}while(1){l=D;r=c[(c[p>>2]|0)+(E<<2)>>2]|0;e=n;while(1){a[r]=a[l]^-128;B=e-1|0;if((B|0)>0){l=l+1|0;r=r+1|0;e=B}else{break}}e=E+1|0;if((e|0)<(c[o>>2]|0)){D=D+n|0;E=e}else{break}}}else if((m|0)==65537){if((t|0)>0){F=k;G=q;H=t}else{break}while(1){n=F;b[G>>1]=he((d[n]|d[n+1|0]<<8)<<16>>16|0)|0;n=H-1|0;if((n|0)>0){F=F+2|0;G=G+2|0;H=n}else{break}}}else if((m|0)==65552){if((t|0)>0){I=k;J=q;K=t}else{break}while(1){n=(d[I+1|0]|0)<<8;b[J>>1]=(d[1316536+((n|(d[I+2|0]|0))>>>4&255)|0]|0)<<8|(d[1316536+((n|(d[I]|0)<<16)>>>12&255)|0]|0);n=K-1|0;if((n|0)>0){I=I+3|0;J=J+2|0;K=n}else{break}}}else if((m|0)==65553){if((t|0)>0){L=k;M=q;N=t}else{break}while(1){n=a[L]|0;a[M]=n<<24>>24>-1?-128-n&255:n;n=N-1|0;if((n|0)>0){L=L+1|0;M=M+1|0;N=n}else{break}}}else if((m|0)==65561){n=c[o>>2]|0;p=(t|0)/(n|0)|0;if((n|0)<=0){break}e=f+64|0;r=(p|0)>0;l=p*5|0;B=k;A=0;w=n;while(1){if(r){n=B;C=c[(c[e>>2]|0)+(A<<2)>>2]|0;O=0;while(1){P=n+2|0;Q=d[P]|0;R=d[n+1|0]|0;c[C>>2]=R|Q<<28|R<<20|Q<<8&3840|(d[n]|0)<<12;Q=d[n+4|0]|0;R=d[n+3|0]|0;c[C+4>>2]=Q<<4|Q<<24|R<<16|R>>>4|(d[P]|0)<<8&61440;P=O+1|0;if((P|0)<(p|0)){n=n+5|0;C=C+8|0;O=P}else{break}}S=B+l|0;T=c[o>>2]|0}else{S=B;T=w}O=A+1|0;if((O|0)<(T|0)){B=S;A=O;w=T}else{break}}}else if((m|0)==65559|(m|0)==65557|(m|0)==65544|(m|0)==65536|(m|0)==65541){nrc(q|0,k|0,ca(t,s)|0)|0}else if((m|0)==65554|(m|0)==542135120){w=c[o>>2]|0;if((w|0)<=0){break}A=f+64|0;B=ca((t|0)/(w|0)|0,s)|0;w=k;l=0;while(1){nrc(c[(c[A>>2]|0)+(l<<2)>>2]|0,w|0,B)|0;p=l+1|0;if((p|0)<(c[o>>2]|0)){w=w+B|0;l=p}else{break}}}else if((m|0)==1347637264){l=c[o>>2]|0;B=(t|0)/(l|0)|0;if((l|0)<=0){break}w=f+64|0;A=(B|0)>0;p=B<<1;e=k;r=0;O=l;while(1){if(A){l=e;C=c[(c[w>>2]|0)+(r<<2)>>2]|0;n=B;while(1){P=l;b[C>>1]=he((d[P]|d[P+1|0]<<8)<<16>>16|0)|0;P=n-1|0;if((P|0)>0){l=l+2|0;C=C+2|0;n=P}else{break}}U=e+p|0;V=c[o>>2]|0}else{U=e;V=O}n=r+1|0;if((n|0)<(V|0)){e=U;r=n;O=V}else{break}}}else if((m|0)==65548){if((t|0)>0){W=k;X=q;Y=t}else{break}while(1){c[X>>2]=((d[W+1|0]|0)<<8|(d[W+2|0]|0)<<16|(d[W]|0))<<8;O=Y-1|0;if((O|0)>0){W=W+3|0;X=X+4|0;Y=O}else{break}}}else if((m|0)==65547){if((t|0)>0){Z=k;_=q;$=t}else{break}while(1){O=Z;c[_>>2]=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)^-2147483648;O=$-1|0;if((O|0)>0){Z=Z+4|0;_=_+4|0;$=O}else{break}}}else if((m|0)==65550){if((t|0)>0){aa=k;ba=q;da=t}else{break}while(1){c[ba>>2]=((d[aa+1|0]|0)<<8|(d[aa+2|0]|0)<<16|(d[aa]|0))<<8^-2147483648;O=da-1|0;if((O|0)>0){aa=aa+3|0;ba=ba+4|0;da=O}else{break}}}else if((m|0)==65539){if((t|0)>0){ea=k;fa=q;ga=t}else{break}while(1){O=ea;b[fa>>1]=(he((d[O]|d[O+1|0]<<8)<<16>>16|0)|0)^-32768;O=ga-1|0;if((O|0)>0){ea=ea+2|0;fa=fa+2|0;ga=O}else{break}}}else if((m|0)==65549){if((t|0)>0){ha=k;ia=q;ja=t}else{break}while(1){c[ia>>2]=((d[ha+1|0]|0)<<8|(d[ha]|0)<<16|(d[ha+2|0]|0))<<8;O=ja-1|0;if((O|0)>0){ha=ha+3|0;ia=ia+4|0;ja=O}else{break}}}else if((m|0)==65543|(m|0)==65542){if((t|0)<=0){break}O=h;r=k;e=q;p=t;while(1){b[e>>1]=b[O+((d[r]|0)<<1)>>1]|0;B=p-1|0;if((B|0)>0){r=r+1|0;e=e+2|0;p=B}else{break}}}else if((m|0)==65540){if((t|0)>0){ka=k;la=q;ma=t}else{break}while(1){a[la]=a[ka]^-128;p=ma-1|0;if((p|0)>0){ka=ka+1|0;la=la+1|0;ma=p}else{break}}}else if((m|0)==65551){if((t|0)>0){na=k;oa=q;pa=t}else{break}while(1){c[oa>>2]=((d[na+1|0]|0)<<8|(d[na]|0)<<16|(d[na+2|0]|0))<<8^-2147483648;p=pa-1|0;if((p|0)>0){na=na+3|0;oa=oa+4|0;pa=p}else{break}}}else if((m|0)==65538){if((t|0)>0){qa=k;ra=q;sa=t}else{break}while(1){p=qa;b[ra>>1]=(d[p]|d[p+1|0]<<8)<<16>>16^-32768;p=sa-1|0;if((p|0)>0){qa=qa+2|0;ra=ra+2|0;sa=p}else{break}}}else if((m|0)==65558){if((t|0)>0){ta=k;ua=q;va=t}else{break}while(1){p=ta;e=p|0;r=p+4|0;p=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0;e=ua;c[e>>2]=je(p|0)|0;c[e+4>>2]=r;r=va-1|0;if((r|0)>0){ta=ta+8|0;ua=ua+8|0;va=r}else{break}}}else if((m|0)==65546){if((t|0)>0){wa=k;xa=q;ya=t}else{break}while(1){r=wa;c[xa>>2]=(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24)^-2147483648;r=ya-1|0;if((r|0)>0){wa=wa+4|0;xa=xa+4|0;ya=r}else{break}}}else{u=-1;i=j;return u|0}}while(0);c[g>>2]=1;u=v;i=j;return u|0}function UWa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;h=i;j=e;k=g+28|0;l=c[k>>2]|0;if((l|0)<128){m=-1094995529;i=h;return m|0}n=c[g+24>>2]|0;g=n+l|0;do{if((a[n]|0)==10){if((d[n+1|0]|0)>>>0>5>>>0){break}o=a[n+2|0]|0;p=a[n+3|0]|0;q=p&255;r=n+4|0;s=(d[r]|d[r+1|0]<<8)<<16>>16;r=n+6|0;t=(d[r]|d[r+1|0]<<8)<<16>>16;r=n+8|0;u=(d[r]|d[r+1|0]<<8)<<16>>16;r=n+10|0;v=(d[r]|d[r+1|0]<<8)<<16>>16;r=n+12|0;c[b+224>>2]=(d[r]|d[r+1|0]<<8)<<16>>16&65535;r=n+14|0;c[b+228>>2]=(d[r]|d[r+1|0]<<8)<<16>>16&65535;if((u&65535)>>>0<(s&65535)>>>0|(v&65535)>>>0<(t&65535)>>>0){KIb(b,16,2359136,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;m=-1094995529;i=h;return m|0}r=u&65535;u=s&65535;s=r-u+1|0;x=(v&65535)-(t&65535)+1|0;t=a[n+65|0]|0;v=t&255;y=n+68|0;z=n+66|0;A=(d[z]|d[z+1|0]<<8)<<16>>16&65535;z=ca(A,v)|0;do{if(!(z>>>0<((ca(ca(s,q)|0,v)|0)+7|0)>>>3>>>0)){B=o<<24>>24==0;if(B){if(z>>>0>(((g-y|0)>>>0)/(x>>>0)|0)>>>0){break}}switch(v<<8|q|0){case 264:case 260:case 258:case 257:case 1025:case 769:case 513:{c[b+140>>2]=11;break};case 776:{c[b+140>>2]=2;break};default:{KIb(b,16,2244432,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;m=-1094995529;i=h;return m|0}}C=n+128|0;D=H4a(b,s,x)|0;if((D|0)<0){m=D;i=h;return m|0}D=M4a(b,j,0)|0;if((D|0)<0){m=D;i=h;return m|0}c[e+88>>2]=1;D=c[e>>2]|0;E=c[e+32>>2]|0;F=hJb(z+16|0)|0;if((F|0)==0){m=-12;i=h;return m|0}G=p<<24>>24==8;a:do{if(t<<24>>24==3&G){if((x|0)==0){H=C;I=99;break}J=g;K=(s|0)!=0;L=A<<1;M=(z|0)==0;if(B){N=C;O=D;P=0;while(1){Q=J-N|0;R=Q>>>0>z>>>0?z:Q;nrc(F|0,N|0,R)|0;Q=N+R|0;if(K){R=0;do{S=R*3|0;a[O+S|0]=a[F+R|0]|0;a[O+(S+1)|0]=a[F+(R+A)|0]|0;a[O+(S+2)|0]=a[F+(R+L)|0]|0;R=R+1|0;}while(R>>>0<s>>>0)}R=P+1|0;if(R>>>0<x>>>0){N=Q;O=O+E|0;P=R}else{H=Q;I=99;break a}}}else{T=C;U=D;V=0}while(1){b:do{if(M){W=T}else{P=0;O=T;while(1){if((g|0)==(O|0)){W=g;break b}do{if((J-O|0)<1){X=0;Y=1;Z=O}else{N=O+1|0;R=a[O]|0;if((R&255)>>>0<192>>>0|(g|0)==(N|0)){X=R;Y=1;Z=N;break}S=R&63;if((J-N|0)<1){X=0;Y=S;Z=N;break}X=a[N]|0;Y=S;Z=O+2|0}}while(0);if(P>>>0>=z>>>0|Y<<24>>24==0){_=P}else{S=P-z|0;N=~(Y-1&255);R=S>>>0>N>>>0?S:N;mrc(F+P|0,X|0,-R|0)|0;_=P-R|0}if(_>>>0<z>>>0){P=_;O=Z}else{W=Z;break}}}}while(0);if(K){Q=0;do{O=Q*3|0;a[U+O|0]=a[F+Q|0]|0;a[U+(O+1)|0]=a[F+(Q+A)|0]|0;a[U+(O+2)|0]=a[F+(Q+L)|0]|0;Q=Q+1|0;}while(Q>>>0<s>>>0)}Q=V+1|0;if(Q>>>0<x>>>0){T=W;U=U+E|0;V=Q}else{H=W;I=99;break}}}else{L=t<<24>>24==1;if(L&G){K=c[k>>2]|0;J=K-769|0;if((K|0)<769){KIb(b,16,2202912,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if((c[b+696>>2]&8|0)!=0){$=-1094995529;break}$=c[k>>2]|0;break}if((x|0)==0){aa=C}else{K=g;M=(z|0)==0;Q=C;O=D;P=0;while(1){c:do{if(B){R=K-Q|0;N=R>>>0>z>>>0?z:R;nrc(F|0,Q|0,N)|0;ba=Q+N|0}else{if(M){ba=Q;break}else{da=0;ea=Q}while(1){if((g|0)==(ea|0)){ba=g;break c}do{if((K-ea|0)<1){fa=0;ga=1;ha=ea}else{N=ea+1|0;R=a[ea]|0;if((R&255)>>>0<192>>>0|(g|0)==(N|0)){fa=R;ga=1;ha=N;break}S=R&63;if((K-N|0)<1){fa=0;ga=S;ha=N;break}fa=a[N]|0;ga=S;ha=ea+2|0}}while(0);if(da>>>0>=z>>>0|ga<<24>>24==0){ia=da}else{S=da-z|0;N=~(ga-1&255);R=S>>>0>N>>>0?S:N;mrc(F+da|0,fa|0,-R|0)|0;ia=da-R|0}if(ia>>>0<z>>>0){da=ia;ea=ha}else{ba=ha;break}}}}while(0);nrc(O|0,F|0,s)|0;R=P+1|0;if(R>>>0<x>>>0){Q=ba;O=O+E|0;P=R}else{aa=ba;break}}}if((aa-n|0)==(J|0)){ja=aa}else{KIb(b,24,2171120,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if((J|0)<0){ka=0}else{ka=(l|0)<(J|0)?l:J}ja=n+ka|0}if((g-ja|0)>=1){if((a[ja]|0)==12){H=ja+1|0;I=99;break}}KIb(b,16,2143712,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;if((c[b+696>>2]&8|0)!=0){$=-1094995529;break}$=c[k>>2]|0;break}P=(x|0)==0;if(L){if(P){H=C;I=99;break}O=(z<<3)+8|0;Q=g;K=(s|0)==0;M=32-q|0;R=(z|0)==0;N=C;S=D;la=0;while(1){d:do{if(B){ma=Q-N|0;na=ma>>>0>z>>>0?z:ma;nrc(F|0,N|0,na)|0;oa=N+na|0}else{if(R){oa=N;break}else{pa=0;qa=N}while(1){if((g|0)==(qa|0)){oa=g;break d}do{if((Q-qa|0)<1){ra=0;sa=1;ta=qa}else{na=qa+1|0;ma=a[qa]|0;if((ma&255)>>>0<192>>>0|(g|0)==(na|0)){ra=ma;sa=1;ta=na;break}ua=ma&63;if((Q-na|0)<1){ra=0;sa=ua;ta=na;break}ra=a[na]|0;sa=ua;ta=qa+2|0}}while(0);if(pa>>>0>=z>>>0|sa<<24>>24==0){va=pa}else{ua=pa-z|0;na=~(sa-1&255);ma=ua>>>0>na>>>0?ua:na;mrc(F+pa|0,ra|0,-ma|0)|0;va=pa-ma|0}if(va>>>0<z>>>0){pa=va;qa=ta}else{oa=ta;break}}}}while(0);if(!K){ma=0;na=0;while(1){ua=F+(ma>>>3)|0;wa=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(ma&7)>>>(M>>>0);ua=ma+q|0;a[S+na|0]=wa;wa=na+1|0;if(wa>>>0<s>>>0){ma=O>>>0>ua>>>0?ua:O;na=wa}else{break}}}na=la+1|0;if(na>>>0<x>>>0){N=oa;S=S+E|0;la=na}else{H=oa;I=99;break a}}}if(P){H=C;I=99;break}la=g;S=(s|0)==0;N=v-1|0;O=(N|0)>-1;M=(z|0)==0;K=r+1-u|0;Q=C;R=D;L=0;while(1){J=D+(ca(E,L)|0)|0;e:do{if(B){na=la-Q|0;ma=na>>>0>z>>>0?z:na;nrc(F|0,Q|0,ma)|0;xa=Q+ma|0}else{if(M){xa=Q;break}else{ya=0;za=Q}while(1){if((g|0)==(za|0)){xa=g;break e}do{if((la-za|0)<1){Aa=0;Ba=1;Ca=za}else{ma=za+1|0;na=a[za]|0;if((na&255)>>>0<192>>>0|(g|0)==(ma|0)){Aa=na;Ba=1;Ca=ma;break}wa=na&63;if((la-ma|0)<1){Aa=0;Ba=wa;Ca=ma;break}Aa=a[ma]|0;Ba=wa;Ca=za+2|0}}while(0);if(ya>>>0>=z>>>0|Ba<<24>>24==0){Da=ya}else{wa=ya-z|0;ma=~(Ba-1&255);na=wa>>>0>ma>>>0?wa:ma;mrc(F+ya|0,Aa|0,-na|0)|0;Da=ya-na|0}if(Da>>>0<z>>>0){ya=Da;za=Ca}else{xa=Ca;break}}}}while(0);do{if(!S){if(O){Ea=0}else{mrc(J|0,0,K|0)|0;break}do{na=128>>>((Ea&7)>>>0);ma=Ea>>>3;wa=0;ua=N;do{wa=(d[F+((ca(ua,A)|0)+ma)|0]&na|0)!=0|wa<<1;ua=ua-1|0;}while((ua|0)>-1);a[R+Ea|0]=wa;Ea=Ea+1|0;}while(Ea>>>0<s>>>0)}}while(0);J=L+1|0;if(J>>>0<x>>>0){Q=xa;R=R+E|0;L=J}else{H=xa;I=99;break}}}}while(0);if((I|0)==99){E=H;B=E-n|0;do{if(t<<24>>24==1&G){D=c[e+4>>2]|0;C=g-E|0;L=(C>>>0)/3|0;R=C>>>0<768>>>0;Q=R?L:256;if((Q|0)==0){Fa=D;I=104}else{N=C>>>0>770>>>0;C=D;K=0;O=H;while(1){c[C>>2]=d[O]<<16|d[O+1|0]<<8|d[O+2|0]|-16777216;S=K+1|0;if((S|0)<(Q|0)){C=C+4|0;K=S;O=O+3|0}else{break}}if(R){Fa=D+((N?256:L)<<2)|0;I=104}}if((I|0)==104){mrc(Fa|0,0,256-Q<<2|0)|0}Ga=B+768|0}else{if((ca(v,q)|0)==1){O=e+4|0;c[c[O>>2]>>2]=-16777216;c[(c[O>>2]|0)+4>>2]=-1;Ga=B;break}if(!((p&255)>>>0<8>>>0)){Ga=B;break}O=n+((l|0)<16?l:16)|0;K=c[e+4>>2]|0;C=g-O|0;S=(C>>>0)/3|0;la=S>>>0<16>>>0?S:16;if((la|0)==0){Ha=K}else{M=C>>>0>50>>>0;C=K;P=0;J=O;while(1){c[C>>2]=d[J]<<16|d[J+1|0]<<8|d[J+2|0]|-16777216;O=P+1|0;if((O|0)<(la|0)){C=C+4|0;P=O;J=J+3|0}else{break}}if(la>>>0<256>>>0){Ha=K+((M?16:S)<<2)|0}else{Ga=B;break}}mrc(Ha|0,0,256-la<<2|0)|0;Ga=B}}while(0);c[f>>2]=1;$=Ga}kJb(F);m=$;i=h;return m|0}}while(0);KIb(b,16,2295368,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;m=-1094995529;i=h;return m|0}}while(0);KIb(b,16,2448264,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;m=-1094995529;i=h;return m|0}function VWa(a){a=a|0;var b=0,d=0;b=UHb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+88>>2]=1;c[b+84>>2]=1;d=0;return d|0}function WWa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;g=i;i=i+1040|0;h=g|0;j=g+8|0;k=g+16|0;l=b+120|0;m=c[l>>2]|0;do{if((m|0)<=65535){n=b+124|0;o=c[n>>2]|0;if((o|0)>65535){break}p=c[b+140>>2]|0;switch(p|0){case 10:{q=827344;r=1;s=1;t=m;u=o;break};case 2:{q=0;r=8;s=3;t=m;u=o;break};case 22:case 19:case 24:case 21:case 8:{v=k|0;rIb(v,p)|0;q=v;r=8;s=1;t=c[l>>2]|0;u=c[n>>2]|0;break};case 11:{q=c[e+4>>2]|0;r=8;s=1;t=m;u=o;break};default:{KIb(b,16,2359112,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=g;return x|0}}o=((ca(t,r)|0)+7>>3)+1&-2;v=ca(ca(s<<1,u)|0,o)|0;p=(q|0)!=0;z=(p?897:128)+v|0;v=d5a(b,d,z,(z|0)<0|0?-1:0)|0;if((v|0)<0){x=v;i=g;return x|0}v=d+24|0;z=c[v>>2]|0;A=d+28|0;B=z+(c[A>>2]|0)|0;C=c[b+224>>2]|0;c[h>>2]=C;D=c[b+228>>2]|0;c[j>>2]=D;if(C>>>0>65535>>>0|D>>>0>65535>>>0){xKb(h,j,C,(C|0)<0|0?-1:0,D,(D|0)<0|0?-1:0,65535,0)|0}a[z]=10;a[z+1|0]=5;a[z+2|0]=1;a[z+3|0]=r;D=z+4|0;y=0;a[D]=y;y=y>>8;a[D+1|0]=y;D=z+6|0;y=0;a[D]=y;y=y>>8;a[D+1|0]=y;D=z+8|0;y=(c[l>>2]|0)+65535&65535;a[D]=y;y=y>>8;a[D+1|0]=y;D=z+10|0;y=(c[n>>2]|0)+65535&65535;a[D]=y;y=y>>8;a[D+1|0]=y;D=z+12|0;y=c[h>>2]&65535;a[D]=y;y=y>>8;a[D+1|0]=y;D=z+14|0;y=c[j>>2]&65535;a[D]=y;y=y>>8;a[D+1|0]=y;D=z+16|0;if(p){p=D;C=0;while(1){E=c[q+(C<<2)>>2]|0;a[p+2|0]=E;a[p+1|0]=E>>>8;a[p]=E>>>16;E=C+1|0;if((E|0)<16){p=p+3|0;C=E}else{break}}}else{a[z+18|0]=0;a[z+17|0]=0;a[D]=0;a[z+21|0]=0;a[z+20|0]=0;a[z+19|0]=0;a[z+24|0]=0;a[z+23|0]=0;a[z+22|0]=0;a[z+27|0]=0;a[z+26|0]=0;a[z+25|0]=0;a[z+30|0]=0;a[z+29|0]=0;a[z+28|0]=0;a[z+33|0]=0;a[z+32|0]=0;a[z+31|0]=0;a[z+36|0]=0;a[z+35|0]=0;a[z+34|0]=0;a[z+39|0]=0;a[z+38|0]=0;a[z+37|0]=0;a[z+42|0]=0;a[z+41|0]=0;a[z+40|0]=0;a[z+45|0]=0;a[z+44|0]=0;a[z+43|0]=0;a[z+48|0]=0;a[z+47|0]=0;a[z+46|0]=0;a[z+51|0]=0;a[z+50|0]=0;a[z+49|0]=0;a[z+54|0]=0;a[z+53|0]=0;a[z+52|0]=0;a[z+57|0]=0;a[z+56|0]=0;a[z+55|0]=0;a[z+60|0]=0;a[z+59|0]=0;a[z+58|0]=0;a[z+63|0]=0;a[z+62|0]=0;a[z+61|0]=0}a[z+64|0]=0;a[z+65|0]=s;C=z+66|0;y=o&65535;a[C]=y;y=y>>8;a[C+1|0]=y;C=z+68|0;if((C-(c[v>>2]|0)|0)<128){p=C;while(1){E=p+1|0;a[p]=0;if((E-(c[v>>2]|0)|0)<128){p=E}else{F=E;break}}}else{F=C}a:do{if((c[n>>2]|0)>0){p=c[e>>2]|0;z=B;D=s;E=Erc(D<<1|0>>>31,0<<1|D>>>31,o,(o|0)<0|0?-1:0)|0;D=G;H=ca(o,s)|0;I=e+32|0;b:do{if((o|0)>=1){J=F;K=0;L=p;while(1){M=J;N=z-M|0;O=(N|0)<0|0?-1:0;if((O|0)<(D|0)|(O|0)==(D|0)&N>>>0<E>>>0){break b}else{P=0;Q=J}while(1){N=L+(P+H)|0;O=a[L+P|0]|0;R=L+(P+s)|0;S=1;T=Q;while(1){do{if(R>>>0<N>>>0){if(!((a[R]|0)==O<<24>>24&(S|0)<63)){U=23;break}V=O;W=S+1|0;X=T}else{U=23}}while(0);if((U|0)==23){U=0;if((S|0)!=1|(O&255)>>>0>191>>>0){a[T]=S|192;Y=T+1|0}else{Y=T}Z=Y+1|0;a[Y]=O;if((R|0)==(N|0)){break}V=a[R]|0;W=1;X=Z}O=V;R=R+s|0;S=W;T=X}T=P+1|0;if((T|0)<(s|0)){P=T;Q=Z}else{break}}T=Z-M|0;if((T|0)<0){break b}S=J+T|0;T=K+1|0;if((T|0)<(c[n>>2]|0)){J=S;K=T;L=L+(c[I>>2]|0)|0}else{_=S;break a}}}}while(0);KIb(b,16,2295344,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=g;return x|0}else{_=F}}while(0);if((s|0)==1&(r|0)==8){if((B-_|0)<257){KIb(b,16,2295344,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=g;return x|0}a[_]=12;n=_+1|0;o=0;while(1){C=c[q+(o<<2)>>2]|0;a[n+2|0]=C;a[n+1|0]=C>>>8;a[n]=C>>>16;C=o+1|0;if((C|0)<256){n=n+3|0;o=C}else{break}}$=_+769|0}else{$=_}c[A>>2]=$-(c[v>>2]|0);o=d+36|0;c[o>>2]=c[o>>2]|1;c[f>>2]=1;x=0;i=g;return x|0}}while(0);KIb(b,16,2448224,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=g;return x|0}function XWa(a){a=a|0;VHb(a+804|0);return 0}function YWa(a){a=a|0;c[a+140>>2]=11;return 0}function ZWa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;c[g>>2]=0;if((l|0)<3){m=-1;i=j;return m|0}h=k+l|0;n=e+60|0;o=f+24|0;p=f+4|0;q=f+8|0;r=f;s=f+12|0;t=f+16|0;u=e;v=h;w=e+120|0;x=e+124|0;y=k;a:while(1){k=a[y]|0;z=k&255;A=y+3|0;B=y+1|0;C=he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0;B=C&65535;b:do{if(k<<24>>24==-128){D=32}else{if((B|0)>(v-A|0)){m=l;D=67;break a}switch(z|0){case 20:{E=y+(B+3)|0;if(!((C&65535)>>>0>2>>>0)){break b}F=(c[n>>2]|0)+32|0;G=y+5|0;while(1){H=G+5|0;I=(d[G+3|0]|0)-128|0;J=(d[G+2|0]|0)-128|0;K=d[G+1|0]<<10|512;c[F+(d[G]<<2)>>2]=d[((J*1436|0)+K>>10)+1404400|0]<<16|d[G+4|0]<<24|d[((J*-731|0)+K+(I*-352|0)>>10)+1404400|0]<<8|d[((I*1815|0)+K>>10)+1404400|0];if(H>>>0<E>>>0){G=H}else{break}}break};case 23:{break b;break};case 22:{G=c[o>>2]|0;E=c[o+4>>2]|0;F=c[n>>2]|0;H=A;K=(he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;H=y+5|0;I=(he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;H=F+24|0;c[H>>2]=G;c[H+4>>2]=E;E=H4a(e,K,I)|0;if((E|0)<0){m=E;D=67;break a}E=y+8|0;c[F+8>>2]=(he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;E=a[y+13|0]|0;I=E&255;L=F+12|0;c[L>>2]=I;if(E<<24>>24==0){break b}if((B-11|0)<(I<<3|0)){D=24;break a}I=F+16|0;F=I;mJb(I);I=hJb(c[L>>2]<<4)|0;E=I;c[F>>2]=E;if((I|0)==0){D=27;break a}if((c[L>>2]|0)>0){M=y+14|0;N=1;O=0;P=E}else{break b}while(1){E=M;c[P+(O<<4)+8>>2]=(he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;c[P+(O<<4)+12>>2]=d[M+3|0]|0;E=M+4|0;I=(he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;E=P+(O<<4)|0;c[E>>2]=I;K=M+6|0;H=(he((d[K]|d[K+1|0]<<8)<<16>>16|0)|0)&65535;K=P+(O<<4)+4|0;c[K>>2]=H;G=c[w>>2]|0;J=c[x>>2]|0;if((I|0)>(G|0)|(H|0)>(J|0)){KIb(u,16,2202808,(Q=i,i=i+32|0,c[Q>>2]=I,c[Q+8>>2]=H,c[Q+16>>2]=G,c[Q+24>>2]=J,Q)|0);i=Q;c[E>>2]=0;c[K>>2]=0}K=N&65535;if((K|0)>=(c[L>>2]|0)){break b}M=M+8|0;N=N+1&65535;O=K;P=c[F>>2]|0}break};case 128:{D=32;break b;break};case 21:{F=c[n>>2]|0;if((C&65535)>>>0<5>>>0){break b}K=B-4|0;E=A;J=(he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;E=y+7|0;if((a[y+6|0]|0)>-1){G=F+1056|0;H=G+(J*24|0)+20|0;if(K>>>0>(c[H>>2]|0)>>>0){break b}I=G+(J*24|0)+16|0;nrc((c[G+(J*24|0)+8>>2]|0)+(c[I>>2]|0)|0,E|0,K)|0;c[I>>2]=(c[I>>2]|0)+K;c[H>>2]=(c[H>>2]|0)-K;break b}if((K|0)<8){break b}K=B-11|0;H=(d[y+8|0]<<8|d[E]<<16|d[y+9|0])-4|0;E=y+10|0;I=(he((d[E]|d[E+1|0]<<8)<<16>>16|0)|0)&65535;E=y+14|0;G=y+12|0;R=(he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;do{if(!((c[w>>2]|0)>>>0<I>>>0)){if((c[x>>2]|0)>>>0<R>>>0){break}if(K>>>0>H>>>0){KIb(u,16,2143688,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;break b}G=F+1056|0;c[G+(J*24|0)>>2]=I;c[G+(J*24|0)+4>>2]=R;S=G+(J*24|0)+8|0;A4a(S,G+(J*24|0)+12|0,H);T=c[S>>2]|0;if((T|0)==0){break b}nrc(T|0,E|0,K)|0;c[G+(J*24|0)+16>>2]=K;c[G+(J*24|0)+20>>2]=H-K;break b}}while(0);KIb(u,16,2171080,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;break b;break};default:{KIb(u,16,2448176,(Q=i,i=i+16|0,c[Q>>2]=z,c[Q+8>>2]=B,Q)|0);i=Q;break b}}}}while(0);if((D|0)==32){D=0;z=c[n>>2]|0;A=z+24|0;C=c[A>>2]|0;k=c[A+4>>2]|0;if((C|0)==0&(k|0)==(-2147483648|0)){U=c[o+4>>2]|0;V=c[o>>2]|0}else{U=k;V=C}mrc(f|0,0,24)|0;c[o>>2]=V;c[o+4>>2]=U;c[A>>2]=0;c[A+4>>2]=-2147483648;A=z+12|0;c:do{if((c[A>>2]|0)==0){W=1}else{c[p>>2]=0;c[q>>2]=2e4;b[r>>1]=0;C=c[A>>2]|0;c[s>>2]=C;c[t>>2]=pJb(C<<2)|0;if((c[s>>2]|0)==0){W=1;break}C=z+16|0;k=z+1056|0;K=z+1573896|0;H=z+32|0;J=1;E=0;while(1){R=c[(c[C>>2]|0)+(E<<4)+8>>2]|0;I=pJb(100)|0;c[(c[t>>2]|0)+(E<<2)>>2]=I;I=c[C>>2]|0;F=c[(c[t>>2]|0)+(E<<2)>>2]|0;c[F>>2]=c[I+(E<<4)>>2];c[F+4>>2]=c[I+(E<<4)+4>>2];I=R&65535;R=k+(I*24|0)|0;G=c[R>>2]|0;c[F+8>>2]=G;T=c[k+(I*24|0)+4>>2]|0;c[F+12>>2]=T;c[F+84>>2]=1;c[F+52>>2]=c[R>>2];R=k+(I*24|0)+8|0;S=c[R>>2]|0;if((S|0)==0){X=F}else{F=c[k+(I*24|0)+20>>2]|0;Y=k+(I*24|0)+16|0;if((F|0)==0){Z=S;_=G;$=T}else{KIb(u,16,2359056,(Q=i,i=i+16|0,c[Q>>2]=c[Y>>2],c[Q+8>>2]=F,Q)|0);i=Q;F=c[(c[t>>2]|0)+(E<<2)>>2]|0;Z=c[R>>2]|0;_=c[F+8>>2]|0;$=c[F+12>>2]|0}F=Z+(c[Y>>2]|0)|0;Y=hJb(ca(_,$)|0)|0;c[(c[(c[t>>2]|0)+(E<<2)>>2]|0)+20>>2]=Y;Y=c[t>>2]|0;R=c[Y+(E<<2)>>2]|0;if((c[R+20>>2]|0)==0){W=0;break c}T=c[R+12>>2]|0;G=R+8|0;d:do{if((T|0)>0){S=Z;I=0;aa=0;ba=R;da=T;ea=G;fa=Y;while(1){ga=S;ha=aa;ia=ba;ja=da;ka=ea;la=fa;e:while(1){ma=ga;while(1){if(!(ma>>>0<F>>>0)){na=ia;oa=ja;pa=ka;qa=I;break d}ra=ma+1|0;sa=a[ma]|0;if(sa<<24>>24==0){ta=ma+2|0;ua=d[ra]|0;va=ua&63;if((ua&64|0)==0){wa=va;xa=ta}else{wa=d[ta]|va<<8;xa=ma+3|0}if((ua&128|0)==0){ya=0;za=xa}else{ya=a[xa]|0;za=xa+1|0}if((wa|0)>0){Aa=za;Ba=ya;Ca=wa;D=51}else{Da=za;Ea=wa}}else{Aa=ra;Ba=sa;Ca=1;D=51}if((D|0)==51){D=0;Fa=Ca+I|0;if((Fa|0)>(ca(c[ka>>2]|0,ja)|0)){Da=Aa;Ea=Ca}else{break e}}if((Ea|0)==0){break}else{ma=Da}}ma=c[ka>>2]|0;sa=(I|0)%(ma|0)|0;if((sa|0)>0){KIb(u,16,2295288,(Q=i,i=i+16|0,c[Q>>2]=sa,c[Q+8>>2]=ma,Q)|0);i=Q;Ga=c[t>>2]|0}else{Ga=la}ma=ha+1|0;sa=c[Ga+(E<<2)>>2]|0;ra=c[sa+12>>2]|0;ua=sa+8|0;if((ma|0)<(ra|0)){ga=Da;ha=ma;ia=sa;ja=ra;ka=ua;la=Ga}else{na=sa;oa=ra;pa=ua;qa=I;break d}}mrc((c[ia+20>>2]|0)+I|0,Ba|0,Ca|0)|0;la=c[t>>2]|0;ka=c[la+(E<<2)>>2]|0;ja=c[ka+12>>2]|0;ga=ka+8|0;if((ha|0)<(ja|0)){S=Aa;I=Fa;aa=ha;ba=ka;da=ja;ea=ga;fa=la}else{na=ka;oa=ja;pa=ga;qa=Fa;break}}}else{na=R;oa=T;pa=G;qa=0}}while(0);if((qa|0)<(ca(c[pa>>2]|0,oa)|0)){break}else{X=na}}c[X+16>>2]=256;G=pJb(1024)|0;c[(c[(c[t>>2]|0)+(E<<2)>>2]|0)+24>>2]=G;G=(c[C>>2]|0)+(E<<4)+12|0;T=c[(c[t>>2]|0)+(E<<2)>>2]|0;c[T+96>>2]=(c[G>>2]|0)>>>6&1;if((c[K>>2]|0)==0){D=61}else{if((c[G>>2]&64|0)!=0){D=61}}if((D|0)==61){D=0;nrc(c[T+24>>2]|0,H|0,c[T+16>>2]<<2)|0}T=J&65535;if(!(T>>>0<(c[s>>2]|0)>>>0)){W=1;break c}J=J+1&65535;E=T}KIb(u,16,2244360,(Q=i,i=i+1|0,i=i+7&-8,c[Q>>2]=0,Q)|0);i=Q;W=0}}while(0);c[g>>2]=W}z=y+(B+3)|0;if(z>>>0<h>>>0){y=z}else{m=l;D=67;break}}if((D|0)==24){c[L>>2]=0;m=-1094995529;i=j;return m|0}else if((D|0)==27){c[L>>2]=0;m=-12;i=j;return m|0}else if((D|0)==67){i=j;return m|0}return 0}function _Wa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;mJb(b+16|0);c[b+12>>2]=0;a=b+1056|0;b=0;do{d=b&65535;mJb(a+(d*24|0)+8|0);c[a+(d*24|0)+12>>2]=0;b=b+1&65535;}while(!(b<<16>>16==-1));return 0}function $Wa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0;h=i;j=c[b+60>>2]|0;k=e;l=c[g+24>>2]|0;m=g+28|0;g=c[m>>2]|0;if(!((g|0)>-1)){KIb(0,0,2359024,(n=i,i=i+24|0,c[n>>2]=2295272,c[n+8>>2]=2244336,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}o=j+12|0;c[o>>2]=l;p=j+20|0;c[p>>2]=l;q=l+g|0;r=j+16|0;c[r>>2]=q;s=q;if(g>>>0<11>>>0){t=-1094995529;i=h;return t|0}g=l+2|0;c[o>>2]=g;q=l;if(!((d[q]|d[q+1|0]<<8)<<16>>16<<16>>16==4660)){t=-1094995529;i=h;return t|0}q=l+4|0;c[o>>2]=q;u=g;g=(d[u]|d[u+1|0]<<8)<<16>>16&65535;u=j;c[u>>2]=g;v=l+6|0;c[o>>2]=v;w=q;q=(d[w]|d[w+1|0]<<8)<<16>>16&65535;w=j+4|0;c[w>>2]=q;x=s-v|0;v=x>>>0>4>>>0?4:x;x=v+7|0;y=l+x|0;c[o>>2]=y;z=d[l+(v+6)|0]|0;v=z&15;A=(z>>>4)+1|0;z=j+8|0;c[z>>2]=A;j=ca(A,v)|0;do{if(!(v>>>0>8>>>0)){if((j-1|0)>>>0>31>>>0){break}A=s-y|0;if((A|0)<1){B=10}else{if((a[y]|0)==-1){B=11}else{B=10}}if((B|0)==10){if((j|0)==8|(j|0)==4|(j|0)==1){B=11}else{C=-1;D=0}}do{if((B|0)==11){E=A>>>0>2>>>0?2:A;F=l+(x+E)|0;c[o>>2]=F;if((s-F|0)<2){G=0;H=F}else{I=l+(x+(E+2))|0;c[o>>2]=I;E=F;G=(d[E]|d[E+1|0]<<8)<<16>>16&65535;H=I}if((s-H|0)<2){J=0;K=H}else{I=H+2|0;c[o>>2]=I;E=H;J=(d[E]|d[E+1|0]<<8)<<16>>16&65535;K=I}if((s-K|0)>>>0<J>>>0){t=-1094995529}else{C=G;D=J;break}i=h;return t|0}}while(0);c[b+140>>2]=11;if((tIb(g,q,0,b)|0)<0){t=-1;i=h;return t|0}A=c[u>>2]|0;I=b+120|0;do{if((A|0)!=(c[I>>2]|0)){E=c[w>>2]|0;if((E|0)==(c[b+124>>2]|0)){break}F=H4a(b,A,E)|0;if((F|0)<0){t=F}else{break}i=h;return t|0}}while(0);A=M4a(b,k,0)|0;if((A|0)<0){t=A;i=h;return t|0}A=e;F=e+32|0;mrc(c[A>>2]|0,0,ca(c[F>>2]|0,c[w>>2]|0)|0)|0;c[e+88>>2]=1;c[e+304>>2]=1;E=c[o>>2]|0;L=E;M=L-(c[p>>2]|0)+D|0;N=c[e+4>>2]|0;O=N;do{if((C|0)==1&(D|0)>1){if(((c[r>>2]|0)-L|0)<1){P=0}else{if(!((d[E]|0)>>>0<6>>>0)){B=26;break}c[o>>2]=E+1;P=d[E]|0}c[O>>2]=c[1412488+(d[1713080+(P<<2)|0]<<2)>>2];c[N+4>>2]=c[1412488+(d[1713081+(P<<2)|0]<<2)>>2];c[N+8>>2]=c[1412488+(d[1713082+(P<<2)|0]<<2)>>2];c[N+12>>2]=c[1412488+(d[1713083+(P<<2)|0]<<2)>>2];Q=4}else{B=26}}while(0);do{if((B|0)==26){if((C|0)==2){L=(D|0)>16?16:D;if((L|0)<=0){Q=L;break}R=c[r>>2]|0;S=0;T=E;while(1){if((R-T|0)<1){U=0;V=T}else{W=T+1|0;c[o>>2]=W;U=d[T]|0;V=W}c[O+(S<<2)>>2]=c[1412488+((U>>>0>15>>>0?15:U)<<2)>>2];W=S+1|0;if((W|0)<(L|0)){S=W;T=V}else{Q=L;break}}}else if((C|0)==3){L=(D|0)>16?16:D;if((L|0)<=0){Q=L;break}T=c[r>>2]|0;S=0;R=E;while(1){if((T-R|0)<1){X=0;Y=R}else{W=R+1|0;c[o>>2]=W;X=d[R]|0;Y=W}c[O+(S<<2)>>2]=c[1391384+((X>>>0>63>>>0?63:X)<<2)>>2];W=S+1|0;if((W|0)<(L|0)){S=W;R=Y}else{Q=L;break}}}else{if(!((C-4|0)>>>0<2>>>0)){if((j|0)==2){c[O>>2]=c[353122];c[N+4>>2]=c[353125];c[N+8>>2]=c[353127];c[N+12>>2]=c[353129];Q=4;break}else if((j|0)==1){c[O>>2]=-16777216;c[N+4>>2]=-1;Q=2;break}else{nrc(N|0,1412488,64)|0;Q=16;break}}if((D|0)>770){Z=256}else{L=(D|0)/3|0;if((D|0)>2){Z=L}else{Q=L;break}}L=c[r>>2]|0;R=0;S=E;while(1){if((L-S|0)<3){_=0;$=S}else{T=S+3|0;c[o>>2]=T;_=d[S+1|0]<<8|d[S]<<16|d[S+2|0];$=T}c[O+(R<<2)>>2]=_<<2|_>>>4&197379|-16777216;T=R+1|0;if((T|0)<(Z|0)){R=T;S=$}else{Q=Z;break}}}}}while(0);mrc(O+(Q<<2)|0,0,1024-(Q<<2)|0)|0;E=c[r>>2]|0;N=c[p>>2]|0;S=E;R=S-N|0;if((M|0)<0){aa=0}else{aa=(R|0)<(M|0)?R:M}R=N+aa|0;c[o>>2]=R;L=c[w>>2]|0;T=L-1|0;a:do{if((S-R|0)<2){ba=R;B=51}else{W=N+(aa+2)|0;c[o>>2]=W;da=R;if((d[da]|d[da+1|0]<<8)<<16>>16<<16>>16==0){ba=W;B=51;break}da=S-W|0;if(da>>>0>5>>>0){ea=(v|0)==8;fa=(1<<v)-1|0;ga=0;ha=T;ia=0;ja=0;ka=da;da=E;la=W;while(1){W=da;if((W-la|0)<2){ma=0;na=la}else{oa=la+2|0;c[o>>2]=oa;pa=la;ma=(d[pa]|d[pa+1|0]<<8)<<16>>16&65535;na=oa}oa=ka-((ka|0)>(ma|0)?ma:ka)|0;pa=W-na|0;qa=pa>>>0>2>>>0?2:pa;pa=na+qa|0;c[o>>2]=pa;if((W-pa|0)<1){ra=0}else{c[o>>2]=na+(qa+1);ra=d[pa]|0}pa=ja;qa=ia;W=ha;sa=ga;b:while(1){ta=ca(qa,v)|0;ua=pa;va=W;wa=sa;while(1){xa=c[z>>2]|0;if(!ea){ya=ua;break}if((qa|0)>=(xa|0)){za=ua;break b}Aa=c[o>>2]|0;Ba=c[r>>2]|0;Ca=Ba;Da=Ca-Aa|0;if(!(Da>>>0>oa>>>0)){za=ua;break b}if((Da|0)<1){Ea=0;Fa=Aa}else{Da=Aa+1|0;c[o>>2]=Da;Ea=d[Aa]|0;Fa=Da}do{if((Ea|0)==(ra|0)){if((Ca-Fa|0)<1){Ga=Fa;B=70}else{Da=Fa+1|0;c[o>>2]=Da;Aa=a[Fa]|0;if(Aa<<24>>24==0){Ga=Da;B=70}else{Ha=Aa&255;Ia=Da}}do{if((B|0)==70){B=0;if((Ca-Ga|0)<2){Ha=0;Ia=Ga;break}Da=Ga+2|0;c[o>>2]=Da;Aa=Ga;Ha=(d[Aa]|d[Aa+1|0]<<8)<<16>>16&65535;Ia=Da}}while(0);if((Ca-Ia|0)<1){Ja=Ha;Ka=0;La=Ia;break}Da=Ia+1|0;c[o>>2]=Da;Ja=Ha;Ka=d[Ia]|0;La=Da}else{Ja=1;Ka=Ea;La=Fa}}while(0);if((Ba|0)==(La|0)){za=Ka;break b}Ca=Ka&255;Da=Ja;Aa=va;Ma=wa;while(1){if((Da|0)<=0){Na=Ma;break}Oa=c[A>>2]|0;Pa=ca(c[F>>2]|0,Aa)|0;Qa=Da+Ma|0;Ra=c[u>>2]|0;if((Qa|0)<(Ra|0)){B=91;break}Sa=Ra-Ma|0;mrc(Oa+(Pa+Ma)|0,Ca|0,Sa|0)|0;Ra=Aa-1|0;if((Ra|0)<0){break a}else{Da=Da-Sa|0;Aa=Ra;Ma=0}}if((B|0)==91){B=0;mrc(Oa+(Pa+Ma)|0,Ca|0,Da|0)|0;Na=Qa}if((Aa|0)<0){break a}else{ua=Ka;va=Aa;wa=Na}}while(1){if((qa|0)>=(xa|0)){za=ya;break b}ua=c[o>>2]|0;Ba=c[r>>2]|0;Ra=Ba;Sa=Ra-ua|0;if(!(Sa>>>0>oa>>>0)){za=ya;break b}if((Sa|0)<1){Ta=0;Ua=ua}else{Sa=ua+1|0;c[o>>2]=Sa;Ta=d[ua]|0;Ua=Sa}do{if((Ta|0)==(ra|0)){if((Ra-Ua|0)<1){Va=Ua;B=82}else{Sa=Ua+1|0;c[o>>2]=Sa;ua=a[Ua]|0;if(ua<<24>>24==0){Va=Sa;B=82}else{Wa=ua&255;Xa=Sa}}do{if((B|0)==82){B=0;if((Ra-Va|0)<2){Wa=0;Xa=Va;break}Sa=Va+2|0;c[o>>2]=Sa;ua=Va;Wa=(d[ua]|d[ua+1|0]<<8)<<16>>16&65535;Xa=Sa}}while(0);if((Ra-Xa|0)<1){Ya=Wa;Za=0;_a=Xa;break}Sa=Xa+1|0;c[o>>2]=Sa;Ya=Wa;Za=d[Xa]|0;_a=Sa}else{Ya=1;Za=Ta;_a=Ua}}while(0);if((Ba|0)==(_a|0)){za=Za;break b}if((Ya|0)>0){break}else{ya=Za}}Ra=Ya;Aa=Za<<ta;Da=fa<<ta;Ca=qa;Ma=va;Sa=wa;while(1){ua=8;$a=Da;ab=Aa;bb=Ca;cb=Ma;db=Sa;c:while(1){eb=ua-v|0;if((eb|0)>-1){fb=eb;gb=db;hb=cb}else{ib=$a;jb=ab;kb=bb;lb=cb;mb=db;break}while(1){eb=(c[A>>2]|0)+((ca(c[F>>2]|0,hb)|0)+gb)|0;a[eb]=d[eb]|ab>>fb&$a;eb=gb+1|0;if((eb|0)==(c[u>>2]|0)){nb=hb-1|0;if((nb|0)<0){break}else{ob=0;pb=nb}}else{ob=eb;pb=hb}eb=fb-v|0;if((eb|0)>-1){fb=eb;gb=ob;hb=pb}else{ib=$a;jb=ab;kb=bb;lb=pb;mb=ob;break c}}eb=(c[w>>2]|0)-1|0;nb=bb+1|0;qb=ab<<v;rb=$a<<v;if((nb|0)<(c[z>>2]|0)){ua=fb;$a=rb;ab=qb;bb=nb;cb=eb;db=0}else{ib=rb;jb=qb;kb=nb;lb=eb;mb=0;break}}db=Ra-1|0;if((db|0)>0){Ra=db;Aa=jb;Da=ib;Ca=kb;Ma=lb;Sa=mb}else{pa=Za;qa=kb;W=lb;sa=mb;continue b}}}sa=c[o>>2]|0;W=c[r>>2]|0;pa=W-sa|0;if(pa>>>0>5>>>0){ga=wa;ha=va;ia=qa;ja=za;ka=pa;da=W;la=sa}else{sb=wa;tb=va;ub=qa;vb=za;break}}}else{sb=0;tb=T;ub=0;vb=0}la=c[I>>2]|0;if((sb|0)>=(la|0)){break}da=(ca(la,tb+1|0)|0)-sb|0;if((v|0)==8){la=vb&255;ka=da;ja=tb;ia=sb;while(1){if((ka|0)<=0){break a}wb=c[A>>2]|0;xb=ca(c[F>>2]|0,ja)|0;ha=c[u>>2]|0;if((ka+ia|0)<(ha|0)){break}ga=ha-ia|0;mrc(wb+(xb+ia)|0,la|0,ga|0)|0;ha=ja-1|0;if((ha|0)<0){break a}else{ka=ka-ga|0;ja=ha;ia=0}}mrc(wb+(xb+ia)|0,la|0,ka|0)|0;break}ja=(da|0)/(8/(v>>>0)|0|0)|0;ha=ca(ub,v)|0;if((ja|0)<=0){break}ga=ja;ja=vb<<ha;fa=(1<<v)-1<<ha;ha=ub;ea=tb;sa=sb;while(1){W=8;pa=fa;oa=ja;Sa=ha;Ma=ea;Ca=sa;d:while(1){Da=W-v|0;if((Da|0)>-1){yb=Da;zb=Ca;Ab=Ma}else{Bb=pa;Cb=oa;Db=Sa;Eb=Ma;Fb=Ca;break}while(1){Da=(c[A>>2]|0)+((ca(c[F>>2]|0,Ab)|0)+zb)|0;a[Da]=d[Da]|oa>>yb&pa;Da=zb+1|0;if((Da|0)==(c[u>>2]|0)){Aa=Ab-1|0;if((Aa|0)<0){break}else{Gb=0;Hb=Aa}}else{Gb=Da;Hb=Ab}Da=yb-v|0;if((Da|0)>-1){yb=Da;zb=Gb;Ab=Hb}else{Bb=pa;Cb=oa;Db=Sa;Eb=Hb;Fb=Gb;break d}}Da=(c[w>>2]|0)-1|0;Aa=Sa+1|0;Ra=oa<<v;ta=pa<<v;if((Aa|0)<(c[z>>2]|0)){W=yb;pa=ta;oa=Ra;Sa=Aa;Ma=Da;Ca=0}else{Bb=ta;Cb=Ra;Db=Aa;Eb=Da;Fb=0;break}}Ca=ga-1|0;if((Ca|0)>0){ga=Ca;ja=Cb;fa=Bb;ha=Db;ea=Eb;sa=Fb}else{break}}}}while(0);e:do{if((B|0)==51){if((L|0)>0){Ib=T;Jb=ba;Kb=E}else{break}while(1){S=Kb-Jb|0;if((Kb|0)==(Jb|0)){break e}R=(c[A>>2]|0)+(ca(c[F>>2]|0,Ib)|0)|0;N=c[I>>2]|0;nrc(R|0,Jb|0,N>>>0>S>>>0?S:N)|0;N=c[I>>2]|0;S=c[r>>2]|0;R=c[o>>2]|0;M=S-R|0;O=R+(M>>>0>N>>>0?N:M)|0;c[o>>2]=O;if((Ib|0)>0){Ib=Ib-1|0;Jb=O;Kb=S}else{break}}}}while(0);c[f>>2]=1;t=c[m>>2]|0;i=h;return t|0}}while(0);QIb(b,2448152,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;t=-1163346256;i=h;return t|0}function aXa(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((e|0)>0){g=0}else{return}do{h=g-f|0;i=a[b+h|0]|0;j=a[d+g|0]|0;k=a[d+h|0]|0;h=k&255;l=(j&255)-h|0;m=(i&255)-h|0;h=(l|0)>-1?l:-l|0;n=(m|0)>-1?m:-m|0;o=l+m|0;m=(o|0)>-1?o:-o|0;if((h|0)>(n|0)|(h|0)>(m|0)){p=(n|0)>(m|0)?k:j}else{p=i}a[b+g|0]=(a[c+g|0]|0)+p;g=g+1|0;}while((g|0)<(e|0));return}function bXa(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;c[b+8>>2]=a;d=b+24|0;c[d>>2]=UHb()|0;e=UHb()|0;c[b+36>>2]=e;if((c[d>>2]|0)==0|(e|0)==0){f=-12;return f|0}e=c[a+64>>2]|0;if((c[e>>2]|0)!=0){f=0;return f|0}c[e+4>>2]=1;gXa(b);f=0;return f|0}function cXa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0;j=i;i=i+24|0;k=j|0;l=c[e+60>>2]|0;m=c[h+24>>2]|0;n=c[h+28>>2]|0;c[k>>2]=0;o=l+24|0;p=o;H5a(e,p);q=j+8|0;c[q>>2]=c[o>>2];c[q+4>>2]=c[o+4>>2];c[q+8>>2]=c[o+8>>2];r=l+36|0;s=r;c[o>>2]=c[r>>2];c[o+4>>2]=c[r+4>>2];c[o+8>>2]=c[r+8>>2];c[r>>2]=c[q>>2];c[r+4>>2]=c[q+4>>2];c[r+8>>2]=c[q+8>>2];q=r;r=c[q>>2]|0;if(!((n|0)>-1)){KIb(0,0,2477672,(t=i,i=i+24|0,c[t>>2]=2468176,c[t+8>>2]=2458600,c[t+16>>2]=135,t)|0);i=t;Hd();return 0}u=l+12|0;c[u>>2]=m;v=l+20|0;c[v>>2]=m;w=l+16|0;c[w>>2]=m+n;do{if((n|0)>=8){c[u>>2]=m+8;x=m;y=x|0;z=x+4|0;x=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=je(x|0)|0;x=z|0;if(!((y|0)==218765834&(x|0)==(-1974645177|0)|(y|0)==218765834&(x|0)==(-1991225785|0))){break}x=l+48|0;c[x>>2]=0;y=l+1168|0;c[y>>2]=0;z=l+1172|0;A=z;c[l+1204>>2]=58;c[l+1208>>2]=34;c[l+1212>>2]=0;B=_pc(A,2359016,56)|0;if((B|0)!=0){KIb(e,16,2295240,(t=i,i=i+8|0,c[t>>2]=B,t)|0);i=t;C=-542398533;i=j;return C|0}B=c[u>>2]|0;D=c[w>>2]|0;a:do{if((D|0)==(B|0)){E=e;F=l+1124|0;G=11}else{H=e+688|0;I=l+52|0;J=l+56|0;K=e;L=l+60|0;M=l+64|0;N=l+68|0;O=l+76|0;P=l+72|0;Q=e+224|0;R=e+228|0;S=e+120|0;T=e+124|0;U=l+80|0;V=l+84|0;W=l+88|0;X=l+1160|0;Y=e+140|0;Z=r+88|0;_=r+84|0;$=r+296|0;aa=l+1156|0;ba=r|0;da=l+92|0;ea=r+32|0;fa=l+96|0;ga=r+4|0;ha=l+100|0;ia=l+1128|0;ja=ia;ka=l+1132|0;la=l+1136|0;ma=la;na=l+1140|0;oa=l+1144|0;pa=oa;qa=l+1148|0;ra=l+1124|0;sa=l+1188|0;ta=l+1184|0;ua=l+1152|0;va=l+1164|0;wa=l+1176|0;xa=z;ya=l;za=ha;Aa=D;Ba=B;b:while(1){Ca=Aa;if((Ca-Ba|0)<4){Da=0;Ea=Ba}else{Fa=Ba+4|0;c[u>>2]=Fa;Ga=Ba;Ha=je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0;if((Ha|0)<0){G=15;break}if(Ha>>>0>(Ca-Fa|0)>>>0){G=15;break}else{Da=Ha;Ea=Fa}}if((Ca-Ea|0)<4){Ia=0}else{c[u>>2]=Ea+4;Ca=Ea;Ia=d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0}if((c[H>>2]&256|0)!=0){KIb(K,48,2170992,(t=i,i=i+40|0,c[t>>2]=Ia&255,c[t+8>>2]=Ia>>>8&255,c[t+16>>2]=Ia>>>16&255,c[t+24>>2]=Ia>>>24,c[t+32>>2]=Da,t)|0);i=t}do{if((Ia|0)==1380206665){if((Da|0)!=13){Ja=ra;G=243;break a}Ca=c[u>>2]|0;Fa=c[w>>2]|0;if((Fa-Ca|0)<4){Ka=0;La=Ca}else{Ha=Ca+4|0;c[u>>2]=Ha;Ga=Ca;Ka=je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0;La=Ha}c[I>>2]=Ka;if((Fa-La|0)<4){Ma=0}else{c[u>>2]=La+4;Fa=La;Ma=je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0}c[J>>2]=Ma;if((tIb(Ka,Ma,0,K)|0)!=0){G=27;break b}Fa=c[w>>2]|0;Ha=c[u>>2]|0;Ga=Fa;if((Ga-Ha|0)<1){Na=0;Oa=Ha}else{Ca=Ha+1|0;c[u>>2]=Ca;Na=d[Ha]|0;Oa=Ca}c[L>>2]=Na;if((Ga-Oa|0)<1){Pa=0;Qa=Oa}else{Ca=Oa+1|0;c[u>>2]=Ca;Pa=d[Oa]|0;Qa=Ca}c[M>>2]=Pa;if((Ga-Qa|0)<1){Ra=0;Sa=Qa}else{Ca=Qa+1|0;c[u>>2]=Ca;Ra=d[Qa]|0;Sa=Ca}c[N>>2]=Ra;if((Ga-Sa|0)<1){Ta=0;Ua=Sa}else{Ca=Sa+1|0;c[u>>2]=Ca;Ta=d[Sa]|0;Ua=Ca}c[O>>2]=Ta;if((Ga-Ua|0)<1){Va=0;Wa=Ua}else{Ca=Ua+1|0;c[u>>2]=Ca;Va=d[Ua]|0;Wa=Ca}c[P>>2]=Va;Ca=Ga-Wa|0;Ga=Wa+(Ca>>>0>4>>>0?4:Ca)|0;c[u>>2]=Ga;c[x>>2]=c[x>>2]|1;if((c[H>>2]&1|0)==0){Xa=Ga;Ya=Fa;break}Fa=c[J>>2]|0;KIb(K,48,2120088,(t=i,i=i+56|0,c[t>>2]=c[I>>2],c[t+8>>2]=Fa,c[t+16>>2]=Na,c[t+24>>2]=Pa,c[t+32>>2]=Ra,c[t+40>>2]=Ta,c[t+48>>2]=Va,t)|0);i=t;Xa=c[u>>2]|0;Ya=c[w>>2]|0}else if((Ia|0)==1145980233){G=176;break b}else if((Ia|0)==1397641844){if((c[M>>2]|0)!=3|Da>>>0>256>>>0){G=180;break}if((c[x>>2]&8|0)==0){G=180;break}Fa=c[w>>2]|0;Ga=c[u>>2]|0;Ca=Fa-Ga|0;if((Da|0)==0){Za=Ga;_a=Ca;$a=Fa}else{Fa=0;Ha=Ga;Ga=Ca;while(1){if((Ga|0)<1){ab=0}else{c[u>>2]=Ha+1;ab=(d[Ha]|0)<<24}Ca=za+(Fa<<2)|0;c[Ca>>2]=c[Ca>>2]&16777215|ab;Ca=Fa+1|0;bb=c[w>>2]|0;cb=c[u>>2]|0;db=bb-cb|0;if(Ca>>>0<Da>>>0){Fa=Ca;Ha=cb;Ga=db}else{Za=cb;_a=db;$a=bb;break}}}Ga=Za+(_a>>>0>4>>>0?4:_a)|0;c[u>>2]=Ga;Xa=Ga;Ya=$a}else if((Ia|0)==1935231088){if((c[x>>2]&2|0)!=0){G=42;break b}Ga=c[w>>2]|0;Ha=c[u>>2]|0;Fa=Ga;if((Fa-Ha|0)<4){eb=0;fb=Ha}else{bb=Ha+4|0;c[u>>2]=bb;db=Ha;eb=je(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0;fb=bb}c[Q>>2]=eb;if((Fa-fb|0)<4){gb=0;hb=fb}else{Fa=fb+4|0;c[u>>2]=Fa;bb=fb;gb=je(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0;hb=Fa}c[R>>2]=gb;if((eb|gb|0)<0){c[Q>>2]=0;c[R>>2]=1;ib=c[w>>2]|0;jb=c[u>>2]|0}else{ib=Ga;jb=hb}Ga=ib;Fa=Ga-jb|0;bb=Fa>>>0>1>>>0?1:Fa;Fa=Ga-(jb+bb)|0;Ga=jb+((Fa>>>0>4>>>0?4:Fa)+bb)|0;c[u>>2]=Ga;Xa=Ga;Ya=ib}else if((Ia|0)==1951942004){if((eXa(c[u>>2]|0,Da,0,k)|0)<0){KIb(K,24,2566720,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}Ga=Da+4|0;bb=c[w>>2]|0;Fa=c[u>>2]|0;db=bb-Fa|0;Ha=Fa+(db>>>0>Ga>>>0?Ga:db)|0;c[u>>2]=Ha;Xa=Ha;Ya=bb}else if((Ia|0)==1163152464){if(((Da>>>0)%3|0|0)!=0|Da>>>0>768>>>0){G=180;break}bb=(Da>>>0)/3|0;if(Da>>>0>2>>>0){Ha=bb>>>0>1>>>0;db=0;do{Ga=c[u>>2]|0;Fa=c[w>>2]|0;if((Fa-Ga|0)<1){kb=-16777216;lb=Ga}else{cb=Ga+1|0;c[u>>2]=cb;kb=(d[Ga]|0)<<16|-16777216;lb=cb}if((Fa-lb|0)<1){mb=0;nb=lb}else{cb=lb+1|0;c[u>>2]=cb;mb=(d[lb]|0)<<8;nb=cb}if((Fa-nb|0)<1){ob=0}else{c[u>>2]=nb+1;ob=d[nb]|0}c[za+(db<<2)>>2]=kb|mb|ob;db=db+1|0;}while((db|0)<(bb|0));db=Ha?bb:1;if(db>>>0<256>>>0){pb=db;G=161}}else{pb=0;G=161}if((G|0)==161){while(1){G=0;c[za+(pb<<2)>>2]=-16777216;db=pb+1|0;if((db|0)<256){pb=db;G=161}else{break}}}c[x>>2]=c[x>>2]|8;bb=c[w>>2]|0;Ha=c[u>>2]|0;db=bb-Ha|0;Fa=Ha+(db>>>0>4>>>0?4:db)|0;c[u>>2]=Fa;Xa=Fa;Ya=bb}else if((Ia|0)==1951945850){if((eXa(c[u>>2]|0,Da,1,k)|0)<0){KIb(K,24,2548448,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t}bb=Da+4|0;Fa=c[w>>2]|0;db=c[u>>2]|0;Ha=Fa-db|0;cb=db+(Ha>>>0>bb>>>0?bb:Ha)|0;c[u>>2]=cb;Xa=cb;Ya=Fa}else if((Ia|0)==1413563465){Fa=c[x>>2]|0;if((Fa&1|0)==0){G=51;break b}if((Fa&2|0)==0){c[S>>2]=c[I>>2];c[T>>2]=c[J>>2];cb=Irb(c[M>>2]|0)|0;c[U>>2]=cb;qb=c[L>>2]|0;Ha=ca(qb,cb)|0;c[V>>2]=Ha;c[W>>2]=Ha+7>>3;c[X>>2]=(ca(Ha,c[S>>2]|0)|0)+7>>3;do{if((qb|0)==2|(qb|0)==4|(qb|0)==8){if((c[M>>2]|0)==2){c[Y>>2]=2;break}if((qb|0)==16){G=63;break}else if(!((qb|0)==2|(qb|0)==4|(qb|0)==8)){G=68;break}if((c[M>>2]|0)==6){c[Y>>2]=28;break}if((qb|0)==16){G=63;break}else if(!((qb|0)==2|(qb|0)==4|(qb|0)==8)){G=68;break}if((c[M>>2]|0)==0){c[Y>>2]=8;break}else{if((qb|0)==16){G=63;break}else{G=68;break}}}else if((qb|0)==16){G=63}else{G=68}}while(0);do{if((G|0)==63){G=0;if((c[M>>2]|0)==0){c[Y>>2]=31;break}cb=c[M>>2]|0;if((cb|0)==2){c[Y>>2]=41;break}else if((cb|0)==6){c[Y>>2]=291;break}else{G=68;break}}}while(0);c:do{if((G|0)==68){G=0;do{if((Ha|0)==1|(Ha|0)==2|(Ha|0)==4|(Ha|0)==8){if((c[M>>2]|0)!=3){break}c[Y>>2]=11;break c}}while(0);if((qb|0)==1){c[Y>>2]=10;break}else if((qb|0)!=8){G=72;break b}cb=c[M>>2]|0;if((cb|0)!=4){rb=cb;break b}c[Y>>2]=66}}while(0);if((J5a(e,s,1)|0)<0){Ja=ra;G=243;break a}K5a(e);c[Z>>2]=1;c[_>>2]=1;c[$>>2]=(c[P>>2]|0)!=0;if((c[P>>2]|0)==0){sb=c[X>>2]|0}else{c[ua>>2]=0;Ha=Jrb(0,c[V>>2]|0,c[I>>2]|0)|0;c[va>>2]=Ha;sb=Ha}c[aa>>2]=sb+1;c[da>>2]=c[ba>>2];c[fa>>2]=c[ea>>2];if((c[Y>>2]|0)==11){nrc(c[ga>>2]|0,ha|0,1024)|0}B4a(ia,ka,c[X>>2]|0);if((c[ja>>2]|0)==0){Ja=ra;G=243;break a}if((c[P>>2]|0)==0){if((c[M>>2]|0)==6){G=86}}else{G=86}if((G|0)==86){G=0;A4a(la,na,c[X>>2]|0);if((c[ma>>2]|0)==0){Ja=ra;G=243;break a}}A4a(oa,qa,(c[X>>2]|0)+16|0);Ha=c[pa>>2]|0;if((Ha|0)==0){Ja=ra;G=243;break a}cb=Ha+15|0;c[ra>>2]=cb;c[sa>>2]=c[aa>>2];c[ta>>2]=cb;tb=c[x>>2]|0}else{tb=Fa}c[x>>2]=tb|2;cb=c[u>>2]|0;Ha=(c[w>>2]|0)-cb|0;bb=Ha>>>0<Da>>>0?Ha:Da;c[wa>>2]=bb;c[xa>>2]=cb;c[u>>2]=cb+(Ha>>>0>Da>>>0?Da:Ha);Ha=bb;while(1){if((Ha|0)==0){break}ub=$pc(A,1)|0;if(ub>>>0>1>>>0){G=148;break b}if((c[sa>>2]|0)==0){d:do{if((c[x>>2]&4|0)==0){if((c[P>>2]|0)==0){bb=c[da>>2]|0;cb=c[fa>>2]|0;db=c[y>>2]|0;Ga=ca(db,cb)|0;Ca=bb+Ga|0;if((db|0)==0){vb=c[ja>>2]|0}else{vb=bb+(Ga-cb)|0}cb=c[ra>>2]|0;fXa(ya,Ca,d[cb]|0,cb+1|0,vb,c[X>>2]|0,c[W>>2]|0);do{if((c[O>>2]|0)==64){if((c[y>>2]|0)<=0){break}cb=Ga-(c[fa>>2]|0)|0;if((c[L>>2]|0)==16){db=bb+cb|0;wb=c[X>>2]|0;xb=(wb|0)/2|0;if((wb|0)<=1){break}wb=(c[M>>2]|0)==6?4:3;yb=0;do{zb=b[db+(yb+1<<1)>>1]|0;Ab=db+(yb<<1)|0;b[Ab>>1]=(b[Ab>>1]|0)+zb;Ab=db+(yb+2<<1)|0;b[Ab>>1]=(b[Ab>>1]|0)+zb;yb=yb+wb|0;}while((yb|0)<(xb|0))}else{xb=c[X>>2]|0;if((xb|0)<=0){break}yb=(c[M>>2]|0)==6?4:3;wb=cb+1|0;db=cb+2|0;zb=0;do{Ab=a[bb+(wb+zb)|0]|0;Bb=bb+(zb+cb)|0;a[Bb]=(a[Bb]|0)+Ab;Bb=bb+(db+zb)|0;a[Bb]=(a[Bb]|0)+Ab;zb=zb+yb|0;}while((zb|0)<(xb|0))}}}while(0);xb=(c[y>>2]|0)+1|0;c[y>>2]=xb;if((xb|0)!=(c[J>>2]|0)){break}c[x>>2]=c[x>>2]|4;if((c[O>>2]|0)!=64){break}if((c[L>>2]|0)==16){xb=Ca;zb=c[X>>2]|0;yb=(zb|0)/2|0;if((zb|0)<=1){break}zb=(c[M>>2]|0)==6?4:3;db=0;while(1){cb=b[xb+(db+1<<1)>>1]|0;wb=xb+(db<<1)|0;b[wb>>1]=(b[wb>>1]|0)+cb;wb=xb+(db+2<<1)|0;b[wb>>1]=(b[wb>>1]|0)+cb;db=db+zb|0;if((db|0)>=(yb|0)){break d}}}else{yb=c[X>>2]|0;if((yb|0)<=0){break}db=(c[M>>2]|0)==6?4:3;zb=Ga+1|0;xb=Ga+2|0;Ca=0;while(1){cb=a[bb+(zb+Ca)|0]|0;wb=bb+(Ca+Ga)|0;a[wb]=(a[wb]|0)+cb;wb=bb+(xb+Ca)|0;a[wb]=(a[wb]|0)+cb;Ca=Ca+db|0;if((Ca|0)>=(yb|0)){break d}}}}else{Cb=0}e:while(1){yb=c[da>>2]|0;Ca=c[y>>2]|0;db=ca(Ca,c[fa>>2]|0)|0;xb=yb+db|0;bb=c[ua>>2]|0;if(((d[1323224+bb|0]|0)&128>>>((Ca&7)>>>0)|0)==0){Db=Cb;Eb=bb;Fb=Ca}else{if((Cb|0)!=0){break d}Ca=c[ra>>2]|0;fXa(ya,c[ma>>2]|0,d[Ca]|0,Ca+1|0,c[ja>>2]|0,c[va>>2]|0,c[W>>2]|0);Ca=c[ma>>2]|0;c[ma>>2]=c[ja>>2];c[ja>>2]=Ca;Ca=c[na>>2]|0;c[na>>2]=c[ka>>2];c[ka>>2]=Ca;Db=1;Eb=c[ua>>2]|0;Fb=c[y>>2]|0}do{if(((d[704184+Eb|0]|0)&128>>>((Fb&7)>>>0)|0)!=0){Ca=c[I>>2]|0;bb=c[V>>2]|0;Ga=c[ja>>2]|0;zb=d[704176+Eb|0]|0;cb=d[704192+Eb|0]|0;if((bb|0)==4){if((Ca|0)>0){Gb=0;Hb=0}else{break}while(1){wb=Hb<<2&4;Ab=128>>>((Hb&7)>>>0);if((Ab&cb|0)!=0){Bb=yb+((Hb>>1)+db)|0;a[Bb]=((d[Ga+(Gb>>1)|0]|0)>>>((Gb<<2&4^4)>>>0)&15)<<4-wb|(d[Bb]|0)&65295>>>(wb>>>0)}wb=Hb+1|0;if((wb|0)<(Ca|0)){Gb=((Ab&zb|0)!=0)+Gb|0;Hb=wb}else{break}}}else if((bb|0)==2){if((Ca|0)>0){Ib=0;Jb=0}else{break}while(1){wb=Jb<<1&6;Ab=128>>>((Jb&7)>>>0);if((Ab&cb|0)!=0){Bb=yb+((Jb>>2)+db)|0;a[Bb]=((d[Ga+(Ib>>2)|0]|0)>>>((Ib<<1&6^6)>>>0)&3)<<6-wb|(d[Bb]|0)&65343>>>(wb>>>0)}wb=Jb+1|0;if((wb|0)<(Ca|0)){Ib=((Ab&zb|0)!=0)+Ib|0;Jb=wb}else{break}}}else if((bb|0)==1){if((Ca|0)>0){Kb=0;Lb=0}else{break}while(1){wb=Lb&7;Ab=128>>>(wb>>>0);if((Ab&cb|0)!=0){Bb=yb+((Lb>>3)+db)|0;a[Bb]=((d[Ga+(Kb>>3)|0]|0)>>>((Kb&7^7)>>>0)&1)<<(wb^7)|(d[Bb]|0)&65407>>>(wb>>>0)}wb=Lb+1|0;if((wb|0)<(Ca|0)){Kb=((Ab&zb|0)!=0)+Kb|0;Lb=wb}else{break}}}else{wb=bb>>3;if((Ca|0)>0){Mb=xb;Nb=Ga;Ob=0}else{break}while(1){Ab=128>>>((Ob&7)>>>0);if((Ab&cb|0)!=0){nrc(Mb|0,Nb|0,wb)|0}if((Ab&zb|0)==0){Pb=Nb}else{Pb=Nb+wb|0}Ab=Ob+1|0;if((Ab|0)<(Ca|0)){Mb=Mb+wb|0;Nb=Pb;Ob=Ab}else{break}}}}}while(0);xb=(c[y>>2]|0)+1|0;c[y>>2]=xb;if((xb|0)!=(c[J>>2]|0)){Cb=Db;continue}mrc(c[ja>>2]|0,0,c[X>>2]|0)|0;while(1){xb=c[ua>>2]|0;if((xb|0)==6){break e}db=xb+1|0;c[ua>>2]=db;c[y>>2]=0;xb=Jrb(db,c[V>>2]|0,c[I>>2]|0)|0;c[va>>2]=xb;c[aa>>2]=xb+1;if((xb|0)!=0){Cb=Db;continue e}}}c[x>>2]=c[x>>2]|4}}while(0);c[sa>>2]=c[aa>>2];c[ta>>2]=c[ra>>2]}Qb=c[wa>>2]|0;if((ub|0)==1){G=146;break}else{Ha=Qb}}do{if((G|0)==146){G=0;if((Qb|0)==0){break}KIb(0,24,2488632,(t=i,i=i+8|0,c[t>>2]=Qb,t)|0);i=t}}while(0);Ha=c[w>>2]|0;Fa=c[u>>2]|0;xb=Ha-Fa|0;db=Fa+(xb>>>0>4>>>0?4:xb)|0;c[u>>2]=db;Xa=db;Ya=Ha}else{G=180}}while(0);if((G|0)==180){G=0;Ha=Da+4|0;db=c[w>>2]|0;xb=c[u>>2]|0;Fa=db-xb|0;yb=xb+(Fa>>>0>Ha>>>0?Ha:Fa)|0;c[u>>2]=yb;Xa=yb;Ya=db}if((Ya|0)==(Xa|0)){E=K;F=ra;G=11;break a}else{Aa=Ya;Ba=Xa}}if((G|0)==15){KIb(K,16,2202792,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Ja=ra;G=243;break}else if((G|0)==27){c[J>>2]=0;c[I>>2]=0;KIb(K,16,2143592,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Ja=ra;G=243;break}else if((G|0)==42){KIb(K,16,2638080,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Ja=ra;G=243;break}else if((G|0)==51){KIb(K,16,2614960,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Ja=ra;G=243;break}else if((G|0)==72){rb=c[M>>2]|0}else if((G|0)==148){KIb(c[l+8>>2]|0,16,2501488,(t=i,i=i+8|0,c[t>>2]=ub,t)|0);i=t;Ja=ra;G=243;break}else if((G|0)==176){Ba=c[x>>2]|0;if((Ba&4|0)==0){KIb(K,16,2530632,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Rb=c[x>>2]|0}else{Rb=Ba}if((Rb&6|0)==0){Ja=ra;G=243;break}Ba=c[u>>2]|0;Aa=(c[w>>2]|0)-Ba|0;c[u>>2]=Ba+(Aa>>>0>4>>>0?4:Aa);Aa=c[V>>2]|0;do{if((Aa|0)==1){if((c[M>>2]|0)!=3){break}if((c[J>>2]|0)<=0){break}Ba=1;wa=c[ba>>2]|0;while(1){ta=c[I>>2]|0;aa=(ta|0)/8|0;sa=wa+aa|0;va=aa<<3;if((ta&7|0)==7){a[wa+(va|6)|0]=(d[sa]|0)>>>1&1;Sb=c[I>>2]|0}else{Sb=ta}if((Sb&6)>>>0<6>>>0){Tb=Sb}else{a[wa+(va|5)|0]=(d[sa]|0)>>>2&1;Tb=c[I>>2]|0}if((Tb&7)>>>0<5>>>0){Ub=Tb}else{a[wa+(va|4)|0]=(d[sa]|0)>>>3&1;Ub=c[I>>2]|0}if((Ub&4)>>>0<4>>>0){Vb=Ub}else{a[wa+(va|3)|0]=(d[sa]|0)>>>4&1;Vb=c[I>>2]|0}if((Vb&7)>>>0<3>>>0){Wb=Vb}else{a[wa+(va|2)|0]=(d[sa]|0)>>>5&1;Wb=c[I>>2]|0}if((Wb&6)>>>0<2>>>0){Xb=Wb}else{a[wa+(va|1)|0]=(d[sa]|0)>>>6&1;Xb=c[I>>2]|0}if((Xb&7|0)!=0){a[wa+va|0]=(d[sa]|0)>>>7}if((ta|0)>7){ta=aa;do{ta=ta-1|0;aa=wa+ta|0;sa=ta<<3;a[wa+(sa|7)|0]=a[aa]&1;a[wa+(sa|6)|0]=(d[aa]|0)>>>1&1;a[wa+(sa|5)|0]=(d[aa]|0)>>>2&1;a[wa+(sa|4)|0]=(d[aa]|0)>>>3&1;a[wa+(sa|3)|0]=(d[aa]|0)>>>4&1;a[wa+(sa|2)|0]=(d[aa]|0)>>>5&1;a[wa+(sa|1)|0]=(d[aa]|0)>>>6&1;a[wa+sa|0]=(d[aa]|0)>>>7;}while((ta|0)>0)}if((Ba|0)>=(c[J>>2]|0)){break}Ba=Ba+1|0;wa=wa+(c[fa>>2]|0)|0}Yb=c[V>>2]|0;G=191}else{Yb=Aa;G=191}}while(0);f:do{if((G|0)==191){do{if((Yb|0)==2){if((c[J>>2]|0)<=0){Zb=Yb;break}Aa=1;wa=c[ba>>2]|0;while(1){Ba=c[I>>2]|0;ta=(Ba|0)/4|0;aa=(Ba&3|0)==3;do{if((c[M>>2]|0)==3){if(aa){a[wa+(ta<<2|2)|0]=(d[wa+ta|0]|0)>>>2&3;_b=c[I>>2]|0}else{_b=Ba}if((_b&2)>>>0>1>>>0){a[wa+(ta<<2|1)|0]=(d[wa+ta|0]|0)>>>4&3;$b=c[I>>2]|0}else{$b=_b}if(($b&3|0)!=0){a[wa+(ta<<2)|0]=(d[wa+ta|0]|0)>>>6}if((Ba|0)>3){ac=ta}else{break}do{ac=ac-1|0;sa=wa+ac|0;va=ac<<2;a[wa+(va|3)|0]=a[sa]&3;a[wa+(va|2)|0]=(d[sa]|0)>>>2&3;a[wa+(va|1)|0]=(d[sa]|0)>>>4&3;a[wa+va|0]=(d[sa]|0)>>>6;}while((ac|0)>0)}else{if(aa){a[wa+(ta<<2|2)|0]=((d[wa+ta|0]|0)>>>2&3)*85;bc=c[I>>2]|0}else{bc=Ba}if((bc&2)>>>0>1>>>0){a[wa+(ta<<2|1)|0]=((d[wa+ta|0]|0)>>>4&3)*85;cc=c[I>>2]|0}else{cc=bc}if((cc&3|0)!=0){a[wa+(ta<<2)|0]=((d[wa+ta|0]|0)>>>6)*85}if((Ba|0)>3){dc=ta}else{break}do{dc=dc-1|0;sa=wa+dc|0;va=dc<<2;a[wa+(va|3)|0]=(a[sa]&3)*85;a[wa+(va|2)|0]=((d[sa]|0)>>>2&3)*85;a[wa+(va|1)|0]=((d[sa]|0)>>>4&3)*85;a[wa+va|0]=((d[sa]|0)>>>6)*85;}while((dc|0)>0)}}while(0);if((Aa|0)>=(c[J>>2]|0)){break}Aa=Aa+1|0;wa=wa+(c[fa>>2]|0)|0}Zb=c[V>>2]|0}else{Zb=Yb}}while(0);if((Zb|0)!=4){break}if((c[J>>2]|0)<=0){break}wa=1;Aa=c[ba>>2]|0;while(1){ta=c[I>>2]|0;Ba=(ta|0)/2|0;aa=(ta&1|0)!=0;do{if((c[M>>2]|0)==3){if(aa){a[Aa+(Ba<<1)|0]=(d[Aa+Ba|0]|0)>>>4}if((ta|0)>1){ec=Ba}else{break}do{ec=ec-1|0;sa=Aa+ec|0;va=ec<<1;a[Aa+(va|1)|0]=a[sa]&15;a[Aa+va|0]=(d[sa]|0)>>>4;}while((ec|0)>0)}else{if(aa){a[Aa+(Ba<<1)|0]=((d[Aa+Ba|0]|0)>>>4)*17}if((ta|0)>1){fc=Ba}else{break}do{fc=fc-1|0;sa=Aa+fc|0;va=fc<<1;a[Aa+(va|1)|0]=(a[sa]&15)*17;a[Aa+va|0]=((d[sa]|0)>>>4)*17;}while((fc|0)>0)}}while(0);if((wa|0)>=(c[J>>2]|0)){break f}wa=wa+1|0;Aa=Aa+(c[fa>>2]|0)|0}}}while(0);M=c[o>>2]|0;V=c[M>>2]|0;do{if((V|0)!=0){if((c[h+36>>2]&1|0)!=0){break}if((c[e+52>>2]|0)==1196314701){break}if((c[M+68>>2]|0)!=(c[r+68>>2]|0)){break}if((c[M+72>>2]|0)!=(c[r+72>>2]|0)){break}if((c[M+80>>2]|0)!=(c[r+80>>2]|0)){break}Aa=c[ba>>2]|0;M5a(p,2147483647,0);wa=c[J>>2]|0;if((wa|0)<=0){break}Ba=0;ta=Aa;Aa=V;aa=c[I>>2]|0;sa=c[W>>2]|0;va=wa;while(1){if((ca(sa,aa)|0)>0){wa=0;do{ua=ta+wa|0;a[ua]=(a[ua]|0)+(a[Aa+wa|0]|0);wa=wa+1|0;gc=c[I>>2]|0;hc=c[W>>2]|0;}while((wa|0)<(ca(hc,gc)|0));ic=gc;jc=hc;kc=c[J>>2]|0}else{ic=aa;jc=sa;kc=va}wa=c[fa>>2]|0;ua=Ba+1|0;if((ua|0)<(kc|0)){Ba=ua;ta=ta+wa|0;Aa=Aa+wa|0;aa=ic;sa=jc;va=kc}else{break}}}}while(0);L5a(s,2147483647,0);JHb(r,c[k>>2]|0);c[k>>2]=0;fa=YHb(f,c[q>>2]|0)|0;if((fa|0)<0){C=fa;i=j;return C|0}else{c[g>>2]=1;lc=(c[u>>2]|0)-(c[v>>2]|0)|0;mc=ra;break}}KIb(K,16,2587984,(t=i,i=i+16|0,c[t>>2]=qb,c[t+8>>2]=rb,t)|0);i=t;Ja=ra;G=243}}while(0);if((G|0)==11){KIb(E,16,2244320,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;Ja=F;G=243}if((G|0)==243){OGb(k);L5a(s,2147483647,0);lc=-1094995529;mc=Ja}cqc(A)|0;c[mc>>2]=0;C=lc;i=j;return C|0}}while(0);KIb(e,16,2448128,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;C=-1094995529;i=j;return C|0}function dXa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;d=b+24|0;H5a(a,d);VHb(d);d=b+36|0;H5a(a,d);VHb(d);mJb(b+1144|0);c[b+1148>>2]=0;mJb(b+1128|0);c[b+1132>>2]=0;mJb(b+1136|0);c[b+1140>>2]=0;return 0}function eXa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+1104|0;j=h|0;k=h+56|0;l=h+64|0;m=h+72|0;n=h+80|0;o=b+e|0;p=o;q=b;r=Ob(b|0,0,e|0)|0;if((r|0)==0){s=-1094995529;i=h;return s|0}e=r+1|0;do{if((f|0)==0){c[m>>2]=e;t=p-e|0;u=e}else{if((e|0)==(o|0)){s=-1094995529;i=h;return s|0}v=r+2|0;if((a[e]|0)!=0){s=-1094995529;i=h;return s|0}c[j+32>>2]=58;c[j+36>>2]=34;c[j+40>>2]=0;do{if((_pc(j,2359016,56)|0)==0){c[j>>2]=v;w=j+4|0;c[w>>2]=p-v;SFb(n,0,-1);x=j+12|0;y=j+16|0;z=n+4|0;while(1){if((c[w>>2]|0)==0){A=11;break}YFb(n,1,k,l);B=c[l>>2]|0;if((B|0)==0){C=-12;A=12;break}c[x>>2]=c[k>>2];c[y>>2]=B;B=$pc(j,1)|0;if(B>>>0>1>>>0){C=-542398533;A=12;break}c[z>>2]=(c[x>>2]|0)-(c[k>>2]|0)+(c[z>>2]|0);if((B|0)==1){A=11;break}}if((A|0)==11){cqc(j)|0;a[(c[n>>2]|0)+(c[z>>2]|0)|0]=0;D=0;break}else if((A|0)==12){cqc(j)|0;_Fb(n,0)|0;D=C;break}}else{D=-542398533}}while(0);if((D|0)<0){s=D;i=h;return s|0}x=c[n+4>>2]|0;_Fb(n,m)|0;if((c[m>>2]|0)==0){s=-12}else{t=x;u=v;break}i=h;return s|0}}while(0);n=r-q|0;q=(r|0)==(b|0);if(q){E=0}else{r=0;D=0;while(1){C=((d[b+D|0]|0)>>>7&255)+r|0;j=D+1|0;if(j>>>0<n>>>0){r=C;D=j}else{E=C;break}}}do{if((n|0)==-1|E>>>0>(-2-n|0)>>>0){F=0}else{D=hJb(n+1+E|0)|0;if((D|0)==0){F=0;break}if(q){G=D}else{r=0;C=D;while(1){j=b+r|0;A=a[j]|0;if(A<<24>>24<0){k=C+1|0;a[C]=(A&255)>>>6|-64;a[k]=a[j]&63|-128;H=k}else{a[C]=A;H=C}A=H+1|0;k=r+1|0;if(k>>>0<n>>>0){r=k;C=A}else{G=A;break}}}a[G]=0;F=D}}while(0);G=c[m>>2]|0;n=(t|0)==0;if(n){I=0}else{H=0;b=0;while(1){q=((d[G+b|0]|0)>>>7&255)+H|0;E=b+1|0;if(E>>>0<t>>>0){H=q;b=E}else{I=q;break}}}do{if((t|0)==-1|I>>>0>(-2-t|0)>>>0){J=0}else{b=hJb(t+1+I|0)|0;if((b|0)==0){J=0;break}if(n){K=b}else{H=0;q=b;while(1){E=G+H|0;C=a[E]|0;if(C<<24>>24<0){r=q+1|0;a[q]=(C&255)>>>6|-64;a[r]=a[E]&63|-128;L=r}else{a[q]=C;L=q}C=L+1|0;r=H+1|0;if(r>>>0<t>>>0){H=r;q=C}else{K=C;break}}}a[K]=0;J=b}}while(0);K=c[m>>2]|0;if((K|0)!=(u|0)){kJb(K)}if((F|0)==0|(J|0)==0){kJb(F);kJb(J);s=-12;i=h;return s|0}else{MGb(g,F,J,12)|0;s=0;i=h;return s|0}return 0}function fXa(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;switch(f|0){case 2:{mf[c[b>>2]&2047](e,g,h,i);return};case 0:{nrc(e|0,g|0,i)|0;return};case 1:{if((j|0)>0){f=0;while(1){a[e+f|0]=a[g+f|0]|0;k=f+1|0;if((k|0)<(j|0)){f=k}else{l=j;break}}}else{l=0}do{if((j|0)==1){f=i-1|0;if((l|0)>(f|0)){m=l;break}k=d[e]|0;n=l;while(1){o=(d[g+n|0]|0)+k|0;a[e+n|0]=o;p=n+1|0;if((p|0)>(f|0)){m=p;break}else{k=o;n=p}}}else if((j|0)==4){if((l|0)>=(i|0)){return}n=c[e>>2]|0;k=l;do{f=c[g+k>>2]|0;n=(f&2139062143)+(n&2139062143)^(f^n)&-2139062144;c[e+k>>2]=n;k=k+4|0;}while((k|0)<(i|0));return}else if((j|0)==2){k=i-2|0;if((l|0)>(k|0)){m=l;break}n=d[e]|0;f=d[e+1|0]|0;p=l;while(1){o=(d[g+p|0]|0)+n|0;a[e+p|0]=o;q=p+1|0;r=(d[g+q|0]|0)+f|0;a[e+q|0]=r;q=p+2|0;if((q|0)>(k|0)){m=q;break}else{n=o;f=r;p=q}}}else if((j|0)==3){p=i-3|0;if((l|0)>(p|0)){m=l;break}f=d[e]|0;n=d[e+1|0]|0;k=d[e+2|0]|0;q=l;while(1){r=(d[g+q|0]|0)+f|0;a[e+q|0]=r;o=q+1|0;s=(d[g+o|0]|0)+n|0;a[e+o|0]=s;o=q+2|0;t=(d[g+o|0]|0)+k|0;a[e+o|0]=t;o=q+3|0;if((o|0)>(p|0)){m=o;break}else{f=r;n=s;k=t;q=o}}}else{m=l}}while(0);if((m|0)<(i|0)){u=m}else{return}do{a[e+u|0]=(a[g+u|0]|0)+(a[e+(u-j)|0]|0);u=u+1|0;}while((u|0)<(i|0));return};case 3:{if((j|0)>0){u=0;while(1){a[e+u|0]=((d[h+u|0]|0)>>>1)+(a[g+u|0]|0);m=u+1|0;if((m|0)<(j|0)){u=m}else{v=j;break}}}else{v=0}do{if((j|0)==2){u=i-2|0;if((v|0)>(u|0)){w=v;break}m=d[e]|0;l=d[e+1|0]|0;q=v;while(1){k=(((d[h+q|0]|0)+m|0)>>>1)+(d[g+q|0]|0)|0;a[e+q|0]=k;n=q+1|0;f=(((d[h+n|0]|0)+l|0)>>>1)+(d[g+n|0]|0)|0;a[e+n|0]=f;n=q+2|0;if((n|0)>(u|0)){w=n;break}else{m=k&255;l=f&255;q=n}}}else if((j|0)==4){q=i-4|0;if((v|0)>(q|0)){w=v;break}l=d[e]|0;m=d[e+1|0]|0;u=d[e+2|0]|0;n=d[e+3|0]|0;f=v;while(1){k=(((d[h+f|0]|0)+l|0)>>>1)+(d[g+f|0]|0)|0;a[e+f|0]=k;p=f+1|0;o=(((d[h+p|0]|0)+m|0)>>>1)+(d[g+p|0]|0)|0;a[e+p|0]=o;p=f+2|0;t=(((d[h+p|0]|0)+u|0)>>>1)+(d[g+p|0]|0)|0;a[e+p|0]=t;p=f+3|0;s=(((d[h+p|0]|0)+n|0)>>>1)+(d[g+p|0]|0)|0;a[e+p|0]=s;p=f+4|0;if((p|0)>(q|0)){w=p;break}else{l=k&255;m=o&255;u=t&255;n=s&255;f=p}}}else if((j|0)==3){f=i-3|0;if((v|0)>(f|0)){w=v;break}n=d[e]|0;u=d[e+1|0]|0;m=d[e+2|0]|0;l=v;while(1){q=(((d[h+l|0]|0)+n|0)>>>1)+(d[g+l|0]|0)|0;a[e+l|0]=q;p=l+1|0;s=(((d[h+p|0]|0)+u|0)>>>1)+(d[g+p|0]|0)|0;a[e+p|0]=s;p=l+2|0;t=(((d[h+p|0]|0)+m|0)>>>1)+(d[g+p|0]|0)|0;a[e+p|0]=t;p=l+3|0;if((p|0)>(f|0)){w=p;break}else{n=q&255;u=s&255;m=t&255;l=p}}}else if((j|0)==1){l=i-1|0;if((v|0)>(l|0)){w=v;break}m=d[e]|0;u=v;while(1){n=(((d[h+u|0]|0)+m|0)>>>1)+(d[g+u|0]|0)|0;a[e+u|0]=n;f=u+1|0;if((f|0)>(l|0)){w=f;break}else{m=n&255;u=f}}}else{w=v}}while(0);if((w|0)<(i|0)){x=w}else{return}do{a[e+x|0]=(((d[h+x|0]|0)+(d[e+(x-j)|0]|0)|0)>>>1)+(d[g+x|0]|0);x=x+1|0;}while((x|0)<(i|0));return};case 4:{do{if((j|0)>0){x=0;do{a[e+x|0]=(a[g+x|0]|0)+(a[h+x|0]|0);x=x+1|0;}while((x|0)<(j|0));if(!((j|0)>2&(i|0)>4)){y=j;break}x=(j|0)==4?i:i-3|0;pe[c[b+4>>2]&1023](e+j|0,g+j|0,h+j|0,x-j|0,j);y=x}else{y=0}}while(0);b=i-y|0;if((b|0)>0){z=0}else{return}do{i=z-j+y|0;x=a[e+i|0]|0;w=z+y|0;v=a[h+w|0]|0;u=a[h+i|0]|0;i=u&255;m=(v&255)-i|0;l=(x&255)-i|0;i=(m|0)>-1?m:-m|0;f=(l|0)>-1?l:-l|0;n=m+l|0;l=(n|0)>-1?n:-n|0;if((i|0)>(f|0)|(i|0)>(l|0)){A=(f|0)>(l|0)?u:v}else{A=x}a[e+w|0]=(a[g+w|0]|0)+A;z=z+1|0;}while((z|0)<(b|0));return};default:{return}}}function gXa(a){a=a|0;c[a>>2]=98;c[a+4>>2]=444;return}function hXa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f-4|0;if((g|0)<0){h=0}else{i=0;while(1){j=c[d+i>>2]|0;k=c[e+i>>2]|0;c[b+i>>2]=(k&2139062143)+(j&2139062143)^(k^j)&-2139062144;j=i+4|0;if((j|0)>(g|0)){h=j;break}else{i=j}}}if((h|0)<(f|0)){l=h}else{return}do{a[b+l|0]=(a[e+l|0]|0)+(a[d+l|0]|0);l=l+1|0;}while((l|0)<(f|0));return}function iXa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+60>>2]|0;e=a+140|0;switch(c[e>>2]|0){case 28:{c[a+792>>2]=32;break};case 2:{c[a+792>>2]=24;break};case 10:{c[a+792>>2]=1;break};case 11:{c[a+792>>2]=8;break};case 8:{c[a+792>>2]=40;break};default:{}}f=UHb()|0;c[a+804>>2]=f;if((f|0)==0){g=-12;i=b;return g|0}c[f+88>>2]=1;c[f+84>>2]=1;l8(d+4|0,a);f=c[a+216>>2]|0;if((f|0)<0){h=0}else{h=(f|0)>5?5:f}f=d+1260|0;c[f>>2]=h;if((c[e>>2]|0)==10){c[f>>2]=0}f=c[d+5416>>2]|0;if((f|0)==0){g=0;i=b;return g|0}e=d+5420|0;if((c[e>>2]|0)==0){c[e>>2]=(f*1e4|0|0)/254|0;g=0;i=b;return g|0}else{KIb(a,16,2202736,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;g=-22;i=b;return g|0}return 0}function jXa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0;h=i;i=i+64|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=c[b+60>>2]|0;s=r;t=c[b+88>>2]&262144;u=(t|0)!=0;switch(c[b+140>>2]|0){case 8:{v=8;w=0;break};case 2:{v=8;w=2;break};case 31:{v=16;w=0;break};case 66:{v=8;w=4;break};case 41:{v=16;w=2;break};case 291:{v=16;w=6;break};case 10:{v=1;w=0;break};case 28:{v=8;w=6;break};case 11:{v=8;w=3;break};default:{x=-1;i=h;return x|0}}z=ca(Irb(w)|0,v)|0;A=b+120|0;B=(ca(c[A>>2]|0,z)|0)+7>>3;C=r+1264|0;D=C;c[r+1296>>2]=58;c[r+1300>>2]=34;c[r+1304>>2]=0;E=c[b+84>>2]|0;do{if((E|0)==-1){F=-1}else{if((E|0)<0){F=0;break}F=(E|0)>9?9:E}}while(0);if((Hpc(D,F,8,15,8,0,2448048,56)|0)!=0){x=-1;i=h;return x|0}F=Mpc(D,B)|0;E=b+124|0;H=c[E>>2]|0;I=(((F+4095|0)/4096|0)*12|0)+F|0;F=Erc(I,(I|0)<0|0?-1:0,H,(H|0)<0|0?-1:0)|0;H=wrc(F,G,16384,0)|0;F=G;I=0;if((F|0)>(I|0)|(F|0)==(I|0)&H>>>0>2147483647>>>0){x=-12;i=h;return x|0}I=d5a(b,e,H,F)|0;if((I|0)<0){x=I;i=h;return x|0}I=e+24|0;F=c[I>>2]|0;H=r+1248|0;c[H>>2]=F;J=r+1252|0;c[J>>2]=F;F=e+28|0;K=r+1256|0;c[K>>2]=(c[I>>2]|0)+(c[F>>2]|0);I=hJb(B+32<<((c[r+1260>>2]|0)==5))|0;a:do{if((I|0)==0){L=0;M=0;N=-1}else{O=I+15|0;if(u){P=B+1|0;Q=hJb(P)|0;if((Q|0)==0){L=0;M=0;N=-1;break}R=hJb(P)|0;if((R|0)==0){L=0;M=Q;N=-1;break}else{S=R;T=Q}}else{S=0;T=0}Q=c[H>>2]|0;R=Q|0;y=1196314761;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;R=Q+4|0;y=169478669;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;R=(c[H>>2]|0)+8|0;c[H>>2]=R;Q=r+1320|0;P=Q;y=je(c[A>>2]|0)|0;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;U=r+1324|0;y=je(c[E>>2]|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;V=r+1328|0;a[V]=v;a[r+1329|0]=w;a[r+1330|0]=0;a[r+1331|0]=0;a[r+1332|0]=t>>>18;W=R;y=218103808;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;W=Dpc(0,0,0)|0;c[o>>2]=1380206665;R=Dpc(W,o,4)|0;W=c[H>>2]|0;y=1380206665;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;W=Dpc(R,Q,13)|0;nrc(c[H>>2]|0,Q|0,13)|0;R=(c[H>>2]|0)+13|0;c[H>>2]=R;X=R;y=je(W|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;X=c[r+5420>>2]|0;if((X|0)==0){y=je(c[b+224>>2]|0)|0;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;Y=0;Z=c[b+228>>2]|0}else{y=je(X|0)|0;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;Y=1;Z=X}y=je(Z|0)|0;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;a[V]=Y;V=c[H>>2]|0;y=150994944;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;V=Dpc(0,0,0)|0;c[n>>2]=1935231088;U=Dpc(V,n,4)|0;V=c[H>>2]|0;y=1935231088;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;V=Dpc(U,Q,9)|0;nrc(c[H>>2]|0,Q|0,9)|0;U=(c[H>>2]|0)+9|0;c[H>>2]=U;X=U;y=je(V|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;do{if((w|0)==3){X=c[f+4>>2]|0;V=r+2088|0;U=Q;P=0;W=0;R=V;while(1){_=c[X+(W<<2)>>2]|0;$=_>>>24;aa=($|0)==255?P:1;a[R]=$;a[U+2|0]=_;a[U+1|0]=_>>>8;a[U]=_>>>16;_=W+1|0;if((_|0)<256){U=U+3|0;P=aa;W=_;R=R+1|0}else{break}}R=c[H>>2]|0;y=196608;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;R=Dpc(0,0,0)|0;c[m>>2]=1163152464;W=Dpc(R,m,4)|0;R=c[H>>2]|0;y=1163152464;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;R=Dpc(W,Q,768)|0;nrc(c[H>>2]|0,Q|0,768)|0;W=(c[H>>2]|0)+768|0;c[H>>2]=W;P=W;y=je(R|0)|0;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;if((aa|0)==0){break}P=c[H>>2]|0;y=65536;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;P=Dpc(0,0,0)|0;c[l>>2]=1397641844;R=Dpc(P,l,4)|0;P=c[H>>2]|0;y=1397641844;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;P=Dpc(R,V,256)|0;nrc(c[H>>2]|0,V|0,256)|0;R=(c[H>>2]|0)+256|0;c[H>>2]=R;W=R;y=je(P|0)|0;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;c[H>>2]=(c[H>>2]|0)+4}}while(0);W=r+1280|0;c[W>>2]=4096;P=r+1276|0;c[P>>2]=Q;b:do{if(u){R=f|0;U=f+32|0;X=(z|0)==1;_=z>>3;$=r+1268|0;ba=C;da=k;ea=T;fa=S;ga=0;while(1){ha=Jrb(ga,z,c[A>>2]|0)|0;do{if((ha|0)>0){if((c[E>>2]|0)<=0){ia=fa;ja=ea;break}ka=d[1323224+ga|0]|0;la=704200+(ga<<2)|0;ma=ha+1|0;na=(ma|0)==0;oa=0;pa=ea;qa=fa;ra=0;while(1){c:do{if((ka&128>>>((ra&7)>>>0)|0)==0){sa=qa;ta=pa;ua=oa}else{va=c[R>>2]|0;wa=ca(c[U>>2]|0,ra)|0;xa=c[A>>2]|0;ya=c[la>>2]|0;do{if(X){mrc(qa|0,0,ha|0)|0;if((xa|0)>0){za=0;Aa=0}else{break}while(1){Ba=Aa&7;if((128>>>(Ba>>>0)&ya|0)==0){Ca=za}else{Da=qa+(za>>3)|0;a[Da]=((d[va+((Aa>>3)+wa)|0]|0)>>>((Ba^7)>>>0)&1)<<(za&7^7)|(d[Da]|0);Ca=za+1|0}Da=Aa+1|0;if((Da|0)<(xa|0)){za=Ca;Aa=Da}else{break}}}else{if((xa|0)<=0){break}Da=0;Ba=qa;Ea=va+wa|0;while(1){if((128>>>((Da&7)>>>0)&ya|0)==0){Fa=Ba}else{nrc(Ba|0,Ea|0,_)|0;Fa=Ba+_|0}Ga=Da+1|0;if((Ga|0)<(xa|0)){Da=Ga;Ba=Fa;Ea=Ea+_|0}else{break}}}}while(0);xa=lXa(s,O,qa,oa,ha,_)|0;c[$>>2]=ma;c[ba>>2]=xa;if(na){sa=pa;ta=qa;ua=qa;break}while(1){if((Lpc(D,0)|0)!=0){sa=pa;ta=qa;ua=qa;break c}if((c[W>>2]|0)==0){xa=c[H>>2]|0;if(((c[K>>2]|0)-xa|0)>4196){ya=xa;y=1048576;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;ya=Dpc(0,0,0)|0;c[k>>2]=1413563465;xa=Dpc(ya,da,4)|0;ya=c[H>>2]|0;y=1413563465;a[ya]=y;y=y>>8;a[ya+1|0]=y;y=y>>8;a[ya+2|0]=y;y=y>>8;a[ya+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;ya=Dpc(xa,Q,4096)|0;nrc(c[H>>2]|0,Q|0,4096)|0;xa=(c[H>>2]|0)+4096|0;c[H>>2]=xa;wa=xa;y=je(ya|0)|0;a[wa]=y;y=y>>8;a[wa+1|0]=y;y=y>>8;a[wa+2|0]=y;y=y>>8;a[wa+3|0]=y;c[H>>2]=(c[H>>2]|0)+4}c[W>>2]=4096;c[P>>2]=Q}if((c[$>>2]|0)==0){sa=pa;ta=qa;ua=qa;break}}}}while(0);wa=ra+1|0;if((wa|0)<(c[E>>2]|0)){oa=ua;pa=ta;qa=sa;ra=wa}else{ia=sa;ja=ta;break}}}else{ia=fa;ja=ea}}while(0);ha=ga+1|0;if((ha|0)<7){ea=ja;fa=ia;ga=ha}else{Ha=ia;Ia=ja;break}}}else{if((c[E>>2]|0)<=0){Ha=S;Ia=T;break}ga=f|0;fa=f+32|0;ea=z>>3;$=B+1|0;da=r+1268|0;ba=C;_=j;if(($|0)==0){X=0;U=0;while(1){R=(c[ga>>2]|0)+(ca(c[fa>>2]|0,U)|0)|0;V=lXa(s,O,R,X,B,ea)|0;c[da>>2]=0;c[ba>>2]=V;V=U+1|0;if((V|0)<(c[E>>2]|0)){X=R;U=V}else{Ha=S;Ia=T;break b}}}else{Ja=0;Ka=0}while(1){U=(c[ga>>2]|0)+(ca(c[fa>>2]|0,Ka)|0)|0;X=lXa(s,O,U,Ja,B,ea)|0;c[da>>2]=$;c[ba>>2]=X;do{if((Lpc(D,0)|0)!=0){break}if((c[W>>2]|0)==0){X=c[H>>2]|0;if(((c[K>>2]|0)-X|0)>4196){V=X;y=1048576;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;V=Dpc(0,0,0)|0;c[j>>2]=1413563465;X=Dpc(V,_,4)|0;V=c[H>>2]|0;y=1413563465;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;V=Dpc(X,Q,4096)|0;nrc(c[H>>2]|0,Q|0,4096)|0;X=(c[H>>2]|0)+4096|0;c[H>>2]=X;R=X;y=je(V|0)|0;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[H>>2]=(c[H>>2]|0)+4}c[W>>2]=4096;c[P>>2]=Q}}while((c[da>>2]|0)!=0);R=Ka+1|0;if((R|0)<(c[E>>2]|0)){Ja=U;Ka=R}else{Ha=S;Ia=T;break}}}}while(0);O=p;do{da=Lpc(D,4)|0;_=(da|0)==1;if(!(da>>>0<2>>>0)){L=Ha;M=Ia;N=-1;break a}da=4096-(c[W>>2]|0)|0;do{if((da|0)>0){ba=c[H>>2]|0;if(((c[K>>2]|0)-ba|0)<=(da+100|0)){break}$=ba;y=je(da|0)|0;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;$=Dpc(0,0,0)|0;c[p>>2]=1413563465;ba=Dpc($,O,4)|0;$=c[H>>2]|0;y=1413563465;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;$=Dpc(ba,Q,da)|0;nrc(c[H>>2]|0,Q|0,da)|0;ba=(c[H>>2]|0)+da|0;c[H>>2]=ba;ea=ba;y=je($|0)|0;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;c[H>>2]=(c[H>>2]|0)+4}}while(0);c[W>>2]=4096;c[P>>2]=Q}while(!_);Q=c[H>>2]|0;y=0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;Q=Dpc(0,0,0)|0;c[q>>2]=1145980233;P=Dpc(Q,q,4)|0;Q=c[H>>2]|0;y=1145980233;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=(c[H>>2]|0)+4|0;c[H>>2]=Q;W=Q;y=je(P|0)|0;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;c[F>>2]=(c[H>>2]|0)-(c[J>>2]|0);W=e+36|0;c[W>>2]=c[W>>2]|1;c[g>>2]=1;L=Ha;M=Ia;N=0}}while(0);kJb(I);kJb(M);kJb(L);Ipc(D)|0;x=N;i=h;return x|0}function kXa(a){a=a|0;VHb(a+804|0);return 0}function lXa(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;k=c[b+1260>>2]|0;l=(k|0)==0;if(!((h|0)!=0|l)){KIb(0,0,2358984,(m=i,i=i+24|0,c[m>>2]=2295224,c[m+8>>2]=2244296,c[m+16>>2]=165,m)|0);i=m;Hd();return 0}m=(f|0)!=0|l?k:1;if((m|0)!=5){mXa(b+4|0,d+1|0,m,e,f,g,h);a[d]=m;n=d;i=j;return n|0}m=d+(g+16)|0;k=b+4|0;mXa(k,d+1|0,0,e,f,g,h);a[d]=0;if((g|0)<0){b=d+(g+17)|0;mXa(k,b,1,e,f,g,h);a[m]=1;mXa(k,b,2,e,f,g,h);a[m]=2;mXa(k,b,3,e,f,g,h);a[m]=3;mXa(k,b,4,e,f,g,h);a[m]=4;n=d;i=j;return n|0}else{o=1;p=0;q=0}while(1){b=q<<24>>24;r=(q<<24>>24>-1?b:-b|0)+p|0;if((o|0)>(g|0)){break}b=a[d+o|0]|0;o=o+1|0;p=r;q=b}q=(r|0)!=2147483647;p=q?m:d;o=q?d:m;mXa(k,p+1|0,1,e,f,g,h);a[p]=1;m=1;d=0;q=1;while(1){b=q<<24>>24;s=(q<<24>>24>-1?b:-b|0)+d|0;if((m|0)>(g|0)){break}b=a[p+m|0]|0;m=m+1|0;d=s;q=b}q=(s|0)<(r|0);d=q?s:r;r=q?o:p;s=q?p:o;mXa(k,r+1|0,2,e,f,g,h);a[r]=2;o=1;p=0;q=2;while(1){m=q<<24>>24;t=(q<<24>>24>-1?m:-m|0)+p|0;if((o|0)>(g|0)){break}m=a[r+o|0]|0;o=o+1|0;p=t;q=m}q=(t|0)<(d|0);p=q?t:d;d=q?s:r;t=q?r:s;mXa(k,d+1|0,3,e,f,g,h);a[d]=3;s=1;r=0;q=3;while(1){o=q<<24>>24;u=(q<<24>>24>-1?o:-o|0)+r|0;if((s|0)>(g|0)){break}o=a[d+s|0]|0;s=s+1|0;r=u;q=o}q=(u|0)<(p|0);r=q?u:p;p=q?t:d;u=q?d:t;mXa(k,p+1|0,4,e,f,g,h);a[p]=4;h=1;f=0;e=4;while(1){k=e<<24>>24;v=(e<<24>>24>-1?k:-k|0)+f|0;if((h|0)>(g|0)){break}k=a[p+h|0]|0;h=h+1|0;f=v;e=k}n=(v|0)<(r|0)?p:u;i=j;return n|0}function mXa(b,e,f,g,h,i,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;switch(f|0){case 1:{f=g+j|0;nrc(e|0,g|0,j)|0;k=e+j|0;l=i-j|0;m=32-j|0;n=(m|0)>(l|0)?l:m;if((n|0)>0){m=j-1|0;o=m-i|0;p=j-33|0;q=(o|0)>(p|0)?o:p;p=~q;o=f;r=g;s=0;t=k;while(1){a[t]=(a[o]|0)-(a[r]|0);u=s+1|0;if((u|0)<(n|0)){o=o+1|0;r=r+1|0;s=u;t=t+1|0}else{break}}t=m-q|0;v=g+t|0;w=g+p|0;x=e+t|0}else{v=f;w=g;x=k}mf[c[b+1076>>2]&2047](x,v,w,l-n|0);return};case 0:{nrc(e|0,g|0,i)|0;return};case 4:{if((j|0)>0){n=0;while(1){a[e+n|0]=(a[g+n|0]|0)-(a[h+n|0]|0);l=n+1|0;if((l|0)<(j|0)){n=l}else{y=j;break}}}else{y=0}n=i-y|0;if((n|0)>0){z=0}else{return}do{l=z-j+y|0;w=a[g+l|0]|0;v=z+y|0;x=a[h+v|0]|0;k=a[h+l|0]|0;l=k&255;f=(x&255)-l|0;t=(w&255)-l|0;l=(f|0)>-1?f:-f|0;p=(t|0)>-1?t:-t|0;q=f+t|0;t=(q|0)>-1?q:-q|0;if((l|0)>(p|0)|(l|0)>(t|0)){A=(p|0)>(t|0)?k:x}else{A=w}a[e+v|0]=(a[g+v|0]|0)-A;z=z+1|0;}while((z|0)<(n|0));return};case 3:{if((j|0)>0){n=0;while(1){a[e+n|0]=(a[g+n|0]|0)-((d[h+n|0]|0)>>>1);z=n+1|0;if((z|0)<(j|0)){n=z}else{B=j;break}}}else{B=0}if((B|0)<(i|0)){C=B}else{return}do{a[e+C|0]=(d[g+C|0]|0)-(((d[h+C|0]|0)+(d[g+(C-j)|0]|0)|0)>>>1);C=C+1|0;}while((C|0)<(i|0));return};case 2:{mf[c[b+1076>>2]&2047](e,g,h,i);return};default:{return}}}function nXa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;j=i;k=c[h+24>>2]|0;l=c[h+28>>2]|0;h=c[e+60>>2]|0;m=h;c[m>>2]=k;n=h+4|0;c[n>>2]=k;o=h+8|0;c[o>>2]=k+l;l=Krb(e,h)|0;if((l|0)<0){p=l;i=j;return p|0}l=M4a(e,f,0)|0;if((l|0)<0){p=l;i=j;return p|0}c[f+88>>2]=1;c[f+84>>2]=1;l=h+12|0;k=c[l>>2]|0;q=k>>>0>65535>>>0;r=q?k>>>16:k;k=q?16:0;if((r&65280|0)==0){s=k;t=r}else{s=k|8;t=r>>>8}c[e+796>>2]=s+1+(d[1359664+t|0]|0);a:do{switch(c[e+140>>2]|0){case 54:{t=c[l>>2]|0;s=(((t|0)/2|0)+2147450880|0)/(t|0)|0;t=c[e+120>>2]|0;r=t<<1;k=c[f+32>>2]|0;q=c[m>>2]|0;u=c[e+124>>2]|0;if((q+((ca(t*6|0,u)|0)/2|0)|0)>>>0>(c[o>>2]|0)>>>0){p=-1094995529;i=j;return p|0}if((u|0)>0){v=(t|0)==0;w=(ca(t,(u|0)>1?u:1)|0)<<1;x=c[f>>2]|0;z=0;A=q;while(1){if(!v){B=x;C=0;do{b[B+(C<<1)>>1]=((ca((he(b[A+(C<<1)>>1]|0)|0)&65535,s)|0)+16384|0)>>>15;C=C+1|0;}while(C>>>0<t>>>0)}C=z+1|0;if((C|0)<(u|0)){x=x+k|0;z=C;A=A+r|0}else{break}}A=q+w|0;c[m>>2]=A;D=A}else{D=q}A=u>>1;if((A|0)<=0){E=D;break a}z=(t|0)/2|0;k=(t+1|0)>>>0>2>>>0;x=(c[f+36>>2]|0)/2|0;v=(c[f+40>>2]|0)/2|0;C=(ca(t,A)|0)<<1;B=0;F=c[f+4>>2]|0;G=c[f+8>>2]|0;H=D;while(1){do{if(k){I=0;do{b[F+(I<<1)>>1]=((ca((he(b[H+(I<<1)>>1]|0)|0)&65535,s)|0)+16384|0)>>>15;I=I+1|0;}while(I>>>0<z>>>0);I=H+t|0;if(k){J=0}else{break}do{b[G+(J<<1)>>1]=((ca((he(b[I+(J<<1)>>1]|0)|0)&65535,s)|0)+16384|0)>>>15;J=J+1|0;}while(J>>>0<z>>>0)}}while(0);I=B+1|0;if((I|0)<(A|0)){B=I;F=F+(x<<1)|0;G=G+(v<<1)|0;H=H+r|0}else{break}}r=D+C|0;c[m>>2]=r;E=r;break};case 2:{r=c[e+120>>2]|0;K=r*3|0;L=8;M=3;N=0;O=(c[l>>2]|0)<255|0;P=r;Q=14;break};case 32:{r=c[e+120>>2]|0;K=r<<1;L=16;M=1;N=0;O=(c[l>>2]|0)<65535?2:0;P=r;Q=14;break};case 8:{r=c[e+120>>2]|0;K=r;L=8;M=1;N=0;O=(c[l>>2]|0)<255|0;P=r;Q=14;break};case 28:{r=c[e+120>>2]|0;K=r<<2;L=8;M=4;N=0;O=0;P=r;Q=14;break};case 0:case 70:case 72:{r=c[f>>2]|0;H=c[f+32>>2]|0;v=c[l>>2]|0;G=c[e+120>>2]<<((v|0)>255);x=c[m>>2]|0;F=e+124|0;B=c[F>>2]|0;A=x+((ca(B*3|0,G)|0)/2|0)|0;if(A>>>0>(c[o>>2]|0)>>>0){p=-1094995529;i=j;return p|0}b:do{if((B|0)>0){A=(G|0)/2|0;if((G|0)>1){R=r;S=1;T=x;U=B;V=v}else{z=r;s=1;k=x;t=B;u=v;while(1){if((u|0)<256){nrc(z|0,k|0,G)|0;W=c[m>>2]|0;X=c[F>>2]|0}else{W=k;X=t}q=W+G|0;c[m>>2]=q;if((s|0)>=(X|0)){Y=X;Z=q;break b}z=z+H|0;s=s+1|0;k=q;t=X;u=c[l>>2]|0}}while(1){if((V|0)<256){nrc(R|0,T|0,G)|0;_=c[m>>2]|0;$=c[F>>2]|0}else{u=R;t=0;while(1){k=T+(t<<1)|0;b[u+(t<<1)>>1]=he((d[k]|d[k+1|0]<<8)<<16>>16|0)|0;k=t+1|0;if((k|0)<(A|0)){t=k}else{_=T;$=U;break}}}t=_+G|0;c[m>>2]=t;if((S|0)>=($|0)){Y=$;Z=t;break b}R=R+H|0;S=S+1|0;T=t;U=$;V=c[l>>2]|0}}else{Y=B;Z=x}}while(0);x=G>>1;B=Y>>1;if((B|0)<=0){E=Z;break a}H=f+36|0;F=f+40|0;v=(x|0)/2|0;r=(x|0)>1;C=1;A=c[f+4>>2]|0;t=c[f+8>>2]|0;u=Z;while(1){k=c[l>>2]|0;do{if((k|0)<256){nrc(A|0,u|0,x)|0;aa=c[m>>2]|0;ba=c[l>>2]|0}else{if(!r){aa=u;ba=k;break}s=A;z=0;while(1){q=u+(z<<1)|0;b[s+(z<<1)>>1]=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=z+1|0;if((q|0)<(v|0)){z=q}else{aa=u;ba=k;break}}}}while(0);k=aa+x|0;c[m>>2]=k;do{if((ba|0)<256){nrc(t|0,k|0,x)|0;da=c[m>>2]|0}else{if(!r){da=k;break}z=t;s=0;while(1){q=aa+((s<<1)+x)|0;b[z+(s<<1)>>1]=he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0;q=s+1|0;if((q|0)<(v|0)){s=q}else{da=k;break}}}}while(0);k=da+x|0;c[m>>2]=k;if((C|0)>=(B|0)){E=k;break a}C=C+1|0;A=A+(c[H>>2]|0)|0;t=t+(c[F>>2]|0)|0;u=k}break};case 42:{u=c[e+120>>2]|0;K=u*6|0;L=16;M=3;N=0;O=(c[l>>2]|0)<65535?2:0;P=u;Q=14;break};case 66:{u=c[e+120>>2]|0;K=u<<1;L=8;M=2;N=0;O=0;P=u;Q=14;break};case 292:{u=c[e+120>>2]|0;K=u<<3;L=16;M=4;N=0;O=(c[l>>2]|0)<65535?2:0;P=u;Q=14;break};case 9:case 10:{u=c[e+120>>2]|0;K=u+7>>3;L=1;M=1;N=1;O=0;P=u;Q=14;break};default:{p=-22;i=j;return p|0}}}while(0);c:do{if((Q|0)==14){da=c[f>>2]|0;aa=c[f+32>>2]|0;ba=c[m>>2]|0;Z=e+124|0;Y=c[Z>>2]|0;V=ba+(ca(Y,K)|0)|0;if(V>>>0>(c[o>>2]|0)>>>0){p=-1094995529;i=j;return p|0}V=h+16|0;$=c[V>>2]|0;do{if(($|0)>=4){if((N|0)!=0&($|0)==7){break}if((Y|0)<=0){E=ba;break c}U=(K|0)/2|0;T=(K|0)>1;S=(K|0)==0;R=(K+1|0)>>>0>2>>>0;_=da;X=0;W=ba;while(1){d:do{if((O|0)==0){if((c[l>>2]|0)<256){nrc(_|0,W|0,K)|0;break}if(!T){break}D=_;J=0;do{u=W+(J<<1)|0;b[D+(J<<1)>>1]=he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;J=J+1|0;}while((J|0)<(U|0))}else if((O|0)==1){J=c[l>>2]|0;D=(((J|0)/2|0)+32640|0)/(J|0)|0;if(S){break}else{ea=0;fa=W}while(1){a[_+ea|0]=((ca(d[fa+ea|0]|0,D)|0)+64|0)>>>7;J=ea+1|0;if(!(J>>>0<K>>>0)){break d}ea=J;fa=c[m>>2]|0}}else if((O|0)==2){D=c[l>>2]|0;J=(((D|0)/2|0)+2147450880|0)/(D|0)|0;if(!R){break}D=W;u=_;F=0;do{b[u+(F<<1)>>1]=((ca((he(b[D+(F<<1)>>1]|0)|0)&65535,J)|0)+16384|0)>>>15;F=F+1|0;}while(F>>>0<U>>>0)}}while(0);F=(c[m>>2]|0)+K|0;c[m>>2]=F;J=X+1|0;if((J|0)<(c[Z>>2]|0)){_=_+aa|0;X=J;W=F}else{E=F;break c}}}}while(0);if((Y|0)<=0){E=ba;break}$=(aa|0)<0;W=e+120|0;X=(N|0)==0;_=(L|0)==16;U=(1<<L)-1|0;R=32-L|0;S=da;T=1;F=P;e:while(1){J=$?0:S;D=0;f:do{if((ca(F,M)|0)>0){u=S;if(X){ga=J;ha=32;ia=0;ja=F}else{t=J;H=32;A=0;C=F;while(1){B=c[m>>2]|0;x=c[o>>2]|0;g:do{if((c[V>>2]|0)<4&B>>>0<x>>>0){v=B;while(1){if(!(((a[v]|0)-48&255)>>>0>9>>>0)){ka=v;break g}r=v+1|0;c[m>>2]=r;if(r>>>0<x>>>0){v=r}else{ka=r;break}}}else{ka=B}}while(0);if(!(ka>>>0<x>>>0)){p=-1094995529;Q=111;break e}c[m>>2]=ka+1;B=c[l>>2]|0;v=((B>>1)+(U&-(a[ka]&1))|0)/(B|0)|0;if(_){b[u+(A<<1)>>1]=v;la=H;ma=t;na=C}else{B=D;if((H|0)>(L|0)){oa=H-L|0;pa=B<<L|v;qa=t;ra=C}else{r=t;y=je(B<<H|v>>>((L-H|0)>>>0)|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;oa=R+H|0;pa=v;qa=t+4|0;ra=c[W>>2]|0}D=pa;la=oa;ma=qa;na=ra}v=A+1|0;if((v|0)<(ca(na,M)|0)){t=ma;H=la;A=v;C=na}else{sa=ma;ta=la;break f}}}while(1){C=c[m>>2]|0;A=c[o>>2]|0;h:do{if((c[V>>2]|0)<4&C>>>0<A>>>0){H=C;while(1){if(!(((a[H]|0)-48&255)>>>0>9>>>0)){ua=H;break h}t=H+1|0;c[m>>2]=t;if(t>>>0<A>>>0){H=t}else{ua=t;break}}}else{ua=C}}while(0);if(ua>>>0<A>>>0){va=0;wa=0;xa=ua}else{p=-1094995529;Q=111;break e}while(1){ya=(va*10|0)+wa|0;C=xa+1|0;c[m>>2]=C;x=(d[xa]|0)-48|0;if(x>>>0<10>>>0){va=ya;wa=x;xa=C}else{break}}A=ca(ya,U)|0;C=c[l>>2]|0;x=((C>>1)+A|0)/(C|0)|0;if(_){b[u+(ia<<1)>>1]=x;za=ha;Aa=ga;Ba=ja}else{C=D;if((ha|0)>(L|0)){Ca=ha-L|0;Da=C<<L|x;Ea=ga;Fa=ja}else{A=ga;y=je(C<<ha|x>>>((L-ha|0)>>>0)|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;Ca=R+ha|0;Da=x;Ea=ga+4|0;Fa=c[W>>2]|0}D=Da;za=Ca;Aa=Ea;Ba=Fa}x=ia+1|0;if((x|0)<(ca(Ba,M)|0)){ga=Aa;ha=za;ia=x;ja=Ba}else{sa=Aa;ta=za;break}}}else{sa=J;ta=32}}while(0);if(!_){if((ta|0)<32){J=D<<ta;D=J;u=J>>>24&255;J=ta;x=sa;while(1){a[x]=u;A=D;D=A<<8;C=J+8|0;if((C|0)<32){u=A>>>16&255;J=C;x=x+1|0}else{break}}}D=0}if((T|0)>=(c[Z>>2]|0)){Q=108;break}S=S+aa|0;T=T+1|0;F=c[W>>2]|0}if((Q|0)==108){E=c[m>>2]|0;break}else if((Q|0)==111){i=j;return p|0}}}while(0);c[g>>2]=1;p=E-(c[n>>2]|0)|0;i=j;return p|0}function oXa(a){a=a|0;var b=0,d=0;b=UHb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+88>>2]=1;c[b+84>>2]=1;d=0;return d|0}function pXa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=i;h=a+140|0;j=a+120|0;k=a+124|0;l=(c2(c[h>>2]|0,c[j>>2]|0,c[k>>2]|0)|0)+200|0;m=d5a(a,b,l,(l|0)<0|0?-1:0)|0;if((m|0)<0){n=m;i=g;return n|0}m=c[b+24>>2]|0;l=b+28|0;o=c[l>>2]|0;p=c[k>>2]|0;a:do{switch(c[h>>2]|0){case 0:{k=c[j>>2]|0;do{if((k&1|0)==0){if((p&1|0)!=0){break}q=k;r=53;s=(p*3|0|0)/2|0;t=k;break a}}while(0);KIb(a,16,2614848,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;n=-22;i=g;return n|0};case 31:{k=c[j>>2]|0;q=k<<1;r=53;s=p;t=k;break};case 9:{k=c[j>>2]|0;q=k+7>>3;r=52;s=p;t=k;break};case 55:{k=c[j>>2]|0;q=k<<1;r=53;s=(p*3|0|0)/2|0;t=k;break};case 2:{k=c[j>>2]|0;q=k*3|0;r=54;s=p;t=k;break};case 41:{k=c[j>>2]|0;q=k*6|0;r=54;s=p;t=k;break};case 8:{k=c[j>>2]|0;q=k;r=53;s=p;t=k;break};default:{n=-1;i=g;return n|0}}}while(0);j=m;Rb(m|0,o|0,2587960,(u=i,i=i+24|0,c[u>>2]=r,c[u+8>>2]=t,c[u+16>>2]=s,u)|0)|0;i=u;s=lrc(m|0)|0;t=m+s|0;r=c[h>>2]|0;if((r|0)==9){v=t}else{a=(1<<((e[(qKb(r)|0)+8>>1]|0)>>>11&15)+1)-1|0;Rb(t|0,o-s|0,2566712,(u=i,i=i+8|0,c[u>>2]=a,u)|0)|0;i=u;v=m+((lrc(t|0)|0)+s)|0}s=c[d+32>>2]|0;if((p|0)>0){t=ca(q,p)|0;m=0;u=v;a=c[d>>2]|0;while(1){nrc(u|0,a|0,q)|0;o=m+1|0;if((o|0)<(p|0)){m=o;u=u+q|0;a=a+s|0}else{break}}w=v+t|0}else{w=v}v=c[h>>2]|0;do{if((v|0)==0|(v|0)==55){h=p>>1;t=q>>1;if((h|0)<=0){x=w;break}s=t<<1;a=d+36|0;u=d+40|0;m=(ca(h,t)|0)<<1;o=0;r=w;k=c[d+4>>2]|0;y=c[d+8>>2]|0;while(1){nrc(r|0,k|0,t)|0;nrc(r+t|0,y|0,t)|0;z=o+1|0;if((z|0)<(h|0)){o=z;r=r+s|0;k=k+(c[a>>2]|0)|0;y=y+(c[u>>2]|0)|0}else{break}}x=w+m|0}else{x=w}}while(0);c[l>>2]=x-j;j=b+36|0;c[j>>2]=c[j>>2]|1;c[f>>2]=1;n=0;i=g;return n|0}function qXa(a){a=a|0;VHb(a+804|0);return 0}function rXa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+64|0;f=e|0;g=c[b+60>>2]|0;c[b+796>>2]=10;l8(g,b);h=g+1244|0;EXa(h,b);M6(f|0,c[h>>2]|0);h=0;while(1){a[g+(h+1468)|0]=a[f+(d[1322152+h|0]|0)|0]|0;b=h+1|0;if((b|0)<64){h=b}else{j=0;break}}do{a[g+(j+1532)|0]=a[f+(d[1322440+j|0]|0)|0]|0;j=j+1|0;}while((j|0)<64);i=e;return 0}function sXa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;h=i;j=b+60|0;k=c[j>>2]|0;l=k;m=e;n=c[g+24>>2]|0;o=g+28|0;g=c[o>>2]|0;do{if((g|0)>=28){p=n+4|0;if((d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)!=1718641513){break}c[k+1316>>2]=m;c[e+88>>2]=1;c[e+84>>2]=1;p=k+1600|0;c[p>>2]=1;q=g-8|0;r=n+8|0;s=(he((d[r]|d[r+1|0]<<8)<<16>>16|0)|0)&65535;if((s|0)>(q|0)){KIb(b,16,2530600,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}r=n+10|0;v=he((d[r]|d[r+1|0]<<8)<<16>>16|0)|0;if((v&65535)>>>0>1>>>0){KIb(b,16,2515344,(t=i,i=i+8|0,c[t>>2]=v&65535,t)|0);i=t;u=-1163346256;i=h;return u|0}v=n+16|0;r=(he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535;v=n+18|0;w=(he((d[v]|d[v+1|0]<<8)<<16>>16|0)|0)&65535;v=b+120|0;x=c[v>>2]|0;y=b+124|0;z=c[y>>2]|0;if(!((r|0)==(x|0)&(w|0)==(z|0))){KIb(b,16,2501440,(t=i,i=i+32|0,c[t>>2]=x,c[t+8>>2]=z,c[t+16>>2]=r,c[t+24>>2]=w,t)|0);i=t;u=-1163346256;i=h;return u|0}w=n+20|0;r=(d[w]|0)>>>2&3;z=k+1320|0;c[z>>2]=r;x=a[n+25|0]&15;A=k+1604|0;c[A>>2]=x;if(x>>>0>2>>>0){KIb(b,16,2488608,(t=i,i=i+8|0,c[t>>2]=x,t)|0);i=t;u=-1094995529;i=h;return u|0}if((c[b+944>>2]|0)==0){B=x}else{c[A>>2]=0;B=0}if((r|0)==0){c[k+1596>>2]=k+1468;C=B}else{c[k+1596>>2]=k+1532;c[e+296>>2]=1;c[e+300>>2]=(c[z>>2]|0)==1;C=c[A>>2]|0}A=(a[w]&-64)<<24>>24==-64;if((C|0)==0){c[b+140>>2]=A?78:74}else{c[b+140>>2]=A?102:100}A=d[n+27|0]|0;do{if((A&2|0)==0){mrc(k+1324|0,4,64)|0;D=n+28|0}else{if((g-28|0)<64){KIb(b,16,2477648,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}else{w=0;do{a[l+1324+w|0]=a[n+((d[l+1248+w|0]|0)+28)|0]|0;w=w+1|0;}while((w|0)<64);D=n+92|0;break}}}while(0);a:do{if((A&1|0)==0){mrc(k+1388|0,4,64)|0}else{if((n+g-D|0)>=64){w=0;while(1){a[l+1388+w|0]=a[D+(d[l+1248+w|0]|0)|0]|0;w=w+1|0;if((w|0)>=64){break a}}}KIb(b,16,2477648,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}}while(0);A=n+(s+8)|0;w=q-s|0;r=M4a(b,m,0)|0;if((r|0)<0){u=r;i=h;return u|0}r=a[A]|0;x=(r&255)>>>3;b:do{if((r&255)>>>0<64>>>0|(x|0)>(w|0)){E=34}else{F=b+828|0;G=w;H=A;I=x;c:while(1){J=c[j>>2]|0;K=H+1|0;L=je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0;if(L>>>0>G>>>0){E=36;break}K=a[H+7|0]|0;M=K&255;N=M>>>4;O=M&15;if(!((K&255)>>>0<64>>>0&(O|0)==0)){E=38;break}K=J+1460|0;c[K>>2]=(c[v>>2]|0)+15>>4;M=c[y>>2]|0;if((c[J+1320>>2]|0)==0){c[J+1464>>2]=M+15>>4}else{c[J+1464>>2]=M+31>>5}M=H+5|0;P=(d[M]|d[M+1|0]<<8)<<16>>16;M=(he(P|0)|0)&65535;Q=J+1456|0;R=J+1452|0;S=R;if((c[Q>>2]|0)==(M|0)){T=c[S>>2]|0;if((T|0)==0){E=44}else{U=T}}else{E=44}if((E|0)==44){E=0;mJb(R);R=pJb(M*24|0)|0;T=R;c[S>>2]=T;if((R|0)==0){V=-12;E=61;break}c[Q>>2]=M;U=T}if(P<<16>>16==0){V=-22;E=61;break}P=(M<<1)+I|0;if((P|0)>(G|0)){E=48;break}T=1<<N;Q=H+G|0;R=T;W=0;X=0;Y=H+P|0;P=0;Z=c[K>>2]|0;_=U;while(1){c[_+(P*24|0)>>2]=Y;$=H+((P<<1)+I)|0;aa=he((d[$]|d[$+1|0]<<8)<<16>>16|0)|0;$=Z-W|0;ba=R;while(1){if($>>>0<ba>>>0){ba=ba>>1}else{break}}$=aa&65535;ca=Y+$|0;c[_+(P*24|0)+4>>2]=W;c[_+(P*24|0)+8>>2]=X;c[_+(P*24|0)+12>>2]=ba;c[_+(P*24|0)+16>>2]=$;if((aa&65535)>>>0<6>>>0){E=53;break c}$=ba+W|0;da=c[K>>2]|0;ea=($|0)==(da|0);if(ca>>>0>Q>>>0){E=55;break c}fa=(ea&1)+X|0;ga=ea?0:$;$=P+1|0;if(($|0)>=(M|0)){break}R=ea?T:ba;W=ga;X=fa;Y=ca;P=$;Z=da;_=c[S>>2]|0}ha=c[J+1464>>2]|0;if(!((ga|0)==0&(fa|0)==(ha|0))){E=59;break}if((L|0)<0){V=L;E=61;break}S=c[j>>2]|0;_=S+1456|0;Xe[c[F>>2]&511](b,10,0,0,c[_>>2]|0)|0;Z=S+1452|0;S=c[_>>2]|0;_=0;while(1){if((_|0)>=(S|0)){break}ia=c[(c[Z>>2]|0)+(_*24|0)+20>>2]|0;if((ia|0)<0){E=66;break c}else{_=_+1|0}}_=H+L|0;Z=G-L|0;if(!((c[z>>2]|0)!=0&(Z|0)>0)){E=70;break}if((c[p>>2]|0)==0){E=70;break}c[p>>2]=0;S=a[_]|0;J=(S&255)>>>3;if((S&255)>>>0<64>>>0|(J|0)>(Z|0)){E=34;break b}else{G=Z;H=_;I=J}}if((E|0)==36){I=b;KIb(I,16,2119952,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==38){I=b;KIb(I,16,2638016,(t=i,i=i+16|0,c[t>>2]=1<<N,c[t+8>>2]=1<<O,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==48){I=b;KIb(I,16,2614816,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==53){I=b;KIb(I,16,2587928,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==55){I=b;KIb(I,16,2566680,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==59){I=b;KIb(I,16,2548416,(t=i,i=i+16|0,c[t>>2]=fa,c[t+8>>2]=ha,t)|0);i=t;ja=-1094995529;ka=I;break}else if((E|0)==61){ja=V;ka=b;break}else if((E|0)==66){KIb(b,16,2244232,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=ia;i=h;return u|0}else if((E|0)==70){c[f>>2]=1;u=c[o>>2]|0;i=h;return u|0}}}while(0);if((E|0)==34){p=b;KIb(p,16,2143528,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;ja=-1094995529;ka=p}KIb(ka,16,2295184,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=ja;i=h;return u|0}}while(0);KIb(b,16,2358832,(t=i,i=i+1|0,i=i+7&-8,c[t>>2]=0,t)|0);i=t;u=-1094995529;i=h;return u|0}function tXa(a){a=a|0;mJb((c[a+60>>2]|0)+1452|0);return 0}function uXa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0;h=i;i=i+4376|0;f=h|0;j=h+24|0;k=h+4120|0;l=h+4248|0;m=e+60|0;n=c[m>>2]|0;o=c[n+1452>>2]|0;p=o+(g*24|0)|0;q=c[p>>2]|0;r=c[n+1316>>2]|0;s=o+(g*24|0)+20|0;c[s>>2]=-1;t=a[q]|0;u=(t&255)>>>3;v=a[q+1|0]|0;w=v&255;do{if(v<<24>>24==0){x=1}else{y=w>>>0>224>>>0?224:w;if(!(y>>>0>128>>>0)){x=y;break}x=(y<<2)-384|0}}while(0);w=q+2|0;v=(he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535;w=q+4|0;y=(he((d[w]|d[w+1|0]<<8)<<16>>16|0)|0)&65535;w=c[o+(g*24|0)+16>>2]|0;z=v+u|0;A=w-z-y|0;if((t&255)>>>0>63>>>0){t=q+6|0;B=(he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535;C=B;D=w-(y+v)-B|0;E=7}else{if((A|0)>=0){C=A;D=u;E=7}}do{if((E|0)==7){A=D-u|0;B=z+y|0;t=B+C|0;if(t>>>0>w>>>0){break}else{F=0}do{b[k+(F<<1)>>1]=ca(d[n+(F+1324)|0]|0,x)|0;b[l+(F<<1)>>1]=ca(d[n+(F+1388)|0]|0,x)|0;F=F+1|0;}while((F|0)<64);G=q+u|0;H=(c[n+1320>>2]|0)==0;I=c[r+32>>2]|0;if(H){J=c[r+36>>2]|0;K=J;L=I;M=J}else{J=c[r+36>>2]|0;K=J<<1;L=I<<1;M=J}J=c[e+140>>2]|0;if((J|0)==78|(J|0)==102){N=5;O=2}else{N=4;O=1}J=c[r>>2]|0;P=c[o+(g*24|0)+8>>2]<<4;Q=ca(P,L)|0;R=c[o+(g*24|0)+4>>2]|0;S=Q+(R<<5)|0;Q=J+S|0;T=c[r+4>>2]|0;U=(ca(P,K)|0)+(R<<N)|0;R=T+U|0;P=c[r+8>>2]|0;V=P+U|0;W=r+12|0;X=c[W>>2]|0;Y=X+S|0;do{if(H){Z=Y;_=V;$=R;aa=Q}else{if((c[n+1600>>2]|0)==(c[r+300>>2]|0)){Z=Y;_=V;$=R;aa=Q;break}Z=X+((c[r+44>>2]|0)+S)|0;_=P+((c[r+40>>2]|0)+U)|0;$=T+(M+U)|0;aa=J+(I+S)|0}}while(0);S=aa;I=k|0;J=j;U=j|0;T=o+(g*24|0)+12|0;P=c[T>>2]|0;X=P<<2;if((X|0)>0){Q=n+36|0;R=0;do{qe[c[Q>>2]&1023](j+(R<<6<<1)|0);R=R+1|0;}while((R|0)<(X|0))}R=(G|0)==0?0:v<<3;Q=R+8|0;V=G|0;Y=je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0;V=Y>>>0>65535>>>0;H=V?Y>>>16:Y;ba=V?16:0;if((H&65280|0)==0){da=ba;ea=H}else{da=ba|8;ea=H>>>8}H=(d[1359664+ea|0]|0)+da|0;ba=31-H|0;if((H|0)==31){H=ba+1|0;V=(Q>>>0>H>>>0?H:Q)+5|0;fa=Y<<H>>>27|ba<<5;ga=Q>>>0>V>>>0?V:Q}else{V=ba<<1;ba=V+6|0;fa=(Y>>>((26-V|0)>>>0))-32|0;ga=Q>>>0>ba>>>0?ba:Q}ba=(fa>>>1^-(fa&1))&65535;b[U>>1]=ba;if((X|0)>1){V=ga;Y=0;H=1;ha=5;ia=ba;ba=U;while(1){ja=ba+128|0;ka=q+((V>>>3)+u)|0;la=ka|0;ma=ka+4|0;ka=d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0;ma=je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0;la=zrc(je(ka|0)|0,ma|0,32-(V&7)|0)|0;ma=la;la=d[1615456+(ha>>>0>6>>>0?6:ha)|0]|0;ka=la&3;na=la>>>5;oa=la>>>2&7;la=ma>>>0>65535>>>0;pa=la?ma>>>16:ma;qa=la?16:0;if((pa&65280|0)==0){ra=qa;sa=pa}else{ra=qa|8;sa=pa>>>8}pa=31-ra-(d[1359664+sa|0]|0)|0;do{if(pa>>>0>ka>>>0){qa=(pa<<1)+(oa-ka)|0;la=qa+V|0;ta=(ka+1<<na)+(-1<<oa)+(ma>>>((32-qa|0)>>>0))|0;ua=Q>>>0>la>>>0?la:Q}else{la=pa+1|0;if((na|0)==0){qa=la+V|0;ta=pa;ua=Q>>>0>qa>>>0?qa:Q;break}else{qa=la+V|0;va=(Q>>>0>qa>>>0?qa:Q)+na|0;ta=(ma<<la>>>((32-na|0)>>>0))+(pa<<na)|0;ua=Q>>>0>va>>>0?va:Q;break}}}while(0);if((ta|0)==0){wa=0}else{wa=Y^-(ta&1)}na=(ia&65535)-wa+(wa^(ta+1|0)>>>1)&65535;b[ja>>1]=na;pa=H+1|0;if((pa|0)<(X|0)){V=ua;Y=wa;H=pa;ha=ta;ia=na;ba=ja}else{xa=ua;break}}}else{xa=ga}ba=c[m>>2]|0;ia=X>>>0>65535>>>0;ha=ia?P>>>14&65535:X;H=ia?16:0;if((ha&65280|0)==0){ya=H;za=ha}else{ya=H|8;za=ha>>>8}ha=(d[1359664+za|0]|0)+ya|0;H=q+((xa>>>3)+u)|0;ia=H|0;Y=H+4|0;H=64<<ha;V=X-1|0;a:do{if((R|0)!=(xa|0)){G=d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0;na=je(d[ia]|d[ia+1|0]<<8|d[ia+2|0]<<16|d[ia+3|0]<<24|0)|0;pa=zrc(je(G|0)|0,na|0,32-(xa&7)|0)|0;na=ba+1596|0;G=pa;pa=2;ma=4;oa=V;ka=xa;while(1){va=R-ka|0;if((va|0)<32){if((G>>>((32-va|0)>>>0)|0)==0){break a}}va=q+((ka>>>3)+u)|0;la=va|0;qa=va+4|0;va=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;qa=je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0;la=zrc(je(va|0)|0,qa|0,32-(ka&7)|0)|0;qa=la;la=d[676416+(ma>>>0>15>>>0?15:ma)|0]|0;va=la&3;Aa=la>>>5;Ba=la>>>2&7;la=qa>>>0>65535>>>0;Ca=la?qa>>>16:qa;Da=la?16:0;if((Ca&65280|0)==0){Ea=Da;Fa=Ca}else{Ea=Da|8;Fa=Ca>>>8}Ca=31-Ea-(d[1359664+Fa|0]|0)|0;do{if(Ca>>>0>va>>>0){Da=(Ca<<1)+(Ba-va)|0;la=Da+ka|0;Ga=(va+1<<Aa)+(-1<<Ba)+(qa>>>((32-Da|0)>>>0))|0;Ha=Q>>>0>la>>>0?la:Q}else{la=Ca+1|0;if((Aa|0)==0){Da=la+ka|0;Ga=Ca;Ha=Q>>>0>Da>>>0?Da:Q;break}else{Da=la+ka|0;Ia=(Q>>>0>Da>>>0?Da:Q)+Aa|0;Ga=(qa<<la>>>((32-Aa|0)>>>0))+(Ca<<Aa)|0;Ha=Q>>>0>Ia>>>0?Ia:Q;break}}}while(0);Ja=oa+1+Ga|0;if(!(Ja>>>0<H>>>0)){break}Aa=q+((Ha>>>3)+u)|0;Ca=Aa|0;qa=Aa+4|0;Aa=d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0;qa=je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0;Ca=zrc(je(Aa|0)|0,qa|0,32-(Ha&7)|0)|0;qa=Ca;Ca=d[1011168+(pa>>>0>9>>>0?9:pa)|0]|0;Aa=Ca&3;Ba=Ca>>>5;va=Ca>>>2&7;Ca=qa>>>0>65535>>>0;Ia=Ca?qa>>>16:qa;la=Ca?16:0;if((Ia&65280|0)==0){Ka=la;La=Ia}else{Ka=la|8;La=Ia>>>8}Ia=31-Ka-(d[1359664+La|0]|0)|0;do{if(Ia>>>0>Aa>>>0){la=(Ia<<1)+(va-Aa)|0;Ca=la+Ha|0;Ma=(Aa+1<<Ba)+(-1<<va)+(qa>>>((32-la|0)>>>0))|0;Na=Q>>>0>Ca>>>0?Ca:Q;Oa=qa<<la}else{la=Ia+1|0;Ca=qa<<la;Da=la+Ha|0;la=Q>>>0>Da>>>0?Da:Q;if((Ba|0)==0){Ma=Ia;Na=la;Oa=Ca;break}Da=la+Ba|0;Ma=(Ca>>>((32-Ba|0)>>>0))+(Ia<<Ba)|0;Na=Q>>>0>Da>>>0?Da:Q;Oa=Ca<<Ba}}while(0);Ba=Ma+1|0;Ia=Oa>>31;qa=Na+1|0;va=Q>>>0>qa>>>0?qa:Q;b[j+((d[(c[na>>2]|0)+(Ja>>>(ha>>>0))|0]|0)+((Ja&V)<<6)<<1)>>1]=(Ba^Ia)-Ia;if((R|0)==(va|0)){break a}else{G=Oa<<1;pa=Ba;ma=Ga;oa=Ja;ka=va}}KIb(e,16,2170920,(Pa=i,i=i+16|0,c[Pa>>2]=Ja,c[Pa+8>>2]=H,Pa)|0);i=Pa;Qa=-1094995529;i=h;return Qa|0}}while(0);if((c[T>>2]|0)!=0){H=n+1312|0;R=L<<2;V=R+8|0;ha=U;Q=0;ba=S;while(1){mf[c[H>>2]&2047](ba,L,ha,I);mf[c[H>>2]&2047](ba+16|0,L,ha+128|0,I);mf[c[H>>2]&2047](ba+(R<<1)|0,L,ha+256|0,I);mf[c[H>>2]&2047](ba+(V<<1)|0,L,ha+384|0,I);ia=Q+1|0;if(ia>>>0<(c[T>>2]|0)>>>0){ha=ha+512|0;Q=ia;ba=ba+32|0}else{break}}}do{if((c[e+88>>2]&8192|0)==0){ba=l|0;Q=vXa(e,p,$,K,q+z|0,y,ba,O)|0;if((Q|0)<0){Qa=Q;i=h;return Qa|0}Q=vXa(e,p,_,K,q+B|0,C,ba,O)|0;if((Q|0)<0){Qa=Q}else{break}i=h;return Qa|0}}while(0);B=n+1604|0;Q=c[B>>2]|0;do{if((Q|0)!=0){if((c[W>>2]|0)==0|(D|0)==(u|0)){break}ba=Z;ha=q+t|0;I=c[T>>2]|0;V=I<<2;if((V|0)>0){H=n+36|0;R=0;do{qe[c[H>>2]&1023](j+(R<<6<<1)|0);R=R+1|0;}while((R|0)<(V|0));Ra=c[B>>2]|0}else{Ra=Q}V=A<<3;R=V>>>0>2147483639>>>0|(ha|0)==0;H=R?0:ha;S=R?0:V;c[f>>2]=H;c[f+12>>2]=S;c[f+16>>2]=S+8;c[f+4>>2]=H+(S>>3);c[f+8>>2]=0;S=I<<8;if((Ra|0)==2){wXa(f,U,S,16)}else{wXa(f,U,S,8)}S=I<<4;H=I<<5;V=L>>1;nrc(Z|0,J|0,H)|0;nrc(ba+(V<<1)|0,j+(S<<1)|0,H)|0;R=V<<1;nrc(ba+(R<<1)|0,j+(H<<1)|0,H)|0;ia=R+V|0;R=H+S|0;nrc(ba+(ia<<1)|0,j+(R<<1)|0,H)|0;Y=ia+V|0;ia=R+S|0;nrc(ba+(Y<<1)|0,j+(ia<<1)|0,H)|0;R=Y+V|0;Y=ia+S|0;nrc(ba+(R<<1)|0,j+(Y<<1)|0,H)|0;ia=R+V|0;R=Y+S|0;nrc(ba+(ia<<1)|0,j+(R<<1)|0,H)|0;Y=ia+V|0;ia=R+S|0;nrc(ba+(Y<<1)|0,j+(ia<<1)|0,H)|0;R=Y+V|0;Y=ia+S|0;nrc(ba+(R<<1)|0,j+(Y<<1)|0,H)|0;ia=R+V|0;R=Y+S|0;nrc(ba+(ia<<1)|0,j+(R<<1)|0,H)|0;Y=ia+V|0;ia=R+S|0;nrc(ba+(Y<<1)|0,j+(ia<<1)|0,H)|0;R=Y+V|0;Y=ia+S|0;nrc(ba+(R<<1)|0,j+(Y<<1)|0,H)|0;ia=R+V|0;R=Y+S|0;nrc(ba+(ia<<1)|0,j+(R<<1)|0,H)|0;Y=ia+V|0;ia=R+S|0;nrc(ba+(Y<<1)|0,j+(ia<<1)|0,H)|0;R=Y+V|0;Y=ia+S|0;nrc(ba+(R<<1)|0,j+(Y<<1)|0,H)|0;nrc(ba+(R+V<<1)|0,j+(Y+S<<1)|0,H)|0}}while(0);c[s>>2]=0;Qa=0;i=h;return Qa|0}}while(0);KIb(e,16,2202656,(Pa=i,i=i+1|0,i=i+7&-8,c[Pa>>2]=0,Pa)|0);i=Pa;Qa=-1094995529;i=h;return Qa|0}function vXa(a,e,f,g,h,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;m=i;i=i+4096|0;n=m|0;o=a+60|0;p=c[o>>2]|0;q=n|0;r=e+12|0;e=c[r>>2]<<l;if((e|0)>0){s=p+36|0;t=0;do{qe[c[s>>2]&1023](n+(t<<6<<1)|0);t=t+1|0;}while((t|0)<(e|0))}t=j<<3;j=t>>>0>2147483639>>>0|(h|0)==0;s=j?0:h;h=j?0:t;t=h+8|0;j=s|0;u=je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;j=u>>>0>65535>>>0;v=j?u>>>16:u;w=j?16:0;if((v&65280|0)==0){x=w;y=v}else{x=w|8;y=v>>>8}v=(d[1359664+y|0]|0)+x|0;x=31-v|0;if((v|0)==31){v=x+1|0;y=(t>>>0>v>>>0?v:t)+5|0;z=u<<v>>>27|x<<5;A=t>>>0>y>>>0?y:t}else{y=x<<1;x=y+6|0;z=(u>>>((26-y|0)>>>0))-32|0;A=t>>>0>x>>>0?x:t}x=(z>>>1^-(z&1))&65535;b[q>>1]=x;if((e|0)>1){z=A;y=0;u=1;v=5;w=x;x=q;while(1){j=x+128|0;B=s+(z>>>3)|0;C=B|0;D=B+4|0;B=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;D=je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=zrc(je(B|0)|0,D|0,32-(z&7)|0)|0;D=C;C=d[1615456+(v>>>0>6>>>0?6:v)|0]|0;B=C&3;E=C>>>5;F=C>>>2&7;C=D>>>0>65535>>>0;G=C?D>>>16:D;H=C?16:0;if((G&65280|0)==0){I=H;J=G}else{I=H|8;J=G>>>8}G=31-I-(d[1359664+J|0]|0)|0;do{if(G>>>0>B>>>0){H=(G<<1)+(F-B)|0;C=H+z|0;K=(B+1<<E)+(-1<<F)+(D>>>((32-H|0)>>>0))|0;L=t>>>0>C>>>0?C:t}else{C=G+1|0;if((E|0)==0){H=C+z|0;K=G;L=t>>>0>H>>>0?H:t;break}else{H=C+z|0;M=(t>>>0>H>>>0?H:t)+E|0;K=(D<<C>>>((32-E|0)>>>0))+(G<<E)|0;L=t>>>0>M>>>0?M:t;break}}}while(0);if((K|0)==0){N=0}else{N=y^-(K&1)}E=(w&65535)-N+(N^(K+1|0)>>>1)&65535;b[j>>1]=E;G=u+1|0;if((G|0)<(e|0)){z=L;y=N;u=G;v=K;w=E;x=j}else{O=L;break}}}else{O=A}A=c[o>>2]|0;o=e>>>0>65535>>>0;L=o?e>>>16:e;x=o?16:0;if((L&65280|0)==0){P=x;Q=L}else{P=x|8;Q=L>>>8}L=(d[1359664+Q|0]|0)+P|0;P=s+(O>>>3)|0;Q=P|0;x=P+4|0;P=64<<L;o=e-1|0;a:do{if((h|0)!=(O|0)){e=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;w=je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0;K=zrc(je(e|0)|0,w|0,32-(O&7)|0)|0;w=A+1596|0;e=K;K=2;v=4;u=o;N=O;while(1){y=h-N|0;if((y|0)<32){if((e>>>((32-y|0)>>>0)|0)==0){break a}}y=s+(N>>>3)|0;z=y|0;J=y+4|0;y=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;J=je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0;z=zrc(je(y|0)|0,J|0,32-(N&7)|0)|0;J=z;z=d[676416+(v>>>0>15>>>0?15:v)|0]|0;y=z&3;I=z>>>5;E=z>>>2&7;z=J>>>0>65535>>>0;G=z?J>>>16:J;D=z?16:0;if((G&65280|0)==0){R=D;S=G}else{R=D|8;S=G>>>8}G=31-R-(d[1359664+S|0]|0)|0;do{if(G>>>0>y>>>0){D=(G<<1)+(E-y)|0;z=D+N|0;T=(y+1<<I)+(-1<<E)+(J>>>((32-D|0)>>>0))|0;U=t>>>0>z>>>0?z:t}else{z=G+1|0;if((I|0)==0){D=z+N|0;T=G;U=t>>>0>D>>>0?D:t;break}else{D=z+N|0;F=(t>>>0>D>>>0?D:t)+I|0;T=(J<<z>>>((32-I|0)>>>0))+(G<<I)|0;U=t>>>0>F>>>0?F:t;break}}}while(0);V=u+1+T|0;if(!(V>>>0<P>>>0)){break}I=s+(U>>>3)|0;G=I|0;J=I+4|0;I=d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0;J=je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0;G=zrc(je(I|0)|0,J|0,32-(U&7)|0)|0;J=G;G=d[1011168+(K>>>0>9>>>0?9:K)|0]|0;I=G&3;E=G>>>5;y=G>>>2&7;G=J>>>0>65535>>>0;F=G?J>>>16:J;z=G?16:0;if((F&65280|0)==0){W=z;X=F}else{W=z|8;X=F>>>8}F=31-W-(d[1359664+X|0]|0)|0;do{if(F>>>0>I>>>0){z=(F<<1)+(y-I)|0;G=z+U|0;Y=(I+1<<E)+(-1<<y)+(J>>>((32-z|0)>>>0))|0;Z=t>>>0>G>>>0?G:t;_=J<<z}else{z=F+1|0;G=J<<z;D=z+U|0;z=t>>>0>D>>>0?D:t;if((E|0)==0){Y=F;Z=z;_=G;break}D=z+E|0;Y=(G>>>((32-E|0)>>>0))+(F<<E)|0;Z=t>>>0>D>>>0?D:t;_=G<<E}}while(0);E=Y+1|0;F=_>>31;J=Z+1|0;y=t>>>0>J>>>0?J:t;b[n+((d[(c[w>>2]|0)+(V>>>(L>>>0))|0]|0)+((V&o)<<6)<<1)>>1]=(E^F)-F;if((h|0)==(y|0)){break a}else{e=_<<1;K=E;v=T;u=V;N=y}}KIb(a,16,2170920,(N=i,i=i+16|0,c[N>>2]=V,c[N+8>>2]=P,N)|0);i=N;$=-1094995529;i=m;return $|0}}while(0);P=c[r>>2]|0;if((P|0)==0){$=0;i=m;return $|0}V=p+1312|0;p=g<<2;if((l|0)<=0){a=0;while(1){T=a+1|0;if(T>>>0<P>>>0){a=T}else{$=0;break}}i=m;return $|0}a=l<<3;P=l<<7;T=q;q=0;_=f;while(1){f=_+(a<<1)|0;h=T;o=0;L=_;while(1){mf[c[V>>2]&2047](L,g,h,k);mf[c[V>>2]&2047](L+(p<<1)|0,g,h+128|0,k);n=o+1|0;if((n|0)<(l|0)){h=h+256|0;o=n;L=L+16|0}else{break}}L=q+1|0;if(L>>>0<(c[r>>2]|0)>>>0){T=T+(P<<1)|0;q=L;_=f}else{$=0;break}}i=m;return $|0}function wXa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=(1<<g)-1|0;i=a+8|0;j=(g|0)==16;k=j?7:4;l=32-k|0;m=a+12|0;n=32-g|0;o=~f;p=c[a>>2]|0;q=c[a+16>>2]|0;a=h;r=0;s=c[i>>2]|0;a:while(1){t=d[p+(s>>>3)|0]|0;u=((s|0)<(q|0))+s|0;c[i>>2]=u;v=p+(u>>>3)|0;w=v|0;x=v+4|0;v=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;w=zrc(je(v|0)|0,x|0,32-(u&7)|0)|0;x=w;do{if((t&128>>>((s&7)>>>0)|0)==0){w=x>>>(l>>>0);v=u+k|0;y=q>>>0>v>>>0?v:q;c[i>>2]=y;v=w+2>>1;if((w&1|0)==0){z=v;A=y;break}z=-v|0;A=y}else{y=u+g|0;v=q>>>0>y>>>0?y:q;c[i>>2]=v;z=x>>>(n>>>0);A=v}}while(0);x=z+a&h;if(j){b[e+(r<<1)>>1]=x>>>6}else{b[e+(r<<1)>>1]=x<<2|x>>>6}u=r+1|0;do{if((u|0)<(f|0)){if(((c[m>>2]|0)-A|0)<=0){B=A;break}t=d[p+(A>>>3)|0]|0;v=((A|0)<(q|0))+A|0;c[i>>2]=v;if((t&128>>>((A&7)>>>0)|0)==0){B=v}else{a=x;r=u;s=v;continue a}}else{B=A}}while(0);v=p+(B>>>3)|0;t=v|0;y=v+4|0;v=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;y=je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0;t=zrc(je(v|0)|0,y|0,32-(B&7)|0)|0;y=t>>>28;t=B+4|0;v=q>>>0>t>>>0?t:q;c[i>>2]=v;if((y|0)==0){t=p+(v>>>3)|0;w=t|0;C=t+4|0;t=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0;w=zrc(je(t|0)|0,C|0,32-(v&7)|0)|0;C=v+11|0;t=q>>>0>C>>>0?C:q;c[i>>2]=t;D=w>>>21;E=t}else{D=y;E=v}v=(D+u|0)>(f|0)?f-u|0:D;y=(v|0)>0;do{if(j){if(!y){F=u;break}t=x>>>6&65535;w=-2-r-D|0;C=(w|0)<(o|0)?o:w;w=u;G=0;while(1){b[e+(w<<1)>>1]=t;H=G+1|0;if((H|0)<(v|0)){w=w+1|0;G=H}else{break}}F=~C}else{if(!y){F=u;break}G=(x<<2|x>>>6)&65535;w=-2-r-D|0;t=(w|0)<(o|0)?o:w;w=u;H=0;while(1){b[e+(w<<1)>>1]=G;I=H+1|0;if((I|0)<(v|0)){w=w+1|0;H=I}else{break}}F=~t}}while(0);if((F|0)<(f|0)){a=x;r=F;s=E}else{break}}return}function xXa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+352>>2]=0;c[b+356>>2]=0;c[a+796>>2]=10;EXa(b,a);c[b+208>>2]=-1;mrc(b+220|0,4,128)|0;return 0}function yXa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;h=i;j=c[b+60>>2]|0;k=c[g+24>>2]|0;l=g+28|0;g=c[l>>2]|0;m=e;n=j+72|0;c[n>>2]=m;c[e+88>>2]=1;c[e+84>>2]=1;do{if((g|0)>=28){e=k;if(g>>>0<(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)>>>0){break}e=k+4|0;if((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)!=1718641513){break}e=k+8|0;o=g-8|0;p=e;q=(he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0)&65535;if((q|0)>(o|0)){KIb(b,16,2614792,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}p=k+10|0;t=he((d[p]|d[p+1|0]<<8)<<16>>16|0)|0;if((t&65535)>>>0>1>>>0){KIb(b,16,2587896,(r=i,i=i+8|0,c[r>>2]=t&65535,r)|0);i=r;s=-1094995529;i=h;return s|0}t=k+16|0;p=(he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535;t=k+18|0;u=(he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&65535;t=b+120|0;v=c[t>>2]|0;w=b+124|0;x=c[w>>2]|0;if(!((p|0)==(v|0)&(u|0)==(x|0))){KIb(b,16,2566624,(r=i,i=i+32|0,c[r>>2]=v,c[r+8>>2]=x,c[r+16>>2]=p,c[r+24>>2]=u,r)|0);i=r;s=-1094995529;i=h;return s|0}u=k+20|0;p=(d[u]|0)>>>2&3;x=j+212|0;c[x>>2]=p;if((p|0)==3){KIb(b,16,2548384,(r=i,i=i+8|0,c[r>>2]=3,r)|0);i=r;s=-1094995529;i=h;return s|0}v=(d[u]|0)>>>6;c[j+364>>2]=v;c[j+368>>2]=v+2;c[j+372>>2]=1<<v>>1;u=a[k+25|0]&15;y=j+400|0;c[y>>2]=u;if(u>>>0>2>>>0){KIb(b,16,2530576,(r=i,i=i+8|0,c[r>>2]=u,r)|0);i=r;s=-1094995529;i=h;return s|0}if((c[b+944>>2]|0)==0){z=u}else{c[y>>2]=0;z=0}if((v|0)==3){c[b+140>>2]=(z|0)!=0?102:78}else if((v|0)==2){c[b+140>>2]=(z|0)!=0?100:74}else{KIb(b,16,2515312,(r=i,i=i+8|0,c[r>>2]=c[j+216>>2],r)|0);i=r;s=-1094995529;i=h;return s|0}v=j+208|0;if((c[v>>2]|0)==(p|0)){A=p;B=m}else{y=j+4|0;u=j+76|0;if((p|0)==0){L6(y,u,1322152)}else{L6(y,u,1322440)}u=c[x>>2]|0;c[v>>2]=u;A=u;B=c[n>>2]|0}u=B+296|0;if((A|0)==0){c[u>>2]=0}else{c[u>>2]=1;c[B+300>>2]=c[x>>2]&1}c[b+384>>2]=d[k+22|0]|0;c[b+388>>2]=d[k+23|0]|0;c[b+392>>2]=d[k+24|0]|0;x=j+348|0;c[x>>2]=0;u=k+28|0;v=d[k+27|0]|0;if((v&2|0)==0){mrc(j+220|0,4,64)|0;c[x>>2]=1;C=u}else{if((q-64|0)<20){KIb(b,16,2501416,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}y=j+220|0;if((grc(y,u,64)|0)!=0){nrc(y|0,u|0,64)|0;c[x>>2]=1}C=k+92|0}do{if((v&1|0)==0){mrc(j+284|0,4,64)|0;c[x>>2]=1}else{if((C-e|0)>(q-64|0)){KIb(b,16,2501416,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else{u=j+284|0;if((grc(u,C,64)|0)==0){break}nrc(u|0,C|0,64)|0;c[x>>2]=1;break}}}while(0);if((M4a(b,B,0)|0)<0){s=-1;i=h;return s|0}x=c[n>>2]|0;a:do{if(!((c[x+296>>2]|0)==-1)){e=j+384|0;v=j+388|0;u=j+392|0;y=j+396|0;p=j+352|0;D=j+356|0;E=D;F=j+360|0;G=b+824|0;H=o-q|0;I=k+(q+8)|0;J=0;K=x;while(1){if((H|0)<=0){L=47;break}M=a[I]|0;N=(M&255)>>>3;if((M&255)>>>0<64>>>0|(N|0)>(H|0)){L=47;break}M=I+1|0;O=je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0;if((O|0)>(H|0)){L=49;break}M=a[I+7|0]|0;P=M&255;Q=P>>>4;R=P&15;if(!((M&255)>>>0<64>>>0&(R|0)==0)){L=51;break}c[e>>2]=Q;c[v>>2]=0;M=(c[t>>2]|0)+15>>4;c[u>>2]=M;P=(c[K+296>>2]|0)+4|0;S=(c[w>>2]|0)-1+(1<<P)>>P;c[y>>2]=S;P=M&(1<<Q)-1;T=ca((P&1)+(M>>Q)+(P>>>1&1)+(P>>>2&1)|0,S)|0;S=I+5|0;if((T|0)!=((he((d[S]|d[S+1|0]<<8)<<16>>16|0)|0)&65535|0)){L=53;break}if((c[p>>2]|0)!=(T|0)){mJb(D);S=hJb((T*4384|0)+4384|0)|0;c[E>>2]=S;if((S|0)==0){s=-1094995529;L=76;break}c[p>>2]=T}S=(T<<1)+N|0;if((S|0)>(H|0)){L=58;break}P=I+S|0;c[c[E>>2]>>2]=P;S=c[E>>2]|0;c[S+20>>2]=0;if((T|0)>0){M=0;U=P;V=S;while(1){W=I+((M<<1)+N)|0;X=U+((he((d[W]|d[W+1|0]<<8)<<16>>16|0)|0)&65535)|0;W=M+1|0;c[V+(W*4384|0)>>2]=X;Y=c[E>>2]|0;c[Y+(W*4384|0)+20>>2]=0;if((W|0)<(T|0)){M=W;U=X;V=Y}else{Z=X;_=Y;break}}}else{Z=P;_=S}if(Z>>>0>(I+H|0)>>>0){L=62;break}if((O|0)<0){s=-1094995529;L=76;break}c[F>>2]=J;V=c[y>>2]|0;if((V|0)>0){U=0;M=0;T=c[u>>2]|0;N=V;while(1){if((T|0)<1){$=U;aa=T;ba=N}else{V=U;Y=1<<c[e>>2];X=0;W=T;while(1){da=W-X|0;ea=Y;while(1){if((da|0)<(ea|0)){ea=ea>>1}else{break}}c[_+(V*4384|0)+4>>2]=V;c[_+(V*4384|0)+8>>2]=X;c[_+(V*4384|0)+12>>2]=M;c[_+(V*4384|0)+16>>2]=ea;fa=V+1|0;da=ea+X|0;ga=c[u>>2]|0;if((da|0)>=(ga|0)|(ea|0)==0){break}else{V=fa;Y=ea;X=da;W=ga}}$=fa;aa=ga;ba=c[y>>2]|0}W=M+1|0;if((W|0)<(ba|0)){U=$;M=W;T=aa;N=ba}else{ha=$;break}}}else{ha=0}if((se[c[G>>2]&127](b,934,_,0,ha,4384)|0)!=0){s=-1;L=76;break}N=J+1|0;T=c[n>>2]|0;if(((c[T+296>>2]|0)-N|0)==-1){break a}else{H=H-O|0;I=I+O|0;J=N;K=T}}if((L|0)==47){KIb(b,16,2244176,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==49){KIb(b,16,2202592,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==51){KIb(b,16,2170880,(r=i,i=i+16|0,c[r>>2]=1<<Q,c[r+8>>2]=1<<R,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==53){KIb(b,16,2143496,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==58){KIb(b,16,2119928,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==62){KIb(b,16,2637992,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}else if((L|0)==76){i=h;return s|0}}}while(0);c[n>>2]=0;c[f>>2]=1;s=c[l>>2]|0;i=h;return s|0}}while(0);KIb(b,16,2447968,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=h;return s|0}function zXa(a){a=a|0;mJb((c[a+60>>2]|0)+356|0);return 0}function AXa(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=i;i=i+24|0;h=g|0;j=f;k=c[e+60>>2]|0;l=k;m=c[f+8>>2]|0;n=c[f+12>>2]|0;o=c[f+4>>2]|0;p=c[f+16>>2]|0;q=c[k+72>>2]|0;r=c[k+356>>2]|0;s=c[r+(o*4384|0)>>2]|0;t=(c[r+((o+1|0)*4384|0)>>2]|0)-s|0;o=p>>>0>65535>>>0;r=o?p>>>16:p;u=o?16:0;if((r&65280|0)==0){v=u;w=r}else{v=u|8;w=r>>>8}r=(d[1359664+w|0]|0)+v|0;v=c[q>>2]|0;w=c[q+4>>2]|0;u=c[q+8>>2]|0;o=c[q+12>>2]|0;x=c[q+32>>2]|0;y=c[q+36>>2]|0;z=c[q+40>>2]|0;A=c[q+44>>2]|0;if((c[q+296>>2]|0)==0){B=v;C=w;D=u;E=A;F=z;G=y;H=x;I=o}else{do{if((c[k+360>>2]|0)==(c[q+300>>2]|0)){J=v+x|0;K=w+y|0;L=u+z|0;if((o|0)==0){M=J;N=K;O=L;P=0;break}M=J;N=K;O=L;P=o+A|0}else{M=v;N=w;O=u;P=o}}while(0);B=M;C=N;D=O;E=A<<1;F=z<<1;G=y<<1;H=x<<1;I=P}P=n<<4;n=m<<5;x=B+((ca(H,P)|0)+n)|0;B=ca(G,P)|0;y=m<<c[k+368>>2];m=C+(y+B)|0;B=D+(y+(ca(F,P)|0))|0;if((I|0)==0){Q=0}else{Q=I+((ca(E,P)|0)+n)|0}if((t|0)<6){KIb(e,16,2358776,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;S=-1094995529;i=g;return S|0}n=a[s]|0;P=(n&255)>>>3;I=s+2|0;y=(he((d[I]|d[I+1|0]<<8)<<16>>16|0)|0)&65535;I=y+P|0;D=s+4|0;C=(he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=C+I|0;if((n&255)>>>0>63>>>0){z=s+6|0;T=(he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535}else{T=t-D|0}z=T+D|0;A=k+400|0;O=(c[A>>2]|0)==0?0:t-z|0;if((O|T|0)<0|(n&255)>>>0<48>>>0){KIb(e,16,2295136,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;S=-1094995529;i=g;return S|0}R=a[s+1|0]|0;e=R&255;do{if(R<<24>>24==0){U=1}else{n=e>>>0>224>>>0?224:e;if(!(n>>>0>128>>>0)){U=n;break}U=(n<<2)-384|0}}while(0);e=f+20|0;do{if((c[k+348>>2]|0)==0){if((U|0)!=(c[e>>2]|0)){V=23;break}W=f+4128|0}else{V=23}}while(0);if((V|0)==23){c[e>>2]=U;e=f+4128|0;V=e;R=f+4256|0;n=0;while(1){t=(ca(d[k+(n+220)|0]|0,U)|0)&65535;N=k+(n+4)|0;b[V+((d[N]|0)<<1)>>1]=t;t=(ca(d[k+(n+284)|0]|0,U)|0)&65535;b[R+((d[N]|0)<<1)>>1]=t;t=n+1|0;if((t|0)<64){n=t}else{W=e;break}}}e=BXa(l,j,s+P|0,y,x,H,p,4,r+2|0,W,0)|0;if((e|0)<0){S=e;i=g;return S|0}e=k+372|0;W=k+364|0;k=r-1|0;r=f+4256|0;H=BXa(l,j,s+I|0,C,m,G,p,c[e>>2]|0,k+(c[W>>2]|0)|0,r,1)|0;if((H|0)<0){S=H;i=g;return S|0}H=BXa(l,j,s+D|0,T,B,F,p,c[e>>2]|0,k+(c[W>>2]|0)|0,r,1)|0;if((H|0)<0){S=H;i=g;return S|0}if((Q|0)==0|(O|0)==0){S=0;i=g;return S|0}H=s+z|0;z=Q;s=f+32|0;mrc(s|0,0,4096)|0;f=O<<3;O=f>>>0>2147483639>>>0|(H|0)==0;r=O?0:H;H=O?0:f;c[h>>2]=r;c[h+12>>2]=H;c[h+16>>2]=H+8;c[h+4>>2]=r+(H>>3);c[h+8>>2]=0;H=s;r=p<<8;if((c[A>>2]|0)==2){CXa(h,H,r,16)}else{CXa(h,H,r,8)}r=p<<4;H=p<<5;p=E>>1;nrc(Q|0,s|0,H)|0;nrc(z+(p<<1)|0,j+32+(r<<1)|0,H)|0;s=p<<1;nrc(z+(s<<1)|0,j+32+(H<<1)|0,H)|0;Q=s+p|0;s=H+r|0;nrc(z+(Q<<1)|0,j+32+(s<<1)|0,H)|0;E=Q+p|0;Q=s+r|0;nrc(z+(E<<1)|0,j+32+(Q<<1)|0,H)|0;s=E+p|0;E=Q+r|0;nrc(z+(s<<1)|0,j+32+(E<<1)|0,H)|0;Q=s+p|0;s=E+r|0;nrc(z+(Q<<1)|0,j+32+(s<<1)|0,H)|0;E=Q+p|0;Q=s+r|0;nrc(z+(E<<1)|0,j+32+(Q<<1)|0,H)|0;s=E+p|0;E=Q+r|0;nrc(z+(s<<1)|0,j+32+(E<<1)|0,H)|0;Q=s+p|0;s=E+r|0;nrc(z+(Q<<1)|0,j+32+(s<<1)|0,H)|0;E=Q+p|0;Q=s+r|0;nrc(z+(E<<1)|0,j+32+(Q<<1)|0,H)|0;s=E+p|0;E=Q+r|0;nrc(z+(s<<1)|0,j+32+(E<<1)|0,H)|0;Q=s+p|0;s=E+r|0;nrc(z+(Q<<1)|0,j+32+(s<<1)|0,H)|0;E=Q+p|0;Q=s+r|0;nrc(z+(E<<1)|0,j+32+(Q<<1)|0,H)|0;s=E+p|0;E=Q+r|0;nrc(z+(s<<1)|0,j+32+(E<<1)|0,H)|0;nrc(z+(s+p<<1)|0,j+32+(E+r<<1)|0,H)|0;S=0;i=g;return S|0}function BXa(a,e,f,g,h,j,k,l,m,n,o){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;p=i;i=i+24|0;q=p|0;r=ca(l,k)|0;s=e+32|0;mrc(s|0,0,4096)|0;t=g<<3;g=t>>>0>2147483639>>>0|(f|0)==0;u=g?0:f;f=g?0:t;t=q|0;c[t>>2]=u;g=q+12|0;c[g>>2]=f;v=f+8|0;w=q+16|0;c[w>>2]=v;c[q+4>>2]=u+(f>>3);f=q+8|0;c[f>>2]=0;x=s|0;s=u|0;u=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;s=u>>>0>65535>>>0;y=s?u>>>16:u;z=s?16:0;if((y&65280|0)==0){A=z;B=y}else{A=z|8;B=y>>>8}y=d[1359664+B|0]|0;B=31-A|0;A=B-y|0;if((B|0)==(y|0)){y=A+6|0;C=u<<A+1>>>27|A<<5;D=v>>>0>y>>>0?y:v}else{y=A<<1;A=y+6|0;C=(u>>>((26-y|0)>>>0))-32|0;D=v>>>0>A>>>0?A:v}c[f>>2]=D;D=(C>>>1^-(C&1))&65535;b[x>>1]=D;if((r|0)>1){C=D;D=1;v=3;A=x;while(1){y=A+128|0;u=(v|0)>-1?v:-v|0;B=DXa(q,d[1322712+((u|0)>3?3:u)|0]|0)|0;u=(B^v>>>15)&1;z=((B+1|0)>>>1^-u)+u&65535;u=z+C&65535;b[y>>1]=u;B=D+1|0;if((B|0)<(r|0)){C=u;D=B;v=z<<16>>16;A=y}else{break}}}A=r<<6;v=r-1|0;a:do{if((v|0)<(A|0)){r=c[f>>2]|0;D=(c[g>>2]|0)-r|0;if((D|0)<1){break}else{E=r;F=v;G=1322140;H=1322322;I=D}while(1){D=d[G]|0;r=d[H]|0;if((I|0)<9){C=(c[t>>2]|0)+(E>>>3)|0;y=C|0;z=C+4|0;C=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;z=je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=zrc(je(C|0)|0,z|0,32-(E&7)|0)|0;if((y>>>((32-I|0)>>>0)|0)==0){break a}}y=DXa(q,d[1322824+D|0]|0)|0;if((y|0)<0){J=-1094995529;K=28;break}D=c[f>>2]|0;z=(c[g>>2]|0)-D|0;if((z|0)<1){J=-1094995529;K=28;break}if((z|0)<9){C=(c[t>>2]|0)+(D>>>3)|0;B=C|0;u=C+4|0;C=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0;u=je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0;B=zrc(je(C|0)|0,u|0,32-(D&7)|0)|0;if((B>>>((32-z|0)>>>0)|0)==0){J=-1094995529;K=28;break}}z=(DXa(q,d[1322824+r|0]|0)|0)+1|0;if((z|0)<0){J=-1094995529;K=28;break}r=F+1+y|0;if((r|0)>=(A|0)){break a}B=c[f>>2]|0;D=c[w>>2]|0;u=(c[t>>2]|0)+(B>>>3)|0;C=u|0;s=u+4|0;u=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=zrc(je(u|0)|0,s|0,32-(B&7)|0)|0;s=C>>31;C=B+1|0;B=D>>>0>C>>>0?C:D;c[f>>2]=B;b[e+32+((d[(r>>m)+(a+80)|0]|0)+((r&v)<<6)<<1)>>1]=(s^z)-s;s=(c[g>>2]|0)-B|0;if((s|0)<1){break a}else{E=B;F=r;G=1322136+((y|0)>15?15:y)|0;H=1322320+((z|0)>9?9:z)|0;I=s}}if((K|0)==28){i=p;return J|0}}}while(0);K=(k|0)>0;if((o|0)==0){if(!K){J=0;i=p;return J|0}o=a+68|0;I=j<<2;H=I+8|0;G=l<<2;if((l|0)>2){F=x;E=0;g=h;while(1){mf[c[o>>2]&2047](g,j,F,n);mf[c[o>>2]&2047](g+16|0,j,F+128|0,n);mf[c[o>>2]&2047](g+(I<<1)|0,j,F+256|0,n);mf[c[o>>2]&2047](g+(H<<1)|0,j,F+384|0,n);v=E+1|0;if((v|0)<(k|0)){F=F+512|0;E=v;g=g+(G<<1)|0}else{J=0;break}}i=p;return J|0}else{g=x;E=0;F=h;while(1){mf[c[o>>2]&2047](F,j,g,n);mf[c[o>>2]&2047](F+(I<<1)|0,j,g+128|0,n);H=E+1|0;if((H|0)<(k|0)){g=g+256|0;E=H;F=F+(G<<1)|0}else{J=0;break}}i=p;return J|0}}else{if(!K){J=0;i=p;return J|0}K=a+68|0;a=j<<2;G=a+8|0;F=l<<2;if((l|0)>2){l=x;E=0;g=h;while(1){mf[c[K>>2]&2047](g,j,l,n);mf[c[K>>2]&2047](g+(a<<1)|0,j,l+128|0,n);mf[c[K>>2]&2047](g+16|0,j,l+256|0,n);mf[c[K>>2]&2047](g+(G<<1)|0,j,l+384|0,n);I=E+1|0;if((I|0)<(k|0)){l=l+512|0;E=I;g=g+(F<<1)|0}else{J=0;break}}i=p;return J|0}else{g=x;x=0;E=h;while(1){mf[c[K>>2]&2047](E,j,g,n);mf[c[K>>2]&2047](E+(a<<1)|0,j,g+128|0,n);h=x+1|0;if((h|0)<(k|0)){g=g+256|0;x=h;E=E+(F<<1)|0}else{J=0;break}}i=p;return J|0}}return 0}function CXa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=(1<<g)-1|0;i=a+8|0;j=(g|0)==16;k=j?7:4;l=32-k|0;m=32-g|0;n=~f;o=c[a>>2]|0;p=c[a+16>>2]|0;a=h;q=0;r=c[i>>2]|0;while(1){s=d[o+(r>>>3)|0]|0;t=((r|0)<(p|0))+r|0;c[i>>2]=t;u=o+(t>>>3)|0;v=u|0;w=u+4|0;u=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;w=je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=zrc(je(u|0)|0,w|0,32-(t&7)|0)|0;w=v;do{if((s&128>>>((r&7)>>>0)|0)==0){v=w>>>(l>>>0);u=t+k|0;x=p>>>0>u>>>0?u:p;c[i>>2]=x;u=v+2>>1;if((v&1|0)==0){y=u;z=x;break}y=-u|0;z=x}else{x=t+g|0;u=p>>>0>x>>>0?x:p;c[i>>2]=u;y=w>>>(m>>>0);z=u}}while(0);w=y+a&h;if(j){b[e+(q<<1)>>1]=w>>>6}else{b[e+(q<<1)>>1]=w<<2|w>>>6}t=q+1|0;if((t|0)<(f|0)){s=d[o+(z>>>3)|0]|0;u=((z|0)<(p|0))+z|0;c[i>>2]=u;if((s&128>>>((z&7)>>>0)|0)==0){A=u}else{a=w;q=t;r=u;continue}}else{A=z}u=o+(A>>>3)|0;s=u|0;x=u+4|0;u=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0;s=zrc(je(u|0)|0,x|0,32-(A&7)|0)|0;x=s>>>28;s=A+4|0;u=p>>>0>s>>>0?s:p;c[i>>2]=u;if((x|0)==0){s=o+(u>>>3)|0;v=s|0;B=s+4|0;s=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0;v=zrc(je(s|0)|0,B|0,32-(u&7)|0)|0;B=u+11|0;s=p>>>0>B>>>0?B:p;c[i>>2]=s;C=v>>>21;D=s}else{C=x;D=u}u=(C+t|0)>(f|0)?f-t|0:C;x=(u|0)>0;do{if(j){if(!x){E=t;break}s=w>>>6&65535;v=-2-q-C|0;B=(v|0)<(n|0)?n:v;v=t;F=0;while(1){b[e+(v<<1)>>1]=s;G=F+1|0;if((G|0)<(u|0)){v=v+1|0;F=G}else{break}}E=~B}else{if(!x){E=t;break}F=(w<<2|w>>>6)&65535;v=-2-q-C|0;s=(v|0)<(n|0)?n:v;v=t;G=0;while(1){b[e+(v<<1)>>1]=F;H=G+1|0;if((H|0)<(u|0)){v=v+1|0;G=H}else{break}}E=~s}}while(0);if((E|0)<(f|0)){a=w;q=E;r=D}else{break}}return}function DXa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=(c[a>>2]|0)+(f>>>3)|0;a=h|0;i=h+4|0;h=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0;a=zrc(je(h|0)|0,i|0,32-(f&7)|0)|0;i=a;a=(b&3)+1|0;h=b>>>5;j=b>>>2&7;b=i>>>0>65535>>>0;k=b?i>>>16:i;l=b?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=31-m-(d[1359664+n|0]|0)|0;if(!(k>>>0<a>>>0)){n=(k<<1)-a+j|0;m=f+1+n|0;o=(a<<h)+(-1<<j)+(i>>>((31-n|0)>>>0))|0;p=g>>>0>m>>>0?m:g;c[e>>2]=p;return o|0}m=k+1|0;if((h|0)==0){n=m+f|0;o=k;p=g>>>0>n>>>0?n:g;c[e>>2]=p;return o|0}else{n=f+h+m|0;o=(i<<m>>>((32-h|0)>>>0))+(k<<h)|0;p=g>>>0>n>>>0?n:g;c[e>>2]=p;return o|0}return 0}function EXa(a,b){a=a|0;b=b|0;c[a+68>>2]=786;c[a>>2]=1;M6(a+4|0,1);return}function FXa(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;F0a(d,e);e=c>>1;c=0;f=0;while(1){g=c<<3;h=b[d+(g<<1)>>1]|0;if(h<<16>>16<4){i=4}else{i=h<<16>>16>1019?1019:h}b[a+(f<<1)>>1]=i;h=b[d+((g|1)<<1)>>1]|0;if(h<<16>>16<4){j=4}else{j=h<<16>>16>1019?1019:h}b[a+(f+1<<1)>>1]=j;h=b[d+((g|2)<<1)>>1]|0;if(h<<16>>16<4){k=4}else{k=h<<16>>16>1019?1019:h}b[a+(f+2<<1)>>1]=k;h=b[d+((g|3)<<1)>>1]|0;if(h<<16>>16<4){l=4}else{l=h<<16>>16>1019?1019:h}b[a+(f+3<<1)>>1]=l;h=b[d+((g|4)<<1)>>1]|0;if(h<<16>>16<4){m=4}else{m=h<<16>>16>1019?1019:h}b[a+(f+4<<1)>>1]=m;h=b[d+((g|5)<<1)>>1]|0;if(h<<16>>16<4){n=4}else{n=h<<16>>16>1019?1019:h}b[a+(f+5<<1)>>1]=n;h=b[d+((g|6)<<1)>>1]|0;if(h<<16>>16<4){o=4}else{o=h<<16>>16>1019?1019:h}b[a+(f+6<<1)>>1]=o;h=b[d+((g|7)<<1)>>1]|0;if(h<<16>>16<4){p=4}else{p=h<<16>>16>1019?1019:h}b[a+(f+7<<1)>>1]=p;h=c+1|0;if((h|0)<8){c=h;f=f+e|0}else{break}}return}function GXa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;e=c[a+60>>2]|0;if((c[a+140>>2]|0)!=74){KIb(a,16,2202544,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1;i=b;return g|0}h=c[a+120>>2]|0;if((h&1|0)!=0){KIb(a,16,2170832,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1;i=b;return g|0}if((c[a+124>>2]&15|0)==0){if((h&15|0)!=0){j=7}}else{j=7}do{if((j|0)==7){h=hJb(8192)|0;c[e>>2]=h;if((h|0)==0){g=-12;i=b;return g|0}else{c[e+4>>2]=h+4096;c[e+8>>2]=h+6144;break}}}while(0);j=a+840|0;h=c[j>>2]|0;do{if((h|0)==-99){c[j>>2]=2;KIb(a,32,2143432,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;k=c[j>>2]|0}else{if(!(h>>>0>3>>>0)){k=h;break}KIb(a,16,2119816,(f=i,i=i+8|0,c[f>>2]=h,f)|0);i=f;g=-1;i=b;return g|0}}while(0);f=c[699260+(k<<3)>>2]|0;c[a+52>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24;f=e+12|0;h=e+4108|0;e=1;l=k;while(1){k=e-1|0;m=0;do{c[f+(k<<8)+(m<<2)>>2]=ca(d[2656104+(l<<6)+m|0]|0,e)|0;m=m+1|0;}while((m|0)<64);m=c[j>>2]|0;n=0;do{c[h+(k<<8)+(n<<2)>>2]=ca(d[2656360+(m<<6)+n|0]|0,e)|0;n=n+1|0;}while((n|0)<64);n=e+1|0;if((n|0)>=17){break}e=n;l=c[j>>2]|0}j=UHb()|0;c[a+804>>2]=j;c[j+84>>2]=1;c[j+88>>2]=1;g=0;i=b;return g|0}function HXa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;g=b+120|0;h=b+124|0;i=(ca((c[g>>2]<<4)+240&-256,(c[h>>2]|0)+15&-16)|0|500)+32768|0;j=d5a(b,d,i,(i|0)<0|0?-1:0)|0;if((j|0)<0){k=j;return k|0}j=c[d+24>>2]|0;i=d+28|0;l=c[i>>2]|0;m=(c[g>>2]|0)+15>>4;n=c[h>>2]|0;o=a[1359672]|0;p=o&255;q=0;r=m;while(1){s=(r>>p)+q|0;t=(1<<p)-1&r;if((p|0)>0){p=p-1|0;q=s;r=t}else{break}}r=j+156|0;q=n+15>>4;n=b+840|0;p=ca(s,q)|0;s=j+((p<<1)+164)|0;if((q|0)>0){t=(m|0)>0;u=b+60|0;v=e+32|0;w=e+36|0;x=e|0;z=e+4|0;A=e+8|0;e=b+88|0;b=q-1|0;B=c[692256+(c[n>>2]<<2)>>2]|0;C=j+164|0;D=l-164|0;l=0;E=s;while(1){if(t){F=l<<4;G=(l|0)==(b|0);H=B;I=C;J=D;K=E;L=0;M=8;while(1){N=m-L|0;O=M;while(1){if((N|0)<(O|0)){O=O>>1}else{break}}N=c[h>>2]|0;P=c[g>>2]|0;if((P&15|0)==0){Q=0}else{Q=(O+L|0)==(m|0)}R=c[u>>2]|0;S=ca(c[1906264+(c[n>>2]<<2)>>2]|0,O)|0;T=S>>>2;U=S>>>5;S=T-U>>3;V=(T+U|0)>>>3;U=c[v>>2]|0;T=c[w>>2]|0;W=c[x>>2]|0;X=W+((ca(U,F)|0)+(L<<5))|0;Y=L<<4;Z=(ca(T,F)|0)+Y|0;_=(c[z>>2]|0)+Z|0;$=(c[A>>2]|0)+Z|0;a:do{if(G&(N&15|0)!=0|Q){Z=R;aa=O<<4;JXa(W,Y,F,U,P,N,c[Z>>2]|0,aa);ba=L<<3;da=R+4|0;ea=O<<3;JXa(c[z>>2]|0,ba,F,T,c[g>>2]>>1,c[h>>2]|0,c[da>>2]|0,ea);fa=R+8|0;JXa(c[A>>2]|0,ba,F,T,c[g>>2]>>1,c[h>>2]|0,c[fa>>2]|0,ea);ea=c[da>>2]|0;da=c[fa>>2]|0;fa=J-6|0;ba=c[u>>2]|0;ga=H-1|0;ha=KXa(O,c[Z>>2]|0,O<<5,K+6|0,fa,ba+12+(ga<<8)|0,0)|0;if((c[e>>2]&8192|0)!=0){ia=0;ja=0;ka=ha;la=H;break}Z=ha+6|0;ma=fa-ha|0;fa=ba+4108+(ga<<8)|0;ga=KXa(O,ea,aa,K+Z|0,ma,fa,1)|0;ia=KXa(O,da,aa,K+(ga+Z)|0,ma-ga|0,fa,1)|0;ja=ga;ka=ha;la=H}else{ha=K+6|0;ga=J-6|0;fa=H-1|0;ma=KXa(O,X,U,ha,ga,R+12+(fa<<8)|0,0)|0;if((c[e>>2]&8192|0)==0){Z=ma+6|0;aa=ga-ma|0;da=R+4108+(fa<<8)|0;fa=KXa(O,_,T,K+Z|0,aa,da,1)|0;na=KXa(O,$,T,K+(fa+Z)|0,aa-fa|0,da,1)|0;oa=fa}else{na=0;oa=0}fa=oa+ma+na|0;do{if((fa|0)>(V|0)){if((H|0)<(c[692272+(c[n>>2]<<2)>>2]|0)){pa=na;qa=oa;ra=H}else{break}while(1){da=ra+1|0;aa=c[u>>2]|0;Z=KXa(O,X,U,ha,ga,aa+12+(ra<<8)|0,0)|0;if((c[e>>2]&8192|0)==0){ea=Z+6|0;ba=ga-Z|0;sa=aa+4108+(ra<<8)|0;aa=KXa(O,_,T,K+ea|0,ba,sa,1)|0;ta=KXa(O,$,T,K+(aa+ea)|0,ba-aa|0,sa,1)|0;ua=aa}else{ta=pa;ua=qa}if((ua+Z+ta|0)<=(V|0)){ia=ta;ja=ua;ka=Z;la=da;break a}if((da|0)<(c[692272+(c[n>>2]<<2)>>2]|0)){pa=ta;qa=ua;ra=da}else{ia=ta;ja=ua;ka=Z;la=da;break a}}}}while(0);if((fa|0)>=(S|0)){ia=na;ja=oa;ka=ma;la=H;break}if((H|0)>(c[692256+(c[n>>2]<<2)>>2]|0)){va=na;wa=oa;xa=H}else{ia=na;ja=oa;ka=ma;la=H;break}while(1){da=xa-1|0;Z=c[u>>2]|0;aa=xa-2|0;sa=KXa(O,X,U,ha,ga,Z+12+(aa<<8)|0,0)|0;if((c[e>>2]&8192|0)==0){ba=sa+6|0;ea=ga-sa|0;ya=Z+4108+(aa<<8)|0;aa=KXa(O,_,T,K+ba|0,ea,ya,1)|0;za=KXa(O,$,T,K+(aa+ba)|0,ea-aa|0,ya,1)|0;Aa=aa}else{za=va;Aa=wa}if((Aa+sa+za|0)>=(S|0)){ia=za;ja=Aa;ka=sa;la=da;break a}if((da|0)>(c[692256+(c[n>>2]<<2)>>2]|0)){va=za;wa=Aa;xa=da}else{ia=za;ja=Aa;ka=sa;la=da;break}}}}while(0);a[K]=48;a[K+1|0]=la;S=K+2|0;y=he(ka&65535|0)|0;a[S]=y;y=y>>8;a[S+1|0]=y;S=K+4|0;y=he(ja&65535|0)|0;a[S]=y;y=y>>8;a[S+1|0]=y;S=ka+6+ja+ia|0;T=I;y=he(S&65535|0)|0;a[T]=y;y=y>>8;a[T+1|0]=y;T=I+2|0;$=K+S|0;_=J-S|0;S=O+L|0;if((S|0)<(m|0)){H=la;I=T;J=_;K=$;L=S;M=O}else{Ba=la;Ca=T;Da=_;Ea=$;break}}}else{Ba=B;Ca=C;Da=D;Ea=E}M=l+1|0;if((M|0)<(q|0)){B=Ba;C=Ca;D=Da;l=M;E=Ea}else{Fa=Ea;break}}}else{Fa=s}a[r]=64;s=Fa-r|0;r=j+157|0;y=je(s|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;r=j+161|0;y=he(p&65535|0)|0;a[r]=y;y=y>>8;a[r+1|0]=y;a[j+163|0]=o<<4;o=s+156|0;s=j;y=je(o|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=j+4|0;y=1718641513;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=j+8|0;y=-27648;a[s]=y;y=y>>8;a[s+1|0]=y;s=j+10|0;y=0;a[s]=y;y=y>>8;a[s+1|0]=y;s=j+12|0;y=1735421286;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;s=j+16|0;y=he(c[g>>2]&65535|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;s=j+18|0;y=he(c[h>>2]&65535|0)|0;a[s]=y;y=y>>8;a[s+1|0]=y;a[j+20|0]=-125;a[j+21|0]=0;a[j+22|0]=2;a[j+23|0]=2;a[j+24|0]=6;a[j+25|0]=32;a[j+26|0]=0;a[j+27|0]=3;nrc(j+28|0,2656104+(c[n>>2]<<6)|0,64)|0;nrc(j+92|0,2656360+(c[n>>2]<<6)|0,64)|0;n=d+36|0;c[n>>2]=c[n>>2]|1;c[i>>2]=o;c[f>>2]=1;k=0;return k|0}function IXa(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(a+804|0);mJb(b);return 0}function JXa(a,c,d,e,f,g,h,i){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=h;k=f-c|0;l=k>>>0>i>>>0?i:k;k=g-d|0;m=k>>>0>16>>>0?16:k;k=e>>>1;e=a+((ca(k,d)|0)+c<<1)|0;do{if((m|0)>0){if((l|0)>0){a=~i;n=c-1-f|0;o=n>>>0<a>>>0?a:n;n=~o;a=d-1-g|0;p=a>>>0>4294967279>>>0?a:-17;a=0;q=h;r=e;while(1){s=0;do{b[q+(s<<1)>>1]=b[r+(s<<1)>>1]|0;s=s+1|0;}while((s|0)<(l|0));s=b[q+(-2-o<<1)>>1]|0;if(n>>>0<i>>>0){t=n;do{b[q+(t<<1)>>1]=s;t=t+1|0;}while(t>>>0<i>>>0)}t=a+1|0;if((t|0)<(m|0)){a=t;q=q+(i<<1)|0;r=r+(k<<1)|0}else{u=p;break}}}else{p=d-1-g|0;r=p>>>0>4294967279>>>0?p:-17;p=0;q=h;while(1){a=b[q-2>>1]|0;if((i|0)!=0){n=0;do{b[q+(n<<1)>>1]=a;n=n+1|0;}while(n>>>0<i>>>0)}n=p+1|0;if((n|0)<(m|0)){p=n;q=q+(i<<1)|0}else{u=r;break}}}r=j+(ca(-2-(u<<1)|0,i)|0)|0;if(u>>>0>4294967279>>>0){v=r;w=~u;break}return}else{v=h;w=0}}while(0);if((i|0)==0){return}else{x=w;y=v}while(1){w=0;do{b[y+(w<<1)>>1]=b[v+(w-i<<1)>>1]|0;w=w+1|0;}while(w>>>0<i>>>0);w=x+1|0;if(w>>>0<16>>>0){x=w;y=y+(i<<1)|0}else{break}}return}function KXa(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;m=i;i=i+4120|0;n=m|0;o=m+4096|0;p=n|0;if((e|0)>0){q=g>>1;r=g<<3;g=2-l|0;s=g<<6;t=(l|0)==0;u=r+16|0;v=256>>>(l>>>0);w=32>>>(l>>>0);x=p;z=0;A=f;while(1){f=x;B=A;C=0;while(1){b[f>>1]=b[B>>1]|0;b[f+2>>1]=b[B+2>>1]|0;b[f+4>>1]=b[B+4>>1]|0;b[f+6>>1]=b[B+6>>1]|0;b[f+8>>1]=b[B+8>>1]|0;b[f+10>>1]=b[B+10>>1]|0;b[f+12>>1]=b[B+12>>1]|0;b[f+14>>1]=b[B+14>>1]|0;D=C+1|0;if((D|0)<8){f=f+16|0;B=B+(q<<1)|0;C=D}else{break}}HNa(x);C=x+(s<<1)|0;B=C;f=A+r|0;D=0;while(1){b[B>>1]=b[f>>1]|0;b[B+2>>1]=b[f+2>>1]|0;b[B+4>>1]=b[f+4>>1]|0;b[B+6>>1]=b[f+6>>1]|0;b[B+8>>1]=b[f+8>>1]|0;b[B+10>>1]=b[f+10>>1]|0;b[B+12>>1]=b[f+12>>1]|0;b[B+14>>1]=b[f+14>>1]|0;E=D+1|0;if((E|0)<8){B=B+16|0;f=f+(q<<1)|0;D=E}else{break}}HNa(C);if(t){D=x+128|0;f=D;B=A+16|0;E=0;while(1){b[f>>1]=b[B>>1]|0;b[f+2>>1]=b[B+2>>1]|0;b[f+4>>1]=b[B+4>>1]|0;b[f+6>>1]=b[B+6>>1]|0;b[f+8>>1]=b[B+8>>1]|0;b[f+10>>1]=b[B+10>>1]|0;b[f+12>>1]=b[B+12>>1]|0;b[f+14>>1]=b[B+14>>1]|0;F=E+1|0;if((F|0)<8){f=f+16|0;B=B+(q<<1)|0;E=F}else{break}}HNa(D);E=x+384|0;B=E;f=A+u|0;C=0;while(1){b[B>>1]=b[f>>1]|0;b[B+2>>1]=b[f+2>>1]|0;b[B+4>>1]=b[f+4>>1]|0;b[B+6>>1]=b[f+6>>1]|0;b[B+8>>1]=b[f+8>>1]|0;b[B+10>>1]=b[f+10>>1]|0;b[B+12>>1]=b[f+12>>1]|0;b[B+14>>1]=b[f+14>>1]|0;F=C+1|0;if((F|0)<8){B=B+16|0;f=f+(q<<1)|0;C=F}else{break}}HNa(E)}C=z+1|0;if((C|0)<(e|0)){x=x+(v<<1)|0;z=C;A=A+w|0}else{break}}G=(b[p>>1]|0)-16384|0;H=g}else{G=-16384;H=2-l|0}l=e<<H;H=j<<3;j=(H|0)<0;e=j?0:h;h=j?0:H;c[o+20>>2]=h<<3;H=o+8|0;c[H>>2]=e;c[o+16>>2]=e+h;h=o+12|0;c[h>>2]=e;e=o+4|0;c[e>>2]=32;j=o|0;c[j>>2]=0;g=(G|0)/(c[k>>2]|0)|0;LXa(o,g<<1^g>>31,184);if((l|0)>1){G=64;p=0;w=1;A=5;z=g;while(1){g=((b[n+(G<<1)>>1]|0)-16384|0)/(c[k>>2]|0)|0;v=g-z|0;x=v>>31;if((g|0)==(z|0)){I=0}else{I=((x^v)-x<<1)+(x^p)|0}LXa(o,I,d[1615448+((A|0)>6?6:A)|0]|0);v=w+1|0;if((v|0)<(l|0)){G=G+64|0;p=x;w=v;A=I;z=g}else{break}}}if((l|0)>0){z=0;I=1;A=2;w=4;while(1){p=d[699136+I|0]|0;G=k+(p<<2)|0;g=z;v=0;x=A;q=w;while(1){u=(b[n+((v<<6)+p<<1)>>1]|0)/(c[G>>2]|0)|0;if((u|0)==0){J=q;K=x;L=g+1|0}else{LXa(o,g,d[676400+((q|0)>15?15:q)|0]|0);t=u>>31;r=(t^u)-t|0;LXa(o,r-1|0,d[1011152+((x|0)>9?9:x)|0]|0);t=u>>>31;u=c[j>>2]|0;s=c[e>>2]|0;if((s|0)>1){M=s-1|0;N=u<<1|t}else{C=je(t>>>((1-s|0)>>>0)|u<<s|0)|0;u=c[h>>2]|0;y=C;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;M=s+31|0;N=t}c[j>>2]=N;c[e>>2]=M;J=g;K=r;L=0}r=v+1|0;if((r|0)<(l|0)){g=L;v=r;x=K;q=J}else{break}}q=I+1|0;if((q|0)<64){z=L;I=q;A=K;w=J}else{break}}}J=c[e>>2]|0;if((J|0)>=32){c[e>>2]=32;c[j>>2]=0;O=c[h>>2]|0;P=c[H>>2]|0;Q=O;R=P;S=Q-R|0;i=m;return S|0}w=c[j>>2]<<J;c[j>>2]=w;J=w>>>24&255;while(1){w=c[h>>2]|0;c[h>>2]=w+1;a[w]=J;w=c[j>>2]|0;c[j>>2]=w<<8;K=(c[e>>2]|0)+8|0;c[e>>2]=K;if((K|0)>=32){break}J=w>>>16&255}c[e>>2]=32;c[j>>2]=0;O=c[h>>2]|0;P=c[H>>2]|0;Q=O;R=P;S=Q-R|0;i=m;return S|0}function LXa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0;g=f&3;h=f>>5;i=f>>>2&7;f=g+1<<h;if(!(f>>>0>e>>>0)){j=e-f+(1<<i)|0;f=j>>>0>65535>>>0;k=f?j>>>16:j;l=f?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=(d[1359664+n|0]|0)+m|0;m=k-i+g|0;g=m+1|0;i=b|0;n=c[i>>2]|0;l=b+4|0;f=c[l>>2]|0;if((f|0)>(g|0)){o=f-g|0;p=n<<g}else{g=je(n<<f|0)|0;n=b+12|0;q=c[n>>2]|0;y=g;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;o=f+31-m|0;p=0}c[i>>2]=p;c[l>>2]=o;m=k+1|0;if((o|0)>(m|0)){r=o-m|0;s=p<<m|j}else{f=je(j>>>((m-o|0)>>>0)|p<<o|0)|0;p=b+12|0;m=c[p>>2]|0;y=f;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;r=31-k+o|0;s=j}c[i>>2]=s;c[l>>2]=r;return}if((h|0)==0){r=b|0;l=c[r>>2]|0;s=b+4|0;i=c[s>>2]|0;if((i|0)>(e|0)){t=i-e|0;u=l<<e}else{j=je(l<<i|0)|0;l=b+12|0;o=c[l>>2]|0;y=j;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;t=32-e+i|0;u=0}c[r>>2]=u;c[s>>2]=t;if((t|0)>1){v=t-1|0;w=u<<1|1}else{i=je(1>>>((1-t|0)>>>0)|u<<t|0)|0;u=b+12|0;l=c[u>>2]|0;y=i;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+31|0;w=1}c[r>>2]=w;c[s>>2]=v;return}v=e>>h;s=b|0;w=c[s>>2]|0;r=b+4|0;t=c[r>>2]|0;if((t|0)>(v|0)){x=t-v|0;z=w<<v}else{u=je(w<<t|0)|0;w=b+12|0;l=c[w>>2]|0;y=u;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;x=32-v+t|0;z=0}c[s>>2]=z;c[r>>2]=x;if((x|0)>1){A=x-1|0;B=z<<1|1}else{t=je(1>>>((1-x|0)>>>0)|z<<x|0)|0;z=b+12|0;v=c[z>>2]|0;y=t;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;A=x+31|0;B=1}c[s>>2]=B;c[r>>2]=A;x=(1<<h)-1&e;if((A|0)>(h|0)){C=A-h|0;D=B<<h|x}else{e=je(x>>>((h-A|0)>>>0)|B<<A|0)|0;B=b+12|0;b=c[B>>2]|0;y=e;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;C=32-h+A|0;D=x}c[s>>2]=D;c[r>>2]=C;return}function MXa(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;g=e+60|0;h=c[g>>2]|0;j=c[e+88>>2]&262144;k=(j|0)!=0;l=j>>>18;c[e+796>>2]=10;j=UHb()|0;m=e+804|0;c[m>>2]=j;if((j|0)==0){n=-12;i=f;return n|0}c[h+19096>>2]=930;c[h+19092>>2]=k?1322440:1322152;l8(h+19100|0,e);j=c[h+20352>>2]|0;if((j-1&j|0)!=0){KIb(e,16,2447904,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-22;i=f;return n|0}p=e+140|0;q=h+20392|0;do{if((a[(qKb(c[p>>2]|0)|0)+7|0]|0)<0){r=c[q>>2]|0;if((r&7|0)==0){s=r;break}KIb(e,16,2358736,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-22;i=f;return n|0}else{c[q>>2]=0;s=0}}while(0);q=h+20360|0;c[q>>2]=(c[p>>2]|0)==74?2:3;p=h+20408|0;r=c[p>>2]|0;t=h+20412|0;c[t>>2]=698936+(r*36|0);u=h+20380|0;c[u>>2]=(s|0)!=0?4:3;s=(c[e+120>>2]|0)+15>>4;c[h+20344>>2]=s;v=c[e+124>>2]|0;if(k){w=v+31>>5;c[h+20348>>2]=w;x=w}else{w=v+15>>4;c[h+20348>>2]=w;x=w}w=(s|0)/(j|0)|0;v=h+20364|0;y=s-(ca(w,j)|0)|0;z=y-(y>>>1&1431655765)|0;y=(z>>>2&858993459)+(z&858993459)|0;z=(y>>>4)+y&252645135;y=(z>>>8)+z|0;z=((y>>>16)+y&63)+w|0;c[v>>2]=z;w=h+20368|0;c[w>>2]=ca(z,x)|0;z=l+1|0;l=h+20372|0;c[l>>2]=z;y=c[h+20400>>2]|0;if((y|0)==-1){A=698616+(c[698968+(r*36|0)>>2]<<6)|0;c[h+19088>>2]=A;B=A}else{A=698616+(y<<6)|0;c[h+19088>>2]=A;B=A}if((lrc(c[h+20396>>2]|0)|0)!=4){KIb(e,16,2295088,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=f;return n|0}A=c[e+80>>2]|0;y=(A|0)/118|0;C=h+20388|0;c[C>>2]=y;do{if((A+117|0)>>>0>234>>>0){if((A|0)>7669){KIb(e,16,2202504,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=f;return n|0}D=h+19088|0;E=h+16912|0;F=0;G=0;H=B;I=y;while(1){J=(ca(d[H+F|0]|0,I)|0)&65535;b[E+(F<<1)>>1]=J;K=2048/(J<<16>>16|0)|0;J=K>>>0>65535>>>0;L=J?K>>>16:K;K=J?16:0;if((L&65280|0)==0){M=K;N=L}else{M=K|8;N=L>>>8}O=((d[1359664+N|0]|0)+M<<1|1)+G|0;L=F+1|0;if((L|0)>=64){break}F=L;G=O;H=c[D>>2]|0;I=c[C>>2]|0}I=O<<3;D=h+20384|0;c[D>>2]=I;if((c[q>>2]|0)==3){H=I+(O<<2)|0;c[D>>2]=H;P=H}else{P=I}I=c[u>>2]|0;if((I|0)!=4){Q=I;R=P;break}I=P+(O<<2)|0;c[D>>2]=I;Q=4;R=I}else{I=h+20384|0;D=c[I>>2]|0;do{if((D|0)==0){H=0;while(1){if((H|0)>=3){break}if((c[699120+(H<<2)>>2]|0)<(ca(ca(x,s)|0,z)|0)){H=H+1|0}else{break}}c[I>>2]=c[698952+(r*36|0)+(H<<2)>>2]}else{if((D|0)>=128){break}KIb(e,16,2244096,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=f;return n|0}}while(0);D=c[698944+(r*36|0)>>2]|0;G=c[698948+(r*36|0)>>2]|0;F=h+19088|0;E=h+16912|0;L=D;do{K=0;do{b[E+(L<<7)+(K<<1)>>1]=ca(d[(c[F>>2]|0)+K|0]|0,L)|0;K=K+1|0;}while((K|0)<64);L=L+1|0;}while((L|0)<16);L=hJb(c[w>>2]<<2)|0;c[h+20416>>2]=L;if((L|0)==0){L=c[g>>2]|0;mJb(m);F=L+20420|0;E=F;K=c[E>>2]|0;do{if((K|0)!=0){H=e+808|0;if((c[H>>2]|0)<=0){break}kJb(c[K+17024>>2]|0);if((c[H>>2]|0)>1){S=1}else{break}do{kJb(c[(c[E>>2]|0)+(S*17040|0)+17024>>2]|0);S=S+1|0;}while((S|0)<(c[H>>2]|0))}}while(0);mJb(F);mJb(L+20416|0);n=-12;i=f;return n|0}E=e+808|0;K=pJb((c[E>>2]|0)*17040|0)|0;H=h+20420|0;c[H>>2]=K;if((K|0)==0){K=c[g>>2]|0;mJb(m);J=K+20420|0;T=J;U=c[T>>2]|0;do{if((U|0)!=0){if((c[E>>2]|0)<=0){break}kJb(c[U+17024>>2]|0);if((c[E>>2]|0)>1){V=1}else{break}do{kJb(c[(c[T>>2]|0)+(V*17040|0)+17024>>2]|0);V=V+1|0;}while((V|0)<(c[E>>2]|0))}}while(0);mJb(J);mJb(K+20416|0);n=-12;i=f;return n|0}a:do{if((c[E>>2]|0)>0){T=G+2|0;b:do{if((D|0)<(T|0)){U=0;while(1){L=hJb((c[v>>2]<<8)+256|0)|0;c[(c[H>>2]|0)+(U*17040|0)+17024>>2]=L;L=c[(c[H>>2]|0)+(U*17040|0)+17024>>2]|0;if((L|0)==0){break b}else{W=D}do{c[L+(W<<4)>>2]=-1;c[L+(W<<4)+8>>2]=0;c[L+(W<<4)+12>>2]=0;W=W+1|0;}while((W|0)<(T|0));U=U+1|0;if((U|0)>=(c[E>>2]|0)){break a}}}else{U=0;while(1){L=hJb((c[v>>2]<<8)+256|0)|0;c[(c[H>>2]|0)+(U*17040|0)+17024>>2]=L;if((c[(c[H>>2]|0)+(U*17040|0)+17024>>2]|0)==0){break b}U=U+1|0;if((U|0)>=(c[E>>2]|0)){break a}}}}while(0);T=c[g>>2]|0;mJb(m);U=T+20420|0;L=U;F=c[L>>2]|0;do{if((F|0)!=0){if((c[E>>2]|0)<=0){break}kJb(c[F+17024>>2]|0);if((c[E>>2]|0)>1){X=1}else{break}do{kJb(c[(c[L>>2]|0)+(X*17040|0)+17024>>2]|0);X=X+1|0;}while((X|0)<(c[E>>2]|0))}}while(0);mJb(U);mJb(T+20416|0);n=-12;i=f;return n|0}}while(0);Q=c[u>>2]|0;R=c[I>>2]|0}}while(0);u=h+20404|0;c[u>>2]=(ca(ca(c[w>>2]|0,c[l>>2]|0)|0,(Q<<1)+2+((ca(R,j)|0)/8|0)|0)|0)+200;c[e+52>>2]=c[(c[t>>2]|0)+4>>2];t=e;e=ca(c[l>>2]|0,c[w>>2]|0)|0;w=c[h+20384>>2]|0;KIb(t,48,2170736,(o=i,i=i+32|0,c[o>>2]=c[p>>2],c[o+8>>2]=e,c[o+16>>2]=k?2143400:2119808,c[o+24>>2]=w,o)|0);i=o;KIb(t,48,2637944,(o=i,i=i+8|0,c[o>>2]=c[u>>2],o)|0);i=o;n=0;i=f;return n|0}function NXa(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0;k=i;i=i+40|0;l=k|0;m=k+24|0;n=f+60|0;o=c[n>>2]|0;mrc(m|0,0,16)|0;p=o+20380|0;q=c[p>>2]|0;r=q<<1;s=f+804|0;nrc(c[s>>2]|0,h|0,472)|0;t=c[s>>2]|0;c[t+88>>2]=1;c[t+84>>2]=1;t=(c[o+20404>>2]|0)+16384|0;s=d5a(f,g,t,(t|0)<0|0?-1:0)|0;if((s|0)<0){u=s;i=k;return u|0}s=c[g+24>>2]|0;v=s+4|0;y=1718641513;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;v=s+8|0;w=s+10|0;y=0;a[w]=y;y=y>>8;a[w+1|0]=y;w=c[o+20396>>2]|0;x=s+12|0;y=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=f+120|0;w=s+16|0;y=he(c[x>>2]&65535|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;w=f+124|0;z=s+18|0;y=he(c[w>>2]&65535|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y;z=c[o+20360>>2]<<6;if((c[f+88>>2]&262144|0)==0){A=z&255}else{A=(((c[h+300>>2]|0)!=0?4:8)|z)&255}a[s+20|0]=A;a[s+21|0]=0;a[s+22|0]=c[f+384>>2];a[s+23|0]=c[f+388>>2];a[s+24|0]=c[f+392>>2];a[s+25|0]=(c[o+20392>>2]|0)>>>3|64;a[s+26|0]=0;A=s+27|0;if((c[o+20400>>2]|0)==4){a[A]=0;B=s+28|0}else{a[A]=3;A=o+19088|0;z=s+28|0;C=0;while(1){a[z]=a[(c[A>>2]|0)+C|0]|0;D=C+1|0;if((D|0)<64){z=z+1|0;C=D}else{break}}C=s+92|0;z=0;while(1){a[C]=a[(c[A>>2]|0)+z|0]|0;D=z+1|0;if((D|0)<64){C=C+1|0;z=D}else{break}}B=s+156|0}z=v;C=v;y=he(B-z&65535|0)|0;a[C]=y;y=y>>8;a[C+1|0]=y;C=o+20376|0;c[C>>2]=0;v=o+20372|0;a:do{if((c[v>>2]|0)>0){A=o+20368|0;D=o+20352|0;E=o+20388|0;F=f+828|0;G=o+20348|0;H=o+20344|0;I=o+20364|0;J=o+20416|0;K=q<<4&255;L=z+t|0;M=l+20|0;N=l+8|0;O=l+16|0;P=l+12|0;Q=l+4|0;R=l|0;S=d[1322140]|0;T=d[1322322]|0;U=h+300|0;V=B;while(1){W=V+1|0;a[V]=64;X=V+5|0;y=he(c[A>>2]&65535|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;X=c[D>>2]|0;Y=X>>>0>65535>>>0;Z=Y?X>>>16:X;X=Y?16:0;if((Z&65280|0)==0){_=X;$=Z}else{_=X|8;$=Z>>>8}a[V+7|0]=(d[1359664+$|0]|0)+_<<4;Z=V+8|0;X=V+((c[A>>2]<<1)+8)|0;if((c[E>>2]|0)==0){Y=Xe[c[F>>2]&511](f,654,0,0,c[G>>2]|0)|0;if((Y|0)!=0){u=Y;break}}Y=c[G>>2]|0;if((Y|0)>0){aa=X;ba=Z;Z=0;da=c[H>>2]|0;ea=Y;while(1){if((da|0)>0){Y=Z<<4;fa=aa;ga=ba;ha=0;ia=0;ja=c[D>>2]|0;ka=da;while(1){la=c[E>>2]|0;if((la|0)==0){ma=(ca(c[I>>2]|0,Z)|0)+ha|0;na=c[(c[J>>2]|0)+(ma<<2)>>2]|0}else{na=la}la=ka-ia|0;ma=ja;while(1){if((la|0)<(ma|0)){ma=ma>>1}else{break}}a[fa]=K;la=fa+1|0;oa=fa+r|0;pa=L-oa<<3;qa=(pa|0)<0;ra=qa?0:oa;oa=qa?0:pa;c[M>>2]=oa<<3;c[N>>2]=ra;c[O>>2]=ra+oa;c[P>>2]=ra;c[Q>>2]=32;c[R>>2]=0;oa=c[n>>2]|0;pa=oa;qa=oa+20372|0;if((c[qa>>2]|0)==1){sa=0}else{sa=(c[U>>2]|0)==0^c[oa+20376>>2]}do{if((c[oa+20388>>2]|0)==0){if((na|0)<16){ta=oa+16912+(na<<7)|0;break}ua=oa+18960|0;va=oa+19088|0;wa=0;while(1){b[ua+(wa<<1)>>1]=ca(d[(c[va>>2]|0)+wa|0]|0,na)|0;xa=wa+1|0;if((xa|0)<64){wa=xa}else{ta=ua;break}}}else{ta=oa+16912|0}}while(0);ua=oa+20380|0;if((c[ua>>2]|0)>0){wa=oa+20360|0;va=ia<<3;xa=ia<<4;ya=oa+16|0;za=oa+16400|0;Aa=oa+19092|0;Ba=oa+20392|0;Ca=ma<<8;Da=0;Ea=ra;Fa=ra;while(1){Ga=(Da-1|0)>>>0<2>>>0;Ha=Ga&1;do{if(Ga){if((c[wa>>2]|0)==3){Ia=37;break}Ja=va;Ka=c[x>>2]>>1;La=2}else{Ia=37}}while(0);if((Ia|0)==37){Ia=0;Ja=xa;Ka=c[x>>2]|0;La=4}Ga=c[h+32+(Da<<2)>>2]|0;Ma=c[qa>>2]|0;Na=ca(Ma,Ga)|0;Oa=(c[h+(Da<<2)>>2]|0)+((ca(Na,Y)|0)+(ca(Ga,sa)|0))+(Ja<<1)|0;Ga=(c[w>>2]|0)/(Ma|0)|0;if((Da|0)<3){QXa(pa,Oa,Na,Ja,Y,Ka,Ga,ya,za,ma,La,Ha);Ma=Fa;Pa=Ea;Qa=ca(La,ma)|0;Ra=b[ta>>1]|0;Sa=((b[ya>>1]|0)-16384|0)/(Ra|0)|0;TXa(l,184,Sa<<1^Sa>>31);if((Qa|0)>1){Ta=3;Ua=Sa;Sa=1;Va=0;Wa=ya;while(1){Xa=Wa+128|0;Ya=((b[Xa>>1]|0)-16384|0)/(Ra|0)|0;Za=Ya-Ua|0;_a=(Za^Va)-Va|0;$a=_a<<1^_a>>31;TXa(l,d[1322712+Ta|0]|0,$a);_a=($a&1)+$a>>1;$a=Sa+1|0;if(($a|0)<(Qa|0)){Ta=(_a|0)>3?3:_a;Ua=Ya;Sa=$a;Va=Za>>31;Wa=Xa}else{break}}}Wa=c[Aa>>2]|0;Va=Qa<<6;Sa=0;Ua=S;Ta=T;Ra=1;while(1){Ha=Wa+Ra|0;Xa=a[Ha]|0;Za=Xa&255;b:do{if((Za|0)<(Va|0)){$a=Sa;Ya=Ua;_a=Ta;ab=Za;bb=Xa;while(1){cb=(b[ya+(ab<<1)>>1]|0)/(b[ta+((bb&255)<<1)>>1]|0)|0;if((cb|0)==0){db=_a;eb=Ya;fb=$a+1|0}else{gb=(cb|0)>-1?cb:-cb|0;TXa(l,d[1322824+Ya|0]|0,$a);TXa(l,d[1322824+_a|0]|0,gb-1|0);hb=cb>>>31;cb=c[R>>2]|0;ib=c[Q>>2]|0;if((ib|0)>1){jb=ib-1|0;kb=cb<<1|hb}else{lb=je(hb>>>((1-ib|0)>>>0)|cb<<ib|0)|0;cb=c[P>>2]|0;mb=cb;y=lb;a[mb]=y;y=y>>8;a[mb+1|0]=y;y=y>>8;a[mb+2|0]=y;y=y>>8;a[mb+3|0]=y;c[P>>2]=cb+4;jb=ib+31|0;kb=hb}c[R>>2]=kb;c[Q>>2]=jb;db=d[1322320+((gb|0)>9?9:gb)|0]|0;eb=d[1322136+(($a|0)>15?15:$a)|0]|0;fb=0}gb=ab+64|0;if((gb|0)>=(Va|0)){nb=fb;ob=eb;pb=db;break b}$a=fb;Ya=eb;_a=db;ab=gb;bb=a[Ha]|0}}else{nb=Sa;ob=Ua;pb=Ta}}while(0);Ha=Ra+1|0;if((Ha|0)<64){Sa=nb;Ua=ob;Ta=pb;Ra=Ha}else{break}}Ra=c[Q>>2]|0;if((Ra|0)<32){Ta=c[R>>2]<<Ra;c[R>>2]=Ta;Ua=c[P>>2]|0;Sa=Ra+8|0;Va=(((Sa|0)>32?Ra+7|0:31)-Ra|0)>>>3;Wa=Va<<3;Qa=Ta>>>24&255;Ha=Ua;Xa=Ta;Ta=Ra;while(1){a[Ha]=Qa;qb=Xa<<8;Ra=Ta+8|0;if((Ra|0)<32){Qa=Xa>>>16&255;Ha=Ha+1|0;Xa=qb;Ta=Ra}else{break}}Ta=Ua+(Va+1)|0;c[P>>2]=Ta;c[R>>2]=qb;c[Q>>2]=Sa+Wa;rb=Ta}else{rb=c[P>>2]|0}c[Q>>2]=32;c[R>>2]=0;Ta=c[N>>2]|0;c[m+(Da<<2)>>2]=Pa-Ma-Ta+rb<<3>>3;sb=Ta;tb=rb}else{RXa(Oa,Na,Ja,Y,Ka,Ga,ya,ma,c[Ba>>2]|0);Ta=c[Ba>>2]|0;Xa=e[ya>>1]|0;SXa(l,Xa,(1<<Ta)-1|0,Ta);Ha=0;Qa=1;Ra=Xa;while(1){Xa=Qa+1|0;Za=e[ya+(Qa<<1)>>1]|0;if((Za|0)==(Ra|0)){ub=Ha+1|0;vb=Ra}else{bb=c[R>>2]|0;ab=c[Q>>2]|0;_a=(ab|0)>1;do{if((Ha|0)==0){if(_a){wb=ab-1|0;xb=bb<<1|1}else{Ya=je(1>>>((1-ab|0)>>>0)|bb<<ab|0)|0;$a=c[P>>2]|0;gb=$a;y=Ya;a[gb]=y;y=y>>8;a[gb+1|0]=y;y=y>>8;a[gb+2|0]=y;y=y>>8;a[gb+3|0]=y;c[P>>2]=$a+4;wb=ab+31|0;xb=1}c[R>>2]=xb;c[Q>>2]=wb}else{if(_a){yb=ab-1|0;zb=bb<<1}else{$a=je(bb<<ab|0)|0;gb=c[P>>2]|0;Ya=gb;y=$a;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;c[P>>2]=gb+4;yb=ab+31|0;zb=0}c[R>>2]=zb;c[Q>>2]=yb;if((Ha|0)<16){if((yb|0)>4){Ab=yb-4|0;Bb=zb<<4|Ha}else{gb=je(Ha>>>((4-yb|0)>>>0)|zb<<yb|0)|0;Ya=c[P>>2]|0;$a=Ya;y=gb;a[$a]=y;y=y>>8;a[$a+1|0]=y;y=y>>8;a[$a+2|0]=y;y=y>>8;a[$a+3|0]=y;c[P>>2]=Ya+4;Ab=yb+28|0;Bb=Ha}c[R>>2]=Bb;c[Q>>2]=Ab;break}else{if((yb|0)>15){Cb=yb-15|0;Db=zb<<15|Ha}else{Ya=je(Ha>>>((15-yb|0)>>>0)|zb<<yb|0)|0;$a=c[P>>2]|0;gb=$a;y=Ya;a[gb]=y;y=y>>8;a[gb+1|0]=y;y=y>>8;a[gb+2|0]=y;y=y>>8;a[gb+3|0]=y;c[P>>2]=$a+4;Cb=yb+17|0;Db=Ha}c[R>>2]=Db;c[Q>>2]=Cb;break}}}while(0);SXa(l,Za,Ra,Ta);ub=0;vb=Za}if((Xa|0)<(Ca|0)){Ha=ub;Qa=Xa;Ra=vb}else{break}}Ra=Fa;Qa=Ea;do{if((ub|0)==0){Eb=c[Q>>2]|0}else{Ha=c[R>>2]|0;Ta=c[Q>>2]|0;if((Ta|0)>1){Fb=Ta-1|0;Gb=Ha<<1}else{Ga=je(Ha<<Ta|0)|0;Ha=c[P>>2]|0;Na=Ha;y=Ga;a[Na]=y;y=y>>8;a[Na+1|0]=y;y=y>>8;a[Na+2|0]=y;y=y>>8;a[Na+3|0]=y;c[P>>2]=Ha+4;Fb=Ta+31|0;Gb=0}c[R>>2]=Gb;c[Q>>2]=Fb;if((ub|0)<16){if((Fb|0)>4){Hb=Fb-4|0;Ib=Gb<<4|ub}else{Ta=je(ub>>>((4-Fb|0)>>>0)|Gb<<Fb|0)|0;Ha=c[P>>2]|0;Na=Ha;y=Ta;a[Na]=y;y=y>>8;a[Na+1|0]=y;y=y>>8;a[Na+2|0]=y;y=y>>8;a[Na+3|0]=y;c[P>>2]=Ha+4;Hb=Fb+28|0;Ib=ub}c[R>>2]=Ib;c[Q>>2]=Hb;Eb=Hb;break}else{if((Fb|0)>15){Jb=Fb-15|0;Kb=Gb<<15|ub}else{Ha=je(ub>>>((15-Fb|0)>>>0)|Gb<<Fb|0)|0;Na=c[P>>2]|0;Ta=Na;y=Ha;a[Ta]=y;y=y>>8;a[Ta+1|0]=y;y=y>>8;a[Ta+2|0]=y;y=y>>8;a[Ta+3|0]=y;c[P>>2]=Na+4;Jb=Fb+17|0;Kb=ub}c[R>>2]=Kb;c[Q>>2]=Jb;Eb=Jb;break}}}while(0);if((Eb|0)<32){Na=c[R>>2]<<Eb;c[R>>2]=Na;Ta=c[P>>2]|0;Ha=Eb+8|0;Ga=(((Ha|0)>32?Eb+7|0:31)-Eb|0)>>>3;Oa=Ga<<3;Ma=Na>>>24&255;Pa=Ta;Wa=Na;Na=Eb;while(1){a[Pa]=Ma;Lb=Wa<<8;Sa=Na+8|0;if((Sa|0)<32){Ma=Wa>>>16&255;Pa=Pa+1|0;Wa=Lb;Na=Sa}else{break}}Na=Ta+(Ga+1)|0;c[P>>2]=Na;c[R>>2]=Lb;c[Q>>2]=Ha+Oa;Mb=Na}else{Mb=c[P>>2]|0}c[Q>>2]=32;c[R>>2]=0;Na=c[N>>2]|0;c[m+(Da<<2)>>2]=Qa-Ra-Na+Mb<<3>>3;sb=Na;tb=Mb}Na=Da+1|0;if((Na|0)<(c[ua>>2]|0)){Da=Na;Ea=sb;Fa=tb}else{break}}}a[la]=na;Fa=(c[p>>2]|0)-1|0;Ea=(c[m+(Fa<<2)>>2]|0)+r|0;if((Fa|0)>0){Fa=0;Da=Ea;ua=fa;while(1){Ca=ua+2|0;ya=m+(Fa<<2)|0;Ba=Ca;y=he(c[ya>>2]&65535|0)|0;a[Ba]=y;y=y>>8;a[Ba+1|0]=y;Ba=(c[ya>>2]|0)+Da|0;ya=Fa+1|0;if((ya|0)<((c[p>>2]|0)-1|0)){Fa=ya;Da=Ba;ua=Ca}else{Nb=Ba;break}}}else{Nb=Ea}ua=ga;y=he(Nb&65535|0)|0;a[ua]=y;y=y>>8;a[ua+1|0]=y;Ob=ga+2|0;Pb=fa+Nb|0;ua=ma+ia|0;Qb=c[H>>2]|0;if((ua|0)>=(Qb|0)){break}fa=Pb;ga=Ob;ha=ha+1|0;ia=ua;ja=ma;ka=Qb}Rb=Pb;Sb=Ob;Tb=Qb;Ub=c[G>>2]|0}else{Rb=aa;Sb=ba;Tb=da;Ub=ea}ka=Z+1|0;if((ka|0)<(Ub|0)){aa=Rb;ba=Sb;Z=ka;da=Tb;ea=Ub}else{Vb=Rb;break}}}else{Vb=X}ea=W;y=je(Vb-V|0)|0;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;ea=(c[C>>2]|0)+1|0;c[C>>2]=ea;if((ea|0)<(c[v>>2]|0)){V=Vb}else{Wb=Vb;break a}}i=k;return u|0}else{Wb=B}}while(0);B=Wb-s|0;Wb=s;y=je(B|0)|0;a[Wb]=y;y=y>>8;a[Wb+1|0]=y;y=y>>8;a[Wb+2|0]=y;y=y>>8;a[Wb+3|0]=y;c[g+28>>2]=B;B=g+36|0;c[B>>2]=c[B>>2]|1;c[j>>2]=1;u=0;i=k;return u|0}function OXa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+60>>2]|0;mJb(a+804|0);d=b+20420|0;e=d;f=c[e>>2]|0;a:do{if((f|0)!=0){g=a+808|0;if((c[g>>2]|0)>0){h=0;i=f}else{break}while(1){kJb(c[i+(h*17040|0)+17024>>2]|0);j=h+1|0;if((j|0)>=(c[g>>2]|0)){break a}h=j;i=c[e>>2]|0}}}while(0);mJb(d);mJb(b+20416|0);return 0}function PXa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0;e=i;i=i+168|0;h=e|0;j=e+16|0;k=e+32|0;l=e+40|0;m=e+104|0;n=a+60|0;o=c[n>>2]|0;p=c[o+20420>>2]|0;q=p+(g*17040|0)|0;r=o+20344|0;s=c[r>>2]|0;if((s|0)>0){t=a+804|0;u=a+120|0;v=f<<4;w=a+124|0;a=p+(g*17040|0)+16384|0;x=j+4|0;y=p+(g*17040|0)+17024|0;z=p+(g*17040|0)+12288|0;A=p+(g*17040|0)+16896|0;B=0;C=c[o+20352>>2]|0;D=0;E=s;while(1){s=E-B|0;F=C;while(1){if((s|0)<(F|0)){F=F>>1}else{break}}s=c[t>>2]|0;G=D+1|0;H=G<<4;I=c[n>>2]|0;J=I;K=c[I+20412>>2]|0;L=c[K+8>>2]|0;M=c[K+12>>2]|0;K=I+20372|0;if((c[K>>2]|0)==1){N=0}else{N=(c[s+300>>2]|0)==0^c[I+20376>>2]}O=F+B|0;P=I+20380|0;if((c[P>>2]|0)>0){Q=I+20360|0;R=B<<3;S=B<<4;T=I+20392|0;U=0;do{if((U|0)==1){c[x>>2]=1;V=x;W=15}else{X=(U|0)==2;Y=j+(U<<2)|0;c[Y>>2]=X&1;if(X){V=Y;W=15}else{Z=Y;W=16}}do{if((W|0)==15){W=0;if((c[Q>>2]|0)==3){Z=V;W=16;break}c[h+(U<<2)>>2]=2;_=R;$=c[u>>2]>>1;aa=V;ba=2}}while(0);if((W|0)==16){W=0;c[h+(U<<2)>>2]=4;_=S;$=c[u>>2]|0;aa=Z;ba=4}Y=c[s+32+(U<<2)>>2]|0;X=c[K>>2]|0;da=ca(X,Y)|0;ea=(c[s+(U<<2)>>2]|0)+((ca(da,v)|0)+(ca(Y,N)|0))+(_<<1)|0;Y=(c[w>>2]|0)/(X|0)|0;X=p+(g*17040|0)+(U<<12)|0;if((U|0)<3){QXa(J,ea,da,_,v,$,Y,X,a,F,ba,c[aa>>2]|0)}else{RXa(ea,da,_,v,$,Y,X,F,c[T>>2]|0)}U=U+1|0;}while((U|0)<(c[P>>2]|0))}U=M+2|0;T=(L|0)<(U|0);if(T){s=c[y>>2]|0;K=L;do{S=K+H|0;c[s+(S<<4)>>2]=-1;c[s+(S<<4)+4>>2]=K;K=K+1|0;}while((K|0)<(U|0))}a:do{if((L|0)>(M|0)){fa=0}else{K=I+20392|0;s=F<<8;S=I+16912|0;R=L;Q=c[P>>2]|0;X=c[K>>2]|0;while(1){c[k>>2]=0;Y=(X|0)!=0;if((Q-(Y&1)|0)>0){da=S+(R<<7)|0;ea=0;ga=0;while(1){ha=(UXa(J,k,ga,F,c[h+(ga<<2)>>2]|0,da,q)|0)+ea|0;ia=ga+1|0;ja=c[P>>2]|0;ka=c[K>>2]|0;la=(ka|0)!=0;if((ia|0)<(ja-(la&1)|0)){ea=ha;ga=ia}else{ma=ha;na=la;oa=ja;pa=ka;break}}}else{ma=0;na=Y;oa=Q;pa=X}if(na){ga=1<<pa;ea=ga-1|0;c[k>>2]=0;da=b[z>>1]|0;ka=(pa|0)==8?4:7;ja=1<<ka-1;la=da-ea&ea;ha=ga-ja|0;ia=(la|0)<(ha|0)?0:ga;qa=la-ia|0;ra=-ja|0;if((qa|0)<(ra|0)){sa=pa}else{sa=(qa|0)<=(ja|0)&(la|0)!=(ia|0)?ka:pa}ia=sa+1|0;la=0;qa=1;ta=da;while(1){da=qa+1|0;ua=b[p+(g*17040|0)+12288+(qa<<1)>>1]|0;if((ua|0)==(ta|0)){va=ia;wa=la+1|0;xa=ta}else{do{if((la|0)==0){ya=ia+1|0}else{if((la|0)<16){ya=ia+4|0;break}else{ya=ia+15|0;break}}}while(0);za=ua-ta&ea;Aa=(za|0)<(ha|0)?0:ga;Ba=za-Aa|0;if((Ba|0)<(ra|0)){Ca=pa}else{Ca=(Ba|0)<=(ja|0)&(za|0)!=(Aa|0)?ka:pa}va=ya+1+Ca|0;wa=0;xa=ua}if((da|0)<(s|0)){ia=va;la=wa;qa=da;ta=xa}else{break}}do{if((wa|0)==0){Da=va}else{if((wa|0)<16){Da=va+4|0;break}else{Da=va+15|0;break}}}while(0);Ea=Da+ma|0}else{Ea=ma}if((Ea|0)>52e4){break}c[l+(R<<2)>>2]=Ea;c[m+(R<<2)>>2]=c[k>>2];ta=R+1|0;if((ta|0)>(M|0)){fa=Ea;break a}else{R=ta;Q=oa;X=pa}}c[k>>2]=1073741823;fa=Ea}}while(0);X=c[l+(M<<2)>>2]|0;Q=I+20384|0;R=M+1|0;if((X|0)>(ca(c[Q>>2]|0,F)|0)){s=I+16912|0;K=I+20392|0;S=F<<8;ta=I+19088|0;qa=R;la=fa;while(1){if((qa|0)>=128){Fa=la;break}c[k>>2]=0;if((qa|0)<16){Ga=s+(qa<<7)|0}else{ia=c[ta>>2]|0;ka=0;while(1){b[p+(g*17040|0)+16896+(ka<<1)>>1]=ca(d[ia+ka|0]|0,qa)|0;ja=ka+1|0;if((ja|0)<64){ka=ja}else{Ga=A;break}}}ka=c[K>>2]|0;ia=(ka|0)!=0;if(((c[P>>2]|0)-(ia&1)|0)>0){ja=0;ra=0;while(1){ga=(UXa(J,k,ra,F,c[h+(ra<<2)>>2]|0,Ga,q)|0)+ja|0;ha=ra+1|0;ea=c[K>>2]|0;Y=(ea|0)!=0;if((ha|0)<((c[P>>2]|0)-(Y&1)|0)){ja=ga;ra=ha}else{Ha=ga;Ia=Y;Ja=ea;break}}}else{Ha=0;Ia=ia;Ja=ka}if(Ia){ra=1<<Ja;ja=ra-1|0;c[k>>2]=0;ea=b[z>>1]|0;Y=(Ja|0)==8?4:7;ga=1<<Y-1;ha=ea-ja&ja;Aa=ra-ga|0;za=(ha|0)<(Aa|0)?0:ra;Ba=ha-za|0;Ka=-ga|0;if((Ba|0)<(Ka|0)){La=Ja}else{La=(Ba|0)<=(ga|0)&(ha|0)!=(za|0)?Y:Ja}za=La+1|0;ha=0;Ba=1;Ma=ea;while(1){ea=Ba+1|0;Na=b[p+(g*17040|0)+12288+(Ba<<1)>>1]|0;if((Na|0)==(Ma|0)){Oa=za;Pa=ha+1|0;Qa=Ma}else{do{if((ha|0)==0){Ra=za+1|0}else{if((ha|0)<16){Ra=za+4|0;break}else{Ra=za+15|0;break}}}while(0);Sa=Na-Ma&ja;Ta=(Sa|0)<(Aa|0)?0:ra;Ua=Sa-Ta|0;if((Ua|0)<(Ka|0)){Va=Ja}else{Va=(Ua|0)<=(ga|0)&(Sa|0)!=(Ta|0)?Y:Ja}Oa=Ra+1+Va|0;Pa=0;Qa=Na}if((ea|0)<(S|0)){za=Oa;ha=Pa;Ba=ea;Ma=Qa}else{break}}do{if((Pa|0)==0){Wa=Oa}else{if((Pa|0)<16){Wa=Oa+4|0;break}else{Wa=Oa+15|0;break}}}while(0);Xa=Wa+Ha|0}else{Xa=Ha}if((Xa|0)>(ca(c[Q>>2]|0,F)|0)){qa=qa+1|0;la=Xa}else{Fa=Xa;break}}c[l+(R<<2)>>2]=Fa;c[m+(R<<2)>>2]=c[k>>2];Ya=qa}else{c[l+(R<<2)>>2]=X;c[m+(R<<2)>>2]=(c[m+(M<<2)>>2]|0)+1;Ya=M}la=c[y>>2]|0;c[la+(M+(H|1)<<4)+4>>2]=Ya;S=ca(c[Q>>2]|0,O)|0;if(T){P=H-16|0;K=L;do{J=P+K|0;ta=la+(J<<4)+8|0;s=la+(J<<4)+12|0;I=L;do{Ma=I+H|0;Ba=(c[l+(I<<2)>>2]|0)+(c[ta>>2]|0)|0;Za=(Ba|0)>(S|0)?1073741823:c[m+(I<<2)>>2]|0;ha=c[s>>2]|0;if((ha|0)<1073741823){_a=(Za|0)<1073741823?Za+ha|0:1073741823}else{_a=1073741823}ha=la+(Ma<<4)|0;za=la+(Ma<<4)+12|0;if((c[ha>>2]|0)==-1){W=90}else{if((c[za>>2]|0)>=(_a|0)){W=90}}if((W|0)==90){W=0;c[la+(Ma<<4)+8>>2]=Ba;c[za>>2]=_a;c[ha>>2]=J}I=I+1|0;}while((I|0)<(U|0));K=K+1|0;}while((K|0)<(U|0));c[k>>2]=Za}K=L+H|0;S=L;P=K;T=c[la+(K<<4)+12>>2]|0;b:while(1){K=S;while(1){Q=K+1|0;if((Q|0)>=(U|0)){break b}M=Q+H|0;R=c[la+(M<<4)+12>>2]|0;if((R|0)>(T|0)){K=Q}else{S=Q;P=M;T=R;continue b}}}c[k>>2]=T;S=c[r>>2]|0;if((O|0)<(S|0)){B=O;C=F;D=G;E=S}else{$a=P;break}}}else{$a=0}E=o+20364|0;D=c[E>>2]|0;if((D|0)<=0){i=e;return 0}C=c[p+(g*17040|0)+17024>>2]|0;g=c[o+20416>>2]|0;o=$a;$a=D;p=D;while(1){D=$a-1|0;c[g+((ca(p,f)|0)+D<<2)>>2]=c[C+(o<<4)+4>>2];if((D|0)<=0){break}o=c[C+(o<<4)>>2]|0;$a=D;p=c[E>>2]|0}i=e;return 0}function QXa(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;o=m<<2;if((l|0)<=0){return}p=i-g|0;q=(p|0)>16?16:p;p=(q|0)>0;r=k+((q<<4)-16<<1)|0;s=m<<3;t=(n|0)==0;n=a+19096|0;u=a+19100|0;a=(m|0)>2;v=(g+16|0)>(i|0);w=g-1-i|0;i=(w|0)>-17?~w:16;w=0;g=j;j=f;f=d;while(1){if((j|0)>=(h|0)){break}d=j+o|0;do{if((d|0)>(h|0)|v){x=h-j|0;y=(x|0)>(o|0)?o:x;if(p){x=f;z=y<<1;A=y-1|0;if((y|0)<(o|0)){B=0;do{C=B<<4;nrc(k+(C<<1)|0,x+(ca(B,e)|0)|0,z)|0;D=b[k+(A+C<<1)>>1]|0;E=y;do{b[k+(E+C<<1)>>1]=D;E=E+1|0;}while((E|0)<(o|0));B=B+1|0;}while((B|0)<(q|0))}else{B=0;do{nrc(k+(B<<4<<1)|0,x+(ca(B,e)|0)|0,z)|0;B=B+1|0;}while((B|0)<(q|0))}if((i|0)<16){F=i}else{G=32;H=k;break}}else{F=0}while(1){nrc(k+(F<<4<<1)|0,r|0,s)|0;B=F+1|0;if((B|0)<16){F=B}else{G=32;H=k;break}}}else{G=e;H=f}}while(0);mf[c[n>>2]&2047](u,H,G,g);B=g+128|0;do{if(t){if(a){mf[c[n>>2]&2047](u,H+16|0,G,B);I=g+256|0}else{I=B}z=G<<2;mf[c[n>>2]&2047](u,H+(z<<1)|0,G,I);x=I+128|0;if(!a){J=x;break}mf[c[n>>2]&2047](u,H+(z+8<<1)|0,G,x);J=I+256|0}else{x=G<<2;mf[c[n>>2]&2047](u,H+(x<<1)|0,G,B);z=g+256|0;if(!a){J=z;break}mf[c[n>>2]&2047](u,H+16|0,G,z);mf[c[n>>2]&2047](u,H+(x+8<<1)|0,G,g+384|0);J=g+512|0}}while(0);B=w+1|0;if((B|0)<(l|0)){w=B;g=J;j=d;f=f+(o<<1)|0}else{K=22;break}}if((K|0)==22){return}mrc(g|0,0,ca(m<<7,l-w|0)|0)|0;return}function RXa(a,c,d,e,f,g,h,i,j){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=h;l=i<<4;m=f-d|0;d=(m|0)>(l|0)?l:m;m=g-e|0;f=(m|0)>16?16:m;do{if((f|0)>0){m=d<<1;n=(d|0)>0;o=(d|0)<(l|0);p=c>>1;q=d-1|0;r=e-1-g|0;s=(r|0)>-17;t=s?r:-17;if((j|0)==8){r=0;u=h;v=a;while(1){nrc(u|0,v|0,m)|0;if(n){w=0;do{x=u+(w<<1)|0;b[x>>1]=(b[x>>1]|0)>>>2;w=w+1|0;}while((w|0)<(d|0))}if(o){w=u+(q<<1)|0;x=d;do{b[u+(x<<1)>>1]=b[w>>1]|0;x=x+1|0;}while((x|0)<(l|0))}x=r+1|0;if((x|0)<(f|0)){r=x;u=u+(l<<1)|0;v=v+(p<<1)|0}else{break}}}else{v=0;u=h;r=a;while(1){nrc(u|0,r|0,m)|0;if(n){x=0;do{w=u+(x<<1)|0;y=b[w>>1]|0;b[w>>1]=y<<6|y>>>4;x=x+1|0;}while((x|0)<(d|0))}if(o){x=u+(q<<1)|0;y=d;do{b[u+(y<<1)>>1]=b[x>>1]|0;y=y+1|0;}while((y|0)<(l|0))}y=v+1|0;if((y|0)<(f|0)){v=y;u=u+(l<<1)|0;r=r+(p<<1)|0}else{break}}}p=k+(ca(-32-(t<<5)|0,i)|0)|0;if(s){z=p;A=~t;break}return}else{z=h;A=0}}while(0);h=-l|0;k=i<<5;i=A;A=z;while(1){nrc(A|0,A+(h<<1)|0,k)|0;z=i+1|0;if((z|0)<16){i=z;A=A+(l<<1)|0}else{break}}return}function SXa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;g=1<<f;h=(f|0)==8?3:6;i=1<<h;j=g-1&d-e;e=(j|0)<(g-i|0)?0:g;g=j-e|0;do{if((g|0)>=(-i|0)){if(!((g|0)<=(i|0)&(j|0)!=(e|0))){break}d=b|0;k=c[d>>2]|0;l=b+4|0;m=c[l>>2]|0;if((m|0)>1){n=m-1|0;o=k<<1}else{p=je(k<<m|0)|0;k=b+12|0;q=c[k>>2]|0;y=p;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;n=m+31|0;o=0}c[d>>2]=o;c[l>>2]=n;m=((g|0)>-1?g:-g|0)-1|0;if((n|0)>(h|0)){r=n-h|0;s=o<<h|m}else{k=je(m>>>((h-n|0)>>>0)|o<<n|0)|0;q=b+12|0;p=c[q>>2]|0;y=k;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;r=32-h+n|0;s=m}c[d>>2]=s;c[l>>2]=r;m=g>>>31;if((r|0)>1){t=r-1|0;u=s<<1|m}else{q=je(m>>>((1-r|0)>>>0)|s<<r|0)|0;p=b+12|0;k=c[p>>2]|0;y=q;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;t=r+31|0;u=m}c[d>>2]=u;c[l>>2]=t;return}}while(0);t=b|0;u=c[t>>2]|0;r=b+4|0;s=c[r>>2]|0;if((s|0)>1){v=s-1|0;w=u<<1|1}else{n=je(1>>>((1-s|0)>>>0)|u<<s|0)|0;u=b+12|0;h=c[u>>2]|0;y=n;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=s+31|0;w=1}c[t>>2]=w;c[r>>2]=v;if((v|0)>(f|0)){x=v-f|0;z=w<<f|g}else{s=je(g>>>((f-v|0)>>>0)|w<<v|0)|0;w=b+12|0;b=c[w>>2]|0;y=s;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;x=32-f+v|0;z=g}c[t>>2]=z;c[r>>2]=x;return}function TXa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0;g=(e&3)+1|0;h=e>>>5;i=e>>>2&7;e=g<<h;if(!(e>>>0>f>>>0)){j=(1<<i)-e+f|0;e=j>>>0>65535>>>0;k=e?j>>>16:j;l=e?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=(d[1359664+n|0]|0)+m|0;m=k-i+g|0;g=b|0;i=c[g>>2]|0;n=b+4|0;l=c[n>>2]|0;if((l|0)>(m|0)){o=l;p=i<<m}else{e=je(i<<l|0)|0;i=b+12|0;q=c[i>>2]|0;y=e;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;o=l+32|0;p=0}l=o-m|0;c[g>>2]=p;c[n>>2]=l;m=k+1|0;if((l|0)>(m|0)){r=l-m|0;s=p<<m|j}else{o=je(j>>>((m-l|0)>>>0)|p<<l|0)|0;p=b+12|0;m=c[p>>2]|0;y=o;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;r=31-k+l|0;s=j}c[g>>2]=s;c[n>>2]=r;return}r=f>>h;n=b|0;s=c[n>>2]|0;g=b+4|0;j=c[g>>2]|0;if((r|0)==0){t=s;u=j}else{if((j|0)>(r|0)){v=j-r|0;w=s<<r}else{l=je(s<<j|0)|0;s=b+12|0;k=c[s>>2]|0;y=l;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;v=32-r+j|0;w=0}c[n>>2]=w;c[g>>2]=v;t=w;u=v}v=b|0;w=b+4|0;if((u|0)>1){x=u-1|0;z=t<<1|1}else{g=je(1>>>((1-u|0)>>>0)|t<<u|0)|0;t=b+12|0;n=c[t>>2]|0;y=g;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;x=u+31|0;z=1}c[v>>2]=z;c[w>>2]=x;if((h|0)==0){return}u=(1<<h)-1&f;if((x|0)>(h|0)){A=x-h|0;B=z<<h|u}else{f=je(z<<x|u>>>((h-x|0)>>>0)|0)|0;z=b+12|0;b=c[z>>2]|0;y=f;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;A=32-h+x|0;B=u}c[v>>2]=B;c[w>>2]=A;return}function UXa(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;l=ca(i,h)|0;h=b[j>>1]|0;i=((b[k+(g<<12)>>1]|0)-16384|0)/(h|0)|0;m=i<<1^i>>31;if(m>>>0<32>>>0){n=(m>>5)+5|0}else{o=m+32|0;m=o>>>0>65535>>>0;p=m?o>>>16:o;o=m?16:0;if((p&65280|0)==0){q=o;r=p}else{q=o|8;r=p>>>8}n=((d[1359664+r|0]|0)+q<<1)-5|0}q=n+1|0;n=k+(g<<12)+128|0;r=b[n>>1]|0;p=r<<16>>16;o=p-16384|0;m=(c[f>>2]|0)+((((o|0)>-1?o:16384-p|0)|0)%(h|0)|0)|0;c[f>>2]=m;a:do{if((l|0)>1){p=3;o=i;s=2;t=0;u=n;v=q;w=m;x=r;while(1){y=x<<16>>16;z=y-16384|0;A=(z|0)/(h|0)|0;B=((((z|0)>-1?z:16384-y|0)|0)%(h|0)|0)+w|0;c[f>>2]=B;y=A-o|0;z=y>>31;C=(y^t)-t|0;y=C<<1^C>>31;C=d[1322712+p|0]|0;D=(C&3)+1|0;E=C>>>5;F=C>>>2&7;C=D<<E;if(C>>>0>y>>>0){G=(y>>E)+E|0}else{E=(1<<F)-C+y|0;C=E>>>0>65535>>>0;H=C?E>>>16:E;E=C?16:0;if((H&65280|0)==0){I=E;J=H}else{I=E|8;J=H>>>8}G=D-F+((d[1359664+J|0]|0)+I<<1)|0}F=v+1+G|0;D=(y&1)+y>>1;y=u+128|0;if((s|0)>=(l|0)){K=F;L=B;break a}p=(D|0)>3?3:D;o=A;s=s+1|0;t=z;u=y;v=F;w=B;x=b[y>>1]|0}}else{K=q;L=m}}while(0);m=c[e+19092>>2]|0;e=l<<6;l=0;q=d[1322140]|0;G=d[1322322]|0;I=1;J=0;h=L;while(1){L=m+I|0;r=a[L]|0;n=r&255;b:do{if((n|0)<(e|0)){i=l;x=q;w=G;v=n;u=J;t=h;s=r;while(1){o=b[k+(g<<12)+(v<<1)>>1]|0;p=o<<16>>16;y=b[j+((s&255)<<1)>>1]|0;B=(p|0)/(y|0)|0;F=(((o<<16>>16>-1?p:-p|0)|0)%(y|0)|0)+t|0;c[f>>2]=F;if((B|0)==0){M=u;N=w;O=x;P=i+1|0}else{y=(B|0)>-1?B:-B|0;B=d[1322824+x|0]|0;p=(B&3)+1|0;o=B>>>5;z=B>>>2&7;B=p<<o;if(B>>>0>i>>>0){Q=(i>>o)+o|0}else{o=(1<<z)-B+i|0;B=o>>>0>65535>>>0;A=B?o>>>16:o;o=B?16:0;if((A&65280|0)==0){R=o;S=A}else{R=o|8;S=A>>>8}Q=p-z+((d[1359664+S|0]|0)+R<<1)|0}z=d[1322824+w|0]|0;p=y-1|0;A=(z&3)+1|0;o=z>>>5;B=z>>>2&7;z=A<<o;if(z>>>0>p>>>0){T=(p>>o)+o|0}else{o=(1<<B)-z+p|0;p=o>>>0>65535>>>0;z=p?o>>>16:o;o=p?16:0;if((z&65280|0)==0){U=o;V=z}else{U=o|8;V=z>>>8}T=A-B+((d[1359664+V|0]|0)+U<<1)|0}M=u+3+Q+T|0;N=d[1322320+((y|0)>9?9:y)|0]|0;O=d[1322136+((i|0)>15?15:i)|0]|0;P=0}y=v+64|0;if((y|0)>=(e|0)){W=P;X=O;Y=N;Z=M;_=F;break b}i=P;x=O;w=N;v=y;u=M;t=F;s=a[L]|0}}else{W=l;X=q;Y=G;Z=J;_=h}}while(0);L=I+1|0;if((L|0)<64){l=W;q=X;G=Y;I=L;J=Z;h=_}else{break}}return K+7+Z&-8|0}function VXa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=e>>1;e=0;h=d;while(1){d=e<<3;b[f+(d<<1)>>1]=b[h>>1]|0;b[f+((d|1)<<1)>>1]=b[h+2>>1]|0;b[f+((d|2)<<1)>>1]=b[h+4>>1]|0;b[f+((d|3)<<1)>>1]=b[h+6>>1]|0;b[f+((d|4)<<1)>>1]=b[h+8>>1]|0;b[f+((d|5)<<1)>>1]=b[h+10>>1]|0;b[f+((d|6)<<1)>>1]=b[h+12>>1]|0;b[f+((d|7)<<1)>>1]=b[h+14>>1]|0;d=e+1|0;if((d|0)<8){e=d;h=h+(g<<1)|0}else{break}}qe[c[a+1108>>2]&1023](f);return}function WXa(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=c[j>>2]|0;k=h+f|0;if((f|0)<14){l=-1094995529;i=g;return l|0}m=h;n=(d[m]|d[m+1|0]<<8)<<16>>16;m=n&65535;o=h+8|0;p=(d[o]|d[o+1|0]<<8)<<16>>16&65535;o=h+10|0;q=(d[o]|d[o+1|0]<<8)<<16>>16;o=q&65535;r=h+12|0;if(!(((d[r]|d[r+1|0]<<8)<<16>>16&-8)<<16>>16==16)){QIb(a,2447872,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;l=-1163346256;i=g;return l|0}c[a+140>>2]=50;if(f>>>0<m>>>0){l=-1094995529;i=g;return l|0}if(!(n<<16>>16==44)){QIb(a,2358688,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}n=H4a(a,p,o)|0;if((n|0)<0){l=n;i=g;return l|0}n=M4a(a,b,0)|0;if((n|0)<0){l=n;i=g;return l|0}c[b+88>>2]=1;n=c[b+32>>2]|0;a:do{if(!(q<<16>>16==0)){f=p<<1;r=0;t=h+m|0;u=c[b>>2]|0;while(1){if((k-t|0)>>>0<f>>>0){break}nrc(u|0,t|0,f)|0;v=r+1|0;if(v>>>0<o>>>0){r=v;t=t+f|0;u=u+n|0}else{break a}}c[e>>2]=1;KIb(a,24,2295064,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;l=c[j>>2]|0;i=g;return l|0}}while(0);c[e>>2]=1;l=((ca(o,p)|0)<<1)+m|0;i=g;return l|0}function XXa(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;c[a+416>>2]=1;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;c[a+420>>2]=3;g[b+100>>2]=.09090909361839294;g[b+104>>2]=.1818181872367859;g[b+108>>2]=.27272728085517883;g[b+112>>2]=.3636363744735718;g[b+116>>2]=.4545454680919647;g[b+120>>2]=.5454545617103577;g[b+124>>2]=.6363636255264282;g[b+128>>2]=.7272727489471436;g[b+132>>2]=.8181818127632141;g[b+136>>2]=.9090909361839294;return 0}function YXa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0.0;l=i;i=i+1544|0;m=l|0;n=l+40|0;o=l+80|0;p=l+760|0;q=l+1400|0;r=l+1440|0;s=l+1480|0;t=c[k+24>>2]|0;u=c[k+28>>2]|0;k=f+60|0;v=c[k>>2]|0;w=v;c[h+76>>2]=160;x=M4a(f,h,0)|0;if((x|0)<0){y=x;i=l;return y|0}x=c[h>>2]|0;switch(u|0){case 8:{z=2;A=7;break};case 34:{B=4;A=18;break};case 1:{C=0;D=d[t]|0;A=11;break};case 4:{z=1;A=7;break};case 17:{z=3;A=7;break};case 7:{B=2;A=18;break};case 35:{z=4;A=7;break};case 0:{B=0;A=18;break};case 3:{B=1;A=18;break};case 16:{B=3;A=18;break};default:{A=21}}do{if((A|0)==7){h=a[t]|0;E=h&255;if(!(z>>>0>E>>>0)){C=z;D=E;A=11;break}E=(c[k>>2]|0)+4042|0;if((a[E]|0)==0){KIb(f,24,2119760,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;a[E]=1;G=a[t]|0}else{G=h}H=G&255;A=13}else if((A|0)==18){KIb(f,24,2614688,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;I=B;J=t;A=19}}while(0);do{if((A|0)==11){if((C|0)>=(D|0)){H=C;A=13;break}KIb(f,16,2637896,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;A=21}}while(0);if((A|0)==13){I=H;J=t+1|0;A=19}else if((A|0)==21){t=v+20|0;c[t>>2]=-1;K=t;A=23}a:do{if((A|0)==19){b:do{if((I|0)==0){QIb(f,2587808,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;t=v+20|0;c[t>>2]=0;L=t}else{t=v+20|0;c[t>>2]=I;do{if((I|0)==1){H=J;C=(d[H]|d[H+1|0]<<8)<<16>>16;b[v+4040>>1]=he(C|0)|0;if(!(C<<16>>16==-1)){M=1;break}KIb(f,24,2143376,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2358640,F)|0);i=F;N=t;A=45;break a}else if((I|0)==(-1|0)){K=t;A=23;break a}else{if((I|0)>0){M=I}else{L=t;break b}}}while(0);C=c[692976+(M<<2)>>2]|0;H=C+((e[693e3+(M<<1)>>1]|0)*3|0)|0;D=u<<3;B=D>>>0>2147483639>>>0|(J|0)==0;G=B?0:J;k=B?0:D;D=v;c[D>>2]=G;c[v+12>>2]=k;B=k+8|0;z=v+16|0;c[z>>2]=B;c[v+4>>2]=G+(k>>3);k=v+8|0;c[k>>2]=0;mrc(v+24|0,0,71)|0;do{if((M|0)!=0){h=C;E=0;O=B;P=G;while(1){Q=d[h+2|0]|0;R=P+(E>>>3)|0;S=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(E&7)>>>((32-Q|0)>>>0);R=E+Q|0;c[k>>2]=O>>>0>R>>>0?R:O;R=v+((d[h|0]|0)+24)|0;a[R]=d[R]|S<<d[h+1|0];S=h+3|0;if(!(S>>>0<H>>>0)){break}h=S;E=c[k>>2]|0;O=c[z>>2]|0;P=c[D>>2]|0}if((a[v+94|0]|0)==0){break}KIb(f,24,2143376,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2295024,F)|0);i=F;N=t;A=45;break a}}while(0);D=c[t>>2]|0;c:do{if((D|0)==2){z=0;k=1;while(1){if((k|0)>=5){break c}H=(d[v+(k+40)|0]|0)-(d[v+(k+39)|0]|0)|0;if((((H|0)>-1?H:-H|0)|0)>10){break}G=H-z|0;if((((G|0)>-1?G:-G|0)|0)>12){break}else{z=H;k=k+1|0}}KIb(f,24,2143376,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2244056,F)|0);i=F;N=t;A=45;break a}}while(0);if((D|0)<=2){L=t;break}if((a[v+76|0]|0)==0){A=41}else{if(!((d[v+72|0]|0)>>>0>123>>>0)){A=41}}do{if((A|0)==41){if((a[v+77|0]|0)!=0){if((d[v+73|0]|0)>>>0>123>>>0){break}}if((a[v+78|0]|0)!=0){if((d[v+74|0]|0)>>>0>123>>>0){break}}if((a[v+79|0]|0)==0){L=t;break b}if(!((d[v+75|0]|0)>>>0>123>>>0)){L=t;break b}}}while(0);KIb(f,24,2143376,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2202472,F)|0);i=F;N=t;A=45;break a}}while(0);D=s|0;ZXa(w,D);_Xa(w,D,x);if(($Xa(w,q|0)|0)<0){KIb(f,24,2143376,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2170696,F)|0);i=F;N=L;A=45;break}aYa(w,x);if((c[L>>2]|0)==-1){N=L;A=45;break}a[v+95|0]=0;T=L}}while(0);if((A|0)==23){KIb(f,24,2143376,(F=i,i=i+16|0,c[F>>2]=c[f+428>>2],c[F+8>>2]=2447840,F)|0);i=F;N=K;A=45}if((A|0)==45){c[N>>2]=-1;A=v+95|0;a[A]=(a[A]|0)+1;A=s|0;ZXa(w,A);_Xa(w,A,x);$Xa(w,q|0)|0;aYa(w,x);T=N}N=v+3364|0;w=q|0;A=r|0;s=v+20|0;K=m|0;F=v+100|0;f=F;L=N;M=0;while(1){J=c[s>>2]|0;I=(J|0)>1;if(I){U=+(M+1|0)*.25}else{U=(J|0)==1&(M|0)==0?.625:1.0}d:do{if(U!=1.0){zlb(K,w,f,U,1.0-U,10);bYa(K,A)}else{do{if(!I){if((J|0)==-1&(M|0)==0){break}if((J|M|0)!=0){break d}bYa(f,A);break d}}while(0);bYa(w,A)}}while(0);M3(L,A,x+((M*40|0)<<2)|0,40,10);J=M+1|0;if((J|0)<4){L=L+160|0;M=J}else{break}}U=+g[A>>2];g[K>>2]=U*.625;A=n|0;g[A>>2]=U*.7749999761581421;U=+g[r+4>>2];g[m+4>>2]=U*.390625;g[n+4>>2]=U*.6006249785423279;U=+g[r+8>>2];g[m+8>>2]=U*.24414099752902985;g[n+8>>2]=U*.46548399329185486;U=+g[r+12>>2];g[m+12>>2]=U*.15258799493312836;g[n+12>>2]=U*.3607499897480011;U=+g[r+16>>2];g[m+16>>2]=U*.09536699950695038;g[n+16>>2]=U*.2795819938182831;U=+g[r+20>>2];g[m+20>>2]=U*.05960499867796898;g[n+20>>2]=U*.2166759967803955;U=+g[r+24>>2];g[m+24>>2]=U*.0372529998421669;g[n+24>>2]=U*.16792400181293488;U=+g[r+28>>2];g[m+28>>2]=U*.02328299917280674;g[n+28>>2]=U*.1301410049200058;U=+g[r+32>>2];g[m+32>>2]=U*.014551999978721142;g[n+32>>2]=U*.10085900127887726;U=+g[r+36>>2];g[m+36>>2]=U*.009095000103116035;g[n+36>>2]=U*.07816600054502487;n=p|0;N3(n,K,N,160,10);K=v+4044|0;nrc(o|0,K|0,40)|0;p=o+40|0;M3(p,A,n,160,10);nrc(K|0,o+640|0,40)|0;nlb(v+4088|0,.30000001192092896,p,160);Alb(x,p,+pHb(N,N,160),160,.9375,v+4084|0);nrc(v+3324|0,v+3964|0,40)|0;nrc(F|0,q|0,40)|0;c[v+4016>>2]=c[T>>2];c[j>>2]=1;y=u;i=l;return y|0}function ZXa(b,e){b=b|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0;f=i;i=i+64|0;h=f|0;j=b+20|0;k=c[j>>2]|0;if((k|0)<=1){do{if((k|0)==1){l=c[b+4012>>2]|0;m=((l+(c[b+4008>>2]|0)|0)/2|0)-5|0;if((m|0)<0){n=0}else{n=(m|0)>54?54:m}m=n+(d[b+40|0]<<1)|0;c[h>>2]=m;o=8;p=m;q=l}else if((k|0)==0){i=f;return}else{l=c[b+4012>>2]|0;m=h|0;c[m>>2]=l;r=d[b+95|0]|0;if((r|0)==3){s=l-2|0;c[m>>2]=s;t=s}else if((r|0)==1){t=l}else if((r|0)==2){r=l-1|0;c[m>>2]=r;t=r}else{r=l-6|0;c[m>>2]=r;t=r}if((t|0)>=0){o=4;p=t;q=l;break}c[m>>2]=0;o=4;p=0;q=l}}while(0);t=b+4004|0;u=+g[t>>2];v=(+g[695736+(p<<2)>>2]-u)*.5/+(o|0);n=o|1;l=n>>>0>2>>>0;m=1;w=u;while(1){g[e+(m-1<<2)>>2]=v*+(m|0)+w;r=m+1|0;if((r|0)>(o|0)){break}m=r;w=+g[t>>2]}g[t>>2]=+g[e+((l?n-2|0:0)<<2)>>2];c[b+4008>>2]=q;c[b+4012>>2]=p;i=f;return}if((k|0)==4){x=16}else if((k|0)==3){x=4}else{x=5}p=0;q=k;while(1){k=d[b+40+p|0]<<2;n=h+(p<<2)|0;c[n>>2]=k;do{if((q|0)==4){if((p+1&3|0)!=0){y=k;break}l=(((c[h+(p-2<<2)>>2]|0)+(c[h+(p-1<<2)>>2]|0)+(c[h+(p-3<<2)>>2]|0)|0)/3|0)-6|0;if((l|0)<0){z=0}else{z=(l|0)>32?32:l}l=z+k|0;c[n>>2]=l;y=l}else{y=k}}while(0);w=+g[695736+(y<<2)>>2];k=e+(p<<2)|0;g[k>>2]=w;if((a[b+24+p|0]|0)!=0){g[k>>2]=-0.0-w;k=b+56+p|0;a[k]=(a[k]|0)+39&127}k=p+1|0;if((k|0)>=(x|0)){break}p=k;q=c[j>>2]|0}c[b+4008>>2]=c[h+(x-2<<2)>>2];q=c[h+(x-1<<2)>>2]|0;c[b+4012>>2]=q;g[b+4004>>2]=+g[695736+(q<<2)>>2];if((c[j>>2]|0)!=2){i=f;return}j=e+16|0;w=+g[j>>2];g[e+28>>2]=w;q=e+12|0;v=+g[q>>2];u=v;g[e+24>>2]=u*.4+w*.6;g[e+20>>2]=v;b=e+8|0;v=+g[b>>2]*.8;g[j>>2]=v+u*.2;j=e+4|0;u=+g[j>>2];w=u;g[q>>2]=w*.2+v;g[b>>2]=u;g[j>>2]=+g[e>>2]*.6+w*.4;i=f;return}function _Xa(e,f,i){e=e|0;f=f|0;i=i|0;var j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0;switch(c[e+20>>2]|0){case-1:{j=+g[f>>2]*.01;k=i+160|0;l=i;m=0;n=-44;while(1){g[l>>2]=j*+(b[693424+((n&127)<<1)>>1]|0);o=m+1|0;if((o|0)<40){l=l+4|0;m=o;n=n+1&65535}else{break}}j=+g[f+4>>2]*.01;n=i+320|0;m=k;k=0;l=-4;while(1){g[m>>2]=j*+(b[693424+((l&127)<<1)>>1]|0);o=k+1|0;if((o|0)<40){m=m+4|0;k=o;l=l+1&65535}else{break}}j=+g[f+8>>2]*.01;l=i+480|0;k=n;n=0;m=36;while(1){g[k>>2]=j*+(b[693424+((m&127)<<1)>>1]|0);o=n+1|0;if((o|0)<40){k=k+4|0;n=o;m=m+1&65535}else{break}}j=+g[f+12>>2]*.01;m=l;l=0;n=76;while(1){g[m>>2]=j*+(b[693424+((n&127)<<1)>>1]|0);k=l+1|0;if((k|0)<40){m=m+4|0;l=k;n=n+1&65535}else{break}}return};case 4:{n=i;l=0;while(1){j=+g[f+(l<<2)>>2]*.01;m=d[e+56+l|0]|0;k=1-m&65535;g[n>>2]=j*+(b[693424+((-m&65535&127)<<1)>>1]|0);g[n+4>>2]=j*+(b[693424+((k&127)<<1)>>1]|0);g[n+8>>2]=j*+(b[693424+((k+1&65535&127)<<1)>>1]|0);g[n+12>>2]=j*+(b[693424+((k+2&65535&127)<<1)>>1]|0);g[n+16>>2]=j*+(b[693424+((k+3&65535&127)<<1)>>1]|0);g[n+20>>2]=j*+(b[693424+((k+4&65535&127)<<1)>>1]|0);g[n+24>>2]=j*+(b[693424+((k+5&65535&127)<<1)>>1]|0);g[n+28>>2]=j*+(b[693424+((k+6&65535&127)<<1)>>1]|0);g[n+32>>2]=j*+(b[693424+((k+7&65535&127)<<1)>>1]|0);g[n+36>>2]=j*+(b[693424+((k+8&65535&127)<<1)>>1]|0);k=l+1|0;if((k|0)<16){n=n+40|0;l=k}else{break}}return};case 0:{mrc(i|0,0,640)|0;return};case 1:{j=+g[f>>2]*41921422912597656.0e-21;l=i;n=0;k=b[e+4040>>1]|0;while(1){p=(k*521&65535)+259&65535;g[l>>2]=j*+(p<<16>>16|0);m=n+1|0;if((m|0)<20){l=l+4|0;n=m;k=p}else{break}}j=+g[f+4>>2]*41921422912597656.0e-21;k=i+80|0;n=0;l=p;while(1){q=(l*521&65535)+259&65535;g[k>>2]=j*+(q<<16>>16|0);p=n+1|0;if((p|0)<20){k=k+4|0;n=p;l=q}else{break}}j=+g[f+8>>2]*41921422912597656.0e-21;l=i+160|0;n=0;k=q;while(1){r=(k*521&65535)+259&65535;g[l>>2]=j*+(r<<16>>16|0);q=n+1|0;if((q|0)<20){l=l+4|0;n=q;k=r}else{break}}j=+g[f+12>>2]*41921422912597656.0e-21;k=i+240|0;n=0;l=r;while(1){s=(l*521&65535)+259&65535;g[k>>2]=j*+(s<<16>>16|0);r=n+1|0;if((r|0)<20){k=k+4|0;n=r;l=s}else{break}}j=+g[f+16>>2]*41921422912597656.0e-21;l=i+320|0;n=0;k=s;while(1){t=(k*521&65535)+259&65535;g[l>>2]=j*+(t<<16>>16|0);s=n+1|0;if((s|0)<20){l=l+4|0;n=s;k=t}else{break}}j=+g[f+20>>2]*41921422912597656.0e-21;k=i+400|0;n=0;l=t;while(1){u=(l*521&65535)+259&65535;g[k>>2]=j*+(u<<16>>16|0);t=n+1|0;if((t|0)<20){k=k+4|0;n=t;l=u}else{break}}j=+g[f+24>>2]*41921422912597656.0e-21;l=i+480|0;n=0;k=u;while(1){v=(k*521&65535)+259&65535;g[l>>2]=j*+(v<<16>>16|0);u=n+1|0;if((u|0)<20){l=l+4|0;n=u;k=v}else{break}}j=+g[f+28>>2]*41921422912597656.0e-21;k=i+560|0;n=0;l=v;while(1){v=(l*521&65535)+259&65535;g[k>>2]=j*+(v<<16>>16|0);u=n+1|0;if((u|0)<20){k=k+4|0;n=u;l=v}else{break}}return};case 3:{j=+g[f>>2]*.5;l=i;n=0;k=-(d[e+56|0]|0)&65535;while(1){g[l>>2]=j*+(a[693192+(k&127)|0]|0);v=n+1|0;if((v|0)<40){l=l+4|0;n=v;k=k+1&65535}else{break}}j=+g[f+4>>2]*.5;k=i+160|0;n=0;l=-(d[e+57|0]|0)&65535;while(1){g[k>>2]=j*+(a[693192+(l&127)|0]|0);v=n+1|0;if((v|0)<40){k=k+4|0;n=v;l=l+1&65535}else{break}}j=+g[f+8>>2]*.5;l=i+320|0;n=0;k=-(d[e+58|0]|0)&65535;while(1){g[l>>2]=j*+(a[693192+(k&127)|0]|0);v=n+1|0;if((v|0)<40){l=l+4|0;n=v;k=k+1&65535}else{break}}j=+g[f+12>>2]*.5;k=i+480|0;n=0;l=-(d[e+59|0]|0)&65535;while(1){g[k>>2]=j*+(a[693192+(l&127)|0]|0);v=n+1|0;if((v|0)<40){k=k+4|0;n=v;l=l+1&65535}else{break}}return};case 2:{l=i;i=0;n=d[e+87|0]<<8&16128|d[e+88|0]<<14|d[e+86|0]<<1&192|d[e+85|0]<<3&56|(a[e+84|0]&255)>>>3&7;k=e+2684|0;while(1){j=+g[f+(i<<2)>>2]*41921422912597656.0e-21;v=k+80|0;u=l;t=0;s=n;r=k;while(1){w=(s*521&65535)+259&65535;g[r>>2]=+(w<<16>>16|0);q=0;x=0.0;while(1){p=q+1|0;y=x+ +h[693016+(q<<3)>>3]*(+g[r+(-q<<2)>>2]+ +g[r+(q-20<<2)>>2]);if((p|0)<10){q=p;x=y}else{break}}g[u>>2]=j*(y+ +g[r-40>>2]*.8985137);q=t+1|0;if((q|0)<20){u=u+4|0;t=q;s=w;r=r+4|0}else{break}}r=i+1|0;if((r|0)<8){l=l+80|0;i=r;n=w;k=v}else{break}}nrc(e+2604|0,e+3244|0,80)|0;return};default:{return}}}function $Xa(b,f){b=b|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0;h=b+20|0;i=c[h>>2]|0;if((i|0)==1|(i|0)==(-1|0)){j=c[b+4016>>2]|0;if((j|0)==1|(j|0)==(-1|0)){k=b+140|0}else{k=b+100|0}if((i|0)==1){i=b+96|0;a[i]=(a[i]|0)+1;j=0;while(1){l=j+1|0;m=+(l|0)*.008522727272727272+(((a[b+84+j|0]|0)!=0?.02:-.02)+ +g[k+(j<<2)>>2]*29.0*.03125);g[f+(j<<2)>>2]=m;g[b+140+(j<<2)>>2]=m;if((l|0)<10){j=l}else{break}}n=(d[i]|0)>>>0<10>>>0?.875:.10000000149011612;o=f+4|0;p=f+8|0;q=f+12|0;r=f+16|0;s=f+20|0;t=f+24|0;u=f+28|0;v=f+32|0;w=f+36|0}else{i=a[b+95|0]|0;if((i&255)>>>0>1>>>0){x=(i&255)>>>0<4>>>0?.815625011920929:.6343749761581421}else{x=.90625}m=1.0-x;y=m/11.0+x*+g[k>>2];g[f>>2]=y;g[b+140>>2]=y;y=m*2.0/11.0+x*+g[k+4>>2];i=f+4|0;g[i>>2]=y;g[b+144>>2]=y;y=m*3.0/11.0+x*+g[k+8>>2];j=f+8|0;g[j>>2]=y;g[b+148>>2]=y;y=m*4.0/11.0+x*+g[k+12>>2];l=f+12|0;g[l>>2]=y;g[b+152>>2]=y;y=m*5.0/11.0+x*+g[k+16>>2];z=f+16|0;g[z>>2]=y;g[b+156>>2]=y;y=m*6.0/11.0+x*+g[k+20>>2];A=f+20|0;g[A>>2]=y;g[b+160>>2]=y;y=m*7.0/11.0+x*+g[k+24>>2];B=f+24|0;g[B>>2]=y;g[b+164>>2]=y;y=m*8.0/11.0+x*+g[k+28>>2];C=f+28|0;g[C>>2]=y;g[b+168>>2]=y;y=m*9.0/11.0+x*+g[k+32>>2];D=f+32|0;g[D>>2]=y;g[b+172>>2]=y;y=m*10.0/11.0+x*+g[k+36>>2];k=f+36|0;g[k>>2]=y;g[b+176>>2]=y;n=.125;o=i;p=j;q=l;r=z;s=A;t=B;u=C;v=D;w=k}y=+g[f>>2];x=+g[o>>2];m=y>.02?y:.019999999552965164;y=m+.02;E=+g[p>>2];F=x>y?x:y;y=F+.02;x=+g[q>>2];G=E>y?E:y;y=G+.02;E=+g[r>>2];H=x>y?x:y;y=H+.02;x=+g[s>>2];I=E>y?E:y;y=I+.02;E=+g[t>>2];J=x>y?x:y;y=J+.02;x=+g[u>>2];K=E>y?E:y;y=K+.02;E=+g[v>>2];L=x>y?x:y;y=L+.02;x=+g[w>>2];M=E>y?E:y;y=M+.02;E=x>y?x:y;y=E>.98?.9800000190734863:E;g[w>>2]=y;E=y+-.02;y=M>E?E:M;g[v>>2]=y;M=y+-.02;y=L>M?M:L;g[u>>2]=y;L=y+-.02;y=K>L?L:K;g[t>>2]=y;K=y+-.02;y=J>K?K:J;g[s>>2]=y;J=y+-.02;y=I>J?J:I;g[r>>2]=y;I=y+-.02;y=H>I?I:H;g[q>>2]=y;H=y+-.02;y=G>H?H:G;g[p>>2]=y;G=y+-.02;y=F>G?G:F;g[o>>2]=y;F=y+-.02;g[f>>2]=m>F?F:m;zlb(f,f,b+100|0,n,1.0-n,10);N=0;return N|0}a[b+96|0]=0;o=0;n=0.0;do{p=b+84+o|0;q=c[695712+(o<<2)>>2]|0;m=n+ +(e[q+(d[p]<<2)>>1]|0)*1.0e-4;r=o<<1;g[f+(r<<2)>>2]=m;n=m+ +(e[q+(d[p]<<2)+2>>1]|0)*1.0e-4;g[f+((r|1)<<2)>>2]=n;o=o+1|0;}while((o|0)<5);n=+g[f+36>>2];if((c[h>>2]|0)==2){if(n>.7&n<.97){O=3}else{N=-1;return N|0}while(1){if((O|0)>=10){N=0;P=22;break}if(+R(+(+g[f+(O<<2)>>2]- +g[f+(O-2<<2)>>2]))<.08){N=-1;P=22;break}else{O=O+1|0}}if((P|0)==22){return N|0}}else{if(n>.66&n<.985){Q=4}else{N=-1;return N|0}while(1){if((Q|0)>=10){N=0;P=22;break}if(+R(+(+g[f+(Q<<2)>>2]- +g[f+(Q-4<<2)>>2]))<.0931){N=-1;P=22;break}else{Q=Q+1|0}}if((P|0)==22){return N|0}}return 0}function aYa(b,e){b=b|0;e=e|0;var f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0;f=c[b+20>>2]|0;h=(f|0)>2;do{if(!(h|(f|0)==0)){if((f|0)==-1){if((c[b+4016>>2]|0)>2){break}}i=e+68|0;nrc(b+180|0,i|0,572)|0;nrc(b+1392|0,i|0,572)|0;mrc(b+4020|0,0,20)|0;return}}while(0);if(h){h=a[b+72|0]|0;if(h<<24>>24==0){j=0.0}else{j=+((d[b+80|0]|0)+1|0)*.25}g[b+4020>>2]=j;a[b+4036|0]=h+16;h=a[b+73|0]|0;if(h<<24>>24==0){k=0.0}else{k=+((d[b+81|0]|0)+1|0)*.25}g[b+4024>>2]=k;a[b+4037|0]=h+16;h=a[b+74|0]|0;if(h<<24>>24==0){l=0.0}else{l=+((d[b+82|0]|0)+1|0)*.25}g[b+4028>>2]=l;a[b+4038|0]=h+16;h=a[b+75|0]|0;if(h<<24>>24==0){m=0.0}else{m=+((d[b+83|0]|0)+1|0)*.25}g[b+4032>>2]=m;a[b+4039|0]=h+16;n=j}else{do{if((f|0)==-1){h=a[b+95|0]|0;if(!((h&255)>>>0<3>>>0)){o=0.0;break}o=.9- +((h&255)-1|0)*.3}else{o=1.0}}while(0);f=b+4020|0;j=+g[f>>2];m=j>o?o:j;g[f>>2]=m;f=b+4024|0;j=+g[f>>2];g[f>>2]=j>o?o:j;f=b+4028|0;j=+g[f>>2];g[f>>2]=j>o?o:j;f=b+4032|0;j=+g[f>>2];g[f>>2]=j>o?o:j;f=b+76|0;y=0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;n=m}f=b+752|0;h=0;i=f;p=e;m=n;while(1){q=b+4020+(h<<2)|0;if(m!=0.0){r=p+160|0;s=b+76+h|0;t=b+180+((h*40|0)+143-(d[b+4036+h|0]|0)<<2)|0;u=i;v=p;while(1){if((a[s]|0)==0){n=+g[t>>2];g[u>>2]=n;w=n;x=t+4|0}else{g[u>>2]=0.0;n=(+g[t-16>>2]+ +g[t+12>>2])*-.006821999792009592+0.0;g[u>>2]=n;j=n+(+g[t-12>>2]+ +g[t+8>>2])*.041248999536037445;g[u>>2]=j;z=t+4|0;n=j+(+g[t-8>>2]+ +g[z>>2])*-.1434590071439743;g[u>>2]=n;j=n+(+g[t-4>>2]+ +g[t>>2])*.5888630151748657;g[u>>2]=j;w=j;x=z}g[u>>2]=+g[v>>2]+w*+g[q>>2];z=u+4|0;A=v+4|0;if(A>>>0<r>>>0){t=x;u=z;v=A}else{B=A;C=z;break}}}else{nrc(i|0,p|0,160)|0;B=p+160|0;C=i+160|0}v=h+1|0;if((v|0)>=4){break}h=v;i=C;p=B;m=+g[b+4020+(v<<2)>>2]}nrc(b+180|0,b+820|0,572)|0;B=b+4020|0;m=+g[B>>2];if(m>1.0){D=.5}else{D=m*.5}g[B>>2]=D;B=b+4024|0;m=+g[B>>2];if(m>1.0){E=.5}else{E=m*.5}g[B>>2]=E;B=b+4028|0;E=+g[B>>2];if(E>1.0){F=.5}else{F=E*.5}g[B>>2]=F;B=b+4032|0;F=+g[B>>2];if(F>1.0){G=.5}else{G=F*.5}g[B>>2]=G;B=b+1964|0;p=0;C=B;i=f;G=D;while(1){h=b+4020+(p<<2)|0;if(G!=0.0){x=i+160|0;v=b+76+p|0;u=b+1392+((p*40|0)+143-(d[b+4036+p|0]|0)<<2)|0;t=C;r=i;while(1){if((a[v]|0)==0){D=+g[u>>2];g[t>>2]=D;H=D;I=u+4|0}else{g[t>>2]=0.0;D=(+g[u-16>>2]+ +g[u+12>>2])*-.006821999792009592+0.0;g[t>>2]=D;F=D+(+g[u-12>>2]+ +g[u+8>>2])*.041248999536037445;g[t>>2]=F;q=u+4|0;D=F+(+g[u-8>>2]+ +g[q>>2])*-.1434590071439743;g[t>>2]=D;F=D+(+g[u-4>>2]+ +g[u>>2])*.5888630151748657;g[t>>2]=F;H=F;I=q}g[t>>2]=+g[r>>2]+H*+g[h>>2];q=t+4|0;s=r+4|0;if(s>>>0<x>>>0){u=I;t=q;r=s}else{J=s;K=q;break}}}else{nrc(C|0,i|0,160)|0;J=i+160|0;K=C+160|0}r=p+1|0;if((r|0)>=4){break}p=r;C=K;i=J;G=+g[b+4020+(r<<2)>>2]}nrc(b+1392|0,b+2032|0,572)|0;Blb(e,B,+pHb(f,f,40),40);f=b+912|0;Blb(e+160|0,b+2124|0,+pHb(f,f,40),40);f=b+1072|0;Blb(e+320|0,b+2284|0,+pHb(f,f,40),40);f=b+1232|0;Blb(e+480|0,b+2444|0,+pHb(f,f,40),40);return}function bYa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;i=i+80|0;d=c|0;e=d|0;h[e>>3]=+U(+g[a>>2]*3.141592653589793);h[d+8>>3]=+U(+g[a+4>>2]*3.141592653589793);h[d+16>>3]=+U(+g[a+8>>2]*3.141592653589793);h[d+24>>3]=+U(+g[a+12>>2]*3.141592653589793);h[d+32>>3]=+U(+g[a+16>>2]*3.141592653589793);h[d+40>>3]=+U(+g[a+20>>2]*3.141592653589793);h[d+48>>3]=+U(+g[a+24>>2]*3.141592653589793);h[d+56>>3]=+U(+g[a+28>>2]*3.141592653589793);h[d+64>>3]=+U(+g[a+32>>2]*3.141592653589793);h[d+72>>3]=+U(+g[a+36>>2]*3.141592653589793);CPa(e,b,5);g[b>>2]=+g[b>>2]*.9883;e=b+4|0;g[e>>2]=+g[e>>2]*.97673689;e=b+8|0;g[e>>2]=+g[e>>2]*.9653090683869999;e=b+12|0;g[e>>2]=+g[e>>2]*.9540149522868719;e=b+16|0;g[e>>2]=+g[e>>2]*.9428529773451155;e=b+20|0;g[e>>2]=+g[e>>2]*.9318215975101777;e=b+24|0;g[e>>2]=+g[e>>2]*.9209192848193085;e=b+28|0;g[e>>2]=+g[e>>2]*.9101445291869226;e=b+32|0;g[e>>2]=+g[e>>2]*.8994958381954355;e=b+36|0;g[e>>2]=+g[e>>2]*.8889717368885489;i=c;return}function cYa(e){e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;h=c[e+60>>2]|0;if(!(a[692968]|0)){c[846781]=5414640;c[846783]=260;$2(3387120,8,24,255352,1,1,255304,2,2,0,0,0,6)|0;c[846813]=5415680;c[846815]=306;$2(3387248,8,37,255944,1,1,255864,2,2,0,0,0,6)|0;c[846775]=5416904;c[846777]=32;$2(3387096,5,6,255296,1,1,255288,1,1,0,0,0,6)|0;c[1518679]=5417032;c[1518681]=296;$2(6074712,8,28,1241088,1,1,1241032,2,2,0,0,0,6)|0;c[1518673]=5418216;c[1518675]=272;$2(6074688,8,20,1241008,1,1,1240968,2,2,0,0,0,6)|0;c[1518667]=5419304;c[1518669]=64;$2(6074664,6,7,1240448,1,1,1240440,1,1,0,0,0,6)|0;c[1518661]=5419560;c[1518663]=64;$2(6074640,6,9,1240424,1,1,1240408,1,1,0,0,0,6)|0;c[846769]=5419816;c[846771]=384;$2(3387072,8,20,255264,1,1,255224,2,2,0,0,0,6)|0;c[846757]=5421352;c[846759]=272;$2(3387024,8,24,255128,1,1,255080,2,2,0,0,0,6)|0;c[846763]=5422440;c[846765]=264;$2(3387048,8,24,255200,1,1,255152,2,2,0,0,0,6)|0;c[846751]=5423496;c[846753]=64;$2(3387e3,6,9,255064,1,1,255048,1,1,0,0,0,6)|0;c[846745]=5423752;c[846747]=32;$2(3386976,5,10,255032,1,1,255016,1,1,0,0,0,6)|0;c[846787]=5423880;c[846789]=260;$2(3387144,8,23,255840,1,1,255792,2,2,0,0,0,6)|0;c[846792]=5424920;c[846794]=264;$2(3387164,8,28,255760,1,1,255704,2,2,0,0,0,6)|0;c[846797]=5425976;c[846799]=290;$2(3387184,8,32,255672,1,1,255608,2,2,0,0,0,6)|0;c[846802]=5427136;c[846804]=324;$2(3387204,8,35,255568,1,1,255496,2,2,0,0,0,6)|0;c[846807]=5428432;c[846809]=390;$2(3387224,8,38,255456,1,1,255376,2,2,0,0,0,6)|0;XSa(7687744);j=0;while(1){b[5095944+(j<<1)>>1]=27600-~~(+V(+(j|0)*.00019353590323589742)*-5167.0);k=j+1|0;if((k|0)<8117){j=k}else{l=0;m=0;n=0;break}}while(1){j=Erc(m,l,214013,0)|0;k=wrc(j,G,2531011,0)|0;g[5467640+(n<<2)>>2]=(+(k>>>16&32767|0)*6103515625.0e-14+-1.0)*1.3;j=n+1|0;if((j|0)<4096){l=G;m=k;n=j}else{o=0;break}}while(1){a[5412336+(o*5|0)|0]=(o>>>0)/81|0;n=(o>>>0)%81|0;a[5412337+(o*5|0)|0]=(n>>>0)/27|0;m=(n>>>0)%27|0;a[5412338+(o*5|0)|0]=(m>>>0)/9|0;n=(m>>>0)%9|0;a[5412339+(o*5|0)|0]=(n>>>0)/3|0;a[5412340+(o*5|0)|0]=(n>>>0)%3|0;n=o+1|0;if((n|0)<256){o=n}else{p=0;break}}while(1){a[5411952+(p*3|0)|0]=(p>>>0)/25|0;o=(p>>>0)%25|0;a[5411953+(p*3|0)|0]=(o>>>0)/5|0;a[5411954+(p*3|0)|0]=(o>>>0)%5|0;o=p+1|0;if((o|0)<128){p=o}else{q=0;r=0;break}}do{q=(q*214013|0)+2531011|0;g[5484104+(r<<2)>>2]=+((q>>>16&32767)>>>0>>>0)*6103515625.0e-14+-1.0;r=r+1|0;}while((r|0)<128);a[692968]=1}r=c[e+96>>2]|0;do{if((r|0)!=0){q=c[e+100>>2]|0;if((q|0)<48){break}else{s=r;t=q}while(1){if((grc(s,2458528,7)|0)==0){u=14;break}q=t-1|0;if((q|0)>7){s=s+1|0;t=q}else{v=q;break}}do{if((u|0)==14){if((t|0)<12){v=t;break}if((a[s+7|0]|0)==67){KIb(e,16,2419384,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=f;return x|0}q=t-8|0;p=s+8|0;o=je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;if((o|0)>(q|0)){KIb(e,16,2410304,(w=i,i=i+16|0,c[w>>2]=q,c[w+8>>2]=o,w)|0);i=w;x=-1;i=f;return x|0}q=e;KIb(q,48,2402680,(w=i,i=i+8|0,c[w>>2]=o,w)|0);i=w;o=s+12|0;if((d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)!=1094927441){KIb(q,16,2395768,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=f;return x|0}o=s+20|0;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=je(p|0)|0;n=h+4|0;c[n>>2]=o;c[h>>2]=o;c[e+416>>2]=o;if(((c[n>>2]|0)-1|0)>>>0>1>>>0){KIb(q,16,2388536,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1094995529;i=f;return x|0}o=(p|0)==33554432;p=e+448|0;c[p>>2]=o?3:4;c[p+4>>2]=o?0:0;o=s+24|0;c[e+412>>2]=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=s+28|0;p=e+72|0;c[p>>2]=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=s+32|0;m=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;c[h+8>>2]=m;o=s+36|0;l=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;c[h+12>>2]=l;o=s+40|0;j=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;c[h+16>>2]=j;if(j>>>0>268435455>>>0){KIb(q,16,2381752,(w=i,i=i+8|0,c[w>>2]=j,w)|0);i=w;x=-1094995529;i=f;return x|0}j=l>>>0>65535>>>0;o=j?l>>>16:l;k=j?16:0;if((o&65280|0)==0){y=k;z=o}else{y=k|8;z=o>>>8}o=d[1359664+z|0]|0;k=y+1+o|0;c[h+24>>2]=k;j=m>>>0>65535>>>0;A=j?m>>>16:m;B=j?16:0;if((A&65280|0)==0){C=B;D=A}else{C=B|8;D=A>>>8}c[h+20>>2]=C+1+(d[1359664+D|0]|0);c[h+28>>2]=(m|0)/16|0;if((m|0)>8207){x=-1094995529;i=f;return x|0}m=k-7|0;c[h+36>>2]=m;c[h+32>>2]=255>>>((9-k|0)>>>0);switch((m<<1)+(c[n>>2]|0)|0){case 5:{E=80;break};case 6:{E=100;break};case 3:{E=56;break};case 2:{E=48;break};case 4:{E=72;break};case 1:{E=40;break};default:{E=m}}n=c[p>>2]|0;c[h+44>>2]=(E*2240|0|0)<(n|0)?4:(E*1760|0|0)<(n|0)?3:(E*1440|0|0)<(n|0)?2:(E*1e3|0|0)<(n|0)|0;n=c[p>>2]|0;do{if((n|0)<8001){c[h+40>>2]=0}else{p=h+40|0;if((n|0)<16e3){c[p>>2]=1;break}else{c[p>>2]=2;break}}}while(0);if(m>>>0>2>>>0){KIb(q,16,2375184,(w=i,i=i+8|0,c[w>>2]=k,w)|0);i=w;x=-1;i=f;return x|0}if((l|0)==(1<<y+o|0)){nZa(h+38832|0,k,1)|0;PSa(h+51240|0);c[e+420>>2]=1;x=0;i=f;return x|0}else{KIb(q,16,2368440,(w=i,i=i+8|0,c[w>>2]=l,w)|0);i=w;x=-1094995529;i=f;return x|0}}}while(0);KIb(e,16,2441568,(w=i,i=i+8|0,c[w>>2]=v,w)|0);i=w;x=-1;i=f;return x|0}}while(0);KIb(e,16,2468136,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;x=-1;i=f;return x|0}function dYa(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0.0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0.0,Dc=0.0,Ec=0.0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0.0,Kc=0,Lc=0.0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0;k=i;i=i+200|0;l=k|0;m=k+8|0;n=k+40|0;o=k+64|0;p=k+88|0;q=k+112|0;r=k+136|0;s=k+160|0;t=k+184|0;u=c[j+24>>2]|0;v=c[e+60>>2]|0;w=v;if((u|0)==0){x=0;i=k;return x|0}z=v+16|0;if((c[j+28>>2]|0)<(c[z>>2]|0)){x=-1;i=k;return x|0}j=v+28|0;c[f+76>>2]=c[j>>2]<<4;A=M4a(e,f,0)|0;if((A|0)<0){x=A;i=k;return x|0}A=v+4|0;e=v+43040|0;B=v+43044|0;C=v+43048|0;D=v+129856|0;E=v+129844|0;F=v+121312|0;G=v+496|0;H=v+36|0;I=v+40|0;J=v;K=s|0;L=s+12|0;M=s+16|0;N=s+4|0;O=s+8|0;P=t|0;Q=v+129848|0;R=t+8|0;S=t+4|0;T=v+368|0;W=v+628|0;X=W;Y=v+38808|0;Z=v+38812|0;_=v+38816|0;$=v+38820|0;aa=v+38824|0;ba=v+38828|0;da=W;ea=v+129852|0;fa=v+129860|0;ga=(W|0)==0;W=r|0;ha=r+12|0;ia=r+16|0;ja=r+4|0;ka=r+8|0;la=p|0;ma=p+12|0;na=p+16|0;oa=p+4|0;pa=p+8|0;qa=v+44|0;ra=o|0;sa=o+12|0;ta=o+16|0;ua=o+4|0;va=o+8|0;wa=q|0;xa=q+12|0;ya=q+16|0;za=q+4|0;Aa=q+8|0;Ba=v+38764|0;Ca=v+38768|0;Da=Ca;Ea=n|0;Fa=n+12|0;Ga=n+16|0;Ha=n+4|0;Ia=n+8|0;Ja=v+38772|0;Ka=v+38776|0;La=v+38780|0;Ma=v+38784|0;Na=v+12|0;Oa=v+38804|0;Pa=v+28760|0;Qa=v+28756|0;Ra=v+32|0;Sa=m+26|0;Ta=m|0;Ua=m+4|0;Va=m+8|0;Wa=m+12|0;Xa=m+16|0;Ya=m+20|0;Za=m+24|0;_a=v+38832|0;$a=v+38916|0;ab=v+500|0;bb=v+51240|0;v=c[f>>2]|0;f=0;cb=c[j>>2]|0;db=c[A>>2]|0;a:while(1){eb=ca(db,cb)|0;if(eb>>>0>1024>>>0){x=-1;fb=290;break}c[e>>2]=u;c[B>>2]=c[z>>2];gb=w+43048+(eb<<2)|0;hb=eb<<2;orc(C|0,gb|0,hb|0)|0;mrc(gb|0,0,hb|0)|0;b:do{if((c[D>>2]|0)==0){c[E>>2]=0;KIb(0,48,2447816,(ib=i,i=i+1|0,i=i+7&-8,c[ib>>2]=0,ib)|0);i=ib;c[G>>2]=0;mrc(F|0,0,852)|0;hb=c[H>>2]|0;if((hb|0)>1){jb=29}else{jb=(8<<hb)-1|0}hb=(d[1648368+((c[I>>2]|0)*30|0)+jb|0]|0)+1|0;if((c[J>>2]|0)>0){gb=0;do{kb=0;do{lb=w+120672+(gb*80|0)+(kb<<3)|0;mb=(a[w+120672+(gb*80|0)+(kb<<3)+1|0]|0)+(a[lb]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+2|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+3|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+4|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+5|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+6|0]|0)+(a[w+120672+(gb*80|0)+(kb<<3)+7|0]|0)|0;nb=(mb|0)/8|0;if((mb|0)>7){ob=nb+255&255}else{ob=nb&255}mrc(lb|0,ob|0,8)|0;kb=kb+1|0;}while((kb|0)<(hb|0));gb=gb+1|0;}while((gb|0)<(c[J>>2]|0))}gb=c[e>>2]|0;hb=c[B>>2]<<3;kb=hb>>>0>2147483639>>>0|(gb|0)==0;lb=kb?0:gb;gb=kb?0:hb;c[K>>2]=lb;c[L>>2]=gb;c[M>>2]=gb+8;c[N>>2]=lb+(gb>>3);c[O>>2]=0;iYa(s,t);gb=c[P>>2]|0;if((gb-2|0)>>>0>5>>>0){c[E>>2]=1;KIb(0,16,2170672,(ib=i,i=i+1|0,i=i+7&-8,c[ib>>2]=0,ib)|0);i=ib;break}if((gb|0)==2){pb=1}else{pb=(gb|0)==3|0}c[Q>>2]=pb;lb=(c[B>>2]|0)-((c[O>>2]|0)/8|0)|0;hb=c[R>>2]|0;kb=c[S>>2]|0;nb=kb<<3;mb=nb>>>0>2147483639>>>0|(hb|0)==0;qb=mb?0:hb;hb=mb?0:nb;c[K>>2]=qb;c[L>>2]=hb;nb=hb+8|0;c[M>>2]=nb;mb=qb+(hb>>3)|0;c[N>>2]=mb;c[O>>2]=0;do{if((gb|0)==2|(gb|0)==4|(gb|0)==5){rb=qb;sb=nb>>>0>8>>>0?8:nb;tb=((d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24)&255)*257|0;rb=qb+(sb>>>3)|0;ub=d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0;rb=sb+8|0;c[O>>2]=nb>>>0>rb>>>0?rb:nb;rb=(ub<<1&510)+tb|0;tb=c[e>>2]|0;ub=c[z>>2]|0;sb=rb&65535;if((ub|0)>0){vb=rb;rb=0;do{vb=vb-(d[tb+rb|0]|0)|0;rb=rb+1|0;}while((rb|0)<(ub|0));wb=vb&65535}else{wb=sb}if(wb<<16>>16==0){break}c[E>>2]=1;KIb(0,16,2143352,(ib=i,i=i+1|0,i=i+7&-8,c[ib>>2]=0,ib)|0);i=ib;break b}}while(0);c[T>>2]=0;c[X>>2]=0;gb=(c[Y>>2]|0)-1|0;c[Y>>2]=(gb|0)<0?0:gb;gb=(c[Z>>2]|0)-1|0;c[Z>>2]=(gb|0)<0?0:gb;gb=(c[_>>2]|0)-1|0;c[_>>2]=(gb|0)<0?0:gb;gb=(c[$>>2]|0)-1|0;c[$>>2]=(gb|0)<0?0:gb;gb=(c[aa>>2]|0)-1|0;c[aa>>2]=(gb|0)<0?0:gb;gb=(c[ba>>2]|0)-1|0;c[ba>>2]=(gb|0)<0?0:gb;do{if((lb|0)>0){gb=lb;ub=0;rb=0;tb=0;c:while(1){if(tb>>>0>15>>>0){fb=27;break}xb=w+240+(tb<<3)|0;c[w+240+(tb<<3)+4>>2]=0;if((tb|0)>0){c[w+240+(tb-1<<3)+4>>2]=xb;c[K>>2]=qb;c[L>>2]=hb;c[M>>2]=nb;c[N>>2]=mb;yb=rb<<3;c[O>>2]=nb>>>0>yb>>>0?yb:nb;if(!(rb>>>0<kb>>>0)){fb=50;break}}yb=w+48+(tb*12|0)|0;iYa(s,yb);zb=w+48+(tb*12|0)+4|0;Ab=c[zb>>2]|0;Bb=c[O>>2]|0;Cb=((Bb|0)/8|0)+Ab|0;Db=Ab+2+(Ab>>>0>255>>>0)|0;Eb=yb|0;Fb=c[Eb>>2]|0;if((Fb|0)==0){fb=50;break}if((Db|0)>(gb|0)){if(!((Fb-10|0)>>>0<3>>>0)){fb=50;break}c[zb>>2]=Ab+gb-Db}Ab=gb-Db|0;c[xb>>2]=yb;xb=c[Eb>>2]|0;if((xb|0)==8){fb=35;break}do{if((xb-9|0)>>>0<4>>>0){if((ub|0)>0){c[w+628+(ub-1<<3)+4>>2]=w+628+(ub<<3)}c[w+628+(ub<<3)>>2]=yb;c[w+628+(ub<<3)+4>>2]=0;Gb=ub+1|0}else{if((xb|0)==15){fb=43;break c}else if((xb|0)==13){Eb=c[M>>2]|0;Db=c[K>>2]|0;zb=Db+(Bb>>>3)|0;Fb=Bb+6|0;Hb=Eb>>>0>Fb>>>0?Fb:Eb;c[Y>>2]=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Bb&7)>>>0)&63;zb=Db+(Hb>>>3)|0;Fb=Hb+6|0;Ib=Eb>>>0>Fb>>>0?Fb:Eb;c[Z>>2]=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Hb&7)>>>0)&63;Hb=Db+(Ib>>>3)|0;zb=Ib+6|0;Fb=Eb>>>0>zb>>>0?zb:Eb;c[_>>2]=(d[Hb]|d[Hb+1|0]<<8|d[Hb+2|0]<<16|d[Hb+3|0]<<24|0)>>>((Ib&7)>>>0)&63;Ib=Db+(Fb>>>3)|0;Hb=Fb+6|0;zb=Eb>>>0>Hb>>>0?Hb:Eb;c[$>>2]=(d[Ib]|d[Ib+1|0]<<8|d[Ib+2|0]<<16|d[Ib+3|0]<<24|0)>>>((Fb&7)>>>0)&63;Fb=Db+(zb>>>3)|0;Ib=zb+6|0;Hb=Eb>>>0>Ib>>>0?Ib:Eb;c[aa>>2]=(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)>>>((zb&7)>>>0)&63;zb=Db+(Hb>>>3)|0;Db=Hb+6|0;c[ba>>2]=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Hb&7)>>>0)&63;c[O>>2]=Eb>>>0>Db>>>0?Db:Eb;Gb=ub;break}else if((xb|0)==14){c[Y>>2]=hYa(s,c[1518672]|0,c[1518673]|0,0,2)|0;c[Z>>2]=hYa(s,c[1518672]|0,c[1518673]|0,0,2)|0;c[_>>2]=hYa(s,c[1518672]|0,c[1518673]|0,0,2)|0;c[$>>2]=hYa(s,c[1518672]|0,c[1518673]|0,0,2)|0;c[aa>>2]=hYa(s,c[1518672]|0,c[1518673]|0,0,2)|0;c[ba>>2]=hYa(s,c[1518672]|0,c[1518673]|0,0,2)|0;Gb=ub;break}else{Eb=xb-16|0;if(!(Eb>>>0<32>>>0)){Gb=ub;break}if((1056997120>>>(Eb>>>0)&1|0)!=0){Gb=ub;break}Eb=c[G>>2]|0;if((Eb|0)>0){c[w+368+(Eb-1<<3)+4>>2]=w+368+(Eb<<3)}c[w+368+(Eb<<3)>>2]=yb;Eb=c[G>>2]|0;c[w+368+(Eb<<3)+4>>2]=0;c[G>>2]=Eb+1;Gb=ub;break}}}while(0);if((Ab|0)>0){gb=Ab;ub=Gb;rb=Cb;tb=tb+1|0}else{fb=50;break}}if((fb|0)==27){fb=0;KIb(0,32,2358552,(ib=i,i=i+8|0,c[ib>>2]=2119736,ib)|0);i=ib;break b}else if((fb|0)==35){fb=0;KIb(0,32,2358552,(ib=i,i=i+8|0,c[ib>>2]=2637880,ib)|0);i=ib;break b}else if((fb|0)==43){fb=0;KIb(0,32,2358552,(ib=i,i=i+8|0,c[ib>>2]=2614672,ib)|0);i=ib;break b}else if((fb|0)==50){fb=0;if((c[X>>2]|0)==0){break}d:do{if(ga){Jb=0;fb=133}else{tb=da;while(1){Kb=c[tb>>2]|0;if((Kb|0)==0){Lb=0;break}if((c[Kb>>2]|0)==9){fb=55;break}rb=c[tb+4>>2]|0;if((rb|0)==0){Lb=0;break}else{tb=rb}}e:do{if((fb|0)==55){fb=0;if((tb|0)==0){Lb=0;break}Cb=c[Kb+8>>2]|0;Ab=c[Kb+4>>2]<<3;rb=Ab>>>0>2147483639>>>0|(Cb|0)==0;ub=rb?0:Cb;Cb=rb?0:Ab;c[wa>>2]=ub;c[xa>>2]=Cb;c[ya>>2]=Cb+8;c[za>>2]=ub+(Cb>>3);c[Aa>>2]=0;Cb=c[H>>2]|0;if((Cb|0)>1){Mb=29}else{Mb=(8<<Cb)-1|0}Cb=(d[1648368+((c[I>>2]|0)*30|0)+Mb|0]|0)+1|0;ub=c[J>>2]|0;if(Cb>>>0>1>>>0){Ab=1;rb=ub;while(1){if((rb|0)>0){gb=0;while(1){sb=hYa(q,c[846780]|0,c[846781]|0,0,2)|0;a[w+120672+(gb*80|0)+(Ab<<3)|0]=sb;vb=0;yb=sb;while(1){sb=c[846775]|0;xb=c[Aa>>2]|0;Bb=c[ya>>2]|0;Eb=c[wa>>2]|0;Db=Eb+(xb>>>3)|0;Hb=32-(c[846774]|0)|0;zb=(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)>>>((xb&7)>>>0)<<Hb>>>(Hb>>>0);Hb=b[sb+(zb<<2)>>1]|0;Db=(b[sb+(zb<<2)+2>>1]|0)+xb|0;xb=Bb>>>0>Db>>>0?Db:Bb;c[Aa>>2]=xb;if(Hb<<16>>16==0){Db=Eb+(xb>>>3)|0;zb=(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)>>>((xb&7)>>>0)&7;Db=xb+3|0;xb=Bb>>>0>Db>>>0?Db:Bb;Db=Eb+(xb>>>3)|0;Eb=zb^31;sb=(d[Db]|d[Db+1|0]<<8|d[Db+2|0]<<16|d[Db+3|0]<<24|0)>>>((xb&7)>>>0)<<Eb>>>(Eb>>>0);Eb=xb+1+zb|0;c[Aa>>2]=Bb>>>0>Eb>>>0?Eb:Bb;Nb=sb}else{Nb=(Hb<<16>>16)-1|0}Hb=Nb+1|0;sb=hYa(q,c[846812]|0,c[846813]|0,0,2)|0;if((sb&1|0)==0){Ob=-(sb>>1)|0}else{Ob=sb+1>>1}sb=Hb+vb|0;if((sb|0)>7){Lb=1;break e}if((Nb|0)>=0){Bb=1;do{a[Bb+vb+(w+120672+(gb*80|0)+(Ab<<3))|0]=((ca(Bb,Ob)|0)/(Hb|0)|0)+yb;Bb=Bb+1|0;}while((Bb|0)<=(Hb|0))}if((sb|0)<7){vb=sb;yb=Ob+yb|0}else{break}}yb=gb+1|0;vb=c[J>>2]|0;if((yb|0)<(vb|0)){gb=yb}else{Pb=vb;break}}}else{Pb=rb}gb=Ab+1|0;if((gb|0)<(Cb|0)){Ab=gb;rb=Pb}else{Qb=Pb;break}}}else{Qb=ub}if((Qb|0)>0){Rb=0}else{Lb=1;break}while(1){rb=w+120672+(Rb*80|0)|0;Ab=rb|0;y=0;a[Ab]=y;y=y>>8;a[Ab+1|0]=y;y=y>>8;a[Ab+2|0]=y;y=y>>8;a[Ab+3|0]=y;Ab=rb+4|0;y=0;a[Ab]=y;y=y>>8;a[Ab+1|0]=y;y=y>>8;a[Ab+2|0]=y;y=y>>8;a[Ab+3|0]=y;Ab=Rb+1|0;if((Ab|0)<(c[J>>2]|0)){Rb=Ab}else{Lb=1;break}}}}while(0);tb=da;while(1){Sb=c[tb>>2]|0;if((Sb|0)==0){Jb=Lb;fb=133;break d}if((c[Sb>>2]|0)==10){break}ub=c[tb+4>>2]|0;if((ub|0)==0){Jb=Lb;fb=133;break d}else{tb=ub}}if((tb|0)==0){Jb=Lb;fb=133;break}ub=c[Sb+8>>2]|0;Ab=c[Sb+4>>2]<<3;rb=Ab>>>0>2147483639>>>0|(ub|0)==0;Cb=rb?0:ub;ub=rb?0:Ab;c[ra>>2]=Cb;c[sa>>2]=ub;c[ta>>2]=ub+8;c[ua>>2]=Cb+(ub>>3);c[va>>2]=0;Cb=0;Ab=0;rb=ub;while(1){if((Cb|0)>=(c[J>>2]|0)){break}Tb=w+120672+(Cb*80|0)|0;f:do{if((rb-Ab|0)<16){Ub=Ab;Vb=rb}else{ub=hYa(o,c[846780]|0,c[846781]|0,0,2)|0;a[Tb|0]=ub;gb=0;vb=ub;while(1){ub=c[va>>2]|0;yb=c[sa>>2]|0;if((yb-ub|0)<16){Ub=ub;Vb=yb;break f}Hb=c[846775]|0;Bb=c[ta>>2]|0;Eb=c[ra>>2]|0;zb=Eb+(ub>>>3)|0;xb=32-(c[846774]|0)|0;Db=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((ub&7)>>>0)<<xb>>>(xb>>>0);xb=b[Hb+(Db<<2)>>1]|0;zb=(b[Hb+(Db<<2)+2>>1]|0)+ub|0;ub=Bb>>>0>zb>>>0?zb:Bb;c[va>>2]=ub;if(xb<<16>>16==0){zb=Eb+(ub>>>3)|0;Db=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((ub&7)>>>0)&7;zb=ub+3|0;Hb=Bb>>>0>zb>>>0?zb:Bb;zb=Eb+(Hb>>>3)|0;Eb=Db^31;Fb=(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)>>>((Hb&7)>>>0)<<Eb>>>(Eb>>>0);Eb=Hb+1+Db|0;Db=Bb>>>0>Eb>>>0?Eb:Bb;c[va>>2]=Db;Wb=Fb;Xb=Db}else{Wb=(xb<<16>>16)-1|0;Xb=ub}ub=Wb+1|0;xb=ub+gb|0;if((xb|0)>7){Ub=Xb;Vb=yb;break f}if((yb-Xb|0)<16){Ub=Xb;Vb=yb;break f}yb=hYa(o,c[846812]|0,c[846813]|0,0,2)|0;if((yb&1|0)==0){Yb=-(yb>>1)|0}else{Yb=yb+1>>1}if((Wb|0)>=0){yb=1;do{a[yb+gb+(w+120672+(Cb*80|0))|0]=((ca(yb,Yb)|0)/(ub|0)|0)+vb;yb=yb+1|0;}while((yb|0)<=(ub|0))}if((xb|0)<7){gb=xb;vb=Yb+vb|0}else{break}}Ub=c[va>>2]|0;Vb=c[sa>>2]|0}}while(0);if((Vb-Ub|0)<16){fb=97;break}Cb=Cb+1|0;Ab=Ub;rb=Vb}if((fb|0)==97){fb=0;rb=Tb;Ab=rb|0;y=0;a[Ab]=y;y=y>>8;a[Ab+1|0]=y;y=y>>8;a[Ab+2|0]=y;y=y>>8;a[Ab+3|0]=y;Ab=rb+4|0;y=0;a[Ab]=y;y=y>>8;a[Ab+1|0]=y;y=y>>8;a[Ab+2|0]=y;y=y>>8;a[Ab+3|0]=y}Ab=c[H>>2]|0;rb=Ab+1|0;if((rb|0)>0){Cb=0;tb=c[J>>2]|0;while(1){if((tb|0)>0){vb=0;while(1){gb=0;do{ub=c[va>>2]|0;yb=c[sa>>2]|0;if((yb-ub|0)<1){break}Db=d[(c[ra>>2]|0)+(ub>>>3)|0]|0;Fb=((ub|0)<(c[ta>>2]|0))+ub|0;c[va>>2]=Fb;g:do{if((Db&1<<(ub&7)|0)==0){Bb=w+121312+(vb*192|0)+(Cb<<6)+(gb<<3)|0;Eb=Bb|0;y=0;a[Eb]=y;y=y>>8;a[Eb+1|0]=y;y=y>>8;a[Eb+2|0]=y;y=y>>8;a[Eb+3|0]=y;Eb=Bb+4|0;y=0;a[Eb]=y;y=y>>8;a[Eb+1|0]=y;y=y>>8;a[Eb+2|0]=y;y=y>>8;a[Eb+3|0]=y}else{if((yb-Fb|0)<16){break}else{Zb=0}do{a[w+121312+(vb*192|0)+(Cb<<6)+(gb<<3)+Zb|0]=hYa(o,c[846768]|0,c[846769]|0,0,2)|0;Zb=Zb+1|0;if((Zb|0)>=8){break g}}while(((c[sa>>2]|0)-(c[va>>2]|0)|0)>=16)}}while(0);gb=gb+1|0;}while((gb|0)<8);gb=vb+1|0;Fb=c[J>>2]|0;if((gb|0)<(Fb|0)){vb=gb}else{_b=Fb;break}}}else{_b=tb}vb=Cb+1|0;if((vb|0)<(rb|0)){Cb=vb;tb=_b}else{break}}$b=c[H>>2]|0}else{$b=Ab}if(($b|0)>1){ac=26;fb=114}else{tb=(8<<$b)-4|0;if((tb|0)>0){ac=tb;fb=114}else{bc=$b}}if((fb|0)==114){fb=0;tb=0;Cb=c[J>>2]|0;while(1){h:do{if((Cb|0)>0){if((tb|0)>19){rb=0;vb=Cb;while(1){if(((c[sa>>2]|0)-(c[va>>2]|0)|0)<16){cc=vb;break h}a[w+122112+(rb*26|0)+tb|0]=((hYa(o,c[846762]|0,c[846763]|0,0,2)|0)&255)-16;Fb=rb+1|0;gb=c[J>>2]|0;if((Fb|0)<(gb|0)){rb=Fb;vb=gb}else{cc=gb;break}}}else{vb=0;rb=Cb;while(1){if(((c[sa>>2]|0)-(c[va>>2]|0)|0)<16){cc=rb;break h}a[w+122112+(vb*26|0)+tb|0]=hYa(o,c[846762]|0,c[846763]|0,0,2)|0;gb=w+121696+(vb*208|0)+(tb<<3)|0;Fb=gb|0;y=-252645136;a[Fb]=y;y=y>>8;a[Fb+1|0]=y;y=y>>8;a[Fb+2|0]=y;y=y>>8;a[Fb+3|0]=y;Fb=gb+4|0;y=-252645136;a[Fb]=y;y=y>>8;a[Fb+1|0]=y;y=y>>8;a[Fb+2|0]=y;y=y>>8;a[Fb+3|0]=y;Fb=vb+1|0;gb=c[J>>2]|0;if((Fb|0)<(gb|0)){vb=Fb;rb=gb}else{cc=gb;break}}}}else{cc=Cb}}while(0);rb=tb+1|0;if((rb|0)<(ac|0)){tb=rb;Cb=cc}else{break}}bc=c[H>>2]|0}if((bc|0)>1){dc=25;fb=125}else{Cb=(8<<bc)-5|0;if((Cb|0)>0){dc=Cb;fb=125}}if((fb|0)==125){fb=0;Cb=0;tb=c[J>>2]|0;while(1){if((tb|0)>0){Ab=0;while(1){rb=0;do{if(((c[sa>>2]|0)-(c[va>>2]|0)|0)<16){break}a[w+121696+(Ab*208|0)+(Cb<<3)+rb|0]=(hYa(o,c[846756]|0,c[846757]|0,0,2)|0)+224;rb=rb+1|0;}while((rb|0)<8);rb=Ab+1|0;vb=c[J>>2]|0;if((rb|0)<(vb|0)){Ab=rb}else{ec=vb;break}}}else{ec=tb}Ab=Cb+1|0;if((Ab|0)<(dc|0)){Cb=Ab;tb=ec}else{break}}}kYa(w,1);fc=0;gc=Lb}}while(0);if((fb|0)==133){fb=0;kYa(w,0);fc=1;gc=Jb}i:do{if(ga){fb=138}else{tb=da;while(1){hc=c[tb>>2]|0;if((hc|0)==0){fb=138;break i}if((c[hc>>2]|0)==11){break}Cb=c[tb+4>>2]|0;if((Cb|0)==0){fb=138;break i}else{tb=Cb}}Cb=fc|gc^1;if(Cb|(tb|0)==0){ic=Cb;fb=149;break}Cb=c[hc+4>>2]<<3;Ab=c[hc+8>>2]|0;vb=Cb>>>0>2147483639>>>0|(Ab|0)==0;rb=vb?0:Ab;Ab=vb?0:Cb;c[la>>2]=rb;c[ma>>2]=Ab;vb=Ab+8|0;c[na>>2]=vb;c[oa>>2]=rb+(Ab>>3);c[pa>>2]=0;do{if((Cb|0)>31){Ab=rb;gb=(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24)&8188;c[pa>>2]=vb>>>0>13>>>0?13:vb;if(!(gb>>>0>3>>>0)){break}gb=c[J>>2]|0;Ab=c[qa>>2]|0;if((c[Q>>2]|0)==0){QIb(0,2488560,(ib=i,i=i+1|0,i=i+7&-8,c[ib>>2]=0,ib)|0);i=ib;break}if((gb|0)>0){jc=0}else{break}do{Fb=0;do{mrc(w+116832+(jc*1920|0)+(Fb<<6)|0,a[1677568+(Ab*30|0)+Fb|0]|0,64)|0;Fb=Fb+1|0;}while((Fb|0)<30);jc=jc+1|0;}while((jc|0)<(gb|0))}}while(0);jYa(w,p,Cb,0,8);kc=0}}while(0);if((fb|0)==138){fb=0;ic=fc|gc^1;fb=149}if((fb|0)==149){fb=0;vb=0;while(1){rb=c[fa>>2]|0;if((rb|0)>3839){c[fa>>2]=rb-3840}if((c[J>>2]|0)>0){lc=+g[611872+(vb<<2)>>2];rb=0;do{tb=0;do{gb=c[fa>>2]|0;c[fa>>2]=gb+1;Ab=w+101472+(rb*7680|0)+(vb<<8)+(tb<<2)|0;Fb=tb<<1;g[w+59488+(rb<<14)+(Fb<<7)+(vb<<2)>>2]=lc*+g[5467640+(gb<<2)>>2]*+g[Ab>>2];gb=c[fa>>2]|0;c[fa>>2]=gb+1;g[w+59488+(rb<<14)+((Fb|1)<<7)+(vb<<2)>>2]=lc*+g[5467640+(gb<<2)>>2]*+g[Ab>>2];tb=tb+1|0;}while((tb|0)<64);rb=rb+1|0;}while((rb|0)<(c[J>>2]|0))}rb=vb+1|0;if((rb|0)<8){vb=rb}else{kc=ic;break}}}j:do{if(ga){fb=164}else{vb=da;while(1){mc=c[vb>>2]|0;if((mc|0)==0){fb=164;break j}if((c[mc>>2]|0)==12){break}rb=c[vb+4>>2]|0;if((rb|0)==0){fb=164;break j}else{vb=rb}}if(kc|(vb|0)==0){fb=164;break}rb=c[mc+4>>2]<<3;Cb=c[mc+8>>2]|0;tb=rb>>>0>2147483639>>>0|(Cb|0)==0;Ab=tb?0:Cb;Cb=tb?0:rb;c[W>>2]=Ab;c[ha>>2]=Cb;c[ia>>2]=Cb+8;c[ja>>2]=Ab+(Cb>>3);c[ka>>2]=0;Cb=c[H>>2]|0;jYa(w,r,rb,8,(Cb|0)>1?30:8<<Cb)}}while(0);do{if((fb|0)==164){fb=0;Cb=c[H>>2]|0;rb=(Cb|0)>1?30:8<<Cb;if((rb|0)>8){nc=8}else{break}do{Cb=c[fa>>2]|0;if((Cb|0)>3839){c[fa>>2]=Cb-3840}if((c[J>>2]|0)>0){lc=+g[611872+(nc<<2)>>2];Cb=0;do{Ab=0;do{tb=c[fa>>2]|0;c[fa>>2]=tb+1;gb=w+101472+(Cb*7680|0)+(nc<<8)+(Ab<<2)|0;Fb=Ab<<1;g[w+59488+(Cb<<14)+(Fb<<7)+(nc<<2)>>2]=lc*+g[5467640+(tb<<2)>>2]*+g[gb>>2];tb=c[fa>>2]|0;c[fa>>2]=tb+1;g[w+59488+(Cb<<14)+((Fb|1)<<7)+(nc<<2)>>2]=lc*+g[5467640+(tb<<2)>>2]*+g[gb>>2];Ab=Ab+1|0;}while((Ab|0)<64);Cb=Cb+1|0;}while((Cb|0)<(c[J>>2]|0))}nc=nc+1|0;}while((nc|0)<(rb|0))}}while(0);c[ea>>2]=1;break b}}}while(0);if((c[ea>>2]|0)==0){break}kYa(w,0);kb=0;do{nb=c[fa>>2]|0;if((nb|0)>3839){c[fa>>2]=nb-3840}nb=c[J>>2]|0;if((nb|0)>0){lc=+g[611872+(kb<<2)>>2];mb=0;while(1){hb=0;do{qb=c[fa>>2]|0;c[fa>>2]=qb+1;lb=w+101472+(mb*7680|0)+(kb<<8)+(hb<<2)|0;rb=hb<<1;g[w+59488+(mb<<14)+(rb<<7)+(kb<<2)>>2]=lc*+g[5467640+(qb<<2)>>2]*+g[lb>>2];qb=c[fa>>2]|0;c[fa>>2]=qb+1;g[w+59488+(mb<<14)+((rb|1)<<7)+(kb<<2)>>2]=lc*+g[5467640+(qb<<2)>>2]*+g[lb>>2];hb=hb+1|0;}while((hb|0)<64);hb=mb+1|0;lb=c[J>>2]|0;if((hb|0)<(lb|0)){mb=hb}else{oc=lb;break}}}else{oc=nb}kb=kb+1|0;}while((kb|0)<8);kb=c[H>>2]|0;mb=(kb|0)>1?30:8<<kb;if((mb|0)>8){pc=8;qc=oc}else{break}while(1){kb=c[fa>>2]|0;if((kb|0)>3839){c[fa>>2]=kb-3840}if((qc|0)>0){lc=+g[611872+(pc<<2)>>2];kb=0;while(1){lb=0;do{hb=c[fa>>2]|0;c[fa>>2]=hb+1;qb=w+101472+(kb*7680|0)+(pc<<8)+(lb<<2)|0;rb=lb<<1;g[w+59488+(kb<<14)+(rb<<7)+(pc<<2)>>2]=lc*+g[5467640+(hb<<2)>>2]*+g[qb>>2];hb=c[fa>>2]|0;c[fa>>2]=hb+1;g[w+59488+(kb<<14)+((rb|1)<<7)+(pc<<2)>>2]=lc*+g[5467640+(hb<<2)>>2]*+g[qb>>2];lb=lb+1|0;}while((lb|0)<64);lb=kb+1|0;qb=c[J>>2]|0;if((lb|0)<(qb|0)){kb=lb}else{rc=qb;break}}}else{rc=qc}kb=pc+1|0;if((kb|0)<(mb|0)){pc=kb;qc=rc}else{break}}}}while(0);if((c[E>>2]|0)==0){k:do{if((c[D>>2]|0)==2){if((c[T>>2]|0)==0){break}c[Ba>>2]=0;mrc(Ca|0,-1|0,20)|0;mb=c[G>>2]|0;do{if((mb|0)>0){kb=256;nb=0;qb=mb;while(1){if((qb|0)>0){sc=0;tc=0;uc=0}else{break k}do{lb=c[w+368+(tc<<3)>>2]|0;hb=c[lb>>2]|0;rb=(hb|0)>(sc|0)&(hb|0)<(kb|0);sc=rb?hb:sc;uc=rb?lb:uc;tc=tc+1|0;}while((tc|0)<(qb|0));if((uc|0)==0){break k}lb=uc|0;if((nb|0)==0){rb=(c[lb>>2]|0)-16|0;if(rb>>>0>31>>>0){break k}if((1056997120>>>(rb>>>0)&1|0)!=0){break k}}rb=c[uc+8>>2]|0;hb=c[uc+4>>2]<<3;vb=hb>>>0>2147483639>>>0|(rb|0)==0;Cb=vb?0:rb;rb=vb?0:hb;c[Ea>>2]=Cb;c[Fa>>2]=rb;hb=rb+8|0;c[Ga>>2]=hb;c[Ha>>2]=Cb+(rb>>3);c[Ia>>2]=0;rb=c[lb>>2]|0;if((rb-32|0)>>>0<16>>>0){if((1056997120>>>((rb-16|0)>>>0)&1|0)==0){vc=1}else{fb=205}}else{fb=205}if((fb|0)==205){fb=0;vc=0}do{if((rb-17|0)>>>0<7>>>0|(rb-33|0)>>>0<7>>>0){lb=(c[H>>2]|0)+(5-(rb&15))|0;if(!(lb>>>0<4>>>0)){break}gYa(w,lb,n,vc)}else{if((rb|0)==31){gYa(w,0,n,vc);gYa(w,1,n,vc);gYa(w,2,n,vc);gYa(w,3,n,vc);break}else if((rb|0)==46){lb=Cb;vb=(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24)&63;lb=hb>>>0>6>>>0?6:hb;c[Ia>>2]=lb;c[Y>>2]=vb;vb=Cb+(lb>>>3)|0;Ab=(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((lb&6)>>>0)&63;vb=lb+6|0;lb=hb>>>0>vb>>>0?vb:hb;c[Ia>>2]=lb;c[Z>>2]=Ab;Ab=Cb+(lb>>>3)|0;vb=(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)>>>((lb&7)>>>0)&63;Ab=lb+6|0;lb=hb>>>0>Ab>>>0?Ab:hb;c[Ia>>2]=lb;c[_>>2]=vb;vb=Cb+(lb>>>3)|0;Ab=(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((lb&7)>>>0)&63;vb=lb+6|0;lb=hb>>>0>vb>>>0?vb:hb;c[Ia>>2]=lb;c[$>>2]=Ab;Ab=Cb+(lb>>>3)|0;vb=(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)>>>((lb&7)>>>0)&63;Ab=lb+6|0;lb=hb>>>0>Ab>>>0?Ab:hb;c[Ia>>2]=lb;c[aa>>2]=vb;vb=Cb+(lb>>>3)|0;Ab=(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)>>>((lb&7)>>>0)&63;vb=lb+6|0;c[Ia>>2]=hb>>>0>vb>>>0?vb:hb;c[ba>>2]=Ab;gYa(w,0,n,vc);gYa(w,1,n,vc);gYa(w,2,n,vc);gYa(w,3,n,vc);break}else{break}}}while(0);hb=nb+1|0;Cb=c[G>>2]|0;if((hb|0)<(Cb|0)){kb=sc;nb=hb;qb=Cb}else{break}}qb=c[Da>>2]>>31;nb=c[Ja>>2]|0;if(!((nb|0)>-1)){wc=qb;break}if(!((qb|0)>-1)){wc=1;break}c[w+38788+(qb<<2)>>2]=nb;wc=1}else{wc=-1}}while(0);mb=c[Ka>>2]|0;do{if((mb|0)>-1){if(!((wc|0)>-1)){xc=2;break}c[w+38788+(wc<<2)>>2]=mb;xc=2}else{xc=wc}}while(0);mb=c[La>>2]|0;do{if((mb|0)>-1){if(!((xc|0)>-1)){yc=3;break}c[w+38788+(xc<<2)>>2]=mb;yc=3}else{yc=xc}}while(0);mb=c[Ma>>2]|0;nb=(yc|0)>-1;do{if((mb|0)>-1){if(!nb){zc=4;break}c[w+38788+(yc<<2)>>2]=mb;zc=4}else{if(nb){zc=yc}else{break k}}}while(0);c[w+38788+(zc<<2)>>2]=c[Ba>>2]}}while(0);nb=c[D>>2]|0;if((c[A>>2]|0)>0){mb=0;do{mrc(w+38944+(mb<<11)|0,0,c[Na>>2]<<3|0)|0;mb=mb+1|0;}while((mb|0)<(c[A>>2]|0))}mb=c[Ma>>2]|0;l:do{if((mb|0)>-1){if((mb|0)<(c[Oa>>2]|0)){Ac=mb}else{break}do{if((b[w+28764+(Ac*10|0)>>1]|0)!=(nb|0)){break l}if((c[A>>2]|0)==1){Bc=0}else{Bc=d[w+28764+(Ac*10|0)+2|0]|0}qb=b[w+28764+(Ac*10|0)+6>>1]|0;if(qb<<16>>16<0){Cc=0.0}else{Cc=+g[1239400+(((c[Q>>2]|0)==0)<<8)+((qb&63)<<2)>>2]}lc=+(d[w+28764+(Ac*10|0)+8|0]|0)*.7853981633974483;Dc=Cc*+U(lc);Ec=Cc*+V(lc);qb=w+28764+(Ac*10|0)+4|0;kb=w+38944+(Bc<<11)+(b[qb>>1]<<3)|0;g[kb>>2]=Dc+ +g[kb>>2];kb=w+38944+(Bc<<11)+(b[qb>>1]<<3)+4|0;g[kb>>2]=Ec+ +g[kb>>2];kb=w+38944+(Bc<<11)+((b[qb>>1]|0)+1<<3)|0;g[kb>>2]=+g[kb>>2]-Dc;kb=w+38944+(Bc<<11)+((b[qb>>1]|0)+1<<3)+4|0;g[kb>>2]=+g[kb>>2]-Ec;Ac=Ac+1|0;}while((Ac|0)<(c[Oa>>2]|0))}}while(0);mb=c[Pa>>2]|0;kb=c[Qa>>2]|0;if((mb|0)==(kb|0)){Fc=0}else{qb=kb;while(1){fYa(w,w+756+(qb*28|0)|0);kb=((c[Qa>>2]|0)+1|0)%1e3|0;c[Qa>>2]=kb;if((mb|0)==(kb|0)){Fc=0;break}else{qb=kb}}}do{qb=w+38768+(Fc<<2)|0;mb=c[qb>>2]|0;if((mb|0)>-1){kb=w+38788+(Fc<<2)|0;Cb=c[kb>>2]|0;m:do{if((mb|0)<(Cb|0)){hb=4-Fc|0;rb=7-hb|0;Ab=mb;vb=Cb;while(1){if((b[w+28764+(Ab*10|0)>>1]|0)!=(nb|0)){Gc=Ab;break m}lb=b[w+28764+(Ab*10|0)+4>>1]|0;gb=lb>>hb;if((c[A>>2]|0)==1){Hc=0}else{Hc=d[w+28764+(Ab*10|0)+2|0]|0}if((gb|0)<(c[Ra>>2]|0)){if((gb|0)<2){Ic=gb&65535}else{Ic=(gb|0)>59?3:2}b[Sa>>1]=Ic;tb=b[w+28764+(Ab*10|0)+6>>1]|0;if(tb<<16>>16<0){Jc=0.0}else{Jc=+g[1239400+(((c[Q>>2]|0)==0)<<8)+((tb&63)<<2)>>2]}g[Ta>>2]=Jc;c[Ua>>2]=w+38944+(Hc<<11)+(gb<<3);c[Va>>2]=1238120+(Fc*320|0)+((lb-(gb<<hb)|0)*20|0);c[Wa>>2]=-128-(gb<<8)+(d[w+28764+(Ab*10|0)+8|0]<<6);c[Xa>>2]=(lb<<1|1)<<rb;c[Ya>>2]=Fc;b[Za>>1]=0;fYa(w,m);Kc=c[kb>>2]|0}else{Kc=vb}lb=Ab+1|0;if((lb|0)<(Kc|0)){Ab=lb;vb=Kc}else{Gc=lb;break}}}else{Gc=mb}}while(0);c[qb>>2]=Gc}Fc=Fc+1|0;}while((Fc|0)<4)}nb=c[A>>2]|0;if((nb|0)>0){mb=0;kb=nb;while(1){if((kb|0)==1){Lc=(c[J>>2]|0)==2?.5:1.0}else{Lc=1.0}Cb=w+38944+(mb<<11)|0;g[Cb>>2]=+g[Cb>>2]*2.0;g[w+38944+(mb<<11)+4>>2]=0.0;re[c[$a>>2]&1023](_a,Cb);Cb=(c[Na>>2]|0)+7&-8;if((Cb|0)>0){vb=c[A>>2]|0;Ab=vb<<1;rb=w+43048+(mb<<2)|0;hb=0;while(1){g[rb>>2]=+g[rb>>2]+Lc*+g[w+38944+(mb<<11)+(hb<<3)>>2];lb=rb+(vb<<2)|0;g[lb>>2]=Lc*+g[w+38944+(mb<<11)+(hb<<3)+4>>2]+ +g[lb>>2];lb=hb+1|0;if((lb|0)<(Cb|0)){rb=rb+(Ab<<2)|0;hb=lb}else{break}}}hb=c[E>>2]|0;if((hb|0)==0){if((c[ab>>2]|0)!=0){fb=264;break a}}Ab=mb+1|0;rb=c[A>>2]|0;if((Ab|0)<(rb|0)){mb=Ab;kb=rb}else{Mc=rb;Nc=hb;break}}}else{Mc=nb;Nc=c[E>>2]|0}do{if((Nc|0)==0){if((c[ea>>2]|0)==0){break}kb=c[D>>2]|0;c[l>>2]=0;mb=c[H>>2]|0;hb=(mb|0)>1?30:8<<mb;if((Mc|0)>0&(hb|0)<32){mb=kb<<3;rb=128-(hb<<2)|0;Ab=mb|1;Cb=mb|2;vb=mb|3;qb=mb|4;lb=mb|5;gb=mb|6;tb=mb|7;Fb=0;while(1){mrc(w+59488+(Fb<<14)+(mb<<7)+(hb<<2)|0,0,rb|0)|0;mrc(w+59488+(Fb<<14)+(Ab<<7)+(hb<<2)|0,0,rb|0)|0;mrc(w+59488+(Fb<<14)+(Cb<<7)+(hb<<2)|0,0,rb|0)|0;mrc(w+59488+(Fb<<14)+(vb<<7)+(hb<<2)|0,0,rb|0)|0;mrc(w+59488+(Fb<<14)+(qb<<7)+(hb<<2)|0,0,rb|0)|0;mrc(w+59488+(Fb<<14)+(lb<<7)+(hb<<2)|0,0,rb|0)|0;mrc(w+59488+(Fb<<14)+(gb<<7)+(hb<<2)|0,0,rb|0)|0;mrc(w+59488+(Fb<<14)+(tb<<7)+(hb<<2)|0,0,rb|0)|0;yb=c[A>>2]|0;ub=Fb+1|0;if((ub|0)<(yb|0)){Fb=ub}else{Oc=yb;break}}}else{Oc=Mc}Fb=c[J>>2]|0;if((Fb|0)>0){rb=kb<<3;hb=rb|1;tb=rb|2;gb=rb|3;lb=rb|4;qb=rb|5;vb=rb|6;Cb=rb|7;Ab=0;mb=Fb;do{Fb=w+51264+(Ab<<12)|0;yb=w+59456+(Ab<<2)|0;WSa(bb,Fb,yb,7687744,l,w+92256+(Ab<<2)|0,mb,w+59488+(Ab<<14)+(rb<<7)|0);ub=c[J>>2]|0;Db=(ub<<5)+Ab|0;WSa(bb,Fb,yb,7687744,l,w+92256+(Db<<2)|0,ub,w+59488+(Ab<<14)+(hb<<7)|0);ub=c[J>>2]|0;xb=(ub<<5)+Db|0;WSa(bb,Fb,yb,7687744,l,w+92256+(xb<<2)|0,ub,w+59488+(Ab<<14)+(tb<<7)|0);ub=c[J>>2]|0;Db=(ub<<5)+xb|0;WSa(bb,Fb,yb,7687744,l,w+92256+(Db<<2)|0,ub,w+59488+(Ab<<14)+(gb<<7)|0);ub=c[J>>2]|0;xb=(ub<<5)+Db|0;WSa(bb,Fb,yb,7687744,l,w+92256+(xb<<2)|0,ub,w+59488+(Ab<<14)+(lb<<7)|0);ub=c[J>>2]|0;Db=(ub<<5)+xb|0;WSa(bb,Fb,yb,7687744,l,w+92256+(Db<<2)|0,ub,w+59488+(Ab<<14)+(qb<<7)|0);ub=c[J>>2]|0;xb=(ub<<5)+Db|0;WSa(bb,Fb,yb,7687744,l,w+92256+(xb<<2)|0,ub,w+59488+(Ab<<14)+(vb<<7)|0);ub=c[J>>2]|0;WSa(bb,Fb,yb,7687744,l,w+92256+((ub<<5)+xb<<2)|0,ub,w+59488+(Ab<<14)+(Cb<<7)|0);mb=c[J>>2]|0;Ab=Ab+1|0;}while((Ab|0)<(mb|0));Pc=c[A>>2]|0}else{Pc=Oc}mb=4>>>((c[H>>2]|0)>>>0);if((Pc|0)<=0){break}Ab=0;Cb=c[j>>2]|0;vb=Pc;while(1){if((Cb|0)>0){qb=0;lb=vb;while(1){Ec=+g[w+92256+((ca(ca(qb,mb)|0,c[J>>2]|0)|0)+Ab<<2)>>2]*8388608.0;gb=w+43048+((ca(qb,lb)|0)+Ab<<2)|0;g[gb>>2]=Ec+ +g[gb>>2];gb=qb+1|0;tb=c[j>>2]|0;hb=c[A>>2]|0;if((gb|0)<(tb|0)){qb=gb;lb=hb}else{Qc=tb;Rc=hb;break}}}else{Qc=Cb;Rc=vb}lb=Ab+1|0;if((lb|0)<(Rc|0)){Ab=lb;Cb=Qc;vb=Rc}else{break}}}}while(0);c[D>>2]=((c[D>>2]|0)+1|0)%16|0;if((eb|0)>0){nb=0;do{vb=~~+g[w+43048+(nb<<2)>>2];do{if((vb|0)>27600){if((vb|0)>35716){Sc=32767;break}Sc=b[5095944+(vb-27600<<1)>>1]|0}else{if(!((vb|0)<-27600)){Sc=vb&65535;break}if((vb|0)<-35716){Sc=-32767;break}Sc=-(b[5095944+(-27600-vb<<1)>>1]|0)&65535}}while(0);b[v+(nb<<1)>>1]=Sc;nb=nb+1|0;}while((nb|0)<(eb|0))}eb=c[A>>2]|0;nb=c[j>>2]|0;vb=v+((ca(nb,eb)|0)<<1)|0;Cb=f+1|0;if((Cb|0)<16){v=vb;f=Cb;cb=nb;db=eb}else{fb=289;break}}if((fb|0)==264){KIb(0,32,2358552,(ib=i,i=i+8|0,c[ib>>2]=2294984,ib)|0);i=ib;x=-1;i=k;return x|0}else if((fb|0)==289){c[h>>2]=1;x=c[z>>2]|0;i=k;return x|0}else if((fb|0)==290){i=k;return x|0}return 0}function eYa(a){a=a|0;pZa((c[a+60>>2]|0)+38832|0);return 0}function fYa(a,d){a=a|0;d=d|0;var e=0,f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0,x=0,y=0,z=0.0;e=d+12|0;f=(c[e>>2]|0)+(c[d+16>>2]|0)|0;c[e>>2]=f;e=d+24|0;h=b[e>>1]|0;i=c[d+20>>2]|0;j=+g[1239912+(i*124|0)+(h<<16>>16<<2)>>2]*+g[d>>2];k=+(f|0)*.01227184630308513;l=+V(k)*j;m=j*+U(k);do{if((i|0)>2){n=3}else{f=b[d+26>>1]|0;if(f<<16>>16>2){n=3;break}o=c[d+8>>2]|0;k=+g[o+16>>2];j=-0.0-k;p=+g[o+12>>2];q=+g[o>>2];r=p-q;s=+g[o+8>>2];t=1.0-s-p;p=+g[o+4>>2];u=p+k+-1.0;v=q-p;o=f<<16>>16;w=c[d+4>>2]|0;x=c[1241248+(o<<3)>>2]|0;y=w+(x<<3)|0;g[y>>2]=m*r+ +g[y>>2];if(f<<16>>16>0){z=r}else{z=-0.0-r}y=w+(x<<3)+4|0;g[y>>2]=l*z+ +g[y>>2];y=c[1241252+(o<<3)>>2]|0;o=w+(y<<3)|0;g[o>>2]=m*j+ +g[o>>2];o=w+(y<<3)+4|0;g[o>>2]=l*(f<<16>>16>1?j:k)+ +g[o>>2];o=w|0;g[o>>2]=m*t+ +g[o>>2];o=w+4|0;g[o>>2]=l*t+ +g[o>>2];o=w+8|0;g[o>>2]=m*u+ +g[o>>2];o=w+12|0;g[o>>2]=l*u+ +g[o>>2];o=w+16|0;g[o>>2]=m*v+ +g[o>>2];o=w+20|0;g[o>>2]=l*v+ +g[o>>2];o=w+24|0;g[o>>2]=m*s+ +g[o>>2];o=w+28|0;g[o>>2]=l*s+ +g[o>>2]}}while(0);if((n|0)==3){n=c[d+4>>2]|0;o=n+4|0;g[o>>2]=l+ +g[o>>2];o=n|0;g[o>>2]=m+ +g[o>>2];o=n+12|0;g[o>>2]=+g[o>>2]-l;o=n+8|0;g[o>>2]=+g[o>>2]-m}o=h+1&65535;b[e>>1]=o;if((o<<16>>16|0)>=((1<<5-i)-1|0)){return}i=a+28760|0;o=a+756+((c[i>>2]|0)*28|0)|0;a=d;c[o>>2]=c[a>>2];c[o+4>>2]=c[a+4>>2];c[o+8>>2]=c[a+8>>2];c[o+12>>2]=c[a+12>>2];c[o+16>>2]=c[a+16>>2];c[o+20>>2]=c[a+20>>2];c[o+24>>2]=c[a+24>>2];c[i>>2]=((c[i>>2]|0)+1|0)%1e3|0;return}function gYa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;j=i;k=4-f|0;l=1<<(c[e+20>>2]|0)+~f;m=g+8|0;n=g+12|0;if(((c[n>>2]|0)-(c[m>>2]|0)|0)<=0){i=j;return}o=e+129848|0;p=3387144+(k*20|0)|0;q=3387148+(k*20|0)|0;r=l-1|0;s=2-l|0;t=1<<k;u=e+8|0;v=e|0;w=g|0;x=g+16|0;y=(h|0)!=0?6074688:6074712;h=y|0;z=y+4|0;y=e+32|0;A=e+38768+(f<<2)|0;f=e+38764|0;B=l<<3;C=0;D=0;E=1;a:while(1){F=(c[o>>2]|0)==0;G=hYa(g,c[p>>2]|0,c[q>>2]|0,1,2)|0;do{if(F){H=G+E|0;if((H|0)<(r|0)){I=H;J=D;K=C;break}else{L=C;M=D;N=H}while(1){H=s+N|0;O=L+l|0;P=M+t|0;if((H|0)<(r|0)){I=H;J=P;K=O;break}else{L=O;M=P;N=H}}}else{if((G|0)<2){Q=C;H=D;P=G;while(1){if(((c[n>>2]|0)-(c[m>>2]|0)|0)<0){R=6;break a}O=(P|0)==0;S=H+((O?1:8)<<k)|0;T=Q+(O?l:B)|0;O=hYa(g,c[p>>2]|0,c[q>>2]|0,1,2)|0;if((O|0)<2){Q=T;H=S;P=O}else{U=T;V=S;W=1;X=O;break}}}else{U=C;V=D;W=E;X=G}I=W-2+X|0;J=V;K=U}}while(0);if((K|0)>=(c[u>>2]|0)){R=30;break}G=I>>k;if(G>>>0>255>>>0){R=30;break}if((c[v>>2]|0)>1){F=c[m>>2]|0;P=c[w>>2]|0;H=(d[P+(F>>>3)|0]|0)>>>((F&7)>>>0);O=c[x>>2]|0;S=((F|0)<(O|0))+F|0;c[m>>2]=S;F=d[P+(S>>>3)|0]|0;c[m>>2]=((S|0)<(O|0))+S;Y=H&1;Z=(1<<(S&7)&F|0)!=0}else{Y=0;Z=0}F=hYa(g,c[h>>2]|0,c[z>>2]|0,0,2)|0;S=(c[e+38808+(b[1240456+(G<<1)>>1]<<2)>>2]|0)+F|0;F=(S|0)<0?0:S;S=c[m>>2]|0;H=c[x>>2]|0;O=c[w>>2]|0;P=O+(S>>>3)|0;T=(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)>>>((S&7)>>>0)&7;P=S+3|0;S=H>>>0>P>>>0?P:H;c[m>>2]=S;if(Z){P=c[1518667]|0;_=O+(S>>>3)|0;$=32-(c[1518666]|0)|0;aa=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((S&7)>>>0)<<$>>>($>>>0);$=b[P+(aa<<2)>>1]|0;_=(b[P+(aa<<2)+2>>1]|0)+S|0;S=H>>>0>_>>>0?_:H;c[m>>2]=S;if($<<16>>16==0){_=O+(S>>>3)|0;aa=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((S&7)>>>0)&7;_=S+3|0;P=H>>>0>_>>>0?_:H;c[m>>2]=P;_=O+(P>>>3)|0;ba=aa^31;ca=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((P&7)>>>0)<<ba>>>(ba>>>0);ba=P+1+aa|0;aa=H>>>0>ba>>>0?ba:H;c[m>>2]=aa;da=ca;ea=aa}else{da=($<<16>>16)-1|0;ea=S}S=c[1518661]|0;$=O+(ea>>>3)|0;aa=32-(c[1518660]|0)|0;ca=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((ea&7)>>>0)<<aa>>>(aa>>>0);aa=b[S+(ca<<2)>>1]|0;$=(b[S+(ca<<2)+2>>1]|0)+ea|0;ca=H>>>0>$>>>0?$:H;c[m>>2]=ca;if(aa<<16>>16==0){$=O+(ca>>>3)|0;S=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((ca&7)>>>0)&7;$=ca+3|0;ca=H>>>0>$>>>0?$:H;c[m>>2]=ca;$=O+(ca>>>3)|0;O=S^31;ba=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)>>>((ca&7)>>>0)<<O>>>(O>>>0);O=ca+1+S|0;c[m>>2]=H>>>0>O>>>0?O:H;fa=ba}else{fa=(aa<<16>>16)-1|0}aa=T-fa|0;ga=F-da&65535;ha=((aa|0)<0?aa+8|0:aa)&255}else{ga=0;ha=0}do{if((c[y>>2]|0)>(G+1|0)){aa=J+2|0;if((c[A>>2]|0)<0){c[A>>2]=c[f>>2]}ba=((aa|0)>15?J+65522|0:aa)&65535;b[e+28764+((c[f>>2]|0)*10|0)>>1]=ba;a[e+28764+((c[f>>2]|0)*10|0)+2|0]=Y;aa=I&65535;b[e+28764+((c[f>>2]|0)*10|0)+4>>1]=aa;b[e+28764+((c[f>>2]|0)*10|0)+6>>1]=F;a[e+28764+((c[f>>2]|0)*10|0)+8|0]=T;H=(c[f>>2]|0)+1|0;c[f>>2]=H;if(!Z){break}if((c[A>>2]|0)<0){c[A>>2]=H;ia=c[f>>2]|0}else{ia=H}b[e+28764+(ia*10|0)>>1]=ba;a[e+28764+((c[f>>2]|0)*10|0)+2|0]=Y^1;b[e+28764+((c[f>>2]|0)*10|0)+4>>1]=aa;b[e+28764+((c[f>>2]|0)*10|0)+6>>1]=ga;a[e+28764+((c[f>>2]|0)*10|0)+8|0]=ha;c[f>>2]=(c[f>>2]|0)+1}}while(0);if(((c[n>>2]|0)-(c[m>>2]|0)|0)>0){C=K;D=J;E=I+1|0}else{R=30;break}}if((R|0)==6){if((Q|0)>=(c[u>>2]|0)){i=j;return}KIb(0,16,2244016,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;i=j;return}else if((R|0)==30){i=j;return}}function hYa(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;k=a+8|0;l=c[k>>2]|0;m=c[a+16>>2]|0;n=c[a>>2]|0;a=n+(l>>>3)|0;o=32-e|0;p=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>((l&7)>>>0)<<o>>>(o>>>0);o=b[f+(p<<2)>>1]|0;a=b[f+(p<<2)+2>>1]|0;p=a<<16>>16;do{if((h|0)>1&a<<16>>16<0){q=l+e|0;r=m>>>0>q>>>0?q:m;q=n+(r>>>3)|0;s=p+32|0;t=((d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((r&7)>>>0)<<s>>>(s>>>0))+o|0;s=b[f+(t<<2)>>1]|0;q=b[f+(t<<2)+2>>1]|0;t=q<<16>>16;if(!((h|0)>2&q<<16>>16<0)){u=t;v=s;w=r;break}q=r-p|0;r=m>>>0>q>>>0?q:m;q=n+(r>>>3)|0;x=t+32|0;t=((d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)>>>((r&7)>>>0)<<x>>>(x>>>0))+s|0;u=b[f+(t<<2)+2>>1]|0;v=b[f+(t<<2)>>1]|0;w=r}else{u=p;v=o;w=l}}while(0);l=u+w|0;w=m>>>0>l>>>0?l:m;c[k>>2]=w;if((v|0)==0){l=n+(w>>>3)|0;u=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)>>>((w&7)>>>0)&7;l=w+3|0;o=m>>>0>l>>>0?l:m;c[k>>2]=o;l=n+(o>>>3)|0;p=u^31;f=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)>>>((o&7)>>>0)<<p>>>(p>>>0);p=o+1+u|0;u=m>>>0>p>>>0?p:m;c[k>>2]=u;y=f;z=u}else{y=v-1|0;z=w}if((g|0)==0){A=y;i=j;return A|0}if((y|0)>59){KIb(0,16,2202432,(g=i,i=i+8|0,c[g>>2]=y,g)|0);i=g;A=0;i=j;return A|0}g=c[255984+(y<<2)>>2]|0;if((y&-4|0)<=0){A=g;i=j;return A|0}w=y>>2;y=n+(z>>>3)|0;n=32-w|0;v=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((z&7)>>>0)<<n>>>(n>>>0);n=z+w|0;c[k>>2]=m>>>0>n>>>0?n:m;A=v+g|0;i=j;return A|0}function iYa(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;f=a+8|0;g=c[f>>2]|0;h=a+16|0;j=c[h>>2]|0;k=c[a>>2]|0;a=k+(g>>>3)|0;l=(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)>>>((g&7)>>>0)&255;a=g+8|0;c[f>>2]=j>>>0>a>>>0?a:j;j=b|0;c[j>>2]=l;if((l|0)==0){c[b+4>>2]=0;c[b+8>>2]=0;m=0;n=0;o=c[f>>2]|0;p=(o|0)/8|0;KIb(0,48,2477592,(q=i,i=i+24|0,c[q>>2]=m,c[q+8>>2]=n,c[q+16>>2]=p,q)|0);i=q;i=e;return}l=c[f>>2]|0;a=c[h>>2]|0;g=k+(l>>>3)|0;r=(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)>>>((l&7)>>>0)&255;g=l+8|0;c[f>>2]=a>>>0>g>>>0?g:a;a=b+4|0;c[a>>2]=r;g=c[j>>2]|0;if((g&128|0)==0){s=g;t=r}else{c[a>>2]=r<<8;r=c[f>>2]|0;g=c[h>>2]|0;l=k+(r>>>3)|0;u=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)>>>((r&7)>>>0)&255;l=r+8|0;c[f>>2]=g>>>0>l>>>0?l:g;g=u|c[a>>2];c[a>>2]=g;u=c[j>>2]&127;c[j>>2]=u;s=u;t=g}if((s|0)==127){g=c[f>>2]|0;u=c[h>>2]|0;h=k+(g>>>3)|0;l=(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)>>>((g&7)>>>0);h=g+8|0;c[f>>2]=u>>>0>h>>>0?h:u;u=l<<8&65280|c[j>>2];c[j>>2]=u;v=u;w=c[a>>2]|0}else{v=s;w=t}t=c[f>>2]|0;c[b+8>>2]=k+((t|0)/8|0);m=v;n=w;o=t;p=(o|0)/8|0;KIb(0,48,2477592,(q=i,i=i+24|0,c[q>>2]=m,c[q+8>>2]=n,c[q+16>>2]=p,q)|0);i=q;i=e;return}function jYa(e,f,h,j,k){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0.0,O=0,P=0.0,Q=0.0,R=0,S=0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0.0,da=0,ea=0,fa=0.0,ga=0,ha=0,ia=0,ja=0.0,ka=0,la=0.0;l=i;i=i+104|0;m=l|0;n=l+40|0;mrc(n|0,0,64)|0;o=(j|0)<(k|0);if((h|0)==0){if(!o){i=l;return}h=e+129860|0;p=e|0;q=j;do{r=c[h>>2]|0;if((r|0)>3839){c[h>>2]=r-3840}if((c[p>>2]|0)>0){s=+g[611872+(q<<2)>>2];r=0;do{t=0;do{u=c[h>>2]|0;c[h>>2]=u+1;v=e+101472+(r*7680|0)+(q<<8)+(t<<2)|0;w=t<<1;g[e+59488+(r<<14)+(w<<7)+(q<<2)>>2]=s*+g[5467640+(u<<2)>>2]*+g[v>>2];u=c[h>>2]|0;c[h>>2]=u+1;g[e+59488+(r<<14)+((w|1)<<7)+(q<<2)>>2]=s*+g[5467640+(u<<2)>>2]*+g[v>>2];t=t+1|0;}while((t|0)<64);r=r+1|0;}while((r|0)<(c[p>>2]|0))}q=q+1|0;}while((q|0)<(k|0));i=l;return}if(!o){i=l;return}o=e|0;q=e+129860|0;p=f+8|0;h=f+12|0;r=f|0;t=f+16|0;f=m|0;s=0.0;v=j;a:while(1){j=c[o>>2]|0;b:do{if((j|0)<2|(v|0)<12){x=49}else{u=c[p>>2]|0;w=c[h>>2]|0;if((v|0)>23){y=1;z=u}else{if((w-u|0)<=0){x=49;break}A=(d[(c[r>>2]|0)+(u>>>3)|0]|0)>>>((u&7)>>>0);B=((u|0)<(c[t>>2]|0))+u|0;c[p>>2]=B;u=A&1;if((u|0)==0){x=49;break}else{y=u;z=B}}if((w-z|0)>15){w=c[r>>2]|0;B=c[t>>2]|0;u=0;A=z;while(1){C=(d[w+(A>>>3)|0]|0)>>>((A&7)>>>0);D=((A|0)<(B|0))+A|0;c[p>>2]=D;c[n+(u<<2)>>2]=C&1;C=u+1|0;if((C|0)<16){u=C;A=D}else{E=0;break}}}else{E=0}do{A=a[e+118752+(v<<6)+E|0]|0;u=e+116832+(v<<6)+E|0;if(A<<24>>24>(a[u]|0)){a[u]=A}E=E+1|0;}while((E|0)<64);A=c[o>>2]|0;if((A|0)>0){F=0}else{G=1;H=y;I=1;x=50;break}c:while(1){u=0;do{B=e+116832+(F*1920|0)+(v<<6)+u|0;w=a[B]|0;if(w<<24>>24<8){break c}D=(w<<24>>24)-8|0;d:do{if((D|0)>22){J=8;K=1}else{w=c[525400+(D<<2)>>2]|0;switch(w|0){case 4:{J=30;K=1;break d;break};case 5:{J=8;K=1;break d;break};case 2:{J=24;K=5;break d;break};case 0:{J=10;K=10;break d;break};case 3:{J=30;K=w;break d;break};case 1:{J=16;K=w;break d;break};default:{J=8;K=1;break d}}}}while(0);D=0;do{w=D+u|0;do{if((w|0)<128){if(!((a[((w|0)%64|0)+(e+116832+(F*1920|0)+(((w|0)/64|0)+v<<6))|0]|0)>(a[B]|0)&(D|0)>0)){break}KIb(0,32,2501320,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;C=e+116832+(F*1920|0)+(v<<6)+w|0;mrc(C|0,J|0,D|0)|0;mrc(C|0,J|0,3)|0}}while(0);D=D+1|0;}while((D|0)<(K|0));u=K+u|0;}while((u|0)<64);u=F+1|0;if((u|0)<(A|0)){F=u}else{G=1;H=y;I=1;x=50;break b}}KIb(0,16,2587784,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;A=c[q>>2]|0;if((A|0)>3839){c[q>>2]=A-3840}if((c[o>>2]|0)<=0){M=s;break}N=+g[611872+(v<<2)>>2];A=0;while(1){u=0;do{D=c[q>>2]|0;c[q>>2]=D+1;B=e+101472+(A*7680|0)+(v<<8)+(u<<2)|0;w=u<<1;g[e+59488+(A<<14)+(w<<7)+(v<<2)>>2]=N*+g[5467640+(D<<2)>>2]*+g[B>>2];D=c[q>>2]|0;c[q>>2]=D+1;g[e+59488+(A<<14)+((w|1)<<7)+(v<<2)>>2]=N*+g[5467640+(D<<2)>>2]*+g[B>>2];u=u+1|0;}while((u|0)<64);u=A+1|0;if((u|0)<(c[o>>2]|0)){A=u}else{M=s;break}}}}while(0);if((x|0)==49){x=0;if((j|0)>0){G=0;H=0;I=j;x=50}else{M=s}}if((x|0)==50){x=0;A=611872+(v<<2)|0;u=v+1|0;B=0;N=s;while(1){D=c[q>>2]|0;if((D|0)>3839){c[q>>2]=D-3840}D=c[p>>2]|0;if(((c[h>>2]|0)-D|0)>0){w=d[(c[r>>2]|0)+(D>>>3)|0]|0;c[p>>2]=((D|0)<(c[t>>2]|0))+D;O=(w&1<<(D&7)|0)==0}else{O=1}D=(B*5|0)+1|0;w=0;C=1;P=N;Q=0.0;while(1){e:do{switch(a[((w|0)/2|0)+(e+116832+(B*1920|0)+(v<<6))|0]|0){case 30:{R=c[p>>2]|0;if(((c[h>>2]|0)-R|0)<=3){S=c[q>>2]|0;c[q>>2]=S+1;g[f>>2]=+g[5467640+(S<<2)>>2]*+g[A>>2];T=Q;U=P;V=C;W=1;break e}S=c[846751]|0;X=c[t>>2]|0;Y=c[r>>2]|0;Z=Y+(R>>>3)|0;_=32-(c[846750]|0)|0;$=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((R&7)>>>0)<<_>>>(_>>>0);_=b[S+($<<2)>>1]|0;Z=(b[S+($<<2)+2>>1]|0)+R|0;R=X>>>0>Z>>>0?Z:X;c[p>>2]=R;if(_<<16>>16==0){Z=Y+(R>>>3)|0;$=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((R&7)>>>0)&7;Z=R+3|0;R=X>>>0>Z>>>0?Z:X;c[p>>2]=R;Z=Y+(R>>>3)|0;Y=$^31;S=(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)>>>((R&7)>>>0)<<Y>>>(Y>>>0);Y=R+1+$|0;c[p>>2]=X>>>0>Y>>>0?Y:X;aa=S}else{aa=(_<<16>>16)-1|0}if(aa>>>0>7>>>0){x=90;break a}g[f>>2]=+g[301552+(aa<<2)>>2];T=Q;U=P;V=C;W=1;break};case 34:{_=c[p>>2]|0;if(((c[h>>2]|0)-_|0)<=6){S=c[q>>2]|0;c[q>>2]=S+1;g[f>>2]=+g[5467640+(S<<2)>>2]*+g[A>>2];T=Q;U=P;V=C;W=1;break e}if((C|0)!=0){S=c[t>>2]|0;X=c[r>>2]|0;Y=X+(_>>>3)|0;$=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((_&7)>>>0)&3;Y=_+2|0;R=S>>>0>Y>>>0?Y:S;c[p>>2]=R;Y=X+(R>>>3)|0;X=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((R&7)>>>0)&31;Y=R+5|0;c[p>>2]=S>>>0>Y>>>0?Y:S;ba=(+(X>>>0>>>0)+-16.0)/15.0;g[f>>2]=ba;T=ba;U=+(1<<$|0);V=0;W=1;break e}$=c[846745]|0;X=c[t>>2]|0;S=c[r>>2]|0;Y=S+(_>>>3)|0;R=32-(c[846744]|0)|0;Z=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((_&7)>>>0)<<R>>>(R>>>0);R=b[$+(Z<<2)>>1]|0;Y=(b[$+(Z<<2)+2>>1]|0)+_|0;_=X>>>0>Y>>>0?Y:X;c[p>>2]=_;if(R<<16>>16==0){Y=S+(_>>>3)|0;Z=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((_&7)>>>0)&7;Y=_+3|0;_=X>>>0>Y>>>0?Y:X;c[p>>2]=_;Y=S+(_>>>3)|0;S=Z^31;$=(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((_&7)>>>0)<<S>>>(S>>>0);S=_+1+Z|0;c[p>>2]=X>>>0>S>>>0?S:X;da=$}else{da=(R<<16>>16)-1|0}if(da>>>0>9>>>0){x=99;break a}ba=Q+ +g[301512+(da<<2)>>2]/P;g[f>>2]=ba;T=ba;U=P;V=0;W=1;break};case 8:{R=c[p>>2]|0;if(((c[h>>2]|0)-R|0)<=9){ba=+g[A>>2];$=c[q>>2]|0;g[f>>2]=+g[5467640+($<<2)>>2]*ba;g[m+4>>2]=+g[5467640+($+1<<2)>>2]*ba;g[m+8>>2]=+g[5467640+($+2<<2)>>2]*ba;g[m+12>>2]=+g[5467640+($+3<<2)>>2]*ba;g[m+16>>2]=+g[5467640+($+4<<2)>>2]*ba;g[m+20>>2]=+g[5467640+($+5<<2)>>2]*ba;g[m+24>>2]=+g[5467640+($+6<<2)>>2]*ba;g[m+28>>2]=+g[5467640+($+7<<2)>>2]*ba;g[m+32>>2]=+g[5467640+($+8<<2)>>2]*ba;g[m+36>>2]=+g[5467640+($+9<<2)>>2]*ba;c[q>>2]=$+10;T=Q;U=P;V=C;W=10;break e}f:do{if(O){$=c[t>>2]|0;X=(c[r>>2]|0)+(R>>>3)|0;S=(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)>>>((R&7)>>>0)&255;X=R+8|0;c[p>>2]=$>>>0>X>>>0?X:$;if(S>>>0>242>>>0){x=66;break a}g[f>>2]=+g[1552152+(H*12|0)+(d[5412336+(S*5|0)|0]<<2)>>2];g[m+8>>2]=+g[1552152+(H*12|0)+(d[5412337+(S*5|0)|0]<<2)>>2];g[m+16>>2]=+g[1552152+(H*12|0)+(d[5412338+(S*5|0)|0]<<2)>>2];g[m+24>>2]=+g[1552152+(H*12|0)+(d[5412339+(S*5|0)|0]<<2)>>2];g[m+32>>2]=+g[1552152+(H*12|0)+(d[5412340+(S*5|0)|0]<<2)>>2]}else{S=0;$=R;while(1){X=S<<1;if((X+w|0)>127){break f}Z=c[r>>2]|0;_=d[Z+($>>>3)|0]|0;Y=c[t>>2]|0;ea=(($|0)<(Y|0))+$|0;c[p>>2]=ea;if((_&1<<($&7)|0)==0){fa=0.0;ga=ea}else{_=(d[Z+(ea>>>3)|0]|0)>>>((ea&7)>>>0);Z=((ea|0)<(Y|0))+ea|0;c[p>>2]=Z;fa=+g[1552152+(H*12|0)+((_<<1&2)<<2)>>2];ga=Z}g[m+(X<<2)>>2]=fa;X=S+1|0;if((X|0)<5){S=X;$=ga}else{break}}}}while(0);ba=+g[A>>2];R=c[q>>2]|0;g[m+4>>2]=+g[5467640+(R<<2)>>2]*ba;g[m+12>>2]=+g[5467640+(R+1<<2)>>2]*ba;g[m+20>>2]=+g[5467640+(R+2<<2)>>2]*ba;g[m+28>>2]=+g[5467640+(R+3<<2)>>2]*ba;g[m+36>>2]=+g[5467640+(R+4<<2)>>2]*ba;c[q>>2]=R+5;T=Q;U=P;V=C;W=10;break};case 16:{R=c[p>>2]|0;if(((c[h>>2]|0)-R|0)<=9){ba=+g[A>>2];$=c[q>>2]|0;g[f>>2]=+g[5467640+($<<2)>>2]*ba;g[m+4>>2]=+g[5467640+($+1<<2)>>2]*ba;g[m+8>>2]=+g[5467640+($+2<<2)>>2]*ba;g[m+12>>2]=+g[5467640+($+3<<2)>>2]*ba;g[m+16>>2]=+g[5467640+($+4<<2)>>2]*ba;c[q>>2]=$+5;T=Q;U=P;V=C;W=5;break e}if(O){$=c[t>>2]|0;S=(c[r>>2]|0)+(R>>>3)|0;X=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((R&7)>>>0)&255;S=R+8|0;c[p>>2]=$>>>0>S>>>0?S:$;if(X>>>0>242>>>0){x=80;break a}g[f>>2]=+g[1552152+(H*12|0)+(d[5412336+(X*5|0)|0]<<2)>>2];g[m+4>>2]=+g[1552152+(H*12|0)+(d[5412337+(X*5|0)|0]<<2)>>2];g[m+8>>2]=+g[1552152+(H*12|0)+(d[5412338+(X*5|0)|0]<<2)>>2];g[m+12>>2]=+g[1552152+(H*12|0)+(d[5412339+(X*5|0)|0]<<2)>>2];g[m+16>>2]=+g[1552152+(H*12|0)+(d[5412340+(X*5|0)|0]<<2)>>2];T=Q;U=P;V=C;W=5;break e}else{ha=0;ia=R}while(1){if((ha+w|0)>127){T=Q;U=P;V=C;W=5;break e}R=c[r>>2]|0;X=d[R+(ia>>>3)|0]|0;$=c[t>>2]|0;S=((ia|0)<($|0))+ia|0;c[p>>2]=S;if((X&1<<(ia&7)|0)==0){ja=0.0;ka=S}else{X=(d[R+(S>>>3)|0]|0)>>>((S&7)>>>0);R=((S|0)<($|0))+S|0;c[p>>2]=R;ja=+g[1552152+(H*12|0)+((X<<1&2)<<2)>>2];ka=R}g[m+(ha<<2)>>2]=ja;R=ha+1|0;if((R|0)<5){ha=R;ia=ka}else{T=Q;U=P;V=C;W=5;break}}break};case 24:{R=c[p>>2]|0;if(((c[h>>2]|0)-R|0)<=6){ba=+g[A>>2];X=c[q>>2]|0;g[f>>2]=+g[5467640+(X<<2)>>2]*ba;g[m+4>>2]=+g[5467640+(X+1<<2)>>2]*ba;g[m+8>>2]=+g[5467640+(X+2<<2)>>2]*ba;c[q>>2]=X+3;T=Q;U=P;V=C;W=3;break e}X=c[t>>2]|0;S=(c[r>>2]|0)+(R>>>3)|0;$=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((R&7)>>>0)&127;S=R+7|0;c[p>>2]=X>>>0>S>>>0?S:X;if($>>>0>124>>>0){x=85;break a}g[f>>2]=+((d[5411952+($*3|0)|0]|0)-2|0)*.5;g[m+4>>2]=+((d[5411953+($*3|0)|0]|0)-2|0)*.5;g[m+8>>2]=+((d[5411954+($*3|0)|0]|0)-2|0)*.5;T=Q;U=P;V=C;W=3;break};case 10:{$=c[p>>2]|0;if(((c[h>>2]|0)-$|0)>0){X=d[(c[r>>2]|0)+($>>>3)|0]|0;c[p>>2]=(($|0)<(c[t>>2]|0))+$;g[f>>2]=((X&1<<($&7)|0)==0?.8100000023841858:-.8100000023841858)- +g[5484104+(((ca(D+w|0,u)|0)&127)<<2)>>2]*9.0/40.0;T=Q;U=P;V=C;W=1;break e}else{$=c[q>>2]|0;c[q>>2]=$+1;g[f>>2]=+g[5467640+($<<2)>>2]*+g[A>>2];T=Q;U=P;V=C;W=1;break e}break};default:{$=c[q>>2]|0;c[q>>2]=$+1;g[f>>2]=+g[5467640+($<<2)>>2]*+g[A>>2];T=Q;U=P;V=C;W=1}}}while(0);g:do{if(G){$=0;do{X=$+w|0;if((X|0)>=128){break g}S=(X|0)/2|0;ba=+g[m+($<<2)>>2];g[e+59488+(X<<7)+(v<<2)>>2]=+g[e+101472+(v<<8)+(S<<2)>>2]*ba;do{if((c[o>>2]|0)==2){la=+g[e+109152+(v<<8)+(S<<2)>>2];if((c[n+(((X|0)/8|0)<<2)>>2]|0)==0){g[e+75872+(X<<7)+(v<<2)>>2]=la*ba;break}else{g[e+75872+(X<<7)+(v<<2)>>2]=la*(-0.0-ba);break}}}while(0);$=$+1|0;}while(($|0)<(W|0))}else{$=0;do{X=$+w|0;if((X|0)<128){g[e+59488+(B<<14)+(X<<7)+(v<<2)>>2]=+g[e+101472+(B*7680|0)+(v<<8)+(((X|0)/2|0)<<2)>>2]*+g[m+($<<2)>>2]}$=$+1|0;}while(($|0)<(W|0))}}while(0);$=W+w|0;if(($|0)<128){w=$;C=V;P=U;Q=T}else{break}}C=B+1|0;if((C|0)<(I|0)){B=C;N=U}else{M=U;break}}}B=v+1|0;if((B|0)<(k|0)){s=M;v=B}else{x=116;break}}if((x|0)==66){KIb(0,16,2566536,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;i=l;return}else if((x|0)==80){KIb(0,16,2566536,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;i=l;return}else if((x|0)==85){KIb(0,16,2548336,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;i=l;return}else if((x|0)==90){KIb(0,16,2530440,(L=i,i=i+8|0,c[L>>2]=aa,L)|0);i=L;i=l;return}else if((x|0)==99){KIb(0,16,2515176,(L=i,i=i+8|0,c[L>>2]=da,L)|0);i=L;i=l;return}else if((x|0)==116){i=l;return}}function kYa(b,e){b=b|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=b|0;h=c[f>>2]|0;if((h|0)>0){i=b+40|0;j=0;while(1){k=0;do{l=0;do{m=c[i>>2]|0;n=d[1648272+(m*30|0)+k|0]|0;if((n|0)<((d[1012984+m|0]|0)-1|0)){o=n+1|0;p=ca(a[b+120672+(j*80|0)+(o<<3)+l|0]|0,c[1548288+(m*1200|0)+(o*120|0)+(k<<2)>>2]|0)|0;q=(ca(a[b+120672+(j*80|0)+(n<<3)+l|0]|0,c[1548288+(m*1200|0)+(n*120|0)+(k<<2)>>2]|0)|0)+p|0}else{q=ca(a[b+120672+(j*80|0)+(n<<3)+l|0]|0,c[1548288+(m*1200|0)+(n*120|0)+(k<<2)>>2]|0)|0}a[b+120832+(j*240|0)+(k<<3)+l|0]=(((q|0)<0?q+255|0:q)|0)/256|0;l=l+1|0;}while((l|0)<8);k=k+1|0;}while((k|0)<30);k=j+1|0;l=c[f>>2]|0;if((k|0)<(l|0)){j=k}else{r=l;break}}}else{r=h}h=c[b+36>>2]|0;j=(h|0)>1?30:8<<h;h=b+129848|0;q=c[h>>2]|0;if((q|0)!=0&(e|0)==0){if((j|0)>0){s=0;t=r}else{return}while(1){if((t|0)>0){e=0;while(1){i=0;do{l=a[((i|0)/8|0)+(b+120832+(e*240|0)+(s<<3))|0]|0;a[b+122164+(e*1920|0)+(s<<6)+i|0]=l;if(l<<24>>24<0){g[b+101472+(e*7680|0)+(s<<8)+(i<<2)>>2]=0.0}else{g[b+101472+(e*7680|0)+(s<<8)+(i<<2)>>2]=+g[1239400+((l&63)<<2)>>2]}i=i+1|0;}while((i|0)<64);i=e+1|0;l=c[f>>2]|0;if((i|0)<(l|0)){e=i}else{u=l;break}}}else{u=t}e=s+1|0;if((e|0)<(j|0)){s=e;t=u}else{break}}return}u=(q|0)==0|0;if((j|0)>0){v=0;w=r}else{return}while(1){r=v-4|0;do{if(r>>>0<20>>>0){if((w|0)<=0){x=w;break}q=(v|0)/8|0;t=0;while(1){s=b+122112+(t*26|0)+r|0;e=0;do{l=(e|0)/8|0;i=(a[b+120832+(t*240|0)+(v<<3)+l|0]|0)-(a[((e|0)%8|0)+(b+121312+(t*192|0)+(q<<6)+(l<<3))|0]|0)-(a[b+121696+(t*208|0)+(r<<3)+l|0]|0)|0;l=a[s]|0;k=i-l|0;a[b+122164+(t*1920|0)+(v<<6)+e|0]=k;do{if((k|0)<0){y=28}else{if((c[h>>2]|0)==0&(i|0)==(l|0)){y=28;break}g[b+101472+(t*7680|0)+(v<<8)+(e<<2)>>2]=+g[1239400+(u<<8)+((k&63)<<2)>>2]}}while(0);if((y|0)==28){y=0;g[b+101472+(t*7680|0)+(v<<8)+(e<<2)>>2]=0.0}e=e+1|0;}while((e|0)<64);e=t+1|0;s=c[f>>2]|0;if((e|0)<(s|0)){t=e}else{x=s;break}}}else{t=(w|0)>0;if((v|0)>4){if(t){z=0}else{x=w;break}while(1){q=b+122112+(z*26|0)+r|0;s=0;do{e=(s|0)/8|0;k=(a[b+120832+(z*240|0)+(v<<3)+e|0]|0)-(a[((s|0)%8|0)+(b+121312+(z*192|0)+128+(e<<3))|0]|0)|0;e=a[q]|0;l=k-e|0;a[b+122164+(z*1920|0)+(v<<6)+s|0]=l;do{if((l|0)<0){y=38}else{if((c[h>>2]|0)==0&(k|0)==(e|0)){y=38;break}g[b+101472+(z*7680|0)+(v<<8)+(s<<2)>>2]=+g[1239400+(u<<8)+((l&63)<<2)>>2]}}while(0);if((y|0)==38){y=0;g[b+101472+(z*7680|0)+(v<<8)+(s<<2)>>2]=0.0}s=s+1|0;}while((s|0)<64);s=z+1|0;q=c[f>>2]|0;if((s|0)<(q|0)){z=s}else{x=q;break}}}else{if(t){A=0}else{x=w;break}while(1){q=0;do{s=a[((q|0)/8|0)+(b+120832+(A*240|0)+(v<<3))|0]|0;a[b+122164+(A*1920|0)+(v<<6)+q|0]=s;l=s&255;do{if(s<<24>>24<0){y=45}else{if((c[h>>2]|0)==0&s<<24>>24==0){y=45;break}g[b+101472+(A*7680|0)+(v<<8)+(q<<2)>>2]=+g[1239400+(u<<8)+((l&63)<<2)>>2]}}while(0);if((y|0)==45){y=0;g[b+101472+(A*7680|0)+(v<<8)+(q<<2)>>2]=0.0}q=q+1|0;}while((q|0)<64);q=A+1|0;l=c[f>>2]|0;if((q|0)<(l|0)){A=q}else{x=l;break}}}}}while(0);r=v+1|0;if((r|0)<(j|0)){v=r;w=x}else{break}}return}function lYa(a){a=a|0;c[a+140>>2]=11;return 0}function mYa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=M4a(b,e,0)|0;if((g|0)<0){l=g;i=h;return l|0}c[e+88>>2]=1;c[e+84>>2]=1;g=c[e>>2]|0;m=j+k|0;if((k|0)<108){l=-1094995529;i=h;return l|0}n=j+104|0;o=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;if(o>>>0>256>>>0){KIb(b,16,2447760,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=o,p)|0);i=p;l=-1094995529;i=h;return l|0}if((k-108|0)<((o<<3)+8|0)){l=-1094995529;i=h;return l|0}n=c[e+4>>2]|0;q=b;r=o<<3;s=0;t=j+108|0;while(1){u=t;v=he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0;u=v&65535;if((v&65535)>>>0>255>>>0){KIb(q,16,2358520,(p=i,i=i+8|0,c[p>>2]=u,p)|0);i=p}else{c[n+(u<<2)>>2]=(d[t+2|0]|0)<<16|(d[t+4|0]|0)<<8|(d[t+6|0]|0)|-16777216}u=s+1|0;if((u|0)>(o|0)){break}else{s=u;t=t+8|0}}c[e+304>>2]=1;if((k-(r+116)|0)<18){l=-1094995529;i=h;return l|0}t=b+124|0;a:do{if((c[t>>2]|0)>0){b=e+32|0;s=0;o=g;n=j+(r+134)|0;b:while(1){p=n;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=(he(q|0)|0)&65535;u=n+2|0;if((m-u|0)<(p|0)){l=-1094995529;w=25;break}v=n+(p+2)|0;c:do{if(!(q<<16>>16==0)){x=p;y=u;z=o;while(1){A=y+1|0;B=d[y]|0;if((B&128|0)==0){if((z+B|0)>>>0>(o+(c[b>>2]|0)|0)>>>0){break c}C=B+1|0;if((m-A|0)<(C|0)){l=-1094995529;w=25;break b}nrc(z|0,A|0,C)|0;D=z+C|0;E=y+(B+2)|0;F=x-2-B|0}else{C=257-B|0;B=z+C|0;if(B>>>0>(o+(c[b>>2]|0)|0)>>>0){break c}mrc(z|0,a[A]|0,C|0)|0;D=B;E=y+2|0;F=x-2|0}if((F|0)>0){x=F;y=E;z=D}else{break}}}}while(0);u=s+1|0;if((u|0)<(c[t>>2]|0)){s=u;o=o+(c[b>>2]|0)|0;n=v}else{break a}}if((w|0)==25){i=h;return l|0}}}while(0);c[f>>2]=1;l=k;i=h;return l|0}function nYa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+60|0;e=c[b>>2]|0;c[e>>2]=a;c[a+140>>2]=11;f=c[a+100>>2]|0;g=f>>>0<1024>>>0?f:1024;h=c[a+96>>2]|0;a=f-g|0;f=(g|0)/4|0;if((g|0)>3){g=(c[b>>2]|0)+12|0;i=0;do{j=h+(a+(i<<2))|0;c[g+(i<<2)>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|-16777216;i=i+1|0;}while((i|0)<(f|0))}f=e+4|0;c[f>>2]=UHb()|0;i=UHb()|0;c[e+8>>2]=i;if(!((c[f>>2]|0)==0|(i|0)==0)){k=0;return k|0}i=c[b>>2]|0;VHb(i+4|0);VHb(i+8|0);k=-12;return k|0}function oYa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;h=i;i=i+128|0;j=c[b+60>>2]|0;k=j;l=c[j+4>>2]|0;m=c[j+8>>2]|0;n=V1(g,0,0)|0;o=g+28|0;p=c[o>>2]|0;if((p|0)<134){KIb(b,16,2447736,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=-1094995529;i=h;return r|0}q=c[g+24>>2]|0;g=j+1036|0;c[g>>2]=q;c[j+1044>>2]=q;s=j+1040|0;c[s>>2]=q+p;WHb(m);aIb(m,l);p=M4a(b,l,1)|0;if((p|0)<0){r=p;i=h;return r|0}p=c[l>>2]|0;q=c[s>>2]|0;t=c[g>>2]|0;u=q;v=u-t|0;w=v>>>0>4>>>0?4:v;v=t+w|0;c[g>>2]=v;x=h|0;y=u-v|0;z=y>>>0>128>>>0?128:y;nrc(x|0,v|0,z)|0;v=u-(t+(w+z))|0;y=(v>>>0>1>>>0?1:v)+z|0;z=t+(w+y)|0;c[g>>2]=z;if((u-z|0)<1){A=0;B=z}else{u=t+(w+(y+1))|0;c[g>>2]=u;A=d[z]|0;B=u}u=c[l+32>>2]|0;z=c[b+120>>2]|0;y=c[b+124>>2]|0;a:do{if((A|0)==16){if(!((q|0)!=(B|0)&(y|0)>0)){break}b=-u|0;w=0;t=y;v=p+(ca(y-1|0,u)|0)|0;C=q;D=B;while(1){E=C;b:do{if((E-D|0)<1){F=D;G=1;H=35}else{I=D+1|0;c[g>>2]=I;J=a[D]|0;K=J&255;if(J<<24>>24==-4){break a}do{if((J&255)>>>0>247>>>0){if((E-I|0)<1){L=0;M=I}else{N=D+2|0;c[g>>2]=N;L=(d[I]|0)<<8;M=N}if((E-M|0)<1){O=0;P=M}else{N=M+1|0;c[g>>2]=N;O=d[M]|0;P=N}Q=O|L+(K<<16&458752);R=P}else{if((J&255)>>>0>239>>>0){if((E-I|0)<1){S=0;T=I}else{N=D+2|0;c[g>>2]=N;S=d[I]|0;T=N}Q=S|K<<8&3840;R=T;break}if((J&255)>>>0>223>>>0){Q=K&31;R=I;break}do{if((J&255)>>>0>191>>>0){if((E-I|0)<1){U=0;V=I}else{N=D+2|0;c[g>>2]=N;U=(d[I]|0)<<8;V=N}if((E-V|0)<1){W=0;X=V}else{N=V+1|0;c[g>>2]=N;W=d[V]|0;X=N}Y=W|U+(K<<16&4128768);Z=X}else{if(!(J<<24>>24<0)){Y=K;Z=I;break}if((E-I|0)<1){_=0;$=I}else{N=D+2|0;c[g>>2]=N;_=d[I]|0;$=N}Y=_|K<<8&32512;Z=$}}while(0);N=Y+1|0;if((N|0)>0){F=Z;G=N;H=35;break b}else{aa=v;ba=t;da=w;break b}}}while(0);K=Q+2|0;if((E-R|0)<1){ea=0}else{c[g>>2]=R+1;ea=a[R]|0}if((K|0)>0){fa=0;ga=w;ha=t;ia=v}else{aa=v;ba=t;da=w;break}while(1){I=ga+1|0;a[ia+ga|0]=ea;if((I|0)<(z|0)){ja=ia;ka=ha;la=I}else{I=ha-1|0;if((I|0)<1){break a}else{ja=ia+b|0;ka=I;la=0}}I=fa+1|0;if((I|0)<(K|0)){fa=I;ga=la;ha=ka;ia=ja}else{aa=ja;ba=ka;da=la;break}}}}while(0);c:do{if((H|0)==35){H=0;E=1;K=w;I=t;J=v;N=C;ma=F;while(1){if((N-ma|0)<1){na=0}else{c[g>>2]=ma+1;na=a[ma]|0}oa=K+1|0;a[J+K|0]=na;if((oa|0)<(z|0)){pa=J;qa=I;ra=oa}else{oa=I-1|0;if((oa|0)<1){break a}else{pa=J+b|0;qa=oa;ra=0}}if((E|0)>=(G|0)){aa=pa;ba=qa;da=ra;break c}E=E+1|0;K=ra;I=qa;J=pa;N=c[s>>2]|0;ma=c[g>>2]|0}}}while(0);ma=c[g>>2]|0;N=c[s>>2]|0;if((N|0)!=(ma|0)&(ba|0)>0){w=da;t=ba;v=aa;C=N;D=ma}else{break}}}else{rYa(k,p,u,z,y,A,x,c[m>>2]|0)}}while(0);if((n|0)==0){sa=j+12|0}else{c[l+304>>2]=1;m=j+12|0;nrc(m|0,n|0,1024)|0;sa=m}nrc(c[l+4>>2]|0,sa|0,1024)|0;sa=YHb(e,l)|0;if((sa|0)<0){r=sa;i=h;return r|0}c[f>>2]=1;r=c[o>>2]|0;i=h;return r|0}function pYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);VHb(b+8|0);return 0}function qYa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=c[a+100>>2]|0;e=b>>>0<1024>>>0?b:1024;f=c[a+96>>2]|0;g=b-e|0;b=(e|0)/4|0;if((e|0)<=3){return}e=(c[a+60>>2]|0)+12|0;a=0;do{h=f+(g+(a<<2))|0;c[e+(a<<2)>>2]=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|-16777216;a=a+1|0;}while((a|0)<(b|0));return}function rYa(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;m=i;n=(l|0)==0?e:l;if((h|0)>0){l=0;do{o=ca(l,f)|0;nrc(e+o|0,n+o|0,g)|0;l=l+1|0;}while((l|0)<(h|0))}l=h-1|0;o=b+1036|0;p=b+1040|0;b=(j|0)==0;q=(j|0)==1;j=-f|0;r=e+(ca(l,f)|0)|0;e=l;l=0;a:while(1){s=(e|0)>-1;t=l;while(1){u=c[o>>2]|0;v=c[p>>2]|0;if(!((v|0)!=(u|0)&s)){w=56;break a}if((v-u|0)<1){x=0;y=u}else{z=u+1|0;c[o>>2]=z;x=d[u]|0;y=z}b:do{if(b){A=x;B=v;C=y}else{if((v|0)==(y|0)){A=x;B=v;C=v;break}else{D=x;E=v;F=y}while(1){if((D&240|0)!=240){A=D;B=E;C=F;break b}c:do{if(q){z=D&15;u=c[692128+(z<<2)>>2]|0;G=c[692192+(z<<2)>>2]|0;if((E-F|0)<1){H=0}else{c[o>>2]=F+1;H=d[F]|0}I=H>>>4;J=H>>>0>127>>>0?I|-16:I;I=H&15;K=I>>>0>7>>>0?H|-16:I;I=J+t|0;do{if((I|0)>=0){L=u+t|0;if((L+J|0)>(g|0)){break}M=e-K|0;if((M-G|0)<0|(M|0)>(h|0)|(L|0)>(g|0)){break}if((e-G|0)<0){break}if((z|0)==0){break c}L=(ca(M,f)|0)+I|0;M=0;while(1){N=ca(M,f)|0;O=L-N|0;P=t-N|0;N=0;do{a[r+(P+N)|0]=a[n+(O+N)|0]|0;N=N+1|0;}while((N|0)<(u|0));M=M+1|0;if((M|0)>=(G|0)){break c}}}}while(0);KIb(0,16,2358456,(I=i,i=i+48|0,c[I>>2]=J,c[I+8>>2]=K,c[I+16>>2]=u,c[I+24>>2]=G,c[I+32>>2]=t,c[I+40>>2]=e,I)|0);i=I}}while(0);I=c[p>>2]|0;z=c[o>>2]|0;if((I-z|0)<1){Q=0;R=z}else{M=z+1|0;c[o>>2]=M;Q=d[z]|0;R=M}if((I|0)==(R|0)){A=Q;B=I;C=I;break}else{D=Q;E=I;F=R}}}}while(0);if((A|0)==224){w=56;break a}if((A|0)>224){w=29;break}if((A|0)>191){w=36;break}if((A|0)>127){w=44;break}if((A|0)!=0){a[r+t|0]=a[k+(A&127)|0]|0}v=t+1|0;if((v|0)<(g|0)){t=v}else{w=55;break}}if((w|0)==29){w=0;s=A&31;if((B-C|0)<1){S=0}else{c[o>>2]=C+1;S=a[C]|0}v=t;I=0;M=e;z=r;while(1){L=v+1|0;a[z+v|0]=S;if((L|0)<(g|0)){T=z;U=M;V=L}else{L=z+j|0;N=M-1|0;if((N|0)<0){r=L;e=N;l=0;continue a}else{T=L;U=N;V=0}}N=I+1|0;if((N|0)>(s|0)){r=T;e=U;l=V;continue a}else{v=V;I=N;M=U;z=T}}}else if((w|0)==36){w=0;z=A&31;if((z+1|0)>>>0>(B-C|0)>>>0){w=56;break}else{W=t;X=1;Y=e;Z=r;_=B;$=C}while(1){if((_-$|0)<1){aa=0}else{c[o>>2]=$+1;aa=a[$]|0}M=W+1|0;a[Z+W|0]=aa;if((M|0)<(g|0)){ba=Z;da=Y;ea=M}else{M=Z+j|0;I=Y-1|0;if((I|0)<0){r=M;e=I;l=0;continue a}else{ba=M;da=I;ea=0}}if((X|0)>(z|0)){r=ba;e=da;l=ea;continue a}W=ea;X=X+1|0;Y=da;Z=ba;_=c[p>>2]|0;$=c[o>>2]|0}}else if((w|0)==44){w=0;z=A&63;do{if((z|0)==0){if((B-C|0)<1){fa=64;break}c[o>>2]=C+1;fa=(d[C]|0)+64|0}else if((z|0)==1){if((B-C|0)<1){fa=320;break}c[o>>2]=C+1;fa=(d[C]|0)+320|0}else{fa=z}}while(0);z=r;I=e;M=fa+t|0;while(1){if((M|0)<(g|0)){r=z;e=I;l=M;continue a}v=M-g|0;s=z+j|0;N=I-1|0;if((N|0)<0){r=s;e=N;l=v;continue a}else{z=s;I=N;M=v}}}else if((w|0)==55){w=0;r=r+j|0;e=e-1|0;l=0;continue}}if((w|0)==56){i=m;return}}function sYa(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;e=c[a+792>>2]|0;switch(e|0){case 1:case 33:{c[a+140>>2]=9;break};case 16:{c[a+140>>2]=46;break};case 24:{c[a+140>>2]=2;break};case 2:case 4:case 8:case 34:case 36:case 40:{c[a+140>>2]=11;break};case 32:{c[a+140>>2]=30;break};default:{KIb(a,16,2447688,(a=i,i=i+8|0,c[a>>2]=e,a)|0);i=a;f=-1094995529;i=b;return f|0}}a=UHb()|0;c[d+4>>2]=a;f=(a|0)==0?-12:0;i=b;return f|0}function tYa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0;j=i;k=c[e+60>>2]|0;l=k;m=c[h+24>>2]|0;n=h+28|0;o=c[n>>2]|0;if(!((o|0)>-1)){KIb(0,0,2294952,(p=i,i=i+24|0,c[p>>2]=2244e3,c[p+8>>2]=2202408,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}q=k+8|0;c[q>>2]=m;r=k+16|0;c[r>>2]=m;s=k+12|0;c[s>>2]=m+o;o=k+4|0;m=N4a(e,c[o>>2]|0)|0;if((m|0)<0){t=m;i=j;return t|0}m=c[n>>2]|0;a:do{if((m|0)>=8){u=c[s>>2]|0;v=c[r>>2]|0;w=u;x=w-v|0;y=(x|0)<4?x:4;x=v+y|0;c[q>>2]=x;do{if((w-x|0)<2){z=x;A=13}else{B=v+(y+2)|0;c[q>>2]=B;C=x;if(((d[C]|d[C+1|0]<<8)<<16>>16&2048)==0){z=B;A=13;break}if((m|0)<14){break a}if((w-B|0)<2){D=0;E=B}else{C=v+(y+4)|0;c[q>>2]=C;F=B;D=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;E=C}C=w-E|0;F=C>>>0>2>>>0?2:C;C=E+F|0;c[q>>2]=C;if((w-C|0)<2){G=0;H=C}else{B=E+(F+2)|0;c[q>>2]=B;F=C;G=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;H=B}B=w-H|0;F=H+(B>>>0>2>>>0?2:B)|0;c[q>>2]=F;B=c[k>>2]|0;C=c[B+124>>2]|0;if((G|0)>(C-D|0)){break a}else{I=D;J=G;K=B;L=C;M=F}}}while(0);if((A|0)==13){y=c[k>>2]|0;v=c[y+124>>2]|0;I=0;J=v;K=y;L=v;M=z}v=c[o>>2]|0;y=c[v+32>>2]|0;x=ca(y,I)|0;F=c[e+792>>2]|0;b:do{switch(F|0){case 2:case 34:{vYa(l,x,J,2);break};case 24:{C=c[v>>2]|0;B=k;N=ca(L,y)|0;if((J|0)==0){break a}else{O=x;P=J;Q=u;R=M}c:while(1){S=P-1|0;if((Q-R|0)<1){T=-3;U=R}else{V=R+1|0;c[q>>2]=V;T=((d[R]|0)*3|0)-3|0;U=V}W=T+O|0;if((W|0)>(N|0)|(W|0)<0){A=104;break}else{X=W;Y=Q;Z=U}d:while(1){V=Y;e:do{if((V-Z|0)<1){_=Z;A=107}else{$=Z+1|0;c[q>>2]=$;aa=a[Z]|0;ba=aa<<24>>24;if((ba|0)==(-1|0)){break d}else if((ba|0)==0){_=$;A=107;break}if(aa<<24>>24<0){if((V-$|0)<1){da=0;ea=$}else{fa=Z+2|0;c[q>>2]=fa;da=a[$]|0;ea=fa}if((V-ea|0)<1){ga=0;ha=ea}else{fa=ea+1|0;c[q>>2]=fa;ga=a[ea]|0;ha=fa}if((V-ha|0)<1){ia=0}else{c[q>>2]=ha+1;ia=a[ha]|0}ja=(ba*-3|0)+X|0;if((ja|0)>(N|0)|(ja|0)<0){A=122;break c}if(aa<<24>>24==0){ka=X;break}fa=X;la=-ba|0;while(1){ma=la-1|0;a[C+fa|0]=da;a[C+(fa+1)|0]=ga;a[C+(fa+2)|0]=ia;if((ma|0)==0){ka=ja;break}else{fa=fa+3|0;la=ma}}}else{na=(ba*3|0)+X|0;if((na|0)>(N|0)|(na|0)<0){A=126;break c}if(aa<<24>>24==0){ka=X;break}else{oa=X;pa=ba;qa=Y;ra=$}while(1){la=pa-1|0;if((qa-ra|0)<1){sa=0}else{c[q>>2]=ra+1;sa=a[ra]|0}a[C+oa|0]=sa;fa=c[q>>2]|0;if(((c[s>>2]|0)-fa|0)<1){ta=0}else{c[q>>2]=fa+1;ta=a[fa]|0}a[C+(oa+1)|0]=ta;fa=c[q>>2]|0;if(((c[s>>2]|0)-fa|0)<1){ua=0}else{c[q>>2]=fa+1;ua=a[fa]|0}a[C+(oa+2)|0]=ua;if((la|0)==0){ka=na;break e}oa=oa+3|0;pa=la;qa=c[s>>2]|0;ra=c[q>>2]|0}}}}while(0);if((A|0)==107){A=0;if((V-_|0)<1){va=-3}else{c[q>>2]=_+1;va=((d[_]|0)*3|0)-3|0}wa=va+X|0;if((wa|0)>(N|0)|(wa|0)<0){A=111;break c}else{ka=wa}}X=ka;Y=c[s>>2]|0;Z=c[q>>2]|0}if((S|0)==0){break a}else{O=O+y|0;P=S;Q=Y;R=$}}if((A|0)==104){KIb(c[B>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=W,c[p+8>>2]=N,p)|0);i=p;break a}else if((A|0)==111){KIb(c[B>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=wa,c[p+8>>2]=N,p)|0);i=p;break a}else if((A|0)==122){KIb(c[B>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=ja,c[p+8>>2]=N,p)|0);i=p;break a}else if((A|0)==126){KIb(c[B>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=na,c[p+8>>2]=N,p)|0);i=p;break a}break};case 1:case 33:{C=c[v>>2]|0;ba=k;aa=ca(L,y)|0;la=x-y|0;fa=J+1|0;if((fa|0)==0){break a}else{xa=la;ya=fa;za=la;Aa=u;Ba=M}f:while(1){la=Aa;if((la-Ba|0)<1){Ca=0;Da=Ba}else{fa=Ba+1|0;c[q>>2]=fa;Ca=d[Ba]|0;Da=fa}if((la-Da|0)<1){break a}fa=Da+1|0;c[q>>2]=fa;ma=a[Da]|0;Ea=(ma&255)<<24;Fa=ma<<24>>24;if(ma<<24>>24==0){break a}if((Ca&128|0)==0){Ga=za;Ha=ya;Ia=(Ca<<1)+xa|0}else{Ja=za+y|0;Ga=Ja;Ha=ya-1|0;Ia=(Ca<<1&254)+Ja|0}if((Ia|0)>(aa|0)|(Ia|0)<0){A=25;break}do{if(ma<<24>>24==-1){Ka=Ia}else{if((Ea|0)>=0){Ja=Ea>>23;La=Ia+Ja|0;if((La|0)>(aa|0)|(La|0)<0){A=38;break f}Ma=la-fa|0;Na=Ma>>>0>Ja>>>0?Ja:Ma;nrc(C+Ia|0,fa|0,Na)|0;c[q>>2]=(c[q>>2]|0)+Na;Ka=La;break}Na=-Fa|0;if((la-fa|0)<1){Oa=0;Pa=fa}else{Ma=Da+2|0;c[q>>2]=Ma;Oa=a[fa]|0;Pa=Ma}if((la-Pa|0)<1){Qa=0}else{c[q>>2]=Pa+1;Qa=a[Pa]|0}Ra=Ia+(Na<<1)|0;if((Ra|0)>(aa|0)|(Ra|0)<0){A=35;break f}else{Sa=Ia;Ta=Na}while(1){Na=Ta-1|0;a[C+Sa|0]=Oa;a[C+(Sa+1)|0]=Qa;if((Na|0)==0){break}else{Sa=Sa+2|0;Ta=Na}}Ka=Ia-(Fa<<1)|0}}while(0);if((Ha|0)==0){break a}xa=Ka;ya=Ha;za=Ga;Aa=c[s>>2]|0;Ba=c[q>>2]|0}if((A|0)==25){KIb(c[ba>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=Ia,c[p+8>>2]=aa,p)|0);i=p;break a}else if((A|0)==35){KIb(c[ba>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=Ra,c[p+8>>2]=aa,p)|0);i=p;break a}else if((A|0)==38){KIb(c[ba>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=La,c[p+8>>2]=aa,p)|0);i=p;break a}break};case 8:case 40:{C=c[v>>2]|0;N=k;B=ca(L,y)|0;if((J|0)==0){break b}else{Ua=x;Va=J;Wa=u;Xa=M}g:while(1){Fa=Va-1|0;if((Wa-Xa|0)<1){Ya=-4;Za=Xa}else{la=Xa+1|0;c[q>>2]=la;Ya=((d[Xa]|0)<<2)-4|0;Za=la}_a=Ya+Ua|0;if((_a|0)>(B|0)|(_a|0)<0){A=46;break}else{$a=_a;ab=Wa;bb=Za}h:while(1){la=ab;do{if((la-bb|0)<1){cb=bb;A=50}else{db=bb+1|0;c[q>>2]=db;fa=a[bb]|0;Ea=(fa&255)<<24;ma=fa<<24>>24;if((ma|0)==0){cb=db;A=50;break}else if((ma|0)==(-1|0)){break h}if((Ea|0)>=0){S=Ea>>22;eb=S+$a|0;if((eb|0)>(B|0)|(eb|0)<0){A=68;break g}Ea=la-db|0;V=Ea>>>0>S>>>0?S:Ea;nrc(C+$a|0,db|0,V)|0;Ea=(c[q>>2]|0)+V|0;c[q>>2]=Ea;fb=eb;gb=Ea;break}Ea=-ma|0;if((la-db|0)<1){hb=0;ib=db}else{V=bb+2|0;c[q>>2]=V;hb=a[db]|0;ib=V}if((la-ib|0)<1){jb=0;kb=ib}else{V=ib+1|0;c[q>>2]=V;jb=a[ib]|0;kb=V}if((la-kb|0)<1){lb=0;mb=kb}else{V=kb+1|0;c[q>>2]=V;lb=a[kb]|0;mb=V}if((la-mb|0)<1){nb=0;ob=mb}else{V=mb+1|0;c[q>>2]=V;nb=a[mb]|0;ob=V}pb=(Ea<<2)+$a|0;if((pb|0)>(B|0)|(pb|0)<0){A=65;break g}if(fa<<24>>24==0){fb=$a;gb=ob;break}else{qb=$a;rb=Ea}while(1){Ea=rb-1|0;a[C+qb|0]=hb;a[C+(qb+1)|0]=jb;a[C+(qb+2)|0]=lb;a[C+(qb+3)|0]=nb;if((Ea|0)==0){break}else{qb=qb+4|0;rb=Ea}}fb=$a-(ma<<2)|0;gb=c[q>>2]|0}}while(0);if((A|0)==50){A=0;if((la-cb|0)<1){sb=-4;tb=cb}else{Ea=cb+1|0;c[q>>2]=Ea;sb=((d[cb]|0)<<2)-4|0;tb=Ea}ub=sb+$a|0;if((ub|0)>(B|0)|(ub|0)<0){A=53;break g}else{fb=ub;gb=tb}}$a=fb;ab=c[s>>2]|0;bb=gb}if((Fa|0)==0){break b}else{Ua=Ua+y|0;Va=Fa;Wa=ab;Xa=db}}if((A|0)==46){KIb(c[N>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=_a,c[p+8>>2]=B,p)|0);i=p;break b}else if((A|0)==53){KIb(c[N>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=ub,c[p+8>>2]=B,p)|0);i=p;break b}else if((A|0)==65){KIb(c[N>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=pb,c[p+8>>2]=B,p)|0);i=p;break b}else if((A|0)==68){KIb(c[N>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=eb,c[p+8>>2]=B,p)|0);i=p;break b}break};case 4:case 36:{vYa(l,x,J,4);break};case 32:{C=c[v>>2]|0;aa=k;ba=ca(L,y)|0;if((J|0)==0){break a}else{vb=x;wb=J;xb=u;yb=M}i:while(1){Ea=wb-1|0;if((xb-yb|0)<1){zb=-4;Ab=yb}else{fa=yb+1|0;c[q>>2]=fa;zb=((d[yb]|0)<<2)-4|0;Ab=fa}Bb=zb+vb|0;if((Bb|0)>(ba|0)|(Bb|0)<0){A=140;break}else{Cb=Bb;Db=xb;Eb=Ab}j:while(1){fa=Db;do{if((fa-Eb|0)<1){Fb=Eb;A=145}else{Gb=Eb+1|0;c[q>>2]=Gb;V=a[Eb]|0;S=(V&255)<<24;Na=V<<24>>24;if((Na|0)==0){Fb=Gb;A=145;break}else if((Na|0)==(-1|0)){break j}if((S|0)<0){Ma=-Na|0;if((fa-Gb|0)<4){Hb=0}else{c[q>>2]=Eb+5;Ja=Gb;Hb=je(d[Ja]|d[Ja+1|0]<<8|d[Ja+2|0]<<16|d[Ja+3|0]<<24|0)|0}Ib=(Ma<<2)+Cb|0;if((Ib|0)>(ba|0)|(Ib|0)<0){A=155;break i}if(V<<24>>24==0){Jb=Cb;break}else{Kb=Cb;Lb=Ma}while(1){Ma=Lb-1|0;c[C+Kb>>2]=Hb;if((Ma|0)==0){break}else{Kb=Kb+4|0;Lb=Ma}}Jb=Cb-(Na<<2)|0;break}Mb=(S>>22)+Cb|0;if((Mb|0)>(ba|0)|(Mb|0)<0){A=159;break i}if(V<<24>>24==0){Jb=Cb;break}else{Nb=Cb;Ob=Na;Pb=Db;Qb=Gb}while(1){ma=Ob-1|0;if((Pb-Qb|0)<4){Rb=0}else{c[q>>2]=Qb+4;Ma=Qb;Rb=je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0}c[C+Nb>>2]=Rb;if((ma|0)==0){break}Nb=Nb+4|0;Ob=ma;Pb=c[s>>2]|0;Qb=c[q>>2]|0}Jb=(Na<<2)+Cb|0}}while(0);if((A|0)==145){A=0;if((fa-Fb|0)<1){Sb=-4}else{c[q>>2]=Fb+1;Sb=((d[Fb]|0)<<2)-4|0}Tb=Sb+Cb|0;if((Tb|0)>(ba|0)|(Tb|0)<0){A=149;break i}else{Jb=Tb}}Cb=Jb;Db=c[s>>2]|0;Eb=c[q>>2]|0}if((Ea|0)==0){break a}else{vb=vb+y|0;wb=Ea;xb=Db;yb=Gb}}if((A|0)==140){KIb(c[aa>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=Bb,c[p+8>>2]=ba,p)|0);i=p;break a}else if((A|0)==149){KIb(c[aa>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=Tb,c[p+8>>2]=ba,p)|0);i=p;break a}else if((A|0)==155){KIb(c[aa>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=Ib,c[p+8>>2]=ba,p)|0);i=p;break a}else if((A|0)==159){KIb(c[aa>>2]|0,16,2358408,(p=i,i=i+16|0,c[p>>2]=Mb,c[p+8>>2]=ba,p)|0);i=p;break a}break};case 16:{C=c[v>>2]|0;B=ca(L,y)|0;if((J|0)==0){break a}else{Ub=x;Vb=J;Wb=M}k:while(1){N=Vb-1|0;if((w-Wb|0)<1){Xb=-2;Yb=Wb}else{Fa=Wb+1|0;c[q>>2]=Fa;Xb=((d[Wb]|0)<<1)-2|0;Yb=Fa}Zb=Xb+Ub|0;if((Zb|0)>(B|0)|(Zb|0)<0){A=76;break}else{_b=Zb;$b=Yb}l:while(1){m:do{if((w-$b|0)<1){ac=$b}else{Fa=$b;while(1){bc=Fa+1|0;c[q>>2]=bc;la=a[Fa]|0;V=(la&255)<<24;cc=la<<24>>24;if((cc|0)==0){ac=bc;break m}else if((cc|0)==(-1|0)){break l}if((V|0)<0){S=-cc|0;if((w-bc|0)<2){dc=0;ec=bc}else{ma=Fa+3|0;c[q>>2]=ma;Ma=bc;dc=he((d[Ma]|d[Ma+1|0]<<8)<<16>>16|0)|0;ec=ma}fc=(S<<1)+_b|0;if((fc|0)>(B|0)|(fc|0)<0){A=91;break k}if(la<<24>>24==0){gc=ec}else{hc=_b;ic=S;A=92;break}}else{jc=(V>>23)+_b|0;if((jc|0)>(B|0)|(jc|0)<0){A=95;break k}if(la<<24>>24==0){gc=bc}else{kc=_b;lc=cc;mc=bc;break}}if((w-gc|0)<1){ac=gc;break m}else{Fa=gc}}if((A|0)==92){while(1){A=0;Fa=ic-1|0;b[C+hc>>1]=dc;if((Fa|0)==0){break}else{hc=hc+2|0;ic=Fa;A=92}}_b=_b-(cc<<1)|0;$b=ec;continue l}while(1){Fa=lc-1|0;if((w-mc|0)<2){nc=0;oc=mc}else{Na=mc+2|0;c[q>>2]=Na;la=mc;nc=he((d[la]|d[la+1|0]<<8)<<16>>16|0)|0;oc=Na}b[C+kc>>1]=nc;if((Fa|0)==0){break}else{kc=kc+2|0;lc=Fa;mc=oc}}_b=(cc<<1)+_b|0;$b=oc;continue l}}while(0);if((w-ac|0)<1){pc=-2;qc=ac}else{fa=ac+1|0;c[q>>2]=fa;pc=((d[ac]|0)<<1)-2|0;qc=fa}rc=pc+_b|0;if((rc|0)>(B|0)|(rc|0)<0){A=84;break k}else{_b=rc;$b=qc}}if((N|0)==0){break a}else{Ub=Ub+y|0;Vb=N;Wb=bc}}if((A|0)==76){KIb(K,16,2358408,(p=i,i=i+16|0,c[p>>2]=Zb,c[p+8>>2]=B,p)|0);i=p;break a}else if((A|0)==84){KIb(K,16,2358408,(p=i,i=i+16|0,c[p>>2]=rc,c[p+8>>2]=B,p)|0);i=p;break a}else if((A|0)==91){KIb(K,16,2358408,(p=i,i=i+16|0,c[p>>2]=fc,c[p+8>>2]=B,p)|0);i=p;break a}else if((A|0)==95){KIb(K,16,2358408,(p=i,i=i+16|0,c[p>>2]=jc,c[p+8>>2]=B,p)|0);i=p;break a}break};default:{KIb(K,16,2447688,(p=i,i=i+8|0,c[p>>2]=F,p)|0);i=p;break a}}}while(0);F=V1(h,0,0)|0;y=c[o>>2]|0;if((F|0)==0){sc=k+20|0}else{c[y+304>>2]=1;w=k+20|0;nrc(w|0,F|0,1024)|0;sc=w}nrc(c[y+4>>2]|0,sc|0,1024)|0}}while(0);sc=YHb(f,c[o>>2]|0)|0;if((sc|0)<0){t=sc;i=j;return t|0}c[g>>2]=1;t=c[n>>2]|0;i=j;return t|0}function uYa(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function vYa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;h=i;i=i+16|0;j=h|0;k=c[b+4>>2]|0;l=c[k+32>>2]|0;m=c[k>>2]|0;k=b|0;n=ca(c[(c[k>>2]|0)+124>>2]|0,l)|0;o=(g|0)==4;p=o?8:16;if((f|0)==0){i=h;return}q=b+12|0;r=b+8|0;b=p-1|0;s=(1<<g)+255|0;t=p>>>2;u=t-1|0;v=j|0;w=e;e=f;f=c[q>>2]|0;x=c[r>>2]|0;a:while(1){y=e-1|0;if((f-x|0)<1){z=-1;A=x}else{B=x+1|0;c[r>>2]=B;z=(d[x]|0)-1|0;A=B}C=(ca(z,p)|0)+w|0;if((C|0)>(n|0)|(C|0)<0){D=6;break}else{E=C;F=f;G=A}b:while(1){B=F;c:do{if((B-G|0)<1){H=G;D=10}else{I=G+1|0;c[r>>2]=I;J=a[G]|0;K=(J&255)<<24;L=J<<24>>24;if((L|0)==(-1|0)){break b}else if((L|0)==0){H=I;D=10;break}if((K|0)<0){M=b;N=I;while(1){O=B-N|0;if((O|0)<1){P=0}else{P=d[N]|0}a[j+(b-M)|0]=P>>>(((ca(M,g)|0)&7)>>>0)&s;Q=(M&u|0)==0|0;R=N+(O>>>0>Q>>>0?Q:O)|0;c[r>>2]=R;if((M|0)>0){M=M-1|0;N=R}else{break}}N=-L|0;S=(ca(p,N)|0)+E|0;if((S|0)>(n|0)|(S|0)<0){D=22;break a}if(J<<24>>24==0){T=E;break}M=ca(p,L)|0;R=E;O=N;while(1){N=O-1|0;nrc(m+R|0,v|0,p)|0;if((N|0)==0){break}else{R=R+p|0;O=N}}T=E-M|0;break}O=K>>22;U=(ca(O,t)|0)+E|0;if((U|0)>(n|0)|(U|0)<0){D=31;break a}R=O-1|0;if((O|0)==0){T=E;break}if(o){O=E;L=R;J=F;N=I;while(1){if((J-N|0)<1){V=0;W=0}else{c[r>>2]=N+1;Q=a[N]|0;V=(Q&255)>>>4;W=Q&15}a[m+O|0]=V;Q=O+2|0;a[m+(O+1)|0]=W;if((L|0)==0){T=Q;break c}O=Q;L=L-1|0;J=c[q>>2]|0;N=c[r>>2]|0}}else{N=E;J=R;L=F;O=I;while(1){if((L-O|0)<1){X=0;Y=0;Z=0;_=0}else{c[r>>2]=O+1;K=a[O]|0;X=(K&255)>>>6;Y=(K&255)>>>4&3;Z=(K&255)>>>2&3;_=K&3}a[m+N|0]=X;a[m+(N+1)|0]=Y;a[m+(N+2)|0]=Z;K=N+4|0;a[m+(N+3)|0]=_;if((J|0)==0){T=K;break c}N=K;J=J-1|0;L=c[q>>2]|0;O=c[r>>2]|0}}}}while(0);if((D|0)==10){D=0;if((B-H|0)<1){$=-1}else{c[r>>2]=H+1;$=(d[H]|0)-1|0}aa=(ca($,p)|0)+E|0;if((aa|0)>(n|0)|(aa|0)<0){D=14;break a}else{T=aa}}E=T;F=c[q>>2]|0;G=c[r>>2]|0}if((y|0)==0){D=37;break}else{w=w+l|0;e=y;f=F;x=I}}if((D|0)==6){KIb(c[k>>2]|0,16,2358408,(ba=i,i=i+16|0,c[ba>>2]=C,c[ba+8>>2]=n,ba)|0);i=ba;i=h;return}else if((D|0)==14){KIb(c[k>>2]|0,16,2358408,(ba=i,i=i+16|0,c[ba>>2]=aa,c[ba+8>>2]=n,ba)|0);i=ba;i=h;return}else if((D|0)==22){KIb(c[k>>2]|0,16,2358408,(ba=i,i=i+16|0,c[ba>>2]=S,c[ba+8>>2]=n,ba)|0);i=ba;i=h;return}else if((D|0)==31){KIb(c[k>>2]|0,16,2358408,(ba=i,i=i+16|0,c[ba>>2]=U,c[ba+8>>2]=n,ba)|0);i=ba;i=h;return}else if((D|0)==37){i=h;return}}function wYa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;d=a+60|0;e=c[d>>2]|0;f=a+120|0;g=a+124|0;h=a;if((tIb(c[f>>2]|0,c[g>>2]|0,0,h)|0)<0){j=-22;i=b;return j|0}k=e;c[k>>2]=a;l=e+76|0;c[l>>2]=c[f>>2];m=a+140|0;n=c[m>>2]|0;if((n|0)==8){c[l>>2]=(c[f>>2]|0)/4|0;c[e+4>>2]=4;o=40}else if((n|0)==27){c[e+4>>2]=4;p=8}else if((n|0)==2){c[e+4>>2]=3;p=8}else if((n|0)==45){c[e+4>>2]=2;p=8}else{KIb(h,16,2447656,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;if((c[m>>2]|0)==8){o=40}else{p=8}}if((p|0)==8){o=c[e+4>>2]<<3}c[a+792>>2]=o;o=e+80|0;c[o>>2]=pJb(c[l>>2]|0)|0;p=e+88|0;c[p>>2]=pJb(c[l>>2]|0)|0;n=pJb((c[l>>2]<<2)+4|0)|0;c[e+84>>2]=n;do{if(!((c[p>>2]|0)==0|(n|0)==0)){if((c[o>>2]|0)==0){break}r=d2(e+8|0,c[m>>2]|0,c[f>>2]|0,c[g>>2]|0)|0;if((r|0)<0){KIb(h,16,2294920,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=r;i=b;return j|0}r=c[l>>2]|0;s=c[(c[k>>2]|0)+124>>2]|0;c[e+72>>2]=((r|0)/127|0)+16+((ca(ca(s,r)|0,c[e+4>>2]|0)|0)+s<<1);s=UHb()|0;r=a+804|0;c[r>>2]=s;if((s|0)!=0){j=0;i=b;return j|0}s=c[d>>2]|0;VHb(r);e2(s+8|0);kJb(c[s+80>>2]|0);kJb(c[s+84>>2]|0);kJb(c[s+88>>2]|0);j=-12;i=b;return j|0}}while(0);KIb(h,16,2358376,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;j=-12;i=b;return j|0}function xYa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;h=c[b+60>>2]|0;i=c[b+804>>2]|0;j=d5a(b,e,c[h+72>>2]|0,0)|0;if((j|0)<0){k=j;return k|0}j=c[b+136>>2]|0;l=c[h>>2]|0;do{if((j|0)==0){m=4}else{if(((c[l+428>>2]|0)%(j|0)|0|0)==0){m=4;break}c[i+88>>2]=2;c[i+84>>2]=0}}while(0);if((m|0)==4){c[i+88>>2]=1;c[i+84>>2]=1}j=c[e+24>>2]|0;n=h;do{if((c[(c[l+804>>2]|0)+84>>2]|0)==0){o=ca(c[h+4>>2]|0,c[h+76>>2]|0)|0;p=f|0;q=c[l+124>>2]|0;r=f+32|0;s=h+8|0;t=h+40|0;u=0;while(1){if((u|0)>=(q|0)){v=q;break}w=(c[p>>2]|0)+(ca(c[r>>2]|0,u)|0)|0;if((grc(w,(c[s>>2]|0)+(ca(c[t>>2]|0,u)|0)|0,o)|0)==0){u=u+1|0}else{v=q;break}}while(1){if((v|0)<=(u|0)){break}q=v-1|0;w=(c[p>>2]|0)+(ca(c[r>>2]|0,q)|0)|0;if((grc(w,(c[s>>2]|0)+(ca(c[t>>2]|0,q)|0)|0,o)|0)==0){v=q}else{break}}o=j;y=0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;t=j+4|0;if((u|0)==0){x=v;z=o;A=t;m=15;break}B=v;C=u;D=o;E=t;F=c[(c[n>>2]|0)+124>>2]|0;m=16}else{t=c[l+124>>2]|0;o=j;y=0;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;x=t;z=o;A=j+4|0;m=15}}while(0);if((m|0)==15){l=c[(c[n>>2]|0)+124>>2]|0;if((x|0)==(l|0)){G=x;H=0;I=z;J=A;m=17}else{B=x;C=0;D=z;E=A;F=l;m=16}}do{if((m|0)==16){if((C|0)==(F|0)){G=B;H=F;I=D;J=E;m=17;break}l=E;y=2048;a[l]=y;y=y>>8;a[l+1|0]=y;l=E+2|0;y=he(C&65535|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;l=E+4|0;y=0;a[l]=y;y=y>>8;a[l+1|0]=y;l=E+6|0;y=he(B-C&65535|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;l=E+8|0;y=0;a[l]=y;y=y>>8;a[l+1|0]=y;K=C;L=E+10|0;M=B;N=D}}while(0);if((m|0)==17){D=J;y=0;a[D]=y;y=y>>8;a[D+1|0]=y;K=H;L=J+2|0;M=G;N=I}if((K|0)<(M|0)){I=h+76|0;G=f|0;J=f+32|0;H=h+4|0;D=h+8|0;B=D;E=h+40|0;C=h+84|0;F=h+88|0;l=h+80|0;A=L;z=K;while(1){K=c[I>>2]|0;x=c[G>>2]|0;v=c[J>>2]|0;o=K-1|0;t=ca(c[H>>2]|0,o)|0;s=c[B>>2]|0;r=c[E>>2]|0;c[(c[C>>2]|0)+(K<<2)>>2]=0;if((K|0)>0){p=ca(r,z)|0;r=ca(v,z)|0;v=c[H>>2]|0;q=0;w=0;O=v+1|0;P=1073741823;Q=K;R=1073741823;S=K;T=x+(t+r)|0;r=s+(p+t)|0;t=o;p=v;while(1){v=t+127|0;s=(((K|0)>(v|0)?v:K)|0)<(Q|0);v=s?R:P;U=s?S:Q;V=s?1073741823:R;W=s?K:S;s=(t|0)==0;if(s){X=V+1|0;Y=v+1|0;Z=O+1|0}else{X=V;Y=v;Z=O}v=t+1|0;V=c[C>>2]|0;_=(c[V+(v<<2)>>2]|0)+Z|0;if((_|0)>(X|0)){$=W;aa=X;ba=U;da=Y}else{ea=(_|0)>(Y|0);$=ea?v:W;aa=ea?_:1073741823;ba=ea?U:v;da=ea?Y:_}do{if((c[(c[(c[n>>2]|0)+804>>2]|0)+84>>2]|0)==0){if((grc(T,r,p)|0)!=0){fa=0;break}_=q+1|0;fa=_>>>0>254>>>0?254:_}else{fa=0}}while(0);_=c[V+(fa+t<<2)>>2]|0;ea=_+2|0;a[(c[F>>2]|0)+t|0]=fa;v=c[H>>2]|0;do{if((t|0)<(o|0)){if((grc(T,T+v|0,v)|0)!=0){ga=1;break}U=w+1|0;ga=U>>>0>128>>>0?128:U}else{ga=1}}while(0);V=c[C>>2]|0;U=v+1+(c[V+(ga+t<<2)>>2]|0)|0;if(s){ha=U+1|0;ia=_+1|0}else{ha=U;ia=ea}do{if(ga>>>0>1>>>0){if(!((fa|0)==0|(ha|0)<(ia|0))){m=39;break}c[V+(t<<2)>>2]=ha;a[(c[l>>2]|0)+t|0]=-ga}else{m=39}}while(0);do{if((m|0)==39){m=0;ea=V+(t<<2)|0;if((fa|0)==0){c[ea>>2]=da;a[(c[l>>2]|0)+t|0]=ba-t;break}else{c[ea>>2]=ia;a[(c[l>>2]|0)+t|0]=0;break}}}while(0);V=c[H>>2]|0;ea=-V|0;if((t|0)>0){q=fa;w=ga;O=Z;P=V+da|0;Q=ba;R=V+aa|0;S=$;T=T+ea|0;r=r+ea|0;t=t-1|0;p=V}else{break}}ja=c[G>>2]|0}else{ja=x}p=ca(c[J>>2]|0,z)|0;if((a[c[l>>2]|0]|0)==0){a[A]=(a[c[F>>2]|0]|0)+1;ka=d[c[F>>2]|0]|0}else{a[A]=1;ka=0}t=A+1|0;if((ka|0)<(K|0)){r=ka;T=t;while(1){S=a[(c[l>>2]|0)+r|0]|0;R=S<<24>>24;a[T]=S;Q=T+1|0;do{if(S<<24>>24==0){a[Q]=(a[(c[F>>2]|0)+r|0]|0)+1;la=(d[(c[F>>2]|0)+r|0]|0)+r|0;ma=T+2|0}else{P=(c[(c[n>>2]|0)+140>>2]|0)==8;O=c[H>>2]|0;if(S<<24>>24>0){do{if(P){if((ca(O,R)|0)>0){na=0;oa=O;pa=Q}else{qa=Q;break}while(1){a[pa]=~a[ja+(na+p+(ca(oa,r)|0))|0];w=pa+1|0;q=na+1|0;o=c[H>>2]|0;if((q|0)<(ca(o,R)|0)){na=q;oa=o;pa=w}else{qa=w;break}}}else{w=ca(O,R)|0;nrc(Q|0,ja+((ca(O,r)|0)+p)|0,w)|0;qa=T+(w+1)|0}}while(0);la=R+r|0;ma=qa;break}else{do{if(P){if((O|0)>0){ra=0;sa=O;ta=Q}else{ua=Q;break}while(1){a[ta]=~a[ja+(ra+p+(ca(sa,r)|0))|0];w=ta+1|0;o=ra+1|0;q=c[H>>2]|0;if((o|0)<(q|0)){ra=o;sa=q;ta=w}else{ua=w;break}}}else{nrc(Q|0,ja+((ca(O,r)|0)+p)|0,O)|0;ua=T+(O+1)|0}}while(0);la=r-R|0;ma=ua;break}}}while(0);if((la|0)<(K|0)){r=la;T=ma}else{va=ma;break}}}else{va=t}a[va]=-1;T=va+1|0;r=z+1|0;if((r|0)<(M|0)){A=T;z=r}else{wa=T;xa=D;break}}}else{wa=L;xa=h+8|0}a[wa]=0;h=wa+1-j|0;y=je(h|0)|0;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[e+28>>2]=h;f2(xa,f,c[b+140>>2]|0,c[b+120>>2]|0,c[b+124>>2]|0);if((c[i+84>>2]|0)!=0){i=e+36|0;c[i>>2]=c[i>>2]|1}c[g>>2]=1;k=0;return k|0}function yYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(a+804|0);e2(b+8|0);kJb(c[b+80>>2]|0);kJb(c[b+84>>2]|0);kJb(c[b+88>>2]|0);return 0}function zYa(a){a=a|0;c[a+140>>2]=42;c[a+796>>2]=10;return 0}function AYa(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;h=c[f+24>>2]|0;j=a+120|0;k=a+48|0;l=(c[k>>2]|0)==146?1:64;m=(c[j>>2]|0)-1+l&-l;l=f+28|0;f=a+124|0;if((c[l>>2]|0)<(ca(c[f>>2]<<2,m)|0)){KIb(a,16,2202384,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=g;return o|0}n=M4a(a,d,0)|0;if((n|0)<0){o=n;i=g;return o|0}c[d+88>>2]=1;c[d+84>>2]=1;n=c[f>>2]|0;if((n|0)>0){f=c[j>>2]|0;j=(f|0)>0;a=c[d+32>>2]|0;p=0;q=h;h=c[d>>2]|0;while(1){d=h;if(j){r=c[k>>2]|0;s=(f|0)>1?f:1;if((r|0)==1096176208){t=0;u=q;v=d;while(1){w=c[u>>2]|0;b[v>>1]=w>>>16&65535&-64|w>>>26&65535;b[v+2>>1]=w>>>6&65535&-64|w>>>16&63;b[v+4>>1]=w>>>6&63|w<<4&65535;w=t+1|0;if((w|0)<(f|0)){t=w;u=u+4|0;v=v+6|0}else{break}}}else{v=0;u=q;t=d;w=r;while(1){x=je(c[u>>2]|0)|0;if((w|0)==134){y=x<<6&65535;z=x>>>4&65535;A=134;B=x>>>14&65535}else{y=x<<4&65535;z=x>>>6&65535;A=w;B=x>>>16&65535}b[t>>1]=B&-64|(B&65535)>>>10;b[t+2>>1]=z&-64|(z&65535)>>>10;b[t+4>>1]=(y&65535)>>>10|y;x=v+1|0;if((x|0)<(f|0)){v=x;u=u+4|0;t=t+6|0;w=A}else{break}}}C=q+(s<<2)|0}else{C=q}w=p+1|0;if((w|0)<(n|0)){p=w;q=C+(m-f<<2)|0;h=h+a|0}else{break}}}c[e>>2]=1;o=c[l>>2]|0;i=g;return o|0}function BYa(a){a=a|0;var b=0;b=UHb()|0;c[a+804>>2]=b;return((b|0)==0?-12:0)|0}function CYa(b,d,f,g){b=b|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0;h=b+120|0;i=c[h>>2]|0;j=b+48|0;k=(c[j>>2]|0)==146?1:64;l=i-1+k&-k;k=l-i<<2;i=b+124|0;m=ca(c[i>>2]<<2,l)|0;l=d5a(b,d,m,(m|0)<0|0?-1:0)|0;if((l|0)<0){n=l;return n|0}l=c[b+804>>2]|0;c[l+84>>2]=1;c[l+88>>2]=1;if((c[i>>2]|0)>0){l=f+32|0;b=c[d+24>>2]|0;m=c[f>>2]|0;f=0;while(1){if((c[h>>2]|0)>0){o=b;p=m;q=0;while(1){r=(e[p+2>>1]|0)>>>6;s=p+6|0;t=(e[p+4>>1]|0)>>>4;u=c[j>>2]|0;v=(e[p>>1]|0)>>>6&65535;do{if((u|0)==134){w=(r&65535)<<10|v<<20|(t&65535)>>>2;x=10}else{z=(r&65535)<<12|v<<22|t&65535;if((u|0)!=1096176208){w=z;x=10;break}A=o;y=z;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y}}while(0);if((x|0)==10){x=0;u=o;y=je(w|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y}u=o+4|0;t=q+1|0;if((t|0)<(c[h>>2]|0)){o=u;p=s;q=t}else{B=u;break}}}else{B=b}mrc(B|0,0,k|0)|0;q=f+1|0;if((q|0)<(c[i>>2]|0)){b=B+k|0;m=m+(c[l>>2]|0)|0;f=q}else{break}}}f=d+36|0;c[f>>2]=c[f>>2]|1;c[g>>2]=1;n=0;return n|0}function DYa(a){a=a|0;mJb(a+804|0);return 0}function EYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;l8(b+4|0,a);c[b+1388>>2]=b+1308;c[b+1392>>2]=b+1348;c[a+416>>2]=1;b=a+448|0;c[b>>2]=4;c[b+4>>2]=0;c[a+420>>2]=1;return 0}function FYa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=i;i=i+136|0;j=h|0;k=h+16|0;l=h+96|0;m=c[g+24>>2]|0;n=c[g+28>>2]|0;g=c[a+60>>2]|0;o=g;if((n|0)<20){KIb(a,16,2447584,(p=i,i=i+8|0,c[p>>2]=n,p)|0);i=p;c[f>>2]=0;q=-1094995529;i=h;return q|0}c[e+76>>2]=160;p=M4a(a,e,0)|0;if((p|0)<0){q=p;i=h;return q|0}p=c[e>>2]|0;e=(m|0)==0?8:168;a=0;n=0;do{r=d[682776+n|0]|0;s=m+(a>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(a&7)>>>((32-r|0)>>>0);s=r+a|0;a=e>>>0>s>>>0?s:e;c[l+(n<<2)>>2]=b[(c[1359624+(n<<2)>>2]|0)+(t<<1)>>1]|0;n=n+1|0;}while((n|0)<10);n=g+1388|0;t=l|0;Trb(c[n>>2]|0,t);l=g+1396|0;c[l>>2]=Wrb(t)|0;t=m+(a>>>3)|0;s=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(a&7)>>>27;t=a+5|0;a=b[1391008+(s<<1)>>1]|0;s=g+1304|0;r=Xrb(o,k|0,1,1,c[s>>2]|0)|0;c[j>>2]=r;u=c[s>>2]|0;c[j+4>>2]=Xrb(o,k+20|0,2,a>>>0<=u>>>0|0,(Vrb(ca(u,a)|0)|0)>>12)|0;c[j+8>>2]=Xrb(o,k+40|0,3,0,a)|0;c[j+12>>2]=Yrb(c[l>>2]|0,a)|0;Urb(k+60|0,c[n>>2]|0);u=g+1724|0;v=e>>>0>t>>>0?t:e;t=p;p=0;w=r;while(1){r=m+(v>>>3)|0;x=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(v&7)>>>25;r=v+7|0;y=e>>>0>r>>>0?r:e;r=m+(y>>>3)|0;z=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(y&7)>>>24;r=y+8|0;y=e>>>0>r>>>0?r:e;r=m+(y>>>3)|0;A=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(y&7)>>>25;r=y+7|0;y=e>>>0>r>>>0?r:e;r=m+(y>>>3)|0;B=y+7|0;C=e>>>0>B>>>0;_rb(o,k+(p*20|0)|0,x,A,(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(y&7)>>>25,w,z);z=t;y=0;while(1){r=b[u+(y+10<<1)>>1]|0;A=r<<2;if((A+32768|0)>>>0>65535>>>0){D=(r>>29^32767)&65535}else{D=A&65535}b[z>>1]=D;A=y+1|0;if((A|0)<40){z=z+2|0;y=A}else{break}}y=p+1|0;if((y|0)>=4){break}v=C?B:e;t=t+80|0;p=y;w=c[j+(y<<2)>>2]|0}c[s>>2]=a;c[g+1400>>2]=c[l>>2];l=g+1392|0;g=c[l>>2]|0;c[l>>2]=c[n>>2];c[n>>2]=g;c[f>>2]=1;q=20;i=h;return q|0}function GYa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+416>>2]|0;if((d|0)!=1){KIb(a,16,2294880,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;f=-1;i=b;return f|0}e=a+424|0;c[e>>2]=160;c[a+116>>2]=160;c[a+72>>2]=8e3;d=a+60|0;g=c[d>>2]|0;c[g+1388>>2]=g+1308;c[g+1392>>2]=g+1348;c[g>>2]=a;l8(g+4|0,a);h=rPa(g+1248|0,c[e>>2]|0,10,2)|0;if((h|0)<0){e=c[d>>2]|0;qPa(e+1248|0);Emb(e+1276|0);f=h;i=b;return f|0}else{Dmb(a,g+1276|0);f=0;i=b;return f|0}return 0}function HYa(f,h,j,k){f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0.0,ta=0.0,ua=0.0,va=0,wa=0,xa=0,ya=0.0,za=0.0,Aa=0.0,Ba=0.0,Ca=0.0,Da=0,Ea=0.0,Fa=0.0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0.0,Qa=0.0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;l=i;i=i+3640|0;m=l|0;n=l+8|0;o=l+168|0;p=l+328|0;q=l+488|0;r=l+648|0;s=l+848|0;t=l+888|0;u=l+1048|0;v=l+1208|0;w=l+1368|0;x=l+1528|0;z=l+1536|0;A=l+1544|0;B=l+2184|0;C=l+3464|0;D=l+3504|0;E=l+3584|0;F=l+3624|0;G=c[f+60>>2]|0;H=G;I=(j|0)!=0;if(I){J=c[j>>2]|0}else{J=0}K=G+1300|0;if((c[K>>2]|0)!=0){L=0;i=l;return L|0}M=d5a(f,h,20,0)|0;if((M|0)<0){L=M;i=l;return L|0}M=G+1404|0;N=M;O=0;P=0;do{Q=b[N+(O+60<<1)>>1]|0;c[A+(O<<2)>>2]=Q;P=((ca(Q,Q)|0)>>>4)+P|0;O=O+1|0;}while((O|0)<100);do{if(I){O=c[j+76>>2]|0;if((O|0)<=0){R=100;S=P;T=12;break}Q=(O|0)>1?-O|0:-1;U=Q>>>0>4294967236>>>0;V=100;W=P;X=0;do{Y=b[J+(X<<1)>>1]>>2;c[A+(V<<2)>>2]=Y;W=((ca(Y,Y)|0)>>>4)+W|0;V=V+1|0;X=X+1|0;}while((X|0)<(O|0)&(V|0)<160);V=U?100-Q|0:160;if((V|0)<160){R=V;S=W;T=12}else{Z=W}}else{R=100;S=P;T=12}}while(0);if((T|0)==12){mrc(A+(R<<2)|0,0,160-R<<2|0)|0;Z=S}S=(Vrb(Z>>5)|0)>>10;Z=b[695519]|0;R=31;T=0;P=15;V=Z-S|0;do{O=(V|0)>0;R=O?P:R;T=O?T:P;P=(R+T|0)>>>1;V=(b[1391008+(P<<1)>>1]|0)-S|0;}while((P|0)!=(T|0));P=b[1391008+((((b[1391008+(R<<1)>>1]|0)+V|0)>(S|0)?T:R)<<1)>>1]|0;pPa(G+1248|0,A|0,160,10,10,16,B|0,C|0,2,0,0,12,0)|0;A=12-(c[C+36>>2]|0)|0;C=D+60|0;b[C>>1]=-(c[B+1152>>2]<<A);b[D+62>>1]=-(c[B+1156>>2]<<A);b[D+64>>1]=-(c[B+1160>>2]<<A);b[D+66>>1]=-(c[B+1164>>2]<<A);b[D+68>>1]=-(c[B+1168>>2]<<A);b[D+70>>1]=-(c[B+1172>>2]<<A);b[D+72>>1]=-(c[B+1176>>2]<<A);b[D+74>>1]=-(c[B+1180>>2]<<A);b[D+76>>1]=-(c[B+1184>>2]<<A);b[D+78>>1]=-(c[B+1188>>2]<<A);A=P<<16>>16;P=E|0;do{if((Srb(P,C,f)|0)!=0){Urb(C,c[G+1392>>2]|0);if((Srb(P,C,f)|0)==0){break}mrc(E|0,0,40)|0}}while(0);B=h+28|0;R=0;T=(c[B>>2]|0)<0?0:c[h+24>>2]|0;S=32;V=0;O=0;while(1){X=E+(V<<2)|0;Y=c[X>>2]|0;_=c[1359624+(V<<2)>>2]|0;$=(d[682744+V|0]|0)-1|0;aa=$>>>1;ba=(b[_+(aa<<1)>>1]|0)-Y|0;if((aa|0)==0){da=$;ea=0;fa=ba}else{ga=$;$=0;ha=aa;aa=ba;while(1){ba=(aa|0)>0;ia=ba?ha:ga;ja=ba?$:ha;ba=(ia+ja|0)>>>1;ka=(b[_+(ba<<1)>>1]|0)-Y|0;if((ba|0)==(ja|0)){da=ia;ea=ja;fa=ka;break}else{ga=ia;$=ja;ha=ba;aa=ka}}}aa=((b[_+(da<<1)>>1]|0)+fa|0)>(Y|0)?ea:da;ha=d[682760+V|0]|0;if((S|0)>(ha|0)){la=S;ma=aa|O<<ha;na=T}else{$=T;y=je(aa>>>((ha-S|0)>>>0)|O<<S|0)|0;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;la=S+32|0;ma=aa;na=T+4|0}oa=la-ha|0;R=ma;c[X>>2]=b[_+(aa<<1)>>1]|0;aa=V+1|0;if((aa|0)<10){T=na;S=oa;V=aa;O=ma}else{break}}O=G+1396|0;c[O>>2]=Wrb(P)|0;V=G+1388|0;Trb(c[V>>2]|0,P);P=G+1304|0;c[F>>2]=Xrb(H,D|0,1,1,c[P>>2]|0)|0;S=c[P>>2]|0;c[F+4>>2]=Xrb(H,D+20|0,2,A>>>0<=S>>>0|0,(Vrb(ca(S,A)|0)|0)>>12)|0;c[F+8>>2]=Xrb(H,D+40|0,3,0,A)|0;c[F+12>>2]=Yrb(c[O>>2]|0,A)|0;Urb(C,c[V>>2]|0);C=31;S=0;T=15;la=Z-A|0;do{Z=(la|0)>0;C=Z?T:C;S=Z?S:T;T=(C+S|0)>>>1;la=(b[1391008+(T<<1)>>1]|0)-A|0;}while((T|0)!=(S|0));T=((b[1391008+(C<<1)>>1]|0)+la|0)>(A|0)?S:C;if((oa|0)>5){pa=oa-5|0;qa=T|ma<<5;ra=na}else{C=na;y=je(T>>>((5-oa|0)>>>0)|ma<<oa|0)|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;pa=oa+27|0;qa=T;ra=na+4|0}R=qa;na=M;M=q;T=r;oa=t;C=u;ma=v;S=w;la=r+40|0;Z=s|0;da=q|0;ea=la;fa=p;E=p|0;aa=G+1824|0;ha=G+2128|0;$=G+4|0;ga=n;W=n|0;n=v|0;Q=w|0;U=o|0;ka=ra;ra=pa;pa=0;ba=qa;while(1){qa=pa*40|0;ja=c[F+(pa<<2)>>2]|0;mrc(M|0,0,160)|0;ia=0;do{g[r+(ia<<2)>>2]=+(b[H+1724+(ia+40<<1)>>1]|0);g[s+(ia<<2)>>2]=+(b[D+(pa*20|0)+(ia<<1)>>1]|0)*.000244140625;ia=ia+1|0;}while((ia|0)<10);M3(la,Z,da,40,10);nrc(oa|0,ea|0,160)|0;ia=0;do{g[q+(ia<<2)>>2]=+(b[na+(ia+qa<<1)>>1]|0)- +g[r+(ia+10<<2)>>2];ia=ia+1|0;}while((ia|0)<40);mrc(T|0,0,40)|0;sa=0.0;ia=20;_=0;ta=0.0;ua=0.0;while(1){X=146-ia|0;Y=(ia|0)<40;va=Y?ia:40;if((va|0)>0){wa=0;do{g[p+(wa<<2)>>2]=+(b[H+1824+(wa+X<<1)>>1]|0);wa=wa+1|0;}while((wa|0)<(va|0))}do{if(Y){va=40-ia|0;if((va|0)>0){xa=0}else{break}do{g[p+(xa+ia<<2)>>2]=+(b[H+1824+(xa+X<<1)>>1]|0);xa=xa+1|0;}while((xa|0)<(va|0))}}while(0);M3(la,Z,E,40,10);ya=0.0;za=0.0;X=0;do{Aa=+g[r+(X+10<<2)>>2];za=za+Aa*Aa;ya=ya+Aa*+g[q+(X<<2)>>2];X=X+1|0;}while((X|0)<40);if(ya>0.0){Aa=ya/za;Ba=ya*Aa;Ca=Aa}else{Ba=0.0;Ca=sa}X=Ba>ta;Da=X?ia:_;Ea=X?Ba:ta;Fa=X?Ca:ua;X=ia+1|0;if((X|0)<147){sa=Ca;ia=X;_=Da;ta=Ea;ua=Fa}else{break}}_=D+(pa*20|0)|0;do{if(Ea!=0.0){ia=146-Da|0;X=(Da|0)<40;Y=X?Da:40;if((Y|0)>0){va=0;do{g[p+(va<<2)>>2]=+(b[H+1824+(va+ia<<1)>>1]|0);va=va+1|0;}while((va|0)<(Y|0))}do{if(X){Y=40-Da|0;if((Y|0)>0){Ga=0}else{break}do{g[p+(Ga+Da<<2)>>2]=+(b[H+1824+(Ga+ia<<1)>>1]|0);Ga=Ga+1|0;}while((Ga|0)<(Y|0))}}while(0);M3(la,Z,E,40,10);ia=0;do{X=q+(ia<<2)|0;g[X>>2]=+g[X>>2]-Fa*+g[r+(ia+10<<2)>>2];ia=ia+1|0;}while((ia|0)<40);ia=Da-19|0;if((ia|0)==0){Ha=0;Ia=0;Ja=0;break}nrc(C|0,ea|0,160)|0;Rrb(ha,aa,Da);Ha=(ca(Zrb($,ha)|0,ja)|0)>>>12;Ia=ia;Ja=1}else{Ha=0;Ia=0;Ja=0}}while(0);if(Ja){nrc(fa|0,ea|0,160)|0}ia=Ja?E:0;JYa(la,Z,1418352,ia,0,da,x,m);ya=+g[m>>2];X=c[x>>2]|0;if(ya!=0.0){Y=0;do{g[o+(Y<<2)>>2]=+(a[1418352+(X*40|0)+Y|0]|0);Y=Y+1|0;}while((Y|0)<40);M3(la,Z,U,40,10);if(Ja){Y=0;za=0.0;ua=0.0;do{ta=+g[p+(Y<<2)>>2];za=za+ +g[r+(Y+10<<2)>>2]*ta;ua=ua+ta*ta;Y=Y+1|0;}while((Y|0)<40);ta=za/ua;Y=0;while(1){va=r+(Y+10<<2)|0;g[va>>2]=+g[va>>2]-ta*+g[p+(Y<<2)>>2];va=Y+1|0;if((va|0)<40){Y=va}else{Ka=0;break}}}else{Ka=0}do{Y=q+(Ka<<2)|0;g[Y>>2]=+g[Y>>2]-ya*+g[r+(Ka+10<<2)>>2];Ka=Ka+1|0;}while((Ka|0)<40);nrc(ga|0,ea|0,160)|0;La=W}else{La=0}JYa(la,Z,1412976,ia,La,da,z,m);Y=c[z>>2]|0;va=0;do{g[v+(va<<2)>>2]=+(a[1418352+(X*40|0)+va|0]|0);g[w+(va<<2)>>2]=+(a[1412976+(Y*40|0)+va|0]|0);va=va+1|0;}while((va|0)<40);M3(la,Z,n,40,10);nrc(ma|0,ea|0,160)|0;va=(ca(e[1423472+(X<<1)>>1]|0,ja)|0)>>>8;M3(la,Z,Q,40,10);nrc(S|0,ea|0,160)|0;ia=(ca(e[1418096+(Y<<1)>>1]|0,ja)|0)>>>8;wa=0;Ma=0;ya=3.4028234663852886e+38;while(1){Na=ca(b[1383370+(wa*6|0)>>1]|0,va)|0;Oa=d[1384904+wa|0]|0;ta=+(Na>>>(Oa>>>0)>>>0>>>0)*.000244140625;ua=+((ca(b[1383372+(wa*6|0)>>1]|0,ia)|0)>>>(Oa>>>0)>>>0>>>0)*.000244140625;if(Ja){za=+((ca(b[1383368+(wa*6|0)>>1]|0,Ha)|0)>>>(Oa>>>0)>>>0>>>0)*.000244140625;Oa=0;sa=0.0;while(1){Aa=+g[t+(Oa<<2)>>2]+za*+g[u+(Oa<<2)>>2]+ta*+g[v+(Oa<<2)>>2]+ua*+g[w+(Oa<<2)>>2];g[q+(Oa<<2)>>2]=Aa;Pa=Aa- +(b[na+(Oa+qa<<1)>>1]|0);Aa=sa+Pa*Pa;Na=Oa+1|0;if((Na|0)<40){Oa=Na;sa=Aa}else{Qa=Aa;break}}}else{Oa=0;sa=0.0;while(1){za=+g[t+(Oa<<2)>>2]+ta*+g[v+(Oa<<2)>>2]+ua*+g[w+(Oa<<2)>>2];g[q+(Oa<<2)>>2]=za;Aa=za- +(b[na+(Oa+qa<<1)>>1]|0);za=sa+Aa*Aa;Na=Oa+1|0;if((Na|0)<40){Oa=Na;sa=za}else{Qa=za;break}}}Oa=Qa<ya;Ra=Oa?wa:Ma;Na=wa+1|0;if((Na|0)<256){wa=Na;Ma=Ra;ya=Oa?Qa:ya}else{break}}if((ra|0)>7){Sa=ra-7|0;Ta=ba<<7|Ia;Ua=ka}else{Ma=ka;y=je(ba<<ra|Ia>>>((7-ra|0)>>>0)|0)|0;a[Ma]=y;y=y>>8;a[Ma+1|0]=y;y=y>>8;a[Ma+2|0]=y;y=y>>8;a[Ma+3|0]=y;Sa=ra+25|0;Ta=Ia;Ua=ka+4|0}R=Ta;if((Sa|0)>8){Va=Sa-8|0;Wa=Ta<<8|Ra;Xa=Ua}else{Ma=Ua;y=je(Ra>>>((8-Sa|0)>>>0)|Ta<<Sa|0)|0;a[Ma]=y;y=y>>8;a[Ma+1|0]=y;y=y>>8;a[Ma+2|0]=y;y=y>>8;a[Ma+3|0]=y;Va=Sa+24|0;Wa=Ra;Xa=Ua+4|0}R=Wa;if((Va|0)>7){Ya=Va-7|0;Za=Wa<<7|X;_a=Xa}else{Ma=Xa;y=je(X>>>((7-Va|0)>>>0)|Wa<<Va|0)|0;a[Ma]=y;y=y>>8;a[Ma+1|0]=y;y=y>>8;a[Ma+2|0]=y;y=y>>8;a[Ma+3|0]=y;Ya=Va+25|0;Za=X;_a=Xa+4|0}R=Za;if((Ya|0)>7){$a=Ya-7|0;ab=Za<<7|Y;bb=_a}else{Ma=_a;y=je(Y>>>((7-Ya|0)>>>0)|Za<<Ya|0)|0;a[Ma]=y;y=y>>8;a[Ma+1|0]=y;y=y>>8;a[Ma+2|0]=y;y=y>>8;a[Ma+3|0]=y;$a=Ya+25|0;ab=Y;bb=_a+4|0}R=ab;_rb(H,_,Ia,X,Y,ja,Ra);Ma=pa+1|0;if((Ma|0)<4){ka=bb;ra=$a;pa=Ma;ba=ab}else{break}}if(($a|0)<32){ba=ab<<$a;R=ba;ab=ba>>>24&255;ba=$a;$a=bb;while(1){a[$a]=ab;bb=R;R=bb<<8;pa=ba+8|0;if((pa|0)<32){ab=bb>>>16&255;ba=pa;$a=$a+1|0}else{break}}}R=0;c[P>>2]=A;c[G+1400>>2]=c[O>>2];O=G+1392|0;A=c[O>>2]|0;c[O>>2]=c[V>>2];c[V>>2]=A;do{if(I){A=c[j+76>>2]|0;if((A|0)>0){V=(A|0)>1;O=0;do{b[N+(O<<1)>>1]=(b[J+(O<<1)>>1]|0)>>>2;O=O+1|0;}while((O|0)<(A|0));cb=V?A:1}else{cb=0}O=G+1276|0;ja=Fmb(O,j)|0;if((ja|0)<0){L=ja}else{db=cb;eb=O;break}i=l;return L|0}else{c[K>>2]=1;db=0;eb=G+1276|0}}while(0);mrc(N+(db<<1)|0,0,160-db<<1|0)|0;Gmb(eb,c[f+424>>2]|0,h+8|0,h+48|0);c[B>>2]=20;c[k>>2]=1;L=0;i=l;return L|0}function IYa(a){a=a|0;var b=0;b=c[a+60>>2]|0;qPa(b+1248|0);Emb(b+1276|0);return 0}function JYa(b,d,e,f,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0,v=0.0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0.0,H=0.0,I=0.0,J=0,K=0.0,L=0.0,M=0.0;m=i;i=i+160|0;n=m|0;g[l>>2]=0.0;c[k>>2]=0;o=n|0;p=(h|0)==0;if((f|0)==0){q=0.0;r=0;s=0.0;while(1){t=0;do{g[n+(t<<2)>>2]=+(a[e+(r*40|0)+t|0]|0);t=t+1|0;}while((t|0)<40);M3(b,d,o,40,10);if(p){u=0.0;v=0.0;w=0}else{t=0;x=0.0;y=0.0;do{z=+g[h+(t<<2)>>2];x=x+ +g[b+(t<<2)>>2]*z;y=y+z*z;t=t+1|0;}while((t|0)<40);z=x/y;t=0;while(1){A=b+(t<<2)|0;g[A>>2]=+g[A>>2]-z*+g[h+(t<<2)>>2];A=t+1|0;if((A|0)<40){t=A}else{u=0.0;v=0.0;w=0;break}}}do{z=+g[b+(w<<2)>>2];v=v+z*z;u=u+z*+g[j+(w<<2)>>2];w=w+1|0;}while((w|0)<40);if(u>0.0){z=u/v;B=u*z;C=z}else{B=0.0;C=q}if(B>s){c[k>>2]=r;g[l>>2]=C;D=B}else{D=s}t=r+1|0;if((t|0)<128){q=C;r=t;s=D}else{break}}i=m;return}else{E=0.0;F=0;G=0.0}while(1){r=0;do{g[n+(r<<2)>>2]=+(a[e+(F*40|0)+r|0]|0);r=r+1|0;}while((r|0)<40);M3(b,d,o,40,10);r=0;D=0.0;s=0.0;do{C=+g[f+(r<<2)>>2];D=D+ +g[b+(r<<2)>>2]*C;s=s+C*C;r=r+1|0;}while((r|0)<40);C=D/s;r=0;do{w=b+(r<<2)|0;g[w>>2]=+g[w>>2]-C*+g[f+(r<<2)>>2];r=r+1|0;}while((r|0)<40);if(p){H=0.0;I=0.0;J=0}else{r=0;C=0.0;s=0.0;do{D=+g[h+(r<<2)>>2];C=C+ +g[b+(r<<2)>>2]*D;s=s+D*D;r=r+1|0;}while((r|0)<40);D=C/s;r=0;while(1){w=b+(r<<2)|0;g[w>>2]=+g[w>>2]-D*+g[h+(r<<2)>>2];w=r+1|0;if((w|0)<40){r=w}else{H=0.0;I=0.0;J=0;break}}}do{D=+g[b+(J<<2)>>2];I=I+D*D;H=H+D*+g[j+(J<<2)>>2];J=J+1|0;}while((J|0)<40);if(H>0.0){D=H/I;K=H*D;L=D}else{K=0.0;L=E}if(K>G){c[k>>2]=F;g[l>>2]=L;M=K}else{M=G}r=F+1|0;if((r|0)<128){E=L;F=r;G=M}else{break}}i=m;return}function KYa(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+60>>2]|0;c[a+416>>2]=1;e=a+448|0;c[e>>2]=4;c[e+4>>2]=0;c[a+420>>2]=3;if((c[a+432>>2]|0)<1){KIb(a,16,2358176,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1163346256;i=b;return f|0}else{qHb(d,c[a+88>>2]&8388608);f=0;i=b;return f|0}return 0}function LYa(a,e,f,h){a=a|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,aa=0,ba=0.0,ca=0,da=0,ea=0.0,fa=0.0,ga=0.0;j=i;i=i+24|0;k=j|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;h=c[a+60>>2]|0;n=h;o=a+432|0;p=c[o>>2]|0;if((m|0)<(p|0)){KIb(a,16,2447536,(q=i,i=i+16|0,c[q>>2]=m,c[q+8>>2]=p,q)|0);i=q;r=-1094995529;i=j;return r|0}c[e+76>>2]=160;q=M4a(a,e,0)|0;if((q|0)<0){r=q;i=j;return r|0}q=c[o>>2]|0;a=q>>>0>268435455>>>0?-8:q<<3;q=a>>>0>2147483639>>>0|(l|0)==0;p=q?0:l;l=q?8:a+8|0;a=h+600|0;q=h+744|0;m=q;s=h+620|0;t=h+1060|0;u=h+256|0;v=h+1056|0;w=h+260|0;x=h+1052|0;y=h+264|0;z=h+1048|0;A=h+268|0;B=h+1044|0;C=h+272|0;D=h+1040|0;E=h+276|0;F=h+1036|0;G=h+280|0;H=h+1032|0;I=h+284|0;J=h+1028|0;K=J;L=h+288|0;M=h+1024|0;N=M;O=h+292|0;P=k|0;Q=k+4|0;R=k+8|0;S=k+12|0;T=k+16|0;k=h+64|0;U=h+320|0;V=h+764|0;W=h+912|0;X=h+1064|0;h=0;Y=0;Z=c[e>>2]|0;while(1){e=p+(h>>>3)|0;_=h+3|0;aa=l>>>0>_>>>0?_:l;ba=+g[2019896+(((d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)>>>((h&7)>>>0)&7)<<2)>>2];e=Y&1|6;_=p+(aa>>>3)|0;ca=32-e|0;da=(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)>>>((aa&7)>>>0)<<ca>>>(ca>>>0);ca=aa+e|0;orc(a|0,s|0,144)|0;ea=32.0- +g[t>>2]*+g[u>>2]- +g[v>>2]*+g[w>>2]- +g[x>>2]*+g[y>>2]- +g[z>>2]*+g[A>>2]- +g[B>>2]*+g[C>>2]- +g[D>>2]*+g[E>>2]- +g[F>>2]*+g[G>>2]- +g[H>>2]*+g[I>>2]- +g[K>>2]*+g[L>>2]- +g[N>>2]*+g[O>>2];if(ea<0.0){fa=0.0}else{fa=ea>60.0?6.907755278982:ea*.1151292546497}ea=ba*+$(fa)*1.1920928955078125e-7;g[P>>2]=ea*+(b[1677720+(da*10|0)>>1]|0);g[Q>>2]=ea*+(b[1677722+(da*10|0)>>1]|0);g[R>>2]=ea*+(b[1677724+(da*10|0)>>1]|0);g[S>>2]=ea*+(b[1677726+(da*10|0)>>1]|0);g[T>>2]=ea*+(b[1677728+(da*10|0)>>1]|0);ea=+pHb(P,P,5);if(ea>2.980232238769531e-7){ga=ea}else{ga=2.980232238769531e-7}orc(M|0,J|0,36)|0;g[t>>2]=+fd(+ga)*10.0+33.2574989159953;M3(m,k,P,5,36);da=Z;c[da>>2]=c[q>>2];c[da+4>>2]=c[q+4>>2];c[da+8>>2]=c[q+8>>2];c[da+12>>2]=c[q+12>>2];c[da+16>>2]=c[q+16>>2];if((Y&7|0)==3){MYa(n,U,V,522480,k,522928,36,40,35,70);MYa(n,W,X,1201280,u,1202856,10,8,20,28)}da=Y+1|0;if((da|0)<32){h=l>>>0>ca>>>0?ca:l;Y=da;Z=Z+20|0}else{break}}c[f>>2]=1;r=c[o>>2]|0;i=j;return r|0}function MYa(a,b,d,e,f,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0;n=i;i=i+936|0;o=n|0;p=n+152|0;q=n+784|0;r=q|0;s=a|0;a=n+335&-32;t=j+15|0;mf[c[s>>2]&2047](a,e,b,t+k+l&-16);e=a+(j<<2)|0;do{if((j|0)>-1){u=j;while(1){g[o+(u<<2)>>2]=+pHb(e,a+(j-u<<2)|0,k);if((u|0)>0){u=u-1|0}else{break}}u=k+j|0;v=a+(u<<2)|0;w=j;while(1){g[p+(w<<2)>>2]=+pHb(v,a+(u-w<<2)|0,l);if((w|0)>0){w=w-1|0}else{break}}if((j|0)<0){x=0.0*1.00390625;break}else{y=0}do{w=d+(y<<2)|0;z=+g[w>>2]*.5625+ +g[o+(y<<2)>>2];g[w>>2]=z;g[q+(y<<2)>>2]=+g[p+(y<<2)>>2]+z;y=y+1|0;}while((y|0)<=(j|0));x=+g[r>>2]*1.00390625}else{x=0.0*1.00390625}}while(0);g[r>>2]=x;if(+g[q+(j<<2)>>2]!=0.0&x>0.0){A=x;B=0}else{C=b;D=b+(k<<2)|0;E=D;F=m<<2;orc(C|0,E|0,F|0)|0;i=n;return}while(1){if((B|0)>=(j|0)){break}r=B+1|0;x=-0.0- +g[q+(r<<2)>>2];if((B|0)>0){y=0;z=x;while(1){G=z- +g[f+(y<<2)>>2]*+g[q+(B-y<<2)>>2];p=y+1|0;if((p|0)<(B|0)){y=p;z=G}else{H=G;break}}}else{H=x}z=H/A;G=A*(1.0-z*z);g[f+(B<<2)>>2]=z;y=r>>1;if((y|0)>0){p=B-1|0;o=0;do{d=f+(o<<2)|0;I=+g[d>>2];l=f+(p-o<<2)|0;J=+g[l>>2];g[d>>2]=I+z*J;g[l>>2]=J+z*I;o=o+1|0;}while((o|0)<(y|0))}if(G<0.0){K=17;break}else{A=G;B=r}}if((K|0)==17){C=b;D=b+(k<<2)|0;E=D;F=m<<2;orc(C|0,E|0,F|0)|0;i=n;return}mf[c[s>>2]&2047](f,f,h,t&-16);C=b;D=b+(k<<2)|0;E=D;F=m<<2;orc(C|0,E|0,F|0)|0;i=n;return}function NYa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;e=c[a+60>>2]|0;do{if((c[a+100>>2]|0)>=24){f=c[a+96>>2]|0;if((grc(f,2119728,4)|0)!=0){break}g=f+4|0;h=(d[g]|d[g+1|0]<<8)<<16>>16;g=(he(h|0)|0)&65535;c[e>>2]=g;if(!(h<<16>>16==769)){QIb(a,2614632,(j=i,i=i+8|0,c[j>>2]=g,j)|0);i=j;k=-1163346256;i=b;return k|0}g=f+8|0;h=(d[g]|d[g+1|0]<<8)<<16>>16;g=(he(h|0)|0)&65535;c[a+416>>2]=g;l=f+12|0;m=je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;l=a+412|0;c[l>>2]=m;if((g-1|0)>>>0>1>>>0|(m|0)<8e3|(m|0)>96e3){KIb(a,16,2587744,(j=i,i=i+16|0,c[j>>2]=m,c[j+8>>2]=g,j)|0);i=j;k=-1094995529;i=b;return k|0}c[a+420>>2]=6;g=h<<16>>16==512;h=a+448|0;c[h>>2]=g?3:4;c[h+4>>2]=g?0:0;g=f+16|0;f=d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0;g=je(f|0)|0;h=e+4|0;c[h>>2]=g;if((g|0)>1048576|(f|0)==0){KIb(a,16,2566512,(j=i,i=i+8|0,c[j>>2]=g,j)|0);i=j;n=c[h>>2]|0}else{n=g}g=c[l>>2]|0;c[h>>2]=(n|0)>(g|0)?n:g;g=e+8|0;h=0;a:while(1){o=RYa(g+(h*5060|0)|0,1225224+(h*324|0)|0,643)|0;if((o|0)<0){p=12;break}q=RYa(g+(h*5060|0)+20|0,1953208+(h<<7)|0,255)|0;if((q|0)<0){p=14;break}r=RYa(g+(h*5060|0)+40|0,1677352+(h*72|0)|0,140)|0;if((r|0)<0){p=16;break}else{s=0}while(1){if((s|0)>=11){t=0;break}l=RYa(g+(h*5060|0)+60+(s*20|0)|0,1226344+(h*2640|0)+(s*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{s=s+1|0}}while(1){if((t|0)>=11){v=0;break}l=RYa(g+(h*5060|0)+280+(t*20|0)|0,1226608+(h*2640|0)+(t*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{t=t+1|0}}while(1){if((v|0)>=11){w=0;break}l=RYa(g+(h*5060|0)+500+(v*20|0)|0,1226872+(h*2640|0)+(v*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{v=v+1|0}}while(1){if((w|0)>=11){x=0;break}l=RYa(g+(h*5060|0)+720+(w*20|0)|0,1227136+(h*2640|0)+(w*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{w=w+1|0}}while(1){if((x|0)>=11){y=0;break}l=RYa(g+(h*5060|0)+940+(x*20|0)|0,1227400+(h*2640|0)+(x*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{x=x+1|0}}while(1){if((y|0)>=11){z=0;break}l=RYa(g+(h*5060|0)+1160+(y*20|0)|0,1227664+(h*2640|0)+(y*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{y=y+1|0}}while(1){if((z|0)>=11){A=0;break}l=RYa(g+(h*5060|0)+1380+(z*20|0)|0,1227928+(h*2640|0)+(z*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{z=z+1|0}}while(1){if((A|0)>=11){B=0;break}l=RYa(g+(h*5060|0)+1600+(A*20|0)|0,1228192+(h*2640|0)+(A*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{A=A+1|0}}while(1){if((B|0)>=11){C=0;break}l=RYa(g+(h*5060|0)+1820+(B*20|0)|0,1228456+(h*2640|0)+(B*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{B=B+1|0}}while(1){if((C|0)>=11){D=0;break}l=RYa(g+(h*5060|0)+2040+(C*20|0)|0,1228720+(h*2640|0)+(C*24|0)|0,43)|0;if((l|0)<0){u=l;p=19;break a}else{C=C+1|0}}while(1){if((D|0)>=15){E=0;break}F=RYa(g+(h*5060|0)+2260+(D*20|0)|0,568696+(h*1320|0)+(D*88|0)|0,169)|0;if((F|0)<0){p=22;break a}else{D=D+1|0}}while(1){if((E|0)>=125){break}G=RYa(g+(h*5060|0)+2560+(E*20|0)|0,920520+(h*28e3|0)+(E*224|0)|0,441)|0;if((G|0)<0){p=25;break a}else{E=E+1|0}}l=h+1|0;if((l|0)<3){h=l}else{k=0;p=27;break}}if((p|0)==12){PYa(a)|0;k=o;i=b;return k|0}else if((p|0)==14){PYa(a)|0;k=q;i=b;return k|0}else if((p|0)==16){PYa(a)|0;k=r;i=b;return k|0}else if((p|0)==19){PYa(a)|0;k=u;i=b;return k|0}else if((p|0)==22){PYa(a)|0;k=F;i=b;return k|0}else if((p|0)==25){PYa(a)|0;k=G;i=b;return k|0}else if((p|0)==27){i=b;return k|0}}}while(0);KIb(a,16,2637848,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}function OYa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=a+60|0;m=c[l>>2]|0;n=e;o=m+97392|0;do{if((c[o>>2]|0)==0){p=g+28|0;q=c[p>>2]|0;if((q|0)!=8192){r=q;s=c[g+24>>2]|0;break}nrc(m+81008|0,c[g+24>>2]|0,8192)|0;c[o>>2]=1;c[f>>2]=0;t=c[p>>2]|0;i=h;return t|0}else{c[o>>2]=0;p=c[g+24>>2]|0;q=p;u=(((he((d[q]|d[q+1|0]<<8)<<16>>16|0)|0)&65535)+7|0)>>>3;q=c[g+28>>2]|0;if((u+3|0)>(q|0)|(q|0)>8192){KIb(a,16,2447488,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;t=-1094995529;i=h;return t|0}w=m+81008|0;x=u+2|0;if((grc(w,p,x)|0)==0){nrc(m+89200|0,p+x|0,q-2-u|0)|0;r=q+8192|0;s=w;break}KIb(a,16,2358144,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;t=-1094995529;i=h;return t|0}}while(0);o=e+76|0;c[o>>2]=c[m+4>>2];w=M4a(a,n,0)|0;if((w|0)<0){t=w;i=h;return t|0}w=c[e>>2]|0;n=c[e+4>>2]|0;if((r|0)<5){KIb(a,16,2294824,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;t=-1094995529;i=h;return t|0}e=s;q=(he((d[e]|d[e+1|0]<<8)<<16>>16|0)|0)&65535;e=(q+7|0)>>>3;if((r|0)<(e+3|0)){KIb(a,16,2243928,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;t=-1094995529;i=h;return t|0}u=(s+2|0)==0?0:q;q=u+8|0;x=m+48232|0;c[x>>2]=0;a:do{if((u|0)==0){p=m+48236|0;c[p>>2]=0;y=p}else{p=m+48240|0;z=m+64624|0;A=0;B=0;while(1){C=s+((A>>>3)+2)|0;D=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>>17;C=A+15|0;E=q>>>0>C>>>0?C:q;c[p+(B<<2)>>2]=D;D=((E|0)<(q|0))+E|0;if((d[s+((E>>>3)+2)|0]&128>>>((E&7)>>>0)|0)==0){c[z+(c[x>>2]<<2)>>2]=0;F=D}else{E=s+((D>>>3)+2)|0;C=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>23;E=D+9|0;c[z+(c[x>>2]<<2)>>2]=C;F=q>>>0>E>>>0?E:q}G=(c[x>>2]|0)+1|0;c[x>>2]=G;if((u-F|0)>0){A=F;B=G}else{break}}B=m+48236|0;c[B>>2]=0;if((G|0)<=0){y=B;break}A=m+48240|0;z=a+416|0;p=j|0;E=j+4|0;C=k|0;D=k+4|0;H=0;I=s+(e+2)|0;J=r-2-e|0;b:while(1){K=A+(H<<2)|0;L=c[K>>2]|0;if((J|0)<(L|0)){M=25;break}N=L<<3;L=N>>>0>2147483639>>>0|(I|0)==0;O=L?0:I;P=L?0:N;N=P+8|0;L=c[B>>2]|0;Q=c[l>>2]|0;R=Q;S=0;T=0;while(1){if((S|0)>=6){U=T;break}V=((T|0)<(N|0))+T|0;if((d[O+(T>>>3)|0]&128>>>((T&7)>>>0)|0)==0){U=V;break}else{S=S+1|0;T=V}}T=12-S|0;V=1<<((T|0)<8^T);T=Q+48236|0;if(((c[T>>2]|0)+V|0)>(c[Q+4>>2]|0)){M=30;break}W=c[z>>2]|0;if((W|0)>1){X=O+(U>>>3)|0;Y=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(U&7)>>>30;X=U+2|0;Z=Y+1|0;_=N>>>0>X>>>0?X:N}else{Z=0;_=U}c[p>>2]=(Z|0)==4;X=(Z|0)>1;c[E>>2]=X?2:0;c[C>>2]=16;c[D>>2]=X?17:16;X=Q+47956|0;Y=Q+47964|0;$=Q+47960|0;aa=(V|0)>0;ba=(V|0)>1;da=V<<2;ea=0;fa=_;ga=W;while(1){if((ea|0)>=(ga|0)){break}W=c[j+(ea<<2)>>2]|0;ha=c[k+(ea<<2)>>2]|0;ia=R+15188+(ea<<14)|0;ja=c[R+8+(W*5060|0)+4>>2]|0;ka=O+(fa>>>3)|0;la=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(fa&7)>>>23;ka=b[ja+(la<<2)>>1]|0;ma=b[ja+(la<<2)+2>>1]|0;la=ma<<16>>16;if(ma<<16>>16<0){ma=fa+9|0;na=N>>>0>ma>>>0?ma:N;ma=O+(na>>>3)|0;oa=((je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>((la+32|0)>>>0))+ka|0;pa=b[ja+(oa<<2)+2>>1]|0;qa=b[ja+(oa<<2)>>1]|0;ra=na}else{pa=la;qa=ka;ra=fa}ka=pa+ra|0;la=N>>>0>ka>>>0?ka:N;c[X>>2]=qa;ka=qa-2>>6;c[Y>>2]=ka;c[$>>2]=qa-1-(ka<<6);do{if((qa|0)==642){if(aa){ka=32-ha|0;na=0;oa=la;while(1){ja=O+(oa>>>3)|0;ma=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(oa&7)>>>(ka>>>0);ja=oa+ha|0;sa=N>>>0>ja>>>0?ja:N;c[R+15188+(ea<<14)+(na<<2)>>2]=ma;ma=na+1|0;if((ma|0)<(V|0)){na=ma;oa=sa}else{ta=sa;break}}}else{ta=la}c[R+48224+(ea<<2)>>2]=0;ua=ta}else{oa=c[R+8+(W*5060|0)+24>>2]|0;na=O+(la>>>3)|0;ka=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(la&7)>>>23;na=b[oa+(ka<<2)>>1]|0;sa=b[oa+(ka<<2)+2>>1]|0;ka=sa<<16>>16;if(sa<<16>>16<0){sa=la+9|0;ma=N>>>0>sa>>>0?sa:N;sa=O+(ma>>>3)|0;ja=((je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ma&7)>>>((ka+32|0)>>>0))+na|0;va=b[oa+(ja<<2)+2>>1]|0;wa=b[oa+(ja<<2)>>1]|0;xa=ma}else{va=ka;wa=na;xa=la}na=va+xa|0;ka=N>>>0>na>>>0?na:N;na=R+48224+(ea<<2)|0;c[na>>2]=wa;if((wa|0)==0){ma=O+(ka>>>3)|0;ja=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(ka&7);if(ja>>>0>134217727>>>0){ma=ja>>>23;oa=(d[1382088+ma|0]|0)+ka|0;ya=d[1276064+ma|0]|0;za=N>>>0>oa>>>0?oa:N}else{oa=ja>>>0>65535>>>0;ma=oa?ja>>>16:ja;sa=oa?16:0;if((ma&65280|0)==0){Aa=sa;Ba=ma}else{Aa=sa|8;Ba=ma>>>8}ma=(d[1359664+Ba|0]|0)+Aa<<1;sa=63-ma+ka|0;ya=(ja>>>((ma-31|0)>>>0))-1|0;za=N>>>0>sa>>>0?sa:N}Ca=-127-ya|0;Da=za}else if((wa|0)==254){sa=O+(ka>>>3)|0;ma=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ka&7);if(ma>>>0>134217727>>>0){sa=ma>>>23;ja=(d[1382088+sa|0]|0)+ka|0;Ea=d[1276064+sa|0]|0;Fa=N>>>0>ja>>>0?ja:N}else{ja=ma>>>0>65535>>>0;sa=ja?ma>>>16:ma;oa=ja?16:0;if((sa&65280|0)==0){Ga=oa;Ha=sa}else{Ga=oa|8;Ha=sa>>>8}sa=(d[1359664+Ha|0]|0)+Ga<<1;oa=63-sa+ka|0;Ea=(ma>>>((sa-31|0)>>>0))-1|0;Fa=N>>>0>oa>>>0?oa:N}Ca=Ea+127|0;Da=Fa}else{Ca=wa-127|0;Da=ka}ka=O+(Da>>>3)|0;oa=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(Da&7)>>>28;ka=Da+4|0;sa=N>>>0>ka>>>0?ka:N;c[na>>2]=oa|Ca<<4;oa=c[X>>2]|0;if((oa|0)==0){mrc(ia|0,0,da|0)|0;ua=sa;break}do{if((oa|0)>1){na=c[Y>>2]|0;if((c[$>>2]|0)<=0){Ia=sa;break}ka=(na|0)==0;ma=12<<na;ja=32-na|0;Ja=0;Ka=0;La=0;Ma=sa;while(1){Na=Ja+5|0;Oa=c[R+8+(W*5060|0)+60+(na*220|0)+(Na*20|0)+4>>2]|0;Pa=c[R+8+(W*5060|0)+60+(na*220|0)+(Na*20|0)>>2]|0;Na=O+(Ma>>>3)|0;Qa=(je(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(Ma&7)>>>((32-Pa|0)>>>0);Na=b[Oa+(Qa<<2)>>1]|0;Ra=b[Oa+(Qa<<2)+2>>1]|0;Qa=Ra<<16>>16;if(Ra<<16>>16<0){Ra=Pa+Ma|0;Pa=N>>>0>Ra>>>0?Ra:N;Ra=O+(Pa>>>3)|0;Sa=((je(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Pa&7)>>>((Qa+32|0)>>>0))+Na|0;Ta=b[Oa+(Sa<<2)+2>>1]|0;Ua=b[Oa+(Sa<<2)>>1]|0;Va=Pa}else{Ta=Qa;Ua=Na;Va=Ma}Na=Ta+Va|0;Qa=N>>>0>Na>>>0?Na:N;if((Ua|0)==0){Na=O+(Qa>>>3)|0;Pa=(je(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(Qa&7);if(Pa>>>0>134217727>>>0){Na=Pa>>>23;Sa=(d[1382088+Na|0]|0)+Qa|0;Wa=d[1276064+Na|0]|0;Xa=N>>>0>Sa>>>0?Sa:N}else{Sa=Pa>>>0>65535>>>0;Na=Sa?Pa>>>16:Pa;Oa=Sa?16:0;if((Na&65280|0)==0){Ya=Oa;Za=Na}else{Ya=Oa|8;Za=Na>>>8}Na=(d[1359664+Za|0]|0)+Ya<<1;Oa=63-Na+Qa|0;Wa=(Pa>>>((Na-31|0)>>>0))-1|0;Xa=N>>>0>Oa>>>0?Oa:N}_a=-21-Wa|0;$a=Xa}else if((Ua|0)==42){Oa=O+(Qa>>>3)|0;Na=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Qa&7);if(Na>>>0>134217727>>>0){Oa=Na>>>23;Pa=(d[1382088+Oa|0]|0)+Qa|0;ab=d[1276064+Oa|0]|0;bb=N>>>0>Pa>>>0?Pa:N}else{Pa=Na>>>0>65535>>>0;Oa=Pa?Na>>>16:Na;Sa=Pa?16:0;if((Oa&65280|0)==0){cb=Sa;db=Oa}else{cb=Sa|8;db=Oa>>>8}Oa=(d[1359664+db|0]|0)+cb<<1;Sa=63-Oa+Qa|0;ab=(Na>>>((Oa-31|0)>>>0))-1|0;bb=N>>>0>Sa>>>0?Sa:N}_a=ab+21|0;$a=bb}else{_a=Ua-21|0;$a=Qa}if(ka){eb=_a;fb=$a}else{Qa=O+($a>>>3)|0;Sa=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<($a&7)>>>(ja>>>0);Qa=$a+na|0;eb=Sa|_a<<na;fb=N>>>0>Qa>>>0?Qa:N}Qa=eb+(((Ja|0)==0?ma:0)-Ka)|0;c[R+47968+(La<<2)>>2]=Qa;Sa=Qa>>na;do{if((Sa|0)<0){Oa=-Sa|0;Na=Oa>>>0>65535>>>0;Pa=Na?Oa>>>16:Oa;Oa=Na?16:0;if((Pa&65280|0)==0){gb=Oa;hb=Pa}else{gb=Oa|8;hb=Pa>>>8}Pa=(d[1359664+hb|0]|0)+gb|0;ib=(Pa|0)>4?-5:~Pa}else{if((Sa|0)<=0){ib=0;break}Pa=Sa>>>0>65535>>>0;Oa=Pa?Sa>>>16:Sa;Na=Pa?16:0;if((Oa&65280|0)==0){jb=Na;kb=Oa}else{jb=Na|8;kb=Oa>>>8}Oa=jb+1+(d[1359664+kb|0]|0)|0;ib=(Oa|0)>5?5:Oa}}while(0);Sa=La+1|0;if((Sa|0)<(c[$>>2]|0)){Ja=ib;Ka=Qa;La=Sa;Ma=fb}else{Ia=fb;break}}}else{Ia=sa}}while(0);sa=c[R+8+(W*5060|0)+44>>2]|0;oa=c[R+8+(W*5060|0)+40>>2]|0;Ma=O+(Ia>>>3)|0;La=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ia&7)>>>((32-oa|0)>>>0);Ma=b[sa+(La<<2)>>1]|0;Ka=b[sa+(La<<2)+2>>1]|0;La=Ka<<16>>16;if(Ka<<16>>16<0){Ka=oa+Ia|0;oa=N>>>0>Ka>>>0?Ka:N;Ka=O+(oa>>>3)|0;Ja=((je(d[Ka]|d[Ka+1|0]<<8|d[Ka+2|0]<<16|d[Ka+3|0]<<24|0)|0)<<(oa&7)>>>((La+32|0)>>>0))+Ma|0;lb=b[sa+(Ja<<2)+2>>1]|0;mb=b[sa+(Ja<<2)>>1]|0;nb=oa}else{lb=La;mb=Ma;nb=Ia}Ma=lb+nb|0;La=N>>>0>Ma>>>0?Ma:N;if((mb|0)>14){Ma=((mb|0)/5|0)-3|0;oa=(Ma|0)/2|0;do{if((Ma|0)<-1){ob=0}else{Ja=(oa|0)>10?10:oa;if((Ja|0)<=9){ob=Ja;break}ob=((((mb|0)%5|0|0)!=2)<<31>>31)+Ja|0}}while(0);pb=R+8+(W*5060|0)+2560+((mb-15|0)*20|0)|0;qb=ob;rb=21;sb=10}else{pb=R+8+(W*5060|0)+2260+(mb*20|0)|0;qb=0;rb=13;sb=6}if(!aa){ua=La;break}oa=pb|0;Ma=(qb|0)==0;Ja=32-qb|0;sa=sb<<1;Ka=c[pb+4>>2]|0;na=0;ma=La;while(1){ja=c[oa>>2]|0;ka=O+(ma>>>3)|0;Sa=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ma&7)>>>((32-ja|0)>>>0);ka=b[Ka+(Sa<<2)>>1]|0;Oa=b[Ka+(Sa<<2)+2>>1]|0;Sa=Oa<<16>>16;if(Oa<<16>>16<0){Oa=ja+ma|0;ja=N>>>0>Oa>>>0?Oa:N;Oa=O+(ja>>>3)|0;Na=((je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(ja&7)>>>((Sa+32|0)>>>0))+ka|0;tb=b[Ka+(Na<<2)+2>>1]|0;ub=b[Ka+(Na<<2)>>1]|0;vb=ja}else{tb=Sa;ub=ka;vb=ma}ka=tb+vb|0;Sa=N>>>0>ka>>>0?ka:N;ka=(ub|0)/(rb|0)|0;ja=(ub|0)%(rb|0)|0;do{if((ka|0)==0){Na=O+(Sa>>>3)|0;Oa=(je(d[Na]|d[Na+1|0]<<8|d[Na+2|0]<<16|d[Na+3|0]<<24|0)|0)<<(Sa&7);if(Oa>>>0>134217727>>>0){Na=Oa>>>23;Pa=(d[1382088+Na|0]|0)+Sa|0;wb=d[1276064+Na|0]|0;xb=N>>>0>Pa>>>0?Pa:N}else{Pa=Oa>>>0>65535>>>0;Na=Pa?Oa>>>16:Oa;Ra=Pa?16:0;if((Na&65280|0)==0){yb=Ra;zb=Na}else{yb=Ra|8;zb=Na>>>8}Na=(d[1359664+zb|0]|0)+yb<<1;Ra=63-Na+Sa|0;wb=(Oa>>>((Na-31|0)>>>0))-1|0;xb=N>>>0>Ra>>>0?Ra:N}Ab=-(wb+sb|0)|0;Bb=xb}else{if((sa|0)!=(ka|0)){Ab=ka-sb|0;Bb=Sa;break}Ra=O+(Sa>>>3)|0;Na=(je(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Sa&7);if(Na>>>0>134217727>>>0){Ra=Na>>>23;Oa=(d[1382088+Ra|0]|0)+Sa|0;Cb=d[1276064+Ra|0]|0;Db=N>>>0>Oa>>>0?Oa:N}else{Oa=Na>>>0>65535>>>0;Ra=Oa?Na>>>16:Na;Pa=Oa?16:0;if((Ra&65280|0)==0){Eb=Pa;Fb=Ra}else{Eb=Pa|8;Fb=Ra>>>8}Ra=(d[1359664+Fb|0]|0)+Eb<<1;Pa=63-Ra+Sa|0;Cb=(Na>>>((Ra-31|0)>>>0))-1|0;Db=N>>>0>Pa>>>0?Pa:N}Ab=Cb+sb|0;Bb=Db}}while(0);Sa=Ab<<qb;ka=R+15188+(ea<<14)+(na<<2)|0;c[ka>>2]=Sa;do{if((ja|0)==0){Pa=O+(Bb>>>3)|0;Ra=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Bb&7);if(Ra>>>0>134217727>>>0){Pa=Ra>>>23;Na=(d[1382088+Pa|0]|0)+Bb|0;Gb=d[1276064+Pa|0]|0;Hb=N>>>0>Na>>>0?Na:N}else{Na=Ra>>>0>65535>>>0;Pa=Na?Ra>>>16:Ra;Oa=Na?16:0;if((Pa&65280|0)==0){Ib=Oa;Jb=Pa}else{Ib=Oa|8;Jb=Pa>>>8}Pa=(d[1359664+Jb|0]|0)+Ib<<1;Oa=63-Pa+Bb|0;Gb=(Ra>>>((Pa-31|0)>>>0))-1|0;Hb=N>>>0>Oa>>>0?Oa:N}Kb=-(Gb+sb|0)|0;Lb=Hb}else{if((sa|0)!=(ja|0)){Kb=ja-sb|0;Lb=Bb;break}Oa=O+(Bb>>>3)|0;Pa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Bb&7);if(Pa>>>0>134217727>>>0){Oa=Pa>>>23;Ra=(d[1382088+Oa|0]|0)+Bb|0;Mb=d[1276064+Oa|0]|0;Nb=N>>>0>Ra>>>0?Ra:N}else{Ra=Pa>>>0>65535>>>0;Oa=Ra?Pa>>>16:Pa;Na=Ra?16:0;if((Oa&65280|0)==0){Ob=Na;Pb=Oa}else{Ob=Na|8;Pb=Oa>>>8}Oa=(d[1359664+Pb|0]|0)+Ob<<1;Na=63-Oa+Bb|0;Mb=(Pa>>>((Oa-31|0)>>>0))-1|0;Nb=N>>>0>Na>>>0?Na:N}Kb=Mb+sb|0;Lb=Nb}}while(0);ja=Kb<<qb;Na=R+15188+(ea<<14)+((na|1)<<2)|0;c[Na>>2]=ja;if(Ma){Qb=Lb}else{Oa=O+(Lb>>>3)|0;Pa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Lb&7)>>>(Ja>>>0);Oa=Lb+qb|0;Ra=N>>>0>Oa>>>0?Oa:N;c[ka>>2]=Pa|Sa;Pa=O+(Ra>>>3)|0;Oa=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Ra&7)>>>(Ja>>>0);Pa=Ra+qb|0;c[Na>>2]=Oa|ja;Qb=N>>>0>Pa>>>0?Pa:N}Pa=na+2|0;if((Pa|0)<(V|0)){na=Pa;ma=Qb}else{ua=Qb;break}}}}while(0);W=c[X>>2]|0;do{if(!((W|0)<2|(W|0)==642)){ia=c[Y>>2]|0;c[Y>>2]=ia+3;la=1<<ia+2;ia=1<<ha;ma=ia-1|0;na=1-ia-1|0;if(ba){Rb=1}else{break}do{ia=c[$>>2]|0;Ja=(ia|0)>(Rb|0)?Rb:ia;do{if((Ja|0)>0){ia=Rb-1|0;Ma=0;sa=0;do{Ma=(ca(c[R+15188+(ea<<14)+(ia-sa<<2)>>2]|0,c[R+47968+(sa<<2)>>2]|0)|0)+Ma|0;sa=sa+1|0;}while((sa|0)<(Ja|0));sa=Ma+la|0;if((Ma|0)>=0){Sb=sa;M=142;break}ia=sa-1>>c[Y>>2];Tb=(ia|0)>(na|0)?ia:na}else{Sb=la;M=142}}while(0);if((M|0)==142){M=0;Ja=Sb>>c[Y>>2];Tb=(Ja|0)>(ma|0)?ma:Ja}Ja=R+15188+(ea<<14)+(Rb<<2)|0;c[Ja>>2]=(c[Ja>>2]|0)+Tb;Rb=Rb+1|0;}while((Rb|0)<(V|0))}}while(0);if((P-ua|0)<0){M=162;break b}ea=ea+1|0;fa=ua;ga=c[z>>2]|0}ga=Q+15188|0;fa=Q+31572|0;c:do{switch(Z|0){case 3:{if(!aa){break c}ea=c[Q+48224>>2]|0;P=c[Q+48228>>2]|0;R=0;do{Y=(c[ga+(R<<2)>>2]|0)+ea|0;$=R+L|0;b[w+($<<1)>>1]=(c[fa+(R<<2)>>2]|0)+P+Y;b[n+($<<1)>>1]=Y;R=R+1|0;}while((R|0)<(V|0));break};case 2:{if(!aa){break c}R=Q+48224|0;P=Q+48228|0;ea=0;do{Y=ga+(ea<<2)|0;$=(c[Y>>2]|0)+(c[R>>2]|0)|0;c[Y>>2]=$;Y=ea+L|0;b[w+(Y<<1)>>1]=$;b[n+(Y<<1)>>1]=$-(c[fa+(ea<<2)>>2]|0)-(c[P>>2]|0);ea=ea+1|0;}while((ea|0)<(V|0));break};case 1:{if(!aa){break c}ea=c[Q+48224>>2]|0;P=c[Q+48228>>2]|0;R=0;do{$=R+L|0;b[w+($<<1)>>1]=(c[ga+(R<<2)>>2]|0)+ea;b[n+($<<1)>>1]=(c[fa+(R<<2)>>2]|0)+P;R=R+1|0;}while((R|0)<(V|0));break};case 4:{if(!aa){break c}R=c[Q+48228>>2]|0;P=c[Q+48224>>2]|0;ea=0;do{$=(c[fa+(ea<<2)>>2]|0)+R|0;Y=(c[ga+(ea<<2)>>2]|0)+P<<1|$&1;ba=ea+L|0;b[w+(ba<<1)>>1]=(Y+$|0)/2|0;b[n+(ba<<1)>>1]=(Y-$|0)/2|0;ea=ea+1|0;}while((ea|0)<(V|0));break};case 0:{if(!aa){break c}ea=c[Q+48224>>2]|0;P=0;do{b[w+(P+L<<1)>>1]=(c[ga+(P<<2)>>2]|0)+ea;P=P+1|0;}while((P|0)<(V|0));break};default:{}}}while(0);c[T>>2]=(c[T>>2]|0)+V;ga=c[K>>2]|0;L=H+1|0;if((L|0)<(c[x>>2]|0)){H=L;I=I+ga|0;J=J-ga|0}else{y=B;break a}}if((M|0)==25){KIb(a,16,2202328,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;y=B;break}else if((M|0)==30){J=a;KIb(J,16,2143296,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;Ub=J}else if((M|0)==162){Ub=a}KIb(Ub,16,2170600,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;y=B}}while(0);c[o>>2]=c[y>>2];c[f>>2]=(c[y>>2]|0)>0;t=c[g+28>>2]|0;i=h;return t|0}function PYa(a){a=a|0;var b=0,d=0;b=(c[a+60>>2]|0)+8|0;a=0;do{c3(b+(a*5060|0)|0);c3(b+(a*5060|0)+20|0);c3(b+(a*5060|0)+40|0);d=0;do{c3(b+(a*5060|0)+60+(d*220|0)|0);c3(b+(a*5060|0)+60+(d*220|0)+20|0);c3(b+(a*5060|0)+60+(d*220|0)+40|0);c3(b+(a*5060|0)+60+(d*220|0)+60|0);c3(b+(a*5060|0)+60+(d*220|0)+80|0);c3(b+(a*5060|0)+60+(d*220|0)+100|0);c3(b+(a*5060|0)+60+(d*220|0)+120|0);c3(b+(a*5060|0)+60+(d*220|0)+140|0);c3(b+(a*5060|0)+60+(d*220|0)+160|0);c3(b+(a*5060|0)+60+(d*220|0)+180|0);c3(b+(a*5060|0)+60+(d*220|0)+200|0);d=d+1|0;}while((d|0)<10);c3(b+(a*5060|0)+2260|0);c3(b+(a*5060|0)+2280|0);c3(b+(a*5060|0)+2300|0);c3(b+(a*5060|0)+2320|0);c3(b+(a*5060|0)+2340|0);c3(b+(a*5060|0)+2360|0);c3(b+(a*5060|0)+2380|0);c3(b+(a*5060|0)+2400|0);c3(b+(a*5060|0)+2420|0);c3(b+(a*5060|0)+2440|0);c3(b+(a*5060|0)+2460|0);c3(b+(a*5060|0)+2480|0);c3(b+(a*5060|0)+2500|0);c3(b+(a*5060|0)+2520|0);c3(b+(a*5060|0)+2540|0);d=0;do{c3(b+(a*5060|0)+2560+(d*20|0)|0);d=d+1|0;}while((d|0)<125);a=a+1|0;}while((a|0)<3);return 0}function QYa(a){a=a|0;c[(c[a+60>>2]|0)+97392>>2]=0;return}function RYa(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+2008|0;j=h|0;k=h+648|0;l=h+1936|0;m=i;i=i+72|0;mrc(l|0,0,68)|0;n=(g|0)>0;if(n){o=0;p=f;f=0;q=0;while(1){r=d[p]|0;s=((q|0)!=0?r&15:r>>>4)+1|0;r=l+(s<<2)|0;c[r>>2]=(c[r>>2]|0)+1;r=(f|0)>(s|0)?f:s;a[j+o|0]=s;s=o+1|0;if((s|0)<(g|0)){o=s;p=p+q|0;f=r;q=q^1}else{t=r;break}}}else{t=0}c[m+4>>2]=0;q=1;f=0;do{f=(c[l+(q<<2)>>2]|0)+f<<1;q=q+1|0;c[m+(q<<2)>>2]=f;}while((q|0)<17);if(n){u=0}else{v=(t|0)>9;w=v?9:t;x=j|0;y=k;z=$2(e,w,g,x,1,1,y,2,2,0,0,0,0)|0;i=h;return z|0}do{n=m+((d[j+u|0]|0)<<2)|0;q=c[n>>2]|0;c[n>>2]=q+1;b[k+(u<<1)>>1]=q;u=u+1|0;}while((u|0)<(g|0));v=(t|0)>9;w=v?9:t;x=j|0;y=k;z=$2(e,w,g,x,1,1,y,2,2,0,0,0,0)|0;i=h;return z|0}function SYa(a,b,d){a=a|0;b=b|0;d=d|0;c[a+532>>2]=b;c[a+528>>2]=b;c[a+536>>2]=b+d;c[a>>2]=0;c[a+4>>2]=65280;c[a+8>>2]=0;c[a+12>>2]=-1;return}function TYa(a,b,e){a=a|0;b=b|0;e=e|0;c[a+528>>2]=b;c[a+536>>2]=b+e;e=a|0;c[e>>2]=0;c[a+4>>2]=65280;c[a+8>>2]=0;c[a+12>>2]=-1;c[a+532>>2]=b+2;a=b;c[e>>2]=(he((d[a]|d[a+1|0]<<8)<<16>>16|0)|0)&65535;return}function UYa(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c;f=(c|0)<0|0?-1:0;mrc(b+16|0,0,512)|0;c=0;g=-2147483648;h=0;i=0;while(1){wrc(g<<8|0>>>24,c<<8|g>>>24,-2147483648,0)|0;j=G;k=(j|0)>(h|0)?j:h+1|0;if(!((h|0)>255|(h|0)==0|(k|0)>(d|0))){a[b+272+h|0]=k}j=xrc(0,1,g,c)|0;l=Erc(j,G,e,f)|0;wrc(l,G,-2147483648,0)|0;l=G;j=wrc(l,(l|0)<0|0?-1:0,g,c)|0;l=i+1|0;if((l|0)<128){c=G;g=j;h=k;i=l}else{break}}i=256-d|0;if((i|0)>(d|0)){m=1}else{h=i;while(1){i=b+272+h|0;if((a[i]|0)==0){g=h;c=g<<24|0>>>8;l=((h|0)<0|0?-1:0)<<24|g>>>8;g=xrc(0,1,c,l)|0;k=Erc(g,G,e,f)|0;wrc(k,G,-2147483648,0)|0;k=G;g=wrc(k,(k|0)<0|0?-1:0,c,l)|0;wrc(g<<8|0>>>24,G<<8|g>>>24,-2147483648,0)|0;g=G;l=h+1|0;c=(g|0)>(h|0)?g:l;a[i]=(c|0)>(d|0)?d:c;n=l}else{n=h+1|0}if((n|0)>(d|0)){m=1;break}else{h=n}}}do{a[b+16+m|0]=-(a[256-m+(b+272)|0]|0);m=m+1|0;}while((m|0)<255);return}function VYa(a){a=a|0;var b=0,d=0;b=a+4|0;c[b>>2]=255;d=a|0;c[d>>2]=(c[d>>2]|0)+255;WYa(a);c[b>>2]=255;WYa(a);return(c[a+532>>2]|0)-(c[a+528>>2]|0)|0}function WYa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b+4|0;if((c[d>>2]|0)>=256){return}e=b+12|0;f=b|0;g=b+532|0;h=b+8|0;b=c[e>>2]|0;i=c[f>>2]|0;while(1){do{if((b|0)<0){j=i>>8;c[e>>2]=j;k=j;l=i}else{if((i|0)<65281){j=c[g>>2]|0;c[g>>2]=j+1;a[j]=b;if((c[h>>2]|0)!=0){do{j=c[g>>2]|0;c[g>>2]=j+1;a[j]=-1;j=(c[h>>2]|0)-1|0;c[h>>2]=j;}while((j|0)!=0)}j=c[f>>2]|0;m=j>>8;c[e>>2]=m;k=m;l=j;break}if((i|0)<=65535){c[h>>2]=(c[h>>2]|0)+1;k=b;l=i;break}j=c[g>>2]|0;c[g>>2]=j+1;a[j]=b+1;if((c[h>>2]|0)!=0){do{j=c[g>>2]|0;c[g>>2]=j+1;a[j]=0;j=(c[h>>2]|0)-1|0;c[h>>2]=j;}while((j|0)!=0)}j=c[f>>2]|0;m=j>>>8&255;c[e>>2]=m;k=m;l=j}}while(0);j=l<<8&65280;c[f>>2]=j;m=c[d>>2]<<8;c[d>>2]=m;if((m|0)<256){b=k;i=j}else{break}}return}function XYa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=c[a+9856>>2]|0;e=c[d+160>>2]|0;f=c[a+9992>>2]|0;g=c[a+7792>>2]|0;h=c[a+13672>>2]|0;j=c[a+13676>>2]|0;k=c[a+13664>>2]|0;l=c[a+13696>>2]|0;m=c[a+11556>>2]|0;n=c[a+11560>>2]|0;o=a+9800|0;p=c[o>>2]|0;q=c[o+4>>2]|0;o=a+9792|0;r=c[o>>2]|0;s=c[o+4>>2]|0;o=c[a+13680>>2]|0;t=c[a+13692>>2]|0;u=c[a+13668>>2]|0;Rb(c[(c[a+4>>2]|0)+668>>2]|0,256,2481104,(a=i,i=i+136|0,c[a>>2]=c[d+164>>2],c[a+8>>2]=e,c[a+16>>2]=f,c[a+24>>2]=g,c[a+32>>2]=h,c[a+40>>2]=j,c[a+48>>2]=k,c[a+56>>2]=l,c[a+64>>2]=m,c[a+72>>2]=n,c[a+80>>2]=p,c[a+88>>2]=q,c[a+96>>2]=r,c[a+104>>2]=s,c[a+112>>2]=o,c[a+120>>2]=t,c[a+128>>2]=u,a)|0)|0;i=a;i=b;return}function YYa(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0.0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ia=0.0,ja=0.0,ka=0,la=0,ma=0,na=0.0,oa=0,pa=0,qa=0.0,ra=0,sa=0,ta=0.0,ua=0,va=0.0,wa=0.0,xa=0.0,ya=0.0,za=0.0,Aa=0.0,Ba=0.0,Ca=0.0,Da=0.0,Ea=0,Fa=0,Ga=0,Ha=0.0,Ia=0,Ja=0.0,Ka=0,La=0.0,Ma=0.0,Na=0,Oa=0,Pa=0,Qa=0.0;d=i;i=i+168|0;e=d|0;f=d+40|0;j=d+80|0;k=d+88|0;l=b+4|0;m=c[l>>2]|0;n=m+556|0;do{if(!(+g[n>>2]!=0.0)){o=c[m+524>>2]|0;if((o|0)==0){break}p=c[m+540>>2]|0;if((p|0)==0){g[n>>2]=1.0;break}q=c[m+112>>2]|0;if((q|0)>1){s=+(q|0)}else{s=1.0}t=+(p|0)/(+(o|0)*(1.0/(+(c[m+104>>2]|0)/+(c[m+108>>2]|0))/s));if(t<.3333333432674408){u=.3333333432674408}else{u=t>1.0?1.0:t}g[n>>2]=u}}while(0);n=c[m+536>>2]|0;o=UGb(b+13660|0,(n|0)==0?2429888:n,1318992,1318960,1318976,0,0,0,m)|0;if((o|0)<0){m=c[l>>2]|0;KIb(m,16,2419352,(v=i,i=i+8|0,c[v>>2]=c[m+536>>2],v)|0);i=v;w=o;i=d;return w|0}h[b+13248>>3]=826.0;h[b+13256>>3]=1.0;h[b+13264>>3]=.4;c[b+13624>>2]=1;o=b+13584|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13544|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13504|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13464|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13408>>3]=590.0;h[b+13272>>3]=826.0;h[b+13280>>3]=1.0;h[b+13288>>3]=.4;c[b+13628>>2]=1;o=b+13592|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13552|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13512|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13472|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13416>>3]=590.0;h[b+13296>>3]=826.0;h[b+13304>>3]=1.0;h[b+13312>>3]=.4;c[b+13632>>2]=1;o=b+13600|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13560|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13520|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13480|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13424>>3]=590.0;h[b+13320>>3]=826.0;h[b+13328>>3]=1.0;h[b+13336>>3]=.4;c[b+13636>>2]=1;o=b+13608|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13568|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13528|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13488|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13432>>3]=590.0;h[b+13344>>3]=826.0;h[b+13352>>3]=1.0;h[b+13360>>3]=.4;c[b+13640>>2]=1;o=b+13616|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13576|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13536|0;c[o>>2]=1;c[o+4>>2]=0;o=b+13496|0;c[o>>2]=1;c[o+4>>2]=0;h[b+13440>>3]=590.0;o=c[l>>2]|0;m=c[o+564>>2]|0;n=b+13240|0;h[n>>3]=+(m|0);if((m|0)==0){h[n>>3]=+(((c[o+524>>2]|0)*3|0|0)/4|0|0)}m=b+60|0;p=c[m>>2]|0;do{if((p&1024|0)==0){x=p}else{q=c[o+672>>2]|0;if((q|0)==0){y=-1}else{z=q;q=-1;while(1){A=_b(z+1|0,59)|0;B=q+1|0;if((A|0)==0){y=B;break}else{z=A;q=B}}}q=b+68|0;z=(c[q>>2]|0)+y|0;if((z|0)<1|z>>>0>26843544>>>0){w=-1;i=d;return w|0}B=pJb(z*80|0)|0;A=b+13236|0;c[A>>2]=B;C=b+13232|0;c[C>>2]=z;if((z|0)>0){D=c[b+144>>2]|0;E=0;do{c[B+(E*80|0)+40>>2]=2;c[B+(E*80|0)>>2]=2;g[B+(E*80|0)+44>>2]=236.0;g[B+(E*80|0)+4>>2]=236.0;c[B+(E*80|0)+20>>2]=D+10;H=D*100|0;I=B+(E*80|0)+56|0;c[I>>2]=H;c[I+4>>2]=(H|0)<0|0?-1:0;E=E+1|0;}while((E|0)<(z|0))}E=0;B=c[(c[l>>2]|0)+672>>2]|0;D=z;while(1){if((E|0)>=(D-(c[q>>2]|0)|0)){J=32;break}H=_b(B|0,59)|0;if((H|0)==0){K=0}else{a[H]=0;K=H+1|0}H=Bd(B|0,2410296,(v=i,i=i+8|0,c[v>>2]=j,v)|0)|0;i=v;I=c[j>>2]|0;if(!((I|0)>-1)){J=26;break}if((I|0)>=(c[C>>2]|0)){J=28;break}L=c[A>>2]|0;M=Bd(B|0,2381616,(v=i,i=i+104|0,c[v>>2]=L+(I*80|0),c[v+8>>2]=L+(I*80|0)+4,c[v+16>>2]=L+(I*80|0)+12,c[v+24>>2]=L+(I*80|0)+16,c[v+32>>2]=L+(I*80|0)+8,c[v+40>>2]=L+(I*80|0)+20,c[v+48>>2]=L+(I*80|0)+72,c[v+56>>2]=L+(I*80|0)+76,c[v+64>>2]=L+(I*80|0)+48,c[v+72>>2]=L+(I*80|0)+56,c[v+80>>2]=L+(I*80|0)+64,c[v+88>>2]=L+(I*80|0)+68,c[v+96>>2]=L+(I*80|0)+24,v)|0)|0;i=v;N=M+H|0;if((N|0)!=14){J=31;break}E=E+1|0;B=K;D=c[C>>2]|0}if((J|0)==26){Cd(2402656,2395736,205,2652760);return 0}else if((J|0)==28){Cd(2388496,2395736,206,2652760);return 0}else if((J|0)==31){KIb(c[l>>2]|0,16,2375128,(v=i,i=i+16|0,c[v>>2]=E,c[v+8>>2]=N,v)|0);i=v;w=-1;i=d;return w|0}else if((J|0)==32){B=c[l>>2]|0;q=c[B+112>>2]|0;if((q|0)>1){O=+(q|0)}else{O=1.0}u=1.0/(+(c[B+104>>2]|0)/+(c[B+108>>2]|0))/O;mrc(e|0,0,40)|0;mrc(f|0,0,40)|0;q=b+24|0;s=+(c[q>>2]|0)*+(D|0)/u;z=~~+s>>>0;H=(F=+s,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);M=B+496|0;B=~~(+g[M>>2]*4.0)|1;if((D|0)>0){I=0;do{L=c[A>>2]|0;P=c[L+(I*80|0)>>2]|0;S=L+(I*80|0)+40|0;c[S>>2]=P;T=L+(I*80|0)+12|0;s=+g[L+(I*80|0)+4>>2];U=b+13464+(P<<3)|0;u=+(c[T>>2]|0)*s+(+((c[U>>2]|0)>>>0)+ +((c[U+4>>2]|0)>>>0)*4294967296.0);V=(F=+u,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[U>>2]=~~+u>>>0;c[U+4>>2]=V;V=L+(I*80|0)+16|0;U=b+13504+(P<<3)|0;u=s*+(c[V>>2]|0)+(+((c[U>>2]|0)>>>0)+ +((c[U+4>>2]|0)>>>0)*4294967296.0);W=(F=+u,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[U>>2]=~~+u>>>0;c[U+4>>2]=W;W=L+(I*80|0)+8|0;U=c[W>>2]|0;X=b+13544+(P<<3)|0;Y=wrc(c[X>>2]|0,c[X+4>>2]|0,U,(U|0)<0|0?-1:0)|0;c[X>>2]=Y;c[X+4>>2]=G;X=b+13624+(P<<2)|0;c[X>>2]=(c[X>>2]|0)+1;X=c[S>>2]|0;S=e+(X<<3)|0;h[S>>3]=+h[S>>3]+s*+((c[V>>2]|0)+(c[T>>2]|0)|0);T=(c[L+(I*80|0)+20>>2]|0)+(c[W>>2]|0)|0;W=f+(X<<3)|0;X=wrc(T,(T|0)<0|0?-1:0,c[W>>2]|0,c[W+4>>2]|0)|0;c[W>>2]=X;c[W+4>>2]=G;I=I+1|0;Z=c[C>>2]|0;}while((I|0)<(Z|0));I=f+8|0;E=f+16|0;W=f+24|0;_=Z;aa=c[I+4>>2]|0;ca=c[I>>2]|0;da=c[E+4>>2]|0;ea=c[E>>2]|0;fa=c[W+4>>2]|0;ga=c[W>>2]|0}else{_=D;aa=0;ca=0;da=0;ea=0;fa=0;ga=0}W=wrc(ea,da,ga,fa)|0;E=wrc(W,G,ca,aa)|0;W=G;if(H>>>0<W>>>0|H>>>0==W>>>0&z>>>0<E>>>0){KIb(c[l>>2]|0,16,2307912,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}E=hJb(_<<3)|0;W=E;I=hJb(c[C>>2]<<3)|0;X=I;T=((B|0)%2|0|0)==1;s=+(z>>>0)+ +(H>>>0)*4294967296.0;L=(B|0)>0;V=(B|0)/-2|0;u=65536.0;t=0.0;S=0;P=c[C>>2]|0;while(1){ia=t+u;h[n>>3]=+((c[(c[l>>2]|0)+524>>2]|0)/2|0|0);if((P|0)>0){Y=0;while(1){U=(c[A>>2]|0)+(Y*80|0)|0;ja=+$Ya(b,U,ia,Y);h[W+(Y<<3)>>3]=ja;h[b+13408+(c[U>>2]<<3)>>3]=ja;U=Y+1|0;ka=c[C>>2]|0;if((U|0)<(ka|0)){Y=U}else{la=ka;break}}}else{la=P}if(!T){J=43;break}Y=la-300|0;ka=(Y|0)<0?0:Y;if((ka|0)<(la|0)){Y=ka;while(1){ka=W+(Y<<3)|0;h[ka>>3]=+fZa(b,c[(c[A>>2]|0)+(Y*80|0)+40>>2]|0,+h[ka>>3]);ka=Y+1|0;U=c[C>>2]|0;if((ka|0)<(U|0)){Y=ka}else{ma=U;break}}}else{ma=la}a:do{if((ma|0)>0){Y=ma;do{Y=Y-1|0;U=W+(Y<<3)|0;h[U>>3]=+fZa(b,c[(c[A>>2]|0)+(Y*80|0)+40>>2]|0,+h[U>>3]);}while((Y|0)>0);Y=c[C>>2]|0;if((Y|0)<=0){na=0.0;oa=Y;break}U=c[A>>2]|0;if(L){ka=0;while(1){pa=c[U+(ka*80|0)+40>>2]|0;ja=+g[M>>2];qa=ja*ja;ra=ka+V|0;if(ja==0.0){sa=0;ja=0.0;ta=0.0;while(1){ua=ra+sa|0;do{if((ua|0)>-1&(ua|0)<(Y|0)){if((pa|0)!=(c[U+(ua*80|0)+40>>2]|0)){va=ta;wa=ja;break}va=ta+1.0;wa=ja+ +h[W+(ua<<3)>>3]}else{va=ta;wa=ja}}while(0);ua=sa+1|0;if((ua|0)<(B|0)){sa=ua;ja=wa;ta=va}else{xa=wa;ya=va;break}}}else{sa=0;ta=0.0;ja=0.0;while(1){ua=ra+sa|0;za=+(ua-ka|0);Aa=+$(za*(-0.0-za)/qa);do{if((ua|0)>-1&(ua|0)<(Y|0)){if((pa|0)!=(c[U+(ua*80|0)+40>>2]|0)){Ba=ja;Ca=ta;break}Ba=ja+Aa;Ca=ta+Aa*+h[W+(ua<<3)>>3]}else{Ba=ja;Ca=ta}}while(0);ua=sa+1|0;if((ua|0)<(B|0)){sa=ua;ta=Ca;ja=Ba}else{xa=Ca;ya=Ba;break}}}h[X+(ka<<3)>>3]=xa/ya;sa=ka+1|0;if((sa|0)<(Y|0)){ka=sa}else{Da=0.0;Ea=0;Fa=U;break}}}else{ka=0;while(1){h[X+(ka<<3)>>3]=+r;sa=ka+1|0;if((sa|0)<(Y|0)){ka=sa}else{Da=0.0;Ea=0;Fa=U;break}}}while(1){ja=+gZa(b,Fa+(Ea*80|0)|0,+h[X+(Ea<<3)>>3],Ea);g[Fa+(Ea*80|0)+44>>2]=ja;if(!(ja>0.0)){KIb(0,16,2251136,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v}ta=+g[Fa+(Ea*80|0)+4>>2]*+((c[Fa+(Ea*80|0)+12>>2]|0)+1+(c[Fa+(Ea*80|0)+16>>2]|0)|0)/ja+ +(c[Fa+(Ea*80|0)+8>>2]|0)+ +(c[Fa+(Ea*80|0)+20>>2]|0);ja=ta+ +((bZa(b,~~ta)|0)<<3|0);U=(F=+Da,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);ka=Fa+(Ea*80|0)+32|0;c[ka>>2]=~~+Da>>>0;c[ka+4>>2]=U;ta=Da+ja;U=Ea+1|0;ka=c[C>>2]|0;if((U|0)>=(ka|0)){na=ta;oa=ka;break a}Da=ta;Ea=U;Fa=c[A>>2]|0}}else{na=0.0;oa=ma}}while(0);if(na>s){Ga=S+1|0;Ha=ia-u}else{Ga=S;Ha=ia}ta=u*.5;if(ta>1.0e-7){u=ta;t=Ha;S=Ga;P=oa}else{break}}if((J|0)==43){Cd(2302624,2395736,971,2652072);return 0}kJb(E);kJb(I);P=c[C>>2]|0;if((P|0)>0){S=c[A>>2]|0;X=c[l>>2]|0;B=c[X+500>>2]|0;W=c[X+504>>2]|0;t=0.0;X=0;do{V=~~(+g[S+(X*80|0)+44>>2]/118.0);if((V|0)<(B|0)){Ia=B}else{Ia=(V|0)>(W|0)?W:V}t=t+ +(Ia|0);X=X+1|0;}while((X|0)<(P|0));Ja=t}else{Ja=0.0}if((Ga|0)>=41){Cd(2291384,2395736,1043,2652072);return 0}P=c[q>>2]|0;KIb(c[l>>2]|0,48,2284648,(v=i,i=i+16|0,c[v>>2]=P,c[v+8>>2]=~~(na/(s/+(P|0))),v)|0);i=v;KIb(c[l>>2]|0,48,2280848,(v=i,i=i+8|0,h[v>>3]=Ja/+(c[C>>2]|0),v)|0);i=v;do{if((Ga|0)==0){KIb(c[l>>2]|0,32,2276600,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v}else if((Ga|0)==40){KIb(c[l>>2]|0,16,2272232,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}else{if(!(+R(+(na/s+-1.0))>.01)){break}KIb(c[l>>2]|0,16,2267464,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}}while(0);C=c[m>>2]|0;if((C&1024|0)==0){x=C;break}q=c[l>>2]|0;if((c[q+164>>2]|0)!=1){x=C;break}KIb(q,16,2368352,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}}}while(0);if((x&1024|0)!=0){w=0;i=d;return w|0}h[b+13368>>3]=.001;h[b+13376>>3]=.001;x=b+13384|0;h[x>>3]=.001;m=b+13392|0;h[m>>3]=.001;Ga=c[l>>2]|0;if(+g[Ga+496>>2]>1.0){KIb(Ga,16,2353448,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=d;return w|0}na=+g[Ga+552>>2];if(!(na!=0.0)){w=0;i=d;return w|0}Ga=b+144|0;v=b+16|0;Ia=k|0;J=k+40|0;oa=k+48|0;ma=k+56|0;Fa=k+4|0;Ea=k+72|0;la=k+76|0;n=k+20|0;_=b+9992|0;aa=k+64|0;ca=k+12|0;fa=k+16|0;ga=k+8|0;da=b+24|0;ea=b+68|0;Z=0;Ja=na;while(1){f=c[Ga>>2]|0;na=+(f|0);Ha=Ja*(+(Z|0)/1.0e4+1.0)*na;do{if(((Z|0)%(((c[v>>2]|0)+3|0)/4|0|0)|0|0)==0){c[Ia>>2]=1;Ka=1}else{if(((Z|0)%((c[ea>>2]|0)+1|0)|0|0)==0){c[Ia>>2]=2;Ka=2;break}else{c[Ia>>2]=3;Ka=3;break}}}while(0);c[J>>2]=Ka;Da=Ha*na/1.0e5;e=(F=+Da,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[oa>>2]=~~+Da>>>0;c[oa+4>>2]=e;c[ma>>2]=f;c[ma+4>>2]=(f|0)<0|0?-1:0;g[Fa>>2]=236.0;c[Ea>>2]=2;c[la>>2]=1;c[n>>2]=1;if((c[_>>2]|0)==1){c[aa>>2]=f;e=~~Ha;c[ca>>2]=e;c[fa>>2]=0;La=+(e|0)*236.0;Ma=0.0;Na=0;Oa=0;Pa=0}else{c[aa>>2]=0;c[ca>>2]=0;e=~~(Ha*.9);c[fa>>2]=e;N=~~(Ha*.1);La=0.0;Ma=+(e|0)*236.0;Na=(N|0)<0|0?-1:0;Oa=N;Pa=N}c[ga>>2]=Pa;N=b+13464+(Ka<<3)|0;Da=La+(+((c[N>>2]|0)>>>0)+ +((c[N+4>>2]|0)>>>0)*4294967296.0);e=(F=+Da,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[N>>2]=~~+Da>>>0;c[N+4>>2]=e;e=b+13504+(Ka<<3)|0;Da=Ma+(+((c[e>>2]|0)>>>0)+ +((c[e+4>>2]|0)>>>0)*4294967296.0);N=(F=+Da,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[e>>2]=~~+Da>>>0;c[e+4>>2]=N;N=b+13544+(Ka<<3)|0;e=wrc(c[N>>2]|0,c[N+4>>2]|0,Oa,Na)|0;c[N>>2]=e;c[N+4>>2]=G;N=b+13624+(Ka<<2)|0;c[N>>2]=(c[N>>2]|0)+1;+$Ya(b,k,+h[m>>3]/+h[x>>3],Z);N=c[l>>2]|0;e=c[N+112>>2]|0;if((e|0)>1){Qa=+(e|0)}else{Qa=1.0}h[m>>3]=+(c[da>>2]|0)/(1.0/(+(c[N+104>>2]|0)/+(c[N+108>>2]|0))/Qa)+ +h[m>>3];e=Z+1|0;if((e|0)>=1800){w=0;break}Z=e;Ja=+g[N+552>>2]}i=d;return w|0}function ZYa(a,b){a=a|0;b=+b;var d=0,e=0;d=i;if(b<.9){KIb(0,16,2240656,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}i=d;return+(+g[a+4>>2]*+((c[a+12>>2]|0)+1+(c[a+16>>2]|0)|0)/b)}function _Ya(a,b){a=a|0;b=+b;var d=0,e=0;d=i;if(!(b>0.0)){KIb(0,16,2251136,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}i=d;return+(+g[a+4>>2]*+((c[a+12>>2]|0)+1+(c[a+16>>2]|0)|0)/b)}function $Ya(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0,j=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0.0,y=0,z=0.0,A=0.0,B=0,C=0,D=0.0,E=0.0;f=i;i=i+168|0;j=f|0;l=a+4|0;m=c[l>>2]|0;n=c[b+40>>2]|0;o=+(c[a+144>>2]|0);p=j|0;h[p>>3]=3.141592653589793;h[j+8>>3]=2.718281828459045;q=b+12|0;r=c[q>>2]|0;s=b+4|0;t=+g[s>>2];h[j+16>>3]=+(r|0)*t;u=b+16|0;v=c[u>>2]|0;h[j+24>>3]=+(v|0)*t;h[j+32>>3]=+(v+r|0)*t;h[j+40>>3]=+(c[b+8>>2]|0)/o;r=c[b>>2]|0;v=(r|0)==3;w=c[b+72>>2]|0;if(v){x=+((c[b+76>>2]|0)+w|0)*.5}else{x=+(w|0)}h[j+48>>3]=x;h[j+56>>3]=+(c[b+64>>2]|0)/o;w=b+48|0;h[j+64>>3]=(+((c[w>>2]|0)>>>0)+ +(c[w+4>>2]|0)*4294967296.0)/o;w=b+56|0;h[j+72>>3]=(+((c[w>>2]|0)>>>0)+ +(c[w+4>>2]|0)*4294967296.0)/o;h[j+80>>3]=+((r|0)==1|0);h[j+88>>3]=+((r|0)==2|0);h[j+96>>3]=+(v&1|0);v=a+13584+(n<<3)|0;o=+(c[a+13624+(n<<2)>>2]|0);h[j+104>>3]=(+((c[v>>2]|0)>>>0)+ +((c[v+4>>2]|0)>>>0)*4294967296.0)/o;h[j+112>>3]=+g[m+492>>2];m=a+13472|0;h[j+120>>3]=(+((c[m>>2]|0)>>>0)+ +((c[m+4>>2]|0)>>>0)*4294967296.0)/+(c[a+13628>>2]|0);m=a+13480|0;x=+(c[a+13632>>2]|0);h[j+128>>3]=(+((c[m>>2]|0)>>>0)+ +((c[m+4>>2]|0)>>>0)*4294967296.0)/x;m=a+13520|0;h[j+136>>3]=(+((c[m>>2]|0)>>>0)+ +((c[m+4>>2]|0)>>>0)*4294967296.0)/x;m=a+13528|0;h[j+144>>3]=(+((c[m>>2]|0)>>>0)+ +((c[m+4>>2]|0)>>>0)*4294967296.0)/+(c[a+13636>>2]|0);m=a+13464+(n<<3)|0;v=a+13504+(n<<3)|0;r=wrc(c[v>>2]|0,c[v+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;h[j+152>>3]=(+(r>>>0)+ +(G>>>0)*4294967296.0)/o;h[j+160>>3]=0.0;o=+XGb(c[a+13660>>2]|0,p,b);h[k>>3]=o;b=c[k+4>>2]&2147483647;p=2146435072;if(b>>>0>p>>>0|b>>>0==p>>>0&(c[k>>2]|0)>>>0>0>>>0){p=c[l>>2]|0;KIb(p,16,2255632,(y=i,i=i+8|0,c[y>>2]=c[p+536>>2],y)|0);i=y;z=-1.0;i=f;return+z}p=a+13384|0;h[p>>3]=o+ +h[p>>3];x=o*d;d=(x<0.0?0.0:x)+1.0;p=c[l>>2]|0;if((c[p+528>>2]|0)>0){x=d;a=0;b=p;while(1){p=c[b+532>>2]|0;do{if((c[p+(a<<4)>>2]|0)>(e|0)){A=x;B=b}else{if((c[p+(a<<4)+4>>2]|0)<(e|0)){A=x;B=b;break}j=c[p+(a<<4)+8>>2]|0;if((j|0)==0){A=x*+g[p+(a<<4)+12>>2];B=b;break}if((j|0)>0){C=b}else{KIb(0,16,2251136,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;C=c[l>>2]|0}A=+g[s>>2]*+((c[q>>2]|0)+1+(c[u>>2]|0)|0)/+(j|0);B=C}}while(0);p=a+1|0;if((p|0)<(c[B+528>>2]|0)){x=A;a=p;b=B}else{D=A;break}}}else{D=d}if(D<.9){KIb(0,16,2240656,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y}d=+g[s>>2]*+((c[q>>2]|0)+1+(c[u>>2]|0)|0)/D;do{if((n|0)==1){u=c[l>>2]|0;D=+g[u+184>>2];if(!(D<0.0)){E=d;break}E=D*(-0.0-d)+ +g[u+188>>2]}else if((n|0)==3){u=c[l>>2]|0;D=+g[u+160>>2];if(!(D<0.0)){E=d;break}E=D*(-0.0-d)+ +g[u+172>>2]}else{E=d}}while(0);z=E<1.0?1.0:E;i=f;return+z}function aZa(a){a=a|0;TGb(c[a+13660>>2]|0);mJb(a+13236|0);return}function bZa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0.0,k=0.0,l=0.0,m=0,n=0.0,o=0,p=0.0,q=0,r=0,s=0;d=i;e=a+4|0;f=c[e>>2]|0;g=c[f+112>>2]|0;if((g|0)>1){j=+(g|0)}else{j=1.0}k=1.0/(+(c[f+104>>2]|0)/+(c[f+108>>2]|0))/j;g=c[f+524>>2]|0;j=+(c[f+544>>2]|0)/k;l=+(c[f+540>>2]|0)/k;if((g|0)==0){m=0;i=d;return m|0}k=+(b|0);b=a+13240|0;n=+h[b>>3]-k;h[b>>3]=n;if(n<0.0){KIb(f,16,2345064,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;do{if(k>l){f=c[e>>2]|0;if((c[a+9960>>2]|0)!=(c[f+504>>2]|0)){break}KIb(f,16,2338928,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}}while(0);h[b>>3]=0.0;p=0.0}else{p=n}n=+(g|0);g=~~(n-p+-1.0);f=~~j;q=~~l;if((g|0)<(f|0)){r=f}else{r=(g|0)>(q|0)?q:g}l=p+ +(r|0);h[b>>3]=l;if(!(l>n)){m=0;i=d;return m|0}r=~~+ba((l-n)*.125);if((r|0)<4){s=(c[a+48>>2]|0)==13?4:r}else{s=r}h[b>>3]=l- +(s<<3|0);b=c[e>>2]|0;if((c[b+688>>2]&2|0)==0){m=s;i=d;return m|0}KIb(b,48,2333352,(o=i,i=i+8|0,c[o>>2]=s,o)|0);i=o;m=s;i=d;return m|0}function cZa(a){a=a|0;var b=0,d=0;b=c[a+108>>2]|0;d=c[a+13236>>2]|0;c[a+11556>>2]=c[d+(b*80|0)+72>>2];c[a+11560>>2]=c[d+(b*80|0)+76>>2];return}function dZa(d,f){d=d|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0.0,L=0,M=0.0,N=0.0,O=0,P=0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0,$=0.0,aa=0.0,da=0.0,ea=0,fa=0,ga=0.0,ia=0.0,ja=0.0,ka=0.0,la=0.0,ma=0.0,na=0.0,oa=0.0,pa=0.0,qa=0.0,ra=0.0,sa=0.0,ta=0.0,ua=0.0,va=0.0,wa=0.0,xa=0;j=i;i=i+96|0;k=j|0;l=j+8|0;m=j+16|0;n=c[d+108>>2]|0;o=d+4|0;p=c[o>>2]|0;q=d+9992|0;r=c[q>>2]|0;eZa(k,l,p,r);s=c[o>>2]|0;t=c[s+112>>2]|0;if((t|0)>1){u=+(t|0)}else{u=1.0}v=1.0/(+(c[s+104>>2]|0)/+(c[s+108>>2]|0))/u;s=(f|0)==0;do{if((n|0)>2&s){f=c[d+1e4>>2]|0;t=(f|0)==1?d+13456|0:d+13448|0;u=+S(+((c[t>>2]|0)>>>0)+ +(c[t+4>>2]|0)*4294967296.0);if(u<10.0){break}w=+h[d+13400>>3]*+((c[d+13216>>2]|0)-(c[d+13220>>2]|0)|0)/(u+1.0);u=+h[d+13248+(f*24|0)+16>>3];t=d+13248+(f*24|0)+8|0;x=d+13248+(f*24|0)|0;y=u*+h[x>>3];h[t>>3]=u*+h[t>>3]+1.0;h[x>>3]=w+y}}while(0);x=d+60|0;t=(c[x>>2]&1024|0)==0;a:do{if(t){do{if((c[q>>2]|0)==3){z=14}else{if((c[d+13944>>2]|0)!=0){z=14;break}A=d+9848|0}}while(0);if((z|0)==14){A=d+9856|0}f=c[A>>2]|0;do{if((f|0)!=0){B=f+136|0;C=c[B>>2]|0;D=c[B+4>>2]|0;if((C|0)==0&(D|0)==(-2147483648|0)){break}y=(+(C>>>0)+ +(D|0)*4294967296.0)*+(c[d+24>>2]|0)/v;E=(F=+y,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);H=~~+y>>>0;I=m;break a}}while(0);y=+(n|0)*+(c[d+24>>2]|0)/v;E=(F=+y,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);H=~~+y>>>0;I=m}else{if(!((n|0)>-1)){Cd(2402656,2395736,783,2652736);return 0.0}if((n|0)<(c[d+13232>>2]|0)){f=c[d+13236>>2]|0;D=f+(n*80|0)+32|0;E=c[D+4>>2]|0;H=c[D>>2]|0;I=f+(n*80|0)|0;break}KIb(d,16,2327904,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;K=-1.0;i=j;return+K}}while(0);m=d+13208|0;A=xrc(c[m>>2]|0,c[m+4>>2]|0,H,E)|0;y=+(c[p+76>>2]|0);w=(y-(+(A>>>0)+ +(G|0)*4294967296.0))/y;y=w>0.0?w:.0010000000474974513;A=(r|0)==1;E=d+9792|0;q=d+9800|0;do{if(t){f=A?E:q;D=c[f>>2]|0;C=c[f+4>>2]|0;f=I+40|0;c[f>>2]=r;c[I>>2]=r;B=c[q+4>>2]|0;L=I+48|0;c[L>>2]=c[q>>2];c[L+4>>2]=B;B=c[E+4>>2]|0;L=I+56|0;c[L>>2]=c[E>>2];c[L+4>>2]=B;g[I+4>>2]=236.0;c[I+72>>2]=c[d+11556>>2];c[I+76>>2]=c[d+11560>>2];c[I+20>>2]=1;w=+S(+(D>>>0)+ +(C|0)*4294967296.0);u=w*+h[d+13248+(r*24|0)>>3]/(+h[d+13248+(r*24|0)+8>>3]*236.0);if(A){c[I+64>>2]=c[d+144>>2];C=~~u;c[I+12>>2]=C;c[I+16>>2]=0;c[I+8>>2]=0;M=+(C|0)*236.0;N=0.0;O=0;P=0}else{c[I+64>>2]=0;c[I+12>>2]=0;C=~~(u*.9);c[I+16>>2]=C;D=~~(u*.1);c[I+8>>2]=D;M=0.0;N=+(C|0)*236.0;O=(D|0)<0|0?-1:0;P=D}D=d+13464+(r<<3)|0;u=M+(+((c[D>>2]|0)>>>0)+ +((c[D+4>>2]|0)>>>0)*4294967296.0);C=(F=+u,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[D>>2]=~~+u>>>0;c[D+4>>2]=C;C=d+13504+(r<<3)|0;u=N+(+((c[C>>2]|0)>>>0)+ +((c[C+4>>2]|0)>>>0)*4294967296.0);D=(F=+u,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[C>>2]=~~+u>>>0;c[C+4>>2]=D;D=d+13544+(r<<3)|0;C=wrc(c[D>>2]|0,c[D+4>>2]|0,P,O)|0;c[D>>2]=C;c[D+4>>2]=G;D=d+13624+(r<<2)|0;c[D>>2]=(c[D>>2]|0)+1;D=d+13392|0;u=+$Ya(d,I,y*(+h[D>>3]/+h[d+13384>>3]),n);if(u<0.0){K=-1.0;i=j;return+K}if(!(u>0.0)){Cd(2317016,2395736,858,2652736);return 0.0}w=+fZa(d,c[f>>2]|0,u);u=w;if(!(w>0.0)){Cd(2317016,2395736,860,2652736);return 0.0}if((r|0)==2){z=35}else{if((c[d+20>>2]|0)==0){U=w;V=0.0}else{z=35}}if((z|0)==35){w=+g[p+496>>2];f=d+13368|0;C=d+13376|0;W=+h[C>>3]*w;X=u+ +h[f>>3]*w;h[f>>3]=X;w=W+1.0;h[C>>3]=w;W=X/w;U=W;V=W}if(!(U>0.0)){Cd(2317016,2395736,871,2652736);return 0.0}W=+gZa(d,I,U,n);h[D>>3]=+(c[d+24>>2]|0)/v+ +h[D>>3];if(W>0.0){Y=W;Z=V;break}Cd(2317016,2395736,877,2652736);return 0.0}else{do{if(!A){if((r|0)==(c[I+40>>2]|0)){break}Cd(2322136,2395736,818,2652736);return 0.0}}while(0);Y=+g[I+44>>2]/y;Z=0.0}}while(0);I=c[o>>2]|0;if((c[I+688>>2]&2|0)==0){_=c[k>>2]|0}else{A=(BLb(r)|0)<<24>>24;r=c[k>>2]|0;k=c[l>>2]|0;p=(c[m>>2]|0)/1e3|0;m=c[d+13216>>2]|0;z=c[E>>2]|0;O=c[E+4>>2]|0;P=c[q>>2]|0;t=c[q+4>>2]|0;D=(c[d+24>>2]|0)/1e3|0;KIb(I,48,2312496,(J=i,i=i+128|0,c[J>>2]=A,c[J+8>>2]=r,h[J+16>>3]=Y,c[J+24>>2]=k,c[J+32>>2]=n,c[J+40>>2]=(H|0)/1e3|0,c[J+48>>2]=p,h[J+56>>3]=y,h[J+64>>3]=Z,c[J+72>>2]=m,c[J+80>>2]=z,c[J+88>>2]=O,c[J+96>>2]=P,c[J+104>>2]=t,c[J+112>>2]=D,c[J+120>>2]=~~v,J)|0);i=J;_=r}v=+(_|0);do{if(Y<v){$=v}else{Z=+(c[l>>2]|0);if(!(Y>Z)){$=Y;break}$=Z}}while(0);Y=$;b:do{if((c[d+9980>>2]|0)==0){aa=+(~~(Y+.5)|0)}else{l=c[o>>2]|0;v=+g[l+192>>2]*6103515625.0e-14;Z=+g[l+208>>2]*6103515625.0e-14;y=+g[l+336>>2];_=c[d+14412>>2]|0;r=c[d+14416>>2]|0;J=c[l+340>>2]|0;D=c[l+344>>2]|0;t=c[d+116>>2]|0;P=c[d+120>>2]|0;O=d+144|0;z=c[O>>2]|0;m=(z|0)>0;if(m){V=-0.0- +g[l+196>>2];U=-0.0- +g[l+200>>2];p=(t|0)/5|0;N=+(p|0);H=(P|0)/5|0;M=+(H|0);n=(P<<2|0)/5|0;P=(t<<2|0)/5|0;W=+g[l+204>>2]+1.0;l=c[d+12556>>2]|0;t=c[d+9200>>2]|0;k=c[d+9192>>2]|0;A=c[d+9216>>2]|0;I=c[d+124>>2]|0;C=c[d+12492>>2]|0;w=0.0;X=0.0;f=0;while(1){B=c[l+(f<<2)>>2]|0;u=+S(+((e[t+(B<<1)>>1]|0)>>>0));da=+S(+((e[k+(B<<1)>>1]|0)>>>0));L=a[A+B|0]|0;ea=(B|0)%(I|0)|0;fa=(B|0)/(I|0)|0;ga=da<4.0?4.0:da;da=u<4.0?4.0:u;if((b[C+(B<<1)>>1]&1)==0){ia=+T(+da,+V);ja=da}else{ia=W;ja=ga}da=+T(+ga,+U)*ia;B=(L&255)-128|0;ga=+(ca(B,B)|0);if(L<<24>>24<0){ka=(1.0-v*ga)*da}else{ka=(1.0-Z*ga)*da}da=ka;do{if((ea|0)<(p|0)){la=+(p-ea|0)/N}else{if((ea|0)<=(P|0)){la=0.0;break}la=+(ea-P|0)/N}}while(0);do{if((fa|0)<(H|0)){ga=+(H-fa|0)/M;ma=la>ga?la:ga}else{if((fa|0)<=(n|0)){ma=la;break}ga=+(fa-n|0)/M;ma=la>ga?la:ga}}while(0);ga=da*(1.0-y*ma);u=ja*(ga<1.0e-5?9999999747378752.0e-21:ga);ga=w+ja;na=X+u;g[_+(f<<2)>>2]=ja;g[r+(f<<2)>>2]=u;fa=f+1|0;if((fa|0)<(z|0)){w=ga;X=na;f=fa}else{oa=ga;pa=na;break}}}else{oa=0.0;pa=0.0}f=c[x>>2]|0;do{if((f&131072|0)==0){qa=pa;ra=oa}else{X=pa/oa;if(m){w=+(D|0);y=+(D|0);M=+(J|0);N=+(J|0);Z=oa;v=pa;n=0;while(1){U=Y*+g[_+(n<<2)>>2];W=+g[r+(n<<2)>>2];V=X*(U/W);do{if(V>w){sa=v-W;ta=Z-U/y}else{if(!(V<M)){sa=v;ta=Z;break}sa=v-W;ta=Z-U/N}}while(0);H=n+1|0;if((H|0)<(z|0)){Z=ta;v=sa;n=H}else{ua=ta;va=sa;break}}}else{ua=oa;va=pa}v=va<.001?.0010000000474974513:va;if(!(ua<.001)){qa=v;ra=ua;break}qa=v;ra=.0010000000474974513}}while(0);if(!m){aa=$;break}z=c[d+12556>>2]|0;n=c[d+9976>>2]|0;v=qa/ra;H=0;P=f;while(1){Z=Y*+g[_+(H<<2)>>2]/+g[r+(H<<2)>>2];if((P&131072|0)==0){wa=Z}else{wa=v*Z}p=~~(wa+.5);if((p|0)>(D|0)){xa=D}else{xa=(p|0)<(J|0)?J:p}c[n+(c[z+(H<<2)>>2]<<2)>>2]=xa;p=H+1|0;if((p|0)>=(c[O>>2]|0)){aa=$;break b}H=p;P=c[x>>2]|0}}}while(0);if(!s){K=aa;i=j;return+K}h[d+13400>>3]=aa;s=c[q+4>>2]|0;x=d+13448|0;c[x>>2]=c[q>>2];c[x+4>>2]=s;s=c[E+4>>2]|0;x=d+13456|0;c[x>>2]=c[E>>2];c[x+4>>2]=s;K=aa;i=j;return+K}function eZa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0.0,j=0,k=0.0,l=0.0,m=0.0,n=0,o=0,p=0.0,q=0.0,r=0,s=0,t=0,u=0;f=c[d+576>>2]|0;h=c[d+580>>2]|0;if((f|0)>(h|0)){Cd(2259968,2395736,482,2652280)}if((e|0)==3){i=+g[d+160>>2];j=i<0.0;if(j){k=-0.0-i}else{k=i}l=+g[d+172>>2];if(j){m=-0.0-i}else{m=i}n=~~(+(h|0)*m+l+.5);o=~~(+(f|0)*k+l+.5)}else if((e|0)==1){l=+g[d+184>>2];e=l<0.0;if(e){p=-0.0-l}else{p=l}k=+g[d+188>>2];if(e){q=-0.0-l}else{q=l}n=~~(+(h|0)*q+k+.5);o=~~(+(f|0)*p+k+.5)}else{n=h;o=f}if((o|0)<1){r=1}else{r=(o|0)>32767?32767:o}if((n|0)<1){s=1;t=(s|0)<(r|0);u=t?r:s;c[a>>2]=r;c[b>>2]=u;return}s=(n|0)>32767?32767:n;t=(s|0)<(r|0);u=t?r:s;c[a>>2]=r;c[b>>2]=u;return}function fZa(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0.0,i=0,j=0,k=0.0,l=0.0,m=0.0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0;e=c[a+4>>2]|0;f=+h[a+13424>>3];i=a+13644|0;j=c[i>>2]|0;k=+h[a+13408+(j<<3)>>3];do{if((b|0)==3){l=+g[e+160>>2];if(l>0.0){m=k*l+ +g[e+172>>2]}else{m=d}n=m<1.0?1.0:m;o=11}else if((b|0)==1){l=+g[e+184>>2];if(!(l>0.0|(j|0)==2)){p=d;o=9;break}if(l<0.0){q=-0.0-l}else{q=l}p=f*q+ +g[e+188>>2];o=9}else{p=d;o=9}}while(0);do{if((o|0)==9){d=p<1.0?1.0:p;if((j|0)==(b|0)|(b|0)!=1){n=d;o=11;break}r=d;s=a+13408+(b<<3)|0}}while(0);do{if((o|0)==11){j=a+13408+(b<<3)|0;p=+h[j>>3];d=+((c[e+508>>2]|0)*118|0|0);q=p+d;if(n>q){r=q;s=j;break}q=p-d;if(!(n<q)){r=n;s=j;break}r=q;s=j}}while(0);h[s>>3]=r;if((b|0)==3){return+r}c[i>>2]=b;return+r}function gZa(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0.0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0.0;f=i;i=i+16|0;j=f|0;k=f+8|0;l=a+4|0;m=c[l>>2]|0;n=c[m+524>>2]|0;o=+(n|0);p=c[m+112>>2]|0;if((p|0)>1){q=+(p|0)}else{q=1.0}r=1.0/(+(c[m+104>>2]|0)/+(c[m+108>>2]|0))/q;q=+(c[m+544>>2]|0)/r;s=+(c[m+540>>2]|0)/r;p=c[b+40>>2]|0;eZa(j,k,m,p);m=c[l>>2]|0;t=c[m+520>>2]|0;do{if((t|0)==0){u=d}else{if(!(((e|0)%(t|0)|0|0)==0&(p|0)==2)){u=d;break}u=+g[m+516>>2]*d}}while(0);do{if((n|0)==0){v=u}else{p=a+13240|0;d=+h[p>>3];do{if(q!=0.0){r=(o-d)*2.0/o;do{if(r>1.0){w=1.0}else{if(!(r<1.0e-4)){w=r;break}w=1.0e-4}}while(0);r=u*+T(+w,+(1.0/+g[m+548>>2]));x=(q-o+d)*+g[m+560>>2];y=x>1.0?x:1.0;if(y<.9){KIb(0,16,2240656,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}x=+g[b+4>>2]*+((c[b+12>>2]|0)+1+(c[b+16>>2]|0)|0)/y;if(!(r>x)){A=r;break}t=c[l>>2]|0;if((c[t+688>>2]&2|0)==0){A=x;break}KIb(t,48,2263936,(z=i,i=i+16|0,h[z>>3]=r,h[z+8>>3]=x,z)|0);i=z;A=x}else{A=u}}while(0);if(!(s!=0.0)){v=A;break}x=d*2.0/o;do{if(x>1.0){B=1.0}else{if(!(x<1.0e-4)){B=x;break}B=1.0e-4}}while(0);t=c[l>>2]|0;x=A/+T(+B,+(1.0/+g[t+548>>2]));d=+h[p>>3]*+g[t+556>>2];r=d>1.0?d:1.0;if(r<.9){KIb(0,16,2240656,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z}d=+g[b+4>>2]*+((c[b+12>>2]|0)+1+(c[b+16>>2]|0)|0)/r;if(!(x<d)){v=x;break}t=c[l>>2]|0;if((c[t+688>>2]&2|0)==0){v=d;break}KIb(t,48,2263936,(z=i,i=i+16|0,h[z>>3]=x,h[z+8>>3]=d,z)|0);i=z;v=d}}while(0);z=c[j>>2]|0;do{if(!(+g[(c[l>>2]|0)+512>>2]==0.0)){j=c[k>>2]|0;if((z|0)==(j|0)){break}B=+aa(+(z|0));A=+aa(+(j|0))-B;C=+$(B+A*(1.0/(+$(((+aa(v)-B)/A+-.5)*-4.0)+1.0)));i=f;return+C}}while(0);A=+(z|0);if(v<A){C=A;i=f;return+C}A=+(c[k>>2]|0);if(!(v>A)){C=v;i=f;return+C}C=A;i=f;return+C}function hZa(a){a=a|0;var b=0,d=0,e=0,f=0;b=1317528;while(1){d=c[b>>2]|0;if(!((d|0)>-1)){e=0;f=5;break}if((d|0)==(a|0)){break}else{b=b+8|0}}if((f|0)==5){return e|0}e=c[b+4>>2]|0;return e|0}function iZa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=c[b+60>>2]|0;f=b+52|0;g=c[f>>2]|0;do{if((g|0)==544694642|(g|0)==909201230){h=Q4a(729160,c[b+792>>2]|0)|0;c[b+140>>2]=h;j=h}else if((g|0)==1463898711){h=Q4a(729232,c[b+792>>2]|0)|0;c[b+140>>2]=h;j=h}else if((g|0)==0){h=b+140|0;k=c[h>>2]|0;if(!((k|0)==-1)){j=k;break}k=c[b+792>>2]|0;if((k|0)==0){j=-1;break}l=Q4a(729232,k)|0;c[h>>2]=l;j=l}else{l=Q4a(1317528,g)|0;c[b+140>>2]=l;j=l}}while(0);g=b+140|0;l=qKb(j)|0;if((l|0)==0){KIb(b,16,2119696,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;m=-22;i=d;return m|0}j=l+7|0;do{if(!((a[j]&66)==0)){h=cGb(1024)|0;c[e+4>>2]=h;if((h|0)==0){m=-12;i=d;return m|0}k=c[h+4>>2]|0;if((a[j]&64)==0){mrc(k|0,0,1024)|0;break}else{rIb(k,c[g>>2]|0)|0;break}}}while(0);j=b+792|0;k=c[j>>2]|0;do{if((k|0)==4|(k|0)==2){if((c[g>>2]|0)!=11){n=19;break}h=c[f>>2]|0;if(!((h|0)==0|(h|0)==544694642)){n=19;break}c[e+16>>2]=1;c[e+8>>2]=c2(11,(c[b+120>>2]|0)+15&-16,c[b+124>>2]|0)|0}else{n=19}}while(0);if((n|0)==19){do{if((oKb(l)|0)==16){k=c[j>>2]|0;if((k|0)==0){o=0;break}o=(k|0)<16|0}else{o=0}}while(0);c[e+24>>2]=o;c[e+8>>2]=c2(c[g>>2]|0,c[b+120>>2]|0,c[b+124>>2]|0)|0}o=c[b+100>>2]|0;if((o|0)>8){if((grc((c[b+96>>2]|0)+(o-9)|0,2637824,9)|0)==0){n=26}else{n=25}}else{n=25}if((n|0)==25){o=c[f>>2]|0;if((o|0)==1987410275|(o|0)==3|(o|0)==1463898711){n=26}else{p=o}}if((n|0)==26){c[e+12>>2]=1;p=c[f>>2]|0}if((p|0)!=846624121){m=0;i=d;return m|0}if((c[g>>2]|0)!=1){m=0;i=d;return m|0}c[e+20>>2]=1;m=0;i=d;return m|0}function jZa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;j=b+140|0;k=qKb(c[j>>2]|0)|0;l=c[b+60>>2]|0;m=c[g+24>>2]|0;n=g+28|0;o=c[n>>2]|0;p=g|0;do{if((c[p>>2]|0)==0){q=1}else{if((c[l+16>>2]|0)!=0){q=1;break}if((c[l+20>>2]|0)!=0){q=1;break}q=(c[l+24>>2]|0)!=0}}while(0);r=e;s=e;c[e+88>>2]=1;c[e+84>>2]=1;t=b+704|0;u=c[t+4>>2]|0;v=e+320|0;c[v>>2]=c[t>>2];c[v+4>>2]=u;u=b+64|0;v=c[(c[u>>2]|0)+32>>2]|0;t=v+8|0;w=c[t+4>>2]|0;x=e+144|0;c[x>>2]=c[t>>2];c[x+4>>2]=w;w=v+64|0;EHb(r,c[w>>2]|0,c[w+4>>2]|0);w=c[(c[(c[u>>2]|0)+32>>2]|0)+48>>2]|0;CHb(r,w,(w|0)<0|0?-1:0);w=l+28|0;if((c[w>>2]|0)>-1){c[e+296>>2]=1;c[e+300>>2]=c[w>>2]}w=b+120|0;r=b+124|0;u=b;v=tIb(c[w>>2]|0,c[r>>2]|0,0,u)|0;if((v|0)<0){z=v;i=h;return z|0}if(q){v=c[l+8>>2]|0;x=cGb((v|0)>(o|0)?v:o)|0;c[e+360>>2]=x;A=x}else{x=eGb(c[p>>2]|0)|0;c[e+360>>2]=x;A=x}x=e+360|0;if((A|0)==0){z=-12;i=h;return z|0}a:do{if((c[l+16>>2]|0)==0){if((c[l+24>>2]|0)==0){if(!q){B=m;C=o;D=4;break}nrc(c[A+4>>2]|0,m|0,o)|0;B=c[(c[x>>2]|0)+4>>2]|0;C=o;D=4;break}p=c[A+4>>2]|0;v=(o|0)>1;if((a[k+7|0]&1)==0){if(!v){B=p;C=o;D=4;break}t=b+792|0;E=0;while(1){F=m+E|0;G=p+E|0;y=((d[F]|d[F+1|0]<<8)<<16>>16&65535)<<16-(c[t>>2]|0)&65535;a[G]=y;y=y>>8;a[G+1|0]=y;G=E+2|0;if((G|1|0)<(o|0)){E=G}else{B=p;C=o;D=4;break}}}else{if(!v){B=p;C=o;D=4;break}E=b+792|0;t=0;while(1){G=m+t|0;F=(he((d[G]|d[G+1|0]<<8)<<16>>16|0)|0)&65535;G=p+t|0;y=he(F<<16-(c[E>>2]|0)&65535|0)|0;a[G]=y;y=y>>8;a[G+1|0]=y;G=t+2|0;if((G|1|0)<(o|0)){t=G}else{B=p;C=o;D=4;break}}}}else{p=c[A+4>>2]|0;t=(c[l+8>>2]|0)-1024|0;E=c[b+792>>2]|0;if((E|0)==4){if((t|0)>1){H=0;I=0;J=1}else{B=p;C=t;D=8;break}while(1){if((H|0)>=(c[n>>2]|0)){B=p;C=t;D=8;break a}v=m+H|0;a[p+I|0]=(d[v]|0)>>>4;a[p+J|0]=a[v]&15;v=H+1|0;G=v<<1;F=G|1;if((F|0)<(t|0)){H=v;I=G;J=F}else{B=p;C=t;D=8;break}}}else if((E|0)==2){if((t|0)>3){K=0;L=0;M=3}else{B=p;C=t;D=16;break}while(1){if((K|0)>=(c[n>>2]|0)){B=p;C=t;D=16;break a}F=m+K|0;a[p+L|0]=(d[F]|0)>>>6;a[p+(L|1)|0]=(d[F]|0)>>>4&3;a[p+(L|2)|0]=(d[F]|0)>>>2&3;a[p+M|0]=a[F]&3;F=K+1|0;G=F<<2;v=G|3;if((v|0)<(t|0)){K=F;L=G;M=v}else{B=p;C=t;D=16;break}}}else{KIb(0,0,2447392,(N=i,i=i+24|0,c[N>>2]=2358040,c[N+8>>2]=2294784,c[N+16>>2]=208,N)|0);i=N;Hd();return 0}}}while(0);M=b+52|0;L=c[M>>2]|0;if((L|0)==2016499265|(L|0)==1886737985){L=c[l+8>>2]|0;O=B+(C-L)|0;P=L}else{O=B;P=c[l+8>>2]|0}B=l+8|0;L=c[j>>2]|0;K=P-((L|0)==11?1024:0)|0;if((C|0)<(K|0)){KIb(u,16,2243768,(N=i,i=i+16|0,c[N>>2]=C,c[N+8>>2]=K,N)|0);i=N;fGb(x);z=-22;i=h;return z|0}N=a2(s,O,L,c[w>>2]|0,c[r>>2]|0)|0;if((N|0)<0){fGb(x);z=N;i=h;return z|0}N=c[j>>2]|0;if((N|0)==11){L=V1(g,0,0)|0;do{if((L|0)!=0){g=l+4|0;fGb(g);O=cGb(1024)|0;c[g>>2]=O;if((O|0)!=0){nrc(c[O+4>>2]|0,L|0,1024)|0;c[e+304>>2]=1;break}fGb(x);z=-12;i=h;return z|0}}while(0);Q=c[j>>2]|0}else{Q=N}switch(Q|0){case 3:case 8:case 46:case 45:case 44:case 9:case 11:{N=e+32|0;L=D-1+(c[N>>2]|0)&-D;if((ca(L,c[r>>2]|0)|0)<=(C|0)){c[N>>2]=L}if((Q|0)==25){R=48}else if((Q|0)==11){R=52}else{R=53}break};case 25:{R=48;break};default:{R=53}}do{if((R|0)==48){if((c[M>>2]|0)!=842094158){R=53;break}L=e+32|0;N=c[L>>2]|0;O=D-1|0;g=-D|0;s=O+N&g;K=c[r>>2]|0;u=ca(s,K)|0;P=e+36|0;m=O+(c[P>>2]|0)&g;if(((ca(m,(K+1|0)/2|0)|0)+u|0)<=(C|0)){u=ca(s-N|0,K)|0;K=e+4|0;c[K>>2]=(c[K>>2]|0)+u;c[L>>2]=s;c[P>>2]=m}if((Q|0)==11){R=52}else{R=53}}}while(0);if((R|0)==52){if((C|0)<(c[B>>2]|0)){R=54}else{R=53}}if((R|0)==53){if((a[k+7|0]&64)==0){S=Q}else{R=54}}do{if((R|0)==54){Q=eGb(c[l+4>>2]|0)|0;c[e+364>>2]=Q;if((Q|0)!=0){c[e+4>>2]=c[Q+4>>2];S=c[j>>2]|0;break}fGb(x);z=-12;i=h;return z|0}}while(0);do{if((S|0)==3){x=e+32|0;Q=(c[x>>2]|0)+3&-4;if((ca(Q,c[r>>2]|0)|0)>(C|0)){break}c[x>>2]=Q}}while(0);if((c[l+12>>2]|0)!=0){l=e+32|0;Q=c[l>>2]|0;x=ca(Q,(c[r>>2]|0)-1|0)|0;k=e;c[k>>2]=(c[k>>2]|0)+x;c[l>>2]=-Q}Q=c[M>>2]|0;do{if((Q|0)==846624121){R=67}else if((Q|0)==842094169|(Q|0)==909203033|(Q|0)==875714137|(Q|0)==961893977){l=e+8|0;x=c[l>>2]|0;k=e+4|0;c[l>>2]=c[k>>2];c[k>>2]=x;R=66}else if((Q|0)==808596553){x=c[w>>2]|0;k=c[r>>2]|0;l=ca(k+1|0,x+1|0)|0;if(((l*3|0|0)/2|0|0)!=(C|0)){break}B=e+4|0;D=l-(ca(k,x)|0)|0;c[B>>2]=(c[B>>2]|0)+D;B=e+8|0;c[B>>2]=(c[B>>2]|0)+((D*5|0|0)/4|0);R=66}else{T=Q;R=75}}while(0);if((R|0)==66){if((Q|0)==846624121){R=67}else{T=Q;R=75}}do{if((R|0)==67){if((S|0)!=1){break}Q=c[r>>2]|0;if((Q|0)<=0){break}D=e+32|0;B=0;x=c[e>>2]|0;k=c[w>>2]|0;l=Q;while(1){if((k|0)>0){Q=0;do{m=x+(Q<<1|1)|0;a[m]=a[m]^-128;Q=Q+1|0;U=c[w>>2]|0;}while((Q|0)<(U|0));V=U;W=c[r>>2]|0}else{V=k;W=l}Q=B+1|0;if((Q|0)<(W|0)){B=Q;x=x+(c[D>>2]|0)|0;k=V;l=W}else{break}}T=c[M>>2]|0;R=75}}while(0);do{if((R|0)==75){if((T|0)!=1431918169){break}if((c[j>>2]|0)!=1){break}M=c[r>>2]|0;if((M|0)<=0){break}W=e+32|0;V=0;U=c[e>>2]|0;S=c[w>>2]|0;l=M;while(1){if((S-1|0)>0){M=0;do{k=M<<1;D=U+(k|3)|0;x=a[D]|0;B=U+(k|1)|0;a[D]=a[B]|0;a[B]=x;M=M+2|0;X=c[w>>2]|0;}while((M|0)<(X-1|0));Y=X;Z=c[r>>2]|0}else{Y=S;Z=l}M=V+1|0;if((M|0)<(Z|0)){V=M;U=U+(c[W>>2]|0)|0;S=Y;l=Z}else{break}}}}while(0);Z=c[b+408>>2]|0;do{if(Z>>>0>1>>>0){c[e+296>>2]=1;if(!((Z|0)==2|(Z|0)==4)){break}c[e+300>>2]=1}}while(0);c[f>>2]=1;z=C;i=h;return z|0}function kZa(a){a=a|0;fGb((c[a+60>>2]|0)+4|0);return 0}function lZa(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+140|0;d=qKb(c[b>>2]|0)|0;e=c[a+60>>2]|0;f=a+804|0;c[f>>2]=e;S4a(e);c[(c[f>>2]|0)+88>>2]=1;c[a+792>>2]=oKb(d)|0;d=a+52|0;if((c[d>>2]|0)!=0){return 0}c[d>>2]=hZa(c[b>>2]|0)|0;return 0}function mZa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=b+140|0;h=b+120|0;i=b+124|0;j=c2(c[g>>2]|0,c[h>>2]|0,c[i>>2]|0)|0;if((j|0)<0){k=j;return k|0}l=d5a(b,d,j,(j|0)<0|0?-1:0)|0;if((l|0)<0){k=l;return k|0}l=d+24|0;j=b2(e,c[g>>2]|0,c[h>>2]|0,c[i>>2]|0,c[l>>2]|0,c[d+28>>2]|0)|0;if((j|0)<0){k=j;return k|0}do{if((c[b+52>>2]|0)==846624121&(j|0)>0){if((c[g>>2]|0)!=1){break}if((ca(c[i>>2]<<1,c[h>>2]|0)|0)>1){m=1}else{break}do{e=(c[l>>2]|0)+m|0;a[e]=a[e]^-128;m=m+2|0;}while((m|0)<(ca(c[i>>2]<<1,c[h>>2]|0)|0))}}while(0);h=d+36|0;c[h>>2]=c[h>>2]|1;c[f>>2]=1;k=0;return k|0}function nZa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0.0,j=0,k=0,l=0.0,m=0,n=0,o=0.0,p=0,q=0,r=0;e=1<<b;f=(d|0)==0;do{if(f){c[a>>2]=b;c[a+4>>2]=0;h=0;i=-6.283185307179586/+(e|0);j=6}else{k=(d|0)==3;l=(k?-6.283185307179586:6.283185307179586)/+(e|0);c[a>>2]=b;if((d|0)==1){c[a+4>>2]=1;h=1;i=l;j=6;break}else{c[a+4>>2]=k&1;if((d|0)==2){m=1;n=0;o=l;p=1;break}else{h=0;i=l;j=6;break}}}}while(0);if((j|0)==6){m=(d|0)==3?1:-1;n=h;o=i;p=0}c[a+8>>2]=m;if((b-4|0)>>>0>12>>>0){q=-1;return q|0}if((pda(a+20|0,b-1|0,n?1:p)|0)<0){q=-1;return q|0}oda(b);c[a+12>>2]=c[1405944+(b<<2)>>2];p=c[1305952+(b<<2)>>2]|0;if(f){r=1}else{r=(d|0)==3|0}d=e>>2;e=d&-r;c[a+16>>2]=p+(e<<2);if((d|0)>0){r=0;do{g[p+(e+r<<2)>>2]=+V(o*+(r|0));r=r+1|0;}while((r|0)<(d|0))}c[a+84>>2]=316;q=0;return q|0}function oZa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0,w=0.0,x=0.0,y=0,z=0;d=1<<c[a>>2];e=a+4|0;f=c[e>>2]|0;h=.5- +(f|0);i=c[a+12>>2]|0;j=c[a+16>>2]|0;if((f|0)==0){f=a+20|0;k=b;re[c[a+52>>2]&1023](f,k);re[c[a+56>>2]&1023](f,k)}l=+g[b>>2];k=b+4|0;m=+g[k>>2];g[b>>2]=l+m;g[k>>2]=l-m;f=d>>2;if((f|0)>1){m=-0.0-h;n=1;do{o=n<<1;p=d-o|0;q=b+(o<<2)|0;l=+g[q>>2];r=b+(p<<2)|0;s=+g[r>>2];t=(l+s)*.5;u=(l-s)*m;v=b+((o|1)<<2)|0;s=+g[v>>2];o=b+(p+1<<2)|0;l=+g[o>>2];w=(s-l)*.5;x=h*(s+l);p=i+(n<<2)|0;y=j+(n<<2)|0;g[q>>2]=t+ +g[p>>2]*x-u*+g[y>>2];g[v>>2]=w+u*+g[p>>2]+x*+g[y>>2];g[r>>2]=t-x*+g[p>>2]+u*+g[y>>2];g[o>>2]=u*+g[p>>2]-w+x*+g[y>>2];n=n+1|0;}while((n|0)<(f|0));z=f<<1|1}else{z=3}f=b+(z<<2)|0;g[f>>2]=+(c[a+8>>2]|0)*+g[f>>2];if((c[e>>2]|0)==0){return}g[b>>2]=+g[b>>2]*.5;g[k>>2]=+g[k>>2]*.5;k=a+20|0;e=b;re[c[a+52>>2]&1023](k,e);re[c[a+56>>2]&1023](k,e);return}function pZa(a){a=a|0;tda(a+20|0);return}function qZa(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+1024|0;g=b|0;h=d;j=c[f+24>>2]|0;SFb(g,0,4096);k=f+28|0;do{if((j|0)!=0){if((c[k>>2]|0)>0){l=j;m=1}else{break}a:while(1){n=a[l]|0;do{if((n<<24>>24|0)==0){break a}else if((n<<24>>24|0)==60){o=_b(l|0,62)|0;if((o|0)==0){break a}if((JFb(l,2447360,5)|0)!=0){if((JFb(l,2358e3,4)|0)!=0){p=o;q=m;break}}UFb(g,2294768,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;p=o;q=m}else{do{if((OFb(n<<24>>24)|0)==0){WFb(g,a[l]|0,1)}else{if((m|0)!=0){break}WFb(g,32,1)}}while(0);p=l;q=OFb(a[l]|0)|0}}while(0);l=p+1|0;m=q}UFb(g,2243680,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;fmb(h,c[g>>2]|0,c[f+8>>2]|0,c[f+48>>2]|0,0)|0}}while(0);c[e>>2]=(c[d+12>>2]|0)!=0;_Fb(g,0)|0;i=b;return c[k>>2]|0}function rZa(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=c[a+60>>2]|0;g=f;c[f>>2]=a;c[a+140>>2]=11;h=a+96|0;j=c[h>>2]|0;do{if((j|0)!=0){k=a+100|0;if((c[k>>2]|0)<774){break}l=j;m=(d[l]|d[l+1|0]<<8)<<16>>16;b[f+4>>1]=m;l=j+2|0;c[f+8>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24;l=a+120|0;n=a+124|0;if((m&65535|0)>=(ca(c[n>>2]|0,c[l>>2]|0)|0)){KIb(a,16,2357976,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=e;return p|0}m=f+16|0;q=0;do{r=q*3|0;c[m+(q<<2)>>2]=(d[j+(r+6)|0]|0)<<16|(d[j+(r+7)|0]|0)<<8|(d[j+(r+8)|0]|0)|-16777216;q=q+1|0;}while((q|0)<256);q=(c[k>>2]|0)-774|0;if((q|0)<=0){p=0;i=e;return p|0}m=pJb(ca(c[n>>2]|0,c[l>>2]|0)|0)|0;if((m|0)==0){p=-12;i=e;return p|0}uZa(g,(c[h>>2]|0)+774|0,q,m,c[l>>2]|0,0);c[f+12>>2]=m;p=0;i=e;return p|0}}while(0);KIb(a,16,2447336,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-22;i=e;return p|0}function sZa(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=c[f+24>>2]|0;h=c[f+28>>2]|0;f=c[a+60>>2]|0;i=M4a(a,b,0)|0;if((i|0)<0){j=i;return j|0}uZa(f,g,h,c[b>>2]|0,c[b+32>>2]|0,e[f+4>>1]|0);nrc(c[b+4>>2]|0,f+16|0,1024)|0;c[d>>2]=1;j=h;return j|0}function tZa(a){a=a|0;kJb(c[(c[a+60>>2]|0)+12>>2]|0);return 0}function uZa(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=b|0;j=c[i>>2]|0;k=c[j+120>>2]|0;l=(h|0)%(k|0)|0;m=(h|0)/(k|0)|0;h=g-k|0;n=b+12|0;b=c[n>>2]|0;o=d+e|0;p=f+(ca(c[j+124>>2]|0,g)|0)|0;if((m|0)<0){q=b;r=f;s=k}else{j=ca(m+1|0,g)|0;t=1;u=b;v=f;w=k;k=b;while(1){if((k|0)==0){x=w}else{nrc(v|0,u|0,w)|0;x=c[(c[i>>2]|0)+120>>2]|0}y=u+x|0;if((t|0)>(m|0)){break}t=t+1|0;u=y;v=v+g|0;w=x;k=c[n>>2]|0}q=y;r=f+j|0;s=x}x=q+(l-s)|0;s=r+(-h|0)|0;q=r+(l-g)|0;a:do{if((e|0)>0){l=p;r=h+1|0;j=x;f=q;y=d;k=s;while(1){w=y+1|0;v=a[y]|0;if(v<<24>>24<0){if(!(w>>>0<o>>>0)){z=j;A=f;B=k;break a}u=a[w]|0;if(u<<24>>24==0){z=j;A=f;B=k;break a}else{C=u&255;D=y+2|0}}else{C=1;D=w}if((C|0)>=(l-f|0)){z=j;A=f;B=k;break a}b:do{if((c[n>>2]|0)==0){E=v&127;F=18}else{w=v|-128;if(w<<24>>24==-128){G=C;H=k;I=f;J=j}else{E=w;F=18;break}while(1){w=G;u=I;t=J;while(1){K=w-1|0;if((w|0)==0){L=H;M=u;N=t;break b}m=u+1|0;a[u]=a[t]|0;O=t+1|0;if((m|0)==(H|0)){break}else{w=K;u=m;t=O}}t=u+r|0;w=H+g|0;if((K|0)<(l-t|0)){G=K;H=w;I=t;J=O}else{L=w;M=t;N=O;break}}}}while(0);c:do{if((F|0)==18){F=0;v=C;t=k;w=f;m=j;while(1){i=v;b=w;P=m;while(1){Q=i-1|0;if((i|0)==0){L=t;M=b;N=P;break c}R=b+1|0;a[b]=E;S=P+1|0;if((R|0)==(t|0)){break}else{i=Q;b=R;P=S}}P=b+r|0;i=t+g|0;if((Q|0)<(l-P|0)){v=Q;t=i;w=P;m=S}else{L=i;M=P;N=S;break}}}}while(0);if(D>>>0<o>>>0){j=N;f=M;y=D;k=L}else{z=N;A=M;B=L;break}}}else{z=x;A=q;B=s}}while(0);if((c[n>>2]|0)!=0&A>>>0<p>>>0){T=z;U=A;V=B}else{return}while(1){B=V-U|0;nrc(U|0,T|0,B)|0;A=V+h|0;if(A>>>0<p>>>0){T=T+B|0;U=A;V=V+g|0}else{break}}return}function vZa(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a+60|0;f=c[e>>2]|0;g=c[a+416>>2]|0;if((g|0)>2){KIb(a,16,2447296,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=d;return j|0}if((c[a+412>>2]|0)!=22050){KIb(a,16,2357952,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-22;i=d;return j|0}c[a+424>>2]=735;c[a+72>>2]=(g*176400|0)+1920;a=hJb(g*11760|0)|0;c[f+12>>2]=a;if((a|0)==0){mJb((c[e>>2]|0)+12|0);j=-12;i=d;return j|0}else{b[f+2>>1]=0;b[f>>1]=0;j=0;i=d;return j|0}return 0}function wZa(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;a:do{if((h|0)==0){j=f+416|0;k=c[f+60>>2]|0;l=j;m=(c[j>>2]|0)==2;n=4}else{j=c[h>>2]|0;o=j;p=c[f+60>>2]|0;q=f+416|0;r=c[q>>2]|0;s=(r|0)==2;if((j|0)==0){k=p;l=q;m=s;n=4;break}t=p+4|0;u=c[t>>2]|0;if((u|0)>=8){v=p+4|0;if(s){w=v;x=p;z=q;A=u;B=o;n=16;break}C=o;D=0;E=q;F=p;H=v;I=c[q>>2]|0;n=19;break}v=p+8|0;u=ca(r,c[v>>2]|0)|0;J=f+424|0;nrc((c[p+12>>2]|0)+(u<<1)|0,j|0,ca(r<<1,c[J>>2]|0)|0)|0;c[v>>2]=(c[v>>2]|0)+(c[J>>2]|0);J=c[t>>2]|0;do{if((J|0)==0){v=h+136|0;r=c[v+4>>2]|0;j=p+16|0;c[j>>2]=c[v>>2];c[j+4>>2]=r}else{if((J|0)<7){break}r=p+4|0;if((J|0)<8){j=c[p+12>>2]|0;if(s){w=r;x=p;z=q;A=7;B=j;n=16;break a}else{K=r;L=p;M=q;N=0;O=7;P=j;n=17;break a}}else{if(s){w=r;x=p;z=q;A=J;B=o;n=16;break a}else{K=r;L=p;M=q;N=0;O=J;P=o;n=17;break a}}}}while(0);c[t>>2]=J+1;Q=0;return Q|0}}while(0);do{if((n|0)==4){o=c[k+4>>2]|0;if((o|0)>7){Q=0;return Q|0}else{q=k+4|0;p=c[k+12>>2]|0;if(m){w=q;x=k;z=l;A=o;B=p;n=16;break}else{K=q;L=k;M=l;N=0;O=o;P=p;n=17;break}}}}while(0);if((n|0)==16){l=x;b[l>>1]=b[l>>1]&-256;l=x+2|0;b[l>>1]=b[l>>1]&-256;K=w;L=x;M=z;N=1;O=A;P=B;n=17}do{if((n|0)==17){B=c[M>>2]|0;if((O|0)!=7){C=P;D=N;E=M;F=L;H=K;I=B;n=19;break}R=L+8|0;S=P;T=N;U=M;V=L;W=K;X=B}}while(0);if((n|0)==19){R=f+424|0;S=C;T=D;U=E;V=F;W=H;X=I}I=ca(c[R>>2]|0,X)|0;X=I+8|0;R=d5a(f,g,X,(X|0)<0|0?-1:0)|0;if((R|0)<0){Q=R;return Q|0}R=c[g+24>>2]|0;a[R]=T?33:32;a[R+1|0]=16;X=R+2|0;y=I;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=R+6|0;f=V;if(T){a[X]=(e[V+2>>1]|0)>>>8;a[R+7|0]=(e[V>>1]|0)>>>8}else{T=X;y=b[V>>1]|0;a[T]=y;y=y>>8;a[T+1|0]=y}if((I|0)>0){T=R+8|0;R=0;X=S;while(1){H=f+((R&1)<<1)|0;F=X+2|0;E=b[H>>1]|0;D=(b[X>>1]|0)-E|0;C=(D|0)<0;n=D>>>31;K=(D|0)>-1?D:-D|0;if((K|0)>16128){Y=127}else{if(K>>>0<255>>>0){Z=(d[K+1303321|0]|0)-1>>4}else{do{if(K>>>0<4096>>>0){_=(d[1303320+(K>>>4)|0]|0)>>>2}else{if(K>>>0<16384>>>0){_=(d[1303320+(K>>>6)|0]|0)>>>1;break}else{D=K>>>16;L=(D&65280|0)==0;M=((d[1359664+(L?D:K>>>24)|0]|0)+(L?0:8)|0)>>>1;L=K>>>((M+2|0)>>>0);D=d[1303320+(L>>>((M+8|0)>>>0))|0]|0;Erc(L,0,c[1367848+(D<<2)>>2]|0,0)|0;_=G+(D<<M)|0;break}}}while(0);Z=_-((ca(_,_)|0)>>>0>K>>>0)|0}Y=((K|0)>((ca(Z,Z)|0)+Z|0))+Z|0}if(C){J=Y;while(1){t=E-(ca(J,J)|0)|0;if((t+32768|0)>>>0>65535>>>0){J=J-1|0}else{$=J;aa=t&65535;break}}}else{J=Y;while(1){C=(ca(J,J)|0)+E|0;if((C+32768|0)>>>0>65535>>>0){J=J-1|0}else{$=J;aa=C&65535;break}}}b[H>>1]=aa;a[T]=$|n<<7;J=R+1|0;if((J|0)<(I|0)){T=T+1|0;R=J;X=F}else{break}}ba=S+(I<<1)|0}else{ba=S}if((c[W>>2]|0)<8){da=V+16|0}else{da=h+136|0}h=c[da+4>>2]|0;V=g+8|0;c[V>>2]=c[da>>2];c[V+4>>2]=h;c[g+48>>2]=(I|0)/(c[U>>2]|0)|0;U=(c[W>>2]|0)+1|0;if((ba|0)==0){ea=(U|0)>8?U:8}else{ea=U}c[W>>2]=ea;c[i>>2]=1;Q=0;return Q|0}function xZa(a){a=a|0;mJb((c[a+60>>2]|0)+12|0);return 0}function yZa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a+60>>2]|0;c[d+4>>2]=a;e=c[a+120>>2]|0;do{if((e&15|0)==0){f=a+124|0;if((c[f>>2]&15|0)!=0){break}c[d+5664>>2]=e;c[d+5668>>2]=c[f>>2];f=d+8|0;c[f>>2]=UHb()|0;g=UHb()|0;h=d+12|0;c[h>>2]=g;do{if((g|0)!=0){if((c[f>>2]|0)==0){break}c[a+140>>2]=5;j=0;i=b;return j|0}}while(0);VHb(h);VHb(f);j=-12;i=b;return j|0}}while(0);KIb(a,16,2170456,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;j=-1163346256;i=b;return j|0}function zZa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;h=i;i=i+32|0;j=h|0;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=g;n=g+12|0;o=c[n>>2]|0;p=c[o>>2]|0;q=N4a(b,o)|0;if((q|0)<0){r=q;i=h;return r|0}if((p|0)==0){f2(c[n>>2]|0,c[g+8>>2]|0,c[b+140>>2]|0,c[b+120>>2]|0,c[b+124>>2]|0)}if(!((l|0)>-1)){KIb(0,0,2294736,(s=i,i=i+24|0,c[s>>2]=2243664,c[s+8>>2]=2202232,c[s+16>>2]=135,s)|0);i=s;Hd();return 0}b=g+5652|0;c[b>>2]=k;p=g+5660|0;c[p>>2]=k;q=k+l|0;o=g+5656|0;c[o>>2]=q;mrc(j|0,0,32)|0;if(l>>>0>7>>>0){t=q;u=k;a:while(1){v=t;if((v-u|0)<2){w=0;x=u}else{y=u+2|0;c[b>>2]=y;z=u;w=(d[z]|d[z+1|0]<<8)<<16>>16&65535;x=y}if((v-x|0)<4){A=0;B=x}else{y=x+4|0;c[b>>2]=y;z=x;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;B=y}if((v-B|0)<2){C=0;D=B}else{v=B+2|0;c[b>>2]=v;y=B;C=(d[y]|d[y+1|0]<<8)<<16>>16&65535;D=v}E=C>>>8;do{if((w|0)==4113){F=D;H=t;break a}else if((w|0)==4098){v=(E|0)==0?256:E;y=C&255;if((y|0)==0){I=(v*6|0)>>>0<A>>>0?256:0}else{I=y}y=0;z=t;J=D;while(1){if((z-J|0)<1){K=0}else{c[b>>2]=J+1;K=a[J]|0}a[m+20+(y*6|0)|0]=K;L=c[b>>2]|0;if(((c[o>>2]|0)-L|0)<1){M=0}else{c[b>>2]=L+1;M=a[L]|0}a[m+20+(y*6|0)+1|0]=M;L=c[b>>2]|0;if(((c[o>>2]|0)-L|0)<1){N=0}else{c[b>>2]=L+1;N=a[L]|0}a[m+20+(y*6|0)+2|0]=N;L=c[b>>2]|0;if(((c[o>>2]|0)-L|0)<1){O=0}else{c[b>>2]=L+1;O=a[L]|0}a[m+20+(y*6|0)+3|0]=O;L=c[b>>2]|0;if(((c[o>>2]|0)-L|0)<1){P=0}else{c[b>>2]=L+1;P=a[L]|0}a[m+20+(y*6|0)+4|0]=P;L=c[b>>2]|0;if(((c[o>>2]|0)-L|0)<1){Q=0}else{c[b>>2]=L+1;Q=a[L]|0}a[m+20+(y*6|0)+5|0]=Q;L=y+1|0;if((L|0)>=(v|0)){break}y=L;z=c[o>>2]|0;J=c[b>>2]|0}if((I|0)==0){R=c[b>>2]|0;S=c[o>>2]|0;break}J=0;z=c[o>>2]|0;y=c[b>>2]|0;while(1){v=z;if((v-y|0)<1){T=0}else{c[b>>2]=y+1;T=d[y]|0}c[m+1556+(J<<4)>>2]=T;L=c[b>>2]|0;if((v-L|0)<1){U=0;V=L}else{v=L+1|0;c[b>>2]=v;U=d[L]|0;V=v}c[m+1556+(J<<4)+4>>2]=U;v=c[o>>2]|0;L=v;if((L-V|0)<1){W=0;X=V}else{Y=V+1|0;c[b>>2]=Y;W=d[V]|0;X=Y}c[m+1556+(J<<4)+8>>2]=W;if((L-X|0)<1){Z=0;_=X}else{L=X+1|0;c[b>>2]=L;Z=d[X]|0;_=L}c[m+1556+(J<<4)+12>>2]=Z;L=J+1|0;if((L|0)<(I|0)){J=L;z=v;y=_}else{R=_;S=v;break}}}else{R=D;S=t}}while(0);if((S-R|0)>>>0>7>>>0){t=S;u=R}else{F=R;H=S;break}}$=E<<24>>24;aa=C<<24>>24;ba=A;ca=F;da=H;ea=c[p>>2]|0}else{$=0;aa=0;ba=0;ca=k;da=q;ea=k}k=ca;q=k-ea|0;if(ba>>>0>(da-k|0)>>>0){KIb(c[g+4>>2]|0,16,2447256,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;k=c[b>>2]|0;fa=(c[o>>2]|0)-k|0;ga=k;ha=c[p>>2]|0}else{fa=ba;ga=ca;ha=ea}ea=wrc(fa,0,q,(q|0)<0|0?-1:0)|0;q=G;fa=8-$|0;$=8-aa|0;aa=g+5664|0;ca=g+5668|0;ba=ga-ha|0;ha=(ba|0)<0|0?-1:0;b:do{if((ha|0)<(q|0)|(ha|0)==(q|0)&ba>>>0<ea>>>0){ga=0;k=-1;da=0;H=0;c:while(1){F=H+16|0;A=da+16|0;C=ga;E=k;S=H;while(1){R=S+4|0;u=C;t=E;D=da;while(1){_=c[b>>2]|0;I=_;Z=c[p>>2]|0;X=I-Z|0;W=(X|0)<0|0?-1:0;if(!((W|0)<(q|0)|(W|0)==(q|0)&X>>>0<ea>>>0)){ia=45;break c}do{if((t|0)<0){if(((c[o>>2]|0)-I|0)<2){ja=7;ka=0;la=_;break}X=_+2|0;c[b>>2]=X;W=_;ja=7;ka=(d[W]|d[W+1|0]<<8)<<16>>16&65535;la=X}else{ja=t;ka=u;la=_}}while(0);_=ka>>(ja<<1)&3;I=j+(_<<2)|0;c[I>>2]=(c[I>>2]|0)+1;I=ja-1|0;d:do{if((_|0)==3){X=D+4|0;W=la;V=W-Z|0;U=(V|0)<0|0?-1:0;if((U|0)<(q|0)|(U|0)==(q|0)&V>>>0<ea>>>0){ma=la;na=I;oa=ka;pa=0;qa=D;ra=S;sa=W}else{ia=57;break c}while(1){do{if((na|0)<0){if(((c[o>>2]|0)-sa|0)<2){ta=7;ua=0;va=ma;break}W=ma+2|0;c[b>>2]=W;V=ma;ta=7;ua=(d[V]|d[V+1|0]<<8)<<16>>16&65535;va=W}else{ta=na;ua=oa;va=ma}}while(0);W=ua>>(ta<<1)&3;V=j+16+(W<<2)|0;c[V>>2]=(c[V>>2]|0)+1;V=ta-1|0;if((W|0)==1){if(((c[o>>2]|0)-va|0)<1){wa=0}else{c[b>>2]=va+1;wa=d[va]|0}csb(m,qa,ra,fa-(wa>>>4)|0,$-(wa&15)|0)}else if((W|0)==2){if(((c[o>>2]|0)-va|0)<1){xa=0}else{c[b>>2]=va+1;xa=d[va]|0}asb(m,qa,ra,m+20+((c[m+1556+(xa<<4)>>2]|0)*6|0)|0);U=qa+2|0;asb(m,U,ra,m+20+((c[m+1556+(xa<<4)+4>>2]|0)*6|0)|0);T=ra+2|0;asb(m,qa,T,m+20+((c[m+1556+(xa<<4)+8>>2]|0)*6|0)|0);asb(m,U,T,m+20+((c[m+1556+(xa<<4)+12>>2]|0)*6|0)|0)}else if((W|0)==3){if(((c[o>>2]|0)-va|0)<1){ya=0}else{c[b>>2]=va+1;ya=d[va]|0}asb(m,qa,ra,m+20+(ya*6|0)|0);W=qa+2|0;T=c[b>>2]|0;if(((c[o>>2]|0)-T|0)<1){za=0}else{c[b>>2]=T+1;za=d[T]|0}asb(m,W,ra,m+20+(za*6|0)|0);T=ra+2|0;U=c[b>>2]|0;if(((c[o>>2]|0)-U|0)<1){Aa=0}else{c[b>>2]=U+1;Aa=d[U]|0}asb(m,qa,T,m+20+(Aa*6|0)|0);U=c[b>>2]|0;if(((c[o>>2]|0)-U|0)<1){Ba=0}else{c[b>>2]=U+1;Ba=d[U]|0}asb(m,W,T,m+20+(Ba*6|0)|0)}T=pa+1|0;if((T|0)>=4){Ca=V;Da=ua;break d}W=c[b>>2]|0;U=W;Q=U-(c[p>>2]|0)|0;P=(Q|0)<0|0?-1:0;if((P|0)<(q|0)|(P|0)==(q|0)&Q>>>0<ea>>>0){ma=W;na=V;oa=ua;pa=T;qa=(T&1|0)==0?D:X;ra=(T&2|0)==0?S:R;sa=U}else{ia=57;break c}}}else if((_|0)==2){if(((c[o>>2]|0)-la|0)<1){Ea=0}else{c[b>>2]=la+1;Ea=d[la]|0}bsb(m,D,S,m+20+((c[m+1556+(Ea<<4)>>2]|0)*6|0)|0);X=D+4|0;bsb(m,X,S,m+20+((c[m+1556+(Ea<<4)+4>>2]|0)*6|0)|0);bsb(m,D,R,m+20+((c[m+1556+(Ea<<4)+8>>2]|0)*6|0)|0);bsb(m,X,R,m+20+((c[m+1556+(Ea<<4)+12>>2]|0)*6|0)|0);Ca=I;Da=ka}else if((_|0)==1){if(((c[o>>2]|0)-la|0)<1){Fa=0}else{c[b>>2]=la+1;Fa=d[la]|0}esb(m,D,S,fa-(Fa>>>4)|0,$-(Fa&15)|0);Ca=I;Da=ka}else{Ca=I;Da=ka}}while(0);I=D+8|0;if((I|0)<(A|0)){u=Da;t=Ca;D=I}else{break}}D=S+8|0;if((D|0)<(F|0)){C=Da;E=Ca;S=D}else{break}}S=c[aa>>2]|0;E=(A|0)<(S|0);C=E?H:F;if((C|0)>=(c[ca>>2]|0)){break b}D=(c[b>>2]|0)-(c[p>>2]|0)|0;t=(D|0)<0|0?-1:0;if((t|0)<(q|0)|(t|0)==(q|0)&D>>>0<ea>>>0){ga=Da;k=Ca;da=A-(E?0:S)|0;H=C}else{break b}}if((ia|0)==45){KIb(c[g+4>>2]|0,40,2357920,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;break}else if((ia|0)==57){KIb(c[g+4>>2]|0,40,2357920,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;break}}}while(0);s=YHb(e,c[n>>2]|0)|0;if((s|0)<0){r=s;i=h;return r|0}c[f>>2]=1;f=g+8|0;g=c[f>>2]|0;c[f>>2]=c[n>>2];c[n>>2]=g;r=l;i=h;return r|0}function AZa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+12|0);VHb(b+8|0);return 0}function BZa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;d=a+60|0;e=c[d>>2]|0;AIb(e+5672|0,1);f=e+5960|0;c[f>>2]=0;g=a+120|0;h=c[g>>2]|0;do{if((h&15|0)==0){j=a+124|0;k=c[j>>2]|0;if((k&15|0)!=0){break}if((h-1&h|0)==0){if((k-1&k|0)==0){l=h}else{m=6}}else{m=6}if((m|0)==6){KIb(a,16,2294688,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=c[g>>2]|0}k=e+5664|0;c[k>>2]=l;o=e+5668|0;c[o>>2]=c[j>>2];c[f>>2]=0;c[e+16>>2]=1;j=e+8|0;c[j>>2]=UHb()|0;p=UHb()|0;c[e+12>>2]=p;if((c[j>>2]|0)==0|(p|0)==0){p=c[d>>2]|0;VHb(p+12|0);VHb(p+8|0);kJb(c[p+5972>>2]|0);kJb(c[p+5944>>2]|0);kJb(c[p+5948>>2]|0);kJb(c[p+5952>>2]|0);kJb(c[p+5956>>2]|0);q=-12;i=b;return q|0}else{c[e+5972>>2]=hJb(70700)|0;c[e+5944>>2]=pJb(((ca(c[o>>2]|0,c[k>>2]|0)|0)/16|0)<<3)|0;c[e+5948>>2]=hJb(((ca(c[o>>2]|0,c[k>>2]|0)|0)/16|0)<<3)|0;c[e+5952>>2]=pJb(((ca(c[o>>2]|0,c[k>>2]|0)|0)/64|0)<<3)|0;c[e+5956>>2]=hJb(((ca(c[o>>2]|0,c[k>>2]|0)|0)/64|0)<<3)|0;q=0;i=b;return q|0}}}while(0);KIb(a,16,2357880,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;q=-22;i=b;return q|0}function CZa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;h=i;i=i+288|0;j=h|0;k=h+80|0;l=h+272|0;m=c[b+60>>2]|0;n=m;o=m+4|0;c[o>>2]=b;p=m+5964|0;c[p>>2]=f;q=c[f+168>>2]|0;if((q|0)==0){f=m+5936|0;c[f>>2]=256;c[f+4>>2]=0}else{f=q-1|0;q=m+5936|0;c[q>>2]=f;c[q+4>>2]=(f|0)<0|0?-1:0}f=m+5664|0;q=m+5668|0;r=(((((ca(c[q>>2]|0,c[f>>2]|0)|0)/64|0)*138|0)+7|0)/8|0)+2568|0;s=d5a(b,e,r,(r|0)<0|0?-1:0)|0;if((s|0)<0){t=s;i=h;return t|0}s=e+24|0;r=m+5968|0;c[r>>2]=c[s>>2];u=m+5960|0;if((c[u>>2]|0)==(c[b+136>>2]|0)){c[u>>2]=0}v=m+16|0;do{if((c[v>>2]|0)!=0){w=M4a(b,c[m+12>>2]|0,0)|0;if((w|0)<0){t=w;i=h;return t|0}w=M4a(b,c[m+8>>2]|0,0)|0;if((w|0)<0){t=w;i=h;return t|0}else{w=c[r>>2]|0;y=4097;a[w]=y;y=y>>8;a[w+1|0]=y;w=(c[r>>2]|0)+2|0;c[r>>2]=w;x=w;y=8;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;x=(c[r>>2]|0)+4|0;c[r>>2]=x;a[x]=0;x=(c[r>>2]|0)+1|0;c[r>>2]=x;a[x]=0;x=(c[r>>2]|0)+1|0;c[r>>2]=x;w=x;y=c[f>>2]&65535;a[w]=y;y=y>>8;a[w+1|0]=y;w=(c[r>>2]|0)+2|0;c[r>>2]=w;x=w;y=c[q>>2]&65535;a[x]=y;y=y>>8;a[x+1|0]=y;x=(c[r>>2]|0)+2|0;c[r>>2]=x;a[x]=8;x=(c[r>>2]|0)+1|0;c[r>>2]=x;a[x]=0;x=(c[r>>2]|0)+1|0;c[r>>2]=x;a[x]=4;x=(c[r>>2]|0)+1|0;c[r>>2]=x;a[x]=0;c[r>>2]=(c[r>>2]|0)+1;c[v>>2]=0;break}}}while(0);v=c[m+5972>>2]|0;mrc(v|0,0,70700)|0;b=hJb(((ca(c[q>>2]|0,c[f>>2]|0)|0)/64|0)*248|0)|0;x=v|0;c[x>>2]=b;w=c[q>>2]|0;z=c[f>>2]|0;if((w|0)>0){A=(z|0)>0;B=0;C=0;while(1){if(A){D=C|8;E=B;H=0;while(1){c[b+(E*248|0)+240>>2]=H;I=E+1|0;c[b+(E*248|0)+244>>2]=C;J=H|8;c[b+(I*248|0)+240>>2]=J;K=E+2|0;c[b+(I*248|0)+244>>2]=C;c[b+(K*248|0)+240>>2]=H;I=E+3|0;c[b+(K*248|0)+244>>2]=D;c[b+(I*248|0)+240>>2]=J;c[b+(I*248|0)+244>>2]=D;I=E+4|0;J=H+16|0;if((J|0)<(z|0)){E=I;H=J}else{L=I;break}}}else{L=B}H=C+16|0;if((H|0)<(w|0)){B=L;C=H}else{break}}}C=(ca(z,w)|0)/16|0;w=hJb(6144)|0;z=w;L=C*96|0;B=hJb(L)|0;b=hJb(L)|0;L=b;A=c[p>>2]|0;H=c[f>>2]|0;E=c[q>>2]|0;a:do{if((E|0)>0){D=A|0;I=A+32|0;J=A+36|0;K=A+4|0;M=A+8|0;if((H|0)>0){N=B;O=0}else{P=0;while(1){P=P+4|0;if((P|0)>=(E|0)){break a}}}while(1){P=N;S=0;do{T=0;do{U=T<<1;V=U+O|0;W=V|1;X=0;do{Y=(X+U|0)*6|0;Z=(X<<1)+S|0;_=(ca(c[I>>2]|0,V)|0)+Z|0;a[P+Y|0]=a[(c[D>>2]|0)+_|0]|0;_=(ca(c[J>>2]|0,V)|0)+Z|0;$=d[(c[K>>2]|0)+_|0]|0;aa=d[(c[M>>2]|0)+_|0]|0;_=Z|1;da=(ca(c[I>>2]|0,V)|0)+_|0;a[P+(Y|1)|0]=a[(c[D>>2]|0)+da|0]|0;da=(ca(c[J>>2]|0,V)|0)+_|0;ea=d[(c[K>>2]|0)+da|0]|0;fa=d[(c[M>>2]|0)+da|0]|0;da=(ca(c[I>>2]|0,W)|0)+Z|0;a[P+(Y+2)|0]=a[(c[D>>2]|0)+da|0]|0;da=(ca(c[J>>2]|0,W)|0)+Z|0;Z=d[(c[K>>2]|0)+da|0]|0;ga=d[(c[M>>2]|0)+da|0]|0;da=(ca(c[I>>2]|0,W)|0)+_|0;a[P+(Y+3)|0]=a[(c[D>>2]|0)+da|0]|0;da=(ca(c[J>>2]|0,W)|0)+_|0;_=d[(c[M>>2]|0)+da|0]|0;a[P+(Y+4)|0]=($+2+ea+Z+(d[(c[K>>2]|0)+da|0]|0)|0)>>>2;a[P+(Y+5)|0]=(aa+2+fa+ga+_|0)>>>2;X=X+1|0;}while((X|0)<2);T=T+1|0;}while((T|0)<2);P=P+24|0;S=S+4|0;}while((S|0)<(H|0));S=O+4|0;if((S|0)<(E|0)){N=P;O=S}else{break}}}}while(0);O=C*24|0;if((O|0)>0){N=0;do{c[L+(N<<2)>>2]=d[B+N|0]|0;N=N+1|0;}while((N|0)<(O|0))}O=m+5976|0;HZa(n,v,L,C,z,4,(c[O>>2]|0)!=0?255:256);N=v+4112|0;c[N>>2]=(c[O>>2]|0)!=0?255:256;E=v+70680|0;c[E>>2]=hJb(C<<4)|0;HZa(n,v,L,C<<2,m+20|0,2,256);C=v+4116|0;c[C>>2]=256;L=0;do{H=L*12|0;A=n+20+(L*6|0)|0;K=v+6168+H|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;mrc(H+4+(v+6168)|0,a[n+20+(L*6|0)+4|0]|0,4)|0;mrc(H+8+(v+6168)|0,a[n+20+(L*6|0)+5|0]|0,4)|0;L=L+1|0;}while((L|0)<(c[C>>2]|0));if((c[N>>2]|0)>0){L=0;do{H=L<<2;K=0;do{A=K+H|0;M=z+(A*6|0)|0;J=d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0;M=c[C>>2]|0;D=n+1556+(L<<4)+(K<<2)|0;I=J>>>24;if((M|0)>0){S=J&255;T=J>>>8&255;X=J>>>16&255;J=d[z+(A*6|0)+4|0]|0;W=d[z+(A*6|0)+5|0]|0;A=2147483647;V=0;U=0;while(1){_=U*12|0;ga=_|1;fa=(d[v+6168+_|0]|0)-S|0;aa=(d[v+6168+ga|0]|0)-T|0;Y=ca(aa,aa)|0;aa=(d[ga+1+(v+6168)|0]|0)-X|0;ga=ca(aa,aa)|0;aa=(d[(_|3)+(v+6168)|0]|0)-I|0;da=ca(aa,aa)|0;aa=(d[_+4+(v+6168)|0]|0)-J|0;Z=(d[_+5+(v+6168)|0]|0)-J|0;ea=ca(Z,Z)|0;Z=(d[_+6+(v+6168)|0]|0)-J|0;$=ca(Z,Z)|0;Z=(d[_+7+(v+6168)|0]|0)-J|0;ia=ca(Z,Z)|0;Z=Y+(ca(fa,fa)|0)+ga+da|0;da=(d[_+8+(v+6168)|0]|0)-W|0;ga=ca(da,da)|0;da=(d[_+9+(v+6168)|0]|0)-W|0;fa=ca(da,da)|0;da=(d[_+10+(v+6168)|0]|0)-W|0;Y=ca(da,da)|0;da=(d[_+11+(v+6168)|0]|0)-W|0;_=ea+(ca(aa,aa)|0)+(Z<<2)+$+ia+ga+fa+Y+(ca(da,da)|0)|0;da=(_|0)<(A|0);Y=da?U:V;fa=U+1|0;if((fa|0)<(M|0)){A=da?_:A;V=Y;U=fa}else{ja=Y;break}}}else{ja=0}c[D>>2]=ja;K=K+1|0;}while((K|0)<4);K=L*48|0;H=0;do{U=H<<2;V=H<<4;A=V+K|0;M=(V|1)+K|0;W=(V|4)+K|0;J=(V|5)+K|0;V=0;do{I=n+1556+(L<<4)+(V<<2)|0;X=c[284480+(V<<2)>>2]|0;a[A+X+(v+9240)|0]=a[((c[I>>2]|0)*12|0)+U+(v+6168)|0]|0;a[M+X+(v+9240)|0]=a[(((c[I>>2]|0)*12|0)+U|1)+(v+6168)|0]|0;a[W+X+(v+9240)|0]=a[(((c[I>>2]|0)*12|0)+U|2)+(v+6168)|0]|0;a[J+X+(v+9240)|0]=a[(((c[I>>2]|0)*12|0)+U|3)+(v+6168)|0]|0;V=V+1|0;}while((V|0)<4);H=H+1|0;}while((H|0)<3);H=L*192|0;V=v+21528+H|0;U=0;while(1){J=((U|0)/2|0)<<2;W=J+K+(v+9240)|0;a[V]=a[W]|0;a[V+1|0]=a[W]|0;W=(J|1)+K+(v+9240)|0;a[V+2|0]=a[W]|0;a[V+3|0]=a[W]|0;W=(J|2)+K+(v+9240)|0;a[V+4|0]=a[W]|0;a[V+5|0]=a[W]|0;W=(J|3)+K+(v+9240)|0;a[V+6|0]=a[W]|0;a[V+7|0]=a[W]|0;W=U+1|0;if((W|0)<8){V=V+8|0;U=W}else{break}}U=K+16|0;V=K+17|0;W=K+18|0;J=K+19|0;M=H+64+(v+21528)|0;A=0;while(1){D=((A|0)/2|0)<<2;I=U+D+(v+9240)|0;a[M]=a[I]|0;a[M+1|0]=a[I]|0;I=V+D+(v+9240)|0;a[M+2|0]=a[I]|0;a[M+3|0]=a[I]|0;I=W+D+(v+9240)|0;a[M+4|0]=a[I]|0;a[M+5|0]=a[I]|0;I=J+D+(v+9240)|0;a[M+6|0]=a[I]|0;a[M+7|0]=a[I]|0;I=A+1|0;if((I|0)<8){M=M+8|0;A=I}else{break}}A=K+32|0;M=K+33|0;J=K+34|0;W=K+35|0;V=H+128+(v+21528)|0;U=0;while(1){I=((U|0)/2|0)<<2;D=A+I+(v+9240)|0;a[V]=a[D]|0;a[V+1|0]=a[D]|0;D=M+I+(v+9240)|0;a[V+2|0]=a[D]|0;a[V+3|0]=a[D]|0;D=J+I+(v+9240)|0;a[V+4|0]=a[D]|0;a[V+5|0]=a[D]|0;D=W+I+(v+9240)|0;a[V+6|0]=a[D]|0;a[V+7|0]=a[D]|0;D=U+1|0;if((D|0)<8){V=V+8|0;U=D}else{break}}L=L+1|0;}while((L|0)<(c[N>>2]|0))}kJb(B);kJb(b);kJb(w);if((c[u>>2]|0)!=0){EZa(n,8);EZa(n,4)}w=v+4100|0;b=k|0;B=l;L=m+12|0;ja=k+64|0;z=k+128|0;k=l+12|0;C=m+5936|0;U=l|0;V=l+4|0;W=l+8|0;J=m+5952|0;M=m+8|0;A=v+70684|0;H=v+4120|0;K=0;while(1){D=c[f>>2]|0;if((K|0)>=((ca(c[q>>2]|0,D)|0)/64|0|0)){I=c[w>>2]|0;if((I|0)<=524287){ka=0;la=0;break}if((c[O>>2]|0)==0){ka=0;la=0;break}KIb(c[o>>2]|0,16,2447152,(X=i,i=i+8|0,c[X>>2]=(I|0)/8|0,X)|0);i=X;ma=(+((c[C>>2]|0)>>>0)+ +((c[C+4>>2]|0)>>>0)*4294967296.0)*1.5;X=(F=+ma,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[C>>2]=~~+ma>>>0;c[C+4>>2]=X;c[w>>2]=0;mrc(A|0,0,16)|0;mrc(H|0,0,2048)|0;K=0;continue}X=c[x>>2]|0;I=X+(K*248|0)|0;T=X+(K*248|0)+244|0;S=c[T>>2]|0;P=(ca(S,D)|0)/64|0;D=X+(K*248|0)+240|0;Y=c[D>>2]|0;fa=((Y|0)/8|0)+P|0;c[B>>2]=c[299548];c[B+4>>2]=c[299549];c[B+8>>2]=c[299550];c[B+12>>2]=c[299551];if((c[u>>2]|0)==0){c[X+(K*248|0)+4>>2]=2147483647}else{P=(c[J>>2]|0)+(fa<<3)|0;_=X+(K*248|0)+228|0;da=c[P+4>>2]|0;c[_>>2]=c[P>>2];c[_+4>>2]=da;da=c[J>>2]|0;_=c[da+(fa<<3)>>2]|0;P=c[da+(fa<<3)+4>>2]|0;do{if((_+7|0)>>>0>14>>>0){na=2147483647}else{if((P+7|0)>>>0>14>>>0){na=2147483647;break}fa=_+Y|0;da=P+S|0;if(fa>>>0>((c[f>>2]|0)-8|0)>>>0){na=2147483647;break}if(da>>>0>((c[q>>2]|0)-8|0)>>>0){na=2147483647;break}ga=c[p>>2]|0;ia=c[M>>2]|0;na=FZa(ga|0,ia|0,Y,S,fa,da,ga+32|0,ia+32|0,8)|0}}while(0);c[X+(K*248|0)+4>>2]=na}if((c[u>>2]|0)>>>0>1>>>0){P=c[p>>2]|0;_=c[L>>2]|0;c[I>>2]=FZa(P|0,_|0,Y,S,Y,S,P+32|0,_+32|0,8)|0;oa=P}else{c[I>>2]=2147483647;oa=c[p>>2]|0}P=c[oa+32>>2]|0;_=oa|0;ia=0;ga=b;while(1){da=(ca(ia+S|0,P)|0)+Y|0;a[ga]=a[(c[_>>2]|0)+da|0]|0;a[ga+1|0]=a[(c[_>>2]|0)+(da+1)|0]|0;a[ga+2|0]=a[(c[_>>2]|0)+(da+2)|0]|0;a[ga+3|0]=a[(c[_>>2]|0)+(da+3)|0]|0;a[ga+4|0]=a[(c[_>>2]|0)+(da+4)|0]|0;a[ga+5|0]=a[(c[_>>2]|0)+(da+5)|0]|0;a[ga+6|0]=a[(c[_>>2]|0)+(da+6)|0]|0;a[ga+7|0]=a[(c[_>>2]|0)+(da+7)|0]|0;da=ia+1|0;if((da|0)<8){ia=da;ga=ga+8|0}else{break}}ga=c[oa+36>>2]|0;ia=oa+4|0;_=0;P=ja;while(1){da=(ca(_+S|0,ga)|0)+Y|0;a[P]=a[(c[ia>>2]|0)+da|0]|0;a[P+1|0]=a[(c[ia>>2]|0)+(da+1)|0]|0;a[P+2|0]=a[(c[ia>>2]|0)+(da+2)|0]|0;a[P+3|0]=a[(c[ia>>2]|0)+(da+3)|0]|0;a[P+4|0]=a[(c[ia>>2]|0)+(da+4)|0]|0;a[P+5|0]=a[(c[ia>>2]|0)+(da+5)|0]|0;a[P+6|0]=a[(c[ia>>2]|0)+(da+6)|0]|0;a[P+7|0]=a[(c[ia>>2]|0)+(da+7)|0]|0;da=_+1|0;if((da|0)<8){_=da;P=P+8|0}else{break}}P=c[oa+40>>2]|0;_=oa+8|0;ia=0;ga=z;while(1){da=(ca(ia+S|0,P)|0)+Y|0;a[ga]=a[(c[_>>2]|0)+da|0]|0;a[ga+1|0]=a[(c[_>>2]|0)+(da+1)|0]|0;a[ga+2|0]=a[(c[_>>2]|0)+(da+2)|0]|0;a[ga+3|0]=a[(c[_>>2]|0)+(da+3)|0]|0;a[ga+4|0]=a[(c[_>>2]|0)+(da+4)|0]|0;a[ga+5|0]=a[(c[_>>2]|0)+(da+5)|0]|0;a[ga+6|0]=a[(c[_>>2]|0)+(da+6)|0]|0;a[ga+7|0]=a[(c[_>>2]|0)+(da+7)|0]|0;da=ia+1|0;if((da|0)<8){ia=da;ga=ga+8|0}else{break}}ga=c[N>>2]|0;ia=X+(K*248|0)+236|0;if((ga|0)>0){_=2147483647;Y=0;P=0;while(1){S=P*192|0;da=b;fa=v+21528+S|0;$=64;Z=0;while(1){aa=$-1|0;ea=(d[fa]|0)-(d[da]|0)|0;pa=(ca(ea,ea)|0)+Z|0;if((aa|0)==0){break}else{da=da+1|0;fa=fa+1|0;$=aa;Z=pa}}Z=ja;$=S+64+(v+21528)|0;fa=64;da=0;while(1){aa=fa-1|0;ea=(d[$]|0)-(d[Z]|0)|0;qa=(ca(ea,ea)|0)+da|0;if((aa|0)==0){break}else{Z=Z+1|0;$=$+1|0;fa=aa;da=qa}}da=z;fa=S+128+(v+21528)|0;$=64;Z=0;while(1){aa=$-1|0;ea=(d[fa]|0)-(d[da]|0)|0;ra=(ca(ea,ea)|0)+Z|0;if((aa|0)==0){break}else{da=da+1|0;fa=fa+1|0;$=aa;Z=ra}}Z=qa+(pa<<2)+ra|0;$=(Z|0)<(_|0);fa=$?Z:_;Z=$?P:Y;$=P+1|0;if(($|0)<(ga|0)){_=fa;Y=Z;P=$}else{sa=fa;ta=Z;break}}}else{sa=2147483647;ta=0}c[ia>>2]=ta;P=X+(K*248|0)+8|0;c[P>>2]=sa;GZa(X+(K*248|0)+20|0,c[D>>2]|0,c[T>>2]|0,n,v);GZa(X+(K*248|0)+72|0,(c[D>>2]|0)+4|0,c[T>>2]|0,n,v);GZa(X+(K*248|0)+124|0,c[D>>2]|0,(c[T>>2]|0)+4|0,n,v);GZa(X+(K*248|0)+176|0,(c[D>>2]|0)+4|0,(c[T>>2]|0)+4|0,n,v);Y=X+(K*248|0)+12|0;c[Y>>2]=0;_=c[X+(K*248|0)+20+(c[X+(K*248|0)+40>>2]<<2)>>2]|0;c[Y>>2]=_;ga=c[X+(K*248|0)+36>>2]|0;Z=(c[X+(K*248|0)+72+(c[X+(K*248|0)+92>>2]<<2)>>2]|0)+_|0;c[Y>>2]=Z;_=c[X+(K*248|0)+88>>2]|0;fa=(c[X+(K*248|0)+124+(c[X+(K*248|0)+144>>2]<<2)>>2]|0)+Z|0;c[Y>>2]=fa;Z=c[X+(K*248|0)+140>>2]|0;$=(c[X+(K*248|0)+176+(c[X+(K*248|0)+196>>2]<<2)>>2]|0)+fa|0;c[Y>>2]=$;Y=ga+2+_+Z+(c[X+(K*248|0)+192>>2]|0)|0;c[k>>2]=Y;Z=c[C>>2]|0;_=c[C+4>>2]|0;ga=X+(K*248|0)+16|0;fa=c[I>>2]|0;da=fa;S=c[U>>2]|0;aa=Erc(S,(S|0)<0|0?-1:0,Z,_)|0;S=wrc(aa,G,da<<7|0>>>25,((fa|0)<0|0?-1:0)<<7|da>>>25)|0;da=G;fa=0;if(da>>>0<fa>>>0|da>>>0==fa>>>0&S>>>0<2147483647>>>0){c[ga>>2]=0;ua=S}else{ua=2147483647}S=c[X+(K*248|0)+4>>2]|0;fa=S;da=c[V>>2]|0;aa=Erc(da,(da|0)<0|0?-1:0,Z,_)|0;da=wrc(aa,G,fa<<7|0>>>25,((S|0)<0|0?-1:0)<<7|fa>>>25)|0;fa=G;S=(ua|0)<0|0?-1:0;if(fa>>>0<S>>>0|fa>>>0==S>>>0&da>>>0<ua>>>0){c[ga>>2]=1;va=da}else{va=ua}da=c[P>>2]|0;P=da;S=c[W>>2]|0;fa=Erc(S,(S|0)<0|0?-1:0,Z,_)|0;S=wrc(fa,G,P<<7|0>>>25,((da|0)<0|0?-1:0)<<7|P>>>25)|0;P=G;da=(va|0)<0|0?-1:0;if(P>>>0<da>>>0|P>>>0==da>>>0&S>>>0<va>>>0){c[ga>>2]=2;wa=S}else{wa=va}S=$;da=Erc(Y,(Y|0)<0|0?-1:0,Z,_)|0;_=wrc(da,G,S<<7|0>>>25,(($|0)<0|0?-1:0)<<7|S>>>25)|0;S=G;$=(wa|0)<0|0?-1:0;if(S>>>0<$>>>0|S>>>0==$>>>0&_>>>0<wa>>>0){c[ga>>2]=3;xa=3}else{xa=c[ga>>2]|0}_=v+70684+(xa<<2)|0;c[_>>2]=(c[_>>2]|0)+1;c[w>>2]=(c[w>>2]|0)+(c[l+(c[ga>>2]<<2)>>2]|0);_=c[ga>>2]|0;if((_|0)==2){$=v+5144+(c[ia>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1;ya=c[ga>>2]|0}else{ya=_}if((ya|0)==3){_=0;do{ga=c[X+(K*248|0)+20+(_*52|0)+20>>2]|0;if((ga|0)==3){$=v+4120+(c[X+(K*248|0)+20+(_*52|0)+24>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1;$=v+4120+(c[X+(K*248|0)+20+(_*52|0)+28>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1;$=v+4120+(c[X+(K*248|0)+20+(_*52|0)+32>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1;$=v+4120+(c[X+(K*248|0)+20+(_*52|0)+36>>2]<<2)|0;c[$>>2]=(c[$>>2]|0)+1}else if((ga|0)==2){ga=v+5144+(c[X+(K*248|0)+20+(_*52|0)+48>>2]<<2)|0;c[ga>>2]=(c[ga>>2]|0)+1}_=_+1|0;}while((_|0)<4)}K=K+1|0}while(1){if((c[v+5144+(ka<<2)>>2]|0)==0){za=la}else{c[v+1028+(ka<<2)>>2]=la;c[v+4+(la<<2)>>2]=ka;K=v+4120+(c[n+1556+(ka<<4)>>2]<<2)|0;c[K>>2]=(c[K>>2]|0)+1;K=v+4120+(c[n+1556+(ka<<4)+4>>2]<<2)|0;c[K>>2]=(c[K>>2]|0)+1;K=v+4120+(c[n+1556+(ka<<4)+8>>2]<<2)|0;c[K>>2]=(c[K>>2]|0)+1;K=v+4120+(c[n+1556+(ka<<4)+12>>2]<<2)|0;c[K>>2]=(c[K>>2]|0)+1;za=la+1|0}K=ka+1|0;if((K|0)<(((c[O>>2]|0)!=0?255:256)|0)){ka=K;la=za}else{break}}la=v+4104|0;c[la>>2]=za;za=0;ka=0;while(1){if((c[v+4120+(za<<2)>>2]|0)==0){Aa=ka}else{c[v+3076+(za<<2)>>2]=ka;c[v+2052+(ka<<2)>>2]=za;Aa=ka+1|0}O=za+1|0;if((O|0)<256){za=O;ka=Aa}else{break}}ka=v+4108|0;c[ka>>2]=Aa;do{if((Aa|0)!=0){za=c[r>>2]|0;y=4098;a[za]=y;y=y>>8;a[za+1|0]=y;za=(c[r>>2]|0)+2|0;c[r>>2]=za;O=za;y=(c[la>>2]<<2)+((c[ka>>2]|0)*6|0)|0;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;O=(c[r>>2]|0)+4|0;c[r>>2]=O;a[O]=c[la>>2];O=(c[r>>2]|0)+1|0;c[r>>2]=O;a[O]=c[ka>>2];O=(c[r>>2]|0)+1|0;c[r>>2]=O;if((c[ka>>2]|0)>0){za=0;K=O;while(1){ya=v+2052+(za<<2)|0;l=n+20+((c[ya>>2]|0)*6|0)|0;xa=K;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;xa=(c[r>>2]|0)+4|0;c[r>>2]=xa;a[xa]=a[n+20+((c[ya>>2]|0)*6|0)+4|0]|0;xa=(c[r>>2]|0)+1|0;c[r>>2]=xa;a[xa]=a[n+20+((c[ya>>2]|0)*6|0)+5|0]|0;ya=(c[r>>2]|0)+1|0;c[r>>2]=ya;xa=za+1|0;if((xa|0)<(c[ka>>2]|0)){za=xa;K=ya}else{Ba=ya;break}}}else{Ba=O}if((c[la>>2]|0)>0){Ca=0;Da=Ba}else{break}do{K=v+4+(Ca<<2)|0;a[Da]=c[v+3076+(c[n+1556+(c[K>>2]<<4)>>2]<<2)>>2];za=(c[r>>2]|0)+1|0;c[r>>2]=za;a[za]=c[v+3076+(c[n+1556+(c[K>>2]<<4)+4>>2]<<2)>>2];za=(c[r>>2]|0)+1|0;c[r>>2]=za;a[za]=c[v+3076+(c[n+1556+(c[K>>2]<<4)+8>>2]<<2)>>2];za=(c[r>>2]|0)+1|0;c[r>>2]=za;a[za]=c[v+3076+(c[n+1556+(c[K>>2]<<4)+12>>2]<<2)>>2];Da=(c[r>>2]|0)+1|0;c[r>>2]=Da;Ca=Ca+1|0;}while((Ca|0)<(c[la>>2]|0))}}while(0);la=ca(c[q>>2]|0,c[f>>2]|0)|0;f=(la|0)/64|0;q=j|0;c[q>>2]=0;Ca=j+4|0;c[Ca>>2]=0;Da=j+8|0;Ba=j+72|0;c[Ba>>2]=Da;ka=j+76|0;c[ka>>2]=r;if((c[v+70696>>2]&1|0)!=0){c[w>>2]=(c[w>>2]|0)+8}j=c[r>>2]|0;y=4113;a[j]=y;y=y>>8;a[j+1|0]=y;j=(c[r>>2]|0)+2|0;c[r>>2]=j;Aa=j;y=(c[w>>2]|0)/8|0;a[Aa]=y;y=y>>8;a[Aa+1|0]=y;y=y>>8;a[Aa+2|0]=y;y=y>>8;a[Aa+3|0]=y;Aa=(c[r>>2]|0)+4|0;c[r>>2]=Aa;a[Aa]=0;Aa=(c[r>>2]|0)+1|0;c[r>>2]=Aa;a[Aa]=0;c[r>>2]=(c[r>>2]|0)+1;Aa=Da;if((la|0)>63){la=0;do{w=c[x>>2]|0;j=c[w+(la*248|0)+240>>2]|0;O=c[w+(la*248|0)+244>>2]|0;K=c[w+(la*248|0)+16>>2]|0;do{if((K|0)==1){za=w+(la*248|0)+228|0;ya=w+(la*248|0)+232|0;a[c[Ba>>2]|0]=8-(c[ya>>2]|0)&15|8-(c[za>>2]|0)<<4;c[Ba>>2]=(c[Ba>>2]|0)+1;xa=c[Ca>>2]|0;l=1<<14-xa|c[q>>2];c[q>>2]=l;wa=xa+2|0;c[Ca>>2]=wa;if((wa|0)==16){wa=c[ka>>2]|0;xa=c[wa>>2]|0;y=l&65535;a[xa]=y;y=y>>8;a[xa+1|0]=y;c[wa>>2]=(c[wa>>2]|0)+2;wa=c[ka>>2]|0;xa=(c[Ba>>2]|0)-Aa|0;nrc(c[wa>>2]|0,Da|0,xa)|0;c[wa>>2]=(c[wa>>2]|0)+xa;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da}esb(n,j,O,c[za>>2]|0,c[ya>>2]|0)}else if((K|0)==2){ya=w+(la*248|0)+236|0;a[c[Ba>>2]|0]=c[v+1028+(c[ya>>2]<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;za=c[Ca>>2]|0;xa=2<<14-za|c[q>>2];c[q>>2]=xa;wa=za+2|0;c[Ca>>2]=wa;if((wa|0)==16){wa=c[ka>>2]|0;za=c[wa>>2]|0;y=xa&65535;a[za]=y;y=y>>8;a[za+1|0]=y;c[wa>>2]=(c[wa>>2]|0)+2;wa=c[ka>>2]|0;za=(c[Ba>>2]|0)-Aa|0;nrc(c[wa>>2]|0,Da|0,za)|0;c[wa>>2]=(c[wa>>2]|0)+za;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da}za=c[ya>>2]|0;bsb(n,j,O,n+20+((c[n+1556+(za<<4)>>2]|0)*6|0)|0);ya=j+4|0;bsb(n,ya,O,n+20+((c[n+1556+(za<<4)+4>>2]|0)*6|0)|0);wa=O+4|0;bsb(n,j,wa,n+20+((c[n+1556+(za<<4)+8>>2]|0)*6|0)|0);bsb(n,ya,wa,n+20+((c[n+1556+(za<<4)+12>>2]|0)*6|0)|0)}else if((K|0)==3){za=c[Ca>>2]|0;wa=3<<14-za|c[q>>2];c[q>>2]=wa;ya=za+2|0;c[Ca>>2]=ya;if((ya|0)==16){ya=c[ka>>2]|0;za=c[ya>>2]|0;y=wa&65535;a[za]=y;y=y>>8;a[za+1|0]=y;c[ya>>2]=(c[ya>>2]|0)+2;ya=c[ka>>2]|0;za=(c[Ba>>2]|0)-Aa|0;nrc(c[ya>>2]|0,Da|0,za)|0;c[ya>>2]=(c[ya>>2]|0)+za;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da;Ea=0}else{Ea=0}do{za=(Ea<<2&4)+j|0;ya=(Ea<<1&4)+O|0;wa=w+(la*248|0)+20+(Ea*52|0)+20|0;xa=c[wa>>2]|0;if((xa|0)==3){l=c[w+(la*248|0)+20+(Ea*52|0)+24>>2]|0;a[c[Ba>>2]|0]=c[v+3076+(l<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;asb(n,za,ya,n+20+(l*6|0)|0);l=c[w+(la*248|0)+20+(Ea*52|0)+28>>2]|0;a[c[Ba>>2]|0]=c[v+3076+(l<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;va=za+2|0;asb(n,va,ya,n+20+(l*6|0)|0);l=c[w+(la*248|0)+20+(Ea*52|0)+32>>2]|0;a[c[Ba>>2]|0]=c[v+3076+(l<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;W=ya+2|0;asb(n,za,W,n+20+(l*6|0)|0);l=c[w+(la*248|0)+20+(Ea*52|0)+36>>2]|0;a[c[Ba>>2]|0]=c[v+3076+(l<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;asb(n,va,W,n+20+(l*6|0)|0)}else if((xa|0)==1){l=w+(la*248|0)+20+(Ea*52|0)+40|0;W=w+(la*248|0)+20+(Ea*52|0)+44|0;a[c[Ba>>2]|0]=8-(c[W>>2]|0)&15|8-(c[l>>2]|0)<<4;c[Ba>>2]=(c[Ba>>2]|0)+1;csb(n,za,ya,c[l>>2]|0,c[W>>2]|0)}else if((xa|0)==2){xa=w+(la*248|0)+20+(Ea*52|0)+48|0;a[c[Ba>>2]|0]=c[v+1028+(c[xa>>2]<<2)>>2];c[Ba>>2]=(c[Ba>>2]|0)+1;W=c[xa>>2]|0;asb(n,za,ya,n+20+((c[n+1556+(W<<4)>>2]|0)*6|0)|0);xa=za+2|0;asb(n,xa,ya,n+20+((c[n+1556+(W<<4)+4>>2]|0)*6|0)|0);l=ya+2|0;asb(n,za,l,n+20+((c[n+1556+(W<<4)+8>>2]|0)*6|0)|0);asb(n,xa,l,n+20+((c[n+1556+(W<<4)+12>>2]|0)*6|0)|0)}W=c[Ca>>2]|0;l=(c[wa>>2]&3)<<14-W|c[q>>2];c[q>>2]=l;wa=W+2|0;c[Ca>>2]=wa;if((wa|0)==16){wa=c[ka>>2]|0;W=c[wa>>2]|0;y=l&65535;a[W]=y;y=y>>8;a[W+1|0]=y;c[wa>>2]=(c[wa>>2]|0)+2;wa=c[ka>>2]|0;W=(c[Ba>>2]|0)-Aa|0;nrc(c[wa>>2]|0,Da|0,W)|0;c[wa>>2]=(c[wa>>2]|0)+W;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da}Ea=Ea+1|0;}while((Ea|0)<4)}else if((K|0)==0){W=c[q>>2]|0;wa=(c[Ca>>2]|0)+2|0;c[Ca>>2]=wa;if((wa|0)!=16){break}wa=c[ka>>2]|0;l=c[wa>>2]|0;y=W&65535;a[l]=y;y=y>>8;a[l+1|0]=y;c[wa>>2]=(c[wa>>2]|0)+2;wa=c[ka>>2]|0;l=(c[Ba>>2]|0)-Aa|0;nrc(c[wa>>2]|0,Da|0,l)|0;c[wa>>2]=(c[wa>>2]|0)+l;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da}}while(0);la=la+1|0;}while((la|0)<(f|0))}f=c[Ca>>2]|0;la=c[q>>2]&65535;b:while(1){Ea=f;do{if((Ea|0)==0){break b}Ea=Ea+2|0;c[Ca>>2]=Ea;}while((Ea|0)!=16);Ea=c[ka>>2]|0;n=c[Ea>>2]|0;y=la;a[n]=y;y=y>>8;a[n+1|0]=y;c[Ea>>2]=(c[Ea>>2]|0)+2;Ea=c[ka>>2]|0;n=(c[Ba>>2]|0)-Aa|0;nrc(c[Ea>>2]|0,Da|0,n)|0;c[Ea>>2]=(c[Ea>>2]|0)+n;c[Ca>>2]=0;c[q>>2]=0;c[Ba>>2]=Da;f=0;la=0}c[(c[o>>2]|0)+804>>2]=c[L>>2];o=c[M>>2]|0;c[M>>2]=c[L>>2];c[L>>2]=o;o=m+5944|0;L=c[o>>2]|0;M=m+5948|0;c[o>>2]=c[M>>2];c[M>>2]=L;L=c[J>>2]|0;M=m+5956|0;c[J>>2]=c[M>>2];c[M>>2]=L;kJb(c[x>>2]|0);kJb(c[E>>2]|0);c[u>>2]=(c[u>>2]|0)+1;c[e+28>>2]=(c[r>>2]|0)-(c[s>>2]|0);if((c[u>>2]|0)==1){u=e+36|0;c[u>>2]=c[u>>2]|1}c[g>>2]=1;t=0;i=h;return t|0}function DZa(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+12|0);VHb(b+8|0);kJb(c[b+5972>>2]|0);kJb(c[b+5944>>2]|0);kJb(c[b+5948>>2]|0);kJb(c[b+5952>>2]|0);kJb(c[b+5956>>2]|0);return 0}function EZa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;d=i;i=i+8|0;e=d|0;f=a+5664|0;g=c[f>>2]|0;h=a+5668|0;j=c[h>>2]|0;k=(ca(j,(g|0)/(b|0)|0)|0)/(b|0)|0;l=(b|0)==4;if(l){m=a+5944|0;n=a+5948|0}else{m=a+5952|0;n=a+5956|0}o=c[m>>2]|0;m=c[n>>2]|0;if((j|0)<=0){i=d;return}n=a+5952|0;p=a+5964|0;q=a+8|0;a=e;r=e+4|0;s=e;t=0;u=g;g=j;while(1){if((u|0)>0){j=(t|0)/8|0;v=(t|0)/(b|0)|0;w=v+1|0;x=(t|0)==0;y=0;z=u;do{A=z-b|0;do{if(y>>>0>A>>>0){B=2147483647}else{if(t>>>0>((c[h>>2]|0)-b|0)>>>0){B=2147483647;break}C=c[p>>2]|0;D=c[q>>2]|0;B=FZa(C|0,D|0,y,t,y,t,C+32|0,D+32|0,b)|0}}while(0);do{if(l){D=(ca((z|0)/8|0,j)|0)+((y|0)/8|0)|0;C=c[n>>2]|0;E=c[C+(D<<3)>>2]|0;F=c[C+(D<<3)+4>>2]|0;if((E+7|0)>>>0>14>>>0){G=0;H=0;I=B;break}if((F+7|0)>>>0>14>>>0){G=0;H=0;I=B;break}D=E+y|0;C=F+t|0;if(D>>>0>(z-4|0)>>>0){G=0;H=0;I=B;break}if(C>>>0>((c[h>>2]|0)-4|0)>>>0){G=0;H=0;I=B;break}J=c[p>>2]|0;K=c[q>>2]|0;L=FZa(J|0,K|0,y,t,D,C,J+32|0,K+32|0,4)|0;K=(L|0)<(B|0);G=K?E:0;H=K?F:0;I=K?L:B}else{G=0;H=0;I=B}}while(0);L=(ca(z,v)|0)/(b|0)|0;K=(y|0)/(b|0)|0;F=K+L|0;do{if((F|0)<(k|0)&(F|0)>-1){E=c[m+(F<<3)>>2]|0;J=c[m+(F<<3)+4>>2]|0;if((E+7|0)>>>0>14>>>0){M=G;N=H;O=I;break}if((J+7|0)>>>0>14>>>0){M=G;N=H;O=I;break}C=E+y|0;D=J+t|0;if(C>>>0>A>>>0){M=G;N=H;O=I;break}if(D>>>0>((c[h>>2]|0)-b|0)>>>0){M=G;N=H;O=I;break}P=c[p>>2]|0;Q=c[q>>2]|0;R=FZa(P|0,Q|0,y,t,C,D,P+32|0,Q+32|0,b)|0;Q=(R|0)<(I|0);M=Q?E:G;N=Q?J:H;O=Q?R:I}else{M=G;N=H;O=I}}while(0);R=F+1|0;do{if((R|0)<(k|0)&(R|0)>-1){Q=c[m+(R<<3)>>2]|0;J=c[m+(R<<3)+4>>2]|0;if((Q+7|0)>>>0>14>>>0){S=M;T=N;U=O;break}if((J+7|0)>>>0>14>>>0){S=M;T=N;U=O;break}E=Q+y|0;P=J+t|0;if(E>>>0>A>>>0){S=M;T=N;U=O;break}if(P>>>0>((c[h>>2]|0)-b|0)>>>0){S=M;T=N;U=O;break}D=c[p>>2]|0;C=c[q>>2]|0;V=FZa(D|0,C|0,y,t,E,P,D+32|0,C+32|0,b)|0;C=(V|0)<(O|0);S=C?Q:M;T=C?J:N;U=C?V:O}else{S=M;T=N;U=O}}while(0);R=((ca(z,w)|0)/(b|0)|0)+K|0;do{if((R|0)<(k|0)&(R|0)>-1){V=c[m+(R<<3)>>2]|0;C=c[m+(R<<3)+4>>2]|0;if((V+7|0)>>>0>14>>>0){W=S;X=T;Y=U;break}if((C+7|0)>>>0>14>>>0){W=S;X=T;Y=U;break}J=V+y|0;Q=C+t|0;if(J>>>0>A>>>0){W=S;X=T;Y=U;break}if(Q>>>0>((c[h>>2]|0)-b|0)>>>0){W=S;X=T;Y=U;break}D=c[p>>2]|0;P=c[q>>2]|0;E=FZa(D|0,P|0,y,t,J,Q,D+32|0,P+32|0,b)|0;P=(E|0)<(U|0);W=P?V:S;X=P?C:T;Y=P?E:U}else{W=S;X=T;Y=U}}while(0);R=K-1+L|0;E=R-((z|0)/(b|0)|0)|0;P=E+1|0;C=E+2|0;do{if(x){if((y|0)==0){Z=W;_=X;$=Y;break}E=c[o+(R<<3)>>2]|0;V=c[o+(R<<3)+4>>2]|0;if((E+7|0)>>>0>14>>>0){Z=W;_=X;$=Y;break}if((V+7|0)>>>0>14>>>0){Z=W;_=X;$=Y;break}D=E+y|0;if(D>>>0>A>>>0){Z=W;_=X;$=Y;break}if(V>>>0>((c[h>>2]|0)-b|0)>>>0){Z=W;_=X;$=Y;break}Q=c[p>>2]|0;J=c[q>>2]|0;aa=FZa(Q|0,J|0,y,0,D,V,Q+32|0,J+32|0,b)|0;J=(aa|0)<(Y|0);Z=J?E:W;_=J?V:X;$=J?aa:Y}else{aa=c[o+(R<<3)>>2]|0;J=c[o+(P<<3)>>2]|0;V=c[o+(C<<3)>>2]|0;do{if((aa|0)>(J|0)){if((V|0)<=(J|0)){ba=J;break}ba=(V|0)>(aa|0)?aa:V}else{if((J|0)<=(V|0)){ba=J;break}ba=(V|0)>(aa|0)?V:aa}}while(0);c[e>>2]=ba;E=c[o+(R<<3)+4>>2]|0;Q=c[o+(P<<3)+4>>2]|0;D=c[o+(C<<3)+4>>2]|0;do{if((E|0)>(Q|0)){if((D|0)<=(Q|0)){da=Q;break}da=(D|0)>(E|0)?E:D}else{if((Q|0)<=(D|0)){da=Q;break}da=(D|0)>(E|0)?D:E}}while(0);c[s+4>>2]=da;do{if((ba+7|0)>>>0>14>>>0){ea=W;fa=X;ga=Y}else{if((da+7|0)>>>0>14>>>0){ea=W;fa=X;ga=Y;break}ha=ba+y|0;ia=da+t|0;if(ha>>>0>A>>>0){ea=W;fa=X;ga=Y;break}if(ia>>>0>((c[h>>2]|0)-b|0)>>>0){ea=W;fa=X;ga=Y;break}ja=c[p>>2]|0;ka=c[q>>2]|0;la=FZa(ja|0,ka|0,y,t,ha,ia,ja+32|0,ka+32|0,b)|0;ka=(la|0)<(Y|0);ea=ka?ba:W;fa=ka?da:X;ga=ka?la:Y}}while(0);do{if((aa+7|0)>>>0>14>>>0){ma=ea;na=fa;oa=ga}else{if((E+7|0)>>>0>14>>>0){ma=ea;na=fa;oa=ga;break}la=aa+y|0;ka=E+t|0;if(la>>>0>A>>>0){ma=ea;na=fa;oa=ga;break}if(ka>>>0>((c[h>>2]|0)-b|0)>>>0){ma=ea;na=fa;oa=ga;break}ja=c[p>>2]|0;ia=c[q>>2]|0;ha=FZa(ja|0,ia|0,y,t,la,ka,ja+32|0,ia+32|0,b)|0;ia=(ha|0)<(ga|0);ma=ia?aa:ea;na=ia?E:fa;oa=ia?ha:ga}}while(0);do{if((J+7|0)>>>0>14>>>0){pa=ma;qa=na;ra=oa}else{if((Q+7|0)>>>0>14>>>0){pa=ma;qa=na;ra=oa;break}E=J+y|0;aa=Q+t|0;if(E>>>0>A>>>0){pa=ma;qa=na;ra=oa;break}if(aa>>>0>((c[h>>2]|0)-b|0)>>>0){pa=ma;qa=na;ra=oa;break}ha=c[p>>2]|0;ia=c[q>>2]|0;ja=FZa(ha|0,ia|0,y,t,E,aa,ha+32|0,ia+32|0,b)|0;ia=(ja|0)<(oa|0);pa=ia?J:ma;qa=ia?Q:na;ra=ia?ja:oa}}while(0);if((V+7|0)>>>0>14>>>0){Z=pa;_=qa;$=ra;break}if((D+7|0)>>>0>14>>>0){Z=pa;_=qa;$=ra;break}Q=V+y|0;J=D+t|0;if(Q>>>0>A>>>0){Z=pa;_=qa;$=ra;break}if(J>>>0>((c[h>>2]|0)-b|0)>>>0){Z=pa;_=qa;$=ra;break}ja=c[p>>2]|0;ia=c[q>>2]|0;ha=FZa(ja|0,ia|0,y,t,Q,J,ja+32|0,ia+32|0,b)|0;ia=(ha|0)<(ra|0);Z=ia?V:pa;_=ia?D:qa;$=ia?ha:ra}}while(0);c[a>>2]=Z;c[r>>2]=_;if(($|0)==-1){sa=_;ta=Z}else{C=_;P=$;R=Z;while(1){L=c[e>>2]|0;K=c[e+4>>2]|0;ha=P;ia=C;ja=R;J=0;while(1){Q=L+(c[827232+(J<<3)>>2]|0)|0;aa=K+(c[827236+(J<<3)>>2]|0)|0;do{if((Q+7|0)>>>0>14>>>0){ua=ja;va=ia;wa=ha}else{if((aa+7|0)>>>0>14>>>0){ua=ja;va=ia;wa=ha;break}E=Q+y|0;ka=aa+t|0;if(E>>>0>A>>>0){ua=ja;va=ia;wa=ha;break}if(ka>>>0>((c[h>>2]|0)-b|0)>>>0){ua=ja;va=ia;wa=ha;break}la=c[p>>2]|0;xa=c[q>>2]|0;ya=FZa(la|0,xa|0,y,t,E,ka,la+32|0,xa+32|0,b)|0;xa=(ya|0)<(ha|0);ua=xa?Q:ja;va=xa?aa:ia;wa=xa?ya:ha}}while(0);aa=J+1|0;if((aa|0)<8){ha=wa;ia=va;ja=ua;J=aa}else{break}}c[a>>2]=ua;c[r>>2]=va;if((P|0)==(wa|0)){sa=va;ta=ua;break}else{C=va;P=wa;R=ua}}}c[o+(F<<3)>>2]=ta;c[o+(F<<3)+4>>2]=sa;y=y+b|0;z=c[f>>2]|0;}while((y|0)<(z|0));za=z;Aa=c[h>>2]|0}else{za=u;Aa=g}y=t+b|0;if((y|0)<(Aa|0)){t=y;u=za;g=Aa}else{break}}i=d;return}function FZa(a,b,e,f,g,h,i,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;l=(k|0)>0;m=(k|0)==0;if(!l){n=0;return n|0}o=c[a>>2]|0;p=c[i>>2]|0;q=c[b>>2]|0;r=c[j>>2]|0;s=0;t=0;do{if(m){u=0}else{v=o+((ca(p,t+f|0)|0)+e)|0;w=q+((ca(r,t+h|0)|0)+g)|0;x=k;y=0;while(1){z=x-1|0;A=(d[w]|0)-(d[v]|0)|0;B=(ca(A,A)|0)+y|0;if((z|0)==0){break}else{v=v+1|0;w=w+1|0;x=z;y=B}}u=B<<2}s=u+s|0;t=t+1|0;}while((t|0)<(k|0));if(!l){n=s;return n|0}t=c[a+4>>2]|0;u=c[i+4>>2]|0;B=c[b+4>>2]|0;r=c[j+4>>2]|0;q=s;s=0;do{if(m){C=0}else{p=t+((ca(u,s+f|0)|0)+e)|0;o=B+((ca(r,s+h|0)|0)+g)|0;y=k;x=0;while(1){w=y-1|0;v=(d[o]|0)-(d[p]|0)|0;z=(ca(v,v)|0)+x|0;if((w|0)==0){C=z;break}else{p=p+1|0;o=o+1|0;y=w;x=z}}}q=C+q|0;s=s+1|0;}while((s|0)<(k|0));if(!l){n=q;return n|0}l=c[a+8>>2]|0;a=c[i+8>>2]|0;i=c[b+8>>2]|0;b=c[j+8>>2]|0;j=q;q=0;while(1){if(m){D=0}else{s=l+((ca(a,q+f|0)|0)+e)|0;C=i+((ca(b,q+h|0)|0)+g)|0;r=k;B=0;while(1){u=r-1|0;t=(d[C]|0)-(d[s]|0)|0;x=(ca(t,t)|0)+B|0;if((u|0)==0){D=x;break}else{s=s+1|0;C=C+1|0;r=u;B=x}}}B=D+j|0;r=q+1|0;if((r|0)<(k|0)){j=B;q=r}else{n=B;break}}return n|0}function GZa(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;j=i;i=i+48|0;k=j|0;l=g+5960|0;if((c[l>>2]|0)==0){c[b+4>>2]=2147483647}else{m=g+5664|0;n=(e|0)/4|0;o=n+((ca(c[m>>2]|0,f)|0)/16|0)|0;p=g+5944|0;q=(c[p>>2]|0)+(o<<3)|0;o=b+40|0;r=c[q+4>>2]|0;c[o>>2]=c[q>>2];c[o+4>>2]=r;r=c[m>>2]|0;m=((ca(r,f)|0)/16|0)+n|0;n=c[p>>2]|0;p=c[n+(m<<3)>>2]|0;o=c[n+(m<<3)+4>>2]|0;do{if((p+7|0)>>>0>14>>>0){s=2147483647}else{if((o+7|0)>>>0>14>>>0){s=2147483647;break}m=p+e|0;n=o+f|0;if(m>>>0>(r-4|0)>>>0){s=2147483647;break}if(n>>>0>((c[g+5668>>2]|0)-4|0)>>>0){s=2147483647;break}q=c[g+5964>>2]|0;t=c[g+8>>2]|0;s=FZa(q|0,t|0,e,f,m,n,q+32|0,t+32|0,4)|0}}while(0);c[b+4>>2]=s}if((c[l>>2]|0)>>>0>1>>>0){l=c[g+5964>>2]|0;s=c[g+12>>2]|0;c[b>>2]=FZa(l|0,s|0,e,f,e,f,l+32|0,s+32|0,4)|0;u=l}else{c[b>>2]=2147483647;u=c[g+5964>>2]|0}l=ca(c[g+5664>>2]|0,f)|0;s=k|0;r=u+32|0;o=c[r>>2]|0;p=(ca(o,f)|0)+e|0;t=c[u>>2]|0;a[s]=a[t+p|0]|0;a[k+1|0]=a[t+(p+1)|0]|0;a[k+2|0]=a[t+(p+2)|0]|0;a[k+3|0]=a[t+(p+3)|0]|0;p=f+1|0;q=(ca(p,o)|0)+e|0;a[k+4|0]=a[t+q|0]|0;a[k+5|0]=a[t+(q+1)|0]|0;a[k+6|0]=a[t+(q+2)|0]|0;a[k+7|0]=a[t+(q+3)|0]|0;q=f+2|0;n=(ca(q,o)|0)+e|0;a[k+8|0]=a[t+n|0]|0;a[k+9|0]=a[t+(n+1)|0]|0;a[k+10|0]=a[t+(n+2)|0]|0;a[k+11|0]=a[t+(n+3)|0]|0;n=f+3|0;m=(ca(n,o)|0)+e|0;a[k+12|0]=a[t+m|0]|0;a[k+13|0]=a[t+(m+1)|0]|0;a[k+14|0]=a[t+(m+2)|0]|0;a[k+15|0]=a[t+(m+3)|0]|0;m=((e|0)/4|0)+((l|0)/16|0)|0;l=k+16|0;o=u+36|0;v=c[o>>2]|0;w=(ca(v,f)|0)+e|0;x=c[u+4>>2]|0;a[l]=a[x+w|0]|0;a[k+17|0]=a[x+(w+1)|0]|0;a[k+18|0]=a[x+(w+2)|0]|0;a[k+19|0]=a[x+(w+3)|0]|0;w=(ca(p,v)|0)+e|0;a[k+20|0]=a[x+w|0]|0;a[k+21|0]=a[x+(w+1)|0]|0;a[k+22|0]=a[x+(w+2)|0]|0;a[k+23|0]=a[x+(w+3)|0]|0;w=(ca(q,v)|0)+e|0;a[k+24|0]=a[x+w|0]|0;a[k+25|0]=a[x+(w+1)|0]|0;a[k+26|0]=a[x+(w+2)|0]|0;a[k+27|0]=a[x+(w+3)|0]|0;w=(ca(n,v)|0)+e|0;a[k+28|0]=a[x+w|0]|0;a[k+29|0]=a[x+(w+1)|0]|0;a[k+30|0]=a[x+(w+2)|0]|0;a[k+31|0]=a[x+(w+3)|0]|0;w=k+32|0;v=u+40|0;y=c[v>>2]|0;z=(ca(y,f)|0)+e|0;A=c[u+8>>2]|0;a[w]=a[A+z|0]|0;a[k+33|0]=a[A+(z+1)|0]|0;a[k+34|0]=a[A+(z+2)|0]|0;a[k+35|0]=a[A+(z+3)|0]|0;z=(ca(p,y)|0)+e|0;a[k+36|0]=a[A+z|0]|0;a[k+37|0]=a[A+(z+1)|0]|0;a[k+38|0]=a[A+(z+2)|0]|0;a[k+39|0]=a[A+(z+3)|0]|0;z=(ca(q,y)|0)+e|0;a[k+40|0]=a[A+z|0]|0;a[k+41|0]=a[A+(z+1)|0]|0;a[k+42|0]=a[A+(z+2)|0]|0;a[k+43|0]=a[A+(z+3)|0]|0;z=(ca(n,y)|0)+e|0;a[k+44|0]=a[A+z|0]|0;a[k+45|0]=a[A+(z+1)|0]|0;a[k+46|0]=a[A+(z+2)|0]|0;a[k+47|0]=a[A+(z+3)|0]|0;z=c[h+4112>>2]|0;k=b+48|0;if((z|0)>0){y=2147483647;n=0;q=0;while(1){p=q*48|0;u=s;B=h+9240+p|0;C=15;D=0;while(1){E=(d[B]|0)-(d[u]|0)|0;F=(ca(E,E)|0)+D|0;if((C|0)==0){break}u=u+1|0;B=B+1|0;C=C-1|0;D=F}D=l;C=p+16+(h+9240)|0;B=16;u=0;while(1){E=B-1|0;H=(d[C]|0)-(d[D]|0)|0;I=(ca(H,H)|0)+u|0;if((E|0)==0){break}else{D=D+1|0;C=C+1|0;B=E;u=I}}u=w;B=p+32+(h+9240)|0;C=16;D=0;while(1){E=C-1|0;H=(d[B]|0)-(d[u]|0)|0;J=(ca(H,H)|0)+D|0;if((E|0)==0){break}else{u=u+1|0;B=B+1|0;C=E;D=J}}D=I+(F<<2)+J|0;C=(D|0)<(y|0);B=C?D:y;D=C?q:n;C=q+1|0;if((C|0)<(z|0)){y=B;n=D;q=C}else{K=B;L=D;break}}}else{K=2147483647;L=0}c[k>>2]=L;L=b+8|0;c[L>>2]=K;K=b+12|0;c[K>>2]=0;k=m<<2;m=c[h+70680>>2]|0;q=0;do{n=c[m+(q+k<<2)>>2]|0;c[b+24+(q<<2)>>2]=n;y=(q<<1&2)+e|0;z=(q&2)+f|0;J=c[r>>2]|0;F=(ca(z,J)|0)+y|0;I=z+1|0;w=(ca(I,J)|0)+y|0;J=c[o>>2]|0;l=(ca(z,J)|0)+y|0;s=(ca(I,J)|0)+y|0;J=c[v>>2]|0;D=(ca(z,J)|0)+y|0;z=(ca(I,J)|0)+y|0;y=n*12|0;n=y|1;J=(d[t+F|0]|0)-(d[h+6168+y|0]|0)|0;I=ca(J,J)|0;J=(d[t+(F+1)|0]|0)-(d[h+6168+n|0]|0)|0;F=(ca(J,J)|0)+I|0;I=(d[t+w|0]|0)-(d[n+1+(h+6168)|0]|0)|0;n=(ca(I,I)|0)+F|0;F=(d[t+(w+1)|0]|0)-(d[(y|3)+(h+6168)|0]|0)|0;w=(ca(F,F)|0)+n|0;n=(d[x+l|0]|0)-(d[y+4+(h+6168)|0]|0)|0;F=(d[x+(l+1)|0]|0)-(d[y+5+(h+6168)|0]|0)|0;l=ca(F,F)|0;F=(d[x+s|0]|0)-(d[y+6+(h+6168)|0]|0)|0;I=ca(F,F)|0;F=(d[x+(s+1)|0]|0)-(d[y+7+(h+6168)|0]|0)|0;s=ca(F,F)|0;F=(d[A+D|0]|0)-(d[y+8+(h+6168)|0]|0)|0;J=ca(F,F)|0;F=(d[A+(D+1)|0]|0)-(d[y+9+(h+6168)|0]|0)|0;D=(ca(F,F)|0)+J|0;J=(d[A+z|0]|0)-(d[y+10+(h+6168)|0]|0)|0;F=(ca(J,J)|0)+D|0;D=(d[A+(z+1)|0]|0)-(d[y+11+(h+6168)|0]|0)|0;y=s+(I+(l+(ca(n,n)|0)))+(w<<2)+((ca(D,D)|0)+F)|0;M=y+(c[K>>2]|0)|0;c[K>>2]=M;q=q+1|0;}while((q|0)<4);q=g+5936|0;g=c[q>>2]|0;K=c[q+4>>2]|0;q=b+20|0;h=b+16|0;A=c[b>>2]|0;x=A;t=wrc(g<<1|0>>>31,K<<1|g>>>31,x<<7|0>>>25,((A|0)<0|0?-1:0)<<7|x>>>25)|0;x=G;A=0;if(x>>>0<A>>>0|x>>>0==A>>>0&t>>>0<2147483647>>>0){c[q>>2]=0;c[h>>2]=2;N=t}else{N=2147483647}t=c[b+4>>2]|0;b=t;A=Erc(g,K,10,0)|0;x=G;v=wrc(A,x,b<<7|0>>>25,((t|0)<0|0?-1:0)<<7|b>>>25)|0;b=G;t=(N|0)<0|0?-1:0;if(b>>>0<t>>>0|b>>>0==t>>>0&v>>>0<N>>>0){c[q>>2]=1;c[h>>2]=10;O=v}else{O=N}N=c[L>>2]|0;L=N;v=wrc(A,x,L<<7|0>>>25,((N|0)<0|0?-1:0)<<7|L>>>25)|0;L=G;N=(O|0)<0|0?-1:0;if(L>>>0<N>>>0|L>>>0==N>>>0&v>>>0<O>>>0){c[q>>2]=2;c[h>>2]=10;P=v}else{P=O}O=M;v=Erc(g,K,34,0)|0;K=wrc(v,G,O<<7|0>>>25,((M|0)<0|0?-1:0)<<7|O>>>25)|0;O=G;M=(P|0)<0|0?-1:0;if(!(O>>>0<M>>>0|O>>>0==M>>>0&K>>>0<P>>>0)){i=j;return}c[q>>2]=3;c[h>>2]=34;i=j;return}function HZa(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=(ca(h,h)|0)>>>2;k=j*6|0;l=hJb(ca(i<<2,k)|0)|0;m=l;n=(h|0)==4;if(n){o=hJb(ca(f<<2,k)|0)|0}else{o=c[d+70680>>2]|0}d=b+5672|0;Tca(e,k,f,m,i,1,o,d);Uca(e,k,f,m,i,1,o,d);if(n){kJb(o)}if((i|0)<1|(j|0)==0){kJb(l);return}o=j>>>0>1>>>0?j:1;n=o*6|0;d=0;f=m;m=g;while(1){g=m+(o*6|0)|0;k=0;e=f;b=m;while(1){a[b|0]=c[e>>2];a[b+1|0]=c[e+4>>2];a[b+2|0]=c[e+8>>2];a[b+3|0]=c[e+12>>2];a[b+4|0]=c[e+16>>2];a[b+5|0]=c[e+20>>2];h=k+1|0;if((h|0)<(j|0)){k=h;e=e+24|0;b=b+6|0}else{break}}b=d+1|0;if((b|0)<(i|0)){d=b;f=f+(n<<2)|0;m=g}else{break}}kJb(l);return}function IZa(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=46;a=UHb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function JZa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;j=i;i=i+8|0;k=j|0;l=c[e+60>>2]|0;m=c[h+24>>2]|0;n=h+28|0;h=c[n>>2]|0;if(!((h|0)>-1)){KIb(0,0,2202184,(o=i,i=i+24|0,c[o>>2]=2170384,c[o+8>>2]=2143160,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}p=l+8|0;c[p>>2]=m;c[l+16>>2]=m;q=l+12|0;c[q>>2]=m+h;h=l+4|0;m=N4a(e,c[h>>2]|0)|0;if((m|0)<0){r=m;i=j;return r|0}m=l;l=c[m>>2]|0;e=c[l+120>>2]|0;s=c[h>>2]|0;t=(c[s+32>>2]|0)/2|0;u=c[s>>2]|0;s=c[p>>2]|0;v=c[q>>2]|0;do{if((v-s|0)<1){w=0;x=7}else{y=a[s]|0;if(y<<24>>24==-31){z=v;A=s;break}w=y&255;x=7}}while(0);if((x|0)==7){KIb(l,16,2447104,(o=i,i=i+8|0,c[o>>2]=w,o)|0);i=o;z=c[q>>2]|0;A=c[p>>2]|0}w=z;if((w-A|0)<4){B=0;C=A}else{l=A+4|0;c[p>>2]=l;s=A;B=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)&16777215;C=l}if((B|0)==(w-4-C|0)){D=C;E=z}else{KIb(c[m>>2]|0,24,2357840,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;D=c[p>>2]|0;E=c[q>>2]|0}q=c[m>>2]|0;a:do{if((E|0)!=(D|0)){m=t<<2;z=k|0;C=k+2|0;w=k+4|0;B=k+6|0;l=E;s=-4;A=ca(((c[q+120>>2]|0)+3|0)/4|0,((c[q+124>>2]|0)+3|0)/4|0)|0;v=0;y=0;F=D;b:while(1){if((l-F|0)<1){G=0;H=1;I=F;x=17}else{J=F+1|0;c[p>>2]=J;K=a[F]|0;L=K&255;M=(L&31)+1|0;if((L&128|0)==0){G=L;H=M;I=J;x=17}else{N=y;O=M;P=K;Q=J}}if((x|0)==17){x=0;if((l-I|0)<1){R=0;S=I}else{J=I+1|0;c[p>>2]=J;R=d[I]|0;S=J}if((l-S|0)<1){T=1}else{T=(a[S]|0)>-1}N=(R|G<<8)&65535;O=T?H:1;P=T?0:32;Q=S}J=(O|0)>(A|0)?A:O;U=P&255;c:do{switch(U&224|0){case 32:{V=N;W=Q;x=34;break};case 0:{if((l-Q|0)>>>0<30>>>0){break a}K=s+4|0;M=(K|0)<(e|0);L=M?K:0;K=(M?0:m)+v|0;M=A-1|0;if((M|0)<0){x=43;break b}X=K+L|0;b[u+(X<<1)>>1]=N;Y=Q+2|0;c[p>>2]=Y;Z=Q;b[u+(X+1<<1)>>1]=he((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0;Z=Q+4|0;c[p>>2]=Z;_=Y;b[u+(X+2<<1)>>1]=he((d[_]|d[_+1|0]<<8)<<16>>16|0)|0;_=Q+6|0;c[p>>2]=_;Y=Z;b[u+(X+3<<1)>>1]=he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0;Y=X+t|0;X=Q+8|0;c[p>>2]=X;Z=_;b[u+(Y<<1)>>1]=he((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0;Z=Q+10|0;c[p>>2]=Z;_=X;b[u+(Y+1<<1)>>1]=he((d[_]|d[_+1|0]<<8)<<16>>16|0)|0;_=Q+12|0;c[p>>2]=_;X=Z;b[u+(Y+2<<1)>>1]=he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0;X=Q+14|0;c[p>>2]=X;Z=_;b[u+(Y+3<<1)>>1]=he((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0;Z=Y+t|0;Y=Q+16|0;c[p>>2]=Y;_=X;b[u+(Z<<1)>>1]=he((d[_]|d[_+1|0]<<8)<<16>>16|0)|0;_=Q+18|0;c[p>>2]=_;X=Y;b[u+(Z+1<<1)>>1]=he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0;X=Q+20|0;c[p>>2]=X;Y=_;b[u+(Z+2<<1)>>1]=he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0;Y=Q+22|0;c[p>>2]=Y;_=X;b[u+(Z+3<<1)>>1]=he((d[_]|d[_+1|0]<<8)<<16>>16|0)|0;_=Z+t|0;Z=Q+24|0;c[p>>2]=Z;X=Y;b[u+(_<<1)>>1]=he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0;X=Q+26|0;c[p>>2]=X;Y=Z;b[u+(_+1<<1)>>1]=he((d[Y]|d[Y+1|0]<<8)<<16>>16|0)|0;Y=Q+28|0;c[p>>2]=Y;Z=X;b[u+(_+2<<1)>>1]=he((d[Z]|d[Z+1|0]<<8)<<16>>16|0)|0;Z=Q+30|0;c[p>>2]=Z;X=Y;Y=he((d[X]|d[X+1|0]<<8)<<16>>16|0)|0;b[u+(_+3<<1)>>1]=Y;$=Y;aa=K;ba=M;da=L;ea=Z;break};case 128:{Z=v;L=J;M=A;K=s;while(1){if((L|0)==0){$=N;aa=Z;ba=M;da=K;ea=Q;break c}Y=K+4|0;_=(Y|0)<(e|0);X=M-1|0;if((X|0)<0){x=25;break b}else{Z=Z+(_?0:m)|0;L=L-1|0;M=X;K=_?Y:0}}break};case 192:{if((l-Q|0)<2){V=0;W=Q;x=34;break c}K=Q+2|0;c[p>>2]=K;M=Q;V=he((d[M]|d[M+1|0]<<8)<<16>>16|0)|0;W=K;x=34;break};case 160:{if((l-Q|0)<2){fa=0;ga=Q}else{K=Q+2|0;c[p>>2]=K;M=Q;fa=he((d[M]|d[M+1|0]<<8)<<16>>16|0)|0;ga=K}if((J|0)==0){$=fa;aa=v;ba=A;da=s;ea=ga;break c}else{ha=s;ia=A;ja=v;ka=J}while(1){K=ka-1|0;M=ha+4|0;L=(M|0)<(e|0);Z=L?M:0;M=(L?0:m)+ja|0;L=ia-1|0;if((L|0)<0){x=30;break b}Y=M+Z|0;b[u+(Y<<1)>>1]=fa;b[u+(Y+1<<1)>>1]=fa;b[u+(Y+2<<1)>>1]=fa;b[u+(Y+3<<1)>>1]=fa;_=Y+t|0;b[u+(_<<1)>>1]=fa;b[u+(_+1<<1)>>1]=fa;b[u+(_+2<<1)>>1]=fa;b[u+(_+3<<1)>>1]=fa;Y=_+t|0;b[u+(Y<<1)>>1]=fa;b[u+(Y+1<<1)>>1]=fa;b[u+(Y+2<<1)>>1]=fa;b[u+(Y+3<<1)>>1]=fa;_=Y+t|0;b[u+(_<<1)>>1]=fa;b[u+(_+1<<1)>>1]=fa;b[u+(_+2<<1)>>1]=fa;b[u+(_+3<<1)>>1]=fa;if((K|0)==0){$=fa;aa=M;ba=L;da=Z;ea=ga;break}else{ha=Z;ia=L;ja=M;ka=K}}break};default:{x=44;break b}}}while(0);do{if((x|0)==34){x=0;if((l-W|0)<2){la=0;ma=W}else{K=W+2|0;c[p>>2]=K;M=W;la=(he((d[M]|d[M+1|0]<<8)<<16>>16|0)|0)&65535;ma=K}b[z>>1]=la;b[B>>1]=V;K=(V&65535)>>>10&31;M=la>>>10&31;L=(V&65535)>>>5&31;Z=la>>>5&31;_=V&31;Y=la&31;b[C>>1]=(Z*21|0)+(L*11|0)&65504|((Y*21|0)+(_*11|0)|0)>>>5|((M*21|0)+(K*11|0)|0)>>>5<<10;b[w>>1]=(Z*11|0)+(L*21|0)&65504|((Y*11|0)+(_*21|0)|0)>>>5|((M*11|0)+(K*21|0)|0)>>>5<<10;if((l-ma|0)>>>0<J<<2>>>0){break a}if((J|0)==0){$=V;aa=v;ba=A;da=s;ea=ma;break}else{na=s;oa=A;pa=v;qa=J;ra=ma}while(1){K=qa-1|0;M=na+4|0;_=(M|0)<(e|0);Y=_?M:0;M=(_?0:m)+pa|0;_=oa-1|0;if((_|0)<0){x=39;break b}L=M+Y|0;Z=ra+1|0;c[p>>2]=Z;X=d[ra]|0;b[u+(L<<1)>>1]=b[k+(X>>>6<<1)>>1]|0;b[u+(L+1<<1)>>1]=b[k+((X>>>4&3)<<1)>>1]|0;b[u+(L+2<<1)>>1]=b[k+((X>>>2&3)<<1)>>1]|0;b[u+(L+3<<1)>>1]=b[k+((X&3)<<1)>>1]|0;X=L+t|0;L=ra+2|0;c[p>>2]=L;sa=d[Z]|0;b[u+(X<<1)>>1]=b[k+(sa>>>6<<1)>>1]|0;b[u+(X+1<<1)>>1]=b[k+((sa>>>4&3)<<1)>>1]|0;b[u+(X+2<<1)>>1]=b[k+((sa>>>2&3)<<1)>>1]|0;b[u+(X+3<<1)>>1]=b[k+((sa&3)<<1)>>1]|0;sa=X+t|0;X=ra+3|0;c[p>>2]=X;Z=d[L]|0;b[u+(sa<<1)>>1]=b[k+(Z>>>6<<1)>>1]|0;b[u+(sa+1<<1)>>1]=b[k+((Z>>>4&3)<<1)>>1]|0;b[u+(sa+2<<1)>>1]=b[k+((Z>>>2&3)<<1)>>1]|0;b[u+(sa+3<<1)>>1]=b[k+((Z&3)<<1)>>1]|0;Z=sa+t|0;sa=ra+4|0;c[p>>2]=sa;L=d[X]|0;b[u+(Z<<1)>>1]=b[k+(L>>>6<<1)>>1]|0;b[u+(Z+1<<1)>>1]=b[k+((L>>>4&3)<<1)>>1]|0;b[u+(Z+2<<1)>>1]=b[k+((L>>>2&3)<<1)>>1]|0;b[u+(Z+3<<1)>>1]=b[k+((L&3)<<1)>>1]|0;if((K|0)==0){$=V;aa=M;ba=_;da=Y;ea=sa;break}else{na=Y;oa=_;pa=M;qa=K;ra=sa}}}}while(0);if((E|0)==(ea|0)){break a}else{s=da;A=ba;v=aa;y=$;F=ea}}if((x|0)==25){KIb(q,16,2294616,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((x|0)==30){KIb(q,16,2294616,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((x|0)==39){KIb(q,16,2294616,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((x|0)==43){KIb(q,16,2294616,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((x|0)==44){KIb(q,16,2243568,(o=i,i=i+16|0,c[o>>2]=U,c[o+8>>2]=l-Q,o)|0);i=o;break}}}while(0);o=YHb(f,c[h>>2]|0)|0;if((o|0)<0){r=o;i=j;return r|0}c[g>>2]=1;r=c[n>>2]|0;i=j;return r|0}function KZa(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function LZa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;i=i+24|0;g=f|0;h=c[a>>2]|0;j=(h|0)/16|0;k=c[a+4>>2]|0;l=(k|0)/16|0;m=c[b>>2]|0;n=b+32|0;o=c[n>>2]|0;p=c[b+4>>2]|0;q=c[b+8>>2]|0;r=e>>>0>268435455>>>0?-8:e<<3;e=r>>>0>2147483639>>>0|(d|0)==0;s=e?0:d;d=e?0:r;c[g>>2]=s;c[g+12>>2]=d;c[g+16>>2]=d+8;c[g+4>>2]=s+(d>>3);d=g+8|0;c[d>>2]=0;if(e){t=e?-1094995529:0;i=f;return t|0}if((k|0)<=15){t=0;i=f;return t|0}k=(h|0)>15;h=b+36|0;e=b+40|0;b=a+592|0;s=a+12|0;r=a+76|0;u=a+8|0;v=a+332|0;a=q;q=p;p=m+(o<<3)|0;w=m;m=0;x=o;a:while(1){if(k){o=a;y=q;z=p;A=w;B=0;do{C=MZa(g,b,s,r)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){ef[c[(c[u>>2]|0)+1120>>2]&4095](A,c[n>>2]|0,b)}C=MZa(g,b,s,r)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){ef[c[(c[u>>2]|0)+1120>>2]&4095](A+8|0,c[n>>2]|0,b)}A=A+16|0;C=MZa(g,b,s,r)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){ef[c[(c[u>>2]|0)+1120>>2]&4095](z,c[n>>2]|0,b)}C=MZa(g,b,s,r)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){ef[c[(c[u>>2]|0)+1120>>2]&4095](z+8|0,c[n>>2]|0,b)}z=z+16|0;C=MZa(g,b,s,v)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){ef[c[(c[u>>2]|0)+1120>>2]&4095](y,c[h>>2]|0,b)}y=y+8|0;C=MZa(g,b,s,v)|0;if((C|0)<0){t=C;D=27;break a}if((C|0)>0){ef[c[(c[u>>2]|0)+1120>>2]&4095](o,c[e>>2]|0,b)}o=o+8|0;B=B+1|0;}while((B|0)<(j|0));E=o;F=y;G=z;H=A;I=c[n>>2]|0}else{E=a;F=q;G=p;H=w;I=x}B=I-j<<4;C=m+1|0;if((C|0)<(l|0)){a=E+((c[e>>2]|0)-j<<3)|0;q=F+((c[h>>2]|0)-j<<3)|0;p=G+B|0;w=H+B|0;m=C;x=I}else{D=26;break}}if((D|0)==26){t=(c[d>>2]|0)/8|0;i=f;return t|0}else if((D|0)==27){i=f;return t|0}return 0}function MZa(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=a+8|0;i=c[h>>2]|0;j=a+16|0;k=c[j>>2]|0;l=a|0;m=c[l>>2]|0;n=m+(i>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(i&7)>>>24;n=i+8|0;i=k>>>0>n>>>0?n:k;c[h>>2]=i;if((o|0)==255){p=0;return p|0}n=m+(i>>>3)|0;m=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(i&7)>>>26;n=i+6|0;i=k>>>0>n>>>0?n:k;c[h>>2]=i;k=a+12|0;if(((c[k>>2]|0)-i|0)<(m<<1|0)){p=-1094995529;return p|0}mrc(e|0,0,128)|0;i=c[h>>2]|0;a:do{if((m|0)==0){q=0;r=i}else{a=c[j>>2]|0;n=c[l>>2]|0;s=m;t=i;while(1){u=n+(t>>>3)|0;v=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>30;u=t+2|0;w=a>>>0>u>>>0?u:a;c[h>>2]=w;if((v|0)==-2){q=s;r=w;break a}u=s-1|0;x=d[f+s|0]|0;b[e+(x<<1)>>1]=ca(c[g+(x<<2)>>2]|0,v)|0;if((u|0)==0){q=0;r=w;break}else{s=u;t=w}}}}while(0);i=-r&3;if((i|0)==0){y=r}else{m=c[j>>2]|0;t=r+i|0;i=m>>>0>t>>>0?t:m;c[h>>2]=i;y=i}i=c[k>>2]|0;if((i-y|0)<(q<<2|0)){p=-1094995529;return p|0}b:do{if((q|0)==0){z=0;A=y}else{k=c[j>>2]|0;m=c[l>>2]|0;t=q;r=y;while(1){s=m+(r>>>3)|0;a=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(r&7)>>28;s=r+4|0;n=k>>>0>s>>>0?s:k;c[h>>2]=n;if((a|0)==-8){z=t;A=n;break b}s=t-1|0;w=d[f+t|0]|0;b[e+(w<<1)>>1]=ca(c[g+(w<<2)>>2]|0,a)|0;if((s|0)==0){z=0;A=n;break}else{t=s;r=n}}}}while(0);y=-A&7;if((y|0)==0){B=A}else{q=c[j>>2]|0;r=A+y|0;y=q>>>0>r>>>0?r:q;c[h>>2]=y;B=y}if((i-B|0)<(z<<3|0)){p=-1094995529;return p|0}if((z|0)!=0){i=c[j>>2]|0;j=c[l>>2]|0;l=z;z=B;while(1){B=j+(z>>>3)|0;y=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7);B=z+8|0;q=i>>>0>B>>>0?B:i;c[h>>2]=q;B=l-1|0;r=d[f+l|0]|0;b[e+(r<<1)>>1]=ca(y>>24,c[g+(r<<2)>>2]|0)|0;if((B|0)==0){break}else{l=B;z=q}}}z=d[f]|0;b[e+(z<<1)>>1]=ca(c[g+(z<<2)>>2]|0,o)|0;p=1;return p|0}function NZa(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=b+8|0;c[j>>2]=e;k=0;l=e;while(1){e=d[1242080+k|0]|0;m=d[l+1128+k|0]|0;a[b+12+k|0]=a[(e<<3&56|e>>>3)+(l+1128)|0]|0;c[b+76+(m<<2)>>2]=c[h+(k<<2)>>2];c[b+332+(m<<2)>>2]=c[i+(k<<2)>>2];m=k+1|0;if((m|0)>=64){break}k=m;l=c[j>>2]|0}c[b>>2]=f;c[b+4>>2]=g;return}function OZa(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;g=a+14120|0;do{if((e|0)<4){h=c[1281509]|0;j=a+14128|0;k=c[j>>2]|0;l=c[a+14136>>2]|0;m=c[g>>2]|0;n=m+(k>>>3)|0;o=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(k&7)>>>18;n=b[h+(o<<2)>>1]|0;p=b[h+(o<<2)+2>>1]|0;o=p<<16>>16;if(p<<16>>16<0){p=k+14|0;q=l>>>0>p>>>0?p:l;p=m+(q>>>3)|0;r=((je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(q&7)>>>((o+32|0)>>>0))+n|0;s=b[h+(r<<2)+2>>1]|0;t=b[h+(r<<2)>>1]|0;u=q}else{s=o;t=n;u=k}k=s+u|0;n=l>>>0>k>>>0?k:l;c[j>>2]=n;if((t|0)>=0){v=t-128|0;break}k=m+(n>>>3)|0;o=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(n&7)>>>25;k=n+7|0;n=l>>>0>k>>>0?k:l;c[j>>2]=n;if((o|0)==127){k=n+11|0;c[j>>2]=l>>>0>k>>>0?k:l;v=1;break}else if((o|0)==126){k=d[m+(n>>>3)|0]|0;q=((n|0)<(l|0))+n|0;c[j>>2]=q;r=m+(q>>>3)|0;h=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)&-16777216;r=q+8|0;c[j>>2]=l>>>0>r>>>0?r:l;if((k&128>>>((n&7)>>>0)|0)==0){v=h+16777216>>24;break}else{v=h>>24;break}}else if((o|0)==124){h=m+(n>>>3)|0;k=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(n&7)>>>25;h=n+7|0;c[j>>2]=l>>>0>h>>>0?h:l;v=(k<<24)+16777216>>24;break}else if((o|0)==125){k=m+(n>>>3)|0;m=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(n&7)>>>25;k=n+7|0;c[j>>2]=l>>>0>k>>>0?k:l;v=m|-128;break}else{v=o;break}}else{o=c[1281515]|0;m=a+14128|0;l=c[m>>2]|0;k=c[a+14136>>2]|0;j=c[g>>2]|0;n=j+(l>>>3)|0;h=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(l&7)>>>18;n=b[o+(h<<2)>>1]|0;r=b[o+(h<<2)+2>>1]|0;h=r<<16>>16;if(r<<16>>16<0){r=l+14|0;q=k>>>0>r>>>0?r:k;r=j+(q>>>3)|0;p=((je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(q&7)>>>((h+32|0)>>>0))+n|0;w=b[o+(p<<2)+2>>1]|0;x=b[o+(p<<2)>>1]|0;y=q}else{w=h;x=n;y=l}l=w+y|0;n=k>>>0>l>>>0?l:k;c[m>>2]=n;if((x|0)>=0){v=x-128|0;break}l=j+(n>>>3)|0;h=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(n&7)>>>23;l=n+9|0;n=k>>>0>l>>>0?l:k;c[m>>2]=n;if((h|0)==509){l=j+(n>>>3)|0;q=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(n&7)>>>25;l=n+7|0;c[m>>2]=k>>>0>l>>>0?l:k;v=q|-128;break}else if((h|0)==510){q=n+9|0;c[m>>2]=k>>>0>q>>>0?q:k;v=1;break}else if((h|0)==508){h=j+(n>>>3)|0;j=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(n&7)>>>25;h=n+7|0;c[m>>2]=k>>>0>h>>>0?h:k;v=(j<<24)+16777216>>24;break}else{KIb(c[a+4>>2]|0,16,2480208,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;z=65535;i=f;return z|0}}}while(0);z=-v|0;i=f;return z|0}function PZa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;f=c[b+60>>2]|0;g=f;if((c[b+100>>2]|0)<8){KIb(b,16,2395704,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1094995529;i=e;return j|0}k=b+128|0;l=b+132|0;m=b;n=tIb(c[k>>2]|0,c[l>>2]|0,0,m)|0;if((n|0)<0){j=n;i=e;return j|0}uTa(g);c[f+4>>2]=b;c[f+28>>2]=2;c[f+48>>2]=c[b+48>>2];n=c[k>>2]|0;c[f+8>>2]=n;c[f+14044>>2]=n;n=c[l>>2]|0;c[f+12>>2]=n;c[f+14048>>2]=n;n=c[b+96>>2]|0;c[f+10052>>2]=a[n+3|0]&1;l=n+4|0;k=je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;l=f+14672|0;c[l>>2]=k;o=k>>28;p=k>>>12&255;q=f+13944|0;c[q>>2]=1;do{if((o|0)==2){if(!((k&266338304)>>>0>1048576>>>0)){break}c[q>>2]=0;c[b+176>>2]=1}else if((o|0)==1){c[f+14028>>2]=(p|0)!=0?3:1;c[f+13788>>2]=(p|0)==2}else{KIb(m,16,2388472,(h=i,i=i+8|0,c[h>>2]=k,h)|0);i=h;QIb(m,2381600,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-1163346256;i=e;return j|0}}while(0);if((c[b+688>>2]&1|0)!=0){k=c[n>>2]|0;KIb(m,48,2375112,(h=i,i=i+16|0,c[h>>2]=c[l>>2],c[h+8>>2]=k,h)|0);i=h}c[b+140>>2]=0;b=rTa(g)|0;if((b|0)<0){j=b;i=e;return j|0}Zga(f+11548|0);DMa();if(a[676256]|0){j=0;i=e;return j|0}c[1281509]=5291112;c[1281511]=16384;$2(5126032,14,256,615152,1,1,614640,2,2,0,0,0,4)|0;c[1281515]=5225560;c[1281517]=16388;$2(5126056,14,256,615920,1,1,615408,2,2,0,0,0,4)|0;a[676256]=1;j=0;i=e;return j|0}function QZa(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0;j=i;i=i+40|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=c[h+24>>2]|0;q=h+28|0;h=c[q>>2]|0;r=e+60|0;s=c[r>>2]|0;t=s;u=f;c[s+60>>2]=c[e+88>>2];c[s+64>>2]=c[e+92>>2];if((h|0)==0){v=0;i=j;return v|0}f=e+212|0;w=c[f>>2]|0;do{if((w|0)==0){x=(d[p]|0)+1|0;y=h-1|0;z=x<<3;if((y|0)>(z|0)){A=y-z|0;B=p+(z|1)|0;C=x;D=p+5|0;E=7;break}KIb(e,16,2243536,(F=i,i=i+8|0,c[F>>2]=x,F)|0);i=F;v=-1094995529;i=j;return v|0}else{if((w|0)>0){A=h;B=p;C=w;D=0;E=7}}}while(0);a:do{if((E|0)==7){p=e+220|0;h=e;x=k;z=m;y=o;H=k;I=x+4|0;J=l|0;K=l+4|0;L=n|0;M=n+4|0;N=0;O=w;b:while(1){P=(O|0)==0;if(P){Q=D+(N<<3)|0}else{Q=(c[p>>2]|0)+(N<<2)|0}R=d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0;if(!(R>>>0<A>>>0)){v=-1094995529;E=166;break}S=N+1|0;if((S|0)==(C|0)){T=A}else{if(P){U=D+(S<<3)|0}else{U=(c[p>>2]|0)+(S<<2)|0}T=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0}V=T-R|0;W=N+2|0;if((W|0)<(C|0)){if(P){X=D+(W<<3)|0}else{X=(c[p>>2]|0)+(W<<2)|0}Y=d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0}else{Y=A}W=Y-R|0;if((V|0)<1|(W|0)<1){v=-1094995529;E=166;break}P=(V|0)>(W|0)?V:W;if((P+R|0)>>>0>A>>>0){v=-1094995529;E=166;break}Z=B+R|0;_=c[r>>2]|0;R=_;$=V<<3;V=P<<3;P=V>>>0>2147483639>>>0|(Z|0)==0;aa=P?0:Z;Z=P?0:V;V=_+14120|0;c[V>>2]=aa;c[_+14132>>2]=Z;P=Z+8|0;ba=_+14136|0;c[ba>>2]=P;c[_+14124>>2]=aa+(Z>>3);Z=_+14128|0;c[Z>>2]=0;da=_+48|0;if((c[da>>2]|0)==6){ea=a[aa]|0;fa=(P|0)>0|0;c[Z>>2]=fa;ga=(d[aa]|0)<<fa;ha=((fa|0)<(P|0))+fa|0;c[Z>>2]=ha;fa=_+9992|0;c[fa>>2]=(ga>>>7&1)+1;if(ea<<24>>24>-1){KIb(c[_+4>>2]|0,16,2410280,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;ia=c[Z>>2]|0;ja=c[V>>2]|0;ka=c[ba>>2]|0}else{ia=ha;ja=aa;ka=P}ha=d[ja+(ia>>>3)|0]|0;ea=((ia|0)<(ka|0))+ia|0;c[Z>>2]=ea;if((ha&128>>>((ia&7)>>>0)|0)!=0){E=28;break}ha=ja+(ea>>>3)|0;ga=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ea&7)>>>27;ha=ea+5|0;ea=ka>>>0>ha>>>0?ha:ka;c[Z>>2]=ea;c[_+9960>>2]=ga;if((ga|0)==0){E=30;break}ga=c[fa>>2]|0;do{if((ga|0)==1){if((c[_+14028>>2]|0)!=3){la=ea;break}fa=ja+(ea>>>3)|0;ha=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ea&7)>>>24;fa=ea+8|0;ma=ka>>>0>fa>>>0?fa:ka;c[Z>>2]=ma;c[_+9860>>2]=ha;ha=ja+(ma>>>3)|0;fa=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(ma&7)>>>24;ha=ma+8|0;ma=ka>>>0>ha>>>0?ha:ka;c[Z>>2]=ma;c[_+9864>>2]=fa;fa=ja+(ma>>>3)|0;ha=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ma&7)>>>24;fa=ma+8|0;ma=ka>>>0>fa>>>0?fa:ka;c[Z>>2]=ma;c[_+9868>>2]=ha;la=ma}else{la=ea}}while(0);ea=_+12476|0;ma=_+12480|0;ha=c[_+116>>2]|0;fa=(ca(ha,c[ma>>2]|0)|0)+(c[ea>>2]|0)|0;na=ja+(la>>>3)|0;oa=je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0;na=la&7;do{if((oa&-1048576>>>(na>>>0)|0)==0){E=37}else{if((fa|0)!=0){if((fa|0)<(c[_+144>>2]|0)){E=37;break}}c[ea>>2]=0;c[ma>>2]=0;pa=ca(c[_+120>>2]|0,ha)|0;qa=la}}while(0);if((E|0)==37){E=0;fa=la+6|0;ra=ka>>>0>fa>>>0?fa:ka;c[Z>>2]=ra;c[ea>>2]=oa<<na>>>26;fa=ja+(ra>>>3)|0;sa=(je(d[fa]|d[fa+1|0]<<8|d[fa+2|0]<<16|d[fa+3|0]<<24|0)|0)<<(ra&7)>>>26;fa=ra+6|0;ra=ka>>>0>fa>>>0?fa:ka;c[Z>>2]=ra;c[ma>>2]=sa;sa=ja+(ra>>>3)|0;fa=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(ra&7)>>>20;sa=ra+12|0;ra=ka>>>0>sa>>>0?sa:ka;c[Z>>2]=ra;pa=fa;qa=ra}ra=qa+3|0;c[Z>>2]=ka>>>0>ra>>>0?ra:ka;c[_+11556>>2]=1;c[_+10048>>2]=1;ta=pa;ua=ha;va=ga}else{ra=aa;fa=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)>>>6&3;ra=P>>>0>2>>>0?2:P;c[Z>>2]=ra;if((fa|0)==3){c[_+9992>>2]=3;sa=_+13944|0;if((c[sa>>2]|0)!=0){E=47;break}if((c[_+9848>>2]|0)==0){E=49;break}else{wa=sa}}else if((fa|0)==1){c[_+9992>>2]=1;E=45}else if((fa|0)==0){c[_+9992>>2]=1;E=45}else if((fa|0)==2){c[_+9992>>2]=2;E=45}else{E=44;break}if((E|0)==45){E=0;wa=_+13944|0}fa=aa+(ra>>>3)|0;sa=d[fa]|0;xa=(ra|0)<(P|0)|ra;c[Z>>2]=xa;if((sa&128>>>((ra&2)>>>0)|0)!=0){E=51;break}ra=fa;fa=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(xa&3)>>>27;ra=xa+5|0;xa=P>>>0>ra>>>0?ra:P;c[Z>>2]=xa;ra=_+9960|0;c[ra>>2]=fa;if((fa|0)==0){E=53;break}fa=_+14672|0;sa=c[fa>>2]&266338304;if(sa>>>0>1048576>>>0){ya=d[aa+(xa>>>3)|0]|0;za=((xa|0)<(P|0))+xa|0;c[Z>>2]=za;if((ya&128>>>((xa&7)>>>0)|0)==0){Aa=0}else{Aa=(c[(c[_+4>>2]|0)+800>>2]|0)==0|0}c[_+13836>>2]=Aa;Ba=za}else{Ba=xa}xa=aa+(Ba>>>3)|0;za=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ba&7);if(sa>>>0<2097152>>>0){sa=Ba+8|0;xa=P>>>0>sa>>>0?sa:P;c[Z>>2]=xa;Ca=za>>>24<<7;Da=xa}else{xa=Ba+13|0;sa=P>>>0>xa>>>0?xa:P;c[Z>>2]=sa;Ca=za>>>19<<2;Da=sa}Ea=_+4|0;Fa=c[Ea>>2]|0;sa=c[Fa+96>>2]|0;za=a[sa+1|0]&7;do{if((za|0)==0){Ga=Fa;Ha=_+8|0}else{xa=d[1359664+za|0]|0;ya=xa+1|0;Ia=aa+(Da>>>3)|0;Ja=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Da&7)>>>((31-xa|0)>>>0);xa=ya+Da|0;c[Z>>2]=P>>>0>xa>>>0?xa:P;if((Ja|0)==0){Ka=c[_+14048>>2]|0;La=c[_+14044>>2]|0}else{xa=Ja<<1;if((c[Fa+100>>2]|0)<(xa+8|0)){E=65;break b}Ka=(d[sa+(xa+7)|0]|0)<<2;La=(d[sa+(xa+6)|0]|0)<<2}xa=_+8|0;if((La|0)==(c[xa>>2]|0)){if((Ka|0)==(c[_+12>>2]|0)){Ma=Fa}else{E=70}}else{E=70}if((E|0)==70){E=0;Ia=Fa+224|0;Na=c[Ia>>2]|0;Oa=c[Ia+4>>2]|0;c[k>>2]=Na;c[k+4>>2]=Oa;KIb(Fa,48,2488496,(F=i,i=i+16|0,c[F>>2]=La,c[F+8>>2]=Ka,F)|0);i=F;if((tIb(La,Ka,0,c[Ea>>2]|0)|0)<0){Pa=Ea;break b}xTa(R);if((Na|0)==0){c[H>>2]=1;c[I>>2]=1}Na=_+12|0;Oa=c[Na>>2]|0;Ia=ca(La<<1,Oa)|0;Qa=c[xa>>2]|0;if((Ia|0)==(ca(Qa,Ka)|0)){Ia=(c[Ea>>2]|0)+224|0;c[J>>2]=2;c[K>>2]=1;yKb(z,x,l);Ra=Ia;Ia=c[m+4>>2]|0;c[Ra>>2]=c[m>>2];c[Ra+4>>2]=Ia;Sa=c[Na>>2]|0;Ta=c[xa>>2]|0}else{Sa=Oa;Ta=Qa}if((ca(Sa,La)|0)==(ca(Ka<<1,Ta)|0)){Qa=(c[Ea>>2]|0)+224|0;c[L>>2]=1;c[M>>2]=2;yKb(y,x,n);Oa=Qa;Qa=c[o+4>>2]|0;c[Oa>>2]=c[o>>2];c[Oa+4>>2]=Qa}Qa=H4a(c[Ea>>2]|0,La,Ka)|0;if((Qa|0)<0){Ua=Qa;E=103;break b}c[xa>>2]=La;c[Na>>2]=Ka;Na=rTa(R)|0;if((Na|0)<0){Ua=Na;E=103;break b}Ma=c[Ea>>2]|0}if((c[Ma+688>>2]&1|0)==0){Ga=Ma;Ha=xa;break}KIb(Ma,48,2477560,(F=i,i=i+24|0,c[F>>2]=Ja,c[F+8>>2]=ya,c[F+16>>2]=za,F)|0);i=F;Ga=c[Ea>>2]|0;Ha=xa}}while(0);if((tIb(c[Ha>>2]|0,c[_+12>>2]|0,0,Ga)|0)<0){Pa=Ea;break}za=EMa(R)|0;sa=_+13856|0;P=c[sa>>2]|0;aa=c[sa+4>>2]|0;ga=P&-32768|Ca;ha=xrc(ga,(ga|0)<0|0?-1:0,P,aa)|0;ma=G;na=0;oa=(ma|0)>(na|0)|(ma|0)==(na|0)&ha>>>0>16384>>>0?ga-32768|0:ga;ga=xrc(oa,(oa|0)<0|0?-1:0,P,aa)|0;ha=G;na=-1;ma=(ha|0)<(na|0)|(ha|0)==(na|0)&ga>>>0<-16384>>>0?oa+32768|0:oa;oa=ma;ga=(ma|0)<0|0?-1:0;na=_+9992|0;ha=c[na>>2]|0;ea=(ha|0)==3;do{if((oa|0)==(P|0)&(ga|0)==(aa|0)){if(!ea){Va=ha;break}Wa=b[_+13872>>1]|0;Xa=b[_+13874>>1]|0;E=89}else{c[sa>>2]=oa;c[sa+4>>2]=ga;if(ea){xa=b[_+13872>>1]|0;ya=_+13864|0;Ja=xrc(oa,ga,c[ya>>2]|0,c[ya+4>>2]|0)|0;ya=wrc(Ja,G,xa&65535,0)|0;Ja=ya&65535;b[_+13874>>1]=Ja;Wa=xa;Xa=Ja;E=89;break}else{Ja=_+13864|0;xa=xrc(oa,ga,c[Ja>>2]|0,c[Ja+4>>2]|0)|0;b[_+13872>>1]=xa;c[Ja>>2]=oa;c[Ja+4>>2]=ga;Va=ha;break}}}while(0);if((E|0)==89){E=0;if((Wa&65535)>>>0<=(Xa&65535)>>>0|Xa<<16>>16==0|Wa<<16>>16==0){E=90;break}GRa(R);Va=c[na>>2]|0}ha=c[Z>>2]|0;ga=(d[(c[V>>2]|0)+(ha>>>3)|0]|0)<<(ha&7)>>>7;oa=c[ba>>2]|0;ea=((ha|0)<(oa|0))+ha|0;c[Z>>2]=ea;ha=ga&1;c[_+12472>>2]=ha;if((c[fa>>2]&266338304)>>>0<2097152>>>0&(Va|0)==3){ga=ea+5|0;c[Z>>2]=oa>>>0>ga>>>0?ga:oa;Ya=3}else{Ya=Va}c[_+11556>>2]=1;c[_+10048>>2]=1;c[_+228>>2]=(Ya|0)==1;c[_+13832>>2]=1;oa=c[Ea>>2]|0;if((c[oa+800>>2]|0)==0){c[_+13836>>2]=1}if((c[oa+688>>2]&1|0)==0){Za=Ya;_a=Va}else{ga=c[_+12476>>2]|0;ea=c[_+12480>>2]|0;sa=c[ra>>2]|0;KIb(oa,32,2458440,(F=i,i=i+48|0,c[F>>2]=ma,c[F+8>>2]=ga,c[F+16>>2]=ea,c[F+24>>2]=Ya,c[F+32>>2]=sa,c[F+40>>2]=ha,F)|0);i=F;ha=c[na>>2]|0;Za=ha;_a=ha}if((Za|0)==3){if((c[wa>>2]|0)!=0){E=100;break}}ha=c[_+116>>2]|0;ta=(ca(c[_+120>>2]|0,ha)|0)-za|0;ua=ha;va=_a}if((ta|0)<0){Ua=ta;E=103;break}$a=_+12476|0;ab=c[$a>>2]|0;ha=_+116|0;bb=_+12480|0;cb=c[bb>>2]|0;if((ab|0)>=(ua|0)){E=108;break}sa=c[_+120>>2]|0;if((cb|0)>=(sa|0)){E=108;break}if((ta|0)>((ca(sa,ua)|0)-((ca(cb,ua)|0)+ab)|0)){E=110;break}sa=c[_+9856>>2]|0;ea=(sa|0)==0;do{if((cb|ab|0)==0){if(ea){E=115;break}zpb(_+14424|0);ETa(R);c[_+13708>>2]=0;c[_+13704>>2]=0;c[bb>>2]=0;c[$a>>2]=0;E=115}else{if(ea){E=115;break}if((c[sa+88>>2]|0)!=(va|0)){E=118;break b}}}while(0);if((E|0)==115){E=0;sa=DTa(R,e)|0;if((sa|0)<0){v=sa;E=166;break}STa(R)}do{if((c[da>>2]|0)==6){sa=c[bb>>2]|0;if((sa|0)!=0){db=sa;break}c[_+14084>>2]=1;db=0}else{c[_+14084>>2]=1;c[_+13704>>2]=c[$a>>2];db=c[bb>>2]|0}}while(0);da=c[$a>>2]|0;sa=_+13708|0;c[sa>>2]=db;ea=_+9892|0;if((c[_+228>>2]|0)==0){c[ea>>2]=1347360;c[_+9888>>2]=1347360}else{c[ea>>2]=1434232;c[_+9888>>2]=1434232}if((c[_+13832>>2]|0)!=0){c[_+9896>>2]=1379496}QTa(R,c[_+9960>>2]|0);c[_+14032>>2]=0;c[_+14036>>2]=0;c[_+14040>>2]=0;ea=c[_+128>>2]|0;c[_+12532>>2]=ea;c[_+12528>>2]=ea;c[_+12524>>2]=ea;c[_+12520>>2]=ea;ea=c[_+124>>2]|0;c[_+12540>>2]=ea;c[_+12536>>2]=ea;NTa(R);ea=_+13732|0;c[ea>>2]=ta;c:do{if((ta|0)>0){eb=_+4|0;za=_+12496|0;na=_+12500|0;ma=_+12504|0;ra=_+12508|0;fa=_+12512|0;ba=_+12516|0;ga=_+12544|0;oa=_+12548|0;aa=_+12552|0;P=_+11736|0;Ja=_+11740|0;xa=_+14340|0;ya=W<<3;Na=_+9992|0;Qa=_+13836|0;Oa=_+13704|0;Ia=_+14084|0;Ra=$;while(1){fb=8>>>((c[(c[eb>>2]|0)+800>>2]|0)>>>0);c[za>>2]=(c[za>>2]|0)+2;c[na>>2]=(c[na>>2]|0)+2;c[ma>>2]=(c[ma>>2]|0)+2;c[ra>>2]=(c[ra>>2]|0)+2;c[fa>>2]=(c[fa>>2]|0)+1;c[ba>>2]=(c[ba>>2]|0)+1;c[ga>>2]=(c[ga>>2]|0)+(fb<<1);c[oa>>2]=(c[oa>>2]|0)+fb;c[aa>>2]=(c[aa>>2]|0)+fb;c[P>>2]=1;c[Ja>>2]=0;fb=JMa(R,c[xa>>2]|0)|0;if((fb|0)==-1){E=138;break b}gb=c[Z>>2]|0;hb=(c[V>>2]|0)+(gb>>>3)|0;ib=(je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(gb&7)>>>16;hb=gb+16|0;if((hb|0)>(Ra|0)){jb=ib>>>((hb-Ra|0)>>>0)}else{jb=ib}ib=(jb|0)==0?-2:fb;if((ib|0)==-1){E=138;break b}if((Ra|0)>=(gb|0)|(ya|0)<(gb|0)){kb=Ra;lb=ib;mb=gb}else{KIb(h,48,2637768,(F=i,i=i+16|0,c[F>>2]=$,c[F+8>>2]=ya,F)|0);i=F;kb=ya;lb=0;mb=c[Z>>2]|0}if((kb|0)<(mb|0)){E=138;break b}if((c[Na>>2]|0)!=3){Nga(R)}KTa(R,c[xa>>2]|0);if((c[Qa>>2]|0)!=0){Pga(R)}gb=(c[$a>>2]|0)+1|0;c[$a>>2]=gb;if((gb|0)==(c[ha>>2]|0)){c[$a>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;NTa(R);nb=c[$a>>2]|0}else{nb=gb}if((nb|0)==(c[Oa>>2]|0)){c[Ia>>2]=0}if((lb|0)==-2){ob=kb;pb=nb;break c}gb=(c[ea>>2]|0)-1|0;c[ea>>2]=gb;if((gb|0)>0){Ra=kb}else{ob=kb;pb=nb;break}}}else{ob=$;pb=c[$a>>2]|0}}while(0);ypb(_+14424|0,da,c[sa>>2]|0,pb-1|0,c[bb>>2]|0,112);if((ob|0)<0){v=ob;E=166;break}ea=((ob|0)>($|0)?S:N)+1|0;if((ea|0)>=(C|0)){break a}N=ea;O=c[f>>2]|0}do{if((E|0)==28){O=_+4|0;QIb(c[O>>2]|0,2402584,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;Pa=O}else if((E|0)==30){O=_+4|0;KIb(c[O>>2]|0,16,2515096,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;Pa=O}else if((E|0)==44){O=_+4|0;KIb(c[O>>2]|0,16,2587632,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;Pa=O}else if((E|0)==47){O=_+4|0;KIb(c[O>>2]|0,16,2566408,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;Pa=O}else if((E|0)==49){O=_+4|0;KIb(c[O>>2]|0,16,2548288,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;Pa=O}else if((E|0)==51){O=_+4|0;KIb(c[O>>2]|0,16,2530376,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;Pa=O}else if((E|0)==53){O=_+4|0;KIb(c[O>>2]|0,16,2515096,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;Pa=O}else if((E|0)==65){KIb(Fa,16,2501240,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;Pa=Ea}else if((E|0)==90){KIb(c[Ea>>2]|0,48,2468056,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;v=-1094995529;i=j;return v|0}else if((E|0)==100){KIb(0,0,2441496,(F=i,i=i+24|0,c[F>>2]=2429832,c[F+8>>2]=2419328,c[F+16>>2]=441,F)|0);i=F;Hd();return 0}else if((E|0)==103){if((Ua|0)==-123){v=-1094995529;i=j;return v|0}else{Pa=_+4|0;break}}else if((E|0)==108){KIb(c[_+4>>2]|0,16,2170352,(F=i,i=i+16|0,c[F>>2]=ab,c[F+8>>2]=cb,F)|0);i=F;v=-1094995529;i=j;return v|0}else if((E|0)==110){KIb(c[_+4>>2]|0,16,2143144,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;v=-1094995529;i=j;return v|0}else if((E|0)==118){KIb(c[_+4>>2]|0,16,2119624,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;v=-1094995529;i=j;return v|0}else if((E|0)==138){O=c[bb>>2]|0;KIb(c[eb>>2]|0,16,2614560,(F=i,i=i+16|0,c[F>>2]=c[$a>>2],c[F+8>>2]=O,F)|0);i=F;v=-1094995529;i=j;return v|0}else if((E|0)==166){i=j;return v|0}}while(0);KIb(c[Pa>>2]|0,16,2202160,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;v=-1094995529;i=j;return v|0}}while(0);F=s+9856|0;do{if((c[F>>2]|0)!=0){if((c[s+12480>>2]|0)<(c[s+120>>2]|0)){break}zpb(s+14424|0);ETa(t);do{if((c[s+9992>>2]|0)==3){E=156}else{if((c[s+13944>>2]|0)!=0){E=156;break}Pa=s+9848|0;$a=c[Pa>>2]|0;if(($a|0)==0){qb=Pa;break}eb=YHb(u,$a|0)|0;if((eb|0)<0){v=eb;i=j;return v|0}else{HTa(t,c[Pa>>2]|0,u);ITa(t,u,c[Pa>>2]|0,0)|0;qb=Pa;break}}}while(0);do{if((E|0)==156){Pa=YHb(u,c[F>>2]|0)|0;if((Pa|0)<0){v=Pa;i=j;return v|0}else{HTa(t,c[F>>2]|0,u);ITa(t,u,c[F>>2]|0,0)|0;qb=s+9848|0;break}}}while(0);if((c[qb>>2]|0)==0){if((c[s+13944>>2]|0)!=0){E=163}}else{E=163}if((E|0)==163){c[g>>2]=1}c[F>>2]=0}}while(0);v=c[q>>2]|0;i=j;return v|0}function RZa(a){a=a|0;xTa(c[a+60>>2]|0);return 0}function SZa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;d=b+784|0;Y2(d);e=d|0;d=c[e>>2]|0;f=b+788|0;g=c[f>>2]|0;if((g|0)>1){h=g-1|0;i=d<<1|1}else{j=je(1>>>((1-g|0)>>>0)|d<<g|0)|0;d=b+796|0;k=c[d>>2]|0;y=j;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[d>>2]=(c[d>>2]|0)+4;h=g+31|0;i=1}c[e>>2]=i;c[f>>2]=h;g=(c[b+9992>>2]|0)==2|0;if((h|0)>1){l=h-1|0;m=i<<1|g}else{d=je(g>>>((1-h|0)>>>0)|i<<h|0)|0;i=b+796|0;k=c[i>>2]|0;y=d;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=h+31|0;m=g}c[e>>2]=m;c[f>>2]=l;if((l|0)>1){n=l-1|0;o=m<<1}else{g=je(m<<l|0)|0;m=b+796|0;h=c[m>>2]|0;y=g;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;n=l+31|0;o=0}c[e>>2]=o;c[f>>2]=n;l=c[b+9960>>2]|0;if((n|0)>5){p=n-5|0;q=o<<5|l}else{m=je(o<<n|l>>>((5-n|0)>>>0)|0)|0;o=b+796|0;h=c[o>>2]|0;y=m;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;p=n+27|0;q=l}c[e>>2]=q;c[f>>2]=p;if((p|0)>6){r=p-6|0;s=q<<6}else{l=je(q<<p|0)|0;q=b+796|0;n=c[q>>2]|0;y=l;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;r=p+26|0;s=0}c[e>>2]=s;c[f>>2]=r;if((r|0)>6){t=r-6|0;u=s<<6}else{p=je(s<<r|0)|0;s=b+796|0;q=c[s>>2]|0;y=p;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;t=r+26|0;u=0}c[e>>2]=u;c[f>>2]=t;r=ca(c[b+120>>2]|0,c[b+116>>2]|0)|0;if((t|0)>12){v=t-12|0;w=u<<12|r}else{s=je(r>>>((12-t|0)>>>0)|u<<t|0)|0;u=b+796|0;q=c[u>>2]|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+20|0;w=r}c[e>>2]=w;c[f>>2]=v;if((v|0)>3){x=v-3|0;z=w<<3;c[e>>2]=z;c[f>>2]=x;return}else{r=je(w<<v|0)|0;w=b+796|0;b=c[w>>2]|0;y=r;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;x=v+29|0;z=0;c[e>>2]=z;c[f>>2]=x;return}}function TZa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0;e=i;f=b+9992|0;g=c[f>>2]|0;h=b+784|0;j=c[h>>2]|0;k=b+788|0;l=c[k>>2]|0;if((l|0)>2){m=l-2|0;n=j<<2|g}else{o=je(g>>>((2-l|0)>>>0)|j<<l|0)|0;j=b+796|0;p=c[j>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;m=l+30|0;n=g}c[h>>2]=n;c[k>>2]=m;if((m|0)>1){q=m-1|0;r=n<<1}else{g=je(n<<m|0)|0;n=b+796|0;l=c[n>>2]|0;y=g;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;q=m+31|0;r=0}c[h>>2]=r;c[k>>2]=q;m=c[b+9960>>2]|0;if((q|0)>5){s=q-5|0;t=r<<5|m}else{n=je(r<<q|m>>>((5-q|0)>>>0)|0)|0;r=b+796|0;l=c[r>>2]|0;y=n;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;s=q+27|0;t=m}c[h>>2]=t;c[k>>2]=s;m=d&255;if((s|0)>8){u=s-8|0;v=t<<8|m}else{d=je(m>>>((8-s|0)>>>0)|t<<s|0)|0;t=b+796|0;q=c[t>>2]|0;y=d;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;u=s+24|0;v=m}c[h>>2]=v;c[k>>2]=u;c[b+12480>>2]=0;c[b+12476>>2]=0;vqb(b);u=c[b+12472>>2]|0;v=c[h>>2]|0;m=c[k>>2]|0;if((m|0)>1){w=m-1|0;x=v<<1|u}else{s=je(u>>>((1-m|0)>>>0)|v<<m|0)|0;v=b+796|0;t=c[v>>2]|0;y=s;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;w=m+31|0;x=u}c[h>>2]=x;c[k>>2]=w;if((c[b+11556>>2]|0)!=1){KIb(0,0,2480160,(z=i,i=i+24|0,c[z>>2]=2596296,c[z+8>>2]=2447040,c[z+16>>2]=43,z)|0);i=z;Hd()}if((c[b+10048>>2]|0)!=0){KIb(0,0,2480160,(z=i,i=i+24|0,c[z>>2]=2357768,c[z+8>>2]=2447040,c[z+16>>2]=44,z)|0);i=z;Hd()}if((c[b+13828>>2]|0)!=0){KIb(0,0,2480160,(z=i,i=i+24|0,c[z>>2]=2294576,c[z+8>>2]=2447040,c[z+16>>2]=45,z)|0);i=z;Hd()}if((c[b+13816>>2]|0)!=0){KIb(0,0,2480160,(z=i,i=i+24|0,c[z>>2]=2243520,c[z+8>>2]=2447040,c[z+16>>2]=46,z)|0);i=z;Hd()}if((c[b+13832>>2]|0)!=1){KIb(0,0,2480160,(z=i,i=i+24|0,c[z>>2]=2202128,c[z+8>>2]=2447040,c[z+16>>2]=47,z)|0);i=z;Hd()}if((c[b+13836>>2]|0)!=1){KIb(0,0,2480160,(z=i,i=i+24|0,c[z>>2]=2170328,c[z+8>>2]=2447040,c[z+16>>2]=48,z)|0);i=z;Hd()}z=(c[f>>2]|0)==1;c[b+228>>2]=z&1;f=b+9892|0;if(z){c[f>>2]=1434232;c[b+9888>>2]=1434232;i=e;return}else{c[f>>2]=1347360;c[b+9888>>2]=1347360;i=e;return}}function UZa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[b+60>>2]|0;c[e+15600>>2]=1;f=$Za(b)|0;if((f|0)<0){g=f;i=d;return g|0}f=b+100|0;if((c[f>>2]|0)<2){KIb(b,16,2447008,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1;i=d;return g|0}j=a[(c[b+96>>2]|0)+1|0]&7;c[e+15604>>2]=j;k=c[f>>2]|0;f=(j<<1)+8|0;if((k|0)<(f|0)){KIb(b,24,2357704,(h=i,i=i+16|0,c[h>>2]=f,c[h+8>>2]=k,h)|0);i=h}c[e+15732>>2]=402;c[e+15740>>2]=130;c[e+15736>>2]=716;c[e+15744>>2]=112;c[e+15276>>2]=675024;c[e+15280>>2]=675024;g=0;i=d;return g|0}function VZa(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;g=a+4|0;h=c[g>>2]|0;j=c[a+8>>2]|0;k=c[a+12>>2]|0;mrc(e|0,0,32)|0;l=b+8|0;m=c[l>>2]|0;n=b+16|0;o=c[n>>2]|0;p=b|0;q=c[p>>2]|0;r=q+(m>>>3)|0;s=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;r=m+3|0;t=o>>>0>r>>>0?r:o;c[l>>2]=t;if((s&-536870912>>>((m&7)>>>0)|0)!=0){u=-1;i=f;return u|0}m=q+(t>>>3)|0;q=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(t&7)>>>30;m=t+2|0;c[l>>2]=o>>>0>m>>>0?m:o;c[e>>2]=(q|0)==1?0:q;q=c[l>>2]|0;o=c[p>>2]|0;m=d[o+(q>>>3)|0]|0;t=c[n>>2]|0;s=((q|0)<(t|0))+q|0;c[l>>2]=s;if((m&128>>>((q&7)>>>0)|0)!=0){u=-1;i=f;return u|0}q=o+(s>>>3)|0;m=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(s&7)>>>27;q=s+5|0;c[l>>2]=t>>>0>q>>>0?q:t;c[e+4>>2]=m;m=c[n>>2]|0;t=(c[l>>2]|0)+1|0;q=m>>>0>t>>>0?t:m;c[l>>2]=q;t=o+(q>>>3)|0;s=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(q&7)>>>19;t=q+13|0;c[l>>2]=m>>>0>t>>>0?t:m;c[e+28>>2]=s;s=a+15604|0;a=c[s>>2]|0;m=a>>>0>65535>>>0;t=m?a>>>16:a;a=m?16:0;if((t&65280|0)==0){v=a;w=t}else{v=a|8;w=t>>>8}t=(d[1359664+w|0]|0)+v|0;v=c[l>>2]|0;w=c[n>>2]|0;a=o+(v>>>3)|0;o=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(v&7)>>>((31-t|0)>>>0);a=v+1+t|0;c[l>>2]=w>>>0>a>>>0?a:w;do{if((o|0)==0){x=j;y=k}else{if((o|0)>(c[s>>2]|0)){KIb(h,16,2143112,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;u=-1094995529;i=f;return u|0}w=c[h+100>>2]|0;a=o<<1;t=a+8|0;if((w|0)>=(t|0)){v=c[(c[g>>2]|0)+96>>2]|0;x=(d[v+(a+6)|0]|0)<<2;y=(d[v+(a+7)|0]|0)<<2;break}KIb(h,16,2357704,(z=i,i=i+16|0,c[z>>2]=t,c[z+8>>2]=w,z)|0);i=z;u=-22;i=f;return u|0}}while(0);c[e+20>>2]=x;c[e+24>>2]=y;z=_Za(b,ca(x+15>>4,y+15>>4)|0)|0;y=c[l>>2]|0;x=c[n>>2]|0;b=(c[p>>2]|0)+(y>>>3)|0;p=(je(d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0)|0)<<(y&7)>>>((32-z|0)>>>0);b=y+z|0;c[l>>2]=x>>>0>b>>>0?b:x;c[e+12>>2]=p;p=c[n>>2]|0;n=(c[l>>2]|0)+1|0;c[l>>2]=p>>>0>n>>>0?n:p;u=0;i=f;return u|0}function WZa(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;h=e+8|0;j=e+16|0;k=e|0;e=b+15272|0;l=0;m=f;a:while(1){f=0;n=m;while(1){o=c[h>>2]|0;p=c[j>>2]|0;q=c[k>>2]|0;r=q+(o>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(o&7);if((s&-1434451968|0)==0){r=1;t=o;u=s;while(1){v=u>>>24;w=a[1369728+v|0]|0;x=w&255;y=((w&255)>>>0>8>>>0?8:x)+t|0;z=p>>>0>y>>>0;A=z?y:p;if(!(w<<24>>24==9)){B=6;break}w=d[1369984+v|0]|r<<4;if(!(w>>>0<134217728>>>0)){C=w;break}y=q+(A>>>3)|0;D=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(A&7);if(z){r=w;t=A;u=D}else{C=w;break}}if((B|0)==6){B=0;C=d[1369984+v|0]|r<<(x-1>>1)}c[h>>2]=A;E=C-1|0}else{u=s>>>24;t=(d[1369728+u|0]|0)+o|0;c[h>>2]=p>>>0>t>>>0?t:p;E=d[1369216+u|0]|0}u=E<<1;if(u>>>0>160>>>0){B=12;break a}t=a[675088+(((a[n+(-(c[e>>2]|0)|0)|0]|0)*90|0)+99+((a[n-1|0]|0)*9|0)+(d[675992+u|0]|0))|0]|0;a[n]=t;if(t<<24>>24==9){B=13;break a}q=a[675088+(((a[n+(1-(c[e>>2]|0))|0]|0)*90|0)+99+((t<<24>>24)*9|0)+(d[675992+(u|1)|0]|0))|0]|0;a[n+1|0]=q;if(q<<24>>24==9){B=13;break a}q=f+2|0;if((q|0)<4){f=q;n=n+2|0}else{break}}f=l+1|0;if((f|0)<4){l=f;m=n+((c[e>>2]|0)-2)|0}else{F=0;B=16;break}}if((B|0)==12){KIb(c[b+4>>2]|0,16,2202088,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;F=-1;i=g;return F|0}else if((B|0)==13){KIb(c[b+4>>2]|0,16,2170288,(G=i,i=i+1|0,i=i+7&-8,c[G>>2]=0,G)|0);i=G;F=-1;i=g;return F|0}else if((B|0)==16){i=g;return F|0}return 0}function XZa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;f=b+14128|0;g=c[f>>2]|0;h=c[b+14136>>2]|0;j=c[b+14120>>2]|0;k=j+(g>>>3)|0;l=(je(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)|0)<<(g&7);if((l&-1434451968|0)==0){k=1;m=g;n=l;while(1){o=n>>>24;p=a[1369728+o|0]|0;q=p&255;r=((p&255)>>>0>8>>>0?8:q)+m|0;s=h>>>0>r>>>0;t=s?r:h;if(!(p<<24>>24==9)){u=4;break}p=d[1369984+o|0]|0|k<<4;if(!(p>>>0<134217728>>>0)){v=p;break}r=j+(t>>>3)|0;w=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7);if(s){k=p;m=t;n=w}else{v=p;break}}if((u|0)==4){v=d[1369984+o|0]|0|k<<(q-1>>1)}c[f>>2]=t;x=v-1|0}else{v=l>>>24;l=(d[1369728+v|0]|0)+g|0;c[f>>2]=h>>>0>l>>>0?l:h;x=d[1369216+v|0]|0}if(x>>>0>11>>>0){KIb(c[b+4>>2]|0,16,2294536,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;z=-1;i=e;return z|0}if(x>>>0>5>>>0){KIb(c[b+4>>2]|0,16,2243504,(y=i,i=i+1|0,i=i+7&-8,c[y>>2]=0,y)|0);i=y;A=x-6|0}else{A=x}if((c[b+9992>>2]|0)==3){z=c[676184+(A<<2)>>2]|0;i=e;return z|0}else{z=c[676160+(A<<2)>>2]|0;i=e;return z|0}return 0}function YZa(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;h=f+124|0;i=f+116|0;j=c[i>>2]|0;if((j|0)<=0){return}k=f+9856|0;l=f+15644|0;m=f+15648|0;n=1;o=ca(c[h>>2]|0,g)|0;p=j;while(1){j=c[(c[(c[k>>2]|0)+1536>>2]|0)+(o<<2)>>2]|0;q=(j&7|0)!=0;if(!((j&16777216|0)==0&(q^1))){b[(c[m>>2]|0)+(o<<1)>>1]=-1}if(q){a[(c[l>>2]|0)+o|0]=-1;r=c[i>>2]|0}else{r=p}if((n|0)>=(r|0)){break}n=n+1|0;o=o+1|0;p=r}if((r|0)<=0){return}r=f+9856|0;p=g<<4;o=f+148|0;n=f+15648|0;l=f+15644|0;m=g<<3;k=f+152|0;q=0;j=0;s=ca(c[h>>2]|0,g)|0;while(1){t=c[(c[r>>2]|0)+1512>>2]|0;u=d[675056+(a[t+s|0]|0)|0]|0;v=(j|0)!=0;w=s-1|0;if(v){x=d[675056+(a[t+w|0]|0)|0]|0}else{x=q}t=v&1^1;y=t<<2;z=y|j<<4;A=0;do{B=z+(ca(c[o>>2]|0,A+p|0)|0)|0;C=(c[c[r>>2]>>2]|0)+B|0;B=t;while(1){D=B+A|0;E=c[n>>2]|0;F=e[E+(s<<1)>>1]|0;do{if((F&1<<D|0)==0){if((B|0)==0){G=(e[E+(w<<1)>>1]&1<<D+3|0)!=0?x:0;break}else{G=(F&1<<D-1|0)==0?0:u;break}}else{G=u}}while(0);if((G|0)!=0){ZZa(C,1,c[o>>2]|0,G)}D=B+1|0;if((D|0)>=4){break}C=C+4|0;B=D}A=A+4|0;}while((A|0)<16);A=y|j<<3;z=0;do{B=c[l>>2]|0;C=z<<2;D=(d[B+s|0]|0)>>>(C>>>0)&15;if(v){H=(d[B+w|0]|0)>>>(C>>>0)&15}else{H=0}z=z+1|0;C=A+(ca(c[k>>2]|0,m)|0)|0;B=(c[(c[r>>2]|0)+(z<<2)>>2]|0)+C|0;C=t;while(1){do{if((1<<C&D|0)==0){if((C|0)==0){I=(H&2|0)!=0?x:0;break}else{I=(1<<C-1&D|0)==0?0:u;break}}else{I=u}}while(0);if((I|0)!=0){ZZa(B,1,c[k>>2]|0,I)}F=C+1|0;if((F|0)<2){B=B+4|0;C=F}else{break}}C=A+(ca(c[k>>2]|0,m|4)|0)|0;B=(c[(c[r>>2]|0)+(z<<2)>>2]|0)+C|0;C=t;while(1){do{if((1<<C+2&D|0)==0){if((C|0)==0){J=(1<<C+3&H|0)!=0?x:0;break}else{J=(1<<C+1&D|0)==0?0:u;break}}else{J=u}}while(0);if((J|0)!=0){ZZa(B,1,c[k>>2]|0,J)}F=C+1|0;if((F|0)<2){B=B+4|0;C=F}else{break}}}while((z|0)<2);z=j+1|0;K=c[i>>2]|0;if((z|0)>=(K|0)){break}q=x;j=z;s=s+1|0}if((K|0)<=0){return}K=f+9856|0;s=(g|0)!=0;j=(s&1)<<2^4;x=f+15644|0;q=g<<3;J=f+152|0;k=g<<4;H=f+148|0;r=f+15648|0;f=0;m=0;I=ca(c[h>>2]|0,g)|0;while(1){g=c[K>>2]|0;l=c[g+1512>>2]|0;G=d[675056+(a[l+I|0]|0)|0]|0;if(s){L=d[675056+(a[l+(I-(c[h>>2]|0))|0]|0)|0]|0}else{L=f}l=m<<4;o=j;n=g;while(1){g=c[n>>2]|0;p=c[H>>2]|0;z=(ca(p,o+k|0)|0)+l|0;u=g+z|0;t=c[r>>2]|0;A=b[t+(I<<1)>>1]|0;do{if((o|0)==0){if((A&1)==0){M=(b[t+(I-(c[h>>2]|0)<<1)>>1]&4096)!=0?L:0}else{M=G}if((M|0)==0){N=t;O=A}else{ZZa(u,p,1,M);w=c[r>>2]|0;N=w;O=b[w+(I<<1)>>1]|0}if((O&2)==0){P=(b[N+(I-(c[h>>2]|0)<<1)>>1]&8192)!=0?L:0}else{P=G}if((P|0)==0){Q=N;R=O}else{ZZa(g+(z+4)|0,c[H>>2]|0,1,P);w=c[r>>2]|0;Q=w;R=b[w+(I<<1)>>1]|0}if((R&4)==0){S=(b[Q+(I-(c[h>>2]|0)<<1)>>1]&16384)!=0?L:0}else{S=G}if((S|0)==0){T=Q;U=R}else{ZZa(g+(z+8)|0,c[H>>2]|0,1,S);w=c[r>>2]|0;T=w;U=b[w+(I<<1)>>1]|0}if((U&8)==0){V=(b[T+(I-(c[h>>2]|0)<<1)>>1]|0)<0?L:0}else{V=G}if((V|0)==0){break}ZZa(g+(z+12)|0,c[H>>2]|0,1,V)}else{w=A&65535;if((w&1<<o|0)==0){W=(w&1<<o-4|0)==0?0:G}else{W=G}if((W|0)==0){X=A}else{ZZa(u,p,1,W);X=b[(c[r>>2]|0)+(I<<1)>>1]|0}w=o|1;v=X&65535;if((v&1<<w|0)==0){Y=(v&1<<w-4|0)==0?0:G}else{Y=G}if((Y|0)==0){Z=X}else{ZZa(g+(z+4)|0,c[H>>2]|0,1,Y);Z=b[(c[r>>2]|0)+(I<<1)>>1]|0}w=o|2;v=Z&65535;if((v&1<<w|0)==0){_=(v&1<<w-4|0)==0?0:G}else{_=G}if((_|0)==0){$=Z}else{ZZa(g+(z+8)|0,c[H>>2]|0,1,_);$=b[(c[r>>2]|0)+(I<<1)>>1]|0}w=o|3;v=$&65535;if((v&1<<w|0)==0){aa=(v&1<<w-4|0)==0?0:G}else{aa=G}if((aa|0)==0){break}ZZa(g+(z+12)|0,c[H>>2]|0,1,aa)}}while(0);z=o+4|0;if((z|0)>=16){break}o=z;n=c[K>>2]|0}n=m<<3;o=0;do{l=c[x>>2]|0;z=a[l+I|0]|0;g=o<<2;p=(z&255)>>>(g>>>0)&15;if(s){ba=(d[l+(I-(c[h>>2]|0))|0]|0)>>>(g>>>0)&15}else{ba=0}o=o+1|0;g=j;l=z;while(1){z=c[(c[K>>2]|0)+(o<<2)>>2]|0;u=c[J>>2]|0;A=(ca(u,g+q|0)|0)+n|0;t=z+A|0;w=g>>1;v=(g|0)!=0;y=v^1;do{if((l&255&1<<w|0)==0){if(!v){C=(1<<w+2&ba|0)!=0;if(C|y){da=C?L:0;break}}da=(p&1<<w-2|0)==0?0:G}else{da=G}}while(0);if((da|0)==0){ea=l}else{ZZa(t,u,1,da);ea=a[(c[x>>2]|0)+I|0]|0}C=z+(A+4)|0;B=w|1;do{if((ea&255&1<<B|0)==0){if(!v){D=(1<<B+2&ba|0)!=0;if(D|y){fa=D?L:0;break}}fa=(p&1<<B-2|0)==0?0:G}else{fa=G}}while(0);if((fa|0)!=0){ZZa(C,c[J>>2]|0,1,fa)}B=g+4|0;if((B|0)>=8){break}g=B;l=a[(c[x>>2]|0)+I|0]|0}}while((o|0)<2);o=m+1|0;if((o|0)>=(c[i>>2]|0)){break}f=L;m=o;I=I+1|0}return}function ZZa(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=c*-2|0;h=-f|0;i=b+(-c|0)|0;j=d[i]|0;k=(d[b+g|0]|0)-(d[b+c|0]|0)-(j-(d[b]|0)<<2)>>3;if((k|0)<(h|0)){l=h}else{l=(k|0)>(f|0)?f:k}a[i]=a[1403376+((j|1024)+l)|0]|0;a[b]=a[1403376+(1024-l+(d[b]|0))|0]|0;l=b+e|0;j=b+(e-c)|0;i=d[j]|0;k=(d[b+(g+e)|0]|0)-(d[b+(e+c)|0]|0)-(i-(d[l]|0)<<2)>>3;if((k|0)<(h|0)){m=h}else{m=(k|0)>(f|0)?f:k}a[j]=a[1403376+((i|1024)+m)|0]|0;a[l]=a[1403376+(1024-m+(d[l]|0))|0]|0;l=e<<1;m=b+l|0;i=b+(l-c)|0;j=d[i]|0;k=(d[b+(l+g)|0]|0)-(d[b+(l+c)|0]|0)-(j-(d[m]|0)<<2)>>3;if((k|0)<(h|0)){n=h}else{n=(k|0)>(f|0)?f:k}a[i]=a[1403376+((j|1024)+n)|0]|0;a[m]=a[1403376+(1024-n+(d[m]|0))|0]|0;m=l+e|0;e=b+m|0;l=b+(m-c)|0;n=d[l]|0;j=(d[b+(m+g)|0]|0)-(d[b+(m+c)|0]|0)-(n-(d[e]|0)<<2)>>3;if((j|0)<(h|0)){o=h;p=n|1024;q=p+o|0;r=1403376+q|0;s=a[r]|0;a[l]=s;t=a[e]|0;u=t&255;v=1024-o|0;w=v+u|0;x=1403376+w|0;y=a[x]|0;a[e]=y;return}o=(j|0)>(f|0)?f:j;p=n|1024;q=p+o|0;r=1403376+q|0;s=a[r]|0;a[l]=s;t=a[e]|0;u=t&255;v=1024-o|0;w=v+u|0;x=1403376+w|0;y=a[x]|0;a[e]=y;return}function _Za(a,b){a=a|0;b=b|0;a=b-1|0;b=0;while(1){if((b|0)>=5){break}if((e[664984+(b<<1)>>1]|0|0)<(a|0)){b=b+1|0}else{break}}return d[665e3+b|0]|0|0}function $Za(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+60>>2]|0;d=b;uTa(d);c[b+28>>2]=2;e=a+48|0;c[b+48>>2]=c[e>>2];c[b+8>>2]=c[a+120>>2];c[b+12>>2]=c[a+124>>2];c[b+4>>2]=a;c[a+140>>2]=0;c[a+176>>2]=1;c[b+13944>>2]=0;f=rTa(d)|0;if((f|0)<0){g=f;return g|0}zma(b+15288|0,70,8,1);f=c[e>>2]|0;if((f|0)==69){fsb(b+14672|0);h=c[e>>2]|0}else{h=f}if((h|0)==70){s_a(b+14672|0)}h=a_a(b)|0;if((h|0)<0){xTa(d);g=h;return g|0}if((c[1474316]|0)==0){h=0;while(1){d=h*19|0;m_a(636088+(h*2592|0)|0,1296,5897264+(h*380|0)|0,0,d);m_a(617728+(h*216|0)|0,108,5897544+(h*380|0)|0,0,d+2|0);m_a(616648+(h*216|0)|0,108,5897584+(h*380|0)|0,0,d+4|0);m_a(649048+(h<<7)|0,16,5897304+(h*380|0)|0,675008,d+6|0);m_a(649080+(h<<7)|0,16,5897324+(h*380|0)|0,675008,d+7|0);m_a(649112+(h<<7)|0,16,5897344+(h*380|0)|0,675008,d+8|0);m_a(649144+(h<<7)|0,16,5897364+(h*380|0)|0,675008,d+9|0);m_a(637384+(h*2592|0)|0,1296,5897284+(h*380|0)|0,0,d+1|0);m_a(617836+(h*216|0)|0,108,5897564+(h*380|0)|0,0,d+3|0);m_a(616756+(h*216|0)|0,108,5897604+(h*380|0)|0,0,d+5|0);m_a(649064+(h<<7)|0,16,5897384+(h*380|0)|0,675008,d+10|0);m_a(649096+(h<<7)|0,16,5897404+(h*380|0)|0,675008,d+11|0);m_a(649128+(h<<7)|0,16,5897424+(h*380|0)|0,675008,d+12|0);m_a(649160+(h<<7)|0,16,5897444+(h*380|0)|0,675008,d+13|0);m_a(618808+(h*3456|0)|0,864,5897464+(h*380|0)|0,0,d+14|0);m_a(619672+(h*3456|0)|0,864,5897484+(h*380|0)|0,0,d+15|0);m_a(620536+(h*3456|0)|0,864,5897504+(h*380|0)|0,0,d+16|0);m_a(621400+(h*3456|0)|0,864,5897524+(h*380|0)|0,0,d+17|0);m_a(665008+(h<<5)|0,32,5897624+(h*380|0)|0,0,d+18|0);d=h+1|0;if((d|0)<5){h=d}else{i=0;break}}do{h=i*12|0;m_a(665392+(i*1296|0)|0,1296,5899264+(i*380|0)|0,0,h+95|0);m_a(674464+(i<<6)|0,16,5899304+(i*380|0)|0,675008,h+96|0);m_a(674480+(i<<6)|0,16,5899324+(i*380|0)|0,675008,h+97|0);m_a(674496+(i<<6)|0,16,5899344+(i*380|0)|0,675008,h+98|0);m_a(674512+(i<<6)|0,16,5899364+(i*380|0)|0,675008,h+99|0);m_a(652712+(i*1728|0)|0,864,5899464+(i*380|0)|0,0,h+100|0);m_a(651200+(i*216|0)|0,108,5899544+(i*380|0)|0,0,h+102|0);m_a(649688+(i*216|0)|0,108,5899584+(i*380|0)|0,0,h+104|0);m_a(653576+(i*1728|0)|0,864,5899484+(i*380|0)|0,0,h+101|0);m_a(651308+(i*216|0)|0,108,5899564+(i*380|0)|0,0,h+103|0);m_a(649796+(i*216|0)|0,108,5899604+(i*380|0)|0,0,h+105|0);m_a(665168+(i<<5)|0,32,5899624+(i*380|0)|0,0,h+106|0);i=i+1|0;}while((i|0)<7)}c[(c[a+64>>2]|0)+4>>2]=1;g=0;return g|0}function a_a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+15272|0;c[b>>2]=(c[a+116>>2]<<2)+4;d=a+124|0;e=a+120|0;f=a+15644|0;c[f>>2]=pJb(ca(c[e>>2]|0,c[d>>2]|0)|0)|0;g=a+15640|0;c[g>>2]=pJb(ca(c[d>>2]<<1,c[e>>2]|0)|0)|0;h=a+15648|0;c[h>>2]=pJb(ca(c[d>>2]<<1,c[e>>2]|0)|0)|0;i=a+15264|0;c[i>>2]=hJb(c[b>>2]<<3)|0;j=pJb(ca(c[d>>2]<<2,c[e>>2]|0)|0)|0;e=a+15548|0;c[e>>2]=j;do{if((c[f>>2]|0)!=0){if((c[g>>2]|0)==0){break}if((c[h>>2]|0)==0){break}d=c[i>>2]|0;if((d|0)==0|(j|0)==0){break}c[a+15268>>2]=d+(c[b>>2]<<2);k=0;return k|0}}while(0);mJb(i);c[a+15268>>2]=0;mJb(a+15728|0);mJb(e);mJb(g);mJb(f);mJb(h);k=-12;return k|0}function b_a(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0;k=i;i=i+88|0;l=k|0;m=k+32|0;n=k+40|0;o=k+48|0;p=k+56|0;q=c[j+24>>2]|0;r=j+28|0;j=c[r>>2]|0;s=f+60|0;t=c[s>>2]|0;u=t;v=t;w=g;if((j|0)==0){if((c[t+13944>>2]|0)!=0){x=0;i=k;return x|0}g=t+9852|0;y=c[g>>2]|0;if((y|0)==0){x=0;i=k;return x|0}z=YHb(w,y|0)|0;if((z|0)<0){x=z;i=k;return x|0}c[g>>2]=0;c[h>>2]=1;x=0;i=k;return x|0}g=f+212|0;z=c[g>>2]|0;y=(z|0)==0;do{if(y){A=(d[q]|0)+1|0;B=q+5|0;C=A<<3|1;D=q+C|0;E=j-C|0;C=q+1|0;F=B;G=d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0;if((d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)==1){H=G;I=A;J=B;K=E;L=D;break}H=je(G|0)|0;I=A;J=B;K=E;L=D}else{H=c[c[f+220>>2]>>2]|0;I=z;J=0;K=j;L=q}}while(0);do{if((H|0)>=0){do{if(y){q=J-4|0;j=J;z=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;if((d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)==1){M=z;break}M=je(z|0)|0}else{M=c[c[f+220>>2]>>2]|0}}while(0);if((M|0)>(K|0)){break}z=t+14120|0;q=z;do{if(y){j=J-4|0;D=J;E=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;if((d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)==1){N=E}else{N=je(E|0)|0}E=L+N|0;j=J-4|0;D=J;B=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;if((d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)==1){O=B;P=E;break}O=je(B|0)|0;P=E}else{E=c[c[f+220>>2]>>2]|0;O=E;P=L+E|0}}while(0);E=K-O<<3;B=E>>>0>2147483639>>>0|(P|0)==0;j=B?0:P;D=B?0:E;E=z;c[E>>2]=j;B=t+14132|0;c[B>>2]=D;A=t+14136|0;c[A>>2]=D+8;G=t+14124|0;c[G>>2]=j+(D>>3);D=t+14128|0;c[D>>2]=0;j=t+15732|0;do{if((Ee[c[j>>2]&511](u,q,p)|0)>=0){C=p+12|0;if((c[C>>2]|0)!=0){break}F=c[t+9848>>2]|0;if((F|0)==0){Q=28}else{if((c[F>>2]|0)==0){Q=28}}do{if((Q|0)==28){if((c[p>>2]|0)!=3){break}KIb(f,16,2446936,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;x=-1094995529;i=k;return x|0}}while(0);F=c[f+856>>2]|0;do{if((F|0)>7){S=c[p>>2]|0;if((S|0)!=3){if((F|0)<=31){break}if(!((S|0)!=1|(F|0)>47)){break}}x=c[r>>2]|0;i=k;return x|0}}while(0);F=t+13732|0;S=c[F>>2]|0;if((S|0)>0){KIb(f,16,2357656,(R=i,i=i+8|0,c[R>>2]=S,R)|0);i=R;zpb(t+14424|0);ETa(v)}S=t+8|0;T=p+20|0;U=c[T>>2]|0;do{if((c[S>>2]|0)==(U|0)){V=c[p+24>>2]|0;if((c[t+12>>2]|0)!=(V|0)){W=V;Q=41;break}X=t+4|0}else{W=c[p+24>>2]|0;Q=41}}while(0);do{if((Q|0)==41){V=t+4|0;Y=p+24|0;KIb(c[V>>2]|0,24,2294472,(R=i,i=i+16|0,c[R>>2]=U,c[R+8>>2]=W,R)|0);i=R;if((tIb(c[T>>2]|0,c[Y>>2]|0,0,c[V>>2]|0)|0)!=0){x=-1094995529;i=k;return x|0}Z=c[V>>2]|0;_=Z+224|0;$=c[S>>2]|0;aa=t+12|0;ba=c[aa>>2]|0;da=c[T>>2]|0;ea=c[Y>>2]|0;fa=c[_>>2]|0;ga=c[Z+228>>2]|0;Z=m;ha=m;c[ha>>2]=fa;ia=Z+4|0;c[ia>>2]=ga;if((fa|0)==0){c[ha>>2]=1;c[ia>>2]=1}c[n>>2]=ca(ea,$)|0;c[n+4>>2]=ca(da,ba)|0;yKb(o,Z,n);Z=c[o+4>>2]|0;ba=_;c[ba>>2]=c[o>>2];c[ba+4>>2]=Z;Z=c[T>>2]|0;c[S>>2]=Z;ba=c[Y>>2]|0;c[aa>>2]=ba;aa=H4a(c[V>>2]|0,Z,ba)|0;if((aa|0)<0){x=aa;i=k;return x|0}aa=sTa(v)|0;if((aa|0)<0){x=aa;i=k;return x|0}mJb(t+15264|0);c[t+15268>>2]=0;mJb(t+15728|0);mJb(t+15548|0);mJb(t+15640|0);mJb(t+15644|0);mJb(t+15648|0);aa=a_a(u)|0;if((aa|0)<0){x=aa}else{X=V;break}i=k;return x|0}}while(0);T=c[p>>2]|0;U=t+9992|0;c[U>>2]=(T|0)==0?1:T;if((DTa(v,c[X>>2]|0)|0)<0){x=-1;i=k;return x|0}STa(v);T=t+15728|0;if((c[T>>2]|0)==0){V=t+148|0;aa=hJb((c[V>>2]|0)*48|0)|0;c[T>>2]=aa;c[t+15704>>2]=aa;T=c[V>>2]|0;c[t+15708>>2]=aa+(T<<4);V=T<<5;c[t+15712>>2]=aa+V;T=V|16;c[t+15716>>2]=aa+T;ba=c[t+152>>2]<<3;c[t+15720>>2]=aa+(V+ba);c[t+15724>>2]=aa+(T+ba)}ba=c[p+28>>2]|0;c[t+15608>>2]=ba;T=t+15616|0;aa=c[T>>2]|0;V=t+15612|0;do{if((c[U>>2]|0)==3){Z=c[V>>2]|0;Y=aa-Z&8191;if((Y|0)==0){c[t+15628>>2]=8192;c[t+15624>>2]=8192;c[t+15636>>2]=8192;c[t+15632>>2]=8192;c[t+15620>>2]=0;break}_=((ba-Z<<14&134201344)>>>0)/(Y>>>0)|0;c[t+15632>>2]=_;Z=((aa-ba<<14&134201344)>>>0)/(Y>>>0)|0;c[t+15636>>2]=Z;if(((_|Z)&511|0)==0){c[t+15624>>2]=_>>>9;c[t+15628>>2]=Z>>>9;c[t+15620>>2]=1;break}else{c[t+15624>>2]=_;c[t+15628>>2]=Z;c[t+15620>>2]=0;break}}else{c[V>>2]=aa;c[T>>2]=ba}}while(0);ba=t+12480|0;c[ba>>2]=0;T=t+12476|0;c[T>>2]=0;K5a(c[X>>2]|0);aa=t+116|0;V=t+120|0;Z=t+15532|0;_=t+15528|0;Y=f+220|0;da=t+15516|0;$=da;ea=da;da=t+15536|0;ia=t+12|0;ha=t+15540|0;fa=t+15520|0;ga=t+9960|0;ja=t+12484|0;ka=t+15264|0;la=t+15272|0;ma=t+14084|0;na=t+13704|0;oa=t+13708|0;pa=t+12496|0;qa=t+12500|0;ra=t+12504|0;sa=t+12508|0;ta=t+12512|0;ua=t+12516|0;va=t+12544|0;wa=t+12548|0;xa=t+12552|0;ya=t+15268|0;za=t+124|0;Aa=t+15656|0;Ba=t+15680|0;Ca=t+15684|0;Da=t+15696|0;Ea=t+15700|0;Fa=t+9856|0;Ga=t+15660|0;Ha=t+15564|0;Ia=t+15600|0;Ja=t+15552|0;Ka=t+15740|0;La=t+15556|0;Ma=t+15640|0;Na=t+15644|0;Oa=t+15648|0;Pa=t+15560|0;Qa=t+15524|0;Ra=t+15284|0;Sa=t+15672|0;Ta=t+15668|0;Ua=t+15664|0;Va=t+15692|0;Wa=t+15676|0;Xa=t+15744|0;Ya=l;Za=t+14340|0;_a=t+15736|0;$a=t+128|0;ab=l|0;bb=t+15280|0;cb=t+15228|0;db=t+15236|0;eb=t+148|0;fb=t+15232|0;gb=t+15224|0;hb=t+152|0;ib=t+15548|0;jb=t+15568|0;kb=t+14672|0;lb=kb;mb=t+15184|0;nb=mb;ob=t+9852|0;pb=t+15632|0;qb=t+15636|0;rb=t+15624|0;sb=t+14928|0;tb=t+15196|0;ub=t+15620|0;vb=t+15704|0;wb=t+15708|0;xb=t+15628|0;yb=t+15712|0;zb=t+15720|0;Ab=t+15716|0;Bb=t+15724|0;Cb=jb;Db=t+15576|0;Eb=t+15572|0;Fb=t+15580|0;Gb=t+14424|0;Hb=0;a:while(1){if((Hb|0)>=(I|0)){break}Ib=(c[g>>2]|0)==0;do{if(Ib){Jb=Hb<<3;Kb=J+(Jb-4)|0;Lb=J+Jb|0;Jb=d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0;if((d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0)==1){Mb=Jb;break}Mb=je(Jb|0)|0}else{Mb=c[(c[Y>>2]|0)+(Hb<<2)>>2]|0}}while(0);Jb=Hb+1|0;do{if((Jb|0)==(I|0)){Nb=K}else{if(!Ib){Nb=c[(c[Y>>2]|0)+(Jb<<2)>>2]|0;break}Kb=Jb<<3;Lb=J+(Kb-4)|0;Ob=J+Kb|0;Kb=d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0;if((d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)==1){Nb=Kb;break}Nb=je(Kb|0)|0}}while(0);Ib=Nb-Mb|0;if((Mb|0)<0|(Mb|0)>(K|0)){Q=69;break}Kb=c[aa>>2]|0;c[Z>>2]=ca(c[V>>2]|0,Kb)|0;Lb=(ca(Kb,c[ba>>2]|0)|0)+(c[T>>2]|0)|0;c[F>>2]=Lb-(c[_>>2]|0);do{if((Jb|0)<(I|0)){Lb=(c[g>>2]|0)==0;do{if(Lb){Kb=Jb<<3;Ob=J+(Kb-4)|0;Pb=J+Kb|0;Kb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;if((d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)==1){Qb=Kb;break}Qb=je(Kb|0)|0}else{Qb=c[(c[Y>>2]|0)+(Jb<<2)>>2]|0}}while(0);if((Qb|0)<0){Q=81;break a}do{if(Lb){Kb=Jb<<3;Ob=J+(Kb-4)|0;Pb=J+Kb|0;Kb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;if((d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)==1){Rb=Kb;break}Rb=je(Kb|0)|0}else{Rb=c[(c[Y>>2]|0)+(Jb<<2)>>2]|0}}while(0);if((Rb|0)>(K|0)){Q=81;break a}do{if(Lb){Kb=Jb<<3;Ob=J+(Kb-4)|0;Pb=J+Kb|0;Kb=d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0;if((d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)==1){Sb=Kb}else{Sb=je(Kb|0)|0}Kb=L+Sb|0;Ob=Jb<<3;Pb=J+(Ob-4)|0;Tb=J+Ob|0;Ob=d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0;if((d[Pb]|d[Pb+1|0]<<8|d[Pb+2|0]<<16|d[Pb+3|0]<<24|0)==1){Ub=Ob;Vb=Kb;break}Ub=je(Ob|0)|0;Vb=Kb}else{Kb=c[(c[Y>>2]|0)+(Jb<<2)>>2]|0;Ub=Kb;Vb=L+Kb|0}}while(0);Lb=K-Ub<<3;Kb=Lb>>>0>2147483639>>>0|(Vb|0)==0;Ob=Kb?0:Vb;Pb=Kb?0:Lb;c[E>>2]=Ob;c[B>>2]=Pb;c[A>>2]=Pb+8;c[G>>2]=Ob+(Pb>>3);c[D>>2]=0;if((Ee[c[j>>2]&511](u,q,p)|0)>=0){c[Z>>2]=c[C>>2];Wb=Ib;break}Pb=Hb+2|0;if((Pb|0)>=(I|0)){Wb=K-Mb|0;break}do{if((c[g>>2]|0)==0){Ob=Pb<<3;Lb=J+(Ob-4)|0;Kb=J+Ob|0;Ob=d[Kb]|d[Kb+1|0]<<8|d[Kb+2|0]<<16|d[Kb+3|0]<<24|0;if((d[Lb]|d[Lb+1|0]<<8|d[Lb+2|0]<<16|d[Lb+3|0]<<24|0)==1){Xb=Ob;break}Xb=je(Ob|0)|0}else{Xb=c[(c[Y>>2]|0)+(Pb<<2)>>2]|0}}while(0);Wb=Xb-Mb|0}else{Wb=Ib}}while(0);if((Wb|0)<0|(Wb|0)>(K-Mb|0)){Q=98;break}Ib=c[Z>>2]|0;Pb=L+Mb|0;Ob=Wb<<3;Lb=Ob>>>0>2147483639>>>0|(Pb|0)==0;Kb=Lb?0:Pb;Pb=Lb?0:Ob;c[E>>2]=Kb;c[B>>2]=Pb;c[A>>2]=Pb+8;c[G>>2]=Kb+(Pb>>3);c[D>>2]=0;if((Ee[c[j>>2]&511](u,q,$)|0)<0){Q=100;break}Pb=c[ea>>2]|0;if((((Pb|0)==0?1:Pb)|0)!=(c[U>>2]|0)){Q=102;break}if((c[S>>2]|0)!=(c[da>>2]|0)){Q=105;break}if((c[ia>>2]|0)!=(c[ha>>2]|0)){Q=105;break}c[Z>>2]=Ib;c[ga>>2]=c[fa>>2];Pb=c[_>>2]|0;c[F>>2]=Ib-Pb;c[ja>>2]=0;Ib=(ca(c[aa>>2]|0,c[ba>>2]|0)|0)+(c[T>>2]|0)|0;if((Pb|0)!=(Ib|0)){KIb(c[X>>2]|0,16,2119512,(R=i,i=i+16|0,c[R>>2]=Pb,c[R+8>>2]=Ib,R)|0);i=R;Ib=c[_>>2]|0;Pb=c[aa>>2]|0;c[T>>2]=(Ib|0)%(Pb|0)|0;c[ba>>2]=(Ib|0)/(Pb|0)|0}mrc(c[ka>>2]|0,-1|0,c[la>>2]<<3|0)|0;c[ma>>2]=1;c[na>>2]=c[T>>2];c[oa>>2]=c[ba>>2];NTa(v);Pb=c[ba>>2]|0;b:do{if((Pb|0)<(c[V>>2]|0)){Ib=Pb;Kb=c[F>>2]|0;while(1){if((Kb|0)==0){Yb=Ib;break b}do{if((c[ja>>2]|0)<=1){Ob=c[D>>2]|0;Lb=(c[B>>2]|0)-Ob|0;if((Lb|0)<1){Yb=Ib;break b}if((Lb|0)>=8){break}Tb=(c[E>>2]|0)+(Ob>>>3)|0;if(((je(d[Tb]|d[Tb+1|0]<<8|d[Tb+2|0]<<16|d[Tb+3|0]<<24|0)|0)<<(Ob&7)>>>((32-Lb|0)>>>0)|0)==0){Yb=Ib;break b}}}while(0);Lb=c[X>>2]|0;Ob=8>>>((c[Lb+800>>2]|0)>>>0);c[pa>>2]=(c[pa>>2]|0)+2;c[qa>>2]=(c[qa>>2]|0)+2;c[ra>>2]=(c[ra>>2]|0)+2;c[sa>>2]=(c[sa>>2]|0)+2;c[ta>>2]=(c[ta>>2]|0)+1;c[ua>>2]=(c[ua>>2]|0)+1;Tb=(c[va>>2]|0)+(Ob<<1)|0;c[va>>2]=Tb;c[wa>>2]=(c[wa>>2]|0)+Ob;c[xa>>2]=(c[xa>>2]|0)+Ob;Ob=c[ya>>2]|0;Zb=c[T>>2]|0;_b=(Zb<<2)+4|0;$b=Ob+_b|0;do{if((c[ea>>2]|0)==0){ac=c[za>>2]|0;bc=(ca(ac,Ib)|0)+Zb|0;mrc(Aa|0,0,48)|0;c[Ba>>2]=1;c[Ca>>2]=1;c[Da>>2]=1;c[Ea>>2]=1;cc=c[aa>>2]|0;dc=(ca(Ib-(c[oa>>2]|0)|0,cc)|0)+(Zb-(c[na>>2]|0))|0;ec=(Zb|0)==0;if(!(ec|(dc|0)==0)){fc=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc-1<<2)>>2]|0;c[Va>>2]=fc;c[Wa>>2]=fc}if((dc|0)>=(cc|0)){fc=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc-ac<<2)>>2]|0;c[Ta>>2]=fc;c[Ua>>2]=fc}if(!((Zb+1|0)>=(cc|0)|(dc|0)<(cc-1|0))){c[Sa>>2]=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(1-ac+bc<<2)>>2]}if((dc|0)>(cc|0)&(ec^1)){c[Ga>>2]=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc+~ac<<2)>>2]}c[ga>>2]=c[fa>>2];ac=c[D>>2]|0;ec=c[E>>2]|0;cc=d[ec+(ac>>>3)|0]<<(ac&7)>>>7;dc=c[A>>2]|0;fc=((ac|0)<(dc|0))+ac|0;c[D>>2]=fc;ac=cc&1;c[Ha>>2]=ac;if((ac|0)==0){do{if((c[Ia>>2]|0)==0){ac=d[ec+(fc>>>3)|0]|0;c[D>>2]=((fc|0)<(dc|0))+fc;if((ac&128>>>((fc&7)>>>0)|0)!=0){break}KIb(Lb,16,2637728,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R}}while(0);c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc<<2)>>2]=1;c[Ja>>2]=0;if((Ee[c[Ka>>2]&511](u,q,$b)|0)<0){gc=-1}else{hc=1;Q=304}}else{c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(bc<<2)>>2]=2;c[Ja>>2]=1;fc=c[D>>2]|0;dc=c[A>>2]|0;ac=ec+(fc>>>3)|0;cc=(je(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(fc&7)>>>30;ac=fc+2|0;c[D>>2]=dc>>>0>ac>>>0?ac:dc;dc=c[la>>2]|0;ac=ca(cc,16843009)|0;c[$b>>2]=ac;c[Ob+(dc+_b)>>2]=ac;c[Ob+((dc<<1)+_b)>>2]=ac;c[Ob+((dc*3|0)+_b)>>2]=ac;hc=2;Q=304}if((Q|0)==304){Q=0;c[La>>2]=hc;c[Pa>>2]=0;ac=c[fa>>2]|0;dc=c[Qa>>2]|0;if((dc|0)==2&(ac|0)<19){ic=ac+10|0}else{ic=(dc|0)!=0&(ac|0)<26?ac+5|0:ac}if((ic|0)<0){jc=0}else{jc=(ic|0)>30?30:ic}ac=5897264+((d[664808+jc|0]|0)*380|0)|0;c[Ra>>2]=ac;gc=h_a(q,ac,c[Ha>>2]|0)|0}b[(c[Ma>>2]|0)+(bc<<1)>>1]=gc;a[(c[Na>>2]|0)+bc|0]=gc>>>16;b[(c[Oa>>2]|0)+(bc<<1)>>1]=-1;a[(c[(c[Fa>>2]|0)+1512>>2]|0)+bc|0]=c[ga>>2];if((gc|0)==-1){Q=314;break a}if((c[Ha>>2]|0)==0){e_a(u,$b,gc);break}else{d_a(u,$b,gc);break}}else{ac=c[Za>>2]|0;dc=c[za>>2]|0;cc=(ca(dc,Ib)|0)+Zb|0;mrc(Aa|0,0,48)|0;c[Ba>>2]=1;c[Ca>>2]=1;c[Da>>2]=1;c[Ea>>2]=1;fc=c[aa>>2]|0;kc=(ca(Ib-(c[oa>>2]|0)|0,fc)|0)+(Zb-(c[na>>2]|0))|0;lc=(Zb|0)==0;if(!(lc|(kc|0)==0)){mc=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc-1<<2)>>2]|0;c[Va>>2]=mc;c[Wa>>2]=mc}if((kc|0)>=(fc|0)){mc=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc-dc<<2)>>2]|0;c[Ta>>2]=mc;c[Ua>>2]=mc}if(!((Zb+1|0)>=(fc|0)|(kc|0)<(fc-1|0))){c[Sa>>2]=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(1-dc+cc<<2)>>2]}if((kc|0)>(fc|0)&(lc^1)){c[Ga>>2]=c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc+~dc<<2)>>2]}c[ga>>2]=c[fa>>2];dc=ve[c[_a>>2]&4095](u)|0;c[Ja>>2]=dc;c:do{if((dc|0)==-1){nc=-1}else{lc=(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc<<2)|0;c[lc>>2]=c[664936+(dc<<2)>>2];fc=(c[ib>>2]|0)+(cc<<2)|0;c[fc>>2]=c[Ja>>2];do{if((c[Ja>>2]|0)==6){kc=c[U>>2]|0;if((kc|0)==2){c[fc>>2]=2;oc=c[U>>2]|0}else{oc=kc}if((oc|0)!=3){break}c[fc>>2]=7}}while(0);c[Ha>>2]=(c[lc>>2]|0)>>>1&1;fc=c[Ja>>2]|0;kc=c[T>>2]|0;mc=ca(c[$a>>2]|0,c[ba>>2]|0)|0;mrc(jb|0,0,32)|0;if((3900>>>(fc>>>0)&1|0)!=0){pc=c[777608+(fc<<2)>>2]|0;qc=0;rc=c[D>>2]|0;sc=c[A>>2]|0;tc=c[E>>2]|0;while(1){uc=tc+(rc>>>3)|0;vc=(je(d[uc]|d[uc+1|0]<<8|d[uc+2|0]<<16|d[uc+3|0]<<24|0)|0)<<(rc&7);do{if((vc&-1434451968|0)==0){uc=rc+8|0;wc=sc>>>0>uc>>>0?uc:sc;uc=tc+(wc>>>3)|0;xc=(je(d[uc]|d[uc+1|0]<<8|d[uc+2|0]<<16|d[uc+3|0]<<24|0)|0)<<(wc&7)>>>8|vc;uc=xc|1;if((xc&-1431655766|0)==0){yc=-2147483648;break}if((uc|0)>-1){xc=uc;zc=31;while(1){Ac=zc-1|0;Bc=(xc>>>30|xc<<2)-(xc<<zc>>>(Ac>>>0))|0;if((Bc|0)>-1){xc=Bc;zc=Ac}else{Cc=Bc;Dc=Ac;break}}}else{Cc=uc;Dc=31}zc=wc+55-(Dc<<1)|0;c[D>>2]=sc>>>0>zc>>>0?zc:sc;yc=((Cc<<Dc>>>(Dc>>>0))-1^-(Cc&1))+1>>1}else{zc=vc>>>24;xc=(d[1369728+zc|0]|0)+rc|0;c[D>>2]=sc>>>0>xc>>>0?xc:sc;yc=a[1369472+zc|0]|0}}while(0);c[u+15568+(qc<<3)>>2]=yc;vc=c[D>>2]|0;zc=c[A>>2]|0;xc=c[E>>2]|0;Ac=xc+(vc>>>3)|0;Bc=(je(d[Ac]|d[Ac+1|0]<<8|d[Ac+2|0]<<16|d[Ac+3|0]<<24|0)|0)<<(vc&7);do{if((Bc&-1434451968|0)==0){Ac=vc+8|0;Ec=zc>>>0>Ac>>>0?Ac:zc;Ac=xc+(Ec>>>3)|0;Fc=(je(d[Ac]|d[Ac+1|0]<<8|d[Ac+2|0]<<16|d[Ac+3|0]<<24|0)|0)<<(Ec&7)>>>8|Bc;Ac=Fc|1;if((Fc&-1431655766|0)==0){Gc=-2147483648;Hc=vc;break}if((Ac|0)>-1){Fc=Ac;Ic=31;while(1){Jc=Ic-1|0;Kc=(Fc>>>30|Fc<<2)-(Fc<<Ic>>>(Jc>>>0))|0;if((Kc|0)>-1){Fc=Kc;Ic=Jc}else{Lc=Kc;Mc=Jc;break}}}else{Lc=Ac;Mc=31}Ic=Ec+55-(Mc<<1)|0;Fc=zc>>>0>Ic>>>0?Ic:zc;c[D>>2]=Fc;Gc=((Lc<<Mc>>>(Mc>>>0))-1^-(Lc&1))+1>>1;Hc=Fc}else{Fc=Bc>>>24;Ic=(d[1369728+Fc|0]|0)+vc|0;wc=zc>>>0>Ic>>>0?Ic:zc;c[D>>2]=wc;Gc=a[1369472+Fc|0]|0;Hc=wc}}while(0);c[u+15568+(qc<<3)+4>>2]=Gc;vc=qc+1|0;if((vc|0)<(pc|0)){qc=vc;rc=Hc;sc=zc;tc=xc}else{break}}}d:do{switch(fc|0){case 0:case 1:{tc=c[$a>>2]|0;sc=(ca(c[ba>>2]<<1,tc)|0)+(c[T>>2]<<1)|0;rc=c[(c[Fa>>2]|0)+1524>>2]|0;qc=rc+(sc<<2)|0;pc=qc;lc=tc<<2;c[qc>>2]=0;c[pc+lc>>2]=0;c[rc+(sc<<2)+4>>2]=0;c[pc+(lc+4)>>2]=0;break};case 6:{if((c[U>>2]|0)!=2){Q=150;break d}lc=c[$a>>2]|0;pc=(ca(c[ba>>2]<<1,lc)|0)+(c[T>>2]<<1)|0;sc=c[(c[Fa>>2]|0)+1524>>2]|0;rc=sc+(pc<<2)|0;qc=rc;tc=lc<<2;c[rc>>2]=0;c[qc+tc>>2]=0;c[sc+(pc<<2)+4>>2]=0;c[qc+(tc+4)>>2]=0;l_a(u,6,0,0,0,2,2,0,c[Ia>>2]|0,0,lb,nb);break};case 7:{Q=150;break};case 3:{j_a(u,3,0,0);l_a(u,3,0,0,0,1,1,0,c[Ia>>2]|0,0,lb,nb);j_a(u,3,1,1);l_a(u,3,8,0,1,1,1,0,c[Ia>>2]|0,0,lb,nb);j_a(u,3,2,2);l_a(u,3,0,8,c[$a>>2]|0,1,1,0,c[Ia>>2]|0,0,lb,nb);j_a(u,3,3,3);l_a(u,3,8,8,(c[$a>>2]|0)+1|0,1,1,0,c[Ia>>2]|0,0,lb,nb);break};case 10:{k_a(u,10,0);k_a(u,10,1);i_a(u,10);break};case 8:case 9:{j_a(u,fc,0,0);tc=(fc|0)==8;j_a(u,fc,tc?2:1,1);qc=c[Ia>>2]|0;if(tc){l_a(u,8,0,0,0,2,1,0,qc,0,lb,nb);l_a(u,8,0,8,c[$a>>2]|0,2,1,0,c[Ia>>2]|0,0,lb,nb);break d}else{l_a(u,fc,0,0,0,1,2,0,qc,0,lb,nb);l_a(u,fc,8,0,1,1,2,0,c[Ia>>2]|0,0,lb,nb);break d}break};case 2:case 11:{j_a(u,fc,0,0);l_a(u,fc,0,0,0,2,2,0,c[Ia>>2]|0,0,lb,nb);break};case 4:case 5:{qc=c[Cb>>2]|0;c[Db>>2]=qc;tc=c[Eb>>2]|0;c[Fb>>2]=tc;pc=c[Ia>>2]|0;sc=(fc|0)==5|0;if((pc|0)==0){k_a(u,fc,sc);Nc=c[Ia>>2]|0}else{rc=c[$a>>2]|0;lc=(ca(c[ba>>2]<<1,rc)|0)+(c[T>>2]<<1)|0;vc=(c[Wa>>2]|0)==0;if(vc){Oc=0;Pc=0}else{Bc=lc-1|0;wc=c[(c[Fa>>2]|0)+1524>>2]|0;Oc=b[wc+(Bc<<2)+2>>1]|0;Pc=b[wc+(Bc<<2)>>1]|0}Bc=(c[Ua>>2]|0)==0;if(Bc){Qc=Pc;Rc=Oc}else{wc=lc-rc|0;Fc=c[(c[Fa>>2]|0)+1524>>2]|0;Qc=b[Fc+(wc<<2)>>1]|0;Rc=b[Fc+(wc<<2)+2>>1]|0}do{if((c[Sa>>2]|0)==0){if(Bc|vc){Sc=Pc;Tc=Oc;break}wc=lc-rc-1|0;Fc=c[(c[Fa>>2]|0)+1524>>2]|0;Sc=b[Fc+(wc<<2)>>1]|0;Tc=b[Fc+(wc<<2)+2>>1]|0}else{wc=lc-rc+2|0;Fc=c[(c[Fa>>2]|0)+1524>>2]|0;Sc=b[Fc+(wc<<2)>>1]|0;Tc=b[Fc+(wc<<2)+2>>1]|0}}while(0);do{if((Pc|0)>(Qc|0)){if((Sc|0)<=(Qc|0)){Uc=Qc;break}Uc=(Sc|0)>(Pc|0)?Pc:Sc}else{if((Qc|0)<=(Sc|0)){Uc=Qc;break}Uc=(Sc|0)>(Pc|0)?Sc:Pc}}while(0);do{if((Oc|0)>(Rc|0)){if((Tc|0)<=(Rc|0)){Vc=Rc;break}Vc=(Tc|0)>(Oc|0)?Oc:Tc}else{if((Rc|0)<=(Tc|0)){Vc=Rc;break}Vc=(Tc|0)>(Oc|0)?Tc:Oc}}while(0);vc=Uc+qc&65535;Bc=c[Fa>>2]|0;xc=Vc+tc&65535;zc=c[Bc+1524>>2]|0;b[zc+(lc<<2)>>1]=vc;b[zc+(lc<<2)+2>>1]=xc;wc=c[Bc+1528>>2]|0;b[wc+(lc<<2)>>1]=vc;b[wc+(lc<<2)+2>>1]=xc;Bc=lc|1;b[zc+(Bc<<2)>>1]=vc;b[zc+(Bc<<2)+2>>1]=xc;b[wc+(Bc<<2)>>1]=vc;b[wc+(Bc<<2)+2>>1]=xc;Fc=lc+rc|0;b[zc+(Fc<<2)>>1]=vc;b[zc+(Fc<<2)+2>>1]=xc;b[wc+(Fc<<2)>>1]=vc;b[wc+(Fc<<2)+2>>1]=xc;Fc=Bc+rc|0;b[zc+(Fc<<2)>>1]=vc;b[zc+(Fc<<2)+2>>1]=xc;b[wc+(Fc<<2)>>1]=vc;b[wc+(Fc<<2)+2>>1]=xc;Nc=pc}l_a(u,fc,0,0,0,2,2,sc,Nc,0,lb,nb);break};default:{}}}while(0);if((Q|0)==150){Q=0;xc=c[T>>2]|0;Fc=c[ba>>2]|0;wc=(ca(c[za>>2]|0,Fc)|0)+xc|0;vc=c[ob>>2]|0;zc=c[(c[vc+1536>>2]|0)+(wc<<2)>>2]|0;if((zc&2055|0)==0){wc=mc+kc<<1;Bc=c[$a>>2]|0;Ic=c[vc+1524>>2]|0;vc=c[Fa>>2]|0;uc=c[pb>>2]|0;Jc=c[vc+1524>>2]|0;Kc=c[qb>>2]|0;Wc=c[vc+1528>>2]|0;vc=wc|1;Xc=Ic+(wc<<2)|0;b[Jc+(wc<<2)>>1]=((ca(b[Xc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(wc<<2)>>1]=(8192-(ca(b[Xc>>1]|0,Kc)|0)|0)>>>14;Xc=Ic+(wc<<2)+2|0;b[Jc+(wc<<2)+2>>1]=((ca(b[Xc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(wc<<2)+2>>1]=(8192-(ca(b[Xc>>1]|0,Kc)|0)|0)>>>14;Xc=Ic+(vc<<2)|0;b[Jc+(vc<<2)>>1]=((ca(b[Xc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(vc<<2)>>1]=(8192-(ca(b[Xc>>1]|0,Kc)|0)|0)>>>14;Xc=Ic+(vc<<2)+2|0;b[Jc+(vc<<2)+2>>1]=((ca(b[Xc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(vc<<2)+2>>1]=(8192-(ca(b[Xc>>1]|0,Kc)|0)|0)>>>14;Xc=Bc+wc|0;wc=Ic+(Xc<<2)|0;b[Jc+(Xc<<2)>>1]=((ca(b[wc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(Xc<<2)>>1]=(8192-(ca(b[wc>>1]|0,Kc)|0)|0)>>>14;wc=Ic+(Xc<<2)+2|0;b[Jc+(Xc<<2)+2>>1]=((ca(b[wc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(Xc<<2)+2>>1]=(8192-(ca(b[wc>>1]|0,Kc)|0)|0)>>>14;wc=Bc+vc|0;vc=Ic+(wc<<2)|0;b[Jc+(wc<<2)>>1]=((ca(b[vc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(wc<<2)>>1]=(8192-(ca(b[vc>>1]|0,Kc)|0)|0)>>>14;vc=Ic+(wc<<2)+2|0;b[Jc+(wc<<2)+2>>1]=((ca(b[vc>>1]|0,uc)|0)+8192|0)>>>14;b[Wc+(wc<<2)+2>>1]=(8192-(ca(b[vc>>1]|0,Kc)|0)|0)>>>14}else{Kc=c[$a>>2]|0;vc=(ca(Fc<<1,Kc)|0)+(xc<<1)|0;xc=c[Fa>>2]|0;Fc=c[xc+1524>>2]|0;wc=Fc+(vc<<2)|0;Wc=wc;uc=Kc<<2;c[wc>>2]=0;c[Wc+uc>>2]=0;c[Fc+(vc<<2)+4>>2]=0;c[Wc+(uc+4)>>2]=0;uc=c[$a>>2]|0;Wc=(ca(c[ba>>2]<<1,uc)|0)+(c[T>>2]<<1)|0;vc=c[xc+1528>>2]|0;xc=vc+(Wc<<2)|0;Fc=xc;wc=uc<<2;c[xc>>2]=0;c[Fc+wc>>2]=0;c[vc+(Wc<<2)+4>>2]=0;c[Fc+(wc+4)>>2]=0}do{if((zc&112|0)==0){i_a(u,fc)}else{wc=c[Ia>>2]|0;if((wc|0)==0){Yc=(c[rb>>2]|0)!=8192}else{Yc=0}Fc=Yc&1;Wc=Yc?kb:sb;vc=Yc?mb:tb;l_a(u,3,0,0,0,1,1,0,wc,Fc,lb,nb);l_a(u,3,0,0,0,1,1,1,c[Ia>>2]|0,Fc,Wc,vc);l_a(u,3,8,0,1,1,1,0,c[Ia>>2]|0,Fc,lb,nb);l_a(u,3,8,0,1,1,1,1,c[Ia>>2]|0,Fc,Wc,vc);l_a(u,3,0,8,c[$a>>2]|0,1,1,0,c[Ia>>2]|0,Fc,lb,nb);l_a(u,3,0,8,c[$a>>2]|0,1,1,1,c[Ia>>2]|0,Fc,Wc,vc);l_a(u,3,8,8,(c[$a>>2]|0)+1|0,1,1,0,c[Ia>>2]|0,Fc,lb,nb);l_a(u,3,8,8,(c[$a>>2]|0)+1|0,1,1,1,c[Ia>>2]|0,Fc,Wc,vc);if(!Yc){break}_e[c[u+15208+(c[ub>>2]<<3)>>2]&511](c[va>>2]|0,c[vb>>2]|0,c[wb>>2]|0,c[rb>>2]|0,c[xb>>2]|0,c[eb>>2]|0);_e[c[u+15208+(c[ub>>2]<<3)+4>>2]&511](c[wa>>2]|0,c[yb>>2]|0,c[zb>>2]|0,c[rb>>2]|0,c[xb>>2]|0,c[hb>>2]|0);_e[c[u+15208+(c[ub>>2]<<3)+4>>2]&511](c[xa>>2]|0,c[Ab>>2]|0,c[Bb>>2]|0,c[rb>>2]|0,c[xb>>2]|0,c[hb>>2]|0)}}while(0);fc=c[$a>>2]|0;zc=(ca(c[ba>>2]<<1,fc)|0)+(c[T>>2]<<1)|0;kc=c[(c[Fa>>2]|0)+1524>>2]|0;mc=kc+(zc<<2)|0;vc=mc;Wc=fc<<2;c[mc>>2]=0;c[vc+Wc>>2]=0;c[kc+(zc<<2)+4>>2]=0;c[vc+(Wc+4)>>2]=0}if((c[Ja>>2]|0)==6){Wc=c[la>>2]|0;c[$b>>2]=0;c[Ob+(Wc+_b)>>2]=0;c[Ob+((Wc<<1)+_b)>>2]=0;c[Ob+((Wc*3|0)+_b)>>2]=0;nc=0;break}c[Pa>>2]=1;c[La>>2]=0;do{if((c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc<<2)>>2]&7|0)==0){Wc=0;do{a[Ob+((Wc&3|_b)+(ca(c[la>>2]|0,Wc>>2)|0))|0]=0;Wc=Wc+1|0;}while((Wc|0)<16);Wc=c[fa>>2]|0;sc=c[Qa>>2]|0;pc=(sc|0)==2&(Wc|0)<19;if(pc){Zc=Wc+10|0}else{Zc=(sc|0)!=0&(Wc|0)<26?Wc+5|0:Wc}if((Zc|0)<0){_c=0}else{_c=(Zc|0)>30?30:Zc}rc=5899264+((d[664839+_c|0]|0)*380|0)|0;c[Ra>>2]=rc;if((c[(c[ib>>2]|0)+(cc<<2)>>2]|0)!=11){$c=rc;break}c[Ha>>2]=1;c[Pa>>2]=1;c[La>>2]=2;if(pc){ad=Wc+10|0}else{ad=(sc|0)!=0&(Wc|0)<26?Wc+5|0:Wc}if((ad|0)<0){bd=0}else{bd=(ad|0)>30?30:ad}Wc=5897264+((d[664808+bd|0]|0)*380|0)|0;c[Ra>>2]=Wc;$c=Wc}else{if((c[Ha>>2]|0)==0){if((Ee[c[Ka>>2]&511](u,q,$b)|0)<0){nc=-1;break c}else{cd=1}}else{Wc=c[D>>2]|0;sc=c[A>>2]|0;pc=(c[E>>2]|0)+(Wc>>>3)|0;rc=(je(d[pc]|d[pc+1|0]<<8|d[pc+2|0]<<16|d[pc+3|0]<<24|0)|0)<<(Wc&7)>>>30;pc=Wc+2|0;c[D>>2]=sc>>>0>pc>>>0?pc:sc;sc=c[la>>2]|0;pc=ca(rc,16843009)|0;c[$b>>2]=pc;c[Ob+(sc+_b)>>2]=pc;c[Ob+((sc<<1)+_b)>>2]=pc;c[Ob+((sc*3|0)+_b)>>2]=pc;cd=2}c[La>>2]=cd;c[Pa>>2]=0;pc=c[fa>>2]|0;sc=c[Qa>>2]|0;if((sc|0)==2&(pc|0)<19){dd=pc+10|0}else{dd=(sc|0)!=0&(pc|0)<26?pc+5|0:pc}if((dd|0)<0){ed=0}else{ed=(dd|0)>30?30:dd}pc=5897264+((d[664808+ed|0]|0)*380|0)|0;c[Ra>>2]=pc;$c=pc}}while(0);nc=h_a(q,$c,c[Ha>>2]|0)|0}}while(0);b[(c[Ma>>2]|0)+(cc<<1)>>1]=nc;a[(c[Na>>2]|0)+cc|0]=nc>>>16;dc=c[T>>2]|0;bc=c[ba>>2]|0;ec=c[$a>>2]|0;pc=(ca(ec,bc)|0)+dc<<1;sc=c[Fa>>2]|0;rc=1-ec|0;Wc=-ec|0;lc=0;tc=0;qc=0;vc=(c[sc+1524>>2]|0)+(pc<<2)|0;pc=bc;zc=bc;while(1){kc=b[vc>>1]|0;mc=kc+3|0;fc=(mc-(b[vc-4>>1]|0)|0)>>>0>6>>>0;do{if((tc|0)==0){if(fc){Q=218}else{if(((b[vc+2>>1]|0)+3-(b[vc-4+2>>1]|0)|0)>>>0>6>>>0){Q=218}else{fd=lc}}if((Q|0)==218){Q=0;fd=lc|17}do{if((pc|0)==0){gd=qc}else{if(!((mc-(b[vc+(Wc<<2)>>1]|0)|0)>>>0>6>>>0)){if(!(((b[vc+2>>1]|0)+3-(b[vc+(Wc<<2)+2>>1]|0)|0)>>>0>6>>>0)){gd=qc;break}}gd=qc|3}}while(0);Fc=(b[vc+4>>1]|0)+3|0;if((Fc-kc|0)>>>0>6>>>0){Q=242}else{if(((b[vc+6>>1]|0)+3-(b[vc+2>>1]|0)|0)>>>0>6>>>0){Q=242}else{hd=fd}}if((Q|0)==242){Q=0;hd=fd|68}if((zc|0)==0){id=hd;jd=gd;kd=0;ld=0;break}if(!((Fc-(b[vc+(rc<<2)>>1]|0)|0)>>>0>6>>>0)){if(!(((b[vc+6>>1]|0)+3-(b[vc+(rc<<2)+2>>1]|0)|0)>>>0>6>>>0)){id=hd;jd=gd;kd=zc;ld=zc;break}}id=hd;jd=gd|12;kd=zc;ld=zc}else{if(fc){Q=225}else{if(((b[vc+2>>1]|0)+3-(b[vc-4+2>>1]|0)|0)>>>0>6>>>0){Q=225}else{md=lc}}if((Q|0)==225){Q=0;md=17<<tc|lc}if((mc-(b[vc+(Wc<<2)>>1]|0)|0)>>>0>6>>>0){Q=228}else{if(((b[vc+2>>1]|0)+3-(b[vc+(Wc<<2)+2>>1]|0)|0)>>>0>6>>>0){Q=228}else{nd=qc}}if((Q|0)==228){Q=0;nd=3<<tc|qc}Fc=(b[vc+4>>1]|0)+3|0;if((Fc-kc|0)>>>0>6>>>0){Q=237}else{if(((b[vc+6>>1]|0)+3-(b[vc+2>>1]|0)|0)>>>0>6>>>0){Q=237}else{od=md}}if((Q|0)==237){Q=0;od=md|17<<(tc|2)}if(!((Fc-(b[vc+(rc<<2)>>1]|0)|0)>>>0>6>>>0)){if(!(((b[vc+6>>1]|0)+3-(b[vc+(rc<<2)+2>>1]|0)|0)>>>0>6>>>0)){id=od;jd=nd;kd=pc;ld=zc;break}}id=od;jd=nd|3<<(tc|2);kd=pc;ld=zc}}while(0);kc=tc+8|0;if((kc|0)<16){lc=id;tc=kc;qc=jd;vc=vc+(ec<<2)|0;pc=kd;zc=ld}else{break}}zc=(c[ma>>2]|0)==0;pc=zc?jd:jd&-16;ec=(dc|0)==0;vc=ec?id&-4370:id;do{if((c[Ia>>2]|0)==0){pd=pc;qd=vc}else{qc=vc>>>1&8738|vc;tc=pc>>>4&240|pc;if(!ec){lc=dc-1+(ca(c[za>>2]|0,bc)|0)|0;rc=(c[Oa>>2]|0)+(lc<<1)|0;b[rc>>1]=e[rc>>1]|vc<<3&34952}if(!zc){pd=tc;qd=qc;break}rc=(ca(c[za>>2]|0,bc-1|0)|0)+dc|0;lc=(c[Oa>>2]|0)+(rc<<1)|0;b[lc>>1]=e[lc>>1]|pc<<12;pd=tc;qd=qc}}while(0);b[(c[Oa>>2]|0)+(cc<<1)>>1]=pd|qd|e[(c[Ma>>2]|0)+(cc<<1)>>1];a[(c[sc+1512>>2]|0)+cc|0]=c[ga>>2];if((nc|0)==-1){Q=314;break a}pc=(c[Ha>>2]|0)!=0;if((c[(c[(c[Fa>>2]|0)+1536>>2]|0)+(cc<<2)>>2]&7|0)!=0){if(pc){d_a(u,$b,nc);break}else{e_a(u,$b,nc);break}}if(pc){mrc(Ya|0,0,32)|0;pc=c[ga>>2]|0;dc=e[664872+(d[(c[bb>>2]|0)+pc|0]<<1)>>1]|0;if((f_a(ab,q,c[Ra>>2]|0,3,0,dc,dc,e[664872+(pc<<1)>>1]|0)|0)==0){qe[c[cb>>2]&1023](ab)}else{qe[c[gb>>2]&1023](ab)}pc=e[664872+(c[ga>>2]<<1)>>1]|0;dc=0;bc=nc;zc=Tb;while(1){vc=dc<<2;ec=0;rd=bc;do{qc=b[l+(ec+vc<<1)>>1]|0;tc=qc<<16>>16;do{if((rd&1|0)==0){Q=261}else{if((f_a(ac,q,c[Ra>>2]|0,c[La>>2]|0,0,pc,pc,pc)|0)==0){Q=261;break}b[ac>>1]=qc;ef[c[fb>>2]&4095](zc+(ec<<2)|0,c[eb>>2]|0,ac)}}while(0);if((Q|0)==261){Q=0;ef[c[db>>2]&4095](zc+(ec<<2)|0,c[eb>>2]|0,tc)}ec=ec+1|0;rd=rd>>1;}while((ec|0)<4);ec=dc+1|0;if((ec|0)<4){dc=ec;bc=rd;zc=zc+(c[eb>>2]<<2)|0}else{break}}zc=c[fa>>2]|0;bc=c[Qa>>2]|0;if((bc|0)==2&(zc|0)<19){sd=zc+10|0}else{sd=(bc|0)!=0&(zc|0)<26?zc+5|0:zc}if((sd|0)<0){td=0}else{td=(sd|0)>30?30:sd}c[Ra>>2]=5899264+((d[664839+td|0]|0)*380|0);ud=rd}else{zc=e[664872+(c[ga>>2]<<1)>>1]|0;bc=0;dc=nc;ac=Tb;while(1){pc=0;cc=dc;do{do{if((cc&1|0)!=0){sc=ac+(pc<<2)|0;ec=c[eb>>2]|0;vc=c[Za>>2]|0;if((f_a(vc,q,c[Ra>>2]|0,c[La>>2]|0,0,zc,zc,zc)|0)==0){ef[c[db>>2]&4095](sc,ec,b[vc>>1]|0);b[vc>>1]=0;break}else{ef[c[fb>>2]&4095](sc,ec,vc);break}}}while(0);pc=pc+1|0;cc=cc>>1;}while((pc|0)<4);pc=bc+1|0;if((pc|0)<4){bc=pc;dc=cc;ac=ac+(c[eb>>2]<<2)|0}else{ud=cc;break}}}ac=c[ga>>2]|0;dc=e[664872+(d[674976+ac|0]<<1)>>1]|0;bc=e[664872+(d[674944+ac|0]<<1)>>1]|0;ac=c[wa>>2]|0;zc=0;pc=ud;do{do{if((pc&1|0)!=0){tc=c[hb>>2]|0;vc=ac+((ca(tc,zc<<1&4)|0)+(zc<<2&4))|0;ec=c[Za>>2]|0;if((f_a(ec,q,c[Ra>>2]|0,c[Pa>>2]|0,1,dc,bc,bc)|0)==0){ef[c[db>>2]&4095](vc,tc,b[ec>>1]|0);b[ec>>1]=0;break}else{ef[c[fb>>2]&4095](vc,tc,ec);break}}}while(0);zc=zc+1|0;pc=pc>>1;}while((zc|0)<4);zc=c[xa>>2]|0;ac=0;cc=pc;while(1){do{if((cc&1|0)!=0){ec=c[hb>>2]|0;tc=zc+((ca(ec,ac<<1&4)|0)+(ac<<2&4))|0;vc=c[Za>>2]|0;if((f_a(vc,q,c[Ra>>2]|0,c[Pa>>2]|0,1,dc,bc,bc)|0)==0){ef[c[db>>2]&4095](tc,ec,b[vc>>1]|0);b[vc>>1]=0;break}else{ef[c[fb>>2]&4095](tc,ec,vc);break}}}while(0);vc=ac+1|0;if((vc|0)<4){ac=vc;cc=cc>>1}else{break}}}}while(0);Tb=(c[T>>2]|0)+1|0;c[T>>2]=Tb;do{if((Tb|0)==(c[aa>>2]|0)){c[T>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;NTa(v);orc(c[ka>>2]|0,c[ya>>2]|0,c[la>>2]<<2|0)|0;mrc(c[ya>>2]|0,-1|0,c[la>>2]<<2|0)|0;$b=c[Xa>>2]|0;if(($b|0)==0){break}_b=c[ba>>2]|0;if((_b|0)<=1){break}re[$b&1023](u,_b-2|0)}}while(0);if((c[T>>2]|0)==(c[na>>2]|0)){c[ma>>2]=0}Tb=(c[F>>2]|0)-1|0;c[F>>2]=Tb;_b=c[ba>>2]|0;if((_b|0)<(c[V>>2]|0)){Ib=_b;Kb=Tb}else{Yb=_b;break}}}else{Yb=Pb}}while(0);ypb(Gb,c[na>>2]|0,c[oa>>2]|0,(c[T>>2]|0)-1|0,Yb,112);if((c[ba>>2]|0)==(c[V>>2]|0)){Q=323;break}else{Hb=Jb}}if((Q|0)==69){KIb(f,16,2479376,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R}else if((Q|0)==81){KIb(f,16,2479376,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R}else if((Q|0)==98){KIb(f,16,2243432,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R}else if((Q|0)==100){KIb(c[X>>2]|0,16,2202048,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;Q=323}else if((Q|0)==102){KIb(c[X>>2]|0,16,2170264,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;Q=323}else if((Q|0)==105){KIb(c[X>>2]|0,16,2143096,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;Q=323}else if((Q|0)==314){ypb(Gb,c[na>>2]|0,c[oa>>2]|0,(c[T>>2]|0)-1|0,c[ba>>2]|0,14);Q=323}do{if((Q|0)==323){if((c[Fa>>2]|0)==0){break}Hb=c[Xa>>2]|0;if((Hb|0)!=0){re[Hb&1023](u,(c[V>>2]|0)-1|0)}Hb=c[s>>2]|0;F=Hb;zpb(Hb+14424|0);ETa(F);c[Hb+13732>>2]=0;do{if((c[Hb+9992>>2]|0)==3){Q=328}else{if((c[Hb+13944>>2]|0)!=0){Q=328;break}ma=Hb+9848|0;la=c[ma>>2]|0;if((la|0)==0){vd=0;break}ya=YHb(w,la|0)|0;if((ya|0)<0){x=ya;i=k;return x|0}else{HTa(F,c[ma>>2]|0,w);ITa(F,w,c[ma>>2]|0,0)|0;vd=1;break}}}while(0);do{if((Q|0)==328){Jb=Hb+9856|0;ma=YHb(w,c[Jb>>2]|0)|0;if((ma|0)<0){x=ma;i=k;return x|0}else{HTa(F,c[Jb>>2]|0,w);ITa(F,w,c[Jb>>2]|0,0)|0;vd=1;break}}}while(0);c[h>>2]=vd}}while(0);x=c[r>>2]|0;i=k;return x|0}}while(0);KIb(f,16,2596104,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;x=-1094995529;i=k;return x|0}}while(0);KIb(f,16,2479376,(R=i,i=i+1|0,i=i+7&-8,c[R>>2]=0,R)|0);i=R;x=-1094995529;i=k;return x|0}function c_a(a){a=a|0;var b=0;b=c[a+60>>2]|0;xTa(b);mJb(b+15264|0);c[b+15268>>2]=0;mJb(b+15728|0);mJb(b+15548|0);mJb(b+15640|0);mJb(b+15644|0);mJb(b+15648|0);return 0}function d_a(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;j=i;i=i+32|0;k=j|0;l=k|0;m=f+14120|0;n=f+9960|0;o=c[n>>2]|0;p=e[664872+(d[(c[f+15276>>2]|0)+o|0]<<1)>>1]|0;q=e[664872+(o<<1)>>1]|0;o=c[f+12544>>2]|0;r=f+14340|0;s=c[r>>2]|0;mrc(k|0,0,32)|0;t=f+15284|0;if((f_a(l,m,c[t>>2]|0,3,0,p,p,q)|0)==0){qe[c[f+15228>>2]&1023](l)}else{qe[c[f+15224>>2]&1023](l)}l=a[g]|0;p=c[1057760+(l<<24>>24<<2)>>2]|0;u=f+15664|0;v=f+15676|0;w=(c[u>>2]|0)!=0;x=(c[v>>2]|0)==0;do{if(x&(w^1)){y=6}else{if(!w){z=l<<24>>24==3?1:p;A=(z|0)==2?1:z;y=(A|0)==0?4:A;break}if(!x){y=p;break}A=l<<24>>24==3?2:p;z=(A|0)==1?2:A;y=(z|0)==0?5:z}}while(0);p=f+148|0;re[c[f+15440+(y<<2)>>2]&1023](o,c[p>>2]|0);y=f+15236|0;l=f+15556|0;x=f+15232|0;w=o;o=0;z=h;while(1){h=o<<2;A=0;B=z;do{C=b[k+(A+h<<1)>>1]|0;D=C<<16>>16;do{if((B&1|0)==0){E=14}else{if((f_a(s,m,c[t>>2]|0,c[l>>2]|0,0,q,q,q)|0)==0){E=14;break}b[s>>1]=C;ef[c[x>>2]&4095](w+(A<<2)|0,c[p>>2]|0,s)}}while(0);if((E|0)==14){E=0;ef[c[y>>2]&4095](w+(A<<2)|0,c[p>>2]|0,D)}A=A+1|0;B=B>>1;}while((A|0)<4);A=o+1|0;if((A|0)<4){w=w+(c[p>>2]<<2)|0;o=A;z=B}else{break}}z=a[g]|0;g=z<<24>>24==3?0:c[1057760+(z<<24>>24<<2)>>2]|0;z=(c[u>>2]|0)!=0;u=(c[v>>2]|0)==0;do{if(u&(z^1)){F=6}else{if(!z){v=(g|0)==3?1:g;o=(v|0)==2?1:v;F=(o|0)==0?4:o;break}if(!u){F=g;break}o=(g|0)==3?2:g;v=(o|0)==1?2:o;F=(v|0)==0?5:v}}while(0);g=c[n>>2]|0;n=e[664872+(d[674976+g|0]<<1)>>1]|0;u=e[664872+(d[674944+g|0]<<1)>>1]|0;g=f+15396+(F<<2)|0;F=f+152|0;z=f+15560|0;v=c[f+12548>>2]|0;re[c[g>>2]&1023](v,c[F>>2]|0);o=0;p=B;do{do{if((p&1|0)!=0){B=c[F>>2]|0;w=v+((ca(B,o<<1&4)|0)+(o<<2&4))|0;E=c[r>>2]|0;if((f_a(E,m,c[t>>2]|0,c[z>>2]|0,1,n,u,u)|0)==0){ef[c[y>>2]&4095](w,B,b[E>>1]|0);b[E>>1]=0;break}else{ef[c[x>>2]&4095](w,B,E);break}}}while(0);o=o+1|0;p=p>>1;}while((o|0)<4);o=c[f+12552>>2]|0;re[c[g>>2]&1023](o,c[F>>2]|0);g=0;f=p;while(1){do{if((f&1|0)!=0){p=c[F>>2]|0;v=o+((ca(p,g<<1&4)|0)+(g<<2&4))|0;E=c[r>>2]|0;if((f_a(E,m,c[t>>2]|0,c[z>>2]|0,1,n,u,u)|0)==0){ef[c[y>>2]&4095](v,p,b[E>>1]|0);b[E>>1]=0;break}else{ef[c[x>>2]&4095](v,p,E);break}}}while(0);E=g+1|0;if((E|0)<4){g=E;f=f>>1}else{break}}i=j;return}function e_a(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+208|0;k=j|0;l=j+8|0;m=j+16|0;n=c[f+12544>>2]|0;mrc(m|0,0,192)|0;if((c[f+15660>>2]|0)!=0){c[m>>2]=1}if((c[f+15664>>2]|0)!=0){c[m+8>>2]=1;c[m+4>>2]=1}if((c[f+15668>>2]|0)!=0){c[m+16>>2]=1;c[m+12>>2]=1}if((c[f+15672>>2]|0)!=0){c[m+20>>2]=1}if((c[f+15676>>2]|0)!=0){c[m+64>>2]=1;c[m+32>>2]=1}if((c[f+15692>>2]|0)!=0){c[m+128>>2]=1;c[m+96>>2]=1}o=f+9960|0;p=e[664872+(c[o>>2]<<1)>>1]|0;q=f+148|0;r=l;s=f+15556|0;t=f+14340|0;u=f+14120|0;v=f+15284|0;w=f+15236|0;x=f+15232|0;y=f+15272|0;z=n;n=0;A=h;h=g;g=c[q>>2]|0;while(1){B=z;C=0;D=(n<<3)+9|0;E=A;F=g;while(1){G=a[h+C|0]|0;H=c[1057776+(G<<24>>24<<2)>>2]|0;I=c[m+(D+7<<2)>>2]|0;J=c[m+(D-7<<2)>>2]|0;K=B+(4-F)|0;L=(c[m+(D-8<<2)>>2]|0)!=0;M=L^1;N=(c[m+(D-1<<2)>>2]|0)==0;do{if(N&M){O=11}else{if(!L){P=G<<24>>24==1?1:H;O=(P|0)==2?9:P;break}if(!N){O=H;break}P=G<<24>>24==2?0:H;Q=(P|0)==2?10:P;O=(Q|0)==3?12:Q}}while(0);if((I|0)==0){H=(O|0)==3?12:O;G=(H|0)==8?13:H;R=(G|0)==7?14:G}else{R=O}if((J|0)!=0|M){S=K}else{c[l>>2]=ca(d[B+(3-F)|0]|0,16843009)|0;S=r}ef[c[f+15288+(R<<2)>>2]&4095](B,S,F);c[m+(D<<2)>>2]=1;do{if((E&1|0)!=0){G=c[q>>2]|0;H=c[t>>2]|0;if((f_a(H,u,c[v>>2]|0,c[s>>2]|0,0,p,p,p)|0)==0){ef[c[w>>2]&4095](B,G,b[H>>1]|0);b[H>>1]=0;break}else{ef[c[x>>2]&4095](B,G,H);break}}}while(0);K=C+1|0;T=E>>1;U=c[q>>2]|0;if((K|0)<4){B=B+4|0;C=K;D=D+1|0;E=T;F=U}else{break}}V=c[y>>2]|0;F=n+1|0;if((F|0)<4){z=z+(U<<2)|0;n=F;A=T;h=h+V|0;g=U}else{break}}U=V<<2;g=c[o>>2]|0;o=e[664872+(d[674976+g|0]<<1)>>1]|0;A=e[664872+(d[674944+g|0]<<1)>>1]|0;g=f+15680|0;n=f+15684|0;z=f+15696|0;q=f+15700|0;p=f+152|0;s=k;m=f+15560|0;S=0;R=T;while(1){T=S+1|0;r=c[f+12544+(T<<2)>>2]|0;c[g>>2]=0;c[n>>2]=0;c[z>>2]=0;c[q>>2]=0;l=r;r=0;O=R;while(1){F=0;E=O;D=f+15656+((r<<2)+6<<2)|0;while(1){C=a[h+(V+(((ca(c[y>>2]|0,r)|0)+F<<1)-U))|0]|0;B=c[1057776+(C<<24>>24<<2)>>2]|0;K=F<<2;M=l+K|0;J=c[p>>2]|0;I=c[D-12>>2]|0;H=l+(K+4-J)|0;G=(c[D-16>>2]|0)!=0;N=G^1;L=(c[D-4>>2]|0)==0;do{if(L&N){W=11}else{if(!G){Q=C<<24>>24==1?1:B;W=(Q|0)==2?9:Q;break}if(!L){W=B;break}Q=C<<24>>24==2?0:B;P=(Q|0)==2?10:Q;W=(P|0)==3?12:P}}while(0);if((F|r|0)==0){X=W}else{B=(W|0)==3?12:W;C=(B|0)==8?13:B;X=(C|0)==7?14:C}if((I|0)!=0|N){Y=H}else{c[k>>2]=ca(d[l+((K|3)-J)|0]|0,16843009)|0;Y=s}ef[c[f+15288+(X<<2)>>2]&4095](M,Y,J);c[D>>2]=1;do{if((E&1|0)!=0){C=c[p>>2]|0;B=c[t>>2]|0;if((f_a(B,u,c[v>>2]|0,c[m>>2]|0,1,o,A,A)|0)==0){ef[c[w>>2]&4095](M,C,b[B>>1]|0);b[B>>1]=0;break}else{ef[c[x>>2]&4095](M,C,B);break}}}while(0);M=F+1|0;Z=E>>1;if((M|0)>=2){break}F=M;E=Z;D=D+4|0}D=r+1|0;if((D|0)<2){l=l+(c[p>>2]<<2)|0;r=D;O=Z}else{break}}if((T|0)<2){S=T;R=Z}else{break}}i=j;return}function f_a(e,f,g,h,i,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;m=c[g+200+(h*20|0)+4>>2]|0;h=f+8|0;n=c[h>>2]|0;o=f+16|0;p=c[o>>2]|0;q=f|0;r=c[q>>2]|0;s=r+(n>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(n&7)>>>23;s=b[m+(t<<2)>>1]|0;u=b[m+(t<<2)+2>>1]|0;t=u<<16>>16;if(u<<16>>16<0){u=n+9|0;v=p>>>0>u>>>0?u:p;u=r+(v>>>3)|0;r=((je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(v&7)>>>((t+32|0)>>>0))+s|0;w=b[m+(r<<2)+2>>1]|0;x=b[m+(r<<2)>>1]|0;y=v}else{w=t;x=s;y=n}n=w+y|0;c[h>>2]=p>>>0>n>>>0?n:p;p=x&7;n=a[827416+(x>>3)|0]|0;y=g+360|0;w=n&255;g_a(e,w>>>6,3,f,y,j);do{if((n&63)==0){if((p|0)==0){z=0}else{A=0;break}return z|0}else{g_a(e+2|0,w>>>4&3,2,f,y,k);g_a(e+8|0,w>>>2&3,2,f,y,k);g_a(e+10|0,w&3,2,f,y,l);A=1}}while(0);if((x&4|0)!=0){w=c[g+280+(i*20|0)+4>>2]|0;k=c[h>>2]|0;n=c[o>>2]|0;j=c[q>>2]|0;s=j+(k>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(k&7)>>>23;s=b[w+(t<<2)>>1]|0;v=b[w+(t<<2)+2>>1]|0;t=v<<16>>16;if(v<<16>>16<0){v=k+9|0;r=n>>>0>v>>>0?v:n;v=j+(r>>>3)|0;j=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(r&7)>>>((t+32|0)>>>0))+s|0;B=b[w+(j<<2)+2>>1]|0;C=b[w+(j<<2)>>1]|0;D=r}else{B=t;C=s;D=k}k=B+D|0;c[h>>2]=n>>>0>k>>>0?k:n;n=d[827416+C|0]|0;g_a(e+4|0,n>>>6,3,f,y,l);g_a(e+6|0,n>>>4&3,2,f,y,l);g_a(e+12|0,n>>>2&3,2,f,y,l);g_a(e+14|0,n&3,2,f,y,l)}if((x&2|0)!=0){n=c[g+280+(i*20|0)+4>>2]|0;C=c[h>>2]|0;k=c[o>>2]|0;D=c[q>>2]|0;B=D+(C>>>3)|0;s=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>23;B=b[n+(s<<2)>>1]|0;t=b[n+(s<<2)+2>>1]|0;s=t<<16>>16;if(t<<16>>16<0){t=C+9|0;r=k>>>0>t>>>0?t:k;t=D+(r>>>3)|0;D=((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(r&7)>>>((s+32|0)>>>0))+B|0;E=b[n+(D<<2)+2>>1]|0;F=b[n+(D<<2)>>1]|0;G=r}else{E=s;F=B;G=C}C=E+G|0;c[h>>2]=k>>>0>C>>>0?C:k;k=d[827416+F|0]|0;g_a(e+16|0,k>>>6,3,f,y,l);g_a(e+24|0,k>>>4&3,2,f,y,l);g_a(e+18|0,k>>>2&3,2,f,y,l);g_a(e+26|0,k&3,2,f,y,l)}if((x&1|0)!=0){x=c[g+320+(i*20|0)+4>>2]|0;i=c[h>>2]|0;g=c[o>>2]|0;o=c[q>>2]|0;q=o+(i>>>3)|0;k=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(i&7)>>>23;q=b[x+(k<<2)>>1]|0;F=b[x+(k<<2)+2>>1]|0;k=F<<16>>16;if(F<<16>>16<0){F=i+9|0;C=g>>>0>F>>>0?F:g;F=o+(C>>>3)|0;o=((je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(C&7)>>>((k+32|0)>>>0))+q|0;H=b[x+(o<<2)+2>>1]|0;I=b[x+(o<<2)>>1]|0;J=C}else{H=k;I=q;J=i}i=H+J|0;c[h>>2]=g>>>0>i>>>0?i:g;g=d[827416+I|0]|0;g_a(e+20|0,g>>>6,3,f,y,l);g_a(e+22|0,g>>>4&3,2,f,y,l);g_a(e+28|0,g>>>2&3,2,f,y,l);g_a(e+30|0,g&3,2,f,y,l)}z=A|p;return z|0}function g_a(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((e|0)==0){return}if((e|0)==(f|0)){f=c[h+4>>2]|0;h=g+8|0;j=c[h>>2]|0;k=c[g+16>>2]|0;l=c[g>>2]|0;m=l+(j>>>3)|0;n=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(j&7)>>>23;m=b[f+(n<<2)>>1]|0;o=b[f+(n<<2)+2>>1]|0;n=o<<16>>16;if(o<<16>>16<0){o=j+9|0;p=k>>>0>o>>>0?o:k;o=l+(p>>>3)|0;q=((je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(p&7)>>>((n+32|0)>>>0))+m|0;r=b[f+(q<<2)+2>>1]|0;s=b[f+(q<<2)>>1]|0;t=p}else{r=n;s=m;t=j}j=r+t|0;t=k>>>0>j>>>0?j:k;c[h>>2]=t;if((s|0)>23){j=s-23|0;r=l+(t>>>3)|0;m=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(t&7)>>>((55-s|0)>>>0);r=t+j|0;n=k>>>0>r>>>0?r:k;c[h>>2]=n;u=(m|1<<j)+22|0;v=n}else{u=s;v=t}w=u+e|0;x=v;y=l;z=k}else{w=e;x=c[g+8>>2]|0;y=c[g>>2]|0;z=c[g+16>>2]|0}e=d[y+(x>>>3)|0]|0;c[g+8>>2]=((x|0)<(z|0))+x;b[a>>1]=((ca((e&128>>>((x&7)>>>0)|0)==0?w:-w|0,i)|0)+8|0)>>>4;return}function h_a(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=c[e+(f*20|0)+4>>2]|0;h=a+8|0;i=c[h>>2]|0;j=c[a+16>>2]|0;k=c[a>>2]|0;a=k+(i>>>3)|0;l=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(i&7)>>>23;a=b[g+(l<<2)>>1]|0;m=b[g+(l<<2)+2>>1]|0;l=m<<16>>16;if(m<<16>>16<0){m=i+9|0;n=j>>>0>m>>>0?m:j;m=k+(n>>>3)|0;o=((je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(n&7)>>>((l+32|0)>>>0))+a|0;p=b[g+(o<<2)+2>>1]|0;q=b[g+(o<<2)>>1]|0;r=n}else{p=l;q=a;r=i}i=p+r|0;r=j>>>0>i>>>0?i:j;c[h>>2]=r;i=d[674928+(q&15)|0]|0;p=e+40+(f*80|0)+(i*20|0)+4|0;a=e+40+(f*80|0)+(i*20|0)|0;if((q&8|0)==0){s=0;t=r}else{i=c[p>>2]|0;f=c[a>>2]|0;e=k+(r>>>3)|0;l=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(r&7)>>>((32-f|0)>>>0);f=b[i+(l<<2)>>1]|0;e=(b[i+(l<<2)+2>>1]|0)+r|0;r=j>>>0>e>>>0?e:j;c[h>>2]=r;s=f;t=r}if((q&4|0)==0){u=s;v=t}else{r=c[p>>2]|0;f=c[a>>2]|0;e=k+(t>>>3)|0;l=(je(d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0)|0)<<(t&7)>>>((32-f|0)>>>0);f=b[r+(l<<2)>>1]|0;e=(b[r+(l<<2)+2>>1]|0)+t|0;t=j>>>0>e>>>0?e:j;c[h>>2]=t;u=f<<2|s;v=t}if((q&2|0)==0){w=u;x=v}else{t=c[p>>2]|0;s=c[a>>2]|0;f=k+(v>>>3)|0;e=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(v&7)>>>((32-s|0)>>>0);s=b[t+(e<<2)>>1]|0;f=(b[t+(e<<2)+2>>1]|0)+v|0;v=j>>>0>f>>>0?f:j;c[h>>2]=v;w=s<<8|u;x=v}if((q&1|0)==0){y=w;z=x}else{v=c[p>>2]|0;p=c[a>>2]|0;a=k+(x>>>3)|0;u=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(x&7)>>>((32-p|0)>>>0);p=b[v+(u<<2)>>1]|0;a=(b[v+(u<<2)+2>>1]|0)+x|0;x=j>>>0>a>>>0?a:j;c[h>>2]=x;y=p<<10|w;z=x}x=d[827416+(q>>4)|0]|0;q=x>>>6;if((q|0)==1){w=d[k+(z>>>3)|0]<<(z&7)>>>7;p=((z|0)<(j|0))+z|0;c[h>>2]=p;A=c[674912+((w&1)<<2)>>2]|y;B=p}else if((q|0)==2){A=y|1114112;B=z}else{A=y;B=z}z=x>>>4&3;if((z|0)==2){C=A|2228224;D=B}else if((z|0)==1){z=d[k+(B>>>3)|0]<<(B&7)>>>7;y=((B|0)<(j|0))+B|0;c[h>>2]=y;C=c[674912+((z&1)<<2)>>2]<<1|A;D=y}else{C=A;D=B}B=x>>>2&3;if((B|0)==2){E=C|4456448;F=D}else if((B|0)==1){B=d[k+(D>>>3)|0]<<(D&7)>>>7;A=((D|0)<(j|0))+D|0;c[h>>2]=A;E=c[674912+((B&1)<<2)>>2]<<2|C;F=A}else{E=C;F=D}D=x&3;if((D|0)==1){x=d[k+(F>>>3)|0]<<(F&7)>>>7;c[h>>2]=((F|0)<(j|0))+F;G=c[674912+((x&1)<<2)>>2]<<3|E;return G|0}else if((D|0)==2){G=E|8912896;return G|0}else{G=E;return G|0}return 0}function i_a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+15600|0;e=c[d>>2]|0;if((e|0)!=0|(b|0)==10){f=0}else{f=(c[a+15624>>2]|0)!=8192}g=a+14672|0;h=a+15184|0;l_a(a,b,0,0,0,2,2,0,e,f&1,g,h);e=c[d>>2]|0;if(f){l_a(a,b,0,0,0,2,2,1,e,1,g,h);h=a+15620|0;g=a+15624|0;f=a+15628|0;_e[c[a+15208+(c[h>>2]<<3)>>2]&511](c[a+12544>>2]|0,c[a+15704>>2]|0,c[a+15708>>2]|0,c[g>>2]|0,c[f>>2]|0,c[a+148>>2]|0);d=a+152|0;_e[c[a+15208+(c[h>>2]<<3)+4>>2]&511](c[a+12548>>2]|0,c[a+15712>>2]|0,c[a+15720>>2]|0,c[g>>2]|0,c[f>>2]|0,c[d>>2]|0);_e[c[a+15208+(c[h>>2]<<3)+4>>2]&511](c[a+12552>>2]|0,c[a+15716>>2]|0,c[a+15724>>2]|0,c[g>>2]|0,c[f>>2]|0,c[d>>2]|0);return}else{l_a(a,b,0,0,0,2,2,1,e,0,a+14928|0,a+15196|0);return}}function j_a(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=c[a+128>>2]|0;i=d[1998176+f|0]|0;j=d[735248+e|0]|0;k=(c[a+12476>>2]<<1|f&1)+(ca((c[a+12480>>2]<<1)+(f>>1)|0,h)|0)|0;l=(f|0)==3?-1:j;f=(c[a+15656+(i-1<<2)>>2]|0)==0;if(f){m=0;n=0}else{o=k-1|0;p=c[(c[a+9856>>2]|0)+1524>>2]|0;m=b[p+(o<<2)>>1]|0;n=b[p+(o<<2)+2>>1]|0}o=i-4|0;i=(c[a+15656+(o<<2)>>2]|0)==0;if(i){q=m;r=n}else{p=k-h|0;s=c[(c[a+9856>>2]|0)+1524>>2]|0;q=b[s+(p<<2)>>1]|0;r=b[s+(p<<2)+2>>1]|0}do{if((c[a+15656+(o+l<<2)>>2]|0)==0){if(i){t=m;u=n;break}if(f){if((c[a+15600>>2]|0)==0){t=m;u=n;break}}p=k-h-1|0;s=c[(c[a+9856>>2]|0)+1524>>2]|0;t=b[s+(p<<2)>>1]|0;u=b[s+(p<<2)+2>>1]|0}else{p=k-h+l|0;s=c[(c[a+9856>>2]|0)+1524>>2]|0;t=b[s+(p<<2)>>1]|0;u=b[s+(p<<2)+2>>1]|0}}while(0);do{if((m|0)>(q|0)){if((t|0)<=(q|0)){v=q;break}v=(t|0)>(m|0)?m:t}else{if((q|0)<=(t|0)){v=q;break}v=(t|0)>(m|0)?t:m}}while(0);do{if((n|0)>(r|0)){if((u|0)<=(r|0)){w=r;break}w=(u|0)>(n|0)?n:u}else{if((r|0)<=(u|0)){w=r;break}w=(u|0)>(n|0)?u:n}}while(0);n=d[735264+e|0]|0;e=(c[a+15568+(g<<3)>>2]|0)+v&65535;v=a+9856|0;u=(c[a+15568+(g<<3)+4>>2]|0)+w&65535;w=0;do{g=ca(h,w)|0;a=c[(c[v>>2]|0)+1524>>2]|0;r=0;do{m=g+(r+k)|0;b[a+(m<<2)>>1]=e;b[a+(m<<2)+2>>1]=u;r=r+1|0;}while((r|0)<(j|0));w=w+1|0;}while((w|0)<(n|0));return}function k_a(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=c[a+12476>>2]|0;g=c[a+12480>>2]|0;h=(ca(c[a+124>>2]|0,g)|0)+f|0;i=c[a+128>>2]|0;j=(ca(g<<1,i)|0)+(f<<1)|0;g=c[a+9856>>2]|0;k=(e|0)!=0;l=c[(c[g+1536>>2]|0)+(h<<2)>>2]&(k?49152:12288);if((l&c[a+15676>>2]|0)==0){m=0;n=0;o=0}else{h=j-1|0;p=c[g+1524+(e<<2)>>2]|0;m=1;n=b[p+(h<<2)>>1]|0;o=b[p+(h<<2)+2>>1]|0}h=c[a+15664>>2]|0;if((l&h|0)==0){q=0;r=0;s=0}else{p=j-i|0;t=c[g+1524+(e<<2)>>2]|0;q=1;r=b[t+(p<<2)>>1]|0;s=b[t+(p<<2)+2>>1]|0}do{if((h|0)==0){u=8}else{if((l&c[a+15672>>2]|0)==0){u=8;break}p=j-i+2|0;t=c[g+1524+(e<<2)>>2]|0;v=1;w=b[t+(p<<2)>>1]|0;x=b[t+(p<<2)+2>>1]|0}}while(0);do{if((u|0)==8){if((f+1|0)!=(c[a+116>>2]|0)){v=0;w=0;x=0;break}if((l&c[a+15660>>2]|0)==0){v=0;w=0;x=0;break}h=j-i-1|0;p=c[g+1524+(e<<2)>>2]|0;v=1;w=b[p+(h<<2)>>1]|0;x=b[p+(h<<2)+2>>1]|0}}while(0);l=q+m+v|0;do{if((l|0)==3){do{if((n|0)>(r|0)){if((w|0)<=(r|0)){y=r;break}y=(w|0)>(n|0)?n:w}else{if((r|0)<=(w|0)){y=r;break}y=(w|0)>(n|0)?w:n}}while(0);if((o|0)>(s|0)){if((x|0)<=(s|0)){z=s;A=y;break}z=(x|0)>(o|0)?o:x;A=y;break}else{if((s|0)<=(x|0)){z=s;A=y;break}z=(x|0)>(o|0)?x:o;A=y;break}}else{v=r+n+w|0;m=s+o+x|0;if((l|0)!=2){z=m;A=v;break}z=(m|0)/2|0;A=(v|0)/2|0}}while(0);l=(c[a+15568+(e<<3)>>2]|0)+A&65535;A=c[g+1524+(e<<2)>>2]|0;x=(c[a+15568+(e<<3)+4>>2]|0)+z&65535;b[A+(j<<2)>>1]=l;b[A+(j<<2)+2>>1]=x;z=j|1;b[A+(z<<2)>>1]=l;b[A+(z<<2)+2>>1]=x;e=i+j|0;b[A+(e<<2)>>1]=l;b[A+(e<<2)+2>>1]=x;e=i+z|0;b[A+(e<<2)>>1]=l;b[A+(e<<2)+2>>1]=x;if(!((d-4|0)>>>0<2>>>0)){return}d=c[g+1524+((k&1^1)<<2)>>2]|0;k=d+(j<<2)|0;g=k;x=i<<2;c[k>>2]=0;c[g+x>>2]=0;c[d+(j<<2)+4>>2]=0;c[g+(x+4)>>2]=0;return}function l_a(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;o=c[a+12476>>2]|0;p=c[a+12480>>2]|0;q=((ca(c[a+128>>2]|0,p)|0)+o<<1)+g|0;g=c[(c[a+9856>>2]|0)+1524+(j<<2)>>2]|0;r=b[g+(q<<2)>>1]|0;if((k|0)==0){k=b[g+(q<<2)+2>>1]|0;s=(r|0)/2|0;t=(k|0)/2|0;u=s<<1&6;v=t<<1;w=(u&v|0)==6;x=r>>2;y=k>>2;z=s>>2;A=t>>2;B=w?4:v&6;C=w?4:u;D=k&3;E=r&3}else{k=r+50331648|0;u=b[g+(q<<2)+2>>1]|0;q=u+50331648|0;g=((r|0)/2|0)+50331648|0;r=((u|0)/2|0)+50331648|0;x=((k|0)/3|0)-16777216|0;y=((q|0)/3|0)-16777216|0;z=((g|0)/3|0)-16777216|0;A=((r|0)/3|0)-16777216|0;B=c[1706416+(((r|0)%3|0)<<2)>>2]|0;C=c[1706416+(((g|0)%3|0)<<2)>>2]|0;D=(q|0)%3|0;E=(k|0)%3|0}k=(D<<2)+E|0;q=c[((j|0)!=0?a+9852|0:a+9848|0)>>2]|0;g=c[q>>2]|0;r=x+e+(o<<4)|0;x=y+f+(p<<4)|0;y=e>>1;u=z+y+(o<<3)|0;o=f>>1;z=A+o+(p<<3)|0;p=a+148|0;A=c[p>>2]|0;w=(ca(x,A)|0)+r|0;v=g+w|0;t=a+152|0;s=(ca(z,c[t>>2]|0)|0)+u|0;F=(c[q+4>>2]|0)+s|0;G=(c[q+8>>2]|0)+s|0;s=a+136|0;q=c[s>>2]|0;H=h<<3;I=c[a+140>>2]|0;J=i<<3;do{if((q-H|0)<6){K=8}else{if((I-J|0)<6){K=8;break}L=((E|0)!=0)<<1;if((r-L|0)>>>0>(-4-H-L+q|0)>>>0){K=8;break}L=((D|0)!=0)<<1;if((x-L|0)>>>0>(-4-J-L+I|0)>>>0){K=8}else{M=v;N=F;O=G}}}while(0);if((K|0)==8){K=a+9944|0;v=c[K>>2]|0;D=A*22|0;E=v+D|0;L=a+11540|0;P=a+140|0;Ve[c[L>>2]&127](v,g+(w-2-(A<<1))|0,A,A,H|6,J|6,r-2|0,x-2|0,q,I);I=(c[K>>2]|0)+((c[p>>2]<<1)+2)|0;K=c[t>>2]|0;q=h<<2|1;x=i<<2|1;Ve[c[L>>2]&127](E,F,K,K,q,x,u,z,c[s>>2]>>1,c[P>>2]>>1);K=v+(D+16)|0;D=c[t>>2]|0;Ve[c[L>>2]&127](K,G,D,D,q,x,u,z,c[s>>2]>>1,c[P>>2]>>1);M=I;N=E;O=K}if((l|0)==0){l=c[p>>2]|0;K=(c[a+12544>>2]|0)+((ca(l,f)|0)+e)|0;E=(ca(c[t>>2]|0,o)|0)+y|0;Q=K;R=(c[a+12548>>2]|0)+E|0;S=(c[a+12552>>2]|0)+E|0;T=l}else{l=c[p>>2]|0;E=(c[a+15704+(j<<2)>>2]|0)+((ca(l,f)|0)+e)|0;e=j<<1;j=(ca(c[t>>2]|0,o)|0)+y|0;Q=E;R=(c[a+15712+(e<<2)>>2]|0)+j|0;S=(c[a+15712+((e|1)<<2)>>2]|0)+j|0;T=l}if((d|0)==8){ef[c[m+64+(k<<2)>>2]&4095](Q,M,T);U=1;V=M+8|0;W=Q+8|0;X=c[p>>2]|0;Y=m+(U<<6)+(k<<2)|0;Z=c[Y>>2]|0;ef[Z&4095](W,V,X);_=2-h|0;$=n+(_<<2)|0;aa=c[$>>2]|0;ba=c[t>>2]|0;da=i<<2;_e[aa&511](R,N,ba,da,C,B);ea=c[$>>2]|0;fa=c[t>>2]|0;_e[ea&511](S,O,fa,da,C,B);return}else if((d|0)==3){U=1;V=M;W=Q;X=T;Y=m+(U<<6)+(k<<2)|0;Z=c[Y>>2]|0;ef[Z&4095](W,V,X);_=2-h|0;$=n+(_<<2)|0;aa=c[$>>2]|0;ba=c[t>>2]|0;da=i<<2;_e[aa&511](R,N,ba,da,C,B);ea=c[$>>2]|0;fa=c[t>>2]|0;_e[ea&511](S,O,fa,da,C,B);return}else if((d|0)==9){ef[c[m+64+(k<<2)>>2]&4095](Q,M,T);l=c[p>>2]|0;p=l<<3;ga=M+p|0;ha=Q+p|0;ia=l}else{ga=M;ha=Q;ia=T}U=(d|0)==9|0;V=ga;W=ha;X=ia;Y=m+(U<<6)+(k<<2)|0;Z=c[Y>>2]|0;ef[Z&4095](W,V,X);_=2-h|0;$=n+(_<<2)|0;aa=c[$>>2]|0;ba=c[t>>2]|0;da=i<<2;_e[aa&511](R,N,ba,da,C,B);ea=c[$>>2]|0;fa=c[t>>2]|0;_e[ea&511](S,O,fa,da,C,B);return}function m_a(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=i;i=i+6624|0;l=k|0;m=k+72|0;n=k+144|0;o=k+2736|0;p=k+5328|0;mrc(l|0,0,68)|0;if((f|0)>0){if((h|0)==0){q=0;r=0;s=0;while(1){t=a[e+q|0]|0;if(t<<24>>24==0){u=s;v=r}else{a[p+s|0]=t;b[o+(s<<1)>>1]=q;w=t&255;t=l+(w<<2)|0;c[t>>2]=(c[t>>2]|0)+1;u=s+1|0;v=(r|0)>(w|0)?r:w}w=q+1|0;if((w|0)<(f|0)){q=w;r=v;s=u}else{x=v;y=u;break}}}else{u=0;v=0;s=0;while(1){r=a[e+u|0]|0;if(r<<24>>24==0){z=s;A=v}else{a[p+s|0]=r;b[o+(s<<1)>>1]=d[h+u|0]|0;q=r&255;r=l+(q<<2)|0;c[r>>2]=(c[r>>2]|0)+1;z=s+1|0;A=(v|0)>(q|0)?v:q}q=u+1|0;if((q|0)<(f|0)){u=q;v=A;s=z}else{x=A;y=z;break}}}}else{x=0;y=0}c[m>>2]=0;z=0;A=0;do{A=(c[l+(z<<2)>>2]|0)+A<<1;z=z+1|0;c[m+(z<<2)>>2]=A;}while((z|0)<16);if((y|0)>0){z=0;do{A=m+((d[p+z|0]|0)<<2)|0;l=c[A>>2]|0;c[A>>2]=l+1;b[n+(z<<1)>>1]=l;z=z+1|0;}while((z|0)<(y|0))}z=c[316912+(j<<2)>>2]|0;c[g+4>>2]=4284808+(z<<2);c[g+12>>2]=(c[316912+(j+1<<2)>>2]|0)-z;$2(g,(x|0)>9?9:x,y,p|0,1,1,n,2,2,o,2,2,4)|0;i=k;return}function n_a(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[a+60>>2]|0;c[d+15600>>2]=0;e=$Za(a)|0;if((e|0)<0){f=e;return f|0}if((c[2552112]|0)==0){c[2552113]=5131200;c[2552115]=256;$2(10208448,8,16,616592,1,1,616576,1,1,0,0,0,4)|0;e=0;while(1){if(((e|0)%10|0|0)!=9){c[10208876+(e*20|0)>>2]=5179480+(e<<7<<2);c[10208884+(e*20|0)>>2]=128;$2(10208872+(e*20|0)|0,7,9,2029032+(e*9|0)|0,1,1,2028216+(e*9|0)|0,1,1,0,0,0,4)|0}a=e+1|0;if((a|0)<90){e=a}else{g=0;h=0;break}}while(1){e=h<<16>>16;c[10208476+(g*20|0)>>2]=5132224+(e<<2);a=g+1|0;i=b[830448+(a<<1)>>1]|0;c[10208484+(g*20|0)>>2]=(i<<16>>16)-e;$2(10208472+(g*20|0)|0,9,81,2026592+(g*81|0)|0,1,1,2023352+(g*162|0)|0,2,2,0,0,0,4)|0;if((a|0)<20){g=a;h=i}else{j=0;break}}while(1){c[5430124+(j*20|0)>>2]=5126080+(j<<7<<2);c[5430132+(j*20|0)>>2]=128;$2(5430120+(j*20|0)|0,7,8,697384+(j<<3)|0,1,1,697328+(j<<3)|0,1,1,697320,1,1,4)|0;h=j+1|0;if((h|0)<7){j=h}else{k=0;break}}do{c[9881988+(k*20|0)>>2]=5129664+(k<<6<<2);c[9881996+(k*20|0)>>2]=64;$2(9881984+(k*20|0)|0,6,7,1899776+(k<<3)|0,1,1,1899728+(k*7|0)|0,1,1,1899720,1,1,4)|0;k=k+1|0;}while((k|0)<6)}c[d+15732>>2]=250;c[d+15740>>2]=200;c[d+15736>>2]=682;c[d+15744>>2]=644;c[d+15276>>2]=616256;c[d+15280>>2]=616288;f=0;return f|0}function o_a(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c[a+8>>2]|0;g=c[a+12>>2]|0;mrc(e|0,0,32)|0;h=b+8|0;i=c[h>>2]|0;j=b|0;k=c[j>>2]|0;l=d[k+(i>>>3)|0]|0;m=b+16|0;n=c[m>>2]|0;o=((i|0)<(n|0))+i|0;c[h>>2]=o;if((l&128>>>((i&7)>>>0)|0)!=0){p=-1;return p|0}i=k+(o>>>3)|0;k=(je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(o&7)>>>30;i=o+2|0;c[h>>2]=n>>>0>i>>>0?i:n;n=e|0;c[n>>2]=(k|0)==1?0:k;k=c[h>>2]|0;i=c[m>>2]|0;o=c[j>>2]|0;l=o+(k>>>3)|0;q=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(k&7)>>>27;l=k+5|0;c[h>>2]=i>>>0>l>>>0?l:i;c[e+4>>2]=q;q=c[h>>2]|0;i=c[m>>2]|0;l=o+(q>>>3)|0;k=je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0;l=q+2|0;r=i>>>0>l>>>0?l:i;c[h>>2]=r;if((k&-1073741824>>>((q&7)>>>0)|0)!=0){p=-1;return p|0}q=o+(r>>>3)|0;k=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(r&7)>>>30;q=r+2|0;c[h>>2]=i>>>0>q>>>0?q:i;c[e+8>>2]=k;k=c[m>>2]|0;i=(c[h>>2]|0)+1|0;q=k>>>0>i>>>0?i:k;c[h>>2]=q;i=o+(q>>>3)|0;r=(je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(q&7)>>>19;i=q+13|0;c[h>>2]=k>>>0>i>>>0?i:k;c[e+28>>2]=r;r=c[h>>2]|0;if((c[n>>2]|0)==0){s=r;t=c[m>>2]|0;u=6}else{n=d[o+(r>>>3)|0]|0;k=c[m>>2]|0;i=((r|0)<(k|0))+r|0;c[h>>2]=i;if((n&128>>>((r&7)>>>0)|0)==0){s=i;t=k;u=6}else{v=g;w=f}}do{if((u|0)==6){f=o+(s>>>3)|0;g=(je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0)<<(s&7)>>>29;f=s+3|0;k=t>>>0>f>>>0?f:t;c[h>>2]=k;f=c[616176+(g<<2)>>2]|0;if((g|0)==7){g=0;i=k;while(1){r=o+(i>>>3)|0;n=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(i&7)>>>24;r=i+8|0;q=t>>>0>r>>>0?r:t;c[h>>2]=q;r=(n<<2)+g|0;if((n|0)==255){g=r;i=q}else{x=r;y=q;break}}}else{x=f;y=k}i=o+(y>>>3)|0;g=(je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(y&7)>>>29;i=y+3|0;q=t>>>0>i>>>0?i:t;c[h>>2]=q;i=c[616208+(g<<2)>>2]|0;if((g-6|0)>>>0<2>>>0){g=(d[o+(q>>>3)|0]|0)<<(q&7)>>>7;r=((q|0)<(t|0))+q|0;c[h>>2]=r;z=c[616208+((g&1)-i<<2)>>2]|0;A=r}else{z=i;A=q}if((z|0)==0){B=0;C=A}else{v=z;w=x;break}while(1){q=o+(C>>>3)|0;i=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(C&7)>>>24;q=C+8|0;r=t>>>0>q>>>0?q:t;c[h>>2]=r;q=(i<<2)+B|0;if((i|0)==255){B=q;C=r}else{v=q;w=x;break}}}}while(0);if((tIb(w,v,0,c[a+4>>2]|0)|0)<0){p=-1;return p|0}c[e+20>>2]=w;c[e+24>>2]=v;a=_Za(b,ca(v+15>>4,w+15>>4)|0)|0;w=c[h>>2]|0;v=c[m>>2]|0;m=(c[j>>2]|0)+(w>>>3)|0;j=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(w&7)>>>((32-a|0)>>>0);m=w+a|0;c[h>>2]=v>>>0>m>>>0?m:v;c[e+12>>2]=j;p=0;return p|0}function p_a(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;i=f+14084|0;j=g+8|0;k=g+16|0;l=g|0;g=f+15272|0;f=0;m=h;while(1){do{if((f|0)==0){if((c[i>>2]|0)==0){n=0;o=m;p=5;break}h=c[2552113]|0;q=c[j>>2]|0;r=c[k>>2]|0;s=(c[l>>2]|0)+(q>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(q&7)>>>24;s=b[h+(t<<2)>>1]|0;u=s<<16>>16;v=(b[h+(t<<2)+2>>1]|0)+q|0;c[j>>2]=r>>>0>v>>>0?v:r;a[m]=u>>>2&2;a[m+1|0]=u>>>1&2;a[m+2|0]=s&2;a[m+3|0]=u<<1&2}else{n=0;o=m;p=5}}while(0);a:do{if((p|0)==5){while(1){p=0;u=c[g>>2]|0;s=a[o+(-u|0)|0]|0;r=s<<24>>24;v=a[o-1|0]|0;q=v<<24>>24;t=(r<<4)+(a[o+(1-u)|0]|0)+(q<<8)|0;u=0;while(1){if((u|0)>=20){p=12;break}if((t|0)==(e[616608+(u<<1)>>1]|0)){p=8;break}else{u=u+1|0}}do{if((p|0)==8){p=0;if((n|0)>2){p=12;break}t=c[10208476+(u*20|0)>>2]|0;h=c[j>>2]|0;w=c[k>>2]|0;x=c[l>>2]|0;y=x+(h>>>3)|0;z=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(h&7)>>>23;y=b[t+(z<<2)>>1]|0;A=b[t+(z<<2)+2>>1]|0;z=A<<16>>16;if(A<<16>>16<0){A=h+9|0;B=w>>>0>A>>>0?A:w;A=x+(B>>>3)|0;x=((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(B&7)>>>((z+32|0)>>>0))+y|0;C=b[t+(x<<2)+2>>1]|0;D=b[t+(x<<2)>>1]|0;E=B}else{C=z;D=y;E=h}h=C+E|0;c[j>>2]=w>>>0>h>>>0?h:w;w=o+1|0;a[o]=(D|0)/9|0;a[w]=(D|0)%9|0;F=w;G=n+1|0}}while(0);if((p|0)==12){p=0;do{if(s<<24>>24==-1|v<<24>>24==-1){if((q|0)==0|(q|0)==2){u=c[j>>2]|0;w=d[(c[l>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[j>>2]=((u|0)<(c[k>>2]|0))+u;H=(w<<1&2^2)&255;break}else if((q|0)!=(-1|0)){H=0;break}if(!(s<<24>>24<2)){H=0;break}w=c[j>>2]|0;u=d[(c[l>>2]|0)+(w>>>3)|0]<<(w&7)>>>7;c[j>>2]=((w|0)<(c[k>>2]|0))+w;H=(u&1^1)&255}else{u=c[10208876+(((q*10|0)+r|0)*20|0)>>2]|0;w=c[j>>2]|0;h=c[k>>2]|0;y=(c[l>>2]|0)+(w>>>3)|0;z=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>25;y=b[u+(z<<2)>>1]|0;B=(b[u+(z<<2)+2>>1]|0)+w|0;c[j>>2]=h>>>0>B>>>0?B:h;H=y&255}}while(0);a[o]=H;F=o;G=n}r=G+1|0;if((r|0)>=4){break a}n=r;o=F+1|0;p=5}}}while(0);r=f+1|0;if((r|0)<4){f=r;m=m+(c[g>>2]|0)|0}else{break}}return 0}function q_a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;f=i;i=i+48|0;g=f|0;h=e+14120|0;j=c[e+124>>2]|0;k=(ca(j,c[e+12480>>2]|0)|0)+(c[e+12476>>2]|0)|0;l=e+12484|0;m=c[l>>2]|0;do{if((m|0)==0){n=e+14128|0;o=c[n>>2]|0;p=c[e+14136>>2]|0;q=c[h>>2]|0;r=q+(o>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(o&7);if((s&-1434451968|0)==0){r=1;t=o;u=s;while(1){v=u>>>24;w=a[1369728+v|0]|0;x=w&255;y=((w&255)>>>0>8>>>0?8:x)+t|0;z=p>>>0>y>>>0;A=z?y:p;if(!(w<<24>>24==9)){B=5;break}w=d[1369984+v|0]|r<<4;if(!(w>>>0<134217728>>>0)){C=w;break}y=q+(A>>>3)|0;D=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(A&7);if(z){r=w;t=A;u=D}else{C=w;break}}if((B|0)==5){C=d[1369984+v|0]|r<<(x-1>>1)}c[n>>2]=A;E=C-1|0}else{u=s>>>24;t=(d[1369728+u|0]|0)+o|0;c[n>>2]=p>>>0>t>>>0?t:p;E=d[1369216+u|0]|0}u=E+1|0;c[l>>2]=u;if(u>>>0>(c[e+144>>2]|0)>>>0){F=-1}else{G=u;break}i=f;return F|0}else{G=m}}while(0);m=G-1|0;c[l>>2]=m;if((m|0)!=0){F=6;i=f;return F|0}do{if((c[e+15664>>2]|0)==0){if((c[e+15676>>2]|0)==0){H=0;break}H=c[(c[e+15548>>2]|0)+(k-1<<2)>>2]|0}else{mrc(g|0,0,48)|0;if((c[e+15676>>2]|0)==0){I=c[e+15548>>2]|0}else{m=c[e+15548>>2]|0;l=g+(c[m+(k-1<<2)>>2]<<2)|0;c[l>>2]=(c[l>>2]|0)+1;I=m}m=g+(c[I+(k-j<<2)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)+1;if((c[e+15672>>2]|0)!=0){m=g+(c[I+(k+1-j<<2)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)+1}if((c[e+15660>>2]|0)!=0){m=g+(c[I+(k-1-j<<2)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)+1}m=c[g>>2]|0;if((m|0)>0){if((m|0)>1){H=0;break}else{J=1}}else{J=0}m=c[g+4>>2]|0;if((m|0)>(J|0)){if((m|0)>1){H=1;break}else{K=m;L=1}}else{K=J;L=0}m=c[g+8>>2]|0;if((m|0)>(K|0)){if((m|0)>1){H=2;break}else{M=m;N=2}}else{M=K;N=L}m=c[g+12>>2]|0;if((m|0)>(M|0)){if((m|0)>1){H=3;break}else{O=m;P=3}}else{O=M;P=N}m=c[g+16>>2]|0;if((m|0)>(O|0)){if((m|0)>1){H=4;break}else{Q=m;R=4}}else{Q=O;R=P}m=c[g+20>>2]|0;if((m|0)>(Q|0)){if((m|0)>1){H=5;break}else{S=m;T=5}}else{S=Q;T=R}m=c[g+24>>2]|0;if((m|0)>(S|0)){if((m|0)>1){H=6;break}else{U=m;V=6}}else{U=S;V=T}m=c[g+28>>2]|0;if((m|0)>(U|0)){if((m|0)>1){H=7;break}else{W=m;X=7}}else{W=U;X=V}m=c[g+32>>2]|0;if((m|0)>(W|0)){if((m|0)>1){H=8;break}else{Y=m;Z=8}}else{Y=W;Z=X}m=c[g+36>>2]|0;if((m|0)>(Y|0)){if((m|0)>1){H=9;break}else{_=m;$=9}}else{_=Y;$=Z}m=c[g+40>>2]|0;if((m|0)>(_|0)){if((m|0)>1){H=10;break}else{aa=m;ba=10}}else{aa=_;ba=$}H=(c[g+44>>2]|0)>(aa|0)?11:ba}}while(0);if((c[e+9992>>2]|0)==2){ba=c[5430124+((d[1901288+H|0]|0)*20|0)>>2]|0;aa=e+14128|0;g=c[aa>>2]|0;$=c[e+14136>>2]|0;_=c[h>>2]|0;Z=_+(g>>>3)|0;Y=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(g&7)>>>25;Z=b[ba+(Y<<2)>>1]|0;X=(b[ba+(Y<<2)+2>>1]|0)+g|0;g=$>>>0>X>>>0?X:$;c[aa>>2]=g;if(Z<<16>>16<255){F=Z<<16>>16;i=f;return F|0}Z=_+(g>>>3)|0;_=(b[ba+((je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(g&7)>>>25<<2)+2>>1]|0)+g|0;c[aa>>2]=$>>>0>_>>>0?_:$;KIb(c[e+4>>2]|0,16,2446912,(da=i,i=i+1|0,i=i+7&-8,c[da>>2]=0,da)|0);i=da;F=0;i=f;return F|0}else{$=c[9881988+((d[1901304+H|0]|0)*20|0)>>2]|0;H=e+14128|0;_=c[H>>2]|0;aa=c[e+14136>>2]|0;g=c[h>>2]|0;h=g+(_>>>3)|0;Z=(je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(_&7)>>>26;h=b[$+(Z<<2)>>1]|0;ba=(b[$+(Z<<2)+2>>1]|0)+_|0;_=aa>>>0>ba>>>0?ba:aa;c[H>>2]=_;if(h<<16>>16<255){F=h<<16>>16;i=f;return F|0}h=g+(_>>>3)|0;g=(b[$+((je(d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0)|0)<<(_&7)>>>26<<2)+2>>1]|0)+_|0;c[H>>2]=aa>>>0>g>>>0?g:aa;KIb(c[e+4>>2]|0,16,2357632,(da=i,i=i+1|0,i=i+7&-8,c[da>>2]=0,da)|0);i=da;F=0;i=f;return F|0}return 0}function r_a(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0;h=i;i=i+280|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=h+64|0;s=h+72|0;t=h+80|0;u=h+88|0;v=h+96|0;w=h+104|0;x=h+112|0;y=h+120|0;z=h+128|0;A=h+144|0;B=h+160|0;C=h+176|0;D=h+192|0;E=h+224|0;F=h+240|0;G=h+248|0;H=h+256|0;I=h+272|0;J=f+124|0;K=f+116|0;L=c[K>>2]|0;if((L|0)<=0){i=h;return}M=f+9856|0;N=f+15644|0;O=f+15648|0;P=f+15640|0;Q=1;R=ca(c[J>>2]|0,g)|0;S=L;while(1){L=c[(c[(c[M>>2]|0)+1536>>2]|0)+(R<<2)>>2]|0;T=(L&7|0)!=0;if(!((L&16777216|0)==0&(T^1))){b[(c[O>>2]|0)+(R<<1)>>1]=-1;b[(c[P>>2]|0)+(R<<1)>>1]=-1}if(T){a[(c[N>>2]|0)+R|0]=-1;U=c[K>>2]|0}else{U=S}if((Q|0)>=(U|0)){break}Q=Q+1|0;R=R+1|0;S=U}if((U|0)<=0){i=h;return}U=ca(c[J>>2]|0,g)|0;S=f+9856|0;R=f+8|0;Q=f+12|0;N=H|0;P=H+4|0;O=H+8|0;M=f+120|0;T=H+12|0;L=z|0;V=f+15648|0;W=f+15640|0;X=f+15644|0;Y=E|0;Z=E+12|0;_=C|0;$=C+4|0;aa=C+8|0;ba=(g|0)!=0;da=A|0;ea=A+12|0;fa=g<<4;ga=f+148|0;ha=A+8|0;ia=E+8|0;ja=B+8|0;ka=f+15260|0;la=f+15244|0;ma=f+15252|0;na=B|0;oa=A+4|0;pa=E+4|0;qa=f+15256|0;ra=f+15240|0;sa=f+15248|0;ta=B+4|0;ua=g<<3;va=f+152|0;f=0;wa=U;while(1){U=c[S>>2]|0;xa=a[(c[U+1512>>2]|0)+wa|0]|0;ya=a[616544+xa|0]|0;za=d[616512+xa|0]|0;Aa=(ca(c[Q>>2]|0,c[R>>2]|0)|0)<25345;Ba=Aa?za:0;c[N>>2]=1;c[P>>2]=g;c[O>>2]=f;Aa=(c[M>>2]|0)-1|0;c[T>>2]=(Aa|0)>(g|0);Ca=0;Da=0;while(1){if(Da){c[E+(Ca<<2)>>2]=0;Ea=c[L>>2]|0;c[z+(Ca<<2)>>2]=Ea;c[C+(Ca<<2)>>2]=0;c[D+(Ca<<3)+4>>2]=0;c[D+(Ca<<3)>>2]=0;Fa=Ea}else{Ea=(c[785432+(Ca<<2)>>2]|0)+wa+(ca(c[J>>2]|0,c[785416+(Ca<<2)>>2]|0)|0)|0;c[E+(Ca<<2)>>2]=e[(c[V>>2]|0)+(Ea<<1)>>1]|0;Ga=c[(c[U+1536>>2]|0)+(Ea<<2)>>2]|0;c[z+(Ca<<2)>>2]=Ga;c[C+(Ca<<2)>>2]=e[(c[W>>2]|0)+(Ea<<1)>>1]|0;Ha=(c[X>>2]|0)+Ea|0;c[D+(Ca<<3)>>2]=a[Ha]&15;c[D+(Ca<<3)+4>>2]=(d[Ha]|0)>>>4;Fa=Ga}if((Fa&7|0)==0){Ia=Fa>>>24&1}else{Ia=1}c[A+(Ca<<2)>>2]=Ia;c[B+(Ca<<2)>>2]=d[616320+(Ia+1<<5)+xa|0]|0;Ga=Ca+1|0;if((Ga|0)>=4){break}Ca=Ga;Da=(c[H+(Ga<<2)>>2]|0)==0}Da=ya&255;Ca=za*3|0;xa=Ba+Ca|0;Ga=c[Z>>2]<<16|c[Y>>2];Ha=c[_>>2]|0;Ea=Ga|Ha<<4;Ja=Ha<<1&-4370|Ga;Ha=(f|0)!=0;Ka=Ha?(c[aa>>2]|0)>>>3&4369|Ja:Ja&-4370;Ja=ba?(c[$>>2]|0)>>>12&15|Ea:Ea&-16;Ea=(Aa|0)==(g|0);La=c[da>>2]|0;Ma=c[ea>>2]|0;if(Ea){Na=21}else{if((Ma|La|0)==0){Oa=Ja}else{Na=21}}if((Na|0)==21){Na=0;Oa=Ja&-983041}Ja=(Ma|La|0)==0;Ma=c[D>>2]|0;Pa=c[D+24>>2]<<4|Ma;c[I>>2]=Pa;Qa=Ma<<1&-6|Pa;do{if(Ha){Ra=Qa|(c[D+16>>2]|0)>>>1&5;c[F>>2]=Ra;Sa=(c[D+8>>2]|0)>>>2&3|Pa|Ma<<2;if(ba){Ta=Sa;Ua=Sa}else{Va=Sa&-4;Ta=Va;Ua=Va}if(Ea|Ja^1){Va=Ta&-49;Wa=Va;Xa=Va}else{Wa=Ta;Xa=Ua}c[G>>2]=Xa;Va=c[D+4>>2]|0;Sa=c[D+28>>2]<<4|Va;c[I+4>>2]=Sa;c[F+4>>2]=Va<<1&-6|Sa|(c[D+20>>2]|0)>>>1&5;Ya=(c[D+12>>2]|0)>>>2&3|Sa|Va<<2;Va=G+4|0;if(ba){Za=Ya;_a=Ya}else{Sa=Ya&-4;Za=Sa;_a=Sa}c[Va>>2]=_a;if(!(Ea|Ja^1)){$a=Wa;ab=Ra;break}c[Va>>2]=Za&-49;$a=Wa;ab=Ra}else{Ra=F|0;Va=(c[D+8>>2]|0)>>>2&3|Pa|Ma<<2;Sa=G|0;if(ba){c[Sa>>2]=Va;Ya=Qa&-6;c[Ra>>2]=Ya;if(Ea|Ja^1){bb=Va&-49;c[Sa>>2]=bb;cb=bb}else{cb=Va}bb=c[D+4>>2]|0;db=c[D+28>>2]<<4|bb;c[I+4>>2]=db;eb=(c[D+12>>2]|0)>>>2&3|db|bb<<2;fb=G+4|0;c[fb>>2]=eb;c[F+4>>2]=(bb<<1|db)&-6;if(!(Ea|Ja^1)){$a=cb;ab=Ya;break}c[fb>>2]=eb&-49;$a=cb;ab=Ya;break}else{Ya=Qa&-6;c[Ra>>2]=Ya;Ra=Va&-4;if(Ea|Ja^1){eb=Va&-52;gb=eb;hb=eb}else{gb=Ra;hb=Ra}c[Sa>>2]=hb;Sa=c[D+4>>2]|0;Ra=c[D+28>>2]<<4|Sa;c[I+4>>2]=Ra;eb=G+4|0;c[F+4>>2]=(Sa<<1|Ra)&-6;Va=Ra&-4|Sa<<2;c[eb>>2]=Va;if(!(Ea|Ja^1)){$a=gb;ab=Ya;break}c[eb>>2]=Va&-52;$a=gb;ab=Ya;break}}}while(0);Ja=f<<4;Ea=(c[ha>>2]|La|0)==0;Qa=c[ia>>2]|0;Ma=c[ja>>2]|0;Ha=c[na>>2]|0;Aa=(c[oa>>2]|La|0)==0;Ba=c[pa>>2]|0;ya=c[ta>>2]|0;Ya=0;Va=U;while(1){eb=(Ya|0)!=0;Sa=(Qa&8<<Ya|0)==0;Ra=(c[Va>>2]|0)+((ca(c[ga>>2]|0,Ya+fa|0)|0)+Ja)|0;fb=0;while(1){db=fb+Ya|0;bb=1<<db;ib=(bb&Ga|0)==0?0:Ha;jb=eb?db:fb<<2;kb=16<<db;do{if((kb&Oa|0)!=0){lb=c[ga>>2]|0;mb=Ra+(lb<<2)|0;nb=(kb&Ga|0)==0?0:Ha;ob=me[c[qa>>2]&255](mb,lb,za,xa,0,x,y)|0;pb=c[x>>2]|0;qb=c[y>>2]|0;rb=(nb+ib>>1)+1+pb+qb|0;if((ob|0)!=0){_e[c[sa>>2]&511](mb,lb,Da,rb,jb,0);break}if((qb&pb|0)!=0){Te[c[ra>>2]&255](mb,lb,1,1,Da,za,rb,nb,ib);break}if((qb|pb|0)==0){break}Te[c[ra>>2]&255](mb,lb,pb,qb,Da,za,rb>>1,nb>>1,ib>>1)}}while(0);kb=(bb&Ka|0)!=0;do{if(kb){if((fb|0)==0){if(!Ea){break}sb=Sa?0:Ma}else{sb=(1<<db-1&Ga|0)==0?0:Ha}nb=c[ga>>2]|0;rb=me[c[ka>>2]&255](Ra,nb,za,xa,0,v,w)|0;qb=c[v>>2]|0;pb=c[w>>2]|0;lb=(sb+ib>>1)+1+qb+pb|0;if((rb|0)!=0){_e[c[ma>>2]&511](Ra,nb,Da,lb,jb,0);break}if((pb&qb|0)!=0){Te[c[la>>2]&255](Ra,nb,1,1,Da,za,lb,ib,sb);break}if((pb|qb|0)==0){break}Te[c[la>>2]&255](Ra,nb,qb,pb,Da,za,lb>>1,ib>>1,sb>>1)}}while(0);do{if(!eb){if((1<<fb&Oa|0)==0|Aa){break}db=c[ga>>2]|0;bb=(Ba&4096<<fb|0)==0?0:ya;lb=me[c[qa>>2]&255](Ra,db,za,xa,1,t,u)|0;pb=c[t>>2]|0;qb=c[u>>2]|0;nb=(bb+ib>>1)+1+pb+qb|0;if((lb|0)!=0){_e[c[sa>>2]&511](Ra,db,Da,nb,jb,0);break}if((qb&pb|0)!=0){Te[c[ra>>2]&255](Ra,db,1,1,Da,za,nb,ib,bb);break}if((qb|pb|0)==0){break}Te[c[ra>>2]&255](Ra,db,pb,qb,Da,za,nb>>1,ib>>1,bb>>1)}}while(0);do{if(!(Ea|kb&(fb|0)==0^1)){bb=Sa?0:Ma;nb=c[ga>>2]|0;qb=me[c[ka>>2]&255](Ra,nb,za,xa,1,r,s)|0;pb=c[r>>2]|0;db=c[s>>2]|0;lb=(bb+ib>>1)+1+pb+db|0;if((qb|0)!=0){_e[c[ma>>2]&511](Ra,nb,Da,lb,jb,0);break}if((db&pb|0)!=0){Te[c[la>>2]&255](Ra,nb,1,1,Da,za,lb,ib,bb);break}if((db|pb|0)==0){break}Te[c[la>>2]&255](Ra,nb,pb,db,Da,za,lb>>1,ib>>1,bb>>1)}}while(0);ib=fb+1|0;if((ib|0)<4){Ra=Ra+4|0;fb=ib}else{break}}fb=Ya+4|0;if((fb|0)>=16){break}Ya=fb;Va=c[S>>2]|0}Va=f<<3;Ya=0;xa=Pa;Ba=$a;Ga=ab;while(1){Ka=Ya+1|0;Ja=D+8+(Ya<<2)|0;Qa=D+16+(Ya<<2)|0;U=0;La=xa;while(1){fb=U<<1;Ra=(U|0)==0;Sa=1<<(fb|1);eb=U<<3;ib=(c[(c[S>>2]|0)+(Ka<<2)>>2]|0)+((ca(c[va>>2]|0,(U<<2)+ua|0)|0)+Va)|0;jb=0;kb=La;while(1){bb=jb+fb|0;lb=1<<bb;db=(xa&lb|0)==0?0:Ha;pb=1<<bb+2;do{if((Ba&pb|0)==0){tb=kb}else{nb=(xa&pb|0)==0?0:Ha;qb=c[va>>2]|0;rb=ib+(qb<<2)|0;mb=me[c[qa>>2]&255](rb,qb,za,Ca,0,p,q)|0;ob=c[p>>2]|0;ub=c[q>>2]|0;vb=(nb+db>>1)+1+ob+ub|0;if((mb|0)!=0){_e[c[sa>>2]&511](rb,qb,Da,vb,jb<<3,1);tb=xa;break}if((ub&ob|0)!=0){Te[c[ra>>2]&255](rb,qb,1,1,Da,za,vb,nb,db);tb=xa;break}if((ub|ob|0)==0){tb=xa;break}Te[c[ra>>2]&255](rb,qb,ob,ub,Da,za,vb>>1,nb>>1,db>>1);tb=xa}}while(0);nb=Ga&lb;do{if((nb|0)!=0){if((jb|0)==0){if(!Ea){break}wb=(c[Qa>>2]&Sa|0)==0?0:Ma}else{wb=(tb&1<<bb-1|0)==0?0:Ha}vb=c[va>>2]|0;ub=me[c[ka>>2]&255](ib,vb,za,Ca,0,n,o)|0;ob=c[n>>2]|0;qb=c[o>>2]|0;rb=(wb+db>>1)+1+ob+qb|0;if((ub|0)!=0){_e[c[ma>>2]&511](ib,vb,Da,rb,eb,1);break}if((qb&ob|0)!=0){Te[c[la>>2]&255](ib,vb,1,1,Da,za,rb,db,wb);break}if((qb|ob|0)==0){break}Te[c[la>>2]&255](ib,vb,ob,qb,Da,za,rb>>1,db>>1,wb>>1)}}while(0);do{if(Ra){if((Ba&lb|0)==0|Aa){break}bb=(c[Ja>>2]&pb|0)==0?0:ya;rb=c[va>>2]|0;qb=me[c[qa>>2]&255](ib,rb,za,Ca,1,l,m)|0;ob=c[l>>2]|0;vb=c[m>>2]|0;ub=(bb+db>>1)+1+ob+vb|0;if((qb|0)!=0){_e[c[sa>>2]&511](ib,rb,Da,ub,jb<<3,1);break}if((vb&ob|0)!=0){Te[c[ra>>2]&255](ib,rb,1,1,Da,za,ub,db,bb);break}if((vb|ob|0)==0){break}Te[c[ra>>2]&255](ib,rb,ob,vb,Da,za,ub>>1,db>>1,bb>>1)}}while(0);do{if(!((jb|0)!=0|(nb|0)==0|Ea)){pb=(c[Qa>>2]&Sa|0)==0?0:Ma;lb=c[va>>2]|0;bb=me[c[ka>>2]&255](ib,lb,za,Ca,1,j,k)|0;ub=c[j>>2]|0;vb=c[k>>2]|0;ob=(pb+db>>1)+1+ub+vb|0;if((bb|0)!=0){_e[c[ma>>2]&511](ib,lb,Da,ob,eb,1);break}if((vb&ub|0)!=0){Te[c[la>>2]&255](ib,lb,1,1,Da,za,ob,db,pb);break}if((vb|ub|0)==0){break}Te[c[la>>2]&255](ib,lb,ub,vb,Da,za,ob>>1,db>>1,pb>>1)}}while(0);db=jb+1|0;if((db|0)<2){ib=ib+4|0;jb=db;kb=tb}else{break}}kb=U+1|0;if((kb|0)<2){U=kb;La=tb}else{break}}if((Ka|0)>=2){break}Ya=Ka;xa=c[I+(Ka<<2)>>2]|0;Ba=c[G+(Ka<<2)>>2]|0;Ga=c[F+(Ka<<2)>>2]|0}Ga=f+1|0;if((Ga|0)>=(c[K>>2]|0)){break}f=Ga;wa=wa+1|0}i=h;return}function s_a(a){a=a|0;var b=0,d=0;b=i;i=i+512|0;d=b|0;Ysb(a);nta(d,8);c[a>>2]=c[d>>2];c[a+4>>2]=1874;c[a+8>>2]=c[d+8>>2];c[a+12>>2]=822;c[a+16>>2]=916;c[a+20>>2]=2208;c[a+24>>2]=2296;c[a+28>>2]=2068;c[a+32>>2]=c[d+32>>2];c[a+36>>2]=1256;c[a+40>>2]=744;c[a+44>>2]=1736;c[a+48>>2]=1524;c[a+52>>2]=1602;c[a+56>>2]=1674;c[a+60>>2]=354;c[a+256>>2]=c[d+256>>2];c[a+260>>2]=2112;c[a+264>>2]=c[d+264>>2];c[a+268>>2]=410;c[a+272>>2]=628;c[a+276>>2]=1776;c[a+280>>2]=1382;c[a+284>>2]=94;c[a+288>>2]=c[d+288>>2];c[a+292>>2]=1188;c[a+296>>2]=1704;c[a+300>>2]=1348;c[a+304>>2]=1234;c[a+308>>2]=2394;c[a+312>>2]=772;c[a+316>>2]=2e3;c[a+64>>2]=c[d+64>>2];c[a+68>>2]=2242;c[a+72>>2]=c[d+72>>2];c[a+76>>2]=2344;c[a+80>>2]=760;c[a+84>>2]=1882;c[a+88>>2]=2148;c[a+92>>2]=844;c[a+96>>2]=c[d+96>>2];c[a+100>>2]=378;c[a+104>>2]=2416;c[a+108>>2]=1720;c[a+112>>2]=1810;c[a+116>>2]=58;c[a+120>>2]=338;c[a+124>>2]=212;c[a+320>>2]=c[d+320>>2];c[a+324>>2]=682;c[a+328>>2]=c[d+328>>2];c[a+332>>2]=600;c[a+336>>2]=2160;c[a+340>>2]=1048;c[a+344>>2]=794;c[a+348>>2]=1502;c[a+352>>2]=c[d+352>>2];c[a+356>>2]=128;c[a+360>>2]=2010;c[a+364>>2]=1190;c[a+368>>2]=348;c[a+372>>2]=422;c[a+376>>2]=486;c[a+380>>2]=2126;c[a+512>>2]=356;c[a+516>>2]=178;c[a+524>>2]=16;c[a+528>>2]=154;c[a+536>>2]=306;c[a+540>>2]=98;c[a+544>>2]=198;c[a+548>>2]=22;c[a+568>>2]=132;c[a+572>>2]=18;c[a+576>>2]=84;c[a+580>>2]=272;c[a+584>>2]=72;c[a+588>>2]=144;i=b;return}function t_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;B$a(a,b,c,c,8,52,20,6);B$a(a+8|0,b+8|0,c,c,8,52,20,6);d=c<<3;B$a(a+d|0,b+d|0,c,c,8,52,20,6);e=d+8|0;B$a(a+e|0,b+e|0,c,c,8,52,20,6);return}function u_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;B$a(a,b,c,c,8,20,52,6);B$a(a+8|0,b+8|0,c,c,8,20,52,6);d=c<<3;B$a(a+d|0,b+d|0,c,c,8,20,52,6);e=d+8|0;B$a(a+e|0,b+e|0,c,c,8,20,52,6);return}function v_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;E$a(a,b,c,c,52,20,6);E$a(a+8|0,b+8|0,c,c,52,20,6);d=c<<3;E$a(a+d|0,b+d|0,c,c,52,20,6);e=d+8|0;E$a(a+e|0,b+e|0,c,c,52,20,6);return}function w_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,52,20,6);B$a(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,52,20,6);E$a(a,e+32|0,c,16,52,20,6);E$a(a+8|0,e+40|0,c,16,52,20,6);E$a(a+g|0,e+160|0,c,16,52,20,6);E$a(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function x_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,20,5);B$a(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,20,5);E$a(a,e+32|0,c,16,52,20,6);E$a(a+8|0,e+40|0,c,16,52,20,6);E$a(a+g|0,e+160|0,c,16,52,20,6);E$a(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function y_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,52,6);B$a(e+8|0,b+(8-f)|0,16,c,8,20,52,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,52,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,52,6);E$a(a,e+32|0,c,16,52,20,6);E$a(a+8|0,e+40|0,c,16,52,20,6);E$a(a+g|0,e+160|0,c,16,52,20,6);E$a(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function z_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,52,20,6);B$a(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,52,20,6);E$a(a,e+32|0,c,16,20,20,5);E$a(a+8|0,e+40|0,c,16,20,20,5);E$a(a+g|0,e+160|0,c,16,20,20,5);E$a(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function A_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,20,5);B$a(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,20,5);E$a(a,e+32|0,c,16,20,20,5);E$a(a+8|0,e+40|0,c,16,20,20,5);E$a(a+g|0,e+160|0,c,16,20,20,5);E$a(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function B_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,52,6);B$a(e+8|0,b+(8-f)|0,16,c,8,20,52,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,52,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,52,6);E$a(a,e+32|0,c,16,20,20,5);E$a(a+8|0,e+40|0,c,16,20,20,5);E$a(a+g|0,e+160|0,c,16,20,20,5);E$a(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function C_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;E$a(a,b,c,c,20,52,6);E$a(a+8|0,b+8|0,c,c,20,52,6);d=c<<3;E$a(a+d|0,b+d|0,c,c,20,52,6);e=d+8|0;E$a(a+e|0,b+e|0,c,c,20,52,6);return}function D_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,52,20,6);B$a(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,52,20,6);E$a(a,e+32|0,c,16,20,52,6);E$a(a+8|0,e+40|0,c,16,20,52,6);E$a(a+g|0,e+160|0,c,16,20,52,6);E$a(a+h|0,e+168|0,c,16,20,52,6);i=d;return}function E_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,20,5);B$a(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,20,5);E$a(a,e+32|0,c,16,20,52,6);E$a(a+8|0,e+40|0,c,16,20,52,6);E$a(a+g|0,e+160|0,c,16,20,52,6);E$a(a+h|0,e+168|0,c,16,20,52,6);i=d;return}function F_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;D$a(a,b,c,c,52,20);D$a(a+8|0,b+8|0,c,c,52,20);d=c<<3;D$a(a+d|0,b+d|0,c,c,52,20);e=d+8|0;D$a(a+e|0,b+e|0,c,c,52,20);return}function G_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;D$a(a,b,c,c,20,52);D$a(a+8|0,b+8|0,c,c,20,52);d=c<<3;D$a(a+d|0,b+d|0,c,c,20,52);e=d+8|0;D$a(a+e|0,b+e|0,c,c,20,52);return}function H_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;C$a(a,b,c,c,52,20,6);C$a(a+8|0,b+8|0,c,c,52,20,6);d=c<<3;C$a(a+d|0,b+d|0,c,c,52,20,6);e=d+8|0;C$a(a+e|0,b+e|0,c,c,52,20,6);return}function I_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,52,20,6);B$a(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,52,20,6);C$a(a,e+32|0,c,16,52,20,6);C$a(a+8|0,e+40|0,c,16,52,20,6);C$a(a+g|0,e+160|0,c,16,52,20,6);C$a(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function J_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,20,5);B$a(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,20,5);C$a(a,e+32|0,c,16,52,20,6);C$a(a+8|0,e+40|0,c,16,52,20,6);C$a(a+g|0,e+160|0,c,16,52,20,6);C$a(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function K_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,52,6);B$a(e+8|0,b+(8-f)|0,16,c,8,20,52,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,52,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,52,6);C$a(a,e+32|0,c,16,52,20,6);C$a(a+8|0,e+40|0,c,16,52,20,6);C$a(a+g|0,e+160|0,c,16,52,20,6);C$a(a+h|0,e+168|0,c,16,52,20,6);i=d;return}function L_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,52,20,6);B$a(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,52,20,6);C$a(a,e+32|0,c,16,20,20,5);C$a(a+8|0,e+40|0,c,16,20,20,5);C$a(a+g|0,e+160|0,c,16,20,20,5);C$a(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function M_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,20,5);B$a(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,20,5);C$a(a,e+32|0,c,16,20,20,5);C$a(a+8|0,e+40|0,c,16,20,20,5);C$a(a+g|0,e+160|0,c,16,20,20,5);C$a(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function N_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,52,6);B$a(e+8|0,b+(8-f)|0,16,c,8,20,52,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,52,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,52,6);C$a(a,e+32|0,c,16,20,20,5);C$a(a+8|0,e+40|0,c,16,20,20,5);C$a(a+g|0,e+160|0,c,16,20,20,5);C$a(a+h|0,e+168|0,c,16,20,20,5);i=d;return}function O_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;C$a(a,b,c,c,20,52,6);C$a(a+8|0,b+8|0,c,c,20,52,6);d=c<<3;C$a(a+d|0,b+d|0,c,c,20,52,6);e=d+8|0;C$a(a+e|0,b+e|0,c,c,20,52,6);return}function P_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,52,20,6);B$a(e+8|0,b+(8-f)|0,16,c,8,52,20,6);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,52,20,6);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,52,20,6);C$a(a,e+32|0,c,16,20,52,6);C$a(a+8|0,e+40|0,c,16,20,52,6);C$a(a+g|0,e+160|0,c,16,20,52,6);C$a(a+h|0,e+168|0,c,16,20,52,6);i=d;return}function Q_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+336|0;e=d|0;f=c<<1;B$a(e|0,b+(-f|0)|0,16,c,8,20,20,5);B$a(e+8|0,b+(8-f)|0,16,c,8,20,20,5);g=c<<3;B$a(e+128|0,b+(g-f)|0,16,c,13,20,20,5);h=g+8|0;B$a(e+136|0,b+(h-f)|0,16,c,13,20,20,5);C$a(a,e+32|0,c,16,20,52,6);C$a(a+8|0,e+40|0,c,16,20,52,6);C$a(a+g|0,e+160|0,c,16,20,52,6);C$a(a+h|0,e+168|0,c,16,20,52,6);i=d;return}function R_a(a,b,c){a=a|0;b=b|0;c=c|0;B$a(a,b,c,c,8,52,20,6);return}function S_a(a,b,c){a=a|0;b=b|0;c=c|0;B$a(a,b,c,c,8,20,52,6);return}function T_a(a,b,c){a=a|0;b=b|0;c=c|0;E$a(a,b,c,c,52,20,6);return}function U_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);E$a(a,e+16|0,c,8,52,20,6);i=d;return}function V_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);E$a(a,e+16|0,c,8,52,20,6);i=d;return}function W_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,52,6);E$a(a,e+16|0,c,8,52,20,6);i=d;return}function X_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);E$a(a,e+16|0,c,8,20,20,5);i=d;return}function Y_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);E$a(a,e+16|0,c,8,20,20,5);i=d;return}function Z_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,52,6);E$a(a,e+16|0,c,8,20,20,5);i=d;return}function __a(a,b,c){a=a|0;b=b|0;c=c|0;E$a(a,b,c,c,20,52,6);return}function $_a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);E$a(a,e+16|0,c,8,20,52,6);i=d;return}function a$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);E$a(a,e+16|0,c,8,20,52,6);i=d;return}function b$a(a,b,c){a=a|0;b=b|0;c=c|0;D$a(a,b,c,c,52,20);return}function c$a(a,b,c){a=a|0;b=b|0;c=c|0;D$a(a,b,c,c,20,52);return}function d$a(a,b,c){a=a|0;b=b|0;c=c|0;C$a(a,b,c,c,52,20,6);return}function e$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);C$a(a,e+16|0,c,8,52,20,6);i=d;return}function f$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);C$a(a,e+16|0,c,8,52,20,6);i=d;return}function g$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,52,6);C$a(a,e+16|0,c,8,52,20,6);i=d;return}function h$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);C$a(a,e+16|0,c,8,20,20,5);i=d;return}function i$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);C$a(a,e+16|0,c,8,20,20,5);i=d;return}function j$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,52,6);C$a(a,e+16|0,c,8,20,20,5);i=d;return}function k$a(a,b,c){a=a|0;b=b|0;c=c|0;C$a(a,b,c,c,20,52,6);return}function l$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,52,20,6);C$a(a,e+16|0,c,8,20,52,6);i=d;return}function m$a(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+104|0;e=d|0;B$a(e|0,b+(-(c<<1)|0)|0,8,c,13,20,20,5);C$a(a,e+16|0,c,8,20,52,6);i=d;return}function n$a(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=8-h|0;k=8-i|0;l=ca(k,j)|0;m=ca(k,h)|0;k=ca(j,i)|0;j=ca(i,h)|0;n=c[616448+(i>>1<<4)+(h>>1<<2)>>2]|0;if((j|0)==0){h=m+k|0;i=(k|0)!=0?f:1;if((g|0)<=0){return}o=i+1|0;p=i+2|0;q=i+3|0;r=i+4|0;s=i+5|0;t=i+6|0;u=i+7|0;v=0;w=e;x=b;while(1){y=ca(d[w]|0,l)|0;a[x]=(y+n+(ca(d[w+i|0]|0,h)|0)|0)>>>6;y=ca(d[w+1|0]|0,l)|0;a[x+1|0]=(y+n+(ca(d[w+o|0]|0,h)|0)|0)>>>6;y=ca(d[w+2|0]|0,l)|0;a[x+2|0]=(y+n+(ca(d[w+p|0]|0,h)|0)|0)>>>6;y=ca(d[w+3|0]|0,l)|0;a[x+3|0]=(y+n+(ca(d[w+q|0]|0,h)|0)|0)>>>6;y=ca(d[w+4|0]|0,l)|0;a[x+4|0]=(y+n+(ca(d[w+r|0]|0,h)|0)|0)>>>6;y=ca(d[w+5|0]|0,l)|0;a[x+5|0]=(y+n+(ca(d[w+s|0]|0,h)|0)|0)>>>6;y=ca(d[w+6|0]|0,l)|0;a[x+6|0]=(y+n+(ca(d[w+t|0]|0,h)|0)|0)>>>6;y=ca(d[w+7|0]|0,l)|0;a[x+7|0]=(y+n+(ca(d[w+u|0]|0,h)|0)|0)>>>6;y=v+1|0;if((y|0)<(g|0)){v=y;w=w+f|0;x=x+f|0}else{break}}return}else{if((g|0)<=0){return}x=f+1|0;w=f+2|0;v=f+3|0;h=f+4|0;u=f+5|0;t=f+6|0;s=f+7|0;r=f+8|0;q=0;p=e;e=b;while(1){b=ca(d[p]|0,l)|0;o=p+1|0;i=ca(d[o]|0,m)|0;y=p+f|0;z=ca(d[y]|0,k)|0;A=p+x|0;a[e]=(b+n+i+z+(ca(d[A]|0,j)|0)|0)>>>6;z=ca(d[o]|0,l)|0;o=p+2|0;i=ca(d[o]|0,m)|0;b=ca(d[A]|0,k)|0;A=p+w|0;a[e+1|0]=(z+n+i+b+(ca(d[A]|0,j)|0)|0)>>>6;b=ca(d[o]|0,l)|0;o=p+3|0;i=ca(d[o]|0,m)|0;z=ca(d[A]|0,k)|0;A=p+v|0;a[e+2|0]=(b+n+i+z+(ca(d[A]|0,j)|0)|0)>>>6;z=ca(d[o]|0,l)|0;o=p+4|0;i=ca(d[o]|0,m)|0;b=ca(d[A]|0,k)|0;A=p+h|0;a[e+3|0]=(z+n+i+b+(ca(d[A]|0,j)|0)|0)>>>6;b=ca(d[o]|0,l)|0;o=p+5|0;i=ca(d[o]|0,m)|0;z=ca(d[A]|0,k)|0;A=p+u|0;a[e+4|0]=(b+n+i+z+(ca(d[A]|0,j)|0)|0)>>>6;z=ca(d[o]|0,l)|0;o=p+6|0;i=ca(d[o]|0,m)|0;b=ca(d[A]|0,k)|0;A=p+t|0;a[e+5|0]=(z+n+i+b+(ca(d[A]|0,j)|0)|0)>>>6;b=ca(d[o]|0,l)|0;o=p+7|0;i=ca(d[o]|0,m)|0;z=ca(d[A]|0,k)|0;A=p+s|0;a[e+6|0]=(b+n+i+z+(ca(d[A]|0,j)|0)|0)>>>6;z=ca(d[o]|0,l)|0;o=ca(d[p+8|0]|0,m)|0;i=ca(d[A]|0,k)|0;a[e+7|0]=(z+n+o+i+(ca(d[p+r|0]|0,j)|0)|0)>>>6;i=q+1|0;if((i|0)<(g|0)){q=i;p=y;e=e+f|0}else{break}}return}}function o$a(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=8-h|0;k=8-i|0;l=ca(k,j)|0;m=ca(k,h)|0;k=ca(j,i)|0;j=ca(i,h)|0;n=c[616448+(i>>1<<4)+(h>>1<<2)>>2]|0;if((j|0)==0){h=m+k|0;i=(k|0)!=0?f:1;if((g|0)<=0){return}o=i+1|0;p=i+2|0;q=i+3|0;r=0;s=e;t=b;while(1){u=ca(d[s]|0,l)|0;a[t]=(u+n+(ca(d[s+i|0]|0,h)|0)|0)>>>6;u=ca(d[s+1|0]|0,l)|0;a[t+1|0]=(u+n+(ca(d[s+o|0]|0,h)|0)|0)>>>6;u=ca(d[s+2|0]|0,l)|0;a[t+2|0]=(u+n+(ca(d[s+p|0]|0,h)|0)|0)>>>6;u=ca(d[s+3|0]|0,l)|0;a[t+3|0]=(u+n+(ca(d[s+q|0]|0,h)|0)|0)>>>6;u=r+1|0;if((u|0)<(g|0)){r=u;s=s+f|0;t=t+f|0}else{break}}return}else{if((g|0)<=0){return}t=f+1|0;s=f+2|0;r=f+3|0;h=f+4|0;q=0;p=e;e=b;while(1){b=ca(d[p]|0,l)|0;o=p+1|0;i=ca(d[o]|0,m)|0;u=p+f|0;v=ca(d[u]|0,k)|0;w=p+t|0;a[e]=(b+n+i+v+(ca(d[w]|0,j)|0)|0)>>>6;v=ca(d[o]|0,l)|0;o=p+2|0;i=ca(d[o]|0,m)|0;b=ca(d[w]|0,k)|0;w=p+s|0;a[e+1|0]=(v+n+i+b+(ca(d[w]|0,j)|0)|0)>>>6;b=ca(d[o]|0,l)|0;o=p+3|0;i=ca(d[o]|0,m)|0;v=ca(d[w]|0,k)|0;w=p+r|0;a[e+2|0]=(b+n+i+v+(ca(d[w]|0,j)|0)|0)>>>6;v=ca(d[o]|0,l)|0;o=ca(d[p+4|0]|0,m)|0;i=ca(d[w]|0,k)|0;a[e+3|0]=(v+n+o+i+(ca(d[p+h|0]|0,j)|0)|0)>>>6;i=q+1|0;if((i|0)<(g|0)){q=i;p=u;e=e+f|0}else{break}}return}}function p$a(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=8-h|0;k=8-i|0;l=ca(k,j)|0;m=ca(k,h)|0;k=ca(j,i)|0;j=ca(i,h)|0;n=c[616448+(i>>1<<4)+(h>>1<<2)>>2]|0;if((j|0)==0){h=m+k|0;i=(k|0)!=0?f:1;if((g|0)<=0){return}o=i+1|0;p=i+2|0;q=i+3|0;r=i+4|0;s=i+5|0;t=i+6|0;u=i+7|0;v=0;w=e;x=b;while(1){y=ca(d[w]|0,l)|0;a[x]=((d[x]|0)+1+((y+n+(ca(d[w+i|0]|0,h)|0)|0)>>>6)|0)>>>1;y=x+1|0;z=ca(d[w+1|0]|0,l)|0;a[y]=((d[y]|0)+1+((z+n+(ca(d[w+o|0]|0,h)|0)|0)>>>6)|0)>>>1;z=x+2|0;y=ca(d[w+2|0]|0,l)|0;a[z]=((d[z]|0)+1+((y+n+(ca(d[w+p|0]|0,h)|0)|0)>>>6)|0)>>>1;y=x+3|0;z=ca(d[w+3|0]|0,l)|0;a[y]=((d[y]|0)+1+((z+n+(ca(d[w+q|0]|0,h)|0)|0)>>>6)|0)>>>1;z=x+4|0;y=ca(d[w+4|0]|0,l)|0;a[z]=((d[z]|0)+1+((y+n+(ca(d[w+r|0]|0,h)|0)|0)>>>6)|0)>>>1;y=x+5|0;z=ca(d[w+5|0]|0,l)|0;a[y]=((d[y]|0)+1+((z+n+(ca(d[w+s|0]|0,h)|0)|0)>>>6)|0)>>>1;z=x+6|0;y=ca(d[w+6|0]|0,l)|0;a[z]=((d[z]|0)+1+((y+n+(ca(d[w+t|0]|0,h)|0)|0)>>>6)|0)>>>1;y=x+7|0;z=ca(d[w+7|0]|0,l)|0;a[y]=((d[y]|0)+1+((z+n+(ca(d[w+u|0]|0,h)|0)|0)>>>6)|0)>>>1;z=v+1|0;if((z|0)<(g|0)){v=z;w=w+f|0;x=x+f|0}else{break}}return}else{if((g|0)<=0){return}x=f+1|0;w=f+2|0;v=f+3|0;h=f+4|0;u=f+5|0;t=f+6|0;s=f+7|0;r=f+8|0;q=0;p=e;e=b;while(1){b=ca(d[p]|0,l)|0;o=p+1|0;i=ca(d[o]|0,m)|0;z=p+f|0;y=ca(d[z]|0,k)|0;A=p+x|0;a[e]=((d[e]|0)+1+((b+n+i+y+(ca(d[A]|0,j)|0)|0)>>>6)|0)>>>1;y=e+1|0;i=ca(d[o]|0,l)|0;o=p+2|0;b=ca(d[o]|0,m)|0;B=ca(d[A]|0,k)|0;A=p+w|0;a[y]=((d[y]|0)+1+((i+n+b+B+(ca(d[A]|0,j)|0)|0)>>>6)|0)>>>1;B=e+2|0;b=ca(d[o]|0,l)|0;o=p+3|0;i=ca(d[o]|0,m)|0;y=ca(d[A]|0,k)|0;A=p+v|0;a[B]=((d[B]|0)+1+((b+n+i+y+(ca(d[A]|0,j)|0)|0)>>>6)|0)>>>1;y=e+3|0;i=ca(d[o]|0,l)|0;o=p+4|0;b=ca(d[o]|0,m)|0;B=ca(d[A]|0,k)|0;A=p+h|0;a[y]=((d[y]|0)+1+((i+n+b+B+(ca(d[A]|0,j)|0)|0)>>>6)|0)>>>1;B=e+4|0;b=ca(d[o]|0,l)|0;o=p+5|0;i=ca(d[o]|0,m)|0;y=ca(d[A]|0,k)|0;A=p+u|0;a[B]=((d[B]|0)+1+((b+n+i+y+(ca(d[A]|0,j)|0)|0)>>>6)|0)>>>1;y=e+5|0;i=ca(d[o]|0,l)|0;o=p+6|0;b=ca(d[o]|0,m)|0;B=ca(d[A]|0,k)|0;A=p+t|0;a[y]=((d[y]|0)+1+((i+n+b+B+(ca(d[A]|0,j)|0)|0)>>>6)|0)>>>1;B=e+6|0;b=ca(d[o]|0,l)|0;o=p+7|0;i=ca(d[o]|0,m)|0;y=ca(d[A]|0,k)|0;A=p+s|0;a[B]=((d[B]|0)+1+((b+n+i+y+(ca(d[A]|0,j)|0)|0)>>>6)|0)>>>1;y=e+7|0;i=ca(d[o]|0,l)|0;o=ca(d[p+8|0]|0,m)|0;b=ca(d[A]|0,k)|0;a[y]=((d[y]|0)+1+((i+n+o+b+(ca(d[p+r|0]|0,j)|0)|0)>>>6)|0)>>>1;b=q+1|0;if((b|0)<(g|0)){q=b;p=z;e=e+f|0}else{break}}return}}function q$a(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=8-h|0;k=8-i|0;l=ca(k,j)|0;m=ca(k,h)|0;k=ca(j,i)|0;j=ca(i,h)|0;n=c[616448+(i>>1<<4)+(h>>1<<2)>>2]|0;if((j|0)==0){h=m+k|0;i=(k|0)!=0?f:1;if((g|0)<=0){return}o=i+1|0;p=i+2|0;q=i+3|0;r=0;s=e;t=b;while(1){u=ca(d[s]|0,l)|0;a[t]=((d[t]|0)+1+((u+n+(ca(d[s+i|0]|0,h)|0)|0)>>>6)|0)>>>1;u=t+1|0;v=ca(d[s+1|0]|0,l)|0;a[u]=((d[u]|0)+1+((v+n+(ca(d[s+o|0]|0,h)|0)|0)>>>6)|0)>>>1;v=t+2|0;u=ca(d[s+2|0]|0,l)|0;a[v]=((d[v]|0)+1+((u+n+(ca(d[s+p|0]|0,h)|0)|0)>>>6)|0)>>>1;u=t+3|0;v=ca(d[s+3|0]|0,l)|0;a[u]=((d[u]|0)+1+((v+n+(ca(d[s+q|0]|0,h)|0)|0)>>>6)|0)>>>1;v=r+1|0;if((v|0)<(g|0)){r=v;s=s+f|0;t=t+f|0}else{break}}return}else{if((g|0)<=0){return}t=f+1|0;s=f+2|0;r=f+3|0;h=f+4|0;q=0;p=e;e=b;while(1){b=ca(d[p]|0,l)|0;o=p+1|0;i=ca(d[o]|0,m)|0;v=p+f|0;u=ca(d[v]|0,k)|0;w=p+t|0;a[e]=((d[e]|0)+1+((b+n+i+u+(ca(d[w]|0,j)|0)|0)>>>6)|0)>>>1;u=e+1|0;i=ca(d[o]|0,l)|0;o=p+2|0;b=ca(d[o]|0,m)|0;x=ca(d[w]|0,k)|0;w=p+s|0;a[u]=((d[u]|0)+1+((i+n+b+x+(ca(d[w]|0,j)|0)|0)>>>6)|0)>>>1;x=e+2|0;b=ca(d[o]|0,l)|0;o=p+3|0;i=ca(d[o]|0,m)|0;u=ca(d[w]|0,k)|0;w=p+r|0;a[x]=((d[x]|0)+1+((b+n+i+u+(ca(d[w]|0,j)|0)|0)>>>6)|0)>>>1;u=e+3|0;i=ca(d[o]|0,l)|0;o=ca(d[p+4|0]|0,m)|0;b=ca(d[w]|0,k)|0;a[u]=((d[u]|0)+1+((i+n+o+b+(ca(d[p+h|0]|0,j)|0)|0)>>>6)|0)>>>1;b=q+1|0;if((b|0)<(g|0)){q=b;p=v;e=e+f|0}else{break}}return}}function r$a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=e;e=c;c=b;b=0;while(1){j=0;do{k=(ca(d[e+j|0]|0,g)|0)>>>9;a[c+j|0]=(k+16+((ca(d[i+j|0]|0,f)|0)>>>9)|0)>>>5;j=j+1|0;}while((j|0)<16);j=b+1|0;if((j|0)<16){i=i+h|0;e=e+h|0;c=c+h|0;b=j}else{break}}return}function s$a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=e;e=c;c=b;b=0;while(1){j=0;do{k=(ca(d[e+j|0]|0,g)|0)>>>9;a[c+j|0]=(k+16+((ca(d[i+j|0]|0,f)|0)>>>9)|0)>>>5;j=j+1|0;}while((j|0)<8);j=b+1|0;if((j|0)<8){i=i+h|0;e=e+h|0;c=c+h|0;b=j}else{break}}return}function t$a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;i=e;e=c;c=b;b=0;while(1){j=0;do{k=ca(d[e+j|0]|0,g)|0;a[c+j|0]=(k+16+(ca(d[i+j|0]|0,f)|0)|0)>>>5;j=j+1|0;}while((j|0)<16);j=b+1|0;if((j|0)<16){i=i+h|0;e=e+h|0;c=c+h|0;b=j}else{break}}return}function u$a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=e;e=c;c=b;b=0;while(1){j=ca(d[e]|0,g)|0;a[c]=(j+16+(ca(d[i]|0,f)|0)|0)>>>5;j=ca(d[e+1|0]|0,g)|0;a[c+1|0]=(j+16+(ca(d[i+1|0]|0,f)|0)|0)>>>5;j=ca(d[e+2|0]|0,g)|0;a[c+2|0]=(j+16+(ca(d[i+2|0]|0,f)|0)|0)>>>5;j=ca(d[e+3|0]|0,g)|0;a[c+3|0]=(j+16+(ca(d[i+3|0]|0,f)|0)|0)>>>5;j=ca(d[e+4|0]|0,g)|0;a[c+4|0]=(j+16+(ca(d[i+4|0]|0,f)|0)|0)>>>5;j=ca(d[e+5|0]|0,g)|0;a[c+5|0]=(j+16+(ca(d[i+5|0]|0,f)|0)|0)>>>5;j=ca(d[e+6|0]|0,g)|0;a[c+6|0]=(j+16+(ca(d[i+6|0]|0,f)|0)|0)>>>5;j=ca(d[e+7|0]|0,g)|0;a[c+7|0]=(j+16+(ca(d[i+7|0]|0,f)|0)|0)>>>5;j=b+1|0;if((j|0)<8){i=i+h|0;e=e+h|0;c=c+h|0;b=j}else{break}}return}function v$a(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=c*-2|0;m=-c|0;n=c*-3|0;o=c<<1;p=(e|0)!=0;e=(f|0)!=0^3;q=(f|0)==0;f=q|p^1;r=-i|0;s=-k|0;t=-j|0;if(p){u=0;v=b}else{p=0;w=b;while(1){b=w+l|0;x=w+m|0;y=a[x]|0;z=y&255;A=w+c|0;B=d[A]|0;C=a[w]|0;D=C&255;E=B-D|0;F=B-(d[w+o|0]|0)|0;G=D-z|0;do{if(!(C<<24>>24==y<<24>>24)){if(((ca((G|0)>-1?G:-G|0,g)|0)>>7|0)>3){break}D=G<<2;if(f){H=D}else{H=D-B+(d[b]|0)|0}D=H+4>>3;if((D|0)<(r|0)){I=r}else{I=(D|0)>(i|0)?i:D}a[x]=a[1403376+((z|1024)+I)|0]|0;a[w]=a[1403376+(1024-I+(d[w]|0))|0]|0;if(q){break}if((((F|0)>-1?F:-F|0)|0)>(h|0)){break}D=E+F+I>>1;if((D|0)<(t|0)){J=t}else{J=(D|0)>(j|0)?j:D}a[A]=a[1403376+((d[A]|0|1024)-J)|0]|0}}while(0);A=p+1|0;if((A|0)<4){p=A;w=w+1|0}else{break}}return}while(1){w=v+l|0;p=d[w]|0;J=v+m|0;I=a[J]|0;H=I&255;A=p-H|0;F=v+c|0;E=d[F]|0;z=a[v]|0;x=z&255;b=E-x|0;B=p-(d[v+n|0]|0)|0;G=E-(d[v+o|0]|0)|0;y=x-H|0;do{if(!(z<<24>>24==I<<24>>24)){if(((ca((y|0)>-1?y:-y|0,g)|0)>>7|0)>(e|0)){break}x=y<<2;if(f){K=x}else{K=p-E+x|0}x=K+4>>3;if((x|0)<(r|0)){L=r}else{L=(x|0)>(i|0)?i:x}a[J]=a[1403376+((H|1024)+L)|0]|0;a[v]=a[1403376+(1024-L+(d[v]|0))|0]|0;if((((B|0)>-1?B:-B|0)|0)<=(h|0)){x=A+B-L>>1;if((x|0)<(s|0)){M=s}else{M=(x|0)>(k|0)?k:x}a[w]=a[1403376+((d[w]|0|1024)-M)|0]|0}if(q){break}if((((G|0)>-1?G:-G|0)|0)>(h|0)){break}x=b+G+L>>1;if((x|0)<(t|0)){N=t}else{N=(x|0)>(j|0)?j:x}a[F]=a[1403376+((d[F]|0|1024)-N)|0]|0}}while(0);F=u+1|0;if((F|0)<4){u=F;v=v+1|0}else{break}}return}function w$a(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;l=(e|0)!=0;e=(f|0)!=0^3;m=(f|0)==0;f=m|l^1;n=-i|0;o=-k|0;p=-j|0;if(l){q=0;r=b}else{l=0;s=b;while(1){b=s-2|0;t=s-1|0;u=a[t]|0;v=u&255;w=s+1|0;x=d[w]|0;y=a[s]|0;z=y&255;A=x-z|0;B=x-(d[s+2|0]|0)|0;C=z-v|0;do{if(!(y<<24>>24==u<<24>>24)){if(((ca((C|0)>-1?C:-C|0,g)|0)>>7|0)>3){break}D=C<<2;if(f){E=D}else{E=D-x+(d[b]|0)|0}D=E+4>>3;if((D|0)<(n|0)){F=n}else{F=(D|0)>(i|0)?i:D}a[t]=a[1403376+((v|1024)+F)|0]|0;a[s]=a[1403376+(1024-F+z)|0]|0;if(m){break}if((((B|0)>-1?B:-B|0)|0)>(h|0)){break}D=A+B+F>>1;if((D|0)<(p|0)){G=p}else{G=(D|0)>(j|0)?j:D}a[w]=a[1403376+((x|1024)-G)|0]|0}}while(0);x=l+1|0;if((x|0)<4){l=x;s=s+c|0}else{break}}return}while(1){s=r-2|0;l=d[s]|0;G=r-1|0;F=a[G]|0;E=F&255;x=l-E|0;w=r+1|0;B=d[w]|0;A=a[r]|0;z=A&255;v=B-z|0;t=l-(d[r-3|0]|0)|0;b=B-(d[r+2|0]|0)|0;C=z-E|0;do{if(!(A<<24>>24==F<<24>>24)){if(((ca((C|0)>-1?C:-C|0,g)|0)>>7|0)>(e|0)){break}u=C<<2;if(f){H=u}else{H=l-B+u|0}u=H+4>>3;if((u|0)<(n|0)){I=n}else{I=(u|0)>(i|0)?i:u}a[G]=a[1403376+((E|1024)+I)|0]|0;a[r]=a[1403376+(1024-I+z)|0]|0;if((((t|0)>-1?t:-t|0)|0)<=(h|0)){u=x+t-I>>1;if((u|0)<(o|0)){J=o}else{J=(u|0)>(k|0)?k:u}a[s]=a[1403376+((l|1024)-J)|0]|0}if(m){break}if((((b|0)>-1?b:-b|0)|0)>(h|0)){break}u=v+b+I>>1;if((u|0)<(p|0)){K=p}else{K=(u|0)>(j|0)?j:u}a[w]=a[1403376+((B|1024)-K)|0]|0}}while(0);B=q+1|0;if((B|0)<4){q=B;r=r+c|0}else{break}}return}function x$a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;i=-c|0;j=c*-3|0;k=c*-2|0;l=c<<1;m=c*-4|0;n=c*3|0;o=(h|0)==0;h=0;p=b;while(1){b=a[p]|0;q=b&255;r=p+i|0;s=a[r]|0;t=s&255;u=q-t|0;do{if(!(b<<24>>24==s<<24>>24)){v=(ca((u|0)>-1?u:-u|0,e)|0)>>7;if((v|0)>1){break}w=p+j|0;x=d[w]|0;y=p+k|0;z=d[y]|0;A=p+c|0;B=d[A]|0;C=h+g|0;D=d[616432+C|0]|0;E=t+q|0;F=((z+E|0)*26|0)+D+((B+x|0)*25|0)>>7;G=p+l|0;H=d[G]|0;I=d[616416+C|0]|0;C=I+((B+E|0)*26|0)+((H+z|0)*25|0)>>7;E=(v|0)!=0;do{if(E){v=t-f|0;J=t+f|0;if((F|0)<(v|0)){K=v}else{K=(F|0)>(J|0)?J:F}J=q-f|0;v=q+f|0;if((C|0)<(J|0)){L=J;M=K;break}L=(C|0)>(v|0)?v:C;M=K}else{L=C;M=F}}while(0);F=p+m|0;C=((z+x+M|0)*26|0)+D+(((d[F]|0)+q|0)*25|0)>>7;v=p+n|0;J=((H+B+L|0)*26|0)+I+(((d[v]|0)+t|0)*25|0)>>7;N=C&255;O=J&255;do{if(E){P=z-f|0;Q=z+f|0;if((C|0)<(P|0)){R=P&255}else{R=((C|0)>(Q|0)?Q:C)&255}Q=B-f|0;P=B+f|0;if((J|0)<(Q|0)){S=Q&255;T=R;break}S=((J|0)>(P|0)?P:J)&255;T=R}else{S=O;T=N}}while(0);a[y]=T;a[r]=M;a[p]=L;a[A]=S;if(!o){break}a[w]=(((d[r]|0)*25|0)+64+((d[w]|0)*51|0)+(((d[F]|0)+(d[y]|0)|0)*26|0)|0)>>>7;a[G]=(((d[p]|0)*25|0)+64+((d[G]|0)*51|0)+(((d[v]|0)+(d[A]|0)|0)*26|0)|0)>>>7}}while(0);r=h+1|0;if((r|0)<4){h=r;p=p+1|0}else{break}}return}function y$a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=(h|0)==0;h=0;j=b;while(1){b=a[j]|0;k=b&255;l=j-1|0;m=a[l]|0;n=m&255;o=k-n|0;do{if(!(b<<24>>24==m<<24>>24)){p=(ca((o|0)>-1?o:-o|0,e)|0)>>7;if((p|0)>1){break}q=j-3|0;r=d[q]|0;s=j-2|0;t=d[s]|0;u=j+1|0;v=d[u]|0;w=h+g|0;x=d[616432+w|0]|0;y=n+k|0;z=((t+y|0)*26|0)+x+((v+r|0)*25|0)>>7;A=j+2|0;B=d[A]|0;C=d[616416+w|0]|0;w=C+((v+y|0)*26|0)+((B+t|0)*25|0)>>7;y=(p|0)!=0;do{if(y){p=n-f|0;D=n+f|0;if((z|0)<(p|0)){E=p}else{E=(z|0)>(D|0)?D:z}D=k-f|0;p=k+f|0;if((w|0)<(D|0)){F=D;G=E;break}F=(w|0)>(p|0)?p:w;G=E}else{F=w;G=z}}while(0);z=d[j-4|0]|0;w=((t+r+G|0)*26|0)+x+((z+k|0)*25|0)>>7;p=d[j+3|0]|0;D=((B+v+F|0)*26|0)+C+((p+n|0)*25|0)>>7;H=w&255;I=D&255;do{if(y){J=t-f|0;K=t+f|0;if((w|0)<(J|0)){L=J&255}else{L=((w|0)>(K|0)?K:w)&255}K=v-f|0;J=v+f|0;if((D|0)<(K|0)){M=K&255;N=L;break}M=((D|0)>(J|0)?J:D)&255;N=L}else{M=I;N=H}}while(0);a[s]=N;a[l]=G;a[j]=F;a[u]=M;if(!i){break}a[q]=(((G&255)*25|0)+64+(r*51|0)+((z+(N&255)|0)*26|0)|0)>>>7;a[A]=(((F&255)*25|0)+64+(B*51|0)+((p+(M&255)|0)*26|0)|0)>>>7}}while(0);l=h+1|0;if((l|0)<4){h=l;j=j+c|0}else{break}}return}function z$a(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=b*-2|0;k=a+j|0;l=a+b|0;m=a+(j|1)|0;n=a+(b+1)|0;o=a+(j+2)|0;p=a+(b+2)|0;q=a+(j+3)|0;j=(d[k]|0)-(d[a+(-b|0)|0]|0)+(d[m]|0)-(d[a+(1-b)|0]|0)+(d[o]|0)-(d[a+(2-b)|0]|0)+(d[q]|0)-(d[a+(3-b)|0]|0)|0;r=a+(b+3)|0;s=(d[l]|0)-(d[a]|0)+(d[n]|0)-(d[a+1|0]|0)+(d[p]|0)-(d[a+2|0]|0)+(d[r]|0)-(d[a+3|0]|0)|0;t=e<<2;c[h>>2]=(((j|0)>-1?j:-j|0)|0)<(t|0);j=(((s|0)>-1?s:-s|0)|0)<(t|0);c[i>>2]=j&1;i=c[h>>2]|0;if((g|0)==0|((i|0)!=0|j)^1){u=0;return u|0}g=b*-3|0;h=b<<1;b=(d[k]|0)-(d[a+g|0]|0)+(d[m]|0)-(d[a+(g+1)|0]|0)+(d[o]|0)-(d[a+(g+2)|0]|0)+(d[q]|0)-(d[a+(g+3)|0]|0)|0;g=(d[l]|0)-(d[a+h|0]|0)+(d[n]|0)-(d[a+(h|1)|0]|0)+(d[p]|0)-(d[a+(h+2)|0]|0)+(d[r]|0)-(d[a+(h+3)|0]|0)|0;if((i|0)==0){v=0}else{v=(((b|0)>-1?b:-b|0)|0)<(f|0)}if(j){w=(((g|0)>-1?g:-g|0)|0)<(f|0)}else{w=0}u=v&w&1;return u|0}function A$a(a,b,e,f,g,h,i){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=a-2|0;k=a+1|0;l=a+(b-2)|0;m=a+(b+1)|0;n=b<<1;o=a+(n-2)|0;p=a+(n|1)|0;q=n+b|0;r=a+(q-2)|0;s=(d[j]|0)-(d[a-1|0]|0)+(d[l]|0)-(d[a+(b-1)|0]|0)+(d[o]|0)-(d[a+(n-1)|0]|0)+(d[r]|0)-(d[a+(q-1)|0]|0)|0;t=a+(q+1)|0;u=(d[k]|0)-(d[a]|0)+(d[m]|0)-(d[a+b|0]|0)+(d[p]|0)-(d[a+n|0]|0)+(d[t]|0)-(d[a+q|0]|0)|0;v=e<<2;c[h>>2]=(((s|0)>-1?s:-s|0)|0)<(v|0);s=(((u|0)>-1?u:-u|0)|0)<(v|0);c[i>>2]=s&1;i=c[h>>2]|0;if((g|0)==0|((i|0)!=0|s)^1){w=0;return w|0}g=(d[j]|0)-(d[a-3|0]|0)+(d[l]|0)-(d[a+(b-3)|0]|0)+(d[o]|0)-(d[a+(n-3)|0]|0)+(d[r]|0)-(d[a+(q-3)|0]|0)|0;r=(d[k]|0)-(d[a+2|0]|0)+(d[m]|0)-(d[a+(b+2)|0]|0)+(d[p]|0)-(d[a+(n+2)|0]|0)+(d[t]|0)-(d[a+(q+2)|0]|0)|0;if((i|0)==0){x=0}else{x=(((g|0)>-1?g:-g|0)|0)<(f|0)}if(s){y=(((r|0)>-1?r:-r|0)|0)<(f|0)}else{y=0}w=x&y&1;return w|0}function B$a(b,c,e,f,g,h,i,j){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((g|0)<=0){return}k=1<<j-1;l=c;c=b;b=0;while(1){m=l+3|0;n=l-1|0;o=l+2|0;p=ca(d[l]|0,h)|0;q=l+1|0;a[c]=a[((d[l-2|0]|0)+k+(d[m]|0)+(((d[o]|0)+(d[n]|0)|0)*-5|0)+p+(ca(d[q]|0,i)|0)>>j)+1404400|0]|0;p=l+4|0;r=ca(d[q]|0,h)|0;a[c+1|0]=a[((d[n]|0)+k+(d[p]|0)+(((d[m]|0)+(d[l]|0)|0)*-5|0)+r+(ca(d[o]|0,i)|0)>>j)+1404400|0]|0;r=l+5|0;n=ca(d[o]|0,h)|0;a[c+2|0]=a[((d[l]|0)+k+(d[r]|0)+(((d[p]|0)+(d[q]|0)|0)*-5|0)+n+(ca(d[m]|0,i)|0)>>j)+1404400|0]|0;n=l+6|0;s=ca(d[m]|0,h)|0;a[c+3|0]=a[((d[q]|0)+k+(d[n]|0)+(((d[r]|0)+(d[o]|0)|0)*-5|0)+s+(ca(d[p]|0,i)|0)>>j)+1404400|0]|0;s=l+7|0;q=ca(d[p]|0,h)|0;a[c+4|0]=a[((d[o]|0)+k+(d[s]|0)+(((d[n]|0)+(d[m]|0)|0)*-5|0)+q+(ca(d[r]|0,i)|0)>>j)+1404400|0]|0;q=l+8|0;o=ca(d[r]|0,h)|0;a[c+5|0]=a[((d[m]|0)+k+(d[q]|0)+(((d[s]|0)+(d[p]|0)|0)*-5|0)+o+(ca(d[n]|0,i)|0)>>j)+1404400|0]|0;o=l+9|0;m=ca(d[n]|0,h)|0;a[c+6|0]=a[((d[p]|0)+k+(d[o]|0)+(((d[q]|0)+(d[r]|0)|0)*-5|0)+m+(ca(d[s]|0,i)|0)>>j)+1404400|0]|0;m=ca(d[s]|0,h)|0;a[c+7|0]=a[((d[r]|0)+k+(d[l+10|0]|0)+(((d[o]|0)+(d[n]|0)|0)*-5|0)+m+(ca(d[q]|0,i)|0)>>j)+1404400|0]|0;q=b+1|0;if((q|0)<(g|0)){l=l+f|0;c=c+e|0;b=q}else{break}}return}function C$a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=f*-2|0;k=-f|0;l=f<<1;m=f*3|0;n=f<<2;o=f*5|0;p=f*6|0;q=f*7|0;r=f<<3;s=f*9|0;t=f*10|0;u=1<<i-1;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=0;C=c;c=b;while(1){b=d[C+k|0]|0;D=d[C]|0;E=d[C+f|0]|0;F=d[C+l|0]|0;G=d[C+m|0]|0;H=d[C+n|0]|0;I=d[C+o|0]|0;J=d[C+p|0]|0;K=d[C+q|0]|0;L=d[C+r|0]|0;M=d[C+s|0]|0;N=d[C+t|0]|0;a[c]=((d[c]|0)+1+(d[((d[C+j|0]|0)+u+(ca(D,g)|0)+(ca(E,h)|0)+G+((F+b|0)*-5|0)>>i)+1404400|0]|0)|0)>>>1;O=c+e|0;a[O]=((d[O]|0)+1+(d[(b+u+(ca(E,g)|0)+(ca(F,h)|0)+H+((G+D|0)*-5|0)>>i)+1404400|0]|0)|0)>>>1;b=c+v|0;a[b]=((d[b]|0)+1+(d[(D+u+(ca(F,g)|0)+(ca(G,h)|0)+I+((H+E|0)*-5|0)>>i)+1404400|0]|0)|0)>>>1;D=c+w|0;a[D]=((d[D]|0)+1+(d[(E+u+(ca(G,g)|0)+(ca(H,h)|0)+J+((I+F|0)*-5|0)>>i)+1404400|0]|0)|0)>>>1;E=c+x|0;a[E]=((d[E]|0)+1+(d[(F+u+(ca(H,g)|0)+(ca(I,h)|0)+K+((J+G|0)*-5|0)>>i)+1404400|0]|0)|0)>>>1;F=c+y|0;a[F]=((d[F]|0)+1+(d[(G+u+(ca(I,g)|0)+(ca(J,h)|0)+L+((K+H|0)*-5|0)>>i)+1404400|0]|0)|0)>>>1;G=c+z|0;a[G]=((d[G]|0)+1+(d[(H+u+(ca(J,g)|0)+(ca(K,h)|0)+M+((L+I|0)*-5|0)>>i)+1404400|0]|0)|0)>>>1;H=c+A|0;a[H]=((d[H]|0)+1+(d[(I+u+(ca(K,g)|0)+(ca(L,h)|0)+N+((M+J|0)*-5|0)>>i)+1404400|0]|0)|0)>>>1;J=B+1|0;if((J|0)<8){B=J;C=C+1|0;c=c+1|0}else{break}}return}function D$a(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=c;c=b;b=0;while(1){j=i+3|0;k=i-1|0;l=i+2|0;m=ca(d[i]|0,g)|0;n=i+1|0;a[c]=((d[c]|0)+1+(d[((d[i-2|0]|0)+32+(d[j]|0)+(((d[l]|0)+(d[k]|0)|0)*-5|0)+m+(ca(d[n]|0,h)|0)>>6)+1404400|0]|0)|0)>>>1;m=c+1|0;o=i+4|0;p=ca(d[n]|0,g)|0;a[m]=((d[m]|0)+1+(d[((d[k]|0)+32+(d[o]|0)+(((d[j]|0)+(d[i]|0)|0)*-5|0)+p+(ca(d[l]|0,h)|0)>>6)+1404400|0]|0)|0)>>>1;p=c+2|0;k=i+5|0;m=ca(d[l]|0,g)|0;a[p]=((d[p]|0)+1+(d[((d[i]|0)+32+(d[k]|0)+(((d[o]|0)+(d[n]|0)|0)*-5|0)+m+(ca(d[j]|0,h)|0)>>6)+1404400|0]|0)|0)>>>1;m=c+3|0;p=i+6|0;q=ca(d[j]|0,g)|0;a[m]=((d[m]|0)+1+(d[((d[n]|0)+32+(d[p]|0)+(((d[k]|0)+(d[l]|0)|0)*-5|0)+q+(ca(d[o]|0,h)|0)>>6)+1404400|0]|0)|0)>>>1;q=c+4|0;n=i+7|0;m=ca(d[o]|0,g)|0;a[q]=((d[q]|0)+1+(d[((d[l]|0)+32+(d[n]|0)+(((d[p]|0)+(d[j]|0)|0)*-5|0)+m+(ca(d[k]|0,h)|0)>>6)+1404400|0]|0)|0)>>>1;m=c+5|0;l=i+8|0;q=ca(d[k]|0,g)|0;a[m]=((d[m]|0)+1+(d[((d[j]|0)+32+(d[l]|0)+(((d[n]|0)+(d[o]|0)|0)*-5|0)+q+(ca(d[p]|0,h)|0)>>6)+1404400|0]|0)|0)>>>1;q=c+6|0;j=i+9|0;m=ca(d[p]|0,g)|0;a[q]=((d[q]|0)+1+(d[((d[o]|0)+32+(d[j]|0)+(((d[l]|0)+(d[k]|0)|0)*-5|0)+m+(ca(d[n]|0,h)|0)>>6)+1404400|0]|0)|0)>>>1;m=c+7|0;o=ca(d[n]|0,g)|0;a[m]=((d[m]|0)+1+(d[((d[k]|0)+32+(d[i+10|0]|0)+(((d[j]|0)+(d[p]|0)|0)*-5|0)+o+(ca(d[l]|0,h)|0)>>6)+1404400|0]|0)|0)>>>1;l=b+1|0;if((l|0)<8){i=i+f|0;c=c+e|0;b=l}else{break}}return}function E$a(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;j=f*-2|0;k=-f|0;l=f<<1;m=f*3|0;n=f<<2;o=f*5|0;p=f*6|0;q=f*7|0;r=f<<3;s=f*9|0;t=f*10|0;u=1<<i-1;v=e<<1;w=e*3|0;x=e<<2;y=e*5|0;z=e*6|0;A=e*7|0;B=0;C=c;c=b;while(1){b=d[C+k|0]|0;D=d[C]|0;E=d[C+f|0]|0;F=d[C+l|0]|0;G=d[C+m|0]|0;H=d[C+n|0]|0;I=d[C+o|0]|0;J=d[C+p|0]|0;K=d[C+q|0]|0;L=d[C+r|0]|0;M=d[C+s|0]|0;N=d[C+t|0]|0;a[c]=a[((d[C+j|0]|0)+u+(ca(D,g)|0)+(ca(E,h)|0)+G+((F+b|0)*-5|0)>>i)+1404400|0]|0;a[c+e|0]=a[(b+u+(ca(E,g)|0)+(ca(F,h)|0)+H+((G+D|0)*-5|0)>>i)+1404400|0]|0;a[c+v|0]=a[(D+u+(ca(F,g)|0)+(ca(G,h)|0)+I+((H+E|0)*-5|0)>>i)+1404400|0]|0;a[c+w|0]=a[(E+u+(ca(G,g)|0)+(ca(H,h)|0)+J+((I+F|0)*-5|0)>>i)+1404400|0]|0;a[c+x|0]=a[(F+u+(ca(H,g)|0)+(ca(I,h)|0)+K+((J+G|0)*-5|0)>>i)+1404400|0]|0;a[c+y|0]=a[(G+u+(ca(I,g)|0)+(ca(J,h)|0)+L+((K+H|0)*-5|0)>>i)+1404400|0]|0;a[c+z|0]=a[(H+u+(ca(J,g)|0)+(ca(K,h)|0)+M+((L+I|0)*-5|0)>>i)+1404400|0]|0;a[c+A|0]=a[(I+u+(ca(K,g)|0)+(ca(L,h)|0)+N+((M+J|0)*-5|0)>>i)+1404400|0]|0;J=B+1|0;if((J|0)<8){B=J;C=C+1|0;c=c+1|0}else{break}}return}function F$a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;k=c[h+24>>2]|0;l=h+28|0;h=c[l>>2]|0;if((h|0)<5){KIb(e,16,2446888,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=j;return n|0}o=k;p=je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0;o=p>>>14<<1&6;q=p>>>4<<2&12|16;if(((p>>>16)+4|0)!=(h|0)|q>>>0>24>>>0){KIb(e,16,2357600,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=j;return n|0}m=o+2|0;p=e+796|0;c[p>>2]=q;c[e+420>>2]=(q|0)==16?1:2;r=e+416|0;c[r>>2]=m;if((o|0)==2){s=e+448|0;c[s>>2]=51;c[s+4>>2]=0}else if((o|0)==4){s=e+448|0;c[s>>2]=63;c[s+4>>2]=0}else if((o|0)==0){s=e+448|0;c[s>>2]=3;c[s+4>>2]=0}else if((o|0)==6){o=e+448|0;c[o>>2]=1610612799;c[o+4>>2]=0}c[e+412>>2]=48e3;o=q+4|0;c[e+72>>2]=((48e3/((h<<3|0)/(ca(o,m)|0)|0|0)|0)<<5)+(ca(m*48e3|0,o)|0);q=k+4|0;k=o>>>2;o=f+76|0;c[o>>2]=(((h-4|0)/(k|0)|0)<<1|0)/(m|0)|0;m=M4a(e,f,0)|0;if((m|0)<0){n=m;i=j;return n|0}m=ca((ca(c[r>>2]|0,c[o>>2]|0)|0)/2|0,k)|0;k=c[p>>2]|0;do{if((k|0)==24){if((m|0)<=6){break}p=m;o=q;r=c[f>>2]|0;while(1){c[r>>2]=(d[1316536+(d[o+1|0]|0)|0]|0)<<16|(d[1316536+(d[o+2|0]|0)|0]|0)<<24|(d[1316536+(d[o]|0)|0]|0)<<8;c[r+4>>2]=(d[1316536+(d[o+5|0]|0)|0]|0)<<20|(d[1316536+(a[o+6|0]&240)|0]|0)<<28|(d[1316536+(d[o+4|0]|0)|0]|0)<<12|(d[1316536+(a[o+3|0]&15)|0]|0)<<4;e=p-7|0;if((e|0)>6){p=e;o=o+7|0;r=r+8|0}else{break}}}else{r=c[f>>2]|0;if((k|0)==20){if((m|0)<=5){break}o=m;p=q;e=r;while(1){c[e>>2]=(d[1316536+(d[p+1|0]|0)|0]|0)<<20|(d[1316536+(a[p+2|0]&240)|0]|0)<<28|(d[1316536+(d[p]|0)|0]|0)<<12;c[e+4>>2]=(d[1316536+(d[p+4|0]|0)|0]|0)<<20|(d[1316536+(a[p+5|0]&240)|0]|0)<<28|(d[1316536+(d[p+3|0]|0)|0]|0)<<12;h=o-6|0;if((h|0)>5){o=h;p=p+6|0;e=e+8|0}else{break}}}else{if((m|0)<=4){break}e=m;p=q;o=r;while(1){b[o>>1]=d[1316536+(d[p]|0)|0]|0|(d[1316536+(d[p+1|0]|0)|0]|0)<<8;b[o+2>>1]=(d[1316536+(d[p+3|0]|0)|0]|0)<<4|(d[1316536+(a[p+4|0]&240)|0]|0)<<12|(a[1316536+(d[p+2|0]|0)|0]&255)>>>4;h=e-5|0;if((h|0)>4){e=h;p=p+5|0;o=o+4|0}else{break}}}}}while(0);c[g>>2]=1;n=c[l>>2]|0;i=j;return n|0}function G$a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=c[b+60>>2]|0;f=b+416|0;g=c[f>>2]|0;if((g&1|0)!=0|(g|0)>8){KIb(b,16,2357512,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h;j=-22;i=d;return j|0}k=c[b+420>>2]|0;do{if((k|0)==1){c[b+796>>2]=16;l=g;m=20}else if((k|0)==2){n=b+796|0;o=c[n>>2]|0;if((o|0)>20){if((o|0)>24){KIb(b,24,2294440,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;p=c[f>>2]|0}else{p=g}c[n>>2]=24;l=p;m=28;break}else{if((o|0)==0){c[n>>2]=24;l=g;m=28;break}else{c[n>>2]=20;l=g;m=24;break}}}else{l=g;m=(c[b+796>>2]|0)+4|0}}while(0);c[b+424>>2]=0;c[b+72>>2]=ca(l*48e3|0,m)|0;a[e]=0;j=0;i=d;return j|0}function H$a(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0;i=c[d+60>>2]|0;j=g+76|0;k=d+416|0;l=ca(c[k>>2]|0,c[j>>2]|0)|0;m=d+796|0;n=(ca(l,(c[m>>2]|0)+4|0)|0)/8|0;l=n+4|0;o=d5a(d,f,l,(l|0)<0|0?-1:0)|0;if((o|0)<0){p=o;return p|0}o=c[f+24>>2]|0;f=je(((((c[k>>2]|0)+524286|0)>>>1|n<<2)<<10|(((c[m>>2]|0)-16|0)/4|0))<<4|0)|0;n=(l&268435456|0)!=0?0:o;y=f;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=o+4|0;o=c[m>>2]|0;a:do{if((o|0)==16){if((c[j>>2]|0)<=0){break}m=n;f=1;l=c[g>>2]|0;while(1){if((c[k>>2]|0)>0){d=(a[i]|0)==0?16:0;q=m;r=0;s=l;while(1){a[q]=a[1316536+(b[s>>1]&255)|0]|0;a[q+1|0]=a[1316536+((e[s>>1]|0)>>>8)|0]|0;t=s+2|0;a[q+2|0]=a[1316536+(e[t>>1]<<4&240)|0]|d;a[q+3|0]=a[1316536+((e[t>>1]|0)>>>4&255)|0]|0;a[q+4|0]=a[1316536+((e[t>>1]|0)>>>12)|0]|0;t=q+5|0;u=s+4|0;v=r+2|0;if((v|0)<(c[k>>2]|0)){q=t;r=v;s=u}else{w=t;x=u;break}}}else{w=m;x=l}s=(a[i]|0)+1&255;a[i]=(s&255)>>>0>191>>>0?0:s;if((f|0)>=(c[j>>2]|0)){break a}m=w;f=f+1|0;l=x}}else if((o|0)==20){if((c[j>>2]|0)<=0){break}l=n;f=c[g>>2]|0;m=1;while(1){if((c[k>>2]|0)>0){s=(a[i]|0)==0?128:0;r=l;q=0;d=f;while(1){a[r]=a[1316536+((c[d>>2]|0)>>>12&255)|0]|0;a[r+1|0]=a[1316536+((c[d>>2]|0)>>>20&255)|0]|0;a[r+2|0]=a[1316536+((c[d>>2]|0)>>>28|s)|0]|0;u=d+4|0;a[r+3|0]=a[1316536+((c[u>>2]|0)>>>12&255)|0]|0;a[r+4|0]=a[1316536+((c[u>>2]|0)>>>20&255)|0]|0;a[r+5|0]=a[1316536+((c[u>>2]|0)>>>28)|0]|0;u=r+6|0;t=d+8|0;v=q+2|0;if((v|0)<(c[k>>2]|0)){r=u;q=v;d=t}else{z=u;A=t;break}}}else{z=l;A=f}d=(a[i]|0)+1&255;a[i]=(d&255)>>>0>191>>>0?0:d;if((m|0)>=(c[j>>2]|0)){break a}l=z;f=A;m=m+1|0}}else if((o|0)==24){if((c[j>>2]|0)<=0){break}m=n;f=c[g>>2]|0;l=1;while(1){if((c[k>>2]|0)>0){d=(a[i]|0)==0?16:0;q=m;r=f;s=0;while(1){a[q]=a[1316536+((c[r>>2]|0)>>>8&255)|0]|0;a[q+1|0]=a[1316536+((c[r>>2]|0)>>>16&255)|0]|0;a[q+2|0]=a[1316536+((c[r>>2]|0)>>>24)|0]|0;t=r+4|0;a[q+3|0]=a[1316536+((c[t>>2]|0)>>>4&240)|0]|d;a[q+4|0]=a[1316536+((c[t>>2]|0)>>>12&255)|0]|0;a[q+5|0]=a[1316536+((c[t>>2]|0)>>>20&255)|0]|0;a[q+6|0]=a[1316536+((c[t>>2]|0)>>>28)|0]|0;t=q+7|0;u=r+8|0;v=s+2|0;if((v|0)<(c[k>>2]|0)){q=t;r=u;s=v}else{B=t;C=u;break}}}else{B=m;C=f}s=(a[i]|0)+1&255;a[i]=(s&255)>>>0>191>>>0?0:s;if((l|0)>=(c[j>>2]|0)){break a}m=B;f=C;l=l+1|0}}}while(0);c[h>>2]=1;p=0;return p|0}function I$a(a){a=a|0;var b=0;b=c[a+60>>2]|0;SFb(b,0,2048);SFb(b+1024|0,0,2048);SFb(b+2048|0,0,2048);return dmb(a)|0}function J$a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=d;m=c[f+24>>2]|0;n=c[b+60>>2]|0;o=f+28|0;if((m|0)==0){p=d+12|0;q=p;r=c[q>>2]|0;s=(r|0)!=0;t=s&1;c[e>>2]=t;u=c[o>>2]|0;i=g;return u|0}if((c[o>>2]|0)<=0){p=d+12|0;q=p;r=c[q>>2]|0;s=(r|0)!=0;t=s&1;c[e>>2]=t;u=c[o>>2]|0;i=g;return u|0}v=rJb(m)|0;m=n+1024|0;w=m;ZFb(w);c[h>>2]=0;x=BFb(v,2446880)|0;a:do{if((x|0)!=0){y=n+1028|0;z=n;A=x;b:while(1){B=a[A+2|0]|0;do{if(B<<24>>24==62){C=9}else{if((OFb(B<<24>>24)|0)!=0){C=9;break}D=A+1|0}}while(0);c:do{if((C|0)==9){C=0;if((c[y>>2]|0)!=0){UFb(w,2357504,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E}B=HFb(A,2294432,h)|0;if((B|0)==0){break a}F=c[h>>2]|0;if((F|0)==0){break a}if((BFb(B,2243416)|0)==0){if((BFb(B,2202016)|0)==0){G=w}else{C=15}}else{C=15}if((C|0)==15){C=0;ZFb(z);G=z}B=F;while(1){if((OFb(a[B]|0)|0)==0){break}else{B=B+1|0}}if((krc(B,2170240,6)|0)==0){break b}else{H=0;I=B}while(1){F=a[I]|0;if((F<<24>>24|0)==60){if((JFb(I,2446880,2)|0)==0){J=a[I+2|0]|0;if(J<<24>>24==62){D=I;break c}if((OFb(J<<24>>24)|0)!=0){D=I;break c}}if((JFb(I,2143088,3)|0)==0){UFb(G,2357504,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;K=I}else{K=I}while(1){J=K+1|0;L=a[J]|0;if((L<<24>>24|0)==0){D=J;break c}else if((L<<24>>24|0)==62){break}else{K=J}}J=K+2|0;M=J;N=a[J]|0}else if((F<<24>>24|0)==0){D=I;break c}else{M=I;N=F}do{if((OFb(N<<24>>24)|0)==0){WFb(G,a[M]|0,1)}else{if((H|0)!=0){break}WFb(G,32,1)}}while(0);H=OFb(a[M]|0)|0;I=M+1|0}}}while(0);c[h>>2]=0;A=BFb(D,2446880)|0;if((A|0)==0){break a}}kJb(v);p=d+12|0;q=p;r=c[q>>2]|0;s=(r|0)!=0;t=s&1;c[e>>2]=t;u=c[o>>2]|0;i=g;return u|0}}while(0);D=n+2048|0;h=D;ZFb(h);if((c[n+4>>2]|0)!=0){UFb(h,2119496,(E=i,i=i+8|0,c[E>>2]=c[n>>2],E)|0);i=E}UFb(h,2637720,(E=i,i=i+8|0,c[E>>2]=c[m>>2],E)|0);i=E;kJb(v);v=f+8|0;E=c[v>>2]|0;m=c[v+4>>2]|0;v=b+104|0;c[j>>2]=1;c[j+4>>2]=100;b=XIb(E,m,v,j)|0;j=c[f+48>>2]|0;if((j|0)==-1){O=-1}else{c[k>>2]=1;c[k+4>>2]=100;f=XIb(j,(j|0)<0|0?-1:0,v,k)|0;O=f}fmb(l,c[D>>2]|0,b,O,0)|0;p=d+12|0;q=p;r=c[q>>2]|0;s=(r|0)!=0;t=s&1;c[e>>2]=t;u=c[o>>2]|0;i=g;return u|0}function K$a(a){a=a|0;var b=0;b=c[a+60>>2]|0;_Fb(b,0)|0;_Fb(b+1024|0,0)|0;_Fb(b+2048|0,0)|0;return 0}function L$a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=a+100|0;g=(c[f>>2]|0)==0;h=e+16|0;c[h>>2]=g&1;c[a+140>>2]=g?44:11;g=c[a+120>>2]|0;j=c[a+124>>2]|0;c[e+2588>>2]=g;c[e+2592>>2]=j;c[e+2656>>2]=ca(j,g)|0;k=g+7&-8;c[e+2596>>2]=k;l=j+7&-8;c[e+2600>>2]=l;c[e+2660>>2]=ca(k<<1,l)|0;c[e+2584>>2]=g;if((Z$a(e)|0)!=0){KIb(a,16,2395672,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-12;i=b;return n|0}$$a(e+3184|0,1147472,1147456,4);$$a(e+7280|0,1147440,1147424,8);if((c[h>>2]|0)!=0){n=0;i=b;return n|0}if((c[f>>2]|0)<1026){KIb(a,16,2388448,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=b;return n|0}m=c[a+96>>2]|0;a=m;c[e+20>>2]=(d[a]|d[a+1|0]<<8)<<16>>16&65535;a=e+24|0;e=0;while(1){f=m+(e<<2|2)|0;c[a+(e<<2)>>2]=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|-16777216;f=e+1|0;if((f|0)<256){e=f}else{n=0;break}}i=b;return n|0}function M$a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0;j=i;k=c[e+60>>2]|0;l=k;m=k+2608|0;c[m>>2]=f;f=c[h+24>>2]|0;n=h+28|0;h=c[n>>2]|0;if(!((h|0)>-1)){KIb(0,0,2419296,(o=i,i=i+24|0,c[o>>2]=2410264,c[o+8>>2]=2402560,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}p=k+4|0;c[p>>2]=f;q=k+12|0;c[q>>2]=f;r=f+h|0;s=k+8|0;c[s>>2]=r;a:do{if((c[k+16>>2]|0)==0){do{if(h>>>0>7>>>0){t=e;u=k+24|0;v=u;w=k+2588|0;x=k+2592|0;z=k;A=k+2656|0;B=k+2596|0;C=k+2600|0;D=k+2660|0;E=k+2584|0;F=k+2612|0;G=k+2652|0;H=k+2620|0;I=k+2616|0;J=k+2632|0;K=k+2636|0;L=k+2604|0;M=k+1048|0;N=k+2624|0;O=0;P=f;Q=f;R=r;b:while(1){S=P+4|0;c[p>>2]=S;T=P;U=je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0;T=P+8|0;c[p>>2]=T;V=S;S=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;W=je(S|0)|0;V=T;X=V-Q|0;Y=R-V|0;if(Y>>>0<W>>>0){Z=7;break}c:do{if((U|0)==1481654604){if((W|0)==6|(W|0)==4){V=0;while(1){_=v+(V<<2)|0;$=c[_>>2]|0;aa=V*3|0;ba=(($>>>16&255)*129|0)+(b[M+(aa<<1)>>1]|0)>>7;if(ba>>>0>255>>>0){da=-ba>>31&255}else{da=ba&255}ba=(($>>>8&255)*129|0)+(b[M+(aa+1<<1)>>1]|0)>>7;if(ba>>>0>255>>>0){ea=-ba>>31&255}else{ea=ba&255}ba=(($&255)*129|0)+(b[M+(aa+2<<1)>>1]|0)>>7;if(ba>>>0>255>>>0){fa=-ba>>31&255}else{fa=ba&255}c[_>>2]=(da&255)<<16|(ea&255)<<8|fa&255|-16777216;_=V+1|0;if((_|0)<256){V=_}else{ga=O;break}}}else{if(W>>>0<1540>>>0){Z=187;break b}V=P+12|0;c[p>>2]=V;_=0;ba=V;while(1){c[p>>2]=ba+2;V=ba;b[M+(_<<1)>>1]=(d[V]|d[V+1|0]<<8)<<16>>16;V=_+1|0;if((V|0)>=768){break}_=V;ba=c[p>>2]|0}if(W>>>0>3843>>>0){ba=0;while(1){_=c[p>>2]|0;c[p>>2]=_+3;c[v+(ba<<2)>>2]=d[_]<<16|d[_+1|0]<<8|d[_+2|0]|-16777216;_=ba+1|0;if((_|0)<256){ba=_}else{ga=O;break}}}else{mrc(u|0,0,1024)|0;ga=O;break}}}else if((U|0)==1398034258){ga=1}else if((U|0)==1313882444){if((S|0)==196608){ha=0;ia=T}else{Z=10;break b}while(1){c[p>>2]=ia+3;c[v+(ha<<2)>>2]=d[ia]<<16|d[ia+1|0]<<8|d[ia+2|0]|-16777216;ba=ha+1|0;if((ba|0)>=256){ga=O;break c}ha=ba;ia=c[p>>2]|0}}else if((U|0)==1179599434){if(W>>>0<16>>>0){ja=-1094995529;Z=238;break b}ba=P+10|0;c[p>>2]=ba;_=T;ka=(d[_]|d[_+1|0]<<8)<<16>>16&65535;_=P+12|0;c[p>>2]=_;V=ba;ba=(d[V]|d[V+1|0]<<8)<<16>>16&65535;V=P+14|0;c[p>>2]=V;aa=_;_=(d[aa]|d[aa+1|0]<<8)<<16>>16&65535;aa=P+16|0;c[p>>2]=aa;$=V;V=(d[$]|d[$+1|0]<<8)<<16>>16;$=V&65535;la=P+18|0;c[p>>2]=la;ma=aa;aa=(d[ma]|d[ma+1|0]<<8)<<16>>16;ma=aa&65535;if(V<<16>>16==0|aa<<16>>16==0){Z=15;break b}V=c[w>>2]|0;na=$+ba|0;oa=(V|0)<(na|0);pa=c[x>>2]|0;qa=ma+_|0;ra=(pa|0)<(qa|0);if(oa|ra){sa=H4a(c[z>>2]|0,oa?na:V,ra?qa:pa)|0;if((sa|0)<0){ja=sa;Z=238;break b}sa=c[w>>2]|0;pa=(na|0)>(sa|0)?na:sa;sa=c[x>>2]|0;na=(qa|0)>(sa|0)?qa:sa;c[w>>2]=pa;c[x>>2]=na;c[A>>2]=ca(na,pa)|0;sa=pa+7&-8;c[B>>2]=sa;qa=na+7&-8;c[C>>2]=qa;c[D>>2]=ca(sa<<1,qa)|0;c[E>>2]=pa;if((Z$a(l)|0)!=0){Z=20;break b}ta=c[p>>2]|0;ua=c[s>>2]|0}else{ta=la;ua=R}la=ua;pa=la-ta|0;qa=pa>>>0>4>>>0?4:pa;pa=ta+qa|0;c[p>>2]=pa;if((ka|0)==37){sa=c[E>>2]|0;if((la-pa|0)<1){va=0;wa=pa}else{na=ta+(qa+1)|0;c[p>>2]=na;va=d[pa]|0;wa=na}if((la-wa|0)<1){xa=0;ya=wa}else{na=wa+1|0;c[p>>2]=na;xa=d[wa]|0;ya=na}if((la-ya|0)<2){za=0;Aa=ya}else{na=ya+2|0;c[p>>2]=na;ra=ya;za=(d[ra]|d[ra+1|0]<<8)<<16>>16&1;Aa=na}if((la-Aa|0)<4){Ba=0;Ca=Aa}else{na=Aa+4|0;c[p>>2]=na;ra=Aa;Ba=d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0;Ca=na}na=la-Ca|0;ra=na>>>0>4>>>0?4:na;na=Ca+ra|0;c[p>>2]=na;if((la-na|0)<1){Da=0;Ea=na}else{V=Ca+(ra+1)|0;c[p>>2]=V;Da=d[na]|0;Ea=V}V=la-Ea|0;c[p>>2]=Ea+(V>>>0>3>>>0?3:V);V=ca(sa,_)|0;na=(ca(c[x>>2]|0,sa)|0)-ba-V|0;if(Ba>>>0>na>>>0){KIb(c[z>>2]|0,24,2477520,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;Fa=na}else{Fa=Ba}c[G>>2]=0;if((za|0)==0){if((Da&1|0)==0){Z=56}}else{Z=56}do{if((Z|0)==56){Z=0;if((va|0)==2|(va|0)==0){break}na=c[F>>2]|0;c[F>>2]=c[H>>2];c[H>>2]=na}}while(0);na=V+ba|0;ra=(c[F>>2]|0)+na|0;oa=(c[H>>2]|0)+na|0;if(xa>>>0>2>>>0){Z=59;break b}if((va|0)==3|(va|0)==4){na=sa<<2;Ga=(va|0)==4;Ha=xa*255|0;Ia=sa<<1;Ja=sa*3|0;if((Da&4|0)==0){Ka=ra;La=oa;Ma=0;Na=0;while(1){Oa=Ma;Pa=0;while(1){d:do{if((Oa|0)==0){Qa=c[s>>2]|0;Ra=c[p>>2]|0;Sa=Qa;do{if((Sa-Ra|0)<1){Ta=0;Ua=Ra}else{Va=Ra+1|0;c[p>>2]=Va;Wa=a[Ra]|0;if(!(Wa<<24>>24==-1)){Ta=Wa&255;Ua=Va;break}if((Sa-Va|0)>>>0<16>>>0){ja=-1094995529;Z=238;break b}Wa=Va;Va=Ka+Pa|0;y=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;Va=(c[p>>2]|0)+4|0;c[p>>2]=Va;Wa=Va;Va=Ka+(Pa+sa)|0;y=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;Va=(c[p>>2]|0)+4|0;c[p>>2]=Va;Wa=Va;Va=Ka+(Pa+Ia)|0;y=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;Va=(c[p>>2]|0)+4|0;c[p>>2]=Va;Wa=Va;Va=Ka+(Pa+Ja)|0;y=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;Xa=Pa;Ya=0;break d}}while(0);if(Ga&(Ta|0)==0){if((Qa|0)==(Ua|0)){ja=-1094995529;Z=238;break b}c[p>>2]=Ua+1;Xa=Pa-4|0;Ya=(d[Ua]|0)+1|0;break}Sa=Ta+Ha<<1;Ra=a[1897152+(Sa|1)|0]|0;Va=(a[1897152+Sa|0]|0)+Pa|0;Sa=La+((ca(Ra,sa)|0)+Va)|0;Wa=ca(c[x>>2]|0,sa)|0;Za=Sa;Sa=Ka+Pa|0;_a=(ca(Ra+Na|0,sa)|0)+Va|0;Va=0;while(1){if((_a|0)>-1&(_a|0)<(Wa|0)){$a=a[Za]|0}else{$a=0}a[Sa]=$a;Ra=_a+1|0;if((Ra|0)>-1&(Ra|0)<(Wa|0)){a[Sa+1|0]=a[Za+1|0]|0}else{a[Sa+1|0]=0}Ra=_a+2|0;if((Ra|0)>-1&(Ra|0)<(Wa|0)){a[Sa+2|0]=a[Za+2|0]|0}else{a[Sa+2|0]=0}Ra=_a+3|0;if((Ra|0)>-1&(Ra|0)<(Wa|0)){a[Sa+3|0]=a[Za+3|0]|0}else{a[Sa+3|0]=0}Ra=Va+1|0;if((Ra|0)<4){Za=Za+sa|0;Sa=Sa+sa|0;_a=_a+sa|0;Va=Ra}else{Xa=Pa;Ya=0;break}}}else{Va=La+Pa|0;_a=Ka+Pa|0;y=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;_a=Pa+sa|0;Va=La+_a|0;Sa=Ka+_a|0;y=d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;Sa=_a+sa|0;_a=La+Sa|0;Va=Ka+Sa|0;y=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[Va]=y;y=y>>8;a[Va+1|0]=y;y=y>>8;a[Va+2|0]=y;y=y>>8;a[Va+3|0]=y;Va=Sa+sa|0;Sa=La+Va|0;_a=Ka+Va|0;y=d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0;a[_a]=y;y=y>>8;a[_a+1|0]=y;y=y>>8;a[_a+2|0]=y;y=y>>8;a[_a+3|0]=y;Xa=Pa;Ya=Oa-1|0}}while(0);_a=Xa+4|0;if((_a|0)<($|0)){Oa=Ya;Pa=_a}else{break}}Pa=Na+4|0;if((Pa|0)<(ma|0)){Ka=Ka+na|0;La=La+na|0;Ma=Ya;Na=Pa}else{ga=O;break c}}}else{ab=ra;bb=oa;cb=0;db=0}while(1){Na=cb;Ma=0;while(1){do{if((Na|0)==0){La=c[p>>2]|0;Ka=c[s>>2]|0;if((Ka|0)==(La|0)){ja=-1094995529;Z=238;break b}V=La+1|0;c[p>>2]=V;Pa=a[La]|0;Oa=Pa&255;if((Oa|0)==253){if((Ka|0)==(V|0)){ja=-1094995529;Z=238;break b}c[p>>2]=La+2;_a=a[V]|0;mrc(ab+Ma|0,_a|0,4)|0;mrc(ab+(Ma+sa)|0,_a|0,4)|0;mrc(ab+(Ma+Ia)|0,_a|0,4)|0;mrc(ab+(Ma+Ja)|0,_a|0,4)|0;eb=Ma;fb=0;break}else if((Oa|0)==255){if((Ka-V|0)>>>0<16>>>0){ja=-1094995529;Z=238;break b}_a=V;Sa=ab+Ma|0;y=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;Sa=(c[p>>2]|0)+4|0;c[p>>2]=Sa;_a=Sa;Sa=ab+(Ma+sa)|0;y=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;Sa=(c[p>>2]|0)+4|0;c[p>>2]=Sa;_a=Sa;Sa=ab+(Ma+Ia)|0;y=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;Sa=(c[p>>2]|0)+4|0;c[p>>2]=Sa;_a=Sa;Sa=ab+(Ma+Ja)|0;y=d[_a]|d[_a+1|0]<<8|d[_a+2|0]<<16|d[_a+3|0]<<24|0;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;eb=Ma;fb=0;break}else if((Oa|0)==254){if((Ka-V|0)>>>0<4>>>0){ja=-1094995529;Z=238;break b}c[p>>2]=La+2;mrc(ab+Ma|0,a[V]|0,4)|0;Sa=c[p>>2]|0;c[p>>2]=Sa+1;mrc(ab+(Ma+sa)|0,a[Sa]|0,4)|0;Sa=c[p>>2]|0;c[p>>2]=Sa+1;mrc(ab+(Ma+Ia)|0,a[Sa]|0,4)|0;Sa=c[p>>2]|0;c[p>>2]=Sa+1;mrc(ab+(Ma+Ja)|0,a[Sa]|0,4)|0;eb=Ma;fb=0;break}else{if(Ga&Pa<<24>>24==0){if((Ka|0)==(V|0)){ja=-1094995529;Z=238;break b}c[p>>2]=La+2;eb=Ma-4|0;fb=(d[V]|0)+1|0;break}V=Oa+Ha<<1;Oa=a[1897152+(V|1)|0]|0;La=(a[1897152+V|0]|0)+Ma|0;V=bb+((ca(Oa,sa)|0)+La)|0;Ka=ca(c[x>>2]|0,sa)|0;Pa=V;V=ab+Ma|0;Sa=(ca(Oa+db|0,sa)|0)+La|0;La=0;while(1){if((Sa|0)>-1&(Sa|0)<(Ka|0)){gb=a[Pa]|0}else{gb=0}a[V]=gb;Oa=Sa+1|0;if((Oa|0)>-1&(Oa|0)<(Ka|0)){a[V+1|0]=a[Pa+1|0]|0}else{a[V+1|0]=0}Oa=Sa+2|0;if((Oa|0)>-1&(Oa|0)<(Ka|0)){a[V+2|0]=a[Pa+2|0]|0}else{a[V+2|0]=0}Oa=Sa+3|0;if((Oa|0)>-1&(Oa|0)<(Ka|0)){a[V+3|0]=a[Pa+3|0]|0}else{a[V+3|0]=0}Oa=La+1|0;if((Oa|0)<4){Pa=Pa+sa|0;V=V+sa|0;Sa=Sa+sa|0;La=Oa}else{eb=Ma;fb=0;break}}}}else{La=bb+Ma|0;Sa=ab+Ma|0;y=d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;Sa=Ma+sa|0;La=bb+Sa|0;V=ab+Sa|0;y=d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;V=Sa+sa|0;Sa=bb+V|0;La=ab+V|0;y=d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0;a[La]=y;y=y>>8;a[La+1|0]=y;y=y>>8;a[La+2|0]=y;y=y>>8;a[La+3|0]=y;La=V+sa|0;V=bb+La|0;Sa=ab+La|0;y=d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0;a[Sa]=y;y=y>>8;a[Sa+1|0]=y;y=y>>8;a[Sa+2|0]=y;y=y>>8;a[Sa+3|0]=y;eb=Ma;fb=Na-1|0}}while(0);Sa=eb+4|0;if((Sa|0)<($|0)){Na=fb;Ma=Sa}else{break}}Ma=db+4|0;if((Ma|0)<(ma|0)){ab=ab+na|0;bb=bb+na|0;cb=fb;db=Ma}else{ga=O;break}}}else if((va|0)==2){e:do{if((Fa|0)>0){na=ra;Ha=Fa;while(1){Ga=c[s>>2]|0;Ja=c[p>>2]|0;Ia=Ga;if((Ia-Ja|0)<1){hb=0;ib=Ja}else{oa=Ja+1|0;c[p>>2]=oa;hb=d[Ja]|0;ib=oa}oa=(hb>>>1)+1|0;if((oa|0)>(Ha|0)){ja=-1094995529;Z=238;break b}Ja=Ia-ib|0;if((Ga|0)==(ib|0)){ja=-1094995529;Z=238;break b}if((hb&1|0)==0){if(Ja>>>0<oa>>>0){ja=-1094995529;Z=238;break b}nrc(na|0,ib|0,oa)|0;c[p>>2]=(c[p>>2]|0)+oa}else{if((Ja|0)<1){jb=0}else{c[p>>2]=ib+1;jb=a[ib]|0}mrc(na|0,jb|0,oa|0)|0}Ja=Ha-oa|0;if((Ja|0)<=0){break e}na=na+oa|0;Ha=Ja}}}while(0);mrc(c[I>>2]|0,0,c[J>>2]|0)|0;mrc(c[H>>2]|0,0,c[K>>2]|0)|0;ga=O;break}else if((va|0)==0){Ha=c[p>>2]|0;na=(c[s>>2]|0)-Ha|0;Ja=na>>>0>$>>>0?$:na;nrc(ra|0,Ha|0,Ja)|0;Ha=(c[p>>2]|0)+Ja|0;c[p>>2]=Ha;if((aa&65535)>>>0>1>>>0){Ja=1;na=ra;oa=Ha;do{na=na+sa|0;Ja=Ja+1|0;Ha=(c[s>>2]|0)-oa|0;Ga=Ha>>>0>$>>>0?$:Ha;nrc(na|0,oa|0,Ga)|0;oa=(c[p>>2]|0)+Ga|0;c[p>>2]=oa;}while((Ja|0)<(ma|0))}mrc(c[I>>2]|0,0,ca(c[x>>2]|0,sa)|0)|0;mrc(c[H>>2]|0,0,ca(c[x>>2]|0,sa)|0)|0;ga=O;break}else{Z=133;break b}}else if((ka|0)==47){Ja=c[E>>2]|0;oa=ca(Ja,_)|0;na=(c[F>>2]|0)+(oa+ba)|0;ra=c[I>>2]|0;aa=c[H>>2]|0;Ga=pa;Ha=c[q>>2]|0;if((la-Ga|0)<2){kb=0;lb=pa}else{Ia=ta+(qa+2)|0;c[p>>2]=Ia;Ma=pa;kb=(d[Ma]|d[Ma+1|0]<<8)<<16>>16&65535;lb=Ia}if((la-lb|0)<1){mb=0;nb=lb}else{Ia=lb+1|0;c[p>>2]=Ia;mb=d[lb]|0;nb=Ia}if((la-nb|0)<1){ob=0;pb=nb}else{Ia=nb+1|0;c[p>>2]=Ia;ob=d[nb]|0;pb=Ia}if((la-pb|0)<1){qb=0;rb=pb}else{Ia=pb+1|0;c[p>>2]=Ia;qb=a[pb]&1;rb=Ia}Ia=la-rb|0;Ma=Ia>>>0>9>>>0?9:Ia;Ia=rb+Ma|0;c[p>>2]=Ia;if((la-Ia|0)<4){sb=0;tb=Ia}else{Na=rb+(Ma+4)|0;c[p>>2]=Na;Ma=Ia;sb=d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0;tb=Na}Na=la-tb|0;c[p>>2]=tb+(Na>>>0>8>>>0?8:Na);Na=(ca(c[x>>2]|0,Ja)|0)-ba-oa|0;if(sb>>>0>Na>>>0){KIb(c[z>>2]|0,24,2477520,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ub=Na}else{ub=sb}if((qb|0)!=0){Na=c[p>>2]|0;oa=(c[s>>2]|0)-Na|0;c[p>>2]=Na+(oa>>>0>32896>>>0?32896:oa)}if((kb|0)==0){c[L>>2]=-1;mrc(ra|0,0,ca(c[x>>2]|0,Ja)|0)|0;mrc(aa|0,0,ca(c[x>>2]|0,Ja)|0)|0}f:do{switch(mb|0){case 0:{oa=c[p>>2]|0;if(((c[s>>2]|0)-oa|0)>>>0<(ca(ma,$)|0)>>>0){ja=-1094995529;Z=238;break b}else{vb=0;wb=na;xb=oa}while(1){nrc(wb|0,xb|0,$)|0;oa=(c[p>>2]|0)+$|0;c[p>>2]=oa;Na=vb+1|0;if((Na|0)<(ma|0)){vb=Na;wb=wb+Ja|0;xb=oa}else{break}}break};case 4:{nrc(c[F>>2]|0,c[I>>2]|0,ca(c[x>>2]|0,c[E>>2]|0)|0)|0;break};case 5:{if((ub|0)>0){yb=na;zb=ub}else{break f}while(1){oa=c[s>>2]|0;Na=c[p>>2]|0;Ma=oa;if((Ma-Na|0)<1){Ab=0;Bb=Na}else{Ia=Na+1|0;c[p>>2]=Ia;Ab=d[Na]|0;Bb=Ia}Ia=(Ab>>>1)+1|0;if((Ia|0)>(zb|0)){ja=-1094995529;Z=238;break b}Na=Ma-Bb|0;if((oa|0)==(Bb|0)){ja=-1094995529;Z=238;break b}if((Ab&1|0)==0){if(Na>>>0<Ia>>>0){ja=-1094995529;Z=238;break b}nrc(yb|0,Bb|0,Ia)|0;c[p>>2]=(c[p>>2]|0)+Ia}else{if((Na|0)<1){Cb=0}else{c[p>>2]=Bb+1;Cb=a[Bb]|0}mrc(yb|0,Cb|0,Ia|0)|0}Na=zb-Ia|0;if((Na|0)<=0){break f}yb=yb+Ia|0;zb=Na}break};case 2:{if((kb|0)!=((c[L>>2]|0)+1|0)){break f}Na=Ga+8-Ha|0;Ia=Ja<<3;oa=0;Ma=na;Sa=ra;V=aa;while(1){La=0;while(1){if((La|0)>=($|0)){break}if((_$a(l,Ma+La|0,Sa+La|0,V+La|0,Ja,Na,8)|0)==0){La=La+8|0}else{ja=-1094995529;Z=238;break b}}La=oa+8|0;if((La|0)<(ma|0)){oa=La;Ma=Ma+Ia|0;Sa=Sa+Ia|0;V=V+Ia|0}else{break}}break};case 3:{nrc(c[F>>2]|0,c[H>>2]|0,ca(c[x>>2]|0,c[E>>2]|0)|0)|0;break};case 1:{if(((c[s>>2]|0)-(c[p>>2]|0)|0)>>>0<(ca((ma+1|0)>>>1,($+1|0)>>>1)|0)>>>0){ja=-1094995529;Z=238;break b}Ia=Ja<<1;V=0;Sa=na;while(1){Ma=0;do{oa=c[p>>2]|0;c[p>>2]=oa+1;Na=a[oa]|0;oa=Ma+Ja|0;a[Sa+(oa+1)|0]=Na;a[Sa+oa|0]=Na;a[Sa+(Ma|1)|0]=Na;a[Sa+Ma|0]=Na;Ma=Ma+2|0;}while((Ma|0)<($|0));Ma=V+2|0;if((Ma|0)<(ma|0)){V=Ma;Sa=Sa+Ia|0}else{break}}break};default:{Z=179;break b}}}while(0);c[G>>2]=(kb|0)==((c[L>>2]|0)+1|0)?ob:0;c[L>>2]=kb;ga=O;break}else if((ka|0)==1|(ka|0)==3){Ja=c[E>>2]|0;if((la-pa|0)>>>0<2>>>0){ja=-1094995529;Z=238;break b}na=(c[F>>2]|0)+((ca(Ja,_)|0)+ba)|0;aa=Ja;Ja=pa;ra=na;na=1;Ha=ua;Ga=c[q>>2]|0;while(1){qa=Ja+2|0;c[p>>2]=qa;sa=Ja;Ia=qa;Sa=Ia-Ga|0;V=Sa+((d[sa]|d[sa+1|0]<<8)<<16>>16&65535)|0;if((Sa|0)<(V|0)){Sa=Ha;if((Sa-Ia|0)>>>0<2>>>0){ja=-1094995529;Z=238;break b}else{Db=qa;Eb=0;Fb=Sa}while(1){Sa=Db+1|0;c[p>>2]=Sa;Ia=d[Db]|0;sa=Ia>>>1;Ma=sa+1|0;Na=Ma+Eb|0;if((Na|0)>($|0)){ja=-1094995529;Z=238;break b}do{if((Ia&1|0)==0){if((Fb-Sa|0)>>>0<Ma>>>0){ja=-1094995529;Z=238;break b}else{Gb=1;Hb=Eb;Ib=Sa}while(1){c[p>>2]=Ib+1;oa=a[Ib]|0;if(!(oa<<24>>24==0)){a[ra+Hb|0]=oa}if((Gb|0)>=(Ma|0)){break}Gb=Gb+1|0;Hb=Hb+1|0;Ib=c[p>>2]|0}Jb=Eb+1+sa|0}else{c[p>>2]=Db+2;oa=a[Sa]|0;if(oa<<24>>24==0){Jb=Na;break}mrc(ra+Eb|0,oa|0,Ma|0)|0;Jb=Na}}while(0);Kb=c[p>>2]|0;Lb=c[q>>2]|0;Na=Kb;if((Na-Lb|0)>=(V|0)){break}Ma=c[s>>2]|0;if((Ma-Na|0)>>>0<2>>>0){ja=-1094995529;Z=238;break b}else{Db=Kb;Eb=Jb;Fb=Ma}}Mb=Kb;Nb=c[E>>2]|0;Ob=Lb}else{Mb=qa;Nb=aa;Ob=Ga}if((na|0)>=(ma|0)){break}V=c[s>>2]|0;if((V-Mb|0)>>>0<2>>>0){ja=-1094995529;Z=238;break b}else{aa=Nb;Ja=Mb;ra=ra+Nb|0;na=na+1|0;Ha=V;Ga=Ob}}c[G>>2]=0;ga=O;break}else{Z=181;break b}}else if((U|0)==1179927368){nrc(c[F>>2]|0,c[N>>2]|0,c[D>>2]|0)|0;ga=O}else{c[p>>2]=P+((Y>>>0>W>>>0?W:Y)+8);KIb(t,48,2243368,(o=i,i=i+8|0,c[o>>2]=U,o)|0);i=o;ga=O}}while(0);U=X+W|0;Y=c[s>>2]|0;T=c[q>>2]|0;S=Y;Ga=S-T|0;if((U|0)<0){Pb=0}else{Pb=(Ga|0)<(U|0)?Ga:U}U=T+Pb|0;if((W&1|0)==0){Qb=U}else{Ga=S-U|0;Qb=T+((Ga>>>0>1>>>0?1:Ga)+Pb)|0}c[p>>2]=Qb;if((S-Qb|0)>>>0>7>>>0){O=ga;P=Qb;Q=T;R=Y}else{Rb=ga;break}}if((Z|0)==7){KIb(t,16,2446832,(o=i,i=i+8|0,c[o>>2]=W,o)|0);i=o;Rb=O}else if((Z|0)==10){KIb(t,16,2357432,(o=i,i=i+8|0,c[o>>2]=W,o)|0);i=o;ja=-1094995529;i=j;return ja|0}else if((Z|0)==15){KIb(c[z>>2]|0,16,2515064,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ja=-1094995529;i=j;return ja|0}else if((Z|0)==20){KIb(c[z>>2]|0,16,2501208,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ja=-12;i=j;return ja|0}else if((Z|0)==59){KIb(c[z>>2]|0,16,2441456,(o=i,i=i+8|0,c[o>>2]=xa,o)|0);i=o;ja=-1094995529;i=j;return ja|0}else if((Z|0)==133){KIb(c[z>>2]|0,16,2429744,(o=i,i=i+8|0,c[o>>2]=va,o)|0);i=o;ja=-1163346256;i=j;return ja|0}else if((Z|0)==179){KIb(c[z>>2]|0,16,2467976,(o=i,i=i+8|0,c[o>>2]=mb,o)|0);i=o;ja=-1163346256;i=j;return ja|0}else if((Z|0)==181){QIb(c[z>>2]|0,2488440,(o=i,i=i+8|0,c[o>>2]=ka,o)|0);i=o;ja=-1163346256;i=j;return ja|0}else if((Z|0)==187){KIb(t,16,2294368,(o=i,i=i+8|0,c[o>>2]=W,o)|0);i=o;ja=-1094995529;i=j;return ja|0}else if((Z|0)==238){i=j;return ja|0}if((Rb|0)==0){Z=202;break}R=k+2612|0;nrc(c[k+2624>>2]|0,c[R>>2]|0,c[k+2660>>2]|0)|0;Sb=R}else{Z=202}}while(0);if((Z|0)==202){Sb=k+2612|0}R=c[Sb>>2]|0;Q=c[k+2592>>2]|0;P=c[k+2584>>2]|0;D=M4a(c[k>>2]|0,c[m>>2]|0,0)|0;if((D|0)<0){ja=D;i=j;return ja|0}D=c[m>>2]|0;N=c[D+32>>2]|0;if((Q|0)==0){Tb=D}else{F=R;R=c[D>>2]|0;D=Q;while(1){Q=D-1|0;nrc(R|0,F|0,P)|0;if((Q|0)==0){break}else{F=F+P|0;R=R+N|0;D=Q}}Tb=c[m>>2]|0}nrc(c[Tb+4>>2]|0,k+24|0,1024)|0;Ub=k+2652|0}else{D=r;if((h|0)<560){KIb(c[k>>2]|0,16,2548240,(o=i,i=i+8|0,c[o>>2]=h,o)|0);i=o;ja=-1094995529;i=j;return ja|0}N=f+12|0;c[p>>2]=N;R=f+8|0;P=d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0;R=f+16|0;c[p>>2]=R;do{if((P|0)==(c[k+2588>>2]|0)){F=N;Q=k+2592|0;if((d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)!=(c[Q>>2]|0)){break}F=f+18|0;c[p>>2]=F;G=R;E=(d[G]|d[G+1|0]<<8)<<16>>16;G=f+19|0;c[p>>2]=G;L=a[F]|0;F=f+20|0;c[p>>2]=F;x=a[G]|0;G=D-F|0;F=G>>>0>4>>>0?4:G;G=f+(F+22)|0;c[p>>2]=G;H=f+(F+20)|0;b[k+3176>>1]=(d[H]|d[H+1|0]<<8)<<16>>16;H=f+(F+24)|0;c[p>>2]=H;I=G;b[k+3178>>1]=(d[I]|d[I+1|0]<<8)<<16>>16;I=f+(F+26)|0;c[p>>2]=I;G=H;b[k+3180>>1]=(d[G]|d[G+1|0]<<8)<<16>>16;G=f+(F+28)|0;c[p>>2]=G;H=I;b[k+3182>>1]=(d[H]|d[H+1|0]<<8)<<16>>16;H=F+30|0;F=f+H|0;c[p>>2]=F;I=G;G=(d[I]|d[I+1|0]<<8)<<16>>16;I=D-F|0;F=(I>>>0>2>>>0?6:I+4|0)+H|0;H=f+(F+2)|0;c[p>>2]=H;I=f+F|0;b[k+2664>>1]=(d[I]|d[I+1|0]<<8)<<16>>16;I=1;F=H;while(1){c[p>>2]=F+2;H=F;b[l+2664+(I<<1)>>1]=(d[H]|d[H+1|0]<<8)<<16>>16;H=I+1|0;if((H|0)>=256){break}I=H;F=c[p>>2]|0}F=L&255;I=c[p>>2]|0;t=(c[s>>2]|0)-I|0;c[p>>2]=I+(t>>>0>8>>>0?8:t);t=k+2652|0;c[t>>2]=x&255;I=E<<16>>16==0;z=c[m>>2]|0;c[z+84>>2]=I&1;O=z+88|0;do{if(I){c[O>>2]=1;z=c[k+2656>>2]|0;if((z|0)==0){break}H=z;K=c[k+2616>>2]|0;while(1){J=H-1|0;b[K>>1]=G;if((J|0)==0){break}else{H=J;K=K+2|0}}K=z;H=c[k+2620>>2]|0;while(1){X=K-1|0;b[H>>1]=G;if((X|0)==0){break}else{K=X;H=H+2|0}}}else{c[O>>2]=2}}while(0);if(!((L&255)>>>0<9>>>0)){QIb(e,2170224,(o=i,i=i+8|0,c[o>>2]=F,o)|0);i=o;ja=-1163346256;i=j;return ja|0}O=ve[c[282296+(F<<2)>>2]&4095](l)|0;if((O|0)!=0){KIb(e,16,2201976,(o=i,i=i+8|0,c[o>>2]=F,o)|0);i=o;ja=O;i=j;return ja|0}O=c[k+2612>>2]|0;G=c[Q>>2]|0;I=c[k+2584>>2]<<1;E=M4a(c[k>>2]|0,c[m>>2]|0,0)|0;if((E|0)<0){ja=E;i=j;return ja|0}E=c[m>>2]|0;x=c[E+32>>2]|0;if((G|0)==0){Ub=t;break a}H=O;O=c[E>>2]|0;E=G;while(1){G=E-1|0;nrc(O|0,H|0,I)|0;if((G|0)==0){Ub=t;break a}else{H=H+I|0;O=O+x|0;E=G}}}}while(0);KIb(c[k>>2]|0,16,2530296,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;ja=-1163346256;i=j;return ja|0}}while(0);o=c[Ub>>2]|0;if((o|0)!=0){Ub=k+2620|0;m=c[Ub>>2]|0;if((o|0)==2){o=k+2616|0;e=c[o>>2]|0;c[Ub>>2]=e;c[o>>2]=m;Vb=e}else{Vb=m}m=k+2612|0;k=c[m>>2]|0;c[m>>2]=Vb;c[Ub>>2]=k}c[g>>2]=1;ja=c[n>>2]|0;i=j;return ja|0}function N$a(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+2612|0);mJb(b+2616|0);mJb(b+2620|0);mJb(b+2624|0);mJb(b+2644|0);c[b+2636>>2]=0;c[b+2632>>2]=0;c[b+2628>>2]=0;return 0}function O$a(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=c[a+2612>>2]|0;g=a+4|0;h=c[g>>2]|0;j=c[a+2588>>2]|0;k=c[a+2592>>2]|0;if(((c[a+8>>2]|0)-h|0)>>>0<(ca(j<<1,k)|0)>>>0){KIb(c[a>>2]|0,16,2566360,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-1094995529;i=e;return m|0}if((k|0)<=0){m=0;i=e;return m|0}l=a+2584|0;a=f;f=0;n=h;while(1){if((j|0)>0){h=0;o=n;while(1){p=o+2|0;c[g>>2]=p;q=o;b[a+(h<<1)>>1]=(d[q]|d[q+1|0]<<8)<<16>>16;q=h+1|0;if((q|0)<(j|0)){h=q;o=p}else{r=p;break}}}else{r=n}o=f+1|0;if((o|0)<(k|0)){a=a+(c[l>>2]<<1)|0;f=o;n=r}else{m=0;break}}i=e;return m|0}function P$a(a){a=a|0;var b=0;b=i;QIb(c[a>>2]|0,2587584,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return-1163346256|0}function Q$a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a+2600|0;if((c[b>>2]|0)<=0){d=0;return d|0}e=a+2596|0;f=0;a:while(1){g=0;while(1){if((g|0)>=(c[e>>2]|0)){break}h=W$a(a,g,f,8)|0;if((h|0)!=0){d=h;i=8;break a}g=g+8|0}g=f+8|0;if((g|0)<(c[b>>2]|0)){f=g}else{d=0;i=8;break}}if((i|0)==8){return d|0}return 0}function R$a(a){a=a|0;nrc(c[a+2612>>2]|0,c[a+2620>>2]|0,c[a+2636>>2]|0)|0;return 0}function S$a(a){a=a|0;nrc(c[a+2612>>2]|0,c[a+2616>>2]|0,c[a+2632>>2]|0)|0;return 0}function T$a(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+2660>>2]|0;f=b+4|0;if((e|0)<=0){g=0;return g|0}h=b+8|0;i=c[b+2612>>2]|0;b=e;while(1){e=c[h>>2]|0;j=c[f>>2]|0;k=e;if((k-j|0)<1){l=0;m=j}else{n=j+1|0;c[f>>2]=n;l=d[j]|0;m=n}n=(l>>>1)+1|0;if((n|0)>(b|0)){g=-1094995529;o=15;break}j=k-m|0;if((e|0)==(m|0)){g=-1094995529;o=15;break}if((l&1|0)==0){if(j>>>0<n>>>0){g=-1094995529;o=15;break}nrc(i|0,m|0,n)|0;c[f>>2]=(c[f>>2]|0)+n}else{if((j|0)<1){p=0}else{c[f>>2]=m+1;p=a[m]|0}mrc(i|0,p|0,n|0)|0}j=b-n|0;if((j|0)<=0){g=0;o=15;break}i=i+n|0;b=j}if((o|0)==15){return g|0}return 0}function U$a(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[a+2656>>2]|0;g=a+4|0;h=c[g>>2]|0;if(((c[a+8>>2]|0)-h|0)>>>0<f>>>0){KIb(c[a>>2]|0,16,2119464,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=e;return k|0}if((f|0)==0){k=0;i=e;return k|0}else{l=f;m=c[a+2612>>2]|0;n=h}while(1){h=l-1|0;f=n+1|0;c[g>>2]=f;b[m>>1]=b[a+2664+((d[n]|0)<<1)>>1]|0;if((h|0)==0){k=0;break}else{l=h;m=m+2|0;n=f}}i=e;return k|0}function V$a(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;g=c[e+2612>>2]|0;h=c[e+2656>>2]|0;j=e+2644|0;xJb(j,e+2648|0,h);k=c[j>>2]|0;if((k|0)==0){KIb(c[e>>2]|0,16,2143056,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;l=-12;i=f;return l|0}j=e+4|0;a:do{if((h|0)>0){m=e+8|0;n=k;o=h;while(1){p=c[m>>2]|0;q=c[j>>2]|0;r=p;if((r-q|0)<1){s=0;t=q}else{u=q+1|0;c[j>>2]=u;s=d[q]|0;t=u}u=(s>>>1)+1|0;if((u|0)>(o|0)){l=-1094995529;v=19;break}q=r-t|0;if((p|0)==(t|0)){l=-1094995529;v=19;break}if((s&1|0)==0){if(q>>>0<u>>>0){l=-1094995529;v=19;break}nrc(n|0,t|0,u)|0;c[j>>2]=(c[j>>2]|0)+u}else{if((q|0)<1){w=0}else{c[j>>2]=t+1;w=a[t]|0}mrc(n|0,w|0,u|0)|0}q=o-u|0;if((q|0)<=0){break a}n=n+u|0;o=q}if((v|0)==19){i=f;return l|0}}}while(0);if((h|0)==0){l=0;i=f;return l|0}else{x=g;y=k;z=h}while(1){h=z-1|0;b[x>>1]=b[e+2664+((d[y]|0)<<1)>>1]|0;if((h|0)==0){l=0;break}else{x=x+2|0;y=y+1|0;z=h}}i=f;return l|0}function W$a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;i=i+8|0;k=j|0;l=e+4|0;m=c[l>>2]|0;n=c[e+8>>2]|0;if((n|0)==(m|0)){o=-1094995529;i=j;return o|0}p=m+1|0;c[l>>2]=p;q=d[m]|0;a:do{switch(q|0){case 255:{if((h|0)==2){Y$a(e,f,g,2,c[e+2584>>2]|0);break a}r=h>>1;if((W$a(e,f,g,r)|0)!=0){o=-1094995529;i=j;return o|0}s=r+f|0;if((W$a(e,s,g,r)|0)!=0){o=-1094995529;i=j;return o|0}t=r+g|0;if((W$a(e,f,t,r)|0)!=0){o=-1094995529;i=j;return o|0}if((W$a(e,s,t,r)|0)==0){break a}else{o=-1094995529}i=j;return o|0};case 253:{if((n|0)==(p|0)){o=-1094995529;i=j;return o|0}r=c[e+2612>>2]|0;t=c[e+2584>>2]|0;c[l>>2]=m+2;s=b[e+2664+(d[p]<<1)>>1]|0;if((h|0)<=0){break a}u=r+((ca(t,g)|0)+f<<1)|0;r=0;while(1){v=u;w=0;while(1){b[v>>1]=s;x=w+1|0;if((x|0)<(h|0)){v=v+2|0;w=x}else{break}}w=r+1|0;if((w|0)<(h|0)){u=u+(t<<1)|0;r=w}else{break}}break};case 254:{if((n-p|0)>>>0<2>>>0){o=-1094995529;i=j;return o|0}r=c[e+2612>>2]|0;t=c[e+2584>>2]|0;c[l>>2]=m+3;u=p;s=(d[u]|d[u+1|0]<<8)<<16>>16;if((h|0)<=0){break a}u=r+((ca(t,g)|0)+f<<1)|0;r=0;while(1){w=u;v=0;while(1){b[w>>1]=s;x=v+1|0;if((x|0)<(h|0)){w=w+2|0;v=x}else{break}}v=r+1|0;if((v|0)<(h|0)){u=u+(t<<1)|0;r=v}else{break}}break};case 248:{Y$a(e,f,g,h,c[e+2584>>2]|0);break};case 249:case 250:case 251:case 252:{r=c[e+2584>>2]|0;t=b[e+3176+(q-249<<1)>>1]|0;if((h|0)<=0){break a}u=(ca(r,g)|0)+f|0;s=(c[e+2612>>2]|0)+(u<<1)|0;u=0;while(1){v=s;w=0;while(1){b[v>>1]=t;x=w+1|0;if((x|0)<(h|0)){v=v+2|0;w=x}else{break}}w=u+1|0;if((w|0)<(h|0)){s=s+(r<<1)|0;u=w}else{break}}break};case 246:{u=c[e+2584>>2]|0;r=(ca(u,g)|0)+f|0;X$a((c[e+2612>>2]|0)+(r<<1)|0,(c[e+2616>>2]|0)+(r<<1)|0,h,u);break};case 245:{if((n-p|0)>>>0<2>>>0){o=-1094995529;i=j;return o|0}c[l>>2]=m+3;u=p;r=(d[u]|d[u+1|0]<<8)<<16>>16<<16>>16;u=c[e+2588>>2]|0;s=(((r|0)%(u|0)|0)<<16>>16)+f|0;t=(((r|0)/(u|0)|0)<<16>>16)+g|0;u=e+2584|0;r=c[u>>2]|0;w=(ca(t,r)|0)+s|0;if((w|0)>-1){v=w+(ca(r+1|0,h-1|0)|0)|0;r=(v|0)<(c[e+2660>>2]>>1|0);v=r&1;if(r){y=v}else{z=v;A=11}}else{z=0;A=11}if((A|0)==11){KIb(c[e>>2]|0,16,2614448,(B=i,i=i+40|0,c[B>>2]=s,c[B+8>>2]=t,c[B+16>>2]=f,c[B+24>>2]=g,c[B+32>>2]=h,B)|0);i=B;y=z}if((y|0)==0){break a}v=c[u>>2]|0;u=(c[e+2612>>2]|0)+((ca(v,g)|0)+f<<1)|0;X$a(u,(c[e+2620>>2]|0)+(s+(ca(v,t)|0)<<1)|0,h,v);break};case 247:{v=c[e+2584>>2]|0;t=c[e+2612>>2]|0;s=(ca(v,g)|0)+f|0;u=t+(s<<1)|0;r=e+4|0;w=n-p|0;if((h|0)==2){if(w>>>0<4>>>0){break a}c[r>>2]=m+5;x=p;C=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;b[u>>1]=b[e+2664+((C&255)<<1)>>1]|0;b[t+(s+1<<1)>>1]=b[e+2664+((C>>>8&255)<<1)>>1]|0;b[t+(s+v<<1)>>1]=b[e+2664+((C>>>16&255)<<1)>>1]|0;b[t+(v+1+s<<1)>>1]=b[e+2664+(C>>>24<<1)>>1]|0;break a}if(w>>>0<3>>>0){break a}w=m+2|0;c[r>>2]=w;C=d[p]|0;s=m+3|0;c[r>>2]=s;t=b[e+2664+(d[w]<<1)>>1]|0;c[r>>2]=m+4;b[k>>1]=b[e+2664+(d[s]<<1)>>1]|0;b[k+2>>1]=t;if((h|0)==8){D=u;E=e+7280+(C<<6)|0;F=0}else{if((h|0)>0){D=u;E=e+3184+(C<<4)|0;F=0}else{break a}}while(1){C=D;u=E;t=0;while(1){b[C>>1]=b[k+(a[u]<<1)>>1]|0;s=t+1|0;if((s|0)<(h|0)){C=C+2|0;u=u+1|0;t=s}else{break}}t=F+1|0;if((t|0)<(h|0)){D=D+(v<<1)|0;E=E+h|0;F=t}else{break}}break};default:{v=(a[826304+(q<<1)|0]|0)+f|0;t=(a[826305+(q<<1)|0]|0)+g|0;u=e+2584|0;C=c[u>>2]|0;s=(ca(t,C)|0)+v|0;if((s|0)>-1){r=s+(ca(C+1|0,h-1|0)|0)|0;C=(r|0)<(c[e+2660>>2]>>1|0);r=C&1;if(C){G=r}else{H=r;A=5}}else{H=0;A=5}if((A|0)==5){KIb(c[e>>2]|0,16,2614448,(B=i,i=i+40|0,c[B>>2]=v,c[B+8>>2]=t,c[B+16>>2]=f,c[B+24>>2]=g,c[B+32>>2]=h,B)|0);i=B;G=H}if((G|0)==0){break a}r=c[u>>2]|0;u=(c[e+2612>>2]|0)+((ca(r,g)|0)+f<<1)|0;X$a(u,(c[e+2620>>2]|0)+(v+(ca(r,t)|0)<<1)|0,h,r)}}}while(0);o=0;i=j;return o|0}function X$a(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;h=c;i=f<<1;if((e|0)==4){j=c;k=j|0;l=j+4|0;j=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b;m=l|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=l+4|0;y=j;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=c+(f<<1)|0;j=m|0;l=m+4|0;m=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=b+(f<<1)|0;k=l|0;y=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=l+4|0;y=m;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=f<<2;m=h+k|0;l=m|0;j=m+4|0;m=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+k|0;n=j|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+4|0;y=m;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+i|0;k=h+n|0;m=k|0;j=k+4|0;k=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+n|0;n=j|0;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=j+4|0;y=k;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;return}else if((e|0)==2){n=c;k=b;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=c+(f<<1)|0;n=b+(f<<1)|0;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;return}else if((e|0)==8){e=c;n=e|0;k=e+4|0;e=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b;j=k|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=k+4|0;y=e;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=c+8|0;e=j|0;k=j+4|0;j=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;k=b+8|0;n=k|0;y=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+4|0;y=j;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=c+(f<<1)|0;c=n|0;j=n+4|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=b+(f<<1)|0;b=j|0;y=d[c]|d[c+1|0]<<8|d[c+2|0]<<16|d[c+3|0]<<24|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=j+4|0;y=n;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=i+8|0;n=h+b|0;j=n|0;c=n+4|0;n=d[c]|d[c+1|0]<<8|d[c+2|0]<<16|d[c+3|0]<<24|0;c=g+b|0;b=c|0;y=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=c+4|0;y=n;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=f<<2;f=h+b|0;n=f|0;c=f+4|0;f=d[c]|d[c+1|0]<<8|d[c+2|0]<<16|d[c+3|0]<<24|0;c=g+b|0;j=c|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=c+4|0;y=f;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=b+8|0;f=h+j|0;c=f|0;n=f+4|0;f=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+j|0;j=n|0;y=d[c]|d[c+1|0]<<8|d[c+2|0]<<16|d[c+3|0]<<24|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=n+4|0;y=f;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;j=b+i|0;b=h+j|0;f=b|0;n=b+4|0;b=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+j|0;c=n|0;y=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;a[c]=y;y=y>>8;a[c+1|0]=y;y=y>>8;a[c+2|0]=y;y=y>>8;a[c+3|0]=y;c=n+4|0;y=b;a[c]=y;y=y>>8;a[c+1|0]=y;y=y>>8;a[c+2|0]=y;y=y>>8;a[c+3|0]=y;c=j+8|0;b=h+c|0;n=b|0;f=b+4|0;b=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=g+c|0;c=f|0;y=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;a[c]=y;y=y>>8;a[c+1|0]=y;y=y>>8;a[c+2|0]=y;y=y>>8;a[c+3|0]=y;c=f+4|0;y=b;a[c]=y;y=y>>8;a[c+1|0]=y;y=y>>8;a[c+2|0]=y;y=y>>8;a[c+3|0]=y;c=j+i|0;j=h+c|0;b=j|0;f=j+4|0;j=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=g+c|0;n=f|0;y=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=f+4|0;y=j;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=c+8|0;j=h+n|0;f=j|0;b=j+4|0;j=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+n|0;n=b|0;y=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=b+4|0;y=j;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=c+i|0;c=h+n|0;j=c|0;b=c+4|0;c=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=g+n|0;f=b|0;y=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=b+4|0;y=c;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=n+8|0;c=h+f|0;b=c|0;j=c+4|0;c=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+f|0;f=j|0;y=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=j+4|0;y=c;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;f=n+i|0;n=h+f|0;c=n|0;j=n+4|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=g+f|0;b=j|0;y=d[c]|d[c+1|0]<<8|d[c+2|0]<<16|d[c+3|0]<<24|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=j+4|0;y=n;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=f+8|0;n=h+b|0;j=n|0;c=n+4|0;n=d[c]|d[c+1|0]<<8|d[c+2|0]<<16|d[c+3|0]<<24|0;c=g+b|0;b=c|0;y=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=c+4|0;y=n;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=f+i|0;i=h+b|0;f=i|0;n=i+4|0;i=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=g+b|0;c=n|0;y=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;a[c]=y;y=y>>8;a[c+1|0]=y;y=y>>8;a[c+2|0]=y;y=y>>8;a[c+3|0]=y;c=n+4|0;y=i;a[c]=y;y=y>>8;a[c+1|0]=y;y=y>>8;a[c+2|0]=y;y=y>>8;a[c+3|0]=y;c=b+8|0;b=h+c|0;h=b|0;i=b+4|0;b=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;i=g+c|0;c=i|0;y=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[c]=y;y=y>>8;a[c+1|0]=y;y=y>>8;a[c+2|0]=y;y=y>>8;a[c+3|0]=y;c=i+4|0;y=b;a[c]=y;y=y>>8;a[c+1|0]=y;y=y>>8;a[c+2|0]=y;y=y>>8;a[c+3|0]=y;return}else{return}}function Y$a(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+8|0;l=k|0;m=c[e+2612>>2]|0;n=(ca(c[e+2584>>2]|0,g)|0)+f|0;f=m+(n<<1)|0;g=e+4|0;o=c[g>>2]|0;p=(c[e+8>>2]|0)-o|0;if((h|0)==2){if(p>>>0<8>>>0){i=k;return}q=o+2|0;c[g>>2]=q;r=o;b[f>>1]=(d[r]|d[r+1|0]<<8)<<16>>16;r=o+4|0;c[g>>2]=r;s=q;b[m+(n+1<<1)>>1]=(d[s]|d[s+1|0]<<8)<<16>>16;s=o+6|0;c[g>>2]=s;q=r;b[m+(n+j<<1)>>1]=(d[q]|d[q+1|0]<<8)<<16>>16;c[g>>2]=o+8;q=s;b[m+(j+1+n<<1)>>1]=(d[q]|d[q+1|0]<<8)<<16>>16;i=k;return}if(p>>>0<5>>>0){i=k;return}p=o+1|0;c[g>>2]=p;q=d[o]|0;n=o+3|0;c[g>>2]=n;m=p;p=(d[m]|d[m+1|0]<<8)<<16>>16;c[g>>2]=o+5;o=n;b[l>>1]=(d[o]|d[o+1|0]<<8)<<16>>16;b[l+2>>1]=p;do{if((h|0)==8){t=f;u=e+7280+(q<<6)|0;v=0}else{if((h|0)>0){t=f;u=e+3184+(q<<4)|0;v=0;break}i=k;return}}while(0);while(1){q=t;e=u;f=0;while(1){b[q>>1]=b[l+(a[e]<<1)>>1]|0;p=f+1|0;if((p|0)<(h|0)){q=q+2|0;e=e+1|0;f=p}else{break}}f=v+1|0;if((f|0)<(h|0)){t=t+(j<<1)|0;u=u+h|0;v=f}else{break}}i=k;return}function Z$a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a+2612|0;d=b;e=a+2628|0;f=a+2660|0;A4a(d,e,c[f>>2]|0);g=a+2616|0;h=g;i=a+2632|0;A4a(h,i,c[f>>2]|0);j=a+2620|0;k=j;l=a+2636|0;A4a(k,l,c[f>>2]|0);m=a+16|0;if((c[m>>2]|0)==0){A4a(a+2624|0,a+2640|0,c[f>>2]|0)}do{if((c[b>>2]|0)!=0){if((c[g>>2]|0)==0){break}if((c[j>>2]|0)==0){break}if((c[a+2624>>2]|0)!=0){n=0;return n|0}if((c[m>>2]|0)==0){break}else{n=0}return n|0}}while(0);mJb(d);mJb(h);mJb(k);mJb(a+2624|0);mJb(a+2644|0);c[l>>2]=0;c[i>>2]=0;c[e>>2]=0;n=-12;return n|0}function _$a(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;m=i;i=i+8|0;n=m|0;o=n;p=e+4|0;q=c[p>>2]|0;r=c[e+8>>2]|0;if((r|0)==(q|0)){s=-1094995529;i=m;return s|0}t=q+1|0;c[p>>2]=t;u=a[q]|0;v=u&255;a:do{if((u&255)>>>0>247>>>0){if((v|0)==254){if((r|0)==(t|0)){s=-1094995529;i=m;return s|0}c[p>>2]=q+2;w=a[t]|0;if((l|0)>0){x=0}else{break}do{mrc(f+(ca(x,j)|0)|0,w|0,l|0)|0;x=x+1|0;}while((x|0)<(l|0))}else if((v|0)==252){if((l|0)>0){y=0}else{break}do{w=ca(y,j)|0;nrc(f+w|0,g+w|0,l)|0;y=y+1|0;}while((y|0)<(l|0))}else if((v|0)==255){if((l|0)==2){if((r-t|0)>>>0<4>>>0){s=-1094995529;i=m;return s|0}else{c[p>>2]=q+2;a[f]=a[t]|0;w=c[p>>2]|0;c[p>>2]=w+1;a[f+1|0]=a[w]|0;w=c[p>>2]|0;c[p>>2]=w+1;a[f+j|0]=a[w]|0;w=c[p>>2]|0;c[p>>2]=w+1;a[f+(j+1)|0]=a[w]|0;break}}w=l>>1;if((_$a(e,f,g,h,j,k,w)|0)!=0){s=-1094995529;i=m;return s|0}if((_$a(e,f+w|0,g+w|0,h+w|0,j,k,w)|0)!=0){s=-1094995529;i=m;return s|0}z=ca(w,j)|0;if((_$a(e,f+z|0,g+z|0,h+z|0,j,k,w)|0)!=0){s=-1094995529;i=m;return s|0}A=z+w|0;if((_$a(e,f+A|0,g+A|0,h+A|0,j,k,w)|0)==0){break}else{s=-1094995529}i=m;return s|0}else if((v|0)==253){if((r-t|0)>>>0<3>>>0){s=-1094995529;i=m;return s|0}w=q+2|0;c[p>>2]=w;A=d[t]|0;if((l|0)==8){z=w;b[n>>1]=(d[z]|d[z+1|0]<<8)<<16>>16;c[p>>2]=q+4;B=0;C=e+7280+(A<<6)|0}else{z=w;b[n>>1]=(d[z]|d[z+1|0]<<8)<<16>>16;c[p>>2]=q+4;if((l|0)>0){B=0;C=e+3184+(A<<4)|0}else{break}}while(1){A=ca(B,j)|0;z=0;w=C;while(1){a[f+(z+A)|0]=a[o+((a[w]|0)==0)|0]|0;D=z+1|0;if((D|0)<(l|0)){z=D;w=w+1|0}else{break}}w=B+1|0;if((w|0)<(l|0)){B=w;C=C+l|0}else{break}}}else{w=c[e+12>>2]|0;z=w;A=t-z|0;D=(v&7)+k|0;E=r;F=E-z|0;if((D|0)<0){G=0}else{G=(F|0)<(D|0)?F:D}D=w+G|0;c[p>>2]=D;if((E-D|0)<1){H=0}else{c[p>>2]=w+(G+1);H=a[D]|0}if((A|0)<0){I=0}else{I=(F|0)<(A|0)?F:A}c[p>>2]=w+I;if((l|0)>0){J=0}else{break}do{mrc(f+(ca(J,j)|0)|0,H|0,l|0)|0;J=J+1|0;}while((J|0)<(l|0))}}else{w=a[826304+(v<<1)|0]|0;A=a[826305+(v<<1)|0]|0;F=h-(c[e+2620>>2]|0)|0;do{if((F|0)>=(-((ca(A,j)|0)+w|0)|0)){if(((c[e+2660>>2]>>1)-F|0)<(w+l+(ca(l-1+A|0,j)|0)|0)){break}if((l|0)>0){K=0}else{break a}while(1){nrc(f+(ca(K,j)|0)|0,h+((ca(K+A|0,j)|0)+w)|0,l)|0;K=K+1|0;if((K|0)>=(l|0)){break a}}}}while(0);KIb(c[e>>2]|0,16,2458408,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;s=-1094995529;i=m;return s|0}}while(0);s=0;i=m;return s|0}function $$a(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;f=ca(e,e)|0;g=e-1|0;h=f<<4;i=0;j=b;while(1){b=a[c+i|0]|0;k=b<<24>>24;l=a[d+i|0]|0;m=l<<24>>24;do{if(l<<24>>24==0){n=3}else{if((g|0)==(m|0)){n=1;break}if(b<<24>>24==0){n=0;break}n=(g|0)==(k|0)?2:4}}while(0);o=(n|0)==0;p=(n|0)==2;q=(n|0)==3;r=q^1;s=(n|0)==1;t=s^1;u=(n|0)!=2;v=ca(m,e)|0;w=v+k|0;x=e-k|0;y=0;z=j;while(1){A=ca(f,y)|0;B=j+(w+A)|0;C=a[c+y|0]|0;D=C<<24>>24;E=a[d+y|0]|0;F=E<<24>>24;do{if(E<<24>>24==0){G=0;H=3;I=0;J=13}else{if((g|0)==(F|0)){K=0;L=0;M=1;N=0;O=0;P=1;J=15;break}if(C<<24>>24==0){if(p){Q=1;break}else{G=0;H=0;I=1;J=13;break}}R=(g|0)==(D|0);if(o&R){Q=1;break}G=R;H=R?2:4;I=0;J=13}}while(0);do{if((J|0)==13){J=0;if(q){Q=1;break}C=(H|0)==3;E=C^1;if(s|E){K=1;L=G;M=H;N=I;O=C;P=E;J=15}else{Q=1}}}while(0);do{if((J|0)==15){J=0;if(!(O|t)){Q=3;break}if(!(q|K)){Q=3;break}if(!(L|o^1)){Q=0;break}if(!(p|N^1)){Q=0;break}if(!((P|t)&(K|r)&(u|N))){Q=2;break}Q=(M|0)!=2|o?4:2}}while(0);E=D-k|0;C=(E|0)>-1?E:-E|0;E=F-m|0;R=(E|0)>-1?E:-E|0;E=(C|0)>(R|0)?C:R;a:do{if((E|0)>=0){R=E>>1;if((E|0)==0){if((Q|0)==0){if(b<<24>>24>-1){S=k}else{break}while(1){a[z+(S+v)|0]=1;if((S|0)>0){S=S-1|0}else{break a}}}else if((Q|0)==1){if(l<<24>>24>-1){T=m}else{break}while(1){a[z+((ca(T,e)|0)+k)|0]=1;if((T|0)>0){T=T-1|0}else{break a}}}else if((Q|0)==3){if((m|0)<(e|0)){U=m}else{break}while(1){a[z+((ca(U,e)|0)+k)|0]=1;U=U+1|0;if((U|0)>=(e|0)){break a}}}else if((Q|0)==2){if((k|0)>=(e|0)){break}mrc(B|0,1,x|0)|0;break}else{break}}else{V=0}do{C=E-V|0;W=(((ca(V,k)|0)+R+(ca(C,D)|0)|0)/(E|0)|0)&255;X=(((ca(V,m)|0)+R+(ca(C,F)|0)|0)/(E|0)|0)&255;do{if((Q|0)==3){C=X<<24>>24;if((C|0)>=(e|0)){break}Y=W<<24>>24;Z=C;do{a[z+((ca(Z,e)|0)+Y)|0]=1;Z=Z+1|0;}while((Z|0)<(e|0))}else if((Q|0)==0){if(!(W<<24>>24>-1)){break}Z=ca(X<<24>>24,e)|0;Y=W<<24>>24;while(1){a[z+(Y+Z)|0]=1;if((Y|0)>0){Y=Y-1|0}else{break}}}else if((Q|0)==2){Y=W<<24>>24;if((Y|0)>=(e|0)){break}mrc(j+(A+((ca(X<<24>>24,e)|0)+Y))|0,1,e-Y|0)|0}else if((Q|0)==1){if(!(X<<24>>24>-1)){break}Y=W<<24>>24;Z=X<<24>>24;while(1){a[z+((ca(Z,e)|0)+Y)|0]=1;if((Z|0)>0){Z=Z-1|0}else{break}}}}while(0);V=V+1|0;}while((V|0)<=(E|0))}}while(0);E=y+1|0;if((E|0)<16){y=E;z=z+f|0}else{break}}z=i+1|0;if((z|0)<16){i=z;j=j+h|0}else{break}}return}function a0a(a){a=a|0;c[c[a+60>>2]>>2]=a;return 0}function b0a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0;j=i;i=i+48|0;k=j|0;l=c[e+60>>2]|0;m=f;n=l+24|0;o=c[h+24>>2]|0;p=h+28|0;h=c[p>>2]|0;if(!((h|0)>-1)){KIb(0,0,2143e3,(q=i,i=i+24|0,c[q>>2]=2119424,c[q+8>>2]=2637696,c[q+16>>2]=135,q)|0);i=q;Hd();return 0}r=n;c[r>>2]=o;s=l+32|0;c[s>>2]=o;t=l+28|0;c[t>>2]=o+h;if(h>>>0<512>>>0){KIb(e,16,2446712,(q=i,i=i+8|0,c[q>>2]=h,q)|0);i=q;u=-1094995529;i=j;return u|0}h=o+2|0;c[r>>2]=h;v=o;if(!((d[v]|d[v+1|0]<<8)<<16>>16<<16>>16==-9727)){KIb(e,16,2357344,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=j;return u|0}v=o+3|0;c[r>>2]=v;w=a[h]|0;h=o+4|0;c[r>>2]=h;x=a[v]|0;v=x&255;y=l+16|0;c[y>>2]=v;z=o+6|0;c[r>>2]=z;A=h;h=(he((d[A]|d[A+1|0]<<8)<<16>>16|0)|0)&65535;A=o+8|0;c[r>>2]=A;B=z;z=(he((d[B]|d[B+1|0]<<8)<<16>>16|0)|0)&65535;B=l+4|0;c[B>>2]=z;C=o+10|0;c[r>>2]=C;D=A;A=(he((d[D]|d[D+1|0]<<8)<<16>>16|0)|0)&65535;D=l+8|0;c[D>>2]=A;c[r>>2]=o+12;o=C;C=(he((d[o]|d[o+1|0]<<8)<<16>>16|0)|0)&65535;o=l+12|0;c[o>>2]=C;if((v|0)==2){if(!(w<<24>>24==0)){E=9}}else if((v|0)!=1){E=9}if((E|0)==9){KIb(e,16,2294320,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=j;return u|0}if((h-2|0)>>>0>1>>>0){KIb(e,16,2243312,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=j;return u|0}if((C|0)==3){c[e+140>>2]=x<<24>>24==2?41:2}else if((C|0)==1){c[e+140>>2]=x<<24>>24==2?31:8}else if((C|0)==4){c[e+140>>2]=x<<24>>24==2?291:28}else{KIb(e,16,2201928,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=j;return u|0}x=H4a(e,z,A)|0;if((x|0)<0){u=x;i=j;return u|0}x=M4a(e,m,0)|0;if((x|0)<0){u=x;i=j;return u|0}c[f+88>>2]=1;c[f+84>>2]=1;x=c[f>>2]|0;m=c[f+32>>2]|0;f=c[D>>2]|0;e=l+20|0;c[e>>2]=m;A=c[s>>2]|0;z=c[t>>2]|0;C=z-A|0;h=A+((C|0)<512?C:512)|0;c[r>>2]=h;a:do{if(w<<24>>24==0){C=c[B>>2]|0;A=ca(C,f)|0;v=c[y>>2]|0;F=ca(A,v)|0;A=c[o>>2]|0;if((ca(F,A)|0)>>>0>(z-h|0)>>>0){u=-1094995529;i=j;return u|0}if((A|0)==0){G=0}else{H=0;while(1){I=k+(H*12|0)|0;J=I;c[J>>2]=c[n>>2];c[J+4>>2]=c[n+4>>2];c[J+8>>2]=c[n+8>>2];J=ca(H,F)|0;K=I|0;I=c[K>>2]|0;L=(c[k+(H*12|0)+4>>2]|0)-I|0;c[K>>2]=I+(L>>>0>J>>>0?J:L);L=H+1|0;if(L>>>0<A>>>0){H=L}else{G=A;break}}}A=f-1|0;if((A|0)>-1){M=A;N=G;O=G;P=G;Q=v;R=m;S=C}else{break}while(1){A=x+(ca(R,M)|0)|0;H=(S|0)>0;do{if((Q|0)==1){if(H){T=S;U=A;V=N;W=O;X=P}else{Y=N;Z=O;_=P;break}while(1){if((V|0)==0){$=U;aa=0;ba=W;da=X}else{F=0;L=U;while(1){J=k+(F*12|0)|0;I=c[J>>2]|0;c[J>>2]=I+1;J=L+1|0;a[L]=a[I]|0;I=F+1|0;K=c[o>>2]|0;if(I>>>0<K>>>0){F=I;L=J}else{$=J;aa=K;ba=K;da=K;break}}}L=T-1|0;if((L|0)>0){T=L;U=$;V=aa;W=ba;X=da}else{Y=aa;Z=ba;_=da;break}}}else{if(!H){Y=N;Z=O;_=P;break}L=P>>>0>1>>>0?P:1;F=S;K=A;J=O;while(1){if((J|0)==0){ea=K;fa=0}else{I=0;ga=K;while(1){ha=k+(I*12|0)|0;ia=c[ha>>2]|0;c[ha>>2]=ia+2;ha=ia;b[ga>>1]=(d[ha]|d[ha+1|0]<<8)<<16>>16;ha=I+1|0;if(ha>>>0<P>>>0){I=ha;ga=ga+2|0}else{break}}ea=K+(L<<1)|0;fa=P}ga=F-1|0;if((ga|0)>0){F=ga;K=ea;J=fa}else{Y=fa;Z=fa;_=P;break}}}}while(0);A=M-1|0;if(!((A|0)>-1)){break a}M=A;N=Y;O=Z;P=_;Q=c[y>>2]|0;R=c[e>>2]|0;S=c[B>>2]|0}}else{C=x+(ca(f,m)|0)|0;v=c[o>>2]|0;if((ca(f<<3,v)|0)>>>0>(z-h|0)>>>0){u=-1094995529;i=j;return u|0}if((v|0)==0){break}A=l;H=h;J=0;K=f;F=v;b:while(1){if((K|0)==0){ja=H;ka=0;la=F}else{v=H;L=C;ga=1;while(1){I=c[e>>2]|0;if((z-v|0)<4){ha=c[t>>2]|0;ia=c[s>>2]|0;ma=v;na=0;oa=ha;pa=ia;qa=ha-ia|0;E=27}else{ia=v+4|0;ha=v;ra=je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0;ha=c[t>>2]|0;sa=c[s>>2]|0;if((ra|0)<0){ta=0;ua=ia;va=ha;wa=sa}else{ma=ia;na=ra;oa=ha;pa=sa;qa=ha-sa|0;E=27}}if((E|0)==27){E=0;ta=(qa|0)<(na|0)?qa:na;ua=ma;va=oa;wa=pa}sa=wa+ta|0;c[r>>2]=sa;ha=J-I|0;ra=L+ha|0;ia=c[o>>2]|0;xa=ca(ia,c[B>>2]|0)|0;ya=L+(xa+ha)|0;c:do{if((xa|0)>0){ha=ya;if((va|0)==(sa|0)){za=-1094995529;break}else{Aa=va;Ba=sa;Ca=ra}while(1){Da=Ba+1|0;c[r>>2]=Da;Ea=a[Ba]|0;Fa=Ea&127;if(Fa<<24>>24==0){Ga=Ca;E=44;break c}if((ha-Ca|0)<=(ca((Fa&255)-1|0,ia)|0)){break}d:do{if(Ea<<24>>24>-1){if((Aa-Da|0)<1){Ha=0}else{c[r>>2]=Ba+2;Ha=a[Da]|0}Ia=Fa;Ja=Ca;while(1){Ka=Ia-1&255;a[Ja]=Ha;if(Ka<<24>>24==0){break}else{Ia=Ka;Ja=Ja+ia|0}}}else{Ja=Fa;Ia=Ca;Ka=Aa;La=Da;while(1){Ma=Ja-1&255;if((Ka-La|0)<1){Na=0}else{c[r>>2]=La+1;Na=a[La]|0}a[Ia]=Na;if(Ma<<24>>24==0){break d}Ja=Ma;Ia=Ia+ia|0;Ka=c[t>>2]|0;La=c[r>>2]|0}}}while(0);Da=Ca+(ca((Fa-1&255)+1|0,ia)|0)|0;if(!(Da>>>0<ya>>>0)){Ga=Da;E=44;break c}Ea=c[r>>2]|0;La=c[t>>2]|0;if((La|0)==(Ea|0)){za=-1094995529;break c}else{Aa=La;Ba=Ea;Ca=Da}}KIb(c[A>>2]|0,16,2170160,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;za=-1094995529}else{Ga=ra;E=44}}while(0);if((E|0)==44){E=0;za=(Ga-ra|0)/(ia|0)|0}if((za|0)!=(c[B>>2]|0)){u=-1094995529;break b}Oa=c[D>>2]|0;if(!(ga>>>0<Oa>>>0)){break}v=ua;L=L+(-I|0)|0;ga=ga+1|0}ja=ua;ka=Oa;la=c[o>>2]|0}ga=J+1|0;if(ga>>>0<la>>>0){H=ja;J=ga;K=ka;F=la}else{break a}}i=j;return u|0}}while(0);c[g>>2]=1;u=c[p>>2]|0;i=j;return u|0}function c0a(a){a=a|0;var b=0,d=0,e=0;b=i;do{if((c[a+120>>2]|0)<=65535){if((c[a+124>>2]|0)>65535){break}d=UHb()|0;c[a+804>>2]=d;e=(d|0)==0?-12:0;i=b;return e|0}}while(0);KIb(a,16,2446656,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-1;i=b;return e|0}function d0a(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;h=c[d+804>>2]|0;c[h+88>>2]=1;c[h+84>>2]=1;h=c[d+120>>2]|0;i=c[d+124>>2]|0;switch(c[d+140>>2]|0){case 28:{j=0;k=255;l=1;m=3;n=4;break};case 292:{o=1;p=9;break};case 31:{q=0;p=5;break};case 32:{q=1;p=5;break};case 2:{j=0;k=255;l=1;m=3;n=3;break};case 8:{j=0;k=255;l=1;m=2;n=1;break};case 291:{o=0;p=9;break};case 41:{r=0;p=7;break};case 42:{r=1;p=7;break};default:{s=-1094995529;return s|0}}if((p|0)==5){c[d+568>>2]=2;j=q;k=65535;l=2;m=2;n=1}else if((p|0)==7){c[d+568>>2]=2;j=r;k=65535;l=2;m=3;n=3}else if((p|0)==9){c[d+568>>2]=2;j=o;k=65535;l=2;m=3;n=4}o=ca(n,i)|0;r=o<<2;q=d+568|0;if((c[q>>2]|0)==2){t=h}else{t=(h<<1|1)+8|0}u=d5a(d,e,ca((ca(o,t)|0)+512|0,l)|0,0)|0;if((u|0)<0){s=u;return s|0}u=e+24|0;t=c[u>>2]|0;d=e+28|0;v=t+(c[d>>2]|0)|0;w=t;y=-9727;a[w]=y;y=y>>8;a[w+1|0]=y;a[t+2|0]=(c[q>>2]|0)!=2|0;a[t+3|0]=l;w=t+4|0;y=he(m|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;w=t+6|0;y=he(h&65535|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;w=t+8|0;y=he(i&65535|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;w=t+10|0;y=he(n&65535|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;w=t+12|0;y=0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;w=t+16|0;y=je(k|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;w=t+512|0;mrc(t+20|0,0,516)|0;do{if((c[q>>2]|0)==2){k=f|0;m=f+32|0;x=i-1|0;z=(i|0)==0;A=ca(n,h)|0;B=(A|0)==0;C=(l|0)==1;D=(j|0)==0;E=w;F=0;while(1){if(z){G=E}else{H=c[m>>2]|0;I=(ca(H,x)|0)+(ca(F,l)|0)|0;J=E;K=0;L=(c[k>>2]|0)+I|0;I=H;while(1){if(B){M=J;N=I}else{H=L;if(C){if(D){O=J;P=0;while(1){a[O]=a[L+P|0]|0;Q=O+1|0;R=P+n|0;if(R>>>0<A>>>0){O=Q;P=R}else{S=Q;break}}}else{P=J;O=0;while(1){a[P]=a[L+O|0]|0;Q=P+1|0;R=O+n|0;if(R>>>0<A>>>0){P=Q;O=R}else{S=Q;break}}}}else{if(D){O=J;P=0;while(1){Q=O;y=b[H+(P<<1)>>1]|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;Q=O+2|0;R=P+n|0;if(R>>>0<A>>>0){O=Q;P=R}else{S=Q;break}}}else{P=J;O=0;while(1){Q=P;y=he(b[H+(O<<1)>>1]|0)|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;Q=P+2|0;R=O+n|0;if(R>>>0<A>>>0){P=Q;O=R}else{S=Q;break}}}}M=S;N=c[m>>2]|0}O=K+1|0;if(O>>>0<i>>>0){J=M;K=O;L=L+(-N|0)|0;I=N}else{G=M;break}}}I=F+1|0;if(I>>>0<n>>>0){E=G;F=I}else{T=G;break}}}else{F=hJb(h)|0;if((F|0)==0){s=-1;return s|0}E=f|0;m=f+32|0;A=i-1|0;D=(i|0)==0;C=(h|0)==0;B=v-1|0;k=w;x=t+(r+512)|0;z=t+((o<<3)+512)|0;I=0;a:while(1){b:do{if(D){U=k;V=x;W=z}else{L=(ca(c[m>>2]|0,A)|0)+I|0;K=(c[E>>2]|0)+L|0;if(C){L=k;J=x;O=z;P=0;while(1){H=O;Q=L;y=je(H-(c[u>>2]|0)|0)|0;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;Q=L+4|0;R=$rb(O,B-H|0,F,1,0,0,0,128,0)|0;if((R|0)<1){break a}a[O+R|0]=0;H=R+1|0;R=O+H|0;X=J;y=je(H|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;X=J+4|0;H=P+1|0;if(H>>>0<i>>>0){L=Q;J=X;O=R;P=H}else{U=Q;V=X;W=R;break b}}}else{Y=k;Z=x;_=z;$=0;aa=K}while(1){P=_;O=Y;y=je(P-(c[u>>2]|0)|0)|0;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;O=Y+4|0;J=0;do{a[F+J|0]=a[aa+(ca(J,n)|0)|0]|0;J=J+1|0;}while(J>>>0<h>>>0);J=$rb(_,B-P|0,F,1,h,0,0,128,0)|0;if((J|0)<1){break a}a[_+J|0]=0;L=J+1|0;J=_+L|0;R=Z;y=je(L|0)|0;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;R=Z+4|0;L=$+1|0;if(L>>>0<i>>>0){Y=O;Z=R;_=J;$=L;aa=aa+(-(c[m>>2]|0)|0)|0}else{U=O;V=R;W=J;break}}}}while(0);K=I+1|0;if(K>>>0<n>>>0){k=U;x=V;z=W;I=K}else{p=27;break}}if((p|0)==27){kJb(F);T=W;break}kJb(F);s=-1;return s|0}}while(0);c[d>>2]=T-(c[u>>2]|0);u=e+36|0;c[u>>2]=c[u>>2]|1;c[g>>2]=1;s=0;return s|0}function e0a(a){a=a|0;VHb(a+804|0);return 0}function f0a(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[a+140>>2]=19;a=UHb()|0;c[b>>2]=a;return((a|0)==0?-12:0)|0}function g0a(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;h=c[b+60>>2]|0;j=N4a(b,c[h>>2]|0)|0;if((j|0)<0){k=j;i=g;return k|0}j=c[h>>2]|0;l=c[j>>2]|0;m=c[f+24>>2]|0;n=f+28|0;f=c[n>>2]|0;o=c[b+120>>2]|0;p=c[b+124>>2]|0;q=c[j+32>>2]|0;j=m+f|0;a:do{if((f|0)>1){r=0;s=0;t=m;b:while(1){u=t+1|0;v=a[t]|0;c:do{if(v<<24>>24!=0&(v&255)>>>0<192>>>0){w=v;x=s;y=r;while(1){z=w&255;A=o-y|0;B=(z|0)>(A|0)?A:z;if((B|0)<1){C=x;D=y;break}A=l+((ca(x,q)|0)+y)|0;E=a[u]|0;mrc(A|0,E<<3|(E&255)>>>5|0,B|0)|0;E=B+y|0;if((E|0)<(o|0)){F=x;G=E}else{E=x+1|0;if((E|0)<(p|0)){F=E;G=0}else{break a}}E=z-B|0;if((E&255|0)==0){C=F;D=G;break}else{w=E&255;x=F;y=G}}H=t+2|0;I=C;J=D}else{if(!((v&255)>>>0>192>>>0)){break b}y=u;x=v+64&255;w=s;E=r;while(1){B=x&255;z=o-E|0;A=(B|0)>(z|0)?z:B;z=j-y|0;K=(A|0)>(z|0)?z:A;if((K|0)<1){H=y;I=w;J=E;break c}A=(ca(w,q)|0)+E|0;z=0;do{L=a[y+z|0]|0;a[l+(A+z)|0]=L<<3|(L&255)>>>5;z=z+1|0;}while((z|0)<(K|0));z=K+E|0;if((z|0)<(o|0)){M=w;N=z}else{z=w+1|0;if((z|0)<(p|0)){M=z;N=0}else{break a}}z=y+K|0;A=B-K|0;if((A&255|0)==0){H=z;I=M;J=N;break}else{y=z;x=A&255;w=M;E=N}}}}while(0);if((j-H|0)>1){r=J;s=I;t=H}else{break a}}QIb(b,2446640,(t=i,i=i+8|0,c[t>>2]=v&255,t)|0);i=t;k=-1163346256;i=g;return k|0}}while(0);c[e>>2]=1;e=YHb(d,c[h>>2]|0)|0;if((e|0)<0){k=e;i=g;return k|0}k=c[n>>2]|0;i=g;return k|0}function h0a(a){a=a|0;VHb(c[a+60>>2]|0);return 0}function i0a(a){a=a|0;c[c[a+60>>2]>>2]=a;return 0}function j0a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0;j=i;k=f;l=h+24|0;m=c[l>>2]|0;n=h+28|0;h=c[n>>2]|0;o=c[e+60>>2]|0;p=o;q=o+28|0;r=c[q>>2]|0;do{if((r|0)==0){c[q>>2]=8192;s=o+136|0;t=o+148|0;u=wJb(c[s>>2]|0,t,8208)|0;if((u|0)!=0){mrc(u|0,0,c[t>>2]|0)|0;c[s>>2]=u;u=c[q>>2]|0;if((u|0)==0){v=m;w=h;x=0;break}else{y=u;z=t;A=6;break}}KIb(e,16,2446600,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-12;i=j;return C|0}else{y=r;z=o+148|0;A=6}}while(0);do{if((A|0)==6){r=o+140|0;t=c[r>>2]|0;u=y-t|0;s=(h|0)>(u|0)?u:h;u=o+144|0;D=c[u>>2]|0;if((t+16+D+s|0)>>>0>(c[z>>2]|0)>>>0){E=c[o+136>>2]|0;orc(E|0,E+D|0,t|0)|0;c[u>>2]=0;F=0}else{F=D}if((m|0)==0){G=F;H=o+136|0}else{D=o+136|0;nrc((c[D>>2]|0)+((c[r>>2]|0)+F)|0,m|0,s)|0;G=c[u>>2]|0;H=D}D=(c[H>>2]|0)+G|0;u=(c[r>>2]|0)+s|0;c[r>>2]=u;if((u|0)>=(c[q>>2]|0)){v=D;w=u;x=s;break}if((c[l>>2]|0)==0){v=D;w=u;x=s;break}c[g>>2]=0;C=s;i=j;return C|0}}while(0);l=o+4|0;q=l;G=w<<3;H=G>>>0>2147483639>>>0|(v|0)==0;m=H?0:v;v=H?0:G;c[l>>2]=m;l=o+16|0;c[l>>2]=v;G=v+8|0;H=o+20|0;c[H>>2]=G;c[o+8>>2]=m+(v>>3);F=o+12|0;z=o+16568|0;h=c[z>>2]|0;y=G>>>0>h>>>0?h:G;c[F>>2]=y;h=o+16576|0;a:do{if((c[h>>2]|0)==0){s=m+(y>>>3)|0;u=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(y&7)&-65536;s=y+16|0;D=G>>>0>s>>>0?s:G;c[F>>2]=D;s=m+(D>>>3)|0;r=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(D&7)>>>16;s=D+16|0;D=G>>>0>s>>>0?s:G;c[F>>2]=D;if((r|u|0)!=1634364263){KIb(c[o>>2]|0,16,2119392,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}u=o+16572|0;c[u>>2]=0;r=o+16564|0;c[r>>2]=256;s=o+16552|0;c[s>>2]=-1;t=m+(D>>>3)|0;E=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(D&7)>>>24;t=D+8|0;c[F>>2]=G>>>0>t>>>0?t:G;t=o+16540|0;c[t>>2]=E;if((E|0)==0){I=4}else{I=l0a(q,2)|0}E=o+16556|0;c[E>>2]=l0a(q,I)|0;if((c[t>>2]|0)==0){J=0}else{J=l0a(q,2)|0}D=l0a(q,J)|0;K=o+32|0;c[K>>2]=D;if((D|0)==0){KIb(c[o>>2]|0,16,2637672,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}L=o;M=c[L>>2]|0;if(D>>>0>8>>>0){KIb(M,16,2614392,(B=i,i=i+8|0,c[B>>2]=D,B)|0);i=B;c[K>>2]=0;C=-1094995529;i=j;return C|0}c[M+416>>2]=D;do{if((c[t>>2]|0)>0){D=l0a(q,l0a(q,2)|0)|0;if((D|0)==0|D>>>0>65535>>>0){KIb(c[L>>2]|0,16,2243272,(B=i,i=i+8|0,c[B>>2]=D,B)|0);i=B;C=-22;i=j;return C|0}c[r>>2]=D;if((c[t>>2]|0)==0){N=2}else{N=l0a(q,2)|0}D=l0a(q,N)|0;if((c[t>>2]|0)==0){O=0}else{O=l0a(q,2)|0}c[s>>2]=l0a(q,O)|0;if((c[t>>2]|0)==0){P=1}else{P=l0a(q,2)|0}M=l0a(q,P)|0;if((M|0)<=0){Q=D;break}R=c[H>>2]|0;S=0;T=c[F>>2]|0;do{U=T+8|0;T=R>>>0>U>>>0?U:R;S=S+1|0;}while((S|0)<(M|0));c[F>>2]=T;Q=D}else{Q=0}}while(0);M=(Q|0)<3?3:Q;S=o+16560|0;c[S>>2]=M;do{if((c[K>>2]|0)==0){V=M}else{R=0;while(1){U=c[s>>2]|0;W=(U|0)<1;if(U>>>0>1073741822>>>0&(W^1)){A=40;break}X=c[S>>2]|0;Y=X+(c[r>>2]|0)|0;if(!(Y>>>0<1073741823>>>0&Y>>>0>X>>>0)){A=42;break}X=lJb(p+100+(R<<2)|0,W?4:U<<2)|0;if((X|0)<0){C=X;A=208;break}X=p+68+(R<<2)|0;U=lJb(X,(c[S>>2]|0)+(c[r>>2]|0)<<2)|0;if((U|0)<0){C=U;A=208;break}U=c[S>>2]|0;W=c[X>>2]|0;if((U|0)>0){X=0;while(1){c[W+(X<<2)>>2]=0;Y=X+1|0;Z=c[S>>2]|0;if((Y|0)<(Z|0)){X=Y}else{_=Z;break}}}else{_=U}c[p+36+(R<<2)>>2]=W+(_<<2);X=R+1|0;if(X>>>0<(c[K>>2]|0)>>>0){R=X}else{A=48;break}}if((A|0)==40){KIb(c[L>>2]|0,16,2410224,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}else if((A|0)==42){KIb(c[L>>2]|0,16,2402520,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}else if((A|0)==48){V=c[S>>2]|0;break}else if((A|0)==208){i=j;return C|0}}}while(0);S=lJb(o+132|0,V<<2)|0;if((S|0)<0){C=S;i=j;return C|0}S=c[s>>2]|0;r=(S|0)<1?1:S;S=c[E>>2]|0;if((S|0)==3|(S|0)==5){c[(c[L>>2]|0)+420>>2]=6;$=0}else if((S|0)==2){c[(c[L>>2]|0)+420>>2]=5;$=128}else{KIb(c[L>>2]|0,16,2419232,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1163346256;i=j;return C|0}if((c[K>>2]|0)!=0&(r|0)>0){S=0;do{M=c[p+100+(S<<2)>>2]|0;R=0;do{c[M+(R<<2)>>2]=$;R=R+1|0;}while((R|0)<(r|0));S=S+1|0;}while(S>>>0<(c[K>>2]|0)>>>0)}if((c[t>>2]|0)>1){c[u>>2]=32}if((l0a(q,2)|0)!=9){KIb(c[L>>2]|0,16,2587512,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}K=l0a(q,5)|0;S=o+152|0;c[S>>2]=K;if((K-44|0)>>>0>16339>>>0){KIb(c[L>>2]|0,16,2566328,(B=i,i=i+8|0,c[B>>2]=K,B)|0);i=B;C=-1094995529;i=j;return C|0}if((K|0)>0){r=0;while(1){a[p+156+r|0]=l0a(q,8)|0;E=r+1|0;s=c[S>>2]|0;if((E|0)<(s|0)){r=E}else{aa=s;break}}}else{aa=K}r=c[L>>2]|0;if(!((aa|0)>-1)){KIb(0,0,2458368,(B=i,i=i+24|0,c[B>>2]=2441384,c[B+8>>2]=2429704,c[B+16>>2]=135,B)|0);i=B;Hd();return 0}S=p+156+aa|0;do{if((aa|0)>=4){u=o+156|0;if((d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)!=1179011410){break}u=(aa-4|0)>>>0>4>>>0?8:aa;do{if((aa-u|0)>=4){t=p+156+u|0;if((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)!=1163280727){break}t=u+4+(p+156)|0;while(1){if((S-t|0)<4){ba=0;da=t}else{s=t;ba=(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)==544501094;da=t+4|0}if((S-da|0)<4){ea=0;fa=da}else{s=da;ea=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;fa=da+4|0}if(ba){break}s=S-fa|0;E=fa+(s>>>0>ea>>>0?ea:s)|0;if((ea|0)<0){A=82;break}if((S-E|0)>>>0<16>>>0){A=82;break}else{t=E}}if((A|0)==82){KIb(r,16,2515024,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}if((ea|0)<16){KIb(r,16,2501176,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}do{if((S-fa|0)>=2){t=fa;if(!((d[t]|d[t+1|0]<<8)<<16>>16<<16>>16==1)){break}t=S-(fa+2)|0;W=t>>>0>2>>>0?4:t+2|0;t=fa+W|0;if((S-t|0)<4){ga=0;ha=t}else{U=t;ga=d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0;ha=fa+(W+4)|0}c[r+412>>2]=ga;W=S-ha|0;U=W>>>0>4>>>0?4:W;W=S-(ha+U)|0;t=ha+((W>>>0>2>>>0?2:W)+U)|0;do{if((S-t|0)<2){c[r+792>>2]=0;ia=0}else{U=t;W=(d[U]|d[U+1|0]<<8)<<16>>16&65535;c[r+792>>2]=W;if(!((W|0)==16|(W|0)==8)){ia=W;break}W=ea-16|0;if((W|0)>0){KIb(r,32,2467944,(B=i,i=i+8|0,c[B>>2]=W,B)|0);i=B}c[o+16544>>2]=0;c[o+16548>>2]=0;c[h>>2]=1;c[g>>2]=0;break a}}while(0);KIb(r,16,2477472,(B=i,i=i+8|0,c[B>>2]=ia,B)|0);i=B;C=-38;i=j;return C|0}}while(0);KIb(r,16,2488408,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-38;i=j;return C|0}}while(0);KIb(r,16,2530272,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}}while(0);KIb(r,16,2548216,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1094995529;i=j;return C|0}else{S=o+16580|0;if((c[S>>2]|0)!=0){c[g>>2]=0;C=c[n>>2]|0;i=j;return C|0}L=o+16544|0;c[L>>2]=0;K=o+32|0;b:do{if((c[K>>2]|0)!=0){u=o+16548|0;t=o+16564|0;W=o+16540|0;U=o+16552|0;E=o+100|0;s=o+36|0;R=o+16560|0;M=f+76|0;D=f+64|0;T=o+16556|0;X=o+132|0;Z=o+16572|0;Y=y;ja=v;c:while(1){if((ja-Y|0)<5){A=102;break}ka=l0a(q,2)|0;if(ka>>>0>9>>>0){A=104;break}do{if((399>>>(ka>>>0)&1|0)==0){if((ka|0)==5){la=c[t>>2]|0;ma=la>>>0>65535>>>0;na=ma?la>>>16:la;la=ma?16:0;if((na&65280|0)==0){oa=la;pa=na}else{oa=la|8;pa=na>>>8}if((c[W>>2]|0)==0){qa=(d[1359664+pa|0]|0)+oa|0}else{qa=l0a(q,2)|0}ra=l0a(q,qa)|0;if(ra>>>0>(c[t>>2]|0)>>>0){A=115;break c}if((ra|0)==0|ra>>>0>65535>>>0){A=117;break c}c[t>>2]=ra}else if((ka|0)==6){c[u>>2]=l0a(q,2)|0;break}else if((ka|0)==4){A=119;break c}else if((ka|0)==9){na=l0a(q,5)|0;if((na|0)==0){break}else{sa=na}do{sa=sa-1|0;l0a(q,8)|0;}while((sa|0)!=0)}if((ka-4|0)>>>0<2>>>0){break c}}else{na=c[L>>2]|0;la=(ka|0)==8;if(la){ta=1}else{ma=l0a(q,3)|0;ta=ma+1+(((c[W>>2]|0)==0)<<31>>31)|0}ma=c[U>>2]|0;do{if((ma|0)==0){ua=c[c[E+(na<<2)>>2]>>2]|0}else{va=c[W>>2]|0;if((va|0)<2){wa=0}else{wa=(ma|0)/2|0}if((ma|0)>0){xa=c[E+(na<<2)>>2]|0;ya=0;za=wa;while(1){Aa=(c[xa+(ya<<2)>>2]|0)+za|0;Ba=ya+1|0;if((Ba|0)<(ma|0)){ya=Ba;za=Aa}else{Ca=Aa;break}}}else{Ca=wa}za=(Ca|0)/(ma|0)|0;if((va|0)<=1){ua=za;break}ya=c[u>>2]|0;if((ya|0)==0){ua=za;break}ua=za>>ya-1>>1}}while(0);do{if(la){ma=c[t>>2]|0;if((ma|0)<=0){Da=ma;break}ma=c[s+(na<<2)>>2]|0;ya=0;while(1){c[ma+(ya<<2)>>2]=0;za=ya+1|0;xa=c[t>>2]|0;if((za|0)<(xa|0)){ya=za}else{Da=xa;break}}}else{ya=(ka|0)==7;do{if(ya){Ea=l0a(q,2)|0;if((Ea|0)>(c[R>>2]|0)){A=142;break c}if((Ea|0)>0){ma=0;while(1){va=l0a(q,6)|0;xa=c[X>>2]|0;c[xa+(ma<<2)>>2]=va<<31>>31^va>>1;va=ma+1|0;if((va|0)<(Ea|0)){ma=va}else{Fa=xa;Ga=5;Ha=Ea;break}}}else{Fa=c[X>>2]|0;Ga=5;Ha=Ea;break}}else{if(ka>>>0>3>>>0){A=145;break c}Fa=1215416+(ka*12|0)|0;Ga=0;Ha=ka}}while(0);ma=ya^1;xa=ya&(ua|0)!=0;va=(Ha|0)>0;if(xa&va){za=c[p+36+(na<<2)>>2]|0;Aa=-Ha|0;do{Ba=za+(Aa<<2)|0;c[Ba>>2]=(c[Ba>>2]|0)-ua;Aa=Aa+1|0;}while((Aa|0)<0)}Aa=(Ha|0)==0;if(Aa|ma){Ia=Aa?ua:0}else{Ia=c[Z>>2]|0}Aa=c[t>>2]|0;if((Aa|0)<=0){Da=Aa;break}Aa=p+36+(na<<2)|0;if(va){za=0;ya=c[Aa>>2]|0;while(1){Ba=za-1|0;Ja=Ia;Ka=0;do{Ja=(ca(c[ya+(Ba-Ka<<2)>>2]|0,c[Fa+(Ka<<2)>>2]|0)|0)+Ja|0;Ka=Ka+1|0;}while((Ka|0)<(Ha|0));Ka=l0a(q,ta)|0;Ba=c[Aa>>2]|0;c[Ba+(za<<2)>>2]=(Ka<<31>>31^Ka>>1)+(Ja>>Ga);Ka=za+1|0;La=c[t>>2]|0;if((Ka|0)<(La|0)){za=Ka;ya=Ba}else{Ma=La;Na=Ba;break}}}else{ya=Ia>>Ga;za=0;while(1){va=l0a(q,ta)|0;ma=c[Aa>>2]|0;c[ma+(za<<2)>>2]=(va<<31>>31^va>>1)+ya;va=za+1|0;Ba=c[t>>2]|0;if((va|0)<(Ba|0)){za=va}else{Ma=Ba;Na=ma;break}}}if(xa&(Ma|0)>0){Oa=0}else{Da=Ma;break}while(1){za=Na+(Oa<<2)|0;c[za>>2]=(c[za>>2]|0)+ua;za=Oa+1|0;ya=c[t>>2]|0;if((za|0)<(ya|0)){Oa=za}else{Da=ya;break}}}}while(0);la=c[U>>2]|0;do{if((la|0)>0){xa=c[W>>2]|0;if((xa|0)<2){Pa=0}else{Pa=(Da|0)/2|0}if((Da|0)>0){ya=c[s+(na<<2)>>2]|0;za=0;Aa=Pa;while(1){ma=(c[ya+(za<<2)>>2]|0)+Aa|0;Ba=za+1|0;if((Ba|0)<(Da|0)){za=Ba;Aa=ma}else{Qa=ma;break}}}else{Qa=Pa}if((la|0)>1){Aa=c[E+(na<<2)>>2]|0;za=1;do{c[Aa+(za-1<<2)>>2]=c[Aa+(za<<2)>>2];za=za+1|0;Ra=c[U>>2]|0;}while((za|0)<(Ra|0));Sa=Ra;Ta=c[W>>2]|0;Ua=c[t>>2]|0}else{Sa=la;Ta=xa;Ua=Da}za=(Qa|0)/(Ua|0)|0;if((Ta|0)<2){c[(c[E+(na<<2)>>2]|0)+(Sa-1<<2)>>2]=za;break}else{c[(c[E+(na<<2)>>2]|0)+(Sa-1<<2)>>2]=za<<c[u>>2];break}}}while(0);la=c[R>>2]|0;if((la|0)>0){za=c[s+(na<<2)>>2]|0;Aa=-la|0;while(1){c[za+(Aa<<2)>>2]=c[za+((c[t>>2]|0)+Aa<<2)>>2];la=Aa+1|0;if((la|0)<0){Aa=la}else{Va=za;break}}}else{Va=c[s+(na<<2)>>2]|0}za=c[u>>2]|0;do{if((za|0)!=0){if((c[t>>2]|0)<=0){break}c[Va>>2]=c[Va>>2]<<za;if((c[t>>2]|0)>1){Wa=1}else{break}do{Aa=Va+(Wa<<2)|0;c[Aa>>2]=c[Aa>>2]<<c[u>>2];Wa=Wa+1|0;}while((Wa|0)<(c[t>>2]|0))}}while(0);za=(c[L>>2]|0)+1|0;c[L>>2]=za;if((za|0)!=(c[K>>2]|0)){break}c[M>>2]=c[t>>2];za=M4a(e,k,0)|0;if((za|0)<0){C=za;A=208;break c}za=c[K>>2]|0;if((za|0)!=0){na=0;xa=c[t>>2]|0;Aa=za;while(1){za=c[(c[D>>2]|0)+(na<<2)>>2]|0;if((xa|0)>0){la=s+(na<<2)|0;ya=0;ma=za;Ba=za;za=xa;while(1){va=c[T>>2]|0;if((va|0)==2){La=c[(c[la>>2]|0)+(ya<<2)>>2]|0;if(La>>>0>255>>>0){Xa=-La>>31&255}else{Xa=La&255}a[ma]=Xa;Ya=Ba;Za=ma+1|0;_a=c[t>>2]|0}else if((va|0)==3|(va|0)==5){va=c[(c[la>>2]|0)+(ya<<2)>>2]|0;if((va+32768|0)>>>0>65535>>>0){$a=(va>>31^32767)&65535}else{$a=va&65535}b[Ba>>1]=$a;Ya=Ba+2|0;Za=ma;_a=za}else{Ya=Ba;Za=ma;_a=za}va=ya+1|0;if((va|0)<(_a|0)){ya=va;ma=Za;Ba=Ya;za=_a}else{break}}ab=_a;bb=c[K>>2]|0}else{ab=xa;bb=Aa}za=na+1|0;if(za>>>0<bb>>>0){na=za;xa=ab;Aa=bb}else{break}}}c[g>>2]=1}}while(0);if(!((c[L>>2]|0)>>>0<(c[K>>2]|0)>>>0)){break b}Y=c[F>>2]|0;ja=c[l>>2]|0}if((A|0)==102){c[g>>2]=0;break}else if((A|0)==104){KIb(e,16,2357312,(B=i,i=i+8|0,c[B>>2]=ka,B)|0);i=B;c[g>>2]=0;break}else if((A|0)==115){KIb(e,16,2294264,(B=i,i=i+1|0,i=i+7&-8,c[B>>2]=0,B)|0);i=B;C=-1163346256;i=j;return C|0}else if((A|0)==117){KIb(e,16,2243272,(B=i,i=i+8|0,c[B>>2]=ra,B)|0);i=B;C=-22;i=j;return C|0}else if((A|0)==119){c[S>>2]=1}else if((A|0)==142){KIb(c[o>>2]|0,16,2170136,(B=i,i=i+8|0,c[B>>2]=Ea,B)|0);i=B;C=-22;i=j;return C|0}else if((A|0)==145){KIb(c[o>>2]|0,16,2170136,(B=i,i=i+8|0,c[B>>2]=ka,B)|0);i=B;C=-1094995529;i=j;return C|0}else if((A|0)==208){i=j;return C|0}c[g>>2]=0}}while(0);if(!((c[L>>2]|0)>>>0<(c[K>>2]|0)>>>0)){break}c[g>>2]=0}}while(0);g=c[F>>2]|0;F=(g|0)/8|0;c[z>>2]=g-(F<<3);if((F|0)>(w|0)){KIb(c[o>>2]|0,16,2201912,(B=i,i=i+8|0,c[B>>2]=F-w,B)|0);i=B;c[o+140>>2]=0;c[o+144>>2]=0;C=-1094995529;i=j;return C|0}B=o+140|0;w=c[B>>2]|0;if((w|0)==0){C=F;i=j;return C|0}g=o+144|0;c[g>>2]=(c[g>>2]|0)+F;c[B>>2]=w-F;C=x;i=j;return C|0}function k0a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a+60>>2]|0;a=b+32|0;if((c[a>>2]|0)==0){d=b+136|0;mJb(d);e=b+132|0;mJb(e);return 0}f=b+36|0;g=b+68|0;h=b+100|0;i=0;do{c[f+(i<<2)>>2]=0;mJb(g+(i<<2)|0);mJb(h+(i<<2)|0);i=i+1|0;}while(i>>>0<(c[a>>2]|0)>>>0);d=b+136|0;mJb(d);e=b+132|0;mJb(e);return 0}function l0a(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;h=c[a>>2]|0;i=h+(f>>>3)|0;j=(je(d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0)|0)<<(f&7);i=j>>>0>65535>>>0;k=i?j>>>16:j;l=i?16:0;if((k&65280|0)==0){m=l;n=k}else{m=l|8;n=k>>>8}k=(d[1359664+n|0]|0)+m|0;m=k-b|0;if(!((m|0)<7|(k|0)==-2147483615)){n=b+32+f-k|0;c[e>>2]=g>>>0>n>>>0?n:g;o=(j>>>(m>>>0))+(30-k<<b)|0;return o|0}do{if((j|0)>-1){k=c[a+12>>2]|0;m=f;n=0;do{if(!(k>>>0>m>>>0)){o=-1;p=16;break}l=m+1|0;m=g>>>0>l>>>0?l:g;l=h+(m>>>3)|0;q=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7);n=n+1|0;}while((n|0)!=2147483647&(q|0)>-1);if((p|0)==16){return o|0}k=m+1|0;l=g>>>0>k>>>0?k:g;if((n|0)<2147483646){r=n;s=q;t=l;break}if((n|0)!=2147483646){o=-1;return o|0}c[e>>2]=l;o=0;return o|0}else{l=f+1|0;r=0;s=j;t=g>>>0>l>>>0?l:g}}while(0);if((b|0)==0){u=t;v=0}else{j=t+b|0;u=g>>>0>j>>>0?j:g;v=s<<1>>>((32-b|0)>>>0)}c[e>>2]=u;o=v+(r<<b)|0;return o|0}function m0a(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;n0a(e);n0a(e+16|0);n0a(e+32|0);n0a(e+48|0);n0a(e+64|0);n0a(e+80|0);n0a(e+96|0);n0a(e+112|0);f=d<<1;g=f+d|0;h=g+d|0;i=h+d|0;j=i+d|0;k=j+d|0;l=0;do{m=((b[e+(l<<1)>>1]|0)*16383|0)+524256|0;n=b[e+(l+16<<1)>>1]|0;o=m+(n*21407|0)|0;p=m+(n*8867|0)|0;q=m+(n*-8867|0)|0;r=m+(n*-21407|0)|0;n=b[e+(l+8<<1)>>1]|0;m=b[e+(l+24<<1)>>1]|0;s=(m*19266|0)+(n*22725|0)|0;t=(m*-4520|0)+(n*19266|0)|0;u=(m*-22725|0)+(n*12873|0)|0;v=(m*-12873|0)+(n*4520|0)|0;n=b[e+(l+32<<1)>>1]|0;if(n<<16>>16==0){w=r;x=q;y=p;z=o}else{m=n<<16>>16;n=m*16383|0;A=m*-16383|0;w=n+r|0;x=A+q|0;y=A+p|0;z=n+o|0}o=b[e+(l+40<<1)>>1]|0;if(o<<16>>16==0){B=v;C=u;D=t;E=s}else{n=o<<16>>16;B=(n*19266|0)+v|0;C=(n*4520|0)+u|0;D=(n*-22725|0)+t|0;E=(n*12873|0)+s|0}s=b[e+(l+48<<1)>>1]|0;if(s<<16>>16==0){F=w;G=x;H=y;I=z}else{n=s<<16>>16;F=(n*-8867|0)+w|0;G=(n*21407|0)+x|0;H=(n*-21407|0)+y|0;I=(n*8867|0)+z|0}n=b[e+(l+56<<1)>>1]|0;if(n<<16>>16==0){J=B;K=C;L=D;M=E}else{s=n<<16>>16;J=(s*-22725|0)+B|0;K=(s*19266|0)+C|0;L=(s*-12873|0)+D|0;M=(s*4520|0)+E|0}s=M+I>>20;if(s>>>0>255>>>0){N=-s>>31&255}else{N=s&255}a[c+l|0]=N;s=L+H>>20;if(s>>>0>255>>>0){O=-s>>31&255}else{O=s&255}a[c+(l+d)|0]=O;s=K+G>>20;if(s>>>0>255>>>0){P=-s>>31&255}else{P=s&255}a[c+(l+f)|0]=P;s=J+F>>20;if(s>>>0>255>>>0){Q=-s>>31&255}else{Q=s&255}a[c+(l+g)|0]=Q;s=F-J>>20;if(s>>>0>255>>>0){R=-s>>31&255}else{R=s&255}a[c+(l+h)|0]=R;s=G-K>>20;if(s>>>0>255>>>0){S=-s>>31&255}else{S=s&255}a[c+(l+i)|0]=S;s=H-L>>20;if(s>>>0>255>>>0){T=-s>>31&255}else{T=s&255}a[c+(l+j)|0]=T;s=I-M>>20;if(s>>>0>255>>>0){U=-s>>31&255}else{U=s&255}a[c+(k+l)|0]=U;l=l+1|0;}while((l|0)<8);return}function n0a(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=a+4|0;e=d;f=c[e>>2]|0;g=a+8|0;h=g;i=a+12|0;j=i;k=c[j>>2]|0;l=a+2|0;m=b[l>>1]|0;n=b[a>>1]|0;if((c[h>>2]|f|k|m|0)==0){o=n<<3&65528|n<<19;c[j>>2]=o;c[h>>2]=o;c[e>>2]=o;c[a>>2]=o;return}o=(n*16383|0)+1024|0;n=f<<16>>16;f=n*21407|0;e=f+o|0;h=n*8867|0;n=h+o|0;j=o-h|0;h=o-f|0;f=a+6|0;o=b[f>>1]|0;p=(o*19266|0)+(m*22725|0)|0;q=(o*-4520|0)+(m*19266|0)|0;r=(o*-22725|0)+(m*12873|0)|0;s=(o*-12873|0)+(m*4520|0)|0;m=g;o=c[m>>2]|0;if((o|0)==0&(c[m+4>>2]|0)==0){t=s;u=r;v=q;w=p;x=h;y=j;z=n;A=e;B=a+14|0;C=a+10|0}else{m=(o&65535)<<16>>16;o=m*16383|0;D=k<<16>>16;k=D*8867|0;E=m*-16383|0;m=D*21407|0;D=a+10|0;F=b[D>>1]|0;G=a+14|0;H=b[G>>1]|0;t=(F*19266|0)+s+(H*-22725|0)|0;u=(F*4520|0)+r+(H*19266|0)|0;v=(F*-22725|0)+q+(H*-12873|0)|0;w=(F*12873|0)+p+(H*4520|0)|0;x=o+h-k|0;y=E+j+m|0;z=E+n-m|0;A=o+e+k|0;B=G;C=D}b[a>>1]=(w+A|0)>>>11;b[B>>1]=(A-w|0)>>>11;b[l>>1]=(v+z|0)>>>11;b[i>>1]=(z-v|0)>>>11;b[d>>1]=(u+y|0)>>>11;b[C>>1]=(y-u|0)>>>11;b[f>>1]=(t+x|0)>>>11;b[g>>1]=(x-t|0)>>>11;return}function o0a(a,b,c){a=a|0;b=b|0;c=c|0;n0a(c);n0a(c+16|0);n0a(c+32|0);n0a(c+48|0);n0a(c+64|0);n0a(c+80|0);n0a(c+96|0);n0a(c+112|0);p0a(a,b,c);p0a(a+1|0,b,c+2|0);p0a(a+2|0,b,c+4|0);p0a(a+3|0,b,c+6|0);p0a(a+4|0,b,c+8|0);p0a(a+5|0,b,c+10|0);p0a(a+6|0,b,c+12|0);p0a(a+7|0,b,c+14|0);return}function p0a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=((b[f>>1]|0)*16383|0)+524256|0;h=b[f+32>>1]|0;i=g+(h*21407|0)|0;j=g+(h*8867|0)|0;k=g+(h*-8867|0)|0;l=g+(h*-21407|0)|0;h=b[f+16>>1]|0;g=b[f+48>>1]|0;m=(g*19266|0)+(h*22725|0)|0;n=(g*-4520|0)+(h*19266|0)|0;o=(g*-22725|0)+(h*12873|0)|0;p=(g*-12873|0)+(h*4520|0)|0;h=b[f+64>>1]|0;if(h<<16>>16==0){q=l;r=k;s=j;t=i}else{g=h<<16>>16;h=g*16383|0;u=g*-16383|0;q=h+l|0;r=u+k|0;s=u+j|0;t=h+i|0}i=b[f+80>>1]|0;if(i<<16>>16==0){v=p;w=o;x=n;y=m}else{h=i<<16>>16;v=(h*19266|0)+p|0;w=(h*4520|0)+o|0;x=(h*-22725|0)+n|0;y=(h*12873|0)+m|0}m=b[f+96>>1]|0;if(m<<16>>16==0){z=q;A=r;B=s;C=t}else{h=m<<16>>16;z=(h*-8867|0)+q|0;A=(h*21407|0)+r|0;B=(h*-21407|0)+s|0;C=(h*8867|0)+t|0}t=b[f+112>>1]|0;if(t<<16>>16==0){D=v;E=w;F=x;G=y}else{f=t<<16>>16;D=(f*-22725|0)+v|0;E=(f*19266|0)+w|0;F=(f*-12873|0)+x|0;G=(f*4520|0)+y|0}y=(d[c]|0)+(G+C>>20)|0;if(y>>>0>255>>>0){H=-y>>31&255}else{H=y&255}a[c]=H;H=c+e|0;y=(d[H]|0)+(F+B>>20)|0;if(y>>>0>255>>>0){I=-y>>31&255}else{I=y&255}a[H]=I;I=e<<1;H=c+I|0;y=(d[H]|0)+(E+A>>20)|0;if(y>>>0>255>>>0){J=-y>>31&255}else{J=y&255}a[H]=J;J=I+e|0;I=c+J|0;H=(d[I]|0)+(D+z>>20)|0;if(H>>>0>255>>>0){K=-H>>31&255}else{K=H&255}a[I]=K;K=J+e|0;J=c+K|0;I=(d[J]|0)+(z-D>>20)|0;if(I>>>0>255>>>0){L=-I>>31&255}else{L=I&255}a[J]=L;L=K+e|0;K=c+L|0;J=(d[K]|0)+(A-E>>20)|0;if(J>>>0>255>>>0){M=-J>>31&255}else{M=J&255}a[K]=M;M=L+e|0;L=c+M|0;K=(d[L]|0)+(B-F>>20)|0;if(K>>>0>255>>>0){N=-K>>31&255}else{N=K&255}a[L]=N;N=c+(M+e)|0;e=(d[N]|0)+(C-G>>20)|0;if(!(e>>>0>255>>>0)){O=e&255;a[N]=O;return}O=-e>>31&255;a[N]=O;return}function q0a(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;n0a(a);n0a(a+16|0);n0a(a+32|0);n0a(a+48|0);n0a(a+64|0);n0a(a+80|0);n0a(a+96|0);n0a(a+112|0);c=0;do{d=a+(c<<1)|0;e=((b[d>>1]|0)*16383|0)+524256|0;f=a+(c+16<<1)|0;g=b[f>>1]|0;h=e+(g*21407|0)|0;i=e+(g*8867|0)|0;j=e+(g*-8867|0)|0;k=e+(g*-21407|0)|0;g=a+(c+8<<1)|0;e=b[g>>1]|0;l=a+(c+24<<1)|0;m=b[l>>1]|0;n=(m*19266|0)+(e*22725|0)|0;o=(m*-4520|0)+(e*19266|0)|0;p=(m*-22725|0)+(e*12873|0)|0;q=(m*-12873|0)+(e*4520|0)|0;e=a+(c+32<<1)|0;m=b[e>>1]|0;if(m<<16>>16==0){r=k;s=j;t=i;u=h}else{v=m<<16>>16;m=v*16383|0;w=v*-16383|0;r=m+k|0;s=w+j|0;t=w+i|0;u=m+h|0}h=a+(c+40<<1)|0;m=b[h>>1]|0;if(m<<16>>16==0){x=q;y=p;z=o;A=n}else{i=m<<16>>16;x=(i*19266|0)+q|0;y=(i*4520|0)+p|0;z=(i*-22725|0)+o|0;A=(i*12873|0)+n|0}n=a+(c+48<<1)|0;i=b[n>>1]|0;if(i<<16>>16==0){B=r;C=s;D=t;E=u}else{o=i<<16>>16;B=(o*-8867|0)+r|0;C=(o*21407|0)+s|0;D=(o*-21407|0)+t|0;E=(o*8867|0)+u|0}o=a+(c+56<<1)|0;i=b[o>>1]|0;if(i<<16>>16==0){F=x;G=y;H=z;I=A}else{p=i<<16>>16;F=(p*-22725|0)+x|0;G=(p*19266|0)+y|0;H=(p*-12873|0)+z|0;I=(p*4520|0)+A|0}b[d>>1]=I+E>>20;b[g>>1]=H+D>>20;b[f>>1]=G+C>>20;b[l>>1]=F+B>>20;b[e>>1]=B-F>>20;b[h>>1]=C-G>>20;b[n>>1]=D-H>>20;b[o>>1]=E-I>>20;c=c+1|0;}while((c|0)<8);return}function r0a(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=a;s0a(d,0);s0a(d+16|0,0);s0a(d+32|0,0);s0a(d+48|0,0);s0a(d+64|0,0);s0a(d+80|0,0);s0a(d+96|0,0);s0a(d+112|0,0);a=c>>>1;c=a<<1;g=c+a|0;h=g+a|0;i=h+a|0;j=i+a|0;k=j+a|0;l=0;do{m=(e[d+(l<<1)>>1]<<16)+524288|0;n=b[d+(l+16<<1)>>1]|0;o=m+(n*85628|0)|0;p=m+(n*35468|0)|0;q=m+(n*-35468|0)|0;r=m+(n*-85628|0)|0;n=b[d+(l+8<<1)>>1]|0;m=b[d+(l+24<<1)>>1]|0;s=(m*77060|0)+(n*90900|0)|0;t=(m*-18080|0)+(n*77060|0)|0;u=(m*-90900|0)+(n*51492|0)|0;v=(m*-51492|0)+(n*18080|0)|0;n=b[d+(l+32<<1)>>1]|0;if(n<<16>>16==0){w=r;x=q;y=p;z=o}else{m=n<<16>>16;n=m<<16;A=m*-65536|0;w=n+r|0;x=A+q|0;y=A+p|0;z=n+o|0}o=b[d+(l+40<<1)>>1]|0;if(o<<16>>16==0){B=v;C=u;D=t;E=s}else{n=o<<16>>16;B=(n*77060|0)+v|0;C=(n*18080|0)+u|0;D=(n*-90900|0)+t|0;E=(n*51492|0)+s|0}s=b[d+(l+48<<1)>>1]|0;if(s<<16>>16==0){F=w;G=x;H=y;I=z}else{n=s<<16>>16;F=(n*-35468|0)+w|0;G=(n*85628|0)+x|0;H=(n*-85628|0)+y|0;I=(n*35468|0)+z|0}n=b[d+(l+56<<1)>>1]|0;if(n<<16>>16==0){J=B;K=C;L=D;M=E}else{s=n<<16>>16;J=(s*-90900|0)+B|0;K=(s*77060|0)+C|0;L=(s*-51492|0)+D|0;M=(s*18080|0)+E|0}s=M+I>>20;if(s>>>0<1024>>>0){N=s&65535}else{N=-s>>31&1023}b[f+(l<<1)>>1]=N;s=L+H>>20;if(s>>>0<1024>>>0){O=s&65535}else{O=-s>>31&1023}b[f+(l+a<<1)>>1]=O;s=K+G>>20;if(s>>>0<1024>>>0){P=s&65535}else{P=-s>>31&1023}b[f+(l+c<<1)>>1]=P;s=J+F>>20;if(s>>>0<1024>>>0){Q=s&65535}else{Q=-s>>31&1023}b[f+(l+g<<1)>>1]=Q;s=F-J>>20;if(s>>>0<1024>>>0){R=s&65535}else{R=-s>>31&1023}b[f+(l+h<<1)>>1]=R;s=G-K>>20;if(s>>>0<1024>>>0){S=s&65535}else{S=-s>>31&1023}b[f+(l+i<<1)>>1]=S;s=H-L>>20;if(s>>>0<1024>>>0){T=s&65535}else{T=-s>>31&1023}b[f+(l+j<<1)>>1]=T;s=I-M>>20;if(s>>>0<1024>>>0){U=s&65535}else{U=-s>>31&1023}b[f+(k+l<<1)>>1]=U;l=l+1|0;}while((l|0)<8);return}function s0a(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=a;f=a+4|0;g=f;h=c[g>>2]|0;i=a+8|0;j=i;k=a+12|0;l=k;m=c[l>>2]|0;n=a+2|0;o=b[n>>1]|0;if((c[j>>2]|h|m|o|0)==0){p=1-d|0;q=b[a>>1]|0;if((p|0)>-1){r=q<<p}else{r=q+(1<<d-2)>>d-1}q=r&65535|r<<16;c[l>>2]=q;c[j>>2]=q;c[g>>2]=q;c[e>>2]=q;return}else{q=d+15|0;e=(b[a>>1]<<16)+(1<<d+14)|0;d=h<<16>>16;h=d*85628|0;g=e+h|0;j=d*35468|0;d=e+j|0;l=e-j|0;j=e-h|0;h=a+6|0;e=b[h>>1]|0;r=(e*77060|0)+(o*90900|0)|0;p=(e*-18080|0)+(o*77060|0)|0;s=(e*-90900|0)+(o*51492|0)|0;t=(e*-51492|0)+(o*18080|0)|0;o=i;e=c[o>>2]|0;if((e|0)==0&(c[o+4>>2]|0)==0){u=t;v=s;w=p;x=r;y=j;z=l;A=d;B=g;C=a+14|0;D=a+10|0}else{o=(e&65535)<<16>>16;e=o<<16;E=m<<16>>16;m=E*35468|0;F=o*-65536|0;o=E*85628|0;E=a+10|0;G=b[E>>1]|0;H=a+14|0;I=b[H>>1]|0;u=(G*77060|0)+t+(I*-90900|0)|0;v=(G*18080|0)+s+(I*77060|0)|0;w=(G*-90900|0)+p+(I*-51492|0)|0;x=(G*51492|0)+r+(I*18080|0)|0;y=e+j-m|0;z=F+l+o|0;A=F+d-o|0;B=e+g+m|0;C=H;D=E}b[a>>1]=x+B>>q;b[C>>1]=B-x>>q;b[n>>1]=w+A>>q;b[k>>1]=A-w>>q;b[f>>1]=v+z>>q;b[D>>1]=z-v>>q;b[h>>1]=u+y>>q;b[i>>1]=y-u>>q;return}}function t0a(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=a;s0a(d,0);s0a(d+16|0,0);s0a(d+32|0,0);s0a(d+48|0,0);s0a(d+64|0,0);s0a(d+80|0,0);s0a(d+96|0,0);s0a(d+112|0,0);a=c>>>1;c=a<<1;g=c+a|0;h=g+a|0;i=h+a|0;j=i+a|0;k=j+a|0;l=0;do{m=f+(l<<1)|0;n=(e[d+(l<<1)>>1]<<16)+524288|0;o=b[d+(l+16<<1)>>1]|0;p=n+(o*85628|0)|0;q=n+(o*35468|0)|0;r=n+(o*-35468|0)|0;s=n+(o*-85628|0)|0;o=b[d+(l+8<<1)>>1]|0;n=b[d+(l+24<<1)>>1]|0;t=(n*77060|0)+(o*90900|0)|0;u=(n*-18080|0)+(o*77060|0)|0;v=(n*-90900|0)+(o*51492|0)|0;w=(n*-51492|0)+(o*18080|0)|0;o=b[d+(l+32<<1)>>1]|0;if(o<<16>>16==0){x=s;y=r;z=q;A=p}else{n=o<<16>>16;o=n<<16;B=n*-65536|0;x=o+s|0;y=B+r|0;z=B+q|0;A=o+p|0}p=b[d+(l+40<<1)>>1]|0;if(p<<16>>16==0){C=w;D=v;E=u;F=t}else{o=p<<16>>16;C=(o*77060|0)+w|0;D=(o*18080|0)+v|0;E=(o*-90900|0)+u|0;F=(o*51492|0)+t|0}t=b[d+(l+48<<1)>>1]|0;if(t<<16>>16==0){G=x;H=y;I=z;J=A}else{o=t<<16>>16;G=(o*-35468|0)+x|0;H=(o*85628|0)+y|0;I=(o*-85628|0)+z|0;J=(o*35468|0)+A|0}o=b[d+(l+56<<1)>>1]|0;if(o<<16>>16==0){K=C;L=D;M=E;N=F}else{t=o<<16>>16;K=(t*-90900|0)+C|0;L=(t*77060|0)+D|0;M=(t*-51492|0)+E|0;N=(t*18080|0)+F|0}t=(e[m>>1]|0)+(N+J>>20)|0;if(t>>>0<1024>>>0){O=t&65535}else{O=-t>>31&1023}b[m>>1]=O;m=f+(l+a<<1)|0;t=(e[m>>1]|0)+(M+I>>20)|0;if(t>>>0<1024>>>0){P=t&65535}else{P=-t>>31&1023}b[m>>1]=P;m=f+(l+c<<1)|0;t=(e[m>>1]|0)+(L+H>>20)|0;if(t>>>0<1024>>>0){Q=t&65535}else{Q=-t>>31&1023}b[m>>1]=Q;m=f+(l+g<<1)|0;t=(e[m>>1]|0)+(K+G>>20)|0;if(t>>>0<1024>>>0){R=t&65535}else{R=-t>>31&1023}b[m>>1]=R;m=f+(l+h<<1)|0;t=(e[m>>1]|0)+(G-K>>20)|0;if(t>>>0<1024>>>0){S=t&65535}else{S=-t>>31&1023}b[m>>1]=S;m=f+(l+i<<1)|0;t=(e[m>>1]|0)+(H-L>>20)|0;if(t>>>0<1024>>>0){T=t&65535}else{T=-t>>31&1023}b[m>>1]=T;m=f+(l+j<<1)|0;t=(e[m>>1]|0)+(I-M>>20)|0;if(t>>>0<1024>>>0){U=t&65535}else{U=-t>>31&1023}b[m>>1]=U;m=f+(k+l<<1)|0;t=(e[m>>1]|0)+(J-N>>20)|0;if(t>>>0<1024>>>0){V=t&65535}else{V=-t>>31&1023}b[m>>1]=V;l=l+1|0;}while((l|0)<8);return}function u0a(a){a=a|0;s0a(a,0);s0a(a+16|0,0);s0a(a+32|0,0);s0a(a+48|0,0);s0a(a+64|0,0);s0a(a+80|0,0);s0a(a+96|0,0);s0a(a+112|0,0);v0a(a);v0a(a+2|0);v0a(a+4|0);v0a(a+6|0);v0a(a+8|0);v0a(a+10|0);v0a(a+12|0);v0a(a+14|0);return}function v0a(a){a=a|0;var c=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;c=(e[a>>1]<<16)+524288|0;d=a+32|0;f=b[d>>1]|0;g=c+(f*85628|0)|0;h=c+(f*35468|0)|0;i=c+(f*-35468|0)|0;j=c+(f*-85628|0)|0;f=a+16|0;c=b[f>>1]|0;k=a+48|0;l=b[k>>1]|0;m=(l*77060|0)+(c*90900|0)|0;n=(l*-18080|0)+(c*77060|0)|0;o=(l*-90900|0)+(c*51492|0)|0;p=(l*-51492|0)+(c*18080|0)|0;c=a+64|0;l=b[c>>1]|0;if(l<<16>>16==0){q=j;r=i;s=h;t=g}else{u=l<<16>>16;l=u<<16;v=u*-65536|0;q=l+j|0;r=v+i|0;s=v+h|0;t=l+g|0}g=a+80|0;l=b[g>>1]|0;if(l<<16>>16==0){w=p;x=o;y=n;z=m}else{h=l<<16>>16;w=(h*77060|0)+p|0;x=(h*18080|0)+o|0;y=(h*-90900|0)+n|0;z=(h*51492|0)+m|0}m=a+96|0;h=b[m>>1]|0;if(h<<16>>16==0){A=q;B=r;C=s;D=t}else{n=h<<16>>16;A=(n*-35468|0)+q|0;B=(n*85628|0)+r|0;C=(n*-85628|0)+s|0;D=(n*35468|0)+t|0}t=a+112|0;n=b[t>>1]|0;if(n<<16>>16==0){E=w;F=x;G=y;H=z}else{s=n<<16>>16;E=(s*-90900|0)+w|0;F=(s*77060|0)+x|0;G=(s*-51492|0)+y|0;H=(s*18080|0)+z|0}b[a>>1]=H+D>>20;b[f>>1]=G+C>>20;b[d>>1]=F+B>>20;b[k>>1]=E+A>>20;b[c>>1]=A-E>>20;b[g>>1]=B-F>>20;b[m>>1]=C-G>>20;b[t>>1]=D-H>>20;return}function w0a(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=a;x0a(d);x0a(d+16|0);x0a(d+32|0);x0a(d+48|0);x0a(d+64|0);x0a(d+80|0);x0a(d+96|0);x0a(d+112|0);a=c>>>1;c=a<<1;f=c+a|0;g=f+a|0;h=g+a|0;i=h+a|0;j=i+a|0;k=0;do{l=((b[d+(k<<1)>>1]|0)*32767|0)+65534|0;m=b[d+(k+16<<1)>>1]|0;n=l+(m*42813|0)|0;o=l+(m*17734|0)|0;p=l+(m*-17734|0)|0;q=l+(m*-42813|0)|0;m=b[d+(k+8<<1)>>1]|0;l=b[d+(k+24<<1)>>1]|0;r=(l*38531|0)+(m*45451|0)|0;s=(l*-9041|0)+(m*38531|0)|0;t=(l*-45451|0)+(m*25746|0)|0;u=(l*-25746|0)+(m*9041|0)|0;m=b[d+(k+32<<1)>>1]|0;if(m<<16>>16==0){v=q;w=p;x=o;y=n}else{l=m<<16>>16;m=l*32767|0;z=l*-32767|0;v=m+q|0;w=z+p|0;x=z+o|0;y=m+n|0}n=b[d+(k+40<<1)>>1]|0;if(n<<16>>16==0){A=u;B=t;C=s;D=r}else{m=n<<16>>16;A=(m*38531|0)+u|0;B=(m*9041|0)+t|0;C=(m*-45451|0)+s|0;D=(m*25746|0)+r|0}r=b[d+(k+48<<1)>>1]|0;if(r<<16>>16==0){E=v;F=w;G=x;H=y}else{m=r<<16>>16;E=(m*-17734|0)+v|0;F=(m*42813|0)+w|0;G=(m*-42813|0)+x|0;H=(m*17734|0)+y|0}m=b[d+(k+56<<1)>>1]|0;if(m<<16>>16==0){I=A;J=B;K=C;L=D}else{r=m<<16>>16;I=(r*-45451|0)+A|0;J=(r*38531|0)+B|0;K=(r*-25746|0)+C|0;L=(r*9041|0)+D|0}r=L+H>>17;if(r>>>0<4096>>>0){M=r&65535}else{M=-r>>31&4095}b[e+(k<<1)>>1]=M;r=K+G>>17;if(r>>>0<4096>>>0){N=r&65535}else{N=-r>>31&4095}b[e+(k+a<<1)>>1]=N;r=J+F>>17;if(r>>>0<4096>>>0){O=r&65535}else{O=-r>>31&4095}b[e+(k+c<<1)>>1]=O;r=I+E>>17;if(r>>>0<4096>>>0){P=r&65535}else{P=-r>>31&4095}b[e+(k+f<<1)>>1]=P;r=E-I>>17;if(r>>>0<4096>>>0){Q=r&65535}else{Q=-r>>31&4095}b[e+(k+g<<1)>>1]=Q;r=F-J>>17;if(r>>>0<4096>>>0){R=r&65535}else{R=-r>>31&4095}b[e+(k+h<<1)>>1]=R;r=G-K>>17;if(r>>>0<4096>>>0){S=r&65535}else{S=-r>>31&4095}b[e+(k+i<<1)>>1]=S;r=H-L>>17;if(r>>>0<4096>>>0){T=r&65535}else{T=-r>>31&4095}b[e+(j+k<<1)>>1]=T;k=k+1|0;}while((k|0)<8);return}function x0a(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=a+4|0;e=d;f=c[e>>2]|0;g=a+8|0;h=g;i=a+12|0;j=i;k=c[j>>2]|0;l=a+2|0;m=b[l>>1]|0;n=b[a>>1]|0;if((c[h>>2]|f|k|m|0)==0){o=(n+1|0)>>>1;p=o&65535|o<<16;c[j>>2]=p;c[h>>2]=p;c[e>>2]=p;c[a>>2]=p;return}p=(n*32767|0)+32768|0;n=f<<16>>16;f=n*42813|0;e=f+p|0;h=n*17734|0;n=h+p|0;j=p-h|0;h=p-f|0;f=a+6|0;p=b[f>>1]|0;o=(p*38531|0)+(m*45451|0)|0;q=(p*-9041|0)+(m*38531|0)|0;r=(p*-45451|0)+(m*25746|0)|0;s=(p*-25746|0)+(m*9041|0)|0;m=g;p=c[m>>2]|0;if((p|0)==0&(c[m+4>>2]|0)==0){t=s;u=r;v=q;w=o;x=h;y=j;z=n;A=e;B=a+14|0;C=a+10|0}else{m=(p&65535)<<16>>16;p=m*32767|0;D=k<<16>>16;k=D*17734|0;E=m*-32767|0;m=D*42813|0;D=a+10|0;F=b[D>>1]|0;G=a+14|0;H=b[G>>1]|0;t=(F*38531|0)+s+(H*-45451|0)|0;u=(F*9041|0)+r+(H*38531|0)|0;v=(F*-45451|0)+q+(H*-25746|0)|0;w=(F*25746|0)+o+(H*9041|0)|0;x=p+h-k|0;y=E+j+m|0;z=E+n-m|0;A=p+e+k|0;B=G;C=D}b[a>>1]=(w+A|0)>>>16;b[B>>1]=(A-w|0)>>>16;b[l>>1]=(v+z|0)>>>16;b[i>>1]=(z-v|0)>>>16;b[d>>1]=(u+y|0)>>>16;b[C>>1]=(y-u|0)>>>16;b[f>>1]=(t+x|0)>>>16;b[g>>1]=(x-t|0)>>>16;return}function y0a(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=a;x0a(d);x0a(d+16|0);x0a(d+32|0);x0a(d+48|0);x0a(d+64|0);x0a(d+80|0);x0a(d+96|0);x0a(d+112|0);a=c>>>1;c=a<<1;g=c+a|0;h=g+a|0;i=h+a|0;j=i+a|0;k=j+a|0;l=0;do{m=f+(l<<1)|0;n=((b[d+(l<<1)>>1]|0)*32767|0)+65534|0;o=b[d+(l+16<<1)>>1]|0;p=n+(o*42813|0)|0;q=n+(o*17734|0)|0;r=n+(o*-17734|0)|0;s=n+(o*-42813|0)|0;o=b[d+(l+8<<1)>>1]|0;n=b[d+(l+24<<1)>>1]|0;t=(n*38531|0)+(o*45451|0)|0;u=(n*-9041|0)+(o*38531|0)|0;v=(n*-45451|0)+(o*25746|0)|0;w=(n*-25746|0)+(o*9041|0)|0;o=b[d+(l+32<<1)>>1]|0;if(o<<16>>16==0){x=s;y=r;z=q;A=p}else{n=o<<16>>16;o=n*32767|0;B=n*-32767|0;x=o+s|0;y=B+r|0;z=B+q|0;A=o+p|0}p=b[d+(l+40<<1)>>1]|0;if(p<<16>>16==0){C=w;D=v;E=u;F=t}else{o=p<<16>>16;C=(o*38531|0)+w|0;D=(o*9041|0)+v|0;E=(o*-45451|0)+u|0;F=(o*25746|0)+t|0}t=b[d+(l+48<<1)>>1]|0;if(t<<16>>16==0){G=x;H=y;I=z;J=A}else{o=t<<16>>16;G=(o*-17734|0)+x|0;H=(o*42813|0)+y|0;I=(o*-42813|0)+z|0;J=(o*17734|0)+A|0}o=b[d+(l+56<<1)>>1]|0;if(o<<16>>16==0){K=C;L=D;M=E;N=F}else{t=o<<16>>16;K=(t*-45451|0)+C|0;L=(t*38531|0)+D|0;M=(t*-25746|0)+E|0;N=(t*9041|0)+F|0}t=(e[m>>1]|0)+(N+J>>17)|0;if(t>>>0<4096>>>0){O=t&65535}else{O=-t>>31&4095}b[m>>1]=O;m=f+(l+a<<1)|0;t=(e[m>>1]|0)+(M+I>>17)|0;if(t>>>0<4096>>>0){P=t&65535}else{P=-t>>31&4095}b[m>>1]=P;m=f+(l+c<<1)|0;t=(e[m>>1]|0)+(L+H>>17)|0;if(t>>>0<4096>>>0){Q=t&65535}else{Q=-t>>31&4095}b[m>>1]=Q;m=f+(l+g<<1)|0;t=(e[m>>1]|0)+(K+G>>17)|0;if(t>>>0<4096>>>0){R=t&65535}else{R=-t>>31&4095}b[m>>1]=R;m=f+(l+h<<1)|0;t=(e[m>>1]|0)+(G-K>>17)|0;if(t>>>0<4096>>>0){S=t&65535}else{S=-t>>31&4095}b[m>>1]=S;m=f+(l+i<<1)|0;t=(e[m>>1]|0)+(H-L>>17)|0;if(t>>>0<4096>>>0){T=t&65535}else{T=-t>>31&4095}b[m>>1]=T;m=f+(l+j<<1)|0;t=(e[m>>1]|0)+(I-M>>17)|0;if(t>>>0<4096>>>0){U=t&65535}else{U=-t>>31&4095}b[m>>1]=U;m=f+(k+l<<1)|0;t=(e[m>>1]|0)+(J-N>>17)|0;if(t>>>0<4096>>>0){V=t&65535}else{V=-t>>31&4095}b[m>>1]=V;l=l+1|0;}while((l|0)<8);return}function z0a(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;x0a(a);x0a(a+16|0);x0a(a+32|0);x0a(a+48|0);x0a(a+64|0);x0a(a+80|0);x0a(a+96|0);x0a(a+112|0);c=0;do{d=a+(c<<1)|0;e=((b[d>>1]|0)*32767|0)+65534|0;f=a+(c+16<<1)|0;g=b[f>>1]|0;h=e+(g*42813|0)|0;i=e+(g*17734|0)|0;j=e+(g*-17734|0)|0;k=e+(g*-42813|0)|0;g=a+(c+8<<1)|0;e=b[g>>1]|0;l=a+(c+24<<1)|0;m=b[l>>1]|0;n=(m*38531|0)+(e*45451|0)|0;o=(m*-9041|0)+(e*38531|0)|0;p=(m*-45451|0)+(e*25746|0)|0;q=(m*-25746|0)+(e*9041|0)|0;e=a+(c+32<<1)|0;m=b[e>>1]|0;if(m<<16>>16==0){r=k;s=j;t=i;u=h}else{v=m<<16>>16;m=v*32767|0;w=v*-32767|0;r=m+k|0;s=w+j|0;t=w+i|0;u=m+h|0}h=a+(c+40<<1)|0;m=b[h>>1]|0;if(m<<16>>16==0){x=q;y=p;z=o;A=n}else{i=m<<16>>16;x=(i*38531|0)+q|0;y=(i*9041|0)+p|0;z=(i*-45451|0)+o|0;A=(i*25746|0)+n|0}n=a+(c+48<<1)|0;i=b[n>>1]|0;if(i<<16>>16==0){B=r;C=s;D=t;E=u}else{o=i<<16>>16;B=(o*-17734|0)+r|0;C=(o*42813|0)+s|0;D=(o*-42813|0)+t|0;E=(o*17734|0)+u|0}o=a+(c+56<<1)|0;i=b[o>>1]|0;if(i<<16>>16==0){F=x;G=y;H=z;I=A}else{p=i<<16>>16;F=(p*-45451|0)+x|0;G=(p*38531|0)+y|0;H=(p*-25746|0)+z|0;I=(p*9041|0)+A|0}b[d>>1]=I+E>>17;b[g>>1]=H+D>>17;b[f>>1]=G+C>>17;b[l>>1]=F+B>>17;b[e>>1]=B-F>>17;b[h>>1]=C-G>>17;b[n>>1]=D-H>>17;b[o>>1]=E-I>>17;c=c+1|0;}while((c|0)<8);return}function A0a(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=e;g=0;while(1){h=b[f>>1]|0;i=f+16|0;j=b[i>>1]|0;b[f>>1]=j+h;b[i>>1]=h-j;j=f+2|0;h=b[j>>1]|0;i=f+18|0;k=b[i>>1]|0;b[j>>1]=k+h;b[i>>1]=h-k;k=f+4|0;h=b[k>>1]|0;i=f+20|0;j=b[i>>1]|0;b[k>>1]=j+h;b[i>>1]=h-j;j=f+6|0;h=b[j>>1]|0;i=f+22|0;k=b[i>>1]|0;b[j>>1]=k+h;b[i>>1]=h-k;k=f+8|0;h=b[k>>1]|0;i=f+24|0;j=b[i>>1]|0;b[k>>1]=j+h;b[i>>1]=h-j;j=f+10|0;h=b[j>>1]|0;i=f+26|0;k=b[i>>1]|0;b[j>>1]=k+h;b[i>>1]=h-k;k=f+12|0;h=b[k>>1]|0;i=f+28|0;j=b[i>>1]|0;b[k>>1]=j+h;b[i>>1]=h-j;j=f+14|0;h=b[j>>1]|0;i=f+30|0;k=b[i>>1]|0;b[j>>1]=k+h;b[i>>1]=h-k;k=g+1|0;if((k|0)<4){f=f+32|0;g=k}else{break}}n0a(e);n0a(e+16|0);n0a(e+32|0);n0a(e+48|0);n0a(e+64|0);n0a(e+80|0);n0a(e+96|0);n0a(e+112|0);g=d<<1;f=d<<2;k=f+g|0;h=0;do{i=b[e+(h<<1)>>1]|0;j=b[e+(h+16<<1)>>1]|0;l=b[e+(h+32<<1)>>1]|0;m=b[e+(h+48<<1)>>1]|0;n=(l+i<<11)+65536|0;o=(i-l<<11)+65536|0;l=(m*1108|0)+(j*2676|0)|0;i=(m*-2676|0)+(j*1108|0)|0;j=n+l>>17;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[c+h|0]=p;j=o+i>>17;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[c+(h+g)|0]=q;j=o-i>>17;if(j>>>0>255>>>0){r=-j>>31&255}else{r=j&255}a[c+(h+f)|0]=r;j=n-l>>17;if(j>>>0>255>>>0){s=-j>>31&255}else{s=j&255}a[c+(h+k)|0]=s;j=h+d|0;l=b[e+(h+8<<1)>>1]|0;n=b[e+(h+24<<1)>>1]|0;i=b[e+(h+40<<1)>>1]|0;o=b[e+(h+56<<1)>>1]|0;m=(i+l<<11)+65536|0;t=(l-i<<11)+65536|0;i=(o*1108|0)+(n*2676|0)|0;l=(o*-2676|0)+(n*1108|0)|0;n=m+i>>17;if(n>>>0>255>>>0){u=-n>>31&255}else{u=n&255}a[c+j|0]=u;n=t+l>>17;if(n>>>0>255>>>0){v=-n>>31&255}else{v=n&255}a[c+(j+g)|0]=v;n=t-l>>17;if(n>>>0>255>>>0){w=-n>>31&255}else{w=n&255}a[c+(j+f)|0]=w;n=m-i>>17;if(n>>>0>255>>>0){x=-n>>31&255}else{x=n&255}a[c+(j+k)|0]=x;h=h+1|0;}while((h|0)<8);return}function B0a(a,b,c){a=a|0;b=b|0;c=c|0;n0a(c);n0a(c+16|0);n0a(c+32|0);n0a(c+48|0);C0a(a,b,c);C0a(a+1|0,b,c+2|0);C0a(a+2|0,b,c+4|0);C0a(a+3|0,b,c+6|0);C0a(a+4|0,b,c+8|0);C0a(a+5|0,b,c+10|0);C0a(a+6|0,b,c+12|0);C0a(a+7|0,b,c+14|0);return}function C0a(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=b[f>>1]|0;h=b[f+16>>1]|0;i=b[f+32>>1]|0;j=b[f+48>>1]|0;f=((i+g|0)*2896|0)+65536|0;k=((g-i|0)*2896|0)+65536|0;i=(j*1567|0)+(h*3784|0)|0;g=(j*-3784|0)+(h*1567|0)|0;h=(f+i>>17)+(d[c]|0)|0;if(h>>>0>255>>>0){l=-h>>31&255}else{l=h&255}a[c]=l;l=c+e|0;h=(d[l]|0)+(k+g>>17)|0;if(h>>>0>255>>>0){m=-h>>31&255}else{m=h&255}a[l]=m;m=e<<1;l=c+m|0;h=(d[l]|0)+(k-g>>17)|0;if(h>>>0>255>>>0){n=-h>>31&255}else{n=h&255}a[l]=n;n=c+(m+e)|0;e=(d[n]|0)+(f-i>>17)|0;if(!(e>>>0>255>>>0)){o=e&255;a[n]=o;return}o=-e>>31&255;a[n]=o;return}function D0a(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=0;do{f=e<<3;g=d+(f<<1)|0;h=b[g>>1]|0;i=d+((f|1)<<1)|0;j=b[i>>1]|0;k=d+((f|2)<<1)|0;l=b[k>>1]|0;m=d+((f|3)<<1)|0;f=b[m>>1]|0;n=((l+h|0)*23170|0)+1024|0;o=((h-l|0)*23170|0)+1024|0;l=(f*12540|0)+(j*30274|0)|0;h=(f*-30274|0)+(j*12540|0)|0;b[g>>1]=(n+l|0)>>>11;b[i>>1]=(o+h|0)>>>11;b[k>>1]=(o-h|0)>>>11;b[m>>1]=(n-l|0)>>>11;e=e+1|0;}while((e|0)<8);p0a(a,c,d);p0a(a+1|0,c,d+2|0);p0a(a+2|0,c,d+4|0);p0a(a+3|0,c,d+6|0);return}function E0a(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=0;do{f=e<<3;g=d+(f<<1)|0;h=b[g>>1]|0;i=d+((f|1)<<1)|0;j=b[i>>1]|0;k=d+((f|2)<<1)|0;l=b[k>>1]|0;m=d+((f|3)<<1)|0;f=b[m>>1]|0;n=((l+h|0)*23170|0)+1024|0;o=((h-l|0)*23170|0)+1024|0;l=(f*12540|0)+(j*30274|0)|0;h=(f*-30274|0)+(j*12540|0)|0;b[g>>1]=(n+l|0)>>>11;b[i>>1]=(o+h|0)>>>11;b[k>>1]=(o-h|0)>>>11;b[m>>1]=(n-l|0)>>>11;e=e+1|0;}while((e|0)<4);C0a(a,c,d);C0a(a+1|0,c,d+2|0);C0a(a+2|0,c,d+4|0);C0a(a+3|0,c,d+6|0);return}function F0a(a,c){a=a|0;c=c|0;var d=0,e=0;d=0;do{e=a+(d<<1)|0;b[e>>1]=ca(b[e>>1]|0,b[c+(d<<1)>>1]|0)|0;d=d+1|0;}while((d|0)<64);s0a(a,2);s0a(a+16|0,2);s0a(a+32|0,2);s0a(a+48|0,2);s0a(a+64|0,2);s0a(a+80|0,2);s0a(a+96|0,2);s0a(a+112|0,2);b[a>>1]=(b[a>>1]|0)+8192;v0a(a);d=a+2|0;b[d>>1]=(b[d>>1]|0)+8192;v0a(d);d=a+4|0;b[d>>1]=(b[d>>1]|0)+8192;v0a(d);d=a+6|0;b[d>>1]=(b[d>>1]|0)+8192;v0a(d);d=a+8|0;b[d>>1]=(b[d>>1]|0)+8192;v0a(d);d=a+10|0;b[d>>1]=(b[d>>1]|0)+8192;v0a(d);d=a+12|0;b[d>>1]=(b[d>>1]|0)+8192;v0a(d);d=a+14|0;b[d>>1]=(b[d>>1]|0)+8192;v0a(d);return}function G0a(a,b){a=a|0;b=b|0;var c=0.0,d=0;if((b|0)<=0){return}c=3.141592653589793/(+(b|0)*2.0);d=0;do{g[a+(d<<2)>>2]=+V((+(d|0)+.5)*c);d=d+1|0;}while((d|0)<(b|0));return}function H0a(a){a=a|0;var b=0,d=0,e=0.0;b=c[1305896+(a<<2)>>2]|0;d=1<<a;if((d|0)<=0){return}e=3.141592653589793/(+(d|0)*2.0);a=0;do{g[b+(a<<2)>>2]=+V(e*(+(a|0)+.5));a=a+1|0;}while((a|0)<(d|0));return}function I0a(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a+60>>2]|0;e=d;f=a+432|0;h=c[f>>2]|0;if((h|0)==20){c[d+4>>2]=0;j=0}else if((h|0)==19){c[d+4>>2]=1;j=1}else if((h|0)==37){c[d+4>>2]=3;j=3}else if((h|0)==29){c[d+4>>2]=2;j=2}else{h=a+72|0;k=c[h>>2]|0;do{if((k|0)>12200){c[d+4>>2]=0;l=0}else{if((k|0)>7500){c[d+4>>2]=1;l=1;break}m=d+4|0;if((k|0)>5750){c[m>>2]=2;l=2;break}else{c[m>>2]=3;l=3;break}}}while(0);k=c[827528+(l*36|0)>>2]|0;l=c[h>>2]|0;KIb(a,24,2170072,(n=i,i=i+24|0,c[n>>2]=c[f>>2],c[n+8>>2]=k,c[n+16>>2]=l,n)|0);i=n;j=c[d+4>>2]|0}KIb(a,48,2142984,(n=i,i=i+8|0,c[n>>2]=c[827528+(j*36|0)>>2],n)|0);i=n;if((c[d+4>>2]|0)==0){M0a(e);c[d+5688>>2]=2012}else{c[d+5688>>2]=2196}g[d+2912>>2]=.9594929814338684;g[d+2916>>2]=.8412535190582275;g[d+2920>>2]=.6548607349395752;g[d+2924>>2]=.4154150187969208;g[d+2928>>2]=.1423148363828659;g[d+2932>>2]=-.1423148363828659;g[d+2936>>2]=-.4154150187969208;g[d+2940>>2]=-.6548607349395752;g[d+2944>>2]=-.8412535190582275;g[d+2948>>2]=-.9594929814338684;g[d+2956>>2]=-14.0;g[d+2960>>2]=-14.0;g[d+2964>>2]=-14.0;g[d+2968>>2]=-14.0;c[a+416>>2]=1;d=a+448|0;c[d>>2]=4;c[d+4>>2]=0;c[a+420>>2]=3;i=b;return 0}function J0a(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;j=i;i=i+184|0;k=j|0;l=c[a+60>>2]|0;m=l;n=c[h+24>>2]|0;o=c[l+4>>2]|0;p=(o|0)==0;q=p?80:48;c[l>>2]=a;r=c[h+28>>2]|0;h=e[827532+(o*36|0)>>1]|0;s=h>>>3;if((r|0)<(s|0)){KIb(a,16,2446544,(t=i,i=i+8|0,c[t>>2]=r,t)|0);i=t;u=-1;i=j;return u|0}t=d[827535+(o*36|0)|0]|0;r=ca(t,q)|0;v=d[827534+(o*36|0)|0]|0;c[f+76>>2]=ca(r,v)|0;r=M4a(a,f,0)|0;if((r|0)<0){u=r;i=j;return u|0}r=(n|0)==0?8:h+8|0;h=827541+(o*36|0)|0;a=k|0;w=d[827542+(o*36|0)|0]|0;x=32-w|0;y=k+4|0;z=d[827543+(o*36|0)|0]|0;A=32-z|0;B=k+8|0;C=d[827544+(o*36|0)|0]|0;D=32-C|0;E=k+12|0;F=d[827545+(o*36|0)|0]|0;G=32-F|0;H=k+16|0;I=d[827546+(o*36|0)|0]|0;J=32-I|0;K=k+20|0;L=827552+(o*36|0)|0;M=d[827540+(o*36|0)|0]|0;N=d[827563+(o*36|0)|0]|0;O=32-N|0;P=l+5688|0;l=ca(v,q)|0;q=c[f>>2]|0;f=0;Q=0;while(1){if(p){R=d[h]|0;S=n+(Q>>>3)|0;T=32-R|0;U=Q+R|0;c[a>>2]=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((Q&7)>>>0)<<T>>>(T>>>0);V=r>>>0>U>>>0?U:r}else{V=Q}U=n+(V>>>3)|0;T=V+w|0;S=r>>>0>T>>>0?T:r;c[y>>2]=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((V&7)>>>0)<<x>>>(x>>>0);U=n+(S>>>3)|0;T=S+z|0;R=r>>>0>T>>>0?T:r;c[B>>2]=(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)>>>((S&7)>>>0)<<A>>>(A>>>0);S=n+(R>>>3)|0;U=R+C|0;T=r>>>0>U>>>0?U:r;c[E>>2]=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((R&7)>>>0)<<D>>>(D>>>0);R=n+(T>>>3)|0;S=T+F|0;U=r>>>0>S>>>0?S:r;c[H>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((T&7)>>>0)<<G>>>(G>>>0);T=n+(U>>>3)|0;R=U+I|0;S=r>>>0>R>>>0?R:r;c[K>>2]=(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)>>>((U&7)>>>0)<<J>>>(J>>>0);if(p){U=0;T=S;while(1){R=d[827547+U|0]|0;W=n+(T>>>3)|0;X=32-R|0;Y=T+R|0;R=r>>>0>Y>>>0?Y:r;c[k+24+(U<<2)>>2]=(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)>>>((T&7)>>>0)<<X>>>(X>>>0);X=d[L]|0;W=n+(R>>>3)|0;Y=32-X|0;Z=R+X|0;c[k+44+(U<<2)>>2]=(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)>>>((R&7)>>>0)<<Y>>>(Y>>>0);Y=0;R=r>>>0>Z>>>0?Z:r;while(1){Z=d[827553+Y|0]|0;W=n+(R>>>3)|0;X=32-Z|0;_=Z+R|0;$=r>>>0>_>>>0?_:r;b[k+64+(U*20|0)+(Y<<1)>>1]=(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)>>>((R&7)>>>0)<<X>>>(X>>>0);X=Y+1|0;if((X|0)<(M|0)){Y=X;R=$}else{break}}R=n+($>>>3)|0;Y=N+$|0;X=r>>>0>Y>>>0?Y:r;c[k+164+(U<<2)>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>(($&7)>>>0)<<O>>>(O>>>0);R=U+1|0;if((R|0)<(v|0)){U=R;T=X}else{aa=X;break}}}else{T=0;U=S;while(1){X=d[827547+(o*36|0)+T|0]|0;R=n+(U>>>3)|0;Y=32-X|0;W=U+X|0;c[k+24+(T<<2)>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((U&7)>>>0)<<Y>>>(Y>>>0);Y=0;R=r>>>0>W>>>0?W:r;while(1){W=d[827553+(o*36|0)+Y|0]|0;X=n+(R>>>3)|0;_=32-W|0;Z=W+R|0;ba=r>>>0>Z>>>0?Z:r;b[k+64+(T*20|0)+(Y<<1)>>1]=(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)>>>((R&7)>>>0)<<_>>>(_>>>0);_=Y+1|0;if((_|0)<(M|0)){Y=_;R=ba}else{break}}R=n+(ba>>>3)|0;Y=N+ba|0;_=r>>>0>Y>>>0?Y:r;c[k+164+(T<<2)>>2]=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((ba&7)>>>0)<<O>>>(O>>>0);R=T+1|0;if((R|0)<(v|0)){T=R;U=_}else{aa=_;break}}}ef[c[P>>2]&4095](m,k,q);U=f+1|0;if((U|0)<(t|0)){q=q+(l<<2)|0;f=U;Q=aa}else{break}}c[g>>2]=1;u=s;i=j;return u|0}function K0a(a,e,f){a=a|0;e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0.0,P=0,Q=0.0,R=0,S=0.0,T=0,V=0.0,W=0,X=0.0,Y=0,Z=0.0,_=0.0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0.0,va=0,wa=0.0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0.0,Ha=0,Ia=0.0,Ja=0.0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0;j=i;i=i+1472|0;k=j|0;l=j+232|0;m=j+272|0;n=j+312|0;o=j+512|0;p=j+560|0;q=j+640|0;r=j+680|0;s=j+880|0;t=j+1112|0;u=j+1152|0;v=j+1248|0;w=j+1440|0;x=j+1448|0;y=j+1456|0;z=j+1464|0;A=a+4|0;B=d[827534+((c[A>>2]|0)*36|0)|0]|0;C=s+40|0;mrc(s|0,0,40)|0;D=t|0;E=q;F=q|0;G=q;H=(c[221122]|0)+(c[e+4>>2]<<1<<2)|0;I=c[H+4>>2]|0;c[F>>2]=c[H>>2];c[F+4>>2]=I;I=q+8|0;F=(c[221123]|0)+(c[e+8>>2]<<1<<2)|0;H=c[F+4>>2]|0;c[I>>2]=c[F>>2];c[I+4>>2]=H;H=q+16|0;I=(c[221124]|0)+(c[e+12>>2]<<1<<2)|0;F=c[I+4>>2]|0;c[H>>2]=c[I>>2];c[H+4>>2]=F;F=q+24|0;H=(c[221125]|0)+(c[e+16>>2]<<1<<2)|0;I=c[H+4>>2]|0;c[F>>2]=c[H>>2];c[F+4>>2]=I;I=q+32|0;q=(c[221126]|0)+(c[e+20>>2]<<1<<2)|0;F=c[q+4>>2]|0;c[I>>2]=c[q>>2];c[I+4>>2]=F;F=0;do{g[t+(F<<2)>>2]=+g[a+12+(F<<2)>>2]*.33+ +g[G+(F<<2)>>2]+ +g[831552+(F<<2)>>2];F=F+1|0;}while((F|0)<10);F=a;G=B*48|0;I=a+1952|0;DPa(D,9);wPa(D,.039269908169872414,9);q=t+36|0;J=+g[q>>2];nrc(a+12|0,E|0,40)|0;K=+U(+g[D>>2]);g[D>>2]=K;E=t+4|0;L=+U(+g[E>>2]);g[E>>2]=L;H=t+8|0;M=+U(+g[H>>2]);g[H>>2]=M;N=t+12|0;O=+U(+g[N>>2]);g[N>>2]=O;P=t+16|0;Q=+U(+g[P>>2]);g[P>>2]=Q;R=t+20|0;S=+U(+g[R>>2]);g[R>>2]=S;T=t+24|0;V=+U(+g[T>>2]);g[T>>2]=V;W=t+28|0;X=+U(+g[W>>2]);g[W>>2]=X;Y=t+32|0;Z=+U(+g[Y>>2]);g[Y>>2]=Z;_=J>4.084070449666731?8.00000286102295:J*1.9588306564723479;g[q>>2]=_;$=a+2912|0;aa=$|0;J=1.0/+(B|0);ba=p|0;ca=a+2916|0;da=p+8|0;ea=a+2920|0;fa=p+16|0;ga=a+2924|0;ha=p+24|0;ia=a+2928|0;ja=p+32|0;ka=a+2932|0;la=p+40|0;ma=a+2936|0;na=p+48|0;oa=a+2940|0;pa=p+56|0;qa=a+2944|0;ra=p+64|0;sa=a+2948|0;ta=p+72|0;p=1;ua=J*.5;va=r|0;wa=K;K=L;L=M;M=O;O=Q;Q=S;S=V;V=X;X=Z;Z=_;while(1){_=1.0-ua;h[ba>>3]=_*+g[aa>>2]+ua*wa;h[da>>3]=_*+g[ca>>2]+ua*K;h[fa>>3]=_*+g[ea>>2]+ua*L;h[ha>>3]=_*+g[ga>>2]+ua*M;h[ja>>3]=_*+g[ia>>2]+ua*O;h[la>>3]=_*+g[ka>>2]+ua*Q;h[na>>3]=_*+g[ma>>2]+ua*S;h[pa>>3]=_*+g[oa>>2]+ua*V;h[ra>>3]=_*+g[qa>>2]+ua*X;h[ta>>3]=_*+g[sa>>2]+ua*Z;APa(ba,va,10);if((p|0)>=(B|0)){break}p=p+1|0;ua=J+ua;va=va+40|0;wa=+g[D>>2];K=+g[E>>2];L=+g[H>>2];M=+g[N>>2];O=+g[P>>2];Q=+g[R>>2];S=+g[T>>2];V=+g[W>>2];X=+g[Y>>2];Z=+g[q>>2]}nrc($|0,t|0,40)|0;t=a+76|0;$=a+8|0;q=u+44|0;Y=u+4|0;W=u+48|0;T=u+8|0;R=u+52|0;P=u+12|0;N=u|0;H=n|0;E=n+44|0;D=o|0;va=v|0;p=v;ba=a+2956|0;sa=a+2952|0;ta=k;qa=k+40|0;ra=a+2980|0;oa=m|0;pa=k+192|0;k=a+3592|0;ma=a+3600|0;na=l|0;ka=u+16|0;la=u+56|0;ia=u+20|0;ja=u+24|0;ga=u+60|0;ha=u+64|0;ea=B*192|0;fa=0;ca=a+692|0;da=0;while(1){aa=da*10|0;xa=r+(aa<<2)|0;vlb(w,x,c[e+24+(da<<2)>>2]|0,fa,da,(c[A>>2]|0)==3|0,6);if((da|0)==2){if((c[A>>2]|0)==3){ya=9}else{za=fa}}else if((da|0)==0){ya=9}else{za=fa}if((ya|0)==9){ya=0;za=c[w>>2]|0}Aa=c[x>>2]|0;klb(ca,ca+(((Aa|0)<1)-(c[w>>2]|0)<<2)|0,1426320,6,(((Aa+2|0)%3|0)<<1)+2|0,10,48);Aa=e+64+(da*20|0)|0;Ba=c[A>>2]|0;do{if((Ba|0)==1){Ca=b[Aa>>1]|0;Da=Ca&65535;Ea=(Da>>>4&15)*3|0;c[Y>>2]=Ea;Fa=(Da&15)*3|0;c[T>>2]=Fa;Z=(Ca&256)!=0?-1.0:1.0;g[q>>2]=Z;if(Fa>>>0<Ea>>>0){Ga=-0.0-Z}else{Ga=Z}g[W>>2]=Ga;Fa=b[e+64+(da*20|0)+2>>1]|0;Ca=Fa&65535;Da=((Ca>>>4&15)*3|0)+1|0;c[P>>2]=Da;Ha=((Ca&15)*3|0)+1|0;c[ka>>2]=Ha;Z=(Fa&256)!=0?-1.0:1.0;g[R>>2]=Z;if(Ha>>>0<Da>>>0){Ia=-0.0-Z}else{Ia=Z}g[la>>2]=Ia;Da=b[e+64+(da*20|0)+4>>1]|0;Ha=Da&65535;Fa=((Ha>>>4&15)*3|0)+2|0;c[ia>>2]=Fa;Ca=((Ha&15)*3|0)+2|0;c[ja>>2]=Ca;Z=(Da&256)!=0?-1.0:1.0;g[ga>>2]=Z;if(Ca>>>0<Fa>>>0){Ja=-0.0-Z}else{Ja=Z}g[ha>>2]=Ja;c[N>>2]=6;Ka=6;La=Ea}else if((Ba|0)==2){Ea=b[Aa>>1]|0;Fa=(Ea&15)*3|0;c[Y>>2]=Fa;g[q>>2]=(Ea&16)!=0?-1.0:1.0;Ea=b[e+64+(da*20|0)+2>>1]|0;c[T>>2]=((Ea&15)*3|0)+1;g[W>>2]=(Ea&16)!=0?-1.0:1.0;Ea=b[e+64+(da*20|0)+4>>1]|0;c[P>>2]=((Ea&15)*3|0)+2;g[R>>2]=(Ea&16)!=0?-1.0:1.0;c[N>>2]=3;Ka=3;La=Fa}else{Fa=b[Aa>>1]|0;Ea=Fa<<16>>16;Ca=Ea>>>8;if(+g[$>>2]<.8){Da=Ca&2;Ha=((Ea&7)*6|0)+4|0;g[q>>2]=(Ha+Da&3|0)!=0?-1.0:1.0;c[Y>>2]=Ha;Ma=((Ea>>>3&7)*6|0)+2|0;g[W>>2]=(Ma+Da&3|0)!=0?-1.0:1.0;c[T>>2]=Ma;Ma=(Ea>>>6&7)*6|0;g[R>>2]=(Ma+Da&3|0)!=0?-1.0:1.0;c[P>>2]=Ma;c[N>>2]=3;Ka=3;La=Ha;break}else{Ha=Ca&1;Ca=((Ea>>>4&15)*3|0)+Ha|0;c[Y>>2]=Ca;c[T>>2]=Ha+1+((Fa&15)*3|0);Z=(Fa&512)!=0?-1.0:1.0;g[q>>2]=Z;g[W>>2]=-0.0-Z;c[N>>2]=2;Ka=2;La=Ca;break}}}while(0);Aa=c[w>>2]|0;Z=+g[827536+(Ba*36|0)>>2];g[H>>2]=1.0;Ca=0;while(1){X=+g[r+(Ca+aa<<2)>>2];Fa=Ca+1|0;g[n+(Fa<<2)>>2]=X*+g[1323120+(Ca<<2)>>2];g[o+(Ca<<2)>>2]=X*+g[1323080+(Ca<<2)>>2];if((Fa|0)<10){Ca=Fa}else{break}}mrc(E|0,0,148)|0;M3(C,D,H,48,10);if((Aa|0)<48){Ca=10-Aa|0;Ba=Aa;do{Fa=s+(Ba+10<<2)|0;g[Fa>>2]=+g[Fa>>2]+Z*+g[s+(Ca+Ba<<2)>>2];Ba=Ba+1|0;}while((Ba|0)<48)}mrc(p|0,0,192)|0;Ba=0;Ca=La;while(1){if((Ca|0)<48){Z=+g[u+44+(Ba<<2)>>2];Aa=10-Ca|0;Fa=Ca;do{Ha=v+(Fa<<2)|0;g[Ha>>2]=+g[Ha>>2]+Z*+g[s+(Aa+Fa<<2)>>2];Fa=Fa+1|0;}while((Fa|0)<48)}Fa=Ba+1|0;if((Fa|0)>=(Ka|0)){break}Ba=Fa;Ca=c[u+4+(Fa<<2)>>2]|0}Z=(+pHb(va,va,48)+.01)/48.0;Ca=c[e+164+(da<<2)>>2]|0;X=+g[1201832+(Ca<<3)>>2];g[$>>2]=X;V=+ulb(+g[1201836+(Ca<<3)>>2],Z,ba,-56.308998107910156,700152);zlb(ca,ca,va,X,V,48);Z=X;X=Z*Z*.5;Z=X>.4?.4000000059604645:X;X=+g[sa>>2]*.7+Z*.3;S=X>Z?Z:X;g[sa>>2]=S;X=V*S;Ca=0;do{Ba=v+(Ca<<2)|0;g[Ba>>2]=+g[ca+(Ca<<2)>>2]-X*+g[Ba>>2];Ca=Ca+1|0;}while((Ca|0)<48);if((c[A>>2]|0)==3){Ca=0;do{X=+g[r+(Ca+aa<<2)>>2];g[m+(Ca<<2)>>2]=X*+g[1323040+(Ca<<2)>>2];g[l+(Ca<<2)>>2]=X*+g[1323160+(Ca<<2)>>2];Ca=Ca+1|0;}while((Ca|0)<10);nrc(ta|0,ra|0,40)|0;M3(qa,oa,va,48,10);nrc(ra|0,pa|0,40)|0;nlb(k,.4000000059604645,qa,48);nrc(ta|0,ma|0,40)|0;nrc(ma|0,pa|0,40)|0;N3(va,na,qa,48,10);Ca=da*48|0;M3(a+4212+((Ca|10)<<2)|0,xa,ca,48,10);Na=Ca}else{Na=da*48|0}M3(a+1888+(Na+16<<2)|0,xa,va,48,10);Ca=da+1|0;if((Ca|0)<(B|0)){fa=za;ca=ca+192|0;da=Ca}else{break}}nrc(a+1912|0,a+1888+((G|6)<<2)|0,40)|0;if((c[A>>2]|0)!=3){Oa=t;Pa=ea+76|0;Qa=F+Pa|0;orc(Oa|0,Qa|0,616)|0;Ra=y|0;g[Ra>>2]=-1.9999699592590332;Sa=y+4|0;g[Sa>>2]=1.0;Ta=z|0;g[Ta>>2]=-1.9330735206604004;Ua=z+4|0;g[Ua>>2]=.9358919858932495;Va=a+2972|0;mlb(f,I,Ra,Ta,.939805805683136,Va,G);i=j;return}A=a+3596|0;da=0;do{ca=da*48|0;za=a+4212+((ca|10)<<2)|0;fa=a+1888+(ca+16<<2)|0;Alb(fa,fa,+pHb(za,za,48),48,.8999999761581421,A);da=da+1|0;}while((da|0)<(B|0));nrc(a+4212|0,a+4212+(G<<2)|0,40)|0;Oa=t;Pa=ea+76|0;Qa=F+Pa|0;orc(Oa|0,Qa|0,616)|0;Ra=y|0;g[Ra>>2]=-1.9999699592590332;Sa=y+4|0;g[Sa>>2]=1.0;Ta=z|0;g[Ta>>2]=-1.9330735206604004;Ua=z+4|0;g[Ua>>2]=.9358919858932495;Va=a+2972|0;mlb(f,I,Ra,Ta,.939805805683136,Va,G);i=j;return}function L0a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0;e=i;i=i+1112|0;f=e|0;j=e+128|0;k=e+312|0;l=e+376|0;m=e+440|0;n=e+568|0;o=e+696|0;p=e+1016|0;q=a+1952|0;r=a+12|0;s=c[b>>2]|0;t=k;u=(c[221116]|0)+(((c[b+4>>2]|0)*3|0)<<2)|0;c[t>>2]=c[u>>2];c[t+4>>2]=c[u+4>>2];c[t+8>>2]=c[u+8>>2];u=k+12|0;v=(c[221117]|0)+(((c[b+8>>2]|0)*3|0)<<2)|0;c[u>>2]=c[v>>2];c[u+4>>2]=c[v+4>>2];c[u+8>>2]=c[v+8>>2];v=k+24|0;u=(c[221118]|0)+(((c[b+12>>2]|0)*3|0)<<2)|0;c[v>>2]=c[u>>2];c[v+4>>2]=c[u+4>>2];c[v+8>>2]=c[u+8>>2];u=k+36|0;v=(c[221119]|0)+(((c[b+16>>2]|0)*3|0)<<2)|0;c[u>>2]=c[v>>2];c[u+4>>2]=c[v+4>>2];c[u+8>>2]=c[v+8>>2];v=k+48|0;u=(c[221120]|0)+(c[b+20>>2]<<2<<2)|0;c[v>>2]=c[u>>2];c[v+4>>2]=c[u+4>>2];c[v+8>>2]=c[u+8>>2];c[v+12>>2]=c[u+12>>2];w=+g[690768+(s<<2)>>2];x=1.0-w;s=0;do{g[l+(s<<2)>>2]=+g[831488+(s<<2)>>2]+(x*+g[k+(s<<2)>>2]+w*+g[a+12+(s<<2)>>2]);s=s+1|0;}while((s|0)<16);s=a+76|0;k=l|0;nrc(r|0,t|0,64)|0;wPa(k,.019634954084936207,16);t=m|0;w=+U(+g[k>>2]);h[t>>3]=w;h[m+8>>3]=+U(+g[l+4>>2]);h[m+16>>3]=+U(+g[l+8>>2]);h[m+24>>3]=+U(+g[l+12>>2]);h[m+32>>3]=+U(+g[l+16>>2]);h[m+40>>3]=+U(+g[l+20>>2]);h[m+48>>3]=+U(+g[l+24>>2]);h[m+56>>3]=+U(+g[l+28>>2]);h[m+64>>3]=+U(+g[l+32>>2]);h[m+72>>3]=+U(+g[l+36>>2]);h[m+80>>3]=+U(+g[l+40>>2]);h[m+88>>3]=+U(+g[l+44>>2]);h[m+96>>3]=+U(+g[l+48>>2]);h[m+104>>3]=+U(+g[l+52>>2]);h[m+112>>3]=+U(+g[l+56>>2]);h[m+120>>3]=+U(+g[l+60>>2]);l=n+64|0;k=l|0;r=0;x=w;while(1){h[f+(r<<3)>>3]=(x+ +h[a+5560+(r<<3)>>3])*.5;u=r+1|0;if((u|0)>=16){break}r=u;x=+h[m+(u<<3)>>3]}CPa(f|0,n|0,8);CPa(t,k,8);nrc(a+5560|0,m|0,128)|0;m=a+1888|0;k=a+5492|0;nrc(m|0,k|0,64)|0;t=p+92|0;f=p+88|0;r=a+5212|0;u=o;v=o|0;o=a+2956|0;y=a+2960|0;z=0;do{A=z*80|0;B=c[b+24+(z<<2)>>2]|0;do{if((z|0)==0){if((B|0)<390){C=B+88|0;break}else{C=(B*3|0)-690|0;break}}else{D=c[r>>2]|0;if((B|0)>=62){C=D*3|0;break}E=D-10|0;if((E|0)<30){F=90}else{F=(E|0)>262?786:E*3|0}C=B-2+F|0}}while(0);B=c[b+44+(z<<2)>>2]|0;x=+g[1201472+(B<<2)>>2];g[t>>2]=(B-12|0)>>>0<4>>>0?1.0:x;B=C*10923|0;E=B+10923>>15;c[f>>2]=E;c[r>>2]=E;E=B+21846>>15;B=a+76+(A+292<<2)|0;klb(B,a+76+(A+293-E<<2)|0,565616,3,C+3+(E*-3|0)|0,10,80);mrc(u|0,0,320)|0;xlb(b+64+(z*20|0)|0,p,1390328,5,4);Clb(v,p,1.0,80);w=+g[1201704+(c[b+164+(z<<2)>>2]<<2)>>2];G=+$((+pHb(700144,o,2)+ -71.30899810791016)*.11512925464970229)*8.9442720413208;H=w*(G/+S(+pHb(v,v,80)+.01));g[y>>2]=+g[o>>2];g[o>>2]=+fd(+w)*20.0;zlb(B,B,v,x,H,80);M3(a+1888+(A+16<<2)|0,n+(z<<6)|0,B,80,16);z=z+1|0;}while((z|0)<2);nrc(k|0,a+2528|0,64)|0;orc(s|0,a+716|0,1168)|0;s=a+5420|0;k=j;z=c[s>>2]|0;n=0;do{g[z+(n<<2)>>2]=+g[a+5216+(n<<2)>>2]*+g[1323160+(n<<2)>>2];n=n+1|0;}while((n|0)<16);n=a+5216|0;z=a+5428|0;nrc(k|0,z|0,64)|0;k=a+5424|0;M3(j+64|0,c[k>>2]|0,q,30,16);nrc(m|0,z|0,64)|0;M3(q,c[s>>2]|0,q,30,16);nrc(d+56|0,a+2008|0,64)|0;M3(d+120|0,c[s>>2]|0,a+2072|0,130,16);nrc(z|0,d+576|0,64)|0;z=c[k>>2]|0;c[k>>2]=c[s>>2];c[s>>2]=z;z=0;H=0.0;while(1){s=z+16|0;x=+g[j+(s<<2)>>2];g[d+(z<<2)>>2]=x+H*(+g[a+1888+(s<<2)>>2]-x);s=z+1|0;if((s|0)<30){z=s;H=H+.03333333333333333}else{break}}nrc(n|0,l|0,64)|0;i=e;return}function M0a(a){a=a|0;h[a+5560>>3]=.9829730996839018;h[a+5568>>3]=.9324722294043558;h[a+5576>>3]=.8502171357296142;h[a+5584>>3]=.7390089172206591;h[a+5592>>3]=.6026346363792564;h[a+5600>>3]=.4457383557765383;h[a+5608>>3]=.273662990072083;h[a+5616>>3]=.092268359463302;h[a+5624>>3]=-.09226835946330189;h[a+5632>>3]=-.2736629900720829;h[a+5640>>3]=-.4457383557765378;h[a+5648>>3]=-.6026346363792563;h[a+5656>>3]=-.7390089172206593;h[a+5664>>3]=-.850217135729614;h[a+5672>>3]=-.9324722294043557;h[a+5680>>3]=-.9829730996839018;c[a+5420>>2]=a+5284;c[a+5424>>2]=a+5352;c[a+5212>>2]=180;return}function N0a(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+24|0;f=e|0;g=b+60|0;h=c[g>>2]|0;j=h;k=h;c[k>>2]=b;c[b+140>>2]=11;l=UHb()|0;c[h+4>>2]=l;if((l|0)==0){m=-12;i=e;return m|0}if((c[b+100>>2]|0)<16){KIb(b,16,2501152,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-22;i=e;return m|0}b=c[k>>2]|0;l=c[b+96>>2]|0;o=l;p=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+4|0;q=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+8|0;r=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+12|0;s=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;o=l+16|0;l=(c[b+100>>2]|0)-16|0;t=l>>>0>268435455>>>0?-8:l<<3;l=t>>>0>2147483639>>>0|(o|0)==0;u=l?0:o;o=l?0:t;t=f|0;c[t>>2]=u;c[f+12>>2]=o;l=o+8|0;v=f+16|0;c[v>>2]=l;c[f+4>>2]=u+(o>>3);o=f+8|0;c[o>>2]=0;w=a[u]|0;c[o>>2]=(l|0)>0;do{if((w&1)==0){KIb(b,32,2488384,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;l=hJb(8)|0;u=l;c[h+8>>2]=u;if((l|0)==0){x=-12;break}c[u>>2]=0;c[h+32>>2]=1;c[h+28>>2]=1;c[h+24>>2]=1;y=8}else{u=T0a(j,f,h+8|0,h+24|0,p)|0;if((u|0)<0){x=u}else{y=8}}}while(0);do{if((y|0)==8){p=c[o>>2]|0;b=d[(c[t>>2]|0)+(p>>>3)|0]|0;c[o>>2]=((p|0)<(c[v>>2]|0))+p;if((b&1<<(p&7)|0)==0){KIb(c[k>>2]|0,32,2477448,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=hJb(8)|0;b=p;c[h+12>>2]=b;if((p|0)==0){x=-12;break}c[b>>2]=0;c[h+44>>2]=1;c[h+40>>2]=1;c[h+36>>2]=1}else{b=T0a(j,f,h+12|0,h+36|0,q)|0;if((b|0)<0){x=b;break}}b=c[o>>2]|0;p=d[(c[t>>2]|0)+(b>>>3)|0]|0;c[o>>2]=((b|0)<(c[v>>2]|0))+b;if((p&1<<(b&7)|0)==0){KIb(c[k>>2]|0,32,2467920,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;b=hJb(8)|0;p=b;c[h+16>>2]=p;if((b|0)==0){x=-12;break}c[p>>2]=0;c[h+56>>2]=1;c[h+52>>2]=1;c[h+48>>2]=1}else{p=T0a(j,f,h+16|0,h+48|0,r)|0;if((p|0)<0){x=p;break}}p=c[o>>2]|0;b=d[(c[t>>2]|0)+(p>>>3)|0]|0;c[o>>2]=((p|0)<(c[v>>2]|0))+p;if((b&1<<(p&7)|0)!=0){p=T0a(j,f,h+20|0,h+60|0,s)|0;if((p|0)<0){x=p;break}else{m=0}i=e;return m|0}KIb(c[k>>2]|0,32,2458344,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=hJb(8)|0;b=p;c[h+20>>2]=b;if((p|0)==0){x=-12;break}c[b>>2]=0;c[h+68>>2]=1;c[h+64>>2]=1;c[h+60>>2]=1;m=0;i=e;return m|0}}while(0);h=c[g>>2]|0;mJb(h+8|0);mJb(h+12|0);mJb(h+16|0);mJb(h+20|0);VHb(h+4|0);m=x;i=e;return m|0}function O0a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0;h=i;j=c[b+60>>2]|0;k=g+28|0;if((c[k>>2]|0)<770){l=-1094995529;i=h;return l|0}m=j+4|0;n=N4a(b,c[m>>2]|0)|0;if((n|0)<0){l=n;i=h;return l|0}n=c[m>>2]|0;o=g+24|0;g=c[o>>2]|0;if(!((c[k>>2]|0)>-1)){KIb(0,0,2548184,(p=i,i=i+24|0,c[p>>2]=2530256,c[p+8>>2]=2514992,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}p=c[n+4>>2]|0;q=d[g]|0;c[n+304>>2]=q&1;r=q>>>1&1;c[n+84>>2]=r;c[n+88>>2]=2-r;r=g+1|0;g=0;n=p;while(1){c[n>>2]=(d[r]|0)<<16|(d[r+1|0]|0)<<8|(d[r+2|0]|0)|-16777216;p=g+1|0;if((p|0)<256){r=r+3|0;g=p;n=n+4|0}else{break}}n=j+8|0;g=c[n>>2]|0;r=j+24|0;p=j+32|0;c[g+(c[p>>2]<<2)>>2]=0;q=j+28|0;c[g+(c[q>>2]<<2)>>2]=0;c[g+(c[r>>2]<<2)>>2]=0;g=j+12|0;s=c[g>>2]|0;t=j+36|0;u=j+44|0;c[s+(c[u>>2]<<2)>>2]=0;v=j+40|0;c[s+(c[v>>2]<<2)>>2]=0;c[s+(c[t>>2]<<2)>>2]=0;s=j+16|0;w=c[s>>2]|0;x=j+48|0;z=j+56|0;c[w+(c[z>>2]<<2)>>2]=0;A=j+52|0;c[w+(c[A>>2]<<2)>>2]=0;c[w+(c[x>>2]<<2)>>2]=0;w=j+20|0;B=c[w>>2]|0;C=j+60|0;D=j+68|0;c[B+(c[D>>2]<<2)>>2]=0;E=j+64|0;c[B+(c[E>>2]<<2)>>2]=0;c[B+(c[C>>2]<<2)>>2]=0;B=(c[o>>2]|0)+769|0;o=(c[k>>2]|0)-769|0;j=o>>>0>268435455>>>0?-8:o<<3;o=j>>>0>2147483639>>>0|(B|0)==0;F=o?0:B;B=o?8:j+8|0;if(o){l=o?-1094995529:0;i=h;return l|0}o=c[b+120>>2]>>2;j=ca(c[b+124>>2]>>2,o)|0;G=c[(c[m>>2]|0)+32>>2]|0;if((j|0)>0){H=b+52|0;b=G<<2;I=G+2|0;J=G<<1;K=0;L=0;while(1){M=K;while(1){N=c[w>>2]|0;O=c[N>>2]|0;if((O|0)<0){P=N;Q=M;R=O;while(1){S=((Q|0)<(B|0))+Q|0;if(((d[F+(Q>>>3)|0]|0)&1<<(Q&7)|0)==0){T=P}else{T=P+((R&2147483647)<<2)|0}U=T+4|0;V=c[U>>2]|0;if((V|0)<0){P=U;Q=S;R=V}else{W=V;X=S;break}}}else{W=O;X=M}if((W|0)!=(c[N+(c[C>>2]<<2)>>2]|0)){c[N+(c[D>>2]<<2)>>2]=c[N+(c[E>>2]<<2)>>2];c[N+(c[E>>2]<<2)>>2]=c[N+(c[C>>2]<<2)>>2];c[N+(c[C>>2]<<2)>>2]=W}Y=c[1901032+((W>>>2&63)<<2)>>2]|0;R=W&3;if((R|0)==2){Z=24;break}else if((R|0)==3){Z=96;break}else if((R|0)==0){Z=22;break}else if((R|0)==1){Z=48;break}else{M=X}}do{if((Z|0)==22){Z=0;if((L|0)>=(j|0)){_=L;$=X;break}M=-Y|0;R=L-j|0;Q=R>>>0<M>>>0?M:R;R=X;M=L;P=Y;while(1){S=P-1|0;V=c[g>>2]|0;U=c[V>>2]|0;if((U|0)<0){aa=V;ba=R;da=U;while(1){ea=((ba|0)<(B|0))+ba|0;if(((d[F+(ba>>>3)|0]|0)&1<<(ba&7)|0)==0){fa=aa}else{fa=aa+((da&2147483647)<<2)|0}ga=fa+4|0;ha=c[ga>>2]|0;if((ha|0)<0){aa=ga;ba=ea;da=ha}else{ia=ha;ja=ea;break}}}else{ia=U;ja=R}if((ia|0)!=(c[V+(c[t>>2]<<2)>>2]|0)){c[V+(c[u>>2]<<2)>>2]=c[V+(c[v>>2]<<2)>>2];c[V+(c[v>>2]<<2)>>2]=c[V+(c[t>>2]<<2)>>2];c[V+(c[t>>2]<<2)>>2]=ia}da=c[n>>2]|0;ba=c[da>>2]|0;if((ba|0)<0){aa=da;ea=ja;ha=ba;while(1){ga=((ea|0)<(B|0))+ea|0;if(((d[F+(ea>>>3)|0]|0)&1<<(ea&7)|0)==0){ka=aa}else{ka=aa+((ha&2147483647)<<2)|0}la=ka+4|0;ma=c[la>>2]|0;if((ma|0)<0){aa=la;ea=ga;ha=ma}else{na=ma;oa=ga;break}}}else{na=ba;oa=ja}if((na|0)!=(c[da+(c[r>>2]<<2)>>2]|0)){c[da+(c[p>>2]<<2)>>2]=c[da+(c[q>>2]<<2)>>2];c[da+(c[q>>2]<<2)>>2]=c[da+(c[r>>2]<<2)>>2];c[da+(c[r>>2]<<2)>>2]=na}ha=c[c[m>>2]>>2]|0;ea=((M|0)%(o|0)|0)+(ca((M|0)/(o|0)|0,G)|0)<<2;aa=ia>>8;V=ia&255;U=aa&255;a[ha+ea|0]=(na&1|0)==0?ia:aa;if((na&2|0)==0){pa=V}else{pa=U}a[ha+(ea|1)|0]=pa;if((na&4|0)==0){qa=V}else{qa=U}a[ha+(ea|2)|0]=qa;if((na&8|0)==0){ra=V}else{ra=U}a[ha+(ea|3)|0]=ra;ga=na>>4;ma=ea+G|0;a[ha+ma|0]=(ga&1|0)==0?ia:aa;if((ga&2|0)==0){sa=V}else{sa=U}a[ha+(ma+1)|0]=sa;if((ga&4|0)==0){ta=V}else{ta=U}a[ha+(ma+2)|0]=ta;if((ga&8|0)==0){ua=V}else{ua=U}a[ha+(ma+3)|0]=ua;ga=na>>8;ea=ma+G|0;a[ha+ea|0]=(ga&1|0)==0?ia:aa;if((ga&2|0)==0){va=V}else{va=U}a[ha+(ea+1)|0]=va;if((ga&4|0)==0){wa=V}else{wa=U}a[ha+(ea+2)|0]=wa;if((ga&8|0)==0){xa=V}else{xa=U}a[ha+(ea+3)|0]=xa;ga=na>>12;ma=ea+G|0;a[ha+ma|0]=(ga&1|0)==0?ia:aa;if((ga&2|0)==0){ya=V}else{ya=U}a[ha+(ma+1)|0]=ya;if((ga&4|0)==0){za=V}else{za=U}a[ha+(ma+2)|0]=za;if((ga&8|0)==0){Aa=V}else{Aa=U}a[ha+(ma+3)|0]=Aa;ma=M+1|0;if((S|0)!=0&(ma|0)<(j|0)){R=oa;M=ma;P=S}else{break}}_=L-Q|0;$=oa}else if((Z|0)==24){Z=0;if((L|0)>=(j|0)){_=L;$=X;break}P=-Y|0;M=L-j|0;_=L-(M>>>0<P>>>0?P:M)|0;$=X}else if((Z|0)==48){Z=0;do{if((c[H>>2]|0)==877350227){M=((X|0)<(B|0))+X|0;if(((d[F+(X>>>3)|0]|0)&1<<(X&7)|0)!=0){Ba=1;Ca=M;break}Ba=((d[F+(M>>>3)|0]|0)&1<<(M&7)|0)==0?0:2;Ca=((M|0)<(B|0))+M|0}else{Ba=0;Ca=X}}while(0);if((L|0)>=(j|0)){_=L;$=Ca;break}Q=-Y|0;M=L-j|0;P=M>>>0<Q>>>0?Q:M;M=Ca;Q=L;R=Y;while(1){N=R-1|0;O=c[c[m>>2]>>2]|0;ma=(((Q|0)%(o|0)|0)<<2)+(ca(b,(Q|0)/(o|0)|0)|0)|0;ha=O+ma|0;a:do{if((Ba|0)==2){U=M;V=1;ga=ha;while(1){aa=c[s>>2]|0;ea=c[aa>>2]|0;if((ea|0)<0){la=aa;Da=U;Ea=ea;while(1){Fa=((Da|0)<(B|0))+Da|0;if(((d[F+(Da>>>3)|0]|0)&1<<(Da&7)|0)==0){Ga=la}else{Ga=la+((Ea&2147483647)<<2)|0}Ha=Ga+4|0;Ia=c[Ha>>2]|0;if((Ia|0)<0){la=Ha;Da=Fa;Ea=Ia}else{Ja=Ia;Ka=Fa;break}}}else{Ja=ea;Ka=U}if((Ja|0)==(c[aa+(c[x>>2]<<2)>>2]|0)){La=ea}else{c[aa+(c[z>>2]<<2)>>2]=c[aa+(c[A>>2]<<2)>>2];c[aa+(c[A>>2]<<2)>>2]=c[aa+(c[x>>2]<<2)>>2];c[aa+(c[x>>2]<<2)>>2]=Ja;La=c[aa>>2]|0}Ea=Ja&65535;if((La|0)<0){Da=aa;la=Ka;Fa=La;while(1){Ia=((la|0)<(B|0))+la|0;if(((d[F+(la>>>3)|0]|0)&1<<(la&7)|0)==0){Ma=Da}else{Ma=Da+((Fa&2147483647)<<2)|0}Ha=Ma+4|0;Na=c[Ha>>2]|0;if((Na|0)<0){Da=Ha;la=Ia;Fa=Na}else{Oa=Na;Pa=Ia;break}}}else{Oa=La;Pa=Ka}if((Oa|0)!=(c[aa+(c[x>>2]<<2)>>2]|0)){c[aa+(c[z>>2]<<2)>>2]=c[aa+(c[A>>2]<<2)>>2];c[aa+(c[A>>2]<<2)>>2]=c[aa+(c[x>>2]<<2)>>2];c[aa+(c[x>>2]<<2)>>2]=Oa}Fa=Oa&65535;la=ga;y=Fa;a[la]=y;y=y>>8;a[la+1|0]=y;la=ga+2|0;y=Ea;a[la]=y;y=y>>8;a[la+1|0]=y;la=ga+G|0;y=Fa;a[la]=y;y=y>>8;a[la+1|0]=y;la=ga+I|0;y=Ea;a[la]=y;y=y>>8;a[la+1|0]=y;if((V|0)>=2){Qa=Pa;break a}U=Pa;V=V+1|0;ga=ga+J|0}}else if((Ba|0)==1){ga=c[s>>2]|0;V=c[ga>>2]|0;if((V|0)<0){U=ga;la=M;Fa=V;while(1){Da=((la|0)<(B|0))+la|0;if(((d[F+(la>>>3)|0]|0)&1<<(la&7)|0)==0){Ra=U}else{Ra=U+((Fa&2147483647)<<2)|0}ea=Ra+4|0;Ia=c[ea>>2]|0;if((Ia|0)<0){U=ea;la=Da;Fa=Ia}else{Sa=Ia;Ta=Da;break}}}else{Sa=V;Ta=M}if((Sa|0)!=(c[ga+(c[x>>2]<<2)>>2]|0)){c[ga+(c[z>>2]<<2)>>2]=c[ga+(c[A>>2]<<2)>>2];c[ga+(c[A>>2]<<2)>>2]=c[ga+(c[x>>2]<<2)>>2];c[ga+(c[x>>2]<<2)>>2]=Sa}Fa=Sa&255;a[O+(ma|1)|0]=Fa;a[ha]=Fa;la=Sa>>>8&255;a[O+(ma|3)|0]=la;a[O+(ma|2)|0]=la;U=ma+G|0;a[O+(U+1)|0]=Fa;a[O+U|0]=Fa;a[O+(U+3)|0]=la;a[O+(U+2)|0]=la;la=U+G|0;U=O+la|0;Fa=c[s>>2]|0;Da=c[Fa>>2]|0;if((Da|0)<0){Ia=Fa;ea=Ta;Na=Da;while(1){Ha=((ea|0)<(B|0))+ea|0;if(((d[F+(ea>>>3)|0]|0)&1<<(ea&7)|0)==0){Ua=Ia}else{Ua=Ia+((Na&2147483647)<<2)|0}Va=Ua+4|0;Wa=c[Va>>2]|0;if((Wa|0)<0){Ia=Va;ea=Ha;Na=Wa}else{Xa=Wa;Ya=Ha;break}}}else{Xa=Da;Ya=Ta}if((Xa|0)!=(c[Fa+(c[x>>2]<<2)>>2]|0)){c[Fa+(c[z>>2]<<2)>>2]=c[Fa+(c[A>>2]<<2)>>2];c[Fa+(c[A>>2]<<2)>>2]=c[Fa+(c[x>>2]<<2)>>2];c[Fa+(c[x>>2]<<2)>>2]=Xa}Na=Xa&255;a[O+(la+1)|0]=Na;a[U]=Na;ea=Xa>>>8&255;a[O+(la+3)|0]=ea;a[O+(la+2)|0]=ea;Ia=la+G|0;a[O+(Ia+1)|0]=Na;a[O+Ia|0]=Na;a[O+(Ia+3)|0]=ea;a[O+(Ia+2)|0]=ea;Qa=Ya}else if((Ba|0)==0){ea=M;Ia=1;Na=ha;while(1){ga=c[s>>2]|0;V=c[ga>>2]|0;if((V|0)<0){Ha=ga;Wa=ea;Va=V;while(1){Za=((Wa|0)<(B|0))+Wa|0;if(((d[F+(Wa>>>3)|0]|0)&1<<(Wa&7)|0)==0){_a=Ha}else{_a=Ha+((Va&2147483647)<<2)|0}$a=_a+4|0;ab=c[$a>>2]|0;if((ab|0)<0){Ha=$a;Wa=Za;Va=ab}else{bb=ab;cb=Za;break}}}else{bb=V;cb=ea}if((bb|0)!=(c[ga+(c[x>>2]<<2)>>2]|0)){c[ga+(c[z>>2]<<2)>>2]=c[ga+(c[A>>2]<<2)>>2];c[ga+(c[A>>2]<<2)>>2]=c[ga+(c[x>>2]<<2)>>2];c[ga+(c[x>>2]<<2)>>2]=bb}Va=Na+2|0;y=bb&65535;a[Va]=y;y=y>>8;a[Va+1|0]=y;Va=c[s>>2]|0;Wa=c[Va>>2]|0;if((Wa|0)<0){Ha=Va;Ea=cb;aa=Wa;while(1){Za=((Ea|0)<(B|0))+Ea|0;if(((d[F+(Ea>>>3)|0]|0)&1<<(Ea&7)|0)==0){db=Ha}else{db=Ha+((aa&2147483647)<<2)|0}ab=db+4|0;$a=c[ab>>2]|0;if(($a|0)<0){Ha=ab;Ea=Za;aa=$a}else{eb=$a;fb=Za;break}}}else{eb=Wa;fb=cb}if((eb|0)!=(c[Va+(c[x>>2]<<2)>>2]|0)){c[Va+(c[z>>2]<<2)>>2]=c[Va+(c[A>>2]<<2)>>2];c[Va+(c[A>>2]<<2)>>2]=c[Va+(c[x>>2]<<2)>>2];c[Va+(c[x>>2]<<2)>>2]=eb}aa=Na;y=eb&65535;a[aa]=y;y=y>>8;a[aa+1|0]=y;if((Ia|0)>=4){Qa=fb;break a}ea=fb;Ia=Ia+1|0;Na=Na+G|0}}else{Qa=M}}while(0);ha=Q+1|0;if((N|0)!=0&(ha|0)<(j|0)){M=Qa;Q=ha;R=N}else{break}}_=L-P|0;$=Qa}else if((Z|0)==96){Z=0;if((L|0)>=(j|0)){_=L;$=X;break}R=c[c[m>>2]>>2]|0;Q=ca(W>>8,16843009)|0;M=-Y|0;ha=L-j|0;O=ha>>>0<M>>>0?M:ha;ha=L;M=Y;do{ma=((ha|0)%(o|0)|0)+(ca((ha|0)/(o|0)|0,G)|0)<<2;c[R+ma>>2]=Q;S=ma+G|0;c[R+S>>2]=Q;ma=S+G|0;c[R+ma>>2]=Q;c[R+(ma+G)>>2]=Q;M=M-1|0;ha=ha+1|0;}while((M|0)!=0&(ha|0)<(j|0));_=L-O|0;$=X}}while(0);if((_|0)<(j|0)){K=$;L=_}else{break}}}_=YHb(e,c[m>>2]|0)|0;if((_|0)<0){l=_;i=h;return l|0}c[f>>2]=1;l=c[k>>2]|0;i=h;return l|0}function P0a(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+8|0);mJb(b+12|0);mJb(b+16|0);mJb(b+20|0);VHb(b+4|0);return 0}function Q0a(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+416>>2]|0;if((d-1|0)>>>0>1>>>0){KIb(a,16,2566296,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}else{e=(d|0)==2;d=a+448|0;c[d>>2]=e?3:4;c[d+4>>2]=e?0:0;c[a+420>>2]=(c[a+792>>2]|0)!=8;f=0;i=b;return f|0}return 0}function R0a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;j=i;i=i+208|0;k=j|0;l=j+24|0;m=j+120|0;n=j+200|0;o=n;p=c[h+24>>2]|0;q=c[h+28>>2]|0;mrc(l|0,0,96)|0;mrc(m|0,0,80)|0;c[n>>2]=0;c[n+4>>2]=0;if((q|0)<5){KIb(e,16,2294208,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=j;return s|0}h=p;t=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;if(t>>>0>16777216>>>0){KIb(e,16,2243232,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}h=p+4|0;p=q-4|0;u=p>>>0>268435455>>>0?-8:p<<3;p=u>>>0>2147483639>>>0|(h|0)==0;v=p?0:h;h=p?0:u;u=k|0;c[u>>2]=v;w=k+12|0;c[w>>2]=h;x=h+8|0;y=k+16|0;c[y>>2]=x;c[k+4>>2]=v+(h>>3);h=k+8|0;c[h>>2]=0;if(p){s=p?-1094995529:0;i=j;return s|0}p=a[v]|0;z=(x|0)>0|0;c[h>>2]=z;if((p&1)==0){KIb(e,32,2201888,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;c[g>>2]=0;s=1;i=j;return s|0}p=(d[v]|0)>>>(z>>>0);A=((z|0)<(x|0))+z|0;c[h>>2]=A;z=p&1;B=(d[v+(A>>>3)|0]|0)>>>((A&7)>>>0);c[h>>2]=((A|0)<(x|0))+A;A=B&1;B=c[e+416>>2]|0;if((B|0)!=1^(z|0)!=0){KIb(e,16,2170048,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=j;return s|0}if(!((c[e+420>>2]|0)==0^(A|0)!=0)){KIb(e,16,2142960,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=j;return s|0}c[f+76>>2]=(t|0)/(ca(A+1|0,B)|0)|0;B=M4a(e,f,0)|0;if((B|0)<0){s=B;i=j;return s|0}B=c[f>>2]|0;f=B;x=1<<A+z;a:do{if((x|0)>0){v=0;while(1){C=l+(v*24|0)|0;D=C|0;c[D>>2]=256;c[l+(v*24|0)+4>>2]=0;E=l+(v*24|0)+8|0;c[E>>2]=0;F=l+(v*24|0)+12|0;c[F>>2]=pJb(1024)|0;G=l+(v*24|0)+16|0;c[G>>2]=pJb(1024)|0;H=pJb(1024)|0;c[l+(v*24|0)+20>>2]=H;if((c[F>>2]|0)==0){I=-12;break a}if((c[G>>2]|0)==0|(H|0)==0){I=-12;break a}H=c[y>>2]|0;J=(c[h>>2]|0)+1|0;c[h>>2]=H>>>0>J>>>0?J:H;if((S0a(k,C,0,0)|0)<0){I=-1094995529;break a}C=c[y>>2]|0;H=(c[h>>2]|0)+1|0;c[h>>2]=C>>>0>H>>>0?H:C;if((c[E>>2]|0)>1){if(($2(m+(v*20|0)|0,9,c[D>>2]|0,c[G>>2]|0,4,4,c[F>>2]|0,4,4,0,0,0,2)|0)<0){break}}F=v+1|0;if((F|0)<(x|0)){v=F}else{K=21;break a}}KIb(e,16,2119368,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;I=-1094995529}else{K=21}}while(0);if((K|0)==21){x=c[h>>2]|0;k=c[y>>2]|0;v=c[u>>2]|0;b:do{if((A|0)==0){F=z;G=x;while(1){D=v+(G>>>3)|0;E=(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)>>>((G&7)>>>0)&255;D=G+8|0;C=k>>>0>D>>>0?D:k;c[h>>2]=C;c[o+(F<<2)>>2]=E;if((F|0)>0){F=F-1|0;G=C}else{break}}G=(p&1)+1|0;F=0;C=B;while(1){a[C]=c[o+(F<<2)>>2];E=F+1|0;if((E|0)>(z|0)){break}else{F=E;C=C+1|0}}if((G|0)>=(t|0)){break}C=m+4|0;F=l+20|0;E=n;D=m+24|0;H=l+44|0;J=o+4|0;L=G;M=B+G|0;while(1){N=c[h>>2]|0;if(((c[w>>2]|0)-N|0)<0){s=-1094995529;K=83;break}if((L&z|0)==0){O=c[C>>2]|0;if((O|0)==0){P=0}else{Q=c[y>>2]|0;R=c[u>>2]|0;S=R+(N>>>3)|0;T=(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)>>>((N&7)>>>0)&511;S=b[O+(T<<2)>>1]|0;U=b[O+(T<<2)+2>>1]|0;T=U<<16>>16;do{if(U<<16>>16<0){V=N+9|0;W=Q>>>0>V>>>0?V:Q;V=R+(W>>>3)|0;X=T+32|0;Y=((d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((W&7)>>>0)<<X>>>(X>>>0))+S|0;X=b[O+(Y<<2)>>1]|0;V=b[O+(Y<<2)+2>>1]|0;Y=V<<16>>16;if(!(V<<16>>16<0)){Z=Y;_=X;$=W;break}V=W-T|0;W=Q>>>0>V>>>0?V:Q;V=R+(W>>>3)|0;aa=Y+32|0;Y=((d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((W&7)>>>0)<<aa>>>(aa>>>0))+X|0;Z=b[O+(Y<<2)+2>>1]|0;_=b[O+(Y<<2)>>1]|0;$=W}else{Z=T;_=S;$=N}}while(0);S=Z+$|0;c[h>>2]=Q>>>0>S>>>0?S:Q;if((_|0)<0){K=76;break}else{P=_}}S=(c[(c[F>>2]|0)+(P<<2)>>2]<<24>>24)+(c[E>>2]|0)|0;c[E>>2]=S;ba=S&255}else{S=c[D>>2]|0;if((S|0)==0){da=0}else{T=c[y>>2]|0;O=c[u>>2]|0;R=O+(N>>>3)|0;U=(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)>>>((N&7)>>>0)&511;R=b[S+(U<<2)>>1]|0;W=b[S+(U<<2)+2>>1]|0;U=W<<16>>16;do{if(W<<16>>16<0){Y=N+9|0;X=T>>>0>Y>>>0?Y:T;Y=O+(X>>>3)|0;aa=U+32|0;V=((d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((X&7)>>>0)<<aa>>>(aa>>>0))+R|0;aa=b[S+(V<<2)>>1]|0;Y=b[S+(V<<2)+2>>1]|0;V=Y<<16>>16;if(!(Y<<16>>16<0)){ea=V;fa=aa;ga=X;break}Y=X-U|0;X=T>>>0>Y>>>0?Y:T;Y=O+(X>>>3)|0;ha=V+32|0;V=((d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)>>>((X&7)>>>0)<<ha>>>(ha>>>0))+aa|0;ea=b[S+(V<<2)+2>>1]|0;fa=b[S+(V<<2)>>1]|0;ga=X}else{ea=U;fa=R;ga=N}}while(0);N=ea+ga|0;c[h>>2]=T>>>0>N>>>0?N:T;if((fa|0)<0){K=69;break}else{da=fa}}N=(c[(c[H>>2]|0)+(da<<2)>>2]<<24>>24)+(c[J>>2]|0)|0;c[J>>2]=N;ba=N&255}a[M]=ba;N=L+1|0;if((N|0)<(t|0)){L=N;M=M+1|0}else{break b}}if((K|0)==69){KIb(e,16,2637656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==76){KIb(e,16,2637656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==83){i=j;return s|0}}else{M=z;L=x;while(1){J=v+(L>>>3)|0;H=(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)>>>((L&7)>>>0);J=L+16|0;ia=k>>>0>J>>>0?J:k;c[h>>2]=ia;c[o+(M<<2)>>2]=(he(H&65535|0)|0)<<16>>16;if((M|0)>0){M=M-1|0;L=ia}else{break}}L=p&1;M=B+((L<<1)+2)|0;H=0;J=f;while(1){b[J>>1]=c[o+(H<<2)>>2];D=H+1|0;if((D|0)>(z|0)){break}else{H=D;J=J+2|0}}J=L+1|0;H=(t|0)/2|0;if((J|0)>=(H|0)){break}D=m+4|0;E=l+20|0;F=m+24|0;C=l+44|0;G=n;N=m+44|0;R=l+68|0;U=m+64|0;S=l+92|0;O=o+4|0;W=J;J=M;Q=ia;while(1){if(((c[w>>2]|0)-Q|0)<0){s=-1094995529;K=83;break}if((W&z|0)==0){X=c[D>>2]|0;if((X|0)==0){ja=0;ka=Q}else{V=c[y>>2]|0;aa=c[u>>2]|0;ha=aa+(Q>>>3)|0;Y=(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)>>>((Q&7)>>>0)&511;ha=b[X+(Y<<2)>>1]|0;la=b[X+(Y<<2)+2>>1]|0;Y=la<<16>>16;do{if(la<<16>>16<0){ma=Q+9|0;na=V>>>0>ma>>>0?ma:V;ma=aa+(na>>>3)|0;oa=Y+32|0;pa=((d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)>>>((na&7)>>>0)<<oa>>>(oa>>>0))+ha|0;oa=b[X+(pa<<2)>>1]|0;ma=b[X+(pa<<2)+2>>1]|0;pa=ma<<16>>16;if(!(ma<<16>>16<0)){qa=pa;ra=oa;sa=na;break}ma=na-Y|0;na=V>>>0>ma>>>0?ma:V;ma=aa+(na>>>3)|0;ta=pa+32|0;pa=((d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)>>>((na&7)>>>0)<<ta>>>(ta>>>0))+oa|0;qa=b[X+(pa<<2)+2>>1]|0;ra=b[X+(pa<<2)>>1]|0;sa=na}else{qa=Y;ra=ha;sa=Q}}while(0);ha=qa+sa|0;Y=V>>>0>ha>>>0?ha:V;c[h>>2]=Y;if((ra|0)<0){K=47;break}else{ja=ra;ka=Y}}Y=c[(c[E>>2]|0)+(ja<<2)>>2]|0;ha=c[F>>2]|0;if((ha|0)==0){ua=0}else{X=c[y>>2]|0;aa=c[u>>2]|0;la=aa+(ka>>>3)|0;T=(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)>>>((ka&7)>>>0)&511;la=b[ha+(T<<2)>>1]|0;na=b[ha+(T<<2)+2>>1]|0;T=na<<16>>16;do{if(na<<16>>16<0){pa=ka+9|0;oa=X>>>0>pa>>>0?pa:X;pa=aa+(oa>>>3)|0;ta=T+32|0;ma=((d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)>>>((oa&7)>>>0)<<ta>>>(ta>>>0))+la|0;ta=b[ha+(ma<<2)>>1]|0;pa=b[ha+(ma<<2)+2>>1]|0;ma=pa<<16>>16;if(!(pa<<16>>16<0)){va=ma;wa=ta;xa=oa;break}pa=oa-T|0;oa=X>>>0>pa>>>0?pa:X;pa=aa+(oa>>>3)|0;ya=ma+32|0;ma=((d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)>>>((oa&7)>>>0)<<ya>>>(ya>>>0))+ta|0;va=b[ha+(ma<<2)+2>>1]|0;wa=b[ha+(ma<<2)>>1]|0;xa=oa}else{va=T;wa=la;xa=ka}}while(0);la=va+xa|0;c[h>>2]=X>>>0>la>>>0?la:X;if((wa|0)<0){K=53;break}else{ua=wa}}la=((c[(c[C>>2]|0)+(ua<<2)>>2]<<8|Y)<<16>>16)+(c[G>>2]|0)|0;c[G>>2]=la;za=la&65535}else{la=c[N>>2]|0;if((la|0)==0){Aa=0;Ba=Q}else{T=c[y>>2]|0;ha=c[u>>2]|0;aa=ha+(Q>>>3)|0;na=(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)>>>((Q&7)>>>0)&511;aa=b[la+(na<<2)>>1]|0;V=b[la+(na<<2)+2>>1]|0;na=V<<16>>16;do{if(V<<16>>16<0){oa=Q+9|0;ma=T>>>0>oa>>>0?oa:T;oa=ha+(ma>>>3)|0;ta=na+32|0;ya=((d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)>>>((ma&7)>>>0)<<ta>>>(ta>>>0))+aa|0;ta=b[la+(ya<<2)>>1]|0;oa=b[la+(ya<<2)+2>>1]|0;ya=oa<<16>>16;if(!(oa<<16>>16<0)){Ca=ya;Da=ta;Ea=ma;break}oa=ma-na|0;ma=T>>>0>oa>>>0?oa:T;oa=ha+(ma>>>3)|0;pa=ya+32|0;ya=((d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)>>>((ma&7)>>>0)<<pa>>>(pa>>>0))+ta|0;Ca=b[la+(ya<<2)+2>>1]|0;Da=b[la+(ya<<2)>>1]|0;Ea=ma}else{Ca=na;Da=aa;Ea=Q}}while(0);aa=Ca+Ea|0;na=T>>>0>aa>>>0?aa:T;c[h>>2]=na;if((Da|0)<0){K=34;break}else{Aa=Da;Ba=na}}na=c[(c[R>>2]|0)+(Aa<<2)>>2]|0;aa=c[U>>2]|0;if((aa|0)==0){Fa=0}else{la=c[y>>2]|0;ha=c[u>>2]|0;V=ha+(Ba>>>3)|0;Y=(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)>>>((Ba&7)>>>0)&511;V=b[aa+(Y<<2)>>1]|0;X=b[aa+(Y<<2)+2>>1]|0;Y=X<<16>>16;do{if(X<<16>>16<0){ma=Ba+9|0;ya=la>>>0>ma>>>0?ma:la;ma=ha+(ya>>>3)|0;ta=Y+32|0;pa=((d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)>>>((ya&7)>>>0)<<ta>>>(ta>>>0))+V|0;ta=b[aa+(pa<<2)>>1]|0;ma=b[aa+(pa<<2)+2>>1]|0;pa=ma<<16>>16;if(!(ma<<16>>16<0)){Ga=pa;Ha=ta;Ia=ya;break}ma=ya-Y|0;ya=la>>>0>ma>>>0?ma:la;ma=ha+(ya>>>3)|0;oa=pa+32|0;pa=((d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)>>>((ya&7)>>>0)<<oa>>>(oa>>>0))+ta|0;Ga=b[aa+(pa<<2)+2>>1]|0;Ha=b[aa+(pa<<2)>>1]|0;Ia=ya}else{Ga=Y;Ha=V;Ia=Ba}}while(0);V=Ga+Ia|0;c[h>>2]=la>>>0>V>>>0?V:la;if((Ha|0)<0){K=40;break}else{Fa=Ha}}V=((c[(c[S>>2]|0)+(Fa<<2)>>2]<<8|na)<<16>>16)+(c[O>>2]|0)|0;c[O>>2]=V;za=V&65535}b[J>>1]=za;V=W+1|0;if((V|0)>=(H|0)){break b}W=V;J=J+2|0;Q=c[h>>2]|0}if((K|0)==34){KIb(e,16,2637656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==40){KIb(e,16,2637656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==47){KIb(e,16,2637656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==53){KIb(e,16,2637656,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-1094995529;i=j;return s|0}else if((K|0)==83){i=j;return s|0}}}while(0);c[g>>2]=1;I=q}if((c[m+4>>2]|0)!=0){c3(m|0)}kJb(c[l+12>>2]|0);kJb(c[l+16>>2]|0);kJb(c[l+20>>2]|0);if((c[m+24>>2]|0)!=0){c3(m+20|0)}kJb(c[l+36>>2]|0);kJb(c[l+40>>2]|0);kJb(c[l+44>>2]|0);if((c[m+44>>2]|0)!=0){c3(m+40|0)}kJb(c[l+60>>2]|0);kJb(c[l+64>>2]|0);kJb(c[l+68>>2]|0);if((c[m+64>>2]|0)!=0){c3(m+60|0)}kJb(c[l+84>>2]|0);kJb(c[l+88>>2]|0);kJb(c[l+92>>2]|0);s=I;i=j;return s|0}function S0a(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;a:do{if((f|0)<=27){h=a+8|0;j=a|0;k=a+16|0;l=e;m=f;while(1){n=c[h>>2]|0;o=c[j>>2]|0;p=d[o+(n>>>3)|0]|0;c[h>>2]=((n|0)<(c[k>>2]|0))+n;if((p&1<<(n&7)|0)==0){break}n=m+1|0;p=S0a(a,b,l,n)|0;if((p|0)!=0){q=p;r=14;break}if((n|0)>27){break a}else{l=1<<m|l;m=n}}if((r|0)==14){i=g;return q|0}j=b+8|0;n=c[j>>2]|0;if((n|0)>=(c[b>>2]|0)){KIb(0,16,2587488,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;q=-1094995529;i=g;return q|0}p=(c[b+12>>2]|0)+(n<<2)|0;if((m|0)==0){c[p>>2]=0;c[(c[b+16>>2]|0)+(c[j>>2]<<2)>>2]=0}else{c[p>>2]=l;c[(c[b+16>>2]|0)+(c[j>>2]<<2)>>2]=m}p=c[h>>2]|0;n=c[k>>2]|0;t=o+(p>>>3)|0;u=(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((p&7)>>>0)&255;t=p+8|0;c[h>>2]=n>>>0>t>>>0?t:n;c[(c[b+20>>2]|0)+(c[j>>2]<<2)>>2]=u;c[j>>2]=(c[j>>2]|0)+1;j=b+4|0;if((c[j>>2]|0)>=(m|0)){q=0;i=g;return q|0}c[j>>2]=m;q=0;i=g;return q|0}}while(0);KIb(0,16,2614368,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;q=-1094995529;i=g;return q|0}function T0a(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;i=i+152|0;j=h|0;k=h+24|0;l=h+48|0;m=h+72|0;n=h+112|0;mrc(m|0,0,40)|0;if(g>>>0>268435454>>>0){KIb(c[a>>2]|0,16,2441368,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}q=k|0;c[q>>2]=256;c[k+4>>2]=0;r=k+8|0;c[r>>2]=0;s=pJb(1024)|0;t=k+12|0;c[t>>2]=s;u=pJb(1024)|0;v=k+16|0;c[v>>2]=u;w=pJb(1024)|0;x=k+20|0;c[x>>2]=w;y=l|0;c[y>>2]=256;c[l+4>>2]=0;z=l+8|0;c[z>>2]=0;A=pJb(1024)|0;B=l+12|0;c[B>>2]=A;C=pJb(1024)|0;D=l+16|0;c[D>>2]=C;E=pJb(1024)|0;F=l+20|0;c[F>>2]=E;a:do{if((s|0)==0|(u|0)==0|(w|0)==0|(A|0)==0){G=-12}else{if((C|0)==0|(E|0)==0){G=-12;break}H=b+8|0;I=c[H>>2]|0;J=b|0;K=d[(c[J>>2]|0)+(I>>>3)|0]|0;L=b+16|0;c[H>>2]=((I|0)<(c[L>>2]|0))+I;do{if((K&1<<(I&7)|0)!=0){M=S0a(b,k,0,0)|0;if((M|0)<0){G=M;break a}M=c[L>>2]|0;N=(c[H>>2]|0)+1|0;c[H>>2]=M>>>0>N>>>0?N:M;if((c[r>>2]|0)<=1){break}M=$2(m|0,9,c[q>>2]|0,c[v>>2]|0,4,4,c[t>>2]|0,4,4,0,0,0,2)|0;if((M|0)>=0){break}KIb(c[a>>2]|0,16,2119368,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;G=M;break a}}while(0);I=m|0;if((c[m+4>>2]|0)==0){KIb(c[a>>2]|0,16,2429672,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}K=c[H>>2]|0;M=d[(c[J>>2]|0)+(K>>>3)|0]|0;c[H>>2]=((K|0)<(c[L>>2]|0))+K;do{if((M&1<<(K&7)|0)!=0){N=S0a(b,l,0,0)|0;if((N|0)<0){G=N;break a}N=c[L>>2]|0;O=(c[H>>2]|0)+1|0;c[H>>2]=N>>>0>O>>>0?O:N;if((c[z>>2]|0)<=1){break}N=$2(m+20|0,9,c[y>>2]|0,c[D>>2]|0,4,4,c[B>>2]|0,4,4,0,0,0,2)|0;if((N|0)>=0){break}KIb(c[a>>2]|0,16,2119368,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;G=N;break a}}while(0);if((c[m+24>>2]|0)==0){KIb(c[a>>2]|0,16,2419200,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o}K=c[H>>2]|0;M=c[L>>2]|0;N=c[J>>2]|0;O=N+(K>>>3)|0;P=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((K&7)>>>0)&65535;O=K+16|0;K=M>>>0>O>>>0?O:M;c[H>>2]=K;O=N+(K>>>3)|0;Q=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((K&7)>>>0)&65535;O=K+16|0;K=M>>>0>O>>>0?O:M;c[H>>2]=K;O=N+(K>>>3)|0;N=(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)>>>((K&7)>>>0)&65535;O=K+16|0;c[H>>2]=M>>>0>O>>>0?O:M;c[f+8>>2]=-1;c[f+4>>2]=-1;c[f>>2]=-1;c[n+16>>2]=P;c[n+20>>2]=Q;c[n+24>>2]=N;c[n>>2]=I;c[n+4>>2]=m+20;c[n+8>>2]=c[x>>2];c[n+12>>2]=c[F>>2];N=n+28|0;c[N>>2]=f;Q=(g+3>>2)+4|0;P=j|0;c[P>>2]=Q;c[j+4>>2]=0;M=j+8|0;c[M>>2]=0;O=pJb(Q<<2)|0;Q=j+20|0;c[Q>>2]=O;if((O|0)==0){G=-12;break}O=(U0a(b,j,n)|0)>>31;K=c[L>>2]|0;R=(c[H>>2]|0)+1|0;c[H>>2]=K>>>0>R>>>0?R:K;K=c[N>>2]|0;if((c[K>>2]|0)==-1){N=c[M>>2]|0;c[M>>2]=N+1;c[K>>2]=N}N=K+4|0;if((c[N>>2]|0)==-1){R=c[M>>2]|0;c[M>>2]=R+1;c[N>>2]=R}R=K+8|0;S=c[R>>2]|0;if((S|0)==-1){T=c[M>>2]|0;c[M>>2]=T+1;c[R>>2]=T;U=T}else{U=S}S=c[P>>2]|0;if((c[K>>2]|0)<(S|0)){if((c[N>>2]|0)<(S|0)&(U|0)<(S|0)){V=O}else{W=28}}else{W=28}if((W|0)==28){KIb(c[a>>2]|0,16,2410192,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;V=-1094995529}c[e>>2]=c[Q>>2];G=V}}while(0);if((c[m+4>>2]|0)!=0){c3(m|0)}if((c[m+24>>2]|0)!=0){c3(m+20|0)}kJb(c[t>>2]|0);kJb(c[v>>2]|0);kJb(c[x>>2]|0);kJb(c[B>>2]|0);kJb(c[D>>2]|0);kJb(c[F>>2]|0);p=G;i=h;return p|0}function U0a(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;h=e+8|0;if(((c[h>>2]|0)+1|0)>=(c[e>>2]|0)){KIb(0,16,2587488,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=g;return k|0}j=a+8|0;l=c[j>>2]|0;m=c[a>>2]|0;n=d[m+(l>>>3)|0]|0;o=c[a+16>>2]|0;p=((l|0)<(o|0))+l|0;c[j>>2]=p;if((n&1<<(l&7)|0)!=0){l=c[h>>2]|0;c[h>>2]=l+1;n=U0a(a,e,f)|0;if((n|0)<0){k=n;i=g;return k|0}c[(c[e+20>>2]|0)+(l<<2)>>2]=n|-2147483648;l=U0a(a,e,f)|0;if((l|0)<0){k=l;i=g;return k|0}k=n+1+l|0;i=g;return k|0}l=c[(c[f>>2]|0)+4>>2]|0;if((l|0)==0){q=0;r=p}else{n=m+(p>>>3)|0;a=(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((p&7)>>>0)&511;n=b[l+(a<<2)>>1]|0;s=b[l+(a<<2)+2>>1]|0;a=s<<16>>16;do{if(s<<16>>16<0){t=p+9|0;u=o>>>0>t>>>0?t:o;t=m+(u>>>3)|0;v=a+32|0;w=((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((u&7)>>>0)<<v>>>(v>>>0))+n|0;v=b[l+(w<<2)>>1]|0;t=b[l+(w<<2)+2>>1]|0;w=t<<16>>16;if(!(t<<16>>16<0)){x=w;y=v;z=u;break}t=u-a|0;u=o>>>0>t>>>0?t:o;t=m+(u>>>3)|0;A=w+32|0;w=((d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)>>>((u&7)>>>0)<<A>>>(A>>>0))+v|0;x=b[l+(w<<2)+2>>1]|0;y=b[l+(w<<2)>>1]|0;z=u}else{x=a;y=n;z=p}}while(0);p=x+z|0;z=o>>>0>p>>>0?p:o;c[j>>2]=z;q=y;r=z}z=c[(c[f+4>>2]|0)+4>>2]|0;if((z|0)==0){B=0}else{y=m+(r>>>3)|0;p=(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)>>>((r&7)>>>0)&511;y=b[z+(p<<2)>>1]|0;x=b[z+(p<<2)+2>>1]|0;p=x<<16>>16;do{if(x<<16>>16<0){n=r+9|0;a=o>>>0>n>>>0?n:o;n=m+(a>>>3)|0;l=p+32|0;s=((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((a&7)>>>0)<<l>>>(l>>>0))+y|0;l=b[z+(s<<2)>>1]|0;n=b[z+(s<<2)+2>>1]|0;s=n<<16>>16;if(!(n<<16>>16<0)){C=s;D=l;E=a;break}n=a-p|0;a=o>>>0>n>>>0?n:o;n=m+(a>>>3)|0;u=s+32|0;s=((d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)>>>((a&7)>>>0)<<u>>>(u>>>0))+l|0;C=b[z+(s<<2)+2>>1]|0;D=b[z+(s<<2)>>1]|0;E=a}else{C=p;D=y;E=r}}while(0);r=C+E|0;c[j>>2]=o>>>0>r>>>0?r:o;B=D}if((B|q|0)<0){k=-1094995529;i=g;return k|0}D=c[(c[f+12>>2]|0)+(B<<2)>>2]<<8|c[(c[f+8>>2]|0)+(q<<2)>>2];do{if((D|0)==(c[f+16>>2]|0)){c[c[f+28>>2]>>2]=c[h>>2];F=0}else{if((D|0)==(c[f+20>>2]|0)){c[(c[f+28>>2]|0)+4>>2]=c[h>>2];F=0;break}if((D|0)!=(c[f+24>>2]|0)){F=D;break}c[(c[f+28>>2]|0)+8>>2]=c[h>>2];F=0}}while(0);f=c[h>>2]|0;c[h>>2]=f+1;c[(c[e+20>>2]|0)+(f<<2)>>2]=F;k=1;i=g;return k|0}function V0a(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[a+140>>2]=11;a=UHb()|0;c[b+4>>2]=a;return((a|0)==0?-12:0)|0}function W0a(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;l=c[b+60>>2]|0;m=l;n=V1(g,0,0)|0;if(!((k|0)>-1)){KIb(0,0,2142928,(o=i,i=i+24|0,c[o>>2]=2119352,c[o+8>>2]=2637632,c[o+16>>2]=135,o)|0);i=o;Hd();return 0}g=l+8|0;c[g>>2]=j;p=l+16|0;c[p>>2]=j;q=l+12|0;c[q>>2]=j+k;j=l+4|0;r=N4a(b,c[j>>2]|0)|0;if((r|0)<0){s=r;i=h;return s|0}r=c[j>>2]|0;if((n|0)==0){t=l+3604|0}else{c[r+304>>2]=1;b=l+3604|0;nrc(b|0,n|0,1024)|0;t=b}b=l;l=c[b>>2]|0;n=c[l+120>>2]|0;u=c[r+32>>2]|0;v=(c[q>>2]|0)-(c[p>>2]|0)|0;p=c[r>>2]|0;w=ca(u,c[l+124>>2]|0)|0;l=u-4|0;nrc(c[r+4>>2]|0,t|0,1024)|0;t=c[g>>2]|0;r=c[q>>2]|0;x=r-t|0;y=x>>>0>1>>>0?1:x;x=t+y|0;c[g>>2]=x;if((r-x|0)<3){z=0}else{c[g>>2]=t+(y+3);z=(d[t+(y+1)|0]|0)<<8|(d[x]|0)<<16|(d[t+(y+2)|0]|0)}if((z|0)!=(v|0)){KIb(c[b>>2]|0,32,2446448,(o=i,i=i+16|0,c[o>>2]=z,c[o+8>>2]=v,o)|0);i=o}v=c[b>>2]|0;z=ca(((c[v+124>>2]|0)+3|0)/4|0,((c[v+120>>2]|0)+3|0)/4|0)|0;a:do{if((z|0)!=0){v=u<<2;y=u<<1;t=u*3|0;x=0;r=0;A=z;B=0;C=0;D=0;b:while(1){if((x|0)>=(w|0)){E=14;break}F=c[g>>2]|0;G=c[q>>2]|0;c:do{if((G-F|0)<1){H=0;E=20}else{I=F+1|0;c[g>>2]=I;J=d[F]|0;K=J&240;switch(K|0){case 0:case 16:{if((J&16|0)==0){H=J;E=20;break c}if((G-I|0)<1){L=0;E=21;break c}c[g>>2]=F+2;L=d[I]|0;E=21;break c;break};case 64:case 80:{do{if((J&16|0)==0){M=J&15}else{if((G-I|0)<1){M=0;break}c[g>>2]=F+2;M=d[I]|0}}while(0);N=(M<<1)+2|0;if((x|0)==0&(r|0)<8){E=43;break b}if((r|0)==0){O=c[(c[b>>2]|0)+120>>2]|0;P=O<<2;Q=x+l-P|0;R=x-8+O-P|0}else if((r|0)==4){S=x+l-(c[(c[b>>2]|0)+120>>2]<<2)|0;E=48}else{S=r-8+x|0;E=48}if((E|0)==48){E=0;Q=r-4+x|0;R=S}P=N;N=A;O=0;T=r;U=x;while(1){if((P|0)==0){V=D;W=C;X=B;Y=N;Z=T;_=U;break c}$=T+U|0;aa=(O|0)!=0;ba=aa?Q:R;a[p+$|0]=a[p+ba|0]|0;a[p+($+1)|0]=a[p+(ba+1)|0]|0;a[p+($+2)|0]=a[p+(ba+2)|0]|0;a[p+($+3)|0]=a[p+(ba+3)|0]|0;da=$+u|0;$=ba+u|0;a[p+da|0]=a[p+$|0]|0;a[p+(da+1)|0]=a[p+($+1)|0]|0;a[p+(da+2)|0]=a[p+($+2)|0]|0;a[p+(da+3)|0]=a[p+($+3)|0]|0;ba=da+u|0;da=$+u|0;a[p+ba|0]=a[p+da|0]|0;a[p+(ba+1)|0]=a[p+(da+1)|0]|0;a[p+(ba+2)|0]=a[p+(da+2)|0]|0;a[p+(ba+3)|0]=a[p+(da+3)|0]|0;$=ba+u|0;ba=da+u|0;a[p+$|0]=a[p+ba|0]|0;a[p+($+1)|0]=a[p+(ba+1)|0]|0;a[p+($+2)|0]=a[p+(ba+2)|0]|0;a[p+($+3)|0]=a[p+(ba+3)|0]|0;ba=T+4|0;$=(ba|0)<(n|0);da=N-1|0;if((da|0)<0){E=52;break b}else{P=P-1|0;N=da;O=aa&1^1;T=$?ba:0;U=($?0:v)+U|0}}break};case 160:case 176:{U=(J&15)+1|0;do{if((K|0)==160){T=C<<2;if((G-I|0)<1){ea=0}else{c[g>>2]=F+2;ea=a[I]|0}a[m+532+T|0]=ea;O=c[g>>2]|0;if(((c[q>>2]|0)-O|0)<1){fa=0}else{c[g>>2]=O+1;fa=a[O]|0}a[(T|1)+(m+532)|0]=fa;O=c[g>>2]|0;if(((c[q>>2]|0)-O|0)<1){ga=0}else{c[g>>2]=O+1;ga=a[O]|0}a[(T|2)+(m+532)|0]=ga;O=c[g>>2]|0;if(((c[q>>2]|0)-O|0)<1){ha=0}else{c[g>>2]=O+1;ha=a[O]|0}a[(T|3)+(m+532)|0]=ha;O=C+1|0;ia=(O|0)==256?0:O;ja=T}else{if((G-I|0)<1){ia=C;ja=0;break}c[g>>2]=F+2;ia=C;ja=(d[I]|0)<<2}}while(0);T=U;O=A;N=r;P=x;while(1){$=T-1|0;if((T|0)==0){V=D;W=ia;X=B;Y=O;Z=N;_=P;break c}ba=c[g>>2]|0;if(((c[q>>2]|0)-ba|0)<4){ka=0}else{c[g>>2]=ba+4;aa=ba;ka=je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0}aa=30;ba=0;da=N+P|0;while(1){a[p+da|0]=a[(ka>>>(aa>>>0)&3|ja)+(m+532)|0]|0;a[p+(da+1)|0]=a[(ka>>>((aa-2|0)>>>0)&3|ja)+(m+532)|0]|0;a[p+(da+2)|0]=a[(ka>>>((aa-4|0)>>>0)&3|ja)+(m+532)|0]|0;a[p+(da+3)|0]=a[(ka>>>((aa-6|0)>>>0)&3|ja)+(m+532)|0]|0;la=ba+1|0;if((la|0)<4){aa=aa-8|0;ba=la;da=da+u|0}else{break}}da=N+4|0;ba=(da|0)<(n|0);aa=O-1|0;if((aa|0)<0){E=90;break b}else{T=$;O=aa;N=ba?da:0;P=(ba?0:v)+P|0}}break};case 96:case 112:{do{if((J&16|0)==0){ma=J&15;na=I}else{if((G-I|0)<1){ma=0;na=I;break}P=F+2|0;c[g>>2]=P;ma=d[I]|0;na=P}}while(0);if((G-na|0)<1){oa=0}else{c[g>>2]=na+1;oa=a[na]|0}P=ma+1|0;N=A;O=r;T=x;while(1){if((P|0)==0){V=D;W=C;X=B;Y=N;Z=O;_=T;break c}U=O+T|0;mrc(p+U|0,oa|0,4)|0;mrc(p+(U+u)|0,oa|0,4)|0;mrc(p+(U+y)|0,oa|0,4)|0;mrc(p+(U+t)|0,oa|0,4)|0;U=O+4|0;ba=(U|0)<(n|0);da=N-1|0;if((da|0)<0){E=62;break b}else{P=P-1|0;N=da;O=ba?U:0;T=(ba?0:v)+T|0}}break};case 32:case 48:{do{if((J&16|0)==0){pa=J&15}else{if((G-I|0)<1){pa=0;break}c[g>>2]=F+2;pa=d[I]|0}}while(0);if((x|r|0)==0){E=30;break b}if((r|0)==0){T=c[(c[b>>2]|0)+120>>2]|0;qa=x-4+T-(T<<2)|0;ra=0}else{qa=r-4+x|0;ra=r}T=p+qa|0;O=p+(qa+1)|0;N=p+(qa+2)|0;P=p+(qa+3)|0;ba=qa+u|0;U=p+ba|0;da=p+(ba+1)|0;aa=p+(ba+2)|0;la=p+(ba+3)|0;sa=ba+u|0;ba=p+sa|0;ta=p+(sa+1)|0;ua=p+(sa+2)|0;va=p+(sa+3)|0;wa=sa+u|0;sa=p+wa|0;xa=p+(wa+1)|0;ya=p+(wa+2)|0;za=p+(wa+3)|0;wa=pa+1|0;Aa=A;Ba=ra;Ca=x;while(1){if((wa|0)==0){V=D;W=C;X=B;Y=Aa;Z=Ba;_=Ca;break c}Da=Ba+Ca|0;a[p+Da|0]=a[T]|0;a[p+(Da+1)|0]=a[O]|0;a[p+(Da+2)|0]=a[N]|0;a[p+(Da+3)|0]=a[P]|0;Ea=Da+u|0;a[p+Ea|0]=a[U]|0;a[p+(Ea+1)|0]=a[da]|0;a[p+(Ea+2)|0]=a[aa]|0;a[p+(Ea+3)|0]=a[la]|0;Da=Ea+u|0;a[p+Da|0]=a[ba]|0;a[p+(Da+1)|0]=a[ta]|0;a[p+(Da+2)|0]=a[ua]|0;a[p+(Da+3)|0]=a[va]|0;Ea=Da+u|0;a[p+Ea|0]=a[sa]|0;a[p+(Ea+1)|0]=a[xa]|0;a[p+(Ea+2)|0]=a[ya]|0;a[p+(Ea+3)|0]=a[za]|0;Ea=Ba+4|0;Da=(Ea|0)<(n|0);Fa=Aa-1|0;if((Fa|0)<0){E=37;break b}else{wa=wa-1|0;Aa=Fa;Ba=Da?Ea:0;Ca=(Da?0:v)+Ca|0}}break};case 224:{Ca=(J&15)+1|0;Ba=A;Aa=r;wa=x;while(1){za=Ca-1|0;if((Ca|0)==0){V=D;W=C;X=B;Y=Ba;Z=Aa;_=wa;break c}ya=1;xa=Aa+wa|0;while(1){sa=c[g>>2]|0;if(((c[q>>2]|0)-sa|0)<1){Ga=0}else{c[g>>2]=sa+1;Ga=a[sa]|0}a[p+xa|0]=Ga;sa=c[g>>2]|0;if(((c[q>>2]|0)-sa|0)<1){Ha=0}else{c[g>>2]=sa+1;Ha=a[sa]|0}a[p+(xa+1)|0]=Ha;sa=c[g>>2]|0;if(((c[q>>2]|0)-sa|0)<1){Ia=0}else{c[g>>2]=sa+1;Ia=a[sa]|0}a[p+(xa+2)|0]=Ia;sa=c[g>>2]|0;if(((c[q>>2]|0)-sa|0)<1){Ja=0}else{c[g>>2]=sa+1;Ja=a[sa]|0}a[p+(xa+3)|0]=Ja;if((ya|0)>=4){break}ya=ya+1|0;xa=xa+u|0}xa=Aa+4|0;ya=(xa|0)<(n|0);$=Ba-1|0;if(($|0)<0){E=116;break b}else{Ca=za;Ba=$;Aa=ya?xa:0;wa=(ya?0:v)+wa|0}}break};case 240:{QIb(c[b>>2]|0,2170032,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;V=D;W=C;X=B;Y=A;Z=r;_=x;break c;break};case 192:case 208:{wa=(J&15)+1|0;do{if((K|0)==192){Aa=D<<3;if((G-I|0)<1){Ka=0;La=I}else{Ba=F+2|0;c[g>>2]=Ba;Ka=a[I]|0;La=Ba}a[m+1556+Aa|0]=Ka;if(((c[q>>2]|0)-La|0)<1){Ma=0;Na=La}else{Ba=La+1|0;c[g>>2]=Ba;Ma=a[La]|0;Na=Ba}a[(Aa|1)+(m+1556)|0]=Ma;if(((c[q>>2]|0)-Na|0)<1){Oa=0;Pa=Na}else{Ba=Na+1|0;c[g>>2]=Ba;Oa=a[Na]|0;Pa=Ba}a[(Aa|2)+(m+1556)|0]=Oa;if(((c[q>>2]|0)-Pa|0)<1){Qa=0;Ra=Pa}else{Ba=Pa+1|0;c[g>>2]=Ba;Qa=a[Pa]|0;Ra=Ba}a[(Aa|3)+(m+1556)|0]=Qa;Ba=c[q>>2]|0;if((Ba-Ra|0)<1){Sa=0}else{c[g>>2]=Ra+1;Sa=a[Ra]|0}a[(Aa|4)+(m+1556)|0]=Sa;Ca=c[g>>2]|0;if((Ba-Ca|0)<1){Ta=0}else{c[g>>2]=Ca+1;Ta=a[Ca]|0}a[(Aa|5)+(m+1556)|0]=Ta;Ca=c[g>>2]|0;if((Ba-Ca|0)<1){Ua=0}else{c[g>>2]=Ca+1;Ua=a[Ca]|0}a[(Aa|6)+(m+1556)|0]=Ua;Ca=c[g>>2]|0;if((Ba-Ca|0)<1){Va=0}else{c[g>>2]=Ca+1;Va=a[Ca]|0}a[(Aa|7)+(m+1556)|0]=Va;Ca=D+1|0;Wa=(Ca|0)==256?0:Ca;Xa=Aa}else{if((G-I|0)<1){Wa=D;Xa=0;break}c[g>>2]=F+2;Wa=D;Xa=(d[I]|0)<<3}}while(0);Aa=wa;Ca=A;Ba=r;ya=x;while(1){xa=Aa-1|0;if((Aa|0)==0){V=Wa;W=C;X=B;Y=Ca;Z=Ba;_=ya;break c}$=c[g>>2]|0;sa=c[q>>2]|0;if((sa-$|0)<2){Ya=0;Za=$}else{va=$+2|0;c[g>>2]=va;ua=$;Ya=((he((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535)<<8;Za=va}if((sa-Za|0)<2){_a=0;$a=Za}else{va=Za+2|0;c[g>>2]=va;ua=Za;_a=(he((d[ua]|d[ua+1|0]<<8)<<16>>16|0)|0)&65535;$a=va}if((sa-$a|0)<2){ab=0}else{c[g>>2]=$a+2;sa=$a;ab=(he((d[sa]|d[sa+1|0]<<8)<<16>>16|0)|0)&65535}sa=_a<<4&240|Ya&3840|ab&15|ab<<8&16773120;va=21;ua=0;$=_a>>>4|Ya&16773120;ta=Ba+ya|0;while(1){ba=(ua|0)==2;la=ba?21:va;aa=ba?sa:$;a[p+ta|0]=a[(aa>>>(la>>>0)&7|Xa)+(m+1556)|0]|0;a[p+(ta+1)|0]=a[(aa>>>((la-3|0)>>>0)&7|Xa)+(m+1556)|0]|0;a[p+(ta+2)|0]=a[(aa>>>((la-6|0)>>>0)&7|Xa)+(m+1556)|0]|0;a[p+(ta+3)|0]=a[(aa>>>((la-9|0)>>>0)&7|Xa)+(m+1556)|0]|0;ba=ua+1|0;if((ba|0)<4){va=la-12|0;ua=ba;$=aa;ta=ta+u|0}else{break}}ta=Ba+4|0;$=(ta|0)<(n|0);ua=Ca-1|0;if((ua|0)<0){E=108;break b}else{Aa=xa;Ca=ua;Ba=$?ta:0;ya=($?0:v)+ya|0}}break};case 128:case 144:{ya=(J&15)+1|0;do{if((K|0)==128){Ba=B<<1;if((G-I|0)<1){bb=0}else{c[g>>2]=F+2;bb=a[I]|0}a[m+20+Ba|0]=bb;Ca=c[g>>2]|0;if(((c[q>>2]|0)-Ca|0)<1){cb=0}else{c[g>>2]=Ca+1;cb=a[Ca]|0}a[(Ba|1)+(m+20)|0]=cb;Ca=B+1|0;db=(Ca|0)==256?0:Ca;eb=Ba}else{if((G-I|0)<1){db=B;eb=0;break}c[g>>2]=F+2;db=B;eb=(d[I]|0)<<1}}while(0);I=ya;J=A;Ba=r;Ca=x;while(1){Aa=I-1|0;if((I|0)==0){V=D;W=C;X=db;Y=J;Z=Ba;_=Ca;break c}wa=c[g>>2]|0;if(((c[q>>2]|0)-wa|0)<2){fb=0}else{c[g>>2]=wa+2;$=wa;fb=(he((d[$]|d[$+1|0]<<8)<<16>>16|0)|0)&65535}$=32768;wa=0;ta=Ba+Ca|0;while(1){a[p+ta|0]=a[(($&fb|0)!=0|eb)+(m+20)|0]|0;a[p+(ta+1)|0]=a[(($>>>1&fb|0)!=0|eb)+(m+20)|0]|0;a[p+(ta+2)|0]=a[(($>>>2&fb|0)!=0|eb)+(m+20)|0]|0;a[p+(ta+3)|0]=a[(($>>>3&fb|0)!=0|eb)+(m+20)|0]|0;ua=wa+1|0;if((ua|0)<4){$=$>>>4;wa=ua;ta=ta+u|0}else{break}}ta=Ba+4|0;wa=(ta|0)<(n|0);$=J-1|0;if(($|0)<0){E=76;break b}else{I=Aa;J=$;Ba=wa?ta:0;Ca=(wa?0:v)+Ca|0}}break};default:{V=D;W=C;X=B;Y=A;Z=r;_=x;break c}}}}while(0);if((E|0)==20){E=0;L=H&15;E=21}d:do{if((E|0)==21){E=0;F=L+1|0;G=A;Ca=r;Ba=x;while(1){if((F|0)==0){V=D;W=C;X=B;Y=G;Z=Ca;_=Ba;break d}J=Ca+4|0;I=(J|0)<(n|0);ya=G-1|0;if((ya|0)<0){E=24;break b}else{F=F-1|0;G=ya;Ca=I?J:0;Ba=(I?0:v)+Ba|0}}}}while(0);if((Y|0)==0){break a}else{x=_;r=Z;A=Y;B=X;C=W;D=V}}if((E|0)==14){KIb(c[b>>2]|0,32,2357216,(o=i,i=i+16|0,c[o>>2]=x,c[o+8>>2]=w,o)|0);i=o;break}else if((E|0)==24){KIb(c[b>>2]|0,32,2294136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==30){KIb(c[b>>2]|0,32,2243160,(o=i,i=i+8|0,c[o>>2]=K,o)|0);i=o;break}else if((E|0)==37){KIb(c[b>>2]|0,32,2294136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==43){KIb(c[b>>2]|0,32,2201808,(o=i,i=i+8|0,c[o>>2]=K,o)|0);i=o;break}else if((E|0)==52){KIb(c[b>>2]|0,32,2294136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==62){KIb(c[b>>2]|0,32,2294136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==76){KIb(c[b>>2]|0,32,2294136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==90){KIb(c[b>>2]|0,32,2294136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==108){KIb(c[b>>2]|0,32,2294136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}else if((E|0)==116){KIb(c[b>>2]|0,32,2294136,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;break}}}while(0);c[f>>2]=1;f=YHb(e,c[j>>2]|0)|0;s=(f|0)<0?f:k;i=h;return s|0}function X0a(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function Y0a(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+8|0;e=b|0;f=c[a+60>>2]|0;c[e>>2]=0;g=f+3020|0;c[g>>2]=0;h=UHb()|0;j=f+3008|0;c[j>>2]=h;if((h|0)==0){k=-12;i=b;return k|0}h=UHb()|0;c[f+3012>>2]=h;if((h|0)==0){k=-12;i=b;return k|0}c[f+1140>>2]=c[j>>2];if((c[a+100>>2]|0)>3){j=c[a+96>>2]|0;h=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;c[g>>2]=h;l=h}else{l=c[g>>2]|0}if((l|0)<1){KIb(a,16,2357176,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1}else{n=0}l=c5a(8)|0;if((l|0)==0){KIb(a,16,2294112,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;o=-1}else{o=n}n=f+3016|0;c[n>>2]=mWa(l)|0;MGb(e,2243152,2201800,0)|0;f=c[n>>2]|0;c[f+488>>2]=1;c[f+88>>2]=c[a+88>>2];c[f+788>>2]=c[a+788>>2];if((Z4a(f,l,e)|0)<0){KIb(a,16,217e4,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;p=-1}else{p=o}OGb(e);k=p;i=b;return k|0}function Z0a(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;k=c[e+60>>2]|0;l=c[k+3008>>2]|0;m=h+8|0;n=k+3020|0;o=c[n>>2]|0;p=Drc(c[m>>2]|0,c[m+4>>2]|0,o,(o|0)<0|0?-1:0)|0;o=p;do{if((o|0)==0){WHb(l);p=k+3016|0;q=k5a(c[p>>2]|0,l,k+3024|0,h)|0;r=p}else{if((c[k+3024>>2]|0)==0){s=-22;i=j;return s|0}else{q=0;r=k+3016|0;break}}}while(0);h=qKb(c[(c[r>>2]|0)+140>>2]|0)|0;p=l+72|0;do{if((h|0)!=0){if(((c[p>>2]|0)%(c[n>>2]<<(d[h+6|0]|0)|0)|0|0)==0){break}KIb(e,16,2446432,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;s=-1094995529;i=j;return s|0}}while(0);c[g>>2]=c[k+3024>>2];h=e+140|0;c[h>>2]=c[(c[r>>2]|0)+140>>2];G4a(e,c[l+68>>2]|0,(c[p>>2]|0)/(c[n>>2]|0)|0);if((c[g>>2]|0)==0){s=q;i=j;return s|0}q=k+3012|0;c[(c[q>>2]|0)+64>>2]=0;k=c[q>>2]|0;c[k+68>>2]=c[e+120>>2];g=e+124|0;c[k+72>>2]=c[g>>2];e=c[h>>2]|0;c[k+80>>2]=e;h=c[g>>2]|0;g=qKb(e)|0;e=g+7|0;n=a[e]|0;do{if((n&8)==0){p=a[g+4|0]|0;do{if(p<<24>>24==0){t=n}else{r=p&255;m=0;u=0;do{v=(b[g+8+(m<<1)>>1]&3)+1|0;u=(u|0)>(v|0)?u:v;m=m+1|0;}while((m|0)<(r|0));if((u|0)<=0){t=n;break}r=-h|0;m=g+6|0;v=0;do{if((v-1|0)>>>0<2>>>0){w=-(r>>(d[m]|0))|0}else{w=h}x=k+(v<<2)|0;y=c[l+(v<<2)>>2]|0;if(!((x|0)==0|(y|0)==0)){c[x>>2]=y+(ca(ca(w,o)|0,c[l+32+(v<<2)>>2]|0)|0)}v=v+1|0;}while((v|0)<(u|0));t=a[e]|0}}while(0);if((t&66)==0){break}c[k+4>>2]=c[l+4>>2]}}while(0);k=c[q>>2]|0;c[k+32>>2]=c[l+32>>2];c[k+36>>2]=c[l+36>>2];c[k+40>>2]=c[l+40>>2];c[k+44>>2]=c[l+44>>2];c[k+48>>2]=c[l+48>>2];c[k+52>>2]=c[l+52>>2];c[k+56>>2]=c[l+56>>2];c[k+60>>2]=c[l+60>>2];s=YHb(f,k)|0;i=j;return s|0}function _0a(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b+1140>>2]=0;VHb(b+3008|0);VHb(b+3012|0);a=b+3016|0;q5a(c[a>>2]|0)|0;mJb(a);return 0}function $0a(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;c[a+24>>2]=f;c[a+12>>2]=b;c[a+16>>2]=e;c[a+20>>2]=d;f=pJb(b<<2)|0;c[a>>2]=f;if((f|0)==0){g=-12;return g|0}f=hJb(d<<2)|0;b=a+4|0;c[b>>2]=f;if((f|0)==0){mJb(a);g=-12;return g|0}f=e<<1;e=0;while(1){if((e|0)>=(d|0)){h=11;break}i=hJb(f)|0;c[(c[b>>2]|0)+(e<<2)>>2]=i;j=c[b>>2]|0;if((c[j+(e<<2)>>2]|0)==0){break}else{e=e+1|0}}if((h|0)==11){c[a+8>>2]=d-1;g=0;return g|0}a:do{if((e|0)>0){d=e;h=j;while(1){f=d-1|0;mJb(h+(f<<2)|0);if((f|0)<=0){break a}d=f;h=c[b>>2]|0}}}while(0);mJb(b);mJb(a);g=-12;return g|0}function a1a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a+8|0;f=c[e>>2]|0;if(!((f|0)>-1)){KIb(0,0,2474152,(g=i,i=i+24|0,c[g>>2]=2595440,c[g+8>>2]=2446408,c[g+16>>2]=66,g)|0);i=g;Hd();return 0}g=(c[a>>2]|0)+(b<<2)|0;b=c[g>>2]|0;if((b|0)!=0){h=b;i=d;return h|0}b=c[(c[a+4>>2]|0)+(f<<2)>>2]|0;c[e>>2]=f-1;c[g>>2]=b;h=b;i=d;return h|0}function b1a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a|0;e=c[(c[d>>2]|0)+(b<<2)>>2]|0;f=a+8|0;g=(c[f>>2]|0)+1|0;c[f>>2]=g;c[(c[a+4>>2]|0)+(g<<2)>>2]=e;c[(c[d>>2]|0)+(b<<2)>>2]=0;return}function c1a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+12>>2]|0;if((b|0)<=0){return}d=a|0;e=a+8|0;f=a+4|0;a=0;do{g=c[(c[d>>2]|0)+(a<<2)>>2]|0;if((g|0)!=0){h=(c[e>>2]|0)+1|0;c[e>>2]=h;c[(c[f>>2]|0)+(h<<2)>>2]=g;c[(c[d>>2]|0)+(a<<2)>>2]=0}a=a+1|0;}while((a|0)<(b|0));return}function d1a(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+12>>2]|0;if((b|0)>0){d=a|0;e=a+8|0;f=a+4|0;g=0;while(1){h=c[(c[d>>2]|0)+(g<<2)>>2]|0;if((h|0)!=0){i=(c[e>>2]|0)+1|0;c[e>>2]=i;c[(c[f>>2]|0)+(i<<2)>>2]=h;c[(c[d>>2]|0)+(g<<2)>>2]=0}h=g+1|0;if((h|0)<(b|0)){g=h}else{j=f;break}}}else{j=a+4|0}f=c[a+20>>2]|0;if((f|0)>0){k=f}else{l=j;mJb(l);m=a;mJb(m);return}do{k=k-1|0;mJb((c[j>>2]|0)+(k<<2)|0);}while((k|0)>0);l=j;mJb(l);m=a;mJb(m);return}function e1a(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((h|0)>0){i=0}else{return}do{a:do{if((g|0)==1){j=d>>i;k=e>>i;l=f<<i;m=k-1|0;if(m>>>0<4294967293>>>0){n=m<<1;o=-3;while(1){p=((o|0)>0?n:0)-o|0;if(p>>>0>m>>>0){o=p}else{q=p;break}}}else{q=-3}o=a+((ca(q,l)|0)<<2)|0;if(m>>>0<4294967294>>>0){n=m<<1;p=-2;do{p=((p|0)>0?n:0)-p|0;}while(p>>>0>m>>>0);r=ca(p,l)|0;if((k|0)>-2){s=r;t=n}else{break}}else{s=l*-2|0;t=m<<1}if((j|0)<=0){r=-2;while(1){u=r|1;if(u>>>0>m>>>0){v=u;while(1){w=((v|0)>0?t:0)-v|0;if(w>>>0>m>>>0){v=w}else{x=w;break}}}else{x=u}v=a+((ca(x,l)|0)<<2)|0;r=r+2|0;if(r>>>0>m>>>0){w=r;while(1){y=((w|0)>0?t:0)-w|0;if(y>>>0>m>>>0){w=y}else{z=y;break}}}else{z=r}w=a+((ca(z,l)|0)<<2)|0;if(u>>>0<k>>>0){u1a(v,b,j)}if(r>>>0<k>>>0){u1a(w,b,j)}if((r|0)>=(k|0)){break a}}}r=a+(s<<2)|0;n=o;p=-2;while(1){w=p|1;if(w>>>0>m>>>0){y=w;while(1){A=((y|0)>0?t:0)-y|0;if(A>>>0>m>>>0){y=A}else{B=A;break}}}else{B=w}y=ca(B,l)|0;v=a+(y<<2)|0;u=p+2|0;if(u>>>0>m>>>0){A=u;while(1){C=((A|0)>0?t:0)-A|0;if(C>>>0>m>>>0){A=C}else{D=C;break}}}else{D=u}A=ca(D,l)|0;C=a+(A<<2)|0;E=w>>>0<k>>>0;if(E){u1a(v,b,j)}if(u>>>0<k>>>0){u1a(C,b,j)}if(E){E=0;do{F=a+(E+y<<2)|0;c[F>>2]=(c[F>>2]|0)-((c[a+(E+A<<2)>>2]|0)+(c[r+(E<<2)>>2]|0)>>1);E=E+1|0;}while((E|0)<(j|0))}if(p>>>0<k>>>0){E=0;do{A=r+(E<<2)|0;c[A>>2]=((c[n+(E<<2)>>2]|0)+2+(c[a+(E+y<<2)>>2]|0)>>2)+(c[A>>2]|0);E=E+1|0;}while((E|0)<(j|0))}if((u|0)<(k|0)){r=C;n=v;p=u}else{break}}}else if((g|0)==0){p=d>>i;n=e>>i;r=f<<i;k=n-1|0;if(k>>>0<4294967291>>>0){j=k<<1;l=-5;while(1){m=((l|0)>0?j:0)-l|0;if(m>>>0>k>>>0){l=m}else{G=m;break}}}else{G=-5}l=a+((ca(G,r)|0)<<2)|0;if(k>>>0<4294967292>>>0){j=k<<1;m=-4;while(1){o=((m|0)>0?j:0)-m|0;if(o>>>0>k>>>0){m=o}else{H=o;break}}}else{H=-4}m=a+((ca(H,r)|0)<<2)|0;if(k>>>0<4294967293>>>0){j=k<<1;o=-3;while(1){E=((o|0)>0?j:0)-o|0;if(E>>>0>k>>>0){o=E}else{I=E;break}}}else{I=-3}o=a+((ca(I,r)|0)<<2)|0;j=k<<1;if(k>>>0<4294967294>>>0){E=-2;do{E=((E|0)>0?j:0)-E|0;}while(E>>>0>k>>>0);if((n|0)>-4){J=E}else{break}}else{J=-2}y=(p|0)>0;A=m;w=o;F=a+((ca(J,r)|0)<<2)|0;K=l;L=-4;while(1){M=L+3|0;if(M>>>0>k>>>0){N=M;while(1){O=((N|0)>0?j:0)-N|0;if(O>>>0>k>>>0){N=O}else{P=O;break}}}else{P=M}N=ca(P,r)|0;u=a+(N<<2)|0;v=L+4|0;if(v>>>0>k>>>0){C=v;while(1){O=((C|0)>0?j:0)-C|0;if(O>>>0>k>>>0){C=O}else{Q=O;break}}}else{Q=v}C=ca(Q,r)|0;O=a+(C<<2)|0;R=M>>>0<n>>>0;if(R){v1a(u,b,p)}if(v>>>0<n>>>0){v1a(O,b,p)}if(R&y){R=0;do{S=a+(R+N<<2)|0;c[S>>2]=(c[S>>2]|0)-((((c[a+(R+C<<2)>>2]|0)+(c[F+(R<<2)>>2]|0)|0)*3|0)>>1);R=R+1|0;}while((R|0)<(p|0))}R=L+2|0;if(R>>>0<n>>>0&y){C=0;do{v=F+(C<<2)|0;c[v>>2]=(((c[v>>2]<<6)+671088680-((c[a+(C+N<<2)>>2]|0)+(c[w+(C<<2)>>2]|0)<<2)|0)/80|0)-8388608;C=C+1|0;}while((C|0)<(p|0))}if((L|1)>>>0<n>>>0&y){C=0;do{N=w+(C<<2)|0;c[N>>2]=(c[F+(C<<2)>>2]|0)+(c[A+(C<<2)>>2]|0)+(c[N>>2]|0);C=C+1|0;}while((C|0)<(p|0))}if(L>>>0<n>>>0&y){C=0;do{N=A+(C<<2)|0;c[N>>2]=((((c[w+(C<<2)>>2]|0)+(c[K+(C<<2)>>2]|0)|0)*3|0)+4>>3)+(c[N>>2]|0);C=C+1|0;}while((C|0)<(p|0))}if((R|0)<(n|0)){A=F;K=w;w=u;F=O;L=R}else{break}}}}while(0);i=i+1|0;}while((i|0)<(h|0));return}function f1a(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=d+1>>1;b[c>>1]=(e[a>>1]|0)-((((b[a+(f<<1)>>1]|0)*3|0)+2|0)>>>2);g=d>>1;if((g|0)>1){h=1;while(1){i=h+f|0;j=a+(i-1<<1)|0;k=(e[a+(h<<1)>>1]|0)-(((((b[a+(i<<1)>>1]|0)+(b[j>>1]|0)|0)*3|0)+4|0)>>>3)&65535;i=h<<1;b[c+(i<<1)>>1]=k;b[c+(i-1<<1)>>1]=((b[j>>1]|0)-(b[c+(i-2<<1)>>1]|0)&65535)-k;k=h+1|0;if((k|0)<(g|0)){h=k}else{l=g;break}}}else{l=1}g=(d&1|0)!=0;if(g){h=a+(f-1+l<<1)|0;k=(e[a+(l<<1)>>1]|0)-((((b[h>>1]|0)*3|0)+2|0)>>>2)&65535;i=l<<1;b[c+(i<<1)>>1]=k;b[c+(i-1<<1)>>1]=((b[h>>1]|0)-(b[c+(i-2<<1)>>1]|0)&65535)-k}else{k=l<<1;b[c+(k-1<<1)>>1]=(b[a+(f-1+l<<1)>>1]|0)-(b[c+(k-2<<1)>>1]<<1)}k=b[c>>1]|0;l=(((b[c+2>>1]|0)+4+(k<<1)|0)>>>3)+k&65535;b[a>>1]=l;k=d-1|0;if((k|0)>2){d=2;f=l;while(1){i=b[c+(d<<1)>>1]|0;h=d-1|0;j=c+(h<<1)|0;m=(((b[j>>1]|0)+8+(i<<2)+(b[c+((d|1)<<1)>>1]|0)|0)>>>4)+i&65535;b[a+(d<<1)>>1]=m;b[a+(h<<1)>>1]=((((m<<16>>16)+(f<<16>>16)|0)*3|0)>>>1)+(e[j>>1]|0);j=d+2|0;if((j|0)<(k|0)){d=j;f=m}else{n=j;o=m;break}}}else{n=2;o=l}if(g){g=b[c+(n<<1)>>1]|0;l=n-1|0;f=c+(l<<1)|0;d=(((b[f>>1]|0)+4+(g<<1)|0)>>>3)+g&65535;b[a+(n<<1)>>1]=d;b[a+(l<<1)>>1]=((((d<<16>>16)+(o<<16>>16)|0)*3|0)>>>1)+(e[f>>1]|0);return}else{f=n-1|0;b[a+(f<<1)>>1]=(o*3&65535)+(b[c+(f<<1)>>1]|0);return}}function g1a(a,c,d,f,g,h,i){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;if((i|0)>0){j=0}else{return}do{k=f+(j<<1)|0;l=g+(j<<1)|0;m=(e[l>>1]|0)-(((((b[h+(j<<1)>>1]|0)+(b[k>>1]|0)|0)*3|0)+4|0)>>>3)&65535;b[l>>1]=m;l=d+(j<<1)|0;n=((b[k>>1]|0)-(b[l>>1]|0)&65535)-m&65535;b[k>>1]=n;k=c+(j<<1)|0;m=b[l>>1]|0;o=(((b[k>>1]|0)+8+(m<<2)+(n<<16>>16)|0)>>>4)+m&65535;b[l>>1]=o;b[k>>1]=((((o<<16>>16)+(b[a+(j<<1)>>1]|0)|0)*3|0)>>>1)+(e[k>>1]|0);j=j+1|0;}while((j|0)<(i|0));return}function h1a(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=i;if((h|0)<=0){i=d;return}j=b|0;k=b+8|0;l=b+4|0;b=h;a:while(1){h=b-1|0;if((g|0)==1){m=e>>h;n=f<<h;o=m-1|0;do{if(o>>>0<4294967294>>>0){p=o<<1;q=-2;do{q=((q|0)>0?p:0)-q|0;}while(q>>>0>o>>>0);r=ca(q,n)|0;s=c[j>>2]|0;t=c[s+(r<<2)>>2]|0;r=-2;do{r=((r|0)>0?p:0)-r|0;}while(r>>>0>o>>>0);p=ca(r,n)|0;if((t|0)==0){u=p;v=s;w=62;break}x=c[s+(p<<2)>>2]|0}else{p=n*-2|0;q=c[j>>2]|0;y=c[q+(p<<2)>>2]|0;if((y|0)==0){u=p;v=q;w=62}else{x=y}}}while(0);do{if((w|0)==62){w=0;y=c[k>>2]|0;if(!((y|0)>-1)){w=63;break a}q=v+(u<<2)|0;p=c[q>>2]|0;if((p|0)!=0){x=p;break}p=c[(c[l>>2]|0)+(y<<2)>>2]|0;c[k>>2]=y-1;c[q>>2]=p;x=p}}while(0);c[a+(h*20|0)>>2]=x;do{if((m|0)==0){p=-n|0;q=c[j>>2]|0;y=c[q+(p<<2)>>2]|0;if((y|0)==0){z=p;A=q;w=74}else{B=y}}else{y=o<<1;q=-1;do{q=((q|0)>0?y:0)-q|0;}while(q>>>0>o>>>0);s=ca(q,n)|0;t=c[j>>2]|0;r=c[t+(s<<2)>>2]|0;s=-1;do{s=((s|0)>0?y:0)-s|0;}while(s>>>0>o>>>0);y=ca(s,n)|0;if((r|0)==0){z=y;A=t;w=74;break}B=c[t+(y<<2)>>2]|0}}while(0);do{if((w|0)==74){w=0;n=c[k>>2]|0;if(!((n|0)>-1)){w=75;break a}o=A+(z<<2)|0;m=c[o>>2]|0;if((m|0)!=0){B=m;break}m=c[(c[l>>2]|0)+(n<<2)>>2]|0;c[k>>2]=n-1;c[o>>2]=m;B=m}}while(0);c[a+(h*20|0)+4>>2]=B;c[a+(h*20|0)+16>>2]=-1}else if((g|0)==0){m=e>>h;o=f<<h;n=m-1|0;do{if(n>>>0<4294967292>>>0){y=n<<1;q=-4;do{q=((q|0)>0?y:0)-q|0;}while(q>>>0>n>>>0);t=ca(q,o)|0;r=c[j>>2]|0;s=c[r+(t<<2)>>2]|0;t=-4;do{t=((t|0)>0?y:0)-t|0;}while(t>>>0>n>>>0);y=ca(t,o)|0;if((s|0)==0){C=y;D=r;w=13;break}E=c[r+(y<<2)>>2]|0}else{y=o*-4|0;q=c[j>>2]|0;p=c[q+(y<<2)>>2]|0;if((p|0)==0){C=y;D=q;w=13}else{E=p}}}while(0);do{if((w|0)==13){w=0;p=c[k>>2]|0;if(!((p|0)>-1)){w=14;break a}q=D+(C<<2)|0;y=c[q>>2]|0;if((y|0)!=0){E=y;break}y=c[(c[l>>2]|0)+(p<<2)>>2]|0;c[k>>2]=p-1;c[q>>2]=y;E=y}}while(0);c[a+(h*20|0)>>2]=E;do{if(n>>>0<4294967293>>>0){y=n<<1;q=-3;do{q=((q|0)>0?y:0)-q|0;}while(q>>>0>n>>>0);r=ca(q,o)|0;s=c[j>>2]|0;t=c[s+(r<<2)>>2]|0;r=-3;do{r=((r|0)>0?y:0)-r|0;}while(r>>>0>n>>>0);y=ca(r,o)|0;if((t|0)==0){F=y;G=s;w=25;break}H=c[s+(y<<2)>>2]|0}else{y=o*-3|0;q=c[j>>2]|0;p=c[q+(y<<2)>>2]|0;if((p|0)==0){F=y;G=q;w=25}else{H=p}}}while(0);do{if((w|0)==25){w=0;p=c[k>>2]|0;if(!((p|0)>-1)){w=26;break a}q=G+(F<<2)|0;y=c[q>>2]|0;if((y|0)!=0){H=y;break}y=c[(c[l>>2]|0)+(p<<2)>>2]|0;c[k>>2]=p-1;c[q>>2]=y;H=y}}while(0);c[a+(h*20|0)+4>>2]=H;do{if(n>>>0<4294967294>>>0){y=n<<1;q=-2;do{q=((q|0)>0?y:0)-q|0;}while(q>>>0>n>>>0);s=ca(q,o)|0;t=c[j>>2]|0;r=c[t+(s<<2)>>2]|0;s=-2;do{s=((s|0)>0?y:0)-s|0;}while(s>>>0>n>>>0);y=ca(s,o)|0;if((r|0)==0){I=y;J=t;w=37;break}K=c[t+(y<<2)>>2]|0}else{y=o*-2|0;q=c[j>>2]|0;p=c[q+(y<<2)>>2]|0;if((p|0)==0){I=y;J=q;w=37}else{K=p}}}while(0);do{if((w|0)==37){w=0;p=c[k>>2]|0;if(!((p|0)>-1)){w=38;break a}q=J+(I<<2)|0;y=c[q>>2]|0;if((y|0)!=0){K=y;break}y=c[(c[l>>2]|0)+(p<<2)>>2]|0;c[k>>2]=p-1;c[q>>2]=y;K=y}}while(0);c[a+(h*20|0)+8>>2]=K;do{if((m|0)==0){y=-o|0;q=c[j>>2]|0;p=c[q+(y<<2)>>2]|0;if((p|0)==0){L=y;M=q;w=49}else{N=p}}else{p=n<<1;q=-1;do{q=((q|0)>0?p:0)-q|0;}while(q>>>0>n>>>0);t=ca(q,o)|0;r=c[j>>2]|0;s=c[r+(t<<2)>>2]|0;t=-1;do{t=((t|0)>0?p:0)-t|0;}while(t>>>0>n>>>0);p=ca(t,o)|0;if((s|0)==0){L=p;M=r;w=49;break}N=c[r+(p<<2)>>2]|0}}while(0);do{if((w|0)==49){w=0;o=c[k>>2]|0;if(!((o|0)>-1)){w=50;break a}n=M+(L<<2)|0;m=c[n>>2]|0;if((m|0)!=0){N=m;break}m=c[(c[l>>2]|0)+(o<<2)>>2]|0;c[k>>2]=o-1;c[n>>2]=m;N=m}}while(0);c[a+(h*20|0)+12>>2]=N;c[a+(h*20|0)+16>>2]=-3}if((h|0)>0){b=h}else{w=79;break}}if((w|0)==14){KIb(0,0,2474152,(O=i,i=i+24|0,c[O>>2]=2595440,c[O+8>>2]=2446408,c[O+16>>2]=66,O)|0);i=O;Hd()}else if((w|0)==26){KIb(0,0,2474152,(O=i,i=i+24|0,c[O>>2]=2595440,c[O+8>>2]=2446408,c[O+16>>2]=66,O)|0);i=O;Hd()}else if((w|0)==38){KIb(0,0,2474152,(O=i,i=i+24|0,c[O>>2]=2595440,c[O+8>>2]=2446408,c[O+16>>2]=66,O)|0);i=O;Hd()}else if((w|0)==50){KIb(0,0,2474152,(O=i,i=i+24|0,c[O>>2]=2595440,c[O+8>>2]=2446408,c[O+16>>2]=66,O)|0);i=O;Hd()}else if((w|0)==63){KIb(0,0,2474152,(O=i,i=i+24|0,c[O>>2]=2595440,c[O+8>>2]=2446408,c[O+16>>2]=66,O)|0);i=O;Hd()}else if((w|0)==75){KIb(0,0,2474152,(O=i,i=i+24|0,c[O>>2]=2595440,c[O+8>>2]=2446408,c[O+16>>2]=66,O)|0);i=O;Hd()}else if((w|0)==79){i=d;return}}function i1a(a,d,f,g,h,j,k,l,m,n){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;o=i;p=(l|0)==1?3:5;if(!((l|0)!=2&(m|0)>0)){i=o;return}q=f|0;r=f+8|0;s=f+4|0;f=a|0;t=a+4|0;a=m;a:while(1){m=a-1|0;u=d+(m*20|0)+16|0;v=c[u>>2]|0;w=(n>>m)+p|0;x=j>>m;y=(w|0)>(x|0)?x:w;if((v|0)<=(y|0)){w=h>>m;z=k<<m;A=d+(m*20|0)|0;B=d+(m*20|0)+4|0;C=d+(m*20|0)+8|0;D=d+(m*20|0)+12|0;E=x-1|0;F=E<<1;G=(w|0)>0;H=v;while(1){if((l|0)==1){v=c[A>>2]|0;I=c[B>>2]|0;J=H+1|0;do{if(J>>>0>E>>>0){K=J;do{K=((K|0)>0?F:0)-K|0;}while(K>>>0>E>>>0);L=ca(K,z)|0;M=c[q>>2]|0;N=c[M+(L<<2)>>2]|0;L=J;do{L=((L|0)>0?F:0)-L|0;}while(L>>>0>E>>>0);K=ca(L,z)|0;if((N|0)==0){O=K;P=M;Q=51;break}R=c[M+(K<<2)>>2]|0}else{K=ca(J,z)|0;S=c[q>>2]|0;T=c[S+(K<<2)>>2]|0;if((T|0)==0){O=K;P=S;Q=51}else{R=T}}}while(0);do{if((Q|0)==51){Q=0;T=c[r>>2]|0;if(!((T|0)>-1)){Q=52;break a}S=P+(O<<2)|0;K=c[S>>2]|0;if((K|0)!=0){R=K;break}K=c[(c[s>>2]|0)+(T<<2)>>2]|0;c[r>>2]=T-1;c[S>>2]=K;R=K}}while(0);K=H+2|0;do{if(K>>>0>E>>>0){S=K;do{S=((S|0)>0?F:0)-S|0;}while(S>>>0>E>>>0);M=ca(S,z)|0;N=c[q>>2]|0;L=c[N+(M<<2)>>2]|0;M=K;do{M=((M|0)>0?F:0)-M|0;}while(M>>>0>E>>>0);S=ca(M,z)|0;if((L|0)==0){U=S;V=N;Q=62;break}W=c[N+(S<<2)>>2]|0}else{S=ca(K,z)|0;T=c[q>>2]|0;X=c[T+(S<<2)>>2]|0;if((X|0)==0){U=S;V=T;Q=62}else{W=X}}}while(0);do{if((Q|0)==62){Q=0;K=c[r>>2]|0;if(!((K|0)>-1)){Q=63;break a}X=V+(U<<2)|0;T=c[X>>2]|0;if((T|0)!=0){W=T;break}T=c[(c[s>>2]|0)+(K<<2)>>2]|0;c[r>>2]=K-1;c[X>>2]=T;W=T}}while(0);T=J>>>0<x>>>0;X=H>>>0<x>>>0;do{if(T&X){if(G){Y=0}else{break}do{K=I+(Y<<1)|0;S=R+(Y<<1)|0;Z=(e[S>>1]|0)-(((b[K>>1]|0)+2+(b[W+(Y<<1)>>1]|0)|0)>>>2)&65535;b[S>>1]=Z;b[K>>1]=(((Z<<16>>16)+(b[v+(Y<<1)>>1]|0)|0)>>>1)+(e[K>>1]|0);Y=Y+1|0;}while((Y|0)<(w|0))}else{if(T&G){N=0;do{L=R+(N<<1)|0;b[L>>1]=(e[L>>1]|0)-(((b[I+(N<<1)>>1]|0)+2+(b[W+(N<<1)>>1]|0)|0)>>>2);N=N+1|0;}while((N|0)<(w|0))}if(X&G){_=0}else{break}do{N=I+(_<<1)|0;b[N>>1]=(((b[R+(_<<1)>>1]|0)+(b[v+(_<<1)>>1]|0)|0)>>>1)+(e[N>>1]|0);_=_+1|0;}while((_|0)<(w|0))}}while(0);if((H-1|0)>>>0<x>>>0){t1a(v,g,w)}if(X){t1a(I,g,w)}c[A>>2]=R;c[B>>2]=W;T=(c[u>>2]|0)+2|0;c[u>>2]=T;$=T}else if((l|0)==0){T=c[A>>2]|0;J=c[B>>2]|0;N=c[C>>2]|0;L=c[D>>2]|0;M=H+3|0;do{if(M>>>0>E>>>0){K=M;do{K=((K|0)>0?F:0)-K|0;}while(K>>>0>E>>>0);Z=ca(K,z)|0;S=c[q>>2]|0;aa=c[S+(Z<<2)>>2]|0;Z=M;do{Z=((Z|0)>0?F:0)-Z|0;}while(Z>>>0>E>>>0);K=ca(Z,z)|0;if((aa|0)==0){ba=K;da=S;Q=14;break}ea=c[S+(K<<2)>>2]|0}else{K=ca(M,z)|0;fa=c[q>>2]|0;ga=c[fa+(K<<2)>>2]|0;if((ga|0)==0){ba=K;da=fa;Q=14}else{ea=ga}}}while(0);do{if((Q|0)==14){Q=0;I=c[r>>2]|0;if(!((I|0)>-1)){Q=15;break a}X=da+(ba<<2)|0;v=c[X>>2]|0;if((v|0)!=0){ea=v;break}v=c[(c[s>>2]|0)+(I<<2)>>2]|0;c[r>>2]=I-1;c[X>>2]=v;ea=v}}while(0);v=H+4|0;do{if(v>>>0>E>>>0){X=v;do{X=((X|0)>0?F:0)-X|0;}while(X>>>0>E>>>0);S=ca(X,z)|0;aa=c[q>>2]|0;Z=c[aa+(S<<2)>>2]|0;S=v;do{S=((S|0)>0?F:0)-S|0;}while(S>>>0>E>>>0);X=ca(S,z)|0;if((Z|0)==0){ha=X;ia=aa;Q=25;break}ja=c[aa+(X<<2)>>2]|0}else{X=ca(v,z)|0;I=c[q>>2]|0;ga=c[I+(X<<2)>>2]|0;if((ga|0)==0){ha=X;ia=I;Q=25}else{ja=ga}}}while(0);do{if((Q|0)==25){Q=0;ga=c[r>>2]|0;if(!((ga|0)>-1)){Q=26;break a}I=ia+(ha<<2)|0;X=c[I>>2]|0;if((X|0)!=0){ja=X;break}X=c[(c[s>>2]|0)+(ga<<2)>>2]|0;c[r>>2]=ga-1;c[I>>2]=X;ja=X}}while(0);do{if((H|0)>0&(v|0)<(x|0)){Se[c[f>>2]&1023](T,J,N,L,ea,ja,w)}else{if(M>>>0<x>>>0&G){X=0;do{I=ea+(X<<1)|0;b[I>>1]=(e[I>>1]|0)-(((((b[ja+(X<<1)>>1]|0)+(b[L+(X<<1)>>1]|0)|0)*3|0)+4|0)>>>3);X=X+1|0;}while((X|0)<(w|0))}if((H+2|0)>>>0<x>>>0&G){X=0;do{aa=L+(X<<1)|0;b[aa>>1]=(b[aa>>1]|0)-((b[ea+(X<<1)>>1]|0)+(b[N+(X<<1)>>1]|0)&65535);X=X+1|0;}while((X|0)<(w|0))}if((H+1|0)>>>0<x>>>0&G){X=0;do{aa=N+(X<<1)|0;Z=b[aa>>1]|0;b[aa>>1]=(((b[J+(X<<1)>>1]|0)+8+(b[L+(X<<1)>>1]|0)+(Z<<2)|0)>>>4)+Z;X=X+1|0;}while((X|0)<(w|0))}if(H>>>0<x>>>0&G){ka=0}else{break}do{X=J+(ka<<1)|0;b[X>>1]=((((b[N+(ka<<1)>>1]|0)+(b[T+(ka<<1)>>1]|0)|0)*3|0)>>>1)+(e[X>>1]|0);ka=ka+1|0;}while((ka|0)<(w|0))}}while(0);if((H-1|0)>>>0<x>>>0){ef[c[t>>2]&4095](T,g,w)}if(H>>>0<x>>>0){ef[c[t>>2]&4095](J,g,w)}c[A>>2]=N;c[B>>2]=L;c[C>>2]=ea;c[D>>2]=ja;M=(c[u>>2]|0)+2|0;c[u>>2]=M;$=M}else{$=H}if(($|0)>(y|0)){break}else{H=$}}}if((m|0)>0){a=m}else{Q=79;break}}if((Q|0)==15){KIb(0,0,2474152,(la=i,i=i+24|0,c[la>>2]=2595440,c[la+8>>2]=2446408,c[la+16>>2]=66,la)|0);i=la;Hd()}else if((Q|0)==26){KIb(0,0,2474152,(la=i,i=i+24|0,c[la>>2]=2595440,c[la+8>>2]=2446408,c[la+16>>2]=66,la)|0);i=la;Hd()}else if((Q|0)==52){KIb(0,0,2474152,(la=i,i=i+24|0,c[la>>2]=2595440,c[la+8>>2]=2446408,c[la+16>>2]=66,la)|0);i=la;Hd()}else if((Q|0)==63){KIb(0,0,2474152,(la=i,i=i+24|0,c[la>>2]=2595440,c[la+8>>2]=2446408,c[la+16>>2]=66,la)|0);i=la;Hd()}else if((Q|0)==79){i=o;return}}function j1a(a,d,f,g,h,j,k){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;l=i;i=i+160|0;m=l|0;n=(k|0)>0;if(n){o=k;do{o=o-1|0;if((j|0)==1){p=g>>o;q=h<<o;r=p-1|0;if(r>>>0<4294967294>>>0){s=r<<1;t=-2;while(1){u=((t|0)>0?s:0)-t|0;if(u>>>0>r>>>0){t=u}else{v=u;break}}}else{v=-2}c[m+(o*20|0)>>2]=a+((ca(v,q)|0)<<1);if((p|0)==0){w=-1}else{t=r<<1;s=-1;while(1){u=((s|0)>0?t:0)-s|0;if(u>>>0>r>>>0){s=u}else{w=u;break}}}c[m+(o*20|0)+4>>2]=a+((ca(w,q)|0)<<1);c[m+(o*20|0)+16>>2]=-1}else if((j|0)==0){s=g>>o;r=h<<o;t=s-1|0;if(t>>>0<4294967292>>>0){p=t<<1;u=-4;while(1){x=((u|0)>0?p:0)-u|0;if(x>>>0>t>>>0){u=x}else{y=x;break}}}else{y=-4}c[m+(o*20|0)>>2]=a+((ca(y,r)|0)<<1);if(t>>>0<4294967293>>>0){u=t<<1;p=-3;while(1){q=((p|0)>0?u:0)-p|0;if(q>>>0>t>>>0){p=q}else{z=q;break}}}else{z=-3}c[m+(o*20|0)+4>>2]=a+((ca(z,r)|0)<<1);if(t>>>0<4294967294>>>0){p=t<<1;u=-2;while(1){q=((u|0)>0?p:0)-u|0;if(q>>>0>t>>>0){u=q}else{A=q;break}}}else{A=-2}c[m+(o*20|0)+8>>2]=a+((ca(A,r)|0)<<1);if((s|0)==0){B=-1}else{u=t<<1;p=-1;while(1){q=((p|0)>0?u:0)-p|0;if(q>>>0>t>>>0){p=q}else{B=q;break}}}c[m+(o*20|0)+12>>2]=a+((ca(B,r)|0)<<1);c[m+(o*20|0)+16>>2]=-3}}while((o|0)>0)}if((g|0)<=0){i=l;return}o=(j|0)==1?3:5;B=(j|0)!=2&n;n=0;do{if(B){A=k;do{A=A-1|0;z=m+(A*20|0)+16|0;y=c[z>>2]|0;w=(n>>A)+o|0;v=g>>A;p=(w|0)>(v|0)?v:w;if((y|0)<=(p|0)){w=f>>A;t=h<<A;u=m+(A*20|0)|0;s=m+(A*20|0)+4|0;q=m+(A*20|0)+8|0;x=m+(A*20|0)+12|0;C=v-1|0;D=C<<1;E=(w|0)>0;F=y;while(1){if((j|0)==1){y=c[u>>2]|0;G=c[s>>2]|0;H=F+1|0;if(H>>>0>C>>>0){I=H;while(1){J=((I|0)>0?D:0)-I|0;if(J>>>0>C>>>0){I=J}else{K=J;break}}}else{K=H}I=ca(K,t)|0;J=a+(I<<1)|0;L=F+2|0;if(L>>>0>C>>>0){M=L;while(1){N=((M|0)>0?D:0)-M|0;if(N>>>0>C>>>0){M=N}else{O=N;break}}}else{O=L}M=ca(O,t)|0;N=a+(M<<1)|0;if(H>>>0<v>>>0&E){P=0;do{Q=a+(P+I<<1)|0;b[Q>>1]=(e[Q>>1]|0)-(((b[G+(P<<1)>>1]|0)+2+(b[a+(P+M<<1)>>1]|0)|0)>>>2);P=P+1|0;}while((P|0)<(w|0))}P=F>>>0<v>>>0;if(P&E){M=0;do{H=G+(M<<1)|0;b[H>>1]=(((b[a+(M+I<<1)>>1]|0)+(b[y+(M<<1)>>1]|0)|0)>>>1)+(e[H>>1]|0);M=M+1|0;}while((M|0)<(w|0))}if((F-1|0)>>>0<v>>>0){t1a(y,d,w)}if(P){t1a(G,d,w)}c[u>>2]=J;c[s>>2]=N;c[z>>2]=L;R=L}else if((j|0)==0){M=c[u>>2]|0;I=c[s>>2]|0;H=c[q>>2]|0;Q=c[x>>2]|0;S=F+3|0;if(S>>>0>C>>>0){T=S;while(1){U=((T|0)>0?D:0)-T|0;if(U>>>0>C>>>0){T=U}else{V=U;break}}}else{V=S}T=ca(V,t)|0;L=a+(T<<1)|0;N=F+4|0;if(N>>>0>C>>>0){J=N;while(1){G=((J|0)>0?D:0)-J|0;if(G>>>0>C>>>0){J=G}else{W=G;break}}}else{W=N}J=ca(W,t)|0;G=a+(J<<1)|0;if(S>>>0<v>>>0&E){P=0;do{y=a+(P+T<<1)|0;b[y>>1]=(e[y>>1]|0)-(((((b[a+(P+J<<1)>>1]|0)+(b[Q+(P<<1)>>1]|0)|0)*3|0)+4|0)>>>3);P=P+1|0;}while((P|0)<(w|0))}P=F+2|0;if(P>>>0<v>>>0&E){J=0;do{S=Q+(J<<1)|0;b[S>>1]=(b[S>>1]|0)-((b[a+(J+T<<1)>>1]|0)+(b[H+(J<<1)>>1]|0)&65535);J=J+1|0;}while((J|0)<(w|0))}if((F+1|0)>>>0<v>>>0&E){J=0;do{T=H+(J<<1)|0;S=b[T>>1]|0;b[T>>1]=(((b[I+(J<<1)>>1]|0)+8+(b[Q+(J<<1)>>1]|0)+(S<<2)|0)>>>4)+S;J=J+1|0;}while((J|0)<(w|0))}J=F>>>0<v>>>0;if(J&E){S=0;do{T=I+(S<<1)|0;b[T>>1]=((((b[H+(S<<1)>>1]|0)+(b[M+(S<<1)>>1]|0)|0)*3|0)>>>1)+(e[T>>1]|0);S=S+1|0;}while((S|0)<(w|0))}if((F-1|0)>>>0<v>>>0){f1a(M,d,w)}if(J){f1a(I,d,w)}c[u>>2]=H;c[s>>2]=Q;c[q>>2]=L;c[x>>2]=G;c[z>>2]=P;R=P}else{R=F}if((R|0)>(p|0)){break}else{F=R}}}}while((A|0)>0)}n=n+4|0;}while((n|0)<(g|0));i=l;return}function k1a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return l1a(b,c,d,32,e,1)|0}function l1a(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;i=i+4224|0;k=j|0;l=j+4096|0;m=(f|0)==8?3:4;if((g|0)>0){n=(f|0)>0;o=0;p=b;b=a;while(1){if(n){a=o<<5;q=0;do{r=q+a|0;c[k+(r<<2)>>2]=(d[b+q|0]|0)-(d[p+q|0]|0)<<4;s=q|1;c[k+((r|1)<<2)>>2]=(d[b+s|0]|0)-(d[p+s|0]|0)<<4;s=q|2;c[k+((r|2)<<2)>>2]=(d[b+s|0]|0)-(d[p+s|0]|0)<<4;s=q|3;c[k+((r|3)<<2)>>2]=(d[b+s|0]|0)-(d[p+s|0]|0)<<4;q=q+4|0;}while((q|0)<(f|0))}q=o+1|0;if((q|0)<(g|0)){o=q;p=p+e|0;b=b+e|0}else{break}}}e1a(k|0,l|0,f,g,32,h,m);g=m-3|0;l=0;e=0;while(1){b=m-l|0;p=f>>b;o=32<<b;b=o>>1;n=(p|0)>0;q=(l|0)!=0|0;a=e;while(1){if(n){s=((q&1|0)!=0?p:0)+((q&2|0)==0?0:b)|0;r=156680+(h<<7)+(g<<6)+(l<<4)+(q<<2)|0;t=0;u=a;while(1){v=s+(ca(t,o)|0)|0;w=c[r>>2]|0;x=0;y=u;do{z=ca(w,c[k+(v+x<<2)>>2]|0)|0;y=((z|0)>-1?z:-z|0)+y|0;x=x+1|0;}while((x|0)<(p|0));x=t+1|0;if((x|0)<(p|0)){t=x;u=y}else{A=y;break}}}else{A=a}u=q+1|0;if((u|0)<4){q=u;a=A}else{break}}a=l+1|0;if((a|0)<(m|0)){l=a;e=A}else{break}}i=j;return A>>9|0}function m1a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return l1a(b,c,d,32,e,0)|0}function n1a(a){a=a|0;c[a+292>>2]=204;c[a+296>>2]=196;c[a+316>>2]=246;c[a+320>>2]=154;return}function o1a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return l1a(b,c,d,16,e,1)|0}function p1a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return l1a(b,c,d,8,e,1)|0}function q1a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return l1a(b,c,d,16,e,0)|0}function r1a(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return l1a(b,c,d,8,e,0)|0}function s1a(a){a=a|0;c[a>>2]=208;c[a+4>>2]=1058;c[a+8>>2]=24;return}function t1a(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d>>1;g=d+1>>1;if((f|0)>0){h=0;while(1){i=h<<1;b[c+(i<<1)>>1]=b[a+(h<<1)>>1]|0;b[c+((i|1)<<1)>>1]=b[a+(h+g<<1)>>1]|0;i=h+1|0;if((i|0)<(f|0)){h=i}else{j=f;break}}}else{j=0}f=(d&1|0)!=0;if(f){b[c+(j<<1<<1)>>1]=b[a+(j<<1)>>1]|0}j=(e[c>>1]|0)-(((b[c+2>>1]|0)+1|0)>>>1)&65535;b[a>>1]=j;h=d-1|0;if((h|0)>2){d=2;g=j;while(1){i=d-1|0;k=c+(i<<1)|0;l=(e[c+(d<<1)>>1]|0)-(((b[k>>1]|0)+2+(b[c+((d|1)<<1)>>1]|0)|0)>>>2)&65535;b[a+(d<<1)>>1]=l;b[a+(i<<1)>>1]=(((g<<16>>16)+1+(l<<16>>16)|0)>>>1)+(e[k>>1]|0);k=d+2|0;if((k|0)<(h|0)){d=k;g=l}else{m=k;n=l;break}}}else{m=2;n=j}if(f){f=m-1|0;j=c+(f<<1)|0;g=(e[c+(m<<1)>>1]|0)-(((b[j>>1]|0)+1|0)>>>1)&65535;b[a+(m<<1)>>1]=g;b[a+(f<<1)>>1]=(((n<<16>>16)+1+(g<<16>>16)|0)>>>1)+(e[j>>1]|0);return}else{j=m-1|0;b[a+(j<<1)>>1]=n+(b[c+(j<<1)>>1]|0);return}}function u1a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=d>>1;f=d+1>>1;if((e|0)>0){g=0;while(1){h=g<<1;c[b+(g<<2)>>2]=c[a+(h<<2)>>2];c[b+(g+f<<2)>>2]=c[a+((h|1)<<2)>>2];h=g+1|0;if((h|0)<(e|0)){g=h}else{i=e;break}}}else{i=0}g=d&1;d=(g|0)==0;if(!d){c[b+(i<<2)>>2]=c[a+(i<<1<<2)>>2]}i=a+(f<<2)|0;h=e-1|0;j=h+g|0;if((j|0)>0){g=0;while(1){k=g+f|0;l=g+1|0;c[a+(k<<2)>>2]=(-((c[b+(l<<2)>>2]|0)+(c[b+(g<<2)>>2]|0)|0)>>1)+(c[b+(k<<2)>>2]|0);if((l|0)<(j|0)){g=l}else{break}}}if(d){g=j+f|0;c[a+(g<<2)>>2]=(((c[b+(j<<2)>>2]|0)*-2|0)>>1)+(c[b+(g<<2)>>2]|0)}c[a>>2]=((c[i>>2]<<1)+2>>2)+(c[b>>2]|0);if((h|0)>0){i=0;while(1){g=i+1|0;c[a+(g<<2)>>2]=((c[a+(i+f<<2)>>2]|0)+2+(c[a+(g+f<<2)>>2]|0)>>2)+(c[b+(g<<2)>>2]|0);if((g|0)<(h|0)){i=g}else{break}}}if(d){return}c[a+(e<<2)>>2]=((c[a+(f+h<<2)>>2]<<1)+2>>2)+(c[b+(e<<2)>>2]|0);return}function v1a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=d+1>>1;f=b+(e<<2)|0;g=d&1;h=d>>1;d=h-1|0;i=d+g|0;j=(i|0)>0;if(j){k=0;while(1){l=k<<1;m=k+1|0;c[b+(k+e<<2)>>2]=(c[a+((l|1)<<2)>>2]|0)-((((c[a+(m<<1<<2)>>2]|0)+(c[a+(l<<2)>>2]|0)|0)*3|0)>>1);if((m|0)<(i|0)){k=m}else{break}}}k=(g|0)!=0;if(!k){m=i<<1;c[b+(i+e<<2)>>2]=(c[a+((m|1)<<2)>>2]|0)-(((c[a+(m<<2)>>2]|0)*6|0)>>1)}c[b>>2]=8388608-(((c[f>>2]<<1)+167772171+((c[a>>2]|0)*-16|0)|0)/20|0);f=(d|0)>0;if(f){m=0;while(1){l=m+1|0;c[b+(l<<2)>>2]=8388608-(((c[b+(l+e<<2)>>2]|0)+167772171+(c[b+(m+e<<2)>>2]|0)+((c[a+((m<<1)+2<<2)>>2]|0)*-16|0)|0)/20|0);if((l|0)<(d|0)){m=l}else{break}}}m=(g|0)==0;if(!m){c[b+(h<<2)>>2]=8388608-(((c[b+(e+d<<2)>>2]<<1)+167772171+((c[a+((d<<1)+2<<2)>>2]|0)*-16|0)|0)/20|0)}g=a+(e<<2)|0;if(j){j=0;while(1){l=j+e|0;n=j+1|0;c[a+(l<<2)>>2]=(c[b+(j<<2)>>2]|0)+(c[b+(l<<2)>>2]|0)+(c[b+(n<<2)>>2]|0);if((n|0)<(i|0)){j=n}else{break}}}if(!k){k=i+e|0;c[a+(k<<2)>>2]=(c[b+(i<<2)>>2]<<1)+(c[b+(k<<2)>>2]|0)}c[a>>2]=(((c[g>>2]|0)*6|0)+4>>3)+(c[b>>2]|0);if(f){f=0;while(1){g=f+1|0;c[a+(g<<2)>>2]=((((c[a+(g+e<<2)>>2]|0)+(c[a+(f+e<<2)>>2]|0)|0)*3|0)+4>>3)+(c[b+(g<<2)>>2]|0);if((g|0)<(d|0)){f=g}else{break}}}if(m){return}c[a+(h<<2)>>2]=(((c[a+(e+d<<2)>>2]|0)*6|0)+4>>3)+(c[b+(h<<2)>>2]|0);return}function w1a(a){a=a|0;var b=0,d=0;b=ytb(a)|0;if((b|0)>=0){d=0;return d|0}Ktb(c[a+60>>2]|0);d=b;return d|0}



function thb(f,h,j){f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0.0,sb=0.0,tb=0.0,ub=0.0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0.0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0;k=i;i=i+136|0;l=k|0;m=k+16|0;n=k+24|0;o=k+88|0;p=k+104|0;q=f|0;r=c[q>>2]|0;s=f+68588|0;t=f+66180|0;if((a[t]|0)==0){u=0}else{v=e[f+66186>>1]|0;w=f+68596|0;x=c[w>>2]|0;y=c[f+68604>>2]|0;z=(c[s>>2]|0)+(x>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>((32-v|0)>>>0);z=x+v|0;c[w>>2]=y>>>0>z>>>0?z:y;u=A}mrc(l|0,0,16)|0;A=r+416|0;y=c[A>>2]|0;if((y|0)>0){z=0;while(1){a[f+71200+(z*49568|0)+3|0]=0;w=z+1|0;v=c[q>>2]|0;if((w|0)<(c[v+416>>2]|0)){z=w}else{B=v;break}}}else{B=r}z=f+68596|0;if((a[f+66189|0]|0)==1){C=f+68588|0;D=f+68604|0;E=8}else{v=c[z>>2]|0;w=f+68588|0;x=d[(c[w>>2]|0)+(v>>>3)|0]|0;F=f+68604|0;c[z>>2]=((v|0)<(c[F>>2]|0))+v;if((x&128>>>((v&7)>>>0)|0)==0){G=0;H=w;I=F;J=w}else{C=w;D=F;E=8}}if((E|0)==8){G=1;H=C;I=D;J=f+68588|0}D=f+66184|0;C=f+66192|0;F=f+68600|0;w=f+66191|0;v=f+66190|0;x=y;y=0;K=B;L=c[B+416>>2]|0;M=B;a:while(1){B=K+416|0;b:do{if((L|0)>0){if(G|(x|0)==1){N=0;while(1){a[m+N|0]=(e[l+(N<<1)>>1]|0)==(y|0)|0;N=N+1|0;if((N|0)>=(c[B>>2]|0)){break b}}}else{O=0}do{do{if((e[l+(O<<1)>>1]|0)==(y|0)){if((y|0)==((e[D>>1]|0)-(e[C>>1]|0)|0)){a[m+O|0]=1;break}else{N=c[z>>2]|0;P=d[(c[H>>2]|0)+(N>>>3)|0]<<(N&7)>>>7;c[z>>2]=((N|0)<(c[I>>2]|0))+N;a[m+O|0]=P&1;break}}else{a[m+O|0]=0}}while(0);O=O+1|0;}while((O|0)<(c[B>>2]|0))}}while(0);P=b[D>>1]|0;N=P&65535;Q=e[C>>1]|0;if((N-Q|0)==(y|0)){R=Q}else{S=c[z>>2]|0;if(((c[F>>2]|0)-S|0)<1){break}do{if((a[w]|0)==0){U=d[v]|0;V=c[I>>2]|0;W=(c[J>>2]|0)+(S>>>3)|0;X=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(S&7)>>>((32-U|0)>>>0);W=U+S|0;c[z>>2]=V>>>0>W>>>0?W:V;Y=X}else{X=c[J>>2]|0;V=d[X+(S>>>3)|0]|0;W=c[I>>2]|0;U=((S|0)<(W|0))+S|0;c[z>>2]=U;if((V&128>>>((S&7)>>>0)|0)==0){Y=0;break}V=d[v]|0;Z=X+(U>>>3)|0;X=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(U&7)>>>((33-V|0)>>>0);Z=U-1+V|0;c[z>>2]=W>>>0>Z>>>0?Z:W;Y=X+1|0}}while(0);_=N>>>(Y>>>0);if((_|0)<(Q|0)|(_|0)>(N|0)){E=26;break}else{R=_}}if((R|0)<1){break}S=R+y|0;X=c[B>>2]|0;if((X|0)>0){W=R&65535;Z=S;V=0;U=x;$=K;aa=P;ba=M;while(1){do{if((a[m+V|0]|0)==0){da=e[l+(V<<1)>>1]|0;if((da|0)>(Z|0)){ea=U;fa=Z;ga=aa;ha=$;ia=ba;break}ja=(da|0)<(Z|0);ea=ja?1:U+1|0;fa=ja?da:Z;ga=aa;ha=$;ia=ba}else{da=f+71200+(V*49568|0)+3|0;ja=a[da]|0;if((ja&255)>>>0>31>>>0){E=32;break a}b[f+71200+(V*49568|0)+4+((ja&255)<<1)>>1]=W;ja=l+(V<<1)|0;ka=(e[ja>>1]|0)+R&65535;b[ja>>1]=ka;a[da]=(a[da]|0)+1;da=b[D>>1]|0;la=c[q>>2]|0;if((ka&65535)>>>0>(da&65535)>>>0){E=34;break a}else{ea=U;fa=Z;ga=da;ha=la;ia=la}}}while(0);da=V+1|0;ka=c[ha+416>>2]|0;if((da|0)<(ka|0)){Z=fa;V=da;U=ea;$=ha;aa=ga;ba=ia}else{ma=fa;na=ea;oa=ha;pa=ga;qa=ka;ra=ia;break}}}else{ma=S;na=x;oa=K;pa=P;qa=X;ra=M}if((ma|0)<(pa&65535|0)){x=na;y=ma;K=oa;L=qa;M=ra}else{E=39;break}}if((E|0)==26){KIb(K,16,2466912,(sa=i,i=i+8|0,c[sa>>2]=_,sa)|0);i=sa}else if((E|0)==32){KIb($,16,2487400,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==34){KIb(la,16,2476096,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==39){if((qa|0)>0){qa=0;la=oa;oa=ra;while(1){$=f+71200+(qa*49568|0)+3|0;if((a[$]|0)==0){ta=la;ua=oa}else{_=0;K=0;do{b[f+71200+(qa*49568|0)+68+(_<<1)>>1]=K;K=(e[f+71200+(qa*49568|0)+4+(_<<1)>>1]|0)+K|0;_=_+1|0;}while((_|0)<(d[$]|0));$=c[q>>2]|0;ta=$;ua=$}$=qa+1|0;if(($|0)<(c[ta+416>>2]|0)){qa=$;la=ta;oa=ua}else{va=ua;break}}}else{va=ra}do{if((c[va+416>>2]|0)>1){ra=c[z>>2]|0;ua=c[s>>2]|0;oa=d[ua+(ra>>>3)|0]|0;ta=c[f+68604>>2]|0;la=((ra|0)<(ta|0))+ra|0;c[z>>2]=la;if((oa&128>>>((ra&7)>>>0)|0)==0){break}ra=d[ua+(la>>>3)|0]|0;ua=((la|0)<(ta|0))+la|0;c[z>>2]=ua;if((ra&128>>>((la&7)>>>0)|0)==0){break}la=c[A>>2]|0;if((ca(la,la)|0)==0){break}else{wa=0;xa=ua}do{ua=xa+4|0;xa=ta>>>0>ua>>>0?ua:ta;c[z>>2]=xa;wa=wa+1|0;ua=c[A>>2]|0;}while((wa|0)<(ca(ua,ua)|0))}}while(0);wa=c[z>>2]|0;if((a[f+66181|0]|0)==0){ya=wa;za=c[s>>2]|0;Aa=c[f+68604>>2]|0}else{xa=c[f+68604>>2]|0;ta=c[s>>2]|0;ua=ta+(wa>>>3)|0;la=(je(d[ua]|d[ua+1|0]<<8|d[ua+2|0]<<16|d[ua+3|0]<<24|0)|0)<<(wa&7)>>>24;ua=wa+8|0;wa=xa>>>0>ua>>>0?ua:xa;c[z>>2]=wa;a[f+68612|0]=la;ya=wa;za=ta;Aa=xa}xa=s|0;ta=d[za+(ya>>>3)|0]|0;wa=f+68604|0;la=((ya|0)<(Aa|0))+ya|0;c[z>>2]=la;do{if((ta&128>>>((ya&7)>>>0)|0)==0){Ba=la}else{ua=d[za+(la>>>3)|0]|0;ra=((la|0)<(Aa|0))+la|0;c[z>>2]=ra;if((ua&128>>>((la&7)>>>0)|0)==0){Ca=ra}else{ua=e[D>>1]|0;oa=ua<<1;qa=oa>>>0>65535>>>0;$=qa?ua>>>15:oa;oa=qa?16:0;if(($&65280|0)==0){Da=oa;Ea=$}else{Da=oa|8;Ea=$>>>8}$=(d[1359664+Ea|0]|0)+Da+ra|0;ra=Aa>>>0>$>>>0?$:Aa;c[z>>2]=ra;Ca=ra}ra=d[za+(Ca>>>3)|0]|0;$=((Ca|0)<(Aa|0))+Ca|0;c[z>>2]=$;if((ra&128>>>((Ca&7)>>>0)|0)==0){Ba=$;break}ra=e[D>>1]|0;oa=ra<<1;qa=oa>>>0>65535>>>0;ua=qa?ra>>>15:oa;oa=qa?16:0;if((ua&65280|0)==0){Fa=oa;Ga=ua}else{Fa=oa|8;Ga=ua>>>8}ua=(d[1359664+Ga|0]|0)+Fa+$|0;$=Aa>>>0>ua>>>0?ua:Aa;c[z>>2]=$;Ba=$}}while(0);Aa=f+68614|0;a[Aa]=0;if((c[A>>2]|0)>0){Fa=0;do{b[f+71200+(Fa*49568|0)+134>>1]=0;a[f+71200+(Fa*49568|0)+132|0]=0;a[f+71200+(Fa*49568|0)+144|0]=0;Fa=Fa+1|0;}while((Fa|0)<(c[A>>2]|0));Fa=e[D>>1]|0;if((a[Aa]|0)==0){Ha=Fa;E=65}else{Ia=Fa}}else{Ha=e[D>>1]|0;E=65}c:do{if((E|0)==65){Fa=f+68576|0;Ga=f+68618|0;Ca=f+68636|0;za=f+68627|0;Da=f+68632|0;Ea=f+68616|0;la=f+68637|0;ya=f+68638|0;ta=f+66182|0;$=f+68628|0;ua=f+68619|0;oa=f+68568|0;qa=o|0;ra=o+4|0;_=o+8|0;K=o+12|0;X=f+66188|0;P=f+33376|0;S=f+12|0;M=p|0;L=p+4|0;ma=~p;y=f+20|0;na=Ha;x=va;pa=Ba;d:while(1){ia=x+416|0;ga=ca(c[ia>>2]|0,na)|0;c[Fa>>2]=pa;if((c[ia>>2]|0)>0){ha=0;ea=na;fa=na;while(1){a[f+71200+(ha*49568|0)+136|0]=0;R=e[f+71200+(ha*49568|0)+134>>1]|0;if((fa|0)>(R|0)){Ja=R;Ka=e[f+71200+(ha*49568|0)+4+(d[f+71200+(ha*49568|0)+132|0]<<1)>>1]|0}else{Ja=fa;Ka=ea}R=ha+1|0;if((R|0)<(c[ia>>2]|0)){ha=R;ea=Ka;fa=Ja}else{La=Ka;Ma=Ja;break}}}else{La=na;Ma=na}a[Ga]=0;if((c[ia>>2]|0)>0){fa=ga;ea=0;ha=0;R=x;while(1){l=f+71200+(ea*49568|0)+134|0;m=b[l>>1]|0;Y=m&65535;v=fa-Y|0;do{if((Ma|0)==(Y|0)){I=b[f+71200+(ea*49568|0)+4+(d[f+71200+(ea*49568|0)+132|0]<<1)>>1]|0;if((La|0)!=(I&65535|0)){Na=v;Oa=ha;Pa=R;break}b[l>>1]=I+m;a[(ha<<24>>24)+(f+68619)|0]=ea;I=(a[Ga]|0)+1&255;a[Ga]=I;Na=v-La|0;Oa=I;Pa=c[q>>2]|0}else{Na=v;Oa=ha;Pa=R}}while(0);v=ea+1|0;if((v|0)<(c[Pa+416>>2]|0)){fa=Na;ea=v;ha=Oa;R=Pa}else{Qa=Na;Ra=Oa;Sa=Pa;break}}}else{Qa=ga;Ra=0;Sa=x}if((Qa|0)==0){a[Aa]=1}R=e[D>>1]|0;ha=(R|0)/(La|0)|0;ea=ha>>>0>65535>>>0;fa=ea?ha>>>16:ha;ha=ea?16:0;if((fa&65280|0)==0){Ta=ha;Ua=fa}else{Ta=ha|8;Ua=fa>>>8}fa=(d[1359664+Ua|0]|0)+Ta|0;a[Ca]=fa;ha=fa&255;a[za]=a[f+66194+ha|0]|0;c[Da>>2]=f+66202+(ha*58|0);fa=b[f+68522+(ha<<1)>>1]|0;ha=(R>>>1)+Ma|0;R=Ra<<24>>24>0;if(R){ea=Ra<<24>>24;ia=0;do{v=a[f+68619+ia|0]|0;c[f+71200+(v*49568|0)+396>>2]=f+71200+(v*49568|0)+416+(ha<<2);ia=ia+1|0;}while((ia|0)<(ea|0))}ea=La&65535;b[Ea>>1]=ea;ia=(ea<<16>>16)-1|0;ea=ia>>>0>65535>>>0;ga=ea?ia>>>16:ia;ia=ea?16:0;if((ga&65280|0)==0){Va=ia;Wa=ga}else{Va=ia|8;Wa=ga>>>8}a[la]=Va+1+(d[1359664+Wa|0]|0);ga=c[z>>2]|0;ia=c[xa>>2]|0;ea=d[ia+(ga>>>3)|0]|0;v=c[wa>>2]|0;m=((ga|0)<(v|0))+ga|0;c[z>>2]=m;e:do{if((ea&128>>>((ga&7)>>>0)|0)==0){Xa=m}else{l=ia+(m>>>3)|0;Y=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(m&7)>>>30;l=m+2|0;I=v>>>0>l>>>0?l:v;c[z>>2]=I;do{if((Y|0)==0){l=ia+(I>>>3)|0;w=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(I&7)>>>28;l=I+4|0;F=v>>>0>l>>>0?l:v;c[z>>2]=F;if((w|0)==0){Ya=1;Za=F;break}l=ia+(F>>>3)|0;C=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(F&7)>>>((32-w|0)>>>0);l=w+F|0;F=v>>>0>l>>>0?l:v;c[z>>2]=F;l=C+1|0;if((l|0)>-1){Ya=l;Za=F}else{Xa=F;break e}}else{Ya=Y;Za=I}}while(0);if((Ya+Za|0)>(c[oa>>2]|0)){E=90;break d}I=-Za|0;Y=v-Za|0;if((Ya|0)<(I|0)){_a=I}else{_a=(Y|0)<(Ya|0)?Y:Ya}Y=_a+Za|0;c[z>>2]=Y;Xa=Y}}while(0);m=d[ia+(Xa>>>3)|0]|0;ga=((Xa|0)<(v|0))+Xa|0;c[z>>2]=ga;if((m&128>>>((Xa&7)>>>0)|0)!=0){E=95;break}a[ya]=0;f:do{if((c[Sa+416>>2]|0)>1){m=d[ia+(ga>>>3)|0]|0;c[z>>2]=((ga|0)<(v|0))+ga;if((m&128>>>((ga&7)>>>0)|0)!=0){E=98;break d}a[ya]=0;if(Ra<<24>>24==0|R^1){$a=0;ab=Ra;bb=Ra<<24>>24>0;break}m=Ra;ea=Ra<<24>>24;Y=0;while(1){I=f+68640+(Y*320|0)+288|0;F=f+68640+(Y*320|0)|0;a[F]=0;l=f+68640+(Y*320|0)+1|0;a[l]=0;do{if((ea|0)>2){if(m<<24>>24>0){cb=I;db=0;eb=m}else{E=115;break}while(1){C=a[f+68619+db|0]|0;w=f+71200+(C*49568|0)+136|0;do{if((a[w]|0)==0){O=c[z>>2]|0;H=d[(c[J>>2]|0)+(O>>>3)|0]|0;c[z>>2]=((O|0)<(c[wa>>2]|0))+O;if((H&128>>>((O&7)>>>0)|0)==0){fb=cb;gb=eb;break}a[F]=(a[F]|0)+1;a[w]=1;c[cb>>2]=c[f+71200+(C*49568|0)+396>>2];fb=cb+4|0;gb=a[Ga]|0}else{fb=cb;gb=eb}}while(0);C=db+1|0;if((C|0)<(gb<<24>>24|0)){cb=fb;db=C;eb=gb}else{E=115;break}}}else{C=ea&255;a[F]=C;if(m<<24>>24>0){hb=I;ib=0;jb=m}else{kb=C;break}while(1){C=a[f+68619+ib|0]|0;w=f+71200+(C*49568|0)+136|0;if((a[w]|0)==0){c[hb>>2]=c[f+71200+(C*49568|0)+396>>2];lb=hb+4|0;mb=a[Ga]|0}else{lb=hb;mb=jb}a[w]=1;w=ib+1|0;if((w|0)<(mb<<24>>24|0)){hb=lb;ib=w;jb=mb}else{E=115;break}}}}while(0);if((E|0)==115){E=0;kb=a[F]|0}do{if(kb<<24>>24==2){I=c[z>>2]|0;w=c[J>>2]|0;C=d[w+(I>>>3)|0]|0;O=c[wa>>2]|0;H=((I|0)<(O|0))+I|0;c[z>>2]=H;if((C&128>>>((I&7)>>>0)|0)!=0){I=d[w+(H>>>3)|0]|0;c[z>>2]=((H|0)<(O|0))+H;if((I&128>>>((H&7)>>>0)|0)==0){break}else{E=119;break d}}a[l]=1;H=f+68640+(Y*320|0)+32|0;if((c[(c[q>>2]|0)+416>>2]|0)==2){g[H>>2]=1.0;g[f+68640+(Y*320|0)+36>>2]=-1.0;g[f+68640+(Y*320|0)+40>>2]=1.0;g[f+68640+(Y*320|0)+44>>2]=1.0;break}else{g[H>>2]=.70703125;g[f+68640+(Y*320|0)+36>>2]=-.70703125;g[f+68640+(Y*320|0)+40>>2]=.70703125;g[f+68640+(Y*320|0)+44>>2]=.70703125;break}}else{if(!((kb&255)>>>0>2>>>0)){break}H=c[z>>2]|0;I=c[J>>2]|0;O=d[I+(H>>>3)|0]|0;w=c[wa>>2]|0;C=((H|0)<(w|0))+H|0;c[z>>2]=C;if((O&128>>>((H&7)>>>0)|0)==0){break}a[l]=1;H=d[I+(C>>>3)|0]|0;c[z>>2]=((C|0)<(w|0))+C;if((H&128>>>((C&7)>>>0)|0)==0){C=kb&255;if((kb&255)>>>0>6>>>0){QIb(c[q>>2]|0,2500048,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa;break}else{nrc(f+68640+(Y*320|0)+32|0,c[1577008+(C<<2)>>2]|0,ca(C<<2,C)|0)|0;break}}C=c[(c[q>>2]|0)+416>>2]|0;mrc(f+68640+(Y*320|0)+32|0,0,ca(C<<2,C)|0)|0;C=kb&255;H=(ca(C-1|0,C)|0)>>1;if((H|0)>0){C=c[wa>>2]|0;w=c[J>>2]|0;I=0;O=c[z>>2]|0;do{G=w+(O>>>3)|0;ba=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(O&7)>>>26;G=O+6|0;O=C>>>0>G>>>0?G:C;c[z>>2]=O;a[n+I|0]=ba;I=I+1|0;}while((I|0)<(H|0))}if(kb<<24>>24==0){break}H=c[J>>2]|0;I=c[wa>>2]|0;O=0;C=c[z>>2]|0;w=kb;while(1){ba=d[H+(C>>>3)|0]|0;G=((C|0)<(I|0))+C|0;c[z>>2]=G;g[f+68640+(Y*320|0)+32+((ca(O,w&255)|0)+O<<2)>>2]=(ba&128>>>((C&7)>>>0)|0)!=0?1.0:-1.0;ba=O+1|0;nb=a[F]|0;if((ba|0)<(nb&255|0)){O=ba;C=G;w=nb}else{break}}if((nb&255)>>>0>1>>>0){ob=0;pb=1;qb=nb}else{break}while(1){w=pb+1|0;if((pb|0)>0&(w|0)>0){C=0;do{O=a[n+(C+ob)|0]|0;I=O<<24>>24;H=5120376+(32-I<<2)|0;G=5120376+(I-32<<2)|0;if(O<<24>>24<32){O=5120376+(I<<2)|0;ba=0;do{aa=d[F]|0;U=f+68640+(Y*320|0)+32+((ca(aa,C)|0)+ba<<2)|0;rb=+g[U>>2];sb=+g[f+68640+(Y*320|0)+32+((ca(aa,pb)|0)+ba<<2)>>2];tb=+g[H>>2];ub=+g[O>>2];g[U>>2]=rb*ub-sb*tb;g[f+68640+(Y*320|0)+32+((ca(d[F]|0,pb)|0)+ba<<2)>>2]=rb*tb+sb*ub;ba=ba+1|0;}while((ba|0)<(w|0))}else{ba=5120376+(64-I<<2)|0;O=0;do{H=d[F]|0;U=f+68640+(Y*320|0)+32+((ca(H,C)|0)+O<<2)|0;ub=+g[U>>2];sb=+g[f+68640+(Y*320|0)+32+((ca(H,pb)|0)+O<<2)>>2];tb=-0.0- +g[G>>2];rb=+g[ba>>2];g[U>>2]=ub*rb-sb*tb;g[f+68640+(Y*320|0)+32+((ca(d[F]|0,pb)|0)+O<<2)>>2]=ub*tb+sb*rb;O=O+1|0;}while((O|0)<(w|0))}C=C+1|0;}while((C|0)<(pb|0));vb=a[F]|0}else{vb=qb}if((w|0)<(vb&255|0)){ob=ob+pb|0;pb=w;qb=vb}else{break}}}}while(0);g:do{if((a[l]|0)!=0){C=c[z>>2]|0;O=c[J>>2]|0;ba=d[O+(C>>>3)|0]|0;G=c[wa>>2]|0;I=((C|0)<(G|0))+C|0;c[z>>2]=I;if((ba&128>>>((C&7)>>>0)|0)!=0){mrc(f+68640+(Y*320|0)+2|0,1,a[za]|0)|0;break}if((a[za]|0)>0){wb=0;xb=I;yb=O;zb=G}else{break}while(1){G=d[yb+(xb>>>3)|0]<<(xb&7)>>>7;c[z>>2]=((xb|0)<(zb|0))+xb;a[f+68640+(Y*320|0)+2+wb|0]=G&1;G=wb+1|0;if((G|0)>=(a[za]|0)){break g}wb=G;xb=c[z>>2]|0;yb=c[J>>2]|0;zb=c[wa>>2]|0}}}while(0);l=d[F]|0;G=(a[ya]|0)+1&255;a[ya]=G;if((ea|0)==(l|0)){break}O=a[Ga]|0;I=G&255;if((I|0)<(O<<24>>24|0)){m=O;ea=ea-l|0;Y=I}else{Ab=O;E=102;break f}}Ab=a[Ga]|0;E=102}else{Ab=Ra;E=102}}while(0);do{if((E|0)==102){E=0;if(!(Ab<<24>>24>0)){$a=0;ab=Ab;bb=0;break}R=c[xa>>2]|0;ga=c[wa>>2]|0;v=Ab<<24>>24;ia=0;Y=0;ea=c[z>>2]|0;while(1){m=a[f+68619+Y|0]|0;O=d[R+(ea>>>3)|0]<<(ea&7)>>>7;I=((ea|0)<(ga|0))+ea|0;c[z>>2]=I;l=O&1;a[f+71200+(m*49568|0)+2|0]=l;m=l<<24>>24==0?ia:1;l=Y+1|0;if((l|0)<(v|0)){ia=m;Y=l;ea=I}else{$a=m;ab=Ab;bb=1;break}}}}while(0);ea=b[Ea>>1]|0;if(!(ea<<16>>16<8193)){E=155;break}Y=($a|0)!=0;do{if(Y){ia=((d[ta]|0)*90|0)>>>4;v=c[z>>2]|0;ga=c[xa>>2]|0;R=d[ga+(v>>>3)|0]<<(v&7)>>>7;m=c[wa>>2]|0;I=((v|0)<(m|0))+v|0;c[z>>2]=I;v=R&1;a[$]=v;do{if(v<<24>>24==0){if(!bb){Bb=I;break}R=ab<<24>>24;l=0;while(1){b[f+71200+((a[f+68619+l|0]|0)*49568|0)+400>>1]=ea;O=l+1|0;if((O|0)<(R|0)){l=O}else{Bb=I;break}}}else{l=ea<<16>>16;R=(l+3|0)/4|0;F=R>>>0>65535>>>0;O=F?R>>>16:R;R=F?16:0;if((O&65280|0)==0){Cb=R;Db=O}else{Cb=R|8;Db=O>>>8}O=(d[1359664+Db|0]|0)+Cb|0;R=O+1|0;if(!bb){Bb=I;break}F=31-O|0;O=ab<<24>>24;G=0;C=I;while(1){ba=a[f+68619+G|0]|0;U=ga+(C>>>3)|0;H=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(C&7)>>>(F>>>0);U=R+C|0;aa=m>>>0>U>>>0?U:m;c[z>>2]=aa;Eb=H<<2;if((Eb|0)>(l|0)){E=165;break d}if(!((Eb+ha|0)>>>0<12289>>>0)){E=167;break d}b[f+71200+(ba*49568|0)+400>>1]=Eb;ba=G+1|0;if((ba|0)<(O|0)){G=ba;C=aa}else{Bb=aa;break}}}}while(0);I=ga+(Bb>>>3)|0;v=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(Bb&7)>>26;I=Bb+6|0;C=m>>>0>I>>>0?I:m;c[z>>2]=C;I=v+ia|0;if((v|0)==(-32|0)|(v|0)==31){G=((v|0)!=31)<<31>>31;O=c[oa>>2]|0;l=v;v=0;R=C;while(1){C=R+5|0;if((C|0)>=(O|0)){Fb=l;break}F=ga+(R>>>3)|0;aa=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(R&7)>>>27;F=m>>>0>C>>>0?C:m;c[z>>2]=F;if((aa|0)==31){l=31;v=v+31|0;R=F}else{Fb=aa;break}}Gb=I-G+(Fb+v^G)|0}else{Gb=I}if((Gb|0)<0){KIb(c[q>>2]|0,48,2585432,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa;Hb=a[Ga]|0}else{Hb=ab}if(Hb<<24>>24==1){c[f+71200+((a[ua]|0)*49568|0)+140>>2]=Gb;Ib=0}else{R=c[z>>2]|0;l=c[wa>>2]|0;m=(c[xa>>2]|0)+(R>>>3)|0;ga=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(R&7)>>>29;m=R+3|0;R=l>>>0>m>>>0?m:l;c[z>>2]=R;if(!(Hb<<24>>24>0)){Jb=Hb;break}m=(ga|0)==0;O=32-ga|0;ia=Hb<<24>>24;aa=Gb+1|0;F=0;C=R;while(1){R=f+71200+((a[f+68619+F|0]|0)*49568|0)+140|0;c[R>>2]=Gb;ba=c[xa>>2]|0;H=d[ba+(C>>>3)|0]|0;U=((C|0)<(l|0))+C|0;c[z>>2]=U;do{if((H&128>>>((C&7)>>>0)|0)==0){Kb=U}else{if(m){c[R>>2]=aa;Kb=U;break}else{V=ba+(U>>>3)|0;Z=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(U&7)>>>(O>>>0);V=U+ga|0;W=l>>>0>V>>>0?V:l;c[z>>2]=W;c[R>>2]=aa+Z;Kb=W;break}}}while(0);R=F+1|0;if((R|0)<(ia|0)){F=R;C=Kb}else{Ib=0;break}}}while(1){C=a[f+68619+Ib|0]|0;F=f+71200+(C*49568|0)+384|0;ia=a[F]|0;aa=ia<<24>>24==0|0;l=f+71200+(C*49568|0)+152+(aa*116|0)|0;c[f+71200+(C*49568|0)+388>>2]=l;ga=a[za]|0;O=f+71200+(C*49568|0)+152+(aa*116|0)+(ga<<24>>24<<2)|0;m=f+71200+(C*49568|0)+144|0;I=ga<<24>>24>0;do{if((a[m]|0)!=0&I){G=f+66666+((d[Ca]|0)*232|0)+((d[f+71200+(C*49568|0)+392|0]|0)*29|0)|0;c[l>>2]=c[f+71200+(C*49568|0)+152+((ia<<24>>24)*116|0)+(a[G]<<2)>>2];v=a[za]|0;if(v<<24>>24>1){Lb=G;Mb=1}else{Nb=v;break}while(1){v=Lb+1|0;c[f+71200+(C*49568|0)+152+(aa*116|0)+(Mb<<2)>>2]=c[f+71200+(C*49568|0)+152+((a[F]|0)*116|0)+(a[v]<<2)>>2];G=Mb+1|0;R=a[za]|0;if((G|0)<(R<<24>>24|0)){Lb=v;Mb=G}else{Nb=R;break}}}else{Nb=ga}}while(0);if((a[f+71200+(C*49568|0)+132|0]|0)==0){E=193}else{ia=c[z>>2]|0;R=d[(c[J>>2]|0)+(ia>>>3)|0]|0;c[z>>2]=((ia|0)<(c[wa>>2]|0))+ia;if((R&128>>>((ia&7)>>>0)|0)!=0){E=193}}if((E|0)==193){E=0;h:do{if((a[m]|0)==0){ia=c[z>>2]|0;R=c[wa>>2]|0;G=c[J>>2]|0;v=G+(ia>>>3)|0;U=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(ia&7)>>>30;v=ia+2|0;ia=R>>>0>v>>>0?v:R;c[z>>2]=ia;v=U+1&255;a[f+71200+(C*49568|0)+145|0]=v;if(!I){break}U=c[1280171]|0;ba=l;H=45/(v<<24>>24|0)|0;v=ia;ia=R;while(1){R=G+(v>>>3)|0;W=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(v&7)>>>24;R=b[U+(W<<2)>>1]|0;Z=b[U+(W<<2)+2>>1]|0;W=Z<<16>>16;do{if(Z<<16>>16<0){V=v+8|0;B=ia>>>0>V>>>0?V:ia;V=G+(B>>>3)|0;N=((je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(B&7)>>>((W+32|0)>>>0))+R|0;V=b[U+(N<<2)>>1]|0;Q=b[U+(N<<2)+2>>1]|0;N=Q<<16>>16;if(!(Q<<16>>16<0)){Ob=N;Pb=V;Qb=B;break}Q=B-W|0;B=ia>>>0>Q>>>0?Q:ia;Q=G+(B>>>3)|0;ka=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(B&7)>>>((N+32|0)>>>0))+V|0;Ob=b[U+(ka<<2)+2>>1]|0;Pb=b[U+(ka<<2)>>1]|0;Qb=B}else{Ob=W;Pb=R;Qb=v}}while(0);R=Ob+Qb|0;c[z>>2]=ia>>>0>R>>>0?R:ia;R=H-60+Pb|0;c[ba>>2]=R;W=ba+4|0;if(!(W>>>0<O>>>0)){break h}ba=W;H=R;v=c[z>>2]|0;ia=c[wa>>2]|0}}else{if(!(Nb<<24>>24>0)){break}ia=c[1280177]|0;v=c[J>>2]|0;H=0;ba=Nb;do{U=c[z>>2]|0;G=c[wa>>2]|0;R=v+(U>>>3)|0;W=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(U&7)>>>23;R=b[ia+(W<<2)>>1]|0;Z=b[ia+(W<<2)+2>>1]|0;W=Z<<16>>16;do{if(Z<<16>>16<0){w=U+9|0;B=G>>>0>w>>>0?w:G;w=v+(B>>>3)|0;ka=((je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(B&7)>>>((W+32|0)>>>0))+R|0;w=b[ia+(ka<<2)>>1]|0;V=b[ia+(ka<<2)+2>>1]|0;ka=V<<16>>16;if(!(V<<16>>16<0)){Rb=ka;Sb=w;Tb=B;break}V=B-W|0;B=G>>>0>V>>>0?V:G;V=v+(B>>>3)|0;N=((je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(B&7)>>>((ka+32|0)>>>0))+w|0;Rb=b[ia+(N<<2)+2>>1]|0;Sb=b[ia+(N<<2)>>1]|0;Tb=B}else{Rb=W;Sb=R;Tb=U}}while(0);U=Rb+Tb|0;R=G>>>0>U>>>0?U:G;c[z>>2]=R;if((Sb|0)==1){break h}else if((Sb|0)==0){U=v+(R>>>3)|0;W=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(R&7);U=R+14|0;c[z>>2]=G>>>0>U>>>0?U:G;Ub=W>>>18;Vb=W>>>24;Wb=W>>>19&31}else{W=d[605360+Sb|0]|0;U=d[605480+Sb|0]|0;Z=d[v+(R>>>3)|0]<<(R&7)>>>7;c[z>>2]=((R|0)<(G|0))+R;Ub=Z;Vb=U;Wb=W}W=Ub&1;U=Wb+H|0;if((U|0)>=(ba<<24>>24|0)){E=216;break d}Z=f+71200+(C*49568|0)+152+(aa*116|0)+(U<<2)|0;c[Z>>2]=(W-1^Vb)+(W^1)+(c[Z>>2]|0);H=U+1|0;ba=a[za]|0;}while((H|0)<(ba<<24>>24|0))}}while(0);a[F]=(a[F]|0)==0|0;a[f+71200+(C*49568|0)+392|0]=a[Ca]|0;a[m]=1}I=c[l>>2]|0;ba=f+71200+(C*49568|0)+148|0;c[ba>>2]=I;if(ga<<24>>24>1){H=f+71200+(C*49568|0)+152+(aa*116|0)+4|0;v=I;do{I=c[H>>2]|0;v=(v|0)>(I|0)?v:I;c[ba>>2]=v;H=H+4|0;}while(H>>>0<O>>>0)}O=Ib+1|0;H=a[Ga]|0;if((O|0)<(H<<24>>24|0)){Ib=O}else{Xb=H;E=186;break}}}else{Xb=ab;E=186}}while(0);do{if((E|0)==186){E=0;if(!(Xb<<24>>24>0)){Jb=Xb;break}ha=La<<2;ea=0;while(1){H=a[f+68619+ea|0]|0;do{if((a[f+71200+(H*49568|0)+2|0]|0)==0){E=248}else{O=c[z>>2]|0;if((O|0)>=(c[oa>>2]|0)){E=248;break}v=d[(c[xa>>2]|0)+(O>>>3)|0]<<(O&7)>>>7;c[z>>2]=((O|0)<(c[wa>>2]|0))+O;O=v&1;v=9800168+(O*20|0)|0;ba=(O|0)==0;O=ba?1671024:1665552;aa=ba?1671568:1666040;ba=f+71200+(H*49568|0)+400|0;C=f+71200+(H*49568|0)+396|0;ga=0;l=0;m=0;while(1){if((l|3|0)>=(e[ba>>1]|0)){Yb=l;break}F=c[846985]|0;I=c[z>>2]|0;ia=c[wa>>2]|0;U=c[xa>>2]|0;Z=U+(I>>>3)|0;W=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(I&7)>>>23;Z=b[F+(W<<2)>>1]|0;R=b[F+(W<<2)+2>>1]|0;W=R<<16>>16;if(R<<16>>16<0){R=I+9|0;B=ia>>>0>R>>>0?R:ia;R=U+(B>>>3)|0;N=((je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(B&7)>>>((W+32|0)>>>0))+Z|0;Zb=b[F+(N<<2)+2>>1]|0;_b=b[F+(N<<2)>>1]|0;$b=B}else{Zb=W;_b=Z;$b=I}I=Zb+$b|0;Z=ia>>>0>I>>>0?I:ia;c[z>>2]=Z;i:do{if((_b|0)==126){I=0;W=Z;B=ia;N=U;while(1){F=c[846991]|0;R=N+(W>>>3)|0;w=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(W&7)>>>23;R=b[F+(w<<2)>>1]|0;ka=b[F+(w<<2)+2>>1]|0;w=ka<<16>>16;if(ka<<16>>16<0){ka=W+9|0;V=B>>>0>ka>>>0?ka:B;ka=N+(V>>>3)|0;Q=((je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(V&7)>>>((w+32|0)>>>0))+R|0;ac=b[F+(Q<<2)+2>>1]|0;bc=b[F+(Q<<2)>>1]|0;cc=V}else{ac=w;bc=R;cc=W}R=ac+cc|0;w=B>>>0>R>>>0?R:B;c[z>>2]=w;if((bc|0)==136){R=c[846997]|0;V=N+(w>>>3)|0;Q=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(w&7)>>>23;V=b[R+(Q<<2)>>1]|0;F=b[R+(Q<<2)+2>>1]|0;Q=F<<16>>16;if(F<<16>>16<0){F=w+9|0;ka=B>>>0>F>>>0?F:B;F=N+(ka>>>3)|0;da=((je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(ka&7)>>>((Q+32|0)>>>0))+V|0;dc=b[R+(da<<2)+2>>1]|0;ec=b[R+(da<<2)>>1]|0;fc=ka}else{dc=Q;ec=V;fc=w}w=dc+fc|0;V=B>>>0>w>>>0?w:B;c[z>>2]=V;if((ec|0)==100){w=(_gb(s)|0)+100|0;gc=w;hc=c[846997]|0;ic=c[z>>2]|0;jc=c[wa>>2]|0;kc=c[xa>>2]|0}else{gc=ec;hc=R;ic=V;jc=B;kc=N}V=kc+(ic>>>3)|0;R=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(ic&7)>>>23;V=b[hc+(R<<2)>>1]|0;w=b[hc+(R<<2)+2>>1]|0;R=w<<16>>16;if(w<<16>>16<0){w=ic+9|0;Q=jc>>>0>w>>>0?w:jc;w=kc+(Q>>>3)|0;ka=((je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(Q&7)>>>((R+32|0)>>>0))+V|0;lc=b[hc+(ka<<2)+2>>1]|0;mc=b[hc+(ka<<2)>>1]|0;nc=Q}else{lc=R;mc=V;nc=ic}V=lc+nc|0;c[z>>2]=jc>>>0>V>>>0?V:jc;if((mc|0)==100){oc=(_gb(s)|0)+100|0}else{oc=mc}g[o+(I<<2)>>2]=+(gc>>>0>>>0);g[o+((I|1)<<2)>>2]=+(oc>>>0>>>0)}else{V=d[523376+bc|0]|0;c[o+(I<<2)>>2]=c[1585184+(V>>>4<<2)>>2];c[o+((I|1)<<2)>>2]=c[1585184+((V&15)<<2)>>2]}V=I+2|0;if((V|0)>=4){pc=ga;qc=l;rc=m;sc=0;break i}I=V;W=c[z>>2]|0;B=c[wa>>2]|0;N=c[xa>>2]|0}}else{N=e[523120+(_b<<1)>>1]|0;c[qa>>2]=c[1585184+(N>>>12<<2)>>2];c[ra>>2]=c[1585184+((N>>>8&15)<<2)>>2];c[_>>2]=c[1585184+((N>>>4&15)<<2)>>2];c[K>>2]=c[1585184+((N&15)<<2)>>2];pc=ga;qc=l;rc=m;sc=0}}while(0);while(1){U=c[o+(sc<<2)>>2]|0;if((U|0)==0){g[(c[C>>2]|0)+(qc<<2)>>2]=0.0;ia=rc+1|0;tc=ia;uc=(ia|0)>(b[Ea>>1]>>8|0)|pc}else{ia=c[z>>2]|0;Z=d[(c[xa>>2]|0)+(ia>>>3)|0]<<(ia&7)>>>7;c[z>>2]=((ia|0)<(c[wa>>2]|0))+ia;c[(c[C>>2]|0)+(qc<<2)>>2]=U^-2147483648^Z<<31;tc=0;uc=pc}Z=sc+1|0;if((Z|0)>=4){break}pc=uc;qc=qc+1|0;rc=tc;sc=Z}Z=l+4|0;if((a[$]|0)!=0|(uc|0)==0){ga=uc;l=Z;m=tc}else{Yb=Z;break}}m=b[Ea>>1]|0;if((Yb|0)>=(m|0)){break}mrc((c[C>>2]|0)+(Yb<<2)|0,0,m-Yb<<2|0)|0;m=b[Ea>>1]|0;$gb(c[q>>2]|0,s,v,aa,O,1,c[C>>2]|0,Yb,m,m,a[la]|0,0)|0}}while(0);if((E|0)==248){E=0;mrc(c[f+71200+(H*49568|0)+396>>2]|0,0,ha|0)|0}m=ea+1|0;l=a[Ga]|0;if((m|0)<(l<<24>>24|0)){ea=m}else{Jb=l;break}}}}while(0);do{if(Y){ea=La>>>0>65535>>>0;ha=ea?La>>>16:La;l=ea?16:0;if((ha&65280|0)==0){vc=l;wc=ha}else{vc=l|8;wc=ha>>>8}ha=vc-6+(d[1359664+wc|0]|0)|0;l=f+32848+(ha<<6)|0;ea=a[ya]|0;if(ea<<24>>24==0){xc=Jb}else{m=0;ga=ea;while(1){do{if((a[f+68640+(m*320|0)+1|0]|0)==0){yc=ga}else{ea=a[f+68640+(m*320|0)|0]|0;ba=ea&255;Z=f+68640+(m*320|0)+288|0;U=f+68640+(m*320|0)+288+(ba<<2)|0;if((a[za]|0)<=0){yc=ga;break}ia=c[Da>>2]|0;G=f+68640+(m*320|0)+32|0;N=p+(ba<<2)|0;ba=ea<<24>>24==0;ea=f+68640+(m*320|0)+292|0;B=N;W=(((B>>>0>L>>>0?B:L)+ma|0)>>>2)+1|0;B=ia;I=f+68640+(m*320|0)+2|0;V=ia;while(1){ia=I+1|0;do{if((a[I]|0)==1){R=b[B>>1]|0;Q=B+2|0;ka=b[Q>>1]|0;w=b[Ea>>1]|0;da=ka<<16>>16>w<<16>>16?w:ka;if(!(R<<16>>16<da<<16>>16)){zc=V;Ac=Q;break}ka=da<<16>>16;da=R<<16>>16;while(1){if(!ba){R=M;w=Z;while(1){g[R>>2]=+g[(c[w>>2]|0)+(da<<2)>>2];F=w+4|0;if(F>>>0<U>>>0){R=R+4|0;w=F}else{Bc=G;Cc=Z;break}}while(1){w=Bc;R=M;rb=0.0;while(1){F=R+4|0;Dc=rb+ +g[R>>2]*+g[w>>2];if(F>>>0<N>>>0){w=w+4|0;R=F;rb=Dc}else{break}}g[(c[Cc>>2]|0)+(da<<2)>>2]=Dc;R=Cc+4|0;if(R>>>0<U>>>0){Bc=Bc+(W<<2)|0;Cc=R}else{break}}}R=da+1|0;if((R|0)<(ka|0)){da=R}else{zc=V;Ac=Q;break}}}else{Q=B+2|0;if((c[(c[q>>2]|0)+416>>2]|0)!=2){zc=V;Ac=Q;break}da=b[Q>>1]|0;ka=b[Ea>>1]|0;R=b[B>>1]|0;w=((da<<16>>16>ka<<16>>16?ka:da)<<16>>16)-R|0;da=(c[Z>>2]|0)+(R<<2)|0;xe[c[S>>2]&7](da,da,1.4140625,w);da=(c[ea>>2]|0)+(b[B>>1]<<2)|0;xe[c[S>>2]&7](da,da,1.4140625,w);zc=c[Da>>2]|0;Ac=Q}}while(0);if(Ac>>>0<(zc+(a[za]<<1)|0)>>>0){B=Ac;I=ia;V=zc}else{break}}yc=a[ya]|0}}while(0);H=m+1|0;if((H|0)<(yc&255|0)){m=H;ga=yc}else{break}}xc=a[Ga]|0}if(!(xc<<24>>24>0)){break}ga=f+33376+(fa<<2)|0;m=La-fa<<2;H=f+32848+(ha<<6)+44|0;V=0;while(1){I=a[f+68619+V|0]|0;B=I<<24>>24;ea=c[f+71200+(B*49568|0)+388>>2]|0;if(I<<24>>24==(a[X]|0)){mrc(ga|0,0,m|0)|0}j:do{if((a[za]|0)>0){I=f+71200+(B*49568|0)+140|0;Z=f+71200+(B*49568|0)+148|0;W=f+71200+(B*49568|0)+145|0;U=f+71200+(B*49568|0)+396|0;N=ea;G=0;while(1){ba=G+1|0;C=c[Da>>2]|0;O=b[C+(ba<<1)>>1]|0;aa=b[Ea>>1]|0;rb=+T(+10.0,+(+((c[I>>2]|0)-(ca(a[W]|0,(c[Z>>2]|0)-(c[N>>2]|0)|0)|0)|0)/20.0));v=b[C+(G<<1)>>1]|0;xe[c[S>>2]&7](f+33376+(v<<2)|0,(c[U>>2]|0)+(v<<2)|0,rb,((O<<16>>16>aa<<16>>16?aa:O)<<16>>16)-v|0);if((ba|0)>=(a[za]|0)){Ec=U;break j}N=N+4|0;G=ba}}else{Ec=f+71200+(B*49568|0)+396|0}}while(0);ef[c[H>>2]&4095](l,c[Ec>>2]|0,P);B=V+1|0;ea=a[Ga]|0;if((B|0)<(ea<<24>>24|0)){V=B}else{Fc=ea;E=282;break}}}else{Fc=Jb;E=282}}while(0);do{if((E|0)==282){E=0;if(!(Fc<<24>>24>0)){break}fa=0;Y=b[Ea>>1]|0;do{V=a[f+68619+fa|0]|0;l=f+71200+(V*49568|0)|0;H=b[l>>1]|0;m=H<<16>>16;ga=c[f+71200+(V*49568|0)+396>>2]|0;V=Y<<16>>16;if(Y<<16>>16<H<<16>>16){Gc=m-V>>1;Hc=V}else{Gc=0;Hc=m}V=Gc-(m>>1)|0;m=ga+(V<<2)|0;H=Hc>>>0>65535>>>0;ha=H?Hc>>>16:Hc;ea=H?16:0;if((ha&65280|0)==0){Ic=ea;Jc=ha}else{Ic=ea|8;Jc=ha>>>8}ha=Hc>>1;pe[c[y>>2]&1023](m,m,ga+(V+ha<<2)|0,c[f+66144+(Ic-6+(d[1359664+Jc|0]|0)<<2)>>2]|0,ha);Y=b[Ea>>1]|0;b[l>>1]=Y;fa=fa+1|0;Kc=a[Ga]|0;Lc=Kc<<24>>24;}while((fa|0)<(Lc|0));if(Kc<<24>>24>0){Mc=0}else{break}do{fa=a[f+68619+Mc|0]|0;Y=f+71200+(fa*49568|0)+132|0;l=a[Y]|0;if(!((l&255)>>>0<(d[f+71200+(fa*49568|0)+3|0]|0)>>>0)){E=293;break d}a[Y]=l+1;Mc=Mc+1|0;}while((Mc|0)<(Lc|0))}}while(0);l=e[D>>1]|0;if((a[Aa]|0)!=0){Ia=l;break c}na=l;x=c[q>>2]|0;pa=c[z>>2]|0}if((E|0)==90){KIb(Sa,16,2240344,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==95){QIb(Sa,2199376,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==98){QIb(Sa,2528848,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==119){QIb(c[q>>2]|0,2513720,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==155){KIb(0,0,2167760,(sa=i,i=i+24|0,c[sa>>2]=2141088,c[sa+8>>2]=2117592,c[sa+16>>2]=1188,sa)|0);i=sa;Hd();return 0}else if((E|0)==165){KIb(c[q>>2]|0,16,2635632,(sa=i,i=i+8|0,c[sa>>2]=Eb,sa)|0);i=sa}else if((E|0)==167){KIb(0,0,2167760,(sa=i,i=i+24|0,c[sa>>2]=2612e3,c[sa+8>>2]=2117592,c[sa+16>>2]=1203,sa)|0);i=sa;Hd();return 0}else if((E|0)==216){KIb(c[q>>2]|0,16,2546480,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}else if((E|0)==293){KIb(c[q>>2]|0,16,2564592,(sa=i,i=i+1|0,i=i+7&-8,c[sa>>2]=0,sa)|0);i=sa}a[f+68580|0]=1;Nc=0;i=k;return Nc|0}}while(0);c[h+76>>2]=Ia;if((M4a(r,h,0)|0)<0){a[f+68580|0]=1;Nc=0;i=k;return Nc|0}do{if((c[A>>2]|0)>0){r=h+64|0;Ia=0;do{nrc(c[(c[r>>2]|0)+(Ia<<2)>>2]|0,f+71200+(Ia*49568|0)+416|0,e[D>>1]<<2)|0;Ia=Ia+1|0;Oc=c[A>>2]|0;}while((Ia|0)<(Oc|0));if((Oc|0)>0){Pc=0}else{break}do{Ia=e[D>>1]|0;nrc(f+71200+(Pc*49568|0)+416|0,f+71200+(Pc*49568|0)+416+(Ia<<2)|0,Ia<<1)|0;Pc=Pc+1|0;}while((Pc|0)<(c[A>>2]|0))}}while(0);A=f+68613|0;if((a[A]|0)==0){c[j>>2]=1}else{a[A]=0;c[j>>2]=0;WHb(h)}k:do{if((a[t]|0)==0){h=c[f+68568>>2]|0;j=c[z>>2]|0;while(1){if((j|0)>=(h|0)){break}A=d[(c[xa>>2]|0)+(j>>>3)|0]|0;Pc=c[wa>>2]|0;D=((j|0)<(Pc|0))+j|0;c[z>>2]=D;if((A&128>>>((j&7)>>>0)|0)==0){j=D}else{Qc=D;Rc=Pc;break k}}Qc=j;Rc=c[wa>>2]|0}else{h=c[z>>2]|0;Pc=c[f+68572>>2]|0;if((u|0)!=(h+2-Pc|0)){KIb(c[q>>2]|0,16,2291160,(sa=i,i=i+16|0,c[sa>>2]=c[f+68584>>2],c[sa+8>>2]=u-1-h+Pc,sa)|0);i=sa;a[f+68580|0]=1;Nc=0;i=k;return Nc|0}D=u-1-h+Pc|0;Pc=-h|0;A=c[wa>>2]|0;Oc=A-h|0;if((D|0)<(Pc|0)){Sc=Pc}else{Sc=(Oc|0)<(D|0)?Oc:D}D=Sc+h|0;c[z>>2]=D;Qc=D;Rc=A}}while(0);Sc=d[(c[xa>>2]|0)+(Qc>>>3)|0]<<(Qc&7)>>>7;c[z>>2]=((Qc|0)<(Rc|0))+Qc;Qc=f+68584|0;c[Qc>>2]=(c[Qc>>2]|0)+1;Nc=Sc&1;i=k;return Nc|0}a[f+68580|0]=1;Nc=0;i=k;return Nc|0}function uhb(a){a=a|0;c[1510437]=3343992;c[1510439]=132;$2(6041744,6,22,129824,1,1,129776,2,2,0,0,0,4)|0;return}function vhb(e){e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+32|0;j=f|0;k=c[e+60>>2]|0;l=e+100|0;m=c[l>>2]|0;if((m|0)!=46){KIb(e,16,2117544,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-1094995529;i=f;return o|0}m=e+96|0;p=(c[m>>2]|0)+18|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=(c[e+432>>2]<<1)-2|0;r=p>>>0>65535>>>0;s=r?p>>>16:p;p=r?16:0;if((s&65280|0)==0){t=p;u=s}else{t=p|8;u=s>>>8}c[k+48>>2]=t+3+(d[1359664+u|0]|0);u=q&1;c[k+56>>2]=u;if((u|0)!=0){nZa(k+2368|0,7,0)|0;nZa(k+2456|0,7,1)|0;g5(k+2544|0,6,2)|0;g5(k+2656|0,6,3)|0;u=k+4812|0;t=u;G0a(u,256);s=k+2768|0;nrc(k+3788|0,u|0,1024)|0;u=0;do{p=510-u|0;g[s+(u<<2)>>2]=-0.0- +g[s+(p<<2)>>2];g[t+(p<<2)>>2]=+g[t+(u<<2)>>2];u=u+1|0;}while((u|0)<255)}u=q>>>2&15;c[k+60>>2]=u;if(u>>>0>11>>>0){KIb(e,16,2635488,(n=i,i=i+8|0,c[n>>2]=u,n)|0);i=n;o=-1094995529;i=f;return o|0}c[k+64>>2]=q>>>6&1;c[k+68>>2]=q>>>7&15;c[k+76>>2]=q>>>13&1;c[k+80>>2]=q>>>14&1;u=k+72|0;if((q&4096|0)==0){c[u>>2]=10;c[k+84>>2]=24;c[k+88>>2]=48;v=10}else{c[u>>2]=16;c[k+84>>2]=34;c[k+88>>2]=60;v=16}q=k+440|0;t=0;s=v;do{h[q+(t<<3)>>3]=(+(t|0)+1.0)*3.141592653589793/(+(s|0)+1.0);t=t+1|0;s=c[u>>2]|0;}while((t|0)<(s|0));s=(c[m>>2]|0)+22|0;m=(c[l>>2]<<3)-176|0;l=m>>>0>2147483639>>>0|(s|0)==0;t=l?0:s;s=l?0:m;m=k;c[m>>2]=t;c[k+12>>2]=s;l=s+8|0;u=k+16|0;c[u>>2]=l;c[k+4>>2]=t+(s>>3);s=k+8|0;c[s>>2]=0;mrc(j|0,0,32)|0;mrc(k+20|0,-1|0,25)|0;q=0;v=0;p=l;l=t;while(1){t=l+(v>>>3)|0;r=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(v&7)>>>29;t=v+3|0;c[s>>2]=p>>>0>t>>>0?t:p;t=j+(r<<2)|0;w=c[t>>2]|0;if((w|0)>3){x=19;break}c[t>>2]=w+1;a[k+(w+20+(r*3|0))|0]=q;r=q+1|0;if((r|0)>=17){break}q=r;v=c[s>>2]|0;p=c[u>>2]|0;l=c[m>>2]|0}if((x|0)==19){KIb(e,16,2611952,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=f;return o|0}x=e+412|0;m=((c[x>>2]<<8|0)/400|0)+50>>8;c[k+92>>2]=m;l=(((c[x>>2]|0)*9472|0|0)/2e3|0)+50>>8;c[k+96>>2]=l;u=l-m|0;if((u|0)<1){KIb(e,16,2585392,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=f;return o|0}p=(u<<1)-2|0;s=p>>>0>65535>>>0;v=s?p>>>16:p;p=s?16:0;if((v&65280|0)==0){y=p;z=v}else{y=p|8;z=v>>>8}c[k+100>>2]=(d[1359664+z|0]|0)+y;c[k+568>>2]=40;c[k+572>>2]=0;y=l+8|0;c[k+52>>2]=y;if((m|0)<1|(y|0)>416){KIb(e,16,2564544,(n=i,i=i+24|0,c[n>>2]=c[x>>2],c[n+8>>2]=322,c[n+16>>2]=22097,n)|0);i=n;o=-38;i=f;return o|0}b[k+120>>1]=m;x=(u*25|0)>>>6;b[k+122>>1]=x;y=(u*44|0)>>>6;b[k+124>>1]=y;z=l+65535|0;b[k+126>>1]=z;l=u>>3&-16;c[k+116>>2]=l;if((l|0)<1){KIb(e,16,2546432,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1094995529;i=f;return o|0}n=(l<<1)-2|0;l=n>>>0>65535>>>0;u=l?n>>>16:n;n=l?16:0;if((u&65280|0)==0){A=n;B=u}else{A=n|8;B=u>>>8}c[k+112>>2]=A+1+(d[1359664+B|0]|0);B=(y&65535)+1+(z&65535)+((x&65535)-(m<<1)<<1)|0;c[k+108>>2]=B;m=(B<<1)-2|0;B=m>>>0>65535>>>0;x=B?m>>>16:m;m=B?16:0;if((x&65280|0)==0){C=m;D=x}else{C=m|8;D=x>>>8}c[k+104>>2]=(d[1359664+D|0]|0)+C;c[e+416>>2]=1;C=e+448|0;c[C>>2]=4;c[C+4>>2]=0;c[e+420>>2]=3;o=0;i=f;return o|0}function whb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=c[b+60>>2]|0;i=b+432|0;j=c[i>>2]|0;k=c[g+28>>2]|0;while(1){if((k|0)>(j|0)){k=k-j|0}else{break}}j=h;if((k|0)==0){c[f>>2]=0;l=0;return l|0}m=g+24|0;g=c[m>>2]|0;n=k<<3;o=n>>>0>2147483639>>>0;p=o|(g|0)==0;q=p?0:g;g=p?0:n;p=h;c[p>>2]=q;r=h+12|0;c[r>>2]=g;s=g+8|0;t=h+16|0;c[t>>2]=s;u=h+4|0;c[u>>2]=q+(g>>3);v=h+8|0;c[v>>2]=0;do{if((k|0)==(c[i>>2]|0)){a:do{if((g|0)<11){w=0}else{x=s>>>0>4>>>0?4:s;c[v>>2]=x;y=(d[q+(x>>>3)|0]|0)<<(x&4)>>>7;z=(x|0)<(s|0)|x;c[v>>2]=z;c[h+132>>2]=y&1;y=c[h+48>>2]|0;x=z;do{z=q+(x>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7);z=x+6|0;x=s>>>0>z>>>0?z:s;c[v>>2]=x;z=(A&-67108864|0)==-67108864;if((g-x|0)<((-(z&1)&6)+y|0)){w=x;break a}}while(z);z=q+(x>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(x&7)>>>((32-y|0)>>>0);z=x+y|0;B=s>>>0>z>>>0?z:s;c[v>>2]=B;c[h+128>>2]=A;w=B}}while(0);B=h+128|0;A=c[B>>2]|0;if((A|0)<=0){C=w;D=g;break}z=h+412|0;if((c[z>>2]|0)<=0){E=-w|0;F=s-w|0;if((A|0)<(E|0)){G=E}else{G=(F|0)<(A|0)?F:A}F=G+w|0;c[v>>2]=F;C=F;D=g;break}F=h+416|0;zhb(F,c[m>>2]|0,k,j,A);A=h+420|0;E=c[A>>2]|0;H=F;if((E|0)<32){F=c[H>>2]<<E;c[H>>2]=F;E=h+428|0;I=F>>>24&255;while(1){F=c[E>>2]|0;c[E>>2]=F+1;a[F]=I;F=c[H>>2]|0;c[H>>2]=F<<8;J=(c[A>>2]|0)+8|0;c[A>>2]=J;if((J|0)<32){I=F>>>16&255}else{break}}}c[A>>2]=32;c[H>>2]=0;c[z>>2]=(c[z>>2]|0)+(c[B>>2]|0);do{if((Ahb(b,e,f)|0)==0){if((c[f>>2]|0)==0){break}I=(c[B>>2]|0)+w|0;c[h+136>>2]=I&7;l=I>>3;return l|0}}while(0);z=c[v>>2]|0;H=(c[B>>2]|0)-w+z|0;A=-z|0;I=(c[t>>2]|0)-z|0;if((H|0)<(A|0)){K=A}else{K=(I|0)<(H|0)?I:H}H=K+z|0;c[v>>2]=H;C=H;D=c[r>>2]|0}else{H=c[h+136>>2]|0;if((H|0)==0){C=0;D=g;break}z=s>>>0>H>>>0?H:s;c[v>>2]=z;C=z;D=g}}while(0);g=h+412|0;c[g>>2]=0;s=h+136|0;c[s>>2]=0;K=D-C|0;C=Ahb(b,e,f)|0;if((C|0)<0){l=C;return l|0}if((c[f>>2]|0)!=0){f=c[v>>2]|0;c[s>>2]=f&7;l=f>>3;return l|0}c[g>>2]=K;if((K|0)<=0){l=k;return l|0}g=c[m>>2]|0;f=o|(g|0)==0;o=f?0:g;g=f?0:n;c[p>>2]=o;c[r>>2]=g;r=g+8|0;c[t>>2]=r;c[u>>2]=o+(g>>3);c[v>>2]=0;g=n-K|0;if((g|0)<0){L=0}else{L=(r|0)<(g|0)?r:g}c[v>>2]=L;L=h+416|0;v=h+140|0;c[h+436>>2]=2048;c[h+424>>2]=v;c[h+432>>2]=h+396;c[h+428>>2]=v;c[h+420>>2]=32;c[L>>2]=0;zhb(L,c[m>>2]|0,k,j,K);l=k;return l|0}function xhb(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((c[b+56>>2]|0)==0){return 0}pZa(b+2368|0);pZa(b+2456|0);m5(b+2544|0);m5(b+2656|0);return 0}function yhb(a){a=a|0;var b=0,d=0,e=0,f=0,i=0,j=0,k=0,l=0;b=c[a+60>>2]|0;g[b+6856>>2]=0.0;c[b+412>>2]=0;c[b+136>>2]=0;a=b+72|0;d=c[a>>2]|0;if((d|0)>0){e=b+440|0;f=0;i=d;while(1){h[e+(f<<3)>>3]=(+(f|0)+1.0)*3.141592653589793/(+(i|0)+1.0);j=f+1|0;k=c[a>>2]|0;if((j|0)<(k|0)){f=j;i=k}else{l=k;break}}}else{l=d}mrc(b+616|0,0,1752)|0;if((c[b+56>>2]|0)==0){return}mrc(b+12128+(16-l<<2)|0,0,l<<2|0)|0;l=b+6860|0;c[l>>2]=0;c[l+4>>2]=0;mrc(b+6868|0,0,c[b+52>>2]<<2|0)|0;mrc(b+10452|0,0,640)|0;return}function zhb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;i=g+8|0;j=c[i>>2]|0;k=(c[g+12>>2]|0)-j|0;if((k|0)<(h|0)){return}l=b+4|0;m=b+12|0;n=c[m>>2]|0;if(((c[b+20>>2]|0)-32+(c[l>>2]|0)-(n-(c[b+8>>2]|0)<<3)|0)<(h|0)){return}o=k&7;p=k>>3;k=(o|0)>(h|0)?h:o;if((k|0)>0){o=c[g+16>>2]|0;q=(c[g>>2]|0)+(j>>>3)|0;g=32-k|0;r=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(j&7)>>>(g>>>0);q=j+k|0;c[i>>2]=o>>>0>q>>>0?q:o;o=b|0;q=c[o>>2]|0;i=c[l>>2]|0;if((i|0)>(k|0)){s=i-k|0;t=q<<k|r}else{j=n;y=je(r>>>((k-i|0)>>>0)|q<<i|0)|0;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;s=g+i|0;t=r}c[o>>2]=t;c[l>>2]=s}s=h-k|0;k=p<<3;_2(b,e+(f-p)|0,(s|0)>(k|0)?k:s);return}function Ahb(f,j,k){f=f|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0.0,Ha=0.0,Ia=0,Ja=0,Ka=0,La=0.0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0.0,gb=0,hb=0.0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0.0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0.0,jd=0,kd=0.0,ld=0,md=0,nd=0.0;l=i;i=i+7520|0;m=l|0;n=l+24|0;o=l+344|0;p=l+440|0;q=l+568|0;r=l+632|0;s=l+664|0;t=l+792|0;u=l+856|0;v=l+880|0;w=l+1264|0;x=l+4896|0;z=l+6880|0;A=l+7008|0;B=l+7264|0;C=f+60|0;D=c[C>>2]|0;E=D;F=D+72|0;H=c[F>>2]|0;I=c[D+80>>2]|0;if((H|0)==16){J=115304+(I<<7)|0}else{J=115560+(I*80|0)|0}I=D+2304|0;nrc(x|0,I|0,H<<2)|0;H=D+640|0;K=D+52|0;nrc(w|0,H|0,c[K>>2]<<2)|0;L=D+412|0;M=c[L>>2]|0;if((M|0)>0){N=D+140|0;O=M>>>0>2147483639>>>0|(N|0)==0;P=O?0:N;N=O?0:M;c[u>>2]=P;c[u+12>>2]=N;c[u+16>>2]=N+8;c[u+4>>2]=P+(N+7>>3);c[u+8>>2]=0;c[L>>2]=0;Q=u;R=P;S=0;T=N}else{Q=D;R=c[D>>2]|0;S=c[D+8>>2]|0;T=c[D+12>>2]|0}N=Q|0;P=Q+8|0;u=T>>>0>2147483639>>>0|(R|0)==0;L=u?0:R;M=u?0:T;T=M+8|0;if((S|0)<0){V=0}else{V=(T|0)<(S|0)?T:S}a:do{if((M-V|0)>=14){u=((V|0)<(T|0))+V|0;if((d[L+(V>>>3)|0]&128>>>((V&7)>>>0)|0)==0){W=-38;i=l;return W|0}O=((u|0)<(T|0))+u|0;if((d[L+(u>>>3)|0]&128>>>((u&7)>>>0)|0)==0){X=O}else{u=O+12|0;X=T>>>0>u>>>0?u:T}u=D+132|0;O=(c[u>>2]|0)==0;if(O){Y=X}else{Z=c[D+88>>2]|0;if((M-X|0)<(Z|0)){break}_=-X|0;aa=T-X|0;if((Z|0)<(_|0)){ba=_}else{ba=(aa|0)<(Z|0)?aa:Z}Y=ba+X|0}Z=D+84|0;aa=c[1510437]|0;_=D+100|0;da=D+104|0;ea=D+112|0;fa=Y;ga=0;while(1){if(O){ha=c[Z>>2]|0;if((M-fa|0)<(ha|0)){break a}ia=-fa|0;ja=T-fa|0;if((ha|0)<(ia|0)){ka=ia}else{ka=(ja|0)<(ha|0)?ja:ha}la=ka+fa|0}else{la=fa}ha=L+(la>>>3)|0;ja=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(la&7)>>>26;ha=b[aa+(ja<<2)>>1]|0;ia=b[aa+(ja<<2)+2>>1]|0;ja=ia<<16>>16;do{if(ia<<16>>16<0){ma=la+6|0;na=T>>>0>ma>>>0?ma:T;ma=L+(na>>>3)|0;oa=((je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>((ja+32|0)>>>0))+ha|0;ma=b[aa+(oa<<2)>>1]|0;pa=b[aa+(oa<<2)+2>>1]|0;oa=pa<<16>>16;if(!(pa<<16>>16<0)){qa=oa;ra=ma;sa=na;break}pa=na-ja|0;na=T>>>0>pa>>>0?pa:T;pa=L+(na>>>3)|0;ta=((je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(na&7)>>>((oa+32|0)>>>0))+ma|0;qa=b[aa+(ta<<2)+2>>1]|0;ra=b[aa+(ta<<2)>>1]|0;sa=na}else{qa=ja;ra=ha;sa=la}}while(0);ha=qa+sa|0;ja=T>>>0>ha>>>0?ha:T;ha=a[E+20+ra|0]|0;if(ha<<24>>24<0){W=-1094995529;ua=253;break}ia=ha<<24>>24;if((ia-2|0)>>>0<6>>>0){na=c[_>>2]|0;if((M-ja|0)<(na|0)){break a}ta=-ja|0;ma=T-ja|0;if((na|0)<(ta|0)){va=ta}else{va=(ma|0)<(na|0)?ma:na}wa=va+ja|0}else{wa=ja}do{if((ha<<24>>24|0)==2){ja=L+(wa>>>3)|0;na=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(wa&7);ja=wa+6|0;ma=T>>>0>ja>>>0?ja:T;if(!(na>>>0>3623878655>>>0)){xa=2;ya=ma;break}na=ma+2|0;xa=0;ya=T>>>0>na>>>0?na:T}else if((ha<<24>>24|0)==0){na=wa+8|0;xa=2;ya=T>>>0>na>>>0?na:T}else{xa=2;ya=wa}}while(0);if((ia-8|0)>>>0<9>>>0){za=(ca((d[1210504+(ia<<3)|0]|0)-1|0,c[ea>>2]|0)|0)+(c[da>>2]|0)|0}else{za=ha<<24>>24==2?xa:0}na=(e[1210510+(ia<<3)>>1]|0)+za|0;if((M-ya|0)<(na|0)){break a}ma=-ya|0;ja=T-ya|0;if((na|0)<(ma|0)){Aa=ma}else{Aa=(ja|0)<(na|0)?ja:na}na=ga+1|0;if((na|0)<3){fa=Aa+ya|0;ga=na}else{break}}if((ua|0)==253){i=l;return W|0}ga=d[R+(S>>>3)|0]|0;fa=Q+16|0;da=c[fa>>2]|0;ea=((S|0)<(da|0))+S|0;c[P>>2]=ea;if((ga&128>>>((S&7)>>>0)|0)==0){QIb(f,2440976,(Ba=i,i=i+1|0,i=i+7&-8,c[Ba>>2]=0,Ba)|0);i=Ba;W=-1163346256;i=l;return W|0}ga=d[R+(ea>>>3)|0]|0;_=((ea|0)<(da|0))+ea|0;c[P>>2]=_;do{if((ga&128>>>((ea&7)>>>0)|0)==0){Ca=480}else{aa=R+(_>>>3)|0;Z=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(_&7);aa=Z>>>20;O=_+12|0;c[P>>2]=da>>>0>O>>>0?O:da;if(!(Z>>>0>504365055>>>0)){Ca=aa;break}KIb(f,16,2353104,(Ba=i,i=i+8|0,c[Ba>>2]=aa,Ba)|0);i=Ba;W=-1094995529;i=l;return W|0}}while(0);b:do{if((c[u>>2]|0)!=0){da=c[F>>2]|0;do{if((da|0)>0){_=D+440|0;ea=0;do{h[z+(ea<<3)>>3]=+h[_+(ea<<3)>>3]- +h[J+(ea<<3)>>3];ea=ea+1|0;}while((ea|0)<(da|0));ea=v+256|0;_=B|0;ga=(c[D+76>>2]|0)!=0;if((da|0)!=10){Da=ea;Ea=_;Fa=ga;ua=65;break}aa=ga?123912:126472;Bhb(Q,ea);ga=c[P>>2]|0;Z=c[fa>>2]|0;O=c[N>>2]|0;na=O+(ga>>>3)|0;ja=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ga&7)>>>27;na=ga+5|0;ga=Z>>>0>na>>>0?na:Z;c[P>>2]=ga;na=O+(ga>>>3)|0;ma=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ga&7);na=ga+7|0;ga=Z>>>0>na>>>0?na:Z;c[P>>2]=ga;na=O+(ga>>>3)|0;ta=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ga&7);na=ga+6|0;ga=Z>>>0>na>>>0?na:Z;c[P>>2]=ga;na=O+(ga>>>3)|0;O=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ga&7);na=ga+6|0;c[P>>2]=Z>>>0>na>>>0?na:Z;Z=0;do{Ga=+h[v+256+(Z<<3)>>3];Ha=+h[z+(Z<<3)>>3]-Ga;h[A+(Z<<3)>>3]=Ga+Ha*+g[aa+(ja*80|0)+(Z<<2)>>2];h[A+(Z+10<<3)>>3]=Ga+Ha*+g[aa+(ja*80|0)+40+(Z<<2)>>2];Z=Z+1|0;}while((Z|0)<10);Z=ta>>>26;ja=O>>>26;mrc(B|0,0,160)|0;aa=(ma>>>25)*20|0;h[_>>3]=+(d[140088+aa|0]|0)*.0025807601174+-.3375578474429161+0.0;na=1;Ha=0.0;while(1){h[B+(na<<3)>>3]=Ha+(+(d[140088+(na+aa)|0]|0)*.0025807601174+-.3375578474429161);ga=na+1|0;if((ga|0)>=20){break}na=ga;Ha=+h[B+(ga<<3)>>3]}na=(Z*20|0)+2560|0;aa=0;do{_=B+(aa<<3)|0;h[_>>3]=+h[_>>3]+(+(d[140088+(na+aa)|0]|0)*.0012354460219+-.16558078240010365);aa=aa+1|0;}while((aa|0)<20);aa=(ja*20|0)+3840|0;na=0;while(1){Z=B+(na<<3)|0;h[Z>>3]=+h[Z>>3]+(+(d[140088+(aa+na)|0]|0)*.0011763821673+-.16221299507545536);Z=na+1|0;if((Z|0)<20){na=Z}else{Ia=ea;break}}}else{Da=v+256|0;Ea=B|0;Fa=(c[D+76>>2]|0)!=0;ua=65}}while(0);if((ua|0)==65){da=Fa?115720:119816;Chb(Q,Da);ia=c[P>>2]|0;ha=c[fa>>2]|0;ea=c[N>>2]|0;na=ea+(ia>>>3)|0;aa=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ia&7)>>>27;na=ia+5|0;ia=ha>>>0>na>>>0?na:ha;c[P>>2]=ia;na=ea+(ia>>>3)|0;ja=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ia&7);na=ia+7|0;ia=ha>>>0>na>>>0?na:ha;c[P>>2]=ia;na=ea+(ia>>>3)|0;Z=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ia&7);na=ia+7|0;ia=ha>>>0>na>>>0?na:ha;c[P>>2]=ia;na=ea+(ia>>>3)|0;ea=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ia&7);na=ia+7|0;c[P>>2]=ha>>>0>na>>>0?na:ha;ha=0;do{Ha=+h[v+256+(ha<<3)>>3];Ga=+h[z+(ha<<3)>>3]-Ha;h[A+(ha<<3)>>3]=Ha+Ga*+g[da+(aa<<7)+(ha<<2)>>2];h[A+(ha+16<<3)>>3]=Ha+Ga*+g[da+(aa<<7)+64+(ha<<2)>>2];ha=ha+1|0;}while((ha|0)<16);mrc(B|0,0,64)|0;ha=(ja>>>25)*10|0;h[Ea>>3]=+(d[135480+ha|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+8>>3]=+(d[135480+(ha|1)|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+16>>3]=+(d[ha+135482|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+24>>3]=+(d[ha+135483|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+32>>3]=+(d[ha+135484|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+40>>3]=+(d[ha+135485|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+48>>3]=+(d[ha+135486|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+56>>3]=+(d[ha+135487|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+64>>3]=+(d[ha+135488|0]|0)*.0012232979501+-.17539511784991815+0.0;h[B+72>>3]=+(d[ha+135489|0]|0)*.0012232979501+-.17539511784991815+0.0;ha=B+80|0;mrc(ha|0,0,64)|0;aa=(Z>>>25)*10|0;h[ha>>3]=+(d[134200+aa|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+88>>3]=+(d[134200+(aa|1)|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+96>>3]=+(d[aa+134202|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+104>>3]=+(d[aa+134203|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+112>>3]=+(d[aa+134204|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+120>>3]=+(d[aa+134205|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+128>>3]=+(d[aa+134206|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+136>>3]=+(d[aa+134207|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+144>>3]=+(d[aa+134208|0]|0)*.0014062241527+-.16621538411612877+0.0;h[B+152>>3]=+(d[aa+134209|0]|0)*.0014062241527+-.16621538411612877+0.0;mrc(B+160|0,0,96)|0;aa=(ea>>>25)*12|0;ha=0;while(1){da=B+(ha+20<<3)|0;h[da>>3]=+h[da>>3]+(+(d[132664+(ha+aa)|0]|0)*.0016114744851+-.1720838791930345);da=ha+1|0;if((da|0)<12){ha=da}else{Ia=Da;break}}}ha=c[F>>2]|0;do{if((ha|0)>0){aa=0;do{Ga=+h[J+(aa<<3)>>3];ea=aa<<1;h[v+(aa<<3)>>3]=Ga+(+h[A+(aa<<3)>>3]- +h[B+(ea<<3)>>3]);h[v+128+(aa<<3)>>3]=Ga+(+h[A+(ha+aa<<3)>>3]- +h[B+((ea|1)<<3)>>3]);ea=v+256+(aa<<3)|0;h[ea>>3]=Ga+ +h[ea>>3];aa=aa+1|0;}while((aa|0)<(ha|0));aa=ha-1|0;if((ha|0)>1){Ja=0}else{Ka=aa;break}while(1){ea=v+(Ja<<7)|0;Ga=+h[ea>>3];Ha=Ga>.00471238898038469?Ga:.00471238898038469;h[ea>>3]=Ha;ea=1;Ga=Ha;do{Z=v+(Ja<<7)+(ea<<3)|0;Ha=+h[Z>>3];La=Ga+.039269908169872414;Ga=Ha>La?Ha:La;h[Z>>3]=Ga;ea=ea+1|0;}while((ea|0)<(ha|0));ea=v+(Ja<<7)+(aa<<3)|0;Ga=+h[ea>>3];h[ea>>3]=Ga>3.1368802646094087?3.1368802646094087:Ga;ea=1;while(1){if((ea|0)>=(ha|0)){break}if(+h[v+(Ja<<7)+(ea<<3)>>3]<+h[v+(Ja<<7)+(ea-1<<3)>>3]){Ma=1;ua=76;break}else{ea=ea+1|0}}if((ua|0)==76){while(1){ua=0;Ga=+h[v+(Ja<<7)+(Ma<<3)>>3];ea=Ma;while(1){Z=ea-1|0;La=+h[v+(Ja<<7)+(Z<<3)>>3];if(!(La>Ga)){Na=ea;break}h[v+(Ja<<7)+(ea<<3)>>3]=La;if((Z|0)>0){ea=Z}else{Na=Z;break}}h[v+(Ja<<7)+(Na<<3)>>3]=Ga;ea=Ma+1|0;if((ea|0)<(ha|0)){Ma=ea;ua=76}else{break}}}Ja=Ja+1|0;if((Ja|0)>=3){break b}}}else{Ka=ha-1|0}}while(0);aa=v|0;La=+h[aa>>3];h[aa>>3]=La>.00471238898038469?La:.00471238898038469;aa=v+(Ka<<3)|0;La=+h[aa>>3];h[aa>>3]=La>3.1368802646094087?3.1368802646094087:La;aa=1;while(1){if((aa|0)>=(ha|0)){break}if(+h[v+(aa<<3)>>3]<+h[v+(aa-1<<3)>>3]){break}else{aa=aa+1|0}}aa=v+128|0;La=+h[aa>>3];h[aa>>3]=La>.00471238898038469?La:.00471238898038469;aa=v+128+(Ka<<3)|0;La=+h[aa>>3];h[aa>>3]=La>3.1368802646094087?3.1368802646094087:La;aa=1;while(1){if((aa|0)>=(ha|0)){break}if(+h[v+128+(aa<<3)>>3]<+h[v+128+(aa-1<<3)>>3]){break}else{aa=aa+1|0}}La=+h[Ia>>3];h[Ia>>3]=La>.00471238898038469?La:.00471238898038469;aa=v+256+(Ka<<3)|0;La=+h[aa>>3];h[aa>>3]=La>3.1368802646094087?3.1368802646094087:La;aa=1;while(1){if((aa|0)>=(ha|0)){break b}if(+h[v+256+(aa<<3)>>3]<+h[v+256+(aa-1<<3)>>3]){break}else{aa=aa+1|0}}}}while(0);aa=j+76|0;c[aa>>2]=480;ha=M4a(f,j,0)|0;if((ha|0)<0){W=ha;i=l;return W|0}c[aa>>2]=Ca;aa=c[j>>2]|0;ha=D+440|0;ea=ha;Z=f;ja=p|0;da=q|0;na=n;ia=o+88|0;_=o+92|0;ma=o+84|0;O=o|0;ta=m+4|0;ga=m;oa=ta;pa=m+14|0;Oa=m+6|0;Pa=m+8|0;Qa=m+10|0;Ra=m+12|0;Sa=o+4|0;Ta=o+44|0;Ua=o+8|0;Va=o+48|0;Wa=n|0;Xa=s|0;Ya=t|0;Za=r|0;_a=r+4|0;$a=0;c:while(1){if(($a|0)>=3){ua=249;break}d:do{if((c[u>>2]|0)==0){ab=v+($a<<7)|0;if((c[F>>2]|0)==10){Bhb(Q,ab)}else{Chb(Q,ab)}bb=c[F>>2]|0;do{if((bb|0)>0){cb=0;do{db=v+($a<<7)+(cb<<3)|0;h[db>>3]=+h[J+(cb<<3)>>3]+ +h[db>>3];cb=cb+1|0;}while((cb|0)<(bb|0));La=+h[ab>>3];Ha=La>.00471238898038469?La:.00471238898038469;h[ab>>3]=Ha;cb=(bb|0)>1;if(cb){eb=1;fb=Ha}else{gb=0;break}while(1){db=v+($a<<7)+(eb<<3)|0;Ha=+h[db>>3];La=fb+.039269908169872414;hb=Ha>La?Ha:La;h[db>>3]=hb;db=eb+1|0;if((db|0)<(bb|0)){eb=db;fb=hb}else{gb=cb;break}}}else{hb=+h[ab>>3];h[ab>>3]=hb>.00471238898038469?hb:.00471238898038469;gb=0}}while(0);ab=v+($a<<7)+(bb-1<<3)|0;hb=+h[ab>>3];h[ab>>3]=hb>3.1368802646094087?3.1368802646094087:hb;ab=1;while(1){if((ab|0)>=(bb|0)){break d}if(+h[v+($a<<7)+(ab<<3)>>3]<+h[v+($a<<7)+(ab-1<<3)>>3]){break}else{ab=ab+1|0}}if(gb){ib=1}else{break}do{hb=+h[v+($a<<7)+(ib<<3)>>3];ab=ib;while(1){cb=ab-1|0;La=+h[v+($a<<7)+(cb<<3)>>3];if(!(La>hb)){jb=ab;break}h[v+($a<<7)+(ab<<3)>>3]=La;if((cb|0)>0){ab=cb}else{jb=cb;break}}h[v+($a<<7)+(jb<<3)>>3]=hb;ib=ib+1|0;}while((ib|0)<(bb|0))}}while(0);bb=$a*160|0;ab=aa+(bb<<2)|0;if(($a|0)==0){kb=ea}else{kb=v+($a-1<<7)|0}cb=(c[K>>2]|0)+bb|0;db=(c[F>>2]|0)+bb|0;lb=x+(db<<2)|0;mb=c[C>>2]|0;nb=mb;ob=c[1510437]|0;pb=c[P>>2]|0;qb=c[fa>>2]|0;rb=c[N>>2]|0;sb=rb+(pb>>>3)|0;tb=(je(d[sb]|d[sb+1|0]<<8|d[sb+2|0]<<16|d[sb+3|0]<<24|0)|0)<<(pb&7)>>>26;sb=b[ob+(tb<<2)>>1]|0;ub=b[ob+(tb<<2)+2>>1]|0;tb=ub<<16>>16;do{if(ub<<16>>16<0){vb=pb+6|0;wb=qb>>>0>vb>>>0?vb:qb;vb=rb+(wb>>>3)|0;xb=((je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(wb&7)>>>((tb+32|0)>>>0))+sb|0;vb=b[ob+(xb<<2)>>1]|0;yb=b[ob+(xb<<2)+2>>1]|0;xb=yb<<16>>16;if(!(yb<<16>>16<0)){zb=xb;Ab=vb;Bb=wb;break}yb=wb-tb|0;wb=qb>>>0>yb>>>0?yb:qb;yb=rb+(wb>>>3)|0;Cb=((je(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(wb&7)>>>((xb+32|0)>>>0))+vb|0;zb=b[ob+(Cb<<2)+2>>1]|0;Ab=b[ob+(Cb<<2)>>1]|0;Bb=wb}else{zb=tb;Ab=sb;Bb=pb}}while(0);pb=zb+Bb|0;sb=qb>>>0>pb>>>0?pb:qb;c[P>>2]=sb;pb=a[mb+(Ab+20)|0]|0;do{if(pb<<24>>24<0){KIb(Z,16,2291056,(Ba=i,i=i+1|0,i=i+7&-8,c[Ba>>2]=0,Ba)|0);i=Ba;Db=-1094995529}else{tb=pb<<24>>24;ob=d[1210504+(tb<<3)|0]|0;ub=160/(ob>>>0)|0;wb=1210506+(tb<<3)|0;Cb=(tb-2|0)>>>0<6>>>0;if(Cb){vb=ob<<1;xb=(d[1210505+(tb<<3)|0]|0)+1|0;yb=c[mb+92>>2]|0;Eb=c[mb+100>>2]|0;Fb=rb+(sb>>>3)|0;Gb=(je(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(sb&7)>>>((32-Eb|0)>>>0);Fb=Eb+sb|0;c[P>>2]=qb>>>0>Fb>>>0?Fb:qb;Fb=Gb+yb|0;yb=(c[mb+96>>2]|0)-1|0;Gb=(Fb|0)>(yb|0)?yb:Fb;Fb=mb+568|0;if((c[mb+572>>2]|0)==0){ua=116}else{yb=c[Fb>>2]|0;Eb=Gb-yb|0;if((((Eb|0)>-1?Eb:-Eb|0)*20|0|0)>(yb+Gb|0)){ua=116}else{Hb=yb}}if((ua|0)==116){ua=0;c[Fb>>2]=Gb;Hb=Gb}Fb=0;do{yb=Fb<<1|1;c[r+(Fb<<2)>>2]=(ca(yb,Gb)|0)+ob+(ca(vb-yb|0,Hb)|0)>>xb;Fb=Fb+1|0;}while((Fb|0)<(ob|0));c[mb+576>>2]=(Gb-Hb<<16|0)/160|0;Ib=Gb}else{Ib=0}Fb=d[1210507+(tb<<3)|0]|0;do{if((Fb|0)==0){xb=c[P>>2]|0;vb=c[fa>>2]|0;yb=rb+(xb>>>3)|0;Eb=(je(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(xb&7)>>>24;yb=xb+8|0;c[P>>2]=vb>>>0>yb>>>0?yb:vb;g[mb+580>>2]=+g[130104+(Eb<<2)>>2]}else if((Fb|0)==2){Eb=mb+584|0;c[Eb>>2]=0;vb=c[P>>2]|0;yb=c[fa>>2]|0;xb=rb+(vb>>>3)|0;Jb=(je(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(vb&7);xb=Jb>>>26;Kb=vb+6|0;c[P>>2]=yb>>>0>Kb>>>0?Kb:yb;if(Jb>>>0>3623878655>>>0){c[Eb>>2]=1;Eb=c[P>>2]|0;Jb=c[fa>>2]|0;yb=rb+(Eb>>>3)|0;Kb=(je(d[yb]|d[yb+1|0]<<8|d[yb+2|0]<<16|d[yb+3|0]<<24|0)|0)<<(Eb&7)>>>30;yb=Eb+2|0;c[P>>2]=Jb>>>0>yb>>>0?yb:Jb;Lb=xb-162+(xb*3|0)+Kb|0}else{Lb=xb}xb=c[Za>>2]|0;Kb=c[_a>>2]|0;Jb=(((xb|0)>(Kb|0)?Kb:xb)|0)>32?24:16;c[mb+588>>2]=Jb;yb=b[1960752+(Lb<<1)>>1]|0;while(1){if((yb|0)<0){yb=yb+xb|0}else{break}}Eb=(xb+79-yb|0)/(xb|0)|0;c[mb+592>>2]=Eb;vb=Jb>>>1;Mb=yb-vb|0;Nb=mb+600|0;c[Nb>>2]=Mb;Ob=(ca(Eb,xb)|0)+yb|0;c[mb+596>>2]=(Kb+159-Ob|0)/(Kb|0)|0;Eb=Ob-(vb|80)|0;vb=mb+604|0;c[vb>>2]=Eb;if(!(Lb>>>0<54>>>0)){break}Ob=Eb-Kb|0;if((Ob+Jb|0)>0){Eb=Ob;while(1){Ob=Eb-Kb|0;if((Ob+Jb|0)>0){Eb=Ob}else{break}}c[vb>>2]=Eb}if(!(Lb>>>0<6>>>0)){break}Kb=Mb-xb|0;if((Kb+Jb|0)>0){Pb=Kb}else{break}while(1){Kb=Pb-xb|0;if((Kb+Jb|0)>0){Pb=Kb}else{break}}c[Nb>>2]=Pb}}while(0);Gb=d[wb]|0;Jb=(pb&255)>>>0<2>>>0;xb=pb<<24>>24==0;Mb=mb+612|0;Eb=1e3-ub|0;vb=mb+580|0;Kb=mb+616|0;yb=(ub|0)==0;Ob=mb+72|0;Qb=ub>>>0<81>>>0;Rb=ub<<2;Sb=pb<<24>>24==2;Tb=mb+584|0;Ub=mb+588|0;Vb=mb+592|0;Wb=mb+608|0;Xb=Kb;Yb=1210505+(tb<<3)|0;Zb=mb+568|0;_b=mb+576|0;$b=1210508+(tb<<3)|0;ac=mb+122|0;bc=mb+120|0;cc=mb+124|0;dc=mb+126|0;ec=mb+104|0;fc=mb+116|0;gc=mb+108|0;hc=mb+112|0;hb=+(ob|0);ic=0;jc=0;while(1){if((Gb|0)==2){kc=e[ac>>1]|0;lc=e[bc>>1]|0;mc=kc-lc<<2;nc=e[cc>>1]|0;oc=nc-kc<<1;pc=e[dc>>1]|0;qc=1-nc+pc|0;if((jc|0)==0){rc=c[ec>>2]|0;sc=c[P>>2]|0;tc=c[fa>>2]|0;uc=(c[N>>2]|0)+(sc>>>3)|0;vc=(je(d[uc]|d[uc+1|0]<<8|d[uc+2|0]<<16|d[uc+3|0]<<24|0)|0)<<(sc&7)>>>((32-rc|0)>>>0);uc=sc+rc|0;c[P>>2]=tc>>>0>uc>>>0?uc:tc;wc=vc}else{vc=ic-(c[fc>>2]|0)|0;tc=c[hc>>2]|0;uc=c[P>>2]|0;rc=c[fa>>2]|0;sc=(c[N>>2]|0)+(uc>>>3)|0;xc=(je(d[sc]|d[sc+1|0]<<8|d[sc+2|0]<<16|d[sc+3|0]<<24|0)|0)<<(uc&7)>>>((32-tc|0)>>>0);sc=uc+tc|0;c[P>>2]=rc>>>0>sc>>>0?sc:rc;wc=vc+xc|0}xc=c[fc>>2]|0;vc=(c[gc>>2]|0)-xc|0;if((wc|0)<(xc|0)){yc=xc}else{yc=(wc|0)>(vc|0)?vc:wc}do{if((wc|0)<(mc|0)){zc=wc+(lc<<2)|0}else{vc=wc-mc|0;if((vc|0)<(oc|0)){zc=(vc<<1)+(kc<<2)|0;break}xc=vc-oc|0;if((xc|0)<(qc|0)){zc=xc+nc<<2;break}else{zc=pc<<2;break}}}while(0);c[r+(jc<<2)>>2]=zc>>2;Ac=zc;Bc=yc}else if((Gb|0)==1){Ac=c[r+(jc<<2)>>2]<<2;Bc=ic}else{Ac=0;Bc=ic}pc=ca(jc,ub)|0;nc=pc+cb|0;qc=w+(nc<<2)|0;oc=x+(pc+db<<2)|0;e:do{if(Jb){if(xb){kc=(c[Mb>>2]|0)+(jc*1877|0)|0;mc=kc>>>0>65534>>>0?kc-65535|0:kc;Erc(mc,(mc|0)<0|0?-1:0,477218589,0)|0;kc=(G*-9|0)+mc|0;lc=ca(mc,c[736672+(kc<<3)>>2]|0)|0;Erc(mc,0,c[736676+(kc<<3)>>2]|0,0)|0;Cc=((G+lc&65535)>>>0)%(Eb>>>0)|0;Dc=vb}else{lc=c[P>>2]|0;kc=c[fa>>2]|0;mc=c[N>>2]|0;Nb=mc+(lc>>>3)|0;xc=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(lc&7)>>>24;Nb=lc+8|0;lc=kc>>>0>Nb>>>0?Nb:kc;c[P>>2]=lc;Nb=mc+(lc>>>3)|0;mc=(je(d[Nb]|d[Nb+1|0]<<8|d[Nb+2|0]<<16|d[Nb+3|0]<<24|0)|0)<<(lc&7)>>>26;Nb=lc+6|0;c[P>>2]=kc>>>0>Nb>>>0?Nb:kc;Cc=xc;Dc=129848+(mc<<2)|0}La=+g[Dc>>2];mrc(Kb|0,0,24)|0;if(yb){break}else{Ec=0}do{g[w+(nc+Ec<<2)>>2]=La*+g[111304+(Ec+Cc<<2)>>2];Ec=Ec+1|0;}while((Ec|0)<(ub|0))}else{if(!Qb){ua=157;break c}mrc(na|0,0,Rb|0)|0;mc=Ac>>2;c[ia>>2]=mc;g[_>>2]=1.0;c[ma>>2]=0;c[O>>2]=0;f:do{if(Sb){if((c[Tb>>2]|0)==0){Fc=0}else{Fc=((jc|0)==0)<<1}xc=12-Fc|0;kc=c[P>>2]|0;Nb=c[fa>>2]|0;lc=c[N>>2]|0;vc=lc+(kc>>>3)|0;rc=(je(d[vc]|d[vc+1|0]<<8|d[vc+2|0]<<16|d[vc+3|0]<<24|0)|0)<<(kc&7)>>>((32-xc|0)>>>0);vc=kc+xc|0;xc=Nb>>>0>vc>>>0?vc:Nb;c[P>>2]=xc;vc=(c[nb+592+(jc<<2)>>2]|0)>0;if(vc){kc=(c[Ub>>2]|0)==24;sc=kc?8:4;tc=kc?7:3;uc=kc?4:3;Gc=kc?3:4;kc=c[nb+600+(jc<<2)>>2]|0;Hc=rc;Ic=Gc;Jc=0;while(1){Kc=Ic-1|0;g[o+44+(Jc<<2)>>2]=(Hc&sc|0)!=0?-1.0:1.0;Lc=Kc+kc+(ca(Hc&tc,Gc)|0)|0;c[o+4+(c[O>>2]<<2)>>2]=Lc;Lc=c[O>>2]|0;Mc=o+4+(Lc<<2)|0;Nc=c[Mc>>2]|0;if((Nc|0)<0){Oc=Mc;Mc=Nc;while(1){c[Oc>>2]=(c[ia>>2]|0)+Mc;Pc=c[O>>2]|0;Qc=o+4+(Pc<<2)|0;Rc=c[Qc>>2]|0;if((Rc|0)<0){Oc=Qc;Mc=Rc}else{Sc=Rc;Tc=Pc;break}}}else{Sc=Nc;Tc=Lc}if((Sc|0)<80){Mc=Tc+1|0;c[O>>2]=Mc;Uc=Mc}else{Uc=Tc}if((Kc|0)>0){Hc=Hc>>uc;Ic=Kc;Jc=Uc}else{Vc=kc;Wc=Uc;break}}}else{kc=rc>>>1&255;do{if(kc>>>0<79>>>0){Xc=kc+1|0;Yc=1}else{if(kc>>>0<156>>>0){Xc=kc-76|0;Yc=3;break}if(kc>>>0<231>>>0){Xc=kc-151|0;Yc=5;break}else{Xc=kc-224|0;Yc=7;break}}}while(0);La=(rc&512|0)!=0?-1.0:1.0;c[ma>>2]=3;c[Sa>>2]=Xc-Yc;g[Ta>>2]=La;c[Ua>>2]=Xc;if((rc&1|0)==0){Zc=La}else{Zc=-0.0-La}g[Va>>2]=Zc;c[O>>2]=2;Vc=c[nb+600+(jc<<2)>>2]|0;Wc=2}do{if(vc){kc=c[Ub>>2]|0;if((kc+Vc|0)>=1){_c=Vc;break}Jc=c[ia>>2]|0;Ic=Vc;while(1){uc=Ic+Jc|0;if((uc+kc|0)<1){Ic=uc}else{_c=uc;break}}}else{_c=Vc}}while(0);rc=(c[Vb>>2]|0)>0;do{if(rc){Ic=(jc|0)==0;if(Ic|vc^1){$c=_c;ad=Ic?16:4;break}$c=c[Wb>>2]|0;ad=4}else{$c=_c;ad=8}}while(0);Ic=vc?$c-ad|0:0;c[ga>>2]=0;mrc(oa|0,-1|0,10)|0;y=0;b[pa>>1]=y;b[pa+2>>1]=y>>16;if(vc&($c|0)<80){kc=c[Ub>>2]|0;Jc=c[ia>>2]|0;Kc=$c;do{Lc=Kc>>4;Nc=m+(Lc+2<<1)|0;uc=16-(Kc&15)|0;Hc=m+(Lc+3<<1)|0;b[Nc>>1]=65535<<uc&e[Nc>>1];Nc=kc-uc|0;if((Nc|0)>15){uc=m+(Lc+4<<1)|0;b[Hc>>1]=0;b[uc>>1]=e[uc>>1]&65535>>>((Nc-16|0)>>>0)}else{b[Hc>>1]=e[Hc>>1]&65535>>>(Nc>>>0)}Kc=Kc+Jc|0;}while((Kc|0)<80)}if(rc){bd=5-(jc<<1)|0}else{bd=4}Kc=lc+(xc>>>3)|0;Jc=(je(d[Kc]|d[Kc+1|0]<<8|d[Kc+2|0]<<16|d[Kc+3|0]<<24|0)|0)<<(xc&7)>>>((32-bd|0)>>>0);Kc=bd+xc|0;kc=Nb>>>0>Kc>>>0?Kc:Nb;c[P>>2]=kc;g:do{if((Jc|0)<0){cd=0}else{Kc=c[ia>>2]|0;vc=Ic;Nc=0;Hc=0;h:while(1){if((vc|0)<0){uc=vc;while(1){Lc=uc+Kc|0;if((Lc|0)<0){uc=Lc}else{dd=Lc;break}}}else{dd=vc}if((dd|0)>79){do{if((b[ta>>1]|0)==0){if((b[Oa>>1]|0)!=0){ed=31;break}if((b[Pa>>1]|0)!=0){ed=47;break}if((b[Qa>>1]|0)!=0){ed=63;break}if((b[Ra>>1]|0)==0){break h}else{ed=79}}else{ed=15}}while(0);uc=e[m+((ed>>>4)+2<<1)>>1]|0;Lc=(uc&65280|0)==0;fd=ed-(d[1359664+(Lc?uc:uc>>>8)|0]|0)+(Lc?0:-8)|0}else{fd=dd}Lc=m+((fd>>4)+2<<1)|0;uc=e[Lc>>1]|0;Gc=32768>>>((fd&15)>>>0);if((uc&Gc|0)==0){gd=Hc;hd=Nc}else{b[Lc>>1]=(Gc^65535)&uc;gd=fd;hd=Nc+1|0}if((hd|0)>(Jc|0)){cd=gd;break g}else{vc=vc+1|0;Nc=hd;Hc=gd}}Hc=(c[Mb>>2]|0)+(jc*1877|0)|0;Nc=Hc>>>0>65534>>>0?Hc-65535|0:Hc;Erc(Nc,(Nc|0)<0|0?-1:0,477218589,0)|0;Hc=(G*-9|0)+Nc|0;vc=ca(Nc,c[736672+(Hc<<3)>>2]|0)|0;Erc(Nc,0,c[736676+(Hc<<3)>>2]|0,0)|0;Hc=((G+vc&65535)>>>0)%(Eb>>>0)|0;if(!yb){vc=0;do{g[w+(nc+vc<<2)>>2]=+g[111304+(vc+Hc<<2)>>2]*+g[vb>>2];vc=vc+1|0;}while((vc|0)<(ub|0))}vc=kc+8|0;c[P>>2]=Nb>>>0>vc>>>0?vc:Nb;break e}}while(0);c[o+4+(Wc<<2)>>2]=cd;Jc=d[lc+(kc>>>3)|0]|0;c[P>>2]=((kc|0)<(Nb|0))+kc;g[o+44+(c[O>>2]<<2)>>2]=(Jc&128>>>((kc&7)>>>0)|0)!=0?-1.0:1.0;c[O>>2]=(c[O>>2]|0)+1;Jc=c[ia>>2]|0;Ic=(80-cd|0)%(Jc|0)|0;c[Wb>>2]=(Ic|0)==0?0:Jc-Ic|0}else{Ic=5-(d[Yb]|0)|0;c[ma>>2]=-1;Jc=32-Ic|0;xc=c[N>>2]|0;rc=c[fa>>2]|0;vc=d[$b]|0;Hc=0;Nc=c[P>>2]|0;Kc=0;while(1){uc=d[xc+(Nc>>>3)|0]|0;Gc=((Nc|0)<(rc|0))+Nc|0;c[P>>2]=Gc;La=(uc&128>>>((Nc&7)>>>0)|0)!=0?1.0:-1.0;uc=xc+(Gc>>>3)|0;Lc=(je(d[uc]|d[uc+1|0]<<8|d[uc+2|0]<<16|d[uc+3|0]<<24|0)|0)<<(Gc&7)>>>(Jc>>>0);uc=Gc+Ic|0;Gc=rc>>>0>uc>>>0?uc:rc;c[P>>2]=Gc;c[o+4+(Kc<<2)>>2]=(Lc*5|0)+Hc;uc=c[O>>2]|0;c[O>>2]=uc+1;g[o+44+(uc<<2)>>2]=La;if((Hc|0)<(vc|0)){uc=xc+(Gc>>>3)|0;tc=(je(d[uc]|d[uc+1|0]<<8|d[uc+2|0]<<16|d[uc+3|0]<<24|0)|0)<<(Gc&7)>>>(Jc>>>0);uc=Gc+Ic|0;sc=rc>>>0>uc>>>0?uc:rc;c[P>>2]=sc;c[o+4+(c[O>>2]<<2)>>2]=(tc*5|0)+Hc;if((Lc|0)<(tc|0)){id=-0.0-La}else{id=La}tc=c[O>>2]|0;c[O>>2]=tc+1;g[o+44+(tc<<2)>>2]=id;jd=sc}else{jd=Gc}Gc=Hc+1|0;if((Gc|0)>=5){break f}Hc=Gc;Nc=jd;Kc=c[O>>2]|0}}}while(0);Clb(Wa,o,1.0,ub);Kc=c[P>>2]|0;Nc=c[fa>>2]|0;Hc=(c[N>>2]|0)+(Kc>>>3)|0;rc=(je(d[Hc]|d[Hc+1|0]<<8|d[Hc+2|0]<<16|d[Hc+3|0]<<24|0)|0)<<(Kc&7)>>>25;Hc=Kc+7|0;c[P>>2]=Nc>>>0>Hc>>>0?Hc:Nc;La=+pHb(Xb,522440,6)+ -5.240916164;Ga=+g[131128+(rc<<2)>>2];Ha=+$(La+Ga);La=+g[131640+(rc<<2)>>2];if((rc|0)==99){kd=-2.995732307434082}else{kd=(rc|0)==95?1.6094379425048828:Ga}rc=8>>>((d[Yb]|0)>>>0);orc(nb+616+(rc<<2)|0,Kb|0,6-rc<<2|0)|0;if((rc|0)>0){Nc=0;do{g[nb+616+(Nc<<2)>>2]=kd;Nc=Nc+1|0;}while((Nc|0)<(rc|0))}do{if(Cb){if(yb){break}else{ld=0}do{rc=ld+pc|0;Nc=c[_b>>2]|0;Hc=(ca(Nc,rc)|0)+(c[Zb>>2]<<16)|0;Kc=Hc+28671>>16;Ic=(Kc<<16)-Hc<<3;Hc=Ic+360448|0;Jc=Hc>>16;do{if((Nc|0)==0){md=ub}else{xc=(Hc-(((Nc|0)>0?Hc:Ic+425984|0)&-65536)|0)/(Nc|0)|0;vc=(xc|0)/8|0;kc=ub-ld|0;if((xc|0)<8){md=1;break}md=(vc|0)>(kc|0)?kc:vc}}while(0);Nc=rc+cb|0;klb(w+(Nc<<2)|0,w+(Nc-Kc<<2)|0,129160,17,Jc,9,md);ld=md+ld|0;}while((ld|0)<(ub|0))}else{Nc=Ac&3;if((Nc|0)==0){vJb(qc,mc<<2,Rb);break}else{klb(qc,w+(nc-mc<<2)|0,129032,4,Nc,8,ub);break}}}while(0);zlb(qc,qc,Wa,La,Ha,ub)}}while(0);nc=c[Ob>>2]|0;if((nc|0)>0){Ga=(+(jc|0)+.5)/hb;pc=0;do{nd=+h[kb+(pc<<3)>>3];h[p+(pc<<3)>>3]=+U(nd+Ga*(+h[v+($a<<7)+(pc<<3)>>3]-nd));pc=pc+1|0;}while((pc|0)<(nc|0))}CPa(ja,da,nc>>1);M3(oc,da,qc,ub,c[Ob>>2]|0);pc=jc+1|0;if((pc|0)<(ob|0)){ic=Bc;jc=pc}else{break}}if((c[mb+56>>2]|0)==0){nrc(ab|0,lb|0,640)|0}else{jc=c[Ob>>2]|0;if((jc|0)>0){ic=0;do{h[s+(ic<<3)>>3]=+U((+h[kb+(ic<<3)>>3]+ +h[v+($a<<7)+(ic<<3)>>3])*.5);ic=ic+1|0;}while((ic|0)<(jc|0))}CPa(Xa,Ya,jc>>1);ic=mb+52|0;ub=mb+6868|0;Rb=c[Za>>2]|0;Dhb(nb,lb,ab,Ya,ub+((c[ic>>2]|0)+bb<<2)|0,Fb,Rb);_b=c[Ob>>2]|0;if((_b|0)>0){yb=0;do{h[s+(yb<<3)>>3]=+U(+h[v+($a<<7)+(yb<<3)>>3]);yb=yb+1|0;}while((yb|0)<(_b|0))}CPa(Xa,Ya,_b>>1);yb=bb+80|0;Dhb(nb,x+(db+80<<2)|0,aa+(yb<<2)|0,Ya,ub+(yb+(c[ic>>2]|0)<<2)|0,Fb,Rb)}yb=c[Mb>>2]|0;Ob=yb+1|0;c[Mb>>2]=(Ob|0)>65534?yb-65534|0:Ob;c[mb+572>>2]=Gb;if((Gb|0)==0){c[Zb>>2]=0;Db=0;break}else if((Gb|0)==1){c[Zb>>2]=Ib;Db=0;break}else if((Gb|0)==2){c[Zb>>2]=c[r+(ob-1<<2)>>2];Db=0;break}else{Db=0;break}}}while(0);if((Db|0)==0){$a=$a+1|0}else{ua=248;break}}if((ua|0)==157){KIb(0,0,2240312,(Ba=i,i=i+24|0,c[Ba>>2]=2199328,c[Ba+8>>2]=2167728,c[Ba+16>>2]=1286,Ba)|0);i=Ba;Hd();return 0}else if((ua|0)==248){c[k>>2]=0;W=Db;i=l;return W|0}else if((ua|0)==249){$a=c[P>>2]|0;Ya=c[N>>2]|0;aa=d[Ya+($a>>>3)|0]|0;Xa=c[fa>>2]|0;Za=(($a|0)<(Xa|0))+$a|0;c[P>>2]=Za;if((aa&128>>>(($a&7)>>>0)|0)!=0){$a=Ya+(Za>>>3)|0;Ya=(je(d[$a]|d[$a+1|0]<<8|d[$a+2|0]<<16|d[$a+3|0]<<24|0)|0)<<(Za&7)>>>28;$a=Za+4|0;Za=(Xa>>>0>$a>>>0?$a:Xa)+10+(Ya*10|0)|0;c[P>>2]=Xa>>>0>Za>>>0?Za:Xa}c[k>>2]=1;Xa=c[F>>2]|0;nrc(ha|0,v+256|0,Xa<<3)|0;nrc(I|0,x+1920|0,Xa<<2)|0;Xa=c[K>>2]<<2;nrc(H|0,w+1920|0,Xa)|0;if((c[D+56>>2]|0)==0){W=0;i=l;return W|0}orc(D+6868|0,D+8788|0,Xa|0)|0;W=0;i=l;return W|0}}}while(0);c[k>>2]=0;W=1;i=l;return W|0}function Bhb(a,f){a=a|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0;g=i;i=i+8|0;j=g|0;k=a+8|0;l=c[k>>2]|0;m=c[a+16>>2]|0;n=c[a>>2]|0;a=n+(l>>>3)|0;o=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(l&7)>>>24;a=l+8|0;l=m>>>0>a>>>0?a:m;c[k>>2]=l;a=o&65535;b[j>>1]=a;o=n+(l>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>26;o=l+6|0;l=m>>>0>o>>>0?o:m;c[k>>2]=l;b[j+2>>1]=p;p=n+(l>>>3)|0;o=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(l&7)>>>27;p=l+5|0;l=m>>>0>p>>>0?p:m;c[k>>2]=l;b[j+4>>1]=o;o=n+(l>>>3)|0;n=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(l&7)>>>27;o=l+5|0;c[k>>2]=m>>>0>o>>>0?o:m;b[j+6>>1]=n;mrc(f|0,0,80)|0;n=0;m=145208;q=0.0;r=0.0;s=0.0;t=0.0;u=0.0;v=0.0;w=0.0;x=0.0;y=0.0;z=0.0;o=a;while(1){a=(o&65535)*10|0;A=+h[1552120+(n<<3)>>3];B=+h[1552088+(n<<3)>>3];C=q+(A+B*+(d[m+a|0]|0|0));h[f>>3]=C;D=r+(A+B*+(d[m+(a|1)|0]|0|0));h[f+8>>3]=D;E=s+(A+B*+(d[m+(a+2)|0]|0|0));h[f+16>>3]=E;F=t+(A+B*+(d[m+(a+3)|0]|0|0));h[f+24>>3]=F;G=u+(A+B*+(d[m+(a+4)|0]|0|0));h[f+32>>3]=G;H=v+(A+B*+(d[m+(a+5)|0]|0|0));h[f+40>>3]=H;I=w+(A+B*+(d[m+(a+6)|0]|0|0));h[f+48>>3]=I;J=x+(A+B*+(d[m+(a+7)|0]|0|0));h[f+56>>3]=J;K=y+(A+B*+(d[m+(a+8)|0]|0|0));h[f+64>>3]=K;L=z+(A+B*+(d[m+(a+9)|0]|0|0));h[f+72>>3]=L;a=n+1|0;if((a|0)>=4){break}k=m+((e[1552080+(n<<1)>>1]|0)*10|0)|0;n=a;m=k;q=C;r=D;s=E;t=F;u=G;v=H;w=I;x=J;y=K;z=L;o=b[j+(a<<1)>>1]|0}i=g;return}function Chb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0;e=a+8|0;f=c[e>>2]|0;g=c[a+16>>2]|0;i=c[a>>2]|0;a=i+(f>>>3)|0;j=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>24;a=f+8|0;f=g>>>0>a>>>0?a:g;c[e>>2]=f;a=i+(f>>>3)|0;k=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>26;a=f+6|0;f=g>>>0>a>>>0?a:g;c[e>>2]=f;a=i+(f>>>3)|0;l=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>25;a=f+7|0;f=g>>>0>a>>>0?a:g;c[e>>2]=f;a=i+(f>>>3)|0;m=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>26;a=f+6|0;f=g>>>0>a>>>0?a:g;c[e>>2]=f;a=i+(f>>>3)|0;i=(je(d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24|0)|0)<<(f&7)>>>25;a=f+7|0;c[e>>2]=g>>>0>a>>>0?a:g;mrc(b|0,0,24)|0;g=j*5|0;n=+(d[g+138489|0]|0|0)*.003343958628+-.40079182437437144+0.0;o=+(d[g+138490|0]|0|0)*.003343958628+-.40079182437437144+0.0;p=+(d[g+138491|0]|0|0)*.003343958628+-.40079182437437144+0.0;q=+(d[g+138492|0]|0|0)*.003343958628+-.40079182437437144+0.0;j=k*5|0;h[b>>3]=+(d[138488+g|0]|0|0)*.003343958628+-.40079182437437144+0.0+(+(d[j+139768|0]|0|0)*.00069908173703+-.07631556874100326);h[b+8>>3]=n+(+(d[j+139769|0]|0|0)*.00069908173703+-.07631556874100326);h[b+16>>3]=o+(+(d[j+139770|0]|0|0)*.00069908173703+-.07631556874100326);h[b+24>>3]=p+(+(d[j+139771|0]|0|0)*.00069908173703+-.07631556874100326);h[b+32>>3]=q+(+(d[j+139772|0]|0|0)*.00069908173703+-.07631556874100326);j=b+40|0;mrc(j|0,0,24)|0;g=l*5|0;q=+(d[g+137529|0]|0|0)*.0033216608306+-.402419169368931+0.0;p=+(d[g+137530|0]|0|0)*.0033216608306+-.402419169368931+0.0;o=+(d[g+137531|0]|0|0)*.0033216608306+-.402419169368931+0.0;n=+(d[g+137532|0]|0|0)*.0033216608306+-.402419169368931+0.0;l=m*5|0;h[j>>3]=+(d[137528+g|0]|0|0)*.0033216608306+-.402419169368931+0.0+(+(d[l+138168|0]|0|0)*.0010334960326+-.10093308877453286);h[b+48>>3]=q+(+(d[l+138169|0]|0|0)*.0010334960326+-.10093308877453286);h[b+56>>3]=p+(+(d[l+138170|0]|0|0)*.0010334960326+-.10093308877453286);h[b+64>>3]=o+(+(d[l+138171|0]|0|0)*.0010334960326+-.10093308877453286);h[b+72>>3]=n+(+(d[l+138172|0]|0|0)*.0010334960326+-.10093308877453286);l=b+80|0;mrc(l|0,0,40)|0;g=i*6|0;h[l>>3]=+(d[136760+g|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+88>>3]=+(d[136760+(g|1)|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+96>>3]=+(d[g+136762|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+104>>3]=+(d[g+136763|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+112>>3]=+(d[g+136764|0]|0|0)*.0031899104283+-.40782899191841254+0.0;h[b+120>>3]=+(d[g+136765|0]|0|0)*.0031899104283+-.40782899191841254+0.0;return}function Dhb(a,b,d,e,f,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0,H=0,I=0;k=i;i=i+352|0;l=k|0;m=k+8|0;n=k+16|0;o=k+336|0;p=k+344|0;q=a+12192|0;r=a+72|0;N3(f,e,b,80,c[r>>2]|0);do{if((h|0)>1){s=c[a+92>>2]|0;t=c[a+96>>2]|0;u=j-3|0;v=j+3|0;w=f+(-((v|0)<(t|0)?v:t)<<2)|0;t=0;v=f+(-((u|0)<(s|0)?s:u)<<2)|0;x=0.0;do{y=+pHb(f,v,80);u=y>x;x=u?y:x;t=u?v:t;v=v-4|0;}while(!(v>>>0<w>>>0));w=n|0;if(!(x>0.0)){z=f;break}y=+pHb(t,t,80);if(!(y>0.0)){z=f;break}if(x>y){A=.625}else{B=y;A=B/(x*.6+B)}v=0;while(1){B=+g[t+(v<<2)>>2];g[n+(v<<2)>>2]=B+A*(+g[f+(v<<2)>>2]-B);u=v+1|0;if((u|0)<80){v=u}else{z=w;break}}}else{z=f}}while(0);M3(q,e,z,80,c[r>>2]|0);z=c[r>>2]|0;nrc(a+12128+(16-z<<2)|0,a+12128+(96-z<<2)|0,z<<2)|0;z=(h|0)!=0;if(z){f=a+11104|0;g[m>>2]=0.0;g[f>>2]=1.0;n=a+11108|0;j=c[r>>2]|0;nrc(n|0,e|0,j<<2)|0;mrc(a+11104+(j+1<<2)|0,0,(128-j<<2)-4|0)|0;j=c[r>>2]|0;A=+pHb(e,e,j)+1.0;x=+g[e>>2];B=(x+ +pHb(e,e+4|0,j-1|0))/A*.7;nlb(m,B,f,(c[r>>2]|0)+2|0);r=a+2368|0;m=a+2452|0;re[c[m>>2]&1023](r,f);B=+g[n>>2];A=+fd(+(B*B));n=1;B=A<-15.0?-15.0:A;x=A<15.0?A:15.0;do{j=n<<1;y=+g[a+11104+(j<<2)>>2];C=+g[a+11104+((j|1)<<2)>>2];D=+fd(+(y*y+C*C));g[a+11104+(n<<2)>>2]=D;B=B>D?B:D;x=x>D?D:x;n=n+1|0;}while((n|0)<64);D=+g[f>>2];C=+fd(+(D*D));g[f>>2]=C;D=B>C?B:C;B=D-(x>C?C:x);n=a+11360|0;g[n>>2]=A;A=64.0/B;x=((h|0)==1?.38461538461538464:.3401360544217687)*B;B=x*5.863484791035423;h=a+60|0;j=0;y=C;while(1){e=a+11104+(j<<2)|0;if(((Lc(+(A*(D-y)))|0)-1|0)<0){E=0}else{E=(Lc(+(A*(D- +g[e>>2])))|0)-1|0}C=+g[149048+(c[h>>2]<<8)+(E<<2)>>2];g[e>>2]=B*C;e=~~((x*C+-.0295)*70.570526123);if((e|0)>127){g[a+11616+(j<<2)>>2]=+T(1.0331662893295288,+(+(e-127|0)))*1.07157564163208}else{g[a+11616+(j<<2)>>2]=+g[132152+(((e|0)<0?0:e)<<2)>>2]}e=j+1|0;if((e|0)>=65){break}j=e;y=+g[a+11104+(e<<2)>>2]}j=a+11616|0;re[c[a+2648>>2]&1023](a+2544|0,f);re[c[a+2760>>2]&1023](a+2656|0,f);y=+g[n>>2];f=~~y;if((f|0)<-255){F=0}else{F=(f|0)>255?510:f+255|0}g[j>>2]=+g[j>>2]*+g[a+4812+(F<<2)>>2];F=~~(y- +g[a+11356>>2]*2.0);if((F|0)<-255){G=0}else{G=(F|0)>255?510:F+255|0}x=+g[a+11872>>2];B=+g[a+4812+(G<<2)>>2];G=63;D=y;while(1){F=G-1|0;f=~~(-0.0-D- +g[a+11104+(F<<2)>>2]*2.0);if((f|0)<-255){H=0}else{H=(f|0)>255?510:f+255|0}f=a+11616+(G<<2)|0;E=G<<1;g[a+11616+((E|1)<<2)>>2]=+g[f>>2]*+g[a+2768+(H<<2)>>2];g[a+11616+(E<<2)>>2]=+g[f>>2]*+g[a+4812+(H<<2)>>2];if((F|0)==0){break}f=G-2|0;E=~~(+g[n>>2]- +g[a+11104+(f<<2)>>2]*2.0);if((E|0)<-255){I=0}else{I=(E|0)>255?510:E+255|0}E=a+11616+(F<<2)|0;h=F<<1;g[a+11616+((h|1)<<2)>>2]=+g[E>>2]*+g[a+2768+(I<<2)>>2];g[a+11616+(h<<2)>>2]=+g[E>>2]*+g[a+4812+(I<<2)>>2];G=f;D=+g[n>>2]}n=a+11620|0;g[n>>2]=x*B;G=a+2456|0;I=a+2540|0;re[c[I>>2]&1023](G,j);mrc(a+11804|0,0,324)|0;if((c[a+64>>2]|0)!=0){g[l>>2]=0.0;g[a+11800>>2]=0.0;B=+pHb(j,j,46)+1.0;x=+g[j>>2];nlb(l,(x+ +pHb(j,n,45))/B*-1.8,j,47)}B=+S(1.0/+pHb(j,j,47))*.015625;l=0;do{H=a+11616+(l<<2)|0;g[H>>2]=B*+g[H>>2];l=l+1|0;}while((l|0)<47);mrc(a+12512|0,0,192)|0;re[c[m>>2]&1023](r,q);re[c[m>>2]&1023](r,j);g[q>>2]=+g[j>>2]*+g[q>>2];j=a+12196|0;g[j>>2]=+g[n>>2]*+g[j>>2];j=1;do{n=j<<1;r=a+12128+(n+16<<2)|0;B=+g[r>>2];m=n|1;l=a+12128+(m+16<<2)|0;x=+g[l>>2];D=+g[a+11616+(n<<2)>>2];y=+g[a+11616+(m<<2)>>2];g[r>>2]=B*D-x*y;g[l>>2]=x*D+B*y;j=j+1|0;}while((j|0)<64);re[c[I>>2]&1023](G,q)}q=a+11092|0;G=c[q>>2]|0;if((G|0)!=0){I=(G|0)>80?80:G;if((I|0)>0){j=0;do{l=a+12128+(j+16<<2)|0;g[l>>2]=+g[a+10452+(j<<2)>>2]+ +g[l>>2];j=j+1|0;}while((j|0)<(I|0))}j=G-I|0;c[q>>2]=j;orc(a+10452|0,a+10772|0,j<<2|0)|0}do{if(z){j=c[q>>2]|0;I=(j|0)<47;G=I?j:47;if((G|0)>0){j=0;do{l=a+10452+(j<<2)|0;g[l>>2]=+g[a+12128+(j+96<<2)>>2]+ +g[l>>2];j=j+1|0;}while((j|0)<(G|0))}if(!I){break}nrc(a+10452+(G<<2)|0,a+12128+(G+96<<2)|0,47-G<<2)|0;c[q>>2]=47}}while(0);q=a+6856|0;y=+g[q>>2];B=0.0;D=0.0;z=0;do{B=B+ +R(+(+g[b+(z<<2)>>2]));D=D+ +R(+(+g[a+12128+(z+16<<2)>>2]));z=z+1|0;}while((z|0)<80);x=B*.009999990463256836/D;z=0;D=y;do{D=x+D*.9900000095367432;g[d+(z<<2)>>2]=D*+g[a+12128+(z+16<<2)>>2];z=z+1|0;}while((z|0)<80);g[q>>2]=D;if((c[a+68>>2]|0)<=8){i=k;return}q=o|0;g[q>>2]=-1.9999699592590332;g[o+4>>2]=1.0;o=p|0;g[o>>2]=-1.9330735206604004;g[p+4>>2]=.9358919858932495;mlb(d,d,q,o,.939805805683136,a+6860|0,80);i=k;return}function Ehb(a){a=a|0;var b=0,d=0,e=0;b=a+15300|0;Nhb(b);d=c[a+15308>>2]|0;c[a+11248>>2]=d;e=a+11184|0;M6(e,d);L6(e,a+15384|0,1246232);L6(e,a+15516|0,1246168);L6(e,a+364|0,1246664);L6(e,a+496|0,1246728);L6(e,a+628|0,1246792);L6(e,a+232|0,1246600);c[a+11176>>2]=c[a+15304>>2];c[a+11180>>2]=c[b>>2];c[a+11172>>2]=0;return}function Fhb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=a;h=a+148|0;Ghb(g,b|0,d,c[h>>2]|0,0);Ghb(g,b+128|0,d+8|0,c[h>>2]|0,1);i=c[h>>2]|0;Ghb(g,b+256|0,d+(i<<3)|0,i,2);i=c[h>>2]|0;Ghb(g,b+384|0,d+((i<<3)+8)|0,i,3);if((c[a+60>>2]&8192|0)!=0){return}i=a+152|0;Ghb(g,b+512|0,e,c[i>>2]|0,4);Ghb(g,b+640|0,f,c[i>>2]|0,5);return}function Ghb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;if(!((c[a+180+(f<<2)>>2]|0)>-1)){i=g;return}h=c[a+15328+(f<<2)>>2]|0;if((h|0)==1){B0a(d,e,b);j=a+15648+(f<<7)|0;B0a(d+(e<<2)|0,e,j);qe[c[a+10092>>2]&1023](j);i=g;return}else if((h|0)==0){ef[c[a+15300>>2]&4095](d,e,b);i=g;return}else if((h|0)==2){D0a(d,e,b);b=a+15648+(f<<7)|0;D0a(d+4|0,e,b);qe[c[a+10092>>2]&1023](b);i=g;return}else{KIb(c[a+4>>2]|0,16,2443400,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=g;return}}function Hhb(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;k=(c[a+15380>>2]|0)+((i<<1&2|h&1)<<1)|0;l=a+12476|0;m=(c[l>>2]<<4)+(h>>1)|0;n=a+12480|0;o=(c[n>>2]<<4)+(i>>1)|0;p=a+140|0;q=c[p>>2]|0;r=a+8|0;s=c[r>>2]|0;if((m|0)<-16){t=-16}else{t=(m|0)>(s|0)?s:m}m=a+12|0;u=c[m>>2]|0;if((o|0)<-16){v=-16;w=(t|0)>-16&(t|0)<(s|0)?k:k&-4;x=6}else{y=(o|0)>(u|0)?u:o;o=(t|0)>-16&(t|0)<(s|0)?k:k&-4;if((y|0)>-16&(y|0)<(u|0)){z=o;A=y}else{v=y;w=o;x=6}}if((x|0)==6){z=w&-5;A=v}v=a+148|0;w=c[v>>2]|0;o=a+152|0;y=c[o>>2]|0;u=c[f>>2]|0;k=(ca(w,A)|0)+t|0;s=u+k|0;do{if((t|0)<1|(A|0)<1){B=c[a+136>>2]|0;x=11}else{C=c[a+136>>2]|0;if((t+17|0)>=(C|0)){B=C;x=11;break}if((j+1+A|0)<(q|0)){D=0;E=s}else{B=C;x=11}}}while(0);if((x|0)==11){x=a+9944|0;Ve[c[a+11540>>2]&127](c[x>>2]|0,u+(k-1-w)|0,w,w,19,19,t-1|0,A-1|0,B,q);D=1;E=(c[x>>2]|0)+((c[v>>2]|0)+1)|0}v=a+11064+(z<<2)|0;ef[c[v>>2]&4095](b,E,w);ef[c[v>>2]&4095](b+8|0,E+8|0,w);z=w<<3;ef[c[v>>2]&4095](b+z|0,E+z|0,w);x=z+8|0;ef[c[v>>2]&4095](b+x|0,E+x|0,w);if((c[a+60>>2]&8192|0)!=0){return}if((c[a+28>>2]|0)==2){w=(h&3|0)!=0|0;F=(i&3|0)==0?w:w|2;G=h>>2;H=i>>2}else{w=(h|0)/2|0;h=(i|0)/2|0;F=h<<1&2|w&1;G=w>>1;H=h>>1}h=(c[l>>2]<<3)+G|0;G=(c[n>>2]<<3)+H|0;H=c[r>>2]>>1;if((h|0)<-8){I=-8}else{I=(h|0)>(H|0)?H:h}h=(I|0)==(H|0)?F&-2:F;F=c[m>>2]>>1;if((G|0)<-8){J=-8}else{J=(G|0)>(F|0)?F:G}G=(ca(J,y)|0)+I|0;m=(c[f+4>>2]|0)+G|0;H=(D|0)!=0;if(H){D=a+9944|0;r=c[o>>2]|0;Ve[c[a+11540>>2]&127](c[D>>2]|0,m,r,r,9,9,I,J,c[a+136>>2]>>1,c[p>>2]>>1);K=c[D>>2]|0}else{K=m}m=g+16+(((J|0)==(F|0)?h&-3:h)<<2)|0;h=j>>1;mf[c[m>>2]&2047](d,K,y,h);K=(c[f+8>>2]|0)+G|0;if(H){H=a+9944|0;G=c[o>>2]|0;Ve[c[a+11540>>2]&127](c[H>>2]|0,K,G,G,9,9,I,J,c[a+136>>2]>>1,c[p>>2]>>1);L=c[H>>2]|0}else{L=K}mf[c[m>>2]&2047](e,L,y,h);return}function Ihb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=i;do{if((c[a+108>>2]|0)==0){e=c[a+4>>2]|0;if((c[e+100>>2]|0)<4){break}f=c[e+96>>2]|0;g=(f|0)==0;h=g?8:40;j=f;k=je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0;j=g?8:16;l=k>>>16<<10&2096128;c[a+24>>2]=l;m=f+(j>>>3)|0;n=(d[m]|0)>>>7;o=g&1^1;g=o|j;c[a+15360>>2]=n;j=(g>>>0<h>>>0)+g|0;g=(d[m]|0)<<o>>>7&1;c[a+13836>>2]=g;o=((j|0)<(h|0))+j|0;m=(d[f+(j>>>3)|0]|0)<<(j&7)>>>7&1;c[a+15320>>2]=m;j=((o|0)<(h|0))+o|0;p=(d[f+(o>>>3)|0]|0)<<(o&7)>>>7&1;c[a+15312>>2]=p;o=((j|0)<(h|0))+j|0;q=(d[f+(j>>>3)|0]|0)<<(j&7)>>>7&1;c[a+15368>>2]=q;j=((o|0)<(h|0))+o|0;h=(d[f+(o>>>3)|0]|0)<<(o&7)>>>7&1;c[a+15372>>2]=h;o=f+(j>>>3)|0;f=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(j&7)>>>29;if((f|0)==0){break}c[a+14080>>2]=(c[a+120>>2]|0)/(f|0)|0;if((c[e+688>>2]&1|0)==0){break}KIb(e,48,2635368,(r=i,i=i+80|0,c[r>>2]=k>>>27,c[r+8>>2]=l,c[r+16>>2]=n,c[r+24>>2]=m,c[r+32>>2]=p,c[r+40>>2]=q,c[r+48>>2]=h,c[r+56>>2]=f,c[r+64>>2]=g,c[r+72>>2]=f,r)|0);i=r}}while(0);f=a+14128|0;g=c[f>>2]|0;h=a+14120|0;q=c[h>>2]|0;p=(d[q+(g>>>3)|0]|0)<<(g&7)>>>7;m=a+14136|0;n=c[m>>2]|0;l=((g|0)<(n|0))+g|0;c[f>>2]=l;g=p&1;c[a+9992>>2]=g+1;if((g|0)!=0){s=l;t=n;u=q;v=s>>>3;w=u+v|0;x=w;y=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;z=je(y|0)|0;A=s&7;B=z<<A;C=B>>>27;D=s+5|0;E=t>>>0>D>>>0;F=E?D:t;c[f>>2]=F;G=a+9960|0;c[G>>2]=C;H=a+9964|0;c[H>>2]=C;I=(C|0)==0;J=I<<31>>31;i=b;return J|0}g=q+(l>>>3)|0;q=(je(d[g]|d[g+1|0]<<8|d[g+2|0]<<16|d[g+3|0]<<24|0)|0)<<(l&7)>>>25;g=l+7|0;c[f>>2]=n>>>0>g>>>0?g:n;KIb(c[a+4>>2]|0,48,2443280,(r=i,i=i+8|0,c[r>>2]=q,r)|0);i=r;s=c[f>>2]|0;t=c[m>>2]|0;u=c[h>>2]|0;v=s>>>3;w=u+v|0;x=w;y=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;z=je(y|0)|0;A=s&7;B=z<<A;C=B>>>27;D=s+5|0;E=t>>>0>D>>>0;F=E?D:t;c[f>>2]=F;G=a+9960|0;c[G>>2]=C;H=a+9964|0;c[H>>2]=C;I=(C|0)==0;J=I<<31>>31;i=b;return J|0}function Jhb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;b=i;do{if((c[a+9992>>2]|0)==1){if((c[a+15312>>2]|0)==0){c[a+15316>>2]=0;e=5}else{f=a+14128|0;g=c[f>>2]|0;h=(d[(c[a+14120>>2]|0)+(g>>>3)|0]|0)<<(g&7)>>>7;c[f>>2]=((g|0)<(c[a+14136>>2]|0))+g;g=h&1;c[a+15316>>2]=g;if((g|0)==0){e=5}else{j=g}}if((e|0)==5){do{if((c[a+15372>>2]|0)==0){c[a+14096>>2]=0;e=9}else{g=a+14128|0;h=c[g>>2]|0;f=(d[(c[a+14120>>2]|0)+(h>>>3)|0]|0)<<(h&7)>>>7;c[g>>2]=((h|0)<(c[a+14136>>2]|0))+h;h=f&1;c[a+14096>>2]=h;if((h|0)==0){e=9;break}k=c[a+14128>>2]|0;l=c[a+14120>>2]|0;m=c[a+14136>>2]|0}}while(0);if((e|0)==9){h=a+14128|0;f=c[h>>2]|0;g=c[a+14120>>2]|0;n=d[g+(f>>>3)|0]|0;o=c[a+14136>>2]|0;p=((f|0)<(o|0))+f|0;c[h>>2]=p;if((n&128>>>((f&7)>>>0)|0)==0){q=0;r=p}else{f=(d[g+(p>>>3)|0]|0)<<(p&7)>>>7;n=((p|0)<(o|0))+p|0;c[h>>2]=n;q=(f&1)+1|0;r=n}c[a+14068>>2]=q;n=d[g+(r>>>3)|0]|0;f=((r|0)<(o|0))+r|0;c[h>>2]=f;if((n&128>>>((r&7)>>>0)|0)==0){s=0;t=f}else{n=(d[g+(f>>>3)|0]|0)<<(f&7)>>>7;p=((f|0)<(o|0))+f|0;c[h>>2]=p;s=(n&1)+1|0;t=p}c[a+14064>>2]=s;k=t;l=g;m=o}o=(d[l+(k>>>3)|0]|0)<<(k&7)>>>7;c[a+14128>>2]=((k|0)<(m|0))+k;c[a+14072>>2]=o&1;j=0}c[a+14112>>2]=0;c[a+12472>>2]=1;o=c[a+4>>2]|0;if((c[o+688>>2]&1|0)==0){break}g=c[a+14068>>2]|0;p=c[a+14064>>2]|0;n=c[a+14072>>2]|0;h=c[a+14096>>2]|0;KIb(o,48,2586192,(u=i,i=i+48|0,c[u>>2]=c[a+9960>>2],c[u+8>>2]=g,c[u+16>>2]=p,c[u+24>>2]=n,c[u+32>>2]=h,c[u+40>>2]=j,u)|0);i=u}else{c[a+15316>>2]=0;h=c[(c[a+9856>>2]|0)+1536>>2]|0;n=a+14128|0;p=c[n>>2]|0;g=a+14136|0;o=c[g>>2]|0;f=c[a+14120>>2]|0;v=f+(p>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(p&7)>>>30;v=p+2|0;p=o>>>0>v>>>0?v:o;c[n>>2]=p;c[a+15376>>2]=w;a:do{if((w|0)==2){v=a+120|0;if((c[v>>2]|0)<=0){break}x=a+116|0;y=a+124|0;z=0;A=p;B=o;C=c[x>>2]|0;while(1){D=d[f+(A>>>3)|0]|0;E=((A|0)<(B|0))+A|0;c[n>>2]=E;F=(C|0)>0;b:do{if((D&128>>>((A&7)>>>0)|0)==0){if(F){G=0;H=E;I=B}else{J=C;break}while(1){K=(d[f+(H>>>3)|0]|0)<<(H&7);c[n>>2]=((H|0)<(I|0))+H;c[h+((ca(c[y>>2]|0,z)|0)+G<<2)>>2]=K<<4&2048|12296;K=G+1|0;L=c[x>>2]|0;if((K|0)>=(L|0)){J=L;break b}G=K;H=c[n>>2]|0;I=c[g>>2]|0}}else{if(F){M=0}else{J=C;break}while(1){c[h+((ca(c[y>>2]|0,z)|0)+M<<2)>>2]=14344;K=M+1|0;L=c[x>>2]|0;if((K|0)<(L|0)){M=K}else{J=L;break}}}}while(0);F=z+1|0;if((F|0)>=(c[v>>2]|0)){break a}z=F;A=c[n>>2]|0;B=c[g>>2]|0;C=J}}else if((w|0)==3){C=a+116|0;if((c[C>>2]|0)<=0){break}B=a+120|0;A=a+124|0;z=0;v=p;x=o;y=c[B>>2]|0;while(1){F=d[f+(v>>>3)|0]|0;E=((v|0)<(x|0))+v|0;c[n>>2]=E;D=(y|0)>0;c:do{if((F&128>>>((v&7)>>>0)|0)==0){if(D){N=0;O=E;P=x}else{Q=y;break}while(1){L=(d[f+(O>>>3)|0]|0)<<(O&7);c[n>>2]=((O|0)<(P|0))+O;c[h+((ca(c[A>>2]|0,N)|0)+z<<2)>>2]=L<<4&2048|12296;L=N+1|0;K=c[B>>2]|0;if((L|0)>=(K|0)){Q=K;break c}N=L;O=c[n>>2]|0;P=c[g>>2]|0}}else{if(D){R=0}else{Q=y;break}while(1){c[h+((ca(c[A>>2]|0,R)|0)+z<<2)>>2]=14344;L=R+1|0;K=c[B>>2]|0;if((L|0)<(K|0)){R=L}else{Q=K;break}}}}while(0);D=z+1|0;if((D|0)>=(c[C>>2]|0)){break a}z=D;v=c[n>>2]|0;x=c[g>>2]|0;y=Q}}else if((w|0)==1){y=a+120|0;x=c[y>>2]|0;if((x|0)<=0){break}v=a+116|0;z=a+124|0;C=0;B=c[v>>2]|0;A=x;while(1){if((B|0)>0){x=0;do{D=c[n>>2]|0;E=(d[f+(D>>>3)|0]|0)<<(D&7);c[n>>2]=((D|0)<(c[g>>2]|0))+D;c[h+((ca(c[z>>2]|0,C)|0)+x<<2)>>2]=E<<4&2048|12296;x=x+1|0;S=c[v>>2]|0;}while((x|0)<(S|0));T=S;U=c[y>>2]|0}else{T=B;U=A}x=C+1|0;if((x|0)<(U|0)){C=x;B=T;A=U}else{break}}}else if((w|0)==0){A=a+120|0;B=c[A>>2]|0;if((B|0)<=0){break}C=a+116|0;y=a+124|0;v=0;z=c[C>>2]|0;x=B;while(1){if((z|0)>0){B=0;do{c[h+((ca(c[y>>2]|0,v)|0)+B<<2)>>2]=12296;B=B+1|0;V=c[C>>2]|0;}while((B|0)<(V|0));W=V;X=c[A>>2]|0}else{W=z;X=x}B=v+1|0;if((B|0)<(X|0)){v=B;z=W;x=X}else{break}}}}while(0);h=c[n>>2]|0;w=d[f+(h>>>3)|0]|0;o=c[g>>2]|0;p=((h|0)<(o|0))+h|0;c[n>>2]=p;if((w&128>>>((h&7)>>>0)|0)==0){Y=0;Z=p}else{h=(d[f+(p>>>3)|0]|0)<<(p&7)>>>7;w=((p|0)<(o|0))+p|0;c[n>>2]=w;Y=(h&1)+1|0;Z=w}w=c[a+9960>>2]|0;do{if((w|0)<11){h=c[1246552+(Y<<2)>>2]|0;c[a+15364>>2]=h;_=h}else{if((w|0)<21){h=c[1246536+(Y<<2)>>2]|0;c[a+15364>>2]=h;_=h;break}else{h=c[1246520+(Y<<2)>>2]|0;c[a+15364>>2]=h;_=h;break}}}while(0);if((c[a+15360>>2]|0)==0){c[a+14116>>2]=0;$=Z;aa=0}else{g=(d[f+(Z>>>3)|0]|0)<<(Z&7)>>>7;h=((Z|0)<(o|0))+Z|0;c[n>>2]=h;p=g&1;c[a+14116>>2]=p;$=h;aa=p}do{if((c[a+15320>>2]|0)==0){ba=$}else{p=(d[f+($>>>3)|0]|0)<<($&7)>>>7;h=(($|0)<(o|0))+$|0;c[n>>2]=h;g=p&1;c[a+15352>>2]=g^1;if((g|0)==0){ba=h;break}g=d[f+(h>>>3)|0]|0;p=((h|0)<(o|0))+h|0;c[n>>2]=p;if((g&128>>>((h&7)>>>0)|0)==0){da=0;ea=p}else{h=(d[f+(p>>>3)|0]|0)<<(p&7)>>>7;g=((p|0)<(o|0))+p|0;c[n>>2]=g;da=(h&1)+1|0;ea=g}c[a+15324>>2]=da;ba=ea}}while(0);if((c[a+15372>>2]|0)==0){c[a+14096>>2]=0;fa=ba;e=68}else{g=(d[f+(ba>>>3)|0]|0)<<(ba&7)>>>7;h=((ba|0)<(o|0))+ba|0;c[n>>2]=h;p=g&1;c[a+14096>>2]=p;if((p|0)==0){fa=h;e=68}else{ga=h;ha=p}}if((e|0)==68){p=d[f+(fa>>>3)|0]|0;h=((fa|0)<(o|0))+fa|0;c[n>>2]=h;if((p&128>>>((fa&7)>>>0)|0)==0){ia=0;ja=h}else{p=(d[f+(h>>>3)|0]|0)<<(h&7)>>>7;g=((h|0)<(o|0))+h|0;c[n>>2]=g;ia=(p&1)+1|0;ja=g}c[a+14064>>2]=ia;c[a+14068>>2]=ia;ga=ja;ha=0}g=(d[f+(ga>>>3)|0]|0)<<(ga&7)>>>7;p=((ga|0)<(o|0))+ga|0;c[n>>2]=p;h=g&1;c[a+14072>>2]=h;g=(d[f+(p>>>3)|0]|0)<<(p&7)>>>7;c[n>>2]=((p|0)<(o|0))+p;p=g&1;c[a+14060>>2]=p;c[a+14112>>2]=0;g=a+12472|0;c[g>>2]=c[g>>2]^1;g=c[a+4>>2]|0;if((c[g+688>>2]&1|0)==0){break}x=c[a+14068>>2]|0;z=c[a+15352>>2]|0;v=c[a+15324>>2]|0;KIb(g,48,2290944,(u=i,i=i+88|0,c[u>>2]=c[a+14064>>2],c[u+8>>2]=x,c[u+16>>2]=h,c[u+24>>2]=p,c[u+32>>2]=ha,c[u+40>>2]=w,c[u+48>>2]=aa,c[u+56>>2]=z,c[u+64>>2]=v,c[u+72>>2]=_,c[u+80>>2]=0,u)|0);i=u}}while(0);c[a+14100>>2]=0;c[a+14104>>2]=0;u=a+108|0;c[u>>2]=(c[u>>2]|0)+1;if((c[a+15316>>2]|0)==0){ka=0;i=b;return ka|0}u=c[a+9960>>2]|0;aqb(a+14672|0,u<<1,u-1|1)|0;ka=1;i=b;return ka|0}function Khb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=e;if((c[e+15316>>2]|0)!=0){m=0;i=g;return m|0}do{if((c[e+9992>>2]|0)==2){n=ca(c[e+124>>2]|0,c[e+12480>>2]|0)|0;if((c[(c[e+9160>>2]|0)+(n+(c[e+12476>>2]|0)<<2)>>2]&2048|0)!=0){c[e+12488>>2]=0;mrc(e+180|0,-1|0,24)|0;c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11744>>2]=0;c[e+11748>>2]=0;c[e+9924>>2]=1;c[e+15380>>2]=0;m=0;i=g;return m|0}n=c[7696524+((c[e+15364>>2]|0)*20|0)>>2]|0;o=e+14128|0;p=c[o>>2]|0;q=c[e+14136>>2]|0;r=c[e+14120>>2]|0;s=r+(p>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(p&7)>>>23;s=b[n+(t<<2)>>1]|0;u=b[n+(t<<2)+2>>1]|0;t=u<<16>>16;do{if(u<<16>>16<0){v=p+9|0;w=q>>>0>v>>>0?v:q;v=r+(w>>>3)|0;x=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(w&7)>>>((t+32|0)>>>0))+s|0;v=b[n+(x<<2)>>1]|0;y=b[n+(x<<2)+2>>1]|0;x=y<<16>>16;if(!(y<<16>>16<0)){z=x;A=v;B=w;break}y=w-t|0;w=q>>>0>y>>>0?y:q;y=r+(w>>>3)|0;C=((je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(w&7)>>>((x+32|0)>>>0))+v|0;z=b[n+(C<<2)+2>>1]|0;A=b[n+(C<<2)>>1]|0;B=w}else{z=t;A=s;B=p}}while(0);p=z+B|0;c[o>>2]=q>>>0>p>>>0?p:q;if((A|0)<0){m=-1;i=g;return m|0}else{p=A>>>6&1^1;c[e+12488>>2]=p;D=A&63;E=p;break}}else{p=e+12488|0;c[p>>2]=1;s=c[1825693]|0;t=e+14128|0;n=c[t>>2]|0;r=c[e+14136>>2]|0;u=c[e+14120>>2]|0;w=u+(n>>>3)|0;C=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(n&7)>>>23;w=b[s+(C<<2)>>1]|0;v=b[s+(C<<2)+2>>1]|0;C=v<<16>>16;if(v<<16>>16<0){v=n+9|0;x=r>>>0>v>>>0?v:r;v=u+(x>>>3)|0;u=((je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(x&7)>>>((C+32|0)>>>0))+w|0;F=b[s+(u<<2)+2>>1]|0;G=b[s+(u<<2)>>1]|0;H=x}else{F=C;G=w;H=n}n=F+H|0;c[t>>2]=r>>>0>n>>>0?n:r;if((G|0)>=0){r=(Drb(e,0,h)|0)^G>>>5&1;a[c[h>>2]|0]=r;n=(Drb(e,1,h)|0)^G>>>4&1;a[c[h>>2]|0]=n;t=(Drb(e,2,h)|0)^G>>>3&1;a[c[h>>2]|0]=t;w=(Drb(e,3,h)|0)^G>>>2&1;a[c[h>>2]|0]=w;D=G&1|(G&2|(w<<2|(t<<3|(n<<4|r<<5))));E=c[p>>2]|0;break}p=c[e+12480>>2]|0;KIb(c[e+4>>2]|0,16,2240248,(I=i,i=i+16|0,c[I>>2]=c[e+12476>>2],c[I+8>>2]=p,I)|0);i=I;m=-1;i=g;return m|0}}while(0);if((E|0)!=0){E=e+14128|0;G=c[E>>2]|0;h=c[e+14120>>2]|0;H=d[h+(G>>>3)|0]<<(G&7)>>>7;F=c[e+14136>>2]|0;A=((G|0)<(F|0))+G|0;c[E>>2]=A;c[e+176>>2]=H&1;if((c[e+14112>>2]|0)==0){J=A}else{H=c[2055613]|0;G=h+(A>>>3)|0;B=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(A&7)>>>29;G=b[H+(B<<2)>>1]|0;z=(b[H+(B<<2)+2>>1]|0)+A|0;A=F>>>0>z>>>0?z:F;c[E>>2]=A;c[e+13820>>2]=G;J=A}if(!((c[e+14096>>2]|0)==0|(D|0)==0)){A=d[h+(J>>>3)|0]|0;G=((J|0)<(F|0))+J|0;c[E>>2]=G;if((A&128>>>((J&7)>>>0)|0)==0){K=0}else{J=d[h+(G>>>3)|0]<<(G&7)>>>7;c[E>>2]=((G|0)<(F|0))+G;K=(J&1)+1|0}c[e+14064>>2]=K;c[e+14068>>2]=K}qe[c[e+10096>>2]&1023](c[e+14340>>2]|0);K=0;while(1){if((K|0)>=6){m=0;L=82;break}if((JUa(e,f+(K<<7)|0,K,D>>>((5-K|0)>>>0)&1,0)|0)<0){break}else{K=K+1|0}}if((L|0)==82){i=g;return m|0}J=c[e+12480>>2]|0;KIb(c[e+4>>2]|0,16,2167672,(I=i,i=i+24|0,c[I>>2]=c[e+12476>>2],c[I+8>>2]=J,c[I+16>>2]=K,I)|0);i=I;m=-1;i=g;return m|0}K=c[e+128>>2]|0;J=c[e+12496>>2]|0;G=c[e+9148>>2]|0;F=J-1|0;E=G+(F<<2)|0;h=J-K|0;A=G+(h<<2)|0;z=2-K+J|0;J=G+(z<<2)|0;K=e+12476|0;B=(c[e+14084>>2]|0)==0;a:do{if((c[K>>2]|0)==0){H=b[E>>1]|0;p=H<<16>>16;if(B){M=H;N=p;L=27}else{O=p;L=26}}else{if(!B){O=b[E>>1]|0;L=26;break}do{if((c[e+14116>>2]|0)==0){if((c[e+15368>>2]|0)==0){break}p=b[E>>1]|0;H=b[A>>1]|0;r=p-H|0;n=(r|0)>-1?r:-r|0;r=b[G+(F<<2)+2>>1]|0;t=b[G+(h<<2)+2>>1]|0;w=r-t|0;C=(w|0)>-1?w:-w|0;if((((n|0)>(C|0)?n:C)|0)<=7){break}C=e+14128|0;n=c[C>>2]|0;w=d[(c[e+14120>>2]|0)+(n>>>3)|0]<<(n&7)>>>7;c[C>>2]=((n|0)<(c[e+14136>>2]|0))+n;n=w&1;if((n|0)==0){c[j>>2]=p;c[k>>2]=r;break a}else if((n|0)==1){c[j>>2]=H;c[k>>2]=t;break a}else{break}}}while(0);q=b[E>>1]|0;M=q;N=q<<16>>16;L=27}}while(0);if((L|0)==26){c[j>>2]=O;c[k>>2]=b[G+(F<<2)+2>>1]|0}else if((L|0)==27){O=b[A>>1]|0;A=O<<16>>16;E=b[J>>1]|0;J=E<<16>>16;do{if(M<<16>>16>O<<16>>16){if(!(E<<16>>16>O<<16>>16)){P=A;break}P=(J|0)>(N|0)?N:J}else{if(!(O<<16>>16>E<<16>>16)){P=A;break}P=(J|0)>(N|0)?J:N}}while(0);c[j>>2]=P;P=b[G+(F<<2)+2>>1]|0;F=P<<16>>16;N=b[G+(h<<2)+2>>1]|0;h=N<<16>>16;J=b[G+(z<<2)+2>>1]|0;z=J<<16>>16;do{if(P<<16>>16>N<<16>>16){if(!(J<<16>>16>N<<16>>16)){Q=h;break}Q=(z|0)>(F|0)?F:z}else{if(!(N<<16>>16>J<<16>>16)){Q=h;break}Q=(z|0)>(F|0)?z:F}}while(0);c[k>>2]=Q}b:do{if((D|0)!=0){qe[c[e+10096>>2]&1023](c[e+14340>>2]|0);if((c[e+14096>>2]|0)!=0){Q=e+14128|0;F=c[Q>>2]|0;z=c[e+14120>>2]|0;h=d[z+(F>>>3)|0]|0;J=c[e+14136>>2]|0;N=((F|0)<(J|0))+F|0;c[Q>>2]=N;if((h&128>>>((F&7)>>>0)|0)==0){R=0}else{F=d[z+(N>>>3)|0]<<(N&7)>>>7;c[Q>>2]=((N|0)<(J|0))+N;R=(F&1)+1|0}c[e+14064>>2]=R;c[e+14068>>2]=R}do{if((c[e+15320>>2]|0)!=0){if((c[e+15352>>2]|0)==0){break}F=e+14128|0;N=c[F>>2]|0;J=c[e+14120>>2]|0;Q=d[J+(N>>>3)|0]<<(N&7)>>>7;z=c[e+14136>>2]|0;h=((N|0)<(z|0))+N|0;c[F>>2]=h;N=Q&1;c[e+15356>>2]=N;if((N|0)!=0){break b}N=d[J+(h>>>3)|0]|0;Q=((h|0)<(z|0))+h|0;c[F>>2]=Q;if((N&128>>>((h&7)>>>0)|0)==0){S=0}else{h=d[J+(Q>>>3)|0]<<(Q&7)>>>7;c[F>>2]=((Q|0)<(z|0))+Q;S=(h&1)+1|0}c[e+15324>>2]=S;break b}}while(0);c[e+15356>>2]=0}}while(0);if((KUa(e,j,k)|0)<0){m=-1;i=g;return m|0}S=c[j>>2]|0;j=c[k>>2]|0;do{if(((j|S)&1|0)==0){L=54}else{if((c[e+14116>>2]|0)==0){L=54;break}k=e+14128|0;R=c[k>>2]|0;h=e+14120|0;Q=d[(c[h>>2]|0)+(R>>>3)|0]<<(R&7)>>>7;z=e+14136|0;c[k>>2]=((R|0)<(c[z>>2]|0))+R;c[e+15380>>2]=Q&1;T=k;U=h;V=z}}while(0);if((L|0)==54){c[e+15380>>2]=0;T=e+14128|0;U=e+14120|0;V=e+14136|0}c[e+11736>>2]=1;c[e+11740>>2]=0;c[e+11744>>2]=S;c[e+11748>>2]=j;j=e+15356|0;S=e+15324|0;z=e+236|0;h=0;c:while(1){k=f+(h<<7)|0;do{if((1<<5-h&D|0)==0){c[l+180+(h<<2)>>2]=-1}else{if((c[j>>2]|0)==0){W=c[S>>2]|0}else{Q=c[T>>2]|0;R=c[U>>2]|0;F=d[R+(Q>>>3)|0]|0;J=c[V>>2]|0;N=((Q|0)<(J|0))+Q|0;c[T>>2]=N;if((F&128>>>((Q&7)>>>0)|0)==0){X=0}else{Q=d[R+(N>>>3)|0]<<(N&7)>>>7;c[T>>2]=((N|0)<(J|0))+N;X=(Q&1)+1|0}c[S>>2]=X;W=X}c[l+15328+(h<<2)>>2]=W;Q=c[S>>2]|0;if((Q|0)==0){if((JUa(e,k,h,1,z)|0)<0){break c}else{break}}N=c[l+15384+((Q-1|0)*132|0)>>2]|0;Q=c[T>>2]|0;J=c[U>>2]|0;R=d[J+(Q>>>3)|0]|0;F=c[V>>2]|0;P=((Q|0)<(F|0))+Q|0;c[T>>2]=P;if((R&128>>>((Q&7)>>>0)|0)==0){L=67}else{Q=a[J+(P>>>3)|0]|0;c[T>>2]=((P|0)<(F|0))+P;if((JUa(e,k,h,1,N)|0)<0){break c}if((((Q&255)<<(P&7)>>>7&1)+1|0)>>>0<2>>>0){L=67}}if((L|0)==67){L=0;if((JUa(e,l+15648+(h<<7)|0,h,1,N)|0)<0){break c}}c[l+180+(h<<2)>>2]=63}}while(0);k=h+1|0;if((k|0)<6){h=k}else{m=0;L=82;break}}if((L|0)==82){i=g;return m|0}L=c[e+12480>>2]|0;KIb(c[e+4>>2]|0,16,2199272,(I=i,i=i+24|0,c[I>>2]=c[K>>2],c[I+8>>2]=L,c[I+16>>2]=h,I)|0);i=I;m=-1;i=g;return m|0}function Lhb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;d=a+88|0;c[d>>2]=c[d>>2]|16384;if((EUa(a)|0)<0){e=-1;return e|0}Ehb(b);_pb(b+14672|0,b);e=0;return e|0}function Mhb(a){a=a|0;$pb((c[a+60>>2]|0)+14672|0);return Wga(a)|0}function Nhb(a){a=a|0;c[a>>2]=2290;c[a+4>>2]=2064;c[a+8>>2]=1;return}function Ohb(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;Qhb(f);Qhb(f+16|0);Qhb(f+32|0);Qhb(f+48|0);Qhb(f+64|0);Qhb(f+80|0);Qhb(f+96|0);Qhb(f+112|0);Rhb(f);Rhb(f+2|0);Rhb(f+4|0);Rhb(f+6|0);Rhb(f+8|0);Rhb(f+10|0);Rhb(f+12|0);Rhb(f+14|0);g=c;c=f;f=0;while(1){h=(b[c>>1]|0)+(d[g]|0)|0;if(h>>>0>255>>>0){i=-h>>31&255}else{i=h&255}a[g]=i;h=g+1|0;j=(b[c+2>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){k=-j>>31&255}else{k=j&255}a[h]=k;h=g+2|0;j=(b[c+4>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){l=-j>>31&255}else{l=j&255}a[h]=l;h=g+3|0;j=(b[c+6>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){m=-j>>31&255}else{m=j&255}a[h]=m;h=g+4|0;j=(b[c+8>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){n=-j>>31&255}else{n=j&255}a[h]=n;h=g+5|0;j=(b[c+10>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){o=-j>>31&255}else{o=j&255}a[h]=o;h=g+6|0;j=(b[c+12>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){p=-j>>31&255}else{p=j&255}a[h]=p;h=g+7|0;j=(b[c+14>>1]|0)+(d[h]|0)|0;if(j>>>0>255>>>0){q=-j>>31&255}else{q=j&255}a[h]=q;h=f+1|0;if((h|0)<8){g=g+e|0;c=c+16|0;f=h}else{break}}return}function Phb(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;Qhb(e);Qhb(e+16|0);Qhb(e+32|0);Qhb(e+48|0);Qhb(e+64|0);Qhb(e+80|0);Qhb(e+96|0);Qhb(e+112|0);Rhb(e);Rhb(e+2|0);Rhb(e+4|0);Rhb(e+6|0);Rhb(e+8|0);Rhb(e+10|0);Rhb(e+12|0);Rhb(e+14|0);f=c;c=e;e=0;while(1){g=b[c>>1]|0;if((g&65535)>>>0>255>>>0){h=-(g<<16>>16)>>31&255}else{h=g&255}a[f]=h;g=b[c+2>>1]|0;if((g&65535)>>>0>255>>>0){i=-(g<<16>>16)>>31&255}else{i=g&255}a[f+1|0]=i;g=b[c+4>>1]|0;if((g&65535)>>>0>255>>>0){j=-(g<<16>>16)>>31&255}else{j=g&255}a[f+2|0]=j;g=b[c+6>>1]|0;if((g&65535)>>>0>255>>>0){k=-(g<<16>>16)>>31&255}else{k=g&255}a[f+3|0]=k;g=b[c+8>>1]|0;if((g&65535)>>>0>255>>>0){l=-(g<<16>>16)>>31&255}else{l=g&255}a[f+4|0]=l;g=b[c+10>>1]|0;if((g&65535)>>>0>255>>>0){m=-(g<<16>>16)>>31&255}else{m=g&255}a[f+5|0]=m;g=b[c+12>>1]|0;if((g&65535)>>>0>255>>>0){n=-(g<<16>>16)>>31&255}else{n=g&255}a[f+6|0]=n;g=b[c+14>>1]|0;if((g&65535)>>>0>255>>>0){o=-(g<<16>>16)>>31&255}else{o=g&255}a[f+7|0]=o;g=e+1|0;if((g|0)<8){f=f+d|0;c=c+16|0;e=g}else{break}}return}function Qhb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=a+2|0;d=b[c>>1]|0;e=a+14|0;f=b[e>>1]|0;g=(f*565|0)+(d*2841|0)|0;h=(f*-2841|0)+(d*565|0)|0;d=a+10|0;f=b[d>>1]|0;i=a+6|0;j=b[i>>1]|0;k=(j*2408|0)+(f*1609|0)|0;l=(j*-1609|0)+(f*2408|0)|0;f=a+4|0;j=b[f>>1]|0;m=a+12|0;n=b[m>>1]|0;o=(n*1108|0)+(j*2676|0)|0;p=(n*-2676|0)+(j*1108|0)|0;j=b[a>>1]<<11;n=a+8|0;q=b[n>>1]<<11;r=q+j|0;s=j-q|0;q=g-k|0;j=((h-l+q|0)*181|0)+128>>8;t=((l-h+q|0)*181|0)+128>>8;q=r+o|0;b[a>>1]=(g+128+k+q|0)>>>8;a=s+p|0;b[c>>1]=(j+128+a|0)>>>8;c=s-p|0;b[f>>1]=(t+128+c|0)>>>8;f=r-o|0;b[i>>1]=(h+128+l+f|0)>>>8;b[n>>1]=(128-h-l+f|0)>>>8;b[d>>1]=(128-t+c|0)>>>8;b[m>>1]=(128-j+a|0)>>>8;b[e>>1]=(128-g-k+q|0)>>>8;return}function Rhb(a){a=a|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=a+16|0;d=b[c>>1]|0;e=a+112|0;f=b[e>>1]|0;g=(d*2841|0)+4+(f*565|0)>>3;h=(d*565|0)+4+(f*-2841|0)>>3;f=a+80|0;d=b[f>>1]|0;i=a+48|0;j=b[i>>1]|0;k=(d*1609|0)+4+(j*2408|0)>>3;l=(d*2408|0|4)+(j*-1609|0)>>3;j=a+32|0;d=b[j>>1]|0;m=a+96|0;n=b[m>>1]|0;o=(d*2676|0)+4+(n*1108|0)>>3;p=(d*1108|0)+4+(n*-2676|0)>>3;n=b[a>>1]<<11;d=a+64|0;q=b[d>>1]<<11;r=q+n>>3;s=n-q>>3;q=g-k|0;n=((h-l+q|0)*181|0)+128>>8;t=((l-h+q|0)*181|0)+128>>8;q=r+o|0;b[a>>1]=(g+8192+k+q|0)>>>14;a=s+p|0;b[c>>1]=(n+8192+a|0)>>>14;c=s-p|0;b[j>>1]=(t+8192+c|0)>>>14;j=r-o|0;b[i>>1]=(h+8192+l+j|0)>>>14;b[d>>1]=(8192-h-l+j|0)>>>14;b[f>>1]=(8192-t+c|0)>>>14;b[m>>1]=(8192-n+a|0)>>>14;b[e>>1]=(8192-g-k+q|0)>>>14;return}function Shb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;d=i;e=b+784|0;f=b+9992|0;g=c[f>>2]|0;h=g-1|0;j=e|0;k=c[j>>2]|0;l=b+788|0;m=c[l>>2]|0;if((m|0)>1){n=m-1|0;o=k<<1|h;p=g}else{g=je(h>>>((1-m|0)>>>0)|k<<m|0)|0;k=b+796|0;q=c[k>>2]|0;y=g;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;n=m+31|0;o=h;p=c[f>>2]|0}c[j>>2]=o;c[l>>2]=n;if((p|0)==1){if((n|0)>7){r=n-7|0;s=o<<7}else{p=je(o<<n|0)|0;h=b+796|0;m=c[h>>2]|0;y=p;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;r=n+25|0;s=0}c[j>>2]=s;c[l>>2]=r;t=r;u=s}else{t=n;u=o}o=b+9960|0;n=c[o>>2]|0;if((t|0)>5){v=t-5|0;w=u<<5|n}else{s=je(u<<t|n>>>((5-t|0)>>>0)|0)|0;u=b+796|0;r=c[u>>2]|0;y=s;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+27|0;w=n}c[j>>2]=w;c[l>>2]=v;n=b+14072|0;c[n>>2]=1;t=b+14060|0;c[t>>2]=1;u=b+14096|0;c[u>>2]=0;r=b+14116|0;c[r>>2]=0;s=b+15352|0;c[s>>2]=0;h=b+15324|0;c[h>>2]=0;c[b+15316>>2]=0;if((c[b+14088>>2]|0)==0){KIb(0,0,2442504,(x=i,i=i+24|0,c[x>>2]=2585992,c[x+8>>2]=2440792,c[x+16>>2]=87,x)|0);i=x;Hd();return 0}if((c[f>>2]|0)==1){if((c[b+12472>>2]|0)!=1){KIb(0,0,2442504,(x=i,i=i+24|0,c[x>>2]=2353008,c[x+8>>2]=2440792,c[x+16>>2]=90,x)|0);i=x;Hd();return 0}if((c[b+15312>>2]|0)==0){z=w;A=v}else{if((v|0)>1){B=v-1|0;C=w<<1}else{x=je(w<<v|0)|0;f=b+796|0;m=c[f>>2]|0;y=x;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;B=v+31|0;C=0}c[j>>2]=C;c[l>>2]=B;z=C;A=B}if((c[b+15372>>2]|0)==0){D=z;E=A}else{B=c[u>>2]|0;if((A|0)>1){F=A-1|0;G=z<<1|B}else{C=je(B>>>((1-A|0)>>>0)|z<<A|0)|0;z=b+796|0;f=c[z>>2]|0;y=C;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;F=A+31|0;G=B}c[j>>2]=G;c[l>>2]=F;D=G;E=F}if((c[u>>2]|0)==0){MUa(e,c[b+14068>>2]|0);MUa(e,c[b+14064>>2]|0);H=c[j>>2]|0;I=c[l>>2]|0}else{H=D;I=E}E=c[n>>2]|0;if((I|0)>1){J=I-1|0;K=H<<1|E}else{D=je(E>>>((1-I|0)>>>0)|H<<I|0)|0;H=b+796|0;F=c[H>>2]|0;y=D;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[H>>2]=(c[H>>2]|0)+4;J=I+31|0;K=E}c[j>>2]=K;c[l>>2]=J;c[b+14112>>2]=0;L=b+14100|0;c[L>>2]=0;M=b+14104|0;c[M>>2]=0;i=d;return 0}if((v|0)>2){N=v-2|0;O=w<<2}else{J=je(w<<v|0)|0;w=b+796|0;K=c[w>>2]|0;y=J;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;N=v+30|0;O=0}c[j>>2]=O;c[l>>2]=N;MUa(e,0);N=c[o>>2]|0;do{if((N|0)<11){c[b+15364>>2]=0}else{o=b+15364|0;if((N|0)<21){c[o>>2]=1;break}else{c[o>>2]=2;break}}}while(0);if((c[b+15360>>2]|0)!=0){N=c[r>>2]|0;r=c[j>>2]|0;o=c[l>>2]|0;if((o|0)>1){P=o-1|0;Q=r<<1|N}else{O=je(N>>>((1-o|0)>>>0)|r<<o|0)|0;r=b+796|0;v=c[r>>2]|0;y=O;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;P=o+31|0;Q=N}c[j>>2]=Q;c[l>>2]=P}do{if((c[b+15320>>2]|0)!=0){P=c[s>>2]|0;Q=P^1;N=c[j>>2]|0;o=c[l>>2]|0;if((o|0)>1){R=o-1|0;S=N<<1|Q;T=P}else{P=je(Q>>>((1-o|0)>>>0)|N<<o|0)|0;N=b+796|0;r=c[N>>2]|0;y=P;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[N>>2]=(c[N>>2]|0)+4;R=o+31|0;S=Q;T=c[s>>2]|0}c[j>>2]=S;c[l>>2]=R;if((T|0)!=0){break}MUa(e,c[h>>2]|0)}}while(0);if((c[b+15372>>2]|0)!=0){h=c[u>>2]|0;T=c[j>>2]|0;R=c[l>>2]|0;if((R|0)>1){U=R-1|0;V=T<<1|h}else{S=je(h>>>((1-R|0)>>>0)|T<<R|0)|0;T=b+796|0;s=c[T>>2]|0;y=S;a[s]=y;y=y>>8;a[s+1|0]=y;y=y>>8;a[s+2|0]=y;y=y>>8;a[s+3|0]=y;c[T>>2]=(c[T>>2]|0)+4;U=R+31|0;V=h}c[j>>2]=V;c[l>>2]=U}if((c[u>>2]|0)==0){u=b+14064|0;MUa(e,c[u>>2]|0);c[b+14068>>2]=c[u>>2]}u=c[n>>2]|0;n=c[j>>2]|0;e=c[l>>2]|0;if((e|0)>1){W=e-1|0;X=n<<1|u}else{U=je(u>>>((1-e|0)>>>0)|n<<e|0)|0;n=b+796|0;V=c[n>>2]|0;y=U;a[V]=y;y=y>>8;a[V+1|0]=y;y=y>>8;a[V+2|0]=y;y=y>>8;a[V+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;W=e+31|0;X=u}c[j>>2]=X;c[l>>2]=W;u=c[t>>2]|0;if((W|0)>1){Y=W-1|0;Z=X<<1|u}else{t=je(X<<W|u>>>((1-W|0)>>>0)|0)|0;X=b+796|0;e=c[X>>2]|0;y=t;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;c[X>>2]=(c[X>>2]|0)+4;Y=W+31|0;Z=u}c[j>>2]=Z;c[l>>2]=Y;c[b+14112>>2]=0;L=b+14100|0;c[L>>2]=0;M=b+14104|0;c[M>>2]=0;i=d;return 0}function Thb(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;RUa(b);n=b+12488|0;o=c[b+180>>2]|0;if((c[n>>2]|0)==0){p=(o>>31)+32&-32;q=(c[b+184>>2]|0)>-1?p|16:p;p=(c[b+188>>2]|0)>-1?q|8:q;q=(c[b+192>>2]|0)>-1?p|4:p;p=(((c[b+196>>2]|0)>-1?q|2:q)|(c[b+200>>2]|0)>>>31^1)+64|0;q=c[1246296+(c[b+15364>>2]<<2)>>2]|0;r=c[q+(p<<3)+4>>2]|0;s=c[q+(p<<3)>>2]|0;p=b+784|0;q=c[p>>2]|0;t=b+788|0;u=c[t>>2]|0;if((u|0)>(r|0)){v=u-r|0;w=q<<r|s;x=c[b+796>>2]|0}else{z=je(s>>>((r-u|0)>>>0)|q<<u|0)|0;q=b+796|0;A=c[q>>2]|0;y=z;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;A=(c[q>>2]|0)+4|0;c[q>>2]=A;v=32-r+u|0;w=s;x=A}c[p>>2]=w;c[t>>2]=v;w=b+792|0;p=(x-(c[w>>2]|0)<<3)+(32-v)|0;v=b+13700|0;x=c[v>>2]|0;c[v>>2]=p;A=b+13696|0;c[A>>2]=(c[A>>2]|0)-x+p;Rga(b,0,0,k,l)|0;QUa(b,g-(c[k>>2]|0)|0,h-(c[l>>2]|0)|0);l=((c[b+796>>2]|0)-(c[w>>2]|0)<<3)+(32-(c[t>>2]|0))|0;t=c[v>>2]|0;c[v>>2]=l;v=b+13664|0;c[v>>2]=(c[v>>2]|0)-t+l}else{l=(o|0)>0;o=l&1;t=Drb(b,0,m)|0;a[c[m>>2]|0]=l&1;l=(c[b+184>>2]|0)>0;v=l&1;w=Drb(b,1,m)|0;a[c[m>>2]|0]=l&1;l=(c[b+188>>2]|0)>0;h=l&1;k=Drb(b,2,m)|0;a[c[m>>2]|0]=l&1;l=(c[b+192>>2]|0)>0;g=l&1;p=Drb(b,3,m)|0;a[c[m>>2]|0]=l&1;l=(c[b+196>>2]|0)>0|0;m=(c[b+200>>2]|0)>0|0;x=m|(l<<1|(g<<2|(h<<3|(v<<4|o<<5))));A=m|(l<<1|((p^g)<<2|((k^h)<<3|((w^v)<<4|(t^o)<<5))));o=b+784|0;if((c[b+9992>>2]|0)==1){t=e[1341754+(A<<2)>>1]|0;v=e[1341752+(A<<2)>>1]|0;A=o|0;w=c[A>>2]|0;h=b+788|0;k=c[h>>2]|0;if((k|0)>(t|0)){B=k-t|0;C=w<<t|v}else{g=je(v>>>((t-k|0)>>>0)|w<<k|0)|0;w=b+796|0;p=c[w>>2]|0;y=g;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;B=32-t+k|0;C=v}c[A>>2]=C;c[h>>2]=B;D=C;E=B}else{B=c[1246296+(c[b+15364>>2]<<2)>>2]|0;C=c[B+(x<<3)+4>>2]|0;h=c[B+(x<<3)>>2]|0;x=o|0;B=c[x>>2]|0;A=b+788|0;v=c[A>>2]|0;if((v|0)>(C|0)){F=v-C|0;G=B<<C|h}else{k=je(h>>>((C-v|0)>>>0)|B<<v|0)|0;B=b+796|0;t=c[B>>2]|0;y=k;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;F=32-C+v|0;G=h}c[x>>2]=G;c[A>>2]=F;D=G;E=F}F=o|0;o=b+788|0;if((E|0)>1){H=E-1|0;I=D<<1}else{G=je(D<<E|0)|0;D=b+796|0;A=c[D>>2]|0;y=G;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;H=E+31|0;I=0}c[F>>2]=I;c[o>>2]=H;if((c[b+14112>>2]|0)==0){J=H}else{c[b+13820>>2]=0;E=d[1293753]|0;D=d[1293752]|0;if((H|0)>(E|0)){K=H-E|0;L=I<<E|D}else{A=je(D>>>((E-H|0)>>>0)|I<<H|0)|0;I=b+796|0;G=c[I>>2]|0;y=A;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[I>>2]=(c[I>>2]|0)+4;K=32-E+H|0;L=D}c[F>>2]=L;c[o>>2]=K;J=K}K=((c[b+796>>2]|0)-(c[b+792>>2]|0)<<3)+(32-J)|0;J=b+13700|0;o=c[J>>2]|0;c[J>>2]=K;J=b+13696|0;c[J>>2]=(c[J>>2]|0)-o+K}UUa(b,f|0,0);UUa(b,f+128|0,1);UUa(b,f+256|0,2);UUa(b,f+384|0,3);UUa(b,f+512|0,4);UUa(b,f+640|0,5);f=(c[n>>2]|0)==0;n=((c[b+796>>2]|0)-(c[b+792>>2]|0)<<3)+(32-(c[b+788>>2]|0))|0;K=b+13700|0;o=c[K>>2]|0;c[K>>2]=n;K=n-o|0;if(f){f=b+13676|0;c[f>>2]=(c[f>>2]|0)+K;i=j;return}else{f=b+13672|0;c[f>>2]=(c[f>>2]|0)+K;i=j;return}}function Uhb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[b+60>>2]|0;if((bUa(b)|0)<0){e=-1;return e|0}Ehb(d);c[b+100>>2]=4;c[b+96>>2]=pJb(14)|0;b=c[d+4>>2]|0;f=(c[b+100>>2]|0)<0?0:c[b+96>>2]|0;g=c[d+24>>2]|0;if((g|0)>2097151){h=2047}else{h=(g|0)/1024|0}g=h|((c[b+108>>2]|0)/(c[b+104>>2]|0)|0)<<11;c[d+15360>>2]=1;b=c[d+13836>>2]|0;h=g<<2|b;c[d+15320>>2]=1;c[d+15312>>2]=1;c[d+15368>>2]=0;c[d+15372>>2]=1;a[f]=h>>>10;a[f+1|0]=h>>>2;a[f+2|0]=b<<6|180;a[f+3|0]=-128;c[d+14080>>2]=c[d+120>>2];e=0;return e|0}function Vhb(a){a=a|0;c[a+140>>2]=4;c[2450057]=9472120;c[2450059]=512;$2(9800224,9,16,1703378,4,2,1703376,4,2,0,0,0,4)|0;return 0}function Whb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;j=i;k=c[e+60>>2]|0;l=c[h+24>>2]|0;m=c[h+28>>2]|0;if((m|0)<9){KIb(e,16,2440376,(n=i,i=i+8|0,c[n>>2]=m,n)|0);i=n;o=-1094995529;i=j;return o|0}h=hJb(m+16|0)|0;if((h|0)==0){KIb(e,16,2352896,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-12;i=j;return o|0}mrc(h+m|0,0,16)|0;p=M4a(e,f,0)|0;if((p|0)<0){kJb(h);o=p;i=j;return o|0}c[f+84>>2]=1;if((m|0)>8){p=8;do{a[h+p|0]=a[1316536+(d[l+p|0]|0)|0]|0;p=p+1|0;}while((p|0)<(m|0))}p=h+8|0;q=(m<<3)-64|0;r=q>>>0>2147483639>>>0|(p|0)==0;s=r?0:p;p=r?0:q;q=k+4|0;c[q>>2]=s;c[k+16>>2]=p;r=k+20|0;c[r>>2]=p+8;c[k+8>>2]=s+(p>>3);p=k+12|0;c[p>>2]=0;s=l+2|0;l=(d[s]|0)>>>4;do{if((l|0)==6){c[k>>2]=2}else{t=8-l|0;u=k;c[u>>2]=t;if((t|0)>4){QIb(e,2290728,(n=i,i=i+8|0,c[n>>2]=(d[s]|0)>>>4,n)|0);i=n;c[u>>2]=4;break}if((t|0)>=1){break}QIb(e,2290728,(n=i,i=i+8|0,c[n>>2]=(d[s]|0)>>>4,n)|0);i=n;c[u>>2]=1}}while(0);n=e+124|0;s=c[n>>2]|0;if((s|0)>0){l=e+120|0;e=f+32|0;u=f+36|0;t=f+40|0;v=k;k=c[f+4>>2]|0;w=c[f+8>>2]|0;x=0;y=c[f>>2]|0;f=0;z=0;A=0;B=c[l>>2]|0;C=s;while(1){if((B|0)>1){s=0;D=f;E=z;F=A;do{G=c[2450057]|0;H=c[p>>2]|0;I=c[r>>2]|0;J=c[q>>2]|0;K=J+(H>>>3)|0;L=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(H&7)>>>23;K=b[G+(L<<2)>>1]|0;M=(b[G+(L<<2)+2>>1]|0)+H|0;H=I>>>0>M>>>0?M:I;c[p>>2]=H;if(K<<16>>16==15){M=8-(c[v>>2]|0)|0;L=J+(H>>>3)|0;J=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(H&7)>>>((32-M|0)>>>0);L=M+H|0;c[p>>2]=I>>>0>L>>>0?L:I;N=a[1316536+J|0]|0}else{N=((K<<16>>16)-7<<c[v>>2])+D&255}K=s<<1;J=y+K|0;a[J]=N;I=c[2450057]|0;L=c[p>>2]|0;H=c[r>>2]|0;M=c[q>>2]|0;G=M+(L>>>3)|0;O=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(L&7)>>>23;G=b[I+(O<<2)>>1]|0;P=(b[I+(O<<2)+2>>1]|0)+L|0;L=H>>>0>P>>>0?P:H;c[p>>2]=L;if(G<<16>>16==15){P=8-(c[v>>2]|0)|0;O=M+(L>>>3)|0;M=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>((32-P|0)>>>0);O=P+L|0;c[p>>2]=H>>>0>O>>>0?O:H;Q=d[1316536+M|0]|0}else{Q=((G<<16>>16)-7<<c[v>>2])+E|0}a[k+s|0]=Q;E=Q&255;G=a[J]|0;J=c[2450057]|0;M=c[p>>2]|0;H=c[r>>2]|0;O=c[q>>2]|0;L=O+(M>>>3)|0;P=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>23;L=b[J+(P<<2)>>1]|0;I=(b[J+(P<<2)+2>>1]|0)+M|0;M=H>>>0>I>>>0?I:H;c[p>>2]=M;if(L<<16>>16==15){I=8-(c[v>>2]|0)|0;P=O+(M>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(M&7)>>>((32-I|0)>>>0);P=I+M|0;c[p>>2]=H>>>0>P>>>0?P:H;R=d[1316536+O|0]|0}else{R=((L<<16>>16)-7<<c[v>>2])+(G&255)|0}a[y+(K|1)|0]=R;D=R&255;K=c[2450057]|0;G=c[p>>2]|0;L=c[r>>2]|0;O=c[q>>2]|0;H=O+(G>>>3)|0;P=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(G&7)>>>23;H=b[K+(P<<2)>>1]|0;M=(b[K+(P<<2)+2>>1]|0)+G|0;G=L>>>0>M>>>0?M:L;c[p>>2]=G;if(H<<16>>16==15){M=8-(c[v>>2]|0)|0;P=O+(G>>>3)|0;O=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(G&7)>>>((32-M|0)>>>0);P=M+G|0;c[p>>2]=L>>>0>P>>>0?P:L;S=d[1316536+O|0]|0}else{S=((H<<16>>16)-7<<c[v>>2])+F|0}a[w+s|0]=S;F=S&255;s=s+1|0;T=c[l>>2]|0;}while((s|0)<((T|0)/2|0|0));U=D;V=E;W=F;X=T;Y=c[n>>2]|0}else{U=f;V=z;W=A;X=B;Y=C}s=x+1|0;if((s|0)<(Y|0)){k=k+(c[u>>2]|0)|0;w=w+(c[t>>2]|0)|0;x=s;y=y+(c[e>>2]|0)|0;f=U;z=V;A=W;B=X;C=Y}else{break}}}c[g>>2]=1;kJb(h);o=m;i=j;return o|0}function Xhb(a){a=a|0;var b=0;c[a+416>>2]=1;b=a+448|0;c[b>>2]=4;c[b+4>>2]=0;c[a+420>>2]=0;return 0}function Yhb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;j=g+24|0;k=c[j>>2]|0;l=c[g+28>>2]|0;if((l|0)==0){m=0;i=h;return m|0}if((l|0)<4){KIb(b,16,2440272,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-22;i=h;return m|0}g=k;o=(d[g]|d[g+1|0]<<8)<<16>>16;g=o&65535;p=k+2|0;q=(d[p]|d[p+1|0]<<8)<<16>>16;p=k+4|0;if((q&65535|0)>(l|0)){KIb(b,16,2352832,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;m=-1094995529;i=h;return m|0}n=e+76|0;c[n>>2]=g;k=M4a(b,e,0)|0;if((k|0)<0){m=k;i=h;return m|0}k=e;e=c[k>>2]|0;b=e+g|0;if(q<<16>>16==o<<16>>16){nrc(e|0,p|0,g)|0;c[f>>2]=1;m=l;i=h;return m|0}a:do{if(o<<16>>16==0){r=e}else{g=b;q=e;s=128;t=p;while(1){u=s&255;v=q;w=t;while(1){x=c[j>>2]|0;if((w-x|0)>=(l|0)){r=v;break a}y=a[w]|0;z=(y&255)>>>6;A=y&63;B=w+1|0;if((z|0)==2){C=A&255;D=(C&32|0)==0?C+1|0:1}else if((z|0)==1){D=((A&255)<<1)+2|0}else if((z|0)==0){D=((A&255)<<2)+4|0}else{D=(A&255)+1|0}if((g-v|0)<(D|0)){r=v;break a}E=(y&32)==0;if((z|0)==3|((z|0)!=2|E)^1){F=0}else{F=(A&255)+1|0}if((F+B-x|0)>(l|0)){r=v;break a}if((z|0)==2){G=41;break}else if((z|0)==1){G=35;break}else if((z|0)==0){G=25;break}mrc(v|0,u|0,D|0)|0;z=v+D|0;if(z>>>0<b>>>0){v=z;w=B}else{r=z;break a}}do{if((G|0)==25){G=0;u=A&255;z=u<<2;x=v;C=s;H=B;I=A+1&255;while(1){J=d[H]|0;K=C-2+(J&3)|0;if(K>>>0>255>>>0){L=-K>>31&255}else{L=K&255}a[x]=L;K=(J>>>2&3)-2+(L&255)|0;if(K>>>0>255>>>0){M=-K>>31&255}else{M=K&255}a[x+1|0]=M;K=(J>>>4&3)-2+(M&255)|0;if(K>>>0>255>>>0){N=-K>>31&255}else{N=K&255}a[x+2|0]=N;K=(J>>>6)-2+(N&255)|0;if(K>>>0>255>>>0){O=-K>>31&255}else{O=K&255}P=O&255;a[x+3|0]=O;K=I-1&255;if(K<<24>>24==0){break}else{x=x+4|0;C=P;H=H+1|0;I=K}}Q=w+(u+2)|0;R=P;S=v+(z+4)|0}else if((G|0)==35){G=0;I=A&255;H=I<<1;C=v;x=s;K=B;J=A+1&255;while(1){T=d[K]|0;U=(a[110056+(T&15)|0]|0)+x|0;if(U>>>0>255>>>0){V=-U>>31&255}else{V=U&255}a[C]=V;U=(a[110056+(T>>>4)|0]|0)+(V&255)|0;if(U>>>0>255>>>0){W=-U>>31&255}else{W=U&255}X=W&255;a[C+1|0]=W;U=J-1&255;if(U<<24>>24==0){break}else{C=C+2|0;x=X;K=K+1|0;J=U}}Q=w+(I+2)|0;R=X;S=v+(H+2)|0}else if((G|0)==41){G=0;if(E){nrc(v|0,B|0,D)|0;Q=w+(D+1)|0;R=d[w+D|0]|0;S=v+D|0;break}J=(y<<3<<24>>24>>3)+s|0;if(J>>>0>255>>>0){Y=-J>>31&255}else{Y=J&255}a[v]=Y;Q=B;R=Y&255;S=v+1|0}}while(0);if(S>>>0<b>>>0){q=S;s=R;t=Q}else{r=S;break}}}}while(0);c[n>>2]=r-(c[k>>2]|0);c[f>>2]=1;m=l;i=h;return m|0}function Zhb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+60|0;d=c[b>>2]|0;c[d>>2]=a;c[d+44>>2]=0;c[a+140>>2]=11;e=a+120|0;f=a+124|0;a=ca(c[f>>2]|0,c[e>>2]|0)|0;c[d+20>>2]=a;g=hJb(a)|0;a=d+16|0;c[a>>2]=g;if((g|0)==0){h=-12;return h|0}g=ca(c[f>>2]|0,c[e>>2]|0)|0;c[d+28>>2]=g;e=hJb(g+130|0)|0;c[d+24>>2]=e;if((e|0)==0){mJb(a);h=-12;return h|0}a=UHb()|0;c[d+4>>2]=a;if((a|0)!=0){h=0;return h|0}a=c[b>>2]|0;VHb(a+4|0);mJb(a+16|0);mJb(a+24|0);mJb(a+32|0);h=-12;return h|0}function _hb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;h=i;j=e;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=g;if(!((l|0)>-1)){KIb(0,0,2140984,(n=i,i=i+24|0,c[n>>2]=2117480,c[n+8>>2]=2635280,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}o=k+l|0;p=g+36|0;a:do{if(l>>>0<9>>>0){q=k;r=l}else{s=g+32|0;t=g+40|0;u=b;v=k;w=l;b:while(1){if((w|0)<4){x=0;y=v}else{z=v;x=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;y=v+4|0}z=o-y|0;if((z|0)<4){A=0;B=y;C=z}else{z=y+4|0;D=y;E=je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0;if((E|0)<0){F=9;break}D=o-z|0;A=E>>>0>D>>>0?D:E;B=z;C=D}do{if((x|0)==1414283600){if((A|0)<768){G=-1094995529;F=120;break b}D=c[p>>2]|0;if((D|0)>255){G=-1094995529;F=120;break b}z=iJb(c[s>>2]|0,(D<<10)+1024|0)|0;D=z;if((z|0)==0){G=-12;F=120;break b}c[s>>2]=D;z=B;H=D+(c[p>>2]<<8<<2)|0;D=0;while(1){c[H>>2]=d[1198208+(d[z]|0)|0]<<16|d[1198208+(d[z+1|0]|0)|0]<<8|d[1198208+(d[z+2|0]|0)|0]|-16777216;I=D+1|0;if((I|0)<256){z=z+3|0;H=H+4|0;D=I}else{break}}c[p>>2]=(c[p>>2]|0)+1;J=1414283600;K=B+768|0}else if((x|0)==1414482003){if((A|0)<4){G=-1094995529;F=120;break b}if((C|0)<4){L=0;M=B}else{D=B;L=d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0;M=B+4|0}if(L>>>0<(c[p>>2]|0)>>>0){c[t>>2]=L;J=1414482003;K=M;break}else{KIb(u,16,2352800,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;J=1414482003;K=M;break}}else if((x|0)==541149014){F=12;break b}else{J=x;K=B+(C>>>0>A>>>0?A:C)|0}}while(0);D=o-K|0;if(D>>>0<9>>>0|(J|0)==541149014){q=K;r=D;break a}else{v=K;w=D}}if((F|0)==9){KIb(u,16,2440200,(n=i,i=i+8|0,c[n>>2]=E,n)|0);i=n;G=-1094995529;i=h;return G|0}else if((F|0)==12){q=B;r=o-B|0;break}else if((F|0)==120){i=h;return G|0}}}while(0);if((c[p>>2]|0)<1){KIb(c[g>>2]|0,16,2290704,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}p=M4a(b,j,1)|0;if((p|0)<0){G=p;i=h;return G|0}p=g+44|0;if((c[p>>2]|0)==0){b=g;c[p>>2]=ca(c[(c[b>>2]|0)+124>>2]|0,c[e+32>>2]|0)|0;N=b}else{N=g}nrc(c[e+4>>2]|0,(c[g+32>>2]|0)+(c[g+40>>2]<<8<<2)|0,1024)|0;c[g+8>>2]=q;b=g+12|0;c[b>>2]=r;B=c[N>>2]|0;o=c[B+120>>2]|0;E=ca(c[B+124>>2]|0,o)|0;B=c[g+16>>2]|0;K=c[g+20>>2]|0;J=g+24|0;C=c[J>>2]|0;if((r|0)<8){G=-1094995529;i=h;return G|0}A=q;x=(d[A]|d[A+1|0]<<8)<<16>>16&65535;A=q+2|0;M=(d[A]|d[A+1|0]<<8)<<16>>16&65535;A=q+4|0;L=(d[A]|d[A+1|0]<<8)<<16>>16&65535;A=q+6|0;y=(d[A]|d[A+1|0]<<8)<<16>>16&65535;if(!((x|0)<(r|0)&(M|0)<(r|0)&(L|0)<(r|0)&(y|0)<(r|0))){G=-1094995529;i=h;return G|0}A=q+M|0;if(!((r-M|0)>-1)){KIb(0,0,2140984,(n=i,i=i+24|0,c[n>>2]=2117480,c[n+8>>2]=2635280,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}M=q+r|0;l=q+L|0;if(!((r-L|0)>-1)){KIb(0,0,2140984,(n=i,i=i+24|0,c[n>>2]=2117480,c[n+8>>2]=2635280,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}L=a[q+x|0]|0;k=L&255;w=L+22&255;L=k<<1;v=q+((L|1)+x)|0;t=r-1-x-L|0;s=B+K|0;D=t>>>0>268435455>>>0?-8:t<<3;t=D>>>0>2147483639>>>0|(v|0)==0;H=t?0:v;v=t?8:D+8|0;c:do{if(t){O=t?-1094995529:0}else{D=x+1|0;z=B;I=0;d:while(1){P=w;Q=I;while(1){if(P<<24>>24==22){F=47;break d}R=((Q|0)<(v|0))+Q|0;S=(P&255)-23+(k&-((d[H+(Q>>>3)|0]|0)>>>((Q&7)>>>0)&1))|0;if(!(S>>>0<L>>>0)){G=-1094995529;F=120;break d}T=a[q+(D+S)|0]|0;if((T&255)>>>0<22>>>0){break}else{P=T;Q=R}}if(!(z>>>0<s>>>0)){O=K;break c}a[z]=T;z=z+1|0;I=R}if((F|0)==47){O=z-B|0;break}else if((F|0)==120){i=h;return G|0}}}while(0);if((O|0)<0){G=-1094995529;i=h;return G|0}R=B+O|0;do{if((a[q+y|0]|0)==2){T=c[J>>2]|0;K=g+28|0;s=c[K>>2]|0;L=c[b>>2]|0;H=L-y|0;k=T+s|0;if((H|0)<=0){KIb(0,0,2140984,(n=i,i=i+24|0,c[n>>2]=2117480,c[n+8>>2]=2635280,c[n+16>>2]=135,n)|0);i=n;Hd();return 0}v=q+L|0;L=v;if((s|0)<1|(H|0)==1){U=s;V=C;break}s=k;H=T;w=q+(y+1)|0;x=T;e:while(1){do{if((L-w|0)<1){W=0;X=w;F=57}else{T=w+1|0;t=a[w]|0;I=t&255;if(!((t&255)>>>0<224>>>0)){D=(t&255)>>>0>251>>>0;if(D){Y=I&3}else{Y=(I<<2&124)+4|0}if((s-x|0)<(Y|0)){break e}t=L-T|0;if(t>>>0<Y>>>0){break e}u=t>>>0>Y>>>0?Y:t;nrc(x|0,T|0,u)|0;if(D){break e}else{Z=Y;_=w+(u+1)|0;break}}if((I&128|0)==0){W=I;X=T;F=57;break}if((I&64|0)==0){u=L-T|0;do{if((u|0)<1){$=0;aa=T;ba=0}else{D=(d[T]|0)>>>6;if((u|0)<2){$=0;aa=T;ba=D;break}t=T;$=(he((d[t]|d[t+1|0]<<8)<<16>>16|0)|0)&16383;aa=w+3|0;ba=D}}while(0);da=$;ea=(I&63)+4|0;fa=ba;ga=aa;F=70;break}if((L-T|0)<2){ha=0;ia=T}else{u=T;ha=(he((d[u]|d[u+1|0]<<8)<<16>>16|0)|0)&65535;ia=w+3|0}if((L-ia|0)<1){ja=0;ka=ia}else{ja=d[ia]|0;ka=ia+1|0}da=ha|I<<12&65536;ea=(ja|I<<6&768)+5|0;fa=I&3;ga=ka;F=70}}while(0);if((F|0)==57){F=0;if((L-X|0)<1){la=0;ma=X}else{la=d[X]|0;ma=X+1|0}da=la|W<<3&768;ea=(W>>>2&7)+3|0;fa=W&3;ga=ma;F=70}if((F|0)==70){F=0;u=da+1|0;D=ea+fa|0;if((s-x|0)<(D|0)){break}t=x+fa|0;if((t-H|0)<(u|0)){break}Q=L-ga|0;if(Q>>>0<fa>>>0){break}P=Q>>>0>fa>>>0?fa:Q;nrc(x|0,ga|0,P)|0;vJb(t,u,ea);Z=D;_=ga+P|0}P=x+Z|0;if(P>>>0>=k>>>0|(v|0)==(_|0)){break}else{w=_;x=P}}U=c[K>>2]|0;V=C}else{U=(c[b>>2]|0)+~y|0;V=q+(y+1)|0}}while(0);f:do{if((E|0)!=0&(O|0)>0){y=e;q=e+32|0;b=M;C=A;_=l;Z=V;ga=B;ea=0;fa=0;da=0;ma=E;W=U;g:while(1){la=ga;X=da;h:while(1){na=la+1|0;oa=a[la]|0;pa=oa&255;switch(pa|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:{F=101;break h;break};case 9:case 19:{F=89;break h;break};case 12:case 13:case 14:case 15:case 16:case 17:case 18:{F=88;break h;break};case 10:case 20:{F=93;break h;break};case 0:{break};case 11:case 21:{F=97;break h;break};default:{qa=0;ra=C;break h}}if(na>>>0<R>>>0){la=na;X=X^1}else{break f}}do{if((F|0)==88){F=0;qa=pa-10|0;ra=C}else if((F|0)==89){F=0;if((M|0)==(C|0)){F=90;break g}if((b-C|0)<1){qa=0;ra=C;break}qa=d[C]|0;ra=C+1|0}else if((F|0)==93){F=0;la=b-C|0;if(la>>>0<2>>>0){F=94;break g}if((la|0)<2){qa=0;ra=C;break}la=C;qa=(he((d[la]|d[la+1|0]<<8)<<16>>16|0)|0)&65535;ra=C+2|0}else if((F|0)==97){F=0;la=b-C|0;if(la>>>0<3>>>0){F=98;break g}if((la|0)<3){qa=0;ra=C;break}qa=d[C+1|0]<<8|d[C]<<16|d[C+2|0];ra=C+3|0}else if((F|0)==101){F=0;qa=pa;ra=C}}while(0);if((qa|0)>(ma|0)){break f}do{if((oa&255)>>>0<12>>>0){la=X^1;if(!(X<<24>>24==1)){aib(m,j,fa,ea,qa,0,0);sa=W;ta=la;ua=Z;va=_;break}if((W|0)<(qa|0)){break f}ka=c[y>>2]|0;ja=c[q>>2]|0;ha=c[(c[N>>2]|0)+120>>2]|0;ia=ja-ha|0;i:do{if((qa|0)!=0){aa=(ca(ja,ea)|0)+fa|0;if((aa|0)<(c[p>>2]|0)){wa=Z;xa=qa;ya=aa;za=fa}else{break}while(1){aa=ha-za|0;ba=(xa|0)>(aa|0)?aa:xa;nrc(ka+ya|0,wa|0,ba)|0;aa=ba+za|0;$=(aa|0)<(ha|0);if((xa|0)==(ba|0)){break i}Y=ba+ya+($?0:ia)|0;if((Y|0)<(c[p>>2]|0)){wa=wa+ba|0;xa=xa-ba|0;ya=Y;za=$?aa:0}else{break}}}}while(0);sa=W-qa|0;ta=la;ua=Z+qa|0;va=_}else{if((M|0)==(_|0)){F=113;break g}if((b-_|0)<1){Aa=0;Ba=_}else{Aa=d[_]|0;Ba=_+1|0}aib(m,j,fa,ea,qa,Aa>>>4<<28>>28,Aa<<28>>28);sa=W;ta=0;ua=Z;va=Ba}}while(0);X=qa+fa|0;if((ma|0)!=(qa|0)&na>>>0<R>>>0){C=ra;_=va;Z=ua;ga=na;ea=((X|0)/(o|0)|0)+ea|0;fa=(X|0)%(o|0)|0;da=ta;ma=ma-qa|0;W=sa}else{break f}}if((F|0)==90){KIb(c[N>>2]|0,16,2240152,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}else if((F|0)==94){KIb(c[N>>2]|0,16,2240152,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}else if((F|0)==98){KIb(c[N>>2]|0,16,2240152,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}else if((F|0)==113){KIb(c[N>>2]|0,16,2199176,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;G=-1094995529;i=h;return G|0}}}while(0);n=g+4|0;WHb(c[n>>2]|0);g=YHb(c[n>>2]|0,j)|0;if((g|0)<0){G=g;i=h;return G|0}c[f>>2]=1;G=r;i=h;return G|0}function $hb(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+16|0);mJb(b+24|0);mJb(b+32|0);return 0}function aib(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;k=c[a>>2]|0;l=c[k+120>>2]|0;m=h+e|0;if((m|0)<0){i=j;return}if((m|0)>=(c[k+124>>2]|0)){i=j;return}h=g+d|0;if(!((h|0)>-1&(h|0)<(l|0))){i=j;return}g=c[b>>2]|0;n=c[c[a+4>>2]>>2]|0;o=(n|0)==0?g:n;n=c[b+32>>2]|0;b=n-l|0;p=(ca(n,e)|0)+d|0;e=h+(ca(n,m)|0)|0;do{if((o|0)==(g|0)){m=p-e|0;if((((m|0)>-1?m:-m|0)|0)>=(f|0)){break}QIb(k,2167552,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;i=j;return}}while(0);if((f|0)==0){i=j;return}k=a+44|0;a=d;d=h;h=e;e=p;p=f;while(1){f=c[k>>2]|0;if(!((e|0)<(f|0)&(h|0)<(f|0))){q=11;break}f=l-a|0;m=(p|0)>(f|0)?f:p;f=l-d|0;n=(m|0)>(f|0)?f:m;nrc(g+e|0,o+h|0,n)|0;m=n+a|0;f=n+d|0;r=(m|0)<(l|0);s=(f|0)<(l|0);if((p|0)==(n|0)){q=11;break}else{a=r?m:0;d=s?f:0;h=n+h+(s?0:b)|0;e=n+e+(r?0:b)|0;p=p-n|0}}if((q|0)==11){i=j;return}}function bib(a){a=a|0;c[a+140>>2]=9;return 0}function cib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;h=i;i=i+264|0;j=h|0;k=h+256|0;l=e;m=c[g+24>>2]|0;n=g+28|0;g=m+(c[n>>2]|0)|0;o=b+120|0;p=j|0;q=b+124|0;r=m;while(1){if((c[o>>2]|0)!=0){if((c[q>>2]|0)!=0){s=16;break}}m=mc(r|0,2440080)|0;t=r+m|0;u=Bd(t|0,2352752,(v=i,i=i+16|0,c[v>>2]=p,c[v+8>>2]=k,v)|0)|0;i=v;if((u|0)!=2){s=5;break}u=lrc(p|0)|0;do{if((u|0)>6){if((c[q>>2]|0)!=0){s=11;break}if((grc(j+(u-7)|0,2240120,7)|0)!=0){s=10;break}c[q>>2]=c[k>>2]}else{s=10}}while(0);if((s|0)==10){s=0;if((u|0)>5){s=11}else{s=14;break}}if((s|0)==11){s=0;if((c[o>>2]|0)!=0){s=14;break}if((grc(j+(u-6)|0,2199144,6)|0)!=0){s=14;break}c[o>>2]=c[k>>2]}r=r+(m+1+(mc(t|0,2140976)|0))|0}if((s|0)==5){KIb(b,16,2290624,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=h;return w|0}else if((s|0)==14){KIb(b,16,2167504,(v=i,i=i+8|0,c[v>>2]=p,v)|0);i=v;w=-1094995529;i=h;return w|0}else if((s|0)==16){s=M4a(b,l,0)|0;if((s|0)<0){w=s;i=h;return w|0}s=c[o>>2]|0;o=(s+7|0)/8|0;l=c[q>>2]|0;a:do{if((l|0)>0){p=r+((mc(r|0,2117440)|0)+1)|0;k=e;j=e+32|0;if((s|0)>0){x=p;y=0}else{p=0;while(1){p=p+1|0;if((p|0)>=(l|0)){break a}}}b:while(1){p=ca(c[j>>2]|0,y)|0;t=(c[k>>2]|0)+p|0;p=x;m=0;while(1){u=mc(p|0,2635272)|0;z=p+(u+1)|0;if(!(z>>>0<g>>>0)){break b}if((PFb(d[z]|0)|0)==0){break b}A=a[z]|0;do{if((A&255)>>>0>96>>>0){B=A-87&255}else{if((A&255)>>>0>64>>>0){B=A-55&255;break}else{B=A-48&255;break}}}while(0);C=p+(u+2)|0;if((PFb(d[C]|0)|0)==0){D=B}else{A=B<<4;E=a[C]|0;do{if((E&255)>>>0>96>>>0){F=E-87&255}else{if((E&255)>>>0>64>>>0){F=E-55&255;break}else{F=E-48&255;break}}}while(0);D=F+A&255}a[t]=a[1316536+(D&255)|0]|0;E=m+1|0;if((E|0)<(o|0)){t=t+1|0;p=C;m=E}else{break}}m=y+1|0;if((m|0)<(c[q>>2]|0)){x=C;y=m}else{break a}}KIb(b,16,2611864,(v=i,i=i+8|0,c[v>>2]=z,v)|0);i=v;w=-1094995529;i=h;return w|0}}while(0);c[e+84>>2]=1;c[e+88>>2]=1;c[f>>2]=1;w=c[n>>2]|0;i=h;return w|0}return 0}function dib(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=a+120|0;j=c[h>>2]|0;k=(j+7|0)/8|0;l=a+124|0;m=(ca((k*7|0)+2|0,c[l>>2]|0)|0)+110|0;n=d5a(a,b,m,(m|0)<0|0?-1:0)|0;if((n|0)<0){o=n;i=g;return o|0}n=b+24|0;m=c[n>>2]|0;a=c[e>>2]|0;p=Rb(m|0,32,2440056,(q=i,i=i+8|0,c[q>>2]=c[h>>2],q)|0)|0;i=q;h=Rb(m+p|0,33,2352720,(q=i,i=i+8|0,c[q>>2]=c[l>>2],q)|0)|0;i=q;r=h+p|0;p=Rb(m+r|0,40,2290584,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;h=m+(r+p)|0;a:do{if((c[l>>2]|0)>0){p=e+32|0;if((j|0)<=0){r=0;m=h;while(1){s=Rb(m|0,2,2199136,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;t=m+s|0;s=r+1|0;if((s|0)<(c[l>>2]|0)){r=s;m=t}else{u=t;break a}}}m=(k|0)>1?k:1;r=0;t=a;s=h;while(1){v=0;w=t;x=s;while(1){y=Rb(x|0,7,2240104,(q=i,i=i+8|0,c[q>>2]=d[1316536+(d[w]|0)|0]|0,q)|0)|0;i=q;z=x+y|0;A=v+1|0;if((A|0)<(k|0)){v=A;w=w+1|0;x=z}else{break}}w=t+(m+((c[p>>2]|0)-k))|0;v=Rb(z|0,2,2199136,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;A=x+(y+v)|0;v=r+1|0;if((v|0)<(c[l>>2]|0)){r=v;t=w;s=A}else{u=A;break}}}else{u=h}}while(0);h=Rb(u|0,5,2167496,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0)|0;i=q;c[b+28>>2]=u+h-(c[n>>2]|0);n=b+36|0;c[n>>2]=c[n>>2]|1;c[f>>2]=1;o=0;i=g;return o|0}function eib(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a+120|0;e=c[d>>2]|0;if((e|0)==48){f=c[a+124>>2]|0;if((f|0)==48){g=6}else{h=f}}else if((e|0)==0){if((c[a+124>>2]|0)==0){g=6}else{g=3}}else{g=3}if((g|0)==3){h=c[a+124>>2]|0}else if((g|0)==6){c[d>>2]=48;c[a+124>>2]=48;c[a+140>>2]=9;j=0;i=b;return j|0}KIb(a,16,2352656,(a=i,i=i+32|0,c[a>>2]=e,c[a+8>>2]=h,c[a+16>>2]=48,c[a+24>>2]=48,a)|0);i=a;j=-22;i=b;return j|0}function fib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+584|0;h=g|0;j=c[b+60>>2]|0;mrc(h|0,0,580)|0;k=M4a(b,d,0)|0;if((k|0)<0){l=k;i=g;return l|0}k=f+24|0;m=c[k>>2]|0;n=a[m]|0;a:do{if(!(n<<24>>24==0)){o=f+28|0;p=0;q=0;r=n;s=m;while(1){if((q|0)>=(c[o>>2]|0)){break a}t=r-33&255;if((t&255)>>>0>93>>>0){u=p;v=s}else{w=p+1|0;if((w|0)>354){break}Utb(h,94);Stb(h,t);u=w;v=c[k>>2]|0}w=q+1|0;t=a[v+w|0]|0;if(t<<24>>24==0){break a}else{p=u;q=w;r=t;s=v}}KIb(b,24,2439960,(s=i,i=i+8|0,c[s>>2]=q,s)|0);i=s}}while(0);mrc(j|0,0,2304)|0;gib(h,j,16,16,0);gib(h,j+16|0,16,16,0);gib(h,j+32|0,16,16,0);gib(h,j+768|0,16,16,0);gib(h,j+784|0,16,16,0);gib(h,j+800|0,16,16,0);gib(h,j+1536|0,16,16,0);gib(h,j+1552|0,16,16,0);gib(h,j+1568|0,16,16,0);Vtb(j,j);h=d+32|0;b=0;v=0;u=0;k=c[d>>2]|0;d=0;while(1){m=(a[j+d|0]|0)+u&255;if((v|0)==7){a[k+b|0]=m;x=0;y=0;z=b+1|0}else{x=m<<1;y=v+1|0;z=b}if((z|0)==6){A=k+(c[h>>2]|0)|0;B=0}else{A=k;B=z}m=d+1|0;if((m|0)<2304){b=B;v=y;u=x;k=A;d=m}else{break}}c[e>>2]=1;l=c[f+28>>2]|0;i=g;return l|0}function gib(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+8|0;j=h|0;Ttb(a,0,j);k=d[j]|0;l=0;m=1243992+(g*24|0)|0;while(1){n=m+4|0;o=c[n>>2]|0;if((k|0)>=(o|0)){p=c[m>>2]|0;if((k|0)<(p+o|0)){break}}l=l+1|0;m=m+8|0}Utb(a,p&255);Stb(a,(d[j]|0)-(c[n>>2]|0)&255);if((l|0)==0){hib(a,b,e,f);i=h;return}else if((l|0)==2){i=h;return}else{l=(e|0)/2|0;e=(f|0)/2|0;f=g+1|0;gib(a,b,l,e,f);gib(a,b+l|0,l,e,f);g=e*48|0;gib(a,b+g|0,l,e,f);gib(a,b+(g+l)|0,l,e,f);i=h;return}}function hib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;i=i+8|0;j=h|0;if((f|0)>3){k=(f|0)/2|0;f=(g|0)/2|0;hib(b,e,k,f);hib(b,e+k|0,k,f);g=f*48|0;hib(b,e+g|0,k,f);hib(b,e+(g+k)|0,k,f);i=h;return}Ttb(b,0,j);f=d[j]|0;k=0;g=1244088;while(1){l=g+4|0;m=c[l>>2]|0;if((f|0)>=(m|0)){n=c[g>>2]|0;if((f|0)<(n+m|0)){break}}k=k+1|0;g=g+8|0}Utb(b,n&255);Stb(b,(d[j]|0)-(c[l>>2]|0)&255);if((k&1|0)!=0){a[e]=1}if((k&2|0)!=0){a[e+1|0]=1}if((k&4|0)!=0){a[e+48|0]=1}if((k&8|0)==0){i=h;return}a[e+49|0]=1;i=h;return}function iib(a){a=a|0;var b=0,d=0;b=UHb()|0;c[a+804>>2]=b;if((b|0)==0){d=-12;return d|0}c[b+88>>2]=1;d=0;return d|0}function jib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+21704|0;j=h|0;k=h+8|0;l=h+18448|0;m=h+20752|0;n=h+21336|0;o=h+21696|0;p=c[b+60>>2]|0;mrc(k|0,0,18436)|0;mrc(m|0,0,580)|0;q=b+120|0;r=c[q>>2]|0;if((r|0)==48){s=c[b+124>>2]|0;if((s|0)==48){t=6}else{u=s}}else if((r|0)==0){if((c[b+124>>2]|0)==0){t=6}else{t=3}}else{t=3}if((t|0)==3){u=c[b+124>>2]|0}else if((t|0)==6){c[q>>2]=48;c[b+124>>2]=48;q=f+32|0;t=c[f>>2]|0;f=0;s=0;while(1){v=t+f|0;a[p+(s|4)|0]=(d[v]|0)>>>7;a[p+(s|5)|0]=(d[v]|0)>>>6&1;w=s|3;a[p+((s|1)+5)|0]=(d[v]|0)>>>5&1;a[p+(s|7)|0]=(d[v]|0)>>>4&1;a[p+(w+5)|0]=(d[v]|0)>>>3&1;a[p+(w+6)|0]=(d[v]|0)>>>2&1;a[p+(w+7)|0]=(d[v]|0)>>>1&1;a[p+((s|7)+4)|0]=a[v]&1;v=s+8|0;w=f+1|0;if((w|0)==6){x=t+(c[q>>2]|0)|0;y=0}else{x=t;y=w}if((v|0)<2304){t=x;f=y;s=v}else{break}}s=l|0;l=p+4|0;nrc(s|0,l|0,2304)|0;Vtb(l,s);lib(l,16,16,0,k);lib(p+20|0,16,16,0,k);lib(p+36|0,16,16,0,k);lib(p+772|0,16,16,0,k);lib(p+788|0,16,16,0,k);lib(p+804|0,16,16,0,k);lib(p+1540|0,16,16,0,k);lib(p+1556|0,16,16,0,k);lib(p+1572|0,16,16,0,k);p=k+18432|0;l=c[p>>2]|0;if((l|0)>0){s=l;do{l=s-1|0;c[p>>2]=l;y=c[k+(l<<2)>>2]|0;Ttb(m,c[y>>2]&255,j);Utb(m,0);Stb(m,(d[j]|0)+(c[y+4>>2]|0)&255);s=c[p>>2]|0;}while((s|0)>0)}s=m|0;if((c[s>>2]|0)==0){z=0}else{p=0;while(1){Ttb(m,94,o);j=p+1|0;a[n+p|0]=(a[o]|0)+33;if((c[s>>2]|0)==0){z=j;break}else{p=j}}}p=z+2|0;s=d5a(b,e,p,(p|0)<0|0?-1:0)|0;if((s|0)<0){A=s;i=h;return A|0}s=c[e+24>>2]|0;if((z|0)>0){p=s;o=z;while(1){m=o-1|0;a[p]=a[n+m|0]|0;if((m|0)>0){p=p+1|0;o=m}else{break}}B=s+z|0}else{B=s}a[B]=10;a[B+1|0]=0;B=e+36|0;c[B>>2]=c[B>>2]|1;c[g>>2]=1;A=0;i=h;return A|0}KIb(b,16,2439872,(b=i,i=i+32|0,c[b>>2]=r,c[b+8>>2]=u,c[b+16>>2]=48,c[b+24>>2]=48,b)|0);i=b;A=-22;i=h;return A|0}function kib(a){a=a|0;mJb(a+804|0);return 0}function lib(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=g+18432|0;i=f;f=e;e=d;d=b;a:while(1){b:do{if((a[d]|0)==0){if((f|0)==0){j=8;break a}else{k=d;l=f}while(1){b=l-1|0;m=e;n=k;while(1){if((m|0)==0){break}if((a[n]|0)==0){m=m-1|0;n=n+1|0}else{break b}}if((b|0)==0){j=8;break a}else{k=k+48|0;l=b}}}}while(0);n=(mib(d,e,f)|0)==0;o=c[h>>2]|0;p=(o|0)>4606;if(!n){j=11;break}if(!p){c[h>>2]=o+1;c[g+(o<<2)>>2]=1244e3+(i*24|0)}n=(e|0)/2|0;m=(f|0)/2|0;q=i+1|0;lib(d,n,m,q,g);lib(d+n|0,n,m,q,g);r=m*48|0;lib(d+r|0,n,m,q,g);i=q;f=m;e=n;d=d+(r+n)|0}if((j|0)==8){l=c[h>>2]|0;if((l|0)>4606){return}c[h>>2]=l+1;c[g+(l<<2)>>2]=1244008+(i*24|0);return}else if((j|0)==11){if(!p){c[h>>2]=o+1;c[g+(o<<2)>>2]=1243992+(i*24|0)}nib(g,d,e,f);return}}function mib(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;if((c|0)>3){e=(c|0)/2|0;c=(d|0)/2|0;if((mib(b,e,c)|0)==0){f=0;return f|0}if((mib(b+e|0,e,c)|0)==0){f=0;return f|0}d=c*48|0;if((mib(b+d|0,e,c)|0)==0){f=0;return f|0}else{return(mib(b+(d+e)|0,e,c)|0)!=0|0}}if((a[b]|0)!=0){f=1;return f|0}if((a[b+1|0]|0)!=0){f=1;return f|0}if((a[b+48|0]|0)!=0){f=1;return f|0}f=(a[b+49|0]|0)!=0|0;return f|0}function nib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e|0)>3){g=d;h=e;e=f;while(1){f=(h|0)/2|0;i=(e|0)/2|0;nib(b,g,f,i);nib(b,g+f|0,f,i);j=i*48|0;nib(b,g+j|0,f,i);k=g+(j+f)|0;if((h|0)>7){g=k;h=f;e=i}else{l=k;break}}}else{l=d}d=b+18432|0;e=c[d>>2]|0;if((e|0)>4606){return}h=1244088+((a[l]|0)+(a[l+1|0]<<1)+(a[l+48|0]<<2)+(a[l+49|0]<<3)<<3)|0;c[d>>2]=e+1;c[b+(e<<2)>>2]=h;return}function oib(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;do{if((e|0)>5){i=b;if(((he((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535|0)!=(f|0)){break}c[h>>2]=f;c[g>>2]=b+2;if((e-f|0)<6){j=-1;return j|0}i=f+2|0;k=f+6|0;l=b+i|0;m=(he((d[l]|d[l+1|0]<<8)<<16>>16|0)|0)&65535;c[h+4>>2]=m;c[g+4>>2]=b+(f+4);if((k|0)>(e-m|0)){j=-1;return j|0}else{l=i+(m+2)|0;i=b+l|0;n=(he((d[i]|d[i+1|0]<<8)<<16>>16|0)|0)&65535;c[h+8>>2]=n;c[g+8>>2]=b+(l+2);return((m+k|0)>(e-n|0))<<31>>31|0}}}while(0);if(!((e-3|0)>>>0<2147483133>>>0)){j=-1;return j|0}if((a[b]|0)==2){o=3;p=0;q=b}else{j=-1;return j|0}while(1){r=q+1|0;if((p|0)>=2){break}b=h+(p<<2)|0;c[b>>2]=0;a:do{if((o|0)<(e|0)){f=r;n=o;k=0;while(1){if(!((a[f]|0)==-1)){s=f;t=n;u=k;break a}m=k+255|0;c[b>>2]=m;l=n+256|0;i=f+1|0;if((l|0)<(e|0)){f=i;n=l;k=m}else{s=i;t=l;u=m;break}}}else{s=r;t=o;u=0}}while(0);c[b>>2]=u+(d[s]|0);k=(d[s]|0)+t|0;if((k|0)>(e|0)){j=-1;v=13;break}else{o=k;p=p+1|0;q=s}}if((v|0)==13){return j|0}c[h+8>>2]=e-o;c[g>>2]=r;r=(c[h>>2]|0)+1|0;c[g+4>>2]=q+r;c[g+8>>2]=q+(r+(c[h+4>>2]|0));j=0;return j|0}function pib(a){a=a|0;c[a+140>>2]=7;return 0}function qib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;h=i;j=c[g+24>>2]|0;k=c[g+28>>2]|0;g=b+120|0;l=c[g>>2]|0;if((l&3|0)!=0){KIb(b,16,2439840,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=h;return n|0}o=b+124|0;if((k|0)<(ca(c[o>>2]|0,l)|0)){KIb(b,16,2352568,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m;n=-1094995529;i=h;return n|0}m=M4a(b,e,0)|0;if((m|0)<0){n=m;i=h;return n|0}c[e+88>>2]=1;c[e+84>>2]=1;m=c[g>>2]|0;b=m-4|0;l=c[o>>2]|0;if((l|0)>0){p=e+32|0;q=e+36|0;r=e+40|0;s=c[e+8>>2]|0;t=0;u=c[e+4>>2]|0;v=c[e>>2]|0;e=j;j=0;w=0;x=0;y=m;m=l;while(1){l=e+b|0;if((y|0)>0){z=0;A=l;B=j;C=w;D=x;while(1){E=A;F=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;G=A-4|0;E=F>>>16;H=(z|0)!=0;if(H){I=(c[2040+((E&31)<<2)>>2]|0)+B|0}else{I=E<<2&124}E=(c[2040+((F>>>21&31)<<2)>>2]|0)+I|0;J=E+(c[2040+((F>>>26&31)<<2)>>2]|0)|0;K=J+(c[2040+((F&31)<<2)>>2]|0)|0;L=F>>>5&31;if(H){M=(c[2040+((F>>>10&31)<<2)>>2]|0)+D|0;N=(c[2040+(L<<2)>>2]|0)+C|0}else{M=F>>>10<<2&124;N=L<<2}a[v+z|0]=I<<1;a[v+(z|1)|0]=E<<1;a[v+(z|2)|0]=J<<1;a[v+(z|3)|0]=K<<1;J=z>>2;a[u+J|0]=N<<1;a[s+J|0]=M<<1;J=z+4|0;O=c[g>>2]|0;if((J|0)<(O|0)){z=J;A=G;B=K;C=N;D=M}else{break}}P=G;Q=K;R=N;S=M;T=O;U=c[o>>2]|0}else{P=l;Q=j;R=w;S=x;T=y;U=m}D=t+1|0;if((D|0)<(U|0)){s=s+(c[r>>2]|0)|0;t=D;u=u+(c[q>>2]|0)|0;v=v+(c[p>>2]|0)|0;e=P+(T+4)|0;j=Q;w=R;x=S;y=T;m=U}else{break}}}c[f>>2]=1;n=k;i=h;return n|0}function rib(a){a=a|0;c[a+140>>2]=11;return 0}function sib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=c[g+24>>2]|0;m=c[g+28>>2]|0;n=l+m|0;o=(c[b+52>>2]|0)==1095981124;if((m|0)<53){KIb(b,16,2439808,(p=i,i=i+8|0,c[p>>2]=m,p)|0);i=p;q=-1;i=h;return q|0}do{if((a[l]|0)==91){if((a[l+13|0]|0)!=45){break}if((a[l+26|0]|0)!=93){break}r=g+8|0;s=c[r>>2]|0;t=c[r+4>>2]|0;if((s|0)==0&(t|0)==(-2147483648|0)){u=0;v=0}else{c[j>>2]=1;c[j+4>>2]=1e6;c[k>>2]=1;c[k+4>>2]=1e3;r=XIb(s,t,j,k)|0;u=G;v=r}a:do{if((a[l+3|0]|0)==58){if((a[l+6|0]|0)!=58){w=0;break}if((a[l+9|0]|0)==46){x=0;y=0;z=0}else{w=0;break}do{r=(a[l+((d[311848+x|0]|0)+1)|0]|0)-48&255;if((r&255)>>>0>9>>>0){w=0;break a}t=wrc(r&255,0,z,y)|0;z=Erc(d[311864+x|0]|0,0,t,G)|0;y=G;x=x+1|0;}while(x>>>0<9>>>0);t=xrc(z,y,v,u)|0;w=t}else{w=0}}while(0);c[e+4>>2]=w;b:do{if((a[l+16|0]|0)==58){if((a[l+19|0]|0)!=58){A=0;break}if((a[l+22|0]|0)==46){B=0;C=0;D=0}else{A=0;break}do{t=(a[l+((d[311848+B|0]|0)+14)|0]|0)-48&255;if((t&255)>>>0>9>>>0){A=0;break b}r=wrc(t&255,0,D,C)|0;D=Erc(d[311864+B|0]|0,0,r,G)|0;C=G;B=B+1|0;}while(B>>>0<9>>>0);r=xrc(D,C,v,u)|0;A=r}else{A=0}}while(0);c[e+8>>2]=A;r=l+27|0;t=(d[r]|d[r+1|0]<<8)<<16>>16;r=t&65535;s=l+29|0;E=(d[s]|d[s+1|0]<<8)<<16>>16;s=E&65535;if((tIb(r,s,0,b)|0)<0){q=-1;i=h;return q|0}F=l+31|0;H=(d[F]|d[F+1|0]<<8)<<16>>16&65535;F=l+33|0;I=(d[F]|d[F+1|0]<<8)<<16>>16&65535;F=l+41|0;J=e+16|0;c[J>>2]=pJb(4)|0;K=pJb(100)|0;c[c[J>>2]>>2]=K;c[e+12>>2]=1;K=c[c[J>>2]>>2]|0;c[K>>2]=H;c[K+4>>2]=I;c[K+8>>2]=r;c[K+12>>2]=s;c[K+84>>2]=1;c[K+52>>2]=r;K=hJb(ca(s,r)|0)|0;c[(c[c[J>>2]>>2]|0)+20>>2]=K;c[(c[c[J>>2]>>2]|0)+16>>2]=4;K=pJb(1024)|0;c[(c[c[J>>2]>>2]|0)+24>>2]=K;K=c[c[J>>2]>>2]|0;I=K+16|0;do{if((c[I>>2]|0)>0){H=c[K+24>>2]|0;L=F;M=0;while(1){N=L+3|0;c[H+(M<<2)>>2]=d[L+1|0]<<8|d[L]<<16|d[L+2|0];O=M+1|0;P=c[I>>2]|0;if((O|0)<(P|0)){L=N;M=O}else{break}}if((P|0)<=0){Q=N;break}if(o){M=N;L=0;while(1){H=M+1|0;O=(c[K+24>>2]|0)+(L<<2)|0;c[O>>2]=c[O>>2]|d[M]<<24;O=L+1|0;if((O|0)<(c[I>>2]|0)){M=H;L=O}else{Q=H;break}}}else{L=0;while(1){M=(c[K+24>>2]|0)+(L<<2)|0;c[M>>2]=c[M>>2]|((L|0)!=0?-16777216:0);M=L+1|0;if((M|0)<(c[I>>2]|0)){L=M}else{Q=N;break}}}}else{Q=F}}while(0);F=n-Q<<3;I=F>>>0>2147483639>>>0|(Q|0)==0;L=I?0:Q;M=I?8:F+8|0;do{if(!(E<<16>>16==0)){F=(s+1|0)>>>1;if(t<<16>>16==0){break}else{R=0;S=0;T=c[K+20>>2]|0}while(1){if((S|0)==(F|0)){U=R;V=0;W=(c[(c[c[J>>2]>>2]|0)+20>>2]|0)+r|0}else{U=R;V=0;W=T}while(1){I=L+(U>>>3)|0;H=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(U&7);I=14-((d[1359664+(H>>>24)|0]|0)>>>1<<2)|0;O=H>>>((32-I|0)>>>0);H=I+U|0;I=M>>>0>H>>>0?H:M;H=L+(I>>>3)|0;X=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(I&7)>>>30;H=I+2|0;Y=M>>>0>H>>>0?H:M;H=r-V|0;I=(O|0)>(H|0)?H:O;Z=(I|0)==0?H:I;mrc(W|0,X&255|0,Z|0)|0;X=Z+V|0;if((X|0)<(r|0)){U=Y;V=X;W=W+Z|0}else{break}}X=-Y&7;if((X|0)==0){_=Y}else{I=X+Y|0;_=M>>>0>I>>>0?I:M}I=S+1|0;if((I|0)<(s|0)){R=_;S=I;T=W+(Z+r)|0}else{break}}}}while(0);c[f>>2]=1;q=m;i=h;return q|0}}while(0);KIb(b,16,2352488,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0}function tib(a){a=a|0;var b=0;b=a+52|0;if((c[b>>2]|0)==0){c[b>>2]=1112758340}c[a+792>>2]=4;return 0}function uib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;h=i;i=i+24|0;j=h|0;k=g+24|0;l=Crc(c[k>>2]|0,c[k+4>>2]|0,1e3,0)|0;k=G;m=wrc(c[g+8>>2]|0,0,l,k)|0;n=xrc(m,G,c[g+4>>2]|0,0)|0;m=G;o=e+27|0;if((f|0)<53){KIb(b,16,2439720,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0}r=c[g+12>>2]|0;if((r|0)!=1){KIb(b,24,2352408,(p=i,i=i+8|0,c[p>>2]=r,p)|0);i=p}r=g+16|0;g=c[c[r>>2]>>2]|0;do{if((c[g+20>>2]|0)!=0){s=c[g+24>>2]|0;if((s|0)==0){break}t=c[g+16>>2]|0;if((t|0)>4){KIb(b,24,2240016,(p=i,i=i+8|0,c[p>>2]=t,p)|0);i=p;u=c[(c[c[r>>2]>>2]|0)+24>>2]|0}else{u=s}if((c[u>>2]|0)>>>0>16777215>>>0){KIb(b,24,2199008,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}s=0;t=0;if(k>>>0>s>>>0|k>>>0==s>>>0&l>>>0>359999999>>>0|(m>>>0>t>>>0|m>>>0==t>>>0&n>>>0>359999999>>>0)){KIb(b,24,2167464,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0}t=Frc(l,k,6e4,0)|0;s=G;v=Frc(l,k,1e3,0)|0;w=G;x=Frc(l,k,36e5,0)|0;z=Grc(t,s,60,0)|0;s=Grc(v,w,60,0)|0;w=Grc(l,k,1e3,0)|0;v=Frc(n,m,6e4,0)|0;t=G;A=Frc(n,m,1e3,0)|0;B=G;C=Frc(n,m,36e5,0)|0;D=Grc(v,t,60,0)|0;t=Grc(A,B,60,0)|0;B=Grc(n,m,1e3,0)|0;Rb(e|0,28,2140896,(p=i,i=i+64|0,c[p>>2]=x,c[p+8>>2]=z,c[p+16>>2]=s,c[p+24>>2]=w,c[p+32>>2]=C,c[p+40>>2]=D,c[p+48>>2]=t,c[p+56>>2]=B,p)|0)|0;i=p;B=c[c[r>>2]>>2]|0;t=(c[B+12>>2]|0)+1|0;D=(c[B+8>>2]|0)+1&65534;B=o;y=D&65535;a[B]=y;y=y>>8;a[B+1|0]=y;B=t&65534;t=e+29|0;y=B&65535;a[t]=y;y=y>>8;a[t+1|0]=y;t=e+31|0;y=c[c[c[r>>2]>>2]>>2]&65535;a[t]=y;y=y>>8;a[t+1|0]=y;t=e+33|0;y=c[(c[c[r>>2]>>2]|0)+4>>2]&65535;a[t]=y;y=y>>8;a[t+1|0]=y;t=e+35|0;y=D+65535+(c[c[c[r>>2]>>2]>>2]|0)&65535;a[t]=y;y=y>>8;a[t+1|0]=y;t=e+37|0;y=B+65535+(c[(c[c[r>>2]>>2]|0)+4>>2]|0)&65535;a[t]=y;y=y>>8;a[t+1|0]=y;t=c[c[(c[c[r>>2]>>2]|0)+24>>2]>>2]|0;a[e+43|0]=t;a[e+42|0]=t>>>8;a[e+41|0]=t>>>16;t=c[(c[(c[c[r>>2]>>2]|0)+24>>2]|0)+4>>2]|0;a[e+46|0]=t;a[e+45|0]=t>>>8;a[e+44|0]=t>>>16;t=c[(c[(c[c[r>>2]>>2]|0)+24>>2]|0)+8>>2]|0;a[e+49|0]=t;a[e+48|0]=t>>>8;a[e+47|0]=t>>>16;t=c[(c[(c[c[r>>2]>>2]|0)+24>>2]|0)+12>>2]|0;a[e+52|0]=t;a[e+51|0]=t>>>8;a[e+50|0]=t>>>16;t=e+53|0;B=e-2+f-t|0;D=(B|0)<0;C=D?0:t;t=D?0:B;c[j+20>>2]=t<<3;B=j+8|0;c[B>>2]=C;c[j+16>>2]=C+t;t=j+12|0;c[t>>2]=C;C=j+4|0;c[C>>2]=32;D=j|0;c[D>>2]=0;w=c[c[r>>2]>>2]|0;if((vib(j,c[w+20>>2]|0,c[w+52>>2]<<1,c[w+8>>2]|0,(c[w+12>>2]|0)+1>>1)|0)!=0){q=-1;i=h;return q|0}w=e+39|0;y=(32-(c[C>>2]|0)+((c[t>>2]|0)-(c[B>>2]|0)<<3)|0)>>>3&65535;a[w]=y;y=y>>8;a[w+1|0]=y;w=c[c[r>>2]>>2]|0;s=c[w+52>>2]|0;if((vib(j,(c[w+20>>2]|0)+s|0,s<<1,c[w+8>>2]|0,c[w+12>>2]>>1)|0)!=0){q=-1;i=h;return q|0}w=c[c[r>>2]>>2]|0;if((c[w+12>>2]&1|0)!=0){s=c[w+8>>2]|0;do{if((s|0)<256){w=(d[1359664+s|0]|0)>>>1<<2|2;z=c[D>>2]|0;x=c[C>>2]|0;if((x|0)>(w|0)){E=x;F=z<<w|s}else{A=je(s>>>((w-x|0)>>>0)|z<<x|0)|0;z=c[t>>2]|0;y=A;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;E=x+32|0;F=s}H=E-w|0;I=F}else{w=c[D>>2]|0;x=c[C>>2]|0;if((x|0)>14){H=x-14|0;I=w<<14;break}else{z=je(w<<x|0)|0;w=c[t>>2]|0;y=z;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;H=x+18|0;I=0;break}}}while(0);c[D>>2]=I;c[C>>2]=H;if((H|0)>2){J=H-2|0;K=I<<2}else{s=je(I<<H|0)|0;x=c[t>>2]|0;y=s;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;J=H+30|0;K=0}c[D>>2]=K;c[C>>2]=J;Y2(j)}x=c[C>>2]|0;if((x|0)<32){s=c[D>>2]<<x;c[D>>2]=s;x=s>>>24&255;while(1){s=c[t>>2]|0;c[t>>2]=s+1;a[s]=x;s=c[D>>2]|0;c[D>>2]=s<<8;w=(c[C>>2]|0)+8|0;c[C>>2]=w;if((w|0)<32){x=s>>>16&255}else{break}}}c[C>>2]=32;c[D>>2]=0;q=(((c[t>>2]|0)-(c[B>>2]|0)<<3|0)/8|0)+53|0;i=h;return q|0}}while(0);KIb(b,24,2290464,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1;i=h;return q|0}function vib(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((h|0)<=0){i=0;return i|0}j=(g|0)>0;k=g&1;l=(k|0)==0;m=1359664+k|0;n=b|0;o=b+4|0;p=b+12|0;q=b+20|0;r=b+8|0;s=e;e=0;t=0;a:while(1){if(j){u=0;v=c[o>>2]|0;w=c[p>>2]|0;while(1){if(((c[q>>2]|0)-32+v-(w-(c[r>>2]|0)<<3)|0)<56){i=-1;x=33;break a}z=a[s+u|0]&3;A=u;do{A=A+1|0;if((A|0)>=(g|0)){break}}while((a[s+A|0]&3|0)==(z|0));B=A-u|0;if((A|0)==(g|0)&(z|0)==0){C=B+k|0}else{C=(B|0)>255?255:B}do{if((C|0)<256){B=(d[1359664+C|0]|0)>>>1<<2|2;D=c[n>>2]|0;if((v|0)>(B|0)){E=v;F=D<<B|C;G=w}else{H=w;y=je(C>>>((B-v|0)>>>0)|D<<v|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=(c[p>>2]|0)+4|0;c[p>>2]=H;E=v+32|0;F=C;G=H}I=G;J=E-B|0;K=F}else{B=c[n>>2]|0;if((v|0)>14){I=w;J=v-14|0;K=B<<14;break}else{H=w;y=je(B<<v|0)|0;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;H=(c[p>>2]|0)+4|0;c[p>>2]=H;I=H;J=v+18|0;K=0;break}}}while(0);c[n>>2]=K;c[o>>2]=J;if((J|0)>2){L=J-2|0;M=K<<2|z;N=I}else{A=I;y=je(z>>>((2-J|0)>>>0)|K<<J|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;A=(c[p>>2]|0)+4|0;c[p>>2]=A;L=J+30|0;M=z;N=A}c[n>>2]=M;c[o>>2]=L;A=C+u|0;if((A|0)<(g|0)){u=A;v=L;w=N}else{O=z;break}}}else{O=t}if(!((O|0)==0|l)){w=(d[m]|0)>>>1<<2|2;v=c[n>>2]|0;u=c[o>>2]|0;if((u|0)>(w|0)){P=u;Q=v<<w|k}else{A=je(k>>>((w-u|0)>>>0)|v<<u|0)|0;v=c[p>>2]|0;y=A;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;P=u+32|0;Q=k}u=P-w|0;c[n>>2]=Q;c[o>>2]=u;if((u|0)>2){R=u-2|0;S=Q<<2}else{w=je(Q<<u|0)|0;v=c[p>>2]|0;y=w;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;R=u+30|0;S=0}c[n>>2]=S;c[o>>2]=R}Y2(b);u=e+1|0;if((u|0)<(h|0)){s=s+f|0;e=u;t=O}else{i=0;x=33;break}}if((x|0)==33){return i|0}return 0}function wib(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;h=b;j=c[f+28>>2]|0;if((j|0)<100){k=-1094995529;i=g;return k|0}l=c[f+24>>2]|0;f=l;m=je(d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)|0;f=l+4|0;if((d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0)!=117440512){KIb(a,16,2439648,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(j>>>0<m>>>0|m>>>0<100>>>0){KIb(a,16,2352344,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}f=l+8|0;o=d[f]|d[f+1|0]<<8|d[f+2|0]<<16|d[f+3|0]<<24|0;f=je(o|0)|0;p=l+12|0;q=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=je(q|0)|0;r=l+16|0;s=a+120|0;c[s>>2]=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;r=l+20|0;t=a+124|0;c[t>>2]=je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0;r=l+24|0;u=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=je(u|0)|0;v=l+28|0;w=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;v=je(w|0)|0;x=l+32|0;y=je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0;x=l+36|0;z=je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0;x=l+40|0;A=je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0;x=l+44|0;B=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=je(B|0)|0;C=l+48|0;D=je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=l+52|0;E=je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=l+56|0;F=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=je(F|0)|0;G=l+60|0;H=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;G=je(H|0)|0;I=l+64|0;J=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;I=je(J|0)|0;K=l+76|0;L=d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0;K=je(L|0)|0;M=l+m|0;N=a;KIb(N,48,2290368,(n=i,i=i+40|0,c[n>>2]=f,c[n+8>>2]=p,c[n+16>>2]=y,c[n+24>>2]=z,c[n+32>>2]=A,n)|0);i=n;KIb(N,48,2239952,(n=i,i=i+48|0,c[n>>2]=E,c[n+8>>2]=K,c[n+16>>2]=x,c[n+24>>2]=v,c[n+32>>2]=D,c[n+40>>2]=r,n)|0);i=n;KIb(N,48,2198976,(n=i,i=i+24|0,c[n>>2]=C,c[n+8>>2]=G,c[n+16>>2]=I,n)|0);i=n;if(f>>>0>2>>>0){KIb(N,16,2167440,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if((q|0)==0|p>>>0>32>>>0){KIb(N,16,2140872,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if((u|0)!=0){QIb(N,2117424,(n=i,i=i+8|0,c[n>>2]=r,n)|0);i=n;k=-1163346256;i=g;return k|0}if(v>>>0>1>>>0){KIb(N,16,2635200,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(z>>>0>1>>>0){KIb(N,16,2611784,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(!((y|0)==32|(y|0)==16|(y|0)==8)){KIb(N,16,2585168,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(!((A|0)==32|(A|0)==16|(A|0)==8)){KIb(N,16,2564392,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if((B|0)==0|x>>>0>32>>>0){KIb(N,16,2546392,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if(K>>>0>256>>>0){KIb(N,16,2528768,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}y=tIb(c[s>>2]|0,c[t>>2]|0,0,0)|0;if((y|0)<0){k=y;i=g;return k|0}y=(A-1+(ca(c[s>>2]|0,x)|0)&-A)>>>3;if(D>>>0<y>>>0){KIb(N,16,2513616,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}A=K*12|0;if((j-m|0)>>>0<((ca(c[t>>2]|0,D)|0)+A|0)>>>0){KIb(N,16,2499984,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}if((o|0)!=33554432){RIb(N,2487336,(n=i,i=i+8|0,c[n>>2]=f,n)|0);i=n;k=-1163346256;i=g;return k|0}f=a+140|0;c[f>>2]=-1;a:do{switch(E|0){case 4:case 5:{if(!((x|0)==32|(x|0)==24|(x|0)==16)){k=-1094995529;i=g;return k|0}o=(B|0)==268435456;do{if(o&(q|0)==251658240){s=(H|0)==-536674304;if((F|0)==8126464&s&(J|0)==520093696){c[f>>2]=(w|0)!=0?45:46;break}if(!((F|0)==520093696&s&(J|0)==8126464)){O=60;break a}c[f>>2]=(w|0)!=0?49:50}else{if(o&(q|0)==268435456){s=(H|0)==-536412160;if((F|0)==16252928&s&(J|0)==520093696){c[f>>2]=(w|0)!=0?43:44;break}if(!((F|0)==520093696&s&(J|0)==16252928)){O=60;break a}c[f>>2]=(w|0)!=0?47:48;break}if((x|0)==24){s=(H|0)==16711680;if((F|0)==65280&s&(J|0)==-16777216){c[f>>2]=(w|0)!=0?2:3;break}if(!((F|0)==-16777216&s&(J|0)==65280)){O=60;break a}c[f>>2]=(w|0)!=0?3:2;break}else if((x|0)==32){s=(H|0)==16711680;if((F|0)==65280&s&(J|0)==-16777216){c[f>>2]=(w|0)!=0?27:30;break}if(!((F|0)==-16777216&s&(J|0)==65280)){O=60;break a}c[f>>2]=(w|0)!=0?29:28;break}else{O=60;break a}}}while(0);P=l+(A+m)|0;break};case 0:case 1:{if(!((x|0)==8|(x|0)==1)){k=-1094995529;i=g;return k|0}if((p|0)==8){c[f>>2]=8;P=M;break a}else if((p|0)==1){c[f>>2]=9;P=M;break a}else{O=60;break a}break};case 2:case 3:{if((B|0)!=134217728){O=60;break a}c[f>>2]=11;P=M;break};default:{KIb(N,16,2476024,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;k=-1094995529;i=g;return k|0}}}while(0);if((O|0)==60){QIb(N,2466840,(n=i,i=i+24|0,c[n>>2]=x,c[n+8>>2]=p,c[n+16>>2]=E,n)|0);i=n;k=-1163346256;i=g;return k|0}n=M4a(a,h,0)|0;if((n|0)<0){k=n;i=g;return k|0}c[b+84>>2]=1;c[b+88>>2]=1;do{if((c[f>>2]|0)==11){n=c[b+4>>2]|0;if((L|0)==0){Q=P;break}h=K>>>0>1>>>0?K*12|0:12;a=P;E=0;while(1){c[n+(E<<2)>>2]=(d[a+6|0]|0)<<8|(d[a+4|0]|0)<<16|(d[a+8|0]|0);p=E+1|0;if(p>>>0<K>>>0){a=a+12|0;E=p}else{break}}Q=P+h|0}else{Q=P}}while(0);if((c[t>>2]|0)>0){P=b+32|0;K=Q;Q=c[b>>2]|0;b=0;while(1){nrc(Q|0,K|0,y)|0;L=b+1|0;if((L|0)<(c[t>>2]|0)){K=K+D|0;Q=Q+(c[P>>2]|0)|0;b=L}else{break}}}c[e>>2]=1;k=j;i=g;return k|0}function xib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0;g=i;h=c[b+140>>2]|0;j=qKb(h)|0;k=oKb(j)|0;l=a[j+7|0]&1;switch(h|0){case 29:case 27:{m=1;n=3;break};case 11:case 21:case 22:case 19:case 24:{o=k;p=8;q=8;r=256;s=3;t=l;u=0;v=0;w=0;x=0;break};case 9:{o=k;p=1;q=8;r=0;s=0;t=1;u=0;v=1;w=0;x=0;break};case 46:case 45:case 50:case 49:{j=(h-49|0)>>>0<2>>>0;o=k;p=16;q=16;r=0;s=4;t=l;u=j?31744:31;v=0;w=j?31:31744;x=992;break};case 2:{o=k;p=24;q=32;r=0;s=4;t=1;u=255;v=0;w=16711680;x=65280;break};case 28:case 30:{m=l;n=3;break};case 44:case 43:case 48:case 47:{j=(h-47|0)>>>0<2>>>0;o=k;p=16;q=16;r=0;s=4;t=l;u=j?63488:31;v=0;w=j?31:63488;x=2016;break};case 3:{o=k;p=24;q=32;r=0;s=4;t=l;u=255;v=0;w=16711680;x=65280;break};case 8:{o=k;p=8;q=8;r=0;s=0;t=l;u=0;v=0;w=0;x=0;break};default:{KIb(b,16,2439520,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;z=-22;i=g;return z|0}}if((n|0)==3){n=(h-28|0)>>>0<2>>>0;o=24;p=32;q=32;r=0;s=4;t=m;u=n?16711680:255;v=0;w=n?255:16711680;x=65280}n=b+120|0;m=(q-1+(ca(c[n>>2]|0,p)|0)&-q)>>>3;h=r*12|0;l=b+124|0;k=(ca(m,c[l>>2]|0)|0)+(h|111)|0;j=d5a(b,d,k,(k|0)<0|0?-1:0)|0;if((j|0)<0){z=j;i=g;return z|0}j=c[d+24>>2]|0;c[e+84>>2]=1;c[e+88>>2]=1;k=j;y=1862270976;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+4|0;y=117440512;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+8|0;y=33554432;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+12|0;y=je(o|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+16|0;y=je(c[n>>2]|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+20|0;y=je(c[l>>2]|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+24|0;y=0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+28|0;y=je(t|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+32|0;y=536870912;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+36|0;y=je(v|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+40|0;y=je(q|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+44|0;y=je(p|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+48|0;y=je(m|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+52|0;y=je(s|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+56|0;y=je(w|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+60|0;y=je(x|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+64|0;y=je(u|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=j+68|0;y=134217728;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=je(r|0)|0;u=j+72|0;y=k;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=j+76|0;y=k;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=j+80|0;y=je(c[n>>2]|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=j+84|0;y=je(c[l>>2]|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=j+88|0;y=0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=j+92|0;y=0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;u=j+96|0;y=0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;nrc(j+100|0,2352264,11)|0;u=j+111|0;if((r|0)==0){A=u}else{n=e+4|0;k=h|111;h=u;u=0;while(1){x=c[(c[n>>2]|0)+(u<<2)>>2]|0;w=h;y=je(u|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;w=h+4|0;y=he(x>>>16<<8&65535|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;w=h+6|0;y=he(x&65535&-256|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;w=h+8|0;y=he(x<<8&65535|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;a[h+10|0]=7;a[h+11|0]=0;w=u+1|0;if(w>>>0<r>>>0){h=h+12|0;u=w}else{break}}A=j+k|0}if((c[l>>2]|0)>0){k=e+32|0;j=A;A=0;u=c[e>>2]|0;while(1){nrc(j|0,u|0,m)|0;e=A+1|0;if((e|0)<(c[l>>2]|0)){j=j+m|0;A=e;u=u+(c[k>>2]|0)|0}else{break}}}k=d+36|0;c[k>>2]=c[k>>2]|1;c[f>>2]=1;z=0;i=g;return z|0}function yib(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a+60|0;e=c[d>>2]|0;c[e>>2]=a;c[a+140>>2]=0;f=c[a+124>>2]|0;if((f|0)<8){KIb(a,16,2611752,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-22;i=b;return h|0}j=c[a+120>>2]|0;if((j&1|0)!=0){KIb(a,16,2585120,(g=i,i=i+8|0,c[g>>2]=j,g)|0);i=g;h=-22;i=b;return h|0}g=ca(j,f)|0;f=e+16|0;c[f>>2]=g;j=hJb(g)|0;c[e+8>>2]=j;if((j|0)==0){h=-12;i=b;return h|0}j=hJb((c[f>>2]|0)+130|0)|0;c[e+12>>2]=j;if((j|0)==0){j=c[d>>2]|0;VHb(j+4|0);mJb(j+8|0);mJb(j+12|0);h=-12;i=b;return h|0}j=UHb()|0;c[e+4>>2]=j;if((j|0)!=0){h=0;i=b;return h|0}j=c[d>>2]|0;VHb(j+4|0);mJb(j+8|0);mJb(j+12|0);h=-12;i=b;return h|0}function zib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;h=i;j=b+60|0;k=c[j>>2]|0;l=k+4|0;m=N4a(b,c[l>>2]|0)|0;if((m|0)<0){n=m;i=h;return n|0}m=c[g+24>>2]|0;o=g+28|0;g=c[o>>2]|0;if(!((g|0)>-1)){KIb(0,0,2140840,(p=i,i=i+24|0,c[p>>2]=2117408,c[p+8>>2]=2635176,c[p+16>>2]=135,p)|0);i=p;Hd();return 0}q=k+20|0;c[q>>2]=m;c[k+28>>2]=m;c[k+24>>2]=m+g;do{if((g|0)<4){r=6}else{c[q>>2]=m+4;k=m;s=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;if((s|0)==0){r=6;break}else if((s|0)!=1){KIb(b,16,2439480,(p=i,i=i+8|0,c[p>>2]=s,p)|0);i=p;n=-1094995529;i=h;return n|0}s=c[j>>2]|0;k=c[s+12>>2]|0;t=s+24|0;u=s+20|0;v=c[u>>2]|0;if(((c[t>>2]|0)-v|0)<4){w=0}else{c[u>>2]=v+4;x=v;w=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0}x=Bib(b,w)|0;if((x|0)!=0){n=x;i=h;return n|0}x=c[s+28>>2]|0;v=(c[t>>2]|0)-x|0;c[u>>2]=x+((v|0)<16?v:16);v=Cib(s,k,c[s+16>>2]>>1)|0;if((v|0)!=0){KIb(b,16,2352208,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=v;i=h;return n|0}v=s+8|0;x=b+124|0;if((c[x>>2]|0)<=0){break}u=b+120|0;t=c[v>>2]|0;y=k;k=0;while(1){z=((d[y]|0)<<1)+(d[t]|0)&63;A=z&255;a[t]=A;B=y+1|0;if(((c[u>>2]|0)-1|0)>1){C=z;z=1;D=B;while(1){E=t+(z+1)|0;F=((d[D]|0)<<1)+(d[E]|0)&63;a[t+z|0]=(F+C|0)>>>1;G=F&255;a[E]=G;E=z+2|0;H=D+1|0;if((E|0)<((c[u>>2]|0)-1|0)){C=F;z=E;D=H}else{I=G;J=E;K=H;break}}}else{I=A;J=1;K=B}a[t+J|0]=I;L=c[u>>2]|0;D=k+1|0;M=c[x>>2]|0;if((D|0)<(M|0)){t=t+L|0;y=K;k=D}else{break}}k=s+4|0;if((M|0)<=0){break}y=c[k>>2]|0;t=c[y>>2]|0;D=c[v>>2]|0;z=0;C=L;H=y;y=M;while(1){if((C|0)>0){E=0;do{G=a[D+E|0]|0;a[t+E|0]=G<<2|(G&255)>>>3;E=E+1|0;N=c[u>>2]|0;}while((E|0)<(N|0));O=N;P=c[k>>2]|0;Q=c[x>>2]|0}else{O=C;P=H;Q=y}E=z+1|0;if((E|0)<(Q|0)){t=t+(c[P+32>>2]|0)|0;D=D+O|0;z=E;C=O;H=P;y=Q}else{break}}}}while(0);do{if((r|0)==6){Q=c[j>>2]|0;P=Q;O=Q+12|0;N=c[O>>2]|0;M=Q+24|0;L=Q+20|0;K=c[L>>2]|0;I=c[M>>2]|0;if((I-K|0)<4){R=0;S=K}else{J=K+4|0;c[L>>2]=J;w=K;R=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;S=J}if((I-S|0)<4){T=0}else{c[L>>2]=S+4;I=S;T=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0}I=Bib(b,R)|0;if((I|0)!=0){n=I;i=h;return n|0}I=c[M>>2]|0;J=Q+28|0;w=c[J>>2]|0;if(T>>>0<(I-w|0)>>>0){U=T;V=I;W=w}else{KIb(b,24,2167392,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;U=0;V=c[M>>2]|0;W=c[J>>2]|0}w=V-W|0;c[L>>2]=W+((w|0)<12?w:12);w=Q+16|0;I=Cib(P,N,c[w>>2]>>1)|0;if((I|0)!=0){KIb(b,16,2352208,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;n=I;i=h;return n|0}I=Q+8|0;K=c[I>>2]|0;m=a[N]|0;q=m&255;a[K]=m<<1;m=N+1|0;N=b+120|0;if(((c[N>>2]|0)-1|0)>1){g=q;y=1;H=m;while(1){C=(d[H]|0)+g&31;a[K+y|0]=C+g;a[K+(y+1)|0]=C<<1;z=y+2|0;D=H+1|0;if((z|0)<((c[N>>2]|0)-1|0)){g=C;y=z;H=D}else{X=C;Y=z;Z=D;break}}}else{X=q;Y=1;Z=m}a[K+Y|0]=X<<1;H=b+124|0;y=c[H>>2]|0;if((y|0)>1){g=K+(c[N>>2]|0)|0;D=K;z=Z;C=1;while(1){t=((d[D]|0)>>>1)+(d[z]|0)&31;a[g]=t<<1;x=z+1|0;if(((c[N>>2]|0)-1|0)>1){k=t;u=1;v=x;while(1){s=u+1|0;E=((d[D+s|0]|0)>>>1)+(d[v]|0)&31;a[g+u|0]=E+k;a[g+s|0]=E<<1;s=u+2|0;B=v+1|0;if((s|0)<((c[N>>2]|0)-1|0)){k=E;u=s;v=B}else{_=E;$=s;aa=B;break}}}else{_=t;$=1;aa=x}a[g+$|0]=_<<1;v=C+1|0;u=c[H>>2]|0;if((v|0)<(u|0)){D=g;g=g+(c[N>>2]|0)|0;z=aa;C=v}else{ba=u;break}}}else{ba=y}if((U|0)==0){ca=ba}else{C=U+8|0;z=c[J>>2]|0;g=(c[M>>2]|0)-z|0;if((C|0)<0){da=0}else{da=(g|0)<(C|0)?g:C}c[L>>2]=z+da;z=Dib(P,c[O>>2]|0,(c[w>>2]|0)/2|0)|0;do{if((z|0)>=0){C=((c[w>>2]|0)/2|0)-1|0;g=(z|0)>(C|0)?C:z;if((g|0)>0){ea=0}else{break}do{C=(c[I>>2]|0)+(ea<<1|1)|0;a[C]=(a[(c[O>>2]|0)+ea|0]<<1)+(a[C]|0)&63;ea=ea+1|0;}while((ea|0)<(g|0))}}while(0);ca=c[H>>2]|0}O=Q+4|0;if((ca|0)<=0){break}z=c[O>>2]|0;w=c[z>>2]|0;P=c[I>>2]|0;L=0;M=c[N>>2]|0;J=z;z=ca;while(1){if((M|0)>0){y=0;do{g=a[P+y|0]|0;a[w+y|0]=g<<2|(g&255)>>>3;y=y+1|0;fa=c[N>>2]|0;}while((y|0)<(fa|0));ga=fa;ha=c[O>>2]|0;ia=c[H>>2]|0}else{ga=M;ha=J;ia=z}y=L+1|0;if((y|0)<(ia|0)){w=w+(c[ha+32>>2]|0)|0;P=P+ga|0;L=y;M=ga;J=ha;z=ia}else{break}}}}while(0);ia=YHb(e,c[l>>2]|0)|0;if((ia|0)<0){n=ia;i=h;return n|0}c[f>>2]=1;n=c[o>>2]|0;i=h;return n|0}function Aib(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+4|0);mJb(b+8|0);mJb(b+12|0);return 0}function Bib(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;f=i;g=c[b+60>>2]|0;if((e|0)==0){h=0;i=f;return h|0}j=e+4|0;e=g+20|0;k=c[g+24>>2]|0;if(!(j>>>0<(k-(c[e>>2]|0)|0)>>>0)){KIb(b,16,2290272,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;h=-1094995529;i=f;return h|0}m=c[g+28>>2]|0;n=k-m|0;if((j|0)<0){o=0}else{o=(n|0)<(j|0)?n:j}j=m+o|0;c[e>>2]=j;if((k-j|0)<2){p=0;q=j}else{n=m+(o+2)|0;c[e>>2]=n;o=j;p=(d[o]|d[o+1|0]<<8)<<16>>16&65535;q=n}if((k-q|0)<2){r=0;s=q}else{n=q+2|0;c[e>>2]=n;o=q;r=(d[o]|d[o+1|0]<<8)<<16>>16&65535;s=n}n=r<<1;o=r+1|0;if(!(n>>>0<(k-s|0)>>>0)){KIb(b,16,2239856,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;h=-1094995529;i=f;return h|0}c[e>>2]=s+n;n=g+12|0;s=g+16|0;mrc(c[n>>2]|0,0,c[s>>2]|0)|0;e=Dib(g,c[n>>2]|0,c[s>>2]|0)|0;if((e|0)<0){KIb(b,16,2198928,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;h=e;i=f;return h|0}l=g+4|0;g=c[l>>2]|0;s=c[g+4>>2]|0;k=c[g+8>>2]|0;r=c[n>>2]|0;n=r+e|0;e=b+124|0;j=c[e>>2]|0;if((p|0)==0){p=j>>2;a:do{if((p|0)>0){m=b+120|0;t=n;u=0;v=r;w=k;x=s;y=s+(c[g+36>>2]|0)|0;z=k+(c[g+40>>2]|0)|0;A=c[m>>2]|0;B=g;C=j;b:while(1){if((A>>1|0)>0){D=0;E=v;F=A;while(1){if((t-E|0)<1){h=0;G=39;break b}H=E+1|0;I=a[E]|0;J=I&255;if(I<<24>>24==0){K=F}else{if(!(J>>>0<o>>>0)){h=-1094995529;G=39;break b}I=q+(J<<1)|0;J=(d[I]|d[I+1|0]<<8)<<16>>16&65535;I=J>>>3&248;L=(I>>>5|I)&255;I=D|1;a[y+I|0]=L;a[y+D|0]=L;a[x+I|0]=L;a[x+D|0]=L;L=(J>>>8&248|J>>>13)&255;a[z+I|0]=L;a[z+D|0]=L;a[w+I|0]=L;a[w+D|0]=L;K=c[m>>2]|0}L=D+2|0;if((L|0)<(K>>1|0)){D=L;E=H;F=K}else{break}}M=H;N=K;O=c[l>>2]|0;P=c[e>>2]|0}else{M=v;N=A;O=B;P=C}F=c[O+36>>2]<<1;E=x+F|0;D=c[O+40>>2]<<1;L=w+D|0;I=u+1|0;J=P>>2;if((I|0)<(J|0)){u=I;v=M;w=L;x=E;y=y+F|0;z=z+D|0;A=N;B=O;C=P}else{Q=L;R=E;S=P;T=J;U=O;break a}}if((G|0)==39){i=f;return h|0}}else{Q=k;R=s;S=j;T=p;U=g}}while(0);if((S&3|0)==0){h=0;i=f;return h|0}p=(S+1>>1)-(T<<1)|0;T=ca(c[U+36>>2]|0,p)|0;nrc(R|0,R+(-T|0)|0,T)|0;T=ca(c[(c[l>>2]|0)+40>>2]|0,p)|0;nrc(Q|0,Q+(-T|0)|0,T)|0;h=0;i=f;return h|0}else{c:do{if((j>>1|0)>0){T=b+120|0;Q=n;p=0;R=r;U=k;S=s;O=c[T>>2]|0;P=g;N=j;d:while(1){if((O>>1|0)>0){M=0;K=R;H=O;while(1){if((Q-K|0)<1){h=0;G=39;break d}V=K+1|0;C=a[K]|0;B=C&255;if(C<<24>>24==0){W=H}else{if(!(B>>>0<o>>>0)){h=-1094995529;G=39;break d}C=q+(B<<1)|0;B=(d[C]|d[C+1|0]<<8)<<16>>16&65535;C=B>>>3&248;a[S+M|0]=C>>>5|C;a[U+M|0]=B>>>8&248|B>>>13;W=c[T>>2]|0}B=M+1|0;if((B|0)<(W>>1|0)){M=B;K=V;H=W}else{break}}X=V;Y=W;Z=c[l>>2]|0;_=c[e>>2]|0}else{X=R;Y=O;Z=P;_=N}H=S+(c[Z+36>>2]|0)|0;K=U+(c[Z+40>>2]|0)|0;M=p+1|0;if((M|0)<(_>>1|0)){p=M;R=X;U=K;S=H;O=Y;P=Z;N=_}else{$=K;aa=H;ba=_;da=Z;break c}}if((G|0)==39){i=f;return h|0}}else{$=k;aa=s;ba=j;da=g}}while(0);if((ba&1|0)==0){h=0;i=f;return h|0}ba=b+120|0;nrc(aa|0,aa+(-(c[da+36>>2]|0)|0)|0,c[ba>>2]>>1)|0;nrc($|0,$+(-(c[(c[l>>2]|0)+40>>2]|0)|0)|0,c[ba>>2]>>1)|0;h=0;i=f;return h|0}return 0}function Cib(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=e+f|0;f=c[b+20>>2]|0;h=b+24|0;i=c[b+28>>2]|0;j=f;k=i;l=b+20|0;b=c[h>>2]|0;if((b-j|0)<1){m=0;n=f}else{o=f+1|0;c[l>>2]=o;m=d[f]|0;n=o}if((b-n|0)<1){p=0;q=n}else{o=n+1|0;c[l>>2]=o;p=d[n]|0;q=o}o=p+m|0;n=m<<1;m=b-q|0;f=m>>>0>n>>>0?n:m;m=q+f|0;c[l>>2]=m;if((b-m|0)<1){r=0}else{c[l>>2]=q+(f+1);r=d[m]|0}m=j-k-(p<<1)|0;j=b-k|0;k=e;e=r;r=o;a:while(1){f=k;q=128;n=r;while(1){s=q>>1;t=m+(n<<1)+((e&q|0)!=0)|0;if((t|0)<0){u=0}else{u=(j|0)<(t|0)?j:t}t=i+u|0;if((b-t|0)<1){v=0}else{v=d[t]|0}if((v|0)==(p|0)){w=f;x=19;break a}if(v>>>0<p>>>0){t=f+1|0;a[f]=v;if(t>>>0>g>>>0){w=t;x=19;break a}else{y=t;z=o}}else{y=f;z=v}if((s|0)==0){break}else{f=y;q=s;n=z}}n=c[l>>2]|0;if((c[h>>2]|0)==(n|0)){w=y;x=19;break}c[l>>2]=n+1;k=y;e=d[n]|0;r=z}if((x|0)==19){return((w|0)!=(g|0)?-1094995529:0)|0}return 0}function Dib(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=e+f|0;a:do{if((f|0)>0){h=b+20|0;i=b+24|0;j=e;k=g;l=e;while(1){m=c[h>>2]|0;n=c[i>>2]|0;if((n|0)==(m|0)){o=-1094995529;p=30;break}q=m+1|0;c[h>>2]=q;r=a[m]|0;s=r&255;if((r&255)>>>0<224>>>0){do{if((s&128|0)==0){if((n-q|0)<1){t=0;u=q}else{v=m+2|0;c[h>>2]=v;t=d[q]|0;u=v}w=t|s<<3&768;x=(s>>>2&7)+3|0;y=s&3;z=u}else{if((s&64|0)==0){v=n-q|0;do{if((v|0)<1){A=0;B=q;C=0}else{D=(d[q]|0)>>>6;if((v|0)<2){A=0;B=q;C=D;break}E=m+3|0;c[h>>2]=E;F=q;A=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&16383;B=E;C=D}}while(0);w=A;x=(s&63)+4|0;y=C;z=B;break}v=s&3;D=n;if((D-q|0)<2){G=0;H=q}else{E=m+3|0;c[h>>2]=E;F=q;G=(he((d[F]|d[F+1|0]<<8)<<16>>16|0)|0)&65535;H=E}if((D-H|0)<1){I=0;J=H}else{D=H+1|0;c[h>>2]=D;I=d[H]|0;J=D}D=(I|s<<6&768)+5|0;if((D+v|0)>(k-l|0)){K=l;L=j;break a}else{w=G|s<<12&65536;x=D;y=v;z=J}}}while(0);m=w+1|0;v=l+(x+y)|0;if(v>>>0>g>>>0){o=-1094995529;p=30;break}if((l-j+y|0)<(m|0)){o=-1094995529;p=30;break}D=n-z|0;E=D>>>0>y>>>0?y:D;nrc(l|0,z|0,E)|0;c[h>>2]=(c[h>>2]|0)+E;vJb(l+y|0,m,x);M=v}else{v=(r&255)>>>0>251>>>0;if(v){N=s&3}else{N=(s<<2&124)+4|0}if((k-l|0)<(N|0)){o=-1094995529;p=30;break}m=n-q|0;E=m>>>0>N>>>0?N:m;nrc(l|0,q|0,E)|0;c[h>>2]=(c[h>>2]|0)+E;E=l+N|0;if(v){K=E;L=j;break a}else{M=E}}if(M>>>0<g>>>0){l=M}else{K=M;L=j;break a}}if((p|0)==30){return o|0}}else{K=e;L=e}}while(0);o=K-L|0;return o|0}function Eib(a){a=a|0;var b=0;b=i;c[a+140>>2]=7;c[a+796>>2]=12;if((c[a+120>>2]&7|0)==0){i=b;return 0}KIb(a,24,2352160,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function Fib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=b+124|0;k=b+120|0;if(+(c[j>>2]|0)<+(c[f>>2]|0)*1.5*+(c[k>>2]|0)){KIb(b,16,2439440,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=g;return m|0}l=M4a(b,d,0)|0;if((l|0)<0){m=l;i=g;return m|0}c[d+84>>2]=1;c[d+88>>2]=1;l=c[f>>2]|0;if((l|0)>0){f=d+32|0;b=d;n=d+36|0;o=d+4|0;p=d+40|0;q=d+8|0;d=h;h=l;l=c[k>>2]|0;while(1){r=h-1|0;if((l|0)>0){s=ca(c[p>>2]|0,r)|0;t=ca(c[n>>2]|0,r)|0;u=d;v=(c[b>>2]|0)+(ca(c[f>>2]|0,r)|0)|0;w=(c[o>>2]|0)+t|0;t=(c[q>>2]|0)+s|0;s=0;while(1){a[w]=a[u]|0;a[v]=a[u+1|0]|0;a[t]=a[u+2|0]|0;a[v+1|0]=a[u+3|0]|0;a[w+1|0]=a[u+4|0]|0;a[v+2|0]=a[u+5|0]|0;a[t+1|0]=a[u+6|0]|0;a[v+3|0]=a[u+7|0]|0;a[v+4|0]=a[u+8|0]|0;a[v+5|0]=a[u+9|0]|0;a[v+6|0]=a[u+10|0]|0;x=u+12|0;a[v+7|0]=a[u+11|0]|0;y=s+8|0;z=c[k>>2]|0;if((y|0)<(z|0)){u=x;v=v+8|0;w=w+2|0;t=t+2|0;s=y}else{A=x;B=z;break}}}else{A=d;B=l}if((r|0)>0){d=A;h=r;l=B}else{break}}}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function Gib(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;if((c[a+120>>2]&7|0)!=0){KIb(a,16,2439360,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-1094995529;i=b;return e|0}f=UHb()|0;c[a+804>>2]=f;c[a+792>>2]=12;if((f|0)!=0){e=0;i=b;return e|0}KIb(a,16,2352112,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;e=-12;i=b;return e|0}function Hib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0.0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=b+120|0;h=b+124|0;i=+(ca(c[h>>2]|0,c[g>>2]|0)|0)*1.5;j=d5a(b,d,~~+i>>>0,(F=+i,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0))|0;if((j|0)<0){k=j;return k|0}j=c[b+804>>2]|0;c[j+84>>2]=1;c[j+88>>2]=1;j=c[h>>2]|0;if((j|0)>0){h=e+32|0;b=e|0;l=e+36|0;m=e+4|0;n=e+40|0;o=e+8|0;e=c[d+24>>2]|0;p=j;j=c[g>>2]|0;while(1){q=p-1|0;if((j|0)>0){r=ca(c[n>>2]|0,q)|0;s=ca(c[l>>2]|0,q)|0;t=e;u=(c[b>>2]|0)+(ca(c[h>>2]|0,q)|0)|0;v=(c[m>>2]|0)+s|0;s=(c[o>>2]|0)+r|0;r=0;while(1){a[t]=a[v]|0;a[t+1|0]=a[u]|0;a[t+2|0]=a[s]|0;a[t+3|0]=a[u+1|0]|0;a[t+4|0]=a[v+1|0]|0;a[t+5|0]=a[u+2|0]|0;a[t+6|0]=a[s+1|0]|0;a[t+7|0]=a[u+3|0]|0;a[t+8|0]=a[u+4|0]|0;a[t+9|0]=a[u+5|0]|0;a[t+10|0]=a[u+6|0]|0;w=t+12|0;a[t+11|0]=a[u+7|0]|0;x=r+8|0;y=c[g>>2]|0;if((x|0)<(y|0)){t=w;u=u+8|0;v=v+2|0;s=s+2|0;r=x}else{z=w;A=y;break}}}else{z=e;A=j}if((q|0)>0){e=z;p=q;j=A}else{break}}}A=d+36|0;c[A>>2]=c[A>>2]|1;c[f>>2]=1;k=0;return k|0}function Iib(a){a=a|0;mJb(a+804|0);return 0}function Jib(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=c[a+120>>2]|0;do{if((f&1|0)==0){g=c[a+124>>2]|0;if((g&1|0)!=0){break}h=a;if((tIb(f,g,0,h)|0)<0){break}if((c[a+100>>2]|0)<3){KIb(h,16,2198832,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}c[a+140>>2]=11;g=c[a+96>>2]|0;l=d[g]|0;c[e+8>>2]=l;m=d[g+1|0]|0;c[e+12>>2]=m;n=d[g+2|0]|0;c[e+16>>2]=n;do{if((m+l|0)<=256){if((l+n|0)>256){break}g=UHb()|0;c[e+4>>2]=g;k=(g|0)==0?-12:0;i=b;return k|0}}while(0);KIb(h,16,2167304,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}}while(0);KIb(a,16,2239776,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=b;return k|0}function Kib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=i;j=c[b+60>>2]|0;k=j+4|0;l=c[k>>2]|0;m=g+28|0;n=j+8|0;if((c[m>>2]|0)<(((c[n>>2]|0)*3|0)+4|0)){KIb(b,16,2439336,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}q=N4a(b,l)|0;if((q|0)<0){p=q;i=h;return p|0}if((c[b+428>>2]|0)==0){mrc(c[l+4>>2]|0,0,1024)|0}q=l|0;r=j+40|0;c[r>>2]=c[q>>2];s=c[q>>2]|0;q=j+36|0;c[q>>2]=s;t=g+24|0;g=(c[t>>2]|0)+4|0;u=j+28|0;c[u>>2]=g;v=j+32|0;c[v>>2]=(c[t>>2]|0)+(c[m>>2]|0);w=j+24|0;c[w>>2]=0;x=a[c[t>>2]|0]|0;y=x&255;if((x&255)>>>0>1>>>0){KIb(b,16,2352088,(o=i,i=i+8|0,c[o>>2]=y,o)|0);i=o;p=-1094995529;i=h;return p|0}x=c[j+12+(y<<2)>>2]|0;y=c[l+4>>2]|0;if((c[n>>2]|0)>0){z=0;A=g;do{g=d[A+1|0]<<10|d[A]<<18|d[A+2|0]<<2;c[y+(z+x<<2)>>2]=g|g>>>6&197379|-16777216;z=z+1|0;A=A+3|0;c[u>>2]=A;}while((z|0)<(c[n>>2]|0))}c[l+304>>2]=1;n=b+124|0;z=c[n>>2]|0;a:do{if((z|0)>0){A=b+120|0;x=l+32|0;y=0;g=c[A>>2]|0;B=s;C=z;b:while(1){if((g|0)>0){D=2;E=B;while(1){F=c[u>>2]|0;if((F-(c[t>>2]|0)|0)>=(c[m>>2]|0)){G=14;break b}H=c[w>>2]|0;if((H|0)==0){I=F+1|0;c[u>>2]=I;c[w>>2]=F;J=(d[F]|0)>>>4;K=F;L=I}else{I=a[H]&15;c[w>>2]=0;J=I;K=0;L=F}if(J<<24>>24==15){if((K|0)==0){c[u>>2]=L+1;c[w>>2]=L;M=(d[L]|0)>>>4}else{F=a[K]&15;c[w>>2]=0;M=F}F=M&255;I=c[x>>2]|0;H=(ca(a[827201+(F<<1)|0]|0,I)|0)+(a[827200+(F<<1)|0]|0)|0;F=E+H|0;if(F>>>0<(c[r>>2]|0)>>>0){G=26;break b}a[E]=a[F]|0;a[(c[q>>2]|0)+1|0]=a[E+(H+1)|0]|0;a[(c[q>>2]|0)+I|0]=a[E+(H+I)|0]|0;F=I+1|0;a[(c[q>>2]|0)+F|0]=a[E+(H+F)|0]|0}else{F=J&255;H=c[x>>2]|0;I=d[736099+(F<<2)|0]|0;if(((c[v>>2]|0)-L|0)<(I|0)){G=20;break b}a[E]=a[L]|0;a[(c[q>>2]|0)+1|0]=a[(c[u>>2]|0)+(d[736096+(F<<2)|0]|0)|0]|0;a[(c[q>>2]|0)+H|0]=a[(c[u>>2]|0)+(d[736097+(F<<2)|0]|0)|0]|0;a[(c[q>>2]|0)+(H+1)|0]=a[(c[u>>2]|0)+(d[736098+(F<<2)|0]|0)|0]|0;c[u>>2]=(c[u>>2]|0)+I}N=(c[q>>2]|0)+2|0;c[q>>2]=N;O=c[A>>2]|0;if((D|0)>=(O|0)){break}D=D+2|0;E=N}P=D;Q=O;R=N;S=c[n>>2]|0}else{P=0;Q=g;R=B;S=C}E=R+((c[x>>2]<<1)-P)|0;c[q>>2]=E;I=y+2|0;if((I|0)<(S|0)){y=I;g=Q;B=E;C=S}else{break a}}if((G|0)==14){KIb(b,16,2439336,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}else if((G|0)==20){KIb(c[j>>2]|0,16,2439336,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}else if((G|0)==26){KIb(c[j>>2]|0,16,2290216,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;p=-1094995529;i=h;return p|0}}}while(0);o=YHb(e,c[k>>2]|0)|0;if((o|0)<0){p=o;i=h;return p|0}c[f>>2]=1;p=c[m>>2]|0;i=h;return p|0}function Lib(a){a=a|0;VHb((c[a+60>>2]|0)+4|0);return 0}function Mib(a){a=a|0;c[a+140>>2]=0;return 0}function Nib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=c[f+24>>2]|0;j=f+28|0;f=b+120|0;k=b+124|0;if((c[j>>2]|0)<(ca(((c[f>>2]|0)+1>>1)*6|0,(c[k>>2]|0)+1>>1)|0)){KIb(b,16,2439304,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;m=-22;i=g;return m|0}l=M4a(b,d,0)|0;if((l|0)<0){m=l;i=g;return m|0}c[d+84>>2]=1;c[d+88>>2]=1;l=c[k>>2]|0;if((l+1>>1|0)>0){b=d+32|0;n=d+36|0;o=d+40|0;p=h;h=c[d>>2]|0;q=c[d+4>>2]|0;r=c[d+8>>2]|0;d=0;s=c[f>>2]|0;t=l;while(1){if((s+1>>1|0)>0){l=p;u=0;while(1){a[q+u|0]=a[l]^-128;a[r+u|0]=a[l+1|0]^-128;v=u<<1;a[h+v|0]=a[l+2|0]|0;w=v|1;a[h+w|0]=a[l+3|0]|0;a[h+((c[b>>2]|0)+v)|0]=a[l+4|0]|0;x=l+6|0;a[h+(w+(c[b>>2]|0))|0]=a[l+5|0]|0;w=u+1|0;y=c[f>>2]|0;if((w|0)<(y+1>>1|0)){l=x;u=w}else{break}}z=x;A=y;B=c[k>>2]|0}else{z=p;A=s;B=t}u=d+1|0;if((u|0)<(B+1>>1|0)){p=z;h=h+(c[b>>2]<<1)|0;q=q+(c[n>>2]|0)|0;r=r+(c[o>>2]|0)|0;d=u;s=A;t=B}else{break}}}c[e>>2]=1;m=c[j>>2]|0;i=g;return m|0}function Oib(a){a=a|0;var b=0,d=0,e=0;b=i;d=UHb()|0;c[a+804>>2]=d;if((d|0)!=0){e=0;i=b;return e|0}KIb(a,16,2439272,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;e=-12;i=b;return e|0}function Pib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=b+120|0;h=b+124|0;i=ca(((c[g>>2]|0)+1>>1)*6|0,(c[h>>2]|0)+1>>1)|0;j=d5a(b,d,i,(i|0)<0|0?-1:0)|0;if((j|0)<0){k=j;return k|0}j=c[d+24>>2]|0;i=c[b+804>>2]|0;c[i+84>>2]=1;c[i+88>>2]=1;i=c[h>>2]|0;if((i+1>>1|0)>0){b=e+32|0;l=e+36|0;m=e+40|0;n=j;j=c[e>>2]|0;o=c[e+4>>2]|0;p=c[e+8>>2]|0;e=0;q=c[g>>2]|0;r=i;while(1){if((q+1>>1|0)>0){i=n;s=0;while(1){a[i]=a[o+s|0]^-128;a[i+1|0]=a[p+s|0]^-128;t=s<<1;a[i+2|0]=a[j+t|0]|0;u=t|1;a[i+3|0]=a[j+u|0]|0;a[i+4|0]=a[j+((c[b>>2]|0)+t)|0]|0;v=i+6|0;a[i+5|0]=a[j+(u+(c[b>>2]|0))|0]|0;u=s+1|0;w=c[g>>2]|0;if((u|0)<(w+1>>1|0)){i=v;s=u}else{break}}x=v;y=w;z=c[h>>2]|0}else{x=n;y=q;z=r}s=e+1|0;if((s|0)<(z+1>>1|0)){n=x;j=j+(c[b>>2]<<1)|0;o=o+(c[l>>2]|0)|0;p=p+(c[m>>2]|0)|0;e=s;q=y;r=z}else{break}}}z=d+36|0;c[z>>2]=c[z>>2]|1;c[f>>2]=1;k=0;return k|0}function Qib(a){a=a|0;mJb(a+804|0);return 0}function Rib(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a+60|0;e=c[d>>2]|0;c[a+140>>2]=17;c[a+796>>2]=8;c[e+36>>2]=0;c[e+40>>2]=0;c[e+44>>2]=0;f=_pc(e+4|0,2239768,56)|0;if((f|0)!=0){KIb(a,16,2198792,(a=i,i=i+8|0,c[a>>2]=f,a)|0);i=a;g=-12;i=b;return g|0}a=UHb()|0;c[e>>2]=a;if((a|0)!=0){g=0;i=b;return g|0}a=c[d>>2]|0;VHb(a);cqc(a+4|0)|0;g=-12;i=b;return g|0}function Sib(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;h=c[b+60>>2]|0;j=d;k=h;l=c[k>>2]|0;m=h+4|0;n=m;o=c[l>>2]|0;p=f+36|0;do{if((c[p>>2]&1|0)==0){if((o|0)!=0){q=o+(ca((c[b+124>>2]|0)-1|0,c[l+32>>2]|0)|0)|0;c[d+84>>2]=0;c[d+88>>2]=2;r=q;break}KIb(b,16,2439240,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=g;return t|0}else{c[d+84>>2]=1;c[d+88>>2]=1;r=o}}while(0);o=Xpc(n)|0;if((o|0)!=0){KIb(b,16,2352056,(s=i,i=i+8|0,c[s>>2]=o,s)|0);i=s;t=-1094995529;i=g;return t|0}o=M4a(b,j,1)|0;if((o|0)<0){t=o;i=g;return t|0}c[m>>2]=c[f+24>>2];m=f+28|0;c[h+8>>2]=c[m>>2];f=b+124|0;o=c[f>>2]|0;q=d+32|0;a:do{if((o|0)>0){u=ca(o-1|0,c[q>>2]|0)|0;v=h+16|0;w=b+120|0;x=h+20|0;y=l+32|0;z=r;A=(c[d>>2]|0)+u|0;u=1;while(1){c[v>>2]=A;c[x>>2]=c[w>>2]<<1;B=$pc(n,2)|0;if(B>>>0>1>>>0){break}do{if((c[p>>2]&1|0)==0){if((c[w>>2]<<1|0)>0){C=0}else{break}do{D=A+C|0;E=a[D]|0;a[D]=(a[z+C|0]&(-(E<<24>>24==0|0)&255))+E;C=C+1|0;}while((C|0)<(c[w>>2]<<1|0))}}while(0);if((u|0)>=(c[f>>2]|0)){break a}z=z+(-(c[y>>2]|0)|0)|0;A=A+(-(c[q>>2]|0)|0)|0;u=u+1|0}KIb(b,16,2290176,(s=i,i=i+8|0,c[s>>2]=B,s)|0);i=s;t=-1094995529;i=g;return t|0}}while(0);WHb(c[k>>2]|0);s=YHb(c[k>>2]|0,j)|0;if((s|0)<0){t=s;i=g;return t|0}c[e>>2]=1;t=c[m>>2]|0;i=g;return t|0}function Tib(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b);cqc(b+4|0)|0;return 0}function Uib(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=c[a+60>>2]|0;c[d>>2]=a;e=a+120|0;c[d+792>>2]=c[e>>2];f=a+124|0;c[d+796>>2]=c[f>>2];c[d+4>>2]=c[a+792>>2];g=d+836|0;h=g;mrc(g|0,0,56)|0;g=ca((c[e>>2]<<2)+1020|0,(c[f>>2]|0)+64|0)|0;c[d+8>>2]=g;do{if((g|0)!=0){f=pJb(g)|0;c[d+12>>2]=f;if((f|0)!=0){break}KIb(a,16,2564352,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-12;i=b;return k|0}}while(0);c[d+868>>2]=0;c[d+872>>2]=0;c[d+876>>2]=0;d=_pc(h,2546384,56)|0;if((d|0)==0){k=0;i=b;return k|0}KIb(a,16,2528744,(j=i,i=i+8|0,c[j>>2]=d,j)|0);i=j;k=-1313558101;i=b;return k|0}function Vib(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;j=e;k=c[g+24>>2]|0;l=c[g+28>>2]|0;g=c[b+60>>2]|0;m=g;n=d[k]|0;o=g+808|0;c[o>>2]=n;p=k+1|0;a:do{if((n&1|0)==0){if((c[g+892>>2]|0)!=0){q=l-1|0;r=p;break}KIb(b,16,2140760,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else{u=g+892|0;c[u>>2]=0;v=a[p]|0;w=v&255;x=a[k+2|0]|0;z=x&255;A=d[k+3|0]|0;B=g+804|0;c[B>>2]=A;C=d[k+4|0]|0;D=g+800|0;c[D>>2]=C;E=d[k+5|0]|0;F=g+816|0;c[F>>2]=E;G=d[k+6|0]|0;H=g+820|0;c[H>>2]=G;c[u>>2]=0;I=g+896|0;c[I>>2]=0;J=k+7|0;K=l-7|0;L=b;KIb(L,48,2439192,(s=i,i=i+56|0,c[s>>2]=n,c[s+8>>2]=w,c[s+16>>2]=z,c[s+24>>2]=A,c[s+32>>2]=C,c[s+40>>2]=E,c[s+48>>2]=G,s)|0);i=s;if(!(v<<24>>24==0&x<<24>>24==1)){QIb(L,2352040,(s=i,i=i+16|0,c[s>>2]=w,c[s+8>>2]=z,s)|0);i=s;t=-1163346256;i=h;return t|0}z=c[F>>2]|0;w=c[H>>2]|0;do{if((z|0)==0){M=w}else{if((w|0)==0){M=0;break}x=c[B>>2]|0;if(!(x>>>0<2>>>0)){QIb(L,2239744,(s=i,i=i+8|0,c[s>>2]=x,s)|0);i=s;t=-1163346256;i=h;return t|0}x=c[D>>2]|0;if((x|0)==4){c[g+4>>2]=8;c[I>>2]=2278;c[b+140>>2]=11;c[g+812>>2]=c[g+792>>2]}else if((x|0)==8){c[g+4>>2]=32;c[I>>2]=2512;c[b+140>>2]=298;c[g+812>>2]=c[g+792>>2]<<2}else if((x|0)==5|(x|0)==6){c[g+4>>2]=16;c[I>>2]=2652;c[b+140>>2]=(x|0)==5?46:44;c[g+812>>2]=c[g+792>>2]<<1}else{c[I>>2]=0;QIb(L,2198776,(s=i,i=i+8|0,c[s>>2]=x,s)|0);i=s;t=-1163346256;i=h;return t|0}x=Xpc(g+836|0)|0;if((x|0)!=0){KIb(L,16,2167232,(s=i,i=i+8|0,c[s>>2]=x,s)|0);i=s;t=-1313558101;i=h;return t|0}x=g+788|0;v=b+120|0;G=b+124|0;E=ca(c[G>>2]|0,c[v>>2]|0)|0;C=g+4|0;c[x>>2]=jJb(c[x>>2]|0,E,(c[C>>2]|0)/8|0)|0;E=g+784|0;A=ca(c[G>>2]|0,c[v>>2]|0)|0;N=jJb(c[E>>2]|0,A,(c[C>>2]|0)/8|0)|0;c[E>>2]=N;A=c[F>>2]|0;c[g+824>>2]=((c[g+792>>2]|0)-1+A|0)/(A|0)|0;A=c[H>>2]|0;c[g+828>>2]=((c[g+796>>2]|0)-1+A|0)/(A|0)|0;A=c[x>>2]|0;if((A|0)==0|(N|0)==0){t=-12;i=h;return t|0}else{N=ca(c[G>>2]|0,c[v>>2]|0)|0;mrc(A|0,0,ca(N,(c[C>>2]|0)/8|0)|0)|0;N=ca(c[G>>2]|0,c[v>>2]|0)|0;mrc(c[E>>2]|0,0,ca(N,(c[C>>2]|0)/8|0)|0)|0;c[u>>2]=1378;q=K;r=J;break a}}}while(0);QIb(L,2290152,(s=i,i=i+16|0,c[s>>2]=z,c[s+8>>2]=M,s)|0);i=s;t=-1163346256;i=h;return t|0}}while(0);M=g+892|0;n=M4a(b,j,0)|0;if((n|0)<0){t=n;i=h;return t|0}do{if((c[g+804>>2]|0)==0){if(!((c[g+8>>2]|0)>>>0<q>>>0)){nrc(c[g+12>>2]|0,r|0,q)|0;break}KIb(b,16,2117320,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s;t=-1094995529;i=h;return t|0}else{n=g+836|0;j=g+856|0;c[j>>2]=0;c[g+844>>2]=0;c[n>>2]=r;c[g+840>>2]=q;c[g+848>>2]=c[g+12>>2];c[g+852>>2]=c[g+8>>2];k=$pc(n,2)|0;if(!(k>>>0>1>>>0)){c[g+832>>2]=c[j>>2];break}KIb(b,16,2635136,(s=i,i=i+8|0,c[s>>2]=k,s)|0);i=s;t=-1094995529;i=h;return t|0}}while(0);q=e+84|0;do{if((c[o>>2]&1|0)==0){c[q>>2]=0;c[e+88>>2]=2;if((c[g+832>>2]|0)==0){break}ve[c[g+896>>2]&4095](m)|0}else{c[q>>2]=1;c[e+88>>2]=1;ve[c[M>>2]&4095](m)|0}}while(0);m=c[e>>2]|0;M=g+788|0;q=c[M>>2]|0;o=c[g+800>>2]|0;if((o|0)==4){r=e+4|0;k=0;while(1){j=k*3|0;n=(c[r>>2]|0)+(k<<2)|0;y=(d[g+(j+16)|0]|0)<<16|(d[g+(j+17)|0]|0)<<8|(d[g+(j+18)|0]|0)|-16777216;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;n=k+1|0;if((n|0)<256){k=n}else{O=35;break}}}else if((o|0)==5|(o|0)==6|(o|0)==8){O=35}else{KIb(b,16,2611720,(s=i,i=i+8|0,c[s>>2]=o,s)|0);i=s}if((O|0)==35){O=c[g+812>>2]|0;uIb(m,c[e+32>>2]|0,q,O,O,c[g+796>>2]|0)}O=g+784|0;g=c[O>>2]|0;c[O>>2]=c[M>>2];c[M>>2]=g;c[f>>2]=1;t=l;i=h;return t|0}function Wib(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+12|0);cqc(b+836|0)|0;mJb(b+788|0);mJb(b+784|0);return 0}function Xib(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((c[a+800>>2]|0)==4){nrc(a+16|0,b|0,768)|0;d=b+768|0}else{d=b}b=ca(c[a+796>>2]|0,c[a+792>>2]|0)|0;nrc(c[a+788>>2]|0,d|0,ca(b,(c[a+4>>2]|0)/8|0)|0)|0;return 0}function Yib(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;e=b+12|0;f=c[e>>2]|0;g=c[b+788>>2]|0;h=c[b+784>>2]|0;if((c[b+808>>2]&2|0)==0){j=f}else{k=0;l=f;while(1){m=b+16+k|0;a[m]=a[m]^a[l];m=k+1|0;if((m|0)<768){k=m;l=l+1|0}else{break}}j=f+768|0}f=j+((ca(c[b+824>>2]<<1,c[b+828>>2]|0)|0)+3&-4)|0;l=b+796|0;k=c[l>>2]|0;if((k|0)>0){m=b+820|0;n=b+792|0;o=b+816|0;p=0;q=h;h=0;r=g;g=f;s=k;k=c[m>>2]|0;t=c[n>>2]|0;while(1){u=s-p|0;v=(u|0)>(k|0)?k:u;if((t|0)>0){u=(v|0)>0;w=0;x=h;y=g;z=t;A=c[o>>2]|0;while(1){B=a[j+x|0]|0;C=B&1;D=a[j+(x+1)|0]>>1;E=x+2|0;F=z-w|0;G=(F|0)>(A|0)?A:F;F=r+w|0;H=(B>>1)+w|0;B=D+p|0;a:do{if(u){I=q+(H+(ca(D,z)|0))|0;if((G|0)>0){J=0;K=F;L=I}else{I=0;M=F;N=z;while(1){O=B+I|0;if((O|0)<0){P=21}else{if((O|0)<(c[l>>2]|0)){Q=N}else{P=21}}if((P|0)==21){P=0;mrc(M|0,0,G|0)|0;Q=c[n>>2]|0}O=I+1|0;if((O|0)<(v|0)){I=O;M=M+Q|0;N=Q}else{R=Q;break a}}}while(1){N=B+J|0;do{if((N|0)<0){P=17}else{if((N|0)<(c[l>>2]|0)){S=0}else{P=17;break}do{M=H+S|0;do{if((M|0)<0){P=15}else{if((M|0)>=(c[n>>2]|0)){P=15;break}a[K+S|0]=a[L+S|0]|0}}while(0);if((P|0)==15){P=0;a[K+S|0]=0}S=S+1|0;}while((S|0)<(G|0))}}while(0);if((P|0)==17){P=0;mrc(K|0,0,G|0)|0}N=c[n>>2]|0;M=J+1|0;if((M|0)<(v|0)){J=M;K=K+N|0;L=L+N|0}else{R=N;break}}}else{R=z}}while(0);if(u&(C|0)!=0&(G|0)>0){H=w-1-z|0;B=~A;D=(H|0)>(B|0)?H:B;B=0;H=y;N=F;while(1){M=0;I=H;while(1){O=N+M|0;a[O]=a[O]^a[I];O=M+1|0;if((O|0)<(G|0)){M=O;I=I+1|0}else{break}}I=H+~D|0;M=c[n>>2]|0;O=B+1|0;if((O|0)<(v|0)){B=O;H=I;N=N+M|0}else{T=I;U=M;break}}}else{T=y;U=R}N=c[o>>2]|0;H=N+w|0;if((H|0)<(U|0)){w=H;x=E;y=T;z=U;A=N}else{break}}V=E;W=T;X=U;Y=c[m>>2]|0;Z=c[l>>2]|0}else{V=h;W=g;X=t;Y=k;Z=s}A=ca(Y,X)|0;z=Y+p|0;if((z|0)<(Z|0)){p=z;q=q+A|0;h=V;r=r+A|0;g=W;s=Z;k=Y;t=X}else{_=W;break}}}else{_=f}f=_-(c[e>>2]|0)|0;e=c[b+832>>2]|0;if((f|0)==(e|0)){i=d;return 0}KIb(c[b>>2]|0,16,2585096,(b=i,i=i+16|0,c[b>>2]=f,c[b+8>>2]=e,b)|0);i=b;i=d;return 0}function Zib(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0;e=i;f=d+12|0;g=c[f>>2]|0;h=g+((ca(c[d+824>>2]<<1,c[d+828>>2]|0)|0)+3&-4)|0;j=d+796|0;k=c[j>>2]|0;if((k|0)>0){l=d+820|0;m=d+792|0;n=d+816|0;o=0;p=c[d+784>>2]|0;q=0;r=c[d+788>>2]|0;s=h;t=k;k=c[l>>2]|0;u=c[m>>2]|0;while(1){v=t-o|0;w=(v|0)>(k|0)?k:v;if((u|0)>0){v=(w|0)>0;x=0;y=q;z=s;A=u;B=c[n>>2]|0;while(1){C=a[g+y|0]|0;D=C&1;E=a[g+(y+1)|0]>>1;F=y+2|0;G=A-x|0;H=(G|0)>(B|0)?B:G;G=r+(x<<1)|0;I=(C>>1)+x|0;C=E+o|0;a:do{if(v){J=p+(I+(ca(E,A)|0)<<1)|0;K=H<<1;if((H|0)>0){L=0;M=G;N=J;O=A;P=A}else{J=0;Q=G;R=A;while(1){S=C+J|0;if((S|0)<0){T=17}else{if((S|0)<(c[j>>2]|0)){U=R}else{T=17}}if((T|0)==17){T=0;mrc(Q|0,0,K|0)|0;U=c[m>>2]|0}S=J+1|0;if((S|0)<(w|0)){J=S;Q=Q+(U<<1)|0;R=U}else{V=U;break a}}}while(1){R=C+L|0;do{if((R|0)<0){T=13}else{if((R|0)<(c[j>>2]|0)){W=0}else{T=13;break}while(1){Q=I+W|0;if((Q|0)>-1&(Q|0)<(O|0)){b[M+(W<<1)>>1]=b[N+(W<<1)>>1]|0}else{b[M+(W<<1)>>1]=0}Q=W+1|0;if((Q|0)<(H|0)){W=Q}else{X=O;Y=P;break}}}}while(0);if((T|0)==13){T=0;mrc(M|0,0,K|0)|0;R=c[m>>2]|0;X=R;Y=R}R=L+1|0;if((R|0)<(w|0)){L=R;M=M+(X<<1)|0;N=N+(X<<1)|0;O=X;P=Y}else{V=Y;break}}}else{V=A}}while(0);if((D|0)==0|v^1){Z=z}else{I=(H|0)>0;C=x-1-A|0;E=~B;K=((C|0)>(E|0)?C:E)*-2|0;E=0;C=z;R=G;while(1){if(I){Q=0;J=C;while(1){S=R+(Q<<1)|0;b[S>>1]=b[S>>1]^b[J>>1];S=Q+1|0;if((S|0)<(H|0)){Q=S;J=J+2|0}else{break}}_=C+(K-2)|0}else{_=C}J=E+1|0;if((J|0)<(w|0)){E=J;C=_;R=R+(V<<1)|0}else{Z=_;break}}}R=c[n>>2]|0;C=R+x|0;if((C|0)<(V|0)){x=C;y=F;z=Z;A=V;B=R}else{break}}$=F;aa=Z;ba=V;da=c[j>>2]|0;ea=c[l>>2]|0}else{$=q;aa=s;ba=u;da=t;ea=k}B=ca(ea,ba)|0;A=ea+o|0;if((A|0)<(da|0)){o=A;p=p+(B<<1)|0;q=$;r=r+(B<<1)|0;s=aa;t=da;k=ea;u=ba}else{break}}fa=aa;ga=c[f>>2]|0}else{fa=h;ga=g}g=fa-ga|0;ga=c[d+832>>2]|0;if((g|0)==(ga|0)){i=e;return 0}KIb(c[d>>2]|0,16,2585096,(d=i,i=i+16|0,c[d>>2]=g,c[d+8>>2]=ga,d)|0);i=d;i=e;return 0}function _ib(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;d=i;e=b+12|0;f=c[e>>2]|0;g=f+((ca(c[b+824>>2]<<1,c[b+828>>2]|0)|0)+3&-4)|0;h=b+796|0;j=c[h>>2]|0;if((j|0)>0){k=b+820|0;l=b+792|0;m=b+816|0;n=0;o=c[b+784>>2]|0;p=0;q=c[b+788>>2]|0;r=g;s=j;j=c[k>>2]|0;t=c[l>>2]|0;while(1){u=s-n|0;v=(u|0)>(j|0)?j:u;if((t|0)>0){u=(v|0)>0;w=0;x=p;y=r;z=t;A=c[m>>2]|0;while(1){B=a[f+x|0]|0;C=B&1;D=a[f+(x+1)|0]>>1;E=x+2|0;F=z-w|0;G=(F|0)>(A|0)?A:F;F=q+(w<<2)|0;H=(B>>1)+w|0;B=D+n|0;if(u){I=G<<2;J=(G|0)>0;K=0;L=F;M=o+(H+(ca(D,z)|0)<<2)|0;while(1){D=B+K|0;do{if((D|0)<0){N=10}else{if((D|0)>=(c[h>>2]|0)){N=10;break}if(J){O=0}else{break}do{P=H+O|0;do{if((P|0)<0){N=13}else{if((P|0)>=(c[l>>2]|0)){N=13;break}c[L+(O<<2)>>2]=c[M+(O<<2)>>2]}}while(0);if((N|0)==13){N=0;c[L+(O<<2)>>2]=0}O=O+1|0;}while((O|0)<(G|0))}}while(0);if((N|0)==10){N=0;mrc(L|0,0,I|0)|0}D=c[l>>2]|0;P=K+1|0;if((P|0)<(v|0)){K=P;L=L+(D<<2)|0;M=M+(D<<2)|0}else{Q=D;break}}}else{Q=z}if((C|0)==0|u^1){R=y;S=Q}else{M=(G|0)>0;L=w-1-z|0;K=~A;I=((L|0)>(K|0)?L:K)*-4|0;K=0;L=y;H=F;J=Q;while(1){if(M){B=0;D=L;while(1){P=H+(B<<2)|0;c[P>>2]=c[P>>2]^c[D>>2];P=B+1|0;if((P|0)<(G|0)){B=P;D=D+4|0}else{break}}T=L+(I-4)|0;U=c[l>>2]|0}else{T=L;U=J}D=K+1|0;if((D|0)<(v|0)){K=D;L=T;H=H+(U<<2)|0;J=U}else{R=T;S=U;break}}}J=c[m>>2]|0;H=J+w|0;if((H|0)<(S|0)){w=H;x=E;y=R;z=S;A=J}else{break}}V=E;W=R;X=S;Y=c[k>>2]|0;Z=c[h>>2]|0}else{V=p;W=r;X=t;Y=j;Z=s}A=ca(Y,X)|0;z=Y+n|0;if((z|0)<(Z|0)){n=z;o=o+(A<<2)|0;p=V;q=q+(A<<2)|0;r=W;s=Z;j=Y;t=X}else{break}}_=W;$=c[e>>2]|0}else{_=g;$=f}f=_-$|0;$=c[b+832>>2]|0;if((f|0)==($|0)){i=d;return 0}KIb(c[b>>2]|0,16,2585096,(b=i,i=i+16|0,c[b>>2]=f,c[b+8>>2]=$,b)|0);i=b;i=d;return 0}function $ib(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a+60|0;e=c[d>>2]|0;f=1;do{c[5120728+(f<<2)>>2]=~~(+(-f|0)*+aa(+(f|0)*.00390625)*369.3299304675746);f=f+1|0;}while((f|0)<256);c[e>>2]=a;c[e+1824>>2]=0;c[e+1820>>2]=c[a+360>>2];f=e+4|0;c[f>>2]=8;g=c[a+276>>2]|0;if((g|0)>0){c[f>>2]=(g|0)>127?127:g}g=c[a+84>>2]|0;f=(g|0)>-1?g:9;if(f>>>0>9>>>0){KIb(a,16,2351992,(h=i,i=i+8|0,c[h>>2]=f,h)|0);i=h;j=-22;i=b;return j|0}g=e+1828|0;mrc(g|0,0,56)|0;k=a+120|0;l=c[k>>2]|0;m=a+124|0;n=c[m>>2]|0;o=(ca(n,l)|0)+1028+(ca(((l+15|0)/16|0)<<1,(n+15|0)/16|0)|0)|0;n=e+1816|0;c[n>>2]=o;l=hJb(o)|0;c[e+12>>2]=l;if((l|0)==0){KIb(a,16,2290120,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-12;i=b;return j|0}l=c[n>>2]|0;o=l+11+(l+7>>3)+(l+63>>6)|0;c[n>>2]=o;n=hJb(o)|0;c[e+8>>2]=n;if((n|0)==0){KIb(a,16,2239704,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-12;i=b;return j|0}n=(c[k>>2]|0)+15&-16;c[e+1812>>2]=n;k=hJb(ca(n,c[m>>2]|0)|0)|0;c[e+1808>>2]=k;if((k|0)==0){KIb(a,16,2198744,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;j=-12;i=b;return j|0}c[e+1860>>2]=0;c[e+1864>>2]=0;c[e+1868>>2]=0;e=Gpc(g,f,2167224,56)|0;if((e|0)!=0){KIb(a,16,2140736,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h;j=-1;i=b;return j|0}h=UHb()|0;e=a+804|0;c[e>>2]=h;if((h|0)!=0){j=0;i=b;return j|0}h=c[d>>2]|0;mJb(h+8|0);mJb(h+12|0);Ipc(h+1828|0)|0;mJb(h+1808|0);VHb(e);j=-12;i=b;return j|0}function ajb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0;h=i;i=i+256|0;j=h|0;k=c[b+60>>2]|0;l=k+1824|0;m=c[l>>2]|0;n=(m|0)==0;o=n&1;p=m+1|0;c[l>>2]=p;if((p|0)==(c[k+1820>>2]|0)){c[l>>2]=0}l=c[b+804>>2]|0;c[l+88>>2]=n?1:2;c[l+84>>2]=o;l=f+4|0;p=c[l>>2]|0;do{if(n){m=p;q=f|0;r=c[q>>2]|0;s=k+1808|0;t=0;do{u=m+(t<<2)|0;v=t*3|0;a[k+(v+18)|0]=c[u>>2];a[k+(v+17)|0]=(c[u>>2]|0)>>>8;a[k+(v+16)|0]=(c[u>>2]|0)>>>16;t=t+1|0;}while((t|0)<256);t=k+12|0;nrc(c[t>>2]|0,k+16|0,768)|0;nrc(k+784|0,c[l>>2]|0,1024)|0;m=b+124|0;if((c[m>>2]|0)<=0){w=0;x=768;break}u=b+120|0;v=f+32|0;y=0;z=768;A=r;B=c[u>>2]|0;while(1){nrc((c[t>>2]|0)+z|0,A|0,B)|0;C=c[u>>2]|0;D=C+z|0;E=y+1|0;F=c[m>>2]|0;if((E|0)<(F|0)){y=E;z=D;A=A+(c[v>>2]|0)|0;B=C}else{G=D;H=s;I=q;J=0;K=F;L=59;break}}}else{q=k+784|0;s=(grc(p,q,1024)|0)==0;B=p;v=f|0;A=c[v>>2]|0;z=k+1808|0;y=c[z>>2]|0;m=k+12|0;if(s){M=0;N=0}else{s=0;u=0;while(1){t=c[B+(s<<2)>>2]|0;r=t>>>8;F=t>>>16;D=s*3|0;C=k+(D+16)|0;a[(c[m>>2]|0)+u|0]=(d[C]|0)^F;E=k+(D+17)|0;a[(c[m>>2]|0)+(u+1)|0]=(d[E]|0)^r;O=k+(D+18)|0;a[(c[m>>2]|0)+(u+2)|0]=(d[O]|0)^t;a[C]=F;a[E]=r;a[O]=t;t=s+1|0;if((t|0)<256){s=t;u=u+3|0}else{break}}nrc(q|0,c[l>>2]|0,1024)|0;M=1;N=768}u=b+120|0;s=b+124|0;B=(c[m>>2]|0)+N|0;t=(ca((((c[u>>2]|0)+15|0)/16|0)<<1,((c[s>>2]|0)+15|0)/16|0)|0)+3&-4;mrc(B|0,0,t|0)|0;O=t+N|0;t=c[s>>2]|0;if((t|0)<=0){w=M;x=O;break}r=f+32|0;E=k+1812|0;F=k;C=j|0;D=k+4|0;P=O;O=y;Q=0;R=A;S=B;B=t;t=c[u>>2]|0;while(1){T=B-Q|0;U=(T|0)>16?16:T;if((t|0)>0){T=P;V=0;W=S;X=t;Y=-1;while(1){Z=X-V|0;_=(Z|0)>16?16:Z;Z=R+V|0;$=c[r>>2]|0;aa=c[E>>2]|0;ba=c[F>>2]|0;da=c[ba+120>>2]|0;ea=da-V|0;fa=(ea|0)<16?ea:16;ea=c[ba+124>>2]|0;ba=ea-Q|0;ga=(ba|0)<16?ba:16;mrc(C|0,0,256)|0;ba=(ga|0)>0&(fa|0)>0;if(ba){ha=O+V|0;ia=0;ja=Z;ka=0;while(1){la=0;ma=ka;do{na=(a[ha+la|0]^a[ja+la|0])&255;oa=j+na|0;a[oa]=(a[oa]|0)+1;ma=na|ma;la=la+1|0;}while((la|0)<(fa|0));la=ia+1|0;if((la|0)<(ga|0)){ha=ha+aa|0;ia=la;ja=ja+$|0;ka=ma}else{pa=ma;break}}}else{pa=0}ka=0;ja=1;do{ka=(c[5120728+((d[j+ja|0]|0)<<2)>>2]|0)+ka|0;ja=ja+1|0;}while((ja|0)<256);a:do{if((ka|0)==0){qa=0;ra=0;sa=pa}else{ja=c[D>>2]|0;ia=Q-ja|0;ha=(ia|0)>0?ia:0;ia=ja+Q|0;la=ea-ga|0;if((ha|0)<(((ia|0)>(la|0)?la:ia)|0)){ta=ha;ua=ka;va=0;wa=0;xa=pa}else{qa=0;ra=0;sa=pa;break}while(1){ha=V-ja|0;ia=(ha|0)>0?ha:0;ha=ja+V|0;na=da-fa|0;b:do{if((ia|0)<(((ha|0)>(na|0)?na:ha)|0)){oa=ta-Q|0;ya=ca(oa,aa)|0;if((ta|0)==(Q|0)){za=ua;Aa=ia;Ba=va;Ca=wa;Da=xa}else{Ea=ua;Fa=ia;Ga=va;Ha=wa;while(1){Ia=Fa-V|0;mrc(C|0,0,256)|0;if(ba){Ja=O+(Fa+ya)|0;Ka=0;La=Z;Ma=0;while(1){Na=0;Oa=Ma;do{Pa=(a[Ja+Na|0]^a[La+Na|0])&255;Qa=j+Pa|0;a[Qa]=(a[Qa]|0)+1;Oa=Pa|Oa;Na=Na+1|0;}while((Na|0)<(fa|0));Na=Ka+1|0;if((Na|0)<(ga|0)){Ja=Ja+aa|0;Ka=Na;La=La+$|0;Ma=Oa}else{Ra=Oa;break}}}else{Ra=0}Ma=0;La=1;do{Ma=(c[5120728+((d[j+La|0]|0)<<2)>>2]|0)+Ma|0;La=La+1|0;}while((La|0)<256);if((Ma|0)<(Ea|0)){if((Ma|0)==0){qa=oa;ra=Ia;sa=Ra;break a}else{Sa=Ma;Ta=oa;Ua=Ia}}else{Sa=Ea;Ta=Ga;Ua=Ha}La=Fa+1|0;Ka=ja+V|0;Ja=da-fa|0;if((La|0)<(((Ka|0)>(Ja|0)?Ja:Ka)|0)){Ea=Sa;Fa=La;Ga=Ta;Ha=Ua}else{Va=Sa;Wa=Ta;Xa=Ua;Ya=Ra;break b}}}while(1){do{if((Aa|0)==(V|0)){Za=za;_a=Ba;$a=Ca;ab=Da}else{Ha=Aa-V|0;mrc(C|0,0,256)|0;if(ba){Ga=O+(Aa+ya)|0;Fa=0;Ea=Z;La=0;while(1){Ka=0;Ja=La;do{Na=(a[Ga+Ka|0]^a[Ea+Ka|0])&255;Pa=j+Na|0;a[Pa]=(a[Pa]|0)+1;Ja=Na|Ja;Ka=Ka+1|0;}while((Ka|0)<(fa|0));Ka=Fa+1|0;if((Ka|0)<(ga|0)){Ga=Ga+aa|0;Fa=Ka;Ea=Ea+$|0;La=Ja}else{bb=Ja;break}}}else{bb=0}La=0;Ea=1;do{La=(c[5120728+((d[j+Ea|0]|0)<<2)>>2]|0)+La|0;Ea=Ea+1|0;}while((Ea|0)<256);if((La|0)>=(za|0)){Za=za;_a=Ba;$a=Ca;ab=bb;break}if((La|0)==0){qa=oa;ra=Ha;sa=bb;break a}else{Za=La;_a=oa;$a=Ha;ab=bb}}}while(0);Ia=Aa+1|0;Ma=ja+V|0;Ea=da-fa|0;if((Ia|0)<(((Ma|0)>(Ea|0)?Ea:Ma)|0)){za=Za;Aa=Ia;Ba=_a;Ca=$a;Da=ab}else{Va=Za;Wa=_a;Xa=$a;Ya=ab;break}}}else{Va=ua;Wa=va;Xa=wa;Ya=xa}}while(0);ia=ta+1|0;ha=ja+Q|0;if((ia|0)<(((ha|0)>(la|0)?la:ha)|0)){ta=ia;ua=Va;va=Wa;wa=Xa;xa=Ya}else{qa=Wa;ra=Xa;sa=Ya;break}}}}while(0);a[W]=ra<<1|(sa|0)!=0;a[W+1|0]=qa<<1;if((sa|0)==0|(U|0)<1){cb=T}else{fa=c[E>>2]|0;da=O+(ra+V+(ca(fa,qa)|0))|0;$=(_|0)>0;aa=Y-X|0;ga=(aa|0)>-17?~aa:16;aa=0;ba=T;ka=Z;ea=da;da=fa;while(1){if($){fa=0;la=ba;while(1){a[(c[m>>2]|0)+la|0]=a[ea+fa|0]^a[ka+fa|0];ja=fa+1|0;if((ja|0)<(_|0)){fa=ja;la=la+1|0}else{break}}db=ga+ba|0;eb=c[E>>2]|0}else{db=ba;eb=da}la=aa+1|0;if((la|0)<(U|0)){aa=la;ba=db;ka=ka+(c[r>>2]|0)|0;ea=ea+eb|0;da=eb}else{cb=db;break}}}da=V+16|0;fb=W+2|0;gb=c[u>>2]|0;if((da|0)>=(gb|0)){break}T=cb;V=da;W=fb;X=gb;Y=Y+16|0}hb=cb;ib=fb;jb=gb;kb=c[s>>2]|0}else{hb=P;ib=S;jb=t;kb=B}Y=Q+16|0;if((Y|0)<(kb|0)){P=hb;O=O+(c[E>>2]<<4)|0;Q=Y;R=R+(c[r>>2]<<4)|0;S=ib;B=kb;t=jb}else{G=hb;H=z;I=v;J=M;K=kb;L=59;break}}}}while(0);c:do{if((L|0)==59){kb=b+124|0;if((K|0)<=0){w=J;x=G;break}M=b+120|0;hb=k+1812|0;jb=f+32|0;ib=1;gb=c[H>>2]|0;fb=c[I>>2]|0;while(1){nrc(gb|0,fb|0,c[M>>2]|0)|0;if((ib|0)>=(c[kb>>2]|0)){w=J;x=G;break c}ib=ib+1|0;gb=gb+(c[hb>>2]|0)|0;fb=fb+(c[jb>>2]|0)|0}}}while(0);G=k+1828|0;J=G;if(n){Jpc(J)|0}c[G>>2]=c[k+12>>2];c[k+1832>>2]=x;c[k+1836>>2]=0;x=k+8|0;c[k+1840>>2]=c[x>>2];c[k+1844>>2]=c[k+1816>>2];G=k+1848|0;c[G>>2]=0;if((Lpc(J,2)|0)!=0){KIb(b,16,2439160,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;lb=-1;i=h;return lb|0}J=(-o&6|1)+(c[G>>2]|0)|0;k=d5a(b,e,J,(J|0)<0|0?-1:0)|0;if((k|0)<0){lb=k;i=h;return lb|0}k=c[e+24>>2]|0;J=k+1|0;a[k]=(w?2:0)|n&1;if(n){a[J]=0;a[k+2|0]=1;a[k+3|0]=1;a[k+4|0]=4;a[k+5|0]=16;a[k+6|0]=16;mb=k+7|0}else{mb=J}nrc(mb|0,c[x>>2]|0,c[G>>2]|0)|0;G=e+36|0;c[G>>2]=c[G>>2]|o;c[g>>2]=1;lb=0;i=h;return lb|0}function bjb(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+8|0);mJb(b+12|0);Ipc(b+1828|0)|0;mJb(b+1808|0);VHb(a+804|0);return 0}function cjb(a){a=a|0;var b=0;b=i;c[a+140>>2]=56;c[a+796>>2]=10;if((c[a+52>>2]|0)!=1983000929){i=b;return 0}QIb(a,2290088,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return 0}function djb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;j=c[a+120>>2]|0;k=e;l=g+24|0;m=c[l>>2]|0;n=j<<3;o=(n|0)/3|0;if((j|0)==1){KIb(a,16,2439112,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;q=-1094995529;i=h;return q|0}r=c[g+28>>2]|0;s=c[a+124>>2]|0;do{if((c[a+52>>2]|0)==1983000880){if(((r|0)%(s|0)|0|0)!=0){t=o;break}u=(r|0)/(s|0)|0;t=(u*3|0|0)<(n|0)?o:u}else{t=o}}while(0);o=g+28|0;g=ca(s,t)|0;if((r|0)<(g|0)){KIb(a,16,2351928,(p=i,i=i+16|0,c[p>>2]=r,c[p+8>>2]=g,p)|0);i=p;q=-1094995529;i=h;return q|0}p=M4a(a,k,0)|0;if((p|0)<0){q=p;i=h;return q|0}c[e+88>>2]=1;c[e+84>>2]=1;p=c[e>>2]|0;k=c[e+4>>2]|0;g=c[e+8>>2]|0;r=(c[l>>2]|0)+t|0;l=g;s=k;n=p;u=c[a+124>>2]|0;if((u|0)>0){a=e+32|0;v=e+36|0;w=e+40|0;if((j&1|0)==0){j=r;e=m;x=l;y=s;z=n;A=1;while(1){B=j-1|0;C=j-2|0;D=e;E=x;F=y;G=z;while(1){H=D;I=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=D+4|0;b[F>>1]=I<<6;J=G+2|0;b[G>>1]=I>>>4&65535&-64;b[E>>1]=I>>>14&65535&-64;if(!(H>>>0<B>>>0)){K=13;break}I=H;H=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;I=D+8|0;b[J>>1]=H<<6;b[F+2>>1]=H>>>4&65535&-64;L=G+6|0;b[G+4>>1]=H>>>14&65535&-64;if(!(I>>>0<C>>>0)){K=15;break}H=I;I=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=D+12|0;b[E+2>>1]=I<<6;M=G+8|0;b[L>>1]=I>>>4&65535&-64;b[F+4>>1]=I>>>14&65535&-64;if(!(H>>>0<B>>>0)){K=17;break}I=H;H=d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0;N=D+16|0;b[M>>1]=H<<6;b[E+4>>1]=H>>>4&65535&-64;b[G+10>>1]=H>>>14&65535&-64;if(N>>>0<C>>>0){D=N;E=E+6|0;F=F+6|0;G=G+12|0}else{K=19;break}}if((K|0)==13){K=0;b[J>>1]=128;G=p+(ca(c[a>>2]|0,A)|0)|0;F=k+(ca(c[v>>2]|0,A)|0)|0;O=D+5|0;P=g+(ca(c[w>>2]|0,A)|0)|0;Q=F;R=G}else if((K|0)==15){K=0;b[L>>1]=128;G=p+(ca(c[a>>2]|0,A)|0)|0;F=k+(ca(c[v>>2]|0,A)|0)|0;O=D+10|0;P=g+(ca(c[w>>2]|0,A)|0)|0;Q=F;R=G}else if((K|0)==17){K=0;b[M>>1]=128;G=p+(ca(c[a>>2]|0,A)|0)|0;F=k+(ca(c[v>>2]|0,A)|0)|0;O=D+13|0;P=g+(ca(c[w>>2]|0,A)|0)|0;Q=F;R=G}else if((K|0)==19){K=0;G=p+(ca(c[a>>2]|0,A)|0)|0;F=k+(ca(c[v>>2]|0,A)|0)|0;O=N;P=g+(ca(c[w>>2]|0,A)|0)|0;Q=F;R=G}if((A|0)<(u|0)){j=j+t|0;e=O;x=P;y=Q;z=R;A=A+1|0}else{break}}}else{A=r;r=m;m=l;l=s;s=n;n=1;while(1){R=A-1|0;z=A-2|0;Q=r;y=m;P=l;x=s;while(1){O=Q;e=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=Q+4|0;b[P>>1]=e<<6;S=x+2|0;b[x>>1]=e>>>4&65535&-64;b[y>>1]=e>>>14&65535&-64;if(!(O>>>0<R>>>0)){K=23;break}e=O;O=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;T=Q+8|0;b[S>>1]=O<<6;b[P+2>>1]=O>>>4&65535&-64;b[x+4>>1]=O>>>14&65535&-64;if(!(T>>>0<z>>>0)){K=25;break}O=T;e=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=Q+12|0;b[y+2>>1]=e<<6;U=x+8|0;b[x+6>>1]=e>>>4&65535&-64;b[P+4>>1]=e>>>14&65535&-64;if(!(O>>>0<R>>>0)){K=27;break}e=O;O=d[e]|d[e+1|0]<<8|d[e+2|0]<<16|d[e+3|0]<<24|0;e=Q+16|0;b[U>>1]=O<<6;b[y+4>>1]=O>>>4&65535&-64;V=x+12|0;b[x+10>>1]=O>>>14&65535&-64;if(e>>>0<z>>>0){Q=e;y=y+6|0;P=P+6|0;x=V}else{K=29;break}}if((K|0)==23){K=0;b[S>>1]=128;x=p+(ca(c[a>>2]|0,n)|0)|0;P=k+(ca(c[v>>2]|0,n)|0)|0;W=Q+5|0;X=g+(ca(c[w>>2]|0,n)|0)|0;Y=P;Z=x}else if((K|0)==25){K=0;x=p+(ca(c[a>>2]|0,n)|0)|0;P=k+(ca(c[v>>2]|0,n)|0)|0;W=T;X=g+(ca(c[w>>2]|0,n)|0)|0;Y=P;Z=x}else if((K|0)==27){K=0;b[U>>1]=128;x=p+(ca(c[a>>2]|0,n)|0)|0;P=k+(ca(c[v>>2]|0,n)|0)|0;W=Q+13|0;X=g+(ca(c[w>>2]|0,n)|0)|0;Y=P;Z=x}else if((K|0)==29){K=0;b[V>>1]=128;x=p+(ca(c[a>>2]|0,n)|0)|0;P=k+(ca(c[v>>2]|0,n)|0)|0;W=Q+18|0;X=g+(ca(c[w>>2]|0,n)|0)|0;Y=P;Z=x}if((n|0)<(u|0)){A=A+t|0;r=W;m=X;l=Y;s=Z;n=n+1|0}else{break}}}}c[f>>2]=1;q=c[o>>2]|0;i=h;return q|0}function ejb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;e=a+60|0;f=c[e>>2]|0;do{if((c[a+100>>2]|0)==4){g=a+96|0;if((c[g>>2]|0)==0){break}h=a+120|0;j=c[h>>2]|0;do{if((j&15|0)==0){k=a+124|0;l=c[k>>2]|0;if((l&15|0)!=0){break}m=tIb(j,l,0,a)|0;if((m|0)<0){n=m;i=b;return n|0}m=f+1248|0;c[m>>2]=pJb(ca(c[h>>2]<<1,c[k>>2]|0)|0)|0;l=pJb(ca(c[h>>2]<<1,c[k>>2]|0)|0)|0;c[f+1252>>2]=l;if((c[m>>2]|0)==0|(l|0)==0){l=c[e>>2]|0;mJb(l+1248|0);mJb(l+1252|0);mJb(l+3136|0);c[l+3140>>2]=0;m=l+3148|0;k=0;do{mJb(m+(k<<4)+12|0);c[m+(k<<4)>>2]=0;k=k+1|0;}while((k|0)<100);c3(l+2344|0);n=-12;i=b;return n|0}else{k=c[g>>2]|0;m=f+3144|0;c[m>>2]=(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0)>>>16;l8(f+4|0,a);c[f>>2]=a;k=0;do{c[9882108+(k*80|0)>>2]=5903776+(k<<9);c[9882116+(k*80|0)>>2]=32;$2(9882104+(k*80|0)|0,5,7,1900761+(k<<6)|0,2,1,1900760+(k<<6)|0,2,1,0,0,0,4)|0;c[9882128+(k*80|0)>>2]=5903904+(k<<9);c[9882136+(k*80|0)>>2]=32;$2(9882124+(k*80|0)|0,5,7,1900777+(k<<6)|0,2,1,1900776+(k<<6)|0,2,1,0,0,0,4)|0;c[9882148+(k*80|0)>>2]=5904032+(k<<9);c[9882156+(k*80|0)>>2]=32;$2(9882144+(k*80|0)|0,5,7,1900793+(k<<6)|0,2,1,1900792+(k<<6)|0,2,1,0,0,0,4)|0;c[9882168+(k*80|0)>>2]=5904160+(k<<9);c[9882176+(k*80|0)>>2]=32;$2(9882164+(k*80|0)|0,5,7,1900809+(k<<6)|0,2,1,1900808+(k<<6)|0,2,1,0,0,0,4)|0;k=k+1|0;}while((k|0)<2);c[a+140>>2]=(c[m>>2]|0)>2?44:50;n=0;i=b;return n|0}}}while(0);KIb(a,16,2271904,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=b;return n|0}}while(0);KIb(a,16,2276312,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;n=-1094995529;i=b;return n|0}function fjb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0;j=i;i=i+5920|0;k=j|0;l=j+2048|0;m=j+2560|0;n=j+4608|0;o=j+4872|0;p=j+5904|0;q=c[h+24>>2]|0;r=c[h+28>>2]|0;h=c[e+60>>2]|0;s=h;t=f;if((r|0)<20){u=-1094995529;i=j;return u|0}v=e+120|0;if((c[v>>2]&15|0)!=0){KIb(0,0,2439080,(w=i,i=i+24|0,c[w>>2]=2351872,c[w+8>>2]=2290064,c[w+16>>2]=831,w)|0);i=w;Hd();return 0}x=e+124|0;if((c[x>>2]&15|0)!=0){KIb(0,0,2439080,(w=i,i=i+24|0,c[w>>2]=2351872,c[w+8>>2]=2290064,c[w+16>>2]=831,w)|0);i=w;Hd();return 0}y=q+4|0;z=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;if(r>>>0<(z+8|0)>>>0){KIb(c[h>>2]|0,16,2239664,(w=i,i=i+16|0,c[w>>2]=r,c[w+8>>2]=z,w)|0);i=w;u=-1094995529;i=j;return u|0}z=q;y=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;do{if((y|0)==1836213859){z=r-20|0;A=h+3144|0;B=c[A>>2]|0;if((B|0)<2){KIb(c[h>>2]|0,16,2167200,(w=i,i=i+8|0,c[w>>2]=B,w)|0);i=w;u=-1094995529;i=j;return u|0}B=q+12|0;C=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;B=q+16|0;D=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;if((D|z|0)<0){KIb(c[h>>2]|0,16,2140720,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=-1094995529;i=j;return u|0}B=h+3148|0;E=e+428|0;F=h;G=0;while(1){H=c[B+(G<<4)+8>>2]|0;do{if((H|0)!=0){if((H|0)>=(c[E>>2]|0)){break}KIb(c[F>>2]|0,16,2117296,(w=i,i=i+8|0,c[w>>2]=H,w)|0);i=w}}while(0);H=G+1|0;if((H|0)<100){G=H}else{I=-1;J=0;break}}while(1){if((c[B+(J<<4)+8>>2]|0)==(C|0)){K=19;break}G=(c[B+(J<<4)+4>>2]|0)==0?J:I;H=J+1|0;if((H|0)<100){I=G;J=H}else{L=G;K=20;break}}if((K|0)==19){if((J|0)>99){L=I;K=20}else{M=J}}if((K|0)==20){c[B+(L<<4)+8>>2]=C;M=L}G=B+(M<<4)+4|0;H=c[G>>2]|0;if(z>>>0>(-17-H|0)>>>0){u=-1094995529;i=j;return u|0}N=B+(M<<4)+12|0;O=wJb(c[N>>2]|0,B+(M<<4)|0,r-4+H|0)|0;c[N>>2]=O;if((O|0)==0){KIb(c[F>>2]|0,16,2635112,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=-12;i=j;return u|0}nrc(O+(c[G>>2]|0)|0,q+20|0,z)|0;O=(c[G>>2]|0)+z|0;c[G>>2]=O;if(O>>>0<D>>>0){u=r;i=j;return u|0}H=c[N>>2]|0;N=c[E>>2]|0;if((C|0)!=(N|0)){KIb(c[F>>2]|0,16,2611648,(w=i,i=i+16|0,c[w>>2]=C,c[w+8>>2]=N,w)|0);i=w}if((c[A>>2]|0)<2){u=-1094995529;i=j;return u|0}else{c[B+(M<<4)+8>>2]=0;c[G>>2]=0;P=H;Q=1836213872;R=O;break}}else{P=q+12|0;Q=y;R=r-12|0}}while(0);y=M4a(e,t,0)|0;if((y|0)<0){u=y;i=j;return u|0}a:do{if((Q|0)==1836213872|(Q|0)==846358128){c[f+88>>2]=2;y=h;t=c[y>>2]|0;q=c[t+120>>2]|0;M=c[t+124>>2]|0;L=c[h+1248>>2]|0;J=c[h+1252>>2]|0;I=h+3144|0;do{if((c[I>>2]|0)>1){if(R>>>0<20>>>0){S=-1094995529;break}O=P+8|0;H=P+12|0;G=P+16|0;T=20;U=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;V=d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0;W=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;K=132}else{O=P-4|0;G=(d[O]|d[O+1|0]<<8)<<16>>16&65535;O=P-2|0;H=(d[O]|d[O+1|0]<<8)<<16>>16&65535;T=0;U=H;V=R-G-H|0;W=G;K=132}}while(0);b:do{if((K|0)==132){do{if(!(W>>>0>R>>>0|W>>>0>268435454>>>0|V>>>0>(R-W|0)>>>0)){B=R-V-W|0;if(U>>>0>B>>>0|T>>>0>(B-U|0)>>>0){break}B=h+3136|0;A=B;A4a(B,h+3140|0,W);B=c[A>>2]|0;if((B|0)==0){S=-12;break b}ef[c[h+1100>>2]&4095](B,P+T|0,W>>>2);B=c[A>>2]|0;A=W<<3;C=A>>>0>2147483639>>>0|(B|0)==0;F=C?0:B;B=C?0:A;c[h+1276>>2]=F;c[h+1288>>2]=B;c[h+1292>>2]=B+8;c[h+1280>>2]=F+(B>>3);c[h+1284>>2]=0;B=T+W|0;F=B+U|0;A=P+B|0;if(!((R-B|0)>-1)){KIb(0,0,2439080,(w=i,i=i+24|0,c[w>>2]=2380928,c[w+8>>2]=2374544,c[w+16>>2]=135,w)|0);i=w;Hd();return 0}c[h+1308>>2]=A;c[h+1316>>2]=A;A=P+R|0;c[h+1312>>2]=A;B=P+F|0;if(!((R-F|0)>-1)){KIb(0,0,2439080,(w=i,i=i+24|0,c[w>>2]=2380928,c[w+8>>2]=2374544,c[w+16>>2]=135,w)|0);i=w;Hd();return 0}c[h+1296>>2]=B;c[h+1304>>2]=B;c[h+1300>>2]=A;A=q<<1;B=0;do{if((c[I>>2]|0)>1){c[s+1320+(B<<2)>>2]=((ca(a[791841+(B<<1)|0]|0,A)|0)/2|0)+(a[791840+(B<<1)|0]|0)}else{c[s+1320+(B<<2)>>2]=(B&15)-8+((ca((B>>4)-8|0,A)|0)/2|0)}B=B+1|0;}while((B|0)<256);if((M|0)<=0){break a}B=q<<3;A=L;F=J;C=0;while(1){E=0;while(1){if((E|0)>=(q|0)){break}D=hjb(s,A+(E<<1)|0,F+(E<<1)|0,3,3,q)|0;if((D|0)<0){S=D;break b}else{E=E+8|0}}E=C+8|0;if((E|0)<(M|0)){A=A+(B<<1)|0;F=F+(B<<1)|0;C=E}else{break a}}}}while(0);KIb(t,16,2439936,(w=i,i=i+32|0,c[w>>2]=W,c[w+8>>2]=V,c[w+16>>2]=U,c[w+24>>2]=W-R+V+U,w)|0);i=w;S=-1094995529}}while(0);KIb(c[y>>2]|0,16,2487312,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=S;i=j;return u|0}else if((Q|0)==846358121){c[f+88>>2]=1;t=P-4|0;M=R+4|0;q=p;J=h;L=c[J>>2]|0;I=c[L+120>>2]|0;C=c[L+124>>2]|0;if((ca(I+15>>4<<3,C+15>>4)|0)>(M|0)){KIb(L,16,2367312,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;X=-1094995529}else{L=c[h+1248>>2]|0;if(!((M|0)>-1)){KIb(0,0,2439080,(w=i,i=i+24|0,c[w>>2]=2380928,c[w+8>>2]=2374544,c[w+16>>2]=135,w)|0);i=w;Hd();return 0}if((C|0)<=0){break}B=(I|0)>0;F=(M|0)<8;M=p|0;A=p+4|0;E=p+8|0;D=p+12|0;z=I<<4;G=t;t=L;L=0;while(1){if(B){if(F){break}else{Y=G;Z=t;_=0}while(1){mrc(q|0,0,16)|0;H=Y;O=(d[H]|d[H+1|0]<<8)<<16>>16&65535;c[M>>2]=O;H=Y+2|0;N=(d[H]|d[H+1|0]<<8)<<16>>16&65535;c[A>>2]=N;if((O&32768|0)!=0){KIb(c[J>>2]|0,16,2284328,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}if((N&32768|0)!=0){KIb(c[J>>2]|0,16,2280576,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}H=O<<1;$=O>>>10;aa=N>>>10;c[E>>2]=(((((H&1984)+(N&992)|0)>>>0)/96|0)<<5)+((((($<<1)+aa|0)>>>0)/3|0)<<10)+((((H&62)+(N&31)|0)>>>0)/3|0);H=N<<1;c[D>>2]=(((((H&1984)+(O&992)|0)>>>0)/96|0)<<5)+(((((aa<<1)+$|0)>>>0)/3|0)<<10)+((((H&62)+(O&31)|0)>>>0)/3|0);O=Y+4|0;H=d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0;O=0;do{$=O>>>2<<3;aa=ca(O,I)|0;N=0;do{b[Z+(N+aa<<1)>>1]=c[p+((H>>>(((N>>2<<1)+$|0)>>>0)&3)<<2)>>2];N=N+1|0;}while((N|0)<16);O=O+1|0;}while((O|0)<16);O=Y+8|0;H=Z+32|0;N=_+16|0;if((N|0)<(I|0)){Y=O;Z=H;_=N}else{ba=O;da=H;ea=N;break}}}else{ba=G;da=t;ea=0}N=L+16|0;if((N|0)<(C|0)){G=ba;t=da+(z-ea<<1)|0;L=N}else{break a}}mrc(q|0,0,16)|0;X=-1}KIb(c[J>>2]|0,16,2546360,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=X;i=j;return u|0}else if((Q|0)==1836213865){c[f+88>>2]=1;L=h;z=c[L>>2]|0;t=c[z+120>>2]|0;G=c[z+124>>2]|0;C=P;I=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;c:do{if(I>>>0>67108864>>>0){fa=-1094995529}else{C=I+12|0;if(C>>>0>R>>>0){KIb(z,16,2367312,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;fa=-1094995529;break}D=P+(I+4)|0;E=(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24)<<2;D=P+C|0;if((E+C|0)!=(R|0)|E>>>0>67108864>>>0){KIb(z,16,2352592,(w=i,i=i+24|0,c[w>>2]=E,c[w+8>>2]=I,c[w+16>>2]=R,w)|0);i=w;fa=-1094995529;break}E=n|0;C=o;mrc(k|0,0,2048)|0;A=P+R|0;mrc(m|0,-1|0,2048)|0;M=A;F=D;B=P+(I+13)|0;y=d[D]|0;while(1){N=F+2|0;H=d[B]|0;O=H-y|0;if((M-N|0)<(((O+1|0)>0?O+2|0:1)|0)){K=60;break}$=F+3|0;aa=a[N]|0;ga=aa&255;if((y|0)>(H|0)){ha=N;ia=$;ja=aa;ka=ga}else{aa=y;N=$;$=ga;while(1){c[k+(aa<<2)>>2]=$;ga=aa+1|0;la=a[N]|0;ma=la&255;if((ga|0)>(H|0)){break}else{aa=ga;N=N+1|0;$=ma}}ha=F+(O+3)|0;ia=F+(O+4)|0;ja=la;ka=ma}if(ja<<24>>24==0){K=64;break}else{F=ha;B=ia;y=ka}}do{if((K|0)==60){KIb(z,16,2307488,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;na=0}else if((K|0)==64){c[k+1024>>2]=1;y=D;B=ia;while(1){if((B-y&3|0)==0){break}else{B=B+1|0}}if(B>>>0>A>>>0){KIb(z,16,2301616,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;na=0;break}else{oa=257}while(1){y=65536;O=65536;F=0;$=0;N=0;while(1){aa=c[k+(N<<2)>>2]|0;if((aa|0)!=0&(aa|0)<(y|0)){H=(aa|0)<(O|0);pa=H?N:$;qa=H?$:N;ra=H?aa:O;sa=H?O:aa}else{pa=$;qa=F;ra=O;sa=y}aa=N+1|0;if((aa|0)<(oa|0)){y=sa;O=ra;F=qa;$=pa;N=aa}else{break}}if((sa|0)==65536){ta=0;break}c[k+(oa<<2)>>2]=ra+sa;a[l+pa|0]=0;a[l+qa|0]=1;c[m+(qa<<2)>>2]=oa;c[m+(pa<<2)>>2]=oa;c[k+(qa<<2)>>2]=0;c[k+(pa<<2)>>2]=0;N=oa+1|0;if((N|0)<512){oa=N}else{ta=0;break}}do{N=m+(ta<<2)|0;$=c[N>>2]|0;if(($|0)==-1){ua=0;va=0}else{F=ta;O=0;y=0;aa=N;N=$;while(1){wa=(d[l+F|0]<<O)+y|0;xa=O+1|0;if((xa|0)>31){KIb(c[L>>2]|0,16,2290560,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ya=c[aa>>2]|0}else{ya=N}$=m+(ya<<2)|0;H=c[$>>2]|0;if((H|0)==-1){break}else{F=ya;O=xa;y=wa;aa=$;N=H}}ua=xa&255;va=wa}c[o+(ta<<2)>>2]=va;a[n+ta|0]=ua;ta=ta+1|0;}while((ta|0)<257);N=($2(h+2344|0,9,257,E,1,1,C,4,4,0,0,0,0)|0)==0;na=N?B:0}}while(0);if((na|0)==0){KIb(c[L>>2]|0,16,2344480,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;fa=-1094995529;break}if(na>>>0>A>>>0){KIb(0,0,2439080,(w=i,i=i+24|0,c[w>>2]=2338464,c[w+8>>2]=2290064,c[w+16>>2]=788,w)|0);i=w;Hd();return 0}C=P+4|0;E=I<<3;D=E>>>0>2147483639>>>0|(C|0)==0;N=D?0:C;C=D?0:E;E=h+1276|0;c[E>>2]=N;D=h+1288|0;c[D>>2]=C;aa=h+1292|0;c[aa>>2]=C+8;c[h+1280>>2]=N+(C>>3);C=h+1284|0;c[C>>2]=0;N=M-na|0;y=h+3136|0;O=y;A4a(y,h+3140|0,N);y=c[O>>2]|0;if((y|0)==0){fa=-12;break}ef[c[h+1100>>2]&4095](y,na,N>>>2);y=c[O>>2]|0;O=N<<3;N=O>>>0>2147483639>>>0|(y|0)==0;F=N?0:y;y=N?0:O;O=h+1256|0;c[O>>2]=F;c[h+1268>>2]=y;N=y+8|0;H=h+1272|0;c[H>>2]=N;c[h+1260>>2]=F+(y>>3);y=h+1264|0;c[y>>2]=0;$=h+2364|0;c[$>>2]=0;do{if((G|0)>0){ga=(t|0)>0;za=h+44|0;Aa=h+2368|0;Ba=h+2348|0;Ca=h+1248|0;Da=h+2496|0;Ea=h+2624|0;Fa=h+2752|0;Ga=h+2880|0;Ha=h+3008|0;Ia=0;d:while(1){if(ga){Ja=0;do{qe[c[za>>2]&1023](Aa);Ka=0;do{La=s+2368+(Ka<<7)|0;Ma=c[C>>2]|0;Na=(c[D>>2]|0)-Ma|0;if((Na|0)<2){K=92;break d}Oa=c[Ba>>2]|0;Pa=c[y>>2]|0;Qa=c[H>>2]|0;Ra=c[O>>2]|0;Sa=Ra+(Pa>>>3)|0;Ta=(je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Pa&7)>>>23;Sa=b[Oa+(Ta<<2)>>1]|0;Ua=b[Oa+(Ta<<2)+2>>1]|0;Ta=Ua<<16>>16;do{if(Ua<<16>>16<0){Va=Pa+9|0;Wa=Qa>>>0>Va>>>0?Va:Qa;Va=Ra+(Wa>>>3)|0;Xa=((je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Wa&7)>>>((Ta+32|0)>>>0))+Sa|0;Va=b[Oa+(Xa<<2)>>1]|0;Ya=b[Oa+(Xa<<2)+2>>1]|0;Xa=Ya<<16>>16;if(!(Ya<<16>>16<0)){Za=Xa;_a=Va;$a=Wa;break}Ya=Wa-Ta|0;Wa=Qa>>>0>Ya>>>0?Ya:Qa;Ya=Ra+(Wa>>>3)|0;ab=((je(d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0)|0)<<(Wa&7)>>>((Xa+32|0)>>>0))+Va|0;Za=b[Oa+(ab<<2)+2>>1]|0;_a=b[Oa+(ab<<2)>>1]|0;$a=Wa}else{Za=Ta;_a=Sa;$a=Pa}}while(0);Pa=Za+$a|0;Sa=Qa>>>0>Pa>>>0?Pa:Qa;c[y>>2]=Sa;if(_a>>>0>15>>>0){K=97;break d}if((_a|0)==0){bb=0;cb=Ma}else{Pa=c[aa>>2]|0;Ta=(c[E>>2]|0)+(Ma>>>3)|0;Ua=(je(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Ma&7);Ta=(Ua^-2147483648)>>31;Wa=_a+Ma|0;ab=Pa>>>0>Wa>>>0?Wa:Pa;c[C>>2]=ab;bb=((Ta^Ua)>>>((32-_a|0)>>>0)^Ta)-Ta<<4;cb=ab}ab=(c[$>>2]|0)+bb&65535;b[La>>1]=ab;c[$>>2]=ab<<16>>16;ab=1;Ta=Sa;Sa=cb;e:while(1){Ua=ab;Pa=Ta;while(1){Wa=Ra+(Pa>>>3)|0;Va=(je(d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0)|0)<<(Pa&7)>>>23;Wa=b[Oa+(Va<<2)>>1]|0;Xa=b[Oa+(Va<<2)+2>>1]|0;Va=Xa<<16>>16;do{if(Xa<<16>>16<0){Ya=Pa+9|0;db=Qa>>>0>Ya>>>0?Ya:Qa;Ya=Ra+(db>>>3)|0;eb=((je(d[Ya]|d[Ya+1|0]<<8|d[Ya+2|0]<<16|d[Ya+3|0]<<24|0)|0)<<(db&7)>>>((Va+32|0)>>>0))+Wa|0;Ya=b[Oa+(eb<<2)>>1]|0;fb=b[Oa+(eb<<2)+2>>1]|0;eb=fb<<16>>16;if(!(fb<<16>>16<0)){gb=eb;hb=Ya;ib=db;break}fb=db-Va|0;db=Qa>>>0>fb>>>0?fb:Qa;fb=Ra+(db>>>3)|0;jb=((je(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(db&7)>>>((eb+32|0)>>>0))+Ya|0;gb=b[Oa+(jb<<2)+2>>1]|0;hb=b[Oa+(jb<<2)>>1]|0;ib=db}else{gb=Va;hb=Wa;ib=Pa}}while(0);Wa=gb+ib|0;kb=Qa>>>0>Wa>>>0?Wa:Qa;c[y>>2]=kb;if((hb|0)==0){break e}else if((hb|0)!=240){break}Ua=Ua+16|0;Pa=kb}Pa=hb&15;if((Pa|0)==0){K=109;break d}Wa=c[aa>>2]|0;Va=(c[E>>2]|0)+(Sa>>>3)|0;Xa=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Sa&7);Va=(Xa^-2147483648)>>31;db=Pa+Sa|0;jb=Wa>>>0>db>>>0?db:Wa;c[C>>2]=jb;lb=(hb>>4)+Ua|0;if((lb|0)>63){K=110;break}Wa=d[1242080+lb|0]|0;b[s+2368+(Ka<<7)+(Wa<<1)>>1]=ca(d[1548224+Wa|0]|0,((Va^Xa)>>>((32-Pa|0)>>>0)^Va)-Va|0)|0;Va=lb+1|0;if((Va|0)>63){break}else{ab=Va;Ta=kb;Sa=jb}}if((K|0)==110){K=0;KIb(c[L>>2]|0,16,2312096,(w=i,i=i+8|0,c[w>>2]=lb,w)|0);i=w}Ka=Ka+1|0;}while((Ka|0)<6);Ka=c[(c[L>>2]|0)+120>>2]|0;Sa=c[Ca>>2]|0;Ta=(ca(Ka,Ia)|0)+Ja|0;b[Aa>>1]=(b[Aa>>1]|0)+8192;ijb(Aa);b[Da>>1]=(b[Da>>1]|0)+8192;ijb(Da);b[Ea>>1]=(b[Ea>>1]|0)+8192;ijb(Ea);b[Fa>>1]=(b[Fa>>1]|0)+8192;ijb(Fa);if((c[(c[L>>2]|0)+88>>2]&8192|0)==0){ijb(Ga);ijb(Ha)}ab=Ka+1|0;Qa=Ka<<1;Oa=Sa+(Ta<<1)|0;Ta=0;while(1){Sa=Ta>>2<<1;Ra=Ta<<4&48;La=Ta<<3;Ma=Oa;jb=0;while(1){Va=(jb>>2)+Sa|0;Pa=jb<<1&6|Ra;Xa=jb+La|0;Wa=b[s+2880+(Xa<<1)>>1]|0;db=b[s+3008+(Xa<<1)>>1]|0;Xa=db+Wa>>1;Ya=Wa<<1;Wa=b[s+2368+(Va<<7)+(Pa<<1)>>1]|0;b[Ma>>1]=(Wa+db<<8&63488)+((Wa+Ya|0)>>>3)+(Wa-Xa<<3&2016);Wa=b[s+2368+(Va<<7)+((Pa|1)<<1)>>1]|0;b[Ma+2>>1]=(Wa-Xa<<3&2016)+((Wa+Ya|0)>>>3)+(Wa+db<<8&63488);Wa=b[s+2368+(Va<<7)+((Pa|8)<<1)>>1]|0;b[Ma+(Ka<<1)>>1]=(Wa-Xa<<3&2016)+((Wa+Ya|0)>>>3)+(Wa+db<<8&63488);Wa=b[s+2368+(Va<<7)+((Pa|9)<<1)>>1]|0;b[Ma+(ab<<1)>>1]=(Wa-Xa<<3&2016)+((Wa+Ya|0)>>>3)+(Wa+db<<8&63488);db=jb+1|0;if((db|0)<8){Ma=Ma+4|0;jb=db}else{break}}jb=Ta+1|0;if((jb|0)<8){Oa=Oa+(Qa<<1)|0;Ta=jb}else{break}}Ja=Ja+16|0;}while((Ja|0)<(t|0))}Ja=Ia+16|0;if((Ja|0)<(G|0)){Ia=Ja}else{K=121;break}}if((K|0)==92){KIb(c[L>>2]|0,16,2327448,(w=i,i=i+8|0,c[w>>2]=Na,w)|0);i=w;fa=-1;break c}else if((K|0)==97){KIb(c[L>>2]|0,16,2321672,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;fa=-1094995529;break c}else if((K|0)==109){KIb(c[L>>2]|0,16,2316600,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;fa=-1094995529;break c}else if((K|0)==121){mb=c[y>>2]|0;nb=c[H>>2]|0;ob=c[O>>2]|0;pb=Ba;break}}else{mb=0;nb=N;ob=F;pb=h+2348|0}}while(0);F=c[pb>>2]|0;N=ob+(mb>>>3)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(mb&7)>>>23;N=b[F+(O<<2)>>1]|0;H=b[F+(O<<2)+2>>1]|0;O=H<<16>>16;do{if(H<<16>>16<0){C=mb+9|0;E=nb>>>0>C>>>0?C:nb;C=ob+(E>>>3)|0;aa=((je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>((O+32|0)>>>0))+N|0;C=b[F+(aa<<2)>>1]|0;$=b[F+(aa<<2)+2>>1]|0;aa=$<<16>>16;if(!($<<16>>16<0)){qb=aa;rb=C;sb=E;break}$=E-O|0;E=nb>>>0>$>>>0?$:nb;$=ob+(E>>>3)|0;D=((je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(E&7)>>>((aa+32|0)>>>0))+C|0;qb=b[F+(D<<2)+2>>1]|0;rb=b[F+(D<<2)>>1]|0;sb=E}else{qb=O;rb=N;sb=mb}}while(0);N=qb+sb|0;c[y>>2]=nb>>>0>N>>>0?N:nb;if((rb|0)==256){break a}KIb(c[L>>2]|0,16,2332824,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;break a}}while(0);KIb(c[L>>2]|0,16,2513592,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;u=fa;i=j;return u|0}else{G=e;if((Q|0)==1600417395){KIb(G,16,2466808,(w=i,i=i+8|0,c[w>>2]=r,w)|0);i=w;break}else{KIb(G,16,2457032,(w=i,i=i+8|0,c[w>>2]=r,w)|0);i=w;break}}}while(0);c[f+84>>2]=(c[f+88>>2]|0)==1;w=h+1248|0;Q=c[v>>2]<<1;uIb(c[f>>2]|0,c[f+32>>2]|0,c[w>>2]|0,Q,Q,c[x>>2]|0);x=h+1252|0;h=c[x>>2]|0;c[x>>2]=c[w>>2];c[w>>2]=h;c[g>>2]=1;u=r;i=j;return u|0}function gjb(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;mJb(b+1248|0);mJb(b+1252|0);mJb(b+3136|0);c[b+3140>>2]=0;a=b+3148|0;d=0;do{mJb(a+(d<<4)+12|0);c[a+(d<<4)>>2]=0;d=d+1|0;}while((d|0)<100);c3(b+2344|0);return 0}function hjb(a,f,g,h,j,k){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;l=i;m=a+3144|0;n=a+1284|0;o=a+1292|0;p=a+1276|0;q=a+1252|0;r=a|0;s=j;j=h;h=g;g=f;a:while(1){f=-1<<j;t=(j|0)>-1;u=s;v=h;w=g;while(1){x=1<<u;y=c[m>>2]|0;z=c[9882104+(((y|0)<2|0)*80|0)+((d[564872+(u<<2)+j|0]|0)*20|0)+4>>2]|0;A=c[n>>2]|0;B=c[o>>2]|0;C=(c[p>>2]|0)+(A>>>3)|0;D=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(A&7)>>>27;C=b[z+(D<<2)>>1]|0;E=C<<16>>16;F=(b[z+(D<<2)+2>>1]|0)+A|0;c[n>>2]=B>>>0>F>>>0?F:B;G=c[q>>2]|0;H=c[r>>2]|0;if(!((C&65535)>>>0<7>>>0&t)){I=4;break a}J=G+((ca(1-x+(c[H+124>>2]|0)|0,k)|0)+f<<1)|0;if((E|0)==6){I=10;break a}else if((E|0)==2){break}else if((E|0)!=1){I=15;break a}C=u-1|0;B=hjb(a,w,v,j,C,k)|0;if((B|0)<0){K=B;I=59;break a}B=k<<C;u=C;v=v+(B<<1)|0;w=w+(B<<1)|0}f=j-1|0;t=hjb(a,w,v,f,u,k)|0;if((t|0)<0){K=t;I=59;break}t=1<<f;s=u;j=f;h=v+(t<<1)|0;g=w+(t<<1)|0}if((I|0)==4){KIb(0,0,2439080,(L=i,i=i+24|0,c[L>>2]=2428888,c[L+8>>2]=2290064,c[L+16>>2]=352,L)|0);i=L;Hd();return 0}else if((I|0)==10){g=a+1308|0;h=c[g>>2]|0;if(((c[a+1312>>2]|0)-h|0)>>>0<4>>>0){KIb(H,16,2418336,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}s=h+2|0;c[g>>2]=s;r=h;b[w>>1]=(d[r]|d[r+1|0]<<8)<<16>>16;c[g>>2]=h+4;h=s;s=(d[h]|d[h+1|0]<<8)<<16>>16;if((j|0)==0){b[w+(k<<1)>>1]=s;K=0;i=l;return K|0}else{b[w+2>>1]=s;K=0;i=l;return K|0}}else if((I|0)==15){do{if((E&3|0)==0){if((c[a+1300>>2]|0)!=(c[a+1296>>2]|0)){break}KIb(H,16,2409448,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}}while(0);do{if((E|0)==5){s=a+1308|0;h=c[s>>2]|0;g=(c[a+1312>>2]|0)-h|0;if(g>>>0<2>>>0){KIb(H,16,2418336,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}if(G>>>0>v>>>0|J>>>0<v>>>0){KIb(0,0,2439080,(L=i,i=i+24|0,c[L>>2]=2401728,c[L+8>>2]=2290064,c[L+16>>2]=404,L)|0);i=L;Hd();return 0}if((g|0)<2){M=0;N=0;O=v;break}c[s>>2]=h+2;s=h;M=(d[s]|d[s+1|0]<<8)<<16>>16&65535;N=0;O=v}else if((E|0)==3){if((y|0)>1){K=0}else{M=0;N=1;O=v;break}i=l;return K|0}else if((E|0)==4){s=a+1296|0;h=c[s>>2]|0;if(((c[a+1300>>2]|0)-h|0)<1){P=0}else{c[s>>2]=h+1;P=d[h]|0}h=a+1308|0;s=c[h>>2]|0;g=(c[a+1312>>2]|0)-s|0;if(g>>>0<2>>>0){KIb(H,16,2418336,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}else{r=v+(c[a+1320+(P<<2)>>2]<<1)|0;if((g|0)<2){M=0;N=1;O=r;break}c[h>>2]=s+2;h=s;M=(d[h]|d[h+1|0]<<8)<<16>>16&65535;N=1;O=r;break}}else if((E|0)==0){r=a+1296|0;h=c[r>>2]|0;if(((c[a+1300>>2]|0)-h|0)<1){Q=0}else{c[r>>2]=h+1;Q=d[h]|0}M=0;N=1;O=v+(c[a+1320+(Q<<2)>>2]<<1)|0}else{M=0;N=1;O=v}}while(0);if(G>>>0>O>>>0|O>>>0>J>>>0){KIb(H,16,2395024,(L=i,i=i+1|0,i=i+7&-8,c[L>>2]=0,L)|0);i=L;K=-1094995529;i=l;return K|0}H=M*65537|0;if((j|0)==3){if((x|0)<=0){K=0;i=l;return K|0}M=(N|0)==0;J=-N|0;G=0;v=O;Q=w;while(1){a=v;c[Q>>2]=((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24)&J)+H;a=v+4|0;c[Q+4>>2]=((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24)&J)+H;a=v+8|0;c[Q+8>>2]=((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24)&J)+H;a=v+12|0;c[Q+12>>2]=((d[a]|d[a+1|0]<<8|d[a+2|0]<<16|d[a+3|0]<<24)&J)+H;if(M){R=v}else{R=v+(k<<1)|0}a=G+1|0;if((a|0)<(x|0)){G=a;v=R;Q=Q+(k<<1)|0}else{K=0;break}}i=l;return K|0}else if((j|0)==2){if((x|0)<=0){K=0;i=l;return K|0}Q=-N|0;if((N|0)==0){R=0;v=w;while(1){G=O;c[v>>2]=((d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24)&Q)+H;G=O+4|0;c[v+4>>2]=((d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24)&Q)+H;G=R+1|0;if((G|0)<(x|0)){R=G;v=v+(k<<1)|0}else{K=0;break}}i=l;return K|0}else{v=0;R=O;G=w;while(1){M=R;c[G>>2]=((d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24)&Q)+H;M=R+4|0;c[G+4>>2]=((d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24)&Q)+H;M=v+1|0;if((M|0)<(x|0)){v=M;R=R+(k<<1)|0;G=G+(k<<1)|0}else{K=0;break}}i=l;return K|0}}else if((j|0)==1){if((x|0)<=0){K=0;i=l;return K|0}if((N|0)==0){G=0;R=w;while(1){c[R>>2]=H;v=G+1|0;if((v|0)<(x|0)){G=v;R=R+(k<<1)|0}else{K=0;break}}i=l;return K|0}R=-N|0;G=0;v=O;Q=w;while(1){M=v;c[Q>>2]=((d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24)&R)+H;M=G+1|0;if((M|0)<(x|0)){G=M;v=v+(k<<1)|0;Q=Q+(k<<1)|0}else{K=0;break}}i=l;return K|0}else if((j|0)==0){if((x|0)<=0){K=0;i=l;return K|0}if((N|0)==0){j=H&65535;Q=0;v=w;while(1){b[v>>1]=j;G=Q+1|0;if((G|0)<(x|0)){Q=G;v=v+(k<<1)|0}else{K=0;break}}i=l;return K|0}else{v=-N|0;N=0;Q=O;O=w;while(1){b[O>>1]=(e[Q>>1]&v)+H;w=N+1|0;if((w|0)<(x|0)){N=w;Q=Q+(k<<1)|0;O=O+(k<<1)|0}else{K=0;break}}i=l;return K|0}}else{KIb(0,0,2439080,(L=i,i=i+24|0,c[L>>2]=2387848,c[L+8>>2]=2290064,c[L+16>>2]=334,L)|0);i=L;Hd();return 0}}else if((I|0)==59){i=l;return K|0}return 0}function ijb(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;i=i+256|0;e=d|0;f=0;while(1){g=b[a+(f<<1)>>1]|0;h=f+32|0;j=b[a+(h<<1)>>1]|0;k=j+g|0;l=g-j|0;j=f+16|0;g=b[a+(j<<1)>>1]|0;m=f+48|0;n=b[a+(m<<1)>>1]|0;o=n+g|0;p=(((g-n|0)*92682|0)>>16)-o|0;n=o+k|0;g=k-o|0;o=p+l|0;k=l-p|0;p=f+40|0;l=b[a+(p<<1)>>1]|0;q=f+24|0;r=b[a+(q<<1)>>1]|0;s=r+l|0;t=l-r|0;r=f+8|0;l=b[a+(r<<1)>>1]|0;u=f+56|0;v=b[a+(u<<1)>>1]|0;w=v+l|0;x=l-v|0;v=w+s|0;l=((x+t|0)*121095|0)>>16;y=((t*-171254|0)>>16)-v+l|0;t=(((w-s|0)*92682|0)>>16)-y|0;s=t+(((x*70936|0)>>16)-l)|0;c[e+(f<<2)>>2]=v+n;c[e+(u<<2)>>2]=n-v;c[e+(r<<2)>>2]=y+o;c[e+(m<<2)>>2]=o-y;c[e+(j<<2)>>2]=t+k;c[e+(p<<2)>>2]=k-t;c[e+(h<<2)>>2]=s+g;c[e+(q<<2)>>2]=g-s;s=f+1|0;if((s|0)<8){f=s}else{z=0;break}}do{f=c[e+(z<<2)>>2]|0;s=z|4;g=c[e+(s<<2)>>2]|0;q=g+f|0;h=f-g|0;g=z|2;f=c[e+(g<<2)>>2]|0;t=z|6;k=c[e+(t<<2)>>2]|0;p=k+f|0;j=(((f-k|0)*92682|0)>>16)-p|0;k=p+q|0;f=q-p|0;p=j+h|0;q=h-j|0;j=z|5;h=c[e+(j<<2)>>2]|0;y=z|3;o=c[e+(y<<2)>>2]|0;m=o+h|0;r=h-o|0;o=z|1;h=c[e+(o<<2)>>2]|0;v=z|7;n=c[e+(v<<2)>>2]|0;u=n+h|0;l=h-n|0;n=u+m|0;h=((l+r|0)*121095|0)>>16;x=((r*-171254|0)>>16)-n+h|0;r=(((u-m|0)*92682|0)>>16)-x|0;m=r+(((l*70936|0)>>16)-h)|0;b[a+(z<<1)>>1]=(n+k|0)>>>6;b[a+(v<<1)>>1]=(k-n|0)>>>6;b[a+(o<<1)>>1]=(x+p|0)>>>6;b[a+(t<<1)>>1]=(p-x|0)>>>6;b[a+(g<<1)>>1]=(r+q|0)>>>6;b[a+(j<<1)>>1]=(q-r|0)>>>6;b[a+(s<<1)>>1]=(m+f|0)>>>6;b[a+(y<<1)>>1]=(f-m|0)>>>6;z=z+8|0;}while((z|0)<64);i=d;return}function jjb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[b+60>>2]|0;c[e>>2]=b;f=c[b+792>>2]|0;if((f|0)==8){c[b+140>>2]=11;a[e+4|0]=1;a[e+5|0]=0}else if((f|0)==32){c[b+140>>2]=30;a[e+4|0]=4}else if((f|0)==24){c[b+140>>2]=We[c[b+152>>2]&2047](b,728880)|0;a[e+4|0]=3;a[e+5|0]=2;a[e+6|0]=1;a[e+7|0]=0}else{KIb(b,16,2438976,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;h=-1094995529;i=d;return h|0}if((c[b+140>>2]|0)!=30){h=0;i=d;return h|0}a[e+5|0]=2;a[e+6|0]=1;a[e+7|0]=0;a[e+8|0]=3;h=0;i=d;return h|0}function kjb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;i=c[h+24>>2]|0;j=c[h+28>>2]|0;k=c[e+60>>2]|0;l=c[e+124>>2]|0;m=a[k+4|0]|0;n=m&255;o=M4a(e,f,0)|0;if((o|0)<0){p=o;return p|0}o=l<<1;a:do{if(!(m<<24>>24==0)){q=i+(ca(n,o)|0)|0;r=f;s=f+32|0;t=i+j|0;if((l|0)==0){u=0;while(1){u=u+1|0;if(!(u>>>0<n>>>0)){break a}}}else{v=q;w=0}b:while(1){u=ca(w,o)|0;x=k+(w+5)|0;y=j-u|0;z=v;A=0;while(1){B=c[r>>2]|0;C=c[s>>2]|0;D=ca(C,A)|0;E=(d[x]|0)+D|0;D=A<<1;if(y>>>0<(D+2|0)>>>0){p=-1094995529;F=30;break b}G=b[i+(D+u)>>1]|0;c:do{if(G<<16>>16==0){H=z}else{D=B+(E+C)|0;I=z;J=(he(G|0)|0)&65535;K=B+E|0;while(1){if((t-I|0)<2){p=-1094995529;F=30;break b}L=I+1|0;M=a[I]|0;do{if(M<<24>>24>-1){N=M+1&255;O=N&255;P=J-1-O|0;if((D-K|0)>>>0<(ca(O,n)|0)>>>0){H=L;break c}if((t-L|0)<(O|0)){p=-1094995529;F=30;break b}if(N<<24>>24==0){Q=K;R=P;S=L;break}O=M&255;T=ca(n,O+1|0)|0;U=L;V=N;N=K;while(1){W=V-1&255;a[N]=a[U]|0;if(W<<24>>24==0){break}else{U=U+1|0;V=W;N=N+n|0}}Q=K+T|0;R=P;S=I+(O+2)|0}else{N=1-M&255;if((D-K|0)>>>0<(ca(N&255,n)|0)>>>0){H=L;break c}V=ca(n,(-M&255)+1|0)|0;U=N;N=K;while(1){W=U-1&255;a[N]=a[L]|0;if(W<<24>>24==0){break}else{U=W;N=N+n|0}}Q=K+V|0;R=J-2|0;S=I+2|0}}while(0);if((R|0)==0){H=S;break}else{I=S;J=R;K=Q}}}}while(0);E=A+1|0;if(E>>>0<l>>>0){z=H;A=E}else{break}}A=w+1|0;if(A>>>0<n>>>0){v=H;w=A}else{break a}}if((F|0)==30){return p|0}}}while(0);if((c[e+792>>2]|0)<9){e=V1(h,0,0)|0;if((e|0)==0){X=k+12|0}else{c[f+304>>2]=1;h=k+12|0;nrc(h|0,e|0,1024)|0;X=h}nrc(c[f+4>>2]|0,X|0,1024)|0}c[g>>2]=1;p=j;return p|0}function ljb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=c[a+60>>2]|0;if(((c[a+416>>2]|0)-1|0)>>>0>1>>>0){KIb(a,16,2140664,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-1094995529;i=b;return f|0}g=c[(c[a+12>>2]|0)+12>>2]|0;if((g|0)==86071){c[d+4>>2]=1489656}else if((g|0)==86072){c[d+4>>2]=1237992}else{KIb(a,16,2117256,(e=i,i=i+8|0,c[e>>2]=g,e)|0);i=e;f=-1094995529;i=b;return f|0}c[a+420>>2]=5;f=0;i=b;return f|0}function mjb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;j=c[b+60>>2]|0;k=e;l=j+8|0;m=l;n=l;o=c[n>>2]|0;if((o|0)!=0|(g|0)==0){p=o}else{o=g+28|0;q=c[o>>2]|0;r=b+416|0;s=c[r>>2]|0;t=(q|0)/(s|0)|0;u=t-2|0;if(((q|0)%(s|0)|0|0)==0){v=q;w=s}else{KIb(b,24,2239512,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;v=c[o>>2]|0;w=c[r>>2]|0}if((v|0)<(w*3|0|0)){KIb(b,16,2198656,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-22;i=h;return y|0}w=g+24|0;a[j]=a[(c[w>>2]|0)+1|0]^-128;if((c[r>>2]|0)==2){a[j+1|0]=a[(c[w>>2]|0)+(t+1)|0]^-128}c[j+20>>2]=0;c[j+16>>2]=u;v=hJb(u)|0;c[n>>2]=v;if((v|0)==0){y=-12;i=h;return y|0}do{if((c[r>>2]|0)==2){o=hJb(u)|0;c[j+12>>2]=o;if((o|0)!=0){z=c[n>>2]|0;break}mJb(l);y=-12;i=h;return y|0}else{z=v}}while(0);nrc(z|0,(c[w>>2]|0)+2|0,u)|0;if((c[r>>2]|0)==2){nrc(c[j+12>>2]|0,(c[w>>2]|0)+(t+2)|0,u)|0}p=c[n>>2]|0}if((p|0)==0){KIb(b,16,2167144,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-22;i=h;return y|0}x=j+20|0;p=(c[j+16>>2]|0)-(c[x>>2]|0)|0;n=(p|0)<2048?p:2048;if((n|0)<1){c[f>>2]=0;y=c[g+28>>2]|0;i=h;return y|0}c[e+76>>2]=n<<1;g=M4a(b,k,0)|0;if((g|0)<0){y=g;i=h;return y|0}g=b+416|0;a:do{if((c[g>>2]|0)>0){k=e;p=j+4|0;if((n|0)==0){u=0;while(1){u=u+1|0;if((u|0)>=(c[g>>2]|0)){break a}}}else{A=0}do{u=j+A|0;t=c[p>>2]|0;w=n;r=(c[m+(A<<2)>>2]|0)+(c[x>>2]|0)|0;z=a[u]|0;v=c[k+(A<<2)>>2]|0;while(1){l=w-1|0;o=d[r]|0;s=(a[t+(o&15)|0]|0)+(z&255)|0;if(s>>>0>255>>>0){B=-s>>31&255}else{B=s&255}a[v]=B;s=(a[t+(o>>>4)|0]|0)+(B&255)|0;if(s>>>0>255>>>0){C=-s>>31&255}else{C=s&255}a[v+1|0]=C;if((l|0)==0){break}else{w=l;r=r+1|0;z=C;v=v+2|0}}a[u]=C;A=A+1|0;}while((A|0)<(c[g>>2]|0))}}while(0);c[x>>2]=(c[x>>2]|0)+n;c[f>>2]=1;y=ca((((c[b+428>>2]|0)==0)<<1)+n|0,c[g>>2]|0)|0;i=h;return y|0}function njb(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+8|0);mJb(b+12|0);c[b+16>>2]=0;c[b+20>>2]=0;return 0}function ojb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b+60|0;g=c[f>>2]|0;AIb(g,1);h=b+80|0;j=c[h>>2]|0;if((j|0)<1){c[g+260>>2]=4;k=4}else{l=(j|0)/118|0;c[h>>2]=l;c[g+260>>2]=l;k=l}l=b;h=g+260|0;KIb(l,32,2239472,(j=i,i=i+8|0,c[j>>2]=k,j)|0);i=j;c[g+268>>2]=0;k=(c[(c[b+12>>2]|0)+12>>2]|0)==145|0;c[g+264>>2]=k;m=g+316|0;c[m>>2]=k|4;k=g+284|0;n=0;do{o=c[832488+(n<<2)>>2]|0;c[k+(n<<2)>>2]=~~(+(d[2103984+(o*3|0)|0]|0|0)*.3+ +(d[2103985+(o*3|0)|0]|0|0)*.59+ +(d[2103986+(o*3|0)|0]|0|0)*.11);n=n+1|0;}while((n|0)<(c[m>>2]|0));m=hJb((c[h>>2]|0)*128e3|0)|0;c[g+272>>2]=m;do{if((m|0)!=0){n=hJb(32768)|0;c[g+280>>2]=n;if((n|0)==0){break}n=pJb((c[h>>2]|0)*4e3|0)|0;c[g+276>>2]=n;if((n|0)==0){break}n=pJb(256)|0;c[g+308>>2]=n;if((n|0)==0){break}n=hJb(4096)|0;c[g+304>>2]=n;if((n|0)==0){break}n=pJb(48)|0;c[b+96>>2]=n;if((n|0)==0){KIb(l,16,2167096,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;p=-12;i=e;return p|0}c[b+100>>2]=32;k=n;y=je(c[h>>2]|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=n+16|0;y=16777216;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=UHb()|0;n=b+804|0;c[n>>2]=k;if((k|0)==0){o=c[f>>2]|0;VHb(n);kJb(c[o+272>>2]|0);kJb(c[o+280>>2]|0);kJb(c[o+304>>2]|0);kJb(c[o+276>>2]|0);kJb(c[o+308>>2]|0);p=-12;i=e;return p|0}c[k+88>>2]=1;c[k+84>>2]=1;k=b+52|0;if((c[k>>2]|0)==0){c[k>>2]=1832138337}k=g+320|0;c[k>>2]=0;c[k+4>>2]=-2147483648;p=0;i=e;return p|0}}while(0);KIb(l,16,2198616,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;p=-12;i=e;return p|0}function pjb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0;h=b+60|0;i=c[h>>2]|0;j=c[b+804>>2]|0;k=c[i+276>>2]|0;l=c[i+308>>2]|0;m=c[i+304>>2]|0;n=c[i+272>>2]|0;o=c[i+280>>2]|0;p=i+264|0;q=c[p>>2]<<8;r=b+124|0;s=c[r>>2]|0;t=(s|0)>200?25:s>>3;s=b+120|0;u=c[s>>2]|0;v=(u|0)>320?40:u>>3;u=ca(v,t)|0;do{if((f|0)==0){w=i+260|0;if((c[w>>2]|0)==0){x=0;return x|0}z=c[i+268>>2]|0;if((z|0)==0){A=0;B=0}else{A=z;B=z}c[w>>2]=B;C=A}else{w=i+268|0;z=c[w>>2]|0;D=c[i+260>>2]|0;if(!(z>>>0<D>>>0)){if((z|0)==(D|0)){C=D;break}else{x=0}return x|0}nrc(j|0,f|0,472)|0;c[j+88>>2]=1;c[j+84>>2]=1;D=c[s>>2]|0;z=c[r>>2]|0;E=(z|0)>200?200:z;z=(D|0)>320?320:D;D=c[j>>2]|0;F=j+32|0;G=n+(((c[w>>2]|0)*32e3|0)<<2)|0;H=-200;I=0;J=8;K=1;while(1){L=I-((J|0)>(K|0)?J:K)|0;M=H>>>0>L>>>0?H:L;L=I+8|0;N=0;O=G;P=319;Q=8;R=2;S=-1;while(1){T=P>>>1;U=~T;V=(((Q|0)>(R|0)?Q:R)+S|0)>>>1;W=~V;X=U>>>0>W>>>0?U:W;W=~T;T=~V;V=-(W>>>0>T>>>0?W:T)|0;T=N+8|0;W=I;U=O;while(1){if((W|0)<(E|0)){Y=N;Z=U;while(1){if((Y|0)<(z|0)){_=ca(c[F>>2]|0,W)|0;c[Z>>2]=((d[D+(_+(Y|1))|0]|0)+(d[D+(_+Y)|0]|0)|0)>>>1}_=Y+2|0;if((_|0)<(T|0)&(_|0)<320){Y=_;Z=Z+4|0}else{break}}}Z=W+1|0;if((Z|0)<(L|0)&(Z|0)<200){W=Z;U=U+(V<<2)|0}else{break}}$=O+((ca(M,X)|0)<<2)|0;if((T|0)<320){N=T;O=$;P=P-8|0;Q=Q+8|0;R=R+8|0;S=S-8|0}else{break}}if((L|0)<200){G=$;H=H+8|0;I=L;J=J+8|0;K=K+8|0}else{break}}c[w>>2]=(c[w>>2]|0)+1;K=i+320|0;if(!((c[K>>2]|0)==0&(c[K+4>>2]|0)==(-2147483648|0))){x=0;return x|0}J=f+136|0;I=c[J+4>>2]|0;c[K>>2]=c[J>>2];c[K+4>>2]=I;x=0;return x|0}}while(0);f=i+268|0;$=i+260|0;do{if((C|0)==0){aa=0;ba=55}else{j=(ca(C,u+q|0)|0)+4096|0;r=d5a(b,e,j,(j|0)<0|0?-1:0)|0;if((r|0)<0){x=r;return x|0}r=c[e+24>>2]|0;s=i;Tca(n,32,(c[$>>2]|0)*1e3|0,o,256,50,k,s);Uca(n,32,(c[$>>2]|0)*1e3|0,o,256,50,k,s);s=c[h>>2]|0;A=c[s+280>>2]|0;B=s+316|0;I=s+284|0;K=0;J=0;while(1){H=c[B>>2]|0;do{if((J|0)<(H-1|0)){G=J+1|0;if((K|0)!=(c[I+(G<<2)>>2]|0)){da=J;ea=H;break}D=I+(J<<2)|0;F=c[D>>2]|0;z=K-F|0;if((z|0)<0){da=G;ea=H;break}a[5411680+F|0]=0;if((z|0)>=1){F=1;do{a[5411680+(F+(c[D>>2]|0))|0]=(F*7|0|0)/(z|0)|0;F=F+1|0;}while((F|0)<=(z|0))}da=G;ea=c[B>>2]|0}else{da=J;ea=H}}while(0);if((da|0)>=(ea-1|0)){a[5411680+K|0]=0}a[5411424+K|0]=da;H=da+1|0;L=(c[B>>2]|0)-1|0;a[5411168+K|0]=(H|0)>(L|0)?L:H;H=K+1|0;if((H|0)<256){K=H;J=da}else{break}}J=s+296|0;K=s+288|0;B=s+264|0;I=0;w=A;H=m;while(1){L=0;z=0;F=0;while(1){D=L<<2;T=L<<1&6;X=T|1;E=0;S=0;R=0;Q=z;P=F;while(1){O=c[w+(S+D<<2)>>2]&255;N=a[5411424+O|0]|0;if((N&255)>>>0>2>>>0){fa=O+P-(c[J>>2]|0)|0}else{fa=P}if(N<<24>>24==0){ga=Q-O+(c[K>>2]|0)|0}else{ga=Q}M=d[5411680+O|0]|0;if((a[1067024+(M<<5)+(T<<2)+S|0]|0)==0){ha=N}else{ha=a[5411168+O|0]|0}ia=(ha&3|R<<2)^3;if((a[1067024+(M<<5)+(X<<2)+S|0]|0)==0){ja=N}else{ja=a[5411168+O|0]|0}ka=(ja&3|E<<2)^3;O=S+1|0;if((O|0)<4){E=ka;S=O;R=ia;Q=ga;P=fa}else{break}}a[H+L|0]=ia;a[H+(L+2048)|0]=ka;P=L+1|0;if((P|0)<8){L=P;z=ga;F=fa}else{break}}F=(fa|0)>0;do{if(F&(ga|0)>0){if((c[B>>2]|0)==0){ba=52;break}if((ga|0)>(fa|0)){z=0;do{L=c[J>>2]|0;P=w+(z<<2)|0;Q=c[P>>2]|0;c[P>>2]=(L|0)>(Q|0)?Q:L;z=z+1|0;}while((z|0)<32)}else{z=0;do{L=c[K>>2]|0;Q=w+(z<<2)|0;P=c[Q>>2]|0;c[Q>>2]=(L|0)>(P|0)?L:P;z=z+1|0;}while((z|0)<32)}la=H;ma=w;na=I-1|0}else{ba=52}}while(0);if((ba|0)==52){ba=0;a[l+I|0]=F&1;la=H+8|0;ma=w+128|0;na=I}z=na+1|0;if((z|0)<256){I=z;w=ma;H=la}else{break}}nrc(r|0,m|0,4096)|0;if((c[$>>2]|0)<=0){aa=j;ba=55;break}H=u+q|0;w=k;I=r+4096|0;K=j;J=0;while(1){if(!((t|0)<1|(v|0)<1)){B=0;do{A=ca(B,v)|0;s=0;do{z=s+A|0;a[I+z|0]=c[w+(z<<2)>>2];s=s+1|0;}while((s|0)<(v|0));B=B+1|0;}while((B|0)<(t|0))}B=K+u|0;if((c[p>>2]|0)==0){oa=B;pa=u}else{F=0;do{s=a[l+(c[w+(F+256<<2)>>2]|0)|0]<<1|a[l+(c[w+(F<<2)>>2]|0)|0]|a[l+(c[w+(F+512<<2)>>2]|0)|0]<<2;if((F|0)<232){qa=a[l+(c[w+(F+768<<2)>>2]|0)|0]<<3|s}else{qa=s}a[I+(F+u)|0]=qa<<2;F=F+1|0;}while((F|0)<256);oa=B+q|0;pa=H}F=J+1|0;if((F|0)<(c[$>>2]|0)){w=w+4e3|0;I=I+pa|0;K=oa;J=F}else{ra=oa;sa=H;break}}}}while(0);if((ba|0)==55){ra=aa;sa=u+q|0}q=je(c[f>>2]|0)|0;u=b+96|0;b=(c[u>>2]|0)+4|0;y=q;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=(c[u>>2]|0)+8|0;y=1048576;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;b=je(sa|0)|0;sa=(c[u>>2]|0)+12|0;y=b;a[sa]=y;y=y>>8;a[sa+1|0]=y;y=y>>8;a[sa+2|0]=y;y=y>>8;a[sa+3|0]=y;c[f>>2]=0;f=i+320|0;i=c[f>>2]|0;sa=c[f+4>>2]|0;b=e+16|0;c[b>>2]=i;c[b+4>>2]=sa;b=e+8|0;c[b>>2]=i;c[b+4>>2]=sa;c[f>>2]=0;c[f+4>>2]=-2147483648;c[e+28>>2]=ra;f=e+36|0;c[f>>2]=c[f>>2]|1;c[g>>2]=(ra|0)!=0;x=0;return x|0}function qjb(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(a+804|0);kJb(c[b+272>>2]|0);kJb(c[b+280>>2]|0);kJb(c[b+304>>2]|0);kJb(c[b+276>>2]|0);kJb(c[b+308>>2]|0);return 0}function rjb(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;c[k>>2]=g;c[l>>2]=h;g=c[a>>2]|0;n=g;o=g;p=g+84|0;q=c[p>>2]|0;a:do{if((q|0)>(h|0)){r=-100}else{s=g+88|0;t=g+48|0;u=g+96|0;v=g+44|0;w=g+4|0;x=q;y=h;while(1){if((x|0)==0){z=0;A=y}else{if((c[u>>2]|0)==0){break}else{z=x;A=y}}while(1){if((z|0)>=(A|0)){r=-100;break a}B=c[s>>2]|0;C=d[(c[k>>2]|0)+z|0]|0|(B<<8|0>>>24);D=c[s+4>>2]<<8|B>>>24|0;c[s>>2]=C;c[s+4>>2]=D;E=Xe[c[t>>2]&511](C,D,n,u,m)|0;if((E|0)!=0){break}z=z+1|0;A=c[l>>2]|0}if((E|0)<1){r=-100;break a}c[s>>2]=0;c[s+4>>2]=0;D=z+1-(c[v>>2]|0)|0;c[p>>2]=E;if((c[m>>2]|0)!=0){if(((c[w>>2]|0)+D|0)>=1){r=D;break a}}C=E+D|0;c[p>>2]=C;D=c[l>>2]|0;if((C|0)>(D|0)){r=-100;break a}else{x=C;y=D}}c[p>>2]=0;r=x}}while(0);if((IWa(o,r,k,l)|0)<0){o=c[p>>2]|0;E=c[l>>2]|0;c[p>>2]=o-((o|0)>(E|0)?E:o);c[e>>2]=0;c[f>>2]=0;F=c[l>>2]|0;i=j;return F|0}c[e>>2]=c[k>>2];c[f>>2]=c[l>>2];l=c[g+100>>2]|0;f=b+48|0;if((l|0)==0){G=c[f>>2]|0}else{c[f>>2]=l;G=l}if((G|0)!=86018){c[b+412>>2]=c[g+56>>2];G=c[b+440>>2]|0;if((G|0)==1){l=b+456|0;c[l>>2]=4;c[l+4>>2]=0}else if((G|0)==2){G=b+456|0;c[G>>2]=3;c[G+4>>2]=0}G=c[g+52>>2]|0;do{if((G|0)>1){l=b+456|0;f=c[l>>2]|0;k=c[l+4>>2]|0;if((f|0)==4&(k|0)==0){c[b+416>>2]=1;l=b+448|0;c[l>>2]=4;c[l+4>>2]=0;break}if(!((G|0)>2&((f|0)==3&(k|0)==0))){H=27;break}c[b+416>>2]=2;k=b+448|0;c[k>>2]=3;c[k+4>>2]=0}else{H=27}}while(0);if((H|0)==27){c[b+416>>2]=G;G=g+72|0;H=c[G+4>>2]|0;k=b+448|0;c[k>>2]=c[G>>2];c[k+4>>2]=H}c[a+304>>2]=c[g+64>>2];c[b+464>>2]=c[g+80>>2]}c[b+72>>2]=c[g+60>>2];F=r;i=j;return F|0}function sjb(a){a=a|0;var b=0;b=c[a>>2]|0;c[b+44>>2]=7;c[b+48>>2]=40;return 0}function tjb(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;i=i+56|0;j=h|0;k=h+24|0;l=h+48|0;m=je(a|0)|0;a=l|0;c[a>>2]=je(b|0)|0;c[a+4>>2]=m;m=l+8|0;c[j>>2]=m-7;c[j+12>>2]=56;c[j+16>>2]=64;c[j+4>>2]=m;c[j+8>>2]=0;m=T$(j,k)|0;if((m|0)<0){n=0;i=h;return n|0}c[f>>2]=0;c[g>>2]=1;c[e+56>>2]=c[k>>2];c[e+52>>2]=d[1343560+(d[k+15|0]|0)|0]|0;c[e+64>>2]=c[k+4>>2];c[e+60>>2]=c[k+8>>2];n=m;i=h;return n|0}function ujb(b){b=b|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0;f=i;i=i+192|0;h=f|0;j=c[b+60>>2]|0;k=j;c[j+4>>2]=b;l=b+412|0;c[j+6512>>2]=c[l>>2];c[j+6772>>2]=66;c[j+6776>>2]=48;c[j+6780>>2]=608;c[j+6784>>2]=408;c[j+6788>>2]=428;c[b+420>>2]=8;m=c[b+100>>2]|0;do{if((m|0)>0){n=Ajb(k,b,j+6504|0,c[b+96>>2]|0,m<<3,1)|0;if((n|0)<0){o=n;i=f;return o|0}else{p=b+416|0;break}}else{n=c[l>>2]|0;do{if((n|0)>92016){q=0}else{if((n|0)>75131){q=1;break}if((n|0)>55425){q=2;break}if((n|0)>46008){q=3;break}if((n|0)>37565){q=4;break}if((n|0)>27712){q=5;break}if((n|0)>23003){q=6;break}if((n|0)>18782){q=7;break}if((n|0)>13855){q=8;break}if((n|0)>11501){q=9;break}q=(n|0)>9390?10:11}}while(0);c[j+6508>>2]=q;n=b+416|0;c[j+6540>>2]=c[n>>2];c[j+6520>>2]=-1;c[j+6544>>2]=-1;r=0;while(1){if(!(r>>>0<8>>>0)){break}if((d[1343560+r|0]|0)==(c[n>>2]|0)){break}else{r=r+1|0}}s=(r|0)==8?0:r;c[j+6516>>2]=s;if((s|0)==0){p=n;break}t=h|0;u=s-1|0;if(u>>>0>6>>>0){KIb(b,16,2276248,(v=i,i=i+8|0,c[v>>2]=s,v)|0);i=v;if((c[b+696>>2]&8|0)==0){p=n;break}else{o=-1094995529}i=f;return o|0}w=a[312752+s|0]|0;nrc(h|0,2103696+(u*15|0)|0,w*3|0)|0;do{if((s|0)==7){if((c[b+680>>2]|0)>=1){break}KIb(b,32,2271736,(v=i,i=i+8|0,c[v>>2]=1,v)|0);i=v;a[h+8|0]=2}}while(0);Hjb(k,t,w,3,0)|0;p=n}}while(0);if((c[p>>2]|0)>64){KIb(b,16,2487288,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;o=-1094995529;i=f;return o|0}c[846819]=10228768;c[846821]=304;$2(3387272,8,e[722708]|0,c[361372]|0,1,1,c[361360]|0,2,2,0,0,0,4)|0;c[846824]=10227688;c[846826]=270;$2(3387292,8,e[722709]|0,c[361373]|0,1,1,c[361361]|0,2,2,0,0,0,4)|0;c[846829]=10225488;c[846831]=550;$2(3387312,8,e[722710]|0,c[361374]|0,1,1,c[361362]|0,2,2,0,0,0,4)|0;c[846834]=10224288;c[846836]=300;$2(3387332,8,e[722711]|0,c[361375]|0,1,1,c[361363]|0,2,2,0,0,0,4)|0;c[846839]=10222976;c[846841]=328;$2(3387352,8,e[722712]|0,c[361376]|0,1,1,c[361364]|0,2,2,0,0,0,4)|0;c[846844]=10221800;c[846846]=294;$2(3387372,8,e[722713]|0,c[361377]|0,1,1,c[361365]|0,2,2,0,0,0,4)|0;c[846849]=10220576;c[846851]=306;$2(3387392,8,e[722714]|0,c[361378]|0,1,1,c[361366]|0,2,2,0,0,0,4)|0;c[846854]=10219504;c[846856]=268;$2(3387412,8,e[722715]|0,c[361379]|0,1,1,c[361367]|0,2,2,0,0,0,4)|0;c[846859]=10217464;c[846861]=510;$2(3387432,8,e[722716]|0,c[361380]|0,1,1,c[361368]|0,2,2,0,0,0,4)|0;c[846864]=10216e3;c[846866]=366;$2(3387452,8,e[722717]|0,c[361381]|0,1,1,c[361369]|0,2,2,0,0,0,4)|0;c[846869]=10214152;c[846871]=462;$2(3387472,8,e[722718]|0,c[361382]|0,1,1,c[361370]|0,2,2,0,0,0,4)|0;bkb();yfa(j+5376|0,b);qHb(j+5396|0,c[b+88>>2]&8388608);c[j+5432>>2]=523124044;qkb();c[846875]=10212744;c[846877]=352;$2(3387496,7,121,1446024,1,1,1445536,4,4,0,0,0,4)|0;OPa(j+5120|0,11,1,2.9802322387695312e-8)|0;OPa(j+5248|0,10,1,5.960464477539063e-8)|0;OPa(j+5184|0,8,1,2.384185791015625e-7)|0;OPa(j+5312|0,11,0,-65536.0)|0;Fqb(8817248,4.0,1024);Fqb(8816736,6.0,128);H0a(10);H0a(9);H0a(7);if((c[2467039]|0)==0){x=0}else{o=0;i=f;return o|0}while(1){y=+(x|0);z=y*+T(+y,+.3333333333333333);g[9835392+(x<<2)>>2]=z;j=x+1|0;if((j|0)<8192){x=j}else{o=0;break}}i=f;return o|0}function vjb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+40|0;j=h|0;k=h+32|0;l=b+60|0;m=c[l>>2]|0;n=c[g+24>>2]|0;o=c[g+28>>2]|0;V1(g,1,h+24|0)|0;p=V1(g,71,k)|0;q=m+5696|0;c[q>>2]=0;if((p|0)!=0&(c[k>>2]|0)>0){c[q>>2]=(d[p]|0)+1}p=c[m+5692>>2]|0;if((p|0)>-1){c[q>>2]=p}if((o|0)>268435454){r=-1094995529;i=h;return r|0}p=o<<3;q=p>>>0>2147483639>>>0|(n|0)==0;k=q?0:n;s=q?0:p;c[j>>2]=k;p=j+12|0;c[p>>2]=s;t=j+16|0;c[t>>2]=s+8;c[j+4>>2]=k+(s>>3);s=j+8|0;c[s>>2]=0;if(q){r=q?-1094995529:0;i=h;return r|0}q=c[m+6504>>2]|0;do{if((q|0)==17|(q|0)==19|(q|0)==23|(q|0)==39){m=c[l>>2]|0;k=m;u=m+6516|0;v=c[u>>2]|0;w=m+6504|0;x=c[w>>2]|0;if((x|0)==39|(x|0)==23){y=512}else{y=1024}z=m+8|0;c[z>>2]=e;A=Cjb(b)|0;if((A|0)<0){r=A;i=h;return r|0}B=m+4|0;c[(c[B>>2]|0)+840>>2]=(c[w>>2]|0)-1;c[m+1004>>2]=0;if(v>>>0>7>>>0){QIb(b,2192600,(C=i,i=i+8|0,c[C>>2]=c[u>>2],C)|0);i=C;r=-1094995529;i=h;return r|0}u=a[312752+v|0]|0;m=v-1|0;v=(x|0)==39;x=A;A=0;while(1){if((A|0)>=(u|0)){D=24;break}E=d[2103696+(m*15|0)+(A*3|0)|0]|0;F=d[2103696+(m*15|0)+(A*3|0)+1|0]|0;w=Djb(k,E,F)|0;if((w|0)==0){D=16;break}if(!v){G=c[t>>2]|0;H=(c[s>>2]|0)+4|0;c[s>>2]=G>>>0>H>>>0?H:G}if((E|0)==3){I=Ejb(k,w+160|0,j,0)|0}else if((E|0)==0){I=Ejb(k,w+160|0,j,0)|0}else if((E|0)==1){I=Fjb(k,j,w)|0}else{I=x}if((I|0)<0){r=I;D=32;break}else{x=I;A=A+1|0}}if((D|0)==16){KIb(c[B>>2]|0,16,2140624,(C=i,i=i+16|0,c[C>>2]=E,c[C+8>>2]=F,C)|0);i=C;r=-1094995529;i=h;return r|0}else if((D|0)==24){Ijb(k);A=c[z>>2]|0;c[A+76>>2]=y;c[A+344>>2]=c[b+412>>2];c[f>>2]=1;A=c[s>>2]|0;x=(c[p>>2]|0)-A|0;v=-A|0;m=(c[t>>2]|0)-A|0;if((x|0)<(v|0)){J=v}else{J=(m|0)<(x|0)?m:x}x=J+A|0;c[s>>2]=x;K=x;break}else if((D|0)==32){i=h;return r|0}}else{x=Bjb(b,e,f,j,g)|0;if((x|0)<0){r=x;i=h;return r|0}else{K=c[s>>2]|0;break}}}while(0);s=K+7>>3;K=s;while(1){if((K|0)>=(o|0)){r=o;D=32;break}if((a[n+K|0]|0)==0){K=K+1|0}else{r=s;D=32;break}}if((D|0)==32){i=h;return r|0}return 0}function wjb(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[a+60>>2]|0;a=b+492|0;d=0;do{e=a+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){dkb(f+112352|0)}mJb(e);e=a+64+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){dkb(f+112352|0)}mJb(e);e=a+128+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){dkb(f+112352|0)}mJb(e);e=a+192+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){dkb(f+112352|0)}mJb(e);d=d+1|0;}while((d|0)<16);PPa(b+5120|0);PPa(b+5184|0);PPa(b+5248|0);PPa(b+5312|0);return 0}function xjb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=(c[a+60>>2]|0)+492|0;a=0;while(1){d=c[b+192+(a<<2)>>2]|0;if((d|0)!=0){mrc(d+9568|0,0,6144)|0;mrc(d+61760|0,0,6144)|0}d=a+1|0;if((d|0)<16){a=d}else{e=0;break}}while(1){a=c[b+128+(e<<2)>>2]|0;if((a|0)!=0){mrc(a+9568|0,0,6144)|0;mrc(a+61760|0,0,6144)|0}a=e+1|0;if((a|0)<16){e=a}else{f=0;break}}while(1){e=c[b+64+(f<<2)>>2]|0;if((e|0)!=0){mrc(e+9568|0,0,6144)|0;mrc(e+61760|0,0,6144)|0}e=f+1|0;if((e|0)<16){f=e}else{g=0;break}}do{f=c[b+(g<<2)>>2]|0;if((f|0)!=0){mrc(f+9568|0,0,6144)|0;mrc(f+61760|0,0,6144)|0}g=g+1|0;}while((g|0)<16);return}function yjb(a){a=a|0;var b=0,d=0;b=c[a+60>>2]|0;d=ujb(a)|0;if((c[a+100>>2]|0)<=0){return d|0}c[b+6816>>2]=(d|0)==0;return d|0}function zjb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;g=i;i=i+24|0;h=g|0;j=c[a+60>>2]|0;k=j;l=c[f+24>>2]|0;m=f+28|0;n=c[m>>2]|0;o=n>>>0>268435455>>>0?-8:n<<3;p=o>>>0>2147483639>>>0|(l|0)==0;q=p?0:l;l=p?0:o;o=h|0;c[o>>2]=q;r=h+12|0;c[r>>2]=l;s=l+8|0;t=h+16|0;c[t>>2]=s;c[h+4>>2]=q+(l>>3);l=h+8|0;c[l>>2]=0;if(p){u=p?-1094995529:0;i=g;return u|0}p=q;v=je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0;p=s>>>0>11>>>0?11:s;c[l>>2]=p;if((v&-2097152|0)!=1457520640){u=-1094995529;i=g;return u|0}v=q+(p>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(p&3)>>>19;v=p+13|0;p=s>>>0>v>>>0?v:s;c[l>>2]=p;v=w+3|0;if((v|0)>(n|0)){u=-1094995529;i=g;return u|0}n=q+(p>>>3)|0;w=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=p+1|0;x=s>>>0>n>>>0?n:s;c[l>>2]=x;a:do{if((w&-2147483648>>>((p&7)>>>0)|0)==0){n=q+(x>>>3)|0;y=je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0;n=x+1|0;c[l>>2]=s>>>0>n>>>0?n:s;n=j+6820|0;c[n>>2]=0;z=(y&-2147483648>>>((x&7)>>>0)|0)!=0;y=c[l>>2]|0;A=c[t>>2]|0;do{if(z){B=q+(y>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)>>>31;B=y+1|0;c[l>>2]=A>>>0>B>>>0?B:A;c[n>>2]=C;if((C|0)!=0){D=q;E=n;break a}C=c[l>>2]|0;B=c[t>>2]|0;F=q+(C>>>3)|0;G=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(C&7)>>>30;F=C+2|0;C=B>>>0>F>>>0?F:B;c[l>>2]=C;F=G<<3;G=F+8|0;if(G>>>0<26>>>0){H=G+C|0;G=B>>>0>H>>>0?H:B;c[l>>2]=G;I=G;J=B;break}else{G=C+16|0;C=(B>>>0>G>>>0?G:B)-8+F|0;F=B>>>0>C>>>0?C:B;c[l>>2]=F;I=F;J=B;break}}else{I=y;J=A}}while(0);A=I+1|0;y=(J>>>0>A>>>0?A:J)+6|0;A=J>>>0>y>>>0?y:J;c[l>>2]=A;y=q+(A>>>3)|0;B=je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0;y=A+4|0;F=J>>>0>y>>>0?y:J;c[l>>2]=F;if((-268435456>>>((A&7)>>>0)&B|0)!=0){QIb(c[j+4>>2]|0,2213448,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-1163346256;i=g;return u|0}B=q+(F>>>3)|0;A=je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0;B=F+3|0;y=J>>>0>B>>>0?B:J;c[l>>2]=y;if((A&-536870912>>>((F&7)>>>0)|0)!=0){QIb(c[j+4>>2]|0,2211208,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-1163346256;i=g;return u|0}do{if(z){F=q+(y>>>3)|0;A=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(y&7)>>>30;F=y+2|0;B=J>>>0>F>>>0?F:J;c[l>>2]=B;F=A<<3;A=F+8|0;C=q+(B>>>3)|0;G=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(B&7);if(A>>>0<26>>>0){C=A+B|0;c[l>>2]=J>>>0>C>>>0?C:J;L=G>>>((24-F|0)>>>0)}else{C=B+16|0;B=J>>>0>C>>>0?C:J;c[l>>2]=B;C=F-8|0;A=q+(B>>>3)|0;H=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(B&7)>>>((40-F|0)>>>0);F=C+B|0;c[l>>2]=J>>>0>F>>>0?F:J;L=H|G>>>16<<C}C=Pjb(k,h,L)|0;if((C|0)<0){u=C;i=g;return u|0}G=L-C|0;C=c[l>>2]|0;H=-C|0;F=c[t>>2]|0;B=F-C|0;if((G|0)<(H|0)){M=H}else{M=(B|0)<(G|0)?B:G}G=M+C|0;c[l>>2]=G;N=G;O=F}else{F=Pjb(k,h,0)|0;if((F|0)<0){u=F;i=g;return u|0}else{N=c[l>>2]|0;O=c[t>>2]|0;break}}}while(0);y=c[o>>2]|0;F=y+(N>>>3)|0;G=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(N&7)>>>29;F=N+3|0;c[l>>2]=O>>>0>F>>>0?F:O;c[j+6824>>2]=G;switch(G|0){case 1:{G=c[l>>2]|0;F=c[t>>2]|0;C=y+(G>>>3)|0;B=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(G&7)>>>23;C=G+9|0;c[l>>2]=F>>>0>C>>>0?C:F;c[j+6828>>2]=B;break};case 6:case 7:{B=c[t>>2]|0;F=(c[l>>2]|0)+1|0;c[l>>2]=B>>>0>F>>>0?F:B;break};case 3:case 4:case 5:{B=c[t>>2]|0;F=(c[l>>2]|0)+6|0;c[l>>2]=B>>>0>F>>>0?F:B;break};case 0:{B=c[t>>2]|0;F=(c[l>>2]|0)+8|0;c[l>>2]=B>>>0>F>>>0?F:B;break};default:{}}B=c[l>>2]|0;F=c[t>>2]|0;C=y+(B>>>3)|0;G=je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=B+1|0;H=F>>>0>C>>>0?C:F;c[l>>2]=H;b:do{if((G&-2147483648>>>((B&7)>>>0)|0)==0){P=H}else{if(!z){C=H;while(1){A=y+(C>>>3)|0;Q=je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0;A=C+1|0;R=(F>>>0>A>>>0?A:F)+8|0;A=F>>>0>R>>>0?R:F;c[l>>2]=A;if((Q&-2147483648>>>((C&7)>>>0)|0)==0){P=A;break b}else{C=A}}}C=y+(H>>>3)|0;A=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(H&7)>>>30;C=H+2|0;Q=F>>>0>C>>>0?C:F;c[l>>2]=Q;C=A<<3;A=C+8|0;if(A>>>0<26>>>0){R=A+Q|0;A=F>>>0>R>>>0?R:F;c[l>>2]=A;P=A;break}else{A=Q+16|0;Q=(F>>>0>A>>>0?A:F)-8+C|0;C=F>>>0>Q>>>0?Q:F;c[l>>2]=C;P=C;break}}}while(0);H=y+(P>>>3)|0;z=je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0;H=P+1|0;B=F>>>0>H>>>0?H:F;c[l>>2]=B;if((z&-2147483648>>>((P&7)>>>0)|0)==0){D=y;E=n;break}z=B+8|0;c[l>>2]=F>>>0>z>>>0?z:F;D=y;E=n}else{z=c[j+4>>2]|0;if((c[z+96>>2]|0)!=0){D=q;E=j+6820|0;break}KIb(z,48,2222712,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-11;i=g;return u|0}}while(0);do{if((c[E>>2]|0)==0){switch(c[j+6824>>2]|0){case 3:case 5:case 7:{q=c[t>>2]|0;P=(c[l>>2]|0)+2|0;c[l>>2]=q>>>0>P>>>0?P:q;S=0;break};case 1:{S=c[j+6828>>2]|0;break};case 0:{q=c[t>>2]|0;P=0;O=c[l>>2]|0;while(1){N=D+(O>>>3)|0;k=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(O&7)>>>24;N=O+8|0;M=q>>>0>N>>>0?N:q;c[l>>2]=M;N=k+P|0;if((k|0)==255){P=N;O=M}else{S=N;break}}break};default:{S=0}}O=S<<3;P=(c[r>>2]|0)-(c[l>>2]|0)|0;if((O|0)>(P|0)){KIb(c[j+4>>2]|0,16,2218984,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-1094995529;i=g;return u|0}if((O+256|0)>=(P|0)){break}KIb(c[j+4>>2]|0,16,2216040,(K=i,i=i+16|0,c[K>>2]=O,c[K+8>>2]=P,K)|0);i=K;u=-1094995529;i=g;return u|0}}while(0);r=j+6816|0;do{if((c[r>>2]|0)==0){S=a+96|0;t=c[S>>2]|0;if((t|0)==0){c[e>>2]=0;u=c[m>>2]|0;i=g;return u|0}E=j;P=j+6760|0;O=j+6504|0;if((c[P>>2]|0)==4){nrc(j+6240|0,O|0,264)|0;T=c[S>>2]|0}else{T=t}c[P>>2]=0;t=Ajb(E,a,O,T,c[a+100>>2]<<3,1)|0;if((t|0)>=0){c[r>>2]=1;U=c[o>>2]|0;break}if((c[P>>2]|0)==4){u=t;i=g;return u|0}if((c[j+6496>>2]|0)==0){u=t;i=g;return u|0}nrc(O|0,j+6240|0,264)|0;O=c[j+4>>2]|0;c[O+416>>2]=c[j+6744>>2];S=j+6752|0;q=c[S+4>>2]|0;n=O+448|0;c[n>>2]=c[S>>2];c[n+4>>2]=q;Hjb(E,j+6548|0,c[j+6740>>2]|0,c[P>>2]|0,0)|0;u=t;i=g;return u|0}else{U=D}}while(0);D=c[l>>2]|0;l=U+(D>>>3)|0;if(((je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(D&7)&-1048576|0)==-1048576){KIb(c[j+4>>2]|0,16,2239392,(K=i,i=i+1|0,i=i+7&-8,c[K>>2]=0,K)|0);i=K;u=-1094995529;i=g;return u|0}else{K=Bjb(a,b,e,h,f)|0;u=(K|0)<0?K:v;i=g;return u|0}return 0}function Ajb(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+216|0;l=k|0;m=k+192|0;n=h>>>0>2147483639>>>0|(g|0)==0;o=n?0:g;p=n?0:h;q=m|0;c[q>>2]=o;c[m+12>>2]=p;r=p+8|0;s=m+16|0;c[s>>2]=r;c[m+4>>2]=o+(p+7>>3);t=m+8|0;c[t>>2]=0;if(n){u=n?-1094995529:0;i=k;return u|0}n=CRa(f,g,h,j)|0;if((n|0)<0){u=-1094995529;i=k;return u|0}j=c[f+4>>2]|0;if((j|0)>12){KIb(e,16,2167064,(v=i,i=i+8|0,c[v>>2]=j,v)|0);i=v;u=-1094995529;i=k;return u|0}h=f|0;g=c[h>>2]|0;a:do{if((g|0)==23){if(!((j-3|0)>>>0>4>>>0)){w=(r|0)<(n|0)?r:n;c[t>>2]=w;x=w;y=10;break}KIb(e,16,2263496,(v=i,i=i+8|0,c[v>>2]=j,v)|0);i=v;u=-1094995529;i=k;return u|0}else{w=(r|0)<(n|0)?r:n;c[t>>2]=w;switch(g|0){case 39:{break};case 1:case 2:case 4:case 17:{x=w;y=10;break a;break};default:{RIb(e,2259624,(v=i,i=i+16|0,c[v>>2]=(c[f+16>>2]|0)==1?2255320:10230192,c[v+8>>2]=g,v)|0);i=v;u=-38;i=k;return u|0}}z=c[f+12>>2]|0;A=l|0;c[f+40>>2]=0;c[f+16>>2]=0;B=d[o+(w>>>3)|0]|0;C=((w|0)<(r|0))+w|0;c[t>>2]=C;if((B&128>>>((w&7)>>>0)|0)!=0){QIb(e,2240080,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1163346256;i=k;return u|0}w=o+(C>>>3)|0;B=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(C&7)>>>29;w=C+3|0;C=r>>>0>w>>>0?w:r;c[t>>2]=C;if((B|0)!=0){RIb(e,2234816,(v=i,i=i+8|0,c[v>>2]=B,v)|0);i=v;u=-1163346256;i=k;return u|0}B=d[o+(C>>>3)|0]|0;w=((C|0)<(r|0))+C|0;c[t>>2]=w;if((B&128>>>((C&7)>>>0)|0)!=0){RIb(e,2231168,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1163346256;i=k;return u|0}C=o+(w>>>3)|0;B=je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0;C=w+4|0;D=r>>>0>C>>>0?C:r;c[t>>2]=D;b:do{if((B&-268435456>>>((w&7)>>>0)|0)!=0){C=D;while(1){E=o+(C>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(C&7)>>>28;E=C+4|0;G=r>>>0>E>>>0?E:r;c[t>>2]=G;do{if((F|0)==15){E=o+(G>>>3)|0;H=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(G&7)>>>24;E=G+8|0;I=r>>>0>E>>>0?E:r;c[t>>2]=I;E=H+15|0;if((E|0)!=270){J=E;K=I;break}E=o+(I>>>3)|0;H=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(I&7)>>>16;E=I+16|0;I=r>>>0>E>>>0?E:r;c[t>>2]=I;J=H+270|0;K=I}else{J=F;K=G}}while(0);G=J<<3;if((p-K|0)<(G|4|0)){break}F=-K|0;I=r-K|0;if((G|0)<(F|0)){L=F}else{L=(I|0)<(G|0)?I:G}G=L+K|0;I=o+(G>>>3)|0;F=je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0;I=G+4|0;C=r>>>0>I>>>0?I:r;c[t>>2]=C;if((-268435456>>>((G&7)>>>0)&F|0)==0){break b}}KIb(c[b+4>>2]|0,16,2611552,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1094995529;i=k;return u|0}}while(0);D=l|0;w=z-1|0;if(w>>>0>6>>>0){KIb(e,16,2276248,(v=i,i=i+8|0,c[v>>2]=z,v)|0);i=v;u=-1094995529;i=k;return u|0}B=a[312752+z|0]|0;nrc(A|0,2103696+(w*15|0)|0,B*3|0)|0;do{if((z|0)==7){if((c[e+680>>2]|0)>=1){break}KIb(e,32,2271736,(v=i,i=i+8|0,c[v>>2]=1,v)|0);i=v;a[l+8|0]=2}}while(0);do{if((b|0)!=0){z=Hjb(b,D,B,3,0)|0;if((z|0)==0){break}if((z|0)<0){u=z}else{break a}i=k;return u|0}}while(0);B=c[t>>2]|0;D=c[s>>2]|0;z=(c[q>>2]|0)+(B>>>3)|0;A=(je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0)<<(B&7)>>>30;z=B+2|0;c[t>>2]=D>>>0>z>>>0?z:D;if((A|0)==0){break}RIb(e,2227336,(v=i,i=i+8|0,c[v>>2]=A,v)|0);i=v;u=-1163346256;i=k;return u|0}}while(0);c:do{if((y|0)==10){K=c[f+12>>2]|0;L=l|0;p=d[o+(x>>>3)|0]|0;J=((x|0)<(r|0))+x|0;c[t>>2]=J;if((p&128>>>((x&7)>>>0)|0)!=0){QIb(e,2240080,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;u=-1163346256;i=k;return u|0}p=((J|0)<(r|0))+J|0;if((d[o+(J>>>3)|0]&128>>>((J&7)>>>0)|0)==0){M=p}else{J=p+14|0;M=r>>>0>J>>>0?J:r}J=M&7;p=d[o+(M>>>3)|0]|0;n=((M|0)<(r|0))+M|0;c[t>>2]=n;if((g|0)==6|(g|0)==20){j=n+3|0;A=r>>>0>j>>>0?j:r;c[t>>2]=A;N=A}else{N=n}do{if((K|0)==0){n=N+4|0;c[t>>2]=r>>>0>n>>>0?n:r;n=Gjb(e,f,l|0,m)|0;if((n|0)<0){u=n}else{O=n;break}i=k;return u|0}else{n=K-1|0;if(n>>>0>6>>>0){KIb(e,16,2276248,(v=i,i=i+8|0,c[v>>2]=K,v)|0);i=v;u=-1094995529;i=k;return u|0}A=a[312752+K|0]|0;nrc(L|0,2103696+(n*15|0)|0,A*3|0)|0;if((K|0)!=7){O=A;break}if((c[e+680>>2]|0)>=1){O=A;break}KIb(e,32,2271736,(v=i,i=i+8|0,c[v>>2]=1,v)|0);i=v;a[l+8|0]=2;O=A}}while(0);K=l|0;do{if((O|0)>0){L=0;A=0;do{n=a[l+(A*3|0)+2|0]|0;if(n<<24>>24==0){P=0}else{P=n<<24>>24!=5|0}L=(((a[l+(A*3|0)|0]|0)==1?2:1)&-P)+L|0;A=A+1|0;}while((A|0)<(O|0));if((L|0)<=1){y=29;break}c[f+40>>2]=0}else{y=29}}while(0);do{if((y|0)==29){if((c[f+16>>2]|0)!=1){break}A=f+40|0;if(!((c[A>>2]|0)==-1)){break}c[A>>2]=1}}while(0);do{if((b|0)!=0){A=Hjb(b,K,O,3,0)|0;if((A|0)==0){break}if((A|0)<0){u=A}else{break c}i=k;return u|0}}while(0);K=c[h>>2]|0;if((p&128>>>(J>>>0)|0)!=0){d:do{switch(K|0){case 22:{A=c[s>>2]|0;n=(c[t>>2]|0)+5|0;j=(A>>>0>n>>>0?n:A)+11|0;n=A>>>0>j>>>0?j:A;c[t>>2]=n;Q=n;R=A;break};case 17:case 19:case 20:case 23:{A=c[t>>2]|0;n=c[s>>2]|0;j=(c[q>>2]|0)+(A>>>3)|0;D=(je(d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0)|0)<<(A&7)>>>29;j=A+3|0;A=n>>>0>j>>>0?j:n;c[t>>2]=A;if((D|0)==0){Q=A;R=n;break d}RIb(e,2234816,(v=i,i=i+8|0,c[v>>2]=D,v)|0);i=v;u=-1163346256;i=k;return u|0};default:{Q=c[t>>2]|0;R=c[s>>2]|0}}}while(0);J=Q+1|0;c[t>>2]=R>>>0>J>>>0?J:R}if(!((K|0)==17|(K|0)==19|(K|0)==20|(K|0)==23)){break}J=c[t>>2]|0;p=c[s>>2]|0;D=(c[q>>2]|0)+(J>>>3)|0;n=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(J&7)>>>30;D=J+2|0;c[t>>2]=p>>>0>D>>>0?D:p;if((n|0)==0){break}RIb(e,2227336,(v=i,i=i+8|0,c[v>>2]=n,v)|0);i=v;u=-1163346256;i=k;return u|0}}while(0);u=c[t>>2]|0;i=k;return u|0}function Bjb(e,f,h,j,k){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0.0,ua=0,va=0,wa=0,xa=0.0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0.0,Na=0,Oa=0,Pa=0.0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0.0,Va=0,Wa=0.0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0.0,nb=0,ob=0.0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0;l=i;i=i+688|0;m=l|0;n=l+256|0;o=l+264|0;p=l+272|0;q=l+296|0;r=l+488|0;s=l+680|0;t=c[e+60>>2]|0;u=t;v=t+8|0;c[v>>2]=f;w=j|0;x=j+8|0;z=c[x>>2]|0;A=(c[w>>2]|0)+(z>>>3)|0;a:do{if(((je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7)&-1048576|0)==-1048576){B=q|0;C=T$(j,p)|0;b:do{if((C|0)>0){D=t+6768|0;do{if((c[D>>2]|0)==0){if((a[p+16|0]|0)==1){break}RIb(c[t+4>>2]|0,2267024,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;c[D>>2]=1}}while(0);D=t+6760|0;if((c[D>>2]|0)==4){nrc(t+6240|0,t+6504|0,264)|0}c[D>>2]=0;F=p+15|0;G=a[F]|0;do{if(G<<24>>24==0){c[t+6516>>2]=0;if((c[t+5696>>2]|0)==0){break}if((c[t+6496>>2]|0)!=0){break}a[q+3|0]=0;a[B]=0;a[q+5|0]=1;a[q+2|0]=1;a[q+1|0]=0;a[q+4|0]=1;if((Hjb(u,q|0,2,2,0)|0)!=0){H=-7;break b}}else{I=G&255;c[t+6516>>2]=I;J=c[t+4>>2]|0;K=q|0;L=I-1|0;if(L>>>0>6>>>0){KIb(J,16,2276248,(E=i,i=i+8|0,c[E>>2]=I,E)|0);i=E;H=-1094995529;break b}M=a[312752+I|0]|0;nrc(B|0,2103696+(L*15|0)|0,M*3|0)|0;do{if(G<<24>>24==7){if((c[J+680>>2]|0)>=1){N=0;break}KIb(J,32,2271736,(E=i,i=i+8|0,c[E>>2]=1,E)|0);i=E;a[q+8|0]=2;N=c[D>>2]|0}else{N=0}}while(0);J=Hjb(u,K,M,N>>>0>2>>>0?N:2,0)|0;if((J|0)<0){H=J;break b}}}while(0);D=c[p>>2]|0;c[t+6512>>2]=D;c[t+6508>>2]=d[p+14|0]|0;c[t+6504>>2]=d[p+13|0]|0;do{if((c[t+6496>>2]|0)==4){if((c[t+6252>>2]|0)!=(d[F]|0)){O=21;break}if((c[t+6248>>2]|0)!=(D|0)){O=21}}else{O=21}}while(0);if((O|0)==21){c[t+6520>>2]=-1;c[t+6544>>2]=-1}if((a[p+12|0]|0)!=0){O=24;break}D=c[j+16>>2]|0;F=(c[x>>2]|0)+16|0;c[x>>2]=D>>>0>F>>>0?F:D;O=24}else{O=24}}while(0);do{if((O|0)==24){if((C|0)<0){H=C;break}B=c[t+6508>>2]|0;if((B|0)<=12){O=28;break a}KIb(c[t+4>>2]|0,16,2167064,(E=i,i=i+8|0,c[E>>2]=B,E)|0);i=E;P=-1094995529;break a}}while(0);KIb(e,16,2198576,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;P=H}else{O=28}}while(0);c:do{if((O|0)==28){H=Cjb(e)|0;if((H|0)<0){P=H;break}p=t+6504|0;N=p;q=t+4|0;c[(c[q>>2]|0)+840>>2]=(c[p>>2]|0)-1;c[t+1004>>2]=0;z=j+16|0;A=j+12|0;C=t+6760|0;B=t+6240|0;D=r|0;F=t+6516|0;G=e;J=t+6520|0;L=t+6544|0;I=t+6548|0;Q=t+6740|0;R=t+488|0;S=t+412|0;U=t+416|0;V=t+16|0;W=m|0;X=0;Y=0;Z=0;_=0;$=7;aa=0;ba=H;H=c[x>>2]|0;d:while(1){ca=c[z>>2]|0;da=c[w>>2]|0;ea=da+(H>>>3)|0;fa=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(H&7);ga=fa>>>29;ea=H+3|0;ha=ca>>>0>ea>>>0?ea:ca;c[x>>2]=ha;if((ga|0)==7){O=158;break}ea=da+(ha>>>3)|0;ia=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(ha&7)>>>28;ea=ha+4|0;c[x>>2]=ca>>>0>ea>>>0?ea:ca;if((fa|0)>-1){fa=Djb(u,ga,ia)|0;if((fa|0)==0){O=33;break}else{ja=fa;ka=1024}}else{ja=Y;ka=aa}e:do{switch(ga|0){case 2:{fa=c[x>>2]|0;ca=c[w>>2]|0;ea=d[ca+(fa>>>3)|0]<<(fa&7)>>>7;ha=c[z>>2]|0;da=((fa|0)<(ha|0))+fa|0;c[x>>2]=da;fa=ja+104544|0;c[fa>>2]=ea<<1&2;ea=ca+(da>>>3)|0;la=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(da&7)>>>29;ea=da+3|0;c[x>>2]=ha>>>0>ea>>>0?ea:ha;ha=ja+104548|0;c[ha>>2]=la;la=0;ea=0;while(1){da=ea+1|0;ma=c[x>>2]|0;na=d[ca+(ma>>>3)|0]<<(ma&7);oa=c[z>>2]|0;pa=((ma|0)<(oa|0))+ma|0;c[x>>2]=pa;ma=na>>>7&1;c[ja+104552+(la<<2)>>2]=ma;na=ca+(pa>>>3)|0;qa=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(pa&7)>>>28;na=pa+4|0;c[x>>2]=oa>>>0>na>>>0?na:oa;c[ja+104584+(la<<2)>>2]=qa;if((ma|0)==0){c[ja+104616+(la<<2)>>2]=2;ra=da}else{ma=c[x>>2]|0;qa=c[z>>2]|0;oa=ca+(ma>>>3)|0;na=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(ma&7)>>>30;oa=ma+2|0;c[x>>2]=qa>>>0>oa>>>0?oa:qa;c[ja+104616+(la<<2)>>2]=na;ra=(na|0)==3?ea+2|0:da}da=la+1|0;if((da|0)>(c[ha>>2]|0)){break}else{la=da;ea=ra}}ea=ja+160|0;la=c[x>>2]|0;ha=d[ca+(la>>>3)|0]|0;M=c[z>>2]|0;K=((la|0)<(M|0))+la|0;c[x>>2]=K;da=c[fa>>2]|0;if((ha&128>>>((la&7)>>>0)|0)==0){sa=da>>>0>1>>>0|0}else{sa=1}c[fa>>2]=sa+da;da=ca+(K>>>3)|0;la=je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0;da=K+1|0;ha=M>>>0>da>>>0?da:M;c[x>>2]=ha;da=ca+(ha>>>3)|0;na=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ha&7)>>>30;da=ha+2|0;c[x>>2]=M>>>0>da>>>0?da:M;ta=+g[1722032+(na<<2)>>2];na=Ejb(u,ea,j,0)|0;if((na|0)!=0){P=na;break c}if((ra|0)<=0){ua=_;va=Z;wa=X;break e}na=ja+176|0;M=ea|0;ea=(la&-2147483648>>>((K&7)>>>0)|0)==0;K=0;while(1){la=c[fa>>2]|0;if((K|0)==0){xa=1.0;ya=0;za=1}else{da=c[x>>2]|0;if((la|0)==3){Aa=1;Ba=da;Ca=c[z>>2]|0;Da=c[w>>2]|0;O=51}else{ha=c[w>>2]|0;qa=d[ha+(da>>>3)|0]<<(da&7)>>>7;oa=c[z>>2]|0;ma=((da|0)<(oa|0))+da|0;c[x>>2]=ma;da=qa&1;if((da|0)==0){Ea=0;Fa=0}else{Aa=da;Ba=ma;Ca=oa;Da=ha;O=51}}if((O|0)==51){O=0;ha=c[846875]|0;oa=Da+(Ba>>>3)|0;ma=(je(d[oa]|d[oa+1|0]<<8|d[oa+2|0]<<16|d[oa+3|0]<<24|0)|0)<<(Ba&7)>>>25;oa=b[ha+(ma<<2)>>1]|0;da=b[ha+(ma<<2)+2>>1]|0;ma=da<<16>>16;do{if(da<<16>>16<0){qa=Ba+7|0;pa=Ca>>>0>qa>>>0?qa:Ca;qa=Da+(pa>>>3)|0;Ga=((je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(pa&7)>>>((ma+32|0)>>>0))+oa|0;qa=b[ha+(Ga<<2)>>1]|0;Ha=b[ha+(Ga<<2)+2>>1]|0;Ga=Ha<<16>>16;if(!(Ha<<16>>16<0)){Ia=Ga;Ja=qa;Ka=pa;break}Ha=pa-ma|0;pa=Ca>>>0>Ha>>>0?Ha:Ca;Ha=Da+(pa>>>3)|0;La=((je(d[Ha]|d[Ha+1|0]<<8|d[Ha+2|0]<<16|d[Ha+3|0]<<24|0)|0)<<(pa&7)>>>((Ga+32|0)>>>0))+qa|0;Ia=b[ha+(La<<2)+2>>1]|0;Ja=b[ha+(La<<2)>>1]|0;Ka=pa}else{Ia=ma;Ja=oa;Ka=Ba}}while(0);oa=Ia+Ka|0;c[x>>2]=Ca>>>0>oa>>>0?oa:Ca;Ea=Ja-60|0;Fa=Aa}xa=+T(+ta,+(+(-Ea|0)));ya=Ea;za=Fa}do{if((la|0)==3){g[ja+104648+(K*480|0)>>2]=xa}else{oa=c[na>>2]|0;if((oa|0)<=0){break}ma=(za|0)==0;ha=a[M]|0;da=0;pa=0;La=ya;Ma=xa;qa=ha;Ga=oa;oa=ha;while(1){if(qa<<24>>24==0){Na=pa;Oa=La;Pa=Ma;Qa=0;Ra=Ga;Sa=oa}else{ha=0;Ha=pa;Ta=La;Ua=Ma;Va=oa;while(1){if((c[ja+3332+(Ha<<2)>>2]|0)==0){Wa=Ua;Xa=Ta;Ya=Va}else{do{if(ma){Za=c[846875]|0;_a=c[x>>2]|0;$a=c[z>>2]|0;ab=c[w>>2]|0;bb=ab+(_a>>>3)|0;cb=(je(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(_a&7)>>>25;bb=b[Za+(cb<<2)>>1]|0;db=b[Za+(cb<<2)+2>>1]|0;cb=db<<16>>16;do{if(db<<16>>16<0){eb=_a+7|0;fb=$a>>>0>eb>>>0?eb:$a;eb=ab+(fb>>>3)|0;gb=((je(d[eb]|d[eb+1|0]<<8|d[eb+2|0]<<16|d[eb+3|0]<<24|0)|0)<<(fb&7)>>>((cb+32|0)>>>0))+bb|0;eb=b[Za+(gb<<2)>>1]|0;hb=b[Za+(gb<<2)+2>>1]|0;gb=hb<<16>>16;if(!(hb<<16>>16<0)){ib=gb;jb=eb;kb=fb;break}hb=fb-cb|0;fb=$a>>>0>hb>>>0?hb:$a;hb=ab+(fb>>>3)|0;lb=((je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(fb&7)>>>((gb+32|0)>>>0))+eb|0;ib=b[Za+(lb<<2)+2>>1]|0;jb=b[Za+(lb<<2)>>1]|0;kb=fb}else{ib=cb;jb=bb;kb=_a}}while(0);_a=ib+kb|0;c[x>>2]=$a>>>0>_a>>>0?_a:$a;_a=jb-60|0;if((_a|0)==0){mb=Ua;nb=Ta;break}bb=_a+Ta|0;if(ea){ob=1.0;pb=bb}else{ob=+(1-(bb<<1&2)|0);pb=bb>>1}mb=ob*+T(+ta,+(+(-pb|0)));nb=bb}else{mb=Ua;nb=Ta}}while(0);g[ja+104648+(K*480|0)+(Ha<<2)>>2]=mb;Wa=mb;Xa=nb;Ya=a[M]|0}bb=ha+1|0;qb=Ha+1|0;if((bb|0)<(Ya&255|0)){ha=bb;Ha=qb;Ta=Xa;Ua=Wa;Va=Ya}else{break}}Na=qb;Oa=Xa;Pa=Wa;Qa=Ya;Ra=c[na>>2]|0;Sa=Ya}Va=da+1|0;if((Va|0)<(Ra|0)){da=Va;pa=Na;La=Oa;Ma=Pa;qa=Qa;Ga=Ra;oa=Sa}else{break}}}}while(0);la=K+1|0;if((la|0)<(ra|0)){K=la}else{ua=_;va=Z;wa=X;break}}break};case 3:{rb=X;sb=1;tb=Ejb(u,ja+160|0,j,0)|0;O=155;break};case 1:{rb=X;sb=1;tb=Fjb(u,j,ja)|0;O=155;break};case 4:{K=c[x>>2]|0;na=c[w>>2]|0;M=d[na+(K>>>3)|0]|0;ea=c[z>>2]|0;fa=((K|0)<(ea|0))+K|0;c[x>>2]=fa;ca=na+(fa>>>3)|0;la=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(fa&7)>>>24;ca=fa+8|0;fa=ea>>>0>ca>>>0?ca:ea;c[x>>2]=fa;if((la|0)==255){ca=na+(fa>>>3)|0;na=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(fa&7)>>>24;ca=fa+8|0;oa=ea>>>0>ca>>>0?ca:ea;c[x>>2]=oa;ub=na+255|0;vb=oa}else{ub=la;vb=fa}do{if((M&128>>>((K&7)>>>0)|0)==0){wb=vb}else{fa=-vb&7;if((fa|0)==0){wb=vb;break}la=fa+vb|0;fa=ea>>>0>la>>>0?la:ea;c[x>>2]=fa;wb=fa}}while(0);K=ub<<3;if(((c[A>>2]|0)-wb|0)<(K|0)){O=82;break d}M=-wb|0;fa=ea-wb|0;if((K|0)<(M|0)){xb=M}else{xb=(fa|0)<(K|0)?fa:K}c[x>>2]=xb+wb;ua=_;va=Z;wa=X;break};case 0:{rb=X+1|0;sb=1;tb=Ejb(u,ja+160|0,j,0)|0;O=155;break};case 6:{K=c[x>>2]|0;if((ia|0)==15){fa=c[z>>2]|0;M=(c[w>>2]|0)+(K>>>3)|0;la=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>24;M=K+8|0;oa=fa>>>0>M>>>0?M:fa;c[x>>2]=oa;yb=la+14|0;zb=oa}else{yb=ia;zb=K}if(((c[A>>2]|0)-zb|0)<(yb<<3|0)){O=98;break d}if((yb|0)<=0){ua=_;va=Z;wa=X;break e}K=(Y|0)==0;oa=Y+112352|0;la=yb;fa=zb;while(1){M=c[z>>2]|0;na=c[w>>2]|0;ca=na+(fa>>>3)|0;Ga=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(fa&7)>>>28;ca=fa+4|0;qa=M>>>0>ca>>>0?ca:M;c[x>>2]=qa;do{if((Ga|0)==14){Ab=1;O=101}else if((Ga|0)==13){Ab=0;O=101}else if((Ga|0)==0){ca=la<<3;La=ca-4|0;do{if((La|0)<69){Bb=La}else{pa=qa+13|0;da=M>>>0>pa>>>0?pa:M;c[x>>2]=da;pa=ca-17|0;if((pa|0)>7){ma=~((ca-25|0)>>>3);Va=ma>>>0>4294967041>>>0;Ta=pa;Ha=0;ha=1;bb=da;while(1){da=na+(bb>>>3)|0;_a=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(bb&7)>>>24;da=bb+8|0;cb=M>>>0>da>>>0?da:M;c[x>>2]=cb;a[m+Ha|0]=_a;_a=Ta-8|0;da=ha+1|0;if(da>>>0<256>>>0&(_a|0)>7){Ta=_a;Ha=ha;ha=da;bb=cb}else{break}}bb=Va?ma:-255;Cb=(bb<<3)+pa|0;Db=-bb|0}else{Cb=pa;Db=0}a[m+Db|0]=0;bb=c[q>>2]|0;if((c[bb+688>>2]&1|0)!=0){KIb(bb,48,2513576,(E=i,i=i+8|0,c[E>>2]=W,E)|0);i=E}bb=Bd(W|0,2499968,(E=i,i=i+16|0,c[E>>2]=n,c[E+8>>2]=o,E)|0)|0;i=E;if((bb|0)!=2){Bb=Cb;break}c[(c[(c[q>>2]|0)+64>>2]|0)+48>>2]=1024;Bb=Cb}}while(0);ca=c[x>>2]|0;La=-ca|0;bb=(c[z>>2]|0)-ca|0;if((Bb|0)<(La|0)){Eb=La}else{Eb=(bb|0)<(Bb|0)?bb:Bb}c[x>>2]=Eb+ca;Fb=la}else if((Ga|0)==11){ca=d[na+(qa>>>3)|0]|0;bb=((qa|0)<(M|0))+qa|0;c[x>>2]=bb;if((ca&128>>>((qa&7)>>>0)|0)==0){Gb=1;Hb=bb;Ib=M}else{ca=na+(bb>>>3)|0;La=(je(d[ca]|d[ca+1|0]<<8|d[ca+2|0]<<16|d[ca+3|0]<<24|0)|0)<<(bb&7)>>>28;ca=bb+4|0;c[x>>2]=M>>>0>ca>>>0?ca:M;c[V>>2]=La;La=c[z>>2]|0;ca=(c[x>>2]|0)+4|0;bb=La>>>0>ca>>>0?ca:La;c[x>>2]=bb;Gb=2;Hb=bb;Ib=La}La=d[na+(Hb>>>3)|0]|0;bb=((Hb|0)<(Ib|0))+Hb|0;c[x>>2]=bb;if((La&128>>>((Hb&7)>>>0)|0)==0){Jb=Gb;Kb=bb;Lb=Ib}else{bb=0;La=0;f:while(1){g:do{if((bb|0)<57){ca=La;while(1){if((ca|0)<7){Mb=ca;break g}ha=c[x>>2]|0;Ha=d[na+(ha>>>3)|0]|0;Ta=c[z>>2]|0;cb=((ha|0)<(Ta|0))+ha|0;c[x>>2]=cb;if((Ha&128>>>((ha&7)>>>0)|0)==0){Nb=cb;Ob=Ta;break f}else{ca=0}}}else{if((La|0)<7){Mb=La}else{O=125;break f}}}while(0);pa=c[x>>2]|0;ma=d[na+(pa>>>3)|0]<<(pa&7)>>>7;c[x>>2]=((pa|0)<(c[z>>2]|0))+pa;c[u+156+(bb<<2)>>2]=ma&1;bb=bb+1|0;La=Mb+1|0}if((O|0)==125){O=0;Nb=c[x>>2]|0;Ob=c[z>>2]|0}Jb=((bb|0)/7|0)+Gb|0;Kb=Nb;Lb=Ob}La=d[na+(Kb>>>3)|0]|0;ma=((Kb|0)<(Lb|0))+Kb|0;c[x>>2]=ma;if((La&128>>>((Kb&7)>>>0)|0)==0){Pb=1;Qb=Jb;Rb=ma;Sb=Lb}else{La=na+(ma>>>3)|0;pa=(je(d[La]|d[La+1|0]<<8|d[La+2|0]<<16|d[La+3|0]<<24|0)|0)<<(ma&7)>>>28;La=ma+4|0;c[x>>2]=Lb>>>0>La>>>0?La:Lb;c[S>>2]=pa;pa=c[x>>2]|0;La=c[z>>2]|0;ma=na+(pa>>>3)|0;Va=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(pa&7)>>>28;ma=pa+4|0;c[x>>2]=La>>>0>ma>>>0?ma:La;c[U>>2]=Va;Va=c[S>>2]|0;La=Va+1|0;ma=Jb+1|0;if((La|0)>0){pa=0;do{ca=c[x>>2]|0;Ta=c[z>>2]|0;cb=na+(ca>>>3)|0;ha=(je(d[cb]|d[cb+1|0]<<8|d[cb+2|0]<<16|d[cb+3|0]<<24|0)|0)<<(ca&7)>>>24;cb=ca+8|0;c[x>>2]=Ta>>>0>cb>>>0?cb:Ta;c[u+420+(pa<<2)>>2]=ha;pa=pa+1|0;}while((pa|0)<(La|0));Tb=Jb+2+Va|0}else{Tb=ma}Pb=La;Qb=Tb;Rb=c[x>>2]|0;Sb=c[z>>2]|0}pa=d[na+(Rb>>>3)|0]|0;bb=((Rb|0)<(Sb|0))+Rb|0;c[x>>2]=bb;if((pa&128>>>((Rb&7)>>>0)|0)==0){Ub=Qb;Vb=bb;Wb=Sb}else{pa=na+(bb>>>3)|0;ha=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(bb&7)>>>25;pa=bb+7|0;c[x>>2]=Sb>>>0>pa>>>0?pa:Sb;c[R>>2]=ha;ha=c[z>>2]|0;pa=(c[x>>2]|0)+1|0;bb=ha>>>0>pa>>>0?pa:ha;c[x>>2]=bb;Ub=Qb+1|0;Vb=bb;Wb=ha}if((Pb|0)>0){Xb=0;Yb=Vb;Zb=Wb}else{Fb=Ub;break}while(1){ha=d[na+(Yb>>>3)|0]<<(Yb&7)>>>7;c[x>>2]=((Yb|0)<(Zb|0))+Yb;c[u+20+(Xb<<2)>>2]=ha&1;ha=c[x>>2]|0;bb=c[z>>2]|0;pa=na+(ha>>>3)|0;Ta=(je(d[pa]|d[pa+1|0]<<8|d[pa+2|0]<<16|d[pa+3|0]<<24|0)|0)<<(ha&7)>>>25;pa=ha+7|0;c[x>>2]=bb>>>0>pa>>>0?pa:bb;c[u+88+(Xb<<2)>>2]=Ta;Ta=Xb+1|0;if((Ta|0)>=(Pb|0)){break}Xb=Ta;Yb=c[x>>2]|0;Zb=c[z>>2]|0}Fb=Ub+Pb|0}else{La=(la<<3)-4|0;ma=-qa|0;Va=M-qa|0;if((La|0)<(ma|0)){_b=ma}else{_b=(Va|0)<(La|0)?Va:La}c[x>>2]=_b+qa;Fb=la}}while(0);h:do{if((O|0)==101){O=0;if(K){KIb(c[q>>2]|0,16,2564192,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;Fb=la;break}qa=c[J>>2]|0;if((qa|0)==0){KIb(c[q>>2]|0,16,2546280,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;M=(la<<3)-4|0;na=c[x>>2]|0;Ga=-na|0;La=(c[z>>2]|0)-na|0;if((M|0)<(Ga|0)){$b=Ga}else{$b=(La|0)<(M|0)?La:M}c[x>>2]=$b+na;Fb=la;break}else if((qa|0)==(-1|0)){O=107}do{if((O|0)==107){O=0;if((c[C>>2]|0)!=4){break}KIb(c[q>>2]|0,16,2528632,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;qa=(la<<3)-4|0;na=c[x>>2]|0;M=-na|0;La=(c[z>>2]|0)-na|0;if((qa|0)<(M|0)){ac=M}else{ac=(La|0)<(qa|0)?La:qa}c[x>>2]=ac+na;Fb=la;break h}}while(0);do{if((c[L>>2]|0)==-1){na=c[C>>2]|0;if(!(na>>>0<4>>>0)){O=115;break}qa=c[q>>2]|0;if((c[qa+416>>2]|0)!=1){O=115;break}c[J>>2]=1;c[L>>2]=1;c[qa+840>>2]=28;Hjb(u,I,c[Q>>2]|0,na,1)|0}else{O=115}}while(0);if((O|0)==115){O=0;c[J>>2]=1;c[(c[q>>2]|0)+840>>2]=4}Fb=ekb(u,oa,j,Ab,la,$)|0}}while(0);na=la-Fb|0;if((na|0)<=0){ua=_;va=Z;wa=X;break e}la=na;fa=c[x>>2]|0}break};case 5:{if((c[C>>2]|0)==4){nrc(B|0,p|0,264)|0}c[C>>2]=0;fa=Gjb(e,N,D,j)|0;if((fa|0)<0){P=fa;break c}if((Z|0)!=0){KIb(G,16,2117168,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;rb=X;sb=_;tb=ba;O=155;break e}la=Hjb(u,D,fa,1,1)|0;if((la|0)!=0){P=la;break c}c[F>>2]=0;ua=_;va=1;wa=X;break};default:{P=-558323010;break c}}}while(0);if((O|0)==155){O=0;if((tb|0)==0){ua=sb;va=Z;wa=rb}else{P=tb;break c}}la=c[x>>2]|0;if(((c[A>>2]|0)-la|0)<3){O=157;break}else{X=wa;Y=ja;Z=va;_=ua;$=ga;aa=ka;ba=0;H=la}}if((O|0)==33){KIb(c[q>>2]|0,16,2140624,(E=i,i=i+16|0,c[E>>2]=ga,c[E+8>>2]=ia,E)|0);i=E;P=-1094995529;break}else if((O|0)==82){KIb(c[q>>2]|0,16,2418256,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;P=-1094995529;break}else if((O|0)==98){KIb(G,16,2635032,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;P=-1094995529;break}else if((O|0)==157){KIb(G,16,2611552,(E=i,i=i+1|0,i=i+7&-8,c[E>>2]=0,E)|0);i=E;P=-1094995529;break}else if((O|0)==158){Ijb(u);if((c[J>>2]|0)==1){bc=(c[t+6532>>2]|0)>(c[t+6512>>2]|0)|0}else{bc=0}H=aa<<bc;if(!((c[C>>2]|0)==0|(_|0)==0)){c[e+412>>2]=c[t+6512>>2]<<bc;c[e+424>>2]=H;c[C>>2]=4}do{if((bc|0)!=0){ba=V1(k,70,s)|0;if(!((ba|0)!=0&(c[s>>2]|0)>3)){break}$=ba;y=(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24)<<1;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y}}while(0);C=(H|0)!=0;_=C&1;c[h>>2]=_;aa=c[v>>2]|0;if(C){c[aa+76>>2]=H;c[aa+344>>2]=c[e+412>>2]}else{WHb(aa)}c[h>>2]=_;_=c[t+5696>>2]|0;if(!((_|0)!=0&(X|0)==2)){cc=0;i=l;return cc|0}aa=t+6752|0;if(!((c[aa>>2]|0)==3&(c[aa+4>>2]|0)==0)){cc=0;i=l;return cc|0}if((_|0)==1){c[f+4>>2]=c[f>>2];cc=0;i=l;return cc|0}else if((_|0)==2){c[f>>2]=c[f+4>>2];cc=0;i=l;return cc|0}else{cc=0;i=l;return cc|0}}}}while(0);f=t+6760|0;if((c[f>>2]|0)==4){cc=P;i=l;return cc|0}if((c[t+6496>>2]|0)==0){cc=P;i=l;return cc|0}nrc(t+6504|0,t+6240|0,264)|0;h=c[t+4>>2]|0;c[h+416>>2]=c[t+6744>>2];e=t+6752|0;v=c[e+4>>2]|0;s=h+448|0;c[s>>2]=c[e>>2];c[s+4>>2]=v;Hjb(u,t+6548|0,c[t+6740>>2]|0,c[f>>2]|0,0)|0;cc=P;i=l;return cc|0}function Cjb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+60>>2]|0;d=b+492|0;e=0;while(1){f=c[d+(e<<2)>>2]|0;if((f|0)!=0){c[f+52320>>2]=f+15712;c[f+104512>>2]=f+67904}f=e+1|0;if((f|0)<16){e=f}else{g=0;break}}while(1){e=c[d+64+(g<<2)>>2]|0;if((e|0)!=0){c[e+52320>>2]=e+15712;c[e+104512>>2]=e+67904}e=g+1|0;if((e|0)<16){g=e}else{h=0;break}}while(1){g=c[d+128+(h<<2)>>2]|0;if((g|0)!=0){c[g+52320>>2]=g+15712;c[g+104512>>2]=g+67904}g=h+1|0;if((g|0)<16){h=g}else{i=0;break}}do{h=c[d+192+(i<<2)>>2]|0;if((h|0)!=0){c[h+52320>>2]=h+15712;c[h+104512>>2]=h+67904}i=i+1|0;}while((i|0)<16);i=b+8|0;WHb(c[i>>2]|0);d=a+416|0;if((c[d>>2]|0)==0){j=1;return j|0}h=c[i>>2]|0;c[h+76>>2]=2048;g=M4a(a,h,0)|0;if((g|0)<0){j=g;return j|0}g=c[d>>2]|0;if((g|0)<=0){j=0;return j|0}d=b+5436|0;b=0;while(1){h=c[d+(b<<2)>>2]|0;if((h|0)!=0){c[h+52160>>2]=c[(c[(c[i>>2]|0)+64>>2]|0)+(b<<2)>>2]}h=b+1|0;if((h|0)<(g|0)){b=h}else{j=0;break}}return j|0}function Djb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+384|0;g=f|0;h=f+192|0;j=b+6516|0;k=c[j>>2]|0;if((k|0)==0){l=c[b+748+(d<<6)+(e<<2)>>2]|0;i=f;return l|0}m=b+1004|0;n=c[m>>2]|0;o=(d|0)==1;do{if((n|0)==0&o&(k|0)==1){p=b+6760|0;if((c[p>>2]|0)==4){nrc(b+6240|0,b+6504|0,264)|0}c[p>>2]=0;KIb(c[b+4>>2]|0,48,2284296,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;p=g|0;a[p]=a[2103711]|0;a[p+1|0]=a[2103712]|0;a[p+2|0]=a[2103713]|0;if((Hjb(b,g|0,1,2,1)|0)<0){l=0;i=f;return l|0}else{c[j>>2]=2;c[b+6544>>2]=0;r=c[m>>2]|0;s=2;break}}else{r=n;s=k}}while(0);k=(d|0)==0;a:do{if((r|d|0)==0&(s|0)==2){n=b+6760|0;if((c[n>>2]|0)==4){nrc(b+6240|0,b+6504|0,264)|0}c[n>>2]=0;KIb(c[b+4>>2]|0,48,2280536,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;n=h|0;a[n]=a[2103696]|0;a[n+1|0]=a[2103697]|0;a[n+2|0]=a[2103698]|0;if((Hjb(b,h|0,1,2,1)|0)<0){l=0;i=f;return l|0}c[j>>2]=1;if((c[b+6520>>2]|0)==0){break}c[b+6544>>2]=-1}else{b:do{switch(s|0){case 4:{t=c[m>>2]|0;u=4;v=25;break};case 1:{break a;break};case 3:case 2:{w=s;v=28;break};case 5:{x=c[m>>2]|0;y=5;v=22;break};case 7:{n=c[m>>2]|0;if(!((n|0)==3&o)){z=n;v=19;break b}c[m>>2]=4;n=c[b+564>>2]|0;c[b+812+(e<<2)>>2]=n;l=n;i=f;return l|0};case 6:{z=c[m>>2]|0;v=19;break};default:{l=0;i=f;return l|0}}}while(0);do{if((v|0)==19){n=a[312752+s|0]|0;if((z|0)!=(n-1|0)){x=z;y=s;v=22;break}if(!((d|0)==3|(d|0)==0)){x=z;y=s;v=22;break}c[m>>2]=n;n=c[b+684>>2]|0;c[b+748+(d<<6)+(e<<2)>>2]=n;l=n;i=f;return l|0}}while(0);do{if((v|0)==22){if(!((x|0)==2&o)){t=x;u=y;v=25;break}c[m>>2]=3;n=c[b+560>>2]|0;c[b+812+(e<<2)>>2]=n;l=n;i=f;return l|0}}while(0);do{if((v|0)==25){if((t|0)!=2){w=u;v=28;break}if(!((u|0)==4&k)){A=u;break}c[m>>2]=3;n=c[b+496>>2]|0;c[b+748+(e<<2)>>2]=n;l=n;i=f;return l|0}}while(0);do{if((v|0)==28){n=c[m>>2]|0;if(!((n|0)==((w|0)!=2|0)&o)){A=w;break}c[m>>2]=n+1;n=c[b+556>>2]|0;c[b+812+(e<<2)>>2]=n;l=n;i=f;return l|0}}while(0);if((A|0)==2){l=0}else{break}i=f;return l|0}}while(0);A=c[m>>2]|0;if((A|d|0)!=0){l=0;i=f;return l|0}c[m>>2]=A+1;A=c[b+492>>2]|0;c[b+748+(e<<2)>>2]=A;l=A;i=f;return l|0}function Ejb(f,h,j,l){f=f|0;h=h|0;j=j|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0.0,Ib=0.0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0.0,sc=0.0,tc=0.0,uc=0.0;m=i;i=i+40|0;n=m|0;o=h+152|0;p=h|0;q=h+5312|0;r=f+6504|0;s=c[r>>2]|0;t=(s|0)==39;if((s|0)==17|(s|0)==19|(s|0)==23){u=1}else{u=t}s=n|0;c[s>>2]=0;v=j+8|0;w=c[v>>2]|0;x=j+16|0;y=c[x>>2]|0;z=j|0;A=(c[z>>2]|0)+(w>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(w&7)>>>24;A=w+8|0;c[v>>2]=y>>>0>A>>>0?A:y;y=(l|0)!=0;do{if(!y){if((Mjb(f,p,j)|0)<0){C=-1094995529}else{break}i=m;return C|0}}while(0);l=h+4|0;A=(c[l>>2]|0)==2?3:5;w=h+16|0;D=c[w>>2]|0;a:do{if((D|0)>0){E=h|0;F=32-A|0;G=j+12|0;H=(1<<A)-1|0;I=a[E]|0;J=0;K=0;L=I;M=D;N=I;b:while(1){if(L<<24>>24==0){O=J;P=0;Q=M;T=N}else{I=c[z>>2]|0;U=J;V=0;while(1){W=c[v>>2]|0;X=c[x>>2]|0;Y=I+(W>>>3)|0;Z=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(W&7)>>>28;Y=W+4|0;W=X>>>0>Y>>>0?Y:X;c[v>>2]=W;if((Z|0)==12){_=14;break b}Y=c[G>>2]|0;$=V&255;aa=W;while(1){W=I+(aa>>>3)|0;ba=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(aa&7)>>>(F>>>0);W=aa+A|0;da=X>>>0>W>>>0?W:X;c[v>>2]=da;W=ba+($&255)|0;if((Y-da|0)<0){_=16;break b}ea=W&255;fa=a[E]|0;ga=fa&255;if(ea>>>0>ga>>>0){_=18;break b}if((ba|0)==(H|0)){$=W&255;aa=da}else{break}}if((V|0)<(ea|0)){aa=U;$=V;while(1){c[h+3172+(aa<<2)>>2]=Z;c[h+3684+(aa<<2)>>2]=ea;Y=$+1|0;if((Y|0)<(ea|0)){aa=aa+1|0;$=Y}else{break}}ha=U-V+ea|0;ia=ea;ja=a[E]|0}else{ha=U;ia=V;ja=fa}if((ia|0)<(ja&255|0)){U=ha;V=ia}else{break}}O=ha;P=ja;Q=c[w>>2]|0;T=ja}V=K+1|0;if((V|0)<(Q|0)){J=O;K=V;L=P;M=Q;N=T}else{_=24;break}}if((_|0)==14){KIb(c[f+4>>2]|0,16,2307440,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}else if((_|0)==16){KIb(c[f+4>>2]|0,16,2301536,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}else if((_|0)==18){KIb(c[f+4>>2]|0,16,2290496,(ka=i,i=i+16|0,c[ka>>2]=ea,c[ka+8>>2]=ga,ka)|0);i=ka;C=-1094995529;i=m;return C|0}else if((_|0)==24){N=h+4164|0;if((Q|0)<=0){la=N;break}M=f+4|0;L=0;K=0;J=0;H=B-90|0;F=B;G=1;V=T;U=T;c:while(1){d:do{if(V<<24>>24==0){ma=K;na=F;oa=H;pa=G;qa=J;ra=0;sa=U}else{I=0;$=K;aa=J;Z=H;Y=F;X=G;da=U;while(1){W=I;ba=$;ta=Z;ua=Y;va=X;wa=da;e:while(1){xa=W;ya=ba;za=ua;Aa=wa;f:while(1){Ba=xa;Ca=ya;Da=Aa;while(1){Ea=c[h+3684+(Ca<<2)>>2]|0;Fa=c[h+3172+(Ca<<2)>>2]|0;if((Fa|0)==13){break f}else if((Fa|0)==15|(Fa|0)==14){break e}else if((Fa|0)!=0){break}if((Ba|0)<(Ea|0)){mrc(h+4164+(Ca<<2)|0,0,Ea-Ba<<2|0)|0;Ga=Ea;Ha=Ca-Ba+Ea|0;Ia=a[E]|0}else{Ga=Ba;Ha=Ca;Ia=Da}if((Ga|0)<(Ia&255|0)){Ba=Ga;Ca=Ha;Da=Ia}else{ma=Ha;na=za;oa=ta;pa=va;qa=aa;ra=Ia;sa=Ia;break d}}if((Ba|0)<(Ea|0)){Fa=c[846875]|0;Ja=c[x>>2]|0;Ka=c[z>>2]|0;La=Ba;Ma=Ca;Na=za;Oa=c[v>>2]|0;do{Pa=Ka+(Oa>>>3)|0;Qa=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Oa&7)>>>25;Pa=b[Fa+(Qa<<2)>>1]|0;Ra=b[Fa+(Qa<<2)+2>>1]|0;Qa=Ra<<16>>16;do{if(Ra<<16>>16<0){Sa=Oa+7|0;Ta=Ja>>>0>Sa>>>0?Sa:Ja;Sa=Ka+(Ta>>>3)|0;Ua=((je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ta&7)>>>((Qa+32|0)>>>0))+Pa|0;Sa=b[Fa+(Ua<<2)>>1]|0;Va=b[Fa+(Ua<<2)+2>>1]|0;Ua=Va<<16>>16;if(!(Va<<16>>16<0)){Wa=Ua;Xa=Sa;Ya=Ta;break}Va=Ta-Qa|0;Ta=Ja>>>0>Va>>>0?Va:Ja;Va=Ka+(Ta>>>3)|0;Za=((je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Ta&7)>>>((Ua+32|0)>>>0))+Sa|0;Wa=b[Fa+(Za<<2)+2>>1]|0;Xa=b[Fa+(Za<<2)>>1]|0;Ya=Ta}else{Wa=Qa;Xa=Pa;Ya=Oa}}while(0);Pa=Wa+Ya|0;Oa=Ja>>>0>Pa>>>0?Pa:Ja;c[v>>2]=Oa;Na=Na-60+Xa|0;if(Na>>>0>255>>>0){break c}g[h+4164+(Ma<<2)>>2]=-0.0- +g[8815024+(Na+100<<2)>>2];La=La+1|0;Ma=Ma+1|0;}while((La|0)<(Ea|0));_a=La;$a=Ma;ab=Na;bb=a[E]|0}else{_a=Ba;$a=Ca;ab=za;bb=Da}if((_a|0)<(bb&255|0)){xa=_a;ya=$a;za=ab;Aa=bb}else{ma=$a;na=ab;oa=ta;pa=va;qa=aa;ra=bb;sa=bb;break d}}if((Ba|0)<(Ea|0)){Aa=Ba;ya=Ca;xa=ta;Oa=va;while(1){Ja=Oa-1|0;if((Oa|0)>0){Fa=c[v>>2]|0;Ka=c[x>>2]|0;Pa=(c[z>>2]|0)+(Fa>>>3)|0;Qa=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Fa&7)>>>23;Pa=Fa+9|0;c[v>>2]=Ka>>>0>Pa>>>0?Pa:Ka;cb=Qa-256|0}else{Qa=c[846875]|0;Ka=c[v>>2]|0;Pa=c[x>>2]|0;Fa=c[z>>2]|0;Ra=Fa+(Ka>>>3)|0;Ta=(je(d[Ra]|d[Ra+1|0]<<8|d[Ra+2|0]<<16|d[Ra+3|0]<<24|0)|0)<<(Ka&7)>>>25;Ra=b[Qa+(Ta<<2)>>1]|0;Za=b[Qa+(Ta<<2)+2>>1]|0;Ta=Za<<16>>16;do{if(Za<<16>>16<0){Sa=Ka+7|0;Ua=Pa>>>0>Sa>>>0?Sa:Pa;Sa=Fa+(Ua>>>3)|0;Va=((je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(Ua&7)>>>((Ta+32|0)>>>0))+Ra|0;Sa=b[Qa+(Va<<2)>>1]|0;db=b[Qa+(Va<<2)+2>>1]|0;Va=db<<16>>16;if(!(db<<16>>16<0)){eb=Va;fb=Sa;gb=Ua;break}db=Ua-Ta|0;Ua=Pa>>>0>db>>>0?db:Pa;db=Fa+(Ua>>>3)|0;hb=((je(d[db]|d[db+1|0]<<8|d[db+2|0]<<16|d[db+3|0]<<24|0)|0)<<(Ua&7)>>>((Va+32|0)>>>0))+Sa|0;eb=b[Qa+(hb<<2)+2>>1]|0;fb=b[Qa+(hb<<2)>>1]|0;gb=Ua}else{eb=Ta;fb=Ra;gb=Ka}}while(0);Ka=eb+gb|0;c[v>>2]=Pa>>>0>Ka>>>0?Ka:Pa;cb=fb-60|0}ib=cb+xa|0;if((ib|0)<-100){jb=-100}else{jb=(ib|0)>155?155:ib}if((ib|0)!=(jb|0)){QIb(c[M>>2]|0,2316480,(ka=i,i=i+16|0,c[ka>>2]=ib,c[ka+8>>2]=jb,ka)|0);i=ka}g[h+4164+(ya<<2)>>2]=-0.0- +g[8815024+(jb+200<<2)>>2];Ka=Aa+1|0;if((Ka|0)<(Ea|0)){Aa=Ka;ya=ya+1|0;xa=ib;Oa=Ja}else{break}}kb=Ea;lb=Ca-Ba+Ea|0;mb=ib;nb=Ba+va-Ea|0;ob=a[E]|0}else{kb=Ba;lb=Ca;mb=ta;nb=va;ob=Da}if((kb|0)<(ob&255|0)){W=kb;ba=lb;ta=mb;ua=za;va=nb;wa=ob}else{ma=lb;na=za;oa=mb;pa=nb;qa=aa;ra=ob;sa=ob;break d}}if((Ba|0)<(Ea|0)){wa=Ba;ua=Ca;ba=aa;while(1){W=c[846875]|0;Oa=c[v>>2]|0;xa=c[x>>2]|0;ya=c[z>>2]|0;Aa=ya+(Oa>>>3)|0;Ka=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Oa&7)>>>25;Aa=b[W+(Ka<<2)>>1]|0;Ra=b[W+(Ka<<2)+2>>1]|0;Ka=Ra<<16>>16;do{if(Ra<<16>>16<0){Ta=Oa+7|0;Qa=xa>>>0>Ta>>>0?Ta:xa;Ta=ya+(Qa>>>3)|0;Fa=((je(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Qa&7)>>>((Ka+32|0)>>>0))+Aa|0;Ta=b[W+(Fa<<2)>>1]|0;Za=b[W+(Fa<<2)+2>>1]|0;Fa=Za<<16>>16;if(!(Za<<16>>16<0)){pb=Fa;qb=Ta;rb=Qa;break}Za=Qa-Ka|0;Qa=xa>>>0>Za>>>0?Za:xa;Za=ya+(Qa>>>3)|0;Ma=((je(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(Qa&7)>>>((Fa+32|0)>>>0))+Ta|0;pb=b[W+(Ma<<2)+2>>1]|0;qb=b[W+(Ma<<2)>>1]|0;rb=Qa}else{pb=Ka;qb=Aa;rb=Oa}}while(0);Oa=pb+rb|0;c[v>>2]=xa>>>0>Oa>>>0?Oa:xa;sb=ba-60+qb|0;if((sb|0)<-155){tb=-155}else{tb=(sb|0)>100?100:sb}if((sb|0)!=(tb|0)){QIb(c[M>>2]|0,2321536,(ka=i,i=i+16|0,c[ka>>2]=sb,c[ka+8>>2]=tb,ka)|0);i=ka}g[h+4164+(ua<<2)>>2]=+g[8815024+(200-tb<<2)>>2];Oa=wa+1|0;if((Oa|0)>=(Ea|0)){break}wa=Oa;ua=ua+1|0;ba=sb}ub=Ea;vb=Ca-Ba+Ea|0;wb=sb;xb=a[E]|0}else{ub=Ba;vb=Ca;wb=aa;xb=Da}if((ub|0)<(xb&255|0)){I=ub;$=vb;aa=wb;Z=ta;Y=za;X=va;da=xb}else{ma=vb;na=za;oa=ta;pa=va;qa=wb;ra=xb;sa=xb;break}}}}while(0);da=L+1|0;if((da|0)<(c[w>>2]|0)){L=da;K=ma;J=qa;H=oa;F=na;G=pa;V=ra;U=sa}else{la=N;break a}}KIb(c[M>>2]|0,16,2312056,(ka=i,i=i+8|0,c[ka>>2]=Na,ka)|0);i=ka;C=-1094995529;i=m;return C|0}}else{la=h+4164|0}}while(0);Na=c[v>>2]|0;g:do{if(t){zb=0;Ab=Na}else{sa=c[z>>2]|0;ra=d[sa+(Na>>>3)|0]<<(Na&7)>>>7;pa=c[x>>2]|0;na=((Na|0)<(pa|0))+Na|0;c[v>>2]=na;oa=ra&1;if((oa|0)==0){zb=0;Ab=na;break}if((c[l>>2]|0)==2){KIb(c[f+4>>2]|0,16,2352512,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}ra=c[h+76>>2]|0;qa=c[h+84>>2]|0;ma=sa+(na>>>3)|0;xb=(je(d[ma]|d[ma+1|0]<<8|d[ma+2|0]<<16|d[ma+3|0]<<24|0)|0)<<(na&7)>>>30;ma=na+2|0;na=pa>>>0>ma>>>0?ma:pa;c[v>>2]=na;ma=xb+1|0;c[s>>2]=ma;xb=sa+(na>>>3)|0;wb=(je(d[xb]|d[xb+1|0]<<8|d[xb+2|0]<<16|d[xb+3|0]<<24|0)|0)<<(na&7)>>>26;xb=na+6|0;na=pa>>>0>xb>>>0?xb:pa;c[v>>2]=na;h:do{if((wb|0)<(qa|0)){xb=e[ra+(wb<<1)>>1]|0;za=sa+(na>>>3)|0;vb=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(na&7)>>>27;za=na+5|0;ub=pa>>>0>za>>>0?za:pa;c[v>>2]=ub;za=vb+xb|0;c[n+8>>2]=za;xb=e[ra+(qa<<1)>>1]|0;if((za|0)>=(xb|0)){break}vb=sa+(ub>>>3)|0;Da=(je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(ub&7)>>>28;vb=ub+4|0;ub=pa>>>0>vb>>>0?vb:pa;c[v>>2]=ub;c[n+24>>2]=Da;if(ma>>>0>1>>>0){Bb=1;Cb=ub;Db=za}else{zb=oa;Ab=ub;break g}while(1){ub=sa+(Cb>>>3)|0;za=(je(d[ub]|d[ub+1|0]<<8|d[ub+2|0]<<16|d[ub+3|0]<<24|0)|0)<<(Cb&7)>>>27;ub=Cb+5|0;Da=pa>>>0>ub>>>0?ub:pa;c[v>>2]=Da;ub=za+Db|0;c[n+8+(Bb<<2)>>2]=ub;if((ub|0)>=(xb|0)){break h}za=sa+(Da>>>3)|0;vb=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Da&7)>>>28;za=Da+4|0;Da=pa>>>0>za>>>0?za:pa;c[v>>2]=Da;c[n+24+(Bb<<2)>>2]=vb;vb=Bb+1|0;if((vb|0)<(c[s>>2]|0)){Bb=vb;Cb=Da;Db=ub}else{zb=oa;Ab=Da;break g}}}}while(0);KIb(c[f+4>>2]|0,16,2344448,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}}while(0);Db=d[(c[z>>2]|0)+(Ab>>>3)|0]<<(Ab&7)>>>7;c[v>>2]=((Ab|0)<(c[x>>2]|0))+Ab;Ab=Db&1;Db=o|0;c[Db>>2]=Ab;do{if(!((Ab|0)==0|u)){if((Ojb(f,o,j,p)|0)<0){C=-1094995529}else{break}i=m;return C|0}}while(0);do{if(!t){Ab=c[v>>2]|0;Cb=d[(c[z>>2]|0)+(Ab>>>3)|0]|0;c[v>>2]=((Ab|0)<(c[x>>2]|0))+Ab;if((Cb&128>>>((Ab&7)>>>0)|0)==0){break}QIb(c[f+4>>2]|0,2338456,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1163346256;i=m;return C|0}}while(0);do{if(!((c[Db>>2]|0)==0|u^1)){if((Ojb(f,o,j,p)|0)<0){C=-1094995529}else{break}i=m;return C|0}}while(0);p=h+88|0;j=c[p>>2]|0;o=1024/(j|0)|0;u=c[h+76>>2]|0;if((j|0)>0){j=h|0;Db=0;do{t=e[u+(d[j]<<1)>>1]|0;mrc(h+5312+(t+(Db<<7)<<2)|0,0,o-t<<2|0)|0;Db=Db+1|0;}while((Db|0)<(c[p>>2]|0))}p=c[w>>2]|0;i:do{if((p|0)>0){Db=h|0;o=f+5404|0;j=f+5428|0;t=f+5432|0;Ab=0;Cb=0;Bb=q;l=a[Db]|0;Na=p;j:while(1){oa=a[h+20+Cb|0]|0;pa=oa&255;if(l<<24>>24==0){Eb=Ab;Fb=0;Gb=Na}else{sa=oa<<24>>24==0;oa=Ab;ma=0;do{qa=(c[h+3172+(oa<<2)>>2]|0)-1|0;ra=e[u+(ma<<1)>>1]|0;na=Bb+(ra<<2)|0;ma=ma+1|0;wb=(e[u+(ma<<1)>>1]|0)-ra|0;k:do{if(qa>>>0>12>>>0){if(sa){break}ra=wb<<2;M=0;xb=na;while(1){mrc(xb|0,0,ra|0)|0;Da=M+1|0;if(Da>>>0<pa>>>0){M=Da;xb=xb+512|0}else{break}}}else{if((qa|0)==12){if(sa){break}xb=(wb|0)>0;M=la+(oa<<2)|0;ra=0;va=na;while(1){if(xb){ta=0;Da=c[t>>2]|0;do{Da=(ca(Da,1664525)|0)+1013904223|0;g[va+(ta<<2)>>2]=+(Da|0);ta=ta+1|0;}while((ta|0)<(wb|0));c[t>>2]=Da}Hb=+Ae[c[j>>2]&7](va,va,wb);Ib=+g[M>>2]/+S(Hb);xe[c[o>>2]&7](va,va,Ib,wb);ta=ra+1|0;if(ta>>>0<pa>>>0){ra=ta;va=va+512|0}else{break k}}}va=c[1454520+(qa<<2)>>2]|0;ra=c[1454568+(qa<<2)>>2]|0;M=c[3387276+(qa*20|0)>>2]|0;xb=c[v>>2]|0;ta=c[x>>2]|0;l:do{switch(qa>>>1|0){case 2:{if(sa){Jb=xb;break l}xa=la+(oa<<2)|0;ub=c[z>>2]|0;vb=xb;za=1;Ca=na;while(1){Ba=vb;sb=wb;Ea=Ca;while(1){tb=ub+(Ba>>>3)|0;qb=(je(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(Ba&7)>>>24;tb=b[M+(qb<<2)>>1]|0;rb=b[M+(qb<<2)+2>>1]|0;qb=rb<<16>>16;if(rb<<16>>16<0){rb=Ba+8|0;pb=ta>>>0>rb>>>0?rb:ta;rb=ub+(pb>>>3)|0;ob=((je(d[rb]|d[rb+1|0]<<8|d[rb+2|0]<<16|d[rb+3|0]<<24|0)|0)<<(pb&7)>>>((qb+32|0)>>>0))+tb|0;Kb=pb;Lb=b[M+(ob<<2)+2>>1]|0;Mb=b[M+(ob<<2)>>1]|0}else{Kb=Ba;Lb=qb;Mb=tb}tb=Kb+Lb|0;Nb=ta>>>0>tb>>>0?tb:ta;tb=e[ra+(Mb<<1)>>1]|0;Ib=+g[xa>>2];g[Ea>>2]=Ib*+g[va+((tb&15)<<2)>>2];g[Ea+4>>2]=Ib*+g[va+((tb>>>4&15)<<2)>>2];tb=sb-2|0;if((tb|0)==0){break}else{Ba=Nb;sb=tb;Ea=Ea+8|0}}if(!(za>>>0<pa>>>0)){Jb=Nb;break l}vb=Nb;za=za+1|0;Ca=Ca+512|0}break};case 3:case 4:{if(sa){Jb=xb;break l}Ca=la+(oa<<2)|0;za=c[z>>2]|0;vb=xb;xa=1;ub=na;while(1){Da=vb;Ea=wb;sb=ub;while(1){Ba=za+(Da>>>3)|0;Ja=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Da&7);Ba=Ja>>>24;Pa=b[M+(Ba<<2)>>1]|0;tb=b[M+(Ba<<2)+2>>1]|0;Ba=tb<<16>>16;if(tb<<16>>16<0){tb=Da+8|0;qb=ta>>>0>tb>>>0?tb:ta;tb=za+(qb>>>3)|0;ob=(je(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(qb&7);tb=(ob>>>((Ba+32|0)>>>0))+Pa|0;Ob=b[M+(tb<<2)+2>>1]|0;Pb=qb;Qb=ob;Rb=b[M+(tb<<2)>>1]|0}else{Ob=Ba;Pb=Da;Qb=Ja;Rb=Pa}Pa=Ob+Pb|0;Ja=e[ra+(Rb<<1)>>1]|0;Ba=Ja>>>8&15;if((Ba|0)==0){Sb=0}else{Sb=Qb<<Ob>>>((32-Ba|0)>>>0)<<(Ja>>>12)}tb=Ba+(ta>>>0>Pa>>>0?Pa:ta)|0;Tb=ta>>>0>tb>>>0?tb:ta;tb=(g[k>>2]=+g[Ca>>2],c[k>>2]|0);g[sb>>2]=+g[va+((Ja&15)<<2)>>2]*(c[k>>2]=tb^Sb>>>1<<31,+g[k>>2]);g[sb+4>>2]=+g[va+((Ja>>>4&15)<<2)>>2]*(c[k>>2]=tb^Sb<<31,+g[k>>2]);tb=Ea-2|0;if((tb|0)==0){break}else{Da=Tb;Ea=tb;sb=sb+8|0}}if(!(xa>>>0<pa>>>0)){Jb=Tb;break l}vb=Tb;xa=xa+1|0;ub=ub+512|0}break};case 1:{if(sa){Jb=xb;break l}ub=la+(oa<<2)|0;xa=c[z>>2]|0;vb=xb;Ca=1;za=na;while(1){sb=vb;Ea=za;Da=wb;while(1){tb=xa+(sb>>>3)|0;Ja=(je(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(sb&7);tb=Ja>>>24;Pa=b[M+(tb<<2)>>1]|0;Ba=b[M+(tb<<2)+2>>1]|0;tb=Ba<<16>>16;if(Ba<<16>>16<0){Ba=sb+8|0;ob=ta>>>0>Ba>>>0?Ba:ta;Ba=xa+(ob>>>3)|0;qb=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(ob&7);Ba=(qb>>>((tb+32|0)>>>0))+Pa|0;Ub=ob;Vb=qb;Wb=b[M+(Ba<<2)+2>>1]|0;Xb=b[M+(Ba<<2)>>1]|0}else{Ub=sb;Vb=Ja;Wb=tb;Xb=Pa}Pa=Ub+Wb|0;tb=e[ra+(Xb<<1)>>1]|0;Ja=tb>>>8&15;Ba=(Ja|0)!=0?Vb<<Wb:0;qb=Ja+(ta>>>0>Pa>>>0?Pa:ta)|0;Yb=ta>>>0>qb>>>0?qb:ta;qb=(g[k>>2]=+g[ub>>2],c[k>>2]|0);g[Ea>>2]=+g[va+((tb&3)<<2)>>2]*(c[k>>2]=Ba&-2147483648^qb,+g[k>>2]);Pa=Ba<<(tb>>>12&1);g[Ea+4>>2]=+g[va+((tb>>>2&3)<<2)>>2]*(c[k>>2]=Pa&-2147483648^qb,+g[k>>2]);Ba=Pa<<(tb>>>13&1);g[Ea+8>>2]=+g[va+((tb>>>4&3)<<2)>>2]*(c[k>>2]=Ba&-2147483648^qb,+g[k>>2]);g[Ea+12>>2]=+g[va+((tb>>>6&3)<<2)>>2]*(c[k>>2]=Ba<<(tb>>>14&1)&-2147483648^qb,+g[k>>2]);qb=Da-4|0;if((qb|0)==0){break}else{sb=Yb;Ea=Ea+16|0;Da=qb}}if(!(Ca>>>0<pa>>>0)){Jb=Yb;break l}vb=Yb;Ca=Ca+1|0;za=za+512|0}break};case 0:{if(sa){Jb=xb;break l}za=la+(oa<<2)|0;Ca=c[z>>2]|0;vb=xb;ub=1;xa=na;while(1){Da=vb;Ea=xa;sb=wb;while(1){qb=Ca+(Da>>>3)|0;tb=(je(d[qb]|d[qb+1|0]<<8|d[qb+2|0]<<16|d[qb+3|0]<<24|0)|0)<<(Da&7)>>>24;qb=b[M+(tb<<2)>>1]|0;Ba=b[M+(tb<<2)+2>>1]|0;tb=Ba<<16>>16;if(Ba<<16>>16<0){Ba=Da+8|0;Pa=ta>>>0>Ba>>>0?Ba:ta;Ba=Ca+(Pa>>>3)|0;Ja=((je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Pa&7)>>>((tb+32|0)>>>0))+qb|0;Zb=Pa;_b=b[M+(Ja<<2)>>1]|0;$b=b[M+(Ja<<2)+2>>1]|0}else{Zb=Da;_b=qb;$b=tb}tb=Zb+$b|0;ac=ta>>>0>tb>>>0?tb:ta;tb=e[ra+(_b<<1)>>1]|0;Ib=+g[za>>2];g[Ea>>2]=Ib*+g[va+((tb&3)<<2)>>2];g[Ea+4>>2]=Ib*+g[va+((tb>>>2&3)<<2)>>2];g[Ea+8>>2]=Ib*+g[va+((tb>>>4&3)<<2)>>2];g[Ea+12>>2]=Ib*+g[va+((tb>>>6&3)<<2)>>2];tb=sb-4|0;if((tb|0)==0){break}else{Da=ac;Ea=Ea+16|0;sb=tb}}if(!(ub>>>0<pa>>>0)){Jb=ac;break l}vb=ac;ub=ub+1|0;xa=xa+512|0}break};default:{if(sa){Jb=xb;break l}xa=la+(oa<<2)|0;ub=xb;vb=1;za=na;while(1){Ca=c[z>>2]|0;sb=wb;Ea=za;Da=ub;while(1){tb=Ca+(Da>>>3)|0;qb=(je(d[tb]|d[tb+1|0]<<8|d[tb+2|0]<<16|d[tb+3|0]<<24|0)|0)<<(Da&7);tb=qb>>>24;Ja=b[M+(tb<<2)>>1]|0;Pa=b[M+(tb<<2)+2>>1]|0;tb=Pa<<16>>16;if(Pa<<16>>16<0){Pa=Da+8|0;Ba=ta>>>0>Pa>>>0?Pa:ta;Pa=Ca+(Ba>>>3)|0;ob=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Ba&7);Pa=(ob>>>((tb+32|0)>>>0))+Ja|0;bc=b[M+(Pa<<2)+2>>1]|0;cc=b[M+(Pa<<2)>>1]|0;dc=Ba;ec=ob}else{bc=tb;cc=Ja;dc=Da;ec=qb}qb=bc+dc|0;Ja=ta>>>0>qb>>>0?qb:ta;if((cc|0)==0){c[Ea>>2]=0;c[Ea+4>>2]=0;fc=Ja}else{qb=e[ra+(cc<<1)>>1]|0;tb=qb>>>12;ob=qb>>>8;Ba=32-tb|0;Pa=ec<<bc>>>(Ba>>>0)<<Ba;Ba=tb+Ja|0;Ja=ta>>>0>Ba>>>0?Ba:ta;if((ob&1|0)==0){Ba=c[va+((qb&15)<<2)>>2]|0;c[Ea>>2]=Ba|Pa&-2147483648;gc=Pa<<((Ba|0)!=0);hc=Ja}else{Ba=Ca+(Ja>>>3)|0;tb=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(Ja&7);Ba=~tb;pb=tb>>>0<4294901760>>>0;rb=pb?Ba>>>16:Ba;Ba=pb?16:0;if((rb&65280|0)==0){ic=Ba;jc=rb}else{ic=Ba|8;jc=rb>>>8}rb=31-ic-(d[1359664+jc|0]|0)|0;if(rb>>>0>8>>>0){break j}Ba=rb+1|0;pb=Ba+Ja|0;Ja=rb+4|0;nb=(ta>>>0>pb>>>0?pb:ta)+Ja|0;c[Ea>>2]=c[9835392+((tb<<Ba>>>((28-rb|0)>>>0))+(1<<Ja)<<2)>>2]|Pa&-2147483648;gc=Pa<<1;hc=ta>>>0>nb>>>0?nb:ta}nb=Ea+4|0;if((ob&2|0)==0){kc=hc;lc=c[va+((qb>>>4&15)<<2)>>2]|gc&-2147483648}else{qb=Ca+(hc>>>3)|0;ob=(je(d[qb]|d[qb+1|0]<<8|d[qb+2|0]<<16|d[qb+3|0]<<24|0)|0)<<(hc&7);qb=~ob;Pa=ob>>>0<4294901760>>>0;Ja=Pa?qb>>>16:qb;qb=Pa?16:0;if((Ja&65280|0)==0){mc=qb;nc=Ja}else{mc=qb|8;nc=Ja>>>8}Ja=31-mc-(d[1359664+nc|0]|0)|0;if(Ja>>>0>8>>>0){break j}qb=Ja+1|0;Pa=qb+hc|0;rb=Ja+4|0;Ba=(ta>>>0>Pa>>>0?Pa:ta)+rb|0;kc=ta>>>0>Ba>>>0?Ba:ta;lc=c[9835392+((ob<<qb>>>((28-Ja|0)>>>0))+(1<<rb)<<2)>>2]|gc&-2147483648}c[nb>>2]=lc;fc=kc}nb=sb-2|0;if((nb|0)==0){break}else{sb=nb;Ea=Ea+8|0;Da=fc}}xe[c[o>>2]&7](za,za,+g[xa>>2],wb);if(!(vb>>>0<pa>>>0)){Jb=fc;break l}ub=fc;vb=vb+1|0;za=za+512|0}}}}while(0);c[v>>2]=Jb}}while(0);oa=oa+1|0;oc=a[Db]|0;}while((ma|0)<(oc&255|0));Eb=oa;Fb=oc;Gb=c[w>>2]|0}ma=Cb+1|0;if((ma|0)<(Gb|0)){Ab=Eb;Cb=ma;Bb=Bb+(pa<<7<<2)|0;l=Fb;Na=Gb}else{break i}}KIb(c[f+4>>2]|0,16,2332784,(ka=i,i=i+1|0,i=i+7&-8,c[ka>>2]=0,ka)|0);i=ka;C=-1094995529;i=m;return C|0}}while(0);do{if((zb|0)!=0){ka=c[s>>2]|0;if((ka|0)>0){pc=0;qc=0}else{break}while(1){Gb=c[n+8+(qc<<2)>>2]|0;Fb=h+5312+(Gb<<2)|0;Ib=+g[Fb>>2];Eb=pc;while(1){w=Eb+1|0;if((e[u+(w<<1)>>1]|0)>(Gb|0)){break}else{Eb=w}}do{if((c[h+3172+(Eb<<2)>>2]|0)!=13){Gb=la+(Eb<<2)|0;Hb=+g[Gb>>2];if(!(Hb!=0.0)){break}rc=+(-(c[n+24+(qc<<2)>>2]|0)|0);if(Ib!=0.0){sc=Ib/Hb;Hb=sc/+S(+S(+R(+sc)));if(sc>0.0){tc=-0.0-rc}else{tc=rc}uc=Hb+tc}else{uc=rc}rc=uc*+yb(+(+R(+uc)));g[Fb>>2]=rc*+g[Gb>>2]}}while(0);Fb=qc+1|0;if((Fb|0)<(ka|0)){pc=Eb;qc=Fb}else{break}}}}while(0);if((c[r>>2]|0)!=1|y){C=0;i=m;return C|0}Njb(f,h);C=0;i=m;return C|0}function Fjb(f,h,j){f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0.0,aa=0;k=i;l=f+6504|0;if((c[l>>2]|0)==39){m=1;n=3}else{o=h+8|0;p=c[o>>2]|0;q=d[(c[h>>2]|0)+(p>>>3)|0]<<(p&7);c[o>>2]=((p|0)<(c[h+16>>2]|0))+p;p=q&128;q=p>>>7;if((p|0)==0){r=0;s=0;t=q}else{m=q;n=3}}a:do{if((n|0)==3){q=j+160|0;if((Mjb(f,q,h)|0)!=0){u=-1094995529;i=k;return u|0}p=a[j+52364|0]|0;o=j+52352|0;nrc(o|0,q|0,152)|0;a[j+52365|0]=p;b:do{if((c[j+52448>>2]|0)!=0){if((c[l>>2]|0)==1){break}p=h+8|0;q=c[p>>2]|0;v=h+16|0;w=c[v>>2]|0;x=h|0;y=(c[x>>2]|0)+(q>>>3)|0;z=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(q&7)>>>31;y=q+1|0;c[p>>2]=w>>>0>y>>>0?y:w;w=z&255;a[j+52380|0]=w;if(w<<24>>24==0){break}w=a[o]|0;z=c[p>>2]|0;y=c[v>>2]|0;q=c[x>>2]|0;A=q+(z>>>3)|0;B=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(z&7)>>>21;A=z+11|0;z=y>>>0>A>>>0?A:y;c[p>>2]=z;b[j+52382>>1]=B;B=q+(z>>>3)|0;A=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(z&7)>>>29;B=z+3|0;z=y>>>0>B>>>0?B:y;c[p>>2]=z;g[j+52384>>2]=+g[841888+(A<<2)>>2];A=(w&255)>>>0>40>>>0?40:w&255;if((A|0)==0){break}else{C=0;D=z;E=q;F=y}while(1){y=d[E+(D>>>3)|0]<<(D&7)>>>7;c[p>>2]=((D|0)<(F|0))+D;a[j+52388+C|0]=y&1;y=C+1|0;if((y|0)>=(A|0)){break b}C=y;D=c[p>>2]|0;E=c[x>>2]|0;F=c[v>>2]|0}}}while(0);o=h+8|0;v=c[o>>2]|0;x=h+16|0;p=c[x>>2]|0;A=h|0;y=c[A>>2]|0;q=y+(v>>>3)|0;z=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(v&7)>>>30;q=v+2|0;v=p>>>0>q>>>0?q:p;c[o>>2]=v;if((z|0)==3){KIb(c[f+4>>2]|0,16,2409416,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;u=-1094995529;i=k;return u|0}else if((z|0)==0){r=0;s=1;t=m;break}if((z|0)==2){mrc(j+8|0,1,ca(d[j+160|0]|0,c[j+176>>2]|0)|0)|0;r=2;s=1;t=m;break}else if((z|0)!=1){r=z;s=1;t=m;break}z=j+176|0;q=j+160|0;if((ca(d[q]|0,c[z>>2]|0)|0)>0){G=0;H=v;I=y;J=p}else{r=1;s=1;t=m;break}while(1){p=d[I+(H>>>3)|0]<<(H&7)>>>7;c[o>>2]=((H|0)<(J|0))+H;a[j+8+G|0]=p&1;p=G+1|0;if((p|0)>=(ca(d[q]|0,c[z>>2]|0)|0)){r=1;s=1;t=m;break a}G=p;H=c[o>>2]|0;I=c[A>>2]|0;J=c[x>>2]|0}}}while(0);J=j+160|0;I=Ejb(f,J,h,t)|0;if((I|0)!=0){u=I;i=k;return u|0}I=j+52352|0;H=Ejb(f,I,h,t)|0;if((H|0)!=0){u=H;i=k;return u|0}do{if(s){do{if((r|0)!=0){H=c[j+236>>2]|0;t=j+176|0;h=c[t>>2]|0;if((h|0)<=0){break}G=j+160|0;m=f+5424|0;F=a[G]|0;E=j+57664|0;D=0;C=0;n=j+5472|0;x=F;A=h;h=F;while(1){F=j+180+D|0;if(x<<24>>24==0){K=C;L=0;M=A;N=h}else{o=0;z=C;q=h;while(1){do{if((a[j+8+z|0]|0)==0){O=q}else{if(!((c[j+3332+(z<<2)>>2]|0)>>>0<13>>>0)){O=q;break}if(!((c[j+55524+(z<<2)>>2]|0)>>>0<13>>>0)){O=q;break}if((a[F]|0)==0){O=q;break}p=H+(o<<1)|0;y=H+(o+1<<1)|0;v=0;do{w=e[p>>1]|0;B=w+(v<<7)|0;ef[c[m>>2]&4095](n+(B<<2)|0,E+(B<<2)|0,(e[y>>1]|0)-w|0);v=v+1|0;}while((v|0)<(d[F]|0));O=a[G]|0}}while(0);v=o+1|0;P=z+1|0;if((v|0)<(O&255|0)){o=v;z=P;q=O}else{break}}K=P;L=O;M=c[t>>2]|0;N=O}q=d[F]<<7;z=D+1|0;if((z|0)<(M|0)){E=E+(q<<2)|0;D=z;C=K;n=n+(q<<2)|0;x=L;A=M;h=N}else{break}}}}while(0);if((c[l>>2]|0)!=1){break}Njb(f,J);Njb(f,I)}}while(0);I=c[j+52428>>2]|0;J=j+52368|0;l=c[J>>2]|0;if((l|0)<=0){u=0;i=k;return u|0}N=j+52352|0;M=(r|0)==0;r=f+5404|0;f=a[N]|0;L=0;K=0;O=j+57664|0;P=j+5472|0;s=f;h=l;l=f;while(1){f=j+52372+K|0;if(s<<24>>24==0){Q=L;R=0;S=h;T=l}else{A=0;x=L;n=l;while(1){C=c[j+55524+(x<<2)>>2]|0;D=c[j+56036+(x<<2)>>2]|0;do{if((C-14|0)>>>0<2>>>0){if((A|0)<(D|0)){U=A;V=x;W=C}else{X=x;Y=A;Z=n;break}while(1){E=(W<<1)-29|0;if(M){_=E}else{_=ca(1-(d[j+8+V|0]<<1)|0,E)|0}$=+(_|0)*+g[j+56516+(V<<2)>>2];if((a[f]|0)==0){aa=U+1|0}else{E=I+(U<<1)|0;t=U+1|0;G=I+(t<<1)|0;m=0;while(1){H=e[E>>1]|0;q=H+(m<<7)|0;xe[c[r>>2]&7](O+(q<<2)|0,P+(q<<2)|0,$,(e[G>>1]|0)-H|0);H=m+1|0;if((H|0)<(d[f]|0)){m=H}else{aa=t;break}}}t=V+1|0;if((aa|0)>=(D|0)){break}U=aa;V=t;W=c[j+55524+(t<<2)>>2]|0}X=x-A+D|0;Y=D;Z=a[N]|0}else{X=x-A+D|0;Y=D;Z=n}}while(0);if((Y|0)<(Z&255|0)){A=Y;x=X;n=Z}else{break}}Q=X;R=Z;S=c[J>>2]|0;T=Z}n=d[f]<<7;x=K+1|0;if((x|0)<(S|0)){L=Q;K=x;O=O+(n<<2)|0;P=P+(n<<2)|0;s=R;h=S;l=T}else{u=0;break}}i=k;return u|0}function Gjb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;j=g+8|0;k=g+16|0;l=c[k>>2]|0;m=(c[j>>2]|0)+2|0;n=l>>>0>m>>>0?m:l;c[j>>2]=n;m=g|0;o=c[m>>2]|0;p=o+(n>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(n&7)>>>28;p=n+4|0;n=l>>>0>p>>>0?p:l;c[j>>2]=n;if((c[e+4>>2]|0)==(q|0)){r=n;s=l;t=o}else{KIb(b,24,2475912,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;r=c[j>>2]|0;s=c[k>>2]|0;t=c[m>>2]|0}o=t+(r>>>3)|0;l=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>28;o=r+4|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;n=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>28;o=r+4|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;q=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>28;o=r+4|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;e=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>30;o=r+2|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>29;o=r+3|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=t+(r>>>3)|0;v=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(r&7)>>>28;o=r+4|0;r=s>>>0>o>>>0?o:s;c[j>>2]=r;o=((r|0)<(s|0))+r|0;if(((d[t+(r>>>3)|0]|0)&128>>>((r&7)>>>0)|0)==0){w=o}else{r=o+4|0;w=s>>>0>r>>>0?r:s}c[j>>2]=w;r=((w|0)<(s|0))+w|0;if(((d[t+(w>>>3)|0]|0)&128>>>((w&7)>>>0)|0)==0){x=r}else{w=r+4|0;x=s>>>0>w>>>0?w:s}c[j>>2]=x;w=((x|0)<(s|0))+x|0;if(((d[t+(x>>>3)|0]|0)&128>>>((x&7)>>>0)|0)==0){y=w}else{x=w+3|0;y=s>>>0>x>>>0?x:s}c[j>>2]=y;x=g+12|0;g=n+l|0;w=q+g|0;r=e+w|0;if(((c[x>>2]|0)-y|0)<(p+r+v<<2|0)){KIb(b,16,2466744,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;z=-1;i=h;return z|0}a:do{if((l|0)!=0){o=f;A=l;B=y;C=t;D=s;while(1){E=A-1|0;F=(d[C+(B>>>3)|0]|0)<<(B&7)>>>7;c[j>>2]=((B|0)<(D|0))+B;a[o|0]=F&1;F=c[j>>2]|0;G=c[k>>2]|0;H=(c[m>>2]|0)+(F>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(F&7)>>>28;H=F+4|0;c[j>>2]=G>>>0>H>>>0?H:G;a[o+1|0]=I;a[o+2|0]=1;if((E|0)==0){break a}o=o+3|0;A=E;B=c[j>>2]|0;C=c[m>>2]|0;D=c[k>>2]|0}}}while(0);b:do{if((n|0)!=0){s=f+(l*3|0)|0;t=n;while(1){y=t-1|0;D=c[j>>2]|0;C=(d[(c[m>>2]|0)+(D>>>3)|0]|0)<<(D&7)>>>7;c[j>>2]=((D|0)<(c[k>>2]|0))+D;a[s|0]=C&1;C=c[j>>2]|0;D=c[k>>2]|0;B=(c[m>>2]|0)+(C>>>3)|0;A=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(C&7)>>>28;B=C+4|0;c[j>>2]=D>>>0>B>>>0?B:D;a[s+1|0]=A;a[s+2|0]=2;if((y|0)==0){break b}s=s+3|0;t=y}}}while(0);c:do{if((q|0)!=0){n=f+(g*3|0)|0;l=q;while(1){t=l-1|0;s=c[j>>2]|0;y=(d[(c[m>>2]|0)+(s>>>3)|0]|0)<<(s&7)>>>7;c[j>>2]=((s|0)<(c[k>>2]|0))+s;a[n|0]=y&1;y=c[j>>2]|0;s=c[k>>2]|0;A=(c[m>>2]|0)+(y>>>3)|0;D=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(y&7)>>>28;A=y+4|0;c[j>>2]=s>>>0>A>>>0?A:s;a[n+1|0]=D;a[n+2|0]=3;if((t|0)==0){break c}n=n+3|0;l=t}}}while(0);if((e|0)!=0){q=f+(w*3|0)|0;w=e;while(1){e=w-1|0;a[q|0]=3;g=c[j>>2]|0;l=c[k>>2]|0;n=(c[m>>2]|0)+(g>>>3)|0;t=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(g&7)>>>28;n=g+4|0;c[j>>2]=l>>>0>n>>>0?n:l;a[q+1|0]=t;a[q+2|0]=4;if((e|0)==0){break}else{q=q+3|0;w=e}}}w=p<<2;p=c[j>>2]|0;q=-p|0;e=c[k>>2]|0;t=e-p|0;if((w|0)<(q|0)){J=q}else{J=(t|0)<(w|0)?t:w}w=J+p|0;c[j>>2]=w;if((v|0)==0){K=w}else{p=f+(r*3|0)|0;f=v;J=w;w=e;while(1){e=f-1|0;t=J+1|0;c[j>>2]=w>>>0>t>>>0?t:w;a[p|0]=2;t=c[j>>2]|0;q=c[k>>2]|0;l=(c[m>>2]|0)+(t>>>3)|0;n=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(t&7)>>>28;l=t+4|0;c[j>>2]=q>>>0>l>>>0?l:q;a[p+1|0]=n;a[p+2|0]=5;if((e|0)==0){break}p=p+3|0;f=e;J=c[j>>2]|0;w=c[k>>2]|0}K=c[j>>2]|0}w=-K&7;J=c[k>>2]|0;if((w|0)==0){L=K}else{k=w+K|0;K=J>>>0>k>>>0?k:J;c[j>>2]=K;L=K}K=(c[m>>2]|0)+(L>>>3)|0;m=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(L&7)>>>24;K=L+8|0;L=J>>>0>K>>>0?K:J;c[j>>2]=L;K=m<<3;if(((c[x>>2]|0)-L|0)<(K|0)){KIb(b,16,2466744,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;z=-1094995529;i=h;return z|0}u=-L|0;b=J-L|0;if((K|0)<(u|0)){M=u}else{M=(b|0)<(K|0)?b:K}c[j>>2]=M+L;z=v+r|0;i=h;return z|0}function Hjb(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0;j=i;i=i+1096|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=b+4|0;p=c[o>>2]|0;q=b+6548|0;if((q|0)!=(e|0)){nrc(q|0,e|0,f*3|0)|0;c[b+6740>>2]=f}q=p+456|0;a:do{if((c[q>>2]|0)==0&(c[q+4>>2]|0)==(-2147483648|0)){r=0;s=0}else{t=n;u=j+1048|0;v=j+1056|0;w=j+1064|0;x=j+1072|0;y=j+1080|0;mrc(t|0,0,1024)|0;if(f>>>0>64>>>0){r=0;s=0;break}if((f|0)>0){z=0;A=0;B=0;C=0;while(1){if((a[e+(C*3|0)+2|0]|0)!=1){D=z;E=A;F=B;G=C;break}if((a[e+(C*3|0)|0]|0)==1){if(!((B|0)==0|(A|0)==0)){r=0;s=0;break a}H=0;I=1;J=z+2|0}else{H=B^1;I=A;J=z+1|0}K=C+1|0;if((K|0)<(f|0)){z=J;A=I;B=H;C=K}else{D=J;E=I;F=H;G=K;break}}if((F|0)!=0&(E|0)!=0|(D|0)<0){r=0;s=0;break}else{L=D;M=G}}else{L=0;M=0}if((M|0)<(f|0)){C=0;B=0;A=M;while(1){if((a[e+(A*3|0)+2|0]|0)!=2){N=C;O=B;P=A;break}if((a[e+(A*3|0)|0]|0)==1){if((B|0)!=0){r=0;s=0;break a}Q=0;R=C+2|0}else{Q=B^1;R=C+1|0}z=A+1|0;if((z|0)<(f|0)){C=R;B=Q;A=z}else{N=R;O=Q;P=z;break}}if((O|0)!=0|(N|0)<0){r=0;s=0;break}else{S=N;T=P}}else{S=0;T=M}if((T|0)<(f|0)){A=0;B=0;C=T;while(1){if((a[e+(C*3|0)+2|0]|0)!=3){U=A;break}if((a[e+(C*3|0)|0]|0)==1){if((B|0)!=0){r=0;s=0;break a}V=0;W=A+2|0}else{V=B^1;W=A+1|0}z=C+1|0;if((z|0)<(f|0)){A=W;B=V;C=z}else{U=W;break}}if((U|0)<0){r=0;s=0;break}else{X=U}}else{X=0}if((L&1|0)==0){Y=L;Z=0}else{C=a[e+1|0]|0;B=n|0;c[B>>2]=4;c[B+4>>2]=0;a[n+8|0]=0;a[n+9|0]=C;a[n+10|0]=1;C=t+11|0;a[C]=a[u]|0;a[C+1|0]=a[u+1|0]|0;a[C+2|0]=a[u+2|0]|0;a[C+3|0]=a[u+3|0]|0;a[C+4|0]=a[u+4|0]|0;Y=L-1|0;Z=1}if((Y|0)>3){C=k|0;B=l|0;A=m|0;z=n+(Z<<4)|0;K=a[e+(Z*3|0)+1|0]|0;_=z|0;if((a[e+(Z*3|0)|0]|0)==1){c[_>>2]=192;c[_+4>>2]=0;a[n+(Z<<4)+8|0]=1;a[n+(Z<<4)+9|0]=K;a[n+(Z<<4)+10|0]=1;$=z+11|0;a[$]=a[C]|0;a[$+1|0]=a[C+1|0]|0;a[$+2|0]=a[C+2|0]|0;a[$+3|0]=a[C+3|0]|0;a[$+4|0]=a[C+4|0]|0;aa=1}else{c[_>>2]=64;c[_+4>>2]=0;a[n+(Z<<4)+8|0]=0;a[n+(Z<<4)+9|0]=K;a[n+(Z<<4)+10|0]=1;K=z+11|0;a[K]=a[B]|0;a[K+1|0]=a[B+1|0]|0;a[K+2|0]=a[B+2|0]|0;a[K+3|0]=a[B+3|0]|0;a[K+4|0]=a[B+4|0]|0;B=Z+1|0;K=n+(B<<4)|0;z=a[e+(B*3|0)+1|0]|0;_=K|0;c[_>>2]=128;c[_+4>>2]=0;a[n+(B<<4)+8|0]=0;a[n+(B<<4)+9|0]=z;a[n+(B<<4)+10|0]=1;B=K+11|0;a[B]=a[A]|0;a[B+1|0]=a[A+1|0]|0;a[B+2|0]=a[A+2|0]|0;a[B+3|0]=a[A+3|0]|0;a[B+4|0]=a[A+4|0]|0;aa=2}ba=Y-2|0;ca=aa+Z|0}else{ba=Y;ca=Z}do{if((ba|0)>1){A=k|0;B=l|0;K=m|0;z=n+(ca<<4)|0;_=a[e+(ca*3|0)+1|0]|0;C=z|0;if((a[e+(ca*3|0)|0]|0)==1){c[C>>2]=3;c[C+4>>2]=0;a[n+(ca<<4)+8|0]=1;a[n+(ca<<4)+9|0]=_;a[n+(ca<<4)+10|0]=1;$=z+11|0;a[$]=a[A]|0;a[$+1|0]=a[A+1|0]|0;a[$+2|0]=a[A+2|0]|0;a[$+3|0]=a[A+3|0]|0;a[$+4|0]=a[A+4|0]|0;da=1}else{c[C>>2]=1;c[C+4>>2]=0;a[n+(ca<<4)+8|0]=0;a[n+(ca<<4)+9|0]=_;a[n+(ca<<4)+10|0]=1;_=z+11|0;a[_]=a[B]|0;a[_+1|0]=a[B+1|0]|0;a[_+2|0]=a[B+2|0]|0;a[_+3|0]=a[B+3|0]|0;a[_+4|0]=a[B+4|0]|0;_=ca+1|0;z=n+(_<<4)|0;C=a[e+(_*3|0)+1|0]|0;$=z|0;c[$>>2]=2;c[$+4>>2]=0;a[n+(_<<4)+8|0]=0;a[n+(_<<4)+9|0]=C;a[n+(_<<4)+10|0]=1;_=z+11|0;a[_]=a[K]|0;a[_+1|0]=a[K+1|0]|0;a[_+2|0]=a[K+2|0]|0;a[_+3|0]=a[K+3|0]|0;a[_+4|0]=a[K+4|0]|0;da=2}_=da+ca|0;z=ba-2|0;if((z|0)>1){ea=_;fa=z}else{ga=_;break}while(1){_=(a[e+(ea*3|0)|0]|0)==1;z=n+(ea<<4)|0;C=a[e+(ea*3|0)+1|0]|0;$=z|0;c[$>>2]=-1;c[$+4>>2]=-1;$=n+(ea<<4)+8|0;if(_){a[$]=1;a[n+(ea<<4)+9|0]=C;a[n+(ea<<4)+10|0]=1;_=z+11|0;a[_]=a[A]|0;a[_+1|0]=a[A+1|0]|0;a[_+2|0]=a[A+2|0]|0;a[_+3|0]=a[A+3|0]|0;a[_+4|0]=a[A+4|0]|0;ha=1}else{a[$]=0;a[n+(ea<<4)+9|0]=C;a[n+(ea<<4)+10|0]=1;C=z+11|0;a[C]=a[B]|0;a[C+1|0]=a[B+1|0]|0;a[C+2|0]=a[B+2|0]|0;a[C+3|0]=a[B+3|0]|0;a[C+4|0]=a[B+4|0]|0;C=ea+1|0;z=n+(C<<4)|0;$=a[e+(C*3|0)+1|0]|0;_=z|0;c[_>>2]=-1;c[_+4>>2]=-1;a[n+(C<<4)+8|0]=0;a[n+(C<<4)+9|0]=$;a[n+(C<<4)+10|0]=1;C=z+11|0;a[C]=a[K]|0;a[C+1|0]=a[K+1|0]|0;a[C+2|0]=a[K+2|0]|0;a[C+3|0]=a[K+3|0]|0;a[C+4|0]=a[K+4|0]|0;ha=2}C=ha+ea|0;z=fa-2|0;if((z|0)>1){ea=C;fa=z}else{ga=C;break}}}else{ga=ca}}while(0);do{if((S|0)>1){u=k|0;t=l|0;K=m|0;B=n+(ga<<4)|0;A=a[e+(ga*3|0)+1|0]|0;C=B|0;if((a[e+(ga*3|0)|0]|0)==1){c[C>>2]=1536;c[C+4>>2]=0;a[n+(ga<<4)+8|0]=1;a[n+(ga<<4)+9|0]=A;a[n+(ga<<4)+10|0]=1;z=B+11|0;a[z]=a[u]|0;a[z+1|0]=a[u+1|0]|0;a[z+2|0]=a[u+2|0]|0;a[z+3|0]=a[u+3|0]|0;a[z+4|0]=a[u+4|0]|0;ia=1}else{c[C>>2]=512;c[C+4>>2]=0;a[n+(ga<<4)+8|0]=0;a[n+(ga<<4)+9|0]=A;a[n+(ga<<4)+10|0]=1;A=B+11|0;a[A]=a[t]|0;a[A+1|0]=a[t+1|0]|0;a[A+2|0]=a[t+2|0]|0;a[A+3|0]=a[t+3|0]|0;a[A+4|0]=a[t+4|0]|0;A=ga+1|0;B=n+(A<<4)|0;C=a[e+(A*3|0)+1|0]|0;z=B|0;c[z>>2]=1024;c[z+4>>2]=0;a[n+(A<<4)+8|0]=0;a[n+(A<<4)+9|0]=C;a[n+(A<<4)+10|0]=1;A=B+11|0;a[A]=a[K]|0;a[A+1|0]=a[K+1|0]|0;a[A+2|0]=a[K+2|0]|0;a[A+3|0]=a[K+3|0]|0;a[A+4|0]=a[K+4|0]|0;ia=2}A=ia+ga|0;B=S-2|0;if((B|0)>1){ja=A;ka=B}else{la=A;break}while(1){A=(a[e+(ja*3|0)|0]|0)==1;B=n+(ja<<4)|0;C=a[e+(ja*3|0)+1|0]|0;z=B|0;c[z>>2]=-1;c[z+4>>2]=-1;z=n+(ja<<4)+8|0;if(A){a[z]=1;a[n+(ja<<4)+9|0]=C;a[n+(ja<<4)+10|0]=2;A=B+11|0;a[A]=a[u]|0;a[A+1|0]=a[u+1|0]|0;a[A+2|0]=a[u+2|0]|0;a[A+3|0]=a[u+3|0]|0;a[A+4|0]=a[u+4|0]|0;ma=1}else{a[z]=0;a[n+(ja<<4)+9|0]=C;a[n+(ja<<4)+10|0]=2;C=B+11|0;a[C]=a[t]|0;a[C+1|0]=a[t+1|0]|0;a[C+2|0]=a[t+2|0]|0;a[C+3|0]=a[t+3|0]|0;a[C+4|0]=a[t+4|0]|0;C=ja+1|0;B=n+(C<<4)|0;z=a[e+(C*3|0)+1|0]|0;A=B|0;c[A>>2]=-1;c[A+4>>2]=-1;a[n+(C<<4)+8|0]=0;a[n+(C<<4)+9|0]=z;a[n+(C<<4)+10|0]=2;C=B+11|0;a[C]=a[K]|0;a[C+1|0]=a[K+1|0]|0;a[C+2|0]=a[K+2|0]|0;a[C+3|0]=a[K+3|0]|0;a[C+4|0]=a[K+4|0]|0;ma=2}C=ma+ja|0;B=ka-2|0;if((B|0)>1){ja=C;ka=B}else{la=C;break}}}else{la=ga}}while(0);if((X|0)>3){K=k|0;t=l|0;u=m|0;C=X-4|0;B=la;z=X;do{A=(a[e+(B*3|0)|0]|0)==1;$=n+(B<<4)|0;_=a[e+(B*3|0)+1|0]|0;na=$|0;c[na>>2]=-1;c[na+4>>2]=-1;na=n+(B<<4)+8|0;if(A){a[na]=1;a[n+(B<<4)+9|0]=_;a[n+(B<<4)+10|0]=3;A=$+11|0;a[A]=a[K]|0;a[A+1|0]=a[K+1|0]|0;a[A+2|0]=a[K+2|0]|0;a[A+3|0]=a[K+3|0]|0;a[A+4|0]=a[K+4|0]|0;oa=1}else{a[na]=0;a[n+(B<<4)+9|0]=_;a[n+(B<<4)+10|0]=3;_=$+11|0;a[_]=a[t]|0;a[_+1|0]=a[t+1|0]|0;a[_+2|0]=a[t+2|0]|0;a[_+3|0]=a[t+3|0]|0;a[_+4|0]=a[t+4|0]|0;_=B+1|0;$=n+(_<<4)|0;na=a[e+(_*3|0)+1|0]|0;A=$|0;c[A>>2]=-1;c[A+4>>2]=-1;a[n+(_<<4)+8|0]=0;a[n+(_<<4)+9|0]=na;a[n+(_<<4)+10|0]=3;_=$+11|0;a[_]=a[u]|0;a[_+1|0]=a[u+1|0]|0;a[_+2|0]=a[u+2|0]|0;a[_+3|0]=a[u+3|0]|0;a[_+4|0]=a[u+4|0]|0;oa=2}B=oa+B|0;z=z-2|0;}while((z|0)>3);pa=B;qa=X-2-(C&-2)|0}else{pa=la;qa=X}if((qa|0)>1){z=k|0;u=l|0;t=m|0;K=n+(pa<<4)|0;_=a[e+(pa*3|0)+1|0]|0;$=K|0;if((a[e+(pa*3|0)|0]|0)==1){c[$>>2]=48;c[$+4>>2]=0;a[n+(pa<<4)+8|0]=1;a[n+(pa<<4)+9|0]=_;a[n+(pa<<4)+10|0]=3;na=K+11|0;a[na]=a[z]|0;a[na+1|0]=a[z+1|0]|0;a[na+2|0]=a[z+2|0]|0;a[na+3|0]=a[z+3|0]|0;a[na+4|0]=a[z+4|0]|0;ra=1}else{c[$>>2]=16;c[$+4>>2]=0;a[n+(pa<<4)+8|0]=0;a[n+(pa<<4)+9|0]=_;a[n+(pa<<4)+10|0]=3;_=K+11|0;a[_]=a[u]|0;a[_+1|0]=a[u+1|0]|0;a[_+2|0]=a[u+2|0]|0;a[_+3|0]=a[u+3|0]|0;a[_+4|0]=a[u+4|0]|0;u=pa+1|0;_=n+(u<<4)|0;K=a[e+(u*3|0)+1|0]|0;$=_|0;c[$>>2]=32;c[$+4>>2]=0;a[n+(u<<4)+8|0]=0;a[n+(u<<4)+9|0]=K;a[n+(u<<4)+10|0]=3;u=_+11|0;a[u]=a[t]|0;a[u+1|0]=a[t+1|0]|0;a[u+2|0]=a[t+2|0]|0;a[u+3|0]=a[t+3|0]|0;a[u+4|0]=a[t+4|0]|0;ra=2}sa=qa-2|0;ta=ra+pa|0}else{sa=qa;ta=pa}if((sa|0)==0){ua=ta}else{t=n+(ta<<4)|0;u=a[e+(ta*3|0)+1|0]|0;_=t|0;c[_>>2]=256;c[_+4>>2]=0;a[n+(ta<<4)+8|0]=0;a[n+(ta<<4)+9|0]=u;a[n+(ta<<4)+10|0]=3;u=t+11|0;a[u]=a[v]|0;a[u+1|0]=a[v+1|0]|0;a[u+2|0]=a[v+2|0]|0;a[u+3|0]=a[v+3|0]|0;a[u+4|0]=a[v+4|0]|0;ua=ta+1|0}do{if((ua|0)<(f|0)){if((a[e+(ua*3|0)+2|0]|0)!=4){va=ua;break}u=n+(ua<<4)|0;t=a[e+(ua*3|0)+1|0]|0;_=u|0;c[_>>2]=8;c[_+4>>2]=0;a[n+(ua<<4)+8|0]=3;a[n+(ua<<4)+9|0]=t;a[n+(ua<<4)+10|0]=4;t=u+11|0;a[t]=a[w]|0;a[t+1|0]=a[w+1|0]|0;a[t+2|0]=a[w+2|0]|0;a[t+3|0]=a[w+3|0]|0;a[t+4|0]=a[w+4|0]|0;va=ua+1|0}else{va=ua}}while(0);b:do{if((va|0)<(f|0)){w=va;while(1){if((a[e+(w*3|0)+2|0]|0)!=4){wa=w;break b}v=n+(w<<4)|0;C=a[e+(w*3|0)+1|0]|0;B=v|0;c[B>>2]=-1;c[B+4>>2]=-1;a[n+(w<<4)+8|0]=3;a[n+(w<<4)+9|0]=C;a[n+(w<<4)+10|0]=4;C=v+11|0;a[C]=a[x]|0;a[C+1|0]=a[x+1|0]|0;a[C+2|0]=a[x+2|0]|0;a[C+3|0]=a[x+3|0]|0;a[C+4|0]=a[x+4|0]|0;C=w+1|0;if((C|0)<(f|0)){w=C}else{wa=C;break}}}else{wa=va}}while(0);x=wa;while(1){if((x|0)>1){xa=1;ya=0}else{break}while(1){w=xa-1|0;C=n+(w<<4)|0;v=c[C+4>>2]|0;B=n+(xa<<4)|0;t=B|0;u=c[t+4>>2]|0;if(v>>>0>u>>>0|v>>>0==u>>>0&(c[C>>2]|0)>>>0>(c[t>>2]|0)>>>0){t=B;c[y>>2]=c[t>>2];c[y+4>>2]=c[t+4>>2];c[y+8>>2]=c[t+8>>2];c[y+12>>2]=c[t+12>>2];B=n+(w<<4)|0;c[t>>2]=c[B>>2];c[t+4>>2]=c[B+4>>2];c[t+8>>2]=c[B+8>>2];c[t+12>>2]=c[B+12>>2];c[B>>2]=c[y>>2];c[B+4>>2]=c[y+4>>2];c[B+8>>2]=c[y+8>>2];c[B+12>>2]=c[y+12>>2];za=xa}else{za=ya}B=xa+1|0;if((B|0)<(x|0)){xa=B;ya=za}else{break}}if((za|0)>0){x=za}else{break}}if((wa|0)>0){Aa=0;Ba=0;Ca=0}else{r=0;s=0;break}while(1){a[e+(Aa*3|0)|0]=a[n+(Aa<<4)+8|0]|0;a[e+(Aa*3|0)+1|0]=a[n+(Aa<<4)+9|0]|0;a[e+(Aa*3|0)+2|0]=a[n+(Aa<<4)+10|0]|0;x=n+(Aa<<4)|0;y=c[x>>2]|0;B=c[x+4>>2]|0;x=(y|0)==(-1|0)&(B|0)==(-1|0);t=(x?0:y)|Ca;y=(x?0:B)|Ba;B=Aa+1|0;if((B|0)<(wa|0)){Aa=B;Ba=y;Ca=t}else{r=y;s=t;break}}}}while(0);do{if((f|0)>0){Ca=b+6544|0;Ba=0;Aa=0;c:while(1){wa=a[e+(Aa*3|0)|0]|0;if((Ba|0)>63){Da=-1094995529;Ea=110;break}n=b+492+((wa&255)<<6)+(d[e+(Aa*3|0)+1|0]<<2)|0;za=c[n>>2]|0;ya=(za|0)!=0;do{if((a[e+(Aa*3|0)+2|0]|0)==0){if(ya){dkb(za+112352|0)}mJb(n);Fa=Ba}else{if(!ya){xa=pJb(456160)|0;c[n>>2]=xa;if((xa|0)==0){Da=-12;Ea=110;break c}ckb(b,xa+112352|0)}if(wa<<24>>24==2){Fa=Ba;break}xa=wa<<24>>24==1;do{if(xa){Ga=1}else{if(!(wa<<24>>24==0)){Ga=0;break}Ga=(c[Ca>>2]|0)==1|0}}while(0);if((Ba|0)>=(64-Ga|0)){Ea=94;break c}va=Ba+1|0;c[b+5436+(Ba<<2)>>2]=(c[n>>2]|0)+160;if(!xa){if(!(wa<<24>>24==0)){Fa=va;break}if((c[Ca>>2]|0)!=1){Fa=va;break}}c[b+5436+(va<<2)>>2]=(c[n>>2]|0)+52352;Fa=Ba+2|0}}while(0);n=Aa+1|0;if((n|0)<(f|0)){Ba=Fa;Aa=n}else{Ea=103;break}}if((Ea|0)==94){KIb(c[o>>2]|0,16,2487288,(Aa=i,i=i+1|0,i=i+7&-8,c[Aa>>2]=0,Aa)|0);i=Aa;Da=-1094995529;i=j;return Da|0}else if((Ea|0)==103){if(!((c[Ca>>2]|0)==1&(Fa|0)==2)){Ha=r;Ia=s;Ja=Fa;break}Aa=(s|0)==4&(r|0)==0;Ha=Aa?0:0;Ia=Aa?3:0;Ja=Fa;break}else if((Ea|0)==110){i=j;return Da|0}}else{Ha=r;Ia=s;Ja=0}}while(0);nrc(b+748|0,b+492|0,256)|0;if(!((Ia|0)==0&(Ha|0)==0)){s=p+448|0;c[s>>2]=Ia;c[s+4>>2]=Ha}s=b+6752|0;c[s>>2]=Ia;c[s+4>>2]=Ha;c[b+6744>>2]=Ja;c[p+416>>2]=Ja;c[b+6760>>2]=g;do{if((h|0)!=0){g=Cjb(c[o>>2]|0)|0;if((g|0)<0){Da=g}else{break}i=j;return Da|0}}while(0);Da=0;i=j;return Da|0}function Ijb(b){b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=b+6504|0;e=c[d>>2]|0;if((e|0)==23){f=292}else if((e|0)==39){f=242}else{f=c[b+6772>>2]|0}e=b+6776|0;h=b+6788|0;i=b+6520|0;j=b+6780|0;k=3;while(1){l=(k|0)<2;m=(k|0)==1;n=(k|0)==2;o=(k|0)<3;p=0;do{q=c[b+492+(k<<6)+(p<<2)>>2]|0;do{if((q|0)!=0){if(l){r=q+52352|0;s=q+160|0;t=0;do{u=c[b+620+(t<<2)>>2]|0;do{if((u|0)!=0){if((c[u+104544>>2]|0)!=0){break}v=u+104548|0;if((c[v>>2]|0)<0){break}else{w=0;x=0}while(1){do{if((c[u+104552+(w<<2)>>2]|0)==(k|0)){if((c[u+104584+(w<<2)>>2]|0)!=(p|0)){y=17;break}z=u+104616+(w<<2)|0;if((c[z>>2]|0)==1){A=x}else{Ljb(b,s,u,x);B=c[z>>2]|0;z=((B|0)!=0)+x|0;if((B|0)==2){C=z;break}else{A=z}}Ljb(b,r,u,A);C=A+1|0}else{y=17}}while(0);if((y|0)==17){y=0;C=((c[u+104616+(w<<2)>>2]|0)==3?2:1)+x|0}z=w+1|0;if((z|0)>(c[v>>2]|0)){break}else{w=z;x=C}}}}while(0);t=t+1|0;}while((t|0)<16)}do{if((c[d>>2]|0)==4){if((c[q+256>>2]|0)==0){break}if((a[q+188|0]|0)!=0){re[c[e>>2]&1023](b,q+160|0)}if(!((a[q+52380|0]|0)!=0&m)){break}re[c[e>>2]&1023](b,q+52352|0)}}while(0);t=q+160|0;r=t|0;s=q+312|0;if((c[s>>2]|0)!=0){mf[c[j>>2]&2047](q+5472|0,s,t|0,1)}t=q+52352|0;s=q+52504|0;if((c[s>>2]|0)!=0){mf[c[j>>2]&2047](q+57664|0,s,t|0,1)}if(l){s=q+160|0;u=0;do{v=c[b+620+(u<<2)>>2]|0;do{if((v|0)!=0){if((c[v+104544>>2]|0)!=1){break}z=v+104548|0;if((c[z>>2]|0)<0){break}else{D=0;E=0}while(1){do{if((c[v+104552+(D<<2)>>2]|0)==(k|0)){if((c[v+104584+(D<<2)>>2]|0)!=(p|0)){y=40;break}B=v+104616+(D<<2)|0;if((c[B>>2]|0)==1){F=E}else{Ljb(b,s,v,E);G=c[B>>2]|0;B=((G|0)!=0)+E|0;if((G|0)==2){H=B;break}else{F=B}}Ljb(b,t,v,F);H=F+1|0}else{y=40}}while(0);if((y|0)==40){y=0;H=((c[v+104616+(D<<2)>>2]|0)==3?2:1)+E|0}B=D+1|0;if((B|0)>(c[z>>2]|0)){break}else{D=B;E=H}}}}while(0);u=u+1|0;}while((u|0)<16)}if(n){if((c[q+104544>>2]|0)==3){y=45}}else{y=45}if((y|0)==45){y=0;re[f&1023](b,r);if((c[d>>2]|0)==4){re[c[h>>2]&1023](b,r)}do{if(m){re[f&1023](b,t);if((c[d>>2]|0)!=4){break}re[c[h>>2]&1023](b,t)}}while(0);if((c[i>>2]|0)>0){fkb(b,q+112352|0,k,c[q+52320>>2]|0,c[q+104512>>2]|0)}if(!o){break}}t=q+104512|0;r=q+52320|0;u=0;do{s=c[b+620+(u<<2)>>2]|0;do{if((s|0)!=0){if((c[s+104544>>2]|0)!=3){break}v=c[s+104548>>2]|0;if((v|0)<0){break}z=s+52320|0;B=0;G=0;while(1){do{if((c[s+104552+(B<<2)>>2]|0)==(k|0)){if((c[s+104584+(B<<2)>>2]|0)!=(p|0)){y=67;break}I=c[s+104616+(B<<2)>>2]|0;if((I|0)==1){J=G;K=c[z>>2]|0;L=c[i>>2]|0}else{M=+g[s+104648+(G*480|0)>>2];N=c[z>>2]|0;O=c[r>>2]|0;P=c[i>>2]|0;Q=1024<<((P|0)==1);if((Q|0)>0){R=0;do{S=O+(R<<2)|0;g[S>>2]=+g[S>>2]+M*+g[N+(R<<2)>>2];R=R+1|0;}while((R|0)<(Q|0))}Q=((I|0)!=0)+G|0;if((I|0)==2){T=Q;break}else{J=Q;K=N;L=P}}Q=J+1|0;M=+g[s+104648+(J*480|0)>>2];R=c[t>>2]|0;O=1024<<((L|0)==1);if((O|0)>0){U=0}else{T=Q;break}while(1){S=R+(U<<2)|0;g[S>>2]=+g[S>>2]+M*+g[K+(U<<2)>>2];S=U+1|0;if((S|0)<(O|0)){U=S}else{T=Q;break}}}else{y=67}}while(0);if((y|0)==67){y=0;T=((c[s+104616+(B<<2)>>2]|0)==3?2:1)+G|0}Q=B+1|0;if((Q|0)>(v|0)){break}else{B=Q;G=T}}}}while(0);u=u+1|0;}while((u|0)<16)}}while(0);p=p+1|0;}while((p|0)<16);if((k|0)>0){k=k-1|0}else{break}}return}function Jjb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[d+52160>>2]|0;f=d+9408|0;g=b+1024|0;ef[c[b+5164>>2]&4095](b+5248|0,g,d+5312|0);if((a[d+13|0]|0)==0){pe[c[b+5412>>2]&1023](e,f,g,6254360,256);h=f;i=b+2048|0;j=i;nrc(h|0,j|0,1024)|0;return}else{k=f;nrc(e|0,k|0,768)|0;pe[c[b+5412>>2]&1023](e+768|0,d+10176|0,g,6282136,64);nrc(e+1280|0,b+1280|0,768)|0;h=k;i=b+2048|0;j=i;nrc(h|0,j|0,1024)|0;return}}function Kjb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,i=0.0,j=0,k=0,l=0,m=0;d=c[b+52160>>2]|0;e=b+9408|0;f=0;do{h=b+5312+(f<<2)|0;i=+g[h>>2];j=b+5312+(511-f<<2)|0;g[h>>2]=-0.0- +g[j>>2];g[j>>2]=i;j=b+5312+((f|1)<<2)|0;i=-0.0- +g[j>>2];h=b+5312+(510-f<<2)|0;g[j>>2]=+g[h>>2];g[h>>2]=i;f=f+2|0;}while((f|0)<256);f=a+1024|0;ef[c[a+5164>>2]&4095](a+5248|0,f,b+5312|0);h=0;while(1){j=a+1024+(h<<2)|0;g[j>>2]=-0.0- +g[j>>2];j=h+2|0;if((j|0)<512){h=j}else{k=128;break}}while(1){h=k-128|0;g[d+(h<<2)>>2]=+g[a+1024+(255-k<<2)>>2]*+g[1446544+(h<<2)>>2]+ +g[b+9408+(k+256<<2)>>2]*+g[1446544+(k+384<<2)>>2]+ +g[1446544+(k+896<<2)>>2]*(-0.0- +g[b+9408+(767-k<<2)>>2])+ +g[1446544+(k+1408<<2)>>2]*(-0.0- +g[b+9408+(k+1280<<2)>>2]);h=k+1|0;if((h|0)<256){k=h}else{l=0;break}}while(1){k=l+128|0;g[d+(k<<2)>>2]=+g[a+1024+(l<<2)>>2]*+g[1446544+(k<<2)>>2]+ +g[1446544+(l+640<<2)>>2]*(-0.0- +g[b+9408+(511-l<<2)>>2])+ +g[1446544+(l+1152<<2)>>2]*(-0.0- +g[b+9408+(l+512<<2)>>2])+ +g[b+9408+(1535-l<<2)>>2]*+g[1446544+(l+1664<<2)>>2];k=l+1|0;if((k|0)<256){l=k}else{m=0;break}}do{l=m+384|0;g[d+(l<<2)>>2]=+g[a+1024+(m+256<<2)>>2]*+g[1446544+(l<<2)>>2]+ +g[1446544+(m+896<<2)>>2]*(-0.0- +g[b+9408+(255-m<<2)>>2])+ +g[1446544+(m+1408<<2)>>2]*(-0.0- +g[b+9408+(m+768<<2)>>2]);m=m+1|0;}while((m|0)<128);m=e;orc(b+11456|0,m|0,4096)|0;nrc(m|0,f|0,2048)|0;return}function Ljb(e,f,h,j){e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;k=i;l=c[h+236>>2]|0;if((c[e+6504>>2]|0)==4){KIb(c[e+4>>2]|0,16,2584984,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=k;return}e=c[h+176>>2]|0;if((e|0)<=0){i=k;return}m=h+160|0;n=a[m]|0;o=h+5472|0;p=0;q=0;r=f+5312|0;f=n;s=n;while(1){n=h+180+p|0;if(f<<24>>24==0){t=q;u=0;v=s}else{w=0;x=q;y=s;while(1){do{if((c[h+3332+(x<<2)>>2]|0)==0){z=y}else{A=+g[h+104648+(j*480|0)+(x<<2)>>2];B=a[n]|0;if(B<<24>>24==0){z=y;break}C=b[l+(w<<1)>>1]|0;D=b[l+(w+1<<1)>>1]|0;E=0;F=B;while(1){if((C&65535)>>>0<(D&65535)>>>0){B=E<<7;G=D&65535;H=C&65535;do{I=H+B|0;J=r+(I<<2)|0;g[J>>2]=+g[J>>2]+A*+g[o+(I<<2)>>2];H=H+1|0;}while((H|0)<(G|0));K=a[n]|0}else{K=F}G=E+1|0;if((G|0)<(K&255|0)){E=G;F=K}else{break}}z=a[m]|0}}while(0);F=w+1|0;E=x+1|0;if((F|0)<(z&255|0)){w=F;x=E;y=z}else{t=E;u=z;v=z;break}}}y=(d[n]|0)<<7;x=p+1|0;if((x|0)<(e|0)){o=o+(y<<2)|0;p=x;q=t;r=r+(y<<2)|0;f=u;s=v}else{break}}i=k;return}function Mjb(e,f,h){e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;j=i;k=c[e+6504>>2]|0;l=(k|0)!=39;do{if(l){m=h+8|0;n=c[m>>2]|0;o=h|0;p=c[o>>2]|0;q=d[p+(n>>>3)|0]|0;r=h+16|0;s=c[r>>2]|0;t=((n|0)<(s|0))+n|0;c[m>>2]=t;if((q&128>>>((n&7)>>>0)|0)!=0){KIb(c[e+4>>2]|0,16,2401704,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1094995529;i=j;return v|0}n=f+4|0;c[f+8>>2]=c[n>>2];q=p+(t>>>3)|0;p=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(t&7)>>>30;q=t+2|0;c[m>>2]=s>>>0>q>>>0?q:s;c[n>>2]=p;if((k|0)!=23|(p|0)==0){s=f+12|0;a[f+13|0]=a[s]|0;q=c[m>>2]|0;t=(d[(c[o>>2]|0)+(q>>>3)|0]|0)<<(q&7)>>>7;c[m>>2]=((q|0)<(c[r>>2]|0))+q;a[s]=t&1;w=p;x=m;y=r;z=o;break}KIb(c[e+4>>2]|0,16,2394944,(u=i,i=i+8|0,c[u>>2]=p,u)|0);i=u;c[n>>2]=0;v=-1094995529;i=j;return v|0}else{w=c[f+4>>2]|0;x=h+8|0;y=h+16|0;z=h|0}}while(0);h=f+16|0;c[h>>2]=1;a[f+20|0]=1;n=c[x>>2]|0;p=c[y>>2]|0;o=(c[z>>2]|0)+(n>>>3)|0;r=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(n&7);a:do{if((w|0)==2){o=n+4|0;c[x>>2]=p>>>0>o>>>0?o:p;a[f|0]=r>>>28;o=0;do{m=c[x>>2]|0;t=d[(c[z>>2]|0)+(m>>>3)|0]|0;c[x>>2]=((m|0)<(c[y>>2]|0))+m;s=c[h>>2]|0;if((t&128>>>((m&7)>>>0)|0)==0){c[h>>2]=s+1;a[f+20+s|0]=1}else{m=s-1+(f+20)|0;a[m]=(a[m]|0)+1}o=o+1|0;}while((o|0)<7);c[f+88>>2]=8;o=e+6508|0;m=c[o>>2]|0;c[f+76>>2]=c[1297968+(m<<2)>>2];c[f+84>>2]=d[1446256+m|0]|0;c[f+92>>2]=d[1278256+(c[o>>2]|0)|0]|0;c[f+96>>2]=0;A=35}else{o=n+6|0;c[x>>2]=p>>>0>o>>>0?o:p;o=f|0;a[o]=r>>>26;c[f+88>>2]=1;m=e+6508|0;s=c[m>>2]|0;do{if((k|0)==39|(k|0)==23){t=c[1297912+(s<<2)>>2]|0;c[f+76>>2]=t;q=a[1446240+s|0]|0;c[f+84>>2]=q&255;c[f+92>>2]=d[1278240+(c[m>>2]|0)|0]|0;if(q<<24>>24==0|(t|0)==0){v=-558323010}else{break}i=j;return v|0}else{c[f+76>>2]=c[1298024+(s<<2)>>2];c[f+84>>2]=d[1446272+s|0]|0;c[f+92>>2]=d[1278272+(c[m>>2]|0)|0]|0}}while(0);if(l){s=c[x>>2]|0;t=(d[(c[z>>2]|0)+(s>>>3)|0]|0)<<(s&7)>>>7;c[x>>2]=((s|0)<(c[y>>2]|0))+s;s=t&1;c[f+96>>2]=s;c[f+104>>2]=0;B=s}else{B=c[f+96>>2]|0}if((B|0)==0){A=35;break}if((k|0)==23){KIb(c[e+4>>2]|0,16,2380888,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;v=-1163346256;i=j;return v|0}else if((k|0)==1){s=c[x>>2]|0;t=c[z>>2]|0;q=d[t+(s>>>3)|0]|0;C=c[y>>2]|0;D=((s|0)<(C|0))+s|0;c[x>>2]=D;do{if((q&128>>>((s&7)>>>0)|0)!=0){E=t+(D>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(D&7)>>>27;E=D+5|0;c[x>>2]=C>>>0>E>>>0?E:C;c[f+104>>2]=F;if(!((F|0)==31|(F|0)==0)){break}KIb(c[e+4>>2]|0,16,2367256,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break a}}while(0);C=a[o]|0;D=a[1446176+(c[m>>2]|0)|0]|0;if(((C&255)>>>0>(D&255)>>>0?D:C)<<24>>24==0){A=35;break}else{G=0;H=t}while(1){C=c[x>>2]|0;D=(d[H+(C>>>3)|0]|0)<<(C&7)>>>7;c[x>>2]=((C|0)<(c[y>>2]|0))+C;a[f+108+G|0]=D&1;D=G+1|0;C=a[o]|0;s=a[1446176+(c[m>>2]|0)|0]|0;if((D|0)>=(((C&255)>>>0>(s&255)>>>0?s:C)&255|0)){A=35;break a}G=D;H=c[z>>2]|0}}else if((k|0)==17|(k|0)==2){KIb(c[e+4>>2]|0,16,2387808,(u=i,i=i+1|0,i=i+7&-8,c[u>>2]=0,u)|0);i=u;break}else{m=c[x>>2]|0;t=c[y>>2]|0;D=(c[z>>2]|0)+(m>>>3)|0;C=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(m&7)>>>31;D=m+1|0;c[x>>2]=t>>>0>D>>>0?D:t;t=C&255;a[f+28|0]=t;if(t<<24>>24==0){A=35;break}t=a[o]|0;C=c[x>>2]|0;D=c[y>>2]|0;m=c[z>>2]|0;s=m+(C>>>3)|0;q=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(C&7)>>>21;s=C+11|0;C=D>>>0>s>>>0?s:D;c[x>>2]=C;b[f+30>>1]=q;q=m+(C>>>3)|0;s=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(C&7)>>>29;q=C+3|0;C=D>>>0>q>>>0?q:D;c[x>>2]=C;g[f+32>>2]=+g[841888+(s<<2)>>2];s=(t&255)>>>0>40>>>0?40:t&255;if((s|0)==0){A=35;break}else{I=0;J=C;K=m;L=D}while(1){D=(d[K+(J>>>3)|0]|0)<<(J&7)>>>7;c[x>>2]=((J|0)<(L|0))+J;a[f+36+I|0]=D&1;D=I+1|0;if((D|0)>=(s|0)){A=35;break a}I=D;J=c[x>>2]|0;K=c[z>>2]|0;L=c[y>>2]|0}}}}while(0);do{if((A|0)==35){y=d[f|0]|0;L=c[f+84>>2]|0;if((y|0)>(L|0)){KIb(c[e+4>>2]|0,16,2374480,(u=i,i=i+16|0,c[u>>2]=y,c[u+8>>2]=L,u)|0);i=u;break}else{v=0;i=j;return v|0}}}while(0);a[f|0]=0;v=-1094995529;i=j;return v|0}function Njb(d,f){d=d|0;f=f|0;var h=0,i=0,j=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0.0,v=0,w=0.0,x=0,y=0.0,z=0,A=0.0,B=0,C=0.0,D=0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0,K=0;h=f+100|0;if((c[h>>2]|0)==0){i=0;do{g[f+36032+(i*24|0)+16>>2]=0.0;g[f+36032+(i*24|0)+20>>2]=0.0;g[f+36032+(i*24|0)>>2]=0.0;g[f+36032+(i*24|0)+4>>2]=0.0;g[f+36032+(i*24|0)+8>>2]=1.0;g[f+36032+(i*24|0)+12>>2]=1.0;i=i+1|0;}while((i|0)<672);c[h>>2]=1}if((c[f+4>>2]|0)==2){h=0;do{g[f+36032+(h*24|0)+16>>2]=0.0;g[f+36032+(h*24|0)+20>>2]=0.0;g[f+36032+(h*24|0)>>2]=0.0;g[f+36032+(h*24|0)+4>>2]=0.0;g[f+36032+(h*24|0)+8>>2]=1.0;g[f+36032+(h*24|0)+12>>2]=1.0;h=h+1|0;}while((h|0)<672);return}h=a[1446176+(c[d+6508>>2]|0)|0]|0;if(!(h<<24>>24==0)){d=f+76|0;i=f+96|0;j=0;l=c[d>>2]|0;while(1){m=b[l+(j<<1)>>1]|0;n=j+1|0;if((m&65535)>>>0<(e[l+(n<<1)>>1]|0)>>>0){o=f+108+j|0;p=m&65535;while(1){m=f+5312+(p<<2)|0;if((c[i>>2]|0)==0){q=0}else{q=(a[o]|0)!=0|0}r=f+36032+(p*24|0)+16|0;s=+g[r>>2];t=f+36032+(p*24|0)+20|0;u=+g[t>>2];v=f+36032+(p*24|0)|0;w=+g[v>>2];x=f+36032+(p*24|0)+4|0;y=+g[x>>2];z=f+36032+(p*24|0)+8|0;A=+g[z>>2];B=f+36032+(p*24|0)+12|0;C=+g[B>>2];if(A>1.0){D=(g[k>>2]=.953125/A,c[k>>2]|0);E=w*(c[k>>2]=D+32767+(D&1)&-65536,+g[k>>2])}else{E=0.0}if(C>1.0){D=(g[k>>2]=.953125/C,c[k>>2]|0);F=y*(c[k>>2]=D+32767+(D&1)&-65536,+g[k>>2])}else{F=0.0}G=s*E;if((q|0)==0){H=+g[m>>2]}else{I=(c[k>>2]=(g[k>>2]=G+u*F,c[k>>2]|0)+32768&-65536,+g[k>>2])+ +g[m>>2];g[m>>2]=I;H=I}I=H-G;g[x>>2]=(c[k>>2]=(g[k>>2]=y*.90625+u*I,c[k>>2]|0)&-65536,+g[k>>2]);g[B>>2]=(c[k>>2]=(g[k>>2]=C*.90625+(u*u+I*I)*.5,c[k>>2]|0)&-65536,+g[k>>2]);g[v>>2]=(c[k>>2]=(g[k>>2]=w*.90625+s*H,c[k>>2]|0)&-65536,+g[k>>2]);g[z>>2]=(c[k>>2]=(g[k>>2]=A*.90625+(s*s+H*H)*.5,c[k>>2]|0)&-65536,+g[k>>2]);g[t>>2]=(c[k>>2]=(g[k>>2]=(s-E*H)*.953125,c[k>>2]|0)&-65536,+g[k>>2]);g[r>>2]=(c[k>>2]=(g[k>>2]=H*.953125,c[k>>2]|0)&-65536,+g[k>>2]);r=p+1|0;t=c[d>>2]|0;if((r|0)<(e[t+(n<<1)>>1]|0)){p=r}else{J=t;break}}}else{J=l}if((n|0)<(h&255|0)){j=n;l=J}else{break}}}J=c[f+104>>2]|0;if((J|0)==0){return}l=J-1|0;if((l|0)<672){K=l}else{return}do{g[f+36032+(K*24|0)+16>>2]=0.0;g[f+36032+(K*24|0)+20>>2]=0.0;g[f+36032+(K*24|0)>>2]=0.0;g[f+36032+(K*24|0)+4>>2]=0.0;g[f+36032+(K*24|0)+8>>2]=1.0;g[f+36032+(K*24|0)+12>>2]=1.0;K=K+30|0;}while((K|0)<672);return}function Ojb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;j=(c[f+4>>2]|0)==2;k=j&1;if(j){l=7}else{l=(c[a+6504>>2]|0)==1?20:12}j=f+88|0;if((c[j>>2]|0)<=0){m=0;i=h;return m|0}f=2-k|0;n=e+8|0;o=e+16|0;p=32-f|0;q=k<<1;k=6-q|0;r=32-k|0;s=5-q|0;q=32-s|0;t=c[e>>2]|0;e=0;a:while(1){u=c[n>>2]|0;v=c[o>>2]|0;w=t+(u>>>3)|0;x=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(u&7)>>>(p>>>0);w=u+f|0;c[n>>2]=v>>>0>w>>>0?w:v;v=b+4+(e<<2)|0;c[v>>2]=x;b:do{if((x|0)!=0){w=c[n>>2]|0;u=(d[t+(w>>>3)|0]|0)<<(w&7)>>>7;y=c[o>>2]|0;z=((w|0)<(y|0))+w|0;c[n>>2]=z;w=u&1;if((c[v>>2]|0)<=0){break}u=w+3|0;A=0;B=z;z=y;while(1){y=t+(B>>>3)|0;C=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(B&7)>>>(r>>>0);y=B+k|0;c[n>>2]=z>>>0>y>>>0?y:z;c[b+36+(e<<4)+(A<<2)>>2]=C;C=c[n>>2]|0;y=c[o>>2]|0;D=t+(C>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(C&7)>>>(q>>>0);D=C+s|0;c[n>>2]=y>>>0>D>>>0?D:y;F=b+292+(e<<4)+(A<<2)|0;c[F>>2]=E;if((E|0)>(l|0)){break a}do{if((E|0)!=0){y=c[n>>2]|0;D=(d[t+(y>>>3)|0]|0)<<(y&7)>>>7;c[n>>2]=((y|0)<(c[o>>2]|0))+y;c[b+164+(e<<4)+(A<<2)>>2]=D&1;D=c[n>>2]|0;y=(d[t+(D>>>3)|0]|0)<<(D&7)>>>7;C=c[o>>2]|0;G=((D|0)<(C|0))+D|0;c[n>>2]=G;D=y&1;y=u-D|0;if((c[F>>2]|0)<=0){break}H=32-y|0;I=c[307600+((D<<1|w)<<2)>>2]|0;D=0;J=G;do{G=t+(J>>>3)|0;K=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(J&7)>>>(H>>>0);G=J+y|0;J=C>>>0>G>>>0?G:C;c[n>>2]=J;g[b+420+(e*320|0)+(A*80|0)+(D<<2)>>2]=+g[I+(K<<2)>>2];D=D+1|0;}while((D|0)<(c[F>>2]|0))}}while(0);D=A+1|0;if((D|0)>=(c[v>>2]|0)){break b}A=D;B=c[n>>2]|0;z=c[o>>2]|0}}}while(0);v=e+1|0;if((v|0)<(c[j>>2]|0)){e=v}else{m=0;L=17;break}}if((L|0)==17){i=h;return m|0}KIb(c[a+4>>2]|0,16,2327384,(a=i,i=i+16|0,c[a>>2]=E,c[a+8>>2]=l,a)|0);i=a;c[F>>2]=0;m=-1094995529;i=h;return m|0}function Pjb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+48|0;f=e|0;g=c[a+4>>2]|0;mrc(f|0,0,44)|0;h=b+8|0;j=c[h>>2]|0;k=(c[b+12>>2]|0)-j|0;if((d|0)==0){l=k;m=0}else{l=(k|0)<(d|0)?k:d;m=1}if((j&7|0)!=0){QIb(g,2207848,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;o=-1163346256;i=e;return o|0}if((l|0)<1){o=-1094995529;i=e;return o|0}d=b|0;k=(j|0)/8|0;j=Ajb(0,g,f,(c[d>>2]|0)+k|0,l,m)|0;if((j|0)<0){o=-1094995529;i=e;return o|0}m=a+6816|0;do{if((c[m>>2]|0)==0){KIb(g,48,2195056,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=12}else{if((c[a+6512>>2]|0)==(c[f+8>>2]|0)){if((c[a+6516>>2]|0)==(c[f+12>>2]|0)){break}}KIb(g,32,2199112,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n;p=12}}while(0);if((p|0)==12){c[m>>2]=0;m=(j+7|0)/8|0;p=g+100|0;n=g+96|0;f=c[n>>2]|0;do{if((c[p>>2]|0)<(m|0)){kJb(f);a=hJb(m+16|0)|0;c[n>>2]=a;if((a|0)==0){o=-12}else{q=a;break}i=e;return o|0}else{q=f}}while(0);c[p>>2]=m;nrc(q|0,(c[d>>2]|0)+k|0,m)|0;mrc((c[g+96>>2]|0)+m|0,0,16)|0}m=c[h>>2]|0;g=-m|0;k=(c[b+16>>2]|0)-m|0;if((j|0)<(g|0)){r=g}else{r=(k|0)<(j|0)?k:j}c[h>>2]=r+m;o=j;i=e;return o|0}function Qjb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[d+52160>>2]|0;f=d+9408|0;g=(a[d+12|0]|0)!=0?8816736:6282136;h=(a[d+13|0]|0)!=0;i=h?8817248:6282648;j=h?8816736:6282136;h=b+1024|0;k=b+5728|0;l=d+4|0;if((c[l>>2]|0)==2){m=b+5184|0;n=b+5228|0;ef[c[n>>2]&4095](m,h,d+5312|0);ef[c[n>>2]&4095](m,b+1536|0,d+5824|0);ef[c[n>>2]&4095](m,b+2048|0,d+6336|0);ef[c[n>>2]&4095](m,b+2560|0,d+6848|0);ef[c[n>>2]&4095](m,b+3072|0,d+7360|0);ef[c[n>>2]&4095](m,b+3584|0,d+7872|0);ef[c[n>>2]&4095](m,b+4096|0,d+8384|0);ef[c[n>>2]&4095](m,b+4608|0,d+8896|0)}else{ef[c[b+5164>>2]&4095](b+5120|0,h,d+5312|0)}m=c[d+8>>2]|0;do{if((m|0)==0|(m|0)==3){if(!((c[l>>2]|0)>>>0<2>>>0)){o=7;break}pe[c[b+5412>>2]&1023](e,f,h,i,512)}else{o=7}}while(0);do{if((o|0)==7){nrc(e|0,f|0,1792)|0;i=(c[l>>2]|0)==2;m=b+5412|0;pe[c[m>>2]&1023](e+1792|0,d+11200|0,h,j,64);if(i){pe[c[m>>2]&1023](e+2304|0,b+1280|0,b+1536|0,g,64);pe[c[m>>2]&1023](e+2816|0,b+1792|0,b+2048|0,g,64);pe[c[m>>2]&1023](e+3328|0,b+2304|0,b+2560|0,g,64);pe[c[m>>2]&1023](k,b+2816|0,b+3072|0,g,64);nrc(e+3840|0,k|0,256)|0;break}else{nrc(e+2304|0,b+1280|0,1792)|0;break}}}while(0);e=c[l>>2]|0;if((e|0)==2){nrc(f|0,b+5984|0,256)|0;l=b+5412|0;pe[c[l>>2]&1023](d+9664|0,b+3328|0,b+3584|0,g,64);pe[c[l>>2]&1023](d+10176|0,b+3840|0,b+4096|0,g,64);pe[c[l>>2]&1023](d+10688|0,b+4352|0,b+4608|0,g,64);nrc(d+11200|0,b+4864|0,256)|0;return}g=f;f=b+3072|0;if((e|0)==1){nrc(g|0,f|0,1792)|0;nrc(d+11200|0,b+4864|0,256)|0;return}else{nrc(g|0,f|0,2048)|0;return}}function Rjb(d,e){d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=e|0;h=c[e+76>>2]|0;if((c[e+4>>2]|0)==2){return}i=c[e+52160>>2]|0;j=d+1024|0;k=b[e+30>>1]|0;if(k<<16>>16<1024){l=((k&65535)<<16)+67108864|0;if((l|0)>0){m=l>>16;n=4}else{o=0}}else{m=2048;n=4}if((n|0)==4){n=e+32|0;l=0;while(1){g[i+(l<<2)>>2]=+g[e+23744+(l+2048-(k<<16>>16)<<2)>>2]*+g[n>>2];p=l+1|0;if((p|0)<(m|0)){l=p}else{o=m;break}}}mrc(i+(o<<2)|0,0,2048-o<<2|0)|0;mf[c[d+6784>>2]&2047](d,j,i,f);i=e+152|0;if((c[i>>2]|0)!=0){mf[c[d+6780>>2]&2047](j,i,f,0)}f=e|0;i=a[f]|0;if(i<<24>>24==0){return}else{q=0;r=i}while(1){do{if((a[e+36+q|0]|0)==0){s=r;t=q+1|0}else{i=b[h+(q<<1)>>1]|0;j=q+1|0;o=b[h+(j<<1)>>1]|0;if(!((i&65535)>>>0<(o&65535)>>>0)){s=r;t=j;break}m=o&65535;o=i&65535;do{i=e+5312+(o<<2)|0;g[i>>2]=+g[d+1024+(o<<2)>>2]+ +g[i>>2];o=o+1|0;}while((o|0)<(m|0));s=a[f]|0;t=j}}while(0);if((t|0)<(((s&255)>>>0>40>>>0?40:s&255)|0)){q=t;r=s}else{break}}return}function Sjb(a,b,f,h){a=a|0;b=b|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0;j=i;i=i+168|0;k=j|0;l=j+80|0;m=c[f+92>>2]|0;n=d[f|0]|0;o=(m|0)>(n|0)?n:m;m=f+88|0;n=c[m>>2]|0;if((n|0)<=0){i=j;return}p=f+84|0;q=f+76|0;f=(h|0)==0;h=l|0;r=0;s=n;while(1){n=b+4+(r<<2)|0;t=c[n>>2]|0;if((t|0)>0){u=r<<7;v=c[p>>2]|0;w=0;x=t;while(1){t=v-(c[b+36+(r<<4)+(w<<2)>>2]|0)|0;y=(t|0)<0?0:t;t=c[b+292+(r<<4)+(w<<2)>>2]|0;a:do{if((t|0)==0){z=x}else{A=(t|0)>0;if(A){B=0;while(1){C=-0.0- +g[b+420+(r*320|0)+(w*80|0)+(B<<2)>>2];g[k+(B<<2)>>2]=C;D=B+1|0;E=D>>1;if((E|0)>0){F=B-1|0;G=0;do{H=k+(G<<2)|0;I=+g[H>>2];J=k+(F-G<<2)|0;K=+g[J>>2];g[H>>2]=I+K*C;g[J>>2]=K+I*C;G=G+1|0;}while((G|0)<(E|0))}if((D|0)<(t|0)){B=D}else{break}}}B=c[q>>2]|0;E=e[B+(((y|0)>(o|0)?o:y)<<1)>>1]|0;G=e[B+(((v|0)>(o|0)?o:v)<<1)>>1]|0;B=G-E|0;if((B|0)<1){z=x;break}F=(c[b+164+(r<<4)+(w<<2)>>2]|0)==0;J=F?1:-1;H=(F?E:G-1|0)+u|0;G=(B|0)>0;if(!f){if(G){L=0;M=H}else{z=x;break}while(1){E=(L|0)>(t|0)?t:L;if((E|0)>=1){F=a+(M<<2)|0;N=1;C=+g[F>>2];do{I=+g[a+(M-(ca(N,J)|0)<<2)>>2];C=C-I*+g[k+(N-1<<2)>>2];g[F>>2]=C;N=N+1|0;}while((N|0)<=(E|0))}E=L+1|0;if((E|0)<(B|0)){L=E;M=M+J|0}else{z=x;break a}}}if(G){O=0;P=H}else{z=x;break}while(1){E=a+(P<<2)|0;C=+g[E>>2];g[h>>2]=C;N=(O|0)>(t|0)?t:O;if((N|0)>=1){F=1;I=C;do{I=I+ +g[l+(F<<2)>>2]*+g[k+(F-1<<2)>>2];F=F+1|0;}while((F|0)<=(N|0));g[E>>2]=I}if(A){N=t;while(1){F=N-1|0;g[l+(N<<2)>>2]=+g[l+(F<<2)>>2];if((F|0)>0){N=F}else{break}}}N=O+1|0;if((N|0)<(B|0)){O=N;P=P+J|0}else{break}}z=c[n>>2]|0}}while(0);t=w+1|0;if((t|0)<(z|0)){v=y;w=t;x=z}else{break}}Q=c[m>>2]|0}else{Q=s}x=r+1|0;if((x|0)<(Q|0)){r=x;s=Q}else{break}}i=j;return}function Tjb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=(a[f+12|0]|0)!=0;h=(a[f+13|0]|0)!=0;i=f+4|0;if((c[i>>2]|0)==3){mrc(e|0,0,1792)|0;f=e+1792|0;mf[c[b+5396>>2]&2047](f,f,h?8816736:6282136,128)}else{mf[c[b+5396>>2]&2047](e,e,h?8817248:6282648,1024)}h=c[b+5420>>2]|0;f=e+4096|0;if((c[i>>2]|0)==1){i=e+5888|0;mf[h&2047](i,i,g?8816736:6282136,128);mrc(e+6400|0,0,1792)|0;j=b+5312|0;k=b+5360|0;l=c[k>>2]|0;ef[l&4095](j,d,e);return}else{mf[h&2047](f,f,g?8817248:6282648,1024);j=b+5312|0;k=b+5360|0;l=c[k>>2]|0;ef[l&4095](j,d,e);return}}function Ujb(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0;e=d+5312|0;f=(a[d+12|0]|0)!=0;h=f?8817248:6282648;i=f?8816736:6282136;f=c[d+4>>2]|0;if((f|0)==1){j=e;nrc(j|0,b+3072|0,1792)|0;mrc(d+7616|0,0,1792)|0;mf[c[b+5420>>2]&2047](d+7104|0,b+4864|0,i+256|0,64);k=0;while(1){g[d+5312+(k+512<<2)>>2]=+g[b+1024+(1023-k<<2)>>2]*+g[i+(63-k<<2)>>2];l=k+1|0;if((l|0)<64){k=l}else{m=j;break}}}else if((f|0)==2){f=e;nrc(f|0,d+9408|0,2048)|0;mrc(d+7616|0,0,1792)|0;mf[c[b+5420>>2]&2047](d+7104|0,b+4864|0,i+256|0,64);j=0;while(1){g[d+5312+(j+512<<2)>>2]=+g[b+1024+(1023-j<<2)>>2]*+g[i+(63-j<<2)>>2];k=j+1|0;if((k|0)<64){j=k}else{m=f;break}}}else{mf[c[b+5420>>2]&2047](e,b+3072|0,h+2048|0,512);f=0;do{g[d+5312+(f+512<<2)>>2]=+g[b+1024+(1023-f<<2)>>2]*+g[h+(511-f<<2)>>2];f=f+1|0;}while((f|0)<512);m=e}e=d+27840|0;nrc(d+23744|0,e|0,4096)|0;nrc(e|0,c[d+52160>>2]|0,4096)|0;nrc(d+31936|0,m|0,4096)|0;return}function Vjb(b){b=b|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0;e=i;i=i+24|0;f=e|0;h=e+8|0;j=e+16|0;k=b+60|0;l=c[k>>2]|0;m=l;c[b+424>>2]=1024;n=b+412|0;o=0;while(1){if((o|0)>=16){break}if((c[n>>2]|0)==(c[1965112+(o<<2)>>2]|0)){break}else{o=o+1|0}}p=c[b+416>>2]|0;q=l+228|0;c[q>>2]=p;if((o|0)==16){KIb(b,16,2198504,(r=i,i=i+8|0,c[r>>2]=c[n>>2],r)|0);i=r;s=-22;i=e;return s|0}if((p|0)>6){KIb(b,16,2166984,(r=i,i=i+8|0,c[r>>2]=p,r)|0);i=r;s=-22;i=e;return s|0}t=c[b+840>>2]|0;if(!((t|0)==(-99|0)|(t|0)==1)){KIb(b,16,2140528,(r=i,i=i+8|0,c[r>>2]=t,r)|0);i=r;s=-22;i=e;return s|0}if(+(c[b+72>>2]|0)*1024.0/+(c[n>>2]|0)>+(p*6144|0|0)){KIb(b,16,2117088,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;s=-22;i=e;return s|0}c[l+224>>2]=o;n=l+232|0;c[n>>2]=2103912+((p-1|0)*5|0);qHb(l+164|0,c[b+88>>2]&8388608);Fqb(8817248,4.0,1024);Fqb(8816736,6.0,128);H0a(10);H0a(7);p=OPa(l+36|0,11,0,32768.0)|0;a:do{if((p|0)==0){t=OPa(l+100|0,8,0,32768.0)|0;if((t|0)!=0){u=t;break}t=pJb((c[q>>2]|0)*12288|0)|0;v=l+4832|0;c[v>>2]=t;do{if((t|0)==0){if(((c[q>>2]|0)*12288|0|0)==0){break}KIb(b,16,2634960,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;u=-12;break a}}while(0);t=pJb((d[c[n>>2]|0]|0)*456160|0)|0;c[l+236>>2]=t;do{if((t|0)==0){if(((d[c[n>>2]|0]|0)*456160|0|0)==0){break}KIb(b,16,2634960,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;u=-12;break a}}while(0);t=pJb(21)|0;w=b+96|0;c[w>>2]=t;if((t|0)==0){KIb(b,16,2634960,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;u=-12;break}if((c[q>>2]|0)>0){x=0;do{c[m+200+(x<<2)>>2]=(c[v>>2]|0)+((x*3072|0)<<2);x=x+1|0;}while((x|0)<(c[q>>2]|0));z=c[w>>2]|0}else{z=t}c[b+100>>2]=5;x=c[k>>2]|0;v=z;y=je((c[x+224>>2]<<4|c[x+228>>2])<<19|268457701|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;a[z+4|0]=0;v=f|0;c[v>>2]=c[526264+(o<<2)>>2];c[f+4>>2]=c[525872+(o<<2)>>2];x=j|0;c[x>>2]=d[1446272+o|0]|0;c[j+4>>2]=d[1446256+o|0]|0;A=c[n>>2]|0;B=a[A]|0;if(B<<24>>24==0){C=B&255}else{B=0;D=A;while(1){A=B+1|0;a[h+B|0]=(a[D+A|0]|0)==1|0;E=c[n>>2]|0;F=d[E]|0;if((A|0)<(F|0)){B=A;D=E}else{C=F;break}}}D=Lrb(l+240|0,b,2,v,x,C,h|0)|0;if((D|0)!=0){u=D;break}c[l+284>>2]=Orb(b)|0;c[l+288>>2]=1454408+(c[l+8>>2]<<4);D=c[b+80>>2]|0;if((D|0)==0){G=120.0}else{G=+(D|0)}g[l+300>>2]=G;qkb();D=0;do{H=+g[8815024+(D<<2)>>2];g[8813312+(D<<2)>>2]=+S(H*+S(H));D=D+1|0;}while((D|0)<428);c[b+116>>2]=1024;Dmb(b,l+304|0);s=0;i=e;return s|0}else{u=p}}while(0);p=c[k>>2]|0;PPa(p+36|0);PPa(p+100|0);Nrb(p+240|0);k=c[p+284>>2]|0;if((k|0)!=0){Qrb(k)}mJb(p+4832|0);mJb(p+236|0);Emb(p+304|0);s=u;i=e;return s|0}function Wjb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0.0,Ja=0.0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0;j=i;i=i+416|0;k=j|0;l=j+16|0;m=j+352|0;n=j+408|0;o=c[b+60>>2]|0;p=o;q=o+200|0;r=o+296|0;if((c[r>>2]|0)==2){s=0;i=j;return s|0}t=(f|0)!=0;do{if(t){u=Fmb(o+304|0,f)|0;if((u|0)<0){s=u;i=j;return s|0}else{v=(c[f+76>>2]|0)+2048|0;break}}else{v=2048}}while(0);u=o+228|0;w=c[u>>2]|0;x=w-1|0;if((w|0)>0){z=f+64|0;A=f+76|0;f=3072-v<<2;if(t){B=0;while(1){C=p+200+(B<<2)|0;D=c[C>>2]|0;nrc(D+4096|0,D+8192|0,4096)|0;nrc((c[C>>2]|0)+8192|0,c[(c[z>>2]|0)+(d[2103872+(x*6|0)+B|0]<<2)>>2]|0,c[A>>2]<<2)|0;mrc((c[C>>2]|0)+(v<<2)|0,0,f|0)|0;C=B+1|0;D=c[u>>2]|0;if((C|0)<(D|0)){B=C}else{E=D;break}}}else{B=0;while(1){A=p+200+(B<<2)|0;x=c[A>>2]|0;nrc(x+4096|0,x+8192|0,4096)|0;mrc((c[A>>2]|0)+(v<<2)|0,0,f|0)|0;A=B+1|0;x=c[u>>2]|0;if((A|0)<(x|0)){B=A}else{E=x;break}}}}else{E=w}w=c[o+284>>2]|0;if((w|0)!=0){Prb(w,q,E)}E=b+428|0;if((c[E>>2]|0)==0){s=0;i=j;return s|0}w=o+232|0;B=c[w>>2]|0;if((a[B]|0)!=0){f=o+236|0;v=o+224|0;x=o+260|0;A=o+164|0;z=o+100|0;D=o+148|0;C=o+36|0;F=o+84|0;G=o+264|0;H=o+240|0;I=o+244|0;J=m;K=0;L=0;M=B;while(1){B=L+1|0;N=a[M+B|0]|0;O=N<<24>>24==1?2:1;P=c[f>>2]|0;Q=N<<24>>24==3;N=0;do{R=P+(L*456160|0)+160+(N*52192|0)|0;S=N+K|0;T=c[q+(S<<2)>>2]|0;U=T+4096|0;V=l+(S*56|0)|0;if(Q){W=V|0;c[W>>2]=0;X=l+(S*56|0)+12|0;c[X>>2]=0;Y=l+(S*56|0)+16|0;c[Y>>2]=1;c[l+(S*56|0)+20>>2]=1;c[P+(L*456160|0)+160+(N*52192|0)+84>>2]=(c[v>>2]|0)>7?1:3;Z=P+(L*456160|0)+160+(N*52192|0)+4|0;_=W;$=X;aa=Y}else{Y=P+(L*456160|0)+160+(N*52192|0)+4|0;_e[c[(c[I>>2]|0)+8>>2]&511](m,H,U,t?T+6144|0:0,S,c[Y>>2]|0);nrc(V|0,J|0,56)|0;Z=Y;_=V|0;$=l+(S*56|0)+12|0;aa=l+(S*56|0)+16|0}c[P+(L*456160|0)+160+(N*52192|0)+8>>2]=c[Z>>2];V=c[_>>2]|0;c[Z>>2]=V;Y=P+(L*456160|0)+160+(N*52192|0)+12|0;a[P+(L*456160|0)+160+(N*52192|0)+13|0]=a[Y]|0;a[Y]=c[$>>2];Y=c[aa>>2]|0;X=P+(L*456160|0)+160+(N*52192|0)+88|0;c[X>>2]=Y;W=(Y|0)==8|0;c[P+(L*456160|0)+160+(N*52192|0)+80>>2]=c[(c[x>>2]|0)+(W<<2)>>2];if(Q){ba=P+(L*456160|0)+160+(N*52192|0)+84|0;da=ba;ea=ba}else{da=(c[G>>2]|0)+(W<<2)|0;ea=P+(L*456160|0)+160+(N*52192|0)+84|0}c[ea>>2]=c[da>>2];if((Y|0)>0){Y=0;do{a[P+(L*456160|0)+160+(N*52192|0)+20+Y|0]=c[l+(S*56|0)+20+(Y<<2)>>2];Y=Y+1|0;}while((Y|0)<(c[X>>2]|0));fa=c[Z>>2]|0}else{fa=V}ef[c[2016072+(fa<<2)>>2]&4095](A,R,T);if((c[Z>>2]|0)==2){ef[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+5312|0,P+(L*456160|0)+160+(N*52192|0)+15552|0);ef[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+5824|0,P+(L*456160|0)+160+(N*52192|0)+16576|0);ef[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+6336|0,P+(L*456160|0)+160+(N*52192|0)+17600|0);ef[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+6848|0,P+(L*456160|0)+160+(N*52192|0)+18624|0);ef[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+7360|0,P+(L*456160|0)+160+(N*52192|0)+19648|0);ef[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+7872|0,P+(L*456160|0)+160+(N*52192|0)+20672|0);ef[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+8384|0,P+(L*456160|0)+160+(N*52192|0)+21696|0);ef[c[D>>2]&4095](z,P+(L*456160|0)+160+(N*52192|0)+8896|0,P+(L*456160|0)+160+(N*52192|0)+22720|0)}else{ef[c[F>>2]&4095](C,P+(L*456160|0)+160+(N*52192|0)+5312|0,P+(L*456160|0)+160+(N*52192|0)+15552|0)}nrc(T|0,U|0,4096)|0;N=N+1|0;}while((N|0)<(O|0));N=c[w>>2]|0;if((B|0)<(d[N]|0)){K=O+K|0;L=B;M=N}else{break}}}M=c[u>>2]<<13;L=d5a(b,e,M,(M|0)<0|0?-1:0)|0;if((L|0)<0){s=L;i=j;return s|0}L=o+12|0;M=e+24|0;K=e+28|0;C=o+32|0;F=o+20|0;z=o+28|0;D=o+24|0;Z=o+16|0;A=L;fa=b+88|0;da=L;L=k;ea=b+72|0;G=b+412|0;x=o+300|0;aa=o+236|0;$=o+240|0;_=o+244|0;J=n|0;H=o+292|0;m=o+288|0;I=o+4|0;a:while(1){v=c[K>>2]|0;q=(v|0)<0;f=q?0:c[M>>2]|0;N=q?0:v;c[C>>2]=N<<3;c[F>>2]=f;c[z>>2]=f+N;c[D>>2]=f;c[Z>>2]=32;c[A>>2]=0;do{if((c[E>>2]&255|0)==1){if((c[fa>>2]&8388608|0)!=0){ga=32;ha=0;break}c[A>>2]=454672;c[Z>>2]=13;Y2(da);f=0;N=c[A>>2]|0;v=c[Z>>2]|0;while(1){q=a[2438824+f|0]|0;if((v|0)>8){ia=v-8|0;ja=q|N<<8}else{P=je(q>>>((8-v|0)>>>0)|N<<v|0)|0;Q=c[D>>2]|0;y=P;a[Q]=y;y=y>>8;a[Q+1|0]=y;y=y>>8;a[Q+2|0]=y;y=y>>8;a[Q+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;ia=v+24|0;ja=q}c[A>>2]=ja;c[Z>>2]=ia;q=f+1|0;if((q|0)<13){f=q;N=ja;v=ia}else{break}}if((ia|0)>7){ka=ia-7|0;la=ja<<7}else{v=je(ja<<ia|0)|0;N=c[D>>2]|0;y=v;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;ka=ia+25|0;la=0}c[A>>2]=la;c[Z>>2]=ka;ga=ka;ha=la}else{ga=32;ha=0}}while(0);mrc(L|0,0,16)|0;B=c[w>>2]|0;if((a[B]|0)==0){ma=ga}else{O=0;N=0;v=B;B=ha;f=ga;while(1){U=l+(O*56|0)|0;T=N+1|0;R=a[v+T|0]|0;V=R&255;q=R<<24>>24==1;R=q?2:1;Q=c[aa>>2]|0;P=Q+(N*456160|0)|0;if((f|0)>3){na=f-3|0;oa=B<<3|V}else{X=je(V>>>((3-f|0)>>>0)|B<<f|0)|0;Y=c[D>>2]|0;y=X;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;na=f+29|0;oa=V}c[A>>2]=oa;c[Z>>2]=na;Y=k+(V<<2)|0;V=c[Y>>2]|0;c[Y>>2]=V+1;if((na|0)>4){pa=na-4|0;qa=oa<<4|V}else{Y=je(V>>>((4-na|0)>>>0)|oa<<na|0)|0;X=c[D>>2]|0;y=Y;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;pa=na+28|0;qa=V}c[A>>2]=qa;c[Z>>2]=pa;V=0;do{c[n+(V<<2)>>2]=Q+(N*456160|0)+160+(V*52192|0)+5312;V=V+1|0;}while((V|0)<(R|0));mf[c[(c[_>>2]|0)+12>>2]&2047]($,O,J,U);V=0;do{c[H>>2]=V+O;bf[c[c[m>>2]>>2]&15](b,p,Q+(N*456160|0)+160+(V*52192|0)|0,+g[x>>2]);V=V+1|0;}while((V|0)<(R|0));V=P|0;c[V>>2]=0;b:do{if(q){X=O+1|0;if((c[U>>2]|0)!=(c[l+(X*56|0)>>2]|0)){break}if((c[l+(O*56|0)+12>>2]|0)!=(c[l+(X*56|0)+12>>2]|0)){break}c[V>>2]=1;Y=c[l+(O*56|0)+16>>2]|0;S=0;while(1){if((S|0)>=(Y|0)){break b}if((c[l+(O*56|0)+20+(S<<2)>>2]|0)==(c[l+(X*56|0)+20+(S<<2)>>2]|0)){S=S+1|0}else{break}}c[V>>2]=0}}while(0);c[H>>2]=O;U=c[I>>2]|0;do{if((U|0)==0){ra=0}else{if((c[V>>2]|0)==0){ra=0;break}if((U|0)<=0){S=c[(c[m>>2]|0)+12>>2]|0;if((S|0)==0){ra=0;break}jf[S&3](p,P,+g[x>>2]);ra=0;break}S=Q+(N*456160|0)+248|0;X=c[S>>2]|0;if((X|0)<=0){ra=0;break}Y=Q+(N*456160|0)+244|0;W=0;ba=c[Y>>2]|0;sa=X;while(1){if((ba|0)>0){X=W<<4;ta=0;do{a[ta+X+(Q+(N*456160|0)+8)|0]=1;ta=ta+1|0;ua=c[Y>>2]|0;}while((ta|0)<(ua|0));va=ua;wa=c[S>>2]|0}else{va=ba;wa=sa}ta=(d[Q+(N*456160|0)+180+W|0]|0)+W|0;if((ta|0)<(wa|0)){W=ta;ba=va;sa=wa}else{ra=0;break}}}}while(0);do{c[Q+(N*456160|0)+160+(ra*52192|0)+3132>>2]=0;P=Q+(N*456160|0)+160+(ra*52192|0)+88|0;U=c[P>>2]|0;if((U<<4|0)>0){sa=Q+(N*456160|0)+160+(ra*52192|0)+84|0;ba=(ra|0)==0;W=Q+(N*456160|0)+160+(ra*52192|0)+80|0;S=0;Y=0;ta=0;X=c[sa>>2]|0;while(1){c:do{if((X|0)>0){if(ba){xa=0;ya=S;za=X}else{Aa=0;Ba=S;while(1){Ca=(d[(c[W>>2]|0)+Aa|0]|0)+Ba|0;Da=Aa+1|0;if((Da|0)<(X|0)){Aa=Da;Ba=Ca}else{Ea=Ca;Fa=X;break c}}}while(1){do{if((c[V>>2]|0)==0){Ga=za}else{if((a[xa+ta+(Q+(N*456160|0)+8)|0]|0)==0){Ga=za;break}if((a[(c[W>>2]|0)+xa|0]|0)==0){Ga=za;break}else{Ha=0}do{Ba=Ha+ya|0;Aa=Q+(N*456160|0)+5472+(Ba<<2)|0;Ca=Q+(N*456160|0)+57664+(Ba<<2)|0;Ia=+g[Ca>>2];Ja=(+g[Aa>>2]+Ia)*.5;g[Aa>>2]=Ja;g[Ca>>2]=Ja-Ia;Ha=Ha+1|0;}while((Ha|0)<(d[(c[W>>2]|0)+xa|0]|0));Ga=c[sa>>2]|0}}while(0);Ca=(d[(c[W>>2]|0)+xa|0]|0)+ya|0;Aa=xa+1|0;if((Aa|0)<(Ga|0)){xa=Aa;ya=Ca;za=Ga}else{Ea=Ca;Fa=Ga;break}}}else{Ea=S;Fa=X}}while(0);Ca=ta-1|0;Aa=Fa;while(1){if((Aa|0)<=0){break}if((a[Ca+Aa+(Q+(N*456160|0)+160+(ra*52192|0)+5156)|0]|0)==0){break}else{Aa=Aa-1|0}}Ka=(Y|0)>(Aa|0)?Y:Aa;Ca=ta+16|0;La=c[P>>2]|0;if((Ca|0)<(La<<4|0)){S=Ea;Y=Ka;ta=Ca;X=Fa}else{break}}Ma=Ka&255;Na=La}else{Ma=0;Na=U}X=Q+(N*456160|0)+160+(ra*52192|0)|0;a[X]=Ma;if((Na|0)>0){ta=0;Y=Ma;S=Na;while(1){W=Q+(N*456160|0)+160+(ra*52192|0)+20+ta|0;if(Y<<24>>24==0){Oa=0;Pa=S}else{sa=ta<<4;ba=0;do{Ca=(d[W]|0)+ta|0;Ba=ta;while(1){if((Ba|0)>=(Ca|0)){Qa=1;break}if((a[(Ba<<4)+ba+(Q+(N*456160|0)+160+(ra*52192|0)+5156)|0]|0)==0){Qa=0;break}else{Ba=Ba+1|0}}a[ba+sa+(Q+(N*456160|0)+160+(ra*52192|0)+5156)|0]=Qa;ba=ba+1|0;Ra=a[X]|0;}while((ba|0)<(Ra&255|0));Oa=Ra;Pa=c[P>>2]|0}ba=(d[W]|0)+ta|0;if((ba|0)<(Pa|0)){ta=ba;Y=Oa;S=Pa}else{break}}}ra=ra+1|0;}while((ra|0)<(R|0));do{if(q){S=c[V>>2]|0;d:do{if((S|0)!=0){Y=Q+(N*456160|0)+160|0;ta=a[Y]|0;P=Q+(N*456160|0)+52352|0;X=a[P]|0;U=(ta&255)>>>0>(X&255)>>>0?ta:X;a[Y]=U;a[P]=U;P=c[Q+(N*456160|0)+248>>2]|0;Y=P<<4;do{if(!((Y|0)<1|U<<24>>24==0)){X=U&255;ta=0;ba=0;while(1){sa=0;Sa=ba;do{Sa=((a[sa+ta+(Q+(N*456160|0)+8)|0]|0)!=0)+Sa|0;sa=sa+1|0;}while((sa|0)<(X|0));sa=ta+16|0;if((sa|0)<(Y|0)){ta=sa;ba=Sa}else{break}}if((Sa|0)==0){break}ba=(Sa|0)<(ca(X,P)|0);c[Q+(N*456160|0)+4>>2]=ba?1:2;break d}}while(0);c[Q+(N*456160|0)+4>>2]=0}}while(0);P=c[A>>2]|0;Y=c[Z>>2]|0;if((Y|0)>1){Ta=Y-1|0;Ua=P<<1|S}else{U=je(S>>>((1-Y|0)>>>0)|P<<Y|0)|0;P=c[D>>2]|0;y=U;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;Ta=Y+31|0;Ua=S}c[A>>2]=Ua;c[Z>>2]=Ta;if((c[V>>2]|0)==0){Va=0;break}Yjb(p,Q+(N*456160|0)+160|0);Y=Q+(N*456160|0)+4|0;P=c[Y>>2]|0;U=c[A>>2]|0;W=c[Z>>2]|0;if((W|0)>2){Wa=W-2|0;Xa=U<<2|P}else{ba=je(P>>>((2-W|0)>>>0)|U<<W|0)|0;U=c[D>>2]|0;y=ba;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;Wa=W+30|0;Xa=P}c[A>>2]=Xa;c[Z>>2]=Wa;if((c[Y>>2]|0)!=1){Va=0;break}Y=Q+(N*456160|0)+248|0;P=c[Y>>2]|0;if((P|0)<=0){Va=0;break}W=Q+(N*456160|0)+160|0;U=0;ba=a[W]|0;ta=P;P=Xa;sa=Wa;while(1){if(ba<<24>>24==0){Ya=0;Za=ta;_a=P;$a=sa}else{Aa=U<<4;Ba=0;Ca=P;Da=sa;while(1){ab=d[Ba+Aa+(Q+(N*456160|0)+8)|0]|0;if((Da|0)>1){bb=Da-1|0;cb=ab|Ca<<1}else{db=je(ab>>>((1-Da|0)>>>0)|Ca<<Da|0)|0;eb=c[D>>2]|0;y=db;a[eb]=y;y=y>>8;a[eb+1|0]=y;y=y>>8;a[eb+2|0]=y;y=y>>8;a[eb+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;bb=Da+31|0;cb=ab}c[A>>2]=cb;c[Z>>2]=bb;ab=Ba+1|0;fb=a[W]|0;if((ab|0)<(fb&255|0)){Ba=ab;Ca=cb;Da=bb}else{break}}Ya=fb;Za=c[Y>>2]|0;_a=cb;$a=bb}Da=(d[Q+(N*456160|0)+180+U|0]|0)+U|0;if((Da|0)<(Za|0)){U=Da;ba=Ya;ta=Za;P=_a;sa=$a}else{Va=0;break}}}else{Va=0}}while(0);do{c[H>>2]=Va+O;q=Q+(N*456160|0)+160+(Va*52192|0)|0;sa=c[V>>2]|0;P=Q+(N*456160|0)+160+(Va*52192|0)+4644|0;ta=c[P>>2]|0;ba=c[A>>2]|0;U=c[Z>>2]|0;if((U|0)>8){gb=U-8|0;hb=ba<<8|ta}else{Y=je(ta>>>((8-U|0)>>>0)|ba<<U|0)|0;ba=c[D>>2]|0;y=Y;a[ba]=y;y=y>>8;a[ba+1|0]=y;y=y>>8;a[ba+2|0]=y;y=y>>8;a[ba+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;gb=U+24|0;hb=ta}c[A>>2]=hb;c[Z>>2]=gb;if((sa|0)==0){Yjb(p,q|0)}sa=Q+(N*456160|0)+160+(Va*52192|0)+88|0;do{if((c[sa>>2]|0)>0){ta=0;do{U=Q+(N*456160|0)+160+(Va*52192|0)+20+ta|0;te[c[(c[m>>2]|0)+4>>2]&7](p,q,ta,d[U]|0,+g[x>>2]);ta=(d[U]|0)+ta|0;ib=c[sa>>2]|0;}while((ta|0)<(ib|0));if((ib|0)<=0){break}ta=q|0;U=a[ta]|0;ba=c[P>>2]|0;Y=0;W=U;S=ib;Da=U;while(1){if(W<<24>>24==0){jb=ba;kb=0;lb=S;mb=Da}else{U=Y<<4;Ca=ba;Ba=0;Aa=Da;while(1){ab=Ba+U|0;if((a[Q+(N*456160|0)+160+(Va*52192|0)+5156+ab|0]|0)==0){eb=c[Q+(N*456160|0)+160+(Va*52192|0)+4644+(ab<<2)>>2]|0;ab=eb-Ca+60|0;if(!(ab>>>0<121>>>0)){nb=139;break a}db=d[1446024+ab|0]|0;ob=c[1445536+(ab<<2)>>2]|0;ab=c[A>>2]|0;pb=c[Z>>2]|0;if((pb|0)>(db|0)){qb=pb-db|0;rb=ab<<db|ob}else{sb=je(ob>>>((db-pb|0)>>>0)|ab<<pb|0)|0;ab=c[D>>2]|0;y=sb;a[ab]=y;y=y>>8;a[ab+1|0]=y;y=y>>8;a[ab+2|0]=y;y=y>>8;a[ab+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;qb=32-db+pb|0;rb=ob}c[A>>2]=rb;c[Z>>2]=qb;tb=eb;ub=a[ta]|0}else{tb=Ca;ub=Aa}eb=Ba+1|0;if((eb|0)<(ub&255|0)){Ca=tb;Ba=eb;Aa=ub}else{break}}jb=tb;kb=ub;lb=c[sa>>2]|0;mb=ub}Aa=(d[Q+(N*456160|0)+160+(Va*52192|0)+20+Y|0]|0)+Y|0;if((Aa|0)<(lb|0)){ba=jb;Y=Aa;W=kb;S=lb;Da=mb}else{break}}}}while(0);P=Q+(N*456160|0)+160+(Va*52192|0)+3132|0;Da=(c[P>>2]|0)!=0|0;S=c[A>>2]|0;W=c[Z>>2]|0;if((W|0)>1){vb=W-1|0;wb=S<<1|Da}else{Y=je(Da>>>((1-W|0)>>>0)|S<<W|0)|0;S=c[D>>2]|0;y=Y;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;vb=W+31|0;wb=Da}c[A>>2]=wb;c[Z>>2]=vb;Da=c[P>>2]|0;do{if((Da|0)==0){xb=wb;yb=vb}else{W=Da-1|0;if((vb|0)>2){zb=vb-2|0;Ab=W|wb<<2}else{S=je(W>>>((2-vb|0)>>>0)|wb<<vb|0)|0;Y=c[D>>2]|0;y=S;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;zb=vb+30|0;Ab=W}c[A>>2]=Ab;c[Z>>2]=zb;W=c[Q+(N*456160|0)+160+(Va*52192|0)+3136>>2]|0;if((zb|0)>6){Bb=zb-6|0;Cb=W|Ab<<6}else{Y=je(W>>>((6-zb|0)>>>0)|Ab<<zb|0)|0;S=c[D>>2]|0;y=Y;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;Bb=zb+26|0;Cb=W}c[A>>2]=Cb;c[Z>>2]=Bb;if((c[P>>2]|0)>0){Db=0;Eb=Cb;Fb=Bb}else{xb=Cb;yb=Bb;break}while(1){W=c[Q+(N*456160|0)+160+(Va*52192|0)+3140+(Db<<2)>>2]|0;if((Fb|0)>5){Gb=Fb-5|0;Hb=W|Eb<<5}else{S=je(W>>>((5-Fb|0)>>>0)|Eb<<Fb|0)|0;Y=c[D>>2]|0;y=S;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;Gb=Fb+27|0;Hb=W}c[A>>2]=Hb;c[Z>>2]=Gb;W=c[Q+(N*456160|0)+160+(Va*52192|0)+3156+(Db<<2)>>2]|0;if((Gb|0)>4){Ib=Gb-4|0;Jb=W|Hb<<4}else{Y=je(W>>>((4-Gb|0)>>>0)|Hb<<Gb|0)|0;S=c[D>>2]|0;y=Y;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;Ib=Gb+28|0;Jb=W}c[A>>2]=Jb;c[Z>>2]=Ib;W=Db+1|0;if((W|0)<(c[P>>2]|0)){Db=W;Eb=Jb;Fb=Ib}else{xb=Jb;yb=Ib;break}}}}while(0);if((yb|0)>1){Kb=yb-1|0;Lb=xb<<1}else{P=je(xb<<yb|0)|0;Da=c[D>>2]|0;y=P;a[Da]=y;y=y>>8;a[Da+1|0]=y;y=y>>8;a[Da+2|0]=y;y=y>>8;a[Da+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;Kb=yb+31|0;Lb=0}c[A>>2]=Lb;c[Z>>2]=Kb;if((Kb|0)>1){Mb=Kb-1|0;Nb=Lb<<1}else{Da=je(Lb<<Kb|0)|0;P=c[D>>2]|0;y=Da;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;Mb=Kb+31|0;Nb=0}c[A>>2]=Nb;c[Z>>2]=Mb;P=c[sa>>2]|0;if((P|0)>0){Da=q|0;W=Q+(N*456160|0)+160+(Va*52192|0)+80|0;S=a[Da]|0;Y=0;ba=S;ta=P;P=S;while(1){if(ba<<24>>24==0){Ob=0;Pb=ta;Qb=P;Rb=Q+(N*456160|0)+160+(Va*52192|0)+20+Y|0}else{S=Y<<4;Aa=Q+(N*456160|0)+160+(Va*52192|0)+20+Y|0;Ba=0;Ca=0;U=P;while(1){X=Ca+S|0;do{if((a[Q+(N*456160|0)+160+(Va*52192|0)+5156+X|0]|0)==0){if((a[Aa]|0)==0){Sb=U;break}eb=Q+(N*456160|0)+160+(Va*52192|0)+4644+(X<<2)|0;ob=Q+(N*456160|0)+160+(Va*52192|0)+3172+(X<<2)|0;pb=Y;do{Ue[c[(c[m>>2]|0)+8>>2]&3](p,da,Q+(N*456160|0)+160+(Va*52192|0)+5312+((pb<<7)+Ba<<2)|0,d[(c[W>>2]|0)+Ca|0]|0,c[eb>>2]|0,c[ob>>2]|0,+g[x>>2]);pb=pb+1|0;}while((pb|0)<((d[Aa]|0)+Y|0));Sb=a[Da]|0}else{Sb=U}}while(0);X=Ca+1|0;if((X|0)<(Sb&255|0)){Ba=(d[(c[W>>2]|0)+Ca|0]|0)+Ba|0;Ca=X;U=Sb}else{break}}Ob=Sb;Pb=c[sa>>2]|0;Qb=Sb;Rb=Aa}U=(d[Rb]|0)+Y|0;if((U|0)<(Pb|0)){Y=U;ba=Ob;ta=Pb;P=Qb}else{break}}}Va=Va+1|0;}while((Va|0)<(R|0));Q=c[w>>2]|0;if((T|0)>=(d[Q]|0)){break}O=R+O|0;N=T;v=Q;B=c[A>>2]|0;f=c[Z>>2]|0}ma=c[Z>>2]|0}Tb=c[D>>2]|0;Ub=(Tb-(c[F>>2]|0)<<3)+(32-ma)|0;Vb=c[u>>2]|0;if((Ub|0)<=((Vb*6144|0)-3|0)){break}g[x>>2]=+(c[ea>>2]|0)*1024.0/+(c[G>>2]|0)/+(Ub|0)*+g[x>>2]}if((nb|0)==139){KIb(0,0,2351528,(nb=i,i=i+24|0,c[nb>>2]=2289840,c[nb+8>>2]=2239320,c[nb+16>>2]=387,nb)|0);i=nb;Hd();return 0}c[o+276>>2]=(Ub|0)/(Vb|0)|0;Vb=c[A>>2]|0;if((ma|0)>3){Wb=ma-3|0;Xb=Vb<<3|7;Yb=Tb}else{Ub=Tb;y=je(7>>>((3-ma|0)>>>0)|Vb<<ma|0)|0;a[Ub]=y;y=y>>8;a[Ub+1|0]=y;y=y>>8;a[Ub+2|0]=y;y=y>>8;a[Ub+3|0]=y;Ub=(c[D>>2]|0)+4|0;c[D>>2]=Ub;Wb=ma+29|0;Xb=7;Yb=Ub}c[A>>2]=Xb;c[Z>>2]=Wb;if((Wb|0)<32){Ub=Xb<<Wb;c[A>>2]=Ub;Wb=Ub>>>24&255;Ub=Yb;while(1){c[D>>2]=Ub+1;a[Ub]=Wb;Xb=c[A>>2]|0;c[A>>2]=Xb<<8;ma=(c[Z>>2]|0)+8|0;c[Z>>2]=ma;if((ma|0)>=32){break}Wb=Xb>>>16&255;Ub=c[D>>2]|0}Zb=c[D>>2]|0}else{Zb=Yb}c[Z>>2]=32;c[A>>2]=0;A=Zb-(c[F>>2]|0)<<3;c[b+664>>2]=A;if((c[fa>>2]&2|0)==0){Ia=+(c[ea>>2]|0)*1024.0/+(c[G>>2]|0)/+(A|0)*+g[x>>2];g[x>>2]=Ia>65536.0?65536.0:Ia}if(!t){c[r>>2]=(c[r>>2]|0)+1}Gmb(o+304|0,c[b+424>>2]|0,e+8|0,e+48|0);c[K>>2]=32-(c[Z>>2]|0)+((c[D>>2]|0)-(c[F>>2]|0)<<3)>>3;c[h>>2]=1;s=0;i=j;return s|0}function Xjb(a){a=a|0;var b=0;b=c[a+60>>2]|0;PPa(b+36|0);PPa(b+100|0);Nrb(b+240|0);a=c[b+284>>2]|0;if((a|0)!=0){Qrb(a)}mJb(b+4832|0);mJb(b+236|0);Emb(b+304|0);return 0}function Yjb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0;f=b+12|0;g=c[f>>2]|0;h=b+16|0;i=c[h>>2]|0;if((i|0)>1){j=i-1|0;k=g<<1}else{l=je(g<<i|0)|0;g=b+24|0;m=c[g>>2]|0;y=l;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;j=i+31|0;k=0}c[f>>2]=k;c[h>>2]=j;i=e+4|0;g=c[i>>2]|0;if((j|0)>2){n=j-2|0;o=k<<2|g}else{m=je(k<<j|g>>>((2-j|0)>>>0)|0)|0;k=b+24|0;l=c[k>>2]|0;y=m;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[k>>2]=(c[k>>2]|0)+4;n=j+30|0;o=g}c[f>>2]=o;c[h>>2]=n;g=d[e+12|0]|0;if((n|0)>1){p=n-1|0;q=o<<1|g}else{j=je(g>>>((1-n|0)>>>0)|o<<n|0)|0;o=b+24|0;k=c[o>>2]|0;y=j;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;p=n+31|0;q=g}c[f>>2]=q;c[h>>2]=p;g=d[e|0]|0;if((c[i>>2]|0)!=2){if((p|0)>6){r=p-6|0;s=q<<6|g}else{i=je(g>>>((6-p|0)>>>0)|q<<p|0)|0;n=b+24|0;o=c[n>>2]|0;y=i;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;r=p+26|0;s=g}c[f>>2]=s;c[h>>2]=r;if((r|0)>1){t=r-1|0;u=s<<1}else{n=je(s<<r|0)|0;s=b+24|0;o=c[s>>2]|0;y=n;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;t=r+31|0;u=0}c[f>>2]=u;c[h>>2]=t;return}if((p|0)>4){v=p-4|0;w=q<<4|g;x=b+24|0}else{t=je(g>>>((4-p|0)>>>0)|q<<p|0)|0;q=b+24|0;b=c[q>>2]|0;y=t;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;v=p+28|0;w=g;x=q}c[f>>2]=w;c[h>>2]=v;q=1;g=w;w=v;while(1){v=(a[e+20+q|0]|0)==0|0;if((w|0)>1){z=w-1|0;A=g<<1|v}else{p=je(v>>>((1-w|0)>>>0)|g<<w|0)|0;b=c[x>>2]|0;y=p;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;z=w+31|0;A=v}c[f>>2]=A;c[h>>2]=z;v=q+1|0;if((v|0)<8){q=v;g=A;w=z}else{break}}return}function Zjb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=(a[d+13|0]|0)!=0?8817248:6282648;mf[c[b>>2]&2047](d+15552|0,e,(a[d+12|0]|0)!=0?8817248:6282648,1024);mf[c[b+24>>2]&2047](d+19648|0,e+4096|0,f,1024);return}function _jb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=(a[d+12|0]|0)!=0?8816736:6282136;mf[c[b>>2]&2047](d+15552|0,e,(a[d+13|0]|0)!=0?8817248:6282648,1024);nrc(d+19648|0,e+4096|0,1792)|0;mf[c[b+24>>2]&2047](d+21440|0,e+5888|0,f,128);mrc(d+21952|0,0,1792)|0;return}function $jb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=(a[d+12|0]|0)!=0?8816736:6282136;g=(a[d+13|0]|0)!=0?8816736:6282136;h=b|0;i=b+24|0;mf[c[h>>2]&2047](d+15552|0,e+1792|0,f,128);b=e+2304|0;mf[c[i>>2]&2047](d+16064|0,b,f,128);mf[c[h>>2]&2047](d+16576|0,b,g,128);b=e+2816|0;mf[c[i>>2]&2047](d+17088|0,b,f,128);mf[c[h>>2]&2047](d+17600|0,b,g,128);b=e+3328|0;mf[c[i>>2]&2047](d+18112|0,b,f,128);mf[c[h>>2]&2047](d+18624|0,b,g,128);b=e+3840|0;mf[c[i>>2]&2047](d+19136|0,b,f,128);mf[c[h>>2]&2047](d+19648|0,b,g,128);b=e+4352|0;mf[c[i>>2]&2047](d+20160|0,b,f,128);mf[c[h>>2]&2047](d+20672|0,b,g,128);b=e+4864|0;mf[c[i>>2]&2047](d+21184|0,b,f,128);mf[c[h>>2]&2047](d+21696|0,b,g,128);b=e+5376|0;mf[c[i>>2]&2047](d+22208|0,b,f,128);mf[c[h>>2]&2047](d+22720|0,b,g,128);mf[c[i>>2]&2047](d+23232|0,e+5888|0,f,128);return}function akb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=(a[d+12|0]|0)!=0?8817248:6282648;g=(a[d+13|0]|0)!=0?8816736:6282136;mrc(d+15552|0,0,1792)|0;mf[c[b>>2]&2047](d+17344|0,e+1792|0,g,128);nrc(d+17856|0,e+2304|0,1792)|0;mf[c[b+24>>2]&2047](d+19648|0,e+4096|0,f,1024);return}function bkb(){var a=0;c[846881]=8808920;c[846883]=1098;$2(3387520,9,121,522280,1,1,521792,4,4,0,0,0,4)|0;c[846886]=8804552;c[846888]=1092;$2(3387540,9,121,1488104,1,1,1487616,4,4,0,0,0,4)|0;c[846891]=8801480;c[846893]=768;$2(3387560,9,49,521416,1,1,521216,4,4,0,0,0,4)|0;c[846896]=8797376;c[846898]=1026;$2(3387580,9,49,1487240,1,1,1487040,4,4,0,0,0,4)|0;c[846901]=8793144;c[846903]=1058;$2(3387600,9,63,521728,1,1,521472,4,4,0,0,0,4)|0;c[846906]=8788936;c[846908]=1052;$2(3387620,9,63,1487552,1,1,1487296,4,4,0,0,0,4)|0;c[846911]=8786760;c[846913]=544;$2(3387640,9,25,521184,1,1,521128,2,2,0,0,0,4)|0;c[846916]=8784584;c[846918]=544;$2(3387660,9,25,1487008,1,1,1486952,2,2,0,0,0,4)|0;c[846921]=8782216;c[846923]=592;$2(3387680,9,63,521064,1,1,520936,2,2,0,0,0,4)|0;c[846926]=8780168;c[846928]=512;$2(3387700,9,25,520904,1,1,520872,1,1,0,0,0,4)|0;a=1;do{g[608904+(a+320<<2)>>2]=+g[608904+(320-a<<2)>>2];a=a+1|0;}while((a|0)<320);g[152610]=-0.0- +g[152610];g[152738]=-0.0- +g[152738];a=0;do{g[5122448+(a<<2)>>2]=+g[608904+(a<<1<<2)>>2];a=a+1|0;}while((a|0)<320);lub();return}function ckb(a,b){a=a|0;b=b|0;if((c[b+343668>>2]|0)!=0){return}a=b+68|0;c[b+64>>2]=c[a>>2];c[b+4>>2]=0;c[a>>2]=32;c[b+76>>2]=0;c[b+102312>>2]=-1;c[b+14664>>2]=-1;mrc(b+12|0,-1|0,6)|0;c[b+14656>>2]=1152;c[b+102304>>2]=1152;OPa(b+343648|0,7,1,4.76837158203125e-7)|0;OPa(b+343584|0,7,1,-65536.0)|0;mub(b+175392|0);etb(b+343712|0);c[b+343768>>2]=182;c[b+343772>>2]=268;c[b+343776>>2]=48;c[b+343780>>2]=4;return}function dkb(a){a=a|0;PPa(a+343648|0);PPa(a+343584|0);return}function ekb(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0.0,W=0.0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0.0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0;m=i;i=i+272|0;n=m|0;o=m+32|0;p=m+136|0;q=m+248|0;r=q;s=h;c[r>>2]=c[s>>2];c[r+4>>2]=c[s+4>>2];c[r+8>>2]=c[s+8>>2];c[r+12>>2]=c[s+12>>2];c[r+16>>2]=c[s+16>>2];s=(k<<3)-4|0;r=h+8|0;t=c[r>>2]|0;u=-t|0;v=(c[h+16>>2]|0)-t|0;if((s|0)<(u|0)){w=u}else{w=(v|0)<(s|0)?v:s}c[r>>2]=w+t;t=g+8|0;c[t>>2]=0;w=g|0;if((c[w>>2]|0)==0){c[w>>2]=c[f+6512>>2]<<1}r=f+6532|0;if((c[r>>2]|0)==0){c[r>>2]=c[f+6512>>2]<<1}r=q+8|0;s=c[r>>2]|0;v=c[q+16>>2]|0;if((j|0)==0){x=1;z=s}else{j=s+10|0;s=v>>>0>j>>>0?j:v;c[r>>2]=s;x=11;z=s}s=g+68|0;c[g+64>>2]=c[s>>2];r=g+76|0;c[g+72>>2]=c[r>>2];c[g+80>>2]=1;j=q+8|0;u=q|0;h=c[u>>2]|0;A=d[h+(z>>>3)|0]|0;B=q+16|0;C=((z|0)<(v|0))+z|0;c[j>>2]=C;if((A&128>>>((z&7)>>>0)|0)==0){D=x}else{z=m+240|0;A=g+24|0;E=c[A>>2]|0;c[g+4>>2]=1;F=g+12|0;a[z]=a[F]|0;a[z+1|0]=a[F+1|0]|0;a[z+2|0]=a[F+2|0]|0;a[z+3|0]=a[F+3|0]|0;a[z+4|0]=a[F+4|0]|0;a[z+5|0]=a[F+5|0]|0;G=d[h+(C>>>3)|0]<<(C&7)>>>7;H=((C|0)<(v|0))+C|0;c[j>>2]=H;c[g+20>>2]=G&1;G=h+(H>>>3)|0;I=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>28;G=H+4|0;H=v>>>0>G>>>0?G:v;c[j>>2]=H;a[F]=I;I=h+(H>>>3)|0;G=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(H&7)>>>28;I=H+4|0;H=v>>>0>I>>>0?I:v;c[j>>2]=H;a[g+13|0]=G;G=h+(H>>>3)|0;I=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>29;G=H+3|0;a[g+14|0]=I;I=(v>>>0>G>>>0?G:v)+2|0;G=v>>>0>I>>>0?I:v;c[j>>2]=G;I=d[h+(G>>>3)|0]|0;H=((G|0)<(v|0))+G|0;c[j>>2]=H;J=d[h+(H>>>3)|0]|0;K=((H|0)<(v|0))+H|0;c[j>>2]=K;if((128>>>((G&7)>>>0)&I|0)==0){a[g+15|0]=2;a[g+16|0]=1;a[g+17|0]=2;L=K}else{I=h+(K>>>3)|0;G=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(K&7)>>>30;I=K+2|0;K=v>>>0>I>>>0?I:v;c[j>>2]=K;a[g+15|0]=G;G=d[h+(K>>>3)|0]<<(K&7)>>>7;I=((K|0)<(v|0))+K|0;c[j>>2]=I;a[g+16|0]=G&1;G=h+(I>>>3)|0;K=(je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(I&7)>>>30;G=I+2|0;I=v>>>0>G>>>0?G:v;c[j>>2]=I;a[g+17|0]=K;L=I}if((grc(z,F,6)|0)!=0){c[t>>2]=1}if((128>>>((H&7)>>>0)&J|0)==0){c[A>>2]=2;c[g+28>>2]=2;c[g+32>>2]=1;c[g+36>>2]=1;M=2;N=L}else{J=h+(L>>>3)|0;H=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(L&7)>>>30;J=L+2|0;L=v>>>0>J>>>0?J:v;c[j>>2]=L;c[A>>2]=H;A=h+(L>>>3)|0;J=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(L&7)>>>30;A=L+2|0;L=v>>>0>A>>>0?A:v;c[j>>2]=L;c[g+28>>2]=J;J=d[h+(L>>>3)|0]<<(L&7)>>>7;A=((L|0)<(v|0))+L|0;c[j>>2]=A;c[g+32>>2]=J&1;J=d[h+(A>>>3)|0]<<(A&7)>>>7;h=((A|0)<(v|0))+A|0;c[j>>2]=h;c[g+36>>2]=J&1;M=H;N=h}do{if((M|0)==(E|0)){O=N}else{if((c[t>>2]|0)!=0){O=N;break}okb(g);O=c[j>>2]|0}}while(0);D=x-C+O|0}a:do{if((c[t>>2]|0)!=0){O=n;C=o;x=c[w>>2]|0;if((x|0)<32e3){P=3e3}else{P=(x|0)<64e3?4e3:5e3}if((x|0)==24e3){Q=611496;R=32}else if((x|0)==16e3){Q=611464;R=32}else if((x|0)==22050){Q=611480;R=32}else if((x|0)==88200|(x|0)==96e3|(x|0)==128e3|(x|0)==176400|(x|0)==192e3){Q=611544;R=32}else if((x|0)==32e3){Q=611512;R=32}else if((x|0)==44100|(x|0)==48e3|(x|0)==64e3){Q=611528;R=32}else{KIb(c[f+4>>2]|0,16,2401632,(S=i,i=i+8|0,c[S>>2]=x,S)|0);i=S;U=g+12|0}b:do{if((R|0)==32){N=x>>1;E=(((P<<8)+N|0)>>>0)/(x>>>0)|0;M=g+12|0;h=(a[Q+(d[M]|0)|0]|0)+((((P<<7)+N|0)>>>0)/(x>>>0)|0)|0;N=g+44|0;c[N>>2]=h;H=g+13|0;J=a[H]|0;A=J&255;do{if((J&255)>>>0<14>>>0){v=g+52|0;c[v>>2]=E;V=+(E|0);W=+T(+(64.0/V),+.07692307978868484);X=V*W;L=Lc(+X)|0;b[n>>1]=L-E;V=W*X;F=Lc(+V)|0;b[n+2>>1]=F-L;X=W*V;L=Lc(+X)|0;b[n+4>>1]=L-F;V=W*X;F=Lc(+V)|0;b[n+6>>1]=F-L;X=W*V;L=Lc(+X)|0;b[n+8>>1]=L-F;V=W*X;F=Lc(+V)|0;b[n+10>>1]=F-L;X=W*V;L=Lc(+X)|0;b[n+12>>1]=L-F;V=W*X;F=Lc(+V)|0;b[n+14>>1]=F-L;X=W*V;L=Lc(+X)|0;b[n+16>>1]=L-F;V=W*X;F=Lc(+V)|0;b[n+18>>1]=F-L;X=W*V;L=Lc(+X)|0;b[n+20>>1]=L-F;F=Lc(+(W*X))|0;b[n+22>>1]=F-L;b[n+24>>1]=64-F;cd(O|0,13,2,116);F=a[H]|0;L=c[v>>2]|0;if(F<<24>>24==0){Y=L}else{z=F&255;F=0;I=L;do{I=(b[n+(F<<1)>>1]|0)+I|0;F=F+1|0;}while((F|0)<(z|0));c[v>>2]=I;Y=I}Z=Y;_=c[w>>2]|0}else{if((J<<24>>24|0)==15){z=h*3|0;c[g+52>>2]=z;Z=z;_=x;break}else if((J<<24>>24|0)==14){z=h<<1;c[g+52>>2]=z;Z=z;_=x;break}else{KIb(c[f+4>>2]|0,16,2394880,(S=i,i=i+8|0,c[S>>2]=A,S)|0);i=S;U=M;break b}}}while(0);A=g+52|0;h=Z>>>0<64>>>0?Z:64;c[A>>2]=h;do{if((_|0)<32001){$=48}else{if((_|0)==44100){$=35;break}if((_|0)>47999){$=32;break}KIb(0,0,2387768,(S=i,i=i+24|0,c[S>>2]=2380856,c[S+8>>2]=2374456,c[S+16>>2]=403,S)|0);i=S;Hd();return 0}}while(0);J=c[N>>2]|0;H=h-J|0;if(H>>>0>$>>>0){KIb(c[f+4>>2]|0,16,2367208,(S=i,i=i+8|0,c[S>>2]=H,S)|0);i=S;U=M;break}E=a[g+15|0]|0;do{if(E<<24>>24==0){z=(d[g+16|0]|0)+1|0;F=((z&2)+H|0)>>>(z>>>0)<<1;L=g+84|0;c[L>>2]=F;K=c[f+4>>2]|0;G=d[g+14|0]|0;if((F|0)<1){KIb(K,16,2332760,(S=i,i=i+8|0,c[S>>2]=F,S)|0);i=S;U=M;break b}if((G|0)>=(F|0)){KIb(K,16,2327312,(S=i,i=i+8|0,c[S>>2]=G,S)|0);i=S;U=M;break b}if((F|0)==0){aa=h;ba=J;da=0}else{F=z&65535;G=1;do{b[g+262896+(G<<1)>>1]=F;G=G+1|0;ea=c[L>>2]|0;}while(!(G>>>0>ea>>>0));aa=c[A>>2]|0;ba=c[N>>2]|0;da=ea}G=aa-ba|0;F=ca(da,z)|0;I=G-F|0;do{if((I|0)<0){v=g+262898|0;b[v>>1]=(b[v>>1]|0)-1;v=g+262900|0;b[v>>1]=(b[v>>1]|0)-((I|0)<-1);fa=ba&65535;ga=da}else{if((G|0)==(F|0)){fa=ba&65535;ga=da;break}v=g+262896+(da<<1)|0;b[v>>1]=(b[v>>1]|0)+1;fa=c[N>>2]&65535;ga=c[L>>2]|0}}while(0);b[g+262896>>1]=fa;if((ga|0)==0){ha=0;break}else{ia=1;ja=fa}while(1){F=g+262896+(ia<<1)|0;G=(b[F>>1]|0)+ja&65535;b[F>>1]=G;F=ia+1|0;I=c[L>>2]|0;if(F>>>0>I>>>0){ha=I;break}else{ia=F;ja=G}}}else{if((h*49|0)>>>0>(J*110|0)>>>0){L=J<<1;c[g+48>>2]=L;ka=1;la=L}else{c[g+48>>2]=h;ka=0;la=h}X=+(7-(E&255)|0);L=g+48|0;G=Lc(+(X*+lc(+(+(la>>>0>>>0)/+(J>>>0>>>0)))))|0;F=G<<1;if((F|0)<1){KIb(c[f+4>>2]|0,16,2352456,(S=i,i=i+8|0,c[S>>2]=F,S)|0);i=S;U=M;break b}I=o|0;b[I>>1]=0;z=o+2|0;v=c[N>>2]|0;K=c[L>>2]|0;W=+(v|0);V=+T(+(+(K|0)/W),+(1.0/+(F|0)));ma=F-1|0;if((ma|0)>0){na=v;oa=0;pa=W;while(1){W=V*pa;qa=Lc(+W)|0;ra=oa+1|0;b[o+(ra<<1)>>1]=qa-na;if((ra|0)<(ma|0)){na=qa;oa=ra;pa=W}else{sa=qa;break}}}else{sa=v}oa=o+(F<<1)|0;b[oa>>1]=K-sa;cd(z|0,F|0,2,116);na=b[oa>>1]|0;oa=c[N>>2]&65535;b[I>>1]=oa;ma=1;qa=oa;while(1){oa=o+(ma<<1)|0;ta=b[oa>>1]|0;if(ta<<16>>16<1){R=72;break}ra=ta+qa&65535;b[oa>>1]=ra;oa=ma+1|0;if((oa|0)>(F|0)){break}else{ma=oa;qa=ra}}if((R|0)==72){KIb(c[f+4>>2]|0,16,2344424,(S=i,i=i+16|0,c[S>>2]=ma,c[S+8>>2]=ta<<16>>16,S)|0);i=S;U=M;break b}if((ka|0)==0){c[g+84>>2]=F;qa=d[g+14|0]|0;if((qa|0)<(F|0)){nrc(g+262896|0,C|0,G<<2|2)|0;ha=F;break}else{KIb(c[f+4>>2]|0,16,2327312,(S=i,i=i+8|0,c[S>>2]=qa,S)|0);i=S;U=M;break b}}pa=X*((a[g+16|0]|0)!=0?.7692307829856873:1.0);qa=Lc(+(pa*+lc(+(+((c[A>>2]|0)>>>0>>>0)/+((c[L>>2]|0)>>>0>>>0)))))|0;I=qa<<1;z=p|0;K=p+2|0;v=c[L>>2]|0;ra=c[A>>2]|0;pa=+(v|0);V=+T(+(+(ra|0)/pa),+(1.0/+(I|0)));oa=I-1|0;if((oa|0)>0){ua=v;va=0;W=pa;while(1){pa=V*W;wa=Lc(+pa)|0;xa=va+1|0;b[p+(xa<<1)>>1]=wa-ua;if((xa|0)<(oa|0)){ua=wa;va=xa;W=pa}else{ya=wa;break}}}else{ya=v}va=p+(I<<1)|0;b[va>>1]=ra-ya;ua=b[K>>1]|0;if((I|0)>1){oa=1;G=ua;while(1){ma=oa+1|0;wa=b[p+(ma<<1)>>1]|0;xa=(wa|0)>(G|0)?G:wa;if((ma|0)<(I|0)){oa=ma;G=xa}else{za=xa;break}}}else{za=ua}G=K;if((za|0)<(na|0)){cd(G|0,I|0,2,116);oa=b[K>>1]|0;ra=oa<<16>>16;v=na-ra|0;xa=b[va>>1]|0;ma=(xa<<16>>16)-ra>>1;ra=(v|0)>(ma|0)?ma:v;b[K>>1]=ra+(oa&65535);b[va>>1]=(xa&65535)-ra}cd(G|0,I|0,2,116);ra=c[L>>2]&65535;b[z>>1]=ra;c:do{if((I|0)>=1){xa=1;oa=ra;while(1){v=p+(xa<<1)|0;Aa=b[v>>1]|0;if(Aa<<16>>16<1){break}ma=Aa+oa&65535;b[v>>1]=ma;v=xa+1|0;if((v|0)>(I|0)){break c}else{xa=v;oa=ma}}KIb(c[f+4>>2]|0,16,2338432,(S=i,i=i+16|0,c[S>>2]=xa,c[S+8>>2]=Aa<<16>>16,S)|0);i=S;U=M;break b}}while(0);ra=I+F|0;z=g+84|0;c[z>>2]=ra;L=c[f+4>>2]|0;va=d[g+14|0]|0;if((ra|0)<1){KIb(L,16,2332760,(S=i,i=i+8|0,c[S>>2]=ra,S)|0);i=S;U=M;break b}if((va|0)<(ra|0)){ra=F|1;nrc(g+262896|0,C|0,ra<<1)|0;nrc(g+262896+(ra<<1)|0,G|0,qa<<2)|0;ha=c[z>>2]|0;break}else{KIb(L,16,2327312,(S=i,i=i+8|0,c[S>>2]=va,S)|0);i=S;U=M;break b}}}while(0);J=g+84|0;E=d[g+14|0]|0;h=ha-E|0;c[g+262884>>2]=h;H=(h+1|0)>>>1;va=g+262880|0;c[va>>2]=H;L=g+263044|0;nrc(L|0,g+262896+(E<<1)|0,(h<<1)+2|0)|0;E=b[g+263044+(h<<1)>>1]|0;z=E&65535;ra=b[L>>1]|0;L=ra&65535;c[r>>2]=z-L;c[s>>2]=L;if((E&65535)>>>0>64>>>0){KIb(c[f+4>>2]|0,16,2439760,(S=i,i=i+8|0,c[S>>2]=z,S)|0);i=S;U=M;break}if((ra&65535)>>>0>32>>>0){KIb(c[f+4>>2]|0,16,2428824,(S=i,i=i+8|0,c[S>>2]=L,S)|0);i=S;U=M;break}z=g+262994|0;b[z>>1]=ra;ra=h&1;if((H|0)==0){Ba=L}else{L=1;do{b[g+262994+(L<<1)>>1]=b[g+263044+((L<<1)-ra<<1)>>1]|0;L=L+1|0;}while(!(L>>>0>(c[va>>2]|0)>>>0));Ba=c[s>>2]|0}L=g+17|0;W=+(d[L]|0);do{if((Lc(+(W*+lc(+(+((c[A>>2]|0)>>>0>>>0)/+(Ba>>>0>>>0)))))|0)<1){ra=g+262888|0;c[ra>>2]=1;Ca=ra}else{V=+(d[L]|0);ra=Lc(+(V*+lc(+(+((c[A>>2]|0)>>>0>>>0)/+((c[s>>2]|0)>>>0>>>0)))))|0;H=g+262888|0;c[H>>2]=ra;if(!(ra>>>0>5>>>0)){Ca=H;break}KIb(c[f+4>>2]|0,16,2418208,(S=i,i=i+8|0,c[S>>2]=ra,S)|0);i=S;U=M;break b}}while(0);b[g+263142>>1]=b[z>>1]|0;A=c[Ca>>2]|0;if((A|0)!=0){L=1;ra=0;H=A;do{ra=((((c[va>>2]|0)-ra|0)>>>0)/((H+1-L|0)>>>0)|0)+ra|0;b[g+263142+(L<<1)>>1]=b[g+262994+(ra<<1)>>1]|0;L=L+1|0;H=c[Ca>>2]|0;}while(!(L>>>0>H>>>0))}H=c[N>>2]|0;L=c[s>>2]|0;ra=c[w>>2]|0;va=((ra>>1)+2048e3|0)/(ra|0)|0;ra=g+263216|0;c[ra>>2]=0;if(va>>>0<((c[r>>2]|0)+L|0)>>>0){z=0;while(1){if((e[g+262896+(z<<1)>>1]|0)<(va|0)){z=z+1|0}else{Da=L;Ea=H;Fa=0;Ga=z;Ha=0;Ia=H;break}}}else{Da=L;Ea=H;Fa=0;Ga=c[J>>2]|0;Ha=0;Ia=H}while(1){z=Ia-1+Ea|0;va=0;A=Fa;h=Ga;while(1){if((h|0)!=(Ga|0)){if(!(A>>>0>(z-va|0)>>>0)){break}}E=e[g+262896+(h<<1)>>1]|0;va=E+Ia&1;A=E;h=h-1|0}if(Ha>>>0>5>>>0){R=124;break}h=A-Da|0;a[g+263220+Ha|0]=(h|0)>0?h&255:0;h=c[ra>>2]|0;a[g+263226+h|0]=(c[N>>2]|0)-va-(d[g+263220+h|0]|0);h=c[ra>>2]|0;if((a[g+263220+h|0]|0)==0){Ja=Da;Ka=c[s>>2]|0;La=h}else{z=h+1|0;c[ra>>2]=z;Ja=A;Ka=A;La=z}if(((e[g+262896+(Ga<<1)>>1]|0)-A|0)<3){Ma=c[J>>2]|0}else{Ma=Ga}if((A|0)==((c[r>>2]|0)+(c[s>>2]|0)|0)){break}Da=Ja;Ea=Ka;Fa=A;Ga=Ma;Ha=La;Ia=c[N>>2]|0}if((R|0)==124){KIb(c[f+4>>2]|0,16,2409376,(S=i,i=i+8|0,c[S>>2]=Ha,S)|0);i=S;U=M;break}do{if(La>>>0>1>>>0){N=La-1|0;if(!((d[g+263220+N|0]|0)>>>0<3>>>0)){break}c[ra>>2]=N}}while(0);okb(g);c[g+87736>>2]=0;c[g+175384>>2]=0;break a}}while(0);KIb(c[f+4>>2]|0,16,2456920,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;c[g+4>>2]=0;c[s>>2]=32;c[r>>2]=0;c[g+102312>>2]=-1;c[g+14664>>2]=-1;mrc(U|0,-1|0,6)|0}}while(0);U=g+4|0;if((c[U>>2]|0)==0){Na=D}else{La=c[j>>2]|0;do{if((l|0)==1){Ha=c[u>>2]|0;Ia=c[B>>2]|0;Ma=((La|0)<(Ia|0))+La|0;if((d[Ha+(La>>>3)|0]&128>>>((La&7)>>>0)|0)==0){Oa=Ma}else{Ga=Ma+8|0;Oa=Ia>>>0>Ga>>>0?Ga:Ia}c[j>>2]=Oa;Ga=d[Ha+(Oa>>>3)|0]<<(Oa&7)>>>7;c[j>>2]=((Oa|0)<(Ia|0))+Oa;Ia=Ga&1;c[g+40>>2]=Ia;Ga=g+96|0;Ha=(lkb(f,g,q,Ga)|0)!=0;do{if((Ia|0)==0){if(Ha){R=193;break}Ma=g+87744|0;if((lkb(f,g,q,Ma)|0)!=0){R=193;break}Fa=c[g+104>>2]|0;if((Fa|0)>0){Ka=c[u>>2]|0;Ea=c[B>>2]|0;Ja=0;Da=c[j>>2]|0;do{w=d[Ka+(Da>>>3)|0]<<(Da&7)>>>7;Da=((Da|0)<(Ea|0))+Da|0;c[j>>2]=Da;a[g+120+Ja|0]=w&1;Ja=Ja+1|0;}while((Ja|0)<(Fa|0))}Fa=c[g+116>>2]|0;if((Fa|0)>0){Ja=c[u>>2]|0;Da=c[B>>2]|0;Ea=0;Ka=c[j>>2]|0;do{w=d[Ja+(Ka>>>3)|0]<<(Ka&7)>>>7;Ka=((Ka|0)<(Da|0))+Ka|0;c[j>>2]=Ka;a[g+125+Ea|0]=w&1;Ea=Ea+1|0;}while((Ea|0)<(Fa|0))}Fa=c[g+87752>>2]|0;if((Fa|0)>0){Ea=c[u>>2]|0;Ka=c[B>>2]|0;Da=0;Ja=c[j>>2]|0;do{w=d[Ea+(Ja>>>3)|0]<<(Ja&7)>>>7;Ja=((Ja|0)<(Ka|0))+Ja|0;c[j>>2]=Ja;a[g+87768+Da|0]=w&1;Da=Da+1|0;}while((Da|0)<(Fa|0))}Fa=c[g+87764>>2]|0;if((Fa|0)>0){Da=c[u>>2]|0;Ja=c[B>>2]|0;Ka=0;Ea=c[j>>2]|0;do{w=d[Da+(Ea>>>3)|0]<<(Ea&7)>>>7;Ea=((Ea|0)<(Ja|0))+Ea|0;c[j>>2]=Ea;a[g+87773+Ka|0]=w&1;Ka=Ka+1|0;}while((Ka|0)<(Fa|0))}Fa=g+132|0;Ka=g+127|0;a[Fa]=a[Ka]|0;a[Fa+1|0]=a[Ka+1|0]|0;a[Fa+2|0]=a[Ka+2|0]|0;a[Fa+3|0]=a[Ka+3|0]|0;a[Fa+4|0]=a[Ka+4|0]|0;Ka=g+262888|0;do{if((c[Ka>>2]|0)==0){Fa=g+87780|0;Ea=g+87775|0;a[Fa]=a[Ea]|0;a[Fa+1|0]=a[Ea+1|0]|0;a[Fa+2|0]=a[Ea+2|0]|0;a[Fa+3|0]=a[Ea+3|0]|0;a[Fa+4|0]=a[Ea+4|0]|0}else{Ea=c[B>>2]|0;Fa=c[u>>2]|0;Ja=0;Da=c[j>>2]|0;do{w=Fa+(Da>>>3)|0;Ca=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(Da&7)>>>30;w=Da+2|0;Da=Ea>>>0>w>>>0?w:Ea;c[j>>2]=Da;a[g+127+Ja|0]=Ca;Ja=Ja+1|0;Pa=c[Ka>>2]|0;}while(Ja>>>0<Pa>>>0);Ja=g+87780|0;A=g+87775|0;a[Ja]=a[A]|0;a[Ja+1|0]=a[A+1|0]|0;a[Ja+2|0]=a[A+2|0]|0;a[Ja+3|0]=a[A+3|0]|0;a[Ja+4|0]=a[A+4|0]|0;if((Pa|0)==0){break}else{Qa=0;Ra=Da}do{A=Fa+(Ra>>>3)|0;Ja=(je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0)<<(Ra&7)>>>30;A=Ra+2|0;Ra=Ea>>>0>A>>>0?A:Ea;c[j>>2]=Ra;a[g+87775+Qa|0]=Ja;Qa=Qa+1|0;}while(Qa>>>0<(c[Ka>>2]|0)>>>0)}}while(0);mkb(g,q,Ga,0);mkb(g,q,Ma,1);nkb(g,q,Ga,0);nkb(g,q,Ma,1)}else{if(Ha){R=193;break}Ka=g+87744|0;Ea=g+87752|0;Fa=c[Ea>>2]|0;a[g+87756|0]=a[g+87756+Fa|0]|0;a[g+175380|0]=a[g+175372+Fa|0]|0;Da=g+102312|0;c[g+102308>>2]=-((c[Da>>2]|0)!=(Fa|0)|0);Fa=g+87757|0;Ja=g+109|0;a[Fa]=a[Ja]|0;a[Fa+1|0]=a[Ja+1|0]|0;a[Fa+2|0]=a[Ja+2|0]|0;a[Fa+3|0]=a[Ja+3|0]|0;a[Fa+4|0]=a[Ja+4|0]|0;a[Fa+5|0]=a[Ja+5|0]|0;Ja=g+87724|0;Fa=g+175372|0;A=Ja|0;va=Ja+4|0;Ja=d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0;va=Fa|0;y=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=Fa+4|0;y=Ja;a[va]=y;y=y>>8;a[va+1|0]=y;y=y>>8;a[va+2|0]=y;y=y>>8;a[va+3|0]=y;va=g+175381|0;Ja=g+87733|0;a[va]=a[Ja]|0;a[va+1|0]=a[Ja+1|0]|0;a[va+2|0]=a[Ja+2|0]|0;Ja=c[g+104>>2]|0;c[Ea>>2]=Ja;c[g+87836>>2]=c[g+188>>2];va=g+116|0;Fa=c[va>>2]|0;A=g+87764|0;c[A>>2]=Fa;c[Ka>>2]=c[Ga>>2];c[Da>>2]=c[g+14664>>2];if((Ja|0)>0){Da=c[u>>2]|0;Ca=c[B>>2]|0;w=0;Ba=c[j>>2]|0;do{ha=d[Da+(Ba>>>3)|0]<<(Ba&7)>>>7;Ba=((Ba|0)<(Ca|0))+Ba|0;c[j>>2]=Ba;a[g+120+w|0]=ha&1;w=w+1|0;}while((w|0)<(Ja|0));Sa=c[va>>2]|0}else{Sa=Fa}if((Sa|0)>0){Ja=c[u>>2]|0;w=c[B>>2]|0;Ba=0;Ca=c[j>>2]|0;do{Da=d[Ja+(Ca>>>3)|0]<<(Ca&7)>>>7;Ca=((Ca|0)<(w|0))+Ca|0;c[j>>2]=Ca;a[g+125+Ba|0]=Da&1;Ba=Ba+1|0;}while((Ba|0)<(Sa|0))}Ba=c[Ea>>2]|0;if((Ba|0)>0){Ca=c[u>>2]|0;w=c[B>>2]|0;Ja=0;Fa=c[j>>2]|0;do{va=d[Ca+(Fa>>>3)|0]<<(Fa&7)>>>7;Fa=((Fa|0)<(w|0))+Fa|0;c[j>>2]=Fa;a[g+87768+Ja|0]=va&1;Ja=Ja+1|0;}while((Ja|0)<(Ba|0))}Ba=c[A>>2]|0;if((Ba|0)>0){Ja=c[u>>2]|0;Fa=c[B>>2]|0;w=0;Ca=c[j>>2]|0;do{Ea=d[Ja+(Ca>>>3)|0]<<(Ca&7)>>>7;Ca=((Ca|0)<(Fa|0))+Ca|0;c[j>>2]=Ca;a[g+87773+w|0]=Ea&1;w=w+1|0;}while((w|0)<(Ba|0))}Ba=g+132|0;w=g+127|0;a[Ba]=a[w]|0;a[Ba+1|0]=a[w+1|0]|0;a[Ba+2|0]=a[w+2|0]|0;a[Ba+3|0]=a[w+3|0]|0;a[Ba+4|0]=a[w+4|0]|0;Ba=g+262888|0;if((c[Ba>>2]|0)!=0){Ca=c[B>>2]|0;Fa=c[u>>2]|0;Ja=0;A=c[j>>2]|0;do{Ea=Fa+(A>>>3)|0;va=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(A&7)>>>30;Ea=A+2|0;A=Ca>>>0>Ea>>>0?Ea:Ca;c[j>>2]=A;a[g+127+Ja|0]=va;Ja=Ja+1|0;}while(Ja>>>0<(c[Ba>>2]|0)>>>0)}Ba=g+87780|0;Ja=g+87775|0;a[Ba]=a[Ja]|0;a[Ba+1|0]=a[Ja+1|0]|0;a[Ba+2|0]=a[Ja+2|0]|0;a[Ba+3|0]=a[Ja+3|0]|0;a[Ba+4|0]=a[Ja+4|0]|0;a[Ja]=a[w]|0;a[Ja+1|0]=a[w+1|0]|0;a[Ja+2|0]=a[w+2|0]|0;a[Ja+3|0]=a[w+3|0]|0;a[Ja+4|0]=a[w+4|0]|0;mkb(g,q,Ga,0);nkb(g,q,Ga,0);mkb(g,q,Ka,1);nkb(g,q,Ka,1)}}while(0);if((R|0)==193){c[U>>2]=0;c[s>>2]=32;c[r>>2]=0;c[g+102312>>2]=-1;c[g+14664>>2]=-1;mrc(g+12|0,-1|0,6)|0;break}Ga=c[j>>2]|0;Ha=c[u>>2]|0;Ia=d[Ha+(Ga>>>3)|0]<<(Ga&7)>>>7;Ja=c[B>>2]|0;Ba=((Ga|0)<(Ja|0))+Ga|0;c[j>>2]=Ba;Ga=Ia&1;c[g+100>>2]=Ga;do{if((Ga|0)==0){Ta=Ba}else{Ia=c[g+262884>>2]|0;if((Ia|0)>0){Ua=0;Va=Ba}else{Ta=Ba;break}while(1){A=d[Ha+(Va>>>3)|0]<<(Va&7)>>>7;Ca=((Va|0)<(Ja|0))+Va|0;c[j>>2]=Ca;a[g+137+Ua|0]=A&1;A=Ua+1|0;if((A|0)<(Ia|0)){Ua=A;Va=Ca}else{Ta=Ca;break}}}}while(0);Ba=d[Ha+(Ta>>>3)|0]<<(Ta&7)>>>7;Ga=((Ta|0)<(Ja|0))+Ta|0;c[j>>2]=Ga;Ia=Ba&1;c[g+87748>>2]=Ia;if((Ia|0)==0){Wa=Ga;Xa=Ha;Ya=Ja;R=195;break}Ia=c[g+262884>>2]|0;if((Ia|0)>0){Za=0;_a=Ga}else{Wa=Ga;Xa=Ha;Ya=Ja;R=195;break}while(1){Ga=d[Ha+(_a>>>3)|0]<<(_a&7)>>>7;Ba=((_a|0)<(Ja|0))+_a|0;c[j>>2]=Ba;a[g+87785+Za|0]=Ga&1;Ga=Za+1|0;if((Ga|0)<(Ia|0)){Za=Ga;_a=Ba}else{Wa=Ba;Xa=Ha;Ya=Ja;R=195;break}}}else if((l|0)==2|(l|0)==0){Ja=c[B>>2]|0;Ha=((La|0)<(Ja|0))+La|0;if((d[(c[u>>2]|0)+(La>>>3)|0]&128>>>((La&7)>>>0)|0)==0){$a=Ha}else{Ia=Ha+4|0;$a=Ja>>>0>Ia>>>0?Ia:Ja}c[j>>2]=$a;Ja=g+96|0;if((lkb(f,g,q,Ja)|0)!=0){c[U>>2]=0;c[s>>2]=32;c[r>>2]=0;c[g+102312>>2]=-1;c[g+14664>>2]=-1;mrc(g+12|0,-1|0,6)|0;break}Ia=c[g+104>>2]|0;if((Ia|0)>0){Ha=c[u>>2]|0;Ba=c[B>>2]|0;Ga=0;Ka=c[j>>2]|0;do{w=d[Ha+(Ka>>>3)|0]<<(Ka&7)>>>7;Ka=((Ka|0)<(Ba|0))+Ka|0;c[j>>2]=Ka;a[g+120+Ga|0]=w&1;Ga=Ga+1|0;}while((Ga|0)<(Ia|0))}Ia=c[g+116>>2]|0;if((Ia|0)>0){Ga=c[u>>2]|0;Ka=c[B>>2]|0;Ba=0;Ha=c[j>>2]|0;do{w=d[Ga+(Ha>>>3)|0]<<(Ha&7)>>>7;Ha=((Ha|0)<(Ka|0))+Ha|0;c[j>>2]=Ha;a[g+125+Ba|0]=w&1;Ba=Ba+1|0;}while((Ba|0)<(Ia|0))}Ia=g+132|0;Ba=g+127|0;a[Ia]=a[Ba]|0;a[Ia+1|0]=a[Ba+1|0]|0;a[Ia+2|0]=a[Ba+2|0]|0;a[Ia+3|0]=a[Ba+3|0]|0;a[Ia+4|0]=a[Ba+4|0]|0;Ba=g+262888|0;if((c[Ba>>2]|0)!=0){Ia=c[B>>2]|0;Ha=c[u>>2]|0;Ka=0;Ga=c[j>>2]|0;do{w=Ha+(Ga>>>3)|0;Ca=(je(d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0)|0)<<(Ga&7)>>>30;w=Ga+2|0;Ga=Ia>>>0>w>>>0?w:Ia;c[j>>2]=Ga;a[g+127+Ka|0]=Ca;Ka=Ka+1|0;}while(Ka>>>0<(c[Ba>>2]|0)>>>0)}mkb(g,q,Ja,0);nkb(g,q,Ja,0);Ba=c[j>>2]|0;Ka=c[u>>2]|0;Ga=d[Ka+(Ba>>>3)|0]<<(Ba&7)>>>7;Ia=c[B>>2]|0;Ha=((Ba|0)<(Ia|0))+Ba|0;c[j>>2]=Ha;Ba=Ga&1;c[g+100>>2]=Ba;if((Ba|0)==0){Wa=Ha;Xa=Ka;Ya=Ia;R=195;break}Ba=c[g+262884>>2]|0;if((Ba|0)>0){ab=0;bb=Ha}else{Wa=Ha;Xa=Ka;Ya=Ia;R=195;break}while(1){Ha=d[Ka+(bb>>>3)|0]<<(bb&7)>>>7;Ga=((bb|0)<(Ia|0))+bb|0;c[j>>2]=Ga;a[g+137+ab|0]=Ha&1;Ha=ab+1|0;if((Ha|0)<(Ba|0)){ab=Ha;bb=Ga}else{Wa=Ga;Xa=Ka;Ya=Ia;R=195;break}}}else{KIb(c[f+4>>2]|0,16,2564080,(S=i,i=i+8|0,c[S>>2]=l,S)|0);i=S;c[U>>2]=0;c[s>>2]=32;c[r>>2]=0;c[g+102312>>2]=-1;c[g+14664>>2]=-1;mrc(g+12|0,-1|0,6)|0}}while(0);d:do{if((R|0)==195){r=d[Xa+(Wa>>>3)|0]|0;s=((Wa|0)<(Ya|0))+Wa|0;c[j>>2]=s;if((r&128>>>((Wa&7)>>>0)|0)==0){break}r=Xa+(s>>>3)|0;U=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>28;r=s+4|0;s=Ya>>>0>r>>>0?r:Ya;c[j>>2]=s;if((U|0)==15){r=Xa+(s>>>3)|0;l=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(s&7)>>>24;r=s+8|0;bb=Ya>>>0>r>>>0?r:Ya;c[j>>2]=bb;cb=l+15|0;db=bb}else{cb=U;db=s}s=cb<<3;e:do{if((s|0)>7){U=f+4|0;bb=f+6544|0;l=g+175392|0;r=s;ab=db;$a=Ya;_a=Xa;while(1){eb=r-2|0;Za=_a+(ab>>>3)|0;Ta=(je(d[Za]|d[Za+1|0]<<8|d[Za+2|0]<<16|d[Za+3|0]<<24|0)|0)<<(ab&7)>>>30;Za=ab+2|0;fb=$a>>>0>Za>>>0?Za:$a;c[j>>2]=fb;if((Ta|0)==0){R=207;break}else if((Ta|0)!=2){R=209;break}gb=c[U>>2]|0;if((c[bb>>2]|0)==0){R=202;break}Ta=eb-(iub(gb,q,l,eb)|0)|0;c[(c[U>>2]|0)+840>>2]=28;if((Ta|0)<=7){hb=Ta;break e}r=Ta;ab=c[j>>2]|0;$a=c[B>>2]|0;_a=c[u>>2]|0}do{if((R|0)==202){KIb(gb,16,2528496,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;ab=c[j>>2]|0;l=-ab|0;bb=(c[B>>2]|0)-ab|0;if((eb|0)<(l|0)){ib=l}else{ib=(bb|0)<(eb|0)?bb:eb}c[j>>2]=ib+ab;break d}else if((R|0)==207){if((eb|0)>16){R=209;break}ab=_a+(fb>>>3)|0;if(((je(d[ab]|d[ab+1|0]<<8|d[ab+2|0]<<16|d[ab+3|0]<<24|0)|0)<<(fb&7)>>>((34-r|0)>>>0)|0)==0){jb=fb;kb=$a}else{R=209}}}while(0);if((R|0)==209){QIb(c[U>>2]|0,2513528,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S;jb=c[j>>2]|0;kb=c[B>>2]|0}$a=-jb|0;r=kb-jb|0;if((eb|0)<($a|0)){lb=$a}else{lb=(r|0)<(eb|0)?r:eb}c[j>>2]=lb+jb;break d}else{hb=s}}while(0);if((hb|0)<0){KIb(c[f+4>>2]|0,16,2546208,(S=i,i=i+1|0,i=i+7&-8,c[S>>2]=0,S)|0);i=S}if((hb|0)<=0){break}s=c[B>>2]|0;r=(c[j>>2]|0)+hb|0;c[j>>2]=s>>>0>r>>>0?r:s}}while(0);Na=D-La+(c[j>>2]|0)|0}j=(Na+4+(4-Na&7)|0)>>>3;if(!(j>>>0>k>>>0)){i=m;return k|0}KIb(c[f+4>>2]|0,16,2434320,(S=i,i=i+16|0,c[S>>2]=k,c[S+8>>2]=j,S)|0);i=S;i=m;return k|0}function fkb(f,h,j,k,l){f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0,E=0,F=0,G=0,H=0.0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0.0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0.0,qb=0.0,rb=0.0,sb=0,tb=0,ub=0,vb=0,wb=0.0,xb=0.0,yb=0.0,zb=0,Ab=0;m=i;n=(c[f+6532>>2]|0)<(c[h>>2]|0)|0;o=(j|0)==1;j=o?2:1;p=h+80|0;if((c[p>>2]|0)==0){c[h+64>>2]=c[h+68>>2];c[h+72>>2]=c[h+76>>2]}else{c[p>>2]=0}p=h+4|0;a:do{if((c[p>>2]|0)!=0){do{if(o){if((c[h+40>>2]|0)==0){break}q=(c[h+188>>2]|0)!=0;r=q?1.0:.5;s=q?12.0:24.0;q=h+104|0;t=c[q>>2]|0;if((t|0)!=0){u=1;v=t;while(1){t=h+108+u|0;if((c[h+262880+(d[t]<<2)>>2]|0)==0){w=v}else{x=0;do{y=h+86512+(u*192|0)+(x<<2)|0;z=+ad(+(r*+g[y>>2]+7.0));A=h+174160+(u*192|0)+(x<<2)|0;B=+ad(+(r*(s- +g[A>>2])));if(z>1.0e20){KIb(0,16,2584880,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;D=1.0}else{D=z}z=D/(B+1.0);g[y>>2]=z;g[A>>2]=B*z;x=x+1|0;}while(x>>>0<(c[h+262880+(d[t]<<2)>>2]|0)>>>0);w=c[q>>2]|0}t=u+1|0;if(t>>>0>w>>>0){break}else{u=t;v=w}}}v=h+116|0;u=c[v>>2]|0;if((u|0)==0){break a}q=h+262888|0;t=1;x=c[q>>2]|0;A=u;while(1){if((x|0)==0){E=0;F=A}else{u=0;do{y=h+87664+(t*20|0)+(u<<2)|0;s=+ad(+(6.0- +g[y>>2]+1.0));G=h+175312+(t*20|0)+(u<<2)|0;r=+ad(+(12.0- +g[G>>2]));if(s>1.0e20){KIb(0,16,2584880,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;H=1.0}else{H=s}s=H/(r+1.0);g[y>>2]=s;g[G>>2]=r*s;u=u+1|0;I=c[q>>2]|0;}while(u>>>0<I>>>0);E=I;F=c[v>>2]|0}u=t+1|0;if(u>>>0>F>>>0){break a}else{t=u;x=E;A=F}}}}while(0);A=h+262888|0;x=0;do{s=(c[h+96+(x*87648|0)+92>>2]|0)!=0?1.0:.5;t=h+96+(x*87648|0)+8|0;v=c[t>>2]|0;if((v|0)!=0){q=1;u=v;while(1){v=h+96+(x*87648|0)+12+q|0;if((c[h+262880+(d[v]<<2)>>2]|0)==0){J=u}else{G=0;do{y=h+96+(x*87648|0)+86416+(q*192|0)+(G<<2)|0;r=+ad(+(s*+g[y>>2]+6.0));g[y>>2]=r;if(r>1.0e20){KIb(0,16,2584880,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;g[y>>2]=1.0}G=G+1|0;}while(G>>>0<(c[h+262880+(d[v]<<2)>>2]|0)>>>0);J=c[t>>2]|0}v=q+1|0;if(v>>>0>J>>>0){break}else{q=v;u=J}}}u=h+96+(x*87648|0)+20|0;q=c[u>>2]|0;if((q|0)!=0){t=1;v=c[A>>2]|0;G=q;while(1){if((v|0)==0){K=0;L=G}else{q=0;do{y=h+96+(x*87648|0)+87568+(t*20|0)+(q<<2)|0;g[y>>2]=+ad(+(6.0- +g[y>>2]));q=q+1|0;M=c[A>>2]|0;}while(q>>>0<M>>>0);K=M;L=c[u>>2]|0}q=t+1|0;if(q>>>0>L>>>0){break}else{t=q;v=K;G=L}}}x=x+1|0;}while((x|0)<(j|0))}}while(0);L=h+343584|0;K=h+343712|0;M=h+342304|0;J=f+5420|0;F=K|0;E=h+343724|0;I=h+343628|0;w=h+342560|0;o=h+343728|0;x=h+343768|0;A=h+263232|0;G=h+343776|0;v=h+343780|0;t=h+332864|0;u=h+333376|0;q=h+44|0;y=h+262888|0;N=h+273472|0;O=h+68|0;P=h+263216|0;Q=h+76|0;R=h+32|0;T=h+263044|0;U=h+262994|0;V=h+343716|0;W=h+343772|0;X=h+262892|0;Y=h+28|0;Z=h+262884|0;_=h+263142|0;$=f+4|0;aa=h+102312|0;ba=h+14664|0;da=h+12|0;ea=h+343744|0;fa=0;do{ga=h+96+(fa*87648|0)+9312|0;ha=h+96+(fa*87648|0)+30976|0;ia=c[ha>>2]|0;nrc(ga|0,h+96+(fa*87648|0)+13408|0,1152)|0;nrc(h+96+(fa*87648|0)+10464|0,((fa|0)!=0?l:k)|0,4096)|0;ja=ga;ga=0;while(1){mf[c[J>>2]&2047](M,5122448,ja,320);qe[c[F>>2]&1023](M);qe[c[E>>2]&1023](M);ef[c[I>>2]&4095](L,M,w);re[c[o>>2]&1023](h+96+(fa*87648|0)+14592+(ia<<13)+(ga<<8)|0,M);ka=ga+1|0;if((ka|0)<32){ja=ja+128|0;ga=ka}else{break}}ga=h+96+(fa*87648|0)|0;Xe[c[x>>2]&511](f,h,A,h+96+(fa*87648|0)+14592|0,c[ha>>2]|0)|0;c[ha>>2]=c[ha>>2]^1;b:do{if((c[p>>2]|0)!=0){pe[c[v>>2]&1023](K,t,u,A,c[q>>2]|0);ja=c[y>>2]|0;if((ja|0)!=0){ia=0;do{ka=d[h+96+(fa*87648|0)+31+ia|0]|0;if(((d[h+96+(fa*87648|0)+36+ia|0]|0)+ka|0)==1){la=.6000000238418579}else{la=+g[611616+(ka<<2)>>2]}ka=h+96+(fa*87648|0)+14572+(ia<<2)|0;H=+g[ka>>2];if(la<H){ma=la*.75+H*.25}else{ma=la*.90625+H*.09375}g[ka>>2]=ma<.015625?0.0:ma;ia=ia+1|0;}while(ia>>>0<ja>>>0)}ja=h+96+(fa*87648|0)+87628|0;ia=c[O>>2]|0;ka=c[P>>2]|0;do{if((ka|0)==0){na=ia;oa=ia;pa=61}else{qa=(c[h+96+(fa*87648|0)+8>>2]|0)+(h+96+(fa*87648|0)+87628)|0;ra=0;sa=0;ta=ia;ua=ka;c:while(1){va=h+263220+ra|0;if((a[va]|0)==0){wa=sa;xa=ta;ya=ua}else{za=h+263226+ra|0;Aa=0;Ba=sa;Ca=ta;while(1){Da=(d[za]|0)+Aa|0;Ea=c[y>>2]|0;Fa=Ba;while(1){if(Fa>>>0>Ea>>>0){break}if((Ca|0)<(e[h+263142+(Fa<<1)>>1]|0)){break}else{Fa=Fa+1|0}}Ga=Fa-1|0;if((Ga|0)<0){pa=56;break c}df[c[ea>>2]&7](h+273472+(Ca*320|0)+16|0,h+263232+(Da*320|0)+16|0,h+332864+(Da<<3)|0,h+333376+(Da<<3)|0,+g[h+96+(fa*87648|0)+14572+(Ga<<2)>>2],d[ja]<<1,d[qa]<<1);Ea=Aa+1|0;Ha=Ca+1|0;if((Ea|0)<(d[va]|0)){Aa=Ea;Ba=Ga;Ca=Ha}else{break}}wa=Ga;xa=Ha;ya=c[P>>2]|0}Ba=ra+1|0;if(Ba>>>0<ya>>>0){ra=Ba;sa=wa;ta=xa;ua=ya}else{pa=60;break}}if((pa|0)==56){pa=0;KIb(c[$>>2]|0,16,2611464,(C=i,i=i+8|0,c[C>>2]=Ca,C)|0);i=C;break}else if((pa|0)==60){pa=0;na=xa;oa=c[O>>2]|0;pa=61;break}}}while(0);do{if((pa|0)==61){pa=0;ja=(c[Q>>2]|0)+oa|0;if(!(na>>>0<ja>>>0)){break}mrc(h+273472+(na*320|0)|0,0,(ja-na|0)*320|0|0)|0}}while(0);ja=h+96+(fa*87648|0)+14564|0;mrc(h+96+(fa*87648|0)+86080|0,0,336)|0;ka=h+96+(fa*87648|0)+8|0;d:do{if((c[ka>>2]|0)==0){Ia=0}else{ia=h+96+(fa*87648|0)+20|0;ua=h+96+(fa*87648|0)+87638|0;ta=h+96+(fa*87648|0)+4|0;sa=h+96+(fa*87648|0)+14568|0;ra=0;while(1){qa=ra+1|0;Ba=a[h+96+(fa*87648|0)+12+qa|0]|0;Aa=c[h+262880+((Ba&255)<<2)>>2]|0;va=Ba<<24>>24==0?U:T;Ba=b[va>>1]|0;if((c[O>>2]|0)!=(Ba&65535|0)){break}za=(Aa|0)==0;if(!za){Ea=0;Ja=Ba;while(1){Ba=Ea+1|0;Ka=b[va+(Ba<<1)>>1]|0;if((Ja&65535)>>>0<(Ka&65535)>>>0){La=h+96+(fa*87648|0)+86416+(qa*192|0)+(Ea<<2)|0;Ma=Ka&65535;Na=Ja&65535;do{g[h+333888+(ra*192|0)+(Na-(c[O>>2]|0)<<2)>>2]=+g[La>>2];Na=Na+1|0;}while((Na|0)<(Ma|0))}if(Ba>>>0<Aa>>>0){Ea=Ba;Ja=Ka}else{break}}}if((c[ia>>2]|0)>>>0>1>>>0){Oa=(d[h+96+(fa*87648|0)+87628+ra|0]|0)>>>0>=(d[ua]|0)>>>0?2:1}else{Oa=1}Ja=c[y>>2]|0;if((Ja|0)!=0){Ea=0;Ma=b[_>>1]|0;Na=Ja;while(1){Ja=Ea+1|0;La=h+263142+(Ja<<1)|0;Da=b[La>>1]|0;if((Ma&65535)>>>0<(Da&65535)>>>0){Fa=h+96+(fa*87648|0)+87568+(Oa*20|0)+(Ea<<2)|0;Pa=Ma&65535;do{g[h+335232+(ra*192|0)+(Pa-(c[O>>2]|0)<<2)>>2]=+g[Fa>>2];Pa=Pa+1|0;Qa=b[La>>1]|0;}while((Pa|0)<(Qa&65535|0));Ra=Qa;Sa=c[y>>2]|0}else{Ra=Da;Sa=Na}if(Ja>>>0<Sa>>>0){Ea=Ja;Ma=Ra;Na=Sa}else{break}}}Na=c[Z>>2]|0;if((Na|0)!=0){Ma=0;Ea=Na;while(1){if((c[ta>>2]|0)==0){Ta=Ea;Ua=Ma+1|0}else{Na=Ma+1|0;Pa=((e[h+263044+(Na<<1)>>1]|0)+(e[h+263044+(Ma<<1)>>1]|0)|0)>>>1;La=c[O>>2]|0;if((ra|0)<(c[sa>>2]|0)){Va=(a[Pa-La+(h+96+(fa*87648|0)+86032)|0]|0)==1|0}else{Va=1}a[Pa-La+(h+96+(fa*87648|0)+86032+(qa*48|0))|0]=a[h+96+(fa*87648|0)+41+Ma|0]&(-Va&255);Ta=c[Z>>2]|0;Ua=Na}if(Ua>>>0<Ta>>>0){Ma=Ua;Ea=Ta}else{break}}}if(!za){Ea=0;do{Ma=e[va+(Ea<<1)>>1]|0;Ea=Ea+1|0;Na=e[va+(Ea<<1)>>1]|0;La=c[O>>2]|0;Pa=Ma;while(1){if((Pa|0)>=(Na|0)){Wa=0;break}if((a[Pa-La+(h+96+(fa*87648|0)+86032+(qa*48|0))|0]|0)==0){Pa=Pa+1|0}else{Wa=1;break}}mrc(Ma-La+(h+336576+(ra*48|0))|0,Wa|0,Na-Ma|0)|0;}while(Ea>>>0<Aa>>>0)}Aa=c[ka>>2]|0;if(qa>>>0<Aa>>>0){ra=qa}else{Ia=Aa;break d}}KIb(c[$>>2]|0,16,2634880,(C=i,i=i+1|0,i=i+7&-8,c[C>>2]=0,C)|0);i=C;c[p>>2]=0;c[O>>2]=32;c[Q>>2]=0;c[aa>>2]=-1;c[ba>>2]=-1;mrc(da|0,-1|0,6)|0;break b}}while(0);nrc(h+96+(fa*87648|0)+86032|0,h+96+(fa*87648|0)+86032+(Ia*48|0)|0,48)|0;ra=c[O>>2]|0;sa=(Ia|0)==0;do{if((c[R>>2]|0)==0){if(sa){break}else{Xa=0;Ya=Ia}while(1){ta=Xa+1|0;ua=d[h+96+(fa*87648|0)+87628+ta|0]|0;ia=d[h+96+(fa*87648|0)+87628+Xa|0]|0;Aa=ua-ia<<1;Ea=ia<<1;ia=Ea+2|0;va=h+96+(fa*87648|0)+12+ta|0;za=a[va]|0;Pa=za<<24>>24==0?U:T;if((c[h+262880+((za&255)<<2)>>2]|0)==0){Za=Ya}else{za=(ua<<1)-Ea|0;Ea=0;ua=b[Pa>>1]|0;while(1){Ja=Ea+1|0;Da=Pa+(Ja<<1)|0;Fa=b[Da>>1]|0;Ka=Pa+(Ea<<1)|0;Ba=ua&65535;_a=ca(Aa,(Fa&65535)-Ba|0)|0;if((ua&65535)>>>0<(Fa&65535)>>>0){$a=Ba;H=0.0;do{H=H+ +Ie[c[V>>2]&3](h+273472+($a*320|0)+(ia<<3)|0,za);$a=$a+1|0;ab=b[Da>>1]|0;}while(($a|0)<(ab&65535|0));bb=H;cb=b[Ka>>1]|0;db=ab}else{bb=0.0;cb=ua;db=Fa}D=bb/+(_a|0);if((cb&65535)>>>0<(db&65535)>>>0){$a=db&65535;Da=cb&65535;do{g[h+336912+(Xa*192|0)+(Da-ra<<2)>>2]=D;Da=Da+1|0;}while((Da|0)<($a|0))}if(Ja>>>0<(c[h+262880+(d[va]<<2)>>2]|0)>>>0){Ea=Ja;ua=db}else{break}}Za=c[ka>>2]|0}if(ta>>>0<Za>>>0){Xa=ta;Ya=Za}else{eb=Za;pa=114;break}}}else{if(sa){break}ua=0;Ea=c[Q>>2]|0;va=Ia;while(1){za=ua+1|0;ia=d[h+96+(fa*87648|0)+87628+za|0]|0;Aa=d[h+96+(fa*87648|0)+87628+ua|0]|0;D=.5/+(ia-Aa|0);Pa=Aa<<1;Aa=Pa+2|0;if((Ea|0)==0){fb=0;gb=va}else{qa=(ia<<1)-Pa|0;Pa=0;do{g[h+336912+(ua*192|0)+(Pa<<2)>>2]=D*+Ie[c[V>>2]&3](h+273472+((Pa+ra|0)*320|0)+(Aa<<3)|0,qa);Pa=Pa+1|0;hb=c[Q>>2]|0;}while(Pa>>>0<hb>>>0);fb=hb;gb=c[ka>>2]|0}if(za>>>0<gb>>>0){ua=za;Ea=fb;va=gb}else{eb=gb;pa=114;break}}}}while(0);do{if((pa|0)==114){pa=0;if((eb|0)==0){break}ka=c[h+96+(fa*87648|0)+14568>>2]|0;ra=0;while(1){if((ra|0)==(ka|0)){ib=0}else{ib=(ra|0)!=(c[ja>>2]|0)}if((c[X>>2]|0)==0){jb=ra+1|0}else{sa=ra+1|0;D=+(ib&1|0);va=0;Ea=c[O>>2]|0;while(1){ua=h+263154+(va<<1)|0;Pa=b[ua>>1]|0;qa=(Pa&65535)-Ea|0;Aa=va+1|0;ta=h+263154+(Aa<<1)|0;ia=b[ta>>1]|0;if(qa>>>0<((ia&65535)-Ea|0)>>>0){$a=qa;do{H=+g[h+333888+(ra*192|0)+($a<<2)>>2];s=+g[h+335232+(ra*192|0)+($a<<2)>>2];r=s+1.0;z=H/r;g[h+338256+(ra*192|0)+($a<<2)>>2]=+S(s*z);g[h+339600+(ra*192|0)+($a<<2)>>2]=+S(z*+(d[h+96+(fa*87648|0)+86032+(sa*48|0)+$a|0]|0));if((a[h+336576+(ra*48|0)+$a|0]|0)==0){g[h+340944+(ra*192|0)+($a<<2)>>2]=+S(H/((D*s+1.0)*(+g[h+336912+(ra*192|0)+($a<<2)>>2]+1.0)))}else{g[h+340944+(ra*192|0)+($a<<2)>>2]=+S(H*s/(r*(+g[h+336912+(ra*192|0)+($a<<2)>>2]+1.0)))}$a=$a+1|0;kb=b[ta>>1]|0;lb=c[O>>2]|0;}while($a>>>0<((kb&65535)-lb|0)>>>0);mb=lb;nb=b[ua>>1]|0;ob=kb}else{mb=Ea;nb=Pa;ob=ia}$a=(nb&65535)-mb|0;Ja=ob&65535;qa=Ja-mb|0;Da=$a>>>0<qa>>>0;if(Da){_a=$a;r=0.0;s=0.0;do{s=s+ +g[h+333888+(ra*192|0)+(_a<<2)>>2];r=r+ +g[h+336912+(ra*192|0)+(_a<<2)>>2];_a=_a+1|0;}while(_a>>>0<qa>>>0);pb=r+1.1920928955078125e-7;qb=s+1.1920928955078125e-7}else{pb=1.1920928955078125e-7;qb=1.1920928955078125e-7}H=+g[611600+(c[Y>>2]<<2)>>2]*+S(qb/pb);z=H<1.0e5?H:1.0e5;if(Da){qa=$a;do{_a=h+338256+(ra*192|0)+(qa<<2)|0;H=+g[_a>>2];ia=h+340944+(ra*192|0)+(qa<<2)|0;B=+g[ia>>2];rb=z*H/B;g[_a>>2]=H>rb?rb:H;g[ia>>2]=B>z?z:B;qa=qa+1|0;sb=c[O>>2]|0;}while(qa>>>0<(Ja-sb|0)>>>0);tb=sb;ub=b[ua>>1]|0;vb=b[ta>>1]|0}else{tb=mb;ub=nb;vb=ob}Ja=(ub&65535)-tb|0;qa=vb&65535;$a=qa-tb|0;Da=Ja>>>0<$a>>>0;if(Da){if(ib){ia=Ja;z=0.0;s=0.0;while(1){r=s+ +g[h+333888+(ra*192|0)+(ia<<2)>>2];B=+g[h+340944+(ra*192|0)+(ia<<2)>>2];H=+g[h+339600+(ra*192|0)+(ia<<2)>>2];rb=+g[h+338256+(ra*192|0)+(ia<<2)>>2];wb=z+(B*+g[h+336912+(ra*192|0)+(ia<<2)>>2]*B+H*H+rb*rb*+(H==0.0|0));_a=ia+1|0;if(_a>>>0<$a>>>0){ia=_a;z=wb;s=r}else{xb=wb;yb=r;break}}}else{ia=Ja;s=0.0;z=0.0;while(1){r=z+ +g[h+333888+(ra*192|0)+(ia<<2)>>2];wb=+g[h+340944+(ra*192|0)+(ia<<2)>>2];H=+g[h+339600+(ra*192|0)+(ia<<2)>>2];rb=+g[h+338256+(ra*192|0)+(ia<<2)>>2];B=s+(wb*+g[h+336912+(ra*192|0)+(ia<<2)>>2]*wb+H*H+rb*rb*0.0);ta=ia+1|0;if(ta>>>0<$a>>>0){ia=ta;s=B;z=r}else{xb=B;yb=r;break}}}}else{xb=0.0;yb=0.0}z=+S((yb+1.1920928955078125e-7)/(xb+1.1920928955078125e-7));s=z<1.5848932266235352?z:1.5848932266235352;if(Da){ia=Ja;while(1){$a=h+340944+(ra*192|0)+(ia<<2)|0;g[$a>>2]=s*+g[$a>>2];$a=h+338256+(ra*192|0)+(ia<<2)|0;g[$a>>2]=s*+g[$a>>2];$a=h+339600+(ra*192|0)+(ia<<2)|0;g[$a>>2]=s*+g[$a>>2];$a=ia+1|0;ta=c[O>>2]|0;if($a>>>0<(qa-ta|0)>>>0){ia=$a}else{zb=ta;break}}}else{zb=tb}if(Aa>>>0<(c[X>>2]|0)>>>0){va=Aa;Ea=zb}else{jb=sa;break}}}if(jb>>>0<eb>>>0){ra=jb}else{break}}}}while(0);pe[c[W>>2]&1023](h+96+(fa*87648|0)+30992+((c[ha>>2]|0)*19456|0)|0,N,h,ga,ja)}}while(0);ga=c[ha>>2]|0;se[c[G>>2]&127](h,h+293952+(fa*19456|0)|0,h+96+(fa*87648|0)+30992+((1-ga|0)*19456|0)|0,h+96+(fa*87648|0)+30992+(ga*19456|0)|0,A,fa)|0;fa=fa+1|0;}while((fa|0)<(j|0));do{if((c[f+6544>>2]|0)==1){fa=h+175392|0;if((c[fa>>2]|0)==0){nrc(h+313408|0,h+293952|0,19456)|0;Ab=2;break}else{jub(c[$>>2]|0,fa,h+293952|0,h+313408|0,(c[Q>>2]|0)+(c[O>>2]|0)|0)|0;Ab=2;break}}else{Ab=j}}while(0);j=h+343648|0;O=f+5396|0;f=h+342304|0;gkb(j,K,O,k,h+293952|0,f,h+192|0,h+14656|0,n);if((Ab|0)!=2){i=m;return}gkb(j,K,O,l,h+313408|0,f,h+87840|0,h+102304|0,n);i=m;return}function gkb(a,b,d,e,f,h,i,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;l=(k|0)!=0;m=l?5122448:608904;n=128>>>(k>>>0);o=1152>>>(k>>>0);p=2304-o|0;q=i+(p<<2)|0;r=i;s=o<<2;o=d|0;t=64>>>(k>>>0);u=d+20|0;d=192>>>(k>>>0);v=m+(t<<2)|0;w=256>>>(k>>>0);x=m+(n<<2)|0;y=448>>>(k>>>0);z=m+(d<<2)|0;A=512>>>(k>>>0);B=m+(w<<2)|0;C=704>>>(k>>>0);D=m+(320>>>(k>>>0)<<2)|0;E=768>>>(k>>>0);F=m+(384>>>(k>>>0)<<2)|0;G=960>>>(k>>>0);H=m+(y<<2)|0;I=1024>>>(k>>>0);J=m+(A<<2)|0;K=1216>>>(k>>>0);L=m+(576>>>(k>>>0)<<2)|0;k=b+8|0;M=a+44|0;N=h|0;O=h+256|0;h=b+24|0;P=b+20|0;if(l){Q=0;R=e}else{l=0;b=e;while(1){e=c[j>>2]|0;if((e|0)<(n|0)){nrc(q|0,r|0,s)|0;S=p}else{S=e}e=S-n|0;c[j>>2]=e;T=i+(e<<2)|0;U=f+9728+(l<<8)|0;qe[c[k>>2]&1023](U);ef[c[M>>2]&4095](a,N,f+(l<<8)|0);ef[c[M>>2]&4095](a,O,U);ef[c[h>>2]&4095](T,O,N);mf[c[o>>2]&2047](b,T,m,t);pe[c[u>>2]&1023](b,i+(e+d<<2)|0,v,b,t);pe[c[u>>2]&1023](b,i+(e+w<<2)|0,x,b,t);pe[c[u>>2]&1023](b,i+(e+y<<2)|0,z,b,t);pe[c[u>>2]&1023](b,i+(e+A<<2)|0,B,b,t);pe[c[u>>2]&1023](b,i+(e+C<<2)|0,D,b,t);pe[c[u>>2]&1023](b,i+(e+E<<2)|0,F,b,t);pe[c[u>>2]&1023](b,i+(e+G<<2)|0,H,b,t);pe[c[u>>2]&1023](b,i+(e+I<<2)|0,J,b,t);pe[c[u>>2]&1023](b,i+(e+K<<2)|0,L,b,t);e=l+1|0;if((e|0)<32){l=e;b=b+(t<<2)|0}else{break}}return}while(1){b=c[j>>2]|0;if((b|0)<(n|0)){nrc(q|0,r|0,s)|0;V=p}else{V=b}b=V-n|0;c[j>>2]=b;l=i+(b<<2)|0;O=0;do{h=f+(Q<<8)+(O<<2)|0;g[h>>2]=-0.0- +g[h>>2];g[f+(Q<<8)+(O+32<<2)>>2]=+g[f+9728+(Q<<8)+(31-O<<2)>>2];O=O+1|0;}while((O|0)<32);ef[c[M>>2]&4095](a,N,f+(Q<<8)|0);re[c[P>>2]&1023](l,N);mf[c[o>>2]&2047](R,l,m,t);pe[c[u>>2]&1023](R,i+(b+d<<2)|0,v,R,t);pe[c[u>>2]&1023](R,i+(b+w<<2)|0,x,R,t);pe[c[u>>2]&1023](R,i+(b+y<<2)|0,z,R,t);pe[c[u>>2]&1023](R,i+(b+A<<2)|0,B,R,t);pe[c[u>>2]&1023](R,i+(b+C<<2)|0,D,R,t);pe[c[u>>2]&1023](R,i+(b+E<<2)|0,F,R,t);pe[c[u>>2]&1023](R,i+(b+G<<2)|0,H,R,t);pe[c[u>>2]&1023](R,i+(b+I<<2)|0,J,R,t);pe[c[u>>2]&1023](R,i+(b+K<<2)|0,L,R,t);O=Q+1|0;if((O|0)<32){Q=O;R=R+(t<<2)|0}else{break}}return}function hkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0;mrc(d|0,0,10240)|0;a=c[b+68>>2]|0;if((a|0)!=0){h=0;do{i=8;do{j=i-8|0;g[d+(h*320|0)+(i<<3)>>2]=+g[e+(f<<13)+(j<<8)+(h<<3)>>2];g[d+(h*320|0)+(i<<3)+4>>2]=+g[e+(f<<13)+(j<<8)+(h<<3)+4>>2];i=i+1|0;}while((i|0)<40);h=h+1|0;}while(h>>>0<a>>>0)}a=1-f|0;f=c[b+64>>2]|0;if((f|0)==0){return 0}else{k=0}do{g[d+(k*320|0)>>2]=+g[e+(a<<13)+6144+(k<<3)>>2];g[d+(k*320|0)+4>>2]=+g[e+(a<<13)+6144+(k<<3)+4>>2];g[d+(k*320|0)+8>>2]=+g[e+(a<<13)+6400+(k<<3)>>2];g[d+(k*320|0)+12>>2]=+g[e+(a<<13)+6400+(k<<3)+4>>2];g[d+(k*320|0)+16>>2]=+g[e+(a<<13)+6656+(k<<3)>>2];g[d+(k*320|0)+20>>2]=+g[e+(a<<13)+6656+(k<<3)+4>>2];g[d+(k*320|0)+24>>2]=+g[e+(a<<13)+6912+(k<<3)>>2];g[d+(k*320|0)+28>>2]=+g[e+(a<<13)+6912+(k<<3)+4>>2];g[d+(k*320|0)+32>>2]=+g[e+(a<<13)+7168+(k<<3)>>2];g[d+(k*320|0)+36>>2]=+g[e+(a<<13)+7168+(k<<3)+4>>2];g[d+(k*320|0)+40>>2]=+g[e+(a<<13)+7424+(k<<3)>>2];g[d+(k*320|0)+44>>2]=+g[e+(a<<13)+7424+(k<<3)+4>>2];g[d+(k*320|0)+48>>2]=+g[e+(a<<13)+7680+(k<<3)>>2];g[d+(k*320|0)+52>>2]=+g[e+(a<<13)+7680+(k<<3)+4>>2];g[d+(k*320|0)+56>>2]=+g[e+(a<<13)+7936+(k<<3)>>2];g[d+(k*320|0)+60>>2]=+g[e+(a<<13)+7936+(k<<3)+4>>2];k=k+1|0;}while(k>>>0<f>>>0);return 0}function ikb(b,e,f,h,j){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0.0,aa=0,ba=0.0,ca=0.0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;k=i;i=i+384|0;l=k|0;m=k+192|0;n=(c[f+36>>2]|0)==0;o=(n&1)<<2;p=c[f+68>>2]|0;q=c[f+76>>2]|0;r=h+87640|0;s=c[r>>2]|0;t=h+87644|0;u=c[t>>2]|0;do{if((c[f+8>>2]|0)==0){if(!n){break}v=h+87628|0;w=h+87636|0;nrc(h+69904+(((d[v]|0)<<1)*192|0)|0,h+69904+(((d[w]|0)<<1)*192|0)|0,768)|0;nrc(h+77968+(((d[v]|0)<<1)*192|0)|0,h+77968+(((d[w]|0)<<1)*192|0)|0,768)|0}else{if(!n){break}w=h+87628|0;v=f+340944|0;x=q<<2;y=f+338256|0;z=0;do{nrc(h+69904+((((d[w]|0)<<1)+z|0)*192|0)|0,v|0,x)|0;nrc(h+77968+((((d[w]|0)<<1)+z|0)*192|0)|0,y|0,x)|0;z=z+1|0;}while((z|0)<(o|0))}}while(0);z=h+8|0;x=c[z>>2]|0;if((x|0)==0){A=u;B=s;c[r>>2]=B;c[t>>2]=A;i=k;return}y=q<<2;w=0;v=a[h+87628|0]|0;C=x;while(1){x=(v&255)<<1;D=w+1|0;E=h+87628+D|0;F=a[E]|0;if(x>>>0<(F&255)<<1>>>0){G=f+340944+(w*192|0)|0;H=f+338256+(w*192|0)|0;I=x;do{x=I+o|0;nrc(h+69904+(x*192|0)|0,G|0,y)|0;nrc(h+77968+(x*192|0)|0,H|0,y)|0;I=I+1|0;J=a[E]|0;}while((I|0)<((J&255)<<1|0));K=J;L=c[z>>2]|0}else{K=F;L=C}if(D>>>0<L>>>0){w=D;v=K;C=L}else{break}}if((L|0)==0){A=u;B=s;c[r>>2]=B;c[t>>2]=A;i=k;return}C=l|0;K=m|0;v=j+4|0;w=(q|0)>0;J=f+343748|0;y=e+(p*320|0)|0;e=p&1;I=(q|0)>1;E=(q&1|0)==0;H=u;u=s;s=0;G=a[h+87628|0]|0;x=L;while(1){L=(G&255)<<1;M=s+1|0;N=h+87628+M|0;O=a[N]|0;if(L>>>0<(O&255)<<1>>>0){P=f+339600+(s*192|0)|0;Q=H;R=u;S=L;do{do{if(n){if((s|0)==(c[j>>2]|0)){T=28;break}if((s|0)==(c[v>>2]|0)){T=28;break}if(!w){U=K;V=C;break}L=S+o|0;W=0;while(1){X=l+(W<<2)|0;g[X>>2]=0.0;Y=m+(W<<2)|0;g[Y>>2]=0.0;Z=0;_=0.0;$=0.0;do{aa=L-Z|0;ba=+g[611576+(Z<<2)>>2];_=_+ +g[h+69904+(aa*192|0)+(W<<2)>>2]*ba;$=$+ +g[h+77968+(aa*192|0)+(W<<2)>>2]*ba;Z=Z+1|0;}while((Z|0)<=(o|0));g[X>>2]=_;g[Y>>2]=$;Z=W+1|0;if((Z|0)<(q|0)){W=Z}else{U=K;V=C;break}}}else{T=28}}while(0);if((T|0)==28){T=0;U=h+77968+(S*192|0)|0;V=h+69904+((S+o|0)*192|0)|0}W=b+(S<<9)+(p<<3)|0;pe[c[J>>2]&1023](W,y,V,q,S+2|0);do{if((s|0)==(c[j>>2]|0)){T=32}else{if((s|0)==(c[v>>2]|0)){T=32;break}_e[c[f+343752+(Q<<2)>>2]&511](W,P,U,R,p,q)}}while(0);do{if((T|0)==32){T=0;W=Q&1;L=1-(Q+e&2)|0;if(I){ba=+(L|0);ca=+((L^-W)+W|0);Z=0;aa=1;while(1){da=Z<<1|W;ea=b+(S<<9)+(p<<3)+(da<<2)|0;g[ea>>2]=+g[ea>>2]+ba*+g[f+339600+(s*192|0)+(Z<<2)>>2];ea=b+(S<<9)+(p<<3)+((da|2)<<2)|0;g[ea>>2]=+g[ea>>2]+ca*+g[f+339600+(s*192|0)+(aa<<2)>>2];ea=Z+2|0;da=ea|1;if((da|0)<(q|0)){Z=ea;aa=da}else{fa=ea;break}}}else{fa=0}if(E){break}aa=b+(S<<9)+(p<<3)+((fa<<1|W)<<2)|0;g[aa>>2]=+g[aa>>2]+ +(L|0)*+g[f+339600+(s*192|0)+(fa<<2)>>2]}}while(0);R=R+q&511;Q=Q+1&3;S=S+1|0;ga=a[N]|0;}while((S|0)<((ga&255)<<1|0));ha=Q;ia=R;ja=ga;ka=c[z>>2]|0}else{ha=H;ia=u;ja=O;ka=x}if(M>>>0<ka>>>0){H=ha;u=ia;s=M;G=ja;x=ka}else{A=ha;B=ia;break}}c[r>>2]=B;c[t>>2]=A;i=k;return}function jkb(a,b,e,f,h,i){a=a|0;b=b|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=((d[a+96+(i*87648|0)+87636|0]|0)<<1)-32|0;i=(j|0)>0;k=i?j:0;mrc(b|0,0,19456)|0;j=c[a+64>>2]|0;if((j|0)==0){l=0;m=0}else{n=j>>>0>1>>>0;o=0;do{if(i){p=0;do{q=p+2|0;g[b+(p<<8)+(o<<2)>>2]=+g[h+(o*320|0)+(q<<3)>>2];g[b+9728+(p<<8)+(o<<2)>>2]=+g[h+(o*320|0)+(q<<3)+4>>2];p=p+1|0;}while((p|0)<(k|0))}o=o+1|0;}while(o>>>0<j>>>0);l=n?j:1;m=j}j=(c[a+72>>2]|0)+m|0;if(l>>>0<j>>>0){m=l;do{if(i){l=0;do{n=l+32|0;g[b+(l<<8)+(m<<2)>>2]=+g[e+(n<<9)+(m<<3)>>2];g[b+9728+(l<<8)+(m<<2)>>2]=+g[e+(n<<9)+(m<<3)+4>>2];l=l+1|0;}while((l|0)<(k|0))}m=m+1|0;}while(m>>>0<j>>>0)}j=c[a+68>>2]|0;do{if((j|0)==0){r=0}else{m=j>>>0>1>>>0;if((k|0)<38){s=0}else{r=m?j:1;break}do{e=k;do{i=e+2|0;g[b+(e<<8)+(s<<2)>>2]=+g[h+(s*320|0)+(i<<3)>>2];g[b+9728+(e<<8)+(s<<2)>>2]=+g[h+(s*320|0)+(i<<3)+4>>2];e=e+1|0;}while((e|0)<38);s=s+1|0;}while(s>>>0<j>>>0);r=m?j:1}}while(0);s=(c[a+76>>2]|0)+j|0;if(r>>>0<s>>>0&(k|0)<32){t=r}else{return 0}do{r=k;do{g[b+(r<<8)+(t<<2)>>2]=+g[f+(r<<9)+(t<<3)>>2];g[b+9728+(r<<8)+(t<<2)>>2]=+g[f+(r<<9)+(t<<3)+4>>2];r=r+1|0;}while((r|0)<32);t=t+1|0;}while(t>>>0<s>>>0);return 0}function kkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0,H=0;h=i;i=i+48|0;j=h|0;if((f|0)<=0){i=h;return}k=j|0;l=a+28|0;a=j+40|0;m=j+16|0;n=j+24|0;o=j+28|0;p=j|0;q=j+4|0;r=j+8|0;s=j+12|0;j=0;do{re[c[l>>2]&1023](e+(j*320|0)|0,k);t=+g[m>>2];u=+g[n>>2];v=+g[o>>2];w=+g[a>>2]*t-(u*u+v*v)/1.0000009536743164;if(w!=0.0){x=+g[p>>2];y=+g[q>>2];z=v*x+u*y-t*+g[s>>2];A=(u*x-v*y-t*+g[r>>2])/w;g[d+(j<<3)>>2]=A;y=z/w;g[d+(j<<3)+4>>2]=y;B=A;C=y}else{g[d+(j<<3)>>2]=0.0;g[d+(j<<3)+4>>2]=0.0;B=0.0;C=0.0}if(t!=0.0){y=u*C+ +g[q>>2]-B*v;A=(-0.0-(+g[p>>2]+B*u+C*v))/t;g[b+(j<<3)>>2]=A;v=(-0.0-y)/t;g[b+(j<<3)+4>>2]=v;D=A;E=v}else{g[b+(j<<3)>>2]=0.0;g[b+(j<<3)+4>>2]=0.0;D=0.0;E=0.0}F=d+(j<<3)|0;G=d+(j<<3)+4|0;v=+g[F>>2];A=+g[G>>2];if(v*v+A*A<16.0){if(!(D*D+E*E<16.0)){H=11}}else{H=11}if((H|0)==11){H=0;g[F>>2]=0.0;g[G>>2]=0.0;g[b+(j<<3)>>2]=0.0;g[b+(j<<3)+4>>2]=0.0}j=j+1|0;}while((j|0)<(f|0));i=h;return}function lkb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;j=g+8|0;k=c[j>>2]|0;a[g+12|0]=a[g+12+k|0]|0;l=g+92|0;c[l>>2]=c[e+20>>2];e=g+87628|0;a[g+87636|0]=a[g+87628+k|0]|0;m=f+8|0;n=c[m>>2]|0;o=f+16|0;p=c[o>>2]|0;q=f|0;f=c[q>>2]|0;r=f+(n>>>3)|0;s=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(n&7)>>>30;r=n+2|0;c[m>>2]=p>>>0>r>>>0?r:p;p=g|0;c[p>>2]=s;a:do{if((s|0)==0){r=c[m>>2]|0;n=c[o>>2]|0;t=f+(r>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(r&7)>>>30;t=r+2|0;c[m>>2]=n>>>0>t>>>0?t:n;n=1<<u;c[j>>2]=n;u=n-1|0;do{if((n|0)==1){c[l>>2]=0}else{if(!(n>>>0>4>>>0)){break}KIb(c[b+4>>2]|0,16,2499864,(v=i,i=i+8|0,c[v>>2]=n,v)|0);i=v;w=-1;i=h;return w|0}}while(0);a[e|0]=0;a[g+87628+n|0]=16;t=c[j>>2]|0;r=(((t>>>1)+16|0)>>>0)/(t>>>0)|0;if((u|0)>0){t=0;x=a[g+87628|0]|0;do{x=(x&255)+r&255;t=t+1|0;a[g+87628+t|0]=x;}while((t|0)<(u|0))}u=c[m>>2]|0;t=d[(c[q>>2]|0)+(u>>>3)|0]<<(u&7)>>>7;c[m>>2]=((u|0)<(c[o>>2]|0))+u;u=t&1;t=g+13|0;a[t]=u;x=c[j>>2]|0;if(x>>>0>1>>>0){y=2;z=u}else{A=0;B=x;break}while(1){a[g+12+y|0]=z;x=c[j>>2]|0;if(!(y>>>0<x>>>0)){A=0;B=x;break a}y=y+1|0;z=a[t]|0}}else if((s|0)==3){t=c[m>>2]|0;x=c[o>>2]|0;u=f+(t>>>3)|0;r=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>>30;u=t+2|0;c[m>>2]=x>>>0>u>>>0?u:x;a[e|0]=r;r=c[m>>2]|0;x=c[o>>2]|0;u=c[q>>2]|0;t=u+(r>>>3)|0;n=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;t=r+2|0;C=x>>>0>t>>>0?t:x;c[m>>2]=C;t=u+(C>>>3)|0;D=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(C&7)>>>30;t=C+2|0;C=x>>>0>t>>>0?t:x;c[m>>2]=C;t=u+(C>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(C&7)>>>30;t=C+2|0;c[m>>2]=x>>>0>t>>>0?t:x;x=D+1+u|0;c[j>>2]=x;if(x>>>0>5>>>0){KIb(c[b+4>>2]|0,16,2487192,(v=i,i=i+8|0,c[v>>2]=x,v)|0);i=v;w=-1;i=h;return w|0}a[g+87628+x|0]=(je(n|0)|0)<<(r&7)>>>30|16;if((D|0)!=0){r=0;n=a[g+87628|0]|0;do{x=c[m>>2]|0;t=c[o>>2]|0;C=(c[q>>2]|0)+(x>>>3)|0;E=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(x&7)>>>30;C=x+2|0;c[m>>2]=t>>>0>C>>>0?C:t;n=(n&255)+2+(E<<1)&255;r=r+1|0;a[g+87628+r|0]=n;}while((r|0)<(D|0))}D=c[j>>2]|0;if((u|0)==0){F=D}else{r=0;n=D;while(1){D=d[n-r+(g+87628)|0]|0;E=c[m>>2]|0;t=c[o>>2]|0;C=(c[q>>2]|0)+(E>>>3)|0;x=(je(d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0)|0)<<(E&7)>>>30;C=E+2|0;c[m>>2]=t>>>0>C>>>0?C:t;a[(c[j>>2]|0)+~r+(g+87628)|0]=D+254-(x<<1);x=r+1|0;D=c[j>>2]|0;if((x|0)<(u|0)){r=x;n=D}else{F=D;break}}}n=a[1720680+F|0]|0;r=c[m>>2]|0;u=c[o>>2]|0;D=c[q>>2]|0;x=D+(r>>>3)|0;t=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(r&7)>>>((32-n|0)>>>0);x=r+n|0;n=u>>>0>x>>>0?x:u;c[m>>2]=n;x=c[j>>2]|0;if((x|0)>0){G=1;H=n;I=D;J=u}else{K=t;L=35;break}while(1){u=d[I+(H>>>3)|0]<<(H&7)>>>7;c[m>>2]=((H|0)<(J|0))+H;a[g+12+G|0]=u&1;if((G|0)>=(x|0)){K=t;L=35;break a}G=G+1|0;H=c[m>>2]|0;I=c[q>>2]|0;J=c[o>>2]|0}}else if((s|0)==2){t=c[m>>2]|0;x=c[o>>2]|0;u=f+(t>>>3)|0;D=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>>30;u=t+2|0;c[m>>2]=x>>>0>u>>>0?u:x;a[e|0]=D;D=c[m>>2]|0;x=c[o>>2]|0;u=(c[q>>2]|0)+(D>>>3)|0;t=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(D&7)>>>30;u=D+2|0;c[m>>2]=x>>>0>u>>>0?u:x;x=t+1|0;c[j>>2]=x;a[g+87628+x|0]=16;if((t|0)!=0){x=0;u=a[g+87628|0]|0;do{D=c[m>>2]|0;n=c[o>>2]|0;r=(c[q>>2]|0)+(D>>>3)|0;C=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(D&7)>>>30;r=D+2|0;c[m>>2]=n>>>0>r>>>0?r:n;u=(u&255)+2+(C<<1)&255;x=x+1|0;a[g+87628+x|0]=u;}while((x|0)<(t|0))}t=a[1720680+(c[j>>2]|0)|0]|0;x=c[m>>2]|0;u=c[o>>2]|0;C=c[q>>2]|0;n=C+(x>>>3)|0;r=(je(d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0)|0)<<(x&7)>>>((32-t|0)>>>0);n=x+t|0;t=u>>>0>n>>>0?n:u;c[m>>2]=t;n=c[j>>2]|0;if((n|0)>0){M=1;N=t;O=C;P=u}else{K=r;L=35;break}while(1){u=d[O+(N>>>3)|0]<<(N&7)>>>7;c[m>>2]=((N|0)<(P|0))+N;a[g+12+M|0]=u&1;if((M|0)>=(n|0)){K=r;L=35;break a}M=M+1|0;N=c[m>>2]|0;O=c[q>>2]|0;P=c[o>>2]|0}}else if((s|0)==1){r=c[m>>2]|0;n=c[o>>2]|0;u=f+(r>>>3)|0;C=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(r&7)>>>30;u=r+2|0;r=n>>>0>u>>>0?u:n;c[m>>2]=r;u=f+(r>>>3)|0;t=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(r&7)>>>30;u=r+2|0;c[m>>2]=n>>>0>u>>>0?u:n;n=t+1|0;c[j>>2]=n;a[e|0]=0;a[g+87628+n|0]=C|16;C=c[j>>2]|0;if((t|0)==0){Q=C}else{n=0;u=C;while(1){C=d[u-n+(g+87628)|0]|0;r=c[m>>2]|0;x=c[o>>2]|0;D=(c[q>>2]|0)+(r>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(r&7)>>>30;D=r+2|0;c[m>>2]=x>>>0>D>>>0?D:x;a[(c[j>>2]|0)+~n+(g+87628)|0]=C+254-(E<<1);E=n+1|0;C=c[j>>2]|0;if((E|0)<(t|0)){n=E;u=C}else{Q=C;break}}}u=a[1720680+Q|0]|0;n=c[m>>2]|0;t=c[o>>2]|0;C=c[q>>2]|0;E=C+(n>>>3)|0;x=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(n&7)>>>((32-u|0)>>>0);E=n+u|0;u=t>>>0>E>>>0?E:t;c[m>>2]=u;if((c[j>>2]|0)==0){K=x;L=35;break}else{R=0;S=u;T=C;U=t}while(1){t=d[T+(S>>>3)|0]<<(S&7)>>>7;c[m>>2]=((S|0)<(U|0))+S;a[(c[j>>2]|0)-R+(g+12)|0]=t&1;t=R+1|0;if(!(t>>>0<(c[j>>2]|0)>>>0)){K=x;L=35;break a}R=t;S=c[m>>2]|0;T=c[q>>2]|0;U=c[o>>2]|0}}else{A=0;B=c[j>>2]|0}}while(0);do{if((L|0)==35){o=c[j>>2]|0;if(!(K>>>0>(o+1|0)>>>0)){A=K;B=o;break}KIb(c[b+4>>2]|0,16,2475752,(v=i,i=i+8|0,c[v>>2]=K,v)|0);i=v;w=-1;i=h;return w|0}}while(0);K=1;while(1){if(K>>>0>B>>>0){break}if((d[K-1+(g+87628)|0]|0)>>>0>(d[g+87628+K|0]|0)>>>0){L=39;break}else{K=K+1|0}}if((L|0)==39){KIb(c[b+4>>2]|0,16,2466688,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1;i=h;return w|0}v=B>>>0>1>>>0?2:1;b=g+20|0;c[b>>2]=v;a[g+87637|0]=a[e|0]|0;a[g+87637+v|0]=a[g+87628+B|0]|0;B=c[p>>2]|0;if((c[b>>2]|0)>>>0>1>>>0){do{if((B|0)==0){V=(c[j>>2]|0)>>>1}else{if((B&1|0)!=0){b=A-1|0;V=(c[j>>2]|0)-((b|0)>1?b:1)|0;break}if((A|0)==0){V=1;break}else if((A|0)==1){V=(c[j>>2]|0)-1|0;break}else{V=A-1|0;break}}}while(0);a[g+87638|0]=a[g+87628+V|0]|0}V=g+14568|0;c[g+14564>>2]=-((c[V>>2]|0)!=(k|0)|0);c[V>>2]=-1;if(!((B&1|0)==0|(A|0)==0)){c[V>>2]=1-A+(c[j>>2]|0);w=0;i=h;return w|0}if(!((B|0)==2&A>>>0>1>>>0)){w=0;i=h;return w|0}c[V>>2]=A-1;w=0;i=h;return w|0}function mkb(e,f,h,i){e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0.0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;j=c[e+40>>2]|0;if((i|0)==1){k=(j|0)==1?2:1}else{k=1}l=c[e+262884>>2]&1;m=(c[h+92>>2]|0)==0;if((j|0)==0|(i|0)==0){n=m?7:6;o=m?60:31;p=m?3387544:3387624;q=m?3387524:3387604}else{n=m?6:5;o=m?24:12;p=m?3387584:3387664;q=m?3387564:3387644}m=c[p>>2]|0;p=c[q>>2]|0;q=h+8|0;if((c[q>>2]|0)==0){r=0;s=h+86416|0;t=s;u=h+86416+(r*192|0)|0;v=u;nrc(t|0,v|0,192)|0;return}i=f+8|0;j=f+16|0;w=f|0;f=32-n|0;x=0;while(1){a:do{if((a[h+24+x|0]|0)==0){y=c[i>>2]|0;z=c[j>>2]|0;A=c[w>>2]|0;B=A+(y>>>3)|0;C=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(y&7)>>>(f>>>0);B=y+n|0;y=z>>>0>B>>>0?B:z;c[i>>2]=y;D=+((ca(C,k)|0)>>>0>>>0);C=x+1|0;g[h+86416+(C*192|0)>>2]=D;B=h+12+C|0;if((c[e+262880+(d[B]<<2)>>2]|0)>>>0>1>>>0){E=1;F=D;G=y}else{break}do{y=A+(G>>>3)|0;H=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(G&7)>>>23;y=b[m+(H<<2)>>1]|0;I=b[m+(H<<2)+2>>1]|0;H=I<<16>>16;do{if(I<<16>>16<0){J=G+9|0;K=z>>>0>J>>>0?J:z;J=A+(K>>>3)|0;L=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(K&7)>>>((H+32|0)>>>0))+y|0;J=b[m+(L<<2)>>1]|0;M=b[m+(L<<2)+2>>1]|0;L=M<<16>>16;if(!(M<<16>>16<0)){N=L;O=J;P=K;break}M=K-H|0;K=z>>>0>M>>>0?M:z;M=A+(K>>>3)|0;Q=((je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>((L+32|0)>>>0))+J|0;N=b[m+(Q<<2)+2>>1]|0;O=b[m+(Q<<2)>>1]|0;P=K}else{N=H;O=y;P=G}}while(0);y=N+P|0;G=z>>>0>y>>>0?y:z;c[i>>2]=G;F=F+ +(ca(O-o|0,k)|0);g[h+86416+(C*192|0)+(E<<2)>>2]=F;E=E+1|0;}while(E>>>0<(c[e+262880+(d[B]<<2)>>2]|0)>>>0)}else{B=x+1|0;C=h+12+B|0;z=a[C]|0;if(z<<24>>24==(a[h+12+x|0]|0)){if((c[e+262880+((z&255)<<2)>>2]|0)==0){break}A=c[j>>2]|0;y=c[w>>2]|0;H=0;I=c[i>>2]|0;while(1){D=+g[h+86416+(x*192|0)+(H<<2)>>2];K=y+(I>>>3)|0;Q=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(I&7)>>>23;K=b[p+(Q<<2)>>1]|0;J=b[p+(Q<<2)+2>>1]|0;Q=J<<16>>16;do{if(J<<16>>16<0){L=I+9|0;M=A>>>0>L>>>0?L:A;L=y+(M>>>3)|0;R=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>((Q+32|0)>>>0))+K|0;L=b[p+(R<<2)>>1]|0;S=b[p+(R<<2)+2>>1]|0;R=S<<16>>16;if(!(S<<16>>16<0)){T=R;U=L;V=M;break}S=M-Q|0;M=A>>>0>S>>>0?S:A;S=y+(M>>>3)|0;W=((je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(M&7)>>>((R+32|0)>>>0))+L|0;T=b[p+(W<<2)+2>>1]|0;U=b[p+(W<<2)>>1]|0;V=M}else{T=Q;U=K;V=I}}while(0);K=T+V|0;I=A>>>0>K>>>0?K:A;c[i>>2]=I;g[h+86416+(B*192|0)+(H<<2)>>2]=D+ +(ca(U-o|0,k)|0);H=H+1|0;if(!(H>>>0<(c[e+262880+(d[C]<<2)>>2]|0)>>>0)){break a}}}if(!(z<<24>>24==0)){if((c[e+262880+((z&255)<<2)>>2]|0)==0){break}H=c[j>>2]|0;I=c[w>>2]|0;A=0;y=c[i>>2]|0;while(1){X=+g[h+86416+(x*192|0)+(A+l>>1<<2)>>2];K=I+(y>>>3)|0;Q=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(y&7)>>>23;K=b[p+(Q<<2)>>1]|0;J=b[p+(Q<<2)+2>>1]|0;Q=J<<16>>16;do{if(J<<16>>16<0){M=y+9|0;W=H>>>0>M>>>0?M:H;M=I+(W>>>3)|0;L=((je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(W&7)>>>((Q+32|0)>>>0))+K|0;M=b[p+(L<<2)>>1]|0;R=b[p+(L<<2)+2>>1]|0;L=R<<16>>16;if(!(R<<16>>16<0)){Y=L;Z=M;_=W;break}R=W-Q|0;W=H>>>0>R>>>0?R:H;R=I+(W>>>3)|0;S=((je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(W&7)>>>((L+32|0)>>>0))+M|0;Y=b[p+(S<<2)+2>>1]|0;Z=b[p+(S<<2)>>1]|0;_=W}else{Y=Q;Z=K;_=y}}while(0);K=Y+_|0;y=H>>>0>K>>>0?K:H;c[i>>2]=y;g[h+86416+(B*192|0)+(A<<2)>>2]=X+ +(ca(Z-o|0,k)|0);A=A+1|0;if(!(A>>>0<(c[e+262880+(d[C]<<2)>>2]|0)>>>0)){break a}}}if((c[e+262880>>2]|0)==0){break}else{$=0}do{if(($|0)==0){aa=0}else{aa=($<<1)-l|0}D=+g[h+86416+(x*192|0)+(aa<<2)>>2];A=c[i>>2]|0;y=c[j>>2]|0;H=c[w>>2]|0;I=H+(A>>>3)|0;z=(je(d[I]|d[I+1|0]<<8|d[I+2|0]<<16|d[I+3|0]<<24|0)|0)<<(A&7)>>>23;I=b[p+(z<<2)>>1]|0;K=b[p+(z<<2)+2>>1]|0;z=K<<16>>16;do{if(K<<16>>16<0){Q=A+9|0;J=y>>>0>Q>>>0?Q:y;Q=H+(J>>>3)|0;W=((je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(J&7)>>>((z+32|0)>>>0))+I|0;Q=b[p+(W<<2)>>1]|0;S=b[p+(W<<2)+2>>1]|0;W=S<<16>>16;if(!(S<<16>>16<0)){ba=W;da=Q;ea=J;break}S=J-z|0;J=y>>>0>S>>>0?S:y;S=H+(J>>>3)|0;M=((je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(J&7)>>>((W+32|0)>>>0))+Q|0;ba=b[p+(M<<2)+2>>1]|0;da=b[p+(M<<2)>>1]|0;ea=J}else{ba=z;da=I;ea=A}}while(0);A=ba+ea|0;c[i>>2]=y>>>0>A>>>0?A:y;g[h+86416+(B*192|0)+($<<2)>>2]=D+ +(ca(da-o|0,k)|0);$=$+1|0;}while($>>>0<(c[e+262880+(d[C]<<2)>>2]|0)>>>0)}}while(0);C=x+1|0;B=c[q>>2]|0;if(C>>>0<B>>>0){x=C}else{r=B;break}}s=h+86416|0;t=s;u=h+86416+(r*192|0)|0;v=u;nrc(t|0,v|0,192)|0;return}function nkb(e,f,h,i){e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=c[e+40>>2]|0;if((i|0)==1){k=(j|0)==1?2:1}else{k=1}l=(j|0)==0|(i|0)==0;i=l?31:12;j=l?c[846906]|0:c[846916]|0;m=l?c[846921]|0:c[846926]|0;l=h+20|0;if((c[l>>2]|0)==0){n=0;o=h+87568|0;p=o;q=h+87568+(n*20|0)|0;r=q;c[p>>2]=c[r>>2];c[p+4>>2]=c[r+4>>2];c[p+8>>2]=c[r+8>>2];c[p+12>>2]=c[r+12>>2];c[p+16>>2]=c[r+16>>2];return}s=f+8|0;t=f+16|0;u=f|0;f=e+262888|0;e=0;while(1){do{if((a[h+29+e|0]|0)==0){v=c[s>>2]|0;w=c[t>>2]|0;x=c[u>>2]|0;y=x+(v>>>3)|0;z=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(v&7)>>>27;y=v+5|0;v=w>>>0>y>>>0?y:w;c[s>>2]=v;A=+((ca(z,k)|0)>>>0>>>0);z=e+1|0;g[h+87568+(z*20|0)>>2]=A;if((c[f>>2]|0)>>>0>1>>>0){B=1;C=A;D=v}else{E=z;break}while(1){v=x+(D>>>3)|0;y=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(D&7)>>>23;v=b[j+(y<<2)>>1]|0;F=b[j+(y<<2)+2>>1]|0;y=F<<16>>16;do{if(F<<16>>16<0){G=D+9|0;H=w>>>0>G>>>0?G:w;G=x+(H>>>3)|0;I=((je(d[G]|d[G+1|0]<<8|d[G+2|0]<<16|d[G+3|0]<<24|0)|0)<<(H&7)>>>((y+32|0)>>>0))+v|0;G=b[j+(I<<2)>>1]|0;J=b[j+(I<<2)+2>>1]|0;I=J<<16>>16;if(!(J<<16>>16<0)){K=I;L=G;M=H;break}J=H-y|0;H=w>>>0>J>>>0?J:w;J=x+(H>>>3)|0;N=((je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(H&7)>>>((I+32|0)>>>0))+G|0;K=b[j+(N<<2)+2>>1]|0;L=b[j+(N<<2)>>1]|0;M=H}else{K=y;L=v;M=D}}while(0);v=K+M|0;y=w>>>0>v>>>0?v:w;c[s>>2]=y;A=C+ +(ca(L-i|0,k)|0);g[h+87568+(z*20|0)+(B<<2)>>2]=A;v=B+1|0;if(v>>>0<(c[f>>2]|0)>>>0){B=v;C=A;D=y}else{E=z;break}}}else{z=e+1|0;if((c[f>>2]|0)==0){E=z;break}w=c[t>>2]|0;x=c[u>>2]|0;y=0;v=c[s>>2]|0;while(1){A=+g[h+87568+(e*20|0)+(y<<2)>>2];F=x+(v>>>3)|0;H=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(v&7)>>>23;F=b[m+(H<<2)>>1]|0;N=b[m+(H<<2)+2>>1]|0;H=N<<16>>16;if(N<<16>>16<0){N=v+9|0;G=w>>>0>N>>>0?N:w;N=x+(G>>>3)|0;I=((je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(G&7)>>>((H+32|0)>>>0))+F|0;O=b[m+(I<<2)+2>>1]|0;P=b[m+(I<<2)>>1]|0;Q=G}else{O=H;P=F;Q=v}F=O+Q|0;H=w>>>0>F>>>0?F:w;c[s>>2]=H;g[h+87568+(z*20|0)+(y<<2)>>2]=A+ +(ca(P-i|0,k)|0);F=y+1|0;if(F>>>0<(c[f>>2]|0)>>>0){y=F;v=H}else{E=z;break}}}}while(0);z=c[l>>2]|0;if(E>>>0<z>>>0){e=E}else{n=z;break}}o=h+87568|0;p=o;q=h+87568+(n*20|0)|0;r=q;c[p>>2]=c[r>>2];c[p+4>>2]=c[r+4>>2];c[p+8>>2]=c[r+8>>2];c[p+12>>2]=c[r+12>>2];c[p+16>>2]=c[r+16>>2];return}function okb(a){a=a|0;var e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;h=c[a+24>>2]|0;if((h|0)==0){b[a+263154>>1]=b[a+262994>>1]|0;b[a+263156>>1]=b[a+262994+(c[a+262880>>2]<<1)>>1]|0;c[a+262892>>2]=1;i=e;return}j=+g[611560+(h-1<<2)>>2];h=a+263154|0;k=h|0;l=a+263156|0;m=c[a+68>>2]&65535;b[f>>1]=m;n=a+263216|0;o=c[n>>2]|0;if((o|0)!=0){p=1;q=m;do{q=(d[p-1+(a+263220)|0]|0)+q&65535;b[f+(p<<1)>>1]=q;p=p+1|0;}while(!(p>>>0>o>>>0))}o=h;h=a+262880|0;p=c[h>>2]|0;nrc(o|0,a+262994|0,(p<<1)+2|0)|0;q=c[n>>2]|0;if(q>>>0>1>>>0){nrc(a+263154+(p+1<<1)|0,f+2|0,(q<<1)-2|0)|0;r=c[n>>2]|0;s=c[h>>2]|0}else{r=q;s=p}cd(o|0,s+r|0,2,116);r=c[n>>2]|0;n=(c[h>>2]|0)-1+r|0;h=a+262892|0;c[h>>2]=n;if(k>>>0<(a+263154+(n<<1)|0)>>>0){t=l;u=k;v=n}else{i=e;return}a:while(1){n=t;k=v;b:while(1){w=b[n>>1]|0;l=b[u>>1]|0;if(!(+(w&65535|0)<j*+(l&65535|0))){x=9;break}c:do{if(w<<16>>16==l<<16>>16){y=k}else{s=0;while(1){if((s|0)>(r|0)){y=k;break c}if((b[f+(s<<1)>>1]|0)==w<<16>>16){z=0;break}else{s=s+1|0}}while(1){if((z|0)>(r|0)){break}if((b[f+(z<<1)>>1]|0)==l<<16>>16){x=19;break b}else{z=z+1|0}}b[u>>1]=w;y=c[h>>2]|0}}while(0);l=y-1|0;c[h>>2]=l;if(!(u>>>0<(a+263154+(l<<1)|0)>>>0)){x=21;break a}n=n+2|0;k=l}if((x|0)==9){x=0;l=u+2|0;b[l>>1]=w;A=l}else if((x|0)==19){x=0;l=u+2|0;b[l>>1]=w;A=l}if(A>>>0<(a+263154+(k<<1)|0)>>>0){t=n+2|0;u=A;v=k}else{x=21;break}}if((x|0)==21){i=e;return}}function pkb(a,c){a=a|0;c=c|0;return(b[a>>1]|0)-(b[c>>1]|0)|0}function qkb(){var a=0;a=0;do{g[8815024+(a<<2)>>2]=+ad(+(+(a-200|0)*.25));a=a+1|0;}while((a|0)<428);return}function rkb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;e=c[a+60>>2]|0;c[e>>2]=a;f=c[a+792>>2]|0;do{if((f|0)==24){c[a+140>>2]=3}else if((f|0)==8){c[a+140>>2]=11;g=c[a+96>>2]|0;h=c[a+100>>2]|0;j=(h|0)>1024?1024:h;h=e+1044|0;c[h>>2]=j;if((j|0)<=3){break}j=e+20|0;k=g;g=0;while(1){l=k;c[j+(g<<2)>>2]=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|-16777216;l=g+1|0;if((l|0)<((c[h>>2]|0)/4|0|0)){k=k+4|0;g=l}else{break}}}else if((f|0)==16){c[a+140>>2]=46}else{KIb(a,16,2140360,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;m=-1;i=b;return m|0}}while(0);f=UHb()|0;c[e+16>>2]=f;m=(f|0)==0?-12:0;i=b;return m|0}function skb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=c[f+24>>2]|0;j=c[f+28>>2]|0;f=c[a+60>>2]|0;if((j|0)<4){KIb(a,16,2438720,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1094995529;i=g;return l|0}m=f+16|0;n=N4a(a,c[m>>2]|0)|0;if((n|0)<0){l=n;i=g;return l|0}n=h;o=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=h+4|0;p=j-4|0;q=(c[a+792>>2]|0)/8|0;r=c[a+52>>2]|0;do{if((r|0)==877871425){s=f+4|0;if((j|0)>-1){c[s>>2]=h;c[f+12>>2]=h;c[f+8>>2]=h+j;YUa(a,c[m>>2]|0,8,s)|0;t=p;break}else{KIb(0,0,2239272,(k=i,i=i+24|0,c[k>>2]=2198400,c[k+8>>2]=2166896,c[k+16>>2]=135,k)|0);i=k;Hd();return 0}}else if((r|0)==1129529665){if((o|0)==1){s=f+4|0;if((p|0)>-1){c[s>>2]=n;c[f+12>>2]=n;c[f+8>>2]=h+j;YUa(a,c[m>>2]|0,8,s)|0;t=p;break}else{KIb(0,0,2239272,(k=i,i=i+24|0,c[k>>2]=2198400,c[k+8>>2]=2166896,c[k+16>>2]=135,k)|0);i=k;Hd();return 0}}else if((o|0)==0){s=a+120|0;u=c[s>>2]|0;v=(ca(u,q)|0)+q&~q;w=c[a+124>>2]|0;x=ca(v,w)|0;if((p|0)<(x|0)){l=-1094995529;i=g;return l|0}if((w|0)>0){y=n;z=w;A=u}else{t=p;break}while(1){u=z-1|0;w=c[m>>2]|0;nrc((c[w>>2]|0)+(ca(c[w+32>>2]|0,u)|0)|0,y|0,ca(A,q)|0)|0;if((u|0)<=0){break}y=y+v|0;z=u;A=c[s>>2]|0}t=p-x|0;break}else{KIb(a,16,2351424,(k=i,i=i+8|0,c[k>>2]=o,k)|0);i=k;l=-1094995529;i=g;return l|0}}else{KIb(a,16,2289712,(k=i,i=i+8|0,c[k>>2]=r,k)|0);i=k;l=-1;i=g;return l|0}}while(0);if((c[a+140>>2]|0)==11){nrc(c[(c[m>>2]|0)+4>>2]|0,f+20|0,c[f+1044>>2]|0)|0}c[e>>2]=1;e=YHb(b,c[m>>2]|0)|0;l=(e|0)<0?e:t;i=g;return l|0}function tkb(a){a=a|0;VHb((c[a+60>>2]|0)+16|0);return 0}function ukb(b){b=b|0;var e=0,f=0,h=0,i=0,j=0,k=0;e=c[b+60>>2]|0;c[e+4>>2]=b;Gub();f=0;while(1){a[3621616+(f*3|0)|0]=(f|0)/25|0;h=(f|0)%25|0;a[3621617+(f*3|0)|0]=(h|0)/5|0;a[3621618+(f*3|0)|0]=(h|0)%5|0;h=f+1|0;if((h|0)<128){f=h}else{i=0;break}}while(1){c[9906640+(i*12|0)>>2]=(((d[1443168+(i*3|0)|0]|0)<<24)-16777216|0)/3|0;c[9906644+(i*12|0)>>2]=(((d[1443169+(i*3|0)|0]|0)<<24)-16777216|0)/3|0;c[9906648+(i*12|0)>>2]=(((d[1443170+(i*3|0)|0]|0)<<24)-16777216|0)/3|0;f=i+1|0;if((f|0)<32){i=f}else{j=0;break}}do{c[9905104+(j*12|0)>>2]=(((d[3621616+(j*3|0)|0]|0)<<24)-33554432|0)/5|0;c[9905108+(j*12|0)>>2]=(((d[3621617+(j*3|0)|0]|0)<<24)-33554432|0)/5|0;c[9905112+(j*12|0)>>2]=(((d[3621618+(j*3|0)|0]|0)<<24)-33554432|0)/5|0;c[9904048+(j<<3)>>2]=((((j|0)/11|0)<<24)-83886080|0)/11|0;c[9904052+(j<<3)>>2]=((((j|0)%11|0)<<24)-83886080|0)/11|0;j=j+1|0;}while((j|0)<128);c[2476268]=-7190235;c[2476269]=-4793490;c[2476270]=-2396745;c[2476271]=0;c[2476272]=2396745;c[2476273]=4793490;c[2476274]=7190235;c[2475996]=-7829367;c[2475997]=-6710886;c[2475998]=-5592405;c[2475999]=-4473924;c[2476e3]=-3355443;c[2476001]=-2236962;c[2476002]=-1118481;c[2476003]=0;c[2476004]=1118481;c[2476005]=2236962;c[2476006]=3355443;c[2476007]=4473924;c[2476008]=5592405;c[2476009]=6710886;c[2476010]=7829367;j=0;do{g[8983688+(j<<2)>>2]=+Kqc(1.0,(j>>5)-5-(j>>7<<3)|0)*+(j&31|32|0);j=j+1|0;}while((j|0)<256);OPa(e+54556|0,8,1,1.0)|0;OPa(e+54492|0,9,1,1.0)|0;Fqb(e+77568|0,5.0,256);l8(e+54620|0,b);j=b+88|0;qHb(e+55864|0,c[j>>2]&8388608);Akb(e+55900|0,c[j>>2]&8388608);yfa(e+55952|0,b);AIb(e+54204|0,0);c[b+420>>2]=8;j=c[b+440>>2]|0;if((j|0)==2){i=b+456|0;c[i>>2]=3;c[i+4>>2]=0}else if((j|0)==1){j=b+456|0;c[j>>2]=4;c[j+4>>2]=0}j=b+416|0;i=c[j>>2]|0;do{if((i|0)>1){f=b+456|0;h=c[f>>2]|0;k=c[f+4>>2]|0;if((h|0)==4&(k|0)==0){c[j>>2]=1;break}if(!((i|0)>2&((h|0)==3&(k|0)==0))){break}c[j>>2]=2}}while(0);c[e+44992>>2]=1;c[e+56e3>>2]=e+63232;c[e+56028>>2]=e+70400;c[e+56004>>2]=e+64256;c[e+56032>>2]=e+71424;c[e+56008>>2]=e+65280;c[e+56036>>2]=e+72448;c[e+56012>>2]=e+66304;c[e+56040>>2]=e+73472;c[e+56016>>2]=e+67328;c[e+56044>>2]=e+74496;c[e+56020>>2]=e+68352;c[e+56048>>2]=e+75520;c[e+56024>>2]=e+69376;c[e+56052>>2]=e+76544;return 0}function vkb(f,j,k,l){f=f|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0.0,na=0.0,oa=0,pa=0.0,qa=0,ra=0.0,sa=0.0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0.0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0;m=i;i=i+1168|0;n=m|0;o=m+64|0;p=m+72|0;q=m+1096|0;r=m+1128|0;s=m+1136|0;t=j;u=c[l+24>>2]|0;v=c[l+28>>2]|0;l=c[f+60>>2]|0;w=l;do{if((v|0)>1){x=u;if(!((d[x]|d[x+1|0]<<8)<<16>>16<<16>>16==2935)){y=4;break}ef[c[l+55720>>2]&4095](l+86784|0,x,(v|0)>32768?16384:v>>1)}else{y=4}}while(0);if((y|0)==4){nrc(l+86784|0,u|0,(v|0)>32768?32768:v)|0}u=l+86784|0;x=l+8|0;z=v<<3;A=z>>>0>2147483639>>>0|(u|0)==0;B=A?0:u;u=A?0:z;z=x;c[z>>2]=B;c[l+20>>2]=u;A=l+24|0;c[A>>2]=u+8;c[l+12>>2]=B+(u>>3);u=l+16|0;c[u>>2]=0;c[o>>2]=n;B=x;x=U$(B,o)|0;do{if((x|0)==0){c[l+47080>>2]=d[n+4|0]|0;o=d[n+5|0]|0;C=l+52|0;c[C>>2]=o;c[l+56>>2]=d[n+6|0]|0;D=l+60|0;c[D>>2]=d[n+7|0]|0;E=a[n+8|0]|0;F=E&255;c[l+64>>2]=F;c[l+47084>>2]=d[n+32|0]|0;c[l+44>>2]=e[n+34>>1]|0;c[l+40>>2]=c[n+36>>2];H=d[n+40|0]|0;c[l+44928>>2]=H;I=H-F|0;c[l+44924>>2]=I;F=I+1|0;I=l+44932|0;c[I>>2]=F;H=l+36|0;c[H>>2]=e[n+42>>1]|0;J=l+72|0;c[J>>2]=0;K=l+76|0;c[K>>2]=c[n+16>>2];L=l+80|0;c[L>>2]=4;M=l+84|0;c[M>>2]=c[n+20>>2];N=l+88|0;c[N>>2]=4;c[l+92>>2]=0;c[l+48>>2]=c[n+28>>2];c[l+28>>2]=d[n+9|0]|0;c[l+32>>2]=c[n+12>>2];c[l+104>>2]=c[n+56>>2];O=l+108|0;c[O>>2]=0;P=l+112|0;c[P>>2]=0;if(E<<24>>24==0){Q=o}else{c[w+45016+(F<<2)>>2]=0;c[w+45044+(c[I>>2]<<2)>>2]=7;c[w+45092+(c[I>>2]<<2)>>2]=2;c[w+212+(c[I>>2]<<2)>>2]=0;Q=c[C>>2]|0}C=l+100|0;if((Q|0)>=11){c[C>>2]=1;R=vpb(w)|0;y=31;break}c[C>>2]=0;c[l+136>>2]=2;c[l+140>>2]=1;c[l+144>>2]=1;c[l+148>>2]=1;c[l+152>>2]=0;c[l+47116>>2]=0;c[l+156>>2]=1;c[l+160>>2]=1;mrc(l+1888|0,0,28)|0;C=c[A>>2]|0;I=c[z>>2]|0;F=(c[D>>2]|0)==0|0;D=c[u>>2]|0;while(1){o=D+5|0;E=C>>>0>o>>>0?o:C;c[u>>2]=E;o=((E|0)<(C|0))+E|0;if((128>>>((E&7)>>>0)&d[I+(E>>>3)|0]|0)==0){U=o}else{E=o+8|0;U=C>>>0>E>>>0?E:C}c[u>>2]=U;E=((U|0)<(C|0))+U|0;if((d[I+(U>>>3)|0]&128>>>((U&7)>>>0)|0)==0){V=E}else{o=E+8|0;V=C>>>0>o>>>0?o:C}c[u>>2]=V;o=((V|0)<(C|0))+V|0;if((d[I+(V>>>3)|0]&128>>>((V&7)>>>0)|0)==0){W=o}else{E=o+7|0;W=C>>>0>E>>>0?E:C}c[u>>2]=W;if((F|0)==0){break}else{F=F-1|0;D=W}}D=W+2|0;F=C>>>0>D>>>0?D:C;c[u>>2]=F;D=d[I+(F>>>3)|0]|0;E=((F|0)<(C|0))+F|0;c[u>>2]=E;o=(D&128>>>((F&7)>>>0)|0)!=0;do{if((Q|0)==6){if(o){F=I+(E>>>3)|0;D=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>30;F=E+2|0;X=C>>>0>F>>>0?F:C;c[u>>2]=X;c[J>>2]=D;D=I+(X>>>3)|0;F=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(X&7)>>>29;D=X+3|0;X=C>>>0>D>>>0?D:C;c[u>>2]=X;c[L>>2]=F;F=I+(X>>>3)|0;D=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(X&7)>>>29;F=X+3|0;X=C>>>0>F>>>0?F:C;c[u>>2]=X;c[N>>2]=D>>>0<3>>>0?3:D;D=I+(X>>>3)|0;F=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(X&7)>>>29;D=X+3|0;X=C>>>0>D>>>0?D:C;c[u>>2]=X;c[K>>2]=F;F=I+(X>>>3)|0;D=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(X&7)>>>29;F=X+3|0;X=C>>>0>F>>>0?F:C;c[u>>2]=X;c[M>>2]=D>>>0<3>>>0?3:D;Y=X}else{Y=E}X=d[I+(Y>>>3)|0]|0;D=((Y|0)<(C|0))+Y|0;c[u>>2]=D;if((X&128>>>((Y&7)>>>0)|0)==0){Z=D;break}X=I+(D>>>3)|0;F=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(D&7)>>>30;X=D+2|0;D=C>>>0>X>>>0?X:C;c[u>>2]=D;c[O>>2]=F;F=I+(D>>>3)|0;X=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>30;F=D+2|0;c[P>>2]=X;X=(C>>>0>F>>>0?F:C)+10|0;F=C>>>0>X>>>0?X:C;c[u>>2]=F;Z=F}else{if(o){F=E+14|0;X=C>>>0>F>>>0?F:C;c[u>>2]=X;_=X}else{_=E}X=d[I+(_>>>3)|0]|0;F=((_|0)<(C|0))+_|0;c[u>>2]=F;if((X&128>>>((_&7)>>>0)|0)==0){Z=F;break}X=F+14|0;F=C>>>0>X>>>0?X:C;c[u>>2]=F;Z=F}}while(0);E=d[I+(Z>>>3)|0]|0;o=((Z|0)<(C|0))+Z|0;c[u>>2]=o;if((E&128>>>((Z&7)>>>0)|0)==0){$=H;y=42;break}E=I+(o>>>3)|0;P=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(o&7)>>>26;E=o+6|0;o=C>>>0>E>>>0?E:C;c[u>>2]=o;E=P;P=o;while(1){o=P+8|0;aa=C>>>0>o>>>0?o:C;if((E|0)==0){break}else{E=E-1|0;P=aa}}c[u>>2]=aa;$=H;y=42}else{R=x;y=31}}while(0);a:do{if((y|0)==31){if((R|0)==(-16976906|0)){KIb(f,16,2487168,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;ca=-1094995529;i=m;return ca|0}else if((R|0)==(-117640202|0)){da=-117640202;y=49;break}else if((R|0)==(-33754122|0)){KIb(f,16,2475728,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;da=-33754122;y=49;break}else if((R|0)==0){$=l+36|0;y=42;break}else if((R|0)==(-100862986|0)){da=-100862986;y=49;break}else if((R|0)==(-84085770|0)){do{if((c[l+28>>2]|0)!=1){if((c[l+32>>2]|0)!=0){break}KIb(f,16,2428800,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;da=-84085770;y=49;break a}}while(0);KIb(f,24,2439672,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;c[k>>2]=0;ca=v;i=m;return ca|0}else if((R|0)==(-67308554|0)){KIb(f,16,2456872,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;da=-67308554;y=49;break}else if((R|0)==(-50531338|0)){KIb(f,16,2466664,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;da=-50531338;y=49;break}else{c[k>>2]=0;ca=R;i=m;return ca|0}}}while(0);b:do{if((y|0)==42){if((c[$>>2]|0)>(v|0)){KIb(f,16,2418184,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;da=-67308554;y=49;break}R=f+696|0;do{if((c[R>>2]&65537|0)!=0){H=DGb(1)|0;if((EGb(H,0,l+86786|0,(c[$>>2]|0)-2|0)|0)==0){break}KIb(f,16,2409352,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;if((c[R>>2]&8|0)==0){da=-100862986;y=49;break b}else{ca=-1094995529}i=m;return ca|0}}while(0);c[f+412>>2]=c[l+44>>2];c[f+72>>2]=c[l+40>>2];ea=0;fa=c[l+44928>>2]|0;ga=l+45e3|0;y=51}}while(0);do{if((y|0)==49){$=c[l+44928>>2]|0;if(($|0)==0){KIb(f,16,2401592,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;ca=-1094995529;i=m;return ca|0}else{R=l+45e3|0;if((c[R>>2]|0)!=($|0)){ea=da;fa=$;ga=R;y=51;break}ha=da;ia=l+44996|0;break}}}while(0);do{if((y|0)==51){c[ga>>2]=fa;da=l+60|0;R=c[da>>2]|0;$=l+44996|0;c[$>>2]=R;if((c[l+64>>2]|0)==0){ja=R}else{H=R|8;c[$>>2]=H;ja=H}H=c[l+44928>>2]|0;do{if((H|0)>1){x=f+456|0;aa=c[x>>2]|0;Z=c[x+4>>2]|0;if((aa|0)==4&(Z|0)==0){c[ga>>2]=1;c[$>>2]=1;ka=1;la=1;break}if(!((H|0)>2&((aa|0)==3&(Z|0)==0))){ka=fa;la=ja;break}c[ga>>2]=2;c[$>>2]=2;ka=2;la=2}else{ka=fa;la=ja}}while(0);ma=+g[1201664+(c[l+76>>2]<<2)>>2];g[l+128>>2]=ma;na=+g[1201664+(c[l+84>>2]<<2)>>2];g[l+132>>2]=na;g[l+120>>2]=.7071067690849304;g[l+124>>2]=.7071067690849304;if((H|0)==(ka|0)){ha=ea;ia=$;break}Z=c[l+44924>>2]|0;if((la&8|0)!=0&(Z|0)==(ka|0)){ha=ea;ia=$;break}aa=l+44924|0;if((Z|0)>0){Z=0;x=R;while(1){g[w+44936+(Z<<3)>>2]=+g[1201664+(d[2101496+(x*10|0)+(Z<<1)|0]<<2)>>2];g[w+44936+(Z<<3)+4>>2]=+g[1201664+(d[2101496+(x*10|0)+(Z<<1)+1|0]<<2)>>2];_=Z+1|0;Y=c[da>>2]|0;if((_|0)<(c[aa>>2]|0)){Z=_;x=Y}else{oa=Y;break}}}else{oa=R}if(!((oa|0)<2|(oa&1|0)==0)){g[l+44948>>2]=ma;g[l+44944>>2]=ma}if((oa-4|0)>>>0<2>>>0){x=oa-2|0;pa=na*.7071067811865476;g[w+44936+(x<<3)+4>>2]=pa;g[w+44936+(x<<3)>>2]=pa;qa=c[da>>2]|0}else{qa=oa}if((qa-6|0)>>>0<2>>>0){g[w+44936+(qa-3<<3)+4>>2]=na;g[w+44936+(qa-4<<3)>>2]=na}x=c[aa>>2]|0;if((x|0)>0){ra=0.0;sa=0.0;ta=0}else{ha=ea;ia=$;break}do{sa=sa+ +g[w+44936+(ta<<3)>>2];ra=ra+ +g[w+44936+(ta<<3)+4>>2];ta=ta+1|0;}while((ta|0)<(x|0));na=1.0/sa;ma=1.0/ra;x=0;do{da=w+44936+(x<<3)|0;g[da>>2]=na*+g[da>>2];da=w+44936+(x<<3)+4|0;g[da>>2]=ma*+g[da>>2];x=x+1|0;ua=c[aa>>2]|0;}while((x|0)<(ua|0));if((c[$>>2]|0)==1&(ua|0)>0){va=0}else{ha=ea;ia=$;break}while(1){x=w+44936+(va<<3)|0;g[x>>2]=(+g[x>>2]+ +g[w+44936+(va<<3)+4>>2])*.7071067811865476;x=va+1|0;if((x|0)<(ua|0)){va=x}else{ha=ea;ia=$;break}}}}while(0);ea=l+45e3|0;c[f+416>>2]=c[ea>>2];va=c[ia>>2]|0;ua=e[1967928+((va&-9)<<1)>>1]|0;ta=0;qa=f+448|0;oa=(va&8|0)==0;c[qa>>2]=oa?ua:ua|8;c[qa+4>>2]=oa?ta:ta|0;ta=c[l+56>>2]|0;oa=f+464|0;c[oa>>2]=ta;do{if((ta|0)==7){if((c[l+44928>>2]|0)<=1){break}c[oa>>2]=8}}while(0);oa=l+48|0;c[j+76>>2]=c[oa>>2]<<8;ta=M4a(f,t,0)|0;if((ta|0)<0){ca=ta;i=m;return ca|0}ta=c[l+64>>2]|0;qa=c[ia>>2]|0;ua=l+79616|0;va=ua;ka=l+55972|0;la=ka;ja=ua;c[s>>2]=ja;c[ka>>2]=ja;ja=l+80640|0;c[s+4>>2]=ja;c[l+55976>>2]=ja;ja=l+81664|0;c[s+8>>2]=ja;c[l+55980>>2]=ja;ja=l+82688|0;c[s+12>>2]=ja;c[l+55984>>2]=ja;ja=l+83712|0;c[s+16>>2]=ja;c[l+55988>>2]=ja;ja=l+84736|0;c[s+20>>2]=ja;c[l+55992>>2]=ja;ja=l+85760|0;c[s+24>>2]=ja;c[l+55996>>2]=ja;ja=qa&-9;qa=l+44928|0;ua=c[qa>>2]|0;if((ua|0)>0){fa=j;ga=0;$=ua;while(1){if((ga|0)<(c[ea>>2]|0)){c[la+(d[1444760+(ja*12|0)+(ta*6|0)+ga|0]<<2)>>2]=c[fa+(ga<<2)>>2];wa=c[qa>>2]|0}else{wa=$}ua=ga+1|0;if((ua|0)<(wa|0)){ga=ua;$=wa}else{break}}}if((c[oa>>2]|0)>0){wa=r|0;$=l+44924|0;ga=l+60|0;fa=l+140|0;ua=l+144|0;x=l+45012|0;aa=l+100|0;da=l+876|0;R=l+896|0;Z=l+908|0;H=l+900|0;Y=l+4|0;_=l+45072|0;Q=l+45016|0;W=l+45044|0;V=l+45092|0;U=l+148|0;n=l+136|0;P=l+152|0;E=e[722180]|0;C=l+28|0;I=l+47116|0;o=l+47108|0;O=l+47112|0;M=l+156|0;K=l+160|0;N=q+28|0;L=q+24|0;J=q+20|0;F=l+45048|0;X=l+45052|0;D=l+55944|0;xa=l+56004|0;ya=l+44936|0;za=l+44992|0;Aa=l+56028|0;Ba=ka;ka=l+71424|0;Ca=l+70400|0;Da=l+73472|0;Ea=l+72448|0;Fa=l+74496|0;Ga=l+55952|0;Ha=l+45004|0;Ia=l+316|0;Ja=l+47080|0;Ka=l+44932|0;La=l+55920|0;Ma=l+47104|0;Na=l+47084|0;Oa=l+47092|0;Pa=l+47096|0;Qa=l+47088|0;Ra=l+47100|0;Sa=l+240|0;Ta=l+320|0;Ua=l+216|0;Va=l+220|0;Wa=f;f=l+881|0;Xa=l+904|0;Ya=l+912|0;Za=l+54468|0;_a=j;j=ha;$a=0;while(1){c:do{if((j|0)==0){ab=c[$>>2]|0;bb=c[ga>>2]|0;mrc(wa|0,0,7)|0;cb=(ab|0)<1;if((c[fa>>2]|0)==0|cb){db=0}else{eb=0;fb=1;while(1){gb=c[u>>2]|0;hb=d[(c[z>>2]|0)+(gb>>>3)|0]<<(gb&7)>>>7;c[u>>2]=((gb|0)<(c[A>>2]|0))+gb;gb=hb&1;c[w+54464+(fb<<2)>>2]=gb;if((fb|0)>1){ib=(gb|0)==(c[Za>>2]|0)?eb:1}else{ib=eb}gb=fb+1|0;if((gb|0)>(ab|0)){db=ib;break}else{eb=ib;fb=gb}}}if(!((c[ua>>2]|0)==0|cb)){fb=1;do{eb=c[u>>2]|0;gb=d[(c[z>>2]|0)+(eb>>>3)|0]<<(eb&7)>>>7;c[u>>2]=((eb|0)<(c[A>>2]|0))+eb;c[w+54176+(fb<<2)>>2]=gb&1;fb=fb+1|0;}while((fb|0)<=(ab|0))}fb=($a|0)==0;gb=(c[ga>>2]|0)==0|0;while(1){eb=c[u>>2]|0;hb=c[z>>2]|0;jb=d[hb+(eb>>>3)|0]|0;kb=c[A>>2]|0;lb=((eb|0)<(kb|0))+eb|0;c[u>>2]=lb;do{if((jb&128>>>((eb&7)>>>0)|0)==0){if(!fb){break}g[w+45004+(gb<<2)>>2]=1.0}else{mb=hb+(lb>>>3)|0;nb=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(lb&7)>>>24;mb=lb+8|0;c[u>>2]=kb>>>0>mb>>>0?mb:kb;ra=+g[8983688+(nb<<2)>>2];sa=+g[x>>2];if(ra<=1.0&sa>1.0){g[w+45004+(gb<<2)>>2]=ra;break}else{g[w+45004+(gb<<2)>>2]=+T(+ra,+sa);break}}}while(0);if((gb|0)==0){break}gb=gb-1|0}d:do{if((c[aa>>2]|0)==0){y=125}else{gb=c[u>>2]|0;if(fb){ob=gb;pb=c[z>>2]|0;qb=c[A>>2]|0}else{kb=c[z>>2]|0;lb=d[kb+(gb>>>3)|0]|0;hb=c[A>>2]|0;eb=((gb|0)<(hb|0))+gb|0;c[u>>2]=eb;if((lb&128>>>((gb&7)>>>0)|0)==0){y=125;break}else{ob=eb;pb=kb;qb=hb}}hb=d[pb+(ob>>>3)|0]<<(ob&7)>>>7;kb=((ob|0)<(qb|0))+ob|0;c[u>>2]=kb;eb=hb&1;c[da>>2]=eb;if((eb|0)==0){if(cb){y=136;break}else{rb=1}while(1){a[w+880+rb|0]=0;a[w+929+rb|0]=1;eb=rb+1|0;if((eb|0)>(ab|0)){y=125;break d}else{rb=eb}}}do{if((c[ga>>2]|0)==1){a[f]=1;sb=kb;tb=qb;ub=pb}else{if(cb){sb=kb;tb=qb;ub=pb;break}else{vb=1;wb=kb;xb=pb;yb=qb}while(1){eb=d[xb+(wb>>>3)|0]<<(wb&7)>>>7;c[u>>2]=((wb|0)<(yb|0))+wb;a[w+880+vb|0]=eb&1;eb=vb+1|0;zb=c[u>>2]|0;if((eb|0)>(ab|0)){break}vb=eb;wb=zb;xb=c[z>>2]|0;yb=c[A>>2]|0}sb=zb;tb=c[A>>2]|0;ub=c[z>>2]|0}}while(0);kb=ub+(sb>>>3)|0;eb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(sb&7)>>>30;kb=sb+2|0;hb=tb>>>0>kb>>>0?kb:tb;c[u>>2]=hb;kb=ub+(hb>>>3)|0;gb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(hb&7)>>>29;kb=hb+3|0;hb=tb>>>0>kb>>>0?kb:tb;c[u>>2]=hb;kb=gb+2|0;if(kb>>>0>7>>>0){Ab=gb-5+kb|0}else{Ab=kb}kb=ub+(hb>>>3)|0;gb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(hb&7)>>>29;kb=hb+3|0;c[u>>2]=tb>>>0>kb>>>0?kb:tb;kb=gb+5|0;if(kb>>>0>7>>>0){Bb=gb-2+kb|0}else{Bb=kb}kb=(eb*12|0)+25|0;eb=(Ab*12|0)+25|0;if((Ab|0)>=(Bb|0)){KIb(c[Y>>2]|0,16,2387720,(ba=i,i=i+16|0,c[ba>>2]=Ab,c[ba+8>>2]=Bb,ba)|0);i=ba;break}if((kb|0)<(eb|0)){c[Xa>>2]=kb;c[R>>2]=eb;c[H>>2]=(Bb*12|0)+25;xkb(B,$a,c[aa>>2]|0,Ab,Bb,1393208,Z,Ya);y=125;break}else{KIb(c[Y>>2]|0,16,2380800,(ba=i,i=i+16|0,c[ba>>2]=kb,c[ba+8>>2]=eb,ba)|0);i=ba;break}}}while(0);do{if((y|0)==125){y=0;if((c[da>>2]|0)==0|cb){y=136;break}else{Cb=1}while(1){eb=w+929+Cb|0;do{if((a[w+880+Cb|0]|0)==0){a[eb]=1}else{if((a[eb]|0)==0){kb=c[u>>2]|0;gb=d[(c[z>>2]|0)+(kb>>>3)|0]|0;c[u>>2]=((kb|0)<(c[A>>2]|0))+kb;if((gb&128>>>((kb&7)>>>0)|0)==0){break}}a[eb]=0;kb=c[u>>2]|0;gb=c[A>>2]|0;hb=c[z>>2]|0;lb=hb+(kb>>>3)|0;jb=(je(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(kb&7)>>>27;lb=kb+5|0;kb=gb>>>0>lb>>>0?lb:gb;c[u>>2]=kb;sa=+(jb>>>0>>>0)*.03125;jb=hb+(kb>>>3)|0;hb=d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0;jb=kb+2|0;c[u>>2]=gb>>>0>jb>>>0?jb:gb;if((c[Z>>2]|0)<=0){break}gb=(je(hb|0)|0)<<(kb&7);kb=((gb>>>30)*-3|0)+25|0;gb=c[R>>2]|0;hb=0;while(1){jb=d[w+912+hb|0]|0;ra=+((jb>>>1)+gb|0)/+(c[H>>2]|0)-sa;if(ra<0.0){Db=0.0}else{Db=ra>1.0?1.0:ra}ra=+S(Db*3.0);ma=+S(1.0-Db);lb=c[u>>2]|0;nb=c[A>>2]|0;mb=c[z>>2]|0;Eb=mb+(lb>>>3)|0;Fb=(je(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(lb&7)>>>28;Eb=lb+4|0;lb=nb>>>0>Eb>>>0?Eb:nb;c[u>>2]=lb;Eb=mb+(lb>>>3)|0;mb=(je(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(lb&7)>>>30;Eb=lb+2|0;c[u>>2]=nb>>>0>Eb>>>0?Eb:nb;na=+(((Fb|0)==15?mb<<1:mb|4)<<kb-Fb|0)*1.1920928955078125e-7;g[w+936+(Cb*68|0)+(hb<<2)>>2]=ra*na;g[w+1412+(Cb*68|0)+(hb<<2)>>2]=ma*na;Fb=hb+1|0;if((Fb|0)<(c[Z>>2]|0)){gb=jb+gb|0;hb=Fb}else{break}}}}while(0);eb=Cb+1|0;if((eb|0)>(ab|0)){y=136;break}else{Cb=eb}}}}while(0);e:do{if((y|0)==136){y=0;do{if((c[aa>>2]|0)==0){eb=c[u>>2]|0;hb=c[z>>2]|0;gb=d[hb+(eb>>>3)|0]|0;kb=c[A>>2]|0;Fb=((eb|0)<(kb|0))+eb|0;c[u>>2]=Fb;if((gb&128>>>((eb&7)>>>0)|0)!=0){mrc(wa|0,3,7)|0;eb=d[hb+(Fb>>>3)|0]<<(Fb&7)>>>7;c[u>>2]=((Fb|0)<(kb|0))+Fb;Fb=eb&1;c[w+164+($a<<2)>>2]=Fb;Gb=Fb;y=141;break}if(fb){KIb(c[Y>>2]|0,16,2344368,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}else{Fb=w+164+($a<<2)|0;c[Fb>>2]=c[w+164+($a-1<<2)>>2];Hb=Fb;break}}else{if((c[w+188+($a<<2)>>2]|0)==0){Hb=w+164+($a<<2)|0;break}else{mrc(wa|0,3,7)|0;Gb=c[w+164+($a<<2)>>2]|0;y=141;break}}}while(0);do{if((y|0)==141){y=0;Fb=w+164+($a<<2)|0;if((Gb|0)==0){if(!cb){eb=1;do{c[w+212+(eb<<2)>>2]=0;c[w+344+(eb<<2)>>2]=1;eb=eb+1|0;}while((eb|0)<=(ab|0))}c[I>>2]=c[aa>>2];c[Sa>>2]=0;Hb=Fb;break}if((bb|0)<2){KIb(c[Y>>2]|0,16,2374408,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}do{if((c[aa>>2]|0)==0){y=146}else{eb=c[u>>2]|0;kb=d[(c[z>>2]|0)+(eb>>>3)|0]|0;c[u>>2]=((eb|0)<(c[A>>2]|0))+eb;if((kb&128>>>((eb&7)>>>0)|0)!=0){QIb(c[Y>>2]|0,2367160,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}if((c[ga>>2]|0)!=2){y=146;break}c[Ua>>2]=1;c[Va>>2]=1}}while(0);do{if((y|0)==146){y=0;if(cb){break}else{Ib=1}do{eb=c[u>>2]|0;kb=d[(c[z>>2]|0)+(eb>>>3)|0]<<(eb&7)>>>7;c[u>>2]=((eb|0)<(c[A>>2]|0))+eb;c[w+212+(Ib<<2)>>2]=kb&1;Ib=Ib+1|0;}while((Ib|0)<=(ab|0))}}while(0);kb=c[u>>2]|0;if((bb|0)==2){eb=c[z>>2]|0;hb=d[eb+(kb>>>3)|0]<<(kb&7)>>>7;gb=c[A>>2]|0;jb=((kb|0)<(gb|0))+kb|0;c[u>>2]=jb;c[Sa>>2]=hb&1;Jb=jb;Kb=gb;Lb=eb}else{Jb=kb;Kb=c[A>>2]|0;Lb=c[z>>2]|0}kb=Lb+(Jb>>>3)|0;eb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Jb&7)>>>28;kb=Jb+4|0;gb=Kb>>>0>kb>>>0?kb:Kb;c[u>>2]=gb;if((c[da>>2]|0)==0){kb=Lb+(gb>>>3)|0;jb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(gb&7)>>>28;kb=gb+4|0;c[u>>2]=Kb>>>0>kb>>>0?kb:Kb;Mb=jb+3|0}else{Mb=((c[R>>2]|0)-37|0)/12|0}if((eb|0)<(Mb|0)){c[Q>>2]=(eb*12|0)+37;c[W>>2]=(Mb*12|0)+37;xkb(B,$a,c[aa>>2]|0,eb,Mb,1393232,Ia,Ta);Hb=Fb;break}else{KIb(c[Y>>2]|0,16,2352368,(ba=i,i=i+16|0,c[ba>>2]=eb,c[ba+8>>2]=Mb,ba)|0);i=ba;break e}}}while(0);eb=(c[Hb>>2]|0)!=0;do{if(!(cb|eb^1)){jb=0;kb=1;f:while(1){g:do{if((c[w+212+(kb<<2)>>2]|0)==0){c[w+344+(kb<<2)>>2]=1;Nb=jb}else{if((c[aa>>2]|0)==0){y=171}else{gb=w+344+(kb<<2)|0;if((c[gb>>2]|0)==0){y=171}else{Ob=gb}}do{if((y|0)==171){y=0;gb=c[u>>2]|0;hb=d[(c[z>>2]|0)+(gb>>>3)|0]|0;c[u>>2]=((gb|0)<(c[A>>2]|0))+gb;if((hb&128>>>((gb&7)>>>0)|0)==0){if(fb){y=180;break f}else{Nb=jb;break g}}else{Ob=w+344+(kb<<2)|0;break}}}while(0);c[Ob>>2]=0;gb=c[u>>2]|0;hb=c[A>>2]|0;mb=c[z>>2]|0;nb=mb+(gb>>>3)|0;Eb=(je(d[nb]|d[nb+1|0]<<8|d[nb+2|0]<<16|d[nb+3|0]<<24|0)|0)<<(gb&7)>>>30;nb=gb+2|0;gb=hb>>>0>nb>>>0?nb:hb;c[u>>2]=gb;nb=Eb*3|0;if((c[Ia>>2]|0)>0){Pb=0;Qb=gb;Rb=hb;Sb=mb}else{Nb=1;break}while(1){mb=Sb+(Qb>>>3)|0;hb=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(Qb&7)>>>28;mb=Qb+4|0;gb=Rb>>>0>mb>>>0?mb:Rb;c[u>>2]=gb;mb=Sb+(gb>>>3)|0;Eb=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(gb&7)>>>28;mb=gb+4|0;c[u>>2]=Rb>>>0>mb>>>0?mb:Rb;if((hb|0)==15){mb=Eb<<22;c[w+372+(kb*72|0)+(Pb<<2)>>2]=mb;Tb=mb}else{mb=Eb<<21|33554432;c[w+372+(kb*72|0)+(Pb<<2)>>2]=mb;Tb=mb}c[w+372+(kb*72|0)+(Pb<<2)>>2]=Tb>>hb+nb;hb=Pb+1|0;if((hb|0)>=(c[Ia>>2]|0)){Nb=1;break g}Pb=hb;Qb=c[u>>2]|0;Rb=c[A>>2]|0;Sb=c[z>>2]|0}}}while(0);nb=kb+1|0;if((nb|0)>(ab|0)){break}else{jb=Nb;kb=nb}}if((y|0)==180){y=0;KIb(c[Y>>2]|0,16,2338376,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}if((bb|0)!=2|(Nb|0)==0){break}if((c[Ia>>2]|0)>0){Ub=0}else{break}do{if((c[Sa>>2]|0)==0){Vb=0}else{kb=c[u>>2]|0;jb=d[(c[z>>2]|0)+(kb>>>3)|0]<<(kb&7)>>>7;c[u>>2]=((kb|0)<(c[A>>2]|0))+kb;Vb=jb&1}c[w+244+(Ub<<2)>>2]=Vb;Ub=Ub+1|0;}while((Ub|0)<(c[Ia>>2]|0))}}while(0);h:do{if((bb|0)==2){do{if(!((c[aa>>2]|0)!=0&fb)){jb=c[u>>2]|0;kb=d[(c[z>>2]|0)+(jb>>>3)|0]|0;c[u>>2]=((jb|0)<(c[A>>2]|0))+jb;if((kb&128>>>((jb&7)>>>0)|0)!=0){break}if(!fb){break h}KIb(c[Y>>2]|0,24,2332696,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;c[_>>2]=0;break h}}while(0);c[_>>2]=4;do{if(eb){jb=c[Q>>2]|0;if((jb|0)>=62){y=194;break}c[_>>2]=(jb|0)==37?2:3;Wb=0}else{y=194}}while(0);do{if((y|0)==194){y=0;if((c[da>>2]|0)==0){Wb=0;break}if((c[R>>2]|0)>=62){Wb=0;break}c[_>>2]=3;Wb=0}}while(0);do{jb=c[u>>2]|0;kb=d[(c[z>>2]|0)+(jb>>>3)|0]<<(jb&7)>>>7;c[u>>2]=((jb|0)<(c[A>>2]|0))+jb;c[w+45076+(Wb<<2)>>2]=kb&1;Wb=Wb+1|0;}while((Wb|0)<(c[_>>2]|0))}}while(0);kb=eb&1^1;if((kb|0)<=(c[qa>>2]|0)){jb=kb;do{if((c[aa>>2]|0)==0){Fb=2-((jb|0)==(c[Ka>>2]|0))|0;nb=c[u>>2]|0;hb=c[A>>2]|0;mb=(c[z>>2]|0)+(nb>>>3)|0;Eb=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(nb&7)>>>((32-Fb|0)>>>0);mb=Fb+nb|0;c[u>>2]=hb>>>0>mb>>>0?mb:hb;c[w+46912+($a*28|0)+(jb<<2)>>2]=Eb;Xb=Eb}else{Xb=c[w+46912+($a*28|0)+(jb<<2)>>2]|0}if((Xb|0)!=0){a[r+jb|0]=3}jb=jb+1|0;}while((jb|0)<=(c[qa>>2]|0))}i:do{if(!cb){jb=($a|0)<1;Eb=1;j:while(1){c[w+45016+(Eb<<2)>>2]=0;hb=w+46912+($a*28|0)+(Eb<<2)|0;do{if((c[hb>>2]|0)!=0){mb=w+45044+(Eb<<2)|0;nb=c[mb>>2]|0;do{if((c[w+212+(Eb<<2)>>2]|0)==0){if((a[w+880+Eb|0]|0)!=0){Fb=c[R>>2]|0;c[mb>>2]=Fb;Yb=Fb;break}Fb=c[u>>2]|0;gb=c[A>>2]|0;lb=(c[z>>2]|0)+(Fb>>>3)|0;Zb=(je(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(Fb&7);_b=Zb>>>26;lb=Fb+6|0;c[u>>2]=gb>>>0>lb>>>0?lb:gb;if(Zb>>>0>4093640703>>>0){break j}Zb=(_b*3|0)+73|0;c[mb>>2]=Zb;Yb=Zb}else{Zb=c[Q>>2]|0;c[mb>>2]=Zb;Yb=Zb}}while(0);mb=3<<(c[hb>>2]|0)-1;c[w+45092+(Eb<<2)>>2]=(Yb-4+mb|0)/(mb|0)|0;if(jb|(Yb|0)==(nb|0)){break}mrc(wa|0,3,7)|0}}while(0);Eb=Eb+1|0;if((Eb|0)>(ab|0)){break i}}KIb(c[Y>>2]|0,16,2327232,(ba=i,i=i+8|0,c[ba>>2]=_b,ba)|0);i=ba;break e}}while(0);do{if(eb){Eb=c[w+46912+($a*28|0)>>2]|0;if((Eb|0)==0){break}c[V>>2]=((c[W>>2]|0)-(c[Q>>2]|0)|0)/(3<<Eb-1|0)|0}}while(0);Eb=c[qa>>2]|0;k:do{if((kb|0)>(Eb|0)){$b=Eb}else{jb=kb;l:while(1){hb=w+46912+($a*28|0)+(jb<<2)|0;do{if((c[hb>>2]|0)!=0){mb=c[u>>2]|0;Zb=c[A>>2]|0;gb=c[z>>2]|0;lb=gb+(mb>>>3)|0;Fb=(je(d[lb]|d[lb+1|0]<<8|d[lb+2|0]<<16|d[lb+3|0]<<24|0)|0)<<(mb&7)>>>28;lb=mb+4|0;mb=Zb>>>0>lb>>>0?lb:Zb;c[u>>2]=mb;lb=(jb|0)!=0;ac=lb&1;bc=Fb<<(ac^1);a[w+45120+(jb<<8)|0]=bc;Fb=c[hb>>2]|0;cc=c[w+45092+(jb<<2)>>2]|0;dc=(c[w+45016+(jb<<2)>>2]|0)+ac|0;ac=((Fb|0)==3)+Fb|0;if((cc|0)>0){Fb=0;ec=0;fc=mb;while(1){mb=gb+(fc>>>3)|0;gc=(je(d[mb]|d[mb+1|0]<<8|d[mb+2|0]<<16|d[mb+3|0]<<24|0)|0)<<(fc&7)>>>25;mb=fc+7|0;hc=Zb>>>0>mb>>>0?mb:Zb;c[u>>2]=hc;c[p+(ec<<2)>>2]=d[3621616+(gc*3|0)|0]|0;c[p+(ec+1<<2)>>2]=d[3621617+(gc*3|0)|0]|0;c[p+(ec+2<<2)>>2]=d[3621618+(gc*3|0)|0]|0;gc=Fb+1|0;if((gc|0)<(cc|0)){Fb=gc;ec=ec+3|0;fc=hc}else{break}}}fc=bc&255;ec=cc*3|0;if((ec|0)>0){if((ac|0)==2){Fb=0;Zb=0;gb=fc;while(1){nb=gb-2+(c[p+(Zb<<2)>>2]|0)|0;if(nb>>>0>24>>>0){break l}hc=nb&255;a[Fb+dc+(w+45120+(jb<<8))|0]=hc;a[(Fb|1)+dc+(w+45120+(jb<<8))|0]=hc;hc=Zb+1|0;if((hc|0)<(ec|0)){Fb=Fb+2|0;Zb=hc;gb=nb}else{break}}}else if((ac|0)==4){gb=0;Zb=0;Fb=fc;while(1){cc=Fb-2+(c[p+(Zb<<2)>>2]|0)|0;if(cc>>>0>24>>>0){break l}bc=cc&255;a[gb+dc+(w+45120+(jb<<8))|0]=bc;a[(gb|1)+dc+(w+45120+(jb<<8))|0]=bc;a[(gb|2)+dc+(w+45120+(jb<<8))|0]=bc;a[(gb|3)+dc+(w+45120+(jb<<8))|0]=bc;bc=Zb+1|0;if((bc|0)<(ec|0)){gb=gb+4|0;Zb=bc;Fb=cc}else{break}}}else{Fb=(ac|0)==1;Zb=0;gb=0;cc=fc;while(1){bc=cc-2+(c[p+(gb<<2)>>2]|0)|0;if(bc>>>0>24>>>0){break l}if(Fb){a[Zb+dc+(w+45120+(jb<<8))|0]=bc;ic=Zb+1|0}else{ic=Zb}nb=gb+1|0;if((nb|0)<(ec|0)){Zb=ic;gb=nb;cc=bc}else{break}}}}if(!lb){break}if((jb|0)==(c[Ka>>2]|0)){break}cc=c[A>>2]|0;gb=(c[u>>2]|0)+2|0;c[u>>2]=cc>>>0>gb>>>0?gb:cc}}while(0);hb=jb+1|0;cc=c[qa>>2]|0;if((hb|0)>(cc|0)){$b=cc;break k}else{jb=hb}}KIb(c[Y>>2]|0,16,2321512,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}}while(0);do{if((c[U>>2]|0)!=0){Eb=c[u>>2]|0;jb=c[z>>2]|0;hb=d[jb+(Eb>>>3)|0]|0;cc=c[A>>2]|0;gb=((Eb|0)<(cc|0))+Eb|0;c[u>>2]=gb;if((hb&128>>>((Eb&7)>>>0)|0)==0){if(!fb){break}KIb(c[Y>>2]|0,16,2316424,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}else{Eb=jb+(gb>>>3)|0;hb=(je(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(gb&7)>>>30;Eb=gb+2|0;gb=cc>>>0>Eb>>>0?Eb:cc;c[u>>2]=gb;Eb=c[Na>>2]|0;c[Oa>>2]=(d[1443272+hb|0]|0)>>>(Eb>>>0);hb=jb+(gb>>>3)|0;Zb=(je(d[hb]|d[hb+1|0]<<8|d[hb+2|0]<<16|d[hb+3|0]<<24|0)|0)<<(gb&7)>>>30;hb=gb+2|0;gb=cc>>>0>hb>>>0?hb:cc;c[u>>2]=gb;c[Pa>>2]=(d[1444368+Zb|0]|0)>>>(Eb>>>0);Eb=jb+(gb>>>3)|0;Zb=(je(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(gb&7)>>>30;Eb=gb+2|0;gb=cc>>>0>Eb>>>0?Eb:cc;c[u>>2]=gb;c[Qa>>2]=e[1443264+(Zb<<1)>>1]|0;Zb=jb+(gb>>>3)|0;Eb=(je(d[Zb]|d[Zb+1|0]<<8|d[Zb+2|0]<<16|d[Zb+3|0]<<24|0)|0)<<(gb&7)>>>30;Zb=gb+2|0;gb=cc>>>0>Zb>>>0?Zb:cc;c[u>>2]=gb;c[Ra>>2]=e[1444856+(Eb<<1)>>1]|0;Eb=jb+(gb>>>3)|0;jb=(je(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(gb&7)>>>29;Eb=gb+3|0;c[u>>2]=cc>>>0>Eb>>>0?Eb:cc;c[Ma>>2]=b[1444232+(jb<<1)>>1]|0;if((kb|0)>($b|0)){break}else{jc=kb}do{jb=r+jc|0;cc=a[jb]|0;a[jb]=(cc&255)>>>0>2>>>0?cc:2;jc=jc+1|0;}while((jc|0)<=($b|0))}}}while(0);cc=c[aa>>2]|0;m:do{if((cc|0)==0|fb){do{if((c[n>>2]|0)!=0){jb=c[u>>2]|0;Eb=c[z>>2]|0;gb=d[Eb+(jb>>>3)|0]|0;Zb=c[A>>2]|0;hb=((jb|0)<(Zb|0))+jb|0;c[u>>2]=hb;if((gb&128>>>((jb&7)>>>0)|0)==0){break}jb=Eb+(hb>>>3)|0;Eb=(je(d[jb]|d[jb+1|0]<<8|d[jb+2|0]<<16|d[jb+3|0]<<24|0)|0)<<(hb&7)>>>26;jb=hb+6|0;c[u>>2]=Zb>>>0>jb>>>0?jb:Zb;Zb=(Eb<<4)+1073741584|0;if((kb|0)>($b|0)){kc=$b;break m}Eb=($a|0)!=0;jb=Eb^1;hb=0;gb=kb;while(1){if((gb|0)==(kb|0)){y=256}else{if((c[n>>2]|0)==2){y=256}else{lc=hb}}if((y|0)==256){y=0;ec=c[u>>2]|0;dc=c[A>>2]|0;Fb=(c[z>>2]|0)+(ec>>>3)|0;fc=(je(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(ec&7)>>>28;Fb=ec+4|0;c[u>>2]=dc>>>0>Fb>>>0?Fb:dc;lc=(fc|Zb)<<2}fc=w+47120+(gb<<2)|0;do{if(Eb){if((c[fc>>2]|0)==(lc|0)){break}dc=r+gb|0;Fb=a[dc]|0;a[dc]=(Fb&255)>>>0>1>>>0?Fb:1}}while(0);c[fc>>2]=lc;do{if((c[aa>>2]|0)==0){lb=w+47148+(gb<<2)|0;Fb=c[lb>>2]|0;dc=c[u>>2]|0;ec=c[A>>2]|0;ac=(c[z>>2]|0)+(dc>>>3)|0;bc=(je(d[ac]|d[ac+1|0]<<8|d[ac+2|0]<<16|d[ac+3|0]<<24|0)|0)<<(dc&7)>>>29;ac=dc+3|0;c[u>>2]=ec>>>0>ac>>>0?ac:ec;ec=e[1444352+(bc<<1)>>1]|0;c[lb>>2]=ec;if((Fb|0)==(ec|0)|jb){break}ec=r+gb|0;Fb=a[ec]|0;a[ec]=(Fb&255)>>>0>2>>>0?Fb:2}}while(0);fc=gb+1|0;Fb=c[qa>>2]|0;if((fc|0)>(Fb|0)){kc=Fb;break m}else{hb=lc;gb=fc}}}}while(0);if((cc|$a|0)!=0){kc=$b;break}KIb(c[Y>>2]|0,16,2312008,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}else{kc=$b}}while(0);n:do{if((c[P>>2]|0)==0){y=273}else{cc=c[u>>2]|0;gb=c[z>>2]|0;hb=d[gb+(cc>>>3)|0]|0;jb=c[A>>2]|0;Eb=((cc|0)<(jb|0))+cc|0;c[u>>2]=Eb;if((hb&128>>>((cc&7)>>>0)|0)==0){y=273;break}if((kb|0)>(kc|0)){mc=kc;break}else{nc=kb;oc=Eb;pc=jb;qc=gb}while(1){gb=w+47148+(nc<<2)|0;jb=c[gb>>2]|0;Eb=qc+(oc>>>3)|0;cc=(je(d[Eb]|d[Eb+1|0]<<8|d[Eb+2|0]<<16|d[Eb+3|0]<<24|0)|0)<<(oc&7)>>>29;Eb=oc+3|0;c[u>>2]=pc>>>0>Eb>>>0?Eb:pc;Eb=e[1444352+(cc<<1)>>1]|0;c[gb>>2]=Eb;if(!(fb|(jb|0)==(Eb|0))){Eb=r+nc|0;jb=a[Eb]|0;a[Eb]=(jb&255)>>>0>2>>>0?jb:2}jb=nc+1|0;Eb=c[qa>>2]|0;if((jb|0)>(Eb|0)){mc=Eb;break n}nc=jb;oc=c[u>>2]|0;pc=c[A>>2]|0;qc=c[z>>2]|0}}}while(0);do{if((y|0)==273){y=0;if((kb|0)>(kc|0)|(c[aa>>2]|0)!=0&fb^1){mc=kc;break}else{rc=kb}while(1){c[w+47148+(rc<<2)>>2]=E;jb=rc+1|0;Eb=c[qa>>2]|0;if((jb|0)>(Eb|0)){mc=Eb;break}else{rc=jb}}}}while(0);do{if((c[C>>2]|0)==0){jb=c[u>>2]|0;Eb=d[(c[z>>2]|0)+(jb>>>3)|0]|0;gb=c[A>>2]|0;cc=((jb|0)<(gb|0))+jb|0;c[u>>2]=cc;if((Eb&128>>>((jb&7)>>>0)|0)==0){break}jb=cc+10|0;c[u>>2]=gb>>>0>jb>>>0?jb:gb}}while(0);if(eb){gb=c[u>>2]|0;do{if((c[I>>2]|0)==0){jb=c[z>>2]|0;cc=d[jb+(gb>>>3)|0]|0;Eb=c[A>>2]|0;hb=((gb|0)<(Eb|0))+gb|0;c[u>>2]=hb;if((cc&128>>>((gb&7)>>>0)|0)!=0){sc=hb;tc=Eb;uc=jb;y=282;break}if((c[aa>>2]|$a|0)!=0){break}KIb(c[Y>>2]|0,16,2307384,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}else{sc=gb;tc=c[A>>2]|0;uc=c[z>>2]|0;y=282}}while(0);if((y|0)==282){y=0;gb=uc+(sc>>>3)|0;eb=(je(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(sc&7)>>>29;gb=sc+3|0;jb=tc>>>0>gb>>>0?gb:tc;c[u>>2]=jb;gb=uc+(jb>>>3)|0;Eb=(je(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(jb&7)>>>29;gb=jb+3|0;c[u>>2]=tc>>>0>gb>>>0?gb:tc;do{if(!fb){if((eb|0)==(c[o>>2]|0)){if((Eb|0)==(c[O>>2]|0)){break}}gb=a[wa]|0;a[wa]=(gb&255)>>>0>2>>>0?gb:2}}while(0);c[o>>2]=eb;c[O>>2]=Eb}c[I>>2]=0}do{if((c[M>>2]|0)==0){y=302}else{gb=c[u>>2]|0;jb=c[z>>2]|0;hb=d[jb+(gb>>>3)|0]|0;cc=c[A>>2]|0;Zb=((gb|0)<(cc|0))+gb|0;c[u>>2]=Zb;if((hb&128>>>((gb&7)>>>0)|0)==0){y=302;break}o:do{if((kb|0)<=(ab|0)){gb=jb+(Zb>>>3)|0;hb=(je(d[gb]|d[gb+1|0]<<8|d[gb+2|0]<<16|d[gb+3|0]<<24|0)|0)<<(Zb&7)>>>30;gb=Zb+2|0;c[u>>2]=cc>>>0>gb>>>0?gb:cc;c[w+53952+(kb<<2)>>2]=hb;p:do{if((hb|0)!=3){gb=kb;while(1){fc=r+gb|0;Fb=a[fc]|0;a[fc]=(Fb&255)>>>0>2>>>0?Fb:2;gb=gb+1|0;if((gb|0)>(ab|0)){vc=kb;break}Fb=c[u>>2]|0;fc=c[A>>2]|0;ec=(c[z>>2]|0)+(Fb>>>3)|0;lb=(je(d[ec]|d[ec+1|0]<<8|d[ec+2|0]<<16|d[ec+3|0]<<24|0)|0)<<(Fb&7)>>>30;ec=Fb+2|0;c[u>>2]=fc>>>0>ec>>>0?ec:fc;c[w+53952+(gb<<2)>>2]=lb;if((lb|0)==3){break p}}while(1){if((c[w+53952+(vc<<2)>>2]|0)==1){gb=c[u>>2]|0;lb=c[A>>2]|0;fc=(c[z>>2]|0)+(gb>>>3)|0;ec=(je(d[fc]|d[fc+1|0]<<8|d[fc+2|0]<<16|d[fc+3|0]<<24|0)|0)<<(gb&7)>>>29;fc=gb+3|0;c[u>>2]=lb>>>0>fc>>>0?fc:lb;lb=w+53980+(vc<<2)|0;c[lb>>2]=ec+1;ec=0;do{fc=c[u>>2]|0;gb=c[A>>2]|0;Fb=(c[z>>2]|0)+(fc>>>3)|0;bc=(je(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(fc&7)>>>27;Fb=fc+5|0;c[u>>2]=gb>>>0>Fb>>>0?Fb:gb;a[w+54008+(vc<<3)+ec|0]=bc;bc=c[u>>2]|0;gb=c[A>>2]|0;Fb=(c[z>>2]|0)+(bc>>>3)|0;fc=(je(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(bc&7)>>>28;Fb=bc+4|0;c[u>>2]=gb>>>0>Fb>>>0?Fb:gb;a[w+54064+(vc<<3)+ec|0]=fc;fc=c[u>>2]|0;gb=c[A>>2]|0;Fb=(c[z>>2]|0)+(fc>>>3)|0;bc=(je(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(fc&7)>>>29;Fb=fc+3|0;c[u>>2]=gb>>>0>Fb>>>0?Fb:gb;a[w+54120+(vc<<3)+ec|0]=bc;ec=ec+1|0;}while((ec|0)<(c[lb>>2]|0));lb=r+vc|0;ec=a[lb]|0;a[lb]=(ec&255)>>>0>2>>>0?ec:2}vc=vc+1|0;if((vc|0)>(ab|0)){break o}}}}while(0);KIb(c[Y>>2]|0,16,2301440,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}}while(0);wc=c[qa>>2]|0}}while(0);do{if((y|0)==302){y=0;if((mc|0)<0|fb^1){wc=mc;break}else{xc=0}while(1){c[w+53952+(xc<<2)>>2]=2;Eb=xc+1|0;eb=c[qa>>2]|0;if((Eb|0)>(eb|0)){wc=eb;break}else{xc=Eb}}}}while(0);q:do{if((kb|0)>(wc|0)){yc=wc}else{Eb=kb;while(1){eb=a[r+Eb|0]|0;if((eb&255)>>>0>2>>>0){Eub(w+45120+(Eb<<8)|0,c[w+45016+(Eb<<2)>>2]|0,c[w+45044+(Eb<<2)>>2]|0,w+48968+(Eb<<9)|0,w+52552+(Eb*100|0)|0)}if((eb&255)>>>0>1>>>0){if((Fub(Ja,w+52552+(Eb*100|0)|0,c[w+45016+(Eb<<2)>>2]|0,c[w+45044+(Eb<<2)>>2]|0,c[w+47148+(Eb<<2)>>2]|0,(Eb|0)==(c[Ka>>2]|0)|0,c[w+53952+(Eb<<2)>>2]|0,c[w+53980+(Eb<<2)>>2]|0,w+54008+(Eb<<3)|0,w+54064+(Eb<<3)|0,w+54120+(Eb<<3)|0,w+53252+(Eb*100|0)|0)|0)!=0){break}}if(!(eb<<24>>24==0)){Ge[c[La>>2]&255](w+53252+(Eb*100|0)|0,w+48968+(Eb<<9)|0,c[w+45016+(Eb<<2)>>2]|0,c[w+45044+(Eb<<2)>>2]|0,c[w+47120+(Eb<<2)>>2]|0,c[Ma>>2]|0,(c[w+1888+(Eb<<2)>>2]|0)!=0?1392664:1445064,w+47176+(Eb<<8)|0)}eb=Eb+1|0;cc=c[qa>>2]|0;if((eb|0)>(cc|0)){yc=cc;break q}else{Eb=eb}}KIb(c[Y>>2]|0,16,2290432,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;break e}}while(0);do{if((c[K>>2]|0)!=0){kb=c[u>>2]|0;Eb=c[z>>2]|0;eb=d[Eb+(kb>>>3)|0]|0;cc=c[A>>2]|0;Zb=((kb|0)<(cc|0))+kb|0;c[u>>2]=Zb;if((eb&128>>>((kb&7)>>>0)|0)==0){break}kb=Eb+(Zb>>>3)|0;Eb=(je(d[kb]|d[kb+1|0]<<8|d[kb+2|0]<<16|d[kb+3|0]<<24|0)|0)<<(Zb&7)>>>23;kb=Zb+9|0;Zb=cc>>>0>kb>>>0?kb:cc;c[u>>2]=Zb;if((Eb|0)==0){break}else{zc=Eb;Ac=Zb}do{zc=zc-1|0;Zb=Ac+8|0;Ac=cc>>>0>Zb>>>0?Zb:cc;}while((zc|0)!=0);c[u>>2]=Ac}}while(0);c[N>>2]=0;c[L>>2]=0;c[J>>2]=0;if((yc|0)>=1){cc=1;Zb=0;Eb=0;while(1){kb=Eb+1|0;zkb(w,$a,cc,q);do{if((c[w+212+(cc<<2)>>2]|0)==0){Bc=Zb;Cc=w+45044+(cc<<2)|0}else{if((Zb|0)!=0){Bc=Zb;Cc=W;break}zkb(w,$a,0,q);eb=c[Ia>>2]|0;if((eb|0)<=0){Bc=1;Cc=W;break}jb=0;hb=c[Q>>2]|0;ec=c[$>>2]|0;lb=eb;while(1){eb=a[w+320+jb|0]|0;bc=(eb&255)+hb|0;do{if((ec|0)<1){Dc=ec;Ec=lb}else{gb=w+244+(jb<<2)|0;if(eb<<24>>24==0){Dc=ec;Ec=lb;break}else{Fc=1}do{do{if((c[w+212+(Fc<<2)>>2]|0)!=0){Fb=c[w+372+(Fc*72|0)+(jb<<2)>>2]<<5;fc=Fb;ac=(Fb|0)<0|0?-1:0;Fb=hb;do{dc=c[w+56064+(Fb<<2)>>2]<<4;Erc(dc,(dc|0)<0|0?-1:0,fc,ac)|0;c[w+56064+(Fc<<10)+(Fb<<2)>>2]=G;Fb=Fb+1|0;}while((Fb|0)<(bc|0));if((Fc|0)!=2){break}if((c[gb>>2]|0)==0){break}else{Gc=hb}do{Fb=w+58112+(Gc<<2)|0;c[Fb>>2]=-(c[Fb>>2]|0);Gc=Gc+1|0;}while((Gc|0)<(bc|0))}}while(0);Fc=Fc+1|0;Hc=c[$>>2]|0;}while((Fc|0)<=(Hc|0));Dc=Hc;Ec=c[Ia>>2]|0}}while(0);eb=jb+1|0;if((eb|0)<(Ec|0)){jb=eb;hb=bc;ec=Dc;lb=Ec}else{Bc=1;Cc=W;break}}}}while(0);lb=c[Cc>>2]|0;ec=lb+1|0;mrc(w+56064+(kb<<10)+(lb<<2)|0,0,((ec|0)>256?ec:256)-lb<<2|0)|0;lb=cc+1|0;if((lb|0)>(c[qa>>2]|0)){break}else{cc=lb;Zb=Bc;Eb=kb}}}Eb=c[$>>2]|0;if((Eb|0)>=1){Zb=1;cc=Eb;while(1){do{if((c[w+54176+(Zb<<2)>>2]|0)==0){if((c[w+212+(Zb<<2)>>2]|0)==0){Ic=cc;break}Eb=c[Q>>2]|0;lb=c[W>>2]|0;if((Eb|0)<(lb|0)){Jc=Eb;Kc=lb}else{Ic=cc;break}while(1){if((a[w+47176+Jc|0]|0)==0){c[w+56064+(Zb<<10)+(Jc<<2)>>2]=0;Lc=c[W>>2]|0}else{Lc=Kc}lb=Jc+1|0;if((lb|0)<(Lc|0)){Jc=lb;Kc=Lc}else{break}}Ic=c[$>>2]|0}else{Ic=cc}}while(0);kb=Zb+1|0;if((kb|0)>(Ic|0)){break}else{Zb=kb;cc=Ic}}}do{if((c[ga>>2]|0)==2){cc=c[F>>2]|0;Zb=c[X>>2]|0;kb=(cc|0)>(Zb|0)?Zb:cc;cc=c[_>>2]|0;if((cc|0)>0){Mc=0;Nc=cc}else{break}while(1){cc=Mc+1|0;do{if((c[w+45076+(Mc<<2)>>2]|0)==0){Oc=Nc}else{Zb=d[1443288+cc|0]|0;lb=(kb|0)>(Zb|0)?Zb:kb;Zb=d[1443288+Mc|0]|0;if((Zb|0)<(lb|0)){Pc=Zb}else{Oc=Nc;break}do{Zb=w+57088+(Pc<<2)|0;Eb=c[Zb>>2]|0;ec=w+58112+(Pc<<2)|0;hb=c[ec>>2]|0;c[Zb>>2]=hb+Eb;c[ec>>2]=Eb-hb;Pc=Pc+1|0;}while((Pc|0)<(lb|0));Oc=c[_>>2]|0}}while(0);if((cc|0)<(Oc|0)){Mc=cc;Nc=Oc}else{break}}}}while(0);kb=c[qa>>2]|0;if((kb|0)<1){Qc=kb}else{kb=1;while(1){if((c[ga>>2]|0)==0){Rc=w+45004+(2-kb<<2)|0}else{Rc=Ha}xe[c[Ga>>2]&7](w+63232+(kb<<10)|0,w+56064+(kb<<10)|0,+g[Rc>>2]*2.384185791015625e-7,256);lb=kb+1|0;bc=c[qa>>2]|0;if((lb|0)>(bc|0)){Qc=bc;break}else{kb=lb}}}if((c[da>>2]|0)==0){Sc=Qc}else{tpb(w);Sc=c[qa>>2]|0}kb=c[ea>>2]|0;do{if((Sc|0)==(kb|0)){Tc=0}else{if((c[ia>>2]&8|0)==0){Tc=1;break}Tc=(c[$>>2]|0)!=(kb|0)}}while(0);do{if((db|0)==0){do{if(Tc){pe[c[D>>2]&1023](xa,ya,kb,c[$>>2]|0,256);if((c[za>>2]|0)!=0){break}c[za>>2]=1;pe[c[D>>2]&1023](Aa,ya,c[ea>>2]|0,c[$>>2]|0,128)}}while(0);ykb(w,c[ea>>2]|0)}else{r:do{if((c[za>>2]|0)!=0){c[za>>2]=0;switch(c[ga>>2]|0){case 0:case 2:{nrc(ka|0,Ca|0,1024)|0;break r;break};case 6:{mrc(Da|0,0,1024)|0;y=367;break};case 4:{y=367;break};case 7:{mrc(Fa|0,0,1024)|0;y=369;break};case 5:{y=369;break};case 3:{break};default:{break r}}if((y|0)==367){y=0;mrc(Ea|0,0,1024)|0;break}else if((y|0)==369){y=0;mrc(Da|0,0,1024)|0}nrc(Ea|0,ka|0,1024)|0;mrc(ka|0,0,1024)|0}}while(0);ykb(w,Sc);if(!Tc){break}pe[c[D>>2]&1023](Ba,ya,c[ea>>2]|0,c[$>>2]|0,256)}}while(0);Uc=0;Vc=c[ea>>2]|0;y=382;break c}}while(0);KIb(Wa,16,2394848,(ba=i,i=i+1|0,i=i+7&-8,c[ba>>2]=0,ba)|0);i=ba;Wc=1;y=379}else{Wc=j;y=379}}while(0);do{if((y|0)==379){y=0;if((c[ea>>2]|0)<=0){Xc=Wc;break}fb=$a<<8;ab=0;while(1){nrc((c[_a+(ab<<2)>>2]|0)+(fb<<2)|0,c[s+(ab<<2)>>2]|0,1024)|0;cb=ab+1|0;bb=c[ea>>2]|0;if((cb|0)<(bb|0)){ab=cb}else{Uc=Wc;Vc=bb;y=382;break}}}}while(0);do{if((y|0)==382){y=0;ab=(Vc|0)>0;if(ab){Yc=0}else{Xc=Uc;break}do{c[s+(Yc<<2)>>2]=c[la+(d[1444760+(ja*12|0)+(ta*6|0)+Yc|0]<<2)>>2];Yc=Yc+1|0;}while((Yc|0)<(Vc|0));if(ab){Zc=0;_c=Vc}else{Xc=Uc;break}while(1){if((Zc|0)==0){$c=a[1444760+(ja*12|0)+(ta*6|0)|0]|0;y=388}else{fb=a[1444760+(ja*12|0)+(ta*6|0)+Zc|0]|0;if(fb<<24>>24==0){ad=_c}else{$c=fb;y=388}}if((y|0)==388){y=0;fb=la+(($c&255)<<2)|0;c[fb>>2]=(c[fb>>2]|0)+1024;ad=c[ea>>2]|0}fb=Zc+1|0;if((fb|0)<(ad|0)){Zc=fb;_c=ad}else{Xc=Uc;break}}}}while(0);ab=$a+1|0;if((ab|0)<(c[oa>>2]|0)){j=Xc;$a=ab}else{bd=Xc;break}}}else{bd=ha}KHb(t,(bd|0)!=0|0);if((c[ea>>2]|0)>0){bd=0;do{nrc(va+(bd<<10)|0,c[s+(bd<<2)>>2]|0,1024)|0;bd=bd+1|0;}while((bd|0)<(c[ea>>2]|0))}ea=c[l+60>>2]|0;do{if((ea|0)==2){if((c[ia>>2]&-9|0)!=2){cd=0;break}if((c[l+104>>2]|0)==2){cd=1;break}cd=(c[l+112>>2]|0)==2?6:0}else{if((ea|0)<=5){cd=0;break}if((ea|0)!=(c[ia>>2]&-9|0)){cd=0;break}bd=c[l+108>>2]|0;if((bd|0)==2){cd=5;break}else if((bd|0)==3){cd=4;break}else{cd=0;break}}}while(0);ia=I4a(t,cd)|0;if((ia|0)<0){ca=ia;i=m;return ca|0}ia=QGb(t)|0;if((ia|0)==0){ca=-12;i=m;return ca|0}t=c[l+72>>2]|0;if((t|0)==1){c[ia>>2]=2}else if((t|0)==2){c[ia>>2]=1}else if((t|0)==3){c[ia>>2]=3}else{c[ia>>2]=0}h[ia+8>>3]=+g[1201664+(c[l+76>>2]<<2)>>2];h[ia+16>>3]=+g[1201664+(c[l+80>>2]<<2)>>2];h[ia+24>>3]=+g[1201664+(c[l+84>>2]<<2)>>2];h[ia+32>>3]=+g[1201664+(c[l+88>>2]<<2)>>2];if((c[l+92>>2]|0)==0){h[ia+40>>3]=0.0}else{h[ia+40>>3]=+g[1201536+(c[l+96>>2]<<2)>>2]}c[k>>2]=1;k=c[l+36>>2]|0;ca=(v|0)>(k|0)?k:v;i=m;return ca|0}function wkb(a){a=a|0;var b=0;b=c[a+60>>2]|0;PPa(b+54492|0);PPa(b+54556|0);return 0}function xkb(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;m=i;i=i+48|0;n=m|0;o=m+24|0;p=h-g|0;do{if((f|0)==0){q=3}else{h=b+8|0;r=c[h>>2]|0;s=d[(c[b>>2]|0)+(r>>>3)|0]|0;c[h>>2]=((r|0)<(c[b+16>>2]|0))+r;if((s&128>>>((r&7)>>>0)|0)!=0){q=3;break}if((e|0)==0){t=j+(g+1)|0;break}else{i=m;return}}}while(0);if((q|0)==3){q=p-1|0;if((q|0)>0){g=b+8|0;j=c[b>>2]|0;e=c[b+16>>2]|0;b=0;f=c[g>>2]|0;do{r=d[j+(f>>>3)|0]<<(f&7)>>>7;f=((f|0)<(e|0))+f|0;c[g>>2]=f;a[o+b|0]=r&1;b=b+1|0;}while((b|0)<(q|0))}t=o|0}o=(k|0)!=0;q=(l|0)==0;do{if(q&(o^1)){u=0}else{a[n|0]=12;if((p|0)>1){v=0;w=p;x=1}else{u=p;break}while(1){if((a[t+(x-1)|0]|0)==0){b=v+1|0;a[n+b|0]=12;y=w;z=b}else{b=n+v|0;a[b]=(a[b]|0)+12;y=w-1|0;z=v}b=x+1|0;if((b|0)<(p|0)){v=z;w=y;x=b}else{u=y;break}}}}while(0);if(o){c[k>>2]=u}if(q){i=m;return}nrc(l|0,n|0,u)|0;i=m;return}function ykb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((b|0)<1){return}d=a+54492|0;e=a+54536|0;f=a+78592|0;h=a+55880|0;i=a+77568|0;j=a+79104|0;k=j;l=a+54556|0;m=a+54600|0;n=1;do{if((c[a+54464+(n<<2)>>2]|0)==0){ef[c[e>>2]&4095](d,f,a+63232+(n<<10)|0);o=n-1|0;p=a+70400+(o<<10)|0;pe[c[h>>2]&1023](c[a+55972+(o<<2)>>2]|0,p|0,f,i,128);nrc(p|0,k|0,512)|0}else{p=0;do{g[a+78592+(p+128<<2)>>2]=+g[a+63232+(n<<10)+(p<<1<<2)>>2];p=p+1|0;}while((p|0)<128);ef[c[m>>2]&4095](l,f,j);p=n-1|0;o=a+70400+(p<<10)|0;pe[c[h>>2]&1023](c[a+55972+(p<<2)>>2]|0,o,f,i,128);p=0;do{g[a+78592+(p+128<<2)>>2]=+g[a+63232+(n<<10)+((p<<1|1)<<2)>>2];p=p+1|0;}while((p|0)<128);ef[c[m>>2]&4095](l,o,j)}n=n+1|0;}while((n|0)<=(b|0));return}function zkb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;if((c[b+1888+(f<<2)>>2]|0)!=0){if((e|0)==0){upb(b,f)}j=c[b+45016+(f<<2)>>2]|0;k=b+45044+(f<<2)|0;if((j|0)<(c[k>>2]|0)){l=j}else{i=h;return}do{c[b+56064+(f<<10)+(l<<2)>>2]=c[b+1916+(f*6144|0)+(l*24|0)+(e<<2)>>2]>>a[b+45120+(f<<8)+l|0];l=l+1|0;}while((l|0)<(c[k>>2]|0));i=h;return}k=c[b+45016+(f<<2)>>2]|0;l=c[b+45044+(f<<2)>>2]|0;if((f|0)==0){m=1}else{m=(c[b+54176+(f<<2)>>2]|0)!=0}if((k|0)>=(l|0)){i=h;return}e=b+4|0;j=b+16|0;n=b+24|0;o=b+8|0;p=b+54460|0;q=g+20|0;r=g+4|0;s=g|0;t=g+24|0;u=g+12|0;v=g+8|0;w=g+28|0;x=g+16|0;y=k;do{k=a[b+47176+(f<<8)+y|0]|0;z=k&255;a:do{switch(z|0){case 0:{if(!m){A=0;break a}B=c[p>>2]|0;c[b+54204+((B&63)<<2)>>2]=(c[b+54204+((B+9&63)<<2)>>2]|0)+(c[b+54204+((B+40&63)<<2)>>2]|0);B=c[p>>2]|0;c[p>>2]=B+1;A=((((c[b+54204+((B&63)<<2)>>2]|0)>>>8)*181|0)>>>8)-5931008|0;break};case 2:{B=c[t>>2]|0;if((B|0)==0){C=c[j>>2]|0;D=c[n>>2]|0;E=(c[o>>2]|0)+(C>>>3)|0;F=(je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0)<<(C&7)>>>25;E=C+7|0;c[j>>2]=D>>>0>E>>>0?E:D;D=c[9905104+(F*12|0)>>2]|0;c[u>>2]=c[9905108+(F*12|0)>>2];c[v>>2]=c[9905112+(F*12|0)>>2];c[t>>2]=2;A=D;break a}else{D=B-1|0;c[t>>2]=D;A=c[g+8+(D<<2)>>2]|0;break a}break};case 5:{D=c[j>>2]|0;B=c[n>>2]|0;F=(c[o>>2]|0)+(D>>>3)|0;E=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>28;F=D+4|0;c[j>>2]=B>>>0>F>>>0?F:B;A=c[9903984+(E<<2)>>2]|0;break};case 3:{E=c[j>>2]|0;B=c[n>>2]|0;F=(c[o>>2]|0)+(E>>>3)|0;D=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(E&7)>>>29;F=E+3|0;c[j>>2]=B>>>0>F>>>0?F:B;A=c[9905072+(D<<2)>>2]|0;break};case 4:{if((c[w>>2]|0)==0){D=c[j>>2]|0;B=c[n>>2]|0;F=(c[o>>2]|0)+(D>>>3)|0;E=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(D&7)>>>25;F=D+7|0;c[j>>2]=B>>>0>F>>>0?F:B;B=c[9904048+(E<<3)>>2]|0;c[x>>2]=c[9904052+(E<<3)>>2];c[w>>2]=1;A=B;break a}else{c[w>>2]=0;A=c[x>>2]|0;break a}break};case 1:{B=c[q>>2]|0;if((B|0)==0){E=c[j>>2]|0;F=c[n>>2]|0;D=(c[o>>2]|0)+(E>>>3)|0;C=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(E&7)>>>27;D=E+5|0;c[j>>2]=F>>>0>D>>>0?D:F;F=c[9906640+(C*12|0)>>2]|0;c[r>>2]=c[9906644+(C*12|0)>>2];c[s>>2]=c[9906648+(C*12|0)>>2];c[q>>2]=2;A=F;break a}else{F=B-1|0;c[q>>2]=F;A=c[g+(F<<2)>>2]|0;break a}break};default:{if((k&255)>>>0>15>>>0){KIb(c[e>>2]|0,16,2284256,(F=i,i=i+8|0,c[F>>2]=z,F)|0);i=F;G=15}else{G=z}F=d[687488+G|0]|0;B=c[j>>2]|0;C=c[n>>2]|0;D=(c[o>>2]|0)+(B>>>3)|0;E=(je(d[D]|d[D+1|0]<<8|d[D+2|0]<<16|d[D+3|0]<<24|0)|0)<<(B&7)>>32-F;D=B+F|0;c[j>>2]=C>>>0>D>>>0?D:C;A=E<<24-F}}}while(0);c[b+56064+(f<<10)+(y<<2)>>2]=A>>a[b+45120+(f<<8)+y|0];y=y+1|0;}while((y|0)<(l|0));i=h;return}function Akb(a,b){a=a|0;b=b|0;c[a>>2]=2236;c[a+4>>2]=446;c[a+8>>2]=2066;c[a+12>>2]=2230;c[a+16>>2]=1504;c[a+20>>2]=66;c[a+24>>2]=318;c[a+28>>2]=564;c[a+32>>2]=662;c[a+36>>2]=242;c[a+40>>2]=124;c[a+44>>2]=462;c[a+48>>2]=612;return}function Bkb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(!((c|0)!=0&(d|0)>0)){return}if((c|0)>0){e=0;f=b}else{b=0;do{b=b+1|0;}while((b|0)<(d|0));return}while(1){b=0;g=a[f]|0;h=f;do{h=h+256|0;i=a[h]|0;g=(i&255)>>>0<(g&255)>>>0?i:g;b=b+1|0;}while((b|0)<(c|0));a[f]=g;b=e+1|0;if((b|0)<(d|0)){e=b;f=f+1|0}else{break}}return}function Ckb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;if((c|0)>0){d=0;e=0}else{f=0;return f|0}while(1){g=b[a+(d<<1)>>1]|0;h=g<<16>>16;i=(g<<16>>16>-1?h:-h|0)|e;h=d+1|0;if((h|0)<(c|0)){d=h;e=i}else{f=i;break}}return f|0}function Dkb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=a;a=65535-(65536<<d)|0;f=b>>>1;if((f|0)==0){return}else{g=0}do{b=e+(g<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|1)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|2)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|3)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|4)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|5)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|6)<<2)|0;c[b>>2]=c[b>>2]<<d&a;b=e+((g|7)<<2)|0;c[b>>2]=c[b>>2]<<d&a;g=g+8|0;}while(g>>>0<f>>>0);return}function Ekb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=a;a=b;while(1){b=e+4|0;c[e>>2]=c[e>>2]>>d;f=e+8|0;c[b>>2]=c[b>>2]>>d;b=e+12|0;c[f>>2]=c[f>>2]>>d;f=e+16|0;c[b>>2]=c[b>>2]>>d;b=e+20|0;c[f>>2]=c[f>>2]>>d;f=e+24|0;c[b>>2]=c[b>>2]>>d;b=e+28|0;c[f>>2]=c[f>>2]>>d;c[b>>2]=c[b>>2]>>d;b=a-8|0;if((b|0)==0){break}else{e=e+32|0;a=b}}return}function Fkb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a;a=d;d=b;while(1){c[e>>2]=Lc(+(+g[d>>2]*16777216.0))|0;c[e+4>>2]=Lc(+(+g[d+4>>2]*16777216.0))|0;c[e+8>>2]=Lc(+(+g[d+8>>2]*16777216.0))|0;c[e+12>>2]=Lc(+(+g[d+12>>2]*16777216.0))|0;c[e+16>>2]=Lc(+(+g[d+16>>2]*16777216.0))|0;c[e+20>>2]=Lc(+(+g[d+20>>2]*16777216.0))|0;c[e+24>>2]=Lc(+(+g[d+24>>2]*16777216.0))|0;c[e+28>>2]=Lc(+(+g[d+28>>2]*16777216.0))|0;b=a-8|0;if((b|0)==0){break}else{e=e+32|0;a=b;d=d+32|0}}return}function Gkb(c,e,f,g,h,i,j,k){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((h|0)==-960){mrc(k|0,0,256)|0;return}l=~g;m=f;n=d[8779912+f|0]|0;while(1){f=(b[c+(n<<1)>>1]|0)-h-i|0;o=n+1|0;p=d[1445128+o|0]|0;q=(p|0)>(g|0)?g:p;if((m|0)<(q|0)){r=((f|0)>0?-(f&8160)|0:0)-i|0;f=~p;p=(l|0)>(f|0)?l:f;f=m;do{s=r+(b[e+(f<<1)>>1]|0)>>5;if((s|0)<0){t=0}else{t=(s|0)>63?63:s}a[k+f|0]=a[j+t|0]|0;f=f+1|0;}while((f|0)<(q|0));u=~p}else{u=m}if((q|0)<(g|0)){m=u;n=o}else{break}}return}function Hkb(a,c,e){a=a|0;c=c|0;e=e|0;var f=0;if((e|0)>0){f=e}else{return}do{f=f-1|0;e=a+((d[c+f|0]|0)<<1)|0;b[e>>1]=(b[e>>1]|0)+1;}while((f|0)>0);return}function Ikb(a){a=a|0;var b=0,c=0;b=0;c=0;do{c=((e[a+(b<<5)+30>>1]|0)<<4)+(((e[a+(b<<5)+28>>1]|0)*14|0)+(((e[a+(b<<5)+26>>1]|0)*12|0)+(((e[a+(b<<5)+24>>1]|0)*11|0)+(((e[a+(b<<5)+22>>1]|0)*10|0)+(((e[a+(b<<5)+20>>1]|0)*9|0)+(((e[a+(b<<5)+18>>1]|0)<<3)+(((e[a+(b<<5)+16>>1]|0)*7|0)+(((e[a+(b<<5)+14>>1]|0)*6|0)+(((e[a+(b<<5)+12>>1]|0)*5|0)+(((e[a+(b<<5)+10>>1]|0)<<2)+(((((e[a+(b<<5)+2>>1]|0)/3|0)&65535)*5|0)+c+((e[a+(b<<5)+6>>1]|0)*3|0)+((((e[a+(b<<5)+8>>1]|0)>>>1)+(((e[a+(b<<5)+4>>1]|0)/3|0)&65535)|0)*7|0))))))))))))|0;b=b+1|0;}while((b|0)<6);return c|0}function Jkb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=0}else{return}do{h=c[e+(g<<2)>>2]|0;i=(h|0)>-1?h:-h|0;if((i|0)==0){j=24}else{h=i>>>0>65535>>>0;k=h?i>>>16:i;i=h?16:0;if((k&65280|0)==0){l=i;m=k}else{l=i|8;m=k>>>8}j=23-l-(d[1359664+m|0]|0)&255}a[b+g|0]=j;g=g+1|0;}while((g|0)<(f|0));return}function Kkb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a+24|0;g=a+16|0;h=a+8|0;mrc(a|0,0,32)|0;if((e|0)>0){i=0;j=0;k=0;l=0;m=0;n=0;o=0;p=0;q=0}else{return}do{r=c[b+(i<<2)>>2]|0;s=c[d+(i<<2)>>2]|0;t=s+r|0;u=r-s|0;v=r;w=(r|0)<0|0?-1:0;r=Erc(v,w,v,w)|0;k=wrc(k,j,r,G)|0;j=G;r=s;w=(s|0)<0|0?-1:0;s=Erc(r,w,r,w)|0;m=wrc(m,l,s,G)|0;l=G;s=t;w=(t|0)<0|0?-1:0;t=Erc(s,w,s,w)|0;o=wrc(o,n,t,G)|0;n=G;t=u;w=(u|0)<0|0?-1:0;u=Erc(t,w,t,w)|0;q=wrc(q,p,u,G)|0;p=G;i=i+1|0;}while((i|0)<(e|0));c[a>>2]=k;c[a+4>>2]=j;c[h>>2]=m;c[h+4>>2]=l;c[g>>2]=o;c[g+4>>2]=n;c[f>>2]=q;c[f+4>>2]=p;return}function Lkb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0;e=a+12|0;f=a+8|0;h=a+4|0;mrc(a|0,0,16)|0;if((d|0)>0){i=0;j=0.0;k=0.0;l=0.0;m=0.0}else{return}do{n=+g[b+(i<<2)>>2];o=+g[c+(i<<2)>>2];p=n+o;q=n-o;j=n*n+j;g[a>>2]=j;k=o*o+k;g[h>>2]=k;l=p*p+l;g[f>>2]=l;m=q*q+m;g[e>>2]=m;i=i+1|0;}while((i|0)<(d|0));return}function Mkb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0.0,l=0,m=0.0,n=0.0,o=0.0;if((d|0)==1){if((f|0)<=0){return}h=c[a>>2]|0;if((e|0)>0){i=0}else{mrc(h|0,0,f<<2|0)|0;return}do{j=0;k=0.0;do{k=k+ +g[(c[a+(j<<2)>>2]|0)+(i<<2)>>2]*+g[b+(j<<3)>>2];j=j+1|0;}while((j|0)<(e|0));g[h+(i<<2)>>2]=k;i=i+1|0;}while((i|0)<(f|0));return}else if((d|0)==2){if((f|0)<=0){return}d=c[a>>2]|0;i=c[a+4>>2]|0;if((e|0)>0){l=0}else{h=0;do{g[d+(h<<2)>>2]=0.0;g[i+(h<<2)>>2]=0.0;h=h+1|0;}while((h|0)<(f|0));return}do{h=0;m=0.0;n=0.0;do{o=+g[(c[a+(h<<2)>>2]|0)+(l<<2)>>2];m=m+o*+g[b+(h<<3)>>2];n=n+o*+g[b+(h<<3)+4>>2];h=h+1|0;}while((h|0)<(e|0));g[d+(l<<2)>>2]=m;g[i+(l<<2)>>2]=n;l=l+1|0;}while((l|0)<(f|0));return}else{return}}function Nkb(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=e>>>1;if((f|0)==0){return}else{g=0}do{h=b[d+(g<<1)>>1]|0;b[a+(g<<1)>>1]=((ca(b[c+(g<<1)>>1]|0,h)|0)+16384|0)>>>15;i=e-g-1|0;b[a+(i<<1)>>1]=((ca(b[c+(i<<1)>>1]|0,h)|0)+16384|0)>>>15;g=g+1|0;}while((g|0)<(f|0));return}function Okb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=a+2360|0;d=a+2352|0;e=c[d>>2]|0;f=c[d+4>>2]|0;g=c[a+2320>>2]|0;h=g;i=(g|0)<0|0?-1:0;g=c[a+2324>>2]|0;a:do{if((f|0)<(i|0)|(f|0)==(i|0)&e>>>0<h>>>0){j=f;k=e;l=c[b+4>>2]|0;m=c[b>>2]|0}else{n=g;o=(g|0)<0|0?-1:0;p=f;q=e;r=c[b+4>>2]|0;s=c[b>>2]|0;while(1){if((r|0)<(o|0)|(r|0)==(o|0)&s>>>0<n>>>0){j=p;k=q;l=r;m=s;break a}t=xrc(q,p,h,i)|0;u=G;c[d>>2]=t;c[d+4>>2]=u;v=xrc(s,r,n,o)|0;w=G;c[b>>2]=v;c[b+4>>2]=w;if((u|0)<(i|0)|(u|0)==(i|0)&t>>>0<h>>>0){j=u;k=t;l=w;m=v;break}else{p=u;q=t;r=w;s=v}}}}while(0);e=c[a+2336>>2]|0;f=Erc(g,(g|0)<0|0?-1:0,k,j)|0;g=G;s=Erc(h,i,m,l)|0;i=G;h=((((g|0)<(i|0)|(g|0)==(i|0)&f>>>0<s>>>0)&1)<<1)+e|0;c[a+2340>>2]=h;e=h<<3;h=wrc(e,(e|0)<0|0?-1:0,k,j)|0;c[d>>2]=h;c[d+4>>2]=G;d=c[a+2332>>2]<<8;a=wrc(d,(d|0)<0|0?-1:0,m,l)|0;c[b>>2]=a;c[b+4>>2]=G;return}function Pkb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=b+2332|0;f=c[e>>2]|0;do{if((f|0)>0){g=b+2368|0;h=b+2464|0;i=0;j=c[g>>2]|0;k=f;while(1){if((j|0)<1){l=j;m=k}else{n=1;do{a[b+1536+(i<<7)+64+n|0]=c[h>>2];n=n+1|0;o=c[g>>2]|0;}while((n|0)<=(o|0));l=o;m=c[e>>2]|0}n=i+1|0;if((n|0)<(m|0)){i=n;j=l;k=m}else{break}}if((m|0)<=0){p=m;q=26;break}k=b+2368|0;j=0;i=0;g=0;h=c[k>>2]|0;while(1){n=b+1536+(g<<7)+72|0;c[n>>2]=0;if((h|0)<1){r=b+1536+(g<<7)+60|0;c[r>>2]=0;s=r;t=j;q=13}else{r=1;u=0;do{u=u+(d[b+1536+(g<<7)+64+r|0]|0)|0;c[n>>2]=u;r=r+1|0;}while((r|0)<=(h|0));r=(u|0)>1;v=r&1;w=b+1536+(g<<7)+60|0;c[w>>2]=v;x=v+j|0;if(r){y=h;z=w;A=x}else{s=w;t=x;q=13}}do{if((q|0)==13){q=0;c[n>>2]=0;if((h|0)<1){y=h;z=s;A=t;break}else{B=1}while(1){a[b+1536+(g<<7)+64+B|0]=0;x=B+1|0;w=c[k>>2]|0;if((x|0)>(w|0)){y=w;z=s;A=t;break}else{B=x}}}}while(0);n=(g|0)!=0;u=n&1^1;x=b+1536+(g<<7)+56|0;c[x>>2]=u;do{if(n){w=g-1|0;r=1;while(1){if((r|0)>(y|0)){C=u;break}if((a[b+1536+(g<<7)+64+r|0]|0)==(a[b+1536+(w<<7)+64+r|0]|0)){r=r+1|0}else{q=19;break}}if((q|0)==19){q=0;c[x>>2]=1;C=1}c[b+1536+(g<<7)+96>>2]=C;if((c[z>>2]|0)!=0&(i|0)==0){q=22;break}c[b+1536+(g<<7)+92>>2]=0;D=i}else{c[b+1632>>2]=u;q=22}}while(0);if((q|0)==22){q=0;c[b+1536+(g<<7)+92>>2]=1;D=(c[z>>2]|0)==0?i:1}u=g+1|0;E=c[e>>2]|0;if((u|0)<(E|0)){j=A;i=D;g=u;h=y}else{break}}if((A|0)==0){p=E;q=26}else{F=E}}else{p=f;q=26}}while(0);if((q|0)==26){c[b+2464>>2]=0;F=p}if((F|0)<=0){return}p=b+2368|0;q=b+2428|0;f=b+2432|0;E=0;A=c[p>>2]|0;y=F;while(1){if((A|0)<1){G=A;H=y}else{F=1;do{if((a[b+1536+(E<<7)+64+F|0]|0)==0){c[b+1536+(E<<7)+100+(F<<2)>>2]=((c[q>>2]|0)*3|0)+73}else{c[b+1536+(E<<7)+100+(F<<2)>>2]=c[f>>2]}F=F+1|0;I=c[p>>2]|0;}while((F|0)<=(I|0));G=I;H=c[e>>2]|0}F=E+1|0;if((F|0)<(H|0)){E=F;A=G;y=H}else{break}}return}function Qkb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((c[b+2500>>2]|0)==0){return}e=b+2332|0;f=c[e>>2]|0;if((f|0)>0){g=0;h=0;i=f}else{return}while(1){if((a[b+1536+(h<<7)+47|0]|0)==0){j=g}else{j=b+1536+(h<<7)+52|0}f=c[b+1536+(h<<7)+104>>2]|0;k=c[b+1536+(h<<7)+108>>2]|0;l=(f|0)>(k|0)?k:f;f=b+1536+(h<<7)+48|0;k=c[f>>2]|0;if((k|0)>0){m=b+1536+(h<<7)+4|0;n=0;o=k;while(1){do{if((a[j+n|0]|0)==0){p=o;q=n+1|0}else{k=d[1443288+n|0]|0;r=n+1|0;s=d[1443288+r|0]|0;t=(l|0)>(s|0)?s:l;if((k|0)>=(t|0)){p=o;q=r;break}s=c[m>>2]|0;u=c[s+4>>2]|0;v=c[s+8>>2]|0;s=k;do{k=u+(s<<2)|0;w=c[k>>2]|0;x=v+(s<<2)|0;y=c[x>>2]|0;c[k>>2]=y+w>>1;c[x>>2]=w-y>>1;s=s+1|0;}while((s|0)<(t|0));p=c[f>>2]|0;q=r}}while(0);if((q|0)<(p|0)){n=q;o=p}else{break}}z=c[e>>2]|0}else{z=i}o=h+1|0;if((o|0)<(z|0)){g=j;h=o;i=z}else{break}}return}function Rkb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b+2332|0;e=c[d>>2]|0;if((e|0)<=0){return}f=b+2372|0;g=0;h=c[f>>2]|0;i=e;while(1){e=(c[b+1536+(g<<7)+60>>2]|0)==0|0;if((e|0)>(h|0)){j=h;k=i}else{l=b+1536+(g<<7)+8|0;m=b+1536+(g<<7)+12|0;n=e;e=h;while(1){o=a[b+2688+(n*6|0)+g|0]|0;p=o&255;if(o<<24>>24==0){q=e}else{r=(n|0)==0|0;s=(o<<24>>24==3)+p|0;o=c[b+2432+(n<<2)>>2]|0;t=a[(c[b+1536+(g<<7)+100+(n<<2)>>2]|0)-o+(8970872+(r*768|0)+(p-1<<8))|0]|0;p=t&255;u=c[(c[l>>2]|0)+(n<<2)>>2]|0;v=o-r|0;r=a[u+v|0]|0;a[c[(c[m>>2]|0)+(n<<2)>>2]|0]=r;if(!(t<<24>>24==0)){t=s<<1;o=t+s|0;w=u+(v+1)|0;v=1;u=r;while(1){r=a[w]|0;x=a[w+s|0]|0;y=a[w+t|0]|0;a[(c[(c[m>>2]|0)+(n<<2)>>2]|0)+v|0]=((62-x&255)+y&255)+(((x-r&255)+((r-u&255)*5&255)&255)*5&255);r=v+1|0;if((r|0)>(p|0)){break}else{w=w+o|0;v=r;u=y}}}q=c[f>>2]|0}u=n+1|0;if((u|0)>(q|0)){break}else{n=u;e=q}}j=q;k=c[d>>2]|0}e=g+1|0;if((e|0)<(k|0)){g=e;h=j;i=k}else{break}}return}function Skb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=b+2464|0;f=(c[e>>2]|0)==0|0;g=b+2332|0;h=b+2372|0;i=ca(c[g>>2]<<8,(f^1)+(c[h>>2]|0)|0)|0;j=b+1544|0;ef[c[b+1448>>2]&4095](c[(c[j>>2]|0)+(f<<2)>>2]|0,c[(c[b+1540>>2]|0)+(f<<2)>>2]|0,i);i=(c[e>>2]|0)==0|0;f=b+2368|0;if((i|0)<=(c[f>>2]|0)){k=b+188|0;l=b+2328|0;m=i;do{i=c[(c[j>>2]|0)+(m<<2)>>2]|0;a[b+2688+(m*6|0)|0]=1;n=i+256|0;o=c[g>>2]|0;a:do{if((o|0)>1){p=b+2432+(m<<2)|0;if((m|0)==0){q=1;r=i;s=n;while(1){do{if((c[b+1536+(q-1<<7)+60>>2]|0)==0){a[b+2688+q|0]=1}else{if((c[b+1536+(q<<7)+60>>2]|0)==0){a[b+2688+q|0]=0;break}t=Xe[c[k>>2]&511](0,s,r,16,16)|0;u=b+2688+q|0;a[u]=0;if((t|0)<=((((c[b+1536+(q<<7)+100>>2]|0)-(c[p>>2]|0)|0)*500|0|0)/256|0|0)){break}a[u]=1}}while(0);u=q+1|0;t=c[g>>2]|0;if((u|0)<(t|0)){q=u;r=s;s=s+256|0}else{v=t;break a}}}if((m|0)>0){w=1;x=i;y=n}else{s=1;r=i;q=n;while(1){if((a[b+1536+(s<<7)+64+m|0]|0)==(a[b+1536+(s-1<<7)+64+m|0]|0)){Xe[c[k>>2]&511](0,q,r,16,16)|0;a[b+2688+(m*6|0)+s|0]=0}else{a[b+2688+(m*6|0)+s|0]=1}p=s+1|0;t=c[g>>2]|0;if((p|0)<(t|0)){s=p;r=q;q=q+256|0}else{v=t;break a}}}while(1){do{if((a[b+1536+(w<<7)+64+m|0]|0)==(a[b+1536+(w-1<<7)+64+m|0]|0)){q=Xe[c[k>>2]&511](0,y,x,16,16)|0;r=b+2688+(m*6|0)+w|0;a[r]=0;if((q|0)<=500){break}a[r]=1}else{a[b+2688+(m*6|0)+w|0]=1}}while(0);r=w+1|0;q=c[g>>2]|0;if((r|0)<(q|0)){w=r;x=y;y=y+256|0}else{v=q;break}}}else{v=o}}while(0);if((v|0)>0){o=0;n=v;while(1){i=o;do{i=i+1|0;if((i|0)>=(n|0)){break}}while((a[b+2688+(m*6|0)+i|0]|0)==0);a[b+2688+(m*6|0)+o|0]=a[i+~o+(1489944+((c[l>>2]|0)*6|0))|0]|0;q=c[g>>2]|0;if((i|0)<(q|0)){o=i;n=q}else{break}}}m=m+1|0;}while((m|0)<=(c[f>>2]|0))}do{if((c[b+2376>>2]|0)!=0){f=c[b+2380>>2]|0;a[b+2688+(f*6|0)|0]=1;if((c[g>>2]|0)>1){z=1}else{break}do{a[b+2688+(f*6|0)+z|0]=0;z=z+1|0;}while((z|0)<(c[g>>2]|0))}}while(0);if((c[b+2308>>2]|0)!=0){Bca(b)}z=(c[e>>2]|0)==0|0;e=c[h>>2]|0;if((z|0)>(e|0)){A=b+2956|0;c[A>>2]=0;return}f=b+1416|0;m=z;z=c[g>>2]|0;l=e;while(1){e=b+2432+(m<<2)|0;v=(m|0)==0;y=v&1;if((z|0)>0){x=y^1;w=(c[(c[j>>2]|0)+(m<<2)>>2]|0)+(c[e>>2]|0)|0;k=0;n=z;while(1){do{if(v){if((c[b+1536+(k<<7)+60>>2]|0)!=0){B=41;break}C=k+1|0;D=w+256|0;E=n}else{B=41}}while(0);if((B|0)==41){B=0;i=(c[b+1536+(k<<7)+100+(m<<2)>>2]|0)-(c[e>>2]|0)|0;o=k&255;a[b+2744+(m*6|0)+k|0]=o;q=k+1|0;b:do{if((q|0)<(c[g>>2]|0)){r=q;while(1){if((a[b+2688+(m*6|0)+r|0]|0)!=0){F=r;break b}a[b+2744+(m*6|0)+r|0]=o;s=r+1|0;if((s|0)<(c[g>>2]|0)){r=s}else{F=s;break}}}else{F=q}}while(0);q=F-k|0;ef[c[f>>2]&4095](w+(-(c[e>>2]|0)|0)|0,q-1|0,256);o=d[b+2688+(m*6|0)+k|0]|0;r=d[8970872+(y*768|0)+(o-1<<8)+i|0]|0;s=r*3|0;do{if((o|0)==2){if((s|0)==0){break}else{G=x;H=1}while(1){t=a[w+G|0]|0;p=a[w+(G+1)|0]|0;a[w+(H-y)|0]=(p&255)>>>0<(t&255)>>>0?p:t;t=H+1|0;if((t|0)>(s|0)){break}else{G=G+2|0;H=t}}}else if((o|0)==3){if((s|0)==0){break}else{I=x;J=1}while(1){t=a[w+I|0]|0;p=a[w+(I+1)|0]|0;u=(p&255)>>>0<(t&255)>>>0?p:t;t=a[w+(I+2)|0]|0;p=(t&255)>>>0<(u&255)>>>0?t:u;u=a[w+(I+3)|0]|0;a[w+(J-y)|0]=(u&255)>>>0<(p&255)>>>0?u:p;p=J+1|0;if((p|0)>(s|0)){break}else{I=I+4|0;J=p}}}}while(0);do{if(!v){if(!((d[w]|0)>>>0>15>>>0)){break}a[w]=15}}while(0);i=(s|0)==0;do{if(!i){p=1;u=a[w]|0;do{t=w+p|0;K=a[t]|0;L=(u&255)+2|0;u=(K&255)>>>0>L>>>0?L&255:K;a[t]=u;p=p+1|0;}while((p|0)<=(s|0));p=(s+1|0)>>>0>2>>>0?s:1;if((p|0)==0){break}u=p;t=a[w+p|0]|0;do{u=u-1|0;p=w+u|0;K=a[p]|0;L=(t&255)+2|0;t=(K&255)>>>0>L>>>0?L&255:K;a[p]=t;}while((u|0)>0)}}while(0);if(v){a[w-1|0]=a[w]&-2}do{if((o|0)==2){if(i){break}u=(r*6|0)-y|0;t=s;while(1){p=a[w+(t-y)|0]|0;a[w+u|0]=p;a[w+(u-1)|0]=p;p=t-1|0;if((p|0)>0){u=u-2|0;t=p}else{break}}}else if((o|0)==3){if(i){break}t=(r*12|0)-y|0;u=s;while(1){p=a[w+(u-y)|0]|0;a[w+(t-3)|0]=p;a[w+(t-2)|0]=p;a[w+(t-1)|0]=p;a[w+t|0]=p;p=u-1|0;if((p|0)>0){t=t-4|0;u=p}else{break}}}}while(0);C=F;D=w+(q<<8)|0;E=c[g>>2]|0}if((C|0)<(E|0)){w=D;k=C;n=E}else{break}}M=E;N=c[h>>2]|0}else{M=z;N=l}n=m+1|0;if((n|0)>(N|0)){break}else{m=n;z=M;l=N}}A=b+2956|0;c[A>>2]=0;return}function Tkb(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;f=c[b+2308>>2]|0;g=(f|0)==0;do{if(g){h=(c[b+24>>2]|0)==0?0:7;if((c[b+2312>>2]|0)!=6){i=h;break}j=(c[b+44>>2]|0)==0?h:h+14|0;if((c[b+68>>2]|0)==0){i=j;break}i=j+14|0}else{j=c[b+2392>>2]|0;if((c[b+84>>2]|0)==0){k=0}else{h=(j|0)>2?2:0;l=(c[b+2384>>2]|0)==0?h:h+6|0;k=(c[b+2376>>2]|0)+((j|0)<2?6:5)+((c[b+2388>>2]|0)==0?l:l+6|0)|0}if((c[b+88>>2]|0)==0){m=k}else{l=((j|0)==2?9:5)+k|0;m=((c[b+24>>2]|0)==0?2:10)+((j|0)>5?l+2|0:l)|0}do{if((j|0)>1){l=m+1|0;h=c[b+2332>>2]|0;if((h|0)>1){n=l;o=1}else{p=l;break}while(1){l=((c[b+1536+(o<<7)+56>>2]|0)==0?1:2)+n|0;q=o+1|0;if((q|0)<(h|0)){n=l;o=q}else{p=l;break}}}else{p=m}}while(0);j=c[b+2464>>2]|0;if((j|0)==0){i=p;break}if((c[b+2740>>2]|0)!=0){i=(j*5|0)+p|0;break}j=c[b+2332>>2]|0;if((j|0)>0){r=p;s=0}else{i=p;break}while(1){h=(c[b+1536+(s<<7)+60>>2]<<1)+r|0;l=s+1|0;if((l|0)<(j|0)){r=h;s=l}else{i=h;break}}}}while(0);s=b+2332|0;r=c[s>>2]|0;p=(r|0)>0;do{if(p){m=g&1;o=c[b+2392>>2]|0;n=(o|0)==2;k=c[b+2368>>2]|0;j=(k|0)<1;h=b+2372|0;l=b+2476|0;q=m^1;t=b+2472|0;u=g^1;v=i;w=0;x=f;y=f;z=f;A=o;o=f;while(1){B=v+m|0;do{if((c[b+1536+(w<<7)+56>>2]|0)==0){C=B;D=x;E=y;F=z;G=A;H=c[b+1536+(w<<7)+60>>2]|0;I=26}else{J=B+m|0;K=c[b+1536+(w<<7)+60>>2]|0;if((K|0)==0){L=J;M=x;N=y;O=0;P=o;Q=A;R=z;S=1;break}T=(A|0)==2&u;U=T?2:A;V=(T?0:k)+q+((U|0)==2)+J|0;if((o|0)==0){W=K;X=0;Y=U;Z=0;_=0;$=0;aa=V+7+(c[t>>2]|0)|0;I=27;break}else{C=V+9|0;D=o;E=o;F=o;G=U;H=K;I=26;break}}}while(0);if((I|0)==26){I=0;if((H|0)==0){L=C;M=D;N=E;O=0;P=o;Q=G;R=F;S=1}else{W=H;X=o;Y=G;Z=F;_=E;$=D;aa=C;I=27}}do{if((I|0)==27){I=0;if(j){L=aa;M=$;N=_;O=W;P=X;Q=Y;R=Z;S=0;break}B=(Z|0)!=0;K=aa;U=1;V=$;J=_;while(1){do{if((a[b+1536+(w<<7)+64+U|0]|0)==0){ba=K;ca=V;da=J}else{T=a[b+1536+(w<<7)+76+U|0]|0;if(B&T<<24>>24==2){ea=K}else{fa=K+1|0;if(T<<24>>24==0){ba=fa;ca=Z;da=Z;break}else{ea=fa}}ba=ea+2+(c[l>>2]<<3)|0;ca=Z;da=Z}}while(0);fa=U+1|0;if((fa|0)>(k|0)){L=ba;M=ca;N=da;O=W;P=X;Q=Y;R=Z;S=0;break}else{K=ba;U=fa;V=ca;J=da}}}}while(0);do{if(n){J=(((M|0)==0|(w|0)>0)&1)+L|0;if((a[b+1536+(w<<7)+47|0]|0)==0){ga=J;break}ga=(c[b+1536+(w<<7)+48>>2]|0)+J|0}else{ga=L}}while(0);if(j){ha=ga}else{J=ga;V=1;while(1){if((a[b+2688+(V*6|0)+w|0]|0)==0){ia=J}else{ia=((a[b+1536+(w<<7)+64+V|0]|0)==0?J+6|0:J)+2|0}U=V+1|0;if((U|0)>(k|0)){ha=ia;break}else{J=ia;V=U}}}do{if(g){V=S?ha:ha+2|0;if((M|0)!=0){ja=V;ka=M;break}if((c[b+1536+(w<<7)+92>>2]|0)==0){ja=V+1|0;ka=0;break}ja=V+7+(((c[h>>2]|0)+O|0)*7|0)|0;ka=0}else{ja=ha;ka=M}}while(0);do{if(S){la=ja;ma=ka}else{V=c[b+1536+(w<<7)+96>>2]|0;if((N|0)!=0&(V|0)==2){na=ja}else{J=ja+1|0;if((V|0)==0){la=J;ma=N;break}else{na=J}}la=na+6|0;ma=N}}while(0);J=w+1|0;if((J|0)<(r|0)){v=la;w=J;x=ma;y=N;z=R;A=Q;o=P}else{break}}o=(c[b+2620>>2]|0)+la|0;A=b+2624|0;c[A>>2]=o;if(!p){oa=o;I=57;break}z=c[b+2372>>2]|0;y=0;x=0;while(1){w=(c[b+1536+(x<<7)+60>>2]|0)==0|0;if((w|0)>(z|0)){pa=y}else{v=y;h=w;while(1){w=a[b+2688+(h*6|0)+x|0]|0;if(w<<24>>24==0){qa=v}else{qa=v+4+((d[(c[b+1536+(x<<7)+100+(h<<2)>>2]|0)-(c[b+2432+(h<<2)>>2]|0)+(8970872+(((h|0)==0|0)*768|0)+((w&255)-1<<8))|0]|0)*7|0)|0}w=h+1|0;if((w|0)>(z|0)){pa=qa;break}else{v=qa;h=w}}}h=x+1|0;if((h|0)<(r|0)){y=pa;x=h}else{break}}x=b+2628|0;c[x>>2]=pa;if(!p){ra=o;sa=pa;break}y=b+2372|0;z=b+2524|0;h=b+2380|0;v=0;w=c[y>>2]|0;k=r;while(1){j=(c[b+1536+(v<<7)+60>>2]|0)==0|0;if((j|0)>(w|0)){ta=w;ua=k}else{n=b+1536+(v<<7)+8|0;l=b+1536+(v<<7)+16|0;t=b+1536+(v<<7)+20|0;q=b+1536+(v<<7)+24|0;u=j;j=w;while(1){if((a[b+2688+(u*6|0)+v|0]|0)==0){va=j}else{m=b+2432+(u<<2)|0;J=b+1536+(v<<7)+100+(u<<2)|0;Eub(c[(c[n>>2]|0)+(u<<2)>>2]|0,c[m>>2]|0,c[J>>2]|0,c[(c[l>>2]|0)+(u<<2)>>2]|0,c[(c[t>>2]|0)+(u<<2)>>2]|0);Fub(z,c[(c[t>>2]|0)+(u<<2)>>2]|0,c[m>>2]|0,c[J>>2]|0,e[1444352+(c[b+2564+(u<<2)>>2]<<1)>>1]|0,(u|0)==(c[h>>2]|0)|0,2,0,0,0,0,c[(c[q>>2]|0)+(u<<2)>>2]|0)|0;va=c[y>>2]|0}J=u+1|0;if((J|0)>(va|0)){break}else{u=J;j=va}}ta=va;ua=c[s>>2]|0}j=v+1|0;if((j|0)<(ua|0)){v=j;w=ta;k=ua}else{break}}ra=c[A>>2]|0;sa=c[x>>2]|0}else{k=(c[b+2620>>2]|0)+i|0;c[b+2624>>2]=k;oa=k;I=57}}while(0);if((I|0)==57){c[b+2628>>2]=0;ra=oa;sa=0}oa=(c[b+2340>>2]<<3)-ra-sa|0;if((oa|0)<0){wa=-22;return wa|0}sa=b+2560|0;ra=c[sa>>2]<<4;do{if((ra|c[b+2596>>2]|0)==1023){if((_kb(b,1023)|0)>(oa|0)){xa=ra;break}else{wa=0}return wa|0}else{xa=ra}}while(0);while(1){if(!((xa|0)>-1)){wa=-22;I=98;break}if((_kb(b,xa)|0)>(oa|0)){xa=xa-64|0}else{break}}if((I|0)==98){return wa|0}ra=b+2644|0;i=c[ra>>2]|0;ua=b+2640|0;c[ra>>2]=c[ua>>2];c[ua>>2]=i;i=xa+64|0;a:do{if((i|0)<1024){ta=xa;va=i;while(1){if((_kb(b,va)|0)>(oa|0)){ya=ta;break a}r=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=r;r=va+64|0;if((r|0)<1024){ta=va;va=r}else{ya=va;break}}}else{ya=xa}}while(0);xa=ya+16|0;b:do{if((xa|0)<1024){i=ya;va=xa;while(1){if((_kb(b,va)|0)>(oa|0)){za=i;break b}ta=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=ta;ta=va+16|0;if((ta|0)<1024){i=va;va=ta}else{za=va;break}}}else{za=ya}}while(0);ya=za+4|0;c:do{if((ya|0)<1024){xa=za;va=ya;while(1){if((_kb(b,va)|0)>(oa|0)){Aa=xa;break c}i=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=i;i=va+4|0;if((i|0)<1024){xa=va;va=i}else{Aa=va;break}}}else{Aa=za}}while(0);za=Aa+1|0;d:do{if((za|0)<1024){ya=Aa;va=za;while(1){if((_kb(b,va)|0)>(oa|0)){Ba=ya;break d}xa=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=xa;xa=va+1|0;if((xa|0)<1024){ya=va;va=xa}else{Ba=va;break}}}else{Ba=Aa}}while(0);Aa=c[ra>>2]|0;c[ra>>2]=c[ua>>2];c[ua>>2]=Aa;do{if((c[b+2788>>2]|0)==(Aa|0)){if((c[b+2956>>2]|0)==0){I=79;break}Ca=c[b+2372>>2]|0}else{I=79}}while(0);if((I|0)==79){I=b+2372|0;ua=c[I>>2]|0;if((ua|0)<0){Da=ua}else{ra=0;oa=Aa;Aa=c[s>>2]|0;za=ua;while(1){if((Aa|0)>0){ua=0;do{c[b+2788+(ra*24|0)+(ua<<2)>>2]=oa+(d[b+2744+(ra*6|0)+ua|0]<<8);ua=ua+1|0;Ea=c[s>>2]|0;}while((ua|0)<(Ea|0));Fa=Ea;Ga=c[I>>2]|0}else{Fa=Aa;Ga=za}ua=ra+1|0;if((ua|0)>(Ga|0)){Da=Ga;break}else{ra=ua;oa=oa+(Fa<<8)|0;Aa=Fa;za=Ga}}}c[b+2956>>2]=1;Ca=Da}c[sa>>2]=Ba>>4;sa=(c[b+2464>>2]|0)==0|0;Da=b+2372|0;if((sa|0)>(Ca|0)){wa=0;return wa|0}Ca=Ba&15;Ba=sa;while(1){c[b+2592+(Ba<<2)>>2]=Ca;sa=Ba+1|0;if((sa|0)>(c[Da>>2]|0)){wa=0;break}else{Ba=sa}}return wa|0}function Ukb(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;g=c[f+2332>>2]|0;if((g|0)<=0){return}h=c[f+2372>>2]|0;i=0;j=0;while(1){if((h|0)<1){k=i}else{l=f+1536+(j<<7)+4|0;m=f+1536+(j<<7)+28|0;n=0;o=0;p=0;q=0;r=0;s=0;t=1;u=i;v=(c[f+1536+(j<<7)+60>>2]|0)==0|0;while(1){if((v|0)==0&(t|0)>1){w=t-1|0;x=(a[f+1536+(j<<7)+64+w|0]|0)==0;y=x&1^1;z=x?u:w;A=x?t:0}else{y=v;z=u;A=t}x=c[(c[l>>2]|0)+(A<<2)>>2]|0;w=c[(c[f+1536+(d[f+2744+(A*6|0)+j|0]<<7)+8>>2]|0)+(A<<2)>>2]|0;B=c[f+2788+(A*24|0)+(j<<2)>>2]|0;C=c[(c[m>>2]|0)+(A<<2)>>2]|0;D=c[f+2432+(A<<2)>>2]|0;E=c[f+1536+(j<<7)+100+(A<<2)>>2]|0;if((D|0)<(E|0)){F=D;D=s;G=r;H=q;I=p;J=o;K=n;while(1){L=c[x+(F<<2)>>2]|0;M=d[w+F|0]|0;N=a[B+F|0]|0;O=N&255;a:do{if(N<<24>>24==0){P=N&255;Q=D;R=G;S=H;T=I;U=J;V=K}else{switch(O|0){case 1:{W=((L*3|0)>>24-M)+3>>1;if((I|0)==1){b[D>>1]=(e[D>>1]|0)+(W*3|0);P=128;Q=D;R=G;S=H;T=2;U=J;V=K;break a}else if((I|0)==0){P=(W*9|0)&65535;Q=C+(F<<1)|0;R=G;S=H;T=1;U=J;V=K;break a}else{b[D>>1]=(e[D>>1]|0)+W;P=128;Q=D;R=G;S=H;T=0;U=J;V=K;break a}break};case 15:{W=(L<<M>>8)+1>>1;P=(W|0)>32767?32767:W&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a;break};case 2:{W=((L*5|0)>>24-M)+5>>1;if((J|0)==1){b[G>>1]=(e[G>>1]|0)+(W*5|0);P=128;Q=D;R=G;S=H;T=I;U=2;V=K;break a}else if((J|0)==0){P=(W*25|0)&65535;Q=D;R=C+(F<<1)|0;S=H;T=I;U=1;V=K;break a}else{b[G>>1]=(e[G>>1]|0)+W;P=128;Q=D;R=G;S=H;T=I;U=0;V=K;break a}break};case 3:{P=(((L*7|0)>>24-M)+7|0)>>>1&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a;break};case 14:{W=(L<<M>>10)+1>>1;P=(W|0)>8191?8191:W&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a;break};case 4:{W=((L*11|0)>>24-M)+11>>1;if((K|0)==0){P=(W*11|0)&65535;Q=D;R=G;S=C+(F<<1)|0;T=I;U=J;V=1;break a}else{b[H>>1]=(e[H>>1]|0)+W;P=128;Q=D;R=G;S=H;T=I;U=J;V=0;break a}break};case 5:{P=(((L*15|0)>>24-M)+15|0)>>>1&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a;break};default:{W=(L<<M>>25-O)+1>>1;X=1<<O-2;P=((W|0)<(X|0)?W:X+65535|0)&65535;Q=D;R=G;S=H;T=I;U=J;V=K;break a}}}}while(0);b[C+(F<<1)>>1]=P;O=F+1|0;if((O|0)<(E|0)){F=O;D=Q;G=R;H=S;I=T;J=U;K=V}else{Y=Q;Z=R;_=S;$=T;aa=U;ba=V;break}}}else{Y=s;Z=r;_=q;$=p;aa=o;ba=n}K=((A|0)==0?z:A)+1|0;if((K|0)>(h|0)){k=z;break}else{n=ba;o=aa;p=$;q=_;r=Z;s=Y;t=K;u=z;v=y}}}v=j+1|0;if((v|0)<(g|0)){i=k;j=v}else{break}}return}function Vkb(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0;c[e+132>>2]=30720;g=e+120|0;c[g>>2]=f;c[e+128>>2]=f+3840;h=e+124|0;c[h>>2]=f;f=e+116|0;c[f>>2]=32;i=e+112|0;c[i>>2]=0;qe[c[e+2972>>2]&1023](e);j=e+2332|0;if((c[j>>2]|0)>0){k=e+2308|0;l=e+2368|0;m=e+2392|0;n=e+2376|0;o=e+2380|0;p=e+2372|0;q=e+2508|0;r=e+2512|0;s=e+2504|0;t=e+2516|0;u=e+2520|0;v=e+2560|0;w=e+2552|0;x=e+2556|0;z=e+2428|0;A=e+2476|0;B=e+2432|0;C=e+2460|0;D=0;do{do{if((c[k>>2]|0)==0){E=c[l>>2]|0;if((E|0)<=0){F=15;break}G=0;H=c[i>>2]|0;I=c[f>>2]|0;J=E;while(1){if((I|0)>1){K=I-1|0;L=H<<1;M=J}else{E=je(H<<I|0)|0;N=c[h>>2]|0;y=E;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;K=I+31|0;L=0;M=c[l>>2]|0}c[i>>2]=L;c[f>>2]=K;N=G+1|0;if((N|0)<(M|0)){G=N;H=L;I=K;J=M}else{break}}if((c[k>>2]|0)==0&(M|0)>0){O=0;P=L;Q=K;R=M}else{F=15;break}while(1){if((Q|0)>1){S=Q-1|0;T=P<<1|1;U=R}else{J=je(1>>>((1-Q|0)>>>0)|P<<Q|0)|0;I=c[h>>2]|0;y=J;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;S=Q+31|0;T=1;U=c[l>>2]|0}c[i>>2]=T;c[f>>2]=S;I=O+1|0;if((I|0)<(U|0)){O=I;P=T;Q=S;R=U}else{V=S;break}}}else{F=15}}while(0);if((F|0)==15){F=0;V=c[f>>2]|0}I=c[i>>2]|0;if((V|0)>1){W=V-1|0;X=I<<1}else{J=je(I<<V|0)|0;I=c[h>>2]|0;y=J;a[I]=y;y=y>>8;a[I+1|0]=y;y=y>>8;a[I+2|0]=y;y=y>>8;a[I+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;W=V+31|0;X=0}c[i>>2]=X;c[f>>2]=W;I=c[k>>2]|0;do{if((I|0)==0){Y=W;Z=X;F=25}else{if((W|0)>1){_=W-1|0;$=X<<1;aa=I}else{J=je(X<<W|0)|0;H=c[h>>2]|0;y=J;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;_=W+31|0;$=0;aa=c[k>>2]|0}c[i>>2]=$;c[f>>2]=_;if((aa|0)==0){Y=_;Z=$;F=25;break}ba=$;ca=_;da=e+1536+(D<<7)+56|0}}while(0);if((F|0)==25){F=0;I=e+1536+(D<<7)+56|0;H=c[I>>2]|0;if((Y|0)>1){ea=Y-1|0;fa=H|Z<<1}else{J=je(H>>>((1-Y|0)>>>0)|Z<<Y|0)|0;G=c[h>>2]|0;y=J;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;ea=Y+31|0;fa=H}c[i>>2]=fa;c[f>>2]=ea;ba=fa;ca=ea;da=I}do{if((c[da>>2]|0)==0){ga=ba;ha=ca;ia=e+1536+(D<<7)+60|0}else{I=e+1536+(D<<7)+60|0;if((c[k>>2]|0)==0){H=c[I>>2]|0;if((ca|0)>1){ja=ca-1|0;ka=H|ba<<1}else{G=je(H>>>((1-ca|0)>>>0)|ba<<ca|0)|0;J=c[h>>2]|0;y=G;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;ja=ca+31|0;ka=H}c[i>>2]=ka;c[f>>2]=ja;la=ka;ma=ja}else{la=ba;ma=ca}if((c[I>>2]|0)==0){ga=la;ha=ma;ia=I;break}H=c[k>>2]|0;do{if((H|0)==0){na=la;oa=ma;F=43}else{if((ma|0)>1){pa=ma-1|0;qa=la<<1;ra=H}else{J=je(la<<ma|0)|0;G=c[h>>2]|0;y=J;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;pa=ma+31|0;qa=0;ra=c[k>>2]|0}c[i>>2]=qa;c[f>>2]=pa;if((ra|0)==0){na=qa;oa=pa;F=43;break}if((c[m>>2]|0)==2){sa=pa;ta=qa;F=49}else{na=qa;oa=pa;F=43}}}while(0);if((F|0)==43){F=0;H=c[l>>2]|0;if((H|0)<1){ua=na;va=oa}else{G=1;J=na;N=oa;E=H;while(1){H=d[e+1536+(D<<7)+64+G|0]|0;if((N|0)>1){wa=N-1|0;xa=H|J<<1;ya=E}else{za=je(H>>>((1-N|0)>>>0)|J<<N|0)|0;Aa=c[h>>2]|0;y=za;a[Aa]=y;y=y>>8;a[Aa+1|0]=y;y=y>>8;a[Aa+2|0]=y;y=y>>8;a[Aa+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;wa=N+31|0;xa=H;ya=c[l>>2]|0}c[i>>2]=xa;c[f>>2]=wa;H=G+1|0;if((H|0)>(ya|0)){ua=xa;va=wa;break}else{G=H;J=xa;N=wa;E=ya}}}if((c[m>>2]|0)==2){sa=va;ta=ua;F=49}else{Ba=ua;Ca=va}}if((F|0)==49){F=0;if((sa|0)>1){Da=sa-1|0;Ea=ta<<1}else{E=je(ta<<sa|0)|0;N=c[h>>2]|0;y=E;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Da=sa+31|0;Ea=0}c[i>>2]=Ea;c[f>>2]=Da;Ba=Ea;Ca=Da}N=((c[B>>2]|0)-37|0)/12|0;E=((c[C>>2]|0)-37|0)/12|0;if((Ca|0)>4){Fa=Ca-4|0;Ga=N|Ba<<4}else{J=je(N>>>((4-Ca|0)>>>0)|Ba<<Ca|0)|0;G=c[h>>2]|0;y=J;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Fa=Ca+28|0;Ga=N}c[i>>2]=Ga;c[f>>2]=Fa;G=E-3|0;if((Fa|0)>4){Ha=Fa-4|0;Ia=Ga<<4|G}else{J=je(G>>>((4-Fa|0)>>>0)|Ga<<Fa|0)|0;H=c[h>>2]|0;y=J;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ha=Fa+28|0;Ia=G}c[i>>2]=Ia;c[f>>2]=Ha;if((c[k>>2]|0)!=0){if((Ha|0)>1){Ja=Ha-1|0;Ka=Ia<<1}else{G=je(Ia<<Ha|0)|0;H=c[h>>2]|0;y=G;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ja=Ha+31|0;Ka=0}c[i>>2]=Ka;c[f>>2]=Ja;ga=Ka;ha=Ja;ia=I;break}H=N+1|0;if((H|0)<(E|0)){La=H;Ma=Ia;Na=Ha}else{ga=Ia;ha=Ha;ia=I;break}while(1){H=d[1393232+La|0]|0;if((Na|0)>1){Oa=Na-1|0;Pa=H|Ma<<1}else{N=je(H>>>((1-Na|0)>>>0)|Ma<<Na|0)|0;G=c[h>>2]|0;y=N;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Oa=Na+31|0;Pa=H}c[i>>2]=Pa;c[f>>2]=Oa;H=La+1|0;if((H|0)<(E|0)){La=H;Ma=Pa;Na=Oa}else{ga=Pa;ha=Oa;ia=I;break}}}}while(0);do{if((c[ia>>2]|0)==0){Qa=ga;Ra=ha}else{if((c[l>>2]|0)<1){Qa=ga;Ra=ha;break}I=e+1536+(D<<7)+32|0;E=e+1536+(D<<7)+36|0;H=1;G=ga;N=ha;while(1){do{if((a[e+1536+(D<<7)+64+H|0]|0)==0){Sa=G;Ta=N}else{J=e+1536+(D<<7)+76+H|0;Aa=a[J]|0;if((c[k>>2]|0)!=0&Aa<<24>>24==2){Ua=N;Va=G}else{za=Aa&255;if((N|0)>1){Wa=N-1|0;Xa=za|G<<1}else{Aa=je(za>>>((1-N|0)>>>0)|G<<N|0)|0;Ya=c[h>>2]|0;y=Aa;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Wa=N+31|0;Xa=za}c[i>>2]=Xa;c[f>>2]=Wa;if((a[J]|0)==0){Sa=Xa;Ta=Wa;break}else{Ua=Wa;Va=Xa}}J=d[e+1536+(D<<7)+83+H|0]|0;if((Ua|0)>2){Za=Ua-2|0;_a=J|Va<<2}else{za=je(J>>>((2-Ua|0)>>>0)|Va<<Ua|0)|0;Ya=c[h>>2]|0;y=za;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Za=Ua+30|0;_a=J}c[i>>2]=_a;c[f>>2]=Za;if((c[A>>2]|0)>0){$a=0;ab=_a;bb=Za}else{Sa=_a;Ta=Za;break}while(1){J=d[(c[(c[I>>2]|0)+(H<<2)>>2]|0)+$a|0]|0;if((bb|0)>4){cb=bb-4|0;db=J|ab<<4}else{Ya=je(J>>>((4-bb|0)>>>0)|ab<<bb|0)|0;za=c[h>>2]|0;y=Ya;a[za]=y;y=y>>8;a[za+1|0]=y;y=y>>8;a[za+2|0]=y;y=y>>8;a[za+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;cb=bb+28|0;db=J}c[i>>2]=db;c[f>>2]=cb;J=d[(c[(c[E>>2]|0)+(H<<2)>>2]|0)+$a|0]|0;if((cb|0)>4){eb=cb-4|0;fb=J|db<<4}else{za=je(J>>>((4-cb|0)>>>0)|db<<cb|0)|0;Ya=c[h>>2]|0;y=za;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;eb=cb+28|0;fb=J}c[i>>2]=fb;c[f>>2]=eb;J=$a+1|0;if((J|0)<(c[A>>2]|0)){$a=J;ab=fb;bb=eb}else{Sa=fb;Ta=eb;break}}}}while(0);J=H+1|0;if((J|0)>(c[l>>2]|0)){Qa=Sa;Ra=Ta;break}else{H=J;G=Sa;N=Ta}}}}while(0);do{if((c[m>>2]|0)==2){N=e+1536+(D<<7)+47|0;if((c[k>>2]|0)==0|(D|0)>0){G=d[N]|0;if((Ra|0)>1){gb=Ra-1|0;hb=G|Qa<<1}else{H=je(G>>>((1-Ra|0)>>>0)|Qa<<Ra|0)|0;E=c[h>>2]|0;y=H;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;gb=Ra+31|0;hb=G}c[i>>2]=hb;c[f>>2]=gb;ib=hb;jb=gb}else{ib=Qa;jb=Ra}if((a[N]|0)==0){kb=ib;lb=jb;break}N=e+1536+(D<<7)+48|0;G=c[N>>2]|0;if((G|0)>0){mb=0;nb=ib;ob=jb;pb=G}else{kb=ib;lb=jb;break}while(1){G=d[e+1536+(D<<7)+52+mb|0]|0;if((ob|0)>1){qb=ob-1|0;rb=G|nb<<1;sb=pb}else{E=je(G>>>((1-ob|0)>>>0)|nb<<ob|0)|0;H=c[h>>2]|0;y=E;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;qb=ob+31|0;rb=G;sb=c[N>>2]|0}c[i>>2]=rb;c[f>>2]=qb;G=mb+1|0;if((G|0)<(sb|0)){mb=G;nb=rb;ob=qb;pb=sb}else{kb=rb;lb=qb;break}}}else{kb=Qa;lb=Ra}}while(0);do{if((c[k>>2]|0)==0){N=(c[ia>>2]|0)==0|0;G=c[l>>2]|0;if((N|0)>(G|0)){tb=kb;ub=lb}else{H=N;N=kb;E=lb;I=G;while(1){G=d[e+2688+(H*6|0)+D|0]|0;if((E|0)>2){vb=E-2|0;wb=G|N<<2;xb=I}else{J=je(G>>>((2-E|0)>>>0)|N<<E|0)|0;Ya=c[h>>2]|0;y=J;a[Ya]=y;y=y>>8;a[Ya+1|0]=y;y=y>>8;a[Ya+2|0]=y;y=y>>8;a[Ya+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;vb=E+30|0;wb=G;xb=c[l>>2]|0}c[i>>2]=wb;c[f>>2]=vb;G=H+1|0;if((G|0)>(xb|0)){tb=wb;ub=vb;break}else{H=G;N=wb;E=vb;I=xb}}}if((c[n>>2]|0)==0){yb=tb;zb=ub;break}I=d[e+2688+((c[o>>2]|0)*6|0)+D|0]|0;if((ub|0)>1){Ab=ub-1|0;Bb=I|tb<<1}else{E=je(I>>>((1-ub|0)>>>0)|tb<<ub|0)|0;N=c[h>>2]|0;y=E;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ab=ub+31|0;Bb=I}c[i>>2]=Bb;c[f>>2]=Ab;yb=Bb;zb=Ab}else{yb=kb;zb=lb}}while(0);I=c[l>>2]|0;if((I|0)<1){Cb=yb;Db=zb}else{N=1;E=yb;H=zb;G=I;while(1){do{if((a[e+2688+(N*6|0)+D|0]|0)==0){Eb=E;Fb=H;Gb=G}else{if((a[e+1536+(D<<7)+64+N|0]|0)!=0){Eb=E;Fb=H;Gb=G;break}I=c[z>>2]|0;if((H|0)>6){Hb=H-6|0;Ib=I|E<<6;Jb=G}else{Ya=je(I>>>((6-H|0)>>>0)|E<<H|0)|0;J=c[h>>2]|0;y=Ya;a[J]=y;y=y>>8;a[J+1|0]=y;y=y>>8;a[J+2|0]=y;y=y>>8;a[J+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Hb=H+26|0;Ib=I;Jb=c[l>>2]|0}c[i>>2]=Ib;c[f>>2]=Hb;Eb=Ib;Fb=Hb;Gb=Jb}}while(0);I=N+1|0;if((I|0)>(Gb|0)){Cb=Eb;Db=Fb;break}else{N=I;E=Eb;H=Fb;G=Gb}}}G=(c[ia>>2]|0)==0|0;if((G|0)>(c[p>>2]|0)){Kb=Cb;Lb=Db}else{H=e+1536+(D<<7)+12|0;E=G;G=Cb;N=Db;while(1){I=(E|0)==0;J=I&1;Ya=e+2688+(E*6|0)+D|0;do{if((a[Ya]|0)==0){Mb=G;Nb=N}else{za=(d[c[(c[H>>2]|0)+(E<<2)>>2]|0]|0)>>>(J>>>0);if((N|0)>4){Ob=N-4|0;Pb=za|G<<4}else{Aa=je(za>>>((4-N|0)>>>0)|G<<N|0)|0;Qb=c[h>>2]|0;y=Aa;a[Qb]=y;y=y>>8;a[Qb+1|0]=y;y=y>>8;a[Qb+2|0]=y;y=y>>8;a[Qb+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ob=N+28|0;Pb=za}c[i>>2]=Pb;c[f>>2]=Ob;za=a[(c[e+1536+(D<<7)+100+(E<<2)>>2]|0)-(c[e+2432+(E<<2)>>2]|0)+(8970872+(J*768|0)+((d[Ya]|0)-1<<8))|0]|0;Qb=za&255;if(za<<24>>24==0){Rb=Pb;Sb=Ob}else{za=1;Aa=Pb;Tb=Ob;while(1){Ub=d[(c[(c[H>>2]|0)+(E<<2)>>2]|0)+za|0]|0;if((Tb|0)>7){Vb=Tb-7|0;Wb=Ub|Aa<<7}else{Xb=je(Ub>>>((7-Tb|0)>>>0)|Aa<<Tb|0)|0;Yb=c[h>>2]|0;y=Xb;a[Yb]=y;y=y>>8;a[Yb+1|0]=y;y=y>>8;a[Yb+2|0]=y;y=y>>8;a[Yb+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Vb=Tb+25|0;Wb=Ub}c[i>>2]=Wb;c[f>>2]=Vb;Ub=za+1|0;if((Ub|0)>(Qb|0)){Rb=Wb;Sb=Vb;break}else{za=Ub;Aa=Wb;Tb=Vb}}}if((E|0)==(c[o>>2]|0)|I){Mb=Rb;Nb=Sb;break}if((Sb|0)>2){Zb=Sb-2|0;_b=Rb<<2}else{Tb=je(Rb<<Sb|0)|0;Aa=c[h>>2]|0;y=Tb;a[Aa]=y;y=y>>8;a[Aa+1|0]=y;y=y>>8;a[Aa+2|0]=y;y=y>>8;a[Aa+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Zb=Sb+30|0;_b=0}c[i>>2]=_b;c[f>>2]=Zb;Mb=_b;Nb=Zb}}while(0);I=E+1|0;if((I|0)>(c[p>>2]|0)){Kb=Mb;Lb=Nb;break}else{E=I;G=Mb;N=Nb}}}do{if((c[k>>2]|0)==0){N=(D|0)==0;G=N&1;if((Lb|0)>1){$b=Lb-1|0;ac=Kb<<1|G}else{E=je(G>>>((1-Lb|0)>>>0)|Kb<<Lb|0)|0;H=c[h>>2]|0;y=E;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;$b=Lb+31|0;ac=G}c[i>>2]=ac;c[f>>2]=$b;if(N){N=c[q>>2]|0;if(($b|0)>2){bc=$b-2|0;cc=N|ac<<2}else{G=je(N>>>((2-$b|0)>>>0)|ac<<$b|0)|0;H=c[h>>2]|0;y=G;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;bc=$b+30|0;cc=N}c[i>>2]=cc;c[f>>2]=bc;N=c[r>>2]|0;if((bc|0)>2){dc=bc-2|0;ec=N|cc<<2}else{H=je(N>>>((2-bc|0)>>>0)|cc<<bc|0)|0;G=c[h>>2]|0;y=H;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;dc=bc+30|0;ec=N}c[i>>2]=ec;c[f>>2]=dc;N=c[s>>2]|0;if((dc|0)>2){fc=dc-2|0;gc=N|ec<<2}else{G=je(N>>>((2-dc|0)>>>0)|ec<<dc|0)|0;H=c[h>>2]|0;y=G;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;fc=dc+30|0;gc=N}c[i>>2]=gc;c[f>>2]=fc;N=c[t>>2]|0;if((fc|0)>2){hc=fc-2|0;ic=N|gc<<2}else{H=je(N>>>((2-fc|0)>>>0)|gc<<fc|0)|0;G=c[h>>2]|0;y=H;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;hc=fc+30|0;ic=N}c[i>>2]=ic;c[f>>2]=hc;N=c[u>>2]|0;if((hc|0)>3){jc=hc-3|0;kc=N|ic<<3}else{G=je(N>>>((3-hc|0)>>>0)|ic<<hc|0)|0;H=c[h>>2]|0;y=G;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;jc=hc+29|0;kc=N}c[i>>2]=kc;c[f>>2]=jc;lc=kc;mc=jc}else{lc=ac;mc=$b}if((c[k>>2]|0)!=0){nc=lc;oc=mc;F=175;break}N=e+1536+(D<<7)+92|0;H=c[N>>2]|0;if((mc|0)>1){pc=mc-1|0;qc=H|lc<<1;rc=H}else{G=je(H>>>((1-mc|0)>>>0)|lc<<mc|0)|0;E=c[h>>2]|0;y=G;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;pc=mc+31|0;qc=H;rc=c[N>>2]|0}c[i>>2]=qc;c[f>>2]=pc;if((rc|0)==0){sc=qc;tc=pc;F=179;break}N=c[v>>2]|0;if((pc|0)>6){uc=pc-6|0;vc=N|qc<<6}else{H=je(N>>>((6-pc|0)>>>0)|qc<<pc|0)|0;E=c[h>>2]|0;y=H;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;uc=pc+26|0;vc=N}c[i>>2]=vc;c[f>>2]=uc;N=c[ia>>2]|0;E=(N|0)==0|0;if((E|0)>(c[p>>2]|0)){wc=vc;xc=uc;yc=N;break}else{zc=E;Ac=vc;Bc=uc}while(1){E=c[e+2592+(zc<<2)>>2]|0;if((Bc|0)>4){Cc=Bc-4|0;Dc=E|Ac<<4}else{N=je(E>>>((4-Bc|0)>>>0)|Ac<<Bc|0)|0;H=c[h>>2]|0;y=N;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Cc=Bc+28|0;Dc=E}c[i>>2]=Dc;c[f>>2]=Cc;E=c[e+2564+(zc<<2)>>2]|0;if((Cc|0)>3){Ec=Cc-3|0;Fc=E|Dc<<3}else{H=je(E>>>((3-Cc|0)>>>0)|Dc<<Cc|0)|0;N=c[h>>2]|0;y=H;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Ec=Cc+29|0;Fc=E}c[i>>2]=Fc;c[f>>2]=Ec;E=zc+1|0;if((E|0)>(c[p>>2]|0)){sc=Fc;tc=Ec;F=179;break}else{zc=E;Ac=Fc;Bc=Ec}}}else{nc=Kb;oc=Lb;F=175}}while(0);if((F|0)==175){F=0;if((oc|0)>1){Gc=oc-1|0;Hc=nc<<1}else{E=je(nc<<oc|0)|0;N=c[h>>2]|0;y=E;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Gc=oc+31|0;Hc=0}c[i>>2]=Hc;c[f>>2]=Gc;sc=Hc;tc=Gc;F=179}if((F|0)==179){F=0;wc=sc;xc=tc;yc=c[ia>>2]|0}do{if((yc|0)==0){Ic=wc;Jc=xc}else{N=e+1536+(D<<7)+96|0;E=c[N>>2]|0;if((c[k>>2]|0)!=0&(E|0)==2){Kc=xc;Lc=wc}else{if((xc|0)>1){Mc=xc-1|0;Nc=E|wc<<1;Oc=E}else{H=je(E>>>((1-xc|0)>>>0)|wc<<xc|0)|0;G=c[h>>2]|0;y=H;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Mc=xc+31|0;Nc=E;Oc=c[N>>2]|0}c[i>>2]=Nc;c[f>>2]=Mc;if((Oc|0)==0){Ic=Nc;Jc=Mc;break}else{Kc=Mc;Lc=Nc}}N=c[w>>2]|0;if((Kc|0)>3){Pc=Kc-3|0;Qc=N|Lc<<3}else{E=je(N>>>((3-Kc|0)>>>0)|Lc<<Kc|0)|0;G=c[h>>2]|0;y=E;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Pc=Kc+29|0;Qc=N}c[i>>2]=Qc;c[f>>2]=Pc;N=c[x>>2]|0;if((Pc|0)>3){Rc=Pc-3|0;Sc=N|Qc<<3}else{G=je(N>>>((3-Pc|0)>>>0)|Qc<<Pc|0)|0;E=c[h>>2]|0;y=G;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Rc=Pc+29|0;Sc=N}c[i>>2]=Sc;c[f>>2]=Rc;Ic=Sc;Jc=Rc}}while(0);if((c[k>>2]|0)==0){if((Jc|0)>1){Tc=Jc-1|0;Uc=Ic<<1}else{N=je(Ic<<Jc|0)|0;E=c[h>>2]|0;y=N;a[E]=y;y=y>>8;a[E+1|0]=y;y=y>>8;a[E+2|0]=y;y=y>>8;a[E+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Tc=Jc+31|0;Uc=0}c[i>>2]=Uc;c[f>>2]=Tc;if((Tc|0)>1){Vc=Tc-1|0;Wc=Uc<<1}else{E=je(Uc<<Tc|0)|0;N=c[h>>2]|0;y=E;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;Vc=Tc+31|0;Wc=0}c[i>>2]=Wc;c[f>>2]=Vc;Xc=Wc;Yc=Vc}else{Xc=Ic;Yc=Jc}N=c[p>>2]|0;if((N|0)>=1){E=e+1536+(D<<7)+28|0;G=0;H=(c[ia>>2]|0)==0|0;I=1;Ya=Xc;J=Yc;Aa=N;while(1){if((H|0)==0&(I|0)>1){N=I-1|0;Tb=(a[e+1536+(D<<7)+64+N|0]|0)==0;Zc=Tb?I:0;_c=Tb&1^1;$c=Tb?G:N}else{Zc=I;_c=H;$c=G}N=c[e+2432+(Zc<<2)>>2]|0;Tb=e+1536+(D<<7)+100+(Zc<<2)|0;if((N|0)<(c[Tb>>2]|0)){za=e+2788+(Zc*24|0)+(D<<2)|0;Qb=N;N=Ya;Ub=J;while(1){Yb=b[(c[(c[E>>2]|0)+(Zc<<2)>>2]|0)+(Qb<<1)>>1]|0;Xb=Yb&65535;ad=d[(c[za>>2]|0)+Qb|0]|0;a:do{switch(ad|0){case 2:{if(Yb<<16>>16==128){bd=N;cd=Ub;break a}if((Ub|0)>7){dd=Ub-7|0;ed=Xb|N<<7}else{fd=je(Xb>>>((7-Ub|0)>>>0)|N<<Ub|0)|0;gd=c[h>>2]|0;y=fd;a[gd]=y;y=y>>8;a[gd+1|0]=y;y=y>>8;a[gd+2|0]=y;y=y>>8;a[gd+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;dd=Ub+25|0;ed=Xb}c[i>>2]=ed;c[f>>2]=dd;bd=ed;cd=dd;break};case 15:{if((Ub|0)>16){hd=Ub-16|0;id=Xb|N<<16}else{gd=je(Xb>>>((16-Ub|0)>>>0)|N<<Ub|0)|0;fd=c[h>>2]|0;y=gd;a[fd]=y;y=y>>8;a[fd+1|0]=y;y=y>>8;a[fd+2|0]=y;y=y>>8;a[fd+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;hd=Ub+16|0;id=Xb}c[i>>2]=id;c[f>>2]=hd;bd=id;cd=hd;break};case 14:{fd=Xb&16383;if((Ub|0)>14){jd=Ub-14|0;kd=fd|N<<14}else{gd=je(fd>>>((14-Ub|0)>>>0)|N<<Ub|0)|0;ld=c[h>>2]|0;y=gd;a[ld]=y;y=y>>8;a[ld+1|0]=y;y=y>>8;a[ld+2|0]=y;y=y>>8;a[ld+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;jd=Ub+18|0;kd=fd}c[i>>2]=kd;c[f>>2]=jd;bd=kd;cd=jd;break};case 3:{fd=Xb&7;if((Ub|0)>3){md=Ub-3|0;nd=fd|N<<3}else{ld=je(fd>>>((3-Ub|0)>>>0)|N<<Ub|0)|0;gd=c[h>>2]|0;y=ld;a[gd]=y;y=y>>8;a[gd+1|0]=y;y=y>>8;a[gd+2|0]=y;y=y>>8;a[gd+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;md=Ub+29|0;nd=fd}c[i>>2]=nd;c[f>>2]=md;bd=nd;cd=md;break};case 0:{bd=N;cd=Ub;break};case 4:{if(Yb<<16>>16==128){bd=N;cd=Ub;break a}if((Ub|0)>7){od=Ub-7|0;pd=Xb|N<<7}else{fd=je(Xb>>>((7-Ub|0)>>>0)|N<<Ub|0)|0;gd=c[h>>2]|0;y=fd;a[gd]=y;y=y>>8;a[gd+1|0]=y;y=y>>8;a[gd+2|0]=y;y=y>>8;a[gd+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;od=Ub+25|0;pd=Xb}c[i>>2]=pd;c[f>>2]=od;bd=pd;cd=od;break};case 1:{if(Yb<<16>>16==128){bd=N;cd=Ub;break a}if((Ub|0)>5){qd=Ub-5|0;rd=Xb|N<<5}else{gd=je(Xb>>>((5-Ub|0)>>>0)|N<<Ub|0)|0;fd=c[h>>2]|0;y=gd;a[fd]=y;y=y>>8;a[fd+1|0]=y;y=y>>8;a[fd+2|0]=y;y=y>>8;a[fd+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;qd=Ub+27|0;rd=Xb}c[i>>2]=rd;c[f>>2]=qd;bd=rd;cd=qd;break};default:{fd=ad-1|0;gd=(1<<fd)+65535&Xb;if((Ub|0)>(fd|0)){sd=Ub-fd|0;td=gd|N<<fd}else{ld=je(gd>>>((fd-Ub|0)>>>0)|N<<Ub|0)|0;fd=c[h>>2]|0;y=ld;a[fd]=y;y=y>>8;a[fd+1|0]=y;y=y>>8;a[fd+2|0]=y;y=y>>8;a[fd+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;sd=Ub+33-ad|0;td=gd}c[i>>2]=td;c[f>>2]=sd;bd=td;cd=sd}}}while(0);ad=Qb+1|0;if((ad|0)<(c[Tb>>2]|0)){Qb=ad;N=bd;Ub=cd}else{break}}ud=bd;vd=cd;wd=c[p>>2]|0}else{ud=Ya;vd=J;wd=Aa}Ub=((Zc|0)==0?$c:Zc)+1|0;if((Ub|0)>(wd|0)){break}else{G=$c;H=_c;I=Ub;Ya=ud;J=vd;Aa=wd}}}D=D+1|0;}while((D|0)<(c[j>>2]|0))}j=DGb(1)|0;D=e+2340|0;wd=c[D>>2]|0;vd=(wd>>2)+(wd>>4)<<1;ud=c[f>>2]|0;if((ud|0)<32){_c=c[i>>2]<<ud;c[i>>2]=_c;ud=_c>>>24&255;while(1){_c=c[h>>2]|0;c[h>>2]=_c+1;a[_c]=ud;_c=c[i>>2]|0;c[i>>2]=_c<<8;$c=(c[f>>2]|0)+8|0;c[f>>2]=$c;if(($c|0)<32){ud=_c>>>16&255}else{break}}xd=c[D>>2]|0}else{xd=wd}c[f>>2]=32;c[i>>2]=0;i=c[g>>2]|0;g=c[h>>2]|0;h=xd-2+i-g|0;if((h|0)>0){mrc(g|0,0,h|0)|0}if((c[e+2308>>2]|0)==0){h=b[e+2348+(((c[D>>2]|0)>(c[e+2336>>2]|0))<<1)>>1]|0;if(h<<16>>16==0){yd=0}else{e=(he((EGb(j,0,i+4|0,vd-4|0)|0)&65535|0)|0)&65535;g=h&65535;h=0;while(1){zd=((g&1|0)==0?0:e)^h;xd=g>>>1;f=e<<1;if((xd|0)==0){break}else{e=(f&65536|0)==0?f:f^98309;g=xd;h=zd}}yd=zd&65535}zd=i+2|0;y=he(yd|0)|0;a[zd]=y;y=y>>8;a[zd+1|0]=y;zd=c[D>>2]|0;Ad=EGb(j,0,i+vd|0,-3-vd+zd|0)|0;Bd=zd}else{zd=c[D>>2]|0;Ad=EGb(j,0,i+2|0,zd-5|0)|0;Bd=zd}zd=i+(Bd-3)|0;vd=EGb(j,Ad,zd,1)|0;if((vd|0)!=30475){Cd=vd&65535;Dd=Bd;Ed=Dd-2|0;Fd=i+Ed|0;Gd=Fd;y=Cd;a[Gd]=y;y=y>>8;a[Gd+1|0]=y;return}a[zd]=a[zd]^1;zd=c[D>>2]|0;Cd=(EGb(j,Ad,i+(zd-3)|0,1)|0)&65535;Dd=zd;Ed=Dd-2|0;Fd=i+Ed|0;Gd=Fd;y=Cd;a[Gd]=y;y=y>>8;a[Gd+1|0]=y;return}function Wkb(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;e=c[b+108>>2]|0;f=b+24|0;c[f>>2]=0;j=b+44|0;c[j>>2]=0;k=b+68|0;c[k>>2]=0;l=b+84|0;c[l>>2]=0;m=b+88|0;c[m>>2]=0;n=c[b+2392>>2]|0;do{if((n|0)>2){if((c[b+48>>2]|0)==-1){break}c[j>>2]=1;c[l>>2]=1}}while(0);o=b+2384|0;p=(c[o>>2]|0)==0;do{if(!p){if(+g[b+52>>2]<0.0){if(+g[b+60>>2]<0.0){break}}c[j>>2]=1;c[l>>2]=1}}while(0);q=b+2388|0;r=c[q>>2]|0;do{if((r|0)!=0){if(+g[b+56>>2]<0.0){if(+g[b+64>>2]<0.0){break}}c[j>>2]=1;c[l>>2]=1}}while(0);s=b+2308|0;t=(c[s>>2]|0)==0;a:do{if(t){if((c[b+28>>2]|0)==-1){if(!((c[b+32>>2]|0)==-1)){u=31}}else{u=31}if((u|0)==31){c[f>>2]=1}do{if((n|0)>5){if((c[b+72>>2]|0)==-1){break}c[k>>2]=1}}while(0);do{if((n|0)==2){if((c[b+76>>2]|0)==-1){break}c[k>>2]=1}}while(0);if((c[b+80>>2]|0)==-1){break}c[k>>2]=1}else{if((c[e+464>>2]|0)!=0){c[m>>2]=1}if((c[b+36>>2]|0)==-1){if(!((c[b+40>>2]|0)==-1)){u=17}}else{u=17}if((u|0)==17){c[m>>2]=1}do{if((n|0)==2){if((c[b+76>>2]|0)==-1){if((c[b+20>>2]|0)==-1){break}}c[m>>2]=1}}while(0);do{if((n|0)>5){if((c[b+72>>2]|0)==-1){break}c[m>>2]=1}}while(0);do{if((c[b+28>>2]|0)==-1){if(!((c[b+32>>2]|0)==-1)){break}if((c[b+80>>2]|0)==-1){break a}}}while(0);c[f>>2]=1;c[m>>2]=1}}while(0);do{if(t){if(p){v=r}else{n=e;w=b+12|0;x=b+2400|0;y=+g[w>>2];z=y;A=0;while(1){if((A|0)>=3){break}B=+g[1703464+(A<<2)>>2];if(z<B+.01&z>B+-.01){break}else{A=A+1|0}}C=(A|0)==3?-1:A;do{if((C|0)<0){if(y<0.0){D=1;E=r;break}KIb(n,24,2513456,(F=i,i=i+16|0,c[F>>2]=2433496,h[F+8>>3]=.5946035385131836,F)|0);i=F;D=1;E=c[q>>2]|0}else{D=C;E=r}}while(0);g[w>>2]=+g[1703464+(D<<2)>>2];c[x>>2]=D;v=E}if((v|0)==0){break}C=e;n=b+16|0;A=b+2404|0;y=+g[n>>2];z=y;G=0;while(1){if((G|0)>=3){break}B=+g[551960+(G<<2)>>2];if(z<B+.01&z>B+-.01){break}else{G=G+1|0}}x=(G|0)==3?-1:G;do{if((x|0)<0){if(y<0.0){H=1;break}KIb(C,24,2513456,(F=i,i=i+16|0,c[F>>2]=2583240,h[F+8>>3]=.5,F)|0);i=F;H=1}else{H=x}}while(0);g[n>>2]=+g[551960+(H<<2)>>2];c[A>>2]=H}}while(0);if((c[j>>2]|0)==0){if((c[l>>2]|0)!=0){u=59}}else{u=59}do{if((u|0)==59){l=b+48|0;if((c[l>>2]|0)==-1){c[l>>2]=0}if((c[s>>2]|0)==0){u=63}else{if((c[o>>2]|0)==0){u=76}else{u=63}}if((u|0)==63){l=e;H=b+52|0;v=b+2408|0;y=+g[H>>2];z=y;E=0;while(1){if((E|0)>=8){break}B=+g[1489576+(E<<2)>>2];if(z<B+.01&z>B+-.01){break}else{E=E+1|0}}A=(E|0)==8?-1:E;do{if((A|0)<0){if(y<0.0){I=5;break}KIb(l,24,2513456,(F=i,i=i+16|0,c[F>>2]=2438560,h[F+8>>3]=.5946035385131836,F)|0);i=F;I=5}else{I=A}}while(0);g[H>>2]=+g[1489576+(I<<2)>>2];c[v>>2]=I;A=b+60|0;E=b+2416|0;y=+g[A>>2];z=y;n=0;while(1){if((n|0)>=8){break}B=+g[1489576+(n<<2)>>2];if(z<B+.01&z>B+-.01){break}else{n=n+1|0}}v=(n|0)==8?-1:n;do{if((v|0)<0){if(y<0.0){J=5;break}KIb(l,24,2513456,(F=i,i=i+16|0,c[F>>2]=2351368,h[F+8>>3]=.5946035385131836,F)|0);i=F;J=5}else{J=v}}while(0);g[A>>2]=+g[1489576+(J<<2)>>2];c[E>>2]=J;if((c[s>>2]|0)!=0){u=76}}if((u|0)==76){if((c[q>>2]|0)==0){break}}v=e;l=b+56|0;n=b+2412|0;y=+g[l>>2];z=y;H=0;while(1){if((H|0)>=8){break}B=+g[1489576+(H<<2)>>2];if(z<B+.01&z>B+-.01){break}else{H=H+1|0}}E=(H|0)==8?-1:H;do{if((E|0)<3){if(y<0.0){K=6;break}KIb(v,24,2513456,(F=i,i=i+16|0,c[F>>2]=2289688,h[F+8>>3]=.5,F)|0);i=F;K=6}else{K=E}}while(0);g[l>>2]=+g[1489576+(K<<2)>>2];c[n>>2]=K;E=b+64|0;H=b+2420|0;y=+g[E>>2];z=y;A=0;while(1){if((A|0)>=8){break}B=+g[1489576+(A<<2)>>2];if(z<B+.01&z>B+-.01){break}else{A=A+1|0}}n=(A|0)==8?-1:A;do{if((n|0)<3){if(y<0.0){L=6;break}KIb(v,24,2513456,(F=i,i=i+16|0,c[F>>2]=2239232,h[F+8>>3]=.5,F)|0);i=F;L=6}else{L=n}}while(0);g[E>>2]=+g[1489576+(L<<2)>>2];c[H>>2]=L}}while(0);L=c[e+464>>2]|0;do{if((L|0)==8){if((c[e+416>>2]|0)==1){u=94}}else{if(!((L-5|0)>>>0<3>>>0)){break}if((c[e+416>>2]|0)>1){u=94}}}while(0);if((u|0)==94){KIb(e,16,2198312,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;M=-22;i=d;return M|0}L=(c[k>>2]|0)==0;if(L){if((c[m>>2]|0)!=0){u=97}}else{u=97}do{if((u|0)==97){k=b+76|0;if((c[k>>2]|0)==-1){c[k>>2]=0}k=b+72|0;if((c[k>>2]|0)==-1){c[k>>2]=0}k=b+80|0;if(!((c[k>>2]|0)==-1)){break}c[k>>2]=0}}while(0);k=(c[s>>2]|0)==0;if(k){u=105}else{if((c[m>>2]|0)!=0){u=105}}do{if((u|0)==105){s=b+36|0;if((c[s>>2]|0)==-1){c[s>>2]=0}s=b+40|0;if((c[s>>2]|0)==-1){c[s>>2]=1}if(!k){if((c[m>>2]|0)==0){break}}s=b+20|0;if(!((c[s>>2]|0)==-1)){break}c[s>>2]=0}}while(0);do{if((c[f>>2]|0)!=0){m=c[b+28>>2]|0;if((m|0)==-1){KIb(e,16,2166792,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;M=-22;i=d;return M|0}if((m|0)<80){KIb(e,16,2140288,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;M=-22;i=d;return M|0}else{m=b+32|0;if(!((c[m>>2]|0)==-1)){break}c[m>>2]=0;break}}}while(0);if(!k){M=0;i=d;return M|0}if(!((c[j>>2]|0)!=0|L^1)){M=0;i=d;return M|0}L=b+2312|0;if(!(((c[L>>2]|0)-9|0)>>>0<2>>>0)){c[L>>2]=6;M=0;i=d;return M|0}if(a[1443160]|0){M=0;i=d;return M|0}KIb(e,24,2116920,(F=i,i=i+1|0,i=i+7&-8,c[F>>2]=0,F)|0);i=F;a[1443160]=1;M=0;i=d;return M|0}function Xkb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[a+60>>2]|0;a=b;mJb(b+2632|0);d=b+2636|0;e=d;f=c[e>>2]|0;a:do{if((f|0)!=0){g=b+2372|0;if((c[g>>2]|0)>0){h=0;i=f}else{break}while(1){mJb(i+(h<<2)|0);j=h+1|0;if((j|0)>=(c[g>>2]|0)){break a}h=j;i=c[e>>2]|0}}}while(0);mJb(d);mJb(b+2640|0);mJb(b+2644|0);mJb(b+2648|0);mJb(b+2652|0);mJb(b+2656|0);mJb(b+2660|0);mJb(b+2664|0);mJb(b+2668|0);mJb(b+2672|0);mJb(b+2676|0);mJb(b+2680|0);mJb(b+2684|0);d=b+2332|0;if((c[d>>2]|0)<=0){k=b+2960|0;l=k;m=c[l>>2]|0;qe[m&1023](a);return 0}e=b+1536|0;i=0;do{mJb(e+(i<<7)|0);mJb(e+(i<<7)+4|0);mJb(e+(i<<7)+8|0);mJb(e+(i<<7)+12|0);mJb(e+(i<<7)+16|0);mJb(e+(i<<7)+20|0);mJb(e+(i<<7)+24|0);mJb(e+(i<<7)+28|0);mJb(e+(i<<7)+32|0);mJb(e+(i<<7)+36|0);i=i+1|0;}while((i|0)<(c[d>>2]|0));k=b+2960|0;l=k;m=c[l>>2]|0;qe[m&1023](a);return 0}function Ykb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0;g=i;i=i+16|0;h=g|0;j=c[f+60>>2]|0;k=j;l=j+108|0;c[l>>2]=f;m=j+2308|0;c[m>>2]=(c[f+48>>2]|0)==86057;Gub();n=c[l>>2]|0;o=n+448|0;if((c[o>>2]|0)==0&(c[o+4>>2]|0)==0){KIb(n,24,2611320,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}q=c[n+416>>2]|0;a:do{if(!((q-1|0)>>>0>6>>>0)){r=c[o>>2]|0;s=c[o+4>>2]|0;t=0;if(s>>>0>t>>>0|s>>>0==t>>>0&r>>>0>2047>>>0){break}t=r;if((t|0)==0){r=tGb(q)|0;u=r}else{u=t}t=u>>>3&1;r=j+2376|0;c[r>>2]=t;s=j+2372|0;c[s>>2]=q;v=q-t|0;w=j+2368|0;c[w>>2]=v;x=(t|0)==0;y=j+2380|0;c[y>>2]=x?-1:v+1|0;v=x?u:u-8|0;switch(v|0){case 7:{c[j+2392>>2]=3;z=3;A=15;break};case 263:{c[j+2392>>2]=5;z=5;A=15;break};case 3:{c[j+2392>>2]=2;B=0;C=2;break};case 1543:case 55:{c[j+2392>>2]=7;z=7;A=15;break};case 259:{c[j+2392>>2]=4;B=0;C=4;break};case 51:case 1539:{c[j+2392>>2]=6;B=0;C=6;break};case 4:{c[j+2392>>2]=1;z=1;A=15;break};default:{break a}}if((A|0)==15){B=(z|0)!=1|0;C=z}c[j+2384>>2]=B;c[j+2388>>2]=C&4;c[j+2396>>2]=1444480+(C*12|0)+(t*6|0);t=v;D=(v|0)<0|0?-1:0;c[o>>2]=x?t:t|8;c[o+4>>2]=x?D:D|0;D=c[m>>2]|0;x=(D|0)!=0?2:8;t=n+412|0;v=0;while(1){if((v|0)>(x|0)){A=20;break}E=(v|0)%3|0;F=(v|0)/3|0;G=(e[1443280+(E<<1)>>1]|0)>>>(F>>>0);if((G|0)==(c[t>>2]|0)){break}else{v=v+1|0}}if((A|0)==20){KIb(n,16,2564024,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;H=-22;i=g;return H|0}v=j+2324|0;c[v>>2]=G;t=j+2528|0;c[t>>2]=F;x=j+2524|0;c[x>>2]=E;c[j+2312>>2]=(D|0)==0?F+8|0:16;I=n+72|0;J=c[I>>2]|0;b:do{if((J|0)==0){switch(c[w>>2]|0){case 3:{c[I>>2]=32e4;K=32e4;break b;break};case 5:{c[I>>2]=448e3;K=448e3;break b;break};case 4:{c[I>>2]=384e3;K=384e3;break b;break};case 1:{c[I>>2]=96e3;K=96e3;break b;break};case 2:{c[I>>2]=192e3;K=192e3;break b;break};default:{K=0;break b}}}else{K=J}}while(0);if((c[m>>2]|0)==0){J=0;D=2147483647;L=0;M=0;while(1){if((J|0)>=19){N=L;O=M;break}P=((e[1445024+(J<<1)>>1]|0)>>>((c[t>>2]|0)>>>0))*1e3|0;Q=P-K|0;R=(Q|0)>-1?Q:-Q|0;Q=(R|0)<(D|0);S=Q?P:M;P=Q?J:L;T=Q?R:D;if((T|0)==0){N=P;O=S;break}else{J=J+1|0;D=T;L=P;M=S}}c[I>>2]=O;M=N<<1;c[j+2344>>2]=M;L=e[1444e3+(M*6|0)+(c[x>>2]<<1)>>1]<<1;c[j+2336>>2]=L;c[j+2328>>2]=3;c[j+2332>>2]=6;U=L}else{L=h|0;M=h+4|0;D=h+8|0;J=h+12|0;S=0;P=0;T=3;R=0;Q=0;while(1){if(!((T|0)>-1)){V=S;W=P;X=R;Y=Q;break}c[L>>2]=1;c[M>>2]=2;c[D>>2]=3;c[J>>2]=6;Z=c[h+(T<<2)>>2]|0;_=Z<<8;$=c[v>>2]|0;aa=(($<<11|0)/(_|0)|0)<<4;ba=((_-1+$|0)/(_|0)|0)<<4;if((K|0)>(aa|0)){S=_;P=Z;T=T-1|0;R=ba;Q=aa}else{V=_;W=Z;X=ba;Y=aa;break}}if((K|0)<(X|0)|(K|0)>(Y|0)){KIb(n,16,2546128,(p=i,i=i+16|0,c[p>>2]=X,c[p+8>>2]=Y,p)|0);i=p;H=-22;i=g;return H|0}c[j+2328>>2]=T;c[j+2332>>2]=W;Q=c[I>>2]|0;R=c[v>>2]|0;P=2147483647;S=-1;J=0;while(1){D=((e[1445024+(J<<1)>>1]|0)*1e3|0)-Q|0;M=(D|0)>-1?D:-D|0;D=(M|0)<(P|0);da=D?J:S;L=J+1|0;if((L|0)<19){P=D?M:P;S=da;J=L}else{break}}J=(ca((Q|0)/16|0,V)|0)/(R|0)|0;c[j+2344>>2]=da<<1;S=J;while(1){if((S|0)<=1){break}J=((ca(S,R)|0)/1536|0)<<4;if((J|0)>(c[I>>2]|0)){S=S-1|0}else{break}}R=S<<1;c[j+2336>>2]=R;U=R}c[j+2320>>2]=c[I>>2];R=j+2340|0;c[R>>2]=U;Q=c[n+436>>2]|0;if((Q|0)<0){KIb(n,16,2528440,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;H=-22;i=g;return H|0}J=j+2424|0;c[J>>2]=Q;P=c[v>>2]>>1;if((Q|0)>(P|0)){c[J>>2]=P}P=Wkb(k)|0;if((P|0)!=0){H=P;i=g;return H|0}if((c[j+96>>2]|0)==0){ea=0}else{ea=(c[j+2392>>2]|0)==2|0}c[j+2500>>2]=ea;P=j+100|0;if((c[P>>2]|0)==0){fa=0}else{fa=(c[j+2392>>2]|0)>1|0}Q=j+2468|0;c[Q>>2]=fa;T=j+2332|0;c[f+424>>2]=c[T>>2]<<8;c[f+116>>2]=256;L=c[f+464>>2]|0;c[j+2316>>2]=(L|0)==8?7:L;mrc(j+2352|0,0,16)|0;L=c[R>>2]|0;R=L-16+(L>>>2<<4)&-16;if((R|0)==0){ga=1}else{M=R;R=49154;D=1;while(1){do{if((M&1|0)==0){ha=D}else{if((D|0)==0){ha=0;break}else{ia=R;ja=D;ka=0}while(1){aa=((ja&1|0)==0?0:ia)^ka;ba=ja>>>1;Z=ia<<1;if((ba|0)==0){ha=aa;break}else{ia=(Z&65536|0)==0?Z:Z^98309;ja=ba;ka=aa}}}}while(0);if((R|0)==0){la=0}else{aa=R;ba=R;Z=0;while(1){_=((ba&1|0)==0?0:aa)^Z;$=ba>>>1;ma=aa<<1;if(($|0)==0){la=_;break}else{aa=(ma&65536|0)==0?ma:ma^98309;ba=$;Z=_}}}Z=M>>>1;if((Z|0)==0){break}else{M=Z;R=la;D=ha}}ga=ha&65535}b[j+2348>>1]=ga;D=c[x>>2]|0;if((D|0)==1){R=L-14+((L+2|0)>>>2<<4)&-16;if((R|0)==0){na=1}else{M=R;R=49154;I=1;while(1){do{if((M&1|0)==0){oa=I}else{if((I|0)==0){oa=0;break}else{pa=R;qa=I;ra=0}while(1){S=((qa&1|0)==0?0:pa)^ra;Z=qa>>>1;ba=pa<<1;if((Z|0)==0){oa=S;break}else{pa=(ba&65536|0)==0?ba:ba^98309;qa=Z;ra=S}}}}while(0);if((R|0)==0){sa=0}else{S=R;Z=R;ba=0;while(1){aa=((Z&1|0)==0?0:S)^ba;_=Z>>>1;$=S<<1;if((_|0)==0){sa=aa;break}else{S=($&65536|0)==0?$:$^98309;Z=_;ba=aa}}}ba=M>>>1;if((ba|0)==0){break}else{M=ba;R=sa;I=oa}}na=oa&65535}b[j+2350>>1]=na}I=j+2304|0;R=j+2960|0;if((c[I>>2]|0)==0){c[R>>2]=300;c[j+2964>>2]=208;c[j+2968>>2]=1600}else{c[R>>2]=286;c[j+2964>>2]=468;c[j+2968>>2]=318}c[j+2972>>2]=(c[m>>2]|0)==0?96:2;R=c[J>>2]|0;if((R|0)==0){M=c[w>>2]|0;c[j+2428>>2]=d[((c[j+2344>>2]|0)/2|0)+(2101968+((M-1|0)*57|0)+(D*19|0))|0]|0;ta=M}else{M=((R<<9|0)/(c[v>>2]|0)|0)-73|0;R=(M|0)/3|0;if((M|0)<-2){ua=0}else{ua=(R|0)>60?60:R}c[j+2428>>2]=ua;ta=c[w>>2]|0}if((ta|0)<1){va=1}else{R=j+2428|0;M=1;while(1){c[k+2432+(M<<2)>>2]=0;if((c[T>>2]|0)>0){L=0;do{c[k+1536+(L<<7)+100+(M<<2)>>2]=((c[R>>2]|0)*3|0)+73;L=L+1|0;}while((L|0)<(c[T>>2]|0))}L=M+1|0;if((L|0)>(c[w>>2]|0)){va=L;break}else{M=L}}}do{if((c[r>>2]|0)!=0){c[k+2432+(c[y>>2]<<2)>>2]=0;if((c[T>>2]|0)>0){wa=0}else{break}do{c[k+1536+(wa<<7)+100+(va<<2)>>2]=7;wa=wa+1|0;}while((wa|0)<(c[T>>2]|0))}}while(0);c:do{if((c[Q>>2]|0)==0){xa=12}else{y=c[j+104>>2]|0;do{if((y|0)==-1){M=a[((c[j+2344>>2]|0)/2|0)+(2101624+(((c[j+2392>>2]|0)-2|0)*57|0)+((c[x>>2]|0)*19|0))|0]|0;if(!(M<<24>>24<0)){ya=M<<24>>24;break}if(!((c[P>>2]|0)==-1)){ya=15;break}c[Q>>2]=0;xa=12;break c}else{ya=y}}while(0);y=j+2480|0;M=(c[j+2428>>2]|0)/4|0;R=M+3|0;v=M+2|0;M=(v|0)>15?15:v;if((ya|0)<0){za=0}else{za=(ya|0)>(M|0)?M:ya}c[j+2472>>2]=R-za;M=j+2476|0;c[M>>2]=1;a[y]=12;v=za+1|0;d:do{if((v|0)<(R|0)){D=y;J=v;do{L=J;ba=12;while(1){if((a[1393232+L|0]|0)==0){break}Z=ba+12&255;a[D]=Z;S=L+1|0;if((S|0)<(R|0)){L=S;ba=Z}else{break d}}c[M>>2]=(c[M>>2]|0)+1;D=D+1|0;a[D]=12;J=L+1|0;}while((J|0)<(R|0))}}while(0);c[j+2432>>2]=(za*12|0)+37;M=(R*12|0)+37|0;c[j+2460>>2]=M;v=c[T>>2]|0;if((v|0)>0){Aa=0}else{xa=12;break}while(1){c[k+1536+(Aa<<7)+100>>2]=M;y=Aa+1|0;if((y|0)<(v|0)){Aa=y}else{xa=12;break}}}}while(0);while(1){a[8970872+xa|0]=(xa-1|0)/3|0;a[8971640+xa|0]=(xa|0)/3|0;P=xa+1|0;if((P|0)<256){xa=P}else{Ba=12;break}}while(1){a[8971128+Ba|0]=(Ba+2|0)/6|0;a[8971896+Ba|0]=(Ba|0)/6|0;P=Ba+1|0;if((P|0)<256){Ba=P}else{Ca=12;break}}do{a[8971384+Ca|0]=(Ca+8|0)/12|0;a[8972152+Ca|0]=(Ca|0)/12|0;Ca=Ca+1|0;}while((Ca|0)<256);a[8970879]=2;if((c[m>>2]|0)==0){Da=0}else{Aca();Da=c[m>>2]|0}P=j+2508|0;c[P>>2]=2;x=j+2512|0;c[x>>2]=1;v=j+2504|0;c[v>>2]=1;M=(Da|0)!=0?2:3;R=j+2516|0;c[R>>2]=M;y=j+2520|0;c[y>>2]=7;if((c[s>>2]|0)<0){Ea=2;Fa=1;Ga=1;Ha=M;Ia=7;Ja=Da}else{M=0;do{c[k+2564+(M<<2)>>2]=4;M=M+1|0;}while((M|0)<=(c[s>>2]|0));Ea=c[P>>2]|0;Fa=c[x>>2]|0;Ga=c[v>>2]|0;Ha=c[R>>2]|0;Ia=c[y>>2]|0;Ja=c[m>>2]|0}c[j+2560>>2]=40;M=c[t>>2]|0;c[j+2536>>2]=(d[1443272+Ea|0]|0)>>>(M>>>0);c[j+2540>>2]=(d[1444368+Fa|0]|0)>>>(M>>>0);c[j+2532>>2]=e[1443264+(Ga<<1)>>1]|0;c[j+2544>>2]=e[1444856+(Ha<<1)>>1]|0;c[j+2548>>2]=b[1444232+(Ia<<1)>>1]|0;c[j+2552>>2]=0;c[j+2556>>2]=0;M=(Ja|0)==0;if(M){Ka=(c[1635832+(c[j+2392>>2]<<2)>>2]|0)+65|0;La=c[T>>2]|0}else{J=c[T>>2]|0;if((c[j+2740>>2]|0)==0){D=c[w>>2]|0;Ma=ca(J<<1,D)|0;Na=D}else{D=c[w>>2]|0;Ma=D*5|0;Na=D}D=Ma+((J|0)==6?66:65)+((c[r>>2]|0)==0?0:J)|0;if((c[j+2328>>2]|0)==3){Oa=D+(Na*5|0)|0}else{Oa=D+1|0}Ka=Oa+((J|0)==1?10:11)|0;La=J}if((La|0)>0){J=M&1^1;D=0;ba=Ka;Z=Ja;while(1){do{if(M){S=(Z|0)==0;aa=c[w>>2]<<1;_=(S?1:2)+ba+aa|0;if(!S){Pa=_;Qa=Z;break}Pa=aa+((D|0)==0?12:1)+_+((c[r>>2]|0)!=0)|0;Qa=0}else{Pa=ba+2|0;Qa=Z}}while(0);_=Pa+J|0;aa=M?_+2|0:_;_=D+1|0;if((_|0)<(La|0)){D=_;ba=aa;Z=Qa}else{Ra=aa;break}}}else{Ra=Ka}c[j+2620>>2]=Ra+18;Z=ve[c[j+2964>>2]&4095](k)|0;e:do{if((Z|0)==0){ba=c[l>>2]|0;D=c[s>>2]|0;M=D+1|0;J=ca(M,c[T>>2]|0)|0;r=J<<8;if((ve[c[j+2968>>2]&4095](k)|0)!=0){Sa=-12;break}w=hJb(r)|0;c[j+2640>>2]=w;t=(r|0)==0;if(!((w|0)!=0|t)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}w=hJb(r)|0;c[j+2644>>2]=w;if(!((w|0)!=0|t)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}w=J<<10;y=pJb(w)|0;R=j+2648|0;c[R>>2]=y;v=(w|0)==0;if(!((y|0)!=0|v)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}y=hJb(r)|0;r=j+2656|0;c[r>>2]=y;if(!((y|0)!=0|t)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}t=J<<7;y=hJb(t)|0;x=j+2660|0;c[x>>2]=y;P=(t|0)==0;if(!((y|0)!=0|P)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}y=J<<9;aa=hJb(y)|0;_=j+2664|0;c[_>>2]=aa;S=(y|0)==0;if(!((aa|0)!=0|S)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}aa=hJb(t)|0;$=j+2668|0;c[$>>2]=aa;if(!((aa|0)!=0|P)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}aa=hJb(t)|0;t=j+2672|0;c[t>>2]=aa;if(!((aa|0)!=0|P)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}P=hJb(y)|0;y=j+2676|0;c[y>>2]=P;if(!((P|0)!=0|S)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break}do{if((c[Q>>2]|0)!=0){S=J<<4;P=hJb(S)|0;c[j+2680>>2]=P;aa=(S|0)==0;if(!((P|0)!=0|aa)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}P=hJb(S)|0;c[j+2684>>2]=P;if((P|0)!=0|aa){break}KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}}while(0);J=c[T>>2]|0;f:do{if((J|0)>0){aa=M<<2;P=(aa|0)==0;S=(M|0)>0;ma=j+2680|0;Ta=j+2684|0;Ua=0;while(1){Va=pJb(aa)|0;Wa=k+1536+(Ua<<7)|0;c[Wa>>2]=Va;if(!((Va|0)!=0|P)){A=153;break}Va=pJb(aa)|0;Xa=k+1536+(Ua<<7)+8|0;c[Xa>>2]=Va;if(!((Va|0)!=0|P)){A=155;break}Va=pJb(aa)|0;Ya=k+1536+(Ua<<7)+12|0;c[Ya>>2]=Va;if(!((Va|0)!=0|P)){A=157;break}Va=pJb(aa)|0;Za=k+1536+(Ua<<7)+16|0;c[Za>>2]=Va;if(!((Va|0)!=0|P)){A=159;break}Va=pJb(aa)|0;_a=k+1536+(Ua<<7)+20|0;c[_a>>2]=Va;if(!((Va|0)!=0|P)){A=161;break}Va=pJb(aa)|0;$a=k+1536+(Ua<<7)+24|0;c[$a>>2]=Va;if(!((Va|0)!=0|P)){A=163;break}Va=pJb(aa)|0;ab=k+1536+(Ua<<7)+28|0;c[ab>>2]=Va;if(!((Va|0)!=0|P)){A=165;break}if((c[Q>>2]|0)!=0){Va=pJb(aa)|0;c[k+1536+(Ua<<7)+32>>2]=Va;if(!((Va|0)!=0|P)){A=171;break}Va=pJb(aa)|0;c[k+1536+(Ua<<7)+36>>2]=Va;if(!((Va|0)!=0|P)){A=173;break}}if(S){Va=ca(Ua,M)|0;bb=k+1536+(Ua<<7)+32|0;cb=k+1536+(Ua<<7)+36|0;db=(c[Q>>2]|0)==0;eb=0;while(1){fb=eb+Va|0;c[(c[Ya>>2]|0)+(eb<<2)>>2]=(c[x>>2]|0)+(fb<<7);gb=fb<<8;c[(c[Za>>2]|0)+(eb<<2)>>2]=(c[_>>2]|0)+(gb<<1);hb=fb<<6;c[(c[_a>>2]|0)+(eb<<2)>>2]=(c[$>>2]|0)+(hb<<1);c[(c[$a>>2]|0)+(eb<<2)>>2]=(c[t>>2]|0)+(hb<<1);c[(c[ab>>2]|0)+(eb<<2)>>2]=(c[y>>2]|0)+(gb<<1);if(!db){gb=fb<<4;c[(c[bb>>2]|0)+(eb<<2)>>2]=(c[ma>>2]|0)+gb;c[(c[cb>>2]|0)+(eb<<2)>>2]=(c[Ta>>2]|0)+gb}gb=c[T>>2]|0;fb=(ca(gb,eb)|0)+Ua<<8;c[(c[Xa>>2]|0)+(eb<<2)>>2]=(c[r>>2]|0)+fb;c[(c[Wa>>2]|0)+(eb<<2)>>2]=(c[R>>2]|0)+(fb<<2);fb=eb+1|0;if((fb|0)<(M|0)){eb=fb}else{ib=gb;break}}}else{ib=c[T>>2]|0}eb=Ua+1|0;if((eb|0)<(ib|0)){Ua=eb}else{jb=ib;break f}}if((A|0)==153){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((A|0)==155){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((A|0)==157){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((A|0)==159){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((A|0)==161){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((A|0)==163){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((A|0)==165){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((A|0)==171){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else if((A|0)==173){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}}else{jb=J}}while(0);g:do{if((c[I>>2]|0)==0){J=pJb(w)|0;R=j+2652|0;c[R>>2]=J;if(!((J|0)!=0|v)){KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}if((c[T>>2]|0)<=0){break}J=M<<2;r=(J|0)==0;y=(M|0)>0;t=(D|0)>0;$=0;while(1){_=pJb(J)|0;x=_;Ua=k+1536+($<<7)+4|0;c[Ua>>2]=x;if(!((_|0)!=0|r)){break}_=c[T>>2]|0;do{if(y){c[x>>2]=(c[R>>2]|0)+($<<8<<2);if(t){kb=1}else{break}do{Ta=(ca(kb,_)|0)+$<<8;c[(c[Ua>>2]|0)+(kb<<2)>>2]=(c[R>>2]|0)+(Ta<<2);kb=kb+1|0;}while((kb|0)<(M|0))}}while(0);$=$+1|0;if(($|0)>=(_|0)){break g}}KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}else{if((jb|0)<=0){break}$=M<<2;R=($|0)==0;t=(M|0)>0;y=(D|0)>0;r=0;while(1){J=pJb($)|0;Ua=J;x=k+1536+(r<<7)+4|0;c[x>>2]=Ua;if(!((J|0)!=0|R)){break}do{if(t){J=k+1536+(r<<7)|0;c[Ua>>2]=c[c[J>>2]>>2];if(y){lb=1}else{break}do{c[(c[x>>2]|0)+(lb<<2)>>2]=c[(c[J>>2]|0)+(lb<<2)>>2];lb=lb+1|0;}while((lb|0)<(M|0))}}while(0);r=r+1|0;if((r|0)>=(c[T>>2]|0)){break g}}KIb(ba,16,2634832,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;Sa=-12;break e}}while(0);l8(j+136|0,f);ba=f+88|0;qHb(j+1380|0,c[ba>>2]&8388608);Akb(j+1416|0,c[ba>>2]&8388608);H=0;i=g;return H|0}else{Sa=Z}}while(0);Xkb(f)|0;H=Sa;i=g;return H|0}}while(0);KIb(n,16,2584784,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p;H=-22;i=g;return H|0}function Zkb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0;d=b+112|0;e=c[d>>2]|0;f=b+116|0;g=c[f>>2]|0;if((g|0)>16){h=g-16|0;i=e<<16|2935}else{j=je(2935>>>((16-g|0)>>>0)|e<<g|0)|0;e=b+124|0;k=c[e>>2]|0;y=j;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[e>>2]=(c[e>>2]|0)+4;h=g+16|0;i=2935}c[d>>2]=i;c[f>>2]=h;if((h|0)>16){l=h-16|0;m=i<<16}else{g=je(i<<h|0)|0;i=b+124|0;e=c[i>>2]|0;y=g;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=h+16|0;m=0}c[d>>2]=m;c[f>>2]=l;h=c[b+2524>>2]|0;if((l|0)>2){n=l-2|0;o=m<<2|h}else{i=je(m<<l|h>>>((2-l|0)>>>0)|0)|0;m=b+124|0;e=c[m>>2]|0;y=i;a[e]=y;y=y>>8;a[e+1|0]=y;y=y>>8;a[e+2|0]=y;y=y>>8;a[e+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;n=l+30|0;o=h}c[d>>2]=o;c[f>>2]=n;h=(((c[b+2340>>2]|0)-(c[b+2336>>2]|0)|0)/2|0)+(c[b+2344>>2]|0)|0;if((n|0)>6){p=n-6|0;q=o<<6|h}else{l=je(h>>>((6-n|0)>>>0)|o<<n|0)|0;o=b+124|0;m=c[o>>2]|0;y=l;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[o>>2]=(c[o>>2]|0)+4;p=n+26|0;q=h}c[d>>2]=q;c[f>>2]=p;h=b+2312|0;n=c[h>>2]|0;if((p|0)>5){r=p-5|0;s=q<<5|n}else{o=je(q<<p|n>>>((5-p|0)>>>0)|0)|0;q=b+124|0;m=c[q>>2]|0;y=o;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;r=p+27|0;s=n}c[d>>2]=s;c[f>>2]=r;n=c[b+2316>>2]|0;if((r|0)>3){t=r-3|0;u=s<<3|n}else{p=je(s<<r|n>>>((3-r|0)>>>0)|0)|0;s=b+124|0;q=c[s>>2]|0;y=p;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;t=r+29|0;u=n}c[d>>2]=u;c[f>>2]=t;n=b+2392|0;r=c[n>>2]|0;if((t|0)>3){v=t-3|0;w=u<<3|r;x=r}else{s=je(u<<t|r>>>((3-t|0)>>>0)|0)|0;u=b+124|0;q=c[u>>2]|0;y=s;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;v=t+29|0;w=r;x=c[n>>2]|0}c[d>>2]=w;c[f>>2]=v;if((x&1|0)==0|(x|0)==1){z=x;A=w;B=v}else{r=c[b+2400>>2]|0;if((v|0)>2){C=v-2|0;D=w<<2|r;E=x}else{x=je(w<<v|r>>>((2-v|0)>>>0)|0)|0;w=b+124|0;t=c[w>>2]|0;y=x;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;C=v+30|0;D=r;E=c[n>>2]|0}c[d>>2]=D;c[f>>2]=C;z=E;A=D;B=C}if((z&4|0)==0){F=z;G=A;H=B}else{C=c[b+2404>>2]|0;if((B|0)>2){I=B-2|0;J=A<<2|C;K=z}else{z=je(C>>>((2-B|0)>>>0)|A<<B|0)|0;A=b+124|0;D=c[A>>2]|0;y=z;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;I=B+30|0;J=C;K=c[n>>2]|0}c[d>>2]=J;c[f>>2]=I;F=K;G=J;H=I}if((F|0)==2){F=c[b+20>>2]|0;if((H|0)>2){L=H-2|0;M=G<<2|F}else{I=je(F>>>((2-H|0)>>>0)|G<<H|0)|0;J=b+124|0;K=c[J>>2]|0;y=I;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[J>>2]=(c[J>>2]|0)+4;L=H+30|0;M=F}c[d>>2]=M;c[f>>2]=L;N=L;O=M}else{N=H;O=G}G=c[b+2376>>2]|0;if((N|0)>1){P=N-1|0;Q=O<<1|G}else{H=je(O<<N|G>>>((1-N|0)>>>0)|0)|0;O=b+124|0;M=c[O>>2]|0;y=H;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[O>>2]=(c[O>>2]|0)+4;P=N+31|0;Q=G}c[d>>2]=Q;c[f>>2]=P;G=-(c[b+4>>2]|0)|0;if((P|0)>5){R=P-5|0;S=Q<<5|G}else{N=je(Q<<P|G>>>((5-P|0)>>>0)|0)|0;Q=b+124|0;O=c[Q>>2]|0;y=N;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[Q>>2]=(c[Q>>2]|0)+4;R=P+27|0;S=G}c[d>>2]=S;c[f>>2]=R;if((R|0)>1){T=R-1|0;U=S<<1}else{G=je(S<<R|0)|0;S=b+124|0;P=c[S>>2]|0;y=G;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[S>>2]=(c[S>>2]|0)+4;T=R+31|0;U=0}c[d>>2]=U;c[f>>2]=T;if((T|0)>1){V=T-1|0;W=U<<1}else{R=je(U<<T|0)|0;U=b+124|0;S=c[U>>2]|0;y=R;a[S]=y;y=y>>8;a[S+1|0]=y;y=y>>8;a[S+2|0]=y;y=y>>8;a[S+3|0]=y;c[U>>2]=(c[U>>2]|0)+4;V=T+31|0;W=0}c[d>>2]=W;c[f>>2]=V;T=b+24|0;U=c[T>>2]|0;if((V|0)>1){X=V-1|0;Y=W<<1|U;Z=U}else{S=je(W<<V|U>>>((1-V|0)>>>0)|0)|0;W=b+124|0;R=c[W>>2]|0;y=S;a[R]=y;y=y>>8;a[R+1|0]=y;y=y>>8;a[R+2|0]=y;y=y>>8;a[R+3|0]=y;c[W>>2]=(c[W>>2]|0)+4;X=V+31|0;Y=U;Z=c[T>>2]|0}c[d>>2]=Y;c[f>>2]=X;if((Z|0)==0){_=X;$=Y}else{Z=(c[b+28>>2]|0)-80|0;if((X|0)>5){aa=X-5|0;ba=Y<<5|Z}else{T=je(Z>>>((5-X|0)>>>0)|Y<<X|0)|0;Y=b+124|0;U=c[Y>>2]|0;y=T;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;c[Y>>2]=(c[Y>>2]|0)+4;aa=X+27|0;ba=Z}c[d>>2]=ba;c[f>>2]=aa;Z=c[b+32>>2]|0;if((aa|0)>2){ca=aa-2|0;da=ba<<2|Z}else{X=je(ba<<aa|Z>>>((2-aa|0)>>>0)|0)|0;ba=b+124|0;Y=c[ba>>2]|0;y=X;a[Y]=y;y=y>>8;a[Y+1|0]=y;y=y>>8;a[Y+2|0]=y;y=y>>8;a[Y+3|0]=y;c[ba>>2]=(c[ba>>2]|0)+4;ca=aa+30|0;da=Z}c[d>>2]=da;c[f>>2]=ca;_=ca;$=da}da=c[b+36>>2]|0;if((_|0)>1){ea=_-1|0;fa=$<<1|da}else{ca=je($<<_|da>>>((1-_|0)>>>0)|0)|0;$=b+124|0;Z=c[$>>2]|0;y=ca;a[Z]=y;y=y>>8;a[Z+1|0]=y;y=y>>8;a[Z+2|0]=y;y=y>>8;a[Z+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;ea=_+31|0;fa=da}c[d>>2]=fa;c[f>>2]=ea;da=c[b+40>>2]|0;if((ea|0)>1){ga=ea-1|0;ha=fa<<1|da}else{_=je(fa<<ea|da>>>((1-ea|0)>>>0)|0)|0;fa=b+124|0;$=c[fa>>2]|0;y=_;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;c[fa>>2]=(c[fa>>2]|0)+4;ga=ea+31|0;ha=da}c[d>>2]=ha;c[f>>2]=ga;do{if((c[h>>2]|0)==6){da=b+44|0;ea=c[da>>2]|0;if((ga|0)>1){ia=ga-1|0;ja=ha<<1|ea;ka=ea}else{fa=je(ha<<ga|ea>>>((1-ga|0)>>>0)|0)|0;$=b+124|0;_=c[$>>2]|0;y=fa;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;ia=ga+31|0;ja=ea;ka=c[da>>2]|0}c[d>>2]=ja;c[f>>2]=ia;if((ka|0)==0){la=ia;ma=ja}else{da=c[b+48>>2]|0;if((ia|0)>2){na=ia-2|0;oa=ja<<2|da}else{ea=je(ja<<ia|da>>>((2-ia|0)>>>0)|0)|0;$=b+124|0;_=c[$>>2]|0;y=ea;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;na=ia+30|0;oa=da}c[d>>2]=oa;c[f>>2]=na;da=c[b+2408>>2]|0;if((na|0)>3){pa=na-3|0;qa=oa<<3|da}else{$=je(oa<<na|da>>>((3-na|0)>>>0)|0)|0;_=b+124|0;ea=c[_>>2]|0;y=$;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;c[_>>2]=(c[_>>2]|0)+4;pa=na+29|0;qa=da}c[d>>2]=qa;c[f>>2]=pa;da=c[b+2412>>2]|0;if((pa|0)>3){ra=pa-3|0;sa=qa<<3|da}else{_=je(qa<<pa|da>>>((3-pa|0)>>>0)|0)|0;ea=b+124|0;$=c[ea>>2]|0;y=_;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;c[ea>>2]=(c[ea>>2]|0)+4;ra=pa+29|0;sa=da}c[d>>2]=sa;c[f>>2]=ra;da=c[b+2416>>2]|0;if((ra|0)>3){ta=ra-3|0;ua=sa<<3|da}else{ea=je(sa<<ra|da>>>((3-ra|0)>>>0)|0)|0;$=b+124|0;_=c[$>>2]|0;y=ea;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;ta=ra+29|0;ua=da}c[d>>2]=ua;c[f>>2]=ta;da=c[b+2420>>2]|0;if((ta|0)>3){va=ta-3|0;wa=ua<<3|da}else{$=je(ua<<ta|da>>>((3-ta|0)>>>0)|0)|0;_=b+124|0;ea=c[_>>2]|0;y=$;a[ea]=y;y=y>>8;a[ea+1|0]=y;y=y>>8;a[ea+2|0]=y;y=y>>8;a[ea+3|0]=y;c[_>>2]=(c[_>>2]|0)+4;va=ta+29|0;wa=da}c[d>>2]=wa;c[f>>2]=va;la=va;ma=wa}da=b+68|0;_=c[da>>2]|0;if((la|0)>1){xa=la-1|0;ya=ma<<1|_;za=_}else{ea=je(ma<<la|_>>>((1-la|0)>>>0)|0)|0;$=b+124|0;fa=c[$>>2]|0;y=ea;a[fa]=y;y=y>>8;a[fa+1|0]=y;y=y>>8;a[fa+2|0]=y;y=y>>8;a[fa+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;xa=la+31|0;ya=_;za=c[da>>2]|0}c[d>>2]=ya;c[f>>2]=xa;if((za|0)==0){Aa=xa;Ba=ya;break}da=c[b+72>>2]|0;if((xa|0)>2){Ca=xa-2|0;Da=ya<<2|da}else{_=je(ya<<xa|da>>>((2-xa|0)>>>0)|0)|0;$=b+124|0;fa=c[$>>2]|0;y=_;a[fa]=y;y=y>>8;a[fa+1|0]=y;y=y>>8;a[fa+2|0]=y;y=y>>8;a[fa+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;Ca=xa+30|0;Da=da}c[d>>2]=Da;c[f>>2]=Ca;da=c[b+76>>2]|0;if((Ca|0)>2){Ea=Ca-2|0;Fa=Da<<2|da}else{$=je(Da<<Ca|da>>>((2-Ca|0)>>>0)|0)|0;fa=b+124|0;_=c[fa>>2]|0;y=$;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;c[fa>>2]=(c[fa>>2]|0)+4;Ea=Ca+30|0;Fa=da}c[d>>2]=Fa;c[f>>2]=Ea;da=c[b+80>>2]|0;if((Ea|0)>1){Ga=Ea-1|0;Ha=Fa<<1|da}else{fa=je(Fa<<Ea|da>>>((1-Ea|0)>>>0)|0)|0;_=b+124|0;$=c[_>>2]|0;y=fa;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;c[_>>2]=(c[_>>2]|0)+4;Ga=Ea+31|0;Ha=da}c[d>>2]=Ha;c[f>>2]=Ga;if((Ga|0)>9){Ia=Ga-9|0;Ja=Ha<<9}else{da=je(Ha<<Ga|0)|0;_=b+124|0;$=c[_>>2]|0;y=da;a[$]=y;y=y>>8;a[$+1|0]=y;y=y>>8;a[$+2|0]=y;y=y>>8;a[$+3|0]=y;c[_>>2]=(c[_>>2]|0)+4;Ia=Ga+23|0;Ja=0}c[d>>2]=Ja;c[f>>2]=Ia;Aa=Ia;Ba=Ja}else{if((ga|0)>1){Ka=ga-1|0;La=ha<<1}else{_=je(ha<<ga|0)|0;$=b+124|0;da=c[$>>2]|0;y=_;a[da]=y;y=y>>8;a[da+1|0]=y;y=y>>8;a[da+2|0]=y;y=y>>8;a[da+3|0]=y;c[$>>2]=(c[$>>2]|0)+4;Ka=ga+31|0;La=0}c[d>>2]=La;c[f>>2]=Ka;if((Ka|0)>1){Ma=Ka-1|0;Na=La<<1}else{$=je(La<<Ka|0)|0;da=b+124|0;_=c[da>>2]|0;y=$;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;c[da>>2]=(c[da>>2]|0)+4;Ma=Ka+31|0;Na=0}c[d>>2]=Na;c[f>>2]=Ma;Aa=Ma;Ba=Na}}while(0);if((Aa|0)>1){Oa=Aa-1|0;Pa=Ba<<1;c[d>>2]=Pa;c[f>>2]=Oa;return}else{Na=je(Ba<<Aa|0)|0;Ba=b+124|0;b=c[Ba>>2]|0;y=Na;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[Ba>>2]=(c[Ba>>2]|0)+4;Oa=Aa+31|0;Pa=0;c[d>>2]=Pa;c[f>>2]=Oa;return}}function _kb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;i=i+192|0;h=g|0;j=(f<<2)-960|0;f=c[e+2640>>2]|0;if((c[e+2788>>2]|0)==(f|0)){if((c[e+2956>>2]|0)==0){k=3}}else{k=3}if((k|0)==3){k=e+2372|0;l=c[k>>2]|0;if((l|0)>=0){m=e+2332|0;n=0;o=f;f=c[m>>2]|0;p=l;while(1){if((f|0)>0){l=0;do{c[e+2788+(n*24|0)+(l<<2)>>2]=o+(d[e+2744+(n*6|0)+l|0]<<8);l=l+1|0;q=c[m>>2]|0;}while((l|0)<(q|0));r=q;s=c[k>>2]|0}else{r=f;s=p}l=n+1|0;if((l|0)>(s|0)){break}else{n=l;o=o+(r<<8)|0;f=r;p=s}}}c[e+2956>>2]=1}s=e+2332|0;p=c[s>>2]|0;r=e+2372|0;if((p|0)>0){f=e+1436|0;o=e+2548|0;n=0;k=c[r>>2]|0;q=p;while(1){m=(c[e+1536+(n<<7)+60>>2]|0)==0|0;if((m|0)>(k|0)){t=k;u=q}else{l=e+1536+(n<<7)+24|0;v=e+1536+(n<<7)+16|0;w=m;m=k;while(1){if((a[e+2688+(w*6|0)+n|0]|0)==0){x=m}else{Ge[c[f>>2]&255](c[(c[l>>2]|0)+(w<<2)>>2]|0,c[(c[v>>2]|0)+(w<<2)>>2]|0,c[e+2432+(w<<2)>>2]|0,c[e+1536+(n<<7)+100+(w<<2)>>2]|0,j,c[o>>2]|0,1445064,c[e+2788+(w*24|0)+(n<<2)>>2]|0);x=c[r>>2]|0}y=w+1|0;if((y|0)>(x|0)){break}else{w=y;m=x}}t=x;u=c[s>>2]|0}m=n+1|0;if((m|0)<(u|0)){n=m;k=t;q=u}else{z=u;A=t;break}}}else{z=p;A=c[r>>2]|0}r=h|0;mrc(h|0,0,32)|0;b[h+4>>1]=2;b[h+2>>1]=2;b[h+8>>1]=1;mrc(h+32|0,0,32)|0;b[h+36>>1]=2;b[h+34>>1]=2;b[h+40>>1]=1;mrc(h+64|0,0,32)|0;b[h+68>>1]=2;b[h+66>>1]=2;b[h+72>>1]=1;mrc(h+96|0,0,32)|0;b[h+100>>1]=2;b[h+98>>1]=2;b[h+104>>1]=1;mrc(h+128|0,0,32)|0;b[h+132>>1]=2;b[h+130>>1]=2;b[h+136>>1]=1;mrc(h+160|0,0,32)|0;b[h+164>>1]=2;b[h+162>>1]=2;b[h+168>>1]=1;p=((c[e+2428>>2]|0)*3|0)+73|0;t=(c[e+2468>>2]|0)==0|0;u=e+2372|0;if((t|0)>(A|0)){B=e+1444|0;C=c[B>>2]|0;D=ve[C&4095](r)|0;i=g;return D|0}A=e+1440|0;q=t;t=z;while(1){z=c[e+2432+(q<<2)>>2]|0;a:do{if((t|0)>0){if((q|0)==0){E=0;F=t}else{k=0;while(1){n=c[e+1536+(k<<7)+100+(q<<2)>>2]|0;ef[c[A>>2]&4095](h+(k<<5)|0,(c[e+2788+(q*24|0)+(k<<2)>>2]|0)+z|0,((n|0)<(p|0)?n:p)-z|0);n=c[s>>2]|0;x=k+1|0;if((x|0)<(n|0)){k=x}else{G=n;break a}}}while(1){if((c[e+1536+(E<<7)+60>>2]|0)==0){H=F}else{k=c[e+1536+(E<<7)+100>>2]|0;ef[c[A>>2]&4095](h+(E<<5)|0,(c[e+2788+(E<<2)>>2]|0)+z|0,((k|0)<(p|0)?k:p)-z|0);H=c[s>>2]|0}k=E+1|0;if((k|0)<(H|0)){E=k;F=H}else{G=H;break}}}else{G=t}}while(0);z=q+1|0;if((z|0)>(c[u>>2]|0)){break}else{q=z;t=G}}B=e+1444|0;C=c[B>>2]|0;D=ve[C&4095](r)|0;i=g;return D|0}function $kb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=hJb(1024)|0;c[a+2632>>2]=d;if((d|0)==0){KIb(c[a+108>>2]|0,16,2433376,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}d=a+2372|0;g=hJb(c[d>>2]<<2)|0;h=a+2636|0;c[h>>2]=g;do{if((g|0)==0){if((c[d>>2]&1073741823|0)==0){j=0;break}KIb(c[a+108>>2]|0,16,2433376,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}else{j=0}}while(0);while(1){if((j|0)>=(c[d>>2]|0)){f=0;k=10;break}g=pJb(3584)|0;c[(c[h>>2]|0)+(j<<2)>>2]=g;if((c[(c[h>>2]|0)+(j<<2)>>2]|0)==0){break}j=j+1|0}if((k|0)==10){i=b;return f|0}KIb(c[a+108>>2]|0,16,2433376,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}function alb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;h=i;i=i+8104|0;j=h|0;k=h+32|0;l=h+2720|0;m=h+8096|0;n=c[b+60>>2]|0;o=n;do{if((c[n+92>>2]|0)!=0){p=Wkb(o)|0;if((p|0)==0){break}else{q=p}i=h;return q|0}}while(0);if((c[n+2524>>2]|0)==1){r=5}else{if((c[n+2308>>2]|0)!=0){r=5}}if((r|0)==5){Okb(o)}r=c[f+64>>2]|0;p=n+2372|0;s=c[p>>2]|0;do{if((s|0)>0){t=n+2636|0;u=n+2332|0;v=n+2396|0;w=0;do{x=c[(c[t>>2]|0)+(w<<2)>>2]|0;nrc(x|0,x+(c[u>>2]<<8<<1)|0,512)|0;nrc((c[(c[t>>2]|0)+(w<<2)>>2]|0)+512|0,c[r+(d[(c[v>>2]|0)+w|0]<<2)>>2]|0,c[u>>2]<<9)|0;w=w+1|0;y=c[p>>2]|0;}while((w|0)<(y|0));if((y|0)<=0){z=y;break}w=n+1464|0;v=n+2632|0;x=n+1532|0;A=n+2304|0;B=n+1468|0;C=n+1520|0;D=n+1420|0;E=n+1424|0;F=0;H=c[u>>2]|0;I=y;while(1){J=F+1|0;if((H|0)>0){K=0;do{mf[c[w>>2]&2047](c[v>>2]|0,(c[(c[t>>2]|0)+(F<<2)>>2]|0)+(K<<8<<1)|0,c[x>>2]|0,512);if((c[A>>2]|0)!=0){L=We[c[D>>2]&2047](c[v>>2]|0,512)|0;M=L>>>0>65535>>>0;N=M?L>>>16:L;L=M?16:0;if((N&65280|0)==0){O=L;P=N}else{O=L|8;P=N>>>8}N=14-O-(d[1359664+P|0]|0)|0;if((N|0)>0){ef[c[E>>2]&4095](c[v>>2]|0,512,N)}a[o+1536+(K<<7)+40+J|0]=N+6}ef[c[C>>2]&4095](B,c[(c[o+1536+(K<<7)>>2]|0)+(J<<2)>>2]|0,c[v>>2]|0);K=K+1|0;Q=c[u>>2]|0;}while((K|0)<(Q|0));R=Q;S=c[p>>2]|0}else{R=H;S=I}if((J|0)<(S|0)){F=J;H=R;I=S}else{z=S;break}}}else{z=s}}while(0);s=n+2304|0;S=n+2332|0;R=c[S>>2]|0;if((c[s>>2]|0)!=0&(R|0)>0){Q=n+1428|0;P=0;O=z;y=R;r=z;while(1){if((O|0)<1){T=O;U=y;V=r}else{I=o+1536+(P<<7)|0;H=1;do{ef[c[Q>>2]&4095](c[(c[I>>2]|0)+(H<<2)>>2]|0,256,d[o+1536+(P<<7)+40+H|0]|0);H=H+1|0;W=c[p>>2]|0;}while((H|0)<=(W|0));T=W;U=c[S>>2]|0;V=W}H=P+1|0;if((H|0)<(U|0)){P=H;O=T;y=U;r=V}else{X=V;Y=U;break}}}else{X=z;Y=R}R=c[(c[n+1536>>2]|0)+4>>2]|0;z=n+2332|0;U=ca(Y<<8,X)|0;X=n+1368|0;pe[c[X>>2]&1023](R,R,-16777215,16777215,U);U=n+2464|0;c[U>>2]=c[n+2468>>2];Pkb(o);do{if((c[U>>2]|0)!=0){mrc(l|0,0,5376)|0;mrc(k|0,0,2688)|0;R=n+2432|0;Y=c[R>>2]|0;V=((c[n+2472>>2]|0)*12|0|1)+31&-32;r=Y-1+V|0;y=((r|0)<256?r:256)-V|0;r=c[z>>2]|0;if((r|0)>0){T=V<<2;O=n+2368|0;P=(V|0)<1;W=0;S=r;while(1){Q=o+1536+(W<<7)|0;H=c[c[Q>>2]>>2]|0;I=H+(y<<2)|0;if((c[o+1536+(W<<7)+60>>2]|0)==0){Z=S}else{mrc(I|0,0,T|0)|0;F=c[O>>2]|0;if((F|0)>=1){u=c[Q>>2]|0;Q=1;v=F;while(1){F=c[u+(Q<<2)>>2]|0;if((a[o+1536+(W<<7)+64+Q|0]|0)==0|P){_=v}else{B=0;do{C=B+y|0;E=H+(C<<2)|0;c[E>>2]=(c[E>>2]|0)+(c[F+(C<<2)>>2]|0);B=B+1|0;}while((B|0)<(V|0));_=c[O>>2]|0}B=Q+1|0;if((B|0)>(_|0)){break}else{Q=B;v=_}}}pe[c[X>>2]&1023](I,I,-16777215,16777215,V);Z=c[z>>2]|0}v=W+1|0;if((v|0)<(Z|0)){W=v;S=Z}else{break}}$=c[R>>2]|0;aa=Z}else{$=Y;aa=r}S=c[n+2460>>2]|0;if(($|0)<(S|0)){W=c[n+2368>>2]|0;V=(W|0)<0;O=(aa|0)>0;y=$;P=0;while(1){T=a[o+2480+P|0]|0;v=T&255;if(!V){Q=T<<24>>24!=0;T=0;do{a:do{if(O){if((T|0)<=0){if(Q){ba=0}else{break}while(1){if((c[o+1536+(ba<<7)+60>>2]|0)!=0){H=c[(c[o+1536+(ba<<7)>>2]|0)+(T<<2)>>2]|0;u=l+(ba*896|0)+(T<<7)+(P<<3)|0;J=0;B=c[u+4>>2]|0;F=c[u>>2]|0;do{C=c[H+(J+y<<2)>>2]|0;E=C;D=(C|0)<0|0?-1:0;C=Erc(E,D,E,D)|0;F=wrc(C,G,F,B)|0;B=G;J=J+1|0;}while((J|0)<(v|0));c[u>>2]=F;c[u+4>>2]=B}ba=ba+1|0;if((ba|0)>=(aa|0)){break a}}}if(Q){da=0}else{break}do{do{if((c[o+1536+(da<<7)+60>>2]|0)!=0){if((a[o+1536+(da<<7)+64+T|0]|0)==0){break}J=c[(c[o+1536+(da<<7)>>2]|0)+(T<<2)>>2]|0;H=l+(da*896|0)+(T<<7)+(P<<3)|0;C=0;D=c[H+4>>2]|0;E=c[H>>2]|0;do{A=c[J+(C+y<<2)>>2]|0;x=A;t=(A|0)<0|0?-1:0;A=Erc(x,t,x,t)|0;E=wrc(A,G,E,D)|0;D=G;C=C+1|0;}while((C|0)<(v|0));c[H>>2]=E;c[H+4>>2]=D}}while(0);da=da+1|0;}while((da|0)<(aa|0))}}while(0);T=T+1|0;}while((T|0)<=(W|0))}T=v+y|0;if((T|0)<(S|0)){y=T;P=P+1|0}else{break}}}if((aa|0)>0){P=n+2368|0;y=n+2476|0;S=0;while(1){do{if((c[o+1536+(S<<7)+60>>2]|0)!=0){W=c[P>>2]|0;if((W|0)<1){break}else{ea=1}do{do{if((a[o+1536+(S<<7)+64+ea|0]|0)!=0){O=c[y>>2]|0;if((O|0)>0){fa=0}else{break}do{V=l+(S*896|0)+(ea<<7)+(fa<<3)|0;r=l+(S*896|0)+(fa<<3)|0;c[k+(S*448|0)+(ea<<6)+(fa<<2)>>2]=elb(c[V>>2]|0,c[V+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0)|0;fa=fa+1|0;}while((fa|0)<(O|0))}}while(0);ea=ea+1|0;}while((ea|0)<=(W|0))}}while(0);v=S+1|0;if((v|0)<(aa|0)){S=v}else{ga=0;break}}while(1){S=(ga|0)==0;if(S){ha=0}else{ha=o+1536+(ga-1<<7)|0}mrc(o+1536+(ga<<7)+76|0,0,7)|0;b:do{if((c[o+1536+(ga<<7)+60>>2]|0)!=0){do{if(!S){if((c[ha+60>>2]|0)==0){break}if((c[P>>2]|0)<1){break b}v=ga-1|0;W=1;while(1){do{if((a[o+1536+(ga<<7)+64+W|0]|0)!=0){if((a[ha+64+W|0]|0)==0){a[o+1536+(ga<<7)+76+W|0]=1;break}O=c[y>>2]|0;if((O|0)>0){r=0;V=0;Y=0;while(1){R=(c[k+(v*448|0)+(W<<6)+(Y<<2)>>2]|0)-(c[k+(ga*448|0)+(W<<6)+(Y<<2)>>2]|0)|0;T=(R|0)>-1?R:-R|0;R=wrc(T,(T|0)<0|0?-1:0,V,r)|0;T=G;Q=Y+1|0;if((Q|0)<(O|0)){r=T;V=R;Y=Q}else{ia=T;ja=R;break}}}else{ia=0;ja=0}Y=Crc(ja,ia,O,(O|0)<0|0?-1:0)|0;V=G;r=0;if(!((V|0)>(r|0)|(V|0)==(r|0)&Y>>>0>503317>>>0)){break}a[o+1536+(ga<<7)+76+W|0]=1}}while(0);W=W+1|0;if((W|0)>(c[P>>2]|0)){break b}}}}while(0);if((c[P>>2]|0)<1){break}else{ka=1}do{a[o+1536+(ga<<7)+76+ka|0]=1;ka=ka+1|0;}while((ka|0)<=(c[P>>2]|0))}}while(0);S=ga+1|0;W=c[z>>2]|0;if((S|0)<(W|0)){ga=S}else{la=W;ma=y;break}}}else{la=aa;ma=n+2476|0}y=c[ma>>2]|0;if((y|0)>0){P=n+2368|0;W=0;S=0;while(1){v=0;Y=W;c:while(1){r=v;while(1){if((r|0)>=(la|0)){break c}if((c[o+1536+(r<<7)+60>>2]|0)==0){r=r+1|0;continue}na=c[P>>2]|0;if((na|0)<1){r=Y}else{break}}V=l+(r*896|0)+(S<<3)|0;D=Y;H=1;while(1){if((a[o+1536+(r<<7)+64+H|0]|0)==0){oa=D}else{E=l+(r*896|0)+(H<<7)+(S<<3)|0;R=c[V+4>>2]|0;T=c[V>>2]|0;Q=c[E+4>>2]|0;I=c[E>>2]|0;E=r;d:while(1){pa=E;do{pa=pa+1|0;if(!((a[o+1536+(pa<<7)+76+H|0]|0)==0&(pa|0)<(la|0))){break d}}while((c[o+1536+(pa<<7)+60>>2]|0)==0);B=l+(pa*896|0)+(S<<3)|0;u=wrc(c[B>>2]|0,c[B+4>>2]|0,T,R)|0;B=G;F=l+(pa*896|0)+(H<<7)+(S<<3)|0;C=wrc(c[F>>2]|0,c[F+4>>2]|0,I,Q)|0;R=B;T=u;Q=G;I=C;E=pa}c[k+(r*448|0)+(H<<6)+(S<<2)>>2]=elb(I,Q,T,R)|0;oa=pa}E=H+1|0;if((E|0)>(na|0)){v=oa;Y=oa;continue c}else{D=oa;H=E}}}v=S+1|0;if((v|0)<(y|0)){W=Y;S=v}else{break}}}if((la|0)>0){S=n+1448|0;W=n+2368|0;y=0;P=la;while(1){if((c[o+1536+(y<<7)+60>>2]|0)==0){qa=P}else{v=o+1536+(y<<7)+32|0;ef[c[S>>2]&4095](c[(c[v>>2]|0)+4>>2]|0,k+(y*448|0)+64|0,c[W>>2]<<4);H=c[W>>2]|0;if((H|0)>=1){D=o+1536+(y<<7)+36|0;r=1;V=H;while(1){if((a[o+1536+(y<<7)+76+r|0]|0)==0){ra=V}else{H=c[(c[v>>2]|0)+(r<<2)>>2]|0;E=a[H]|0;C=E&255;u=c[ma>>2]|0;if((u|0)>1){B=1;F=C;J=C;while(1){A=d[H+B|0]|0;t=(A|0)>(F|0)?F:A;x=(A|0)>(J|0)?A:J;A=B+1|0;if((A|0)<(u|0)){B=A;F=t;J=x}else{sa=t;ta=x;break}}}else{sa=C;ta=C}J=(ta-13|0)/3|0;F=(J|0)>0?J:0;while(1){ua=F*3|0;if((sa|0)<(ua|0)){F=F-1|0}else{break}}e:do{if((u|0)>0){C=0;J=H;B=E;while(1){x=(B&255)-ua|0;if((x|0)<0){va=0}else{va=(x|0)>15?15:x&255}a[J+C|0]=va;x=C+1|0;if((x|0)>=(c[ma>>2]|0)){break e}t=c[(c[v>>2]|0)+(r<<2)>>2]|0;C=x;J=t;B=a[t+x|0]|0}}}while(0);a[o+1536+(y<<7)+83+r|0]=F;if((c[ma>>2]|0)>0){E=ua+5|0;H=0;do{u=a[(c[(c[v>>2]|0)+(r<<2)>>2]|0)+H|0]|0;B=c[k+(y*448|0)+(r<<6)+(H<<2)>>2]<<E+(u&255)>>24;a[(c[(c[D>>2]|0)+(r<<2)>>2]|0)+H|0]=u<<24>>24==15?B>>>1:B+240|0;H=H+1|0;}while((H|0)<(c[ma>>2]|0))}ra=c[W>>2]|0}H=r+1|0;if((H|0)>(ra|0)){break}else{r=H;V=ra}}}qa=c[z>>2]|0}V=y+1|0;if((V|0)<(qa|0)){y=V;P=qa}else{break}}}if((c[n+2308>>2]|0)==0){break}Cca(o)}}while(0);do{if((c[n+2392>>2]|0)==2){qa=c[z>>2]|0;if((qa|0)<=0){break}ra=n+2500|0;ma=j|0;k=n+1452|0;ua=j+16|0;va=j+24|0;sa=j+8|0;ta=n+2432|0;la=a[1443288]|0;oa=0;na=0;pa=qa;while(1){qa=o+1536+(na<<7)|0;l=(na|0)!=0;aa=o+1536+(na<<7)+47|0;a[aa]=l&1^1;ga=o+1536+(na<<7)+48|0;c[ga>>2]=4;do{if((c[o+1536+(na<<7)+60>>2]|0)==0){wa=4}else{ka=c[ta>>2]|0;ia=4-((ka|0)<62)-((ka|0)==37)|0;c[ga>>2]=ia;if(!l){wa=ia;break}if((ia|0)==(c[oa+48>>2]|0)){wa=ia;break}a[aa]=1;wa=ia}}while(0);ia=c[o+1536+(na<<7)+104>>2]|0;ka=c[o+1536+(na<<7)+108>>2]|0;ja=(ia|0)>(ka|0)?ka:ia;if((c[ra>>2]|0)!=0&(wa|0)>0){ia=qa|0;ka=0;ha=la;while(1){ea=ha&255;fa=ka+1|0;da=a[1443288+fa|0]|0;ba=da&255;$=c[ia>>2]|0;mf[c[k>>2]&2047](ma,(c[$+4>>2]|0)+(ea<<2)|0,(c[$+8>>2]|0)+(ea<<2)|0,((ja|0)>(ba|0)?ba:ja)-ea|0);ea=c[ua>>2]|0;ba=c[ua+4>>2]|0;$=c[va>>2]|0;Z=c[va+4>>2]|0;X=(ba|0)>(Z|0)|(ba|0)==(Z|0)&ea>>>0>$>>>0;_=X?Z:ba;ba=c[ma>>2]|0;Z=c[ma+4>>2]|0;U=c[sa>>2]|0;P=c[sa+4>>2]|0;y=(Z|0)>(P|0)|(Z|0)==(P|0)&ba>>>0>U>>>0;W=y?P:Z;Z=((_|0)<(W|0)|(_|0)==(W|0)&(X?$:ea)>>>0<(y?U:ba)>>>0)&1;a[o+1536+(na<<7)+52+ka|0]=Z;do{if(l){if(Z<<24>>24==(a[oa+52+ka|0]|0)){break}a[aa]=1}}while(0);if((fa|0)<(c[ga>>2]|0)){ka=fa;ha=da}else{break}}xa=c[z>>2]|0}else{xa=pa}ha=na+1|0;if((ha|0)<(xa|0)){oa=qa;na=ha;pa=xa}else{break}}}}while(0);do{if((c[s>>2]|0)==0){xa=c[z>>2]|0;if((xa|0)<=0){break}wa=n+1428|0;j=0;pa=c[p>>2]|0;na=xa;while(1){if((pa|0)<1){ya=pa;za=na}else{xa=o+1536+(j<<7)|0;oa=1;do{ef[c[wa>>2]&4095](c[(c[xa>>2]|0)+(oa<<2)>>2]|0,256,d[o+1536+(j<<7)+40+oa|0]|0);oa=oa+1|0;Aa=c[p>>2]|0;}while((oa|0)<=(Aa|0));ya=Aa;za=c[z>>2]|0}oa=j+1|0;if((oa|0)<(za|0)){j=oa;pa=ya;na=za}else{break}}}}while(0);Qkb(o);Skb(o);za=Tkb(o)|0;if((za|0)!=0){KIb(b,16,2583144,(ya=i,i=i+1|0,i=i+7&-8,c[ya>>2]=0,ya)|0);i=ya;q=za;i=h;return q|0}Rkb(o);Ukb(o);za=c[n+2340>>2]|0;n=d5a(b,e,za,(za|0)<0|0?-1:0)|0;if((n|0)<0){q=n;i=h;return q|0}Vkb(o,c[e+24>>2]|0);o=f+136|0;f=c[o>>2]|0;n=c[o+4>>2]|0;if(!((f|0)==0&(n|0)==(-2147483648|0))){o=c[b+116>>2]|0;c[m>>2]=1;c[m+4>>2]=c[b+412>>2];za=XIb(o,(o|0)<0|0?-1:0,m,b+104|0)|0;b=xrc(f,n,za,G)|0;za=e+8|0;c[za>>2]=b;c[za+4>>2]=G}c[g>>2]=1;q=0;i=h;return q|0}function blb(a){a=a|0;Oqb(a+1468|0);return}function clb(a){a=a|0;var b=0;b=Nqb(a+1468|0,9,0,-1.0)|0;c[a+1532>>2]=1442648;return b|0}function dlb(a){a=a|0;c[(c[a+60>>2]|0)+2304>>2]=1;return Ykb(a)|0}function elb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=0;if((f|0)<(g|0)|(f|0)==(g|0)&e>>>0<16777216>>>0){h=1048576;return h|0}g=Crc(a,b,e>>>24|f<<8,f>>24|((f|0)<0|0?-1:0)<<8)|0;f=G;e=0;b=f>>>0>e>>>0|f>>>0==e>>>0&g>>>0>1073741824>>>0?1073741824:g;if(b>>>0<255>>>0){i=(d[b+1303321|0]|0)-1>>4}else{do{if(b>>>0<4096>>>0){j=(d[1303320+(b>>>4)|0]|0)>>>2}else{if(b>>>0<16384>>>0){j=(d[1303320+(b>>>6)|0]|0)>>>1;break}if(b>>>0<65536>>>0){j=d[1303320+(b>>>8)|0]|0;break}else{g=b>>>16;e=(g&65280|0)==0;f=((d[1359664+(e?g:b>>>24)|0]|0)+(e?0:8)|0)>>>1;e=b>>>((f+2|0)>>>0);g=d[1303320+(e>>>((f+8|0)>>>0))|0]|0;Erc(e,0,c[1367848+(g<<2)>>2]|0,0)|0;j=G+(g<<f)|0;break}}}while(0);i=j-((ca(j,j)|0)>>>0>b>>>0)|0}b=i<<9;h=b>>>0>16777215>>>0?16777215:b;return h|0}function flb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=hJb(2048)|0;c[a+2632>>2]=d;if((d|0)==0){KIb(c[a+108>>2]|0,16,2432704,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}d=a+2372|0;g=hJb(c[d>>2]<<2)|0;h=a+2636|0;c[h>>2]=g;do{if((g|0)==0){if((c[d>>2]&1073741823|0)==0){j=0;break}KIb(c[a+108>>2]|0,16,2432704,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}else{j=0}}while(0);while(1){if((j|0)>=(c[d>>2]|0)){f=0;k=10;break}g=pJb(7168)|0;c[(c[h>>2]|0)+(j<<2)>>2]=g;if((c[(c[h>>2]|0)+(j<<2)>>2]|0)==0){break}j=j+1|0}if((k|0)==10){i=b;return f|0}KIb(c[a+108>>2]|0,16,2432704,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-12;i=b;return f|0}function glb(b,e,f,h){b=b|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0.0,Y=0.0,Z=0,_=0.0,$=0,aa=0,ba=0.0,da=0,ea=0,fa=0.0,ga=0.0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0.0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;j=i;i=i+8088|0;k=j|0;l=j+16|0;m=j+2704|0;n=j+5392|0;o=j+8080|0;p=c[b+60>>2]|0;q=p;do{if((c[p+92>>2]|0)!=0){r=Wkb(q)|0;if((r|0)==0){break}else{s=r}i=j;return s|0}}while(0);if((c[p+2524>>2]|0)==1){t=5}else{if((c[p+2308>>2]|0)!=0){t=5}}if((t|0)==5){Okb(q)}t=c[f+64>>2]|0;r=p+2372|0;u=c[r>>2]|0;do{if((u|0)>0){v=p+2636|0;w=p+2332|0;x=p+2396|0;y=0;do{z=c[(c[v>>2]|0)+(y<<2)>>2]|0;nrc(z|0,z+(c[w>>2]<<8<<2)|0,1024)|0;nrc((c[(c[v>>2]|0)+(y<<2)>>2]|0)+1024|0,c[t+(d[(c[x>>2]|0)+y|0]<<2)>>2]|0,c[w>>2]<<10)|0;y=y+1|0;A=c[r>>2]|0;}while((y|0)<(A|0));if((A|0)<=0){B=A;break}y=p+1380|0;x=p+2632|0;z=p+1532|0;C=p+2304|0;D=p+1468|0;E=p+1520|0;F=0;H=c[w>>2]|0;I=A;while(1){J=F+1|0;if((H|0)>0){K=0;do{mf[c[y>>2]&2047](c[x>>2]|0,(c[(c[v>>2]|0)+(F<<2)>>2]|0)+(K<<8<<2)|0,c[z>>2]|0,512);if((c[C>>2]|0)!=0){a[q+1536+(K<<7)+40+J|0]=0}ef[c[E>>2]&4095](D,c[(c[q+1536+(K<<7)>>2]|0)+(J<<2)>>2]|0,c[x>>2]|0);K=K+1|0;L=c[w>>2]|0;}while((K|0)<(L|0));M=L;N=c[r>>2]|0}else{M=H;N=I}if((J|0)<(N|0)){F=J;H=M;I=N}else{B=N;break}}}else{B=u}}while(0);u=p+2304|0;N=p+2332|0;if((c[u>>2]|0)==0){O=B;P=p+2464|0}else{M=c[N>>2]<<8;L=p+2464|0;A=c[L>>2]|0;t=M&-((A|0)==0|0);I=ca(B+A|0,M)|0;ef[c[p+1432>>2]&4095]((c[p+2652>>2]|0)+(t<<2)|0,(c[p+2648>>2]|0)+(t<<2)|0,I);O=c[r>>2]|0;P=L}L=c[(c[p+1536>>2]|0)+4>>2]|0;I=ca(c[N>>2]<<8,O)|0;O=p+1240|0;kf[c[O>>2]&3](L,L,-.9999999403953552,.9999999403953552,I);c[P>>2]=c[p+2468>>2];Pkb(q);do{if((c[P>>2]|0)!=0){mrc(n|0,0,2688)|0;mrc(l|0,0,2688)|0;mrc(m|0,0,2688)|0;I=p+2432|0;L=c[I>>2]|0;t=((c[p+2472>>2]|0)*12|0|1)+31&-32;M=L-1+t|0;A=((M|0)<256?M:256)-t|0;M=c[N>>2]|0;if((M|0)>0){B=t<<2;H=p+2368|0;F=(t|0)<1;w=0;x=M;while(1){D=q+1536+(w<<7)|0;E=c[c[D>>2]>>2]|0;C=E+(A<<2)|0;if((c[q+1536+(w<<7)+60>>2]|0)==0){Q=x}else{mrc(C|0,0,B|0)|0;z=c[H>>2]|0;if((z|0)>=1){v=c[D>>2]|0;D=1;do{y=c[v+(D<<2)>>2]|0;if(!((a[q+1536+(w<<7)+64+D|0]|0)==0|F)){K=0;do{R=K+A|0;T=E+(R<<2)|0;g[T>>2]=+g[y+(R<<2)>>2]+ +g[T>>2];K=K+1|0;}while((K|0)<(t|0))}D=D+1|0;}while((D|0)<=(z|0))}kf[c[O>>2]&3](C,C,-.9999999403953552,.9999999403953552,t);Q=c[N>>2]|0}z=w+1|0;if((z|0)<(Q|0)){w=z;x=Q}else{break}}U=c[I>>2]|0;V=Q}else{U=L;V=M}x=c[p+2460>>2]|0;if((U|0)<(x|0)){w=c[p+2368>>2]|0;t=(w|0)<0;A=(V|0)>0;F=U;H=0;while(1){B=a[q+2480+H|0]|0;z=B&255;if(!t){D=B<<24>>24!=0;B=0;do{a:do{if(A){if((B|0)<=0){if(D){W=0}else{break}while(1){if((c[q+1536+(W<<7)+60>>2]|0)!=0){E=c[(c[q+1536+(W<<7)>>2]|0)+(B<<2)>>2]|0;v=n+(W*448|0)+(B<<6)+(H<<2)|0;J=0;X=+g[v>>2];do{Y=+g[E+(J+F<<2)>>2];X=X+Y*Y;J=J+1|0;}while((J|0)<(z|0));g[v>>2]=X}W=W+1|0;if((W|0)>=(V|0)){break a}}}if(D){Z=0}else{break}do{do{if((c[q+1536+(Z<<7)+60>>2]|0)!=0){if((a[q+1536+(Z<<7)+64+B|0]|0)==0){break}J=c[(c[q+1536+(Z<<7)>>2]|0)+(B<<2)>>2]|0;E=n+(Z*448|0)+(B<<6)+(H<<2)|0;K=0;Y=+g[E>>2];do{_=+g[J+(K+F<<2)>>2];Y=Y+_*_;K=K+1|0;}while((K|0)<(z|0));g[E>>2]=Y}}while(0);Z=Z+1|0;}while((Z|0)<(V|0))}}while(0);B=B+1|0;}while((B|0)<=(w|0))}B=z+F|0;if((B|0)<(x|0)){F=B;H=H+1|0}else{break}}}if((V|0)>0){H=p+2368|0;F=p+2476|0;x=0;while(1){do{if((c[q+1536+(x<<7)+60>>2]|0)!=0){w=c[H>>2]|0;if((w|0)<1){break}else{$=1}do{do{if((a[q+1536+(x<<7)+64+$|0]|0)!=0){A=c[F>>2]|0;if((A|0)>0){aa=0}else{break}do{X=+g[n+(x*448|0)+(aa<<2)>>2];if(X>0.0){ba=+S(+g[n+(x*448|0)+($<<6)+(aa<<2)>>2]/X)*.125}else{ba=.125}g[l+(x*448|0)+($<<6)+(aa<<2)>>2]=ba>.9999999403953552?.9999999403953552:ba;aa=aa+1|0;}while((aa|0)<(A|0))}}while(0);$=$+1|0;}while(($|0)<=(w|0))}}while(0);z=x+1|0;if((z|0)<(V|0)){x=z}else{da=0;break}}while(1){x=(da|0)==0;if(x){ea=0}else{ea=q+1536+(da-1<<7)|0}mrc(q+1536+(da<<7)+76|0,0,7)|0;b:do{if((c[q+1536+(da<<7)+60>>2]|0)!=0){do{if(!x){if((c[ea+60>>2]|0)==0){break}if((c[H>>2]|0)<1){break b}z=da-1|0;w=1;while(1){do{if((a[q+1536+(da<<7)+64+w|0]|0)!=0){if((a[ea+64+w|0]|0)==0){a[q+1536+(da<<7)+76+w|0]=1;break}A=c[F>>2]|0;if((A|0)>0){X=0.0;t=0;while(1){_=+g[l+(z*448|0)+(w<<6)+(t<<2)>>2]- +g[l+(da*448|0)+(w<<6)+(t<<2)>>2];if(_<0.0){fa=-0.0-_}else{fa=_}_=X+fa;M=t+1|0;if((M|0)<(A|0)){X=_;t=M}else{ga=_;break}}}else{ga=0.0}if(!(ga/+(A|0)>.03)){break}a[q+1536+(da<<7)+76+w|0]=1}}while(0);w=w+1|0;if((w|0)>(c[H>>2]|0)){break b}}}}while(0);if((c[H>>2]|0)<1){break}else{ha=1}do{a[q+1536+(da<<7)+76+ha|0]=1;ha=ha+1|0;}while((ha|0)<=(c[H>>2]|0))}}while(0);x=da+1|0;w=c[N>>2]|0;if((x|0)<(w|0)){da=x}else{ia=w;ja=F;break}}}else{ia=V;ja=p+2476|0}F=c[ja>>2]|0;if((F|0)>0){H=p+2368|0;w=0;x=0;while(1){z=0;t=w;c:while(1){E=z;while(1){if((E|0)>=(ia|0)){break c}if((c[q+1536+(E<<7)+60>>2]|0)==0){E=E+1|0;continue}ka=c[H>>2]|0;if((ka|0)<1){E=t}else{break}}M=n+(E*448|0)+(x<<2)|0;L=t;I=1;while(1){if((a[q+1536+(E<<7)+64+I|0]|0)==0){la=L}else{X=+g[M>>2];Y=+g[n+(E*448|0)+(I<<6)+(x<<2)>>2];B=E;d:while(1){ma=B;do{ma=ma+1|0;if(!((a[q+1536+(ma<<7)+76+I|0]|0)==0&(ma|0)<(ia|0))){break d}}while((c[q+1536+(ma<<7)+60>>2]|0)==0);X=X+ +g[n+(ma*448|0)+(x<<2)>>2];Y=Y+ +g[n+(ma*448|0)+(I<<6)+(x<<2)>>2];B=ma}if(X>0.0){na=+S(Y/X)*.125}else{na=.125}g[l+(E*448|0)+(I<<6)+(x<<2)>>2]=na>.9999999403953552?.9999999403953552:na;la=ma}B=I+1|0;if((B|0)>(ka|0)){z=la;t=la;continue c}else{L=la;I=B}}}z=x+1|0;if((z|0)<(F|0)){w=t;x=z}else{break}}}if((ia|0)>0){x=p+1432|0;w=p+2368|0;F=p+1448|0;H=0;z=ia;while(1){if((c[q+1536+(H<<7)+60>>2]|0)==0){oa=z}else{I=m+(H*448|0)+64|0;ef[c[x>>2]&4095](I,l+(H*448|0)+64|0,c[w>>2]<<4);L=q+1536+(H<<7)+32|0;ef[c[F>>2]&4095](c[(c[L>>2]|0)+4>>2]|0,I,c[w>>2]<<4);I=c[w>>2]|0;if((I|0)>=1){E=q+1536+(H<<7)+36|0;M=1;B=I;while(1){if((a[q+1536+(H<<7)+76+M|0]|0)==0){pa=B}else{I=c[(c[L>>2]|0)+(M<<2)>>2]|0;D=a[I]|0;C=D&255;v=c[ja>>2]|0;if((v|0)>1){K=1;J=C;y=C;while(1){T=d[I+K|0]|0;R=(T|0)>(J|0)?J:T;qa=(T|0)>(y|0)?T:y;T=K+1|0;if((T|0)<(v|0)){K=T;J=R;y=qa}else{ra=R;sa=qa;break}}}else{ra=C;sa=C}y=(sa-13|0)/3|0;J=(y|0)>0?y:0;while(1){ta=J*3|0;if((ra|0)<(ta|0)){J=J-1|0}else{break}}e:do{if((v|0)>0){C=0;y=I;K=D;while(1){qa=(K&255)-ta|0;if((qa|0)<0){ua=0}else{ua=(qa|0)>15?15:qa&255}a[y+C|0]=ua;qa=C+1|0;if((qa|0)>=(c[ja>>2]|0)){break e}R=c[(c[L>>2]|0)+(M<<2)>>2]|0;C=qa;y=R;K=a[R+qa|0]|0}}}while(0);a[q+1536+(H<<7)+83+M|0]=J;if((c[ja>>2]|0)>0){D=ta+5|0;I=0;do{v=a[(c[(c[L>>2]|0)+(M<<2)>>2]|0)+I|0]|0;K=c[m+(H*448|0)+(M<<6)+(I<<2)>>2]<<D+(v&255)>>24;a[(c[(c[E>>2]|0)+(M<<2)>>2]|0)+I|0]=v<<24>>24==15?K>>>1:K+240|0;I=I+1|0;}while((I|0)<(c[ja>>2]|0))}pa=c[w>>2]|0}I=M+1|0;if((I|0)>(pa|0)){break}else{M=I;B=pa}}}oa=c[N>>2]|0}B=H+1|0;if((B|0)<(oa|0)){H=B;z=oa}else{break}}}if((c[p+2308>>2]|0)==0){break}Cca(q)}}while(0);do{if((c[p+2392>>2]|0)==2){oa=c[N>>2]|0;if((oa|0)<=0){break}pa=p+2500|0;ja=k|0;m=p+1456|0;ta=k+8|0;ua=k+12|0;ra=k+4|0;sa=p+2432|0;l=a[1443288]|0;ia=0;la=0;ka=oa;while(1){oa=q+1536+(la<<7)|0;ma=(la|0)!=0;n=q+1536+(la<<7)+47|0;a[n]=ma&1^1;V=q+1536+(la<<7)+48|0;c[V>>2]=4;do{if((c[q+1536+(la<<7)+60>>2]|0)==0){va=4}else{da=c[sa>>2]|0;ha=4-((da|0)<62)-((da|0)==37)|0;c[V>>2]=ha;if(!ma){va=ha;break}if((ha|0)==(c[ia+48>>2]|0)){va=ha;break}a[n]=1;va=ha}}while(0);ha=c[q+1536+(la<<7)+104>>2]|0;da=c[q+1536+(la<<7)+108>>2]|0;ea=(ha|0)>(da|0)?da:ha;if((c[pa>>2]|0)!=0&(va|0)>0){ha=oa|0;da=0;$=l;while(1){aa=$&255;Z=da+1|0;W=a[1443288+Z|0]|0;U=W&255;Q=c[ha>>2]|0;mf[c[m>>2]&2047](ja,(c[Q+4>>2]|0)+(aa<<2)|0,(c[Q+8>>2]|0)+(aa<<2)|0,((ea|0)>(U|0)?U:ea)-aa|0);na=+g[ta>>2];ga=+g[ua>>2];fa=+g[ja>>2];ba=+g[ra>>2];aa=(na>ga?ga:na)<(fa>ba?ba:fa)|0;a[q+1536+(la<<7)+52+da|0]=aa;do{if(ma){if(aa<<24>>24==(a[ia+52+da|0]|0)){break}a[n]=1}}while(0);if((Z|0)<(c[V>>2]|0)){da=Z;$=W}else{break}}wa=c[N>>2]|0}else{wa=ka}$=la+1|0;if(($|0)<(wa|0)){ia=oa;la=$;ka=wa}else{break}}}}while(0);if((c[u>>2]|0)==0){u=c[N>>2]<<8;N=c[P>>2]|0;P=u&-((N|0)==0|0);wa=ca((c[r>>2]|0)+N|0,u)|0;ef[c[p+1432>>2]&4095]((c[p+2652>>2]|0)+(P<<2)|0,(c[p+2648>>2]|0)+(P<<2)|0,wa)}Qkb(q);Skb(q);wa=Tkb(q)|0;if((wa|0)!=0){KIb(b,16,2583008,(P=i,i=i+1|0,i=i+7&-8,c[P>>2]=0,P)|0);i=P;s=wa;i=j;return s|0}Rkb(q);Ukb(q);wa=c[p+2340>>2]|0;p=d5a(b,e,wa,(wa|0)<0|0?-1:0)|0;if((p|0)<0){s=p;i=j;return s|0}Vkb(q,c[e+24>>2]|0);q=f+136|0;f=c[q>>2]|0;p=c[q+4>>2]|0;if(!((f|0)==0&(p|0)==(-2147483648|0))){q=c[b+116>>2]|0;c[o>>2]=1;c[o+4>>2]=c[b+412>>2];wa=XIb(q,(q|0)<0|0?-1:0,o,b+104|0)|0;b=xrc(f,p,wa,G)|0;wa=e+8|0;c[wa>>2]=b;c[wa+4>>2]=G}c[h>>2]=1;s=0;i=j;return s|0}function hlb(a){a=a|0;PPa(a+1468|0);mJb(a+1532|0);return}function ilb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=hJb(2048)|0;e=d;if((d|0)==0){KIb(c[a+108>>2]|0,16,2432704,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d;f=-12;i=b;return f|0}Fqb(e,5.0,256);d=0;do{g[e+(511-d<<2)>>2]=+g[e+(d<<2)>>2];d=d+1|0;}while((d|0)<256);c[a+1532>>2]=e;f=OPa(a+1468|0,9,0,-.00390625)|0;i=b;return f|0}function jlb(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;if((j|0)<=0){i=k;return}if((h|0)>0){l=0}else{m=0;do{b[a+(m<<1)>>1]=0;m=m+1|0;}while((m|0)<(j|0));i=k;return}do{m=0;n=0;o=16384;do{p=(ca(b[e+(n+g<<1)>>1]|0,b[d+(m+l<<1)>>1]|0)|0)+o|0;n=n+f|0;m=m+1|0;o=p+(ca(b[e+(n-g<<1)>>1]|0,b[d+(l-m<<1)>>1]|0)|0)|0;}while((m|0)<(h|0));m=o>>15;n=m&65535;if((m+32768|0)>>>0>65535>>>0){q=(o>>31^32767)&65535}else{q=n}if((q<<16>>16|0)!=(m|0)){KIb(0,24,2432160,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}b[a+(l<<1)>>1]=n;l=l+1|0;}while((l|0)<(j|0));i=k;return}function klb(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0.0,m=0,n=0,o=0.0;if((h|0)<=0){return}if((f|0)>0){i=0}else{mrc(a|0,0,h<<2|0)|0;return}do{j=0;k=0;l=0.0;while(1){m=k+d|0;n=j+1|0;o=l+ +g[b+(j+i<<2)>>2]*+g[c+(k+e<<2)>>2]+ +g[b+(i-n<<2)>>2]*+g[c+(m-e<<2)>>2];if((n|0)<(f|0)){j=n;k=m;l=o}else{break}}g[a+(i<<2)>>2]=o;i=i+1|0;}while((i|0)<(h|0));return}function llb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f|0)<=0){return}g=d+4|0;h=0;i=c[d>>2]|0;j=c[g>>2]|0;while(1){k=Erc(i,(i|0)<0|0?-1:0,15836,0)|0;l=G;m=Erc(j,(j|0)<0|0?-1:0,-7667,-1)|0;n=G;o=wrc(m>>>13|n<<19,n>>>13|0<<19,k>>>13|l<<19,l>>>13|0<<19)|0;p=(((b[e+(h<<1)>>1]|0)-(b[e+(h-1<<1)>>1]<<1)+(b[e+(h-2<<1)>>1]|0)|0)*7699|0)+o|0;o=p+2048|0;l=o>>12;if((l+32768|0)>>>0>65535>>>0){q=(o>>31^32767)&65535}else{q=l&65535}b[a+(h<<1)>>1]=q;l=h+1|0;if((l|0)<(f|0)){h=l;j=i;i=p}else{break}}c[d>>2]=p;c[g>>2]=i;return}function mlb(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=f|0;h=h|0;var i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0.0,q=0;if((h|0)<=0){return}i=d+4|0;j=f+4|0;k=c+4|0;l=0;m=+g[f>>2];n=+g[j>>2];while(1){o=+g[b+(l<<2)>>2]*e- +g[d>>2]*m- +g[i>>2]*n;g[a+(l<<2)>>2]=o+m*+g[c>>2]+n*+g[k>>2];p=+g[f>>2];g[j>>2]=p;g[f>>2]=o;q=l+1|0;if((q|0)<(h|0)){l=q;m=o;n=p}else{break}}return}function nlb(a,b,c,d){a=a|0;b=+b;c=c|0;d=d|0;var e=0,f=0.0,h=0.0,i=0.0;e=d-1|0;f=+g[c+(e<<2)>>2];if((e|0)>0){d=e;h=f;while(1){e=d-1|0;i=+g[c+(e<<2)>>2];g[c+(d<<2)>>2]=h-i*b;if((e|0)>0){d=e;h=i}else{break}}}g[c>>2]=+g[c>>2]- +g[a>>2]*b;g[a>>2]=f;return}function olb(a){a=a|0;c[a>>2]=232;c[a+4>>2]=2;return}function plb(a){a=a|0;var b=0,c=0;b=a+58|0;if((b|0)<=254){c=b;return c|0}c=(b*3|0)-510|0;return c|0}function qlb(a,b){a=a|0;b=b|0;var c=0;if((a|0)<4){c=(b+a|0)*3|0;return c|0}if((a|0)<12){c=a+6+(b*3|0)|0;return c|0}else{c=((b+a|0)*3|0)-18|0;return c|0}return 0}function rlb(a,b){a=a|0;b=b|0;return a-2+(b*3|0)|0}function slb(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(1<<d)-1|0;g=b[a+(f<<1)>>1]|0;if((f|0)>0){h=f;f=g;while(1){i=h-1|0;j=b[a+(i<<1)>>1]|0;k=(j<<16>>16)+f|0;b[a+(h<<1)>>1]=j;if((i|0)>0){h=i;f=k}else{l=k;break}}}else{l=g}if((e|0)==0){m=((((P3(c)|0)>>2)*6165|0)+417193984|0)>>>13&65535;b[a>>1]=m;return}c=l>>d;if(!((c|0)>-10240)){m=-14336;b[a>>1]=m;return}m=c+61440&65535;b[a>>1]=m;return}function tlb(a,d,e,f,g,h,i,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0.0;k=f<<10;if((j|0)>0){f=k;l=0;while(1){m=(ca(b[h+(l<<1)>>1]|0,b[g+(l<<1)>>1]|0)|0)+f|0;n=l+1|0;if((n|0)<(j|0)){f=m;l=n}else{o=m;break}}}else{o=k}p=+(d|0)*+$(+(o|0)*1.3724476653301989e-8);return~~(p/+S(+(Ee[c[a+1224>>2]&511](e,e,i)|0)))>>>12&65535|0}function ulb(a,b,c,d,e){a=+a;b=+b;c=c|0;d=+d;e=e|0;var f=0.0;f=+ad(+((+pHb(e,c,4)+d)*.16609640474436813))*a/+S(b);orc(c|0,c+4|0,12)|0;g[c+12>>2]=+fd(+a)*20.0;return+f}function vlb(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)==2){if((g|0)==0){i=6}else{i=3}}else if((f|0)==0){i=3}else{i=6}do{if((i|0)==3){if((d|0)<197){j=d+59|0;break}else{j=(d*3|0)-335|0;break}}else if((i|0)==6){if((h|0)==4){f=e-5|0;if((f|0)<20){k=20}else{k=(f|0)>134?134:f}if((d|0)<4){j=((k+d|0)*3|0)+1|0;break}if((d|0)<12){j=d+7+(k*3|0)|0;break}else{j=((k+d|0)*3|0)-17|0;break}}else{f=d-1|0;if((h|0)==5){g=e-10|0;if((g|0)<20){l=60}else{l=(g|0)>124?372:g*3|0}j=l+f|0;break}else{g=e-5|0;if((g|0)<20){m=60}else{m=(g|0)>134?402:g*3|0}j=m+f|0;break}}}}while(0);m=(j*10923|0)>>15;c[a>>2]=m;c[b>>2]=j-1+(m*-3|0);return}function wlb(a,c,f,g,h,i,j){a=a|0;c=c|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=(1<<j)-1|0;l=(h&1|0)!=0?8191:-8192;if((i|0)>0){m=h;h=g;n=0;o=l;while(1){p=a+((d[c+(h&k)|0]|0)+n<<1)|0;b[p>>1]=(e[p>>1]|0)+o;p=h>>j;q=m>>1;r=n+1|0;s=(q&1|0)!=0?8191:-8192;if((r|0)<(i|0)){m=q;h=p;n=r;o=s}else{t=p;u=s;break}}}else{t=g;u=l}l=a+((d[f+t|0]|0)<<1)|0;b[l>>1]=(e[l>>1]|0)+u;return}function xlb(a,e,f,h,i){a=a|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0;j=1<<i;i=j-1|0;c[e+84>>2]=0;c[e>>2]=h<<1;if((h|0)>0){k=0}else{return}do{l=k<<1;m=l|1;n=b[a+(m<<1)>>1]|0;o=(d[f+(n&i)|0]|0)+k|0;p=(d[f+(b[a+(l<<1)>>1]&i)|0]|0)+k|0;q=(n&j|0)!=0?-1.0:1.0;c[e+4+(m<<2)>>2]=o;c[e+4+(l<<2)>>2]=p;g[e+44+(m<<2)>>2]=q;if((p|0)<(o|0)){r=-0.0-q}else{r=q}g[e+44+(l<<2)>>2]=r;k=k+1|0;}while((k|0)<(h|0));return}function ylb(a,c,d,e,f,g,h,i){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;if((i|0)<=0){return}j=e<<16>>16;e=f<<16>>16;f=g<<16>>16;g=0;do{k=ca(b[c+(g<<1)>>1]|0,j)|0;l=k+f+(ca(b[d+(g<<1)>>1]|0,e)|0)>>h;if((l+32768|0)>>>0>65535>>>0){m=(l>>31^32767)&65535}else{m=l&65535}b[a+(g<<1)>>1]=m;g=g+1|0;}while((g|0)<(i|0));return}function zlb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=f|0;var h=0;if((f|0)>0){h=0}else{return}do{g[a+(h<<2)>>2]=+g[b+(h<<2)>>2]*d+ +g[c+(h<<2)>>2]*e;h=h+1|0;}while((h|0)<(f|0));return}function Alb(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=d|0;e=+e;f=f|0;var h=0.0,i=0.0,j=0.0,k=0,l=0.0,m=0.0,n=0;h=+pHb(b,b,d);i=+g[f>>2];if(h!=0.0){j=+S(c/h)}else{j=1.0}h=(1.0-e)*j;if((d|0)>0){k=0;l=i}else{m=i;g[f>>2]=m;return}while(1){i=h+l*e;g[a+(k<<2)>>2]=i*+g[b+(k<<2)>>2];n=k+1|0;if((n|0)<(d|0)){k=n;l=i}else{m=i;break}}g[f>>2]=m;return}function Blb(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0.0,f=0.0,h=0;e=+pHb(b,b,d);if(e!=0.0){f=+S(c/e)}else{f=e}if((d|0)>0){h=0}else{return}do{g[a+(h<<2)>>2]=f*+g[b+(h<<2)>>2];h=h+1|0;}while((h|0)<(d|0));return}function Clb(a,b,d,e){a=a|0;b=b|0;d=+d;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0;f=c[b>>2]|0;if((f|0)<=0){return}h=b+84|0;i=b+92|0;j=c[b+88>>2]|0;k=0;do{l=c[b+4+(k<<2)>>2]|0;m=+g[b+44+(k<<2)>>2]*d;a:do{if((j|0)>0){if((c[h>>2]&1<<k|0)==0){n=m;o=l}else{p=a+(l<<2)|0;g[p>>2]=m+ +g[p>>2];break}while(1){p=a+(o<<2)|0;g[p>>2]=n+ +g[p>>2];p=j+o|0;if((p|0)>=(e|0)){break a}n=n*+g[i>>2];o=p}}}while(0);k=k+1|0;}while((k|0)<(f|0));return}function Dlb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0;e=c[b>>2]|0;if((e|0)<=0){return}f=c[b+84>>2]|0;h=c[b+88>>2]|0;if((h|0)>0){i=0}else{return}do{j=c[b+4+(i<<2)>>2]|0;if((f&1<<i|0)==0){k=j;do{g[a+(k<<2)>>2]=0.0;k=h+k|0;}while((k|0)<(d|0))}else{g[a+(j<<2)>>2]=0.0}i=i+1|0;}while((i|0)<(e|0));return}function Elb(a){a=a|0;c[a>>2]=2;return}function Flb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;e=c[a+60>>2]|0;f=c[(c[a+12>>2]|0)+12>>2]|0;if((f|0)==1095123744|(f|0)==69652|(f|0)==69654|(f|0)==69653|(f|0)==69657|(f|0)==69650){g=6;h=1}else if((f|0)==1146374944|(f|0)==69642){g=2;h=2}else{g=2;h=1}j=c[a+416>>2]|0;if(j>>>0<h>>>0|j>>>0>g>>>0){KIb(a,16,2157680,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;k=-22;i=b;return k|0}do{if((f|0)==69636){g=c[a+96>>2]|0;do{if((g|0)!=0){if((c[a+100>>2]|0)<=1){break}j=g;c[e+216>>2]=(d[j]|d[j+1|0]<<8)<<16>>16&65535}}while(0);c[a+420>>2]=(c[e+216>>2]|0)==3?6:1;k=0;i=b;return k|0}else if((f|0)==69632|(f|0)==1146374944|(f|0)==69639|(f|0)==69640|(f|0)==69652|(f|0)==69654|(f|0)==69653|(f|0)==69657|(f|0)==69650|(f|0)==1095123744){l=15}else if((f|0)==69633){if(((c[a+792>>2]|0)-2|0)>>>0>3>>>0){k=-1094995529}else{l=15;break}i=b;return k|0}else if((f|0)==69644){c[e+44>>2]=511;c[e+8>>2]=511;l=17}else if((f|0)==69661){g=c[a+96>>2]|0;if((g|0)==0){l=17;break}if((c[a+100>>2]|0)<=7){l=17;break}j=g;c[e>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;j=g+4|0;c[e+36>>2]=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24;l=17}else{l=17}}while(0);if((l|0)==15){c[a+420>>2]=6;k=0;i=b;return k|0}else if((l|0)==17){c[a+420>>2]=1;k=0;i=b;return k|0}return 0}function Glb(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0,qd=0,rd=0,sd=0,td=0,ud=0,vd=0,wd=0,xd=0,yd=0,zd=0,Ad=0,Bd=0,Cd=0,Dd=0,Ed=0,Fd=0,Gd=0,Id=0,Jd=0,Kd=0,Ld=0,Md=0,Nd=0,Od=0,Pd=0,Qd=0,Rd=0,Sd=0,Td=0,Ud=0,Vd=0,Wd=0,Xd=0,Yd=0,Zd=0,_d=0,$d=0,ae=0,be=0,ce=0,de=0,ee=0,fe=0,ge=0,ie=0,ke=0,le=0,me=0,ne=0,oe=0,pe=0,qe=0,re=0,se=0,te=0,ue=0,ve=0,we=0,xe=0,ye=0,ze=0,Ae=0,Be=0,Ce=0,De=0,Ee=0,Fe=0,Ge=0,He=0,Ie=0,Je=0,Ke=0,Le=0,Me=0,Ne=0,Oe=0,Pe=0,Qe=0,Re=0,Se=0,Te=0,Ue=0,Ve=0,We=0,Xe=0,Ye=0,Ze=0,_e=0,$e=0,af=0,bf=0,cf=0,df=0,ef=0,ff=0,gf=0,hf=0,jf=0,kf=0,lf=0,mf=0,nf=0,of=0,pf=0,qf=0,rf=0,sf=0,tf=0,uf=0,vf=0,wf=0,xf=0,yf=0,zf=0,Af=0,Bf=0,Cf=0,Df=0,Ef=0,Ff=0,Gf=0,Hf=0,If=0,Jf=0,Kf=0,Lf=0,Mf=0,Nf=0,Of=0,Pf=0,Qf=0,Rf=0,Sf=0,Tf=0,Uf=0,Vf=0,Wf=0,Xf=0,Yf=0,Zf=0,_f=0,$f=0,ag=0,bg=0,cg=0;j=i;i=i+496|0;k=j|0;l=j+8|0;m=j+24|0;n=j+32|0;o=j+40|0;p=j+64|0;q=j+96|0;r=j+112|0;s=c[h+24>>2]|0;t=h+28|0;h=c[t>>2]|0;u=e+60|0;v=c[u>>2]|0;if(!((h|0)>-1)){KIb(0,0,2163760,(w=i,i=i+24|0,c[w>>2]=2161648,c[w+8>>2]=2159648,c[w+16>>2]=135,w)|0);i=w;Hd();return 0}x=s+h|0;y=e+416|0;z=c[y>>2]|0;a:do{if((z|0)>=1){A=e+12|0;B=c[(c[A>>2]|0)+12>>2]|0;do{if((B|0)==1095123744){C=53}else if((B|0)==69640){C=54}else if((B|0)==69658){C=18}else if((B|0)==69645){C=44}else if((B|0)==69647){C=42}else if((B|0)==69649){D=4;C=43}else if((B|0)==69648){C=41}else if((B|0)==69652){C=19}else if((B|0)==69635){C=29}else if((B|0)==69642){C=12}else if((B|0)==69644|(B|0)==69661|(B|0)==69655|(B|0)==1330333984|(B|0)==69636|(B|0)==69646){E=(h<<1|0)/(z|0)|0;if((E|0)!=0){F=E;G=s;H=0;I=0;C=57;break}if((B|0)==1095123744){C=53}else if((B|0)==69640){C=54}else if((B|0)==69658){C=18}else if((B|0)==69645){C=44}else if((B|0)==69647){C=42}else if((B|0)==69649){D=4;C=43}else if((B|0)==69648){C=41}else if((B|0)==69652){C=19}else if((B|0)==69642){C=12}else if((B|0)==69651){J=8;C=10}else if((B|0)==69650){C=48}else if((B|0)==69656){C=15}else if((B|0)==69653){C=23}else if((B|0)==1146374944){C=55}else if((B|0)==69654){C=21}else if((B|0)==69638){C=38}else if((B|0)==69639|(B|0)==69659|(B|0)==69637){C=9}else{break a}}else if((B|0)==69651){J=8;C=10}else if((B|0)==69650){C=48}else if((B|0)==69656){C=15}else if((B|0)==69657){if((z*76|0|0)>(h|0)){break a}else{K=0;L=0;M=s;N=128}}else if((B|0)==69653){C=23}else if((B|0)==69633){C=35}else if((B|0)==1146374944){C=55}else if((B|0)==69634){C=26}else if((B|0)==69654){C=21}else if((B|0)==1380008992){C=32}else if((B|0)==69632){if((z*34|0|0)>(h|0)){break a}else{K=0;L=0;M=s;N=64}}else if((B|0)==69638){C=38}else if((B|0)==69639|(B|0)==69659|(B|0)==69637){C=9}else{break a}}while(0);do{if((C|0)==9){E=z<<2;if((E|0)>0){J=E;C=10;break}if((B|0)==1095123744){C=53}else if((B|0)==69640){C=54}else if((B|0)==69658){C=18}else if((B|0)==69645){C=44}else if((B|0)==69647){C=42}else if((B|0)==69649){D=4;C=43}else if((B|0)==69648){C=41}else if((B|0)==69652){C=19}else if((B|0)==69635){C=29}else if((B|0)==69642){C=12}else if((B|0)==69650){C=48}else if((B|0)==69656){C=15}else if((B|0)==69653){C=23}else if((B|0)==69633){C=35}else if((B|0)==1146374944){C=55}else if((B|0)==69634){C=26}else if((B|0)==69654){C=21}else if((B|0)==1380008992){C=32}else if((B|0)==69638){C=38}else{break a}}}while(0);do{if((C|0)==10){F=(h-J<<1|0)/(z|0)|0;G=s;H=0;I=0;C=57}else if((C|0)==12){if((h|0)<4){O=0;P=s}else{B=s;O=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;P=s+4|0}Q=((h-12|0)/30|0)*28|0;R=O-((O|0)%28|0)|0;S=P;T=0;C=56}else if((C|0)==15){if((h|0)<4){U=0;V=s}else{B=s;U=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;V=s+4|0}Q=(h-(z<<3|4)<<1|0)/(z|0)|0;R=U;S=V;T=0;C=56}else if((C|0)==18){F=((h-z|0)/(z|0)|0)<<1;G=s;H=0;I=0;C=57}else if((C|0)==19){B=z*9|0;if((h|0)<4){W=B;X=s;Y=0;Z=0;C=25;break}E=s;W=B;X=s+4|0;Y=0;Z=d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0;C=25}else if((C|0)==21){E=z*5|0;if((h|0)<4){W=E;X=s;Y=1;Z=0;C=25;break}B=s;W=E;X=s+4|0;Y=1;Z=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0;C=25}else if((C|0)==23){B=z*5|0;if((h|0)<4){W=B;X=s;Y=1;Z=0;C=25;break}E=s;W=B;X=s+4|0;Y=1;Z=je(d[E]|d[E+1|0]<<8|d[E+2|0]<<16|d[E+3|0]<<24|0)|0;C=25}else if((C|0)==26){E=c[e+432>>2]|0;if((E|0)>0){_=(E|0)<(h|0)?E:h}else{_=h}F=((((_<<1)-32|0)/3|0)<<2|0)/(z|0)|0;G=s;H=0;I=0;C=57}else if((C|0)==29){E=c[e+432>>2]|0;if((E|0)>0){$=(E|0)<(h|0)?E:h}else{$=h}F=(($-(z<<2)<<1|0)/(z|0)|0)+1|0;G=s;H=0;I=0;C=57}else if((C|0)==32){E=c[e+432>>2]|0;if((E|0)>0){aa=(E|0)<(h|0)?E:h}else{aa=h}F=(aa-(z<<2)<<1|0)/(z|0)|0;G=s;H=0;I=0;C=57}else if((C|0)==35){E=(c[e+792>>2]|0)-2|0;B=c[e+432>>2]|0;if((B|0)>0){ba=(B|0)<(h|0)?B:h}else{ba=h}F=(ca((ba-(z<<2)|0)/(ca(d[1440176+E|0]|0,z)|0)|0,d[1440184+E|0]|0)|0)+1|0;G=s;H=0;I=0;C=57}else if((C|0)==38){E=c[e+432>>2]|0;if((E|0)>0){da=(E|0)<(h|0)?E:h}else{da=h}F=((da+(z*-7|0)<<1|0)/(z|0)|0)+2|0;G=s;H=0;I=0;C=57}else if((C|0)==41){D=3;C=43}else if((C|0)==42){D=2;C=43}else if((C|0)==44){E=(h<<3)-2|0;if((h|0)<1){ea=2;fa=s}else{ea=((d[s]|0)>>>6)+2|0;fa=s+1|0}B=z*22|0;ga=ca(ea,z)|0;ha=(ga*4095|0)+B|0;ia=(E|0)/(ha|0)|0;ja=E-(ca(ha,ia)|0)|0;ha=ia<<12;if((ja|0)<(B|0)){F=ha;G=fa;H=0;I=0;C=57;break}F=((ja-B|0)/(ga|0)|0)+(ha|1)|0;G=fa;H=0;I=0;C=57}else if((C|0)==48){if((c[e+96>>2]|0)!=0){F=((h|0)/(z<<3|0)|0)*14|0;G=s;H=0;I=0;C=57;break}ha=h>>>0>4>>>0?4:h;ga=s+ha|0;if((x-ga|0)<4){ka=0;la=ga}else{B=ga;ka=je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0;la=s+(ha+4)|0}Q=((h-8+(z*-36|0)|0)/(z<<3|0)|0)*14|0;R=ka-((ka|0)%14|0)|0;S=la;T=0;C=56}else if((C|0)==53){F=((h|0)/(z*9|0|0)|0)<<4;G=s;H=0;I=0;C=57}else if((C|0)==54){F=(((h|0)/128|0)*224|0|0)/(z|0)|0;G=s;H=0;I=0;C=57}else if((C|0)==55){F=((h|0)/(z<<4|0)|0)*28|0;G=s;H=0;I=0;C=57}}while(0);if((C|0)==25){ha=(h-4-W<<1|0)/(z|0)|0;Q=ha-((ha|0)%28|0)|0;R=Z-((Z|0)%28|0)|0;S=X;T=Y;C=56}else if((C|0)==43){ha=(b[v+4>>1]|0)==0;F=(ha&1)+((ca(h-(ha?z:0)|0,D)|0)/(z|0)|0)|0;G=s;H=0;I=0;C=57}if((C|0)==56){if((R|0)<1|(R|0)>(Q|0)){break}else{F=Q;G=S;H=T;I=R;C=57}}if((C|0)==57){if((F|0)<1){break}else{K=I;L=H;M=G;N=F}}ha=f+76|0;c[ha>>2]=N;B=M4a(e,f,0)|0;if((B|0)<0){ma=B;i=j;return ma|0}B=f;ga=c[f>>2]|0;ja=ga;ia=c[f+64>>2]|0;if((K|0)==0){na=N}else{if(!((L|0)!=0|(K|0)==(N|0))){KIb(e,24,2194960,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w}c[ha>>2]=K;na=K}E=c[y>>2]|0;oa=(E|0)==2;pa=oa&1;qa=c[(c[A>>2]|0)+12>>2]|0;b:do{if((qa|0)==69638){ra=M+1|0;sa=a[M]|0;ta=sa&255;if((sa&255)>>>0>6>>>0){KIb(e,16,2190064,(w=i,i=i+8|0,c[w>>2]=ta,w)|0);i=w;ma=-1094995529;i=j;return ma|0}sa=d[1442168+ta|0]|0;ua=v;va=v+24|0;c[va>>2]=sa;wa=a[1442160+ta|0]|0;ta=v+28|0;c[ta>>2]=wa;do{if(oa){xa=a[ra]|0;ya=xa&255;if(!((xa&255)>>>0>6>>>0)){c[v+60>>2]=d[1442168+ya|0]|0;c[v+64>>2]=a[1442160+ya|0]|0;xa=M+2|0;za=(d[xa]|d[xa+1|0]<<8)<<16>>16<<16>>16;c[v+32>>2]=za;xa=M+4|0;c[v+68>>2]=(d[xa]|d[xa+1|0]<<8)<<16>>16<<16>>16;xa=M+6|0;Aa=(d[xa]|d[xa+1|0]<<8)<<16>>16;xa=Aa<<16>>16;Ba=v+16|0;c[Ba>>2]=xa;Ca=M+8|0;c[v+52>>2]=(d[Ca]|d[Ca+1|0]<<8)<<16>>16<<16>>16;Ca=M+10|0;Da=(d[Ca]|d[Ca+1|0]<<8)<<16>>16;Ca=Da<<16>>16;Ea=v+20|0;c[Ea>>2]=Ca;Fa=M+12|0;Ga=(d[Fa]|d[Fa+1|0]<<8)<<16>>16;c[v+56>>2]=Ga<<16>>16;b[ja>>1]=Da;b[ga+2>>1]=Ga;b[ga+4>>1]=Aa;b[ga+6>>1]=c[v+52>>2];Ha=ga+8|0;Ia=M+14|0;Ja=Ba;Ka=xa;La=za;Ma=Ca;Na=Ea;break}KIb(e,16,2187512,(w=i,i=i+8|0,c[w>>2]=ya,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{ya=ra;Ea=(d[ya]|d[ya+1|0]<<8)<<16>>16<<16>>16;c[v+32>>2]=Ea;ya=M+3|0;Ca=(d[ya]|d[ya+1|0]<<8)<<16>>16;ya=Ca<<16>>16;za=v+16|0;c[za>>2]=ya;xa=M+5|0;Ba=(d[xa]|d[xa+1|0]<<8)<<16>>16;xa=Ba<<16>>16;Aa=v+20|0;c[Aa>>2]=xa;b[ja>>1]=Ba;b[ga+2>>1]=Ca;Ha=ga+4|0;Ia=M+7|0;Ja=za;Ka=ya;La=Ea;Ma=xa;Na=Aa}}while(0);ra=na-2>>(pa^1);if((ra|0)<=0){Oa=Ia;break}Aa=v+32|0;xa=ua+(pa*36|0)+16|0;Ea=ua+(pa*36|0)+24|0;ya=ua+(pa*36|0)+20|0;za=ua+(pa*36|0)+28|0;Ca=ua+(pa*36|0)+32|0;Ba=Ia;Ga=Ha;Da=ra;Fa=Ka;Pa=sa;Qa=Ma;Ra=wa;Sa=La;while(1){Ta=d[Ba]|0;Ua=Ta>>>4;Va=((ca(Ra,Qa)|0)+(ca(Pa,Fa)|0)|0)/64|0;Wa=(ca(Sa,(Ua&8|0)!=0?Ua|-16:Ua)|0)+Va|0;c[Na>>2]=Fa;if((Wa+32768|0)>>>0>65535>>>0){Xa=(Wa>>31^32767)&65535}else{Xa=Wa&65535}c[Ja>>2]=Xa<<16>>16;Wa=(ca(b[1442128+(Ua<<1)>>1]|0,Sa)|0)>>8;c[Aa>>2]=(Wa|0)<16?16:Wa;b[Ga>>1]=Xa;Wa=Ta&15;Ua=c[xa>>2]|0;Va=ca(c[Ea>>2]|0,Ua)|0;Ya=((ca(c[za>>2]|0,c[ya>>2]|0)|0)+Va|0)/64|0;Va=c[Ca>>2]|0;Za=(ca(Va,(Ta&8|0)!=0?Ta|-16:Wa)|0)+Ya|0;c[ya>>2]=Ua;if((Za+32768|0)>>>0>65535>>>0){_a=(Za>>31^32767)&65535}else{_a=Za&65535}c[xa>>2]=_a<<16>>16;Za=(ca(b[1442128+(Wa<<1)>>1]|0,Va)|0)>>8;c[Ca>>2]=(Za|0)<16?16:Za;b[Ga+2>>1]=_a;Za=Da-1|0;if((Za|0)<=0){break}Ba=Ba+1|0;Ga=Ga+4|0;Da=Za;Fa=c[Ja>>2]|0;Pa=c[va>>2]|0;Qa=c[Na>>2]|0;Ra=c[ta>>2]|0;Sa=c[Aa>>2]|0}Oa=Ia+ra|0}else if((qa|0)==69646){Aa=na>>(pa^1);if((Aa|0)<=0){Oa=M;break}Sa=v;ta=v+8|0;Ra=v;Qa=Sa+(pa*36|0)+8|0;va=Sa+(pa*36|0)|0;Sa=M;Pa=ja;Fa=Aa;while(1){Da=a[Sa]|0;Ga=c[ta>>2]|0;if((Ga|0)==0){c[Ra>>2]=0;c[ta>>2]=127;$a=127;ab=0}else{$a=Ga;ab=c[Ra>>2]|0}Ga=Da&15;Ba=((ca(a[1437448+Ga|0]|0,$a)|0)/8|0)+ab|0;if((Ba+32768|0)>>>0>65535>>>0){bb=(Ba>>31^32767)&65535}else{bb=Ba&65535}c[Ra>>2]=bb<<16>>16;Ba=(ca(b[1437312+(Ga<<1)>>1]|0,$a)|0)>>8;if((Ba|0)<127){cb=127}else{cb=(Ba|0)>24567?24567:Ba}c[ta>>2]=cb;b[Pa>>1]=bb;Ba=c[Qa>>2]|0;if((Ba|0)==0){c[va>>2]=0;c[Qa>>2]=127;db=127;eb=0}else{db=Ba;eb=c[va>>2]|0}Ba=(Da&255)>>>4&255;Da=((ca(a[1437448+Ba|0]|0,db)|0)/8|0)+eb|0;if((Da+32768|0)>>>0>65535>>>0){fb=(Da>>31^32767)&65535}else{fb=Da&65535}c[va>>2]=fb<<16>>16;Da=(ca(b[1437312+(Ba<<1)>>1]|0,db)|0)>>8;if((Da|0)<127){gb=127}else{gb=(Da|0)>24567?24567:Da}c[Qa>>2]=gb;b[Pa+2>>1]=fb;Da=Fa-1|0;if((Da|0)>0){Sa=Sa+1|0;Pa=Pa+4|0;Fa=Da}else{break}}Oa=M+Aa|0}else if((qa|0)==69644){Fa=na>>(pa^1);if((Fa|0)<=0){Oa=M;break}Pa=v;Sa=v+8|0;Qa=v;va=Pa+(pa*36|0)+8|0;ta=Pa+(pa*36|0)|0;Pa=M;Ra=ja;ra=Fa;while(1){Da=a[Pa]|0;Ba=(Da&255)>>>4&255;Ga=Ba&7;Ca=c[Sa>>2]|0;xa=(ca(Ga<<1|1,Ca)|0)>>3;ya=((Ba&8|0)!=0?-xa|0:xa)+(((c[Qa>>2]|0)*254|0)>>8)|0;if((ya+32768|0)>>>0>65535>>>0){hb=(ya>>31^32767)&65535}else{hb=ya&65535}c[Qa>>2]=hb<<16>>16;ya=(ca(b[1442128+(Ga<<1)>>1]|0,Ca)|0)>>8;if((ya|0)<511){ib=511}else{ib=(ya|0)>32767?32767:ya}c[Sa>>2]=ib;b[Ra>>1]=hb;ya=Da&15;Da=ya&7;Ca=c[va>>2]|0;Ga=(ca(Ca,Da<<1|1)|0)>>3;xa=(((c[ta>>2]|0)*254|0)>>8)+((ya&8|0)!=0?-Ga|0:Ga)|0;if((xa+32768|0)>>>0>65535>>>0){jb=(xa>>31^32767)&65535}else{jb=xa&65535}c[ta>>2]=jb<<16>>16;xa=(ca(b[1442128+(Da<<1)>>1]|0,Ca)|0)>>8;if((xa|0)<511){kb=511}else{kb=(xa|0)>32767?32767:xa}c[va>>2]=kb;b[Ra+2>>1]=jb;xa=ra-1|0;if((xa|0)>0){Pa=Pa+1|0;Ra=Ra+4|0;ra=xa}else{break}}Oa=M+Fa|0}else if((qa|0)==69650){ra=c[e+96>>2]|0;if((ra|0)==0){Ra=(E|0)>0;if(Ra){lb=M;mb=0}else{Oa=M;break}do{Pa=lb;c[r+(mb<<6)>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+2|0;c[r+(mb<<6)+4>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+4|0;c[r+(mb<<6)+8>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+6|0;c[r+(mb<<6)+12>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+8|0;c[r+(mb<<6)+16>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+10|0;c[r+(mb<<6)+20>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+12|0;c[r+(mb<<6)+24>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+14|0;c[r+(mb<<6)+28>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+16|0;c[r+(mb<<6)+32>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+18|0;c[r+(mb<<6)+36>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+20|0;c[r+(mb<<6)+40>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+22|0;c[r+(mb<<6)+44>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+24|0;c[r+(mb<<6)+48>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+26|0;c[r+(mb<<6)+52>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+28|0;c[r+(mb<<6)+56>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Pa=lb+30|0;c[r+(mb<<6)+60>>2]=(he((d[Pa]|d[Pa+1|0]<<8)<<16>>16|0)|0)<<16>>16;lb=lb+32|0;mb=mb+1|0;}while((mb|0)<(E|0));if(!Ra){Oa=lb;break}Fa=v;Pa=lb;va=0;while(1){ta=Pa;c[Fa+(va*36|0)+16>>2]=(he((d[ta]|d[ta+1|0]<<8)<<16>>16|0)|0)<<16>>16;ta=Pa+4|0;Sa=Pa+2|0;c[Fa+(va*36|0)+20>>2]=(he((d[Sa]|d[Sa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Sa=va+1|0;Qa=c[y>>2]|0;if((Sa|0)<(Qa|0)){Pa=ta;va=Sa}else{nb=ta;ob=Qa;break}}}else{va=c[e+100>>2]|0;if((va|0)<(E<<5|0)){KIb(e,16,2178424,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ma=-1094995529;i=j;return ma|0}if(!((va|0)>-1)){KIb(0,0,2163760,(w=i,i=i+24|0,c[w>>2]=2161648,c[w+8>>2]=2159648,c[w+16>>2]=135,w)|0);i=w;Hd();return 0}if((E|0)>0){pb=ra;qb=0}else{Oa=M;break}while(1){va=pb;c[r+(qb<<6)>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+2|0;c[r+(qb<<6)+4>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+4|0;c[r+(qb<<6)+8>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+6|0;c[r+(qb<<6)+12>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+8|0;c[r+(qb<<6)+16>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+10|0;c[r+(qb<<6)+20>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+12|0;c[r+(qb<<6)+24>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+14|0;c[r+(qb<<6)+28>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+16|0;c[r+(qb<<6)+32>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+18|0;c[r+(qb<<6)+36>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+20|0;c[r+(qb<<6)+40>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+22|0;c[r+(qb<<6)+44>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+24|0;c[r+(qb<<6)+48>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+26|0;c[r+(qb<<6)+52>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+28|0;c[r+(qb<<6)+56>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=pb+30|0;c[r+(qb<<6)+60>>2]=(he((d[va]|d[va+1|0]<<8)<<16>>16|0)|0)<<16>>16;va=qb+1|0;if((va|0)<(E|0)){pb=pb+32|0;qb=va}else{nb=M;ob=E;break}}}if((ob|0)<=0){Oa=nb;break}ra=(na|0)/14|0;va=(na|0)>13;Pa=v;Fa=nb;Ra=0;Qa=ob;while(1){if(va){ta=Pa+(Ra*36|0)+16|0;Sa=Pa+(Ra*36|0)+20|0;Aa=Fa;xa=c[ia+(Ra<<2)>>2]|0;Ca=0;while(1){Da=d[Aa]|0;Ga=Da&15;ya=Da>>>4<<1&14;Ba=c[r+(Ra<<6)+(ya<<2)>>2]|0;za=c[r+(Ra<<6)+((ya|1)<<2)>>2]|0;ya=Aa+1|0;Ea=xa;wa=Da;Da=0;while(1){if((Da&1|0)==0){sa=d[ya]|0;rb=sa;sb=sa>>>4;tb=ya+1|0}else{rb=wa;sb=wa;tb=ya}sa=c[ta>>2]|0;ua=ca(sa,Ba)|0;Za=((ca(c[Sa>>2]|0,za)|0)+ua>>11)+(sb<<28>>28<<Ga)|0;if((Za+32768|0)>>>0>65535>>>0){ub=(Za>>31^32767)&65535}else{ub=Za&65535}b[Ea>>1]=ub;c[Sa>>2]=sa;c[ta>>2]=ub<<16>>16;sa=Da+1|0;if((sa|0)<14){ya=tb;Ea=Ea+2|0;wa=rb;Da=sa}else{break}}Da=Ca+1|0;if((Da|0)<(ra|0)){Aa=tb;xa=xa+28|0;Ca=Da}else{break}}vb=tb;wb=c[y>>2]|0}else{vb=Fa;wb=Qa}Ca=Ra+1|0;if((Ca|0)<(wb|0)){Fa=vb;Ra=Ca;Qa=wb}else{Oa=vb;break}}}else if((qa|0)==69633){c:do{if((E|0)>0){Qa=v;Ra=M;Fa=0;while(1){ra=Ra;Pa=(d[ra]|d[ra+1|0]<<8)<<16>>16;b[c[ia+(Fa<<2)>>2]>>1]=Pa;c[Qa+(Fa*36|0)>>2]=Pa<<16>>16;Pa=Ra+2|0;xb=(d[Pa]|d[Pa+1|0]<<8)<<16>>16;b[Qa+(Fa*36|0)+4>>1]=xb;if((xb&65535)>>>0>88>>>0){break}Pa=Ra+4|0;ra=Fa+1|0;va=c[y>>2]|0;if((ra|0)<(va|0)){Ra=Pa;Fa=ra}else{yb=Pa;zb=va;break c}}KIb(e,16,2192512,(w=i,i=i+16|0,c[w>>2]=Fa,c[w+8>>2]=xb<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{yb=M;zb=E}}while(0);Ra=e+792|0;Qa=c[Ra>>2]|0;if((Qa|0)!=4){va=d[1440184+(Qa-2)|0]|0;Qa=x-yb|0;Pa=Qa>>>0>268435455>>>0?-8:Qa<<3;ra=Pa>>>0>2147483639>>>0|(yb|0)==0;Ca=ra?0:yb;xa=ra?8:Pa+8|0;Pa=(na-1|0)/(va|0)|0;if((Pa|0)>0){ra=v;Aa=0;ta=0;Sa=zb;while(1){if((Sa|0)>0){Da=(ca(ta,va)|0)+1|0;wa=Aa;Ea=0;while(1){ya=c[ia+(Ea<<2)>>2]|0;Ga=ra+(Ea*36|0)+4|0;za=ra+(Ea*36|0)|0;Ba=wa;sa=0;do{Za=c[Ra>>2]|0;ua=Za-1|0;Va=Ca+(Ba>>>3)|0;Wa=32-Za|0;Ua=(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)>>>((Ba&7)>>>0)<<Wa>>>(Wa>>>0);Wa=Za+Ba|0;Ba=xa>>>0>Wa>>>0?Wa:xa;Wa=b[Ga>>1]|0;Va=(a[(c[1438792+(Za-2<<2)>>2]|0)+Ua|0]|0)+Wa|0;if((Va|0)<0){Ab=0}else{Ab=(Va|0)>88?88:Va&65535}Va=1<<ua;Za=(ca((Ua&Va-1)<<1|1,b[1437984+(Wa<<1)>>1]|0)|0)>>ua;ua=(c[za>>2]|0)+((Ua&Va|0)==0?Za:-Za|0)|0;if((ua+32768|0)>>>0>65535>>>0){Bb=(ua>>31^32767)&65535}else{Bb=ua&65535}c[za>>2]=Bb<<16>>16;b[Ga>>1]=Ab;b[ya+(Da+sa<<1)>>1]=Bb;sa=sa+1|0;}while((sa|0)<(va|0));sa=c[y>>2]|0;ya=Ea+1|0;if((ya|0)<(sa|0)){wa=Ba;Ea=ya}else{Cb=Ba;Db=sa;break}}}else{Cb=Aa;Db=Sa}Ea=ta+1|0;if((Ea|0)<(Pa|0)){Aa=Cb;ta=Ea;Sa=Db}else{Eb=Db;break}}}else{Eb=zb}Sa=(c[e+432>>2]|0)-(Eb<<2)|0;Oa=yb+(Qa>>>0>Sa>>>0?Sa:Qa)|0;break}Sa=na-1|0;ta=(Sa|0)/8|0;if((Sa|0)<=7){Oa=yb;break}Sa=v;Aa=yb;Pa=0;va=zb;while(1){if((va|0)>0){xa=Pa<<3|1;Ca=Aa;Ra=0;while(1){ra=c[ia+(Ra<<2)>>2]|0;Ea=Sa+(Ra*36|0)+4|0;wa=Sa+(Ra*36|0)|0;Da=Ca;Fa=0;while(1){sa=a[Da]|0;ya=b[Ea>>1]|0;Ga=sa&15;za=(a[1438808+Ga|0]|0)+ya|0;if((za|0)<0){Fb=0}else{Fb=(za|0)>88?88:za&65535}za=(ca(Ga<<1&14|1,b[1437984+(ya<<1)>>1]|0)|0)>>3;ya=(c[wa>>2]|0)+((Ga&8|0)==0?za:-za|0)|0;if((ya+32768|0)>>>0>65535>>>0){Gb=(ya>>31^32767)&65535}else{Gb=ya&65535}ya=Gb<<16>>16;c[wa>>2]=ya;b[Ea>>1]=Fb;b[ra+(Fa+xa<<1)>>1]=Gb;za=b[Ea>>1]|0;Ga=(sa&255)>>>4&255;sa=(a[1438808+Ga|0]|0)+za|0;if((sa|0)<0){Hb=0}else{Hb=(sa|0)>88?88:sa&65535}sa=(ca(b[1437984+(za<<1)>>1]|0,Ga<<1&14|1)|0)>>3;za=ya+((Ga&8|0)==0?sa:-sa|0)|0;if((za+32768|0)>>>0>65535>>>0){Ib=(za>>31^32767)&65535}else{Ib=za&65535}c[wa>>2]=Ib<<16>>16;b[Ea>>1]=Hb;b[ra+((Fa|1)+xa<<1)>>1]=Ib;za=Fa+2|0;if((za|0)<8){Da=Da+1|0;Fa=za}else{break}}Fa=Ca+4|0;Da=Ra+1|0;ra=c[y>>2]|0;if((Da|0)<(ra|0)){Ca=Fa;Ra=Da}else{Jb=Fa;Kb=ra;break}}}else{Jb=Aa;Kb=va}Ra=Pa+1|0;if((Ra|0)<(ta|0)){Aa=Jb;Pa=Ra;va=Kb}else{Oa=Jb;break}}}else if((qa|0)==1330333984){if((x|0)==(M|0)){Oa=x;break}va=v;Pa=v+4|0;Aa=v;ta=va+(pa*36|0)+4|0;Sa=va+(pa*36|0)|0;va=M;Qa=ja;while(1){Ra=va+1|0;Ca=d[va]|0;xa=Ca>>>4;ra=b[Pa>>1]|0;Fa=(a[1438808+xa|0]|0)+ra|0;if((Fa|0)<0){Lb=0}else{Lb=(Fa|0)>48?48:Fa&65535}Fa=(ca(xa<<1&14|1,b[1438480+(ra<<1)>>1]|0)|0)>>3;ra=(c[Aa>>2]|0)+((xa&8|0)==0?Fa:-Fa|0)|0;if((ra|0)<-2048){Mb=-2048}else{Mb=(ra|0)>2047?2047:ra}c[Aa>>2]=Mb;b[Pa>>1]=Lb;b[Qa>>1]=Mb<<4;ra=b[ta>>1]|0;Fa=(a[1438808+(Ca&15)|0]|0)+ra|0;if((Fa|0)<0){Nb=0}else{Nb=(Fa|0)>48?48:Fa&65535}Fa=(ca(b[1438480+(ra<<1)>>1]|0,Ca<<1&14|1)|0)>>3;ra=(c[Sa>>2]|0)+((Ca&8|0)==0?Fa:-Fa|0)|0;if((ra|0)<-2048){Ob=-2048}else{Ob=(ra|0)>2047?2047:ra}c[Sa>>2]=Ob;b[ta>>1]=Nb;b[Qa+2>>1]=Ob<<4;if((x|0)==(Ra|0)){Oa=x;break}else{va=Ra;Qa=Qa+4|0}}}else if((qa|0)==69642){if(!oa){ma=-1094995529;i=j;return ma|0}Qa=M+8|0;va=(na|0)/28|0;if((na|0)>27){ta=M+6|0;Sa=M+4|0;Pa=M+2|0;Aa=M;Ra=(na|0)>55?(va*30|0)+8|0:38;ra=Qa;Fa=(d[Sa]|d[Sa+1|0]<<8)<<16>>16<<16>>16;Sa=(d[Aa]|d[Aa+1|0]<<8)<<16>>16<<16>>16;Aa=(d[ta]|d[ta+1|0]<<8)<<16>>16<<16>>16;ta=(d[Pa]|d[Pa+1|0]<<8)<<16>>16<<16>>16;Pa=0;Ca=ja;while(1){xa=d[ra]|0;Da=xa>>>4;Ea=c[1515328+(Da<<2)>>2]|0;wa=c[1515328+(Da+4<<2)>>2]|0;Da=xa&15;xa=c[1515328+(Da<<2)>>2]|0;Ba=c[1515328+(Da+4<<2)>>2]|0;Da=d[ra+1|0]|0;za=20-(Da>>>4)|0;sa=20-(Da&15)|0;Da=Ca+112|0;Ga=ra+2|0;ya=Fa;ua=Sa;Za=Aa;Va=ta;Ua=0;Wa=Ca;while(1){Ya=d[Ga]|0;Ta=(ca(ua,Ea)|0)+128+(ca(Va,wa)|0)+(Ya>>>4<<28>>28<<za)|0;Pb=Ta>>8;Qb=(ca(ya,xa)|0)+128+(ca(Za,Ba)|0)+(Ya<<28>>28<<sa)|0;Ya=Qb>>8;if((Pb+32768|0)>>>0>65535>>>0){Rb=(Ta>>31^32767)&65535}else{Rb=Pb&65535}Sb=Rb<<16>>16;if((Ya+32768|0)>>>0>65535>>>0){Tb=(Qb>>31^32767)&65535}else{Tb=Ya&65535}Ub=Tb<<16>>16;b[Wa>>1]=Rb;b[Wa+2>>1]=Tb;Ya=Ua+1|0;if((Ya|0)<28){Ga=Ga+1|0;Za=ya;ya=Ub;Va=ua;ua=Sb;Ua=Ya;Wa=Wa+4|0}else{break}}Wa=Pa+1|0;if((Wa|0)<(va|0)){ra=ra+30|0;Fa=Ub;Sa=Sb;Aa=ya;ta=ua;Pa=Wa;Ca=Da}else{break}}Vb=M+Ra|0}else{Vb=Qa}Ca=x-Vb|0;Oa=Vb+(Ca>>>0>2>>>0?2:Ca)|0}else if((qa|0)==1380008992){d:do{if((E|0)>0){Ca=v;Pa=M;ta=0;while(1){Aa=Pa;Wb=(d[Aa]|d[Aa+1|0]<<8)<<16>>16;b[Ca+(ta*36|0)+4>>1]=Wb;Aa=Pa+2|0;c[Ca+(ta*36|0)>>2]=(d[Aa]|d[Aa+1|0]<<8)<<16>>16<<16>>16;if((Wb&65535)>>>0>88>>>0){break}Aa=Pa+4|0;Sa=ta+1|0;Fa=c[y>>2]|0;if((Sa|0)<(Fa|0)){Pa=Aa;ta=Sa}else{Xb=Aa;Yb=Fa;break d}}KIb(e,16,2192512,(w=i,i=i+16|0,c[w>>2]=ta,c[w+8>>2]=Wb<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{Xb=M;Yb=E}}while(0);Qa=(na|0)/2|0;if((na|0)<=1){Oa=Xb;break}Ra=k|0;Pa=k+4|0;Ca=v;Da=Xb;ua=ja;ya=0;Fa=Yb;while(1){Aa=Da+1|0;Sa=d[Da]|0;c[Ra>>2]=Sa;if(oa){c[Pa>>2]=d[Aa]|0;Zb=Da+2|0}else{Zb=Aa}e:do{if((Fa|0)>0){Aa=ua;ra=0;va=Sa;while(1){Wa=Ca+(ra*36|0)+4|0;Ua=b[Wa>>1]|0;Va=va&15;Za=(a[1438808+Va|0]|0)+Ua|0;if((Za|0)<0){_b=0}else{_b=(Za|0)>88?88:Za&65535}Za=(ca(Va<<1&14|1,b[1437984+(Ua<<1)>>1]|0)|0)>>3;Ua=Ca+(ra*36|0)|0;Va=(c[Ua>>2]|0)+((va&8|0)==0?Za:-Za|0)|0;if((Va+32768|0)>>>0>65535>>>0){$b=(Va>>31^32767)&65535}else{$b=Va&65535}c[Ua>>2]=$b<<16>>16;b[Wa>>1]=_b;ac=Aa+2|0;b[Aa>>1]=$b;Wa=ra+1|0;bc=c[y>>2]|0;if((Wa|0)>=(bc|0)){break}Aa=ac;ra=Wa;va=c[k+(Wa<<2)>>2]|0}if((bc|0)>0){cc=ac;dc=0;ec=Sa}else{fc=ac;gc=bc;break}while(1){va=ec>>>4;ra=Ca+(dc*36|0)+4|0;Aa=b[ra>>1]|0;Wa=va<<24>>24;Ua=(a[1438808+Wa|0]|0)+Aa|0;if((Ua|0)<0){hc=0}else{hc=(Ua|0)>88?88:Ua&65535}Ua=(ca(va<<1&14|1,b[1437984+(Aa<<1)>>1]|0)|0)>>3;Aa=Ca+(dc*36|0)|0;va=(c[Aa>>2]|0)+((Wa&8|0)==0?Ua:-Ua|0)|0;if((va+32768|0)>>>0>65535>>>0){ic=(va>>31^32767)&65535}else{ic=va&65535}c[Aa>>2]=ic<<16>>16;b[ra>>1]=hc;ra=cc+2|0;b[cc>>1]=ic;Aa=dc+1|0;va=c[y>>2]|0;if((Aa|0)>=(va|0)){fc=ra;gc=va;break e}cc=ra;dc=Aa;ec=c[k+(Aa<<2)>>2]|0}}else{fc=ua;gc=Fa}}while(0);Sa=ya+1|0;if((Sa|0)<(Qa|0)){Da=Zb;ua=fc;ya=Sa;Fa=gc}else{Oa=Zb;break}}}else if((qa|0)==69657){if((E|0)>0){jc=M;kc=0}else{Oa=M;break}while(1){Fa=ia+(kc<<2)|0;ya=c[Fa>>2]|0;ua=jc;Da=(d[ua]|d[ua+1|0]<<8)<<16>>16;ua=Da&15;c[p>>2]=c[1515328+(ua<<2)>>2];c[p+16>>2]=c[1515328+(ua+4<<2)>>2];b[ya>>1]=Da&-16;Da=jc+2|0;ua=(d[Da]|d[Da+1|0]<<8)<<16>>16;c[q>>2]=20-(ua&15);b[ya+2>>1]=ua&-16;ua=jc+4|0;Da=(d[ua]|d[ua+1|0]<<8)<<16>>16;ua=Da&15;c[p+4>>2]=c[1515328+(ua<<2)>>2];c[p+20>>2]=c[1515328+(ua+4<<2)>>2];b[ya+64>>1]=Da&-16;Da=jc+6|0;ua=(d[Da]|d[Da+1|0]<<8)<<16>>16;c[q+4>>2]=20-(ua&15);b[ya+66>>1]=ua&-16;ua=jc+8|0;Da=(d[ua]|d[ua+1|0]<<8)<<16>>16;ua=Da&15;c[p+8>>2]=c[1515328+(ua<<2)>>2];c[p+24>>2]=c[1515328+(ua+4<<2)>>2];b[ya+128>>1]=Da&-16;Da=jc+10|0;ua=(d[Da]|d[Da+1|0]<<8)<<16>>16;c[q+8>>2]=20-(ua&15);b[ya+130>>1]=ua&-16;ua=jc+12|0;Da=(d[ua]|d[ua+1|0]<<8)<<16>>16;ua=Da&15;c[p+12>>2]=c[1515328+(ua<<2)>>2];c[p+28>>2]=c[1515328+(ua+4<<2)>>2];b[ya+192>>1]=Da&-16;Da=jc+14|0;ua=(d[Da]|d[Da+1|0]<<8)<<16>>16;c[q+12>>2]=20-(ua&15);b[ya+194>>1]=ua&-16;ua=jc+16|0;ya=2;while(1){Da=ua;Qa=(c[Fa>>2]|0)+(ya<<1)|0;Ca=0;while(1){Pa=d[Da]|0;Ra=c[q+(Ca<<2)>>2]|0;Sa=b[Qa-2>>1]|0;ta=c[p+(Ca<<2)>>2]|0;Aa=ca(Sa,ta)|0;ra=c[p+16+(Ca<<2)>>2]|0;va=Aa+128+(Pa>>>4<<28>>28<<Ra)+(ca(b[Qa-4>>1]|0,ra)|0)|0;Aa=va>>8;if((Aa+32768|0)>>>0>65535>>>0){lc=(va>>31^32767)&65535}else{lc=Aa&65535}b[Qa>>1]=lc;Aa=(Pa<<28>>28<<Ra)+128+(ca(ta,lc<<16>>16)|0)+(ca(Sa,ra)|0)|0;ra=Aa>>8;if((ra+32768|0)>>>0>65535>>>0){mc=(Aa>>31^32767)&65535}else{mc=ra&65535}b[Qa+2>>1]=mc;ra=Ca+1|0;if((ra|0)>=4){break}Da=Da+1|0;Qa=Qa+64|0;Ca=ra}Ca=ya+2|0;if((Ca|0)<32){ua=ua+4|0;ya=Ca}else{break}}ya=jc+76|0;ua=kc+1|0;if((ua|0)<(E|0)){jc=ya;kc=ua}else{Oa=ya;break}}}else if((qa|0)==69634){ya=ja+((ca(E,na)|0)<<1)|0;ua=M+10|0;Fa=(d[ua]|d[ua+1|0]<<8)<<16>>16<<16>>16;ua=v;c[ua>>2]=Fa;Ca=M+12|0;Qa=(d[Ca]|d[Ca+1|0]<<8)<<16>>16<<16>>16;Ca=v+36|0;c[Ca>>2]=Qa;Da=a[M+14|0]|0;ra=v+4|0;b[ra>>1]=Da&255;Aa=a[M+15|0]|0;Sa=v+40|0;b[Sa>>1]=Aa&255;if((Da&255)>>>0>88>>>0|(Aa&255)>>>0>88>>>0){KIb(e,16,2184912,(w=i,i=i+16|0,c[w>>2]=Da&255,c[w+8>>2]=Aa&255,w)|0);i=w;ma=-1094995529;i=j;return ma|0}Aa=M+16|0;if(ja>>>0<ya>>>0){Da=Aa;ta=0;Ra=0;Pa=ja;va=Fa;Fa=Qa;while(1){if((ta|0)==0){Qa=a[Da]|0;nc=(Qa&255)>>>4;oc=Qa&15;pc=1;qc=Da+1|0}else{nc=Ra;oc=Ra;pc=0;qc=Da}Qa=b[ra>>1]|0;Ua=oc<<24>>24;Wa=(a[1438808+Ua|0]|0)+Qa|0;if((Wa|0)<0){rc=0}else{rc=(Wa|0)>88?88:Wa&65535}Wa=(ca(b[1437984+(Qa<<1)>>1]|0,Ua<<1&14|1)|0)>>3;Qa=va+((Ua&8|0)==0?Wa:-Wa|0)|0;if((Qa+32768|0)>>>0>65535>>>0){sc=(Qa>>31^32767)&65535}else{sc=Qa&65535}Qa=sc<<16>>16;c[ua>>2]=Qa;b[ra>>1]=rc;if(pc){tc=nc;uc=nc;vc=0;wc=qc}else{Wa=a[qc]|0;tc=(Wa&255)>>>4;uc=Wa&15;vc=1;wc=qc+1|0}Wa=b[Sa>>1]|0;Ua=uc<<24>>24;Va=(a[1438808+Ua|0]|0)+Wa|0;if((Va|0)<0){xc=0}else{xc=(Va|0)>88?88:Va&65535}Va=(ca(b[1437984+(Wa<<1)>>1]|0,Ua<<1&14|1)|0)>>3;Wa=Fa+((Ua&8|0)==0?Va:-Va|0)|0;if((Wa+32768|0)>>>0>65535>>>0){yc=(Wa>>31^32767)&65535}else{yc=Wa&65535}Wa=yc<<16>>16;c[Ca>>2]=Wa;b[Sa>>1]=xc;b[Pa>>1]=sc+yc;b[Pa+2>>1]=sc-yc;if(vc){zc=tc;Ac=tc;Bc=0;Cc=wc}else{Va=a[wc]|0;zc=(Va&255)>>>4;Ac=Va&15;Bc=1;Cc=wc+1|0}Va=b[ra>>1]|0;Ua=Ac<<24>>24;Za=(a[1438808+Ua|0]|0)+Va|0;if((Za|0)<0){Dc=0}else{Dc=(Za|0)>88?88:Za&65535}Za=(ca(b[1437984+(Va<<1)>>1]|0,Ua<<1&14|1)|0)>>3;Va=Qa+((Ua&8|0)==0?Za:-Za|0)|0;if((Va+32768|0)>>>0>65535>>>0){Ec=(Va>>31^32767)&65535}else{Ec=Va&65535}Va=Ec<<16>>16;c[ua>>2]=Va;b[ra>>1]=Dc;b[Pa+4>>1]=Ec+yc;Za=Pa+8|0;b[Pa+6>>1]=Ec-yc;if(Za>>>0<ya>>>0){Da=Cc;ta=Bc;Ra=zc;Pa=Za;va=Va;Fa=Wa}else{Fc=Cc;break}}}else{Fc=Aa}Fa=Fc;if((Fa-s&1|0)==0){Oa=Fc;break}va=x-Fa|0;Oa=Fc+(va>>>0>1>>>0?1:va)|0}else if((qa|0)==69651){va=M;Fa=(d[va]|d[va+1|0]<<8)<<16>>16<<16>>16;va=v;c[va>>2]=Fa;Pa=M+2|0;Ra=(d[Pa]|d[Pa+1|0]<<8)<<16>>16;Pa=v+4|0;b[Pa>>1]=Ra;if((Ra&65535)>>>0>88>>>0){KIb(e,16,2180704,(w=i,i=i+8|0,c[w>>2]=Ra<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}ta=M+8|0;Da=na>>(pa^1);if((Da|0)<=0){Oa=ta;break}ya=Da+8|0;ra=ta;ta=ja;ua=Da;Da=Fa;Fa=Ra;while(1){Ra=a[ra]|0;Sa=Fa<<16>>16;Ca=(Ra&255)>>>4&255;Wa=(a[1438808+Ca|0]|0)+Sa|0;if((Wa|0)<0){Gc=0}else{Gc=(Wa|0)>88?88:Wa&65535}Wa=(ca(Ca<<1&14|1,b[1437984+(Sa<<1)>>1]|0)|0)>>3;Sa=Da+((Ca&8|0)==0?Wa:-Wa|0)|0;if((Sa+32768|0)>>>0>65535>>>0){Hc=(Sa>>31^32767)&65535}else{Hc=Sa&65535}Sa=Hc<<16>>16;c[va>>2]=Sa;b[Pa>>1]=Gc;b[ta>>1]=Hc;Wa=b[Pa>>1]|0;Ca=Ra&15;Ra=(a[1438808+Ca|0]|0)+Wa|0;if((Ra|0)<0){Ic=0}else{Ic=(Ra|0)>88?88:Ra&65535}Ra=(ca(b[1437984+(Wa<<1)>>1]|0,Ca<<1&14|1)|0)>>3;Wa=Sa+((Ca&8|0)==0?Ra:-Ra|0)|0;if((Wa+32768|0)>>>0>65535>>>0){Jc=(Wa>>31^32767)&65535}else{Jc=Wa&65535}Wa=Jc<<16>>16;c[va>>2]=Wa;b[Pa>>1]=Ic;b[ta+2>>1]=Jc;Ra=ua-1|0;if((Ra|0)<=0){break}ra=ra+1|0;ta=ta+4|0;ua=Ra;Da=Wa;Fa=b[Pa>>1]|0}Oa=M+ya|0}else if((qa|0)==69636){do{if((c[v+216>>2]|0)==3){if((E|0)<=0){break}Pa=(na|0)/2|0;Fa=(na|0)>1;Da=v;ua=-Pa|0;ta=Pa+((ua|0)>-1?ua:-1)+1|0;ua=M;ra=0;va=E;while(1){if(Fa){Aa=Da+(ra*36|0)+4|0;Wa=Da+(ra*36|0)|0;Ra=ua;Ca=c[ia+(ra<<2)>>2]|0;Sa=Pa;while(1){Va=a[Ra]|0;Za=b[Aa>>1]|0;Ua=(Va&255)>>>4&255;Qa=(a[1438808+Ua|0]|0)+Za|0;if((Qa|0)<0){Kc=0}else{Kc=(Qa|0)>88?88:Qa&65535}Qa=(ca(Ua<<1&14|1,b[1437984+(Za<<1)>>1]|0)|0)>>3;Za=(c[Wa>>2]|0)+((Ua&8|0)==0?Qa:-Qa|0)|0;if((Za+32768|0)>>>0>65535>>>0){Lc=(Za>>31^32767)&65535}else{Lc=Za&65535}Za=Lc<<16>>16;c[Wa>>2]=Za;b[Aa>>1]=Kc;b[Ca>>1]=Lc;Qa=b[Aa>>1]|0;Ua=Va&15;Va=(a[1438808+Ua|0]|0)+Qa|0;if((Va|0)<0){Mc=0}else{Mc=(Va|0)>88?88:Va&65535}Va=(ca(b[1437984+(Qa<<1)>>1]|0,Ua<<1&14|1)|0)>>3;Qa=Za+((Ua&8|0)==0?Va:-Va|0)|0;if((Qa+32768|0)>>>0>65535>>>0){Nc=(Qa>>31^32767)&65535}else{Nc=Qa&65535}c[Wa>>2]=Nc<<16>>16;b[Aa>>1]=Mc;b[Ca+2>>1]=Nc;Qa=Sa-1|0;if((Qa|0)>0){Ra=Ra+1|0;Ca=Ca+4|0;Sa=Qa}else{break}}Oc=ua+ta|0;Pc=c[y>>2]|0}else{Oc=ua;Pc=va}Sa=ra+1|0;if((Sa|0)<(Pc|0)){ua=Oc;ra=Sa;va=Pc}else{break}}}else{if((na|0)<=1){break}va=v;ra=oa?2:1;ua=M;ta=ja;Pa=(na|0)/2|0;Da=E;while(1){if((Da|0)>0){Fa=ua;Sa=ta;Ca=0;while(1){Ra=Fa+1|0;Aa=a[Fa]|0;Wa=va+(Ca*36|0)+4|0;Qa=b[Wa>>1]|0;Va=(Aa&255)>>>4&255;Ua=(a[1438808+Va|0]|0)+Qa|0;if((Ua|0)<0){Qc=0}else{Qc=(Ua|0)>88?88:Ua&65535}Ua=(ca(Va<<1&14|1,b[1437984+(Qa<<1)>>1]|0)|0)>>3;Qa=va+(Ca*36|0)|0;Za=(c[Qa>>2]|0)+((Va&8|0)==0?Ua:-Ua|0)|0;if((Za+32768|0)>>>0>65535>>>0){Rc=(Za>>31^32767)&65535}else{Rc=Za&65535}Za=Rc<<16>>16;c[Qa>>2]=Za;b[Wa>>1]=Qc;Ua=Sa+2|0;b[Sa>>1]=Rc;Va=b[Wa>>1]|0;Ga=Aa&15;Aa=(a[1438808+Ga|0]|0)+Va|0;if((Aa|0)<0){Sc=0}else{Sc=(Aa|0)>88?88:Aa&65535}Aa=(ca(b[1437984+(Va<<1)>>1]|0,Ga<<1&14|1)|0)>>3;Va=Za+((Ga&8|0)==0?Aa:-Aa|0)|0;if((Va+32768|0)>>>0>65535>>>0){Tc=(Va>>31^32767)&65535}else{Tc=Va&65535}c[Qa>>2]=Tc<<16>>16;b[Wa>>1]=Sc;b[Sa+(ra<<1)>>1]=Tc;Wa=Ca+1|0;Qa=c[y>>2]|0;if((Wa|0)<(Qa|0)){Fa=Ra;Sa=Ua;Ca=Wa}else{Uc=Ra;Vc=Ua;Wc=Qa;break}}}else{Uc=ua;Vc=ta;Wc=Da}Ca=Pa-1|0;if((Ca|0)>0){ua=Uc;ta=Vc+(Wc<<1)|0;Pa=Ca;Da=Wc}else{break}}}}while(0);Oa=s+((-h|0)>0?0:h)|0}else if((qa|0)==69647|(qa|0)==69648|(qa|0)==69649){ya=v;Da=v+4|0;if((b[Da>>1]|0)==0){Pa=M+1|0;ta=ga+2|0;b[ja>>1]=(d[M]<<7)-16384;if(oa){b[ta>>1]=(d[Pa]<<7)-16384;Xc=ga+4|0;Yc=M+2|0}else{Xc=ta;Yc=Pa}b[Da>>1]=1;Zc=Xc;_c=na-1|0;$c=Yc}else{Zc=ja;_c=na;$c=M}if((qa|0)==69648){Da=_c<<pa;if((Da|0)<=2){Oa=$c;break}Pa=(Da|0)/3|0;Da=v+8|0;ta=v;ua=-Pa|0;ra=Pa+((ua|0)>-1?ua:-1)+1|0;ua=$c;va=Zc;Ca=Pa;Pa=c[Da>>2]|0;Sa=c[ta>>2]|0;while(1){Fa=ua+1|0;Qa=a[ua]|0;Ua=(Qa&255)>>>5&255;Ra=Ua&3;Wa=Ra<<Pa+7;Va=((Ua&4|0)!=0?-Wa|0:Wa)+Sa|0;if((Va|0)<-16384){ad=-16384}else{ad=(Va|0)>16256?16256:Va}c[ta>>2]=ad;do{if((Ra|0)==3&(Pa|0)<3){Va=Pa+1|0;c[Da>>2]=Va;bd=Va}else{if(!((Ra|0)==0&(Pa|0)>0)){bd=Pa;break}Va=Pa-1|0;c[Da>>2]=Va;bd=Va}}while(0);Ra=va+2|0;b[va>>1]=ad;Va=(Qa&255)>>>2&7;Wa=Va&3;Ua=Wa<<bd+7;Aa=((Va&4|0)!=0?-Ua|0:Ua)+ad|0;if((Aa|0)<-16384){cd=-16384}else{cd=(Aa|0)>16256?16256:Aa}c[ta>>2]=cd;do{if((Wa|0)==3&(bd|0)<3){Aa=bd+1|0;c[Da>>2]=Aa;dd=Aa}else{if(!((Wa|0)==0&(bd|0)>0)){dd=bd;break}Aa=bd-1|0;c[Da>>2]=Aa;dd=Aa}}while(0);Wa=va+4|0;b[Ra>>1]=cd;Aa=Qa&3;Ua=Aa&1;Va=Ua<<dd+7;Ga=((Aa&2|0)!=0?-Va|0:Va)+cd|0;if((Ga|0)<-16384){ed=-16384}else{ed=(Ga|0)>16256?16256:Ga}c[ta>>2]=ed;do{if((Ua|0)!=0&(dd|0)<3){Ga=dd+1|0;c[Da>>2]=Ga;fd=Ga}else{if(!((Ua|0)==0&(dd|0)>0)){fd=dd;break}Ga=dd-1|0;c[Da>>2]=Ga;fd=Ga}}while(0);b[Wa>>1]=ed;Ua=Ca-1|0;if((Ua|0)>0){ua=Fa;va=va+6|0;Ca=Ua;Pa=fd;Sa=ed}else{break}}Oa=$c+ra|0;break}else if((qa|0)==69647){Sa=_c>>(pa^1);if((Sa|0)<=0){Oa=$c;break}Pa=v+8|0;Ca=v;va=ya+(pa*36|0)+8|0;ua=ya+(pa*36|0)|0;Da=$c;ta=Zc;Ua=Sa;while(1){Qa=Da+1|0;Ra=a[Da]|0;Ga=(Ra&255)>>>4&255;Va=Ga&7;Aa=c[Pa>>2]|0;Za=Va<<Aa+7;sa=((Ga&8|0)!=0?-Za|0:Za)+(c[Ca>>2]|0)|0;if((sa|0)<-16384){gd=-16384}else{gd=(sa|0)>16256?16256:sa}c[Ca>>2]=gd;do{if(Va>>>0>4>>>0&(Aa|0)<3){c[Pa>>2]=Aa+1}else{if(!((Va|0)==0&(Aa|0)>0)){break}c[Pa>>2]=Aa-1}}while(0);Aa=ta+2|0;b[ta>>1]=gd;Va=Ra&15;Fa=Va&7;Wa=c[va>>2]|0;sa=Fa<<Wa+7;Za=((Va&8|0)!=0?-sa|0:sa)+(c[ua>>2]|0)|0;if((Za|0)<-16384){hd=-16384}else{hd=(Za|0)>16256?16256:Za}c[ua>>2]=hd;do{if(Fa>>>0>4>>>0&(Wa|0)<3){c[va>>2]=Wa+1}else{if(!((Fa|0)==0&(Wa|0)>0)){break}c[va>>2]=Wa-1}}while(0);b[Aa>>1]=hd;Wa=Ua-1|0;if((Wa|0)>0){Da=Qa;ta=ta+4|0;Ua=Wa}else{break}}Oa=$c+Sa|0;break}else{Ua=_c>>2-pa;if((Ua|0)<=0){Oa=$c;break}ta=v+8|0;Da=v;va=ya+(pa*36|0)+8|0;ua=ya+(pa*36|0)|0;Pa=$c;Ca=Zc;ra=Ua;while(1){Wa=Pa+1|0;Fa=a[Pa]|0;Ra=(Fa&255)>>>6&255;Za=Ra&1;sa=c[ta>>2]|0;Va=Za<<sa+9;Ga=((Ra&2|0)!=0?-Va|0:Va)+(c[Da>>2]|0)|0;if((Ga|0)<-16384){id=-16384}else{id=(Ga|0)>16256?16256:Ga}c[Da>>2]=id;do{if((Za|0)!=0&(sa|0)<3){c[ta>>2]=sa+1}else{if(!((Za|0)==0&(sa|0)>0)){break}c[ta>>2]=sa-1}}while(0);sa=Ca+2|0;b[Ca>>1]=id;Za=(Fa&255)>>>4&3;Qa=Za&1;Aa=c[va>>2]|0;Ga=Qa<<Aa+9;Va=((Za&2|0)!=0?-Ga|0:Ga)+(c[ua>>2]|0)|0;if((Va|0)<-16384){jd=-16384}else{jd=(Va|0)>16256?16256:Va}c[ua>>2]=jd;do{if((Qa|0)!=0&(Aa|0)<3){c[va>>2]=Aa+1}else{if(!((Qa|0)==0&(Aa|0)>0)){break}c[va>>2]=Aa-1}}while(0);Aa=Ca+4|0;b[sa>>1]=jd;Qa=(Fa&255)>>>2&3;Va=Qa&1;Ga=c[ta>>2]|0;Za=Va<<Ga+9;Ra=((Qa&2|0)!=0?-Za|0:Za)+(c[Da>>2]|0)|0;if((Ra|0)<-16384){kd=-16384}else{kd=(Ra|0)>16256?16256:Ra}c[Da>>2]=kd;do{if((Va|0)!=0&(Ga|0)<3){c[ta>>2]=Ga+1}else{if(!((Va|0)==0&(Ga|0)>0)){break}c[ta>>2]=Ga-1}}while(0);Ga=Ca+6|0;b[Aa>>1]=kd;Va=Fa&3;sa=Va&1;Ra=c[va>>2]|0;Za=sa<<Ra+9;Qa=((Va&2|0)!=0?-Za|0:Za)+(c[ua>>2]|0)|0;if((Qa|0)<-16384){ld=-16384}else{ld=(Qa|0)>16256?16256:Qa}c[ua>>2]=ld;do{if((sa|0)!=0&(Ra|0)<3){c[va>>2]=Ra+1}else{if(!((sa|0)==0&(Ra|0)>0)){break}c[va>>2]=Ra-1}}while(0);b[Ga>>1]=ld;Ra=ra-1|0;if((Ra|0)>0){Pa=Wa;Ca=Ca+8|0;ra=Ra}else{break}}Oa=$c+Ua|0;break}}else if((qa|0)==69661){if((x|0)==(M|0)){Oa=x;break}ra=v;Ca=v+4|0;Pa=v;va=ra+(pa*36|0)+4|0;ua=ra+(pa*36|0)|0;ra=M;ta=ja;while(1){Da=ra+1|0;ya=a[ra]|0;Sa=b[Ca>>1]|0;Ra=(ya&255)>>>4&255;sa=(a[1438808+Ra|0]|0)+Sa|0;if((sa|0)<0){md=0}else{md=(sa|0)>88?88:sa&65535}sa=(ca(Ra<<1&14|1,b[1437984+(Sa<<1)>>1]|0)|0)>>3;Sa=(c[Pa>>2]|0)+((Ra&8|0)==0?sa:-sa|0)|0;if((Sa+32768|0)>>>0>65535>>>0){nd=(Sa>>31^32767)&65535}else{nd=Sa&65535}c[Pa>>2]=nd<<16>>16;b[Ca>>1]=md;b[ta>>1]=nd;Sa=b[va>>1]|0;sa=ya&15;ya=(a[1438808+sa|0]|0)+Sa|0;if((ya|0)<0){od=0}else{od=(ya|0)>88?88:ya&65535}ya=(ca(b[1437984+(Sa<<1)>>1]|0,sa<<1&14|1)|0)>>3;Sa=(c[ua>>2]|0)+((sa&8|0)==0?ya:-ya|0)|0;if((Sa+32768|0)>>>0>65535>>>0){pd=(Sa>>31^32767)&65535}else{pd=Sa&65535}c[ua>>2]=pd<<16>>16;b[va>>1]=od;b[ta+2>>1]=pd;if((x|0)==(Da|0)){Oa=x;break}else{ra=Da;ta=ta+4|0}}}else if((qa|0)==69645){ta=h<<3;ra=ta>>>0>2147483639>>>0|(s|0)==0;va=ra?0:s;ua=ra?8:ta+8|0;ra=va;Ca=(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)>>>6&3;ra=ua>>>0>2>>>0?2:ua;Pa=Ca+2|0;Ua=1<<Ca;Da=1<<Ca+1;if((ra|0)<=((E*-22|0)+ta|0)){Sa=30-Ca|0;ya=c[u>>2]|0;sa=~Da;Ra=ra;ra=ja;Fa=E;while(1){if((Fa|0)>0){Aa=Ra;Qa=0;Za=ra;while(1){Va=va+(Aa>>>3)|0;Ba=(je(d[Va]|d[Va+1|0]<<8|d[Va+2|0]<<16|d[Va+3|0]<<24|0)|0)<<(Aa&7)>>16;Va=Aa+16|0;xa=ua>>>0>Va>>>0?Va:ua;c[ya+(Qa*36|0)>>2]=Ba;Va=Za+2|0;b[Za>>1]=Ba;Ba=va+(xa>>>3)|0;za=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(xa&7)>>>26;Ba=xa+6|0;xa=ua>>>0>Ba>>>0?Ba:ua;b[ya+(Qa*36|0)+4>>1]=za;za=Qa+1|0;Ba=c[y>>2]|0;if((za|0)<(Ba|0)){Aa=xa;Qa=za;Za=Va}else{qd=xa;rd=Va;sd=Ba;break}}}else{qd=Ra;rd=ra;sd=Fa}if((qd|0)>(ta-(ca(sd,Pa)|0)|0)){td=qd;ud=rd;vd=sd}else{Za=qd;Qa=0;Aa=rd;Wa=sd;while(1){if((Wa|0)>0){Ga=Za;Ba=0;Va=Aa;while(1){xa=va+(Ga>>>3)|0;za=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ga&7)>>>(Sa>>>0);xa=Ga+Pa|0;wa=ya+(Ba*36|0)+4|0;Ea=b[wa>>1]|0;Ya=Ua;Qb=0;Pb=b[1437984+(Ea<<16>>16<<1)>>1]|0;do{Qb=((Ya&za|0)==0?0:Pb)+Qb|0;Pb=Pb>>1;Ya=Ya>>1;}while((Ya|0)!=0);Ya=ua>>>0>xa>>>0?xa:ua;Ta=Qb+Pb|0;wd=ya+(Ba*36|0)|0;xd=(c[wd>>2]|0)+((za&Da|0)==0?Ta:-Ta|0)|0;c[wd>>2]=xd;Ta=(c[525496+(Ca<<6)+((za&sa)<<2)>>2]|0)+(Ea&65535)|0;yd=Ta<<16;if((yd|0)<0){zd=0}else{zd=(yd|0)>5767168?88:Ta&65535}b[wa>>1]=zd;if((xd+32768|0)>>>0>65535>>>0){Ad=(xd>>31^32767)&65535}else{Ad=xd&65535}c[wd>>2]=Ad<<16>>16;wd=Va+2|0;b[Va>>1]=Ad;xd=Ba+1|0;Ta=c[y>>2]|0;if((xd|0)<(Ta|0)){Ga=Ya;Ba=xd;Va=wd}else{Bd=Ya;Cd=wd;Dd=Ta;break}}}else{Bd=Za;Cd=Aa;Dd=Wa}Va=Qa+1|0;if((Bd|0)<=(ta-(ca(Dd,Pa)|0)|0)&(Va|0)<4095){Za=Bd;Qa=Va;Aa=Cd;Wa=Dd}else{td=Bd;ud=Cd;vd=Dd;break}}}if((td|0)>((vd*-22|0)+ta|0)){break}else{Ra=td;ra=ud;Fa=vd}}}Oa=s+((-h|0)>0?0:h)|0}else if((qa|0)==1146374944){if((E|0)<=0){Oa=M;break}Fa=(na|0)/28|0;ra=(na|0)>27;Ra=s+((h|0)<0?h:0)|0;ta=v;Pa=M;sa=0;Ca=32;while(1){Da=(sa|0)!=0;if(ra){ya=4-sa|0;ua=ta+(sa*36|0)+16|0;Ua=ta+(sa*36|0)+20|0;Sa=Pa;va=c[ia+(sa<<2)>>2]|0;Wa=0;while(1){Aa=Da?Sa+1|0:Sa;Qa=d[Aa]|0;Za=Qa>>>4;Va=Qa&15;Qa=va+56|0;Ba=Aa+ya|0;Ga=va;Ta=0;while(1){if((Za|0)==1){Ed=(c[ua>>2]|0)*60|0;C=647}else if((Za|0)==2){Ed=((c[Ua>>2]|0)*-52|0)+((c[ua>>2]|0)*115|0)|0;C=647}else if((Za|0)==3){Ed=((c[Ua>>2]|0)*-55|0)+((c[ua>>2]|0)*98|0)|0;C=647}else{Fd=0;C=648}if((C|0)==647){C=0;wd=Ed+32>>6;if((wd|0)<-2097152){Gd=-2097152}else{Fd=wd;C=648}}if((C|0)==648){C=0;Gd=(Fd|0)>2097151?2097151:Fd}wd=d[Ba]|0;Ya=((Da?wd>>>4:wd)<<28>>16>>Va<<6)+Gd|0;wd=Ya>>6;if((wd+32768|0)>>>0>65535>>>0){Id=(Ya>>31^32767)&65535}else{Id=wd&65535}b[Ga>>1]=Id;c[Ua>>2]=c[ua>>2];c[ua>>2]=Ya;Ya=Ta+1|0;if((Ya|0)<28){Ba=Ba+1|0;Ga=Ga+2|0;Ta=Ya}else{break}}Ta=Aa+Ca|0;Ga=Wa+1|0;if((Ga|0)<(Fa|0)){Sa=Ta;va=Qa;Wa=Ga}else{Jd=Ta;break}}}else{Jd=Pa}Wa=Da?Jd:Ra;va=sa+1|0;if((va|0)<(c[y>>2]|0)){Pa=Wa;sa=va;Ca=Ca-1|0}else{Oa=Wa;break}}}else if((qa|0)==69639){if((E|0)<=0){Oa=M;break}Ca=v;sa=M;Pa=0;while(1){Kd=sa+2|0;Ra=sa;c[Ca+(Pa*36|0)>>2]=(d[Ra]|d[Ra+1|0]<<8)<<16>>16<<16>>16;Ra=Pa+1|0;Ld=c[y>>2]|0;if((Ra|0)<(Ld|0)){sa=Kd;Pa=Ra}else{break}}Pa=(Ld|0)>0;if(!Pa){Oa=Kd;break}sa=v;Ca=Kd;Ra=0;while(1){Fa=Ca;Md=(d[Fa]|d[Fa+1|0]<<8)<<16>>16;b[sa+(Ra*36|0)+4>>1]=Md;if((Md&65535)>>>0>88>>>0){C=152;break}Nd=Ca+2|0;Fa=Ra+1|0;if((Fa|0)<(Ld|0)){Ca=Nd;Ra=Fa}else{break}}if((C|0)==152){KIb(e,16,2192512,(w=i,i=i+16|0,c[w>>2]=Ra,c[w+8>>2]=Md<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}if(!Pa){Oa=Nd;break}Ca=v;sa=na>>1;Fa=(sa|0)>0;ta=Nd;ra=0;Wa=Ld;while(1){if(Fa){va=Ca+(ra*36|0)+4|0;Sa=Ca+(ra*36|0)|0;ua=ta;Ua=c[B+(ra<<2)>>2]|0;ya=sa;while(1){Ta=a[ua]|0;Ga=b[va>>1]|0;Ba=Ta&15;Va=(a[1438808+Ba|0]|0)+Ga|0;if((Va|0)<0){Od=0}else{Od=(Va|0)>88?88:Va&65535}Va=(ca(Ba<<1&14|1,b[1437984+(Ga<<1)>>1]|0)|0)>>4;Ga=(c[Sa>>2]|0)+((Ba&8|0)==0?Va:-Va|0)|0;if((Ga+32768|0)>>>0>65535>>>0){Pd=(Ga>>31^32767)&65535}else{Pd=Ga&65535}Ga=Pd<<16>>16;c[Sa>>2]=Ga;b[va>>1]=Od;b[Ua>>1]=Pd;Va=b[va>>1]|0;Ba=(Ta&255)>>>4&255;Ta=(a[1438808+Ba|0]|0)+Va|0;if((Ta|0)<0){Qd=0}else{Qd=(Ta|0)>88?88:Ta&65535}Ta=(ca(b[1437984+(Va<<1)>>1]|0,Ba<<1&14|1)|0)>>4;Va=Ga+((Ba&8|0)==0?Ta:-Ta|0)|0;if((Va+32768|0)>>>0>65535>>>0){Rd=(Va>>31^32767)&65535}else{Rd=Va&65535}c[Sa>>2]=Rd<<16>>16;b[va>>1]=Qd;b[Ua+2>>1]=Rd;Va=ya-1|0;if((Va|0)>0){ua=ua+1|0;Ua=Ua+4|0;ya=Va}else{break}}Sd=ta+sa|0;Td=c[y>>2]|0}else{Sd=ta;Td=Wa}ya=ra+1|0;if((ya|0)<(Td|0)){ta=Sd;ra=ya;Wa=Td}else{Oa=Sd;break}}}else if((qa|0)==69635){f:do{if((E|0)>0){Wa=v;ra=M;ta=ja;sa=0;while(1){Ca=ra;Fa=(d[Ca]|d[Ca+1|0]<<8)<<16>>16;b[ta>>1]=Fa;c[Wa+(sa*36|0)>>2]=Fa<<16>>16;Fa=ra+2|0;Ud=(d[Fa]|d[Fa+1|0]<<8)<<16>>16;b[Wa+(sa*36|0)+4>>1]=Ud;if((Ud&65535)>>>0>88>>>0){break}Fa=ra+4|0;Ca=ta+2|0;Pa=sa+1|0;if((Pa|0)<(c[y>>2]|0)){ra=Fa;ta=Ca;sa=Pa}else{Vd=Fa;Wd=Ca;break f}}KIb(e,16,2192512,(w=i,i=i+16|0,c[w>>2]=sa,c[w+8>>2]=Ud<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{Vd=M;Wd=ja}}while(0);ta=na-1>>(pa^1);if((ta|0)<=0){Oa=Vd;break}ra=v;Wa=v+4|0;Ca=v;Fa=ra+(pa*36|0)+4|0;Pa=ra+(pa*36|0)|0;ra=Vd;Ra=Wd;ya=ta;while(1){Ua=a[ra]|0;ua=b[Wa>>1]|0;va=(Ua&255)>>>4&255;Sa=(a[1438808+va|0]|0)+ua|0;if((Sa|0)<0){Xd=0}else{Xd=(Sa|0)>88?88:Sa&65535}Sa=(ca(va<<1&14|1,b[1437984+(ua<<1)>>1]|0)|0)>>3;ua=(c[Ca>>2]|0)+((va&8|0)==0?Sa:-Sa|0)|0;if((ua+32768|0)>>>0>65535>>>0){Yd=(ua>>31^32767)&65535}else{Yd=ua&65535}c[Ca>>2]=Yd<<16>>16;b[Wa>>1]=Xd;b[Ra>>1]=Yd;ua=b[Fa>>1]|0;Sa=Ua&15;Ua=(a[1438808+Sa|0]|0)+ua|0;if((Ua|0)<0){Zd=0}else{Zd=(Ua|0)>88?88:Ua&65535}Ua=(ca(b[1437984+(ua<<1)>>1]|0,Sa<<1&14|1)|0)>>3;ua=(c[Pa>>2]|0)+((Sa&8|0)==0?Ua:-Ua|0)|0;if((ua+32768|0)>>>0>65535>>>0){_d=(ua>>31^32767)&65535}else{_d=ua&65535}c[Pa>>2]=_d<<16>>16;b[Fa>>1]=Zd;b[Ra+2>>1]=_d;ua=ya-1|0;if((ua|0)>0){ra=ra+1|0;Ra=Ra+4|0;ya=ua}else{break}}Oa=Vd+ta|0}else if((qa|0)==69652|(qa|0)==69654|(qa|0)==69653){ya=(qa|0)==69653;do{if((E|0)==0){$d=0}else{Ra=x;ra=M;Fa=0;while(1){Pa=(Ra-ra|0)<4;do{if(ya){if(Pa){ae=0;be=ra;break}Wa=ra;ae=je(d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0)|0;be=ra+4|0}else{if(Pa){ae=0;be=ra;break}Wa=ra;ae=d[Wa]|d[Wa+1|0]<<8|d[Wa+2|0]<<16|d[Wa+3|0]<<24|0;be=ra+4|0}}while(0);c[o+(Fa<<2)>>2]=ae+4+(E<<2);Pa=Fa+1|0;if(Pa>>>0<E>>>0){ra=be;Fa=Pa}else{break}}if((E|0)==0){$d=0;break}Fa=x;ra=v;Ra=(na|0)/28|0;sa=(na|0)>27;Pa=e;Qa=(Ra|0)>1?Ra:1;Aa=0;Wa=0;Ca=qa;while(1){ua=c[o+(Aa<<2)>>2]|0;if((ua|0)<0){ce=0}else{ce=(h|0)<(ua|0)?h:ua}ua=s+ce|0;Ua=c[ia+(Aa<<2)>>2]|0;do{if((Ca|0)==69652){if((Fa-ua|0)<2){de=0;ee=ua}else{Sa=ua;de=(d[Sa]|d[Sa+1|0]<<8)<<16>>16<<16>>16;ee=s+(ce+2)|0}if((Fa-ee|0)<2){fe=de;ge=0;ie=ee;break}Sa=ee;fe=de;ge=(d[Sa]|d[Sa+1|0]<<8)<<16>>16<<16>>16;ie=ee+2|0}else{fe=c[ra+(Aa*36|0)>>2]|0;ge=c[ra+(Aa*36|0)+12>>2]|0;ie=ua}}while(0);if(sa){ua=ie;Sa=ge;va=fe;Da=Ua;Va=0;while(1){do{if((Fa-ua|0)<1){ke=ua;le=0;C=421}else{Ta=ua+1|0;Ba=a[ua]|0;if(!(Ba<<24>>24==-18)){ke=Ta;le=Ba&255;C=421;break}if((Fa-Ta|0)<2){me=0;ne=Ta}else{Ba=Ta;me=(he((d[Ba]|d[Ba+1|0]<<8)<<16>>16|0)|0)<<16>>16;ne=ua+3|0}if((Fa-ne|0)<2){oe=0;pe=ne}else{Ba=ne;oe=(he((d[Ba]|d[Ba+1|0]<<8)<<16>>16|0)|0)<<16>>16;pe=ne+2|0}Ba=pe;Ta=Da;Ga=0;while(1){if((Fa-Ba|0)<2){qe=0;re=Ba}else{Za=Ba;qe=he((d[Za]|d[Za+1|0]<<8)<<16>>16|0)|0;re=Ba+2|0}b[Ta>>1]=qe;Za=Ga+1|0;if((Za|0)<28){Ba=re;Ta=Ta+2|0;Ga=Za}else{se=me;te=oe;ue=re;break}}}}while(0);if((C|0)==421){C=0;wa=le>>>4;Ea=c[1515328+(wa<<2)>>2]|0;za=c[1515328+(wa+4<<2)>>2]|0;wa=20-(le&15)|0;Pb=ke;Qb=Sa;xa=va;Ga=Da;Ta=le;Ba=0;while(1){if((Ba&1|0)==0){if((Fa-Pb|0)<1){ve=0;we=Pb}else{ve=d[Pb]|0;we=Pb+1|0}xe=ve;ye=ve>>>4;ze=we}else{xe=Ta;ye=Ta;ze=Pb}Za=(ca(xa,Ea)|0)+(ca(Qb,za)|0)+(ye<<28>>28<<wa)|0;Ya=Za>>8;if((Ya+32768|0)>>>0>65535>>>0){Ae=(Za>>31^32767)&65535}else{Ae=Ya&65535}Ya=Ae<<16>>16;b[Ga>>1]=Ae;Za=Ba+1|0;if((Za|0)<28){Pb=ze;Qb=xa;xa=Ya;Ga=Ga+2|0;Ta=xe;Ba=Za}else{se=Ya;te=xa;ue=ze;break}}}xa=Va+1|0;if((xa|0)<(Ra|0)){ua=ue;Sa=te;va=se;Da=Da+56|0;Va=xa}else{Be=te;Ce=se;De=Qa;break}}}else{Be=ge;Ce=fe;De=0}do{if((Wa|0)==0){Ee=De;Fe=Ca}else{if((Wa|0)==(De|0)){Ee=Wa;Fe=Ca;break}KIb(Pa,24,2182688,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;Ee=(Wa|0)>(De|0)?Wa:De;Fe=c[(c[A>>2]|0)+12>>2]|0}}while(0);if((Fe|0)!=69652){c[ra+(Aa*36|0)>>2]=Ce;c[ra+(Aa*36|0)+12>>2]=Be}Va=Aa+1|0;if(Va>>>0<(c[y>>2]|0)>>>0){Aa=Va;Wa=Ee;Ca=Fe}else{$d=Ee;break}}}}while(0);c[ha>>2]=$d*28|0;Oa=s+((-h|0)>0?0:h)|0}else if((qa|0)==69640){ya=c[ia>>2]|0;ta=c[ia+4>>2]|0;Ca=(3-E|0)*112|0;Wa=x;Aa=M;if(!((Wa-Aa|0)>>>0>127>>>0)){Oa=M;break}ra=s;Pa=e;Qa=v+16|0;Ra=v+20|0;Fa=v+52|0;sa=v+56|0;Va=M;Da=0;va=Aa;Aa=E;while(1){Sa=va-ra|0;ua=ya+(Da<<1)|0;do{if((Aa|0)==1){Ge=ya+(Da+28<<1)|0;He=(3-Aa|0)*28|0;C=313}else{Ua=ta+(Da<<1)|0;xa=(3-Aa|0)*28|0;if((Aa|0)!=2){Ge=Ua;He=xa;C=313;break}Ba=Sa+4|0;Ta=Sa+5|0;Ga=Ua;Ua=ua;Qb=0;while(1){Pb=Qb<<1;wa=a[s+(Ba+Pb)|0]|0;za=wa&255;Ea=12-(za&15)|0;Ya=za>>>4;if((wa&255)>>>0>79>>>0){QIb(Pa,2167360,(w=i,i=i+8|0,c[w>>2]=Ya,w)|0);i=w;Ie=0}else{Ie=Ya}Ya=c[3176+(Ie<<3)>>2]|0;wa=c[3180+(Ie<<3)>>2]|0;za=Qb+16+Sa|0;Za=0;wd=c[Qa>>2]|0;xd=c[Ra>>2]|0;while(1){yd=(d[s+(za+(Za<<2))|0]<<28>>28<<Ea)+((ca(xd,wa)|0)+32+(ca(wd,Ya)|0)>>6)|0;if((yd+32768|0)>>>0>65535>>>0){Je=(yd>>31^32767)&65535}else{Je=yd&65535}Ke=Je<<16>>16;b[Ua+(Za<<1)>>1]=Je;yd=Za+1|0;if((yd|0)<28){Za=yd;xd=wd;wd=Ke}else{break}}c[Qa>>2]=Ke;c[Ra>>2]=wd;xd=c[Fa>>2]|0;Za=c[sa>>2]|0;Ya=a[s+(Ta+Pb)|0]|0;wa=Ya&255;Ea=12-(wa&15)|0;yd=wa>>>4;if((Ya&255)>>>0>79>>>0){QIb(Pa,2167360,(w=i,i=i+8|0,c[w>>2]=yd,w)|0);i=w;Le=0}else{Le=yd}yd=c[3176+(Le<<3)>>2]|0;Ya=c[3180+(Le<<3)>>2]|0;wa=0;Me=xd;xd=Za;while(1){Za=((d[s+(za+(wa<<2))|0]|0)>>>4<<28>>28<<Ea)+((ca(xd,Ya)|0)+32+(ca(Me,yd)|0)>>6)|0;if((Za+32768|0)>>>0>65535>>>0){Ne=(Za>>31^32767)&65535}else{Ne=Za&65535}Oe=Ne<<16>>16;b[Ga+(wa<<1)>>1]=Ne;Za=wa+1|0;if((Za|0)<28){wa=Za;xd=Me;Me=Oe}else{break}}c[Fa>>2]=Oe;c[sa>>2]=Me;xd=Qb+1|0;if((xd|0)<4){Ga=Ga+(xa<<1)|0;Ua=Ua+(xa<<1)|0;Qb=xd}else{break}}}}while(0);if((C|0)==313){C=0;Qb=Sa+4|0;xa=Sa+5|0;Ua=Ge;Ga=ua;Ta=0;while(1){Ba=Ta<<1;xd=a[s+(Qb+Ba)|0]|0;wa=xd&255;yd=12-(wa&15)|0;Ya=wa>>>4;if((xd&255)>>>0>79>>>0){QIb(Pa,2167360,(w=i,i=i+8|0,c[w>>2]=Ya,w)|0);i=w;Pe=0}else{Pe=Ya}Ya=c[3176+(Pe<<3)>>2]|0;xd=c[3180+(Pe<<3)>>2]|0;wa=Ta+16+Sa|0;Ea=0;za=c[Qa>>2]|0;Pb=c[Ra>>2]|0;while(1){wd=(d[s+(wa+(Ea<<2))|0]<<28>>28<<yd)+((ca(Pb,xd)|0)+32+(ca(za,Ya)|0)>>6)|0;if((wd+32768|0)>>>0>65535>>>0){Qe=(wd>>31^32767)&65535}else{Qe=wd&65535}Re=Qe<<16>>16;b[Ga+(Ea<<1)>>1]=Qe;wd=Ea+1|0;if((wd|0)<28){Ea=wd;Pb=za;za=Re}else{break}}Pb=a[s+(xa+Ba)|0]|0;Ea=Pb&255;Ya=12-(Ea&15)|0;xd=Ea>>>4;if((Pb&255)>>>0>79>>>0){QIb(Pa,2167360,(w=i,i=i+8|0,c[w>>2]=xd,w)|0);i=w;Se=0}else{Se=xd}xd=c[3176+(Se<<3)>>2]|0;Pb=c[3180+(Se<<3)>>2]|0;Ea=0;yd=Re;wd=za;while(1){Za=((d[s+(wa+(Ea<<2))|0]|0)>>>4<<28>>28<<Ya)+((ca(wd,Pb)|0)+32+(ca(yd,xd)|0)>>6)|0;if((Za+32768|0)>>>0>65535>>>0){Te=(Za>>31^32767)&65535}else{Te=Za&65535}Ue=Te<<16>>16;b[Ua+(Ea<<1)>>1]=Te;Za=Ea+1|0;if((Za|0)<28){Ea=Za;wd=yd;yd=Ue}else{break}}c[Qa>>2]=Ue;c[Ra>>2]=yd;wd=Ta+1|0;if((wd|0)<4){Ua=Ua+(He<<1)|0;Ga=Ga+(He<<1)|0;Ta=wd}else{break}}}Ta=Va+128|0;Ga=Ta;if(!((Wa-Ga|0)>>>0>127>>>0)){Oa=Ta;break b}Va=Ta;Da=Da+Ca|0;va=Ga;Aa=c[y>>2]|0}}else if((qa|0)==69659){g:do{if((E|0)>0){Aa=v;va=M;Ca=0;while(1){Da=va;c[Aa+(Ca*36|0)>>2]=(d[Da]|d[Da+1|0]<<8)<<16>>16<<16>>16;Da=va+2|0;Ve=(d[Da]|d[Da+1|0]<<8)<<16>>16;b[Aa+(Ca*36|0)+4>>1]=Ve;if((Ve&65535)>>>0>88>>>0){break}Da=va+4|0;Va=Ca+1|0;if((Va|0)<(c[y>>2]|0)){va=Da;Ca=Va}else{We=Da;break g}}KIb(e,16,2192512,(w=i,i=i+16|0,c[w>>2]=Ca,c[w+8>>2]=Ve<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{We=M}}while(0);va=na>>(pa^1);if((va|0)<=0){Oa=We;break}Aa=v;Da=v+4|0;Va=v;Wa=Aa+(pa*36|0)+4|0;Ra=Aa+(pa*36|0)|0;Aa=We;Qa=ja;Pa=va;while(1){sa=a[Aa]|0;Fa=(sa&255)>>>4;if(oa){Xe=Fa&255;Ye=sa&15}else{Xe=sa&15;Ye=Fa&255}Fa=b[Da>>1]|0;sa=Xe<<24>>24;ta=(a[1438808+sa|0]|0)+Fa|0;if((ta|0)<0){Ze=0}else{Ze=(ta|0)>88?88:ta&65535}ta=(ca(sa<<1&14|1,b[1437984+(Fa<<1)>>1]|0)|0)>>3;Fa=(c[Va>>2]|0)+((sa&8|0)==0?ta:-ta|0)|0;if((Fa+32768|0)>>>0>65535>>>0){_e=(Fa>>31^32767)&65535}else{_e=Fa&65535}c[Va>>2]=_e<<16>>16;b[Da>>1]=Ze;b[Qa>>1]=_e;Fa=b[Wa>>1]|0;ta=Ye<<24>>24;sa=(a[1438808+ta|0]|0)+Fa|0;if((sa|0)<0){$e=0}else{$e=(sa|0)>88?88:sa&65535}sa=(ca(b[1437984+(Fa<<1)>>1]|0,ta<<1&14|1)|0)>>3;Fa=(c[Ra>>2]|0)+((ta&8|0)==0?sa:-sa|0)|0;if((Fa+32768|0)>>>0>65535>>>0){af=(Fa>>31^32767)&65535}else{af=Fa&65535}c[Ra>>2]=af<<16>>16;b[Wa>>1]=$e;b[Qa+2>>1]=af;Fa=Pa-1|0;if((Fa|0)>0){Aa=Aa+1|0;Qa=Qa+4|0;Pa=Fa}else{break}}Oa=We+va|0}else if((qa|0)==69637){h:do{if((E|0)>0){Pa=v;Qa=M;Aa=0;while(1){Wa=Qa;c[Pa+(Aa*36|0)>>2]=(he((d[Wa]|d[Wa+1|0]<<8)<<16>>16|0)|0)<<16>>16;bf=a[Qa+2|0]|0;b[Pa+(Aa*36|0)+4>>1]=bf&255;if((bf&255)>>>0>88>>>0){break}Wa=Qa+4|0;Ra=Aa+1|0;if((Ra|0)<(c[y>>2]|0)){Qa=Wa;Aa=Ra}else{cf=Wa;break h}}KIb(e,16,2180704,(w=i,i=i+8|0,c[w>>2]=bf&255,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{cf=M}}while(0);va=na>>(pa^1);if((va|0)<=0){Oa=cf;break}Aa=v;Qa=v+4|0;Pa=v;Ca=Aa+(pa*36|0)+4|0;Wa=Aa+(pa*36|0)|0;Aa=cf;Ra=ja;Da=va;while(1){Va=d[Aa]|0;Fa=Va>>>4;sa=b[Qa>>1]|0;ta=b[1437984+(sa<<1)>>1]|0;ya=(a[1438808+Fa|0]|0)+sa|0;if((ya|0)<0){df=0}else{df=(ya|0)>88?88:ya&65535}ya=((Fa&4|0)==0?0:ta)+(ta>>3)|0;if((Fa&2|0)==0){ef=ya}else{ef=ya+(ta>>1)|0}if((Fa&1|0)==0){ff=ef}else{ff=ef+(ta>>2)|0}ta=(c[Pa>>2]|0)+((Fa&8|0)==0?ff:-ff|0)|0;if((ta+32768|0)>>>0>65535>>>0){gf=(ta>>31^32767)&65535}else{gf=ta&65535}c[Pa>>2]=gf<<16>>16;b[Qa>>1]=df;b[Ra>>1]=gf;ta=b[Ca>>1]|0;Fa=b[1437984+(ta<<1)>>1]|0;ya=(a[1438808+(Va&15)|0]|0)+ta|0;if((ya|0)<0){hf=0}else{hf=(ya|0)>88?88:ya&65535}ya=(Fa>>3)+((Va&4|0)==0?0:Fa)|0;if((Va&2|0)==0){jf=ya}else{jf=ya+(Fa>>1)|0}if((Va&1|0)==0){kf=jf}else{kf=jf+(Fa>>2)|0}Fa=(c[Wa>>2]|0)+((Va&8|0)==0?kf:-kf|0)|0;if((Fa+32768|0)>>>0>65535>>>0){lf=(Fa>>31^32767)&65535}else{lf=Fa&65535}c[Wa>>2]=lf<<16>>16;b[Ca>>1]=hf;b[Ra+2>>1]=lf;Fa=Da-1|0;if((Fa|0)>0){Aa=Aa+1|0;Ra=Ra+4|0;Da=Fa}else{break}}Oa=cf+va|0}else if((qa|0)==69655){Da=na>>(pa^1);if((Da|0)<=0){Oa=M;break}Ra=v;Aa=v+4|0;Ca=v;Wa=Ra+(pa*36|0)+4|0;Qa=Ra+(pa*36|0)|0;Ra=M;Pa=ja;Fa=Da;while(1){Va=a[Ra]|0;ya=b[Aa>>1]|0;ta=(Va&255)>>>4&255;sa=(a[1438808+ta|0]|0)+ya|0;if((sa|0)<0){mf=0}else{mf=(sa|0)>88?88:sa&65535}sa=(ca(ta<<1&14|1,b[1437984+(ya<<1)>>1]|0)|0)>>6;ya=(c[Ca>>2]|0)+((ta&8|0)==0?sa:-sa|0)|0;if((ya+32768|0)>>>0>65535>>>0){nf=(ya>>31^32767)&65535}else{nf=ya&65535}c[Ca>>2]=nf<<16>>16;b[Aa>>1]=mf;b[Pa>>1]=nf;ya=b[Wa>>1]|0;sa=Va&15;Va=(a[1438808+sa|0]|0)+ya|0;if((Va|0)<0){of=0}else{of=(Va|0)>88?88:Va&65535}Va=(ca(b[1437984+(ya<<1)>>1]|0,sa<<1&14|1)|0)>>6;ya=(c[Qa>>2]|0)+((sa&8|0)==0?Va:-Va|0)|0;if((ya+32768|0)>>>0>65535>>>0){pf=(ya>>31^32767)&65535}else{pf=ya&65535}c[Qa>>2]=pf<<16>>16;b[Wa>>1]=of;b[Pa+2>>1]=pf;ya=Fa-1|0;if((ya|0)>0){Ra=Ra+1|0;Pa=Pa+4|0;Fa=ya}else{break}}Oa=M+Da|0}else if((qa|0)==69658){if((E|0)>0){Fa=M;Pa=0;while(1){Ra=d[Fa]|0;Wa=Ra>>>4;c[l+(Pa<<3)>>2]=c[1515328+(Wa<<2)>>2];c[l+(Pa<<3)+4>>2]=c[1515328+(Wa+4<<2)>>2];Wa=Fa+1|0;c[m+(Pa<<2)>>2]=20-(Ra&15);Ra=Pa+1|0;if((Ra|0)<(E|0)){Fa=Wa;Pa=Ra}else{qf=Wa;break}}}else{qf=M}Pa=(na|0)/2|0;if((na|0)>1){Fa=n|0;Da=n+4|0;Wa=v;Ra=qf;Qa=0;Aa=ja;Ca=E;while(1){va=Ra+1|0;ya=d[Ra]|0;c[Fa>>2]=ya;if(oa){c[Da>>2]=d[va]|0;rf=Ra+2|0}else{rf=va}i:do{if((Ca|0)>0){va=Aa;Va=0;sa=ya;while(1){ta=Wa+(Va*36|0)+16|0;ra=c[ta>>2]|0;Ga=ca(c[l+(Va<<3)>>2]|0,ra)|0;Ta=Wa+(Va*36|0)+20|0;Ua=Ga+128+(sa>>>4<<28>>28<<c[m+(Va<<2)>>2])+(ca(c[l+(Va<<3)+4>>2]|0,c[Ta>>2]|0)|0)|0;Ga=Ua>>8;c[Ta>>2]=ra;if((Ga+32768|0)>>>0>65535>>>0){sf=(Ua>>31^32767)&65535}else{sf=Ga&65535}c[ta>>2]=sf<<16>>16;tf=va+2|0;b[va>>1]=sf;ta=Va+1|0;uf=c[y>>2]|0;if((ta|0)>=(uf|0)){break}va=tf;Va=ta;sa=c[n+(ta<<2)>>2]|0}if((uf|0)>0){vf=tf;wf=0;xf=ya}else{yf=tf;zf=uf;break}while(1){sa=Wa+(wf*36|0)+16|0;Va=c[sa>>2]|0;va=ca(c[l+(wf<<3)>>2]|0,Va)|0;yd=Wa+(wf*36|0)+20|0;ta=va+128+(xf<<28>>28<<c[m+(wf<<2)>>2])+(ca(c[l+(wf<<3)+4>>2]|0,c[yd>>2]|0)|0)|0;va=ta>>8;c[yd>>2]=Va;if((va+32768|0)>>>0>65535>>>0){Af=(ta>>31^32767)&65535}else{Af=va&65535}c[sa>>2]=Af<<16>>16;sa=vf+2|0;b[vf>>1]=Af;va=wf+1|0;ta=c[y>>2]|0;if((va|0)>=(ta|0)){yf=sa;zf=ta;break i}vf=sa;wf=va;xf=c[n+(va<<2)>>2]|0}}else{yf=Aa;zf=Ca}}while(0);ya=Qa+1|0;if((ya|0)<(Pa|0)){Ra=rf;Qa=ya;Aa=yf;Ca=zf}else{break}}}Oa=s+((-h|0)>0?0:h)|0}else if((qa|0)==69656){Ca=v;Aa=M;Qa=0;Ra=M+(pa<<2|8)|0;while(1){Pa=Aa;Bf=(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24)&65535;b[Ca+(Qa*36|0)+4>>1]=Bf;if((Bf&65535)>>>0>88>>>0){C=343;break}Pa=Aa+4|0;Wa=Qa+1|0;if((Wa|0)>(pa|0)){Cf=Pa;Df=0;break}else{Aa=Pa;Qa=Wa;Ra=Ra+4|0}}if((C|0)==343){KIb(e,16,2192512,(w=i,i=i+16|0,c[w>>2]=Qa,c[w+8>>2]=Bf<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}while(1){Aa=Cf;c[Ca+(Df*36|0)>>2]=d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24;Aa=Df+1|0;if((Aa|0)>(pa|0)){break}else{Cf=Cf+4|0;Df=Aa}}Qa=na>>(pa^1);if((Qa|0)<=0){Oa=Ra;break}Aa=v+4|0;Wa=v;Pa=Ca+(pa*36|0)+4|0;Da=Ca+(pa*36|0)|0;Fa=Ra;ya=ja;va=Qa;while(1){Qa=Fa+1|0;sa=a[Fa]|0;ta=b[Aa>>1]|0;Va=(sa&255)>>>4&255;yd=(a[1438808+Va|0]|0)+ta|0;if((yd|0)<0){Ef=0}else{Ef=(yd|0)>88?88:yd&65535}yd=(ca(Va<<1&14|1,b[1437984+(ta<<1)>>1]|0)|0)>>3;ta=(c[Wa>>2]|0)+((Va&8|0)==0?yd:-yd|0)|0;if((ta+32768|0)>>>0>65535>>>0){Ff=(ta>>31^32767)&65535}else{Ff=ta&65535}c[Wa>>2]=Ff<<16>>16;b[Aa>>1]=Ef;b[ya>>1]=Ff;ta=b[Pa>>1]|0;yd=sa&15;sa=(a[1438808+yd|0]|0)+ta|0;if((sa|0)<0){Gf=0}else{Gf=(sa|0)>88?88:sa&65535}sa=(ca(b[1437984+(ta<<1)>>1]|0,yd<<1&14|1)|0)>>3;ta=(c[Da>>2]|0)+((yd&8|0)==0?sa:-sa|0)|0;if((ta+32768|0)>>>0>65535>>>0){Hf=(ta>>31^32767)&65535}else{Hf=ta&65535}c[Da>>2]=Hf<<16>>16;b[Pa>>1]=Gf;b[ya+2>>1]=Hf;ta=va-1|0;if((ta|0)>0){Fa=Qa;ya=ya+4|0;va=ta}else{Oa=Qa;break}}}else if((qa|0)==69632){if((E|0)<=0){Oa=M;break}va=v;ya=M;Fa=0;while(1){Pa=va+(Fa*36|0)|0;Da=ya+2|0;Aa=ya;Wa=(he((d[Aa]|d[Aa+1|0]<<8)<<16>>16|0)|0)<<16>>16;Aa=Wa&127;Ra=Wa&-128;Wa=va+(Fa*36|0)+4|0;Ca=b[Wa>>1]|0;Qa=Pa|0;if((Ca<<16>>16|0)==(Aa|0)){ta=c[Qa>>2]|0;sa=Ra-ta|0;if((((sa|0)<0?-sa|0:sa)|0)>127){C=90}else{If=Ca;Jf=ta}}else{C=90}if((C|0)==90){C=0;ta=Aa&65535;b[Wa>>1]=ta;c[Qa>>2]=Ra;If=ta;Jf=Ra}if((If&65535)>>>0>88>>>0){break}Ra=c[ia+(Fa<<2)>>2]|0;ta=Pa|0;Pa=Da;Da=0;Qa=Jf;Aa=If;while(1){Ca=d[Pa]|0;sa=Aa<<16>>16;yd=b[1437984+(sa<<1)>>1]|0;Va=(a[1438808+(Ca&15)|0]|0)+sa|0;if((Va|0)<0){Kf=0}else{Kf=(Va|0)>88?88:Va&65535}Va=(yd>>3)+((Ca&4|0)==0?0:yd)|0;if((Ca&2|0)==0){Lf=Va}else{Lf=Va+(yd>>1)|0}if((Ca&1|0)==0){Mf=Lf}else{Mf=Lf+(yd>>2)|0}yd=Qa+((Ca&8|0)==0?Mf:-Mf|0)|0;if((yd+32768|0)>>>0>65535>>>0){Nf=(yd>>31^32767)&65535}else{Nf=yd&65535}yd=Nf<<16>>16;c[ta>>2]=yd;b[Wa>>1]=Kf;b[Ra+(Da<<1)>>1]=Nf;Va=Ca>>>4;Ca=b[Wa>>1]|0;sa=b[1437984+(Ca<<1)>>1]|0;Ga=(a[1438808+Va|0]|0)+Ca|0;if((Ga|0)<0){Of=0}else{Of=(Ga|0)>88?88:Ga&65535}Ga=(sa>>3)+((Va&4|0)==0?0:sa)|0;if((Va&2|0)==0){Pf=Ga}else{Pf=Ga+(sa>>1)|0}if((Va&1|0)==0){Qf=Pf}else{Qf=Pf+(sa>>2)|0}sa=yd+((Va&8|0)==0?Qf:-Qf|0)|0;if((sa+32768|0)>>>0>65535>>>0){Rf=(sa>>31^32767)&65535}else{Rf=sa&65535}sa=Rf<<16>>16;c[ta>>2]=sa;b[Wa>>1]=Of;b[Ra+((Da|1)<<1)>>1]=Rf;Va=Da+2|0;if((Va|0)>=64){break}Pa=Pa+1|0;Da=Va;Qa=sa;Aa=b[Wa>>1]|0}Wa=ya+34|0;Aa=Fa+1|0;if((Aa|0)<(c[y>>2]|0)){ya=Wa;Fa=Aa}else{Oa=Wa;break b}}KIb(e,16,2192512,(w=i,i=i+16|0,c[w>>2]=Fa,c[w+8>>2]=If<<16>>16,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else if((qa|0)==1095123744){ya=c[e+96>>2]|0;do{if((ya|0)==0){C=598}else{if((c[e+100>>2]|0)!=1){C=598;break}va=a[ya]|0;Wa=va&255;if(va<<24>>24==0){C=598;break}va=(na|0)/(Wa|0)|0;if((va|0)>0){Sf=Wa;Tf=va;Uf=Wa;C=600}}}while(0);if((C|0)==598){Sf=na;Tf=1;Uf=na;C=600}if((C|0)==600){ya=(Uf|0)/16|0;Fa=v;Wa=(Sf|0)>15;va=M;Aa=0;Qa=E;while(1){if((Qa|0)>0){Da=Aa<<4;Pa=va;Ra=0;while(1){ta=Fa+(Ra*36|0)+16|0;sa=c[ta>>2]|0;Va=Fa+(Ra*36|0)+20|0;yd=c[Va>>2]|0;if(Wa){Ga=Pa;Ca=sa;Ua=yd;ra=(c[ia+(Ra<<2)>>2]|0)+(Da<<1)|0;Ta=0;while(1){xa=d[Ga]|0;Sa=xa>>>4;Qb=xa&15;ua=b[1441856+(Qb<<1)>>1]|0;wd=b[1441888+(Qb<<1)>>1]|0;Qb=Ga+1|0;Ea=Ca;xd=Ua;Pb=xa;xa=ra;Ya=0;while(1){if((Ya&1|0)==0){wa=d[Qb]|0;Vf=wa;Wf=wa>>>4;Xf=Qb+1|0}else{Vf=Pb;Wf=Pb;Xf=Qb}wa=(ca(xd,wd)|0)+(ca(Ea,ua)|0)+(Wf<<28>>28<<Sa<<11)|0;za=wa>>11;if((za+32768|0)>>>0>65535>>>0){Yf=(wa>>31^32767)&65535}else{Yf=za&65535}b[xa>>1]=Yf;Zf=Yf<<16>>16;za=Ya+1|0;if((za|0)<16){Qb=Xf;xd=Ea;Ea=Zf;Pb=Vf;xa=xa+2|0;Ya=za}else{break}}Ya=Ta+1|0;if((Ya|0)<(ya|0)){Ga=Xf;Ca=Zf;Ua=Ea;ra=ra+32|0;Ta=Ya}else{_f=Xf;$f=Zf;ag=Ea;break}}}else{_f=Pa;$f=sa;ag=yd}c[ta>>2]=$f;c[Va>>2]=ag;Ta=Ra+1|0;ra=c[y>>2]|0;if((Ta|0)<(ra|0)){Pa=_f;Ra=Ta}else{bg=_f;cg=ra;break}}}else{bg=va;cg=Qa}Ra=Aa+1|0;if((Ra|0)<(Tf|0)){va=bg;Aa=Ra;Qa=cg}else{break}}}Oa=s+((-h|0)>0?0:h)|0}else{ma=-1;i=j;return ma|0}}while(0);if((c[t>>2]|0)!=0&(Oa|0)==(s|0)){KIb(e,16,2175248,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ma=-1094995529;i=j;return ma|0}else{c[g>>2]=1;ma=Oa-s|0;i=j;return ma|0}}}while(0);KIb(e,16,2198888,(w=i,i=i+1|0,i=i+7&-8,c[w>>2]=0,w)|0);i=w;ma=-1094995529;i=j;return ma|0}function Hlb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;f=b+60|0;g=c[f>>2]|0;h=b+416|0;if((c[h>>2]|0)>2){KIb(b,16,2611016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=e;return k|0}l=c[b+600>>2]|0;if(l>>>0>16>>>0){KIb(b,16,2584536,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-22;i=e;return k|0}do{if((l|0)==0){m=14}else{n=1<<l;o=n<<10;p=hJb(o)|0;c[g+216>>2]=p;if(!((p|0)!=0|(o|0)==0)){KIb(b,16,2634648,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-12;break}o=40<<l;p=hJb(o)|0;c[g+220>>2]=p;if(!((p|0)!=0|(o|0)==0)){KIb(b,16,2634648,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-12;break}o=n<<3;n=hJb(o)|0;c[g+224>>2]=n;if(!((n|0)!=0|(o|0)==0)){KIb(b,16,2634648,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-12;break}o=hJb(65536)|0;c[g+228>>2]=o;if((o|0)!=0){m=14;break}KIb(b,16,2634648,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-12}}while(0);a:do{if((m|0)==14){g=b+12|0;l=b+792|0;c[l>>2]=g5a(c[(c[g>>2]|0)+12>>2]|0)|0;switch(c[(c[g>>2]|0)+12>>2]|0){case 69632:{c[b+424>>2]=64;c[b+432>>2]=(c[h>>2]|0)*34|0;k=0;i=e;return k|0};case 69638:{g=c[h>>2]|0;o=b+424|0;c[o>>2]=(((g*-14|0)+2048|0)/(g|0)|0)+2;c[l>>2]=4;c[b+432>>2]=1024;g=hJb(48)|0;c[b+96>>2]=g;if((g|0)==0){q=-12;break a}c[b+100>>2]=32;n=g;y=c[o>>2]&65535;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+2|0;y=7;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+4|0;y=d[1442168]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+6|0;y=a[1442160]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+8|0;y=d[1442169]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+10|0;y=a[1442161]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+12|0;y=d[1442170]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+14|0;y=a[1442162]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+16|0;y=d[1442171]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+18|0;y=a[1442163]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+20|0;y=d[1442172]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+22|0;y=a[1442164]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+24|0;y=d[1442173]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+26|0;y=a[1442165]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+28|0;y=d[1442174]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;n=g+30|0;y=a[1442166]<<2;a[n]=y;y=y>>8;a[n+1|0]=y;k=0;i=e;return k|0};case 69633:{n=c[h>>2]<<2;c[b+424>>2]=((1024-n<<3|0)/(n|0)|0)+1;c[b+432>>2]=1024;c[l>>2]=4;k=0;i=e;return k|0};case 69645:{l=c[b+412>>2]|0;if(!((l|0)==11025|(l|0)==22050|(l|0)==44100)){KIb(b,16,2563680,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;q=-22;break a}c[b+424>>2]=((l|0)/11025|0)<<9;k=0;i=e;return k|0};case 69646:{c[b+424>>2]=2048/(c[h>>2]|0)|0;c[b+432>>2]=1024;k=0;i=e;return k|0};default:{q=-22;break a}}}}while(0);b=c[f>>2]|0;mJb(b+216|0);mJb(b+220|0);mJb(b+224|0);mJb(b+228|0);k=q;i=e;return k|0}function Ilb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0;k=i;i=i+64|0;l=k|0;m=f+60|0;n=c[m>>2]|0;o=c[h>>2]|0;p=o;q=c[h+64>>2]|0;r=f+416|0;s=c[r>>2]|0;t=(s|0)==2|0;if((c[f+48>>2]|0)==69645){u=((ca((c[h+76>>2]<<2)+18|0,s)|0)+9|0)/8|0}else{u=c[f+432>>2]|0}s=d5a(f,g,u,(u|0)<0|0?-1:0)|0;if((s|0)<0){v=s;i=k;return v|0}s=c[g+24>>2]|0;w=f+12|0;a:do{switch(c[(c[w>>2]|0)+12>>2]|0){case 69633:{x=(c[h+76>>2]|0)-1|0;z=(x|0)/8|0;A=c[r>>2]|0;if((A|0)>0){B=n;C=s;D=0;while(1){E=b[c[q+(D<<2)>>2]>>1]|0;c[B+(D*36|0)+12>>2]=E<<16>>16;F=C;y=E;a[F]=y;y=y>>8;a[F+1|0]=y;a[C+2|0]=b[B+(D*36|0)+4>>1];F=C+4|0;a[C+3|0]=0;E=D+1|0;G=c[r>>2]|0;if((E|0)<(G|0)){C=F;D=E}else{H=F;I=G;break}}}else{H=s;I=A}D=f+600|0;if((c[D>>2]|0)>0){C=z<<3;B=hJb(ca(C,I)|0)|0;G=c[r>>2]|0;do{if((B|0)==0){if(((ca(G,z)|0)&536870911|0)==0){break}KIb(f,16,2634648,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;v=-12;i=k;return v|0}}while(0);if((G|0)>0){A=n;F=0;while(1){E=B+(ca(C,F)|0)|0;Klb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[D>>2]|0,(c[q+(F<<2)>>2]|0)+2|0,E,A+(F*36|0)|0,C,1);E=F+1|0;K=c[r>>2]|0;if((E|0)<(K|0)){F=E}else{L=K;break}}}else{L=G}if((x|0)>7){F=H;A=0;D=L;while(1){if((D|0)>0){K=A<<3;E=F;M=0;while(1){N=(ca(C,M)|0)+K|0;a[E]=a[B+(N|1)|0]<<4|a[B+N|0];a[E+1|0]=a[B+(N|3)|0]<<4|a[B+(N|2)|0];a[E+2|0]=a[B+(N|5)|0]<<4|a[B+(N|4)|0];a[E+3|0]=a[B+(N|7)|0]<<4|a[B+(N|6)|0];N=E+4|0;O=M+1|0;P=c[r>>2]|0;if((O|0)<(P|0)){E=N;M=O}else{Q=N;R=P;break}}}else{Q=F;R=D}M=A+1|0;if((M|0)<(z|0)){F=Q;A=M;D=R}else{break}}}kJb(B);break a}if((x|0)<=7){break a}D=n;A=H;F=0;C=I;while(1){if((C|0)>0){G=F<<3|1;M=A;E=0;while(1){K=c[q+(E<<2)>>2]|0;P=D+(E*36|0)+12|0;N=D+(E*36|0)+4|0;O=M;S=0;while(1){T=c[P>>2]|0;U=(b[K+(S+G<<1)>>1]|0)-T|0;V=b[N>>1]|0;W=b[1437984+(V<<1)>>1]|0;X=(((U|0)>-1?U:-U|0)<<2|0)/(W|0)|0;Y=((X|0)<7?X:7)+(U>>>31<<3)|0;U=((ca(a[1437448+Y|0]|0,W)|0)/8|0)+T|0;if((U+32768|0)>>>0>65535>>>0){Z=(U>>31^32767)&65535}else{Z=U&65535}U=Z<<16>>16;c[P>>2]=U;T=(a[1438808+Y|0]|0)+V|0;if((T|0)<0){_=0}else{_=(T|0)>88?88:T&65535}b[N>>1]=_;T=(b[K+((S|1)+G<<1)>>1]|0)-U|0;V=_<<16>>16;W=b[1437984+(V<<1)>>1]|0;X=(((T|0)>-1?T:-T|0)<<2|0)/(W|0)|0;$=((X|0)<7?X:7)+(T>>>31<<3)|0;T=((ca(a[1437448+$|0]|0,W)|0)/8|0)+U|0;if((T+32768|0)>>>0>65535>>>0){aa=(T>>31^32767)&65535}else{aa=T&65535}c[P>>2]=aa<<16>>16;T=(a[1438808+$|0]|0)+V|0;if((T|0)<0){ba=0}else{ba=(T|0)>88?88:T&65535}b[N>>1]=ba;a[O]=($&255)<<4|Y&255;Y=S+2|0;if((Y|0)<8){O=O+1|0;S=Y}else{break}}S=M+4|0;O=E+1|0;N=c[r>>2]|0;if((O|0)<(N|0)){M=S;E=O}else{da=S;ea=N;break}}}else{da=A;ea=C}E=F+1|0;if((E|0)<(z|0)){A=da;F=E;C=ea}else{break}}break};case 69646:{C=(c[h+76>>2]|0)/2|0;F=f+600|0;if((c[F>>2]|0)>0){A=C<<1;z=C<<2;D=hJb(z)|0;if(!((D|0)!=0|(z|0)==0)){KIb(f,16,2634648,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;v=-12;i=k;return v|0}z=c[r>>2]|0;Klb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[F>>2]|0,p,D,n,A,z);do{if((z|0)==1){if((A|0)>0){fa=s;ga=0}else{break}while(1){a[fa]=a[D+(ga|1)|0]<<4|a[D+ga|0];x=ga+2|0;if((x|0)<(A|0)){fa=fa+1|0;ga=x}else{break}}}else{Klb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[F>>2]|0,o+2|0,D+A|0,n+36|0,A,c[r>>2]|0);if((A|0)>0){ha=s;ia=0}else{break}while(1){a[ha]=a[D+(ia+A)|0]<<4|a[D+ia|0];x=ia+1|0;if((x|0)<(A|0)){ha=ha+1|0;ia=x}else{break}}}}while(0);kJb(D);break a}A=ca(c[r>>2]|0,C)|0;if((A|0)<=0){break a}F=n;z=n+8|0;x=n;B=F+(t*36|0)+8|0;E=F+(t*36|0)|0;F=s;M=p;G=A;while(1){A=b[M>>1]|0;N=c[z>>2]|0;if((N|0)==0){c[x>>2]=0;c[z>>2]=127;ja=127;ka=0}else{ja=N;ka=c[x>>2]|0}N=(A<<16>>16)-ka|0;A=(((N|0)>-1?N:-N|0)<<2|0)/(ja|0)|0;S=((A|0)<7?A:7)+(N>>>31<<3)|0;N=((ca(a[1437448+S|0]|0,ja)|0)/8|0)+ka|0;if((N+32768|0)>>>0>65535>>>0){la=(N>>31^32767)&65535}else{la=N&65535}c[x>>2]=la<<16>>16;N=(ca(b[1437312+(S<<1)>>1]|0,ja)|0)>>8;if((N|0)<127){ma=127}else{ma=(N|0)>24567?24567:N}c[z>>2]=ma;N=b[M+2>>1]|0;A=c[B>>2]|0;if((A|0)==0){c[E>>2]=0;c[B>>2]=127;na=127;oa=0}else{na=A;oa=c[E>>2]|0}A=(N<<16>>16)-oa|0;N=(((A|0)>-1?A:-A|0)<<2|0)/(na|0)|0;O=((N|0)<7?N:7)+(A>>>31<<3)|0;A=((ca(a[1437448+O|0]|0,na)|0)/8|0)+oa|0;if((A+32768|0)>>>0>65535>>>0){pa=(A>>31^32767)&65535}else{pa=A&65535}c[E>>2]=pa<<16>>16;A=(ca(b[1437312+(O<<1)>>1]|0,na)|0)>>8;if((A|0)<127){qa=127}else{qa=(A|0)>24567?24567:A}c[B>>2]=qa;a[F]=(O&255)<<4|S&255;S=G-1|0;if((S|0)>0){F=F+1|0;M=M+4|0;G=S}else{break}}break};case 69638:{G=c[r>>2]|0;do{if((G|0)>0){M=d[1442168]|0;F=n;B=a[1442160]|0;E=s;z=0;while(1){ra=E+1|0;a[E]=0;c[F+(z*36|0)+24>>2]=M;c[F+(z*36|0)+28>>2]=B;x=z+1|0;sa=c[r>>2]|0;if((x|0)<(sa|0)){E=ra;z=x}else{break}}if((sa|0)<=0){ta=ra;ua=sa;va=p;break}z=n;E=ra;B=0;do{F=z+(B*36|0)+32|0;M=c[F>>2]|0;if((M|0)<16){c[F>>2]=16;wa=16}else{wa=M&65535}M=E;y=wa;a[M]=y;y=y>>8;a[M+1|0]=y;E=E+2|0;B=B+1|0;xa=c[r>>2]|0;}while((B|0)<(xa|0));if((xa|0)<=0){ta=E;ua=xa;va=p;break}B=n;z=p;M=0;while(1){ya=z+2|0;c[B+(M*36|0)+20>>2]=b[z>>1]|0;F=M+1|0;za=c[r>>2]|0;if((F|0)<(za|0)){z=ya;M=F}else{break}}if((za|0)<=0){ta=E;ua=za;va=ya;break}M=n;z=E;B=ya;F=0;while(1){Aa=B+2|0;x=b[B>>1]|0;c[M+(F*36|0)+16>>2]=x<<16>>16;C=z;y=x;a[C]=y;y=y>>8;a[C+1|0]=y;Ba=z+2|0;C=F+1|0;Ca=c[r>>2]|0;if((C|0)<(Ca|0)){z=Ba;B=Aa;F=C}else{break}}if((Ca|0)<=0){ta=Ba;ua=Ca;va=Aa;break}F=n;B=Ba;z=0;while(1){M=B;y=c[F+(z*36|0)+20>>2]&65535;a[M]=y;y=y>>8;a[M+1|0]=y;M=B+2|0;E=z+1|0;C=c[r>>2]|0;if((E|0)<(C|0)){B=M;z=E}else{ta=M;ua=C;va=Aa;break}}}else{ta=s;ua=G;va=p}}while(0);G=f+600|0;if((c[G>>2]|0)>0){z=(c[f+432>>2]|0)+(ua*-7|0)|0;B=z<<1;F=hJb(B)|0;if(!((F|0)!=0|(B|0)==0)){KIb(f,16,2634648,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;v=-12;i=k;return v|0}B=c[r>>2]|0;Klb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[G>>2]|0,va,F,n,z,B);do{if((B|0)==1){if((z|0)>0){Da=ta;Ea=0}else{break}while(1){a[Da]=a[F+Ea|0]<<4|a[F+(Ea|1)|0];C=Ea+2|0;if((C|0)<(z|0)){Da=Da+1|0;Ea=C}else{break}}}else{Klb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[G>>2]|0,va+2|0,F+z|0,n+36|0,z,c[r>>2]|0);if((z|0)>0){Fa=ta;Ga=0}else{break}while(1){a[Fa]=a[F+Ga|0]<<4|a[F+(Ga+z)|0];C=Ga+1|0;if((C|0)<(z|0)){Fa=Fa+1|0;Ga=C}else{break}}}}while(0);kJb(F);break a}z=ua*7|0;G=f+432|0;if((z|0)>=(c[G>>2]|0)){break a}B=n;C=n+16|0;M=n+24|0;E=n+20|0;x=n+28|0;D=n+32|0;S=B+(t*36|0)+16|0;O=B+(t*36|0)+24|0;A=B+(t*36|0)+20|0;N=B+(t*36|0)+28|0;P=B+(t*36|0)+32|0;B=ta;K=va;Y=z;while(1){z=c[C>>2]|0;$=ca(c[M>>2]|0,z)|0;T=((ca(c[x>>2]|0,c[E>>2]|0)|0)+$|0)/64|0;$=(b[K>>1]|0)-T|0;V=c[D>>2]|0;if(($|0)>-1){Ha=(V|0)/2|0}else{Ha=(V|0)/-2|0}U=(Ha+$|0)/(V|0)|0;if((U|0)<-8){Ia=-8}else{Ia=(U|0)>7?7:U}U=Ia&15;$=(ca((Ia&8|0)!=0?Ia|-16:U,V)|0)+T|0;c[E>>2]=z;if(($+32768|0)>>>0>65535>>>0){Ja=($>>31^32767)&65535}else{Ja=$&65535}c[C>>2]=Ja<<16>>16;$=(ca(b[1442128+(U<<1)>>1]|0,V)|0)>>8;c[D>>2]=($|0)<16?16:$;$=c[S>>2]|0;V=ca(c[O>>2]|0,$)|0;U=((ca(c[N>>2]|0,c[A>>2]|0)|0)+V|0)/64|0;V=(b[K+2>>1]|0)-U|0;z=c[P>>2]|0;if((V|0)>-1){Ka=(z|0)/2|0}else{Ka=(z|0)/-2|0}T=(Ka+V|0)/(z|0)|0;if((T|0)<-8){La=-8}else{La=(T|0)>7?7:T}T=La&15;V=(ca((La&8|0)!=0?La|-16:T,z)|0)+U|0;c[A>>2]=$;if((V+32768|0)>>>0>65535>>>0){Ma=(V>>31^32767)&65535}else{Ma=V&65535}c[S>>2]=Ma<<16>>16;V=(ca(b[1442128+(T<<1)>>1]|0,z)|0)>>8;c[P>>2]=(V|0)<16?16:V;a[B]=T&255|(Ia&255)<<4;T=Y+1|0;if((T|0)<(c[G>>2]|0)){B=B+1|0;K=K+4|0;Y=T}else{break}}break};case 69645:{Y=(u&268435456|0)!=0?0:s;K=h+76|0;B=(c[K>>2]|0)-1|0;G=2;P=c[r>>2]|0;if((P|0)>0){S=n;A=Y;N=30;O=0;D=2;while(1){C=S+(O*36|0)+4|0;E=b[C>>1]|0;if(E<<16>>16<0){Na=0}else{Na=E<<16>>16>63?63:E}b[C>>1]=Na;E=p+(O<<1)|0;x=e[E>>1]|0;if((N|0)>16){Oa=N-16|0;Pa=D<<16|x;Qa=A;Ra=Na}else{M=A;y=je(x>>>((16-N|0)>>>0)|D<<N|0)|0;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;Oa=N+16|0;Pa=x;Qa=A+4|0;Ra=b[C>>1]|0}G=Pa;C=Ra<<16>>16;if((Oa|0)>6){Sa=Oa-6|0;Ta=C|Pa<<6;Ua=Qa}else{x=Qa;y=je(C>>>((6-Oa|0)>>>0)|Pa<<Oa|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;Sa=Oa+26|0;Ta=C;Ua=Qa+4|0}G=Ta;c[S+(O*36|0)+12>>2]=b[E>>1]|0;E=O+1|0;C=c[r>>2]|0;if((E|0)<(C|0)){A=Ua;N=Sa;O=E;D=Ta}else{Va=Ua;Wa=Sa;Xa=Ta;Ya=C;break}}}else{Va=Y;Wa=30;Xa=2;Ya=P}D=f+600|0;b:do{if((c[D>>2]|0)>0){O=B<<1;N=hJb(O)|0;if(!((N|0)!=0|(O|0)==0)){KIb(f,16,2634648,(J=i,i=i+1|0,i=i+7&-8,c[J>>2]=0,J)|0);i=J;v=-12;i=k;return v|0}O=c[r>>2]|0;Klb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[D>>2]|0,p+(O<<1)|0,N,n,B,O);if((c[r>>2]|0)==2){Klb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,c[D>>2]|0,o+6|0,N+B|0,n+36|0,B,2)}if((B|0)>0){O=Va;A=Wa;S=0;C=Xa;while(1){E=d[N+S|0]|0;if((A|0)>4){Za=A-4|0;_a=C<<4|E;$a=O}else{x=O;y=je(E>>>((4-A|0)>>>0)|C<<A|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;Za=A+28|0;_a=E;$a=O+4|0}G=_a;if((c[r>>2]|0)==2){E=d[N+(S+B)|0]|0;if((Za|0)>4){ab=Za-4|0;bb=E|_a<<4;cb=$a}else{x=$a;y=je(E>>>((4-Za|0)>>>0)|_a<<Za|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;y=y>>8;a[x+2|0]=y;y=y>>8;a[x+3|0]=y;ab=Za+28|0;bb=E;cb=$a+4|0}G=bb;db=ab;eb=cb;fb=bb}else{db=Za;eb=$a;fb=_a}E=S+1|0;if((E|0)<(B|0)){O=eb;A=db;S=E;C=fb}else{gb=eb;hb=db;ib=fb;break}}}else{gb=Va;hb=Wa;ib=Xa}kJb(N);jb=hb;kb=gb;lb=ib}else{if((c[K>>2]|0)<=1){jb=Wa;kb=Va;lb=Xa;break}C=n+12|0;S=n+4|0;A=n+48|0;O=n+40|0;E=Va;x=Wa;M=1;F=Xa;T=Ya;while(1){V=b[p+((ca(T,M)|0)<<1)>>1]|0;z=c[C>>2]|0;$=V-z|0;V=b[S>>1]|0;U=b[1437984+(V<<1)>>1]|0;W=((($|0)>-1?$:-$|0)<<2|0)/(U|0)|0;X=((W|0)<7?W:7)+($>>>31<<3)|0;$=((ca(a[1437448+X|0]|0,U)|0)/8|0)+z|0;if(($+32768|0)>>>0>65535>>>0){mb=($>>31^32767)&65535}else{mb=$&65535}c[C>>2]=mb<<16>>16;$=(a[1438808+X|0]|0)+V|0;if(($|0)<0){nb=0}else{nb=($|0)>88?88:$&65535}b[S>>1]=nb;$=X&255;if((x|0)>4){ob=x-4|0;pb=F<<4|$;qb=E}else{X=E;y=je(F<<x|$>>>((4-x|0)>>>0)|0)|0;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;ob=x+28|0;pb=$;qb=E+4|0}G=pb;if((c[r>>2]|0)==2){$=c[A>>2]|0;X=(b[p+((M<<1|1)<<1)>>1]|0)-$|0;V=b[O>>1]|0;z=b[1437984+(V<<1)>>1]|0;U=(((X|0)>-1?X:-X|0)<<2|0)/(z|0)|0;W=((U|0)<7?U:7)+(X>>>31<<3)|0;X=((ca(a[1437448+W|0]|0,z)|0)/8|0)+$|0;if((X+32768|0)>>>0>65535>>>0){rb=(X>>31^32767)&65535}else{rb=X&65535}c[A>>2]=rb<<16>>16;X=(a[1438808+W|0]|0)+V|0;if((X|0)<0){sb=0}else{sb=(X|0)>88?88:X&65535}b[O>>1]=sb;X=W&255;if((ob|0)>4){tb=ob-4|0;ub=pb<<4|X;vb=qb}else{W=qb;y=je(pb<<ob|X>>>((4-ob|0)>>>0)|0)|0;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;tb=ob+28|0;ub=X;vb=qb+4|0}G=ub;wb=tb;xb=vb;yb=ub}else{wb=ob;xb=qb;yb=pb}X=M+1|0;if((X|0)>=(c[K>>2]|0)){jb=wb;kb=xb;lb=yb;break b}E=xb;x=wb;M=X;F=yb;T=c[r>>2]|0}}}while(0);if((jb|0)<32){K=lb<<jb;G=K;B=K>>>24&255;K=jb;D=kb;while(1){a[D]=B;P=G;G=P<<8;Y=K+8|0;if((Y|0)<32){B=P>>>16&255;K=Y;D=D+1|0}else{break}}}G=0;break};case 69632:{D=0;do{if((c[r>>2]|0)>0){K=n;B=f+600|0;Y=l|0;P=(u&268435456|0)!=0?0:s;T=32;F=0;M=0;while(1){x=K+(F*36|0)+12|0;E=(c[x>>2]|0)>>>7&511;if((T|0)>9){zb=T-9|0;Ab=M<<9|E;Bb=P}else{O=P;y=je(E>>>((9-T|0)>>>0)|M<<T|0)|0;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;zb=T+23|0;Ab=E;Bb=P+4|0}D=Ab;E=K+(F*36|0)+4|0;O=b[E>>1]|0;if((zb|0)>7){Cb=zb-7|0;Db=O|Ab<<7;Eb=Bb}else{A=Bb;y=je(O>>>((7-zb|0)>>>0)|Ab<<zb|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;Cb=zb+25|0;Db=O;Eb=Bb+4|0}D=Db;O=c[B>>2]|0;A=q+(F<<2)|0;if((O|0)>0){Klb(c[(c[w>>2]|0)+12>>2]|0,c[m>>2]|0,O,(c[A>>2]|0)+2|0,Y,K+(F*36|0)|0,64,1);O=Eb;S=Cb;C=0;N=Db;while(1){X=d[l+(C^1)|0]|0;if((S|0)>4){Fb=S-4|0;Gb=N<<4|X;Hb=O}else{W=O;y=je(X>>>((4-S|0)>>>0)|N<<S|0)|0;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;Fb=S+28|0;Gb=X;Hb=O+4|0}D=Gb;X=C+1|0;if((X|0)<64){O=Hb;S=Fb;C=X;N=Gb}else{Ib=Fb;Jb=Hb;Kb=Gb;break}}}else{N=Eb;C=Cb;S=0;O=Db;while(1){X=c[x>>2]|0;W=(b[(c[A>>2]|0)+(S<<1)>>1]|0)-X|0;V=b[E>>1]|0;$=b[1437984+(V<<1)>>1]|0;z=W>>>31<<3;U=(W|0)>-1?W:-W|0;if((U|0)<($|0)){Lb=z;Mb=U}else{Lb=z|4;Mb=U-$|0}z=$>>1;if((Mb|0)<(z|0)){Nb=Lb;Ob=Mb}else{Nb=Lb|2;Ob=Mb-z|0}z=$>>2;if((Ob|0)<(z|0)){Pb=Nb;Qb=Ob}else{Pb=Nb|1;Qb=Ob-z|0}z=($>>3)+U-Qb|0;U=((Pb&8|0)==0?z:-z|0)+X|0;if((U+32768|0)>>>0>65535>>>0){Rb=(U>>31^32767)&65535}else{Rb=U&65535}U=Rb<<16>>16;c[x>>2]=U;X=(a[1438808+Pb|0]|0)+V|0;if((X|0)<0){Sb=0}else{Sb=(X|0)>88?88:X&65535}b[E>>1]=Sb;X=Pb&255;V=(b[(c[A>>2]|0)+((S|1)<<1)>>1]|0)-U|0;z=Sb<<16>>16;$=b[1437984+(z<<1)>>1]|0;W=V>>>31<<3;Tb=(V|0)>-1?V:-V|0;if((Tb|0)<($|0)){Ub=W;Vb=Tb}else{Ub=W|4;Vb=Tb-$|0}W=$>>1;if((Vb|0)<(W|0)){Wb=Ub;Xb=Vb}else{Wb=Ub|2;Xb=Vb-W|0}W=$>>2;if((Xb|0)<(W|0)){Yb=Wb;Zb=Xb}else{Yb=Wb|1;Zb=Xb-W|0}W=($>>3)+Tb-Zb|0;Tb=((Yb&8|0)==0?W:-W|0)+U|0;if((Tb+32768|0)>>>0>65535>>>0){_b=(Tb>>31^32767)&65535}else{_b=Tb&65535}c[x>>2]=_b<<16>>16;Tb=(a[1438808+Yb|0]|0)+z|0;if((Tb|0)<0){$b=0}else{$b=(Tb|0)>88?88:Tb&65535}b[E>>1]=$b;Tb=Yb&255;if((C|0)>4){ac=C-4|0;bc=O<<4|Tb;cc=N}else{z=N;y=je(O<<C|Tb>>>((4-C|0)>>>0)|0)|0;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;ac=C+28|0;bc=Tb;cc=N+4|0}D=bc;if((ac|0)>4){dc=ac-4|0;ec=bc<<4|X;fc=cc}else{Tb=cc;y=je(X>>>((4-ac|0)>>>0)|bc<<ac|0)|0;a[Tb]=y;y=y>>8;a[Tb+1|0]=y;y=y>>8;a[Tb+2|0]=y;y=y>>8;a[Tb+3|0]=y;dc=ac+28|0;ec=X;fc=cc+4|0}D=ec;X=S+2|0;if((X|0)<64){N=fc;C=dc;S=X;O=ec}else{Ib=dc;Jb=fc;Kb=ec;break}}}O=F+1|0;if((O|0)<(c[r>>2]|0)){P=Jb;T=Ib;F=O;M=Kb}else{break}}if((Ib|0)>=32){break}M=Kb<<Ib;D=M;F=M>>>24&255;M=Ib;T=Jb;while(1){a[T]=F;P=D;D=P<<8;K=M+8|0;if((K|0)<32){F=P>>>16&255;M=K;T=T+1|0}else{break}}}}while(0);D=0;break};default:{v=-22;i=k;return v|0}}}while(0);c[g+28>>2]=u;c[j>>2]=1;v=0;i=k;return v|0}function Jlb(a){a=a|0;var b=0;b=c[a+60>>2]|0;mJb(b+216|0);mJb(b+220|0);mJb(b+224|0);mJb(b+228|0);return 0}function Klb(e,f,g,h,i,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0;m=1<<g;n=c[f+216>>2]|0;o=c[f+220>>2]|0;p=c[f+224>>2]|0;q=p+(m<<2)|0;r=c[f+228>>2]|0;mrc(r|0,-1|0,65536)|0;mrc(p|0,0,m<<3|0)|0;f=o+(m*20|0)|0;c[p>>2]=f;c[f>>2]=0;c[o+(m*20|0)+4>>2]=0;f=j+4|0;s=o+(m*20|0)+16|0;c[s>>2]=b[f>>1]|0;t=j+16|0;u=o+(m*20|0)+8|0;c[u>>2]=c[t>>2];v=j+20|0;c[o+(m*20|0)+12>>2]=c[v>>2];w=(e-69632|0)>>>0<2>>>0|(e|0)==69645;if(w){c[u>>2]=c[j+12>>2]}x=(e|0)==69638;do{if(x){c[s>>2]=c[j+32>>2]}else{if((e|0)!=69646){break}y=c[j+8>>2]|0;if((y|0)==0){c[s>>2]=127;c[u>>2]=0;break}else{c[s>>2]=y;c[u>>2]=c[j>>2];break}}}while(0);if((k|0)>0){u=m<<2;s=(m|0)>0;e=u-4|0;y=(m|0)>1;z=(m|0)/2|0;A=j+24|0;B=j+28|0;C=m>>1;D=C-1|0;E=0;F=0;H=-1;I=0;J=q;q=p;while(1){K=b[h+((ca(F,l)|0)<<1)>>1]|0;mrc(J|0,0,u|0)|0;a:do{if(s){L=E&255;M=0;N=o+(((F&1)<<g)*20|0)|0;O=0;P=I;while(1){Q=q+(O<<2)|0;R=c[Q>>2]|0;if((R|0)==0){S=P;break a}T=(O|0)<(z|0)|0;U=c[R+16>>2]|0;V=c[R+8>>2]|0;do{if(x){W=ca(c[A>>2]|0,V)|0;X=((ca(c[B>>2]|0,c[R+12>>2]|0)|0)+W|0)/64|0;W=(K-X|0)/(U|0)|0;Y=W-T|0;if((Y|0)<-8){Z=-8}else{Z=(Y|0)>6?6:Y}Y=W+T|0;if((Y|0)<-7){_=-7}else{_=(Y|0)>7?7:Y}if((Z|0)>(_|0)){$=P;aa=N;ba=M;break}else{da=Z;ea=M;fa=N;ga=P}while(1){Y=da&15;W=(ca(da,U)|0)+X|0;if((W+32768|0)>>>0>65535>>>0){ha=(W>>31^32767)&65535}else{ha=W&65535}W=ha<<16>>16;ia=K-W|0;ja=qc(c[c[Q>>2]>>2]|0,ca(ia,ia)|0)|0;ia=ja;b:do{if(G){ka=ga;la=fa;ma=ea}else{ja=r+(ha&65535)|0;if((d[ja]|0)==(E|0)){ka=ga;la=fa;ma=ea;break}if((ea|0)<(m|0)){na=ea}else{oa=(ea&D)+C|0;if(ia>>>0>(c[c[J+(oa<<2)>>2]>>2]|0)>>>0){ka=ga;la=fa;ma=ea;break}else{na=oa}}oa=ea+1|0;a[ja]=L;ja=J+(na<<2)|0;pa=c[ja>>2]|0;if((pa|0)==0){c[ja>>2]=fa;c[fa+4>>2]=ga;qa=ga+1|0;ra=fa+20|0;sa=fa;ta=ga}else{qa=ga;ra=fa;sa=pa;ta=c[pa+4>>2]|0}c[sa>>2]=ia;pa=(ca(b[1442128+(Y<<1)>>1]|0,U)|0)>>8;c[sa+16>>2]=(pa|0)<16?16:pa;pa=c[Q>>2]|0;c[sa+12>>2]=c[pa+8>>2];c[sa+8>>2]=W;c[n+(ta<<3)>>2]=Y;c[n+(c[sa+4>>2]<<3)+4>>2]=c[pa+4>>2];if((na|0)>0){ua=na}else{ka=qa;la=ra;ma=oa;break}while(1){pa=ua-1>>1;ja=J+(pa<<2)|0;va=c[ja>>2]|0;if(!((c[va>>2]|0)>>>0>ia>>>0)){ka=qa;la=ra;ma=oa;break b}c[J+(ua<<2)>>2]=va;c[ja>>2]=sa;if((pa|0)>0){ua=pa}else{ka=qa;la=ra;ma=oa;break}}}}while(0);ia=da+1|0;if((ia|0)>(_|0)){$=ka;aa=la;ba=ma;break}else{da=ia;ea=ma;fa=la;ga=ka}}}else{X=K-V<<2;if(w){ia=b[1437984+(U<<1)>>1]|0;Y=(X|0)/(ia|0)|0;W=Y-T|0;if((W|0)<-7){wa=-7}else{wa=(W|0)>6?6:W}W=Y+T|0;if((W|0)<-6){xa=-6}else{xa=(W|0)>7?7:W}W=(((wa|0)<1)<<31>>31)+wa|0;Y=(xa>>31)+xa|0;if((W|0)>(Y|0)){$=P;aa=N;ba=M;break}else{ya=W;za=M;Aa=N;Ba=P}while(1){W=(ya|0)<0?7-ya|0:ya;oa=((ca(a[1437448+W|0]|0,ia)|0)/8|0)+V|0;if((oa+32768|0)>>>0>65535>>>0){Ca=(oa>>31^32767)&65535}else{Ca=oa&65535}oa=Ca<<16>>16;pa=K-oa|0;ja=qc(c[c[Q>>2]>>2]|0,ca(pa,pa)|0)|0;pa=ja;c:do{if(G){Da=Ba;Ea=Aa;Fa=za}else{ja=r+(Ca&65535)|0;if((d[ja]|0)==(E|0)){Da=Ba;Ea=Aa;Fa=za;break}if((za|0)<(m|0)){Ga=za}else{va=(za&D)+C|0;if(pa>>>0>(c[c[J+(va<<2)>>2]>>2]|0)>>>0){Da=Ba;Ea=Aa;Fa=za;break}else{Ga=va}}va=za+1|0;a[ja]=L;ja=J+(Ga<<2)|0;Ha=c[ja>>2]|0;if((Ha|0)==0){c[ja>>2]=Aa;c[Aa+4>>2]=Ba;Ia=Ba+1|0;Ja=Aa+20|0;Ka=Aa}else{Ia=Ba;Ja=Aa;Ka=Ha}c[Ka>>2]=pa;Ha=(a[1438808+W|0]|0)+U|0;if((Ha|0)<0){La=0}else{La=(Ha|0)>88?88:Ha}c[Ka+16>>2]=La;Ha=c[Q>>2]|0;c[Ka+12>>2]=c[Ha+8>>2];c[Ka+8>>2]=oa;ja=Ka+4|0;c[n+(c[ja>>2]<<3)>>2]=W;c[n+(c[ja>>2]<<3)+4>>2]=c[Ha+4>>2];if((Ga|0)>0){Ma=Ga}else{Da=Ia;Ea=Ja;Fa=va;break}while(1){Ha=Ma-1>>1;ja=J+(Ha<<2)|0;Na=c[ja>>2]|0;if(!((c[Na>>2]|0)>>>0>pa>>>0)){Da=Ia;Ea=Ja;Fa=va;break c}c[J+(Ma<<2)>>2]=Na;c[ja>>2]=Ka;if((Ha|0)>0){Ma=Ha}else{Da=Ia;Ea=Ja;Fa=va;break}}}}while(0);pa=ya+1|0;if((pa|0)>(Y|0)){$=Da;aa=Ea;ba=Fa;break}else{ya=pa;za=Fa;Aa=Ea;Ba=Da}}}else{Y=(X|0)/(U|0)|0;ia=Y-T|0;if((ia|0)<-7){Oa=-7}else{Oa=(ia|0)>6?6:ia}ia=Y+T|0;if((ia|0)<-6){Pa=-6}else{Pa=(ia|0)>7?7:ia}ia=(((Oa|0)<1)<<31>>31)+Oa|0;Y=(Pa>>31)+Pa|0;if((ia|0)>(Y|0)){$=P;aa=N;ba=M;break}else{Qa=ia;Ra=M;Sa=N;Ta=P}while(1){ia=(Qa|0)<0?7-Qa|0:Qa;pa=((ca(a[1437448+ia|0]|0,U)|0)/8|0)+V|0;if((pa+32768|0)>>>0>65535>>>0){Ua=(pa>>31^32767)&65535}else{Ua=pa&65535}pa=Ua<<16>>16;W=K-pa|0;oa=qc(c[c[Q>>2]>>2]|0,ca(W,W)|0)|0;W=oa;d:do{if(G){Va=Ta;Wa=Sa;Xa=Ra}else{oa=r+(Ua&65535)|0;if((d[oa]|0)==(E|0)){Va=Ta;Wa=Sa;Xa=Ra;break}if((Ra|0)<(m|0)){Ya=Ra}else{va=(Ra&D)+C|0;if(W>>>0>(c[c[J+(va<<2)>>2]>>2]|0)>>>0){Va=Ta;Wa=Sa;Xa=Ra;break}else{Ya=va}}va=Ra+1|0;a[oa]=L;oa=J+(Ya<<2)|0;Ha=c[oa>>2]|0;if((Ha|0)==0){c[oa>>2]=Sa;c[Sa+4>>2]=Ta;Za=Sa;_a=Ta+1|0;$a=Sa+20|0}else{Za=Ha;_a=Ta;$a=Sa}c[Za>>2]=W;Ha=(ca(b[1437312+(ia<<1)>>1]|0,U)|0)>>8;if((Ha|0)<127){ab=127}else{ab=(Ha|0)>24567?24567:Ha}c[Za+16>>2]=ab;Ha=c[Q>>2]|0;c[Za+12>>2]=c[Ha+8>>2];c[Za+8>>2]=pa;oa=Za+4|0;c[n+(c[oa>>2]<<3)>>2]=ia;c[n+(c[oa>>2]<<3)+4>>2]=c[Ha+4>>2];if((Ya|0)>0){bb=Ya}else{Va=_a;Wa=$a;Xa=va;break}while(1){Ha=bb-1>>1;oa=J+(Ha<<2)|0;ja=c[oa>>2]|0;if(!((c[ja>>2]|0)>>>0>W>>>0)){Va=_a;Wa=$a;Xa=va;break d}c[J+(bb<<2)>>2]=ja;c[oa>>2]=Za;if((Ha|0)>0){bb=Ha}else{Va=_a;Wa=$a;Xa=va;break}}}}while(0);W=Qa+1|0;if((W|0)>(Y|0)){$=Va;aa=Wa;ba=Xa;break}else{Qa=W;Ra=Xa;Sa=Wa;Ta=Va}}}}}while(0);Q=O+1|0;if((Q|0)<(m|0)){M=ba;N=aa;O=Q;P=$}else{S=$;break}}}else{S=I}}while(0);K=E+1|0;if((K|0)==255){mrc(r|0,-1|0,65536)|0;cb=0}else{cb=K}K=c[J>>2]|0;P=K|0;if((c[P>>2]|0)>>>0>268435456>>>0){e:do{if(y){O=1;do{N=c[J+(O<<2)>>2]|0;if((N|0)==0){break e}M=N|0;c[M>>2]=(c[M>>2]|0)-(c[P>>2]|0);O=O+1|0;}while((O|0)<(m|0))}}while(0);c[P>>2]=0}if((F|0)==(H+128|0)){if((F|0)>(H|0)){O=F;M=K+4|0;while(1){N=c[M>>2]|0;a[i+O|0]=c[n+(N<<3)>>2];L=O-1|0;if((L|0)>(H|0)){O=L;M=n+(N<<3)+4|0}else{break}}}mrc(J+4|0,0,e|0)|0;db=0;eb=F}else{db=S;eb=H}M=F+1|0;if((M|0)<(k|0)){O=J;J=q;E=cb;F=M;H=eb;I=db;q=O}else{fb=eb;gb=J;break}}}else{fb=-1;gb=p}p=k-1|0;if((p|0)<=(fb|0)){hb=c[gb>>2]|0;ib=hb+8|0;jb=c[ib>>2]|0;kb=j|0;c[kb>>2]=jb;lb=c[ib>>2]|0;c[t>>2]=lb;mb=hb+12|0;nb=c[mb>>2]|0;c[v>>2]=nb;ob=hb+16|0;pb=c[ob>>2]|0;qb=pb&65535;b[f>>1]=qb;rb=j+8|0;c[rb>>2]=pb;sb=c[ob>>2]|0;tb=j+32|0;c[tb>>2]=sb;return}k=(c[gb>>2]|0)+4|0;J=p;while(1){p=c[k>>2]|0;a[i+J|0]=c[n+(p<<3)>>2];eb=J-1|0;if((eb|0)>(fb|0)){k=n+(p<<3)+4|0;J=eb}else{break}}hb=c[gb>>2]|0;ib=hb+8|0;jb=c[ib>>2]|0;kb=j|0;c[kb>>2]=jb;lb=c[ib>>2]|0;c[t>>2]=lb;mb=hb+12|0;nb=c[mb>>2]|0;c[v>>2]=nb;ob=hb+16|0;pb=c[ob>>2]|0;qb=pb&65535;b[f>>1]=qb;rb=j+8|0;c[rb>>2]=pb;sb=c[ob>>2]|0;tb=j+32|0;c[tb>>2]=sb;return}function Llb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=c[a+60>>2]|0;e=c[a+100>>2]|0;do{if((e|0)>23){if((Y$(a,c[a+96>>2]|0,e,b|0,d+32|0)|0)>=0){c[d>>2]=c[a+416>>2];c[d+20>>2]=1;break}KIb(a,16,2438040,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;g=-1094995529;i=b;return g|0}}while(0);c[a+420>>2]=6;g=0;i=b;return g|0}function Mlb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;h=i;i=i+8|0;j=h|0;k=e;l=g+28|0;m=c[l>>2]|0;n=c[a+60>>2]|0;o=n;p=g+24|0;g=c[p>>2]|0;q=g+m|0;r=n+24|0;if((c[r>>2]|0)!=0){c[f>>2]=0;s=m;i=h;return s|0}t=n+20|0;u=c[t>>2]|0;do{if((u|0)==0&(m|0)>1){v=g;if(!((d[v]|d[v+1|0]<<8)<<16>>16<<16>>16==128)){s=-1094995529;i=h;return s|0}if((Y$(a,g,m,j,n+32|0)|0)<0){KIb(a,16,2438040,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;s=-1094995529;i=h;return s|0}c[n>>2]=c[a+416>>2];c[t>>2]=1;v=c[j>>2]|0;if((m|0)<(v|0)){s=-1094995529;i=h;return s|0}else{w=m-v|0;x=g+v|0;break}}else{if((u|0)==0){s=-1094995529}else{w=m;x=g;break}i=h;return s|0}}while(0);g=n;m=(w|0)/((c[g>>2]|0)*18|0|0)|0;do{if((m|0)!=0){if(((w|0)%((c[a+416>>2]|0)*18|0|0)|0|0)!=0){break}u=e+76|0;c[u>>2]=m<<5;j=M4a(a,k,0)|0;if((j|0)<0){s=j;i=h;return s|0}j=c[e+64>>2]|0;t=q;v=n+32|0;y=n+36|0;z=0;A=x;B=m;C=c[g>>2]|0;while(1){D=B-1|0;a:do{if((C|0)>0){E=A;F=0;G=C;while(1){if((t-E|0)<18){break}H=E;I=(he((d[H]|d[H+1|0]<<8)<<16>>16|0)|0)&65535;if((I&32768|0)!=0){break}H=(E+2|0)==0?8:136;J=o+4+(F<<3)|0;K=o+4+(F<<3)+4|0;L=I<<12;I=c[v>>2]|0;M=c[y>>2]|0;N=0;O=0;P=(c[j+(F<<2)>>2]|0)+(z<<1)|0;Q=c[J>>2]|0;R=c[K>>2]|0;while(1){S=E+((N>>>3)+2)|0;T=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(N&7)>>28;S=N+4|0;U=(ca(Q,I)|0)+(ca(R,M)|0)+(ca(L,T)|0)|0;T=U>>12;if((T+32768|0)>>>0>65535>>>0){V=(U>>31^32767)&65535}else{V=T&65535}W=V<<16>>16;b[P>>1]=V;T=O+1|0;if((T|0)<32){N=H>>>0>S>>>0?S:H;O=T;P=P+2|0;R=Q;Q=W}else{break}}c[J>>2]=W;c[K>>2]=Q;R=E+18|0;P=F+1|0;O=c[g>>2]|0;if((P|0)<(O|0)){E=R;F=P;G=O}else{X=R;Y=O;Z=26;break a}}c[r>>2]=1;_=(c[p>>2]|0)+(c[l>>2]|0)|0;$=G;aa=0}else{X=A;Y=C;Z=26}}while(0);if((Z|0)==26){Z=0;_=X;$=Y;aa=(c[r>>2]|0)==0}ba=aa?z+32|0:z;if((D|0)==0){break}else{z=ba;A=_;B=D;C=$}}c[u>>2]=ba;c[f>>2]=1;s=_-(c[p>>2]|0)|0;i=h;return s|0}}while(0);if((w|0)<=3){s=-1094995529;i=h;return s|0}w=x;if(((d[w]|d[w+1|0]<<8)<<16>>16&128)==0){s=-1094995529;i=h;return s|0}c[r>>2]=1;c[f>>2]=0;s=c[l>>2]|0;i=h;return s|0}function Nlb(a){a=a|0;var b=0;b=c[a+60>>2]|0;mrc(b+4|0,0,16)|0;c[b+24>>2]=0;return}function Olb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[a+60>>2]|0;if((c[a+416>>2]|0)>2){KIb(a,16,2289248,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;f=-22;i=b;return f|0}else{c[a+424>>2]=32;c[d+28>>2]=500;X$(500,c[a+412>>2]|0,12,d+32|0);f=0;i=b;return f|0}return 0}function Plb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;i=i+128|0;j=h|0;k=d+60|0;l=c[k>>2]|0;m=c[f>>2]|0;f=d+416|0;n=l+20|0;o=(-((c[n>>2]|0)==0|0)&36)+((c[f>>2]|0)*18|0)|0;p=d5a(d,e,o,(o|0)<0|0?-1:0)|0;if((p|0)<0){q=p;i=h;return q|0}p=c[e+24>>2]|0;if((c[n>>2]|0)==0){e=c[k>>2]|0;k=p;y=128;a[k]=y;y=y>>8;a[k+1|0]=y;k=p+2|0;y=8192;a[k]=y;y=y>>8;a[k+1|0]=y;a[p+4|0]=3;a[p+5|0]=18;a[p+6|0]=4;a[p+7|0]=c[f>>2];k=p+8|0;y=je(c[d+412>>2]|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=p+12|0;y=0;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;k=p+16|0;y=he(c[e+28>>2]&65535|0)|0;a[k]=y;y=y>>8;a[k+1|0]=y;a[p+18|0]=3;k=p+30|0;mrc(p+19|0,0,11)|0;a[k]=a[2350832]|0;a[k+1|0]=a[2350833]|0;a[k+2|0]=a[2350834]|0;a[k+3|0]=a[2350835]|0;a[k+4|0]=a[2350836]|0;a[k+5|0]=a[2350837]|0;c[n>>2]=1;r=p+36|0}else{r=p}p=c[f>>2]|0;if((p|0)>0){n=l+4|0;k=l+32|0;e=l+36|0;l=0;d=r;r=p;while(1){p=n+(l<<3)|0;o=n+(l<<3)+4|0;s=c[k>>2]|0;t=c[e>>2]|0;u=0;v=0;w=c[p>>2]|0;x=c[o>>2]|0;z=0;A=0;while(1){B=b[m+(v+l<<1)>>1]|0;C=(B<<12)-((ca(w,s)|0)+(ca(x,t)|0))>>12;c[j+(u<<2)>>2]=C;D=(z|0)<(C|0)?C:z;E=(A|0)>(C|0)?C:A;C=u+1|0;if((C|0)<32){u=C;v=v+r|0;x=w;w=B;z=D;A=E}else{break}}c[p>>2]=B;c[o>>2]=w;do{if((E|D|0)==0){mrc(d|0,0,18)|0}else{A=(D|0)/7|0;z=(E|0)/-8|0;x=(A|0)>(z|0)?A:z;z=(x|0)==0?1:x;x=d;y=he(z&65535|0)|0;a[x]=y;y=y>>8;a[x+1|0]=y;x=d+2|0;A=32;v=0;u=0;while(1){t=(c[j+(v<<2)>>2]|0)/(z|0)|0;if((t|0)<-8){F=8}else{F=(t|0)>7?7:t&15}if((A|0)>4){G=A-4|0;H=F|u<<4;I=x}else{t=x;y=je(F>>>((4-A|0)>>>0)|u<<A|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;G=A+28|0;H=F;I=x+4|0}t=v+1|0;if((t|0)<32){x=I;A=G;v=t;u=H}else{break}}if((G|0)>=32){break}u=H<<G;v=u>>>24&255;A=G;x=I;z=u;while(1){a[x]=v;u=A+8|0;if((u|0)<32){v=z>>>16&255;A=u;x=x+1|0;z=z<<8}else{break}}}}while(0);w=l+1|0;o=c[f>>2]|0;if((w|0)<(o|0)){l=w;d=d+18|0;r=o}else{break}}}c[g>>2]=1;q=0;i=h;return q|0}function Qlb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+64|0;e=d|0;f=c[b+60>>2]|0;c[f>>2]=b;c[b+140>>2]=0;l8(f+8|0,b);g=0;do{a[e+g|0]=g;g=g+1|0;}while((g|0)<64);L6(f+1136|0,f+1252|0,e|0);e=(c[b+120>>2]|0)+15>>4;c[f+1392>>2]=e;c[f+1396>>2]=(c[b+124>>2]|0)+15>>4;g=f+1384|0;c[g>>2]=16;h=(e|0)/16|0;j=f+1388|0;c[j>>2]=h;k=1;while(1){if(((e|0)%(k|0)|0|0)==0){l=(e|0)/(k|0)|0;if((l|0)<32){m=6;break}}n=k+1|0;if((n|0)<32){k=n}else{o=h;break}}if((m|0)==6){c[j>>2]=l;c[g>>2]=k;o=l}l=hJb(o*768|0)|0;o=l;c[f+1408>>2]=o;if((l|0)==0){KIb(b,16,2610984,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;p=-12;i=d;return p|0}else{c[f+1412>>2]=o;b=c[j>>2]|0;c[f+1416>>2]=o+(b<<6<<1);c[f+1420>>2]=o+((b*96|0)<<1);c[f+1424>>2]=o+((b*288|0)<<1);p=0;i=d;return p|0}return 0}function Rlb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0;k=i;i=i+32|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=c[f+60>>2]|0;q=p;r=c[j+24>>2]|0;s=j+28|0;j=c[s>>2]|0;t=g;u=p+4|0;c[u>>2]=t;c[g+88>>2]=1;c[g+84>>2]=1;g=p+1384|0;v=p+1396|0;w=(ca(c[g>>2]<<1,c[v>>2]|0)|0)+27&-4;if(j>>>0<w>>>0){KIb(f,16,2437992,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=k;return y|0}z=a[r]|0;if(!(z<<24>>24==1)){KIb(c[p>>2]|0,16,2166512,(x=i,i=i+8|0,c[x>>2]=z&255,x)|0);i=x;y=-1094995529;i=k;return y|0}z=a[r+1|0]|0;if(!(z<<24>>24==22)){KIb(c[p>>2]|0,16,2140096,(x=i,i=i+8|0,c[x>>2]=z&255,x)|0);i=x;y=-1094995529;i=k;return y|0}z=r+2|0;A=je(d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0)|0;z=r+6|0;B=(he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535;z=r+8|0;C=(he((d[z]|d[z+1|0]<<8)<<16>>16|0)|0)&65535;z=c[p>>2]|0;if(A>>>0>j>>>0){KIb(z,16,2116712,(x=i,i=i+16|0,c[x>>2]=A,c[x+8>>2]=j,x)|0);i=x;y=-1094995529;i=k;return y|0}A=c[z+120>>2]|0;D=c[z+124>>2]|0;if(!((B|0)==(A|0)&(C|0)==(D|0))){KIb(z,16,2634592,(x=i,i=i+32|0,c[x>>2]=A,c[x+8>>2]=D,c[x+16>>2]=B,c[x+24>>2]=C,x)|0);i=x;y=-1094995529;i=k;return y|0}C=p+1400|0;c[C>>2]=d[r+15|0]|0;B=p+1404|0;c[B>>2]=(a[r+16|0]&-16)<<24>>24==48;D=M4a(f,t,0)|0;if((D|0)<0){y=D;i=k;return y|0}D=c[v>>2]|0;t=ca(c[g>>2]<<1,D)|0;if(!((t|0)>-1)){KIb(0,0,2289216,(x=i,i=i+24|0,c[x>>2]=2238904,c[x+8>>2]=2198056,c[x+16>>2]=135,x)|0);i=x;Hd();return 0}a:do{if((D|0)>0){g=p+1392|0;A=r+(t+24)|0;z=p+1388|0;E=p+1412|0;F=p+1416|0;G=p+1420|0;H=p+1424|0;I=p+1408|0;J=p+1440|0;K=p+1256|0;L=p+1124|0;M=p+20|0;N=r+24|0;O=w;P=0;Q=c[g>>2]|0;R=D;b:while(1){if((Q|0)>0){S=N;T=O;U=0;V=Q;while(1){if((A-S|0)<2){break b}W=S+2|0;X=S;Y=(d[X]|d[X+1|0]<<8)<<16>>16;X=Y&65535;Z=(X<<2)+T|0;if(!(Z>>>0<=j>>>0&Y<<16>>16!=0)){break b}Y=c[z>>2]|0;_=V-U|0;c[l>>2]=c[E>>2];c[m>>2]=c[F>>2];c[n>>2]=c[G>>2];c[o>>2]=c[H>>2];$=c[u>>2]|0;aa=c[$+32>>2]|0;ba=(ca(aa,P)|0)+U<<4;da=(c[$+4>>2]|0)+((ca(c[$+36>>2]|0,P)|0)+U<<3)|0;ea=(c[$+8>>2]|0)+((ca(c[$+40>>2]|0,P)|0)+U<<3)|0;fa=(Y|0)>(_|0)?_:Y;Y=(c[$>>2]|0)+ba|0;ba=(r+T|0)==0?8:X<<5|8;mrc(c[I>>2]|0,0,fa*768|0|0)|0;X=(fa|0)>0;$=(c[B>>2]|0)==0|0;_=0;ga=0;c:while(1){ha=c[q+1412+(ga<<2)>>2]|0;ia=c[2023336+(ga<<2)>>2]|0;ja=c[2023256+((ga|$)<<2)>>2]|0;ka=d[r+((_>>>3)+T)|0]|0;la=((_|0)<(ba|0))+_|0;ma=((la|0)<(ba|0))+la|0;na=(d[r+((la>>>3)+T)|0]|0)<<(la&7)>>>7&1;la=r+((ma>>>3)+T)|0;oa=(je(d[la]|d[la+1|0]<<8|d[la+2|0]<<16|d[la+3|0]<<24|0)|0)<<(ma&7)>>>29;la=ma+3|0;ma=ba>>>0>la>>>0?la:ba;do{if((ka&128>>>((_&7)>>>0)|0)==0){if(!X){pa=ma;break}la=(na|0)==0;qa=(oa|0)==0;ra=32-oa|0;sa=ha;ta=0;ua=ma;while(1){if(la){va=0;wa=ua;while(1){xa=0;ya=wa;while(1){if((xa|0)>=31){za=ya;break}Aa=((ya|0)<(ba|0))+ya|0;if(((d[r+((ya>>>3)+T)|0]|0)&128>>>((ya&7)>>>0)|0)==0){xa=xa+1|0;ya=Aa}else{za=Aa;break}}if(qa){Ba=xa;Ca=za}else{ya=r+((za>>>3)+T)|0;Aa=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(za&7)>>>(ra>>>0);ya=za+oa|0;Ba=Aa+(xa<<oa)|0;Ca=ba>>>0>ya>>>0?ya:ba}if(Ba>>>0>65535>>>0){Da=-1094995529;break c}b[sa+((d[ja+va|0]|0)<<1)>>1]=Ba;ya=va+1|0;if((ya|0)<(ia|0)){va=ya;wa=Ca}else{Ea=Ca;break}}}else{wa=0;va=ua;while(1){ya=r+((va>>>3)+T)|0;Aa=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(va&7);if(Aa>>>0>134217727>>>0){ya=Aa>>>23;Fa=(d[1382088+ya|0]|0)+va|0;Ga=d[1276064+ya|0]|0;Ha=ba>>>0>Fa>>>0?Fa:ba}else{Fa=Aa>>>0>65535>>>0;ya=Fa?Aa>>>16:Aa;Ia=Fa?16:0;if((ya&65280|0)==0){Ja=Ia;Ka=ya}else{Ja=Ia|8;Ka=ya>>>8}ya=(d[1359664+Ka|0]|0)+Ja<<1;Ia=63-ya+va|0;Ga=(Aa>>>((ya-31|0)>>>0))-1|0;Ha=ba>>>0>Ia>>>0?Ia:ba}if(qa){La=Ga;Ma=Ha}else{Ia=r+((Ha>>>3)+T)|0;ya=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(Ha&7)>>>(ra>>>0);Ia=Ha+oa|0;La=ya+(Ga<<oa)|0;Ma=ba>>>0>Ia>>>0?Ia:ba}if(La>>>0>65535>>>0){Da=-1094995529;break c}b[sa+((d[ja+wa|0]|0)<<1)>>1]=La;Ia=wa+1|0;if((Ia|0)<(ia|0)){wa=Ia;va=Ma}else{Ea=Ma;break}}}va=ta+1|0;if((va|0)<(fa|0)){sa=sa+(ia<<1)|0;ta=va;ua=Ea}else{pa=Ea;break}}}else{ua=((ma|0)<(ba|0))+ma|0;ta=r+((ua>>>3)+T)|0;sa=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(ua&7)>>>29;ta=ua+3|0;ua=ba>>>0>ta>>>0?ta:ba;if(!X){pa=ua;break}ta=((d[r+((ma>>>3)+T)|0]|0)&128>>>((ma&7)>>>0)|0)==0;ra=(sa|0)==0;qa=(na|0)==0;la=(oa|0)==0;va=ia-1|0;wa=32-oa|0;Ia=32-sa|0;ya=ha;Aa=0;Fa=ua;while(1){ua=-1;Na=Fa;while(1){d:do{if(ta){Oa=0;Pa=Na;while(1){if((Oa|0)>=31){Qa=Oa;Ra=Pa;break d}Sa=((Pa|0)<(ba|0))+Pa|0;if(((d[r+((Pa>>>3)+T)|0]|0)&128>>>((Pa&7)>>>0)|0)==0){Oa=Oa+1|0;Pa=Sa}else{Qa=Oa;Ra=Sa;break}}}else{Oa=r+((Na>>>3)+T)|0;Pa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Na&7);if(Pa>>>0>134217727>>>0){Oa=Pa>>>23;Sa=(d[1382088+Oa|0]|0)+Na|0;Qa=d[1276064+Oa|0]|0;Ra=ba>>>0>Sa>>>0?Sa:ba;break}Sa=Pa>>>0>65535>>>0;Oa=Sa?Pa>>>16:Pa;Ta=Sa?16:0;if((Oa&65280|0)==0){Ua=Ta;Va=Oa}else{Ua=Ta|8;Va=Oa>>>8}Oa=(d[1359664+Va|0]|0)+Ua<<1;Ta=63-Oa+Na|0;Qa=(Pa>>>((Oa-31|0)>>>0))-1|0;Ra=ba>>>0>Ta>>>0?Ta:ba}}while(0);if(ra){Wa=Qa;Xa=Ra}else{xa=r+((Ra>>>3)+T)|0;Ta=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ra&7)>>>(Ia>>>0);xa=Ra+sa|0;Wa=Ta+(Qa<<sa)|0;Xa=ba>>>0>xa>>>0?xa:ba}if(Wa>>>0>65535>>>0){Da=-1094995529;break c}xa=ua+1+Wa|0;if((xa|0)>=(ia|0)){Ya=Xa;break}e:do{if(qa){Ta=0;Oa=Xa;while(1){if((Ta|0)>=31){Za=Ta;_a=Oa;break e}Pa=((Oa|0)<(ba|0))+Oa|0;if(((d[r+((Oa>>>3)+T)|0]|0)&128>>>((Oa&7)>>>0)|0)==0){Ta=Ta+1|0;Oa=Pa}else{Za=Ta;_a=Pa;break}}}else{Ta=r+((Xa>>>3)+T)|0;Oa=(je(d[Ta]|d[Ta+1|0]<<8|d[Ta+2|0]<<16|d[Ta+3|0]<<24|0)|0)<<(Xa&7);if(Oa>>>0>134217727>>>0){Ta=Oa>>>23;Pa=(d[1382088+Ta|0]|0)+Xa|0;Za=d[1276064+Ta|0]|0;_a=ba>>>0>Pa>>>0?Pa:ba;break}Pa=Oa>>>0>65535>>>0;Ta=Pa?Oa>>>16:Oa;Sa=Pa?16:0;if((Ta&65280|0)==0){$a=Sa;ab=Ta}else{$a=Sa|8;ab=Ta>>>8}Ta=(d[1359664+ab|0]|0)+$a<<1;Sa=63-Ta+Xa|0;Za=(Oa>>>((Ta-31|0)>>>0))-1|0;_a=ba>>>0>Sa>>>0?Sa:ba}}while(0);if(la){bb=Za;cb=_a}else{Sa=r+((_a>>>3)+T)|0;Ta=(je(d[Sa]|d[Sa+1|0]<<8|d[Sa+2|0]<<16|d[Sa+3|0]<<24|0)|0)<<(_a&7)>>>(wa>>>0);Sa=_a+oa|0;bb=Ta+(Za<<oa)|0;cb=ba>>>0>Sa>>>0?Sa:ba}Sa=bb+1|0;if(Sa>>>0>65535>>>0){Da=-1094995529;break c}b[ya+((d[ja+xa|0]|0)<<1)>>1]=Sa;if((xa|0)<(va|0)){ua=xa;Na=cb}else{Ya=cb;break}}Na=Aa+1|0;if((Na|0)<(fa|0)){ya=ya+(ia<<1)|0;Aa=Na;Fa=Ya}else{pa=Ya;break}}}}while(0);ia=ga+1|0;if((ia|0)<4){_=pa;ga=ia}else{db=21;break}}do{if((db|0)==21){db=0;if(!X){Da=0;break}ga=aa<<3;_=aa<<1;ba=0;$=Y;ia=da;ja=ea;while(1){oa=0;do{do{if((c[B>>2]|0)==0){Tlb(J,K,l,n)}else{ha=c[n>>2]|0;if((oa|0)>=2){na=0;do{b[q+1440+((d[q+1256+na|0]|0)<<1)>>1]=b[ha+(na<<1)>>1]|0;na=na+1|0;}while((na|0)<64);c[n>>2]=ha+128;break}na=c[l>>2]|0;xa=0;ma=na;ka=ha;while(1){Fa=xa<<3;b[q+1440+((d[q+1256+Fa|0]|0)<<1)>>1]=b[ma>>1]|0;b[q+1440+((d[(Fa|1)+(q+1256)|0]|0)<<1)>>1]=b[ma+2>>1]|0;b[q+1440+((d[(Fa|2)+(q+1256)|0]|0)<<1)>>1]=b[ma+4>>1]|0;b[q+1440+((d[(Fa|3)+(q+1256)|0]|0)<<1)>>1]=b[ma+6>>1]|0;b[q+1440+((d[(Fa|4)+(q+1256)|0]|0)<<1)>>1]=b[ka>>1]|0;b[q+1440+((d[(Fa|5)+(q+1256)|0]|0)<<1)>>1]=b[ka+2>>1]|0;b[q+1440+((d[(Fa|6)+(q+1256)|0]|0)<<1)>>1]=b[ka+4>>1]|0;b[q+1440+((d[(Fa|7)+(q+1256)|0]|0)<<1)>>1]=b[ka+6>>1]|0;Fa=xa+1|0;if((Fa|0)<8){xa=Fa;ma=ma+8|0;ka=ka+8|0}else{break}}c[l>>2]=na+64;c[n>>2]=ha+64}}while(0);ka=c[C>>2]|0;ma=0;do{xa=q+1440+(ma<<1)|0;Fa=e[xa>>1]|0;Aa=Fa&1;b[xa>>1]=((ca(ca(d[2023272+ma|0]|0,ka)|0,Fa>>>1^-Aa)|0)>>>4)+Aa;ma=ma+1|0;}while((ma|0)<64);qe[c[L>>2]&1023](J);if((c[B>>2]|0)==0){ma=$+((ca(ga,oa>>1)|0)+(oa<<3&8))|0;ef[c[M>>2]&4095](J,ma,aa)}else{ma=$+((oa<<3&8)+(ca(oa>>1,aa)|0))|0;ef[c[M>>2]&4095](J,ma,_)}oa=oa+1|0;}while((oa|0)<4);Tlb(J,K,m,o);oa=c[C>>2]|0;ma=0;do{ka=q+1440+(ma<<1)|0;Aa=e[ka>>1]|0;Fa=Aa&1;b[ka>>1]=((ca(ca(d[2023272+ma|0]|0,oa)|0,Aa>>>1^-Fa)|0)>>>4)+Fa;ma=ma+1|0;}while((ma|0)<64);qe[c[L>>2]&1023](J);ef[c[M>>2]&4095](J,ia,c[(c[u>>2]|0)+36>>2]|0);Tlb(J,K,m,o);ma=c[C>>2]|0;oa=0;do{Fa=q+1440+(oa<<1)|0;Aa=e[Fa>>1]|0;ka=Aa&1;b[Fa>>1]=((ca(ca(d[2023272+oa|0]|0,ma)|0,Aa>>>1^-ka)|0)>>>4)+ka;oa=oa+1|0;}while((oa|0)<64);qe[c[L>>2]&1023](J);ef[c[M>>2]&4095](J,ja,c[(c[u>>2]|0)+40>>2]|0);oa=ba+1|0;if((oa|0)<(fa|0)){ba=oa;$=$+16|0;ia=ia+8|0;ja=ja+8|0}else{Da=0;break}}}}while(0);if((Da|0)<0){y=Da;db=98;break b}fa=(c[z>>2]|0)+U|0;eb=c[g>>2]|0;if((fa|0)<(eb|0)){S=W;T=Z;U=fa;V=eb}else{break}}fb=W;gb=Z;hb=eb;ib=c[v>>2]|0}else{fb=N;gb=O;hb=Q;ib=R}V=P+1|0;if((V|0)<(ib|0)){N=fb;O=gb;P=V;Q=hb;R=ib}else{break a}}if((db|0)==98){i=k;return y|0}KIb(f,16,2350808,(x=i,i=i+1|0,i=i+7&-8,c[x>>2]=0,x)|0);i=x;y=-1094995529;i=k;return y|0}}while(0);c[h>>2]=1;y=c[s>>2]|0;i=k;return y|0}function Slb(a){a=a|0;mJb((c[a+60>>2]|0)+1408|0);return 0}function Tlb(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=0;i=c[g>>2]|0;while(1){j=h<<3;k=c[f>>2]|0;b[a+((d[e+j|0]|0)<<1)>>1]=b[k>>1]|0;b[a+((d[e+(j|1)|0]|0)<<1)>>1]=b[k+2>>1]|0;b[a+((d[e+(j|2)|0]|0)<<1)>>1]=b[k+4>>1]|0;b[a+((d[e+(j|3)|0]|0)<<1)>>1]=b[k+6>>1]|0;b[a+((d[e+(j|4)|0]|0)<<1)>>1]=b[i>>1]|0;b[a+((d[e+(j|5)|0]|0)<<1)>>1]=b[i+2>>1]|0;b[a+((d[e+(j|6)|0]|0)<<1)>>1]=b[i+4>>1]|0;b[a+((d[e+(j|7)|0]|0)<<1)>>1]=b[i+6>>1]|0;c[f>>2]=k+8;k=(c[g>>2]|0)+8|0;c[g>>2]=k;j=h+1|0;if((j|0)<4){h=j;i=k}else{l=4;m=k;break}}do{i=l<<3;b[a+((d[e+i|0]|0)<<1)>>1]=b[m>>1]|0;b[a+((d[e+(i|1)|0]|0)<<1)>>1]=b[m+2>>1]|0;b[a+((d[e+(i|2)|0]|0)<<1)>>1]=b[m+4>>1]|0;b[a+((d[e+(i|3)|0]|0)<<1)>>1]=b[m+6>>1]|0;b[a+((d[e+(i|4)|0]|0)<<1)>>1]=b[m+8>>1]|0;b[a+((d[e+(i|5)|0]|0)<<1)>>1]=b[m+10>>1]|0;b[a+((d[e+(i|6)|0]|0)<<1)>>1]=b[m+12>>1]|0;b[a+((d[e+(i|7)|0]|0)<<1)>>1]=b[m+14>>1]|0;m=m+16|0;c[g>>2]=m;l=l+1|0;}while((l|0)<8);return}function Ulb(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;f=c[b+60>>2]|0;g=f;h=f;c[h>>2]=b;if((c[b+100>>2]|0)<36){KIb(b,16,2584480,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1094995529;i=e;return k|0}l=c[b+96>>2]|0;m=l+12|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=je(n|0)|0;o=f+52|0;c[o>>2]=m;if((n|0)==0|m>>>0>536870911>>>0){n=b;KIb(n,16,2475544,(j=i,i=i+8|0,c[j>>2]=m,j)|0);i=j;KIb(n,16,2563632,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-1;i=e;return k|0}n=a[l+17|0]|0;m=f+56|0;a[m]=n;a[f+57|0]=a[l+18|0]|0;a[f+58|0]=a[l+19|0]|0;a[f+59|0]=a[l+20|0]|0;p=f+24|0;c[p>>2]=d[l+21|0]|0;l=n&255;if((l|0)==16){c[b+420>>2]=6}else if((l|0)==24|(l|0)==32){c[b+420>>2]=7}else{QIb(b,2545976,(j=i,i=i+8|0,c[j>>2]=l,j)|0);i=j;k=-1163346256;i=e;return k|0}c[b+796>>2]=d[m]|0;l=c[p>>2]|0;do{if((l|0)<1){KIb(b,24,2528256,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;c[p>>2]=c[b+416>>2]}else{n=b+416|0;if((l|0)>8){c[p>>2]=c[n>>2];break}else{c[n>>2]=l;break}}}while(0);l=c[b+416>>2]|0;if((l-1|0)>>>0>7>>>0){KIb(b,16,2513288,(j=i,i=i+8|0,c[j>>2]=l,j)|0);i=j;k=-1163346256;i=e;return k|0}l=c[p>>2]|0;n=1433664+(l-1<<3)|0;q=c[n+4>>2]|0;r=b+448|0;c[r>>2]=c[n>>2];c[r+4>>2]=q;q=c[o>>2]<<2;o=f+68|0;if((q|0)==0){if((l|0)>0){s=0}else{k=0;i=e;return k|0}while(1){c[g+28+(s<<2)>>2]=hJb(0)|0;if((d[m]|0)>>>0>16>>>0){f=(RKb(c[(c[h>>2]|0)+420>>2]|0)|0)!=0;c[o>>2]=f&1;if(!f){t=21}}else{c[o>>2]=0;t=21}if((t|0)==21){t=0;c[g+36+(s<<2)>>2]=hJb(0)|0}c[g+44+(s<<2)>>2]=hJb(0)|0;f=s+1|0;r=c[p>>2]|0;if((f|0)<(((r|0)>2?2:r)|0)){s=f}else{k=0;break}}i=e;return k|0}else{u=0;v=l}while(1){if((u|0)>=(((v|0)>2?2:v)|0)){k=0;t=40;break}l=hJb(q)|0;c[g+28+(u<<2)>>2]=l;if((l|0)==0){t=25;break}if((d[m]|0)>>>0>16>>>0){l=(RKb(c[(c[h>>2]|0)+420>>2]|0)|0)!=0;c[o>>2]=l&1;if(!l){t=29}}else{c[o>>2]=0;t=29}if((t|0)==29){t=0;l=hJb(q)|0;c[g+36+(u<<2)>>2]=l;if((l|0)==0){t=30;break}}l=hJb(q)|0;c[g+44+(u<<2)>>2]=l;if((l|0)==0){t=33;break}u=u+1|0;v=c[p>>2]|0}if((t|0)==25){KIb(c[h>>2]|0,16,2487016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}else if((t|0)==30){KIb(c[h>>2]|0,16,2487016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}else if((t|0)==33){KIb(c[h>>2]|0,16,2487016,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}else if((t|0)==40){i=e;return k|0}t=c[(c[h>>2]|0)+60>>2]|0;h=t+24|0;if((c[h>>2]|0)>0){p=t+28|0;v=t+68|0;u=t+36|0;g=t+44|0;t=0;do{mJb(p+(t<<2)|0);if((c[v>>2]|0)==0){mJb(u+(t<<2)|0)}mJb(g+(t<<2)|0);t=t+1|0;q=c[h>>2]|0;}while((t|0)<(((q|0)>2?2:q)|0))}KIb(b,16,2499632,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j;k=-12;i=e;return k|0}function Vlb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0;k=i;i=i+176|0;l=k|0;m=k+16|0;n=k+144|0;o=k+152|0;p=k+160|0;q=k+168|0;r=f+60|0;s=c[r>>2]|0;t=g;u=c[j+24>>2]|0;v=j+28|0;j=c[v>>2]|0;w=j>>>0>268435455>>>0?-8:j<<3;j=w>>>0>2147483639>>>0|(u|0)==0;x=j?0:u;u=j?0:w;w=s+4|0;c[w>>2]=x;y=s+16|0;c[y>>2]=u;z=u+8|0;A=s+20|0;c[A>>2]=z;c[s+8>>2]=x+(u>>3);B=s+12|0;c[B>>2]=0;if(j){C=j?-1094995529:0;i=k;return C|0}c[s+64>>2]=0;a:do{if((u|0)>2){j=s+24|0;D=f;E=l|0;F=l+4|0;G=l+8|0;H=g+76|0;I=f+420|0;J=g+64|0;K=0;L=0;M=z;N=x;while(1){O=N+(L>>>3)|0;P=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(L&7)>>>29;O=L+3|0;Q=M>>>0>O>>>0?O:M;c[B>>2]=Q;if((P|0)==7){R=159;break}else if(!((P|0)==3|(P|0)==1|(P|0)==0)){R=6;break}O=(P|0)==1;S=O?2:1;T=S+K|0;U=c[j>>2]|0;if((T|0)>(U|0)){R=9;break}V=d[1433736+(U-1<<3)+K|0]|0;if((V+S|0)>(U|0)){R=9;break}U=c[r>>2]|0;W=U+12|0;X=U+20|0;Y=c[X>>2]|0;Z=(c[W>>2]|0)+4|0;_=(Y>>>0>Z>>>0?Z:Y)+12|0;Z=Y>>>0>_>>>0?_:Y;c[W>>2]=Z;_=U+4|0;$=c[_>>2]|0;aa=a[$+(Z>>>3)|0]|0;ba=((Z|0)<(Y|0))+Z|0;c[W>>2]=ba;da=$+(ba>>>3)|0;ea=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ba&7)>>>30;da=ba+2|0;ba=Y>>>0>da>>>0?da:Y;c[W>>2]=ba;da=ea<<3;ea=U+60|0;c[ea>>2]=da;fa=U+56|0;ga=(d[fa]|0)-da+S|0;da=ga-1|0;b:do{if(da>>>0>32>>>0){KIb(D,16,2166488,(ha=i,i=i+8|0,c[ha>>2]=da,ha)|0);i=ha;ia=-1163346256}else{ja=d[$+(ba>>>3)|0]|0;ka=((ba|0)<(Y|0))+ba|0;c[W>>2]=ka;la=(ja&128>>>((ba&7)>>>0)|0)==0;if((128>>>((Z&7)>>>0)&(aa&255)|0)==0){ma=c[U+52>>2]|0}else{ja=$+(ka>>>3)|0;na=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ka&7)&-65536;ja=ka+16|0;ka=Y>>>0>ja>>>0?ja:Y;c[W>>2]=ka;ja=$+(ka>>>3)|0;oa=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ka&7)>>>16;ja=ka+16|0;c[W>>2]=Y>>>0>ja>>>0?ja:Y;ma=oa|na}do{if((ma|0)!=0){na=U+52|0;if(ma>>>0>(c[na>>2]|0)>>>0){break}oa=U+64|0;ja=c[oa>>2]|0;do{if((ja|0)==0){c[E>>2]=t;c[F>>2]=0;c[G>>2]=0;c[H>>2]=ma;ka=J5a(f,l,0)|0;if((ka|0)<0){ia=ka;break b}}else{if((ma|0)==(ja|0)){break}KIb(D,16,2116672,(ha=i,i=i+16|0,c[ha>>2]=ma,c[ha+8>>2]=ja,ha)|0);i=ha;ia=-1094995529;break b}}while(0);c[oa>>2]=ma;if((c[U+68>>2]|0)!=0){ja=U+36|0;ka=0;do{c[ja+(ka<<2)>>2]=c[(c[J>>2]|0)+(ka+V<<2)>>2];ka=ka+1|0;}while((ka|0)<(S|0))}do{if(la){ka=c[W>>2]|0;ja=c[X>>2]|0;pa=c[_>>2]|0;qa=pa+(ka>>>3)|0;ra=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ka&7)>>>24;qa=ka+8|0;ka=ja>>>0>qa>>>0?qa:ja;c[W>>2]=ka;qa=pa+(ka>>>3)|0;sa=(je(d[qa]|d[qa+1|0]<<8|d[qa+2|0]<<16|d[qa+3|0]<<24|0)|0)<<(ka&7)>>>24;qa=ka+8|0;ka=ja>>>0>qa>>>0?qa:ja;c[W>>2]=ka;qa=c[na>>2]|0;ta=0;ua=ka;while(1){ka=pa+(ua>>>3)|0;va=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(ua&7)>>>28;ka=ua+4|0;wa=ja>>>0>ka>>>0?ka:ja;c[W>>2]=wa;c[o+(ta<<2)>>2]=va;va=pa+(wa>>>3)|0;ka=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7)>>>28;va=wa+4|0;wa=ja>>>0>va>>>0?va:ja;c[W>>2]=wa;c[p+(ta<<2)>>2]=ka;ka=pa+(wa>>>3)|0;va=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(wa&7)>>>29;ka=wa+3|0;wa=ja>>>0>ka>>>0?ka:ja;c[W>>2]=wa;c[q+(ta<<2)>>2]=va;va=pa+(wa>>>3)|0;ka=(je(d[va]|d[va+1|0]<<8|d[va+2|0]<<16|d[va+3|0]<<24|0)|0)<<(wa&7)>>>27;va=wa+5|0;wa=ja>>>0>va>>>0?va:ja;c[W>>2]=wa;c[n+(ta<<2)>>2]=ka;if(!(ka>>>0<qa>>>0)){ia=-1094995529;break b}if((ka|0)==0){xa=wa}else{va=ka;ka=wa;while(1){wa=va-1|0;ya=pa+(ka>>>3)|0;za=(je(d[ya]|d[ya+1|0]<<8|d[ya+2|0]<<16|d[ya+3|0]<<24|0)|0)<<(ka&7)>>>16;ya=ka+16|0;Aa=ja>>>0>ya>>>0?ya:ja;c[W>>2]=Aa;b[m+(ta<<6)+(wa<<1)>>1]=za;if((wa|0)>0){va=wa;ka=Aa}else{xa=Aa;break}}}ka=ta+1|0;if((ka|0)<(S|0)){ta=ka;ua=xa}else{break}}c:do{if((c[ea>>2]|0)!=0){if((c[oa>>2]|0)<=0){break}ua=U+16|0;ta=U+44|0;if(((c[ua>>2]|0)-xa|0)<1){ia=-1;break b}else{Ba=xa;Ca=0}while(1){ja=0;qa=Ba;while(1){ka=c[ea>>2]|0;va=c[X>>2]|0;Aa=pa+(qa>>>3)|0;wa=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(qa&7)>>>((32-ka|0)>>>0);Aa=ka+qa|0;c[W>>2]=va>>>0>Aa>>>0?Aa:va;c[(c[ta+(ja<<2)>>2]|0)+(Ca<<2)>>2]=wa;wa=ja+1|0;if((wa|0)>=(S|0)){break}ja=wa;qa=c[W>>2]|0}qa=Ca+1|0;if((qa|0)>=(c[oa>>2]|0)){break c}ja=c[W>>2]|0;if(((c[ua>>2]|0)-ja|0)<1){ia=-1;break b}else{Ba=ja;Ca=qa}}}}while(0);pa=U+28|0;ua=U+57|0;ta=U+58|0;qa=U+16|0;ja=U+59|0;wa=(da|0)==0;va=(da|0)<26;Aa=33-ga|0;ka=ga-17|0;za=49-ga|0;ya=U;Da=U+36|0;Ea=Da;Fa=0;do{Ga=pa+(Fa<<2)|0;Ha=c[Ga>>2]|0;Ia=c[oa>>2]|0;Ja=(ca(d[ua]|0,c[q+(Fa<<2)>>2]|0)|0)/4|0;if((Ia|0)>0){Ka=0;La=d[ta]|0;Ma=0;while(1){Na=c[W>>2]|0;if(((c[qa>>2]|0)-Na|0)<1){ia=-1;break b}Oa=(La>>>9)+3|0;Pa=Oa>>>0>65535>>>0;Qa=Pa?Oa>>>16:Oa;Oa=Pa?16:0;if((Qa&65280|0)==0){Ra=Oa;Sa=Qa}else{Ra=Oa|8;Sa=Qa>>>8}Qa=(d[1359664+Sa|0]|0)+Ra|0;Oa=d[ja]|0;Pa=(Qa|0)>(Oa|0)?Oa:Qa;Qa=0;Oa=Na;while(1){if((Qa|0)>=9){Ta=Oa;R=51;break}Ua=c[_>>2]|0;Na=d[Ua+(Oa>>>3)|0]|0;Va=c[X>>2]|0;Wa=((Oa|0)<(Va|0))+Oa|0;c[W>>2]=Wa;if((Na&128>>>((Oa&7)>>>0)|0)==0){R=50;break}else{Qa=Qa+1|0;Oa=Wa}}do{if((R|0)==50){R=0;if(Qa>>>0>8>>>0){Ta=Wa;R=51;break}if((Pa|0)==1){Xa=Qa;break}Oa=Ua+(Wa>>>3)|0;Na=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Wa&7)>>>((32-Pa|0)>>>0);Oa=(Qa<<Pa)-Qa|0;if((Na|0)>1){Ya=Wa+Pa|0;c[W>>2]=Va>>>0>Ya>>>0?Ya:Va;Xa=Oa-1+Na|0;break}else{Na=Pa-1+Wa|0;c[W>>2]=Va>>>0>Na>>>0?Na:Va;Xa=Oa;break}}}while(0);do{if((R|0)==51){R=0;if(wa){Xa=0;break}Pa=c[X>>2]|0;Qa=c[_>>2]|0;Oa=Qa+(Ta>>>3)|0;Na=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Ta&7);if(va){Oa=Ta+da|0;c[W>>2]=Pa>>>0>Oa>>>0?Oa:Pa;Xa=Na>>>(Aa>>>0);break}else{Oa=Ta+16|0;Ya=Pa>>>0>Oa>>>0?Oa:Pa;c[W>>2]=Ya;Oa=Qa+(Ya>>>3)|0;Qa=(je(d[Oa]|d[Oa+1|0]<<8|d[Oa+2|0]<<16|d[Oa+3|0]<<24|0)|0)<<(Ya&7)>>>(za>>>0);Oa=Ya+ka|0;c[W>>2]=Pa>>>0>Oa>>>0?Oa:Pa;Xa=Qa|Na>>>16<<ka;break}}}while(0);Na=Xa+Ma|0;c[Ha+(Ka<<2)>>2]=Na>>>1^-(Na&1);do{if(Na>>>0>65535>>>0){Za=0;_a=65535;$a=Ka}else{Qa=(ca(Na,Ja)|0)-((ca(La,Ja)|0)>>>9)+La|0;if(!(Qa>>>0<128>>>0)){Za=0;_a=Qa;$a=Ka;break}Pa=Ka+1|0;if((Pa|0)>=(Ia|0)){Za=0;_a=Qa;$a=Ka;break}Oa=(Qa&65280|0)==0;Ya=((Qa+16|0)>>>6)+7+(Oa?0:-8)-(d[1359664+(Oa?Qa:Qa>>>8)|0]|0)|0;Qa=d[ja]|0;Oa=(Ya|0)>(Qa|0)?Qa:Ya;Ya=0;Qa=c[W>>2]|0;while(1){if((Ya|0)>=9){R=66;break}ab=c[_>>2]|0;bb=d[ab+(Qa>>>3)|0]|0;cb=c[X>>2]|0;db=((Qa|0)<(cb|0))+Qa|0;c[W>>2]=db;if((bb&128>>>((Qa&7)>>>0)|0)==0){R=65;break}else{Ya=Ya+1|0;Qa=db}}do{if((R|0)==65){R=0;if(Ya>>>0>8>>>0){eb=db;fb=cb;gb=ab;R=67;break}if((Oa|0)==1){hb=Ya;break}bb=ab+(db>>>3)|0;ib=(je(d[bb]|d[bb+1|0]<<8|d[bb+2|0]<<16|d[bb+3|0]<<24|0)|0)<<(db&7)>>>((32-Oa|0)>>>0);bb=(Ya<<Oa)-Ya|0;if((ib|0)>1){jb=db+Oa|0;c[W>>2]=cb>>>0>jb>>>0?jb:cb;hb=bb-1+ib|0;break}else{ib=Oa-1+db|0;c[W>>2]=cb>>>0>ib>>>0?ib:cb;hb=bb;break}}else if((R|0)==66){R=0;eb=Qa;fb=c[X>>2]|0;gb=c[_>>2]|0;R=67}}while(0);if((R|0)==67){R=0;Qa=gb+(eb>>>3)|0;Oa=(je(d[Qa]|d[Qa+1|0]<<8|d[Qa+2|0]<<16|d[Qa+3|0]<<24|0)|0)<<(eb&7)>>>16;Qa=eb+16|0;c[W>>2]=fb>>>0>Qa>>>0?Qa:fb;hb=Oa}if((hb|0)>0){Oa=Ia-Ka|0;if((hb|0)<(Oa|0)){kb=hb}else{KIb(c[ya>>2]|0,16,2610944,(ha=i,i=i+24|0,c[ha>>2]=hb,c[ha+8>>2]=Ia,c[ha+16>>2]=Ka,ha)|0);i=ha;kb=Oa-1|0}mrc(Ha+(Pa<<2)|0,0,kb<<2|0)|0;lb=kb;mb=kb+Ka|0}else{lb=hb;mb=Ka}Za=(lb|0)<65536|0;_a=0;$a=mb}}while(0);Na=$a+1|0;if((Na|0)<(Ia|0)){Ka=Na;La=_a;Ma=Za}else{break}}}Ma=c[o+(Fa<<2)>>2]|0;do{if((Ma|0)==15){La=c[Ga>>2]|0;Ka=c[oa>>2]|0;if((Ka|0)<2){nb=Ka;ob=La;break}Ia=1;Ha=c[La>>2]|0;while(1){Ja=La+(Ia<<2)|0;Na=(c[Ja>>2]|0)+Ha<<Aa>>Aa;c[Ja>>2]=Na;Ja=Ia+1|0;if((Ja|0)<(Ka|0)){Ia=Ja;Ha=Na}else{R=84;break}}}else{if((Ma|0)<=0){R=84;break}KIb(D,24,2634560,(ha=i,i=i+8|0,c[ha>>2]=Ma,ha)|0);i=ha;R=84}}while(0);if((R|0)==84){R=0;nb=c[oa>>2]|0;ob=c[Ga>>2]|0}Ma=c[Ea+(Fa<<2)>>2]|0;Ha=c[n+(Fa<<2)>>2]|0;Ia=c[p+(Fa<<2)>>2]|0;Ka=c[ob>>2]|0;c[Ma>>2]=Ka;d:do{if((nb|0)>=2){if((Ha|0)==0){nrc(Ma+4|0,ob+4|0,(nb<<2)-4|0)|0;break}else if((Ha|0)==31){La=1;Na=Ka;do{Na=(c[ob+(La<<2)>>2]|0)+Na<<Aa>>Aa;c[Ma+(La<<2)>>2]=Na;La=La+1|0;}while((La|0)<(nb|0))}else{La=(Ha|0)>0;if(La){Na=1-nb|0;Ja=1;Oa=Ka;do{Oa=(c[ob+(Ja<<2)>>2]|0)+Oa<<Aa>>Aa;c[Ma+(Ja<<2)>>2]=Oa;Ja=Ja+1|0;}while((Ja|0)<=(Ha|0)&(Ja|0)<(nb|0));Ja=-Ha|0;pb=1-(Na>>>0<Ja>>>0?Ja:Na)|0}else{pb=1}if((pb|0)>=(nb|0)){break}Ja=1<<Ia-1;if(La){qb=Ma;rb=pb}else{Oa=Ja>>Ia;Qa=Ma;Ya=pb;while(1){c[Ma+(Ya<<2)>>2]=(c[ob+(Ya<<2)>>2]|0)+Oa+(c[Qa>>2]|0)<<Aa>>Aa;bb=Ya+1|0;if((bb|0)>=(nb|0)){break d}Qa=Qa+4|0;Ya=bb}}while(1){Ya=c[ob+(rb<<2)>>2]|0;Qa=c[qb>>2]|0;Oa=0;La=0;while(1){Na=La+1|0;sb=(ca(b[m+(Fa<<6)+(La<<1)>>1]|0,(c[qb+(Na<<2)>>2]|0)-Qa|0)|0)+Oa|0;if((Na|0)<(Ha|0)){Oa=sb;La=Na}else{break}}La=qb+4|0;c[Ma+(rb<<2)>>2]=Qa+Ya+(sb+Ja>>Ia)<<Aa>>Aa;e:do{if((Ya|0)!=0){Oa=(Ya|0)>0?1:-1;Pa=Ya;Na=0;while(1){if((ca(Pa,Oa)|0)<=0){break e}bb=Na+1|0;ib=c[qb+(bb<<2)>>2]|0;jb=Qa-ib|0;if((Qa|0)==(ib|0)){tb=0}else{tb=(jb|0)>0?1:-1}ib=ca(tb,Oa)|0;ub=m+(Fa<<6)+(Na<<1)|0;b[ub>>1]=(e[ub>>1]|0)-ib;ub=Pa-(ca((ca(ib,jb)|0)>>Ia,bb)|0)|0;if((bb|0)<(Ha|0)){Pa=ub;Na=bb}else{break}}}}while(0);Qa=rb+1|0;if((Qa|0)<(nb|0)){qb=La;rb=Qa}else{break}}}}}while(0);Fa=Fa+1|0;}while((Fa|0)<(S|0));do{if(!((sa|0)==0|O^1)){Fa=c[oa>>2]|0;if((Fa|0)<=0){break}Aa=c[Da>>2]|0;Ea=c[U+40>>2]|0;ya=0;do{ja=Aa+(ya<<2)|0;ka=Ea+(ya<<2)|0;za=c[ka>>2]|0;va=(c[ja>>2]|0)-((ca(za,sa)|0)>>ra)|0;c[ja>>2]=va+za;c[ka>>2]=va;ya=ya+1|0;}while((ya|0)<(Fa|0))}}while(0);ra=c[ea>>2]|0;if((ra|0)==0){break}sa=Da;Fa=U+44|0;ya=c[oa>>2]|0;Ea=(ya|0)>0;Aa=0;do{if(Ea){va=c[sa+(Aa<<2)>>2]|0;ka=c[Fa+(Aa<<2)>>2]|0;za=0;do{ja=va+(za<<2)|0;c[ja>>2]=c[ka+(za<<2)>>2]|c[ja>>2]<<ra;za=za+1|0;}while((za|0)<(ya|0))}Aa=Aa+1|0;}while((Aa|0)<(S|0))}else{if((c[oa>>2]|0)>0){Aa=U+16|0;ya=U+36|0;ra=0;do{if(((c[Aa>>2]|0)-(c[W>>2]|0)|0)<1){ia=-1;break b}else{vb=0}do{Fa=a[fa]|0;sa=Fa&255;do{if(Fa<<24>>24==0){wb=0}else{Ea=c[W>>2]|0;Da=c[X>>2]|0;za=c[_>>2]|0;ka=za+(Ea>>>3)|0;va=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(Ea&7);if((Fa&255)>>>0<26>>>0){ka=Ea+sa|0;c[W>>2]=Da>>>0>ka>>>0?ka:Da;wb=va>>>((32-sa|0)>>>0);break}else{ka=Ea+16|0;Ea=Da>>>0>ka>>>0?ka:Da;c[W>>2]=Ea;ka=sa-16|0;ja=za+(Ea>>>3)|0;za=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(Ea&7)>>>((48-sa|0)>>>0);ja=Ea+ka|0;c[W>>2]=Da>>>0>ja>>>0?ja:Da;wb=za|va>>>16<<ka;break}}}while(0);Fa=32-sa|0;c[(c[ya+(vb<<2)>>2]|0)+(ra<<2)>>2]=wb<<Fa>>Fa;vb=vb+1|0;}while((vb|0)<(S|0));ra=ra+1|0;}while((ra|0)<(c[oa>>2]|0))}c[ea>>2]=0}}while(0);na=(RKb(c[I>>2]|0)|0)==0;ra=d[fa]|0;if(!na){if((ra|0)==16){na=c[J>>2]|0;ya=c[oa>>2]|0;Aa=(ya|0)>0;Fa=U+36|0;ka=0;while(1){if(Aa){va=c[Fa+(ka<<2)>>2]|0;za=0;Da=c[na+(ka+V<<2)>>2]|0;while(1){b[Da>>1]=c[va+(za<<2)>>2];ja=za+1|0;if((ja|0)<(ya|0)){za=ja;Da=Da+2|0}else{break}}}Da=ka+1|0;if((Da|0)<(S|0)){ka=Da}else{ia=0;break b}}}else if((ra|0)==24){ka=U+36|0;ya=0;na=c[oa>>2]|0;while(1){if((na|0)>0){Fa=c[ka+(ya<<2)>>2]|0;Aa=0;while(1){Da=Fa+(Aa<<2)|0;c[Da>>2]=c[Da>>2]<<8;Da=Aa+1|0;za=c[oa>>2]|0;if((Da|0)<(za|0)){Aa=Da}else{xb=za;break}}}else{xb=na}Aa=ya+1|0;if((Aa|0)<(S|0)){ya=Aa;na=xb}else{ia=0;break b}}}else{ia=0;break b}}if((ra|0)==16){na=c[oa>>2]|0;if((na|0)<=0){ia=0;break b}ya=c[U+24>>2]|0;ka=U+36|0;Aa=0;Fa=(c[c[J>>2]>>2]|0)+(V<<1)|0;while(1){za=0;Da=Fa;while(1){b[Da>>1]=c[(c[ka+(za<<2)>>2]|0)+(Aa<<2)>>2];va=za+1|0;if((va|0)<(S|0)){za=va;Da=Da+2|0}else{break}}Da=Aa+1|0;if((Da|0)<(na|0)){Aa=Da;Fa=Fa+(ya<<1)|0}else{ia=0;break b}}}else if((ra|0)==24){if((c[oa>>2]|0)<=0){ia=0;break b}ya=U+24|0;Fa=U+36|0;Aa=0;na=(c[c[J>>2]>>2]|0)+(V<<2)|0;while(1){ka=0;Da=na;while(1){c[Da>>2]=c[(c[Fa+(ka<<2)>>2]|0)+(Aa<<2)>>2]<<8;za=ka+1|0;if((za|0)<(S|0)){ka=za;Da=Da+4|0}else{break}}Da=Aa+1|0;if((Da|0)<(c[oa>>2]|0)){Aa=Da;na=na+(c[ya>>2]<<2)|0}else{ia=0;break b}}}else if((ra|0)==32){if((c[oa>>2]|0)<=0){ia=0;break b}ya=U+24|0;na=U+36|0;Aa=0;Fa=(c[c[J>>2]>>2]|0)+(V<<2)|0;while(1){Da=0;ka=Fa;while(1){c[ka>>2]=c[(c[na+(Da<<2)>>2]|0)+(Aa<<2)>>2];za=Da+1|0;if((za|0)<(S|0)){Da=za;ka=ka+4|0}else{break}}ka=Aa+1|0;if((ka|0)<(c[oa>>2]|0)){Aa=ka;Fa=Fa+(c[ya>>2]<<2)|0}else{ia=0;break b}}}else{ia=0;break b}}}while(0);KIb(D,16,2140064,(ha=i,i=i+8|0,c[ha>>2]=ma,ha)|0);i=ha;ia=-1094995529}}while(0);S=c[B>>2]|0;V=c[y>>2]|0;if((ia|0)<0){if((V|0)==(S|0)){yb=S}else{C=ia;R=165;break}}else{yb=V}if((yb-S|0)<=2){zb=D;break a}K=T;L=S;M=c[A>>2]|0;N=c[w>>2]|0}if((R|0)==6){KIb(D,16,2437952,(ha=i,i=i+8|0,c[ha>>2]=P,ha)|0);i=ha;C=-1163346256;i=k;return C|0}else if((R|0)==9){KIb(D,16,2350776,(ha=i,i=i+1|0,i=i+7&-8,c[ha>>2]=0,ha)|0);i=ha;C=-1094995529;i=k;return C|0}else if((R|0)==159){N=(c[v>>2]<<3)-Q|0;if((N|0)>8){KIb(D,16,2238880,(ha=i,i=i+8|0,c[ha>>2]=N,ha)|0);i=ha}if((c[j>>2]|0)==(K|0)){c[h>>2]=1}else{KIb(D,24,2198024,(ha=i,i=i+1|0,i=i+7&-8,c[ha>>2]=0,ha)|0);i=ha}C=c[v>>2]|0;i=k;return C|0}else if((R|0)==165){i=k;return C|0}}else{zb=f}}while(0);KIb(zb,16,2289176,(ha=i,i=i+1|0,i=i+7&-8,c[ha>>2]=0,ha)|0);i=ha;C=-1094995529;i=k;return C|0}function Wlb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;a=b+24|0;if((c[a>>2]|0)<=0){return 0}d=b+28|0;e=b+68|0;f=b+36|0;g=b+44|0;b=0;do{mJb(d+(b<<2)|0);if((c[e>>2]|0)==0){mJb(f+(b<<2)|0)}mJb(g+(b<<2)|0);b=b+1|0;h=c[a>>2]|0;}while((b|0)<(((h|0)>2?2:h)|0));return 0}function Xlb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0;d=i;e=b+60|0;f=c[e>>2]|0;c[f>>2]=4096;g=b+424|0;c[g>>2]=4096;h=b+796|0;if((c[b+420>>2]|0)==7){if((c[h>>2]|0)!=24){KIb(b,24,2437920,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}c[h>>2]=24}else{c[h>>2]=16;c[f+28>>2]=0}k=c[b+84>>2]|0;if((k|0)==-1){c[f+8>>2]=2}else{if((k|0)<0){l=0}else{l=(k|0)>2?2:k}c[f+8>>2]=l}l=f+49216|0;c[l>>2]=40;k=f+49220|0;c[k>>2]=10;m=f+49224|0;c[m>>2]=14;c[f+49228>>2]=4;n=c[g>>2]|0;o=b+416|0;p=f+20|0;c[p>>2]=((ca(ca(c[o>>2]|0,n)|0,c[h>>2]|0)|0)+10+(((n|0)<4096)<<5|23)&-8|0)/8|0;n=pJb(52)|0;q=b+96|0;c[q>>2]=n;r=b+100|0;a:do{if((n|0)==0){s=-12}else{c[r>>2]=36;t=n;y=603979776;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=n+4|0;y=1667329121;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=n+12|0;y=je(c[g>>2]|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=c[h>>2]|0;a[n+17|0]=t;u=c[o>>2]|0;a[n+21|0]=u;v=n+24|0;y=je(c[p>>2]|0)|0;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;v=c[b+412>>2]|0;w=n+28|0;y=je(ca(ca(u,v)|0,t)|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;w=n+32|0;y=je(v|0)|0;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;if((c[f+8>>2]|0)>0){a[n+18|0]=c[l>>2];a[n+19|0]=c[k>>2];a[n+20|0]=c[m>>2]}w=f+12|0;c[w>>2]=4;v=c[b+604>>2]|0;do{if((v|0)>-1){if((v-1|0)>>>0>29>>>0){KIb(b,16,2350736,(j=i,i=i+8|0,c[j>>2]=v,j)|0);i=j;s=-22;break a}else{c[w>>2]=v;x=v;break}}else{x=4}}while(0);v=f+16|0;c[v>>2]=6;w=c[b+608>>2]|0;do{if((w|0)>-1){if((w-1|0)>>>0>29>>>0){KIb(b,16,2289136,(j=i,i=i+8|0,c[j>>2]=w,j)|0);i=j;s=-22;break a}else{c[v>>2]=w;z=w;break}}else{z=6}}while(0);if((z|0)<(x|0)){KIb(b,16,2238832,(j=i,i=i+16|0,c[j>>2]=x,c[j+8>>2]=z,j)|0);i=j;s=-22;break}c[f+49524>>2]=b;w=rPa(f+49496|0,c[g>>2]|0,z,2)|0;if((w|0)<0){s=w;break}else{A=0}i=d;return A|0}}while(0);qPa((c[e>>2]|0)+49496|0);mJb(q);c[r>>2]=0;A=s;i=d;return A|0}function Ylb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[a+60>>2]|0;g=f;h=d+76|0;i=c[h>>2]|0;c[f>>2]=i;if((c[h>>2]|0)<4096){j=((((i|0)<4096)<<5|23)+10+(ca(ca(c[a+416>>2]|0,i)|0,c[a+796>>2]|0)|0)&-8|0)/8|0}else{j=c[f+20>>2]|0}i=j<<1;h=d5a(a,b,i,(i|0)<0|0?-1:0)|0;if((h|0)<0){k=h;return k|0}h=f+4|0;if((c[f+8>>2]|0)==0){c[h>>2]=1;c[f+28>>2]=0}else{c[h>>2]=0;c[f+28>>2]=(c[a+796>>2]|0)-16}a=d+64|0;d=b+24|0;i=b+28|0;b=_lb(g,c[d>>2]|0,c[i>>2]|0,c[a>>2]|0)|0;if((b|0)>(j|0)){c[h>>2]=1;c[f+28>>2]=0;l=_lb(g,c[d>>2]|0,c[i>>2]|0,c[a>>2]|0)|0}else{l=b}c[i>>2]=l;c[e>>2]=1;k=0;return k|0}function Zlb(a){a=a|0;qPa((c[a+60>>2]|0)+49496|0);mJb(a+96|0);c[a+100>>2]=0;return 0}function _lb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=b+49524|0;i=(c[h>>2]|0)+416|0;j=(c[i>>2]|0)-1|0;k=(f|0)<0;l=k?0:e;e=k?0:f;c[b+49212>>2]=e<<3;f=b+49200|0;c[f>>2]=l;c[b+49208>>2]=l+e;e=b+49204|0;c[e>>2]=l;l=b+49196|0;c[l>>2]=32;k=b+49192|0;c[k>>2]=0;do{if((c[i>>2]|0)>0){m=0;n=0;o=0;p=0;while(1){q=c[g+((d[1433736+(j<<3)+m|0]|0)<<2)>>2]|0;if((c[1433800+(j*20|0)+(n<<2)>>2]|0)==1){$lb(b,1,p,q,c[g+((d[m+1+(1433736+(j<<3))|0]|0)<<2)>>2]|0);r=p+1|0;s=o;t=m+2|0}else{$lb(b,0,o,q,0);r=p;s=o+1|0;t=m+1|0}if((t|0)<(c[(c[h>>2]|0)+416>>2]|0)){m=t;n=n+1|0;o=s;p=r}else{break}}p=c[k>>2]|0;o=c[l>>2]|0;if((o|0)>3){u=o;v=p;w=7;break}n=je(7>>>((3-o|0)>>>0)|p<<o|0)|0;p=c[e>>2]|0;y=n;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[e>>2]=(c[e>>2]|0)+4;x=o+29|0;z=7}else{u=32;v=0;w=7}}while(0);if((w|0)==7){x=u-3|0;z=v<<3|7}c[k>>2]=z;c[l>>2]=x;if((x|0)>=32){c[l>>2]=32;c[k>>2]=0;A=c[f>>2]|0;B=c[e>>2]|0;C=B;D=A;E=C-D|0;F=E<<3;G=F>>3;return G|0}v=z<<x;c[k>>2]=v;x=v>>>24&255;while(1){v=c[e>>2]|0;c[e>>2]=v+1;a[v]=x;v=c[k>>2]|0;c[k>>2]=v<<8;z=(c[l>>2]|0)+8|0;c[l>>2]=z;if((z|0)>=32){break}x=v>>>16&255}c[l>>2]=32;c[k>>2]=0;A=c[f>>2]|0;B=c[e>>2]|0;C=B;D=A;E=C-D|0;F=E<<3;G=F>>3;return G|0}function $lb(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0;k=i;i=i+4416|0;l=k|0;m=k+4096|0;n=k+4224|0;o=k+4360|0;p=k+4392|0;q=k+4400|0;r=k+4408|0;c[p>>2]=h;c[p+4>>2]=j;s=e+49192|0;t=(f|0)==1;u=t?2:1;if((c[e+4>>2]|0)!=0){amb(e,f,g);v=e+49524|0;w=c[v>>2]|0;if((c[w+420>>2]|0)==7){x=32-(c[w+796>>2]|0)|0;c[q>>2]=h;c[q+4>>2]=j;w=e|0;if((c[w>>2]|0)<=0){i=k;return}z=s|0;A=e+49196|0;B=e+49204|0;C=0;D=c[z>>2]|0;E=c[A>>2]|0;while(1){F=0;H=D;I=E;while(1){J=c[(c[v>>2]|0)+796>>2]|0;K=c[(c[q+(F<<2)>>2]|0)+(C<<2)>>2]>>x&(1<<J)-1;if((I|0)>(J|0)){L=I-J|0;M=H<<J|K}else{N=je(K>>>((J-I|0)>>>0)|H<<I|0)|0;O=c[B>>2]|0;y=N;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[B>>2]=(c[B>>2]|0)+4;L=32-J+I|0;M=K}c[z>>2]=M;c[A>>2]=L;K=F+1|0;if((K|0)<(u|0)){F=K;H=M;I=L}else{break}}I=C+1|0;if((I|0)<(c[w>>2]|0)){C=I;D=M;E=L}else{break}}i=k;return}else{c[r>>2]=h;c[r+4>>2]=j;j=e|0;if((c[j>>2]|0)<=0){i=k;return}L=s|0;E=e+49196|0;M=e+49204|0;D=0;C=c[L>>2]|0;w=c[E>>2]|0;while(1){A=0;z=C;B=w;while(1){x=c[(c[v>>2]|0)+796>>2]|0;q=b[(c[r+(A<<2)>>2]|0)+(D<<1)>>1]&(1<<x)-1;if((B|0)>(x|0)){P=B-x|0;Q=z<<x|q}else{I=je(q>>>((x-B|0)>>>0)|z<<B|0)|0;H=c[M>>2]|0;y=I;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[M>>2]=(c[M>>2]|0)+4;P=32-x+B|0;Q=q}c[L>>2]=Q;c[E>>2]=P;q=A+1|0;if((q|0)<(u|0)){A=q;z=Q;B=P}else{break}}B=D+1|0;if((B|0)<(c[j>>2]|0)){D=B;C=Q;w=P}else{break}}i=k;return}}P=e+49524|0;w=c[P>>2]|0;Q=e+28|0;C=e+24|0;c[C>>2]=u-1+(c[w+796>>2]|0)-(c[Q>>2]|0);D=(QKb(c[w+420>>2]|0)|0)<<3;w=c[P>>2]|0;P=D-(c[w+796>>2]|0)|0;D=e|0;j=c[D>>2]|0;a:do{if((c[w+420>>2]|0)==7){E=0;L=j;M=h;while(1){r=M;if((L|0)>0){v=0;while(1){c[e+32+(E<<14)+(v<<2)>>2]=c[r+(v<<2)>>2]>>P;B=v+1|0;z=c[D>>2]|0;if((B|0)<(z|0)){v=B}else{R=z;break}}}else{R=L}v=E+1|0;if((v|0)>=(u|0)){break a}E=v;L=R;M=c[p+(v<<2)>>2]|0}}else{M=0;L=j;E=h;while(1){v=E;if((L|0)>0){r=0;while(1){c[e+32+(M<<14)+(r<<2)>>2]=b[v+(r<<1)>>1]>>P;z=r+1|0;B=c[D>>2]|0;if((z|0)<(B|0)){r=z}else{S=B;break}}}else{S=L}r=M+1|0;if((r|0)>=(u|0)){break a}M=r;L=S;E=c[p+(r<<2)>>2]|0}}}while(0);amb(e,f,g);do{if(t){g=c[D>>2]|0;if((g|0)>2){f=2;p=0;S=0;P=0;h=0;j=0;R=0;w=0;E=0;L=c[e+36>>2]|0;M=c[e+16420>>2]|0;while(1){r=c[e+32+(f<<2)>>2]|0;v=f-2|0;B=r-(L<<1)+(c[e+32+(v<<2)>>2]|0)|0;z=c[e+16416+(f<<2)>>2]|0;A=z-(M<<1)+(c[e+16416+(v<<2)>>2]|0)|0;v=A+B>>1;q=(v|0)>-1?v:-v|0;v=wrc(q,(q|0)<0|0?-1:0,h,P)|0;q=G;x=B-A|0;H=(x|0)>-1?x:-x|0;x=wrc(H,(H|0)<0|0?-1:0,S,p)|0;H=G;I=(B|0)>-1?B:-B|0;B=wrc(I,(I|0)<0|0?-1:0,E,w)|0;I=G;F=(A|0)>-1?A:-A|0;A=wrc(F,(F|0)<0|0?-1:0,R,j)|0;F=G;K=f+1|0;if((K|0)<(g|0)){f=K;p=H;S=x;P=q;h=v;j=F;R=A;w=I;E=B;L=r;M=z}else{T=H;U=x;V=q;W=v;X=F;Y=A;Z=I;_=B;break}}}else{T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;_=0}M=wrc(Y,X,_,Z)|0;L=G;E=o|0;c[E>>2]=M;c[E+4>>2]=L;E=wrc(U,T,_,Z)|0;w=G;R=o+8|0;c[R>>2]=E;c[R+4>>2]=w;R=wrc(U,T,Y,X)|0;j=G;h=o+16|0;c[h>>2]=R;c[h+4>>2]=j;h=wrc(U,T,W,V)|0;P=G;S=o+24|0;c[S>>2]=h;c[S+4>>2]=P;S=(w>>>0<L>>>0|w>>>0==L>>>0&E>>>0<M>>>0)&1;M=o+(S<<3)|0;E=c[M+4>>2]|0;L=j>>>0<E>>>0|j>>>0==E>>>0&R>>>0<(c[M>>2]|0)>>>0?2:S;S=o+(L<<3)|0;M=c[S+4>>2]|0;R=P>>>0<M>>>0|P>>>0==M>>>0&h>>>0<(c[S>>2]|0)>>>0?3:L;if((R|0)==1){if((g|0)>0){L=0;do{S=e+16416+(L<<2)|0;c[S>>2]=(c[e+32+(L<<2)>>2]|0)-(c[S>>2]|0);L=L+1|0;}while((L|0)<(g|0))}c[e+49188>>2]=1;c[e+49184>>2]=0;$=0;aa=1;break}else if((R|0)==0){c[e+49188>>2]=0;c[e+49184>>2]=0;$=0;aa=0;break}else if((R|0)==2){if((g|0)>0){L=0;do{S=e+16416+(L<<2)|0;h=c[S>>2]|0;M=e+32+(L<<2)|0;P=(c[M>>2]|0)-h|0;c[S>>2]=P;c[M>>2]=(P>>31)+h;L=L+1|0;}while((L|0)<(g|0))}c[e+49188>>2]=1;c[e+49184>>2]=31;$=31;aa=1;break}else{if((g|0)>0){L=0;do{R=e+32+(L<<2)|0;h=c[R>>2]|0;P=e+16416+(L<<2)|0;M=c[P>>2]|0;c[R>>2]=M+h>>1;c[P>>2]=h-M;L=L+1|0;}while((L|0)<(g|0))}c[e+49188>>2]=1;c[e+49184>>2]=1;$=1;aa=1;break}}else{c[e+49188>>2]=0;c[e+49184>>2]=0;$=0;aa=0}}while(0);o=s|0;s=c[o>>2]|0;V=e+49196|0;W=c[V>>2]|0;if((W|0)>8){ba=W-8|0;da=s<<8|$;ea=aa}else{aa=je($>>>((8-W|0)>>>0)|s<<W|0)|0;s=e+49204|0;T=c[s>>2]|0;y=aa;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;ba=W+24|0;da=$;ea=c[e+49188>>2]|0}c[o>>2]=da;c[V>>2]=ba;if((ba|0)>8){fa=ba-8|0;ga=da<<8|ea;ha=e+49204|0}else{$=je(da<<ba|ea>>>((8-ba|0)>>>0)|0)|0;da=e+49204|0;W=c[da>>2]|0;y=$;a[W]=y;y=y>>8;a[W+1|0]=y;y=y>>8;a[W+2|0]=y;y=y>>8;a[W+3|0]=y;c[da>>2]=(c[da>>2]|0)+4;fa=ba+24|0;ga=ea;ha=da}c[o>>2]=ga;c[V>>2]=fa;fa=e+8|0;ga=e+49228|0;da=e+49496|0;ea=e+12|0;ba=e+16|0;W=l|0;$=m|0;s=0;do{if((c[fa>>2]|0)==1){c[e+49232+(s*132|0)>>2]=6;c[e+49232+(s*132|0)+128>>2]=6;c[e+49232+(s*132|0)+4>>2]=160;c[e+49232+(s*132|0)+8>>2]=-190;c[e+49232+(s*132|0)+12>>2]=170;c[e+49232+(s*132|0)+16>>2]=-130;c[e+49232+(s*132|0)+20>>2]=80;c[e+49232+(s*132|0)+24>>2]=-25}else{T=pPa(da,e+32+(s<<14)|0,c[D>>2]|0,c[ea>>2]|0,c[ba>>2]|0,9,W,$,2,0,0,9,1)|0;c[e+49232+(s*132|0)>>2]=T;aa=T-1|0;c[e+49232+(s*132|0)+128>>2]=c[m+(aa<<2)>>2];nrc(e+49232+(s*132|0)+4|0,l+(aa<<7)|0,T<<2)|0}T=c[o>>2]|0;aa=c[V>>2]|0;if((aa|0)>4){ia=aa-4|0;ja=T<<4}else{U=je(T<<aa|0)|0;T=c[ha>>2]|0;y=U;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;ia=aa+28|0;ja=0}c[o>>2]=ja;c[V>>2]=ia;aa=c[e+49232+(s*132|0)+128>>2]|0;if((ia|0)>4){ka=ia-4|0;la=ja<<4|aa}else{T=je(ja<<ia|aa>>>((4-ia|0)>>>0)|0)|0;U=c[ha>>2]|0;y=T;a[U]=y;y=y>>8;a[U+1|0]=y;y=y>>8;a[U+2|0]=y;y=y>>8;a[U+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;ka=ia+28|0;la=aa}c[o>>2]=la;c[V>>2]=ka;aa=c[ga>>2]|0;if((ka|0)>3){ma=ka-3|0;na=la<<3|aa}else{U=je(la<<ka|aa>>>((3-ka|0)>>>0)|0)|0;T=c[ha>>2]|0;y=U;a[T]=y;y=y>>8;a[T+1|0]=y;y=y>>8;a[T+2|0]=y;y=y>>8;a[T+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;ma=ka+29|0;na=aa}c[o>>2]=na;c[V>>2]=ma;aa=e+49232+(s*132|0)|0;T=c[aa>>2]|0;if((ma|0)>5){oa=ma-5|0;pa=na<<5|T}else{U=je(na<<ma|T>>>((5-ma|0)>>>0)|0)|0;X=c[ha>>2]|0;y=U;a[X]=y;y=y>>8;a[X+1|0]=y;y=y>>8;a[X+2|0]=y;y=y>>8;a[X+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;oa=ma+27|0;pa=T}c[o>>2]=pa;c[V>>2]=oa;if((c[aa>>2]|0)>0){T=0;X=pa;U=oa;while(1){Y=c[e+49232+(s*132|0)+4+(T<<2)>>2]&65535;if((U|0)>16){qa=U-16|0;ra=X<<16|Y}else{Z=je(Y>>>((16-U|0)>>>0)|X<<U|0)|0;_=c[ha>>2]|0;y=Z;a[_]=y;y=y>>8;a[_+1|0]=y;y=y>>8;a[_+2|0]=y;y=y>>8;a[_+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;qa=U+16|0;ra=Y}c[o>>2]=ra;c[V>>2]=qa;Y=T+1|0;if((Y|0)<(c[aa>>2]|0)){T=Y;X=ra;U=qa}else{break}}}s=s+1|0;}while((s|0)<(u|0));s=c[Q>>2]|0;do{if((s|0)!=0){qa=(1<<s)-1|0;if((c[D>>2]|0)>0){sa=0}else{break}do{ra=0;do{oa=c[Q>>2]|0;pa=e+32+(ra<<14)+(sa<<2)|0;ma=c[pa>>2]&qa;na=c[o>>2]|0;ka=c[V>>2]|0;if((ka|0)>(oa|0)){ta=ka-oa|0;ua=na<<oa|ma;va=oa}else{la=je(ma>>>((oa-ka|0)>>>0)|na<<ka|0)|0;na=c[ha>>2]|0;y=la;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[ha>>2]=(c[ha>>2]|0)+4;ta=32-oa+ka|0;ua=ma;va=c[Q>>2]|0}c[o>>2]=ua;c[V>>2]=ta;c[pa>>2]=c[pa>>2]>>va;ra=ra+1|0;}while((ra|0)<(u|0));sa=sa+1|0;}while((sa|0)<(c[D>>2]|0))}}while(0);sa=n;va=n|0;ta=e+32800|0;V=e+49220|0;ua=e+49216|0;o=n+128|0;Q=0;do{nrc(sa|0,e+49232+(Q*132|0)|0,132)|0;ha=c[va>>2]|0;do{if((ha|0)==31){c[ta>>2]=c[e+32+(Q<<14)>>2];s=c[D>>2]|0;if((s|0)>1){wa=1}else{xa=s;break}while(1){c[e+32800+(wa<<2)>>2]=(c[e+32+(Q<<14)+(wa<<2)>>2]|0)-(c[e+32+(Q<<14)+(wa-1<<2)>>2]|0);s=wa+1|0;qa=c[D>>2]|0;if((s|0)<(qa|0)){wa=s}else{xa=qa;break}}}else{if((ha|0)<=0){xa=c[D>>2]|0;break}qa=e+32+(Q<<14)|0;c[ta>>2]=c[qa>>2];s=1;do{ra=32-(c[C>>2]|0)|0;c[e+32800+(s<<2)>>2]=(c[e+32+(Q<<14)+(s<<2)>>2]|0)-(c[e+32+(Q<<14)+(s-1<<2)>>2]|0)<<ra>>ra;s=s+1|0;}while((s|0)<=(ha|0));s=ha+1|0;ra=c[D>>2]|0;if((s|0)>=(ra|0)){xa=ra;break}ra=qa;pa=s;s=c[o>>2]|0;ma=ha;while(1){ka=1<<s-1;oa=(ma|0)>0;na=c[ra>>2]|0;if(oa){la=ka;ga=0;while(1){ia=(ca((c[ra+(ma-ga<<2)>>2]|0)-na|0,c[n+4+(ga<<2)>>2]|0)|0)+la|0;ja=ga+1|0;if((ja|0)<(ma|0)){la=ia;ga=ja}else{ya=ia;break}}}else{ya=ka}ga=32-(c[C>>2]|0)|0;la=(c[ra+(ma+1<<2)>>2]|0)-((ya>>s)+na)<<ga>>ga;c[e+32800+(pa<<2)>>2]=la;b:do{if((la|0)==0){za=s;Aa=ma}else{ga=ma-1|0;if(!oa){za=s;Aa=ma;break}if((la|0)<0){ia=la;ja=ga;l=s;m=ma;while(1){if((ia|0)>=0){za=l;Aa=m;break b}$=c[ra>>2]|0;W=c[ra+(m-ja<<2)>>2]|0;ba=$-W|0;if(($|0)==(W|0)){Ba=0}else{Ba=(ba|0)>0?1:-1}W=n+4+(ja<<2)|0;c[W>>2]=(c[W>>2]|0)+Ba;W=ca(Ba,-ba|0)|0;ba=c[o>>2]|0;$=c[va>>2]|0;ea=ia-(ca($-ja|0,W>>ba)|0)|0;if((ja|0)>0){ia=ea;ja=ja-1|0;l=ba;m=$}else{za=ba;Aa=$;break}}}else{m=la;l=ga;ja=s;ia=ma;while(1){if((m|0)<=0){za=ja;Aa=ia;break b}$=c[ra>>2]|0;ba=c[ra+(ia-l<<2)>>2]|0;ea=$-ba|0;if(($|0)==(ba|0)){Ca=0}else{Ca=(ea|0)>0?1:-1}ba=n+4+(l<<2)|0;c[ba>>2]=(c[ba>>2]|0)-Ca;ba=ca(Ca,ea)|0;ea=c[o>>2]|0;$=c[va>>2]|0;W=m-(ca($-l|0,ba>>ea)|0)|0;if((l|0)>0){m=W;l=l-1|0;ja=ea;ia=$}else{za=ea;Aa=$;break}}}}}while(0);la=pa+1|0;oa=c[D>>2]|0;if((la|0)<(oa|0)){ra=ra+4|0;pa=la;s=za;ma=Aa}else{xa=oa;break}}}}while(0);if((xa|0)>0){ha=0;ma=0;s=ta;pa=c[V>>2]|0;while(1){ra=(pa>>>9)+3|0;qa=ra>>>0>65535>>>0;oa=qa?ra>>>16:ra;ra=qa?16:0;if((oa&65280|0)==0){Da=ra;Ea=oa}else{Da=ra|8;Ea=oa>>>8}oa=((c[s>>2]|0)*-2|0)-1|0;ra=oa>>31^oa;oa=s+4|0;qa=ma+1|0;bmb(e,ra-ha|0,(d[1359664+Ea|0]|0)+Da|0,c[C>>2]|0);la=c[ua>>2]|0;na=pa-((ca(la,pa)|0)>>>9)+(ca(ra,la)|0)|0;la=(ra|0)>65535?65535:na;do{if(la>>>0<128>>>0){na=c[D>>2]|0;if((qa|0)>=(na|0)){Fa=la;Ga=oa;Ha=qa;Ia=0;break}ra=(la&65280|0)==0;ka=((la+16|0)>>>6)+7+(ra?0:-8)-(d[1359664+(ra?la:la>>>8)|0]|0)|0;c:do{if((c[oa>>2]|0)==0){ra=qa;ia=oa;ja=0;while(1){if((ra|0)>=(na|0)){Ja=ra;Ka=ia;La=ja;break c}l=ia+4|0;m=ra+1|0;ga=ja+1|0;if((c[l>>2]|0)==0){ra=m;ia=l;ja=ga}else{Ja=m;Ka=l;La=ga;break}}}else{Ja=qa;Ka=oa;La=0}}while(0);bmb(e,La,ka,16);Fa=0;Ga=Ka;Ha=Ja;Ia=La>>>0<65536>>>0|0}else{Fa=la;Ga=oa;Ha=qa;Ia=0}}while(0);if((Ha|0)<(c[D>>2]|0)){ha=Ia;ma=Ha;s=Ga;pa=Fa}else{break}}}Q=Q+1|0;}while((Q|0)<(u|0));i=k;return}function amb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0;f=b|0;g=(c[f>>2]|0)<4096;h=g&1;i=b+49192|0;j=c[i>>2]|0;k=b+49196|0;l=c[k>>2]|0;if((l|0)>3){m=l-3|0;n=j<<3|d}else{o=je(d>>>((3-l|0)>>>0)|j<<l|0)|0;j=b+49204|0;p=c[j>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;m=l+29|0;n=d}c[i>>2]=n;c[k>>2]=m;if((m|0)>4){q=m-4|0;r=n<<4|e}else{d=je(e>>>((4-m|0)>>>0)|n<<m|0)|0;n=b+49204|0;l=c[n>>2]|0;y=d;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;q=m+28|0;r=e}c[i>>2]=r;c[k>>2]=q;if((q|0)>12){s=q-12|0;t=r<<12}else{e=je(r<<q|0)|0;r=b+49204|0;m=c[r>>2]|0;y=e;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;s=q+20|0;t=0}c[i>>2]=t;c[k>>2]=s;if((s|0)>1){u=s-1|0;v=t<<1|h}else{q=je(h>>>((1-s|0)>>>0)|t<<s|0)|0;t=b+49204|0;r=c[t>>2]|0;y=q;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[t>>2]=(c[t>>2]|0)+4;u=s+31|0;v=h}c[i>>2]=v;c[k>>2]=u;h=c[b+28>>2]>>3;if((u|0)>2){w=u-2|0;x=v<<2|h}else{s=je(h>>>((2-u|0)>>>0)|v<<u|0)|0;v=b+49204|0;t=c[v>>2]|0;y=s;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;w=u+30|0;x=h}c[i>>2]=x;c[k>>2]=w;h=c[b+4>>2]|0;if((w|0)>1){z=w-1|0;A=x<<1|h}else{u=je(x<<w|h>>>((1-w|0)>>>0)|0)|0;x=b+49204|0;v=c[x>>2]|0;y=u;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;z=w+31|0;A=h}c[i>>2]=A;c[k>>2]=z;if(!g){return}g=c[f>>2]|0;f=g&65535;h=g>>>16;if((z|0)>16){B=z-16|0;C=A<<16|h}else{g=je(h>>>((16-z|0)>>>0)|A<<z|0)|0;A=b+49204|0;w=c[A>>2]|0;y=g;a[w]=y;y=y>>8;a[w+1|0]=y;y=y>>8;a[w+2|0]=y;y=y>>8;a[w+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;B=z+16|0;C=h}c[i>>2]=C;c[k>>2]=B;if((B|0)>16){D=B-16|0;E=C<<16|f}else{h=je(f>>>((16-B|0)>>>0)|C<<B|0)|0;C=b+49204|0;b=c[C>>2]|0;y=h;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;D=B+16|0;E=f}c[i>>2]=E;c[k>>2]=D;return}function bmb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0;g=c[b+49224>>2]|0;h=(g|0)<(e|0)?g:e;e=(1<<h)-1|0;g=(d|0)/(e|0)|0;i=(d|0)%(e|0)|0;if((g|0)>8){e=b+49192|0;j=c[e>>2]|0;k=b+49196|0;l=c[k>>2]|0;if((l|0)>9){m=l-9|0;n=j<<9|511}else{o=je(511>>>((9-l|0)>>>0)|j<<l|0)|0;j=b+49204|0;p=c[j>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;m=l+23|0;n=511}c[e>>2]=n;c[k>>2]=m;if((m|0)>(f|0)){q=m-f|0;r=n<<f|d}else{l=je(d>>>((f-m|0)>>>0)|n<<m|0)|0;n=b+49204|0;j=c[n>>2]|0;y=l;a[j]=y;y=y>>8;a[j+1|0]=y;y=y>>8;a[j+2|0]=y;y=y>>8;a[j+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;q=32-f+m|0;r=d}c[e>>2]=r;c[k>>2]=q;return}if((g|0)==0){s=c[b+49192>>2]|0;t=c[b+49196>>2]|0}else{q=(1<<g)-1|0;k=b+49192|0;r=c[k>>2]|0;e=b+49196|0;d=c[e>>2]|0;if((d|0)>(g|0)){u=d-g|0;v=r<<g|q}else{m=je(q>>>((g-d|0)>>>0)|r<<d|0)|0;r=b+49204|0;f=c[r>>2]|0;y=m;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;u=32-g+d|0;v=q}c[k>>2]=v;c[e>>2]=u;s=v;t=u}u=b+49192|0;v=b+49196|0;if((t|0)>1){w=t-1|0;x=s<<1}else{e=je(s<<t|0)|0;s=b+49204|0;k=c[s>>2]|0;y=e;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;w=t+31|0;x=0}c[u>>2]=x;c[v>>2]=w;if((h|0)==1){return}if((i|0)>0){t=i+1|0;if((w|0)>(h|0)){z=w-h|0;A=x<<h|t}else{i=je(x<<w|t>>>((h-w|0)>>>0)|0)|0;s=b+49204|0;k=c[s>>2]|0;y=i;a[k]=y;y=y>>8;a[k+1|0]=y;y=y>>8;a[k+2|0]=y;y=y>>8;a[k+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;z=32-h+w|0;A=t}c[u>>2]=A;c[v>>2]=z;return}else{z=h-1|0;if((w|0)>(z|0)){B=w-z|0;C=x<<z}else{z=je(x<<w|0)|0;x=b+49204|0;b=c[x>>2]|0;y=z;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;B=33-h+w|0;C=0}c[u>>2]=C;c[v>>2]=B;return}}function cmb(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;l=i;m=FFb(2427824,(n=i,i=i+80|0,c[n>>2]=b,c[n+8>>2]=d,c[n+16>>2]=e,c[n+24>>2]=e,c[n+32>>2]=f,c[n+40>>2]=f,c[n+48>>2]=-g,c[n+56>>2]=-h,c[n+64>>2]=-j,c[n+72>>2]=k,n)|0)|0;i=n;c[a+860>>2]=m;if((m|0)==0){o=-12;i=l;return o|0}c[a+864>>2]=lrc(m|0)|0;o=0;i=l;return o|0}function dmb(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=FFb(2427824,(e=i,i=i+80|0,c[e>>2]=2581888,c[e+8>>2]=16,c[e+16>>2]=16777215,c[e+24>>2]=16777215,c[e+32>>2]=0,c[e+40>>2]=0,c[e+48>>2]=0,c[e+56>>2]=0,c[e+64>>2]=0,c[e+72>>2]=2,e)|0)|0;i=e;c[a+860>>2]=d;if((d|0)==0){f=-12;i=b;return f|0}c[a+864>>2]=lrc(d|0)|0;f=0;i=b;return f|0}function emb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+8|0;j=h|0;c[j>>2]=d;k=(g|0)==2;do{if((g|0)==2|(g|0)==0){do{if(k){l=_b(d|0,44)|0;c[j>>2]=l;if((l|0)==0){m=-1094995529;i=h;return m|0}n=l+1|0;c[j>>2]=n;l=rb(n|0,j|0,10)|0;n=c[j>>2]|0;if((a[n]|0)==44){o=n+1|0;c[j>>2]=o;p=l;q=o;break}else{m=-1094995529;i=h;return m|0}}else{p=0;q=d}}while(0);UFb(b,2437904,(r=i,i=i+8|0,c[r>>2]=p,r)|0);i=r;if((e|0)==-1){UFb(b,2634544,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}else{o=(e|0)/36e4|0;l=(o*-36e4|0)+e|0;n=(l|0)/6e3|0;s=l+(n*-6e3|0)|0;l=(s|0)/100|0;UFb(b,2610896,(r=i,i=i+32|0,c[r>>2]=o,c[r+8>>2]=n,c[r+16>>2]=l,c[r+24>>2]=s+(l*-100|0),r)|0);i=r}l=(f|0)==-1?-1:f+e|0;if((l|0)==-1){UFb(b,2634544,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}else{s=(l|0)/36e4|0;n=(s*-36e4|0)+l|0;l=(n|0)/6e3|0;o=n+(l*-6e3|0)|0;n=(o|0)/100|0;UFb(b,2610896,(r=i,i=i+32|0,c[r>>2]=s,c[r+8>>2]=l,c[r+16>>2]=n,c[r+24>>2]=o+(n*-100|0),r)|0);i=r}if(k){t=q;break}UFb(b,2350720,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;t=q}else{t=d}}while(0);d=mc(t|0,2289128)|0;q=((a[t+d|0]|0)==10)+d|0;UFb(b,2238824,(r=i,i=i+16|0,c[r>>2]=q,c[r+8>>2]=t,r)|0);i=r;if(!k){m=q;i=h;return m|0}UFb(b,2198016,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r;m=q;i=h;return m|0}function fmb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+1024|0;h=g|0;SFb(h,0,-1);j=emb(h,b,d,e,f)|0;do{if((j|0)<0){k=j}else{if(!((c[h+4>>2]|0)>>>0<(c[h+8>>2]|0)>>>0)){k=-12;break}f=a+16|0;d=a+12|0;b=iJb(c[f>>2]|0,(c[d>>2]<<2)+4|0)|0;l=b;if((b|0)==0){k=-12;break}c[f>>2]=l;f=a+8|0;b=c[f>>2]|0;m=e*10|0;c[f>>2]=b>>>0>m>>>0?b:m;m=pJb(100)|0;c[l+(c[d>>2]<<2)>>2]=m;c[m+84>>2]=3;l=_Fb(h,m+92|0)|0;if((l|0)<0){k=l;break}c[d>>2]=(c[d>>2]|0)+1;n=j;i=g;return n|0}}while(0);_Fb(h,0)|0;n=k;i=g;return n|0}function gmb(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=d+e|0;a:do{if((e|0)>0){k=(g|0)==0;l=d+(e-1)|0;if((f|0)==0){m=d;while(1){n=a[m]|0;if(n<<24>>24==0){break a}do{if(k){o=n<<24>>24;if((Ob(2140056,o|0,4)|0)==0){p=8;break}UFb(b,2116664,(q=i,i=i+8|0,c[q>>2]=o,q)|0);i=q}else{p=8}}while(0);b:do{if((p|0)==8){p=0;do{if((n<<24>>24|0)==13){if(!(m>>>0<l>>>0)){break}if((a[m+1|0]|0)==10){break b}}else if((n<<24>>24|0)==10){if(!(m>>>0<l>>>0)){break b}UFb(b,2166480,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break b}}while(0);WFb(b,n,1)}}while(0);m=m+1|0;if(!(m>>>0<j>>>0)){break a}}}if(k){r=d}else{m=d;while(1){n=a[m]|0;if(n<<24>>24==0){break a}c:do{if((_b(f|0,n<<24>>24|0)|0)==0){do{if((n<<24>>24|0)==13){if(!(m>>>0<l>>>0)){break}if((a[m+1|0]|0)==10){break c}}else if((n<<24>>24|0)==10){if(!(m>>>0<l>>>0)){break c}UFb(b,2166480,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break c}}while(0);WFb(b,n,1)}else{UFb(b,2166480,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}}while(0);m=m+1|0;if(!(m>>>0<j>>>0)){break a}}}do{m=a[r]|0;k=m<<24>>24;if(m<<24>>24==0){break a}d:do{if((_b(f|0,k|0)|0)==0){if((Ob(2140056,k|0,4)|0)!=0){UFb(b,2116664,(q=i,i=i+8|0,c[q>>2]=k,q)|0);i=q;break}do{if((m<<24>>24|0)==10){if(!(r>>>0<l>>>0)){break d}UFb(b,2166480,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;break d}else if((m<<24>>24|0)==13){if(!(r>>>0<l>>>0)){break}if((a[r+1|0]|0)==10){break d}}}while(0);WFb(b,m,1)}else{UFb(b,2166480,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q}}while(0);r=r+1|0;}while(r>>>0<j>>>0)}}while(0);UFb(b,2198016,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;i=h;return}function hmb(a){a=a|0;var b=0,d=0,e=0;b=pJb(72)|0;d=b;c[b+36>>2]=-1;if((imb(d,a)|0)>=0){e=d;return e|0}jmb(d);e=0;return e|0}function imb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+24|0;f=e|0;g=b+36|0;if((c[g>>2]|0)>-1){h=omb(b,d)|0}else{h=d}if((h|0)==0){j=-1094995529;i=e;return j|0}d=e+8|0;k=h;while(1){if((a[k]|0)==0){j=0;l=11;break}h=Bd(k|0,2239808,(m=i,i=i+16|0,c[m>>2]=d,c[m+8>>2]=f,m)|0)|0;i=m;m=mc(k|0,2234672)|0;n=k+(((a[k+m|0]|0)!=0)+m)|0;do{if((h|0)==2){if((irc(d,2387560)|0)==0){c[g>>2]=0;o=omb(b,n)|0}else{o=n}if((irc(d,2338240)|0)==0){c[g>>2]=1;p=omb(b,o)|0}else{p=o}if((irc(d,2271552)|0)==0){c[g>>2]=2;q=omb(b,p)|0}else{q=p}if((irc(d,2427768)|0)!=0){r=q;break}c[g>>2]=3;r=omb(b,q)|0}else{r=n}}while(0);if((r|0)==0){j=-1094995529;l=11;break}else{k=r}}if((l|0)==11){i=e;return j|0}return 0}function jmb(a){a=a|0;if((a|0)==0){return}lmb(a,2012768);mJb(a+56|0);lmb(a,2012912);mJb(a+60|0);lmb(a,2013056);mJb(a+64|0);lmb(a,2013200);mJb(a+68|0);kJb(a);return}function kmb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;a:do{if((d|0)==0){f=0;while(1){if(!(f>>>0<4>>>0)){break a}g=2012768+(f*144|0)|0;if((irc(c[g>>2]|0,2427768)|0)==0){break}else{f=f+1|0}}lmb(a,g)}}while(0);g=a+32|0;d=c[g>>2]|0;if((imb(a,b)|0)==0){h=(c[a+28>>2]|0)+(d*20|0)|0}else{h=0}if((e|0)==0){return h|0}c[e>>2]=(c[g>>2]|0)-d;return h|0}function lmb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+8|0;e=d|0;f=a;a=b+16|0;g=f+(c[a>>2]|0)|0;c[e>>2]=1;h=b+4|0;j=c[h>>2]|0;if((j|0)==0){k=g;l=e}else{k=c[g>>2]|0;l=f+(c[b+20>>2]|0)|0}do{if((k|0)==0){m=j}else{g=c[l>>2]|0;if((g|0)<=0){m=j;break}e=b+24|0;n=b+12|0;o=1;p=k;q=g;while(1){if((c[e>>2]|0)==0){r=q}else{g=0;do{if((c[b+24+(g*12|0)+4>>2]|0)==0){mJb(p+(c[b+24+(g*12|0)+8>>2]|0)|0)}g=g+1|0;}while((c[b+24+(g*12|0)>>2]|0)!=0);r=c[l>>2]|0}if((o|0)>=(r|0)){break}o=o+1|0;p=p+(c[n>>2]|0)|0;q=r}m=c[h>>2]|0}}while(0);c[l>>2]=0;if((m|0)==0){i=d;return}mJb(f+(c[a>>2]|0)|0);i=d;return}function mmb(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0;g=i;i=i+256|0;h=g+32|0;j=g+168|0;k=g+176|0;l=g+184|0;m=g+192|0;n=g+200|0;o=g+208|0;p=g+216|0;q=g+224|0;r=g+232|0;s=g+240|0;t=g+248|0;do{if((f|0)!=0){u=d|0;v=g|0;w=d+4|0;x=g+40|0;y=g+8|0;z=g+16|0;A=d+8|0;B=g+24|0;C=d+12|0;D=h;E=d+16|0;F=d+20|0;G=d+24|0;H=d+28|0;I=d+32|0;J=d+36|0;K=d+40|0;L=f;M=0;N=0;a:while(1){O=L;P=M;while(1){Q=(P|0)!=0;if((a[O]|0)==0){R=73;break a}do{if(Q){if((c[u>>2]|0)==0){S=P;break}T=Bd(O|0,2581880,(U=i,i=i+8|0,c[U>>2]=v,U)|0)|0;i=U;if((T|0)!=1){if((krc(O,2437880,2)|0)!=0){S=P;break}}ef[c[u>>2]&4095](e,P,N);S=0}else{S=0}}while(0);T=Bd(O|0,2581880,(U=i,i=i+8|0,c[U>>2]=v,U)|0)|0;i=U;if((T|0)==1){T=c[w>>2]|0;if((T|0)!=0){re[T&1023](e,(a[v]|0)==78|0)}V=O+2|0}else{if((krc(O,2437880,2)|0)!=0){break}T=O+1|0;W=a[T]|0;if(W<<24>>24==92){X=T;while(1){b[h>>1]=48;mrc(x|0,0,128)|0;c[j>>2]=-1;c[l>>2]=-1;c[m>>2]=-1;c[n>>2]=-1;c[s>>2]=-1;c[t>>2]=-1;Y=Bd(X|0,2350680,(U=i,i=i+24|0,c[U>>2]=y,c[U+8>>2]=z,c[U+16>>2]=k,U)|0)|0;i=U;b:do{if((Y|0)>1){Z=a[z]|0;if(Z<<24>>24==48){_=1}else{_=(Z<<24>>24!=49)<<31>>31}c[k>>2]=((_|0)!=-1)+(c[k>>2]|0);Z=c[A>>2]|0;if((Z|0)==0){break}ef[Z&4095](e,a[y]|0,_)}else{Z=Bd(X|0,2289112,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((Z|0)<=0){$=Bd(X|0,2238808,(U=i,i=i+24|0,c[U>>2]=j,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if(($|0)>1){break}$=Bd(X|0,2197992,(U=i,i=i+24|0,c[U>>2]=h,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if(($|0)>1){break}$=Bd(X|0,2166456,(U=i,i=i+32|0,c[U>>2]=h,c[U+8>>2]=j,c[U+16>>2]=B,c[U+24>>2]=k,U)|0)|0;i=U;if(($|0)>2){break}$=Bd(X|0,2140040,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if(($|0)<=0){aa=Bd(X|0,2116640,(U=i,i=i+24|0,c[U>>2]=n,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((aa|0)>1){break}aa=Bd(X|0,2634520,(U=i,i=i+24|0,c[U>>2]=h,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((aa|0)>1){break}aa=Bd(X|0,2610864,(U=i,i=i+32|0,c[U>>2]=h,c[U+8>>2]=n,c[U+16>>2]=B,c[U+24>>2]=k,U)|0)|0;i=U;if((aa|0)>2){break}aa=Bd(X|0,2584432,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((aa|0)<=0){ba=Bd(X|0,2563608,(U=i,i=i+24|0,c[U>>2]=x,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((ba|0)>1){break}ba=Bd(X|0,2545960,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((ba|0)<=0){ca=Bd(X|0,2528240,(U=i,i=i+24|0,c[U>>2]=l,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((ca|0)>1){break}ca=Bd(X|0,2513272,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((ca|0)<=0){da=Bd(X|0,2499616,(U=i,i=i+24|0,c[U>>2]=m,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((da|0)>1){break}da=Bd(X|0,2487e3,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;if((da|0)>0){break}da=Bd(X|0,2475528,(U=i,i=i+24|0,c[U>>2]=m,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((da|0)>1){break}da=Bd(X|0,2466576,(U=i,i=i+16|0,c[U>>2]=B,c[U+8>>2]=k,U)|0)|0;i=U;do{if((da|0)<=0){ea=Bd(X|0,2456584,(U=i,i=i+24|0,c[U>>2]=x,c[U+8>>2]=B,c[U+16>>2]=k,U)|0)|0;i=U;if((ea|0)>1){break}ea=Bd(X|0,2439408,(U=i,i=i+48|0,c[U>>2]=o,c[U+8>>2]=p,c[U+16>>2]=q,c[U+24>>2]=r,c[U+32>>2]=B,c[U+40>>2]=k,U)|0)|0;i=U;do{if((ea|0)<=4){fa=Bd(X|0,2428600,(U=i,i=i+64|0,c[U>>2]=o,c[U+8>>2]=p,c[U+16>>2]=q,c[U+24>>2]=r,c[U+32>>2]=s,c[U+40>>2]=t,c[U+48>>2]=B,c[U+56>>2]=k,U)|0)|0;i=U;if((fa|0)>6){break}fa=Bd(X|0,2418088,(U=i,i=i+32|0,c[U>>2]=o,c[U+8>>2]=p,c[U+16>>2]=B,c[U+24>>2]=k,U)|0)|0;i=U;if((fa|0)>2){fa=c[J>>2]|0;if((fa|0)==0){break b}ga=c[o>>2]|0;ha=c[p>>2]|0;Se[fa&1023](e,ga,ha,ga,ha,-1,-1);break b}ha=Bd(X|0,2409096,(U=i,i=i+32|0,c[U>>2]=o,c[U+8>>2]=p,c[U+16>>2]=B,c[U+24>>2]=k,U)|0)|0;i=U;if((ha|0)<=2){c[k>>2]=(mc(X+1|0,2401496)|0)+2;break b}ha=c[K>>2]|0;if((ha|0)==0){break b}ef[ha&4095](e,c[o>>2]|0,c[p>>2]|0);break b}}while(0);ea=c[J>>2]|0;if((ea|0)==0){break b}Se[ea&1023](e,c[o>>2]|0,c[p>>2]|0,c[q>>2]|0,c[r>>2]|0,c[s>>2]|0,c[t>>2]|0);break b}}while(0);da=c[I>>2]|0;if((da|0)==0){break b}re[da&1023](e,x);break b}}while(0);ca=c[m>>2]|0;do{if((ca|0)==-1){ia=-1}else{if((a[X+2|0]|0)==110){ia=ca;break}if((ca&4|0)==0){ja=(ca&8|0)!=0?3:0}else{ja=6}da=ja+(ca&3)|0;c[m>>2]=da;ia=da}}while(0);ca=c[H>>2]|0;if((ca|0)==0){break b}re[ca&1023](e,ia);break b}}while(0);ba=c[G>>2]|0;if((ba|0)==0){break b}re[ba&1023](e,c[l>>2]|0);break b}}while(0);aa=c[F>>2]|0;if((aa|0)==0){break b}re[aa&1023](e,(a[x]|0)!=0?x:0);break b}}while(0);$=c[E>>2]|0;if(($|0)==0){break b}ef[$&4095](e,c[n>>2]|0,(a[D]|0)-48|0);break b}}while(0);Z=c[C>>2]|0;if((Z|0)==0){break}ef[Z&4095](e,c[j>>2]|0,(a[D]|0)-48|0)}}while(0);Y=X+((c[k>>2]|0)-1)|0;Z=a[Y]|0;if(Z<<24>>24==92){X=Y}else{ka=Y;la=Z;break}}}else{ka=T;la=W}if(la<<24>>24==125){V=ka+1|0}else{ma=-1094995529;R=78;break a}}if((V|0)==0){na=S;oa=N;R=4;break a}else{O=V;P=S}}X=(S|0)==0;Z=X?O:S;Y=X?1:N+1|0;X=O+1|0;if((X|0)==0){na=Z;oa=Y;R=4;break}else{L=X;M=Z;N=Y}}if((R|0)==4){if((na|0)==0){break}pa=na;qa=oa;ra=d|0}else if((R|0)==73){if(Q){pa=P;qa=N;ra=u}else{break}}else if((R|0)==78){i=g;return ma|0}M=c[ra>>2]|0;if((M|0)==0){break}ef[M&4095](e,pa,qa)}}while(0);qa=c[d+44>>2]|0;if((qa|0)==0){ma=0;i=g;return ma|0}qe[qa&1023](e);ma=0;i=g;return ma|0}function nmb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((d|0)==0){e=3}else{if((a[d]|0)==0){e=3}else{f=d}}if((e|0)==3){f=2394680}d=c[b+24>>2]|0;g=b+20|0;b=0;while(1){if((b|0)>=(d|0)){h=0;e=8;break}i=c[g>>2]|0;if((irc(c[i+(b*36|0)>>2]|0,f)|0)==0){break}else{b=b+1|0}}if((e|0)==8){return h|0}h=i+(b*36|0)|0;return h|0}function omb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=b+36|0;f=c[e>>2]|0;g=b+40+(f<<2)|0;if((d|0)==0){h=0;return h|0}i=2012772+(f*144|0)|0;j=(f|0)!=0;k=(f|0)==0;l=b;m=2012784+(f*144|0)|0;n=2012776+(f*144|0)|0;o=c[b+56+(f<<2)>>2]|0;p=d;a:while(1){d=a[p]|0;if((d<<24>>24|0)==33){if((a[p+1|0]|0)==58){q=p;r=o}else{s=6}}else if((d<<24>>24|0)==91){s=4;break}else if((d<<24>>24|0)==59){q=p;r=o}else if((d<<24>>24|0)==0){h=p;s=47;break}else{s=6}b:do{if((s|0)==6){s=0;d=c[i>>2]|0;if(j&(o|0)==0){t=lrc(d|0)|0;if((krc(p,d,t)|0)!=0){h=0;s=47;break a}if((a[p+t|0]|0)!=58){h=0;s=47;break a}d=p+(t+1)|0;t=d;u=0;v=a[d]|0;c:while(1){if((v<<24>>24|0)==13|(v<<24>>24|0)==10|(v<<24>>24|0)==0){break}else{w=t;x=v}while(1){d=w+1|0;if(!(x<<24>>24==32)){break}w=d;x=a[d]|0}d=mc(w|0,2231056)|0;y=iJb(u,(c[g>>2]<<2)+4|0)|0;z=y;if((y|0)==0){h=0;s=47;break a}c[z+(c[g>>2]<<2)>>2]=-1;y=0;while(1){A=c[2012792+(f*144|0)+(y*12|0)>>2]|0;if((A|0)==0){break}if((krc(w,A,d)|0)==0){s=17;break}else{y=y+1|0}}if((s|0)==17){s=0;c[z+(c[g>>2]<<2)>>2]=y}c[g>>2]=(c[g>>2]|0)+1;A=w+(((a[w+d|0]|0)==44)+d)|0;while(1){B=a[A]|0;if(B<<24>>24==32){A=A+1|0}else{t=A;u=z;v=B;continue c}}}c[b+56+(c[e>>2]<<2)>>2]=u;q=t;r=u;break}if(k){v=mc(p|0,2218864)|0;if((a[p+v|0]|0)==58){C=0}else{q=p;r=o;break}while(1){z=c[2012792+(C*12|0)>>2]|0;if((z|0)==0){q=p;r=o;break b}if((krc(p,z,v)|0)==0){break}else{C=C+1|0}}u=c[2012796+(C*12|0)>>2]|0;t=(c[2012800+(C*12|0)>>2]|0)+(c[m>>2]|0)|0;z=p+(v+1)|0;while(1){if((a[z]|0)==32){z=z+1|0}else{break}}v=c[1637272+(u<<2)>>2]|0;A=mc(z|0,2227240)|0;Ee[v&511](l+t|0,z,A)|0;q=z;r=o;break}A=c[n>>2]|0;v=lrc(A|0)|0;if((krc(p,A,v)|0)!=0){q=p;r=o;break}if((a[p+v|0]|0)!=58){q=p;r=o;break}A=c[e>>2]|0;d=l+(c[2012788+(A*144|0)>>2]|0)|0;y=l+(c[2012784+(A*144|0)>>2]|0)|0;B=c[2012780+(A*144|0)>>2]|0;A=iJb(c[y>>2]|0,ca((c[d>>2]|0)+1|0,B)|0)|0;if((A|0)==0){h=0;s=47;break a}c[y>>2]=A;y=ca(c[d>>2]|0,B)|0;D=A+y|0;mrc(D|0,0,B|0)|0;c[d>>2]=(c[d>>2]|0)+1;if((D|0)==0){h=0;s=47;break a}D=p+(v+1)|0;v=D;d=0;B=a[D]|0;while(1){if((B<<24>>24|0)==13|(B<<24>>24|0)==10|(B<<24>>24|0)==0){q=v;r=o;break b}D=c[g>>2]|0;if((d|0)>=(D|0)){q=v;r=o;break b}E=D-1|0;D=v;F=B;while(1){G=D+1|0;if(!(F<<24>>24==32)){break}D=G;F=a[G]|0}F=(d|0)==(E|0);G=mc(D|0,(F?2227240:2222520)|0)|0;H=c[o+(d<<2)>>2]|0;if((H|0)>-1){Ee[c[1637272+(c[2012792+(f*144|0)+(H*12|0)+4>>2]<<2)>>2]&511](A+((c[2012792+(f*144|0)+(H*12|0)+8>>2]|0)+y)|0,D,G)|0}H=D+G|0;do{if(F){I=H}else{if((a[H]|0)==0){I=H;break}I=D+(G+1)|0}}while(0);while(1){J=a[I]|0;if(!(J<<24>>24==32)){break}I=I+1|0}v=I;d=d+1|0;B=J}}}while(0);B=mc(q|0,2234672)|0;d=q+(((a[q+B|0]|0)!=0)+B)|0;if((d|0)==0){h=0;s=47;break}else{o=r;p=d}}if((s|0)==4){c[e>>2]=-1;h=p;return h|0}else if((s|0)==47){return h|0}return 0}function pmb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hJb(e+1|0)|0;g=(f|0)!=0;if(!g){h=g&1;i=h^1;return i|0}nrc(f|0,d|0,e)|0;a[f+e|0]=0;e=b;b=c[e>>2]|0;if((b|0)!=0){kJb(b)}c[e>>2]=f;h=g&1;i=h^1;return i|0}function qmb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=i;e=Bd(b|0,2215920,(b=i,i=i+8|0,c[b>>2]=a,b)|0)|0;i=b;i=d;return(e|0)==1|0}function rmb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=i;e=Bd(b|0,2207568,(b=i,i=i+8|0,c[b>>2]=a,b)|0)|0;i=b;i=d;return(e|0)==1|0}function smb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=i;e=Bd(b|0,2211072,(f=i,i=i+8|0,c[f>>2]=a,f)|0)|0;i=f;if((e|0)==1){g=1;i=d;return g|0}e=Bd(b|0,2215920,(f=i,i=i+8|0,c[f>>2]=a,f)|0)|0;i=f;g=(e|0)==1|0;i=d;return g|0}function tmb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=Bd(b|0,2213352,(b=i,i=i+32|0,c[b>>2]=e,c[b+8>>2]=f,c[b+16>>2]=g,c[b+24>>2]=h,b)|0)|0;i=b;b=(j|0)==4;if(!b){k=b&1;i=d;return k|0}c[a>>2]=((c[f>>2]|0)*6e3|0)+((c[e>>2]|0)*36e4|0)+((c[g>>2]|0)*100|0)+(c[h>>2]|0);k=b&1;i=d;return k|0}function umb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=Bd(b|0,2215920,(b=i,i=i+8|0,c[b>>2]=e,b)|0)|0;i=b;if((f|0)!=1){g=0;i=d;return g|0}f=c[e>>2]|0;c[a>>2]=(f>>>1&2)+f-(-(f>>>3&1)&5);g=1;i=d;return g|0}function vmb(a){a=a|0;var b=0,d=0,e=0;b=c[a+60>>2]|0;l8(b+4|0,a);d=a+120|0;c[b+1428>>2]=((c[d>>2]|0)+15|0)/16|0;e=a+124|0;c[b+1432>>2]=((c[e>>2]|0)+15|0)/16|0;c[b+1436>>2]=(c[d>>2]|0)/16|0;c[b+1440>>2]=(c[e>>2]|0)/16|0;c[b>>2]=a;return}function wmb(){var a=0,b=0,c=0.0;if(!(+g[2194973]!=0.0)){a=0;do{g[8779640+(a<<2)>>2]=+ad(+(+(a-15|0)/3.0));a=a+1|0;}while((a|0)<64)}if(+g[1353659]!=0.0){return}else{b=0}do{c=+g[692872+(b<<2)>>2]*2.0;g[5414448+(47-b<<2)>>2]=c;g[5414448+(b<<2)>>2]=c;b=b+1|0;}while((b|0)<24);return}function xmb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;c[a+192>>2]=d;e=a+196|0;c[e>>2]=1<<d;c[a+188>>2]=b;g[a>>2]=+Kqc(1.0,b);g[a+4>>2]=+Kqc(1.0,b-1|0);g[a+8>>2]=+Kqc(1.0,b-2|0);g[a+12>>2]=+Kqc(1.0,b-3|0);g[a+16>>2]=+Kqc(1.0,b-4|0);g[a+20>>2]=+Kqc(1.0,b-5|0);g[a+24>>2]=+Kqc(1.0,b-6|0);g[a+28>>2]=+Kqc(1.0,b-7|0);g[a+32>>2]=+Kqc(1.0,b-8|0);g[a+36>>2]=+Kqc(1.0,b-9|0);g[a+40>>2]=+Kqc(1.0,b-10|0);g[a+44>>2]=+Kqc(1.0,b-11|0);g[a+48>>2]=+Kqc(1.0,b-12|0);g[a+52>>2]=+Kqc(1.0,b-13|0);g[a+56>>2]=+Kqc(1.0,b-14|0);g[a+60>>2]=+Kqc(1.0,b-15|0);b=-15;do{g[a+64+(b+15<<2)>>2]=+ad(+(+(b|0)*(-1.0/+(c[e>>2]|0))));b=b+1|0;}while((b|0)<16);return}function ymb(a,b,d,e,f,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=i|0;var j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0;if((c[f>>2]|0)==0){j=1.0}else{j=+g[a+(c[f+4>>2]<<2)>>2]}f=c[e>>2]|0;if((f|0)==0){if((h|0)>0){k=0}else{l=d;m=b+(h<<2)|0;n=m;o=h<<2;nrc(l|0,n|0,o)|0;return}do{g[i+(k<<2)>>2]=j*+g[b+(k<<2)>>2]+ +g[d+(k<<2)>>2];k=k+1|0;}while((k|0)<(h|0));l=d;m=b+(h<<2)|0;n=m;o=h<<2;nrc(l|0,n|0,o)|0;return}if((f|0)>0){k=a+196|0;p=a+188|0;q=c[a+192>>2]|0;r=0;s=0;while(1){t=c[e+32+(r<<2)>>2]<<q;u=c[e+4+(r<<2)>>2]|0;v=+g[a+(u<<2)>>2];w=r+1|0;x=(w|0)<(f|0);if(x){y=e+4+(w<<2)|0}else{y=p}z=+g[a+64+((c[y>>2]|0)+15-u<<2)>>2];if((s|0)<(t|0)){u=s;while(1){g[i+(u<<2)>>2]=v*(j*+g[b+(u<<2)>>2]+ +g[d+(u<<2)>>2]);A=u+1|0;if((A|0)<(t|0)){u=A}else{B=t;break}}}else{B=s}u=(c[k>>2]|0)+t|0;if((B|0)<(u|0)){A=B+1|0;C=(u|0)>(A|0);D=B;E=v;while(1){g[i+(D<<2)>>2]=E*(j*+g[b+(D<<2)>>2]+ +g[d+(D<<2)>>2]);F=D+1|0;if((F|0)<(u|0)){D=F;E=z*E}else{break}}G=C?u:A}else{G=B}if(x){r=w;s=G}else{H=G;break}}}else{H=0}if((H|0)<(h|0)){I=H}else{l=d;m=b+(h<<2)|0;n=m;o=h<<2;nrc(l|0,n|0,o)|0;return}do{g[i+(I<<2)>>2]=j*+g[b+(I<<2)>>2]+ +g[d+(I<<2)>>2];I=I+1|0;}while((I|0)<(h|0));l=d;m=b+(h<<2)|0;n=m;o=h<<2;nrc(l|0,n|0,o)|0;return}function zmb(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0;h=e;nrc(f|0,h|0,184)|0;e=(c|0)==0;if(e){i=c<<1;j=f+(i<<2)|0;k=j;nrc(h|0,k|0,184)|0;return}else{l=0}do{m=a+(l<<2)|0;n=b+(l<<2)|0;o=l<<1;g[f+(o+46<<2)>>2]=+g[m>>2]+ +g[n>>2];g[f+((o|1)+46<<2)>>2]=+g[m>>2]- +g[n>>2];n=l|1;m=a+(n<<2)|0;p=b+(n<<2)|0;g[f+((o|2)+46<<2)>>2]=+g[m>>2]+ +g[p>>2];g[f+((o|3)+46<<2)>>2]=+g[m>>2]- +g[p>>2];l=l+2|0;}while(l>>>0<c>>>0);if(e){i=c<<1;j=f+(i<<2)|0;k=j;nrc(h|0,k|0,184)|0;return}else{q=c;r=f;s=d}while(1){d=0;t=0.0;u=0.0;do{t=t+ +g[r+(d<<2)>>2]*+g[5414448+(d<<2)>>2];e=d|1;u=u+ +g[r+(e<<2)>>2]*+g[5414448+(e<<2)>>2];d=d+2|0;}while((d|0)<48);g[s>>2]=u;g[s+4>>2]=t;d=q-1|0;if((d|0)==0){break}else{q=d;r=r+8|0;s=s+8|0}}i=c<<1;j=f+(i<<2)|0;k=j;nrc(h|0,k|0,184)|0;return}function Amb(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+8|0;b=a|0;d=0;e=0;f=2508;while(1){c[3344524+(d*20|0)>>2]=3667704+(e<<2);g=c[1428920+(d<<2)>>2]|0;h=3344532+(d*20|0)|0;c[h>>2]=1<<g;c[9772340+(d*20|0)>>2]=3667704+(f<<2);j=c[1429160+(d<<2)>>2]|0;k=9772348+(d*20|0)|0;c[k>>2]=1<<j;$2(3344520+(d*20|0)|0,g,c[1428904+(d<<2)>>2]|0,c[1428952+(d<<2)>>2]|0,1,1,c[1428936+(d<<2)>>2]|0,1,1,c[1428888+(d<<2)>>2]|0,1,1,4)|0;$2(9772336+(d*20|0)|0,j,c[1429144+(d<<2)>>2]|0,c[1429192+(d<<2)>>2]|0,1,1,c[1429176+(d<<2)>>2]|0,1,1,c[1429128+(d<<2)>>2]|0,1,1,4)|0;j=d+1|0;if((j|0)<4){d=j;e=(c[h>>2]|0)+e|0;f=(c[k>>2]|0)+f|0}else{l=0;m=76;break}}while(1){c[5120524+(l*20|0)>>2]=3667704+(m<<2);f=c[1429032+(l<<2)>>2]|0;e=5120532+(l*20|0)|0;c[e>>2]=1<<f;$2(5120520+(l*20|0)|0,f,c[1429e3+(l<<2)>>2]|0,c[1429096+(l<<2)>>2]|0,1,1,c[1429064+(l<<2)>>2]|0,2,2,c[1428968+(l<<2)>>2]|0,1,1,4)|0;f=l+1|0;if((f|0)<8){l=f;m=(c[e>>2]|0)+m|0}else{break}}c[b>>2]=2564;m=0;do{l=c[2007072+(m<<4)>>2]|0;if((l|0)==0){c[5093708+(m*20|0)>>2]=0}else{Bmb(l,c[2007076+(m<<4)>>2]|0,b,5093704+(m*20|0)|0)}m=m+1|0;}while((m|0)<112);Bmb(2010616,0,b,6041512);Bmb(2010616,2010608,b,6041532);Bmb(2010960,2010944,b,6041552);Bmb(2010928,2010912,b,6041572);Bmb(2010896,2010880,b,6041592);Bmb(2010864,2010848,b,6041612);Bmb(2010752,2010720,b,6041632);Bmb(2010832,2010800,b,6041652);Bmb(2010712,2010680,b,6041672);Bmb(2010792,2010760,b,6041692);Bmb(2010664,2010632,b,6041712);Bmb(2010568,0,b,3661224);Bmb(2010592,0,b,3661244);Bmb(2010584,2010576,b,3661264);Bmb(2010560,2010528,b,3661284);Bmb(2010520,2010488,b,3661304);Bmb(2010472,2010440,b,3661324);Bmb(2011232,2010976,b,3661344);i=a;return}function Bmb(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+768|0;j=h|0;k=h+512|0;l=a[d]|0;m=a[d+1|0]|0;n=m&255;a:do{if((l&255)>>>0>(m&255)>>>0){o=0}else{p=l&255;q=0;r=0;s=d+2|0;b:while(1){t=s+1|0;u=a[s]|0;if(u<<24>>24==0){v=q;w=r}else{x=p&255;y=q;z=r;A=u&255;while(1){if((z|0)>=256){break b}a[k+z|0]=x;u=y+1|0;b[j+(z<<1)>>1]=y;B=z+1|0;C=A-1|0;if((C|0)>0){y=u;z=B;A=C}else{v=u;w=B;break}}}A=p+1|0;if((A|0)>(n|0)){o=w;break a}else{p=A;q=v<<1;r=w;s=t}}KIb(0,0,2610832,(s=i,i=i+24|0,c[s>>2]=2584392,c[s+8>>2]=2563584,c[s+16>>2]=66,s)|0);i=s;Hd()}}while(0);c[g+4>>2]=3667704+(c[f>>2]<<2);w=1<<n;c[g+12>>2]=w;$2(g,n,o,k|0,1,1,j,2,2,e,1,1,4)|0;c[f>>2]=(c[f>>2]|0)+w;i=h;return}function Cmb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0,Fc=0,Gc=0,Hc=0,Ic=0,Jc=0,Kc=0,Lc=0,Mc=0,Nc=0,Oc=0,Pc=0,Qc=0,Rc=0,Sc=0,Tc=0,Uc=0,Vc=0,Wc=0,Xc=0,Yc=0,Zc=0,_c=0,$c=0,ad=0,bd=0,cd=0,dd=0,ed=0,fd=0,gd=0,hd=0,id=0,jd=0,kd=0,ld=0,md=0,nd=0,od=0,pd=0;k=i;i=i+296|0;l=k|0;m=k+192|0;n=k+256|0;o=f+8|0;p=c[o>>2]|0;q=f+16|0;r=c[q>>2]|0;s=f|0;f=c[s>>2]|0;t=f+(p>>>3)|0;u=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(p&7)>>>27;t=p+5|0;c[o>>2]=r>>>0>t>>>0?t:r;r=u+1|0;t=g+4|0;c[t>>2]=r;if((u-28|0)>>>0<3>>>0){KIb(j,16,2426880,(v=i,i=i+8|0,c[v>>2]=r,v)|0);i=v;w=-1094995529;i=k;return w|0}r=c[o>>2]|0;u=d[f+(r>>>3)|0]<<(r&7)>>>7;c[o>>2]=((r|0)<(c[q>>2]|0))+r;c[g+20>>2]=u&1;u=(h|0)>0;a:do{if(u){r=g+84|0;p=g+76|0;x=g+80|0;y=g+92|0;z=g+100|0;A=g+96|0;B=0;b:while(1){mrc(g+72+(B*7768|0)+20|0,0,128)|0;C=g+72+(B*7768|0)|0;D=g+72+(B*7768|0)+8|0;c[D>>2]=0;E=c[o>>2]|0;F=c[q>>2]|0;G=c[s>>2]|0;H=G+(E>>>3)|0;I=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>30;H=E+2|0;E=F>>>0>H>>>0?H:F;c[o>>2]=E;c:do{if((I|0)==1){H=G+(E>>>3)|0;J=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(E&7)>>>30;H=E+2|0;K=F>>>0>H>>>0?H:F;c[o>>2]=K;if((B|0)!=0){c[D>>2]=J;do{if((J|0)==0){H=c[t>>2]|0;c[g+72+(B*7768|0)+4>>2]=H;L=H}else{H=c[o>>2]|0;M=c[q>>2]|0;N=G+(H>>>3)|0;O=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(H&7)>>>27;N=H+5|0;c[o>>2]=M>>>0>N>>>0?N:M;M=g+72+(B*7768|0)+4|0;c[M>>2]=O;if((O|0)>(c[t>>2]|0)){P=15;break b}if((c[D>>2]|0)!=3){L=O;break}O=c[o>>2]|0;N=c[q>>2]|0;H=G+(O>>>3)|0;Q=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(O&7)>>>30;H=O+2|0;c[o>>2]=N>>>0>H>>>0?H:N;c[g+72+(B*7768|0)+12>>2]=Q+1+(c[C>>2]<<1);L=c[M>>2]|0}}while(0);M=g+72+(B*7768|0)+4|0;if((L|0)==0){R=0;break}Q=c[o>>2]|0;N=c[q>>2]|0;H=G+(Q>>>3)|0;O=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(Q&7)>>>30;H=Q+2|0;Q=N>>>0>H>>>0?H:N;c[o>>2]=Q;if((c[M>>2]|0)<=0){R=0;break}H=3344520+(O*20|0)|0;S=c[3344524+(O*20|0)>>2]|0;O=0;T=Q;Q=N;while(1){N=c[H>>2]|0;U=G+(T>>>3)|0;V=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(T&7)>>>((32-N|0)>>>0);N=e[S+(V<<2)>>1]|0;U=(b[S+(V<<2)+2>>1]|0)+T|0;c[o>>2]=Q>>>0>U>>>0?U:Q;c[g+72+(B*7768|0)+20+(O<<2)>>2]=(c[g+92+(O<<2)>>2]|0)+N&7;N=O+1|0;if((N|0)>=(c[M>>2]|0)){R=0;break c}O=N;T=c[o>>2]|0;Q=c[q>>2]|0}}Q=G+(K>>>3)|0;T=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(K&7)>>>30;Q=K+2|0;c[o>>2]=F>>>0>Q>>>0?Q:F;c[x>>2]=T;do{if((T|0)==0){Q=c[t>>2]|0;c[p>>2]=Q;W=Q}else{Q=c[o>>2]|0;O=c[q>>2]|0;M=G+(Q>>>3)|0;S=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(Q&7)>>>27;M=Q+5|0;c[o>>2]=O>>>0>M>>>0?M:O;c[p>>2]=S;if((S|0)>(c[t>>2]|0)){P=26;break b}if((c[x>>2]|0)!=3){W=S;break}S=c[o>>2]|0;O=c[q>>2]|0;M=G+(S>>>3)|0;Q=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(S&7)>>>30;M=S+2|0;c[o>>2]=O>>>0>M>>>0?M:O;c[r>>2]=Q+1+(c[C>>2]<<1);W=c[p>>2]|0}}while(0);if((W|0)==0){R=J;break}T=c[o>>2]|0;K=c[q>>2]|0;Q=G+(T>>>3)|0;O=(je(d[Q]|d[Q+1|0]<<8|d[Q+2|0]<<16|d[Q+3|0]<<24|0)|0)<<(T&7);Q=O>>>27;M=T+5|0;T=K>>>0>M>>>0?M:K;c[o>>2]=T;if((Q|0)>(c[p>>2]|0)){P=29;break b}M=G+(T>>>3)|0;S=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(T&7)>>>30;M=T+2|0;T=K>>>0>M>>>0?M:K;c[o>>2]=T;M=G+(T>>>3)|0;H=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(T&7)>>>29;M=T+3|0;T=K>>>0>M>>>0?M:K;c[o>>2]=T;do{if((Q|0)!=0){M=G+(T>>>3)|0;N=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(T&7)>>>29;M=T+3|0;c[o>>2]=K>>>0>M>>>0?M:K;c[y>>2]=N;if(O>>>0>268435455>>>0){X=1}else{break}do{N=c[o>>2]|0;M=c[q>>2]|0;U=G+(N>>>3)|0;V=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(N&7)>>>29;U=N+3|0;c[o>>2]=M>>>0>U>>>0?U:M;c[g+92+(X<<2)>>2]=V;X=X+1|0;}while((X|0)<(Q|0))}}while(0);if((Q|0)>=(c[p>>2]|0)){R=J;break}O=32-S|0;if((S|0)==0){K=Q;while(1){c[g+92+(K<<2)>>2]=H;T=K+1|0;if((T|0)<(c[p>>2]|0)){K=T}else{R=J;break}}}else{K=Q;while(1){T=c[o>>2]|0;V=c[q>>2]|0;M=G+(T>>>3)|0;U=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(T&7)>>>(O>>>0);M=T+S|0;c[o>>2]=V>>>0>M>>>0?M:V;c[g+92+(K<<2)>>2]=U+H&7;U=K+1|0;if((U|0)<(c[p>>2]|0)){K=U}else{R=J;break}}}}else if((I|0)==0){if((c[t>>2]|0)>0){Y=0;Z=E;_=F}else{R=0;break}while(1){J=G+(Z>>>3)|0;K=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(Z&7)>>>29;J=Z+3|0;c[o>>2]=_>>>0>J>>>0?J:_;c[g+72+(B*7768|0)+20+(Y<<2)>>2]=K;K=Y+1|0;if((K|0)>=(c[t>>2]|0)){R=0;break c}Y=K;Z=c[o>>2]|0;_=c[q>>2]|0}}else if((I|0)==3){K=G+(E>>>3)|0;J=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(E&7)>>>30;K=E+2|0;H=F>>>0>K>>>0?K:F;c[o>>2]=H;K=G+(H>>>3)|0;S=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(H&7)>>>30;K=H+2|0;c[o>>2]=F>>>0>K>>>0?K:F;c[D>>2]=S;do{if((S|0)==0){K=c[t>>2]|0;c[g+72+(B*7768|0)+4>>2]=K;$=K}else{K=c[o>>2]|0;H=c[q>>2]|0;O=G+(K>>>3)|0;Q=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(K&7)>>>27;O=K+5|0;c[o>>2]=H>>>0>O>>>0?O:H;H=g+72+(B*7768|0)+4|0;c[H>>2]=Q;if((Q|0)>(c[t>>2]|0)){P=68;break b}if((c[D>>2]|0)!=3){$=Q;break}Q=c[o>>2]|0;O=c[q>>2]|0;K=G+(Q>>>3)|0;U=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(Q&7)>>>30;K=Q+2|0;c[o>>2]=O>>>0>K>>>0?K:O;c[g+72+(B*7768|0)+12>>2]=U+1+(c[C>>2]<<1);$=c[H>>2]|0}}while(0);S=g+72+(B*7768|0)+4|0;if(($|0)==0){R=J;break}H=c[o>>2]|0;U=c[q>>2]|0;O=G+(H>>>3)|0;K=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(H&7)>>>30;O=H+2|0;H=U>>>0>O>>>0?O:U;c[o>>2]=H;O=G+(H>>>3)|0;Q=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(H&7)>>>29;O=H+3|0;c[o>>2]=U>>>0>O>>>0?O:U;c[g+72+(B*7768|0)+20>>2]=Q;if((c[S>>2]|0)<=1){R=J;break}Q=3344520+(K*20|0)|0;U=c[3344524+(K*20|0)>>2]|0;K=1;while(1){O=c[Q>>2]|0;H=c[o>>2]|0;V=c[q>>2]|0;M=G+(H>>>3)|0;T=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(H&7)>>>((32-O|0)>>>0);O=e[U+(T<<2)>>1]|0;M=(b[U+(T<<2)+2>>1]|0)+H|0;c[o>>2]=V>>>0>M>>>0?M:V;c[g+72+(B*7768|0)+20+(K<<2)>>2]=(c[g+72+(B*7768|0)+20+(K-1<<2)>>2]|0)+O&7;O=K+1|0;if((O|0)<(c[S>>2]|0)){K=O}else{R=J;break}}}else if((I|0)==2){J=G+(E>>>3)|0;K=(je(d[J]|d[J+1|0]<<8|d[J+2|0]<<16|d[J+3|0]<<24|0)|0)<<(E&7)>>>30;J=E+2|0;c[o>>2]=F>>>0>J>>>0?J:F;c[D>>2]=K;do{if((K|0)==0){c[g+72+(B*7768|0)+4>>2]=c[t>>2]}else{J=c[o>>2]|0;S=c[q>>2]|0;U=G+(J>>>3)|0;Q=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(J&7)>>>27;U=J+5|0;c[o>>2]=S>>>0>U>>>0?U:S;c[g+72+(B*7768|0)+4>>2]=Q;if((Q|0)>(c[t>>2]|0)){P=42;break b}if((c[D>>2]|0)!=3){break}Q=c[o>>2]|0;S=c[q>>2]|0;U=G+(Q>>>3)|0;J=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(Q&7)>>>30;U=Q+2|0;c[o>>2]=S>>>0>U>>>0?U:S;c[g+72+(B*7768|0)+12>>2]=J+1+(c[C>>2]<<1)}}while(0);if((B|0)!=0){K=g+72+(B*7768|0)+4|0;if((c[K>>2]|0)==0){R=0;break}J=c[o>>2]|0;S=c[q>>2]|0;U=G+(J>>>3)|0;Q=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(J&7)>>>30;U=J+2|0;J=S>>>0>U>>>0?U:S;c[o>>2]=J;U=c[3344524+(Q*20|0)>>2]|0;O=3344520+(Q*20|0)|0;Q=c[O>>2]|0;V=G+(J>>>3)|0;M=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(J&7)>>>((32-Q|0)>>>0);Q=e[U+(M<<2)>>1]|0;V=(b[U+(M<<2)+2>>1]|0)+J|0;c[o>>2]=S>>>0>V>>>0?V:S;c[g+72+(B*7768|0)+20>>2]=(c[y>>2]|0)+Q&7;if((c[K>>2]|0)>1){aa=1}else{R=0;break}while(1){Q=aa-1|0;S=(c[g+92+(aa<<2)>>2]|0)-(c[g+92+(Q<<2)>>2]|0)|0;V=c[O>>2]|0;J=c[o>>2]|0;M=c[q>>2]|0;H=G+(J>>>3)|0;T=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(J&7)>>>((32-V|0)>>>0);V=e[U+(T<<2)>>1]|0;H=(b[U+(T<<2)+2>>1]|0)+J|0;c[o>>2]=M>>>0>H>>>0?H:M;c[g+72+(B*7768|0)+20+(aa<<2)>>2]=S+V+(c[g+72+(B*7768|0)+20+(Q<<2)>>2]|0)&7;Q=aa+1|0;if((Q|0)<(c[K>>2]|0)){aa=Q}else{R=0;break c}}}if((c[p>>2]|0)==0){R=0;break}K=c[o>>2]|0;U=c[q>>2]|0;O=G+(K>>>3)|0;Q=je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0;O=K&7;V=K+1|0;K=U>>>0>V>>>0?V:U;c[o>>2]=K;V=G+(K>>>3)|0;S=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(K&7)>>>31;V=K+1|0;K=U>>>0>V>>>0?V:U;c[o>>2]=K;V=3344520+(S*20|0)|0;M=G+(K>>>3)|0;H=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>29;M=K+3|0;K=U>>>0>M>>>0?M:U;c[o>>2]=K;M=G+(K>>>3)|0;J=(je(d[M]|d[M+1|0]<<8|d[M+2|0]<<16|d[M+3|0]<<24|0)|0)<<(K&7)>>>28;M=K+4|0;c[o>>2]=U>>>0>M>>>0?M:U;U=c[p>>2]|0;do{if((U|0)==0){ba=0}else{c[z>>2]=H;c[A>>2]=H;c[y>>2]=H;if((U|0)>3){da=3}else{ba=U;break}do{c[g+92+(da<<2)>>2]=H-(a[(d[2010408+da|0]|0)-1+(2005768+(H*144|0)+(J*9|0))|0]|0);da=da+1|0;}while((da|0)<(U|0));ba=c[p>>2]|0}}while(0);if((Q&-2147483648>>>(O>>>0)|0)==0){if((ba|0)<=0){R=0;break}U=V|0;J=c[3344524+(S*20|0)>>2]|0;H=0;while(1){M=c[U>>2]|0;K=c[o>>2]|0;T=c[q>>2]|0;N=G+(K>>>3)|0;ea=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(K&7)>>>((32-M|0)>>>0);M=e[J+(ea<<2)>>1]|0;N=(b[J+(ea<<2)+2>>1]|0)+K|0;c[o>>2]=T>>>0>N>>>0?N:T;T=g+92+(H<<2)|0;c[T>>2]=(c[T>>2]|0)+M&7;M=H+1|0;if((M|0)<(c[p>>2]|0)){H=M}else{R=0;break c}}}if((ba&-2|0)>0){H=3344524+(S*20|0)|0;J=V|0;U=0;while(1){O=c[o>>2]|0;Q=d[G+(O>>>3)|0]|0;M=c[q>>2]|0;T=((O|0)<(M|0))+O|0;c[o>>2]=T;if((Q&128>>>((O&7)>>>0)|0)==0){O=g+92+(U<<2)|0;Q=c[O>>2]|0;N=c[H>>2]|0;K=c[J>>2]|0;ea=G+(T>>>3)|0;fa=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(T&7)>>>((32-K|0)>>>0);K=e[N+(fa<<2)>>1]|0;ea=(b[N+(fa<<2)+2>>1]|0)+T|0;c[o>>2]=M>>>0>ea>>>0?ea:M;c[O>>2]=K+Q&7;Q=g+92+((U|1)<<2)|0;K=c[Q>>2]|0;O=c[J>>2]|0;M=c[o>>2]|0;ea=c[q>>2]|0;T=G+(M>>>3)|0;fa=(je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(M&7)>>>((32-O|0)>>>0);O=e[N+(fa<<2)>>1]|0;T=(b[N+(fa<<2)+2>>1]|0)+M|0;c[o>>2]=ea>>>0>T>>>0?T:ea;c[Q>>2]=O+K&7}K=U+2|0;O=c[p>>2]|0;if((K|0)<(O&-2|0)){U=K}else{ga=K;ha=O;break}}}else{ga=0;ha=ba}if((ha&1|0)==0){R=0;break}U=g+92+(ga<<2)|0;J=c[U>>2]|0;H=c[3344524+(S*20|0)>>2]|0;O=c[V>>2]|0;K=c[o>>2]|0;Q=c[q>>2]|0;ea=G+(K>>>3)|0;T=(je(d[ea]|d[ea+1|0]<<8|d[ea+2|0]<<16|d[ea+3|0]<<24|0)|0)<<(K&7)>>>((32-O|0)>>>0);O=e[H+(T<<2)>>1]|0;ea=(b[H+(T<<2)+2>>1]|0)+K|0;c[o>>2]=Q>>>0>ea>>>0?ea:Q;c[U>>2]=O+J&7;R=0}else{R=0}}while(0);F=c[D>>2]|0;do{if((F|0)==2){E=c[g+72+(B*7768|0)+4>>2]|0;if((E|0)>=(c[t>>2]|0)){break}if((B|0)==0){I=E;do{c[g+92+(I<<2)>>2]=1;I=I+1|0;}while((I|0)<(c[t>>2]|0))}else{I=E;do{V=c[o>>2]|0;S=d[G+(V>>>3)|0]<<(V&7)>>>7;c[o>>2]=((V|0)<(c[q>>2]|0))+V;c[g+72+(B*7768|0)+20+(I<<2)>>2]=S&1;I=I+1|0;}while((I|0)<(c[t>>2]|0))}}else if((F|0)==3){if((B|0)==0){ia=(c[t>>2]|0)-(c[r>>2]|0)|0;ja=c[p>>2]|0}else{I=c[g+72+(B*7768|0)+4>>2]|0;ia=(c[g+72+(B*7768|0)+12>>2]|0)+I|0;ja=I}if((ja|0)<(ia|0)){ka=ja}else{break}do{c[g+72+(B*7768|0)+20+(ka<<2)>>2]=1;ka=ka+1|0;}while((ka|0)<(ia|0))}}while(0);d:do{if((R|0)!=0){F=R-1+((c[C>>2]|0)*3|0)|0;la=0;while(1){if((la|0)>=(c[t>>2]|0)){break d}D=g+72+(B*7768|0)+20+(la<<2)|0;ma=(c[D>>2]|0)+(a[2005576+(F<<5)+la|0]|0)|0;c[D>>2]=ma;if(ma>>>0>7>>>0){P=88;break b}la=la+1|0}}}while(0);C=B+1|0;if((C|0)<(h|0)){B=C}else{na=G;break a}}if((P|0)==15){KIb(j,16,2634480,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==26){KIb(j,16,2634480,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==29){KIb(j,16,2140008,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==42){KIb(j,16,2634480,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==68){KIb(j,16,2634480,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==88){KIb(j,16,2116600,(v=i,i=i+16|0,c[v>>2]=la,c[v+8>>2]=ma,v)|0);i=v;w=-1094995529;i=k;return w|0}}else{na=f}}while(0);f=c[t>>2]|0;t=f-1|0;e:do{if((f|0)>0){if((h|0)==2){oa=f;pa=t}else{ma=f;la=t;while(1){if((c[g+92+(la<<2)>>2]|0)!=0){qa=ma;break e}if((la|0)>0){ma=la;la=la-1|0}else{qa=la;break e}}}while(1){if((c[g+92+(pa<<2)>>2]|0)!=0){qa=oa;break e}if((c[g+7860+(pa<<2)>>2]|0)!=0){qa=oa;break e}if((pa|0)>0){oa=pa;pa=pa-1|0}else{qa=pa;break}}}else{qa=f}}while(0);f=g+12|0;c[f>>2]=qa;pa=g+8|0;c[pa>>2]=(d[2010376+t|0]|0)+1;f:do{if((qa|0)==0){t=g+16|0;c[t>>2]=0;ra=t;P=215}else{t=g+16|0;c[t>>2]=(d[2010376+(qa-1)|0]|0)+1;do{if(u){oa=g+220|0;la=g+228|0;ma=g+224|0;R=0;g:while(1){mrc(g+72+(R*7768|0)+148|0,0,128)|0;ia=c[o>>2]|0;ka=c[q>>2]|0;sa=c[s>>2]|0;ja=sa+(ia>>>3)|0;ga=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ia&7)>>>30;ja=ia+2|0;ia=ka>>>0>ja>>>0?ja:ka;c[o>>2]=ia;h:do{if((ga|0)==2){ja=sa+(ia>>>3)|0;ha=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(ia&7)>>>30;ja=ia+2|0;ba=ka>>>0>ja>>>0?ja:ka;c[o>>2]=ba;if((R|0)!=0){ja=c[5120524+(ha*20|0)>>2]|0;da=5120520+(ha*20|0)|0;aa=c[da>>2]|0;$=sa+(ba>>>3)|0;_=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(ba&7)>>>((32-aa|0)>>>0);aa=e[ja+(_<<2)>>1]|0;$=(b[ja+(_<<2)+2>>1]|0)+ba|0;c[o>>2]=ka>>>0>$>>>0?$:ka;c[g+72+(R*7768|0)+148>>2]=(c[oa>>2]|0)+aa&63;if((c[f>>2]|0)>1){ta=1}else{break}while(1){aa=ta-1|0;$=(c[g+220+(ta<<2)>>2]|0)-(c[g+220+(aa<<2)>>2]|0)|0;_=c[da>>2]|0;Z=c[o>>2]|0;Y=c[q>>2]|0;X=sa+(Z>>>3)|0;W=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(Z&7)>>>((32-_|0)>>>0);_=e[ja+(W<<2)>>1]|0;X=(b[ja+(W<<2)+2>>1]|0)+Z|0;c[o>>2]=Y>>>0>X>>>0?X:Y;c[g+72+(R*7768|0)+148+(ta<<2)>>2]=$+_+(c[g+72+(R*7768|0)+148+(aa<<2)>>2]|0)&63;ta=ta+1|0;if((ta|0)>=(c[f>>2]|0)){break h}}}ja=ha|4;da=sa+(ba>>>3)|0;aa=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ba&7)>>>26;da=ba+6|0;_=ka>>>0>da>>>0?da:ka;c[o>>2]=_;da=sa+(_>>>3)|0;$=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(_&7)>>>26;da=_+6|0;c[o>>2]=ka>>>0>da>>>0?da:ka;da=c[f>>2]|0;if((da|0)==0){break}c[la>>2]=aa;c[ma>>2]=aa;c[oa>>2]=aa;if((da|0)>3){_=3;do{c[g+220+(_<<2)>>2]=aa-(a[(d[2010408+_|0]|0)-1+(2008920+($*9|0))|0]|0);_=_+1|0;}while((_|0)<(da|0));ua=c[f>>2]|0}else{ua=da}if((ua|0)<=0){break}_=5120520+(ja*20|0)|0;$=c[5120524+(ja*20|0)>>2]|0;aa=0;do{ba=c[_>>2]|0;ha=c[o>>2]|0;Y=c[q>>2]|0;X=sa+(ha>>>3)|0;Z=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(ha&7)>>>((32-ba|0)>>>0);ba=e[$+(Z<<2)>>1]|0;X=(b[$+(Z<<2)+2>>1]|0)+ha|0;c[o>>2]=Y>>>0>X>>>0?X:Y;Y=g+220+(aa<<2)|0;c[Y>>2]=(ba<<28>>28)+(c[Y>>2]|0)&63;aa=aa+1|0;}while((aa|0)<(c[f>>2]|0))}else if((ga|0)==1){aa=sa+(ia>>>3)|0;$=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ia&7)>>>30;aa=ia+2|0;_=ka>>>0>aa>>>0?aa:ka;c[o>>2]=_;if((R|0)!=0){if((c[f>>2]|0)<=0){break}aa=5120520+($*20|0)|0;ja=c[5120524+($*20|0)>>2]|0;da=0;Y=_;ba=ka;while(1){X=c[aa>>2]|0;ha=sa+(Y>>>3)|0;Z=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(Y&7)>>>((32-X|0)>>>0);X=e[ja+(Z<<2)>>1]|0;ha=(b[ja+(Z<<2)+2>>1]|0)+Y|0;c[o>>2]=ba>>>0>ha>>>0?ha:ba;c[g+72+(R*7768|0)+148+(da<<2)>>2]=(c[g+220+(da<<2)>>2]|0)+X&63;X=da+1|0;if((X|0)>=(c[f>>2]|0)){break h}da=X;Y=c[o>>2]|0;ba=c[q>>2]|0}}ba=sa+(_>>>3)|0;Y=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<(_&7);if(($|0)!=3){ba=Y>>>27;da=_+5|0;ja=ka>>>0>da>>>0?da:ka;c[o>>2]=ja;da=sa+(ja>>>3)|0;aa=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ja&7)>>>29;da=ja+3|0;ja=ka>>>0>da>>>0?da:ka;c[o>>2]=ja;da=sa+(ja>>>3)|0;X=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ja&7)>>>26;da=ja+6|0;ja=ka>>>0>da>>>0?da:ka;c[o>>2]=ja;da=c[f>>2]|0;if((ba|0)>(da|0)|(aa|0)==7){P=124;break g}if((ba|0)==0){va=da}else{da=sa+(ja>>>3)|0;ha=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ja&7)>>>26;da=ja+6|0;c[o>>2]=ka>>>0>da>>>0?da:ka;c[oa>>2]=ha;if(Y>>>0>268435455>>>0){ha=1;do{da=c[o>>2]|0;ja=c[q>>2]|0;Z=sa+(da>>>3)|0;W=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(da&7)>>>26;Z=da+6|0;c[o>>2]=ja>>>0>Z>>>0?Z:ja;c[g+220+(ha<<2)>>2]=W;ha=ha+1|0;}while((ha|0)<(ba|0))}va=c[f>>2]|0}if((ba|0)>=(va|0)){wa=$;xa=va;P=154;break}ha=32-aa|0;if((aa|0)==0){W=ba;while(1){c[g+220+(W<<2)>>2]=X;ja=W+1|0;Z=c[f>>2]|0;if((ja|0)<(Z|0)){W=ja}else{wa=$;xa=Z;P=154;break h}}}else{W=ba;while(1){Z=c[o>>2]|0;ja=c[q>>2]|0;da=sa+(Z>>>3)|0;L=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(Z&7)>>>(ha>>>0);da=Z+aa|0;c[o>>2]=ja>>>0>da>>>0?da:ja;c[g+220+(W<<2)>>2]=L+X&63;L=W+1|0;ja=c[f>>2]|0;if((L|0)<(ja|0)){W=L}else{wa=$;xa=ja;P=154;break h}}}}$=Y>>>26;W=_+6|0;X=ka>>>0>W>>>0?W:ka;c[o>>2]=X;W=sa+(X>>>3)|0;aa=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(X&7)>>>26;W=X+6|0;c[o>>2]=ka>>>0>W>>>0?W:ka;W=c[f>>2]|0;do{if((W|0)!=0){c[la>>2]=$;c[ma>>2]=$;c[oa>>2]=$;if((W|0)>3){ya=3}else{break}do{c[g+220+(ya<<2)>>2]=$-(a[(d[2010408+ya|0]|0)-1+(2008920+(aa*9|0))|0]|0);ya=ya+1|0;}while((ya|0)<(W|0))}}while(0);W=c[o>>2]|0;aa=c[q>>2]|0;$=sa+(W>>>3)|0;_=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(W&7)>>>27;$=W+5|0;W=aa>>>0>$>>>0?$:aa;c[o>>2]=W;$=sa+(W>>>3)|0;Y=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(W&7)>>>30;$=W+2|0;W=aa>>>0>$>>>0?$:aa;c[o>>2]=W;$=sa+(W>>>3)|0;X=(je(d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0)|0)<<(W&7)>>>28;$=W+4|0;W=aa>>>0>$>>>0?$:aa;c[o>>2]=W;$=X+57|0;i:do{if((_|0)!=0){X=0;ha=W;ba=aa;while(1){ja=g+220+(X<<2)|0;L=c[ja>>2]|0;da=sa+(ha>>>3)|0;Z=(je(d[da]|d[da+1|0]<<8|d[da+2|0]<<16|d[da+3|0]<<24|0)|0)<<(ha&7)>>>28;da=ha+4|0;c[o>>2]=ba>>>0>da>>>0?da:ba;c[ja>>2]=L+57+Z&63;Z=X+1|0;if((Z|0)>=(_|0)){break i}X=Z;ha=c[o>>2]|0;ba=c[q>>2]|0}}}while(0);if((_|0)>=(c[f>>2]|0)){break}aa=32-Y|0;if((Y|0)==0){W=_;do{ba=g+220+(W<<2)|0;c[ba>>2]=(c[ba>>2]|0)+$&63;W=W+1|0;}while((W|0)<(c[f>>2]|0))}else{W=_;do{ba=g+220+(W<<2)|0;ha=(c[ba>>2]|0)+$|0;X=c[o>>2]|0;Z=c[q>>2]|0;L=sa+(X>>>3)|0;ja=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(X&7)>>>(aa>>>0);L=X+Y|0;c[o>>2]=Z>>>0>L>>>0?L:Z;c[ba>>2]=ha+ja&63;W=W+1|0;}while((W|0)<(c[f>>2]|0))}}else if((ga|0)==0){if((c[f>>2]|0)>0){za=0;Aa=ia;Ba=ka}else{break}while(1){W=sa+(Aa>>>3)|0;Y=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Aa&7)>>>26;W=Aa+6|0;c[o>>2]=Ba>>>0>W>>>0?W:Ba;c[g+72+(R*7768|0)+148+(za<<2)>>2]=Y;Y=za+1|0;if((Y|0)>=(c[f>>2]|0)){break h}za=Y;Aa=c[o>>2]|0;Ba=c[q>>2]|0}}else if((ga|0)==3){if((R|0)!=0){if((c[f>>2]|0)>0){Ca=0}else{break}while(1){c[g+72+(R*7768|0)+148+(Ca<<2)>>2]=c[g+220+(Ca<<2)>>2];Ca=Ca+1|0;if((Ca|0)>=(c[f>>2]|0)){break h}}}Y=sa+(ia>>>3)|0;W=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(ia&7)>>>30;Y=ia+2|0;aa=ka>>>0>Y>>>0?Y:ka;c[o>>2]=aa;Y=sa+(aa>>>3)|0;$=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(aa&7)>>>30;Y=aa+2|0;aa=ka>>>0>Y>>>0?Y:ka;c[o>>2]=aa;if((W|0)!=3){Y=sa+(aa>>>3)|0;_=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(aa&7)>>>26;Y=aa+6|0;c[o>>2]=ka>>>0>Y>>>0?Y:ka;c[oa>>2]=_;_=c[f>>2]|0;if((_|0)<=1){wa=W;xa=_;P=154;break}_=5120520+($*20|0)|0;Y=c[5120524+($*20|0)>>2]|0;ja=1;while(1){ha=c[_>>2]|0;ba=c[o>>2]|0;Z=c[q>>2]|0;L=sa+(ba>>>3)|0;X=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(ba&7)>>>((32-ha|0)>>>0);ha=e[Y+(X<<2)>>1]|0;L=(b[Y+(X<<2)+2>>1]|0)+ba|0;c[o>>2]=Z>>>0>L>>>0?L:Z;c[g+220+(ja<<2)>>2]=(c[g+220+(ja-1<<2)>>2]|0)+ha&63;ha=ja+1|0;Z=c[f>>2]|0;if((ha|0)<(Z|0)){ja=ha}else{wa=W;xa=Z;P=154;break h}}}W=$|4;ja=sa+(aa>>>3)|0;Y=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(aa&7)>>>26;ja=aa+6|0;_=ka>>>0>ja>>>0?ja:ka;c[o>>2]=_;ja=sa+(_>>>3)|0;Z=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(_&7)>>>26;ja=_+6|0;c[o>>2]=ka>>>0>ja>>>0?ja:ka;ja=c[f>>2]|0;do{if((ja|0)!=0){c[la>>2]=Y;c[ma>>2]=Y;c[oa>>2]=Y;if((ja|0)>3){Da=3}else{break}do{c[g+220+(Da<<2)>>2]=Y-(a[(d[2010408+Da|0]|0)-1+(2008920+(Z*9|0))|0]|0);Da=Da+1|0;}while((Da|0)<(ja|0))}}while(0);ja=c[o>>2]|0;Z=c[q>>2]|0;Y=sa+(ja>>>3)|0;aa=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(ja&7)>>>28;Y=ja+4|0;c[o>>2]=Z>>>0>Y>>>0?Y:Z;Z=aa+56|0;c[oa>>2]=Z+(c[oa>>2]|0)&63;if((c[f>>2]|0)<=1){break}aa=5120520+(W*20|0)|0;Y=c[5120524+(W*20|0)>>2]|0;ja=Z;Z=1;do{$=c[aa>>2]|0;_=c[o>>2]|0;ha=c[q>>2]|0;L=sa+(_>>>3)|0;ba=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(_&7)>>>((32-$|0)>>>0);$=e[Y+(ba<<2)>>1]|0;L=(b[Y+(ba<<2)+2>>1]|0)+_|0;c[o>>2]=ha>>>0>L>>>0?L:ha;ja=($<<28>>28)+(ja&63)|0;$=g+220+(Z<<2)|0;c[$>>2]=ja+(c[$>>2]|0)&63;Z=Z+1|0;}while((Z|0)<(c[f>>2]|0))}}while(0);do{if((P|0)==154){P=0;if((wa|0)==3|(wa|0)==0){break}ka=wa-1|0;if((xa|0)>0){Ea=0}else{break}while(1){ia=g+72+(R*7768|0)+148+(Ea<<2)|0;Fa=(c[ia>>2]|0)-(a[2008856+(ka<<5)+Ea|0]|0)|0;c[ia>>2]=Fa;if(Fa>>>0>63>>>0){P=158;break g}ia=Ea+1|0;if((ia|0)<(c[f>>2]|0)){Ea=ia}else{break}}}}while(0);ka=R+1|0;if((ka|0)<(h|0)){R=ka}else{P=160;break}}if((P|0)==124){KIb(j,16,2197960,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==158){KIb(j,16,2166416,(v=i,i=i+16|0,c[v>>2]=Ea,c[v+8>>2]=Fa,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==160){if((c[f>>2]|0)==0){ra=t;P=215;break f}else{Ga=sa;break}}}else{Ga=na}}while(0);R=c[o>>2]|0;oa=d[Ga+(R>>>3)|0]<<(R&7)>>>7;c[o>>2]=((R|0)<(c[q>>2]|0))+R;R=g+24|0;c[R>>2]=oa&1;if(u){Ha=0}else{P=458;break}j:while(1){mrc(g+72+(Ha*7768|0)+276|0,0,128)|0;oa=(c[R>>2]|0)!=0?7:3;ma=c[o>>2]|0;la=c[s>>2]|0;G=d[la+(ma>>>3)|0]<<(ma&7)>>>7;c[o>>2]=((ma|0)<(c[q>>2]|0))+ma;c[g+72+(Ha*7768|0)+16>>2]=G&1;G=c[o>>2]|0;ma=c[q>>2]|0;ka=la+(G>>>3)|0;ia=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(G&7)>>>30;ka=G+2|0;G=ma>>>0>ka>>>0?ka:ma;c[o>>2]=G;do{if((ia|0)==3){if((Ha|0)==0){break}ka=(c[R>>2]|0)!=0?9772396:9772336;ga=d[la+(G>>>3)|0]|0;Z=((G|0)<(ma|0))+G|0;c[o>>2]=Z;if((ga&128>>>((G&7)>>>0)|0)==0){ga=c[f>>2]|0;if((ga|0)<0){w=ga;P=635;break j}else{Ia=ga}}else{ga=la+(Z>>>3)|0;Ja=(je(d[ga]|d[ga+1|0]<<8|d[ga+2|0]<<16|d[ga+3|0]<<24|0)|0)<<(Z&7)>>>27;ga=Z+5|0;c[o>>2]=ma>>>0>ga>>>0?ga:ma;if((Ja|0)>(c[f>>2]|0)){P=205;break j}else{Ia=Ja}}if((Ia|0)<=0){break}ga=ka+4|0;Z=ka|0;ka=0;do{do{if((c[g+72+(Ha*7768|0)+20+(ka<<2)>>2]|0)==0){if((c[g+92+(ka<<2)>>2]|0)==0){break}ja=c[o>>2]|0;Y=d[la+(ja>>>3)|0]<<(ja&7)>>>7;c[o>>2]=((ja|0)<(c[q>>2]|0))+ja;c[g+72+(Ha*7768|0)+276+(ka<<2)>>2]=Y&1}else{Y=c[g+348+(ka<<2)>>2]|0;ja=c[ga>>2]|0;aa=c[Z>>2]|0;W=c[o>>2]|0;$=c[q>>2]|0;ha=la+(W>>>3)|0;L=(je(d[ha]|d[ha+1|0]<<8|d[ha+2|0]<<16|d[ha+3|0]<<24|0)|0)<<(W&7)>>>((32-aa|0)>>>0);aa=e[ja+(L<<2)>>1]|0;ha=(b[ja+(L<<2)+2>>1]|0)+W|0;c[o>>2]=$>>>0>ha>>>0?ha:$;c[g+72+(Ha*7768|0)+276+(ka<<2)>>2]=aa+Y&oa}}while(0);ka=ka+1|0;}while((ka|0)<(Ia|0))}else if((ia|0)==1){ka=(c[R>>2]|0)!=0?9772356:9772336;Z=d[la+(G>>>3)|0]|0;ga=((G|0)<(ma|0))+G|0;c[o>>2]=ga;if((Z&128>>>((G&7)>>>0)|0)==0){Z=c[f>>2]|0;if((Z|0)<0){w=Z;P=635;break j}else{Ka=Z}}else{Z=la+(ga>>>3)|0;La=(je(d[Z]|d[Z+1|0]<<8|d[Z+2|0]<<16|d[Z+3|0]<<24|0)|0)<<(ga&7)>>>27;Z=ga+5|0;c[o>>2]=ma>>>0>Z>>>0?Z:ma;if((La|0)>(c[f>>2]|0)){P=177;break j}else{Ka=La}}if((Ka|0)<=0){break}Z=(Ha|0)==0;ga=ka+4|0;Y=ka|0;ka=0;do{do{if((c[g+72+(Ha*7768|0)+20+(ka<<2)>>2]|0)==0){if(Z){break}if((c[g+92+(ka<<2)>>2]|0)==0){break}aa=c[o>>2]|0;$=d[la+(aa>>>3)|0]<<(aa&7)>>>7;c[o>>2]=((aa|0)<(c[q>>2]|0))+aa;c[g+72+(Ha*7768|0)+276+(ka<<2)>>2]=$&1}else{$=c[ga>>2]|0;aa=c[Y>>2]|0;ha=c[o>>2]|0;W=c[q>>2]|0;L=la+(ha>>>3)|0;ja=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(ha&7)>>>((32-aa|0)>>>0);aa=b[$+(ja<<2)>>1]|0;L=(b[$+(ja<<2)+2>>1]|0)+ha|0;c[o>>2]=W>>>0>L>>>0?L:W;c[g+72+(Ha*7768|0)+276+(ka<<2)>>2]=aa}}while(0);ka=ka+1|0;}while((ka|0)<(Ka|0))}else if((ia|0)==2){ka=(c[R>>2]|0)==0;Y=ka?9772336:9772356;ga=ka?9772336:9772376;ka=d[la+(G>>>3)|0]|0;Z=((G|0)<(ma|0))+G|0;c[o>>2]=Z;if((ka&128>>>((G&7)>>>0)|0)==0){ka=c[f>>2]|0;if((ka|0)<0){w=ka;P=635;break j}else{Ma=ka}}else{ka=la+(Z>>>3)|0;Na=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(Z&7)>>>27;ka=Z+5|0;c[o>>2]=ma>>>0>ka>>>0?ka:ma;if((Na|0)>(c[f>>2]|0)){P=189;break j}else{Ma=Na}}if((Ma|0)<=0){break}ka=(Ha|0)==0;Z=Y+4|0;aa=Y|0;Y=ga+4|0;W=ga|0;ga=0;L=0;while(1){do{if((c[g+72+(Ha*7768|0)+20+(L<<2)>>2]|0)==0){if(ka){Oa=ga;break}if((c[g+92+(L<<2)>>2]|0)==0){Oa=ga;break}ha=c[o>>2]|0;ja=d[la+(ha>>>3)|0]<<(ha&7)>>>7;c[o>>2]=((ha|0)<(c[q>>2]|0))+ha;c[g+72+(Ha*7768|0)+276+(L<<2)>>2]=ja&1;Oa=ga}else{if((L|0)==0){ja=c[Z>>2]|0;ha=c[aa>>2]|0;$=c[o>>2]|0;_=c[q>>2]|0;ba=la+($>>>3)|0;X=(je(d[ba]|d[ba+1|0]<<8|d[ba+2|0]<<16|d[ba+3|0]<<24|0)|0)<<($&7)>>>((32-ha|0)>>>0);ha=b[ja+(X<<2)>>1]|0;ba=(b[ja+(X<<2)+2>>1]|0)+$|0;c[o>>2]=_>>>0>ba>>>0?ba:_;Pa=ha}else{ha=c[Y>>2]|0;_=c[W>>2]|0;ba=c[o>>2]|0;$=c[q>>2]|0;X=la+(ba>>>3)|0;ja=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(ba&7)>>>((32-_|0)>>>0);_=e[ha+(ja<<2)>>1]|0;X=(b[ha+(ja<<2)+2>>1]|0)+ba|0;c[o>>2]=$>>>0>X>>>0?X:$;Pa=_+ga&oa}c[g+72+(Ha*7768|0)+276+(L<<2)>>2]=Pa;Oa=Pa}}while(0);_=L+1|0;if((_|0)<(Ma|0)){ga=Oa;L=_}else{break}}}else if((ia|0)==0){L=c[R>>2]|0;ga=L+2|0;W=d[la+(G>>>3)|0]|0;Y=((G|0)<(ma|0))+G|0;c[o>>2]=Y;if((W&128>>>((G&7)>>>0)|0)==0){W=c[f>>2]|0;if((W|0)<0){w=W;P=635;break j}else{Qa=W}}else{W=la+(Y>>>3)|0;Ra=(je(d[W]|d[W+1|0]<<8|d[W+2|0]<<16|d[W+3|0]<<24|0)|0)<<(Y&7)>>>27;W=Y+5|0;c[o>>2]=ma>>>0>W>>>0?W:ma;if((Ra|0)>(c[f>>2]|0)){P=165;break j}else{Qa=Ra}}if((Qa|0)<=0){break}W=(Ha|0)==0;Y=30-L|0;L=0;do{do{if((c[g+72+(Ha*7768|0)+20+(L<<2)>>2]|0)==0){if(W){break}if((c[g+92+(L<<2)>>2]|0)==0){break}aa=c[o>>2]|0;Z=d[la+(aa>>>3)|0]<<(aa&7)>>>7;c[o>>2]=((aa|0)<(c[q>>2]|0))+aa;c[g+72+(Ha*7768|0)+276+(L<<2)>>2]=Z&1}else{Z=c[o>>2]|0;aa=c[q>>2]|0;ka=la+(Z>>>3)|0;_=(je(d[ka]|d[ka+1|0]<<8|d[ka+2|0]<<16|d[ka+3|0]<<24|0)|0)<<(Z&7)>>>(Y>>>0);ka=ga+Z|0;c[o>>2]=aa>>>0>ka>>>0?ka:aa;c[g+72+(Ha*7768|0)+276+(L<<2)>>2]=_}}while(0);L=L+1|0;}while((L|0)<(Qa|0))}}while(0);la=Ha+1|0;if((la|0)<(h|0)){Ha=la}else{ra=t;P=215;break f}}if((P|0)==165){KIb(j,16,2238760,(v=i,i=i+8|0,c[v>>2]=Ra,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==177){KIb(j,16,2238760,(v=i,i=i+8|0,c[v>>2]=La,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==189){KIb(j,16,2238760,(v=i,i=i+8|0,c[v>>2]=Na,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==205){KIb(j,16,2238760,(v=i,i=i+8|0,c[v>>2]=Ja,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==635){i=k;return w|0}}}while(0);do{if((P|0)==215){if(!u){P=458;break}Ja=g+24|0;Na=b[714392]|0;La=0;do{mrc(g+72+(La*7768|0)+404|0,0,4096)|0;mrc(g+72+(La*7768|0)+4500|0,15,5)|0;do{if((c[f>>2]|0)>0){Ra=(La|0)==0;Ha=g+72+(La*7768|0)+16|0;Qa=0;Oa=Na;while(1){Ma=Qa+1|0;Pa=b[1428784+(Ma<<1)>>1]|0;Ka=1428784+(Qa<<1)|0;Ia=Oa&65535;Ga=(Pa&65535)-Ia|0;na=g+72+(La*7768|0)+20+(Qa<<2)|0;sa=c[na>>2]|0;Fa=c[g+72+(La*7768|0)+276+(Qa<<2)>>2]|0;do{if((sa|0)==0){if(Ra){break}Ea=g+92+(Qa<<2)|0;if(!((c[Ea>>2]|0)!=0&(Fa|0)==0)){break}nrc(g+72+(La*7768|0)+404+(Ia<<1)|0,g+476+(Ia<<1)|0,Ga<<1)|0;c[na>>2]=c[Ea>>2]}else{if((c[Ja>>2]|0)==0){Ea=sa-1|0;xa=c[Ha>>2]|0;Sa=d[2011248+(xa*28|0)+(Ea<<2)+Fa|0]|0;Ta=xa;Ua=Ea}else{Sa=Fa;Ta=c[Ha>>2]|0;Ua=sa-1|0}Ea=(((Ta<<3)+Sa|0)*7|0)+Ua|0;xa=c[2007068+(Ea<<4)>>2]|0;wa=(xa|0)>-1?xa:Ea;xa=e[Ka>>1]|0;Da=a[2007064+(Ea<<4)|0]|0;Ca=Da&255;Ba=d[2007065+(Ea<<4)|0]|0;Aa=d[2007066+(Ea<<4)|0]|0;za=(1<<Aa)-1|0;if((Ga|0)<=0){break}ya=ca(Ba,Ca)|0;va=5093708+(wa*20|0)|0;ua=5093704+(wa*20|0)|0;wa=(a[2007067+(Ea<<4)|0]|0)==0;Ea=32-Aa|0;ta=Ba>>>0>1>>>0?Ba:1;qa=Da<<24>>24==1;Da=ca(ta,Ca>>>0>1>>>0?Ca:1)|0;t=0;R=c[o>>2]|0;while(1){if(qa){Va=R;Wa=c[q>>2]|0;Xa=c[s>>2]|0;P=228}else{la=c[s>>2]|0;ma=d[la+(R>>>3)|0]|0;G=c[q>>2]|0;ia=((R|0)<(G|0))+R|0;c[o>>2]=ia;if((ma&128>>>((R&7)>>>0)|0)==0){Ya=ya;Za=ia}else{Va=ia;Wa=G;Xa=la;P=228}}if((P|0)==228){P=0;la=c[va>>2]|0;G=t;ia=0;ma=Va;while(1){oa=c[ua>>2]|0;L=Xa+(ma>>>3)|0;ga=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(ma&7)>>>((32-oa|0)>>>0);oa=b[la+(ga<<2)>>1]|0;L=(b[la+(ga<<2)+2>>1]|0)+ma|0;ga=Wa>>>0>L>>>0?L:Wa;c[o>>2]=ga;L=G;Y=oa<<16>>16;oa=0;W=ga;while(1){ga=Y&za;do{if(wa){_=ga&65535;if((ga|0)==0){_a=_;$a=W;break}aa=d[Xa+(W>>>3)|0]|0;ka=((W|0)<(Wa|0))+W|0;c[o>>2]=ka;if((aa&128>>>((W&7)>>>0)|0)==0){_a=_;$a=ka;break}_a=-ga&65535;$a=ka}else{_a=ga<<Ea>>Ea&65535;$a=W}}while(0);b[g+72+(La*7768|0)+404+(L+xa<<1)>>1]=_a;ga=oa+1|0;if((ga|0)<(Ba|0)){L=L+1|0;Y=Y>>>(Aa>>>0);oa=ga;W=$a}else{break}}W=ia+1|0;if((W|0)<(Ca|0)){G=G+ta|0;ia=W;ma=$a}else{Ya=Da;Za=$a;break}}}ma=t+Ya|0;if((ma|0)<(Ga|0)){t=ma;R=Za}else{break}}}}while(0);ab=c[f>>2]|0;if((Ma|0)<(ab|0)){Qa=Ma;Oa=Pa}else{break}}if((ab|0)<=2){break}Oa=c[2007e3+((c[ra>>2]|0)-1<<2)>>2]|0;Qa=0;do{Ha=c[o>>2]|0;Ra=c[q>>2]|0;Ga=(c[s>>2]|0)+(Ha>>>3)|0;Ka=(je(d[Ga]|d[Ga+1|0]<<8|d[Ga+2|0]<<16|d[Ga+3|0]<<24|0)|0)<<(Ha&7)>>>28;Ga=Ha+4|0;c[o>>2]=Ra>>>0>Ga>>>0?Ga:Ra;a[g+72+(La*7768|0)+4500+Qa|0]=Ka;Qa=Qa+1|0;}while((Qa|0)<(Oa|0))}}while(0);La=La+1|0;}while((La|0)<(h|0));k:do{if((h|0)==2){La=g+40|0;Ja=c[ra>>2]|0;mrc(La|0,0,Ja|0)|0;Na=c[o>>2]|0;Oa=c[s>>2]|0;Qa=d[Oa+(Na>>>3)|0]|0;Ka=c[q>>2]|0;Ra=((Na|0)<(Ka|0))+Na|0;c[o>>2]=Ra;l:do{if((Qa&128>>>((Na&7)>>>0)|0)!=0){Ga=d[Oa+(Ra>>>3)|0]|0;Ha=((Ra|0)<(Ka|0))+Ra|0;c[o>>2]=Ha;if((Ga&128>>>((Ra&7)>>>0)|0)==0){mrc(La|0,1,Ja|0)|0;break}if((Ja|0)>0){bb=0;cb=Ha;db=Oa;eb=Ka}else{break}while(1){Ha=d[db+(cb>>>3)|0]<<(cb&7)>>>7;c[o>>2]=((cb|0)<(eb|0))+cb;a[g+40+bb|0]=Ha&1;Ha=bb+1|0;if((Ha|0)>=(Ja|0)){break l}bb=Ha;cb=c[o>>2]|0;db=c[s>>2]|0;eb=c[q>>2]|0}}}while(0);Ja=g+56|0;Ka=c[ra>>2]|0;mrc(Ja|0,0,Ka|0)|0;Oa=c[o>>2]|0;La=c[s>>2]|0;Ra=d[La+(Oa>>>3)|0]|0;Na=c[q>>2]|0;Qa=((Oa|0)<(Na|0))+Oa|0;c[o>>2]=Qa;if((Ra&128>>>((Oa&7)>>>0)|0)==0){fb=1;break}Oa=d[La+(Qa>>>3)|0]|0;Ra=((Qa|0)<(Na|0))+Qa|0;c[o>>2]=Ra;if((Oa&128>>>((Qa&7)>>>0)|0)==0){mrc(Ja|0,1,Ka|0)|0;fb=1;break}if((Ka|0)>0){gb=0;hb=Ra;ib=La;jb=Na}else{fb=1;break}while(1){Na=d[ib+(hb>>>3)|0]<<(hb&7)>>>7;c[o>>2]=((hb|0)<(jb|0))+hb;a[g+56+gb|0]=Na&1;Na=gb+1|0;if((Na|0)>=(Ka|0)){fb=1;break k}gb=Na;hb=c[o>>2]|0;ib=c[s>>2]|0;jb=c[q>>2]|0}}else{fb=0}}while(0);Ka=0;do{Na=c[g+72+(Ka*7768|0)+4540>>2]|0;La=c[pa>>2]|0;mrc(Na|0,0,La|0)|0;Ra=c[o>>2]|0;Ja=c[s>>2]|0;Qa=d[Ja+(Ra>>>3)|0]|0;Oa=c[q>>2]|0;Ha=((Ra|0)<(Oa|0))+Ra|0;c[o>>2]=Ha;m:do{if((Qa&128>>>((Ra&7)>>>0)|0)!=0){Ga=d[Ja+(Ha>>>3)|0]|0;sa=((Ha|0)<(Oa|0))+Ha|0;c[o>>2]=sa;if((Ga&128>>>((Ha&7)>>>0)|0)==0){mrc(Na|0,1,La|0)|0;break}if((La|0)>0){kb=0;lb=sa;mb=Ja;nb=Oa}else{break}while(1){sa=d[mb+(lb>>>3)|0]<<(lb&7)>>>7;c[o>>2]=((lb|0)<(nb|0))+lb;a[Na+kb|0]=sa&1;sa=kb+1|0;if((sa|0)>=(La|0)){break m}kb=sa;lb=c[o>>2]|0;mb=c[s>>2]|0;nb=c[q>>2]|0}}}while(0);Ka=Ka+1|0;}while((Ka|0)<(h|0));Ka=g+6540|0;La=0;n:while(1){Na=g+72+(La*7768|0)+6468|0;mrc(c[Na>>2]|0,0,960)|0;Oa=c[o>>2]|0;Ja=c[s>>2]|0;Ha=d[Ja+(Oa>>>3)|0]|0;Ra=c[q>>2]|0;Qa=((Oa|0)<(Ra|0))+Oa|0;c[o>>2]=Qa;do{if((Ha&128>>>((Oa&7)>>>0)|0)==0){c[g+72+(La*7768|0)+6476>>2]=0}else{sa=Ja+(Qa>>>3)|0;Ga=(je(d[sa]|d[sa+1|0]<<8|d[sa+2|0]<<16|d[sa+3|0]<<24|0)|0)<<(Qa&7)>>>28;sa=Qa+4|0;Fa=Ra>>>0>sa>>>0?sa:Ra;c[o>>2]=Fa;sa=Ga+1|0;na=d[Ja+(Fa>>>3)|0]|0;Ia=((Fa|0)<(Ra|0))+Fa|0;c[o>>2]=Ia;if((na&128>>>((Fa&7)>>>0)|0)==0){c[g+72+(La*7768|0)+6476>>2]=sa}else{Fa=Ja+(Ia>>>3)|0;na=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ia&7)>>>28;Fa=Ia+4|0;c[o>>2]=Ra>>>0>Fa>>>0?Fa:Ra;c[g+72+(La*7768|0)+6476>>2]=na+1}na=c[o>>2]|0;Fa=c[q>>2]|0;Ia=Ja+(na>>>3)|0;R=(je(d[Ia]|d[Ia+1|0]<<8|d[Ia+2|0]<<16|d[Ia+3|0]<<24|0)|0)<<(na&7)>>>30;Ia=na+2|0;na=Fa>>>0>Ia>>>0?Ia:Fa;c[o>>2]=na;o:do{if((R|0)==1){Ia=c[1510379]|0;t=c[Na>>2]|0;Da=0;ta=na;Ca=Fa;while(1){Aa=c[1510378]|0;Ba=Ja+(ta>>>3)|0;xa=(je(d[Ba]|d[Ba+1|0]<<8|d[Ba+2|0]<<16|d[Ba+3|0]<<24|0)|0)<<(ta&7)>>>((32-Aa|0)>>>0);Aa=b[Ia+(xa<<2)>>1]|0;Ba=(b[Ia+(xa<<2)+2>>1]|0)+ta|0;c[o>>2]=Ca>>>0>Ba>>>0?Ba:Ca;c[t+(Da*60|0)>>2]=Aa;Aa=Da+1|0;if((Aa|0)>=(sa|0)){break o}Da=Aa;ta=c[o>>2]|0;Ca=c[q>>2]|0}}else if((R|0)==0){Ca=c[Na>>2]|0;ta=Ja+(na>>>3)|0;Da=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(na&7)>>>29;ta=na+3|0;c[o>>2]=Fa>>>0>ta>>>0?ta:Fa;c[Ca>>2]=Da;if(sa>>>0>1>>>0){ob=1}else{break}do{Da=c[o>>2]|0;ta=c[q>>2]|0;t=Ja+(Da>>>3)|0;Ia=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Da&7)>>>29;t=Da+3|0;c[o>>2]=ta>>>0>t>>>0?t:ta;c[Ca+(ob*60|0)>>2]=Ia;ob=ob+1|0;}while((ob|0)<(sa|0))}else if((R|0)==2){if((La|0)==0){Ca=c[1510379]|0;Ia=c[1510378]|0;ta=Ja+(na>>>3)|0;t=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(na&7)>>>((32-Ia|0)>>>0);Ia=b[Ca+(t<<2)>>1]|0;ta=(b[Ca+(t<<2)+2>>1]|0)+na|0;c[o>>2]=Fa>>>0>ta>>>0?ta:Fa;ta=c[Ka>>2]|0;c[ta>>2]=Ia;if(!(sa>>>0>1>>>0)){break}Ia=c[1510384]|0;t=1;do{Ca=c[1510383]|0;Da=c[o>>2]|0;Pa=c[q>>2]|0;Ma=Ja+(Da>>>3)|0;Aa=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Da&7)>>>((32-Ca|0)>>>0);Ca=e[Ia+(Aa<<2)>>1]|0;Ma=(b[Ia+(Aa<<2)+2>>1]|0)+Da|0;c[o>>2]=Pa>>>0>Ma>>>0?Ma:Pa;c[ta+(t*60|0)>>2]=(c[ta+((t-1|0)*60|0)>>2]|0)+Ca&7;t=t+1|0;}while((t|0)<(sa|0))}else{t=c[1510384]|0;ta=c[Ka>>2]|0;Ia=c[Na>>2]|0;Ca=0;Pa=na;Ma=Fa;while(1){Da=c[1510383]|0;Aa=Ja+(Pa>>>3)|0;Ba=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Pa&7)>>>((32-Da|0)>>>0);Da=e[t+(Ba<<2)>>1]|0;Aa=(b[t+(Ba<<2)+2>>1]|0)+Pa|0;c[o>>2]=Ma>>>0>Aa>>>0?Aa:Ma;c[Ia+(Ca*60|0)>>2]=(c[ta+(Ca*60|0)>>2]|0)+Da&7;Da=Ca+1|0;if((Da|0)>=(sa|0)){break o}Ca=Da;Pa=c[o>>2]|0;Ma=c[q>>2]|0}}}else if((R|0)==3){if((La|0)!=0){Ma=c[Ka>>2]|0;Pa=c[Na>>2]|0;Ca=0;while(1){c[Pa+(Ca*60|0)>>2]=c[Ma+(Ca*60|0)>>2];Ca=Ca+1|0;if((Ca|0)>=(sa|0)){break o}}}Ca=Ja+(na>>>3)|0;Ma=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(na&7)>>>30;Ca=na+2|0;Pa=Fa>>>0>Ca>>>0?Ca:Fa;c[o>>2]=Pa;Ca=Ja+(Pa>>>3)|0;ta=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(Pa&7)>>>29;Ca=Pa+3|0;c[o>>2]=Fa>>>0>Ca>>>0?Ca:Fa;Ca=32-Ma|0;if((Ma|0)==0){Pa=c[Ka>>2]|0;Ia=0;do{c[Pa+(Ia*60|0)>>2]=ta;Ia=Ia+1|0;}while((Ia|0)<(sa|0))}else{Ia=0;while(1){if((Ia|0)>=(sa|0)){break o}Pa=c[o>>2]|0;t=c[q>>2]|0;Da=Ja+(Pa>>>3)|0;Aa=(je(d[Da]|d[Da+1|0]<<8|d[Da+2|0]<<16|d[Da+3|0]<<24|0)|0)<<(Pa&7)>>>(Ca>>>0);Da=Pa+Ma|0;c[o>>2]=t>>>0>Da>>>0?Da:t;t=Aa+ta|0;c[(c[Ka>>2]|0)+(Ia*60|0)>>2]=t;if((t|0)>7){w=-1094995529;P=635;break n}else{Ia=Ia+1|0}}}}}while(0);Fa=c[o>>2]|0;na=c[q>>2]|0;R=Ja+(Fa>>>3)|0;Ia=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Fa&7)>>>30;R=Fa+2|0;Fa=na>>>0>R>>>0?R:na;c[o>>2]=Fa;p:do{if((Ia|0)==2){if((La|0)==0){R=c[Ka>>2]|0;ta=R|0;do{if((c[ta>>2]|0)>0){Ma=c[1510389]|0;Ca=c[1510388]|0;t=Ja+(Fa>>>3)|0;Aa=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Fa&7)>>>((32-Ca|0)>>>0);Ca=b[Ma+(Aa<<2)>>1]|0;t=(b[Ma+(Aa<<2)+2>>1]|0)+Fa|0;c[o>>2]=na>>>0>t>>>0?t:na;c[R+4>>2]=Ca;if((c[ta>>2]|0)<=1){break}Ca=c[1510394]|0;t=1;do{Aa=c[1510393]|0;Ma=c[o>>2]|0;Da=c[q>>2]|0;Pa=Ja+(Ma>>>3)|0;Ba=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(Ma&7)>>>((32-Aa|0)>>>0);Aa=e[Ca+(Ba<<2)>>1]|0;Pa=(b[Ca+(Ba<<2)+2>>1]|0)+Ma|0;c[o>>2]=Da>>>0>Pa>>>0?Pa:Da;c[R+4+(t<<2)>>2]=(c[R+4+(t-1<<2)>>2]|0)+Aa&15;t=t+1|0;}while((t|0)<(c[ta>>2]|0))}}while(0);if(sa>>>0>1>>>0){pb=1}else{break}while(1){ta=R+(pb*60|0)|0;if((c[ta>>2]|0)>0){t=pb-1|0;Ca=c[1510399]|0;Aa=R+(t*60|0)|0;Da=0;do{Pa=c[1510398]|0;Ma=c[o>>2]|0;Ba=c[q>>2]|0;xa=Ja+(Ma>>>3)|0;Ea=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ma&7)>>>((32-Pa|0)>>>0);Pa=e[Ca+(Ea<<2)>>1]|0;xa=(b[Ca+(Ea<<2)+2>>1]|0)+Ma|0;c[o>>2]=Ba>>>0>xa>>>0?xa:Ba;if((Da|0)<(c[Aa>>2]|0)){qb=c[R+(t*60|0)+4+(Da<<2)>>2]|0}else{qb=7}c[R+(pb*60|0)+4+(Da<<2)>>2]=qb+Pa&15;Da=Da+1|0;}while((Da|0)<(c[ta>>2]|0))}pb=pb+1|0;if((pb|0)>=(sa|0)){break p}}}R=c[Na>>2]|0;ta=0;do{q:do{if((c[R+(ta*60|0)>>2]|0)>0){Da=c[o>>2]|0;t=d[Ja+(Da>>>3)|0]|0;Aa=c[q>>2]|0;Ca=((Da|0)<(Aa|0))+Da|0;c[o>>2]=Ca;Pa=R+(ta*60|0)|0;if((t&128>>>((Da&7)>>>0)|0)!=0){Da=Pa|0;if((c[Da>>2]|0)<=0){break}t=c[1510389]|0;Ba=c[1510388]|0;xa=Ja+(Ca>>>3)|0;Ma=(je(d[xa]|d[xa+1|0]<<8|d[xa+2|0]<<16|d[xa+3|0]<<24|0)|0)<<(Ca&7)>>>((32-Ba|0)>>>0);Ba=b[t+(Ma<<2)>>1]|0;xa=(b[t+(Ma<<2)+2>>1]|0)+Ca|0;c[o>>2]=Aa>>>0>xa>>>0?xa:Aa;c[R+(ta*60|0)+4>>2]=Ba;if((c[Da>>2]|0)<=1){break}Ba=c[1510394]|0;Aa=1;while(1){xa=c[1510393]|0;Ca=c[o>>2]|0;Ma=c[q>>2]|0;t=Ja+(Ca>>>3)|0;Ea=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(Ca&7)>>>((32-xa|0)>>>0);xa=e[Ba+(Ea<<2)>>1]|0;t=(b[Ba+(Ea<<2)+2>>1]|0)+Ca|0;c[o>>2]=Ma>>>0>t>>>0?t:Ma;c[R+(ta*60|0)+4+(Aa<<2)>>2]=(c[R+(ta*60|0)+4+(Aa-1<<2)>>2]|0)+xa&15;Aa=Aa+1|0;if((Aa|0)>=(c[Da>>2]|0)){break q}}}Da=c[Ka>>2]|0;Aa=Pa|0;if((c[Aa>>2]|0)<=0){break}Ba=Da+(ta*60|0)|0;xa=0;do{if((xa|0)<(c[Ba>>2]|0)){rb=c[Da+(ta*60|0)+4+(xa<<2)>>2]|0}else{rb=7}c[R+(ta*60|0)+4+(xa<<2)>>2]=rb;xa=xa+1|0;}while((xa|0)<(c[Aa>>2]|0))}}while(0);ta=ta+1|0;}while((ta|0)<(sa|0))}else if((Ia|0)==3){if((La|0)==0){ta=Ja+(Fa>>>3)|0;R=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(Fa&7)>>>30;ta=Fa+2|0;Aa=na>>>0>ta>>>0?ta:na;c[o>>2]=Aa;ta=Ja+(Aa>>>3)|0;xa=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(Aa&7)>>>28;ta=Aa+4|0;c[o>>2]=na>>>0>ta>>>0?ta:na;ta=(R|0)==0;Aa=32-R|0;Da=c[Ka>>2]|0;Ba=0;do{Pa=Da+(Ba*60|0)|0;Ma=0;while(1){if((Ma|0)>=(c[Pa>>2]|0)){break}if(ta){sb=0}else{t=c[o>>2]|0;Ca=c[q>>2]|0;Ea=Ja+(t>>>3)|0;wa=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(t&7)>>>(Aa>>>0);Ea=t+R|0;c[o>>2]=Ca>>>0>Ea>>>0?Ea:Ca;sb=wa}wa=sb+xa|0;c[Da+(Ba*60|0)+4+(Ma<<2)>>2]=wa;if((wa|0)>15){w=-1094995529;P=635;break n}else{Ma=Ma+1|0}}Ba=Ba+1|0;}while((Ba|0)<(sa|0))}else{Ba=c[Na>>2]|0;Da=c[Ka>>2]|0;xa=0;do{R=Ba+(xa*60|0)|0;if((c[R>>2]|0)>0){Aa=Da+(xa*60|0)|0;ta=0;do{if((ta|0)<(c[Aa>>2]|0)){tb=c[Da+(xa*60|0)+4+(ta<<2)>>2]|0}else{tb=7}c[Ba+(xa*60|0)+4+(ta<<2)>>2]=tb;ta=ta+1|0;}while((ta|0)<(c[R>>2]|0))}xa=xa+1|0;}while((xa|0)<(sa|0))}}else if((Ia|0)==0){xa=c[Na>>2]|0;Ba=0;do{Da=xa+(Ba*60|0)|0;if((c[Da>>2]|0)>0){R=0;do{ta=c[o>>2]|0;Aa=c[q>>2]|0;Ma=Ja+(ta>>>3)|0;Pa=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(ta&7)>>>28;Ma=ta+4|0;c[o>>2]=Aa>>>0>Ma>>>0?Ma:Aa;c[xa+(Ba*60|0)+4+(R<<2)>>2]=Pa;R=R+1|0;}while((R|0)<(c[Da>>2]|0))}Ba=Ba+1|0;}while((Ba|0)<(sa|0))}else if((Ia|0)==1){if((La|0)==0){Ba=c[Ka>>2]|0;xa=0;while(1){Da=Ba+(xa*60|0)|0;do{if((c[Da>>2]|0)>0){R=c[1510389]|0;Pa=c[1510388]|0;Aa=c[o>>2]|0;Ma=c[q>>2]|0;ta=Ja+(Aa>>>3)|0;wa=(je(d[ta]|d[ta+1|0]<<8|d[ta+2|0]<<16|d[ta+3|0]<<24|0)|0)<<(Aa&7)>>>((32-Pa|0)>>>0);Pa=b[R+(wa<<2)>>1]|0;ta=(b[R+(wa<<2)+2>>1]|0)+Aa|0;c[o>>2]=Ma>>>0>ta>>>0?ta:Ma;c[Ba+(xa*60|0)+4>>2]=Pa;if((c[Da>>2]|0)<=1){break}Pa=c[1510394]|0;Ma=1;do{ta=c[1510393]|0;Aa=c[o>>2]|0;wa=c[q>>2]|0;R=Ja+(Aa>>>3)|0;Ca=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Aa&7)>>>((32-ta|0)>>>0);ta=e[Pa+(Ca<<2)>>1]|0;R=(b[Pa+(Ca<<2)+2>>1]|0)+Aa|0;c[o>>2]=wa>>>0>R>>>0?R:wa;c[Ba+(xa*60|0)+4+(Ma<<2)>>2]=(c[Ba+(xa*60|0)+4+(Ma-1<<2)>>2]|0)+ta&15;Ma=Ma+1|0;}while((Ma|0)<(c[Da>>2]|0))}}while(0);xa=xa+1|0;if((xa|0)>=(sa|0)){break p}}}xa=c[Na>>2]|0;Ba=0;do{Da=xa+(Ba*60|0)|0;if((c[Da>>2]|0)>0){Ma=c[1510404]|0;Pa=c[Ka>>2]|0;ta=Pa+(Ba*60|0)|0;wa=0;do{R=c[1510403]|0;Aa=c[o>>2]|0;Ca=c[q>>2]|0;Ea=Ja+(Aa>>>3)|0;t=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Aa&7)>>>((32-R|0)>>>0);R=e[Ma+(t<<2)>>1]|0;Ea=(b[Ma+(t<<2)+2>>1]|0)+Aa|0;c[o>>2]=Ca>>>0>Ea>>>0?Ea:Ca;if((wa|0)<(c[ta>>2]|0)){ub=c[Pa+(Ba*60|0)+4+(wa<<2)>>2]|0}else{ub=7}c[xa+(Ba*60|0)+4+(wa<<2)>>2]=ub+R&15;wa=wa+1|0;}while((wa|0)<(c[Da>>2]|0))}Ba=Ba+1|0;}while((Ba|0)<(sa|0))}}while(0);Ia=c[o>>2]|0;na=c[q>>2]|0;Fa=Ja+(Ia>>>3)|0;Ba=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ia&7)>>>30;Fa=Ia+2|0;Ia=na>>>0>Fa>>>0?Fa:na;c[o>>2]=Ia;r:do{if((Ba|0)==0){Fa=c[Na>>2]|0;xa=0;do{Da=Fa+(xa*60|0)|0;if((c[Da>>2]|0)>0){wa=0;do{do{if((wa|0)==0){P=358}else{Pa=c[Fa+(xa*60|0)+32+(wa-1<<2)>>2]|0;if((Pa|0)<15){P=358;break}if((Pa|0)>29){c[Fa+(xa*60|0)+32+(wa<<2)>>2]=31;break}ta=30-Pa|0;Ma=ta>>>0>65535>>>0;R=Ma?ta>>>16:ta;ta=Ma?16:0;if((R&65280|0)==0){vb=ta;wb=R}else{vb=ta|8;wb=R>>>8}R=(d[1359664+wb|0]|0)+vb|0;ta=c[o>>2]|0;Ma=c[q>>2]|0;Ca=Ja+(ta>>>3)|0;Ea=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(ta&7)>>>((31-R|0)>>>0);Ca=ta+1+R|0;c[o>>2]=Ma>>>0>Ca>>>0?Ca:Ma;c[Fa+(xa*60|0)+32+(wa<<2)>>2]=Pa+1+Ea}}while(0);if((P|0)==358){P=0;Ea=c[o>>2]|0;Pa=c[q>>2]|0;Ma=Ja+(Ea>>>3)|0;Ca=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Ea&7)>>>27;Ma=Ea+5|0;c[o>>2]=Pa>>>0>Ma>>>0?Ma:Pa;c[Fa+(xa*60|0)+32+(wa<<2)>>2]=Ca}wa=wa+1|0;}while((wa|0)<(c[Da>>2]|0))}xa=xa+1|0;}while((xa|0)<(sa|0))}else if((Ba|0)==1){if((La|0)==0){xa=c[Ka>>2]|0;Fa=0;while(1){Da=xa+(Fa*60|0)|0;do{if((c[Da>>2]|0)>0){wa=c[o>>2]|0;Ca=c[q>>2]|0;Pa=Ja+(wa>>>3)|0;Ma=(je(d[Pa]|d[Pa+1|0]<<8|d[Pa+2|0]<<16|d[Pa+3|0]<<24|0)|0)<<(wa&7)>>>27;Pa=wa+5|0;c[o>>2]=Ca>>>0>Pa>>>0?Pa:Ca;c[xa+(Fa*60|0)+32>>2]=Ma;if((c[Da>>2]|0)>1){xb=1;yb=Ma}else{break}do{Ma=(c[xa+(Fa*60|0)+4+(xb<<2)>>2]|0)<=(c[xa+(Fa*60|0)+4+(xb-1<<2)>>2]|0)?6041652:6041692;Ca=c[Ma+4>>2]|0;Pa=c[Ma>>2]|0;Ma=c[o>>2]|0;wa=c[q>>2]|0;Ea=Ja+(Ma>>>3)|0;R=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ma&7)>>>((32-Pa|0)>>>0);Pa=b[Ca+(R<<2)>>1]|0;Ea=(b[Ca+(R<<2)+2>>1]|0)+Ma|0;c[o>>2]=wa>>>0>Ea>>>0?Ea:wa;yb=Pa+yb|0;c[xa+(Fa*60|0)+32+(xb<<2)>>2]=yb;xb=xb+1|0;}while((xb|0)<(c[Da>>2]|0))}}while(0);Fa=Fa+1|0;if((Fa|0)>=(sa|0)){break r}}}Fa=c[Na>>2]|0;xa=0;do{Da=Fa+(xa*60|0)|0;do{if((c[Da>>2]|0)>=1){Pa=c[Ka>>2]|0;wa=c[1510429]|0;Ea=c[1510428]|0;Ma=c[o>>2]|0;R=c[q>>2]|0;Ca=Ja+(Ma>>>3)|0;ta=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(Ma&7)>>>((32-Ea|0)>>>0);Ea=e[wa+(ta<<2)>>1]|0;Ca=(b[wa+(ta<<2)+2>>1]|0)+Ma|0;c[o>>2]=R>>>0>Ca>>>0?Ca:R;R=Pa+(xa*60|0)|0;if((c[R>>2]|0)>0){zb=c[Pa+(xa*60|0)+32>>2]|0}else{zb=0}c[Fa+(xa*60|0)+32>>2]=zb+Ea&31;if((c[Da>>2]|0)>1){Ab=1}else{break}do{Ea=(Ab|0)>=(c[R>>2]|0);Ca=Ab-1|0;do{if((c[Fa+(xa*60|0)+4+(Ab<<2)>>2]|0)>(c[Fa+(xa*60|0)+4+(Ca<<2)>>2]|0)){if(Ea){Ma=c[1510424]|0;ta=c[1510423]|0;wa=c[o>>2]|0;Aa=c[q>>2]|0;t=Ja+(wa>>>3)|0;za=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(wa&7)>>>((32-ta|0)>>>0);ta=b[Ma+(za<<2)>>1]|0;t=(b[Ma+(za<<2)+2>>1]|0)+wa|0;c[o>>2]=Aa>>>0>t>>>0?t:Aa;c[Fa+(xa*60|0)+32+(Ab<<2)>>2]=(c[Fa+(xa*60|0)+32+(Ca<<2)>>2]|0)+ta;break}ta=c[o>>2]|0;Aa=d[Ja+(ta>>>3)|0]|0;t=c[q>>2]|0;wa=((ta|0)<(t|0))+ta|0;c[o>>2]=wa;if((Aa&128>>>((ta&7)>>>0)|0)==0){c[Fa+(xa*60|0)+32+(Ab<<2)>>2]=c[Pa+(xa*60|0)+32+(Ab<<2)>>2];break}ta=c[Fa+(xa*60|0)+32+(Ca<<2)>>2]|0;if((ta|0)<15){Aa=Ja+(wa>>>3)|0;za=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(wa&7)>>>27;Aa=wa+5|0;c[o>>2]=t>>>0>Aa>>>0?Aa:t;c[Fa+(xa*60|0)+32+(Ab<<2)>>2]=za;break}if((ta|0)>29){c[Fa+(xa*60|0)+32+(Ab<<2)>>2]=31;break}za=30-ta|0;Aa=za>>>0>65535>>>0;Ma=Aa?za>>>16:za;za=Aa?16:0;if((Ma&65280|0)==0){Bb=za;Cb=Ma}else{Bb=za|8;Cb=Ma>>>8}Ma=(d[1359664+Cb|0]|0)+Bb|0;za=Ja+(wa>>>3)|0;Aa=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(wa&7)>>>((31-Ma|0)>>>0);za=wa+1+Ma|0;c[o>>2]=t>>>0>za>>>0?za:t;c[Fa+(xa*60|0)+32+(Ab<<2)>>2]=ta+1+Aa}else{Aa=Ea?6041652:6041712;ta=c[Aa+4>>2]|0;t=c[Aa>>2]|0;Aa=c[o>>2]|0;za=c[q>>2]|0;Ma=Ja+(Aa>>>3)|0;wa=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Aa&7)>>>((32-t|0)>>>0);t=b[ta+(wa<<2)>>1]|0;Ma=(b[ta+(wa<<2)+2>>1]|0)+Aa|0;c[o>>2]=za>>>0>Ma>>>0?Ma:za;if(Ea){c[Fa+(xa*60|0)+32+(Ab<<2)>>2]=(c[Fa+(xa*60|0)+32+(Ca<<2)>>2]|0)+t;break}else{c[Fa+(xa*60|0)+32+(Ab<<2)>>2]=(c[Pa+(xa*60|0)+32+(Ab<<2)>>2]|0)+t&31;break}}}while(0);Ab=Ab+1|0;}while((Ab|0)<(c[Da>>2]|0))}}while(0);xa=xa+1|0;}while((xa|0)<(sa|0))}else if((Ba|0)==2){if((La|0)!=0){xa=c[Na>>2]|0;Fa=0;while(1){Da=xa+(Fa*60|0)|0;Pa=c[Da>>2]|0;s:do{if((Pa|0)>=1){R=c[Ka>>2]|0;do{if((Pa|0)>(c[R+(Fa*60|0)>>2]|0)){Db=Pa}else{Ca=c[o>>2]|0;Ea=d[Ja+(Ca>>>3)|0]|0;c[o>>2]=((Ca|0)<(c[q>>2]|0))+Ca;t=c[Da>>2]|0;if((Ea&128>>>((Ca&7)>>>0)|0)!=0){Db=t;break}if((t|0)>0){Eb=0}else{break s}while(1){c[xa+(Fa*60|0)+32+(Eb<<2)>>2]=c[R+(Fa*60|0)+32+(Eb<<2)>>2];Eb=Eb+1|0;if((Eb|0)>=(c[Da>>2]|0)){break s}}}}while(0);if((Db|0)<=0){break}R=c[o>>2]|0;t=c[q>>2]|0;Ca=Ja+(R>>>3)|0;Ea=(je(d[Ca]|d[Ca+1|0]<<8|d[Ca+2|0]<<16|d[Ca+3|0]<<24|0)|0)<<(R&7)>>>27;Ca=R+5|0;c[o>>2]=t>>>0>Ca>>>0?Ca:t;c[xa+(Fa*60|0)+32>>2]=Ea;if((c[Da>>2]|0)>1){Fb=1;Gb=Ea}else{break}do{Ea=(c[xa+(Fa*60|0)+4+(Fb<<2)>>2]|0)<=(c[xa+(Fa*60|0)+4+(Fb-1<<2)>>2]|0)?6041652:6041692;t=c[Ea+4>>2]|0;Ca=c[Ea>>2]|0;Ea=c[o>>2]|0;R=c[q>>2]|0;za=Ja+(Ea>>>3)|0;Ma=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(Ea&7)>>>((32-Ca|0)>>>0);Ca=b[t+(Ma<<2)>>1]|0;za=(b[t+(Ma<<2)+2>>1]|0)+Ea|0;c[o>>2]=R>>>0>za>>>0?za:R;Gb=Ca+Gb|0;c[xa+(Fa*60|0)+32+(Fb<<2)>>2]=Gb;Fb=Fb+1|0;}while((Fb|0)<(c[Da>>2]|0))}}while(0);Fa=Fa+1|0;if((Fa|0)>=(sa|0)){break r}}}Fa=c[Ka>>2]|0;xa=Fa|0;if((c[xa>>2]|0)>0){Da=0;do{do{if((Da|0)==0){P=409}else{Pa=c[Fa+32+(Da-1<<2)>>2]|0;if((Pa|0)<15){P=409;break}if((Pa|0)>29){c[Fa+32+(Da<<2)>>2]=31;break}Ca=30-Pa|0;R=Ca>>>0>65535>>>0;za=R?Ca>>>16:Ca;Ca=R?16:0;if((za&65280|0)==0){Hb=Ca;Ib=za}else{Hb=Ca|8;Ib=za>>>8}za=(d[1359664+Ib|0]|0)+Hb|0;Ca=c[o>>2]|0;R=c[q>>2]|0;Ea=Ja+(Ca>>>3)|0;Ma=(je(d[Ea]|d[Ea+1|0]<<8|d[Ea+2|0]<<16|d[Ea+3|0]<<24|0)|0)<<(Ca&7)>>>((31-za|0)>>>0);Ea=Ca+1+za|0;c[o>>2]=R>>>0>Ea>>>0?Ea:R;c[Fa+32+(Da<<2)>>2]=Pa+1+Ma}}while(0);if((P|0)==409){P=0;Ma=c[o>>2]|0;Pa=c[q>>2]|0;R=Ja+(Ma>>>3)|0;Ea=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Ma&7)>>>27;R=Ma+5|0;c[o>>2]=Pa>>>0>R>>>0?R:Pa;c[Fa+32+(Da<<2)>>2]=Ea}Da=Da+1|0;}while((Da|0)<(c[xa>>2]|0))}if(sa>>>0>1>>>0){Jb=1}else{break}do{xa=Fa+(Jb*60|0)|0;t:do{if((c[xa>>2]|0)>=1){Da=c[1510409]|0;Ea=c[1510408]|0;Pa=c[o>>2]|0;R=c[q>>2]|0;Ma=Ja+(Pa>>>3)|0;za=(je(d[Ma]|d[Ma+1|0]<<8|d[Ma+2|0]<<16|d[Ma+3|0]<<24|0)|0)<<(Pa&7)>>>((32-Ea|0)>>>0);Ea=e[Da+(za<<2)>>1]|0;Ma=(b[Da+(za<<2)+2>>1]|0)+Pa|0;c[o>>2]=R>>>0>Ma>>>0?Ma:R;R=Jb-1|0;Ma=Fa+(R*60|0)|0;Pa=c[Ma>>2]|0;if((Pa|0)>0){Kb=c[Fa+(R*60|0)+32>>2]|0}else{Kb=0}c[Fa+(Jb*60|0)+32>>2]=Kb+Ea&31;if((c[xa>>2]|0)>1){Lb=1;Mb=Pa}else{break}while(1){Pa=(Lb|0)>=(Mb|0);Ea=Lb-1|0;za=(((c[Fa+(Jb*60|0)+4+(Lb<<2)>>2]|0)>(c[Fa+(Jb*60|0)+4+(Ea<<2)>>2]|0))<<1|Pa&1)+6|0;Da=c[6041516+(za*20|0)>>2]|0;Ca=c[6041512+(za*20|0)>>2]|0;za=c[o>>2]|0;t=c[q>>2]|0;Aa=Ja+(za>>>3)|0;wa=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(za&7)>>>((32-Ca|0)>>>0);Ca=b[Da+(wa<<2)>>1]|0;Aa=(b[Da+(wa<<2)+2>>1]|0)+za|0;c[o>>2]=t>>>0>Aa>>>0?Aa:t;if(Pa){c[Fa+(Jb*60|0)+32+(Lb<<2)>>2]=(c[Fa+(Jb*60|0)+32+(Ea<<2)>>2]|0)+Ca}else{c[Fa+(Jb*60|0)+32+(Lb<<2)>>2]=(c[Fa+(R*60|0)+32+(Lb<<2)>>2]|0)+Ca&31}Ca=Lb+1|0;if((Ca|0)>=(c[xa>>2]|0)){break t}Lb=Ca;Mb=c[Ma>>2]|0}}}while(0);Jb=Jb+1|0;}while((Jb|0)<(sa|0))}else if((Ba|0)==3){if((La|0)==0){Fa=Ja+(Ia>>>3)|0;xa=(je(d[Fa]|d[Fa+1|0]<<8|d[Fa+2|0]<<16|d[Fa+3|0]<<24|0)|0)<<(Ia&7)>>>30;Fa=Ia+2|0;Ma=na>>>0>Fa>>>0?Fa:na;c[o>>2]=Ma;Fa=xa+1|0;R=Ja+(Ma>>>3)|0;Ca=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(Ma&7)>>>27;R=Ma+5|0;c[o>>2]=na>>>0>R>>>0?R:na;R=xa^31;xa=c[Ka>>2]|0;Ma=0;while(1){Ea=xa+(Ma*60|0)|0;if((c[Ea>>2]|0)>0){Pa=0;do{t=c[o>>2]|0;Aa=c[q>>2]|0;za=Ja+(t>>>3)|0;wa=(je(d[za]|d[za+1|0]<<8|d[za+2|0]<<16|d[za+3|0]<<24|0)|0)<<(t&7)>>>(R>>>0);za=Fa+t|0;c[o>>2]=Aa>>>0>za>>>0?za:Aa;c[xa+(Ma*60|0)+32+(Pa<<2)>>2]=Pa+Ca+wa;Pa=Pa+1|0;}while((Pa|0)<(c[Ea>>2]|0))}Ma=Ma+1|0;if((Ma|0)>=(sa|0)){break r}}}Ma=c[Na>>2]|0;Ca=0;do{xa=Ma+(Ca*60|0)|0;if((c[xa>>2]|0)>0){Fa=c[Ka>>2]|0;R=Fa+(Ca*60|0)|0;Ea=0;do{u:do{if((Ea|0)<(c[R>>2]|0)){c[Ma+(Ca*60|0)+32+(Ea<<2)>>2]=c[Fa+(Ca*60|0)+32+(Ea<<2)>>2]}else{do{if((Ea|0)!=0){Pa=c[Ma+(Ca*60|0)+32+(Ea-1<<2)>>2]|0;if((Pa|0)<15){break}if((Pa|0)>29){c[Ma+(Ca*60|0)+32+(Ea<<2)>>2]=31;break u}wa=30-Pa|0;Aa=wa>>>0>65535>>>0;za=Aa?wa>>>16:wa;wa=Aa?16:0;if((za&65280|0)==0){Nb=wa;Ob=za}else{Nb=wa|8;Ob=za>>>8}za=(d[1359664+Ob|0]|0)+Nb|0;wa=c[o>>2]|0;Aa=c[q>>2]|0;t=Ja+(wa>>>3)|0;Da=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(wa&7)>>>((31-za|0)>>>0);t=wa+1+za|0;c[o>>2]=Aa>>>0>t>>>0?t:Aa;c[Ma+(Ca*60|0)+32+(Ea<<2)>>2]=Pa+1+Da;break u}}while(0);Da=c[o>>2]|0;Pa=c[q>>2]|0;Aa=Ja+(Da>>>3)|0;t=(je(d[Aa]|d[Aa+1|0]<<8|d[Aa+2|0]<<16|d[Aa+3|0]<<24|0)|0)<<(Da&7)>>>27;Aa=Da+5|0;c[o>>2]=Pa>>>0>Aa>>>0?Aa:Pa;c[Ma+(Ca*60|0)+32+(Ea<<2)>>2]=t}}while(0);Ea=Ea+1|0;}while((Ea|0)<(c[xa>>2]|0))}Ca=Ca+1|0;}while((Ca|0)<(sa|0))}}while(0);na=c[Na>>2]|0;Pb=0;while(1){Ia=c[na+(Pb*60|0)>>2]|0;if((Ia|0)>0){Qb=0;while(1){Rb=c[na+(Pb*60|0)+32+(Qb<<2)>>2]|0;if(Rb>>>0>31>>>0){P=452;break n}if((Qb|0)!=0){if((Rb|0)<=(c[na+(Pb*60|0)+32+(Qb-1<<2)>>2]|0)){P=452;break n}}Ba=Qb+1|0;if((Ba|0)<(Ia|0)){Qb=Ba}else{break}}}Ia=Pb+1|0;if((Ia|0)<(sa|0)){Pb=Ia}else{break}}Ia=g+72+(La*7768|0)+6476|0;if((sa|0)>=(c[Ia>>2]|0)){break}nrc(na+(sa*60|0)|0,na+(Ga*60|0)|0,60)|0;Ba=Ga+2|0;if((Ba|0)<(c[Ia>>2]|0)){Sb=Ba}else{break}do{Ba=c[Na>>2]|0;nrc(Ba+(Sb*60|0)|0,Ba+((Sb-1|0)*60|0)|0,60)|0;Sb=Sb+1|0;}while((Sb|0)<(c[Ia>>2]|0))}}while(0);Na=La+1|0;if((Na|0)<(h|0)){La=Na}else{P=459;break}}if((P|0)==452){KIb(j,16,2288984,(v=i,i=i+32|0,c[v>>2]=La,c[v+8>>2]=Pb,c[v+16>>2]=Qb,c[v+24>>2]=Rb,v)|0);i=v;w=-1094995529;i=k;return w|0}else if((P|0)==459){Ka=m;Na=n;Ja=0;while(1){mrc(c[g+72+(Ja*7768|0)+7760>>2]|0,0,640)|0;Ra=Ja+1|0;if((Ra|0)<(h|0)){Ja=Ra}else{Tb=fb;Ub=Ka;Vb=Na;break}}}else if((P|0)==635){i=k;return w|0}}}while(0);if((P|0)==458){Tb=0;Ub=m;Vb=n}n=c[o>>2]|0;Ub=c[s>>2]|0;fb=d[Ub+(n>>>3)|0]<<(n&7)>>>7;c[o>>2]=((n|0)<(c[q>>2]|0))+n;n=fb&1;fb=g+17272|0;Rb=c[fb>>2]|0;c[Rb>>2]=n;do{if((n|0)==0){Wb=Ub}else{mrc(Rb+64|0,0,768)|0;Qb=c[o>>2]|0;Pb=c[s>>2]|0;Sb=d[Pb+(Qb>>>3)|0]<<(Qb&7)>>>7;c[o>>2]=((Qb|0)<(c[q>>2]|0))+Qb;Qb=Sb&1;Sb=c[fb>>2]|0;c[Sb+4>>2]=Qb;if((Qb|0)==0){RIb(j,2581776,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1163346256;i=k;return w|0}Qb=c[915307]|0;Nb=c[915306]|0;Ob=c[o>>2]|0;Jb=c[q>>2]|0;Mb=Pb+(Ob>>>3)|0;Lb=(je(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(Ob&7)>>>((32-Nb|0)>>>0);Nb=b[Qb+(Lb<<2)>>1]|0;Mb=(b[Qb+(Lb<<2)+2>>1]|0)+Ob|0;c[o>>2]=Jb>>>0>Mb>>>0?Mb:Jb;Jb=Nb+1|0;c[Sb+8>>2]=Jb;do{if(Tb){Nb=Sb+12|0;mrc(Nb|0,0,Jb|0)|0;Mb=c[o>>2]|0;Ob=c[s>>2]|0;Lb=d[Ob+(Mb>>>3)|0]|0;Qb=c[q>>2]|0;Kb=((Mb|0)<(Qb|0))+Mb|0;c[o>>2]=Kb;v:do{if((Lb&128>>>((Mb&7)>>>0)|0)!=0){Hb=d[Ob+(Kb>>>3)|0]|0;Ib=((Kb|0)<(Qb|0))+Kb|0;c[o>>2]=Ib;if((Hb&128>>>((Kb&7)>>>0)|0)==0){mrc(Nb|0,1,Jb|0)|0;break}if((Jb|0)>0){Xb=0;Yb=Ib;Zb=Ob;_b=Qb}else{break}while(1){Ib=d[Zb+(Yb>>>3)|0]<<(Yb&7)>>>7;c[o>>2]=((Yb|0)<(_b|0))+Yb;a[Sb+12+Xb|0]=Ib&1;Ib=Xb+1|0;if((Ib|0)>=(Jb|0)){break v}Xb=Ib;Yb=c[o>>2]|0;Zb=c[s>>2]|0;_b=c[q>>2]|0}}}while(0);Qb=c[fb>>2]|0;Ob=Qb+28|0;Nb=c[Qb+8>>2]|0;mrc(Ob|0,0,Nb|0)|0;Kb=c[o>>2]|0;Mb=c[s>>2]|0;Lb=d[Mb+(Kb>>>3)|0]|0;Ib=c[q>>2]|0;Hb=((Kb|0)<(Ib|0))+Kb|0;c[o>>2]=Hb;w:do{if((Lb&128>>>((Kb&7)>>>0)|0)!=0){Fb=d[Mb+(Hb>>>3)|0]|0;Gb=((Hb|0)<(Ib|0))+Hb|0;c[o>>2]=Gb;if((Fb&128>>>((Hb&7)>>>0)|0)==0){mrc(Ob|0,1,Nb|0)|0;break}if((Nb|0)>0){$b=0;ac=Gb;bc=Mb;cc=Ib}else{break}while(1){Gb=d[bc+(ac>>>3)|0]<<(ac&7)>>>7;c[o>>2]=((ac|0)<(cc|0))+ac;a[Qb+28+$b|0]=Gb&1;Gb=$b+1|0;if((Gb|0)>=(Nb|0)){break w}$b=Gb;ac=c[o>>2]|0;bc=c[s>>2]|0;cc=c[q>>2]|0}}}while(0);Nb=c[fb>>2]|0;Qb=Nb+44|0;Ib=c[Nb+8>>2]|0;mrc(Qb|0,0,Ib|0)|0;Mb=c[o>>2]|0;Ob=c[s>>2]|0;Hb=d[Ob+(Mb>>>3)|0]|0;Kb=c[q>>2]|0;Lb=((Mb|0)<(Kb|0))+Mb|0;c[o>>2]=Lb;if((Hb&128>>>((Mb&7)>>>0)|0)==0){dc=Ob;ec=c[fb>>2]|0;break}Mb=d[Ob+(Lb>>>3)|0]|0;Hb=((Lb|0)<(Kb|0))+Lb|0;c[o>>2]=Hb;x:do{if((Mb&128>>>((Lb&7)>>>0)|0)==0){mrc(Qb|0,1,Ib|0)|0}else{if((Ib|0)>0){fc=0;gc=Hb;hc=Ob;ic=Kb}else{break}while(1){Gb=d[hc+(gc>>>3)|0]<<(gc&7)>>>7;c[o>>2]=((gc|0)<(ic|0))+gc;a[Nb+44+fc|0]=Gb&1;Gb=fc+1|0;if((Gb|0)>=(Ib|0)){break x}fc=Gb;gc=c[o>>2]|0;hc=c[s>>2]|0;ic=c[q>>2]|0}}}while(0);RIb(j,2437840,(v=i,i=i+1|0,i=i+7&-8,c[v>>2]=0,v)|0);i=v;w=-1163346256;i=k;return w|0}else{dc=Pb;ec=Sb}}while(0);Sb=ec+60|0;c[Sb>>2]=0;y:do{if(u){Pb=g+7832|0;Jb=ec+8|0;Ib=ec+4|0;Nb=0;Kb=c[Jb>>2]|0;z:while(1){if((Kb|0)>0){Ob=(Nb|0)==0;Hb=0;do{if(Ob){jc=1}else{jc=(a[ec+12+Hb|0]|0)==0|0}c[m+(Hb<<2)>>2]=jc;Hb=Hb+1|0;}while((Hb|0)<(Kb|0))}Hb=c[g+72+(Nb*7768|0)+7760>>2]|0;Ob=c[Pb>>2]|0;Qb=(Nb|0)==0;do{if(Qb){kc=Kb;P=495}else{Lb=c[o>>2]|0;Mb=d[dc+(Lb>>>3)|0]|0;c[o>>2]=((Lb|0)<(c[q>>2]|0))+Lb;Gb=c[Jb>>2]|0;if((Mb&128>>>((Lb&7)>>>0)|0)==0){kc=Gb;P=495;break}if((Gb|0)>0){lc=0;mc=Gb}else{break}while(1){if((c[m+(lc<<2)>>2]|0)==0){nc=mc}else{c[Hb+(lc*40|0)>>2]=c[Ob+(lc*40|0)>>2];c[Hb+(lc*40|0)+4>>2]=c[Ob+(lc*40|0)+4>>2];c[Hb+(lc*40|0)+8>>2]=c[Ob+(lc*40|0)+8>>2];c[Hb+(lc*40|0)+12>>2]=c[Ob+(lc*40|0)+12>>2];nc=c[Jb>>2]|0}Gb=lc+1|0;if((Gb|0)<(nc|0)){lc=Gb;mc=nc}else{break}}}}while(0);do{if((P|0)==495){P=0;if((kc|0)>0){oc=0;pc=kc}else{break}while(1){if((c[m+(oc<<2)>>2]|0)==0){qc=pc}else{Gb=c[o>>2]|0;Lb=d[dc+(Gb>>>3)|0]<<(Gb&7)>>>7;c[o>>2]=((Gb|0)<(c[q>>2]|0))+Gb;Gb=Lb&1;c[Hb+(oc*40|0)>>2]=Gb;if((Gb|0)==0){rc=-1}else{Gb=c[o>>2]|0;Lb=c[q>>2]|0;Mb=dc+(Gb>>>3)|0;Fb=(je(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(Gb&7)>>>27;Mb=Gb+5|0;c[o>>2]=Lb>>>0>Mb>>>0?Mb:Lb;rc=Fb}c[Hb+(oc*40|0)+8>>2]=rc;Fb=c[o>>2]|0;Lb=d[dc+(Fb>>>3)|0]<<(Fb&7)>>>7;c[o>>2]=((Fb|0)<(c[q>>2]|0))+Fb;Fb=Lb&1;c[Hb+(oc*40|0)+4>>2]=Fb;if((Fb|0)==0){sc=32}else{Fb=c[o>>2]|0;Lb=c[q>>2]|0;Mb=dc+(Fb>>>3)|0;Gb=(je(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(Fb&7)>>>27;Mb=Fb+5|0;c[o>>2]=Lb>>>0>Mb>>>0?Mb:Lb;sc=Gb}c[Hb+(oc*40|0)+12>>2]=sc;qc=c[Jb>>2]|0}Gb=oc+1|0;if((Gb|0)<(qc|0)){oc=Gb;pc=qc}else{break}}}}while(0);Gb=Nb+1|0;Lb=c[o>>2]|0;Mb=c[q>>2]|0;Fb=dc+(Lb>>>3)|0;Db=31-Nb|0;Eb=(je(d[Fb]|d[Fb+1|0]<<8|d[Fb+2|0]<<16|d[Fb+3|0]<<24|0)|0)<<(Lb&7)>>>(Db>>>0);Fb=Lb+Gb|0;c[o>>2]=Mb>>>0>Fb>>>0?Fb:Mb;do{if((Eb|0)==3){Mb=c[Jb>>2]|0;if((Mb|0)>0){tc=0;uc=Mb}else{vc=Mb;wc=Mb;break}while(1){if((c[m+(tc<<2)>>2]|0)==0){xc=uc}else{c[Hb+(tc*40|0)+32>>2]=c[Ob+(tc*40|0)+32>>2];xc=c[Jb>>2]|0}Mb=tc+1|0;if((Mb|0)<(xc|0)){tc=Mb;uc=xc}else{yc=xc;P=512;break}}}else if((Eb|0)==2){Mb=c[Jb>>2]|0;if((Mb|0)>0){zc=0;Ac=Mb}else{vc=Mb;wc=Mb;break}while(1){if((c[m+(zc<<2)>>2]|0)==0){Bc=Ac}else{Mb=c[915317]|0;Fb=c[915316]|0;Lb=c[o>>2]|0;Ab=c[q>>2]|0;Bb=dc+(Lb>>>3)|0;Cb=(je(d[Bb]|d[Bb+1|0]<<8|d[Bb+2|0]<<16|d[Bb+3|0]<<24|0)|0)<<(Lb&7)>>>((32-Fb|0)>>>0);Fb=e[Mb+(Cb<<2)>>1]|0;Bb=(b[Mb+(Cb<<2)+2>>1]|0)+Lb|0;c[o>>2]=Ab>>>0>Bb>>>0?Bb:Ab;c[Hb+(zc*40|0)+32>>2]=(Fb<<29>>29)+(c[Ob+(zc*40|0)+32>>2]|0)&15;Bc=c[Jb>>2]|0}Fb=zc+1|0;if((Fb|0)<(Bc|0)){zc=Fb;Ac=Bc}else{yc=Bc;P=512;break}}}else if((Eb|0)==1){Fb=c[Jb>>2]|0;if((Fb|0)>0){Cc=0;Dc=Fb}else{vc=Fb;wc=Fb;break}while(1){if((c[m+(Cc<<2)>>2]|0)==0){Ec=Dc}else{Fb=c[915312]|0;Ab=c[915311]|0;Bb=c[o>>2]|0;Lb=c[q>>2]|0;Cb=dc+(Bb>>>3)|0;Mb=(je(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0)<<(Bb&7)>>>((32-Ab|0)>>>0);Ab=b[Fb+(Mb<<2)>>1]|0;Cb=(b[Fb+(Mb<<2)+2>>1]|0)+Bb|0;c[o>>2]=Lb>>>0>Cb>>>0?Cb:Lb;c[Hb+(Cc*40|0)+32>>2]=Ab;Ec=c[Jb>>2]|0}Ab=Cc+1|0;if((Ab|0)<(Ec|0)){Cc=Ab;Dc=Ec}else{yc=Ec;P=512;break}}}else if((Eb|0)==0){Ab=c[Jb>>2]|0;if((Ab|0)>0){Fc=0;Gc=Ab}else{vc=Ab;wc=Ab;break}while(1){if((c[m+(Fc<<2)>>2]|0)==0){Hc=Gc}else{Ab=c[o>>2]|0;Lb=c[q>>2]|0;Cb=dc+(Ab>>>3)|0;Bb=(je(d[Cb]|d[Cb+1|0]<<8|d[Cb+2|0]<<16|d[Cb+3|0]<<24|0)|0)<<(Ab&7)>>>28;Cb=Ab+4|0;c[o>>2]=Lb>>>0>Cb>>>0?Cb:Lb;c[Hb+(Fc*40|0)+32>>2]=Bb;Hc=c[Jb>>2]|0}Bb=Fc+1|0;if((Bb|0)<(Hc|0)){Fc=Bb;Gc=Hc}else{yc=Hc;P=512;break}}}else{yc=c[Jb>>2]|0;P=512}}while(0);do{if((P|0)==512){P=0;if((yc|0)>0){Ic=0;Jc=yc;Kc=yc}else{vc=yc;wc=yc;break}while(1){if((c[m+(Ic<<2)>>2]|0)==0){Lc=Jc;Mc=Kc}else{Eb=c[Sb>>2]|0;Bb=c[Hb+(Ic*40|0)+32>>2]|0;Nc=Bb+Eb|0;if((Nc|0)>48){break z}c[Hb+(Ic*40|0)+36>>2]=Eb;c[Sb>>2]=(c[Sb>>2]|0)+Bb;Bb=c[Jb>>2]|0;Lc=Bb;Mc=Bb}Bb=Ic+1|0;if((Bb|0)<(Lc|0)){Ic=Bb;Jc=Lc;Kc=Mc}else{vc=Lc;wc=Mc;break}}}}while(0);do{if(Qb){Oc=vc;Pc=wc;P=533}else{Bb=c[o>>2]|0;Eb=d[dc+(Bb>>>3)|0]|0;c[o>>2]=((Bb|0)<(c[q>>2]|0))+Bb;Lb=c[Jb>>2]|0;if((Eb&128>>>((Bb&7)>>>0)|0)==0){Oc=Lb;Pc=Lb;P=533;break}if((Lb|0)>0){Qc=0;Rc=Lb}else{break}while(1){do{if((c[m+(Qc<<2)>>2]|0)==0){Sc=Rc}else{Lb=Hb+(Qc*40|0)+32|0;Bb=c[Lb>>2]|0;if((Bb|0)==0){Sc=Rc;break}Eb=c[Ob+(Qc*40|0)+36>>2]|0;Cb=c[Hb+(Qc*40|0)+36>>2]|0;if((Bb|0)<=0){Sc=Rc;break}Bb=Ob+(Qc*40|0)+32|0;Ab=Eb-1|0;Mb=c[915337]|0;Fb=0;do{zb=c[915336]|0;xb=c[o>>2]|0;yb=c[q>>2]|0;vb=dc+(xb>>>3)|0;wb=(je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(xb&7)>>>((32-zb|0)>>>0);zb=e[Mb+(wb<<2)>>1]|0;vb=(b[Mb+(wb<<2)+2>>1]|0)+xb|0;c[o>>2]=yb>>>0>vb>>>0?vb:yb;yb=zb<<24>>24;zb=c[Bb>>2]|0;do{if((Fb|0)<(zb|0)){Tc=c[ec+64+(Fb+Eb<<4)>>2]|0}else{if((zb|0)==0){Tc=0;break}Tc=c[ec+64+(Ab+zb<<4)>>2]|0}}while(0);c[ec+64+(Fb+Cb<<4)>>2]=Tc+yb&1023;Fb=Fb+1|0;}while((Fb|0)<(c[Lb>>2]|0));Sc=c[Jb>>2]|0}}while(0);Lb=Qc+1|0;if((Lb|0)<(Sc|0)){Qc=Lb;Rc=Sc}else{Uc=Sc;P=565;break}}}}while(0);do{if((P|0)==533){P=0;if((Oc|0)>0){Vc=0}else{Uc=Pc;P=565;break}while(1){A:do{if((c[m+(Vc<<2)>>2]|0)!=0){Lb=Hb+(Vc*40|0)+32|0;Fb=c[Lb>>2]|0;if((Fb|0)==0){break}Cb=c[Hb+(Vc*40|0)+36>>2]|0;do{if((Fb|0)>1){Ab=c[o>>2]|0;Eb=d[dc+(Ab>>>3)|0]|0;Bb=c[q>>2]|0;Mb=((Ab|0)<(Bb|0))+Ab|0;c[o>>2]=Mb;zb=c[Lb>>2]|0;if((Eb&128>>>((Ab&7)>>>0)|0)==0){Wc=zb;break}if((zb|0)==0){break A}zb=dc+(Mb>>>3)|0;Ab=(je(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)|0)<<(Mb&7)>>>22;zb=Mb+10|0;c[o>>2]=Bb>>>0>zb>>>0?zb:Bb;c[ec+64+(Cb-1+(c[Lb>>2]|0)<<4)>>2]=Ab;Ab=(c[Lb>>2]|0)-2|0;if(!((Ab|0)>-1)){break A}Bb=Cb+1|0;zb=Ab;while(1){Ab=c[ec+64+(Bb+zb<<4)>>2]|0;Mb=Ab>>>0>65535>>>0;Eb=Mb?Ab>>>16:Ab;Ab=Mb?16:0;if((Eb&65280|0)==0){Xc=Ab;Yc=Eb}else{Xc=Ab|8;Yc=Eb>>>8}Eb=(d[1359664+Yc|0]|0)+Xc|0;Ab=c[o>>2]|0;Mb=c[q>>2]|0;vb=dc+(Ab>>>3)|0;xb=(je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(Ab&7)>>>((31-Eb|0)>>>0);vb=Ab+1+Eb|0;c[o>>2]=Mb>>>0>vb>>>0?vb:Mb;c[ec+64+(zb+Cb<<4)>>2]=xb;if((zb|0)>0){zb=zb-1|0}else{break A}}}else{Wc=Fb}}while(0);if((Wc|0)<=0){break}Fb=Cb-1|0;zb=0;do{do{if((zb|0)==0){P=548}else{Bb=c[ec+64+(Fb+zb<<4)>>2]|0;if((Bb|0)<512){P=548;break}yb=1023-Bb|0;Bb=yb>>>0>65535>>>0;xb=Bb?yb>>>16:yb;yb=Bb?16:0;if((xb&65280|0)==0){Zc=yb;_c=xb}else{Zc=yb|8;_c=xb>>>8}xb=(d[1359664+_c|0]|0)+Zc|0;yb=xb+1|0;Bb=c[o>>2]|0;Mb=c[q>>2]|0;vb=dc+(Bb>>>3)|0;Eb=(je(d[vb]|d[vb+1|0]<<8|d[vb+2|0]<<16|d[vb+3|0]<<24|0)|0)<<(Bb&7)>>>((31-xb|0)>>>0);xb=yb+Bb|0;c[o>>2]=Mb>>>0>xb>>>0?xb:Mb;c[ec+64+(zb+Cb<<4)>>2]=(-1<<yb)+1024+Eb}}while(0);if((P|0)==548){P=0;Eb=c[o>>2]|0;yb=c[q>>2]|0;Mb=dc+(Eb>>>3)|0;xb=(je(d[Mb]|d[Mb+1|0]<<8|d[Mb+2|0]<<16|d[Mb+3|0]<<24|0)|0)<<(Eb&7)>>>22;Mb=Eb+10|0;c[o>>2]=yb>>>0>Mb>>>0?Mb:yb;c[ec+64+(zb+Cb<<4)>>2]=xb}zb=zb+1|0;}while((zb|0)<(c[Lb>>2]|0))}}while(0);Lb=Vc+1|0;zb=c[Jb>>2]|0;if((Lb|0)<(zb|0)){Vc=Lb}else{Uc=zb;P=565;break}}}}while(0);do{if((P|0)==565){P=0;if((Uc|0)>0&(Qb^1)){$c=0}else{break}do{do{if((c[m+($c<<2)>>2]|0)!=0){zb=c[Hb+($c*40|0)+32>>2]|0;if((zb|0)==0){break}Lb=c[Hb+($c*40|0)+36>>2]|0;Cb=c[Ob+($c*40|0)+36>>2]|0;if((zb|0)<=0){break}Fb=c[Ob+($c*40|0)+32>>2]|0;xb=(Fb|0)>0;yb=0;do{do{if(xb){Mb=yb+Lb|0;Eb=c[ec+64+(Mb<<4)>>2]|0;Bb=0;vb=1024;Ab=0;do{wb=Eb-(c[ec+64+(Ab+Cb<<4)>>2]|0)|0;ub=(wb|0)>-1?wb:-wb|0;wb=(ub|0)<(vb|0);Bb=wb?Ab:Bb;vb=wb?ub:vb;Ab=Ab+1|0;}while((Ab|0)<(Fb|0));if((vb|0)>=8){P=575;break}c[l+(Mb<<2)>>2]=Bb+Cb}else{P=575}}while(0);do{if((P|0)==575){P=0;if((yb|0)<(Fb|0)){c[l+(yb+Lb<<2)>>2]=yb+Cb;break}else{c[l+(yb+Lb<<2)>>2]=-1;break}}}while(0);yb=yb+1|0;}while((yb|0)<(zb|0))}}while(0);$c=$c+1|0;}while(($c|0)<(Uc|0))}}while(0);Ob=c[o>>2]|0;Qb=c[q>>2]|0;zb=dc+(Ob>>>3)|0;yb=(je(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)|0)<<(Ob&7)>>>(Db>>>0);zb=Ob+Gb|0;c[o>>2]=Qb>>>0>zb>>>0?zb:Qb;do{if((yb|0)==3){Qb=c[Jb>>2]|0;if((Qb|0)>0){ad=0}else{bd=Qb;break}while(1){do{if((c[m+(ad<<2)>>2]|0)!=0){zb=Hb+(ad*40|0)+32|0;if((c[zb>>2]|0)<=0){break}Ob=Hb+(ad*40|0)+36|0;Lb=0;do{Cb=(c[Ob>>2]|0)+Lb|0;Fb=c[l+(Cb<<2)>>2]|0;if((Fb|0)>-1){cd=c[ec+64+(Fb<<4)+4>>2]|0}else{cd=32}c[ec+64+(Cb<<4)+4>>2]=cd;Lb=Lb+1|0;}while((Lb|0)<(c[zb>>2]|0))}}while(0);zb=ad+1|0;if((zb|0)<(Qb|0)){ad=zb}else{dd=Qb;P=617;break}}}else if((yb|0)==2){Qb=c[Jb>>2]|0;if((Qb|0)>0){ed=0;fd=Qb}else{bd=Qb;break}while(1){do{if((c[m+(ed<<2)>>2]|0)==0){gd=fd}else{Qb=Hb+(ed*40|0)+32|0;if((c[Qb>>2]|0)<=0){gd=fd;break}zb=Hb+(ed*40|0)+36|0;Lb=c[915332]|0;Ob=0;do{Cb=c[915331]|0;Fb=c[o>>2]|0;xb=c[q>>2]|0;Ab=dc+(Fb>>>3)|0;Eb=(je(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(Fb&7)>>>((32-Cb|0)>>>0);Cb=e[Lb+(Eb<<2)>>1]|0;Ab=(b[Lb+(Eb<<2)+2>>1]|0)+Fb|0;c[o>>2]=xb>>>0>Ab>>>0?Ab:xb;xb=(c[zb>>2]|0)+Ob|0;Ab=c[l+(xb<<2)>>2]|0;if((Ab|0)>-1){hd=c[ec+64+(Ab<<4)+4>>2]|0}else{hd=34}c[ec+64+(xb<<4)+4>>2]=hd+(Cb<<27>>27)&63;Ob=Ob+1|0;}while((Ob|0)<(c[Qb>>2]|0));gd=c[Jb>>2]|0}}while(0);Qb=ed+1|0;if((Qb|0)<(gd|0)){ed=Qb;fd=gd}else{dd=gd;P=617;break}}}else if((yb|0)==1){Qb=c[Jb>>2]|0;if((Qb|0)>0){id=0}else{bd=Qb;break}while(1){do{if((c[m+(id<<2)>>2]|0)!=0){Qb=Hb+(id*40|0)+32|0;Ob=c[Qb>>2]|0;if((Ob|0)==0){break}if((c[Ib>>2]|0)==0){zb=c[915327]|0;Lb=c[915326]|0;Cb=c[o>>2]|0;xb=c[q>>2]|0;Ab=dc+(Cb>>>3)|0;Fb=(je(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(Cb&7)>>>((32-Lb|0)>>>0);Lb=b[zb+(Fb<<2)>>1]|0;Ab=(b[zb+(Fb<<2)+2>>1]|0)+Cb|0;c[o>>2]=xb>>>0>Ab>>>0?Ab:xb;c[ec+64+(c[Hb+(id*40|0)+36>>2]<<4)+4>>2]=Lb+24;break}if((Ob|0)<=0){break}Ob=Hb+(id*40|0)+36|0;Lb=c[915322]|0;xb=0;do{Ab=c[915321]|0;Cb=c[o>>2]|0;Fb=c[q>>2]|0;zb=dc+(Cb>>>3)|0;Eb=(je(d[zb]|d[zb+1|0]<<8|d[zb+2|0]<<16|d[zb+3|0]<<24|0)|0)<<(Cb&7)>>>((32-Ab|0)>>>0);Ab=b[Lb+(Eb<<2)>>1]|0;zb=(b[Lb+(Eb<<2)+2>>1]|0)+Cb|0;c[o>>2]=Fb>>>0>zb>>>0?zb:Fb;c[ec+64+((c[Ob>>2]|0)+xb<<4)+4>>2]=Ab+20;xb=xb+1|0;}while((xb|0)<(c[Qb>>2]|0))}}while(0);Qb=id+1|0;xb=c[Jb>>2]|0;if((Qb|0)<(xb|0)){id=Qb}else{dd=xb;P=617;break}}}else if((yb|0)==0){xb=c[Jb>>2]|0;if((xb|0)>0){jd=0}else{bd=xb;break}while(1){do{if((c[m+(jd<<2)>>2]|0)!=0){xb=Hb+(jd*40|0)+32|0;Qb=c[xb>>2]|0;if((Qb|0)==0){break}if((c[Ib>>2]|0)==0){Ob=c[o>>2]|0;Lb=c[q>>2]|0;Ab=dc+(Ob>>>3)|0;Fb=(je(d[Ab]|d[Ab+1|0]<<8|d[Ab+2|0]<<16|d[Ab+3|0]<<24|0)|0)<<(Ob&7)>>>26;Ab=Ob+6|0;c[o>>2]=Lb>>>0>Ab>>>0?Ab:Lb;c[ec+64+(c[Hb+(jd*40|0)+36>>2]<<4)+4>>2]=Fb;break}if((Qb|0)<=0){break}Qb=Hb+(jd*40|0)+36|0;Fb=0;do{Lb=c[o>>2]|0;Ab=c[q>>2]|0;Ob=dc+(Lb>>>3)|0;zb=(je(d[Ob]|d[Ob+1|0]<<8|d[Ob+2|0]<<16|d[Ob+3|0]<<24|0)|0)<<(Lb&7)>>>26;Ob=Lb+6|0;c[o>>2]=Ab>>>0>Ob>>>0?Ob:Ab;c[ec+64+((c[Qb>>2]|0)+Fb<<4)+4>>2]=zb;Fb=Fb+1|0;}while((Fb|0)<(c[xb>>2]|0))}}while(0);xb=jd+1|0;Fb=c[Jb>>2]|0;if((xb|0)<(Fb|0)){jd=xb}else{dd=Fb;P=617;break}}}else{dd=c[Jb>>2]|0;P=617}}while(0);do{if((P|0)==617){P=0;if((dd|0)>0){kd=0;ld=dd}else{bd=dd;break}while(1){do{if((c[m+(kd<<2)>>2]|0)==0){md=ld}else{yb=c[Hb+(kd*40|0)+36>>2]|0;Db=Hb+(kd*40|0)+32|0;if((c[Db>>2]|0)>0){nd=0}else{md=ld;break}do{Fb=c[o>>2]|0;xb=c[q>>2]|0;Qb=dc+(Fb>>>3)|0;zb=(je(d[Qb]|d[Qb+1|0]<<8|d[Qb+2|0]<<16|d[Qb+3|0]<<24|0)|0)<<(Fb&7)>>>27;Qb=Fb+5|0;c[o>>2]=xb>>>0>Qb>>>0?Qb:xb;c[ec+64+(nd+yb<<4)+12>>2]=zb;nd=nd+1|0;}while((nd|0)<(c[Db>>2]|0));md=c[Jb>>2]|0}}while(0);Db=kd+1|0;if((Db|0)<(md|0)){kd=Db;ld=md}else{bd=md;break}}}}while(0);if((Gb|0)<(h|0)){Nb=Gb;Kb=bd}else{break y}}Kb=c[j+428>>2]|0;KIb(j,16,2350600,(v=i,i=i+16|0,c[v>>2]=Nc,c[v+8>>2]=Kb,v)|0);i=v;w=-1094995529;i=k;return w|0}}while(0);if(!Tb){Wb=dc;break}if((c[ec+8>>2]|0)<=0){Wb=dc;break}Sb=g+15600|0;Kb=g+7832|0;Nb=0;Jb=ec;while(1){if((a[Jb+12+Nb|0]|0)==0){od=Jb}else{nrc((c[Sb>>2]|0)+(Nb*40|0)|0,(c[Kb>>2]|0)+(Nb*40|0)|0,40)|0;od=c[fb>>2]|0}if((a[od+28+Nb|0]|0)==0){pd=od}else{Ib=(c[Sb>>2]|0)+(Nb*40|0)|0;nrc(Vb|0,Ib|0,40)|0;nrc(Ib|0,(c[Kb>>2]|0)+(Nb*40|0)|0,40)|0;nrc((c[Kb>>2]|0)+(Nb*40|0)|0,Vb|0,40)|0;pd=c[fb>>2]|0}Ib=Nb+1|0;if((Ib|0)<(c[pd+8>>2]|0)){Nb=Ib;Jb=pd}else{break}}Wb=c[s>>2]|0}}while(0);s=c[o>>2]|0;pd=d[Wb+(s>>>3)|0]<<(s&7)>>>7;c[o>>2]=((s|0)<(c[q>>2]|0))+s;s=pd&1;c[g+28>>2]=s;if((s|0)==0){w=0;i=k;return w|0}s=c[o>>2]|0;pd=c[q>>2]|0;fb=Wb+(s>>>3)|0;Vb=(je(d[fb]|d[fb+1|0]<<8|d[fb+2|0]<<16|d[fb+3|0]<<24|0)|0)<<(s&7)>>>28;fb=s+4|0;c[o>>2]=pd>>>0>fb>>>0?fb:pd;c[g+32>>2]=Vb;Vb=c[o>>2]|0;pd=c[q>>2]|0;q=Wb+(Vb>>>3)|0;Wb=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(Vb&7)>>>28;q=Vb+4|0;c[o>>2]=pd>>>0>q>>>0?q:pd;c[g+36>>2]=Wb;w=0;i=k;return w|0}function Dmb(a,b){a=a|0;b=b|0;var d=0;c[b>>2]=a;d=a+116|0;c[b+4>>2]=c[d>>2];c[b+8>>2]=c[d>>2];c[b+16>>2]=0;return}function Emb(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a+16>>2]|0;if((d|0)!=0){KIb(c[a>>2]|0,24,2426784,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e}mJb(a+12|0);mrc(a|0,0,24)|0;i=b;return}function Fmb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+8|0;e=d|0;f=a+12|0;g=a+16|0;h=wJb(c[f>>2]|0,a+20|0,(c[g>>2]<<4)+16|0)|0;j=h;if((h|0)==0){k=-12;i=d;return k|0}c[f>>2]=j;f=c[g>>2]|0;h=j+(f<<4)|0;l=b+76|0;m=c[l>>2]|0;n=j+(f<<4)+8|0;c[n>>2]=m;o=a+4|0;c[n>>2]=(c[o>>2]|0)+m;m=b+136|0;b=c[m>>2]|0;n=c[m+4>>2]|0;do{if((b|0)==0&(n|0)==(-2147483648|0)){m=h|0;c[m>>2]=0;c[m+4>>2]=-2147483648}else{m=a|0;p=c[m>>2]|0;c[e>>2]=1;c[e+4>>2]=c[p+412>>2];q=XIb(b,n,p+104|0,e)|0;p=h|0;r=c[o>>2]|0;s=xrc(q,G,r,(r|0)<0|0?-1:0)|0;r=G;c[p>>2]=s;c[p+4>>2]=r;if((c[g>>2]|0)==0){break}p=j+(f-1<<4)|0;q=c[p+4>>2]|0;if((q|0)<(r|0)|(q|0)==(r|0)&(c[p>>2]|0)>>>0<s>>>0){break}KIb(c[m>>2]|0,24,2581632,(m=i,i=i+1|0,i=i+7&-8,c[m>>2]=0,m)|0);i=m}}while(0);c[o>>2]=0;o=a+8|0;c[o>>2]=(c[o>>2]|0)+(c[l>>2]|0);c[g>>2]=(c[g>>2]|0)+1;k=0;i=d;return k|0}function Gmb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=a+16|0;if((c[j>>2]|0)==0){if((c[a+20>>2]|0)==0){k=-2147483648;l=0}else{m=c[a+12>>2]|0;k=c[m+4>>2]|0;l=c[m>>2]|0}KIb(c[a>>2]|0,24,2437728,(n=i,i=i+8|0,c[n>>2]=b,n)|0);i=n;o=k;p=l}else{l=c[a+12>>2]|0;o=c[l+4>>2]|0;p=c[l>>2]|0}if((d|0)!=0){l=c[a>>2]|0;if((p|0)==0&(o|0)==(-2147483648|0)){q=-2147483648;r=0}else{c[h>>2]=1;c[h+4>>2]=c[l+412>>2];k=XIb(p,o,h,l+104|0)|0;q=G;r=k}c[d>>2]=r;c[d+4>>2]=q}do{if((b|0)==0){s=0;t=0;u=0;v=a+8|0;w=18}else{q=a+12|0;d=0;r=0;k=b;while(1){if(!(r>>>0<(c[j>>2]|0)>>>0)){x=d;y=r;z=k;A=1;break}l=c[q>>2]|0;h=l+(r<<4)+8|0;o=c[h>>2]|0;p=(o|0)>(k|0)?k:o;c[h>>2]=o-p;o=k-p|0;h=p+d|0;m=l+(r<<4)|0;l=c[m>>2]|0;B=c[m+4>>2]|0;if(!((l|0)==0&(B|0)==(-2147483648|0))){C=wrc(p,(p|0)<0|0?-1:0,l,B)|0;c[m>>2]=C;c[m+4>>2]=G}m=r+1|0;if((k|0)==(p|0)){x=h;y=m;z=o;A=0;break}else{d=h;r=m;k=o}}k=a+8|0;c[k>>2]=(c[k>>2]|0)-x;if((y|0)==0){s=A;t=z;u=x;v=k;w=18;break}r=c[a+12>>2]|0;D=(c[r+(y-1<<4)+8>>2]|0)!=0|0;E=r;F=A;H=z;I=y;J=x;K=k}}while(0);if((w|0)==18){D=0;E=c[a+12>>2]|0;F=s;H=t;I=0;J=u;K=v}v=I-D|0;D=a+12|0;orc(E|0,E+(v<<4)|0,(c[j>>2]|0)-v<<4|0)|0;E=c[j>>2]|0;c[j>>2]=E-v;if(F){if((E|0)!=(v|0)){KIb(0,0,2350568,(n=i,i=i+24|0,c[n>>2]=2288960,c[n+8>>2]=2238728,c[n+16>>2]=105,n)|0);i=n;Hd()}if((c[K>>2]|0)!=(c[a+4>>2]|0)){KIb(0,0,2350568,(n=i,i=i+24|0,c[n>>2]=2197912,c[n+8>>2]=2238728,c[n+16>>2]=106,n)|0);i=n;Hd()}K=c[D>>2]|0;do{if((K|0)!=0){D=K|0;v=c[D>>2]|0;E=c[D+4>>2]|0;if((v|0)==0&(E|0)==(-2147483648|0)){break}F=wrc(v,E,H,(H|0)<0|0?-1:0)|0;c[D>>2]=F;c[D+4>>2]=G}}while(0);KIb(c[a>>2]|0,48,2166352,(n=i,i=i+8|0,c[n>>2]=H,n)|0);i=n}if((e|0)==0){i=f;return}n=c[a>>2]|0;c[g>>2]=1;c[g+4>>2]=c[n+412>>2];a=XIb(J,(J|0)<0|0?-1:0,g,n+104|0)|0;c[e>>2]=a;i=f;return}function Hmb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a+16|0;c[a+12>>2]=b;c[a+20>>2]=b+e;e=b+1|0;c[f>>2]=e;g=(d[b]|0)<<18;h=a|0;c[h>>2]=g;i=b+2|0;c[f>>2]=i;j=(d[e]|0)<<10|g;c[h>>2]=j;c[f>>2]=b+3;c[h>>2]=(d[i]|0)<<2|j|2;c[a+4>>2]=510;return}function Imb(){var b=0,c=0,d=0,e=0;if(a[1370864]|0){return}else{b=0}while(1){c=b<<1;d=a[918664+(b<<2)|0]|0;a[(c|1)+1377336|0]=d;a[c+1377336|0]=d;d=a[918665+(b<<2)|0]|0;a[(c+128|1)+1377336|0]=d;a[c+1377464|0]=d;d=a[918666+(b<<2)|0]|0;a[(c+256|1)+1377336|0]=d;a[c+1377592|0]=d;d=a[918667+(b<<2)|0]|0;a[(c+384|1)+1377336|0]=d;a[c+1377720|0]=d;d=a[794232+b|0]<<1;a[c+1377976|0]=d;a[c+1377977|0]=d|1;if((b|0)==0){d=128-c|0;a[d+1377847|0]=1;a[d+1377846|0]=0;b=b+1|0;continue}else{d=a[918600+b|0]<<1;e=128-c|0;a[e+1377847|0]=d;a[e+1377846|0]=d|1;d=b+1|0;if((d|0)<64){b=d;continue}else{break}}}nrc(1378104,1012920,63)|0;a[1370864]=1;return}function Jmb(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;g=e+1684|0;h=c[g>>2]|0;i=h<<4;j=c[e+2140>>2]|0;a[e+2224|0]=a[j+(i|15)|0]|0;k=(h*10|0)+8|0;h=e+2144|0;a[e+2225|0]=a[(c[h>>2]|0)+k|0]|0;l=e+2148|0;a[e+2226|0]=a[(c[l>>2]|0)+k|0]|0;k=e+1704|0;m=e+1972|0;nrc(j+i|0,(c[k>>2]|0)+((c[m>>2]|0)*15|0)|0,16)|0;i=e+1708|0;j=e+1976|0;n=(c[i>>2]|0)+((c[j>>2]|0)*7|0)|0;o=(c[h>>2]|0)+((c[g>>2]|0)*10|0|1)|0;h=n|0;p=n+4|0;n=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;p=o|0;y=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=o+4|0;y=n;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;p=e+1712|0;n=(c[p>>2]|0)+((c[j>>2]|0)*7|0)|0;o=(c[l>>2]|0)+((c[g>>2]|0)*10|0|1)|0;l=n|0;h=n+4|0;n=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=o|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=o+4|0;y=n;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;h=0;while(1){n=h<<1;o=n|1;a[e+2152+o|0]=a[(c[k>>2]|0)+((ca(c[m>>2]|0,n)|0)+15)|0]|0;a[n+2+(e+2152)|0]=a[(c[k>>2]|0)+((ca(c[m>>2]|0,o)|0)+15)|0]|0;o=h+1|0;a[e+2178+o|0]=a[(c[i>>2]|0)+((ca(c[j>>2]|0,h)|0)+7)|0]|0;a[e+2188+o|0]=a[(c[p>>2]|0)+((ca(c[j>>2]|0,h)|0)+7)|0]|0;if((o|0)<8){h=o}else{break}}if((c[e+1668>>2]|0)!=0){q=e+1996|0;r=c[q>>2]|0;s=e+1716|0;c[s>>2]=r;t=r&255;u=c[g>>2]|0;v=e+1720|0;w=c[v>>2]|0;x=w+u|0;a[x]=t;return}do{if((f|0)==0){z=2;A=2;B=2;C=2;D=2;E=2;F=2;G=2}else{h=a[1423896+f|0]|0;do{if(h<<24>>24<0){o=f>>>0>5>>>0;n=b[e+1774>>1]|0;do{if(n<<16>>16==-2){H=2}else{l=b[e+1782>>1]|0;if(l<<16>>16==-2){H=2;break}I=(b[e+1768>>1]|0)-(b[e+1776>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){H=1;break}I=(b[e+1770>>1]|0)-(b[e+1778>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){H=1;break}if(o){I=(b[e+1864>>1]|0)-(b[e+1872>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){H=1;break}I=(b[e+1866>>1]|0)-(b[e+1874>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){H=1;break}}else{if(!(n<<16>>16==l<<16>>16)){H=1;break}}H=0}}while(0);n=b[e+1806>>1]|0;if(n<<16>>16==-2){J=H;K=2;break}l=b[e+1814>>1]|0;if(l<<16>>16==-2){J=H;K=2;break}I=(b[e+1800>>1]|0)-(b[e+1808>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){J=H;K=1;break}I=(b[e+1802>>1]|0)-(b[e+1810>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){J=H;K=1;break}if(o){I=(b[e+1896>>1]|0)-(b[e+1904>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){J=H;K=1;break}I=(b[e+1898>>1]|0)-(b[e+1906>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){J=H;K=1;break}}else{if(!(n<<16>>16==l<<16>>16)){J=H;K=1;break}}J=H;K=0}else{J=0;K=0}}while(0);do{if((h&64)==0){L=0;M=0}else{l=f>>>0>5>>>0;n=b[e+1774>>1]|0;do{if(n<<16>>16==-2){N=2}else{I=b[e+1806>>1]|0;if(I<<16>>16==-2){N=2;break}O=(b[e+1768>>1]|0)-(b[e+1800>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){N=1;break}O=(b[e+1770>>1]|0)-(b[e+1802>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){N=1;break}if(l){O=(b[e+1864>>1]|0)-(b[e+1896>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){N=1;break}O=(b[e+1866>>1]|0)-(b[e+1898>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){N=1;break}}else{if(!(n<<16>>16==I<<16>>16)){N=1;break}}N=0}}while(0);n=b[e+1782>>1]|0;if(n<<16>>16==-2){L=N;M=2;break}o=b[e+1814>>1]|0;if(o<<16>>16==-2){L=N;M=2;break}I=(b[e+1776>>1]|0)-(b[e+1808>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){L=N;M=1;break}I=(b[e+1778>>1]|0)-(b[e+1810>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){L=N;M=1;break}if(l){I=(b[e+1872>>1]|0)-(b[e+1904>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){L=N;M=1;break}I=(b[e+1874>>1]|0)-(b[e+1906>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){L=N;M=1;break}}else{if(!(n<<16>>16==o<<16>>16)){L=N;M=1;break}}L=N;M=0}}while(0);h=e+1768|0;o=f>>>0>5>>>0;n=b[e+1766>>1]|0;do{if(n<<16>>16==-2){P=2}else{I=b[e+1774>>1]|0;if(I<<16>>16==-2){P=2;break}O=(b[e+1760>>1]|0)-(b[h>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){P=1;break}O=(b[e+1762>>1]|0)-(b[e+1770>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){P=1;break}if(o){O=(b[e+1856>>1]|0)-(b[e+1864>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){P=1;break}O=(b[e+1858>>1]|0)-(b[e+1866>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){P=1;break}}else{if(!(n<<16>>16==I<<16>>16)){P=1;break}}P=0}}while(0);n=b[e+1798>>1]|0;do{if(n<<16>>16==-2){Q=2}else{I=b[e+1806>>1]|0;if(I<<16>>16==-2){Q=2;break}O=(b[e+1792>>1]|0)-(b[e+1800>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){Q=1;break}O=(b[e+1794>>1]|0)-(b[e+1802>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){Q=1;break}if(o){O=(b[e+1888>>1]|0)-(b[e+1896>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){Q=1;break}O=(b[e+1890>>1]|0)-(b[e+1898>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){Q=1;break}}else{if(!(n<<16>>16==I<<16>>16)){Q=1;break}}Q=0}}while(0);n=b[e+1742>>1]|0;do{if(n<<16>>16==-2){R=2}else{I=b[e+1774>>1]|0;if(I<<16>>16==-2){R=2;break}O=(b[e+1736>>1]|0)-(b[h>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){R=1;break}O=(b[e+1738>>1]|0)-(b[e+1770>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){R=1;break}if(o){O=(b[e+1832>>1]|0)-(b[e+1864>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){R=1;break}O=(b[e+1834>>1]|0)-(b[e+1866>>1]|0)|0;if((((O|0)>-1?O:-O|0)|0)>3){R=1;break}}else{if(!(n<<16>>16==I<<16>>16)){R=1;break}}R=0}}while(0);n=b[e+1750>>1]|0;if(n<<16>>16==-2){z=P;A=Q;B=J;C=K;D=R;E=2;F=L;G=M;break}h=b[e+1782>>1]|0;if(h<<16>>16==-2){z=P;A=Q;B=J;C=K;D=R;E=2;F=L;G=M;break}I=(b[e+1744>>1]|0)-(b[e+1776>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}I=(b[e+1746>>1]|0)-(b[e+1778>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}if(o){I=(b[e+1840>>1]|0)-(b[e+1872>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}I=(b[e+1842>>1]|0)-(b[e+1874>>1]|0)|0;if((((I|0)>-1?I:-I|0)|0)>3){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}}else{if(!(n<<16>>16==h<<16>>16)){z=P;A=Q;B=J;C=K;D=R;E=1;F=L;G=M;break}}z=P;A=Q;B=J;C=K;D=R;E=0;F=L;G=M}}while(0);M=C&255;L=B&255;R=A&255;if((0<<16|0>>>16|(0<<24|0>>>8)|(0<<8|0>>>24)|(M<<24|0>>>8)|(L<<16|0>>>16)|(R<<8|0>>>24)|z&255|0)==0&((F&255)<<16|0>>>16|((G&255)<<24|0>>>8)|((E&255)<<8|0>>>24)|D&255|(0<<24|M>>>8)|(0<<16|L>>>16)|(0<<8|R>>>24)|0)==0){q=e+1996|0;r=c[q>>2]|0;s=e+1716|0;c[s>>2]=r;t=r&255;u=c[g>>2]|0;v=e+1720|0;w=c[v>>2]|0;x=w+u|0;a[x]=t;return}R=e+1696|0;L=e+1996|0;if((c[R>>2]&1|0)==0){S=e+1672|0}else{M=(c[L>>2]|0)+1+(c[e+1716>>2]|0)>>1;K=e+1672|0;J=M+(c[K>>2]|0)|0;if((J|0)<0){T=0}else{T=(J|0)>63?63:J}J=d[2021104+T|0]|0;Q=(c[e+1676>>2]|0)+M|0;if((Q|0)<0){U=0}else{U=(Q|0)>63?63:Q}Q=d[1954056+U|0]|0;U=d[311784+T|0]|0;T=z&255;z=A&255;Se[c[e+1544>>2]&1023](c[k>>2]|0,c[m>>2]|0,J,Q,U,T,z);A=e+1552|0;Se[c[A>>2]&1023](c[i>>2]|0,c[j>>2]|0,J,Q,U,T,z);Se[c[A>>2]&1023](c[p>>2]|0,c[j>>2]|0,J,Q,U,T,z);S=K}K=c[L>>2]|0;z=(c[S>>2]|0)+K|0;if((z|0)<0){V=0}else{V=(z|0)>63?63:z}z=d[2021104+V|0]|0;T=e+1676|0;U=(c[T>>2]|0)+K|0;if((U|0)<0){W=0}else{W=(U|0)>63?63:U}U=d[1954056+W|0]|0;W=d[311784+V|0]|0;Se[c[e+1544>>2]&1023]((c[k>>2]|0)+8|0,c[m>>2]|0,z,U,W,B&255,C&255);C=e+1548|0;B=c[m>>2]|0;Se[c[C>>2]&1023]((c[k>>2]|0)+(B<<3)|0,B,z,U,W,F&255,G&255);if((c[R>>2]&2|0)==0){q=e+1996|0;r=c[q>>2]|0;s=e+1716|0;c[s>>2]=r;t=r&255;u=c[g>>2]|0;v=e+1720|0;w=c[v>>2]|0;x=w+u|0;a[x]=t;return}R=(c[L>>2]|0)+1+(d[(c[e+1720>>2]|0)+(c[g>>2]|0)|0]|0)>>1;L=R+(c[S>>2]|0)|0;if((L|0)<0){X=0}else{X=(L|0)>63?63:L}L=d[2021104+X|0]|0;S=(c[T>>2]|0)+R|0;if((S|0)<0){Y=0}else{Y=(S|0)>63?63:S}S=d[1954056+Y|0]|0;Y=d[311784+X|0]|0;X=D&255;D=E&255;Se[c[C>>2]&1023](c[k>>2]|0,c[m>>2]|0,L,S,Y,X,D);m=e+1556|0;Se[c[m>>2]&1023](c[i>>2]|0,c[j>>2]|0,L,S,Y,X,D);Se[c[m>>2]&1023](c[p>>2]|0,c[j>>2]|0,L,S,Y,X,D);q=e+1996|0;r=c[q>>2]|0;s=e+1716|0;c[s>>2]=r;t=r&255;u=c[g>>2]|0;v=e+1720|0;w=c[v>>2]|0;x=w+u|0;a[x]=t;return}function Kmb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g|0)==1){h=b+2198|0;c[f>>2]=h;i=c[b+1704>>2]|0;j=a[i+7|0]|0;a[b+2199|0]=j;k=c[b+1972>>2]|0;a[b+2200|0]=a[i+(k+7)|0]|0;a[b+2201|0]=a[i+((k<<1)+7)|0]|0;a[b+2202|0]=a[i+((k*3|0)+7)|0]|0;a[b+2203|0]=a[i+((k<<2)+7)|0]|0;a[b+2204|0]=a[i+((k*5|0)+7)|0]|0;a[b+2205|0]=a[i+((k*6|0)+7)|0]|0;mrc(b+2206|0,a[i+((k*7|0)+7)|0]|0,10)|0;a[h]=j;j=b+1684|0;k=b+2140|0;i=(c[k>>2]|0)+(c[j>>2]<<4|8)|0;l=e+1|0;m=i|0;n=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=i+4|0;i=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;m=l|0;y=n;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=l+4|0;y=i;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;m=b+1696|0;l=e+9|0;o=(i>>>24|0<<8)&255;if((c[m>>2]&4|0)==0){mrc(l|0,o|0,9)|0;p=o}else{o=(c[k>>2]|0)+((c[j>>2]<<4)+16)|0;i=l;l=o|0;q=o+4|0;o=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=i|0;y=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=i+4|0;y=o;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;p=(o>>>24|0<<8)&255}a[e+17|0]=p;a[e]=n;if((c[m>>2]&2|0)==0){return}m=a[(c[k>>2]|0)+(c[j>>2]<<4|7)|0]|0;a[e]=m;a[h]=m;return}else if((g|0)==2){m=b+2160|0;c[f>>2]=m;h=e+1|0;nrc(h|0,(c[b+1704>>2]|0)+((c[b+1972>>2]|0)*7|0)|0,16)|0;a[e+17|0]=a[e+16|0]|0;a[e]=a[h]|0;if((c[b+1696>>2]&1|0)==0){return}a[e]=a[m]|0;return}else if((g|0)==3){c[f>>2]=b+2206;m=c[b+1704>>2]|0;h=c[b+1972>>2]|0;a[b+2207|0]=a[m+(h<<3|7)|0]|0;a[b+2208|0]=a[m+((h*9|0)+7)|0]|0;a[b+2209|0]=a[m+((h*10|0)+7)|0]|0;a[b+2210|0]=a[m+((h*11|0)+7)|0]|0;a[b+2211|0]=a[m+((h*12|0)+7)|0]|0;a[b+2212|0]=a[m+((h*13|0)+7)|0]|0;a[b+2213|0]=a[m+((h*14|0)+7)|0]|0;mrc(b+2214|0,a[m+((h*15|0)+7)|0]|0,10)|0;nrc(e|0,m+((h*7|0)+7)|0,9)|0;mrc(e+9|0,a[e+8|0]|0,9)|0;return}else if((g|0)==0){g=b+2152|0;c[f>>2]=g;a[g]=a[b+2153|0]|0;mrc(b+2169|0,a[b+2168|0]|0,9)|0;f=e+1|0;nrc(f|0,(c[b+2140>>2]|0)+(c[b+1684>>2]<<4)|0,16)|0;a[e+17|0]=a[e+16|0]|0;a[e]=a[f]|0;if((c[b+1696>>2]&3|0)!=3){return}f=a[b+2224|0]|0;a[e]=f;a[g]=f;return}else{return}}function Lmb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b+2178|0;a[b+2187|0]=a[b+2186|0]|0;e=b+2188|0;a[b+2197|0]=a[b+2196|0]|0;f=b+1684|0;g=(c[f>>2]|0)*10|0;h=b+2144|0;i=c[h>>2]|0;a[i+(g+9)|0]=a[i+(g+8)|0]|0;g=(c[f>>2]|0)*10|0;i=b+2148|0;j=c[i>>2]|0;a[j+(g+9)|0]=a[j+(g+8)|0]|0;g=c[f>>2]|0;do{if((g|0)!=0){if((c[b+1688>>2]|0)==0){break}j=a[b+2225|0]|0;a[d|0]=j;a[(c[h>>2]|0)+(g*10|0)|0]=j;j=a[b+2226|0]|0;a[e|0]=j;a[(c[i>>2]|0)+((c[f>>2]|0)*10|0)|0]=j;return}}while(0);a[d|0]=a[b+2179|0]|0;a[e|0]=a[b+2189|0]|0;b=g*10|0;g=c[h>>2]|0;a[g+b|0]=a[g+(b|1)|0]|0;b=(c[f>>2]|0)*10|0;f=c[i>>2]|0;a[f+b|0]=a[f+(b|1)|0]|0;return}function Mmb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b+1952|0;c[b+1944>>2]=c[f>>2];g=b+1964|0;c[b+1956>>2]=c[g>>2];h=b+1960|0;j=b+1684|0;k=c[b+1968>>2]|0;c[k+(c[j>>2]<<1<<2)>>2]=c[h>>2];c[k+((c[j>>2]<<1|1)<<2)>>2]=c[g>>2];g=b+1696|0;do{if((c[g>>2]&1|0)==0){j=b+1948|0;k=c[j>>2]|0;c[j>>2]=a[1012600+k|0]|0;if((26>>>(k>>>0)&1|0)!=0){KIb(0,16,2426584,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[j>>2]=0}j=c[h>>2]|0;c[h>>2]=a[1012600+j|0]|0;if((26>>>(j>>>0)&1|0)!=0){KIb(0,16,2426584,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[h>>2]=0}j=c[d>>2]|0;c[d>>2]=a[1012608+j|0]|0;if(!((j|0)==3|(j|0)==1)){break}KIb(0,16,2426584,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[d>>2]=0}}while(0);if((c[g>>2]&2|0)!=0){i=e;return}g=b+1948|0;b=c[g>>2]|0;c[g>>2]=a[307440+b|0]|0;if((25>>>(b>>>0)&1|0)!=0){KIb(0,16,2426584,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[g>>2]=0}g=c[f>>2]|0;c[f>>2]=a[307440+g|0]|0;if((25>>>(g>>>0)&1|0)!=0){KIb(0,16,2426584,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[f>>2]=0}f=c[d>>2]|0;c[d>>2]=a[307448+f|0]|0;if(!((f-2|0)>>>0<2>>>0)){i=e;return}KIb(0,16,2426584,(l=i,i=i+1|0,i=i+7&-8,c[l>>2]=0,l)|0);i=l;c[d>>2]=0;i=e;return}function Nmb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=d+1704|0;g=c[f>>2]|0;h=d+1708|0;i=c[h>>2]|0;j=d+1712|0;k=c[j>>2]|0;if((a[1423896+e|0]|0)==0){e=d+1288|0;l=c[d+1248>>2]|0;m=c[d+1684>>2]<<3;n=c[d+1688>>2]<<3;o=b[d+1774>>1]|0;if(o<<16>>16>-1){p=c[d+1264>>2]|0;q=c[d+1596+(o<<16>>16<<3)>>2]|0;dnb(d,c[q>>2]|0,c[q+4>>2]|0,c[q+8>>2]|0,8,g,i,k,m,n,e,l,b[d+1768>>1]|0,b[d+1770>>1]|0);r=p;s=d+1416|0}else{r=l;s=e}if(!((b[d+1870>>1]|0)>-1)){return}e=c[d+1596>>2]|0;dnb(d,c[e>>2]|0,c[e+4>>2]|0,c[e+8>>2]|0,8,g,i,k,m,n,s,r,b[d+1864>>1]|0,b[d+1866>>1]|0);return}r=d+1352|0;s=d+1252|0;n=c[s>>2]|0;m=d+1480|0;e=d+1268|0;l=d+1684|0;p=c[l>>2]<<3;q=d+1688|0;o=c[q>>2]<<3;t=b[d+1774>>1]|0;if(t<<16>>16>-1){u=c[e>>2]|0;v=c[d+1596+(t<<16>>16<<3)>>2]|0;dnb(d,c[v>>2]|0,c[v+4>>2]|0,c[v+8>>2]|0,4,g,i,k,p,o,r,n,b[d+1768>>1]|0,b[d+1770>>1]|0);w=u;x=m}else{w=n;x=r}if((b[d+1870>>1]|0)>-1){n=c[d+1596>>2]|0;dnb(d,c[n>>2]|0,c[n+4>>2]|0,c[n+8>>2]|0,4,g,i,k,p,o,x,w,b[d+1864>>1]|0,b[d+1866>>1]|0)}w=c[s>>2]|0;x=(c[f>>2]|0)+8|0;o=(c[h>>2]|0)+4|0;p=(c[j>>2]|0)+4|0;k=c[l>>2]<<3|4;l=c[q>>2]<<3;q=b[d+1782>>1]|0;if(q<<16>>16>-1){i=c[e>>2]|0;g=c[d+1596+(q<<16>>16<<3)>>2]|0;dnb(d,c[g>>2]|0,c[g+4>>2]|0,c[g+8>>2]|0,4,x,o,p,k,l,r,w,b[d+1776>>1]|0,b[d+1778>>1]|0);y=i;z=m}else{y=w;z=r}if((b[d+1878>>1]|0)>-1){w=c[d+1596>>2]|0;dnb(d,c[w>>2]|0,c[w+4>>2]|0,c[w+8>>2]|0,4,x,o,p,k,l,z,y,b[d+1872>>1]|0,b[d+1874>>1]|0)}Omb(d,4,c[f>>2]|0,c[h>>2]|0,c[j>>2]|0,0,4,r,c[s>>2]|0,m,c[e>>2]|0,d+1800|0);Omb(d,4,c[f>>2]|0,c[h>>2]|0,c[j>>2]|0,4,4,r,c[s>>2]|0,m,c[e>>2]|0,d+1808|0);return}function Omb(a,d,e,f,g,h,i,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0;o=e+((ca(c[a+1972>>2]|0,i)|0)+h<<1)|0;e=(ca(c[a+1976>>2]|0,i)|0)+h|0;p=f+e|0;f=g+e|0;e=(c[a+1684>>2]<<3)+h|0;h=(c[a+1688>>2]<<3)+i|0;i=b[n+6>>1]|0;if(i<<16>>16>-1){g=c[a+1596+(i<<16>>16<<3)>>2]|0;dnb(a,c[g>>2]|0,c[g+4>>2]|0,c[g+8>>2]|0,d,o,p,f,e,h,j,k,b[n>>1]|0,b[n+2>>1]|0);q=m;r=l}else{q=k;r=j}if(!((b[n+102>>1]|0)>-1)){return}j=c[a+1596>>2]|0;dnb(a,c[j>>2]|0,c[j+4>>2]|0,c[j+8>>2]|0,d,o,p,f,e,h,r,q,b[n+96>>1]|0,b[n+98>>1]|0);return}function Pmb(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;l=f+1728+(g<<3)|0;m=g-1|0;n=f+1728+(m<<3)|0;o=g-4|0;p=f+1728+(o<<3)|0;q=k&65535;b[f+1728+(g<<3)+6>>1]=q;r=c[f+1612+(q<<16>>16<<2)>>2]&65535;b[f+1728+(g<<3)+4>>1]=r;q=(b[f+1728+(h<<3)+6>>1]|0)==-1?g-5|0:h;h=f+1728+(q<<3)|0;s=b[f+1728+(m<<3)+6>>1]|0;do{if((i|0)==4){if(s<<16>>16==-1){t=284496;u=19;break}v=b[f+1728+(o<<3)+6>>1]|0;if(v<<16>>16==-1){t=284496;u=19;break}if((b[n>>1]|s|b[f+1728+(m<<3)+2>>1])<<16>>16==0){t=284496;u=19;break}if((b[p>>1]|v|b[f+1728+(o<<3)+2>>1])<<16>>16==0){t=284496;u=19}else{u=6}}else{u=6}}while(0);do{if((u|0)==6){v=b[f+1728+(o<<3)+6>>1]|0;do{if(s<<16>>16>-1){if(v<<16>>16<0){if((b[f+1728+(q<<3)+6>>1]|0)<0){w=n;u=18;break}}if(s<<16>>16<0){u=10}else{u=14}}else{u=10}}while(0);do{if((u|0)==10){if(v<<16>>16>-1){if((b[f+1728+(q<<3)+6>>1]|0)<0){w=p;u=18;break}}if(!((s&v)<<16>>16<0)){u=14;break}if((b[f+1728+(q<<3)+6>>1]|0)>-1){w=h;u=18}else{u=14}}}while(0);do{if((u|0)==14){if((i|0)==3){w=(b[f+1728+(q<<3)+6>>1]|0)==(k|0)?h:0;u=18;break}else if((i|0)==2){if((v<<16>>16|0)==(k|0)){w=p;u=18;break}else{break}}else if((i|0)==1){if((s<<16>>16|0)==(k|0)){w=n;u=18;break}else{break}}else{break}}}while(0);if((u|0)==18){if((w|0)!=0){t=w;u=19;break}}x=r<<16>>16;y=c[f+2304+(s<<16>>16<<2)>>2]|0;z=b[n>>1]|0;A=(z>>31)+256+(ca(ca(x,z)|0,y)|0)>>9;z=b[f+1728+(m<<3)+2>>1]|0;B=(z>>31)+256+(ca(ca(x,z)|0,y)|0)>>9;y=c[f+2304+(v<<16>>16<<2)>>2]|0;z=b[p>>1]|0;C=(z>>31)+256+(ca(ca(x,z)|0,y)|0)>>9;z=b[f+1728+(o<<3)+2>>1]|0;D=(z>>31)+256+(ca(ca(x,z)|0,y)|0)>>9;y=c[f+2304+(b[f+1728+(q<<3)+6>>1]<<2)>>2]|0;z=b[h>>1]|0;E=(z>>31)+256+(ca(ca(x,z)|0,y)|0)>>9;z=b[f+1728+(q<<3)+2>>1]|0;F=(z>>31)+256+(ca(ca(x,z)|0,y)|0)>>9;y=A-C|0;z=B-D|0;x=((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)|0;z=C-E|0;y=D-F|0;G=((z|0)>-1?z:-z|0)+((y|0)>-1?y:-y|0)|0;y=E-A|0;z=F-B|0;H=((y|0)>-1?y:-y|0)+((z|0)>-1?z:-z|0)|0;do{if((x|0)>(G|0)){if((H|0)<=(G|0)){I=G;break}I=(H|0)>(x|0)?x:H}else{if((G|0)<=(H|0)){I=G;break}I=(H|0)>(x|0)?H:x}}while(0);if((I|0)==(x|0)){b[l>>1]=E;b[f+1728+(g<<3)+2>>1]=F;break}if((I|0)==(G|0)){b[l>>1]=A;b[f+1728+(g<<3)+2>>1]=B;break}else{b[l>>1]=C;b[f+1728+(g<<3)+2>>1]=D;break}}}while(0);if((u|0)==19){b[l>>1]=b[t>>1]|0;b[f+1728+(g<<3)+2>>1]=b[t+2>>1]|0}if(i>>>0<4>>>0){i=f+1576|0;t=c[i>>2]|0;u=f+1584|0;I=c[u>>2]|0;q=f+1568|0;h=c[q>>2]|0;o=h+(t>>>3)|0;p=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(t&7);if(p>>>0>134217727>>>0){o=p>>>23;m=(d[1382088+o|0]|0)+t|0;c[i>>2]=I>>>0>m>>>0?m:I;J=a[1306768+o|0]|0}else{o=p>>>0>65535>>>0;m=o?p>>>16:p;p=o?16:0;if((m&65280|0)==0){K=p;L=m}else{K=p|8;L=m>>>8}m=(d[1359664+L|0]|0)+K|0;K=31-m+t|0;t=I>>>0>K>>>0?K:I;K=h+(t>>>3)|0;h=(je(d[K]|d[K+1|0]<<8|d[K+2|0]<<16|d[K+3|0]<<24|0)|0)<<(t&7)>>>(m>>>0);K=t+(32-m)|0;c[i>>2]=I>>>0>K>>>0?K:I;I=h>>>1;J=(h&1|0)==0?I:-I|0}I=l|0;b[I>>1]=(e[I>>1]|0)+J;J=c[i>>2]|0;I=c[u>>2]|0;u=c[q>>2]|0;q=u+(J>>>3)|0;h=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(J&7);if(h>>>0>134217727>>>0){q=h>>>23;K=(d[1382088+q|0]|0)+J|0;c[i>>2]=I>>>0>K>>>0?K:I;M=a[1306768+q|0]|0}else{q=h>>>0>65535>>>0;K=q?h>>>16:h;h=q?16:0;if((K&65280|0)==0){N=h;O=K}else{N=h|8;O=K>>>8}K=(d[1359664+O|0]|0)+N|0;N=31-K+J|0;J=I>>>0>N>>>0?N:I;N=u+(J>>>3)|0;u=(je(d[N]|d[N+1|0]<<8|d[N+2|0]<<16|d[N+3|0]<<24|0)|0)<<(J&7)>>>(K>>>0);N=J+(32-K)|0;c[i>>2]=I>>>0>N>>>0?N:I;I=u>>>1;M=(u&1|0)==0?I:-I|0}I=f+1728+(g<<3)+2|0;b[I>>1]=(e[I>>1]|0)+M}if((j|0)==1){M=l;P=c[M+4>>2]|0;Q=c[M>>2]|0}else if((j|0)==0){M=l;I=f+1728+(g+4<<3)|0;u=c[M>>2]|0;N=c[M+4>>2]|0;c[I>>2]=u;c[I+4>>2]=N;I=f+1728+(g+5<<3)|0;c[I>>2]=u;c[I+4>>2]=N;P=N;Q=u}else if((j|0)==2){j=l;l=f+1728+(g+4<<3)|0;u=c[j+4>>2]|0;c[l>>2]=c[j>>2];c[l+4>>2]=u;return}else{return}u=f+1728+(g+1<<3)|0;c[u>>2]=Q;c[u+4>>2]=P;return}function Qmb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[a+1684>>2]|0;d=b<<1;e=c[a+1920>>2]|0;f=e+(d<<3)|0;g=a+1736|0;h=c[f+4>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=h;h=c[a+1924>>2]|0;f=h+(d<<3)|0;i=a+1832|0;j=c[f+4>>2]|0;c[i>>2]=c[f>>2];c[i+4>>2]=j;j=d|1;f=e+(j<<3)|0;k=a+1744|0;l=c[f+4>>2]|0;c[k>>2]=c[f>>2];c[k+4>>2]=l;l=h+(j<<3)|0;j=a+1840|0;f=c[l+4>>2]|0;c[j>>2]=c[l>>2];c[j+4>>2]=f;f=d+2|0;l=e+(f<<3)|0;e=a+1752|0;m=c[l+4>>2]|0;c[e>>2]=c[l>>2];c[e+4>>2]=m;m=h+(f<<3)|0;f=a+1848|0;h=c[m+4>>2]|0;c[f>>2]=c[m>>2];c[f+4>>2]=h;h=c[a+1968>>2]|0;m=a+1936|0;c[m>>2]=c[h+(d<<2)>>2];l=a+1940|0;c[l>>2]=c[h+((d|1)<<2)>>2];d=a+1696|0;h=c[d>>2]|0;do{if((h&2|0)==0){c[g>>2]=0;c[g+4>>2]=-65535;c[k>>2]=0;c[k+4>>2]=-65535;c[i>>2]=0;c[i+4>>2]=-65535;c[j>>2]=0;c[j+4>>2]=-65535;c[l>>2]=-1;c[m>>2]=-1;n=h&-13;c[d>>2]=n;o=b;p=n}else{if((b|0)==0){o=0;p=h;break}n=h|8;c[d>>2]=n;o=b;p=n}}while(0);if((o|0)==((c[a+1636>>2]|0)-1|0)){o=p&-5;c[d>>2]=o;q=o}else{q=p}if((q&4|0)==0){c[e>>2]=0;c[e+4>>2]=-65535;c[f>>2]=0;c[f+4>>2]=-65535}if((q&8|0)!=0){return}q=a+1728|0;c[q>>2]=0;c[q+4>>2]=-65535;q=a+1824|0;c[q>>2]=0;c[q+4>>2]=-65535;return}function Rmb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=a+1696|0;c[b>>2]=c[b>>2]|1;d=a+1704|0;c[d>>2]=(c[d>>2]|0)+16;e=a+1708|0;c[e>>2]=(c[e>>2]|0)+8;f=a+1712|0;c[f>>2]=(c[f>>2]|0)+8;g=a+1744|0;h=a+1728|0;i=c[g+4>>2]|0;c[h>>2]=c[g>>2];c[h+4>>2]=i;i=a+1776|0;g=a+1760|0;j=c[i+4>>2]|0;c[g>>2]=c[i>>2];c[g+4>>2]=j;j=a+1808|0;i=a+1792|0;k=c[j+4>>2]|0;c[i>>2]=c[j>>2];c[i+4>>2]=k;k=a+1840|0;l=a+1824|0;m=c[k+4>>2]|0;c[l>>2]=c[k>>2];c[l+4>>2]=m;m=a+1872|0;k=a+1856|0;n=c[m+4>>2]|0;c[k>>2]=c[m>>2];c[k+4>>2]=n;n=a+1904|0;m=a+1888|0;o=c[n+4>>2]|0;c[m>>2]=c[n>>2];c[m+4>>2]=o;o=a+1684|0;p=a+1920|0;q=a+1800|0;r=(c[p>>2]|0)+(c[o>>2]<<1<<3)|0;s=c[q+4>>2]|0;c[r>>2]=c[q>>2];c[r+4>>2]=s;s=(c[p>>2]|0)+((c[o>>2]<<1|1)<<3)|0;p=c[j+4>>2]|0;c[s>>2]=c[j>>2];c[s+4>>2]=p;p=a+1924|0;s=a+1896|0;j=(c[p>>2]|0)+(c[o>>2]<<1<<3)|0;r=c[s+4>>2]|0;c[j>>2]=c[s>>2];c[j+4>>2]=r;r=(c[p>>2]|0)+((c[o>>2]<<1|1)<<3)|0;p=c[n+4>>2]|0;c[r>>2]=c[n>>2];c[r+4>>2]=p;p=a+1692|0;c[p>>2]=(c[p>>2]|0)+1;p=(c[o>>2]|0)+1|0;c[o>>2]=p;do{if((p|0)==(c[a+1636>>2]|0)){c[b>>2]=6;c[a+1956>>2]=-1;c[a+1944>>2]=-1;c[h>>2]=0;c[h+4>>2]=-65535;c[g>>2]=0;c[g+4>>2]=-65535;c[i>>2]=0;c[i+4>>2]=-65535;c[l>>2]=0;c[l+4>>2]=-65535;c[k>>2]=0;c[k+4>>2]=-65535;c[m>>2]=0;c[m+4>>2]=-65535;c[o>>2]=0;r=a+1688|0;n=(c[r>>2]|0)+1|0;c[r>>2]=n;r=c[a+1588>>2]|0;c[d>>2]=(c[r>>2]|0)+(ca(n<<4,c[a+1972>>2]|0)|0);j=ca(n<<3,c[a+1976>>2]|0)|0;c[e>>2]=(c[r+4>>2]|0)+j;c[f>>2]=(c[r+8>>2]|0)+j;if((n|0)==(c[a+1640>>2]|0)){t=0}else{break}return t|0}}while(0);t=1;return t|0}function Smb(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+1728|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1760|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1792|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1824|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1856|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1888|0;c[b>>2]=0;c[b+4>>2]=-65535;b=a+1864|0;d=1423936;e=c[d>>2]|0;f=c[d+4>>2]|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1896|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1904|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1872|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1768|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1800|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1808|0;c[b>>2]=e;c[b+4>>2]=f;b=a+1776|0;c[b>>2]=e;c[b+4>>2]=f;c[a+1956>>2]=-1;c[a+1944>>2]=-1;f=c[a+1588>>2]|0;c[a+1704>>2]=c[f>>2];c[a+1708>>2]=c[f+4>>2];c[a+1712>>2]=c[f+8>>2];b=c[f+32>>2]|0;c[a+1972>>2]=b;c[a+1976>>2]=c[f+36>>2];f=b<<3;c[a+1988>>2]=f;c[a+1992>>2]=f+8;mrc(a+1684|0,0,16)|0;return 0}function Tmb(a){a=a|0;var b=0,d=0;b=a+1636|0;c[a+1720>>2]=pJb(c[b>>2]|0)|0;c[a+1920>>2]=pJb(c[b>>2]<<4|8)|0;c[a+1924>>2]=pJb(c[b>>2]<<4|8)|0;c[a+1968>>2]=pJb(c[b>>2]<<3)|0;c[a+2140>>2]=pJb((c[b>>2]<<4)+16|0)|0;c[a+2144>>2]=pJb((c[b>>2]|0)*10|0)|0;c[a+2148>>2]=pJb((c[b>>2]|0)*10|0)|0;d=a+1640|0;c[a+1928>>2]=pJb(ca(c[b>>2]<<5,c[d>>2]|0)|0)|0;c[a+2288>>2]=pJb(ca(c[d>>2]|0,c[b>>2]|0)|0)|0;c[a+2320>>2]=pJb(128)|0;return}function Umb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;l8(b+4|0,a);Mia(b+1248|0,8);G8a(b+1280|0,8);enb(b+1288|0,a);d=b+1132|0;M6(d,c[b+1564>>2]|0);L6(d,b+2008|0,1242080);c[b>>2]=a;c[a+140>>2]=0;d=b+1588|0;c[d>>2]=UHb()|0;e=b+1596|0;c[e>>2]=UHb()|0;f=UHb()|0;c[b+1604>>2]=f;do{if((c[d>>2]|0)!=0){if((c[e>>2]|0)==0|(f|0)==0){break}c[b+1980>>2]=0;c[b+1984>>2]=8;c[b+2228>>2]=964;c[b+2232>>2]=492;c[b+2236>>2]=560;c[b+2240>>2]=638;c[b+2244>>2]=158;c[b+2248>>2]=448;c[b+2252>>2]=974;c[b+2256>>2]=522;c[b+2260>>2]=560;c[b+2264>>2]=492;c[b+2268>>2]=964;c[b+2272>>2]=834;c[b+2276>>2]=448;c[b+2280>>2]=974;c[b+2284>>2]=522;g=b+1784|0;c[g>>2]=0;c[g+4>>2]=-65535;g=b+1880|0;c[g>>2]=0;c[g+4>>2]=-65535;h=0;return h|0}}while(0);Vmb(a)|0;h=-12;return h|0}function Vmb(a){a=a|0;var b=0;b=c[a+60>>2]|0;VHb(b+1588|0);VHb(b+1596|0);VHb(b+1604|0);kJb(c[b+1720>>2]|0);kJb(c[b+1920>>2]|0);kJb(c[b+1924>>2]|0);kJb(c[b+1968>>2]|0);kJb(c[b+2140>>2]|0);kJb(c[b+2144>>2]|0);kJb(c[b+2148>>2]|0);kJb(c[b+1928>>2]|0);kJb(c[b+2288>>2]|0);kJb(c[b+2320>>2]|0);mJb(b+2312|0);return 0}function Wmb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;e=b+1|0;b=e|0;g=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=e+4|0;e=d[b]|d[b+1|0]<<8|d[b+2|0]<<16|d[b+3|0]<<24|0;b=a;c[b>>2]=g;c[b+4>>2]=e;b=a+f|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f<<1)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f*3|0)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f<<2)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f*5|0)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f*6|0)|0;c[b>>2]=g;c[b+4>>2]=e;b=a+(f*7|0)|0;c[b>>2]=g;c[b+4>>2]=e;return}function Xmb(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;b=Erc(d[e+1|0]|0,0,16843009,16843009)|0;g=a;c[g>>2]=b;c[g+4>>2]=G;g=Erc(d[e+2|0]|0,0,16843009,16843009)|0;b=a+f|0;c[b>>2]=g;c[b+4>>2]=G;b=Erc(d[e+3|0]|0,0,16843009,16843009)|0;g=a+(f<<1)|0;c[g>>2]=b;c[g+4>>2]=G;g=Erc(d[e+4|0]|0,0,16843009,16843009)|0;b=a+(f*3|0)|0;c[b>>2]=g;c[b+4>>2]=G;b=Erc(d[e+5|0]|0,0,16843009,16843009)|0;g=a+(f<<2)|0;c[g>>2]=b;c[g+4>>2]=G;g=Erc(d[e+6|0]|0,0,16843009,16843009)|0;b=a+(f*5|0)|0;c[b>>2]=g;c[b+4>>2]=G;b=Erc(d[e+7|0]|0,0,16843009,16843009)|0;g=a+(f*6|0)|0;c[g>>2]=b;c[g+4>>2]=G;g=Erc(d[e+8|0]|0,0,16843009,16843009)|0;e=a+(f*7|0)|0;c[e>>2]=g;c[e+4>>2]=G;return}function Ymb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=0;while(1){h=g+1|0;i=e+g|0;j=e+h|0;k=e+(g+2)|0;l=ca(g,f)|0;m=0;while(1){n=m+1|0;a[b+(m+l)|0]=((((d[i]|0)+2+((d[j]|0)<<1)+(d[k]|0)|0)>>>2)+(((d[c+m|0]|0)+2+((d[c+n|0]|0)<<1)+(d[c+(m+2)|0]|0)|0)>>>2)|0)>>>1;if((n|0)<8){m=n}else{break}}if((h|0)<8){g=h}else{break}}return}function Zmb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=0;do{h=ca(g,f)|0;i=0;do{j=i+g|0;k=j+2|0;l=j+1|0;m=j+3|0;a[b+(i+h)|0]=((((d[e+l|0]|0)+2+((d[e+k|0]|0)<<1)+(d[e+m|0]|0)|0)>>>2)+(((d[c+l|0]|0)+2+((d[c+k|0]|0)<<1)+(d[c+m|0]|0)|0)>>>2)|0)>>>1;i=i+1|0;}while((i|0)<8);g=g+1|0;}while((g|0)<8);return}function _mb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e+1|0;h=c+1|0;i=0;do{j=ca(i,f)|0;k=0;do{do{if((k|0)==(i|0)){a[b+(i+j)|0]=((d[g]|0)+2+((d[c]|0)<<1)+(d[h]|0)|0)>>>2}else{if((k|0)>(i|0)){l=k-i|0;a[b+(k+j)|0]=((d[c+(l-1)|0]|0)+2+((d[c+l|0]|0)<<1)+(d[c+(l+1)|0]|0)|0)>>>2;break}else{l=i-k|0;a[b+(k+j)|0]=((d[e+(l-1)|0]|0)+2+((d[e+l|0]|0)<<1)+(d[e+(l+1)|0]|0)|0)>>>2;break}}}while(0);k=k+1|0;}while((k|0)<8);i=i+1|0;}while((i|0)<8);return}function $mb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=0;while(1){g=c+1|0;h=e+c|0;i=e+g|0;j=e+(c+2)|0;k=ca(c,f)|0;a[b+k|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+1)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+2)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+3)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+4)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+5)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+6)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;a[b+(k+7)|0]=((d[h]|0)+2+((d[i]|0)<<1)+(d[j]|0)|0)>>>2;if((g|0)<8){c=g}else{break}}return}function anb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0;e=0;do{g=ca(e,f)|0;h=0;while(1){i=h+1|0;a[b+(h+g)|0]=((d[c+h|0]|0)+2+((d[c+i|0]|0)<<1)+(d[c+(h+2)|0]|0)|0)>>>2;if((i|0)<8){h=i}else{break}}e=e+1|0;}while((e|0)<8);return}function bnb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=a;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+e|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e<<1)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e*3|0)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e<<2)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e*5|0)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e*6|0)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;d=a+(e*7|0)|0;c[d>>2]=-2139062144;c[d+4>>2]=-2139062144;return}function cnb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[c+8|0]|0;h=d[e+8|0]|0;i=(((g-(d[c]|0)<<2)+((((d[c+7|0]|0)-(d[c+1|0]|0)|0)*3|0)+(((d[c+6|0]|0)-(d[c+2|0]|0)<<1)+((d[c+5|0]|0)-(d[c+3|0]|0))))|0)*17|0)+16>>5;c=(((h-(d[e]|0)<<2)+((((d[e+7|0]|0)-(d[e+1|0]|0)|0)*3|0)+(((d[e+6|0]|0)-(d[e+2|0]|0)<<1)+((d[e+5|0]|0)-(d[e+3|0]|0))))|0)*17|0)+16>>5;e=(h+g<<4)+16|0;g=i*-3|0;h=0;do{j=e+(ca(h-3|0,c)|0)|0;k=ca(h,f)|0;a[b+k|0]=a[(j+g>>5)+1404400|0]|0;a[b+(k+1)|0]=a[(j+(i*-2|0)>>5)+1404400|0]|0;a[b+(k+2)|0]=a[(j-i>>5)+1404400|0]|0;a[b+(k+3)|0]=a[(j>>5)+1404400|0]|0;a[b+(k+4)|0]=a[(j+i>>5)+1404400|0]|0;a[b+(k+5)|0]=a[(j+(i<<1)>>5)+1404400|0]|0;a[b+(k+6)|0]=a[(j+(i*3|0)>>5)+1404400|0]|0;a[b+(k+7)|0]=a[(j+(i<<2)>>5)+1404400|0]|0;h=h+1|0;}while((h|0)<8);return}function dnb(a,b,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;p=(n<<16>>16)+(j<<3)|0;j=(o<<16>>16)+(k<<3)|0;k=j<<2&12|p&3;o=p>>2;n=j>>2;q=a+1972|0;r=c[q>>2]|0;s=(ca(r,n)|0)+o|0;t=b+s|0;u=p>>3;v=j>>3;w=a+1976|0;x=(ca(c[w>>2]|0,v)|0)+u|0;y=d+x|0;d=e+x|0;x=c[a+1636>>2]|0;e=x<<4;z=c[a+1640>>2]|0;A=z<<4;if((b|0)==0){return}B=p&7;p=(B|0)==0?0:-3;C=j&7;j=(C|0)==0?0:-3;do{if((o|0)<(-p|0)){D=6}else{if((n|0)<(-j|0)){D=6;break}if((o+16|0)>(e+p|0)){D=6;break}if((n+16|0)>(A+j|0)){D=6;break}ef[c[l+(k<<2)>>2]&4095](g,t,r);_e[m&511](h,y,c[w>>2]|0,f,B,C);E=d}}while(0);if((D|0)==6){D=a+1280|0;t=a+2312|0;Ve[c[D>>2]&127](c[t>>2]|0,b+(s-2-(r<<1))|0,r,r,21,21,o-2|0,n-2|0,e,A);A=c[q>>2]|0;ef[c[l+(k<<2)>>2]&4095](g,(c[t>>2]|0)+((A<<1)+2)|0,A);A=c[w>>2]|0;g=x<<3;x=z<<3;Ve[c[D>>2]&127](c[t>>2]|0,y,A,A,9,9,u,v,g,x);_e[m&511](h,c[t>>2]|0,c[w>>2]|0,f,B,C);h=c[w>>2]|0;Ve[c[D>>2]&127](c[t>>2]|0,d,h,h,9,9,u,v,g,x);E=c[t>>2]|0}_e[m&511](i,E,c[w>>2]|0,f,B,C);return}function enb(a,b){a=a|0;b=b|0;c[a>>2]=962;c[a+4>>2]=852;c[a+8>>2]=1644;c[a+12>>2]=2178;c[a+16>>2]=656;c[a+20>>2]=1784;c[a+24>>2]=700;c[a+28>>2]=1854;c[a+32>>2]=1240;c[a+36>>2]=256;c[a+40>>2]=1208;c[a+44>>2]=362;c[a+48>>2]=1588;c[a+52>>2]=1168;c[a+56>>2]=562;c[a+60>>2]=26;c[a+64>>2]=1828;c[a+68>>2]=2170;c[a+72>>2]=420;c[a+76>>2]=2334;c[a+80>>2]=1140;c[a+84>>2]=30;c[a+88>>2]=130;c[a+92>>2]=1388;c[a+96>>2]=2078;c[a+100>>2]=360;c[a+104>>2]=2264;c[a+108>>2]=816;c[a+112>>2]=1750;c[a+116>>2]=1856;c[a+120>>2]=1930;c[a+124>>2]=2006;c[a+128>>2]=532;c[a+132>>2]=2232;c[a+136>>2]=1690;c[a+140>>2]=1166;c[a+144>>2]=316;c[a+148>>2]=146;c[a+152>>2]=228;c[a+156>>2]=1508;c[a+160>>2]=938;c[a+164>>2]=1956;c[a+168>>2]=1108;c[a+172>>2]=1780;c[a+176>>2]=1876;c[a+180>>2]=1150;c[a+184>>2]=2032;c[a+188>>2]=2116;c[a+192>>2]=1912;c[a+196>>2]=1962;c[a+200>>2]=668;c[a+204>>2]=1210;c[a+208>>2]=444;c[a+212>>2]=1618;c[a+216>>2]=842;c[a+220>>2]=876;c[a+224>>2]=808;c[a+228>>2]=790;c[a+232>>2]=1282;c[a+236>>2]=306;c[a+240>>2]=2300;c[a+244>>2]=2238;c[a+248>>2]=344;c[a+252>>2]=2392;c[a+256>>2]=282;c[a+260>>2]=478;c[a+264>>2]=8;c[a+268>>2]=646;c[a+272>>2]=956;c[a+276>>2]=1;return}function fnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Qob(a,b,c,c);Qob(a+8|0,b+8|0,c,c);d=c<<3;Qob(a+d|0,b+d|0,c,c);e=d+8|0;Qob(a+e|0,b+e|0,c,c);return}function gnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Pob(a,b,c,c);Pob(a+8|0,b+8|0,c,c);d=c<<3;Pob(a+d|0,b+d|0,c,c);e=d+8|0;Pob(a+e|0,b+e|0,c,c);return}function hnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Oob(a,b,c,c);Oob(a+8|0,b+8|0,c,c);d=c<<3;Oob(a+d|0,b+d|0,c,c);e=d+8|0;Oob(a+e|0,b+e|0,c,c);return}function inb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Nob(a,b,c,c);Nob(a+8|0,b+8|0,c,c);d=c<<3;Nob(a+d|0,b+d|0,c,c);e=d+8|0;Nob(a+e|0,b+e|0,c,c);return}function jnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Fob(a,b,b,c,c);d=b+8|0;Fob(a+8|0,d,d,c,c);d=c<<3;e=b+d|0;Fob(a+d|0,e,e,c,c);e=d+8|0;d=b+e|0;Fob(a+e|0,d,d,c,c);return}function knb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Mob(a,b,c,c);Mob(a+8|0,b+8|0,c,c);d=c<<3;Mob(a+d|0,b+d|0,c,c);e=d+8|0;Mob(a+e|0,b+e|0,c,c);return}function lnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Fob(a,b,b+1|0,c,c);Fob(a+8|0,b+8|0,b+9|0,c,c);d=c<<3;Fob(a+d|0,b+d|0,b+(d|1)|0,c,c);e=d+8|0;Fob(a+e|0,b+e|0,b+(d+9)|0,c,c);return}function mnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Lob(a,b,c,c);Lob(a+8|0,b+8|0,c,c);d=c<<3;Lob(a+d|0,b+d|0,c,c);e=d+8|0;Lob(a+e|0,b+e|0,c,c);return}function nnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Kob(a,b,c,c);Kob(a+8|0,b+8|0,c,c);d=c<<3;Kob(a+d|0,b+d|0,c,c);e=d+8|0;Kob(a+e|0,b+e|0,c,c);return}function onb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Job(a,b,c,c);Job(a+8|0,b+8|0,c,c);d=c<<3;Job(a+d|0,b+d|0,c,c);e=d+8|0;Job(a+e|0,b+e|0,c,c);return}function pnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Iob(a,b,c,c);Iob(a+8|0,b+8|0,c,c);d=c<<3;Iob(a+d|0,b+d|0,c,c);e=d+8|0;Iob(a+e|0,b+e|0,c,c);return}function qnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Hob(a,b,c,c);Hob(a+8|0,b+8|0,c,c);d=c<<3;Hob(a+d|0,b+d|0,c,c);e=d+8|0;Hob(a+e|0,b+e|0,c,c);return}function rnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Fob(a,b,b+c|0,c,c);Fob(a+8|0,b+8|0,b+(c+8)|0,c,c);d=c<<3;Fob(a+d|0,b+d|0,b+(d+c)|0,c,c);e=d+8|0;Fob(a+e|0,b+e|0,b+(e+c)|0,c,c);return}function snb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Gob(a,b,c,c);Gob(a+8|0,b+8|0,c,c);d=c<<3;Gob(a+d|0,b+d|0,c,c);e=d+8|0;Gob(a+e|0,b+e|0,c,c);return}function tnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=c+1|0;Fob(a,b,b+d|0,c,c);Fob(a+8|0,b+8|0,b+(c+9)|0,c,c);e=c<<3;Fob(a+e|0,b+e|0,b+(d+e)|0,c,c);f=e+8|0;Fob(a+f|0,b+f|0,b+(f+d)|0,c,c);return}function unb(a,b,c){a=a|0;b=b|0;c=c|0;Qob(a,b,c,c);return}function vnb(a,b,c){a=a|0;b=b|0;c=c|0;Pob(a,b,c,c);return}function wnb(a,b,c){a=a|0;b=b|0;c=c|0;Oob(a,b,c,c);return}function xnb(a,b,c){a=a|0;b=b|0;c=c|0;Nob(a,b,c,c);return}function ynb(a,b,c){a=a|0;b=b|0;c=c|0;Fob(a,b,b,c,c);return}function znb(a,b,c){a=a|0;b=b|0;c=c|0;Mob(a,b,c,c);return}function Anb(a,b,c){a=a|0;b=b|0;c=c|0;Fob(a,b,b+1|0,c,c);return}function Bnb(a,b,c){a=a|0;b=b|0;c=c|0;Lob(a,b,c,c);return}function Cnb(a,b,c){a=a|0;b=b|0;c=c|0;Kob(a,b,c,c);return}function Dnb(a,b,c){a=a|0;b=b|0;c=c|0;Job(a,b,c,c);return}function Enb(a,b,c){a=a|0;b=b|0;c=c|0;Iob(a,b,c,c);return}function Fnb(a,b,c){a=a|0;b=b|0;c=c|0;Hob(a,b,c,c);return}function Gnb(a,b,c){a=a|0;b=b|0;c=c|0;Fob(a,b,b+c|0,c,c);return}function Hnb(a,b,c){a=a|0;b=b|0;c=c|0;Gob(a,b,c,c);return}function Inb(a,b,c){a=a|0;b=b|0;c=c|0;Fob(a,b,b+(c+1)|0,c,c);return}function Jnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Eob(a,b,c,c);Eob(a+8|0,b+8|0,c,c);d=c<<3;Eob(a+d|0,b+d|0,c,c);e=d+8|0;Eob(a+e|0,b+e|0,c,c);return}function Knb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Dob(a,b,c,c);Dob(a+8|0,b+8|0,c,c);d=c<<3;Dob(a+d|0,b+d|0,c,c);e=d+8|0;Dob(a+e|0,b+e|0,c,c);return}function Lnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Cob(a,b,c,c);Cob(a+8|0,b+8|0,c,c);d=c<<3;Cob(a+d|0,b+d|0,c,c);e=d+8|0;Cob(a+e|0,b+e|0,c,c);return}function Mnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Bob(a,b,c,c);Bob(a+8|0,b+8|0,c,c);d=c<<3;Bob(a+d|0,b+d|0,c,c);e=d+8|0;Bob(a+e|0,b+e|0,c,c);return}function Nnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;tob(a,b,b,c,c);d=b+8|0;tob(a+8|0,d,d,c,c);d=c<<3;e=b+d|0;tob(a+d|0,e,e,c,c);e=d+8|0;d=b+e|0;tob(a+e|0,d,d,c,c);return}function Onb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Aob(a,b,c,c);Aob(a+8|0,b+8|0,c,c);d=c<<3;Aob(a+d|0,b+d|0,c,c);e=d+8|0;Aob(a+e|0,b+e|0,c,c);return}function Pnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;tob(a,b,b+1|0,c,c);tob(a+8|0,b+8|0,b+9|0,c,c);d=c<<3;tob(a+d|0,b+d|0,b+(d|1)|0,c,c);e=d+8|0;tob(a+e|0,b+e|0,b+(d+9)|0,c,c);return}function Qnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;zob(a,b,c,c);zob(a+8|0,b+8|0,c,c);d=c<<3;zob(a+d|0,b+d|0,c,c);e=d+8|0;zob(a+e|0,b+e|0,c,c);return}function Rnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;yob(a,b,c,c);yob(a+8|0,b+8|0,c,c);d=c<<3;yob(a+d|0,b+d|0,c,c);e=d+8|0;yob(a+e|0,b+e|0,c,c);return}function Snb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;xob(a,b,c,c);xob(a+8|0,b+8|0,c,c);d=c<<3;xob(a+d|0,b+d|0,c,c);e=d+8|0;xob(a+e|0,b+e|0,c,c);return}function Tnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;wob(a,b,c,c);wob(a+8|0,b+8|0,c,c);d=c<<3;wob(a+d|0,b+d|0,c,c);e=d+8|0;wob(a+e|0,b+e|0,c,c);return}function Unb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;vob(a,b,c,c);vob(a+8|0,b+8|0,c,c);d=c<<3;vob(a+d|0,b+d|0,c,c);e=d+8|0;vob(a+e|0,b+e|0,c,c);return}function Vnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;tob(a,b,b+c|0,c,c);tob(a+8|0,b+8|0,b+(c+8)|0,c,c);d=c<<3;tob(a+d|0,b+d|0,b+(d+c)|0,c,c);e=d+8|0;tob(a+e|0,b+e|0,b+(e+c)|0,c,c);return}function Wnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;uob(a,b,c,c);uob(a+8|0,b+8|0,c,c);d=c<<3;uob(a+d|0,b+d|0,c,c);e=d+8|0;uob(a+e|0,b+e|0,c,c);return}function Xnb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=c+1|0;tob(a,b,b+d|0,c,c);tob(a+8|0,b+8|0,b+(c+9)|0,c,c);e=c<<3;tob(a+e|0,b+e|0,b+(d+e)|0,c,c);f=e+8|0;tob(a+f|0,b+f|0,b+(f+d)|0,c,c);return}function Ynb(a,b,c){a=a|0;b=b|0;c=c|0;Eob(a,b,c,c);return}function Znb(a,b,c){a=a|0;b=b|0;c=c|0;Dob(a,b,c,c);return}function _nb(a,b,c){a=a|0;b=b|0;c=c|0;Cob(a,b,c,c);return}function $nb(a,b,c){a=a|0;b=b|0;c=c|0;Bob(a,b,c,c);return}function aob(a,b,c){a=a|0;b=b|0;c=c|0;tob(a,b,b,c,c);return}function bob(a,b,c){a=a|0;b=b|0;c=c|0;Aob(a,b,c,c);return}function cob(a,b,c){a=a|0;b=b|0;c=c|0;tob(a,b,b+1|0,c,c);return}function dob(a,b,c){a=a|0;b=b|0;c=c|0;zob(a,b,c,c);return}function eob(a,b,c){a=a|0;b=b|0;c=c|0;yob(a,b,c,c);return}function fob(a,b,c){a=a|0;b=b|0;c=c|0;xob(a,b,c,c);return}function gob(a,b,c){a=a|0;b=b|0;c=c|0;wob(a,b,c,c);return}function hob(a,b,c){a=a|0;b=b|0;c=c|0;vob(a,b,c,c);return}function iob(a,b,c){a=a|0;b=b|0;c=c|0;tob(a,b,b+c|0,c,c);return}function job(a,b,c){a=a|0;b=b|0;c=c|0;uob(a,b,c,c);return}function kob(a,b,c){a=a|0;b=b|0;c=c|0;tob(a,b,b+(c+1)|0,c,c);return}function lob(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;if((f|0)==2){h=0;do{rob(a+(ca(h,b)|0)|0,1,c,d);h=h+1|0;}while((h|0)<16);return}else if((f|0)!=0){sob(a,1,c,d,e);sob(a+b|0,1,c,d,e);sob(a+(b<<1)|0,1,c,d,e);sob(a+(b*3|0)|0,1,c,d,e);sob(a+(b<<2)|0,1,c,d,e);sob(a+(b*5|0)|0,1,c,d,e);sob(a+(b*6|0)|0,1,c,d,e);sob(a+(b*7|0)|0,1,c,d,e)}if((g|0)==0){return}sob(a+(b<<3)|0,1,c,d,e);sob(a+(b*9|0)|0,1,c,d,e);sob(a+(b*10|0)|0,1,c,d,e);sob(a+(b*11|0)|0,1,c,d,e);sob(a+(b*12|0)|0,1,c,d,e);sob(a+(b*13|0)|0,1,c,d,e);sob(a+(b*14|0)|0,1,c,d,e);sob(a+(b*15|0)|0,1,c,d,e);return}function mob(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;if((f|0)==2){rob(a,b,c,d);rob(a+1|0,b,c,d);rob(a+2|0,b,c,d);rob(a+3|0,b,c,d);rob(a+4|0,b,c,d);rob(a+5|0,b,c,d);rob(a+6|0,b,c,d);rob(a+7|0,b,c,d);rob(a+8|0,b,c,d);rob(a+9|0,b,c,d);rob(a+10|0,b,c,d);rob(a+11|0,b,c,d);rob(a+12|0,b,c,d);rob(a+13|0,b,c,d);rob(a+14|0,b,c,d);rob(a+15|0,b,c,d);return}else if((f|0)!=0){sob(a,b,c,d,e);sob(a+1|0,b,c,d,e);sob(a+2|0,b,c,d,e);sob(a+3|0,b,c,d,e);sob(a+4|0,b,c,d,e);sob(a+5|0,b,c,d,e);sob(a+6|0,b,c,d,e);sob(a+7|0,b,c,d,e)}if((g|0)==0){return}sob(a+8|0,b,c,d,e);sob(a+9|0,b,c,d,e);sob(a+10|0,b,c,d,e);sob(a+11|0,b,c,d,e);sob(a+12|0,b,c,d,e);sob(a+13|0,b,c,d,e);sob(a+14|0,b,c,d,e);sob(a+15|0,b,c,d,e);return}function nob(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((h|0)==2){qob(b,1,e,f);qob(b+c|0,1,e,f);qob(b+(c<<1)|0,1,e,f);qob(b+(c*3|0)|0,1,e,f);qob(b+(c<<2)|0,1,e,f);qob(b+(c*5|0)|0,1,e,f);qob(b+(c*6|0)|0,1,e,f);qob(b+(c*7|0)|0,1,e,f);return}else if((h|0)!=0){j=3}if((j|0)==3){j=-g|0;h=0;do{k=ca(h,c)|0;l=b+k|0;m=b+(k-1)|0;n=d[m]|0;o=d[l]|0;p=n-o|0;do{if((((p|0)>-1?p:-p|0)|0)<(e|0)){q=d[b+(k-2)|0]|0;r=q-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=d[b+(k+1)|0]|0;s=r-o|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=((o-n|0)*3|0)+4+q-r>>3;if((s|0)<(j|0)){t=j}else{t=(s|0)>(g|0)?g:s}s=t+n|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[m]=u;s=o-t|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[l]=v}}while(0);h=h+1|0;}while((h|0)<4)}if((i|0)==0){return}i=-g|0;h=4;do{v=ca(h,c)|0;t=b+v|0;u=b+(v-1)|0;j=d[u]|0;l=d[t]|0;o=j-l|0;do{if((((o|0)>-1?o:-o|0)|0)<(e|0)){m=d[b+(v-2)|0]|0;n=m-j|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=d[b+(v+1)|0]|0;k=n-l|0;if((((k|0)>-1?k:-k|0)|0)>=(f|0)){break}k=((l-j|0)*3|0)+4+m-n>>3;if((k|0)<(i|0)){w=i}else{w=(k|0)>(g|0)?g:k}k=w+j|0;if(k>>>0>255>>>0){x=-k>>31&255}else{x=k&255}a[u]=x;k=l-w|0;if(k>>>0>255>>>0){y=-k>>31&255}else{y=k&255}a[t]=y}}while(0);h=h+1|0;}while((h|0)<8);return}function oob(b,c,e,f,g,h,i){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((h|0)==2){qob(b,c,e,f);qob(b+1|0,c,e,f);qob(b+2|0,c,e,f);qob(b+3|0,c,e,f);qob(b+4|0,c,e,f);qob(b+5|0,c,e,f);qob(b+6|0,c,e,f);qob(b+7|0,c,e,f);return}else if((h|0)!=0){j=3}if((j|0)==3){j=c*-2|0;h=-g|0;k=0;do{l=b+k|0;m=b+(k-c)|0;n=d[m]|0;o=d[l]|0;p=n-o|0;do{if((((p|0)>-1?p:-p|0)|0)<(e|0)){q=d[b+(k+j)|0]|0;r=q-n|0;if((((r|0)>-1?r:-r|0)|0)>=(f|0)){break}r=d[b+(k+c)|0]|0;s=r-o|0;if((((s|0)>-1?s:-s|0)|0)>=(f|0)){break}s=((o-n|0)*3|0)+4+q-r>>3;if((s|0)<(h|0)){t=h}else{t=(s|0)>(g|0)?g:s}s=t+n|0;if(s>>>0>255>>>0){u=-s>>31&255}else{u=s&255}a[m]=u;s=(d[l]|0)-t|0;if(s>>>0>255>>>0){v=-s>>31&255}else{v=s&255}a[l]=v}}while(0);k=k+1|0;}while((k|0)<4)}if((i|0)==0){return}i=c*-2|0;k=-g|0;v=4;do{t=b+v|0;u=b+(v-c)|0;h=d[u]|0;j=d[t]|0;l=h-j|0;do{if((((l|0)>-1?l:-l|0)|0)<(e|0)){m=d[b+(v+i)|0]|0;n=m-h|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){break}n=d[b+(v+c)|0]|0;o=n-j|0;if((((o|0)>-1?o:-o|0)|0)>=(f|0)){break}o=((j-h|0)*3|0)+4+m-n>>3;if((o|0)<(k|0)){w=k}else{w=(o|0)>(g|0)?g:o}o=w+h|0;if(o>>>0>255>>>0){x=-o>>31&255}else{x=o&255}a[u]=x;o=(d[t]|0)-w|0;if(o>>>0>255>>>0){y=-o>>31&255}else{y=o&255}a[t]=y}}while(0);v=v+1|0;}while((v|0)<8);return}function pob(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=e;b[e>>1]=(b[e>>1]|0)+8;h=0;do{i=g+(h<<4)+2|0;j=b[i>>1]|0;k=g+(h<<4)+14|0;l=b[k>>1]|0;m=(j*3|0)-(l<<1)|0;n=g+(h<<4)+6|0;o=b[n>>1]|0;p=g+(h<<4)+10|0;q=b[p>>1]|0;r=(q<<1)+(o*3|0)|0;s=(q*-3|0)+(o<<1)|0;o=(l*3|0)+(j<<1)|0;j=(o+m+r<<1)+r|0;l=(m-r+s<<1)+m|0;q=(o-s-r<<1)+o|0;r=(m-o-s<<1)-s|0;s=g+(h<<4)+4|0;o=b[s>>1]|0;m=g+(h<<4)+12|0;t=b[m>>1]|0;u=(t*-10|0)+(o<<2)|0;v=(t<<2)+(o*10|0)|0;o=g+(h<<4)|0;t=b[o>>1]|0;w=g+(h<<4)+8|0;x=b[w>>1]|0;y=t-x<<3|4;z=x+t<<3|4;t=z+v|0;x=y+u|0;A=y-u|0;u=z-v|0;b[o>>1]=(t+j|0)>>>3;b[i>>1]=(x+l|0)>>>3;b[s>>1]=(A+q|0)>>>3;b[n>>1]=(u+r|0)>>>3;b[w>>1]=(u-r|0)>>>3;b[p>>1]=(A-q|0)>>>3;b[m>>1]=(x-l|0)>>>3;b[k>>1]=(t-j|0)>>>3;h=h+1|0;}while((h|0)<8);h=f<<1;g=f*3|0;j=f<<2;t=f*5|0;k=f*6|0;l=f*7|0;x=0;do{m=b[e+(x+8<<1)>>1]|0;q=b[e+(x+56<<1)>>1]|0;A=(m*3|0)-(q<<1)|0;p=b[e+(x+24<<1)>>1]|0;r=b[e+(x+40<<1)>>1]|0;u=(r<<1)+(p*3|0)|0;w=(r*-3|0)+(p<<1)|0;p=(q*3|0)+(m<<1)|0;m=(p+A+u<<1)+u|0;q=(A-u+w<<1)+A|0;r=(p-w-u<<1)+p|0;u=(A-p-w<<1)-w|0;w=b[e+(x+16<<1)>>1]|0;p=b[e+(x+48<<1)>>1]|0;A=(p*-10|0)+(w<<2)|0;n=(p<<2)+(w*10|0)|0;w=b[e+(x<<1)>>1]|0;p=b[e+(x+32<<1)>>1]|0;s=w-p<<3;i=p+w<<3;w=i+n|0;p=s+A|0;o=s-A|0;A=i-n|0;n=c+x|0;a[n]=a[1403376+((d[n]|1024)+(w+m>>7))|0]|0;n=c+(x+f)|0;a[n]=a[1403376+((d[n]|1024)+(p+q>>7))|0]|0;n=c+(x+h)|0;a[n]=a[1403376+((o+r>>7)+1024+(d[n]|0))|0]|0;n=c+(x+g)|0;a[n]=a[1403376+((A+u>>7)+1024+(d[n]|0))|0]|0;n=c+(x+j)|0;a[n]=a[1403376+((A-u>>7)+1024+(d[n]|0))|0]|0;n=c+(x+t)|0;a[n]=a[1403376+((o-r>>7)+1024+(d[n]|0))|0]|0;n=c+(x+k)|0;a[n]=a[1403376+((p-q>>7)+1024+(d[n]|0))|0]|0;n=c+(x+l)|0;a[n]=a[1403376+((w-m>>7)+1024+(d[n]|0))|0]|0;x=x+1|0;}while((x|0)<8);return}function qob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b+(-c|0)|0;h=d[g]|0;i=d[b]|0;j=h-i|0;k=(j|0)>-1?j:-j|0;if((k|0)>=(e|0)){return}j=d[b+(c*-2|0)|0]|0;l=j-h|0;if((((l|0)>-1?l:-l|0)|0)>=(f|0)){return}l=b+c|0;m=(d[l]|0)-i|0;if((((m|0)>-1?m:-m|0)|0)>=(f|0)){return}m=h+2+i|0;n=(e>>2)+2|0;e=(d[b+(c*-3|0)|0]|0)-h|0;a[g]=(((((e|0)>-1?e:-e|0)|0)<(f|0)&(k|0)<(n|0)?j+h|0:j<<1)+m|0)>>>2;j=(d[b+(c<<1)|0]|0)-i|0;do{if((((j|0)>-1?j:-j|0)|0)<(f|0)){c=i-h|0;if((((c|0)>-1?c:-c|0)|0)>=(n|0)){break}a[b]=(m+i+(d[l]|0)|0)>>>2;return}}while(0);a[b]=(((d[l]|0)<<1)+m|0)>>>2;return}function rob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=b+(-c|0)|0;h=d[g]|0;i=d[b]|0;j=h-i|0;k=(j|0)>-1?j:-j|0;if((k|0)>=(e|0)){return}j=b+(c*-2|0)|0;l=d[j]|0;m=l-h|0;if((((m|0)>-1?m:-m|0)|0)>=(f|0)){return}m=b+c|0;n=(d[m]|0)-i|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){return}n=h+2+i|0;o=(e>>2)+2|0;e=(d[b+(c*-3|0)|0]|0)-h|0;if((((e|0)>-1?e:-e|0)|0)<(f|0)&(k|0)<(o|0)){a[g]=(n+h+l|0)>>>2;a[j]=(((d[j]|0)<<1)+n|0)>>>2}else{a[g]=((l<<1)+n|0)>>>2}l=(d[b+(c<<1)|0]|0)-i|0;do{if((((l|0)>-1?l:-l|0)|0)<(f|0)){c=i-h|0;if((((c|0)>-1?c:-c|0)|0)>=(o|0)){break}a[b]=(n+i+(d[m]|0)|0)>>>2;a[m]=(((d[m]|0)<<1)+n|0)>>>2;return}}while(0);a[b]=(((d[m]|0)<<1)+n|0)>>>2;return}function sob(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=b+(-c|0)|0;i=d[h]|0;j=d[b]|0;k=i-j|0;if((((k|0)>-1?k:-k|0)|0)>=(e|0)){return}e=b+(c*-2|0)|0;k=d[e]|0;l=k-i|0;if((((l|0)>-1?l:-l|0)|0)>=(f|0)){return}l=b+c|0;m=d[l]|0;n=m-j|0;if((((n|0)>-1?n:-n|0)|0)>=(f|0)){return}n=((j-i|0)*3|0)+4+k-m>>3;m=-g|0;if((n|0)<(m|0)){o=m}else{o=(n|0)>(g|0)?g:n}n=o+i|0;if(n>>>0>255>>>0){p=-n>>31&255}else{p=n&255}a[h]=p;p=j-o|0;if(p>>>0>255>>>0){q=-p>>31&255}else{q=p&255}a[b]=q;p=d[b+(c*-3|0)|0]|0;o=p-i|0;if((((o|0)>-1?o:-o|0)|0)<(f|0)){o=d[e]|0;i=p+4+(((d[h]|0)-o|0)*3|0)-(q&255)>>3;if((i|0)<(m|0)){r=m}else{r=(i|0)>(g|0)?g:i}i=r+o|0;if(i>>>0>255>>>0){s=-i>>31&255}else{s=i&255}a[e]=s}s=d[b+(c<<1)|0]|0;c=s-j|0;if((((c|0)>-1?c:-c|0)|0)>=(f|0)){return}f=d[l]|0;c=(d[h]|0)+4+((f-(d[b]|0)|0)*3|0)-s>>3;if((c|0)<(m|0)){t=m}else{t=(c|0)>(g|0)?g:c}c=f-t|0;if(c>>>0>255>>>0){u=-c>>31&255}else{u=c&255}a[l]=u;return}function tob(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=i;i=i+208|0;k=j|0;l=h<<1;m=0;n=k|0;o=e+(-l|0)|0;while(1){e=d[o]|0;p=d[o+1|0]|0;q=d[o+2|0]|0;b[n>>1]=((p+e&65535)*5&65535)-(q+(d[o-1|0]|0)&65535);r=d[o+3|0]|0;b[n+2>>1]=((q+p&65535)*5&65535)-(r+e&65535);e=d[o+4|0]|0;b[n+4>>1]=((r+q&65535)*5&65535)-(e+p&65535);p=d[o+5|0]|0;b[n+6>>1]=((e+r&65535)*5&65535)-(p+q&65535);q=d[o+6|0]|0;b[n+8>>1]=((p+e&65535)*5&65535)-(q+r&65535);r=d[o+7|0]|0;b[n+10>>1]=((q+p&65535)*5&65535)-(r+e&65535);e=d[o+8|0]|0;b[n+12>>1]=((r+q&65535)*5&65535)-(e+p&65535);b[n+14>>1]=((e+r&65535)*5&65535)-((d[o+9|0]|0)+q&65535);q=m+1|0;if((q|0)<13){m=q;n=n+16|0;o=o+h|0}else{break}}o=g<<1;n=g*3|0;m=h*3|0;q=g<<2;r=h<<2;e=g*5|0;p=h*5|0;s=g*6|0;t=h*6|0;u=g*7|0;v=h*7|0;w=0;x=k+32|0;k=f;f=c;while(1){c=b[x>>1]|0;y=b[x+16>>1]|0;z=b[x+32>>1]|0;A=b[x+48>>1]|0;B=b[x+64>>1]|0;C=b[x+80>>1]|0;D=b[x+96>>1]|0;E=b[x+112>>1]|0;F=b[x+128>>1]|0;G=b[x+144>>1]|0;H=y*5|0;a[f]=((d[f]|0)+1+(d[(64-(b[x-16>>1]|0)+(c*5|0)+H-z+(d[k]<<6)>>7)+1404400|0]|0)|0)>>>1;I=f+g|0;J=z*5|0;a[I]=((d[I]|0)+1+(d[(64-c+H+J-A+(d[k+h|0]<<6)>>7)+1404400|0]|0)|0)>>>1;H=f+o|0;c=A*5|0;a[H]=((d[H]|0)+1+(d[(64-y+J+c-B+(d[k+l|0]<<6)>>7)+1404400|0]|0)|0)>>>1;J=f+n|0;y=B*5|0;a[J]=((d[J]|0)+1+(d[(64-z+c+y-C+(d[k+m|0]<<6)>>7)+1404400|0]|0)|0)>>>1;c=f+q|0;z=C*5|0;a[c]=((d[c]|0)+1+(d[(64-A+y+z-D+(d[k+r|0]<<6)>>7)+1404400|0]|0)|0)>>>1;y=f+e|0;A=D*5|0;a[y]=((d[y]|0)+1+(d[(64-B+z+A-E+(d[k+p|0]<<6)>>7)+1404400|0]|0)|0)>>>1;z=f+s|0;B=E*5|0;a[z]=((d[z]|0)+1+(d[(64-C+A+B-F+(d[k+t|0]<<6)>>7)+1404400|0]|0)|0)>>>1;A=f+u|0;a[A]=((d[A]|0)+1+(d[(64-D+B+(F*5|0)-G+(d[k+v|0]<<6)>>7)+1404400|0]|0)|0)>>>1;G=w+1|0;if((G|0)<8){w=G;x=x+2|0;k=k+1|0;f=f+1|0}else{break}}i=j;return}function uob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n>>1]|0;q=b[n+16>>1]|0;r=b[n+32>>1]|0;s=b[n+48>>1]|0;t=b[n+64>>1]|0;u=b[n+80>>1]|0;v=b[n+96>>1]|0;w=b[n+112>>1]|0;x=b[n+128>>1]|0;y=b[n+144>>1]|0;z=b[n+160>>1]|0;a[j]=((d[j]|0)+1+(d[(((b[n-16>>1]|0)*-7|0)+512+(c*42|0)+(q*96|0)+(r*-2|0)-s>>10)+1404400|0]|0)|0)>>>1;A=j+f|0;a[A]=((d[A]|0)+1+(d[((c*-7|0)+512+(q*42|0)+(r*96|0)+(s*-2|0)-t>>10)+1404400|0]|0)|0)>>>1;c=j+g|0;a[c]=((d[c]|0)+1+(d[((q*-7|0)+512+(r*42|0)+(s*96|0)+(t*-2|0)-u>>10)+1404400|0]|0)|0)>>>1;q=j+m|0;a[q]=((d[q]|0)+1+(d[((r*-7|0)+512+(s*42|0)+(t*96|0)+(u*-2|0)-v>>10)+1404400|0]|0)|0)>>>1;r=j+l|0;a[r]=((d[r]|0)+1+(d[((s*-7|0)+512+(t*42|0)+(u*96|0)+(v*-2|0)-w>>10)+1404400|0]|0)|0)>>>1;s=j+k|0;a[s]=((d[s]|0)+1+(d[((t*-7|0)+512+(u*42|0)+(v*96|0)+(w*-2|0)-x>>10)+1404400|0]|0)|0)>>>1;t=j+o|0;a[t]=((d[t]|0)+1+(d[((u*-7|0)+512+(v*42|0)+(w*96|0)+(x*-2|0)-y>>10)+1404400|0]|0)|0)>>>1;u=j+p|0;a[u]=((d[u]|0)+1+(d[((v*-7|0)+512+(w*42|0)+(x*96|0)+(y*-2|0)-z>>10)+1404400|0]|0)|0)>>>1;z=e+1|0;if((z|0)<8){e=z;n=n+2|0;j=j+1|0}else{break}}i=h;return}function vob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=f*10|0;q=e<<1;r=e*3|0;s=e<<2;t=e*5|0;u=e*6|0;v=e*7|0;w=0;x=c;c=b;while(1){b=d[x]|0;y=d[x+f|0]|0;z=d[x+h|0]|0;A=d[x+i|0]|0;B=d[x+j|0]|0;C=d[x+k|0]|0;D=d[x+l|0]|0;E=d[x+m|0]|0;F=d[x+n|0]|0;G=d[x+o|0]|0;H=d[x+p|0]|0;a[c]=((d[c]|0)+1+(d[(((d[x+g|0]|0)*-7|0)+64+(b*42|0)+(y*96|0)+(z*-2|0)-A>>7)+1404400|0]|0)|0)>>>1;I=c+e|0;a[I]=((d[I]|0)+1+(d[((b*-7|0)+64+(y*42|0)+(z*96|0)+(A*-2|0)-B>>7)+1404400|0]|0)|0)>>>1;b=c+q|0;a[b]=((d[b]|0)+1+(d[((y*-7|0)+64+(z*42|0)+(A*96|0)+(B*-2|0)-C>>7)+1404400|0]|0)|0)>>>1;y=c+r|0;a[y]=((d[y]|0)+1+(d[((z*-7|0)+64+(A*42|0)+(B*96|0)+(C*-2|0)-D>>7)+1404400|0]|0)|0)>>>1;z=c+s|0;a[z]=((d[z]|0)+1+(d[((A*-7|0)+64+(B*42|0)+(C*96|0)+(D*-2|0)-E>>7)+1404400|0]|0)|0)>>>1;A=c+t|0;a[A]=((d[A]|0)+1+(d[((B*-7|0)+64+(C*42|0)+(D*96|0)+(E*-2|0)-F>>7)+1404400|0]|0)|0)>>>1;B=c+u|0;a[B]=((d[B]|0)+1+(d[((C*-7|0)+64+(D*42|0)+(E*96|0)+(F*-2|0)-G>>7)+1404400|0]|0)|0)>>>1;C=c+v|0;a[C]=((d[C]|0)+1+(d[((D*-7|0)+64+(E*42|0)+(F*96|0)+(G*-2|0)-H>>7)+1404400|0]|0)|0)>>>1;H=w+1|0;if((H|0)<8){w=H;x=x+1|0;c=c+1|0}else{break}}return}function wob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;p=d[m+3|0]|0;b[l>>1]=((((e*42&65535)+((d[m-1|0]|0)*-7&65535)&65535)+(n*96&65535)&65535)+(o*-2&65535)&65535)-p;q=d[m+4|0]|0;b[l+2>>1]=((((n*42&65535)+(e*-7&65535)&65535)+(o*96&65535)&65535)+(p*-2&65535)&65535)-q;e=d[m+5|0]|0;b[l+4>>1]=((((o*42&65535)+(n*-7&65535)&65535)+(p*96&65535)&65535)+(q*-2&65535)&65535)-e;n=d[m+6|0]|0;b[l+6>>1]=((((p*42&65535)+(o*-7&65535)&65535)+(q*96&65535)&65535)+(e*-2&65535)&65535)-n;o=d[m+7|0]|0;b[l+8>>1]=((((q*42&65535)+(p*-7&65535)&65535)+(e*96&65535)&65535)+(n*-2&65535)&65535)-o;p=d[m+8|0]|0;b[l+10>>1]=((((e*42&65535)+(q*-7&65535)&65535)+(n*96&65535)&65535)+(o*-2&65535)&65535)-p;q=d[m+9|0]|0;b[l+12>>1]=((((n*42&65535)+(e*-7&65535)&65535)+(o*96&65535)&65535)+(p*-2&65535)&65535)-q;b[l+14>>1]=((((o*42&65535)+(n*-7&65535)&65535)+(p*96&65535)&65535)+(q*-2&65535)&65535)-(d[m+10|0]|0);q=k+1|0;if((q|0)<13){k=q;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;q=f*6|0;p=f*7|0;n=0;o=j+32|0;j=c;while(1){c=b[o>>1]|0;e=b[o+16>>1]|0;r=b[o+32>>1]|0;s=b[o+48>>1]|0;t=b[o+64>>1]|0;u=b[o+80>>1]|0;v=b[o+96>>1]|0;w=b[o+112>>1]|0;x=b[o+128>>1]|0;y=b[o+144>>1]|0;z=e*5|0;a[j]=((d[j]|0)+1+(d[(512-(b[o-16>>1]|0)+(c*5|0)+z-r>>10)+1404400|0]|0)|0)>>>1;A=j+f|0;B=r*5|0;a[A]=((d[A]|0)+1+(d[(512-c+z+B-s>>10)+1404400|0]|0)|0)>>>1;z=j+g|0;c=s*5|0;a[z]=((d[z]|0)+1+(d[(512-e+B+c-t>>10)+1404400|0]|0)|0)>>>1;B=j+m|0;e=t*5|0;a[B]=((d[B]|0)+1+(d[(512-r+c+e-u>>10)+1404400|0]|0)|0)>>>1;c=j+l|0;r=u*5|0;a[c]=((d[c]|0)+1+(d[(512-s+e+r-v>>10)+1404400|0]|0)|0)>>>1;e=j+k|0;s=v*5|0;a[e]=((d[e]|0)+1+(d[(512-t+r+s-w>>10)+1404400|0]|0)|0)>>>1;r=j+q|0;t=w*5|0;a[r]=((d[r]|0)+1+(d[(512-u+s+t-x>>10)+1404400|0]|0)|0)>>>1;s=j+p|0;a[s]=((d[s]|0)+1+(d[(512-v+t+(x*5|0)-y>>10)+1404400|0]|0)|0)>>>1;y=n+1|0;if((y|0)<8){n=y;o=o+2|0;j=j+1|0}else{break}}i=h;return}function xob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n>>1]|0;q=b[n+16>>1]|0;r=b[n+32>>1]|0;s=b[n+48>>1]|0;t=b[n+64>>1]|0;u=b[n+80>>1]|0;v=b[n+96>>1]|0;w=b[n+112>>1]|0;x=b[n+128>>1]|0;y=b[n+144>>1]|0;z=q*5|0;a[j]=((d[j]|0)+1+(d[(32-(b[n-16>>1]|0)+(c*5|0)+z-r>>6)+1404400|0]|0)|0)>>>1;A=j+f|0;B=r*5|0;a[A]=((d[A]|0)+1+(d[(32-c+z+B-s>>6)+1404400|0]|0)|0)>>>1;z=j+g|0;c=s*5|0;a[z]=((d[z]|0)+1+(d[(32-q+B+c-t>>6)+1404400|0]|0)|0)>>>1;B=j+m|0;q=t*5|0;a[B]=((d[B]|0)+1+(d[(32-r+c+q-u>>6)+1404400|0]|0)|0)>>>1;c=j+l|0;r=u*5|0;a[c]=((d[c]|0)+1+(d[(32-s+q+r-v>>6)+1404400|0]|0)|0)>>>1;q=j+k|0;s=v*5|0;a[q]=((d[q]|0)+1+(d[(32-t+r+s-w>>6)+1404400|0]|0)|0)>>>1;r=j+o|0;t=w*5|0;a[r]=((d[r]|0)+1+(d[(32-u+s+t-x>>6)+1404400|0]|0)|0)>>>1;s=j+p|0;a[s]=((d[s]|0)+1+(d[(32-v+t+(x*5|0)-y>>6)+1404400|0]|0)|0)>>>1;y=e+1|0;if((y|0)<8){e=y;n=n+2|0;j=j+1|0}else{break}}i=h;return}function yob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m-1|0]|0;n=d[m]|0;o=d[m+1|0]|0;p=d[m+2|0]|0;b[l>>1]=((((e*-2&65535)-(d[m-2|0]|0)&65535)+(n*96&65535)&65535)+(o*42&65535)&65535)+(p*-7&65535);q=d[m+3|0]|0;b[l+2>>1]=((((n*-2&65535)-e&65535)+(o*96&65535)&65535)+(p*42&65535)&65535)+(q*-7&65535);e=d[m+4|0]|0;b[l+4>>1]=((((o*-2&65535)-n&65535)+(p*96&65535)&65535)+(q*42&65535)&65535)+(e*-7&65535);n=d[m+5|0]|0;b[l+6>>1]=((((p*-2&65535)-o&65535)+(q*96&65535)&65535)+(e*42&65535)&65535)+(n*-7&65535);o=d[m+6|0]|0;b[l+8>>1]=((((q*-2&65535)-p&65535)+(e*96&65535)&65535)+(n*42&65535)&65535)+(o*-7&65535);p=d[m+7|0]|0;b[l+10>>1]=((((e*-2&65535)-q&65535)+(n*96&65535)&65535)+(o*42&65535)&65535)+(p*-7&65535);q=d[m+8|0]|0;b[l+12>>1]=((((n*-2&65535)-e&65535)+(o*96&65535)&65535)+(p*42&65535)&65535)+(q*-7&65535);b[l+14>>1]=((((o*-2&65535)-n&65535)+(p*96&65535)&65535)+(q*42&65535)&65535)+((d[m+9|0]|0)*-7&65535);q=k+1|0;if((q|0)<13){k=q;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;q=f*6|0;p=f*7|0;n=0;o=j+32|0;j=c;while(1){c=b[o>>1]|0;e=b[o+16>>1]|0;r=b[o+32>>1]|0;s=b[o+48>>1]|0;t=b[o+64>>1]|0;u=b[o+80>>1]|0;v=b[o+96>>1]|0;w=b[o+112>>1]|0;x=b[o+128>>1]|0;y=b[o+144>>1]|0;z=e*5|0;a[j]=((d[j]|0)+1+(d[(512-(b[o-16>>1]|0)+(c*5|0)+z-r>>10)+1404400|0]|0)|0)>>>1;A=j+f|0;B=r*5|0;a[A]=((d[A]|0)+1+(d[(512-c+z+B-s>>10)+1404400|0]|0)|0)>>>1;z=j+g|0;c=s*5|0;a[z]=((d[z]|0)+1+(d[(512-e+B+c-t>>10)+1404400|0]|0)|0)>>>1;B=j+m|0;e=t*5|0;a[B]=((d[B]|0)+1+(d[(512-r+c+e-u>>10)+1404400|0]|0)|0)>>>1;c=j+l|0;r=u*5|0;a[c]=((d[c]|0)+1+(d[(512-s+e+r-v>>10)+1404400|0]|0)|0)>>>1;e=j+k|0;s=v*5|0;a[e]=((d[e]|0)+1+(d[(512-t+r+s-w>>10)+1404400|0]|0)|0)>>>1;r=j+q|0;t=w*5|0;a[r]=((d[r]|0)+1+(d[(512-u+s+t-x>>10)+1404400|0]|0)|0)>>>1;s=j+p|0;a[s]=((d[s]|0)+1+(d[(512-v+t+(x*5|0)-y>>10)+1404400|0]|0)|0)>>>1;y=n+1|0;if((y|0)<8){n=y;o=o+2|0;j=j+1|0}else{break}}i=h;return}function zob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=e<<1;q=e*3|0;r=e<<2;s=e*5|0;t=e*6|0;u=e*7|0;v=0;w=c;c=b;while(1){b=d[w]|0;x=d[w+f|0]|0;y=d[w+h|0]|0;z=d[w+i|0]|0;A=d[w+j|0]|0;B=d[w+k|0]|0;C=d[w+l|0]|0;D=d[w+m|0]|0;E=d[w+n|0]|0;F=d[w+o|0]|0;G=x*5|0;a[c]=((d[c]|0)+1+(d[(4-(d[w+g|0]|0)+(b*5|0)+G-y>>3)+1404400|0]|0)|0)>>>1;H=c+e|0;I=y*5|0;a[H]=((d[H]|0)+1+(d[(4-b+G+I-z>>3)+1404400|0]|0)|0)>>>1;G=c+p|0;b=z*5|0;a[G]=((d[G]|0)+1+(d[(4-x+I+b-A>>3)+1404400|0]|0)|0)>>>1;I=c+q|0;x=A*5|0;a[I]=((d[I]|0)+1+(d[(4-y+b+x-B>>3)+1404400|0]|0)|0)>>>1;b=c+r|0;y=B*5|0;a[b]=((d[b]|0)+1+(d[(4-z+x+y-C>>3)+1404400|0]|0)|0)>>>1;x=c+s|0;z=C*5|0;a[x]=((d[x]|0)+1+(d[(4-A+y+z-D>>3)+1404400|0]|0)|0)>>>1;y=c+t|0;A=D*5|0;a[y]=((d[y]|0)+1+(d[(4-B+z+A-E>>3)+1404400|0]|0)|0)>>>1;z=c+u|0;a[z]=((d[z]|0)+1+(d[(4-C+A+(E*5|0)-F>>3)+1404400|0]|0)|0)>>>1;F=v+1|0;if((F|0)<8){v=F;w=w+1|0;c=c+1|0}else{break}}return}function Aob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n-16>>1]|0;q=b[n>>1]|0;r=b[n+16>>1]|0;s=b[n+32>>1]|0;t=b[n+48>>1]|0;u=b[n+64>>1]|0;v=b[n+80>>1]|0;w=b[n+96>>1]|0;x=b[n+112>>1]|0;y=b[n+128>>1]|0;z=b[n+144>>1]|0;a[j]=((d[j]|0)+1+(d[(512-(b[n-32>>1]|0)+(c*-2|0)+(q*96|0)+(r*42|0)+(s*-7|0)>>10)+1404400|0]|0)|0)>>>1;A=j+f|0;a[A]=((d[A]|0)+1+(d[(512-c+(q*-2|0)+(r*96|0)+(s*42|0)+(t*-7|0)>>10)+1404400|0]|0)|0)>>>1;c=j+g|0;a[c]=((d[c]|0)+1+(d[(512-q+(r*-2|0)+(s*96|0)+(t*42|0)+(u*-7|0)>>10)+1404400|0]|0)|0)>>>1;q=j+m|0;a[q]=((d[q]|0)+1+(d[(512-r+(s*-2|0)+(t*96|0)+(u*42|0)+(v*-7|0)>>10)+1404400|0]|0)|0)>>>1;r=j+l|0;a[r]=((d[r]|0)+1+(d[(512-s+(t*-2|0)+(u*96|0)+(v*42|0)+(w*-7|0)>>10)+1404400|0]|0)|0)>>>1;s=j+k|0;a[s]=((d[s]|0)+1+(d[(512-t+(u*-2|0)+(v*96|0)+(w*42|0)+(x*-7|0)>>10)+1404400|0]|0)|0)>>>1;t=j+o|0;a[t]=((d[t]|0)+1+(d[(512-u+(v*-2|0)+(w*96|0)+(x*42|0)+(y*-7|0)>>10)+1404400|0]|0)|0)>>>1;u=j+p|0;a[u]=((d[u]|0)+1+(d[(512-v+(w*-2|0)+(x*96|0)+(y*42|0)+(z*-7|0)>>10)+1404400|0]|0)|0)>>>1;z=e+1|0;if((z|0)<8){e=z;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Bob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=f*-2|0;h=-f|0;i=f<<1;j=f*3|0;k=f<<2;l=f*5|0;m=f*6|0;n=f*7|0;o=f<<3;p=f*9|0;q=e<<1;r=e*3|0;s=e<<2;t=e*5|0;u=e*6|0;v=e*7|0;w=0;x=c;c=b;while(1){b=d[x+h|0]|0;y=d[x]|0;z=d[x+f|0]|0;A=d[x+i|0]|0;B=d[x+j|0]|0;C=d[x+k|0]|0;D=d[x+l|0]|0;E=d[x+m|0]|0;F=d[x+n|0]|0;G=d[x+o|0]|0;H=d[x+p|0]|0;a[c]=((d[c]|0)+1+(d[(64-(d[x+g|0]|0)+(b*-2|0)+(y*96|0)+(z*42|0)+(A*-7|0)>>7)+1404400|0]|0)|0)>>>1;I=c+e|0;a[I]=((d[I]|0)+1+(d[(64-b+(y*-2|0)+(z*96|0)+(A*42|0)+(B*-7|0)>>7)+1404400|0]|0)|0)>>>1;b=c+q|0;a[b]=((d[b]|0)+1+(d[(64-y+(z*-2|0)+(A*96|0)+(B*42|0)+(C*-7|0)>>7)+1404400|0]|0)|0)>>>1;y=c+r|0;a[y]=((d[y]|0)+1+(d[(64-z+(A*-2|0)+(B*96|0)+(C*42|0)+(D*-7|0)>>7)+1404400|0]|0)|0)>>>1;z=c+s|0;a[z]=((d[z]|0)+1+(d[(64-A+(B*-2|0)+(C*96|0)+(D*42|0)+(E*-7|0)>>7)+1404400|0]|0)|0)>>>1;A=c+t|0;a[A]=((d[A]|0)+1+(d[(64-B+(C*-2|0)+(D*96|0)+(E*42|0)+(F*-7|0)>>7)+1404400|0]|0)|0)>>>1;B=c+u|0;a[B]=((d[B]|0)+1+(d[(64-C+(D*-2|0)+(E*96|0)+(F*42|0)+(G*-7|0)>>7)+1404400|0]|0)|0)>>>1;C=c+v|0;a[C]=((d[C]|0)+1+(d[(64-D+(E*-2|0)+(F*96|0)+(G*42|0)+(H*-7|0)>>7)+1404400|0]|0)|0)>>>1;H=w+1|0;if((H|0)<8){w=H;x=x+1|0;c=c+1|0}else{break}}return}function Cob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;c=b;b=0;while(1){h=g+1|0;i=g+2|0;j=g+3|0;a[c]=((d[c]|0)+1+(d[(((d[g-1|0]|0)*-7|0)+64+((d[g]|0)*42|0)+((d[h]|0)*96|0)+((d[i]|0)*-2|0)-(d[j]|0)>>7)+1404400|0]|0)|0)>>>1;k=c+1|0;l=g+4|0;a[k]=((d[k]|0)+1+(d[(((d[g]|0)*-7|0)+64+((d[h]|0)*42|0)+((d[i]|0)*96|0)+((d[j]|0)*-2|0)-(d[l]|0)>>7)+1404400|0]|0)|0)>>>1;k=c+2|0;m=g+5|0;a[k]=((d[k]|0)+1+(d[(((d[h]|0)*-7|0)+64+((d[i]|0)*42|0)+((d[j]|0)*96|0)+((d[l]|0)*-2|0)-(d[m]|0)>>7)+1404400|0]|0)|0)>>>1;h=c+3|0;k=g+6|0;a[h]=((d[h]|0)+1+(d[(((d[i]|0)*-7|0)+64+((d[j]|0)*42|0)+((d[l]|0)*96|0)+((d[m]|0)*-2|0)-(d[k]|0)>>7)+1404400|0]|0)|0)>>>1;i=c+4|0;h=g+7|0;a[i]=((d[i]|0)+1+(d[(((d[j]|0)*-7|0)+64+((d[l]|0)*42|0)+((d[m]|0)*96|0)+((d[k]|0)*-2|0)-(d[h]|0)>>7)+1404400|0]|0)|0)>>>1;j=c+5|0;i=g+8|0;a[j]=((d[j]|0)+1+(d[(((d[l]|0)*-7|0)+64+((d[m]|0)*42|0)+((d[k]|0)*96|0)+((d[h]|0)*-2|0)-(d[i]|0)>>7)+1404400|0]|0)|0)>>>1;l=c+6|0;j=g+9|0;a[l]=((d[l]|0)+1+(d[(((d[m]|0)*-7|0)+64+((d[k]|0)*42|0)+((d[h]|0)*96|0)+((d[i]|0)*-2|0)-(d[j]|0)>>7)+1404400|0]|0)|0)>>>1;m=c+7|0;a[m]=((d[m]|0)+1+(d[(((d[k]|0)*-7|0)+64+((d[h]|0)*42|0)+((d[i]|0)*96|0)+((d[j]|0)*-2|0)-(d[g+10|0]|0)>>7)+1404400|0]|0)|0)>>>1;j=b+1|0;if((j|0)<8){g=g+f|0;c=c+e|0;b=j}else{break}}return}function Dob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;c=b;b=0;while(1){h=g+1|0;i=g+2|0;j=g+3|0;a[c]=((d[c]|0)+1+(d[(4-(d[g-1|0]|0)-(d[i]|0)+(((d[h]|0)+(d[g]|0)|0)*5|0)>>3)+1404400|0]|0)|0)>>>1;k=c+1|0;l=g+4|0;a[k]=((d[k]|0)+1+(d[(4-(d[g]|0)-(d[j]|0)+(((d[i]|0)+(d[h]|0)|0)*5|0)>>3)+1404400|0]|0)|0)>>>1;k=c+2|0;m=g+5|0;a[k]=((d[k]|0)+1+(d[(4-(d[h]|0)-(d[l]|0)+(((d[j]|0)+(d[i]|0)|0)*5|0)>>3)+1404400|0]|0)|0)>>>1;h=c+3|0;k=g+6|0;a[h]=((d[h]|0)+1+(d[(4-(d[i]|0)-(d[m]|0)+(((d[l]|0)+(d[j]|0)|0)*5|0)>>3)+1404400|0]|0)|0)>>>1;i=c+4|0;h=g+7|0;a[i]=((d[i]|0)+1+(d[(4-(d[j]|0)-(d[k]|0)+(((d[m]|0)+(d[l]|0)|0)*5|0)>>3)+1404400|0]|0)|0)>>>1;j=c+5|0;i=g+8|0;a[j]=((d[j]|0)+1+(d[(4-(d[l]|0)-(d[h]|0)+(((d[k]|0)+(d[m]|0)|0)*5|0)>>3)+1404400|0]|0)|0)>>>1;l=c+6|0;a[l]=((d[l]|0)+1+(d[(4-(d[m]|0)-(d[i]|0)+(((d[h]|0)+(d[k]|0)|0)*5|0)>>3)+1404400|0]|0)|0)>>>1;m=c+7|0;a[m]=((d[m]|0)+1+(d[(4-(d[k]|0)-(d[g+9|0]|0)+(((d[i]|0)+(d[h]|0)|0)*5|0)>>3)+1404400|0]|0)|0)>>>1;h=b+1|0;if((h|0)<8){g=g+f|0;c=c+e|0;b=h}else{break}}return}function Eob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c;c=b;b=0;while(1){h=g-1|0;i=g+1|0;j=g+2|0;k=g+3|0;a[c]=((d[c]|0)+1+(d[(64-(d[g-2|0]|0)+((d[h]|0)*-2|0)+((d[g]|0)*96|0)+((d[i]|0)*42|0)+((d[j]|0)*-7|0)>>7)+1404400|0]|0)|0)>>>1;l=c+1|0;m=g+4|0;a[l]=((d[l]|0)+1+(d[(64-(d[h]|0)+((d[g]|0)*-2|0)+((d[i]|0)*96|0)+((d[j]|0)*42|0)+((d[k]|0)*-7|0)>>7)+1404400|0]|0)|0)>>>1;h=c+2|0;l=g+5|0;a[h]=((d[h]|0)+1+(d[(64-(d[g]|0)+((d[i]|0)*-2|0)+((d[j]|0)*96|0)+((d[k]|0)*42|0)+((d[m]|0)*-7|0)>>7)+1404400|0]|0)|0)>>>1;h=c+3|0;n=g+6|0;a[h]=((d[h]|0)+1+(d[(64-(d[i]|0)+((d[j]|0)*-2|0)+((d[k]|0)*96|0)+((d[m]|0)*42|0)+((d[l]|0)*-7|0)>>7)+1404400|0]|0)|0)>>>1;i=c+4|0;h=g+7|0;a[i]=((d[i]|0)+1+(d[(64-(d[j]|0)+((d[k]|0)*-2|0)+((d[m]|0)*96|0)+((d[l]|0)*42|0)+((d[n]|0)*-7|0)>>7)+1404400|0]|0)|0)>>>1;j=c+5|0;i=g+8|0;a[j]=((d[j]|0)+1+(d[(64-(d[k]|0)+((d[m]|0)*-2|0)+((d[l]|0)*96|0)+((d[n]|0)*42|0)+((d[h]|0)*-7|0)>>7)+1404400|0]|0)|0)>>>1;k=c+6|0;a[k]=((d[k]|0)+1+(d[(64-(d[m]|0)+((d[l]|0)*-2|0)+((d[n]|0)*96|0)+((d[h]|0)*42|0)+((d[i]|0)*-7|0)>>7)+1404400|0]|0)|0)>>>1;m=c+7|0;a[m]=((d[m]|0)+1+(d[(64-(d[l]|0)+((d[n]|0)*-2|0)+((d[h]|0)*96|0)+((d[i]|0)*42|0)+((d[g+9|0]|0)*-7|0)>>7)+1404400|0]|0)|0)>>>1;i=b+1|0;if((i|0)<8){g=g+f|0;c=c+e|0;b=i}else{break}}return}function Fob(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;j=i;i=i+208|0;k=j|0;l=h<<1;m=0;n=k|0;o=e+(-l|0)|0;while(1){e=d[o]|0;p=d[o+1|0]|0;q=d[o+2|0]|0;b[n>>1]=((p+e&65535)*5&65535)-(q+(d[o-1|0]|0)&65535);r=d[o+3|0]|0;b[n+2>>1]=((q+p&65535)*5&65535)-(r+e&65535);e=d[o+4|0]|0;b[n+4>>1]=((r+q&65535)*5&65535)-(e+p&65535);p=d[o+5|0]|0;b[n+6>>1]=((e+r&65535)*5&65535)-(p+q&65535);q=d[o+6|0]|0;b[n+8>>1]=((p+e&65535)*5&65535)-(q+r&65535);r=d[o+7|0]|0;b[n+10>>1]=((q+p&65535)*5&65535)-(r+e&65535);e=d[o+8|0]|0;b[n+12>>1]=((r+q&65535)*5&65535)-(e+p&65535);b[n+14>>1]=((e+r&65535)*5&65535)-((d[o+9|0]|0)+q&65535);q=m+1|0;if((q|0)<13){m=q;n=n+16|0;o=o+h|0}else{break}}o=g<<1;n=h*3|0;m=g*3|0;q=h<<2;r=g<<2;e=h*5|0;p=g*5|0;s=h*6|0;t=g*6|0;u=h*7|0;v=g*7|0;w=0;x=k+32|0;k=f;f=c;while(1){c=b[x>>1]|0;y=b[x+16>>1]|0;z=b[x+32>>1]|0;A=b[x+48>>1]|0;B=b[x+64>>1]|0;C=b[x+80>>1]|0;D=b[x+96>>1]|0;E=b[x+112>>1]|0;F=b[x+128>>1]|0;G=b[x+144>>1]|0;H=y*5|0;a[f]=a[(64-(b[x-16>>1]|0)+(c*5|0)+H-z+(d[k]<<6)>>7)+1404400|0]|0;I=z*5|0;a[f+g|0]=a[(64-c+H+I-A+(d[k+h|0]<<6)>>7)+1404400|0]|0;H=A*5|0;a[f+o|0]=a[(64-y+I+H-B+(d[k+l|0]<<6)>>7)+1404400|0]|0;I=B*5|0;a[f+m|0]=a[(64-z+H+I-C+(d[k+n|0]<<6)>>7)+1404400|0]|0;H=C*5|0;a[f+r|0]=a[(64-A+I+H-D+(d[k+q|0]<<6)>>7)+1404400|0]|0;I=D*5|0;a[f+p|0]=a[(64-B+H+I-E+(d[k+e|0]<<6)>>7)+1404400|0]|0;H=E*5|0;a[f+t|0]=a[(64-C+I+H-F+(d[k+s|0]<<6)>>7)+1404400|0]|0;a[f+v|0]=a[(64-D+H+(F*5|0)-G+(d[k+u|0]<<6)>>7)+1404400|0]|0;G=w+1|0;if((G|0)<8){w=G;x=x+2|0;k=k+1|0;f=f+1|0}else{break}}i=j;return}function Gob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n>>1]|0;q=b[n+16>>1]|0;r=b[n+32>>1]|0;s=b[n+48>>1]|0;t=b[n+64>>1]|0;u=b[n+80>>1]|0;v=b[n+96>>1]|0;w=b[n+112>>1]|0;x=b[n+128>>1]|0;y=b[n+144>>1]|0;z=b[n+160>>1]|0;a[j]=a[(((b[n-16>>1]|0)*-7|0)+512+(c*42|0)+(q*96|0)+(r*-2|0)-s>>10)+1404400|0]|0;a[j+f|0]=a[((c*-7|0)+512+(q*42|0)+(r*96|0)+(s*-2|0)-t>>10)+1404400|0]|0;a[j+g|0]=a[((q*-7|0)+512+(r*42|0)+(s*96|0)+(t*-2|0)-u>>10)+1404400|0]|0;a[j+m|0]=a[((r*-7|0)+512+(s*42|0)+(t*96|0)+(u*-2|0)-v>>10)+1404400|0]|0;a[j+l|0]=a[((s*-7|0)+512+(t*42|0)+(u*96|0)+(v*-2|0)-w>>10)+1404400|0]|0;a[j+k|0]=a[((t*-7|0)+512+(u*42|0)+(v*96|0)+(w*-2|0)-x>>10)+1404400|0]|0;a[j+o|0]=a[((u*-7|0)+512+(v*42|0)+(w*96|0)+(x*-2|0)-y>>10)+1404400|0]|0;a[j+p|0]=a[((v*-7|0)+512+(w*42|0)+(x*96|0)+(y*-2|0)-z>>10)+1404400|0]|0;z=e+1|0;if((z|0)<8){e=z;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Hob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=f*10|0;q=e<<1;r=e*3|0;s=e<<2;t=e*5|0;u=e*6|0;v=e*7|0;w=0;x=c;c=b;while(1){b=d[x]|0;y=d[x+f|0]|0;z=d[x+h|0]|0;A=d[x+i|0]|0;B=d[x+j|0]|0;C=d[x+k|0]|0;D=d[x+l|0]|0;E=d[x+m|0]|0;F=d[x+n|0]|0;G=d[x+o|0]|0;H=d[x+p|0]|0;a[c]=a[(((d[x+g|0]|0)*-7|0)+64+(b*42|0)+(y*96|0)+(z*-2|0)-A>>7)+1404400|0]|0;a[c+e|0]=a[((b*-7|0)+64+(y*42|0)+(z*96|0)+(A*-2|0)-B>>7)+1404400|0]|0;a[c+q|0]=a[((y*-7|0)+64+(z*42|0)+(A*96|0)+(B*-2|0)-C>>7)+1404400|0]|0;a[c+r|0]=a[((z*-7|0)+64+(A*42|0)+(B*96|0)+(C*-2|0)-D>>7)+1404400|0]|0;a[c+s|0]=a[((A*-7|0)+64+(B*42|0)+(C*96|0)+(D*-2|0)-E>>7)+1404400|0]|0;a[c+t|0]=a[((B*-7|0)+64+(C*42|0)+(D*96|0)+(E*-2|0)-F>>7)+1404400|0]|0;a[c+u|0]=a[((C*-7|0)+64+(D*42|0)+(E*96|0)+(F*-2|0)-G>>7)+1404400|0]|0;a[c+v|0]=a[((D*-7|0)+64+(E*42|0)+(F*96|0)+(G*-2|0)-H>>7)+1404400|0]|0;H=w+1|0;if((H|0)<8){w=H;x=x+1|0;c=c+1|0}else{break}}return}function Iob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;p=d[m+3|0]|0;b[l>>1]=((((e*42&65535)+((d[m-1|0]|0)*-7&65535)&65535)+(n*96&65535)&65535)+(o*-2&65535)&65535)-p;q=d[m+4|0]|0;b[l+2>>1]=((((n*42&65535)+(e*-7&65535)&65535)+(o*96&65535)&65535)+(p*-2&65535)&65535)-q;e=d[m+5|0]|0;b[l+4>>1]=((((o*42&65535)+(n*-7&65535)&65535)+(p*96&65535)&65535)+(q*-2&65535)&65535)-e;n=d[m+6|0]|0;b[l+6>>1]=((((p*42&65535)+(o*-7&65535)&65535)+(q*96&65535)&65535)+(e*-2&65535)&65535)-n;o=d[m+7|0]|0;b[l+8>>1]=((((q*42&65535)+(p*-7&65535)&65535)+(e*96&65535)&65535)+(n*-2&65535)&65535)-o;p=d[m+8|0]|0;b[l+10>>1]=((((e*42&65535)+(q*-7&65535)&65535)+(n*96&65535)&65535)+(o*-2&65535)&65535)-p;q=d[m+9|0]|0;b[l+12>>1]=((((n*42&65535)+(e*-7&65535)&65535)+(o*96&65535)&65535)+(p*-2&65535)&65535)-q;b[l+14>>1]=((((o*42&65535)+(n*-7&65535)&65535)+(p*96&65535)&65535)+(q*-2&65535)&65535)-(d[m+10|0]|0);q=k+1|0;if((q|0)<13){k=q;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;q=f*6|0;p=f*7|0;n=0;o=j+32|0;j=c;while(1){c=b[o>>1]|0;e=b[o+16>>1]|0;r=b[o+32>>1]|0;s=b[o+48>>1]|0;t=b[o+64>>1]|0;u=b[o+80>>1]|0;v=b[o+96>>1]|0;w=b[o+112>>1]|0;x=b[o+128>>1]|0;y=b[o+144>>1]|0;z=e*5|0;a[j]=a[(512-(b[o-16>>1]|0)+(c*5|0)+z-r>>10)+1404400|0]|0;A=r*5|0;a[j+f|0]=a[(512-c+z+A-s>>10)+1404400|0]|0;z=s*5|0;a[j+g|0]=a[(512-e+A+z-t>>10)+1404400|0]|0;A=t*5|0;a[j+m|0]=a[(512-r+z+A-u>>10)+1404400|0]|0;z=u*5|0;a[j+l|0]=a[(512-s+A+z-v>>10)+1404400|0]|0;A=v*5|0;a[j+k|0]=a[(512-t+z+A-w>>10)+1404400|0]|0;z=w*5|0;a[j+q|0]=a[(512-u+A+z-x>>10)+1404400|0]|0;a[j+p|0]=a[(512-v+z+(x*5|0)-y>>10)+1404400|0]|0;y=n+1|0;if((y|0)<8){n=y;o=o+2|0;j=j+1|0}else{break}}i=h;return}function Job(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n>>1]|0;q=b[n+16>>1]|0;r=b[n+32>>1]|0;s=b[n+48>>1]|0;t=b[n+64>>1]|0;u=b[n+80>>1]|0;v=b[n+96>>1]|0;w=b[n+112>>1]|0;x=b[n+128>>1]|0;y=b[n+144>>1]|0;z=q*5|0;a[j]=a[(32-(b[n-16>>1]|0)+(c*5|0)+z-r>>6)+1404400|0]|0;A=r*5|0;a[j+f|0]=a[(32-c+z+A-s>>6)+1404400|0]|0;z=s*5|0;a[j+g|0]=a[(32-q+A+z-t>>6)+1404400|0]|0;A=t*5|0;a[j+m|0]=a[(32-r+z+A-u>>6)+1404400|0]|0;z=u*5|0;a[j+l|0]=a[(32-s+A+z-v>>6)+1404400|0]|0;A=v*5|0;a[j+k|0]=a[(32-t+z+A-w>>6)+1404400|0]|0;z=w*5|0;a[j+o|0]=a[(32-u+A+z-x>>6)+1404400|0]|0;a[j+p|0]=a[(32-v+z+(x*5|0)-y>>6)+1404400|0]|0;y=e+1|0;if((y|0)<8){e=y;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Kob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m-1|0]|0;n=d[m]|0;o=d[m+1|0]|0;p=d[m+2|0]|0;b[l>>1]=((((e*-2&65535)-(d[m-2|0]|0)&65535)+(n*96&65535)&65535)+(o*42&65535)&65535)+(p*-7&65535);q=d[m+3|0]|0;b[l+2>>1]=((((n*-2&65535)-e&65535)+(o*96&65535)&65535)+(p*42&65535)&65535)+(q*-7&65535);e=d[m+4|0]|0;b[l+4>>1]=((((o*-2&65535)-n&65535)+(p*96&65535)&65535)+(q*42&65535)&65535)+(e*-7&65535);n=d[m+5|0]|0;b[l+6>>1]=((((p*-2&65535)-o&65535)+(q*96&65535)&65535)+(e*42&65535)&65535)+(n*-7&65535);o=d[m+6|0]|0;b[l+8>>1]=((((q*-2&65535)-p&65535)+(e*96&65535)&65535)+(n*42&65535)&65535)+(o*-7&65535);p=d[m+7|0]|0;b[l+10>>1]=((((e*-2&65535)-q&65535)+(n*96&65535)&65535)+(o*42&65535)&65535)+(p*-7&65535);q=d[m+8|0]|0;b[l+12>>1]=((((n*-2&65535)-e&65535)+(o*96&65535)&65535)+(p*42&65535)&65535)+(q*-7&65535);b[l+14>>1]=((((o*-2&65535)-n&65535)+(p*96&65535)&65535)+(q*42&65535)&65535)+((d[m+9|0]|0)*-7&65535);q=k+1|0;if((q|0)<13){k=q;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;q=f*6|0;p=f*7|0;n=0;o=j+32|0;j=c;while(1){c=b[o>>1]|0;e=b[o+16>>1]|0;r=b[o+32>>1]|0;s=b[o+48>>1]|0;t=b[o+64>>1]|0;u=b[o+80>>1]|0;v=b[o+96>>1]|0;w=b[o+112>>1]|0;x=b[o+128>>1]|0;y=b[o+144>>1]|0;z=e*5|0;a[j]=a[(512-(b[o-16>>1]|0)+(c*5|0)+z-r>>10)+1404400|0]|0;A=r*5|0;a[j+f|0]=a[(512-c+z+A-s>>10)+1404400|0]|0;z=s*5|0;a[j+g|0]=a[(512-e+A+z-t>>10)+1404400|0]|0;A=t*5|0;a[j+m|0]=a[(512-r+z+A-u>>10)+1404400|0]|0;z=u*5|0;a[j+l|0]=a[(512-s+A+z-v>>10)+1404400|0]|0;A=v*5|0;a[j+k|0]=a[(512-t+z+A-w>>10)+1404400|0]|0;z=w*5|0;a[j+q|0]=a[(512-u+A+z-x>>10)+1404400|0]|0;a[j+p|0]=a[(512-v+z+(x*5|0)-y>>10)+1404400|0]|0;y=n+1|0;if((y|0)<8){n=y;o=o+2|0;j=j+1|0}else{break}}i=h;return}function Lob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=-f|0;h=f<<1;i=f*3|0;j=f<<2;k=f*5|0;l=f*6|0;m=f*7|0;n=f<<3;o=f*9|0;p=e<<1;q=e*3|0;r=e<<2;s=e*5|0;t=e*6|0;u=e*7|0;v=0;w=c;c=b;while(1){b=d[w]|0;x=d[w+f|0]|0;y=d[w+h|0]|0;z=d[w+i|0]|0;A=d[w+j|0]|0;B=d[w+k|0]|0;C=d[w+l|0]|0;D=d[w+m|0]|0;E=d[w+n|0]|0;F=d[w+o|0]|0;G=x*5|0;a[c]=a[(4-(d[w+g|0]|0)+(b*5|0)+G-y>>3)+1404400|0]|0;H=y*5|0;a[c+e|0]=a[(4-b+G+H-z>>3)+1404400|0]|0;G=z*5|0;a[c+p|0]=a[(4-x+H+G-A>>3)+1404400|0]|0;H=A*5|0;a[c+q|0]=a[(4-y+G+H-B>>3)+1404400|0]|0;G=B*5|0;a[c+r|0]=a[(4-z+H+G-C>>3)+1404400|0]|0;H=C*5|0;a[c+s|0]=a[(4-A+G+H-D>>3)+1404400|0]|0;G=D*5|0;a[c+t|0]=a[(4-B+H+G-E>>3)+1404400|0]|0;a[c+u|0]=a[(4-C+G+(E*5|0)-F>>3)+1404400|0]|0;F=v+1|0;if((F|0)<8){v=F;w=w+1|0;c=c+1|0}else{break}}return}function Mob(c,e,f,g){c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+208|0;j=h|0;k=0;l=j|0;m=e+(-(g<<1)|0)|0;while(1){e=d[m]|0;n=d[m+1|0]|0;o=d[m+2|0]|0;b[l>>1]=((n+e&65535)*5&65535)-(o+(d[m-1|0]|0)&65535);p=d[m+3|0]|0;b[l+2>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+4|0]|0;b[l+4>>1]=((p+o&65535)*5&65535)-(e+n&65535);n=d[m+5|0]|0;b[l+6>>1]=((e+p&65535)*5&65535)-(n+o&65535);o=d[m+6|0]|0;b[l+8>>1]=((n+e&65535)*5&65535)-(o+p&65535);p=d[m+7|0]|0;b[l+10>>1]=((o+n&65535)*5&65535)-(p+e&65535);e=d[m+8|0]|0;b[l+12>>1]=((p+o&65535)*5&65535)-(e+n&65535);b[l+14>>1]=((e+p&65535)*5&65535)-((d[m+9|0]|0)+o&65535);o=k+1|0;if((o|0)<13){k=o;l=l+16|0;m=m+g|0}else{break}}g=f<<1;m=f*3|0;l=f<<2;k=f*5|0;o=f*6|0;p=f*7|0;e=0;n=j+32|0;j=c;while(1){c=b[n-16>>1]|0;q=b[n>>1]|0;r=b[n+16>>1]|0;s=b[n+32>>1]|0;t=b[n+48>>1]|0;u=b[n+64>>1]|0;v=b[n+80>>1]|0;w=b[n+96>>1]|0;x=b[n+112>>1]|0;y=b[n+128>>1]|0;z=b[n+144>>1]|0;a[j]=a[(512-(b[n-32>>1]|0)+(c*-2|0)+(q*96|0)+(r*42|0)+(s*-7|0)>>10)+1404400|0]|0;a[j+f|0]=a[(512-c+(q*-2|0)+(r*96|0)+(s*42|0)+(t*-7|0)>>10)+1404400|0]|0;a[j+g|0]=a[(512-q+(r*-2|0)+(s*96|0)+(t*42|0)+(u*-7|0)>>10)+1404400|0]|0;a[j+m|0]=a[(512-r+(s*-2|0)+(t*96|0)+(u*42|0)+(v*-7|0)>>10)+1404400|0]|0;a[j+l|0]=a[(512-s+(t*-2|0)+(u*96|0)+(v*42|0)+(w*-7|0)>>10)+1404400|0]|0;a[j+k|0]=a[(512-t+(u*-2|0)+(v*96|0)+(w*42|0)+(x*-7|0)>>10)+1404400|0]|0;a[j+o|0]=a[(512-u+(v*-2|0)+(w*96|0)+(x*42|0)+(y*-7|0)>>10)+1404400|0]|0;a[j+p|0]=a[(512-v+(w*-2|0)+(x*96|0)+(y*42|0)+(z*-7|0)>>10)+1404400|0]|0;z=e+1|0;if((z|0)<8){e=z;n=n+2|0;j=j+1|0}else{break}}i=h;return}function Nob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=f*-2|0;h=-f|0;i=f<<1;j=f*3|0;k=f<<2;l=f*5|0;m=f*6|0;n=f*7|0;o=f<<3;p=f*9|0;q=e<<1;r=e*3|0;s=e<<2;t=e*5|0;u=e*6|0;v=e*7|0;w=0;x=c;c=b;while(1){b=d[x+h|0]|0;y=d[x]|0;z=d[x+f|0]|0;A=d[x+i|0]|0;B=d[x+j|0]|0;C=d[x+k|0]|0;D=d[x+l|0]|0;E=d[x+m|0]|0;F=d[x+n|0]|0;G=d[x+o|0]|0;H=d[x+p|0]|0;a[c]=a[(64-(d[x+g|0]|0)+(b*-2|0)+(y*96|0)+(z*42|0)+(A*-7|0)>>7)+1404400|0]|0;a[c+e|0]=a[(64-b+(y*-2|0)+(z*96|0)+(A*42|0)+(B*-7|0)>>7)+1404400|0]|0;a[c+q|0]=a[(64-y+(z*-2|0)+(A*96|0)+(B*42|0)+(C*-7|0)>>7)+1404400|0]|0;a[c+r|0]=a[(64-z+(A*-2|0)+(B*96|0)+(C*42|0)+(D*-7|0)>>7)+1404400|0]|0;a[c+s|0]=a[(64-A+(B*-2|0)+(C*96|0)+(D*42|0)+(E*-7|0)>>7)+1404400|0]|0;a[c+t|0]=a[(64-B+(C*-2|0)+(D*96|0)+(E*42|0)+(F*-7|0)>>7)+1404400|0]|0;a[c+u|0]=a[(64-C+(D*-2|0)+(E*96|0)+(F*42|0)+(G*-7|0)>>7)+1404400|0]|0;a[c+v|0]=a[(64-D+(E*-2|0)+(F*96|0)+(G*42|0)+(H*-7|0)>>7)+1404400|0]|0;H=w+1|0;if((H|0)<8){w=H;x=x+1|0;c=c+1|0}else{break}}return}function Oob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c;c=b;b=0;while(1){h=g+1|0;i=g+2|0;j=g+3|0;a[c]=a[(((d[g-1|0]|0)*-7|0)+64+((d[g]|0)*42|0)+((d[h]|0)*96|0)+((d[i]|0)*-2|0)-(d[j]|0)>>7)+1404400|0]|0;k=g+4|0;a[c+1|0]=a[(((d[g]|0)*-7|0)+64+((d[h]|0)*42|0)+((d[i]|0)*96|0)+((d[j]|0)*-2|0)-(d[k]|0)>>7)+1404400|0]|0;l=g+5|0;a[c+2|0]=a[(((d[h]|0)*-7|0)+64+((d[i]|0)*42|0)+((d[j]|0)*96|0)+((d[k]|0)*-2|0)-(d[l]|0)>>7)+1404400|0]|0;h=g+6|0;a[c+3|0]=a[(((d[i]|0)*-7|0)+64+((d[j]|0)*42|0)+((d[k]|0)*96|0)+((d[l]|0)*-2|0)-(d[h]|0)>>7)+1404400|0]|0;i=g+7|0;a[c+4|0]=a[(((d[j]|0)*-7|0)+64+((d[k]|0)*42|0)+((d[l]|0)*96|0)+((d[h]|0)*-2|0)-(d[i]|0)>>7)+1404400|0]|0;j=g+8|0;a[c+5|0]=a[(((d[k]|0)*-7|0)+64+((d[l]|0)*42|0)+((d[h]|0)*96|0)+((d[i]|0)*-2|0)-(d[j]|0)>>7)+1404400|0]|0;k=g+9|0;a[c+6|0]=a[(((d[l]|0)*-7|0)+64+((d[h]|0)*42|0)+((d[i]|0)*96|0)+((d[j]|0)*-2|0)-(d[k]|0)>>7)+1404400|0]|0;a[c+7|0]=a[(((d[h]|0)*-7|0)+64+((d[i]|0)*42|0)+((d[j]|0)*96|0)+((d[k]|0)*-2|0)-(d[g+10|0]|0)>>7)+1404400|0]|0;k=b+1|0;if((k|0)<8){g=g+f|0;c=c+e|0;b=k}else{break}}return}function Pob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=c;c=b;b=0;while(1){h=g+1|0;i=g+2|0;j=g+3|0;a[c]=a[(4-(d[g-1|0]|0)-(d[i]|0)+(((d[h]|0)+(d[g]|0)|0)*5|0)>>3)+1404400|0]|0;k=g+4|0;a[c+1|0]=a[(4-(d[g]|0)-(d[j]|0)+(((d[i]|0)+(d[h]|0)|0)*5|0)>>3)+1404400|0]|0;l=g+5|0;a[c+2|0]=a[(4-(d[h]|0)-(d[k]|0)+(((d[j]|0)+(d[i]|0)|0)*5|0)>>3)+1404400|0]|0;h=g+6|0;a[c+3|0]=a[(4-(d[i]|0)-(d[l]|0)+(((d[k]|0)+(d[j]|0)|0)*5|0)>>3)+1404400|0]|0;i=g+7|0;a[c+4|0]=a[(4-(d[j]|0)-(d[h]|0)+(((d[l]|0)+(d[k]|0)|0)*5|0)>>3)+1404400|0]|0;j=g+8|0;a[c+5|0]=a[(4-(d[k]|0)-(d[i]|0)+(((d[h]|0)+(d[l]|0)|0)*5|0)>>3)+1404400|0]|0;a[c+6|0]=a[(4-(d[l]|0)-(d[j]|0)+(((d[i]|0)+(d[h]|0)|0)*5|0)>>3)+1404400|0]|0;a[c+7|0]=a[(4-(d[h]|0)-(d[g+9|0]|0)+(((d[j]|0)+(d[i]|0)|0)*5|0)>>3)+1404400|0]|0;i=b+1|0;if((i|0)<8){g=g+f|0;c=c+e|0;b=i}else{break}}return}function Qob(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c;c=b;b=0;while(1){h=g-1|0;i=g+1|0;j=g+2|0;k=g+3|0;a[c]=a[(64-(d[g-2|0]|0)+((d[h]|0)*-2|0)+((d[g]|0)*96|0)+((d[i]|0)*42|0)+((d[j]|0)*-7|0)>>7)+1404400|0]|0;l=g+4|0;a[c+1|0]=a[(64-(d[h]|0)+((d[g]|0)*-2|0)+((d[i]|0)*96|0)+((d[j]|0)*42|0)+((d[k]|0)*-7|0)>>7)+1404400|0]|0;h=g+5|0;a[c+2|0]=a[(64-(d[g]|0)+((d[i]|0)*-2|0)+((d[j]|0)*96|0)+((d[k]|0)*42|0)+((d[l]|0)*-7|0)>>7)+1404400|0]|0;m=g+6|0;a[c+3|0]=a[(64-(d[i]|0)+((d[j]|0)*-2|0)+((d[k]|0)*96|0)+((d[l]|0)*42|0)+((d[h]|0)*-7|0)>>7)+1404400|0]|0;i=g+7|0;a[c+4|0]=a[(64-(d[j]|0)+((d[k]|0)*-2|0)+((d[l]|0)*96|0)+((d[h]|0)*42|0)+((d[m]|0)*-7|0)>>7)+1404400|0]|0;j=g+8|0;a[c+5|0]=a[(64-(d[k]|0)+((d[l]|0)*-2|0)+((d[h]|0)*96|0)+((d[m]|0)*42|0)+((d[i]|0)*-7|0)>>7)+1404400|0]|0;a[c+6|0]=a[(64-(d[l]|0)+((d[h]|0)*-2|0)+((d[m]|0)*96|0)+((d[i]|0)*42|0)+((d[j]|0)*-7|0)>>7)+1404400|0]|0;a[c+7|0]=a[(64-(d[h]|0)+((d[m]|0)*-2|0)+((d[i]|0)*96|0)+((d[j]|0)*42|0)+((d[g+9|0]|0)*-7|0)>>7)+1404400|0]|0;j=b+1|0;if((j|0)<8){g=g+f|0;c=c+e|0;b=j}else{break}}return}function Rob(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=c[b>>2]|0;e=c[b+124>>2]|0;f=e+d|0;g=d-e<<1;Erc(g,(g|0)<0|0?-1:0,1075036753,0)|0;g=G;e=c[b+60>>2]|0;d=c[b+64>>2]|0;h=d+e|0;i=e-d<<5;Erc(i,(i|0)<0|0?-1:0,1367679739,0)|0;i=G;d=h+f|0;e=f-h<<1;Erc(e,(e|0)<0|0?-1:0,1078937202,0)|0;e=G;h=i+g|0;f=i-g<<1;Erc(f,(f|0)<0|0?-1:0,-1078937202,-1)|0;f=G;g=c[b+28>>2]|0;i=c[b+96>>2]|0;j=i+g|0;k=g-i<<1;Erc(k,(k|0)<0|0?-1:0,1449139879,0)|0;k=G;i=c[b+32>>2]|0;g=c[b+92>>2]|0;l=g+i|0;m=i-g<<1;Erc(m,(m|0)<0|0?-1:0,1598879467,0)|0;m=G;g=l+j|0;i=j-l<<4;Erc(i,(i|0)<0|0?-1:0,1369329156,0)|0;i=G;l=m+k|0;j=m-k<<4;Erc(j,(j|0)<0|0?-1:0,-1369329156,-1)|0;j=G;k=g+d|0;m=d-g<<1;Erc(m,(m|0)<0|0?-1:0,1094777670,0)|0;m=G;g=i+e|0;d=i-e<<1;Erc(d,(d|0)<0|0?-1:0,-1094777670,-1)|0;d=G;e=l+h|0;i=h-l<<1;Erc(i,(i|0)<0|0?-1:0,1094777670,0)|0;i=G;l=j+f|0;h=j-f<<1;Erc(h,(h|0)<0|0?-1:0,-1094777670,-1)|0;h=G;f=c[b+12>>2]|0;j=c[b+112>>2]|0;n=j+f|0;o=f-j<<1;Erc(o,(o|0)<0|0?-1:0,1140405281,0)|0;o=G;j=c[b+48>>2]|0;f=c[b+76>>2]|0;p=f+j|0;q=j-f<<2;Erc(q,(q|0)<0|0?-1:0,1593609622,0)|0;q=G;f=p+n|0;j=n-p<<1;Erc(j,(j|0)<0|0?-1:0,1389039203,0)|0;j=G;p=q+o|0;n=q-o<<1;Erc(n,(n|0)<0|0?-1:0,-1389039203,-1)|0;n=G;o=c[b+16>>2]|0;q=c[b+108>>2]|0;r=q+o|0;s=o-q<<1;Erc(s,(s|0)<0|0?-1:0,1187781572,0)|0;s=G;q=c[b+44>>2]|0;o=c[b+80>>2]|0;t=o+q|0;u=q-o<<2;Erc(u,(u|0)<0|0?-1:0,1255676567,0)|0;u=G;o=t+r|0;q=r-t<<1;Erc(q,(q|0)<0|0?-1:0,1692549166,0)|0;q=G;t=u+s|0;r=u-s<<1;Erc(r,(r|0)<0|0?-1:0,-1692549166,-1)|0;r=G;s=o+f|0;u=f-o<<3;Erc(u,(u|0)<0|0?-1:0,1375954754,0)|0;u=G;o=q+j|0;f=q-j<<3;Erc(f,(f|0)<0|0?-1:0,-1375954754,-1)|0;f=G;j=t+p|0;q=p-t<<3;Erc(q,(q|0)<0|0?-1:0,1375954754,0)|0;q=G;t=r+n|0;p=r-n<<3;Erc(p,(p|0)<0|0?-1:0,-1375954754,-1)|0;p=G;n=s+k|0;r=k-s<<1;Erc(r,(r|0)<0|0?-1:0,1162209775,0)|0;r=G;s=u+m|0;k=u-m<<1;Erc(k,(k|0)<0|0?-1:0,-1162209775,-1)|0;k=G;m=o+g|0;u=g-o<<1;Erc(u,(u|0)<0|0?-1:0,1162209775,0)|0;u=G;o=f+d|0;g=f-d<<1;Erc(g,(g|0)<0|0?-1:0,-1162209775,-1)|0;g=G;d=j+e|0;f=e-j<<1;Erc(f,(f|0)<0|0?-1:0,1162209775,0)|0;f=G;j=q+i|0;e=q-i<<1;Erc(e,(e|0)<0|0?-1:0,-1162209775,-1)|0;e=G;i=t+l|0;q=l-t<<1;Erc(q,(q|0)<0|0?-1:0,1162209775,0)|0;q=G;t=p+h|0;l=p-h<<1;Erc(l,(l|0)<0|0?-1:0,-1162209775,-1)|0;l=G;h=c[b+4>>2]|0;p=c[b+120>>2]|0;v=p+h|0;w=h-p<<1;Erc(w,(w|0)<0|0?-1:0,1085490621,0)|0;w=G;p=c[b+56>>2]|0;h=c[b+68>>2]|0;x=h+p|0;y=p-h<<3;Erc(y,(y|0)<0|0?-1:0,1829445839,0)|0;y=G;h=x+v|0;p=v-x<<1;Erc(p,(p|0)<0|0?-1:0,1122057232,0)|0;p=G;x=y+w|0;v=y-w<<1;Erc(v,(v|0)<0|0?-1:0,-1122057232,-1)|0;v=G;w=c[b+24>>2]|0;y=c[b+100>>2]|0;z=y+w|0;A=w-y<<1;Erc(A,(A|0)<0|0?-1:0,1336817425,0)|0;A=G;y=c[b+36>>2]|0;w=c[b+88>>2]|0;B=w+y|0;C=y-w<<1;Erc(C,(C|0)<0|0?-1:0,1802489638,0)|0;C=G;w=B+z|0;y=z-B<<2;Erc(y,(y|0)<0|0?-1:0,1849463489,0)|0;y=G;B=C+A|0;z=C-A<<2;Erc(z,(z|0)<0|0?-1:0,-1849463489,-1)|0;z=G;A=w+h|0;C=h-w<<1;Erc(C,(C|0)<0|0?-1:0,1291378312,0)|0;C=G;w=y+p|0;h=y-p<<1;Erc(h,(h|0)<0|0?-1:0,-1291378312,-1)|0;h=G;p=B+x|0;y=x-B<<1;Erc(y,(y|0)<0|0?-1:0,1291378312,0)|0;y=G;B=z+v|0;x=z-v<<1;Erc(x,(x|0)<0|0?-1:0,-1291378312,-1)|0;x=G;v=c[b+8>>2]|0;z=c[b+116>>2]|0;D=z+v|0;E=v-z<<1;Erc(E,(E|0)<0|0?-1:0,1106914669,0)|0;E=G;z=c[b+52>>2]|0;v=c[b+72>>2]|0;F=v+z|0;H=z-v<<3;Erc(H,(H|0)<0|0?-1:0,1104762768,0)|0;H=G;v=F+D|0;z=D-F<<1;Erc(z,(z|0)<0|0?-1:0,1217503044,0)|0;z=G;F=H+E|0;D=H-E<<1;Erc(D,(D|0)<0|0?-1:0,-1217503044,-1)|0;D=G;E=c[b+20>>2]|0;H=c[b+104>>2]|0;I=H+E|0;J=E-H<<1;Erc(J,(J|0)<0|0?-1:0,1251843312,0)|0;J=G;H=c[b+40>>2]|0;E=c[b+84>>2]|0;b=E+H|0;K=H-E<<1;Erc(K,(K|0)<0|0?-1:0,2088574387,0)|0;K=G;E=b+I|0;H=I-b<<2;Erc(H,(H|0)<0|0?-1:0,1138893993,0)|0;H=G;b=K+J|0;I=K-J<<2;Erc(I,(I|0)<0|0?-1:0,-1138893993,-1)|0;I=G;J=E+v|0;K=v-E<<1;Erc(K,(K|0)<0|0?-1:0,1932684223,0)|0;K=G;E=H+z|0;v=H-z<<1;Erc(v,(v|0)<0|0?-1:0,-1932684223,-1)|0;v=G;z=b+F|0;H=F-b<<1;Erc(H,(H|0)<0|0?-1:0,1932684223,0)|0;H=G;b=I+D|0;F=I-D<<1;Erc(F,(F|0)<0|0?-1:0,-1932684223,-1)|0;F=G;D=J+A|0;I=A-J<<2;Erc(I,(I|0)<0|0?-1:0,1402911301,0)|0;I=G;J=K+C|0;A=K-C<<2;Erc(A,(A|0)<0|0?-1:0,-1402911301,-1)|0;A=G;C=E+w|0;K=w-E<<2;Erc(K,(K|0)<0|0?-1:0,1402911301,0)|0;K=G;E=v+h|0;w=v-h<<2;Erc(w,(w|0)<0|0?-1:0,-1402911301,-1)|0;w=G;h=z+p|0;v=p-z<<2;Erc(v,(v|0)<0|0?-1:0,1402911301,0)|0;v=G;z=H+y|0;p=H-y<<2;Erc(p,(p|0)<0|0?-1:0,-1402911301,-1)|0;p=G;y=b+B|0;H=B-b<<2;Erc(H,(H|0)<0|0?-1:0,1402911301,0)|0;H=G;b=F+x|0;B=F-x<<2;Erc(B,(B|0)<0|0?-1:0,-1402911301,-1)|0;B=G;x=n-D<<1;Erc(x,(x|0)<0|0?-1:0,1518500250,0)|0;x=G;F=I-r<<1;Erc(F,(F|0)<0|0?-1:0,-1518500250,-1)|0;F=G;L=s-J<<1;Erc(L,(L|0)<0|0?-1:0,1518500250,0)|0;L=G;M=A-k<<1;Erc(M,(M|0)<0|0?-1:0,-1518500250,-1)|0;M=G;N=A+k+M|0;k=m-C<<1;Erc(k,(k|0)<0|0?-1:0,1518500250,0)|0;k=G;A=K-u<<1;Erc(A,(A|0)<0|0?-1:0,-1518500250,-1)|0;A=G;O=K+u+A|0;u=o-E<<1;Erc(u,(u|0)<0|0?-1:0,1518500250,0)|0;u=G;K=w-g<<1;Erc(K,(K|0)<0|0?-1:0,-1518500250,-1)|0;K=G;P=w+g+K|0;g=E+o+P|0;o=P+u|0;P=K+u|0;u=d-h<<1;Erc(u,(u|0)<0|0?-1:0,1518500250,0)|0;u=G;E=v-f<<1;Erc(E,(E|0)<0|0?-1:0,-1518500250,-1)|0;E=G;w=v+f+E|0;f=j-z<<1;Erc(f,(f|0)<0|0?-1:0,1518500250,0)|0;f=G;v=p-e<<1;Erc(v,(v|0)<0|0?-1:0,-1518500250,-1)|0;v=G;Q=p+e+v|0;e=z+j+Q|0;j=Q+f|0;Q=v+f|0;f=i-y<<1;Erc(f,(f|0)<0|0?-1:0,1518500250,0)|0;f=G;z=H-q<<1;Erc(z,(z|0)<0|0?-1:0,-1518500250,-1)|0;z=G;p=H+q+z|0;q=t-b<<1;Erc(q,(q|0)<0|0?-1:0,1518500250,0)|0;q=G;H=B-l<<1;Erc(H,(H|0)<0|0?-1:0,-1518500250,-1)|0;H=G;R=B+l+H|0;l=b+t+R|0;t=R+q|0;R=H+q|0;c[a>>2]=D+n;c[a+64>>2]=x;c[a+32>>2]=I+r+F;c[a+96>>2]=F;c[a+16>>2]=J+s+N;c[a+80>>2]=M+L;c[a+48>>2]=N+L;c[a+112>>2]=M;c[a+8>>2]=C+m+g;c[a+72>>2]=P+k;c[a+40>>2]=o+O;c[a+104>>2]=K+A;c[a+24>>2]=g+O;c[a+88>>2]=P+A;c[a+56>>2]=o+k;c[a+120>>2]=K;K=y+i+l|0;i=l+p|0;l=t+p|0;p=t+f|0;t=R+f|0;f=R+z|0;R=H+z|0;c[a+4>>2]=h+d+K;c[a+68>>2]=t+u;c[a+36>>2]=l+w;c[a+100>>2]=R+E;c[a+20>>2]=i+e;c[a+84>>2]=f+Q;c[a+52>>2]=p+j;c[a+116>>2]=H+v;c[a+12>>2]=K+e;c[a+76>>2]=t+Q;c[a+44>>2]=l+j;c[a+108>>2]=R+v;c[a+28>>2]=i+w;c[a+92>>2]=f+E;c[a+60>>2]=p+u;c[a+124>>2]=H;return}function Sob(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=e+8|0;h=c[g>>2]|0;i=-h&7;j=c[e+16>>2]|0;if((i|0)==0){k=h}else{l=i+h|0;h=j>>>0>l>>>0?l:j;c[g>>2]=h;k=h}h=((c[e+12>>2]|0)-k|0)/8|0;l=(h|0)<(f|0)?h:f;f=c[e>>2]|0;e=(k|0)/8|0;h=f+e|0;i=a+8|0;c[i>>2]=h;m=e+l|0;n=f+m|0;c[a+12>>2]=n;o=l<<3;l=-k|0;p=j-k|0;if((o|0)<(l|0)){q=l}else{q=(p|0)<(o|0)?p:o}c[g>>2]=q+k;k=a|0;c[k>>2]=0;if((e|0)<(m|0)){m=f+(e+1)|0;c[i>>2]=m;r=(d[h]|0)<<8;s=m}else{r=65280;s=h}c[k>>2]=r;if(s>>>0<n>>>0){h=s+1|0;c[i>>2]=h;t=r|(d[s]|0);u=h}else{t=r|255;u=s}s=t<<8;c[k>>2]=s;if(u>>>0<n>>>0){t=u+1|0;c[i>>2]=t;v=s|(d[u]|0);w=t}else{v=s|255;w=u}u=v<<8;c[k>>2]=u;if(w>>>0<n>>>0){c[i>>2]=w+1;x=u|(d[w]|0)}else{x=u|255}c[k>>2]=x;b[a+6>>1]=-16;b[a+4>>1]=-1;x=0;do{b[8378640+(x<<2)>>1]=b[1401400+(255-x<<1)>>1]|0;b[8378642+(x<<2)>>1]=-(b[1401400+(x<<1)>>1]|0);x=x+1|0;}while((x|0)<256);b[a+16>>1]=-32768;b[a+18>>1]=-32768;b[a+20>>1]=-32768;b[a+22>>1]=-32768;b[a+24>>1]=-32768;b[a+26>>1]=-32768;b[a+28>>1]=-32768;b[a+30>>1]=-32768;b[a+32>>1]=-32768;b[a+34>>1]=-32768;b[a+36>>1]=-32768;b[a+38>>1]=-32768;b[a+40>>1]=-32768;b[a+42>>1]=-32768;b[a+44>>1]=-32768;b[a+46>>1]=-32768;b[a+48>>1]=-32768;b[a+50>>1]=-32768;b[a+52>>1]=-32768;b[a+54>>1]=-32768;b[a+56>>1]=-32768;b[a+58>>1]=-32768;return}function Tob(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;k=i;c[a>>2]=b;c[a+8>>2]=d;c[a+12>>2]=e;c[a+16>>2]=f;c[a+20>>2]=h;c[a+4>>2]=j+16;a:do{if((h|0)>0){j=h;while(1){j=j-1|0;d=e>>j;l=f<<j;switch(g|0){case 5:case 6:{c[a+56+(j*36|0)+32>>2]=1;break};case 3:{m=d-1|0;if(m>>>0<4294967294>>>0){n=m<<1;o=-2;while(1){p=((o|0)>0?n:0)-o|0;if(p>>>0>m>>>0){o=p}else{q=p;break}}}else{q=-2}c[a+56+(j*36|0)>>2]=b+((ca(q,l)|0)<<1);if((d|0)==0){r=-1}else{o=m<<1;n=-1;while(1){p=((n|0)>0?o:0)-n|0;if(p>>>0>m>>>0){n=p}else{r=p;break}}}c[a+56+(j*36|0)+4>>2]=b+((ca(r,l)|0)<<1);c[a+56+(j*36|0)+32>>2]=-1;break};case 2:{c[a+56+(j*36|0)>>2]=b;n=b+(l<<1)|0;c[a+56+(j*36|0)+4>>2]=n;c[a+56+(j*36|0)+8>>2]=b;c[a+56+(j*36|0)+12>>2]=n;c[a+56+(j*36|0)+16>>2]=b;c[a+56+(j*36|0)+20>>2]=n;c[a+56+(j*36|0)+32>>2]=-5;break};case 8:{n=d-1|0;if(n>>>0<4294967292>>>0){m=n<<1;o=-4;while(1){p=((o|0)>0?m:0)-o|0;if(p>>>0>n>>>0){o=p}else{s=p;break}}}else{s=-4}c[a+56+(j*36|0)>>2]=b+((ca(s,l)|0)<<1);if(n>>>0<4294967293>>>0){o=n<<1;m=-3;while(1){p=((m|0)>0?o:0)-m|0;if(p>>>0>n>>>0){m=p}else{t=p;break}}}else{t=-3}c[a+56+(j*36|0)+4>>2]=b+((ca(t,l)|0)<<1);if(n>>>0<4294967294>>>0){m=n<<1;o=-2;while(1){p=((o|0)>0?m:0)-o|0;if(p>>>0>n>>>0){o=p}else{u=p;break}}}else{u=-2}c[a+56+(j*36|0)+8>>2]=b+((ca(u,l)|0)<<1);if((d|0)==0){v=-1}else{o=n<<1;m=-1;while(1){p=((m|0)>0?o:0)-m|0;if(p>>>0>n>>>0){m=p}else{v=p;break}}}c[a+56+(j*36|0)+12>>2]=b+((ca(v,l)|0)<<1);c[a+56+(j*36|0)+32>>2]=-3;break};case 4:{m=d-2|0;c[a+56+(j*36|0)>>2]=b;n=d-1|0;o=b+(l<<1)|0;c[a+56+(j*36|0)+4>>2]=o;c[a+56+(j*36|0)+8>>2]=b;c[a+56+(j*36|0)+12>>2]=o;c[a+56+(j*36|0)+16>>2]=b;c[a+56+(j*36|0)+20>>2]=o;c[a+56+(j*36|0)+24>>2]=b+((ca((m|0)<0?m:0,l)|0)<<1);c[a+56+(j*36|0)+28>>2]=b+((ca((n|0)<1?n:1,l)|0)<<1);c[a+56+(j*36|0)+32>>2]=-5;break};default:{c[a+56+(j*36|0)+32>>2]=0}}if((j|0)<=0){break a}}}}while(0);switch(g|0){case 4:{c[a+28>>2]=630;c[a+32>>2]=186;c[a+36>>2]=192;c[a+52>>2]=1564;c[a+24>>2]=7;w=0;i=k;return w|0};case 5:case 6:{c[a+28>>2]=682;c[a+48>>2]=206;c[a+52>>2]=(g|0)==5?2314:1044;c[a+24>>2]=1;w=0;i=k;return w|0};case 8:{c[a+28>>2]=134;c[a+32>>2]=398;c[a+36>>2]=490;c[a+40>>2]=396;c[a+44>>2]=488;c[a+52>>2]=896;c[a+24>>2]=5;w=0;i=k;return w|0};case 3:{c[a+28>>2]=228;c[a+32>>2]=502;c[a+36>>2]=732;c[a+52>>2]=300;c[a+24>>2]=3;w=0;i=k;return w|0};case 7:{c[a+28>>2]=100;c[a+32>>2]=468;c[a+36>>2]=1070;c[a+52>>2]=1718;c[a+24>>2]=0;w=0;i=k;return w|0};case 2:{c[a+28>>2]=684;c[a+32>>2]=502;c[a+36>>2]=192;c[a+52>>2]=358;c[a+24>>2]=7;w=0;i=k;return w|0};default:{KIb(0,16,2426272,(a=i,i=i+8|0,c[a>>2]=g,a)|0);i=a;w=-1;i=k;return w|0}}return 0}function Uob(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;h=i;i=i+32|0;j=h;k=c[a+32>>2]|0;l=c[a+36>>2]|0;m=a+56+(b*36|0)+32|0;n=c[m>>2]|0;o=a+((b*36|0)+56)|0;c[j>>2]=c[o>>2];c[j+4>>2]=c[o+4>>2];c[j+8>>2]=c[o+8>>2];c[j+12>>2]=c[o+12>>2];c[j+16>>2]=c[o+16>>2];c[j+20>>2]=c[o+20>>2];j=c[a>>2]|0;b=n+5|0;p=e-2|0;if((b|0)<0){q=0}else{q=(b|0)>(p|0)?p:b}p=j+((ca(q,f)|0)<<1)|0;c[h+24>>2]=p;q=n+6|0;r=e-1|0;if((q|0)<1){s=1}else{s=(q|0)>(r|0)?r:q}q=j+((ca(s,f)|0)<<1)|0;c[h+28>>2]=q;if(b>>>0<e>>>0){mf[k&2047](c[h+20>>2]|0,p,q,d)}if((n+1|0)>>>0<e>>>0){_e[l&511](c[h>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0,c[h+16>>2]|0,p,d)}if((n-1|0)>>>0<e>>>0){ef[c[a+52>>2]&4095](c[h>>2]|0,c[a+4>>2]|0,d)}if(n>>>0<e>>>0){ef[c[a+52>>2]&4095](c[h+4>>2]|0,c[a+4>>2]|0,d)}d=h+8|0;c[o>>2]=c[d>>2];c[o+4>>2]=c[d+4>>2];c[o+8>>2]=c[d+8>>2];c[o+12>>2]=c[d+12>>2];c[o+16>>2]=c[d+16>>2];c[o+20>>2]=c[d+20>>2];c[m>>2]=(c[m>>2]|0)+2;i=g;return}function Vob(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(e[h>>1]|0)-(((b[a+(g<<1)>>1]|0)+2+(b[d+(g<<1)>>1]|0)|0)>>>2);g=g+1|0;}while((g|0)<(f|0));return}function Wob(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((h|0)>0){i=0}else{return}do{j=d+(i<<1)|0;b[j>>1]=((8-(b[a+(i<<1)>>1]|0)-(b[g+(i<<1)>>1]|0)+(((b[f+(i<<1)>>1]|0)+(b[c+(i<<1)>>1]|0)|0)*9|0)|0)>>>4)+(e[j>>1]|0);i=i+1|0;}while((i|0)<(h|0));return}function Xob(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;f=d>>1;d=(e[a>>1]|0)-(((b[a+(f<<1)>>1]<<1)+2|0)>>>2)&65535;b[c>>1]=d;if((f|0)>1){g=1;do{h=g+f|0;b[c+(g<<1)>>1]=(e[a+(g<<1)>>1]|0)-(((b[a+(h-1<<1)>>1]|0)+2+(b[a+(h<<1)>>1]|0)|0)>>>2);g=g+1|0;}while((g|0)<(f|0));i=b[c>>1]|0}else{i=d}b[c-2>>1]=i;i=b[c+(f-1<<1)>>1]|0;b[c+(f<<1)>>1]=i;b[c+(f+1<<1)>>1]=i;if((f|0)>0){j=0}else{return}while(1){i=c+(j<<1)|0;d=j<<1;b[a+(d<<1)>>1]=((b[i>>1]|0)+1|0)>>>1;g=j+1|0;b[a+((d|1)<<1)>>1]=((b[a+(j+f<<1)>>1]|0)+1+((8-(b[c+(j-1<<1)>>1]|0)-(b[c+(j+2<<1)>>1]|0)+(((b[c+(g<<1)>>1]|0)+(b[i>>1]|0)|0)*9|0)|0)>>>4)|0)>>>1;if((g|0)<(f|0)){j=g}else{break}}return}function Yob(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=a+56+(b*36|0)+32|0;h=c[g>>2]|0;i=a+56+(b*36|0)|0;j=c[i>>2]|0;k=a+56+(b*36|0)+4|0;b=c[k>>2]|0;l=c[a+32>>2]|0;m=c[a+36>>2]|0;n=c[a>>2]|0;o=h+1|0;p=e-1|0;if(o>>>0>p>>>0){q=p<<1;r=o;while(1){s=((r|0)>0?q:0)-r|0;if(s>>>0>p>>>0){r=s}else{t=s;break}}}else{t=o}r=n+((ca(t,f)|0)<<1)|0;t=h+2|0;if(t>>>0>p>>>0){q=p<<1;s=t;while(1){u=((s|0)>0?q:0)-s|0;if(u>>>0>p>>>0){s=u}else{v=u;break}}}else{v=t}t=n+((ca(v,f)|0)<<1)|0;if(o>>>0<e>>>0){mf[l&2047](b,r,t,d)}l=h>>>0<e>>>0;if(l){mf[m&2047](j,b,r,d)}if((h-1|0)>>>0<e>>>0){ef[c[a+52>>2]&4095](j,c[a+4>>2]|0,d)}if(!l){c[i>>2]=r;c[k>>2]=t;w=c[g>>2]|0;x=w+2|0;c[g>>2]=x;return}ef[c[a+52>>2]&4095](b,c[a+4>>2]|0,d);c[i>>2]=r;c[k>>2]=t;w=c[g>>2]|0;x=w+2|0;c[g>>2]=x;return}function Zob(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(((b[a+(g<<1)>>1]|0)+1+(b[d+(g<<1)>>1]|0)|0)>>>1)+(e[h>>1]|0);g=g+1|0;}while((g|0)<(f|0));return}function _ob(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d>>1;g=(e[a>>1]|0)-(((b[a+(f<<1)>>1]<<1)+2|0)>>>2)&65535;b[c>>1]=g;a:do{if((f|0)>1){h=1;i=g;while(1){j=h+f|0;k=j-1|0;l=a+(k<<1)|0;m=(e[a+(h<<1)>>1]|0)-(((b[l>>1]|0)+2+(b[a+(j<<1)>>1]|0)|0)>>>2)&65535;j=c+(h<<1)|0;b[j>>1]=m;b[c+(k<<1)>>1]=(((i<<16>>16)+1+(m<<16>>16)|0)>>>1)+(e[l>>1]|0);l=h+1|0;if((l|0)>=(f|0)){break a}h=l;i=b[j>>1]|0}}}while(0);g=d-1|0;b[c+(g<<1)>>1]=(b[c+(f-1<<1)>>1]|0)+(b[a+(g<<1)>>1]|0);if((f|0)>0){n=0}else{return}do{g=n<<1;b[a+(g<<1)>>1]=((b[c+(n<<1)>>1]|0)+1|0)>>>1;b[a+((g|1)<<1)>>1]=((b[c+(n+f<<1)>>1]|0)+1|0)>>>1;n=n+1|0;}while((n|0)<(f|0));return}function $ob(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=i;i=i+40|0;j=c[a+32>>2]|0;k=c[a+36>>2]|0;l=a+56+(b*36|0)+32|0;m=c[l>>2]|0;n=a+((b*36|0)+56)|0;nrc(h|0,n|0,32)|0;b=c[a>>2]|0;o=m+7|0;p=e-2|0;if((o|0)<0){q=0}else{q=(o|0)>(p|0)?p:o}c[h+32>>2]=b+((ca(q,f)|0)<<1);q=m+8|0;o=e-1|0;if((q|0)<1){r=1}else{r=(q|0)>(o|0)?o:q}q=b+((ca(r,f)|0)<<1)|0;c[h+36>>2]=q;if((m+5|0)>>>0<e>>>0){_e[j&511](c[h+12>>2]|0,c[h+20>>2]|0,c[h+24>>2]|0,c[h+28>>2]|0,q,d)}if((m+1|0)>>>0<e>>>0){_e[k&511](c[h>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0,c[h+16>>2]|0,c[h+24>>2]|0,d)}if((m-1|0)>>>0<e>>>0){ef[c[a+52>>2]&4095](c[h>>2]|0,c[a+4>>2]|0,d)}if(!(m>>>0<e>>>0)){s=h+8|0;t=s;nrc(n|0,t|0,32)|0;u=c[l>>2]|0;v=u+2|0;c[l>>2]=v;i=g;return}ef[c[a+52>>2]&4095](c[h+4>>2]|0,c[a+4>>2]|0,d);s=h+8|0;t=s;nrc(n|0,t|0,32)|0;u=c[l>>2]|0;v=u+2|0;c[l>>2]=v;i=g;return}function apb(a,c,d,f,g,h){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((h|0)>0){i=0}else{return}do{j=d+(i<<1)|0;b[j>>1]=(e[j>>1]|0)-((16-(b[a+(i<<1)>>1]|0)-(b[g+(i<<1)>>1]|0)+(((b[f+(i<<1)>>1]|0)+(b[c+(i<<1)>>1]|0)|0)*9|0)|0)>>>5);i=i+1|0;}while((i|0)<(h|0));return}function bpb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d>>1;g=a+(f<<1)|0;h=b[g>>1]|0;i=f+1|0;j=a+(i<<1)|0;b[c>>1]=(e[a>>1]|0)-((16-h-(b[j>>1]|0)+(h*18|0)|0)>>>5);b[c+2>>1]=(e[a+2>>1]|0)-(((b[g>>1]<<3)+16+((b[j>>1]|0)*9|0)-(b[a+(f+2<<1)>>1]|0)|0)>>>5);j=f-1|0;if((j|0)>2){g=2;do{h=g+f|0;b[c+(g<<1)>>1]=(e[a+(g<<1)>>1]|0)-((16-(b[a+(h-2<<1)>>1]|0)-(b[a+(h+1<<1)>>1]|0)+(((b[a+(h<<1)>>1]|0)+(b[a+(h-1<<1)>>1]|0)|0)*9|0)|0)>>>5);g=g+1|0;}while((g|0)<(j|0))}g=b[a+(d-1<<1)>>1]|0;h=c+(j<<1)|0;b[h>>1]=(e[a+(j<<1)>>1]|0)-((16-(b[a+(d-3<<1)>>1]|0)-g+((g+(b[a+(d-2<<1)>>1]|0)|0)*9|0)|0)>>>5);b[c-2>>1]=b[c>>1]|0;d=b[h>>1]|0;b[c+(f<<1)>>1]=d;b[c+(i<<1)>>1]=d;if((f|0)>0){k=0}else{return}while(1){d=c+(k<<1)|0;i=k<<1;b[a+(i<<1)>>1]=((b[d>>1]|0)+1|0)>>>1;h=k+1|0;b[a+((i|1)<<1)>>1]=((b[a+(k+f<<1)>>1]|0)+1+((8-(b[c+(k-1<<1)>>1]|0)-(b[c+(k+2<<1)>>1]|0)+(((b[c+(h<<1)>>1]|0)+(b[d>>1]|0)|0)*9|0)|0)>>>4)|0)>>>1;if((h|0)<(f|0)){k=h}else{break}}return}function cpb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;e=a+56+(b*36|0)+32|0;b=c[e>>2]|0;g=c[a>>2]|0;h=g+((ca(b-1|0,f)|0)<<1)|0;i=g+((ca(b,f)|0)<<1)|0;ef[c[a+48>>2]&4095](h,i,d);f=a+52|0;b=a+4|0;ef[c[f>>2]&4095](h,c[b>>2]|0,d);ef[c[f>>2]&4095](i,c[b>>2]|0,d);c[e>>2]=(c[e>>2]|0)+2;return}function dpb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0;if((d|0)>0){f=0}else{return}do{g=a+(f<<1)|0;h=c+(f<<1)|0;i=(e[g>>1]|0)-(((b[h>>1]|0)+1|0)>>>1)&65535;b[g>>1]=i;b[h>>1]=i+(b[h>>1]|0);f=f+1|0;}while((f|0)<(d|0));return}function epb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;f=d>>1;if((f|0)>0){g=0}else{return}while(1){d=g+f|0;h=a+(d<<1)|0;i=(e[a+(g<<1)>>1]|0)-(((b[h>>1]|0)+1|0)>>>1)&65535;b[c+(g<<1)>>1]=i;b[c+(d<<1)>>1]=i+(b[h>>1]|0);h=g+1|0;if((h|0)<(f|0)){g=h}else{j=0;break}}do{g=j<<1;b[a+(g<<1)>>1]=b[c+(j<<1)>>1]|0;b[a+((g|1)<<1)>>1]=b[c+(j+f<<1)>>1]|0;j=j+1|0;}while((j|0)<(f|0));return}function fpb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;f=d>>1;if((f|0)>0){g=0}else{return}while(1){d=g+f|0;h=a+(d<<1)|0;i=(e[a+(g<<1)>>1]|0)-(((b[h>>1]|0)+1|0)>>>1)&65535;b[c+(g<<1)>>1]=i;b[c+(d<<1)>>1]=i+(b[h>>1]|0);h=g+1|0;if((h|0)<(f|0)){g=h}else{j=0;break}}do{g=j<<1;b[a+(g<<1)>>1]=((b[c+(j<<1)>>1]|0)+1|0)>>>1;b[a+((g|1)<<1)>>1]=((b[c+(j+f<<1)>>1]|0)+1|0)>>>1;j=j+1|0;}while((j|0)<(f|0));return}function gpb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=i;i=i+32|0;h=g|0;j=c[a+32>>2]|0;k=c[a+36>>2]|0;if((e|0)>1){l=a|0;m=e-2|0;n=h|0;o=1;do{p=c[l>>2]|0;q=o-7|0;if((q|0)<0){r=0}else{r=(q|0)>(m|0)?m:q}c[n>>2]=p+((ca(r,f)|0)<<1);q=o-5|0;if((q|0)<0){s=0}else{s=(q|0)>(m|0)?m:q}c[h+4>>2]=p+((ca(s,f)|0)<<1);q=o-3|0;if((q|0)<0){t=0}else{t=(q|0)>(m|0)?m:q}c[h+8>>2]=p+((ca(t,f)|0)<<1);q=o-1|0;if((q|0)<0){u=0}else{u=(q|0)>(m|0)?m:q}c[h+12>>2]=p+((ca(u,f)|0)<<1);q=o+1|0;if((q|0)<0){v=0}else{v=(q|0)>(m|0)?m:q}c[h+16>>2]=p+((ca(v,f)|0)<<1);q=o+3|0;if((q|0)<0){w=0}else{w=(q|0)>(m|0)?m:q}c[h+20>>2]=p+((ca(w,f)|0)<<1);q=o+5|0;if((q|0)<0){x=0}else{x=(q|0)>(m|0)?m:q}c[h+24>>2]=p+((ca(x,f)|0)<<1);q=o+7|0;if((q|0)<0){y=0}else{y=(q|0)>(m|0)?m:q}c[h+28>>2]=p+((ca(y,f)|0)<<1);q=p+((ca(o,f)|0)<<1)|0;ef[k&4095](q,n,d);o=o+2|0;}while((o|0)<(e|0))}o=(e|0)>0;if(!o){z=e+1|0;A=a+56+(b*36|0)+32|0;c[A>>2]=z;i=g;return}n=a|0;k=e-1|0;y=h|0;m=0;do{x=c[n>>2]|0;w=m-7|0;if((w|0)<1){B=1}else{B=(w|0)>(k|0)?k:w}c[y>>2]=x+((ca(B,f)|0)<<1);w=m-5|0;if((w|0)<1){C=1}else{C=(w|0)>(k|0)?k:w}c[h+4>>2]=x+((ca(C,f)|0)<<1);w=m-3|0;if((w|0)<1){D=1}else{D=(w|0)>(k|0)?k:w}c[h+8>>2]=x+((ca(D,f)|0)<<1);w=m-1|0;if((w|0)<1){E=1}else{E=(w|0)>(k|0)?k:w}c[h+12>>2]=x+((ca(E,f)|0)<<1);w=m|1;if((w|0)<1){F=1}else{F=(w|0)>(k|0)?k:w}c[h+16>>2]=x+((ca(F,f)|0)<<1);w=m+3|0;if((w|0)<1){G=1}else{G=(w|0)>(k|0)?k:w}c[h+20>>2]=x+((ca(G,f)|0)<<1);w=m+5|0;if((w|0)<1){H=1}else{H=(w|0)>(k|0)?k:w}c[h+24>>2]=x+((ca(H,f)|0)<<1);w=m+7|0;if((w|0)<1){I=1}else{I=(w|0)>(k|0)?k:w}c[h+28>>2]=x+((ca(I,f)|0)<<1);w=x+((ca(m,f)|0)<<1)|0;ef[j&4095](w,y,d);m=m+2|0;}while((m|0)<(e|0));if(!o){z=e+1|0;A=a+56+(b*36|0)+32|0;c[A>>2]=z;i=g;return}o=a+52|0;m=a|0;y=a+4|0;j=0;do{I=(c[m>>2]|0)+((ca(j,f)|0)<<1)|0;ef[c[o>>2]&4095](I,c[y>>2]|0,d);j=j+1|0;}while((j|0)<(e|0));z=e+1|0;A=a+56+(b*36|0)+32|0;c[A>>2]=z;i=g;return}function hpb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)<=0){return}g=c[d>>2]|0;h=c[d+28>>2]|0;i=c[d+4>>2]|0;j=c[d+24>>2]|0;k=c[d+8>>2]|0;l=c[d+20>>2]|0;m=c[d+12>>2]|0;n=c[d+16>>2]|0;d=0;do{o=a+(d<<1)|0;b[o>>1]=(e[o>>1]|0)-(((((b[h+(d<<1)>>1]|0)+(b[g+(d<<1)>>1]|0)|0)*-8|0)+128+(((b[j+(d<<1)>>1]|0)+(b[i+(d<<1)>>1]|0)|0)*21|0)+(((b[l+(d<<1)>>1]|0)+(b[k+(d<<1)>>1]|0)|0)*-46|0)+(((b[n+(d<<1)>>1]|0)+(b[m+(d<<1)>>1]|0)|0)*161|0)|0)>>>8);d=d+1|0;}while((d|0)<(f|0));return}function ipb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)<=0){return}g=c[d>>2]|0;h=c[d+28>>2]|0;i=c[d+4>>2]|0;j=c[d+24>>2]|0;k=c[d+8>>2]|0;l=c[d+20>>2]|0;m=c[d+12>>2]|0;n=c[d+16>>2]|0;d=0;do{o=a+(d<<1)|0;b[o>>1]=(((((b[h+(d<<1)>>1]|0)+(b[g+(d<<1)>>1]|0)|0)*-2|0)+128+(((b[j+(d<<1)>>1]|0)+(b[i+(d<<1)>>1]|0)|0)*10|0)+(((b[l+(d<<1)>>1]|0)+(b[k+(d<<1)>>1]|0)|0)*-25|0)+(((b[n+(d<<1)>>1]|0)+(b[m+(d<<1)>>1]|0)|0)*81|0)|0)>>>8)+(e[o>>1]|0);d=d+1|0;}while((d|0)<(f|0));return}function jpb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d>>1;d=(f|0)>0;if(!d){return}g=f-1|0;h=0;do{i=h-3|0;if((i|0)<0){j=0}else{j=(i|0)>(g|0)?g:i}i=h-2|0;if((i|0)<0){k=0}else{k=(i|0)>(g|0)?g:i}i=h-1|0;if((i|0)<0){l=0}else{l=(i|0)>(g|0)?g:i}i=h+1|0;m=h+2|0;n=h+3|0;o=h+4|0;b[c+(h<<1)>>1]=(((((b[a+(((o|0)>(g|0)?g:o)<<1)>>1]|0)+(b[a+(j<<1)>>1]|0)|0)*-2|0)+128+(((b[a+(((n|0)>(g|0)?g:n)<<1)>>1]|0)+(b[a+(k<<1)>>1]|0)|0)*10|0)+(((b[a+(((m|0)>(g|0)?g:m)<<1)>>1]|0)+(b[a+(l<<1)>>1]|0)|0)*-25|0)+(((b[a+(((i|0)>(g|0)?g:i)<<1)>>1]|0)+(b[a+(h<<1)>>1]|0)|0)*81|0)|0)>>>8)+(e[a+(h+f<<1)>>1]|0);h=h+1|0;}while((h|0)<(f|0));if(!d){return}h=f-1|0;g=0;do{l=g-4|0;if((l|0)<0){p=0}else{p=(l|0)>(h|0)?h:l}l=g-3|0;if((l|0)<0){q=0}else{q=(l|0)>(h|0)?h:l}l=g-2|0;if((l|0)<0){r=0}else{r=(l|0)>(h|0)?h:l}l=g-1|0;if((l|0)<0){s=0}else{s=(l|0)>(h|0)?h:l}l=g+1|0;k=g+2|0;j=g+3|0;b[c+(g+f<<1)>>1]=(e[a+(g<<1)>>1]|0)-(((((b[c+(((j|0)>(h|0)?h:j)<<1)>>1]|0)+(b[c+(p<<1)>>1]|0)|0)*-8|0)+128+(((b[c+(((k|0)>(h|0)?h:k)<<1)>>1]|0)+(b[c+(q<<1)>>1]|0)|0)*21|0)+(((b[c+(((l|0)>(h|0)?h:l)<<1)>>1]|0)+(b[c+(r<<1)>>1]|0)|0)*-46|0)+(((b[c+(g<<1)>>1]|0)+(b[c+(s<<1)>>1]|0)|0)*161|0)|0)>>>8);g=g+1|0;}while((g|0)<(f|0));if(d){t=0}else{return}do{d=t<<1;b[a+(d<<1)>>1]=b[c+(t+f<<1)>>1]|0;b[a+((d|1)<<1)>>1]=b[c+(t<<1)>>1]|0;t=t+1|0;}while((t|0)<(f|0));return}function kpb(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=i;i=i+24|0;j=h;k=c[a+32>>2]|0;l=c[a+36>>2]|0;m=c[a+40>>2]|0;n=c[a+44>>2]|0;o=a+56+(b*36|0)+32|0;p=c[o>>2]|0;q=a+((b*36|0)+56)|0;c[j>>2]=c[q>>2];c[j+4>>2]=c[q+4>>2];c[j+8>>2]=c[q+8>>2];c[j+12>>2]=c[q+12>>2];j=k;k=l;l=m;m=n;n=c[a>>2]|0;b=p+3|0;r=e-1|0;if(b>>>0>r>>>0){s=r<<1;t=b;while(1){u=((t|0)>0?s:0)-t|0;if(u>>>0>r>>>0){t=u}else{v=u;break}}}else{v=b}t=n+((ca(v,f)|0)<<1)|0;c[h+16>>2]=t;v=p+4|0;if(v>>>0>r>>>0){s=r<<1;u=v;while(1){w=((u|0)>0?s:0)-u|0;if(w>>>0>r>>>0){u=w}else{x=w;break}}}else{x=v}v=n+((ca(x,f)|0)<<1)|0;c[h+20>>2]=v;if(b>>>0<e>>>0){mf[l&2047](c[h+12>>2]|0,t,v,d)}if((p+2|0)>>>0<e>>>0){mf[m&2047](c[h+8>>2]|0,c[h+12>>2]|0,t,d)}if((p+1|0)>>>0<e>>>0){mf[j&2047](c[h+4>>2]|0,c[h+8>>2]|0,c[h+12>>2]|0,d)}j=p>>>0<e>>>0;if(j){mf[k&2047](c[h>>2]|0,c[h+4>>2]|0,c[h+8>>2]|0,d)}if((p-1|0)>>>0<e>>>0){ef[c[a+52>>2]&4095](c[h>>2]|0,c[a+4>>2]|0,d)}if(!j){y=h+8|0;z=y;c[q>>2]=c[z>>2];c[q+4>>2]=c[z+4>>2];c[q+8>>2]=c[z+8>>2];c[q+12>>2]=c[z+12>>2];A=c[o>>2]|0;B=A+2|0;c[o>>2]=B;i=g;return}ef[c[a+52>>2]&4095](c[h+4>>2]|0,c[a+4>>2]|0,d);y=h+8|0;z=y;c[q>>2]=c[z>>2];c[q+4>>2]=c[z+4>>2];c[q+8>>2]=c[z+8>>2];c[q+12>>2]=c[z+12>>2];A=c[o>>2]|0;B=A+2|0;c[o>>2]=B;i=g;return}function lpb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(((((b[d+(g<<1)>>1]|0)+(b[a+(g<<1)>>1]|0)|0)*217|0)+2048|0)>>>12)+(e[h>>1]|0);g=g+1|0;}while((g|0)<(f|0));return}function mpb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(((((b[d+(g<<1)>>1]|0)+(b[a+(g<<1)>>1]|0)|0)*6497|0)+2048|0)>>>12)+(e[h>>1]|0);g=g+1|0;}while((g|0)<(f|0));return}function npb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(e[h>>1]|0)-(((((b[d+(g<<1)>>1]|0)+(b[a+(g<<1)>>1]|0)|0)*1817|0)+2048|0)>>>12);g=g+1|0;}while((g|0)<(f|0));return}function opb(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0;if((f|0)>0){g=0}else{return}do{h=c+(g<<1)|0;b[h>>1]=(e[h>>1]|0)-(((((b[d+(g<<1)>>1]|0)+(b[a+(g<<1)>>1]|0)|0)*113|0)+64|0)>>>7);g=g+1|0;}while((g|0)<(f|0));return}function ppb(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=d>>1;g=(e[a>>1]|0)-((((b[a+(f<<1)>>1]|0)*3634|0)+2048|0)>>>12)&65535;b[c>>1]=g;h=(f|0)>1;a:do{if(h){i=1;j=g;while(1){k=i+f|0;l=k-1|0;m=a+(l<<1)|0;n=(e[a+(i<<1)>>1]|0)-(((((b[a+(k<<1)>>1]|0)+(b[m>>1]|0)|0)*1817|0)+2048|0)>>>12)&65535;k=c+(i<<1)|0;b[k>>1]=n;b[c+(l<<1)>>1]=(e[m>>1]|0)-(((((n<<16>>16)+(j<<16>>16)|0)*113|0)+64|0)>>>7);n=i+1|0;if((n|0)>=(f|0)){break a}i=n;j=b[k>>1]|0}}}while(0);g=d-1|0;d=a+(g<<1)|0;j=c+(g<<1)|0;b[j>>1]=(e[d>>1]|0)-((((b[c+(f-1<<1)>>1]|0)*226|0)+64|0)>>>7);g=(((b[c+(f<<1)>>1]|0)*434|0)+2048>>12)+(b[c>>1]|0)|0;b[a>>1]=(g+1|0)>>>1;if(h){o=g;p=1}else{q=g;r=b[j>>1]|0;s=r<<16>>16;t=q*12994|0;u=t+2048|0;v=u>>>12;w=v+1|0;x=w+s|0;y=x>>>1;z=y&65535;b[d>>1]=z;return}while(1){g=p+f|0;h=b[c+(g-1<<1)>>1]|0;i=((((b[c+(g<<1)>>1]|0)+h|0)*217|0)+2048>>12)+(b[c+(p<<1)>>1]|0)|0;g=p<<1;b[a+(g-1<<1)>>1]=(h+1+((((i+o|0)*6497|0)+2048|0)>>>12)|0)>>>1;b[a+(g<<1)>>1]=(i+1|0)>>>1;g=p+1|0;if((g|0)<(f|0)){o=i;p=g}else{q=i;break}}r=b[j>>1]|0;s=r<<16>>16;t=q*12994|0;u=t+2048|0;v=u>>>12;w=v+1|0;x=w+s|0;y=x>>>1;z=y&65535;b[d>>1]=z;return}function qpb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[a+24>>2]|0;e=c[a+20>>2]|0;if((e|0)<=0){return}f=a+8|0;g=a+12|0;h=a+16|0;i=a+28|0;j=e;do{j=j-1|0;e=c[f>>2]>>j;k=c[g>>2]>>j;l=c[h>>2]<<j;m=a+56+(j*36|0)+32|0;n=(b>>j)+d|0;o=(n|0)>(k|0)?k:n;if((c[m>>2]|0)<=(o|0)){do{pe[c[i>>2]&1023](a,j,e,k,l);}while((c[m>>2]|0)<=(o|0))}}while((j|0)>0);return}function rpb(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;e=c[a+16>>2]|0;f=c[a+12>>2]|0;g=ca(e*27|0,f)|0;h=c[a+4>>2]|0;if((h|0)==20){i=(c[a>>2]|0)==1?g-81|0:g}else if((h|0)==24){i=(c[a>>2]|0)==1?g-108|0:g}else{i=g}g=c[a+56>>2]|0;if((b[g+((i-1|0)*12|0)>>1]|0)==0&(e|0)>0){i=a|0;j=a+36|0;k=a+64|0;l=0;m=0;n=0;o=h;while(1){if((f|0)>0){p=(m|0)!=0;q=m*11|0;r=(m|0)==0;s=m<<2;t=-(m&1)|0;u=t&9;v=m>>>1;w=m*10|0;x=m>>1;y=x+4|0;z=t&6;t=x*45|0;x=l;A=0;B=n;C=o;while(1){D=(A|0)==11;E=(A|0)>9;F=(A+q|0)*27|0;G=r&D;H=(A+w|0)*27|0;I=(A|0)/5|0;J=0;K=x;L=B+6|0;M=C;while(1){N=(((J|0)%3|0|0)==0)+L|0;if((M|0)==20){if(p&(c[i>>2]|0)==1&D){O=K;P=20}else{Q=h;R=11}}else{Q=M;R=11}do{if((R|0)==11){R=0;if((Q|0)==24){if((c[i>>2]|0)==1&E){O=K;P=24;break}}S=J+F|0;T=S+s|0;U=((S|0)/11|0|0)%27|0;S=(U|0)/9|0;V=J+H|0;W=(V<<1)+s+I|0;X=((V|0)/5|0|0)%27|0;V=(X|0)%9|0;Y=(X|0)/9|0;Z=(J|0)/3|0;_=1517672+J|0;$=c[j>>2]|0;if(G){aa=V+u|0;ba=0;do{do{if(($|0)==1440){da=(ba*27|0)+J|0;if((da|0)<90){ea=0;fa=da}else{ea=34304;fa=(da<<1)-180|0}b[g+(K*12|0)+2+(ba<<1)>>1]=fa<<1|ea}else if(($|0)==1280){da=aa+(d[1517632+ba|0]|0)|0;ga=(((((d[1517832+ba|0]|0)+W|0)%10|0)*3|0)+Y<<1)+y|0;if((da|0)>79){ha=d[1517705+(ga<<1)|0]|0;ia=(d[1517704+(ga<<1)|0]|0)+(da-80<<((ga|0)>59))|0}else{ha=ga;ia=da}b[g+(K*12|0)+2+(ba<<1)>>1]=ha<<9|ia<<1}else if(($|0)==720){da=c[k>>2]|0;if((da|0)==4){b[g+(K*12|0)+2+(ba<<1)>>1]=((((d[1517832+ba|0]|0)+11|0)%(f|0)|0)*6|0)+(d[_]|0)<<8|(d[1517616+ba|0]|0)+Z<<1;break}else if((da|0)==7){if((ba|0)==1){ja=3}else{ja=(ba|0)==2?3:0}ga=ja+J|0;ka=(d[1517840+ba|0]|0)+((ga|0)/6|0)|0;la=(((d[1517832+ba|0]|0)+11|0)%(f|0)|0)*6|0;ma=(d[1517640+ga|0]|0)+la|0;if((ka|0)>21){na=(ma<<1)-la|0}else{na=ma}b[g+(K*12|0)+2+(ba<<1)>>1]=na<<8|ka<<2;break}else if((da|0)==0){b[g+(K*12|0)+2+(ba<<1)>>1]=((((d[1517832+ba|0]|0)+11|0)%(f|0)|0)*3|0)+(d[_]|0)<<9|(d[1517616+ba|0]|0)+Z<<1;break}else{break}}else if(($|0)==960){da=((d[1517832+ba|0]|0)+W|0)%10|0;ka=(-(da&1)&3)+X|0;b[g+(K*12|0)+2+(ba<<1)>>1]=((ka|0)/6|0)+t+(d[1517848+da|0]|0)<<9|((ka|0)%6|0)+z+(d[1517624+ba|0]|0)<<1}}while(0);ba=ba+1|0;}while((ba|0)<5)}else{ba=((U|0)%9|0)+u|0;aa=V+u|0;ka=0;do{do{if(($|0)==960){da=((d[1517832+ka|0]|0)+W|0)%10|0;ma=(-(da&1)&3)+X|0;b[g+(K*12|0)+2+(ka<<1)>>1]=((ma|0)/6|0)+t+(d[1517848+da|0]|0)<<9|((ma|0)%6|0)+z+(d[1517624+ka|0]|0)<<1}else if(($|0)==720){ma=c[k>>2]|0;if((ma|0)==4){b[g+(K*12|0)+2+(ka<<1)>>1]=((((((d[1517832+ka|0]|0)+A|0)%(f|0)|0)<<1)+m|0)*3|0)+(d[_]|0)<<8|(d[1517616+ka|0]|0)+Z<<1;break}else if((ma|0)==0){b[g+(K*12|0)+2+(ka<<1)>>1]=((((d[1517832+ka|0]|0)+A|0)%(f|0)|0)*3|0)+(d[_]|0)<<9|(d[1517616+ka|0]|0)+Z<<1;break}else if((ma|0)==7){if((ka|0)==1){oa=3}else{oa=(ka|0)==2?3:0}ma=oa+J|0;da=(d[1517840+ka|0]|0)+((ma|0)/6|0)|0;la=(((d[1517832+ka|0]|0)+A|0)%(f|0)|0)*6|0;ga=(d[1517640+ma|0]|0)+la|0;if((da|0)>21){pa=(ga<<1)-la|0}else{pa=ga}b[g+(K*12|0)+2+(ka<<1)>>1]=pa<<8|da<<2;break}else{break}}else if(($|0)==1440){b[g+(K*12|0)+2+(ka<<1)>>1]=(((((T+(d[1517832+ka|0]|0)|0)%11|0)*3|0)+S<<1)+v<<9)+512|ba+(d[1517632+ka|0]|0)<<1}else if(($|0)==1280){da=aa+(d[1517632+ka|0]|0)|0;ga=(((((d[1517832+ka|0]|0)+W|0)%10|0)*3|0)+Y<<1)+y|0;if((da|0)>79){qa=d[1517705+(ga<<1)|0]|0;ra=(d[1517704+(ga<<1)|0]|0)+(da-80<<((ga|0)>59))|0}else{qa=ga;ra=da}b[g+(K*12|0)+2+(ka<<1)>>1]=qa<<9|ra<<1}}while(0);ka=ka+1|0;}while((ka|0)<5)}b[g+(K*12|0)>>1]=N;O=K+1|0;P=Q}}while(0);sa=N+5|0;ka=J+1|0;if((ka|0)<27){J=ka;K=O;L=sa;M=P}else{break}}M=A+1|0;if((M|0)<(f|0)){x=O;A=M;B=sa;C=P}else{ta=O;ua=sa;va=P;break}}}else{ta=l;ua=n;va=o}C=m+1|0;if((C|0)<(e|0)){l=ta;m=C;n=ua;o=va}else{break}}}va=h&16;h=(va|0)!=0;o=c[a+60>>2]|0;if((c[o+((h?8191:5631)<<2)>>2]|0)!=0){return 0}ua=h?4096:2816;h=o+(ua<<2)|0;n=(c[a+32>>2]|0)==720;a=n?1397e3:1397768;m=n?1397256:1398024;if((va|0)==0){va=0;n=o;ta=h;l=1396744;while(1){e=0;P=n;sa=ta;do{O=(d[1396560+(e<<2)|0]|0)+1|0;f=sa+24|0;Q=0;g=P;ra=sa;while(1){qa=c[l+(Q<<2)>>2]<<O;c[g>>2]=qa;c[ra>>2]=qa<<1;qa=Q+1|0;if((qa|0)<6){Q=qa;g=g+4|0;ra=ra+4|0}else{break}}ra=(d[1396561+(e<<2)|0]|0)+1|0;g=sa+84|0;Q=6;O=P+24|0;qa=f;while(1){pa=c[l+(Q<<2)>>2]<<ra;c[O>>2]=pa;c[qa>>2]=pa<<1;pa=Q+1|0;if((pa|0)<21){Q=pa;O=O+4|0;qa=qa+4|0}else{break}}qa=(d[1396562+(e<<2)|0]|0)+1|0;O=sa+172|0;Q=21;ra=P+84|0;f=g;while(1){pa=c[l+(Q<<2)>>2]<<qa;c[ra>>2]=pa;c[f>>2]=pa<<1;pa=Q+1|0;if((pa|0)<43){Q=pa;ra=ra+4|0;f=f+4|0}else{break}}f=(d[1396563+(e<<2)|0]|0)+1|0;sa=sa+256|0;ra=43;Q=P+172|0;qa=O;while(1){g=c[l+(ra<<2)>>2]<<f;c[Q>>2]=g;c[qa>>2]=g<<1;g=ra+1|0;if((g|0)<64){ra=g;Q=Q+4|0;qa=qa+4|0}else{break}}P=P+256|0;e=e+1|0;}while((e|0)<22);e=va+1|0;if((e|0)<2){va=e;n=P;ta=sa;l=1397512}else{break}}return 0}l=o+4096|0;ta=0;n=o;va=h;while(1){h=d[1518520+ta|0]<<9;e=va+256|0;qa=0;Q=n;ra=va;while(1){c[Q>>2]=ca(h,c[a+(qa<<2)>>2]|0)|0;c[ra>>2]=ca(h,c[m+(qa<<2)>>2]|0)|0;f=qa+1|0;if((f|0)<64){qa=f;Q=Q+4|0;ra=ra+4|0}else{break}}ra=ta+1|0;if((ra|0)<16){ta=ra;n=n+256|0;va=e}else{break}}va=ua|1024;ua=o+8192|0;n=0;ta=l;l=o+(va<<2)|0;while(1){ra=d[1518520+n|0]<<10;Q=l+256|0;qa=0;h=ta;sa=l;while(1){c[h>>2]=ca(ra,c[a+(qa<<2)>>2]|0)|0;c[sa>>2]=ca(ra,c[m+(qa<<2)>>2]|0)|0;P=qa+1|0;if((P|0)<64){qa=P;h=h+4|0;sa=sa+4|0}else{break}}sa=n+1|0;if((sa|0)<16){n=sa;ta=ta+256|0;l=Q}else{break}}l=o+12288|0;ta=0;n=ua;ua=o+(va+1024<<2)|0;while(1){sa=d[1518520+ta|0]<<11;h=ua+256|0;qa=0;ra=n;e=ua;while(1){c[ra>>2]=ca(sa,c[a+(qa<<2)>>2]|0)|0;c[e>>2]=ca(sa,c[m+(qa<<2)>>2]|0)|0;P=qa+1|0;if((P|0)<64){qa=P;ra=ra+4|0;e=e+4|0}else{break}}e=ta+1|0;if((e|0)<16){ta=e;n=n+256|0;ua=h}else{break}}ua=0;n=l;l=o+(va+2048<<2)|0;while(1){va=d[1518520+ua|0]<<12;o=l+256|0;ta=0;e=n;ra=l;while(1){c[e>>2]=ca(va,c[a+(ta<<2)>>2]|0)|0;c[ra>>2]=ca(va,c[m+(ta<<2)>>2]|0)|0;qa=ta+1|0;if((qa|0)<64){ta=qa;e=e+4|0;ra=ra+4|0}else{break}}ra=ua+1|0;if((ra|0)<16){ua=ra;n=n+256|0;l=o}else{break}}return 0}function spb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+6200|0;g=f|0;h=f+1248|0;j=f+1272|0;k=f+2912|0;l=f+3736|0;m=f+4560|0;n=c[e+60>>2]|0;if(!(a[1393856]|0)){a[1393856]=1;o=0;p=0;do{q=b[1395736+(p<<1)>>1]|0;r=j+(o<<1)|0;b[r>>1]=q;s=a[1395320+p|0]|0;t=k+o|0;a[t]=s;u=a[1394488+p|0]|0;a[l+o|0]=u;v=a[1394904+p|0]|0;w=v&255;b[m+(o<<1)>>1]=w;if(v<<24>>24==0){x=o}else{v=q<<1;b[r>>1]=v;r=s+1&255;a[t]=r;t=o+1|0;b[j+(t<<1)>>1]=v|1;a[k+t|0]=r;a[l+t|0]=u;b[m+(t<<1)>>1]=-w;x=t}p=p+1|0;o=x+1|0;}while((p|0)<409);$2(h,9,o,k|0,1,1,j,2,2,0,0,0,0)|0;j=c[h+8>>2]|0;if((j|0)>0){k=c[h+4>>2]|0;o=0;do{p=b[k+(o<<2)>>1]|0;x=p<<16>>16;t=b[k+(o<<2)+2>>1]|0;if(t<<16>>16<0){y=0;z=p}else{y=(a[l+x|0]|0)+1&255;z=b[m+(x<<1)>>1]|0}a[8373906+(o<<2)|0]=t;b[8373904+(o<<2)>>1]=z;a[8373907+(o<<2)|0]=y;o=o+1|0;}while((o|0)<(j|0))}c3(h)}mrc(g|0,0,1244)|0;l8(g,e);h8(g,g+484|0,c[e+244>>2]|0);c[n+144>>2]=c[g>>2];c[n+164>>2]=c[g+504>>2];c[n+148>>2]=c[g+1108>>2];c[n+156>>2]=c[g+1120>>2];h=0;do{a[n+(h+16)|0]=a[(d[1242080+h|0]|0)+(g+1128)|0]|0;h=h+1|0;}while((h|0)<64);c[n+152>>2]=c[g+1112>>2];c[n+160>>2]=548;if((c[e+800>>2]|0)==0){nrc(n+80|0,1242144,64)|0;A=n+8|0;B=A;c[B>>2]=e;C=e+400|0;c[C>>2]=3;i=f;return 0}else{h=0;do{j=d[1242144+h|0]|0;a[n+(h+80)|0]=a[(j<<2&32|j&7|j>>>1&24)+(g+1128)|0]|0;h=h+1|0;}while((h|0)<64);A=n+8|0;B=A;c[B>>2]=e;C=e+400|0;c[C>>2]=3;i=f;return 0}return 0}function tpb(b){b=b|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0,M=0.0,N=0.0,O=0.0,P=0,Q=0,R=0,T=0,U=0,V=0;e=i;i=i+120|0;f=e|0;h=e+24|0;j=e+48|0;nrc(f|0,1393384,17)|0;k=b+904|0;l=c[k>>2]|0;m=b+908|0;n=c[m>>2]|0;if((n|0)>0){o=c[b+896>>2]|0;p=0;q=0;r=l;while(1){s=a[b+912+q|0]|0;t=s&255;if((t+r|0)>(o|0)){a[h+(p&255)|0]=r-l;a[f+q|0]=1;u=l;v=p+1&255}else{u=r;v=p}if(s<<24>>24==0){w=v;x=u}else{s=v;y=0;z=u;while(1){if((z|0)==(o|0)){a[h+(s&255)|0]=o-l;A=l;B=s+1&255}else{A=z;B=s}C=t-y|0;D=o-A|0;E=(C|0)>(D|0)?D:C;C=E+A|0;D=E+y|0;if((D|0)<(t|0)){s=B;y=D;z=C}else{w=B;x=C;break}}}z=q+1|0;if((z|0)<(n|0)){p=w;q=z;r=x}else{F=w;G=x;break}}}else{F=0;G=l}a[h+(F&255)|0]=G-l;l=b+44924|0;G=c[l>>2]|0;if((G|0)<1){i=e;return}x=F+1&255;F=b+896|0;w=x&255;r=x<<24>>24==0;x=b+54460|0;q=1;p=G;G=n;while(1){if((a[b+880+q|0]|0)==0){H=p;I=G}else{if(r){J=G}else{n=0;B=c[F>>2]|0;while(1){A=d[h+n|0]|0;nrc(b+63232+(q<<10)+(B<<2)|0,b+63232+(q<<10)+(c[k>>2]<<2)|0,A<<2)|0;o=n+1|0;if((o|0)>=(w|0)){break}n=o;B=A+B|0}J=c[m>>2]|0}B=(J|0)>0;if(B){n=0;A=c[F>>2]|0;while(1){o=a[b+912+n|0]|0;u=o&255;if(o<<24>>24==0){K=0.0;L=A}else{o=u>>>0>1>>>0?u:1;M=0.0;v=0;z=A;while(1){N=+g[b+63232+(q<<10)+(z<<2)>>2];O=M+N*N;y=v+1|0;if((y|0)<(u|0)){M=O;v=y;z=z+1|0}else{break}}K=O;L=A+o|0}g[j+(n<<2)>>2]=+S(K/+(u|0));z=n+1|0;if((z|0)<(J|0)){n=z;A=L}else{break}}}A=a[b+887+q|0]|0;a:do{if(A<<24>>24>-1){n=A<<24>>24;z=1392160+(n*12|0)|0;if(!B){P=J;break}v=1392164+(n*12|0)|0;y=1392168+(n*12|0)|0;n=0;s=(c[F>>2]|0)-2|0;t=J;while(1){if((a[f+n|0]|0)==0){Q=t}else{C=b+63232+(q<<10)+(s<<2)|0;M=+g[z>>2];g[C>>2]=M*+g[C>>2];N=+g[v>>2];C=b+63232+(q<<10)+(s+1<<2)|0;g[C>>2]=N*+g[C>>2];C=b+63232+(q<<10)+(s+2<<2)|0;g[C>>2]=+g[y>>2]*+g[C>>2];C=b+63232+(q<<10)+(s+3<<2)|0;g[C>>2]=N*+g[C>>2];C=b+63232+(q<<10)+(s+4<<2)|0;g[C>>2]=M*+g[C>>2];Q=c[m>>2]|0}C=n+1|0;if((C|0)>=(Q|0)){R=Q;T=32;break a}D=(d[b+912+n|0]|0)+s|0;n=C;s=D;t=Q}}else{R=J;T=32}}while(0);do{if((T|0)==32){T=0;if((R|0)<=0){P=R;break}B=0;A=c[F>>2]|0;t=R;while(1){M=+g[b+936+(q*68|0)+(B<<2)>>2]*+g[j+(B<<2)>>2]*-4.656612873077393e-10;N=+g[b+1412+(q*68|0)+(B<<2)>>2];s=b+912+B|0;if((a[s]|0)==0){U=A;V=t}else{n=0;y=A;do{v=c[x>>2]|0;c[b+54204+((v&63)<<2)>>2]=(c[b+54204+((v+9&63)<<2)>>2]|0)+(c[b+54204+((v+40&63)<<2)>>2]|0);v=c[x>>2]|0;c[x>>2]=v+1;z=b+63232+(q<<10)+(y<<2)|0;y=y+1|0;g[z>>2]=N*+g[z>>2]+M*+(c[b+54204+((v&63)<<2)>>2]|0);n=n+1|0;}while((n|0)<(d[s]|0));U=y;V=c[m>>2]|0}s=B+1|0;if((s|0)<(V|0)){B=s;A=U;t=V}else{P=V;break}}}}while(0);H=c[l>>2]|0;I=P}t=q+1|0;if((t|0)>(H|0)){break}else{q=t;p=H;G=I}}i=e;return}function upb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=i;i=i+1024|0;h=g|0;j=e+16|0;k=c[j>>2]|0;l=e+24|0;m=c[l>>2]|0;n=e+8|0;o=c[n>>2]|0;p=o+(k>>>3)|0;q=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(k&7);p=q>>>30;r=k+2|0;k=m>>>0>r>>>0?r:m;c[j>>2]=k;r=(q>>31&5)+12|0;q=p-1|0;do{if(q>>>0<2>>>0){s=e+45016+(f<<2)|0;t=c[s>>2]|0;u=e+45044+(f<<2)|0;v=c[u>>2]|0;if((t|0)<(v|0)){w=0;x=t;y=k;z=v}else{A=v;B=s;break}while(1){v=a[e+47176+(f<<8)+x|0]|0;if((v&255)>>>0>7>>>0&(v&255)>>>0<r>>>0){v=d[o+(y>>>3)|0]<<(y&7)>>>7;t=((y|0)<(m|0))+y|0;c[j>>2]=t;c[h+(w<<2)>>2]=(v&1)<<q;C=w+1|0;D=t;E=c[u>>2]|0}else{C=w;D=y;E=z}t=x+1|0;if((t|0)<(E|0)){w=C;x=t;y=D;z=E}else{A=E;B=s;break}}}else{if((p|0)!=3){A=c[e+45044+(f<<2)>>2]|0;B=e+45016+(f<<2)|0;break}s=e+45016+(f<<2)|0;u=c[s>>2]|0;t=e+45044+(f<<2)|0;v=c[t>>2]|0;if((u|0)>=(v|0)){A=v;B=s;break}F=e+4|0;H=2;I=0;J=u;u=v;while(1){do{if(((a[e+47176+(f<<8)+J|0]|0)-8&255)>>>0<9>>>0){if((H|0)!=2){K=I;L=H+1|0;M=u;break}v=c[j>>2]|0;N=c[l>>2]|0;O=(c[n>>2]|0)+(v>>>3)|0;P=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(v&7);O=v+5|0;c[j>>2]=N>>>0>O>>>0?O:N;if(P>>>0>3623878655>>>0){KIb(c[F>>2]|0,24,2426e3,(N=i,i=i+1|0,i=i+7&-8,c[N>>2]=0,N)|0);i=N;Q=26}else{Q=P>>>27}c[h+(I<<2)>>2]=d[1443168+(Q*3|0)|0]|0;c[h+(I+1<<2)>>2]=d[1443169+(Q*3|0)|0]|0;c[h+(I+2<<2)>>2]=d[1443170+(Q*3|0)|0]|0;K=I+3|0;L=0;M=c[t>>2]|0}else{K=I;L=H;M=u}}while(0);P=J+1|0;if((P|0)<(M|0)){H=L;I=K;J=P;u=M}else{A=M;B=s;break}}}}while(0);M=c[B>>2]|0;B=e+45044+(f<<2)|0;if((M|0)>=(A|0)){i=g;return}A=(p|0)!=0;p=e+54460|0;K=0;L=M;while(1){M=a[e+47176+(f<<8)+L|0]|0;Q=M&255;E=d[1393360+Q|0]|0;a:do{if(M<<24>>24==0){z=0;while(1){D=c[p>>2]|0;c[e+54204+((D&63)<<2)>>2]=(c[e+54204+((D+9&63)<<2)>>2]|0)+(c[e+54204+((D+40&63)<<2)>>2]|0);D=c[p>>2]|0;c[p>>2]=D+1;c[e+1916+(f*6144|0)+(L*24|0)+(z<<2)>>2]=(c[e+54204+((D&63)<<2)>>2]&8388607)-4194304;D=z+1|0;if((D|0)<6){z=D}else{R=K;break}}}else{if((M&255)>>>0<8>>>0){z=c[j>>2]|0;D=c[l>>2]|0;y=(c[n>>2]|0)+(z>>>3)|0;x=(je(d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0)|0)<<(z&7)>>>((32-E|0)>>>0);y=z+E|0;c[j>>2]=D>>>0>y>>>0?y:D;D=c[1392632+(Q<<2)>>2]|0;c[e+1916+(f*6144|0)+(L*24|0)>>2]=b[D+(x*12|0)>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+4>>2]=b[D+(x*12|0)+2>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+8>>2]=b[D+(x*12|0)+4>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+12>>2]=b[D+(x*12|0)+6>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+16>>2]=b[D+(x*12|0)+8>>1]<<8;c[e+1916+(f*6144|0)+(L*24|0)+20>>2]=b[D+(x*12|0)+10>>1]<<8;R=K;break}if(A&Q>>>0<r>>>0){S=c[h+(K<<2)>>2]|0;T=K+1|0}else{S=0;T=K}x=E-S|0;D=32-x|0;y=24-E|0;z=Q-8|0;C=1392808+(z<<1)|0;w=-1<<x-1;q=E-2+S|0;m=32-q|0;o=24-q|0;k=1<<23-S;s=S-1|0;u=1392768+(z<<2)+(s<<1)|0;J=1392728+(z<<2)+(s<<1)|0;if((S|0)==0){s=0;while(1){z=c[j>>2]|0;I=c[l>>2]|0;H=(c[n>>2]|0)+(z>>>3)|0;t=d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0;H=z+x|0;c[j>>2]=I>>>0>H>>>0?H:I;I=(je(t|0)|0)<<(z&7)>>D<<y;z=b[C>>1]|0;t=I;H=(I|0)<0|0?-1:0;I=Erc(z<<16>>16,z<<16>>16<0|0?-1:0,t,H)|0;z=G;F=wrc(I>>>15|z<<17,z>>>15|0<<17,t,H)|0;c[e+1916+(f*6144|0)+(L*24|0)+(s<<2)>>2]=F;F=s+1|0;if((F|0)<6){s=F}else{R=T;break a}}}else{U=0}while(1){s=c[j>>2]|0;C=c[l>>2]|0;F=c[n>>2]|0;H=F+(s>>>3)|0;t=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(s&7)>>D;H=s+x|0;s=C>>>0>H>>>0?H:C;c[j>>2]=s;if((t|0)==(w|0)){H=F+(s>>>3)|0;F=(je(d[H]|d[H+1|0]<<8|d[H+2|0]<<16|d[H+3|0]<<24|0)|0)<<(s&7)>>m;H=s+q|0;c[j>>2]=C>>>0>H>>>0?H:C;C=F<<o;if((C|0)>-1){V=k}else{V=b[J>>1]<<8}F=b[u>>1]|0;H=C;s=(C|0)<0|0?-1:0;C=Erc(F<<16>>16,F<<16>>16<0|0?-1:0,H,s)|0;F=G;z=wrc(V,0,H,s)|0;s=wrc(z,G,C>>>15|F<<17,F>>>15|0<<17)|0;W=s}else{W=t<<y}c[e+1916+(f*6144|0)+(L*24|0)+(U<<2)>>2]=W;t=U+1|0;if((t|0)<6){U=t}else{R=T;break}}}}while(0);E=e+1916+(f*6144|0)+(L*24|0)|0;Q=e+1916+(f*6144|0)+(L*24|0)+4|0;M=c[Q>>2]|0;y=e+1916+(f*6144|0)+(L*24|0)+12|0;u=c[y>>2]|0;J=e+1916+(f*6144|0)+(L*24|0)+20|0;k=c[J>>2]|0;o=M-u-k|0;q=e+1916+(f*6144|0)+(L*24|0)+8|0;m=c[q>>2]|0;w=Erc(m,(m|0)<0|0?-1:0,10273905,0)|0;m=w>>>23|G<<9;w=e+1916+(f*6144|0)+(L*24|0)+16|0;x=c[w>>2]|0;D=Erc(x,(x|0)<0|0?-1:0,11863283,0)|0;x=D>>>23|G<<9;D=k+M|0;t=Erc(D,(D|0)<0|0?-1:0,3070444,0)|0;D=t>>>23|G<<9;t=c[E>>2]|0;s=(x>>1)+t|0;F=t-x|0;x=s+m|0;t=s-m|0;m=u+M+D|0;M=D+(k-u)|0;c[E>>2]=x+m;c[Q>>2]=F+o;c[q>>2]=t+M;c[y>>2]=t-M;c[w>>2]=F-o;c[J>>2]=x-m;m=L+1|0;if((m|0)<(c[B>>2]|0)){K=R;L=m}else{break}}i=g;return}function vpb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;g=i;h=f+28|0;j=c[h>>2]|0;if((j|0)==1){QIb(c[f+4>>2]|0,2581496,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-84085770;i=g;return l|0}else if((j|0)==3){KIb(c[f+4>>2]|0,16,2437600,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-84085770;i=g;return l|0}else{if((c[f+32>>2]|0)!=0){QIb(c[f+4>>2]|0,2350456,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-84085770;i=g;return l|0}if((c[f+47080>>2]|0)==3){QIb(c[f+4>>2]|0,2288864,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;l=-1163346256;i=g;return l|0}m=f+16|0;n=f+24|0;o=c[n>>2]|0;p=(c[m>>2]|0)+5|0;q=o>>>0>p>>>0?p:o;c[m>>2]=q;p=f+60|0;r=f+8|0;s=c[r>>2]|0;t=0;u=q;while(1){q=u+5|0;v=o>>>0>q>>>0?q:o;c[m>>2]=v;q=((v|0)<(o|0))+v|0;if((128>>>((v&7)>>>0)&d[s+(v>>>3)|0]|0)==0){w=q;x=q}else{v=q+8|0;q=o>>>0>v>>>0?v:o;w=q;x=q}c[m>>2]=x;q=t+1|0;y=c[p>>2]|0;z=(y|0)!=0?1:2;if((q|0)<(z|0)){t=q;u=w}else{break}}do{if((j|0)==1){u=d[s+(w>>>3)|0]|0;t=((w|0)<(o|0))+w|0;c[m>>2]=t;if((u&128>>>((w&7)>>>0)|0)==0){A=t;break}u=t+16|0;t=o>>>0>u>>>0?u:o;c[m>>2]=t;A=t}else{A=w}}while(0);w=d[s+(A>>>3)|0]|0;t=((A|0)<(o|0))+A|0;c[m>>2]=t;do{if((w&128>>>((A&7)>>>0)|0)==0){B=t;C=j}else{do{if((y|0)>2){u=s+(t>>>3)|0;x=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(t&7)>>>30;u=t+2|0;q=o>>>0>u>>>0?u:o;c[m>>2]=q;c[f+72>>2]=x;if((y&1|0)==0){D=q}else{x=s+(q>>>3)|0;u=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>29;x=q+3|0;q=o>>>0>x>>>0?x:o;c[m>>2]=q;c[f+80>>2]=u;u=s+(q>>>3)|0;x=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(q&7)>>>29;u=q+3|0;q=o>>>0>u>>>0?u:o;c[m>>2]=q;c[f+76>>2]=x;D=q}if((y&4|0)==0){E=D;break}q=s+(D>>>3)|0;x=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(D&7)>>>29;q=D+3|0;u=o>>>0>q>>>0?q:o;c[m>>2]=u;c[f+88>>2]=x>>>0<3>>>0?3:x;x=s+(u>>>3)|0;q=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>29;x=u+3|0;u=o>>>0>x>>>0?x:o;c[m>>2]=u;c[f+84>>2]=q>>>0<3>>>0?3:q;E=u}else{E=t}}while(0);do{if((c[f+64>>2]|0)==0){F=E}else{u=d[s+(E>>>3)|0]<<(E&7)>>>7;q=((E|0)<(o|0))+E|0;c[m>>2]=q;x=u&1;c[f+92>>2]=x;if((x|0)==0){F=q;break}x=s+(q>>>3)|0;u=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(q&7)>>>27;x=q+5|0;q=o>>>0>x>>>0?x:o;c[m>>2]=q;c[f+96>>2]=u;F=q}}while(0);if((j|0)==0){G=0;H=F}else{B=F;C=j;break}while(1){q=d[s+(H>>>3)|0]|0;I=((H|0)<(o|0))+H|0;c[m>>2]=I;J=(q&128>>>((H&7)>>>0)|0)!=0;if((G|0)>=(z|0)){break}if(J){q=I+6|0;u=o>>>0>q>>>0?q:o;c[m>>2]=u;K=u}else{K=I}G=G+1|0;H=K}if(J){u=I+6|0;q=o>>>0>u>>>0?u:o;c[m>>2]=q;L=q}else{L=I}q=s+(L>>>3)|0;u=(je(d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0)|0)<<(L&7)>>>30;q=L+2|0;x=o>>>0>q>>>0?q:o;c[m>>2]=x;if((u|0)==2){q=x+12|0;v=o>>>0>q>>>0?q:o;c[m>>2]=v;M=v}else if((u|0)==1){v=x+5|0;q=o>>>0>v>>>0?v:o;c[m>>2]=q;M=q}else if((u|0)==3){u=s+(x>>>3)|0;q=(je(d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24|0)|0)<<(x&7)>>>27;u=x+5|0;v=o>>>0>u>>>0?u:o;c[m>>2]=v;u=(q<<3)+16|0;q=-v|0;N=o-v|0;if((u|0)<(q|0)){O=q}else{O=(N|0)<(u|0)?N:u}u=O+v|0;c[m>>2]=u;M=u}else{M=x}if((y|0)<2){x=0;u=M;while(1){v=((u|0)<(o|0))+u|0;if((d[s+(u>>>3)|0]&128>>>((u&7)>>>0)|0)==0){P=v}else{N=v+8|0;v=(o>>>0>N>>>0?N:o)+6|0;P=o>>>0>v>>>0?v:o}c[m>>2]=P;v=x+1|0;if((v|0)<(z|0)){x=v;u=P}else{Q=P;break}}}else{Q=M}u=d[s+(Q>>>3)|0]|0;x=((Q|0)<(o|0))+Q|0;c[m>>2]=x;if((u&128>>>((Q&7)>>>0)|0)==0){B=x;C=0;break}u=c[f+48>>2]|0;if((u|0)>0){R=0;S=x}else{B=x;C=0;break}while(1){if((u|0)==1){T=S;U=45}else{x=((S|0)<(o|0))+S|0;if((d[s+(S>>>3)|0]&128>>>((S&7)>>>0)|0)==0){V=x}else{T=x;U=45}}if((U|0)==45){U=0;x=T+5|0;V=o>>>0>x>>>0?x:o}c[m>>2]=V;x=R+1|0;if((x|0)<(u|0)){R=x;S=V}else{B=V;C=0;break}}}}while(0);V=d[s+(B>>>3)|0]|0;S=((B|0)<(o|0))+B|0;c[m>>2]=S;if((V&128>>>((B&7)>>>0)|0)==0){W=S}else{B=s+(S>>>3)|0;V=(je(d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24|0)|0)<<(S&7)>>>29;B=S+3|0;c[f+56>>2]=V;V=(o>>>0>B>>>0?B:o)+2|0;B=o>>>0>V>>>0?V:o;c[m>>2]=B;do{if((y|0)==2){V=s+(B>>>3)|0;S=(je(d[V]|d[V+1|0]<<8|d[V+2|0]<<16|d[V+3|0]<<24|0)|0)<<(B&7)>>>30;V=B+2|0;R=o>>>0>V>>>0?V:o;c[m>>2]=R;c[f+104>>2]=S;S=s+(R>>>3)|0;V=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(R&7)>>>30;S=R+2|0;R=o>>>0>S>>>0?S:o;c[m>>2]=R;c[f+112>>2]=V;X=0;Y=R}else{if((y|0)<=5){X=0;Y=B;break}R=s+(B>>>3)|0;V=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(B&7)>>>30;R=B+2|0;S=o>>>0>R>>>0?R:o;c[m>>2]=S;c[f+108>>2]=V;X=0;Y=S}}while(0);while(1){B=((Y|0)<(o|0))+Y|0;if((d[s+(Y>>>3)|0]&128>>>((Y&7)>>>0)|0)==0){Z=B}else{y=B+8|0;Z=o>>>0>y>>>0?y:o}c[m>>2]=Z;y=X+1|0;if((y|0)<(z|0)){X=y;Y=Z}else{break}}Y=Z+1|0;Z=o>>>0>Y>>>0?Y:o;c[m>>2]=Z;W=Z}do{if((C|0)==0){if((c[f+48>>2]|0)==6){_=W;break}Z=W+1|0;Y=o>>>0>Z>>>0?Z:o;c[m>>2]=Y;_=Y}else if((C|0)==2){if((c[f+48>>2]|0)==6){$=W}else{Y=d[s+(W>>>3)|0]|0;Z=((W|0)<(o|0))+W|0;c[m>>2]=Z;if((Y&128>>>((W&7)>>>0)|0)==0){_=Z;break}else{$=Z}}Z=$+6|0;Y=o>>>0>Z>>>0?Z:o;c[m>>2]=Y;_=Y}else{_=W}}while(0);W=d[s+(_>>>3)|0]|0;$=((_|0)<(o|0))+_|0;c[m>>2]=$;if((W&128>>>((_&7)>>>0)|0)==0){aa=$}else{_=s+($>>>3)|0;W=(je(d[_]|d[_+1|0]<<8|d[_+2|0]<<16|d[_+3|0]<<24|0)|0)<<($&7)>>>26;_=$+6|0;$=o>>>0>_>>>0?_:o;c[m>>2]=$;_=W+1|0;W=0;C=$;do{$=C+8|0;C=o>>>0>$>>>0?$:o;W=W+1|0;}while((W|0)<(_|0));c[m>>2]=C;aa=C}C=f+48|0;if((c[C>>2]|0)==6){_=d[s+(aa>>>3)|0]<<(aa&7)>>>7;W=((aa|0)<(o|0))+aa|0;c[m>>2]=W;$=d[s+(W>>>3)|0]<<(W&7)>>>7;Y=((W|0)<(o|0))+W|0;c[m>>2]=Y;ba=_&1;da=$&1;ea=Y}else{ba=1;da=0;ea=aa}aa=s+(ea>>>3)|0;Y=(je(d[aa]|d[aa+1|0]<<8|d[aa+2|0]<<16|d[aa+3|0]<<24|0)|0)<<(ea&7)>>>30;aa=ea+2|0;ea=o>>>0>aa>>>0?aa:o;c[m>>2]=ea;aa=f+136|0;c[aa>>2]=Y;Y=ea&7;$=d[s+(ea>>>3)|0]|0;_=((ea|0)<(o|0))+ea|0;c[m>>2]=_;ea=d[s+(_>>>3)|0]<<(_&7)>>>7;W=((_|0)<(o|0))+_|0;c[m>>2]=W;_=ea&1;c[f+140>>2]=_;if((_|0)==0){mrc(f+54464|0,0,28)|0}_=d[s+(W>>>3)|0]<<(W&7)>>>7;c[m>>2]=((W|0)<(o|0))+W;W=_&1;c[f+144>>2]=W;do{if((W|0)==0){_=f+44924|0;if((c[_>>2]|0)<1){break}else{fa=1}do{c[f+54176+(fa<<2)>>2]=1;fa=fa+1|0;}while((fa|0)<=(c[_>>2]|0))}}while(0);fa=f+44932|0;c[f+54176+(c[fa>>2]<<2)>>2]=0;c[f+54176>>2]=0;W=c[m>>2]|0;_=c[r>>2]|0;o=d[_+(W>>>3)|0]<<(W&7)>>>7;s=c[n>>2]|0;ea=((W|0)<(s|0))+W|0;c[m>>2]=ea;W=o&1;c[f+148>>2]=W;if((W|0)==0){c[f+47092>>2]=d[1443274]|0;c[f+47096>>2]=d[1444369]|0;c[f+47088>>2]=e[721633]|0;c[f+47100>>2]=e[722430]|0;c[f+47104>>2]=b[722123]|0}W=d[_+(ea>>>3)|0]<<(ea&7)>>>7;o=((ea|0)<(s|0))+ea|0;c[m>>2]=o;c[f+152>>2]=W&1;W=d[_+(o>>>3)|0]<<(o&7)>>>7;ea=((o|0)<(s|0))+o|0;c[m>>2]=ea;c[f+156>>2]=W&1;W=d[_+(ea>>>3)|0]<<(ea&7)>>>7;o=((ea|0)<(s|0))+ea|0;c[m>>2]=o;c[f+160>>2]=W&1;W=o&7;ea=d[_+(o>>>3)|0]|0;c[m>>2]=((o|0)<(s|0))+o;do{if((c[p>>2]|0)>1){if((c[C>>2]|0)>0){ga=0;ha=0}else{ia=0;break}while(1){do{if((ha|0)==0){c[f+188>>2]=1;U=80}else{o=c[m>>2]|0;s=d[(c[r>>2]|0)+(o>>>3)|0]<<(o&7);c[m>>2]=((o|0)<(c[n>>2]|0))+o;o=s&128;c[f+188+(ha<<2)>>2]=o>>>7;if((o|0)!=0){U=80;break}o=c[f+164+(ha-1<<2)>>2]|0;c[f+164+(ha<<2)>>2]=o;ja=o}}while(0);if((U|0)==80){U=0;o=c[m>>2]|0;s=d[(c[r>>2]|0)+(o>>>3)|0]<<(o&7)>>>7;c[m>>2]=((o|0)<(c[n>>2]|0))+o;o=s&1;c[f+164+(ha<<2)>>2]=o;ja=o}o=ja+ga|0;s=ha+1|0;if((s|0)<(c[C>>2]|0)){ga=o;ha=s}else{ia=o;break}}}else{mrc(f+164|0,0,24)|0;ia=0}}while(0);do{if((ba|0)==0){if((c[p>>2]|0)>1){ka=(ia|0)==0|0}else{ka=1}ha=f+44924|0;if((ka|0)>(c[ha>>2]|0)){break}else{la=ka}do{ga=c[m>>2]|0;ja=c[n>>2]|0;o=(c[r>>2]|0)+(ga>>>3)|0;s=(je(d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0)|0)<<(ga&7)>>>27;o=ga+5|0;c[m>>2]=ja>>>0>o>>>0?o:ja;c[f+46912+(la<<2)>>2]=d[1392832+(s*6|0)|0]|0;c[f+46940+(la<<2)>>2]=d[1392833+(s*6|0)|0]|0;c[f+46968+(la<<2)>>2]=d[1392834+(s*6|0)|0]|0;c[f+46996+(la<<2)>>2]=d[1392835+(s*6|0)|0]|0;c[f+47024+(la<<2)>>2]=d[1392836+(s*6|0)|0]|0;c[f+47052+(la<<2)>>2]=d[1392837+(s*6|0)|0]|0;la=la+1|0;}while((la|0)<=(c[ha>>2]|0))}else{ha=c[C>>2]|0;if((ha|0)<=0){break}s=f+44924|0;ja=0;o=c[s>>2]|0;ga=ha;while(1){ha=(c[f+164+(ja<<2)>>2]|0)==0|0;if((ha|0)>(o|0)){ma=o;na=ga}else{_=ha;do{ha=c[m>>2]|0;Z=c[n>>2]|0;X=(c[r>>2]|0)+(ha>>>3)|0;z=(je(d[X]|d[X+1|0]<<8|d[X+2|0]<<16|d[X+3|0]<<24|0)|0)<<(ha&7)>>>30;X=ha+2|0;c[m>>2]=Z>>>0>X>>>0?X:Z;c[f+46912+(ja*28|0)+(_<<2)>>2]=z;_=_+1|0;oa=c[s>>2]|0;}while((_|0)<=(oa|0));ma=oa;na=c[C>>2]|0}_=ja+1|0;if((_|0)<(na|0)){ja=_;o=ma;ga=na}else{break}}}}while(0);do{if((c[f+64>>2]|0)!=0){if((c[C>>2]|0)>0){pa=0}else{break}do{na=c[m>>2]|0;ma=d[(c[r>>2]|0)+(na>>>3)|0]<<(na&7)>>>7;c[m>>2]=((na|0)<(c[n>>2]|0))+na;c[f+46912+(pa*28|0)+(c[fa>>2]<<2)>>2]=ma&1;pa=pa+1|0;}while((pa|0)<(c[C>>2]|0))}}while(0);do{if((c[h>>2]|0)==0){pa=c[m>>2]|0;if((c[C>>2]|0)==6){qa=pa;ra=c[n>>2]|0}else{fa=d[(c[r>>2]|0)+(pa>>>3)|0]|0;ma=c[n>>2]|0;na=((pa|0)<(ma|0))+pa|0;c[m>>2]=na;if((fa&128>>>((pa&7)>>>0)|0)==0){break}else{qa=na;ra=ma}}ma=qa+((c[f+44924>>2]|0)*5|0)|0;c[m>>2]=ra>>>0>ma>>>0?ma:ra}}while(0);ra=f+1888|0;do{if((da|0)==0){mrc(ra|0,0,28)|0}else{c[ra>>2]=0;qa=(ia|0)!=6|0;h=f+44928|0;if((qa|0)>(c[h>>2]|0)){break}else{sa=qa}do{do{if((sa|0)==0){if((c[f+46940>>2]|0)!=0){ta=0;break}if((c[f+192>>2]|0)!=0){ta=0;break}if((c[f+46968>>2]|0)!=0){ta=0;break}if((c[f+196>>2]|0)!=0){ta=0;break}if((c[f+46996>>2]|0)!=0){ta=0;break}if((c[f+200>>2]|0)!=0){ta=0;break}if((c[f+47024>>2]|0)!=0){ta=0;break}if((c[f+204>>2]|0)!=0){ta=0;break}if((c[f+47052>>2]|0)!=0){ta=0;break}if((c[f+208>>2]|0)==0){U=111}else{ta=0}}else{if((c[f+46940+(sa<<2)>>2]|0)!=0){ta=0;break}if((c[f+46968+(sa<<2)>>2]|0)!=0){ta=0;break}if((c[f+46996+(sa<<2)>>2]|0)!=0){ta=0;break}if((c[f+47024+(sa<<2)>>2]|0)!=0){ta=0;break}if((c[f+47052+(sa<<2)>>2]|0)==0){U=111}else{ta=0}}}while(0);if((U|0)==111){U=0;qa=c[m>>2]|0;ma=d[(c[r>>2]|0)+(qa>>>3)|0]<<(qa&7);c[m>>2]=((qa|0)<(c[n>>2]|0))+qa;ta=ma>>>7&1}c[f+1888+(sa<<2)>>2]=ta;sa=sa+1|0;}while((sa|0)<=(c[h>>2]|0))}}while(0);do{if((c[aa>>2]|0)==0){sa=c[m>>2]|0;ta=c[n>>2]|0;ia=c[r>>2]|0;ra=ia+(sa>>>3)|0;da=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>26;ra=sa+6|0;sa=ta>>>0>ra>>>0?ra:ta;c[m>>2]=sa;ra=ia+(sa>>>3)|0;ia=(je(d[ra]|d[ra+1|0]<<8|d[ra+2|0]<<16|d[ra+3|0]<<24|0)|0)<<(sa&7)>>>28;ra=sa+4|0;c[m>>2]=ta>>>0>ra>>>0?ra:ta;ta=(ia|(da<<4)+1073741584)<<2;da=f+44928|0;if((c[da>>2]|0)<0){break}else{ua=0}do{c[f+47120+(ua<<2)>>2]=ta;ua=ua+1|0;}while((ua|0)<=(c[da>>2]|0))}}while(0);ua=c[f+44924>>2]|0;do{if(($&128>>>(Y>>>0)|0)==0){U=121}else{if((ua|0)<1){va=ua;wa=f+44924|0;break}aa=c[r>>2]|0;da=c[n>>2]|0;ta=1;ia=c[m>>2]|0;while(1){ra=((ia|0)<(da|0))+ia|0;if((d[aa+(ia>>>3)|0]&128>>>((ia&7)>>>0)|0)==0){xa=ra}else{sa=ra+10|0;ra=(da>>>0>sa>>>0?sa:da)+8|0;xa=da>>>0>ra>>>0?ra:da}c[m>>2]=xa;ra=ta+1|0;if((ra|0)>(ua|0)){U=121;break}else{ta=ra;ia=xa}}}}while(0);a:do{if((U|0)==121){xa=f+44924|0;if((ua|0)<1){va=ua;wa=xa;break}if((ea&128>>>(W>>>0)|0)==0){Y=1;while(1){a[f+887+Y|0]=-1;$=c[xa>>2]|0;ia=Y+1|0;if((ia|0)>($|0)){va=$;wa=xa;break a}else{Y=ia}}}else{ya=1}while(1){Y=c[m>>2]|0;ia=c[r>>2]|0;$=d[ia+(Y>>>3)|0]|0;ta=c[n>>2]|0;da=((Y|0)<(ta|0))+Y|0;c[m>>2]=da;if(($&128>>>((Y&7)>>>0)|0)==0){a[f+887+ya|0]=-1}else{Y=ia+(da>>>3)|0;ia=(je(d[Y]|d[Y+1|0]<<8|d[Y+2|0]<<16|d[Y+3|0]<<24|0)|0)<<(da&7)>>>27;Y=da+5|0;c[m>>2]=ta>>>0>Y>>>0?Y:ta;a[f+887+ya|0]=ia}ia=ya+1|0;ta=c[xa>>2]|0;if((ia|0)>(ta|0)){va=ta;wa=xa;break}else{ya=ia}}}}while(0);ya=c[C>>2]|0;do{if((ya|0)>1){C=c[m>>2]|0;W=d[(c[r>>2]|0)+(C>>>3)|0]|0;ea=c[n>>2]|0;ua=((C|0)<(ea|0))+C|0;c[m>>2]=ua;if((W&128>>>((C&7)>>>0)|0)==0){za=va;break}C=(c[f+36>>2]|0)-2|0;W=C>>>0>65535>>>0;U=W?C>>>16:C;C=W?16:0;if((U&65280|0)==0){Aa=C;Ba=U}else{Aa=C|8;Ba=U>>>8}U=ca(Aa+4+(d[1359664+Ba|0]|0)|0,ya-1|0)|0;C=-ua|0;W=ea-ua|0;if((U|0)<(C|0)){Ca=C}else{Ca=(W|0)<(U|0)?W:U}c[m>>2]=Ca+ua;QIb(c[f+4>>2]|0,2238680,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k;za=c[wa>>2]|0}else{za=va}}while(0);if((za|0)>=1){za=1;do{a[f+929+za|0]=1;c[f+344+(za<<2)>>2]=1;za=za+1|0;}while((za|0)<=(c[wa>>2]|0))}c[f+47116>>2]=1;l=0;i=g;return l|0}return 0}function wpb(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=i;i=i+128|0;g=f|0;b[e>>1]=(b[e>>1]|0)+4;h=0;while(1){j=g+(h<<1)|0;k=e+(h<<1)|0;l=h+8|0;m=b[e+(l<<1)>>1]|0;n=m<<16>>16;o=h+16|0;p=b[e+(o<<1)>>1]|0;q=p<<16>>16;r=h+24|0;s=b[e+(r<<1)>>1]|0;t=s<<16>>16;u=h+32|0;v=b[e+(u<<1)>>1]|0;w=v<<16>>16;x=h+40|0;y=b[e+(x<<1)>>1]|0;z=y<<16>>16;A=h+48|0;B=b[e+(A<<1)>>1]|0;C=B<<16>>16;D=h+56|0;E=b[e+(D<<1)>>1]|0;F=E<<16>>16;if((p|m|s|v|y|B|E)<<16>>16==0){E=b[k>>1]|0;b[g+(D<<1)>>1]=E;b[g+(A<<1)>>1]=E;b[g+(x<<1)>>1]=E;b[g+(u<<1)>>1]=E;b[g+(r<<1)>>1]=E;b[g+(o<<1)>>1]=E;b[g+(l<<1)>>1]=E;b[j>>1]=E}else{E=F+n|0;B=n-F|0;F=z+t|0;n=z-t|0;t=C+q|0;z=((q-C|0)*181|0)>>8;C=b[k>>1]|0;k=C+w|0;q=C-w|0;w=(B*473|0)+(n*-196|0)>>9;C=E+F+w|0;y=((E-F|0)*181|0)>>8;F=w+y|0;w=(B*196|0)+(n*473|0)>>9;n=w+y|0;y=z+t+k|0;b[j>>1]=y+C;j=q+z|0;b[g+(l<<1)>>1]=j+F;l=q-z|0;b[g+(o<<1)>>1]=l+n;o=k-t-z|0;b[g+(r<<1)>>1]=o+w;b[g+(u<<1)>>1]=o-w;b[g+(x<<1)>>1]=l-n;b[g+(A<<1)>>1]=j-F;b[g+(D<<1)>>1]=y-C}C=h+1|0;if((C|0)<8){h=C}else{G=0;break}}do{h=G<<3;e=b[g+((h|1)<<1)>>1]|0;C=b[g+((h|7)<<1)>>1]|0;y=C+e|0;D=e-C|0;C=b[g+((h|5)<<1)>>1]|0;e=b[g+((h|3)<<1)>>1]|0;F=e+C|0;j=C-e|0;e=b[g+((h|2)<<1)>>1]|0;C=b[g+((h|6)<<1)>>1]|0;A=C+e|0;n=((e-C|0)*181|0)>>8;C=b[g+(h<<1)>>1]|0;e=b[g+((h|4)<<1)>>1]|0;h=e+C|0;l=C-e|0;e=(j*-196|0)+(D*473|0)>>9;C=F+y+e|0;x=((y-F|0)*181|0)>>8;F=e+x|0;e=(j*473|0)+(D*196|0)>>9;D=e+x|0;x=h+A+n|0;j=x+C>>4;if(j>>>0>255>>>0){H=-j>>31&255}else{H=j&255}j=ca(G,d)|0;a[c+j|0]=H;y=l+n|0;w=y+F>>4;if(w>>>0>255>>>0){I=-w>>31&255}else{I=w&255}a[c+(j+1)|0]=I;w=l-n|0;l=w+D>>4;if(l>>>0>255>>>0){J=-l>>31&255}else{J=l&255}a[c+(j+2)|0]=J;l=h-A-n|0;n=l+e>>4;if(n>>>0>255>>>0){K=-n>>31&255}else{K=n&255}a[c+(j+3)|0]=K;n=l-e>>4;if(n>>>0>255>>>0){L=-n>>31&255}else{L=n&255}a[c+(j+4)|0]=L;n=w-D>>4;if(n>>>0>255>>>0){M=-n>>31&255}else{M=n&255}a[c+(j+5)|0]=M;n=y-F>>4;if(n>>>0>255>>>0){N=-n>>31&255}else{N=n&255}a[c+(j+6)|0]=N;n=x-C>>4;if(n>>>0>255>>>0){O=-n>>31&255}else{O=n&255}a[c+(j+7)|0]=O;G=G+1|0;}while((G|0)<8);i=f;return}function xpb(a){a=a|0;if((c[(c[a>>2]|0)+684>>2]|0)==0){return}mrc(c[a+40>>2]|0,127,ca(c[a+20>>2]|0,c[a+24>>2]|0)|0)|0;c[a+32>>2]=(c[a+12>>2]|0)*3|0;c[a+36>>2]=0;return}function ypb(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=i;l=b+16|0;m=c[l>>2]|0;n=(ca(m,f)|0)+e|0;e=b+12|0;f=c[e>>2]|0;o=f-1|0;if((n|0)<0){p=0}else{p=(n|0)>(o|0)?o:n}n=(ca(m,h)|0)+g|0;if((n|0)<0){q=0}else{q=(n|0)>(f|0)?f:n}n=b+8|0;f=c[n>>2]|0;g=c[f+(p<<2)>>2]|0;h=c[f+(q<<2)>>2]|0;f=b|0;m=c[f>>2]|0;o=c[m+712>>2]|0;do{if((o|0)!=0){if((c[o+28>>2]|0)==0){break}i=k;return}}while(0);if((p|0)>(q|0)|(g|0)>(h|0)){KIb(m,16,2425920,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;i=k;return}if((c[m+684>>2]|0)==0){i=k;return}if((j&18|0)==0){r=-2}else{m=b+32|0;c[m>>2]=p-1-q+(c[m>>2]|0);r=-20}if((j&36|0)==0){s=r}else{m=b+32|0;c[m>>2]=p-1-q+(c[m>>2]|0);s=r&-38}if((j&72|0)==0){t=s}else{r=b+32|0;c[r>>2]=p-1-q+(c[r>>2]|0);t=s&-73}if((j&14|0)!=0){c[b+36>>2]=1;c[b+32>>2]=2147483647}do{if((t|0)==-128){mrc((c[b+40>>2]|0)+g|0,0,h-g|0)|0}else{if((g|0)>=(h|0)){break}s=b+40|0;r=g;do{m=(c[s>>2]|0)+r|0;a[m]=(d[m]|0)&t;r=r+1|0;}while((r|0)<(h|0))}}while(0);if((q|0)==(c[e>>2]|0)){c[b+32>>2]=2147483647;u=b+40|0}else{e=b+40|0;q=(c[e>>2]|0)+h|0;a[q]=(d[q]|0)&t;t=(c[e>>2]|0)+h|0;a[t]=d[t]|0|j;u=e}e=(c[u>>2]|0)+g|0;a[e]=a[e]|1;if((g|0)<=0){i=k;return}g=c[f>>2]|0;if((c[g+816>>2]&2|0)!=0){i=k;return}f=c[g+712>>2]|0;do{if((f|0)!=0){if((c[f+28>>2]|0)==0){break}i=k;return}}while(0);if((c[(c[g+12>>2]|0)+16>>2]&128|0)!=0){i=k;return}f=c[b+132>>2]|0;if((f|0)==0){i=k;return}if((c[f+2164>>2]|0)!=0){i=k;return}if((ca(c[l>>2]|0,c[g+328>>2]|0)|0)>=(p|0)){i=k;return}if((a[(c[u>>2]|0)+(c[(c[n>>2]|0)+(p-1<<2)>>2]|0)|0]&-2)<<24>>24==112){i=k;return}c[b+36>>2]=1;c[b+32>>2]=2147483647;i=k;return}function zpb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0;g=i;i=i+96|0;h=g|0;j=g+64|0;k=f+132|0;l=c[k>>2]|0;m=l+32|0;n=f+28|0;o=c[n>>2]|0;p=f+20|0;q=c[p>>2]|0;r=f|0;s=c[r>>2]|0;if((c[s+684>>2]|0)==0){i=g;return}t=c[f+32>>2]|0;if((t|0)==0){i=g;return}if((c[s+800>>2]|0)!=0){i=g;return}u=c[s+712>>2]|0;do{if((u|0)!=0){if((c[u+28>>2]|0)==0){break}i=g;return}}while(0);if((c[(c[s+12>>2]|0)+16>>2]&128|0)!=0|(l|0)==0){i=g;return}if((c[l+2164>>2]|0)!=0){i=g;return}u=f+16|0;v=c[u>>2]|0;w=v*3|0;x=c[s+328>>2]|0;y=c[s+332>>2]|0;if((t|0)==(ca(w,y+x|0)|0)){i=g;return}z=f+24|0;A=f+40|0;B=0;while(1){if((B|0)>=(v|0)){break}C=(ca(q-1|0,c[z>>2]|0)|0)+B|0;if((a[(c[A>>2]|0)+C|0]|0)==127){B=B+1|0}else{break}}do{if((B|0)==(v|0)){if((c[s+48>>2]|0)!=2){break}if((c[s+124>>2]&16|0)==0){break}if((t|0)!=(ca(w,x+1+y|0)|0)){break}KIb(s,48,2581464,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;i=g;return}}while(0);y=f+136|0;x=c[y>>2]|0;a:do{if((x|0)!=0){do{if((c[x+68>>2]|0)==(c[l+68>>2]|0)){if((c[x+72>>2]|0)!=(c[l+72>>2]|0)){break}if((c[x+80>>2]|0)==(c[l+80>>2]|0)){break a}}}while(0);KIb(s,24,2437488,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;c[y>>2]=0}}while(0);s=f+140|0;x=c[s>>2]|0;b:do{if((x|0)!=0){w=c[k>>2]|0;do{if((c[x+68>>2]|0)==(c[w+68>>2]|0)){if((c[x+72>>2]|0)!=(c[w+72>>2]|0)){break}if((c[x+80>>2]|0)==(c[w+80>>2]|0)){break b}}}while(0);KIb(c[r>>2]|0,24,2350400,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;c[s>>2]=0}}while(0);c:do{if((c[(c[k>>2]|0)+1524>>2]|0)==0){KIb(c[r>>2]|0,16,2288832,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;x=(ca(o<<3,q)|0)+16|0;w=dGb(ca(c[z>>2]<<2,c[p>>2]|0)|0)|0;c[(c[k>>2]|0)+1548>>2]=w;w=dGb(x)|0;c[(c[k>>2]|0)+1516>>2]=w;w=c[k>>2]|0;t=c[w+1548>>2]|0;do{if((t|0)==0){E=w}else{if((c[w+1516>>2]|0)==0){E=w;break}c[w+1556>>2]=c[t+4>>2];v=c[k>>2]|0;c[v+1524>>2]=(c[(c[v+1516>>2]|0)+4>>2]|0)+16;v=dGb(ca(c[z>>2]<<2,c[p>>2]|0)|0)|0;c[(c[k>>2]|0)+1552>>2]=v;v=dGb(x)|0;c[(c[k>>2]|0)+1520>>2]=v;v=c[k>>2]|0;B=c[v+1552>>2]|0;if((B|0)==0){E=v;break}if((c[v+1520>>2]|0)==0){E=v;break}c[v+1560>>2]=c[B+4>>2];B=c[k>>2]|0;c[B+1528>>2]=(c[(c[B+1520>>2]|0)+4>>2]|0)+16;break c}}while(0);fGb(E+1548|0);fGb((c[k>>2]|0)+1516|0);c[(c[k>>2]|0)+1556>>2]=0;c[(c[k>>2]|0)+1524>>2]=0;fGb((c[k>>2]|0)+1552|0);fGb((c[k>>2]|0)+1520|0);c[(c[k>>2]|0)+1560>>2]=0;c[(c[k>>2]|0)+1528>>2]=0;i=g;return}}while(0);do{if((c[(c[r>>2]|0)+688>>2]&1024|0)!=0){if((c[p>>2]|0)>0){F=0}else{break}do{if((c[u>>2]|0)>0){E=0;do{q=(ca(c[z>>2]|0,F)|0)+E|0;KIb(c[r>>2]|0,48,2238672,(D=i,i=i+8|0,c[D>>2]=d[(c[A>>2]|0)+q|0]|0,D)|0);i=D;E=E+1|0;}while((E|0)<(c[u>>2]|0))}KIb(c[r>>2]|0,48,2197896,(D=i,i=i+1|0,i=i+7&-8,c[D>>2]=0,D)|0);i=D;F=F+1|0;}while((F|0)<(c[p>>2]|0))}}while(0);F=f+12|0;E=f+8|0;q=c[F>>2]|0;d:do{if((q|0)>0){o=0;x=q;while(1){t=x-1|0;w=(c[A>>2]|0)+(c[(c[E>>2]|0)+(t<<2)>>2]|0)|0;B=a[w]|0;v=B&255;C=(v&16|0)==0?(v&2|0)==0?o:1:1;if((C|0)==0){a[w]=B|2}if((t|0)<=0){break}o=(v&1|0)==0?C:0;x=t}x=c[F>>2]|0;if((x|0)>0){G=0;H=x}else{break}while(1){x=H-1|0;o=(c[A>>2]|0)+(c[(c[E>>2]|0)+(x<<2)>>2]|0)|0;t=a[o]|0;C=t&255;v=(C&32|0)==0?(C&4|0)==0?G:1:1;if((v|0)==0){a[o]=t|4}if((x|0)<=0){break}G=(C&1|0)==0?v:0;H=x}x=c[F>>2]|0;if((x|0)>0){I=0;J=x}else{break}while(1){x=J-1|0;v=(c[A>>2]|0)+(c[(c[E>>2]|0)+(x<<2)>>2]|0)|0;C=a[v]|0;t=C&255;o=(t&64|0)==0?(t&8|0)==0?I:1:1;if((o|0)==0){a[v]=C|8}if((x|0)<=0){break d}I=(t&1|0)==0?o:0;J=x}}}while(0);J=f+152|0;e:do{if((c[J>>2]|0)!=0){I=c[F>>2]|0;if((I|0)>0){K=0;L=I}else{break}while(1){I=L-1|0;H=(c[A>>2]|0)+(c[(c[E>>2]|0)+(I<<2)>>2]|0)|0;G=a[H]|0;q=G&255;x=(q&98|0)==0?(q&16|0)==0?K:0:1;if((x|0)==0){a[H]=G|2}if((I|0)<=0){break e}K=(q&1|0)==0?x:0;L=I}}}while(0);do{if((c[(c[r>>2]|0)+696>>2]&8|0)==0){M=49}else{L=c[F>>2]|0;K=L-2|0;I=c[u>>2]|0;if((K|0)<(I+100|0)){N=L;break}else{O=1;P=K;Q=I}while(1){I=c[E>>2]|0;K=c[A>>2]|0;L=K+(c[I+(P<<2)>>2]|0)|0;x=a[L]|0;q=x&255;G=(q&1|0)==0?O:1;if((a[K+(c[I+(P+1<<2)>>2]|0)|0]|0)!=127|x<<24>>24==127){R=G}else{R=(q&112|0)==0?G:0}if((R|0)==0){a[L]=x|14;S=c[u>>2]|0}else{S=Q}x=P-1|0;if((x|0)<(S+100|0)){M=49;break}else{O=R;P=x;Q=S}}}}while(0);if((M|0)==49){N=c[F>>2]|0}S=f+60|0;do{if((N|0)>0){Q=9999999;P=N;do{P=P-1|0;R=c[(c[E>>2]|0)+(P<<2)>>2]|0;O=(c[A>>2]|0)+R|0;x=a[O]|0;L=x&255;G=(L&2|0)==0?((a[(c[S>>2]|0)+R|0]|0)==0)+Q|0:0;do{if((c[J>>2]|0)==0){if((G|0)>=50){break}a[O]=x|2}else{if((G|0)>=100){break}a[O]=x|2}}while(0);Q=(L&1|0)==0?G:9999999;}while((P|0)>0);P=c[F>>2]|0;if((P|0)>0){T=Q;U=P}else{V=P;break}do{U=U-1|0;P=c[(c[E>>2]|0)+(U<<2)>>2]|0;x=(c[A>>2]|0)+P|0;O=a[x]|0;R=O&255;q=(R&4|0)==0?((a[(c[S>>2]|0)+P|0]|0)==0)+T|0:0;do{if((c[J>>2]|0)==0){if((q|0)>=50){break}a[x]=O|4}else{if((q|0)>=100){break}a[x]=O|4}}while(0);T=(R&1|0)==0?q:9999999;}while((U|0)>0);Q=c[F>>2]|0;if((Q|0)>0){W=T;X=Q}else{V=Q;break}while(1){Q=X-1|0;O=c[(c[E>>2]|0)+(Q<<2)>>2]|0;x=(c[A>>2]|0)+O|0;G=a[x]|0;L=G&255;P=(L&8|0)==0?((a[(c[S>>2]|0)+O|0]|0)==0)+W|0:0;do{if((c[J>>2]|0)==0){if((P|0)>=50){break}a[x]=G|8}else{if((P|0)>=100){break}a[x]=G|8}}while(0);if((Q|0)<=0){break}W=(L&1|0)==0?P:9999999;X=Q}G=c[F>>2]|0;if((G|0)>0){Y=0;Z=0;_=G}else{V=G;break}while(1){G=(c[A>>2]|0)+(c[(c[E>>2]|0)+(Z<<2)>>2]|0)|0;x=d[G]|0;q=x&14;if((x&1|0)==0){a[G]=x|Y;$=q|Y;aa=c[F>>2]|0}else{$=q;aa=_}q=Z+1|0;if((q|0)<(aa|0)){Y=$;Z=q;_=aa}else{V=aa;break}}}else{V=N}}while(0);do{if((c[J>>2]|0)==0){if((V|0)>0){ba=0}else{da=0;ea=0;fa=0;break}while(1){N=(c[A>>2]|0)+(c[(c[E>>2]|0)+(ba<<2)>>2]|0)|0;aa=a[N]|0;a[N]=(aa&14)==0?aa:aa|14;aa=ba+1|0;N=c[F>>2]|0;if((aa|0)<(N|0)){ba=aa}else{ga=N;M=69;break}}}else{ga=V;M=69}}while(0);do{if((M|0)==69){if((ga|0)<=0){da=0;ea=0;fa=0;break}V=c[E>>2]|0;ba=c[A>>2]|0;N=0;aa=0;_=0;Z=0;while(1){$=d[ba+(c[V+(Z<<2)>>2]|0)|0]|0;Y=($>>>2&1)+_|0;X=($>>>1&1)+N|0;W=($>>>3&1)+aa|0;$=Z+1|0;if(($|0)<(ga|0)){N=X;aa=W;_=Y;Z=$}else{da=X;ea=W;fa=Y;break}}}}while(0);ga=c[r>>2]|0;Z=(BLb(c[(c[k>>2]|0)+88>>2]|0)|0)<<24>>24;KIb(ga,32,2166272,(D=i,i=i+32|0,c[D>>2]=fa,c[D+8>>2]=da,c[D+16>>2]=ea,c[D+24>>2]=Z,D)|0);i=D;Z=c[y>>2]|0;do{if((Z|0)==0){ha=1}else{if((c[Z>>2]|0)==0){ha=1;break}ea=c[F>>2]|0;if((ea|0)>0){da=c[E>>2]|0;fa=c[A>>2]|0;ga=0;_=0;while(1){aa=((a[fa+(c[da+(_<<2)>>2]|0)|0]&12)!=12)+ga|0;N=_+1|0;if((N|0)<(ea|0)){ga=aa;_=N}else{ia=aa;break}}}else{ia=0}if((c[(c[r>>2]|0)+48>>2]|0)==28){if((c[f+156>>2]|0)<1){ha=1;break}}if((ia|0)<5){ha=0;break}if((ia|0)>99){ja=(ia|0)/50|0}else{ja=1}_=c[p>>2]|0;if((_-1|0)>0){ga=f+4|0;ea=0;da=0;fa=0;aa=c[u>>2]|0;N=_;while(1){if((aa|0)>0){_=ea<<4;V=0;ba=da;Y=fa;W=aa;while(1){X=(ca(c[z>>2]|0,ea)|0)+V|0;do{if((a[(c[A>>2]|0)+X|0]&12)==12){ka=Y;la=ba;ma=W}else{$=ba+1|0;if((($|0)%(ja|0)|0|0)!=0){ka=Y;la=$;ma=W;break}T=c[k>>2]|0;if((c[T+88>>2]|0)==1){U=T+32|0;q=c[U>>2]|0;x=(ca(_,q)|0)+(V<<4)|0;G=(c[T>>2]|0)+x|0;R=c[y>>2]|0;O=c[R>>2]|0;I=O+x|0;if((c[(c[r>>2]|0)+48>>2]|0)==28){na=q}else{M5a(R+1496|0,ea,0);na=c[U>>2]|0}R=(Xe[c[(c[ga>>2]|0)+52>>2]&511](0,I,G,na,16)|0)+Y|0;G=c[U>>2]|0;U=R-(Xe[c[(c[ga>>2]|0)+52>>2]&511](0,I,O+((G<<4)+x)|0,G,16)|0)|0;ka=U;la=$;ma=c[u>>2]|0;break}else{if((c[(c[T+1536>>2]|0)+(X<<2)>>2]&7|0)==0){ka=Y-1|0;la=$;ma=W;break}else{ka=Y+1|0;la=$;ma=W;break}}}}while(0);X=V+1|0;if((X|0)<(ma|0)){V=X;ba=la;Y=ka;W=ma}else{break}}oa=la;pa=ka;qa=ma;ra=c[p>>2]|0}else{oa=da;pa=fa;qa=aa;ra=N}W=ea+1|0;if((W|0)<(ra-1|0)){ea=W;da=oa;fa=pa;aa=qa;N=ra}else{sa=pa;break}}}else{sa=0}ha=(sa|0)>0|0}}while(0);sa=c[F>>2]|0;if((sa|0)>0){pa=(ha|0)==0;ha=c[E>>2]|0;ra=c[A>>2]|0;qa=0;while(1){oa=c[ha+(qa<<2)>>2]|0;do{if((a[ra+oa|0]&12)==12){ma=(c[(c[k>>2]|0)+1536>>2]|0)+(oa<<2)|0;if(pa){c[ma>>2]=12296;break}else{c[ma>>2]=1;break}}}while(0);oa=qa+1|0;ma=c[F>>2]|0;if((oa|0)<(ma|0)){qa=oa}else{ta=ma;break}}}else{ta=sa}sa=c[y>>2]|0;if((sa|0)==0){M=109}else{if((c[sa>>2]|0)==0){M=109}}do{if((M|0)==109){sa=c[s>>2]|0;if((sa|0)==0){if((ta|0)<=0){break}}else{if(!((c[sa>>2]|0)==0&(ta|0)>0)){break}}sa=c[E>>2]|0;qa=c[(c[k>>2]|0)+1536>>2]|0;pa=0;ra=ta;while(1){ha=qa+(c[sa+(pa<<2)>>2]<<2)|0;if((c[ha>>2]&7|0)==0){c[ha>>2]=1;ua=c[F>>2]|0}else{ua=ra}ha=pa+1|0;if((ha|0)<(ua|0)){pa=ha;ra=ua}else{break}}}}while(0);ua=c[p>>2]|0;if((ua|0)>0){ta=f+68|0;ra=f+72|0;pa=f+160|0;sa=f+164|0;qa=f+68|0;ha=0;ma=c[u>>2]|0;oa=ua;while(1){if((ma|0)>0){ka=ha<<1;la=0;na=ma;while(1){ja=(ca(c[z>>2]|0,ha)|0)+la|0;ia=c[k>>2]|0;Z=c[(c[ia+1536>>2]|0)+(ja<<2)>>2]|0;N=c[y>>2]|0;if((N|0)==0){va=1}else{va=(c[N>>2]|0)==0}N=va&1;aa=va?2:1;do{if((Z&7|0)==0){if(!((a[(c[A>>2]|0)+ja|0]&10)==2)){wa=na;break}fa=c[n>>2]|0;da=(ca(fa,ka)|0)+(la<<1)|0;ea=c[ia+1524+(N<<2)>>2]|0;c[ta>>2]=b[ea+(da<<2)>>1]|0;c[ra>>2]=b[ea+(da<<2)+2>>1]|0;if((Z&64|0)==0){xa=0}else{ga=da|1;c[f+76>>2]=b[ea+(ga<<2)>>1]|0;c[f+80>>2]=b[ea+(ga<<2)+2>>1]|0;W=fa+da|0;c[f+84>>2]=b[ea+(W<<2)>>1]|0;c[f+88>>2]=b[ea+(W<<2)+2>>1]|0;W=fa+ga|0;c[f+92>>2]=b[ea+(W<<2)>>1]|0;c[f+96>>2]=b[ea+(W<<2)+2>>1]|0;xa=1}Te[c[pa>>2]&255](c[sa>>2]|0,0,aa,xa,qa,la,ha,0,0);wa=c[u>>2]|0}else{wa=na}}while(0);aa=la+1|0;if((aa|0)<(wa|0)){la=aa;na=wa}else{break}}ya=wa;za=c[p>>2]|0}else{ya=ma;za=oa}na=ha+1|0;if((na|0)<(za|0)){ha=na;ma=ya;oa=za}else{Aa=za;break}}}else{Aa=ua}ua=c[k>>2]|0;f:do{if((c[ua+88>>2]|0)==3){if((Aa|0)<=0){Ba=Aa;M=266;break}za=f+144|0;oa=f+68|0;ya=f+72|0;ma=f+100|0;ha=f+104|0;wa=f+160|0;qa=f+164|0;xa=f+68|0;sa=f+146|0;pa=0;ra=c[u>>2]|0;ta=Aa;g:while(1){if((ra|0)>0){va=pa<<1;na=0;la=ra;while(1){ka=(ca(va,c[n>>2]|0)|0)+(na<<1)|0;aa=(ca(c[z>>2]|0,pa)|0)+na|0;do{if((c[(c[(c[k>>2]|0)+1536>>2]|0)+(aa<<2)>>2]&7|0)==0){if(!((a[(c[A>>2]|0)+aa|0]&10)==10)){Ca=la;break}Z=c[y>>2]|0;if((Z|0)==0){M=139}else{if((c[Z>>2]|0)==0){M=139}else{Da=3}}if((M|0)==139){M=0;Da=2}Z=c[s>>2]|0;if((Z|0)==0){M=142}else{if((c[Z>>2]|0)==0){M=142}else{Ea=Da}}if((M|0)==142){M=0;Ea=Da&1}N=b[za>>1]|0;if(N<<16>>16==0){c[oa>>2]=0;c[ya>>2]=0;c[ma>>2]=0;Fa=0}else{ia=N&65535;N=e[sa>>1]|0;if((c[(c[r>>2]|0)+48>>2]|0)==28){break g}M5a(Z+1496|0,pa,0);Z=c[(c[s>>2]|0)+1524>>2]|0;ja=b[Z+(ka<<2)>>1]|0;c[oa>>2]=(ca(ja,N)|0)/(ia|0)|0;W=b[Z+(ka<<2)+2>>1]|0;c[ya>>2]=(ca(W,N)|0)/(ia|0)|0;Z=N-ia|0;c[ma>>2]=(ca(ja,Z)|0)/(ia|0)|0;Fa=(ca(W,Z)|0)/(ia|0)|0}c[ha>>2]=Fa;Te[c[wa>>2]&255](c[qa>>2]|0,0,Ea,0,xa,na,pa,0,0);Ca=c[u>>2]|0}else{Ca=la}}while(0);ka=na+1|0;if((ka|0)<(Ca|0)){na=ka;la=Ca}else{break}}Ga=Ca;Ha=c[p>>2]|0}else{Ga=ra;Ha=ta}la=pa+1|0;if((la|0)<(Ha|0)){pa=la;ra=Ga;ta=Ha}else{Ia=Ha;M=265;break f}}KIb(0,0,2139976,(D=i,i=i+24|0,c[D>>2]=2116552,c[D+8>>2]=2634448,c[D+16>>2]=1166,D)|0);i=D;Hd()}else{ta=h;ra=j;pa=c[f+44>>2]|0;xa=c[z>>2]|0;qa=c[u>>2]|0;wa=c[r>>2]|0;do{if((c[wa+48>>2]|0)==28){if((c[f+148>>2]|0)==0){KIb(0,0,2139976,(D=i,i=i+24|0,c[D>>2]=2610784,c[D+8>>2]=2634448,c[D+16>>2]=45,D)|0);i=D;Hd()}else{Ja=qa<<2;Ka=4;break}}else{Ja=c[n>>2]|0;Ka=2}}while(0);if((c[F>>2]|0)>0){ha=0;ma=0;ya=ua;while(1){oa=c[(c[E>>2]|0)+(ma<<2)>>2]|0;sa=(a[(c[A>>2]|0)+oa|0]&8)==0?3:(c[(c[ya+1536>>2]|0)+(oa<<2)>>2]&7|0)==0?0:3;a[pa+oa|0]=sa;do{if((sa|0)==3){La=ha+1|0}else{za=c[y>>2]|0;if((c[za>>2]|0)==0){La=ha;break}la=c[za+1524>>2]|0;if((la|0)==0){La=ha;break}na=c[z>>2]|0;va=ca(((oa|0)%(na|0)|0)+(ca((oa|0)/(na|0)|0,Ja)|0)|0,Ka)|0;na=c[k>>2]|0;ka=c[na+1524>>2]|0;b[ka+(va<<2)>>1]=b[la+(va<<2)>>1]|0;b[ka+(va<<2)+2>>1]=b[la+(va<<2)+2>>1]|0;va=oa<<2;a[(c[na+1556>>2]|0)+va|0]=a[(c[za+1556>>2]|0)+va|0]|0;La=ha}}while(0);oa=ma+1|0;if((oa|0)>=(c[F>>2]|0)){break}ha=La;ma=oa;ya=c[k>>2]|0}Ma=La;Na=c[r>>2]|0}else{Ma=0;Na=wa}do{if((c[Na+684>>2]&1|0)!=0){if((Ma|0)<=((qa|0)/2|0|0)){break}ya=h|0;ma=h+4|0;ha=j|0;oa=ca(Ja,Ka)|0;sa=f+68|0;va=sa|0;za=f+72|0;na=f+160|0;la=f+164|0;ka=1;aa=0;ia=1;h:while(1){if((ka|0)==0){if((aa|0)>=2){M=263}}else{if((aa|0)>=10){M=263}}if((M|0)==263){M=0;if((ia|0)!=0){break}Z=c[F>>2]|0;if((Z|0)>0){Oa=0;Pa=Z}else{ka=1;aa=0;ia=1;continue}while(1){Z=pa+(c[(c[E>>2]|0)+(Oa<<2)>>2]|0)|0;if((a[Z]|0)==0){Qa=Pa}else{a[Z]=3;Qa=c[F>>2]|0}Z=Oa+1|0;if((Z|0)<(Qa|0)){Oa=Z;Pa=Qa}else{ka=1;aa=0;ia=1;continue h}}}Z=c[p>>2]|0;if((Z|0)>0){W=(aa|0)>1;ja=ia;N=0;ea=0;ga=c[u>>2]|0;fa=Z;while(1){if((ga|0)>0){Z=ca(N,Ja)|0;da=N^aa;Y=(N|0)>0;ba=N+1|0;V=(ba|0)<(Aa|0);_=N<<4;Q=ja;P=0;L=ea;while(1){X=c[z>>2]|0;$=(ca(X,N)|0)+P|0;mrc(ta|0,0,64)|0;mrc(ra|0,0,32)|0;T=P+Z|0;U=ca(T,Ka)|0;i:do{if(((da^P)&1|0)==0){G=pa+$|0;if((a[G]|0)==3){Ra=L;Sa=Q;break}x=(P|0)>0;if(x){Ta=(a[pa+($-1)|0]|0)==3|0}else{Ta=0}O=(P+1|0)<(qa|0);if(O){Ua=(a[pa+($+1)|0]|0)==3?1:Ta}else{Ua=Ta}if(Y){Va=(a[pa+($-xa)|0]|0)==3?1:Ua}else{Va=Ua}if(V){Wa=(a[pa+($+xa)|0]|0)==3?1:Va}else{Wa=Va}if((Wa|0)==0){Ra=L;Sa=Q;break}if(x){Xa=(a[pa+($-1)|0]|0)==2|0}else{Xa=0}if(O){Ya=(a[pa+($+1)|0]|0)==2?1:Xa}else{Ya=Xa}if(Y){Za=(a[pa+($-xa)|0]|0)==2?1:Ya}else{Za=Ya}if(V){_a=(a[pa+($+xa)|0]|0)==2?1:Za}else{_a=Za}if((_a|0)==0&W){Ra=L;Sa=Q;break}do{if(x){I=$-1|0;if((a[pa+I|0]|0)==0){$a=0;break}R=U-Ka|0;q=c[k>>2]|0;K=c[q+1524>>2]|0;c[ya>>2]=b[K+(R<<2)>>1]|0;c[ma>>2]=b[K+(R<<2)+2>>1]|0;c[ha>>2]=a[(c[q+1556>>2]|0)+(I<<2)|0]|0;$a=1}else{$a=0}}while(0);do{if(O){I=$+1|0;if((a[pa+I|0]|0)==0){ab=$a;break}q=U+Ka|0;R=c[k>>2]|0;K=c[R+1524>>2]|0;c[h+($a<<3)>>2]=b[K+(q<<2)>>1]|0;c[h+($a<<3)+4>>2]=b[K+(q<<2)+2>>1]|0;c[j+($a<<2)>>2]=a[(c[R+1556>>2]|0)+(I<<2)|0]|0;ab=$a+1|0}else{ab=$a}}while(0);do{if(Y){if((a[pa+($-xa)|0]|0)==0){bb=ab;break}I=U-oa|0;R=c[k>>2]|0;q=c[R+1524>>2]|0;c[h+(ab<<3)>>2]=b[q+(I<<2)>>1]|0;c[h+(ab<<3)+4>>2]=b[q+(I<<2)+2>>1]|0;c[j+(ab<<2)>>2]=a[(c[R+1556>>2]|0)+($-X<<2)|0]|0;bb=ab+1|0}else{bb=ab}}while(0);do{if(V){if((a[pa+($+xa)|0]|0)==0){cb=bb;break}R=ca(T+Ja|0,Ka)|0;I=c[k>>2]|0;q=c[I+1524>>2]|0;c[h+(bb<<3)>>2]=b[q+(R<<2)>>1]|0;c[h+(bb<<3)+4>>2]=b[q+(R<<2)+2>>1]|0;c[j+(bb<<2)>>2]=a[(c[I+1556>>2]|0)+($+X<<2)|0]|0;cb=bb+1|0}else{cb=bb}}while(0);if((cb|0)==0){Ra=L;Sa=0;break}j:do{if((cb|0)>1){I=0;R=0;q=0;K=0;do{R=(c[h+(I<<3)>>2]|0)+R|0;q=(c[h+(I<<3)+4>>2]|0)+q|0;H=c[j+(I<<2)>>2]|0;K=H+K|0;if((I|0)!=0){if((H|0)!=(c[j+(I-1<<2)>>2]|0)){db=cb;break j}}I=I+1|0;}while((I|0)<(cb|0));c[h+(cb<<3)>>2]=(R|0)/(I|0)|0;c[h+(cb<<3)+4>>2]=(q|0)/(I|0)|0;c[j+(cb<<2)>>2]=(K|0)/(I|0)|0;H=(cb|0)>2;o=H?-99999:0;t=H?99999:0;H=0;C=o;v=o;B=t;w=t;eb=o;o=t;do{t=c[h+(H<<3)>>2]|0;C=(C|0)>(t|0)?C:t;fb=c[h+(H<<3)+4>>2]|0;v=(v|0)>(fb|0)?v:fb;gb=c[j+(H<<2)>>2]|0;eb=(eb|0)>(gb|0)?eb:gb;B=(B|0)>(t|0)?t:B;w=(w|0)>(fb|0)?fb:w;o=(o|0)>(gb|0)?gb:o;H=H+1|0;}while((H|0)<(cb|0));H=R-C-B|0;I=cb+1|0;gb=h+(I<<3)|0;c[gb>>2]=H;fb=q-v-w|0;t=h+(I<<3)+4|0;c[t>>2]=fb;hb=K-eb-o|0;ib=j+(I<<2)|0;c[ib>>2]=hb;if((cb|0)==4){c[gb>>2]=(H|0)/2|0;c[t>>2]=(fb|0)/2|0;c[ib>>2]=(hb|0)/2|0}db=cb+2|0}else{db=cb}}while(0);hb=db+1|0;ib=c[k>>2]|0;fb=c[ib+1524>>2]|0;t=b[fb+(U<<2)>>1]|0;H=b[fb+(U<<2)+2>>1]|0;gb=a[(c[ib+1556>>2]|0)+($<<2)|0]|0;c[h+(hb<<3)>>2]=t;c[h+(hb<<3)+4>>2]=H;c[j+(hb<<2)>>2]=gb;gb=db+2|0;if((gb|0)>0){hb=P<<4;I=pa+($-1)|0;jb=pa+($+1)|0;kb=pa+($-xa)|0;lb=pa+($+xa)|0;mb=0;nb=1073741824;ob=0;pb=ib;ib=fb;while(1){qb=pb+32|0;rb=c[pb>>2]|0;sb=(ca(_,c[qb>>2]|0)|0)+hb|0;tb=c[h+(mb<<3)>>2]|0;c[va>>2]=tb;b[ib+(U<<2)>>1]=tb;tb=c[h+(mb<<3)+4>>2]|0;c[za>>2]=tb;b[ib+(U<<2)+2>>1]=tb;tb=c[j+(mb<<2)>>2]|0;if((tb|0)<0){ub=ob;vb=nb;wb=pb}else{Te[c[na>>2]&255](c[la>>2]|0,tb,1,0,sa,P,N,0,0);do{if(x){if((a[I]|0)==0){xb=0;break}tb=c[qb>>2]|0;yb=sb-1|0;zb=0;Ab=0;while(1){Bb=ca(Ab,tb)|0;Cb=(d[rb+(yb+Bb)|0]|0)-(d[rb+(Bb+sb)|0]|0)|0;Bb=((Cb|0)>-1?Cb:-Cb|0)+zb|0;Cb=Ab+1|0;if((Cb|0)<16){zb=Bb;Ab=Cb}else{xb=Bb;break}}}else{xb=0}}while(0);do{if(O){if((a[jb]|0)==0){Db=xb;break}o=c[qb>>2]|0;eb=sb|15;K=sb+16|0;w=xb;v=0;while(1){q=ca(v,o)|0;B=(d[rb+(q+eb)|0]|0)-(d[rb+(K+q)|0]|0)|0;q=((B|0)>-1?B:-B|0)+w|0;B=v+1|0;if((B|0)<16){w=q;v=B}else{Db=q;break}}}else{Db=xb}}while(0);do{if(Y){if((a[kb]|0)==0){Eb=Db;break}v=c[qb>>2]|0;w=Db;K=0;while(1){eb=K+sb|0;o=(d[rb+(eb-v)|0]|0)-(d[rb+eb|0]|0)|0;eb=((o|0)>-1?o:-o|0)+w|0;o=K+1|0;if((o|0)<16){w=eb;K=o}else{Eb=eb;break}}}else{Eb=Db}}while(0);do{if(V){if((a[lb]|0)==0){Fb=Eb;break}K=c[qb>>2]|0;w=K*15|0;v=K<<4;K=Eb;eb=0;while(1){o=eb+sb|0;q=(d[rb+(o+w)|0]|0)-(d[rb+(o+v)|0]|0)|0;o=((q|0)>-1?q:-q|0)+K|0;q=eb+1|0;if((q|0)<16){K=o;eb=q}else{Fb=o;break}}}else{Fb=Eb}}while(0);rb=(Fb|0)>(nb|0);ub=rb?ob:mb;vb=rb?nb:Fb;wb=c[k>>2]|0}rb=mb+1|0;sb=c[wb+1524>>2]|0;if((rb|0)<(gb|0)){mb=rb;nb=vb;ob=ub;pb=wb;ib=sb}else{Gb=ub;Hb=sb;break}}}else{Gb=0;Hb=fb}ib=c[h+(Gb<<3)>>2]|0;c[va>>2]=ib;pb=c[h+(Gb<<3)+4>>2]|0;c[za>>2]=pb;ob=ib&65535;ib=pb&65535;pb=0;do{nb=pb+U|0;mb=0;do{gb=nb+(ca(mb,Ja)|0)|0;b[Hb+(gb<<2)>>1]=ob;b[Hb+(gb<<2)+2>>1]=ib;mb=mb+1|0;}while((mb|0)<(Ka|0));pb=pb+1|0;}while((pb|0)<(Ka|0));Te[c[na>>2]&255](c[la>>2]|0,c[j+(Gb<<2)>>2]|0,1,0,sa,P,N,0,0);do{if((c[va>>2]|0)==(t|0)){if((c[za>>2]|0)!=(H|0)){break}a[G]=1;Ra=L;Sa=0;break i}}while(0);a[G]=2;Ra=L+1|0;Sa=0}else{Ra=L;Sa=Q}}while(0);U=P+1|0;Ib=c[u>>2]|0;if((U|0)<(Ib|0)){Q=Sa;P=U;L=Ra}else{break}}Jb=Sa;Kb=Ra;Lb=Ib;Mb=c[p>>2]|0;Nb=ba}else{Jb=ja;Kb=ea;Lb=ga;Mb=fa;Nb=N+1|0}if((Nb|0)<(Mb|0)){ja=Jb;N=Nb;ea=Kb;ga=Lb;fa=Mb}else{Ob=Jb;Pb=Kb;break}}}else{Ob=ia;Pb=0}ka=Pb;aa=aa+1|0;ia=Ob}Ia=c[p>>2]|0;M=265;break f}}while(0);xa=c[p>>2]|0;if((xa|0)<=0){Ba=xa;M=266;break}pa=f+68|0;qa=pa|0;ra=f+72|0;ta=f+160|0;wa=f+164|0;ia=0;aa=c[u>>2]|0;ka=xa;while(1){if((aa|0)>0){xa=0;za=aa;while(1){va=(ca(c[z>>2]|0,ia)|0)+xa|0;sa=c[y>>2]|0;if((sa|0)==0){Qb=2}else{Qb=(c[sa>>2]|0)!=0?1:2}do{if((c[(c[(c[k>>2]|0)+1536>>2]|0)+(va<<2)>>2]&7|0)==0){if((a[(c[A>>2]|0)+va|0]&8)==0){Rb=za;break}c[qa>>2]=0;c[ra>>2]=0;Te[c[ta>>2]&255](c[wa>>2]|0,0,Qb,0,pa,xa,ia,0,0);Rb=c[u>>2]|0}else{Rb=za}}while(0);va=xa+1|0;if((va|0)<(Rb|0)){xa=va;za=Rb}else{break}}Sb=Rb;Tb=c[p>>2]|0}else{Sb=aa;Tb=ka}za=ia+1|0;if((za|0)<(Tb|0)){ia=za;aa=Sb;ka=Tb}else{Ia=Tb;M=265;break}}}}while(0);do{if((M|0)==265){if((Ia|0)<=0){Ba=Ia;M=266;break}Tb=l+36|0;Sb=l+40|0;Rb=f+48|0;Qb=f+52|0;Ob=f+56|0;Pb=c[u>>2]|0;Kb=0;while(1){if((Pb|0)>0){Jb=Kb<<3;Mb=c[z>>2]|0;Lb=c[k>>2]|0;Nb=c[Lb+1536>>2]|0;Ib=0;do{Ra=(ca(Mb,Kb)|0)+Ib|0;if((c[Nb+(Ra<<2)>>2]&7|0)==0){M=276}else{if((c[J>>2]|0)==0){M=276}}if((M|0)==276){M=0;Sa=c[Lb>>2]|0;Gb=c[m>>2]|0;j=ca(Gb,Kb)|0;Ka=c[Lb+4>>2]|0;Hb=c[Tb>>2]|0;Ja=c[Lb+8>>2]|0;h=c[Sb>>2]|0;ub=c[n>>2]|0;wb=ca(ub,Kb)|0;vb=c[Rb>>2]|0;Fb=j+Ib<<4;j=wb+Ib<<1;wb=0;do{Eb=wb<<3&8;Db=wb>>>1<<3;xb=0;db=0;do{cb=ca(Gb,db+Db|0)|0;xb=(d[Sa+((Eb|7)+cb+Fb)|0]|0)+((d[Sa+((Eb|6)+cb+Fb)|0]|0)+((d[Sa+((Eb|5)+cb+Fb)|0]|0)+((d[Sa+((Eb|4)+cb+Fb)|0]|0)+((d[Sa+((Eb|3)+cb+Fb)|0]|0)+((d[Sa+((Eb|2)+cb+Fb)|0]|0)+((d[Sa+((Eb|1)+cb+Fb)|0]|0)+((d[Sa+(Eb+cb+Fb)|0]|0)+xb)))))))|0;db=db+1|0;}while((db|0)<8);b[vb+((ca(ub,wb>>1)|0)+(wb&1)+j<<1)>>1]=(xb+4|0)>>>3;wb=wb+1|0;}while((wb|0)<4);wb=Ib<<3;j=(ca(Hb,Jb)|0)+wb|0;ub=(ca(h,Jb)|0)+wb|0;wb=0;vb=0;Fb=0;do{Sa=ca(Hb,Fb)|0;Gb=ca(h,Fb)|0;wb=(d[Ka+((j|7)+Sa)|0]|0)+((d[Ka+((j|6)+Sa)|0]|0)+((d[Ka+((j|5)+Sa)|0]|0)+((d[Ka+((j|4)+Sa)|0]|0)+((d[Ka+((j|3)+Sa)|0]|0)+((d[Ka+((j|2)+Sa)|0]|0)+((d[Ka+((j|1)+Sa)|0]|0)+((d[Ka+(j+Sa)|0]|0)+wb)))))))|0;vb=(d[Ja+((ub|7)+Gb)|0]|0)+((d[Ja+((ub|6)+Gb)|0]|0)+((d[Ja+((ub|5)+Gb)|0]|0)+((d[Ja+((ub|4)+Gb)|0]|0)+((d[Ja+((ub|3)+Gb)|0]|0)+((d[Ja+((ub|2)+Gb)|0]|0)+((d[Ja+((ub|1)+Gb)|0]|0)+((d[Ja+(ub+Gb)|0]|0)+vb)))))))|0;Fb=Fb+1|0;}while((Fb|0)<8);b[(c[Qb>>2]|0)+(Ra<<1)>>1]=(wb+4|0)>>>3;b[(c[Ob>>2]|0)+(Ra<<1)>>1]=(vb+4|0)>>>3}Ib=Ib+1|0;}while((Ib|0)<(Pb|0))}Ib=Kb+1|0;if((Ib|0)<(Ia|0)){Kb=Ib}else{Ub=Rb;Vb=Qb;Wb=Ob;Xb=Ia;break}}}}while(0);if((M|0)==266){Ub=f+48|0;Vb=f+52|0;Wb=f+56|0;Xb=Ba}Apb(f,c[Ub>>2]|0,c[u>>2]<<1,Xb<<1,c[n>>2]|0,1);Apb(f,c[Vb>>2]|0,c[u>>2]|0,c[p>>2]|0,c[z>>2]|0,0);Apb(f,c[Wb>>2]|0,c[u>>2]|0,c[p>>2]|0,c[z>>2]|0,0);Xb=c[Ub>>2]|0;Ba=c[u>>2]|0;M=c[p>>2]|0;Ia=c[n>>2]|0;J=(M<<1)-1|0;Ob=(Ba<<1)-1|0;do{if((J|0)>1&(Ob|0)>1){Qb=1;do{Rb=ca(Qb,Ia)|0;Kb=b[Xb+(Rb<<1)>>1]|0;Pb=1;while(1){Sb=Xb+(Pb+Rb<<1)|0;Tb=b[Sb>>1]|0;Ib=Pb+1|0;b[Sb>>1]=((((Tb<<3)-Kb-(b[Xb+(Ib+Rb<<1)>>1]|0)|0)*10923|0)+32768|0)>>>16;if((Ib|0)<(Ob|0)){Kb=Tb;Pb=Ib}else{break}}Qb=Qb+1|0;}while((Qb|0)<(J|0));if((Ob|0)<2){break}else{Yb=1}do{Qb=1;Pb=b[Xb+(Yb<<1)>>1]|0;while(1){Kb=Xb+((ca(Qb,Ia)|0)+Yb<<1)|0;Rb=b[Kb>>1]|0;Ib=Qb+1|0;b[Kb>>1]=((((Rb<<3)-Pb-(b[Xb+((ca(Ib,Ia)|0)+Yb<<1)>>1]|0)|0)*10923|0)+32768|0)>>>16;if((Ib|0)<(J|0)){Qb=Ib;Pb=Rb}else{break}}Yb=Yb+1|0;}while((Yb|0)<(Ob|0))}}while(0);if((M|0)>0){Ob=l+36|0;Yb=l+40|0;J=0;Ia=Ba;Xb=M;while(1){if((Ia|0)>0){Pb=J<<4;Qb=J<<3;Rb=J<<1;Ib=0;Kb=Ia;while(1){Tb=(ca(c[z>>2]|0,J)|0)+Ib|0;Sb=c[k>>2]|0;do{if((c[(c[Sb+1536>>2]|0)+(Tb<<2)>>2]&120|0)==0){if((a[(c[A>>2]|0)+Tb|0]&2)==0){Zb=Kb;break}Jb=c[Sb>>2]|0;Lb=(ca(Pb,c[m>>2]|0)|0)+(Ib<<4)|0;Nb=c[Sb+4>>2]|0;Mb=ca(c[Ob>>2]|0,Qb)|0;Fb=c[Sb+8>>2]|0;ub=ca(c[Yb>>2]|0,Qb)|0;Ja=Sb+32|0;j=Ib<<1;Ka=0;do{h=Ka&1;Hb=Ka>>1;Gb=(ca(Hb+Rb|0,c[n>>2]|0)|0)+(h|j)|0;Sa=b[(c[Ub>>2]|0)+(Gb<<1)>>1]|0;if(Sa<<16>>16<0){_b=0}else{_b=Sa<<16>>16>2040?-1:((Sa<<16>>16|0)/8|0)&255}Sa=Hb<<3;Hb=h<<3|Lb;h=Hb|1;Gb=Hb|2;db=Hb|3;Eb=Hb|4;Db=Hb|5;ba=Hb|6;cb=Hb|7;bb=0;do{ab=bb+Sa|0;a[Jb+(Hb+(ca(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(h+(ca(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(Gb+(ca(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(db+(ca(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(Eb+(ca(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(Db+(ca(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(ba+(ca(c[Ja>>2]|0,ab)|0))|0]=_b;a[Jb+(cb+(ca(c[Ja>>2]|0,ab)|0))|0]=_b;bb=bb+1|0;}while((bb|0)<8);Ka=Ka+1|0;}while((Ka|0)<4);Ka=Ib<<3;Ja=Mb+Ka|0;Jb=ub+Ka|0;Ka=(ca(c[z>>2]|0,J)|0)+Ib|0;Lb=b[(c[Vb>>2]|0)+(Ka<<1)>>1]|0;j=b[(c[Wb>>2]|0)+(Ka<<1)>>1]|0;if(Lb<<16>>16<0){$b=0}else{$b=Lb<<16>>16>2040?-1:((Lb<<16>>16|0)/8|0)&255}if(j<<16>>16<0){ac=0}else{ac=j<<16>>16>2040?-1:((j<<16>>16|0)/8|0)&255}j=Sb+36|0;Lb=Sb+40|0;Ka=Ja|1;vb=Jb|1;Ra=Ja|2;wb=Jb|2;bb=Ja|3;cb=Jb|3;ba=Ja|4;Db=Jb|4;Eb=Ja|5;db=Jb|5;Gb=Ja|6;h=Jb|6;Hb=Ja|7;Sa=Jb|7;xb=0;do{a[Nb+((ca(c[j>>2]|0,xb)|0)+Ja)|0]=$b;a[Fb+((ca(c[Lb>>2]|0,xb)|0)+Jb)|0]=ac;a[Nb+(Ka+(ca(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(vb+(ca(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(Ra+(ca(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(wb+(ca(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(bb+(ca(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(cb+(ca(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(ba+(ca(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(Db+(ca(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(Eb+(ca(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(db+(ca(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(Gb+(ca(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(h+(ca(c[Lb>>2]|0,xb)|0))|0]=ac;a[Nb+(Hb+(ca(c[j>>2]|0,xb)|0))|0]=$b;a[Fb+(Sa+(ca(c[Lb>>2]|0,xb)|0))|0]=ac;xb=xb+1|0;}while((xb|0)<8);Zb=c[u>>2]|0}else{Zb=Kb}}while(0);Sb=Ib+1|0;if((Sb|0)<(Zb|0)){Ib=Sb;Kb=Zb}else{break}}bc=Zb;cc=c[p>>2]|0}else{bc=Ia;cc=Xb}Kb=J+1|0;if((Kb|0)<(cc|0)){J=Kb;Ia=bc;Xb=cc}else{dc=cc;ec=bc;break}}}else{dc=M;ec=Ba}if((c[(c[r>>2]|0)+684>>2]&2|0)!=0){Bpb(f,c[c[k>>2]>>2]|0,ec<<1,dc<<1,c[m>>2]|0,1);dc=l+36|0;Bpb(f,c[(c[k>>2]|0)+4>>2]|0,c[u>>2]|0,c[p>>2]|0,c[dc>>2]|0,0);ec=l+40|0;Bpb(f,c[(c[k>>2]|0)+8>>2]|0,c[u>>2]|0,c[p>>2]|0,c[ec>>2]|0,0);Cpb(f,c[c[k>>2]>>2]|0,c[u>>2]<<1,c[p>>2]<<1,c[m>>2]|0,1);Cpb(f,c[(c[k>>2]|0)+4>>2]|0,c[u>>2]|0,c[p>>2]|0,c[dc>>2]|0,0);Cpb(f,c[(c[k>>2]|0)+8>>2]|0,c[u>>2]|0,c[p>>2]|0,c[ec>>2]|0,0)}if((c[F>>2]|0)>0){ec=f+64|0;f=0;do{p=c[(c[E>>2]|0)+(f<<2)>>2]|0;do{if((c[(c[k>>2]|0)+88>>2]|0)!=3){if((a[(c[A>>2]|0)+p|0]&14)==0){break}a[(c[S>>2]|0)+p|0]=0}}while(0);a[(c[ec>>2]|0)+p|0]=1;f=f+1|0;}while((f|0)<(c[F>>2]|0))}c[k>>2]=0;c[s>>2]=0;c[y>>2]=0;i=g;return}function Apb(d,e,f,g,h,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=ca(h,g)|0;o=hJb(n<<3)|0;p=o;c[l>>2]=p;q=hJb(n<<4)|0;n=q;c[m>>2]=n;if((o|0)==0|(q|0)==0){KIb(c[d>>2]|0,16,2584296,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);i=q;r=l;mJb(r);s=m;mJb(s);i=k;return}q=(g|0)>0;if(q){o=(f|0)>0;t=d+24|0;u=d+132|0;v=d+40|0;w=0;do{do{if(o){x=w>>j;y=ca(w,h)|0;z=c[(c[u>>2]|0)+1536>>2]|0;A=-1;B=1024;C=0;while(1){D=(ca(c[t>>2]|0,x)|0)+(C>>j)|0;do{if((c[z+(D<<2)>>2]&7|0)==0){E=12}else{if((a[(c[v>>2]|0)+D|0]&4)==0){E=12;break}F=B;H=A;I=C+y|0}}while(0);if((E|0)==12){E=0;D=C+y|0;F=b[e+(D<<1)>>1]|0;H=C;I=D}b[p+(I<<3)+2>>1]=F;c[n+(I<<4)+4>>2]=(H|0)>-1?C-H|0:9999;D=C+1|0;if((D|0)<(f|0)){A=H;B=F;C=D}else{break}}if(!o){break}C=w>>j;B=ca(w,h)|0;A=c[(c[u>>2]|0)+1536>>2]|0;y=-1;z=1024;x=f;while(1){D=x-1|0;J=(ca(c[t>>2]|0,C)|0)+(D>>j)|0;do{if((c[A+(J<<2)>>2]&7|0)==0){E=19}else{if((a[(c[v>>2]|0)+J|0]&4)==0){E=19;break}K=z;L=y;M=D+B|0}}while(0);if((E|0)==19){E=0;J=D+B|0;K=b[e+(J<<1)>>1]|0;L=D;M=J}b[p+(M<<3)>>1]=K;c[n+(M<<4)>>2]=(L|0)>-1?L-D|0:9999;if((D|0)>0){y=L;z=K;x=D}else{break}}}}while(0);w=w+1|0;}while((w|0)<(g|0))}w=(f|0)>0;if(w){K=d+24|0;L=d+132|0;M=d+40|0;v=0;do{do{if(q){t=v>>j;u=c[(c[L>>2]|0)+1536>>2]|0;o=-1;F=1024;H=0;while(1){I=(ca(c[K>>2]|0,H>>j)|0)+t|0;do{if((c[u+(I<<2)>>2]&7|0)==0){E=35}else{if((a[(c[M>>2]|0)+I|0]&4)==0){E=35;break}N=F;O=o;P=(ca(H,h)|0)+v|0}}while(0);if((E|0)==35){E=0;I=(ca(H,h)|0)+v|0;N=b[e+(I<<1)>>1]|0;O=H;P=I}b[p+(P<<3)+6>>1]=N;c[n+(P<<4)+12>>2]=(O|0)>-1?H-O|0:9999;I=H+1|0;if((I|0)<(g|0)){o=O;F=N;H=I}else{break}}if(!q){break}H=v>>j;F=c[(c[L>>2]|0)+1536>>2]|0;o=-1;u=1024;t=g;while(1){I=t-1|0;D=(ca(c[K>>2]|0,I>>j)|0)+H|0;do{if((c[F+(D<<2)>>2]&7|0)==0){E=42}else{if((a[(c[M>>2]|0)+D|0]&4)==0){E=42;break}Q=u;R=o;S=(ca(I,h)|0)+v|0}}while(0);if((E|0)==42){E=0;D=(ca(I,h)|0)+v|0;Q=b[e+(D<<1)>>1]|0;R=I;S=D}b[p+(S<<3)+4>>1]=Q;c[n+(S<<4)+8>>2]=(R|0)>-1?R-I|0:9999;if((I|0)>0){o=R;u=Q;t=I}else{break}}}}while(0);v=v+1|0;}while((v|0)<(f|0))}if(!q){r=l;mJb(r);s=m;mJb(s);i=k;return}q=d+24|0;v=d+132|0;Q=d+40|0;if(w){T=0}else{r=l;mJb(r);s=m;mJb(s);i=k;return}do{w=T>>j;d=ca(T,h)|0;R=c[q>>2]|0;S=c[(c[v>>2]|0)+1536>>2]|0;E=0;do{M=(ca(R,w)|0)+(E>>j)|0;do{if((c[S+(M<<2)>>2]&120|0)==0){if((a[(c[Q>>2]|0)+M|0]&4)==0){break}K=E+d|0;L=c[n+(K<<4)>>2]|0;N=268435456/((L>>>0>1>>>0?L:1)>>>0)|0;L=0;O=b[p+(K<<3)>>1]|0;P=Erc(O<<16>>16,O<<16>>16<0|0?-1:0,N,L)|0;O=G;t=c[n+(K<<4)+4>>2]|0;u=268435456/((t>>>0>1>>>0?t:1)>>>0)|0;t=0;o=b[p+(K<<3)+2>>1]|0;F=Erc(o<<16>>16,o<<16>>16<0|0?-1:0,u,t)|0;o=wrc(F,G,P,O)|0;O=G;P=wrc(u,t,N,L)|0;L=G;N=c[n+(K<<4)+8>>2]|0;t=268435456/((N>>>0>1>>>0?N:1)>>>0)|0;N=0;u=b[p+(K<<3)+4>>1]|0;F=Erc(u<<16>>16,u<<16>>16<0|0?-1:0,t,N)|0;u=wrc(F,G,o,O)|0;O=G;o=wrc(t,N,P,L)|0;L=G;P=c[n+(K<<4)+12>>2]|0;N=268435456/((P>>>0>1>>>0?P:1)>>>0)|0;P=0;t=b[p+(K<<3)+6>>1]|0;F=Erc(t<<16>>16,t<<16>>16<0|0?-1:0,N,P)|0;t=wrc(F,G,u,O)|0;O=G;u=wrc(N,P,o,L)|0;L=G;o=wrc(u>>>1|L<<31,L>>>1|0<<31,t,O)|0;O=Crc(o,G,u,L)|0;b[e+(K<<1)>>1]=O}}while(0);E=E+1|0;}while((E|0)<(f|0));T=T+1|0;}while((T|0)<(g|0));r=l;mJb(r);s=m;mJb(s);i=k;return}function Bpb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;l=i;do{if((c[(c[e>>2]|0)+48>>2]|0)==28){if((c[e+148>>2]|0)==0){KIb(0,0,2139976,(m=i,i=i+24|0,c[m>>2]=2610784,c[m+8>>2]=2634448,c[m+16>>2]=45,m)|0);i=m;Hd()}else{n=c[e+16>>2]<<2;o=4;break}}else{n=c[e+28>>2]|0;o=2}}while(0);m=o>>>(k>>>0);o=ca(n,m)|0;if((h|0)<=0){i=l;return}n=g-1|0;g=(n|0)>0;p=e+24|0;q=e+40|0;r=e+132|0;e=j<<3;s=0;do{if(g){t=s>>k;u=ca(e,s)|0;v=ca(o,s)|0;w=0;while(1){x=ca(c[p>>2]|0,t)|0;y=x+(w>>k)|0;z=c[q>>2]|0;A=w+1|0;B=x+(A>>k)|0;x=c[r>>2]|0;C=c[x+1536>>2]|0;D=(w<<3)+u|0;E=(ca(w,m)|0)+v|0;F=c[x+1524>>2]|0;x=F+(E<<2)|0;G=(ca(A,m)|0)+v|0;H=F+(G<<2)|0;I=(a[z+y|0]&14)!=0;J=I^1;K=(a[z+B|0]&14)==0;do{if(!(K&J)){if(((c[C+(B<<2)>>2]|c[C+(y<<2)>>2])&7|0)==0){z=(b[x>>1]|0)-(b[H>>1]|0)|0;L=(b[F+(G<<2)+2>>1]|0)+(b[F+(E<<2)+2>>1]|0)|0;if((((L|0)>-1?L:-L|0)+((z|0)>-1?z:-z|0)|0)<2){break}}z=D|7;L=D|6;M=D+8|0;N=D+9|0;O=K|J;P=D|5;Q=D|4;R=D+10|0;S=D+11|0;T=0;do{U=ca(T,j)|0;V=f+(U+z)|0;W=d[V]|0;X=f+(U+L)|0;Y=W-(d[X]|0)|0;Z=f+(M+U)|0;_=d[Z]|0;$=_-W|0;aa=f+(N+U)|0;ba=(d[aa]|0)-_|0;_=(($|0)>-1?$:-$|0)-(((Y|0)>-1?Y:-Y|0)+1+((ba|0)>-1?ba:-ba|0)>>1)|0;ba=(_|0)>0?_:0;_=($|0)<0?-ba|0:ba;do{if((_|0)!=0){if(O){da=(_<<4|0)/9|0}else{da=_}if(I){a[V]=a[1403376+(((da*7|0)>>4)+1024+W)|0]|0;a[X]=a[1403376+(((da*5|0)>>4)+1024+(d[X]|0))|0]|0;ba=f+(U+P)|0;a[ba]=a[1403376+(((da*3|0)>>4)+1024+(d[ba]|0))|0]|0;ba=f+(U+Q)|0;a[ba]=a[1403376+((da>>4)+1024+(d[ba]|0))|0]|0}if(K){break}a[Z]=a[1403376+(1024-((da*7|0)>>4)+(d[Z]|0))|0]|0;a[aa]=a[1403376+(1024-((da*5|0)>>4)+(d[aa]|0))|0]|0;ba=f+(R+U)|0;a[ba]=a[1403376+(1024-((da*3|0)>>4)+(d[ba]|0))|0]|0;ba=f+(S+U)|0;a[ba]=a[1403376+(1024-(da>>4)+(d[ba]|0))|0]|0}}while(0);T=T+1|0;}while((T|0)<8)}}while(0);if((A|0)<(n|0)){w=A}else{break}}}s=s+1|0;}while((s|0)<(h|0));i=l;return}function Cpb(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;l=i;do{if((c[(c[e>>2]|0)+48>>2]|0)==28){if((c[e+148>>2]|0)==0){KIb(0,0,2139976,(m=i,i=i+24|0,c[m>>2]=2610784,c[m+8>>2]=2634448,c[m+16>>2]=45,m)|0);i=m;Hd()}else{n=c[e+16>>2]<<2;o=4;break}}else{n=c[e+28>>2]|0;o=2}}while(0);m=o>>>(k>>>0);o=ca(n,m)|0;n=h-1|0;if((n|0)<=0){i=l;return}h=(g|0)>0;p=e+24|0;q=e+40|0;r=e+132|0;e=j*7|0;s=j*6|0;t=j<<3;u=j*9|0;v=j*5|0;w=j<<2;x=j*10|0;y=j*11|0;z=0;while(1){if(h){A=z>>k;B=z+1|0;C=B>>k;D=ca(z,j)|0;E=ca(z,o)|0;F=ca(B,o)|0;G=0;while(1){H=G>>k;I=c[p>>2]|0;J=(ca(I,A)|0)+H|0;K=c[q>>2]|0;L=(ca(I,C)|0)+H|0;H=c[r>>2]|0;I=c[H+1536>>2]|0;M=ca(G,m)|0;N=M+E|0;O=c[H+1524>>2]|0;H=O+(N<<2)|0;P=M+F|0;M=O+(P<<2)|0;Q=(a[K+J|0]&14)!=0;R=Q^1;S=(a[K+L|0]&14)==0;do{if(!(S&R)){if(((c[I+(L<<2)>>2]|c[I+(J<<2)>>2])&7|0)==0){K=(b[H>>1]|0)-(b[M>>1]|0)|0;T=(b[O+(P<<2)+2>>1]|0)+(b[O+(N<<2)+2>>1]|0)|0;if((((T|0)>-1?T:-T|0)+((K|0)>-1?K:-K|0)|0)<2){break}}K=G+D<<3;T=S|R;U=0;do{V=K+U|0;W=f+(V+e)|0;X=d[W]|0;Y=f+(V+s)|0;Z=X-(d[Y]|0)|0;_=f+(V+t)|0;$=d[_]|0;aa=$-X|0;ba=f+(V+u)|0;da=(d[ba]|0)-$|0;$=((aa|0)>-1?aa:-aa|0)-(((Z|0)>-1?Z:-Z|0)+1+((da|0)>-1?da:-da|0)>>1)|0;da=($|0)>0?$:0;$=(aa|0)<0?-da|0:da;do{if(($|0)!=0){if(T){ea=($<<4|0)/9|0}else{ea=$}if(Q){a[W]=a[1403376+(((ea*7|0)>>4)+1024+X)|0]|0;a[Y]=a[1403376+(((ea*5|0)>>4)+1024+(d[Y]|0))|0]|0;da=f+(V+v)|0;a[da]=a[1403376+(((ea*3|0)>>4)+1024+(d[da]|0))|0]|0;da=f+(V+w)|0;a[da]=a[1403376+((ea>>4)+1024+(d[da]|0))|0]|0}if(S){break}a[_]=a[1403376+(1024-((ea*7|0)>>4)+(d[_]|0))|0]|0;a[ba]=a[1403376+(1024-((ea*5|0)>>4)+(d[ba]|0))|0]|0;da=f+(V+x)|0;a[da]=a[1403376+(1024-((ea*3|0)>>4)+(d[da]|0))|0]|0;da=f+(V+y)|0;a[da]=a[1403376+(1024-(ea>>4)+(d[da]|0))|0]|0}}while(0);U=U+1|0;}while((U|0)<8)}}while(0);S=G+1|0;if((S|0)<(g|0)){G=S}else{fa=B;break}}}else{fa=z+1|0}if((fa|0)<(n|0)){z=fa}else{break}}i=l;return}function Dpb(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=i;i=i+40|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=r3a(d,e)|0;p=d|0;q=d+4|0;if(((c[q>>2]|0)-(c[p>>2]|0)|0)>>>0<(o*12|0)>>>0){r=-1094995529;i=h;return r|0}s=n;t=(f|0)>2;u=a;v=d+8|0;w=f+1|0;f=0;while(1){if((f|0)>=(o|0)){break}a:do{if(t){x=0}else{C3a(d,e,k,m,l,j)|0;do{if((q3a(c[k>>2]|0)|0)==0){y=c[k>>2]&65535;z=0;while(1){if(!(z>>>0<117>>>0)){A=11;break}if((b[312800+(z*34|0)>>1]|0)==y<<16>>16){A=10;break}else{z=z+1|0}}if((A|0)==10){A=0;y=312768+(z*34|0)|0;c[n>>2]=y;B=1;C=y}else if((A|0)==11){A=0;c[n>>2]=0;y=hJb(7)|0;c[n>>2]=y;if((y|0)==0){x=-12;break a}Rb(y|0,7,2425736,(D=i,i=i+8|0,c[D>>2]=c[k>>2],D)|0)|0;i=D;B=0;C=c[n>>2]|0}y=c[l>>2]|0;E=c[m>>2]|0;switch(E|0){case 3:{F=y3a(y,C,0,d,e,g)|0;break};case 1:case 7:{F=z3a(y,C,0,d,e,g)|0;break};case 10:case 5:{F=v3a(y,C,0,d,e,g)|0;break};case 12:{F=x3a(y,C,0,d,e,g)|0;break};case 2:{F=A3a(y,C,d,e,g)|0;break};case 9:case 4:{F=w3a(y,C,0,d,e,g)|0;break};default:{QIb(u,2581440,(D=i,i=i+8|0,c[D>>2]=E,D)|0);i=D;F=0}}if(B){G=F;break}mJb(s);G=F}else{G=Dpb(a,d,e,w,g)|0}}while(0);E=c[j>>2]|0;y=c[v>>2]|0;H=(c[q>>2]|0)-y|0;if((E|0)<0){I=0}else{I=(H|0)<(E|0)?H:E}c[p>>2]=y+I;x=G}}while(0);if((x|0)<0){r=x;A=28;break}else{f=f+1|0}}if((A|0)==28){i=h;return r|0}r=s3a(d,e)|0;i=h;return r|0}function Epb(){if(a[1412960]|0){return}c[2458833]=8777520;c[2458835]=528;c[2458838]=8774928;c[2458840]=648;$2(9835328,9,104,1721616,1,1,1721824,1,1,1721376,2,2,4)|0;$2(9835348,9,104,1721720,1,1,1721928,1,1,1721376,2,2,4)|0;c[2458843]=8772880;c[2458845]=512;$2(9835368,9,11,1721584,1,1,1721600,1,1,0,0,0,4)|0;a[1412960]=1;return}function Fpb(a,e,f,g,h,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;m=i;i=i+24|0;n=m|0;o=a+120|0;p=(c[o>>2]|0)+2|0;q=p<<2;r=hJb(q)|0;s=r;t=hJb(q)|0;q=t;if((r|0)==0|(t|0)==0){u=s;v=q;w=-12;x=u;kJb(x);y=v;kJb(y);i=m;return w|0}c[q>>2]=c[o>>2];c[t+4>>2]=0;c[t+8>>2]=0;t=f<<3;f=t>>>0>2147483639>>>0|(e|0)==0;r=f?0:e;e=f?0:t;f=n|0;c[f>>2]=r;c[n+12>>2]=e;z=n+16|0;c[z>>2]=e+8;c[n+4>>2]=r+(e>>3);e=n+8|0;c[e>>2]=0;A=r;r=je(d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0)|0;if((r&-1048576|0)==1048576){B=0}else{B=(r&-65536|0)!=65536}if((h|0)<=0){u=s;v=q;w=0;x=u;kJb(x);y=v;kJb(y);i=m;return w|0}r=(k|0)==2;A=r|B;B=a;C=a+696|0;D=(l&1|0)==0;l=q;q=s;s=0;E=g;a:while(1){g=q+(p<<2)|0;if((k|0)==4){F=Gpb(a,n,c[o>>2]|0,q,g,l)|0;if((F|0)<0){u=q;v=l;w=F;G=40;break}H=c[o>>2]|0;G=38}else if((k|0)==3){I=D;G=10}else{I=0;G=10}do{if((G|0)==10){G=0;if(!A){F=c[e>>2]|0;J=c[f>>2]|0;K=c[z>>2]|0;L=-1;M=t-F|0;N=F;while(1){if((M|0)<=0){u=q;v=l;w=0;G=40;break a}F=d[J+(N>>>3)|0]<<(N&7)>>>7;O=((N|0)<(K|0))+N|0;c[e>>2]=O;P=F&1|L<<1;if((P&4095|0)==1){break}else{L=P;M=M-1|0;N=O}}}do{if(r|I){Q=c[f>>2]|0;G=17}else{N=c[e>>2]|0;M=c[f>>2]|0;L=d[M+(N>>>3)|0]|0;c[e>>2]=((N|0)<(c[z>>2]|0))+N;if((L&128>>>((N&7)>>>0)|0)!=0){Q=M;G=17;break}R=Gpb(a,n,c[o>>2]|0,q,g,l)|0}}while(0);do{if((G|0)==17){G=0;M=0;N=c[o>>2]|0;L=q;b:while(1){K=c[9835332+(M*20|0)>>2]|0;J=c[z>>2]|0;O=0;P=c[e>>2]|0;while(1){F=Q+(P>>>3)|0;S=(je(d[F]|d[F+1|0]<<8|d[F+2|0]<<16|d[F+3|0]<<24|0)|0)<<(P&7)>>>23;F=b[K+(S<<2)>>1]|0;T=b[K+(S<<2)+2>>1]|0;S=T<<16>>16;if(T<<16>>16<0){T=P+9|0;U=J>>>0>T>>>0?T:J;T=Q+(U>>>3)|0;V=((je(d[T]|d[T+1|0]<<8|d[T+2|0]<<16|d[T+3|0]<<24|0)|0)<<(U&7)>>>((S+32|0)>>>0))+F|0;W=b[K+(V<<2)+2>>1]|0;X=b[K+(V<<2)>>1]|0;Y=U}else{W=S;X=F;Y=P}F=W+Y|0;Z=J>>>0>F>>>0?F:J;_=X+O|0;if(X>>>0<64>>>0){break}if((X|0)==-1){G=29;break b}else{O=_;P=Z}}c[e>>2]=Z;$=L+4|0;c[L>>2]=_;if(!($>>>0<g>>>0)){G=23;break}if(!(N>>>0>_>>>0)){G=25;break}M=M^1;N=N-_|0;L=$}if((G|0)==23){G=0;KIb(B,16,2425680,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;R=-1094995529;break}else if((G|0)==25){G=0;if((N|0)==(_|0)){c[$>>2]=0;R=0;break}else{KIb(B,16,2581408,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;R=-1094995529;break}}else if((G|0)==29){G=0;c[e>>2]=Z;KIb(B,16,2437448,(aa=i,i=i+1|0,i=i+7&-8,c[aa>>2]=0,aa)|0);i=aa;R=-1094995529;break}}}while(0);do{if(r){L=c[e>>2]|0;M=-L&7;if((M|0)==0){break}P=c[z>>2]|0;O=M+L|0;c[e>>2]=P>>>0>O>>>0?O:P}}while(0);P=(R|0)<0;if((c[C>>2]&8|0)!=0&P){u=q;v=l;w=R;G=40;break a}O=c[o>>2]|0;if(!P){H=O;G=38;break}Hpb(E,j,O,l);ba=q;ca=l}}while(0);if((G|0)==38){G=0;Hpb(E,j,H,q);ba=l;ca=q}g=s+1|0;if((g|0)<(h|0)){l=ca;q=ba;s=g;E=E+j|0}else{u=ba;v=ca;w=0;G=40;break}}if((G|0)==40){x=u;kJb(x);y=v;kJb(y);i=m;return w|0}return 0}function Gpb(a,e,f,g,h,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;k=i;if((f|0)==0){c[g>>2]=0;l=0;i=k;return l|0}m=e+8|0;n=e+16|0;o=c[2458843]|0;p=c[e>>2]|0;e=j+4|0;q=0;r=0;s=g;g=c[j>>2]|0;j=0;a:while(1){t=c[m>>2]|0;u=c[n>>2]|0;v=p+(t>>>3)|0;w=(je(d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0)|0)<<(t&7)>>>23;v=b[o+(w<<2)>>1]|0;x=(b[o+(w<<2)+2>>1]|0)+t|0;t=u>>>0>x>>>0?x:u;c[m>>2]=t;if((v|0)==(-1|0)){y=7;break}else if((v|0)==0){if(g>>>0<f>>>0){z=(c[e>>2]|0)+g|0;A=e+4|0}else{z=g;A=e}if(z>>>0<f>>>0){B=(c[A>>2]|0)+z|0;C=A+4|0}else{B=z;C=A}if(z>>>0>f>>>0){y=13;break}D=z;E=B;F=s;G=r-j+z|0;H=q;I=C}else if((v|0)==1){x=c[9835332+(q*20|0)>>2]|0;w=0;J=t;do{t=p+(J>>>3)|0;K=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(J&7)>>>23;t=b[x+(K<<2)>>1]|0;L=b[x+(K<<2)+2>>1]|0;K=L<<16>>16;if(L<<16>>16<0){L=J+9|0;M=u>>>0>L>>>0?L:u;L=p+(M>>>3)|0;N=((je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(M&7)>>>((K+32|0)>>>0))+t|0;O=b[x+(N<<2)+2>>1]|0;P=b[x+(N<<2)>>1]|0;Q=M}else{O=K;P=t;Q=J}t=O+Q|0;J=u>>>0>t>>>0?t:u;c[m>>2]=J;if((P|0)==-1){y=18;break a}w=P+w|0;}while((P|0)>=64);J=s+4|0;c[s>>2]=w+r;if(!(J>>>0<h>>>0)){y=21;break}u=w+j|0;if(u>>>0>f>>>0|w>>>0>f>>>0){y=23;break}x=(q|0)==0;t=c[9835332+((x&1)*20|0)>>2]|0;K=c[n>>2]|0;M=0;N=c[m>>2]|0;do{L=p+(N>>>3)|0;R=(je(d[L]|d[L+1|0]<<8|d[L+2|0]<<16|d[L+3|0]<<24|0)|0)<<(N&7)>>>23;L=b[t+(R<<2)>>1]|0;S=b[t+(R<<2)+2>>1]|0;R=S<<16>>16;if(S<<16>>16<0){S=N+9|0;T=K>>>0>S>>>0?S:K;S=p+(T>>>3)|0;U=((je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(T&7)>>>((R+32|0)>>>0))+L|0;V=b[t+(U<<2)+2>>1]|0;W=b[t+(U<<2)>>1]|0;X=T}else{V=R;W=L;X=N}L=V+X|0;N=K>>>0>L>>>0?L:K;c[m>>2]=N;if((W|0)==-1){y=18;break a}M=W+M|0;}while((W|0)>=64);N=s+8|0;c[J>>2]=M;if(!(N>>>0<h>>>0)){y=21;break}K=M+u|0;if(K>>>0>f>>>0|M>>>0>f>>>0){y=23;break}D=K;E=g;F=N;G=0;H=x&1^1;I=e}else{if((v-9|0)>>>0<2>>>0){y=26;break}N=v-5|0;K=N+(g-j)|0;t=e-4|0;w=g-(c[t>>2]|0)|0;L=N+g|0;if(L>>>0>f>>>0|K>>>0>f>>>0){y=28;break}N=s+4|0;c[s>>2]=K+r;if(!(N>>>0<h>>>0)){y=30;break}D=L;E=w;F=N;G=0;H=(q|0)==0|0;I=t}if(D>>>0>=f>>>0|E>>>0>D>>>0){Y=I;Z=E}else{t=I;N=E;while(1){w=t+8|0;L=(c[t>>2]|0)+N+(c[t+4>>2]|0)|0;if(L>>>0>D>>>0){Y=w;Z=L;break}else{t=w;N=L}}}if(D>>>0<f>>>0){e=Y;q=H;r=G;s=F;g=Z;j=D}else{y=34;break}}if((y|0)==7){KIb(a,16,2350376,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((y|0)==13){KIb(a,16,2581408,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((y|0)==18){KIb(a,16,2437448,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((y|0)==21){KIb(a,16,2425680,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((y|0)==23){KIb(a,16,2581408,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((y|0)==26){RIb(a,2288808,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1163346256;i=k;return l|0}else if((y|0)==28){KIb(a,16,2581408,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((y|0)==30){KIb(a,16,2425680,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1094995529;i=k;return l|0}else if((y|0)==34){y=F+4|0;c[F>>2]=G;if((G|0)==0){l=0;i=k;return l|0}if(y>>>0<h>>>0){c[y>>2]=0;l=0;i=k;return l|0}else{KIb(a,16,2425680,(_=i,i=i+1|0,i=i+7&-8,c[_>>2]=0,_)|0);i=_;l=-1;i=k;return l|0}}return 0}function Hpb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;h=0;if((e|0)>0){j=(d&268435456|0)!=0?0:b;k=32;l=-1;m=e;n=0;o=0}else{i=g;return}while(1){e=n+1|0;b=c[f+(n<<2)>>2]|0;d=~l;p=m-b|0;if((b|0)>16){q=d&65535;r=b-17&-16;s=j;t=k;u=b;v=o;while(1){if((t|0)>16){w=t-16|0;x=v<<16|q;z=s}else{A=s;y=je(v<<t|q>>>((16-t|0)>>>0)|0)|0;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;w=t+16|0;x=q;z=s+4|0}h=x;A=u-16|0;if((A|0)>16){s=z;t=w;u=A;v=x}else{break}}B=z;C=w;D=b-16-r|0;E=x}else{B=j;C=k;D=b;E=o}if((D|0)==0){F=C;G=B;H=E}else{v=(1<<D)-1&d;if((C|0)>(D|0)){I=C;J=E<<D|v;K=B}else{u=B;y=je(E<<C|v>>>((D-C|0)>>>0)|0)|0;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;I=C+32|0;J=v;K=B+4|0}h=J;F=I-D|0;G=K;H=J}if((p|0)>0){j=G;k=F;l=d;m=p;n=e;o=H}else{break}}if((F|0)>=32){i=g;return}o=H<<F;h=o;H=o>>>24&255;o=F;F=G;while(1){a[F]=H;G=h;h=G<<8;n=o+8|0;if((n|0)<32){H=G>>>16&255;o=n;F=F+1|0}else{break}}i=g;return}function Ipb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+60>>2]|0;d=a+120|0;if((c[d>>2]|0)==0){e=-1094995529;return e|0}f=a+124|0;if((c[f>>2]|0)==0){e=-1094995529;return e|0}c[b+4>>2]=a;c[b+4752>>2]=c[a+88>>2];g=b+4760|0;c[g>>2]=UHb()|0;h=UHb()|0;c[b+4772>>2]=h;if((c[g>>2]|0)==0|(h|0)==0){e=-12;return e|0}l8(b+38528|0,a);c[b+4728>>2]=c[d>>2];c[b+4732>>2]=c[f>>2];c[b+40804>>2]=1;c[b+40800>>2]=1;e=0;return e|0}function Jpb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b+4792|0;c[d+4792>>2]=c[e>>2];c[d+4748>>2]=c[b+4748>>2];f=d+4796|0;g=c[f>>2]|0;a:do{if((c[e>>2]|0)>0){h=0;i=g;b:while(1){do{if((i|0)==0){j=d+4804+(h*2580|0)+2572|0;if((c[j>>2]|0)!=0){break}k=hJb((c[d+4804+(h*2580|0)+2564>>2]|0)*6|0)|0;c[j>>2]=k;if((k|0)==0){l=-12;m=10;break b}}else{k=d+4804+(h*2580|0)+2568|0;if((c[k>>2]|0)!=0){break}j=hJb(c[d+4804+(h*2580|0)+2564>>2]<<5)|0;c[k>>2]=j;if((j|0)==0){l=-12;m=10;break b}}}while(0);j=h+1|0;k=c[f>>2]|0;if((j|0)<(c[e>>2]|0)){h=j;i=k}else{n=k;break a}}if((m|0)==10){return l|0}}else{n=g}}while(0);if((n|0)>1){o=1}else{l=0;return l|0}while(1){n=a[b+38196+o|0]|0;a[d+280+o|0]=n;a[256-o+(d+24)|0]=-n;n=o+1|0;if((n|0)<256){o=n}else{l=0;break}}return l|0}function Kpb(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+40796|0;d=0;while(1){if((d|0)>=(c[b>>2]|0)){e=0;f=4;break}if((Jpb(a,c[a+39772+(d<<2)>>2]|0)|0)<0){e=-12;f=4;break}else{d=d+1|0}}if((f|0)==4){return e|0}return 0}function Lpb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;d=a+40804|0;e=a+40800|0;f=ca(c[e>>2]|0,c[d>>2]|0)|0;g=a+40796|0;c[g>>2]=f;if((f|0)<=0){KIb(0,0,2425648,(h=i,i=i+24|0,c[h>>2]=2581296,c[h+8>>2]=2437400,c[h+16>>2]=119,h)|0);i=h;Hd();return 0}h=a+4|0;j=a;k=0;l=f;while(1){if((k|0)>=(l|0)){m=0;n=8;break}f=pJb(40840)|0;o=c[d>>2]|0;p=(k|0)%(o|0)|0;q=(k|0)/(o|0)|0;r=c[h>>2]|0;s=c[r+120>>2]|0;t=(ca(s,p)|0)/(o|0)|0;u=c[r+124>>2]|0;r=ca(u,q)|0;v=c[e>>2]|0;w=(r|0)/(v|0)|0;if((f|0)==0){m=-12;n=8;break}r=(ca(u,q+1|0)|0)/(v|0)|0;v=(ca(s,p+1|0)|0)/(o|0)|0;c[a+39772+(k<<2)>>2]=f;nrc(f|0,j|0,40840)|0;mrc(f+4688|0,0,32)|0;c[f+40808>>2]=v-t;c[f+40812>>2]=r-w;c[f+40816>>2]=t;c[f+40820>>2]=w;w=hJb(((c[f+4728>>2]|0)*24|0)+144|0)|0;c[f+38492>>2]=w;if((w|0)==0){m=-12;n=8;break}k=k+1|0;l=c[g>>2]|0}if((n|0)==8){i=b;return m|0}return 0}function Mpb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+38524|0;if((c[b>>2]|0)>0){d=0}else{e=0;return e|0}while(1){f=a+38164+(d<<2)|0;g=hJb(c[f>>2]<<5)|0;c[a+38452+(d<<2)>>2]=g;if((g|0)==0){e=-12;h=4;break}mrc(g|0,-128|0,c[f>>2]<<5|0)|0;f=d+1|0;if((f|0)<(c[b>>2]|0)){d=f}else{e=0;h=4;break}}if((h|0)==4){return e|0}return 0}function Npb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d+4792|0;if((c[f>>2]|0)<=0){return}g=e+4796|0;h=0;do{a[e+4804+(h*2580|0)+2576|0]=-128;a[e+4804+(h*2580|0)+2577|0]=-128;do{if((c[g>>2]|0)==0){i=e+4804+(h*2580|0)+2564|0;if((c[i>>2]|0)<=0){break}j=e+4804+(h*2580|0)+2572|0;k=0;do{l=c[j>>2]|0;b[l+(k*6|0)>>1]=0;b[l+(k*6|0)+2>>1]=4;a[l+(k*6|0)+4|0]=0;a[(c[j>>2]|0)+(k*6|0)+5|0]=1;k=k+1|0;}while((k|0)<(c[i>>2]|0))}else{i=c[d+38452+(c[e+4804+(h*2580|0)+2560>>2]<<2)>>2]|0;k=c[e+4804+(h*2580|0)+2568>>2]|0;if((i|0)==0){mrc(k|0,-128|0,c[e+4804+(h*2580|0)+2564>>2]<<5|0)|0;break}else{nrc(k|0,i|0,c[e+4804+(h*2580|0)+2564>>2]<<5)|0;break}}}while(0);h=h+1|0;}while((h|0)<(c[f>>2]|0));return}function Opb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[a+60>>2]|0;d=b+4760|0;e=d;if((c[e>>2]|0)!=0){H5a(a,d)}VHb(e);e=b+4772|0;d=e;if((c[d>>2]|0)!=0){H5a(a,e)}VHb(d);d=b+40796|0;if((c[d>>2]|0)>0){e=b+39772|0;f=b+4792|0;g=0;do{h=c[e+(g<<2)>>2]|0;if((c[f>>2]|0)>0){i=0;do{mJb(h+4804+(i*2580|0)+2568|0);mJb(h+4804+(i*2580|0)+2572|0);i=i+1|0;}while((i|0)<(c[f>>2]|0))}mJb(h+38492|0);g=g+1|0;}while((g|0)<(c[d>>2]|0))}mJb(a+668|0);a=b+38524|0;if((c[a>>2]|0)>0){g=b+38452|0;f=b+4688|0;e=b+39772|0;i=0;do{mJb(g+(i<<2)|0);if((c[d>>2]|0)>0){j=0;do{mJb((c[e+(j<<2)>>2]|0)+4688+(i<<2)|0);j=j+1|0;}while((j|0)<(c[d>>2]|0))}mJb(f+(i<<2)|0);i=i+1|0;}while((i|0)<(c[a>>2]|0))}if((c[d>>2]|0)<=0){return 0}a=b+39772|0;b=0;do{mJb(a+(b<<2)|0);b=b+1|0;}while((b|0)<(c[d>>2]|0));return 0}function Ppb(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;d=a+54|0;Qpb(a,(ca(b[1386096+(c<<1)>>1]|0,b[d>>1]|0)|0)>>10);e=a+52|0;a=(((b[e>>1]|0)*127|0)>>7)+(b[920152+(c<<1)>>1]|0)|0;if((a|0)<0){f=0}else{f=(a|0)>18432?18432:a&65535}b[e>>1]=f;e=(f<<16>>16)-16384|0;f=b[1062856+((e>>>6&31)<<1)>>1]|0;a=e>>11;if((a|0)<0){g=f>>-a&65535;b[d>>1]=g;return}else{g=f<<a&65535;b[d>>1]=g;return}}function Qpb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=d+4|0;g=((c[f>>2]|0)+e|0)>>>31;h=d+8|0;i=a[h]|0;j=a[566664+((g|0)!=(i<<24>>24|0))|0]|0;k=d+9|0;l=a[566664+((g|0)==(a[k]|0))|0]|0;a[k]=i;a[h]=g;g=d+12|0;h=b[g>>1]|0;i=h<<16>>16;if(h<<16>>16<-8191){m=-8191}else{m=(i|0)>8191?8191:i}h=((ca(m,j)|0)>>5)+(l<<7)|0;l=d+14|0;m=h+(((b[l>>1]|0)*127|0)>>7)|0;if((m|0)<-12288){n=-12288}else{n=(m|0)>12288?12288:m&65535}b[l>>1]=n;l=n<<16>>16;n=15360-l|0;m=((i*255|0)>>8)+(j*-192|0)|0;j=-n|0;if((m|0)<(j|0)){o=j&65535}else{o=((m|0)>(n|0)?n:m)&65535}b[g>>1]=o;g=d+40|0;m=((b[g>>1]|0)*255|0)>>>8;if((e|0)==0){n=m&65535;b[g>>1]=n;j=d+42|0;i=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=i;j=d+44|0;h=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=h;j=d+46|0;k=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=k;j=d+48|0;p=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=p;j=d+50|0;q=((b[j>>1]|0)*255|0)>>>8&65535;b[j>>1]=q;r=c[d+32>>2]|0;s=c[d+28>>2]|0;t=c[d+24>>2]|0;u=c[d+20>>2]|0;v=c[d+16>>2]|0;w=q;x=p;y=k;z=h;A=i;B=n;C=d+36|0}else{n=c[d+16>>2]|0;i=((n^e)>>31&65280|128)+m&65535;b[g>>1]=i;g=d+42|0;m=c[d+20>>2]|0;h=((m^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=h;g=d+44|0;k=c[d+24>>2]|0;p=((k^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=p;g=d+46|0;q=c[d+28>>2]|0;j=((q^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=j;g=d+48|0;D=c[d+32>>2]|0;E=((D^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=E;g=d+50|0;F=d+36|0;G=((c[F>>2]^e)>>31&65280|128)+(((b[g>>1]|0)*255|0)>>>8)&65535;b[g>>1]=G;r=D;s=q;t=k;u=m;v=n;w=G;x=E;y=j;z=p;A=h;B=i;C=F}c[C>>2]=r;c[d+32>>2]=s;c[d+28>>2]=t;c[d+24>>2]=u;c[d+20>>2]=v;C=e<<1;if((C+32768|0)>>>0>65535>>>0){H=(C>>31^32767)&65535}else{H=C&65535}C=H<<16>>16;c[d+16>>2]=C;H=((ca(B<<16>>16,C)|0)>>15)+(((ca(A<<16>>16,v)|0)>>15)+(((ca(z<<16>>16,u)|0)>>15)+(((ca(y<<16>>16,t)|0)>>15)+(((ca(x<<16>>16,s)|0)>>15)+((ca(w<<16>>16,r)|0)>>15)))))|0;c[f>>2]=H;f=d|0;r=(b[f>>1]|0)+e<<1;if((r+32768|0)>>>0>65535>>>0){I=(r>>31^32767)&65535}else{I=r&65535}r=((ca(o<<16>>16,I<<16>>16)|0)>>15)+H|0;H=d+10|0;d=r+((ca(b[H>>1]|0,l)|0)>>15)|0;if(!((d+32768|0)>>>0>65535>>>0)){J=d&65535;b[f>>1]=J;b[H>>1]=I;return}J=(d>>31^32767)&65535;b[f>>1]=J;b[H>>1]=I;return}function Rpb(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;Qpb(a,c);c=a+52|0;e=(((b[c>>1]|0)*127|0)>>7)+(b[1109336+((d&1)<<1)>>1]|0)|0;if((e|0)<0){f=0}else{f=(e|0)>22528?22528:e&65535}b[c>>1]=f;c=(f<<16>>16)-20480|0;f=b[1062856+((c>>>6&31)<<1)>>1]|0;e=c>>11;if((e|0)<0){g=f>>-e&65535;h=a+54|0;b[h>>1]=g;return}else{g=f<<e&65535;h=a+54|0;b[h>>1]=g;return}}function Spb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;c[d>>2]=0;c[e>>2]=0;f=0;g=0;while(1){h=f<<1;c[e>>2]=(ca(b[692848+(f<<1)>>1]|0,b[a+(h<<1)>>1]|0)|0)+g;i=ca(b[692848+(11-f<<1)>>1]|0,b[a+((h|1)<<1)>>1]|0)|0;c[d>>2]=i+(c[d>>2]|0);i=f+1|0;if((i|0)>=12){break}f=i;g=c[e>>2]|0}return}function Tpb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=c[a+148>>2]|0;d=c[a+152>>2]|0;e=c[a+12544>>2]|0;if((c[a+14680>>2]&8388608|0)==0){return}f=c[a+12552>>2]|0;g=c[a+12548>>2]|0;Upb(e,b);Upb(e+8|0,b);a=b<<3;Upb(e+a|0,b);Upb(e+(a+8)|0,b);Upb(g,d);Upb(f,d);return}function Upb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+256|0;g=f|0;h=e*7|0;c[g>>2]=(d[b]|0)<<2;c[g+224>>2]=(d[b+h|0]|0)<<2;c[g+4>>2]=(d[b+1|0]|0)<<2;c[g+228>>2]=(d[b+(h+1)|0]|0)<<2;c[g+8>>2]=(d[b+2|0]|0)<<2;c[g+232>>2]=(d[b+(h+2)|0]|0)<<2;c[g+12>>2]=(d[b+3|0]|0)<<2;c[g+236>>2]=(d[b+(h+3)|0]|0)<<2;c[g+16>>2]=(d[b+4|0]|0)<<2;c[g+240>>2]=(d[b+(h+4)|0]|0)<<2;c[g+20>>2]=(d[b+5|0]|0)<<2;c[g+244>>2]=(d[b+(h+5)|0]|0)<<2;c[g+24>>2]=(d[b+6|0]|0)<<2;c[g+248>>2]=(d[b+(h+6)|0]|0)<<2;c[g+28>>2]=(d[b+7|0]|0)<<2;c[g+252>>2]=(d[b+(h+7)|0]|0)<<2;h=1;while(1){j=ca(h,e)|0;k=h<<3;l=0;do{m=l+j|0;c[g+(l+k<<2)>>2]=((d[b+m|0]|0)<<1)+(d[b+(m-e)|0]|0)+(d[b+(m+e)|0]|0);l=l+1|0;}while((l|0)<8);l=h+1|0;if((l|0)<7){h=l}else{n=0;break}}do{h=n<<3;l=c[g+(h<<2)>>2]|0;k=ca(n,e)|0;a[b+k|0]=(l+2|0)>>>2;a[b+(k+7)|0]=((c[g+((h|7)<<2)>>2]|0)+2|0)>>>2;j=h|1;a[b+(k+1)|0]=(l+8+(c[g+(j<<2)>>2]<<1)+(c[g+(j+1<<2)>>2]|0)|0)>>>4;j=h|2;a[b+(k+2)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+((h|3)<<2)>>2]|0)|0)>>>4;j=h|3;a[b+(k+3)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+(j+1<<2)>>2]|0)|0)>>>4;j=h|4;a[b+(k+4)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+((h|5)<<2)>>2]|0)|0)>>>4;j=h|5;a[b+(k+5)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+(j+1<<2)>>2]|0)|0)>>>4;j=h|6;a[b+(k+6)|0]=((c[g+(j-1<<2)>>2]|0)+8+(c[g+(j<<2)>>2]<<1)+(c[g+((h|7)<<2)>>2]|0)|0)>>>4;n=n+1|0;}while((n|0)<8);i=f;return}function Vpb(){if(a[1380320]|0){return}ATa(1379560,8373432);a[1380320]=1;return}function Wpb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;if((e|0)>0){g=32;h=0}else{j=32;while(1){k=j-1|0;if((k|0)>0){j=k}else{l=0;break}}i=f;return l|0}while(1){j=0;k=h;while(1){if((d[b+j|0]|0|0)==(g|0)){c[a+(j<<2)>>2]=k;m=k+1|0}else{m=k}n=j+1|0;if((n|0)<(e|0)){j=n;k=m}else{break}}if((m&1|0)!=0){break}k=g-1|0;if((k|0)>0){g=k;h=m>>>1}else{l=0;o=10;break}}if((o|0)==10){i=f;return l|0}KIb(0,16,2425520,(o=i,i=i+1|0,i=i+7&-8,c[o>>2]=0,o)|0);i=o;l=-1;i=f;return l|0}function Xpb(a){a=a|0;var b=0,d=0,e=0;b=a+108|0;d=hJb((c[b>>2]<<2)+16|0)|0;c[a+132>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+144>>2]=d;d=hJb((c[b>>2]<<2)+16|0)|0;c[a+136>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+148>>2]=d;d=hJb((c[b>>2]<<2)+16|0)|0;c[a+140>>2]=d;if((d|0)==0){e=-12;return e|0}c[a+152>>2]=d;e=0;return e|0}function Ypb(a){a=a|0;var b=0;b=c[a+60>>2]|0;c[b>>2]=a;c[b+116>>2]=c[a+88>>2];l8(b+860488|0,a);Hqb(b+861732|0,a);c[b+108>>2]=c[a+120>>2];c[b+112>>2]=c[a+124>>2];return}function Zpb(a){a=a|0;mJb(a+132|0);c[a+144>>2]=0;mJb(a+136|0);c[a+148>>2]=0;mJb(a+140|0);c[a+152>>2]=0;return}function _pb(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;c[a+512>>2]=b;f=0;g=0;h=0;while(1){c[5829724+(f*20|0)>>2]=2659648+(g<<2);j=e[3272+(h<<1)>>1]|0;c[5829732+(f*20|0)>>2]=j;k=j+g|0;$2(5829720+(f*20|0)|0,9,77,13314+(f*308|0)|0,4,2,13312+(f*308|0)|0,4,2,0,0,0,4)|0;c[5829884+(f*20|0)>>2]=2659648+(k<<2);j=e[3272+((h|1)<<1)>>1]|0;c[5829892+(f*20|0)>>2]=j;l=j+k|0;$2(5829880+(f*20|0)|0,9,77,8386+(f*308|0)|0,4,2,8384+(f*308|0)|0,4,2,0,0,0,4)|0;c[5830044+(f*20|0)>>2]=2659648+(l<<2);k=e[3272+((h|2)<<1)>>1]|0;c[5830052+(f*20|0)>>2]=k;j=k+l|0;$2(5830040+(f*20|0)|0,9,77,10850+(f*308|0)|0,4,2,10848+(f*308|0)|0,4,2,0,0,0,4)|0;c[5830204+(f*20|0)>>2]=2659648+(j<<2);l=e[3272+((h|3)<<1)>>1]|0;c[5830212+(f*20|0)>>2]=l;$2(5830200+(f*20|0)|0,9,77,5922+(f*308|0)|0,4,2,5920+(f*308|0)|0,4,2,0,0,0,4)|0;k=f+1|0;if((k|0)<8){f=k;g=l+j|0;h=h+4|0}else{m=0;n=18914;o=32;break}}while(1){c[5829404+(m*20|0)>>2]=2659648+(n<<2);h=e[3272+(o<<1)>>1]|0;c[5829412+(m*20|0)>>2]=h;g=h+n|0;$2(5829400+(m*20|0)|0,9,34,4834+(m*136|0)|0,4,2,4832+(m*136|0)|0,4,2,0,0,0,4)|0;c[5829564+(m*20|0)>>2]=2659648+(g<<2);h=e[3272+((o|1)<<1)>>1]|0;c[5829572+(m*20|0)>>2]=h;$2(5829560+(m*20|0)|0,9,34,3746+(m*136|0)|0,4,2,3744+(m*136|0)|0,4,2,0,0,0,4)|0;f=m+1|0;if((f|0)<8){m=f;n=h+g|0;o=o+2|0}else{break}}c[1457311]=2769176;c[1457313]=128;$2(5829240,7,12,3618,4,2,3616,4,2,0,0,0,4)|0;c[1457316]=2769688;c[1457318]=128;$2(5829260,7,12,3666,4,2,3664,4,2,0,0,0,4)|0;c[1457331]=2770200;c[1457333]=128;$2(5829320,7,12,3426,4,2,3424,4,2,0,0,0,4)|0;c[1457336]=2770712;c[1457338]=128;$2(5829340,7,12,3474,4,2,3472,4,2,0,0,0,4)|0;c[1457341]=2771224;c[1457343]=128;$2(5829360,7,12,3522,4,2,3520,4,2,0,0,0,4)|0;c[1457346]=2771736;c[1457348]=128;$2(5829380,7,12,3570,4,2,3568,4,2,0,0,0,4)|0;o=c[b+116>>2]|0;if((o|0)>0){c[a+36>>2]=pJb(o<<2)|0;Nhb(a+436|0);o=a+448|0;M6(o,c[a+444>>2]|0);L6(o,a+40|0,1246600);L6(o,a+172|0,1246728);L6(o,a+304|0,1246792);cqb(a+516|0);i=d;return}else{KIb(0,0,2425472,(d=i,i=i+24|0,c[d>>2]=2581240,c[d+8>>2]=2437328,c[d+16>>2]=695,d)|0);i=d;Hd()}}function $pb(a){a=a|0;mJb(a+36|0);return}function aqb(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0;h=i;i=i+48|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=e+512|0;q=c[p>>2]|0;r=q+14128|0;s=c[r>>2]|0;t=d[(c[q+14120>>2]|0)+(s>>>3)|0]<<(s&7)>>>7;c[r>>2]=((s|0)<(c[q+14136>>2]|0))+s;c[e+32>>2]=t&1;c[e+580>>2]=f;t=f>>1;s=e+576|0;c[s>>2]=t;c[e+584>>2]=g;g=((f>>2)+65536|0)/(t|0)|0;c[e+592>>2]=g;if((t|0)<5){c[e+588>>2]=t;c[e+596>>2]=g}else{g=(t+3>>3)+t|0;c[e+588>>2]=g;c[e+596>>2]=((g>>1)+65536|0)/(g|0)|0}mrc(e|0,0,32)|0;g=q+13704|0;c[g>>2]=0;t=q+13708|0;c[t>>2]=0;f=q+12480|0;c[f>>2]=0;r=q+120|0;if((c[r>>2]<<1|0)<=0){u=0;v=q+12476|0;w=q+14424|0;x=c[g>>2]|0;y=c[t>>2]|0;z=c[v>>2]|0;A=z>>1;B=A-1|0;C=u>>1;D=C-1|0;ypb(w,x,y,B,D,112);i=h;return 0}E=q+7656|0;F=q+7660|0;G=q+7624|0;H=q+12544|0;I=q+7628|0;J=q+12548|0;K=q+7632|0;L=q+12552|0;M=q+124|0;N=q+12476|0;O=q+116|0;P=e+600|0;Q=e+36|0;R=e+624|0;S=e+620|0;T=e+572|0;U=e+604|0;V=e+608|0;W=e+612|0;X=e+616|0;Y=e+588|0;Z=q+9928|0;_=q+9932|0;$=q+9136|0;aa=e+16|0;ba=0;a:while(1){da=c[F>>2]|0;ea=c[I>>2]|0;fa=c[K>>2]|0;c[H>>2]=(c[G>>2]|0)+(ca(ba<<3,c[E>>2]|0)|0);ga=ca(da<<2,ba&-2)|0;c[J>>2]=ea+ga;c[L>>2]=fa+ga;ga=c[M>>2]|0;c[N>>2]=0;if((c[O>>2]<<1|0)>0){fa=ca(ba>>1,ga)|0;while(1){ga=c[p>>2]|0;ea=ga+12476|0;da=(c[ea>>2]|0)==0|0;c[P>>2]=da;ha=ga+12480|0;ia=((c[ha>>2]|0)==0)<<1|da;c[P>>2]=ia;da=((c[ea>>2]|0)>=((c[ga+116>>2]<<1)-1|0))<<2|ia;c[P>>2]=da;do{if((ia|0)==3){c[R>>2]=16;c[S>>2]=0}else if((ia|0)==2){c[R>>2]=(d[(c[Q>>2]|0)+((c[ea>>2]<<1)-2)|0]|0)>>>2;c[S>>2]=2}else if((ia|0)==1){c[R>>2]=(d[(c[Q>>2]|0)+(c[ha>>2]&1^1)|0]|0)>>>2;c[S>>2]=1}else{ja=c[ea>>2]<<1;ka=c[ha>>2]&1;la=ka^1;ma=c[Q>>2]|0;na=d[ma+(la|ja)|0]|0;oa=ja-2|0;ja=d[ma+(oa|ka)|0]|0;ka=d[ma+(la|oa)|0]|0;oa=na>>>0>ja>>>0?ja:na;c[R>>2]=oa;if((c[ha>>2]&c[ea>>2]|0)==0){pa=oa}else{la=ka>>>0>oa>>>0?oa:ka;c[R>>2]=la;pa=la}c[R>>2]=pa>>2;la=-1379132>>>((ja<<3&24|na<<1&6)>>>0)&3;if((la|0)==3){c[S>>2]=16771800>>>((((c[s>>2]|0)>12)<<3|ka<<1&6)>>>0)&3;break}else{c[S>>2]=la;break}}}while(0);_e[c[T>>2]&511](c[ga+12544>>2]|0,c[ga+9944>>2]|0,c[ga+7656>>2]|0,j,k,da);ea=c[s>>2]|0;c[U>>2]=0;ha=c[j>>2]|0;ia=(ha|0)<3;do{if((ha|0)<(ea|0)|ia){c[S>>2]=0;if(!ia){break}c[U>>2]=1;la=(c[k>>2]|0)+9|0;c[k>>2]=la;c[V>>2]=(la*6899|0)>>17}}while(0);if((ha|0)<(ea<<1|0)){do{if((c[P>>2]&3|0)==0){ia=c[S>>2]|0;if((ia|0)==2){c[S>>2]=10;break}else if((ia|0)==1){c[S>>2]=11;break}else{break}}else{c[S>>2]=0}}while(0);c[W>>2]=0}else{ha=c[p>>2]|0;ia=c[aa>>2]|0;if((ia|0)==0){da=(ea|0)<13?2:1;ga=ha+14128|0;la=c[ga>>2]|0;ka=c[ha+14136>>2]|0;na=ha+14120|0;ja=(c[na>>2]|0)+(la>>>3)|0;oa=(je(d[ja]|d[ja+1|0]<<8|d[ja+2|0]<<16|d[ja+3|0]<<24|0)|0)<<(la&7)>>>((32-da|0)>>>0);ja=la+da|0;da=ka>>>0>ja>>>0?ja:ka;c[ga>>2]=da;ga=5829240+(((c[s>>2]|0)<13|0)*80|0)+(oa*20|0)|0;c[aa>>2]=ga;qa=ga;ra=da;sa=ka;ta=na}else{qa=ia;ra=c[ha+14128>>2]|0;sa=c[ha+14136>>2]|0;ta=ha+14120|0}ia=c[qa+4>>2]|0;na=(c[ta>>2]|0)+(ra>>>3)|0;ka=(je(d[na]|d[na+1|0]<<8|d[na+2|0]<<16|d[na+3|0]<<24|0)|0)<<(ra&7)>>>25;na=b[ia+(ka<<2)>>1]|0;da=na<<16>>16;ga=(b[ia+(ka<<2)+2>>1]|0)+ra|0;c[ha+14128>>2]=sa>>>0>ga>>>0?ga:sa;c[W>>2]=da;if(na<<16>>16<0){break a}c[S>>2]=d[3384+((c[S>>2]|0)*12|0)+da|0]|0}if((bqb(e,0)|0)!=0){break a}da=c[N>>2]|0;if((da&1&c[f>>2]|0)==0){ua=fa;va=da}else{da=c[p>>2]|0;na=da+12476|0;ga=(c[na>>2]|0)>>>0<2>>>0|0;c[P>>2]=ga;ha=((c[da+12480>>2]|0)>>>0<2>>>0)<<1|ga;c[P>>2]=ha;ga=((c[na>>2]|0)>=((c[da+116>>2]<<1)-1|0))<<2|ha;c[P>>2]=ga;c[W>>2]=0;if((ha|0)==0){wa=d[(c[Q>>2]|0)+((c[na>>2]<<1)-2)|0]<<2&12}else{wa=4<<(204>>>(ga>>>0)&1)}c[X>>2]=wa;_e[c[T>>2]&511](c[da+12548>>2]|0,c[da+9944>>2]|0,c[da+7660>>2]|0,l,m,ga);c[S>>2]=c[X>>2];ga=c[Y>>2]|0;c[U>>2]=0;da=c[l>>2]|0;na=(da|0)<3;do{if((da|0)<(ga|0)|na){c[S>>2]=0;if(!na){break}c[U>>2]=1;ha=(c[m>>2]|0)+9|0;c[m>>2]=ha;c[V>>2]=(ha*6899|0)>>17}}while(0);if((bqb(e,1)|0)!=0){break a}na=c[p>>2]|0;_e[c[T>>2]&511](c[na+12552>>2]|0,c[na+9944>>2]|0,c[na+7660>>2]|0,n,o,c[P>>2]|0);c[S>>2]=c[X>>2];na=c[Y>>2]|0;c[U>>2]=0;ga=c[n>>2]|0;da=(ga|0)<3;do{if((ga|0)<(na|0)|da){c[S>>2]=0;if(!da){break}c[U>>2]=1;ea=(c[o>>2]|0)+9|0;c[o>>2]=ea;c[V>>2]=(ea*6899|0)>>17}}while(0);if((bqb(e,2)|0)!=0){break a}c[J>>2]=(c[J>>2]|0)+8;c[L>>2]=(c[L>>2]|0)+8;a[(c[Z>>2]|0)+fa|0]=0;a[(c[_>>2]|0)+fa|0]=1;a[(c[$>>2]|0)+fa|0]=c[s>>2];ua=fa+1|0;va=c[N>>2]|0}c[H>>2]=(c[H>>2]|0)+8;da=va+1|0;c[N>>2]=da;if((da|0)<(c[O>>2]<<1|0)){fa=ua}else{break}}xa=c[f>>2]|0}else{xa=ba}if((xa&1|0)==0){ya=xa}else{MTa(q,(xa<<3)-8|0,16);ya=c[f>>2]|0}fa=ya+1|0;c[f>>2]=fa;if((fa|0)<(c[r>>2]<<1|0)){ba=fa}else{u=fa;v=N;za=53;break}}if((za|0)==53){w=q+14424|0;x=c[g>>2]|0;y=c[t>>2]|0;z=c[v>>2]|0;A=z>>1;B=A-1|0;C=u>>1;D=C-1|0;ypb(w,x,y,B,D,112);i=h;return 0}u=c[f>>2]|0;v=N;w=q+14424|0;x=c[g>>2]|0;y=c[t>>2]|0;z=c[v>>2]|0;A=z>>1;B=A-1|0;C=u>>1;D=C-1|0;ypb(w,x,y,B,D,112);i=h;return 0}function bqb(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;h=f+512|0;i=c[h>>2]|0;j=i+14340|0;qe[c[i+10092>>2]&1023](c[j>>2]|0);k=(g|0)!=0;if(k){l=2}else{l=(c[f+624>>2]|0)!=0|0}m=c[h>>2]|0;n=f+20+(l<<2)|0;l=c[n>>2]|0;o=m+14128|0;p=c[o>>2]|0;q=c[m+14136>>2]|0;r=m+14120|0;if((l|0)==0){m=(c[r>>2]|0)+(p>>>3)|0;s=(je(d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0)|0)<<(p&7)>>>29;m=p+3|0;t=q>>>0>m>>>0?m:q;c[o>>2]=t;m=5829400+(((c[f+576>>2]|0)<13|0)*160|0)+(s*20|0)|0;c[n>>2]=m;u=m;v=t}else{u=l;v=p}p=c[u+4>>2]|0;u=c[r>>2]|0;r=u+(v>>>3)|0;l=(je(d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0)|0)<<(v&7)>>>23;r=b[p+(l<<2)>>1]|0;t=b[p+(l<<2)+2>>1]|0;l=t<<16>>16;if(t<<16>>16<0){t=v+9|0;m=q>>>0>t>>>0?t:q;t=u+(m>>>3)|0;n=((je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(m&7)>>>((l+32|0)>>>0))+r|0;w=b[p+(n<<2)+2>>1]|0;x=b[p+(n<<2)>>1]|0;y=m}else{w=l;x=r;y=v}v=w+y|0;y=q>>>0>v>>>0?v:q;c[o>>2]=y;v=(x|0)>16;w=-(v&1)&17;r=x-w|0;do{if((r|0)<1){if((x|0)==(w|0)){z=0;break}else{A=-1}return A|0}else{l=r+1>>1;m=l-((l|0)>1)|0;l=u+(y>>>3)|0;n=(je(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)|0)<<(y&7)>>>((32-m|0)>>>0);l=m+y|0;c[o>>2]=q>>>0>l>>>0?l:q;l=n&1;z=((n>>1)+(d[1615424+r|0]|0)^-l)+l|0}}while(0);a:do{if(v){c[i+180>>2]=0;do{if((c[f+604>>2]|0)!=0){if(!((z+1|0)>>>0<3>>>0)){break}r=(ca(((ca(c[f+608>>2]|0,c[(k?f+596|0:f+592|0)>>2]|0)|0)+4096>>13)+z|0,c[(k?f+588|0:f+576|0)>>2]|0)|0)+4>>3;if(r>>>0>255>>>0){B=-r>>31&255}else{B=r&255}r=c[i+12544+(g<<2)>>2]|0;q=c[i+7656+((k&1)<<2)>>2]|0;mrc(r|0,B|0,8)|0;mrc(r+q|0,B|0,8)|0;o=q<<1;mrc(r+o|0,B|0,8)|0;y=o+q|0;mrc(r+y|0,B|0,8)|0;o=y+q|0;mrc(r+o|0,B|0,8)|0;y=o+q|0;mrc(r+y|0,B|0,8)|0;o=y+q|0;mrc(r+o|0,B|0,8)|0;mrc(r+(o+q)|0,B|0,8)|0;C=0;D=0;break a}}while(0);E=0;F=(z|0)==0|0;G=55}else{q=c[f+32>>2]|0;do{if(k){H=1;I=64;J=q}else{o=c[f+612>>2]|0;r=(o|0)<3?0:q;if((o|0)>4){H=0;I=64;J=r;break}o=c[f+624>>2]|0;y=(o|0)>1;H=y?2:3;I=y?o:64;J=r}}while(0);q=f+(H<<2)|0;r=c[q>>2]|0;if((r|0)==0){o=c[h>>2]|0;y=o+14128|0;u=c[y>>2]|0;w=c[o+14136>>2]|0;x=(c[o+14120>>2]|0)+(u>>>3)|0;o=(je(d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0)|0)<<(u&7)>>>29;x=u+3|0;c[y>>2]=w>>>0>x>>>0?x:w;w=f+576|0;x=5829720+(((c[w>>2]|0)<13|0)*320|0)+((H>>>1)*160|0)+(o*20|0)|0;c[q>>2]=x;K=x;L=w}else{K=r;L=f+576|0}r=9602376>>>(c[f+620>>2]<<1>>>0)&3;w=f+580|0;x=f+584|0;q=i+14128|0;o=i+14120|0;y=i+14136|0;u=f+12|0;b:do{if((J|0)==0){l=0;n=0;m=K;while(1){p=n+1|0;do{if((p|0)<(I|0)){M=m}else{t=c[u>>2]|0;if((t|0)!=0){M=t;break}t=c[h>>2]|0;s=t+14128|0;N=c[s>>2]|0;O=c[t+14136>>2]|0;P=(c[t+14120>>2]|0)+(N>>>3)|0;t=(je(d[P]|d[P+1|0]<<8|d[P+2|0]<<16|d[P+3|0]<<24|0)|0)<<(N&7)>>>29;P=N+3|0;c[s>>2]=O>>>0>P>>>0?P:O;O=5829880+(((c[L>>2]|0)<13|0)*320|0)+(t*20|0)|0;c[u>>2]=O;M=O}}while(0);O=c[h>>2]|0;t=c[M+4>>2]|0;P=O+14128|0;s=c[P>>2]|0;N=c[O+14136>>2]|0;Q=c[O+14120>>2]|0;O=Q+(s>>>3)|0;R=(je(d[O]|d[O+1|0]<<8|d[O+2|0]<<16|d[O+3|0]<<24|0)|0)<<(s&7)>>>23;O=b[t+(R<<2)>>1]|0;S=b[t+(R<<2)+2>>1]|0;R=S<<16>>16;if(S<<16>>16<0){S=s+9|0;T=N>>>0>S>>>0?S:N;S=Q+(T>>>3)|0;U=((je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(T&7)>>>((R+32|0)>>>0))+O|0;V=b[t+(U<<2)+2>>1]|0;W=b[t+(U<<2)>>1]|0;X=T}else{V=R;W=O;X=s}s=V+X|0;O=N>>>0>s>>>0?s:N;c[P>>2]=O;do{if((W|0)<46){if((W|0)<0){Y=64;Z=64;_=64;break}s=(W|0)>22|0;R=W-(-s&23)|0;T=15007744>>>((R&30)>>>0)&3;Y=T;Z=66319>>>(T<<3>>>0)&R;_=s}else{if((W|0)<73){s=W-46|0;R=c[2087384+(s<<2)>>2]|0;T=R&15;U=Q+(O>>>3)|0;t=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(O&7)>>>((32-T|0)>>>0);U=T+O|0;c[P>>2]=N>>>0>U>>>0?U:N;U=R>>>8;Y=(t&((U|-256)^255))+(R>>>24)|0;Z=(U&255&t)+(R>>>16&255)|0;_=(s|0)>12|0;break}s=W&1;if((W|0)<75){R=Q+(O>>>3)|0;t=(je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(O&7)>>>27;R=O+5|0;c[P>>2]=N>>>0>R>>>0?R:N;R=d[3712+t|0]|0;Y=R&15;Z=R>>>4;_=s^1;break}else{R=-s&3^7;s=Q+(O>>>3)|0;t=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(O&7)>>>((32-R|0)>>>0);s=O+R|0;R=N>>>0>s>>>0?s:N;c[P>>2]=R;s=Q+(R>>>3)|0;U=(je(d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0)|0)<<(R&7)>>>26;s=R+6|0;R=N>>>0>s>>>0?s:N;c[P>>2]=R;s=d[Q+(R>>>3)|0]<<(R&7)>>>7;c[P>>2]=((R|0)<(N|0))+R;Y=t;Z=U;_=s&1;break}}}while(0);N=l+1+Z|0;if((N|0)>63){A=-1;break}P=ca(c[w>>2]|0,Y+1|0)|0;Q=P+(c[x>>2]|0)|0;P=c[q>>2]|0;O=d[(c[o>>2]|0)+(P>>>3)|0]<<(P&7)>>>7;c[q>>2]=((P|0)<(c[y>>2]|0))+P;P=O&1;b[(c[j>>2]|0)+(d[f+40+(r*132|0)+4+N|0]<<1)>>1]=(Q^-P)+P;if((_|0)==0){l=N;n=p;m=M}else{$=p;aa=N;break b}}return A|0}else{m=0;n=0;l=K;while(1){N=n+1|0;do{if((N|0)<(I|0)){ba=l}else{P=c[u>>2]|0;if((P|0)!=0){ba=P;break}P=c[h>>2]|0;Q=P+14128|0;O=c[Q>>2]|0;s=c[P+14136>>2]|0;U=(c[P+14120>>2]|0)+(O>>>3)|0;P=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(O&7)>>>29;U=O+3|0;c[Q>>2]=s>>>0>U>>>0?U:s;s=5829880+(((c[L>>2]|0)<13|0)*320|0)+(P*20|0)|0;c[u>>2]=s;ba=s}}while(0);p=c[h>>2]|0;s=c[ba+4>>2]|0;P=p+14128|0;U=c[P>>2]|0;Q=c[p+14136>>2]|0;O=c[p+14120>>2]|0;p=O+(U>>>3)|0;t=(je(d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0)|0)<<(U&7)>>>23;p=b[s+(t<<2)>>1]|0;R=b[s+(t<<2)+2>>1]|0;t=R<<16>>16;if(R<<16>>16<0){R=U+9|0;T=Q>>>0>R>>>0?R:Q;R=O+(T>>>3)|0;S=((je(d[R]|d[R+1|0]<<8|d[R+2|0]<<16|d[R+3|0]<<24|0)|0)<<(T&7)>>>((t+32|0)>>>0))+p|0;da=b[s+(S<<2)+2>>1]|0;ea=b[s+(S<<2)>>1]|0;fa=T}else{da=t;ea=p;fa=U}U=da+fa|0;p=Q>>>0>U>>>0?U:Q;c[P>>2]=p;do{if((ea|0)<46){if((ea|0)<0){ga=64;ha=64;ia=64;break}U=(ea|0)>22|0;t=ea-(-U&23)|0;T=15007744>>>((t&30)>>>0)&3;ga=T;ha=66319>>>(T<<3>>>0)&t;ia=U}else{if((ea|0)<73){U=ea-46|0;t=c[2087384+(U<<2)>>2]|0;T=t&15;S=O+(p>>>3)|0;s=(je(d[S]|d[S+1|0]<<8|d[S+2|0]<<16|d[S+3|0]<<24|0)|0)<<(p&7)>>>((32-T|0)>>>0);S=T+p|0;c[P>>2]=Q>>>0>S>>>0?S:Q;S=t>>>8;ga=(s&((S|-256)^255))+(t>>>24)|0;ha=(S&255&s)+(t>>>16&255)|0;ia=(U|0)>12|0;break}U=ea&1;if((ea|0)<75){t=O+(p>>>3)|0;s=(je(d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0)|0)<<(p&7)>>>27;t=p+5|0;c[P>>2]=Q>>>0>t>>>0?t:Q;t=d[3712+s|0]|0;ga=t&15;ha=t>>>4;ia=U^1;break}else{t=-U&3^7;U=O+(p>>>3)|0;s=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(p&7)>>>((32-t|0)>>>0);U=p+t|0;t=Q>>>0>U>>>0?U:Q;c[P>>2]=t;U=O+(t>>>3)|0;S=(je(d[U]|d[U+1|0]<<8|d[U+2|0]<<16|d[U+3|0]<<24|0)|0)<<(t&7)>>>26;U=t+6|0;t=Q>>>0>U>>>0?U:Q;c[P>>2]=t;U=d[O+(t>>>3)|0]<<(t&7)>>>7;c[P>>2]=((t|0)<(Q|0))+t;ga=s;ha=S;ia=U&1;break}}}while(0);Q=m+1+ha|0;if((Q|0)>63){A=-1;break}P=c[w>>2]|0;O=c[x>>2]|0;p=c[q>>2]|0;U=d[(c[o>>2]|0)+(p>>>3)|0]<<(p&7)>>>7;c[q>>2]=((p|0)<(c[y>>2]|0))+p;p=U&1;U=((ca(P,ga+1|0)|0)+O^-p)+p|0;p=(ca(b[687624+(Q<<1)>>1]|0,U)|0)>>>8&65535;b[(c[j>>2]|0)+(d[f+40+(r*132|0)+4+Q|0]<<1)>>1]=p;if((ia|0)==0){m=Q;n=N;l=ba}else{$=N;aa=Q;break b}}return A|0}}while(0);c[i+180>>2]=aa;E=$;F=0;G=55}}while(0);do{if((G|0)==55){if(k){$=(ca(c[f+588>>2]|0,z)|0)&65535;b[c[j>>2]>>1]=$;ja=$}else{$=(ca(c[f+576>>2]|0,z)|0)&65535;b[c[j>>2]>>1]=$;ja=$}do{if((z+1|0)>>>0>2>>>0){if((c[f+600>>2]&3|0)==3){break}$=6947196>>>(c[f+620>>2]<<1>>>0)&3;if(($|0)==3){break}aa=ja<<16>>16;ba=c[h>>2]|0;if(($|0)==2){ia=c[ba+14340>>2]|0;ga=ia+(d[f+449|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*6269|0)+32768|0)>>>16);ga=ia+(d[f+451|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*708|0)+32768|0)>>>16);ga=ia+(d[f+453|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*172|0)+32768|0)>>>16);ga=ia+(d[f+455|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*73|0)+32768|0)>>>16);ga=ba+180|0;ia=c[ga>>2]|0;c[ga>>2]=(ia|0)>7?ia:7;break}else if(($|0)==0){ia=(aa*3811|0)+32768>>16;ga=c[ba+14340>>2]|0;ha=ga+(d[f+449|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+456|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ia=(aa*487|0)+32768>>16;ha=ga+(d[f+450|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+464|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ia=(aa*506|0)+32768>>16;ha=ga+(d[f+451|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+472|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ia=(aa*135|0)+32768>>16;ha=ga+(d[f+452|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+480|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+458|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+465|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+459|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+473|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ia=(aa*173|0)+32768>>16;ha=ga+(d[f+453|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+488|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ia=(aa*61|0)+32768>>16;ha=ga+(d[f+454|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+496|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+461|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+489|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ia=(aa*42|0)+32768>>16;ha=ga+(d[f+455|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+504|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)-ia;ha=ga+(d[f+460|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+481|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ha=ga+(d[f+484|0]<<1)|0;b[ha>>1]=(e[ha>>1]|0)+ia;ia=ga+(d[f+457|0]<<1)|0;b[ia>>1]=(e[ia>>1]|0)+(((aa*1084|0)+32768|0)>>>16);ia=ba+180|0;ga=c[ia>>2]|0;c[ia>>2]=(ga|0)>56?ga:56;break}else if(($|0)==1){$=c[ba+14340>>2]|0;ga=$+(d[f+456|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*6269|0)+32768|0)>>>16);ga=$+(d[f+472|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*708|0)+32768|0)>>>16);ga=$+(d[f+488|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*172|0)+32768|0)>>>16);ga=$+(d[f+504|0]<<1)|0;b[ga>>1]=(e[ga>>1]|0)-(((aa*73|0)+32768|0)>>>16);aa=ba+180|0;ba=c[aa>>2]|0;c[aa>>2]=(ba|0)>56?ba:56;break}else{break}}}while(0);if((c[f+604>>2]|0)==0){ef[c[f+524+(c[f+620>>2]<<2)>>2]&4095](c[i+9944>>2]|0,c[i+12544+(g<<2)>>2]|0,c[i+7656+((k&1)<<2)>>2]|0)}else{ba=c[f+608>>2]&255;aa=c[i+12544+(g<<2)>>2]|0;ga=c[i+7656+((k&1)<<2)>>2]|0;mrc(aa|0,ba|0,8)|0;mrc(aa+ga|0,ba|0,8)|0;$=ga<<1;mrc(aa+$|0,ba|0,8)|0;ia=$+ga|0;mrc(aa+ia|0,ba|0,8)|0;$=ia+ga|0;mrc(aa+$|0,ba|0,8)|0;ia=$+ga|0;mrc(aa+ia|0,ba|0,8)|0;$=ia+ga|0;mrc(aa+$|0,ba|0,8)|0;mrc(aa+($+ga)|0,ba|0,8)|0}if((F|0)!=0){C=E;D=F;break}ef[c[f+436>>2]&4095](c[i+12544+(g<<2)>>2]|0,c[i+7656+((k&1)<<2)>>2]|0,c[j>>2]|0);C=E;D=0}}while(0);if(!k){E=c[f+620>>2]|0;j=c[h>>2]|0;a[(c[f+36>>2]|0)+(c[j+12480>>2]&1|c[j+12476>>2]<<1)|0]=(E|0)==4|C<<2|((E|0)==8)<<1}if((c[i+13836>>2]|0)==0){A=0;return A|0}E=c[i+12544+(g<<2)>>2]|0;g=c[i+7656+((k&1)<<2)>>2]|0;k=f+600|0;i=c[k>>2]|0;do{if((i&2|0)==0){if((D|0)!=0){if((c[f+620>>2]|4|0)==4){ka=i;break}}ef[c[f+520>>2]&4095](E,g,c[f+576>>2]|0);ka=c[k>>2]|0}else{ka=i}}while(0);if((ka&1|0)!=0){A=0;return A|0}do{if((D|0)!=0){if((c[f+620>>2]|8|0)==8){A=0}else{break}return A|0}}while(0);ef[c[f+516>>2]&4095](E,g,c[f+576>>2]|0);A=0;return A|0}function cqb(a){a=a|0;c[a+4>>2]=1534;c[a>>2]=218;c[a+56>>2]=58;c[a+8>>2]=1806;c[a+12>>2]=706;c[a+16>>2]=268;c[a+20>>2]=708;c[a+24>>2]=1798;c[a+28>>2]=702;c[a+32>>2]=704;c[a+36>>2]=1804;c[a+40>>2]=710;c[a+44>>2]=712;c[a+48>>2]=2358;c[a+52>>2]=2360;return}function dqb(a,b,c){a=a|0;b=b|0;c=c|0;sqb(a,b,1,c);return}function eqb(a,b,c){a=a|0;b=b|0;c=c|0;sqb(a,1,b,c);return}function fqb(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;j=i&3;if((j|0)==3){c[h>>2]=2432;c[g>>2]=0;mrc(e|0,-128|0,41)|0;return}k=(i&1|0)!=0;if(k){l=0;m=-1;n=256}else{a[e+7|0]=a[b-2|0]|0;o=a[b-1|0]|0;p=o&255;a[e+15|0]=o;q=f-1|0;a[e+6|0]=a[b+(f-2)|0]|0;r=a[b+q|0]|0;s=r&255;t=(o&255)>>>0>(r&255)>>>0;o=t?s:p;u=t?p:s;a[e+14|0]=r;r=q+f|0;a[e+5|0]=a[b+(r-1)|0]|0;q=a[b+r|0]|0;t=q&255;v=o>>>0>t>>>0?t:o;o=u>>>0>t>>>0?u:t;a[e+13|0]=q;q=r+f|0;a[e+4|0]=a[b+(q-1)|0]|0;r=a[b+q|0]|0;u=r&255;w=v>>>0>u>>>0?u:v;v=o>>>0>u>>>0?o:u;a[e+12|0]=r;r=q+f|0;a[e+3|0]=a[b+(r-1)|0]|0;q=a[b+r|0]|0;o=q&255;x=w>>>0>o>>>0?o:w;w=v>>>0>o>>>0?v:o;a[e+11|0]=q;q=r+f|0;a[e+2|0]=a[b+(q-1)|0]|0;r=a[b+q|0]|0;v=r&255;z=x>>>0>v>>>0?v:x;x=w>>>0>v>>>0?w:v;a[e+10|0]=r;r=q+f|0;a[e+1|0]=a[b+(r-1)|0]|0;q=a[b+r|0]|0;w=q&255;A=z>>>0>w>>>0?w:z;z=x>>>0>w>>>0?x:w;a[e+9|0]=q;q=r+f|0;a[e]=a[b+(q-1)|0]|0;r=a[b+q|0]|0;q=r&255;a[e+8|0]=r;l=q+(w+(v+(o+(u+(t+(s+p))))))|0;m=(z|0)>(q|0)?z:q;n=(A|0)>(q|0)?q:A}if((i&2|0)==0){A=-f|0;q=b+A|0;z=d[q]|0;p=(n|0)>(z|0)?z:n;s=(m|0)>(z|0)?m:z;t=d[b+(1-f)|0]|0;u=(p|0)>(t|0)?t:p;p=(s|0)>(t|0)?s:t;s=d[b+(2-f)|0]|0;o=(u|0)>(s|0)?s:u;u=(p|0)>(s|0)?p:s;p=d[b+(3-f)|0]|0;v=(o|0)>(p|0)?p:o;o=(u|0)>(p|0)?u:p;u=d[b+(4-f)|0]|0;w=(v|0)>(u|0)?u:v;v=(o|0)>(u|0)?o:u;o=d[b+(5-f)|0]|0;r=(w|0)>(o|0)?o:w;w=(v|0)>(o|0)?v:o;v=d[b+(6-f)|0]|0;x=(r|0)>(v|0)?v:r;r=(w|0)>(v|0)?w:v;w=a[b+(7-f)|0]|0;B=w&255;if((i&4|0)==0){nrc(e+17|0,q|0,16)|0}else{mrc(e+25|0,w|0,8)|0;w=q;q=e+17|0;i=w|0;C=w+4|0;w=d[C]|d[C+1|0]<<8|d[C+2|0]<<16|d[C+3|0]<<24|0;C=q|0;y=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y;C=q+4|0;y=w;a[C]=y;y=y>>8;a[C+1|0]=y;y=y>>8;a[C+2|0]=y;y=y>>8;a[C+3|0]=y}C=b+(A<<1)|0;A=e+33|0;w=C|0;q=C+4|0;C=d[q]|d[q+1|0]<<8|d[q+2|0]<<16|d[q+3|0]<<24|0;q=A|0;y=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;q=A+4|0;y=C;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;D=B+(v+(o+(u+(p+(s+(t+(z+l)))))))|0;E=(r|0)>(B|0)?r:B;F=(x|0)>(B|0)?B:x}else{D=l;E=m;F=n}if((j|0)==0){j=a[b+~f|0]|0;a[e+16|0]=j;G=j&255}else{j=D+4>>3;if(k){mrc(e|0,j&255|0,17)|0}else{mrc(e+16|0,j&255|0,25)|0}G=j*9|0}c[g>>2]=E-F;c[h>>2]=G+D+(d[e+25|0]|0)+(d[e+26|0]|0);return}function gqb(c,f,g){c=c|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+64|0;j=h|0;k=h+32|0;mrc(j|0,0,32)|0;mrc(k|0,0,32)|0;l=0;while(1){m=(d[c+(15-l)|0]|0)<<4;n=j+((l&1)<<4)|0;b[n>>1]=(e[n>>1]|0)+(m>>>(l>>>1>>>0));n=(l|0)>0?l-1|0:1-l|0;o=j+((n&1)<<4)+2|0;b[o>>1]=(e[o>>1]|0)+(m>>>(n>>>1>>>0));n=l-2|0;o=(n|0)>-1?n:2-l|0;n=j+((o&1)<<4)+4|0;b[n>>1]=(e[n>>1]|0)+(m>>>(o>>>1>>>0));o=l-3|0;n=(o|0)>-1?o:3-l|0;o=j+((n&1)<<4)+6|0;b[o>>1]=(e[o>>1]|0)+(m>>>(n>>>1>>>0));n=l-4|0;o=(n|0)>-1?n:4-l|0;n=j+((o&1)<<4)+8|0;b[n>>1]=(e[n>>1]|0)+(m>>>(o>>>1>>>0));o=l-5|0;n=(o|0)>-1?o:5-l|0;o=j+((n&1)<<4)+10|0;b[o>>1]=(e[o>>1]|0)+(m>>>(n>>>1>>>0));n=l-6|0;o=(n|0)>-1?n:6-l|0;n=j+((o&1)<<4)+12|0;b[n>>1]=(e[n>>1]|0)+(m>>>(o>>>1>>>0));o=l-7|0;n=(o|0)>-1?o:7-l|0;o=j+((n&1)<<4)+14|0;b[o>>1]=(e[o>>1]|0)+(m>>>(n>>>1>>>0));n=l+1|0;if((n|0)<8){l=n}else{p=0;break}}do{l=(d[c+(p+17)|0]|0)<<4;n=k+((p&1)<<4)|0;b[n>>1]=(e[n>>1]|0)+(l>>>(p>>>1>>>0));n=(p|0)>0?p-1|0:1-p|0;m=k+((n&1)<<4)+2|0;b[m>>1]=(e[m>>1]|0)+(l>>>(n>>>1>>>0));n=p-2|0;m=(n|0)>-1?n:2-p|0;n=k+((m&1)<<4)+4|0;b[n>>1]=(e[n>>1]|0)+(l>>>(m>>>1>>>0));m=p-3|0;n=(m|0)>-1?m:3-p|0;m=k+((n&1)<<4)+6|0;b[m>>1]=(e[m>>1]|0)+(l>>>(n>>>1>>>0));n=p-4|0;m=(n|0)>-1?n:4-p|0;n=k+((m&1)<<4)+8|0;b[n>>1]=(e[n>>1]|0)+(l>>>(m>>>1>>>0));m=p-5|0;n=(m|0)>-1?m:5-p|0;m=k+((n&1)<<4)+10|0;b[m>>1]=(e[m>>1]|0)+(l>>>(n>>>1>>>0));n=p-6|0;m=(n|0)>-1?n:6-p|0;n=k+((m&1)<<4)+12|0;b[n>>1]=(e[n>>1]|0)+(l>>>(m>>>1>>>0));m=p-7|0;n=(m|0)>-1?m:7-p|0;m=k+((n&1)<<4)+14|0;b[m>>1]=(e[m>>1]|0)+(l>>>(n>>>1>>>0));p=p+1|0;}while((p|0)<8);p=d[c+25|0]|0;n=p<<3;l=k+26|0;b[l>>1]=(e[l>>1]|0)+n;l=k+12|0;b[l>>1]=(e[l>>1]|0)+n;n=k+30|0;b[n>>1]=(e[n>>1]|0)+(p<<4);p=d[c+26|0]|0;n=p<<3;l=k+10|0;b[l>>1]=(e[l>>1]|0)+(p<<2);p=k+28|0;b[p>>1]=(e[p>>1]|0)+n;p=k+14|0;b[p>>1]=(e[p>>1]|0)+n;n=10;while(1){p=n-7|0;l=(p|0)>-1?p:7-n|0;p=k+((l&1)<<4)+14|0;b[p>>1]=(e[p>>1]|0)+((d[c+(n+17)|0]|0)<<4>>>(l>>>1>>>0));l=n+1|0;if((l|0)<12){n=l}else{q=0;break}}while(1){n=k+(q<<1)|0;b[n>>1]=((((e[k+16+(q<<1)>>1]|0)*181|0)+128|0)>>>8)+(e[n>>1]|0);n=j+(q<<1)|0;b[n>>1]=((((e[j+16+(q<<1)>>1]|0)*181|0)+128|0)>>>8)+(e[n>>1]|0);n=q+1|0;if((n|0)<8){q=n}else{r=f;s=0;break}}while(1){f=s<<4;q=j+(s<<1)|0;n=0;do{c=(n<<1)+f|0;l=ca(e[424+(c<<1)>>1]|0,e[k+(n<<1)>>1]|0)|0;a[r+n|0]=(l+32768+(ca(e[424+((c|1)<<1)>>1]|0,e[q>>1]|0)|0)|0)>>>16;n=n+1|0;}while((n|0)<8);n=s+1|0;if((n|0)<8){r=r+g|0;s=n}else{break}}i=h;return}function hqb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=0;while(1){f=c<<1;a[e]=a[b+((f+2|0)>15?32:f+19|0)|0]|0;g=f|1;a[e+1|0]=a[b+((g+2|0)>15?32:g+19|0)|0]|0;a[e+2|0]=a[b+((f+4|0)>15?32:f+21|0)|0]|0;a[e+3|0]=a[b+((f+5|0)>15?32:f+22|0)|0]|0;a[e+4|0]=a[b+((f+6|0)>15?32:f+23|0)|0]|0;a[e+5|0]=a[b+((f+7|0)>15?32:f+24|0)|0]|0;a[e+6|0]=a[b+((f+8|0)>15?32:f+25|0)|0]|0;a[e+7|0]=a[b+((f+9|0)>15?32:f+26|0)|0]|0;f=c+1|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function iqb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;e=c;c=0;while(1){a[e]=a[b+(c+18)|0]|0;a[e+1|0]=a[b+(c+19)|0]|0;a[e+2|0]=a[b+(c+20)|0]|0;a[e+3|0]=a[b+(c+21)|0]|0;a[e+4|0]=a[b+(c+22)|0]|0;a[e+5|0]=a[b+(c+23)|0]|0;a[e+6|0]=a[b+(c+24)|0]|0;a[e+7|0]=a[b+(c+25)|0]|0;f=c+1|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function jqb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c;c=0;while(1){f=c+1|0;g=f>>1;a[e]=a[b+(g+17)|0]|0;a[e+1|0]=a[b+(g+18)|0]|0;a[e+2|0]=a[b+(g+19)|0]|0;a[e+3|0]=a[b+(g+20)|0]|0;a[e+4|0]=a[b+(g+21)|0]|0;a[e+5|0]=a[b+(g+22)|0]|0;a[e+6|0]=a[b+(g+23)|0]|0;a[e+7|0]=a[b+(g+24)|0]|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function kqb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=b+17|0;g=c;c=0;while(1){a[g]=((d[f]|0)+1+(d[b+33|0]|0)|0)>>>1;a[g+1|0]=((d[b+18|0]|0)+1+(d[b+34|0]|0)|0)>>>1;a[g+2|0]=((d[b+19|0]|0)+1+(d[b+35|0]|0)|0)>>>1;a[g+3|0]=((d[b+20|0]|0)+1+(d[b+36|0]|0)|0)>>>1;a[g+4|0]=((d[b+21|0]|0)+1+(d[b+37|0]|0)|0)>>>1;a[g+5|0]=((d[b+22|0]|0)+1+(d[b+38|0]|0)|0)>>>1;a[g+6|0]=((d[b+23|0]|0)+1+(d[b+39|0]|0)|0)>>>1;a[g+7|0]=((d[b+24|0]|0)+1+(d[b+40|0]|0)|0)>>>1;h=c+1|0;if((h|0)<8){g=g+e|0;c=h}else{break}}return}function lqb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c;c=0;while(1){f=17-c|0;g=c+1|0;h=17-(g>>1)|0;i=0;do{j=i<<1;if((j-c|0)<0){a[e+i|0]=a[b+(f+j)|0]|0}else{a[e+i|0]=a[b+(h+i)|0]|0}i=i+1|0;}while((i|0)<8);if((g|0)<8){e=e+d|0;c=g}else{break}}return}function mqb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;e=c;c=0;while(1){f=16-c|0;a[e]=a[b+f|0]|0;a[e+1|0]=a[b+(f+1)|0]|0;a[e+2|0]=a[b+(f+2)|0]|0;a[e+3|0]=a[b+(f+3)|0]|0;a[e+4|0]=a[b+(f+4)|0]|0;a[e+5|0]=a[b+(f+5)|0]|0;a[e+6|0]=a[b+(f+6)|0]|0;a[e+7|0]=a[b+(f+7)|0]|0;f=c+1|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function nqb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c;c=0;while(1){g=c<<1;h=15-g|0;i=16-g|0;j=16-c|0;k=0;do{if((k-g|0)>0){a[f+k|0]=((d[b+(h+k)|0]|0)+1+(d[b+(i+k)|0]|0)|0)>>>1}else{a[f+k|0]=a[b+(j+(k>>1))|0]|0}k=k+1|0;}while((k|0)<8);k=c+1|0;if((k|0)<8){f=f+e|0;c=k}else{break}}return}function oqb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=c;c=0;while(1){g=b+(7-c)|0;h=b+(15-c)|0;a[f]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+1|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+2|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+3|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+4|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+5|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+6|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;a[f+7|0]=((d[g]|0)+1+(d[h]|0)|0)>>>1;h=c+1|0;if((h|0)<8){f=f+e|0;c=h}else{break}}return}function pqb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;e=c;c=0;while(1){a[e]=a[b+((c|0)>6?8:14-c|0)|0]|0;f=c+1|0;a[e+1|0]=a[b+((f|0)>6?8:13-c|0)|0]|0;a[e+2|0]=a[b+((c+2|0)>6?8:12-c|0)|0]|0;a[e+3|0]=a[b+((c+3|0)>6?8:11-c|0)|0]|0;a[e+4|0]=a[b+((c+4|0)>6?8:10-c|0)|0]|0;a[e+5|0]=a[b+((c+5|0)>6?8:9-c|0)|0]|0;a[e+6|0]=a[b+((c|0)>0?8:8-c|0)|0]|0;a[e+7|0]=a[b+8|0]|0;if((f|0)<8){e=e+d|0;c=f}else{break}}return}function qqb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0;f=c;c=0;while(1){g=b+(15-c)|0;a[f]=a[g]|0;a[f+1|0]=(((d[g]|0)*7|0)+4+(d[b+18|0]|0)|0)>>>3;a[f+2|0]=(((d[g]|0)*6|0)+4+((d[b+19|0]|0)<<1)|0)>>>3;a[f+3|0]=(((d[g]|0)*5|0)+4+((d[b+20|0]|0)*3|0)|0)>>>3;a[f+4|0]=(((d[g]|0)<<2)+4+((d[b+21|0]|0)<<2)|0)>>>3;a[f+5|0]=(((d[g]|0)*3|0)+4+((d[b+22|0]|0)*5|0)|0)>>>3;a[f+6|0]=(((d[g]|0)<<1)+4+((d[b+23|0]|0)*6|0)|0)>>>3;a[f+7|0]=((d[g]|0)+4+((d[b+24|0]|0)*7|0)|0)>>>3;g=c+1|0;if((g|0)<8){f=f+e|0;c=g}else{break}}return}function rqb(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0;f=c;c=0;while(1){g=b+(15-c)|0;h=8-c|0;i=ca(d[g]|0,c)|0;a[f]=(i+4+(ca(d[b+17|0]|0,h)|0)|0)>>>3;i=ca(d[g]|0,c)|0;a[f+1|0]=(i+4+(ca(d[b+18|0]|0,h)|0)|0)>>>3;i=ca(d[g]|0,c)|0;a[f+2|0]=(i+4+(ca(d[b+19|0]|0,h)|0)|0)>>>3;i=ca(d[g]|0,c)|0;a[f+3|0]=(i+4+(ca(d[b+20|0]|0,h)|0)|0)>>>3;i=ca(d[g]|0,c)|0;a[f+4|0]=(i+4+(ca(d[b+21|0]|0,h)|0)|0)>>>3;i=ca(d[g]|0,c)|0;a[f+5|0]=(i+4+(ca(d[b+22|0]|0,h)|0)|0)>>>3;i=ca(d[g]|0,c)|0;a[f+6|0]=(i+4+(ca(d[b+23|0]|0,h)|0)|0)>>>3;i=ca(d[g]|0,c)|0;a[f+7|0]=(i+4+(ca(d[b+24|0]|0,h)|0)|0)>>>3;h=c+1|0;if((h|0)<8){f=f+e|0;c=h}else{break}}return}function sqb(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=f+10>>3;h=c*-4|0;i=c*-3|0;j=c*-2|0;k=-c|0;l=c<<1;m=c*3|0;n=c<<2;o=c*-5|0;p=f<<1;q=0;r=b;while(1){b=a[r+h|0]|0;s=b&255;t=d[r+i|0]|0;u=r+j|0;v=a[u]|0;w=v&255;x=r+k|0;y=d[x]|0;z=d[r]|0;A=r+c|0;B=d[A]|0;C=d[r+l|0]|0;D=d[r+m|0]|0;E=s-t|0;F=t-w|0;G=w-y|0;H=y-z|0;I=((((F|0)>-1?F:-F|0)|0)<=(g|0))+((((E|0)>-1?E:-E|0)|0)<=(g|0))+((((G|0)>-1?G:-G|0)|0)<=(g|0))+((((H|0)>-1?H:-H|0)|0)<=(g|0))|0;do{if((I|0)>0){G=z-B|0;E=B-C|0;F=C-D|0;J=D-(d[r+n|0]|0)|0;K=(d[r+o|0]|0)-s|0;if((I+((((G|0)>-1?G:-G|0)|0)<=(g|0))+((((E|0)>-1?E:-E|0)|0)<=(g|0))+((((F|0)>-1?F:-F|0)|0)<=(g|0))+((((J|0)>-1?J:-J|0)|0)<=(g|0))+((((K|0)>-1?K:-K|0)|0)<=(g|0))|0)<=5){L=7;break}K=(b&255)>>>0>(v&255)>>>0;J=K?w:s;F=K?s:w;K=J>>>0>z>>>0?z:J;J=F>>>0>z>>>0?F:z;F=K>>>0>D>>>0?D:K;K=J>>>0>D>>>0?J:D;if((K-F|0)>=(p|0)){L=7;break}J=F>>>0>t>>>0?t:F;F=K>>>0>t>>>0?K:t;K=J>>>0>y>>>0?y:J;J=F>>>0>y>>>0?F:y;F=K>>>0>B>>>0?B:K;K=J>>>0>B>>>0?J:B;if((((K|0)>(C|0)?K:C)-((F|0)>(C|0)?C:F)|0)>=(p|0)){L=7;break}a[u]=((t<<2)+4+(w*3|0)+C|0)>>>3;a[x]=(((y+t|0)*3|0)+4+(C<<1)|0)>>>3;a[r]=((t<<1)+4+((C+z|0)*3|0)|0)>>>3;a[A]=(t+4+(B*3|0)+(C<<2)|0)>>>3}else{L=7}}while(0);do{if((L|0)==7){L=0;A=(w<<1)+4-(B<<1)+((z-y|0)*5|0)>>3;u=(A|0)>-1?A:-A|0;if((u|0)>=(f|0)){break}v=(s<<1)+4-(y<<1)+((w-t|0)*5|0)>>3;b=(z<<1)+4-(D<<1)+((C-B|0)*5|0)>>3;I=(v|0)>-1?v:-v|0;v=(b|0)>-1?b:-b|0;b=u-((I|0)>(v|0)?v:I)|0;if((b|0)<=0){break}if((A^H|0)>=0){break}A=H>>31;I=(A^H)-A>>1;v=(b*5|0)>>3;b=(((v|0)>(I|0)?I:v)^A)-A|0;a[x]=y-b;a[r]=(d[r]|0)+b}}while(0);y=q+1|0;if((y|0)<8){q=y;r=r+e|0}else{break}}return}function tqb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;d=a;a=i;i=i+8|0;c[a>>2]=c[d>>2];c[a+4>>2]=c[d+4>>2];d=a|0;e=c[d>>2]|0;do{if((e|0)==0){c[d>>2]=1;c[a+4>>2]=1;f=0;g=0;h=1;j=0;k=1}else{l=c[a+4>>2]|0;m=l;n=(l|0)<0|0?-1:0;o=e;p=(e|0)<0|0?-1:0;q=e>>31;if((l|0)!=0){f=q;g=p;h=o;j=n;k=m;break}l=c[344686]|0;r=c[344687]|0;s=Erc(m,n,l,(l|0)<0|0?-1:0)|0;t=G;u=Erc(o,p,r,(r|0)<0|0?-1:0)|0;if((l|0)!=0&((s|0)==(u|0)&(t|0)==(G|0))&(l>>31|0)==(q|0)){v=1;i=b;return v|0}l=c[344688]|0;t=c[344689]|0;u=Erc(m,n,l,(l|0)<0|0?-1:0)|0;s=G;r=Erc(o,p,t,(t|0)<0|0?-1:0)|0;if((l|0)!=0&((u|0)==(r|0)&(s|0)==(G|0))&(l>>31|0)==(q|0)){v=2;i=b;return v|0}l=c[344690]|0;s=c[344691]|0;r=Erc(m,n,l,(l|0)<0|0?-1:0)|0;u=G;t=Erc(o,p,s,(s|0)<0|0?-1:0)|0;if((l|0)!=0&((r|0)==(t|0)&(u|0)==(G|0))&(l>>31|0)==(q|0)){v=3;i=b;return v|0}l=c[344692]|0;u=c[344693]|0;t=Erc(m,n,l,(l|0)<0|0?-1:0)|0;r=G;s=Erc(o,p,u,(u|0)<0|0?-1:0)|0;if((l|0)!=0&((t|0)==(s|0)&(r|0)==(G|0))&(l>>31|0)==(q|0)){v=4;i=b;return v|0}else{l=c[344694]|0;r=c[344695]|0;s=Erc(m,n,l,(l|0)<0|0?-1:0)|0;n=G;m=Erc(o,p,r,(r|0)<0|0?-1:0)|0;r=(l|0)!=0&((s|0)==(m|0)&(n|0)==(G|0))&(l>>31|0)==(q|0)?5:15;i=b;return r|0}}}while(0);e=c[344686]|0;a=c[344687]|0;d=Erc(k,j,e,(e|0)<0|0?-1:0)|0;r=G;q=Erc(h,g,a,(a|0)<0|0?-1:0)|0;do{if((d|0)==(q|0)&(r|0)==(G|0)){if((a|0)!=0){v=1;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=1}else{break}i=b;return v|0}}while(0);e=c[344688]|0;a=c[344689]|0;r=Erc(k,j,e,(e|0)<0|0?-1:0)|0;q=G;d=Erc(h,g,a,(a|0)<0|0?-1:0)|0;do{if((r|0)==(d|0)&(q|0)==(G|0)){if((a|0)!=0){v=2;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=2}else{break}i=b;return v|0}}while(0);e=c[344690]|0;a=c[344691]|0;q=Erc(k,j,e,(e|0)<0|0?-1:0)|0;d=G;r=Erc(h,g,a,(a|0)<0|0?-1:0)|0;do{if((q|0)==(r|0)&(d|0)==(G|0)){if((a|0)!=0){v=3;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=3}else{break}i=b;return v|0}}while(0);e=c[344692]|0;a=c[344693]|0;d=Erc(k,j,e,(e|0)<0|0?-1:0)|0;r=G;q=Erc(h,g,a,(a|0)<0|0?-1:0)|0;do{if((d|0)==(q|0)&(r|0)==(G|0)){if((a|0)!=0){v=4;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=4}else{break}i=b;return v|0}}while(0);e=c[344694]|0;a=c[344695]|0;r=Erc(k,j,e,(e|0)<0|0?-1:0)|0;j=G;k=Erc(h,g,a,(a|0)<0|0?-1:0)|0;do{if((r|0)==(k|0)&(j|0)==(G|0)){if((a|0)!=0){v=5;i=b;return v|0}if((e|0)!=0&(e>>31|0)==(f|0)){v=5}else{break}i=b;return v|0}}while(0);v=15;i=b;return v|0}function uqb(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0;f=b+40|0;if((c[f>>2]|0)==0){g=60;h=5}else{i=c[b+4>>2]|0;j=c[i+104>>2]|0;k=Erc(j,(j|0)<0|0?-1:0,18e5,0)|0;j=G;l=c[i+108>>2]|0;i=l;m=(l|0)<0|0?-1:0;l=Erc(i,m,500,0)|0;n=wrc(l,G,k,j)|0;l=G;o=Erc(i,m,1e3,0)|0;p=G;q=Crc(n,l,o,p)|0;r=q;if((r|0)<1){s=1}else{s=(r|0)>127?127:r}r=Erc(s,(s|0)<0|0?-1:0,o,p)|0;p=xrc(k,j,r,G)|0;r=G;o=-1;q=(r|0)>(o|0)|(r|0)==(o|0)&p>>>0>-1>>>0;o=xrc(0,0,p,r)|0;t=G;u=q?p:o;q?r:t;t=u;u=Erc(i,m,1001,0)|0;m=G;i=Crc(n,l,u,m)|0;l=i;if((l|0)<1){v=1}else{v=(l|0)>127?127:l}l=Erc(v,(v|0)<0|0?-1:0,u,m)|0;m=xrc(k,j,l,G)|0;l=G;j=-1;k=(l|0)>(j|0)|(l|0)==(j|0)&m>>>0>-1>>>0;j=xrc(0,0,m,l)|0;u=G;i=k?m:j;k?l:u;u=(i|0)<(t|0);t=u?v:s;if(u){g=t;h=5}else{w=1;x=t;z=u&1}}if((h|0)==5){w=(g|0)!=60|0;x=g;z=1}g=b+13840|0;c[g>>2]=w;w=ca(z|1e3,x)|0;h=b+784|0;Y2(h);u=b+796|0;t=c[u>>2]|0;c[b+14280>>2]=t;s=h|0;h=c[s>>2]|0;v=b+788|0;i=c[v>>2]|0;if((i|0)>22){A=i-22|0;B=h<<22|32;C=t}else{l=t;y=je(32>>>((22-i|0)>>>0)|h<<i|0)|0;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;l=(c[u>>2]|0)+4|0;c[u>>2]=l;A=i+10|0;B=32;C=l}c[s>>2]=B;c[v>>2]=A;l=c[b+108>>2]|0;i=Erc(l,(l|0)<0|0?-1:0,18e5,0)|0;l=b+4|0;h=c[l>>2]|0;t=c[h+104>>2]|0;k=Erc(i,G,t,(t|0)<0|0?-1:0)|0;t=G;i=c[h+108>>2]|0;h=Erc(i,(i|0)<0|0?-1:0,w,(w|0)<0|0?-1:0)|0;w=Crc(k,t,h,G)|0;h=w;w=h&255;if((A|0)>8){D=A-8|0;E=B<<8|w;F=C}else{t=C;y=je(w>>>((8-A|0)>>>0)|B<<A|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[u>>2]|0)+4|0;c[u>>2]=t;D=A+24|0;E=w;F=t}c[s>>2]=E;c[v>>2]=D;if((D|0)>1){H=D-1|0;I=E<<1|1;J=F}else{t=F;y=je(1>>>((1-D|0)>>>0)|E<<D|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[u>>2]|0)+4|0;c[u>>2]=t;H=D+31|0;I=1;J=t}c[s>>2]=I;c[v>>2]=H;if((H|0)>1){K=H-1|0;L=I<<1;M=J}else{t=J;y=je(I<<H|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[u>>2]|0)+4|0;c[u>>2]=t;K=H+31|0;L=0;M=t}c[s>>2]=L;c[v>>2]=K;if((K|0)>1){N=K-1|0;O=L<<1;P=M}else{t=M;y=je(L<<K|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[u>>2]|0)+4|0;c[u>>2]=t;N=K+31|0;O=0;P=t}c[s>>2]=O;c[v>>2]=N;if((N|0)>1){Q=N-1|0;R=O<<1;S=P}else{t=P;y=je(O<<N|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;t=(c[u>>2]|0)+4|0;c[u>>2]=t;Q=N+31|0;R=0;S=t}c[s>>2]=R;c[v>>2]=Q;if((Q|0)>1){T=Q-1|0;U=R<<1}else{t=S;y=je(R<<Q|0)|0;a[t]=y;y=y>>8;a[t+1|0]=y;y=y>>8;a[t+2|0]=y;y=y>>8;a[t+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;T=Q+31|0;U=0}c[s>>2]=U;c[v>>2]=T;T=b+8|0;U=b+12|0;Q=D5a(1379168,8,c[T>>2]|0,c[U>>2]|0)|0;t=c[s>>2]|0;R=c[v>>2]|0;S=(R|0)>3;do{if((c[f>>2]|0)==0){if(S){V=R-3|0;W=t<<3|Q}else{N=je(Q>>>((3-R|0)>>>0)|t<<R|0)|0;O=c[u>>2]|0;y=N;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;V=R+29|0;W=Q}c[s>>2]=W;c[v>>2]=V;O=(c[b+9992>>2]|0)==2|0;if((V|0)>1){X=V-1|0;Y=W<<1|O}else{N=je(O>>>((1-V|0)>>>0)|W<<V|0)|0;P=c[u>>2]|0;y=N;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;X=V+31|0;Y=O}c[s>>2]=Y;c[v>>2]=X;if((X|0)>1){Z=X-1|0;_=Y<<1}else{O=je(Y<<X|0)|0;P=c[u>>2]|0;y=O;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Z=X+31|0;_=0}c[s>>2]=_;c[v>>2]=Z;if((Z|0)>1){$=Z-1|0;aa=_<<1}else{P=je(_<<Z|0)|0;O=c[u>>2]|0;y=P;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;$=Z+31|0;aa=0}c[s>>2]=aa;c[v>>2]=$;O=c[b+13788>>2]|0;if(($|0)>1){ba=$-1|0;da=aa<<1|O}else{P=je(aa<<$|O>>>((1-$|0)>>>0)|0)|0;N=c[u>>2]|0;y=P;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ba=$+31|0;da=O}c[s>>2]=da;c[v>>2]=ba;if((ba|0)>1){ea=ba-1|0;fa=da<<1}else{O=je(da<<ba|0)|0;N=c[u>>2]|0;y=O;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ea=ba+31|0;fa=0}c[s>>2]=fa;c[v>>2]=ea;N=c[b+9960>>2]|0;if((ea|0)>5){ga=ea-5|0;ha=fa<<5|N}else{O=je(fa<<ea|N>>>((5-ea|0)>>>0)|0)|0;P=c[u>>2]|0;y=O;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ga=ea+27|0;ha=N}c[s>>2]=ha;c[v>>2]=ga;if((ga|0)>1){ia=ga-1|0;ja=ha<<1;break}else{N=je(ha<<ga|0)|0;P=c[u>>2]|0;y=N;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ia=ga+31|0;ja=0;break}}else{if(S){ka=R-3|0;la=t<<3|7}else{P=je(7>>>((3-R|0)>>>0)|t<<R|0)|0;N=c[u>>2]|0;y=P;a[N]=y;y=y>>8;a[N+1|0]=y;y=y>>8;a[N+2|0]=y;y=y>>8;a[N+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ka=R+29|0;la=7}c[s>>2]=la;c[v>>2]=ka;if((ka|0)>3){ma=ka-3|0;na=la<<3|1}else{N=je(1>>>((3-ka|0)>>>0)|la<<ka|0)|0;P=c[u>>2]|0;y=N;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ma=ka+29|0;na=1}c[s>>2]=na;c[v>>2]=ma;P=(Q|0)==8;N=(ma|0)>3;do{if(P){if(N){oa=ma-3|0;pa=na<<3|6;break}else{O=je(6>>>((3-ma|0)>>>0)|na<<ma|0)|0;K=c[u>>2]|0;y=O;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;oa=ma+29|0;pa=6;break}}else{if(N){oa=ma-3|0;pa=na<<3|Q;break}else{K=je(Q>>>((3-ma|0)>>>0)|na<<ma|0)|0;O=c[u>>2]|0;y=K;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;oa=ma+29|0;pa=Q;break}}}while(0);c[s>>2]=pa;c[v>>2]=oa;N=c[g>>2]|0;if((oa|0)>1){qa=oa-1|0;ra=pa<<1|N}else{O=je(pa<<oa|N>>>((1-oa|0)>>>0)|0)|0;K=c[u>>2]|0;y=O;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;qa=oa+31|0;ra=N}c[s>>2]=ra;c[v>>2]=qa;N=b+13816|0;K=c[N>>2]|0;if((qa|0)>1){sa=qa-1|0;ta=ra<<1|K}else{O=je(ra<<qa|K>>>((1-qa|0)>>>0)|0)|0;L=c[u>>2]|0;y=O;a[L]=y;y=y>>8;a[L+1|0]=y;y=y>>8;a[L+2|0]=y;y=y>>8;a[L+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;sa=qa+31|0;ta=K}c[s>>2]=ta;c[v>>2]=sa;if((sa|0)>1){ua=sa-1|0;va=ta<<1}else{K=je(ta<<sa|0)|0;L=c[u>>2]|0;y=K;a[L]=y;y=y>>8;a[L+1|0]=y;y=y>>8;a[L+2|0]=y;y=y>>8;a[L+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ua=sa+31|0;va=0}c[s>>2]=va;c[v>>2]=ua;L=c[b+13788>>2]|0;if((ua|0)>1){wa=ua-1|0;xa=va<<1|L}else{K=je(va<<ua|L>>>((1-ua|0)>>>0)|0)|0;O=c[u>>2]|0;y=K;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;wa=ua+31|0;xa=L}c[s>>2]=xa;c[v>>2]=wa;L=c[b+228>>2]|0;if((wa|0)>1){ya=wa-1|0;za=xa<<1|L}else{O=je(xa<<wa|L>>>((1-wa|0)>>>0)|0)|0;K=c[u>>2]|0;y=O;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ya=wa+31|0;za=L}c[s>>2]=za;c[v>>2]=ya;L=c[b+13836>>2]|0;if((ya|0)>1){Aa=ya-1|0;Ba=za<<1|L}else{K=je(za<<ya|L>>>((1-ya|0)>>>0)|0)|0;O=c[u>>2]|0;y=K;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Aa=ya+31|0;Ba=L}c[s>>2]=Ba;c[v>>2]=Aa;L=b+13824|0;O=c[L>>2]|0;if((Aa|0)>1){Ca=Aa-1|0;Da=Ba<<1|O}else{K=je(Ba<<Aa|O>>>((1-Aa|0)>>>0)|0)|0;M=c[u>>2]|0;y=K;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Ca=Aa+31|0;Da=O}c[s>>2]=Da;c[v>>2]=Ca;if((Ca|0)>1){Ea=Ca-1|0;Fa=Da<<1}else{O=je(Da<<Ca|0)|0;M=c[u>>2]|0;y=O;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Ea=Ca+31|0;Fa=0}c[s>>2]=Fa;c[v>>2]=Ea;if((Ea|0)>1){Ga=Ea-1|0;Ha=Fa<<1}else{M=je(Fa<<Ea|0)|0;O=c[u>>2]|0;y=M;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Ga=Ea+31|0;Ha=0}c[s>>2]=Ha;c[v>>2]=Ga;O=c[b+13828>>2]|0;if((Ga|0)>1){Ia=Ga-1|0;Ja=Ha<<1|O}else{M=je(Ha<<Ga|O>>>((1-Ga|0)>>>0)|0)|0;K=c[u>>2]|0;y=M;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Ia=Ga+31|0;Ja=O}c[s>>2]=Ja;c[v>>2]=Ia;O=c[b+13832>>2]|0;if((Ia|0)>1){Ka=Ia-1|0;La=Ja<<1|O}else{K=je(Ja<<Ia|O>>>((1-Ia|0)>>>0)|0)|0;M=c[u>>2]|0;y=K;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Ka=Ia+31|0;La=O}c[s>>2]=La;c[v>>2]=Ka;if((Ka|0)>1){Ma=Ka-1|0;Na=La<<1|1}else{O=je(1>>>((1-Ka|0)>>>0)|La<<Ka|0)|0;M=c[u>>2]|0;y=O;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Ma=Ka+31|0;Na=1}c[s>>2]=Na;c[v>>2]=Ma;if((Ma|0)>3){Oa=Ma-3|0;Pa=Na<<3}else{M=je(Na<<Ma|0)|0;O=c[u>>2]|0;y=M;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Oa=Ma+29|0;Pa=0}c[s>>2]=Pa;c[v>>2]=Oa;O=(c[b+9992>>2]|0)==2|0;if((Oa|0)>3){Qa=Oa-3|0;Ra=Pa<<3|O}else{M=je(O>>>((3-Oa|0)>>>0)|Pa<<Oa|0)|0;K=c[u>>2]|0;y=M;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Qa=Oa+29|0;Ra=O}c[s>>2]=Ra;c[v>>2]=Qa;if((Qa|0)>1){Sa=Qa-1|0;Ta=Ra<<1}else{O=je(Ra<<Qa|0)|0;K=c[u>>2]|0;y=O;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Sa=Qa+31|0;Ta=0}c[s>>2]=Ta;c[v>>2]=Sa;if((Sa|0)>1){Ua=Sa-1|0;Va=Ta<<1}else{K=je(Ta<<Sa|0)|0;O=c[u>>2]|0;y=K;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Ua=Sa+31|0;Va=0}c[s>>2]=Va;c[v>>2]=Ua;O=c[b+12472>>2]|0;if((Ua|0)>1){Wa=Ua-1|0;Xa=Va<<1|O}else{K=je(Va<<Ua|O>>>((1-Ua|0)>>>0)|0)|0;M=c[u>>2]|0;y=K;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Wa=Ua+31|0;Xa=O}c[s>>2]=Xa;c[v>>2]=Wa;if((Wa|0)>2){Ya=Wa-2|0;Za=Xa<<2}else{O=je(Xa<<Wa|0)|0;M=c[u>>2]|0;y=O;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Ya=Wa+30|0;Za=0}c[s>>2]=Za;c[v>>2]=Ya;if((Ya|0)>1){_a=Ya-1|0;$a=Za<<1|1}else{M=je(1>>>((1-Ya|0)>>>0)|Za<<Ya|0)|0;O=c[u>>2]|0;y=M;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;_a=Ya+31|0;$a=1}c[s>>2]=$a;c[v>>2]=_a;if((_a|0)>1){ab=_a-1|0;bb=$a<<1}else{O=je($a<<_a|0)|0;M=c[u>>2]|0;y=O;a[M]=y;y=y>>8;a[M+1|0]=y;y=y>>8;a[M+2|0]=y;y=y>>8;a[M+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ab=_a+31|0;bb=0}c[s>>2]=bb;c[v>>2]=ab;do{if(P){M=tqb((c[l>>2]|0)+224|0)|0;O=b+13928|0;c[O>>2]=M;K=c[s>>2]|0;H=c[v>>2]|0;if((H|0)>4){cb=H-4|0;db=K<<4|M}else{I=je(M>>>((4-H|0)>>>0)|K<<H|0)|0;K=c[u>>2]|0;y=I;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;cb=H+28|0;db=M}c[s>>2]=db;c[v>>2]=cb;M=(c[T>>2]>>2)-1|0;if((cb|0)>9){eb=cb-9|0;fb=db<<9|M}else{H=je(M>>>((9-cb|0)>>>0)|db<<cb|0)|0;K=c[u>>2]|0;y=H;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;eb=cb+23|0;fb=M}c[s>>2]=fb;c[v>>2]=eb;if((eb|0)>1){gb=eb-1|0;hb=fb<<1|1}else{M=je(1>>>((1-eb|0)>>>0)|fb<<eb|0)|0;K=c[u>>2]|0;y=M;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;gb=eb+31|0;hb=1}c[s>>2]=hb;c[v>>2]=gb;K=c[U>>2]>>2;if((gb|0)>9){ib=gb-9|0;jb=hb<<9|K}else{M=je(K>>>((9-gb|0)>>>0)|hb<<gb|0)|0;H=c[u>>2]|0;y=M;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ib=gb+23|0;jb=K}c[s>>2]=jb;c[v>>2]=ib;if((c[O>>2]|0)!=15){kb=ib;lb=jb;break}O=c[l>>2]|0;K=c[O+224>>2]|0;if((ib|0)>8){mb=ib-8|0;nb=jb<<8|K;ob=O}else{O=je(jb<<ib|K>>>((8-ib|0)>>>0)|0)|0;H=c[u>>2]|0;y=O;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;mb=ib+24|0;nb=K;ob=c[l>>2]|0}c[s>>2]=nb;c[v>>2]=mb;K=c[ob+228>>2]|0;if((mb|0)>8){pb=mb-8|0;qb=nb<<8|K}else{H=je(nb<<mb|K>>>((8-mb|0)>>>0)|0)|0;O=c[u>>2]|0;y=H;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;pb=mb+24|0;qb=K}c[s>>2]=qb;c[v>>2]=pb;kb=pb;lb=qb}else{kb=ab;lb=bb}}while(0);if((c[g>>2]|0)==0){rb=kb;sb=lb}else{if((kb|0)>1){tb=kb-1|0;ub=lb<<1|z}else{P=je(z>>>((1-kb|0)>>>0)|lb<<kb|0)|0;K=c[u>>2]|0;y=P;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;tb=kb+31|0;ub=z}c[s>>2]=ub;c[v>>2]=tb;if((tb|0)>7){vb=tb-7|0;wb=ub<<7|x}else{K=je(x>>>((7-tb|0)>>>0)|ub<<tb|0)|0;P=c[u>>2]|0;y=K;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;vb=tb+25|0;wb=x}c[s>>2]=wb;c[v>>2]=vb;P=h>>>8&3;if((vb|0)>2){xb=vb-2|0;yb=wb<<2|P}else{K=je(P>>>((2-vb|0)>>>0)|wb<<vb|0)|0;O=c[u>>2]|0;y=K;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;xb=vb+30|0;yb=P}c[s>>2]=yb;c[v>>2]=xb;rb=xb;sb=yb}if((c[N>>2]|0)==0){zb=rb;Ab=sb}else{if((rb|0)>2){Bb=rb-2|0;Cb=sb<<2|1}else{P=je(1>>>((2-rb|0)>>>0)|sb<<rb|0)|0;O=c[u>>2]|0;y=P;a[O]=y;y=y>>8;a[O+1|0]=y;y=y>>8;a[O+2|0]=y;y=y>>8;a[O+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Bb=rb+30|0;Cb=1}c[s>>2]=Cb;c[v>>2]=Bb;zb=Bb;Ab=Cb}if((c[L>>2]|0)==0){Db=zb;Eb=Ab}else{if((zb|0)>2){Fb=zb-2|0;Gb=Ab<<2}else{O=je(Ab<<zb|0)|0;P=c[u>>2]|0;y=O;a[P]=y;y=y>>8;a[P+1|0]=y;y=y>>8;a[P+2|0]=y;y=y>>8;a[P+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Fb=zb+30|0;Gb=0}c[s>>2]=Gb;c[v>>2]=Fb;Db=Fb;Eb=Gb}P=c[b+9960>>2]|0;if((Db|0)>5){ia=Db-5|0;ja=Eb<<5|P;break}else{O=je(Eb<<Db|P>>>((5-Db|0)>>>0)|0)|0;K=c[u>>2]|0;y=O;a[K]=y;y=y>>8;a[K+1|0]=y;y=y>>8;a[K+2|0]=y;y=y>>8;a[K+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;ia=Db+27|0;ja=P;break}}}while(0);c[s>>2]=ja;c[v>>2]=ia;if((ia|0)>1){Hb=ia-1|0;Ib=ja<<1}else{Db=je(ja<<ia|0)|0;ja=c[u>>2]|0;y=Db;a[ja]=y;y=y>>8;a[ja+1|0]=y;y=y>>8;a[ja+2|0]=y;y=y>>8;a[ja+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Hb=ia+31|0;Ib=0}c[s>>2]=Ib;c[v>>2]=Hb;if((c[b+13824>>2]|0)!=0){if((Hb|0)>1){Jb=Hb-1|0;Kb=Ib<<1|1}else{ia=je(Ib<<Hb|1>>>((1-Hb|0)>>>0)|0)|0;Ib=c[u>>2]|0;y=ia;a[Ib]=y;y=y>>8;a[Ib+1|0]=y;y=y>>8;a[Ib+2|0]=y;y=y>>8;a[Ib+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Jb=Hb+31|0;Kb=1}c[s>>2]=Kb;c[v>>2]=Jb;Hb=b+144|0;Ib=0;while(1){if((Ib|0)>=6){break}if(((c[Hb>>2]|0)-1|0)>(e[1358712+(Ib<<1)>>1]|0|0)){Ib=Ib+1|0}else{break}}Hb=(ca(c[b+12480>>2]|0,c[b+116>>2]|0)|0)+(c[b+12476>>2]|0)|0;ia=d[1358728+Ib|0]|0;if((Jb|0)>(ia|0)){Lb=Jb-ia|0;Mb=Kb<<ia|Hb}else{Ib=je(Hb>>>((ia-Jb|0)>>>0)|Kb<<Jb|0)|0;Kb=c[u>>2]|0;y=Ib;a[Kb]=y;y=y>>8;a[Kb+1|0]=y;y=y>>8;a[Kb+2|0]=y;y=y>>8;a[Kb+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Lb=32-ia+Jb|0;Mb=Hb}c[b+784>>2]=Mb;c[v>>2]=Lb;if((Lb|0)>1){Nb=Lb-1|0;Ob=Mb<<1|1}else{Hb=je(1>>>((1-Lb|0)>>>0)|Mb<<Lb|0)|0;Mb=c[u>>2]|0;y=Hb;a[Mb]=y;y=y>>8;a[Mb+1|0]=y;y=y>>8;a[Mb+2|0]=y;y=y>>8;a[Mb+3|0]=y;c[u>>2]=(c[u>>2]|0)+4;Nb=Lb+31|0;Ob=1}c[s>>2]=Ob;c[v>>2]=Nb}Nb=b+9892|0;if((c[b+228>>2]|0)==0){c[Nb>>2]=1347360;c[b+9888>>2]=1347360;return}else{c[Nb>>2]=1434232;c[b+9888>>2]=1434232;return}}function vqb(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+144|0;g=0;while(1){if((g|0)>=6){break}if(((c[f>>2]|0)-1|0)>(e[1358712+(g<<1)>>1]|0|0)){g=g+1|0}else{break}}f=(ca(c[b+12480>>2]|0,c[b+116>>2]|0)|0)+(c[b+12476>>2]|0)|0;h=d[1358728+g|0]|0;g=b+784|0;i=c[g>>2]|0;j=b+788|0;k=c[j>>2]|0;if((k|0)>(h|0)){l=k-h|0;m=i<<h|f;c[g>>2]=m;c[j>>2]=l;return}else{n=je(f>>>((h-k|0)>>>0)|i<<k|0)|0;i=b+796|0;b=c[i>>2]|0;y=n;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[i>>2]=(c[i>>2]|0)+4;l=32-h+k|0;m=f;c[g>>2]=m;c[j>>2]=l;return}}function wqb(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=b+784|0;h=c[g>>2]|0;i=b+788|0;j=c[i>>2]|0;if((j|0)>17){k=j-17|0;l=h<<17|1}else{m=je(1>>>((17-j|0)>>>0)|h<<j|0)|0;h=b+796|0;n=c[h>>2]|0;y=m;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;k=j+15|0;l=1}c[g>>2]=l;c[i>>2]=k;if((c[b+13824>>2]|0)==0){j=(f|0)/(c[b+13784>>2]|0)|0;if((k|0)>5){o=k-5|0;p=l<<5|j}else{f=je(l<<k|j>>>((5-k|0)>>>0)|0)|0;h=b+796|0;n=c[h>>2]|0;y=f;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[h>>2]=(c[h>>2]|0)+4;o=k+27|0;p=j}c[g>>2]=p;c[i>>2]=o;j=(c[b+9992>>2]|0)==1|0;if((o|0)>2){q=o-2|0;r=p<<2|j}else{h=je(j>>>((2-o|0)>>>0)|p<<o|0)|0;p=b+796|0;n=c[p>>2]|0;y=h;a[n]=y;y=y>>8;a[n+1|0]=y;y=y>>8;a[n+2|0]=y;y=y>>8;a[n+3|0]=y;c[p>>2]=(c[p>>2]|0)+4;q=o+30|0;r=j}c[g>>2]=r;c[i>>2]=q;j=c[b+9960>>2]|0;if((q|0)>5){s=q-5|0;t=r<<5|j;c[g>>2]=t;c[i>>2]=s;return}else{o=je(r<<q|j>>>((5-q|0)>>>0)|0)|0;r=b+796|0;p=c[r>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[r>>2]=(c[r>>2]|0)+4;s=q+27|0;t=j;c[g>>2]=t;c[i>>2]=s;return}}if((k|0)>1){u=k-1|0;v=l<<1|1}else{j=je(l<<k|1>>>((1-k|0)>>>0)|0)|0;l=b+796|0;q=c[l>>2]|0;y=j;a[q]=y;y=y>>8;a[q+1|0]=y;y=y>>8;a[q+2|0]=y;y=y>>8;a[q+3|0]=y;c[l>>2]=(c[l>>2]|0)+4;u=k+31|0;v=1}c[g>>2]=v;c[i>>2]=u;k=b+144|0;l=0;while(1){if((l|0)>=6){break}if(((c[k>>2]|0)-1|0)>(e[1358712+(l<<1)>>1]|0|0)){l=l+1|0}else{break}}q=(ca(c[b+12480>>2]|0,c[b+116>>2]|0)|0)+(c[b+12476>>2]|0)|0;j=d[1358728+l|0]|0;if((u|0)>(j|0)){w=u-j|0;x=v<<j|q}else{l=je(q>>>((j-u|0)>>>0)|v<<u|0)|0;v=b+796|0;r=c[v>>2]|0;y=l;a[r]=y;y=y>>8;a[r+1|0]=y;y=y>>8;a[r+2|0]=y;y=y>>8;a[r+3|0]=y;c[v>>2]=(c[v>>2]|0)+4;w=32-j+u|0;x=q}c[g>>2]=x;c[i>>2]=w;if((c[k>>2]|0)>1583){if((w|0)>1){z=w-1|0;A=x<<1|1}else{k=je(1>>>((1-w|0)>>>0)|x<<w|0)|0;q=b+796|0;u=c[q>>2]|0;y=k;a[u]=y;y=y>>8;a[u+1|0]=y;y=y>>8;a[u+2|0]=y;y=y>>8;a[u+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;z=w+31|0;A=1}c[g>>2]=A;c[i>>2]=z;B=z;C=A}else{B=w;C=x}x=c[b+9960>>2]|0;if((B|0)>5){D=B-5|0;E=C<<5|x}else{w=je(C<<B|x>>>((5-B|0)>>>0)|0)|0;C=b+796|0;A=c[C>>2]|0;y=w;a[A]=y;y=y>>8;a[A+1|0]=y;y=y>>8;a[A+2|0]=y;y=y>>8;a[A+3|0]=y;c[C>>2]=(c[C>>2]|0)+4;D=B+27|0;E=x}c[g>>2]=E;c[i>>2]=D;if((D|0)>1){F=D-1|0;G=E<<1|1}else{x=je(1>>>((1-D|0)>>>0)|E<<D|0)|0;E=b+796|0;B=c[E>>2]|0;y=x;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[E>>2]=(c[E>>2]|0)+4;F=D+31|0;G=1}c[g>>2]=G;c[i>>2]=F;D=(c[b+9992>>2]|0)==1|0;if((F|0)>2){s=F-2|0;t=G<<2|D;c[g>>2]=t;c[i>>2]=s;return}else{E=je(D>>>((2-F|0)>>>0)|G<<F|0)|0;G=b+796|0;b=c[G>>2]|0;y=E;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;s=F+30|0;t=D;c[g>>2]=t;c[i>>2]=s;return}}function xqb(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[d+9136>>2]|0;YTa(d);f=d+144|0;g=c[f>>2]|0;if((g|0)>1){h=d+12556|0;i=1;j=g;while(1){k=c[h>>2]|0;l=e+(c[k+(i<<2)>>2]|0)|0;m=a[e+(c[k+(i-1<<2)>>2]|0)|0]|0;if(((a[l]|0)-(m<<24>>24)|0)>2){a[l]=m+2;n=c[f>>2]|0}else{n=j}m=i+1|0;if((m|0)<(n|0)){i=m;j=n}else{o=n;break}}}else{o=g}g=o-2|0;a:do{if((g|0)>-1){o=d+12556|0;n=g;while(1){j=c[o>>2]|0;i=e+(c[j+(n<<2)>>2]|0)|0;h=a[e+(c[j+(n+1<<2)>>2]|0)|0]|0;if(((a[i]|0)-(h<<24>>24)|0)>2){a[i]=h+2}if((n|0)<=0){break a}n=n-1|0}}}while(0);if((c[d+48>>2]|0)==20){return}g=c[f>>2]|0;if((g|0)<=1){return}f=d+12492|0;n=c[d+12556>>2]|0;d=1;o=c[n>>2]|0;while(1){h=c[n+(d<<2)>>2]|0;do{if((a[e+h|0]|0)!=(a[e+o|0]|0)){i=(c[f>>2]|0)+(h<<1)|0;j=b[i>>1]|0;if((j&4)==0){break}b[i>>1]=j|2}}while(0);j=d+1|0;if((j|0)<(g|0)){d=j;o=h}else{break}}return}function yqb(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0;k=i;i=i+56|0;l=k|0;m=k+8|0;n=k+16|0;o=k+32|0;p=c[f+60>>2]&512;q=f+12488|0;do{if((c[q>>2]|0)==0){do{if((c[f+14404>>2]&8|0)==0){r=(c[f+180>>2]>>31)+32&-32;s=(c[f+184>>2]|0)>-1?r|16:r;r=(c[f+188>>2]|0)>-1?s|8:s;s=(c[f+192>>2]|0)>-1?r|4:r;r=(c[f+196>>2]|0)>-1?s|2:s;if(!((c[f+200>>2]|0)>-1)){t=r;break}t=r|1}else{r=(c[f+11740>>2]|0)==0;s=c[f+9984>>2]|0;u=((s|0)!=0?8:0)|(r?0:16);v=(c[f+9972>>2]|0)>>>1;w=ca(d[1379128+u|0]|0,v)|0;x=(w|0)==2147483647;z=ca(d[1379128+(u|1)|0]|0,v)|0;A=c[f+13132>>2]|0;B=z+A|0;z=(B|0)<(w|0);C=z?B:w;w=ca(d[1379128+(u|2)|0]|0,v)|0;B=c[f+13128>>2]|0;D=w+B|0;w=(D|0)<(C|0);E=w?D:C;C=B+A+(ca(d[1379128+(u|3)|0]|0,v)|0)|0;u=(C|0)<(E|0);A=u?C:E;E=f+13112|0;C=f+13116|0;B=f+13120|0;D=f+13124|0;F=2147483647;G=-1;H=0;do{I=ca(d[1379529+((H^15)<<1)|0]|0,v)|0;if((H&1|0)==0){J=I}else{J=(c[D>>2]|0)+I|0}if((H&2|0)==0){K=J}else{K=(c[B>>2]|0)+J|0}if((H&4|0)==0){L=K}else{L=(c[C>>2]|0)+K|0}if((H&8|0)==0){M=L}else{M=(c[E>>2]|0)+L|0}I=(M|0)<(F|0);F=I?M:F;G=I?H:G;H=H+1|0;}while((H|0)<16);H=(G<<2)+(u?3:w?2:z?1:x<<31>>31)|0;if((j|h|s|0)!=0|r^1){N=H}else{N=(A+(v<<1)+F|0)>-1?0:H}H=f+10092|0;E=f+14340|0;C=f+180|0;do{if((c[C>>2]|0)>-1){if((N&32|0)!=0){break}c[C>>2]=-1;qe[c[H>>2]&1023](c[E>>2]|0)}}while(0);C=f+184|0;do{if((c[C>>2]|0)>-1){if((N&16|0)!=0){break}c[C>>2]=-1;qe[c[H>>2]&1023]((c[E>>2]|0)+128|0)}}while(0);C=f+188|0;do{if((c[C>>2]|0)>-1){if((N&8|0)!=0){break}c[C>>2]=-1;qe[c[H>>2]&1023]((c[E>>2]|0)+256|0)}}while(0);C=f+192|0;do{if((c[C>>2]|0)>-1){if((N&4|0)!=0){break}c[C>>2]=-1;qe[c[H>>2]&1023]((c[E>>2]|0)+384|0)}}while(0);C=f+196|0;do{if((c[C>>2]|0)>-1){if((N&2|0)!=0){break}c[C>>2]=-1;qe[c[H>>2]&1023]((c[E>>2]|0)+512|0)}}while(0);C=f+200|0;if(!((c[C>>2]|0)>-1)){t=N;break}if((N&1|0)!=0){t=N;break}c[C>>2]=-1;qe[c[H>>2]&1023]((c[E>>2]|0)+640|0);t=N}}while(0);C=f+9984|0;F=c[C>>2]|0;v=f+11740|0;A=c[v>>2]|0;r=f+784|0;s=c[r>>2]|0;x=f+788|0;z=c[x>>2]|0;w=(z|0)>1;if((j|h|t|F|A|0)==0){if(w){O=z-1|0;P=s<<1|1}else{u=je(1>>>((1-z|0)>>>0)|s<<z|0)|0;G=f+796|0;B=c[G>>2]|0;y=u;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[G>>2]=(c[G>>2]|0)+4;O=z+31|0;P=1}c[r>>2]=P;c[x>>2]=O;if((p|0)!=0){G=f+13696|0;c[G>>2]=(c[G>>2]|0)+1;G=f+13700|0;c[G>>2]=(c[G>>2]|0)+1}G=f+13692|0;c[G>>2]=(c[G>>2]|0)+1;i=k;return}if(w){Q=z-1|0;R=s<<1;S=F;T=A}else{A=je(s<<z|0)|0;s=f+796|0;F=c[s>>2]|0;y=A;a[F]=y;y=y>>8;a[F+1|0]=y;y=y>>8;a[F+2|0]=y;y=y>>8;a[F+3|0]=y;c[s>>2]=(c[s>>2]|0)+4;Q=z+31|0;R=0;S=c[C>>2]|0;T=c[v>>2]|0}c[r>>2]=R;c[x>>2]=Q;v=t&3;z=t>>2;s=(c[f+13828>>2]|0)!=0&(v|0)==3?z:z^15;z=(S|0)==0?v:v|8;do{if((T|0)==0){v=d[1379128+z|0]|0;F=d[1379096+z|0]|0;if((Q|0)>(v|0)){U=Q;V=R<<v|F}else{A=je(F>>>((v-Q|0)>>>0)|R<<Q|0)|0;w=f+796|0;G=c[w>>2]|0;y=A;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;U=Q+32|0;V=F}F=U-v|0;c[r>>2]=V;c[x>>2]=F;v=d[1379529+(s<<1)|0]|0;w=d[1379528+(s<<1)|0]|0;if((F|0)>(v|0)){W=F;X=V<<v|w}else{G=je(w>>>((v-F|0)>>>0)|V<<F|0)|0;A=f+796|0;B=c[A>>2]|0;y=G;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;W=F+32|0;X=w}w=W-v|0;c[r>>2]=X;c[x>>2]=w;v=c[C>>2]|0;if((v|0)==0){Y=w}else{F=c[1520312+(v+2<<2)>>2]|0;if((w|0)>2){Z=w-2|0;_=X<<2|F}else{v=je(X<<w|F>>>((2-w|0)>>>0)|0)|0;A=f+796|0;B=c[A>>2]|0;y=v;a[B]=y;y=y>>8;a[B+1|0]=y;y=y>>8;a[B+2|0]=y;y=y>>8;a[B+3|0]=y;c[A>>2]=(c[A>>2]|0)+4;Z=w+30|0;_=F}c[r>>2]=_;c[x>>2]=Z;Y=Z}if((p|0)!=0){F=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-Y)|0;w=f+13700|0;A=c[w>>2]|0;c[w>>2]=F;w=f+13696|0;c[w>>2]=(c[w>>2]|0)-A+F}Rga(f,0,0,l,m)|0;F=c[l>>2]|0;A=h-F|0;if((c[f+13816>>2]|0)!=0){zqb(f,A);zqb(f,j-(c[m>>2]|0)|0);if((h-(c[l>>2]|0)|0)!=1){break}if((j-(c[m>>2]|0)|0)!=1){break}w=c[r>>2]|0;B=c[x>>2]|0;if((B|0)>1){$=B-1|0;aa=w<<1|1}else{v=je(1>>>((1-B|0)>>>0)|w<<B|0)|0;w=f+796|0;G=c[w>>2]|0;y=v;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;$=B+31|0;aa=1}c[r>>2]=aa;c[x>>2]=$;break}B=c[m>>2]|0;w=j-B|0;if((c[f+64>>2]&4|0)==0){Aqb(f,A,1);Aqb(f,w,1);break}if((F|0)==(h|0)){ba=d[1339809]|0}else{ba=(d[1339809+(A<<26>>26<<1)|0]|0)+1|0}if((B|0)==(j|0)){da=d[1339809]|0}else{da=(d[1339809+(w<<26>>26<<1)|0]|0)+1|0}w=(c[x>>2]|0)-(da+ba)|0;B=f+796|0;c[B>>2]=(c[B>>2]|0)+(-(w>>5<<2)|0);c[x>>2]=w&31}else{w=z|16;B=d[1379128+w|0]|0;A=d[1379096+w|0]|0;if((Q|0)>(B|0)){ea=Q;fa=R<<B|A}else{w=je(A>>>((B-Q|0)>>>0)|R<<Q|0)|0;F=f+796|0;G=c[F>>2]|0;y=w;a[G]=y;y=y>>8;a[G+1|0]=y;y=y>>8;a[G+2|0]=y;y=y>>8;a[G+3|0]=y;c[F>>2]=(c[F>>2]|0)+4;ea=Q+32|0;fa=A}A=ea-B|0;c[r>>2]=fa;c[x>>2]=A;B=d[1379529+(s<<1)|0]|0;F=d[1379528+(s<<1)|0]|0;if((A|0)>(B|0)){ga=A;ha=fa<<B|F}else{G=je(F>>>((B-A|0)>>>0)|fa<<A|0)|0;w=f+796|0;v=c[w>>2]|0;y=G;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;ga=A+32|0;ha=F}F=ga-B|0;c[r>>2]=ha;c[x>>2]=F;B=c[C>>2]|0;if((B|0)==0){ia=F}else{A=c[1520312+(B+2<<2)>>2]|0;if((F|0)>2){ja=F-2|0;ka=ha<<2|A}else{B=je(ha<<F|A>>>((2-F|0)>>>0)|0)|0;w=f+796|0;v=c[w>>2]|0;y=B;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[w>>2]=(c[w>>2]|0)+4;ja=F+30|0;ka=A}c[r>>2]=ka;c[x>>2]=ja;ia=ja}if((p|0)==0){la=f+796|0}else{A=f+796|0;F=((c[A>>2]|0)-(c[f+792>>2]|0)<<3)+(32-ia)|0;w=f+13700|0;v=c[w>>2]|0;c[w>>2]=F;w=f+13696|0;c[w>>2]=(c[w>>2]|0)-v+F;la=A}A=f+9148|0;F=f+13816|0;v=f+64|0;w=d[1339809]|0;B=0;do{Rga(f,B,0,l,m)|0;G=c[f+12496+(B<<2)>>2]|0;u=c[A>>2]|0;D=b[u+(G<<2)>>1]|0;I=b[u+(G<<2)+2>>1]|0;G=c[l>>2]|0;u=D-G|0;do{if((c[F>>2]|0)==0){ma=c[m>>2]|0;na=I-ma|0;if((c[v>>2]&4|0)==0){Aqb(f,u,1);Aqb(f,na,1);break}if((D|0)==(G|0)){oa=w}else{oa=(d[1339809+(u<<26>>26<<1)|0]|0)+1|0}if((I|0)==(ma|0)){pa=w}else{pa=(d[1339809+(na<<26>>26<<1)|0]|0)+1|0}na=(c[x>>2]|0)-(pa+oa)|0;c[la>>2]=(c[la>>2]|0)+(-(na>>5<<2)|0);c[x>>2]=na&31}else{zqb(f,u);zqb(f,I-(c[m>>2]|0)|0);if((D-(c[l>>2]|0)|0)!=1){break}if((I-(c[m>>2]|0)|0)!=1){break}na=c[r>>2]|0;ma=c[x>>2]|0;if((ma|0)>1){qa=ma-1|0;ra=na<<1|1}else{sa=je(1>>>((1-ma|0)>>>0)|na<<ma|0)|0;na=c[la>>2]|0;y=sa;a[na]=y;y=y>>8;a[na+1|0]=y;y=y>>8;a[na+2|0]=y;y=y>>8;a[na+3|0]=y;c[la>>2]=(c[la>>2]|0)+4;qa=ma+31|0;ra=1}c[r>>2]=ra;c[x>>2]=qa}}while(0);B=B+1|0;}while((B|0)<4)}}while(0);if((p|0)==0){break}r=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-(c[x>>2]|0))|0;C=f+13700|0;s=c[C>>2]|0;c[C>>2]=r;C=f+13664|0;c[C>>2]=(c[C>>2]|0)-s+r}else{r=f+228|0;do{if((c[r>>2]|0)==0){s=(c[f+180>>2]|0)>0?32:0;C=(c[f+184>>2]|0)>0?s|16:s;s=(c[f+188>>2]|0)>0?C|8:C;C=(c[f+192>>2]|0)>0?s|4:s;s=(c[f+196>>2]|0)>0?C|2:C;if((c[f+200>>2]|0)<=0){ta=s;break}ta=s|1}else{s=f+168|0;C=f+172|0;z=f+13832|0;B=0;w=0;while(1){v=g+(B<<7)|0;F=b[v>>1]|0;A=c[((B|0)<4?s:C)>>2]|0;E=o+(B<<2)|0;H=(Oga(f,B,E)|0)<<16>>16;I=(F&65535)-H<<16;F=A>>1;D=((((I|0)>-65536?F:-F|0)+(I>>16)|0)/(A|0)|0)&65535;do{if(D<<16>>16==0){I=f+180+(B<<2)|0;if((c[I>>2]|0)!=0){break}c[I>>2]=-1}}while(0);do{if((c[z>>2]|0)==0){if(D<<16>>16<-127){ua=-127;break}ua=D<<16>>16>127?127:D}else{ua=D}}while(0);b[v>>1]=ua;D=n+(B<<1)|0;I=((ca(ua<<16>>16,A)|0)+H|1)&65535;b[D>>1]=I;do{if(I<<16>>16<0){b[D>>1]=0;va=0}else{if(!(I<<16>>16>2047)){va=I;break}b[D>>1]=2047;va=2047}}while(0);b[c[E>>2]>>1]=va;if((c[f+180+(B<<2)>>2]|0)>-1){wa=1<<5-B|w}else{wa=w}D=B+1|0;if((D|0)<6){B=D;w=wa}else{ta=wa;break}}}}while(0);x=ta&3;w=f+9984|0;B=(c[w>>2]|0)!=0;if((c[f+9992>>2]|0)==1){z=B?x|4:x;C=d[1379080+z|0]|0;s=d[1379064+z|0]|0;z=f+784|0;D=c[z>>2]|0;I=f+788|0;H=c[I>>2]|0;if((H|0)>(C|0)){xa=H-C|0;ya=D<<C|s}else{A=je(s>>>((C-H|0)>>>0)|D<<H|0)|0;D=f+796|0;v=c[D>>2]|0;y=A;a[v]=y;y=y>>8;a[v+1|0]=y;y=y>>8;a[v+2|0]=y;y=y>>8;a[v+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;xa=32-C+H|0;ya=s}c[z>>2]=ya;c[I>>2]=xa;za=ya;Aa=xa}else{I=f+784|0;z=c[I>>2]|0;s=f+788|0;H=c[s>>2]|0;if((H|0)>1){Ba=H-1|0;Ca=z<<1}else{C=je(z<<H|0)|0;z=f+796|0;D=c[z>>2]|0;y=C;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;Ba=H+31|0;Ca=0}c[I>>2]=Ca;c[s>>2]=Ba;H=(B?x|8:x)|4;x=d[1379128+H|0]|0;B=d[1379096+H|0]|0;if((Ba|0)>(x|0)){Da=Ba;Ea=Ca<<x|B}else{H=je(B>>>((x-Ba|0)>>>0)|Ca<<Ba|0)|0;z=f+796|0;D=c[z>>2]|0;y=H;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;Da=Ba+32|0;Ea=B}B=Da-x|0;c[I>>2]=Ea;c[s>>2]=B;za=Ea;Aa=B}B=f+784|0;s=f+788|0;if((c[r>>2]|0)==0){Fa=za;Ga=Aa}else{if((Aa|0)>1){Ha=Aa-1|0;Ia=za<<1}else{I=je(za<<Aa|0)|0;x=f+796|0;z=c[x>>2]|0;y=I;a[z]=y;y=y>>8;a[z+1|0]=y;y=y>>8;a[z+2|0]=y;y=y>>8;a[z+3|0]=y;c[x>>2]=(c[x>>2]|0)+4;Ha=Aa+31|0;Ia=0}c[B>>2]=Ia;c[s>>2]=Ha;Fa=Ia;Ga=Ha}x=ta>>2;z=d[1379529+(x<<1)|0]|0;I=d[1379528+(x<<1)|0]|0;if((Ga|0)>(z|0)){Ja=Ga-z|0;Ka=Fa<<z|I}else{x=je(I>>>((z-Ga|0)>>>0)|Fa<<Ga|0)|0;D=f+796|0;H=c[D>>2]|0;y=x;a[H]=y;y=y>>8;a[H+1|0]=y;y=y>>8;a[H+2|0]=y;y=y>>8;a[H+3|0]=y;c[D>>2]=(c[D>>2]|0)+4;Ja=32-z+Ga|0;Ka=I}c[B>>2]=Ka;c[s>>2]=Ja;I=c[w>>2]|0;if((I|0)==0){La=Ja}else{w=c[1520312+(I+2<<2)>>2]|0;if((Ja|0)>2){Ma=Ja-2|0;Na=Ka<<2|w}else{I=je(Ka<<Ja|w>>>((2-Ja|0)>>>0)|0)|0;z=f+796|0;D=c[z>>2]|0;y=I;a[D]=y;y=y>>8;a[D+1|0]=y;y=y>>8;a[D+2|0]=y;y=y>>8;a[D+3|0]=y;c[z>>2]=(c[z>>2]|0)+4;Ma=Ja+30|0;Na=w}c[B>>2]=Na;c[s>>2]=Ma;La=Ma}if((p|0)==0){break}s=((c[f+796>>2]|0)-(c[f+792>>2]|0)<<3)+(32-La)|0;B=f+13700|0;w=c[B>>2]|0;c[B>>2]=s;B=f+13696|0;c[B>>2]=(c[B>>2]|0)-w+s}}while(0);La=f+228|0;Ma=f+13828|0;Na=f+784|0;Ja=Na|0;Ka=f+788|0;Ga=f+44|0;Fa=f+796|0;ta=0;Ha=c[La>>2]|0;do{Ia=g+(ta<<7)|0;Aa=(c[q>>2]|0)==0;za=(Ha|0)==0;a:do{if(Aa){if(za){Oa=1378528;Pa=168}else{Pa=167}}else{if(!za){Pa=167;break}Ea=b[Ia>>1]|0;do{if(Ea<<16>>16>254){Qa=254;Ra=254;Pa=155}else{if(Ea<<16>>16<1){Qa=1;Ra=1;Pa=155;break}if(!(Ea<<16>>16==128)){Sa=Ea<<16>>16;break}Da=c[Ja>>2]|0;Ba=c[Ka>>2]|0;if((Ba|0)>8){Ta=Ba-8|0;Ua=Da<<8|255}else{Ca=je(255>>>((8-Ba|0)>>>0)|Da<<Ba|0)|0;Da=c[Fa>>2]|0;y=Ca;a[Da]=y;y=y>>8;a[Da+1|0]=y;y=y>>8;a[Da+2|0]=y;y=y>>8;a[Da+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;Ta=Ba+24|0;Ua=255}c[Ja>>2]=Ua;c[Ka>>2]=Ta;Va=1378528;Wa=1;break a}}while(0);if((Pa|0)==155){Pa=0;b[Ia>>1]=Ra;Sa=Qa}Ea=c[Ja>>2]|0;Ba=f+788|0;Da=c[Ba>>2]|0;if((Da|0)>8){Xa=Da-8|0;Ya=Ea<<8|Sa}else{Ca=je(Sa>>>((8-Da|0)>>>0)|Ea<<Da|0)|0;Ea=f+796|0;xa=c[Ea>>2]|0;y=Ca;a[xa]=y;y=y>>8;a[xa+1|0]=y;y=y>>8;a[xa+2|0]=y;y=y>>8;a[xa+3|0]=y;c[Ea>>2]=(c[Ea>>2]|0)+4;Xa=Da+24|0;Ya=Sa}c[Ja>>2]=Ya;c[Ba>>2]=Xa;Va=1378528;Wa=1}}while(0);if((Pa|0)==167){Pa=0;Oa=Aa?1378528:1316048;Pa=168}do{if((Pa|0)==168){Pa=0;if((c[Ma>>2]|0)==0|Aa^1){Va=Oa;Wa=0;break}za=c[f+180+(ta<<2)>>2]|0;if((za|0)<0){Za=0;_a=0;$a=-1}else{r=Oa|0;Ba=c[329012]|0;Da=Oa+8|0;Ea=c[329014]|0;xa=0;Ca=-1;ya=0;wa=0;va=-1;while(1){ua=b[g+(ta<<7)+(d[f+368+xa|0]<<1)>>1]|0;o=ua<<16>>16;if(ua<<16>>16==0){ab=va;bb=wa;cb=ya;db=Ca}else{qa=xa-Ca|0;ra=qa-1|0;la=(xa|0)==(za|0)|0;m=ua<<16>>16<0?-o|0:o;o=d[(c[Oa+20+(la<<2)>>2]|0)+ra|0]|0;ua=c[r>>2]|0;do{if((o|0)<(ua|0)){if((a[(c[Oa+28+(la<<2)>>2]|0)+ra|0]|0)<(m|0)){eb=ua;break}eb=m-1+o|0}else{eb=ua}}while(0);o=d[(c[1316068+(la<<2)>>2]|0)+ra|0]|0;do{if((o|0)<(Ba|0)){if((a[(c[1316076+(la<<2)>>2]|0)+ra|0]|0)<(m|0)){fb=Ba;break}fb=m-1+o|0}else{fb=Ba}}while(0);o=wa+1+(e[(c[Da>>2]|0)+(eb<<2)+2>>1]|0)|0;m=ya+1+(e[Ea+(fb<<2)+2>>1]|0)|0;if((fb|0)==(Ba|0)){gb=qa;hb=m+14|0}else{gb=d[110072+fb|0]|0;hb=m}ab=gb+va|0;bb=(eb|0)==(ua|0)?o+14|0:o;cb=hb;db=xa}o=xa+1|0;if((o|0)>(za|0)){Za=cb;_a=bb;$a=ab;break}else{xa=o;Ca=db;ya=cb;wa=bb;va=ab}}}Va=(Za|0)<(_a|0)&($a|0)>63?1316048:Oa;Wa=0}}while(0);Aa=c[f+180+(ta<<2)>>2]|0;if((Wa|0)<=(Aa|0)){va=Va|0;wa=Va+8|0;ya=Wa;Ca=Wa-1|0;while(1){xa=b[g+(ta<<7)+(d[f+368+ya|0]<<1)>>1]|0;za=xa<<16>>16;do{if(xa<<16>>16==0){ib=Ca}else{Ba=ya-Ca-1|0;Ea=(ya|0)==(Aa|0)|0;Da=(xa&65535)>>>15&65535;r=xa<<16>>16<0?-za|0:za;o=d[(c[Va+20+(Ea<<2)>>2]|0)+Ba|0]|0;m=c[va>>2]|0;do{if((o|0)<(m|0)){if((a[(c[Va+28+(Ea<<2)>>2]|0)+Ba|0]|0)<(r|0)){jb=m;break}jb=r-1+o|0}else{jb=m}}while(0);m=c[wa>>2]|0;o=e[m+(jb<<2)+2>>1]|0;ua=e[m+(jb<<2)>>1]|0;m=c[Ja>>2]|0;qa=c[Ka>>2]|0;if((qa|0)>(o|0)){kb=qa-o|0;lb=m<<o|ua}else{ra=je(ua>>>((o-qa|0)>>>0)|m<<qa|0)|0;m=c[Fa>>2]|0;y=ra;a[m]=y;y=y>>8;a[m+1|0]=y;y=y>>8;a[m+2|0]=y;y=y>>8;a[m+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;kb=32-o+qa|0;lb=ua}c[Ja>>2]=lb;c[Ka>>2]=kb;if((jb|0)!=(c[va>>2]|0)){if((kb|0)>1){mb=kb-1|0;nb=lb<<1|Da}else{ua=je(Da>>>((1-kb|0)>>>0)|lb<<kb|0)|0;qa=c[Fa>>2]|0;y=ua;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;mb=kb+31|0;nb=Da}c[Ja>>2]=nb;c[Ka>>2]=mb;ib=ya;break}if((c[Ga>>2]|0)>=2){wfa(Na,za,r,Ba,Ea);ib=ya;break}if((kb|0)>1){ob=kb-1|0;pb=lb<<1|Ea}else{qa=je(Ea>>>((1-kb|0)>>>0)|lb<<kb|0)|0;ua=c[Fa>>2]|0;y=qa;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;ob=kb+31|0;pb=Ea}c[Ja>>2]=pb;c[Ka>>2]=ob;if((ob|0)>6){qb=ob-6|0;rb=pb<<6|Ba}else{ua=je(Ba>>>((6-ob|0)>>>0)|pb<<ob|0)|0;qa=c[Fa>>2]|0;y=ua;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;qb=ob+26|0;rb=Ba}c[Ja>>2]=rb;c[Ka>>2]=qb;if((r|0)<128){qa=za&255;if((qb|0)>8){sb=qb-8|0;tb=rb<<8|qa}else{ua=je(qa>>>((8-qb|0)>>>0)|rb<<qb|0)|0;o=c[Fa>>2]|0;y=ua;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;sb=qb+24|0;tb=qa}c[Ja>>2]=tb;c[Ka>>2]=sb;ib=ya;break}if((qb|0)>8){ub=qb-8|0;vb=rb<<8|128}else{qa=je(128>>>((8-qb|0)>>>0)|rb<<qb|0)|0;o=c[Fa>>2]|0;y=qa;a[o]=y;y=y>>8;a[o+1|0]=y;y=y>>8;a[o+2|0]=y;y=y>>8;a[o+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;ub=qb+24|0;vb=128}c[Ja>>2]=vb;c[Ka>>2]=ub;o=za&31;if((ub|0)>5){wb=ub-5|0;xb=vb<<5|o}else{qa=je(o>>>((5-ub|0)>>>0)|vb<<ub|0)|0;ua=c[Fa>>2]|0;y=qa;a[ua]=y;y=y>>8;a[ua+1|0]=y;y=y>>8;a[ua+2|0]=y;y=y>>8;a[ua+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;wb=ub+27|0;xb=o}c[Ja>>2]=xb;c[Ka>>2]=wb;o=za>>>5&63;if((wb|0)>6){yb=wb-6|0;zb=xb<<6|o}else{ua=je(o>>>((6-wb|0)>>>0)|xb<<wb|0)|0;qa=c[Fa>>2]|0;y=ua;a[qa]=y;y=y>>8;a[qa+1|0]=y;y=y>>8;a[qa+2|0]=y;y=y>>8;a[qa+3|0]=y;c[Fa>>2]=(c[Fa>>2]|0)+4;yb=wb+26|0;zb=o}c[Ja>>2]=zb;c[Ka>>2]=yb;ib=ya}}while(0);za=ya+1|0;if((za|0)>(Aa|0)){break}else{ya=za;Ca=ib}}}Ha=c[La>>2]|0;do{if((Ha|0)!=0){if((c[q>>2]|0)==0){break}b[Ia>>1]=b[n+(ta<<1)>>1]|0}}while(0);ta=ta+1|0;}while((ta|0)<6);if((p|0)==0){i=k;return}p=(c[q>>2]|0)==0;q=((c[Fa>>2]|0)-(c[f+792>>2]|0)<<3)+(32-(c[Ka>>2]|0))|0;Ka=f+13700|0;Fa=c[Ka>>2]|0;c[Ka>>2]=q;Ka=q-Fa|0;if(p){p=f+13676|0;c[p>>2]=(c[p>>2]|0)+Ka;p=f+13684|0;c[p>>2]=(c[p>>2]|0)+1;i=k;return}else{p=f+13672|0;c[p>>2]=(c[p>>2]|0)+Ka;Ka=f+13680|0;c[Ka>>2]=(c[Ka>>2]|0)+1;i=k;return}}function zqb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((d|0)==1){e=b+784|0;f=c[e>>2]|0;g=b+788|0;h=c[g>>2]|0;if((h|0)>3){i=h-3|0;j=f<<3}else{k=je(f<<h|0)|0;f=b+796|0;l=c[f>>2]|0;y=k;a[l]=y;y=y>>8;a[l+1|0]=y;y=y>>8;a[l+2|0]=y;y=y>>8;a[l+3|0]=y;c[f>>2]=(c[f>>2]|0)+4;i=h+29|0;j=0}c[e>>2]=j;c[g>>2]=i;return}else if((d|0)==0){i=b+784|0;g=c[i>>2]|0;j=b+788|0;e=c[j>>2]|0;if((e|0)>1){m=e-1|0;n=g<<1|1}else{h=je(1>>>((1-e|0)>>>0)|g<<e|0)|0;g=b+796|0;f=c[g>>2]|0;y=h;a[f]=y;y=y>>8;a[f+1|0]=y;y=y>>8;a[f+2|0]=y;y=y>>8;a[f+3|0]=y;c[g>>2]=(c[g>>2]|0)+4;m=e+31|0;n=1}c[i>>2]=n;c[j>>2]=m;return}else if((d|0)==(-1|0)){m=b+784|0;j=c[m>>2]|0;n=b+788|0;i=c[n>>2]|0;if((i|0)>3){o=i-3|0;p=j<<3|2}else{e=je(2>>>((3-i|0)>>>0)|j<<i|0)|0;j=b+796|0;g=c[j>>2]|0;y=e;a[g]=y;y=y>>8;a[g+1|0]=y;y=y>>8;a[g+2|0]=y;y=y>>8;a[g+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;o=i+29|0;p=2}c[m>>2]=p;c[n>>2]=o;return}else{o=((d|0)<0?-d|0:d)&65535;do{if(o<<16>>16==0){q=0;r=0}else{n=0;p=o;while(1){m=p<<16>>16>>>1&65535;s=n+1&65535;if(m<<16>>16==0){break}else{n=s;p=m}}p=s<<16>>16;if(!(n<<16>>16>0)){q=0;r=p;break}m=o<<16>>16;i=0;j=n;do{g=(j<<16>>16)-1|0;i=i<<2|(1<<g&m)>>g<<1|1;j=j-1&65535;}while(j<<16>>16>0);q=i<<1;r=p}}while(0);o=(q|d>>>31)<<1;d=r<<1|1;r=b+784|0;q=c[r>>2]|0;s=b+788|0;j=c[s>>2]|0;if((j|0)>(d|0)){t=j-d|0;u=q<<d|o}else{m=je(o>>>((d-j|0)>>>0)|q<<j|0)|0;q=b+796|0;b=c[q>>2]|0;y=m;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[q>>2]=(c[q>>2]|0)+4;t=32-d+j|0;u=o}c[r>>2]=u;c[s>>2]=t;return}}function Aqb(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((e|0)==0){g=d[1339809]|0;h=d[1339808]|0;i=b+784|0;j=c[i>>2]|0;k=b+788|0;l=c[k>>2]|0;if((l|0)>(g|0)){m=l-g|0;n=j<<g|h}else{o=je(h>>>((g-l|0)>>>0)|j<<l|0)|0;j=b+796|0;p=c[j>>2]|0;y=o;a[p]=y;y=y>>8;a[p+1|0]=y;y=y>>8;a[p+2|0]=y;y=y>>8;a[p+3|0]=y;c[j>>2]=(c[j>>2]|0)+4;m=32-g+l|0;n=h}c[i>>2]=n;c[k>>2]=m;return}m=f-1|0;k=27-f|0;n=e<<k>>k;k=n>>31;e=(k^n)-k-1|0;n=(e>>m)+1|0;i=d[1339809+(n<<1)|0]|0;h=i+1|0;l=(d[1339808+(n<<1)|0]|0)<<1|k&1;k=b+784|0;n=c[k>>2]|0;g=b+788|0;j=c[g>>2]|0;if((j|0)>(h|0)){q=j-h|0;r=l|n<<h}else{p=je(l>>>((h-j|0)>>>0)|n<<j|0)|0;n=b+796|0;h=c[n>>2]|0;y=p;a[h]=y;y=y>>8;a[h+1|0]=y;y=y>>8;a[h+2|0]=y;y=y>>8;a[h+3|0]=y;c[n>>2]=(c[n>>2]|0)+4;q=31-i+j|0;r=l}c[k>>2]=r;c[g>>2]=q;if((m|0)<=0){return}l=e&(1<<m)-1;if((q|0)>(m|0)){s=q-m|0;t=r<<m|l}else{e=je(r<<q|l>>>((m-q|0)>>>0)|0)|0;m=b+796|0;b=c[m>>2]|0;y=e;a[b]=y;y=y>>8;a[b+1|0]=y;y=y>>8;a[b+2|0]=y;y=y>>8;a[b+3|0]=y;c[m>>2]=(c[m>>2]|0)+4;s=33-f+q|0;t=l}c[k>>2]=t;c[g>>2]=s;return}function Bqb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if(!(a[1379304]|0)){a[1379304]=1;ATa(1378528,8222472);ATa(1316048,8222862);Cqb(1316048,3569392);Cqb(1378528,3585776);e=a[1339809]|0;f=d[1339873]|0;g=1;while(1){h=g-1|0;i=g+1|0;j=i+f|0;k=-4096;while(1){if((k|0)==0){a[5488800+(g*8193|0)|0]=e;k=1;continue}l=(((k|0)<0?-k|0:k)-1>>h)+1|0;if((l|0)<33){m=(d[1339809+(l<<1)|0]|0)+g&255}else{n=l>>5;l=n>>>0>65535>>>0;o=l?n>>>16:n;n=l?16:0;if((o&65280|0)==0){p=n;q=o}else{p=n|8;q=o>>>8}m=j+p+(d[1359664+q|0]|0)&255}a[k+4096+(5484704+(g*8193|0))|0]=m;k=k+1|0;if((k|0)>=4097){break}}if((i|0)<8){g=i}else{break}}mrc(8823392,7,4096)|0;mrc(8824416,6,2048)|0;mrc(8824928,5,1024)|0;mrc(8825184,4,512)|0;mrc(8825312,3,256)|0;mrc(8825376,2,128)|0;mrc(8825408,1,64)|0;mrc(3622e3,1,8193)|0}c[b+12460>>2]=5484704;c[b+13100>>2]=3585776;g=b+13092|0;c[g>>2]=3585776;c[b+13104>>2]=3593968;m=b+13096|0;c[m>>2]=3593968;if((c[b+228>>2]|0)!=0){c[g>>2]=3569392;c[m>>2]=3577584}c[b+13088>>2]=22;m=c[b+48>>2]|0;if((m|0)==20){if((c[b+13816>>2]|0)!=0){c[b+11856>>2]=3622e3}g=b+13080|0;if((c[b+13832>>2]|0)==0){c[g>>2]=-127;c[b+13084>>2]=127;return}else{c[g>>2]=-2047;c[b+13084>>2]=2047;return}}else if((m|0)==13){c[b+11856>>2]=8821344;return}else if((m|0)==22){m=b+13080|0;if((c[b+44>>2]|0)>1){c[m>>2]=-1023;c[b+13084>>2]=1023}else{c[m>>2]=-127;c[b+13084>>2]=127}c[b+9892>>2]=1347360;c[b+9888>>2]=1347360;return}else{c[b+13080>>2]=-127;c[b+13084>>2]=127;c[b+9892>>2]=1347360;c[b+9888>>2]=1347360;return}}function Cqb(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=b|0;h=b+8|0;i=-64;while(1){if((i|0)==0){i=i+1|0;continue}j=i+64|0;k=(i|0)<0?-i|0:i;l=k-1|0;m=0;do{n=j+(m<<7)|0;o=f+n|0;a[o]=100;p=d[(c[b+20>>2]|0)+m|0]|0;q=c[g>>2]|0;do{if((p|0)<(q|0)){if((a[(c[b+28>>2]|0)+m|0]|0)<(k|0)){r=7;break}s=l+p|0;t=c[h>>2]|0;u=(e[t+(s<<2)+2>>1]|0)+1|0;if(!((s|0)!=(q|0)&u>>>0<100>>>0)){v=q;w=t;x=100;break}a[o]=u;v=c[g>>2]|0;w=c[h>>2]|0;x=u&255}else{r=7}}while(0);if((r|0)==7){r=0;v=q;w=c[h>>2]|0;x=100}p=(e[w+(v<<2)+2>>1]|0)+15|0;if(p>>>0<x>>>0){a[o]=p}p=f+(n+8192)|0;a[p]=100;u=d[(c[b+24>>2]|0)+m|0]|0;t=c[g>>2]|0;do{if((u|0)<(t|0)){if((a[(c[b+32>>2]|0)+m|0]|0)<(k|0)){r=16;break}s=l+u|0;y=c[h>>2]|0;z=(e[y+(s<<2)+2>>1]|0)+1|0;if(!((s|0)!=(t|0)&z>>>0<100>>>0)){A=t;B=y;C=100;break}a[p]=z;A=c[g>>2]|0;B=c[h>>2]|0;C=z&255}else{r=16}}while(0);if((r|0)==16){r=0;A=t;B=c[h>>2]|0;C=100}u=(e[B+(A<<2)+2>>1]|0)+15|0;if(u>>>0<C>>>0){a[p]=u}m=m+1|0;}while((m|0)<64);i=i+1|0;if((i|0)>=64){break}}return}function Dqb(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[a+5900>>2]<<1|1;c[a+5904>>2]=b;e=c[a+5892>>2]|0;f=((e-1+b|0)/(b|0)|0)+1|0;b=a+5896|0;c[b>>2]=f;g=0;while(1){if((1<<g|0)<(f|0)){g=g+1|0}else{break}}c[a+5888>>2]=g;h=e>>>0>65535>>>0;i=h?e>>>16:e;e=h?16:0;if((i&65280|0)==0){j=e;k=i}else{j=e|8;k=i>>>8}i=j+1+(d[1359664+k|0]|0)|0;k=(i|0)>2?i:2;c[a+5884>>2]=k;c[a+5876>>2]=(((k|0)>8?k:8)+k<<1)-g;g=0;k=f;while(1){f=k+32>>6;c[a+12+(g<<2)>>2]=(f|0)>2?f:2;c[a+4408+(g<<2)>>2]=1;f=g+1|0;if((f|0)>=367){break}g=f;k=c[b>>2]|0}return}function Eqb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a+5892|0;e=c[d>>2]|0;f=(b|0)==0;if((e|0)!=0&f){g=e}else{e=(1<<c[a+5884>>2])-1|0;c[d>>2]=e;g=e}do{if((g|0)>127){if((g|0)>4095){h=16}else{h=g+128>>8}e=a|0;d=c[e>>2]|0;if((d|0)!=0&f){i=d}else{d=c[a+5900>>2]|0;b=h+2+(d*3|0)|0;j=d+1|0;d=(b|0)>(g|0)|(b|0)<(j|0)?j:b;c[e>>2]=d;i=d}d=a+4|0;e=c[d>>2]|0;if((e|0)!=0&f){k=e}else{e=((c[a+5900>>2]|0)*5|0)+(h<<2|3)|0;b=(e|0)>(g|0)|(e|0)<(i|0)?i:e;c[d>>2]=b;k=b}b=a+8|0;if((c[b>>2]|0)!=0&f){break}d=(h*17|0)+4+((c[a+5900>>2]|0)*7|0)|0;c[b>>2]=(d|0)>(g|0)|(d|0)<(k|0)?k:d}else{d=256/(g+1|0)|0;b=a|0;e=c[b>>2]|0;if((e|0)!=0&f){l=e}else{e=c[a+5900>>2]|0;j=(e*3|0)+(3/(d|0)|0)|0;m=(j|0)<2?2:j;j=e+1|0;e=(m|0)>(g|0)|(m|0)<(j|0)?j:m;c[b>>2]=e;l=e}e=a+4|0;b=c[e>>2]|0;if((b|0)!=0&f){n=b}else{b=((c[a+5900>>2]|0)*5|0)+(7/(d|0)|0)|0;m=(b|0)<3?3:b;b=(m|0)>(g|0)|(m|0)<(l|0)?l:m;c[e>>2]=b;n=b}b=a+8|0;if((c[b>>2]|0)!=0&f){break}e=((c[a+5900>>2]|0)*7|0)+(21/(d|0)|0)|0;d=(e|0)<4?4:e;c[b>>2]=(d|0)>(g|0)|(d|0)<(n|0)?n:d}}while(0);n=a+5880|0;if((c[n>>2]|0)!=0&f){return}c[n>>2]=64;return}function Fqb(a,b,d){a=a|0;b=+b;d=d|0;var e=0,f=0,j=0.0,k=0,l=0.0,m=0,n=0.0,o=0,p=0;e=i;i=i+8192|0;f=e|0;j=b*3.141592653589793/+(d|0);b=j*j;if((d|0)>=1025){KIb(0,0,2425240,(k=i,i=i+24|0,c[k>>2]=2581224,c[k+8>>2]=2437264,c[k+16>>2]=33,k)|0);i=k;Hd()}k=(d|0)>0;if(k){l=0.0;m=0}else{i=e;return}do{j=b*+(ca(d-m|0,m)|0);n=1.0;o=50;do{n=j*n/+(ca(o,o)|0)+1.0;o=o-1|0;}while((o|0)>0);l=l+n;h[f+(m<<3)>>3]=l;m=m+1|0;}while((m|0)<(d|0));b=l+1.0;if(k){p=0}else{i=e;return}do{g[a+(p<<2)>>2]=+S(+h[f+(p<<3)>>3]/b);p=p+1|0;}while((p|0)<(d|0));i=e;return}function Gqb(a){a=a|0;var b=0;do{if(((cYb()|0)&16711680|0)!=0){if(((cYb()|0)&16711680|0)!=65536){return}if(((cYb()|0)&65280)>>>0<768>>>0){break}return}}while(0);b=a+16|0;c[b>>2]=c[b>>2]|512;return}function Hqb(a,b){a=a|0;b=b|0;c[a>>2]=290;c[a+4>>2]=192;c[a+16>>2]=188;c[a+12>>2]=616;c[a+8>>2]=402;return}function Iqb(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=(f>>>1)*65537|0;i=h+65537|0;j=g-2|0;if((j|0)<0){k=0}else{l=0;while(1){m=c[d+(l<<1)>>2]|0;n=a+(l<<1)|0;o=c[n>>2]|0;c[n>>2]=(o&h)+(m&h)^(o^m)&i;m=l+2|0;if((m|0)>(j|0)){k=m;break}else{l=m}}}if((k|0)<(g|0)){p=k}else{return}do{k=a+(p<<1)|0;b[k>>1]=(e[d+(p<<1)>>1]|0)+(e[k>>1]|0)&f;p=p+1|0;}while((p|0)<(g|0));return}function Jqb(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;do{if((f&3|0)==0){i=(g>>>1)*65537|0;j=i+65537|0;k=h-2|0;if((k|0)<0){l=0;break}else{m=0}while(1){n=c[d+(m<<1)>>2]|0;o=c[f+(m<<1)>>2]|0;c[a+(m<<1)>>2]=(n|j)-(o&i)^(o^~n)&j;n=m+2|0;if((n|0)>(k|0)){l=n;break}else{m=n}}}else{if((h|0)>3){p=0;q=3}else{l=0;break}while(1){b[a+(p<<1)>>1]=(e[d+(p<<1)>>1]|0)-(e[f+(p<<1)>>1]|0)&g;k=p|1;b[a+(k<<1)>>1]=(e[d+(k<<1)>>1]|0)-(e[f+(k<<1)>>1]|0)&g;k=p|2;b[a+(k<<1)>>1]=(e[d+(k<<1)>>1]|0)-(e[f+(k<<1)>>1]|0)&g;b[a+(q<<1)>>1]=(e[d+(q<<1)>>1]|0)-(e[f+(q<<1)>>1]|0)&g;k=p+4|0;j=k|3;if((j|0)<(h|0)){p=k;q=j}else{l=k;break}}}}while(0);if((l|0)<(h|0)){r=l}else{return}do{b[a+(r<<1)>>1]=(e[d+(r<<1)>>1]|0)-(e[f+(r<<1)>>1]|0)&g;r=r+1|0;}while((r|0)<(h|0));return}function Kqb(a,c,d,f,g){a=a|0;c=c|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=f-1|0;if((h|0)>0){i=g;j=0;while(1){k=(e[c+(j<<1)>>1]|0)+i|0;b[a+(j<<1)>>1]=k&d;l=j|1;m=k+(e[c+(l<<1)>>1]|0)|0;b[a+(l<<1)>>1]=m&d;l=j+2|0;if((l|0)<(h|0)){i=m;j=l}else{n=m;o=l;break}}}else{n=g;o=0}if((o|0)<(f|0)){p=n;q=o}else{r=n;return r|0}while(1){n=(e[c+(q<<1)>>1]|0)+p|0;b[a+(q<<1)>>1]=n&d;o=q+1|0;if((o|0)<(f|0)){p=n;q=o}else{r=n;break}}return r|0}function Lqb(a,d,f,g,h,i,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;k=c[i>>2]|0;l=c[j>>2]&65535;m=k&65535;if((h|0)<=0){n=l;o=m;c[i>>2]=o;p=n&65535;c[j>>2]=p;return}q=0;r=k&65535;k=l;l=m;while(1){m=b[d+(q<<1)>>1]|0;s=m&65535;t=l-(k&65535)+s&g;do{if((r&65535)>>>0>(m&65535)>>>0){if((t|0)<=(s|0)){u=s;break}u=(t|0)>(l|0)?l:t}else{if((s|0)<=(t|0)){u=s;break}u=(t|0)>(l|0)?t:l}}while(0);t=(e[f+(q<<1)>>1]|0)+u&g;s=t&65535;b[a+(q<<1)>>1]=s;v=q+1|0;w=t&65535;if((v|0)<(h|0)){q=v;r=s;k=m;l=w}else{n=m;o=w;break}}c[i>>2]=o;p=n&65535;c[j>>2]=p;return}function Mqb(a,d,e,f,g,h,i){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=c[h>>2]|0;k=c[i>>2]&65535;l=j&65535;if((g|0)<=0){m=k;n=l;c[h>>2]=n;o=m&65535;c[i>>2]=o;return}p=j&65535;j=k;k=0;q=l;while(1){l=b[d+(k<<1)>>1]|0;r=l&65535;s=q-(j&65535)+r&f;do{if((p&65535)>>>0>(l&65535)>>>0){if((s|0)<=(r|0)){t=r;break}t=(s|0)>(q|0)?q:s}else{if((r|0)<=(s|0)){t=r;break}t=(s|0)>(q|0)?s:q}}while(0);s=b[e+(k<<1)>>1]|0;r=s&65535;b[a+(k<<1)>>1]=r-t&f;u=k+1|0;if((u|0)<(g|0)){p=s;j=l;k=u;q=r}else{m=l;n=r;break}}c[h>>2]=n;o=m&65535;c[i>>2]=o;return}function Nqb(a,d,e,f){a=a|0;d=d|0;e=e|0;f=+f;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0,s=0.0,t=0.0,u=0,v=0,w=0;mrc(a|0,0,60)|0;g=1<<d;c[a+20>>2]=d;c[a+16>>2]=g;h=g>>2;i=a+60|0;c[i>>2]=0;do{if((Hub(a,d-2|0,e)|0)<0){j=a+24|0}else{k=hJb(((g|0)/2|0)<<1)|0;l=k;m=a+24|0;c[m>>2]=l;if((k|0)==0){j=m;break}n=c[i>>2]|0;if((n|0)==0){c[a+28>>2]=l+(h<<1);o=1}else if((n|0)==1){c[a+28>>2]=k+2;o=2}else{j=m;break}p=(f<0.0?+(h|0):0.0)+.125;q=+S(+R(+f));if((h|0)<=0){r=0;return r|0}s=+(g|0);k=a+28|0;n=0;while(1){t=(p+ +(n|0))*6.283185307179586/s;l=Lc(+(q*(-0.0- +U(t))*32768.0))|0;if((l|0)<-32767){u=-32767}else{u=(l|0)>32767?32767:l&65535}l=ca(n,o)|0;b[(c[m>>2]|0)+(l<<1)>>1]=u;v=Lc(+(q*(-0.0- +V(t))*32768.0))|0;if((v|0)<-32767){w=-32767}else{w=(v|0)>32767?32767:v&65535}b[(c[k>>2]|0)+(l<<1)>>1]=w;l=n+1|0;if((l|0)<(h|0)){n=l}else{r=0;break}}return r|0}}while(0);mJb(j);Lub(a);r=-1;return r|0}function Oqb(a){a=a|0;mJb(a+24|0);Lub(a);return}function Pqb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=d;d=1<<c[a+20>>2];k=d>>2;l=d>>3;if((k|0)>0){m=f+((d>>1)-1<<1)|0;d=f;f=0;while(1){n=e[g+(f<<1)>>1]|0;o=h+(f<<1)|0;p=ca(b[o>>1]|0,b[m>>1]|0)|0;q=i+(f<<1)|0;b[j+(n<<2)>>1]=(p-(ca(b[q>>1]|0,b[d>>1]|0)|0)|0)>>>15;p=ca(b[q>>1]|0,b[m>>1]|0)|0;b[j+(n<<2)+2>>1]=((ca(b[o>>1]|0,b[d>>1]|0)|0)+p|0)>>>15;p=f+1|0;if((p|0)<(k|0)){m=m-4|0;d=d+4|0;f=p}else{break}}}re[c[a+36>>2]&1023](a,j);if((l|0)>0){r=0}else{return}do{a=l-r-1|0;f=j+(a<<2)+2|0;d=b[f>>1]|0;m=b[i+(a<<1)>>1]|0;k=ca(m,d)|0;g=j+(a<<2)|0;p=b[g>>1]|0;o=b[h+(a<<1)>>1]|0;a=(k-(ca(o,p)|0)|0)>>>15&65535;k=((ca(o,d)|0)+(ca(p,m)|0)|0)>>>15&65535;m=r+l|0;p=j+(m<<2)+2|0;d=b[p>>1]|0;o=b[i+(m<<1)>>1]|0;n=ca(o,d)|0;q=j+(m<<2)|0;s=b[q>>1]|0;t=b[h+(m<<1)>>1]|0;m=(n-(ca(t,s)|0)|0)>>>15&65535;n=((ca(t,d)|0)+(ca(s,o)|0)|0)>>>15&65535;b[g>>1]=a;b[f>>1]=n;b[q>>1]=m;b[p>>1]=k;r=r+1|0;}while((r|0)<(l|0));return}function Qqb(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=1<<c[a+20>>2];g=f>>1;h=f>>2;Pqb(a,d+(h<<1)|0,e);if((h|0)<=0){return}e=g-1|0;a=f-1|0;f=0;i=0;while(1){b[d+(f<<1)>>1]=-(b[d+(e+i<<1)>>1]|0);b[d+(a+i<<1)>>1]=b[d+(f+g<<1)>>1]|0;j=f+1|0;k=~f;if((j|0)<(h|0)){f=j;i=k}else{break}}return}function Rqb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=d;d=1<<c[a+20>>2];k=d>>1;l=d>>2;m=d>>3;n=l*3|0;o=(m|0)>0;if(!o){re[c[a+36>>2]&1023](a,j);return}p=n-1|0;q=l-1|0;r=k-1|0;s=d-1|0;d=0;do{t=d<<1;u=-((b[f+(p-t<<1)>>1]|0)+(b[f+(t+n<<1)>>1]|0)|0)>>1;v=(b[f+(q-t<<1)>>1]|0)-(b[f+(t+l<<1)>>1]|0)>>1;w=e[g+(d<<1)>>1]|0;x=h+(d<<1)|0;y=ca(b[x>>1]|0,-u|0)|0;z=i+(d<<1)|0;b[j+(w<<2)>>1]=(y-(ca(b[z>>1]|0,v)|0)|0)>>>15;y=ca(b[z>>1]|0,u)|0;b[j+(w<<2)+2>>1]=(y-(ca(b[x>>1]|0,v)|0)|0)>>>15;v=(b[f+(t<<1)>>1]|0)-(b[f+(r-t<<1)>>1]|0)>>1;x=-((b[f+(s-t<<1)>>1]|0)+(b[f+(t+k<<1)>>1]|0)|0)>>1;t=d+m|0;y=e[g+(t<<1)>>1]|0;w=h+(t<<1)|0;u=ca(b[w>>1]|0,-v|0)|0;z=i+(t<<1)|0;b[j+(y<<2)>>1]=(u-(ca(b[z>>1]|0,x)|0)|0)>>>15;u=ca(b[z>>1]|0,v)|0;b[j+(y<<2)+2>>1]=(u-(ca(b[w>>1]|0,x)|0)|0)>>>15;d=d+1|0;}while((d|0)<(m|0));re[c[a+36>>2]&1023](a,j);if(o){A=0}else{return}do{o=m-A-1|0;a=j+(o<<2)|0;d=b[a>>1]|0;g=-(b[i+(o<<1)>>1]|0)|0;k=ca(d,g)|0;f=j+(o<<2)+2|0;s=b[f>>1]|0;r=b[h+(o<<1)>>1]|0;o=((ca(r,s)|0)+k|0)>>>15&65535;k=((ca(s,g)|0)-(ca(r,d)|0)|0)>>>15&65535;d=A+m|0;r=j+(d<<2)|0;g=b[r>>1]|0;s=-(b[i+(d<<1)>>1]|0)|0;l=ca(g,s)|0;q=j+(d<<2)+2|0;n=b[q>>1]|0;p=b[h+(d<<1)>>1]|0;d=((ca(p,n)|0)+l|0)>>>15&65535;l=((ca(n,s)|0)-(ca(p,g)|0)|0)>>>15&65535;b[a>>1]=k;b[f>>1]=d;b[r>>1]=l;b[q>>1]=o;A=A+1|0;}while((A|0)<(m|0));return}function Sqb(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=c[a+8>>2]|0;h=c[a+24>>2]|0;i=c[a+28>>2]|0;j=c[a+12>>2]|0;k=d;d=1<<c[a+20>>2];l=d>>1;m=d>>2;n=d>>3;o=m*3|0;p=(n|0)>0;if(!p){re[c[a+36>>2]&1023](a,j);return}q=o-1|0;r=m-1|0;s=l-1|0;t=d-1|0;d=0;do{u=d<<1;v=-((b[f+(q-u<<1)>>1]|0)+(b[f+(u+o<<1)>>1]|0)|0)>>1;w=(b[f+(r-u<<1)>>1]|0)-(b[f+(u+m<<1)>>1]|0)>>1;x=e[g+(d<<1)>>1]|0;y=h+(d<<1)|0;z=ca(b[y>>1]|0,-v|0)|0;A=i+(d<<1)|0;b[j+(x<<2)>>1]=(z-(ca(b[A>>1]|0,w)|0)|0)>>>15;z=ca(b[A>>1]|0,v)|0;b[j+(x<<2)+2>>1]=(z-(ca(b[y>>1]|0,w)|0)|0)>>>15;w=(b[f+(u<<1)>>1]|0)-(b[f+(s-u<<1)>>1]|0)>>1;y=-((b[f+(t-u<<1)>>1]|0)+(b[f+(u+l<<1)>>1]|0)|0)>>1;u=d+n|0;z=e[g+(u<<1)>>1]|0;x=h+(u<<1)|0;v=ca(b[x>>1]|0,-w|0)|0;A=i+(u<<1)|0;b[j+(z<<2)>>1]=(v-(ca(b[A>>1]|0,y)|0)|0)>>>15;v=ca(b[A>>1]|0,w)|0;b[j+(z<<2)+2>>1]=(v-(ca(b[x>>1]|0,y)|0)|0)>>>15;d=d+1|0;}while((d|0)<(n|0));re[c[a+36>>2]&1023](a,j);if(p){B=0}else{return}do{p=n-B-1|0;a=b[j+(p<<2)>>1]|0;d=-(b[i+(p<<1)>>1]|0)|0;g=ca(a,d)|0;l=b[j+(p<<2)+2>>1]|0;f=b[h+(p<<1)>>1]|0;t=(ca(f,l)|0)+g|0;g=(ca(l,d)|0)-(ca(f,a)|0)|0;a=B+n|0;f=b[j+(a<<2)>>1]|0;d=-(b[i+(a<<1)>>1]|0)|0;l=ca(f,d)|0;s=b[j+(a<<2)+2>>1]|0;m=b[h+(a<<1)>>1]|0;r=(ca(m,s)|0)+l|0;l=(ca(s,d)|0)-(ca(m,f)|0)|0;c[k+(p<<3)>>2]=g;c[k+(p<<3)+4>>2]=r;c[k+(a<<3)>>2]=l;c[k+(a<<3)+4>>2]=t;B=B+1|0;}while((B|0)<(n|0));return}function Tqb(){if(a[1634296]|0){return}CGb(9772672,0,8,99,4096)|0;CGb(9780864,0,8,29,4096)|0;CGb(9776768,0,16,45,4096)|0;a[1634296]=1;return}function Uqb(a,b){a=a|0;b=b|0;var c=0,e=0;c=b-2|0;b=EGb(9776768,0,a,c)|0;e=a+c|0;return((d[e]|d[e+1|0]<<8)<<16>>16&65535^b)&65535|0}function Vqb(a,b){a=a|0;b=b|0;var c=0;c=b-1|0;b=EGb(9772672,60,a,c)|0;return((d[a+c|0]|0)^b)&255|0}function Wqb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=e+2|0;e=f>>>3;g=EGb(9780864,c[9780864+((a[b]&63)<<2)>>2]|0,b+1|0,e-2|0)|0;h=(d[b+(e-1)|0]|0)^g;g=f&7;if((g|0)==0){i=h&255;return i|0}f=d[b+e|0]|0;e=0;b=h;do{h=b<<1;b=f>>>((7-e|0)>>>0)&1^((h&256|0)==0?h:h^285);e=e+1|0;}while(e>>>0<g>>>0);i=b&255;return i|0}function Xqb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=a+b|0;if((a&3|0)!=0&(b|0)>0){f=0;g=a;while(1){h=(d[g]|0)^f;i=g+1|0;if((i&3|0)!=0&i>>>0<e>>>0){f=h;g=i}else{j=h;k=i;break}}}else{j=0;k=a}g=a+(b-3)|0;if(k>>>0<g>>>0){b=j;a=k;while(1){f=c[a>>2]^b;i=a+4|0;if(i>>>0<g>>>0){b=f;a=i}else{l=f;m=i;break}}}else{l=j;m=k}k=l>>>16^l;l=k>>>8^k;if(!(m>>>0<e>>>0)){n=l&255;return n|0}k=l&255;l=m;do{k=(d[l]|0)^k;l=l+1|0;}while(l>>>0<e>>>0);n=k&255;return n|0}function Yqb(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return Zqb(a,b,c,d,e,f,g,h)|0}function Zqb(a,b,f,g,h,i,j,k){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;l=c[a+12240>>2]|0;m=c[a+12252>>2]|0;n=m&1;o=n<<1|1;p=c[a+12464>>2]|0;q=c[a+12280>>2]|0;r=c[a+12284>>2]|0;s=c[a+10516+(i<<2)>>2]|0;t=i+1|0;u=c[a+10516+(t<<2)>>2]|0;v=n+1|0;w=b>>v;x=f>>v;y=o&b;z=o&f;do{if((m&4|0)==0){A=m&2;B=c[a+12416>>2]|0;C=c[a+12420>>2]|0;D=(z<<v)+y|0;E=(w<<v)+y|0;F=(x<<v)+z|0;G=a+12352+(h<<4)|0;H=a+12288+(g<<4)|0;if((D|0)==0){I=(c[G>>2]|0)+((ca(B,x)|0)+w)|0;J=Xe[s&511](a,c[H>>2]|0,I,B,j)|0;if((A|0)==0){K=J;break}L=J;M=x<<1&2|w&1}else{do{if((n|0)==0){J=(c[G>>2]|0)+((ca(B,x)|0)+w)|0;mf[c[(c[a+12444>>2]|0)+(i<<4)+(D<<2)>>2]&2047](c[a+12208>>2]|0,J,B,j);if((A|0)==0){N=0;break}N=x<<1&2|w&1|D}else{J=(c[G>>2]|0)+((ca(B,x)|0)+w)|0;ef[c[(c[a+12452>>2]|0)+(i<<6)+(D<<2)>>2]&4095](c[a+12208>>2]|0,J,B);if((A|0)==0){N=0;break}J=(E|0)/2|0;I=(F|0)/2|0;N=(I<<1|I)&2|(J>>>1|J)&1}}while(0);L=Xe[s&511](a,c[a+12208>>2]|0,c[H>>2]|0,B,j)|0;M=N}if((A|0)==0){K=L;break}F=c[a+12208>>2]|0;E=B<<4;D=F+E|0;G=a+12444|0;J=(ca(C,x>>1)|0)+(w>>1)|0;I=j>>1;mf[c[(c[G>>2]|0)+(t<<4)+(M<<2)>>2]&2047](D,(c[a+12352+(h<<4)+4>>2]|0)+J|0,C,I);O=F+(E|8)|0;mf[c[(c[G>>2]|0)+(t<<4)+(M<<2)>>2]&2047](O,(c[a+12352+(h<<4)+8>>2]|0)+J|0,C,I);J=a;G=(Xe[u&511](J,D,c[a+12288+(g<<4)+4>>2]|0,C,I)|0)+L|0;K=G+(Xe[u&511](J,O,c[a+12288+(g<<4)+8>>2]|0,C,I)|0)|0}else{I=c[a+12416>>2]|0;O=(w<<v)+y|0;J=(x<<v)+z|0;G=a+12352+(h<<4)|0;D=a+12288+(g<<4)|0;if((c[a+12264>>2]|0)>(w|0)){K=536870912;break}if((O|0)>(c[a+12268>>2]<<v|0)){K=536870912;break}if((c[a+12272>>2]|0)>(x|0)){K=536870912;break}if((J|0)>(c[a+12276>>2]<<v|0)){K=536870912;break}E=e[a+13872>>1]|0;F=e[a+13874>>1]|0;a:do{if((c[a+11740>>2]|0)==1){P=F-E|0;Q=n|4;R=(J|0)==0;S=a+12208|0;T=I<<3;U=(n|0)==0;V=a+12444|0;W=a+12448|0;X=a+12352+(h<<4)+32|0;Y=a+12452|0;Z=a+12456|0;if((O|0)==0){_=0;while(1){$=c[a+12160+(_<<3)>>2]|0;aa=(c[a+12160+(_<<3)+4>>2]|0)+J|0;ba=((ca(c[a+12128+(_<<3)>>2]|0,P)|0)/(E|0)|0)+((_&1)<<Q)|0;da=c[a+12128+(_<<3)+4>>2]|0;if(R){ea=_>>1;fa=((ca(da,P)|0)/(E|0)|0)+(ea<<Q)|0;ga=ea}else{fa=aa-da|0;ga=_>>1}da=((aa&o)<<v)+($&o)|0;ea=((fa&o)<<v)+(ba&o)|0;ha=(c[S>>2]|0)+((ca(ga,T)|0)+(_<<3&8))|0;if(U){ia=(c[G>>2]|0)+((ca(aa>>1,I)|0)+($>>1))|0;mf[c[(c[V>>2]|0)+16+(da<<2)>>2]&2047](ha,ia,I,8);ia=(c[X>>2]|0)+((ca(fa>>1,I)|0)+(ba>>1))|0;mf[c[(c[W>>2]|0)+16+(ea<<2)>>2]&2047](ha,ia,I,8)}else{ia=(c[G>>2]|0)+((ca(aa>>2,I)|0)+($>>2))|0;ef[c[(c[Y>>2]|0)+64+(da<<2)>>2]&4095](ha,ia,I);ia=(c[X>>2]|0)+((ca(fa>>2,I)|0)+(ba>>2))|0;ef[c[(c[Z>>2]|0)+64+(ea<<2)>>2]&4095](ha,ia,I)}_=_+1|0;if((_|0)>=4){break a}}}if(R){_=0;do{ia=(c[a+12160+(_<<3)>>2]|0)+O|0;ha=c[a+12160+(_<<3)+4>>2]|0;ea=ia-(c[a+12128+(_<<3)>>2]|0)|0;ba=_>>1;da=((ca(c[a+12128+(_<<3)+4>>2]|0,P)|0)/(E|0)|0)+(ba<<Q)|0;$=((ha&o)<<v)+(ia&o)|0;aa=((da&o)<<v)+(ea&o)|0;ja=(c[S>>2]|0)+((_<<3&8)+(ca(ba,T)|0))|0;if(U){ba=(c[G>>2]|0)+((ca(ha>>1,I)|0)+(ia>>1))|0;mf[c[(c[V>>2]|0)+16+($<<2)>>2]&2047](ja,ba,I,8);ba=(c[X>>2]|0)+((ca(da>>1,I)|0)+(ea>>1))|0;mf[c[(c[W>>2]|0)+16+(aa<<2)>>2]&2047](ja,ba,I,8)}else{ba=(c[G>>2]|0)+((ca(ha>>2,I)|0)+(ia>>2))|0;ef[c[(c[Y>>2]|0)+64+($<<2)>>2]&4095](ja,ba,I);ba=(c[X>>2]|0)+((ca(da>>2,I)|0)+(ea>>2))|0;ef[c[(c[Z>>2]|0)+64+(aa<<2)>>2]&4095](ja,ba,I)}_=_+1|0;}while((_|0)<4)}else{_=0;do{Q=(c[a+12160+(_<<3)>>2]|0)+O|0;P=(c[a+12160+(_<<3)+4>>2]|0)+J|0;R=Q-(c[a+12128+(_<<3)>>2]|0)|0;ba=P-(c[a+12128+(_<<3)+4>>2]|0)|0;ja=((P&o)<<v)+(Q&o)|0;aa=((ba&o)<<v)+(R&o)|0;ea=(c[S>>2]|0)+((_<<3&8)+(ca(_>>1,T)|0))|0;if(U){da=(c[G>>2]|0)+((ca(P>>1,I)|0)+(Q>>1))|0;mf[c[(c[V>>2]|0)+16+(ja<<2)>>2]&2047](ea,da,I,8);da=(c[X>>2]|0)+((ca(ba>>1,I)|0)+(R>>1))|0;mf[c[(c[W>>2]|0)+16+(aa<<2)>>2]&2047](ea,da,I,8)}else{da=(c[G>>2]|0)+((ca(P>>2,I)|0)+(Q>>2))|0;ef[c[(c[Y>>2]|0)+64+(ja<<2)>>2]&4095](ea,da,I);da=(c[X>>2]|0)+((ca(ba>>2,I)|0)+(R>>2))|0;ef[c[(c[Z>>2]|0)+64+(aa<<2)>>2]&4095](ea,da,I)}_=_+1|0;}while((_|0)<4)}}else{_=(c[a+12160>>2]|0)+O|0;Z=(c[a+12164>>2]|0)+J|0;X=c[a+12128>>2]|0;if((O|0)==0){ka=(ca(X,F-E|0)|0)/(E|0)|0}else{ka=_-X|0}X=c[a+12132>>2]|0;if((J|0)==0){la=(ca(X,F-E|0)|0)/(E|0)|0}else{la=Z-X|0}X=((Z&o)<<v)+(_&o)|0;Y=((la&o)<<v)+(ka&o)|0;if((n|0)==0){W=a+12208|0;V=(c[G>>2]|0)+((ca(Z>>1,I)|0)+(_>>1))|0;mf[c[(c[a+12444>>2]|0)+(X<<2)>>2]&2047](c[W>>2]|0,V,I,16);V=(c[a+12352+(h<<4)+32>>2]|0)+((ca(la>>1,I)|0)+(ka>>1))|0;mf[c[(c[a+12448>>2]|0)+(Y<<2)>>2]&2047](c[W>>2]|0,V,I,16);break}else{V=a+12452|0;W=a+12208|0;U=(ca(Z>>2,I)|0)+(_>>2)|0;ef[c[(c[V>>2]|0)+64+(X<<2)>>2]&4095](c[W>>2]|0,(c[G>>2]|0)+U|0,I);_=U+8|0;ef[c[(c[V>>2]|0)+64+(X<<2)>>2]&4095]((c[W>>2]|0)+8|0,(c[G>>2]|0)+_|0,I);Z=I<<3;ef[c[(c[V>>2]|0)+64+(X<<2)>>2]&4095]((c[W>>2]|0)+Z|0,(c[G>>2]|0)+(U+Z)|0,I);U=Z+8|0;ef[c[(c[V>>2]|0)+64+(X<<2)>>2]&4095]((c[W>>2]|0)+U|0,(c[G>>2]|0)+(_+Z)|0,I);_=a+12456|0;X=a+12352+(h<<4)+32|0;V=(ca(la>>2,I)|0)+(ka>>2)|0;ef[c[(c[_>>2]|0)+64+(Y<<2)>>2]&4095](c[W>>2]|0,(c[X>>2]|0)+V|0,I);T=V+8|0;ef[c[(c[_>>2]|0)+64+(Y<<2)>>2]&4095]((c[W>>2]|0)+8|0,(c[X>>2]|0)+T|0,I);ef[c[(c[_>>2]|0)+64+(Y<<2)>>2]&4095]((c[W>>2]|0)+Z|0,(c[X>>2]|0)+(V+Z)|0,I);ef[c[(c[_>>2]|0)+64+(Y<<2)>>2]&4095]((c[W>>2]|0)+U|0,(c[X>>2]|0)+(T+Z)|0,I);break}}}while(0);K=Xe[s&511](a,c[a+12208>>2]|0,c[D>>2]|0,I,16)|0}}while(0);if((k|0)==0){ma=K;return ma|0}if(!((f|b|0)!=0|(i|0)>0)){ma=K;return ma|0}ma=(ca((d[p+(f-r)|0]|0)+(d[p+(b-q)|0]|0)|0,l)|0)+K|0;return ma|0}



function PZb(b,e,f,g,j){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=b;b=e;e=f;f=g;g=j;j=0;o=n+105664|0;p=0;q=0;r=0;s=0;t=c[n+114208>>2]|0;u=n+114136|0;v=Erc(t,(t|0)<0|0?-1:0,c[u>>2]|0,c[u+4>>2]|0)|0;u=Crc(v,G,100,0)|0;v=u;u=(v<<1|0)/3|0;t=(v|0)/4|0;w=(v|0)/8|0;OYb();if((c[n+149748>>2]|0)!=0){c[o+2312>>2]=0;c[n+149748>>2]=0}if((c[n+142380>>2]|0)==2){if((c[n+111428>>2]|0)!=0){c[n+131588>>2]=c[n+147456>>2];c[n+142332>>2]=~~(+(c[n+147456>>2]|0)*+h[n+131608>>3])}}else{c[n+131588>>2]=~~(+(c[n+142332>>2]|0)/+h[n+131608>>3])}c[o+5768>>2]=0;c[o+5772>>2]=0;c[n+101540>>2]=0;c[n+101528>>2]=0;c[n+101524>>2]=1;if((c[n+142380>>2]|0)==2){if((c[n+142320>>2]|0)<=400){c[n+101524>>2]=0}}if((c[n+114616>>2]|0)!=0){c[n+111456>>2]=1}else{c[n+111456>>2]=0}do{if((c[o+8036>>2]|0)==0){x=19}else{if((c[o+2320>>2]&1|0)!=0){x=19;break}if((c[n+114100>>2]|0)==0){break}if((((c[n+114736>>2]|0)>>>0)%((c[n+114740>>2]|0)>>>0)|0|0)==0){x=19}}}while(0);if((x|0)==19){c[o+2312>>2]=0}if((c[o+2312>>2]|0)==0){pZb(n);c[n+114616>>2]=0;y=0;while(1){if((y|0)>=20){break}c[n+101280+(y<<2)>>2]=128;y=y+1|0}}c_b(n);if((c[n+131752>>2]|0)!=0){y=n+131688|0;z=c[y+4>>2]|0;A=v;v=(A|0)<0|0?-1:0;do{if((z|0)>(v|0)|(z|0)==(v|0)&(c[y>>2]|0)>>>0>A>>>0){if((c[n+142340>>2]|0)<=0){break}B=n+142340|0;c[B>>2]=(c[B>>2]|0)-1}}while(0);A=n+131688|0;y=c[A+4>>2]|0;v=u;z=(v|0)<0|0?-1:0;do{if((y|0)>(z|0)|(y|0)==(z|0)&(c[A>>2]|0)>>>0>v>>>0){if((c[n+142340>>2]|0)<=0){x=33;break}c[n+142340>>2]=1}else{x=33}}while(0);if((x|0)==33){v=n+131688|0;A=c[v+4>>2]|0;z=w;w=(z|0)<0|0?-1:0;do{if((A|0)<(w|0)|(A|0)==(w|0)&(c[v>>2]|0)>>>0<z>>>0){if((c[n+142340>>2]|0)!=2){if((c[n+142340>>2]|0)!=3){x=37;break}}c[n+142340>>2]=3}else{x=37}}while(0);if((x|0)==37){z=n+131688|0;v=c[z+4>>2]|0;w=t;t=(w|0)<0|0?-1:0;do{if((v|0)<(t|0)|(v|0)==(t|0)&(c[z>>2]|0)>>>0<w>>>0){if((c[n+142340>>2]|0)!=1){if((c[n+142340>>2]|0)!=2){x=41;break}}c[n+142340>>2]=2}else{x=41}}while(0);if((x|0)==41){w=n+131688|0;z=c[w+4>>2]|0;t=u;u=(t|0)<0|0?-1:0;do{if((z|0)<(u|0)|(z|0)==(u|0)&(c[w>>2]|0)>>>0<t>>>0){if((c[n+142340>>2]|0)!=0){if((c[n+142340>>2]|0)!=1){break}}c[n+142340>>2]=1}}while(0)}}}}if((c[n+142340>>2]|0)>0){t=c[n+142340>>2]|0;if((t|0)==1){c[n+131588>>2]=((c[n+131588>>2]|0)*3|0|0)/2|0}else if((t|0)==2){c[n+131588>>2]=((c[n+131588>>2]|0)*5|0|0)/4|0}else if((t|0)==3){c[n+131588>>2]=((c[n+131588>>2]|0)*5|0|0)/4|0}do{if((c[o+2312>>2]|0)==0){c[n+142344>>2]=c[n+142340>>2]}else{if((c[n+142344>>2]|0)<=0){c[n+142344>>2]=c[n+142340>>2];break}t=n+142344|0;c[t>>2]=(c[t>>2]|0)-1;t=c[n+131592>>2]|0;w=n+131696|0;u=wrc(c[w>>2]|0,c[w+4>>2]|0,t,(t|0)<0|0?-1:0)|0;c[w>>2]=u;c[w+4>>2]=G;w=n+131696|0;u=c[w+4>>2]|0;t=n+114144|0;z=c[t+4>>2]|0;if((u|0)>(z|0)|(u|0)==(z|0)&(c[w>>2]|0)>>>0>(c[t>>2]|0)>>>0){t=n+114144|0;w=c[t+4>>2]|0;z=n+131696|0;c[z>>2]=c[t>>2];c[z+4>>2]=w}w=o+8036|0;c[w>>2]=(c[w>>2]|0)+1;w=n+114736|0;c[w>>2]=(c[w>>2]|0)+1;w=n+142656|0;c[w>>2]=(c[w>>2]|0)+1;w=n+131696|0;z=c[w+4>>2]|0;t=n+131688|0;c[t>>2]=c[w>>2];c[t+4>>2]=z;if((c[n+114288>>2]|0)>>>0>1>>>0){z=(c[n+150216>>2]|0)+1|0;while(1){if(!(z>>>0<(c[n+114288>>2]|0)>>>0)){break}t=n+150224+(z*200|0)|0;w=~~(+(c[t+8>>2]|0)/+h[t>>3]);u=t+80|0;v=wrc(c[u>>2]|0,c[u+4>>2]|0,w,(w|0)<0|0?-1:0)|0;c[u>>2]=v;c[u+4>>2]=G;u=t+80|0;v=c[u+4>>2]|0;w=t+32|0;A=c[w+4>>2]|0;if((v|0)>(A|0)|(v|0)==(A|0)&(c[u>>2]|0)>>>0>(c[w>>2]|0)>>>0){w=t+32|0;u=c[w+4>>2]|0;A=t+80|0;c[A>>2]=c[w>>2];c[A+4>>2]=u}u=t+80|0;A=c[u+4>>2]|0;w=t+72|0;c[w>>2]=c[u>>2];c[w+4>>2]=A;z=z+1|0}}i=k;return}}while(0)}else{c[n+142344>>2]=0}if((g$b(n)|0)==0){z=o+8036|0;c[z>>2]=(c[z>>2]|0)+1;z=n+114736|0;c[z>>2]=(c[z>>2]|0)+1;z=n+142656|0;c[z>>2]=(c[z>>2]|0)+1;i=k;return}do{if((c[n+114116>>2]|0)==1){z=n+131688|0;A=c[z+4>>2]|0;w=n+114136|0;u=c[w+4>>2]|0;if(!((A|0)>=(u|0)&((A|0)>(u|0)|(c[z>>2]|0)>>>0>=(c[w>>2]|0)>>>0))){break}if((c[n+131664>>2]|0)==0){break}w=(c[n+131736>>2]|0)/4|0;if((w|0)!=0){z=n+131688|0;u=c[z+4>>2]|0;A=n+114144|0;t=c[A+4>>2]|0;if((u|0)<(t|0)|(u|0)==(t|0)&(c[z>>2]|0)>>>0<(c[A>>2]|0)>>>0){A=n+114144|0;z=n+114136|0;t=xrc(c[A>>2]|0,c[A+4>>2]|0,c[z>>2]|0,c[z+4>>2]|0)|0;z=w;A=Crc(t,G,z,(z|0)<0|0?-1:0)|0;z=A;if((z|0)!=0){A=n+131688|0;t=n+114136|0;u=xrc(c[A>>2]|0,c[A+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;t=z;z=Crc(u,G,t,(t|0)<0|0?-1:0)|0;w=z}else{w=0}}z=n+131736|0;c[z>>2]=(c[z>>2]|0)-w;if((c[n+131736>>2]|0)<(c[n+131744>>2]|0)){c[n+131736>>2]=c[n+131744>>2]}}}}while(0);do{if((c[n+142380>>2]|0)==2){x=89}else{if((c[n+131648>>2]|0)>150){x=89;break}if((c[n+114116>>2]|0)==2){do{if((c[o+2312>>2]|0)==0){x=145}else{if((c[o+5760>>2]|0)!=0){x=145;break}if((c[n+111428>>2]|0)!=0){x=145;break}if((c[n+131744>>2]|0)<(c[n+131748>>2]|0)){c[n+131744>>2]=c[n+131748>>2]}}}while(0);if((x|0)==145){c[n+131744>>2]=c[n+131740>>2]}}}}while(0);if((x|0)==89){OYb();C=c[n+131736>>2]|0;if((c[o+2312>>2]|0)==0){if((c[n+142380>>2]|0)==2){if((c[n+142320>>2]|0)>600){c[n+131744>>2]=d[1034784+C|0]|0}else{c[n+131744>>2]=d[1034920+C|0]|0}if((c[n+114744>>2]|0)!=0){if((c[n+131744>>2]|0)>(((c[n+131652>>2]|0)*7|0|0)/8|0|0)){c[n+131744>>2]=((c[n+131652>>2]|0)*7|0|0)/8|0}else{if((c[n+131744>>2]|0)<(c[n+131652>>2]>>2|0)){c[n+131744>>2]=c[n+131652>>2]>>2}}}}else{c[n+131744>>2]=d[1034920+C|0]|0}}else{do{if((c[n+114288>>2]|0)==1){if((c[o+5760>>2]|0)==0){if((c[n+111428>>2]|0)==0){x=125;break}}do{if((c[n+114736>>2]|0)>>>0>1>>>0){if((c[n+131652>>2]|0)>=(c[n+131736>>2]|0)){break}C=c[n+131652>>2]|0}}while(0);do{if((c[n+114116>>2]|0)==2){if((C|0)>=(c[n+131748>>2]|0)){break}C=c[n+131748>>2]|0}}while(0);if((c[n+142380>>2]|0)==2){if((c[n+142320>>2]|0)>1e3){c[n+131744>>2]=d[1147936+C|0]|0}else{if((c[n+142320>>2]|0)<400){c[n+131744>>2]=d[1148560+C|0]|0}else{c[n+131744>>2]=d[1147808+C|0]|0}}if((c[n+114116>>2]|0)==2){c[n+131744>>2]=((c[n+131744>>2]|0)*15|0|0)/16|0}}else{c[n+131744>>2]=d[1148560+C|0]|0}}else{x=125}}while(0);if((x|0)==125){c[n+131744>>2]=d[1068664+C|0]|0;do{if((c[n+114116>>2]|0)==2){if((c[n+131744>>2]|0)>=(c[n+131748>>2]|0)){break}if((c[n+131708>>2]|0)<(c[n+131596>>2]|0)){c[n+131744>>2]=c[n+114188>>2]}else{c[n+131744>>2]=c[n+131748>>2]}}}while(0)}}if((c[n+114116>>2]|0)==1){w=n+131688|0;z=c[w+4>>2]|0;t=n+114144|0;u=c[t+4>>2]|0;if((z|0)>=(u|0)&((z|0)>(u|0)|(c[w>>2]|0)>>>0>=(c[t>>2]|0)>>>0)){c[n+131744>>2]=c[n+131740>>2]}else{t=n+131688|0;w=c[t+4>>2]|0;u=n+114136|0;z=c[u+4>>2]|0;if((w|0)>(z|0)|(w|0)==(z|0)&(c[t>>2]|0)>>>0>(c[u>>2]|0)>>>0){u=n+131688|0;t=n+114136|0;z=xrc(c[u>>2]|0,c[u+4>>2]|0,c[t>>2]|0,c[t+4>>2]|0)|0;t=Erc(z,G,128,0)|0;z=G;u=n+114144|0;w=n+114136|0;A=xrc(c[u>>2]|0,c[u+4>>2]|0,c[w>>2]|0,c[w+4>>2]|0)|0;w=Crc(t,z,A,G)|0;A=(ca((c[n+131744>>2]|0)-(c[n+131740>>2]|0)|0,w)|0)/128|0;w=n+131744|0;c[w>>2]=(c[w>>2]|0)-A}}}}if((c[n+131736>>2]|0)>(c[n+131732>>2]|0)){c[n+131736>>2]=c[n+131732>>2]}if((c[n+131744>>2]|0)<(c[n+131740>>2]|0)){c[n+131744>>2]=c[n+131740>>2]}if((c[n+131736>>2]|0)<(c[n+131744>>2]|0)){c[n+131736>>2]=c[n+131744>>2]}C=c$b(n,c[n+131480>>2]|0)|0;if((c[o+2312>>2]|0)==0){D=0}else{do{if((c[n+114288>>2]|0)==1){if((c[o+5764>>2]|0)==0){if((c[o+5760>>2]|0)==0){x=164;break}if((c[n+114616>>2]|0)!=0){x=164;break}}D=16}else{x=164}}while(0);if((x|0)==164){D=192}}if((c[n+142636>>2]|0)!=0){if((c[n+150216>>2]|0)==0){d_b(n,C,0)}else{VZb(n)}}f$b(n,m,l);A=c[n+131744>>2]|0;w=c[n+131736>>2]|0;z=c[n+131744>>2]|0;t=c[n+131736>>2]|0;__b(n);u=0;e_b(c[n+114508>>2]|0,n);do{OYb();Z_b(n,C);if((c[n+108004>>2]|0)!=0){c[n+142396>>2]=c[n+143e3+(C<<2)>>2];if((c[o+2312>>2]|0)!=0){if((c[n+111428>>2]|0)!=0){if((c[n+142408>>2]|0)!=0){c[n+142396>>2]=c[n+142408>>2]}}else{if((c[n+111424>>2]|0)!=0){if((c[n+142404>>2]|0)!=0){c[n+142396>>2]=c[n+142404>>2]}}else{if((c[n+142400>>2]|0)!=0){c[n+142396>>2]=c[n+142400>>2]}}}if((c[n+142396>>2]|0)<5){c[n+142396>>2]=5}if((c[n+142396>>2]|0)>250){c[n+142396>>2]=250}do{if((c[n+114288>>2]|0)==1){if((c[n+114620>>2]|0)==0){break}c[n+142396>>2]=1}}while(0)}}if((c[o+2312>>2]|0)==0){if((f_b(n)|0)!=0){C=c$b(n,c[n+131480>>2]|0)|0;if((c[n+142636>>2]|0)!=0){if((c[n+150216>>2]|0)==0){d_b(n,C,0)}else{VZb(n)}}Z_b(n,C)}a$b(n)}Kbc(n);v=Qac(n)|0;y=n+131484|0;c[y>>2]=(c[y>>2]|0)-v;if((c[n+131484>>2]|0)>0){E=c[n+131484>>2]|0}else{E=0}c[n+131484>>2]=E;OYb();do{if((c[n+142380>>2]|0)!=2){if((c[n+114100>>2]|0)==0){x=214;break}if((c[o+2312>>2]|0)==0){x=214;break}if((c[n+142360>>2]|0)==2){x=214;break}if((g_b(n)|0)!=0){c[o+2312>>2]=0;g$b(n)|0;c[n+114616>>2]=0;pZb(n);$_b(n);C=c$b(n,c[n+131480>>2]|0)|0;f$b(n,m,l);A=c[n+131744>>2]|0;w=c[n+131736>>2]|0;z=c[n+131744>>2]|0;t=c[n+131736>>2]|0;u=u+1|0;j=1;break}else{x=214;break}}else{x=214}}while(0);if((x|0)==214){x=0;OYb();if((c[l>>2]|0)==0){c[l>>2]=1}if((c[n+142380>>2]|0)!=2){x=218}else{if((c[n+114116>>2]|0)==1){x=218}else{x=227}}do{if((x|0)==218){x=0;if((C|0)!=(c[n+131736>>2]|0)){x=227;break}if((c[n+131736>>2]|0)>=(c[n+131732>>2]|0)){x=227;break}if((c[n+131484>>2]|0)<=(c[l>>2]|0)){x=227;break}v=(((c[n+131484>>2]|0)-(c[l>>2]|0)|0)*100|0|0)/(c[l>>2]|0)|0;while(1){if((c[n+131736>>2]|0)<(c[n+131732>>2]|0)){F=(v|0)>0}else{F=0}if(!F){break}y=n+131736|0;c[y>>2]=(c[y>>2]|0)+1;v=~~(+(v|0)*.96)}w=c[n+131736>>2]|0;p=1}}while(0);if((x|0)==227){x=0;p=0}do{if((c[o+2312>>2]|0)==0){if((c[n+114744>>2]|0)==0){x=247;break}v=C;y=$Zb(c[n+114504>>2]|0,o+1816+((c[o+2200>>2]|0)*92|0)|0)|0;if((y|0)>(((c[n+114752>>2]|0)*7|0)>>3|0)){if((C|0)>(z|0)){H=C-1|0}else{H=z}t=H;C=t+z>>1}else{if((y|0)<(c[n+114752>>2]>>1|0)){if((C|0)<(t|0)){I=C+1|0}else{I=t}z=I;C=t+z+1>>1}}if((C|0)>(t|0)){C=t}else{if((C|0)<(z|0)){C=z}}j=(C|0)!=(v|0)|0}else{x=247}}while(0);if((x|0)==247){x=0;if((h_b(n,c[l>>2]|0,c[m>>2]|0,C,w,A)|0)!=0){v=C;y=0;if((c[n+131484>>2]|0)>(c[n+131480>>2]|0)){if((C|0)<(t|0)){J=C+1|0}else{J=t}z=J;if((c[n+101540>>2]|0)>0){if((c[n+101540>>2]|0)<(D|0)){K=(c[n+101540>>2]|0)+1|0}else{K=D}q=K}if((s|0)!=0){if((p|0)==0){b$b(n,1)}C=(t+z+1|0)/2|0;if((C|0)<127){c[n+101540>>2]=0}else{if((c[n+101540>>2]|0)<(D|0)){L=(c[n+101540>>2]|0)+1|0}else{L=D}q=L;c[n+101540>>2]=(D+q|0)/2|0}}else{if((p|0)==0){b$b(n,0)}C=c$b(n,c[n+131480>>2]|0)|0;while(1){if((C|0)<(z|0)){x=272}else{if((c[n+101540>>2]|0)<(q|0)){x=272}else{M=0}}if((x|0)==272){x=0;M=(y|0)<10}if(!M){break}b$b(n,0);C=c$b(n,c[n+131480>>2]|0)|0;y=y+1|0}}r=1}else{if((c[n+101540>>2]|0)==0){if((C|0)>(z|0)){N=C-1|0}else{N=z}t=N}else{if((c[n+101540>>2]|0)>(q|0)){O=(c[n+101540>>2]|0)-1|0}else{O=q}D=O}if((r|0)!=0){if((p|0)==0){b$b(n,1)}C=(t+z|0)/2|0;if((C|0)<127){c[n+101540>>2]=0}else{c[n+101540>>2]=(D+q|0)/2|0}}else{if((p|0)==0){b$b(n,0)}C=c$b(n,c[n+131480>>2]|0)|0;do{if((c[n+114116>>2]|0)==2){if((C|0)>=(z|0)){break}z=C}}while(0);while(1){if((C|0)>(t|0)){x=301}else{if((c[n+101540>>2]|0)>(D|0)){x=301}else{P=0}}if((x|0)==301){x=0;P=(y|0)<10}if(!P){break}b$b(n,0);C=c$b(n,c[n+131480>>2]|0)|0;y=y+1|0}}s=1}if((C|0)>(t|0)){C=t}else{if((C|0)<(z|0)){C=z}}if((c[n+101540>>2]|0)<(q|0)){Q=q}else{if((c[n+101540>>2]|0)>(D|0)){R=D}else{R=c[n+101540>>2]|0}Q=R}c[n+101540>>2]=Q;j=(C|0)!=(v|0)|0}else{j=0}}if((c[n+114620>>2]|0)!=0){j=0}if((j|0)==1){$_b(n);u=u+1|0}}}while((j|0)==1);do{if((c[n+114748>>2]|0)!=0){if((c[n+147400>>2]|0)!=0){break}c[n+114752>>2]=$Zb(c[n+114504>>2]|0,o+1816+((c[o+2200>>2]|0)*92|0)|0)|0}}while(0);if((c[o+2316>>2]|0)!=0){j=c[o+2380>>2]|0;if((c[o+2312>>2]|0)!=0){u=0;while(1){if((u|0)>=((c[o+2328>>2]|0)+1|0)){break}Q=0;while(1){if((Q|0)>=((c[o+2332>>2]|0)+1|0)){break}if((d[j+2|0]|0|0)!=0){R=Q+(ca(u,(c[o+2336>>2]|0)+1|0)|0)|0;c[(c[n+149736>>2]|0)+(R<<2)>>2]=c[j+4>>2]}R=Q+(ca(u,(c[o+2336>>2]|0)+1|0)|0)|0;c[(c[n+149740>>2]|0)+(R<<2)>>2]=c[o+5780+((d[j+2|0]|0)<<2)>>2];R=Q+(ca(u,(c[o+2336>>2]|0)+1|0)|0)|0;c[(c[n+149744>>2]|0)+(R<<2)>>2]=d[j+2|0]|0;j=j+76|0;Q=Q+1|0}u=u+1|0}}}u=c[o+2384>>2]|0;c[n+142592>>2]=0;if((c[o+2312>>2]|0)!=0){j=0;while(1){if((j|0)>=(c[o+2328>>2]|0)){break}Q=0;while(1){if((Q|0)>=(c[o+2332>>2]|0)){break}if((d[u|0]|0|0)==7){v=n+142592|0;c[v>>2]=(c[v>>2]|0)+1}u=u+76|0;Q=Q+1|0}u=u+76|0;j=j+1|0}}if((c[n+114288>>2]|0)==1){h0b(n,o,n+73728|0)}if((c[o+2312>>2]|0)==0){c[o+5756>>2]=1}do{if((c[n+114256>>2]|0)!=0){x=362}else{if((c[o+5760>>2]|0)==0){x=362;break}c[o+5772>>2]=2}}while(0);if((x|0)==362){c[o+5772>>2]=0}c[o+1812>>2]=o+1816+((c[o+2200>>2]|0)*92|0);FZb(n,o);i_b(n);if((c[n+114256>>2]|0)!=0){c[o+5776>>2]=0}Wac(n,e,f,b);c[o+2308>>2]=c[o+2312>>2];f=n+131656|0;e=wrc(c[f>>2]|0,c[f+4>>2]|0,c[b>>2]|0,0)|0;c[f>>2]=e;c[f+4>>2]=G;c[n+131484>>2]=c[b>>2]<<3;if((c[n+114288>>2]|0)>>>0>1>>>0){f=(c[n+150216>>2]|0)+1|0;while(1){if(!(f>>>0<(c[n+114288>>2]|0)>>>0)){break}e=n+150224+(f*200|0)+168|0;j=wrc(c[e>>2]|0,c[e+4>>2]|0,c[b>>2]|0,0)|0;c[e>>2]=j;c[e+4>>2]=G;f=f+1|0}}if((p|0)==0){b$b(n,2)}c[n+131488+(c[o+2312>>2]<<2)>>2]=c[o+2356>>2];if((c[o+2312>>2]|0)==0){d$b(n)}if((c[o+2312>>2]|0)!=0){c[n+131652>>2]=((c[n+131652>>2]|0)*3|0)+2+(c[o+2356>>2]|0)>>2}do{if((c[o+2312>>2]|0)!=0){if(!((c[n+114288>>2]|0)>>>0>1>>>0)){if((c[o+5760>>2]|0)!=0){break}if((c[o+5764>>2]|0)!=0){break}}p=n+131648|0;c[p>>2]=(c[p>>2]|0)+1;if((c[n+142380>>2]|0)==2){p=n+131644|0;c[p>>2]=(c[p>>2]|0)+C;c[n+131640>>2]=(c[n+131644>>2]|0)/(c[n+131648>>2]|0)|0}else{if((c[n+131648>>2]|0)>150){p=n+131644|0;c[p>>2]=(c[p>>2]|0)+C;c[n+131640>>2]=(c[n+131644>>2]|0)/(c[n+131648>>2]|0)|0}else{p=n+131644|0;c[p>>2]=(c[p>>2]|0)+C;c[n+131640>>2]=(((c[n+131644>>2]|0)/(c[n+131648>>2]|0)|0)+(c[n+131732>>2]|0)+1|0)/2|0}if((C|0)>(c[n+131640>>2]|0)){c[n+131640>>2]=C-1}}}}while(0);if((c[o+2316>>2]|0)!=0){C=(c[n+131592>>2]|0)-(c[n+131484>>2]|0)|0;p=n+131696|0;f=wrc(c[p>>2]|0,c[p+4>>2]|0,C,(C|0)<0|0?-1:0)|0;c[p>>2]=f;c[p+4>>2]=G}else{p=c[n+131484>>2]|0;f=n+131696|0;C=xrc(c[f>>2]|0,c[f+4>>2]|0,p,(p|0)<0|0?-1:0)|0;c[f>>2]=C;c[f+4>>2]=G}f=n+131696|0;C=c[f+4>>2]|0;p=n+114144|0;b=c[p+4>>2]|0;if((C|0)>(b|0)|(C|0)==(b|0)&(c[f>>2]|0)>>>0>(c[p>>2]|0)>>>0){p=n+114144|0;f=c[p+4>>2]|0;b=n+131696|0;c[b>>2]=c[p>>2];c[b+4>>2]=f}c[n+131704>>2]=(((c[n+131704>>2]|0)*3|0)+(c[n+131480>>2]|0)+2|0)/4|0;c[n+131708>>2]=(((c[n+131708>>2]|0)*3|0)+(c[n+131484>>2]|0)+2|0)/4|0;c[n+131712>>2]=(((c[n+131712>>2]|0)*31|0)+(c[n+131480>>2]|0)+16|0)/32|0;c[n+131716>>2]=(((c[n+131716>>2]|0)*31|0)+(c[n+131484>>2]|0)+16|0)/32|0;f=c[n+131484>>2]|0;b=n+131720|0;p=wrc(c[b>>2]|0,c[b+4>>2]|0,f,(f|0)<0|0?-1:0)|0;c[b>>2]=p;c[b+4>>2]=G;b=n+131728|0;c[b>>2]=(c[b>>2]|0)+((c[n+131480>>2]|0)-(c[n+131484>>2]|0));b=n+131696|0;p=c[b+4>>2]|0;f=n+131688|0;c[f>>2]=c[b>>2];c[f+4>>2]=p;if((c[n+114288>>2]|0)>>>0>1>>>0){p=(c[n+150216>>2]|0)+1|0;while(1){if(!(p>>>0<(c[n+114288>>2]|0)>>>0)){break}f=n+150224+(p*200|0)|0;b=~~(+(c[f+8>>2]|0)/+h[f>>3]- +(c[n+131484>>2]|0));C=b;e=f+80|0;j=wrc(c[e>>2]|0,c[e+4>>2]|0,C,(C|0)<0|0?-1:0)|0;c[e>>2]=j;c[e+4>>2]=G;e=f+80|0;j=c[e+4>>2]|0;C=f+32|0;u=c[C+4>>2]|0;if((j|0)>(u|0)|(j|0)==(u|0)&(c[e>>2]|0)>>>0>(c[C>>2]|0)>>>0){C=f+32|0;e=c[C+4>>2]|0;u=f+80|0;c[u>>2]=c[C>>2];c[u+4>>2]=e}e=c[n+131484>>2]|0;u=f+88|0;C=wrc(c[u>>2]|0,c[u+4>>2]|0,e,(e|0)<0|0?-1:0)|0;c[u>>2]=C;c[u+4>>2]=G;u=f+96|0;c[u>>2]=(c[u>>2]|0)+b;b=f+80|0;u=c[b+4>>2]|0;C=f+72|0;c[C>>2]=c[b>>2];c[C+4>>2]=u;p=p+1|0}}if((c[o+2312>>2]|0)==0){p=(c[n+131480>>2]|0)-(c[n+131484>>2]|0)|0;u=n+147432|0;C=wrc(c[u>>2]|0,c[u+4>>2]|0,p,(p|0)<0|0?-1:0)|0;c[u>>2]=C;c[u+4>>2]=G;u=n+147432|0;C=c[u+4>>2]|0;p=0;if((C|0)<(p|0)|(C|0)==(p|0)&(c[u>>2]|0)>>>0<0>>>0){u=n+147432|0;c[u>>2]=0;c[u+4>>2]=0}}else{if((c[o+5760>>2]|0)!=0){x=409}else{if((c[o+5764>>2]|0)!=0){x=409}}if((x|0)==409){u=(c[n+131480>>2]|0)-(c[n+131484>>2]|0)|0;p=n+147448|0;C=wrc(c[p>>2]|0,c[p+4>>2]|0,u,(u|0)<0|0?-1:0)|0;c[p>>2]=C;c[p+4>>2]=G;p=n+147448|0;C=c[p+4>>2]|0;u=0;if((C|0)<(u|0)|(C|0)==(u|0)&(c[p>>2]|0)>>>0<0>>>0){p=n+147448|0;c[p>>2]=0;c[p+4>>2]=0}}}if((c[o+2312>>2]|0)!=0){if((c[n+111428>>2]|0)!=0){c[n+142408>>2]=c[n+142396>>2];c[n+142420>>2]=c[o+2356>>2]}else{if((c[n+111424>>2]|0)!=0){c[n+142404>>2]=c[n+142396>>2];c[n+142416>>2]=c[o+2356>>2]}else{c[n+142400>>2]=c[n+142396>>2];c[n+142412>>2]=c[o+2356>>2];c[n+143e3+(c[o+2356>>2]<<2)>>2]=c[n+142396>>2]}}}if((c[o+5760>>2]|0)==1){c[o+2320>>2]=c[o+2320>>2]|2}else{c[o+2320>>2]=c[o+2320>>2]&-3}if((c[o+5764>>2]|0)==1){c[o+2320>>2]=c[o+2320>>2]|4}else{c[o+2320>>2]=c[o+2320>>2]&-5}if((c[o+5756>>2]&c[o+5760>>2]|0)!=0){c[n+114624>>2]=1}else{if((c[o+5756>>2]^c[o+5760>>2]|0)!=0){c[n+114624>>2]=0}}if((c[o+5756>>2]&c[o+5764>>2]|0)!=0){c[n+114628>>2]=1}else{if((c[o+5756>>2]^c[o+5764>>2]|0)!=0){c[n+114628>>2]=0}}if((c[o+5764>>2]&c[o+5760>>2]|0)!=0){c[n+114632>>2]=1}else{if((c[o+5764>>2]^c[o+5760>>2]|0)!=0){c[n+114632>>2]=0}}c[n+142448>>2]=7;if((c[n+114624>>2]|0)!=0){p=n+142448|0;c[p>>2]=c[p>>2]&-3}if((c[n+114628>>2]|0)!=0){p=n+142448|0;c[p>>2]=c[p>>2]&-5}if((c[n+114632>>2]|0)!=0){p=n+142448|0;c[p>>2]=c[p>>2]&-5}if((c[n+114256>>2]|0)==0){do{if((c[n+114224>>2]|0)!=0){if((c[o+5764>>2]|0)==0){x=453;break}if((c[o+2312>>2]|0)==0){x=453;break}j_b(n)}else{x=453}}while(0);if((x|0)==453){k_b(n)}}if((c[o+2312>>2]|0)==0){c[g>>2]=c[o+2320>>2]|1;c[o+2312>>2]=1;c[n+142444>>2]=100}else{c[g>>2]=c[o+2320>>2]&-2;c[n+142444>>2]=c[n+142440>>2]}a[n+79973|0]=0;a[n+79974|0]=0;a[n+79988|0]=0;if((c[o+2316>>2]|0)==0){i=k;return}g=o+8036|0;c[g>>2]=(c[g>>2]|0)+1;g=n+114736|0;c[g>>2]=(c[g>>2]|0)+1;g=n+142656|0;c[g>>2]=(c[g>>2]|0)+1;i=k;return}function QZb(a){a=a|0;var b=0,e=0,f=0,g=0;b=i;e=a;a=e+105664|0;f=e+76880|0;do{if((c[a+2312>>2]|0)==0){g=1}else{if((c[a+5756>>2]|0)!=0){g=1;break}if((c[a+5760>>2]|0)!=0){g=1;break}if((c[a+5764>>2]|0)!=0){g=1;break}if((c[a+5768>>2]|0)!=0){g=1;break}if((c[a+5772>>2]|0)!=0){g=1;break}if((c[a+5776>>2]|0)!=0){g=1;break}if((d[f+3108|0]|0|0)!=0){g=1;break}if((d[f+3093|0]|0|0)!=0){g=1;break}g=(d[f+3094|0]|0|0)!=0}}while(0);i=b;return g&1|0}function RZb(a){a=a|0;var b=0,d=0,e=0,f=0;b=a;a=b+150224+((c[b+150216>>2]|0)*200|0)|0;c[a+8>>2]=c[b+142332>>2];d=b+114128|0;e=c[d+4>>2]|0;f=a+16|0;c[f>>2]=c[d>>2];c[f+4>>2]=e;e=b+114136|0;f=c[e+4>>2]|0;d=a+24|0;c[d>>2]=c[e>>2];c[d+4>>2]=f;f=b+114144|0;d=c[f+4>>2]|0;e=a+32|0;c[e>>2]=c[f>>2];c[e+4>>2]=d;d=b+114152|0;e=c[d+4>>2]|0;f=a+40|0;c[f>>2]=c[d>>2];c[f+4>>2]=e;e=b+114160|0;f=c[e+4>>2]|0;d=a+48|0;c[d>>2]=c[e>>2];c[d+4>>2]=f;f=b+114168|0;d=c[f+4>>2]|0;e=a+56|0;c[e>>2]=c[f>>2];c[e+4>>2]=d;d=b+131688|0;e=c[d+4>>2]|0;f=a+72|0;c[f>>2]=c[d>>2];c[f+4>>2]=e;e=b+131696|0;f=c[e+4>>2]|0;d=a+80|0;c[d>>2]=c[e>>2];c[d+4>>2]=f;f=b+131720|0;d=c[f+4>>2]|0;e=a+88|0;c[e>>2]=c[f>>2];c[e+4>>2]=d;c[a+100>>2]=c[b+131732>>2];c[a+104>>2]=c[b+131736>>2];c[a+108>>2]=c[b+131740>>2];c[a+112>>2]=c[b+131744>>2];c[a+116>>2]=c[b+131640>>2];c[a+120>>2]=c[b+131644>>2];c[a+124>>2]=c[b+131648>>2];c[a+128>>2]=c[b+131652>>2];h[a+136>>3]=+h[b+131496>>3];h[a+144>>3]=+h[b+131504>>3];h[a+152>>3]=+h[b+131512>>3];c[a+160>>2]=c[b+101540>>2];c[a+164>>2]=c[b+131600>>2];d=b+131656|0;e=c[d+4>>2]|0;f=a+168|0;c[f>>2]=c[d>>2];c[f+4>>2]=e;c[a+176>>2]=c[b+111408>>2];c[a+180>>2]=c[b+142444>>2];e=a+184|0;a=b+101264|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];i=i;return}function SZb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;i=i+144|0;d=b|0;e=b+136|0;f=a;a=c[f+114504>>2]|0;g=c[f+107476>>2]|0;j=c[f+107456>>2]|0;k=c[f+107460>>2]|0;c[d>>2]=2;l=b_b(c[a+52>>2]|0,c[a+16>>2]|0,c[g+52>>2]|0,c[g+16>>2]|0,j,k)|0;c[e>>2]=l;c[e+4>>2]=G;l=c[e+4>>2]|0;m=d+24|0;c[m>>2]=c[e>>2];c[m+4>>2]=l;l=c[e+4>>2]|0;m=d+32|0;c[m>>2]=c[e>>2];c[m+4>>2]=l;c[d+8>>2]=ca(j,k)|0;c[d+12>>2]=ca(j,k)|0;j=((j+1|0)>>>0)/2|0;k=((k+1|0)>>>0)/2|0;l=b_b(c[a+56>>2]|0,c[a+36>>2]|0,c[g+56>>2]|0,c[g+36>>2]|0,j,k)|0;c[e>>2]=l;c[e+4>>2]=G;l=d+24|0;m=wrc(c[l>>2]|0,c[l+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;c[l>>2]=m;c[l+4>>2]=G;l=c[e+4>>2]|0;m=d+40|0;c[m>>2]=c[e>>2];c[m+4>>2]=l;l=ca(j,k)|0;m=d+8|0;c[m>>2]=(c[m>>2]|0)+l;c[d+16>>2]=ca(j,k)|0;l=b_b(c[a+60>>2]|0,c[a+36>>2]|0,c[g+60>>2]|0,c[g+36>>2]|0,j,k)|0;c[e>>2]=l;c[e+4>>2]=G;l=d+24|0;g=wrc(c[l>>2]|0,c[l+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;c[l>>2]=g;c[l+4>>2]=G;l=c[e+4>>2]|0;g=d+48|0;c[g>>2]=c[e>>2];c[g+4>>2]=l;l=ca(j,k)|0;g=d+8|0;c[g>>2]=(c[g>>2]|0)+l;c[d+20>>2]=ca(j,k)|0;k=0;while(1){if((k|0)>=4){break}j=d+24+(k<<3)|0;h[d+56+(k<<3)>>3]=+B7b(+((c[d+8+(k<<2)>>2]|0)>>>0>>>0),255.0,+((c[j>>2]|0)>>>0)+ +((c[j+4>>2]|0)>>>0)*4294967296.0);k=k+1|0}qYb(c[f+142336>>2]|0,d)|0;i=b;return}function TZb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;d=i;e=a;a=b;if((c[e+111428>>2]|0)!=0){f=-1;g=f;i=d;return g|0}if((c[e+107476>>2]|0)!=0){nrc(a|0,c[e+107476>>2]|0,92)|0;c[a>>2]=c[e+107456>>2];c[a+4>>2]=c[e+107460>>2];c[a+24>>2]=(c[e+107460>>2]|0)/2|0;h=0}else{h=-1}OYb();f=h;g=f;i=d;return g|0}function UZb(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;i=i+24|0;l=k|0;m=k+8|0;n=b;b=d;d=g;g=h;h=j;if((c[n+142636>>2]|0)!=0){o=-1;p=o;i=k;return p|0}do{if((c[n+107992>>2]|0)==(e|0)){if((c[n+107996>>2]|0)!=(f|0)){break}do{if((R(c[d>>2]|0)|0)<=63){if((R(c[d+4>>2]|0)|0)>63){break}if((R(c[d+8>>2]|0)|0)>63){break}if((R(c[d+12>>2]|0)|0)>63){break}do{if((R(c[g>>2]|0)|0)<=63){if((R(c[g+4>>2]|0)|0)>63){break}if((R(c[g+8>>2]|0)|0)>63){break}if((R(c[g+12>>2]|0)|0)>63){break}if((b|0)==0){VZb(n);o=0;p=o;i=k;return p|0}j=0;while(1){if((j|0)>=4){break}if((c[d+(j<<2)>>2]|0)>=0){q=c[695984+(c[d+(j<<2)>>2]<<2)>>2]|0}else{q=-(c[695984+(-(c[d+(j<<2)>>2]|0)<<2)>>2]|0)|0}c[m+(j<<2)>>2]=q;j=j+1|0}WZb(n,b);XZb(n);a[l|0]=c[m>>2];a[l+1|0]=c[m+4>>2];a[l+2|0]=c[m+8>>2];a[l+3|0]=c[m+12>>2];a[l+4|0]=c[g>>2];a[l+5|0]=c[g+4>>2];a[l+6|0]=c[g+8>>2];a[l+7|0]=c[g+12>>2];c[n+142612>>2]=c[h>>2];c[n+142616>>2]=c[h+4>>2];c[n+142620>>2]=c[h+8>>2];c[n+142624>>2]=c[h+12>>2];YZb(n,l|0,0);o=0;p=o;i=k;return p|0}}while(0);o=-1;p=o;i=k;return p|0}}while(0);o=-1;p=o;i=k;return p|0}}while(0);o=-1;p=o;i=k;return p|0}function VZb(b){b=b|0;a[b+79972|0]=0;i=i;return}function WZb(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b;nrc(c[f+142600>>2]|0,d|0,ca(c[f+107992>>2]|0,c[f+107996>>2]|0)|0)|0;a[f+79973|0]=1;a[f+79974|0]=1;i=e;return}function XZb(b){b=b|0;var c=0;c=b;a[c+79972|0]=1;a[c+79973|0]=1;a[c+79974|0]=1;i=i;return}function YZb(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=b;a[f+79975|0]=d;nrc(f+142604|0,c|0,8)|0;i=e;return}function ZZb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;b=d;d=e;do{if((b|0)==(c[g+107992>>2]|0)){if((d|0)!=(c[g+107996>>2]|0)){break}if((a|0)!=0){nrc(c[g+142628>>2]|0,a|0,ca(b,d)|0)|0;c[g+142632>>2]=1}else{c[g+142632>>2]=0}h=0;j=h;i=f;return j|0}}while(0);h=-1;j=h;i=f;return j|0}function _Zb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=b;b=d;do{if(a>>>0<=3>>>0){c[f+107464>>2]=a;if(!(b>>>0<=3>>>0)){g=-1;break}c[f+107468>>2]=b;g=0}else{g=-1}}while(0);i=e;return g|0}function $Zb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=a;a=b;b=0;g=c[f+52>>2]|0;h=c[a+52>>2]|0;j=0;while(1){if((j|0)>=(c[f+4>>2]|0)){break}k=0;while(1){if((k|0)>=(c[f>>2]|0)){break}b=b+(H9b(g+k|0,c[f+16>>2]|0,h+k|0,c[a+16>>2]|0,e)|0)|0;k=k+16|0}g=g+(c[f+16>>2]<<4)|0;h=h+(c[a+16>>2]<<4)|0;j=j+16|0}i=d;return b|0}function a_b(a){a=a|0;i=i;return c[a+108020>>2]|0}function b_b(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=a;a=b;b=e;e=f;f=g;g=h;c[k>>2]=0;c[k+4>>2]=0;h=0;while(1){if(!((h+16|0)>>>0<=g>>>0)){break}n=0;while(1){if(!((n+16|0)>>>0<=f>>>0)){break}H9b(m+n|0,a,b+n|0,e,l)|0;o=wrc(c[k>>2]|0,c[k+4>>2]|0,c[l>>2]|0,0)|0;c[k>>2]=o;c[k+4>>2]=G;n=n+16|0}if(n>>>0<f>>>0){o=m;p=b;q=0;while(1){if(!(q>>>0<16>>>0)){break}r=n;while(1){if(!(r>>>0<f>>>0)){break}s=(d[o+r|0]|0)-(d[p+r|0]|0)|0;t=ca(s,s)|0;u=wrc(c[k>>2]|0,c[k+4>>2]|0,t,(t|0)<0|0?-1:0)|0;c[k>>2]=u;c[k+4>>2]=G;r=r+1|0}o=o+a|0;p=p+e|0;q=q+1|0}}m=m+(a<<4)|0;b=b+(e<<4)|0;h=h+16|0}while(1){if(!(h>>>0<g>>>0)){break}n=0;while(1){if(!(n>>>0<f>>>0)){break}s=(d[m+n|0]|0)-(d[b+n|0]|0)|0;l=ca(s,s)|0;q=wrc(c[k>>2]|0,c[k+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[k>>2]=q;c[k+4>>2]=G;n=n+1|0}m=m+a|0;b=b+e|0;h=h+1|0}OYb();i=j;return(G=c[k+4>>2]|0,c[k>>2]|0)|0}function c_b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;a=d+101264|0;e=c[a>>2]|0;f=(c[a+4>>2]|0)+(c[a+8>>2]|0)+(c[a+12>>2]|0)|0;if((c[d+107976>>2]|0)==0){c[d+142384>>2]=255;c[d+142388>>2]=128;c[d+142392>>2]=128}else{if((e+f|0)==0){c[d+142384>>2]=63;c[d+142388>>2]=128;c[d+142392>>2]=128}}if((c[d+114288>>2]|0)!=1){i=b;return}if((c[d+111428>>2]|0)!=0){f=d+142384|0;c[f>>2]=(c[f>>2]|0)+40;if((c[d+142384>>2]|0)>255){c[d+142384>>2]=255}c[d+142388>>2]=200;c[d+142392>>2]=1}else{if((c[d+131520>>2]|0)==0){c[d+142388>>2]=214}else{if((c[d+131520>>2]|0)==1){c[d+142388>>2]=192;c[d+142392>>2]=220}else{if((c[d+114616>>2]|0)!=0){f=d+142392|0;c[f>>2]=(c[f>>2]|0)-20;if((c[d+142392>>2]|0)<10){c[d+142392>>2]=10}}}}}if((c[d+114616>>2]|0)==0){c[d+142392>>2]=255}i=b;return}function d_b(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+8|0;g=f|0;h=b;b=d;d=e;e=c[h+142600>>2]|0;j=c[h+142640>>2]|0;k=ca(c[h+107992>>2]|0,c[h+107996>>2]|0)|0;c[h+142648>>2]=(b|0)/2|0;mrc(c[h+142600>>2]|0,0,k|0)|0;if((c[h+107976>>2]|0)!=0){l=c[h+142644>>2]|0;if((l|0)<(k|0)){}else{Cd(2438016,2511648,588,2653104)}do{if((a[(c[h+142652>>2]|0)+l|0]|0)==0){a[e+l|0]=1;j=j-1|0}else{if((a[(c[h+142652>>2]|0)+l|0]|0)<0){m=(c[h+142652>>2]|0)+l|0;a[m]=(a[m]|0)+1}}l=l+1|0;if((l|0)==(k|0)){l=0}if((j|0)!=0){n=(l|0)!=(c[h+142644>>2]|0)}else{n=0}}while(n);c[h+142644>>2]=l}a[h+79973|0]=1;a[h+79974|0]=1;XZb(h);a[g|0]=0;a[g+1|0]=(c[h+142648>>2]|0)-b;a[g+2|0]=0;a[g+3|0]=0;a[g+4|0]=0;a[g+5|0]=d;a[g+6|0]=0;a[g+7|0]=0;YZb(h,g|0,0);i=f;return}function e_b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=a;a=b;b=a+105664|0;do{if((c[b+1800>>2]|0)==0){if((c[b+1804>>2]|0)!=0){break}c[a+114504>>2]=j;i=d;return}}while(0);c[e>>2]=c[e>>2];c[f>>2]=c[f>>2];c[g>>2]=c[g>>2];c[h>>2]=c[h>>2];if((c[b+1804>>2]|0)==3){k=9}else{k=11}sZb(c[b+1800>>2]|0,e,f);sZb(c[b+1804>>2]|0,g,h);C7b(j,a+114512|0,c[b+2268>>2]|0,k&255,c[f>>2]|0,c[e>>2]|0,c[h>>2]|0,c[g>>2]|0,0);N7b(a+114512|0);c[a+114504>>2]=a+114512;i=d;return}function f_b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;h=a;a=h+105664|0;a:do{if((c[h+114192>>2]|0)!=0){if((c[h+114116>>2]|0)!=1){break}c[d>>2]=c[d>>2];c[e>>2]=c[e>>2];c[f>>2]=c[f>>2];c[g>>2]=c[g>>2];j=h+131688|0;k=c[j>>2]|0;l=c[j+4>>2]|0;j=c[h+114196>>2]|0;m=h+114136|0;n=Erc(j,(j|0)<0|0?-1:0,c[m>>2]|0,c[m+4>>2]|0)|0;m=Crc(n,G,100,0)|0;n=G;if((l|0)<(n|0)|(l|0)==(n|0)&k>>>0<m>>>0){if((c[a+1800>>2]|0)<3){o=(c[a+1800>>2]|0)+1|0}else{o=3}c[a+1800>>2]=o;if((c[a+1804>>2]|0)<3){p=(c[a+1804>>2]|0)+1|0}else{p=3}c[a+1804>>2]=p}else{m=h+131688|0;k=c[m>>2]|0;n=c[m+4>>2]|0;m=c[h+114200>>2]|0;l=h+114136|0;j=Erc(m,(m|0)<0|0?-1:0,c[l>>2]|0,c[l+4>>2]|0)|0;l=Crc(j,G,100,0)|0;j=G;if((n|0)>(j|0)|(n|0)==(j|0)&k>>>0>l>>>0){if((c[a+1800>>2]|0)>0){q=(c[a+1800>>2]|0)-1|0}else{q=0}c[a+1800>>2]=q;if((c[a+1804>>2]|0)>0){r=(c[a+1804>>2]|0)-1|0}else{r=0}c[a+1804>>2]=r}}sZb(c[a+1800>>2]|0,d,e);sZb(c[a+1804>>2]|0,f,g);l=(c[e>>2]|0)-1+(ca(c[h+114060>>2]|0,c[d>>2]|0)|0)|0;k=(l|0)/(c[e>>2]|0)|0;l=(c[g>>2]|0)-1+(ca(c[h+114064>>2]|0,c[f>>2]|0)|0)|0;j=(l|0)/(c[g>>2]|0)|0;do{if((c[a+1792>>2]|0)==(k|0)){if((c[a+1796>>2]|0)!=(j|0)){break}break a}}while(0);c[a+1792>>2]=k;c[a+1796>>2]=j;jZb(h);e_b(c[h+114508>>2]|0,h);s=1;t=s;i=b;return t|0}}while(0);s=0;t=s;i=b;return t|0}function g_b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0;b=i;d=a;a=d+105664|0;e=0;c[d+142324>>2]=0;if((c[d+142356>>2]|0)>11){f=0;g=f;i=b;return g|0}OYb();do{if((c[d+142360>>2]|0)==2){if((c[d+142356>>2]|0)<5){break}if((c[d+142452>>2]|0)!=0){break}h=d+101256|0;j=d+131472|0;k=xrc(c[h>>2]|0,c[h+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;l=+(R(k|0)|0)*1.0;k=d+131472|0;j=wrc(1,0,c[k>>2]|0,c[k+4>>2]|0)|0;m=l/(+(j>>>0)+ +(G|0)*4294967296.0);j=d+101248|0;k=d+131464|0;h=xrc(c[j>>2]|0,c[j+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;l=+(R(h|0)|0)*1.0;h=d+131464|0;k=wrc(1,0,c[h>>2]|0,c[h+4>>2]|0)|0;n=l/(+(k>>>0)+ +(G|0)*4294967296.0);l=+(c[a+2324>>2]<<8|0);k=d+101256|0;h=c[k+4>>2]|0;j=d+131472|0;c[j>>2]=c[k>>2];c[j+4>>2]=h;h=d+101248|0;j=c[h+4>>2]|0;k=d+131464|0;c[k>>2]=c[h>>2];c[k+4>>2]=j;j=d+101256|0;k=Erc(10,0,c[j>>2]|0,c[j+4>>2]|0)|0;j=G;h=d+101248|0;o=wrc(1,0,c[h>>2]|0,c[h+4>>2]|0)|0;h=Crc(k,j,o,G)|0;o=G;j=0;do{if((o|0)<(j|0)|(o|0)==(j|0)&h>>>0<15>>>0){k=d+101248|0;if(!(+((c[k>>2]|0)>>>0)+ +(c[k+4>>2]|0)*4294967296.0>l)){break}if(!(m>.25)){if(!(n>.25)){break}}f=1;g=f;i=b;return g|0}}while(0);f=0;g=f;i=b;return g|0}}while(0);if((c[d+142440>>2]|0)==100){if((c[d+142440>>2]|0)>((c[d+142444>>2]|0)+2|0)){p=16}else{p=14}}else{p=14}do{if((p|0)==14){if((c[d+142440>>2]|0)>95){if((c[d+142440>>2]|0)>=((c[d+142444>>2]|0)+5|0)){p=16;break}}if((c[d+142440>>2]|0)>60){if((c[d+142440>>2]|0)>(c[d+142444>>2]<<1|0)){p=23}else{p=19}}else{p=19}do{if((p|0)==19){if((c[d+142440>>2]|0)>75){if((c[d+142440>>2]|0)>(((c[d+142444>>2]|0)*3|0|0)/2|0|0)){p=23;break}}if((c[d+142440>>2]|0)<=90){break}if((c[d+142440>>2]|0)>((c[d+142444>>2]|0)+10|0)){p=23}}}while(0);if((p|0)==23){if((c[a+5760>>2]|0)==0){e=1}}}}while(0);if((p|0)==16){e=1}f=e;g=f;i=b;return g|0}function h_b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=a;a=b;b=d;d=e;e=f;f=g;g=0;k=j+105664|0;do{if((c[j+142472>>2]|0)!=1){if((c[j+142472>>2]|0)!=2){l=g;i=h;return l|0}if((c[k+2312>>2]|0)==0){break}if((c[k+5760>>2]|0)!=0){break}if((c[k+5764>>2]|0)!=0){break}l=g;i=h;return l|0}}while(0);if((c[j+131484>>2]|0)>(a|0)){if((d|0)<(e|0)){m=10}else{m=8}}else{m=8}do{if((m|0)==8){if((c[j+131484>>2]|0)<(b|0)){if((d|0)>(f|0)){m=10;break}}if((c[j+114116>>2]|0)==2){do{if((d|0)>(c[j+131748>>2]|0)){if((c[j+131484>>2]|0)>=(((c[j+131480>>2]|0)*7|0)>>3|0)){m=15;break}g=1}else{m=15}}while(0);if((m|0)==15){do{if((d|0)>(c[j+114188>>2]|0)){if((c[j+131484>>2]|0)>=(c[j+131596>>2]|0)){break}if((c[j+131744>>2]|0)<=(c[j+114188>>2]|0)){break}g=1;c[j+131744>>2]=c[j+114188>>2]}}while(0)}}}}while(0);if((m|0)==10){g=1}l=g;i=h;return l|0}function i_b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=d+105664|0;e=a+1816|0;if((c[a+2312>>2]|0)==0){f=e+((c[a+2200>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]|6;f=e+((c[a+2208>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-3;f=e+((c[a+2212>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-5;f=c[a+2200>>2]|0;c[a+2208>>2]=f;c[a+2212>>2]=f}else{if((c[a+5764>>2]|0)!=0){if((c[a+5772>>2]|0)!=0){Cd(2474448,2511648,3117,2651072)}else{}f=a+1816+((c[a+2200>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]|4;f=a+1816+((c[a+2212>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-5;c[a+2212>>2]=c[a+2200>>2]}else{if((c[a+5772>>2]|0)!=0){if((c[a+5772>>2]&-4|0)!=0){Cd(2465776,2511648,3129,2651072)}else{}if((c[a+5772>>2]|0)==1){if((c[a+2212>>2]|0)!=(c[a+2204>>2]|0)){f=e+((c[a+2204>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]|4;f=e+((c[a+2212>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-5;c[a+2212>>2]=c[a+2204>>2]}}else{if((c[a+2212>>2]|0)!=(c[a+2208>>2]|0)){f=e+((c[a+2208>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]|4;f=e+((c[a+2212>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-5;c[a+2212>>2]=c[a+2208>>2]}}}}if((c[a+5760>>2]|0)!=0){if((c[a+5768>>2]|0)!=0){Cd(2455128,2511648,3163,2651072)}else{}f=a+1816+((c[a+2200>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]|2;f=a+1816+((c[a+2208>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-3;c[a+2208>>2]=c[a+2200>>2]}else{if((c[a+5768>>2]|0)!=0){if((c[a+5772>>2]&-4|0)!=0){Cd(2465776,2511648,3175,2651072)}else{}if((c[a+5768>>2]|0)==1){if((c[a+2208>>2]|0)!=(c[a+2204>>2]|0)){f=e+((c[a+2204>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]|2;f=e+((c[a+2208>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-3;c[a+2208>>2]=c[a+2204>>2]}}else{if((c[a+2212>>2]|0)!=(c[a+2208>>2]|0)){f=e+((c[a+2212>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]|2;f=e+((c[a+2208>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-3;c[a+2208>>2]=c[a+2212>>2]}}}}}if((c[a+5756>>2]|0)!=0){f=a+1816+((c[a+2200>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]|1;f=a+1816+((c[a+2204>>2]|0)*92|0)+88|0;c[f>>2]=c[f>>2]&-2;c[a+2204>>2]=c[a+2200>>2]}if((c[d+114080>>2]|0)==0){i=b;return}if((c[a+2312>>2]|0)==0){S7b(c[d+114504>>2]|0,d+149848|0);N7b(d+149848|0);f=2;while(1){if((f|0)>=3){break}S7b(d+149848|0,d+149756+(f*92|0)|0);f=f+1|0}}else{N7b(d+149756|0);if((c[a+5764>>2]|0)!=0){g=47}else{if((c[a+5772>>2]|0)!=0){g=47}}if((g|0)==47){S7b(d+149756|0,d+150032|0)}if((c[a+5760>>2]|0)!=0){g=50}else{if((c[a+5768>>2]|0)!=0){g=50}}if((g|0)==50){S7b(d+149756|0,d+149940|0)}if((c[a+5756>>2]|0)!=0){S7b(d+149756|0,d+149848|0)}}i=b;return}function j_b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=d+105664|0;if((c[d+142364>>2]|0)==0){c[d+131524>>2]=7}do{if((c[d+142380>>2]|0)!=2){if((c[d+131524>>2]|0)==0){break}c[d+131528>>2]=c[d+131524>>2];e=d+131532|0;c[e>>2]=(c[e>>2]|0)+(c[d+131484>>2]|0);c[d+131536>>2]=(c[d+131532>>2]|0)/(c[d+131524>>2]|0)|0}}while(0);mrc(c[d+149724>>2]|0,1,ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0)|0;c[d+149728>>2]=ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0;c[d+131520>>2]=0;c[d+114612>>2]=0;c[d+114616>>2]=1;i=b;return}function k_b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=d+105664|0;if((c[a+5760>>2]|0)==0){if((c[d+111428>>2]|0)==0){if((c[d+131524>>2]|0)>0){e=d+131524|0;c[e>>2]=(c[e>>2]|0)-1}if((c[d+114608>>2]|0)!=0){e=d+114608|0;c[e>>2]=(c[e>>2]|0)-1}e=d+131520|0;c[e>>2]=(c[e>>2]|0)+1;if((c[d+131520>>2]|0)>>>0>1>>>0){e=d+142424|0;c[e>>2]=(c[e>>2]|0)+(c[d+101264>>2]|0);e=d+142428|0;c[e>>2]=(c[e>>2]|0)+(c[d+101268>>2]|0);e=d+142432|0;c[e>>2]=(c[e>>2]|0)+(c[d+101272>>2]|0);e=d+142436|0;c[e>>2]=(c[e>>2]|0)+(c[d+101276>>2]|0)}}i=b;return}if((c[d+142364>>2]|0)==0){c[d+131524>>2]=7}do{if((c[d+142380>>2]|0)!=2){if((c[d+131524>>2]|0)<=0){break}c[d+131528>>2]=c[d+131524>>2];do{if((c[a+2312>>2]|0)!=0){if((c[d+114616>>2]|0)!=0){break}e=d+131532|0;c[e>>2]=(c[e>>2]|0)+((c[d+131484>>2]|0)-(c[d+131600>>2]|0))}}while(0);c[d+131536>>2]=(c[d+131532>>2]|0)/(c[d+131524>>2]|0)|0}}while(0);mrc(c[d+149724>>2]|0,1,ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0)|0;c[d+149728>>2]=ca(c[a+2328>>2]|0,c[a+2332>>2]|0)|0;c[a+5760>>2]=0;c[d+131520>>2]=0;c[d+142424>>2]=1;c[d+142428>>2]=1;c[d+142432>>2]=1;c[d+142436>>2]=1;do{if((c[d+114176>>2]|0)>=0){if((c[d+114224>>2]|0)==0){break}if((c[d+111428>>2]|0)!=0){break}c[d+114612>>2]=1;c[d+131524>>2]=c[d+131552>>2]}}while(0);if((c[d+114612>>2]|0)==0){c[d+114616>>2]=0}if((c[d+131524>>2]|0)>0){a=d+131524|0;c[a>>2]=(c[a>>2]|0)-1}i=b;return}function l_b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=+e;var f=0,g=0,j=0,k=0,l=0;f=i;g=a;a=b;b=d;d=g+150224+(b*200|0)|0;h[d>>3]=+h[g+131608>>3]/+((c[g+114356+(b<<2)>>2]|0)>>>0>>>0);c[d+8>>2]=(c[g+114292+(b<<2)>>2]|0)*1e3|0;j=a+72|0;k=c[j+4>>2]|0;l=d+40|0;c[l>>2]=c[j>>2];c[l+4>>2]=k;k=a+80|0;l=c[k+4>>2]|0;j=d+48|0;c[j>>2]=c[k>>2];c[j+4>>2]=l;l=a+88|0;j=c[l+4>>2]|0;k=d+56|0;c[k>>2]=c[l>>2];c[k+4>>2]=j;j=qZb(c[a+72>>2]|0,c[d+8>>2]|0,1e3)|0;k=d+16|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0;j=a+80|0;if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){j=(c[d+8>>2]|0)/8|0;k=d+24|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0}else{j=qZb(c[a+80>>2]|0,c[d+8>>2]|0,1e3)|0;k=d+24|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0}j=a+88|0;if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){j=(c[d+8>>2]|0)/8|0;k=d+32|0;c[k>>2]=j;c[k+4>>2]=(j|0)<0|0?-1:0}else{j=qZb(c[a+88>>2]|0,c[d+8>>2]|0,1e3)|0;a=d+32|0;c[a>>2]=j;c[a+4>>2]=(j|0)<0|0?-1:0}if((b|0)>0){c[d+64>>2]=~~(+((((c[g+114292+(b<<2)>>2]|0)-(c[g+114292+(b-1<<2)>>2]|0)|0)*1e3|0)>>>0>>>0)/(+h[d>>3]-e))}c[d+104>>2]=c[g+114180>>2];c[d+112>>2]=c[g+114184>>2];c[d+128>>2]=c[g+114180>>2];g=d+16|0;b=c[g+4>>2]|0;j=d+72|0;c[j>>2]=c[g>>2];c[j+4>>2]=b;b=d+16|0;j=c[b+4>>2]|0;g=d+80|0;c[g>>2]=c[b>>2];c[g+4>>2]=j;j=d+88|0;c[j>>2]=0;c[j+4>>2]=0;c[d+116>>2]=0;c[d+120>>2]=0;c[d+124>>2]=0;h[d+136>>3]=1.0;h[d+144>>3]=1.0;h[d+152>>3]=1.0;c[d+164>>2]=0;i=f;return}function m_b(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=b;a[e+79987|0]=1;a[e+79988|0]=1;mrc(e+79993|0,0,4)|0;mrc(e+80001|0,0,4)|0;a[e+79993|0]=2;a[e+79994|0]=0;a[e+79995|0]=-2;a[e+79996|0]=-2;a[e+80001|0]=4;if((c[e+114096>>2]|0)==0){a[e+80002|0]=-12;f=e;g=f+73728|0;h=g+3152|0;j=h+3121|0;k=j+2|0;a[k]=2;l=e;m=l+73728|0;n=m+3152|0;o=n+3121|0;p=o+3|0;a[p]=4;i=d;return}else{a[e+80002|0]=-2;f=e;g=f+73728|0;h=g+3152|0;j=h+3121|0;k=j+2|0;a[k]=2;l=e;m=l+73728|0;n=m+3152|0;o=n+3121|0;p=o+3|0;a[p]=4;i=d;return}}function n_b(a,c,d,e,f,g,h,j,k,l){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;l=e;e=l|0;b[e>>1]=b[e>>1]<<3;e=l+2|0;b[e>>1]=b[e>>1]<<3;i=i;return 0}function o_b(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;h=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[h>>2];h=a;a=d;d=e;e=h+1860|0;j=(c[c[e+36>>2]>>2]|0)+(c[e+40>>2]|0)|0;k=c[e+44>>2]|0;e=c[h+6016>>2]|0;l=(c[h+6052>>2]|0)+(c[h+5312>>2]|0)|0;h=e;m=b[f+2>>1]&7;n=b[f>>1]&7;o=ca(b[f>>1]>>3,e)|0;l=l+(o+(b[f+2>>1]>>3))|0;if((m|n|0)!=0){p=me[c[a+8>>2]&255](l,h,m,n,j,k,d)|0;q=p;i=g;return q|0}else{p=Xe[c[a+4>>2]&511](j,k,l,h,d)|0;q=p;i=g;return q|0}return 0}function p_b(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=b;b=c;c=e;e=0;h=0;while(1){if((h|0)>=4){break}j=0;while(1){if((j|0)>=4){break}k=(d[g+j|0]|0)-(d[b+j|0]|0)|0;e=e+(ca(k,k)|0)|0;j=j+1|0}g=g+a|0;b=b+c|0;h=h+1|0}i=f;return e|0}function q_b(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;n=i;i=i+288|0;m=n|0;o=n+16|0;p=n+24|0;q=n+104|0;r=n+112|0;s=n+120|0;t=n+136|0;u=n+144|0;v=n+152|0;w=n+160|0;x=n+168|0;y=n+176|0;z=n+208|0;A=n+216|0;B=n+264|0;C=n+280|0;D=e;e=f;f=g;g=h;h=j;j=k;k=l;l=e+1860|0;E=e+5296|0;F=e+3152|0;G=2147483647;c[t>>2]=100;H=2147483647;I=2147483647;J=0;c[w>>2]=2147483647;K=2147483647;L=2147483647;M=2147483647;N=c[D+142588>>2]|0;nrc(y|0,240792,32)|0;O=0;c[z>>2]=0;P=0;Q=p+(P*40|0)|0;c[q>>2]=0;mrc(p|0,0,80)|0;mrc(m|0,0,12)|0;r_b(D,B|0);if((c[B+4>>2]|0)>0){P=_7b(e+3152|0,c[e+6184>>2]|0,p|0,o|0,s|0,c[B+4>>2]|0,D+111444|0)|0;Q=p+(P*40|0)|0;c[q>>2]=c[o+(P<<2)>>2]}s_b(D,A|0,f,g);R=e+27712|0;c[R>>2]=(c[R>>2]|0)+1;c[k>>2]=2147483647;c[e+6448>>2]=0;a[(c[e+6184>>2]|0)+2|0]=0;t_b(D,e,t);R=0;a:while(1){if((R|0)>=20){break}S=2147483647;T=c[B+(c[238640+(R<<2)>>2]<<2)>>2]|0;b:do{if((G|0)>(c[e+27632+(R<<2)>>2]|0)){if((T|0)<0){break}a[(c[e+6184>>2]|0)+2|0]=T;if((a[(c[e+6184>>2]|0)+2|0]|0)!=0){c[e+6052>>2]=c[A+(T*12|0)>>2];c[e+6056>>2]=c[A+(T*12|0)+4>>2];c[e+6060>>2]=c[A+(T*12|0)+8>>2];if((P|0)!=(c[D+111444+(T<<2)>>2]|0)){P=c[D+111444+(T<<2)>>2]|0;Q=p+(P*40|0)|0;c[q>>2]=c[o+(P<<2)>>2]}}do{if((c[e+27716+(R<<2)>>2]|0)!=0){if(!((c[D+114756+(R<<2)>>2]|0)>>>0>1>>>0)){break}if(!((c[e+27712>>2]|0)>>>0<=(ca(c[D+114756+(R<<2)>>2]|0,c[e+27716+(R<<2)>>2]|0)|0)>>>0)){break}U=e+27552+(R<<2)|0;c[U>>2]=(c[U>>2]|0)+4;if((c[e+27552+(R<<2)>>2]|0)>512){c[e+27552+(R<<2)>>2]=512}c[e+27632+(R<<2)>>2]=ca(c[D+114836+(R<<2)>>2]>>7,c[e+27552+(R<<2)>>2]|0)|0;break b}}while(0);U=e+27716+(R<<2)|0;c[U>>2]=(c[U>>2]|0)+1;V=0;c[v>>2]=0;U=c[242592+(R<<2)>>2]|0;a[c[e+6184>>2]|0]=U;a[(c[e+6184>>2]|0)+1|0]=0;V=V+(c[e+6332+(d[(c[e+6184>>2]|0)+2|0]<<2)>>2]|0)|0;c:do{if((c[D+114620>>2]|0)!=0){if((c[D+114260>>2]|0)!=0){break}do{if((U|0)==7){if((d[(c[e+6184>>2]|0)+2|0]|0)!=3){break}break c}}while(0);break b}}while(0);switch(U|0){case 9:{break};case 8:{W=0;X=c[e+6364>>2]|0;Y=((b[q+2>>1]|0)+7>>3)-255|0;Z=((b[q>>1]|0)+7>>3)-255|0;_=(b[q+2>>1]>>3)+255|0;$=(b[q>>1]>>3)+255|0;aa=c[e+6432>>2]|0;ba=c[e+6436>>2]|0;da=c[e+6440>>2]|0;ea=c[e+6444>>2]|0;if((c[D+142356>>2]|0)>5){fa=(c[D+142356>>2]|0)>=8?3:2}else{fa=1}ga=fa;ha=(c[D+142572>>2]|0)+ga|0;if((N|0)!=0){if((O|0)==0){A$b(D,F,e,f,y|0);O=1}w$b(D,e+3152|0,c[e+6184>>2]|0,x,d[(c[e+6184>>2]|0)+2|0]|0,D+111444|0,z,y|0);c[z>>2]=(c[z>>2]|0)+ga;if((c[z>>2]|0)>(ha|0)){ha=c[z>>2]|0}b[C+2>>1]=b[x+2>>1]>>3;b[C>>1]=b[x>>1]>>3}else{c[x>>2]=c[q>>2];b[C+2>>1]=b[q+2>>1]>>3;b[C>>1]=b[q>>1]>>3}if((c[e+6432>>2]|0)<(Y|0)){c[e+6432>>2]=Y}if((c[e+6436>>2]|0)>(_|0)){c[e+6436>>2]=_}if((c[e+6440>>2]|0)<(Z|0)){c[e+6440>>2]=Z}if((c[e+6444>>2]|0)>($|0)){c[e+6444>>2]=$}if((c[D+142356>>2]|0)>=8){ia=0}else{ia=(c[D+142568>>2]|0)-1-ha|0}$=ia;if((c[D+142456>>2]|0)==2){I=Ldc(e,l,E,C,E+24|0,ha,X,D+142932|0,e+6404|0,e+6396|0,q)|0;c[Q+32>>2]=c[E+24>>2]}else{I=Be[c[D+142784>>2]&7](e,l,E,C,E+24|0,ha,X,r,D+142932|0,e+6396|0,q)|0;c[Q+32>>2]=c[E+24>>2];W=c[r>>2]|0;c[r>>2]=0;while(1){if((W|0)>=($|0)){break}W=W+1|0;if((c[r>>2]|0)!=0){c[r>>2]=(c[r>>2]|0)-1}else{Z=Be[c[D+142784>>2]&7](e,l,E,C,E+24|0,ha+W|0,X,r,D+142932|0,e+6396|0,q)|0;if((Z|0)<(I|0)){I=Z;c[Q+32>>2]=c[E+24>>2]}else{c[E+24>>2]=c[Q+32>>2]}}}}c[e+6432>>2]=aa;c[e+6436>>2]=ba;c[e+6440>>2]=da;c[e+6444>>2]=ea;if((I|0)<2147483647){Ne[c[D+142772>>2]&15](e,l,E,E+24|0,q,c[e+6360>>2]|0,D+142932|0,D+80124|0,v,w)|0}c[Q+32>>2]=c[E+24>>2];V=V+(Edc(Q+32|0,q,D+80124|0,128)|0)|0;ja=73;break};case 7:{ja=76;break};case 5:case 6:{ja=73;break};case 0:case 1:case 2:case 3:{c9b(F,(c[F+2992>>2]|0)+(-(c[F+2956>>2]|0)|0)|0,(c[F+2992>>2]|0)-1|0,c[F+2956>>2]|0,F|0,16);c[v>>2]=B9b(c[c[l+36>>2]>>2]|0,c[l+44>>2]|0,e+3152|0,16,w)|0;V=V+(c[(c[e+6412>>2]|0)+((c[e+6192>>2]|0)*40|0)+(d[c[e+6184>>2]|0]<<2)>>2]|0)|0;X=(ca(V,c[e+6376>>2]|0)|0)+128>>8;S=X+(ca(c[e+6372>>2]|0,c[v>>2]|0)|0)|0;if((S|0)<(H|0)){H=S;c[k>>2]=c[v>>2]}break};case 4:{c[v>>2]=K;u_b(e,u,v)|0;if((c[v>>2]|0)==2147483647){S=2147483647}else{V=V+(c[u>>2]|0)|0;c[v>>2]=B9b(c[c[l+36>>2]>>2]|0,c[l+44>>2]|0,e+3152|0,16,w)|0;X=(ca(V,c[e+6376>>2]|0)|0)+128>>8;S=X+(ca(c[e+6372>>2]|0,c[v>>2]|0)|0)|0;if((S|0)<(H|0)){H=S;c[k>>2]=c[v>>2]}}break};default:{}}do{if((ja|0)==73){ja=0;if((c[Q+(U<<2)>>2]|0)==0){break b}else{ja=76;break}}}while(0);d:do{if((ja|0)==76){ja=0;do{if((b[Q+(U<<2)>>1]>>3|0)>=(c[e+6440>>2]|0)){if((b[Q+(U<<2)>>1]>>3|0)>(c[e+6444>>2]|0)){break}if((b[Q+(U<<2)+2>>1]>>3|0)<(c[e+6432>>2]|0)){break}if((b[Q+(U<<2)+2>>1]>>3|0)>(c[e+6436>>2]|0)){break}V=V+(t$b(U,s|0)|0)|0;c[(c[e+6184>>2]|0)+4>>2]=c[Q+(U<<2)>>2];S=v_b(w,V,v,D,e,c[t>>2]|0)|0;break d}}while(0);break b}}while(0);if((c[D+114080>>2]|0)!=0){do{if((U|0)==7){if(!((c[w>>2]|0)>>>0<L>>>0)){break}L=c[w>>2]|0;c[e+6488>>2]=d[(c[e+6184>>2]|0)+2|0]|0}}while(0);do{if((d[c[e+6184>>2]|0]|0)==8){if(!((c[w>>2]|0)>>>0<M>>>0)){break}M=c[w>>2]|0;c[e+6476>>2]=8;c[e+6480>>2]=c[(c[e+6184>>2]|0)+4>>2];a[e+6492|0]=a[(c[e+6184>>2]|0)+10|0]|0;c[e+6484>>2]=d[(c[e+6184>>2]|0)+2|0]|0}}while(0)}do{if((S|0)<(G|0)){ja=93}else{if((c[e+6448>>2]|0)!=0){ja=93;break}U=e+27552+(R<<2)|0;c[U>>2]=(c[U>>2]|0)+4;if((c[e+27552+(R<<2)>>2]|0)>512){c[e+27552+(R<<2)>>2]=512}c[e+27632+(R<<2)>>2]=ca(c[D+114836+(R<<2)>>2]>>7,c[e+27552+(R<<2)>>2]|0)|0}}while(0);if((ja|0)==93){ja=0;J=R;c[h>>2]=V;c[j>>2]=c[v>>2];K=c[w>>2]|0;G=S;U=m;ea=c[e+6184>>2]|0;c[U>>2]=c[ea>>2];c[U+4>>2]=c[ea+4>>2];c[U+8>>2]=c[ea+8>>2];if((c[e+27552+(R<<2)>>2]|0)>=34){ka=(c[e+27552+(R<<2)>>2]|0)-2|0}else{ka=32}c[e+27552+(R<<2)>>2]=ka;c[e+27632+(R<<2)>>2]=ca(c[D+114836+(R<<2)>>2]>>7,c[e+27552+(R<<2)>>2]|0)|0}if((c[e+6448>>2]|0)!=0){ja=101;break a}}}while(0);R=R+1|0}do{if((c[D+114836+(J<<2)>>2]|0)>0){if((c[D+114836+(J<<2)>>2]|0)>=536870911){break}R=c[e+27552+(J<<2)>>2]>>3;if((c[e+27552+(J<<2)>>2]|0)>=(R+32|0)){la=(c[e+27552+(J<<2)>>2]|0)-R|0}else{la=32}c[e+27552+(J<<2)>>2]=la;c[e+27632+(J<<2)>>2]=ca(c[D+114836+(J<<2)>>2]>>7,c[e+27552+(J<<2)>>2]|0)|0}}while(0);J=c[j>>2]>>7;if((J|0)>=1024){J=1023}j=e+27816+(J<<2)|0;c[j>>2]=(c[j>>2]|0)+1;if((c[D+114080>>2]|0)!=0){if((c[e+6476>>2]|0)==0){c[e+6476>>2]=d[m|0]|0;c[e+6480>>2]=c[m+4>>2];a[e+6492|0]=a[m+10|0]|0;c[e+6484>>2]=d[m+2|0]|0;M=K}Hbc(D+149756|0,e,M,L,f,g);do{if((d[m+2|0]|0)==0){if((c[e+6488>>2]|0)==0){break}g=0;f=c[e+6488>>2]|0;L=c[e+6332+(f<<2)>>2]|0;V=L+(t$b(7,s|0)|0)|0;c[v>>2]=0;a[(c[e+6184>>2]|0)+2|0]=f;c[e+6052>>2]=c[A+(f*12|0)>>2];c[e+6056>>2]=c[A+(f*12|0)+4>>2];c[e+6060>>2]=c[A+(f*12|0)+8>>2];a[c[e+6184>>2]|0]=7;a[(c[e+6184>>2]|0)+1|0]=0;c[(c[e+6184>>2]|0)+4>>2]=0;g=v_b(w,V,v,D,e,c[t>>2]|0)|0;if((g|0)<(G|0)){g=m;f=c[e+6184>>2]|0;c[g>>2]=c[f>>2];c[g+4>>2]=c[f+4>>2];c[g+8>>2]=c[f+8>>2]}}}while(0)}do{if((c[D+114620>>2]|0)!=0){if((d[m|0]|0)==7){if((d[m+2|0]|0)==3){break}}a[c[e+6184>>2]|0]=7;a[(c[e+6184>>2]|0)+2|0]=3;c[(c[e+6184>>2]|0)+4>>2]=0;a[(c[e+6184>>2]|0)+1|0]=0;a[(c[e+6184>>2]|0)+9|0]=c[D+108004>>2];a[(c[e+6184>>2]|0)+8|0]=0;i=n;return}}while(0);if((c[e+6448>>2]|0)==0){G=c[e+6184>>2]|0;t=m;c[G>>2]=c[t>>2];c[G+4>>2]=c[t+4>>2];c[G+8>>2]=c[t+8>>2]}if((d[m|0]|0)<=4){w_b(e)}if((P|0)!=(c[D+111444+(d[(c[F+3032>>2]|0)+2|0]<<2)>>2]|0)){c[q>>2]=c[o+((((P|0)!=0^1)&1)<<2)>>2]}x_b(e,q);i=n;return}function r_b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;b=0;f=b;b=f+1|0;c[a+(f<<2)>>2]=0;if((c[e+142448>>2]&1|0)!=0){f=b;b=f+1|0;c[a+(f<<2)>>2]=1}if((c[e+142448>>2]&2|0)!=0){f=b;b=f+1|0;c[a+(f<<2)>>2]=2}if((c[e+142448>>2]&4|0)!=0){e=b;b=e+1|0;c[a+(e<<2)>>2]=3}while(1){if((b|0)>=4){break}c[a+(b<<2)>>2]=-1;b=b+1|0}i=d;return}function s_b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=d;d=e;if((c[g+142448>>2]&1|0)!=0){F_b(g+107480+((c[g+107868>>2]|0)*92|0)|0,a+12|0,b,d)}if((c[g+142448>>2]&2|0)!=0){F_b(g+107480+((c[g+107872>>2]|0)*92|0)|0,a+24|0,b,d)}if((c[g+142448>>2]&4|0)==0){i=f;return}F_b(g+107480+((c[g+107876>>2]|0)*92|0)|0,a+36|0,b,d);i=f;return}function t_b(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=e;e=f;f=c[l+6184>>2]|0;m=0;if((c[a+142596>>2]|0)<=40){i=g;return}f=f-76|0;c[h>>2]=c[f+4>>2];if((d[f+2|0]|0)!=0){do{if((R(b[h>>1]|0)|0)<8){if((R(b[h+2>>1]|0)|0)>=8){break}m=m+1|0}}while(0)}f=f+((-(c[l+6188>>2]|0)|0)*76|0)|0;c[k>>2]=c[f+4>>2];if((d[f+2|0]|0)!=0){do{if((R(b[k>>1]|0)|0)<8){if((R(b[k+2>>1]|0)|0)>=8){break}m=m+1|0}}while(0)}f=f+76|0;c[j>>2]=c[f+4>>2];if((d[f+2|0]|0)!=0){do{if((R(b[j>>1]|0)|0)<8){if((R(b[j+2>>1]|0)|0)>=8){break}m=m+1|0}}while(0)}if((c[l+6288>>2]|0)!=0){if((c[l+6280>>2]|0)!=0){n=20}else{n=19}}else{n=19}if((n|0)==19){if((m|0)>0){n=21}else{n=20}}do{if((n|0)==20){if((m|0)>2){n=21;break}if((m|0)>0){c[e>>2]=90}}}while(0);if((n|0)==21){c[e>>2]=80}i=g;return}function u_b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=a;a=b;b=d;d=j+3152|0;k=c[(c[j+6412>>2]|0)+((c[d+3040>>2]|0)*40|0)+16>>2]|0;l=0;A_b(d,(c[d+2992>>2]|0)+(-(c[d+2956>>2]|0)|0)+16|0);m=c[j+6424>>2]|0;n=0;while(1){if((n|0)>=16){break}o=c[d+3032>>2]|0;p=c[d+3036>>2]|0;c[f>>2]=c[f>>2];c[g>>2]=c[g>>2];c[h>>2]=c[h>>2];if((c[j+6192>>2]|0)==0){q=B_b(o,n,p)|0;p=C_b(o,n)|0;m=(c[j+6420>>2]|0)+(q*400|0)+(p*40|0)|0}D_b(j,n,f,m,g,h)|0;k=k+(c[g>>2]|0)|0;l=l+(c[h>>2]|0)|0;c[o+12+(n<<2)>>2]=c[f>>2];if((l|0)>(c[b>>2]|0)){o=6;break}n=n+1|0}c[a>>2]=k;if((n|0)==16){c[b>>2]=l;n=(ca(k,c[j+6376>>2]|0)|0)+128>>8;r=n+(ca(c[j+6372>>2]|0,l)|0)|0;s=r;i=e;return s|0}else{c[b>>2]=2147483647;r=2147483647;s=r;i=e;return s|0}return 0}function v_b(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;i=i+8|0;k=j|0;l=a;a=b;b=e;e=f;f=g;g=h;h=d[c[f+6184>>2]|0]|0;c[k>>2]=c[(c[f+6184>>2]|0)+4>>2];do{if((c[e+142632>>2]|0)!=0){if((d[c[f+6460>>2]|0]|0|0)!=0){break}c[l>>2]=0;c[b>>2]=0;c[f+6448>>2]=1;m=2147483647;n=m;i=j;return n|0}}while(0);do{if((h|0)!=8){o=7}else{if((c[e+142480>>2]|0)==0){o=7;break}if((c[e+108016>>2]|0)==1){o=7}}}while(0);if((o|0)==7){c[b>>2]=o_b(f,e+142932|0,l,k)|0}k=(ca(a,c[f+6376>>2]|0)|0)+128>>8;a=k+(ca(c[f+6372>>2]|0,c[b>>2]|0)|0)|0;if((h|0)==7){do{if((c[e+142448>>2]&1&c[e+111420>>2]|0)!=0){if((d[(c[f+6184>>2]|0)+2|0]|0|0)==1){break}g=100}}while(0);e=a;h=g;g=Erc(e,(e|0)<0|0?-1:0,h,(h|0)<0|0?-1:0)|0;h=Crc(g,G,100,0)|0;a=h}z_b(c[l>>2]|0,f);m=a;n=m;i=j;return n|0}function w_b(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=b;b=j+3152|0;k=(c[b+2996>>2]|0)+(-(c[b+2976>>2]|0)|0)|0;l=(c[b+3e3>>2]|0)+(-(c[b+2976>>2]|0)|0)|0;m=(c[c[j+2664>>2]>>2]|0)+(c[j+2668>>2]|0)|0;n=(c[c[j+2856>>2]>>2]|0)+(c[j+2860>>2]|0)|0;o=c[j+2672>>2]|0;p=a[k-1|0]|0;q=a[l-1|0]|0;r=0;s=0;mrc(h|0,0,16)|0;t=2147483647;u=u;v=0;while(1){if((v|0)>=8){break}w=(ca(v,c[b+2976>>2]|0)|0)-1|0;a[f+v|0]=a[(c[b+2996>>2]|0)+w|0]|0;w=(ca(v,c[b+2976>>2]|0)|0)-1|0;a[g+v|0]=a[(c[b+3e3>>2]|0)+w|0]|0;v=v+1|0}do{if((c[b+3044>>2]|0)!=0){x=8}else{if((c[b+3048>>2]|0)!=0){x=8;break}y=128;z=128}}while(0);if((x|0)==8){x=2;if((c[b+3044>>2]|0)!=0){v=0;while(1){if((v|0)>=8){break}r=r+(d[k+v|0]|0)|0;s=s+(d[l+v|0]|0)|0;v=v+1|0}x=x+1|0}if((c[b+3048>>2]|0)!=0){v=0;while(1){if((v|0)>=8){break}r=r+(d[f+v|0]|0)|0;s=s+(d[g+v|0]|0)|0;v=v+1|0}x=x+1|0}y=r+(1<<x-1)>>x;z=s+(1<<x-1)>>x}v=0;while(1){if((v|0)>=8){break}x=0;while(1){if((x|0)>=8){break}s=(d[f+v|0]|0)+(d[k+x|0]|0)-(p&255)|0;r=(d[g+v|0]|0)+(d[l+x|0]|0)-(q&255)|0;b=d[m+x|0]|0;w=d[n+x|0]|0;if((s|0)<0){s=0}if((s|0)>255){s=255}if((r|0)<0){r=0}if((r|0)>255){r=255}A=b-y|0;B=ca(A,A)|0;C=h|0;c[C>>2]=(c[C>>2]|0)+B;A=w-z|0;B=ca(A,A)|0;C=h|0;c[C>>2]=(c[C>>2]|0)+B;A=b-(d[k+x|0]|0)|0;B=ca(A,A)|0;C=h+4|0;c[C>>2]=(c[C>>2]|0)+B;A=w-(d[l+x|0]|0)|0;B=ca(A,A)|0;C=h+4|0;c[C>>2]=(c[C>>2]|0)+B;A=b-(d[f+v|0]|0)|0;B=ca(A,A)|0;C=h+8|0;c[C>>2]=(c[C>>2]|0)+B;A=w-(d[g+v|0]|0)|0;B=ca(A,A)|0;C=h+8|0;c[C>>2]=(c[C>>2]|0)+B;A=b-s|0;s=ca(A,A)|0;b=h+12|0;c[b>>2]=(c[b>>2]|0)+s;A=w-r|0;r=ca(A,A)|0;A=h+12|0;c[A>>2]=(c[A>>2]|0)+r;x=x+1|0}m=m+o|0;n=n+o|0;if((v|0)==3){m=(c[c[j+2760>>2]>>2]|0)+(c[j+2764>>2]|0)|0;n=(c[c[j+2952>>2]>>2]|0)+(c[j+2956>>2]|0)|0}v=v+1|0}v=0;while(1){if((v|0)>3){break}if((t|0)>(c[h+(v<<2)>>2]|0)){t=c[h+(v<<2)>>2]|0;u=v}v=v+1|0}a[(c[j+6184>>2]|0)+1|0]=u;i=e;return}function x_b(a,e){a=a|0;e=e|0;var f=0,g=0,h=0;f=i;g=a;a=e;e=g+3152|0;if((d[c[e+3032>>2]|0]|0)!=8){i=f;return}h=g+11108+(((b[(c[e+3032>>2]|0)+4>>1]|0)-(b[a>>1]|0)>>1)+1023<<2)|0;c[h>>2]=(c[h>>2]|0)+1;h=g+19296+(((b[(c[e+3032>>2]|0)+6>>1]|0)-(b[a+2>>1]|0)>>1)+1023<<2)|0;c[h>>2]=(c[h>>2]|0)+1;i=f;return}function y_b(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b;b=d;d=2147483647;k=0;l=0;m=j+1860|0;n=j+3152|0;a[(c[n+3032>>2]|0)+2|0]=0;w_b(j);o=0;while(1){if(!(o>>>0<=3>>>0)){break}a[c[n+3032>>2]|0]=o;c9b(n,(c[n+2992>>2]|0)+(-(c[n+2956>>2]|0)|0)|0,(c[n+2992>>2]|0)-1|0,c[n+2956>>2]|0,n|0,16);p=B9b(c[c[m+36>>2]>>2]|0,c[m+44>>2]|0,n|0,16,h)|0;c[f>>2]=c[(c[j+6412>>2]|0)+((c[n+3040>>2]|0)*40|0)+(o<<2)>>2];q=(ca(c[f>>2]|0,c[j+6376>>2]|0)|0)+128>>8;r=q+(ca(c[j+6372>>2]|0,p)|0)|0;if((d|0)>(r|0)){d=r;l=o;c[g>>2]=c[h>>2];k=c[f>>2]|0}o=o+1|0}a[c[n+3032>>2]|0]=l;if((u_b(j,f,g)|0)>=(d|0)){s=k;t=b;c[t>>2]=s;i=e;return}a[c[n+3032>>2]|0]=4;k=c[f>>2]|0;s=k;t=b;c[t>>2]=s;i=e;return}function z_b(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;e=i;f=d;d=f+3152|0;g=(ca(b[(c[d+2156>>2]|0)+2>>1]|0,b[(c[d+2156>>2]|0)+2>>1]|0)|0)>>4;if(g>>>0<(c[f+6452>>2]|0)>>>0){g=c[f+6452>>2]|0}if(!(a>>>0<g>>>0)){i=e;return}g=0;g=s$b(f)|0;if(g<<1>>>0<(c[f+6452>>2]|0)>>>0){c[f+6448>>2]=1}else{c[f+6448>>2]=0}i=e;return}function A_b(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;a=c[d+2956>>2]|0;e=(c[d+2992>>2]|0)+(-a|0)+16|0;d=b;c[e+(a<<2)>>2]=c[d>>2];c[e+(a<<3)>>2]=c[d>>2];c[e+(a*12|0)>>2]=c[d>>2];i=i;return}function B_b(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=a;a=b;a:do{if((a>>2|0)!=0){g=c[f+12+(a<<2)-16>>2]|0}else{f=f+((-e|0)*76|0)|0;switch(d[f|0]|0|0){case 1:{g=2;break a;break};case 3:{g=1;break a;break};case 0:{g=0;break a;break};case 2:{g=3;break a;break};case 4:{g=c[f+12+(a<<2)+48>>2]|0;break a;break};default:{g=0;break a}}}}while(0);i=i;return g|0}function C_b(a,b){a=a|0;b=b|0;var e=0,f=0;e=a;a=b;a:do{if((a&3|0)!=0){f=c[e+12+(a<<2)-4>>2]|0}else{e=e-76|0;switch(d[e|0]|0|0){case 0:{f=0;break a;break};case 3:{f=1;break a;break};case 4:{f=c[e+12+(a<<2)+12>>2]|0;break a;break};case 2:{f=3;break a;break};case 1:{f=2;break a;break};default:{f=0;break a}}}}while(0);i=i;return f|0}function D_b(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;k=b;b=d;d=e;e=f;f=g;g=h;h=k+5296+(b*28|0)|0;l=k+1860+(b*48|0)|0;m=c[k+6108>>2]|0;n=(c[k+6144>>2]|0)+(c[h+16>>2]|0)|0;o=2147483647;p=n+(-m|0)|0;q=n-1|0;n=a[p-1|0]|0;r=0;while(1){if(!(r>>>0<=3>>>0)){break}s=c[e+(r<<2)>>2]|0;e9b(p,q,m,r,c[h+8>>2]|0,16,n);t=E_b(l,h)|0;u=(ca(s,c[k+6376>>2]|0)|0)+128>>8;v=u+(ca(c[k+6372>>2]|0,t)|0)|0;if((v|0)<(o|0)){c[f>>2]=s;c[g>>2]=t;o=v;c[d>>2]=r}r=r+1|0}c[h+24>>2]=c[d>>2];ccc(k,b);i=j;return o|0}function E_b(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=p_b((c[c[e+36>>2]>>2]|0)+(c[e+40>>2]|0)|0,c[e+44>>2]|0,c[b+8>>2]|0,16)|0;i=d;return a|0}function F_b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=a;a=b;b=e;c[a>>2]=(c[f+52>>2]|0)+d;c[a+4>>2]=(c[f+56>>2]|0)+b;c[a+8>>2]=(c[f+60>>2]|0)+b;i=i;return}function G_b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=c[e+4>>2]|0;f=c[e+16>>2]|0;g=(a>>4|0)/8|0;if((g|0)!=0){h=g<<4}else{h=16}g=h;g=g+4|0;h=ca(f,(a>>5<<4)-4|0)|0;nrc((c[b+52>>2]|0)+h|0,(c[e+52>>2]|0)+h|0,ca(f,g)|0)|0;i=d;return}function H_b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=a;a=b;b=a+105664|0;f=0;g=0;h=I_b(a,c[b+2356>>2]|0)|0;j=J_b(a,c[b+2356>>2]|0)|0;k=c[b+5744>>2]|0;l=c[b+1812>>2]|0;c[b+1812>>2]=a+114636;if((c[b+2312>>2]|0)==0){c[b+5752>>2]=0}else{c[b+5752>>2]=c[a+114084>>2]}if((c[b+5752>>2]|0)!=(c[b+5748>>2]|0)){g8b(b+2400|0,c[b+5752>>2]|0);c[b+5748>>2]=c[b+5752>>2]}if((c[b+5744>>2]|0)<(h|0)){c[b+5744>>2]=h}else{if((c[b+5744>>2]|0)>(j|0)){c[b+5744>>2]=j}}m=c[b+5744>>2]|0;k=m;G_b(l,c[b+1812>>2]|0);o8b(b,a+76880|0,m);f=K_b(e,c[b+1812>>2]|0)|0;m=m-(((m|0)>10)+1)|0;while(1){if((m|0)<(h|0)){break}G_b(l,c[b+1812>>2]|0);o8b(b,a+76880|0,m);g=K_b(e,c[b+1812>>2]|0)|0;if((g|0)>=(f|0)){n=15;break}f=g;k=m;m=m-(((m|0)>10)+1)|0}m=(c[b+5744>>2]|0)+1+((m|0)>10)|0;if((k|0)==(c[b+5744>>2]|0)){f=f-(f>>10)|0;while(1){if((m|0)>=(j|0)){break}G_b(l,c[b+1812>>2]|0);o8b(b,a+76880|0,m);g=K_b(e,c[b+1812>>2]|0)|0;if((g|0)>=(f|0)){n=22;break}f=g-(g>>10)|0;k=m;m=m+(((m|0)>10)+1)|0}}c[b+5744>>2]=k;if((c[b+5744>>2]|0)<(h|0)){c[b+5744>>2]=h}if((c[b+5744>>2]|0)<=(j|0)){o=l;p=b;q=p+1812|0;c[q>>2]=o;i=d;return}c[b+5744>>2]=j;o=l;p=b;q=p+1812|0;c[q>>2]=o;i=d;return}function I_b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;do{if((c[e+114616>>2]|0)!=0){if((c[e+111424>>2]|0)==0){break}if((c[e+111428>>2]|0)!=0){break}f=0;g=f;i=d;return g|0}}while(0);if((a|0)<=6){f=0}else{if((a|0)<=16){f=1}else{f=(a|0)/8|0}}g=f;i=d;return g|0}function J_b(a,b){a=a|0;b=b|0;b=63;if((c[a+146856>>2]|0)>>>0>8>>>0){b=47}i=i;return b|0}function K_b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=a;a=b;b=0;g=c[f+52>>2]|0;h=c[a+52>>2]|0;j=(c[f+4>>2]>>4|0)/8|0;if((j|0)!=0){k=j<<4}else{k=16}j=k;k=ca(c[f+16>>2]|0,c[a+4>>2]>>5<<4)|0;g=g+k|0;h=h+(ca(c[a+16>>2]|0,c[a+4>>2]>>5<<4)|0)|0;k=0;while(1){if((k|0)>=(j|0)){break}l=0;while(1){if((l|0)>=(c[f>>2]|0)){break}b=b+(H9b(g+l|0,c[f+16>>2]|0,h+l|0,c[a+16>>2]|0,e)|0)|0;l=l+16|0}g=g+(c[f+16>>2]<<4)|0;h=h+(c[a+16>>2]<<4)|0;k=k+16|0}i=d;return b|0}function L_b(b,c){b=b|0;c=c|0;c=b;b=c+76880|0;a[b+3103|0]=a[c+142608|0]|0;a[b+3104|0]=a[c+142609|0]|0;a[b+3105|0]=a[c+142610|0]|0;a[b+3106|0]=a[c+142611|0]|0;i=i;return}function M_b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+256|0;e=d|0;f=a;a=b;b=a+105664|0;g=0;h=0;j=I_b(a,c[b+2356>>2]|0)|0;k=J_b(a,c[b+2356>>2]|0)|0;l=0;m=c[b+5744>>2]|0;n=0;o=0;p=0;q=c[b+1812>>2]|0;mrc(e|0,0,256)|0;c[b+1812>>2]=a+114636;if((c[b+2312>>2]|0)==0){c[b+5752>>2]=0}else{c[b+5752>>2]=c[a+114084>>2]}m=c[b+5744>>2]|0;if((m|0)<(j|0)){m=j}else{if((m|0)>(k|0)){m=k}}if((m|0)<16){r=4}else{r=(m|0)/4|0}s=r;T7b(q,c[b+1812>>2]|0);L_b(a,m);n8b(b,a+76880|0,m);g=$Zb(f,c[b+1812>>2]|0)|0;c[e+(m<<2)>>2]=g;r=m;while(1){if((s|0)<=0){break}p=ca(g>>15-((m|0)/8|0),s)|0;if((c[a+146856>>2]|0)>>>0<20>>>0){p=((ca(p,c[a+146856>>2]|0)|0)>>>0)/20|0}if((m+s|0)>(k|0)){t=k}else{t=m+s|0}l=t;if((m-s|0)<(j|0)){u=j}else{u=m-s|0}n=u;do{if((o|0)<=0){if((n|0)==(m|0)){break}if((c[e+(n<<2)>>2]|0)==0){T7b(q,c[b+1812>>2]|0);L_b(a,n);n8b(b,a+76880|0,n);h=$Zb(f,c[b+1812>>2]|0)|0;c[e+(n<<2)>>2]=h}else{h=c[e+(n<<2)>>2]|0}if((h-p|0)<(g|0)){if((h|0)<(g|0)){g=h}r=n}}}while(0);do{if((o|0)>=0){if((l|0)==(m|0)){break}if((c[e+(l<<2)>>2]|0)==0){T7b(q,c[b+1812>>2]|0);L_b(a,l);n8b(b,a+76880|0,l);h=$Zb(f,c[b+1812>>2]|0)|0;c[e+(l<<2)>>2]=h}else{h=c[e+(l<<2)>>2]|0}if((h|0)<(g-p|0)){g=h;r=l}}}while(0);if((r|0)==(m|0)){s=(s|0)/2|0;o=0}else{o=(r|0)<(m|0)?-1:1;m=r}}c[b+5744>>2]=r;c[b+1812>>2]=q;i=d;return}function N_b(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=d;d=e;e=c[g+4>>2]|0;h=c[g+28>>2]|0;j=c[g+12>>2]|0;g=c[d>>2]|0;k=c[d+4>>2]|0;l=c[d+12>>2]|0;m=-1;n=0;while(1){if((n|0)>=16){break}o=c[245048+(n<<2)>>2]|0;p=b[e+(o<<1)>>1]|0;q=p>>31;r=(p^q)-q|0;p=(ca(r+(b[h+(o<<1)>>1]|0)|0,b[j+(o<<1)>>1]|0)|0)>>16;r=(p^q)-q|0;b[g+(o<<1)>>1]=r;b[k+(o<<1)>>1]=ca(r,b[l+(o<<1)>>1]|0)|0;if((p|0)!=0){m=n}n=n+1|0}a[c[d+20>>2]|0]=m+1;i=f;return}function O_b(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;g=d;d=e;e=c[g+24>>2]|0;h=c[g+4>>2]|0;j=c[g+20>>2]|0;k=c[g+28>>2]|0;l=c[g+8>>2]|0;m=c[g+16>>2]|0;n=c[d>>2]|0;o=c[d+4>>2]|0;p=c[d+12>>2]|0;q=b[g+32>>1]|0;mrc(n|0,0,32)|0;mrc(o|0,0,32)|0;r=-1;s=0;while(1){if((s|0)>=16){break}t=c[245048+(s<<2)>>2]|0;u=b[h+(t<<1)>>1]|0;v=(b[j+(t<<1)>>1]|0)+(b[e>>1]|0)+(q<<16>>16)|0;e=e+2|0;w=u>>31;x=(u^w)-w|0;if((x|0)>=(v|0)){x=x+(b[k+(t<<1)>>1]|0)|0;v=((ca(x,b[l+(t<<1)>>1]|0)|0)>>16)+x|0;u=(ca(v,b[m+(t<<1)>>1]|0)|0)>>16;x=(u^w)-w|0;b[n+(t<<1)>>1]=x;b[o+(t<<1)>>1]=ca(x,b[p+(t<<1)>>1]|0)|0;if((u|0)!=0){r=s;e=c[g+24>>2]|0}}s=s+1|0}a[c[d+20>>2]|0]=r+1;i=f;return}function P_b(a){a=a|0;var b=0,e=0,f=0;b=i;e=a;if((d[c[e+6184>>2]|0]|0|0)!=4){f=(d[c[e+6184>>2]|0]|0|0)!=9}else{f=0}a=f&1;f=0;while(1){if((f|0)>=16){break}re[c[e+31924>>2]&1023](e+1860+(f*48|0)|0,e+5296+(f*28|0)|0);f=f+1|0}if((a|0)==0){i=b;return}re[c[e+31924>>2]&1023](e+3012|0,e+5968|0);i=b;return}function Q_b(a){a=a|0;var b=0,e=0,f=0;b=i;e=a;if((d[c[e+6184>>2]|0]|0|0)!=4){f=(d[c[e+6184>>2]|0]|0|0)!=9}else{f=0}a=f&1;f=0;while(1){if((f|0)>=(a+24|0)){break}re[c[e+31924>>2]&1023](e+1860+(f*48|0)|0,e+5296+(f*28|0)|0);f=f+1|0}i=b;return}function R_b(a){a=a|0;var b=0,d=0;b=i;d=a;a=16;while(1){if((a|0)>=24){break}re[c[d+31924>>2]&1023](d+1860+(a*48|0)|0,d+5296+(a*28|0)|0);a=a+1|0}i=b;return}function S_b(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=i;O_b(a,c);O_b(b,d);i=e;return}function T_b(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=i;N_b(a,c);N_b(b,d);i=e;return}function U_b(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+64|0;e=d|0;f=a;nrc(e|0,235552,64)|0;a=0;while(1){if((a|0)>=128){break}g=I8b(a,c[f+108024>>2]|0)|0;b[f+61440+(a<<5)>>1]=65536/(g|0)|0;V_b(c[f+142460>>2]|0,f+(a<<5)|0,f+4096+(a<<5)|0,g&65535);b[f+8192+(a<<5)>>1]=(ca(c[683312+(a<<2)>>2]|0,g)|0)+64>>7;b[f+12288+(a<<5)>>1]=(ca(c[691576+(a<<2)>>2]|0,g)|0)>>7;b[f+105920+(a<<2)>>1]=g;b[f+49152+(a<<5)>>1]=(ca(g,c[e>>2]|0)|0)>>7;g=J8b(a,c[f+108028>>2]|0)|0;b[f+65536+(a<<5)>>1]=65536/(g|0)|0;V_b(c[f+142460>>2]|0,f+16384+(a<<5)|0,f+20480+(a<<5)|0,g&65535);b[f+24576+(a<<5)>>1]=(ca(c[682792+(a<<2)>>2]|0,g)|0)+64>>7;b[f+28672+(a<<5)>>1]=(ca(c[691056+(a<<2)>>2]|0,g)|0)>>7;b[f+106432+(a<<2)>>1]=g;b[f+53248+(a<<5)>>1]=(ca(g,c[e>>2]|0)|0)>>7;g=K8b(a,c[f+108036>>2]|0)|0;b[f+69632+(a<<5)>>1]=65536/(g|0)|0;V_b(c[f+142460>>2]|0,f+32768+(a<<5)|0,f+36864+(a<<5)|0,g&65535);b[f+40960+(a<<5)>>1]=(ca(c[683312+(a<<2)>>2]|0,g)|0)+64>>7;b[f+45056+(a<<5)>>1]=(ca(c[691576+(a<<2)>>2]|0,g)|0)>>7;b[f+106944+(a<<2)>>1]=g;b[f+57344+(a<<5)>>1]=(ca(g,c[e>>2]|0)|0)>>7;g=L8b(a)|0;b[f+61440+(a<<5)+2>>1]=65536/(g|0)|0;V_b(c[f+142460>>2]|0,f+(a<<5)+2|0,f+4096+(a<<5)+2|0,g&65535);b[f+8192+(a<<5)+2>>1]=(ca(c[683312+(a<<2)>>2]|0,g)|0)+64>>7;b[f+12288+(a<<5)+2>>1]=(ca(c[691576+(a<<2)>>2]|0,g)|0)>>7;b[f+105920+(a<<2)+2>>1]=g;b[f+49152+(a<<5)+2>>1]=(ca(g,c[e+4>>2]|0)|0)>>7;g=M8b(a,c[f+108032>>2]|0)|0;b[f+65536+(a<<5)+2>>1]=65536/(g|0)|0;V_b(c[f+142460>>2]|0,f+16384+(a<<5)+2|0,f+20480+(a<<5)+2|0,g&65535);b[f+24576+(a<<5)+2>>1]=(ca(c[682792+(a<<2)>>2]|0,g)|0)+64>>7;b[f+28672+(a<<5)+2>>1]=(ca(c[691056+(a<<2)>>2]|0,g)|0)>>7;b[f+106432+(a<<2)+2>>1]=g;b[f+53248+(a<<5)+2>>1]=(ca(g,c[e+4>>2]|0)|0)>>7;g=N8b(a,c[f+108040>>2]|0)|0;b[f+69632+(a<<5)+2>>1]=65536/(g|0)|0;V_b(c[f+142460>>2]|0,f+32768+(a<<5)+2|0,f+36864+(a<<5)+2|0,g&65535);b[f+40960+(a<<5)+2>>1]=(ca(c[683312+(a<<2)>>2]|0,g)|0)+64>>7;b[f+45056+(a<<5)+2>>1]=(ca(c[691576+(a<<2)>>2]|0,g)|0)>>7;b[f+106944+(a<<2)+2>>1]=g;b[f+57344+(a<<5)+2>>1]=(ca(g,c[e+4>>2]|0)|0)>>7;g=2;while(1){if((g|0)>=16){break}b[f+61440+(a<<5)+(g<<1)>>1]=b[f+61440+(a<<5)+2>>1]|0;b[f+(a<<5)+(g<<1)>>1]=b[f+(a<<5)+2>>1]|0;b[f+4096+(a<<5)+(g<<1)>>1]=b[f+4096+(a<<5)+2>>1]|0;b[f+8192+(a<<5)+(g<<1)>>1]=b[f+8192+(a<<5)+2>>1]|0;b[f+12288+(a<<5)+(g<<1)>>1]=b[f+12288+(a<<5)+2>>1]|0;b[f+49152+(a<<5)+(g<<1)>>1]=(ca(b[f+105920+(a<<2)+2>>1]|0,c[e+(g<<2)>>2]|0)|0)>>7;b[f+65536+(a<<5)+(g<<1)>>1]=b[f+65536+(a<<5)+2>>1]|0;b[f+16384+(a<<5)+(g<<1)>>1]=b[f+16384+(a<<5)+2>>1]|0;b[f+20480+(a<<5)+(g<<1)>>1]=b[f+20480+(a<<5)+2>>1]|0;b[f+24576+(a<<5)+(g<<1)>>1]=b[f+24576+(a<<5)+2>>1]|0;b[f+28672+(a<<5)+(g<<1)>>1]=b[f+28672+(a<<5)+2>>1]|0;b[f+53248+(a<<5)+(g<<1)>>1]=(ca(b[f+106432+(a<<2)+2>>1]|0,c[e+(g<<2)>>2]|0)|0)>>7;b[f+69632+(a<<5)+(g<<1)>>1]=b[f+69632+(a<<5)+2>>1]|0;b[f+32768+(a<<5)+(g<<1)>>1]=b[f+32768+(a<<5)+2>>1]|0;b[f+36864+(a<<5)+(g<<1)>>1]=b[f+36864+(a<<5)+2>>1]|0;b[f+40960+(a<<5)+(g<<1)>>1]=b[f+40960+(a<<5)+2>>1]|0;b[f+45056+(a<<5)+(g<<1)>>1]=b[f+45056+(a<<5)+2>>1]|0;b[f+57344+(a<<5)+(g<<1)>>1]=(ca(b[f+106944+(a<<2)+2>>1]|0,c[e+(g<<2)>>2]|0)|0)>>7;g=g+1|0}a=a+1|0}i=d;return}function V_b(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=c;c=d;d=e;if((a|0)==0){b[g>>1]=65536/(d<<16>>16|0)|0;b[c>>1]=0;b[c>>1]=1<<16-(b[c>>1]|0);i=f;return}a=d<<16>>16;e=0;while(1){if(!(a>>>0>1>>>0)){break}a=a>>>1;e=e+1|0}a=((1<<e+16|0)/(d<<16>>16|0)|0)+1|0;b[g>>1]=a-65536;b[c>>1]=e;b[c>>1]=1<<16-(b[c>>1]|0);i=f;return}function W_b(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;j=e;e=f;f=g;g=e+3152|0;if((a[g+3092|0]|0)!=0){if((d[g+3095|0]|0)==1){k=a[g+3099+(d[(c[g+3032>>2]|0)+11|0]|0)|0]|0}else{k=(c[j+108020>>2]|0)+(a[g+3099+(d[(c[g+3032>>2]|0)+11|0]|0)|0]|0)|0;if((k|0)>=0){if((k|0)<=127){l=k}else{l=127}m=l}else{m=0}k=m}}else{k=c[j+108020>>2]|0}do{if((f|0)!=0){if((k|0)!=(c[e+6472>>2]|0)){break}do{if((c[e+27808>>2]|0)!=(c[e+27812>>2]|0)){n=39}else{if((c[e+27804>>2]|0)!=(c[e+27800>>2]|0)){n=39;break}if((c[e+6392>>2]|0)!=(c[e+6388>>2]|0)){n=39}}}while(0);if((n|0)==39){o=(ca(b[j+105920+(k<<2)+2>>1]|0,(c[e+27812>>2]|0)+(c[e+27800>>2]|0)+(c[e+6388>>2]|0)|0)|0)>>7;p=0;while(1){if((p|0)>=16){break}b[e+1860+(p*48|0)+32>>1]=o;p=p+1|0}o=(ca(b[j+106944+(k<<2)+2>>1]|0,(c[e+27812>>2]|0)+(c[e+27800>>2]|0)+(c[e+6388>>2]|0)|0)|0)>>7;p=16;while(1){if((p|0)>=24){break}b[e+1860+(p*48|0)+32>>1]=o;p=p+1|0}o=(ca(b[j+106432+(k<<2)+2>>1]|0,((c[e+27812>>2]|0)/2|0)+(c[e+27800>>2]|0)+(c[e+6388>>2]|0)|0)|0)>>7;b[e+3044>>1]=o;c[e+27808>>2]=c[e+27812>>2];c[e+27804>>2]=c[e+27800>>2];c[e+6392>>2]=c[e+6388>>2]}i=h;return}}while(0);b[g+2048>>1]=1;b[g+2016>>1]=b[j+105920+(k<<2)>>1]|0;b[g+2080>>1]=b[j+106432+(k<<2)>>1]|0;b[g+2112>>1]=b[j+106944+(k<<2)>>1]|0;p=1;while(1){if((p|0)>=16){break}n=b[j+105920+(k<<2)+2>>1]|0;b[g+2016+(p<<1)>>1]=n;b[g+2048+(p<<1)>>1]=n;b[g+2080+(p<<1)>>1]=b[j+106432+(k<<2)+2>>1]|0;b[g+2112+(p<<1)>>1]=b[j+106944+(k<<2)+2>>1]|0;p=p+1|0}p=0;while(1){if((p|0)>=16){break}c[e+5296+(p*28|0)+12>>2]=g+2016;p=p+1|0}p=16;while(1){if((p|0)>=24){break}c[e+5296+(p*28|0)+12>>2]=g+2112;p=p+1|0}c[e+5980>>2]=g+2080;o=(ca(b[j+105920+(k<<2)+2>>1]|0,(c[e+27812>>2]|0)+(c[e+27800>>2]|0)+(c[e+6388>>2]|0)|0)|0)>>7;p=0;while(1){if((p|0)>=16){break}c[e+1860+(p*48|0)+8>>2]=j+(k<<5);c[e+1860+(p*48|0)+12>>2]=j+61440+(k<<5);c[e+1860+(p*48|0)+16>>2]=j+4096+(k<<5);c[e+1860+(p*48|0)+20>>2]=j+8192+(k<<5);c[e+1860+(p*48|0)+28>>2]=j+12288+(k<<5);c[e+1860+(p*48|0)+24>>2]=j+49152+(k<<5);b[e+1860+(p*48|0)+32>>1]=o;p=p+1|0}o=(ca(b[j+106944+(k<<2)+2>>1]|0,(c[e+27812>>2]|0)+(c[e+27800>>2]|0)+(c[e+6388>>2]|0)|0)|0)>>7;p=16;while(1){if((p|0)>=24){break}c[e+1860+(p*48|0)+8>>2]=j+32768+(k<<5);c[e+1860+(p*48|0)+12>>2]=j+69632+(k<<5);c[e+1860+(p*48|0)+16>>2]=j+36864+(k<<5);c[e+1860+(p*48|0)+20>>2]=j+40960+(k<<5);c[e+1860+(p*48|0)+28>>2]=j+45056+(k<<5);c[e+1860+(p*48|0)+24>>2]=j+57344+(k<<5);b[e+1860+(p*48|0)+32>>1]=o;p=p+1|0}o=(ca(b[j+106432+(k<<2)+2>>1]|0,((c[e+27812>>2]|0)/2|0)+(c[e+27800>>2]|0)+(c[e+6388>>2]|0)|0)|0)>>7;c[e+3024>>2]=j+65536+(k<<5);c[e+3020>>2]=j+16384+(k<<5);c[e+3028>>2]=j+20480+(k<<5);c[e+3032>>2]=j+24576+(k<<5);c[e+3040>>2]=j+28672+(k<<5);c[e+3036>>2]=j+53248+(k<<5);b[e+3044>>1]=o;c[e+6472>>2]=k;c[e+27808>>2]=c[e+27812>>2];c[e+27804>>2]=c[e+27800>>2];c[e+6392>>2]=c[e+6388>>2];i=h;return}function X_b(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=d;d=c[a+6472>>2]|0;g=(ca(b[f+105920+(d<<2)+2>>1]|0,(c[a+27812>>2]|0)+(c[a+27800>>2]|0)+(c[a+6388>>2]|0)|0)|0)>>7;h=0;while(1){if((h|0)>=16){break}b[a+1860+(h*48|0)+32>>1]=g;h=h+1|0}g=(ca(b[f+106944+(d<<2)+2>>1]|0,(c[a+27812>>2]|0)+(c[a+27800>>2]|0)+(c[a+6388>>2]|0)|0)|0)>>7;h=16;while(1){if((h|0)>=24){break}b[a+1860+(h*48|0)+32>>1]=g;h=h+1|0}g=(ca(b[f+106432+(d<<2)+2>>1]|0,((c[a+27812>>2]|0)/2|0)+(c[a+27800>>2]|0)+(c[a+6388>>2]|0)|0)|0)>>7;b[a+3044>>1]=g;i=e;return}function Y_b(a){a=a|0;var b=0,d=0;b=i;d=a;c[d+101528>>2]=0;W_b(d,d+73728|0,0);i=b;return}function Z_b(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=b;b=d;d=f+105664|0;g=f+76880|0;h=0;c[d+2356>>2]=b;c[d+2360>>2]=0;c[d+2368>>2]=0;c[d+2372>>2]=0;c[d+2376>>2]=0;if((b|0)<4){j=4-b|0}else{j=0}h=h|(c[d+2364>>2]|0)!=(j|0);c[d+2364>>2]=j;a[g+3099|0]=a[f+142604|0]|0;a[g+3100|0]=a[f+142605|0]|0;a[g+3101|0]=a[f+142606|0]|0;a[g+3102|0]=a[f+142607|0]|0;if((h|0)==0){i=e;return}U_b(f);i=e;return}function __b(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;e=b;b=e+114924|0;c[b+4>>2]=c[e+114736>>2];c[b+12>>2]=c[e+111408>>2];c[b+16>>2]=c[e+131524>>2];c[b+8>>2]=c[e+131520>>2];nrc(b+36|0,e+113661|0,38)|0;nrc(b+76|0,e+151704|0,16384)|0;f=b+16460|0;g=e+112595|0;a[f]=a[g]|0;a[f+1|0]=a[g+1|0]|0;a[f+2|0]=a[g+2|0]|0;a[f+3|0]=a[g+3|0]|0;g=b+16464|0;f=e+112599|0;a[g]=a[f]|0;a[g+1|0]=a[f+1|0]|0;a[g+2|0]=a[f+2|0]|0;f=b+16476|0;g=e+101212|0;c[f>>2]=c[g>>2];c[f+4>>2]=c[g+4>>2];c[f+8>>2]=c[g+8>>2];c[f+12>>2]=c[g+12>>2];c[f+16>>2]=c[g+16>>2];g=b+16496|0;f=e+101232|0;c[g>>2]=c[f>>2];c[g+4>>2]=c[f+4>>2];c[g+8>>2]=c[f+8>>2];c[g+12>>2]=c[f+12>>2];c[b+16528>>2]=c[e+142440>>2];i=d;return}function $_b(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;e=b;b=e+114924|0;c[e+114736>>2]=c[b+4>>2];c[e+111408>>2]=c[b+12>>2];c[e+131524>>2]=c[b+16>>2];c[e+131520>>2]=c[b+8>>2];nrc(e+113661|0,b+36|0,38)|0;nrc(e+151704|0,b+76|0,16384)|0;f=e+112595|0;g=b+16460|0;a[f]=a[g]|0;a[f+1|0]=a[g+1|0]|0;a[f+2|0]=a[g+2|0]|0;a[f+3|0]=a[g+3|0]|0;g=e+112599|0;f=b+16464|0;a[g]=a[f]|0;a[g+1|0]=a[f+1|0]|0;a[g+2|0]=a[f+2|0]|0;f=e+101212|0;g=b+16476|0;c[f>>2]=c[g>>2];c[f+4>>2]=c[g+4>>2];c[f+8>>2]=c[g+8>>2];c[f+12>>2]=c[g+12>>2];c[f+16>>2]=c[g+16>>2];g=e+101232|0;f=b+16496|0;c[g>>2]=c[f>>2];c[g+4>>2]=c[f+4>>2];c[g+8>>2]=c[f+8>>2];c[g+12>>2]=c[f+12>>2];c[e+142440>>2]=c[b+16528>>2];i=d;return}function a$b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;e=a;X7b(e+105664|0);nrc(e+113661|0,245112,38)|0;a=d;c[a>>2]=c[59654];c[a+4>>2]=c[59655];Bcc(e+80124|0,e+113661|0,d|0);nrc(e+144625|0,e+112586|0,1113)|0;nrc(e+145738|0,e+112586|0,1113)|0;nrc(e+143512|0,e+112586|0,1113)|0;c[e+111408>>2]=((c[e+108020>>2]|0)*3|0|0)/8|0;if((c[e+142364>>2]|0)!=0){c[e+131524>>2]=c[e+131552>>2];f=e;g=f+105664|0;h=g+5760|0;c[h>>2]=1;j=e;k=j+105664|0;l=k+5764|0;c[l>>2]=1;i=b;return}else{c[e+131524>>2]=7;f=e;g=f+105664|0;h=g+5760|0;c[h>>2]=1;j=e;k=j+105664|0;l=k+5764|0;c[l>>2]=1;i=b;return}}function b$b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0.0,k=0,l=0.0,m=0.0,n=0.0;d=i;e=a;a=b;b=c[e+108020>>2]|0;f=100;g=0;OYb();if((c[e+107976>>2]|0)==0){j=+h[e+131504>>3]}else{do{if((c[e+114288>>2]|0)==1){if((c[e+111428>>2]|0)==0){if((c[e+111424>>2]|0)==0){k=7;break}}j=+h[e+131512>>3]}else{k=7}}while(0);if((k|0)==7){j=+h[e+131496>>3]}}g=~~((j*+(c[246888+(c[e+107976>>2]<<9)+(b<<2)>>2]|0)+.5)*+(c[e+107988>>2]|0)/512.0);if((c[e+101540>>2]|0)>0){b=c[e+101540>>2]|0;l=.99;m=390625.0e-10;while(1){if((b|0)<=0){break}b=b-1|0;g=~~(l*+(g|0));l=l+m;if(l>=.999){l=.999}}}if((g|0)>0){f=((c[e+131484>>2]|0)*100|0|0)/(g|0)|0}g=a;if((g|0)==2){k=22}else if((g|0)==1){n=.375}else if((g|0)==0){n=.75}else{k=22}if((k|0)==22){n=.25}if((f|0)>102){f=~~(100.5+ +(f-100|0)*n);j=j*+(f|0)/100.0;if(j>50.0){j=50.0}}else{if((f|0)<99){f=~~(100.5- +(100-f|0)*n);j=j*+(f|0)/100.0;if(j<.01){j=.01}}}if((c[e+107976>>2]|0)==0){h[e+131504>>3]=j;i=d;return}do{if((c[e+114288>>2]|0)==1){if((c[e+111428>>2]|0)==0){if((c[e+111424>>2]|0)==0){k=38;break}}h[e+131512>>3]=j}else{k=38}}while(0);if((k|0)==38){h[e+131496>>3]=j}i=d;return}function c$b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0.0,l=0,m=0,n=0,o=0.0,p=0;d=i;e=a;a=b;b=c[e+131736>>2]|0;c[e+101540>>2]=0;if((c[e+114176>>2]|0)>=0){b=c[e+114176>>2]|0;if((c[e+107976>>2]|0)==0){b=c[e+114236>>2]|0}else{do{if((c[e+114288>>2]|0)==1){if((c[e+111428>>2]|0)==0){f=7;break}b=c[e+114232>>2]|0}else{f=7}}while(0);if((f|0)==7){do{if((c[e+114288>>2]|0)==1){if((c[e+111424>>2]|0)==0){break}b=c[e+114240>>2]|0}}while(0)}}g=b;i=d;return g|0}j=2147483647;if((c[e+107976>>2]|0)==0){k=+h[e+131504>>3]}else{do{if((c[e+114288>>2]|0)==1){if((c[e+111428>>2]|0)==0){if((c[e+111424>>2]|0)==0){f=19;break}}k=+h[e+131512>>3]}else{f=19}}while(0);if((f|0)==19){k=+h[e+131496>>3]}}if((a|0)>=4194303){l=((a|0)/(c[e+107988>>2]|0)|0)<<9}else{l=(a<<9|0)/(c[e+107988>>2]|0)|0}a=c[e+131744>>2]|0;do{m=~~(k*+(c[246888+(c[e+107976>>2]<<9)+(a<<2)>>2]|0)+.5);if((m|0)<=(l|0)){f=26;break}j=m-l|0;n=a+1|0;a=n;}while((n|0)<=(c[e+131736>>2]|0));if((f|0)==26){if((l-m|0)<=(j|0)){b=a}else{b=a-1|0}}if((b|0)>=127){k=.99;o=390625.0e-10;if((c[e+107976>>2]|0)==0){p=0}else{do{if((c[e+114288>>2]|0)==1){if((c[e+111428>>2]|0)==0){if((c[e+111424>>2]|0)==0){f=41;break}if((c[e+114616>>2]|0)!=0){f=41;break}}p=16}else{f=41}}while(0);if((f|0)==41){p=192}}while(1){if((c[e+101540>>2]|0)>=(p|0)){break}a=e+101540|0;c[a>>2]=(c[a>>2]|0)+1;if((c[e+101540>>2]|0)>(p|0)){c[e+101540>>2]=p}m=~~(k*+(m|0));k=k+o;if(k>=.999){k=.999}if((m|0)<=(l|0)){f=50;break}}}g=b;i=d;return g|0}function d$b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;OYb();do{if((c[d+142380>>2]|0)!=2){if((c[d+131484>>2]|0)<=(c[d+131588>>2]|0)){break}a=(c[d+131484>>2]|0)-(c[d+131588>>2]|0)|0;if((c[d+114288>>2]|0)>>>0>1>>>0){e=d+131540|0;c[e>>2]=(c[e>>2]|0)+a}else{e=d+131540|0;c[e>>2]=(c[e>>2]|0)+((a*7|0|0)/8|0);e=d+131532|0;c[e>>2]=(c[e>>2]|0)+((a|0)/8|0)}a=c[d+131540>>2]|0;c[d+131544>>2]=(a|0)/(e$b(d)|0)|0}}while(0);c[d+114736>>2]=0;a=d+131560|0;d=wrc(c[a>>2]|0,c[a+4>>2]|0,1,0)|0;c[a>>2]=d;c[a+4>>2]=G;i=b;return}function e$b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0;b=i;d=a;a=0;e=d+131560|0;if((c[e>>2]|0)==1&(c[e+4>>2]|0)==0){if((c[d+114104>>2]|0)>0){f=c[d+114104>>2]|0}else{f=1}e=f;a=(~~+h[d+131608>>3]<<1)+1|0;do{if((c[d+114100>>2]|0)!=0){if((a|0)<=(e|0)){break}a=e}}while(0);c[d+131584>>2]=a}else{e=0;if((c[d+114736>>2]|0)>>>0>0>>>0){g=c[d+114736>>2]|0}else{g=1}f=g;g=0;while(1){if((g|0)>=5){break}if((g|0)<4){c[d+131568+(g<<2)>>2]=c[d+131568+(g+1<<2)>>2]}else{c[d+131568+(g<<2)>>2]=f}a=a+(ca(c[699536+(g<<2)>>2]|0,c[d+131568+(g<<2)>>2]|0)|0)|0;e=e+(c[699536+(g<<2)>>2]|0)|0;g=g+1|0}a=(a>>>0)/(e>>>0)|0}if((a|0)!=0){j=a;i=b;return j|0}a=1;j=a;i=b;return j|0}function f$b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a;a=b;b=d;if((c[f+114176>>2]|0)>=0){c[a>>2]=0;c[b>>2]=2147483647;i=e;return}if((c[f+107976>>2]|0)==0){c[b>>2]=((c[f+131480>>2]|0)*9|0|0)/8|0;c[a>>2]=((c[f+131480>>2]|0)*7|0|0)/8|0}else{do{if((c[f+114288>>2]|0)>>>0>1>>>0){g=8}else{if((c[f+111428>>2]|0)!=0){g=8;break}if((c[f+111424>>2]|0)!=0){g=8;break}if((c[f+114116>>2]|0)==1){d=f+131688|0;h=c[d>>2]|0;j=c[d+4>>2]|0;d=f+114136|0;k=f+114144|0;l=wrc(c[d>>2]|0,c[d+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;k=G;d=k>>1|((k|0)<0|0?-1:0)<<31;if((j|0)>=(d|0)&((j|0)>(d|0)|h>>>0>=(l>>>1|k<<31)>>>0)){c[b>>2]=((c[f+131480>>2]|0)*12|0|0)/8|0;c[a>>2]=((c[f+131480>>2]|0)*6|0|0)/8|0}else{k=f+131688|0;l=c[k+4>>2]|0;h=f+114136|0;d=c[h+4>>2]|0;j=d>>1|((d|0)<0|0?-1:0)<<31;if((l|0)<=(j|0)&((l|0)<(j|0)|(c[k>>2]|0)>>>0<=((c[h>>2]|0)>>>1|d<<31)>>>0)){c[b>>2]=((c[f+131480>>2]|0)*10|0|0)/8|0;c[a>>2]=(c[f+131480>>2]<<2|0)/8|0}else{c[b>>2]=((c[f+131480>>2]|0)*11|0|0)/8|0;c[a>>2]=((c[f+131480>>2]|0)*5|0|0)/8|0}}}else{if((c[f+114116>>2]|0)==2){c[b>>2]=((c[f+131480>>2]|0)*11|0|0)/8|0;c[a>>2]=(c[f+131480>>2]<<1|0)/8|0}else{c[b>>2]=((c[f+131480>>2]|0)*11|0|0)/8|0;c[a>>2]=((c[f+131480>>2]|0)*5|0|0)/8|0}}}}while(0);if((g|0)==8){c[b>>2]=((c[f+131480>>2]|0)*9|0|0)/8|0;c[a>>2]=((c[f+131480>>2]|0)*7|0|0)/8|0}}f=b;c[f>>2]=(c[f>>2]|0)+200;f=a;c[f>>2]=(c[f>>2]|0)-200;if((c[a>>2]|0)<0){c[a>>2]=0}i=e;return}function g$b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;do{if((c[d+107976>>2]|0)==0){h$b(d)}else{i$b(d);if((c[d+131756>>2]|0)==0){break}c[d+131756>>2]=0;e=0;f=e;i=b;return f|0}}while(0);e=1;f=e;i=b;return f|0}function h$b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0.0;b=i;i=i+8|0;d=b|0;e=a;OYb();if((c[e+114176>>2]|0)>=0){a=k$b(0,c[e+114236>>2]|0,c[e+107988>>2]|0,+h[e+131504>>3])|0;c[d>>2]=a;c[d+4>>2]=(a|0)<0|0?-1:0}else{if((c[e+142380>>2]|0)==2){a=c[e+131588>>2]|0;c[d>>2]=a;c[d+4>>2]=(a|0)<0|0?-1:0}else{if((c[e+113700>>2]|0)==0){a=e+114128|0;f=Crc(c[a>>2]|0,c[a+4>>2]|0,2,0)|0;c[d>>2]=f;c[d+4>>2]=G;f=c[d+4>>2]|0;a=0;if(f>>>0>a>>>0|f>>>0==a>>>0&(c[d>>2]|0)>>>0>((((c[e+114076>>2]|0)*3|0)>>>0)/2|0)>>>0){c[d>>2]=(((c[e+114076>>2]|0)*3|0)>>>0)/2|0;c[d+4>>2]=0}}else{if((c[e+107984>>2]&1|0)!=0){g=c[e+131652>>2]|0}else{g=c[e+131640>>2]|0}a=g;g=32;if((c[e+114288>>2]|0)==1){if((g|0)>(~~(+h[e+131608>>3]*2.0-16.0)|0)){j=g}else{j=~~(+h[e+131608>>3]*2.0-16.0)}k=j}else{k=g}k=(ca(k,c[1035568+(a<<2)>>2]|0)|0)/100|0;if(+((c[e+114736>>2]|0)>>>0>>>0)<+h[e+131608>>3]/2.0){l=+((ca(k,c[e+114736>>2]|0)|0)>>>0>>>0);k=~~(l/(+h[e+131608>>3]/2.0))}if((k|0)<16){k=16}a=(ca(k+16|0,c[e+131588>>2]|0)|0)>>4;c[d>>2]=a;c[d+4>>2]=(a|0)<0|0?-1:0}}}if((c[e+114092>>2]|0)!=0){a=((ca(c[e+131588>>2]|0,c[e+114092>>2]|0)|0)>>>0)/100|0;k=c[d+4>>2]|0;g=0;if(k>>>0>g>>>0|k>>>0==g>>>0&(c[d>>2]|0)>>>0>a>>>0){c[d>>2]=a;c[d+4>>2]=0}}c[e+131480>>2]=c[d>>2];if((c[e+142380>>2]|0)==2){i=b;return}c[e+131736>>2]=c[e+131732>>2];i=b;return}function i$b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;g=a;a=c[g+131588>>2]|0;if((c[g+150216>>2]|0)>>>0>0>>>0){c[g+131588>>2]=c[g+150224+((c[g+150216>>2]|0)*200|0)+64>>2]}j=0;if((c[g+142380>>2]|0)==2){j=c[g+131596>>2]|0;if((j|0)<(c[g+131592>>2]>>5|0)){j=c[g+131592>>2]>>5}}else{if((j|0)<((c[g+131588>>2]|0)/4|0|0)){j=(c[g+131588>>2]|0)/4|0}}do{if((c[g+111428>>2]|0)!=0){if((c[g+114288>>2]|0)!=1){k=15;break}if((c[g+142380>>2]|0)==2){c[g+131588>>2]=c[g+147456>>2];c[g+131480>>2]=c[g+131588>>2]}}else{k=15}}while(0);if((k|0)==15){if((c[g+142380>>2]|0)==2){c[g+131480>>2]=c[g+131588>>2]}else{if((c[g+131540>>2]|0)>0){if((c[g+131544>>2]|0)<=(c[g+131540>>2]|0)){l=c[g+131544>>2]|0}else{l=c[g+131540>>2]|0}m=l;if((m|0)>((c[g+131588>>2]|0)-j|0)){m=(c[g+131588>>2]|0)-j|0}l=g+131540|0;c[l>>2]=(c[l>>2]|0)-m;c[g+131480>>2]=(c[g+131588>>2]|0)-m;if((c[g+131480>>2]|0)<(j|0)){c[g+131480>>2]=j}}else{c[g+131480>>2]=c[g+131588>>2]}do{if((c[g+131532>>2]|0)>0){if((c[g+131480>>2]|0)<=(j|0)){break}if((c[g+131536>>2]|0)<=(c[g+131532>>2]|0)){n=c[g+131536>>2]|0}else{n=c[g+131532>>2]|0}m=n;if((m|0)>((c[g+131480>>2]|0)-j|0)){m=(c[g+131480>>2]|0)-j|0}l=g+131532|0;c[l>>2]=(c[l>>2]|0)-m;l=g+131480|0;c[l>>2]=(c[l>>2]|0)-m}}while(0);do{if((c[g+142328>>2]|0)>150){if((c[g+131524>>2]|0)<=0){break}if((c[g+131528>>2]|0)<8){break}m=(c[g+142328>>2]|0)-100>>5;if((m|0)<1){m=1}else{if((m|0)>10){m=10}}m=(ca(c[g+131480>>2]|0,m)|0)/100|0;if((m|0)>((c[g+131480>>2]|0)-j|0)){m=(c[g+131480>>2]|0)-j|0}if((c[g+131520>>2]|0)==(c[g+131528>>2]>>1|0)){n=ca((c[g+131528>>2]|0)-1|0,m)|0;l=g+131480|0;c[l>>2]=(c[l>>2]|0)+n}else{n=g+131480|0;c[n>>2]=(c[n>>2]|0)-m}}}while(0)}}if((c[g+131480>>2]|0)<(j|0)){c[g+131480>>2]=j}if((c[g+111428>>2]|0)==0){c[g+131600>>2]=c[g+131480>>2]}if((c[g+142380>>2]|0)==0){if((c[g+131664>>2]|0)!=0){j=g+114136|0;m=Crc(c[j>>2]|0,c[j+4>>2]|0,100,0)|0;j=wrc(1,0,m,G)|0;m=j;j=g+131688|0;n=c[j+4>>2]|0;l=g+114136|0;o=c[l+4>>2]|0;do{if((n|0)<(o|0)|(n|0)==(o|0)&(c[j>>2]|0)>>>0<(c[l>>2]|0)>>>0){k=59}else{p=g+131696|0;q=c[p+4>>2]|0;r=g+114136|0;s=c[r+4>>2]|0;if((q|0)<(s|0)|(q|0)==(s|0)&(c[p>>2]|0)>>>0<(c[r>>2]|0)>>>0){k=59;break}r=0;do{if((c[g+114116>>2]|0)==1){p=g+131688|0;s=c[p+4>>2]|0;q=g+114136|0;t=c[q+4>>2]|0;if(!((s|0)>(t|0)|(s|0)==(t|0)&(c[p>>2]|0)>>>0>(c[q>>2]|0)>>>0)){k=90;break}q=g+131688|0;p=g+114136|0;t=xrc(c[q>>2]|0,c[q+4>>2]|0,c[p>>2]|0,c[p+4>>2]|0)|0;p=m;q=Crc(t,G,p,(p|0)<0|0?-1:0)|0;r=q}else{k=90}}while(0);if((k|0)==90){q=g+131696|0;p=c[q+4>>2]|0;t=g+114136|0;s=c[t+4>>2]|0;if((p|0)>(s|0)|(p|0)==(s|0)&(c[q>>2]|0)>>>0>(c[t>>2]|0)>>>0){t=g+131696|0;q=Erc(100,0,c[t>>2]|0,c[t+4>>2]|0)|0;t=G;s=g+131656|0;p=Erc(c[s>>2]|0,c[s+4>>2]|0,8,0)|0;s=Crc(q,t,p,G)|0;r=s}}if((r|0)>(c[g+114124>>2]|0)){r=c[g+114124>>2]|0}else{if((r|0)<0){r=0}}s=(ca(c[g+131480>>2]|0,r)|0)/200|0;p=g+131480|0;c[p>>2]=(c[p>>2]|0)+s;do{if((c[g+142372>>2]|0)!=0){if((c[g+131648>>2]|0)<=150){k=101;break}c[g+131736>>2]=c[g+131640>>2]}else{k=101}}while(0);if((k|0)==101){c[g+131736>>2]=c[g+131732>>2]}}}while(0);if((k|0)==59){l=0;do{if((c[g+114116>>2]|0)==1){j=g+131688|0;o=c[j+4>>2]|0;n=g+114136|0;r=c[n+4>>2]|0;if(!((o|0)<(r|0)|(o|0)==(r|0)&(c[j>>2]|0)>>>0<(c[n>>2]|0)>>>0)){k=62;break}n=g+114136|0;j=g+131688|0;r=xrc(c[n>>2]|0,c[n+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;j=m;n=Crc(r,G,j,(j|0)<0|0?-1:0)|0;l=n}else{k=62}}while(0);if((k|0)==62){m=g+131696|0;n=c[m+4>>2]|0;j=0;if((n|0)<(j|0)|(n|0)==(j|0)&(c[m>>2]|0)>>>0<0>>>0){m=g+131696|0;j=xrc(0,0,c[m>>2]|0,c[m+4>>2]|0)|0;m=Erc(100,0,j,G)|0;j=G;n=g+131656|0;r=Erc(c[n>>2]|0,c[n+4>>2]|0,8,0)|0;n=Crc(m,j,r,G)|0;l=n}}if((l|0)>(c[g+114120>>2]|0)){l=c[g+114120>>2]|0}else{if((l|0)<0){l=0}}n=(ca(c[g+131480>>2]|0,l)|0)/200|0;l=g+131480|0;c[l>>2]=(c[l>>2]|0)-n;do{if((c[g+142372>>2]|0)!=0){if((c[g+131648>>2]|0)<=150){k=85;break}if((c[g+114116>>2]|0)==1){n=g+131688|0;l=c[n+4>>2]|0;r=g+131696|0;j=c[r+4>>2]|0;if((l|0)<(j|0)|(l|0)==(j|0)&(c[n>>2]|0)>>>0<(c[r>>2]|0)>>>0){r=g+131688|0;u=c[r+4>>2]|0;v=c[r>>2]|0}else{r=g+131696|0;u=c[r+4>>2]|0;v=c[r>>2]|0}c[d>>2]=v;c[d+4>>2]=u}else{r=g+131696|0;n=c[r+4>>2]|0;c[d>>2]=c[r>>2];c[d+4>>2]=n}n=c[d+4>>2]|0;r=g+114136|0;j=c[r+4>>2]|0;if((n|0)<(j|0)|(n|0)==(j|0)&(c[d>>2]|0)>>>0<(c[r>>2]|0)>>>0){r=c[d+4>>2]|0;j=g+114136|0;n=c[j+4>>2]|0;l=n>>2|((n|0)<0|0?-1:0)<<30;if((r|0)>(l|0)|(r|0)==(l|0)&(c[d>>2]|0)>>>0>((c[j>>2]|0)>>>2|n<<30)>>>0){n=(c[g+131732>>2]|0)-(c[g+131640>>2]|0)|0;c[e>>2]=n;c[e+4>>2]=(n|0)<0|0?-1:0;n=g+114136|0;j=c[n+4>>2]|0;l=xrc(c[d>>2]|0,c[d+4>>2]|0,(c[n>>2]|0)>>>2|j<<30,j>>2|((j|0)<0|0?-1:0)<<30)|0;c[f>>2]=l;c[f+4>>2]=G;l=c[g+131732>>2]|0;j=Erc(c[e>>2]|0,c[e+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;n=G;r=g+114136|0;m=Erc(c[r>>2]|0,c[r+4>>2]|0,3,0)|0;r=G;o=Crc(j,n,m>>>2|r<<30,r>>2|((r|0)<0|0?-1:0)<<30)|0;c[g+131736>>2]=l-o}else{c[g+131736>>2]=c[g+131732>>2]}}else{c[g+131736>>2]=c[g+131640>>2]}}else{k=85}}while(0);if((k|0)==85){c[g+131736>>2]=c[g+131732>>2]}}c[g+131744>>2]=c[g+131740>>2];if((c[g+131736>>2]|0)<=(c[g+131744>>2]|0)){c[g+131736>>2]=(c[g+131744>>2]|0)+1}if((c[g+131736>>2]|0)>127){c[g+131736>>2]=127}}else{c[g+131736>>2]=c[g+131732>>2]}do{if((c[g+114116>>2]|0)==2){if((c[g+131736>>2]|0)>=(c[g+131748>>2]|0)){break}c[g+131736>>2]=c[g+131748>>2]}}while(0)}do{if((c[g+131752>>2]|0)!=0){if((c[g+114116>>2]|0)!=1){break}if((c[g+107976>>2]|0)==0){break}f=g+131688|0;e=c[f+4>>2]|0;d=0;if((e|0)<(d|0)|(e|0)==(d|0)&(c[f>>2]|0)>>>0<0>>>0){c[g+131756>>2]=1;f=c[g+131592>>2]|0;d=g+131696|0;e=wrc(c[d>>2]|0,c[d+4>>2]|0,f,(f|0)<0|0?-1:0)|0;c[d>>2]=e;c[d+4>>2]=G;d=g+131696|0;e=c[d+4>>2]|0;f=g+114144|0;u=c[f+4>>2]|0;if((e|0)>(u|0)|(e|0)==(u|0)&(c[d>>2]|0)>>>0>(c[f>>2]|0)>>>0){f=c[g+114144>>2]|0;d=g+131696|0;c[d>>2]=f;c[d+4>>2]=(f|0)<0|0?-1:0}f=g+131696|0;d=c[f+4>>2]|0;u=g+131688|0;c[u>>2]=c[f>>2];c[u+4>>2]=d;if((c[g+114288>>2]|0)>>>0>1>>>0){d=(c[g+150216>>2]|0)+1|0;while(1){if(!(d>>>0<(c[g+114288>>2]|0)>>>0)){break}u=g+150224+(d*200|0)|0;f=~~(+(c[u+8>>2]|0)/+h[u>>3]);e=u+80|0;v=wrc(c[e>>2]|0,c[e+4>>2]|0,f,(f|0)<0|0?-1:0)|0;c[e>>2]=v;c[e+4>>2]=G;e=u+80|0;v=c[e+4>>2]|0;f=u+32|0;o=c[f+4>>2]|0;if((v|0)>(o|0)|(v|0)==(o|0)&(c[e>>2]|0)>>>0>(c[f>>2]|0)>>>0){f=u+32|0;e=c[f+4>>2]|0;o=u+80|0;c[o>>2]=c[f>>2];c[o+4>>2]=e}e=u+80|0;o=c[e+4>>2]|0;f=u+72|0;c[f>>2]=c[e>>2];c[f+4>>2]=o;d=d+1|0}}}}}while(0);if((c[g+114256>>2]|0)!=0){w=a;x=g;y=x+131588|0;c[y>>2]=w;i=b;return}if((c[g+131524>>2]|0)!=0){w=a;x=g;y=x+131588|0;c[y>>2]=w;i=b;return}if((c[g+131756>>2]|0)!=0){w=a;x=g;y=x+131588|0;c[y>>2]=w;i=b;return}if((c[g+114176>>2]|0)<0){z=c[g+131492>>2]|0}else{z=c[g+114176>>2]|0}d=z;z=0;o=(c[g+142424>>2]|0)+(c[g+142428>>2]|0)+(c[g+142432>>2]|0)+(c[g+142436>>2]|0)|0;f=((c[g+149728>>2]|0)*100|0|0)/(ca(c[g+107992>>2]|0,c[g+107996>>2]|0)|0)|0;if((o|0)!=0){z=(((c[g+142432>>2]|0)+(c[g+142436>>2]|0)|0)*100|0|0)/(o|0)|0}if((f|0)>(z|0)){z=f}if((c[g+142364>>2]|0)!=0){do{if((c[g+142380>>2]|0)==0){if((c[g+142440>>2]|0)>=15){if((z|0)<5){k=144;break}}c[g+111424>>2]=1}else{k=144}}while(0);if((k|0)==144){if((c[g+142380>>2]|0)==2){c[g+111424>>2]=1}}}if((c[g+111424>>2]|0)==1){if((c[g+142368>>2]|0)!=0){j$b(g)}if((c[g+114616>>2]|0)!=0){c[g+131480>>2]=0}else{if((c[g+114176>>2]|0)<0){if((c[g+142380>>2]|0)==2){c[g+131480>>2]=c[g+131588>>2]}else{k=c[g+142328>>2]|0;z=(c[g+131524>>2]|0)+1|0;f=(z*100|0)+(k-100)|0;o=ca(c[g+131600>>2]|0,z)|0;while(1){if((k|0)<=1e3){break}k=(k|0)/2|0;f=(f|0)/2|0}if((o>>7|0)>(f|0)){c[g+131480>>2]=ca(k,(o|0)/(f|0)|0)|0}else{c[g+131480>>2]=(ca(k,o)|0)/(f|0)|0}}}else{f=k$b(1,d,c[g+107988>>2]|0,1.0)|0;c[g+131480>>2]=(ca(f,c[g+142328>>2]|0)|0)/100|0}}c[g+131528>>2]=c[g+131524>>2]}w=a;x=g;y=x+131588|0;c[y>>2]=w;i=b;return}function j$b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a;if((c[d+114176>>2]|0)<0){e=c[d+131492>>2]|0}else{e=c[d+114176>>2]|0}a=e;e=0;f=0;g=(c[d+142424>>2]|0)+(c[d+142428>>2]|0)+(c[d+142432>>2]|0)+(c[d+142436>>2]|0)|0;h=((c[d+149728>>2]|0)*100|0|0)/(ca(c[d+107992>>2]|0,c[d+107996>>2]|0)|0)|0;if((g|0)!=0){f=(((c[d+142432>>2]|0)+(c[d+142436>>2]|0)|0)*100|0|0)/(g|0)|0}if((h|0)>(f|0)){f=h}if((c[d+142380>>2]|0)!=2){e=c[244320+(a<<2)>>2]|0;if((c[d+142440>>2]|0)<15){j=c[d+142440>>2]|0}else{j=14}e=(ca(e,c[1148072+(j<<2)>>2]|0)|0)/100|0;e=(ca(e,c[1148696+(f<<2)>>2]|0)|0)/100|0;if((c[d+142472>>2]|0)==0){if((c[d+142360>>2]|0)==2){e=(e|0)/2|0}}do{if((e|0)>(c[1035056+(a<<2)>>2]|0)){if((c[d+142380>>2]|0)!=0){k=19;break}e=c[1035056+(a<<2)>>2]|0}else{k=19}}while(0);if((k|0)==19){if((e|0)<110){e=110}}c[d+142328>>2]=e}if((c[d+114176>>2]|0)==-1){if((c[d+142380>>2]|0)==2){c[d+131524>>2]=c[d+131552>>2]}else{c[d+131524>>2]=c[d+131552>>2];if((c[d+142328>>2]|0)>750){e=d+131524|0;c[e>>2]=(c[e>>2]|0)+1}if((c[d+142328>>2]|0)>1e3){e=d+131524|0;c[e>>2]=(c[e>>2]|0)+1}if((c[d+142328>>2]|0)>1250){e=d+131524|0;c[e>>2]=(c[e>>2]|0)+1}if((c[d+142328>>2]|0)>=1500){e=d+131524|0;c[e>>2]=(c[e>>2]|0)+1}if((c[1148152+(f<<2)>>2]|0)>(c[d+131524>>2]|0)){c[d+131524>>2]=c[1148152+(f<<2)>>2]}if((c[d+131524>>2]|0)>(c[d+131548>>2]|0)){c[d+131524>>2]=c[d+131548>>2]}}}else{c[d+131524>>2]=c[d+131552>>2]}if((c[d+142380>>2]|0)==2){i=b;return}c[d+114612>>2]=0;i=b;return}function k$b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=+e;var f=0,g=0,h=0,j=0;f=i;g=d;d=~~(e*+(c[246888+(a<<9)+(b<<2)>>2]|0)+.5);if((g|0)>2048){h=ca(d>>9,g)|0;j=h;i=f;return j|0}else{h=(ca(d,g)|0)>>9;j=h;i=f;return j|0}return 0}function l$b(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[d+80092>>2]=c[612880+(a<<2)>>2];c[d+80096>>2]=c[612368+(a<<2)>>2];i=i;return}function m$b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0.0,h=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=a;a=b;b=d;if((b|0)<160){g=+(b|0)}else{g=160.0}h=g;g=2.8;OYb();c[f+114916>>2]=~~(g*h*h);if((c[f+101540>>2]|0)>0){j=+(~~(h*(+(c[f+101540>>2]|0)*.0015625+1.0))|0);c[f+114916>>2]=~~(g*j*j)}do{if((c[f+142380>>2]|0)==2){if((c[f+107976>>2]|0)==0){break}if((c[f+146872>>2]|0)>>>0>31>>>0){d=(ca(c[f+114916>>2]|0,c[170597]|0)|0)>>4;k=f+114916|0;c[k>>2]=(c[k>>2]|0)+d}else{d=(ca(c[f+114916>>2]|0,c[682264+(c[f+146872>>2]<<2)>>2]|0)|0)>>4;k=f+114916|0;c[k>>2]=(c[k>>2]|0)+d}}}while(0);c[f+80088>>2]=(c[f+114916>>2]|0)/110|0;d=f+80088|0;c[d>>2]=(c[d>>2]|0)+((c[f+80088>>2]|0)==0);hZb(f);d=0;while(1){if((d|0)>=20){break}c[a+27716+(d<<2)>>2]=0;d=d+1|0}k=~~+T(+(+(b|0)),1.25);if((k|0)<8){k=8}if((c[f+114916>>2]|0)>1e3){c[f+114920>>2]=1;b=f+114916|0;c[b>>2]=(c[b>>2]|0)/100|0;d=0;while(1){if((d|0)>=20){break}if((c[f+142488+(d<<2)>>2]|0)<2147483647){c[a+27632+(d<<2)>>2]=(ca(c[f+142488+(d<<2)>>2]|0,k)|0)/100|0}else{c[a+27632+(d<<2)>>2]=2147483647}c[f+114836+(d<<2)>>2]=c[a+27632+(d<<2)>>2];d=d+1|0}}else{c[f+114920>>2]=100;d=0;while(1){if((d|0)>=20){break}if((c[f+142488+(d<<2)>>2]|0)<(2147483647/(k|0)|0|0)){c[a+27632+(d<<2)>>2]=ca(c[f+142488+(d<<2)>>2]|0,k)|0}else{c[a+27632+(d<<2)>>2]=2147483647}c[f+114836+(d<<2)>>2]=c[a+27632+(d<<2)>>2];d=d+1|0}}d=f+143512|0;if((c[f+111428>>2]|0)!=0){d=f+144625|0;l=f;m=l+73728|0;n=m+6428|0;o=c[n>>2]|0;p=d;q=p+19|0;r=q|0;n$b(o,r);s=f;Rdc(s);i=e;return}if((c[f+111424>>2]|0)!=0){d=f+145738|0}l=f;m=l+73728|0;n=m+6428|0;o=c[n>>2]|0;p=d;q=p+19|0;r=q|0;n$b(o,r);s=f;Rdc(s);i=e;return}function n$b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>=4){break}e=0;while(1){if((e|0)>=8){break}f=0;while(1){if((f|0)>=3){break}do{if((f|0)==0){if((e|0)<=((b|0)==0|0)){g=10;break}y0b(d+(b*1152|0)+(e*144|0)+(f*48|0)|0,a+(b*264|0)+(e*33|0)+(f*11|0)|0,246568,2)}else{g=10}}while(0);if((g|0)==10){g=0;w0b(d+(b*1152|0)+(e*144|0)+(f*48|0)|0,a+(b*264|0)+(e*33|0)+(f*11|0)|0,246568)}f=f+1|0}e=e+1|0}b=b+1|0}i=c;return}function o$b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=~~(1.0e6/+h[d+131672>>3]);a=(ca(a,16-(c[d+114088>>2]|0)|0)|0)/16|0;do{if((c[d+142352>>2]|0)<(a|0)){if(((c[d+142348>>2]|0)-(c[d+142352>>2]|0)|0)>=(a|0)){break}if((c[d+142352>>2]|0)==0){c[d+142356>>2]=4}else{if((a*100|0|0)<((c[d+142348>>2]|0)*95|0|0)){e=d+142356|0;c[e>>2]=(c[e>>2]|0)+2;c[d+142352>>2]=0;c[d+142348>>2]=0;if((c[d+142356>>2]|0)>16){c[d+142356>>2]=16}}if((a*100|0|0)>(ca(c[d+142348>>2]|0,c[2004424+(c[d+142356>>2]<<2)>>2]|0)|0)){e=d+142356|0;c[e>>2]=(c[e>>2]|0)-1;c[d+142352>>2]=0;c[d+142348>>2]=0;if((c[d+142356>>2]|0)<4){c[d+142356>>2]=4}}}i=b;return}}while(0);a=d+142356|0;c[a>>2]=(c[a>>2]|0)+4;if((c[d+142356>>2]|0)>16){c[d+142356>>2]=16}c[d+142352>>2]=0;c[d+142348>>2]=0;i=b;return}function p$b(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=c;c=0;f=0;while(1){if((f|0)>=16){break}g=(b[e+(f<<1)>>1]|0)-(b[a+(f<<1)>>1]|0)|0;c=c+(ca(g,g)|0)|0;f=f+1|0}i=d;return c|0}function q$b(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=a;a=d;d=0;g=0;while(1){if((g|0)>=16){break}h=f+1860+(g*48|0)|0;j=f+5296+(g*28|0)|0;k=0;l=a;while(1){if((l|0)>=16){break}m=(b[(c[h+4>>2]|0)+(l<<1)>>1]|0)-(b[(c[j+4>>2]|0)+(l<<1)>>1]|0)|0;k=k+(ca(m,m)|0)|0;l=l+1|0}d=d+k|0;g=g+1|0}i=e;return d|0}function r$b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=0;e=16;while(1){if((e|0)>=24){break}a=a+(p$b(c[d+1860+(e*48|0)+4>>2]|0,c[d+5296+(e*28|0)+4>>2]|0)|0)|0;e=e+1|0}i=b;return a|0}function s$b(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a;a=(c[c[g+2664>>2]>>2]|0)+(c[g+2668>>2]|0)|0;h=(c[c[g+2856>>2]>>2]|0)+(c[g+2860>>2]|0)|0;j=c[g+2672>>2]|0;c[e>>2]=0;c[f>>2]=0;k=b[(c[g+6184>>2]|0)+4>>1]|0;l=b[(c[g+6184>>2]|0)+6>>1]|0;m=c[g+6036>>2]|0;if((k|0)<0){k=k-1|0}else{k=k+1|0}if((l|0)<0){l=l-1|0}else{l=l+1|0}k=(k|0)/2|0;l=(l|0)/2|0;n=(ca(k>>3,m)|0)+(l>>3)|0;o=(c[g+6056>>2]|0)+n|0;p=(c[g+6060>>2]|0)+n|0;if(((k|l)&7|0)!=0){L9b(o,m,l&7,k&7,a,j,f)|0;L9b(p,m,l&7,k&7,h,j,e)|0;c[f>>2]=(c[f>>2]|0)+(c[e>>2]|0);q=c[f>>2]|0;i=d;return q|0}else{F9b(o,m,a,j,f)|0;F9b(p,m,h,j,e)|0;c[f>>2]=(c[f>>2]|0)+(c[e>>2]|0);q=c[f>>2]|0;i=d;return q|0}return 0}function t$b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=i;i=i+8|0;d=c|0;e=a;a=b;if(5>>>0<=e>>>0){if(e>>>0<=9>>>0){}else{f=3}}else{f=3}if((f|0)==3){Cd(2347336,2562608,932,2651008);return 0}a8b(d|0,a)|0;a=u$b(242504,d|0,242512+(e-5<<3)|0)|0;i=c;return a|0}function u$b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=d;d=g0b(a,b,c[f>>2]|0,c[f+4>>2]|0)|0;i=e;return d|0}function v$b(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b;a[c[f+6184>>2]|0]=d;c[(c[f+6184>>2]|0)+4>>2]=c[e>>2];i=i;return}function w$b(a,e,f,g,h,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=i;i=i+136|0;n=m|0;o=m+32|0;p=m+64|0;q=m+72|0;r=m+104|0;s=a;a=e;e=f;f=g;g=h;h=j;j=k;k=l;l=e+((-(c[a+3036>>2]|0)|0)*76|0)|0;t=e-76|0;u=l-76|0;v=0;w=0;c[p>>2]=0;if((d[e+2|0]|0)==0){x=p;y=c[x>>2]|0;z=f;A=z;c[A>>2]=y;B=f;C=a;z$b(B,C);i=m;return}c[n+28>>2]=0;c[n+24>>2]=0;c[n+20>>2]=0;c[n+16>>2]=0;c[n+12>>2]=0;c[n+8>>2]=0;c[n+4>>2]=0;c[n>>2]=0;c[o+28>>2]=0;c[o+24>>2]=0;c[o+20>>2]=0;c[o+16>>2]=0;c[o+12>>2]=0;c[o+8>>2]=0;c[o+4>>2]=0;c[o>>2]=0;if((d[l+2|0]|0)!=0){c[n+(v<<2)>>2]=c[l+4>>2];x$b(c[h+(d[l+2|0]<<2)>>2]|0,g,n+(v<<2)|0,h);c[o+(v<<2)>>2]=d[l+2|0]|0}v=v+1|0;if((d[t+2|0]|0)!=0){c[n+(v<<2)>>2]=c[t+4>>2];x$b(c[h+(d[t+2|0]<<2)>>2]|0,g,n+(v<<2)|0,h);c[o+(v<<2)>>2]=d[t+2|0]|0}v=v+1|0;if((d[u+2|0]|0)!=0){c[n+(v<<2)>>2]=c[u+4>>2];x$b(c[h+(d[u+2|0]<<2)>>2]|0,g,n+(v<<2)|0,h);c[o+(v<<2)>>2]=d[u+2|0]|0}v=v+1|0;if((c[s+107972>>2]|0)!=0){u=ca(((-(c[a+3136>>2]|0)|0)/128|0)+1|0,(c[a+3036>>2]|0)+1|0)|0;t=u+(((-(c[a+3128>>2]|0)|0)/128|0)+1)|0;if((c[(c[s+149744>>2]|0)+(t<<2)>>2]|0)!=0){c[n+(v<<2)>>2]=c[(c[s+149736>>2]|0)+(t<<2)>>2];x$b(c[(c[s+149740>>2]|0)+(t<<2)>>2]|0,g,n+(v<<2)|0,h);c[o+(v<<2)>>2]=c[(c[s+149744>>2]|0)+(t<<2)>>2]}v=v+1|0;if((c[(c[s+149744>>2]|0)+(t-(c[a+3036>>2]|0)-1<<2)>>2]|0)!=0){c[n+(v<<2)>>2]=c[(c[s+149736>>2]|0)+(t-(c[a+3036>>2]|0)-1<<2)>>2];x$b(c[(c[s+149740>>2]|0)+(t-(c[a+3036>>2]|0)-1<<2)>>2]|0,g,n+(v<<2)|0,h);c[o+(v<<2)>>2]=c[(c[s+149744>>2]|0)+(t-(c[a+3036>>2]|0)-1<<2)>>2]}v=v+1|0;if((c[(c[s+149744>>2]|0)+(t-1<<2)>>2]|0)!=0){c[n+(v<<2)>>2]=c[(c[s+149736>>2]|0)+(t-1<<2)>>2];x$b(c[(c[s+149740>>2]|0)+(t-1<<2)>>2]|0,g,n+(v<<2)|0,h);c[o+(v<<2)>>2]=c[(c[s+149744>>2]|0)+(t-1<<2)>>2]}v=v+1|0;if((c[(c[s+149744>>2]|0)+(t+1<<2)>>2]|0)!=0){c[n+(v<<2)>>2]=c[(c[s+149736>>2]|0)+(t+1<<2)>>2];x$b(c[(c[s+149740>>2]|0)+(t+1<<2)>>2]|0,g,n+(v<<2)|0,h);c[o+(v<<2)>>2]=c[(c[s+149744>>2]|0)+(t+1<<2)>>2]}v=v+1|0;if((c[(c[s+149744>>2]|0)+(t+(c[a+3036>>2]|0)+1<<2)>>2]|0)!=0){c[n+(v<<2)>>2]=c[(c[s+149736>>2]|0)+(t+(c[a+3036>>2]|0)+1<<2)>>2];x$b(c[(c[s+149740>>2]|0)+(t+(c[a+3036>>2]|0)+1<<2)>>2]|0,g,n+(v<<2)|0,h);c[o+(v<<2)>>2]=c[(c[s+149744>>2]|0)+(t+(c[a+3036>>2]|0)+1<<2)>>2]}v=v+1|0}t=0;while(1){if((t|0)>=(v|0)){break}if((c[o+(c[k+(t<<2)>>2]<<2)>>2]|0)!=0){if((d[e+2|0]|0)==(c[o+(c[k+(t<<2)>>2]<<2)>>2]|0)){D=24;break}}t=t+1|0}if((D|0)==24){c[p>>2]=c[n+(c[k+(t<<2)>>2]<<2)>>2];w=1;if((t|0)<3){c[j>>2]=3}else{c[j>>2]=2}}if((w|0)==0){t=0;while(1){if((t|0)>=(v|0)){break}c[q+(t<<2)>>2]=b[n+(t<<2)>>1]|0;c[r+(t<<2)>>2]=b[n+(t<<2)+2>>1]|0;t=t+1|0}y$b(q|0,v);y$b(r|0,v);b[p>>1]=c[q+(((v|0)/2|0)<<2)>>2];b[p+2>>1]=c[r+(((v|0)/2|0)<<2)>>2];w=1;c[j>>2]=0}x=p;y=c[x>>2]|0;z=f;A=z;c[A>>2]=y;B=f;C=a;z$b(B,C);i=m;return}function x$b(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=e;if((a|0)==(c[f+(d<<2)>>2]|0)){i=g;return}d=h|0;b[d>>1]=(b[d>>1]|0)*-1|0;d=h+2|0;b[d>>1]=(b[d>>1]|0)*-1|0;i=g;return}function y$b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=1;while(1){if((b|0)>(a-1|0)){break}f=0;while(1){if((f|0)>=(b|0)){break}if((c[e+(f<<2)>>2]|0)>(c[e+(b<<2)>>2]|0)){g=c[e+(b<<2)>>2]|0;h=b;while(1){if((h|0)<=(f|0)){break}c[e+(h<<2)>>2]=c[e+(h-1<<2)>>2];h=h-1|0}c[e+(f<<2)>>2]=g}f=f+1|0}b=b+1|0}i=d;return}function z$b(a,d){a=a|0;d=d|0;var e=0,f=0;e=i;f=a;a=d;if((b[f+2>>1]|0)<((c[a+3128>>2]|0)-128|0)){b[f+2>>1]=(c[a+3128>>2]|0)-128}else{if((b[f+2>>1]|0)>((c[a+3132>>2]|0)+128|0)){b[f+2>>1]=(c[a+3132>>2]|0)+128}}if((b[f>>1]|0)<((c[a+3136>>2]|0)-128|0)){b[f>>1]=(c[a+3136>>2]|0)-128;i=e;return}if((b[f>>1]|0)>((c[a+3140>>2]|0)+128|0)){b[f>>1]=(c[a+3140>>2]|0)+128}i=e;return}function A$b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+32|0;h=g|0;j=a;a=b;b=e;e=f;mrc(h|0,0,32)|0;f=d+1860|0;d=c[c[f+36>>2]>>2]|0;do{if((c[a+3136>>2]|0)==0){if((c[a+3128>>2]|0)!=0){k=4;break}c[h+8>>2]=2147483647;c[h+4>>2]=2147483647;c[h>>2]=2147483647}else{k=4}}while(0);if((k|0)==4){if((c[a+3136>>2]|0)==0){c[h+8>>2]=2147483647;c[h>>2]=2147483647;c[h+4>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,(c[a+2992>>2]|0)-16|0,c[a+2956>>2]|0,-1)|0}else{if((c[a+3128>>2]|0)==0){c[h+8>>2]=2147483647;c[h+4>>2]=2147483647;c[h>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,(c[a+2992>>2]|0)+(-(c[a+2956>>2]<<4)|0)|0,c[a+2956>>2]|0,-1)|0}else{c[h>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,(c[a+2992>>2]|0)+(-(c[a+2956>>2]<<4)|0)|0,c[a+2956>>2]|0,-1)|0;c[h+4>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,(c[a+2992>>2]|0)-16|0,c[a+2956>>2]|0,-1)|0;c[h+8>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,(c[a+2992>>2]|0)+(-(c[a+2956>>2]<<4)|0)-16|0,c[a+2956>>2]|0,-1)|0}}}if((c[j+107972>>2]|0)!=0){k=(c[j+107480+((c[j+107868>>2]|0)*92|0)+52>>2]|0)+b|0;b=c[j+107480+((c[j+107868>>2]|0)*92|0)+16>>2]|0;if((c[a+3136>>2]|0)==0){c[h+16>>2]=2147483647}if((c[a+3128>>2]|0)==0){c[h+20>>2]=2147483647}if((c[a+3132>>2]|0)==0){c[h+24>>2]=2147483647}if((c[a+3140>>2]|0)==0){c[h+28>>2]=2147483647}if((c[h+16>>2]|0)!=2147483647){c[h+16>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,k+(-(b<<4)|0)|0,b,-1)|0}if((c[h+20>>2]|0)!=2147483647){c[h+20>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,k-16|0,b,-1)|0}c[h+12>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,k,b,-1)|0;if((c[h+24>>2]|0)!=2147483647){c[h+24>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,k+16|0,b,-1)|0}if((c[h+28>>2]|0)!=2147483647){c[h+28>>2]=Xe[c[j+142932>>2]&511](d,c[f+44>>2]|0,k+(b<<4)|0,b,-1)|0}}if((c[j+107972>>2]|0)!=0){B$b(h|0,e,8);i=g;return}else{B$b(h|0,e,3);i=g;return}}function B$b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=d;d=1;while(1){if((d|0)>(b-1|0)){break}g=0;while(1){if((g|0)>=(d|0)){break}if((c[f+(g<<2)>>2]|0)>(c[f+(d<<2)>>2]|0)){h=c[f+(d<<2)>>2]|0;j=c[a+(d<<2)>>2]|0;k=d;while(1){if((k|0)<=(g|0)){break}c[f+(k<<2)>>2]=c[f+(k-1<<2)>>2];c[a+(k<<2)>>2]=c[a+(k-1<<2)>>2];k=k-1|0}c[f+(g<<2)>>2]=h;c[a+(g<<2)>>2]=j}g=g+1|0}d=d+1|0}i=e;return}function C$b(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;m=i;i=i+608|0;n=m|0;o=m+8|0;p=m+88|0;q=m+96|0;r=m+104|0;s=m+328|0;t=m+344|0;u=m+352|0;v=m+376|0;w=m+384|0;x=m+392|0;y=m+400|0;z=m+408|0;A=m+440|0;B=m+448|0;C=m+496|0;D=m+512|0;E=m+520|0;F=m+528|0;G=m+536|0;H=m+544|0;I=m+552|0;J=m+560|0;K=m+568|0;L=m+576|0;M=m+584|0;N=m+592|0;O=m+600|0;P=e;e=f;f=g;g=h;h=j;j=k;k=l;l=e+1860|0;Q=e+5296|0;R=e+3152|0;S=0;T=0;U=0;V=0;nrc(z|0,238720,32)|0;W=0;c[A>>2]=0;X=0;Y=(I8b(c[P+108020>>2]|0,c[P+108024>>2]|0)|0)*10|0;Z=2147483647;c[D>>2]=2147483647;_=2147483647;$=o+(X*40|0)|0;c[p>>2]=0;c[r+4>>2]=2147483647;c[r>>2]=2147483647;c[r+8>>2]=2147483647;mrc(o|0,0,80)|0;mrc(r+12|0,0,12)|0;mrc(r+24|0,0,64)|0;D$b(P,C|0);if((c[C+4>>2]|0)>0){X=_7b(e+3152|0,c[e+6184>>2]|0,o|0,n|0,s|0,c[C+4>>2]|0,P+111444|0)|0;$=o+(X*40|0)|0;c[p>>2]=c[n+(X<<2)>>2]}E$b(P,B|0,f,g);c[k>>2]=2147483647;aa=e+27712|0;c[aa>>2]=(c[aa>>2]|0)+1;c[e+6448>>2]=0;aa=0;a:while(1){if((aa|0)>=20){break}ba=2147483647;c[E>>2]=0;c[F>>2]=0;da=c[C+(c[238640+(aa<<2)>>2]<<2)>>2]|0;b:do{if((c[r+4>>2]|0)>(c[e+27632+(aa<<2)>>2]|0)){if((da|0)<0){break}c[u>>2]=0;c[u+12>>2]=0;ea=c[242592+(aa<<2)>>2]|0;a[c[e+6184>>2]|0]=ea;a[(c[e+6184>>2]|0)+2|0]=da;c:do{if((c[P+114620>>2]|0)!=0){if((c[P+114260>>2]|0)!=0){break}do{if((ea|0)==7){if((d[(c[e+6184>>2]|0)+2|0]|0)!=3){break}break c}}while(0);break b}}while(0);if((a[(c[e+6184>>2]|0)+2|0]|0)!=0){c[e+6052>>2]=c[B+(da*12|0)>>2];c[e+6056>>2]=c[B+(da*12|0)+4>>2];c[e+6060>>2]=c[B+(da*12|0)+8>>2];if((X|0)!=(c[P+111444+(da<<2)>>2]|0)){X=c[P+111444+(da<<2)>>2]|0;$=o+(X*40|0)|0;c[p>>2]=c[n+(X<<2)>>2]}}do{if((c[e+27716+(aa<<2)>>2]|0)!=0){if(!((c[P+114756+(aa<<2)>>2]|0)>>>0>1>>>0)){break}if(!((c[e+27712>>2]|0)>>>0<=(ca(c[P+114756+(aa<<2)>>2]|0,c[e+27716+(aa<<2)>>2]|0)|0)>>>0)){break}fa=e+27552+(aa<<2)|0;c[fa>>2]=(c[fa>>2]|0)+4;if((c[e+27552+(aa<<2)>>2]|0)>512){c[e+27552+(aa<<2)>>2]=512}c[e+27632+(aa<<2)>>2]=ca(c[P+114836+(aa<<2)>>2]>>7,c[e+27552+(aa<<2)>>2]|0)|0;break b}}while(0);fa=e+27716+(aa<<2)|0;c[fa>>2]=(c[fa>>2]|0)+1;if((c[e+27796>>2]|0)!=0){if((da|0)==0){c[e+27800>>2]=0}else{if((c[242592+(aa<<2)>>2]|0)==7){if((da|0)!=1){c[e+27800>>2]=12}else{c[e+27800>>2]=6}}else{if((c[242592+(aa<<2)>>2]|0)==9){c[e+27800>>2]=0}else{c[e+27800>>2]=4}}}X_b(P,e)}do{if((U|0)==0){if((da|0)!=0){break}F$b(e,v,x,w);V=d[(c[e+6184>>2]|0)+1|0]|0;ga=16;while(1){if((ga|0)>=24){break}T=T+(a[e+5136+ga|0]|0)|0;ga=ga+1|0}U=1}}while(0);switch(ea|0){case 9:{if((c[238640+(aa<<2)>>2]|0)==1){ha=c[e+27684>>2]|0}else{ha=c[e+27692>>2]|0}fa=ha;if((c[238640+(aa<<2)>>2]|0)==2){ia=c[e+27688>>2]|0}else{ia=fa}fa=ia;ja=H$b(P,e,p,c[r>>2]|0,s|0,t,u+4|0,H,fa)|0;fa=u|0;c[fa>>2]=(c[fa>>2]|0)+(c[t>>2]|0);fa=u+12|0;c[fa>>2]=(c[fa>>2]|0)+(c[H>>2]|0);if((ja|0)<(c[r>>2]|0)){I$b(P,e,u+8|0,u+16|0,c[P+108016>>2]|0)|0;ja=u|0;c[ja>>2]=(c[ja>>2]|0)+(c[u+8>>2]|0);ja=u+12|0;c[ja>>2]=(c[ja>>2]|0)+(c[u+16>>2]|0)}else{ba=2147483647;c[E>>2]=1}break};case 5:case 6:{ka=96;break};case 0:case 1:case 2:case 3:{a[(c[e+6184>>2]|0)+2|0]=0;c9b(R,(c[R+2992>>2]|0)+(-(c[R+2956>>2]|0)|0)|0,(c[R+2992>>2]|0)-1|0,c[R+2956>>2]|0,R|0,16);J$b(e,u+4|0,I);ja=u|0;c[ja>>2]=(c[ja>>2]|0)+(c[u+4>>2]|0);ja=u+12|0;c[ja>>2]=(c[ja>>2]|0)+(c[I>>2]|0);ja=u|0;c[ja>>2]=(c[ja>>2]|0)+(c[(c[e+6412>>2]|0)+((c[e+6192>>2]|0)*40|0)+(d[c[e+6184>>2]|0]<<2)>>2]|0);ja=u|0;c[ja>>2]=(c[ja>>2]|0)+(c[v>>2]|0);c[u+8>>2]=c[x>>2];ja=u+12|0;c[ja>>2]=(c[ja>>2]|0)+(c[w>>2]|0);c[u+16>>2]=c[w>>2];break};case 8:{ja=2147483647;fa=c[P+142572>>2]|0;la=1;ma=c[e+6364>>2]|0;na=((b[p+2>>1]|0)+7>>3)-255|0;oa=((b[p>>1]|0)+7>>3)-255|0;pa=(b[p+2>>1]>>3)+255|0;qa=(b[p>>1]>>3)+255|0;ra=c[e+6432>>2]|0;sa=c[e+6436>>2]|0;ta=c[e+6440>>2]|0;ua=c[e+6444>>2]|0;if((W|0)==0){A$b(P,R,e,f,z|0);W=1}w$b(P,e+3152|0,c[e+6184>>2]|0,y,d[(c[e+6184>>2]|0)+2|0]|0,P+111444|0,A,z|0);b[J+2>>1]=b[y+2>>1]>>3;b[J>>1]=b[y>>1]>>3;if((c[e+6432>>2]|0)<(na|0)){c[e+6432>>2]=na}if((c[e+6436>>2]|0)>(pa|0)){c[e+6436>>2]=pa}if((c[e+6440>>2]|0)<(oa|0)){c[e+6440>>2]=oa}if((c[e+6444>>2]|0)>(qa|0)){c[e+6444>>2]=qa}if((c[A>>2]|0)>(fa|0)){fa=c[A>>2]|0}ja=Be[c[P+142784>>2]&7](e,l,Q,J,Q+24|0,fa,ma,q,P+142932|0,e+6396|0,p)|0;c[$+32>>2]=c[Q+24>>2];qa=0;oa=(c[P+142568>>2]|0)-1-fa|0;qa=c[q>>2]|0;c[q>>2]=0;if((qa|0)>(oa|0)){la=0}while(1){if((qa|0)>=(oa|0)){break}qa=qa+1|0;if((c[q>>2]|0)!=0){c[q>>2]=(c[q>>2]|0)-1}else{va=Be[c[P+142784>>2]&7](e,l,Q,J,Q+24|0,fa+qa|0,ma,q,P+142932|0,e+6396|0,p)|0;if((c[q>>2]|0)>(oa-qa|0)){la=0}if((va|0)<(ja|0)){ja=va;c[$+32>>2]=c[Q+24>>2]}else{c[Q+24>>2]=c[$+32>>2]}}}if((la|0)==1){va=Ke[c[P+142780>>2]&63](e,l,Q,Q+24|0,ma,8,P+142932|0,e+6396|0,p)|0;if((va|0)<(ja|0)){ja=va;c[$+32>>2]=c[Q+24>>2]}else{c[Q+24>>2]=c[$+32>>2]}}c[e+6432>>2]=ra;c[e+6436>>2]=sa;c[e+6440>>2]=ta;c[e+6444>>2]=ua;if((ja|0)<2147483647){Ne[c[P+142772>>2]&15](e,l,Q,Q+24|0,p,c[e+6360>>2]|0,P+142932|0,e+6396|0,K,L)|0}c[$+32>>2]=c[Q+24>>2];qa=Edc($+32|0,p,e+6396|0,96)|0;oa=u|0;c[oa>>2]=(c[oa>>2]|0)+qa;ka=96;break};case 7:{ka=101;break};case 4:{qa=G$b(e,t,u+4|0,G,c[r>>2]|0)|0;oa=u|0;c[oa>>2]=(c[oa>>2]|0)+(c[t>>2]|0);oa=u+12|0;c[oa>>2]=(c[oa>>2]|0)+(c[G>>2]|0);if((qa|0)<(c[r>>2]|0)){qa=u|0;c[qa>>2]=(c[qa>>2]|0)+(c[v>>2]|0);c[u+8>>2]=c[x>>2];qa=u+12|0;c[qa>>2]=(c[qa>>2]|0)+(c[w>>2]|0);c[u+16>>2]=c[w>>2]}else{ba=2147483647;c[E>>2]=1}break};default:{}}if((ka|0)==96){ka=0;z$b($+(ea<<2)|0,R);if((ea|0)==6){ka=98}else{if((ea|0)==5){ka=98}}do{if((ka|0)==98){ka=0;if((c[$+(ea<<2)>>2]|0)!=0){break}break b}}while(0);ka=101}d:do{if((ka|0)==101){ka=0;do{if((b[$+(ea<<2)>>1]>>3|0)>=(c[e+6440>>2]|0)){if((b[$+(ea<<2)>>1]>>3|0)>(c[e+6444>>2]|0)){break}if((b[$+(ea<<2)+2>>1]>>3|0)<(c[e+6432>>2]|0)){break}if((b[$+(ea<<2)+2>>1]>>3|0)>(c[e+6436>>2]|0)){break}v$b(e,ea,$+(ea<<2)|0);ba=K$b(s|0,u,E,P,e)|0;break d}}while(0);break b}}while(0);ba=L$b(ba,u,F,c[E>>2]|0,T,Y,P,e)|0;do{if((d[(c[e+6184>>2]|0)+2|0]|0)==0){if((ba|0)>=(c[r+8>>2]|0)){break}c[r+8>>2]=ba;c[k>>2]=c[u+12>>2]}}while(0);if((c[P+114080>>2]|0)!=0){o_b(e,P+142932|0,M,$+(ea<<2)|0)|0;if((c[M>>2]|0)>>>0<_>>>0){_=c[M>>2]|0}do{if((ea|0)==7){if(!((c[M>>2]|0)>>>0<Z>>>0)){break}Z=c[M>>2]|0;c[e+6488>>2]=d[(c[e+6184>>2]|0)+2|0]|0}}while(0);do{if((d[c[e+6184>>2]|0]|0)==8){if(!((c[M>>2]|0)>>>0<(c[D>>2]|0)>>>0)){break}c[D>>2]=c[M>>2];o_b(e,P+142932|0,D,$+(ea<<2)|0)|0;c[e+6476>>2]=8;c[e+6480>>2]=c[(c[e+6184>>2]|0)+4>>2];a[e+6492|0]=a[(c[e+6184>>2]|0)+10|0]|0;c[e+6484>>2]=d[(c[e+6184>>2]|0)+2|0]|0}}while(0)}do{if((ba|0)<(c[r+4>>2]|0)){ka=123}else{if((c[e+6448>>2]|0)!=0){ka=123;break}ja=e+27552+(aa<<2)|0;c[ja>>2]=(c[ja>>2]|0)+4;if((c[e+27552+(aa<<2)>>2]|0)>512){c[e+27552+(aa<<2)>>2]=512}}}while(0);if((ka|0)==123){ka=0;S=aa;c[h>>2]=c[u>>2];c[j>>2]=c[u+12>>2];if(ea>>>0<=4>>>0){a[(c[e+6184>>2]|0)+1|0]=V;c[(c[e+6184>>2]|0)+4>>2]=0}M$b(r,ba,u,c[F>>2]|0,e);if((c[e+27552+(aa<<2)>>2]|0)>=34){wa=(c[e+27552+(aa<<2)>>2]|0)-2|0}else{wa=32}c[e+27552+(aa<<2)>>2]=wa}c[e+27632+(aa<<2)>>2]=ca(c[P+114836+(aa<<2)>>2]>>7,c[e+27552+(aa<<2)>>2]|0)|0;if((c[e+6448>>2]|0)!=0){ka=133;break a}}}while(0);aa=aa+1|0}do{if((c[P+114836+(S<<2)>>2]|0)>0){if((c[P+114836+(S<<2)>>2]|0)>=536870911){break}wa=c[e+27552+(S<<2)>>2]>>2;if((c[e+27552+(S<<2)>>2]|0)>=(wa+32|0)){xa=(c[e+27552+(S<<2)>>2]|0)-wa|0}else{xa=32}c[e+27552+(S<<2)>>2]=xa;c[e+27632+(S<<2)>>2]=ca(c[P+114836+(S<<2)>>2]>>7,c[e+27552+(S<<2)>>2]|0)|0}}while(0);if((c[P+114080>>2]|0)!=0){if((c[e+6476>>2]|0)==0){c[e+6476>>2]=d[r+12|0]|0;c[e+6480>>2]=c[r+16>>2];a[e+6492|0]=a[r+22|0]|0;c[e+6484>>2]=d[r+14|0]|0;c[D>>2]=_}Hbc(P+149756|0,e,c[D>>2]|0,Z,f,g);do{if((d[r+14|0]|0)==0){if((c[e+6488>>2]|0)==0){break}g=2147483647;c[N>>2]=0;c[O>>2]=0;f=c[e+6488>>2]|0;Z=c[e+6332+(f<<2)>>2]|0;c[u>>2]=Z+(t$b(7,s|0)|0);c[u+12>>2]=0;a[(c[e+6184>>2]|0)+2|0]=f;c[e+6052>>2]=c[B+(f*12|0)>>2];c[e+6056>>2]=c[B+(f*12|0)+4>>2];c[e+6060>>2]=c[B+(f*12|0)+8>>2];a[c[e+6184>>2]|0]=7;a[(c[e+6184>>2]|0)+1|0]=0;c[(c[e+6184>>2]|0)+4>>2]=0;g=K$b(s|0,u,N,P,e)|0;g=L$b(g,u,O,c[N>>2]|0,T,Y,P,e)|0;if((g|0)<(c[r+4>>2]|0)){ka=149}else{if((c[e+6448>>2]|0)!=0){ka=149}}if((ka|0)==149){S=aa;c[h>>2]=c[u>>2];c[j>>2]=c[u+12>>2];M$b(r,g,u,c[O>>2]|0,e)}}}while(0)}do{if((c[P+114620>>2]|0)!=0){if((d[r+12|0]|0)==7){if((d[r+14|0]|0)==3){break}}a[c[e+6184>>2]|0]=7;a[(c[e+6184>>2]|0)+2|0]=3;c[(c[e+6184>>2]|0)+4>>2]=0;a[(c[e+6184>>2]|0)+1|0]=0;a[(c[e+6184>>2]|0)+9|0]=c[P+108004>>2];a[(c[e+6184>>2]|0)+8|0]=0;i=m;return}}while(0);O=c[e+6184>>2]|0;u=r+12|0;c[O>>2]=c[u>>2];c[O+4>>2]=c[u+4>>2];c[O+8>>2]=c[u+8>>2];if((d[r+12|0]|0)==4){ga=0;while(1){if((ga|0)>=16){break}c[(c[R+3032>>2]|0)+12+(ga<<2)>>2]=c[r+24+(ga<<2)>>2];ga=ga+1|0}}if((d[r+12|0]|0)==9){ga=0;while(1){if((ga|0)>=16){break}c[(c[R+3032>>2]|0)+12+(ga<<2)>>2]=c[r+24+(ga<<2)>>2];ga=ga+1|0}nrc(c[e+6320>>2]|0,r+88|0,132)|0;c[(c[e+6184>>2]|0)+4>>2]=c[(c[e+6320>>2]|0)+128>>2]}if((X|0)!=(c[P+111444+(d[(c[R+3032>>2]|0)+2|0]<<2)>>2]|0)){c[p>>2]=c[n+((((X|0)!=0^1)&1)<<2)>>2]}N$b(e,p);i=m;return}function D$b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;b=0;f=b;b=f+1|0;c[a+(f<<2)>>2]=0;if((c[e+142448>>2]&1|0)!=0){f=b;b=f+1|0;c[a+(f<<2)>>2]=1}if((c[e+142448>>2]&2|0)!=0){f=b;b=f+1|0;c[a+(f<<2)>>2]=2}if((c[e+142448>>2]&4|0)!=0){e=b;b=e+1|0;c[a+(e<<2)>>2]=3}while(1){if((b|0)>=4){break}c[a+(b<<2)>>2]=-1;b=b+1|0}i=d;return}function E$b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=d;d=e;if((c[g+142448>>2]&1|0)!=0){f0b(g+107480+((c[g+107868>>2]|0)*92|0)|0,a+12|0,b,d)}if((c[g+142448>>2]&2|0)!=0){f0b(g+107480+((c[g+107872>>2]|0)*92|0)|0,a+24|0,b,d)}if((c[g+142448>>2]&4|0)==0){i=f;return}f0b(g+107480+((c[g+107876>>2]|0)*92|0)|0,a+36|0,b,d);i=f;return}function F$b(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=b;b=e;e=f;f=g;g=g;k=2147483647;l=l;m=m;n=j+3152|0;o=0;while(1){if(!(o>>>0<=3>>>0)){break}a[(c[n+3032>>2]|0)+1|0]=o;d9b(n,(c[n+2996>>2]|0)+(-(c[n+2976>>2]|0)|0)|0,(c[n+3e3>>2]|0)+(-(c[n+2976>>2]|0)|0)|0,(c[n+2996>>2]|0)-1|0,(c[n+3e3>>2]|0)-1|0,c[n+2976>>2]|0,n+256|0,n+320|0,8);icc(j|0,c[j+3116>>2]|0,c[j+3120>>2]|0,c[j+3096>>2]|0,n+256|0,n+320|0,8);kcc(j);R_b(j);p=R$b(j)|0;q=p+(c[(c[j+6416>>2]|0)+((c[n+3040>>2]|0)*40|0)+((d[(c[n+3032>>2]|0)+1|0]|0)<<2)>>2]|0)|0;r=(r$b(j)|0)/4|0;s=(ca(q,c[j+6376>>2]|0)|0)+128>>8;t=s+(ca(c[j+6372>>2]|0,r)|0)|0;if((t|0)<(k|0)){k=t;l=r;m=q;c[e>>2]=p;g=o}o=o+1|0}c[b>>2]=m;c[f>>2]=l;a[(c[n+3032>>2]|0)+1|0]=g;i=h;return}function G$b(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+72|0;j=h|0;k=h+8|0;l=h+24|0;m=h+40|0;n=h+48|0;o=h+56|0;p=h+64|0;q=a;a=b;b=e;e=f;f=g;g=q+3152|0;r=c[(c[q+6412>>2]|0)+((c[g+3040>>2]|0)*40|0)+16>>2]|0;s=0;t=0;c[j>>2]=0;c[j+4>>2]=0;nrc(k|0,c[q+6236>>2]|0,9)|0;nrc(l|0,c[q+6240>>2]|0,9)|0;u=k;k=l;a0b(g,(c[g+2992>>2]|0)+(-(c[g+2956>>2]|0)|0)+16|0);l=c[q+6424>>2]|0;v=0;while(1){if((v|0)>=16){break}w=c[g+3032>>2]|0;x=c[g+3036>>2]|0;c[m>>2]=c[m>>2];c[n>>2]=c[n>>2];c[o>>2]=c[o>>2];c[p>>2]=c[p>>2];if((c[q+6192>>2]|0)==0){y=b0b(w,v,x)|0;x=c0b(w,v)|0;l=(c[q+6420>>2]|0)+(y*400|0)+(x*40|0)|0}x=d0b(q,q+1860+(v*48|0)|0,g+2144+(v*28|0)|0,m,l,u+(d[246856+v|0]|0)|0,k+(d[246824+v|0]|0)|0,n,o,p)|0;y=wrc(c[j>>2]|0,c[j+4>>2]|0,x,(x|0)<0|0?-1:0)|0;c[j>>2]=y;c[j+4>>2]=G;r=r+(c[n>>2]|0)|0;s=s+(c[p>>2]|0)|0;t=t+(c[o>>2]|0)|0;c[w+12+(v<<2)>>2]=c[m>>2];w=c[j+4>>2]|0;y=f;x=(y|0)<0|0?-1:0;if((w|0)>=(x|0)&((w|0)>(x|0)|(c[j>>2]|0)>>>0>=y>>>0)){y=6;break}v=v+1|0}v=c[j+4>>2]|0;m=f;f=(m|0)<0|0?-1:0;if((v|0)>=(f|0)&((v|0)>(f|0)|(c[j>>2]|0)>>>0>=m>>>0)){z=2147483647;A=z;i=h;return A|0}else{c[a>>2]=r;c[b>>2]=t;c[e>>2]=s;e=(ca(r,c[q+6376>>2]|0)|0)+128>>8;z=e+(ca(c[q+6372>>2]|0,s)|0)|0;A=z;i=h;return A|0}return 0}function H$b(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;o=i;i=i+208|0;p=o|0;q=e;e=f;f=g;g=h;h=k;k=l;l=m;mrc(p|0,0,204)|0;c[p+8>>2]=g;c[p>>2]=f;c[p+4>>2]=c[f>>2];c[p+172>>2]=n;c[p+176>>2]=j;j=0;while(1){if((j|0)>=16){break}c[p+28+(j<<2)>>2]=12;j=j+1|0}if((c[q+142360>>2]|0)==0){U$b(q,e,p,0);U$b(q,e,p,1);U$b(q,e,p,2);U$b(q,e,p,3)}else{U$b(q,e,p,2);if((c[p+8>>2]|0)<(g|0)){g=((b[f+2>>1]|0)+7>>3)-255|0;n=((b[f>>1]|0)+7>>3)-255|0;m=(b[f+2>>1]>>3)+255|0;r=(b[f>>1]>>3)+255|0;f=c[e+6432>>2]|0;s=c[e+6436>>2]|0;t=c[e+6440>>2]|0;u=c[e+6444>>2]|0;if((c[e+6432>>2]|0)<(g|0)){c[e+6432>>2]=g}if((c[e+6436>>2]|0)>(m|0)){c[e+6436>>2]=m}if((c[e+6440>>2]|0)<(n|0)){c[e+6440>>2]=n}if((c[e+6444>>2]|0)>(r|0)){c[e+6444>>2]=r}c[p+180>>2]=c[p+92>>2];c[p+184>>2]=c[p+100>>2];c[p+188>>2]=c[p+124>>2];c[p+192>>2]=c[p+132>>2];r=(R((b[p+180>>1]|0)-(b[p+188>>1]|0)|0)|0)>>3;if((r|0)>((R((b[p+182>>1]|0)-(b[p+190>>1]|0)|0)|0)>>3|0)){v=(R((b[p+180>>1]|0)-(b[p+188>>1]|0)|0)|0)>>3}else{v=(R((b[p+182>>1]|0)-(b[p+190>>1]|0)|0)|0)>>3}r=v;V$b(r,p+196|0);v=(R((b[p+184>>1]|0)-(b[p+192>>1]|0)|0)|0)>>3;if((v|0)>((R((b[p+186>>1]|0)-(b[p+194>>1]|0)|0)|0)>>3|0)){w=(R((b[p+184>>1]|0)-(b[p+192>>1]|0)|0)|0)>>3}else{w=(R((b[p+186>>1]|0)-(b[p+194>>1]|0)|0)|0)>>3}r=w;V$b(r,p+200|0);U$b(q,e,p,1);w=(R((b[p+180>>1]|0)-(b[p+184>>1]|0)|0)|0)>>3;if((w|0)>((R((b[p+182>>1]|0)-(b[p+186>>1]|0)|0)|0)>>3|0)){x=(R((b[p+180>>1]|0)-(b[p+184>>1]|0)|0)|0)>>3}else{x=(R((b[p+182>>1]|0)-(b[p+186>>1]|0)|0)|0)>>3}r=x;V$b(r,p+196|0);x=(R((b[p+188>>1]|0)-(b[p+192>>1]|0)|0)|0)>>3;if((x|0)>((R((b[p+190>>1]|0)-(b[p+194>>1]|0)|0)|0)>>3|0)){y=(R((b[p+188>>1]|0)-(b[p+192>>1]|0)|0)|0)>>3}else{y=(R((b[p+190>>1]|0)-(b[p+194>>1]|0)|0)|0)>>3}r=y;V$b(r,p+200|0);U$b(q,e,p,0);if((c[q+142584>>2]|0)!=0){z=30}else{if((c[p+12>>2]|0)==2){z=30}}if((z|0)==30){c[p+4>>2]=c[p+180>>2];U$b(q,e,p,3)}c[e+6432>>2]=f;c[e+6436>>2]=s;c[e+6440>>2]=t;c[e+6444>>2]=u}}j=0;while(1){if((j|0)>=16){break}u=e+5296+(j*28|0)|0;c[u+24>>2]=c[p+92+(j<<2)>>2];a[c[u+20>>2]|0]=a[p+156+j|0]|0;j=j+1|0}c[h>>2]=c[p+16>>2];c[l>>2]=c[p+20>>2];c[k>>2]=c[p+24>>2];a[(c[e+6184>>2]|0)+8|0]=c[p+12>>2];c[c[e+6320>>2]>>2]=c[243224+(c[p+12>>2]<<2)>>2];j=0;while(1){if((j|0)>=(c[c[e+6320>>2]>>2]|0)){break}k=d[243120+(c[p+12>>2]<<4)+j|0]|0;c[(c[e+6320>>2]|0)+4+(j<<3)>>2]=c[p+28+(k<<2)>>2];l=(c[e+6320>>2]|0)+4+(j<<3)+4|0;h=p+92+(k<<2)|0;b[l>>1]=b[h>>1]|0;b[l+2>>1]=b[h+2>>1]|0;j=j+1|0}c[(c[e+6320>>2]|0)+128>>2]=c[p+152>>2];i=o;return c[p+8>>2]|0}function I$b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;f=i;a=b;b=d;d=e;T8b(a+3152|0);icc(a|0,c[a+3116>>2]|0,c[a+3120>>2]|0,c[a+3096>>2]|0,a+3408|0,a+3472|0,8);kcc(a);R_b(a);c[b>>2]=R$b(a)|0;c[d>>2]=(r$b(a)|0)/4|0;e=(ca(c[b>>2]|0,c[a+6376>>2]|0)|0)+128>>8;b=e+(ca(c[a+6372>>2]|0,c[d>>2]|0)|0)|0;i=f;return b|0}function J$b(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=d;d=e;e=g+3012|0;h=g+5968|0;j=c[e>>2]|0;jcc(g|0,c[c[g+1896>>2]>>2]|0,c[g+1904>>2]|0,g+3152|0,16);k=g+1860|0;while(1){if(!(k>>>0<(g+2628|0)>>>0)){break}ef[c[g+31916>>2]&4095](c[k>>2]|0,c[k+4>>2]|0,32);l=j;j=l+2|0;b[l>>1]=b[c[k+4>>2]>>1]|0;l=j;j=l+2|0;b[l>>1]=b[(c[k+4>>2]|0)+32>>1]|0;k=k+96|0}ef[c[g+31920>>2]&4095](c[e>>2]|0,c[e+4>>2]|0,8);k=0;while(1){if((k|0)>=16){break}re[c[g+31924>>2]&1023](g+1860+(k*48|0)|0,g+5296+(k*28|0)|0);k=k+1|0}re[c[g+31924>>2]&1023](e,h);k=(q$b(g,1)|0)<<2;k=k+(p$b(c[e+4>>2]|0,c[h+4>>2]|0)|0)|0;c[d>>2]=k>>4;c[a>>2]=T$b(g)|0;i=f;return}function K$b(a,e,f,g,h){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=a;a=e;e=f;f=g;g=h;h=d[c[g+6184>>2]|0]|0;n=g+1860|0;o=g+3152|0;V8b(g+3152|0,g+3152|0,16);do{if((c[f+142632>>2]|0)!=0){if((d[c[g+6460>>2]|0]|0)!=0){p=4;break}c[g+6448>>2]=1}else{p=4}}while(0);if((p|0)==4){if((c[g+6452>>2]|0)!=0){q=(ca(b[(c[o+2156>>2]|0)+2>>1]|0,b[(c[o+2156>>2]|0)+2>>1]|0)|0)>>4;if(q>>>0<(c[g+6452>>2]|0)>>>0){q=c[g+6452>>2]|0}r=B9b(c[c[n+36>>2]>>2]|0,c[n+44>>2]|0,g+3152|0,16,l)|0;if((c[l>>2]|0)>>>0<q>>>0){n=b[c[o+2828>>2]>>1]|0;do{if(((c[l>>2]|0)-r|0)>>>0<(ca(n,n)|0)>>>4>>>0){p=11}else{if(!((((c[l>>2]|0)>>>0)/2|0)>>>0>r>>>0)){break}if(((c[l>>2]|0)-r|0)>>>0<64>>>0){p=11}}}while(0);do{if((p|0)==11){r=s$b(g)|0;if(!(r<<1>>>0<q>>>0)){break}c[g+6448>>2]=1;c[a+12>>2]=(c[l>>2]|0)+r;c[a>>2]=500;c[a+8>>2]=0;c[a+16>>2]=r;c[e>>2]=1;r=(ca(c[a>>2]|0,c[g+6376>>2]|0)|0)+128>>8;s=r+(ca(c[g+6372>>2]|0,c[a+12>>2]|0)|0)|0;t=s;i=j;return t|0}}while(0)}}}e=t$b(h,m)|0;m=a|0;c[m>>2]=(c[m>>2]|0)+e;J$b(g,a+4|0,k);e=a|0;c[e>>2]=(c[e>>2]|0)+(c[a+4>>2]|0);e=a+12|0;c[e>>2]=(c[e>>2]|0)+(c[k>>2]|0);Q$b(f,g,a+8|0,a+16|0,c[f+108016>>2]|0)|0;f=a|0;c[f>>2]=(c[f>>2]|0)+(c[a+8>>2]|0);f=a+12|0;c[f>>2]=(c[f>>2]|0)+(c[a+16>>2]|0);s=2147483647;t=s;i=j;return t|0}function L$b(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0;m=i;n=b;b=e;e=f;f=h;h=j;j=k;k=l;l=d[c[k+6184>>2]|0]|0;if((c[j+108004>>2]|0)!=0){o=e;c[o>>2]=(c[o>>2]|0)+(c[238752+(c[j+142396>>2]<<2)>>2]|0);o=b|0;c[o>>2]=(c[o>>2]|0)+(c[e>>2]|0)}o=b|0;c[o>>2]=(c[o>>2]|0)+(c[k+6332+(d[(c[k+6184>>2]|0)+2|0]<<2)>>2]|0);if((g|0)!=0){p=n;i=m;return p|0}if((c[j+108004>>2]|0)!=0){if((l|0)!=9){q=(l|0)!=4}else{q=0}l=q&1;q=0;if((l|0)!=0){q=q+(a[k+5160|0]|0)|0}g=0;while(1){if((g|0)>=16){break}q=q+((a[k+5136+g|0]|0)>(l|0))|0;g=g+1|0}if((a[(c[k+6184>>2]|0)+2|0]|0)!=0){g=16;while(1){if((g|0)>=24){break}q=q+(a[k+5136+g|0]|0)|0;g=g+1|0}}else{q=q+f|0}if((q|0)==0){q=b|0;c[q>>2]=(c[q>>2]|0)-((c[b+4>>2]|0)+(c[b+8>>2]|0));c[b+8>>2]=0;if((c[j+142396>>2]|0)!=0){q=c[238752+(255-(c[j+142396>>2]|0)<<2)>>2]|0;q=q-(c[238752+(c[j+142396>>2]<<2)>>2]|0)|0;j=b|0;c[j>>2]=(c[j>>2]|0)+q;j=e;c[j>>2]=(c[j>>2]|0)+q}}}q=(ca(c[b>>2]|0,c[k+6376>>2]|0)|0)+128>>8;n=q+(ca(c[k+6372>>2]|0,c[b+12>>2]|0)|0)|0;do{if((n|0)<2147483647){if((d[(c[k+6184>>2]|0)+2|0]|0)!=0){break}n=n+h|0}}while(0);p=n;i=m;return p|0}function M$b(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;j=a;a=e;e=f;f=g;g=d[c[f+6184>>2]|0]|0;e=e+(c[f+6332+((d[(c[f+6184>>2]|0)+2|0]|0)<<2)>>2]|0)|0;k=(ca((c[a>>2]|0)-(c[a+8>>2]|0)-e|0,c[f+6376>>2]|0)|0)+128>>8;c[j>>2]=k+(ca(c[f+6372>>2]|0,(c[a+12>>2]|0)-(c[a+16>>2]|0)|0)|0);c[j+4>>2]=b;b=j+12|0;a=c[f+6184>>2]|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];nrc(j+88|0,c[f+6320>>2]|0,132)|0;do{if((g|0)!=4){if((g|0)==9){break}i=h;return}}while(0);g=0;while(1){if((g|0)>=16){break}c[j+24+(g<<2)>>2]=c[f+5296+(g*28|0)+24>>2];g=g+1|0}i=h;return}function N$b(a,e){a=a|0;e=e|0;var f=0,g=0,h=0;f=i;g=a;a=e;if((d[c[g+6184>>2]|0]|0)!=9){if((d[c[g+6184>>2]|0]|0)==8){e=g+11108+(((b[(c[g+6184>>2]|0)+4>>1]|0)-(b[a>>1]|0)>>1)+1023<<2)|0;c[e>>2]=(c[e>>2]|0)+1;e=g+19296+(((b[(c[g+6184>>2]|0)+6>>1]|0)-(b[a+2>>1]|0)>>1)+1023<<2)|0;c[e>>2]=(c[e>>2]|0)+1}i=f;return}e=0;while(1){if((e|0)>=(c[c[g+6320>>2]>>2]|0)){break}if((c[(c[g+6320>>2]|0)+4+(e<<3)>>2]|0)==13){h=g+11108+(((b[(c[g+6320>>2]|0)+4+(e<<3)+4>>1]|0)-(b[a>>1]|0)>>1)+1023<<2)|0;c[h>>2]=(c[h>>2]|0)+1;h=g+19296+(((b[(c[g+6320>>2]|0)+4+(e<<3)+6>>1]|0)-(b[a+2>>1]|0)>>1)+1023<<2)|0;c[h>>2]=(c[h>>2]|0)+1}e=e+1|0}i=f;return}function O$b(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+72|0;f=e|0;g=e+8|0;h=e+16|0;j=e+48|0;k=e+56|0;l=e+64|0;m=b;b=d;c[g>>2]=0;c[j>>2]=0;c[k>>2]=0;c[l>>2]=0;a[(c[m+6184>>2]|0)+2|0]=0;F$b(m,h,l,e+40|0);l=c[h>>2]|0;h=P$b(m,g,k,e+32|0)|0;if((G$b(m,f,j,e+24|0,h)|0)<(h|0)){a[c[m+6184>>2]|0]=4;l=l+(c[f>>2]|0)|0;n=l;o=b;c[o>>2]=n;i=e;return}else{l=l+(c[g>>2]|0)|0;n=l;o=b;c[o>>2]=n;i=e;return}}function P$b(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=b;b=e;e=f;f=g;g=g;m=2147483647;n=l+3152|0;o=0;while(1){if(!(o>>>0<=3>>>0)){break}a[c[n+3032>>2]|0]=o;c9b(n,(c[n+2992>>2]|0)+(-(c[n+2956>>2]|0)|0)|0,(c[n+2992>>2]|0)-1|0,c[n+2956>>2]|0,n|0,16);J$b(l,j,k);p=(c[j>>2]|0)+(c[(c[l+6412>>2]|0)+((c[n+3040>>2]|0)*40|0)+((d[c[n+3032>>2]|0]|0)<<2)>>2]|0)|0;q=(ca(p,c[l+6376>>2]|0)|0)+128>>8;r=q+(ca(c[l+6372>>2]|0,c[k>>2]|0)|0)|0;if((r|0)<(m|0)){g=o;m=r;c[b>>2]=p;c[e>>2]=c[j>>2];c[f>>2]=c[k>>2]}o=o+1|0}a[c[n+3032>>2]|0]=g;i=h;return m|0}function Q$b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;f=i;a=b;b=d;d=e;S8b(a+3152|0);icc(a|0,c[a+3116>>2]|0,c[a+3120>>2]|0,c[a+3096>>2]|0,a+3408|0,a+3472|0,8);kcc(a);R_b(a);c[b>>2]=R$b(a)|0;c[d>>2]=(r$b(a)|0)/4|0;e=(ca(c[b>>2]|0,c[a+6376>>2]|0)|0)+128>>8;b=e+(ca(c[a+6372>>2]|0,c[d>>2]|0)|0)|0;i=f;return b|0}function R$b(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+32|0;e=b|0;f=b+16|0;g=a;a=0;h=g+3152|0;nrc(e|0,c[g+6236>>2]|0,9)|0;nrc(f|0,c[g+6240>>2]|0,9)|0;j=e;e=f;f=16;while(1){if((f|0)>=24){break}a=a+(S$b(g,h+2144+(f*28|0)|0,2,j+(d[246856+f|0]|0)|0,e+(d[246824+f|0]|0)|0)|0)|0;f=f+1|0}i=b;return a|0}function S$b(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;k=i;l=e;e=f;f=g;g=h;h=j;j=((f|0)!=0^1)&1;m=a[c[e+20>>2]|0]|0;n=0;o=c[e>>2]|0;e=(a[g]|0)+(a[h]|0)|0;if((m|0)<=16){}else{Cd(2427744,2562608,531,2653184);return 0}while(1){if((j|0)>=(m|0)){break}p=b[o+(c[245048+(j<<2)>>2]<<1)>>1]|0;q=b[(c[61288]|0)+(p<<2)>>1]|0;n=n+(c[(c[l+6428>>2]|0)+(f*1152|0)+((d[246688+j|0]|0)*144|0)+(e*48|0)+(q<<2)>>2]|0)|0;n=n+(b[(c[61290]|0)+(p<<1)>>1]|0)|0;e=d[239776+q|0]|0;j=j+1|0}if((j|0)>=16){r=j;s=f;t=(s|0)!=0;u=t^1;v=u&1;w=(r|0)!=(v|0);x=w&1;e=x;y=e;z=y&255;A=h;a[A]=z;B=g;a[B]=z;C=n;i=k;return C|0}n=n+(c[(c[l+6428>>2]|0)+(f*1152|0)+((d[246688+j|0]|0)*144|0)+(e*48|0)+44>>2]|0)|0;r=j;s=f;t=(s|0)!=0;u=t^1;v=u&1;w=(r|0)!=(v|0);x=w&1;e=x;y=e;z=y&255;A=h;a[A]=z;B=g;a[B]=z;C=n;i=k;return C|0}function T$b(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+32|0;e=b|0;f=b+16|0;g=a;a=0;h=g+3152|0;nrc(e|0,c[g+6236>>2]|0,9)|0;nrc(f|0,c[g+6240>>2]|0,9)|0;j=e;e=f;f=0;while(1){if((f|0)>=16){break}a=a+(S$b(g,h+2144+(f*28|0)|0,0,j+(d[246856+f|0]|0)|0,e+(d[246824+f|0]|0)|0)|0)|0;f=f+1|0}a=a+(S$b(g,h+2816|0,1,j+(d[246880]|0)|0,e+(d[246848]|0)|0)|0)|0;i=b;return a|0}function U$b(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;j=i;i=i+192|0;k=j|0;l=j+16|0;m=j+64|0;n=j+120|0;o=j+136|0;p=j+152|0;q=j+160|0;r=j+168|0;s=j+176|0;t=j+184|0;u=e;e=f;f=g;g=h;h=0;v=0;w=0;x=0;y=0;z=0;A=0;nrc(k|0,c[e+6236>>2]|0,9)|0;nrc(l|0,c[e+6240>>2]|0,9)|0;B=k;C=l;D=j+32|0;E=j+48|0;h=0;v=0;F=u+142788+(g*36|0)|0;G=242848+(g<<6)|0;H=c[243224+(g<<2)>>2]|0;I=(c[f+172>>2]|0)/(H|0)|0;x=u$b(243104,243112,243184+(g<<3)|0)|0;x=x+(t$b(9,c[f+176>>2]|0)|0)|0;J=(ca(x,c[e+6376>>2]|0)|0)+128>>8;w=w+(J+0)|0;h=h+x|0;J=0;while(1){if((J|0)>=(H|0)){break}K=2147483647;L=12;M=0;N=10;while(1){if(!(N>>>0<=13>>>0)){break}nrc(n|0,k|0,9)|0;nrc(o|0,l|0,9)|0;O=n;P=o;if((N|0)==13){Q=0;R=2147483647;if((K|0)<(I|0)){S=7;break}if((c[u+142360>>2]|0)!=0){if((g|0)==1){S=11}else{if((g|0)==0){S=11}}if((S|0)==11){S=0;c[f+4>>2]=c[f+180+(J<<2)>>2];do{if((J|0)==1){if((g|0)!=0){break}c[f+4>>2]=c[f+188>>2]}}while(0);Q=c[f+196+(J<<2)>>2]|0}do{if((g|0)==3){if((J|0)<=0){break}c[f+4>>2]=c[e+5296+((J-1|0)*28|0)+24>>2];do{if((J|0)==4){S=20}else{if((J|0)==8){S=20;break}if((J|0)==12){S=20}}}while(0);if((S|0)==20){S=0;c[f+4>>2]=c[e+5296+((J-4|0)*28|0)+24>>2]}Q=2}}while(0)}T=7-Q|0;U=c[e+6368>>2]|0;b[r>>1]=b[f+4>>1]>>3;b[r+2>>1]=b[f+6>>1]>>3;V=d[243120+(g<<4)+J|0]|0;W=e+1860+(V*48|0)|0;X=e+5296+(V*28|0)|0;R=Be[c[u+142784>>2]&7](e,W,X,r,m+52|0,Q,U,p,F,e+6396|0,c[f>>2]|0)|0;V=c[p>>2]|0;c[p>>2]=0;while(1){if((V|0)>=(T|0)){break}V=V+1|0;if((c[p>>2]|0)!=0){c[p>>2]=(c[p>>2]|0)-1}else{Y=Be[c[u+142784>>2]&7](e,W,X,r,q,Q+V|0,U,p,F,e+6396|0,c[f>>2]|0)|0;if((Y|0)<(R|0)){R=Y;c[m+52>>2]=c[q>>2]}}}do{if((c[u+142360>>2]|0)==0){if((R>>c[601840+(g<<2)>>2]|0)<=4e3){break}W$b(r,c[e+6432>>2]|0,c[e+6436>>2]|0,c[e+6440>>2]|0,c[e+6444>>2]|0);Y=Ke[c[u+142776>>2]&63](e,W,X,r,U,16,F,e+6396|0,c[f>>2]|0)|0;if((Y|0)<(R|0)){R=Y;c[m+52>>2]=c[X+24>>2]}else{c[X+24>>2]=c[m+52>>2]}}}while(0);if((R|0)<2147483647){Ne[c[u+142772>>2]&15](e,W,X,m+52|0,c[f>>2]|0,c[e+6360>>2]|0,F,e+6396|0,s,t)|0}}x=X$b(e,G,J,N,m+(N<<2)|0,c[f>>2]|0,e+6396|0)|0;do{if((b[m+(N<<2)>>1]>>3|0)<(c[e+6440>>2]|0)){S=44}else{if((b[m+(N<<2)>>1]>>3|0)>(c[e+6444>>2]|0)){S=44;break}if((b[m+(N<<2)+2>>1]>>3|0)<(c[e+6432>>2]|0)){S=44;break}if((b[m+(N<<2)+2>>1]>>3|0)>(c[e+6436>>2]|0)){S=44;break}U=((Y$b(e,G,J)|0)>>>0)/4|0;V=Z$b(e,G,J,O,P)|0;x=x+V|0;Q=(ca(x,c[e+6376>>2]|0)|0)+128>>8;T=Q+(ca(c[e+6372>>2]|0,U)|0)|0;if((T|0)<(K|0)){y=x;z=U;M=V;L=N;K=T;nrc(D|0,O|0,9)|0;nrc(E|0,P|0,9)|0}}}while(0);if((S|0)==44){S=0}N=N+1|0}if((S|0)==7){S=0}nrc(B|0,D|0,9)|0;nrc(C|0,E|0,9)|0;X$b(e,G,J,L,m+(L<<2)|0,c[f>>2]|0,e+6396|0)|0;h=h+y|0;v=v+z|0;A=A+M|0;w=w+K|0;if((w|0)>=(c[f+8>>2]|0)){S=50;break}J=J+1|0}if((w|0)>=(c[f+8>>2]|0)){i=j;return}c[f+16>>2]=h;c[f+20>>2]=v;c[f+24>>2]=A;c[f+8>>2]=w;c[f+12>>2]=g;J=0;while(1){if((J|0)>=16){break}g=f+92+(J<<2)|0;w=(c[e+6320>>2]|0)+4+(J<<3)+4|0;b[g>>1]=b[w>>1]|0;b[g+2>>1]=b[w+2>>1]|0;c[f+28+(J<<2)>>2]=c[(c[e+6320>>2]|0)+4+(J<<3)>>2];a[f+156+J|0]=a[e+5136+J|0]|0;J=J+1|0}i=j;return}function V$b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;b=0;if((e|0)>128){e=128}else{if((e|0)<1){e=1}}while(1){f=e>>1;e=f;if((f|0)==0){break}b=b+1|0}c[a>>2]=7-b;i=d;return}function W$b(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;h=a;a=c;c=d;d=e;e=f;if((b[h+2>>1]|0)<(a|0)){j=a}else{j=b[h+2>>1]|0}b[h+2>>1]=j;if((b[h+2>>1]|0)>(c|0)){k=c}else{k=b[h+2>>1]|0}b[h+2>>1]=k;if((b[h>>1]|0)<(d|0)){l=d}else{l=b[h>>1]|0}b[h>>1]=l;if((b[h>>1]|0)>(e|0)){m=e;n=m&65535;o=h;p=o;q=p|0;b[q>>1]=n;i=g;return}else{m=b[h>>1]|0;n=m&65535;o=h;p=o;q=p|0;b[q>>1]=n;i=g;return}}function X$b(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+8|0;k=j|0;l=a;a=b;b=d;d=e;e=f;f=g;g=h;h=l+3152|0;m=c[h+3032>>2]|0;n=c[h+3036>>2]|0;o=0;p=0;q=0;do{r=h+2144+(q*28|0)|0;s=q>>2;t=q&3;if((c[a+(q<<2)>>2]|0)==(b|0)){do{if((t|0)!=0){if((c[a+(q<<2)>>2]|0)!=(c[a+(q-1<<2)>>2]|0)){u=7;break}v=10}else{u=7}}while(0);if((u|0)==7){u=0;do{if((s|0)!=0){if((c[a+(q<<2)>>2]|0)!=(c[a+(q-4<<2)>>2]|0)){u=10;break}v=11}else{u=10}}while(0);if((u|0)==10){u=0;w=d;v=w;if((w|0)==10){if((t|0)!=0){x=c[r-28+24>>2]|0}else{x=_$b(m,q)|0}c[e>>2]=x}else if((w|0)==13){p=Edc(e,f,g,102)|0}else if((w|0)==12){c[e>>2]=0}else if((w|0)==11){if((s|0)!=0){y=c[r-112+24>>2]|0}else{y=$$b(m,q,n)|0}c[e>>2]=y}if((v|0)==11){if((t|0)!=0){z=c[r-28+24>>2]|0}else{z=_$b(m,q)|0}c[k>>2]=z;if((c[k>>2]|0)==(c[e>>2]|0)){v=10}}o=c[(c[l+6424>>2]|0)+(v<<2)>>2]|0}}c[r+24>>2]=c[e>>2];c[(c[l+6320>>2]|0)+4+(q<<3)>>2]=v;c[(c[l+6320>>2]|0)+4+(q<<3)+4>>2]=c[e>>2]}w=q+1|0;q=w;}while((w|0)<16);o=o+p|0;i=j;return o|0}function Y$b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a;a=b;b=d;d=0;g=c[f+6016>>2]|0;h=c[f+6052>>2]|0;j=0;while(1){if((j|0)>=16){break}if((c[a+(j<<2)>>2]|0)==(b|0)){k=f+5296+(j*28|0)|0;l=f+1860+(j*48|0)|0;R8b(k,16,h,g,c[f+6296>>2]|0);hcc(l,k,16);ef[c[f+31912>>2]&4095](c[l>>2]|0,c[l+4>>2]|0,32);re[c[f+31924>>2]&1023](l,k);d=d+(p$b(c[l+4>>2]|0,c[k+4>>2]|0)|0)|0}j=j+1|0}i=e;return d|0}function Z$b(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;j=a;a=b;b=e;e=f;f=g;g=0;k=j+3152|0;l=0;while(1){if((l|0)>=16){break}if((c[a+(l<<2)>>2]|0)==(b|0)){g=g+(S$b(j,k+2144+(l*28|0)|0,3,e+(d[246856+l|0]|0)|0,f+(d[246824+l|0]|0)|0)|0)|0}l=l+1|0}i=h;return g|0}function _$b(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;do{if((a&3|0)==0){f=f-76|0;if((d[f|0]|0|0)==9){a=a+4|0;break}g=c[f+4>>2]|0;h=g;i=e;return h|0}}while(0);g=c[f+12+(a<<2)-4>>2]|0;h=g;i=e;return h|0}function $$b(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;do{if((a>>2|0)==0){g=g+((-e|0)*76|0)|0;if((d[g|0]|0|0)==9){a=a+16|0;break}h=c[g+4>>2]|0;j=h;i=f;return j|0}}while(0);h=c[g+12+(a-4<<2)>>2]|0;j=h;i=f;return j|0}function a0b(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;a=c[d+2956>>2]|0;e=(c[d+2992>>2]|0)+(-a|0)+16|0;d=b;c[e+(a<<2)>>2]=c[d>>2];c[e+(a<<3)>>2]=c[d>>2];c[e+(a*12|0)>>2]=c[d>>2];i=i;return}function b0b(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=a;a=b;a:do{if((a>>2|0)!=0){g=c[f+12+(a<<2)-16>>2]|0}else{f=f+((-e|0)*76|0)|0;switch(d[f|0]|0|0){case 2:{g=3;break a;break};case 1:{g=2;break a;break};case 0:{g=0;break a;break};case 3:{g=1;break a;break};case 4:{g=c[f+12+(a<<2)+48>>2]|0;break a;break};default:{g=0;break a}}}}while(0);i=i;return g|0}function c0b(a,b){a=a|0;b=b|0;var e=0,f=0;e=a;a=b;a:do{if((a&3|0)!=0){f=c[e+12+(a<<2)-4>>2]|0}else{e=e-76|0;switch(d[e|0]|0|0){case 4:{f=c[e+12+(a<<2)+12>>2]|0;break a;break};case 2:{f=3;break a;break};case 0:{f=0;break a;break};case 3:{f=1;break a;break};case 1:{f=2;break a;break};default:{f=0;break a}}}}while(0);i=i;return f|0}function d0b(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;n=i;i=i+160|0;o=n|0;p=n+8|0;q=b;b=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=2147483647;r=0;s=a[g]|0;a[o]=a[g]|0;t=a[h]|0;a[p]=a[h]|0;u=n+32-1&-16;v=n+120-1&-16;w=c[q+6108>>2]|0;x=(c[q+6144>>2]|0)+(c[d+16>>2]|0)|0;y=x+(-w|0)|0;z=x-1|0;A=a[y-1|0]|0;B=0;while(1){if(!(B>>>0<=9>>>0)){break}r=c[f+(B<<2)>>2]|0;e9b(y,z,w,B,c[d+8>>2]|0,16,A);hcc(b,d,16);ef[c[q+31912>>2]&4095](c[b>>2]|0,c[b+4>>2]|0,32);re[c[q+31924>>2]&1023](b,d);a[o]=s;a[p]=t;C=S$b(q,d,3,o,p)|0;r=r+C|0;D=(p$b(c[b+4>>2]|0,c[d+4>>2]|0)|0)>>2;E=(ca(r,c[q+6376>>2]|0)|0)+128>>8;F=E+(ca(c[q+6372>>2]|0,D)|0)|0;if((F|0)<(m|0)){c[j>>2]=r;c[k>>2]=C;c[l>>2]=D;m=F;c[e>>2]=B;a[g]=a[o]|0;a[h]=a[p]|0;e0b(u,c[d+8>>2]|0);nrc(v|0,c[d+4>>2]|0,32)|0}B=B+1|0}c[d+24>>2]=c[e>>2];c8b(v,u,16,x,w);i=n;return m|0}function e0b(a,b){a=a|0;b=b|0;var d=0;d=b;b=a;c[b>>2]=c[d>>2];c[b+16>>2]=c[d+16>>2];c[b+32>>2]=c[d+32>>2];c[b+48>>2]=c[d+48>>2];i=i;return}function f0b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=a;a=b;b=e;c[a>>2]=(c[f+52>>2]|0)+d;c[a+4>>2]=(c[f+56>>2]|0)+b;c[a+8>>2]=(c[f+60>>2]|0)+b;i=i;return}function g0b(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=b;b=e;e=f;f=g;g=0;k=0;do{l=f-1|0;f=l;m=e>>l&1;if((m|0)!=0){n=255-(d[b+(k<<24>>24>>1)|0]|0)|0}else{n=d[b+(k<<24>>24>>1)|0]|0}g=g+(c[238752+(n<<2)>>2]|0)|0;k=a[j+((k<<24>>24)+m)|0]|0;}while((f|0)!=0);i=h;return g|0}function h0b(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b;b=e;e=f;f=c[b+2384>>2]|0;c[e+6456>>2]=c[h+149724>>2];do{if((c[b+2312>>2]|0)!=0){if((c[b+5760>>2]|0)!=0){break}j=0;while(1){if((j|0)>=(c[b+2328>>2]|0)){break}k=0;while(1){if((k|0)>=(c[b+2332>>2]|0)){break}do{if((d[f+2|0]|0)==2){l=10}else{if((d[f+2|0]|0)==3){l=10;break}do{if((d[f|0]|0)!=7){if((a[c[e+6456>>2]|0]|0)==0){break}a[c[e+6456>>2]|0]=0;m=h+149728|0;c[m>>2]=(c[m>>2]|0)-1}}while(0)}}while(0);if((l|0)==10){l=0;if((a[c[e+6456>>2]|0]|0)==0){a[c[e+6456>>2]|0]=1;m=h+149728|0;c[m>>2]=(c[m>>2]|0)+1}}m=e+6456|0;c[m>>2]=(c[m>>2]|0)+1;f=f+76|0;k=k+1|0}f=f+76|0;j=j+1|0}i=g;return}}while(0);mrc(c[h+149724>>2]|0,1,ca(c[b+2328>>2]|0,c[b+2332>>2]|0)|0)|0;c[h+149728>>2]=ca(c[b+2328>>2]|0,c[b+2332>>2]|0)|0;i=g;return}function i0b(a,f,g,h,j,k,l,m){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;n=i;o=a;a=f;f=g;g=h;h=j;j=k;k=l;l=m;m=0;p=0;q=0;while(1){if(!(p>>>0<g>>>0)){break}r=0;while(1){if(!(r>>>0<g>>>0)){break}s=f;f=s+1|0;t=d[s]|0;s=(d[o+m|0]|0)-t|0;s=ca(s,s)|0;s=s*3|0;s=s+(1<<h-1)|0;s=s>>h;if((s|0)>16){s=16}s=16-s|0;s=ca(s,j)|0;u=l+(q<<1)|0;b[u>>1]=(e[u>>1]|0)+s;u=ca(s,t)|0;t=k+(q<<2)|0;c[t>>2]=(c[t>>2]|0)+u;m=m+1|0;r=r+1|0;q=q+1|0}m=m+(a-g)|0;p=p+1|0}i=n;return}function j0b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=a;a=b;b=0;f=0;g=0;h=0;j=0;k=0;l=0;m=c[e+114264>>2]|0;n=c[e+114268>>2]|0;o=c[e+131556>>2]|0;f=a;g=(Ddc(c[e+114488>>2]|0)|0)-(f+1)|0;p=n;if((p|0)==2){j=g;if((j|0)>=(o|0)){j=o-1|0}k=j+1|0}else if((p|0)==3){q=9}else if((p|0)==1){h=f;if((h|0)>=(o|0)){h=o-1|0}k=h+1|0}else{q=9}if((q|0)==9){j=g;h=f;if((j|0)>(h|0)){j=h}if((h|0)>(j|0)){h=j}if((j|0)>((o-1|0)/2|0|0)){j=(o-1|0)/2|0}if((h|0)>((o|0)/2|0|0)){h=(o|0)/2|0}k=h+j+1|0}l=a+j|0;mrc(e+147564|0,0,o<<2|0)|0;b=0;while(1){if((b|0)>=(k|0)){break}c[e+147564+(k-1-b<<2)>>2]=Cdc(c[e+114488>>2]|0,l-b|0,1)|0;b=b+1|0}k0b(e,k,h,m);i=d;return}function k0b(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;j=i;i=i+2760|0;k=d;d=f;f=g;g=h;h=c[k+107996>>2]|0;l=c[k+107992>>2]|0;m=0;n=0;o=j+16-1&-16;p=j+1576-1&-16;q=k+76880|0;r=c[k+147564+(f<<2)>>2]|0;s=j+2368-1&-16;t=c[q+2900>>2]|0;u=c[q+2904>>2]|0;v=c[q+2908>>2]|0;w=0;while(1){if((w|0)>=(l|0)){break}c[k+80168>>2]=-((w<<4)+11|0);c[k+80172>>2]=((c[k+107992>>2]|0)-1-w<<4)+11;x=0;while(1){if((x|0)>=(h|0)){break}mrc(o|0,0,1536)|0;mrc(p|0,0,768)|0;c[k+80160>>2]=-((x<<4)+11|0);c[k+80164>>2]=((c[k+107996>>2]|0)-1-x<<4)+11;y=0;while(1){if((y|0)>=(d|0)){break}if((c[k+147564+(y<<2)>>2]|0)!=0){b[q+2168>>1]=0;b[q+2170>>1]=0;if((y|0)==(f|0)){z=2}else{A=0;A=l0b(k,c[k+147564+(f<<2)>>2]|0,c[k+147564+(y<<2)>>2]|0,m,1e4)|0;if((A|0)<1e4){B=2}else{B=(A|0)<2e4?1:0}z=B}if((z|0)!=0){m0b(q,(c[(c[k+147564+(y<<2)>>2]|0)+52>>2]|0)+m|0,(c[(c[k+147564+(y<<2)>>2]|0)+56>>2]|0)+n|0,(c[(c[k+147564+(y<<2)>>2]|0)+60>>2]|0)+n|0,c[(c[k+147564+(y<<2)>>2]|0)+16>>2]|0,b[q+2168>>1]|0,b[q+2170>>1]|0,s);i0b((c[r+52>>2]|0)+m|0,c[r+16>>2]|0,s,16,g,z,o,p);i0b((c[r+56>>2]|0)+n|0,c[r+36>>2]|0,s+256|0,8,g,z,o+1024|0,p+512|0);i0b((c[r+60>>2]|0)+n|0,c[r+36>>2]|0,s+320|0,8,g,z,o+1280|0,p+640|0)}}y=y+1|0}y=c[k+147524>>2]|0;A=c[k+147488>>2]|0;C=m;D=0;E=0;while(1){if((D|0)>=16){break}F=0;while(1){if((F|0)>=16){break}G=(c[o+(E<<2)>>2]|0)+(e[p+(E<<1)>>1]>>1)|0;G=ca(G,c[k+147664+(e[p+(E<<1)>>1]<<2)>>2]|0)|0;G=G>>>19;a[y+C|0]=G;C=C+1|0;F=F+1|0;E=E+1|0}C=C+(A-16)|0;D=D+1|0}y=c[k+147528>>2]|0;G=c[k+147532>>2]|0;A=c[k+147508>>2]|0;C=n;D=0;E=256;while(1){if((D|0)>=8){break}F=0;while(1){if((F|0)>=8){break}H=E+64|0;I=(c[o+(E<<2)>>2]|0)+(e[p+(E<<1)>>1]>>1)|0;I=ca(I,c[k+147664+(e[p+(E<<1)>>1]<<2)>>2]|0)|0;I=I>>>19;a[y+C|0]=I;I=(c[o+(H<<2)>>2]|0)+(e[p+(H<<1)>>1]>>1)|0;I=ca(I,c[k+147664+(e[p+(H<<1)>>1]<<2)>>2]|0)|0;I=I>>>19;a[G+C|0]=I;C=C+1|0;F=F+1|0;E=E+1|0}C=C+(A-8)|0;D=D+1|0}m=m+16|0;n=n+8|0;x=x+1|0}m=m+((c[r+16>>2]|0)-h<<4)|0;n=n+((c[r+36>>2]|0)-h<<3)|0;w=w+1|0}c[q+2900>>2]=t;c[q+2904>>2]=u;c[q+2908>>2]=v;i=j;return}function l0b(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+32|0;h=g|0;j=g+8|0;k=a;a=d;d=e;e=f;f=k+73728|0;l=c[f+6364>>2]|0;m=2147483647;n=f+1860|0;o=f+5296|0;p=c[n+36>>2]|0;q=c[n+40>>2]|0;r=c[n+44>>2]|0;s=c[f+6052>>2]|0;t=c[o+16>>2]|0;u=c[f+6016>>2]|0;c[h>>2]=0;b[j+2>>1]=b[h+2>>1]>>3;b[j>>1]=b[h>>1]>>3;c[n+36>>2]=a+52;c[n+44>>2]=c[a+16>>2];c[n+40>>2]=e;c[f+6052>>2]=c[d+52>>2];c[f+6016>>2]=c[d+16>>2];c[o+16>>2]=e;if((c[k+142356>>2]|0)<8){v=(c[k+142572>>2]|0)+((c[k+142356>>2]|0)>5)|0}else{v=(c[k+142572>>2]|0)+2|0}m=Ldc(f,n,o,j,o+24|0,v,l,k+142932|0,0,0,h)|0;m=Ne[c[k+142772>>2]&15](f,n,o,o+24|0,h,c[f+6360>>2]|0,k+142932|0,0,g+16|0,g+24|0)|0;c[n+36>>2]=p;c[n+40>>2]=q;c[n+44>>2]=r;c[f+6052>>2]=s;c[o+16>>2]=t;c[f+6016>>2]=u;i=g;return m|0}function m0b(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0;k=i;l=a;a=f;f=g;g=h;h=j;j=b+(ca(f>>3,a)|0)+(g>>3)|0;if(((f|g)&7|0)!=0){_e[c[l+3156>>2]&511](j,a,g&7,f&7,h|0,16)}else{O8b(j,a,h|0,16)}f=f>>1;g=g>>1;a=a+1>>1;j=(ca(f>>3,a)|0)+(g>>3)|0;b=d+j|0;d=e+j|0;if(((f|g)&7|0)!=0){_e[c[l+3152>>2]&511](b,a,g&7,f&7,h+256|0,8);_e[c[l+3152>>2]&511](d,a,g&7,f&7,h+320|0,8);i=k;return}else{P8b(b,a,h+256|0,8);P8b(d,a,h+320|0,8);i=k;return}}function n0b(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=b;b=e;e=f;f=b+3152|0;if((d[c[f+3032>>2]|0]|0)!=4){j=(d[c[f+3032>>2]|0]|0)!=9}else{j=0}k=j&1;j=(o0b(f,k)|0)&255;a[(c[f+3032>>2]|0)+9|0]=j;if((a[(c[f+3032>>2]|0)+9|0]|0)==0){j=3;if((k|0)!=0){r0b(b,e,h);j=0}s0b(b,e,j,h);i=g;return}if((c[h+108004>>2]|0)!=0){q0b(f);f=b+6496|0;c[f>>2]=(c[f>>2]|0)+1}else{p0b(h,b,e)}i=g;return}function o0b(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=i;e=b;b=c;c=1;f=0;if((b|0)!=0){f=0;while(1){if((f|0)>=16){break}c=c&(a[e+1984+f|0]|0)<2;f=f+1|0}}while(1){if((f|0)>=(b+24|0)){break}c=c&(((a[e+1984+f|0]|0)!=0^1)&1);f=f+1|0}i=d;return c|0}function p0b(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=b;b=e;e=a+3152|0;h=c[e+3084>>2]|0;j=c[e+3088>>2]|0;k=3;do{if((d[c[e+3032>>2]|0]|0|0)!=4){if((d[c[e+3032>>2]|0]|0|0)==9){break}t0b(b,h+(d[246880]|0)|0,j+(d[246848]|0)|0,g,a);k=0}}while(0);e=0;while(1){if((e|0)>=16){break}u0b(b,h+(d[246856+e|0]|0)|0,j+(d[246824+e|0]|0)|0,k,g,a);e=e+1|0}e=16;while(1){if((e|0)>=24){break}v0b(b,h+(d[246856+e|0]|0)|0,j+(d[246824+e|0]|0)|0,g,a);e=e+1|0}i=f;return}function q0b(a){a=a|0;var b=0,e=0;b=i;e=a;do{if((d[c[e+3032>>2]|0]|0|0)!=4){if((d[c[e+3032>>2]|0]|0|0)==9){break}mrc(c[e+3084>>2]|0,0,9)|0;mrc(c[e+3088>>2]|0,0,9)|0;i=b;return}}while(0);mrc(c[e+3084>>2]|0,0,8)|0;mrc(c[e+3088>>2]|0,0,8)|0;i=b;return}function r0b(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=e;e=f;f=g;g=j+3152|0;k=c[e>>2]|0;l=c[g+2816>>2]|0;m=(c[g+3084>>2]|0)+8|0;n=(c[g+3088>>2]|0)+8|0;o=a[g+2008|0]|0;g=(a[m]|0)+(a[n]|0)|0;if((o|0)==0){a[k+6|0]=11;c[k>>2]=f+112869+(g*11|0);a[k+7|0]=0;p=j+7652+(g*48|0)+44|0;c[p>>2]=(c[p>>2]|0)+1;k=k+8|0;c[e>>2]=k;a[n]=0;a[m]=0;i=h;return}p=b[l>>1]|0;b[k+4>>1]=b[(c[61288]|0)+(p<<2)+2>>1]|0;q=b[(c[61288]|0)+(p<<2)>>1]|0;a[k+6|0]=q;c[k>>2]=f+112869+(g*11|0);a[k+7|0]=0;r=j+7652+(g*48|0)+(q<<2)|0;c[r>>2]=(c[r>>2]|0)+1;g=d[239776+q|0]|0;k=k+8|0;r=1;while(1){if((r|0)>=(o|0)){break}s=d[246688+r|0]|0;p=b[l+(c[245048+(r<<2)>>2]<<1)>>1]|0;b[k+4>>1]=b[(c[61288]|0)+(p<<2)+2>>1]|0;q=b[(c[61288]|0)+(p<<2)>>1]|0;a[k+6|0]=q;c[k>>2]=f+112869+(s*33|0)+(g*11|0);a[k+7|0]=(g|0)==0;t=j+7652+(s*144|0)+(g*48|0)+(q<<2)|0;c[t>>2]=(c[t>>2]|0)+1;g=d[239776+q|0]|0;k=k+8|0;r=r+1|0}if((r|0)<16){s=d[246688+r|0]|0;a[k+6|0]=11;c[k>>2]=f+112869+(s*33|0)+(g*11|0);a[k+7|0]=0;f=j+7652+(s*144|0)+(g*48|0)+44|0;c[f>>2]=(c[f>>2]|0)+1;k=k+8|0}c[e>>2]=k;a[n]=1;a[m]=1;i=h;return}function s0b(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;k=e;e=f;f=g;g=h;h=k+3152|0;l=c[e>>2]|0;m=h+2144|0;n=0;while(1){if(!(n>>>0<16>>>0)){break}o=a[c[m+20>>2]|0]|0;p=d[246856+n|0]|0;q=d[246824+n|0]|0;r=c[m>>2]|0;s=(c[h+3084>>2]|0)+p|0;t=(c[h+3088>>2]|0)+q|0;u=(a[s]|0)+(a[t]|0)|0;v=(f|0)!=0?0:1;if((v|0)>=(o|0)){a[l+6|0]=11;c[l>>2]=g+112605+(f*264|0)+(v*33|0)+(u*11|0);a[l+7|0]=0;w=k+6500+(f*1152|0)+(v*144|0)+(u*48|0)+44|0;c[w>>2]=(c[w>>2]|0)+1;l=l+8|0;c[e>>2]=l;a[t]=0;a[s]=0}else{x=b[r+(v<<1)>>1]|0;b[l+4>>1]=b[(c[61288]|0)+(x<<2)+2>>1]|0;y=b[(c[61288]|0)+(x<<2)>>1]|0;a[l+6|0]=y;c[l>>2]=g+112605+(f*264|0)+(v*33|0)+(u*11|0);a[l+7|0]=0;w=k+6500+(f*1152|0)+(v*144|0)+(u*48|0)+(y<<2)|0;c[w>>2]=(c[w>>2]|0)+1;u=d[239776+y|0]|0;l=l+8|0;v=v+1|0;if((o|0)<=16){}else{Cd(2345328,2561960,254,2651168)}while(1){if((v|0)>=(o|0)){break}z=c[245048+(v<<2)>>2]|0;A=d[246688+v|0]|0;x=b[r+(z<<1)>>1]|0;b[l+4>>1]=b[(c[61288]|0)+(x<<2)+2>>1]|0;y=b[(c[61288]|0)+(x<<2)>>1]|0;a[l+6|0]=y;c[l>>2]=g+112605+(f*264|0)+(A*33|0)+(u*11|0);a[l+7|0]=(u|0)==0;w=k+6500+(f*1152|0)+(A*144|0)+(u*48|0)+(y<<2)|0;c[w>>2]=(c[w>>2]|0)+1;u=d[239776+y|0]|0;l=l+8|0;v=v+1|0}if((v|0)<16){A=d[246688+v|0]|0;a[l+6|0]=11;c[l>>2]=g+112605+(f*264|0)+(A*33|0)+(u*11|0);a[l+7|0]=0;o=k+6500+(f*1152|0)+(A*144|0)+(u*48|0)+44|0;c[o>>2]=(c[o>>2]|0)+1;l=l+8|0}c[e>>2]=l;a[t]=1;a[s]=1}n=n+1|0;m=m+28|0}n=16;while(1){if(!(n>>>0<24>>>0)){break}f=a[c[m+20>>2]|0]|0;p=d[246856+n|0]|0;q=d[246824+n|0]|0;r=c[m>>2]|0;s=(c[h+3084>>2]|0)+p|0;t=(c[h+3088>>2]|0)+q|0;u=(a[s]|0)+(a[t]|0)|0;if((f|0)!=0){x=b[r>>1]|0;b[l+4>>1]=b[(c[61288]|0)+(x<<2)+2>>1]|0;y=b[(c[61288]|0)+(x<<2)>>1]|0;a[l+6|0]=y;c[l>>2]=g+113133+(u*11|0);a[l+7|0]=0;o=k+8804+(u*48|0)+(y<<2)|0;c[o>>2]=(c[o>>2]|0)+1;u=d[239776+y|0]|0;l=l+8|0;v=1;if((f|0)<=16){}else{Cd(2345328,2561960,327,2651168)}while(1){if((v|0)>=(f|0)){break}z=c[245048+(v<<2)>>2]|0;A=d[246688+v|0]|0;x=b[r+(z<<1)>>1]|0;b[l+4>>1]=b[(c[61288]|0)+(x<<2)+2>>1]|0;y=b[(c[61288]|0)+(x<<2)>>1]|0;a[l+6|0]=y;c[l>>2]=g+113133+(A*33|0)+(u*11|0);a[l+7|0]=(u|0)==0;o=k+8804+(A*144|0)+(u*48|0)+(y<<2)|0;c[o>>2]=(c[o>>2]|0)+1;u=d[239776+y|0]|0;l=l+8|0;v=v+1|0}if((v|0)<16){A=d[246688+v|0]|0;a[l+6|0]=11;c[l>>2]=g+113133+(A*33|0)+(u*11|0);a[l+7|0]=0;f=k+8804+(A*144|0)+(u*48|0)+44|0;c[f>>2]=(c[f>>2]|0)+1;l=l+8|0}c[e>>2]=l;a[t]=1;a[s]=1}else{a[l+6|0]=11;c[l>>2]=g+113133+(u*11|0);a[l+7|0]=0;f=k+8804+(u*48|0)+44|0;c[f>>2]=(c[f>>2]|0)+1;l=l+8|0;c[e>>2]=l;a[t]=0;a[s]=0}n=n+1|0;m=m+28|0}i=j;return}function t0b(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;h=b;b=d;d=e;e=c[h>>2]|0;j=(a[b]|0)+(a[d]|0)|0;a[e+6|0]=11;c[e>>2]=f+112869+(j*11|0);a[e+7|0]=0;f=g+7652+(j*48|0)+44|0;c[f>>2]=(c[f>>2]|0)+1;e=e+8|0;c[h>>2]=e;j=0;e=j&255;a[d]=e;a[b]=e;i=i;return}function u0b(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0;j=b;b=d;d=e;e=f;f=c[j>>2]|0;k=(a[b]|0)+(a[d]|0)|0;l=(e|0)!=0?0:1;a[f+6|0]=11;c[f>>2]=g+112605+(e*264|0)+(l*33|0)+(k*11|0);a[f+7|0]=0;g=h+6500+(e*1152|0)+(l*144|0)+(k*48|0)+44|0;c[g>>2]=(c[g>>2]|0)+1;f=f+8|0;c[j>>2]=f;k=0;f=k&255;a[d]=f;a[b]=f;i=i;return}function v0b(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;h=b;b=d;d=e;e=c[h>>2]|0;j=(a[b]|0)+(a[d]|0)|0;a[e+6|0]=11;c[e>>2]=f+113133+(j*11|0);a[e+7|0]=0;f=g+8804+(j*48|0)+44|0;c[f>>2]=(c[f>>2]|0)+1;e=e+8|0;c[h>>2]=e;j=0;e=j&255;a[d]=e;a[b]=e;i=i;return}function w0b(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;x0b(a,c,b,0,0);i=d;return}function x0b(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=b;b=d;d=e;e=f;f=g;g=a[d+(e>>1)|0]|0;do{k=a[b+e|0]|0;if((e&1|0)!=0){l=255-(g&255)|0}else{l=g&255}m=f+(c[238752+(l<<2)>>2]|0)|0;if((k<<24>>24|0)<=0){c[j+(-(k<<24>>24)<<2)>>2]=m}else{x0b(j,b,d,k<<24>>24,m)}m=e+1|0;e=m;}while((m&1|0)!=0);i=h;return}function y0b(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=i;x0b(a,c,b,d,0);i=e;return}function z0b(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)!=0){}else{Cd(2344216,2561728,17,2650792);return 0}A0b(d);c[d>>2]=9;c[d+4>>2]=DYb(c[d>>2]|0,12)|0;i=b;return(c[d+4>>2]|0)==0|0}function A0b(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)!=0){}else{Cd(2344216,2561728,31,2650552)}a=0;while(1){if((a|0)>=(c[d>>2]|0)){break}FYb(c[(c[d+4>>2]|0)+(a*12|0)>>2]|0);c[(c[d+4>>2]|0)+(a*12|0)>>2]=0;a=a+1|0}FYb(c[d+4>>2]|0);c[d+4>>2]=0;i=b;return}function B0b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=b;b=d;d=a;if((d|0)==0){g=-1;h=g;i=e;return h|0}a=0;while(1){if((a|0)>=(c[d>>2]|0)){break}if((c[(c[d+4>>2]|0)+(a*12|0)+8>>2]|0)==0){j=6;break}a=a+1|0}if((a|0)==(c[d>>2]|0)){g=-1;h=g;i=e;return h|0}do{if((c[(c[d+4>>2]|0)+(a*12|0)+4>>2]|0)>>>0<f>>>0){j=EYb(c[(c[d+4>>2]|0)+(a*12|0)>>2]|0,f)|0;c[(c[d+4>>2]|0)+(a*12|0)>>2]=j;if((c[(c[d+4>>2]|0)+(a*12|0)>>2]|0)!=0){c[(c[d+4>>2]|0)+(a*12|0)+4>>2]=f;break}g=-1;h=g;i=e;return h|0}}while(0);c[b>>2]=c[(c[d+4>>2]|0)+(a*12|0)>>2];c[b+4>>2]=c[(c[d+4>>2]|0)+(a*12|0)+4>>2];c[(c[d+4>>2]|0)+(a*12|0)+8>>2]=1;c[b+8>>2]=(c[d+4>>2]|0)+(a*12|0);g=0;h=g;i=e;return h|0}function C0b(a,b){a=a|0;b=b|0;c[(c[b+8>>2]|0)+8>>2]=0;i=i;return 0}function D0b(){if((c[836336]|0)!=0){return}Qhc();mgc();c[836336]=1;return}function E0b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=1;e=0;f=i;i=i+168|0;c[f>>2]=0;while(1)switch(d|0){case 1:g=a;h=Sa(110,32,87584)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;j=h;if((j|0)!=0){d=2;break}else{d=3;break};case 2:k=j+50480|0;d=4;break;case 3:k=0;d=4;break;case 4:l=k;if((l|0)!=0){d=6;break}else{d=5;break};case 5:m=0;d=9;break;case 6:mrc(j|0,0,87584)|0;n=trc(l+92|0,d,f)|0;d=10;break;case 10:if((n|0)!=0){d=7;break}else{d=8;break};case 7:c[l+88>>2]=0;ma(482,j|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;m=0;d=9;break;case 8:c[l+88>>2]=1;bb(8);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;bb(4);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;mrc(l+9784|0,-1|0,32)|0;c[l+36948>>2]=0;h=j+87488|0;o=g;c[h>>2]=c[o>>2];c[h+4>>2]=c[o+4>>2];c[h+8>>2]=c[o+8>>2];c[h+12>>2]=c[o+12>>2];c[h+16>>2]=c[o+16>>2];c[j+87520>>2]=1;c[j+87528>>2]=0;ma(88,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;ma(494,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+88>>2]=0;ma(100,j+87536|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;m=j;d=9;break;case 9:i=b;return m|0;case-1:if((e|0)==6){n=u;d=10}t=u=0;break}return 0}function F0b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a;a=d+50480|0;Zdc(a);c1b(d+87536|0);FYb(c[d+87544>>2]|0);e=0;while(1){if((e|0)>=(c[d+87560>>2]|0)){break}f=(c[d+87556>>2]|0)+(e*20|0)|0;c1b(f);FYb(c[f+8>>2]|0);FYb(c[f+12>>2]|0);e=e+1|0}FYb(c[d+87556>>2]|0);if((c[d+87560>>2]|0)==0){g=d;h=g;FYb(h);i=b;return}P0b(d+87564|0,((c[a+10148>>2]|0)+7&-8)>>3);g=d;h=g;FYb(h);i=b;return}function G0b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=d;d=a+50480|0;if((b|0)!=1){I0b(d|0,1,2561536,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=d;j=h|0;k=j|0;l=c[k>>2]|0;i=e;return l|0}b=d+8488+((c[d+9784>>2]|0)*108|0)+16|0;if((H0b(b,f)|0)!=0){S7b(b,f)}else{I0b(d|0,1,2343632,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}h=d;j=h|0;k=j|0;l=c[k>>2]|0;i=e;return l|0}function H0b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;do{if((c[e+4>>2]|0)==(c[a+4>>2]|0)){if((c[e>>2]|0)!=(c[a>>2]|0)){f=0;break}if((c[e+24>>2]|0)!=(c[a+24>>2]|0)){f=0;break}f=(c[e+20>>2]|0)==(c[a+20>>2]|0)}else{f=0}}while(0);i=d;return f&1|0}function I0b(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function J0b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=a;a=b;b=d;d=0;if((a|0)==1){d=f+9816|0}else{do{if((a|0)==2){d=f+9880|0}else{if((a|0)==4){d=f+9944|0;break}else{I0b(f|0,1,2561536,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g;h=c[f>>2]|0;j=h;i=e;return j|0}}}while(0)}if((H0b(c[d+4>>2]|0,b)|0)!=0){a=d|0;k=f;l=0;while(1){if((l|0)>=12){break}if((c[k+8488+(l*108|0)>>2]|0)==0){m=15;break}l=l+1|0}if((l|0)>=12){Cd(2427280,2343552,223,2652480);return 0}c[k+8488+(l*108|0)>>2]=1;k=l;l=f+8488+(k*108|0)|0;c[l>>2]=(c[l>>2]|0)-1;l=f+8488|0;m=a;n=k;k=c[m>>2]|0;do{if((k|0)>=0){if((c[l+(k*108|0)>>2]|0)<=0){break}o=l+(k*108|0)|0;c[o>>2]=(c[o>>2]|0)-1}}while(0);c[m>>2]=n;m=l+(n*108|0)|0;c[m>>2]=(c[m>>2]|0)+1;c[d+4>>2]=f+8488+((c[a>>2]|0)*108|0)+16;S7b(b,c[d+4>>2]|0)}else{I0b(f|0,1,2343632,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}h=c[f>>2]|0;j=h;i=e;return j|0}function K0b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=b;b=d;d=a+50480|0;do{if((f|0)>=0){if((f|0)>=8){break}c[b>>2]=d+8488+((c[d+9784+(f<<2)>>2]|0)*108|0)+16;g=0;h=g;i=e;return h|0}}while(0);g=-1;h=g;i=e;return h|0}function L0b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,v=0,w=0,x=0,y=0,z=0;g=i;i=i+8|0;h=1;j=0;k=i;i=i+168|0;c[k>>2]=0;while(1)switch(h|0){case 1:l=g|0;m=a;n=b;o=d;c[l>>2]=e;c[l+4>>2]=f;p=m+50480|0;q=c[o>>2]|0;r=0;c[p>>2]=0;if((n|0)==0){h=2;break}else{h=5;break};case 2:if((c[p+9816>>2]|0)!=2147483647){h=3;break}else{h=4;break};case 3:c[(c[p+9820>>2]|0)+84>>2]=1;h=4;break;case 4:h=5;break;case 5:if((c[p+10008>>2]|0)>=0){h=6;break}else{h=8;break};case 6:if((c[p+8488+((c[p+10008>>2]|0)*108|0)>>2]|0)==0){h=7;break}else{h=8;break};case 7:Sa(c[p+36988>>2]|0,c[p+36980>>2]|0,p+8488+((c[p+10008>>2]|0)*108|0)+4|0)|0;if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;h=8;break;case 8:s=p;v=0;h=9;break;case 9:if((v|0)<12){h=10;break}else{h=13;break};case 10:if((c[s+8488+(v*108|0)>>2]|0)==0){h=11;break}else{h=12;break};case 11:h=13;break;case 12:v=v+1|0;h=9;break;case 13:if((v|0)<12){h=15;break}else{h=14;break};case 14:hb(736,2427280,2343552,223,2652480);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;return 0;case 15:c[s+8488+(v*108|0)>>2]=1;c[p+10008>>2]=v;w=trc(p+92|0,h,k)|0;h=38;break;case 38:if((w|0)!=0){h=16;break}else{h=21;break};case 16:c[p+88>>2]=0;if((c[p+9816>>2]|0)!=2147483647){h=17;break}else{h=18;break};case 17:c[(c[p+9820>>2]|0)+84>>2]=1;h=18;break;case 18:if((c[p+8488+((c[p+10008>>2]|0)*108|0)>>2]|0)>0){h=19;break}else{h=20;break};case 19:x=p+8488+((c[p+10008>>2]|0)*108|0)|0;c[x>>2]=(c[x>>2]|0)-1;h=20;break;case 20:y=-1;h=37;break;case 21:c[p+88>>2]=1;x=db(668,m|0,q|0,q+n|0,o|0)|0;if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;r=x;if((r|0)<0){h=22;break}else{h=25;break};case 22:c[p>>2]=1;c[p+88>>2]=0;if((c[p+8488+((c[p+10008>>2]|0)*108|0)>>2]|0)>0){h=23;break}else{h=24;break};case 23:x=p+8488+((c[p+10008>>2]|0)*108|0)|0;c[x>>2]=(c[x>>2]|0)-1;h=24;break;case 24:y=r;h=37;break;case 25:ma(152,m|0);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;if((c[m+87532>>2]|0)!=0){h=30;break}else{h=26;break};case 26:if((c[m+87560>>2]|0)!=0){h=27;break}else{h=28;break};case 27:la(294,m|0,p|0,c[p+13380>>2]|0,0,0);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;h=29;break;case 28:la(564,p|0,m|0,c[p+13380>>2]|0,0,0);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;h=29;break;case 29:h=30;break;case 30:c[p+8468>>2]=c[p+8452>>2];c[p+8472>>2]=c[p+8456>>2];if((c[p+10120>>2]|0)!=0){h=32;break}else{h=31;break};case 31:c[p+10116>>2]=c[p+10112>>2];h=32;break;case 32:if((c[p+10112>>2]|0)!=0){h=33;break}else{h=36;break};case 33:if((c[p+10120>>2]|0)!=0){h=35;break}else{h=34;break};case 34:ma(10,p|0);if((t|0)!=0&(u|0)!=0){j=urc(c[t>>2]|0,k)|0;if((j|0)>0){h=-1;break}else return 0}t=u=0;h=35;break;case 35:x=p+36948|0;c[x>>2]=(c[x>>2]|0)+1;h=36;break;case 36:c[m+87520>>2]=0;x=c[l+4>>2]|0;z=m+87512|0;c[z>>2]=c[l>>2];c[z+4>>2]=x;c[p+88>>2]=0;y=r;h=37;break;case 37:i=g;return y|0;case-1:if((j|0)==15){w=u;h=38}t=u=0;break}return 0}function M0b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=a;a=0;e=d+50480|0;f=c[d+87524>>2]|0;while(1){if((f|0)==0){break}if((f&1|0)!=0){d=c[e+9784+(a<<2)>>2]|0;g=e+8488|0;h=e+9784+(a<<2)|0;j=c[e+10008>>2]|0;k=c[h>>2]|0;do{if((k|0)>=0){if((c[g+(k*108|0)>>2]|0)<=0){break}l=g+(k*108|0)|0;c[l>>2]=(c[l>>2]|0)-1}}while(0);c[h>>2]=j;k=g+(j*108|0)|0;c[k>>2]=(c[k>>2]|0)+1;do{if((d|0)>=0){if((c[e+8488+(d*108|0)>>2]|0)!=0){break}We[c[e+36988>>2]&2047](c[e+36980>>2]|0,e+8488+(d*108|0)+4|0)|0}}while(0)}a=a+1|0;f=f>>1}f=e;c[e+8484>>2]=f+8488+((c[f+10008>>2]|0)*108|0)+16;f=e+8488+((c[e+10008>>2]|0)*108|0)|0;c[f>>2]=(c[f>>2]|0)-1;a=0;while(1){if((a|0)>=3){break}c[e+9816+(a<<6)>>2]=2147483647;a=a+1|0}i=b;return}function N0b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=a;a=b;b=-1;if((c[g+87520>>2]|0)==1){h=b;j=h;i=f;return j|0}if((c[g+60592>>2]|0)==0){h=b;j=h;i=f;return j|0}else{c[g+87520>>2]=1;k=g+87512|0;l=c[k+4>>2]|0;m=d;c[m>>2]=c[k>>2];c[m+4>>2]=l;l=e;c[l>>2]=0;c[l+4>>2]=0;nrc(a|0,c[g+58964>>2]|0,92)|0;c[a>>2]=c[g+58932>>2];c[a+4>>2]=c[g+58936>>2];c[a+20>>2]=c[a>>2]>>c[g+58956>>2];c[a+24>>2]=c[a+4>>2]>>c[g+58960>>2];b=0;h=b;j=h;i=f;return j|0}return 0}function O0b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=a;a=b;b=d;d=e;e=g+87564|0;h=((c[a+10148>>2]|0)+7&-8)>>3;j=1<<c[a+36972>>2];if((c[g+87500>>2]&-2|0)<(j|0)){k=c[g+87500>>2]&-2}else{k=j}j=k;if((c[a+36948>>2]|0)!=0){if((c[a+8472>>2]|0)!=(c[a+8456>>2]|0)){l=6}}else{l=6}if((l|0)==6){if((c[a+8472>>2]|0)!=(c[a+8456>>2]|0)){P0b(e,((((c[a+8472>>2]|0)+7&-8)>>3)+7&-8)>>3)}Q0b(a,e,h,c[a+8452>>2]|0)}if((b|0)==0){i=f;return}zfc(a,b);mrc(c[e>>2]|0,-1|0,h<<2|0)|0;b=0;while(1){if((b|0)>=(j|0)){break}l=(c[g+87556>>2]|0)+(b*20|0)|0;k=(c[l+8>>2]|0)+50512|0;c[l+4>>2]=670;m=a;c[k>>2]=m+8488+((c[m+10008>>2]|0)*108|0)+16;c[k+4>>2]=a;nrc(k+16|0,g|0,50480)|0;c[k+50496>>2]=b;c[k+50500>>2]=h;c[k+50504>>2]=d;c[k+50508>>2]=e;c[k+50512>>2]=j;if((b|0)==(j-1|0)){a1b(l)}else{b1b(l)}b=b+1|0}b=0;while(1){if((b|0)>=(j|0)){break}_0b((c[g+87556>>2]|0)+(b*20|0)|0)|0;b=b+1|0}i=f;return}function P0b(a,b){a=a|0;b=b|0;var d=0;b=i;d=a;if((d|0)==0){i=b;return}FYb(c[d>>2]|0);mrc(d|0,0,8)|0;i=b;return}function Q0b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=b;c[g>>2]=CYb(d<<2)|0;if((c[g>>2]|0)==0){S0b(a|0,2,2342568,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a}c[g+4>>2]=T0b(e)|0;i=f;return}function R0b(a,b){a=a|0;b=b|0;var d=0;b=i;d=a+50512|0;U0b(c[d>>2]|0,c[d+4>>2]|0,d+16|0,c[d+50496>>2]|0,c[d+50500>>2]|0,c[d+50504>>2]|0,c[d+50508>>2]|0,c[d+50512>>2]|0);i=b;return 1}function S0b(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function T0b(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;do{if((c|0)<640){d=1}else{if((c|0)<=1280){d=2;break}if((c|0)<=4096){d=4;break}else{d=8;break}}}while(0);i=b;return d|0}function U0b(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+176|0;k=h|0;l=a;a=b;b=d;d=f;f=j;j=(g|0)!=0?1:3;g=((c[a+10156>>2]|0)+7&-8)>>3;m=e;while(1){if((m|0)>=(d|0)){break}e=m<<3;n=(c[a+10204>>2]|0)+((ca(e,c[a+10160>>2]|0)|0)<<2)|0;o=0;while(1){if((o|0)>=(g|0)){break}p=o<<3;zgc(b,l,e,p);Afc(a,e,p,n+(p<<2)|0,c[a+10160>>2]|0,k);p=0;while(1){if((p|0)>=(j|0)){break}Dfc(a,b+(p*52|0)|0,e,k);p=p+1|0}o=o+1|0}m=m+f|0}i=h;return}function V0b(a){a=a|0;var b=0;b=a;i=i;return(((c[b+8>>2]|0)>>>0)/8|0)+((((c[b+8>>2]|0)>>>0)%8|0)>>>0>0>>>0)|0}function W0b(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;e=a;a=c[e+8>>2]|0;f=(a>>>0)/8|0;g=7-((a|0)%8|0)|0;if(((c[e>>2]|0)+f|0)>>>0>=(c[e+4>>2]|0)>>>0){qe[c[e+16>>2]&1023](c[e+12>>2]|0);h=0;j=h;i=b;return j|0}else{k=((d[(c[e>>2]|0)+f|0]|0)&1<<g)>>g;c[e+8>>2]=a+1;h=k;j=h;i=b;return j|0}return 0}function X0b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=0;e=b-1|0;while(1){if((e|0)<0){break}a=a|(W0b(d)|0)<<e;e=e-1|0}i=c;return a|0}function Y0b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=X0b(d,b)|0;if((W0b(d)|0)!=0){e=-a|0;i=c;return e|0}else{e=a;i=c;return e|0}return 0}function Z0b(a){a=a|0;var b=0,d=0;b=i;d=a;mrc(d|0,0,20)|0;c[d>>2]=0;i=b;return}function _0b(a){a=a|0;var b=0,d=0;b=i;d=a;if((c[d>>2]|0)>>>0<=1>>>0){}else{Cd(2342168,2561216,82,2649880);return 0}i=b;return((c[d+16>>2]|0)!=0^1)&1|0}function $0b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=1;c[d+16>>2]=0;if((c[d>>2]|0)>>>0<1>>>0){c[d>>2]=1}else{if((c[d>>2]|0)>>>0>1>>>0){a=_0b(d)|0}}if((a|0)==0){e=1;f=e&1;g=a;i=b;return g|0}if((c[d>>2]|0)==1){e=1;f=e&1;g=a;i=b;return g|0}Cd(2427024,2561216,105,2649896);return 0}function a1b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;if((c[d+4>>2]|0)==0){i=b;return}a=((We[c[d+4>>2]&2047](c[d+8>>2]|0,c[d+12>>2]|0)|0)!=0^1)&1;e=d+16|0;c[e>>2]=c[e>>2]|a;i=b;return}function b1b(a){a=a|0;var b=0;b=i;a1b(a);i=b;return}function c1b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;if((c[d>>2]|0)>>>0>=1>>>0){c[d>>2]=0}if((c[d>>2]|0)==0){e=1;f=e&1;i=b;return}Cd(2343400,2561216,134,2649920);f=e&1;i=b;return}function d1b(){if((c[836334]|0)!=0){return}Qhc();mgc();j6b();k6b();y3b();N2b();Lmc();gkc();c[836334]=1;return}function e1b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=d+1434592|0;if((Ydc(a,c[a+8452>>2]|0,c[a+8456>>2]|0)|0)!=0){f1b(a|0,2,2341464,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}if((M7b(d+1472180|0,c[a+8452>>2]|0,c[a+8456>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,160)|0)!=0){f1b(a|0,2,2561056,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}if((M7b(d+1471916|0,c[a+8452>>2]|0,c[a+8456>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,160)|0)!=0){f1b(a|0,2,2426928,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}if((M7b(d+1472012|0,c[a+8452>>2]|0,c[a+8456>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,160)|0)!=0){f1b(a|0,2,2343232,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}FYb(c[d+1472272>>2]|0);c[d+1472272>>2]=DYb((ca(c[a+10144>>2]|0,c[a+10152>>2]|0)|0)*772|0,8)|0;if((c[d+1472272>>2]|0)==0){f1b(a|0,2,2283456,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}FYb(c[d+2050760>>2]|0);c[d+2050760>>2]=DYb(4,ca(c[a+10144>>2]|0,c[a+10152>>2]|0)|0)|0;if((c[d+2050760>>2]|0)==0){f1b(a|0,2,2234128,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}FYb(c[d+2050764>>2]|0);c[d+2050764>>2]=DYb(4,ca(c[a+10144>>2]|0,c[a+10152>>2]|0)|0)|0;if((c[d+2050764>>2]|0)==0){f1b(a|0,2,2194512,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e}i=b;return}function f1b(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function g1b(a,b){a=a|0;b=+b;var c=0,d=0,e=0.0,f=0.0;c=i;d=a;e=b;if(e<.1){f=30.0}else{f=e}h[d+1471616>>3]=f;t3b(d);i=c;return}function h1b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+40|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;c[h>>2]=a;c[h+4>>2]=b;c[j>>2]=d;c[j+4>>2]=e;e=c[j+4>>2]|0;c[k>>2]=c[j>>2];c[k+4>>2]=e;e=f;c[l>>2]=e;c[l+4>>2]=(e|0)<0|0?-1:0;e=c[h+4>>2]|0;c[m>>2]=c[h>>2];c[m+4>>2]=e;e=Erc(c[m>>2]|0,c[m+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;k=Crc(e,G,c[l>>2]|0,c[l+4>>2]|0)|0;l=G;i=g;return(G=l,k)|0}function i1b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;d=i;e=a;a=b;b=e+1434592|0;f=e+2017128|0;if((c[b+36952>>2]|0)!=(c[a>>2]|0)){c[b+36952>>2]=c[a>>2]}c[b+36956>>2]=c[a+4>>2];if((c[b+36952>>2]|0)>>>0<=1>>>0){if((c[b+36956>>2]|0)==0){}else{Cd(2163416,2137528,702,2650736)}}else{if((c[b+36956>>2]|0)>>>0>0>>>0){}else{Cd(2114192,2137528,704,2650736)}}nrc(e+1471600|0,a|0,288)|0;if((c[e+1471640>>2]|0)==-6){c[e+1471828>>2]=0}switch(c[e+1471648>>2]|0){case 1:{c[e+2046868>>2]=0;g=c[e+1471640>>2]|0;j=-5;k=5;if((g|0)<(j|0)){l=j}else{if((g|0)>(k|0)){m=k}else{m=g}l=m}c[e+1471640>>2]=l;break};case 3:{c[e+2046868>>2]=1;break};case 2:{c[e+2046868>>2]=0;break};case 4:{c[e+2046868>>2]=2;l=c[e+1471640>>2]|0;m=-5;g=5;if((l|0)<(m|0)){n=m}else{if((l|0)>(g|0)){o=g}else{o=l}n=o}c[e+1471640>>2]=n;break};case 5:{c[e+2046868>>2]=2;break};case 6:{c[e+2046868>>2]=0;break};default:{}}c[e+1471724>>2]=c[a+124>>2];if((c[e+1471724>>2]|0)!=0){c[e+1471712>>2]=0;c[e+1471716>>2]=0;c[e+83300>>2]=24}else{c[e+83300>>2]=102}c[f+80>>2]=10;c[e+2046872>>2]=7;c[e+1472148>>2]=0;c[e+1472144>>2]=1;c[b+13360>>2]=1;c[b+10132>>2]=0;R5b(b+13408|0);j1b(e,0);a=0;while(1){if((a|0)>=8){break}c[e+2047184+(a<<2)>>2]=c[e+1471836>>2];a=a+1|0}c[e+2047176>>2]=c[e+1471836>>2];if((c[e+1471664>>2]|0)==0){a=e+1471680|0;c[a>>2]=6e4;c[a+4>>2]=0;a=e+1471688|0;c[a>>2]=6e4;c[a+4>>2]=0;a=e+1471696|0;c[a>>2]=24e4;c[a+4>>2]=0}a=e+1471624|0;n=Erc(c[a>>2]|0,c[a+4>>2]|0,1e3,0)|0;c[a>>2]=n;c[a+4>>2]=G;a=e+1471680|0;n=e+1471624|0;o=h1b(c[a>>2]|0,c[a+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0,1e3)|0;n=e+1471680|0;c[n>>2]=o;c[n+4>>2]=G;n=e+1471688|0;if((c[n>>2]|0)==0&(c[n+4>>2]|0)==0){n=e+1471624|0;o=Crc(c[n>>2]|0,c[n+4>>2]|0,8,0)|0;n=e+1471688|0;c[n>>2]=o;c[n+4>>2]=G}else{n=e+1471688|0;o=e+1471624|0;a=h1b(c[n>>2]|0,c[n+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0,1e3)|0;o=e+1471688|0;c[o>>2]=a;c[o+4>>2]=G}o=e+1471696|0;if((c[o>>2]|0)==0&(c[o+4>>2]|0)==0){o=e+1471624|0;a=Crc(c[o>>2]|0,c[o+4>>2]|0,8,0)|0;o=e+1471696|0;c[o>>2]=a;c[o+4>>2]=G}else{o=e+1471696|0;a=e+1471624|0;n=h1b(c[o>>2]|0,c[o+4>>2]|0,c[a>>2]|0,c[a+4>>2]|0,1e3)|0;a=e+1471696|0;c[a>>2]=n;c[a+4>>2]=G}a=f+176|0;n=c[a+4>>2]|0;o=e+1471696|0;l=c[o+4>>2]|0;if((n|0)<(l|0)|(n|0)==(l|0)&(c[a>>2]|0)>>>0<(c[o>>2]|0)>>>0){o=f+176|0;p=c[o+4>>2]|0;q=c[o>>2]|0}else{o=e+1471696|0;p=c[o+4>>2]|0;q=c[o>>2]|0}o=f+176|0;c[o>>2]=q;c[o+4>>2]=p;p=f+168|0;o=c[p+4>>2]|0;q=e+1471696|0;a=c[q+4>>2]|0;if((o|0)<(a|0)|(o|0)==(a|0)&(c[p>>2]|0)>>>0<(c[q>>2]|0)>>>0){q=f+168|0;r=c[q+4>>2]|0;s=c[q>>2]|0}else{q=e+1471696|0;r=c[q+4>>2]|0;s=c[q>>2]|0}q=f+168|0;c[q>>2]=s;c[q+4>>2]=r;g1b(e,+h[e+1471616>>3]);c[f+232>>2]=c[e+1471712>>2];c[f+236>>2]=c[e+1471716>>2];c[e+2017368>>2]=c[e+1471720>>2];c[b+10220>>2]=4;c[b+8460>>2]=c[e+1471608>>2];c[b+8464>>2]=c[e+1471612>>2];c[b+13384>>2]=c[e+1471636>>2];if((c[e+2050792>>2]|0)!=0){if((c[b+8452>>2]|0)<=(c[e+2050792>>2]|0)){}else{Cd(2632256,2137528,824,2650736)}if((c[b+8456>>2]|0)<=(c[e+2050796>>2]|0)){}else{Cd(2608192,2137528,825,2650736)}}k1b(e);if((c[e+2050820>>2]|0)>1){if((c[e+1471664>>2]|0)!=1){t=60}}else{t=60}do{if((t|0)==60){if((c[e+2050816>>2]|0)<=1){u=e;v=u+1471600|0;w=v+40|0;x=c[w>>2]|0;y=R(x|0)|0;z=e;A=z+2046860|0;c[A>>2]=y;B=e;C=B+1471896|0;c[C>>2]=0;D=f;E=D+108|0;c[E>>2]=0;F=e;l1b(F);H=e;I=H+1472156|0;c[I>>2]=0;J=e;K=J+1472172|0;c[K>>2]=0;i=d;return}if((c[e+2046868>>2]|0)==2){break}u=e;v=u+1471600|0;w=v+40|0;x=c[w>>2]|0;y=R(x|0)|0;z=e;A=z+2046860|0;c[A>>2]=y;B=e;C=B+1471896|0;c[C>>2]=0;D=f;E=D+108|0;c[E>>2]=0;F=e;l1b(F);H=e;I=H+1472156|0;c[I>>2]=0;J=e;K=J+1472172|0;c[K>>2]=0;i=d;return}}while(0);X5b(e,c[e+1471624>>2]|0);u=e;v=u+1471600|0;w=v+40|0;x=c[w>>2]|0;y=R(x|0)|0;z=e;A=z+2046860|0;c[A>>2]=y;B=e;C=B+1471896|0;c[C>>2]=0;D=f;E=D+108|0;c[E>>2]=0;F=e;l1b(F);H=e;I=H+1472156|0;c[I>>2]=0;J=e;K=J+1472172|0;c[K>>2]=0;i=d;return}function j1b(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=e+32768|0;c[e+1444720>>2]=b;if((c[e+1444720>>2]|0)!=0){c[a+599640>>2]=a+599632;c[a+1123948>>2]=a+1123940;i=d;return}else{c[a+599640>>2]=a+337488;c[a+1123948>>2]=a+861796;i=d;return}}function k1b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;a=d+1434592|0;e=d+57488|0;_dc(a);if((L7b(d+1472180|0,c[a+8452>>2]|0,c[a+8456>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,160,0,0,0)|0)!=0){f1b(a|0,2,2306648,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}if((L7b(d+1471916|0,c[a+8452>>2]|0,c[a+8456>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,160,0,0,0)|0)!=0){f1b(a|0,2,2300032,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}if((L7b(d+1472012|0,c[a+8452>>2]|0,c[a+8456>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,160,0,0,0)|0)!=0){f1b(a|0,2,2288912,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}f=c[d+1471932>>2]|0;if((c[d+2046880>>2]|0)==1){$nc(d+32768|0,f)}else{if((c[d+2046880>>2]|0)==0){_nc(d+32768|0,f)}}f=a;a=e;e=0;while(1){if((e|0)>=3){break}c[a+(e*52|0)>>2]=a+25824+(e<<13);c[a+50400+(e<<2)>>2]=(c[f+37004>>2]|0)+(ca(e<<1,(c[f+10156>>2]|0)+7&-8)|0);e=e+1|0}c[a+50460>>2]=c[f+37e3>>2];c[a+156>>2]=c[f+10160>>2];i=b;return}function l1b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a;a=f+1434592|0;aic(c[a+10156>>2]|0,d,e);g=c[f+1471860>>2]|0;h=c[d>>2]|0;d=c[e>>2]|0;if((g|0)<(h|0)){j=h}else{if((g|0)>(d|0)){k=d}else{k=g}j=k}c[a+36972>>2]=j;c[a+36976>>2]=c[f+1471864>>2];i=b;return}function m1b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+24|0;d=1;e=0;f=i;i=i+168|0;c[f>>2]=0;while(1)switch(d|0){case 1:g=b|0;j=a;k=Sa(110,32,2055632)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;l=k;if((l|0)!=0){d=2;break}else{d=3;break};case 2:m=l+1434592|0;d=4;break;case 3:m=0;d=4;break;case 4:n=m;if((n|0)!=0){d=6;break}else{d=5;break};case 5:o=0;d=81;break;case 6:mrc(l|0,0,2055632)|0;p=trc(n+92|0,d,f)|0;d=82;break;case 82:if((p|0)!=0){d=7;break}else{d=8;break};case 7:c[n+88>>2]=0;ma(462,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;o=0;d=81;break;case 8:c[n+88>>2]=1;d=9;break;case 9:k=Sa(314,8,89)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+107988>>2]=k;if((c[l+107988>>2]|0)!=0){d=11;break}else{d=10;break};case 10:hb(22,n|0,2,2581704,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=q;d=11;break;case 11:d=12;break;case 12:bb(4);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+2050800>>2]=0;na(100,l|0,j|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;ab(2040,l+1471600|0,c[l+2046868>>2]|0,l+2017128|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;ma(544,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[n+36948>>2]=0;c[n+13376>>2]=1;c[l+1472108>>2]=0;c[l+1472112>>2]=0;c[l+1472116>>2]=0;d=13;break;case 13:k=Sa(314,ca(c[n+10148>>2]|0,c[n+10156>>2]|0)|0,1)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+2047180>>2]=k;if((c[l+2047180>>2]|0)!=0){d=15;break}else{d=14;break};case 14:hb(22,n|0,2,2561464,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=q;d=15;break;case 15:d=16;break;case 16:d=17;break;case 17:k=Sa(314,ca(c[n+10148>>2]|0,c[n+10156>>2]|0)|0,1)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+2047216>>2]=k;if((c[l+2047216>>2]|0)!=0){d=19;break}else{d=18;break};case 18:hb(22,n|0,2,2544064,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=q;d=19;break;case 19:d=20;break;case 20:d=21;break;case 21:k=Sa(940,c[n+10148>>2]|0,c[n+10156>>2]|0)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+2047228>>2]=k;if((c[l+2047228>>2]|0)!=0){d=23;break}else{d=22;break};case 22:hb(22,n|0,2,2526504,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=q;d=23;break;case 23:d=24;break;case 24:d=25;break;case 25:k=Sa(314,ca(c[n+10148>>2]|0,c[n+10156>>2]|0)|0,1)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+2015036>>2]=k;if((c[l+2015036>>2]|0)!=0){d=27;break}else{d=26;break};case 26:hb(22,n|0,2,2511336,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=q;d=27;break;case 27:d=28;break;case 28:d=29;break;case 29:k=Sa(314,c[n+10140>>2]|0,1)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+2047220>>2]=k;if((c[l+2047220>>2]|0)!=0){d=31;break}else{d=30;break};case 30:hb(22,n|0,2,2497224,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=q;d=31;break;case 31:d=32;break;case 32:mrc(c[l+2047220>>2]|0,1,c[n+10140>>2]|0)|0;c[l+2047224>>2]=0;r=0;d=33;break;case 33:if(r>>>0<25>>>0){d=34;break}else{d=40;break};case 34:d=35;break;case 35:k=Sa(314,c[n+10140>>2]<<5|0,1)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+2046752+(r<<2)>>2]=k;if((c[l+2046752+(r<<2)>>2]|0)!=0){d=37;break}else{d=36;break};case 36:hb(22,n|0,2,2486048,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=q;d=37;break;case 37:d=38;break;case 38:d=39;break;case 39:r=r+1|0;d=33;break;case 40:c[l+2050756>>2]=368640;c[l+1472104>>2]=c[l+1471656>>2];c[l+1472152>>2]=0;c[l+2050752>>2]=0;k=l+2017120|0;c[k>>2]=-1;c[k+4>>2]=2147483647;ma(578,l+632412|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+370256>>2]=l+173652;c[l+370260>>2]=l+304720;c[l+894564>>2]=l+697960;c[l+894568>>2]=l+829028;ma(134,l+894564|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+632400>>2]=l+435796;c[l+632404>>2]=l+566864;c[l+1156708>>2]=l+960104;c[l+1156712>>2]=l+1091172;ma(336,l+1156708|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[l+2046748>>2]=c[j+276>>2];c[l+2047172>>2]=1;if((c[l+2046868>>2]|0)==1){d=41;break}else{d=42;break};case 41:ma(84,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;d=68;break;case 42:if((c[l+2046868>>2]|0)==2){d=43;break}else{d=67;break};case 43:s=((c[j+272>>2]|0)>>>0)/160|0;if((c[l+2050816>>2]|0)>1){d=44;break}else{d=65;break};case 44:if((c[l+2050820>>2]|0)==1){d=45;break}else{d=65;break};case 45:v=c[j+268>>2]|0;mrc(g|0,0,20)|0;w=0;d=46;break;case 46:if((w|0)<(c[j+160>>2]|0)){d=47;break}else{d=56;break};case 47:k=v+((s-(c[j+160>>2]|0)+w|0)*160|0)|0;x=c[k+152>>2]|0;y=~~+h[k+144>>3]+1|0;if((x|0)>=0){d=48;break}else{d=54;break};case 48:if((x|0)<(c[j+160>>2]|0)){d=49;break}else{d=54;break};case 49:z=l+2050824+(x*960|0)|0;ma(112,c[z+944>>2]|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[z+948>>2]=y*160|0;d=50;break;case 50:k=ra(2376,c[z+948>>2]|0)|0;if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[z+944>>2]=k;if((c[z+944>>2]|0)!=0){d=52;break}else{d=51;break};case 51:hb(22,n|0,2,2474368,(q=i,i=i+1|0,i=i+7&-8,c[q>>2]=0,q)|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;i=q;d=52;break;case 52:d=53;break;case 53:c[z+628>>2]=c[z+944>>2];c[z+624>>2]=c[z+628>>2];c[z+632>>2]=(c[z+628>>2]|0)+(y*160|0)-160;c[g+(x<<2)>>2]=c[z+944>>2];d=54;break;case 54:d=55;break;case 55:w=w+1|0;d=46;break;case 56:w=0;d=57;break;case 57:if((w|0)<(s|0)){d=58;break}else{d=64;break};case 58:A=c[v+(w*160|0)+152>>2]|0;if((A|0)>=0){d=59;break}else{d=62;break};case 59:if((A|0)<(c[j+160>>2]|0)){d=60;break}else{d=62;break};case 60:if((c[g+(A<<2)>>2]|0)!=0){d=61;break}else{d=62;break};case 61:nrc(c[g+(A<<2)>>2]|0,v+(w*160|0)|0,160)|0;k=g+(A<<2)|0;c[k>>2]=(c[k>>2]|0)+160;d=62;break;case 62:d=63;break;case 63:w=w+1|0;d=57;break;case 64:ma(132,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;d=66;break;case 65:c[l+2048196>>2]=c[j+268>>2];c[l+2048192>>2]=c[l+2048196>>2];c[l+2048200>>2]=(c[l+2048192>>2]|0)+((s-1|0)*160|0);ma(6,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;d=66;break;case 66:d=67;break;case 67:d=68;break;case 68:ma(440,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;r=0;d=69;break;case 69:if((r|0)<13){d=70;break}else{d=80;break};case 70:B=0;d=71;break;case 71:if((B|0)<30){d=72;break}else{d=74;break};case 72:c[l+1485928+(r*120|0)+(B<<2)>>2]=32;d=73;break;case 73:B=B+1|0;d=71;break;case 74:B=0;d=75;break;case 75:if((B|0)<6){d=76;break}else{d=78;break};case 76:c[l+1489984+(r*24|0)+(B<<2)>>2]=32;d=77;break;case 77:B=B+1|0;d=75;break;case 78:d=79;break;case 79:r=r+1|0;d=69;break;case 80:c[l+2047604>>2]=318;c[l+2047608>>2]=18;c[l+2047612>>2]=256;c[l+2047616>>2]=46;c[l+2047620>>2]=20;c[l+2047624>>2]=0;c[l+2047628>>2]=0;c[l+2047632>>2]=0;c[l+2047636>>2]=0;c[l+2047640>>2]=0;c[l+2047644>>2]=122;c[l+2047560>>2]=316;c[l+2047564>>2]=64;c[l+2047568>>2]=88;c[l+2047572>>2]=112;c[l+2047576>>2]=16;c[l+2047580>>2]=0;c[l+2047584>>2]=0;c[l+2047588>>2]=0;c[l+2047592>>2]=0;c[l+2047596>>2]=0;c[l+2047600>>2]=580;c[l+2047736>>2]=242;c[l+2047740>>2]=20;c[l+2047744>>2]=18;c[l+2047748>>2]=92;c[l+2047752>>2]=38;c[l+2047756>>2]=0;c[l+2047760>>2]=0;c[l+2047764>>2]=0;c[l+2047768>>2]=0;c[l+2047772>>2]=0;c[l+2047776>>2]=94;c[l+2047692>>2]=234;c[l+2047696>>2]=36;c[l+2047700>>2]=36;c[l+2047704>>2]=32;c[l+2047708>>2]=4;c[l+2047712>>2]=0;c[l+2047716>>2]=0;c[l+2047720>>2]=0;c[l+2047724>>2]=0;c[l+2047728>>2]=0;c[l+2047732>>2]=622;c[l+2047648>>2]=312;c[l+2047652>>2]=60;c[l+2047656>>2]=74;c[l+2047660>>2]=132;c[l+2047664>>2]=10;c[l+2047668>>2]=58;c[l+2047672>>2]=128;c[l+2047676>>2]=34;c[l+2047680>>2]=610;c[l+2047684>>2]=108;c[l+2047688>>2]=176;c[l+2047780>>2]=148;c[l+2047784>>2]=70;c[l+2047788>>2]=52;c[l+2047792>>2]=30;c[l+2047796>>2]=22;c[l+2047800>>2]=158;c[l+2047804>>2]=248;c[l+2047808>>2]=72;c[l+2047812>>2]=530;c[l+2047816>>2]=152;c[l+2047820>>2]=498;c[l+2047516>>2]=132;c[l+2047520>>2]=54;c[l+2047524>>2]=134;c[l+2047528>>2]=44;c[l+2047532>>2]=14;c[l+2047536>>2]=232;c[l+2047540>>2]=136;c[l+2047544>>2]=206;c[l+2047548>>2]=52;c[l+2047552>>2]=654;c[l+2047556>>2]=620;c[l+2047472>>2]=274;c[l+2047476>>2]=6;c[l+2047480>>2]=190;c[l+2047484>>2]=160;c[l+2047488>>2]=6;c[l+2047492>>2]=0;c[l+2047496>>2]=0;c[l+2047500>>2]=0;c[l+2047504>>2]=140;c[l+2047508>>2]=56;c[l+2047512>>2]=298;c[l+2047428>>2]=50;c[l+2047432>>2]=56;c[l+2047436>>2]=16;c[l+2047440>>2]=100;c[l+2047444>>2]=34;c[l+2047448>>2]=0;c[l+2047452>>2]=0;c[l+2047456>>2]=0;c[l+2047460>>2]=410;c[l+2047464>>2]=368;c[l+2047468>>2]=518;c[l+2047384>>2]=214;c[l+2047388>>2]=50;c[l+2047392>>2]=226;c[l+2047396>>2]=26;c[l+2047400>>2]=12;c[l+2047404>>2]=0;c[l+2047408>>2]=0;c[l+2047412>>2]=0;c[l+2047416>>2]=148;c[l+2047420>>2]=162;c[l+2047424>>2]=664;c[l+2047340>>2]=170;c[l+2047344>>2]=40;c[l+2047348>>2]=90;c[l+2047352>>2]=130;c[l+2047356>>2]=30;c[l+2047360>>2]=0;c[l+2047364>>2]=0;c[l+2047368>>2]=0;c[l+2047372>>2]=0;c[l+2047376>>2]=552;c[l+2047380>>2]=180;c[l+2047296>>2]=150;c[l+2047300>>2]=32;c[l+2047304>>2]=162;c[l+2047308>>2]=68;c[l+2047312>>2]=18;c[l+2047316>>2]=0;c[l+2047320>>2]=0;c[l+2047324>>2]=0;c[l+2047328>>2]=0;c[l+2047332>>2]=670;c[l+2047336>>2]=164;c[l+2047252>>2]=240;c[l+2047256>>2]=14;c[l+2047260>>2]=324;c[l+2047264>>2]=36;c[l+2047268>>2]=40;c[l+2047272>>2]=0;c[l+2047276>>2]=0;c[l+2047280>>2]=0;c[l+2047284>>2]=92;c[l+2047288>>2]=608;c[l+2047292>>2]=264;c[l+2047240>>2]=158;c[l+2047248>>2]=28;c[l+2047244>>2]=68;ma(432,l|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;ma(494,n|0);if((t|0)!=0&(u|0)!=0){e=urc(c[t>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return 0}t=u=0;c[n+88>>2]=0;o=l;d=81;break;case 81:i=b;return o|0;case-1:if((e|0)==6){p=u;d=82}t=u=0;break}return 0}function n1b(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)==0){i=b;return}do{if((d|0)!=0){if(!((c[d+1471540>>2]|0)>>>0>0>>>0)){break}}}while(0);u1b(d+32768|0);v1b(d);FYb(c[d+107988>>2]|0);FYb(c[d+1472272>>2]|0);a=0;while(1){if(!(a>>>0<25>>>0)){break}FYb(c[d+2046752+(a<<2)>>2]|0);a=a+1|0}Zdc(d+1434592|0);FYb(d);i=b;return}function o1b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;b=e+1434592|0;nrc(e+1471600|0,a|0,288)|0;c[b+36952>>2]=c[a>>2];c[b+36956>>2]=c[a+4>>2];c[b+8452>>2]=c[a+8>>2];c[b+8456>>2]=c[a+12>>2];c[b+8476>>2]=0;c[b+8480>>2]=0;e1b(e);c[e+2050816>>2]=c[a+160>>2];c[e+2050820>>2]=c[a+164>>2];if((c[e+2050820>>2]|0)>1){if((c[e+1471664>>2]|0)==1){f=5}else{f=3}}else{f=3}do{if((f|0)==3){if((c[e+2050816>>2]|0)<=1){break}if((c[e+1471648>>2]|0)==5){f=5}}}while(0);if((f|0)==5){W5b(e)}i1b(e,a);c[e+2046856>>2]=0;c[e+1472132>>2]=0;c[e+1472136>>2]=1;c[e+1472140>>2]=2;l1b(e);c[e+2048704>>2]=0;a=1;while(1){if((a|0)>=512){break}c[e+2048704+(a<<2)>>2]=524288/(a|0)|0;a=a+1|0}i=d;return}function p1b(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b;b=f+1434592|0;g=f+32768|0;f=0;a:while(1){if((f|0)>=13){h=101;break}j=c[777792+(f<<2)>>2]|0;k=c[777848+(f<<2)>>2]|0;if(4>(ca(j,k)|0)){l=4}else{l=ca(j,k)|0}k=l;if((f|0)<6){a[g+1128232|0]=0;while(1){if((d[g+1128232|0]|0|0)>=4){break}a[g+1128233|0]=0;while(1){if((d[g+1128233|0]|0|0)>=4){break}a[g+1128234|0]=0;while(1){if((d[g+1128234|0]|0|0)>=(16/(k|0)|0|0)){break}j=g;switch(f|0){case 4:{m=j+1338216+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 3:{m=j+1299816+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 12:{m=j+1400616|0;break};case 5:{m=j+1357416+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 10:{m=j+1398216+((d[j+1128232|0]|0)*600|0)|0;break};case 1:{m=j+1261416+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 6:{m=j+1376616+((d[j+1128232|0]|0)*2400|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 2:{m=j+1223016+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 0:{m=j+1184616+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 7:{m=j+1391016+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 8:{m=j+1386216+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 11:{m=j+1399416+((d[j+1128232|0]|0)*600|0)|0;break};case 9:{m=j+1395816+((d[j+1128232|0]|0)*600|0)|0;break};default:{h=27;break a}}x2b(b,k,m);j=g+1128234|0;a[j]=(a[j]|0)+1}j=g+1128233|0;a[j]=(a[j]|0)+1}j=g+1128232|0;a[j]=(a[j]|0)+1}}else{if((f|0)<9){a[g+1128232|0]=0;while(1){if((d[g+1128232|0]|0|0)>=4){break}a[g+1128233|0]=0;while(1){if((d[g+1128233|0]|0|0)>=(64/(k|0)|0|0)){break}j=g;switch(f|0){case 7:{n=j+1391016+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 6:{n=j+1376616+((d[j+1128232|0]|0)*2400|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 5:{n=j+1357416+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 4:{n=j+1338216+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 3:{n=j+1299816+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 0:{n=j+1184616+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 8:{n=j+1386216+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 2:{n=j+1223016+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 1:{n=j+1261416+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 9:{n=j+1395816+((d[j+1128232|0]|0)*600|0)|0;break};case 11:{n=j+1399416+((d[j+1128232|0]|0)*600|0)|0;break};case 10:{n=j+1398216+((d[j+1128232|0]|0)*600|0)|0;break};case 12:{n=j+1400616|0;break};default:{h=54;break a}}j=n;c[j+420>>2]=k;x2b(b,k,j);j=g+1128233|0;a[j]=(a[j]|0)+1}j=g+1128232|0;a[j]=(a[j]|0)+1}}else{if((f|0)<12){a[g+1128232|0]=0;while(1){if((d[g+1128232|0]|0|0)>=(256/(k|0)|0|0)){break}j=g;switch(f|0){case 3:{o=j+1299816+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 2:{o=j+1223016+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 7:{o=j+1391016+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 6:{o=j+1376616+((d[j+1128232|0]|0)*2400|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 1:{o=j+1261416+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 12:{o=j+1400616|0;break};case 0:{o=j+1184616+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 11:{o=j+1399416+((d[j+1128232|0]|0)*600|0)|0;break};case 10:{o=j+1398216+((d[j+1128232|0]|0)*600|0)|0;break};case 9:{o=j+1395816+((d[j+1128232|0]|0)*600|0)|0;break};case 8:{o=j+1386216+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 5:{o=j+1357416+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 4:{o=j+1338216+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};default:{h=77;break a}}j=o;c[j+420>>2]=k;x2b(b,k,j);j=g+1128232|0;a[j]=(a[j]|0)+1}}else{j=g;switch(f|0){case 7:{p=j+1391016+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 6:{p=j+1376616+((d[j+1128232|0]|0)*2400|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 5:{p=j+1357416+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 0:{p=j+1184616+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 12:{p=j+1400616|0;break};case 2:{p=j+1223016+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 1:{p=j+1261416+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 3:{p=j+1299816+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 4:{p=j+1338216+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 9:{p=j+1395816+((d[j+1128232|0]|0)*600|0)|0;break};case 8:{p=j+1386216+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 11:{p=j+1399416+((d[j+1128232|0]|0)*600|0)|0;break};case 10:{p=j+1398216+((d[j+1128232|0]|0)*600|0)|0;break};default:{h=95;break a}}j=p;c[j+420>>2]=k;x2b(b,k,j)}}}f=f+1|0}if((h|0)==27){Cd(2386904,2337528,229,2652584)}else if((h|0)==54){Cd(2386904,2337528,229,2652584)}else if((h|0)==77){Cd(2386904,2337528,229,2652584)}else if((h|0)==95){Cd(2386904,2337528,229,2652584)}else if((h|0)==101){i=e;return}}function q1b(a){a=a|0;var b=0;b=a;c[b>>2]=600;c[b+4>>2]=300;c[b+8>>2]=300;c[b+12>>2]=300;i=i;return}function r1b(a){a=a|0;var b=0,d=0,e=0.0,f=0;b=i;d=a;a=1;c[c[d>>2]>>2]=0;c[c[d+4>>2]>>2]=0;do{e=(+aa(+(a<<3|0))/.6931471824645996+.6)*2.0*256.0;c[(c[d>>2]|0)+(a<<2)>>2]=~~e;c[(c[d+4>>2]|0)+(a<<2)>>2]=~~e;c[(c[d>>2]|0)+(-a<<2)>>2]=~~e;c[(c[d+4>>2]|0)+(-a<<2)>>2]=~~e;f=a+1|0;a=f;}while((f|0)<=16383);i=b;return}function s1b(a){a=a|0;var b=0,d=0,e=0.0,f=0;b=i;d=a;a=1;c[c[d>>2]>>2]=0;c[c[d+4>>2]>>2]=0;do{e=(+aa(+(a<<3|0))/.6931471824645996+.6)*2.0*256.0;c[(c[d>>2]|0)+(a<<2)>>2]=~~e;c[(c[d+4>>2]|0)+(a<<2)>>2]=~~e;c[(c[d>>2]|0)+(-a<<2)>>2]=~~e;c[(c[d+4>>2]|0)+(-a<<2)>>2]=~~e;f=a+1|0;a=f;}while((f|0)<=16383);i=b;return}function t1b(a){a=a|0;var b=0,d=0;b=i;d=a;T5b(d);u2b(d);v2b(d);c[d+1434580>>2]=230;do{if((c[d+1471724>>2]|0)==0){if((c[d+83296>>2]|0)!=0){break}i=b;return}}while(0);c[d+1434580>>2]=800;i=b;return}function u1b(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=b;b=0;a:while(1){if((b|0)>=13){g=101;break}h=c[777792+(b<<2)>>2]|0;j=c[777848+(b<<2)>>2]|0;if(4>(ca(h,j)|0)){k=4}else{k=ca(h,j)|0}j=k;if((b|0)<6){a[f+1128232|0]=0;while(1){if((d[f+1128232|0]|0|0)>=4){break}a[f+1128233|0]=0;while(1){if((d[f+1128233|0]|0|0)>=4){break}a[f+1128234|0]=0;while(1){if((d[f+1128234|0]|0|0)>=(16/(j|0)|0|0)){break}h=f;switch(b|0){case 10:{l=h+1398216+((d[h+1128232|0]|0)*600|0)|0;break};case 9:{l=h+1395816+((d[h+1128232|0]|0)*600|0)|0;break};case 8:{l=h+1386216+((d[h+1128232|0]|0)*1200|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 7:{l=h+1391016+((d[h+1128232|0]|0)*1200|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 6:{l=h+1376616+((d[h+1128232|0]|0)*2400|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 5:{l=h+1357416+((d[h+1128232|0]|0)*4800|0)+((d[h+1128233|0]|0)*1200|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 4:{l=h+1338216+((d[h+1128232|0]|0)*4800|0)+((d[h+1128233|0]|0)*1200|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 11:{l=h+1399416+((d[h+1128232|0]|0)*600|0)|0;break};case 3:{l=h+1299816+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 2:{l=h+1223016+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 1:{l=h+1261416+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 12:{l=h+1400616|0;break};case 0:{l=h+1184616+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};default:{g=27;break a}}t2b(l);h=f+1128234|0;a[h]=(a[h]|0)+1}h=f+1128233|0;a[h]=(a[h]|0)+1}h=f+1128232|0;a[h]=(a[h]|0)+1}}else{if((b|0)<9){a[f+1128232|0]=0;while(1){if((d[f+1128232|0]|0|0)>=4){break}a[f+1128233|0]=0;while(1){if((d[f+1128233|0]|0|0)>=(64/(j|0)|0|0)){break}h=f;switch(b|0){case 3:{m=h+1299816+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 1:{m=h+1261416+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 0:{m=h+1184616+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 2:{m=h+1223016+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 9:{m=h+1395816+((d[h+1128232|0]|0)*600|0)|0;break};case 5:{m=h+1357416+((d[h+1128232|0]|0)*4800|0)+((d[h+1128233|0]|0)*1200|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 10:{m=h+1398216+((d[h+1128232|0]|0)*600|0)|0;break};case 7:{m=h+1391016+((d[h+1128232|0]|0)*1200|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 4:{m=h+1338216+((d[h+1128232|0]|0)*4800|0)+((d[h+1128233|0]|0)*1200|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 6:{m=h+1376616+((d[h+1128232|0]|0)*2400|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 8:{m=h+1386216+((d[h+1128232|0]|0)*1200|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 11:{m=h+1399416+((d[h+1128232|0]|0)*600|0)|0;break};case 12:{m=h+1400616|0;break};default:{g=54;break a}}t2b(m);h=f+1128233|0;a[h]=(a[h]|0)+1}h=f+1128232|0;a[h]=(a[h]|0)+1}}else{if((b|0)<12){a[f+1128232|0]=0;while(1){if((d[f+1128232|0]|0|0)>=(256/(j|0)|0|0)){break}h=f;switch(b|0){case 3:{n=h+1299816+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 2:{n=h+1223016+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 7:{n=h+1391016+((d[h+1128232|0]|0)*1200|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 6:{n=h+1376616+((d[h+1128232|0]|0)*2400|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 9:{n=h+1395816+((d[h+1128232|0]|0)*600|0)|0;break};case 8:{n=h+1386216+((d[h+1128232|0]|0)*1200|0)+((d[h+1128233|0]|0)*600|0)|0;break};case 11:{n=h+1399416+((d[h+1128232|0]|0)*600|0)|0;break};case 10:{n=h+1398216+((d[h+1128232|0]|0)*600|0)|0;break};case 1:{n=h+1261416+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 0:{n=h+1184616+((d[h+1128232|0]|0)*9600|0)+((d[h+1128233|0]|0)*2400|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 5:{n=h+1357416+((d[h+1128232|0]|0)*4800|0)+((d[h+1128233|0]|0)*1200|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 4:{n=h+1338216+((d[h+1128232|0]|0)*4800|0)+((d[h+1128233|0]|0)*1200|0)+((d[h+1128234|0]|0)*600|0)|0;break};case 12:{n=h+1400616|0;break};default:{g=77;break a}}t2b(n);h=f+1128232|0;a[h]=(a[h]|0)+1}}else{j=f;switch(b|0){case 2:{o=j+1223016+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 1:{o=j+1261416+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 6:{o=j+1376616+((d[j+1128232|0]|0)*2400|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 5:{o=j+1357416+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 8:{o=j+1386216+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 7:{o=j+1391016+((d[j+1128232|0]|0)*1200|0)+((d[j+1128233|0]|0)*600|0)|0;break};case 0:{o=j+1184616+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 4:{o=j+1338216+((d[j+1128232|0]|0)*4800|0)+((d[j+1128233|0]|0)*1200|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 3:{o=j+1299816+((d[j+1128232|0]|0)*9600|0)+((d[j+1128233|0]|0)*2400|0)+((d[j+1128234|0]|0)*600|0)|0;break};case 12:{o=j+1400616|0;break};case 11:{o=j+1399416+((d[j+1128232|0]|0)*600|0)|0;break};case 10:{o=j+1398216+((d[j+1128232|0]|0)*600|0)|0;break};case 9:{o=j+1395816+((d[j+1128232|0]|0)*600|0)|0;break};default:{g=95;break a}}t2b(o)}}}b=b+1|0}if((g|0)==27){Cd(2386904,2337528,229,2652584)}else if((g|0)==54){Cd(2386904,2337528,229,2652584)}else if((g|0)==77){Cd(2386904,2337528,229,2652584)}else if((g|0)==95){Cd(2386904,2337528,229,2652584)}else if((g|0)==101){i=e;return}}function v1b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=d+1434592|0;FYb(c[d+2047180>>2]|0);c[d+2047180>>2]=0;FYb(c[a+10216>>2]|0);c[a+10216>>2]=0;FYb(c[d+2015036>>2]|0);c[d+2015036>>2]=0;FYb(c[d+2047216>>2]|0);c[d+2047216>>2]=0;Ujc(c[d+2047228>>2]|0);c[d+2047228>>2]=0;FYb(c[d+2047220>>2]|0);c[d+2047220>>2]=0;Sdc(a);K7b(d+1472180|0)|0;K7b(d+1471916|0)|0;K7b(d+1472012|0)|0;K7b(d+2048512|0)|0;Hnc(c[d+1471888>>2]|0);FYb(c[d+1472272>>2]|0);c[d+1472272>>2]=0;FYb(c[d+2050760>>2]|0);c[d+2050760>>2]=0;FYb(c[d+2050764>>2]|0);c[d+2050764>>2]=0;a=0;while(1){if((a|0)>=(c[d+2050816>>2]|0)){break}e=d+2050824+(a*960|0)|0;FYb(c[e+944>>2]|0);c[e+944>>2]=0;c[e+948>>2]=0;a=a+1|0}i=b;return}function w1b(a,b){a=a|0;b=b|0;var d=0,e=0;d=b;if((d|0)>7){e=-1}else{c[a+2046872>>2]=d;e=0}i=i;return e|0}function x1b(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[d+1472164>>2]=(a&2|0)!=0;c[d+1472168>>2]=(a&4|0)!=0;c[d+1472160>>2]=(a&1|0)!=0;c[d+1472156>>2]=1;i=i;return}function y1b(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;e=z1b(a,b)|0;if((e|0)!=0){S7b(e,c);f=0;g=f;i=d;return g|0}else{f=-1;g=f;i=d;return g|0}return 0}function z1b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=-1;if((a|0)==1){b=1}else{if((a|0)==2){b=2}else{if((a|0)==4){b=3}}}if((b|0)==-1){f=0;i=d;return f|0}a=e;e=a+1434592|0;g=a;a=b;do{if((a|0)==1){h=c[g+1472132>>2]|0}else{if((a|0)==2){h=c[g+1472136>>2]|0;break}else{h=c[g+1472140>>2]|0;break}}}while(0);f=e+8488+((c[e+9784+(h<<2)>>2]|0)*108|0)+16|0;i=d;return f|0}function A1b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=b;b=d;d=a+1434592|0;do{if((f|0)>=0){if((f|0)>=8){break}c[b>>2]=d+8488+((c[d+9784+(f<<2)>>2]|0)*108|0)+16;g=0;h=g;i=e;return h|0}}while(0);g=-1;h=g;i=e;return h|0}function B1b(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;e=z1b(a,b)|0;if((e|0)!=0){S7b(c,e);f=0;g=f;i=d;return g|0}else{f=-1;g=f;i=d;return g|0}return 0}function C1b(a,b){a=a|0;b=b|0;var d=0;d=a;c[d+1472176>>2]=b;c[d+1472172>>2]=1;i=i;return 0}function D1b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a;a=d+1434592|0;if((c[a+10108>>2]|0)==0){e=a+8488|0;f=a+9784+(c[d+1472136>>2]<<2)|0;g=c[a+10008>>2]|0;h=c[f>>2]|0;do{if((h|0)>=0){if((c[e+(h*108|0)>>2]|0)<=0){break}j=e+(h*108|0)|0;c[j>>2]=(c[j>>2]|0)-1}}while(0);c[f>>2]=g;f=e+(g*108|0)|0;c[f>>2]=(c[f>>2]|0)+1;f=a+8488|0;g=a+9784+(c[d+1472140>>2]<<2)|0;e=c[a+10008>>2]|0;h=c[g>>2]|0;do{if((h|0)>=0){if((c[f+(h*108|0)>>2]|0)<=0){break}j=f+(h*108|0)|0;c[j>>2]=(c[j>>2]|0)-1}}while(0);c[g>>2]=e;g=f+(e*108|0)|0;c[g>>2]=(c[g>>2]|0)+1}else{do{if((c[d+1472148>>2]|0)!=0){if((c[d+1472152>>2]|0)!=0){k=16;break}if((c[d+2050800>>2]|0)!=0){k=16;break}g=a+8488|0;e=a+9784+(c[d+1472140>>2]<<2)|0;f=c[a+10008>>2]|0;h=c[e>>2]|0;do{if((h|0)>=0){if((c[g+(h*108|0)>>2]|0)<=0){break}j=g+(h*108|0)|0;c[j>>2]=(c[j>>2]|0)-1}}while(0);c[e>>2]=f;h=g+(f*108|0)|0;c[h>>2]=(c[h>>2]|0)+1;h=c[d+1472140>>2]|0;c[d+1472140>>2]=c[d+1472136>>2];c[d+1472136>>2]=h}else{k=16}}while(0);if((k|0)==16){if((c[d+1472152>>2]|0)!=0){k=a+8488|0;h=a+9784+(c[d+1472140>>2]<<2)|0;j=c[a+10008>>2]|0;l=c[h>>2]|0;do{if((l|0)>=0){if((c[k+(l*108|0)>>2]|0)<=0){break}m=k+(l*108|0)|0;c[m>>2]=(c[m>>2]|0)-1}}while(0);c[h>>2]=j;h=k+(j*108|0)|0;c[h>>2]=(c[h>>2]|0)+1}if((c[d+1472148>>2]|0)!=0){h=a+8488|0;j=a+9784+(c[d+1472136>>2]<<2)|0;k=c[a+10008>>2]|0;l=c[j>>2]|0;do{if((l|0)>=0){if((c[h+(l*108|0)>>2]|0)<=0){break}m=h+(l*108|0)|0;c[m>>2]=(c[m>>2]|0)-1}}while(0);c[j>>2]=k;j=h+(k*108|0)|0;c[j>>2]=(c[j>>2]|0)+1}}}if((c[d+1472144>>2]|0)==0){i=b;return}j=a+8488|0;k=a+9784+(c[d+1472132>>2]<<2)|0;d=c[a+10008>>2]|0;a=c[k>>2]|0;do{if((a|0)>=0){if((c[j+(a*108|0)>>2]|0)<=0){break}h=j+(a*108|0)|0;c[h>>2]=(c[h>>2]|0)-1}}while(0);c[k>>2]=d;k=j+(d*108|0)|0;c[k>>2]=(c[k>>2]|0)+1;i=b;return}function E1b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=a;a=d+1434592|0;e=1;while(1){if((e|0)>3){f=21;break}g=d;h=e;do{if((h|0)==1){j=c[g+1472132>>2]|0}else{if((h|0)==2){j=c[g+1472136>>2]|0;break}else{j=c[g+1472140>>2]|0;break}}}while(0);g=c[a+9784+(j<<2)>>2]|0;h=a+8488+(g*108|0)+16|0;do{if((c[h+8>>2]|0)!=(c[a+8452>>2]|0)){f=10}else{if((c[h+12>>2]|0)!=(c[a+8456>>2]|0)){f=10;break}c[d+1472120+(e-1<<2)>>2]=g;k=a+8488+(g*108|0)|0;c[k>>2]=(c[k>>2]|0)+1}}while(0);if((f|0)==10){f=0;g=a;k=0;while(1){if((k|0)>=12){break}if((c[g+8488+(k*108|0)>>2]|0)==0){f=13;break}k=k+1|0}if((f|0)==13){f=0}if((k|0)>=12){f=16;break}c[g+8488+(k*108|0)>>2]=1;l=k;L7b(a+8488+(l*108|0)+16|0,c[a+8452>>2]|0,c[a+8456>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,160,0,0,0)|0;F1b(h,a+8488+(l*108|0)+16|0);c[d+1472120+(e-1<<2)>>2]=l}e=e+1|0}if((f|0)==16){Cd(2350544,2343504,223,2652464)}else if((f|0)==21){i=b;return}}function F1b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=a;a=b;b=c[j+8>>2]|0;k=c[j+12>>2]|0;l=c[a+8>>2]|0;m=c[a+12>>2]|0;n=e|0;c[n>>2]=c[j+52>>2];o=n+4|0;c[o>>2]=c[j+56>>2];n=o+4|0;c[n>>2]=c[j+60>>2];c[n+4>>2]=c[j+64>>2];n=f|0;c[n>>2]=c[j+16>>2];o=n+4|0;c[o>>2]=c[j+36>>2];n=o+4|0;c[n>>2]=c[j+36>>2];c[n+4>>2]=c[j+48>>2];j=g|0;c[j>>2]=c[a+52>>2];n=j+4|0;c[n>>2]=c[a+56>>2];j=n+4|0;c[j>>2]=c[a+60>>2];c[j+4>>2]=c[a+64>>2];j=h|0;c[j>>2]=c[a+16>>2];n=j+4|0;c[n>>2]=c[a+36>>2];j=n+4|0;c[j>>2]=c[a+36>>2];c[j+4>>2]=c[a+48>>2];j=0;while(1){if((j|0)>=(m|0)){break}n=0;while(1){if((n|0)>=(l|0)){break}o=0;while(1){if((o|0)>=3){break}if((o|0)==0){p=1}else{p=(o|0)==3}q=p?1:2;r=(ca(ca(n,16/(q|0)|0)|0,b)|0)/(l|0)|0;s=(ca(ca(j,16/(q|0)|0)|0,k)|0)/(m|0)|0;t=c[f+(o<<2)>>2]|0;u=c[h+(o<<2)>>2]|0;v=(c[e+(o<<2)>>2]|0)+(ca((ca((j|0)/(q|0)|0,k)|0)/(m|0)|0,t)|0)+((ca((n|0)/(q|0)|0,b)|0)/(l|0)|0)|0;rec(v,t,(c[g+(o<<2)>>2]|0)+(ca((j|0)/(q|0)|0,u)|0)+((n|0)/(q|0)|0)|0,u,203560+((r&15)<<4)|0,(b<<4|0)/(l|0)|0,203560+((s&15)<<4)|0,(k<<4|0)/(m|0)|0,16/(q|0)|0,16/(q|0)|0);o=o+1|0}n=n+16|0}j=j+16|0}N7b(a);i=d;return}function G1b(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;i=i+32|0;k=j|0;l=j+8|0;m=j+16|0;n=a;a=d;c[k>>2]=e;c[k+4>>2]=f;c[l>>2]=g;c[l+4>>2]=h;h=n+1434592|0;g=0;f=(c[a+20>>2]|0)<(c[a>>2]|0)|0;e=(c[a+24>>2]|0)<(c[a+4>>2]|0)|0;H1b(n,f,e);I1b(m);if((Jnc(c[n+1471888>>2]|0,a,c[k>>2]|0,c[k+4>>2]|0,c[l>>2]|0,c[l+4>>2]|0,b)|0)!=0){g=-1}J1b(m);b=K1b(m)|0;m=n+2047824|0;n=wrc(c[m>>2]|0,c[m+4>>2]|0,b,G)|0;c[m>>2]=n;c[m+4>>2]=G;if((c[h+36952>>2]|0)!=0){o=g;i=j;return o|0}do{if((f|0)==1){if((e|0)!=1){break}o=g;i=j;return o|0}}while(0);f1b(h|0,8,2465704,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;g=-1;o=g;i=j;return o|0}function H1b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a;a=f+1434592|0;if((c[f+2050792>>2]|0)!=0){i=e;return}c[a+8476>>2]=b;c[a+8480>>2]=d;s2b(f);c[f+2050792>>2]=c[a+8452>>2];c[f+2050796>>2]=c[a+8456>>2];i=e;return}function I1b(a){a=a|0;var b=0;b=i;jd(a|0,0)|0;i=b;return}function J1b(a){a=a|0;var b=0;b=i;jd(a+8|0,0)|0;i=b;return}function K1b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;e=a;c[d>>2]=(c[e+8>>2]|0)-(c[e>>2]|0);a=(c[e+12>>2]|0)-(c[e+4>>2]|0)|0;c[d+4>>2]=a;if((a|0)<0){a=d+4|0;c[a>>2]=(c[a>>2]|0)+1e6;a=d|0;e=c[a>>2]|0;c[a>>2]=e-1;f=(e|0)!=0}else{f=0}f=((c[d>>2]|0)*1e6|0)+(c[d+4>>2]|0)|0;i=b;return(G=(f|0)<0|0?-1:0,f)|0}function L1b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0.0,L=0.0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a;a=0;g=(c[f+1471892>>2]|0)+96|0;j=f+2017120|0;if((c[g>>2]|0)==(c[j>>2]|0)&(c[g+4>>2]|0)==(c[j+4>>2]|0)){j=(c[f+1471892>>2]|0)+104|0;g=(c[f+1471892>>2]|0)+96|0;k=xrc(c[j>>2]|0,c[j+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;c[d>>2]=k;c[d+4>>2]=G;a=1}else{k=f+2017112|0;g=f+2017104|0;j=xrc(c[k>>2]|0,c[k+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;c[e>>2]=j;c[e+4>>2]=G;j=(c[f+1471892>>2]|0)+104|0;g=f+2017112|0;k=xrc(c[j>>2]|0,c[j+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;c[d>>2]=k;c[d+4>>2]=G;if((c[e>>2]|0)!=0|(c[e+4>>2]|0)!=0){k=xrc(c[d>>2]|0,c[d+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;g=Erc(k,G,10,0)|0;k=Crc(g,G,c[e>>2]|0,c[e+4>>2]|0)|0;a=k}}if(!((c[d>>2]|0)!=0|(c[d+4>>2]|0)!=0)){l=f;m=l+1471892|0;n=c[m>>2]|0;o=n+96|0;p=o|0;q=c[p>>2]|0;r=o+4|0;s=c[r>>2]|0;t=f;u=t+2017104|0;v=u|0;c[v>>2]=q;w=u+4|0;c[w>>2]=s;x=f;y=x+1471892|0;z=c[y>>2]|0;A=z+104|0;B=A|0;C=c[B>>2]|0;D=A+4|0;E=c[D>>2]|0;F=f;H=F+2017112|0;I=H|0;c[I>>2]=C;J=H+4|0;c[J>>2]=E;i=b;return}if((a|0)!=0){g1b(f,1.0e7/(+((c[d>>2]|0)>>>0)+ +(c[d+4>>2]|0)*4294967296.0))}else{a=(c[f+1471892>>2]|0)+104|0;k=f+2017120|0;e=xrc(c[a>>2]|0,c[a+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;if(+(e>>>0)+ +(G|0)*4294967296.0<1.0e7){e=(c[f+1471892>>2]|0)+104|0;k=f+2017120|0;a=xrc(c[e>>2]|0,c[e+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;K=+(a>>>0)+ +(G|0)*4294967296.0}else{K=1.0e7}L=K;K=1.0e7/+h[f+1471616>>3];K=K*(L-K+(+((c[d>>2]|0)>>>0)+ +(c[d+4>>2]|0)*4294967296.0));K=K/L;g1b(f,1.0e7/K)}l=f;m=l+1471892|0;n=c[m>>2]|0;o=n+96|0;p=o|0;q=c[p>>2]|0;r=o+4|0;s=c[r>>2]|0;t=f;u=t+2017104|0;v=u|0;c[v>>2]=q;w=u+4|0;c[w>>2]=s;x=f;y=x+1471892|0;z=c[y>>2]|0;A=z+104|0;B=A|0;C=c[B>>2]|0;D=A+4|0;E=c[D>>2]|0;F=f;H=F+2017112|0;I=H|0;c[I>>2]=C;J=H+4|0;c[J>>2]=E;i=b;return}function M1b(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+16|0;k=j|0;l=a;a=b;b=d;d=e;e=f;f=g;g=h;h=l+1434592|0;m=l+57488|0;n=l+2017128|0;o=0;if((l|0)==0){p=-1;q=p;i=j;return q|0}do{if((c[l+2050816>>2]|0)>1){if((c[l+2046868>>2]|0)!=2){break}$5b(l)}}while(0);I1b(k);c[l+1471892>>2]=0;c[l+1471900>>2]=0;j1b(l,1);c[h+10132>>2]=0;c[h+13360>>2]=1;c[l+1472144>>2]=1;c[l+1472148>>2]=0;c[l+1472152>>2]=0;do{if((c[l+1471828>>2]|0)!=0){if((c[n+100>>2]|0)==0){break}r=c[n+68>>2]|0;if((r|0)<=(c[n+84>>2]|0)){}else{Cd(2454800,2137528,2853,2650528);return 0}s=Mnc(c[l+1471888>>2]|0,r)|0;c[l+1471892>>2]=s;if((s|0)!=0){c[l+1471896>>2]=c[l+1471892>>2];if((c[l+1471848>>2]|0)>0){g6b(l,r,c[n+28>>2]|0);e6b(l,r);P7b(l+2048512|0);o=l+2048512|0}c[h+10112>>2]=0;c[l+1472152>>2]=1;c[l+1472148>>2]=0;c[l+1472144>>2]=0;c[n+108>>2]=0;c[n+100>>2]=0}else{c[n+100>>2]=0}}}while(0);if((c[l+1471892>>2]|0)==0){do{if((c[h+36948>>2]|0)>>>0>0>>>0){r=Mnc(c[l+1471888>>2]|0,-1)|0;c[l+1471900>>2]=r;if((r|0)!=0){break}p=-1;q=p;i=j;return q|0}}while(0);r=Lnc(c[l+1471888>>2]|0,g)|0;c[l+1471892>>2]=r;if((r|0)!=0){c[h+10112>>2]=1;c[h+10124>>2]=0;if((c[l+1471896>>2]|0)!=0){t=(c[l+1471892>>2]|0)==(c[l+1471896>>2]|0)}else{t=0}c[n+108>>2]=t&1;if((c[n+108>>2]|0)!=0){c[l+1471896>>2]=0;c[l+1472144>>2]=0}}}if((c[l+1471892>>2]|0)==0){c[b>>2]=0;do{if((g|0)!=0){if((c[l+2046868>>2]|0)!=1){break}if((c[l+2048368>>2]|0)!=0){break}_mc(l);c[l+2048368>>2]=1}}while(0);p=-1;q=p;i=j;return q|0}if((o|0)!=0){u=o}else{u=c[l+1471892>>2]|0}c[l+1471904>>2]=u;c[l+1471912>>2]=u;if((c[l+1471900>>2]|0)!=0){c[l+1472008>>2]=c[l+1471900>>2]}else{c[l+1472008>>2]=0}u=(c[l+1471892>>2]|0)+96|0;o=c[u+4>>2]|0;g=e;c[g>>2]=c[u>>2];c[g+4>>2]=o;o=(c[l+1471892>>2]|0)+104|0;g=c[o+4>>2]|0;u=f;c[u>>2]=c[o>>2];c[u+4>>2]=g;c[a>>2]=c[(c[l+1471892>>2]|0)+112>>2];g=(c[l+1471892>>2]|0)+96|0;u=c[g+4>>2]|0;o=l+2017120|0;f=c[o+4>>2]|0;if((u|0)<(f|0)|(u|0)==(f|0)&(c[g>>2]|0)>>>0<(c[o>>2]|0)>>>0){o=(c[l+1471892>>2]|0)+96|0;g=c[o+4>>2]|0;f=l+2017120|0;c[f>>2]=c[o>>2];c[f+4>>2]=g;g=(c[l+1471892>>2]|0)+96|0;f=c[g+4>>2]|0;o=l+2017112|0;c[o>>2]=c[g>>2];c[o+4>>2]=f}if((c[h+10112>>2]|0)!=0){L1b(l)}do{if((c[l+2050820>>2]|0)>1){if((c[l+1471664>>2]|0)!=1){break}Y5b(l);$5b(l)}}while(0);c[b>>2]=0;f=h+8488+((c[h+10008>>2]|0)*108|0)|0;c[f>>2]=(c[f>>2]|0)-1;f=h;o=0;while(1){if((o|0)>=12){break}if((c[f+8488+(o*108|0)>>2]|0)==0){v=51;break}o=o+1|0}if((o|0)>=12){Cd(2350544,2343504,223,2652464);return 0}c[f+8488+(o*108|0)>>2]=1;c[h+10008>>2]=o;c[h+10136>>2]=c[a>>2];do{if((c[l+2046868>>2]|0)==2){if((c[h+36948>>2]|0)!=0){break}if((c[l+1471732>>2]|0)==0){break}if((c[l+1471664>>2]|0)!=0){break}N1b(l,c[l+1471736>>2]|0,c[l+1471740>>2]|0)|0}}while(0);o=h;L7b(o+8488+((c[o+10008>>2]|0)*108|0)+16|0,c[h+8452>>2]|0,c[h+8456>>2]|0,c[h+8476>>2]|0,c[h+8480>>2]|0,160,0,0,0)|0;o=1;while(1){if((o|0)>3){break}f=l;g=o;do{if((g|0)==1){w=c[f+1472132>>2]|0}else{if((g|0)==2){w=c[f+1472136>>2]|0;break}else{w=c[f+1472140>>2]|0;break}}}while(0);f=c[h+9784+(w<<2)>>2]|0;g=h+8488+(f*108|0)+16|0;u=h+9816+(o-1<<6)|0;c[u+4>>2]=g;c[u>>2]=f;Mhc(u+8|0,c[g+8>>2]|0,c[g+12>>2]|0,c[h+8452>>2]|0,c[h+8456>>2]|0);f=u+8|0;if((c[f>>2]|0)!=16384){x=1}else{x=(c[f+4>>2]|0)!=16384}if((x&1|0)!=0){P7b(g)}o=o+1|0}o=h;x=m;m=1;w=1;if((m|0)>=1){y=m-1|0}else{y=0}c[x+188>>2]=o+9816+(y<<6);if((w|0)>=1){z=w-1|0}else{z=0}c[x+192>>2]=o+9816+(z<<6);if((c[l+1471728>>2]|0)==1){ckc()}do{if((c[l+2046868>>2]|0)==1){if((c[l+2050800>>2]|0)!=0){if((c[l+2050820>>2]|0)!=1){v=85;break}}O1b(l,b,d,a)}else{v=85}}while(0);if((v|0)==85){do{if((c[l+2046868>>2]|0)==2){if((c[l+2050800>>2]|0)!=0){if((c[l+2050820>>2]|0)!=1){v=89;break}}P1b(l,b,d,a)}else{v=89}}while(0);if((v|0)==89){if((c[l+2050800>>2]|0)!=0){Q1b(l,b,d,a)}else{R1b(l,b,d,a)}}}if((c[h+13360>>2]|0)!=0){nrc(h+15579+((c[h+23736>>2]|0)*2039|0)|0,h+13540|0,2039)|0}if((c[b>>2]|0)==0){S1b(l)}if((c[b>>2]|0)>>>0>0>>>0){c[l+2050768>>2]=((T1b(l)|0)!=0^1)&1}if((c[l+2050820>>2]|0)>1){if((c[l+1471664>>2]|0)==1){v=104}else{v=102}}else{v=102}do{if((v|0)==102){if((c[l+2050816>>2]|0)<=1){break}if((c[l+2046868>>2]|0)==2){v=104}}}while(0);if((v|0)==104){a6b(l)}J1b(k);v=K1b(k)|0;k=l+2047832|0;b=wrc(c[k>>2]|0,c[k+4>>2]|0,v,G)|0;c[k>>2]=b;c[k+4>>2]=G;do{if((c[l+2050752>>2]|0)!=0){if((c[l+2046868>>2]|0)==1){break}if((c[h+10112>>2]|0)==0){break}U1b(l)}}while(0);p=0;q=p;i=j;return q|0}function N1b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=b;b=d;d=f+1434592|0;H1b(f,1,1);if((a|0)!=0){c[d+8452>>2]=a;if(((c[d+8452>>2]|0)*5|0|0)<(c[f+2050792>>2]|0)){c[d+8452>>2]=((c[f+2050792>>2]|0)/5|0)+1;Oc(2437784,(g=i,i=i+8|0,c[g>>2]=c[d+8452>>2],g)|0)|0;i=g}if((c[d+8452>>2]|0)>(c[f+2050792>>2]|0)){c[d+8452>>2]=c[f+2050792>>2];Oc(2427216,(g=i,i=i+8|0,c[g>>2]=c[d+8452>>2],g)|0)|0;i=g}}if((b|0)!=0){c[d+8456>>2]=b;if(((c[d+8456>>2]|0)*5|0|0)<(c[f+2050796>>2]|0)){c[d+8456>>2]=((c[f+2050796>>2]|0)/5|0)+1;Oc(2417032,(g=i,i=i+8|0,c[g>>2]=c[d+8456>>2],g)|0)|0;i=g}if((c[d+8456>>2]|0)>(c[f+2050796>>2]|0)){c[d+8456>>2]=c[f+2050796>>2];Oc(2408072,(g=i,i=i+8|0,c[g>>2]=c[d+8456>>2],g)|0)|0;i=g}}if((c[d+8452>>2]|0)<=(c[f+2050792>>2]|0)){}else{Cd(2632256,2137528,3295,2650056);return 0}if((c[d+8456>>2]|0)<=(c[f+2050796>>2]|0)){d=1;g=d&1;d=f;k1b(d);i=e;return 0}Cd(2608192,2137528,3296,2650056);return 0}function O1b(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=i;c=a;nnc(c);K2b(c+1434592|0,r2b()|0);anc(c);i=d;return}function P1b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;c[g+2047172>>2]=1;onc(g);b2b(g,b,d,e);unc(g);i=f;return}function Q1b(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;n3b(f);b2b(f,b,c,d);i=e;return}function R1b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;if((c[g+1471664>>2]|0)==1){q3b(g)}else{j3b(g)}b2b(g,b,d,e);i=f;return}function S1b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;a=d+1434592|0;e=0;while(1){if((e|0)>=3){break}f=a+8488+((c[d+1472120+(e<<2)>>2]|0)*108|0)|0;c[f>>2]=(c[f>>2]|0)-1;e=e+1|0}i=b;return}function T1b(a){a=a|0;var b=0,e=0,f=0;b=i;e=a;a=e+1434592|0;do{if((c[a+10108>>2]|0)==0){f=1}else{if((c[e+1472144>>2]|0)!=0){f=1;break}if((c[e+1472148>>2]|0)!=0){f=1;break}if((c[e+1472152>>2]|0)!=0){f=1;break}if((c[a+13360>>2]|0)!=0){f=1;break}if((d[a+13393|0]|0|0)!=0){f=1;break}if((d[a+13409|0]|0|0)!=0){f=1;break}f=(d[a+13410|0]|0|0)!=0}}while(0);i=b;return f&1|0}function U1b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0;b=i;i=i+216|0;d=b|0;e=b+136|0;f=a;a2b(c[f+1471904>>2]|0,c[f+1443076>>2]|0,e);a=0;while(1){if((a|0)>=4){break}c[d+8+(a<<2)>>2]=c[e+64+(a<<2)>>2];g=e+32+(a<<3)|0;j=c[g+4>>2]|0;k=d+24+(a<<3)|0;c[k>>2]=c[g>>2];c[k+4>>2]=j;h[d+56+(a<<3)>>3]=+h[e+(a<<3)>>3];a=a+1|0}c[d>>2]=2;qYb(c[f+2046748>>2]|0,d)|0;i=b;return}function V1b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;d=i;e=b;b=a+1434592|0;if((c[b+10112>>2]|0)==0){f=-1;g=f;i=d;return g|0}if((c[b+8484>>2]|0)!=0){nrc(e|0,c[b+8484>>2]|0,92)|0;c[e>>2]=c[b+8452>>2];c[e+4>>2]=c[b+8456>>2];c[e+20>>2]=c[b+8452>>2]>>c[b+8476>>2];c[e+24>>2]=c[b+8456>>2]>>c[b+8480>>2];h=0}else{h=-1}f=h;g=f;i=d;return g|0}function W1b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;b=d;d=e;do{if((b|0)==(c[g+1444736>>2]|0)){if((d|0)!=(c[g+1444744>>2]|0)){break}if((a|0)!=0){nrc(c[g+2047220>>2]|0,a|0,ca(b,d)|0)|0;c[g+2047224>>2]=1}else{c[g+2047224>>2]=0}h=0;j=h;i=f;return j|0}}while(0);h=-1;j=h;i=f;return j|0}function X1b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=a;a=b;b=d;d=k+1434592|0;c[f>>2]=0;c[g>>2]=0;c[h>>2]=0;c[j>>2]=0;do{if(!(a>>>0>3>>>0)){if(b>>>0>3>>>0){break}l=f;m=g;n=a;if((n|0)==1){c[l>>2]=4;c[m>>2]=5}else if((n|0)==0){c[l>>2]=1;c[m>>2]=1}else if((n|0)==3){c[l>>2]=1;c[m>>2]=2}else if((n|0)==2){c[l>>2]=3;c[m>>2]=5}else{c[l>>2]=1;c[m>>2]=1;Cd(2386904,2137528,100,2653488);return 0}m=h;l=j;n=b;if((n|0)==3){c[m>>2]=1;c[l>>2]=2}else if((n|0)==0){c[m>>2]=1;c[l>>2]=1}else if((n|0)==1){c[m>>2]=4;c[l>>2]=5}else if((n|0)==2){c[m>>2]=3;c[l>>2]=5}else{c[m>>2]=1;c[l>>2]=1;Cd(2386904,2137528,100,2653488);return 0}l=(c[g>>2]|0)-1+(ca(c[k+1471608>>2]|0,c[f>>2]|0)|0)|0;c[d+8452>>2]=(l|0)/(c[g>>2]|0)|0;l=(c[j>>2]|0)-1+(ca(c[k+1471612>>2]|0,c[h>>2]|0)|0)|0;c[d+8456>>2]=(l|0)/(c[j>>2]|0)|0;if((c[d+8452>>2]|0)<=(c[k+2050792>>2]|0)){}else{Cd(2632256,2137528,3259,2650096);return 0}if((c[d+8456>>2]|0)<=(c[k+2050796>>2]|0)){}else{Cd(2608192,2137528,3260,2650096);return 0}k1b(k);o=0;p=o;i=e;return p|0}}while(0);o=-1;p=o;i=e;return p|0}function Y1b(a,b){a=a|0;b=b|0;c[a+2050800>>2]=b;i=i;return}function Z1b(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=b;if((c[e+8>>2]|0)==(c[a+8>>2]|0)){}else{Cd(2400648,2137528,3307,2650264);return 0}if((c[e+12>>2]|0)==(c[a+12>>2]|0)){}else{Cd(2393688,2137528,3308,2650264);return 0}b=_1b(c[e+52>>2]|0,c[e+16>>2]|0,c[a+52>>2]|0,c[a+16>>2]|0,c[e+8>>2]|0,c[e+12>>2]|0)|0;i=d;return b|0}function _1b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=a;a=b;b=d;d=e;e=f;f=g;g=(e|0)%16|0;n=(f|0)%16|0;c[j>>2]=0;c[j+4>>2]=0;c[k>>2]=0;c[l>>2]=0;if((g|0)>0){w6b(m+(e-g)|0,a,b+(e-g)|0,d,g,f,k,l);o=wrc(c[j>>2]|0,c[j+4>>2]|0,c[k>>2]|0,0)|0;c[j>>2]=o;c[j+4>>2]=G}if((n|0)>0){w6b(m+(ca(f-n|0,a)|0)|0,a,b+(ca(f-n|0,d)|0)|0,d,e-g|0,n,k,l);l=wrc(c[j>>2]|0,c[j+4>>2]|0,c[k>>2]|0,0)|0;c[j>>2]=l;c[j+4>>2]=G}l=0;while(1){if((l|0)>=((f|0)/16|0|0)){break}n=m;g=b;o=0;while(1){if((o|0)>=((e|0)/16|0|0)){break}Y6b(n,a,g,d,k)|0;p=wrc(c[j>>2]|0,c[j+4>>2]|0,c[k>>2]|0,0)|0;c[j>>2]=p;c[j+4>>2]=G;n=n+16|0;g=g+16|0;o=o+1|0}m=m+(a<<4)|0;b=b+(d<<4)|0;l=l+1|0}i=h;return(G=c[j+4>>2]|0,c[j>>2]|0)|0}function $1b(a){a=a|0;i=i;return c[a+1444760>>2]|0}function a2b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+112|0;f=e|0;g=e+16|0;j=e+32|0;k=e+48|0;l=e+64|0;m=e+80|0;n=e+96|0;o=e+104|0;p=a;a=b;b=d;d=f|0;c[d>>2]=c[p>>2];q=d+4|0;c[q>>2]=c[p+20>>2];c[q+4>>2]=c[p+20>>2];q=g|0;c[q>>2]=c[p+4>>2];d=q+4|0;c[d>>2]=c[p+24>>2];c[d+4>>2]=c[p+24>>2];d=j|0;c[d>>2]=c[p+52>>2];q=d+4|0;c[q>>2]=c[p+56>>2];c[q+4>>2]=c[p+60>>2];q=k|0;c[q>>2]=c[p+16>>2];d=q+4|0;c[d>>2]=c[p+36>>2];c[d+4>>2]=c[p+36>>2];p=l|0;c[p>>2]=c[a+52>>2];d=p+4|0;c[d>>2]=c[a+56>>2];c[d+4>>2]=c[a+60>>2];d=m|0;c[d>>2]=c[a+16>>2];p=d+4|0;c[p>>2]=c[a+36>>2];c[p+4>>2]=c[a+36>>2];c[n>>2]=0;c[n+4>>2]=0;a=0;p=0;while(1){if((p|0)>=3){break}d=c[f+(p<<2)>>2]|0;q=c[g+(p<<2)>>2]|0;r=ca(d,q)|0;s=_1b(c[j+(p<<2)>>2]|0,c[k+(p<<2)>>2]|0,c[l+(p<<2)>>2]|0,c[m+(p<<2)>>2]|0,d,q)|0;c[o>>2]=s;c[o+4>>2]=G;s=c[o+4>>2]|0;q=b+32+(p+1<<3)|0;c[q>>2]=c[o>>2];c[q+4>>2]=s;c[b+64+(p+1<<2)>>2]=r;h[b+(p+1<<3)>>3]=+B7b(+(r>>>0>>>0),255.0,+((c[o>>2]|0)>>>0)+ +((c[o+4>>2]|0)>>>0)*4294967296.0);s=wrc(c[n>>2]|0,c[n+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[n>>2]=s;c[n+4>>2]=G;a=a+r|0;p=p+1|0}p=c[n+4>>2]|0;o=b+32|0;c[o>>2]=c[n>>2];c[o+4>>2]=p;c[b+64>>2]=a;h[b>>3]=+B7b(+(a>>>0>>>0),255.0,+((c[n>>2]|0)>>>0)+ +((c[n+4>>2]|0)>>>0)*4294967296.0);i=e;return}function b2b(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=b;b=d;d=e;e=f;f=k+1434592|0;l=k+2046876|0;if((c[f+8452>>2]|0)<(c[f+8456>>2]|0)){m=c[f+8452>>2]|0}else{m=c[f+8456>>2]|0}n=m;m=f+13408|0;c2b(k);do{if((c[f+10156>>2]<<3|0)!=(c[c[k+1471912>>2]>>2]|0)){o=6}else{if((c[f+10148>>2]<<3|0)!=(c[(c[k+1471912>>2]|0)+4>>2]|0)){o=6;break}c[k+1471904>>2]=c[k+1471912>>2]}}while(0);if((o|0)==6){d2b(c[k+1471912>>2]|0,k+1471916|0);c[k+1471904>>2]=k+1471916}if((c[k+1472008>>2]|0)!=0){do{if((c[f+10156>>2]<<3|0)!=(c[c[k+1472008>>2]>>2]|0)){o=11}else{if((c[f+10148>>2]<<3|0)!=(c[(c[k+1472008>>2]|0)+4>>2]|0)){o=11;break}c[k+1471908>>2]=c[k+1472008>>2]}}while(0);if((o|0)==11){d2b(c[k+1472008>>2]|0,k+1472012|0);c[k+1471908>>2]=k+1472012}}E1b(k);c[k+2017088>>2]=0;c[k+2017092>>2]=0;c[f+13376>>2]=c[k+2017232>>2];a[f+13393|0]=0;c[k+2047168>>2]=Ync(k,n)|0;if((c[l+32>>2]|0)!=0){l=f;if((c[l+10108>>2]|0)==0){p=1}else{p=(c[l+10124>>2]|0)!=0}if((p&1|0)!=0){c[k+2047164>>2]=n}else{if((c[f+10112>>2]|0)!=0){if(n>>>0<c[k+2047164>>2]<<1>>>0){q=n}else{q=c[k+2047164>>2]<<1}c[k+2047168>>2]=Ync(k,q)|0}c[k+2047164>>2]=0}}q=f;if((c[q+10108>>2]|0)==0){r=1}else{r=(c[q+10124>>2]|0)!=0}if((r&1|0)!=0){e2b(k);R5b(f+13408|0);if((a[m|0]|0)!=0){a[m+1|0]=1;a[m+2|0]=1}c[k+2017232>>2]=0;c[f+36960>>2]=(c[k+1471840>>2]|0)!=0;c[f+36964>>2]=(c[k+1471844>>2]|0)!=0;c[f+36968>>2]=1;if((c[f+36960>>2]|0)!=0){c[f+36968>>2]=0;c[f+36964>>2]=1;c[f+10132>>2]=0;c[f+13360>>2]=0}else{if((c[f+10124>>2]|0)!=0){c[f+10132>>2]=2}}}do{if((c[k+2046868>>2]|0)==2){if((c[k+2046916>>2]|0)==0){break}f2b(k)}}while(0);do{if((c[k+2046868>>2]|0)==0){if((c[k+1471664>>2]|0)!=1){break}if((c[f+10108>>2]|0)==0){break}if((U2b(k)|0)==0){break}i3b(k);m=f+36948|0;c[m>>2]=(c[m>>2]|0)+1;i=g;return}}while(0);mrc(k+1490456|0,0,80)|0;t1b(k);m=_2b(k,j,h)|0;r=f;if((c[r+10108>>2]|0)==0){s=1}else{s=(c[r+10124>>2]|0)!=0}if((s&1|0)==0){c[f+10220>>2]=4;j1b(k,(m|0)<200|0)}if((c[k+2046884>>2]|0)==0){g2b(k,b,d,m)}else{h2b(k,b,d,m,c[j>>2]|0,c[h>>2]|0)}do{if((c[k+2017224>>2]|0)!=0){if((c[k+2017212>>2]|0)!=1){break}h=f;c[k+1473300>>2]=Z1b(c[k+1471904>>2]|0,h+8488+((c[h+10008>>2]|0)*108|0)+16|0)|0}}while(0);if((c[f+10108>>2]|0)==0){c[k+1472144>>2]=1}h=f;c[f+8484>>2]=h+8488+((c[h+10008>>2]|0)*108|0)+16;i2b(k,f);c[k+2050772>>2]=0;hkc(k,d,b);if((a[f+13409|0]|0)!=0){j2b(k)}S1b(k);D1b(k);d=0;while(1){if(!(d>>>0<=3>>>0)){break}k2b(f+24556+(d*2304|0)|0,k+2017372+(d*6912|0)|0);d=d+1|0}do{if((c[f+36960>>2]|0)==0){if((c[f+36964>>2]|0)!=0){break}zec(f)}}while(0);d=f;if((c[d+10108>>2]|0)==0){t=1}else{t=(c[d+10124>>2]|0)!=0}if((t&1|0)==0){do{if((c[f+36960>>2]|0)==0){if((c[f+36964>>2]|0)!=0){break}Fec(f);Pec(f,c[f+10128>>2]|0)}}while(0)}if((c[k+1472148>>2]|0)==1){t=f+10136|0;c[t>>2]=c[t>>2]|2}else{t=f+10136|0;c[t>>2]=c[t>>2]&-3}if((c[k+1472152>>2]|0)==1){t=f+10136|0;c[t>>2]=c[t>>2]|4}else{t=f+10136|0;c[t>>2]=c[t>>2]&-5}l2b(k);c[f+10104>>2]=c[f+10108>>2];e3b(k,c[b>>2]|0,0);if((c[f+10108>>2]|0)==0){c[e>>2]=c[f+10136>>2]|1}else{c[e>>2]=c[f+10136>>2]&-2}a[f+13409|0]=0;a[f+13410|0]=0;a[f+13393|0]=0;c[f+8468>>2]=c[f+8452>>2];c[f+8472>>2]=c[f+8456>>2];if((c[f+10120>>2]|0)==0){c[f+10116>>2]=c[f+10112>>2]}if((c[f+10112>>2]|0)==0){i=g;return}$dc(f);e=f+36948|0;c[e>>2]=(c[e>>2]|0)+1;if((c[k+2050800>>2]|0)!=0){c6b(k+2050808|0)}i=g;return}function c2b(a){a=a|0;var b=0,d=0;b=i;d=a;if((c[d+1472172>>2]|0)!=0){c[d+1447952>>2]=c[d+1472176>>2];c[d+1472172>>2]=0}if((c[d+1472156>>2]|0)==0){i=b;return}c[d+1472144>>2]=c[d+1472160>>2];c[d+1472148>>2]=c[d+1472164>>2];c[d+1472152>>2]=c[d+1472168>>2];c[d+1472156>>2]=0;i=b;return}function d2b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=a;a=b;b=c[j+8>>2]|0;k=c[j+12>>2]|0;l=c[a+8>>2]|0;m=c[a+12>>2]|0;n=c[j+28>>2]|0;o=c[j+32>>2]|0;p=c[a+28>>2]|0;q=c[a+32>>2]|0;r=e|0;c[r>>2]=c[j+52>>2];s=r+4|0;c[s>>2]=c[j+56>>2];r=s+4|0;c[r>>2]=c[j+60>>2];c[r+4>>2]=c[j+64>>2];r=f|0;c[r>>2]=c[j+16>>2];s=r+4|0;c[s>>2]=c[j+36>>2];r=s+4|0;c[r>>2]=c[j+36>>2];c[r+4>>2]=c[j+48>>2];j=g|0;c[j>>2]=c[a+52>>2];r=j+4|0;c[r>>2]=c[a+56>>2];j=r+4|0;c[j>>2]=c[a+60>>2];c[j+4>>2]=c[a+64>>2];j=h|0;c[j>>2]=c[a+16>>2];r=j+4|0;c[r>>2]=c[a+36>>2];j=r+4|0;c[j>>2]=c[a+36>>2];c[j+4>>2]=c[a+48>>2];j=0;while(1){if((j|0)>=3){break}do{if((j|0)==0){t=5}else{if((j|0)==3){t=5;break}A4b(c[e+(j<<2)>>2]|0,o,n,c[f+(j<<2)>>2]|0,c[g+(j<<2)>>2]|0,q,p,c[h+(j<<2)>>2]|0)}}while(0);if((t|0)==5){t=0;A4b(c[e+(j<<2)>>2]|0,k,b,c[f+(j<<2)>>2]|0,c[g+(j<<2)>>2]|0,m,l,c[h+(j<<2)>>2]|0)}j=j+1|0}N7b(a);i=d;return}function e2b(a){a=a|0;var b=0,d=0;b=i;d=a;Iec(d+1434592|0);c[d+1472148>>2]=1;c[d+1472152>>2]=1;i=b;return}function f2b(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0;d=i;e=b;b=e+1434592|0;f=e+2017128|0;g=b+13408|0;j=+h[f+160>>3]>48.0|0;if((c[b+10108>>2]|0)==0){mrc(c[e+2047180>>2]|0,0,ca(c[b+10148>>2]|0,c[b+10156>>2]|0)|0)|0;a[g+1|0]=0;a[g+2|0]=0;c[e+2046856>>2]=0;K5b(g);Uhc(g);i=d;return}if((c[e+1472152>>2]|0)!=0){mrc(c[e+2047180>>2]|0,0,ca(c[b+10148>>2]|0,c[b+10156>>2]|0)|0)|0;a[g+1|0]=0;a[g+2|0]=0;c[e+2046856>>2]=0;K5b(g);Uhc(g);Onc(e);if((a[g|0]|0)!=0){a[g+1|0]=1;a[g+2|0]=1;k=r3b(f,+h[f+160>>3],+h[f+160>>3]*.875)|0;Yhc(g,1,0,k-2|0);Yhc(g,1,1,-2);Vhc(g,1,0);Vhc(g,1,1);a[g+3|0]=0}}else{if((a[g|0]|0)!=0){if((c[f+64>>2]|0)==0){if((c[f+104>>2]|0)!=0){a[g+1|0]=0;a[g+2|0]=1;a[g+3|0]=0;k=r3b(f,+h[f+160>>3],+h[f+160>>3]*1.125)|0;Yhc(g,1,0,k+2|0);Vhc(g,1,0);Yhc(g,1,1,-2);Vhc(g,1,1);if((j|0)!=0){l=12}else{if((c[e+2046856>>2]|0)==100){l=12}}if((l|0)==12){Yhc(g,1,2,3);Vhc(g,1,2);Vhc(g,1,3)}}else{K5b(g);mrc(c[e+2047180>>2]|0,0,ca(c[b+10148>>2]|0,c[b+10156>>2]|0)|0)|0;a[g+1|0]=0;a[g+2|0]=0;Uhc(g)}}else{if((c[f+108>>2]|0)!=0){Vhc(g,0,2);Vhc(g,1,2);M5b(g,0,2);Yhc(g,0,2,3);M5b(g,1,2);Yhc(g,1,2,3);if((j|0)!=0){Vhc(g,0,3);Vhc(g,1,3)}a[g+2|0]=1}else{a[g+1|0]=0;a[g+2|0]=0}}}}i=d;return}function g2b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;d=i;b=a;a=b+1434592|0;K2b(a,e);if((c[a+10108>>2]|0)==0){e2b(b)}else{do{if((c[a+10124>>2]|0)==0){if((c[a+36960>>2]|0)!=0){break}if((c[b+2050800>>2]|0)!=0){break}c[a+23736>>2]=c[b+1472152>>2]}}while(0);n2b(a)}if((c[b+1471728>>2]|0)==1){dkc(b);f=b;rlc(f);i=d;return}if((c[b+1471728>>2]|0)==2){Rjc(b)}else{if((c[b+1471728>>2]|0)==3){Xjc(b)}}f=b;rlc(f);i=d;return}function h2b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=a;a=b;b=d;d=e;e=f;f=g;g=l+1434592|0;m=l+2017128|0;n=0;o=0;p=0;q=0;r=e;s=f;c3b(l,c[m>>2]|0,k,j);do{K2b(g,d);if((n|0)==0){if((c[g+10108>>2]|0)==0){e2b(l)}else{do{if((c[g+10124>>2]|0)==0){if((c[g+36960>>2]|0)!=0){break}if((c[l+2050800>>2]|0)!=0){break}c[l+1458328>>2]=c[l+1472152>>2]}}while(0);n2b(g)}}if((c[l+1471728>>2]|0)==1){dkc(l)}else{if((c[l+1471728>>2]|0)==2){Rjc(l)}}rlc(l);if((c[l+2046884>>2]|0)>>>0>=2>>>0){o2b(l);c[l+2050772>>2]=1;if((c[l+2047084>>2]|0)==0){hkc(l,b,a)}c[m+4>>2]=c[a>>2]<<3;p2b(l);if((c[j>>2]|0)==0){c[j>>2]=1}}if((c[l+1471664>>2]|0)==3){o=0}else{do{if((c[g+10108>>2]|0)==0){if((c[m+92>>2]|0)==0){t=55;break}if((c[m+4>>2]|0)>=(c[m+120>>2]|0)){t=55;break}u=d;v=g;w=Z1b(c[l+1471904>>2]|0,v+8488+((c[v+10008>>2]|0)*108|0)+16|0)|0;v=c[l+1473300>>2]|0;x=c[l+1473300>>2]>>1;w=w+(((w|0)!=0^1)&1)|0;if((w|0)>(v|0)){if((c[m+4>>2]|0)<=(c[j>>2]|0)){t=31}else{t=29}}else{t=29}do{if((t|0)==29){t=0;if((w|0)>(x|0)){if((c[m+4>>2]|0)<=(c[k>>2]|0)){t=31;break}}do{if((w|0)<(x|0)){if((c[m+4>>2]|0)<(c[k>>2]|0)){break}if((d|0)<(s|0)){y=d+1|0}else{y=s}r=y;d=(ca(d,x)|0)/(w|0)|0;if((d|0)<(s+r+1>>1|0)){z=d}else{z=s+r+1>>1}d=z}}while(0)}}while(0);if((t|0)==31){t=0;if((d|0)>(r|0)){A=d-1|0}else{A=r}s=A;d=(ca(d,v)|0)/(w|0)|0;if((d|0)<(s+r>>1|0)){B=d}else{B=s+r>>1}d=B}x=d;C=r;D=s;if((x|0)<(C|0)){E=C}else{if((x|0)>(D|0)){F=D}else{F=x}E=F}d=E;o=(d|0)!=(u|0)|0}else{t=55}}while(0);if((t|0)==55){t=0;if((s|0)>(f|0)){G=s}else{G=f}if((q2b(l,c[j>>2]|0,c[k>>2]|0,d,G,e)|0)!=0){x=d;D=0;if((c[m+4>>2]|0)>(c[m>>2]|0)){if((c[m+4>>2]|0)>=(c[m+120>>2]|0)){s=c[m+232>>2]|0}if((d|0)<(s|0)){H=d+1|0}else{H=s}r=H;do{if((q|0)!=0){t=67}else{if((n|0)>1){t=67;break}V2b(l,0);if((s|0)>(f|0)){I=s}else{I=f}d=Z2b(l,c[m>>2]|0,e,I)|0;while(1){if((d|0)<(r|0)){J=(D|0)<10}else{J=0}if(!J){break}V2b(l,0);if((s|0)>(f|0)){K=s}else{K=f}d=Z2b(l,c[m>>2]|0,e,K)|0;D=D+1|0}}}while(0);if((t|0)==67){t=0;V2b(l,1);d=(s+r+1|0)/2|0}p=1}else{if((d|0)>(r|0)){L=d-1|0}else{L=r}s=L;do{if((p|0)!=0){t=86}else{if((n|0)>1){t=86;break}V2b(l,0);d=Z2b(l,c[m>>2]|0,e,f)|0;do{if((c[l+1471664>>2]|0)==2){if((d|0)>=(r|0)){break}r=d}}while(0);while(1){if((d|0)>(s|0)){M=(D|0)<10}else{M=0}if(!M){break}V2b(l,0);d=Z2b(l,c[m>>2]|0,e,f)|0;D=D+1|0}}}while(0);if((t|0)==86){t=0;V2b(l,1);d=(s+r|0)/2|0}q=1}D=d;u=r;w=s;if((D|0)<(u|0)){N=u}else{if((D|0)>(w|0)){O=w}else{O=D}N=O}d=N;o=(d|0)!=(x|0)|0}else{o=0}}}do{if((c[m+108>>2]|0)!=0){if((c[m+4>>2]|0)>=(c[m+120>>2]|0)){break}o=0}}while(0);if((o|0)!=0){n=n+1|0}}while((o|0)!=0);i=h;return}function i2b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+16|0;e=d|0;f=a;a=b;b=f+57488|0;g=a+13380|0;if((c[b+25808>>2]|0)!=0){c[g>>2]=0}else{I1b(e);y2b(c[f+1471904>>2]|0,f,c[f+2047076>>2]|0);J1b(e);h=K1b(e)|0;e=f+2047840|0;f=wrc(c[e>>2]|0,c[e+4>>2]|0,h,G)|0;c[e>>2]=f;c[e+4>>2]=G}if((c[g>>2]|0)<=0){j=a;k=j+8484|0;l=c[k>>2]|0;R7b(l);i=d;return}Ifc(a,b,c[g>>2]|0,0,0);j=a;k=j+8484|0;l=c[k>>2]|0;R7b(l);i=d;return}function j2b(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=b+1434592|0;b=c[e+10204>>2]|0;f=c[e+10216>>2]|0;g=0;while(1){if((g|0)>=(c[e+10148>>2]|0)){break}h=b;j=f;k=0;while(1){if((k|0)>=(c[e+10156>>2]|0)){break}a[j|0]=a[(c[h>>2]|0)+13|0]|0;k=k+1|0;h=h+4|0;j=j+1|0}b=b+(c[e+10160>>2]<<2)|0;f=f+(c[e+10156>>2]|0)|0;g=g+1|0}i=d;return}function k2b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>=2){break}e=0;while(1){if((e|0)>=2){break}f=0;while(1){if((f|0)>=6){break}g=0;while(1){if((g|0)>=(((f|0)==0?3:6)|0)){break}m2b(d+(b*1152|0)+(e*576|0)+(f*96|0)+(g<<4)|0,a+(b*3456|0)+(e*1728|0)+(f*288|0)+(g*48|0)|0);g=g+1|0}f=f+1|0}e=e+1|0}b=b+1|0}i=c;return}function l2b(a){a=a|0;var b=0,d=0;b=i;d=a;if((c[d+1472144>>2]&c[d+1472148>>2]|0)!=0){c[d+1472108>>2]=1}else{if((c[d+1472144>>2]^c[d+1472148>>2]|0)!=0){c[d+1472108>>2]=0}}if((c[d+1472144>>2]&c[d+1472152>>2]|0)!=0){c[d+1472112>>2]=1}else{if((c[d+1472144>>2]^c[d+1472152>>2]|0)!=0){c[d+1472112>>2]=0}}if((c[d+1472152>>2]&c[d+1472148>>2]|0)!=0){c[d+1472116>>2]=1}else{if((c[d+1472152>>2]^c[d+1472148>>2]|0)!=0){c[d+1472116>>2]=0}}c[d+2046872>>2]=7;if((c[d+1472108>>2]|0)!=0){a=d+2046872|0;c[a>>2]=c[a>>2]&-3}if((c[d+2017196>>2]|0)==2147483647){a=d+2046872|0;c[a>>2]=c[a>>2]&-3}if((c[d+1472112>>2]|0)!=0){a=d+2046872|0;c[a>>2]=c[a>>2]&-5}if((c[d+1472116>>2]|0)==0){i=b;return}a=d+2046872|0;c[a>>2]=c[a>>2]&-5;i=b;return}function m2b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];b=3;while(1){if((b|0)>=11){break}f=e+8|0;c[f>>2]=(c[f>>2]|0)+(c[a+(b<<2)>>2]|0);b=b+1|0}c[e+12>>2]=c[a+44>>2];i=d;return}function n2b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;if((c[d+36960>>2]|0)!=0){e=3}else{if((c[d+10124>>2]|0)!=0){e=3}}if((e|0)==3){Iec(d)}if((c[d+23736>>2]|0)>>>0<4>>>0){}else{Cd(2379872,2137528,129,2651248)}nrc(d+13540|0,d+15579+((c[d+23736>>2]|0)*2039|0)|0,2039)|0;i=b;return}function o2b(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=b;b=e+1490744|0;f=e+1434592|0;g=b|0;h=e+108104|0;c[g>>2]=c[h>>2];c[g+4>>2]=c[h+4>>2];c[g+8>>2]=c[h+8>>2];c[g+12>>2]=c[h+12>>2];nrc(b+16|0,e+108120|0,262136)|0;nrc(b+262152|0,e+370264|0,262136)|0;h=b+524288|0;g=f+13420|0;a[h]=a[g]|0;a[h+1|0]=a[g+1|0]|0;a[h+2|0]=a[g+2|0]|0;nrc(c[e+2015036>>2]|0,c[f+10216>>2]|0,ca(c[f+10148>>2]|0,c[f+10156>>2]|0)|0)|0;e=b+524296|0;g=f+13398|0;a[e]=a[g]|0;a[e+1|0]=a[g+1|0]|0;a[e+2|0]=a[g+2|0]|0;a[e+3|0]=a[g+3|0]|0;g=b+524300|0;e=f+13404|0;a[g]=a[e]|0;a[g+1|0]=a[e+1|0]|0;nrc(b+524302|0,f+13540|0,2039)|0;i=d;return}function p2b(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=b;b=e+1490744|0;f=e+1434592|0;g=e+108104|0;h=b|0;c[g>>2]=c[h>>2];c[g+4>>2]=c[h+4>>2];c[g+8>>2]=c[h+8>>2];c[g+12>>2]=c[h+12>>2];nrc(e+108120|0,b+16|0,262136)|0;nrc(e+370264|0,b+262152|0,262136)|0;h=f+13420|0;g=b+524288|0;a[h]=a[g]|0;a[h+1|0]=a[g+1|0]|0;a[h+2|0]=a[g+2|0]|0;nrc(c[f+10216>>2]|0,c[e+2015036>>2]|0,ca(c[f+10148>>2]|0,c[f+10156>>2]|0)|0)|0;e=f+13398|0;g=b+524296|0;a[e]=a[g]|0;a[e+1|0]=a[g+1|0]|0;a[e+2|0]=a[g+2|0]|0;a[e+3|0]=a[g+3|0]|0;g=f+13404|0;e=b+524300|0;a[g]=a[e]|0;a[g+1|0]=a[e+1|0]|0;nrc(f+13540|0,b+524302|0,2039)|0;i=d;return}function q2b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=a;a=b;b=d;d=e;e=f;f=g;g=j+1434592|0;k=j+2017128|0;l=0;if((c[k+4>>2]|0)>(c[k+120>>2]|0)){l=1;m=l;i=h;return m|0}do{if((c[j+2046884>>2]|0)==3){n=8}else{if((c[j+2046884>>2]|0)!=2){break}if((c[g+10108>>2]|0)==0){n=8;break}if((c[j+1472148>>2]|0)!=0){n=8;break}if((c[j+1472152>>2]|0)!=0){n=8}}}while(0);if((n|0)==8){if((c[k+4>>2]|0)>(a|0)){if((d|0)<(e|0)){n=12}else{n=10}}else{n=10}do{if((n|0)==10){if((c[k+4>>2]|0)<(b|0)){if((d|0)>(f|0)){n=12;break}}if((c[j+1471664>>2]|0)==2){do{if((d|0)>(c[j+2017368>>2]|0)){if((c[k+4>>2]|0)>=(((c[k>>2]|0)*7|0)>>3|0)){break}l=1}}while(0)}}}while(0);if((n|0)==12){l=1}}m=l;i=h;return m|0}function r2b(){var a=0,b=0,c=0,d=0;a=i;b=0;while(1){if((b|0)>=256){break}if(+O2b(b)>=30.0){c=4;break}b=b+1|0}if((b|0)!=256){d=b;i=a;return d|0}b=b-1|0;d=b;i=a;return d|0}function s2b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;a=d+1434592|0;e=d+1471600|0;c[d+1471888>>2]=Inc(c[e+8>>2]|0,c[e+12>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,c[e+60>>2]|0)|0;if((c[d+1471888>>2]|0)==0){f1b(a|0,2,2373632,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}if((L7b(d+2048512|0,c[e+8>>2]|0,c[e+12>>2]|0,c[a+8476>>2]|0,c[a+8480>>2]|0,160,0,0,0)|0)==0){i=b;return}f1b(a|0,2,2365248,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f;i=b;return}function t2b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;FYb(c[d+124>>2]|0);c[d+124>>2]=0;a=0;while(1){if((a|0)>=3){break}e=0;while(1){if((e|0)>=3){break}FYb(c[d+128+(a*12|0)+(e<<2)>>2]|0);c[d+128+(a*12|0)+(e<<2)>>2]=0;FYb(c[d+164+(a*12|0)+(e<<2)>>2]|0);c[d+164+(a*12|0)+(e<<2)>>2]=0;FYb(c[d+200+(a*12|0)+(e<<2)>>2]|0);c[d+200+(a*12|0)+(e<<2)>>2]=0;FYb(c[d+236+(a*12|0)+(e<<2)>>2]|0);c[d+236+(a*12|0)+(e<<2)>>2]=0;e=e+1|0}a=a+1|0}i=b;return}function u2b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;a=d+1473304|0;e=0;while(1){if((e|0)>=30){break}f=(w2b(c[d+1471648>>2]|0)|0)!=0;c[a+(e<<2)>>2]=f?-500:0;e=e+1|0}c[a>>2]=0;c[a+8>>2]=0;c[a+4>>2]=0;e=a+12|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+16|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+20|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+24|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+28|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+32|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+36|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+40|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+44|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+48|0;c[e>>2]=(c[e>>2]|0)+1500;e=a+52|0;c[e>>2]=(c[e>>2]|0)+2e3;e=a+56|0;c[e>>2]=(c[e>>2]|0)+1e3;e=a+60|0;c[e>>2]=(c[e>>2]|0)+1500;e=a+64|0;c[e>>2]=(c[e>>2]|0)+2e3;e=a+68|0;c[e>>2]=(c[e>>2]|0)+2e3;e=a+72|0;c[e>>2]=(c[e>>2]|0)+2e3;e=a+76|0;c[e>>2]=(c[e>>2]|0)+2e3;e=a+80|0;c[e>>2]=(c[e>>2]|0)+2500;e=a+84|0;c[e>>2]=(c[e>>2]|0)+2500;e=a+88|0;c[e>>2]=(c[e>>2]|0)+2e3;e=a+92|0;c[e>>2]=(c[e>>2]|0)+2e3;e=a+116|0;c[e>>2]=(c[e>>2]|0)+2500;e=a+96|0;c[e>>2]=(c[e>>2]|0)+2500;e=a+112|0;c[e>>2]=(c[e>>2]|0)+2500;e=a+104|0;c[e>>2]=(c[e>>2]|0)+2500;e=a+100|0;c[e>>2]=(c[e>>2]|0)+2500;e=a+108|0;c[e>>2]=(c[e>>2]|0)+2500;if((c[d+2046872>>2]&1|0)==0){c[a+16>>2]=2147483647;c[a>>2]=2147483647;c[a+68>>2]=2147483647;c[a+28>>2]=2147483647}if((c[d+2046872>>2]&2|0)==0){c[a+8>>2]=2147483647;c[a+72>>2]=2147483647;c[a+56>>2]=2147483647;c[a+24>>2]=2147483647}if((c[d+2046872>>2]&4|0)==0){c[a+4>>2]=2147483647;c[a+76>>2]=2147483647;c[a+32>>2]=2147483647;c[a+20>>2]=2147483647}if((c[d+2046872>>2]&5|0)!=5){c[a+80>>2]=2147483647;c[a+36>>2]=2147483647;c[a+48>>2]=2147483647;c[a+52>>2]=2147483647}if((c[d+2046872>>2]&6|0)==6){i=b;return}c[a+84>>2]=2147483647;c[a+40>>2]=2147483647;c[a+60>>2]=2147483647;c[a+64>>2]=2147483647;i=b;return}function v2b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=d+2046876|0;e=d+1473304|0;f=0;while(1){if((f|0)>=6){break}g=(w2b(c[d+1471648>>2]|0)|0)!=0;c[e+120+(f<<2)>>2]=g?-500:0;f=f+1|0}g=e+120|0;c[g>>2]=(c[g>>2]|0)+2500;g=e+124|0;c[g>>2]=(c[g>>2]|0)+2500;g=e+128|0;c[g>>2]=(c[g>>2]|0)+2500;g=e+140|0;c[g>>2]=(c[g>>2]|0)+2500;g=e+132|0;c[g>>2]=(c[g>>2]|0)+4500;g=e+136|0;c[g>>2]=(c[g>>2]|0)+4500;f=0;while(1){if((f|0)>=6){break}if((c[a+124>>2]&1<<f|0)!=0){c[e+120+(f<<2)>>2]=2147483647}f=f+1|0}if((c[d+2046872>>2]&1|0)==0){c[e+120>>2]=2147483647}if((c[d+2046872>>2]&2|0)==0){c[e+124>>2]=2147483647}if((c[d+2046872>>2]&4|0)==0){c[e+128>>2]=2147483647}if((c[d+2046872>>2]&5|0)!=5){c[e+132>>2]=2147483647}if((c[d+2046872>>2]&6|0)==6){i=b;return}c[e+136>>2]=2147483647;i=b;return}function w2b(a){a=a|0;var b=0,c=0;b=a;if((b|0)==5){c=1}else{c=(b|0)==2}i=i;return c&1|0}function x2b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;d=a<<4;c[b+420>>2]=a;c[b+124>>2]=DYb(a,1)|0;if((c[b+124>>2]|0)==0){f1b(f|0,2,2331936,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}a=0;while(1){if((a|0)>=3){break}h=0;while(1){if((h|0)>=3){break}c[b+128+(a*12|0)+(h<<2)>>2]=BYb(16,d<<1)|0;if((c[b+128+(a*12|0)+(h<<2)>>2]|0)==0){f1b(f|0,2,2326216,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}c[b+164+(a*12|0)+(h<<2)>>2]=BYb(16,d<<1)|0;if((c[b+164+(a*12|0)+(h<<2)>>2]|0)==0){f1b(f|0,2,2320368,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}c[b+200+(a*12|0)+(h<<2)>>2]=BYb(16,d<<1)|0;if((c[b+200+(a*12|0)+(h<<2)>>2]|0)==0){f1b(f|0,2,2315744,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}c[b+236+(a*12|0)+(h<<2)>>2]=BYb(16,d<<1)|0;if((c[b+236+(a*12|0)+(h<<2)>>2]|0)==0){f1b(f|0,2,2311240,(g=i,i=i+1|0,i=i+7&-8,c[g>>2]=0,g)|0);i=g}c[b+272+(a*12|0)+(h<<2)>>2]=c[b+128+(a*12|0)+(h<<2)>>2];c[b+308+(a*12|0)+(h<<2)>>2]=c[b+164+(a*12|0)+(h<<2)>>2];c[b+344+(a*12|0)+(h<<2)>>2]=c[b+200+(a*12|0)+(h<<2)>>2];c[b+380+(a*12|0)+(h<<2)>>2]=c[b+236+(a*12|0)+(h<<2)>>2];h=h+1|0}a=a+1|0}i=e;return}function y2b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=b;b=d;d=f+1434592|0;g=d+13380|0;if((c[d+10108>>2]|0)==0){h=0}else{h=c[f+1471636>>2]|0}c[g+4>>2]=h;if((b|0)!=2){c[g>>2]=A2b(a,f,(b|0)==1|0)|0;i=e;return}b=z2b(f)|0;f=(((ogc(c[d+10168>>2]|0,0)|0)<<16>>16)*20723|0)+1146230>>18;if((c[d+10108>>2]|0)==0){f=f-4|0}d=f;f=0;a=b;if((d|0)<(f|0)){j=f}else{if((d|0)>(a|0)){k=a}else{k=d}j=k}c[g>>2]=j;i=e;return}function z2b(a){a=a|0;i=i;return((c[a+2047856>>2]|0)>>>0>8>>>0?47:63)|0}function A2b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+256|0;f=e|0;g=a;a=b;b=d;d=a+1434592|0;h=z2b(a)|0;j=0;k=c[d+13380>>2]|0;l=0;m=h;if((k|0)<(l|0)){n=l}else{if((k|0)>(m|0)){o=m}else{o=k}n=o}o=n;if((o|0)<16){p=4}else{p=(o|0)/4|0}n=p;mrc(f|0,-1|0,256)|0;T7b(c[d+8484>>2]|0,a+1472180|0);p=B2b(g,a,o,b)|0;k=o;c[f+(o<<2)>>2]=p;while(1){if((n|0)<=0){break}if((o+n|0)<(h|0)){q=o+n|0}else{q=h}m=q;if((o-n|0)>0){r=o-n|0}else{r=0}l=r;s=ca(p>>15-((o|0)/8|0),n)|0;if((c[a+2047856>>2]|0)>>>0<20>>>0){s=((ca(s,c[a+2047856>>2]|0)|0)>>>0)/20|0}if((c[d+10164>>2]|0)!=0){s=s>>1}do{if((j|0)<=0){if((l|0)==(o|0)){break}if((c[f+(l<<2)>>2]|0)<0){t=B2b(g,a,l,b)|0;c[f+(l<<2)>>2]=t}else{t=c[f+(l<<2)>>2]|0}if((t-s|0)<(p|0)){if((t|0)<(p|0)){p=t}k=l}}}while(0);do{if((j|0)>=0){if((m|0)==(o|0)){break}if((c[f+(m<<2)>>2]|0)<0){t=B2b(g,a,m,b)|0;c[f+(m<<2)>>2]=t}else{t=c[f+(m<<2)>>2]|0}if((t|0)<(p-s|0)){p=t;k=m}}}while(0);if((k|0)==(o|0)){n=(n|0)/2|0;j=0}else{j=(k|0)<(o|0)?-1:1;o=k}}i=e;return k|0}function B2b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=b;b=g+1434592|0;Ifc(b,g+57488|0,d,1,e);e=Z1b(a,c[b+8484>>2]|0)|0;T7b(g+1472180|0,c[b+8484>>2]|0);i=f;return e|0}function C2b(a,d,e,f,g,h,j,k,l,m,n,o,p,q){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;q=i;i=i+16|0;r=q|0;s=q+8|0;t=a;a=d;d=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=p;p=a;u=-1;v=r|0;c[v>>2]=(b[d>>1]|0)+m;c[v+4>>2]=(b[d+2>>1]|0)+m;m=s|0;c[m>>2]=(c[r>>2]|0)*-1|0;c[m+4>>2]=(c[r+4>>2]|0)*-1|0;mrc(j|0,0,a<<1|0)|0;mrc(k|0,0,a<<1|0)|0;if((e|0)!=0){w=u;x=w+1|0;y=x&65535;z=n;b[z>>1]=y;i=q;return}e=a-1|0;while(1){if((e|0)<0){break}a=b[o+(e<<1)>>1]|0;m=b[t+(a<<1)>>1]|0;if((m|0)>=(c[r+(((a|0)!=0)<<2)>>2]|0)){A=7;break}if((m|0)<=(c[s+(((a|0)!=0)<<2)>>2]|0)){A=7;break}p=p-1|0;e=e-1|0}e=0;while(1){if((e|0)>=(p|0)){break}A=b[o+(e<<1)>>1]|0;s=b[t+(A<<1)>>1]|0;a=s>>31;m=(s^a)-a|0;if((m|0)>=(c[r+(((A|0)!=0)<<2)>>2]|0)){s=m+(b[f+(((A|0)!=0)<<1)>>1]|0)|0;m=-32768;d=32767;if((s|0)<(m|0)){B=m}else{if((s|0)>(d|0)){C=d}else{C=s}B=C}s=B;d=((ca(s,b[g+(((A|0)!=0)<<1)>>1]|0)|0)>>16)+s|0;s=(ca(d,b[h+(((A|0)!=0)<<1)>>1]|0)|0)>>16;b[j+(A<<1)>>1]=(s^a)-a;b[k+(A<<1)>>1]=ca(b[j+(A<<1)>>1]|0,b[l+(((A|0)!=0)<<1)>>1]|0)|0;if((s|0)!=0){u=e}}e=e+1|0}w=u;x=w+1|0;y=x&65535;z=n;b[z>>1]=y;i=q;return}function D2b(a,d,e,f,g,h,j,k,l,m,n,o,p,q){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;q=i;i=i+4112|0;r=q|0;s=q+8|0;t=q+16|0;u=a;a=d;d=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=p;p=r|0;c[p>>2]=(b[d>>1]|0)+m+1>>1;c[p+4>>2]=(b[d+2>>1]|0)+m+1>>1;m=s|0;c[m>>2]=(c[r>>2]|0)*-1|0;c[m+4>>2]=(c[r+4>>2]|0)*-1|0;m=0;d=-1;mrc(j|0,0,a<<1|0)|0;mrc(k|0,0,a<<1|0)|0;if((e|0)!=0){v=d;w=v+1|0;x=w&65535;y=n;b[y>>1]=x;i=q;return}e=0;while(1){if((e|0)>=(a|0)){break}p=b[o+(e<<1)>>1]|0;z=b[u+(p<<1)>>1]|0;if((z|0)>=(c[r+(((p|0)!=0)<<2)>>2]|0)){A=6}else{if((z|0)<=(c[s+(((p|0)!=0)<<2)>>2]|0)){A=6}}if((A|0)==6){A=0;p=m;m=p+1|0;c[t+(p<<2)>>2]=e}e=e+1|0}e=0;while(1){if((e|0)>=(m|0)){break}A=b[o+(c[t+(e<<2)>>2]<<1)>>1]|0;s=b[u+(A<<1)>>1]|0;r=s>>31;a=(s^r)-r|0;a=a+((b[f+(((A|0)!=0)<<1)>>1]|0)+1>>1)|0;s=a;p=-32768;z=32767;if((s|0)<(p|0)){B=p}else{if((s|0)>(z|0)){C=z}else{C=s}B=C}a=B;s=((ca(a,b[g+(((A|0)!=0)<<1)>>1]|0)|0)>>16)+a|0;a=(ca(s,b[h+(((A|0)!=0)<<1)>>1]|0)|0)>>15;b[j+(A<<1)>>1]=(a^r)-r;b[k+(A<<1)>>1]=(ca(b[j+(A<<1)>>1]|0,b[l+(((A|0)!=0)<<1)>>1]|0)|0)/2|0;if((a|0)!=0){d=c[t+(e<<2)>>2]|0}e=e+1|0}v=d;w=v+1|0;x=w&65535;y=n;b[y>>1]=x;i=q;return}function E2b(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;j=a;a=d;d=e;e=j+(a*8240|0)|0;k=j+24720+(a*52|0)|0;C2b((c[e+8196>>2]|0)+(d<<4<<1)|0,16,c[j+75200>>2]|0,c[e+8220>>2]|0,c[e+8224>>2]|0,c[e+8212>>2]|0,c[e+8216>>2]|0,(c[e+8192>>2]|0)+(d<<4<<1)|0,(c[k>>2]|0)+(d<<4<<1)|0,c[k+40>>2]|0,b[e+8228>>1]|0,(c[e+8200>>2]|0)+(d<<1)|0,f,g);i=h;return}function F2b(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;a=e+1434592|0;f=e|0;e=0;while(1){if((e|0)>=256){break}if((e|0)==0){g=64}else{h=((ngc(e,0)|0)<<16>>16|0)<148;g=h?84:80}h=g;j=(e|0)==0?64:48;k=0;while(1){if((k|0)>=2){break}if((k|0)==0){l=(ngc(e,c[a+10172>>2]|0)|0)<<16>>16}else{l=(ogc(e,0)|0)<<16>>16}m=l;G2b(f+(e<<4)+(k<<1)|0,f+4096+(e<<4)+(k<<1)|0,m);b[f+8192+(e<<4)+(k<<1)>>1]=(ca(h,m)|0)+64>>7;b[f+12288+(e<<4)+(k<<1)>>1]=(ca(j,m)|0)>>7;b[a+256+(e<<4)+(k<<1)>>1]=m;if((k|0)==0){n=(ngc(e,c[a+10176>>2]|0)|0)<<16>>16}else{n=(ogc(e,c[a+10180>>2]|0)|0)<<16>>16}m=n;G2b(f+16384+(e<<4)+(k<<1)|0,f+20480+(e<<4)+(k<<1)|0,m);b[f+24576+(e<<4)+(k<<1)>>1]=(ca(h,m)|0)+64>>7;b[f+28672+(e<<4)+(k<<1)>>1]=(ca(j,m)|0)>>7;b[a+4352+(e<<4)+(k<<1)>>1]=m;k=k+1|0}k=2;while(1){if((k|0)>=8){break}b[f+(e<<4)+(k<<1)>>1]=b[f+(e<<4)+2>>1]|0;b[f+4096+(e<<4)+(k<<1)>>1]=b[f+4096+(e<<4)+2>>1]|0;b[f+8192+(e<<4)+(k<<1)>>1]=b[f+8192+(e<<4)+2>>1]|0;b[f+12288+(e<<4)+(k<<1)>>1]=b[f+12288+(e<<4)+2>>1]|0;b[a+256+(e<<4)+(k<<1)>>1]=b[a+256+(e<<4)+2>>1]|0;b[f+16384+(e<<4)+(k<<1)>>1]=b[f+16384+(e<<4)+2>>1]|0;b[f+20480+(e<<4)+(k<<1)>>1]=b[f+20480+(e<<4)+2>>1]|0;b[f+24576+(e<<4)+(k<<1)>>1]=b[f+24576+(e<<4)+2>>1]|0;b[f+28672+(e<<4)+(k<<1)>>1]=b[f+28672+(e<<4)+2>>1]|0;b[a+4352+(e<<4)+(k<<1)>>1]=b[a+4352+(e<<4)+2>>1]|0;k=k+1|0}e=e+1|0}i=d;return}function G2b(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=c;c=d;d=c;g=0;while(1){if(!(d>>>0>1>>>0)){break}d=d>>>1;g=g+1|0}d=((1<<g+16|0)/(c|0)|0)+1|0;b[f>>1]=d-65536;b[a>>1]=1<<16-g;i=e;return}function H2b(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=a;a=e;e=g+1434592|0;h=a+24720|0;j=g|0;k=d[(c[c[h+160>>2]>>2]|0)+13|0]|0;l=pgc(e+13408|0,k,c[e+10168>>2]|0)|0;m=z3b(g,l+(c[e+10172>>2]|0)|0)|0;n=(c[g+2017088>>2]|0)+(c[a+75264>>2]|0)|0;c[a+8212>>2]=j+(l<<4);c[a+8216>>2]=j+4096+(l<<4);c[a+8220>>2]=j+8192+(l<<4);c[a+8224>>2]=j+12288+(l<<4);b[a+8228>>1]=(ca(b[e+256+(l<<4)+2>>1]|0,n)|0)>>7;c[h+40>>2]=e+256+(l<<4);o=1;while(1){if((o|0)>=3){break}c[a+(o*8240|0)+8212>>2]=j+16384+(l<<4);c[a+(o*8240|0)+8216>>2]=j+20480+(l<<4);c[a+(o*8240|0)+8220>>2]=j+24576+(l<<4);c[a+(o*8240|0)+8224>>2]=j+28672+(l<<4);b[a+(o*8240|0)+8228>>1]=(ca(b[e+4352+(l<<4)+2>>1]|0,n)|0)>>7;c[h+(o*52|0)+40>>2]=e+4352+(l<<4);o=o+1|0}c[a+75200>>2]=Thc(e+13408|0,k,3)|0;c[a+75216>>2]=l;c[a+75232>>2]=m>>6;m=a+75232|0;c[m>>2]=(c[m>>2]|0)+((c[a+75232>>2]|0)==0);A3b(g,c[a+75216>>2]|0);i=f;return}function I2b(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;e=a;a=d;d=c[a+75216>>2]|0;f=(ca(b[e+1434848+(d<<4)+2>>1]|0,(c[e+2017088>>2]|0)+(c[a+75264>>2]|0)|0)|0)>>7;g=(ca(b[e+1438944+(d<<4)+2>>1]|0,(c[e+2017088>>2]|0)+(c[a+75264>>2]|0)|0)|0)>>7;b[a+8228>>1]=f;b[a+16468>>1]=g;b[a+24708>>1]=g;i=i;return}function J2b(a){a=a|0;var b=0,d=0;b=i;d=a;c[d+2017088>>2]=0;H2b(d,d+32768|0);i=b;return}function K2b(a,b){a=a|0;b=b|0;var d=0;d=a;c[d+10168>>2]=b;c[d+10172>>2]=0;c[d+10176>>2]=0;c[d+10180>>2]=0;i=i;return}function L2b(a){a=a|0;i=i;return c[687184+(a<<2)>>2]|0}function M2b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=0;while(1){if((a|0)>=64){e=7;break}if((c[687184+(a<<2)>>2]|0)>=(d|0)){e=4;break}a=a+1|0}if((e|0)==4){f=a;g=f;i=b;return g|0}else if((e|0)==7){f=63;g=f;i=b;return g|0}return 0}function N2b(){var a=0,b=0,d=0.0;a=i;b=0;while(1){if((b|0)>=256){break}d=+O2b(b);c[5827192+(b<<2)>>2]=P2b(d,1.0e-6,-4.0e-4,.15)|0;c[5828216+(b<<2)>>2]=P2b(d,2.0e-6,-.0012,.5)|0;c[6029216+(b<<2)>>2]=P2b(d,15.0e-7,-9.0e-4,.32)|0;c[6030240+(b<<2)>>2]=P2b(d,21.0e-7,-.00125,.5)|0;c[10210672+(b<<2)>>2]=P2b(d,15.0e-7,-9.0e-4,.33)|0;c[10211696+(b<<2)>>2]=P2b(d,21.0e-7,-.00125,.55)|0;c[5901960+(b<<2)>>2]=P2b(d,271.0e-8,-.00113,.55)|0;b=b+1|0}i=a;return}function O2b(a){a=a|0;var b=0,c=0.0;b=i;c=+((ogc(a,0)|0)<<16>>16|0)/4.0;i=b;return+c}function P2b(a,b,c,d){a=+a;b=+b;c=+c;d=+d;var e=0,f=0.0,g=0.0,h=0,j=0,k=0,l=0;e=i;f=a;a=b;b=c;c=d;if(((a*f+b)*f+c)*f<f){g=((a*f+b)*f+c)*f}else{g=f}f=g;if(f<=2.0){h=0;j=h;i=e;return j|0}k=0;while(1){if((k|0)>=256){l=12;break}if(f<=+O2b(k)){l=9;break}k=k+1|0}if((l|0)==9){h=k;j=h;i=e;return j|0}else if((l|0)==12){h=255;j=h;i=e;return j|0}return 0}function Q2b(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0.0;d=i;e=+O2b(b);b=(a|0)==0?33e5:225e4;b=b+(~~(+(b|0)*e)>>12)|0;i=d;return~~(+(b|0)*c/e+.5)|0}function R2b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=e+2017128|0;if((c[b+116>>2]|0)>(c[b+112>>2]>>5|0)){f=c[b+116>>2]|0}else{f=c[b+112>>2]>>5}g=f;if((a|0)<(g|0)){a=g}do{if((c[e+1472148>>2]|0)!=0){if((c[b+108>>2]|0)==0){break}a=g}}while(0);if((a|0)<=(c[b+120>>2]|0)){h=a;i=d;return h|0}a=c[b+120>>2]|0;h=a;i=d;return h|0}function S2b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=e+2017128|0;f=e+1471600|0;if((c[f+44>>2]|0)!=0){e=((ca(c[b+112>>2]|0,c[f+44>>2]|0)|0)>>>0)/100|0;if((a|0)<(e|0)){g=a}else{g=e}a=g}if((a|0)<=(c[b+120>>2]|0)){h=a;i=d;return h|0}a=c[b+120>>2]|0;h=a;i=d;return h|0}function T2b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=d;do{if((b|0)==0){if((c[f+64>>2]|0)!=1){g=4;break}c[a+136>>2]=c[f+112>>2];c[a+140>>2]=c[f+112>>2];c[a+144>>2]=c[f+112>>2]}else{g=4}}while(0);if((g|0)==4){c[a+136>>2]=((c[f+112>>2]|0)+(c[f+116>>2]|0)|0)/2|0;c[a+140>>2]=((c[f+112>>2]|0)+(c[f+116>>2]|0)|0)/2|0;c[a+144>>2]=((c[f+112>>2]|0)+(c[f+116>>2]|0)|0)/2|0}c[a+12>>2]=c[f+116>>2];c[a+16>>2]=c[f+116>>2];c[a+20>>2]=c[f+116>>2];g=f+80|0;b=c[g+4>>2]|0;d=a+168|0;c[d>>2]=c[g>>2];c[d+4>>2]=b;b=f+80|0;d=c[b+4>>2]|0;g=a+176|0;c[g>>2]=c[b>>2];c[g+4>>2]=d;c[a+192>>2]=c[a+112>>2];c[a+196>>2]=c[a+112>>2];c[a+200>>2]=c[a+112>>2];c[a+204>>2]=c[a+112>>2];d=a+208|0;c[d>>2]=0;c[d+4>>2]=0;d=a+224|0;c[d>>2]=0;c[d+4>>2]=0;c[a+80>>2]=10;c[a+88>>2]=8;c[a+92>>2]=0;c[a+96>>2]=0;c[a+100>>2]=0;c[a+104>>2]=0;c[a+68>>2]=0;c[a+124>>2]=c[f+112>>2];c[a+128>>2]=0;c[a+132>>2]=0;h[a+152>>3]=0.0;h[a+160>>3]=+O2b(c[f+112>>2]|0);h[a+40>>3]=1.0;h[a+48>>3]=1.0;h[a+56>>3]=1.0;i=e;return}function U2b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a;a=d+1471600|0;e=d+2017128|0;if((c[a+104>>2]|0)==0){f=0;g=f;i=b;return g|0}d=e+168|0;h=c[d+4>>2]|0;j=0;if((h|0)<(j|0)|(h|0)==(j|0)&(c[d>>2]|0)>>>0<0>>>0){f=1;g=f;i=b;return g|0}d=c[a+104>>2]|0;j=a+88|0;a=Erc(d,(d|0)<0|0?-1:0,c[j>>2]|0,c[j+4>>2]|0)|0;j=Crc(a,G,100,0)|0;a=j;j=e+168|0;d=c[j+4>>2]|0;h=a;k=(h|0)<0|0?-1:0;do{if((d|0)>(k|0)|(d|0)==(k|0)&(c[j>>2]|0)>>>0>h>>>0){if((c[e+184>>2]|0)<=0){l=8;break}m=e+184|0;c[m>>2]=(c[m>>2]|0)-1}else{l=8}}while(0);if((l|0)==8){l=e+168|0;h=c[l+4>>2]|0;j=a;a=(j|0)<0|0?-1:0;do{if((h|0)<=(a|0)&((h|0)<(a|0)|(c[l>>2]|0)>>>0<=j>>>0)){if((c[e+184>>2]|0)!=0){break}c[e+184>>2]=1}}while(0)}if((c[e+184>>2]|0)<=0){c[e+188>>2]=0;f=0;g=f;i=b;return g|0}if((c[e+188>>2]|0)>0){j=e+188|0;c[j>>2]=(c[j>>2]|0)-1;f=1;g=f;i=b;return g|0}else{c[e+188>>2]=c[e+184>>2];f=0;g=f;i=b;return g|0}return 0}function V2b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0.0,h=0,j=0.0,k=0,l=0,m=0.0;d=i;e=a;a=e+1434592|0;f=100;g=+W2b(e);h=0;h=X2b(c[a+10108>>2]|0,c[a+10168>>2]|0,c[a+10140>>2]|0,g)|0;if((h|0)>0){f=((c[e+2017132>>2]|0)*100|0|0)/(h|0)|0}h=b;if((h|0)==0){j=.75}else if((h|0)==1){j=.375}else if((h|0)==2){k=7}else{k=7}if((k|0)==7){j=.25}if((f|0)>102){f=~~(+(f-100|0)*j+100.0);g=g*+(f|0)/100.0;if(g>50.0){g=50.0}l=e;m=g;Y2b(l,m);i=d;return}if((f|0)<99){f=~~(100.0- +(100-f|0)*j);g=g*+(f|0)/100.0;if(g<.005){g=.005}}l=e;m=g;Y2b(l,m);i=d;return}function W2b(a){a=a|0;var b=0,d=0,e=0.0,f=0.0,g=0;b=i;d=a;if((c[d+1444700>>2]|0)==0){e=+h[d+2017176>>3];f=e;i=b;return+f}if((c[d+1472152>>2]|0)!=0){g=5}else{if((c[d+1472148>>2]|0)!=0){g=5}}do{if((g|0)==5){if((c[d+2017236>>2]|0)!=0){break}if((c[d+2050800>>2]|0)!=0){if((c[d+1471664>>2]|0)==1){break}}e=+h[d+2017184>>3];f=e;i=b;return+f}}while(0);e=+h[d+2017168>>3];f=e;i=b;return+f}function X2b(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;var e=0,f=0;e=i;f=Q2b(a,b,d)|0;b=c;c=Erc(f,(f|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;b=c>>>9|G<<23;i=e;return b|0}function Y2b(a,b){a=a|0;b=+b;var d=0,e=0,f=0.0,g=0;d=i;e=a;f=b;if((c[e+1444700>>2]|0)==0){h[e+2017176>>3]=f;i=d;return}if((c[e+1472152>>2]|0)!=0){g=5}else{if((c[e+1472148>>2]|0)!=0){g=5}else{g=9}}do{if((g|0)==5){if((c[e+2017236>>2]|0)!=0){g=9;break}if((c[e+2050800>>2]|0)!=0){if((c[e+1471664>>2]|0)==1){g=9;break}}h[e+2017184>>3]=f}}while(0);if((g|0)==9){h[e+2017168>>3]=f}i=d;return}function Z2b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0;f=i;g=a;a=e;e=g+1434592|0;h=a;j=2147483647;k=+W2b(g);g=b;b=g;l=c[e+10140>>2]|0;m=Frc(b<<9|0>>>23,((g|0)<0|0?-1:0)<<9|b>>>23,l,(l|0)<0|0?-1:0)|0;l=m;m=d;while(1){n=Q2b(c[e+10108>>2]|0,m,k)|0;if((n|0)<=(l|0)){break}j=n-l|0;d=m+1|0;m=d;if((d|0)>(a|0)){o=10;break}}if((o|0)==10){p=h;i=f;return p|0}if((l-n|0)<=(j|0)){h=m}else{h=m-1|0}p=h;i=f;return p|0}function _2b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;if((c[f+2046868>>2]|0)==0){if((c[f+1471664>>2]|0)==1){g=$2b(f,a,b)|0}else{g=a3b(f,a,b)|0}}else{g=b3b(f,a,b)|0}if((c[f+2047084>>2]|0)==0){h=g;i=e;return h|0}if((g|0)==0){g=g+1|0}if((c[f+2047016>>2]|0)==1){g=g-(c[f+2047020>>2]|0)|0}if((g|0)<(c[a>>2]|0)){c[a>>2]=g}else{if((g|0)>(c[b>>2]|0)){c[b>>2]=g}}h=g;i=e;return h|0}function $2b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;f=a;a=b;b=d;d=f+1434592|0;g=f+2017128|0;h=x3b(f)|0;j=d;if((c[j+10108>>2]|0)==0){k=1}else{k=(c[j+10124>>2]|0)!=0}if((k&1|0)!=0){l=c[g+236>>2]|0;if((c[g+92>>2]|0)!=0){k=c[g+24>>2]|0;m=+O2b(k);j=r3b(g,m,m*.75)|0;if((k+j|0)>(c[g+236>>2]|0)){n=k+j|0}else{n=c[g+236>>2]|0}l=n}else{if((c[d+36948>>2]|0)>>>0>0>>>0){m=1.0;l=v3b(c[g+136>>2]|0,c[g+36>>2]|0,c[258728]|0,c[258762]|0,5827192,5828216)|0;if((ca(c[d+8452>>2]|0,c[d+8456>>2]|0)|0)<=101376){m=m-.25}o=+O2b(l);l=l+(r3b(g,o,o*m)|0)|0}}}else{do{if((c[g+108>>2]|0)!=0){p=24}else{if((c[f+2050800>>2]|0)!=0){p=24;break}if((c[f+1472148>>2]|0)==0){if((c[f+1472152>>2]|0)==0){p=24;break}}do{if((c[g+88>>2]|0)>1){if((c[g+140>>2]|0)>=(h|0)){p=22;break}q=c[g+140>>2]|0}else{p=22}}while(0);if((p|0)==22){q=h}l=v3b(q,c[g+28>>2]|0,c[287016]|0,c[287172]|0,6029216,6030240)|0}}while(0);if((p|0)==24){if((c[d+36948>>2]|0)>>>0>1>>>0){if((c[g+140>>2]|0)<(h|0)){l=c[5901960+(c[g+140>>2]<<2)>>2]|0}else{l=c[5901960+(h<<2)>>2]|0}}else{if((c[g+136>>2]|0)<(h|0)){l=c[5901960+(c[g+136>>2]<<2)>>2]|0}else{l=c[5901960+(h<<2)>>2]|0}}}}n=l;j=c[g+236>>2]|0;k=c[g+232>>2]|0;if((n|0)<(j|0)){r=j}else{if((n|0)>(k|0)){s=k}else{s=n}r=s}l=r;r=h;s=l;n=c[g+232>>2]|0;if((r|0)<(s|0)){t=s}else{if((r|0)>(n|0)){u=n}else{u=r}t=u}h=t;c[b>>2]=h;c[a>>2]=l;do{if((c[d+10108>>2]|0)==0){if((c[g+92>>2]|0)!=0){break}if((c[d+36948>>2]|0)==0){break}t=0;t=s3b(f+2017128|0,c[d+10108>>2]|0,h,2.0)|0;c[b>>2]=h+t;if((c[b>>2]|0)>(c[a>>2]|0)){v=c[b>>2]|0}else{v=c[a>>2]|0}c[b>>2]=v}}while(0);do{if((c[d+10108>>2]|0)==0){if((c[g+92>>2]|0)==0){p=57;break}q=c[g+24>>2]|0}else{p=57}}while(0);if((p|0)==57){q=Z2b(f,c[g>>2]|0,l,h)|0;if((q|0)>(c[b>>2]|0)){if((c[g>>2]|0)>=(c[g+120>>2]|0)){c[b>>2]=q}else{q=c[b>>2]|0}}}if((c[b>>2]|0)<=(c[g+232>>2]|0)){if((c[b>>2]|0)>=(c[g+236>>2]|0)){}else{p=65}}else{p=65}if((p|0)==65){Cd(2335112,2559168,599,2651608);return 0}if((c[a>>2]|0)<=(c[g+232>>2]|0)){if((c[a>>2]|0)>=(c[g+236>>2]|0)){}else{p=68}}else{p=68}if((p|0)==68){Cd(2426048,2559168,601,2651608);return 0}do{if((q|0)<=(c[g+232>>2]|0)){if((q|0)>=(c[g+236>>2]|0)){w=1}else{break}p=w&1;p=q;i=e;return p|0}}while(0);Cd(2342752,2559168,602,2651608);return 0}function a3b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=a;a=b;b=d;d=f+1434592|0;g=f+2017128|0;h=f+1471600|0;j=w3b(f)|0;k=d;if((c[k+10108>>2]|0)==0){l=1}else{l=(c[k+10124>>2]|0)!=0}if((l&1|0)!=0){m=c[g+236>>2]|0;if((c[g+92>>2]|0)!=0){l=c[g+24>>2]|0;n=+O2b(l);k=r3b(g,n,n*.75)|0;if((l+k|0)>(c[g+236>>2]|0)){o=l+k|0}else{o=c[g+236>>2]|0}m=o}else{if((c[d+36948>>2]|0)>>>0>0>>>0){n=1.0;m=v3b(c[g+136>>2]|0,c[g+36>>2]|0,c[258728]|0,c[258762]|0,5827192,5828216)|0;if((ca(c[d+8452>>2]|0,c[d+8456>>2]|0)|0)<=101376){n=n-.25}p=+O2b(m);m=m+(r3b(g,p,p*n)|0)|0}}}else{do{if((c[g+108>>2]|0)!=0){q=40}else{if((c[f+1472148>>2]|0)==0){if((c[f+1472152>>2]|0)==0){q=40;break}}do{if((c[g+88>>2]|0)>1){if((c[g+140>>2]|0)>=(j|0)){q=21;break}r=c[g+140>>2]|0}else{q=21}}while(0);if((q|0)==21){r=c[g+136>>2]|0}if((c[h+64>>2]|0)==2){if((r|0)<(c[f+2017368>>2]|0)){r=c[f+2017368>>2]|0}if((c[g+88>>2]|0)>1){m=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,10210672,10211696)|0}else{m=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,6029216,6030240)|0}m=(m*15|0|0)/16|0}else{if((c[h+64>>2]|0)==3){if((c[f+1472152>>2]|0)!=0){if((c[g+88>>2]|0)>1){m=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,10210672,10211696)|0}else{m=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,6029216,6030240)|0}}else{m=c[f+2017368>>2]|0}}else{m=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,6029216,6030240)|0}}}}while(0);if((q|0)==40){if((c[h+64>>2]|0)==3){m=c[f+2017368>>2]|0}else{if((c[d+36948>>2]|0)>>>0>1>>>0){m=c[5901960+(c[g+140>>2]<<2)>>2]|0}else{m=c[5901960+(c[g+136>>2]<<2)>>2]|0}do{if((c[h+64>>2]|0)==2){if((m|0)>=(c[f+2017368>>2]|0)){break}if((c[g+196>>2]|0)<(c[g+116>>2]|0)){m=c[h+120>>2]|0}else{m=c[f+2017368>>2]|0}}}while(0)}}}o=m;k=c[g+236>>2]|0;l=c[g+232>>2]|0;if((o|0)<(k|0)){s=k}else{if((o|0)>(l|0)){t=l}else{t=o}s=t}m=s;s=j;t=m;o=c[g+232>>2]|0;if((s|0)<(t|0)){u=t}else{if((s|0)>(o|0)){v=o}else{v=s}u=v}j=u;c[b>>2]=j;c[a>>2]=m;u=0;do{if((c[d+10108>>2]|0)==0){if((c[g+92>>2]|0)!=0){q=70;break}if((c[d+36948>>2]|0)==0){q=70;break}u=s3b(f+2017128|0,c[d+10108>>2]|0,j,2.0)|0}else{q=70}}while(0);if((q|0)==70){do{if((c[g+108>>2]|0)==0){if((c[f+1472148>>2]|0)==0){if((c[f+1472152>>2]|0)==0){break}}u=s3b(f+2017128|0,c[d+10108>>2]|0,j,1.75)|0}}while(0)}c[b>>2]=j+u;if((c[b>>2]|0)>(c[a>>2]|0)){w=c[b>>2]|0}else{w=c[a>>2]|0}c[b>>2]=w;if((c[h+64>>2]|0)==3){r=m}else{do{if((c[d+10108>>2]|0)==0){if((c[g+92>>2]|0)==0){q=83;break}r=c[g+24>>2]|0}else{q=83}}while(0);if((q|0)==83){r=Z2b(f,c[g>>2]|0,m,j)|0;if((r|0)>(c[b>>2]|0)){if((c[g>>2]|0)>=(c[g+120>>2]|0)){c[b>>2]=r}else{r=c[b>>2]|0}}}}if((c[b>>2]|0)<=(c[g+232>>2]|0)){if((c[b>>2]|0)>=(c[g+236>>2]|0)){}else{q=92}}else{q=92}if((q|0)==92){Cd(2335112,2559168,793,2651568);return 0}if((c[a>>2]|0)<=(c[g+232>>2]|0)){if((c[a>>2]|0)>=(c[g+236>>2]|0)){}else{q=95}}else{q=95}if((q|0)==95){Cd(2426048,2559168,795,2651568);return 0}do{if((r|0)<=(c[g+232>>2]|0)){if((r|0)>=(c[g+236>>2]|0)){x=1}else{break}q=x&1;q=r;i=e;return q|0}}while(0);Cd(2342752,2559168,796,2651568);return 0}function b3b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;f=a;a=b;b=d;d=f+1434592|0;g=f+2017128|0;h=f+1471600|0;j=c[f+2048508>>2]|0;k=d;if((c[k+10108>>2]|0)==0){l=1}else{l=(c[k+10124>>2]|0)!=0}if((l&1|0)!=0){if((c[g+92>>2]|0)!=0){l=c[g+24>>2]|0;m=+O2b(l);k=r3b(g,m,m*.75)|0;if((l+k|0)>(c[g+236>>2]|0)){n=l+k|0}else{n=c[g+236>>2]|0}o=n}else{m=1.0;o=v3b(j,c[g+36>>2]|0,c[258728]|0,c[258762]|0,5827192,5828216)|0;if((ca(c[d+8452>>2]|0,c[d+8456>>2]|0)|0)<=101376){m=m-.25}m=m+(.05- +(c[f+2048500>>2]|0)*.001);p=+O2b(o);o=o+(r3b(g,p,p*m)|0)|0}}else{do{if((c[g+108>>2]|0)!=0){q=38}else{if((c[f+1472148>>2]|0)==0){if((c[f+1472152>>2]|0)==0){q=38;break}}do{if((c[g+88>>2]|0)>1){if((c[g+140>>2]|0)>=(j|0)){q=19;break}r=c[g+140>>2]|0}else{q=19}}while(0);if((q|0)==19){r=j}if((c[h+64>>2]|0)==2){if((r|0)<(c[f+2017368>>2]|0)){r=c[f+2017368>>2]|0}if((c[g+88>>2]|0)>1){o=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,10210672,10211696)|0}else{o=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,6029216,6030240)|0}o=(o*15|0|0)/16|0}else{if((c[h+64>>2]|0)==3){if((c[f+1472152>>2]|0)!=0){if((c[g+88>>2]|0)>1){o=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,10210672,10211696)|0}else{o=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,6029216,6030240)|0}}else{o=c[f+2017368>>2]|0}}else{o=v3b(r,c[g+28>>2]|0,c[287016]|0,c[287172]|0,6029216,6030240)|0}}}}while(0);if((q|0)==38){if((c[h+64>>2]|0)==3){o=c[f+2017368>>2]|0}else{o=c[5901960+(j<<2)>>2]|0;do{if((c[h+64>>2]|0)==2){if((o|0)>=(c[f+2017368>>2]|0)){break}if((c[g+196>>2]|0)<(c[g+116>>2]|0)){o=c[h+120>>2]|0}else{o=c[f+2017368>>2]|0}}}while(0)}}}n=o;k=c[g+236>>2]|0;l=c[g+232>>2]|0;if((n|0)<(k|0)){s=k}else{if((n|0)>(l|0)){t=l}else{t=n}s=t}o=s;s=j;t=o;n=c[g+232>>2]|0;if((s|0)<(t|0)){u=t}else{if((s|0)>(n|0)){v=n}else{v=s}u=v}j=u;c[b>>2]=j;c[a>>2]=o;u=0;do{if((c[d+10108>>2]|0)==0){if((c[g+92>>2]|0)!=0){q=64;break}u=s3b(f+2017128|0,c[d+10108>>2]|0,j,2.0)|0}else{q=64}}while(0);if((q|0)==64){do{if((c[g+108>>2]|0)==0){if((c[h+64>>2]|0)==1){break}if((c[f+1472148>>2]|0)==0){if((c[f+1472152>>2]|0)==0){break}}u=s3b(f+2017128|0,c[d+10108>>2]|0,j,1.75)|0}}while(0)}c[b>>2]=j+u;if((c[b>>2]|0)>(c[a>>2]|0)){w=c[b>>2]|0}else{w=c[a>>2]|0}c[b>>2]=w;if((c[h+64>>2]|0)==3){r=o}else{do{if((c[d+10108>>2]|0)==0){if((c[g+92>>2]|0)==0){q=78;break}r=c[g+24>>2]|0}else{q=78}}while(0);if((q|0)==78){r=Z2b(f,c[g>>2]|0,o,j)|0;if((r|0)>(c[b>>2]|0)){if((c[g>>2]|0)>=(c[g+120>>2]|0)){c[b>>2]=r}else{r=c[b>>2]|0}}}}if((c[b>>2]|0)<=(c[g+232>>2]|0)){if((c[b>>2]|0)>=(c[g+236>>2]|0)){}else{q=87}}else{q=87}if((q|0)==87){Cd(2335112,2559168,985,2651536);return 0}if((c[a>>2]|0)<=(c[g+232>>2]|0)){if((c[a>>2]|0)>=(c[g+236>>2]|0)){}else{q=90}}else{q=90}if((q|0)==90){Cd(2426048,2559168,987,2651536);return 0}do{if((r|0)<=(c[g+232>>2]|0)){if((r|0)>=(c[g+236>>2]|0)){x=1}else{break}q=x&1;q=r;i=e;return q|0}}while(0);Cd(2342752,2559168,988,2651536);return 0}function c3b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=d;d=e;if((c[g+1471664>>2]|0)==3){c[b>>2]=0;c[d>>2]=2147483647;i=f;return}e=(ca(c[g+2047148>>2]|0,a)|0)/100|0;c[d>>2]=a+e;c[b>>2]=a-e;e=d;c[e>>2]=(c[e>>2]|0)+200;e=b;c[e>>2]=(c[e>>2]|0)-200;if((c[b>>2]|0)<0){c[b>>2]=0}if((c[d>>2]|0)>(c[g+2017248>>2]|0)){c[d>>2]=c[g+2017248>>2]}i=f;return}function d3b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=e+1434592|0;f=e+2017128|0;c[f>>2]=b;b=c[f>>2]|0;e=Erc(b,(b|0)<0|0?-1:0,64,0)|0;b=Erc(e,G,64,0)|0;e=ca(c[a+8452>>2]|0,c[a+8456>>2]|0)|0;a=Crc(b,G,e,(e|0)<0|0?-1:0)|0;c[f+8>>2]=a;i=d;return}function e3b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0;e=i;i=i+8|0;f=e|0;g=a;c[f>>2]=b;c[f+4>>2]=d;d=g+1434592|0;b=g+1471600|0;a=g+2017128|0;j=c[d+10168>>2]|0;c[a+4>>2]=c[f>>2]<<3|0>>>29;if((c[g+2046884>>2]|0)>>>0>=2>>>0){k=1}else{k=(c[b+64>>2]|0)==1}V2b(g,k?2:0);if((c[d+10108>>2]|0)==0){c[a+12>>2]=j;c[a+136>>2]=((c[a+136>>2]|0)*3|0)+j+2>>2}else{do{if((c[a+108>>2]|0)!=0){l=11}else{if((c[g+1472148>>2]|0)==0){if((c[g+1472152>>2]|0)==0){l=11;break}}if((c[g+2050800>>2]|0)!=0){if((c[b+64>>2]|0)==1){l=11;break}}c[a+20>>2]=j;c[a+144>>2]=((c[a+144>>2]|0)*3|0)+j+2>>2}}while(0);if((l|0)==11){c[a+16>>2]=j;c[a+140>>2]=((c[a+140>>2]|0)*3|0)+j+2>>2;k=a+132|0;c[k>>2]=(c[k>>2]|0)+1;m=+O2b(j);k=a+152|0;h[k>>3]=+h[k>>3]+m;h[a+160>>3]=+h[a+152>>3]/+(c[a+132>>2]|0);k=a+128|0;c[k>>2]=(c[k>>2]|0)+j;c[a+124>>2]=(c[a+128>>2]|0)/(c[a+132>>2]|0)|0}}do{if((j|0)<(c[a+24>>2]|0)){l=19}else{if((c[g+2046856>>2]|0)>=100){break}if((c[d+10108>>2]|0)==0){l=19;break}if((c[g+1472152>>2]|0)!=0){l=19;break}if((c[g+1472148>>2]|0)==0){break}if((c[a+108>>2]|0)==0){l=19}}}while(0);if((l|0)==19){c[a+24>>2]=j}f3b(g,c[a+4>>2]|0);if((c[d+10108>>2]|0)!=0){c[a+192>>2]=((c[a+192>>2]|0)*3|0)+(c[a>>2]|0)+2>>2;c[a+196>>2]=((c[a+196>>2]|0)*3|0)+(c[a+4>>2]|0)+2>>2;c[a+200>>2]=((c[a+200>>2]|0)*31|0)+(c[a>>2]|0)+16>>5;c[a+204>>2]=((c[a+204>>2]|0)*31|0)+(c[a+4>>2]|0)+16>>5}j=c[a+4>>2]|0;k=a+208|0;f=wrc(c[k>>2]|0,c[k+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[k>>2]=f;c[k+4>>2]=G;if((c[d+10112>>2]|0)!=0){n=c[a+112>>2]|0}else{n=0}k=a+216|0;f=wrc(c[k>>2]|0,c[k+4>>2]|0,n,(n|0)<0|0?-1:0)|0;c[k>>2]=f;c[k+4>>2]=G;k=a+208|0;f=a+216|0;n=xrc(c[k>>2]|0,c[k+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=a+224|0;c[f>>2]=n;c[f+4>>2]=G;do{if((c[b+228>>2]|0)!=0){if((c[g+1472152>>2]|0)==0){l=29;break}if((c[d+10108>>2]|0)==0){l=29;break}g3b(g)}else{l=29}}while(0);if((l|0)==29){h3b(g)}if((c[d+10108>>2]|0)==0){c[a+88>>2]=0}if((c[d+10112>>2]|0)==0){i=e;return}d=a+88|0;c[d>>2]=(c[d>>2]|0)+1;d=a+84|0;c[d>>2]=(c[d>>2]|0)-1;i=e;return}function f3b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a;a=b;b=e+1471600|0;f=e+2017128|0;if((c[e+1444704>>2]|0)!=0){g=(c[f+112>>2]|0)-a|0;h=f+176|0;j=wrc(c[h>>2]|0,c[h+4>>2]|0,g,(g|0)<0|0?-1:0)|0;c[h>>2]=j;c[h+4>>2]=G}else{h=a;j=f+176|0;g=xrc(c[j>>2]|0,c[j+4>>2]|0,h,(h|0)<0|0?-1:0)|0;c[j>>2]=g;c[j+4>>2]=G}j=f+176|0;g=c[j+4>>2]|0;h=b+96|0;k=c[h+4>>2]|0;if((g|0)<(k|0)|(g|0)==(k|0)&(c[j>>2]|0)>>>0<(c[h>>2]|0)>>>0){h=f+176|0;l=c[h+4>>2]|0;m=c[h>>2]|0}else{h=b+96|0;l=c[h+4>>2]|0;m=c[h>>2]|0}h=f+176|0;c[h>>2]=m;c[h+4>>2]=l;l=f+176|0;h=c[l+4>>2]|0;m=f+168|0;c[m>>2]=c[l>>2];c[m+4>>2]=h;if((c[e+2050800>>2]|0)==0){i=d;return}if((c[e+1471664>>2]|0)!=1){i=d;return}u3b(e+2050808|0,a);i=d;return}function g3b(a){a=a|0;var b=0;b=a+2017128|0;c[b+64>>2]=0;c[b+100>>2]=0;c[b+104>>2]=1;i=i;return}function h3b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=d+2017128|0;if((c[d+1472148>>2]|0)!=0){c[a+64>>2]=0;if((c[a+100>>2]|0)==0){c[a+104>>2]=0}if((c[a+68>>2]|0)>0){e=a+68|0;c[e>>2]=(c[e>>2]|0)-1}i=b;return}else{if((c[d+1472152>>2]|0)==0){if((c[a+68>>2]|0)>0){d=a+68|0;c[d>>2]=(c[d>>2]|0)-1}d=a+64|0;c[d>>2]=(c[d>>2]|0)+1}i=b;return}}function i3b(a){a=a|0;var b=0,d=0;b=i;d=a;f3b(d,0);c[d+1444696>>2]=c[d+1444700>>2];a=d+2017216|0;c[a>>2]=(c[a>>2]|0)+1;a=d+2017212|0;c[a>>2]=(c[a>>2]|0)-1;i=b;return}function j3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a;a=d+1434592|0;e=d+2017128|0;a:do{if((c[d+1472152>>2]|0)!=0){f=10}else{do{if((c[a+36948>>2]|0)!=0){if((c[a+10136>>2]&1|0)!=0){break}if((c[e+84>>2]|0)==0){break}if((c[d+1471652>>2]|0)==0){f=10;break a}if((k3b(d)|0)==0){f=10;break a}}}while(0);c[a+10108>>2]=0;if((c[a+36948>>2]|0)!=0){g=(c[e+84>>2]|0)==0}else{g=0}c[e+92>>2]=g&1;c[e+84>>2]=c[d+1472104>>2];c[e+36>>2]=2e3;c[e+104>>2]=0}}while(0);if((f|0)==10){c[a+10108>>2]=1}if((c[e+68>>2]|0)==0){c[e+80>>2]=10;c[e+68>>2]=c[e+80>>2];if((c[e+68>>2]|0)>(c[e+84>>2]|0)){c[e+68>>2]=c[e+84>>2]}c[d+1472148>>2]=1;c[e+100>>2]=1;c[e+28>>2]=2e3}if((c[a+10108>>2]|0)==0){h=l3b(d)|0;j=d;k=h;d3b(j,k);i=b;return}else{h=m3b(d)|0;j=d;k=h;d3b(j,k);i=b;return}}function k3b(a){a=a|0;i=i;return 0}function l3b(a){a=a|0;var b=0,d=0;b=i;d=a;a=S2b(d,(c[d+2017240>>2]|0)*25|0)|0;i=b;return a|0}function m3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a;a=d+2017128|0;do{if((c[a+108>>2]|0)==0){if((c[d+1472148>>2]|0)==0){if((c[d+1472152>>2]|0)==0){break}}e=(ca(c[a+112>>2]|0,c[a+80>>2]|0)|0)*10|0;f=(e|0)/((c[a+80>>2]|0)+10-1|0)|0;g=f;h=d;j=g;k=R2b(h,j)|0;i=b;return k|0}}while(0);e=ca(c[a+112>>2]|0,c[a+80>>2]|0)|0;f=(e|0)/((c[a+80>>2]|0)+10-1|0)|0;g=f;h=d;j=g;k=R2b(h,j)|0;i=b;return k|0}function n3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a;a=d+1434592|0;e=d+2017128|0;f=c[e+112>>2]|0;do{if((c[a+36948>>2]|0)!=0){if((c[a+10136>>2]&1|0)!=0){break}if((c[d+1471652>>2]|0)!=0){if(((c[e+88>>2]|0)%(c[d+1472104>>2]|0)|0|0)==0){break}}c[a+10108>>2]=1;do{if((c[d+2046868>>2]|0)==0){if((c[d+1471664>>2]|0)!=1){break}f=p3b(d)|0}}while(0);g=d;h=f;d3b(g,h);j=e;k=j+68|0;c[k>>2]=2147483647;l=e;m=l+80|0;c[m>>2]=2147483647;i=b;return}}while(0);c[a+10108>>2]=0;c[e+104>>2]=0;do{if((c[d+2046868>>2]|0)==0){if((c[d+1471664>>2]|0)!=1){break}f=o3b(d)|0}}while(0);g=d;h=f;d3b(g,h);j=e;k=j+68|0;c[k>>2]=2147483647;l=e;m=l+80|0;c[m>>2]=2147483647;i=b;return}function o3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0;b=i;d=a;a=d+2017128|0;e=d+1471600|0;f=d+2050808|0;if((c[d+1471540>>2]|0)==0){g=d+1471680|0;j=Crc(c[g>>2]|0,c[g+4>>2]|0,2,0)|0;g=G;k=0;if((g|0)>(k|0)|(g|0)==(k|0)&j>>>0>2147483647>>>0){l=2147483647}else{j=d+1471680|0;k=Crc(c[j>>2]|0,c[j+4>>2]|0,2,0)|0;l=k}m=l;n=d;o=m;p=S2b(n,o)|0;i=b;return p|0}l=32;q=+h[e+16>>3];do{if((c[f+12>>2]|0)>1){if((c[e+64>>2]|0)!=1){break}q=+h[f+16+((c[f+4>>2]|0)*960|0)+272>>3]}}while(0);if((l|0)>(~~(2.0*q-16.0)|0)){r=l}else{r=~~(2.0*q-16.0)}l=r;if(+(c[a+88>>2]|0)<q/2.0){l=~~(+(ca(l,c[a+88>>2]|0)|0)/(q/2.0))}m=(ca(l+16|0,c[a+112>>2]|0)|0)>>4;n=d;o=m;p=S2b(n,o)|0;i=b;return p|0}function p3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a;a=f+1471600|0;g=f+2017128|0;h=f+2050808|0;f=a+88|0;j=g+168|0;k=xrc(c[f>>2]|0,c[f+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;c[d>>2]=k;c[d+4>>2]=G;k=a+88|0;j=Crc(c[k>>2]|0,c[k+4>>2]|0,100,0)|0;k=wrc(1,0,j,G)|0;c[e>>2]=k;c[e+4>>2]=G;if((c[g+112>>2]>>4|0)>200){l=c[g+112>>2]>>4}else{l=200}k=l;l=c[g+112>>2]|0;do{if((c[h+12>>2]|0)>1){if((c[a+64>>2]|0)!=1){break}g=h+16+((c[h+4>>2]|0)*960|0)|0;l=c[g+280>>2]|0;if((c[g+280>>2]>>4|0)>200){m=c[g+280>>2]>>4}else{m=200}k=m}}while(0);m=c[d+4>>2]|0;h=0;if((m|0)>(h|0)|(m|0)==(h|0)&(c[d>>2]|0)>>>0>0>>>0){h=Crc(c[d>>2]|0,c[d+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;m=G;g=c[a+68>>2]|0;j=(g|0)<0|0?-1:0;if((m|0)<(j|0)|(m|0)==(j|0)&h>>>0<g>>>0){g=Crc(c[d>>2]|0,c[d+4>>2]|0,c[e>>2]|0,c[e+4>>2]|0)|0;n=G;o=g}else{g=c[a+68>>2]|0;n=(g|0)<0|0?-1:0;o=g}l=l-((ca(l,o)|0)/200|0)|0}else{o=c[d+4>>2]|0;g=0;if((o|0)<(g|0)|(o|0)==(g|0)&(c[d>>2]|0)>>>0<0>>>0){g=xrc(0,0,c[d>>2]|0,c[d+4>>2]|0)|0;o=Crc(g,G,c[e>>2]|0,c[e+4>>2]|0)|0;g=G;n=c[a+72>>2]|0;h=(n|0)<0|0?-1:0;if((g|0)<(h|0)|(g|0)==(h|0)&o>>>0<n>>>0){n=xrc(0,0,c[d>>2]|0,c[d+4>>2]|0)|0;d=Crc(n,G,c[e>>2]|0,c[e+4>>2]|0)|0;p=G;q=d}else{d=c[a+72>>2]|0;p=(d|0)<0|0?-1:0;q=d}l=l+((ca(l,q)|0)/200|0)|0}}if((k|0)>(l|0)){r=k;i=b;return r|0}else{r=l;i=b;return r|0}return 0}function q3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a;a=d+1434592|0;e=d+2017128|0;do{if((c[a+36948>>2]|0)!=0){if((c[a+10136>>2]&1|0)!=0){break}if((c[e+84>>2]|0)==0){break}if((c[d+1471652>>2]|0)!=0){if((k3b(d)|0)!=0){break}}c[a+10108>>2]=1;f=p3b(d)|0;g=d;h=f;d3b(g,h);j=e;k=j+68|0;c[k>>2]=2147483647;l=e;m=l+80|0;c[m>>2]=2147483647;i=b;return}}while(0);c[a+10108>>2]=0;if((c[a+36948>>2]|0)!=0){n=(c[e+84>>2]|0)==0}else{n=0}c[e+92>>2]=n&1;c[e+84>>2]=c[d+1472104>>2];c[e+36>>2]=2e3;c[e+104>>2]=0;f=o3b(d)|0;g=d;h=f;d3b(g,h);j=e;k=j+68|0;c[k>>2]=2147483647;l=e;m=l+80|0;c[m>>2]=2147483647;i=b;return}function r3b(a,b,d){a=a|0;b=+b;d=+d;var e=0,f=0,g=0.0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=a;g=b;b=d;a=c[f+232>>2]|0;h=c[f+232>>2]|0;j=c[f+236>>2]|0;while(1){if((j|0)>=(c[f+232>>2]|0)){break}a=j;if(+O2b(j)>=g){k=4;break}j=j+1|0}j=c[f+236>>2]|0;while(1){if((j|0)>=(c[f+232>>2]|0)){k=13;break}h=j;if(+O2b(j)>=b){break}j=j+1|0}if((k|0)==13){l=h;m=a;n=l-m|0;i=e;return n|0}l=h;m=a;n=l-m|0;i=e;return n|0}function s3b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=+e;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=a;a=b;b=d;d=c[g+232>>2]|0;h=~~(e*+(Q2b(a,b,1.0)|0));j=c[g+236>>2]|0;while(1){if((j|0)>=(c[g+232>>2]|0)){k=7;break}d=j;if((Q2b(a,j,1.0)|0)<=(h|0)){break}j=j+1|0}if((k|0)==7){l=d;m=b;n=l-m|0;i=f;return n|0}l=d;m=b;n=l-m|0;i=f;return n|0}function t3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a;a=d+1434592|0;e=d+1471600|0;f=d+2017128|0;g=e+24|0;c[f+112>>2]=~~((+((c[g>>2]|0)>>>0)+ +(c[g+4>>2]|0)*4294967296.0)/+h[e+16>>3]);c[f+116>>2]=(ca(c[f+112>>2]|0,c[e+152>>2]|0)|0)/100|0;if((c[f+116>>2]|0)>200){j=c[f+116>>2]|0}else{j=200}c[f+116>>2]=j;j=c[f+112>>2]|0;g=c[e+156>>2]|0;k=Erc(j,(j|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;g=Crc(k,G,100,0)|0;k=g;if(((c[a+10140>>2]|0)*250|0|0)>2025e3){l=(c[a+10140>>2]|0)*250|0}else{l=2025e3}if((l|0)>(k|0)){if(((c[a+10140>>2]|0)*250|0|0)>2025e3){m=(c[a+10140>>2]|0)*250|0}else{m=2025e3}n=m}else{n=k}c[f+120>>2]=n;c[f+72>>2]=16;c[f+76>>2]=c[d+1472104>>2]>>1;do{if((c[e+228>>2]|0)!=0){if((c[e+60>>2]|0)==0){break}if((c[f+72>>2]|0)>((c[e+60>>2]|0)-1|0)){c[f+72>>2]=(c[e+60>>2]|0)-1}if((c[f+76>>2]|0)>((c[e+60>>2]|0)-1|0)){c[f+76>>2]=(c[e+60>>2]|0)-1}}}while(0);if((c[f+72>>2]|0)<=(c[f+76>>2]|0)){i=b;return}c[f+72>>2]=c[f+76>>2];i=b;return}function u3b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=a;a=b;b=0;b=(c[e+4>>2]|0)+1|0;while(1){if((b|0)>=(c[e+12>>2]|0)){break}f=e+16+(b*960|0)|0;g=f|0;j=~~(+(c[f+240>>2]|0)/+h[f+272>>3]- +(a|0));k=g+176|0;l=wrc(c[k>>2]|0,c[k+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[k>>2]=l;c[k+4>>2]=G;k=g+176|0;l=c[k+4>>2]|0;j=f+264|0;m=c[j+4>>2]|0;if((l|0)<(m|0)|(l|0)==(m|0)&(c[k>>2]|0)>>>0<(c[j>>2]|0)>>>0){j=g+176|0;n=c[j+4>>2]|0;o=c[j>>2]|0}else{j=f+264|0;n=c[j+4>>2]|0;o=c[j>>2]|0}j=g+176|0;c[j>>2]=o;c[j+4>>2]=n;j=g+176|0;f=c[j+4>>2]|0;k=g+168|0;c[k>>2]=c[j>>2];c[k+4>>2]=f;b=b+1|0}i=d;return}function v3b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;j=a;a=b;b=d;d=e;e=f;f=g;if((a|0)>(d|0)){k=c[e+(j<<2)>>2]|0;l=k;i=h;return l|0}if((a|0)<(b|0)){k=c[f+(j<<2)>>2]|0;l=k;i=h;return l|0}else{g=d-b|0;b=((ca(d-a|0,(c[f+(j<<2)>>2]|0)-(c[e+(j<<2)>>2]|0)|0)|0)+(g>>1)|0)/(g|0)|0;k=(c[e+(j<<2)>>2]|0)+b|0;l=k;i=h;return l|0}return 0}function w3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=a;a=d+2017128|0;e=c[d+1471540>>2]|0;if((c[d+1444700>>2]|0)==0){if((e|0)==0){f=c[a+232>>2]|0}else{f=c[a+12>>2]<<1}g=f}else{do{if((c[a+108>>2]|0)!=0){h=13}else{if((c[d+1472148>>2]|0)==0){if((c[d+1472152>>2]|0)==0){h=13;break}}if((e|0)==1){j=((c[a+12>>2]|0)*5|0|0)/4|0}else{j=c[a+16>>2]|0}g=j}}while(0);if((h|0)==13){if((e|0)==1){k=c[a+12>>2]<<1}else{k=c[a+16>>2]<<1}g=k}}if((g|0)<(c[a+232>>2]|0)){l=g;i=b;return l|0}else{l=c[a+232>>2]|0;i=b;return l|0}return 0}function x3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a;a=f+1434592|0;g=f+1471600|0;h=f+2017128|0;f=g+88|0;j=c[f+4>>2]|0;c[d>>2]=(c[f>>2]|0)>>>2|j<<30;c[d+4>>2]=j>>2|((j|0)<0|0?-1:0)<<30;c[e>>2]=0;c[e+4>>2]=0;j=0;if((c[a+10108>>2]|0)==0){k=c[h+232>>2]|0;l=k;i=b;return l|0}if((c[a+36948>>2]|0)>>>0>1>>>0){if((c[h+232>>2]|0)<(((c[h+140>>2]|0)*5|0|0)/4|0|0)){m=c[h+232>>2]|0}else{m=((c[h+140>>2]|0)*5|0|0)/4|0}n=m}else{if((c[h+232>>2]|0)<(((c[h+136>>2]|0)*3|0|0)/2|0|0)){o=c[h+232>>2]|0}else{o=((c[h+136>>2]|0)*3|0|0)/2|0}n=o}o=h+168|0;m=c[o+4>>2]|0;a=g+88|0;f=c[a+4>>2]|0;if((m|0)>(f|0)|(m|0)==(f|0)&(c[o>>2]|0)>>>0>(c[a>>2]|0)>>>0){a=(n|0)/3|0;if((a|0)!=0){o=g+96|0;f=g+88|0;m=xrc(c[o>>2]|0,c[o+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=a;a=Crc(m,G,f,(f|0)<0|0?-1:0)|0;c[e>>2]=a;c[e+4>>2]=G;if((c[e>>2]|0)!=0|(c[e+4>>2]|0)!=0){a=h+168|0;f=g+88|0;m=xrc(c[a>>2]|0,c[a+4>>2]|0,c[f>>2]|0,c[f+4>>2]|0)|0;f=Crc(m,G,c[e>>2]|0,c[e+4>>2]|0)|0;j=f}n=n-j|0}}else{f=h+168|0;m=c[f+4>>2]|0;a=c[d+4>>2]|0;if((m|0)>(a|0)|(m|0)==(a|0)&(c[f>>2]|0)>>>0>(c[d>>2]|0)>>>0){if((c[d>>2]|0)!=0|(c[d+4>>2]|0)!=0){f=g+88|0;a=xrc(c[f>>2]|0,c[f+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0;c[e>>2]=a;c[e+4>>2]=G;if((c[e>>2]|0)!=0|(c[e+4>>2]|0)!=0){a=(c[h+232>>2]|0)-(c[h+140>>2]|0)|0;d=g+88|0;g=h+168|0;f=xrc(c[d>>2]|0,c[d+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;g=Erc(a,(a|0)<0|0?-1:0,f,G)|0;f=Crc(g,G,c[e>>2]|0,c[e+4>>2]|0)|0;j=f}n=(c[h+140>>2]|0)+j|0}}else{n=c[h+232>>2]|0}}k=n;l=k;i=b;return l|0}function y3b(){var a=0,b=0,d=0.0;a=i;b=0;while(1){if((b|0)>=256){break}d=+O2b(b);c[5125008+(b<<2)>>2]=~~(.0418*d+2.4107);c[5123984+(b<<2)>>2]=~~(.063*d+2.742);b=b+1|0}i=a;return}function z3b(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=i;f=a;a=(ngc(b,0)|0)<<16>>16;b=(ca(a*88|0,a)|0)/25|0;if((c[f+2046868>>2]|0)!=2){g=b;i=e;return g|0}if((c[f+1444700>>2]|0)==0){g=b;i=e;return g|0}if((c[f+2047860>>2]|0)>>>0>31>>>0){b=b+((ca(b,d[682263]|0)|0)>>4)|0}else{b=b+((ca(b,d[682232+(c[f+2047860>>2]|0)|0]|0)|0)>>4)|0}g=b;i=e;return g|0}function A3b(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[d+108004>>2]=c[5125008+(a<<2)>>2];c[d+108008>>2]=c[5123984+(a<<2)>>2];i=i;return}function B3b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=a;a=d+1434592|0;e=d+32768|0;c[d+1490740>>2]=7;c[d+1490736>>2]=z3b(d,(c[a+10168>>2]|0)+(c[a+10172>>2]|0)|0)|0;c[e+75232>>2]=(c[d+1490736>>2]|0)/64|0;f=e+75232|0;c[f>>2]=(c[f>>2]|0)+((c[e+75232>>2]|0)==0);if((c[d+2046944>>2]|0)==3){g=(c[a+10108>>2]|0)!=0}else{g=0}c[e+75204>>2]=g?0:1;C3b(d);if((c[d+2047084>>2]|0)!=0){if((c[a+10108>>2]|0)==0){h=5}}else{h=5}if((h|0)==5){D3b(e+1129288|0,a+13714|0);j=0;while(1){if((j|0)>=16){break}h=a;g=j;if((c[h+10108>>2]|0)==0){k=215328+(g*3|0)|0}else{k=h+13666+(g*3|0)|0}Xkc(e+1401216+(j<<4)|0,k,207984);j=j+1|0}}do{if((c[d+2047084>>2]|0)!=0){if((c[a+36948>>2]&7|0)==1){break}if((c[a+10108>>2]|0)==0){break}i=b;return}}while(0);E3b(d);d=a;if((c[d+10108>>2]|0)==0){l=1}else{l=(c[d+10124>>2]|0)!=0}if((l&1|0)==0){if((c[a+10128>>2]|0)!=0){m=e+599632|0}else{m=e+337488|0}Rmc(e+75336|0,m,a+15510|0,c[a+10128>>2]|0);j=0;while(1){if((j|0)>=7){break}Xkc(e+1123992+(j<<4)|0,a+15450+(j*3|0)|0,215488);j=j+1|0}}i=b;return}function C3b(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;e=a;a=e+1434592|0;f=e+1473304|0;e=0;while(1){if((e|0)>=8){break}g=pgc(a+13408|0,e,c[a+10168>>2]|0)|0;h=g+(c[a+10172>>2]|0)|0;g=0;j=255;if((h|0)<(g|0)){k=g}else{if((h|0)>(j|0)){l=j}else{l=h}k=l}h=x4b(k)|0;j=0;while(1){if((j|0)>=13){break}g=ca(h,d[682216+j|0]|0)|0;m=2147483647/(g|0)|0;n=0;while(1){if((n|0)>=30){break}if((c[f+(n<<2)>>2]|0)<(m|0)){o=(ca(c[f+(n<<2)>>2]|0,g)|0)/4|0}else{o=2147483647}c[f+144+(e*1560|0)+(j*120|0)+(n<<2)>>2]=o;n=n+1|0}n=0;while(1){if((n|0)>=6){break}if((c[f+120+(n<<2)>>2]|0)<(m|0)){p=(ca(c[f+120+(n<<2)>>2]|0,g)|0)/4|0}else{p=2147483647}c[f+14184+(e*312|0)+(j*24|0)+(n<<2)>>2]=p;n=n+1|0}j=j+1|0}e=e+1|0}i=b;return}function D3b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;e=d|0;f=a;a=b;b=0;while(1){if(!(b>>>0<=3>>>0)){break}g=0;while(1){if((g|0)>=2){break}h=0;while(1){if((h|0)>=2){break}j=0;while(1){if((j|0)>=6){break}k=0;while(1){if((k|0)>=(((j|0)==0?3:6)|0)){break}wec(a+(b*432|0)+(g*216|0)+(h*108|0)+(j*18|0)+(k*3|0)|0,e|0);Xkc(f+(b*13824|0)+(g*6912|0)+(h*3456|0)+(j*576|0)+(k*48|0)|0,e|0,233600);Zkc(f+(b*13824|0)+(g*6912|0)+(h*3456|0)+(j*576|0)+288+(k*48|0)|0,e|0,233600);if((c[f+(b*13824|0)+(g*6912|0)+(h*3456|0)+(j*576|0)+(k*48|0)+44>>2]|0)==(c[f+(b*13824|0)+(g*6912|0)+(h*3456|0)+(j*576|0)+288+(k*48|0)+44>>2]|0)){}else{Cd(2416832,2558456,192,2652688)}k=k+1|0}j=j+1|0}h=h+1|0}g=g+1|0}b=b+1|0}i=d;return}function E3b(a){a=a|0;var b=0,c=0,d=0,e=0;b=i;c=a;a=c+32768|0;d=c+1448132|0;c=0;while(1){if((c|0)>=10){break}e=0;while(1){if((e|0)>=10){break}Xkc(a+1124184+(c*400|0)+(e*40|0)|0,214328+(c*90|0)+(e*9|0)|0,215456);e=e+1|0}c=c+1|0}Xkc(a+1123952|0,d+9|0,215456);Xkc(a+1124104|0,215313,215456);Xkc(a+1124144|0,d+117|0,215456);c=0;while(1){if((c|0)>=4){break}Xkc(a+1128184+(c*12|0)|0,d+1902+(c<<1)|0,202680);c=c+1|0}i=b;return}function F3b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=a;a=b;b=d;d=e;e=f;if((l|0)==0){c[d>>2]=0;f=e;c[f>>2]=0;c[f+4>>2]=0;i=g;return}f=Erc(b,0,b,0)|0;b=Erc(f,G,a,0)|0;f=wrc(b<<10|0>>>22,G<<10|b>>>22,l>>>1,0)|0;b=Frc(f,G,l,0)|0;c[k>>2]=b;c[k+4>>2]=G;b=c[k+4>>2]|0;f=0;if(b>>>0>f>>>0|b>>>0==f>>>0&(c[k>>2]|0)>>>0>245727>>>0){m=245727}else{m=c[k>>2]|0}G3b(m,j,h);c[d>>2]=((ca(a,c[j>>2]|0)|0)+2|0)>>>2;j=c[h>>2]|0;h=Erc(l,0,j,(j|0)<0|0?-1:0)|0;j=wrc(h,G,512,0)|0;h=G;l=e;c[l>>2]=j>>>10|h<<22;c[l+4>>2]=h>>10|((h|0)<0|0?-1:0)<<22;i=g;return}function G3b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=(f>>2)+8|0;g=(31^(rrc(a|0)|0))-3|0;h=(g<<3)+(a>>g&7)|0;a=f-(c[827672+(h<<2)>>2]|0)<<10>>g+2;g=1024-a|0;f=ca(c[828088+(h<<2)>>2]|0,g)|0;c[b>>2]=f+(ca(c[828088+(h+1<<2)>>2]|0,a)|0)>>10;f=ca(c[828504+(h<<2)>>2]|0,g)|0;c[d>>2]=f+(ca(c[828504+(h+1<<2)>>2]|0,a)|0)>>10;i=e;return}function H3b(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=a;a=d;d=e;e=f;c[h>>2]=0;c[h+4>>2]=0;c[j>>2]=0;c[j+4>>2]=0;f=0;while(1){if((f|0)>=(d|0)){break}l=(b[k+(f<<1)>>1]|0)-(b[a+(f<<1)>>1]|0)|0;m=ca(l,l)|0;l=wrc(c[h>>2]|0,c[h+4>>2]|0,m,(m|0)<0|0?-1:0)|0;c[h>>2]=l;c[h+4>>2]=G;l=ca(b[k+(f<<1)>>1]|0,b[k+(f<<1)>>1]|0)|0;m=wrc(c[j>>2]|0,c[j+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[j>>2]=m;c[j+4>>2]=G;f=f+1|0}f=c[j+4>>2]|0;k=e;c[k>>2]=c[j>>2];c[k+4>>2]=f;i=g;return(G=c[h+4>>2]|0,c[h>>2]|0)|0}function I3b(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0;j=i;k=f;f=g;g=h;h=k;l=c[558424+(d<<4)+(c[h+8>>2]<<3)+(c[h+12>>2]<<2)>>2]|0;if(!(l>>>0<13>>>0)){Cd(2437376,2427112,292,2652440)}h=l;l=c[777792+(h<<2)>>2]|0;d=c[777848+(h<<2)>>2]|0;h=c[k+44>>2]|0;m=c[k+48>>2]|0;k=e;if((k|0)==2){n=0;while(1){if((n|0)>=(l|0)){break}a[f+n|0]=((c[h+n>>2]|0)!=0^1^1)&1;n=n+4|0}n=0;while(1){if((n|0)>=(d|0)){break}a[g+n|0]=((c[m+n>>2]|0)!=0^1^1)&1;n=n+4|0}i=j;return}else if((k|0)==3){n=0;while(1){if((n|0)>=(l|0)){break}e=h+n|0;a[f+n|0]=(((c[e>>2]|0)!=0|(c[e+4>>2]|0)!=0)^1^1)&1;n=n+8|0}n=0;while(1){if((n|0)>=(d|0)){break}e=m+n|0;a[g+n|0]=(((c[e>>2]|0)!=0|(c[e+4>>2]|0)!=0)^1^1)&1;n=n+8|0}i=j;return}else if((k|0)==1){n=0;while(1){if((n|0)>=(l|0)){break}a[f+n|0]=((b[h+n>>1]|0)!=0^1^1)&1;n=n+2|0}n=0;while(1){if((n|0)>=(d|0)){break}a[g+n|0]=((b[m+n>>1]|0)!=0^1^1)&1;n=n+2|0}i=j;return}else if((k|0)==0){nrc(f|0,h|0,l)|0;nrc(g|0,m|0,d)|0;i=j;return}else{Cd(2331816,2558456,736,2650496)}}function J3b(a,b,d,e,f,g,h,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;m=i;n=a;a=b;b=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=n+1434592|0;o=n;p=o+1434592|0;q=o;o=d;do{if((o|0)==1){r=c[q+1472132>>2]|0}else{if((o|0)==2){r=c[q+1472136>>2]|0;break}else{r=c[q+1472140>>2]|0;break}}}while(0);q=p+8488+((c[p+9784+(r<<2)>>2]|0)*108|0)+16|0;r=a+24720|0;p=c[c[r+160>>2]>>2]|0;o=p+36+(d<<3)|0;s=l+9816+(d-1<<6)+8|0;K3b(r,k+(d*24|0)|0,q,f,g,s,s);Yfc(l,r,b,p,d,o,f,g);_fc(r,c[l+10128>>2]|0,o,h+(d<<2)|0,j+(d<<2)|0);j=s;if((c[j>>2]|0)!=16384){t=1}else{t=(c[j+4>>2]|0)!=16384}if((t&1|0)!=0){i=m;return}if(!(e>>>0>=3>>>0)){i=m;return}L3b(n,a,c[k+(d*24|0)>>2]|0,c[q+16>>2]|0,d,e);i=m;return}function K3b(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;k=a;a=b;b=d;d=e;e=f;f=g;g=h;c[a>>2]=c[b+52>>2];c[a+4>>2]=c[b+16>>2];c[a+8>>2]=c[b+56>>2];c[a+16>>2]=c[b+60>>2];h=c[b+36>>2]|0;c[a+20>>2]=h;c[a+12>>2]=h;h=0;while(1){if((h|0)>=3){break}if((h|0)!=0){l=g}else{l=f}b=a+(h<<3)|0;m=c[a+(h<<3)+4>>2]|0;n=c[a+(h<<3)>>2]|0;o=e<<3>>c[k+(h*52|0)+8>>2];p=d<<3>>c[k+(h*52|0)+12>>2];q=l;if((q|0)!=0){r=We[c[q+16>>2]&2047](o,q)|0}else{r=o}if((q|0)!=0){s=We[c[q+20>>2]&2047](p,q)|0}else{s=p}c[b>>2]=n+((ca(s,m)|0)+r);c[b+4>>2]=m;h=h+1|0}i=j;return}function L3b(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=a;a=d;d=e;e=f;f=g;g=h;h=c[c[a+24880>>2]>>2]|0;n=0;o=0;p=2147483647;q=2147483647;r=0;s=c[a+8204>>2]|0;do{if((c[m+2047004>>2]|0)!=0){if((c[m+1444704>>2]|0)==0){t=0;break}t=g>>>0<(c[m+2046984>>2]|0)>>>0}else{t=0}}while(0);u=(t&1)+2|0;c[l>>2]=c[h+36+(f<<3)>>2];c[l+4>>2]=c[h+36+(f<<3)+4>>2];c[l+8>>2]=c[a+1184596+(f<<2)>>2];h=0;while(1){if((h|0)>=(u|0)){break}c[k>>2]=c[l+(h<<2)>>2];t=R(b[k>>1]|0)|0;if((t|0)>(R(b[k+2>>1]|0)|0)){v=R(b[k>>1]|0)|0}else{v=R(b[k+2>>1]|0)|0}if((r|0)>(v>>3|0)){w=r}else{t=R(b[k>>1]|0)|0;if((t|0)>(R(b[k+2>>1]|0)|0)){x=R(b[k>>1]|0)|0}else{x=R(b[k+2>>1]|0)|0}w=x>>3}r=w;do{if((c[k>>2]|0)!=0){y=18}else{if((n|0)==0){y=18;break}}}while(0);if((y|0)==18){y=0;if((n|0)!=0){z=1}else{z=(c[k>>2]|0)!=0^1}n=z&1;t=d+(ca(e,b[k>>1]>>3)|0)+(b[k+2>>1]>>3)|0;q=Xe[c[m+2047252+(g*44|0)>>2]&511](s,c[a+8208>>2]|0,t,e,2147483647)|0;if((q|0)<(p|0)){p=q;o=h}}h=h+1|0}c[a+75268+(f<<2)>>2]=o;c[a+75284+(f<<2)>>2]=r;c[a+75320+(f<<2)>>2]=p;i=j;return}function M3b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a;a=b;b=e+1434592|0;f=e;g=a;do{if((g|0)==1){h=c[f+1472132>>2]|0}else{if((g|0)==2){h=c[f+1472136>>2]|0;break}else{h=c[f+1472140>>2]|0;break}}}while(0);f=c[e+1472120+(a-1<<2)>>2]|0;if((f|0)!=(c[b+9784+(h<<2)>>2]|0)){j=b+8488+(f*108|0)+16|0;i=d;return j|0}else{j=0;i=d;return j|0}return 0}function N3b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;a=d+24720|0;e=c[c[a+160>>2]>>2]|0;f=cgc(a)|0;i=b;return c[d+1128184+(f*12|0)+(c[e+72>>2]<<2)>>2]|0}function O3b(a,b,e,f,g,h,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=i;i=i+112|0;m=l|0;n=l+8|0;o=l+16|0;p=l+24|0;q=l+32|0;r=l+40|0;s=l+48|0;t=l+56|0;u=l+64|0;v=l+72|0;w=a;a=b;b=e;e=f;f=g;g=h;c[m>>2]=j;c[m+4>>2]=k;k=w+1434592|0;j=a+24720|0;c[n>>2]=0;c[o>>2]=0;c[p>>2]=0;c[q>>2]=0;c[r>>2]=0;c[s>>2]=0;c[t>>2]=0;c[t+4>>2]=0;c[u>>2]=0;c[u+4>>2]=0;mrc(v|0,0,40)|0;c[a+1184592>>2]=0;c[g+424>>2]=0;c[(c[c[j+160>>2]>>2]|0)+20>>2]=0;if(f>>>0>=3>>>0){h=P3b(w,a,n,p,t,r,f,v|0,c[m>>2]|0,c[m+4>>2]|0)|0;x=G;y=c[m+4>>2]|0;if((x|0)>=(y|0)&((x|0)>(y|0)|h>>>0>=(c[m>>2]|0)>>>0)){c[b>>2]=2147483647;i=l;return}h=c[(c[c[j+160>>2]>>2]|0)+8>>2]|0;y=f;if(y>>>0<3>>>0){z=0}else{x=c[558436+(y<<4)>>2]|0;if(h>>>0<(c[833024+(x<<2)>>2]|0)>>>0){A=h}else{A=c[833024+(x<<2)>>2]|0}z=A}B=z;Q3b(w,a,g,o,q,u,s,f,B)|0;}else{c[r>>2]=0;z=R3b(w,a,n,p,t,c[m>>2]|0,c[m+4>>2]|0)|0;A=G;x=c[m+4>>2]|0;if((A|0)>=(x|0)&((A|0)>(x|0)|z>>>0>=(c[m>>2]|0)>>>0)){c[b>>2]=2147483647;i=l;return}m=c[(c[c[j+160>>2]>>2]|0)+8>>2]|0;z=f;if(z>>>0<3>>>0){C=0}else{f=c[558436+(z<<4)>>2]|0;if(m>>>0<(c[833024+(f<<2)>>2]|0)>>>0){D=m}else{D=c[833024+(f<<2)>>2]|0}C=D}B=C;Q3b(w,a,g,o,q,u,s,3,B)|0;}do{if((c[r>>2]|0)!=0){if((c[s>>2]|0)==0){E=35;break}B=j;a=B;if((c[a+164>>2]|0)!=0){F=c[(c[a+160>>2]|0)+(-(c[a+156>>2]|0)<<2)>>2]|0}else{F=0}a=F;C=B;if((c[C+168>>2]|0)!=0){H=c[(c[C+160>>2]|0)-4>>2]|0}else{H=0}C=H;if((a|0)!=0){I=d[a+12|0]|0}else{I=0}if((C|0)!=0){J=d[C+12|0]|0}else{J=0}c[b>>2]=(c[n>>2]|0)+(c[o>>2]|0)-(c[p>>2]|0)-(c[q>>2]|0)+(c[206872+(255-(d[k+15507+(I+J)|0]|0)<<2)>>2]|0);C=wrc(c[t>>2]|0,c[t+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;a=e;c[a>>2]=C;c[a+4>>2]=G;mrc(g+504|0,0,40)|0}else{E=35}}while(0);if((E|0)==35){J=j;I=J;if((c[I+164>>2]|0)!=0){K=c[(c[I+160>>2]|0)+(-(c[I+156>>2]|0)<<2)>>2]|0}else{K=0}I=K;K=J;if((c[K+168>>2]|0)!=0){L=c[(c[K+160>>2]|0)-4>>2]|0}else{L=0}K=L;if((I|0)!=0){M=d[I+12|0]|0}else{M=0}if((K|0)!=0){N=d[K+12|0]|0}else{N=0}c[b>>2]=(c[n>>2]|0)+(c[o>>2]|0)+(c[206872+((d[k+15507+(M+N)|0]|0)<<2)>>2]|0);N=wrc(c[t>>2]|0,c[t+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;u=e;c[u>>2]=N;c[u+4>>2]=G;if((c[w+2046944>>2]|0)==0){w=0;while(1){if((w|0)>=5){break}u=v+(w<<3)|0;N=c[u+4>>2]|0;e=2147483647;do{if((N|0)<(e|0)|(N|0)==(e|0)&(c[u>>2]|0)>>>0<-1>>>0){t=v+(c[k+10164>>2]<<3)|0;M=c[t+4>>2]|0;o=2147483647;if(!((M|0)<(o|0)|(M|0)==(o|0)&(c[t>>2]|0)>>>0<-1>>>0)){E=53;break}t=v+(w<<3)|0;o=v+(c[k+10164>>2]<<3)|0;M=xrc(c[t>>2]|0,c[t+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;o=g+504+(w<<3)|0;c[o>>2]=M;c[o+4>>2]=G}else{E=53}}while(0);if((E|0)==53){E=0;u=g+504+(w<<3)|0;c[u>>2]=0;c[u+4>>2]=0}w=w+1|0}}}nrc(g|0,c[c[j+160>>2]>>2]|0,124)|0;i=l;return}function P3b(a,b,d,e,f,g,h,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;m=i;i=i+88|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;r=m+32|0;s=m+40|0;t=m+80|0;u=a;a=b;b=d;d=e;e=f;f=g;g=h;h=j;c[n>>2]=k;c[n+4>>2]=l;l=0;k=a+24720|0;j=c[c[k+160>>2]>>2]|0;v=0;w=a+1123952|0;if((c[u+2046944>>2]|0)==0){x=0;while(1){if((x|0)>=5){break}y=h+(x<<3)|0;c[y>>2]=-1;c[y+4>>2]=2147483647;x=x+1|0}}y=0;while(1){if(!(y>>>0<=9>>>0)){break}z=c[(c[k+160>>2]|0)+(-(c[k+156>>2]|0)<<2)>>2]|0;if((c[k+168>>2]|0)!=0){A=c[(c[k+160>>2]|0)-4>>2]|0}else{A=0}B=A;do{if((c[u+2047036+(c[833024+(g<<2)>>2]<<2)>>2]&1<<y|0)!=0){if((c[u+1444700>>2]|0)==0){C=cec(j,z,0)|0;w=a+1124184+(C*400|0)+((bec(j,B,0)|0)*40|0)|0}c[j+4>>2]=y;W3b(u,a,o,q,p,0,g,s|0,c[n>>2]|0,c[n+4>>2]|0);if((c[o>>2]|0)==2147483647){break}C=(c[o>>2]|0)+(c[w+(y<<2)>>2]|0)|0;D=C;E=c[a+75248>>2]|0;F=Erc(D,(D|0)<0|0?-1:0,E,(E|0)<0|0?-1:0)|0;E=wrc(128,0,F,G)|0;F=G;D=yrc(c[q>>2]|0,c[q+4>>2]|0,c[a+75244>>2]|0)|0;H=wrc(E>>>8|F<<24,F>>8|((F|0)<0|0?-1:0)<<24,D,G)|0;c[r>>2]=H;c[r+4>>2]=G;H=c[r+4>>2]|0;D=c[n+4>>2]|0;if((H|0)<(D|0)|(H|0)==(D|0)&(c[r>>2]|0)>>>0<(c[n>>2]|0)>>>0){l=y;D=c[r+4>>2]|0;c[n>>2]=c[r>>2];c[n+4>>2]=D;v=c[j+8>>2]|0;c[b>>2]=C;c[d>>2]=c[o>>2];C=c[q+4>>2]|0;D=e;c[D>>2]=c[q>>2];c[D+4>>2]=C;c[f>>2]=c[p>>2]}do{if((c[u+2046944>>2]|0)==0){C=c[r+4>>2]|0;D=2147483647;if(!((C|0)<(D|0)|(C|0)==(D|0)&(c[r>>2]|0)>>>0<-1>>>0)){break}x=0;while(1){if((x|0)<5){D=s+(x<<3)|0;C=c[D+4>>2]|0;H=2147483647;I=(C|0)<(H|0)|(C|0)==(H|0)&(c[D>>2]|0)>>>0<-1>>>0}else{I=0}if(!I){break}D=s+(x<<3)|0;H=wrc(c[r>>2]|0,c[r+4>>2]|0,c[D>>2]|0,c[D+4>>2]|0)|0;D=s+(c[u+1444756>>2]<<3)|0;C=xrc(H,G,c[D>>2]|0,c[D+4>>2]|0)|0;c[t>>2]=C;c[t+4>>2]=G;C=c[t+4>>2]|0;D=h+(x<<3)|0;H=c[D+4>>2]|0;if((C|0)<(H|0)|(C|0)==(H|0)&(c[t>>2]|0)>>>0<(c[D>>2]|0)>>>0){D=c[t+4>>2]|0;H=h+(x<<3)|0;c[H>>2]=c[t>>2];c[H+4>>2]=D}x=x+1|0}}}while(0)}}while(0);y=y+1|0}c[j+4>>2]=l;c[j+8>>2]=v;i=m;return(G=c[n+4>>2]|0,c[n>>2]|0)|0}function Q3b(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;l=i;i=i+48|0;m=l|0;n=l+8|0;o=l+16|0;p=l+24|0;q=l+32|0;r=l+40|0;s=a;a=b;b=d;d=e;e=f;f=g;g=h;h=j;j=k;k=a+24720|0;t=0;c[m>>2]=-1;c[m+4>>2]=2147483647;u=0;while(1){if(!(u>>>0<=9>>>0)){break}do{if((c[s+2047052+(j<<2)>>2]&1<<u|0)!=0){c[(c[c[k+160>>2]>>2]|0)+16>>2]=u;b4b(s,a,o,q,p,r,h,c[m>>2]|0,c[m+4>>2]|0);if((c[o>>2]|0)==2147483647){break}v=(c[o>>2]|0)+(c[a+1124104+((c[s+1444700>>2]|0)*40|0)+(u<<2)>>2]|0)|0;w=v;x=c[a+75248>>2]|0;y=Erc(w,(w|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=wrc(128,0,y,G)|0;y=G;w=yrc(c[q>>2]|0,c[q+4>>2]|0,c[a+75244>>2]|0)|0;z=wrc(x>>>8|y<<24,y>>8|((y|0)<0|0?-1:0)<<24,w,G)|0;c[n>>2]=z;c[n+4>>2]=G;z=c[n+4>>2]|0;w=c[m+4>>2]|0;if((z|0)<(w|0)|(z|0)==(w|0)&(c[n>>2]|0)>>>0<(c[m>>2]|0)>>>0){t=u;w=c[n+4>>2]|0;c[m>>2]=c[n>>2];c[m+4>>2]=w;c[d>>2]=v;c[e>>2]=c[o>>2];v=c[q+4>>2]|0;w=f;c[w>>2]=c[q>>2];c[w+4>>2]=v;c[g>>2]=c[p>>2];if((c[a+75204>>2]|0)==0){v=a|0;w=k|0;z=1;while(1){if((z|0)>=3){break}c[v+(z*8240|0)+8196>>2]=c[b+272+(z*12|0)+8>>2];c[v+(z*8240|0)+8192>>2]=c[b+308+(z*12|0)+8>>2];c[w+(z*52|0)>>2]=c[b+344+(z*12|0)+8>>2];c[v+(z*8240|0)+8200>>2]=c[b+380+(z*12|0)+8>>2];c[b+272+(z*12|0)+8>>2]=c[b+272+(z*12|0)>>2];c[b+308+(z*12|0)+8>>2]=c[b+308+(z*12|0)>>2];c[b+344+(z*12|0)+8>>2]=c[b+344+(z*12|0)>>2];c[b+380+(z*12|0)+8>>2]=c[b+380+(z*12|0)>>2];c[b+272+(z*12|0)>>2]=c[v+(z*8240|0)+8196>>2];c[b+308+(z*12|0)>>2]=c[v+(z*8240|0)+8192>>2];c[b+344+(z*12|0)>>2]=c[w+(z*52|0)>>2];c[b+380+(z*12|0)>>2]=c[v+(z*8240|0)+8200>>2];z=z+1|0}}}}}while(0);u=u+1|0}c[(c[c[k+160>>2]>>2]|0)+16>>2]=t;i=l;return(G=c[m+4>>2]|0,c[m>>2]|0)|0}function R3b(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=i;i=i+88|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+40|0;r=k+48|0;s=k+56|0;t=k+64|0;u=k+72|0;v=k+80|0;w=b;b=d;d=e;e=f;f=g;c[m>>2]=h;c[m+4>>2]=j;j=b+24720|0;h=c[c[j+160>>2]>>2]|0;g=c[(c[j+160>>2]|0)+(-(c[j+156>>2]|0)<<2)>>2]|0;if((c[j+168>>2]|0)!=0){x=c[(c[j+160>>2]|0)-4>>2]|0}else{x=0}y=x;x=c[c[c[j+160>>2]>>2]>>2]|0;z=c[777792+(x<<2)>>2]|0;A=c[777848+(x<<2)>>2]|0;B=0;c[n>>2]=0;c[n+4>>2]=0;C=0;c[o>>2]=0;c[o+4>>2]=0;D=b+1123952|0;E=p;F=c[j+44>>2]|0;a[E]=a[F]|0;a[E+1|0]=a[F+1|0]|0;a[E+2|0]=a[F+2|0]|0;a[E+3|0]=a[F+3|0]|0;F=q;E=c[j+48>>2]|0;a[F]=a[E]|0;a[F+1|0]=a[E+1|0]|0;a[F+2|0]=a[E+2|0]|0;a[F+3|0]=a[E+3|0]|0;E=0;a:while(1){if((E|0)>=2){H=26;break}F=0;while(1){if((F|0)>=2){break}c[r>>2]=0;c[s>>2]=2147483647;c[t>>2]=2147483647;c[u>>2]=-1;c[u+4>>2]=2147483647;c[v>>2]=-1;c[v+4>>2]=2147483647;j=(E<<1)+F|0;if((c[w+1444700>>2]|0)==0){I=cec(h,g,j)|0;D=b+1124184+(I*400|0)+((bec(h,y,j)|0)*40|0)|0}I=xrc(c[m>>2]|0,c[m+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;J=w4b(w,b,j,r,D,p+F|0,q+E|0,s,t,u,x,I,G)|0;c[v>>2]=J;c[v+4>>2]=G;J=c[v>>2]|0;I=c[v+4>>2]|0;K=xrc(c[m>>2]|0,c[m+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;L=G;if((I|0)>=(L|0)&((I|0)>(L|0)|J>>>0>=K>>>0)){H=11;break a}K=wrc(c[o>>2]|0,c[o+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;c[o>>2]=K;c[o+4>>2]=G;B=B+(c[s>>2]|0)|0;K=wrc(c[n>>2]|0,c[n+4>>2]|0,c[u>>2]|0,c[u+4>>2]|0)|0;c[n>>2]=K;c[n+4>>2]=G;C=C+(c[t>>2]|0)|0;c[h+76+(j*12|0)>>2]=c[r>>2];K=1;while(1){if((K|0)>=(A|0)){break}c[h+76+((j+(K<<1)|0)*12|0)>>2]=c[r>>2];K=K+1|0}K=1;while(1){if((K|0)>=(z|0)){break}c[h+76+((j+K|0)*12|0)>>2]=c[r>>2];K=K+1|0}K=c[o+4>>2]|0;j=c[m+4>>2]|0;if((K|0)>=(j|0)&((K|0)>(j|0)|(c[o>>2]|0)>>>0>=(c[m>>2]|0)>>>0)){H=21;break a}F=F+z|0}E=E+A|0}if((H|0)==11){c[l>>2]=-1;c[l+4>>2]=2147483647;M=l|0;N=c[M>>2]|0;O=l+4|0;P=c[O>>2]|0;i=k;return(G=P,N)|0}else if((H|0)==21){c[l>>2]=-1;c[l+4>>2]=2147483647;M=l|0;N=c[M>>2]|0;O=l+4|0;P=c[O>>2]|0;i=k;return(G=P,N)|0}else if((H|0)==26){c[d>>2]=B;c[e>>2]=C;C=c[n+4>>2]|0;e=f;c[e>>2]=c[n>>2];c[e+4>>2]=C;c[h+4>>2]=c[h+112>>2];h=B;B=c[b+75248>>2]|0;C=Erc(h,(h|0)<0|0?-1:0,B,(B|0)<0|0?-1:0)|0;B=wrc(128,0,C,G)|0;C=G;h=yrc(c[n>>2]|0,c[n+4>>2]|0,c[b+75244>>2]|0)|0;b=wrc(B>>>8|C<<24,C>>8|((C|0)<0|0?-1:0)<<24,h,G)|0;c[l>>2]=b;c[l+4>>2]=G;M=l|0;N=c[M>>2]|0;O=l+4|0;P=c[O>>2]|0;i=k;return(G=P,N)|0}return 0}function S3b(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0;q=i;i=i+1096|0;r=q|0;s=q+8|0;t=q+16|0;u=q+240|0;v=q+336|0;w=q+352|0;x=q+360|0;y=q+400|0;z=q+440|0;A=q+464|0;B=q+488|0;C=q+520|0;D=q+552|0;E=q+632|0;F=q+648|0;H=q+664|0;I=q+672|0;J=q+680|0;K=q+688|0;L=q+696|0;M=q+712|0;N=q+728|0;O=q+760|0;P=q+776|0;Q=q+792|0;R=q+904|0;S=q+912|0;T=q+920|0;U=q+928|0;V=q+936|0;W=q+944|0;X=q+952|0;Y=q+960|0;Z=q+968|0;_=q+976|0;$=q+984|0;aa=q+1024|0;ba=q+1032|0;da=q+1040|0;ea=q+1048|0;fa=q+1056|0;ga=q+1064|0;ha=q+1072|0;ia=q+1080|0;ja=q+1088|0;ka=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;c[s>>2]=o;c[s+4>>2]=p;p=ka+1434592|0;o=ka+1473304|0;n=e+24720|0;la=c[c[n+160>>2]>>2]|0;ma=p+13408|0;na=a[la+13|0]|0;mrc(v|0,0,16)|0;oa=c[s+4>>2]|0;c[w>>2]=c[s>>2];c[w+4>>2]=oa;mrc(D|0,0,76)|0;oa=-1;c[I>>2]=-1;c[I+4>>2]=2147483647;c[J>>2]=-1;c[J+4>>2]=2147483647;pa=0;qa=1;c[K>>2]=4;ra=Q;mrc(ra|0,0,112)|0;sa=ra|0;c[sa>>2]=-1;c[sa+4>>2]=-1;sa=((ngc(c[p+10168>>2]|0,c[p+10172>>2]|0)|0)<<16>>16)*20|0;ra=(c[777680+(l<<2)>>2]|0)/2|0;ta=(c[777736+(l<<2)>>2]|0)/2|0;ua=0;va=0;wa=(c[ka+2046952>>2]|0)+1|0;xa=o+144+((na&255)*1560|0)+(l*120|0)|0;ya=o+12624+(l*120|0)|0;za=c[ka+2047024>>2]|0;Aa=c[ka+2047036+(c[833024+(l<<2)>>2]<<2)>>2]|0;Ba=c[ka+2047092+(l<<2)>>2]|0;if((c[ka+2046932>>2]|0)!=0){Ca=(c[e+75216>>2]|0)<115}else{Ca=0}c[e+1184592>>2]=Ca&1;T3b(ka,na&255,E|0,F|0,H);Ca=0;while(1){if((Ca|0)>=3){break}Da=A+(Ca<<3)|0;c[Da>>2]=-1;c[Da+4>>2]=2147483647;Ca=Ca+1|0}Ca=0;while(1){if((Ca|0)>=5){break}Da=x+(Ca<<3)|0;c[Da>>2]=-1;c[Da+4>>2]=2147483647;Ca=Ca+1|0}Ca=0;while(1){if((Ca|0)>=4){break}Da=B+(Ca<<3)|0;c[Da>>2]=-1;c[Da+4>>2]=2147483647;Ca=Ca+1|0}Ca=0;while(1){if((Ca|0)>=4){break}c[L+(Ca<<2)>>2]=2147483647;Ca=Ca+1|0}Ca=0;while(1){if((Ca|0)>=4){break}c[e+75304+(Ca<<2)>>2]=2147483647;Ca=Ca+1|0}c[j>>2]=2147483647;Da=1;while(1){if((Da|0)>3){break}c[e+75320+(Da<<2)>>2]=2147483647;if((c[ka+2046872>>2]&c[206840+(Da<<2)>>2]|0)!=0){J3b(ka,e,f,Da,l,g,h,t+160|0,t+176|0,u|0)}c[t+208+(Da<<2)>>2]=-2147450880;c[t+192+(Da<<2)>>2]=0;Da=Da+1|0}Da=1;while(1){if((Da|0)>3){break}if((c[ka+2046872>>2]&c[206840+(Da<<2)>>2]|0)!=0){if((c[ka+2046956>>2]|0)!=0){Ca=1;while(1){if((Ca|0)>3){break}if((c[e+75320+(Da<<2)>>2]>>2|0)>(c[e+75320+(Ca<<2)>>2]|0)){Ea=37;break}Ca=Ca+1|0}if((Ea|0)==37){Ea=0;va=va|c[206808+(Da<<2)>>2]}}}else{va=va|c[206824+(Da<<2)>>2]}do{if((Thc(ma,na&255,2)|0)!=0){if((Zhc(ma,na&255,2)|0)==(Da|0)){break}va=va|c[206824+(Da<<2)>>2]}}while(0);Da=Da+1|0}if((Thc(ma,na&255,3)|0)!=0){va=va|129015}if((Thc(ma,na&255,2)|0)==0){do{if((c[ka+2017236>>2]|0)!=0){if((c[ka+1471848>>2]|0)!=0){break}va=va|-524547;if((c[t+188>>2]|0)!=0){va=va|256}if((c[t+172>>2]|0)!=0){va=va|2}}}while(0)}if((g+ta|0)>(c[p+10148>>2]|0)){Ea=60}else{if((h+ra|0)>(c[p+10156>>2]|0)){Ea=60}}if((Ea|0)==60){va=va|73840}if(l>>>0>(c[ka+2047152>>2]|0)>>>0){va=va|267585544}if((c[e+1129284>>2]|0)==0){if((c[ka+2046872>>2]&1|0)!=0){}else{Cd(2425696,2558456,3277,2650184);return 0}if((c[t+164>>2]|0)==0){Fa=0}else{if((c[t+180>>2]|0)==0){Fa=7}else{Fa=17}}va=~(1<<Fa);wa=30;Ba=0}Fa=0;a:while(1){if((Fa|0)>=30){break}c[R>>2]=0;c[S>>2]=-1;c[S+4>>2]=2147483647;c[T>>2]=0;ra=0;c[U>>2]=0;c[V>>2]=0;c[W>>2]=0;c[X>>2]=0;c[X+4>>2]=0;c[Y>>2]=0;c[Y+4>>2]=0;c[Z>>2]=0;c[Z+4>>2]=0;c[_>>2]=0;ta=0;c[aa>>2]=-1;c[aa+4>>2]=2147483647;f=0;do{if((Fa|0)==(wa|0)){if((oa|0)<0){break}switch(c[213972+(oa*12|0)>>2]|0){case 2:{va=va|-2475088;break};case 1:{va=va|-1192608;break};case 3:{va=va|-3782448;break};case-1:case 4:{Ea=82;break a;break};case 0:{break};default:{}}}}while(0);b:do{if((va&1<<Fa|0)==0){Ga=c[w>>2]|0;Ha=c[w+4>>2]|0;Ia=c[xa+(Fa<<2)>>2]|0;Ja=c[ya+(Fa<<2)>>2]|0;Ka=Erc(Ia,(Ia|0)<0|0?-1:0,Ja,(Ja|0)<0|0?-1:0)|0;Ja=G;Ia=Ja>>5|((Ja|0)<0|0?-1:0)<<27;do{if(!((Ha|0)<(Ia|0)|(Ha|0)==(Ia|0)&Ga>>>0<(Ka>>>5|Ja<<27)>>>0)){if((c[xa+(Fa<<2)>>2]|0)==2147483647){break}La=c[213968+(Fa*12|0)>>2]|0;Da=c[213972+(Fa*12|0)>>2]|0;do{if((Da|0)!=0){if((Ba&1<<La-10|0)==0){break}break b}}while(0);Ma=c[213976+(Fa*12|0)>>2]|0;Na=(Ma|0)>0|0;if((Na|0)!=0){do{if((za&2|0)!=0){if((oa|0)<0){break}if((c[213972+(oa*12|0)>>2]|0)!=0){break}break b}}while(0);do{if((za&4|0)!=0){if((Da|0)==(qa|0)){break}if((Ma|0)==(qa|0)){break}break b}}while(0);c[R>>2]=(c[p+13536>>2]|0)==0}else{if((Da|0)!=0){c[R>>2]=(c[p+13536>>2]|0)==1}}if((Da|0)==0){if((Aa&1<<La|0)==0){break b}if((La|0)!=0){do{if((za&32|0)!=0){if(!((c[e+75300>>2]|0)>>>0<64>>>0)){break}break b}}while(0);do{if((za&8|0)!=0){if(!(La>>>0>=3>>>0)){break}if(!(La>>>0<=9>>>0)){break}do{if((oa|0)>=0){if((c[213972+(oa*12|0)>>2]|0)<=0){break}break b}}while(0)}}while(0);do{if((za&16|0)!=0){if((U3b(La,pa)|0)!=0){break b}else{break}}}while(0)}}else{do{if((c[e+1129284>>2]|0)!=0){if((Thc(p+13408|0,d[la+13|0]|0,3)|0)!=0){break}Oa=ba|0;c[Oa>>2]=Da;c[Oa+4>>2]=Ma;if((V3b(ka,la+68|0,t|0,Ba,La,ba|0)|0)!=0){break}else{break b}}}while(0)}c[la+4>>2]=La;if((c[e+1129284>>2]|0)!=0){Pa=0}else{Pa=La}c[la+16>>2]=Pa;c[la+20>>2]=Da;c[la+24>>2]=Ma;if((c[p+10220>>2]|0)==4){Qa=0}else{Qa=c[p+10220>>2]|0}c[la+72>>2]=Qa;c[e+1129276>>2]=0;Oa=p;Ra=n;Sa=Da;Ta=Ma;if((Sa|0)>=1){Ua=Sa-1|0}else{Ua=0}c[Ra+188>>2]=Oa+9816+(Ua<<6);if((Ta|0)>=1){Va=Ta-1|0}else{Va=0}c[Ra+192>>2]=Oa+9816+(Va<<6);Oa=0;while(1){if((Oa|0)>=3){break}Ra=n+(Oa*52|0)+24|0;Ta=u+(Da*24|0)+(Oa<<3)|0;c[Ra>>2]=c[Ta>>2];c[Ra+4>>2]=c[Ta+4>>2];if((Na|0)!=0){Ta=n+(Oa*52|0)+32|0;Ra=u+(Ma*24|0)+(Oa<<3)|0;c[Ta>>2]=c[Ra>>2];c[Ta+4>>2]=c[Ra+4>>2]}Oa=Oa+1|0}Oa=0;while(1){if((Oa|0)>=5){break}Ma=$+(Oa<<3)|0;c[Ma>>2]=-1;c[Ma+4>>2]=2147483647;Oa=Oa+1|0}if((Da|0)==0){W3b(ka,e,V,Y,_,0,l,$|0,c[w>>2]|0,c[w+4>>2]|0);if((c[V>>2]|0)==2147483647){break b}Ma=c[la+8>>2]|0;Ra=l;if(Ra>>>0<3>>>0){Wa=0}else{Ta=c[558436+(Ra<<4)>>2]|0;if(Ma>>>0<(c[833024+(Ta<<2)>>2]|0)>>>0){Xa=Ma}else{Xa=c[833024+(Ta<<2)>>2]|0}Wa=Xa}Ta=Wa;if((c[L+(Ta<<2)>>2]|0)==2147483647){X3b(ka,m,l,Ta,L+(Ta<<2)|0,M+(Ta<<2)|0,N+(Ta<<3)|0,O+(Ta<<2)|0,P+(Ta<<2)|0)}c[W>>2]=c[M+(Ta<<2)>>2];Ma=N+(Ta<<3)|0;Ra=c[Ma+4>>2]|0;c[Z>>2]=c[Ma>>2];c[Z+4>>2]=Ra;if((c[_>>2]|0)!=0){Ya=(c[O+(Ta<<2)>>2]|0)!=0}else{Ya=0}c[_>>2]=Ya&1;c[la+16>>2]=c[P+(Ta<<2)>>2];c[U>>2]=(c[V>>2]|0)+(c[e+1123952+(c[la+4>>2]<<2)>>2]|0)+(c[L+(Ta<<2)>>2]|0);do{if((La|0)!=0){if((La|0)==9){break}c[U>>2]=(c[U>>2]|0)+sa}}while(0);Ta=wrc(c[Y>>2]|0,c[Y+4>>2]|0,c[Z>>2]|0,c[Z+4>>2]|0)|0;c[X>>2]=Ta;c[X+4>>2]=G}else{Ta=Y3b(ka,e,l,$|0,U,X,_,V,Y,W,Z,R,T,K,t|0,g,h,v|0,aa,c[w>>2]|0,c[w+4>>2]|0)|0;c[S>>2]=Ta;c[S+4>>2]=G;if((c[S>>2]|0)==(-1|0)&(c[S+4>>2]|0)==2147483647){break b}if((Na|0)!=0){Za=255-(d[H]|0)|0}else{Za=d[H]|0}ra=c[206872+(Za<<2)>>2]|0;if((c[p+13536>>2]|0)==2){c[U>>2]=(c[U>>2]|0)+ra}}if((Na|0)!=0){c[U>>2]=(c[U>>2]|0)+(c[F+(Da<<2)>>2]|0)}else{c[U>>2]=(c[U>>2]|0)+(c[E+(Da<<2)>>2]|0)}if((c[T>>2]|0)==0){Ta=((Thc(ma,na&255,3)|0)!=0^1)&1;if((c[_>>2]|0)!=0){c[U>>2]=(c[U>>2]|0)-((c[V>>2]|0)+(c[W>>2]|0));c[W>>2]=0;if((Ta|0)!=0){Ra=n;Ma=Ra;if((c[Ma+164>>2]|0)!=0){_a=c[(c[Ma+160>>2]|0)+(-(c[Ma+156>>2]|0)<<2)>>2]|0}else{_a=0}Ma=_a;Sa=Ra;if((c[Sa+168>>2]|0)!=0){$a=c[(c[Sa+160>>2]|0)-4>>2]|0}else{$a=0}Sa=$a;if((Ma|0)!=0){ab=d[Ma+12|0]|0}else{ab=0}if((Sa|0)!=0){bb=d[Sa+12|0]|0}else{bb=0}Sa=a[p+15507+(ab+bb)|0]|0;if(Sa<<24>>24!=0){c[U>>2]=(c[U>>2]|0)+(c[206872+(255-(Sa&255)<<2)>>2]|0)}}}else{do{if((Ta|0)!=0){if((Da|0)==0){Ea=233;break}if((c[n+25808>>2]|0)!=0){Ea=233;break}Sa=c[V>>2]|0;Ma=c[W>>2]|0;Ra=wrc(Sa,(Sa|0)<0|0?-1:0,Ma,(Ma|0)<0|0?-1:0)|0;Ma=c[e+75248>>2]|0;Sa=Erc(Ra,G,Ma,(Ma|0)<0|0?-1:0)|0;Ma=wrc(128,0,Sa,G)|0;Sa=G;Ra=yrc(c[X>>2]|0,c[X+4>>2]|0,c[e+75244>>2]|0)|0;cb=wrc(Ma>>>8|Sa<<24,Sa>>8|((Sa|0)<0|0?-1:0)<<24,Ra,G)|0;Ra=G;Sa=c[e+75248>>2]|0;Ma=Erc(0,0,Sa,(Sa|0)<0|0?-1:0)|0;Sa=wrc(128,0,Ma,G)|0;Ma=G;db=yrc(c[aa>>2]|0,c[aa+4>>2]|0,c[e+75244>>2]|0)|0;eb=wrc(Sa>>>8|Ma<<24,Ma>>8|((Ma|0)<0|0?-1:0)<<24,db,G)|0;db=G;if((Ra|0)<(db|0)|(Ra|0)==(db|0)&cb>>>0<eb>>>0){eb=n;cb=eb;if((c[cb+164>>2]|0)!=0){fb=c[(c[cb+160>>2]|0)+(-(c[cb+156>>2]|0)<<2)>>2]|0}else{fb=0}cb=fb;db=eb;if((c[db+168>>2]|0)!=0){gb=c[(c[db+160>>2]|0)-4>>2]|0}else{gb=0}db=gb;if((cb|0)!=0){hb=d[cb+12|0]|0}else{hb=0}if((db|0)!=0){ib=d[db+12|0]|0}else{ib=0}c[U>>2]=(c[U>>2]|0)+(c[206872+(d[p+15507+(hb+ib)|0]<<2)>>2]|0)}else{db=n;cb=db;if((c[cb+164>>2]|0)!=0){jb=c[(c[cb+160>>2]|0)+(-(c[cb+156>>2]|0)<<2)>>2]|0}else{jb=0}cb=jb;eb=db;if((c[eb+168>>2]|0)!=0){kb=c[(c[eb+160>>2]|0)-4>>2]|0}else{kb=0}eb=kb;if((cb|0)!=0){lb=d[cb+12|0]|0}else{lb=0}if((eb|0)!=0){mb=d[eb+12|0]|0}else{mb=0}c[U>>2]=(c[U>>2]|0)+(c[206872+(255-(d[p+15507+(lb+mb)|0]|0)<<2)>>2]|0);eb=c[aa+4>>2]|0;c[X>>2]=c[aa>>2];c[X+4>>2]=eb;eb=c[aa+4>>2]|0;cb=0;if((eb|0)>=(cb|0)&((eb|0)>(cb|0)|(c[aa>>2]|0)>>>0>=0>>>0)){}else{Cd(2283064,2558456,3501,2650184);return 0}c[U>>2]=(c[U>>2]|0)-((c[V>>2]|0)+(c[W>>2]|0));c[V>>2]=0;c[W>>2]=0;ta=1}}else{Ea=233}}while(0);if((Ea|0)==233){Ea=0;if((Ta|0)!=0){cb=n;eb=cb;if((c[eb+164>>2]|0)!=0){nb=c[(c[eb+160>>2]|0)+(-(c[eb+156>>2]|0)<<2)>>2]|0}else{nb=0}eb=nb;db=cb;if((c[db+168>>2]|0)!=0){ob=c[(c[db+160>>2]|0)-4>>2]|0}else{ob=0}db=ob;if((eb|0)!=0){pb=d[eb+12|0]|0}else{pb=0}if((db|0)!=0){qb=d[db+12|0]|0}else{qb=0}c[U>>2]=(c[U>>2]|0)+(c[206872+(d[p+15507+(pb+qb)|0]<<2)>>2]|0)}}}db=c[U>>2]|0;eb=c[e+75248>>2]|0;cb=Erc(db,(db|0)<0|0?-1:0,eb,(eb|0)<0|0?-1:0)|0;eb=wrc(128,0,cb,G)|0;cb=G;db=yrc(c[X>>2]|0,c[X+4>>2]|0,c[e+75244>>2]|0)|0;Ra=wrc(eb>>>8|cb<<24,cb>>8|((cb|0)<0|0?-1:0)<<24,db,G)|0;c[S>>2]=Ra;c[S+4>>2]=G}if((Da|0)==0){Ra=c[S+4>>2]|0;db=c[I+4>>2]|0;if((Ra|0)<(db|0)|(Ra|0)==(db|0)&(c[S>>2]|0)>>>0<(c[I>>2]|0)>>>0){db=c[S+4>>2]|0;c[I>>2]=c[S>>2];c[I+4>>2]=db;pa=c[la+4>>2]|0}}else{do{if((Na|0)==0){if((c[R>>2]|0)!=0){break}db=c[S+4>>2]|0;Ra=c[J+4>>2]|0;if(!((db|0)<(Ra|0)|(db|0)==(Ra|0)&(c[S>>2]|0)>>>0<(c[J>>2]|0)>>>0)){break}Ra=c[S+4>>2]|0;c[J>>2]=c[S>>2];c[J+4>>2]=Ra;qa=Da}}while(0)}do{if((c[T>>2]|0)==0){if((Da|0)!=0){break}Oa=0;while(1){if((Oa|0)>=3){break}Ta=A+(Oa<<3)|0;Ra=c[Ta+4>>2]|0;db=c[S+4>>2]|0;if((Ra|0)<(db|0)|(Ra|0)==(db|0)&(c[Ta>>2]|0)>>>0<(c[S>>2]|0)>>>0){Ta=A+(Oa<<3)|0;rb=c[Ta+4>>2]|0;sb=c[Ta>>2]|0}else{rb=c[S+4>>2]|0;sb=c[S>>2]|0}Ta=A+(Oa<<3)|0;c[Ta>>2]=sb;c[Ta+4>>2]=rb;Oa=Oa+1|0}Oa=0;while(1){if((Oa|0)>=4){break}Ta=B+(Oa<<3)|0;db=c[Ta+4>>2]|0;Ra=c[S+4>>2]|0;if((db|0)<(Ra|0)|(db|0)==(Ra|0)&(c[Ta>>2]|0)>>>0<(c[S>>2]|0)>>>0){Ta=B+(Oa<<3)|0;tb=c[Ta+4>>2]|0;ub=c[Ta>>2]|0}else{tb=c[S+4>>2]|0;ub=c[S>>2]|0}Ta=B+(Oa<<3)|0;c[Ta>>2]=ub;c[Ta+4>>2]=tb;Oa=Oa+1|0}}}while(0);Ta=Q+(La<<3)|0;if((c[Ta>>2]|0)==(-1|0)&(c[Ta+4>>2]|0)==(-1|0)){Ea=278}else{Ta=c[X+4>>2]|0;Ra=Q+(La<<3)|0;db=c[Ra+4>>2]|0;if((Ta|0)<(db|0)|(Ta|0)==(db|0)&(c[X>>2]|0)>>>0<(c[Ra>>2]|0)>>>0){Ea=278}}if((Ea|0)==278){Ea=0;Ra=c[X+4>>2]|0;db=Q+(La<<3)|0;c[db>>2]=c[X>>2];c[db+4>>2]=Ra}Ra=c[S+4>>2]|0;db=c[w+4>>2]|0;if((Ra|0)<(db|0)|(Ra|0)==(db|0)&(c[S>>2]|0)>>>0<(c[w>>2]|0)>>>0){Ea=281}else{if((c[e+1129276>>2]|0)!=0){Ea=281}}if((Ea|0)==281){Ea=0;db=3;if((c[R>>2]|0)==0){oa=Fa;if((Da|0)==0){c[la+28>>2]=0;db=1}c[j>>2]=c[U>>2];Ra=c[X+4>>2]|0;Ta=k;c[Ta>>2]=c[X>>2];c[Ta+4>>2]=Ra;Ra=c[S+4>>2]|0;c[w>>2]=c[S>>2];c[w+4>>2]=Ra;nrc(D|0,la|0,76)|0;ua=ta;if((c[e+75204>>2]|0)==0){Z3b(e,m,db)}nrc(c[m+124>>2]|0,e+1128252+(c[la+8>>2]<<8)|0,c[m+420>>2]|0)|0;do{if((za&1|0)!=0){if((Fa|0)<=3){break}db=b[(c[n+40>>2]|0)+2>>1]|0;Ra=4;if((c[e+75300>>2]|0)>>>0<4294967295>>>0){Ra=Ra-((c[e+75300>>2]|0)>>>0<16>>>0)|0}do{if((Da|0)>0){Ta=Ra;cb=Erc(c[X>>2]|0,c[X+4>>2]|0,Ta,(Ta|0)<0|0?-1:0)|0;Ta=G;eb=ca(db,db)|0;Ma=(eb|0)<0|0?-1:0;if(!((Ta|0)<(Ma|0)|(Ta|0)==(Ma|0)&cb>>>0<eb>>>0)){break}f=1}}while(0)}}while(0)}}do{if((c[T>>2]|0)==0){if((Da|0)==0){break}if((c[p+13536>>2]|0)==2){La=(c[U>>2]|0)-ra|0;c[fa>>2]=La;c[fa+4>>2]=(La|0)<0|0?-1:0;La=c[U>>2]|0;c[ga>>2]=La;c[ga+4>>2]=(La|0)<0|0?-1:0}else{La=c[U>>2]|0;c[fa>>2]=La;c[fa+4>>2]=(La|0)<0|0?-1:0;La=(c[U>>2]|0)+ra|0;c[ga>>2]=La;c[ga+4>>2]=(La|0)<0|0?-1:0}La=c[e+75248>>2]|0;db=Erc(c[fa>>2]|0,c[fa+4>>2]|0,La,(La|0)<0|0?-1:0)|0;La=wrc(128,0,db,G)|0;db=G;Ra=yrc(c[X>>2]|0,c[X+4>>2]|0,c[e+75244>>2]|0)|0;eb=wrc(La>>>8|db<<24,db>>8|((db|0)<0|0?-1:0)<<24,Ra,G)|0;c[da>>2]=eb;c[da+4>>2]=G;eb=c[e+75248>>2]|0;Ra=Erc(c[ga>>2]|0,c[ga+4>>2]|0,eb,(eb|0)<0|0?-1:0)|0;eb=wrc(128,0,Ra,G)|0;Ra=G;db=yrc(c[X>>2]|0,c[X+4>>2]|0,c[e+75244>>2]|0)|0;La=wrc(eb>>>8|Ra<<24,Ra>>8|((Ra|0)<0|0?-1:0)<<24,db,G)|0;c[ea>>2]=La;c[ea+4>>2]=G;if((Na|0)!=0){La=c[da+4>>2]|0;db=A+8|0;Ra=c[db+4>>2]|0;if((La|0)<(Ra|0)|(La|0)==(Ra|0)&(c[da>>2]|0)>>>0<(c[db>>2]|0)>>>0){db=c[da+4>>2]|0;Ra=A+8|0;c[Ra>>2]=c[da>>2];c[Ra+4>>2]=db}}else{db=c[da+4>>2]|0;Ra=A|0;La=c[Ra+4>>2]|0;if((db|0)<(La|0)|(db|0)==(La|0)&(c[da>>2]|0)>>>0<(c[Ra>>2]|0)>>>0){Ra=c[da+4>>2]|0;La=A|0;c[La>>2]=c[da>>2];c[La+4>>2]=Ra}}Ra=c[ea+4>>2]|0;La=A+16|0;db=c[La+4>>2]|0;if((Ra|0)<(db|0)|(Ra|0)==(db|0)&(c[ea>>2]|0)>>>0<(c[La>>2]|0)>>>0){La=c[ea+4>>2]|0;db=A+16|0;c[db>>2]=c[ea>>2];c[db+4>>2]=La}do{if((c[R>>2]|0)==0){if((c[p+10220>>2]|0)==3){break}if((c[p+10220>>2]|0)==4){vb=3}else{vb=c[p+10220>>2]|0}La=o+17392+(vb<<3)|0;db=c[La+4>>2]|0;c[ha>>2]=c[La>>2];c[ha+4>>2]=db;Oa=0;while(1){if((Oa|0)>=4){break}if((c[ha>>2]|0)==(-1|0)&(c[ha+4>>2]|0)==2147483647){c[ia>>2]=0;c[ia+4>>2]=0}else{db=o+17392+(Oa<<3)|0;if((c[db>>2]|0)==(-1|0)&(c[db+4>>2]|0)==2147483647){db=o+17424|0;La=xrc(c[db>>2]|0,c[db+4>>2]|0,c[ha>>2]|0,c[ha+4>>2]|0)|0;db=wrc(La,G,10,0)|0;c[ia>>2]=db;c[ia+4>>2]=G}else{db=o+17392+(Oa<<3)|0;La=xrc(c[db>>2]|0,c[db+4>>2]|0,c[ha>>2]|0,c[ha+4>>2]|0)|0;c[ia>>2]=La;c[ia+4>>2]=G}}La=wrc(c[ia>>2]|0,c[ia+4>>2]|0,c[S>>2]|0,c[S+4>>2]|0)|0;c[ia>>2]=La;c[ia+4>>2]=G;La=B+(Oa<<3)|0;db=c[La+4>>2]|0;Ra=c[ia+4>>2]|0;if((db|0)<(Ra|0)|(db|0)==(Ra|0)&(c[La>>2]|0)>>>0<(c[ia>>2]|0)>>>0){La=B+(Oa<<3)|0;wb=c[La+4>>2]|0;xb=c[La>>2]|0}else{wb=c[ia+4>>2]|0;xb=c[ia>>2]|0}La=B+(Oa<<3)|0;c[La>>2]=xb;c[La+4>>2]=wb;Oa=Oa+1|0}}}while(0)}}while(0);if(l>>>0<9>>>0){if(l>>>0<6>>>0){La=$+8|0;Ra=c[La+4>>2]|0;db=$+16|0;c[db>>2]=c[La>>2];c[db+4>>2]=Ra}Ra=$+16|0;db=c[Ra+4>>2]|0;La=$+24|0;c[La>>2]=c[Ra>>2];c[La+4>>2]=db}do{if((c[R>>2]|0)==0){if(!((c[S>>2]|0)!=(-1|0)|(c[S+4>>2]|0)!=2147483647)){break}Oa=0;while(1){if((Oa|0)<5){db=$+(Oa<<3)|0;La=c[db+4>>2]|0;Ra=2147483647;yb=(La|0)<(Ra|0)|(La|0)==(Ra|0)&(c[db>>2]|0)>>>0<-1>>>0}else{yb=0}if(!yb){break}c[ja>>2]=-1;c[ja+4>>2]=2147483647;db=$+(Oa<<3)|0;Ra=wrc(c[S>>2]|0,c[S+4>>2]|0,c[db>>2]|0,c[db+4>>2]|0)|0;db=$+(c[p+10164>>2]<<3)|0;La=xrc(Ra,G,c[db>>2]|0,c[db+4>>2]|0)|0;c[ja>>2]=La;c[ja+4>>2]=G;La=c[ja+4>>2]|0;db=x+(Oa<<3)|0;Ra=c[db+4>>2]|0;if((La|0)<(Ra|0)|(La|0)==(Ra|0)&(c[ja>>2]|0)>>>0<(c[db>>2]|0)>>>0){db=c[ja+4>>2]|0;Ra=x+(Oa<<3)|0;c[Ra>>2]=c[ja>>2];c[Ra+4>>2]=db}Oa=Oa+1|0}}}while(0);if((f|0)!=0){Ea=346;break a}if((c[e+1129276>>2]|0)!=0){if((Na|0)==0){Ea=349;break a}}break b}}while(0)}}while(0);Fa=Fa+1|0}if((Ea|0)==82){Cd(2342608,2558456,3320,2650184);return 0}do{if((oa|0)>=0){Ea=c[w+4>>2]|0;ja=c[s+4>>2]|0;if((Ea|0)>=(ja|0)&((Ea|0)>(ja|0)|(c[w>>2]|0)>>>0>=(c[s>>2]|0)>>>0)){break}if((c[ka+2047072>>2]|0)!=0){if((c[213972+(oa*12|0)>>2]|0)==0){nrc(la|0,D|0,76)|0;ja=la;Ea=c[ja+8>>2]|0;$=c[ja>>2]|0;if($>>>0<3>>>0){zb=0}else{ja=c[558436+($<<4)>>2]|0;if(Ea>>>0<(c[833024+(ja<<2)>>2]|0)>>>0){Ab=Ea}else{Ab=c[833024+(ja<<2)>>2]|0}zb=Ab}ja=zb;if(l>>>0<3>>>0){Bb=3}else{Bb=l}Q3b(ka,e,m,L+(ja<<2)|0,M+(ja<<2)|0,N+(ja<<3)|0,O+(ja<<2)|0,Bb,ja)|0;}}do{if((c[p+10220>>2]|0)==4){Cb=1}else{if((c[p+10220>>2]|0)==(c[D+72>>2]|0)){Cb=1;break}if(((c[D+20>>2]|0)>0|0)==0){Cb=1;break}Cd(2233664,2558456,3681,2650184);return 0}}while(0);if((c[ka+2046924>>2]|0)!=0){Fa=0;while(1){if((Fa|0)>=30){break}ja=o+12624+(l*120|0)+(Fa<<2)|0;if((Fa|0)==(oa|0)){Ea=ja;c[Ea>>2]=(c[Ea>>2]|0)-(c[ja>>2]>>3)}else{if(((c[ja>>2]|0)+1|0)<(c[ka+2046924>>2]<<6|0)){Db=(c[ja>>2]|0)+1|0}else{Db=c[ka+2046924>>2]<<6}c[ja>>2]=Db}Fa=Fa+1|0}}nrc(la|0,D|0,76)|0;ja=e+1129276|0;c[ja>>2]=c[ja>>2]|ua;Ca=0;while(1){if((Ca|0)>=3){break}ja=A+(Ca<<3)|0;if((c[ja>>2]|0)==(-1|0)&(c[ja+4>>2]|0)==2147483647){ja=z+(Ca<<3)|0;c[ja>>2]=-2147483648;c[ja+4>>2]=-1}else{ja=A+(Ca<<3)|0;Ea=xrc(c[w>>2]|0,c[w+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;ja=z+(Ca<<3)|0;c[ja>>2]=Ea;c[ja+4>>2]=G}Ca=Ca+1|0}if((c[e+1129276>>2]|0)!=0){mrc(C|0,0,32)|0;mrc(y|0,0,40)|0}else{Ca=0;while(1){if((Ca|0)>=4){break}ja=B+(Ca<<3)|0;if((c[ja>>2]|0)==(-1|0)&(c[ja+4>>2]|0)==2147483647){ja=C+(Ca<<3)|0;c[ja>>2]=0;c[ja+4>>2]=0}else{ja=B+(Ca<<3)|0;Ea=xrc(c[w>>2]|0,c[w+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;ja=C+(Ca<<3)|0;c[ja>>2]=Ea;c[ja+4>>2]=G}Ca=Ca+1|0}if((c[p+10220>>2]|0)==4){ja=C+24|0;if((c[ja>>2]|0)==0&(c[ja+4>>2]|0)==0){}else{Cd(2194232,2558456,3720,2650184);return 0}}Ca=0;while(1){if((Ca|0)>=5){break}ja=x+(Ca<<3)|0;if((c[ja>>2]|0)==(-1|0)&(c[ja+4>>2]|0)==2147483647){ja=y+(Ca<<3)|0;c[ja>>2]=0;c[ja+4>>2]=0}else{ja=x+(Ca<<3)|0;Ea=xrc(c[w>>2]|0,c[w+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;ja=y+(Ca<<3)|0;c[ja>>2]=Ea;c[ja+4>>2]=G}Ca=Ca+1|0}}if((c[e+1129284>>2]|0)==0){if((c[la+20>>2]|0)==1){}else{Cd(2163176,2558456,3733,2650184);return 0}if((c[la+24>>2]|0)==-1){}else{Cd(2137288,2558456,3734,2650184);return 0}do{if((c[la+4>>2]|0)==10){Eb=1}else{if((c[la+4>>2]|0)==11){Eb=1;break}if((c[la+4>>2]|0)==12){Eb=1;break}Cd(2114032,2558456,3737,2650184);return 0}}while(0);if((c[t+(c[la+4>>2]<<4)+4>>2]|0)==0){}else{Cd(2632096,2558456,3738,2650184);return 0}if((c[la+4>>2]|0)==(c[la+16>>2]|0)){}else{Cd(2607776,2558456,3739,2650184);return 0}}ja=p;Ea=n;$=c[la+20>>2]|0;S=c[la+24>>2]|0;if(($|0)>=1){Fb=$-1|0}else{Fb=0}c[Ea+188>>2]=ja+9816+(Fb<<6);if((S|0)>=1){Gb=S-1|0}else{Gb=0}c[Ea+192>>2]=ja+9816+(Gb<<6);if((c[la+24>>2]|0)<0){Hb=0}else{Hb=c[la+24>>2]|0}_3b(e,m,oa,la+36+(c[la+20>>2]<<3)|0,la+36+(Hb<<3)|0,z|0,y|0,C|0);ja=c[w+4>>2]|0;c[r>>2]=c[w>>2];c[r+4>>2]=ja;Ib=r|0;Jb=c[Ib>>2]|0;Kb=r+4|0;Lb=c[Kb>>2]|0;i=q;return(G=Lb,Jb)|0}}while(0);c[r>>2]=-1;c[r+4>>2]=2147483647;Ib=r|0;Jb=c[Ib>>2]|0;Kb=r+4|0;Lb=c[Kb>>2]|0;i=q;return(G=Lb,Jb)|0}function T3b(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=b;b=e;e=f;f=g;g=j+1434592|0;k=j+57488|0;if((Thc(g+13408|0,d,2)|0)!=0){mrc(b|0,0,16)|0;mrc(e|0,0,16)|0;a[f]=-128;i=h;return}d=a[g+15471+(dgc(k)|0)|0]|0;j=-128;if((c[g+13536>>2]|0)==2){l=g;j=a[l+15475+(egc(l,k)|0)|0]|0;a[f]=j}else{a[f]=-128}c[b>>2]=c[206872+((d&255)<<2)>>2];if((c[g+13536>>2]|0)!=1){f=a[g+15480+((ggc(k)|0)<<1)|0]|0;l=a[g+15480+((hgc(k)|0)<<1)+1|0]|0;m=c[206872+(255-(d&255)<<2)>>2]|0;if((c[g+13536>>2]|0)==2){m=m+(c[206872+((j&255)<<2)>>2]|0)|0}n=m;c[b+12>>2]=n;c[b+8>>2]=n;c[b+4>>2]=n;n=b+4|0;c[n>>2]=(c[n>>2]|0)+(c[206872+((f&255)<<2)>>2]|0);n=b+8|0;c[n>>2]=(c[n>>2]|0)+(c[206872+(255-(f&255)<<2)>>2]|0);n=b+12|0;c[n>>2]=(c[n>>2]|0)+(c[206872+(255-(f&255)<<2)>>2]|0);f=b+8|0;c[f>>2]=(c[f>>2]|0)+(c[206872+((l&255)<<2)>>2]|0);f=b+12|0;c[f>>2]=(c[f>>2]|0)+(c[206872+(255-(l&255)<<2)>>2]|0)}else{c[b+4>>2]=512;c[b+8>>2]=512;c[b+12>>2]=512}if((c[g+13536>>2]|0)!=0){b=g;l=a[b+15490+(fgc(b,k)|0)|0]|0;k=c[206872+(255-(d&255)<<2)>>2]|0;if((c[g+13536>>2]|0)==2){k=k+(c[206872+(255-(j&255)<<2)>>2]|0)|0}c[e+4>>2]=k+(c[206872+((l&255)<<2)>>2]|0);c[e+8>>2]=k+(c[206872+(255-(l&255)<<2)>>2]|0)}else{c[e+4>>2]=512;c[e+8>>2]=512}i=h;return}function U3b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=i;d=a;a=b;do{if((d|0)==5){if((a|0)==1){e=5;break}if((a|0)==4){e=5;break}f=1}else{e=5}}while(0);a:do{if((e|0)==5){do{if((d|0)==8){if((a|0)==1){break}if((a|0)==3){break}f=1;break a}}while(0);do{if((d|0)==7){if((a|0)==2){break}if((a|0)==3){break}f=1;break a}}while(0);do{if((d|0)==6){if((a|0)==2){break}if((a|0)==4){break}f=1;break a}}while(0);f=0}}while(0);i=c;return f|0}function V3b(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;k=a;a=b;b=e;e=g;g=h;a:do{if((f&4|0)==0){do{if((e|0)!=11){if((e|0)==10){break}if((e|0)!=12){break a}}}while(0);if((c[b+(e<<4)+(c[g>>2]<<2)>>2]|0)!=0){break}if(!((c[g+4>>2]|0)==-1)){if((c[b+(e<<4)+(c[g+4>>2]<<2)>>2]|0)!=0){break}}h=d[a+(c[g>>2]|0)|0]|0;l=m4b(k,11,h)|0;m=m4b(k,10,h)|0;n=m4b(k,12,h)|0;do{if((e|0)==11){if((l|0)<=(n|0)){break}o=0;p=o;i=j;return p|0}else{do{if((e|0)==10){if((m|0)<=(n|0)){break}o=0;p=o;i=j;return p|0}else{if((e|0)==12){}else{Cd(2465576,2558456,1697,2653344);return 0}b:do{if((c[g+4>>2]|0)==-1){if((n|0)>=(m|0)){if((c[b+160+(c[g>>2]<<2)>>2]|0)!=0){q=21}}else{q=21}do{if((q|0)==21){if((n|0)>=(l|0)){if((c[b+176+(c[g>>2]<<2)>>2]|0)==0){break}}break b}}while(0);o=0;p=o;i=j;return p|0}else{do{if((n|0)>=(m|0)){if((c[b+160+(c[g>>2]<<2)>>2]|0)!=0){q=28;break}if((c[b+160+(c[g+4>>2]<<2)>>2]|0)!=0){q=28}}else{q=28}}while(0);c:do{if((q|0)==28){do{if((n|0)>=(l|0)){if((c[b+176+(c[g>>2]<<2)>>2]|0)!=0){break}if((c[b+176+(c[g+4>>2]<<2)>>2]|0)==0){break c}}}while(0);break b}}while(0);o=0;p=o;i=j;return p|0}}while(0)}}while(0)}}while(0)}}while(0);o=1;p=o;i=j;return p|0}function W3b(a,b,d,e,f,g,h,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;m=i;i=i+120|0;n=m|0;o=m+8|0;p=m+40|0;q=m+72|0;r=m+88|0;s=a;a=b;b=d;d=e;e=f;f=g;g=h;h=j;c[n>>2]=k;c[n+4>>2]=l;l=c[c[a+24880>>2]>>2]|0;if((g|0)==(c[l>>2]|0)){}else{Cd(2526360,2558456,1001,2651984)}if((c[s+2046944>>2]|0)!=0){mrc(h|0,0,40)|0;q4b(s,a,b,d,e,o|0,c[n>>2]|0,c[n+4>>2]|0,g)}else{k=0;while(1){if(!(k>>>0<=(c[833024+(g<<2)>>2]|0)>>>0)){break}c4b(a,p+(k<<3)|0,r+(k<<3)|0,q+(k<<2)|0,o+(k<<3)|0,c[n>>2]|0,c[n+4>>2]|0,0,g,k,c[s+2047144>>2]|0);k=k+1|0}t4b(s,a,p|0,b,r|0,d,q|0,e,h,g)}if((f|0)==0){i=m;return}g=o+(c[l+8>>2]<<3)|0;l=c[g+4>>2]|0;o=f;c[o>>2]=c[g>>2];c[o+4>>2]=l;i=m;return}function X3b(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;l=i;m=a;a=b;b=d;d=e;e=f;f=g;g=h;h=j;j=k;k=m+32768|0;if((c[m+2047072>>2]|0)!=0){if(b>>>0<3>>>0){n=3}else{n=b}v4b(m,k,e,f,g,h,n)|0;}else{if(b>>>0<3>>>0){o=3}else{o=b}Q3b(m,k,a,e,f,g,h,o,d)|0;}c[j>>2]=c[(c[c[k+24880>>2]>>2]|0)+16>>2];i=l;return}function Y3b(a,e,f,g,h,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;v=v|0;w=w|0;x=x|0;y=y|0;var z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0;z=i;i=i+12520|0;A=z|0;B=z+8|0;C=z+16|0;D=z+24|0;E=z+32|0;F=z+12352|0;H=z+12360|0;I=z+12368|0;J=z+12384|0;K=z+12400|0;L=z+12408|0;M=z+12416|0;N=z+12424|0;O=z+12432|0;P=z+12440|0;Q=z+12448|0;R=z+12456|0;S=z+12464|0;T=z+12472|0;U=z+12480|0;V=z+12488|0;W=z+12496|0;X=z+12504|0;Y=z+12512|0;Z=a;a=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=p;p=q;q=r;r=t;t=u;u=v;v=w;c[B>>2]=x;c[B+4>>2]=y;y=Z+1434592|0;x=Z+1473304|0;w=a+24720|0;_=c[c[w+160>>2]>>2]|0;$=(c[_+24>>2]|0)>0|0;aa=($|0)!=0?2:1;ba=c[_+4>>2]|0;da=s+(ba<<4)|0;s=C|0;c[s>>2]=c[_+20>>2];if((c[_+24>>2]|0)<0){ea=0}else{ea=c[_+24>>2]|0}c[s+4>>2]=ea;c[E>>2]=0;c[E+4>>2]=0;ea=z+56-1&-16;s=0;c[H>>2]=-1;c[H+4>>2]=2147483647;fa=0;ga=0;a:do{if(($|0)!=0){do{if(!((c[da+(c[C>>2]<<2)>>2]|0)==-2147450880)){if((c[da+(c[C+4>>2]<<2)>>2]|0)==-2147450880){break}break a}}while(0);c[A>>2]=-1;c[A+4>>2]=2147483647;ha=A|0;ia=c[ha>>2]|0;ja=A+4|0;ka=c[ja>>2]|0;i=z;return(G=ka,ia)|0}}while(0);if((ba|0)==13){do{if(($|0)!=0){c[da+(c[C>>2]<<2)>>2]=c[u+(c[C>>2]<<2)>>2];c[da+(c[C+4>>2]<<2)>>2]=c[u+(c[C+4>>2]<<2)>>2];if((c[Z+2046920>>2]|0)>>>0<=e>>>0){h4b(Z,a,e,da,r,t,u,K)}else{c[K>>2]=Znc(da+(c[C>>2]<<2)|0,_+36+(c[C>>2]<<3)|0,a+75336|0,c[a+599640>>2]|0,108)|0;la=Znc(da+(c[C+4>>2]<<2)|0,_+36+(c[C+4>>2]<<3)|0,a+75336|0,c[a+599640>>2]|0,108)|0;c[K>>2]=(c[K>>2]|0)+la}la=g;c[la>>2]=(c[la>>2]|0)+(c[K>>2]|0)}else{n4b(Z,a,e,r,t,L,K);if(!((c[L>>2]|0)==-2147450880)){la=g;c[la>>2]=(c[la>>2]|0)+(c[K>>2]|0);la=c[L>>2]|0;c[(c[c[w+160>>2]>>2]|0)+80>>2]=la;c[da+(c[C>>2]<<2)>>2]=la;c[u+(c[C>>2]<<2)>>2]=c[L>>2];break}c[A>>2]=-1;c[A+4>>2]=2147483647;ha=A|0;ia=c[ha>>2]|0;ja=A+4|0;ka=c[ja>>2]|0;i=z;return(G=ka,ia)|0}}while(0)}L=0;while(1){if((L|0)>=(aa|0)){break}c[D+(L<<2)>>2]=c[da+(c[C+(L<<2)>>2]<<2)>>2];if((ba|0)!=13){u=w;K=D+(L<<2)|0;la=(c[u+180>>2]|0)-1248|0;ma=(c[u+184>>2]|0)+1248|0;na=b[K+2>>1]|0;oa=(c[u+172>>2]|0)-1248|0;pa=(c[u+176>>2]|0)+1248|0;if((na|0)<(oa|0)){qa=oa}else{if((na|0)>(pa|0)){ra=pa}else{ra=na}qa=ra}b[K+2>>1]=qa;na=b[K>>1]|0;pa=la;la=ma;if((na|0)<(pa|0)){sa=pa}else{if((na|0)>(la|0)){ta=la}else{ta=na}sa=ta}b[K>>1]=sa}K=a;na=D+(L<<2)|0;do{if((b[na>>1]>>3|0)<(c[K+1128244>>2]|0)){ua=1}else{if((b[na>>1]>>3|0)>(c[K+1128248>>2]|0)){ua=1;break}if((b[na+2>>1]>>3|0)<(c[K+1128236>>2]|0)){ua=1;break}ua=(b[na+2>>1]>>3|0)>(c[K+1128240>>2]|0)}}while(0);if((ua&1|0)!=0){va=40;break}c[_+28+(L<<2)>>2]=c[D+(L<<2)>>2];L=L+1|0}if((va|0)==40){c[A>>2]=-1;c[A+4>>2]=2147483647;ha=A|0;ia=c[ha>>2]|0;ja=A+4|0;ka=c[ja>>2]|0;i=z;return(G=ka,ia)|0}L=0;while(1){if((L|0)>=3){break}c[I+(L<<2)>>2]=c[w+(L*52|0)+16>>2];c[J+(L<<2)>>2]=c[w+(L*52|0)+20>>2];L=L+1|0}D=m4b(Z,ba,d[_+68+(c[C>>2]|0)|0]|0)|0;C=g;c[C>>2]=(c[C>>2]|0)+D;if((c[o>>2]|0)==0){if(($|0)!=0){wa=(c[y+13536>>2]|0)==0|0}else{wa=(c[y+13536>>2]|0)==1|0}c[o>>2]=wa}s=0;wa=_+28|0;if((b[wa>>1]&15|0)!=0){xa=1}else{xa=(b[wa+2>>1]&15|0)!=0}wa=((xa&1|0)!=0^1)&1;if(($|0)!=0){xa=_+32|0;if((b[xa>>1]&15|0)!=0){ya=1}else{ya=(b[xa+2>>1]&15|0)!=0}wa=wa&(((ya&1|0)!=0^1)&1)}ya=x+17424|0;c[ya>>2]=0;c[ya+4>>2]=0;L=0;while(1){if((L|0)>=4){break}ya=x+17392+(L<<3)|0;c[ya>>2]=-1;c[ya+4>>2]=2147483647;L=L+1|0}if((c[y+10220>>2]|0)!=3){c[q>>2]=0;do{if((c[a+75300>>2]|0)>>>0<(c[Z+2047032>>2]|0)>>>0){c[q>>2]=0}else{ya=0;c[M>>2]=0;c[M+4>>2]=0;L=0;b:while(1){if((L|0)>=3){va=130;break}c[_+72>>2]=L;ga=N3b(a)|0;xa=ga;o=c[a+75248>>2]|0;D=Erc(xa,(xa|0)<0|0?-1:0,o,(o|0)<0|0?-1:0)|0;o=wrc(128,0,D,G)|0;D=G;xa=0<<c[a+75244>>2];C=wrc(o>>>8|D<<24,D>>8|((D|0)<0|0?-1:0)<<24,xa,(xa|0)<0|0?-1:0)|0;c[N>>2]=C;c[N+4>>2]=G;do{if((L|0)>0){if((wa|0)==0){va=78;break}C=ya;xa=c[a+75248>>2]|0;D=Erc(C,(C|0)<0|0?-1:0,xa,(xa|0)<0|0?-1:0)|0;xa=wrc(128,0,D,G)|0;D=G;C=yrc(c[M>>2]|0,c[M+4>>2]|0,c[a+75244>>2]|0)|0;o=wrc(xa>>>8|D<<24,D>>8|((D|0)<0|0?-1:0)<<24,C,G)|0;c[F>>2]=o;c[F+4>>2]=G;o=c[F+4>>2]|0;C=x+17392+(L<<3)|0;c[C>>2]=c[F>>2];c[C+4>>2]=o;o=x+17416|0;C=c[o>>2]|0;D=c[o+4>>2]|0;o=wrc(c[F>>2]|0,c[F+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;xa=G;if((D|0)<(xa|0)|(D|0)==(xa|0)&C>>>0<o>>>0){o=x+17416|0;za=c[o+4>>2]|0;Aa=c[o>>2]|0}else{o=wrc(c[F>>2]|0,c[F+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;za=G;Aa=o}o=x+17416|0;c[o>>2]=Aa;c[o+4>>2]=za;if((c[y+10220>>2]|0)==4){o=wrc(c[F>>2]|0,c[F+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;c[F>>2]=o;c[F+4>>2]=G}o=x+17424|0;C=c[o+4>>2]|0;xa=c[F+4>>2]|0;if((C|0)>(xa|0)|(C|0)==(xa|0)&(c[o>>2]|0)>>>0>(c[F>>2]|0)>>>0){o=x+17424|0;Ba=c[o+4>>2]|0;Ca=c[o>>2]|0}else{Ba=c[F+4>>2]|0;Ca=c[F>>2]|0}o=x+17424|0;c[o>>2]=Ca;c[o+4>>2]=Ba}else{va=78}}while(0);if((va|0)==78){va=0;c[O>>2]=0;c[P>>2]=0;c[P+4>>2]=0;do{if((c[y+10220>>2]|0)==4){if((L|0)==0){va=85;break}if((fa|0)!=0){va=85}else{va=81}}else{va=81}}while(0);c:do{if((va|0)==81){va=0;do{if((c[y+10220>>2]|0)!=4){if((c[y+10220>>2]|0)==(c[_+72>>2]|0)){va=85;break c}if((L|0)!=0){break}if((wa|0)!=0){va=85;break c}}}while(0);o=0;while(1){if((o|0)>=3){break}c[w+(o*52|0)+16>>2]=ea+(o<<6<<6);c[w+(o*52|0)+20>>2]=64;o=o+1|0}}}while(0);if((va|0)==85){va=0;o=w;xa=I|0;C=J|0;D=0;while(1){if((D|0)>=3){break}c[o+(D*52|0)+16>>2]=c[xa+(D<<2)>>2];c[o+(D*52|0)+20>>2]=c[C+(D<<2)>>2];D=D+1|0}}wgc(w,r,t,e);o4b(Z,e,a,w,O,P);D=c[O>>2]|0;C=c[a+75248>>2]|0;o=Erc(D,(D|0)<0|0?-1:0,C,(C|0)<0|0?-1:0)|0;C=wrc(128,0,o,G)|0;o=G;D=yrc(c[P>>2]|0,c[P+4>>2]|0,c[a+75244>>2]|0)|0;xa=wrc(C>>>8|o<<24,o>>8|((o|0)<0|0?-1:0)<<24,D,G)|0;c[F>>2]=xa;c[F+4>>2]=G;xa=c[F+4>>2]|0;D=x+17392+(L<<3)|0;c[D>>2]=c[F>>2];c[D+4>>2]=xa;xa=x+17416|0;D=c[xa>>2]|0;o=c[xa+4>>2]|0;xa=wrc(c[F>>2]|0,c[F+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;C=G;if((o|0)<(C|0)|(o|0)==(C|0)&D>>>0<xa>>>0){xa=x+17416|0;Da=c[xa+4>>2]|0;Ea=c[xa>>2]|0}else{xa=wrc(c[F>>2]|0,c[F+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;Da=G;Ea=xa}xa=x+17416|0;c[xa>>2]=Ea;c[xa+4>>2]=Da;if((c[y+10220>>2]|0)==4){xa=wrc(c[F>>2]|0,c[F+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;c[F>>2]=xa;c[F+4>>2]=G}xa=x+17424|0;D=c[xa+4>>2]|0;C=c[F+4>>2]|0;if((D|0)>(C|0)|(D|0)==(C|0)&(c[xa>>2]|0)>>>0>(c[F>>2]|0)>>>0){xa=x+17424|0;Fa=c[xa+4>>2]|0;Ga=c[xa>>2]|0}else{Fa=c[F+4>>2]|0;Ga=c[F>>2]|0}xa=x+17424|0;c[xa>>2]=Ga;c[xa+4>>2]=Fa;do{if((L|0)==0){if((wa|0)==0){break}ya=c[O>>2]|0;xa=c[P+4>>2]|0;c[M>>2]=c[P>>2];c[M+4>>2]=xa}}while(0)}do{if((L|0)==0){if((c[Z+2047068>>2]|0)==0){break}xa=c[B+4>>2]|0;C=2147483647;if(!((xa|0)<(C|0)|(xa|0)==(C|0)&(c[B>>2]|0)>>>0<-1>>>0)){break}C=Crc(c[F>>2]|0,c[F+4>>2]|0,2,0)|0;xa=G;D=c[B+4>>2]|0;if((xa|0)>(D|0)|(xa|0)==(D|0)&C>>>0>(c[B>>2]|0)>>>0){break b}}}while(0);if((L|0)==0){Ha=1}else{C=c[F+4>>2]|0;D=c[H+4>>2]|0;Ha=(C|0)<(D|0)|(C|0)==(D|0)&(c[F>>2]|0)>>>0<(c[H>>2]|0)>>>0}D=Ha&1;if((D|0)!=0){C=c[F+4>>2]|0;c[H>>2]=c[F>>2];c[H+4>>2]=C;c[q>>2]=c[_+72>>2];do{if((c[y+10220>>2]|0)==4){if((L|0)==0){break}if((wa|0)!=0){break}fa=((fa|0)!=0^1)&1}}while(0)}if((c[y+10220>>2]|0)==4){if((D|0)!=0){va=127}else{va=125}}else{va=125}do{if((va|0)==125){va=0;if((c[y+10220>>2]|0)==4){break}if((c[y+10220>>2]|0)==(c[_+72>>2]|0)){va=127}}}while(0);if((va|0)==127){va=0;s=1}L=L+1|0}if((va|0)==130){ya=w;D=I|0;C=J|0;xa=0;while(1){if((xa|0)>=3){break}c[ya+(xa*52|0)+16>>2]=c[D+(xa<<2)>>2];c[ya+(xa*52|0)+20>>2]=c[C+(xa<<2)>>2];xa=xa+1|0}break}xa=w;C=I|0;ya=J|0;D=0;while(1){if((D|0)>=3){break}c[xa+(D*52|0)+16>>2]=c[C+(D<<2)>>2];c[xa+(D*52|0)+20>>2]=c[ya+(D<<2)>>2];D=D+1|0}c[A>>2]=-1;c[A+4>>2]=2147483647;ha=A|0;ia=c[ha>>2]|0;ja=A+4|0;ka=c[ja>>2]|0;i=z;return(G=ka,ia)|0}}while(0)}if((c[y+10220>>2]|0)!=4){Ia=c[y+10220>>2]|0}else{Ia=c[q>>2]|0}c[_+72>>2]=Ia;if((c[y+10220>>2]|0)==4){Ja=N3b(a)|0}else{Ja=0}ga=Ja;if((s|0)!=0){if((fa|0)!=0){L=0;while(1){if((L|0)>=3){break}c[w+(L*52|0)+16>>2]=ea+(L<<6<<6);c[w+(L*52|0)+20>>2]=64;L=L+1|0}}}else{wgc(w,r,t,e)}do{if((c[Z+2047068>>2]|0)!=0){t=c[B+4>>2]|0;r=2147483647;if(!((t|0)<(r|0)|(t|0)==(r|0)&(c[B>>2]|0)>>>0<-1>>>0)){break}o4b(Z,e,a,w,Q,R);r=ga;t=c[Q>>2]|0;L=wrc(r,(r|0)<0|0?-1:0,t,(t|0)<0|0?-1:0)|0;t=c[a+75248>>2]|0;r=Erc(L,G,t,(t|0)<0|0?-1:0)|0;t=wrc(128,0,r,G)|0;r=G;L=yrc(c[R>>2]|0,c[R+4>>2]|0,c[a+75244>>2]|0)|0;ea=wrc(t>>>8|r<<24,r>>8|((r|0)<0|0?-1:0)<<24,L,G)|0;c[F>>2]=ea;c[F+4>>2]=G;ea=Crc(c[F>>2]|0,c[F+4>>2]|0,2,0)|0;L=G;r=c[B+4>>2]|0;if(!((L|0)>(r|0)|(L|0)==(r|0)&ea>>>0>(c[B>>2]|0)>>>0)){break}ea=w;r=I|0;L=J|0;t=0;while(1){if((t|0)>=3){break}c[ea+(t*52|0)+16>>2]=c[r+(t<<2)>>2];c[ea+(t*52|0)+20>>2]=c[L+(t<<2)>>2];t=t+1|0}c[A>>2]=-1;c[A+4>>2]=2147483647;ha=A|0;ia=c[ha>>2]|0;ja=A+4|0;ka=c[ja>>2]|0;i=z;return(G=ka,ia)|0}}while(0);if((c[y+10220>>2]|0)==4){F=N3b(a)|0;R=g;c[R>>2]=(c[R>>2]|0)+F}if(($|0)==0){if((c[a+1129284>>2]|0)!=0){do{if((c[Z+2047172>>2]|0)!=0){if((c[a+1129280>>2]|0)==0){break}$=w|0;F=c[558424+(e<<4)+(c[$+8>>2]<<3)+(c[$+12>>2]<<2)>>2]|0;if(!(F>>>0<13>>>0)){Cd(2437376,2427112,292,2652440);return 0}$=F;F=w+52|0;R=c[558424+(e<<4)+(c[F+8>>2]<<3)+(c[F+12>>2]<<2)>>2]|0;if(!(R>>>0<13>>>0)){Cd(2437376,2427112,292,2652440);return 0}F=R;R=(c[Z+2047172>>2]|0)==2?128:36e3;if(c[a+1129280>>2]<<4>>>0<R>>>0){Ka=c[a+1129280>>2]<<4}else{Ka=R}Q=(ca(b[(c[w+40>>2]|0)+2>>1]|0,b[(c[w+40>>2]|0)+2>>1]|0)|0)/9|0;ga=Q;t=Ka;L=R;if((ga|0)<(t|0)){La=t}else{if((ga|0)>(L|0)){Ma=L}else{Ma=ga}La=Ma}Q=La;ga=Xe[c[Z+2047252+($*44|0)+8>>2]&511](c[a+8204>>2]|0,c[a+8208>>2]|0,c[w+16>>2]|0,c[w+20>>2]|0,S)|0;Q=Q>>>((8-((c[1960336+(e<<2)>>2]|0)+(c[1960696+(e<<2)>>2]|0))|0)>>>0);if((c[S>>2]|0)>>>0<Q>>>0){va=182}else{if((c[S>>2]|0)==0){va=182}}if((va|0)==182){$=(ca(b[c[w+40>>2]>>1]|0,b[c[w+40>>2]>>1]|0)|0)>>6;if(((c[S>>2]|0)-ga|0)>>>0<$>>>0){va=184}else{if((c[S>>2]|0)==(ga|0)){va=184}}if((va|0)==184){ga=Xe[c[Z+2047252+(F*44|0)+8>>2]&511](c[a+16444>>2]|0,c[a+16448>>2]|0,c[w+68>>2]|0,c[w+72>>2]|0,T)|0;if(c[T>>2]<<2>>>0<Q>>>0){va=186}else{if((c[T>>2]|0)==0){va=186}}do{if((va|0)==186){if(!(((c[T>>2]|0)-ga|0)>>>0<$>>>0)){if((c[T>>2]|0)!=(ga|0)){break}}L=Xe[c[Z+2047252+(F*44|0)+8>>2]&511](c[a+24684>>2]|0,c[a+24688>>2]|0,c[w+120>>2]|0,c[w+124>>2]|0,U)|0;if(c[U>>2]<<2>>>0<Q>>>0){va=190}else{if((c[U>>2]|0)==0){va=190}}do{if((va|0)==190){if(!(((c[U>>2]|0)-L|0)>>>0<$>>>0)){if((c[U>>2]|0)!=(L|0)){break}}c[a+1129276>>2]=1;t=w;R=t;if((c[R+164>>2]|0)!=0){Na=c[(c[R+160>>2]|0)+(-(c[R+156>>2]|0)<<2)>>2]|0}else{Na=0}R=Na;ea=t;if((c[ea+168>>2]|0)!=0){Oa=c[(c[ea+160>>2]|0)-4>>2]|0}else{Oa=0}ea=Oa;if((R|0)!=0){Pa=d[R+12|0]|0}else{Pa=0}if((ea|0)!=0){Qa=d[ea+12|0]|0}else{Qa=0}ea=g;c[ea>>2]=(c[ea>>2]|0)+(c[206872+(255-(d[y+15507+(Pa+Qa)|0]|0)<<2)>>2]|0);ea=n;c[ea>>2]=(c[T>>2]|0)+(c[U>>2]|0)<<4;c[ea+4>>2]=0;ea=n;R=wrc(c[S>>2]<<4,0,c[ea>>2]|0,c[ea+4>>2]|0)|0;ea=h;c[ea>>2]=R;c[ea+4>>2]=G;c[p>>2]=1;ea=c[g>>2]|0;R=c[a+75248>>2]|0;t=Erc(ea,(ea|0)<0|0?-1:0,R,(R|0)<0|0?-1:0)|0;R=wrc(128,0,t,G)|0;t=G;ea=h;r=yrc(c[ea>>2]|0,c[ea+4>>2]|0,c[a+75244>>2]|0)|0;ea=wrc(R>>>8|t<<24,t>>8|((t|0)<0|0?-1:0)<<24,r,G)|0;c[E>>2]=ea;c[E+4>>2]=G}}while(0)}}while(0)}}}}while(0)}else{if((v|0)!=0){p=v;c[p>>2]=0;c[p+4>>2]=0}p=h;c[p>>2]=0;c[p+4>>2]=0;c[a+1129276>>2]=1}}do{if((c[a+1129276>>2]|0)==0){c[X>>2]=-1;c[X+4>>2]=2147483647;c[Y>>2]=-1;c[Y+4>>2]=2147483647;p4b(Z,a,k,l,V,v,e,f,c[B>>2]|0,c[B+4>>2]|0);if((c[k>>2]|0)==2147483647){c[g>>2]=2147483647;p=h;c[p>>2]=-1;c[p+4>>2]=2147483647;p=w;S=I|0;U=J|0;T=0;while(1){if((T|0)>=3){break}c[p+(T*52|0)+16>>2]=c[S+(T<<2)>>2];c[p+(T*52|0)+20>>2]=c[U+(T<<2)>>2];T=T+1|0}c[A>>2]=-1;c[A+4>>2]=2147483647;ha=A|0;ia=c[ha>>2]|0;ja=A+4|0;ka=c[ja>>2]|0;i=z;return(G=ka,ia)|0}T=g;c[T>>2]=(c[T>>2]|0)+(c[k>>2]|0);T=l;U=h;p=wrc(c[U>>2]|0,c[U+4>>2]|0,c[T>>2]|0,c[T+4>>2]|0)|0;c[U>>2]=p;c[U+4>>2]=G;U=c[g>>2]|0;p=c[a+75248>>2]|0;T=Erc(U,(U|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;p=wrc(128,0,T,G)|0;T=G;U=h;S=yrc(c[U>>2]|0,c[U+4>>2]|0,c[a+75244>>2]|0)|0;U=wrc(p>>>8|T<<24,T>>8|((T|0)<0|0?-1:0)<<24,S,G)|0;c[Y>>2]=U;c[Y+4>>2]=G;U=c[Y>>2]|0;S=c[Y+4>>2]|0;T=c[a+75248>>2]|0;p=Erc(0,0,T,(T|0)<0|0?-1:0)|0;T=wrc(128,0,p,G)|0;p=G;Qa=v;Pa=yrc(c[Qa>>2]|0,c[Qa+4>>2]|0,c[a+75244>>2]|0)|0;Qa=wrc(T>>>8|p<<24,p>>8|((p|0)<0|0?-1:0)<<24,Pa,G)|0;Pa=G;if((S|0)<(Pa|0)|(S|0)==(Pa|0)&U>>>0<Qa>>>0){Ra=c[Y+4>>2]|0;Sa=c[Y>>2]|0}else{Qa=c[a+75248>>2]|0;U=Erc(0,0,Qa,(Qa|0)<0|0?-1:0)|0;Qa=wrc(128,0,U,G)|0;U=G;Pa=v;S=yrc(c[Pa>>2]|0,c[Pa+4>>2]|0,c[a+75244>>2]|0)|0;Pa=wrc(Qa>>>8|U<<24,U>>8|((U|0)<0|0?-1:0)<<24,S,G)|0;Ra=G;Sa=Pa}c[Y>>2]=Sa;c[Y+4>>2]=Ra;Pa=xrc(c[B>>2]|0,c[B+4>>2]|0,c[Y>>2]|0,c[Y+4>>2]|0)|0;b4b(Z,a,m,n,W,X,e,Pa,G);if((c[m>>2]|0)!=2147483647){Pa=v;S=wrc(c[Pa>>2]|0,c[Pa+4>>2]|0,c[X>>2]|0,c[X+4>>2]|0)|0;c[Pa>>2]=S;c[Pa+4>>2]=G;Pa=g;c[Pa>>2]=(c[Pa>>2]|0)+(c[m>>2]|0);Pa=n;S=h;U=wrc(c[S>>2]|0,c[S+4>>2]|0,c[Pa>>2]|0,c[Pa+4>>2]|0)|0;c[S>>2]=U;c[S+4>>2]=G;if((c[V>>2]|0)!=0){Ta=(c[W>>2]|0)!=0}else{Ta=0}c[j>>2]=Ta&1;break}c[g>>2]=2147483647;S=h;c[S>>2]=-1;c[S+4>>2]=2147483647;S=w;U=I|0;Pa=J|0;Qa=0;while(1){if((Qa|0)>=3){break}c[S+(Qa*52|0)+16>>2]=c[U+(Qa<<2)>>2];c[S+(Qa*52|0)+20>>2]=c[Pa+(Qa<<2)>>2];Qa=Qa+1|0}c[A>>2]=-1;c[A+4>>2]=2147483647;ha=A|0;ia=c[ha>>2]|0;ja=A+4|0;ka=c[ja>>2]|0;i=z;return(G=ka,ia)|0}}while(0);h=w;w=I|0;I=J|0;J=0;while(1){if((J|0)>=3){break}c[h+(J*52|0)+16>>2]=c[w+(J<<2)>>2];c[h+(J*52|0)+20>>2]=c[I+(J<<2)>>2];J=J+1|0}J=c[E+4>>2]|0;c[A>>2]=c[E>>2];c[A+4>>2]=J;ha=A|0;ia=c[ha>>2]|0;ja=A+4|0;ka=c[ja>>2]|0;i=z;return(G=ka,ia)|0}function Z3b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=b;b=d;d=f|0;g=f+24720|0;f=0;while(1){if((f|0)>=(b|0)){break}c[d+(f*8240|0)+8196>>2]=c[a+272+(f*12|0)+4>>2];c[d+(f*8240|0)+8192>>2]=c[a+308+(f*12|0)+4>>2];c[g+(f*52|0)>>2]=c[a+344+(f*12|0)+4>>2];c[d+(f*8240|0)+8200>>2]=c[a+380+(f*12|0)+4>>2];c[a+272+(f*12|0)+4>>2]=c[a+272+(f*12|0)>>2];c[a+308+(f*12|0)+4>>2]=c[a+308+(f*12|0)>>2];c[a+344+(f*12|0)+4>>2]=c[a+344+(f*12|0)>>2];c[a+380+(f*12|0)+4>>2]=c[a+380+(f*12|0)>>2];c[a+272+(f*12|0)>>2]=c[d+(f*8240|0)+8196>>2];c[a+308+(f*12|0)>>2]=c[d+(f*8240|0)+8192>>2];c[a+344+(f*12|0)>>2]=c[g+(f*52|0)>>2];c[a+380+(f*12|0)>>2]=c[d+(f*8240|0)+8200>>2];f=f+1|0}i=e;return}function _3b(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0;k=i;l=a;a=b;b=g;c[a+424>>2]=c[l+1129276>>2];c[a+476>>2]=d;nrc(a|0,c[c[l+24880>>2]>>2]|0,124)|0;c[a+428>>2]=c[e>>2];c[a+432>>2]=c[f>>2];c[a+496>>2]=c[b>>2];c[a+492>>2]=c[b+8>>2];c[a+488>>2]=c[b+16>>2];b=a+504|0;f=h;c[b>>2]=c[f>>2];c[b+4>>2]=c[f+4>>2];c[b+8>>2]=c[f+8>>2];c[b+12>>2]=c[f+12>>2];c[b+16>>2]=c[f+16>>2];c[b+20>>2]=c[f+20>>2];c[b+24>>2]=c[f+24>>2];c[b+28>>2]=c[f+28>>2];c[b+32>>2]=c[f+32>>2];c[b+36>>2]=c[f+36>>2];f=a+544|0;a=j;c[f>>2]=c[a>>2];c[f+4>>2]=c[a+4>>2];c[f+8>>2]=c[a+8>>2];c[f+12>>2]=c[a+12>>2];c[f+16>>2]=c[a+16>>2];c[f+20>>2]=c[a+20>>2];c[f+24>>2]=c[a+24>>2];c[f+28>>2]=c[a+28>>2];i=k;return}function $3b(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0;q=i;i=i+4152|0;r=q|0;s=q+8|0;t=q+16|0;u=q+240|0;v=q+336|0;w=q+344|0;x=q+352|0;y=q+376|0;z=q+400|0;A=q+432|0;B=q+464|0;C=q+544|0;D=q+560|0;E=q+576|0;F=q+584|0;H=q+592|0;I=q+600|0;J=q+608|0;K=q+616|0;L=q+624|0;M=q+632|0;N=q+696|0;O=q+744|0;P=q+752|0;Q=q+760|0;R=q+768|0;S=q+776|0;T=q+784|0;U=q+792|0;V=q+800|0;W=q+808|0;X=q+816|0;Y=q+824|0;Z=q+832|0;_=q+840|0;$=q+848|0;aa=q+856|0;ba=q+864|0;da=q+872|0;ea=q+880|0;fa=q+888|0;ga=q+1080|0;ha=q+1160|0;ia=q+4088|0;ja=q+4096|0;ka=q+4104|0;la=q+4112|0;ma=q+4120|0;na=q+4128|0;oa=q+4136|0;pa=q+4144|0;qa=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;c[s>>2]=o;c[s+4>>2]=p;p=qa+1434592|0;o=qa+1473304|0;n=e+24720|0;ra=c[c[n+160>>2]>>2]|0;sa=p+13408|0;ta=a[ra+13|0]|0;ua=c[s+4>>2]|0;c[v>>2]=c[s>>2];c[v+4>>2]=ua;ua=c[s+4>>2]|0;c[w>>2]=c[s>>2];c[w+4>>2]=ua;mrc(B|0,0,76)|0;ua=0;c[F>>2]=-1;c[F+4>>2]=2147483647;va=1;wa=4;c[L>>2]=0;xa=((ngc(c[p+10168>>2]|0,c[p+10172>>2]|0)|0)<<16>>16)*20|0;ya=0;za=0;Aa=0;if((c[qa+2046932>>2]|0)!=0){Ba=(c[e+75216>>2]|0)<115}else{Ba=0}c[e+1184592>>2]=Ba&1;mrc(e+1128252|0,0,4)|0;Ba=0;while(1){if((Ba|0)>=4){break}Ca=0;while(1){if((Ca|0)>=4){break}c[M+(Ba<<4)+(Ca<<2)>>2]=-2147450880;Ca=Ca+1|0}Ba=Ba+1|0}T3b(qa,ta&255,C|0,D|0,E);Ba=0;while(1){if((Ba|0)>=3){break}Ca=y+(Ba<<3)|0;c[Ca>>2]=-1;c[Ca+4>>2]=2147483647;Ba=Ba+1|0}Ba=0;while(1){if((Ba|0)>=4){break}Ca=z+(Ba<<3)|0;c[Ca>>2]=-1;c[Ca+4>>2]=2147483647;Ba=Ba+1|0}c[H>>2]=2147483647;c[j>>2]=2147483647;Ca=1;while(1){if((Ca|0)>3){break}if((c[qa+2046872>>2]&c[206792+(Ca<<2)>>2]|0)!=0){J3b(qa,e,f,Ca,l,g,h,t+160|0,t+176|0,u|0)}c[t+208+(Ca<<2)>>2]=-2147450880;c[t+192+(Ca<<2)>>2]=0;Ca=Ca+1|0}Ca=1;while(1){if((Ca|0)<=3){Da=(c[qa+2046956>>2]|0)!=0}else{Da=0}if(!Da){break}t=1;while(1){if((t|0)>3){break}if((c[e+75320+(Ca<<2)>>2]>>1|0)>(c[e+75320+(t<<2)>>2]|0)){Ea=32;break}t=t+1|0}if((Ea|0)==32){Ea=0;za=za|1<<Ca}Ca=Ca+1|0}za=0;a:while(1){if((za|0)>=6){break}Da=0;c[O>>2]=-1;c[O+4>>2]=2147483647;t=0;Fa=0;Ga=0;c[P>>2]=0;c[Q>>2]=0;c[R>>2]=0;c[R+4>>2]=0;c[S>>2]=0;c[S+4>>2]=0;c[T>>2]=0;c[T+4>>2]=0;c[U>>2]=0;Ha=0;c[V>>2]=2147483647;c[V+4>>2]=0;Ia=0;Ca=c[206744+(za<<3)>>2]|0;Ja=c[206748+(za<<3)>>2]|0;do{if((za|0)>2){if((c[qa+2046952>>2]|0)>=30){Ea=52;break}if((za|0)==3){switch(c[206744+(ua<<3)>>2]|0){case 0:{Aa=0;break};case 1:{Aa=16;break};case 2:{Aa=8;break};case 3:{Aa=0;break};case-1:case 4:{Ea=47;break a;break};default:{}}}if((Aa&1<<za|0)!=0){break}else{Ea=52;break}}else{Ea=52}}while(0);b:do{if((Ea|0)==52){Ea=0;Ka=c[v>>2]|0;La=c[v+4>>2]|0;Ma=c[o+14184+((ta&255)*312|0)+(l*24|0)+(za<<2)>>2]|0;Na=c[o+16680+(l*24|0)+(za<<2)>>2]|0;Oa=Erc(Ma,(Ma|0)<0|0?-1:0,Na,(Na|0)<0|0?-1:0)|0;Na=G;Ma=Na>>5|((Na|0)<0|0?-1:0)<<27;do{if(!((La|0)<(Ma|0)|(La|0)==(Ma|0)&Ka>>>0<(Oa>>>5|Na<<27)>>>0)){if((c[o+14184+((ta&255)*312|0)+(l*24|0)+(za<<2)>>2]|0)==2147483647){break}do{if((Ca|0)>0){if((c[qa+2046872>>2]&c[206792+(Ca<<2)>>2]|0)!=0){break}break b}}while(0);Pa=(Ja|0)>0|0;if((Pa|0)!=0){if((c[qa+2046872>>2]&c[206792+(Ja<<2)>>2]|0)==0){break b}if((Thc(sa,ta&255,2)|0)!=0){break b}do{if((c[qa+2047024>>2]&2|0)!=0){if((c[206744+(ua<<3)>>2]|0)!=0){break}break b}}while(0);do{if((c[qa+2047024>>2]&4|0)!=0){if((Ca|0)==(va|0)){break}if((Ja|0)==(va|0)){break}break b}}while(0)}do{if((Ca|0)>0){Qa=p+9816+(Ca-1<<6)+8|0;if((c[Qa>>2]|0)!=16384){Ra=1}else{Ra=(c[Qa+4>>2]|0)!=16384}if((Ra&1|0)==0){break}break b}}while(0);do{if((Ja|0)>0){Qa=p+9816+(Ja-1<<6)+8|0;if((c[Qa>>2]|0)!=16384){Sa=1}else{Sa=(c[Qa+4>>2]|0)!=16384}if((Sa&1|0)==0){break}break b}}while(0);if((Pa|0)!=0){if((Da|0)!=0){Ta=Da}else{Ta=(c[p+13536>>2]|0)==0|0}Da=Ta}else{if((Ca|0)!=0){if((Da|0)!=0){Ua=Da}else{Ua=(c[p+13536>>2]|0)==1|0}Da=Ua}}do{if((Thc(sa,ta&255,2)|0)!=0){if((Zhc(sa,ta&255,2)|0)==(Ca|0)){break}break b}}while(0);do{if((Thc(sa,ta&255,3)|0)!=0){if((Ca|0)==0){break}break b}}while(0);if((Thc(sa,ta&255,2)|0)==0){do{if((c[qa+2017236>>2]|0)!=0){if((c[qa+1471848>>2]|0)!=0){break}break b}}while(0)}c[ra+8>>2]=0;c[ra+16>>2]=0;c[ra+20>>2]=Ca;c[ra+24>>2]=Ja;if((c[p+10220>>2]|0)==4){Va=0}else{Va=c[p+10220>>2]|0}c[ra+72>>2]=Va;c[e+1129276>>2]=0;Qa=p;Wa=n;Xa=Ca;Ya=Ja;if((Xa|0)>=1){Za=Xa-1|0}else{Za=0}c[Wa+188>>2]=Qa+9816+(Za<<6);if((Ya|0)>=1){_a=Ya-1|0}else{_a=0}c[Wa+192>>2]=Qa+9816+(_a<<6);Qa=0;while(1){if((Qa|0)>=3){break}Wa=n+(Qa*52|0)+24|0;Ya=u+(Ca*24|0)+(Qa<<3)|0;c[Wa>>2]=c[Ya>>2];c[Wa+4>>2]=c[Ya+4>>2];if((Pa|0)!=0){Ya=n+(Qa*52|0)+32|0;Wa=u+(Ja*24|0)+(Qa<<3)|0;c[Ya>>2]=c[Wa>>2];c[Ya+4>>2]=c[Wa+4>>2]}Qa=Qa+1|0}if((Ca|0)==0){Wa=R3b(qa,e,W,P,S,c[v>>2]|0,c[v+4>>2]|0)|0;Ya=G;Xa=c[v+4>>2]|0;if((Ya|0)>=(Xa|0)&((Ya|0)>(Xa|0)|Wa>>>0>=(c[v>>2]|0)>>>0)){break b}Ga=Ga+(c[W>>2]|0)|0;Ga=Ga+xa|0;Wa=wrc(c[R>>2]|0,c[R+4>>2]|0,c[S>>2]|0,c[S+4>>2]|0)|0;c[R>>2]=Wa;c[R+4>>2]=G;if((c[H>>2]|0)==2147483647){X3b(qa,m,l,0,H,I,J,K,L)}Ga=Ga+(c[H>>2]|0)|0;c[Q>>2]=c[I>>2];Wa=wrc(c[R>>2]|0,c[R+4>>2]|0,c[J>>2]|0,c[J+4>>2]|0)|0;c[R>>2]=Wa;c[R+4>>2]=G;Wa=c[J+4>>2]|0;c[T>>2]=c[J>>2];c[T+4>>2]=Wa;c[ra+16>>2]=c[L>>2]}else{c[$>>2]=-1;c[$+4>>2]=2147483647;c[aa>>2]=-1;c[aa+4>>2]=2147483647;Wa=2147483647;Xa=2147483647;c[ba>>2]=2147483647;c[ba+4>>2]=0;Ya=0;if((Pa|0)!=0){$a=ra+36+(Ja<<3)|0}else{$a=0}ab=$a;bb=0;if((Ca|0)==1){cb=c[o+14184+((ta&255)*312|0)+(l*24|0)>>2]|0}else{cb=c[o+14184+((ta&255)*312|0)+(l*24|0)+8>>2]|0}c[Z>>2]=cb;c[Z+4>>2]=(cb|0)<0|0?-1:0;if((Ca|0)==2){db=c[o+14184+((ta&255)*312|0)+(l*24|0)+4>>2]|0;eb=(db|0)<0|0?-1:0;fb=db}else{eb=c[Z+4>>2]|0;fb=c[Z>>2]|0}c[Z>>2]=fb;c[Z+4>>2]=eb;db=o+17424|0;c[db>>2]=0;c[db+4>>2]=0;Qa=0;while(1){if((Qa|0)>=4){break}db=o+17392+(Qa<<3)|0;c[db>>2]=-1;c[db+4>>2]=2147483647;Qa=Qa+1|0}if((c[p+10220>>2]|0)!=3){wa=0;if((c[e+75300>>2]|0)>>>0<(c[qa+2047032>>2]|0)>>>0){wa=0}else{do{if((c[qa+2047008>>2]|0)==1){if(!((c[m+592>>2]|0)>>>0<4>>>0)){Ea=145;break}wa=c[m+592>>2]|0}else{Ea=145}}while(0);if((Ea|0)==145){Ea=0;if((c[qa+2047008>>2]|0)==2){if((c[m+592>>2]|0)>>>0<4>>>0){gb=c[m+592>>2]|0}else{gb=0}wa=gb}else{db=0;c:while(1){if((db|0)>=3){break}c[ra+72>>2]=db;hb=a4b(qa,e,f,ra+36+(Ca<<3)|0,ab,c[w>>2]|0,c[w+4>>2]|0,X,P,Y,U,V,c[Z>>2]|0,M|0,ha|0,db,g,h)|0;c[_>>2]=hb;c[_+4>>2]=G;if(!((c[_>>2]|0)==(-1|0)&(c[_+4>>2]|0)==2147483647)){hb=N3b(e)|0;ib=c[e+75248>>2]|0;jb=Erc(hb,(hb|0)<0|0?-1:0,ib,(ib|0)<0|0?-1:0)|0;ib=wrc(128,0,jb,G)|0;jb=G;hb=0<<c[e+75244>>2];kb=wrc(ib>>>8|jb<<24,jb>>8|((jb|0)<0|0?-1:0)<<24,hb,(hb|0)<0|0?-1:0)|0;c[ja>>2]=kb;c[ja+4>>2]=G;kb=c[_+4>>2]|0;hb=o+17392+(db<<3)|0;c[hb>>2]=c[_>>2];c[hb+4>>2]=kb;kb=o+17416|0;hb=c[kb>>2]|0;jb=c[kb+4>>2]|0;kb=wrc(c[_>>2]|0,c[_+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;ib=G;if((jb|0)<(ib|0)|(jb|0)==(ib|0)&hb>>>0<kb>>>0){kb=o+17416|0;lb=c[kb+4>>2]|0;mb=c[kb>>2]|0}else{kb=wrc(c[_>>2]|0,c[_+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;lb=G;mb=kb}kb=o+17416|0;c[kb>>2]=mb;c[kb+4>>2]=lb;if((c[p+10220>>2]|0)==4){kb=wrc(c[_>>2]|0,c[_+4>>2]|0,c[ja>>2]|0,c[ja+4>>2]|0)|0;c[_>>2]=kb;c[_+4>>2]=G}kb=o+17424|0;hb=c[kb+4>>2]|0;ib=c[_+4>>2]|0;if((hb|0)>(ib|0)|(hb|0)==(ib|0)&(c[kb>>2]|0)>>>0>(c[_>>2]|0)>>>0){kb=o+17424|0;nb=c[kb+4>>2]|0;ob=c[kb>>2]|0}else{nb=c[_+4>>2]|0;ob=c[_>>2]|0}kb=o+17424|0;c[kb>>2]=ob;c[kb+4>>2]=nb;kb=c[_+4>>2]|0;ib=c[$+4>>2]|0;hb=((kb|0)<(ib|0)|(kb|0)==(ib|0)&(c[_>>2]|0)>>>0<(c[$>>2]|0)>>>0)&1;if((hb|0)!=0){wa=c[ra+72>>2]|0;ib=c[_+4>>2]|0;c[$>>2]=c[_>>2];c[$+4>>2]=ib}if((hb|0)!=0){if((c[p+10220>>2]|0)==4){Ea=168}else{Ea=166}}else{Ea=166}do{if((Ea|0)==166){Ea=0;if((c[ra+72>>2]|0)!=(c[p+10220>>2]|0)){break}if((c[p+10220>>2]|0)!=4){Ea=168}}}while(0);if((Ea|0)==168){Ea=0;hb=c[_+4>>2]|0;c[aa>>2]=c[_>>2];c[aa+4>>2]=hb;Wa=c[X>>2]|0;Xa=c[P>>2]|0;hb=c[Y+4>>2]|0;c[ba>>2]=c[Y>>2];c[ba+4>>2]=hb;hb=c[V+4>>2]|0;c[da>>2]=c[V>>2];c[da+4>>2]=hb;Ya=c[U>>2]|0;nrc(ga|0,ra|0,76)|0;Qa=0;while(1){if((Qa|0)>=4){break}hb=fa+(Qa*12|0)|0;ib=(c[c[n+160>>2]>>2]|0)+76+(Qa*12|0)|0;c[hb>>2]=c[ib>>2];c[hb+4>>2]=c[ib+4>>2];c[hb+8>>2]=c[ib+8>>2];a[e+1128252+Qa|0]=((b[(c[e+8200>>2]|0)+(Qa<<1)>>1]|0)!=0^1)&1;Qa=Qa+1|0}bb=1;do{if((db|0)==0){if((c[qa+2047068>>2]|0)==0){break}ib=c[v+4>>2]|0;hb=2147483647;if(!((ib|0)<(hb|0)|(ib|0)==(hb|0)&(c[v>>2]|0)>>>0<-1>>>0)){break}hb=Crc(c[aa>>2]|0,c[aa+4>>2]|0,2,0)|0;ib=G;kb=c[v+4>>2]|0;if((ib|0)>(kb|0)|(ib|0)==(kb|0)&hb>>>0>(c[v>>2]|0)>>>0){Ea=176;break c}}}while(0)}}db=db+1|0}if((Ea|0)==176){Ea=0;wa=c[ra+72>>2]|0;c[aa>>2]=-1;c[aa+4>>2]=2147483647}}}}}do{if((c[aa>>2]|0)==(-1|0)&(c[aa+4>>2]|0)==2147483647){if((bb|0)==0){break}break b}}while(0);if((c[p+10220>>2]|0)==4){pb=wa}else{pb=c[p+10220>>2]|0}c[ra+72>>2]=pb;do{if((bb|0)!=0){db=c[da+4>>2]|0;c[V>>2]=c[da>>2];c[V+4>>2]=db;c[X>>2]=Wa;c[P>>2]=Xa;db=c[ba+4>>2]|0;c[Y>>2]=c[ba>>2];c[Y+4>>2]=db;c[U>>2]=Ya;nrc(ra|0,ga|0,76)|0;Qa=0;while(1){if((Qa|0)>=4){break}db=(c[c[n+160>>2]>>2]|0)+76+(Qa*12|0)|0;hb=fa+(Qa*12|0)|0;c[db>>2]=c[hb>>2];c[db+4>>2]=c[hb+4>>2];c[db+8>>2]=c[hb+8>>2];Qa=Qa+1|0}}else{hb=a4b(qa,e,f,ra+36+(Ca<<3)|0,ab,c[w>>2]|0,c[w+4>>2]|0,X,P,Y,U,V,c[Z>>2]|0,M|0,ha|0,0,g,h)|0;c[_>>2]=hb;c[_+4>>2]=G;if((c[_>>2]|0)==(-1|0)&(c[_+4>>2]|0)==2147483647){break b}else{break}}}while(0);Ga=Ga+(c[X>>2]|0)|0;ab=wrc(c[R>>2]|0,c[R+4>>2]|0,c[Y>>2]|0,c[Y+4>>2]|0)|0;c[R>>2]=ab;c[R+4>>2]=G;if((c[p+10220>>2]|0)==4){Ga=Ga+(N3b(e)|0)|0}if((Da|0)==0){if((Pa|0)!=0){qb=(c[p+13536>>2]|0)==0|0}else{qb=(c[p+13536>>2]|0)==1|0}Da=qb}if((Pa|0)!=0){rb=255-(d[E]|0)|0}else{rb=d[E]|0}Fa=c[206872+(rb<<2)>>2]|0;ab=c[v>>2]|0;Ya=c[v+4>>2]|0;Xa=Ga;Wa=c[e+75248>>2]|0;bb=Erc(Xa,(Xa|0)<0|0?-1:0,Wa,(Wa|0)<0|0?-1:0)|0;Wa=wrc(128,0,bb,G)|0;bb=G;Xa=yrc(c[R>>2]|0,c[R+4>>2]|0,c[e+75244>>2]|0)|0;hb=wrc(Wa>>>8|bb<<24,bb>>8|((bb|0)<0|0?-1:0)<<24,Xa,G)|0;Xa=G;bb=c[e+75248>>2]|0;Wa=Erc(0,0,bb,(bb|0)<0|0?-1:0)|0;bb=wrc(128,0,Wa,G)|0;Wa=G;db=yrc(c[V>>2]|0,c[V+4>>2]|0,c[e+75244>>2]|0)|0;kb=wrc(bb>>>8|Wa<<24,Wa>>8|((Wa|0)<0|0?-1:0)<<24,db,G)|0;db=G;if((Xa|0)<(db|0)|(Xa|0)==(db|0)&hb>>>0<kb>>>0){kb=Ga;hb=c[e+75248>>2]|0;db=Erc(kb,(kb|0)<0|0?-1:0,hb,(hb|0)<0|0?-1:0)|0;hb=wrc(128,0,db,G)|0;db=G;kb=yrc(c[R>>2]|0,c[R+4>>2]|0,c[e+75244>>2]|0)|0;Xa=wrc(hb>>>8|db<<24,db>>8|((db|0)<0|0?-1:0)<<24,kb,G)|0;sb=G;tb=Xa}else{Xa=c[e+75248>>2]|0;kb=Erc(0,0,Xa,(Xa|0)<0|0?-1:0)|0;Xa=wrc(128,0,kb,G)|0;kb=G;db=yrc(c[V>>2]|0,c[V+4>>2]|0,c[e+75244>>2]|0)|0;hb=wrc(Xa>>>8|kb<<24,kb>>8|((kb|0)<0|0?-1:0)<<24,db,G)|0;sb=G;tb=hb}hb=xrc(ab,Ya,tb,sb)|0;c[aa>>2]=hb;c[aa+4>>2]=G;hb=c[aa+4>>2]|0;Ya=0;if((hb|0)>(Ya|0)|(hb|0)==(Ya|0)&(c[aa>>2]|0)>>>0>0>>>0){vgc(e+24720|0,g,h,3);b4b(qa,e,Q,T,ia,ea,3,c[aa>>2]|0,c[aa+4>>2]|0);if((c[Q>>2]|0)==2147483647){break b}Ga=Ga+(c[Q>>2]|0)|0;Ya=wrc(c[R>>2]|0,c[R+4>>2]|0,c[T>>2]|0,c[T+4>>2]|0)|0;c[R>>2]=Ya;c[R+4>>2]=G;if((c[U>>2]|0)!=0){ub=(c[ia>>2]|0)!=0}else{ub=0}c[U>>2]=ub&1;Ya=wrc(c[V>>2]|0,c[V+4>>2]|0,c[ea>>2]|0,c[ea+4>>2]|0)|0;c[V>>2]=Ya;c[V+4>>2]=G}}if((c[p+13536>>2]|0)==2){Ga=Ga+Fa|0}if((Ja|0)>0){Ga=Ga+(c[D+(Ca<<2)>>2]|0)|0}else{Ga=Ga+(c[C+(Ca<<2)>>2]|0)|0}if((t|0)==0){Ya=((Thc(sa,ta&255,3)|0)!=0^1)&1;do{if((Ya|0)!=0){if((Ca|0)==0){Ea=259;break}if((c[n+25808>>2]|0)!=0){Ea=259;break}hb=c[P>>2]|0;ab=c[Q>>2]|0;db=wrc(hb,(hb|0)<0|0?-1:0,ab,(ab|0)<0|0?-1:0)|0;ab=c[e+75248>>2]|0;hb=Erc(db,G,ab,(ab|0)<0|0?-1:0)|0;ab=wrc(128,0,hb,G)|0;hb=G;db=yrc(c[R>>2]|0,c[R+4>>2]|0,c[e+75244>>2]|0)|0;kb=wrc(ab>>>8|hb<<24,hb>>8|((hb|0)<0|0?-1:0)<<24,db,G)|0;db=G;hb=c[e+75248>>2]|0;ab=Erc(0,0,hb,(hb|0)<0|0?-1:0)|0;hb=wrc(128,0,ab,G)|0;ab=G;Xa=yrc(c[V>>2]|0,c[V+4>>2]|0,c[e+75244>>2]|0)|0;Wa=wrc(hb>>>8|ab<<24,ab>>8|((ab|0)<0|0?-1:0)<<24,Xa,G)|0;Xa=G;if((db|0)<(Xa|0)|(db|0)==(Xa|0)&kb>>>0<Wa>>>0){Wa=n;kb=Wa;if((c[kb+164>>2]|0)!=0){vb=c[(c[kb+160>>2]|0)+(-(c[kb+156>>2]|0)<<2)>>2]|0}else{vb=0}kb=vb;Xa=Wa;if((c[Xa+168>>2]|0)!=0){wb=c[(c[Xa+160>>2]|0)-4>>2]|0}else{wb=0}Xa=wb;if((kb|0)!=0){xb=d[kb+12|0]|0}else{xb=0}if((Xa|0)!=0){yb=d[Xa+12|0]|0}else{yb=0}Ga=Ga+(c[206872+(d[p+15507+(xb+yb)|0]<<2)>>2]|0)|0}else{Xa=n;kb=Xa;if((c[kb+164>>2]|0)!=0){zb=c[(c[kb+160>>2]|0)+(-(c[kb+156>>2]|0)<<2)>>2]|0}else{zb=0}kb=zb;Wa=Xa;if((c[Wa+168>>2]|0)!=0){Ab=c[(c[Wa+160>>2]|0)-4>>2]|0}else{Ab=0}Wa=Ab;if((kb|0)!=0){Bb=d[kb+12|0]|0}else{Bb=0}if((Wa|0)!=0){Cb=d[Wa+12|0]|0}else{Cb=0}Ga=Ga+(c[206872+(255-(d[p+15507+(Bb+Cb)|0]|0)<<2)>>2]|0)|0;Wa=c[V+4>>2]|0;c[R>>2]=c[V>>2];c[R+4>>2]=Wa;Wa=c[V+4>>2]|0;kb=0;if((Wa|0)>=(kb|0)&((Wa|0)>(kb|0)|(c[V>>2]|0)>>>0>=0>>>0)){}else{Cd(2283064,2558456,4191,2650152);return 0}Ga=Ga-((c[P>>2]|0)+(c[Q>>2]|0))|0;c[P>>2]=0;c[Q>>2]=0;Ha=1}}else{Ea=259}}while(0);if((Ea|0)==259){Ea=0;if((Ya|0)!=0){kb=n;Wa=kb;if((c[Wa+164>>2]|0)!=0){Db=c[(c[Wa+160>>2]|0)+(-(c[Wa+156>>2]|0)<<2)>>2]|0}else{Db=0}Wa=Db;Xa=kb;if((c[Xa+168>>2]|0)!=0){Eb=c[(c[Xa+160>>2]|0)-4>>2]|0}else{Eb=0}Xa=Eb;if((Wa|0)!=0){Fb=d[Wa+12|0]|0}else{Fb=0}if((Xa|0)!=0){Gb=d[Xa+12|0]|0}else{Gb=0}Ga=Ga+(c[206872+(d[p+15507+(Fb+Gb)|0]<<2)>>2]|0)|0}}Xa=Ga;Wa=c[e+75248>>2]|0;kb=Erc(Xa,(Xa|0)<0|0?-1:0,Wa,(Wa|0)<0|0?-1:0)|0;Wa=wrc(128,0,kb,G)|0;kb=G;Xa=yrc(c[R>>2]|0,c[R+4>>2]|0,c[e+75244>>2]|0)|0;db=wrc(Wa>>>8|kb<<24,kb>>8|((kb|0)<0|0?-1:0)<<24,Xa,G)|0;c[O>>2]=db;c[O+4>>2]=G}do{if(((c[ra+20>>2]|0)>0|0)!=0){if(((c[ra+24>>2]|0)>0|0)!=0){break}if((Da|0)!=0){break}db=c[O+4>>2]|0;Xa=c[F+4>>2]|0;if(!((db|0)<(Xa|0)|(db|0)==(Xa|0)&(c[O>>2]|0)>>>0<(c[F>>2]|0)>>>0)){break}Xa=c[O+4>>2]|0;c[F>>2]=c[O>>2];c[F+4>>2]=Xa;va=Ca}}while(0);do{if((t|0)==0){if((Ca|0)!=0){break}Qa=0;while(1){if((Qa|0)>=3){break}Ya=y+(Qa<<3)|0;Xa=c[Ya+4>>2]|0;db=c[O+4>>2]|0;if((Xa|0)<(db|0)|(Xa|0)==(db|0)&(c[Ya>>2]|0)>>>0<(c[O>>2]|0)>>>0){Ya=y+(Qa<<3)|0;Hb=c[Ya+4>>2]|0;Ib=c[Ya>>2]|0}else{Hb=c[O+4>>2]|0;Ib=c[O>>2]|0}Ya=y+(Qa<<3)|0;c[Ya>>2]=Ib;c[Ya+4>>2]=Hb;Qa=Qa+1|0}Qa=0;while(1){if((Qa|0)>=4){break}Ya=z+(Qa<<3)|0;db=c[Ya+4>>2]|0;Xa=c[O+4>>2]|0;if((db|0)<(Xa|0)|(db|0)==(Xa|0)&(c[Ya>>2]|0)>>>0<(c[O>>2]|0)>>>0){Ya=z+(Qa<<3)|0;Jb=c[Ya+4>>2]|0;Kb=c[Ya>>2]|0}else{Jb=c[O+4>>2]|0;Kb=c[O>>2]|0}Ya=z+(Qa<<3)|0;c[Ya>>2]=Kb;c[Ya+4>>2]=Jb;Qa=Qa+1|0}}}while(0);Ya=c[O+4>>2]|0;Xa=c[v+4>>2]|0;if((Ya|0)<(Xa|0)|(Ya|0)==(Xa|0)&(c[O>>2]|0)>>>0<(c[v>>2]|0)>>>0){Ea=299}else{if((c[e+1129276>>2]|0)!=0){Ea=299}}if((Ea|0)==299){Ea=0;if((Da|0)==0){Xa=3;ua=za;if((Ca|0)==0){c[ra+28>>2]=0;Xa=1}c[j>>2]=Ga;Ya=c[R+4>>2]|0;db=k;c[db>>2]=c[R>>2];c[db+4>>2]=Ya;Ya=c[O+4>>2]|0;c[v>>2]=c[O>>2];c[v+4>>2]=Ya;Ya=c[v>>2]|0;db=c[v+4>>2]|0;kb=c[Q>>2]|0;Wa=c[e+75248>>2]|0;ab=Erc(kb,(kb|0)<0|0?-1:0,Wa,(Wa|0)<0|0?-1:0)|0;Wa=wrc(128,0,ab,G)|0;ab=G;kb=yrc(c[T>>2]|0,c[T+4>>2]|0,c[e+75244>>2]|0)|0;hb=wrc(Wa>>>8|ab<<24,ab>>8|((ab|0)<0|0?-1:0)<<24,kb,G)|0;kb=xrc(Ya,db,hb,G)|0;c[w>>2]=kb;c[w+4>>2]=G;nrc(B|0,ra|0,76)|0;ya=Ha;if((c[e+75204>>2]|0)==0){Z3b(e,m,Xa)}nrc(c[m+124>>2]|0,e+1128252|0,c[m+420>>2]|0)|0;Qa=0;while(1){if((Qa|0)>=4){break}Xa=N+(Qa*12|0)|0;kb=(c[c[n+160>>2]>>2]|0)+76+(Qa*12|0)|0;c[Xa>>2]=c[kb>>2];c[Xa+4>>2]=c[kb+4>>2];c[Xa+8>>2]=c[kb+8>>2];Qa=Qa+1|0}do{if((c[qa+2047024>>2]&1|0)!=0){if((za|0)<=3){break}kb=b[(c[n+40>>2]|0)+2>>1]|0;Xa=4;if((c[e+75300>>2]|0)>>>0<4294967295>>>0){Xa=Xa-((c[e+75300>>2]|0)>>>0<16>>>0)|0}do{if((Ca|0)>0){hb=Xa;db=Erc(c[R>>2]|0,c[R+4>>2]|0,hb,(hb|0)<0|0?-1:0)|0;hb=G;Ya=ca(kb,kb)|0;ab=(Ya|0)<0|0?-1:0;if(!((hb|0)<(ab|0)|(hb|0)==(ab|0)&db>>>0<Ya>>>0)){break}Ia=1}}while(0)}}while(0)}}do{if((t|0)==0){if((Ca|0)==0){break}if((c[p+13536>>2]|0)==2){kb=Ga-Fa|0;c[ma>>2]=kb;c[ma+4>>2]=(kb|0)<0|0?-1:0;kb=Ga;c[na>>2]=kb;c[na+4>>2]=(kb|0)<0|0?-1:0}else{kb=Ga;c[ma>>2]=kb;c[ma+4>>2]=(kb|0)<0|0?-1:0;kb=Ga+Fa|0;c[na>>2]=kb;c[na+4>>2]=(kb|0)<0|0?-1:0}kb=c[e+75248>>2]|0;Xa=Erc(c[ma>>2]|0,c[ma+4>>2]|0,kb,(kb|0)<0|0?-1:0)|0;kb=wrc(128,0,Xa,G)|0;Xa=G;Ya=yrc(c[R>>2]|0,c[R+4>>2]|0,c[e+75244>>2]|0)|0;db=wrc(kb>>>8|Xa<<24,Xa>>8|((Xa|0)<0|0?-1:0)<<24,Ya,G)|0;c[ka>>2]=db;c[ka+4>>2]=G;db=c[e+75248>>2]|0;Ya=Erc(c[na>>2]|0,c[na+4>>2]|0,db,(db|0)<0|0?-1:0)|0;db=wrc(128,0,Ya,G)|0;Ya=G;Xa=yrc(c[R>>2]|0,c[R+4>>2]|0,c[e+75244>>2]|0)|0;kb=wrc(db>>>8|Ya<<24,Ya>>8|((Ya|0)<0|0?-1:0)<<24,Xa,G)|0;c[la>>2]=kb;c[la+4>>2]=G;do{if((Pa|0)!=0){Ea=326}else{kb=c[ka+4>>2]|0;Xa=y|0;Ya=c[Xa+4>>2]|0;if(!((kb|0)<(Ya|0)|(kb|0)==(Ya|0)&(c[ka>>2]|0)>>>0<(c[Xa>>2]|0)>>>0)){Ea=326;break}Xa=c[ka+4>>2]|0;Ya=y|0;c[Ya>>2]=c[ka>>2];c[Ya+4>>2]=Xa}}while(0);if((Ea|0)==326){Ea=0;do{if((Pa|0)!=0){Xa=c[ka+4>>2]|0;Ya=y+8|0;kb=c[Ya+4>>2]|0;if(!((Xa|0)<(kb|0)|(Xa|0)==(kb|0)&(c[ka>>2]|0)>>>0<(c[Ya>>2]|0)>>>0)){break}Ya=c[ka+4>>2]|0;kb=y+8|0;c[kb>>2]=c[ka>>2];c[kb+4>>2]=Ya}}while(0)}Ya=c[la+4>>2]|0;kb=y+16|0;Xa=c[kb+4>>2]|0;if((Ya|0)<(Xa|0)|(Ya|0)==(Xa|0)&(c[la>>2]|0)>>>0<(c[kb>>2]|0)>>>0){kb=c[la+4>>2]|0;Xa=y+16|0;c[Xa>>2]=c[la>>2];c[Xa+4>>2]=kb}}}while(0);do{if((Da|0)==0){if((t|0)!=0){break}if((Ca|0)==0){break}if((c[p+10220>>2]|0)==3){break}if((c[p+10220>>2]|0)==4){Lb=3}else{Lb=c[p+10220>>2]|0}kb=o+17392+(Lb<<3)|0;Xa=c[kb+4>>2]|0;c[oa>>2]=c[kb>>2];c[oa+4>>2]=Xa;Qa=0;while(1){if((Qa|0)>=4){break}if((c[oa>>2]|0)==(-1|0)&(c[oa+4>>2]|0)==2147483647){c[pa>>2]=0;c[pa+4>>2]=0}else{Xa=o+17392+(Qa<<3)|0;if((c[Xa>>2]|0)==(-1|0)&(c[Xa+4>>2]|0)==2147483647){Xa=o+17424|0;kb=xrc(c[Xa>>2]|0,c[Xa+4>>2]|0,c[oa>>2]|0,c[oa+4>>2]|0)|0;Xa=wrc(kb,G,10,0)|0;c[pa>>2]=Xa;c[pa+4>>2]=G}else{Xa=o+17392+(Qa<<3)|0;kb=xrc(c[Xa>>2]|0,c[Xa+4>>2]|0,c[oa>>2]|0,c[oa+4>>2]|0)|0;c[pa>>2]=kb;c[pa+4>>2]=G}}kb=wrc(c[pa>>2]|0,c[pa+4>>2]|0,c[O>>2]|0,c[O+4>>2]|0)|0;c[pa>>2]=kb;c[pa+4>>2]=G;kb=z+(Qa<<3)|0;Xa=c[kb+4>>2]|0;Ya=c[pa+4>>2]|0;if((Xa|0)<(Ya|0)|(Xa|0)==(Ya|0)&(c[kb>>2]|0)>>>0<(c[pa>>2]|0)>>>0){kb=z+(Qa<<3)|0;Mb=c[kb+4>>2]|0;Nb=c[kb>>2]|0}else{Mb=c[pa+4>>2]|0;Nb=c[pa>>2]|0}kb=z+(Qa<<3)|0;c[kb>>2]=Nb;c[kb+4>>2]=Mb;Qa=Qa+1|0}}}while(0);if((Ia|0)!=0){Ea=355;break a}if((c[e+1129276>>2]|0)!=0){if((Pa|0)==0){Ea=358;break a}}break b}}while(0)}}while(0);za=za+1|0}if((Ea|0)==47){Cd(2342608,2558456,3875,2650152);return 0}Ea=c[v+4>>2]|0;Mb=c[s+4>>2]|0;if((Ea|0)>=(Mb|0)&((Ea|0)>(Mb|0)|(c[v>>2]|0)>>>0>=(c[s>>2]|0)>>>0)){c[r>>2]=-1;c[r+4>>2]=2147483647;Ob=r|0;Pb=c[Ob>>2]|0;Qb=r+4|0;Rb=c[Qb>>2]|0;i=q;return(G=Rb,Pb)|0}if((c[qa+2047072>>2]|0)!=0){if((c[206744+(ua<<3)>>2]|0)==0){nrc(ra|0,B|0,76)|0;Q3b(qa,e,m,H,I,J,K,3,0)|0;}}if((c[v>>2]|0)==(-1|0)&(c[v+4>>2]|0)==2147483647){c[j>>2]=2147483647;j=k;c[j>>2]=-1;c[j+4>>2]=2147483647;j=c[v+4>>2]|0;c[r>>2]=c[v>>2];c[r+4>>2]=j;Ob=r|0;Pb=c[Ob>>2]|0;Qb=r+4|0;Rb=c[Qb>>2]|0;i=q;return(G=Rb,Pb)|0}do{if((c[p+10220>>2]|0)==4){Sb=1}else{if((c[p+10220>>2]|0)==(c[B+72>>2]|0)){Sb=1;break}if(((c[B+20>>2]|0)>0|0)==0){Sb=1;break}Cd(2233664,2558456,4347,2650152);return 0}}while(0);if((c[qa+2046924>>2]|0)!=0){za=0;while(1){if((za|0)>=6){break}Sb=o+16680+(l*24|0)+(za<<2)|0;if((za|0)==(ua|0)){j=Sb;c[j>>2]=(c[j>>2]|0)-(c[Sb>>2]>>3)}else{if(((c[Sb>>2]|0)+1|0)<(c[qa+2046924>>2]<<6|0)){Tb=(c[Sb>>2]|0)+1|0}else{Tb=c[qa+2046924>>2]<<6}c[Sb>>2]=Tb}za=za+1|0}}nrc(ra|0,B|0,76)|0;za=e+1129276|0;c[za>>2]=c[za>>2]|ya;if(((c[B+20>>2]|0)>0|0)!=0){Ba=0;while(1){if((Ba|0)>=4){break}B=(c[c[n+160>>2]>>2]|0)+76+(Ba*12|0)|0;ya=N+(Ba*12|0)|0;c[B>>2]=c[ya>>2];c[B+4>>2]=c[ya+4>>2];c[B+8>>2]=c[ya+8>>2];Ba=Ba+1|0}c[ra+28>>2]=c[(c[c[n+160>>2]>>2]|0)+116>>2];c[ra+32>>2]=c[(c[c[n+160>>2]>>2]|0)+120>>2]}else{Ba=0;while(1){if((Ba|0)>=4){break}c[(c[c[n+160>>2]>>2]|0)+76+(Ba*12|0)>>2]=c[N+(Ba*12|0)>>2];Ba=Ba+1|0}}Ba=0;while(1){if((Ba|0)>=3){break}N=y+(Ba<<3)|0;if((c[N>>2]|0)==(-1|0)&(c[N+4>>2]|0)==2147483647){N=x+(Ba<<3)|0;c[N>>2]=-2147483648;c[N+4>>2]=-1}else{N=y+(Ba<<3)|0;ya=xrc(c[v>>2]|0,c[v+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;N=x+(Ba<<3)|0;c[N>>2]=ya;c[N+4>>2]=G}Ba=Ba+1|0}if((c[e+1129276>>2]|0)!=0){mrc(A|0,0,32)|0}else{Ba=0;while(1){if((Ba|0)>=4){break}y=z+(Ba<<3)|0;if((c[y>>2]|0)==(-1|0)&(c[y+4>>2]|0)==2147483647){y=A+(Ba<<3)|0;c[y>>2]=0;c[y+4>>2]=0}else{y=z+(Ba<<3)|0;N=xrc(c[v>>2]|0,c[v+4>>2]|0,c[y>>2]|0,c[y+4>>2]|0)|0;y=A+(Ba<<3)|0;c[y>>2]=N;c[y+4>>2]=G}Ba=Ba+1|0}if((c[p+10220>>2]|0)==4){Ba=A+24|0;if((c[Ba>>2]|0)==0&(c[Ba+4>>2]|0)==0){}else{Cd(2194232,2558456,4396,2650152);return 0}}}Ba=p;p=n;n=c[ra+20>>2]|0;z=c[ra+24>>2]|0;if((n|0)>=1){Ub=n-1|0}else{Ub=0}c[p+188>>2]=Ba+9816+(Ub<<6);if((z|0)>=1){Vb=z-1|0}else{Vb=0}c[p+192>>2]=Ba+9816+(Vb<<6);if((c[ra+24>>2]|0)<0){Wb=0}else{Wb=c[ra+24>>2]|0}_3b(e,m,ua,ra+36+(c[ra+20>>2]<<3)|0,ra+36+(Wb<<3)|0,x|0,3345296,A|0);A=c[v+4>>2]|0;c[r>>2]=c[v>>2];c[r+4>>2]=A;Ob=r|0;Pb=c[Ob>>2]|0;Qb=r+4|0;Rb=c[Qb>>2]|0;i=q;return(G=Rb,Pb)|0}function a4b(a,d,e,f,g,h,j,k,l,m,n,o,p,q,r,s,t,u){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;t=t|0;u=u|0;var v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;v=i;i=i+16|0;w=v|0;x=v+8|0;y=a;a=d;d=e;e=f;c[x>>2]=h;c[x+4>>2]=j;j=k;k=l;l=m;m=n;n=o;o=q;q=r;r=s;s=t;t=u;u=q+(r*976|0)|0;h=c[c[a+24880>>2]>>2]|0;f=h|0;mrc(u|0,0,976)|0;z=c[x+4>>2]|0;A=u+16|0;c[A>>2]=c[x>>2];c[A+4>>2]=z;c[u>>2]=e;c[u+4>>2]=g;c[u+8>>2]=c[e>>2];c[u+968>>2]=p;p=0;while(1){if((p|0)>=4){break}c[u+52+(p<<2)>>2]=12;p=p+1|0}g4b(y,a,d,q,r,o,s,t);t=u+16|0;s=c[t+4>>2]|0;o=c[x+4>>2]|0;if((s|0)>(o|0)|(s|0)==(o|0)&(c[t>>2]|0)>>>0>(c[x>>2]|0)>>>0){c[w>>2]=-1;c[w+4>>2]=2147483647;B=w|0;C=c[B>>2]|0;D=w+4|0;E=c[D>>2]|0;i=v;return(G=E,C)|0}p=0;while(1){if((p|0)>=4){break}x=(c[u+52+(p<<2)>>2]|0)-10|0;c[h+76+(p*12|0)+4>>2]=c[u+72+(p*224|0)+(x*56|0)+40>>2];if(((c[f+24>>2]|0)>0|0)!=0){c[h+76+(p*12|0)+8>>2]=c[u+72+(p*224|0)+(x*56|0)+44>>2]}b[(c[a+8200>>2]|0)+(p<<1)>>1]=c[u+72+(p*224|0)+(x*56|0)>>2];c[h+76+(p*12|0)>>2]=c[u+52+(p<<2)>>2];p=p+1|0}c[j>>2]=c[u+24>>2];j=u+32|0;p=c[j+4>>2]|0;h=l;c[h>>2]=c[j>>2];c[h+4>>2]=p;c[k>>2]=c[u+48>>2];c[m>>2]=l6b(a,3,0)|0;a=u+40|0;m=c[a+4>>2]|0;k=n;c[k>>2]=c[a>>2];c[k+4>>2]=m;c[f+4>>2]=c[u+64>>2];f=u+16|0;u=c[f+4>>2]|0;c[w>>2]=c[f>>2];c[w+4>>2]=u;B=w|0;C=c[B>>2]|0;D=w+4|0;E=c[D>>2]|0;i=v;return(G=E,C)|0}function b4b(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;l=i;i=i+40|0;m=l|0;n=l+8|0;o=l+16|0;p=l+24|0;q=l+32|0;r=a;a=b;b=d;d=e;e=f;f=g;g=h;c[m>>2]=j;c[m+4>>2]=k;k=c[c[a+24880>>2]>>2]|0;j=k;h=c[j+8>>2]|0;s=c[j>>2]|0;if(s>>>0<3>>>0){t=0}else{j=c[558436+(s<<4)>>2]|0;if(h>>>0<(c[833024+(j<<2)>>2]|0)>>>0){u=h}else{u=c[833024+(j<<2)>>2]|0}t=u}u=t;c[n>>2]=0;c[o>>2]=1;c[p>>2]=0;c[p+4>>2]=0;c[q>>2]=0;c[q+4>>2]=0;t=c[m+4>>2]|0;j=0;do{if(!((t|0)<(j|0)|(t|0)==(j|0)&(c[m>>2]|0)>>>0<0>>>0)){if(((c[k+20>>2]|0)>0|0)!=0){h=1;while(1){if((h|0)>=3){break}zmc(a,g,h);h=h+1|0}}c[b>>2]=0;h=d;c[h>>2]=0;c[h+4>>2]=0;h=f;c[h>>2]=0;c[h+4>>2]=0;c[e>>2]=1;h=1;while(1){if((h|0)>=3){break}c4b(a,n,p,o,q,c[m>>2]|0,c[m+4>>2]|0,h,g,u,c[r+2047144>>2]|0);if((c[n>>2]|0)==2147483647){v=18;break}s=b;c[s>>2]=(c[s>>2]|0)+(c[n>>2]|0);s=d;w=wrc(c[s>>2]|0,c[s+4>>2]|0,c[p>>2]|0,c[p+4>>2]|0)|0;c[s>>2]=w;c[s+4>>2]=G;s=f;w=wrc(c[s>>2]|0,c[s+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[s>>2]=w;c[s+4>>2]=G;s=e;c[s>>2]=c[s>>2]&c[o>>2];h=h+1|0}if((v|0)==18){break}i=l;return}}while(0);c[b>>2]=2147483647;b=d;c[b>>2]=-1;c[b+4>>2]=2147483647;b=f;c[b>>2]=-1;c[b+4>>2]=2147483647;c[e>>2]=0;i=l;return}function c4b(a,b,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;n=i;i=i+120|0;o=n|0;p=n+8|0;q=a;a=b;b=d;d=e;e=f;c[o>>2]=g;c[o+4>>2]=h;h=j;j=k;k=l;l=q+24720|0;g=l+(h*52|0)|0;mrc(p|0,0,112)|0;c[p>>2]=q;f=c[o+4>>2]|0;r=p+88|0;c[r>>2]=c[o>>2];c[r+4>>2]=f;c[p+100>>2]=m;if((h|0)==0){c[(c[c[l+160>>2]>>2]|0)+8>>2]=k}I3b(j,k,g,p+4|0,p+20|0);m=l;f=k;k=0;r=c[c[m+160>>2]>>2]|0;do{if((c[r+20>>2]|0)>0){s=6}else{if((c[g+4>>2]|0)!=0){s=6;break}if((c[m+25808>>2]|0)!=0){s=6;break}o=r;if((c[o>>2]|0)>>>0<3>>>0){t=c[o+76+(k*12|0)>>2]|0}else{t=c[o+4>>2]|0}u=204488+(f*48|0)+((c[1064496+(t<<2)>>2]|0)*12|0)|0}}while(0);if((s|0)==6){u=218736+(f*12|0)|0}c[p+104>>2]=u;dec(l,j,h,614,p);if((c[p+96>>2]|0)!=0){c[a>>2]=2147483647;l=b;c[l>>2]=-1;c[l+4>>2]=2147483647;l=e;c[l>>2]=-1;c[l+4>>2]=2147483647;c[d>>2]=0;i=n;return}else{l=p+64|0;u=c[l+4>>2]|0;f=b;c[f>>2]=c[l>>2];c[f+4>>2]=u;c[a>>2]=c[p+56>>2];a=p+72|0;p=c[a+4>>2]|0;u=e;c[u>>2]=c[a>>2];c[u+4>>2]=p;c[d>>2]=l6b(q,j,h)|0;i=n;return}}function d4b(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;n=d;d=e;e=f;f=g;g=h;h=c[g>>2]|0;o=h+24720|0;p=c[c[o+160>>2]>>2]|0;if((c[g+96>>2]|0)!=0){i=j;return}if(((c[p+20>>2]|0)>0|0)!=0){Amc(h,n,d,e,f)}else{Fmc(h,n,d,e,f,p+12|0)}e4b(n,d,f,g);f4b(n,d,e,f,g);e=c[g+36>>2]|0;p=c[h+75248>>2]|0;q=Erc(e,(e|0)<0|0?-1:0,p,(p|0)<0|0?-1:0)|0;p=wrc(128,0,q,G)|0;q=G;e=g+40|0;r=yrc(c[e>>2]|0,c[e+4>>2]|0,c[h+75244>>2]|0)|0;e=wrc(p>>>8|q<<24,q>>8|((q|0)<0|0?-1:0)<<24,r,G)|0;c[k>>2]=e;c[k+4>>2]=G;e=c[h+75248>>2]|0;r=Erc(0,0,e,(e|0)<0|0?-1:0)|0;e=wrc(128,0,r,G)|0;r=G;q=g+48|0;p=yrc(c[q>>2]|0,c[q+4>>2]|0,c[h+75244>>2]|0)|0;q=wrc(e>>>8|r<<24,r>>8|((r|0)<0|0?-1:0)<<24,p,G)|0;c[l>>2]=q;c[l+4>>2]=G;q=c[k+4>>2]|0;p=c[l+4>>2]|0;if((q|0)<(p|0)|(q|0)==(p|0)&(c[k>>2]|0)>>>0<(c[l>>2]|0)>>>0){s=c[k+4>>2]|0;t=c[k>>2]|0}else{s=c[l+4>>2]|0;t=c[l>>2]|0}c[m>>2]=t;c[m+4>>2]=s;if((n|0)==0){if((b[(c[h+(n*8240|0)+8200>>2]|0)+(d<<1)>>1]|0)!=0){n=c[k+4>>2]|0;s=c[l+4>>2]|0;if((n|0)>(s|0)|(n|0)==(s|0)&(c[k>>2]|0)>>>0>(c[l>>2]|0)>>>0){u=(c[o+25808>>2]|0)!=0^1}else{u=0}v=u}else{v=1}a[h+1128252+(f<<8)+d|0]=v&1}v=g+56|0;c[v>>2]=(c[v>>2]|0)+(c[g+36>>2]|0);v=g+40|0;d=g+64|0;f=wrc(c[d>>2]|0,c[d+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;c[d>>2]=f;c[d+4>>2]=G;d=g+48|0;f=g+72|0;v=wrc(c[f>>2]|0,c[f+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0;c[f>>2]=v;c[f+4>>2]=G;f=g+80|0;v=wrc(c[f>>2]|0,c[f+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;c[f>>2]=v;c[f+4>>2]=G;f=g+80|0;v=c[f+4>>2]|0;m=g+88|0;d=c[m+4>>2]|0;if(!((v|0)>(d|0)|(v|0)==(d|0)&(c[f>>2]|0)>>>0>(c[m>>2]|0)>>>0)){i=j;return}c[g+96>>2]=1;i=j;return}function e4b(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=a;a=d;d=e;e=f;f=d<<1;l=c[e>>2]|0;m=l+24720|0;n=m+(k*52|0)|0;o=(d|0)==3?0:2;d=H3b((c[l+(k*8240|0)+8196>>2]|0)+(a<<4<<1)|0,(c[n>>2]|0)+(a<<4<<1)|0,16<<f,h)|0;a=Arc(d|0,G|0,o|0)|0;d=e+40|0;c[d>>2]=a;c[d+4>>2]=G;d=Arc(c[h>>2]|0,c[h+4>>2]|0,o|0)|0;h=e+48|0;c[h>>2]=d;c[h+4>>2]=G;if((c[l+1184592>>2]|0)==0){i=g;return}if(((c[(c[c[m+160>>2]>>2]|0)+20>>2]|0)>0|0)!=0){i=g;return}m=(ca(ca(b[(c[n+40>>2]|0)+2>>1]|0,b[(c[n+40>>2]|0)+2>>1]|0)|0,1<<f)|0)>>o+2;c[j>>2]=m;c[j+4>>2]=(m|0)<0|0?-1:0;m=c[j+4>>2]|0;o=e+40|0;f=wrc(c[o>>2]|0,c[o+4>>2]|0,(c[j>>2]|0)>>>4|m<<28,m>>4|((m|0)<0|0?-1:0)<<28)|0;c[o>>2]=f;c[o+4>>2]=G;o=e+48|0;e=wrc(c[o>>2]|0,c[o+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;c[o>>2]=e;c[o+4>>2]=G;i=g;return}function f4b(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+1040|0;m=l|0;n=l+1024|0;o=l+1032|0;p=g;g=j;j=k;k=g;q=(c[1960336+(h<<2)>>2]|0)-k|0;h=p>>(k<<1);c[n>>2]=(h&(1<<q)-1)<<k;c[o>>2]=h>>q<<k;k=c[j>>2]|0;q=f;f=p;p=j+4+(c[n>>2]|0)|0;n=j+20+(c[o>>2]|0)|0;o=g;g=c[c[j+104>>2]>>2]|0;h=c[(c[j+104>>2]|0)+8>>2]|0;r=c[j+100>>2]|0;s=k+24720|0;t=c[c[s+160>>2]>>2]|0;u=k+(q*8240|0)|0;v=c[s+(q*52|0)+4>>2]|0;q=1960274+(o<<4)|0;s=e[(c[u+8200>>2]|0)+(f<<1)>>1]|0;w=(c[u+8192>>2]|0)+(f<<4<<1)|0;f=k+1129288+(o*13824|0)+(v*6912|0)+(((c[t+20>>2]|0)>0|0)*3456|0)|0;k=((a[p]|0)!=0)+((a[n]|0)!=0)|0;do{if((v|0)==0){if((c[t+8>>2]|0)==(o|0)){break}Cd(2581320,2558456,575,2653168)}else{u=t;x=c[u+8>>2]|0;y=c[u>>2]|0;if(y>>>0<3>>>0){z=0}else{u=c[558436+(y<<4)>>2]|0;if(x>>>0<(c[833024+(u<<2)>>2]|0)>>>0){A=x}else{A=c[833024+(u<<2)>>2]|0}z=A}if((z|0)==(o|0)){break}Cd(2581320,2558456,575,2653168)}}while(0);if((s|0)==0){B=c[f+(k*48|0)+44>>2]|0;C=0;D=C;E=(D|0)>0;F=E&1;G=F&255;H=n;a[H]=G;I=p;a[I]=G;J=B;K=j;L=K+36|0;c[L>>2]=J;i=l;return}o=q;q=o+2|0;z=b[o>>1]|0;o=b[w>>1]|0;A=b[(c[837020]|0)+(o<<2)>>1]|0;B=(c[f+(k*48|0)+(A<<2)>>2]|0)+(b[(c[837022]|0)+(o<<1)>>1]|0)|0;a[m|0]=a[206856+A|0]|0;f=f+576|0;C=1;while(1){if((C|0)>=(s|0)){break}t=b[g+(C<<1)>>1]|0;o=b[w+(t<<1)>>1]|0;v=b[(c[837020]|0)+(o<<2)>>1]|0;if((r|0)!=0){B=B+((c[f+((((A|0)!=0^1)&1)*288|0)+((((A|0)!=0^1)&1)*48|0)+(v<<2)>>2]|0)+(b[(c[837022]|0)+(o<<1)>>1]|0))|0}else{u=h;x=m|0;y=C;k=(d[x+(b[u+(y<<1<<1)>>1]|0)|0]|0)+1+(d[x+(b[u+((y<<1)+1<<1)>>1]|0)|0]|0)>>1;B=B+((c[f+((((A|0)!=0^1)&1)*288|0)+(k*48|0)+(v<<2)>>2]|0)+(b[(c[837022]|0)+(o<<1)>>1]|0))|0;a[m+t|0]=a[206856+v|0]|0}A=v;v=z-1|0;z=v;if((v|0)==0){v=q;q=v+2|0;z=b[v>>1]|0;f=f+576|0}C=C+1|0}if((z|0)!=0){if((r|0)!=0){B=B+(c[f+((((A|0)!=0^1)&1)*48|0)+44>>2]|0)|0}else{A=h;h=m|0;m=C;k=(d[h+(b[A+(m<<1<<1)>>1]|0)|0]|0)+1+(d[h+(b[A+((m<<1)+1<<1)>>1]|0)|0]|0)>>1;B=B+(c[f+(k*48|0)+44>>2]|0)|0}}D=C;E=(D|0)>0;F=E&1;G=F&255;H=n;a[H]=G;I=p;a[I]=G;J=B;K=j;L=K+36|0;c[L>>2]=J;i=l;return}function g4b(d,f,g,h,j,k,l,m){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0;n=i;i=i+448|0;o=n|0;p=n+8|0;q=n+16|0;r=n+24|0;s=n+32|0;t=n+40|0;u=n+48|0;v=n+56|0;w=n+168|0;x=n+392|0;y=n+400|0;z=n+408|0;A=n+424|0;B=n+432|0;C=n+440|0;D=d;d=f;f=g;g=h;h=j;j=k;k=l;l=m;m=0;c[q>>2]=0;c[q+4>>2]=0;c[r>>2]=0;c[r+4>>2]=0;E=d+24720|0;F=D+1434592|0;H=c[c[E+160>>2]>>2]|0;I=H|0;J=d|0;K=E|0;c[s>>2]=0;c[s+4>>2]=0;L=0;M=c[I>>2]|0;N=c[777792+(M<<2)>>2]|0;O=c[777848+(M<<2)>>2]|0;P=D+2047252+(M*44|0)|0;Q=g+(h*976|0)|0;S=1;T=0;U=(c[I+24>>2]|0)>0|0;V=c[D+2047092+(M<<2)>>2]|0;W=t;X=c[K+44>>2]|0;a[W]=a[X]|0;a[W+1|0]=a[X+1|0]|0;X=u;W=c[K+48>>2]|0;a[X]=a[W]|0;a[X+1|0]=a[W+1|0]|0;W=(c[Q+968>>2]|0)/4|0;X=0;a:while(1){if((X|0)>=2){Y=184;break}Z=0;while(1){if((Z|0)>=2){break}_=12;c[x>>2]=-1;c[x+4>>2]=2147483647;$=(X<<1)+Z|0;aa=0;while(1){if((aa|0)>=(U+1|0)){break}ba=c[I+20+(aa<<2)>>2]|0;c[w+192+(ba<<2)>>2]=0;agc(F,E,f,$,aa,k,l,w+160+(ba<<2)|0,w+176+(ba<<2)|0);aa=aa+1|0}ba=10;b:while(1){if(!(ba>>>0<=13>>>0)){break}ca=y;da=d+8204|0;c[ca>>2]=c[da>>2];c[ca+4>>2]=c[da+4>>2];ea=ba-10|0;da=Q+72+($*224|0)+(ea*56|0)+32|0;c[da>>2]=-1;c[da+4>>2]=2147483647;c:do{if((V&1<<ea|0)==0){if((V3b(D,I+68|0,w|0,V,ba,I+20|0)|0)==0){break}da=z;ca=K+24|0;c[da>>2]=c[ca>>2];c[da+4>>2]=c[ca+4>>2];c[da+8>>2]=c[ca+8>>2];c[da+12>>2]=c[ca+12>>2];ca=Q+72+($*224|0)+(ea*56|0)+48|0;da=t;a[ca]=a[da]|0;a[ca+1|0]=a[da+1|0]|0;da=Q+72+($*224|0)+(ea*56|0)+50|0;ca=u;a[da]=a[ca]|0;a[da+1|0]=a[ca+1|0]|0;do{if((U|0)==0){if((ba|0)!=13){break}if(!((c[j+($<<4)+(c[I+20>>2]<<2)>>2]|0)==-2147450880)){break}ca=v+104|0;da=0;fa=2147483647;ga=c[d+75240>>2]|0;ha=c[x+4>>2]|0;ia=W;ja=(ia|0)<0|0?-1:0;if((ha|0)<(ja|0)|(ha|0)==(ja|0)&(c[x>>2]|0)>>>0<ia>>>0){Y=19;break b}do{if((c[D+1471648>>2]|0)!=5){if((c[D+1471648>>2]|0)==2){break}if(($|0)>0){c[Q+8>>2]=c[H+76+(($-1|0)*12|0)+4>>2];if(($|0)==2){c[Q+8>>2]=c[H+76+(($-2|0)*12|0)+4>>2]}}}}while(0);if(($|0)==0){ka=c[d+75284+(c[I+20>>2]<<2)>>2]|0}else{ia=R(b[Q+8>>1]|0)|0;if((ia|0)>(R(b[Q+10>>1]|0)|0)){la=R(b[Q+8>>1]|0)|0}else{la=R(b[Q+10>>1]|0)|0}ka=la>>3}do{if((c[D+2046908>>2]|0)!=0){if((c[F+10112>>2]|0)==0){Y=36;break}ia=Ync(D,ka)|0;da=ia+(c[D+2047168>>2]|0)>>1}else{Y=36}}while(0);if((Y|0)==36){Y=0;da=c[D+2047168>>2]|0}b[A>>1]=b[Q+8>>1]>>3;b[A+2>>1]=b[Q+10>>1]>>3;do{if((c[D+2047004>>2]|0)!=0){if((c[F+10112>>2]|0)==0){break}b[A>>1]=b[d+1184596+(c[I+20>>2]<<2)>>1]>>3;b[A+2>>1]=b[d+1184596+(c[I+20>>2]<<2)+2>>1]>>3;if((da|0)>8){ma=da}else{ma=8}da=ma}}while(0);ia=10-da|0;ja=d;ha=$;na=c[c[ja+24880>>2]>>2]|0;oa=ja|0;pa=ja+24720|0;ja=k4b(3,ha,c[oa+8208>>2]|0)|0;c[oa+8204>>2]=(c[oa+8204>>2]|0)+ja;if((c[pa+24>>2]&7|0)!=0){Y=44;break a}ja=k4b(3,ha,c[pa+28>>2]|0)|0;c[pa+24>>2]=(c[pa+24>>2]|0)+ja;if((c[na+24>>2]|0)>0){na=k4b(3,ha,c[pa+36>>2]|0)|0;c[pa+32>>2]=(c[pa+32>>2]|0)+na}Xnc(d,c[Q>>2]|0);if((c[D+2046880>>2]|0)==2){fa=foc(d,A,da,ga,1,P,1,c[Q>>2]|0,ca)|0;if((fa|0)<2147483647){fa=doc(d,ca,c[Q>>2]|0,P,1)|0}}else{if((c[D+2046880>>2]|0)==4){fa=ioc(d,A,da,ga,1,P,1,c[Q>>2]|0,ca)|0;if((fa|0)<2147483647){fa=doc(d,ca,c[Q>>2]|0,P,1)|0}}else{if((c[D+2046880>>2]|0)==3){fa=hoc(d,A,da,ga,1,P,1,c[Q>>2]|0,ca)|0;if((fa|0)<2147483647){fa=doc(d,ca,c[Q>>2]|0,P,1)|0}}else{fa=ooc(D,d,A,da,ga,ia,0,P,c[Q>>2]|0,ca)|0}}}if((c[D+1471648>>2]|0)==2){Y=64}else{if((c[D+1471648>>2]|0)==5){Y=64}}if((Y|0)==64){Y=0;ia=H+76+($*12|0)+4|0;na=A;pa=c[d+1128244>>2]|0;ha=c[d+1128248>>2]|0;ja=b[na+2>>1]|0;oa=c[d+1128236>>2]|0;qa=c[d+1128240>>2]|0;if((ja|0)<(oa|0)){ra=oa}else{if((ja|0)>(qa|0)){sa=qa}else{sa=ja}ra=sa}b[na+2>>1]=ra;ja=b[na>>1]|0;qa=pa;pa=ha;if((ja|0)<(qa|0)){ta=qa}else{if((ja|0)>(pa|0)){ua=pa}else{ua=ja}ta=ua}b[na>>1]=ta;na=me[c[D+2047240>>2]&255](d,A,ga,16,P,c[Q>>2]|0,ia)|0;if((na|0)<(fa|0)){fa=na;c[ca>>2]=c[ia>>2]}else{c[ia>>2]=c[ca>>2]}}if((fa|0)<2147483647){Qe[c[D+2047232>>2]&3](d,ca,c[Q>>2]|0,c[F+10128>>2]|0,c[d+75232>>2]|0,P,c[D+2046896>>2]|0,c[D+2046892>>2]|0,d+75336|0,c[d+599640>>2]|0,B,d+75304+(c[I+20>>2]<<2)|0)|0;c[j+($<<4)+(c[I+20>>2]<<2)>>2]=c[ca>>2]}if((c[D+2047004>>2]|0)!=0){c[d+1184596+(c[I+20>>2]<<2)>>2]=c[ca>>2]}nrc(p|0,y|0,8)|0;ia=d;na=z|0;ja=c[c[ia+24880>>2]>>2]|0;pa=ia+8204|0;qa=p;c[pa>>2]=c[qa>>2];c[pa+4>>2]=c[qa+4>>2];qa=ia+24744|0;pa=na;c[qa>>2]=c[pa>>2];c[qa+4>>2]=c[pa+4>>2];if((c[ja+24>>2]|0)>0){ja=ia+24752|0;ia=na+8|0;c[ja>>2]=c[ia>>2];c[ja+4>>2]=c[ia+4>>2]}}}while(0);d:do{if((U|0)!=0){do{if(!((c[j+($<<4)+(c[I+24>>2]<<2)>>2]|0)==-2147450880)){if((c[j+($<<4)+(c[I+20>>2]<<2)>>2]|0)==-2147450880){break}break d}}while(0);break c}}while(0);do{if((U|0)!=0){if((ba|0)!=13){break}if((c[I+72>>2]|0)!=0){break}ca=d;fa=$;ga=c[c[ca+24880>>2]>>2]|0;da=ca|0;ia=ca+24720|0;ca=k4b(3,fa,c[da+8208>>2]|0)|0;c[da+8204>>2]=(c[da+8204>>2]|0)+ca;if((c[ia+24>>2]&7|0)!=0){Y=96;break a}ca=k4b(3,fa,c[ia+28>>2]|0)|0;c[ia+24>>2]=(c[ia+24>>2]|0)+ca;if((c[ga+24>>2]|0)>0){ga=k4b(3,fa,c[ia+36>>2]|0)|0;c[ia+32>>2]=(c[ia+32>>2]|0)+ga}if((c[D+2046920>>2]|0)>>>0<=M>>>0){h4b(D,d,M,w+(ba<<4)|0,k,l,j+($<<4)|0,C);c[j+($<<4)+(c[I+20>>2]<<2)>>2]=c[w+(ba<<4)+(c[I+20>>2]<<2)>>2];c[j+($<<4)+(c[I+24>>2]<<2)>>2]=c[w+(ba<<4)+(c[I+24>>2]<<2)>>2]}nrc(o|0,y|0,8)|0;ga=d;ia=z|0;fa=c[c[ga+24880>>2]>>2]|0;ca=ga+8204|0;da=o;c[ca>>2]=c[da>>2];c[ca+4>>2]=c[da+4>>2];da=ga+24744|0;ca=ia;c[da>>2]=c[ca>>2];c[da+4>>2]=c[ca+4>>2];if((c[fa+24>>2]|0)>0){fa=ga+24752|0;ga=ia+8|0;c[fa>>2]=c[ga>>2];c[fa+4>>2]=c[ga+4>>2]}}}while(0);c[Q+72+($*224|0)+(ea*56|0)+4>>2]=i4b(D,E,$,ba,v+(ba<<3)|0,w|0,j+($<<4)|0,Q|0,d+75336|0,c[d+599640>>2]|0)|0;aa=0;while(1){if((aa|0)>=(U+1|0)){break}c[Q+72+($*224|0)+(ea*56|0)+40+(aa<<2)>>2]=c[v+(ba<<3)+(aa<<2)>>2];if((N|0)>1){c[Q+72+(($+1|0)*224|0)+(ea*56|0)+40+(aa<<2)>>2]=c[v+(ba<<3)+(aa<<2)>>2]}if((O|0)>1){c[Q+72+(($+2|0)*224|0)+(ea*56|0)+40+(aa<<2)>>2]=c[v+(ba<<3)+(aa<<2)>>2]}aa=aa+1|0}ga=d;fa=v+(ba<<3)|0;do{if((b[fa>>1]>>3|0)<(c[ga+1128244>>2]|0)){va=1}else{if((b[fa>>1]>>3|0)>(c[ga+1128248>>2]|0)){va=1;break}if((b[fa+2>>1]>>3|0)<(c[ga+1128236>>2]|0)){va=1;break}va=(b[fa+2>>1]>>3|0)>(c[ga+1128240>>2]|0)}}while(0);do{if((va&1|0)==0){if((U|0)!=0){ga=d;fa=v+(ba<<3)+4|0;do{if((b[fa>>1]>>3|0)<(c[ga+1128244>>2]|0)){wa=1}else{if((b[fa>>1]>>3|0)>(c[ga+1128248>>2]|0)){wa=1;break}if((b[fa+2>>1]>>3|0)<(c[ga+1128236>>2]|0)){wa=1;break}wa=(b[fa+2>>1]>>3|0)>(c[ga+1128240>>2]|0)}}while(0);if((wa&1|0)!=0){break}}if((h|0)>0){ga=g;S=0;T=1;aa=0;while(1){if((aa|0)>=(U+1|0)){break}fa=v+(ba<<3)+(aa<<2)|0;if((b[fa>>1]&15|0)!=0){xa=1}else{xa=(b[fa+2>>1]&15|0)!=0}S=S|xa&1;T=T&(c[v+(ba<<3)+(aa<<2)>>2]|0)==(c[ga+72+($*224|0)+(ea*56|0)+40+(aa<<2)>>2]|0);aa=aa+1|0}do{if((h|0)>1){if((S|0)!=0){break}if((T|0)!=0){break}ga=g+976|0;T=1;aa=0;while(1){if((aa|0)>=(U+1|0)){break}T=T&(c[v+(ba<<3)+(aa<<2)>>2]|0)==(c[ga+72+($*224|0)+(ea*56|0)+40+(aa<<2)>>2]|0);aa=aa+1|0}}}while(0);do{if((S|0)==0){if((T|0)==0){break}fa=ga+72+($*224|0)+(ea*56|0)+32|0;ia=c[fa+4>>2]|0;ca=2147483647;if(!((ia|0)<(ca|0)|(ia|0)==(ca|0)&(c[fa>>2]|0)>>>0<-1>>>0)){break}fa=Q+72+($*224|0)+(ea*56|0)|0;ca=ga+72+($*224|0)+(ea*56|0)|0;c[fa>>2]=c[ca>>2];c[fa+4>>2]=c[ca+4>>2];c[fa+8>>2]=c[ca+8>>2];c[fa+12>>2]=c[ca+12>>2];c[fa+16>>2]=c[ca+16>>2];c[fa+20>>2]=c[ca+20>>2];c[fa+24>>2]=c[ca+24>>2];c[fa+28>>2]=c[ca+28>>2];c[fa+32>>2]=c[ca+32>>2];c[fa+36>>2]=c[ca+36>>2];c[fa+40>>2]=c[ca+40>>2];c[fa+44>>2]=c[ca+44>>2];c[fa+48>>2]=c[ca+48>>2];c[fa+52>>2]=c[ca+52>>2];if((N|0)>1){c[Q+72+(($+1|0)*224|0)+(ea*56|0)>>2]=c[ga+72+(($+1|0)*224|0)+(ea*56|0)>>2]}if((O|0)>1){c[Q+72+(($+2|0)*224|0)+(ea*56|0)>>2]=c[ga+72+(($+2|0)*224|0)+(ea*56|0)>>2]}ca=Q+72+($*224|0)+(ea*56|0)+32|0;fa=c[ca+4>>2]|0;ia=c[x+4>>2]|0;if((fa|0)<(ia|0)|(fa|0)==(ia|0)&(c[ca>>2]|0)>>>0<(c[x>>2]|0)>>>0){_=ba;ca=Q+72+($*224|0)+(ea*56|0)+32|0;ia=c[ca+4>>2]|0;c[x>>2]=c[ca>>2];c[x+4>>2]=ia}break c}}while(0)}ga=Q+16|0;ia=xrc(c[ga>>2]|0,c[ga+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;ga=j4b(D,d,ia,G,$,Q+72+($*224|0)+(ea*56|0)+8|0,Q+72+($*224|0)+(ea*56|0)+16|0,Q+72+($*224|0)+(ea*56|0)+24|0,Q+72+($*224|0)+(ea*56|0)+48|0,Q+72+($*224|0)+(ea*56|0)+50|0,k,l)|0;ia=Q+72+($*224|0)+(ea*56|0)+32|0;c[ia>>2]=ga;c[ia+4>>2]=G;ia=Q+72+($*224|0)+(ea*56|0)+32|0;ga=c[ia+4>>2]|0;ca=2147483647;if((ga|0)<(ca|0)|(ga|0)==(ca|0)&(c[ia>>2]|0)>>>0<-1>>>0){ia=c[Q+72+($*224|0)+(ea*56|0)+4>>2]|0;ca=c[d+75248>>2]|0;ga=Erc(ia,(ia|0)<0|0?-1:0,ca,(ca|0)<0|0?-1:0)|0;ca=wrc(128,0,ga,G)|0;ga=G;ia=0<<c[d+75244>>2];fa=wrc(ca>>>8|ga<<24,ga>>8|((ga|0)<0|0?-1:0)<<24,ia,(ia|0)<0|0?-1:0)|0;ia=Q+72+($*224|0)+(ea*56|0)+32|0;ga=wrc(c[ia>>2]|0,c[ia+4>>2]|0,fa,G)|0;c[ia>>2]=ga;c[ia+4>>2]=G;ia=Q+72+($*224|0)+(ea*56|0)+4|0;c[ia>>2]=(c[ia>>2]|0)+(c[Q+72+($*224|0)+(ea*56|0)+8>>2]|0);c[Q+72+($*224|0)+(ea*56|0)>>2]=e[(c[J+8200>>2]|0)+($<<1)>>1]|0;if((N|0)>1){c[Q+72+(($+1|0)*224|0)+(ea*56|0)>>2]=e[(c[J+8200>>2]|0)+($+1<<1)>>1]|0}if((O|0)>1){c[Q+72+(($+2|0)*224|0)+(ea*56|0)>>2]=e[(c[J+8200>>2]|0)+($+2<<1)>>1]|0}}ia=Q+72+($*224|0)+(ea*56|0)+32|0;ga=c[ia+4>>2]|0;fa=c[x+4>>2]|0;if((ga|0)<(fa|0)|(ga|0)==(fa|0)&(c[ia>>2]|0)>>>0<(c[x>>2]|0)>>>0){_=ba;ia=Q+72+($*224|0)+(ea*56|0)+32|0;fa=c[ia+4>>2]|0;c[x>>2]=c[ia>>2];c[x+4>>2]=fa}break c}}while(0)}}while(0);ba=ba+1|0}if((Y|0)==19){Y=0}if((c[x>>2]|0)==(-1|0)&(c[x+4>>2]|0)==2147483647){Y=161;break a}ea=_-10|0;ba=t;aa=Q+72+($*224|0)+(ea*56|0)+48|0;a[ba]=a[aa]|0;a[ba+1|0]=a[aa+1|0]|0;aa=u;ba=Q+72+($*224|0)+(ea*56|0)+50|0;a[aa]=a[ba]|0;a[aa+1|0]=a[ba+1|0]|0;i4b(D,E,$,_,v+(_<<3)|0,w|0,j+($<<4)|0,Q|0,d+75336|0,c[d+599640>>2]|0)|0;m=m+(c[Q+72+($*224|0)+(ea*56|0)+4>>2]|0)|0;ba=Q+72+($*224|0)+(ea*56|0)+16|0;aa=wrc(c[q>>2]|0,c[q+4>>2]|0,c[ba>>2]|0,c[ba+4>>2]|0)|0;c[q>>2]=aa;c[q+4>>2]=G;aa=Q+72+($*224|0)+(ea*56|0)+24|0;ba=wrc(c[r>>2]|0,c[r+4>>2]|0,c[aa>>2]|0,c[aa+4>>2]|0)|0;c[r>>2]=ba;c[r+4>>2]=G;L=L+(c[Q+72+($*224|0)+(ea*56|0)+8>>2]|0)|0;ba=Q+72+($*224|0)+(ea*56|0)+32|0;aa=wrc(c[s>>2]|0,c[s+4>>2]|0,c[ba>>2]|0,c[ba+4>>2]|0)|0;c[s>>2]=aa;c[s+4>>2]=G;aa=c[s+4>>2]|0;ba=Q+16|0;fa=c[ba+4>>2]|0;if((aa|0)>(fa|0)|(aa|0)==(fa|0)&(c[s>>2]|0)>>>0>(c[ba>>2]|0)>>>0){Y=171;break a}Z=Z+N|0}X=X+O|0}if((Y|0)==44){Cd(2543864,2558456,1654,2651944)}else if((Y|0)==96){Cd(2543864,2558456,1654,2651944)}else if((Y|0)==161){O=$+1|0;while(1){if((O|0)>=4){break}X=0;while(1){if((X|0)>=4){break}N=Q+72+(O*224|0)+(X*56|0)+32|0;c[N>>2]=-1;c[N+4>>2]=2147483647;X=X+1|0}O=O+1|0}O=Q+16|0;c[O>>2]=-1;c[O+4>>2]=2147483647;i=n;return}else if((Y|0)==171){O=$+1|0;while(1){if((O|0)>=4){break}$=0;while(1){if(($|0)>=4){break}X=Q+72+(O*224|0)+($*56|0)+32|0;c[X>>2]=-1;c[X+4>>2]=2147483647;$=$+1|0}O=O+1|0}O=Q+16|0;c[O>>2]=-1;c[O+4>>2]=2147483647;i=n;return}else if((Y|0)==184){c[Q+24>>2]=m;m=c[q+4>>2]|0;Y=Q+32|0;c[Y>>2]=c[q>>2];c[Y+4>>2]=m;c[Q+48>>2]=L;L=c[s+4>>2]|0;m=Q+16|0;c[m>>2]=c[s>>2];c[m+4>>2]=L;L=c[r+4>>2]|0;m=Q+40|0;c[m>>2]=c[r>>2];c[m+4>>2]=L;L=0;while(1){if((L|0)>=4){break}c[Q+52+(L<<2)>>2]=c[H+76+(L*12|0)>>2];L=L+1|0}i=n;return}}function h4b(a,d,e,f,g,h,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+128|0;m=l|0;n=l+8|0;o=l+16|0;p=l+64|0;q=l+72|0;r=l+80|0;s=l+88|0;t=l+104|0;u=l+112|0;v=l+120|0;w=a;a=d;d=e;e=f;f=g;g=h;h=j;j=k;k=c[777792+(d<<2)>>2]<<2;x=c[777848+(d<<2)>>2]<<2;y=a+24720|0;z=c[c[y+160>>2]>>2]|0;A=m|0;c[A>>2]=c[z+20>>2];if((c[z+24>>2]|0)<0){B=0}else{B=c[z+24>>2]|0}c[A+4>>2]=B;B=BYb(16,ca(k,x)|0)|0;A=Tec(c[z+72>>2]|0)|0;C=p;D=y+24|0;c[C>>2]=c[D>>2];c[C+4>>2]=c[D+4>>2];D=q;c[D>>2]=c[259242];c[D+4>>2]=c[259243];D=r|0;c[D>>2]=M3b(w,c[z+20>>2]|0)|0;c[D+4>>2]=M3b(w,c[z+24>>2]|0)|0;D=0;while(1){if((D|0)>=2){break}c[n+(D<<2)>>2]=c[z+36+(c[m+(D<<2)>>2]<<3)>>2];if((c[r+(D<<2)>>2]|0)!=0){C=0;while(1){if((C|0)>=3){break}E=o+(D*24|0)+(C<<3)|0;F=y+(C*52|0)+24+(D<<3)|0;c[E>>2]=c[F>>2];c[E+4>>2]=c[F+4>>2];C=C+1|0}Agc(y,D,c[r+(D<<2)>>2]|0,f,g,0)}c[e+(c[m+(D<<2)>>2]<<2)>>2]=c[h+(c[m+(D<<2)>>2]<<2)>>2];D=D+1|0}h=0;while(1){if((h|0)>=4){break}C=2147483647;F=c[a+75236>>2]|0;E=c[a+1128236>>2]|0;G=c[a+1128240>>2]|0;H=c[a+1128244>>2]|0;I=c[a+1128248>>2]|0;J=(h|0)%2|0;K=s|0;L=y+24|0;c[K>>2]=c[L>>2];c[K+4>>2]=c[L+4>>2];L=s+8|0;K=y+32|0;c[L>>2]=c[K>>2];c[L+4>>2]=c[K+4>>2];qgc(c[s+((((J|0)!=0^1)&1)<<3)>>2]|0,c[s+((((J|0)!=0^1)&1)<<3)+4>>2]|0,B,k,e+(c[m+((((J|0)!=0^1)&1)<<2)>>2]<<2)|0,(c[y+188+((((J|0)!=0^1)&1)<<2)>>2]|0)+8|0,k,x,0,A,0,g<<3,f<<3);if((J|0)!=0){K=y+24|0;L=s+(J<<3)|0;c[K>>2]=c[L>>2];c[K+4>>2]=c[L+4>>2]}Xnc(a,n+(J<<2)|0);L=t;K=e+(c[m+(J<<2)>>2]<<2)|0;b[L>>1]=b[K>>1]|0;b[L+2>>1]=b[K+2>>1]|0;K=t+2|0;b[K>>1]=b[K>>1]>>3;K=t|0;b[K>>1]=b[K>>1]>>3;C=roc(a,t,F,3,w+2047252+(d*44|0)|0,n+(J<<2)|0,B,k,x)|0;if((C|0)<2147483647){C=eoc(a,t,n+(J<<2)|0,B,w+2047252+(d*44|0)|0,1)|0}c[a+1128236>>2]=E;c[a+1128240>>2]=G;c[a+1128244>>2]=H;c[a+1128248>>2]=I;if((C|0)<2147483647){C=Le[c[w+2047236>>2]&3](a,t,n+(J<<2)|0,c[w+1444720>>2]|0,c[a+75232>>2]|0,w+2047252+(d*44|0)|0,0,c[w+2046892>>2]|0,a+75336|0,c[a+599640>>2]|0,u,v,B,k,x)|0}if((J|0)!=0){I=y+24|0;H=p;c[I>>2]=c[H>>2];c[I+4>>2]=c[H+4>>2]}if((C|0)>=(c[q+(J<<2)>>2]|0)){H=26;break}H=e+(c[m+(J<<2)>>2]<<2)|0;I=t;b[H>>1]=b[I>>1]|0;b[H+2>>1]=b[I+2>>1]|0;c[q+(J<<2)>>2]=C;h=h+1|0}c[j>>2]=0;D=0;while(1){if((D|0)>=2){break}if((c[r+(D<<2)>>2]|0)!=0){h=0;while(1){if((h|0)>=3){break}q=y+(h*52|0)+24+(D<<3)|0;t=o+(D*24|0)+(h<<3)|0;c[q>>2]=c[t>>2];c[q+4>>2]=c[t+4>>2];h=h+1|0}}h=Znc(e+(c[m+(D<<2)>>2]<<2)|0,z+36+(c[m+(D<<2)>>2]<<3)|0,a+75336|0,c[a+599640>>2]|0,108)|0;t=j;c[t>>2]=(c[t>>2]|0)+h;D=D+1|0}FYb(B);i=l;return}function i4b(a,b,e,f,g,h,j,k,l,m){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=i;o=a;a=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=c[c[b+160>>2]>>2]|0;b=m|0;p=0;q=c[777792+(c[b>>2]<<2)>>2]|0;r=c[777848+(c[b>>2]<<2)>>2]|0;s=(c[b+24>>2]|0)>0|0;t=e;if((t|0)==10){c[f>>2]=c[g+160+(c[b+20>>2]<<2)>>2];if((s|0)!=0){c[f+4>>2]=c[g+160+(c[b+24>>2]<<2)>>2]}}else if((t|0)==12){c[f>>2]=0;if((s|0)!=0){c[f+4>>2]=0}}else if((t|0)==13){c[f>>2]=c[h+(c[b+20>>2]<<2)>>2];p=p+(Znc(f|0,c[j>>2]|0,k,l,120)|0)|0;if((s|0)!=0){c[f+4>>2]=c[h+(c[b+24>>2]<<2)>>2];p=p+(Znc(f+4|0,c[j+4>>2]|0,k,l,120)|0)|0}}else if((t|0)==11){c[f>>2]=c[g+176+(c[b+20>>2]<<2)>>2];if((s|0)!=0){c[f+4>>2]=c[g+176+(c[b+24>>2]<<2)>>2]}}c[m+76+(a*12|0)+4>>2]=c[f>>2];if((s|0)!=0){c[m+76+(a*12|0)+8>>2]=c[f+4>>2]}c[m+76+(a*12|0)>>2]=e;f=0;while(1){if((f|0)>=(r|0)){break}s=0;while(1){if((s|0)>=(q|0)){break}g=m+76+((a+(f<<1)+s|0)*12|0)|0;t=m+76+(a*12|0)|0;c[g>>2]=c[t>>2];c[g+4>>2]=c[t+4>>2];c[g+8>>2]=c[t+8>>2];s=s+1|0}f=f+1|0}f=(m4b(o,e,d[b+68+(c[b+20>>2]|0)|0]|0)|0)+p|0;i=n;return f|0}function j4b(f,g,h,j,k,l,m,n,o,p,q,r){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0;s=i;i=i+1088|0;t=s|0;u=s+1024|0;v=s+1032|0;w=s+1040|0;x=s+1048|0;y=s+1056|0;z=s+1064|0;A=s+1072|0;B=s+1080|0;C=f;f=g;c[v>>2]=h;c[v+4>>2]=j;j=k;k=l;l=m;m=n;n=o;o=p;p=q;q=r;r=f+24720|0;h=r|0;g=f|0;D=c[c[r+160>>2]>>2]|0;E=h;F=c[558424+(c[D>>2]<<4)+(c[E+8>>2]<<3)+(c[E+12>>2]<<2)>>2]|0;if(!(F>>>0<13>>>0)){Cd(2437376,2427112,292,2652440);return 0}E=F;F=c[777792+(E<<2)>>2]<<2;H=c[777848+(E<<2)>>2]<<2;E=k4b(3,j,c[g+8208>>2]|0)|0;I=(c[g+8204>>2]|0)+E|0;E=k4b(3,j,c[h+20>>2]|0)|0;J=(c[h+16>>2]|0)+E|0;c[w>>2]=0;c[w+4>>2]=0;c[x>>2]=0;c[x+4>>2]=0;E=0;K=218736;L=(c[D+24>>2]|0)>0|0;M=Tec(c[D+72>>2]|0)|0;N=0;while(1){if((N|0)>=(L+1|0)){break}O=k4b(3,j,c[h+24+(N<<3)+4>>2]|0)|0;qgc((c[h+24+(N<<3)>>2]|0)+O|0,c[h+24+(N<<3)+4>>2]|0,J,c[h+20>>2]|0,D+76+(j*12|0)+4+(N<<2)|0,(c[r+188+(N<<2)>>2]|0)+8|0,F,H,N,M,0,(q<<3)+(((j|0)%2|0)<<2)|0,(p<<3)+(((j|0)/2|0)<<2)|0);N=N+1|0}N=l4b(3,j,g|0)|0;ymc(H,F,N,8,I,c[g+8208>>2]|0,J,c[h+20>>2]|0);J=j;j=0;a:while(1){if((j|0)>=((H|0)/4|0|0)){P=46;break}I=0;while(1){if((I|0)>=((F|0)/4|0|0)){break}J=J+((j<<1)+I)|0;N=(c[g+8196>>2]|0)+(J<<4<<1)|0;p=c[f+1401812>>2]|0;q=l4b(3,J,g|0)|0;ef[p&4095](q,N,8);E2b(f,0,J,c[K>>2]|0,c[K+4>>2]|0);q=H3b(N,(c[h>>2]|0)+(J<<4<<1)|0,16,y)|0;N=wrc(c[w>>2]|0,c[w+4>>2]|0,q,G)|0;c[w>>2]=N;c[w+4>>2]=G;N=wrc(c[x>>2]|0,c[x+4>>2]|0,c[y>>2]|0,c[y+4>>2]|0)|0;c[x>>2]=N;c[x+4>>2]=G;N=f;q=0;p=J;M=n+(J&1)|0;r=o+(J>>1)|0;D=0;L=c[K>>2]|0;O=c[K+8>>2]|0;Q=c[C+2047144>>2]|0;R=N+24720|0;S=c[c[R+160>>2]>>2]|0;T=N+(q*8240|0)|0;U=c[R+(q*52|0)+4>>2]|0;q=1960274+(D<<4)|0;R=e[(c[T+8200>>2]|0)+(p<<1)>>1]|0;V=(c[T+8192>>2]|0)+(p<<4<<1)|0;p=N+1129288+(D*13824|0)+(U*6912|0)+(((c[S+20>>2]|0)>0|0)*3456|0)|0;N=((a[M]|0)!=0)+((a[r]|0)!=0)|0;if((U|0)==0){if((c[S+8>>2]|0)!=(D|0)){P=20;break a}}else{U=S;S=c[U+8>>2]|0;T=c[U>>2]|0;if(T>>>0<3>>>0){W=0}else{U=c[558436+(T<<4)>>2]|0;if(S>>>0<(c[833024+(U<<2)>>2]|0)>>>0){X=S}else{X=c[833024+(U<<2)>>2]|0}W=X}if((W|0)!=(D|0)){P=20;break a}}if((R|0)==0){Y=c[p+(N*48|0)+44>>2]|0;Z=0}else{D=q;q=D+2|0;U=b[D>>1]|0;D=b[V>>1]|0;S=b[(c[837020]|0)+(D<<2)>>1]|0;Y=(c[p+(N*48|0)+(S<<2)>>2]|0)+(b[(c[837022]|0)+(D<<1)>>1]|0)|0;a[t|0]=a[206856+S|0]|0;p=p+576|0;Z=1;while(1){if((Z|0)>=(R|0)){break}T=b[L+(Z<<1)>>1]|0;D=b[V+(T<<1)>>1]|0;_=b[(c[837020]|0)+(D<<2)>>1]|0;if((Q|0)!=0){Y=Y+((c[p+((((S|0)!=0^1)&1)*288|0)+((((S|0)!=0^1)&1)*48|0)+(_<<2)>>2]|0)+(b[(c[837022]|0)+(D<<1)>>1]|0))|0}else{$=O;aa=t|0;ba=Z;N=(d[aa+(b[$+(ba<<1<<1)>>1]|0)|0]|0)+1+(d[aa+(b[$+((ba<<1)+1<<1)>>1]|0)|0]|0)>>1;Y=Y+((c[p+((((S|0)!=0^1)&1)*288|0)+(N*48|0)+(_<<2)>>2]|0)+(b[(c[837022]|0)+(D<<1)>>1]|0))|0;a[t+T|0]=a[206856+_|0]|0}S=_;_=U-1|0;U=_;if((_|0)==0){_=q;q=_+2|0;U=b[_>>1]|0;p=p+576|0}Z=Z+1|0}if((U|0)!=0){if((Q|0)!=0){Y=Y+(c[p+((((S|0)!=0^1)&1)*48|0)+44>>2]|0)|0}else{q=O;D=t|0;V=Z;N=(d[D+(b[q+(V<<1<<1)>>1]|0)|0]|0)+1+(d[D+(b[q+((V<<1)+1<<1)>>1]|0)|0]|0)>>1;Y=Y+(c[p+(N*48|0)+44>>2]|0)|0}}}V=(Z|0)>0&255;a[r]=V;a[M]=V;E=E+Y|0;V=E;q=c[f+75248>>2]|0;D=Erc(V,(V|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;q=wrc(128,0,D,G)|0;D=G;V=c[w+4>>2]|0;L=yrc((c[w>>2]|0)>>>2|V<<30|0,V>>2|((V|0)<0|0?-1:0)<<30|0,c[f+75244>>2]|0)|0;V=wrc(q>>>8|D<<24,D>>8|((D|0)<0|0?-1:0)<<24,L,G)|0;c[A>>2]=V;c[A+4>>2]=G;V=c[f+75248>>2]|0;L=Erc(0,0,V,(V|0)<0|0?-1:0)|0;V=wrc(128,0,L,G)|0;L=G;D=c[x+4>>2]|0;q=yrc((c[x>>2]|0)>>>2|D<<30|0,D>>2|((D|0)<0|0?-1:0)<<30|0,c[f+75244>>2]|0)|0;D=wrc(V>>>8|L<<24,L>>8|((L|0)<0|0?-1:0)<<24,q,G)|0;c[B>>2]=D;c[B+4>>2]=G;D=c[A+4>>2]|0;q=c[B+4>>2]|0;if((D|0)<(q|0)|(D|0)==(q|0)&(c[A>>2]|0)>>>0<(c[B>>2]|0)>>>0){ca=c[A+4>>2]|0;da=c[A>>2]|0}else{ca=c[B+4>>2]|0;da=c[B>>2]|0}c[z>>2]=da;c[z+4>>2]=ca;q=c[z+4>>2]|0;D=c[v+4>>2]|0;if((q|0)>=(D|0)&((q|0)>(D|0)|(c[z>>2]|0)>>>0>=(c[v>>2]|0)>>>0)){P=41;break a}I=I+1|0}j=j+1|0}if((P|0)==20){Cd(2581320,2558456,575,2653168);return 0}else if((P|0)==41){c[u>>2]=-1;c[u+4>>2]=2147483647;ea=u|0;fa=c[ea>>2]|0;ga=u+4|0;ha=c[ga>>2]|0;i=s;return(G=ha,fa)|0}else if((P|0)==46){P=c[w+4>>2]|0;j=l;c[j>>2]=(c[w>>2]|0)>>>2|P<<30;c[j+4>>2]=P>>2|((P|0)<0|0?-1:0)<<30;c[k>>2]=E;E=c[x+4>>2]|0;P=m;c[P>>2]=(c[x>>2]|0)>>>2|E<<30;c[P+4>>2]=E>>2|((E|0)<0|0?-1:0)<<30;E=c[k>>2]|0;k=c[f+75248>>2]|0;P=Erc(E,(E|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=wrc(128,0,P,G)|0;P=G;E=l;l=yrc(c[E>>2]|0,c[E+4>>2]|0,c[f+75244>>2]|0)|0;f=wrc(k>>>8|P<<24,P>>8|((P|0)<0|0?-1:0)<<24,l,G)|0;c[u>>2]=f;c[u+4>>2]=G;ea=u|0;fa=c[ea>>2]|0;ga=u+4|0;ha=c[ga>>2]|0;i=s;return(G=ha,fa)|0}return 0}function k4b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=b;b=c[1960336+(a<<2)>>2]|0;a=(ca(e>>b<<2,d)|0)+((e&(1<<b)-1)<<2)|0;i=i;return a|0}function l4b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a;a=d+((k4b(f,b,c[777792+(f<<2)>>2]<<2)|0)<<1)|0;i=e;return a|0}function m4b(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=b;b=g+32768|0;if((Thc(g+1448e3|0,d[(c[c[b+24880>>2]>>2]|0)+13|0]|0,3)|0)!=0){h=0;j=h;i=f;return j|0}g=a;if(g>>>0>=10>>>0){k=g>>>0<=13>>>0}else{k=0}if((k&1|0)!=0){}else{Cd(2561328,2558456,1461,2653152);return 0}h=c[b+1123992+(e<<4)+(a-10<<2)>>2]|0;j=h;i=f;return j|0}function n4b(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;k=i;i=i+64|0;l=k|0;m=k+24|0;n=k+32|0;o=k+40|0;p=k+56|0;q=a;a=d;d=e;e=f;f=g;g=h;h=j;j=a+24720|0;r=q+1434592|0;s=c[c[j+160>>2]>>2]|0;mrc(l|0,0,24)|0;t=2147483647;u=c[a+75236>>2]|0;v=c[s+20>>2]|0;w=n;x=s+36+(v<<3)|0;b[w>>1]=b[x>>1]|0;b[w+2>>1]=b[x+2>>1]|0;x=c[a+1128236>>2]|0;w=c[a+1128240>>2]|0;y=c[a+1128244>>2]|0;z=c[a+1128248>>2]|0;A=M3b(q,v)|0;B=o|0;C=s+36+(v<<3)|0;b[B>>1]=b[C>>1]|0;b[B+2>>1]=b[C+2>>1]|0;C=o+4|0;B=s+36+(v<<3)+4|0;b[C>>1]=b[B>>1]|0;b[C+2>>1]=b[B+2>>1]|0;B=o+8|0;C=a+1184596+(v<<2)|0;b[B>>1]=b[C>>1]|0;b[B+2>>1]=b[C+2>>1]|0;if((A|0)!=0){C=0;while(1){if((C|0)>=3){break}B=l+(C<<3)|0;s=j+(C*52|0)+24|0;c[B>>2]=c[s>>2];c[B+4>>2]=c[s+4>>2];C=C+1|0}Agc(j,0,A,e,f,0)}Xnc(a,n);do{if((c[q+2046908>>2]|0)!=0){if((c[q+1444704>>2]|0)==0){D=10;break}f=Ync(q,c[a+75284+(v<<2)>>2]|0)|0;E=f+(c[q+2047168>>2]|0)>>1}else{D=10}}while(0);if((D|0)==10){E=c[q+2047168>>2]|0}do{if((c[q+2047004>>2]|0)!=0){if(!(d>>>0<12>>>0)){break}if((c[q+1444704>>2]|0)==0){break}if((c[1960696+(d<<2)>>2]|0)<(c[1960336+(d<<2)>>2]|0)){F=c[1960696+(d<<2)>>2]|0}else{F=c[1960336+(d<<2)>>2]|0}f=(c[1960336+(12<<2)>>2]|0)-F<<1;if((E|0)>(f|0)){G=E}else{G=f}E=G}}while(0);do{if((c[q+2047004>>2]|0)!=0){if((c[a+75320+(v<<2)>>2]>>(c[1960336+(d<<2)>>2]|0)+(c[1960696+(d<<2)>>2]|0)+4|0)<5){E=E+2|0}G=1;while(1){if((G|0)<=3){H=(c[q+1444704>>2]|0)!=0}else{H=0}if(!H){D=38;break}if((c[a+75320+(v<<2)>>2]>>3|0)>(c[a+75320+(G<<2)>>2]|0)){break}G=G+1|0}if((D|0)==38){break}c[a+1184596+(v<<2)>>2]=0;c[g>>2]=-2147450880;if((A|0)!=0){G=0;while(1){if((G|0)>=3){break}F=j+(G*52|0)+24|0;f=l+(G<<3)|0;c[F>>2]=c[f>>2];c[F+4>>2]=c[f+4>>2];G=G+1|0}}i=k;return}}while(0);D=m;H=o+(c[a+75268+(v<<2)>>2]<<2)|0;b[D>>1]=b[H>>1]|0;b[D+2>>1]=b[H+2>>1]|0;H=m+2|0;b[H>>1]=b[H>>1]>>3;H=m|0;b[H>>1]=b[H>>1]>>3;H=(c[q+2046900>>2]|0)-1-E|0;if((c[q+2046880>>2]|0)==6){t=koc(a,m,E,u,0,q+2047252+(d*44|0)|0,1,n,g)|0;if((t|0)<2147483647){t=doc(a,g,n,q+2047252+(d*44|0)|0,1)|0}}else{if((c[q+2046880>>2]|0)==5){t=joc(a,m,E,u,0,q+2047252+(d*44|0)|0,1,n,g)|0;if((t|0)<2147483647){t=doc(a,g,n,q+2047252+(d*44|0)|0,1)|0}}else{if((c[q+2046880>>2]|0)==2){t=foc(a,m,E,u,1,q+2047252+(d*44|0)|0,1,n,g)|0;if((t|0)<2147483647){t=doc(a,g,n,q+2047252+(d*44|0)|0,1)|0}}else{if((c[q+2046880>>2]|0)==4){t=ioc(a,m,E,u,1,q+2047252+(d*44|0)|0,1,n,g)|0;if((t|0)<2147483647){t=doc(a,g,n,q+2047252+(d*44|0)|0,1)|0}}else{if((c[q+2046880>>2]|0)==3){t=hoc(a,m,E,u,1,q+2047252+(d*44|0)|0,1,n,g)|0;if((t|0)<2147483647){t=doc(a,g,n,q+2047252+(d*44|0)|0,1)|0}}else{t=ooc(q,a,m,E,u,H,1,q+2047252+(d*44|0)|0,n,g)|0}}}}}c[a+1128236>>2]=x;c[a+1128240>>2]=w;c[a+1128244>>2]=y;c[a+1128248>>2]=z;if((t|0)<2147483647){Qe[c[q+2047232>>2]&3](a,g,n,c[r+10128>>2]|0,c[a+75232>>2]|0,q+2047252+(d*44|0)|0,c[q+2046896>>2]|0,c[q+2046892>>2]|0,a+75336|0,c[a+599640>>2]|0,p,a+75304+(v<<2)|0)|0}c[h>>2]=Znc(g,n,a+75336|0,c[a+599640>>2]|0,108)|0;do{if((c[q+2047004>>2]|0)!=0){if((c[q+1444704>>2]|0)==0){break}c[a+1184596+(v<<2)>>2]=c[g>>2]}}while(0);if((A|0)==0){i=k;return}A=0;while(1){if((A|0)>=3){break}g=j+(A*52|0)+24|0;v=l+(A<<3)|0;c[g>>2]=c[v>>2];c[g+4>>2]=c[v+4>>2];A=A+1|0}i=k;return}function o4b(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+64|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;r=j+56|0;s=a;a=d;d=e;e=f;f=g;g=h;c[k>>2]=0;c[k+4>>2]=0;c[l>>2]=0;c[l+4>>2]=0;h=c[(c[c[e+160>>2]>>2]|0)+20>>2]|0;t=0;while(1){if((t|0)>=3){u=15;break}v=d+(t*8240|0)|0;w=e+(t*52|0)|0;x=w;y=c[558424+(a<<4)+(c[x+8>>2]<<3)+(c[x+12>>2]<<2)>>2]|0;if(!(y>>>0<13>>>0)){u=4;break}x=y;Xe[c[s+2047252+(x*44|0)+8>>2]&511](c[v+8204>>2]|0,c[v+8208>>2]|0,c[w+16>>2]|0,c[w+20>>2]|0,m)|0;if((t|0)==0){c[d+75304+(h<<2)>>2]=c[m>>2]}if((c[s+2046860>>2]|0)>4){c[p>>2]=c[m>>2];c[p+4>>2]=0;v=b[(c[w+40>>2]|0)+2>>1]>>3;if((v|0)<120){y=280-v|0;z=Erc(c[p>>2]|0,c[p+4>>2]|0,y,(y|0)<0|0?-1:0)|0;y=G;c[n>>2]=z>>>8|y<<24;c[n+4>>2]=y>>8|((y|0)<0|0?-1:0)<<24}else{c[n>>2]=0;c[n+4>>2]=0}y=v;v=Erc(c[p>>2]|0,c[p+4>>2]|0,y,(y|0)<0|0?-1:0)|0;y=G;c[o>>2]=v>>>8|y<<24;c[o+4>>2]=y>>8|((y|0)<0|0?-1:0)<<24;y=wrc(c[k>>2]|0,c[k+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0)|0;c[k>>2]=y;c[k+4>>2]=G;y=wrc(c[l>>2]|0,c[l+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[l>>2]=y;c[l+4>>2]=G}else{F3b(c[m>>2]|0,1<<c[777552+(x<<2)>>2],b[(c[w+40>>2]|0)+2>>1]>>3,q,r);w=c[q>>2]|0;x=wrc(c[k>>2]|0,c[k+4>>2]|0,w,(w|0)<0|0?-1:0)|0;c[k>>2]=x;c[k+4>>2]=G;x=wrc(c[l>>2]|0,c[l+4>>2]|0,c[r>>2]|0,c[r+4>>2]|0)|0;c[l>>2]=x;c[l+4>>2]=G}t=t+1|0}if((u|0)==4){Cd(2437376,2427112,292,2652440)}else if((u|0)==15){c[f>>2]=c[k>>2];k=c[l>>2]|0;f=c[l+4>>2]<<4|k>>>28;l=g;c[l>>2]=k<<4|0>>>28;c[l+4>>2]=f;i=j;return}}function p4b(a,b,d,e,f,g,h,j,k,l){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;m=i;i=i+120|0;n=m|0;o=m+8|0;p=m+40|0;q=m+56|0;r=m+88|0;s=a;a=b;b=d;d=e;e=f;f=g;g=h;h=j;c[n>>2]=k;c[n+4>>2]=l;l=a+24720|0;k=c[c[l+160>>2]>>2]|0;j=c[833024+(g<<2)>>2]|0;if((g|0)==(c[k>>2]|0)){}else{Cd(2526360,2558456,960,2652008)}zmc(a,g,0);if((c[s+2046944>>2]|0)==3){mrc(h|0,0,40)|0;q4b(s,a,b,d,e,r|0,c[n>>2]|0,c[n+4>>2]|0,g);if((f|0)!=0){t=r+(c[k+8>>2]<<3)|0;u=c[t+4>>2]|0;v=f;c[v>>2]=c[t>>2];c[v+4>>2]=u}i=m;return}if((c[s+2046944>>2]|0)==2){w=0;while(1){if(!(w>>>0<=j>>>0)){break}r4b(s,g,w,a,l,o+(w<<3)|0,q+(w<<3)|0,p+(w<<2)|0);w=w+1|0}s4b(s,a,o|0,b,q|0,d,p|0,e,r|0,c[n>>2]|0,c[n+4>>2]|0,g)}else{w=0;while(1){if(!(w>>>0<=j>>>0)){break}c4b(a,o+(w<<3)|0,q+(w<<3)|0,p+(w<<2)|0,r+(w<<3)|0,c[n>>2]|0,c[n+4>>2]|0,0,g,w,c[s+2047144>>2]|0);w=w+1|0}t4b(s,a,o|0,b,q|0,d,p|0,e,h,g)}if((f|0)==0){i=m;return}g=r+(c[k+8>>2]<<3)|0;k=c[g+4>>2]|0;r=f;c[r>>2]=c[g>>2];c[r+4>>2]=k;i=m;return}function q4b(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;l=i;i=i+8|0;m=l|0;n=a;a=b;c[m>>2]=h;c[m+4>>2]=j;j=k;k=c[833024+(j<<2)>>2]|0;h=c[301584+(c[n+1444756>>2]<<2)>>2]|0;b=c[c[a+24880>>2]>>2]|0;if(k>>>0<h>>>0){o=k}else{o=h}c[b+8>>2]=o;c4b(a,d,e,f,g+(c[b+8>>2]<<3)|0,c[m>>2]|0,c[m+4>>2]|0,0,j,c[b+8>>2]|0,c[n+2047144>>2]|0);b=n+2050776|0;c[b>>2]=(c[b>>2]|0)+1;i=l;return}function r4b(a,d,e,f,g,h,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;l=i;i=i+32|0;m=l|0;n=l+8|0;o=l+16|0;p=l+24|0;q=a;a=d;d=e;e=h;h=j;j=k;k=f|0;f=g|0;g=c[777792+(a<<2)>>2]<<2;r=c[777848+(a<<2)>>2]<<2;a=0;c[m>>2]=0;c[m+4>>2]=0;s=4<<d;if((d|0)==0){t=0}else{if((d|0)==1){t=3}else{if((d|0)==2){t=6}else{if((d|0)!=3){Cd(2474256,2558456,503,2651920)}t=9}}}c[j>>2]=1;d=0;while(1){if((d|0)>=(r|0)){break}u=0;while(1){if((u|0)>=(g|0)){break}v=(ca(d,c[k+8208>>2]|0)|0)+u|0;w=(ca(d,c[f+20>>2]|0)|0)+u|0;Xe[c[q+2047252+(t*44|0)+8>>2]&511]((c[k+8204>>2]|0)+v|0,c[k+8208>>2]|0,(c[f+16>>2]|0)+w|0,c[f+20>>2]|0,p)|0;w=ca(s,s)|0;F3b(c[p>>2]|0,w,b[(c[f+40>>2]|0)+2>>1]>>3,n,o);a=a+(c[n>>2]|0)|0;w=wrc(c[m>>2]|0,c[m+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[m>>2]=w;c[m+4>>2]=G;w=j;c[w>>2]=c[w>>2]&(c[n>>2]|0)<1024;u=u+s|0}d=d+s|0}c[e>>2]=a;a=c[m>>2]|0;e=c[m+4>>2]<<4|a>>>28;m=h;c[m>>2]=a<<4|0>>>28;c[m+4>>2]=e;i=l;return}function s4b(b,e,f,g,j,k,l,m,n,o,p,q){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0.0,H=0,I=0,J=0,K=0;r=i;i=i+112|0;s=r|0;t=r+8|0;u=r+72|0;v=r+104|0;w=b;b=e;e=f;f=g;g=j;j=k;k=l;l=m;m=n;c[s>>2]=o;c[s+4>>2]=p;p=q;q=c[833024+(p<<2)>>2]|0;o=w+1434592|0;n=b+24720|0;x=c[c[n+160>>2]>>2]|0;y=n;z=y;if((c[z+164>>2]|0)!=0){A=c[(c[z+160>>2]|0)+(-(c[z+156>>2]|0)<<2)>>2]|0}else{A=0}z=A;A=y;if((c[A+168>>2]|0)!=0){B=c[(c[A+160>>2]|0)-4>>2]|0}else{B=0}A=B;if((z|0)!=0){C=d[z+12|0]|0}else{C=0}if((A|0)!=0){D=d[A+12|0]|0}else{D=0}A=a[o+15507+(C+D)|0]|0;nrc(t|0,1706752,64)|0;D=u;c[D>>2]=c[426680];c[D+4>>2]=c[426681];c[D+8>>2]=c[426682];c[D+12>>2]=c[426683];c[D+16>>2]=c[426684];c[D+20>>2]=c[426685];c[D+24>>2]=c[426686];c[D+28>>2]=c[426687];D=c[301584+(c[o+10164>>2]<<2)>>2]|0;c[v>>2]=-1;c[v+4>>2]=2147483647;C=0;z=igc(n)|0;n=o+15495|0;B=q;if((B|0)==2){E=n+6+(z<<1)|0}else if((B|0)==3){E=n+(z*3|0)|0}else if((B|0)==1){E=n+10+z|0}else{Cd(2497104,2485880,111,2652144)}z=E;if((A&255|0)>0){}else{Cd(2511200,2558456,900,2653312)}E=c[206872+((A&255)<<2)>>2]|0;n=c[206872+(255-(A&255)<<2)>>2]|0;A=0;while(1){if(!(A>>>0<=q>>>0)){break}F=+h[u+(A<<3)>>3];c[e+(A<<3)+4>>2]=c[e+(A<<3)>>2];B=0;while(1){if((B|0)>(A-((A|0)==(q|0))|0)){break}if((B|0)==(A|0)){y=e+(A<<3)+4|0;c[y>>2]=(c[y>>2]|0)+(c[206872+((d[z+B|0]|0)<<2)>>2]|0)}else{y=e+(A<<3)+4|0;c[y>>2]=(c[y>>2]|0)+(c[206872+(255-(d[z+B|0]|0)<<2)>>2]|0)}B=B+1|0}if((c[k+(A<<2)>>2]|0)!=0){B=g+(A<<3)|0;y=u4b(c[b+75248>>2]|0,c[b+75244>>2]|0,n,c[B>>2]|0,c[B+4>>2]|0,F)|0;B=G;H=t+(A<<4)+8|0;c[H>>2]=y;c[H+4>>2]=B;H=t+(A<<4)|0;c[H>>2]=y;c[H+4>>2]=B}else{B=g+(A<<3)|0;H=u4b(c[b+75248>>2]|0,c[b+75244>>2]|0,(c[e+(A<<3)>>2]|0)+E|0,c[B>>2]|0,c[B+4>>2]|0,F)|0;B=t+(A<<4)|0;c[B>>2]=H;c[B+4>>2]=G;B=g+(A<<3)|0;H=u4b(c[b+75248>>2]|0,c[b+75244>>2]|0,(c[e+(A<<3)+4>>2]|0)+E|0,c[B>>2]|0,c[B+4>>2]|0,F)|0;B=t+(A<<4)+8|0;c[B>>2]=H;c[B+4>>2]=G}B=t+(A<<4)+8|0;H=c[B+4>>2]|0;y=c[v+4>>2]|0;if((H|0)<(y|0)|(H|0)==(y|0)&(c[B>>2]|0)>>>0<(c[v>>2]|0)>>>0){B=t+(A<<4)+8|0;y=c[B+4>>2]|0;c[v>>2]=c[B>>2];c[v+4>>2]=y;C=A}A=A+1|0}if((c[o+10164>>2]|0)==4){I=C}else{if(q>>>0<D>>>0){J=q}else{J=D}I=J}c[x+8>>2]=I;c4b(b,f,j,l,m+(c[x+8>>2]<<3)|0,c[s>>2]|0,c[s+4>>2]|0,0,p,c[x+8>>2]|0,c[w+2047144>>2]|0);do{if((q|0)==3){if((C|0)!=3){break}x=w+2050776|0;c[x>>2]=(c[x>>2]|0)+1;i=r;return}}while(0);do{if(q>>>0>=2>>>0){if((C|0)!=2){K=48;break}x=w+2050776+(q-2<<2)|0;c[x>>2]=(c[x>>2]|0)+1}else{K=48}}while(0);if((K|0)==48){K=t+24|0;C=c[K+4>>2]|0;x=t+8|0;t=c[x+4>>2]|0;if((C|0)<=(t|0)&((C|0)<(t|0)|(c[K>>2]|0)>>>0<=(c[x>>2]|0)>>>0)){x=w+2050776+(q-1<<2)|0;c[x>>2]=(c[x>>2]|0)+1}else{x=w+2050776+(q<<2)|0;c[x>>2]=(c[x>>2]|0)+1}}i=r;return}function t4b(b,e,f,g,h,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0;o=i;i=i+72|0;p=o|0;q=o+64|0;r=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=c[833024+(n<<2)>>2]|0;n=r+1434592|0;s=b+24720|0;t=c[c[s+160>>2]>>2]|0;u=s;v=u;if((c[v+164>>2]|0)!=0){w=c[(c[v+160>>2]|0)+(-(c[v+156>>2]|0)<<2)>>2]|0}else{w=0}v=w;w=u;if((c[w+168>>2]|0)!=0){x=c[(c[w+160>>2]|0)-4>>2]|0}else{x=0}w=x;if((v|0)!=0){y=d[v+12|0]|0}else{y=0}if((w|0)!=0){z=d[w+12|0]|0}else{z=0}w=a[n+15507+(y+z)|0]|0;nrc(p|0,1706656,64)|0;z=c[301584+(c[n+10164>>2]<<2)>>2]|0;c[q>>2]=-1;c[q+4>>2]=2147483647;y=0;v=igc(s)|0;s=n+15495|0;x=m;if((x|0)==1){A=s+10+v|0}else if((x|0)==2){A=s+6+(v<<1)|0}else if((x|0)==3){A=s+(v*3|0)|0}else{Cd(2497104,2485880,111,2652144)}v=A;if((w&255|0)>0){}else{Cd(2511200,2558456,816,2653280)}A=c[206872+((w&255)<<2)>>2]|0;s=c[206872+(255-(w&255)<<2)>>2]|0;w=0;while(1){if(!(w>>>0<=m>>>0)){break}c[e+(w<<3)+4>>2]=c[e+(w<<3)>>2];if((c[e+(w<<3)>>2]|0)<2147483647){x=0;while(1){if((x|0)>(w-((w|0)==(m|0))|0)){break}if((x|0)==(w|0)){u=e+(w<<3)+4|0;c[u>>2]=(c[u>>2]|0)+(c[206872+((d[v+x|0]|0)<<2)>>2]|0)}else{u=e+(w<<3)+4|0;c[u>>2]=(c[u>>2]|0)+(c[206872+(255-(d[v+x|0]|0)<<2)>>2]|0)}x=x+1|0}}x=g+(w<<3)|0;if((c[x>>2]|0)==(-1|0)&(c[x+4>>2]|0)==2147483647){x=p+(w<<4)+8|0;c[x>>2]=-1;c[x+4>>2]=2147483647;x=p+(w<<4)|0;c[x>>2]=-1;c[x+4>>2]=2147483647}else{if((c[j+(w<<2)>>2]|0)!=0){x=s;u=c[b+75248>>2]|0;B=Erc(x,(x|0)<0|0?-1:0,u,(u|0)<0|0?-1:0)|0;u=wrc(128,0,B,G)|0;B=G;x=g+(w<<3)|0;C=yrc(c[x>>2]|0,c[x+4>>2]|0,c[b+75244>>2]|0)|0;x=wrc(u>>>8|B<<24,B>>8|((B|0)<0|0?-1:0)<<24,C,G)|0;C=G;B=p+(w<<4)+8|0;c[B>>2]=x;c[B+4>>2]=C;B=p+(w<<4)|0;c[B>>2]=x;c[B+4>>2]=C}else{C=c[e+(w<<3)>>2]|0;B=A;x=wrc(C,(C|0)<0|0?-1:0,B,(B|0)<0|0?-1:0)|0;B=c[b+75248>>2]|0;C=Erc(x,G,B,(B|0)<0|0?-1:0)|0;B=wrc(128,0,C,G)|0;C=G;x=g+(w<<3)|0;u=yrc(c[x>>2]|0,c[x+4>>2]|0,c[b+75244>>2]|0)|0;x=wrc(B>>>8|C<<24,C>>8|((C|0)<0|0?-1:0)<<24,u,G)|0;u=p+(w<<4)|0;c[u>>2]=x;c[u+4>>2]=G;u=c[e+(w<<3)+4>>2]|0;x=A;C=wrc(u,(u|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=c[b+75248>>2]|0;u=Erc(C,G,x,(x|0)<0|0?-1:0)|0;x=wrc(128,0,u,G)|0;u=G;C=g+(w<<3)|0;B=yrc(c[C>>2]|0,c[C+4>>2]|0,c[b+75244>>2]|0)|0;C=wrc(x>>>8|u<<24,u>>8|((u|0)<0|0?-1:0)<<24,B,G)|0;B=p+(w<<4)+8|0;c[B>>2]=C;c[B+4>>2]=G}}B=p+(w<<4)+8|0;C=c[B+4>>2]|0;u=c[q+4>>2]|0;if((C|0)<(u|0)|(C|0)==(u|0)&(c[B>>2]|0)>>>0<(c[q>>2]|0)>>>0){y=w;B=p+(w<<4)+8|0;u=c[B+4>>2]|0;c[q>>2]=c[B>>2];c[q+4>>2]=u}w=w+1|0}if((c[n+10164>>2]|0)==4){D=y}else{if(m>>>0<z>>>0){E=m}else{E=z}D=E}c[t+8>>2]=D;D=g+(c[t+8>>2]<<3)|0;g=c[D+4>>2]|0;E=h;c[E>>2]=c[D>>2];c[E+4>>2]=g;c[f>>2]=c[e+(c[t+8>>2]<<3)+(((c[n+10164>>2]|0)==4)<<2)>>2];c[k>>2]=c[j+(c[t+8>>2]<<2)>>2];t=p|0;j=c[t+4>>2]|0;k=l|0;c[k>>2]=c[t>>2];c[k+4>>2]=j;j=p+16|0;k=c[j+4>>2]|0;t=l+8|0;c[t>>2]=c[j>>2];c[t+4>>2]=k;if(m>>>0<2>>>0){F=m}else{F=2}k=p+(F<<4)|0;F=c[k+4>>2]|0;t=l+16|0;c[t>>2]=c[k>>2];c[t+4>>2]=F;if(m>>>0<3>>>0){H=m}else{H=3}F=p+(H<<4)|0;H=c[F+4>>2]|0;t=l+24|0;c[t>>2]=c[F>>2];c[t+4>>2]=H;do{if((m|0)==3){if((y|0)!=3){break}H=p+56|0;t=c[H+4>>2]|0;F=l+32|0;c[F>>2]=c[H>>2];c[F+4>>2]=t;t=r+2050776|0;c[t>>2]=(c[t>>2]|0)+1;i=o;return}}while(0);do{if(m>>>0>=2>>>0){if((y|0)!=2){I=59;break}t=p+40|0;F=c[t+4>>2]|0;H=l+32|0;c[H>>2]=c[t>>2];c[H+4>>2]=F;F=r+2050776+(m-2<<2)|0;c[F>>2]=(c[F>>2]|0)+1}else{I=59}}while(0);if((I|0)==59){I=p+24|0;y=c[I+4>>2]|0;F=p+8|0;H=c[F+4>>2]|0;if((y|0)<(H|0)|(y|0)==(H|0)&(c[I>>2]|0)>>>0<(c[F>>2]|0)>>>0){F=p+24|0;I=c[F+4>>2]|0;H=l+32|0;c[H>>2]=c[F>>2];c[H+4>>2]=I;I=r+2050776+(m-1<<2)|0;c[I>>2]=(c[I>>2]|0)+1}else{I=p+8|0;p=c[I+4>>2]|0;H=l+32|0;c[H>>2]=c[I>>2];c[H+4>>2]=p;p=r+2050776+(m<<2)|0;c[p>>2]=(c[p>>2]|0)+1}}i=o;return}function u4b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=+g;var h=0,j=0,k=0.0;h=i;i=i+8|0;j=h|0;c[j>>2]=e;c[j+4>>2]=f;f=d;d=a;a=Erc(f,(f|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;d=wrc(128,0,a,G)|0;a=G;f=yrc(c[j>>2]|0,c[j+4>>2]|0,b|0)|0;b=wrc(d>>>8|a<<24,a>>8|((a|0)<0|0?-1:0)<<24,f,G)|0;k=(+(b>>>0)+ +(G|0)*4294967296.0)*g;b=(F=+k,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);i=h;return(G=b,~~+k>>>0)|0}function v4b(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;i=i+8|0;k=a;a=b;b=d;d=e;e=f;c[(c[c[a+24880>>2]>>2]|0)+16>>2]=0;b4b(k,a,d,e,g,j|0,h,-1,2147483647);c[b>>2]=(c[d>>2]|0)+(c[a+1124104+((c[k+1444700>>2]|0)*40|0)>>2]|0);k=c[b>>2]|0;b=c[a+75248>>2]|0;d=Erc(k,(k|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;b=wrc(128,0,d,G)|0;d=G;k=e;e=yrc(c[k>>2]|0,c[k+4>>2]|0,c[a+75244>>2]|0)|0;a=wrc(b>>>8|d<<24,d>>8|((d|0)<0|0?-1:0)<<24,e,G)|0;e=G;i=j;return(G=e,a)|0}function w4b(f,g,h,j,k,l,m,n,o,p,q,r,s){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;s=s|0;var t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;t=i;i=i+1168|0;u=t|0;v=t+1024|0;w=t+1032|0;x=t+1040|0;y=t+1048|0;z=t+1056|0;A=t+1064|0;B=t+1072|0;C=t+1080|0;D=t+1144|0;E=t+1152|0;F=t+1160|0;H=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=p;p=q;c[w>>2]=r;c[w+4>>2]=s;s=f+24720|0;r=c[w+4>>2]|0;c[x>>2]=c[w>>2];c[x+4>>2]=r;r=f|0;q=s|0;I=c[r+8208>>2]|0;J=c[q+20>>2]|0;K=k4b(3,g,I)|0;L=(c[r+8204>>2]|0)+K|0;K=k4b(3,g,J)|0;M=(c[q+16>>2]|0)+K|0;K=c[777792+(p<<2)>>2]|0;N=c[777848+(p<<2)>>2]|0;if((g|0)<4){}else{Cd(2454464,2558456,1071,2651512);return 0}p=y;O=k;a[p]=a[O]|0;a[p+1|0]=a[O+1|0]|0;O=A;p=l;a[O]=a[p]|0;a[O+1|0]=a[p+1|0]|0;c[(c[c[s+160>>2]>>2]|0)+8>>2]=0;p=0;a:while(1){if(!(p>>>0<=9>>>0)){P=101;break}O=0;c[E>>2]=0;c[E+4>>2]=0;Q=c[j+(p<<2)>>2]|0;b:do{if((c[H+2047036>>2]&1<<p|0)!=0){do{if((c[H+2047024>>2]&16|0)!=0){if((U3b(p,c[h>>2]|0)|0)!=0){break b}else{break}}}while(0);R=z;S=y;a[R]=a[S]|0;a[R+1|0]=a[S+1|0]|0;S=B;R=A;a[S]=a[R]|0;a[S+1|0]=a[R+1|0]|0;T=0;c:while(1){if((T|0)>=(N|0)){P=92;break}R=0;while(1){if((R|0)>=(K|0)){break}S=g+(T<<1)+R|0;U=L+((R<<2)+(ca(T<<2,I)|0))|0;V=M+((R<<2)+(ca(T<<2,J)|0))|0;W=l4b(3,S,r|0)|0;X=(c[f+8196>>2]|0)+(S<<4<<1)|0;c[(c[c[s+160>>2]>>2]|0)+76+(S*12|0)>>2]=p;if((c[f+1184592>>2]|0)!=0){Y=U}else{Y=V}if((c[f+1184592>>2]|0)!=0){Z=I}else{Z=J}Chc(s,S,1,0,p,Y,Z,V,J,R,T,0);ymc(4,4,W,8,U,I,V,J);if((c[s+25808>>2]|0)!=0){U=218736;elc(W,X,8);E2b(f,0,S,c[U>>2]|0,c[U+4>>2]|0);_=f;$=0;aa=S;ba=z+R|0;da=B+T|0;ea=0;fa=c[U>>2]|0;ga=c[U+8>>2]|0;U=c[H+2047144>>2]|0;ha=_+24720|0;ia=c[c[ha+160>>2]>>2]|0;ja=_+($*8240|0)|0;ka=c[ha+($*52|0)+4>>2]|0;$=1960274+(ea<<4)|0;ha=e[(c[ja+8200>>2]|0)+(aa<<1)>>1]|0;la=(c[ja+8192>>2]|0)+(aa<<4<<1)|0;aa=_+1129288+(ea*13824|0)+(ka*6912|0)+(((c[ia+20>>2]|0)>0|0)*3456|0)|0;_=((a[ba]|0)!=0)+((a[da]|0)!=0)|0;if((ka|0)==0){if((c[ia+8>>2]|0)!=(ea|0)){P=31;break a}}else{ka=ia;ia=c[ka+8>>2]|0;ja=c[ka>>2]|0;if(ja>>>0<3>>>0){ma=0}else{ka=c[558436+(ja<<4)>>2]|0;if(ia>>>0<(c[833024+(ka<<2)>>2]|0)>>>0){na=ia}else{na=c[833024+(ka<<2)>>2]|0}ma=na}if((ma|0)!=(ea|0)){P=31;break a}}if((ha|0)==0){oa=c[aa+(_*48|0)+44>>2]|0;pa=0}else{ea=$;$=ea+2|0;ka=b[ea>>1]|0;ea=b[la>>1]|0;ia=b[(c[837020]|0)+(ea<<2)>>1]|0;oa=(c[aa+(_*48|0)+(ia<<2)>>2]|0)+(b[(c[837022]|0)+(ea<<1)>>1]|0)|0;a[u|0]=a[206856+ia|0]|0;aa=aa+576|0;pa=1;while(1){if((pa|0)>=(ha|0)){break}ja=b[fa+(pa<<1)>>1]|0;ea=b[la+(ja<<1)>>1]|0;qa=b[(c[837020]|0)+(ea<<2)>>1]|0;if((U|0)!=0){oa=oa+((c[aa+((((ia|0)!=0^1)&1)*288|0)+((((ia|0)!=0^1)&1)*48|0)+(qa<<2)>>2]|0)+(b[(c[837022]|0)+(ea<<1)>>1]|0))|0}else{ra=ga;sa=u|0;ta=pa;_=(d[sa+(b[ra+(ta<<1<<1)>>1]|0)|0]|0)+1+(d[sa+(b[ra+((ta<<1)+1<<1)>>1]|0)|0]|0)>>1;oa=oa+((c[aa+((((ia|0)!=0^1)&1)*288|0)+(_*48|0)+(qa<<2)>>2]|0)+(b[(c[837022]|0)+(ea<<1)>>1]|0))|0;a[u+ja|0]=a[206856+qa|0]|0}ia=qa;qa=ka-1|0;ka=qa;if((qa|0)==0){qa=$;$=qa+2|0;ka=b[qa>>1]|0;aa=aa+576|0}pa=pa+1|0}if((ka|0)!=0){if((U|0)!=0){oa=oa+(c[aa+((((ia|0)!=0^1)&1)*48|0)+44>>2]|0)|0}else{$=ga;ea=u|0;la=pa;_=(d[ea+(b[$+(la<<1<<1)>>1]|0)|0]|0)+1+(d[ea+(b[$+((la<<1)+1<<1)>>1]|0)|0]|0)>>1;oa=oa+(c[aa+(_*48|0)+44>>2]|0)|0}}}la=(pa|0)>0&255;a[da]=la;a[ba]=la;O=O+oa|0;la=O;$=c[f+75248>>2]|0;ea=Erc(la,(la|0)<0|0?-1:0,$,($|0)<0|0?-1:0)|0;$=wrc(128,0,ea,G)|0;ea=G;la=yrc(c[E>>2]|0,c[E+4>>2]|0,c[f+75244>>2]|0)|0;fa=wrc($>>>8|ea<<24,ea>>8|((ea|0)<0|0?-1:0)<<24,la,G)|0;la=G;ea=c[x+4>>2]|0;if((la|0)>=(ea|0)&((la|0)>(ea|0)|fa>>>0>=(c[x>>2]|0)>>>0)){P=49;break c}ofc((c[q>>2]|0)+(S<<4<<1)|0,V,J,e[(c[r+8200>>2]|0)+(S<<1)>>1]|0)}else{fa=s;ea=S;la=c[c[fa+160>>2]>>2]|0;do{if(0!=0){P=54}else{if((c[fa+25808>>2]|0)!=0){P=54;break}if((c[la+20>>2]|0)>0){P=54;break}$=la;if((c[$>>2]|0)>>>0<3>>>0){ua=c[$+76+(ea*12|0)>>2]|0}else{ua=c[$+4>>2]|0}va=c[1064496+(ua<<2)>>2]|0}}while(0);if((P|0)==54){P=0;va=0}ea=va;la=204488+(ea*12|0)|0;$kc(W,X,8,ea);E2b(f,0,S,c[la>>2]|0,c[la+4>>2]|0);fa=f;ba=0;da=S;_=z+R|0;aa=B+T|0;ga=0;ia=c[la>>2]|0;U=c[la+8>>2]|0;la=c[H+2047144>>2]|0;ka=fa+24720|0;$=c[c[ka+160>>2]>>2]|0;ha=fa+(ba*8240|0)|0;qa=c[ka+(ba*52|0)+4>>2]|0;ba=1960274+(ga<<4)|0;ka=e[(c[ha+8200>>2]|0)+(da<<1)>>1]|0;ja=(c[ha+8192>>2]|0)+(da<<4<<1)|0;da=fa+1129288+(ga*13824|0)+(qa*6912|0)+(((c[$+20>>2]|0)>0|0)*3456|0)|0;fa=((a[_]|0)!=0)+((a[aa]|0)!=0)|0;if((qa|0)==0){if((c[$+8>>2]|0)!=(ga|0)){P=68;break a}}else{qa=$;$=c[qa+8>>2]|0;ha=c[qa>>2]|0;if(ha>>>0<3>>>0){wa=0}else{qa=c[558436+(ha<<4)>>2]|0;if($>>>0<(c[833024+(qa<<2)>>2]|0)>>>0){xa=$}else{xa=c[833024+(qa<<2)>>2]|0}wa=xa}if((wa|0)!=(ga|0)){P=68;break a}}if((ka|0)==0){ya=c[da+(fa*48|0)+44>>2]|0;za=0}else{ga=ba;ba=ga+2|0;qa=b[ga>>1]|0;ga=b[ja>>1]|0;$=b[(c[837020]|0)+(ga<<2)>>1]|0;ya=(c[da+(fa*48|0)+($<<2)>>2]|0)+(b[(c[837022]|0)+(ga<<1)>>1]|0)|0;a[u|0]=a[206856+$|0]|0;da=da+576|0;za=1;while(1){if((za|0)>=(ka|0)){break}ha=b[ia+(za<<1)>>1]|0;ga=b[ja+(ha<<1)>>1]|0;ta=b[(c[837020]|0)+(ga<<2)>>1]|0;if((la|0)!=0){ya=ya+((c[da+(((($|0)!=0^1)&1)*288|0)+(((($|0)!=0^1)&1)*48|0)+(ta<<2)>>2]|0)+(b[(c[837022]|0)+(ga<<1)>>1]|0))|0}else{ra=U;sa=u|0;Aa=za;fa=(d[sa+(b[ra+(Aa<<1<<1)>>1]|0)|0]|0)+1+(d[sa+(b[ra+((Aa<<1)+1<<1)>>1]|0)|0]|0)>>1;ya=ya+((c[da+(((($|0)!=0^1)&1)*288|0)+(fa*48|0)+(ta<<2)>>2]|0)+(b[(c[837022]|0)+(ga<<1)>>1]|0))|0;a[u+ha|0]=a[206856+ta|0]|0}$=ta;ta=qa-1|0;qa=ta;if((ta|0)==0){ta=ba;ba=ta+2|0;qa=b[ta>>1]|0;da=da+576|0}za=za+1|0}if((qa|0)!=0){if((la|0)!=0){ya=ya+(c[da+(((($|0)!=0^1)&1)*48|0)+44>>2]|0)|0}else{ba=U;ga=u|0;ja=za;fa=(d[ga+(b[ba+(ja<<1<<1)>>1]|0)|0]|0)+1+(d[ga+(b[ba+((ja<<1)+1<<1)>>1]|0)|0]|0)>>1;ya=ya+(c[da+(fa*48|0)+44>>2]|0)|0}}}ja=(za|0)>0&255;a[aa]=ja;a[_]=ja;O=O+ya|0;ja=H3b(X,(c[q>>2]|0)+(S<<4<<1)|0,16,F)|0;ba=G;ga=wrc(c[E>>2]|0,c[E+4>>2]|0,ja>>>2|ba<<30,ba>>2|((ba|0)<0|0?-1:0)<<30)|0;c[E>>2]=ga;c[E+4>>2]=G;ga=O;ba=c[f+75248>>2]|0;ja=Erc(ga,(ga|0)<0|0?-1:0,ba,(ba|0)<0|0?-1:0)|0;ba=wrc(128,0,ja,G)|0;ja=G;ga=yrc(c[E>>2]|0,c[E+4>>2]|0,c[f+75244>>2]|0)|0;ia=wrc(ba>>>8|ja<<24,ja>>8|((ja|0)<0|0?-1:0)<<24,ga,G)|0;ga=G;ja=c[x+4>>2]|0;if((ga|0)>=(ja|0)&((ga|0)>(ja|0)|ia>>>0>=(c[x>>2]|0)>>>0)){P=86;break c}sfc(ea,(c[q>>2]|0)+(S<<4<<1)|0,V,J,e[(c[r+8200>>2]|0)+(S<<1)>>1]|0)}R=R+1|0}T=T+1|0}if((P|0)==49){P=0}else if((P|0)==86){P=0}else if((P|0)==92){P=0;Q=Q+O|0;R=Q;ia=c[f+75248>>2]|0;ja=Erc(R,(R|0)<0|0?-1:0,ia,(ia|0)<0|0?-1:0)|0;ia=wrc(128,0,ja,G)|0;ja=G;R=yrc(c[E>>2]|0,c[E+4>>2]|0,c[f+75244>>2]|0)|0;ga=wrc(ia>>>8|ja<<24,ja>>8|((ja|0)<0|0?-1:0)<<24,R,G)|0;c[D>>2]=ga;c[D+4>>2]=G;ga=c[D+4>>2]|0;R=c[x+4>>2]|0;if((ga|0)<(R|0)|(ga|0)==(R|0)&(c[D>>2]|0)>>>0<(c[x>>2]|0)>>>0){c[m>>2]=Q;c[n>>2]=O;R=c[E+4>>2]|0;ga=o;c[ga>>2]=c[E>>2];c[ga+4>>2]=R;R=c[D+4>>2]|0;c[x>>2]=c[D>>2];c[x+4>>2]=R;c[h>>2]=p;R=k;ga=z;a[R]=a[ga]|0;a[R+1|0]=a[ga+1|0]|0;ga=l;R=B;a[ga]=a[R]|0;a[ga+1|0]=a[R+1|0]|0;T=0;while(1){if((T|0)>=(N<<2|0)){break}nrc(C+(T<<3)|0,M+(ca(T,J)|0)|0,K<<2)|0;T=T+1|0}}}}}while(0);p=p+1|0}if((P|0)==31){Cd(2581320,2558456,575,2653168);return 0}else if((P|0)==68){Cd(2581320,2558456,575,2653168);return 0}else if((P|0)==101){P=c[x+4>>2]|0;p=c[w+4>>2]|0;do{if(!((P|0)>=(p|0)&((P|0)>(p|0)|(c[x>>2]|0)>>>0>=(c[w>>2]|0)>>>0))){if((c[f+1184592>>2]|0)!=0){break}T=0;while(1){if((T|0)>=(N<<2|0)){break}nrc(M+(ca(T,J)|0)|0,C+(T<<3)|0,K<<2)|0;T=T+1|0}B=c[x+4>>2]|0;c[v>>2]=c[x>>2];c[v+4>>2]=B;Ba=v|0;Ca=c[Ba>>2]|0;Da=v+4|0;Ea=c[Da>>2]|0;i=t;return(G=Ea,Ca)|0}}while(0);T=c[x+4>>2]|0;c[v>>2]=c[x>>2];c[v+4>>2]=T;Ba=v|0;Ca=c[Ba>>2]|0;Da=v+4|0;Ea=c[Da>>2]|0;i=t;return(G=Ea,Ca)|0}return 0}function x4b(a){a=a|0;var b=0,c=0,d=0;b=i;c=~~(+T(+(+((ngc(a,0)|0)<<16>>16|0)/4.0),1.25)*5.12);if((c|0)>8){d=c;i=b;return d|0}else{d=8;i=b;return d|0}return 0}function y4b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;b=0;while(1){e=z4b(d,1)|0;if((e|0)<(a|0)){break}b=b+1|0;d=e}i=c;return b|0}function z4b(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>=(a|0)){break}d=d+1>>1;b=b+1|0}i=c;return d|0}function A4b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0;j=i;k=a;a=b;b=c;c=d;d=e;e=f;f=g;g=h;h=Pqc(ca(f,a)|0)|0;if((b|0)<(a|0)){l=a}else{l=b}m=Pqc(l)|0;l=Pqc(a+e|0)|0;n=0;while(1){if((n|0)>=(a|0)){break}B4b(k+(ca(c,n)|0)|0,b,h+(ca(f,n)|0)|0,f,m);n=n+1|0}n=0;while(1){if((n|0)>=(f|0)){break}C4b(h+n|0,f,a,l);B4b(l,a,l+a|0,e,m);D4b(d+n|0,g,e,l+a|0);n=n+1|0}Qqc(h);Qqc(m);Qqc(l);i=j;return}function B4b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=a;a=b;b=c;c=d;if((a|0)==(c|0)){nrc(b|0,g|0,a)|0;i=f;return}d=y4b(a,c)|0;if((d|0)<=0){G4b(g,a,b,c);i=f;return}h=0;j=0;k=a;if((j|0)!=0){l=e}else{j=Pqc(a)|0;l=j}e=l+(z4b(a,1)|0)|0;a=0;while(1){if((a|0)>=(d|0)){break}m=z4b(k,1)|0;if((a|0)==0){n=g}else{n=h}o=n;do{if((a|0)==(d-1|0)){if((m|0)!=(c|0)){p=15;break}h=b}else{p=15}}while(0);if((p|0)==15){p=0;if((a&1|0)!=0){q=e}else{q=l}h=q}if((k&1|0)!=0){E4b(o,k,h)}else{F4b(o,k,h)}k=m;a=a+1|0}if((k|0)!=(c|0)){G4b(h,k,b,c)}if((j|0)!=0){Qqc(j)}i=f;return}function C4b(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=c;c=d;d=b;b=e;e=0;while(1){if((e|0)>=(c|0)){break}h=b;b=h+1|0;a[h]=a[d]|0;e=e+1|0;d=d+g|0}i=f;return}function D4b(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=c;c=d;d=b;b=e;e=0;while(1){if((e|0)>=(c|0)){break}h=b;b=h+1|0;a[d]=a[h]|0;e=e+1|0;d=d+g|0}i=f;return}function E4b(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;j=e;e=f;f=g;g=3;k=e-4+1|0;g=g+(g&1)|0;k=k+(k&1)|0;if((g|0)>(k|0)){l=0;while(1){if((l|0)>=(e|0)){break}m=(ca(d[j+l|0]|0,b[c[380090]>>1]|0)|0)+64|0;n=1;while(1){if((n|0)>=4){break}if((l-n|0)<0){o=0}else{o=l-n|0}if((l+n|0)>=(e|0)){p=e-1|0}else{p=l+n|0}m=m+(ca((d[j+o|0]|0)+(d[j+p|0]|0)|0,b[(c[380090]|0)+(n<<1)>>1]|0)|0)|0;n=n+1|0}m=m>>7;q=m;if((q|0)>255){r=255}else{if((q|0)<0){s=0}else{s=q}r=s}q=f;f=q+1|0;a[q]=r;l=l+2|0}i=h;return}l=0;while(1){if((l|0)>=(g|0)){break}r=(ca(d[j+l|0]|0,b[c[380090]>>1]|0)|0)+64|0;n=1;while(1){if((n|0)>=4){break}if((l-n|0)<0){t=0}else{t=l-n|0}r=r+(ca((d[j+t|0]|0)+(d[j+(l+n)|0]|0)|0,b[(c[380090]|0)+(n<<1)>>1]|0)|0)|0;n=n+1|0}r=r>>7;m=r;if((m|0)>255){u=255}else{if((m|0)<0){v=0}else{v=m}u=v}m=f;f=m+1|0;a[m]=u;l=l+2|0}while(1){if((l|0)>=(k|0)){break}u=(ca(d[j+l|0]|0,b[c[380090]>>1]|0)|0)+64|0;n=1;while(1){if((n|0)>=4){break}u=u+(ca((d[j+(l-n)|0]|0)+(d[j+(l+n)|0]|0)|0,b[(c[380090]|0)+(n<<1)>>1]|0)|0)|0;n=n+1|0}u=u>>7;r=u;if((r|0)>255){w=255}else{if((r|0)<0){x=0}else{x=r}w=x}r=f;f=r+1|0;a[r]=w;l=l+2|0}while(1){if((l|0)>=(e|0)){break}w=(ca(d[j+l|0]|0,b[c[380090]>>1]|0)|0)+64|0;n=1;while(1){if((n|0)>=4){break}if((l+n|0)>=(e|0)){y=e-1|0}else{y=l+n|0}w=w+(ca((d[j+(l-n)|0]|0)+(d[j+y|0]|0)|0,b[(c[380090]|0)+(n<<1)>>1]|0)|0)|0;n=n+1|0}w=w>>7;u=w;if((u|0)>255){z=255}else{if((u|0)<0){A=0}else{A=u}z=A}u=f;f=u+1|0;a[u]=z;l=l+2|0}i=h;return}function F4b(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;j=e;e=f;f=g;g=4;k=e-4|0;g=g+(g&1)|0;k=k+(k&1)|0;if((g|0)>(k|0)){l=0;while(1){if((l|0)>=(e|0)){break}m=64;n=0;while(1){if((n|0)>=4){break}if((l-n|0)<0){o=0}else{o=l-n|0}if((l+1+n|0)>=(e|0)){p=e-1|0}else{p=l+1+n|0}m=m+(ca((d[j+o|0]|0)+(d[j+p|0]|0)|0,b[(c[380092]|0)+(n<<1)>>1]|0)|0)|0;n=n+1|0}m=m>>7;q=m;if((q|0)>255){r=255}else{if((q|0)<0){s=0}else{s=q}r=s}q=f;f=q+1|0;a[q]=r;l=l+2|0}i=h;return}l=0;while(1){if((l|0)>=(g|0)){break}r=64;n=0;while(1){if((n|0)>=4){break}if((l-n|0)<0){t=0}else{t=l-n|0}r=r+(ca((d[j+t|0]|0)+(d[j+(l+1+n)|0]|0)|0,b[(c[380092]|0)+(n<<1)>>1]|0)|0)|0;n=n+1|0}r=r>>7;m=r;if((m|0)>255){u=255}else{if((m|0)<0){v=0}else{v=m}u=v}m=f;f=m+1|0;a[m]=u;l=l+2|0}while(1){if((l|0)>=(k|0)){break}u=64;n=0;while(1){if((n|0)>=4){break}u=u+(ca((d[j+(l-n)|0]|0)+(d[j+(l+1+n)|0]|0)|0,b[(c[380092]|0)+(n<<1)>>1]|0)|0)|0;n=n+1|0}u=u>>7;r=u;if((r|0)>255){w=255}else{if((r|0)<0){x=0}else{x=r}w=x}r=f;f=r+1|0;a[r]=w;l=l+2|0}while(1){if((l|0)>=(e|0)){break}w=64;n=0;while(1){if((n|0)>=4){break}if((l+1+n|0)>=(e|0)){y=e-1|0}else{y=l+1+n|0}w=w+(ca((d[j+(l-n)|0]|0)+(d[j+y|0]|0)|0,b[(c[380092]|0)+(n<<1)>>1]|0)|0)|0;n=n+1|0}w=w>>7;u=w;if((u|0)>255){z=255}else{if((u|0)<0){A=0}else{A=u}z=A}u=f;f=u+1|0;a[u]=z;l=l+2|0}i=h;return}function G4b(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;n=e;e=f;f=h;h=e;(h|0)<0|0?-1:0;o=(f|0)/2|0;p=wrc(0,h,o,(o|0)<0|0?-1:0)|0;o=f;h=Frc(p,G,o,(o|0)<0|0?-1:0)|0;c[k>>2]=h;c[k+4>>2]=G;if((e|0)>(f|0)){h=e-f|0;o=h;p=(f|0)/2|0;q=wrc(o<<31|0>>>1,((h|0)<0|0?-1:0)<<31|o>>>1,p,(p|0)<0|0?-1:0)|0;p=f;o=Crc(q,G,p,(p|0)<0|0?-1:0)|0;r=G;s=o}else{o=f-e|0;p=o;q=(f|0)/2|0;h=wrc(p<<31|0>>>1,((o|0)<0|0?-1:0)<<31|p>>>1,q,(q|0)<0|0?-1:0)|0;q=xrc(0,0,h,G)|0;h=f;p=Crc(q,G,h,(h|0)<0|0?-1:0)|0;r=G;s=p}c[l>>2]=s;c[l+4>>2]=r;r=g;g=H4b(e,f)|0;s=0;p=c[l+4>>2]|0;c[m>>2]=c[l>>2];c[m+4>>2]=p;while(1){p=c[m+4>>2]|0;h=(p|0)<0|0?-1:0;q=0;if(!((h|0)<(q|0)|(h|0)==(q|0)&p>>>0<3>>>0)){break}s=s+1|0;p=wrc(c[m>>2]|0,c[m+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;c[m>>2]=p;c[m+4>>2]=G}p=s;s=f-1|0;q=s;h=Erc(c[k>>2]|0,c[k+4>>2]|0,q,(q|0)<0|0?-1:0)|0;q=wrc(h,G,c[l>>2]|0,c[l+4>>2]|0)|0;c[m>>2]=q;c[m+4>>2]=G;while(1){q=c[m+4>>2]|0;h=wrc(q,(q|0)<0|0?-1:0,4,0)|0;q=G;o=e;t=(o|0)<0|0?-1:0;if(!((q|0)>=(t|0)&((q|0)>(t|0)|h>>>0>=o>>>0))){break}s=s-1|0;o=xrc(c[m>>2]|0,c[m+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;c[m>>2]=o;c[m+4>>2]=G}o=s;if((p|0)>(o|0)){s=0;h=c[l+4>>2]|0;c[m>>2]=c[l>>2];c[m+4>>2]=h;while(1){if((s|0)>=(f|0)){break}h=c[m+4>>2]|0;(h|0)<0|0?-1:0;u=h;h=c[m+4>>2]|0;h>>27|((h|0)<0|0?-1:0)<<5;v=((c[m>>2]|0)>>>27|h<<5)&31;h=g+(v<<4)|0;w=0;x=0;while(1){if((x|0)>=8){break}t=u-4+1+x|0;q=b[h+(x<<1)>>1]|0;if((t|0)<0){y=0}else{if((t|0)>=(e|0)){z=e-1|0}else{z=t}y=z}w=w+(ca(q,d[n+y|0]|0)|0)|0;x=x+1|0}h=w+64>>7;if((h|0)>255){A=255}else{if((h|0)<0){B=0}else{B=h}A=B}h=r;r=h+1|0;a[h]=A;s=s+1|0;h=wrc(c[m>>2]|0,c[m+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;c[m>>2]=h;c[m+4>>2]=G}i=j;return}s=0;A=c[l+4>>2]|0;c[m>>2]=c[l>>2];c[m+4>>2]=A;while(1){if((s|0)>=(p|0)){break}A=c[m+4>>2]|0;(A|0)<0|0?-1:0;u=A;A=c[m+4>>2]|0;A>>27|((A|0)<0|0?-1:0)<<5;v=((c[m>>2]|0)>>>27|A<<5)&31;A=g+(v<<4)|0;w=0;x=0;while(1){if((x|0)>=8){break}if((u-4+1+x|0)<0){C=0}else{C=u-4+1+x|0}w=w+(ca(b[A+(x<<1)>>1]|0,d[n+C|0]|0)|0)|0;x=x+1|0}A=w+64>>7;if((A|0)>255){D=255}else{if((A|0)<0){E=0}else{E=A}D=E}A=r;r=A+1|0;a[A]=D;s=s+1|0;A=wrc(c[m>>2]|0,c[m+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;c[m>>2]=A;c[m+4>>2]=G}while(1){if((s|0)>(o|0)){break}D=c[m+4>>2]|0;(D|0)<0|0?-1:0;u=D;D=c[m+4>>2]|0;D>>27|((D|0)<0|0?-1:0)<<5;v=((c[m>>2]|0)>>>27|D<<5)&31;D=g+(v<<4)|0;w=0;x=0;while(1){if((x|0)>=8){break}w=w+(ca(b[D+(x<<1)>>1]|0,d[n+(u-4+1+x)|0]|0)|0)|0;x=x+1|0}D=w+64>>7;if((D|0)>255){F=255}else{if((D|0)<0){H=0}else{H=D}F=H}D=r;r=D+1|0;a[D]=F;s=s+1|0;D=wrc(c[m>>2]|0,c[m+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;c[m>>2]=D;c[m+4>>2]=G}while(1){if((s|0)>=(f|0)){break}F=c[m+4>>2]|0;(F|0)<0|0?-1:0;u=F;F=c[m+4>>2]|0;F>>27|((F|0)<0|0?-1:0)<<5;v=((c[m>>2]|0)>>>27|F<<5)&31;F=g+(v<<4)|0;w=0;x=0;while(1){if((x|0)>=8){break}if((u-4+1+x|0)>=(e|0)){I=e-1|0}else{I=u-4+1+x|0}w=w+(ca(b[F+(x<<1)>>1]|0,d[n+I|0]|0)|0)|0;x=x+1|0}F=w+64>>7;if((F|0)>255){J=255}else{if((F|0)<0){K=0}else{K=F}J=K}F=r;r=F+1|0;a[F]=J;s=s+1|0;F=wrc(c[m>>2]|0,c[m+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;c[m>>2]=F;c[m+4>>2]=G}i=j;return}function H4b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b<<4;do{if((a|0)>=(d<<4|0)){e=217976}else{if((a|0)>=(d*13|0|0)){e=215928;break}if((a|0)>=(d*11|0|0)){e=216440;break}if((a|0)>=(d*9|0|0)){e=216952;break}else{e=217464;break}}}while(0);i=c;return e|0}function I4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=64;h=64;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function J4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+4096|0;h=g|0;D6b(h|0,f,64,64,c,e);e=a;a=b;b=h|0;h=64;c=64;f=64;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function K4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=64;h=32;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function L4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+2048|0;h=g|0;D6b(h|0,f,64,32,c,e);e=a;a=b;b=h|0;h=64;c=64;f=32;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function M4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=32;h=64;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function N4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+2048|0;h=g|0;D6b(h|0,f,32,64,c,e);e=a;a=b;b=h|0;h=32;c=32;f=64;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function O4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=32;h=32;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function P4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+1024|0;h=g|0;D6b(h|0,f,32,32,c,e);e=a;a=b;b=h|0;h=32;c=32;f=32;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function Q4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=32;h=16;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function R4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+512|0;h=g|0;D6b(h|0,f,32,16,c,e);e=a;a=b;b=h|0;h=32;c=32;f=16;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function S4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=16;h=32;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function T4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+512|0;h=g|0;D6b(h|0,f,16,32,c,e);e=a;a=b;b=h|0;h=16;c=16;f=32;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function U4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=16;h=16;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function V4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+256|0;h=g|0;D6b(h|0,f,16,16,c,e);e=a;a=b;b=h|0;h=16;c=16;f=16;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function W4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=16;h=8;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function X4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+128|0;h=g|0;D6b(h|0,f,16,8,c,e);e=a;a=b;b=h|0;h=16;c=16;f=8;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function Y4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=8;h=16;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function Z4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+128|0;h=g|0;D6b(h|0,f,8,16,c,e);e=a;a=b;b=h|0;h=8;c=8;f=16;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function _4b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=8;h=8;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function $4b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+64|0;h=g|0;D6b(h|0,f,8,8,c,e);e=a;a=b;b=h|0;h=8;c=8;f=8;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function a5b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=8;h=4;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function b5b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+32|0;h=g|0;D6b(h|0,f,8,4,c,e);e=a;a=b;b=h|0;h=8;c=8;f=4;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function c5b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=4;h=8;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function d5b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+32|0;h=g|0;D6b(h|0,f,4,8,c,e);e=a;a=b;b=h|0;h=4;c=4;f=8;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function e5b(a,b,c,e,f){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=c;c=e;e=4;h=4;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(e|0)){break}j=j+(R((d[g+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}g=g+a|0;b=b+c|0;k=k+1|0}i=f;return j|0}function f5b(a,b,c,e,f,g){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+16|0;h=g|0;D6b(h|0,f,4,4,c,e);e=a;a=b;b=h|0;h=4;c=4;f=4;j=0;k=0;while(1){if((k|0)>=(f|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}j=j+(R((d[e+l|0]|0)-(d[b+l|0]|0)|0)|0)|0;l=l+1|0}e=e+a|0;b=b+h|0;k=k+1|0}i=g;return j|0}function g5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=K4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function h5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=M4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function i5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=Q4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function j5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=S4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function k5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=3){break}c[e+(f<<2)>>2]=I4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function l5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=3){break}c[e+(f<<2)>>2]=O4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function m5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=I4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function n5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=O4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function o5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=3){break}c[e+(f<<2)>>2]=U4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function p5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=U4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function q5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=3){break}c[e+(f<<2)>>2]=W4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function r5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=W4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function s5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=3){break}c[e+(f<<2)>>2]=_4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function t5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=_4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function u5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=3){break}c[e+(f<<2)>>2]=Y4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function v5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=Y4b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function w5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=3){break}c[e+(f<<2)>>2]=e5b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function x5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=e5b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function y5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=I4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function z5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=O4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function A5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=U4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function B5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=W4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function C5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=_4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function D5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=Y4b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function E5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=a5b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function F5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=a5b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function G5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=c5b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function H5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=8){break}c[e+(f<<2)>>2]=c5b(h,a,b+f|0,d,2147483647)|0;f=f+1|0}i=g;return}function I5b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;while(1){if((f|0)>=4){break}c[e+(f<<2)>>2]=e5b(h,a,c[b+(f<<2)>>2]|0,d,2147483647)|0;f=f+1|0}i=g;return}function J5b(b){b=b|0;var c=0;c=b;a[c|0]=1;a[c+1|0]=1;a[c+2|0]=1;i=i;return}function K5b(b){b=b|0;a[b|0]=0;i=i;return}function L5b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+80+(b<<2)|0;c[e>>2]=c[e>>2]&~(1<<d);i=i;return}function M5b(a,c,d){a=a|0;c=c|0;d=d|0;b[a+16+(c<<3)+(d<<1)>>1]=0;i=i;return}function N5b(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+128|0;f=e|0;g=e+24|0;h=e+56|0;j=e+88|0;k=e+96|0;l=e+104|0;m=e+112|0;n=b;b=n+1434592|0;o=b+13408|0;p=2147483647;mrc(f|0,0,24)|0;mrc(g|0,0,32)|0;mrc(h|0,0,32)|0;q=c[b+10160>>2]|0;mrc(o+5|0,-1|0,7)|0;mrc(o+12|0,-1|0,3)|0;r=0;while(1){if((r|0)>=(1<<c[b+36972>>2]|0)){break}_hc(m,b,0,r);s=(c[b+10204>>2]|0)+(c[m+8>>2]<<2)|0;t=0;while(1){if((t|0)>=(c[b+10148>>2]|0)){break}u=s;v=c[m+8>>2]|0;while(1){if((v|0)>=(c[m+12>>2]|0)){break}O5b(n,m,u,g|0,f|0,h|0,t,v,12);v=v+8|0;u=u+32|0}t=t+8|0;s=s+(q<<3<<2)|0}r=r+1|0}P5b(g|0,j|0);r=Q5b(g|0,j|0)|0;g=b;if((c[g+10108>>2]|0)==0){w=1}else{w=(c[g+10124>>2]|0)!=0}if((w&1|0)==0){P5b(h|0,k|0);p=Q5b(h|0,k|0)|0;h=0;while(1){if((h|0)>=3){break}w=c[f+(h<<3)>>2]|0;g=c[f+(h<<3)+4>>2]|0;b=w;q=b+g|0;if((q|0)==0){x=128}else{m=((b<<8)+(q>>1)|0)/(q|0)|0;if((m|0)>255){y=255}else{if((m|0)<1){z=1}else{z=m}y=z}x=y&255}a[l+h|0]=x;m=ca(w,c[206872+((d[l+h|0]|0)<<2)>>2]|0)|0;p=p+(m+(ca(g,c[206872+(255-(d[l+h|0]|0)<<2)>>2]|0)|0))|0;h=h+1|0}}if((p|0)<(r|0)){a[o+4|0]=1;r=o+5|0;p=k;a[r]=a[p]|0;a[r+1|0]=a[p+1|0]|0;a[r+2|0]=a[p+2|0]|0;a[r+3|0]=a[p+3|0]|0;a[r+4|0]=a[p+4|0]|0;a[r+5|0]=a[p+5|0]|0;a[r+6|0]=a[p+6|0]|0;p=o+12|0;r=l;a[p]=a[r]|0;a[p+1|0]=a[r+1|0]|0;a[p+2|0]=a[r+2|0]|0;i=e;return}else{a[o+4|0]=0;r=o+5|0;o=j;a[r]=a[o]|0;a[r+1|0]=a[o+1|0]|0;a[r+2|0]=a[o+2|0]|0;a[r+3|0]=a[o+3|0]|0;a[r+4|0]=a[o+4|0]|0;a[r+5|0]=a[o+5|0]|0;a[r+6|0]=a[o+6|0]|0;i=e;return}}function O5b(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;l=i;m=a;a=b;b=d;d=e;e=f;f=g;g=h;h=j;j=k;k=m+1434592|0;n=c[k+10160>>2]|0;o=c[777680+(j<<2)>>2]|0;p=(o|0)/2|0;do{if((g|0)<(c[k+10148>>2]|0)){if((h|0)>=(c[k+10156>>2]|0)){break}q=c[777680+(c[c[b>>2]>>2]<<2)>>2]|0;r=c[777736+(c[c[b>>2]>>2]<<2)>>2]|0;do{if((q|0)==(o|0)){if((r|0)!=(o|0)){break}S5b(m,a,b,d,e,f,o,o,g,h);i=l;return}}while(0);do{if((q|0)==(o|0)){if((r|0)>=(o|0)){s=10;break}S5b(m,a,b,d,e,f,o,p,g,h);S5b(m,a,b+((ca(p,n)|0)<<2)|0,d,e,f,o,p,g+p|0,h)}else{s=10}}while(0);if((s|0)==10){do{if((q|0)<(o|0)){if((r|0)!=(o|0)){s=13;break}S5b(m,a,b,d,e,f,p,o,g,h);S5b(m,a,b+(p<<2)|0,d,e,f,p,o,g,h+p|0)}else{s=13}}while(0);if((s|0)==13){t=c[552572+(j<<2)>>2]|0;if((q|0)<(o|0)){if((r|0)<(o|0)){}else{s=15}}else{s=15}if((s|0)==15){Cd(2324176,2556784,201,2653136)}u=0;while(1){if((u|0)>=4){break}v=ca(p,u&1)|0;w=ca(p,u>>1)|0;O5b(m,a,b+((ca(w,n)|0)+v<<2)|0,d,e,f,g+w|0,h+v|0,t);u=u+1|0}}}i=l;return}}while(0);i=l;return}function P5b(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;f=b;b=d;d=(c[f>>2]|0)+(c[f+4>>2]|0)|0;g=(c[f+8>>2]|0)+(c[f+12>>2]|0)|0;h=(c[f+16>>2]|0)+(c[f+20>>2]|0)|0;j=(c[f+24>>2]|0)+(c[f+28>>2]|0)|0;k=d+g|0;l=k+(h+j)|0;if((l|0)==0){m=128}else{n=((k<<8)+(l>>1)|0)/(l|0)|0;if((n|0)>255){o=255}else{if((n|0)<1){p=1}else{p=n}o=p}m=o&255}a[b|0]=m;m=d;d=m+g|0;if((d|0)==0){q=128}else{g=((m<<8)+(d>>1)|0)/(d|0)|0;if((g|0)>255){r=255}else{if((g|0)<1){s=1}else{s=g}r=s}q=r&255}a[b+1|0]=q;q=h;h=q+j|0;if((h|0)==0){t=128}else{j=((q<<8)+(h>>1)|0)/(h|0)|0;if((j|0)>255){u=255}else{if((j|0)<1){v=1}else{v=j}u=v}t=u&255}a[b+2|0]=t;t=c[f>>2]|0;u=t+(c[f+4>>2]|0)|0;if((u|0)==0){w=128}else{v=((t<<8)+(u>>1)|0)/(u|0)|0;if((v|0)>255){x=255}else{if((v|0)<1){y=1}else{y=v}x=y}w=x&255}a[b+3|0]=w;w=c[f+8>>2]|0;x=w+(c[f+12>>2]|0)|0;if((x|0)==0){z=128}else{y=((w<<8)+(x>>1)|0)/(x|0)|0;if((y|0)>255){A=255}else{if((y|0)<1){B=1}else{B=y}A=B}z=A&255}a[b+4|0]=z;z=c[f+16>>2]|0;A=z+(c[f+20>>2]|0)|0;if((A|0)==0){C=128}else{B=((z<<8)+(A>>1)|0)/(A|0)|0;if((B|0)>255){D=255}else{if((B|0)<1){E=1}else{E=B}D=E}C=D&255}a[b+5|0]=C;C=c[f+24>>2]|0;D=C+(c[f+28>>2]|0)|0;if((D|0)==0){F=128;G=F&255;H=b;I=H+6|0;a[I]=G;i=e;return}f=((C<<8)+(D>>1)|0)/(D|0)|0;if((f|0)>255){J=255}else{if((f|0)<1){K=1}else{K=f}J=K}F=J&255;G=F&255;H=b;I=H+6|0;a[I]=G;i=e;return}function Q5b(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=a;a=b;b=(c[f>>2]|0)+(c[f+4>>2]|0)|0;g=(c[f+8>>2]|0)+(c[f+12>>2]|0)|0;h=(c[f+16>>2]|0)+(c[f+20>>2]|0)|0;j=(c[f+24>>2]|0)+(c[f+28>>2]|0)|0;k=b+g|0;l=h+j|0;m=ca(k,c[206872+((d[a|0]|0)<<2)>>2]|0)|0;n=m+(ca(l,c[206872+(255-(d[a|0]|0)<<2)>>2]|0)|0)|0;if((k|0)>0){k=ca(b,c[206872+((d[a+1|0]|0)<<2)>>2]|0)|0;n=n+(k+(ca(g,c[206872+(255-(d[a+1|0]|0)<<2)>>2]|0)|0))|0;if((b|0)>0){b=ca(c[f>>2]|0,c[206872+((d[a+3|0]|0)<<2)>>2]|0)|0;n=n+(b+(ca(c[f+4>>2]|0,c[206872+(255-(d[a+3|0]|0)<<2)>>2]|0)|0))|0}if((g|0)>0){g=ca(c[f+8>>2]|0,c[206872+((d[a+4|0]|0)<<2)>>2]|0)|0;n=n+(g+(ca(c[f+12>>2]|0,c[206872+(255-(d[a+4|0]|0)<<2)>>2]|0)|0))|0}}if((l|0)<=0){o=n;i=e;return o|0}l=ca(h,c[206872+((d[a+2|0]|0)<<2)>>2]|0)|0;n=n+(l+(ca(j,c[206872+(255-(d[a+2|0]|0)<<2)>>2]|0)|0))|0;if((h|0)>0){h=ca(c[f+16>>2]|0,c[206872+((d[a+5|0]|0)<<2)>>2]|0)|0;n=n+(h+(ca(c[f+20>>2]|0,c[206872+(255-(d[a+5|0]|0)<<2)>>2]|0)|0))|0}if((j|0)>0){j=ca(c[f+24>>2]|0,c[206872+((d[a+6|0]|0)<<2)>>2]|0)|0;n=n+(j+(ca(c[f+28>>2]|0,c[206872+(255-(d[a+6|0]|0)<<2)>>2]|0)|0))|0}o=n;i=e;return o|0}function R5b(b){b=b|0;var c=0,d=0;c=i;d=b;a[d|0]=0;a[d+1|0]=0;a[d+2|0]=0;mrc(d+5|0,-1|0,7)|0;Uhc(d);i=c;return}function S5b(b,e,f,g,h,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;o=i;p=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=p+1434592|0;q=p+57488|0;do{if((l|0)<(c[n+10148>>2]|0)){if((m|0)>=(c[n+10156>>2]|0)){break}c[q+160>>2]=e;p=d[(c[c[q+160>>2]>>2]|0)+13|0]|0;r=q;s=l;t=m;u=c[n+10148>>2]|0;v=c[n+10156>>2]|0;c[r+180>>2]=-(s<<3<<3);c[r+184>>2]=u-k-s<<3<<3;c[r+172>>2]=-(t<<3<<3);c[r+176>>2]=v-j-t<<3<<3;c[r+164>>2]=(s|0)!=0;c[r+168>>2]=(t|0)>(c[b+8>>2]|0);t=f+(p<<2)|0;c[t>>2]=(c[t>>2]|0)+1;if((c[n+10108>>2]|0)==0){i=o;return}t=(jgc(n,c[n+10216>>2]|0,c[c[e>>2]>>2]|0,l,m)|0)==(p|0)|0;r=q;s=r;if((c[s+164>>2]|0)!=0){w=c[(c[s+160>>2]|0)+(-(c[s+156>>2]|0)<<2)>>2]|0}else{w=0}s=w;v=r;if((c[v+168>>2]|0)!=0){x=c[(c[v+160>>2]|0)-4>>2]|0}else{x=0}v=x;if((s|0)!=0){y=d[s+14|0]|0}else{y=0}if((v|0)!=0){z=d[v+14|0]|0}else{z=0}a[(c[c[q+160>>2]>>2]|0)+14|0]=t;v=g+(y+z<<3)+(t<<2)|0;c[v>>2]=(c[v>>2]|0)+1;if((t|0)==0){t=h+(p<<2)|0;c[t>>2]=(c[t>>2]|0)+1}i=o;return}}while(0);i=o;return}function T5b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a;a=d+2046876|0;e=d+1434592|0;f=d+1471600|0;if((c[d+2046860>>2]|0)<0){g=-(c[d+2046860>>2]|0)|0}else{g=c[d+2046860>>2]|0}h=g;c[a>>2]=1;c[a+4>>2]=1;c[a+8>>2]=3;c[a+12>>2]=0;c[a+16>>2]=2;c[a+20>>2]=0;c[a+36>>2]=((c[f+124>>2]|0)!=0^1)&1;c[a+28>>2]=0;c[a+32>>2]=0;c[a+24>>2]=11;c[a+44>>2]=0;c[a+48>>2]=0;c[a+64>>2]=0;c[a+68>>2]=0;c[a+72>>2]=0;c[a+128>>2]=0;c[a+132>>2]=0;c[a+80>>2]=0;c[a+84>>2]=0;c[a+92>>2]=0;c[a+96>>2]=0;c[a+100>>2]=0;c[a+108>>2]=12;c[a+104>>2]=0;c[a+112>>2]=0;c[a+116>>2]=4;c[a+120>>2]=0;c[a+124>>2]=0;c[a+148>>2]=0;c[a+140>>2]=0;c[a+144>>2]=0;c[a+152>>2]=0;c[a+156>>2]=0;g=0;while(1){if((g|0)>=4){break}c[a+160+(g<<2)>>2]=1023;c[a+176+(g<<2)>>2]=1023;g=g+1|0}c[a+192>>2]=0;c[a+52>>2]=0;c[a+196>>2]=0;c[a+60>>2]=0;c[a+200>>2]=0;c[a+204>>2]=0;c[a+268>>2]=0;c[a+76>>2]=30;c[a+208>>2]=0;c[a+212>>2]=0;g=0;while(1){if((g|0)>=13){break}c[a+216+(g<<2)>>2]=0;g=g+1|0}c[a+276>>2]=12;c[a+88>>2]=6;c[a+280>>2]=50;c[a+284>>2]=100;c[a+272>>2]=25;switch(c[f+48>>2]|0){case 3:case 1:case 4:{U5b(d,e,a,h);break};case 2:case 5:{c[d+2047248>>2]=36;break};case 6:{V5b(e,a,h);break};default:{}}if((c[d+2046868>>2]|0)==1){c[a+36>>2]=0}if((c[d+2046868>>2]|0)==0){c[a+8>>2]=0;c[a+36>>2]=0}if((c[a+12>>2]|0)==0){c[d+2047232>>2]=2;c[d+2047236>>2]=2}if((c[a+36>>2]|0)==1){j=(c[d+2046868>>2]|0)!=1}else{j=0}c[d+1217352>>2]=j&1;do{if((c[d+2047176>>2]|0)!=0){if((c[f+48>>2]|0)!=6){break}if((c[a+212>>2]|0)<=(c[d+2047176>>2]|0)){break}c[d+2047176>>2]=c[a+212>>2]}}while(0);if((c[a+124>>2]|0)==63){c[a+132>>2]=0}if((c[d+1471744>>2]|0)!=0){i=b;return}c[a+144>>2]=0;i=b;return}function U5b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=a;a=b;b=d;d=e;c[b+48>>2]=1;c[b+8>>2]=(d|0)<1?3:1;c[b+60>>2]=1;if((d|0)>=1){e=a;if((c[e+10108>>2]|0)==0){h=1}else{h=(c[e+10124>>2]|0)!=0}c[b+96>>2]=((h&1|0)!=0^1)&1;c[b+92>>2]=1;h=g;e=h+1434592|0;if((c[e+10108>>2]|0)==0){j=1}else{j=(c[e+10124>>2]|0)!=0}do{if(j){k=1}else{if((c[h+1472152>>2]|0)!=0){k=1;break}if((c[h+1472148>>2]|0)!=0){l=(c[h+2017236>>2]|0)!=0^1}else{l=0}k=l}}while(0);c[b+68>>2]=(k&1|0)!=0?0:3;if((c[a+8452>>2]|0)<(c[a+8456>>2]|0)){m=c[a+8452>>2]|0}else{m=c[a+8456>>2]|0}if((m|0)>=720){c[b+124>>2]=(c[a+10112>>2]|0)!=0?63:31}else{c[b+124>>2]=24}c[b+192>>2]=1;c[b+128>>2]=1;c[b+32>>2]=1;c[b+48>>2]=2;c[b+16>>2]=1;c[b+76>>2]=10;c[b+132>>2]=1;c[b+8>>2]=2;c[b+172>>2]=7;c[b+188>>2]=7;c[b+168>>2]=7;c[b+184>>2]=7}if((d|0)>=2){m=a;if((c[m+10108>>2]|0)==0){n=1}else{n=(c[m+10124>>2]|0)!=0}c[b+68>>2]=(n&1|0)!=0?0:3;if((c[a+8452>>2]|0)<(c[a+8456>>2]|0)){o=c[a+8452>>2]|0}else{o=c[a+8456>>2]|0}if((o|0)>=720){c[b+124>>2]=(c[a+10112>>2]|0)!=0?63:31}else{c[b+124>>2]=30}c[b+132>>2]=2;c[b+80>>2]=1;c[b+148>>2]=58;c[b+156>>2]=100;c[b+44>>2]=13;c[b+100>>2]=1;c[b+64>>2]=1;c[b+112>>2]=1;c[b+116>>2]=3}if((d|0)>=3){if((c[a+8452>>2]|0)<(c[a+8456>>2]|0)){p=c[a+8452>>2]|0}else{p=c[a+8456>>2]|0}if((p|0)>=720){c[b+124>>2]=63}else{c[b+124>>2]=31}c[b+8>>2]=1;c[b+48>>2]=3;c[b+76>>2]=6;c[b+204>>2]=2;c[b+268>>2]=1}if((d|0)>=4){c[b+96>>2]=1;c[b+68>>2]=3;c[b+124>>2]=63;c[b+48>>2]=4;p=b+148|0;c[p>>2]=c[p>>2]|5;c[b+156>>2]=200;c[b+64>>2]=2;c[b+72>>2]=1}if((d|0)<5){i=f;return}c[b+84>>2]=1;c[b+36>>2]=0;c[b+4>>2]=2;c[b+156>>2]=500;d=0;while(1){if((d|0)>=4){break}c[b+160+(d<<2)>>2]=1;c[b+176+(d<<2)>>2]=1;d=d+1|0}c[g+2047172>>2]=1;i=f;return}function V5b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=a;a=b;b=d;c[a+40>>2]=0;c[a+48>>2]=1;c[a+212>>2]=1;c[a+268>>2]=1;if((b|0)==1){d=f;if((c[d+10108>>2]|0)==0){g=1}else{g=(c[d+10124>>2]|0)!=0}c[a+96>>2]=((g&1|0)!=0^1)&1;c[a+92>>2]=1;g=f;if((c[g+10108>>2]|0)==0){h=1}else{h=(c[g+10124>>2]|0)!=0}c[a+68>>2]=(h&1|0)!=0?0:3;if((c[f+8452>>2]|0)<(c[f+8456>>2]|0)){j=c[f+8452>>2]|0}else{j=c[f+8456>>2]|0}if((j|0)>=720){c[a+124>>2]=(c[f+10112>>2]|0)!=0?63:31}else{c[a+124>>2]=24}c[a+192>>2]=1;c[a+128>>2]=1;c[a+132>>2]=1;c[a+32>>2]=1;c[a+48>>2]=2;c[a+172>>2]=7;c[a+188>>2]=7;c[a+184>>2]=7;c[a+212>>2]=8}if((b|0)>=2){j=f;if((c[j+10108>>2]|0)==0){k=1}else{k=(c[j+10124>>2]|0)!=0}c[a+96>>2]=((k&1|0)!=0^1)&1;c[a+92>>2]=1;k=f;if((c[k+10108>>2]|0)==0){l=1}else{l=(c[k+10124>>2]|0)!=0}c[a+68>>2]=(l&1|0)!=0?0:3;if((c[f+8452>>2]|0)<(c[f+8456>>2]|0)){m=c[f+8452>>2]|0}else{m=c[f+8456>>2]|0}if((m|0)>=720){c[a+124>>2]=(c[f+10112>>2]|0)!=0?63:31}else{c[a+124>>2]=30}c[a+148>>2]=58;c[a+192>>2]=1;c[a+128>>2]=1;c[a+132>>2]=2;c[a+32>>2]=1;c[a+80>>2]=1;c[a+156>>2]=50;c[a+44>>2]=13;c[a+100>>2]=1;c[a+64>>2]=1;c[a+112>>2]=1;c[a+116>>2]=3;c[a+48>>2]=2;c[a+72>>2]=1;c[a+76>>2]=11;c[a+172>>2]=7;c[a+168>>2]=7;c[a+188>>2]=7;c[a+184>>2]=7;c[a+212>>2]=200}if((b|0)>=3){c[a+96>>2]=1;c[a+156>>2]=100;c[a+64>>2]=2;c[a+120>>2]=1;c[a+196>>2]=1;c[a+52>>2]=1;c[a+16>>2]=1;c[a+204>>2]=2;c[a+48>>2]=4;c[a+76>>2]=6;c[a+60>>2]=0;c[a+36>>2]=0;c[a+124>>2]=63;c[a+200>>2]=2;c[a+212>>2]=700}if((b|0)>=4){c[a+116>>2]=4;c[a+48>>2]=5;c[a+268>>2]=0;c[a+100>>2]=2;if((c[f+10104>>2]|0)!=(c[f+10108>>2]|0)){n=1}else{n=0==((((c[f+36948>>2]|0)+1|0)>>>0)%((c[a+116>>2]|0)>>>0)|0|0)}c[a+112>>2]=n&1;c[a+20>>2]=1;n=0;while(1){if((n|0)>=4){break}c[a+160+(n<<2)>>2]=7;c[a+176+(n<<2)>>2]=1;n=n+1|0}c[a+172>>2]=1;c[a>>2]=0;c[a+212>>2]=1e3;c[a+4>>2]=5;c[a+252>>2]=4;c[a+256>>2]=-2;c[a+260>>2]=-2;c[a+264>>2]=-2;c[a+276>>2]=9;c[a+60>>2]=1}if((b|0)>=5){c[a+108>>2]=9;c[a+104>>2]=3;c[a+136>>2]=(((c[f+36948>>2]|0)>>>0)%((c[a+116>>2]|0)>>>0)|0|0)==1;if((c[f+10108>>2]|0)==0){o=1}else{o=(((c[f+36948>>2]|0)>>>0)%(c[a+116>>2]<<1>>>0)|0|0)==1}c[a+140>>2]=o&1;c[a+144>>2]=(c[f+10108>>2]|0)==0?20:15;c[a+84>>2]=3;c[a+208>>2]=1;c[a+4>>2]=6;c[a+60>>2]=0}if((b|0)>=6){c[a+84>>2]=5;c[a+280>>2]=50;c[a+284>>2]=360}if((b|0)<7){i=e;return}b=0;while(1){if((b|0)>=13){break}c[a+216+(b<<2)>>2]=-2;b=b+1|0}i=e;return}function W5b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0;b=i;d=a;a=d+2050808|0;e=d+1471600|0;c[a>>2]=0;c[a+4>>2]=0;if((c[a+12>>2]|0)>1){f=c[a+12>>2]|0}else{f=c[a+8>>2]|0}d=0;while(1){if((d|0)>=(f|0)){break}g=a+16+(d*960|0)|0;j=g|0;c[g+952>>2]=0;c[j+140>>2]=c[e+112>>2];c[j+124>>2]=c[e+112>>2];k=j+208|0;c[k>>2]=0;c[k+4>>2]=0;k=j+224|0;c[k>>2]=0;c[k+4>>2]=0;c[j+128>>2]=0;h[j+152>>3]=0.0;h[j+160>>3]=0.0;c[j+132>>2]=0;c[j+188>>2]=0;c[j+184>>2]=0;h[j+40>>3]=1.0;h[j+48>>3]=1.0;if((c[a+12>>2]|0)>1){c[g+240>>2]=(c[e+188+(d<<2)>>2]|0)*1e3|0;c[j+16>>2]=c[e+112>>2]}else{c[g+240>>2]=(c[e+168+(d<<2)>>2]|0)*1e3|0;c[j+12>>2]=c[e+116>>2];c[j+16>>2]=c[e+116>>2];c[j+20>>2]=c[e+116>>2]}k=c[e+80>>2]|0;l=c[g+240>>2]|0;g=h1b(k,(k|0)<0|0?-1:0,l,(l|0)<0|0?-1:0,1e3)|0;l=j+168|0;c[l>>2]=g;c[l+4>>2]=G;l=j+168|0;g=c[l+4>>2]|0;k=j+176|0;c[k>>2]=c[l>>2];c[k+4>>2]=g;d=d+1|0}i=b;return}function X5b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=a;a=b;b=e+2050808|0;f=e+1471600|0;g=e+2017128|0;j=1.0;if((c[b+12>>2]|0)>1){k=c[b+12>>2]|0}else{k=c[b+8>>2]|0}e=0;while(1){if((e|0)>=(k|0)){break}l=b+16+(e*960|0)|0;m=l|0;if((c[b+12>>2]|0)>1){c[l+240>>2]=(c[f+188+(e<<2)>>2]|0)*1e3|0}else{c[l+240>>2]=(c[f+168+(e<<2)>>2]|0)*1e3|0}j=+(c[l+240>>2]|0)/+(a|0);n=f+80|0;o=(+((c[n>>2]|0)>>>0)+ +(c[n+4>>2]|0)*4294967296.0)*j;n=(F=+o,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);p=l+248|0;c[p>>2]=~~+o>>>0;c[p+4>>2]=n;n=f+88|0;o=(+((c[n>>2]|0)>>>0)+ +(c[n+4>>2]|0)*4294967296.0)*j;n=(F=+o,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);p=l+256|0;c[p>>2]=~~+o>>>0;c[p+4>>2]=n;n=f+96|0;o=(+((c[n>>2]|0)>>>0)+ +(c[n+4>>2]|0)*4294967296.0)*j;n=(F=+o,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);p=l+264|0;c[p>>2]=~~+o>>>0;c[p+4>>2]=n;n=m+176|0;p=c[n+4>>2]|0;q=l+264|0;r=c[q+4>>2]|0;if((p|0)<(r|0)|(p|0)==(r|0)&(c[n>>2]|0)>>>0<(c[q>>2]|0)>>>0){q=m+176|0;s=c[q+4>>2]|0;t=c[q>>2]|0}else{q=l+264|0;s=c[q+4>>2]|0;t=c[q>>2]|0}q=m+176|0;c[q>>2]=t;c[q+4>>2]=s;q=m+168|0;n=c[q+4>>2]|0;r=l+264|0;p=c[r+4>>2]|0;if((n|0)<(p|0)|(n|0)==(p|0)&(c[q>>2]|0)>>>0<(c[r>>2]|0)>>>0){r=m+168|0;u=c[r+4>>2]|0;v=c[r>>2]|0}else{r=l+264|0;u=c[r+4>>2]|0;v=c[r>>2]|0}r=m+168|0;c[r>>2]=v;c[r+4>>2]=u;if((c[b+12>>2]|0)>1){h[l+272>>3]=+h[f+16>>3]/+(c[f+208+(e<<2)>>2]|0)}else{h[l+272>>3]=+h[f+16>>3]}c[m+112>>2]=~~(+(c[l+240>>2]|0)/+h[l+272>>3]);c[m+120>>2]=c[g+120>>2];c[m+232>>2]=c[g+232>>2];c[m+236>>2]=c[g+236>>2];e=e+1|0}i=d;return}function Y5b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0;b=i;d=a;a=d+2050808|0;e=d+1471600|0;f=Z5b(a)|0;g=f|0;j=c[a+4>>2]|0;h[f+272>>3]=+h[e+16>>3]/+(c[e+208+(j<<2)>>2]|0);c[g+112>>2]=~~(+(c[f+240>>2]|0)/+h[f+272>>3]);c[g+120>>2]=c[d+2017248>>2];if((j|0)==0){c[f+280>>2]=c[g+112>>2];i=b;return}else{c[f+280>>2]=~~(+((c[f+240>>2]|0)-((c[e+188+(j-1<<2)>>2]|0)*1e3|0)|0)/(+h[f+272>>3]- +h[e+16>>3]/+(c[e+208+(j-1<<2)>>2]|0)));i=b;return}}function Z5b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;if((c[d+12>>2]|0)>1){e=d+16+((c[d+4>>2]|0)*960|0)|0;i=b;return e|0}else{e=d+16+((c[d>>2]|0)*960|0)|0;i=b;return e|0}return 0}function _5b(a,b){a=a|0;b=+b;var d=0,e=0,f=0,g=0,j=0,k=0;d=i;e=a;a=e+1471600|0;f=Z5b(e+2050808|0)|0;g=f|0;h[f+272>>3]=b;c[g+112>>2]=~~(+(c[f+240>>2]|0)/+h[f+272>>3]);c[g+116>>2]=(ca(c[g+112>>2]|0,c[a+152>>2]|0)|0)/100|0;f=c[g+112>>2]|0;j=c[a+156>>2]|0;k=Erc(f,(f|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=Crc(k,G,100,0)|0;c[g+120>>2]=j;c[g+72>>2]=16;c[g+76>>2]=c[e+1472104>>2]>>1;do{if((c[a+228>>2]|0)!=0){if((c[a+60>>2]|0)==0){break}if((c[g+72>>2]|0)>((c[a+60>>2]|0)-1|0)){c[g+72>>2]=(c[a+60>>2]|0)-1}if((c[g+76>>2]|0)>((c[a+60>>2]|0)-1|0)){c[g+76>>2]=(c[a+60>>2]|0)-1}}}while(0);if((c[g+72>>2]|0)<=(c[g+76>>2]|0)){i=d;return}c[g+72>>2]=c[g+76>>2];i=d;return}function $5b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a;a=Z5b(d+2050808|0)|0;e=c[d+2017216>>2]|0;f=c[d+2017212>>2]|0;nrc(d+2017128|0,a|0,240)|0;nrc(d+2047856|0,a+288|0,656)|0;g=c[a+240>>2]|0;h=d+1471624|0;c[h>>2]=g;c[h+4>>2]=(g|0)<0|0?-1:0;g=a+248|0;h=c[g+4>>2]|0;j=d+1471680|0;c[j>>2]=c[g>>2];c[j+4>>2]=h;h=a+256|0;j=c[h+4>>2]|0;g=d+1471688|0;c[g>>2]=c[h>>2];c[g+4>>2]=j;j=a+264|0;a=c[j+4>>2]|0;g=d+1471696|0;c[g>>2]=c[j>>2];c[g+4>>2]=a;if((c[d+2050820>>2]|0)<=1){i=b;return}c[d+2017216>>2]=e;c[d+2017212>>2]=f;i=b;return}function a6b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=d+1471600|0;e=Z5b(d+2050808|0)|0;nrc(e|0,d+2017128|0,240)|0;nrc(e+288|0,d+2047856|0,656)|0;c[e+240>>2]=c[a+24>>2];d=a+80|0;f=c[d+4>>2]|0;g=e+248|0;c[g>>2]=c[d>>2];c[g+4>>2]=f;f=a+88|0;g=c[f+4>>2]|0;d=e+256|0;c[d>>2]=c[f>>2];c[d+4>>2]=g;g=a+96|0;a=c[g+4>>2]|0;d=e+264|0;c[d>>2]=c[g>>2];c[d+4>>2]=a;i=b;return}function b6b(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a;a=d+2050808|0;e=0;while(1){if((e|0)>=(c[a+8>>2]|0)){break}f=a+16+(e*960|0)+288|0;c[a>>2]=e;jnc(d);g=e;h=f+168|0;c[h>>2]=g;c[h+4>>2]=(g|0)<0|0?-1:0;g=e;h=f+504|0;c[h>>2]=g;c[h+4>>2]=(g|0)<0|0?-1:0;e=e+1|0}c[a>>2]=0;i=b;return}function c6b(a){a=a|0;var b=0,d=0;b=a;if((c[b+12>>2]|0)>1){d=b+16+((c[b+4>>2]|0)*960|0)|0}else{d=b+16+((c[b>>2]|0)*960|0)|0}b=d+952|0;c[b>>2]=(c[b>>2]|0)+1;i=i;return}function d6b(a,f,g,h,j,k,l,m){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;n=i;o=a;a=f;f=g;g=h;h=j;j=k;k=l;l=m;m=0;p=0;q=0;while(1){if(!(p>>>0<g>>>0)){break}r=0;while(1){if(!(r>>>0<g>>>0)){break}s=f;f=s+1|0;t=d[s]|0;s=(d[o+m|0]|0)-t|0;s=ca(s,s)|0;s=s*3|0;s=s+(1<<h-1)|0;s=s>>h;if((s|0)>16){s=16}s=16-s|0;s=ca(s,j)|0;u=l+(q<<1)|0;b[u>>1]=(e[u>>1]|0)+s;u=ca(s,t)|0;t=k+(q<<2)|0;c[t>>2]=(c[t>>2]|0)+u;m=m+1|0;r=r+1|0;q=q+1|0}m=m+(a-g)|0;p=p+1|0}i=n;return}function e6b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+56|0;e=d|0;f=a;a=b;b=f+1434592|0;g=0;h=0;j=0;k=0;l=0;m=c[f+2017100>>2]|0;n=c[f+1471856>>2]|0;o=c[f+2017096>>2]|0;p=a;q=(Nnc(c[f+1471888>>2]|0)|0)-(p+1)|0;r=n;if((r|0)==2){j=q;if((j|0)>=(o|0)){j=o-1|0}k=j+1|0}else if((r|0)==1){h=p;if((h|0)>=(o|0)){h=o-1|0}k=h+1|0}else if((r|0)==3){s=9}else{s=9}if((s|0)==9){j=q;h=p;if((j|0)>(h|0)){j=h}if((h|0)>(j|0)){h=j}if((j|0)>((o-1|0)/2|0|0)){j=(o-1|0)/2|0}if((h|0)>((o|0)/2|0|0)){h=(o|0)/2|0}k=h+j+1|0}l=a+j|0;j=b;a=b;Mhc(e,c[j+8488+((c[j+10008>>2]|0)*108|0)+24>>2]|0,c[a+8488+((c[a+10008>>2]|0)*108|0)+28>>2]|0,c[b+8452>>2]|0,c[b+8456>>2]|0);mrc(f+2048604|0,0,100)|0;g=0;while(1){if((g|0)>=(k|0)){break}c[f+2048604+(k-1-g<<2)>>2]=Mnc(c[f+1471888>>2]|0,l-g|0)|0;g=g+1|0}f6b(f,k,h,m,e);i=d;return}function f6b(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;k=i;i=i+5464|0;l=k+5448|0;m=d;d=f;f=g;g=h;h=j;j=c[m+1444744>>2]|0;n=c[m+1444736>>2]|0;o=0;p=0;q=k+16-1&-16;r=k+3112-1&-16;s=m+57488|0;t=c[m+2048604+(f<<2)>>2]|0;u=k+4672-1&-16;v=16>>c[s+64>>2];if((c[s+60>>2]|0)==(c[s+64>>2]|0)){}else{Cd(2322352,2556304,216,2651192)}w=0;while(1){if((w|0)>=3){break}c[l+(w<<2)>>2]=c[s+(w*52|0)+24>>2];w=w+1|0}x=0;while(1){if((x|0)>=(n|0)){break}c[m+1161012>>2]=-((x<<4)+9|0);c[m+1161016>>2]=((c[m+1444736>>2]|0)-1-x<<4)+9;y=0;while(1){if((y|0)>=(j|0)){break}mrc(q|0,0,3072)|0;mrc(r|0,0,1536)|0;c[m+1161004>>2]=-((y<<4)+9|0);c[m+1161008>>2]=((c[m+1444744>>2]|0)-1-y<<4)+9;z=0;while(1){if((z|0)>=(d|0)){break}if((c[m+2048604+(z<<2)>>2]|0)!=0){b[(c[c[s+160>>2]>>2]|0)+80>>1]=0;b[(c[c[s+160>>2]>>2]|0)+82>>1]=0;if((z|0)==(f|0)){A=2}else{B=0;B=h6b(m,(c[(c[m+2048604+(f<<2)>>2]|0)+52>>2]|0)+o|0,(c[(c[m+2048604+(z<<2)>>2]|0)+52>>2]|0)+o|0,c[(c[m+2048604+(z<<2)>>2]|0)+16>>2]|0)|0;if((B|0)<1e4){C=2}else{C=(B|0)<2e4?1:0}A=C}if((A|0)!=0){i6b(s,(c[(c[m+2048604+(z<<2)>>2]|0)+52>>2]|0)+o|0,(c[(c[m+2048604+(z<<2)>>2]|0)+56>>2]|0)+p|0,(c[(c[m+2048604+(z<<2)>>2]|0)+60>>2]|0)+p|0,c[(c[m+2048604+(z<<2)>>2]|0)+16>>2]|0,v,b[(c[c[s+160>>2]>>2]|0)+80>>1]|0,b[(c[c[s+160>>2]>>2]|0)+82>>1]|0,u,h,y<<4,x<<4);d6b((c[t+52>>2]|0)+o|0,c[t+16>>2]|0,u,16,g,A,q,r);d6b((c[t+56>>2]|0)+p|0,c[t+36>>2]|0,u+256|0,v,g,A,q+1024|0,r+512|0);d6b((c[t+60>>2]|0)+p|0,c[t+36>>2]|0,u+512|0,v,g,A,q+2048|0,r+1024|0)}}z=z+1|0}z=c[m+2048564>>2]|0;B=c[m+2048528>>2]|0;D=o;E=0;F=0;while(1){if((E|0)>=16){break}G=0;while(1){if((G|0)>=16){break}H=(c[q+(F<<2)>>2]|0)+(e[r+(F<<1)>>1]>>1)|0;H=ca(H,c[m+2048704+(e[r+(F<<1)>>1]<<2)>>2]|0)|0;H=H>>>19;a[z+D|0]=H;D=D+1|0;G=G+1|0;F=F+1|0}D=D+(B-16)|0;E=E+1|0}z=c[m+2048568>>2]|0;H=c[m+2048572>>2]|0;B=c[m+2048548>>2]|0;D=p;E=0;F=256;while(1){if((E|0)>=(v|0)){break}G=0;while(1){if((G|0)>=(v|0)){break}I=F+256|0;J=(c[q+(F<<2)>>2]|0)+(e[r+(F<<1)>>1]>>1)|0;J=ca(J,c[m+2048704+(e[r+(F<<1)>>1]<<2)>>2]|0)|0;J=J>>>19;a[z+D|0]=J;J=(c[q+(I<<2)>>2]|0)+(e[r+(I<<1)>>1]>>1)|0;J=ca(J,c[m+2048704+(e[r+(I<<1)>>1]<<2)>>2]|0)|0;J=J>>>19;a[H+D|0]=J;D=D+1|0;G=G+1|0;F=F+1|0}D=D+(B-v)|0;E=E+1|0}o=o+16|0;p=p+v|0;y=y+1|0}o=o+((c[t+16>>2]|0)-j<<4)|0;p=p+(ca(v,(c[t+36>>2]|0)-j|0)|0)|0;x=x+1|0}w=0;while(1){if((w|0)>=3){break}c[s+(w*52|0)+24>>2]=c[l+(w<<2)>>2];w=w+1|0}i=k;return}function g6b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a;a=d;d=(c[f+1471848>>2]|0)-1|0;g=(c[f+1471848>>2]|0)-1|0;h=c[f+2017208>>2]>>1;j=(Nnc(c[f+1471888>>2]|0)|0)-b-1|0;b=c[f+1471856>>2]|0;if((b|0)==2){if((g|0)>(h|0)){g=h}if((g|0)>(j|0)){g=j}d=0}else if((b|0)==1){g=0;if((d|0)>(h|0)){d=h}}else if((b|0)==3){k=11}else{k=11}if((k|0)==11){g=g>>1;if((g|0)>(j|0)){g=j}if((g|0)>(h|0)){g=h}d=g;if((d|0)<(h|0)){d=d+((c[f+1471848>>2]|0)+1&1)|0}}c[f+2017096>>2]=d+1+g;if((c[f+1471540>>2]|0)>>>0>1>>>0){l=~~+O2b(c[f+2017268>>2]|0)}else{l=~~+O2b(c[f+2017264>>2]|0)}if((l|0)>16){c[f+2017100>>2]=c[f+1471852>>2]}else{c[f+2017100>>2]=(c[f+1471852>>2]|0)-((16-l|0)/2|0);if((c[f+2017100>>2]|0)<0){c[f+2017100>>2]=0}}if((c[f+2017096>>2]|0)>((a|0)/150|0|0)){c[f+2017096>>2]=(a|0)/150|0;l=f+2017096|0;c[l>>2]=(c[l>>2]|0)+(((c[f+2017096>>2]&1|0)!=0^1)&1)}if((c[f+2017100>>2]|0)<=((a|0)/300|0|0)){i=e;return}c[f+2017100>>2]=(a|0)/300|0;i=e;return}function h6b(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+48|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=a;a=f;f=m+32768|0;n=f+24720|0;o=c[f+75236>>2]|0;p=2147483647;mrc(h|0,0,4)|0;q=(c[c[f+24880>>2]>>2]|0)+80|0;r=k;s=f+8204|0;c[r>>2]=c[s>>2];c[r+4>>2]=c[s+4>>2];s=l;r=n+24|0;c[s>>2]=c[r>>2];c[s+4>>2]=c[r+4>>2];b[j+2>>1]=b[h+2>>1]>>3;b[j>>1]=b[h>>1]>>3;c[f+8204>>2]=d;c[f+8208>>2]=a;c[n+24>>2]=e;c[n+28>>2]=a;if((c[m+2046860>>2]|0)<8){t=(c[m+2046904>>2]|0)+((c[m+2046860>>2]|0)>5?1:0)|0}else{t=(c[m+2046904>>2]|0)+2|0}if((t|0)<((c[m+2046900>>2]|0)-2|0)){u=t}else{u=(c[m+2046900>>2]|0)-2|0}t=u;foc(f,j,t,o,1,m+2047516|0,0,h,q)|0;p=Qe[c[m+2047232>>2]&3](f,q,h,c[m+1444720>>2]|0,c[f+75232>>2]|0,m+2047516|0,0,c[m+2046892>>2]|0,0,0,g+32|0,g+40|0)|0;m=f+8204|0;f=k;c[m>>2]=c[f>>2];c[m+4>>2]=c[f+4>>2];f=n+24|0;n=l;c[f>>2]=c[n>>2];c[f+4>>2]=c[n+4>>2];i=g;return p|0}function i6b(a,d,e,f,g,h,j,k,l,m,n,o){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0;p=i;i=i+8|0;q=p|0;r=g;g=h;h=l;l=m;m=n;n=o;b[q>>1]=j;b[q+2>>1]=k;k=Tec(c[(c[c[a+160>>2]>>2]|0)+72>>2]|0)|0;if((g|0)==8){s=r+1>>1;t=1}else{s=r;t=0}qgc(d,r,h|0,16,q,l,16,16,0,k,0,m,n);qgc(e,s,h+256|0,g,q,l,g,g,0,k,t,m,n);qgc(f,s,h+512|0,g,q,l,g,g,0,k,t,m,n);i=p;return}function j6b(){q6b();s6b(3348768,233600);return}function k6b(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=9543824;g=218528;h=-16384;j=1;do{if((h|0)==0){j=0}if((j|0)!=0){k=-h|0}else{k=h}l=k;m=j;if((l|0)>4){n=4;do{o=n+1|0;n=o;if((o|0)<11){p=(c[g+(n<<4)+12>>2]|0)<=(l|0)}else{p=0}}while(p);o=n-1|0;n=o;b[f+(h<<2)>>1]=o;m=m|l-(c[g+(n<<4)+12>>2]|0)<<1}else{b[f+(h<<2)>>1]=l}b[f+(h<<2)+2>>1]=m;o=0;q=218528+(b[f+(h<<2)>>1]<<4)|0;if((c[q+12>>2]|0)!=0){r=b[f+(h<<2)+2>>1]|0;s=c[q+8>>2]|0;if((s|0)!=0){t=c[q>>2]|0;u=c[q+4>>2]|0;q=r>>1;v=s;s=0;w=0;do{x=v-1|0;v=x;y=q>>x&1;if((y|0)!=0){z=255-(d[u+(w<<24>>24>>1)|0]|0)|0}else{z=d[u+(w<<24>>24>>1)|0]|0}s=s+(c[206872+(z<<2)>>2]|0)|0;w=a[t+((w<<24>>24)+y)|0]|0;}while((v|0)!=0);o=o+s|0}o=o+(c[206872+(((r&1|0)!=0?127:128)<<2)>>2]|0)|0;b[9609360+(h+16384<<1)>>1]=o}v=h+1|0;h=v;}while((v|0)<16384);c[837020]=9543824;c[837022]=9642128;i=e;return}function l6b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a;c[f>>2]=1;c[g>>2]=h;c[g+4>>2]=f;dec(h+24720|0,b,d,666,g);i=e;return c[f>>2]|0}function m6b(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;f=g;g=c[f+4>>2]|0;c[g>>2]=c[g>>2]&(((b[(c[(c[f>>2]|0)+(a*8240|0)+8200>>2]|0)+(d<<1)>>1]|0)!=0^1)&1);i=i;return}function n6b(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+16|0;j=h|0;k=b;b=e;e=f;f=g;g=k+1434592|0;l=k+57488|0;m=c[c[l+160>>2]>>2]|0;n=c[b>>2]|0;o=l;p=o;if((c[p+164>>2]|0)!=0){q=c[(c[p+160>>2]|0)+(-(c[p+156>>2]|0)<<2)>>2]|0}else{q=0}p=q;q=o;if((c[q+168>>2]|0)!=0){r=c[(c[q+160>>2]|0)-4>>2]|0}else{r=0}q=r;if((p|0)!=0){s=d[p+12|0]|0}else{s=0}if((q|0)!=0){t=d[q+12|0]|0}else{t=0}q=s+t|0;t=((Thc(g+13408|0,d[m+13|0]|0,3)|0)!=0^1)&1;c[j>>2]=k;c[j+4>>2]=l;c[j+8>>2]=b;if((a[m+12|0]|0)==0){if((e|0)!=0){eec(l,f,400,j);c[b>>2]=n;i=h;return}else{m=g+36500+(q<<3)|0;c[m>>2]=(c[m>>2]|0)+t;eec(l,f,312,j);i=h;return}}if((e|0)==0){j=g+36500+(q<<3)+4|0;c[j>>2]=(c[j>>2]|0)+t}t=l;l=f;f=0;while(1){if((f|0)>=3){break}j=t+(f*52|0)|0;q=j;g=c[558424+(l<<4)+(c[q+8>>2]<<3)+(c[q+12>>2]<<2)>>2]|0;if(!(g>>>0<13>>>0)){u=19;break}q=g;mrc(c[j+44>>2]|0,0,c[777792+(q<<2)>>2]|0)|0;mrc(c[j+48>>2]|0,0,c[777848+(q<<2)>>2]|0)|0;f=f+1|0}if((u|0)==19){Cd(2424840,2341888,292,2652416)}if((e|0)!=0){c[b>>2]=n}i=h;return}function o6b(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;l=i;i=i+1048|0;m=l|0;n=l+1024|0;o=l+1032|0;p=l+1040|0;q=f;f=g;g=h;h=j;j=k;k=c[j>>2]|0;r=c[j+4>>2]|0;s=c[j+8>>2]|0;j=k+32768+(q*8240|0)|0;t=r+(q*52|0)|0;q=c[c[r+160>>2]>>2]|0;c[n>>2]=c[s>>2];u=e[(c[j+8200>>2]|0)+(f<<1)>>1]|0;v=c[t+4>>2]|0;w=(c[j+8192>>2]|0)+(f<<4<<1)|0;j=(c[q+20>>2]|0)>0|0;x=k+2017372+(h*6912|0)+(v*3456|0)+(j*1728|0)|0;y=k+1448306+(h*432|0)+(v*216|0)+(j*108|0)|0;z=k+1468364+(h*576|0)+(v*288|0)+(j*144|0)|0;j=(h|0)==0?233584:232560;if((Thc(k+1448e3|0,d[q+13|0]|0,3)|0)!=0){A=0}else{A=16<<(h<<1)}q=A;A=h;k=(c[1960336+(g<<2)>>2]|0)-A|0;B=f>>(A<<1);c[o>>2]=(B&(1<<k)-1)<<A;c[p>>2]=B>>k<<A;A=(c[t+44>>2]|0)+(c[o>>2]|0)|0;k=(c[t+48>>2]|0)+(c[p>>2]|0)|0;B=0;C=0;D=h;if((D|0)==2){B=(c[A>>2]|0)!=0&255;C=(c[k>>2]|0)!=0&255}else if((D|0)==1){B=(b[A>>1]|0)!=0&255;C=(b[k>>1]|0)!=0&255}else if((D|0)==3){E=A;B=((c[E>>2]|0)!=0|(c[E+4>>2]|0)!=0)&1;E=k;C=((c[E>>2]|0)!=0|(c[E+4>>2]|0)!=0)&1}else if((D|0)==0){B=(a[A]|0)!=0&255;C=(a[k]|0)!=0&255}else{Cd(2320752,2556136,170,2652536)}k=((B<<24>>24|0)!=0)+((C<<24>>24|0)!=0)|0;C=r;B=h;A=f;f=c[c[C+160>>2]>>2]|0;do{if((c[f+20>>2]|0)>0){F=13}else{if((v|0)!=0){F=13;break}if((c[C+25808>>2]|0)!=0){F=13;break}D=f;if((c[D>>2]|0)>>>0<3>>>0){G=c[D+76+(A*12|0)>>2]|0}else{G=c[D+4>>2]|0}H=204488+(B*48|0)+((c[1064496+(G<<2)>>2]|0)*12|0)|0}}while(0);if((F|0)==13){H=218736+(B*12|0)|0}B=H;H=c[B>>2]|0;F=c[B+8>>2]|0;B=0;while(1){if((B|0)>=(u|0)){break}G=0;A=0;G=b[w+(b[H+(B<<1)>>1]<<1)>>1]|0;while(1){if(!((G|0)!=0^1)){break}f=n;C=y+((d[j+B|0]|0)*18|0)+(k*3|0)|0;v=0;D=x+((d[j+B|0]|0)*288|0)+(k*48|0)|0;a[(c[f>>2]|0)+6|0]=v;c[c[f>>2]>>2]=C;a[(c[f>>2]|0)+7|0]=A;C=f;c[C>>2]=(c[C>>2]|0)+8;C=D+((v&255)<<2)|0;c[C>>2]=(c[C>>2]|0)+1;C=z+((d[j+B|0]|0)*24|0)+(k<<2)|0;c[C>>2]=(c[C>>2]|0)+(((A|0)!=0^1)&1);A=1;a[m+(b[H+(B<<1)>>1]|0)|0]=0;B=B+1|0;C=F;v=m|0;D=B;k=(d[v+(b[C+(D<<1<<1)>>1]|0)|0]|0)+1+(d[v+(b[C+((D<<1)+1<<1)>>1]|0)|0]|0)>>1;G=b[w+(b[H+(B<<1)>>1]<<1)>>1]|0}D=n;C=y+((d[j+B|0]|0)*18|0)+(k*3|0)|0;v=b[(c[837020]|0)+(G<<2)+2>>1]|0;f=b[(c[837020]|0)+(G<<2)>>1]&255;E=x+((d[j+B|0]|0)*288|0)+(k*48|0)|0;a[(c[D>>2]|0)+6|0]=f;b[(c[D>>2]|0)+4>>1]=v;c[c[D>>2]>>2]=C;a[(c[D>>2]|0)+7|0]=A;C=D;c[C>>2]=(c[C>>2]|0)+8;C=E+((f&255)<<2)|0;c[C>>2]=(c[C>>2]|0)+1;C=z+((d[j+B|0]|0)*24|0)+(k<<2)|0;c[C>>2]=(c[C>>2]|0)+(((A|0)!=0^1)&1);a[m+(b[H+(B<<1)>>1]|0)|0]=a[206856+(b[(c[837020]|0)+(G<<2)>>1]|0)|0]|0;B=B+1|0;C=F;f=m|0;E=B;k=(d[f+(b[C+(E<<1<<1)>>1]|0)|0]|0)+1+(d[f+(b[C+((E<<1)+1<<1)>>1]|0)|0]|0)>>1}if((B|0)>=(q|0)){I=c[n>>2]|0;J=s;c[J>>2]=I;K=r;L=t;M=g;N=h;O=B;P=(O|0)>0;Q=P&1;R=c[o>>2]|0;S=c[p>>2]|0;fec(K,L,M,N,Q,R,S);i=l;return}q=n;m=y+((d[j+B|0]|0)*18|0)+(k*3|0)|0;y=11;F=x+((d[j+B|0]|0)*288|0)+(k*48|0)|0;a[(c[q>>2]|0)+6|0]=y;c[c[q>>2]>>2]=m;a[(c[q>>2]|0)+7|0]=0;m=q;c[m>>2]=(c[m>>2]|0)+8;m=F+((y&255)<<2)|0;c[m>>2]=(c[m>>2]|0)+1;m=z+((d[j+B|0]|0)*24|0)+(k<<2)|0;c[m>>2]=(c[m>>2]|0)+1;I=c[n>>2]|0;J=s;c[J>>2]=I;K=r;L=t;M=g;N=h;O=B;P=(O|0)>0;Q=P&1;R=c[o>>2]|0;S=c[p>>2]|0;fec(K,L,M,N,Q,R,S);i=l;return}function p6b(a,b,d,f,g){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=a;a=b;b=d;d=f;f=g;g=c[f+4>>2]|0;m=(c[f>>2]|0)+32768+(l*8240|0)|0;f=d;n=(c[1960336+(b<<2)>>2]|0)-f|0;o=a>>(f<<1);c[j>>2]=(o&(1<<n)-1)<<f;c[k>>2]=o>>n<<f;fec(g,g+(l*52|0)|0,b,d,(e[(c[m+8200>>2]|0)+(a<<1)>>1]|0|0)>0|0,c[j>>2]|0,c[k>>2]|0);i=h;return}function q6b(){r6b(9881064,1);r6b(9881048,2);r6b(9881040,3);r6b(9881032,4);r6b(9881016,5);r6b(9880984,14);return}function r6b(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=i;e=b;b=c;c=0;while(1){f=c+1|0;c=f;if((f|0)>=(b|0)){break}f=c<<1&255;a[e+1|0]=f;a[e|0]=f;e=e+2|0}a[e+1|0]=0;a[e|0]=0;i=d;return}function s6b(a,b){a=a|0;b=b|0;var c=0;c=i;t6b(a,b,0,0,0);i=c;return}function t6b(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;j=b;b=d;d=e;e=f;f=g;e=e+e|0;f=f+1|0;do{g=d;d=g+1|0;k=a[b+g|0]|0;if((k<<24>>24|0)<=0){c[j+(-(k<<24>>24)<<3)>>2]=e;c[j+(-(k<<24>>24)<<3)+4>>2]=f}else{t6b(j,b,k<<24>>24,e,f)}k=e+1|0;e=k;}while((k&1|0)!=0);i=h;return}function u6b(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;v6b(0,a,b,c)|0;i=d;return}function v6b(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=b;b=d;d=e;e=f;if((a[b+h|0]|0)<=0){j=c[e+(-(a[b+h|0]|0)<<2)>>2]|0}else{j=v6b(a[b+h|0]|0,b,d,e)|0}if((a[b+(h+1)|0]|0)<=0){k=c[e+(-(a[b+(h+1)|0]|0)<<2)>>2]|0}else{k=v6b(a[b+(h+1)|0]|0,b,d,e)|0}c[d+(h>>>1<<3)>>2]=j;c[d+(h>>>1<<3)+4>>2]=k;i=g;return j+k|0}function w6b(a,b,e,f,g,h,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0;l=i;m=a;a=b;b=e;e=f;f=g;g=h;h=j;j=k;c[j>>2]=0;c[h>>2]=0;k=0;while(1){if((k|0)>=(g|0)){break}n=0;while(1){if((n|0)>=(f|0)){break}o=(d[m+n|0]|0)-(d[b+n|0]|0)|0;p=j;c[p>>2]=(c[p>>2]|0)+o;p=ca(o,o)|0;o=h;c[o>>2]=(c[o>>2]|0)+p;n=n+1|0}m=m+a|0;b=b+e|0;k=k+1|0}i=l;return}function x6b(a){a=a|0;var c=0,d=0,e=0;c=i;d=a;a=0;e=0;while(1){if(!(e>>>0<256>>>0)){break}a=a+(ca(b[d+(e<<1)>>1]|0,b[d+(e<<1)>>1]|0)|0)|0;e=e+1|0}i=c;return a|0}function y6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,64,32,h,j);c[f>>2]=c[h>>2];f=c[h>>2]|0;h=c[j>>2]|0;e=c[j>>2]|0;j=Erc(h,(h|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=G;h=xrc(f,0,j>>>11|e<<21,e>>11|((e|0)<0|0?-1:0)<<21)|0;i=g;return h|0}function z6b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+12672|0;j=h|0;k=h+8320|0;A6b(a,j|0,b,1,33,64,233656+(c<<4)-2|0);B6b(j|0,k|0,64,64,32,64,233656+(d<<4)-2|0);d=y6b(k|0,64,e,f,g)|0;i=h;return d|0}function A6b(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0;k=i;l=a;a=c;c=e;e=f;f=g;g=h;h=j;j=0;while(1){if(!(j>>>0<f>>>0)){break}m=0;while(1){if(!(m>>>0<g>>>0)){break}n=ca(d[l|0]|0,b[h>>1]|0)|0;b[a+(m<<1)>>1]=n+(ca(d[l+e|0]|0,b[h+2>>1]|0)|0)+64>>7;l=l+1|0;m=m+1|0}l=l+(c-g)|0;a=a+(g<<1)|0;j=j+1|0}i=k;return}function B6b(c,d,f,g,h,j,k){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;l=i;m=c;c=d;d=f;f=g;g=h;h=j;j=k;k=0;while(1){if(!(k>>>0<g>>>0)){break}n=0;while(1){if(!(n>>>0<h>>>0)){break}o=ca(e[m>>1]|0,b[j>>1]|0)|0;a[c+n|0]=o+(ca(e[m+(f<<1)>>1]|0,b[j+2>>1]|0)|0)+64>>7;m=m+2|0;n=n+1|0}m=m+(d-h<<1)|0;c=c+h|0;k=k+1|0}i=l;return}function C6b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+16792|0;k=j|0;l=j+8320|0;m=j+12688-1&-16;A6b(a,k|0,b,1,33,64,233656+(c<<4)-2|0);B6b(k|0,l|0,64,64,32,64,233656+(d<<4)-2|0);D6b(m,h,64,32,l|0,64);l=y6b(m,64,e,f,g)|0;i=j;return l|0}function D6b(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0;j=i;k=b;b=c;c=e;e=f;f=g;g=h;h=0;while(1){if((h|0)>=(e|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}a[k+l|0]=(d[b+l|0]|0)+(d[f+l|0]|0)+1>>1;l=l+1|0}k=k+c|0;b=b+c|0;f=f+g|0;h=h+1|0}i=j;return}function E6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,32,64,h,j);c[f>>2]=c[h>>2];f=c[h>>2]|0;h=c[j>>2]|0;e=c[j>>2]|0;j=Erc(h,(h|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=G;h=xrc(f,0,j>>>11|e<<21,e>>11|((e|0)<0|0?-1:0)<<21)|0;i=g;return h|0}function F6b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+12672|0;j=h|0;k=h+8320|0;A6b(a,j|0,b,1,65,32,233656+(c<<4)-2|0);B6b(j|0,k|0,32,32,64,32,233656+(d<<4)-2|0);d=E6b(k|0,32,e,f,g)|0;i=h;return d|0}function G6b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+14744|0;k=j|0;l=j+8320|0;m=j+12688-1&-16;A6b(a,k|0,b,1,65,32,233656+(c<<4)-2|0);B6b(k|0,l|0,32,32,64,32,233656+(d<<4)-2|0);D6b(m,h,32,64,l|0,32);l=E6b(m,32,e,f,g)|0;i=j;return l|0}function H6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,32,16,h,j);c[f>>2]=c[h>>2];f=c[h>>2]|0;h=c[j>>2]|0;e=c[j>>2]|0;j=Erc(h,(h|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=G;h=xrc(f,0,j>>>9|e<<23,e>>9|((e|0)<0|0?-1:0)<<23)|0;i=g;return h|0}function I6b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+3264|0;j=h|0;k=h+2112|0;A6b(a,j|0,b,1,17,32,233656+(c<<4)-2|0);B6b(j|0,k|0,32,32,16,32,233656+(d<<4)-2|0);d=H6b(k|0,32,e,f,g)|0;i=h;return d|0}function J6b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+3800|0;k=j|0;l=j+2112|0;m=j+3280-1&-16;A6b(a,k|0,b,1,17,32,233656+(c<<4)-2|0);B6b(k|0,l|0,32,32,16,32,233656+(d<<4)-2|0);D6b(m,h,32,16,l|0,32);l=H6b(m,32,e,f,g)|0;i=j;return l|0}function K6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,16,32,h,j);c[f>>2]=c[h>>2];f=c[h>>2]|0;h=c[j>>2]|0;e=c[j>>2]|0;j=Erc(h,(h|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=G;h=xrc(f,0,j>>>9|e<<23,e>>9|((e|0)<0|0?-1:0)<<23)|0;i=g;return h|0}function L6b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+3264|0;j=h|0;k=h+2112|0;A6b(a,j|0,b,1,33,16,233656+(c<<4)-2|0);B6b(j|0,k|0,16,16,32,16,233656+(d<<4)-2|0);d=K6b(k|0,16,e,f,g)|0;i=h;return d|0}function M6b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+3800|0;k=j|0;l=j+2112|0;m=j+3280-1&-16;A6b(a,k|0,b,1,33,16,233656+(c<<4)-2|0);B6b(k|0,l|0,16,16,32,16,233656+(d<<4)-2|0);D6b(m,h,16,32,l|0,16);l=K6b(m,16,e,f,g)|0;i=j;return l|0}function N6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,64,64,h,j);c[f>>2]=c[h>>2];f=c[h>>2]|0;h=c[j>>2]|0;e=c[j>>2]|0;j=Erc(h,(h|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=G;h=xrc(f,0,j>>>12|e<<20,e>>12|((e|0)<0|0?-1:0)<<20)|0;i=g;return h|0}function O6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,32,32,h,j);c[f>>2]=c[h>>2];f=c[h>>2]|0;h=c[j>>2]|0;e=c[j>>2]|0;j=Erc(h,(h|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=G;h=xrc(f,0,j>>>10|e<<22,e>>10|((e|0)<0|0?-1:0)<<22)|0;i=g;return h|0}function P6b(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;w6b(a,b,c,d,16,16,e,f);i=g;return}function Q6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,16,16,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>8)|0;i=g;return f|0}function R6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,8,16,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>7)|0;i=g;return f|0}function S6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,16,8,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>7)|0;i=g;return f|0}function T6b(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;w6b(a,b,c,d,8,8,e,f);i=g;return}function U6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,8,8,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>6)|0;i=g;return f|0}function V6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,8,4,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>5)|0;i=g;return f|0}function W6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,4,8,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>5)|0;i=g;return f|0}function X6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;w6b(a,b,d,e,4,4,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>4)|0;i=g;return f|0}function Y6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;i=i+16|0;h=g|0;w6b(a,b,d,e,16,16,h,g+8|0);c[f>>2]=c[h>>2];i=g;return c[h>>2]|0}function Z6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;i=i+16|0;h=g|0;w6b(a,b,d,e,16,8,h,g+8|0);c[f>>2]=c[h>>2];i=g;return c[h>>2]|0}function _6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;i=i+16|0;h=g|0;w6b(a,b,d,e,8,16,h,g+8|0);c[f>>2]=c[h>>2];i=g;return c[h>>2]|0}function $6b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;i=i+16|0;h=g|0;w6b(a,b,d,e,8,8,h,g+8|0);c[f>>2]=c[h>>2];i=g;return c[h>>2]|0}function a7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+360|0;j=h|0;k=h+320|0;A6b(a,k|0,b,1,5,4,233656+(c<<4)-2|0);B6b(k|0,j|0,4,4,4,4,233656+(d<<4)-2|0);d=X6b(j|0,4,e,f,g)|0;i=h;return d|0}function b7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+400|0;k=j|0;l=j+360|0;m=j+336-1&-16;A6b(a,l|0,b,1,5,4,233656+(c<<4)-2|0);B6b(l|0,k|0,4,4,4,4,233656+(d<<4)-2|0);D6b(m,h,4,4,k|0,4);k=X6b(m,4,e,f,g)|0;i=j;return k|0}function c7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+464|0;j=h|0;k=h+144|0;A6b(a,j|0,b,1,9,8,233656+(c<<4)-2|0);B6b(j|0,k|0,8,8,8,8,233656+(d<<4)-2|0);d=U6b(k|0,8,e,f,g)|0;i=h;return d|0}function d7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+552|0;k=j|0;l=j+144|0;m=j+480-1&-16;A6b(a,k|0,b,1,9,8,233656+(c<<4)-2|0);B6b(k|0,l|0,8,8,8,8,233656+(d<<4)-2|0);D6b(m,h,8,8,l|0,8);l=U6b(m,8,e,f,g)|0;i=j;return l|0}function e7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+864|0;j=h|0;k=h+544|0;A6b(a,j|0,b,1,17,16,233656+(c<<4)-2|0);B6b(j|0,k|0,16,16,16,16,233656+(d<<4)-2|0);d=Q6b(k|0,16,e,f,g)|0;i=h;return d|0}function f7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+1144|0;k=j|0;l=j+544|0;m=j+880-1&-16;A6b(a,k|0,b,1,17,16,233656+(c<<4)-2|0);B6b(k|0,l|0,16,16,16,16,233656+(d<<4)-2|0);D6b(m,h,16,16,l|0,16);l=Q6b(m,16,e,f,g)|0;i=j;return l|0}function g7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+12672|0;j=h|0;k=h+8320|0;A6b(a,j|0,b,1,65,64,233656+(c<<4)-2|0);B6b(j|0,k|0,64,64,64,64,233656+(d<<4)-2|0);d=N6b(k|0,64,e,f,g)|0;i=h;return d|0}function h7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+16792|0;k=j|0;l=j+8320|0;m=j+12688-1&-16;A6b(a,k|0,b,1,65,64,233656+(c<<4)-2|0);B6b(k|0,l|0,64,64,64,64,233656+(d<<4)-2|0);D6b(m,h,64,64,l|0,64);l=N6b(m,64,e,f,g)|0;i=j;return l|0}function i7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+3264|0;j=h|0;k=h+2112|0;A6b(a,j|0,b,1,33,32,233656+(c<<4)-2|0);B6b(j|0,k|0,32,32,32,32,233656+(d<<4)-2|0);d=O6b(k|0,32,e,f,g)|0;i=h;return d|0}function j7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+4312|0;k=j|0;l=j+2112|0;m=j+3280-1&-16;A6b(a,k|0,b,1,33,32,233656+(c<<4)-2|0);B6b(k|0,l|0,32,32,32,32,233656+(d<<4)-2|0);D6b(m,h,32,32,l|0,32);l=O6b(m,32,e,f,g)|0;i=j;return l|0}function k7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=e7b(a,b,8,0,c,d,e)|0;i=f;return g|0}function l7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=i7b(a,b,8,0,c,d,e)|0;i=f;return g|0}function m7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=g7b(a,b,8,0,c,d,e)|0;i=f;return g|0}function n7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=e7b(a,b,0,8,c,d,e)|0;i=f;return g|0}function o7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=i7b(a,b,0,8,c,d,e)|0;i=f;return g|0}function p7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=g7b(a,b,0,8,c,d,e)|0;i=f;return g|0}function q7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=e7b(a,b,8,8,c,d,e)|0;i=f;return g|0}function r7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=i7b(a,b,8,8,c,d,e)|0;i=f;return g|0}function s7b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=g7b(a,b,8,8,c,d,e)|0;i=f;return g|0}function t7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+608|0;j=h|0;k=h+288|0;A6b(a,j|0,b,1,9,16,233656+(c<<4)-2|0);B6b(j|0,k|0,16,16,8,16,233656+(d<<4)-2|0);d=S6b(k|0,16,e,f,g)|0;i=h;return d|0}function u7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+760|0;k=j|0;l=j+288|0;m=j+624-1&-16;A6b(a,k|0,b,1,9,16,233656+(c<<4)-2|0);B6b(k|0,l|0,16,16,8,16,233656+(d<<4)-2|0);D6b(m,h,16,8,l|0,16);l=S6b(m,16,e,f,g)|0;i=j;return l|0}function v7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+608|0;j=h|0;k=h+288|0;A6b(a,j|0,b,1,17,8,233656+(c<<4)-2|0);B6b(j|0,k|0,8,8,16,8,233656+(d<<4)-2|0);d=R6b(k|0,8,e,f,g)|0;i=h;return d|0}function w7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+760|0;k=j|0;l=j+288|0;m=j+624-1&-16;A6b(a,k|0,b,1,17,8,233656+(c<<4)-2|0);B6b(k|0,l|0,8,8,16,8,233656+(d<<4)-2|0);D6b(m,h,8,16,l|0,8);l=R6b(m,8,e,f,g)|0;i=j;return l|0}function x7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+400|0;j=h|0;k=h+80|0;A6b(a,j|0,b,1,5,8,233656+(c<<4)-2|0);B6b(j|0,k|0,8,8,4,8,233656+(d<<4)-2|0);d=V6b(k|0,8,e,f,g)|0;i=h;return d|0}function y7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+456|0;k=j|0;l=j+80|0;m=j+416-1&-16;A6b(a,k|0,b,1,5,8,233656+(c<<4)-2|0);B6b(k|0,l|0,8,8,4,8,233656+(d<<4)-2|0);D6b(m,h,8,4,l|0,8);l=V6b(m,8,e,f,g)|0;i=j;return l|0}function z7b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+400|0;j=h|0;k=h+80|0;A6b(a,j|0,b,1,9,4,233656+(c<<4)-2|0);B6b(j|0,k|0,4,4,8,4,233656+(d<<4)-2|0);d=W6b(k|0,4,e,f,g)|0;i=h;return d|0}function A7b(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;i=i+456|0;k=j|0;l=j+80|0;m=j+416-1&-16;A6b(a,k|0,b,1,9,4,233656+(c<<4)-2|0);B6b(k|0,l|0,4,4,8,4,233656+(d<<4)-2|0);D6b(m,h,4,8,l|0,4);l=W6b(m,4,e,f,g)|0;i=j;return l|0}function B7b(a,b,c){a=+a;b=+b;c=+c;var d=0,e=0.0,f=0.0,g=0.0,h=0.0;d=i;e=b;b=c;if(!(b>0.0)){f=100.0;g=f;i=d;return+g}c=+fd(+(a*e*e/b))*10.0;if(c>100.0){h=100.0}else{h=c}f=h;g=f;i=d;return+g}function C7b(b,d,e,f,g,h,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0;m=i;n=b;b=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=((f-1+(ca(c[n>>2]|0,g)|0)|0)>>>0)/(f>>>0)|0;o=((h-1+(ca(c[n+4>>2]|0,j)|0)|0)>>>0)/(h>>>0)|0;D7b(c[n+52>>2]|0,c[n+16>>2]|0,c[n>>2]|0,c[n+4>>2]|0,c[b+52>>2]|0,c[b+16>>2]|0,l,o,d,e,f,g,h,j,k);if((l|0)<(c[b>>2]|0)){p=0;while(1){if((p|0)>=(o|0)){break}q=(c[b+52>>2]|0)+(ca(p,c[b+16>>2]|0)|0)+l-1|0;r=(ca(p,c[b+16>>2]|0)|0)+l-2|0;mrc(q|0,a[(c[b+52>>2]|0)+r|0]&255|0,(c[b>>2]|0)-l+1|0)|0;p=p+1|0}}if((o|0)<(c[b+4>>2]|0)){p=o-1|0;while(1){if((p|0)>=(c[b+4>>2]|0)){break}r=(c[b+52>>2]|0)+(ca(p,c[b+16>>2]|0)|0)|0;q=(c[b+52>>2]|0)+(ca(o-2|0,c[b+16>>2]|0)|0)|0;nrc(r|0,q|0,(c[b>>2]|0)+1|0)|0;p=p+1|0}}D7b(c[n+56>>2]|0,c[n+36>>2]|0,c[n+20>>2]|0,c[n+24>>2]|0,c[b+56>>2]|0,c[b+36>>2]|0,(l|0)/2|0,(o|0)/2|0,d,e,f,g,h,j,k);if(((l|0)/2|0|0)<(c[b+20>>2]|0)){p=0;while(1){if((p|0)>=(c[b+24>>2]|0)){break}q=(c[b+56>>2]|0)+(ca(p,c[b+36>>2]|0)|0)+((l|0)/2|0)-1|0;r=(ca(p,c[b+36>>2]|0)|0)+((l|0)/2|0)-2|0;mrc(q|0,a[(c[b+56>>2]|0)+r|0]&255|0,(c[b+20>>2]|0)-((l|0)/2|0)+1|0)|0;p=p+1|0}}if(((o|0)/2|0|0)<(c[b+24>>2]|0)){p=((o|0)/2|0)-1|0;while(1){if((p|0)>=((c[b+4>>2]|0)/2|0|0)){break}r=(c[b+56>>2]|0)+(ca(p,c[b+36>>2]|0)|0)|0;q=(c[b+56>>2]|0)+(ca(((o|0)/2|0)-2|0,c[b+36>>2]|0)|0)|0;nrc(r|0,q|0,c[b+20>>2]|0)|0;p=p+1|0}}D7b(c[n+60>>2]|0,c[n+36>>2]|0,c[n+20>>2]|0,c[n+24>>2]|0,c[b+60>>2]|0,c[b+36>>2]|0,(l|0)/2|0,(o|0)/2|0,d,e,f,g,h,j,k);if(((l|0)/2|0|0)<(c[b+20>>2]|0)){p=0;while(1){if((p|0)>=(c[b+24>>2]|0)){break}k=(c[b+60>>2]|0)+(ca(p,c[b+36>>2]|0)|0)+((l|0)/2|0)-1|0;j=(ca(p,c[b+36>>2]|0)|0)+((l|0)/2|0)-2|0;mrc(k|0,a[(c[b+60>>2]|0)+j|0]&255|0,(c[b+20>>2]|0)-((l|0)/2|0)+1|0)|0;p=p+1|0}}if(((o|0)/2|0|0)>=(c[b+24>>2]|0)){i=m;return}p=((o|0)/2|0)-1|0;while(1){if((p|0)>=((c[b+4>>2]|0)/2|0|0)){break}l=(c[b+60>>2]|0)+(ca(p,c[b+36>>2]|0)|0)|0;j=(c[b+60>>2]|0)+(ca(((o|0)/2|0)-2|0,c[b+36>>2]|0)|0)|0;nrc(l|0,j|0,c[b+20>>2]|0)|0;p=p+1|0}i=m;return}function D7b(a,b,c,d,e,f,g,h,j,k,l,m,n,o,p){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;q=i;r=a;a=b;b=c;c=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=p;p=134;s=134;t=0;u=0;v=1;w=0;x=r;if((a|0)<0){y=c-1|0;y=ca(y,a)|0;x=x+y|0}y=((l*10|0)>>>0)/(k>>>0)|0;if((y|0)==6){t=350}else if((y|0)==5){t=660}else if((y|0)==8){t=542}else{v=0}y=((n*10|0)>>>0)/(m>>>0)|0;if((y|0)==6){u=38;z=5;A=3}else if((y|0)==5){if((o|0)!=0){u=430}else{w=1;u=308}z=2;A=1}else if((y|0)==8){u=674;z=5;A=4}else{v=0}if((v|0)!=0){if((c|0)==(g|0)){B=0;while(1){if((B|0)>=(g|0)){break}mf[t&2047](r,b,d,f);r=r+a|0;d=d+e|0;B=B+1|0}i=q;return}if((w|0)!=0){if(r>>>0<x>>>0){r=x}mf[t&2047](r,b,h,f)}B=0;while(1){if((B|0)>=((g+A-1|0)/(A|0)|0|0)){break}C=0;while(1){if((C|0)>=(z|0)){break}v=r+(ca(C,a)|0)|0;if(v>>>0<x>>>0){v=x}y=h+(ca(C+1|0,e)|0)|0;mf[t&2047](v,b,y,f);C=C+1|0}pe[u&1023](h+e|0,e,d,e,f);if((w|0)!=0){nrc(h|0,h+(ca(z,e)|0)|0,f)|0}r=r+(ca(z,a)|0)|0;d=d+(ca(A,e)|0)|0;B=B+1|0}i=q;return}do{if((k|0)==2){if((l|0)!=1){break}s=10}}while(0);do{if((m|0)==2){if((n|0)!=1){break}if((o|0)!=0){p=10}else{p=142}}}while(0);if((c|0)==(g|0)){B=0;while(1){if((B|0)>=(g|0)){break}Ge[s&255](r,1,k,b+1|0,d,1,l,f);r=r+a|0;d=d+e|0;B=B+1|0}i=q;return}if(g>>>0>c>>>0){A=(j&255)-1|0;z=((ca(A,c)|0)>>>0)/(g>>>0)|0}else{z=(j&255)-1|0;A=((ca(z,n)|0)>>>0)/(m>>>0)|0}Ge[s&255](r,1,k,b+1|0,h,1,l,f);j=((g+A-1|0)>>>0)/(A>>>0)|0;B=0;while(1){if((B|0)>=(j|0)){break}C=1;while(1){if((C|0)>=(z+1|0)){break}if(((ca(B,z)|0)+C|0)<(c|0)){g=r+(ca(C,a)|0)|0;o=h+(ca(C,e)|0)|0;Ge[s&255](g,1,k,b+1|0,o,1,l,f)}else{nrc(h+(ca(C,e)|0)|0,h+(ca(C-1|0,e)|0)|0,e)|0}C=C+1|0}o=0;while(1){if((o|0)>=(f|0)){break}Ge[p&255](h+o|0,e,m,z+1|0,d+o|0,e,n,A);o=o+1|0}nrc(h|0,h+(ca(z,e)|0)|0,e)|0;r=r+(ca(z,a)|0)|0;d=d+(ca(A,e)|0)|0;B=B+1|0}i=q;return}function E7b(b,c,d,e,f,g,h,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;e=i;k=b;b=c;c=d;d=f;f=g;g=h;h=j;j=(g>>>0)/2|0;l=g;m=0;n=a[k]|0;o=a[k+b|0]|0;p=0;while(1){if(!(p>>>0<(ca(h,f)|0)>>>0)){break}a[d+p|0]=(((ca(l,n&255)|0)+(ca(m,o&255)|0)+j|0)>>>0)/(g>>>0)|0;m=m+c|0;while(1){if(!(m>>>0>g>>>0)){break}m=m-g|0;k=k+b|0;n=a[k]|0;o=a[k+b|0]|0}l=g-m|0;p=p+f|0}i=e;return}function F7b(b,c,d,e,f,g,h,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;h=i;e=b;b=c;c=f;f=g;g=j;b=b<<1;j=0;d=0;while(1){if(!(d>>>0<(ca(g,f)|0)>>>0)){break}a[c+d|0]=a[e+j|0]|0;d=d+f|0;j=j+b|0}i=h;return}function G7b(b,c,e,f,g,h,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0;j=i;f=b;b=c;c=g;g=h;h=k;k=b;b=b<<1;a[c|0]=a[f|0]|0;e=g;l=b;while(1){if(!(e>>>0<(ca(h,g)|0)>>>0)){break}m=8;m=m+((d[f+(l-k)|0]|0)*3|0)|0;m=m+((d[f+l|0]|0)*10|0)|0;m=m+((d[f+(l+k)|0]|0)*3|0)|0;m=m>>>4;a[c+e|0]=m;e=e+g|0;l=l+b|0}i=j;return}function H7b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;if((d|0)==0){e=-1;f=e;i=b;return f|0}if((c[d+72>>2]|0)>0){FYb(c[d+68>>2]|0)}mrc(d|0,0,92)|0;e=0;f=e;i=b;return f|0}function I7b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=a;a=b;b=d;d=e;if((g|0)==0){h=-2;j=h;i=f;return j|0}e=a+15&-16;k=b+15&-16;l=e+(d<<1)+31&-32;m=ca(k+(d<<1)|0,l)|0;n=e>>1;o=k>>1;p=l>>1;q=ca(o+d|0,p)|0;r=m+(q<<1)|0;if((c[g+68>>2]|0)==0){c[g+68>>2]=BYb(32,r)|0;c[g+72>>2]=r}do{if((c[g+68>>2]|0)!=0){if((c[g+72>>2]|0)<(r|0)){break}if((d&31|0)!=0){h=-3;j=h;i=f;return j|0}else{c[g+8>>2]=a;c[g+12>>2]=b;c[g>>2]=e;c[g+4>>2]=k;c[g+16>>2]=l;c[g+20>>2]=n;c[g+24>>2]=o;c[g+36>>2]=p;c[g+40>>2]=0;c[g+44>>2]=0;c[g+48>>2]=0;c[g+76>>2]=d;c[g+80>>2]=r;c[g+52>>2]=(c[g+68>>2]|0)+(ca(d,l)|0)+d;c[g+56>>2]=(c[g+68>>2]|0)+m+(ca((d|0)/2|0,p)|0)+((d|0)/2|0);c[g+60>>2]=(c[g+68>>2]|0)+m+q+(ca((d|0)/2|0,p)|0)+((d|0)/2|0);c[g+64>>2]=0;c[g+84>>2]=0;h=0;j=h;i=f;return j|0}}}while(0);h=-1;j=h;i=f;return j|0}function J7b(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;if((f|0)!=0){H7b(f)|0;g=I7b(f,b,c,d)|0;h=g;i=e;return h|0}else{g=-2;h=g;i=e;return h|0}return 0}function K7b(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;if((d|0)==0){e=-1;f=e;i=b;return f|0}if((c[d+72>>2]|0)>0){FYb(c[d+68>>2]|0)}mrc(d|0,0,92)|0;e=0;f=e;i=b;return f|0}function L7b(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;l=i;m=a;a=b;b=d;d=e;e=f;f=g;g=h;h=j;j=k;if((m|0)==0){n=-2;o=n;i=l;return o|0}k=a+7&-8;p=b+7&-8;q=k+(f<<1)+31&-32;r=ca(p+(f<<1)|0,q)|0;s=k>>d;t=p>>e;u=q>>d;v=f>>d;w=f>>e;x=ca(t+(w<<1)|0,u)|0;y=r+(x<<1)|0;a:do{if((h|0)!=0){z=y+31|0;if((g|0)!=0){}else{Cd(2315184,2554848,169,2650120);return 0}if((Ee[h&511](j,z,g)|0)<0){n=-1;o=n;i=l;return o|0}do{if((c[g>>2]|0)!=0){if((c[g+4>>2]|0)>>>0<z>>>0){break}mrc(c[g>>2]|0,0,c[g+4>>2]|0)|0;c[m+68>>2]=(c[g>>2]|0)+31&-32;break a}}while(0);n=-1;o=n;i=l;return o|0}else{do{if((y|0)>(c[m+72>>2]|0)){if((c[m+68>>2]|0)!=0){FYb(c[m+68>>2]|0)}c[m+68>>2]=BYb(32,y)|0;if((c[m+68>>2]|0)!=0){c[m+72>>2]=y;mrc(c[m+68>>2]|0,0,c[m+72>>2]|0)|0;break}n=-1;o=n;i=l;return o|0}}while(0)}}while(0);if((f&31|0)!=0){n=-3;o=n;i=l;return o|0}else{c[m+8>>2]=a;c[m+12>>2]=b;c[m>>2]=k;c[m+4>>2]=p;c[m+16>>2]=q;c[m+28>>2]=a+d>>d;c[m+32>>2]=b+e>>e;c[m+20>>2]=s;c[m+24>>2]=t;c[m+36>>2]=u;c[m+76>>2]=f;c[m+80>>2]=y;c[m+52>>2]=(c[m+68>>2]|0)+(ca(f,q)|0)+f;c[m+56>>2]=(c[m+68>>2]|0)+r+(ca(w,u)|0)+v;c[m+60>>2]=(c[m+68>>2]|0)+r+x+(ca(w,u)|0)+v;c[m+84>>2]=0;n=0;o=n;i=l;return o|0}return 0}function M7b(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;if((h|0)!=0){K7b(h)|0;j=L7b(h,b,c,d,e,f,0,0,0)|0;k=j;i=g;return k|0}else{j=-2;k=j;i=g;return k|0}return 0}function N7b(a){a=a|0;var b=0,d=0;b=i;d=a;if(((c[d+4>>2]|0)-(c[d+12>>2]|0)|0)<16){}else{Cd(2314888,2554712,59,2650856)}if(((c[d>>2]|0)-(c[d+8>>2]|0)|0)<16){}else{Cd(2424016,2554712,60,2650856)}if(((c[d+4>>2]|0)-(c[d+12>>2]|0)|0)>=0){}else{Cd(2341096,2554712,61,2650856)}if(((c[d>>2]|0)-(c[d+8>>2]|0)|0)>=0){}else{Cd(2282248,2554712,62,2650856)}O7b(c[d+52>>2]|0,c[d+16>>2]|0,c[d+8>>2]|0,c[d+12>>2]|0,c[d+76>>2]|0,c[d+76>>2]|0,(c[d+76>>2]|0)+(c[d+4>>2]|0)-(c[d+12>>2]|0)|0,(c[d+76>>2]|0)+(c[d>>2]|0)-(c[d+8>>2]|0)|0);O7b(c[d+56>>2]|0,c[d+36>>2]|0,((c[d+8>>2]|0)+1|0)/2|0,((c[d+12>>2]|0)+1|0)/2|0,(c[d+76>>2]|0)/2|0,(c[d+76>>2]|0)/2|0,((c[d+76>>2]|0)+(c[d+4>>2]|0)-(c[d+12>>2]|0)+1|0)/2|0,((c[d+76>>2]|0)+(c[d>>2]|0)-(c[d+8>>2]|0)+1|0)/2|0);O7b(c[d+60>>2]|0,c[d+36>>2]|0,((c[d+8>>2]|0)+1|0)/2|0,((c[d+12>>2]|0)+1|0)/2|0,(c[d+76>>2]|0)/2|0,(c[d+76>>2]|0)/2|0,((c[d+76>>2]|0)+(c[d+4>>2]|0)-(c[d+12>>2]|0)+1|0)/2|0,((c[d+76>>2]|0)+(c[d>>2]|0)-(c[d+8>>2]|0)+1|0)/2|0);i=b;return}function O7b(b,c,d,e,f,g,h,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=b;b=c;c=d;d=e;e=f;f=g;g=h;h=j;j=f+h+c|0;m=l;n=l+c-1|0;o=l+(-f|0)|0;p=l+c|0;c=0;while(1){if((c|0)>=(d|0)){break}mrc(o|0,a[m|0]&255|0,f|0)|0;mrc(p|0,a[n|0]&255|0,h|0)|0;m=m+b|0;n=n+b|0;o=o+b|0;p=p+b|0;c=c+1|0}m=l+(-f|0)|0;n=l+(ca(b,d-1|0)|0)+(-f|0)|0;o=l+(ca(b,-e|0)|0)+(-f|0)|0;p=l+(ca(b,d)|0)+(-f|0)|0;c=0;while(1){if((c|0)>=(e|0)){break}nrc(o|0,m|0,j)|0;o=o+b|0;c=c+1|0}c=0;while(1){if((c|0)>=(g|0)){break}nrc(p|0,n|0,j)|0;p=p+b|0;c=c+1|0}i=k;return}function P7b(a){a=a|0;var b=0,d=0;b=i;d=a;Q7b(d,c[d+76>>2]|0);i=b;return}function Q7b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a;a=b;b=c[e+28>>2]|0;f=c[e+32>>2]|0;g=a>>1;h=g;j=g;k=g+(c[e+24>>2]|0)-(c[e+32>>2]|0)|0;l=g+(c[e+20>>2]|0)-(c[e+28>>2]|0)|0;if(((c[e+4>>2]|0)-(c[e+12>>2]|0)|0)<16){}else{Cd(2314888,2554712,93,2652808)}if(((c[e>>2]|0)-(c[e+8>>2]|0)|0)<16){}else{Cd(2424016,2554712,94,2652808)}if(((c[e+4>>2]|0)-(c[e+12>>2]|0)|0)>=0){}else{Cd(2341096,2554712,95,2652808)}if(((c[e>>2]|0)-(c[e+8>>2]|0)|0)>=0){}else{Cd(2282248,2554712,96,2652808)}O7b(c[e+52>>2]|0,c[e+16>>2]|0,c[e+8>>2]|0,c[e+12>>2]|0,a,a,a+(c[e+4>>2]|0)-(c[e+12>>2]|0)|0,a+(c[e>>2]|0)-(c[e+8>>2]|0)|0);O7b(c[e+56>>2]|0,c[e+36>>2]|0,b,f,h,j,k,l);O7b(c[e+60>>2]|0,c[e+36>>2]|0,b,f,h,j,k,l);i=d;return}function R7b(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;if((c[d+76>>2]|0)>96){e=96}else{e=c[d+76>>2]|0}Q7b(d,e);i=b;return}function S7b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;b=c[e+52>>2]|0;f=c[a+52>>2]|0;g=0;while(1){if((g|0)>=(c[e+4>>2]|0)){break}nrc(f|0,b|0,c[e>>2]|0)|0;b=b+(c[e+16>>2]|0)|0;f=f+(c[a+16>>2]|0)|0;g=g+1|0}b=c[e+56>>2]|0;f=c[a+56>>2]|0;g=0;while(1){if((g|0)>=(c[e+24>>2]|0)){break}nrc(f|0,b|0,c[e+20>>2]|0)|0;b=b+(c[e+36>>2]|0)|0;f=f+(c[a+36>>2]|0)|0;g=g+1|0}b=c[e+60>>2]|0;f=c[a+60>>2]|0;g=0;while(1){if((g|0)>=(c[e+24>>2]|0)){break}nrc(f|0,b|0,c[e+20>>2]|0)|0;b=b+(c[e+36>>2]|0)|0;f=f+(c[a+36>>2]|0)|0;g=g+1|0}N7b(a);i=d;return}function T7b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;b=c[e+52>>2]|0;f=c[a+52>>2]|0;g=0;while(1){if((g|0)>=(c[e+4>>2]|0)){break}nrc(f|0,b|0,c[e>>2]|0)|0;b=b+(c[e+16>>2]|0)|0;f=f+(c[a+16>>2]|0)|0;g=g+1|0}i=d;return}function U7b(){V7b(2);return}function V7b(a){a=a|0;var b=0;b=i;if((c[1366890]|0)!=0){i=b;return}ff[a&15]();c[1366890]=1;i=b;return}function W7b(){return}function X7b(a){a=a|0;var b=0;b=i;nrc(a+6941|0,1578784,1056)|0;i=b;return}function Y7b(a,b,e,f,g,h,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;l=i;i=i+32|0;m=l|0;n=l+16|0;o=l+24|0;p=b;b=e;e=f;f=g;g=h;h=j;j=k;k=p+((-(c[a+3036>>2]|0)|0)*76|0)|0;a=p-76|0;p=k-76|0;q=m|0;r=g;c[q+8>>2]=0;c[q+4>>2]=0;c[q>>2]=0;c[g+12>>2]=0;c[g+8>>2]=0;c[g+4>>2]=0;c[g>>2]=0;if((d[k+2|0]|0|0)!=0){if((c[k+4>>2]|0)!=0){s=q+4|0;q=s;c[s>>2]=c[k+4>>2];Z7b(c[j+((d[k+2|0]|0)<<2)>>2]|0,h,q,j);r=r+4|0}s=r;c[s>>2]=(c[s>>2]|0)+2}if((d[a+2|0]|0|0)!=0){if((c[a+4>>2]|0)!=0){c[n>>2]=c[a+4>>2];Z7b(c[j+((d[a+2|0]|0)<<2)>>2]|0,h,n,j);if((c[n>>2]|0)!=(c[q>>2]|0)){s=q+4|0;q=s;c[s>>2]=c[n>>2];r=r+4|0}n=r;c[n>>2]=(c[n>>2]|0)+2}else{n=g|0;c[n>>2]=(c[n>>2]|0)+2}}if((d[p+2|0]|0|0)!=0){if((c[p+4>>2]|0)!=0){c[o>>2]=c[p+4>>2];Z7b(c[j+((d[p+2|0]|0)<<2)>>2]|0,h,o,j);if((c[o>>2]|0)!=(c[q>>2]|0)){j=q+4|0;q=j;c[j>>2]=c[o>>2];r=r+4|0}o=r;c[o>>2]=(c[o>>2]|0)+1}else{o=g|0;c[o>>2]=(c[o>>2]|0)+1}}if((c[g+12>>2]|0)!=0){if((c[q>>2]|0)==(c[m+4>>2]|0)){q=g+4|0;c[q>>2]=(c[q>>2]|0)+1}}c[g+12>>2]=(((d[k|0]|0|0)==9)+((d[a|0]|0|0)==9)<<1)+((d[p|0]|0|0)==9);if((c[g+8>>2]|0)>(c[g+4>>2]|0)){p=c[g+4>>2]|0;c[g+4>>2]=c[g+8>>2];c[g+8>>2]=p;p=c[m+4>>2]|0;c[m+4>>2]=c[m+8>>2];c[m+8>>2]=p}if((c[g+4>>2]|0)<(c[g>>2]|0)){t=m|0;u=t;v=c[u>>2]|0;w=f;x=w;c[x>>2]=v;y=m+4|0;z=y;A=c[z>>2]|0;B=b;C=B;c[C>>2]=A;D=m+8|0;E=D;F=c[E>>2]|0;G=e;H=G;c[H>>2]=F;i=l;return}c[m>>2]=c[m+4>>2];t=m|0;u=t;v=c[u>>2]|0;w=f;x=w;c[x>>2]=v;y=m+4|0;z=y;A=c[z>>2]|0;B=b;C=B;c[C>>2]=A;D=m+8|0;E=D;F=c[E>>2]|0;G=e;H=G;c[H>>2]=F;i=l;return}function Z7b(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=e;if((a|0)==(c[f+(d<<2)>>2]|0)){i=g;return}d=h|0;b[d>>1]=(b[d>>1]|0)*-1|0;d=h+2|0;b[d>>1]=(b[d>>1]|0)*-1|0;i=g;return}function _7b(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=a;a=d;d=e;e=g;g=h;h=c[g+(e<<2)>>2]|0;Y7b(k,b,a+(h*40|0)+20|0,a+(h*40|0)+24|0,d+(h<<2)|0,f,e,g);$7b(a+((((h|0)!=0^1)&1)*40|0)+20|0,a+(h*40|0)+20|0,k);$7b(a+((((h|0)!=0^1)&1)*40|0)+24|0,a+(h*40|0)+24|0,k);$7b(d+((((h|0)!=0^1)&1)<<2)|0,d+(h<<2)|0,k);i=j;return h|0}function $7b(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=c;c=d;b[f>>1]=(b[a>>1]|0)*-1|0;b[f+2>>1]=(b[a+2>>1]|0)*-1|0;b8b(f,c);b8b(a,c);i=e;return}function a8b(b,d){b=b|0;d=d|0;var e=0;e=b;b=d;a[e|0]=c[o+(c[b>>2]<<4)>>2];a[e+1|0]=c[o+(c[b+4>>2]<<4)+4>>2];a[e+2|0]=c[o+(c[b+8>>2]<<4)+8>>2];a[e+3|0]=c[o+(c[b+12>>2]<<4)+12>>2];i=i;return e|0}function b8b(a,d){a=a|0;d=d|0;var e=0,f=0;e=i;f=a;a=d;if((b[f+2>>1]|0)<((c[a+3128>>2]|0)-128|0)){b[f+2>>1]=(c[a+3128>>2]|0)-128}else{if((b[f+2>>1]|0)>((c[a+3132>>2]|0)+128|0)){b[f+2>>1]=(c[a+3132>>2]|0)+128}}if((b[f>>1]|0)<((c[a+3136>>2]|0)-128|0)){b[f>>1]=(c[a+3136>>2]|0)-128;i=e;return}if((b[f>>1]|0)>((c[a+3140>>2]|0)+128|0)){b[f>>1]=(c[a+3140>>2]|0)+128}i=e;return}function c8b(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+32|0;k=j|0;l=e;e=f;f=g;g=h;h=c;c=k|0;m=4;n=0;while(1){if((n|0)>=4){break}o=(b[h>>1]|0)+(b[h+16>>1]|0)|0;p=(b[h>>1]|0)-(b[h+16>>1]|0)|0;q=((b[h+8>>1]|0)*35468|0)>>16;r=(b[h+24>>1]|0)+(((b[h+24>>1]|0)*20091|0)>>16)|0;s=q-r|0;q=(b[h+8>>1]|0)+(((b[h+8>>1]|0)*20091|0)>>16)|0;r=((b[h+24>>1]|0)*35468|0)>>16;t=q+r|0;b[c+(0<<1)>>1]=o+t;b[c+((m*3|0)<<1)>>1]=o-t;b[c+(m<<1)>>1]=p+s;b[c+(m<<1<<1)>>1]=p-s;h=h+2|0;c=c+2|0;n=n+1|0}h=k|0;c=k|0;n=0;while(1){if((n|0)>=4){break}o=(b[h>>1]|0)+(b[h+4>>1]|0)|0;p=(b[h>>1]|0)-(b[h+4>>1]|0)|0;q=((b[h+2>>1]|0)*35468|0)>>16;r=(b[h+6>>1]|0)+(((b[h+6>>1]|0)*20091|0)>>16)|0;s=q-r|0;q=(b[h+2>>1]|0)+(((b[h+2>>1]|0)*20091|0)>>16)|0;r=((b[h+6>>1]|0)*35468|0)>>16;t=q+r|0;b[c>>1]=o+t+4>>3;b[c+6>>1]=o-t+4>>3;b[c+2>>1]=p+s+4>>3;b[c+4>>1]=p-s+4>>3;h=h+(m<<1)|0;c=c+(m<<1)|0;n=n+1|0}h=k|0;k=0;while(1){if((k|0)>=4){break}n=0;while(1){if((n|0)>=4){break}m=(b[h+(n<<1)>>1]|0)+(d[l+n|0]|0)|0;if((m|0)<0){m=0}if((m|0)>255){m=255}a[f+n|0]=m;n=n+1|0}h=h+8|0;f=f+g|0;l=l+e|0;k=k+1|0}i=j;return}function d8b(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;j=c;c=e;e=f;f=g;g=(b<<16>>16)+4>>3;b=0;while(1){if((b|0)>=4){break}k=0;while(1){if((k|0)>=4){break}l=g+(d[j+k|0]|0)|0;if((l|0)<0){l=0}if((l|0)>255){l=255}a[e+k|0]=l;k=k+1|0}e=e+f|0;j=j+c|0;b=b+1|0}i=h;return}function e8b(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+32|0;e=d|0;f=c;c=a;a=e|0;g=0;while(1){if((g|0)>=4){break}h=(b[c>>1]|0)+(b[c+24>>1]|0)|0;j=(b[c+8>>1]|0)+(b[c+16>>1]|0)|0;k=(b[c+8>>1]|0)-(b[c+16>>1]|0)|0;l=(b[c>>1]|0)-(b[c+24>>1]|0)|0;b[a>>1]=h+j;b[a+8>>1]=k+l;b[a+16>>1]=h-j;b[a+24>>1]=l-k;c=c+2|0;a=a+2|0;g=g+1|0}c=e|0;a=e|0;g=0;while(1){if((g|0)>=4){break}h=(b[c>>1]|0)+(b[c+6>>1]|0)|0;j=(b[c+2>>1]|0)+(b[c+4>>1]|0)|0;k=(b[c+2>>1]|0)-(b[c+4>>1]|0)|0;l=(b[c>>1]|0)-(b[c+6>>1]|0)|0;b[a>>1]=h+j+3>>3;b[a+2>>1]=k+l+3>>3;b[a+4>>1]=h-j+3>>3;b[a+6>>1]=l-k+3>>3;c=c+8|0;a=a+8|0;g=g+1|0}g=0;while(1){if((g|0)>=16){break}b[f+(g<<4<<1)>>1]=b[e+(g<<1)>>1]|0;g=g+1|0}i=d;return}function f8b(a,c){a=a|0;c=c|0;var d=0,e=0;d=i;e=c;c=(b[a>>1]|0)+3>>3;a=0;while(1){if((a|0)>=16){break}b[e+(a<<4<<1)>>1]=c;a=a+1|0}i=d;return}function g8b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>63){break}e=b;f=0;f=e>>((a|0)>0);f=f>>((a|0)>4);if((a|0)>0){if((f|0)>(9-a|0)){f=9-a|0}}if((f|0)<1){f=1}mrc(d+2048+(b<<4)|0,f&255|0,16)|0;mrc(d+1024+(b<<4)|0,(e<<1)+f&255|0,16)|0;mrc(d+(b<<4)|0,(e+2<<1)+f&255|0,16)|0;b=b+1|0}i=c;return}function h8b(a){a=a|0;var b=0,d=0;b=i;d=a;a=d+2400|0;g8b(a,c[d+5752>>2]|0);c[d+5748>>2]=c[d+5752>>2];i8b(a);d=0;while(1){if((d|0)>=4){break}mrc(a+3072+(d<<4)|0,d&255|0,16)|0;d=d+1|0}i=b;return}function i8b(b){b=b|0;var c=0,d=0;c=i;d=b;b=0;while(1){if((b|0)>63){break}if((b|0)>=40){a[d+3200+b|0]=2;a[d+3264+b|0]=3}else{if((b|0)>=20){a[d+3200+b|0]=1;a[d+3264+b|0]=2}else{if((b|0)>=15){a[d+3200+b|0]=1;a[d+3264+b|0]=1}else{a[d+3200+b|0]=0;a[d+3264+b|0]=0}}}b=b+1|0}a[d+3328|0]=1;a[d+3329|0]=1;a[d+3330|0]=1;a[d+3331|0]=1;a[d+3332|0]=0;a[d+3335|0]=1;a[d+3333|0]=2;a[d+3334|0]=2;a[d+3336|0]=2;a[d+3337|0]=3;i=c;return}function j8b(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=b;b=e;e=f;f=h+2400|0;if((c[h+5748>>2]|0)!=(c[h+5752>>2]|0)){g8b(f,c[h+5752>>2]|0);c[h+5748>>2]=c[h+5752>>2]}h=0;while(1){if((h|0)>=4){break}j=e;if((a[b+3092|0]|0)!=0){if((d[b+3095|0]|0)==1){j=a[b+3103+h|0]|0}else{j=j+(a[b+3103+h|0]|0)|0;if((j|0)>0){if((j|0)>63){k=63}else{k=j}l=k}else{l=0}j=l}}if((a[b+3107|0]|0)!=0){m=0;n=j+(a[b+3113+m|0]|0)|0;o=0;p=n+(a[b+3121+o|0]|0)|0;if((p|0)>0){if((p|0)>63){q=63}else{q=p}r=q}else{r=0}p=r;a[f+3136+(h<<4)+(m<<2)+o|0]=p;o=1;if((n|0)>0){if((n|0)>63){s=63}else{s=n}t=s}else{t=0}p=t;a[f+3136+(h<<4)+(m<<2)+o|0]=p;m=1;while(1){if((m|0)>=4){break}n=j+(a[b+3113+m|0]|0)|0;o=1;while(1){if((o|0)>=4){break}p=n+(a[b+3121+o|0]|0)|0;if((p|0)>0){if((p|0)>63){u=63}else{u=p}v=u}else{v=0}p=v;a[f+3136+(h<<4)+(m<<2)+o|0]=p;o=o+1|0}m=m+1|0}}else{mrc(f+3136+(h<<4)|0,j&255|0,16)|0}h=h+1|0}i=g;return}function k8b(a,b,e,f,g,h,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;l=i;i=i+16|0;m=l|0;n=a;a=b;b=e;e=f;f=g;g=h;h=j;j=k;k=n+2400|0;o=c[n+2312>>2]|0;p=0;while(1){if((p|0)>=(c[n+2332>>2]|0)){break}do{if((d[a|0]|0|0)!=4){if((d[a|0]|0|0)==9){q=0;break}q=(d[a+9|0]|0|0)!=0}else{q=0}}while(0);r=q&1;s=d[k+3136+((d[a+11|0]|0)<<4)+((d[a+2|0]|0)<<2)+(d[k+3328+(d[a|0]|0)|0]|0)|0]|0;if((s|0)!=0){t=d[k+3200+(o<<6)+s|0]|0;c[m>>2]=k+(s<<4);c[m+4>>2]=k+1024+(s<<4);c[m+8>>2]=k+2048+(s<<4);c[m+12>>2]=k+3072+(t<<4);if((p|0)>0){C8b(g,h,j,e,f,m)}if((r|0)==0){F8b(g,h,j,e,f,m)}if((b|0)>0){B8b(g,h,j,e,f,m)}if((r|0)==0){D8b(g,h,j,e,f,m)}}g=g+16|0;h=h+8|0;j=j+8|0;a=a+76|0;p=p+1|0}i=l;return}function l8b(a,b,e,f,g,h,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0;g=i;l=a;a=b;b=e;e=f;f=h;h=j;j=k;k=l+2400|0;m=0;while(1){if((m|0)>=(c[l+2332>>2]|0)){break}do{if((d[a|0]|0|0)!=4){if((d[a|0]|0|0)==9){n=0;break}n=(d[a+9|0]|0|0)!=0}else{n=0}}while(0);o=n&1;p=d[k+3136+((d[a+11|0]|0)<<4)+((d[a+2|0]|0)<<2)+(d[k+3328+(d[a|0]|0)|0]|0)|0]|0;if((p|0)!=0){if((m|0)>0){A8b(f,e,k+(p<<4)|0)}if((o|0)==0){G8b(f,e,k+1024+(p<<4)|0)}if((b|0)>0){x8b(f,e,k+(p<<4)|0)}if((o|0)==0){E8b(f,e,k+1024+(p<<4)|0)}}f=f+16|0;h=h+8|0;j=j+8|0;a=a+76|0;m=m+1|0}i=g;return}function m8b(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f|0;h=a;a=e;e=c[h+1812>>2]|0;j=h+2400|0;k=c[h+2328>>2]|0;l=c[h+2332>>2]|0;m=c[h+2384>>2]|0;n=c[e+16>>2]|0;o=c[e+36>>2]|0;j8b(h,b,c[h+5744>>2]|0);b=c[e+52>>2]|0;p=c[e+56>>2]|0;q=c[e+60>>2]|0;if((c[h+2392>>2]|0)==0){r=0;while(1){if((r|0)>=(k|0)){break}s=0;while(1){if((s|0)>=(l|0)){break}do{if((d[m|0]|0|0)!=4){if((d[m|0]|0|0)==9){t=0;break}t=(d[m+9|0]|0|0)!=0}else{t=0}}while(0);h=t&1;u=d[j+3136+((d[m+11|0]|0)<<4)+((d[m+2|0]|0)<<2)+(d[j+3328+(d[m|0]|0)|0]|0)|0]|0;if((u|0)!=0){v=d[j+3200+(a<<6)+u|0]|0;c[g>>2]=j+(u<<4);c[g+4>>2]=j+1024+(u<<4);c[g+8>>2]=j+2048+(u<<4);c[g+12>>2]=j+3072+(v<<4);if((s|0)>0){C8b(b,p,q,n,o,g)}if((h|0)==0){F8b(b,p,q,n,o,g)}if((r|0)>0){B8b(b,p,q,n,o,g)}if((h|0)==0){D8b(b,p,q,n,o,g)}}b=b+16|0;p=p+8|0;q=q+8|0;m=m+76|0;s=s+1|0}b=b+((n<<4)-(c[e>>2]|0))|0;p=p+((o<<3)-(c[e+20>>2]|0))|0;q=q+((o<<3)-(c[e+20>>2]|0))|0;m=m+76|0;r=r+1|0}i=f;return}else{r=0;while(1){if((r|0)>=(k|0)){break}s=0;while(1){if((s|0)>=(l|0)){break}do{if((d[m|0]|0|0)!=4){if((d[m|0]|0|0)==9){w=0;break}w=(d[m+9|0]|0|0)!=0}else{w=0}}while(0);g=w&1;u=d[j+3136+((d[m+11|0]|0)<<4)+((d[m+2|0]|0)<<2)+(d[j+3328+(d[m|0]|0)|0]|0)|0]|0;if((u|0)!=0){a=j+(u<<4)|0;t=j+1024+(u<<4)|0;if((s|0)>0){A8b(b,n,a)}if((g|0)==0){G8b(b,n,t)}if((r|0)>0){x8b(b,n,a)}if((g|0)==0){E8b(b,n,t)}}b=b+16|0;p=p+8|0;q=q+8|0;m=m+76|0;s=s+1|0}b=b+((n<<4)-(c[e>>2]|0))|0;p=p+((o<<3)-(c[e+20>>2]|0))|0;q=q+((o<<3)-(c[e+20>>2]|0))|0;m=m+76|0;r=r+1|0}i=f;return}}function n8b(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+16|0;g=f|0;h=a;a=c[h+1812>>2]|0;j=h+2400|0;k=c[h+2312>>2]|0;l=c[h+2384>>2]|0;j8b(h,b,e);e=c[a+52>>2]|0;b=0;while(1){if((b|0)>=(c[h+2328>>2]|0)){break}m=0;while(1){if((m|0)>=(c[h+2332>>2]|0)){break}do{if((d[l|0]|0|0)!=4){if((d[l|0]|0|0)==9){n=0;break}n=(d[l+9|0]|0|0)!=0}else{n=0}}while(0);o=n&1;p=d[j+3136+((d[l+11|0]|0)<<4)+((d[l+2|0]|0)<<2)+(d[j+3328+(d[l|0]|0)|0]|0)|0]|0;if((p|0)!=0){if((c[h+2392>>2]|0)==0){q=d[j+3200+(k<<6)+p|0]|0;c[g>>2]=j+(p<<4);c[g+4>>2]=j+1024+(p<<4);c[g+8>>2]=j+2048+(p<<4);c[g+12>>2]=j+3072+(q<<4);if((m|0)>0){C8b(e,0,0,c[a+16>>2]|0,0,g)}if((o|0)==0){F8b(e,0,0,c[a+16>>2]|0,0,g)}if((b|0)>0){B8b(e,0,0,c[a+16>>2]|0,0,g)}if((o|0)==0){D8b(e,0,0,c[a+16>>2]|0,0,g)}}else{if((m|0)>0){A8b(e,c[a+16>>2]|0,j+(p<<4)|0)}if((o|0)==0){G8b(e,c[a+16>>2]|0,j+1024+(p<<4)|0)}if((b|0)>0){x8b(e,c[a+16>>2]|0,j+(p<<4)|0)}if((o|0)==0){E8b(e,c[a+16>>2]|0,j+1024+(p<<4)|0)}}}e=e+16|0;l=l+76|0;m=m+1|0}e=e+((c[a+16>>2]<<4)-(c[a>>2]|0))|0;l=l+76|0;b=b+1|0}i=f;return}function o8b(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;h=a;a=c[h+1812>>2]|0;j=c[a>>2]>>4;k=c[a+4>>2]>>4;l=h+2400|0;m=c[h+2312>>2]|0;j8b(h,b,e);e=(k|0)/8|0;if((e|0)!=0){n=e<<4}else{n=16}e=n;n=(c[a+52>>2]|0)+(ca(c[a+4>>2]>>5<<4,c[a+16>>2]|0)|0)|0;k=(c[h+2384>>2]|0)+((ca(c[a+4>>2]>>5,j+1|0)|0)*76|0)|0;b=0;while(1){if((b|0)>=(e>>4|0)){break}o=0;while(1){if((o|0)>=(j|0)){break}do{if((d[k|0]|0|0)!=4){if((d[k|0]|0|0)==9){p=0;break}p=(d[k+9|0]|0|0)!=0}else{p=0}}while(0);q=p&1;r=d[l+3136+((d[k+11|0]|0)<<4)+((d[k+2|0]|0)<<2)+(d[l+3328+(d[k|0]|0)|0]|0)|0]|0;if((r|0)!=0){if((c[h+2392>>2]|0)==0){s=d[l+3200+(m<<6)+r|0]|0;c[g>>2]=l+(r<<4);c[g+4>>2]=l+1024+(r<<4);c[g+8>>2]=l+2048+(r<<4);c[g+12>>2]=l+3072+(s<<4);if((o|0)>0){C8b(n,0,0,c[a+16>>2]|0,0,g)}if((q|0)==0){F8b(n,0,0,c[a+16>>2]|0,0,g)}B8b(n,0,0,c[a+16>>2]|0,0,g);if((q|0)==0){D8b(n,0,0,c[a+16>>2]|0,0,g)}}else{if((o|0)>0){A8b(n,c[a+16>>2]|0,l+(r<<4)|0)}if((q|0)==0){G8b(n,c[a+16>>2]|0,l+1024+(r<<4)|0)}x8b(n,c[a+16>>2]|0,l+(r<<4)|0);if((q|0)==0){E8b(n,c[a+16>>2]|0,l+1024+(r<<4)|0)}}}n=n+16|0;k=k+76|0;o=o+1|0}n=n+((c[a+16>>2]<<4)-(c[a>>2]|0))|0;k=k+76|0;b=b+1|0}i=f;return}function p8b(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=b;b=c;c=d;d=e;e=f;f=g;g=0;k=0;l=0;do{k=q8b(a[d|0]|0,a[c|0]|0,a[j+(b*-4|0)|0]|0,a[j+(b*-3|0)|0]|0,a[j+(b*-2|0)|0]|0,a[j+(b*-1|0)|0]|0,a[j+0|0]|0,a[j+b|0]|0,a[j+(b<<1)|0]|0,a[j+(b*3|0)|0]|0)|0;g=(r8b(a[e|0]|0,a[j+(b*-2|0)|0]|0,a[j+(b*-1|0)|0]|0,a[j+0|0]|0,a[j+b|0]|0)|0)<<24>>24;s8b(k,g&255,j+(-(b<<1)|0)|0,j+(-b|0)|0,j,j+b|0);j=j+1|0;m=l+1|0;l=m;}while((m|0)<(f<<3|0));i=h;return}function q8b(a,b,c,d,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0;l=a;a=d;d=e;e=f;f=g;g=h;h=j;j=0;j=(j<<24>>24|(R((c&255)-(a&255)|0)|0)>(l&255|0))&255;j=(j<<24>>24|(R((a&255)-(d&255)|0)|0)>(l&255|0))&255;j=(j<<24>>24|(R((d&255)-(e&255)|0)|0)>(l&255|0))&255;j=(j<<24>>24|(R((g&255)-(f&255)|0)|0)>(l&255|0))&255;j=(j<<24>>24|(R((h&255)-(g&255)|0)|0)>(l&255|0))&255;j=(j<<24>>24|(R((k&255)-(h&255)|0)|0)>(l&255|0))&255;j=(j<<24>>24|(((R((e&255)-(f&255)|0)|0)<<1)+((R((d&255)-(g&255)|0)|0)/2|0)|0)>(b&255|0))&255;i=i;return(j<<24>>24)-1&255|0}function r8b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=a;a=0;a=(a<<24>>24|(((R((b&255)-(c&255)|0)|0)>(f&255|0)|0)*-1|0))&255;a=(a<<24>>24|(((R((e&255)-(d&255)|0)|0)>(f&255|0)|0)*-1|0))&255;i=i;return a|0}function s8b(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;j=c;c=d;d=e;e=f;f=g;g=(a[c]^128)&255;k=(a[d]^128)&255;l=(a[e]^128)&255;m=(a[f]^128)&255;n=H8b((g<<24>>24)-(m<<24>>24)|0)|0;n=n<<24>>24&(j&255)&255;n=H8b((n<<24>>24)+(((l<<24>>24)-(k<<24>>24)|0)*3|0)|0)|0;n=n<<24>>24&b<<24>>24&255;b=H8b((n<<24>>24)+4|0)|0;o=H8b((n<<24>>24)+3|0)|0;b=b<<24>>24>>3&255;o=o<<24>>24>>3&255;p=H8b((l<<24>>24)-(b<<24>>24)|0)|0;a[e]=p<<24>>24^128;p=H8b((k<<24>>24)+(o<<24>>24)|0)|0;a[d]=p<<24>>24^128;n=b;n=(n<<24>>24)+1&255;n=n<<24>>24>>1&255;n=n<<24>>24&~(j&255)&255;p=H8b((m<<24>>24)-(n<<24>>24)|0)|0;a[f]=p<<24>>24^128;p=H8b((g<<24>>24)+(n<<24>>24)|0)|0;a[c]=p<<24>>24^128;i=h;return}function t8b(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=b;b=c;c=d;d=e;e=f;f=g;g=0;k=0;l=0;do{k=q8b(a[d|0]|0,a[c|0]|0,a[j-4|0]|0,a[j-3|0]|0,a[j-2|0]|0,a[j-1|0]|0,a[j|0]|0,a[j+1|0]|0,a[j+2|0]|0,a[j+3|0]|0)|0;g=(r8b(a[e|0]|0,a[j-2|0]|0,a[j-1|0]|0,a[j|0]|0,a[j+1|0]|0)|0)<<24>>24;s8b(k,g&255,j-2|0,j-1|0,j,j+1|0);j=j+b|0;m=l+1|0;l=m;}while((m|0)<(f<<3|0));i=h;return}function u8b(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=b;b=c;c=d;d=e;e=f;f=g;g=0;k=0;l=0;do{k=q8b(a[d|0]|0,a[c|0]|0,a[j+(b*-4|0)|0]|0,a[j+(b*-3|0)|0]|0,a[j+(b*-2|0)|0]|0,a[j+(b*-1|0)|0]|0,a[j+0|0]|0,a[j+b|0]|0,a[j+(b<<1)|0]|0,a[j+(b*3|0)|0]|0)|0;g=r8b(a[e|0]|0,a[j+(b*-2|0)|0]|0,a[j+(b*-1|0)|0]|0,a[j+0|0]|0,a[j+b|0]|0)|0;v8b(k,g,j+(-(b*3|0)|0)|0,j+(-(b<<1)|0)|0,j+(-b|0)|0,j,j+b|0,j+(b<<1)|0);j=j+1|0;m=l+1|0;l=m;}while((m|0)<(f<<3|0));i=h;return}function v8b(b,c,d,e,f,g,h,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;l=c;c=d;d=e;e=f;f=g;g=h;h=j;j=(a[c]^128)&255;m=(a[d]^128)&255;n=(a[e]^128)&255;o=(a[f]^128)&255;p=(a[g]^128)&255;q=(a[h]^128)&255;r=H8b((m<<24>>24)-(p<<24>>24)|0)|0;r=H8b((r<<24>>24)+(((o<<24>>24)-(n<<24>>24)|0)*3|0)|0)|0;r=r<<24>>24&b<<24>>24&255;b=r;b=b<<24>>24&(l&255)&255;s=H8b((b<<24>>24)+4|0)|0;b=H8b((b<<24>>24)+3|0)|0;s=s<<24>>24>>3&255;b=b<<24>>24>>3&255;o=H8b((o<<24>>24)-(s<<24>>24)|0)|0;n=H8b((n<<24>>24)+(b<<24>>24)|0)|0;r=r<<24>>24&~(l&255)&255;b=r;r=H8b(((b<<24>>24)*27|0)+63>>7)|0;l=H8b((o<<24>>24)-(r<<24>>24)|0)|0;a[f]=l<<24>>24^128;l=H8b((n<<24>>24)+(r<<24>>24)|0)|0;a[e]=l<<24>>24^128;r=H8b(((b<<24>>24)*18|0)+63>>7)|0;l=H8b((p<<24>>24)-(r<<24>>24)|0)|0;a[g]=l<<24>>24^128;l=H8b((m<<24>>24)+(r<<24>>24)|0)|0;a[d]=l<<24>>24^128;r=H8b(((b<<24>>24)*9|0)+63>>7)|0;l=H8b((q<<24>>24)-(r<<24>>24)|0)|0;a[h]=l<<24>>24^128;l=H8b((j<<24>>24)+(r<<24>>24)|0)|0;a[c]=l<<24>>24^128;i=k;return}function w8b(b,c,d,e,f,g){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=b;b=c;c=d;d=e;e=f;f=g;g=0;k=0;l=0;do{k=q8b(a[d|0]|0,a[c|0]|0,a[j-4|0]|0,a[j-3|0]|0,a[j-2|0]|0,a[j-1|0]|0,a[j|0]|0,a[j+1|0]|0,a[j+2|0]|0,a[j+3|0]|0)|0;g=r8b(a[e|0]|0,a[j-2|0]|0,a[j-1|0]|0,a[j|0]|0,a[j+1|0]|0)|0;v8b(k,g,j-3|0,j-2|0,j-1|0,j,j+1|0,j+2|0);j=j+b|0;m=l+1|0;l=m;}while((m|0)<(f<<3|0));i=h;return}function x8b(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=b;b=c;c=d;d=0;g=0;do{d=y8b(a[c|0]|0,a[f+(b*-2|0)|0]|0,a[f+(b*-1|0)|0]|0,a[f+0|0]|0,a[f+b|0]|0)|0;z8b(d,f+(-(b<<1)|0)|0,f+(-b|0)|0,f,f+b|0);f=f+1|0;h=g+1|0;g=h;}while((h|0)<16);i=e;return}function y8b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=(((((R((c&255)-(d&255)|0)|0)<<1)+((R((b&255)-(e&255)|0)|0)/2|0)|0)<=(a&255|0)|0)*-1|0)&255;i=i;return f|0}function z8b(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=d;d=e;e=(a[h]^128)&255;j=(a[d]^128)&255;k=H8b((((a[c]^128)&255)<<24>>24)-(((a[f]^128)&255)<<24>>24)|0)|0;k=H8b((k<<24>>24)+(((j<<24>>24)-(e<<24>>24)|0)*3|0)|0)|0;k=k<<24>>24&b<<24>>24&255;b=H8b((k<<24>>24)+4|0)|0;b=b<<24>>24>>3&255;f=H8b((j<<24>>24)-(b<<24>>24)|0)|0;a[d]=f<<24>>24^128;d=H8b((k<<24>>24)+3|0)|0;d=d<<24>>24>>3&255;f=H8b((e<<24>>24)+(d<<24>>24)|0)|0;a[h]=f<<24>>24^128;i=g;return}function A8b(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=b;b=c;c=d;d=0;g=0;do{d=y8b(a[c|0]|0,a[f-2|0]|0,a[f-1|0]|0,a[f|0]|0,a[f+1|0]|0)|0;z8b(d,f-2|0,f-1|0,f,f+1|0);f=f+b|0;h=g+1|0;g=h;}while((h|0)<16);i=e;return}function B8b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;h=i;j=b;b=d;d=f;f=g;u8b(a,e,c[f>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,2);if((j|0)!=0){u8b(j,d,c[f>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,1)}if((b|0)==0){i=h;return}u8b(b,d,c[f>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,1);i=h;return}function C8b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;h=i;j=b;b=d;d=f;f=g;w8b(a,e,c[f>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,2);if((j|0)!=0){w8b(j,d,c[f>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,1)}if((b|0)==0){i=h;return}w8b(b,d,c[f>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,1);i=h;return}function D8b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;h=i;j=a;a=b;b=d;d=e;e=f;f=g;p8b(j+(d<<2)|0,d,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,2);p8b(j+(d<<3)|0,d,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,2);p8b(j+(d*12|0)|0,d,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,2);if((a|0)!=0){p8b(a+(e<<2)|0,e,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,1)}if((b|0)==0){i=h;return}p8b(b+(e<<2)|0,e,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,1);i=h;return}function E8b(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=a;a=b;b=c;x8b(e+(a<<2)|0,a,b);x8b(e+(a<<3)|0,a,b);x8b(e+(a*12|0)|0,a,b);i=d;return}function F8b(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;h=i;j=a;a=b;b=d;d=e;e=f;f=g;t8b(j+4|0,d,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,2);t8b(j+8|0,d,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,2);t8b(j+12|0,d,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,2);if((a|0)!=0){t8b(a+4|0,e,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,1)}if((b|0)==0){i=h;return}t8b(b+4|0,e,c[f+4>>2]|0,c[f+8>>2]|0,c[f+12>>2]|0,1);i=h;return}function G8b(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=a;a=b;b=c;A8b(e+4|0,a,b);A8b(e+8|0,a,b);A8b(e+12|0,a,b);i=d;return}function H8b(a){a=a|0;var b=0,c=0,d=0;b=a;if((b|0)<-128){c=-128}else{c=b}b=c;if((b|0)>127){d=127}else{d=b}b=d;i=i;return b&255|0}function I8b(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;e=e+b|0;if((e|0)>127){e=127}else{if((e|0)<0){e=0}}i=d;return c[1614888+(e<<2)>>2]|0}function J8b(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;e=e+b|0;if((e|0)>127){e=127}else{if((e|0)<0){e=0}}i=d;return c[1614888+(e<<2)>>2]<<1|0}function K8b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;e=e+b|0;if((e|0)>127){e=127}else{if((e|0)<0){e=0}}b=c[1614888+(e<<2)>>2]|0;if((b|0)<=132){f=b;i=d;return f|0}b=132;f=b;i=d;return f|0}function L8b(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)>127){d=127}else{if((d|0)<0){d=0}}i=b;return c[2086608+(d<<2)>>2]|0}function M8b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;e=e+b|0;if((e|0)>127){e=127}else{if((e|0)<0){e=0}}b=((c[2086608+(e<<2)>>2]|0)*101581|0)>>16;if((b|0)>=8){f=b;i=d;return f|0}b=8;f=b;i=d;return f|0}function N8b(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;e=e+b|0;if((e|0)>127){e=127}else{if((e|0)<0){e=0}}i=d;return c[2086608+(e<<2)>>2]|0}function O8b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=d;d=e;e=0;while(1){if((e|0)>=16){break}c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];c[b+8>>2]=c[g+8>>2];c[b+12>>2]=c[g+12>>2];g=g+a|0;b=b+d|0;e=e+1|0}i=f;return}function P8b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=d;d=e;e=0;while(1){if((e|0)>=8){break}c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];g=g+a|0;b=b+d|0;e=e+1|0}i=f;return}function Q8b(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=d;d=e;e=0;while(1){if((e|0)>=4){break}c[b>>2]=c[g>>2];c[b+4>>2]=c[g+4>>2];g=g+a|0;b=b+d|0;e=e+1|0}i=f;return}function R8b(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0;j=i;k=d;d=e;e=g;g=h;h=c[k+8>>2]|0;l=f+(c[k+16>>2]|0)+(ca(b[k+24>>1]>>3,e)|0)|0;f=l+(b[k+26>>1]>>3)|0;do{if((b[k+24>>1]&7|0)==0){if((b[k+26>>1]&7|0)!=0){break}l=0;while(1){if((l|0)>=4){break}a[h|0]=a[f|0]|0;a[h+1|0]=a[f+1|0]|0;a[h+2|0]=a[f+2|0]|0;a[h+3|0]=a[f+3|0]|0;h=h+d|0;f=f+e|0;l=l+1|0}i=j;return}}while(0);_e[g&511](f,e,b[k+26>>1]&7,b[k+24>>1]&7,h,d);i=j;return}function S8b(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a;a=e+256|0;f=e+320|0;g=b[(c[e+3032>>2]|0)+4>>1]|0;h=b[(c[e+3032>>2]|0)+6>>1]|0;j=c[e+2884>>2]|0;g=g+(1|g>>31)|0;h=h+(1|h>>31)|0;g=(g|0)/2|0;h=(h|0)/2|0;g=g&c[e+2844>>2];h=h&c[e+2844>>2];k=(ca(g>>3,j)|0)+(h>>3)|0;l=(c[e+2904>>2]|0)+k|0;m=(c[e+2908>>2]|0)+k|0;if(((g|h)&7|0)!=0){_e[c[e+3152>>2]&511](l,j,h&7,g&7,a,8);_e[c[e+3152>>2]&511](m,j,h&7,g&7,f,8);i=d;return}else{P8b(l,j,a,8);P8b(m,j,f,8);i=d;return}}function T8b(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=a;a=c[e+2884>>2]|0;f=0;while(1){if((f|0)>=2){break}g=0;while(1){if((g|0)>=2){break}h=(f<<3)+(g<<1)|0;j=(f<<1)+16+g|0;k=(b[e+2144+(h*28|0)+24>>1]|0)+(b[e+2144+((h+1|0)*28|0)+24>>1]|0)+(b[e+2144+((h+4|0)*28|0)+24>>1]|0)+(b[e+2144+((h+5|0)*28|0)+24>>1]|0)|0;k=k+((k>>31<<3)+4)|0;b[e+2144+(j*28|0)+24>>1]=((k|0)/8|0)&c[e+2844>>2];k=(b[e+2144+(h*28|0)+26>>1]|0)+(b[e+2144+((h+1|0)*28|0)+26>>1]|0)+(b[e+2144+((h+4|0)*28|0)+26>>1]|0)+(b[e+2144+((h+5|0)*28|0)+26>>1]|0)|0;k=k+((k>>31<<3)+4)|0;b[e+2144+(j*28|0)+26>>1]=((k|0)/8|0)&c[e+2844>>2];c[e+2144+(((f<<1)+20+g|0)*28|0)+24>>2]=c[e+2144+(j*28|0)+24>>2];g=g+1|0}f=f+1|0}g=c[e+2904>>2]|0;f=16;while(1){if((f|0)>=20){break}j=e+2144+(f*28|0)|0;k=e+2144+((f+1|0)*28|0)|0;if((c[j+24>>2]|0)==(c[k+24>>2]|0)){U8b(e,j,c[j+8>>2]|0,8,g,a)}else{R8b(j,8,g,a,c[e+3144>>2]|0);R8b(k,8,g,a,c[e+3144>>2]|0)}f=f+2|0}g=c[e+2908>>2]|0;f=20;while(1){if((f|0)>=24){break}k=e+2144+(f*28|0)|0;j=e+2144+((f+1|0)*28|0)|0;if((c[k+24>>2]|0)==(c[j+24>>2]|0)){U8b(e,k,c[k+8>>2]|0,8,g,a)}else{R8b(k,8,g,a,c[e+3144>>2]|0);R8b(j,8,g,a,c[e+3144>>2]|0)}f=f+2|0}i=d;return}function U8b(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=a;a=d;d=e;e=f;f=h;h=g+(c[a+16>>2]|0)+(ca(b[a+24>>1]>>3,f)|0)|0;g=h+(b[a+26>>1]>>3)|0;do{if((b[a+24>>1]&7|0)==0){if((b[a+26>>1]&7|0)!=0){break}Q8b(g,f,d,e);i=j;return}}while(0);_e[c[k+3148>>2]&511](g,f,b[a+26>>1]&7,b[a+24>>1]&7,d,e);i=j;return}function V8b(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=d;d=e;e=b[(c[g+3032>>2]|0)+4>>1]|0;h=b[(c[g+3032>>2]|0)+6>>1]|0;j=c[g+2864>>2]|0;k=(c[g+2900>>2]|0)+(ca(e>>3,j)|0)+(h>>3)|0;if(((e|h)&7|0)!=0){_e[c[g+3156>>2]&511](k,j,h&7,e&7,a,d);i=f;return}else{O8b(k,j,a,d);i=f;return}}function W8b(d,e,f,g,h,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0;k=i;i=i+8|0;l=k|0;m=d;d=e;e=f;f=g;g=h;h=j;j=c[m+2900>>2]|0;n=c[m+2864>>2]|0;c[l>>2]=c[(c[m+3032>>2]|0)+4>>2];if((a[(c[m+3032>>2]|0)+10|0]|0)!=0){X8b(l,m)}o=j+(ca(b[l>>1]>>3,n)|0)|0;j=o+(b[l+2>>1]>>3)|0;if((c[l>>2]&458759|0)!=0){_e[c[m+3156>>2]&511](j,n,b[l+2>>1]&7,b[l>>1]&7,d,g)}else{O8b(j,n,d,g)}g=l|0;b[g>>1]=(b[g>>1]|0)+(1|b[l>>1]>>31);g=l+2|0;b[g>>1]=(b[g>>1]|0)+(1|b[l+2>>1]>>31);g=l|0;b[g>>1]=(b[g>>1]|0)/2|0;g=l+2|0;b[g>>1]=(b[g>>1]|0)/2|0;g=l|0;b[g>>1]=b[g>>1]&c[m+2844>>2];g=l+2|0;b[g>>1]=b[g>>1]&c[m+2844>>2];n=n>>1;g=ca(b[l>>1]>>3,n)|0;d=g+(b[l+2>>1]>>3)|0;g=(c[m+2904>>2]|0)+d|0;j=(c[m+2908>>2]|0)+d|0;if((c[l>>2]&458759|0)!=0){_e[c[m+3152>>2]&511](g,n,b[l+2>>1]&7,b[l>>1]&7,e,h);_e[c[m+3152>>2]&511](j,n,b[l+2>>1]&7,b[l>>1]&7,f,h);i=k;return}else{P8b(g,n,e,h);P8b(j,n,f,h);i=k;return}}function X8b(a,d){a=a|0;d=d|0;var e=0,f=0;e=i;f=a;a=d;if((b[f+2>>1]|0)<((c[a+3128>>2]|0)-152|0)){b[f+2>>1]=(c[a+3128>>2]|0)-128}else{if((b[f+2>>1]|0)>((c[a+3132>>2]|0)+144|0)){b[f+2>>1]=(c[a+3132>>2]|0)+128}}if((b[f>>1]|0)<((c[a+3136>>2]|0)-152|0)){b[f>>1]=(c[a+3136>>2]|0)-128;i=e;return}if((b[f>>1]|0)>((c[a+3140>>2]|0)+144|0)){b[f>>1]=(c[a+3140>>2]|0)+128}i=e;return}function Y8b(a){a=a|0;var b=0,e=0;b=i;e=a;if((d[c[e+3032>>2]|0]|0|0)!=9){W8b(e,c[e+2992>>2]|0,c[e+2996>>2]|0,c[e+3e3>>2]|0,c[e+2956>>2]|0,c[e+2976>>2]|0);i=b;return}else{Z8b(e);_8b(e);i=b;return}}function Z8b(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d;d=0;while(1){if((d|0)>=2){break}g=0;while(1){if((g|0)>=2){break}h=(d<<3)+(g<<1)|0;j=(d<<1)+16+g|0;k=(b[(c[f+3032>>2]|0)+12+(h<<2)>>1]|0)+(b[(c[f+3032>>2]|0)+12+(h+1<<2)>>1]|0)+(b[(c[f+3032>>2]|0)+12+(h+4<<2)>>1]|0)+(b[(c[f+3032>>2]|0)+12+(h+5<<2)>>1]|0)|0;k=k+((k>>31<<3)+4)|0;b[f+2144+(j*28|0)+24>>1]=((k|0)/8|0)&c[f+2844>>2];k=(b[(c[f+3032>>2]|0)+12+(h<<2)+2>>1]|0)+(b[(c[f+3032>>2]|0)+12+(h+1<<2)+2>>1]|0)+(b[(c[f+3032>>2]|0)+12+(h+4<<2)+2>>1]|0)+(b[(c[f+3032>>2]|0)+12+(h+5<<2)+2>>1]|0)|0;k=k+((k>>31<<3)+4)|0;b[f+2144+(j*28|0)+26>>1]=((k|0)/8|0)&c[f+2844>>2];if((a[(c[f+3032>>2]|0)+10|0]|0)!=0){b9b(f+2144+(j*28|0)+24|0,f)}c[f+2144+(((d<<1)+20+g|0)*28|0)+24>>2]=c[f+2144+(j*28|0)+24>>2];g=g+1|0}d=d+1|0}i=e;return}function _8b(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b;b=c[f+2992>>2]|0;g=c[f+2900>>2]|0;if((d[(c[f+3032>>2]|0)+8|0]|0)<3){h=c[f+2956>>2]|0;c[f+2168>>2]=c[(c[f+3032>>2]|0)+12>>2];c[f+2224>>2]=c[(c[f+3032>>2]|0)+20>>2];c[f+2392>>2]=c[(c[f+3032>>2]|0)+44>>2];c[f+2448>>2]=c[(c[f+3032>>2]|0)+52>>2];if((a[(c[f+3032>>2]|0)+10|0]|0)!=0){X8b(f+2168|0,f);X8b(f+2224|0,f);X8b(f+2392|0,f);X8b(f+2448|0,f)}j=f+2144|0;$8b(f,j,b+(c[j+16>>2]|0)|0,h,g,h);j=f+2200|0;$8b(f,j,b+(c[j+16>>2]|0)|0,h,g,h);j=f+2368|0;$8b(f,j,b+(c[j+16>>2]|0)|0,h,g,h);j=f+2424|0;$8b(f,j,b+(c[j+16>>2]|0)|0,h,g,h)}else{k=0;while(1){if((k|0)>=16){break}h=f+2144+(k*28|0)|0;j=f+2144+((k+1|0)*28|0)|0;l=c[f+2956>>2]|0;c[f+2144+((k|0)*28|0)+24>>2]=c[(c[f+3032>>2]|0)+12+(k<<2)>>2];c[f+2144+((k+1|0)*28|0)+24>>2]=c[(c[f+3032>>2]|0)+12+(k+1<<2)>>2];if((a[(c[f+3032>>2]|0)+10|0]|0)!=0){X8b(f+2144+((k|0)*28|0)+24|0,f);X8b(f+2144+((k+1|0)*28|0)+24|0,f)}if((c[h+24>>2]|0)==(c[j+24>>2]|0)){U8b(f,h,b+(c[h+16>>2]|0)|0,l,g,l)}else{a9b(h,b+(c[h+16>>2]|0)|0,l,g,l,c[f+3144>>2]|0);a9b(j,b+(c[j+16>>2]|0)|0,l,g,l,c[f+3144>>2]|0)}k=k+2|0}}b=c[f+2996>>2]|0;g=c[f+2904>>2]|0;k=16;while(1){if((k|0)>=20){break}l=f+2144+(k*28|0)|0;j=f+2144+((k+1|0)*28|0)|0;h=c[f+2976>>2]|0;if((c[l+24>>2]|0)==(c[j+24>>2]|0)){U8b(f,l,b+(c[l+16>>2]|0)|0,h,g,h)}else{a9b(l,b+(c[l+16>>2]|0)|0,h,g,h,c[f+3144>>2]|0);a9b(j,b+(c[j+16>>2]|0)|0,h,g,h,c[f+3144>>2]|0)}k=k+2|0}b=c[f+3e3>>2]|0;g=c[f+2908>>2]|0;k=20;while(1){if((k|0)>=24){break}h=f+2144+(k*28|0)|0;j=f+2144+((k+1|0)*28|0)|0;l=c[f+2976>>2]|0;if((c[h+24>>2]|0)==(c[j+24>>2]|0)){U8b(f,h,b+(c[h+16>>2]|0)|0,l,g,l)}else{a9b(h,b+(c[h+16>>2]|0)|0,l,g,l,c[f+3144>>2]|0);a9b(j,b+(c[j+16>>2]|0)|0,l,g,l,c[f+3144>>2]|0)}k=k+2|0}i=e;return}function $8b(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=a;a=d;d=e;e=f;f=h;h=g+(c[a+16>>2]|0)+(ca(b[a+24>>1]>>3,f)|0)|0;g=h+(b[a+26>>1]>>3)|0;do{if((b[a+24>>1]&7|0)==0){if((b[a+26>>1]&7|0)!=0){break}P8b(g,f,d,e);i=j;return}}while(0);_e[c[k+3152>>2]&511](g,f,b[a+26>>1]&7,b[a+24>>1]&7,d,e);i=j;return}function a9b(d,e,f,g,h,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0;k=i;l=d;d=e;e=f;f=h;h=j;j=g+(c[l+16>>2]|0)+(ca(b[l+24>>1]>>3,f)|0)|0;g=j+(b[l+26>>1]>>3)|0;do{if((b[l+24>>1]&7|0)==0){if((b[l+26>>1]&7|0)!=0){break}j=0;while(1){if((j|0)>=4){break}a[d|0]=a[g|0]|0;a[d+1|0]=a[g+1|0]|0;a[d+2|0]=a[g+2|0]|0;a[d+3|0]=a[g+3|0]|0;d=d+e|0;g=g+f|0;j=j+1|0}i=k;return}}while(0);_e[h&511](g,f,b[l+26>>1]&7,b[l+24>>1]&7,d,e);i=k;return}function b9b(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=a;a=d;if((b[f+2>>1]<<1|0)<((c[a+3128>>2]|0)-152|0)){g=(c[a+3128>>2]|0)-128>>1}else{g=b[f+2>>1]|0}b[f+2>>1]=g;if((b[f+2>>1]<<1|0)>((c[a+3132>>2]|0)+144|0)){h=(c[a+3132>>2]|0)+128>>1}else{h=b[f+2>>1]|0}b[f+2>>1]=h;if((b[f>>1]<<1|0)<((c[a+3136>>2]|0)-152|0)){j=(c[a+3136>>2]|0)-128>>1}else{j=b[f>>1]|0}b[f>>1]=j;if((b[f>>1]<<1|0)>((c[a+3140>>2]|0)+144|0)){k=(c[a+3140>>2]|0)+128>>1;l=k&65535;m=f;n=m|0;b[n>>1]=l;i=e;return}else{k=b[f>>1]|0;l=k&65535;m=f;n=m|0;b[n>>1]=l;i=e;return}}function c9b(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;i=i+16|0;l=k|0;m=b;b=e;e=f;f=g;g=h;h=j;j=a[b-1|0]|0;n=0;while(1){if((n|0)>=16){break}a[l+n|0]=a[e+(ca(n,f)|0)|0]|0;n=n+1|0}switch(d[c[m+3032>>2]|0]|0|0){case 1:{o=0;while(1){if((o|0)>=16){break}c[g>>2]=c[b>>2];c[g+4>>2]=c[b+4>>2];c[g+8>>2]=c[b+8>>2];c[g+12>>2]=c[b+12>>2];g=g+h|0;o=o+1|0}i=k;return};case 4:case 5:case 6:case 7:case 8:case 9:case 10:{i=k;return};case 3:{o=0;while(1){if((o|0)>=16){break}f=0;while(1){if((f|0)>=16){break}e=(d[l+o|0]|0)+(d[b+f|0]|0)-(j&255)|0;if((e|0)<0){e=0}if((e|0)>255){e=255}a[g+f|0]=e;f=f+1|0}g=g+h|0;o=o+1|0}i=k;return};case 2:{o=0;while(1){if((o|0)>=16){break}mrc(g|0,a[l+o|0]&255|0,16)|0;g=g+h|0;o=o+1|0}i=k;return};case 0:{j=0;do{if((c[m+3044>>2]|0)!=0){p=8}else{if((c[m+3048>>2]|0)!=0){p=8;break}q=128}}while(0);if((p|0)==8){if((c[m+3044>>2]|0)!=0){n=0;while(1){if((n|0)>=16){break}j=j+(d[b+n|0]|0)|0;n=n+1|0}}if((c[m+3048>>2]|0)!=0){n=0;while(1){if((n|0)>=16){break}j=j+(d[l+n|0]|0)|0;n=n+1|0}}n=(c[m+3044>>2]|0)+3+(c[m+3048>>2]|0)|0;q=j+(1<<n-1)>>n}o=0;while(1){if((o|0)>=16){break}mrc(g|0,q&255|0,16)|0;g=g+h|0;o=o+1|0}i=k;return};default:{i=k;return}}}function d9b(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;n=i;i=i+16|0;o=n|0;p=n+8|0;q=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=a[b-1|0]|0;r=a[e-1|0]|0;s=0;while(1){if((s|0)>=8){break}a[o+s|0]=a[f+(ca(s,h)|0)|0]|0;a[p+s|0]=a[g+(ca(s,h)|0)|0]|0;s=s+1|0}switch(d[(c[q+3032>>2]|0)+1|0]|0|0){case 1:{s=0;while(1){if((s|0)>=8){break}nrc(j|0,b|0,8)|0;nrc(k|0,e|0,8)|0;j=j+l|0;k=k+l|0;s=s+1|0}i=n;return};case 0:{h=0;g=0;if((c[q+3044>>2]|0)!=0){s=0;while(1){if((s|0)>=8){break}h=h+(d[b+s|0]|0)|0;g=g+(d[e+s|0]|0)|0;s=s+1|0}}if((c[q+3048>>2]|0)!=0){s=0;while(1){if((s|0)>=8){break}h=h+(d[o+s|0]|0)|0;g=g+(d[p+s|0]|0)|0;s=s+1|0}}do{if((c[q+3044>>2]|0)!=0){t=21}else{if((c[q+3048>>2]|0)!=0){t=21;break}u=128;v=128}}while(0);if((t|0)==21){t=(c[q+3044>>2]|0)+2+(c[q+3048>>2]|0)|0;u=h+(1<<t-1)>>t;v=g+(1<<t-1)>>t}s=0;while(1){if((s|0)>=8){break}mrc(j|0,u&255|0,8)|0;mrc(k|0,v&255|0,8)|0;j=j+l|0;k=k+l|0;s=s+1|0}i=n;return};case 3:{s=0;while(1){if((s|0)>=8){break}v=0;while(1){if((v|0)>=8){break}u=(d[o+s|0]|0)+(d[b+v|0]|0)-(m&255)|0;t=(d[p+s|0]|0)+(d[e+v|0]|0)-(r&255)|0;if((u|0)<0){u=0}if((u|0)>255){u=255}if((t|0)<0){t=0}if((t|0)>255){t=255}a[j+v|0]=u;a[k+v|0]=t;v=v+1|0}j=j+l|0;k=k+l|0;s=s+1|0}i=n;return};case 2:{s=0;while(1){if((s|0)>=8){break}mrc(j|0,a[o+s|0]&255|0,8)|0;mrc(k|0,a[p+s|0]&255|0,8)|0;j=j+l|0;k=k+l|0;s=s+1|0}i=n;return};case 4:case 5:case 6:case 7:case 8:case 9:case 10:{i=n;return};default:{i=n;return}}}function e9b(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=i;i=i+88|0;m=l|0;n=l+8|0;o=l+24|0;p=l+40|0;q=l+56|0;r=l+72|0;s=b;b=e;e=f;f=h;h=j;j=k;a[m|0]=a[b|0]|0;a[m+1|0]=a[b+e|0]|0;a[m+2|0]=a[b+(e<<1)|0]|0;a[m+3|0]=a[b+(e*3|0)|0]|0;switch(g|0){case 4:{g=s;a[f+0|0]=(d[g|0]|0)+((d[g+1|0]|0)<<1)+(d[g+2|0]|0)+2>>2;e=(d[g+1|0]|0)+((d[g+2|0]|0)<<1)+(d[g+3|0]|0)+2>>2&255;a[f+h|0]=e;a[f+1|0]=e;e=(d[g+2|0]|0)+((d[g+3|0]|0)<<1)+(d[g+4|0]|0)+2>>2&255;a[f+(h<<1)|0]=e;a[f+(h+1)|0]=e;a[f+2|0]=e;e=(d[g+3|0]|0)+((d[g+4|0]|0)<<1)+(d[g+5|0]|0)+2>>2&255;a[f+(h*3|0)|0]=e;a[f+((h<<1)+1)|0]=e;a[f+(h+2)|0]=e;a[f+3|0]=e;e=(d[g+4|0]|0)+((d[g+5|0]|0)<<1)+(d[g+6|0]|0)+2>>2&255;a[f+((h*3|0)+1)|0]=e;a[f+((h<<1)+2)|0]=e;a[f+(h+3)|0]=e;e=(d[g+5|0]|0)+((d[g+6|0]|0)<<1)+(d[g+7|0]|0)+2>>2&255;a[f+((h*3|0)+2)|0]=e;a[f+((h<<1)+3)|0]=e;a[f+((h*3|0)+3)|0]=(d[g+6|0]|0)+((d[g+7|0]|0)<<1)+(d[g+7|0]|0)+2>>2;i=l;return};case 7:{g=s;a[f+0|0]=(d[g|0]|0)+(d[g+1|0]|0)+1>>1;a[f+h|0]=(d[g|0]|0)+((d[g+1|0]|0)<<1)+(d[g+2|0]|0)+2>>2;e=(d[g+1|0]|0)+(d[g+2|0]|0)+1>>1&255;a[f+1|0]=e;a[f+(h<<1)|0]=e;e=(d[g+1|0]|0)+((d[g+2|0]|0)<<1)+(d[g+3|0]|0)+2>>2&255;a[f+(h*3|0)|0]=e;a[f+(h+1)|0]=e;e=(d[g+2|0]|0)+(d[g+3|0]|0)+1>>1&255;a[f+2|0]=e;a[f+((h<<1)+1)|0]=e;e=(d[g+2|0]|0)+((d[g+3|0]|0)<<1)+(d[g+4|0]|0)+2>>2&255;a[f+(h+2)|0]=e;a[f+((h*3|0)+1)|0]=e;e=(d[g+3|0]|0)+(d[g+4|0]|0)+1>>1&255;a[f+((h<<1)+2)|0]=e;a[f+3|0]=e;e=(d[g+3|0]|0)+((d[g+4|0]|0)<<1)+(d[g+5|0]|0)+2>>2&255;a[f+((h*3|0)+2)|0]=e;a[f+(h+3)|0]=e;a[f+((h<<1)+3)|0]=(d[g+4|0]|0)+((d[g+5|0]|0)<<1)+(d[g+6|0]|0)+2>>2;a[f+((h*3|0)+3)|0]=(d[g+5|0]|0)+((d[g+6|0]|0)<<1)+(d[g+7|0]|0)+2>>2;i=l;return};case 8:{a[r|0]=a[m+3|0]|0;a[r+1|0]=a[m+2|0]|0;a[r+2|0]=a[m+1|0]|0;a[r+3|0]=a[m|0]|0;a[r+4|0]=j;a[r+5|0]=a[s|0]|0;a[r+6|0]=a[s+1|0]|0;a[r+7|0]=a[s+2|0]|0;a[r+8|0]=a[s+3|0]|0;a[f+(h*3|0)|0]=(d[r|0]|0)+(d[r+1|0]|0)+1>>1;a[f+((h*3|0)+1)|0]=(d[r|0]|0)+((d[r+1|0]|0)<<1)+(d[r+2|0]|0)+2>>2;g=(d[r+1|0]|0)+(d[r+2|0]|0)+1>>1&255;a[f+((h*3|0)+2)|0]=g;a[f+(h<<1)|0]=g;g=(d[r+1|0]|0)+((d[r+2|0]|0)<<1)+(d[r+3|0]|0)+2>>2&255;a[f+((h*3|0)+3)|0]=g;a[f+((h<<1)+1)|0]=g;g=(d[r+2|0]|0)+(d[r+3|0]|0)+1>>1&255;a[f+h|0]=g;a[f+((h<<1)+2)|0]=g;g=(d[r+2|0]|0)+((d[r+3|0]|0)<<1)+(d[r+4|0]|0)+2>>2&255;a[f+(h+1)|0]=g;a[f+((h<<1)+3)|0]=g;g=(d[r+3|0]|0)+(d[r+4|0]|0)+1>>1&255;a[f+0|0]=g;a[f+(h+2)|0]=g;g=(d[r+3|0]|0)+((d[r+4|0]|0)<<1)+(d[r+5|0]|0)+2>>2&255;a[f+1|0]=g;a[f+(h+3)|0]=g;a[f+2|0]=(d[r+4|0]|0)+((d[r+5|0]|0)<<1)+(d[r+6|0]|0)+2>>2;a[f+3|0]=(d[r+5|0]|0)+((d[r+6|0]|0)<<1)+(d[r+7|0]|0)+2>>2;i=l;return};case 3:{c[o>>2]=(j&255)+((d[m|0]|0)<<1)+(d[m+1|0]|0)+2>>2;c[o+4>>2]=(d[m|0]|0)+((d[m+1|0]|0)<<1)+(d[m+2|0]|0)+2>>2;c[o+8>>2]=(d[m+1|0]|0)+((d[m+2|0]|0)<<1)+(d[m+3|0]|0)+2>>2;c[o+12>>2]=(d[m+2|0]|0)+((d[m+3|0]|0)<<1)+(d[m+3|0]|0)+2>>2;t=0;while(1){if((t|0)>=4){break}u=0;while(1){if((u|0)>=4){break}a[f+u|0]=c[o+(t<<2)>>2];u=u+1|0}f=f+h|0;t=t+1|0}i=l;return};case 2:{c[n>>2]=(j&255)+((d[s|0]|0)<<1)+(d[s+1|0]|0)+2>>2;c[n+4>>2]=(d[s|0]|0)+((d[s+1|0]|0)<<1)+(d[s+2|0]|0)+2>>2;c[n+8>>2]=(d[s+1|0]|0)+((d[s+2|0]|0)<<1)+(d[s+3|0]|0)+2>>2;c[n+12>>2]=(d[s+2|0]|0)+((d[s+3|0]|0)<<1)+(d[s+4|0]|0)+2>>2;t=0;while(1){if((t|0)>=4){break}u=0;while(1){if((u|0)>=4){break}a[f+u|0]=c[n+(u<<2)>>2];u=u+1|0}f=f+h|0;t=t+1|0}i=l;return};case 5:{a[p|0]=a[m+3|0]|0;a[p+1|0]=a[m+2|0]|0;a[p+2|0]=a[m+1|0]|0;a[p+3|0]=a[m|0]|0;a[p+4|0]=j;a[p+5|0]=a[s|0]|0;a[p+6|0]=a[s+1|0]|0;a[p+7|0]=a[s+2|0]|0;a[p+8|0]=a[s+3|0]|0;a[f+(h*3|0)|0]=(d[p|0]|0)+((d[p+1|0]|0)<<1)+(d[p+2|0]|0)+2>>2;n=(d[p+1|0]|0)+((d[p+2|0]|0)<<1)+(d[p+3|0]|0)+2>>2&255;a[f+(h<<1)|0]=n;a[f+((h*3|0)+1)|0]=n;n=(d[p+2|0]|0)+((d[p+3|0]|0)<<1)+(d[p+4|0]|0)+2>>2&255;a[f+h|0]=n;a[f+((h<<1)+1)|0]=n;a[f+((h*3|0)+2)|0]=n;n=(d[p+3|0]|0)+((d[p+4|0]|0)<<1)+(d[p+5|0]|0)+2>>2&255;a[f+0|0]=n;a[f+(h+1)|0]=n;a[f+((h<<1)+2)|0]=n;a[f+((h*3|0)+3)|0]=n;n=(d[p+4|0]|0)+((d[p+5|0]|0)<<1)+(d[p+6|0]|0)+2>>2&255;a[f+1|0]=n;a[f+(h+2)|0]=n;a[f+((h<<1)+3)|0]=n;n=(d[p+5|0]|0)+((d[p+6|0]|0)<<1)+(d[p+7|0]|0)+2>>2&255;a[f+2|0]=n;a[f+(h+3)|0]=n;a[f+3|0]=(d[p+6|0]|0)+((d[p+7|0]|0)<<1)+(d[p+8|0]|0)+2>>2;i=l;return};case 6:{a[q|0]=a[m+3|0]|0;a[q+1|0]=a[m+2|0]|0;a[q+2|0]=a[m+1|0]|0;a[q+3|0]=a[m|0]|0;a[q+4|0]=j;a[q+5|0]=a[s|0]|0;a[q+6|0]=a[s+1|0]|0;a[q+7|0]=a[s+2|0]|0;a[q+8|0]=a[s+3|0]|0;a[f+(h*3|0)|0]=(d[q+1|0]|0)+((d[q+2|0]|0)<<1)+(d[q+3|0]|0)+2>>2;a[f+(h<<1)|0]=(d[q+2|0]|0)+((d[q+3|0]|0)<<1)+(d[q+4|0]|0)+2>>2;p=(d[q+3|0]|0)+((d[q+4|0]|0)<<1)+(d[q+5|0]|0)+2>>2&255;a[f+h|0]=p;a[f+((h*3|0)+1)|0]=p;p=(d[q+4|0]|0)+(d[q+5|0]|0)+1>>1&255;a[f+0|0]=p;a[f+((h<<1)+1)|0]=p;p=(d[q+4|0]|0)+((d[q+5|0]|0)<<1)+(d[q+6|0]|0)+2>>2&255;a[f+(h+1)|0]=p;a[f+((h*3|0)+2)|0]=p;p=(d[q+5|0]|0)+(d[q+6|0]|0)+1>>1&255;a[f+1|0]=p;a[f+((h<<1)+2)|0]=p;p=(d[q+5|0]|0)+((d[q+6|0]|0)<<1)+(d[q+7|0]|0)+2>>2&255;a[f+(h+2)|0]=p;a[f+((h*3|0)+3)|0]=p;p=(d[q+6|0]|0)+(d[q+7|0]|0)+1>>1&255;a[f+2|0]=p;a[f+((h<<1)+3)|0]=p;a[f+(h+3)|0]=(d[q+6|0]|0)+((d[q+7|0]|0)<<1)+(d[q+8|0]|0)+2>>2;a[f+3|0]=(d[q+7|0]|0)+(d[q+8|0]|0)+1>>1;i=l;return};case 1:{t=0;while(1){if((t|0)>=4){break}u=0;while(1){if((u|0)>=4){break}q=(d[s+u|0]|0)-(j&255)+(d[m+t|0]|0)|0;if((q|0)<0){q=0}if((q|0)>255){q=255}a[f+u|0]=q;u=u+1|0}f=f+h|0;t=t+1|0}i=l;return};case 0:{j=0;q=0;while(1){if((q|0)>=4){break}j=j+(d[s+q|0]|0)|0;j=j+(d[m+q|0]|0)|0;q=q+1|0}j=j+4>>3;t=0;while(1){if((t|0)>=4){break}u=0;while(1){if((u|0)>=4){break}a[f+u|0]=j;u=u+1|0}f=f+h|0;t=t+1|0}i=l;return};case 9:{t=m|0;a[f+0|0]=(d[t|0]|0)+(d[t+1|0]|0)+1>>1;a[f+1|0]=(d[t|0]|0)+((d[t+1|0]|0)<<1)+(d[t+2|0]|0)+2>>2;m=(d[t+1|0]|0)+(d[t+2|0]|0)+1>>1&255;a[f+h|0]=m;a[f+2|0]=m;m=(d[t+1|0]|0)+((d[t+2|0]|0)<<1)+(d[t+3|0]|0)+2>>2&255;a[f+(h+1)|0]=m;a[f+3|0]=m;m=(d[t+2|0]|0)+(d[t+3|0]|0)+1>>1&255;a[f+(h<<1)|0]=m;a[f+(h+2)|0]=m;m=(d[t+2|0]|0)+((d[t+3|0]|0)<<1)+(d[t+3|0]|0)+2>>2&255;a[f+((h<<1)+1)|0]=m;a[f+(h+3)|0]=m;m=a[t+3|0]|0;a[f+((h*3|0)+3)|0]=m;a[f+((h*3|0)+2)|0]=m;a[f+((h*3|0)+1)|0]=m;a[f+(h*3|0)|0]=m;a[f+((h<<1)+3)|0]=m;a[f+((h<<1)+2)|0]=m;i=l;return};default:{i=l;return}}}function f9b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=g9b(a,b,c,d,e,16,16)|0;i=f;return g|0}function g9b(a,b,c,e,f,g,h){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;k=a;a=b;b=c;c=e;e=f;f=g;g=h;h=0;l=0;while(1){if((l|0)>=(g|0)){m=11;break}n=0;while(1){if((n|0)>=(f|0)){break}h=h+(R((d[k+n|0]|0)-(d[b+n|0]|0)|0)|0)|0;n=n+1|0}if(h>>>0>e>>>0){break}k=k+a|0;b=b+c|0;l=l+1|0}if((m|0)==11){o=h;i=j;return o|0}o=h;i=j;return o|0}function h9b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=g9b(a,b,c,d,e,8,8)|0;i=f;return g|0}function i9b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=g9b(a,b,c,d,e,16,8)|0;i=f;return g|0}function j9b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=g9b(a,b,c,d,e,8,16)|0;i=f;return g|0}function k9b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=g9b(a,b,c,d,e,4,4)|0;i=f;return g|0}function l9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=f9b(h,a,b|0,d,-1)|0;c[e+4>>2]=f9b(h,a,b+1|0,d,-1)|0;c[e+8>>2]=f9b(h,a,b+2|0,d,-1)|0;i=g;return}function m9b(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=c;c=d;d=e;e=f;b[e>>1]=f9b(h,a,c|0,d,-1)|0;b[e+2>>1]=f9b(h,a,c+1|0,d,-1)|0;b[e+4>>1]=f9b(h,a,c+2|0,d,-1)|0;b[e+6>>1]=f9b(h,a,c+3|0,d,-1)|0;b[e+8>>1]=f9b(h,a,c+4|0,d,-1)|0;b[e+10>>1]=f9b(h,a,c+5|0,d,-1)|0;b[e+12>>1]=f9b(h,a,c+6|0,d,-1)|0;b[e+14>>1]=f9b(h,a,c+7|0,d,-1)|0;i=g;return}function n9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=i9b(h,a,b|0,d,-1)|0;c[e+4>>2]=i9b(h,a,b+1|0,d,-1)|0;c[e+8>>2]=i9b(h,a,b+2|0,d,-1)|0;i=g;return}function o9b(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=c;c=d;d=e;e=f;b[e>>1]=i9b(h,a,c|0,d,-1)|0;b[e+2>>1]=i9b(h,a,c+1|0,d,-1)|0;b[e+4>>1]=i9b(h,a,c+2|0,d,-1)|0;b[e+6>>1]=i9b(h,a,c+3|0,d,-1)|0;b[e+8>>1]=i9b(h,a,c+4|0,d,-1)|0;b[e+10>>1]=i9b(h,a,c+5|0,d,-1)|0;b[e+12>>1]=i9b(h,a,c+6|0,d,-1)|0;b[e+14>>1]=i9b(h,a,c+7|0,d,-1)|0;i=g;return}function p9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=h9b(h,a,b|0,d,-1)|0;c[e+4>>2]=h9b(h,a,b+1|0,d,-1)|0;c[e+8>>2]=h9b(h,a,b+2|0,d,-1)|0;i=g;return}function q9b(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=c;c=d;d=e;e=f;b[e>>1]=h9b(h,a,c|0,d,-1)|0;b[e+2>>1]=h9b(h,a,c+1|0,d,-1)|0;b[e+4>>1]=h9b(h,a,c+2|0,d,-1)|0;b[e+6>>1]=h9b(h,a,c+3|0,d,-1)|0;b[e+8>>1]=h9b(h,a,c+4|0,d,-1)|0;b[e+10>>1]=h9b(h,a,c+5|0,d,-1)|0;b[e+12>>1]=h9b(h,a,c+6|0,d,-1)|0;b[e+14>>1]=h9b(h,a,c+7|0,d,-1)|0;i=g;return}function r9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=j9b(h,a,b|0,d,-1)|0;c[e+4>>2]=j9b(h,a,b+1|0,d,-1)|0;c[e+8>>2]=j9b(h,a,b+2|0,d,-1)|0;i=g;return}function s9b(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=c;c=d;d=e;e=f;b[e>>1]=j9b(h,a,c|0,d,-1)|0;b[e+2>>1]=j9b(h,a,c+1|0,d,-1)|0;b[e+4>>1]=j9b(h,a,c+2|0,d,-1)|0;b[e+6>>1]=j9b(h,a,c+3|0,d,-1)|0;b[e+8>>1]=j9b(h,a,c+4|0,d,-1)|0;b[e+10>>1]=j9b(h,a,c+5|0,d,-1)|0;b[e+12>>1]=j9b(h,a,c+6|0,d,-1)|0;b[e+14>>1]=j9b(h,a,c+7|0,d,-1)|0;i=g;return}function t9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=k9b(h,a,b|0,d,-1)|0;c[e+4>>2]=k9b(h,a,b+1|0,d,-1)|0;c[e+8>>2]=k9b(h,a,b+2|0,d,-1)|0;i=g;return}function u9b(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=c;c=d;d=e;e=f;b[e>>1]=k9b(h,a,c|0,d,-1)|0;b[e+2>>1]=k9b(h,a,c+1|0,d,-1)|0;b[e+4>>1]=k9b(h,a,c+2|0,d,-1)|0;b[e+6>>1]=k9b(h,a,c+3|0,d,-1)|0;b[e+8>>1]=k9b(h,a,c+4|0,d,-1)|0;b[e+10>>1]=k9b(h,a,c+5|0,d,-1)|0;b[e+12>>1]=k9b(h,a,c+6|0,d,-1)|0;b[e+14>>1]=k9b(h,a,c+7|0,d,-1)|0;i=g;return}function v9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=f9b(h,a,c[b>>2]|0,d,-1)|0;c[e+4>>2]=f9b(h,a,c[b+4>>2]|0,d,-1)|0;c[e+8>>2]=f9b(h,a,c[b+8>>2]|0,d,-1)|0;c[e+12>>2]=f9b(h,a,c[b+12>>2]|0,d,-1)|0;i=g;return}function w9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=i9b(h,a,c[b>>2]|0,d,-1)|0;c[e+4>>2]=i9b(h,a,c[b+4>>2]|0,d,-1)|0;c[e+8>>2]=i9b(h,a,c[b+8>>2]|0,d,-1)|0;c[e+12>>2]=i9b(h,a,c[b+12>>2]|0,d,-1)|0;i=g;return}function x9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=h9b(h,a,c[b>>2]|0,d,-1)|0;c[e+4>>2]=h9b(h,a,c[b+4>>2]|0,d,-1)|0;c[e+8>>2]=h9b(h,a,c[b+8>>2]|0,d,-1)|0;c[e+12>>2]=h9b(h,a,c[b+12>>2]|0,d,-1)|0;i=g;return}function y9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=j9b(h,a,c[b>>2]|0,d,-1)|0;c[e+4>>2]=j9b(h,a,c[b+4>>2]|0,d,-1)|0;c[e+8>>2]=j9b(h,a,c[b+8>>2]|0,d,-1)|0;c[e+12>>2]=j9b(h,a,c[b+12>>2]|0,d,-1)|0;i=g;return}function z9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=b;b=d;d=e;e=f;c[e>>2]=k9b(h,a,c[b>>2]|0,d,-1)|0;c[e+4>>2]=k9b(h,a,c[b+4>>2]|0,d,-1)|0;c[e+8>>2]=k9b(h,a,c[b+8>>2]|0,d,-1)|0;c[e+12>>2]=k9b(h,a,c[b+12>>2]|0,d,-1)|0;i=g;return}function A9b(a){a=a|0;var c=0,d=0,e=0;c=i;d=a;a=0;e=0;do{e=e+(ca(b[d+(a<<1)>>1]|0,b[d+(a<<1)>>1]|0)|0)|0;a=a+1|0;}while(a>>>0<256>>>0);i=c;return e|0}function B9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;C9b(a,b,d,e,16,16,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>8)|0;i=g;return f|0}function C9b(a,b,e,f,g,h,j,k){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0;l=i;m=a;a=b;b=e;e=f;f=g;g=h;h=j;j=k;c[j>>2]=0;c[h>>2]=0;k=0;while(1){if((k|0)>=(g|0)){break}n=0;while(1){if((n|0)>=(f|0)){break}o=(d[m+n|0]|0)-(d[b+n|0]|0)|0;p=j;c[p>>2]=(c[p>>2]|0)+o;p=ca(o,o)|0;o=h;c[o>>2]=(c[o>>2]|0)+p;n=n+1|0}m=m+a|0;b=b+e|0;k=k+1|0}i=l;return}function D9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;C9b(a,b,d,e,8,16,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>7)|0;i=g;return f|0}function E9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;C9b(a,b,d,e,16,8,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>7)|0;i=g;return f|0}function F9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;C9b(a,b,d,e,8,8,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>6)|0;i=g;return f|0}function G9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=g+8|0;C9b(a,b,d,e,4,4,h,j);c[f>>2]=c[h>>2];f=(c[h>>2]|0)-((ca(c[j>>2]|0,c[j>>2]|0)|0)>>>4)|0;i=g;return f|0}function H9b(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;i=i+16|0;h=g|0;C9b(a,b,d,e,16,16,h,g+8|0);c[f>>2]=c[h>>2];i=g;return c[h>>2]|0}function I9b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+360|0;j=h|0;k=h+320|0;J9b(a,k|0,b,1,5,4,247912+(c<<2)|0);K9b(k|0,j|0,4,4,4,4,247912+(d<<2)|0);d=G9b(j|0,4,e,f,g)|0;i=h;return d|0}function J9b(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0;k=i;l=a;a=c;c=e;e=f;f=g;g=h;h=j;j=0;while(1){if(!(j>>>0<f>>>0)){break}m=0;while(1){if(!(m>>>0<g>>>0)){break}n=ca(d[l|0]|0,b[h>>1]|0)|0;b[a+(m<<1)>>1]=n+(ca(d[l+e|0]|0,b[h+2>>1]|0)|0)+64>>7;l=l+1|0;m=m+1|0}l=l+(c-g)|0;a=a+(g<<1)|0;j=j+1|0}i=k;return}function K9b(c,d,f,g,h,j,k){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;l=i;m=c;c=d;d=f;f=g;g=h;h=j;j=k;k=0;while(1){if(!(k>>>0<g>>>0)){break}n=0;while(1){if(!(n>>>0<h>>>0)){break}o=ca(e[m>>1]|0,b[j>>1]|0)|0;a[c+n|0]=o+(ca(e[m+(f<<1)>>1]|0,b[j+2>>1]|0)|0)+64>>7;m=m+2|0;n=n+1|0}m=m+(d-h<<1)|0;c=c+h|0;k=k+1|0}i=l;return}function L9b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+464|0;j=h|0;k=h+144|0;J9b(a,j|0,b,1,9,8,247912+(c<<2)|0);K9b(j|0,k|0,8,8,8,8,247912+(d<<2)|0);d=F9b(k|0,8,e,f,g)|0;i=h;return d|0}function M9b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+864|0;j=h|0;k=h+544|0;J9b(a,j|0,b,1,17,16,247912+(c<<2)|0);K9b(j|0,k|0,16,16,16,16,247912+(d<<2)|0);d=B9b(k|0,16,e,f,g)|0;i=h;return d|0}function N9b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=M9b(a,b,4,0,c,d,e)|0;i=f;return g|0}function O9b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=M9b(a,b,0,4,c,d,e)|0;i=f;return g|0}function P9b(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=M9b(a,b,4,4,c,d,e)|0;i=f;return g|0}function Q9b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+608|0;j=h|0;k=h+288|0;J9b(a,j|0,b,1,9,16,247912+(c<<2)|0);K9b(j|0,k|0,16,16,8,16,247912+(d<<2)|0);d=E9b(k|0,16,e,f,g)|0;i=h;return d|0}function R9b(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+608|0;j=h|0;k=h+288|0;J9b(a,j|0,b,1,17,8,247912+(c<<2)|0);K9b(j|0,k|0,8,8,16,8,247912+(d<<2)|0);d=D9b(k|0,8,e,f,g)|0;i=h;return d|0}function S9b(a){a=a|0;var d=0,e=0;d=i;e=a+3184|0;a=0;while(1){if((a|0)>=128){break}b[e+256+(a<<2)>>1]=I8b(a,c[e+2360>>2]|0)|0;b[e+768+(a<<2)>>1]=J8b(a,c[e+2364>>2]|0)|0;b[e+1280+(a<<2)>>1]=K8b(a,c[e+2372>>2]|0)|0;b[e+256+(a<<2)+2>>1]=L8b(a)|0;b[e+768+(a<<2)+2>>1]=M8b(a,c[e+2368>>2]|0)|0;b[e+1280+(a<<2)+2>>1]=N8b(a,c[e+2376>>2]|0)|0;a=a+1|0}i=d;return}function T9b(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=f;f=c[h+3032>>2]|0;j=e+3184|0;if((a[h+3092|0]|0)!=0){if((d[h+3095|0]|0)==1){k=a[h+3099+(d[f+11|0]|0)|0]|0}else{k=(c[j+2356>>2]|0)+(a[h+3099+(d[f+11|0]|0)|0]|0)|0;if((k|0)>=0){if((k|0)<=127){l=k}else{l=127}m=l}else{m=0}k=m}}else{k=c[j+2356>>2]|0}b[h+2048>>1]=1;b[h+2016>>1]=b[j+256+(k<<2)>>1]|0;b[h+2080>>1]=b[j+768+(k<<2)>>1]|0;b[h+2112>>1]=b[j+1280+(k<<2)>>1]|0;m=1;while(1){if((m|0)>=16){break}l=b[j+256+(k<<2)+2>>1]|0;b[h+2016+(m<<1)>>1]=l;b[h+2048+(m<<1)>>1]=l;b[h+2080+(m<<1)>>1]=b[j+768+(k<<2)+2>>1]|0;b[h+2112+(m<<1)>>1]=b[j+1280+(k<<2)+2>>1]|0;m=m+1|0}i=g;return}function U9b(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+24|0;f=e|0;g=e+16|0;h=b;b=h+11472|0;j=h+3184|0;k=h|0;l=c[h+11532>>2]|0;m=l+(c[h+11568>>2]|0)|0;n=243304;o=0;p=c[h+11636>>2]|0;q=c[h+3168>>2]|0;c[k+3164>>2]=0;c[q+84>>2]=0;if((m-l|0)<3){if((c[h+11628>>2]|0)==0){V9b(j|0,7,2306344,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}c[j+2312>>2]=1;c[j+8040>>2]=0;c[j+2316>>2]=1;s=0}else{t=l;if((c[h+11644>>2]|0)!=0){u=m-l|0;if((u|0)>10){u=10}mf[c[h+11644>>2]&2047](c[h+11648>>2]|0,l,f|0,u);t=f|0}c[j+2312>>2]=a[t|0]&1;c[j+8040>>2]=d[t|0]>>1&7;c[j+2316>>2]=d[t|0]>>4&1;s=(d[t|0]|d[t+1|0]<<8|d[t+2|0]<<16)>>5;do{if((c[h+11628>>2]|0)==0){if(!((l+s|0)>>>0>m>>>0)){if(!((l+s|0)>>>0<l>>>0)){break}}V9b(j|0,7,2552776,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}}while(0);l=l+3|0;t=t+3|0;IYb(j);if((c[j+2312>>2]|0)==0){if((c[h+11628>>2]|0)!=0){if((l+3|0)>>>0<m>>>0){v=16}}else{v=16}if((v|0)==16){do{if((d[t|0]|0)!=157){v=19}else{if((d[t+1|0]|0)!=1){v=19;break}if((d[t+2|0]|0)!=42){v=19}}}while(0);if((v|0)==19){V9b(j|0,5,2422496,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}}if((c[h+11628>>2]|0)!=0){if((l+6|0)>>>0<m>>>0){v=23}}else{v=23}if((v|0)==23){c[j+1792>>2]=(d[t+3|0]|d[t+4|0]<<8)&16383;c[j+1800>>2]=d[t+4|0]>>6;c[j+1796>>2]=(d[t+5|0]|d[t+6|0]<<8)&16383;c[j+1804>>2]=d[t+6|0]>>6}l=l+7|0;t=t+7|0}else{nrc(k+2848|0,q|0,92)|0;nrc(k+2940|0,q|0,92)|0}}do{if((c[h+11632>>2]|0)==0){if((c[j+2312>>2]|0)==0){break}w=-1;x=w;i=e;return x|0}}while(0);W9b(h);if((xpc(b,l,m-l|0,c[h+11644>>2]|0,c[h+11648>>2]|0)|0)!=0){V9b(j|0,2,2340400,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}if((c[j+2312>>2]|0)==0){X9b(b,128)|0;c[j+1808>>2]=X9b(b,128)|0}a[k+3092|0]=X9b(b,128)|0;if((a[k+3092|0]|0)!=0){a[k+3093|0]=X9b(b,128)|0;a[k+3094|0]=X9b(b,128)|0;if((a[k+3094|0]|0)!=0){a[k+3095|0]=X9b(b,128)|0;mrc(k+3099|0,0,8)|0;y=0;while(1){if((y|0)>=2){break}z=0;while(1){if((z|0)>=4){break}if((X9b(b,128)|0)!=0){a[k+3099+(y<<2)+z|0]=Y9b(b,c[n+(y<<2)>>2]|0)|0;if((X9b(b,128)|0)!=0){a[k+3099+(y<<2)+z|0]=-(a[k+3099+(y<<2)+z|0]|0)}}else{a[k+3099+(y<<2)+z|0]=0}z=z+1|0}y=y+1|0}}if((a[k+3093|0]|0)!=0){mrc(k+3096|0,-1|0,3)|0;y=0;while(1){if((y|0)>=3){break}if((X9b(b,128)|0)!=0){a[k+3096+y|0]=Y9b(b,8)|0}y=y+1|0}}}else{a[k+3093|0]=0;a[k+3094|0]=0}c[j+2392>>2]=X9b(b,128)|0;c[j+5744>>2]=Y9b(b,6)|0;c[j+5752>>2]=Y9b(b,3)|0;a[k+3108|0]=0;a[k+3107|0]=X9b(b,128)|0;if((a[k+3107|0]|0)!=0){a[k+3108|0]=X9b(b,128)|0;if((a[k+3108|0]|0)!=0){y=0;while(1){if((y|0)>=4){break}if((X9b(b,128)|0)!=0){a[k+3113+y|0]=Y9b(b,6)|0;if((X9b(b,128)|0)!=0){a[k+3113+y|0]=(a[k+3113+y|0]|0)*-1|0}}y=y+1|0}y=0;while(1){if((y|0)>=4){break}if((X9b(b,128)|0)!=0){a[k+3121+y|0]=Y9b(b,6)|0;if((X9b(b,128)|0)!=0){a[k+3121+y|0]=(a[k+3121+y|0]|0)*-1|0}}y=y+1|0}}}Z9b(h,l+s|0);c[k+3160>>2]=h+11248;c[j+2356>>2]=Y9b(b,7)|0;c[g>>2]=0;c[j+2360>>2]=_9b(b,c[j+2360>>2]|0,g)|0;c[j+2364>>2]=_9b(b,c[j+2364>>2]|0,g)|0;c[j+2368>>2]=_9b(b,c[j+2368>>2]|0,g)|0;c[j+2372>>2]=_9b(b,c[j+2372>>2]|0,g)|0;c[j+2376>>2]=_9b(b,c[j+2376>>2]|0,g)|0;if((c[g>>2]|0)!=0){S9b(h)}T9b(h,h|0);if((c[j+2312>>2]|0)!=0){c[j+5760>>2]=X9b(b,128)|0;c[j+5764>>2]=X9b(b,128)|0;c[j+5768>>2]=0;if((c[j+5760>>2]|0)==0){c[j+5768>>2]=Y9b(b,2)|0}c[j+5772>>2]=0;if((c[j+5764>>2]|0)==0){c[j+5772>>2]=Y9b(b,2)|0}c[j+5788>>2]=X9b(b,128)|0;c[j+5792>>2]=X9b(b,128)|0}c[j+5776>>2]=X9b(b,128)|0;if((c[j+5776>>2]|0)==0){nrc(j+5809|0,j+6922|0,1113)|0}if((c[j+2312>>2]|0)==0){A=1}else{A=(X9b(b,128)|0)!=0}c[j+5756>>2]=A&1;c[h+11636>>2]=1;y=0;while(1){if((y|0)>=4){break}z=0;while(1){if((z|0)>=8){break}A=0;while(1){if((A|0)>=3){break}g=0;while(1){if((g|0)>=11){break}s=j+6941+(y*264|0)+(z*33|0)+(A*11|0)+g|0;if((X9b(b,d[245512+(y*264|0)+(z*33|0)+(A*11|0)+g|0]|0)|0)!=0){a[s]=Y9b(b,8)|0}do{if((A|0)>0){if((d[s]|0)==(d[j+6941+(y*264|0)+(z*33|0)+((A-1|0)*11|0)+g|0]|0)){break}c[h+11636>>2]=0}}while(0);g=g+1|0}A=A+1|0}z=z+1|0}y=y+1|0}mrc(k+384|0,0,800)|0;kac(h);mrc(c[j+5796>>2]|0,0,(c[j+2332>>2]|0)*9|0|0)|0;c[h+11640>>2]=0;$9b(h);o=o|c[k+3164>>2];c[q+84>>2]=aac(b)|0;b=q+84|0;c[b>>2]=c[b>>2]|o;if((c[h+11632>>2]|0)==0){do{if((c[j+2312>>2]|0)==0){if((c[q+84>>2]|0)!=0){v=117;break}c[h+11632>>2]=1}else{v=117}}while(0);if((v|0)==117){V9b(h+3184|0,7,2281856,(r=i,i=i+1|0,i=i+7&-8,c[r>>2]=0,r)|0);i=r}}if((c[j+5776>>2]|0)==0){nrc(j+6922|0,j+5809|0,1113)|0;c[h+11636>>2]=p}w=0;x=w;i=e;return x|0}function V9b(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function W9b(b){b=b|0;var d=0,e=0,f=0;d=i;e=b;b=e+3184|0;f=e|0;if((c[b+2312>>2]|0)==0){nrc(b+7997|0,245112,38)|0;MYb(b);X7b(b);mrc(f+3099|0,0,8)|0;a[f+3095|0]=0;mrc(f+3113|0,0,4)|0;mrc(f+3121|0,0,4)|0;c[b+5760>>2]=1;c[b+5764>>2]=1;c[b+5768>>2]=0;c[b+5772>>2]=0;c[b+5788>>2]=0;c[b+5792>>2]=0}else{if((c[b+2348>>2]|0)!=0){c[f+3144>>2]=304;c[f+3148>>2]=274;c[f+3152>>2]=276;c[f+3156>>2]=264}else{c[f+3144>>2]=180;c[f+3148>>2]=212;c[f+3152>>2]=280;c[f+3156>>2]=242}do{if((c[e+11632>>2]|0)!=0){if((c[e+11624>>2]|0)==0){break}if((c[e+11628>>2]|0)!=0){break}c[e+11628>>2]=1}}while(0)}c[f+3088>>2]=b+5800;c[f+3032>>2]=c[b+2384>>2];c[f+3040>>2]=c[b+2312>>2];a[c[f+3032>>2]|0]=0;c[f+3036>>2]=c[b+2336>>2];c[f+3164>>2]=0;c[f+2844>>2]=-1;if((c[b+2352>>2]|0)==0){i=d;return}c[f+2844>>2]=-8;i=d;return}function X9b(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=0;g=((ca((c[f+16>>2]|0)-1|0,b)|0)>>>8)+1|0;if((c[f+12>>2]|0)<0){ypc(f)}b=c[f+8>>2]|0;h=c[f+12>>2]|0;j=g<<24;k=g;if(b>>>0>=j>>>0){k=(c[f+16>>2]|0)-g|0;b=b-j|0;a=1}j=d[242168+k|0]|0;k=k<<j;b=b<<j;h=h-j|0;c[f+8>>2]=b;c[f+12>>2]=h;c[f+16>>2]=k;i=e;return a|0}function Y9b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=0;e=b-1|0;while(1){if((e|0)<0){break}a=a|(X9b(d,128)|0)<<e;e=e-1|0}i=c;return a|0}function Z9b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a;a=b;b=e+11248|0;f=(c[e+11532>>2]|0)+(c[e+11568>>2]|0)|0;g=Y9b(e+11472|0,2)|0;if((aac(e+11472|0)|0)==0){c[e+11228>>2]=g}g=1<<c[e+11228>>2];h=0;while(1){if(!(h>>>0<(c[e+11528>>2]|0)>>>0)){break}j=c[e+11568+(h<<2)>>2]|0;k=(c[e+11532+(h<<2)>>2]|0)+j|0;if((h|0)==0){l=a-(c[e+11532>>2]|0)+((g-1|0)*3|0)|0;j=j-l|0;if(j>>>0>0>>>0){c[e+11568>>2]=l;h=h+1|0;c[e+11532+(h<<2)>>2]=(c[e+11532>>2]|0)+(c[e+11568>>2]|0)}}while(1){if(!(j>>>0>0>>>0)){break}l=hac(e,a,c[e+11532+(h<<2)>>2]|0,f,k,h-1|0,g)|0;c[e+11568+(h<<2)>>2]=l;j=j-l|0;if(h>>>0<=g>>>0){}else{Cd(2232448,2193392,867,2651224)}if(j>>>0>0>>>0){h=h+1|0;c[e+11532+(h<<2)>>2]=(c[e+11532+(h-1<<2)>>2]|0)+l}}h=h+1|0}c[e+11528>>2]=g+1;g=1;while(1){if(!(g>>>0<(c[e+11528>>2]|0)>>>0)){break}if((xpc(b,c[e+11532+(g<<2)>>2]|0,c[e+11568+(g<<2)>>2]|0,c[e+11644>>2]|0,c[e+11648>>2]|0)|0)!=0){V9b(e+3184|0,2,2162384,(h=i,i=i+8|0,c[h>>2]=g,h)|0);i=h}b=b+28|0;g=g+1|0}i=d;return}function _9b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=b;b=d;d=0;if((X9b(f,128)|0)!=0){d=Y9b(f,4)|0;if((X9b(f,128)|0)!=0){d=-d|0}}if((d|0)==(a|0)){g=d;i=e;return g|0}c[b>>2]=1;g=d;i=e;return g|0}function $9b(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;i=i+112|0;e=b|0;f=b+48|0;g=b+64|0;h=b+80|0;j=b+96|0;k=a;a=k+3184|0;l=k|0;m=c[l+3032>>2]|0;n=0;o=1<<c[a+8044>>2];p=0;q=c[k+3168>>2]|0;r=c[q+16>>2]|0;s=c[q+36>>2]|0;c[j>>2]=0;t=1;while(1){if((t|0)>=4){break}u=c[k+3168+(t<<2)>>2]|0;c[e+(t*12|0)>>2]=c[u+52>>2];c[e+(t*12|0)+4>>2]=c[u+56>>2];c[e+(t*12|0)+8>>2]=c[u+60>>2];c[j+(t<<2)>>2]=c[u+84>>2];t=t+1|0}t=c[q+52>>2]|0;c[f>>2]=t;c[g>>2]=t;c[h>>2]=t;t=c[q+56>>2]|0;c[f+4>>2]=t;c[g+4>>2]=t;c[h+4>>2]=t;t=c[q+60>>2]|0;c[f+8>>2]=t;c[g+8>>2]=t;c[h+8>>2]=t;c[l+3044>>2]=0;if((c[a+5744>>2]|0)!=0){j8b(a,l,c[a+5744>>2]|0)}tpc(q);t=0;while(1){if((t|0)>=(c[a+2328>>2]|0)){break}if((o|0)>1){c[l+3160>>2]=k+11248+(n*28|0);n=n+1|0;if((n|0)==(o|0)){n=0}}u=(ca(t,r)|0)<<4;v=(ca(t,s)|0)<<3;c[l+3084>>2]=c[a+5796>>2];mrc(c[l+3088>>2]|0,0,9)|0;c[l+3048>>2]=0;c[l+3136>>2]=-(t<<4<<3);c[l+3140>>2]=(c[a+2328>>2]|0)-1-t<<4<<3;c[l+3052>>2]=(c[f>>2]|0)+u;c[l+3056>>2]=(c[f+4>>2]|0)+v;c[l+3060>>2]=(c[f+8>>2]|0)+v;c[l+3064>>2]=(c[l+3052>>2]|0)-1;c[l+3068>>2]=(c[l+3056>>2]|0)-1;c[l+3072>>2]=(c[l+3060>>2]|0)-1;w=l+3052|0;c[w>>2]=(c[w>>2]|0)+(-(c[l+2956>>2]|0)|0);w=l+3056|0;c[w>>2]=(c[w>>2]|0)+(-(c[l+2976>>2]|0)|0);w=l+3060|0;c[w>>2]=(c[w>>2]|0)+(-(c[l+2976>>2]|0)|0);c[l+3076>>2]=c[l+2956>>2];c[l+3080>>2]=c[l+2976>>2];bac(c[l+3064>>2]|0,c[l+3068>>2]|0,c[l+3072>>2]|0,c[l+2956>>2]|0,c[l+2976>>2]|0);w=0;while(1){if((w|0)>=(c[a+2332>>2]|0)){break}c[l+3128>>2]=-(w<<4<<3);c[l+3132>>2]=(c[a+2332>>2]|0)-1-w<<4<<3;c[l+2992>>2]=(c[f>>2]|0)+u;c[l+2996>>2]=(c[f+4>>2]|0)+v;c[l+3e3>>2]=(c[f+8>>2]|0)+v;c[l+2900>>2]=(c[e+((d[(c[l+3032>>2]|0)+2|0]|0)*12|0)>>2]|0)+u;c[l+2904>>2]=(c[e+((d[(c[l+3032>>2]|0)+2|0]|0)*12|0)+4>>2]|0)+v;c[l+2908>>2]=(c[e+((d[(c[l+3032>>2]|0)+2|0]|0)*12|0)+8>>2]|0)+v;x=l+3164|0;c[x>>2]=c[x>>2]|c[j+((d[(c[l+3032>>2]|0)+2|0]|0)<<2)>>2];cac(k,l,p);p=p+1|0;c[l+3048>>2]=1;x=aac(c[l+3160>>2]|0)|0;y=l+3164|0;c[y>>2]=c[y>>2]|x;x=l+3052|0;c[x>>2]=(c[x>>2]|0)+16;x=l+3056|0;c[x>>2]=(c[x>>2]|0)+8;x=l+3060|0;c[x>>2]=(c[x>>2]|0)+8;x=l+3064|0;c[x>>2]=(c[x>>2]|0)+16;x=l+3068|0;c[x>>2]=(c[x>>2]|0)+8;x=l+3072|0;c[x>>2]=(c[x>>2]|0)+8;u=u+16|0;v=v+8|0;x=l+3032|0;c[x>>2]=(c[x>>2]|0)+76;x=l+3084|0;c[x>>2]=(c[x>>2]|0)+9;w=w+1|0}bpc(q,(c[l+2992>>2]|0)+16|0,(c[l+2996>>2]|0)+8|0,(c[l+3e3>>2]|0)+8|0);w=l+3032|0;c[w>>2]=(c[w>>2]|0)+76;c[l+3044>>2]=1;if((c[a+5744>>2]|0)!=0){if((t|0)>0){if((c[a+2392>>2]|0)==0){k8b(a,m,t-1|0,r,s,c[g>>2]|0,c[g+4>>2]|0,c[g+8>>2]|0)}else{l8b(a,m,t-1|0,r,s,c[g>>2]|0,c[g+4>>2]|0,c[g+8>>2]|0)}if((t|0)>1){dac(q,c[h>>2]|0,c[h+4>>2]|0,c[h+8>>2]|0);w=h|0;c[w>>2]=(c[w>>2]|0)+(r<<4);w=h+4|0;c[w>>2]=(c[w>>2]|0)+(s<<3);w=h+8|0;c[w>>2]=(c[w>>2]|0)+(s<<3)}w=g|0;c[w>>2]=(c[w>>2]|0)+(r<<4);w=g+4|0;c[w>>2]=(c[w>>2]|0)+(s<<3);w=g+8|0;c[w>>2]=(c[w>>2]|0)+(s<<3);m=m+((c[a+2332>>2]|0)*76|0)|0;m=m+76|0}}else{if((t|0)>0){dac(q,c[h>>2]|0,c[h+4>>2]|0,c[h+8>>2]|0);w=h|0;c[w>>2]=(c[w>>2]|0)+(r<<4);w=h+4|0;c[w>>2]=(c[w>>2]|0)+(s<<3);w=h+8|0;c[w>>2]=(c[w>>2]|0)+(s<<3)}}t=t+1|0}if((c[a+5744>>2]|0)==0){z=q;A=h|0;B=c[A>>2]|0;C=h+4|0;D=c[C>>2]|0;E=h+8|0;F=c[E>>2]|0;dac(z,B,D,F);G=q;eac(G);H=q;fac(H);i=b;return}if((c[a+2392>>2]|0)==0){k8b(a,m,t-1|0,r,s,c[g>>2]|0,c[g+4>>2]|0,c[g+8>>2]|0)}else{l8b(a,m,t-1|0,r,s,c[g>>2]|0,c[g+4>>2]|0,c[g+8>>2]|0)}dac(q,c[h>>2]|0,c[h+4>>2]|0,c[h+8>>2]|0);g=h|0;c[g>>2]=(c[g>>2]|0)+(r<<4);r=h+4|0;c[r>>2]=(c[r>>2]|0)+(s<<3);r=h+8|0;c[r>>2]=(c[r>>2]|0)+(s<<3);z=q;A=h|0;B=c[A>>2]|0;C=h+4|0;D=c[C>>2]|0;E=h+8|0;F=c[E>>2]|0;dac(z,B,D,F);G=q;eac(G);H=q;fac(H);i=b;return}function aac(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;do{if((c[d+12>>2]|0)>32){if((c[d+12>>2]|0)>=1073741824){break}e=1;f=e;i=b;return f|0}}while(0);e=0;f=e;i=b;return f|0}function bac(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=b;b=c;c=d;d=e;e=f;f=0;while(1){if((f|0)>=16){break}a[h+(ca(d,f)|0)|0]=-127;f=f+1|0}f=0;while(1){if((f|0)>=8){break}a[b+(ca(e,f)|0)|0]=-127;f=f+1|0}f=0;while(1){if((f|0)>=8){break}a[c+(ca(e,f)|0)|0]=-127;f=f+1|0}i=g;return}function cac(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=e;e=f;if((a[(c[e+3032>>2]|0)+9|0]|0)!=0){Hac(e)}else{if((aac(c[e+3160>>2]|0)|0)==0){f=(Iac(h,e)|0)==0&255;a[(c[e+3032>>2]|0)+9|0]=f}}f=d[c[e+3032>>2]|0]|0;if((a[e+3092|0]|0)!=0){T9b(h,e)}if((d[(c[e+3032>>2]|0)+2|0]|0)==0){d9b(e,c[e+3056>>2]|0,c[e+3060>>2]|0,c[e+3068>>2]|0,c[e+3072>>2]|0,c[e+3080>>2]|0,c[e+2996>>2]|0,c[e+3e3>>2]|0,c[e+2976>>2]|0);if((f|0)!=4){c9b(e,c[e+3052>>2]|0,c[e+3064>>2]|0,c[e+3076>>2]|0,c[e+2992>>2]|0,c[e+2956>>2]|0)}else{h=e+2016|0;j=c[e+2956>>2]|0;if((a[(c[e+3032>>2]|0)+9|0]|0)!=0){mrc(e+1984|0,0,25)|0}gac(e,(c[e+3052>>2]|0)+16|0);k=0;while(1){if((k|0)>=16){break}l=e+2144+(k*28|0)|0;m=(c[e+2992>>2]|0)+(c[l+16>>2]|0)|0;n=m+(-j|0)|0;e9b(n,m-1|0,j,c[(c[e+3032>>2]|0)+12+(k<<2)>>2]|0,m,j,a[n-1|0]|0);if((a[e+1984+k|0]|0)!=0){if((a[e+1984+k|0]|0)>1){Zoc(c[l>>2]|0,h,m,j)}else{d8b((ca(b[c[l>>2]>>1]|0,b[h>>1]|0)|0)&65535,m,j,m,j);mrc(c[l>>2]|0,0,4)|0}}k=k+1|0}}}else{Y8b(e)}if((a[(c[e+3032>>2]|0)+9|0]|0)!=0){i=g;return}if((f|0)!=4){k=e+2016|0;if((f|0)!=9){f=e+2816|0;if((a[e+2008|0]|0)>1){Yoc(f,e+2080|0);e8b(c[f+4>>2]|0,e+384|0);mrc(c[f>>2]|0,0,32)|0}else{j=(ca(b[c[f>>2]>>1]|0,b[e+2080>>1]|0)|0)&65535;b[c[f+4>>2]>>1]=j;f8b(c[f+4>>2]|0,e+384|0);mrc(c[f>>2]|0,0,4)|0}k=e+2048|0}qpc(e+384|0,k,c[e+2992>>2]|0,c[e+2956>>2]|0,e+1984|0)}rpc(e+896|0,e+2112|0,c[e+2996>>2]|0,c[e+3e3>>2]|0,c[e+2976>>2]|0,e+2e3|0);i=g;return}function dac(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=b;b=e;e=f;f=c[h+76>>2]|0;j=c[h+16>>2]|0;k=16;l=c[h>>2]|0;m=d;d=m+l-1|0;n=m+(-f|0)|0;o=d+1|0;p=0;while(1){if((p|0)>=(k|0)){break}mrc(n|0,a[m|0]&255|0,f|0)|0;mrc(o|0,a[d|0]&255|0,f|0)|0;m=m+j|0;d=d+j|0;n=n+j|0;o=o+j|0;p=p+1|0}j=c[h+36>>2]|0;k=8;l=c[h+20>>2]|0;f=(f>>>0)/2|0;m=b;d=m+l-1|0;n=m+(-f|0)|0;o=d+1|0;p=0;while(1){if((p|0)>=(k|0)){break}mrc(n|0,a[m|0]&255|0,f|0)|0;mrc(o|0,a[d|0]&255|0,f|0)|0;m=m+j|0;d=d+j|0;n=n+j|0;o=o+j|0;p=p+1|0}m=e;d=m+l-1|0;n=m+(-f|0)|0;o=d+1|0;p=0;while(1){if((p|0)>=(k|0)){break}mrc(n|0,a[m|0]&255|0,f|0)|0;mrc(o|0,a[d|0]&255|0,f|0)|0;m=m+j|0;d=d+j|0;n=n+j|0;o=o+j|0;p=p+1|0}i=g;return}function eac(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a;a=c[d+76>>2]|0;e=c[d+16>>2]|0;f=(c[d+52>>2]|0)+(-a|0)|0;g=f+(-(ca(a,e)|0)|0)|0;h=0;while(1){if((h|0)>=(a|0)){break}nrc(g|0,f|0,e)|0;g=g+e|0;h=h+1|0}e=c[d+36>>2]|0;a=(a>>>0)/2|0;f=(c[d+56>>2]|0)+(-a|0)|0;g=f+(-(ca(a,e)|0)|0)|0;h=0;while(1){if((h|0)>=(a|0)){break}nrc(g|0,f|0,e)|0;g=g+e|0;h=h+1|0}f=(c[d+60>>2]|0)+(-a|0)|0;g=f+(-(ca(a,e)|0)|0)|0;h=0;while(1){if((h|0)>=(a|0)){break}nrc(g|0,f|0,e)|0;g=g+e|0;h=h+1|0}i=b;return}function fac(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a;a=c[d+76>>2]|0;e=c[d+16>>2]|0;f=c[d+4>>2]|0;g=(c[d+52>>2]|0)+(-a|0)|0;h=g+(ca(f,e)|0)+(-e|0)|0;j=h+e|0;k=0;while(1){if((k|0)>=(a|0)){break}nrc(j|0,h|0,e)|0;j=j+e|0;k=k+1|0}e=c[d+36>>2]|0;f=c[d+24>>2]|0;a=(a>>>0)/2|0;g=(c[d+56>>2]|0)+(-a|0)|0;h=g+(ca(f,e)|0)+(-e|0)|0;j=h+e|0;k=0;while(1){if((k|0)>=(a|0)){break}nrc(j|0,h|0,e)|0;j=j+e|0;k=k+1|0}g=(c[d+60>>2]|0)+(-a|0)|0;h=g+(ca(f,e)|0)+(-e|0)|0;j=h+e|0;k=0;while(1){if((k|0)>=(a|0)){break}nrc(j|0,h|0,e)|0;j=j+e|0;k=k+1|0}i=b;return}function gac(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;a=c[d+2956>>2]|0;e=(c[d+2992>>2]|0)+(-a|0)+16|0;d=b;c[e+(a<<2)>>2]=c[d>>2];c[e+(a<<3)>>2]=c[d>>2];c[e+(a*12|0)>>2]=c[d>>2];i=i;return}function hac(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;k=a;a=d;d=f;f=g;g=k+3184|0;l=b+(f*3|0)|0;b=0;m=d-a|0;if((f|0)<(h-1|0)){if((iac(l,3,e)|0)!=0){b=jac(k,l)|0}else{if((c[k+11628>>2]|0)!=0){b=m}else{V9b(g|0,7,2136768,(n=i,i=i+1|0,i=i+7&-8,c[n>>2]=0,n)|0);i=n}}}else{b=m}if((iac(a,b,d)|0)!=0){o=b;i=j;return o|0}if((c[k+11628>>2]|0)!=0){b=m}else{V9b(g|0,7,2113288,(n=i,i=i+8|0,c[n>>2]=f+1,n)|0);i=n}o=b;i=j;return o|0}function iac(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=a;a=b;if((d+a|0)>>>0>d>>>0){e=(d+a|0)>>>0<=c>>>0}else{e=0}i=i;return e&1|0}function jac(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;g=a;a=b;if((c[g+11644>>2]|0)!=0){mf[c[g+11644>>2]&2047](c[g+11648>>2]|0,a,f|0,3);a=f|0}i=e;return(d[a|0]|0)+((d[a+1|0]|0)<<8)+((d[a+2|0]|0)<<16)|0}function kac(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=a;a=c[d+5568>>2]|0;e=-1;lac(d);c[d+3136>>2]=0;c[d+3140>>2]=(c[d+5512>>2]|0)-1<<4<<3;f=(c[d+5516>>2]|0)-1<<4<<3;while(1){g=e+1|0;e=g;if((g|0)>=(c[d+5512>>2]|0)){break}g=-1;c[d+3128>>2]=0;c[d+3132>>2]=f;while(1){h=g+1|0;g=h;if((h|0)>=(c[d+5516>>2]|0)){break}mac(d,a,a|0);h=d+3128|0;c[h>>2]=(c[h>>2]|0)-128;h=d+3132|0;c[h>>2]=(c[h>>2]|0)-128;a=a+76|0}g=d+3136|0;c[g>>2]=(c[g>>2]|0)-128;g=d+3140|0;c[g>>2]=(c[g>>2]|0)-128;a=a+76|0}i=b;return}function lac(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=b;b=e+11472|0;f=e+11181|0;c[e+5524>>2]=oac(b,128)|0;a[e+11623|0]=0;if((c[e+5524>>2]|0)!=0){a[e+11623|0]=Fac(b,8)|0}if((c[e+5496>>2]|0)==0){i=d;return}a[e+11620|0]=Fac(b,8)|0;a[e+11621|0]=Fac(b,8)|0;a[e+11622|0]=Fac(b,8)|0;if((oac(b,128)|0)!=0){g=0;do{a[e+10115+g|0]=Fac(b,8)|0;h=g+1|0;g=h;}while((h|0)<4)}if((oac(b,128)|0)!=0){g=0;do{a[e+10119+g|0]=Fac(b,8)|0;h=g+1|0;g=h;}while((h|0)<3)}Gac(b,f);i=d;return}function mac(b,e,f){b=b|0;e=e|0;f=f|0;var g=0;f=i;g=b;b=e;if((a[g+3093|0]|0)!=0){nac(g+11472|0,b|0,g|0)}else{if((c[g+5496>>2]|0)==0){a[b+11|0]=0}}if((c[g+5524>>2]|0)!=0){a[b+9|0]=oac(g+11472|0,d[g+11623|0]|0)|0}else{a[b+9|0]=0}a[b+3|0]=0;if((c[g+5496>>2]|0)==0){pac(g,b);i=f;return}else{qac(g,b,b|0);i=f;return}}function nac(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0;f=i;g=b;b=c;c=e;if((d[c+3092|0]|0|0)==0){i=f;return}if((d[c+3093|0]|0|0)==0){i=f;return}if((oac(g,d[c+3096|0]|0)|0)!=0){a[b+11|0]=(oac(g,d[c+3098|0]|0)|0)+2}else{a[b+11|0]=oac(g,d[c+3097|0]|0)|0}i=f;return}function oac(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=0;g=((ca((c[f+16>>2]|0)-1|0,b)|0)>>>8)+1|0;if((c[f+12>>2]|0)<0){ypc(f)}b=c[f+8>>2]|0;h=c[f+12>>2]|0;j=g<<24;k=g;if(b>>>0>=j>>>0){k=(c[f+16>>2]|0)-g|0;b=b-j|0;a=1}j=d[242168+k|0]|0;k=k<<j;b=b<<j;h=h-j|0;c[f+8>>2]=b;c[f+12>>2]=h;c[f+16>>2]=k;i=e;return a|0}function pac(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b;b=e;e=g+11472|0;h=c[g+5520>>2]|0;a[b+2|0]=0;a[b|0]=Cac(e,243320)|0;if((d[b|0]|0|0)!=4){j=e;k=yac(j,243368)|0;l=k&255;m=b;n=m|0;o=n+1|0;a[o]=l;i=f;return}g=0;a[b+3|0]=1;do{p=Dac(b,g,h)|0;c[b+12+(g<<2)>>2]=xac(e,243376+(p*90|0)+((Eac(b,g)|0)*9|0)|0)|0;p=g+1|0;g=p;}while((p|0)<16);j=e;k=yac(j,243368)|0;l=k&255;m=b;n=m|0;o=n+1|0;a[o]=l;i=f;return}function qac(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;i=i+48|0;j=h|0;k=h+16|0;l=h+32|0;m=h+40|0;n=e;e=f;f=g;g=n+11472|0;a[f+2|0]=oac(g,d[n+11620|0]|0)|0;if((a[f+2|0]|0)==0){c[f+4>>2]=0;p=(wac(g,n+10115|0)|0)&255;a[f|0]=p;if((p&255|0)==4){p=0;a[f+3|0]=1;do{c[e+12+(p<<2)>>2]=xac(g,n+10106|0)|0;q=p+1|0;p=q;}while((q|0)<16)}a[f+1|0]=yac(g,n+10119|0)|0;i=h;return}p=j|0;q=k|0;r=e+((-(c[n+3036>>2]|0)|0)*76|0)|0;s=e-76|0;t=r-76|0;u=n+8964|0;a[f+10|0]=0;if((oac(g,d[n+11621|0]|0)|0)!=0){a[f+2|0]=(oac(g,d[n+11622|0]|0)|0)+2}c[q+8>>2]=0;c[q+4>>2]=0;c[q>>2]=0;c[j+12>>2]=0;c[j+8>>2]=0;c[j+4>>2]=0;c[j>>2]=0;if((d[r+2|0]|0)!=0){if((c[r+4>>2]|0)!=0){v=q+4|0;q=v;c[v>>2]=c[r+4>>2];rac(c[u+(d[r+2|0]<<2)>>2]|0,d[f+2|0]|0,q,u);p=p+4|0}v=p;c[v>>2]=(c[v>>2]|0)+2}if((d[s+2|0]|0)!=0){if((c[s+4>>2]|0)!=0){c[l>>2]=c[s+4>>2];rac(c[u+(d[s+2|0]<<2)>>2]|0,d[f+2|0]|0,l,u);if((c[l>>2]|0)!=(c[q>>2]|0)){v=q+4|0;q=v;c[v>>2]=c[l>>2];p=p+4|0}l=p;c[l>>2]=(c[l>>2]|0)+2}else{l=j|0;c[l>>2]=(c[l>>2]|0)+2}}if((d[t+2|0]|0)!=0){if((c[t+4>>2]|0)!=0){c[m>>2]=c[t+4>>2];rac(c[u+(d[t+2|0]<<2)>>2]|0,d[f+2|0]|0,m,u);if((c[m>>2]|0)!=(c[q>>2]|0)){u=q+4|0;q=u;c[u>>2]=c[m>>2];p=p+4|0}m=p;c[m>>2]=(c[m>>2]|0)+1}else{m=j|0;c[m>>2]=(c[m>>2]|0)+1}}if((oac(g,c[o+(c[j>>2]<<4)>>2]|0)|0)!=0){m=j+4|0;c[m>>2]=(c[m>>2]|0)+((c[j+12>>2]|0)>0&(c[q>>2]|0)==(c[k+4>>2]|0));if((c[j+8>>2]|0)>(c[j+4>>2]|0)){q=c[j+4>>2]|0;c[j+4>>2]=c[j+8>>2];c[j+8>>2]=q;q=c[k+4>>2]|0;c[k+4>>2]=c[k+8>>2];c[k+8>>2]=q}if((oac(g,c[o+(c[j+4>>2]<<4)+4>>2]|0)|0)!=0){if((oac(g,c[o+(c[j+8>>2]<<4)+8>>2]|0)|0)!=0){q=n+11181|0;m=c[n+3136>>2]|0;p=c[n+3140>>2]|0;m=m-128|0;p=p+128|0;u=c[n+3132>>2]|0;u=u+128|0;l=c[n+3128>>2]|0;l=l-128|0;v=(c[j+4>>2]|0)>=(c[j>>2]|0)|0;sac(k+(v<<2)|0,n|0);c[j+12>>2]=(((d[r|0]|0)==9)+((d[s|0]|0)==9)<<1)+((d[t|0]|0)==9);if((oac(g,c[o+(c[j+12>>2]<<4)+12>>2]|0)|0)!=0){tac(g,e,s,r,f,k+(v<<2)|0,q,l,u,m,p);c[f+4>>2]=c[e+72>>2];a[f|0]=9;a[f+3|0]=1}else{e=f+4|0;uac(g,e,q);q=e|0;b[q>>1]=(b[q>>1]|0)+(b[k+(v<<2)>>1]|0);q=e+2|0;b[q>>1]=(b[q>>1]|0)+(b[k+(v<<2)+2>>1]|0);a[f+10|0]=vac(e,l,u,m,p)|0;a[f|0]=8}}else{a[f|0]=6;c[f+4>>2]=c[k+8>>2];sac(f+4|0,n|0)}}else{a[f|0]=5;c[f+4>>2]=c[k+4>>2];sac(f+4|0,n|0)}}else{a[f|0]=7;c[f+4>>2]=0}i=h;return}function rac(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=e;if((a|0)==(c[f+(d<<2)>>2]|0)){i=g;return}d=h|0;b[d>>1]=(b[d>>1]|0)*-1|0;d=h+2|0;b[d>>1]=(b[d>>1]|0)*-1|0;i=g;return}function sac(a,d){a=a|0;d=d|0;var e=0,f=0;e=i;f=a;a=d;if((b[f+2>>1]|0)<((c[a+3128>>2]|0)-128|0)){b[f+2>>1]=(c[a+3128>>2]|0)-128}else{if((b[f+2>>1]|0)>((c[a+3132>>2]|0)+128|0)){b[f+2>>1]=(c[a+3132>>2]|0)+128}}if((b[f>>1]|0)<((c[a+3136>>2]|0)-128|0)){b[f>>1]=(c[a+3136>>2]|0)-128;i=e;return}if((b[f>>1]|0)>((c[a+3140>>2]|0)+128|0)){b[f>>1]=(c[a+3140>>2]|0)+128}i=e;return}function tac(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;q=i;i=i+24|0;r=k;k=i;i=i+4|0;i=i+7&-8;c[k>>2]=c[r>>2];r=q|0;s=q+8|0;t=q+16|0;u=e;e=f;f=g;g=h;h=j;j=l;l=m;m=n;n=o;o=p;p=0;v=3;w=16;if((oac(u,110)|0)!=0){v=2;w=4;if((oac(u,111)|0)!=0){v=oac(u,150)|0;w=2}}do{x=d[243120+(v<<4)+p|0]|0;if((x&3|0)!=0){c[r>>2]=c[e+12+(x<<2)-4>>2]}else{if((d[f|0]|0)!=9){c[r>>2]=c[f+4>>2]}else{c[r>>2]=c[f+12+(x<<2)+16-4>>2]}}if((x>>2|0)!=0){c[s>>2]=c[e+12+(x<<2)-16>>2]}else{if((d[g|0]|0)!=9){c[s>>2]=c[g+4>>2]}else{c[s>>2]=c[g+12+(x<<2)+64-16>>2]}}x=Bac(c[r>>2]|0,c[s>>2]|0)|0;if((oac(u,d[x|0]|0)|0)!=0){if((oac(u,d[x+1|0]|0)|0)!=0){c[t>>2]=0;if((oac(u,d[x+2|0]|0)|0)!=0){b[t>>1]=(Aac(u,j|0)|0)<<1;x=t|0;b[x>>1]=(b[x>>1]|0)+(b[k>>1]|0);b[t+2>>1]=(Aac(u,j+19|0)|0)<<1;x=t+2|0;b[x>>1]=(b[x>>1]|0)+(b[k+2>>1]|0)}}else{c[t>>2]=c[s>>2]}}else{c[t>>2]=c[r>>2]}x=vac(t,l,m,n,o)|0;y=h+10|0;a[y]=d[y]|x;x=d[832912+v|0]|0;y=832848+(v<<4)+(ca(p&255,d[832912+v|0]|0)|0)|0;do{c[e+12+(d[y]<<2)>>2]=c[t>>2];y=y+1|0;z=x-1|0;x=z;}while((z|0)!=0);x=p+1|0;p=x;}while((x|0)<(w|0));a[h+8|0]=v;i=q;return}function uac(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=c;c=d;b[a>>1]=(Aac(f,c)|0)<<1;d=c+19|0;c=d;b[a+2>>1]=(Aac(f,d)|0)<<1;i=e;return}function vac(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=(b[g+2>>1]|0)<(c|0)|0;a=a|(b[g+2>>1]|0)>(d|0);a=a|(b[g>>1]|0)<(e|0);a=a|(b[g>>1]|0)>(f|0);i=i;return a|0}function wac(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=zac(a,236128,b)|0;i=c;return d|0}function xac(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=zac(a,246704,b)|0;i=c;return d|0}function yac(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=zac(a,236184,b)|0;i=c;return d|0}function zac(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=i;g=b;b=c;c=e;e=0;do{h=a[b+((e<<24>>24)+(oac(g,d[c+(e<<24>>24>>1)|0]|0)|0))|0]|0;e=h;}while((h<<24>>24|0)>0);i=f;return-(e<<24>>24)|0}function Aac(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0,h=0,j=0;c=i;e=a;a=b;b=0;if((oac(e,d[a|0]|0)|0)!=0){f=0;do{b=b+((oac(e,d[a+(f+9)|0]|0)|0)<<f)|0;g=f+1|0;f=g;}while((g|0)<3);f=9;do{b=b+((oac(e,d[a+(f+9)|0]|0)|0)<<f)|0;g=f-1|0;f=g;}while((g|0)>3);if((b&65520|0)!=0){if((oac(e,d[a+12|0]|0)|0)!=0){h=10}}else{h=10}if((h|0)==10){b=b+8|0}}else{b=zac(e,238536,a+2|0)|0}if((b|0)==0){j=b;i=c;return j|0}if((oac(e,d[a+1|0]|0)|0)==0){j=b;i=c;return j|0}b=-b|0;j=b;i=c;return j|0}function Bac(a,b){a=a|0;b=b|0;var c=0;c=a;a=b;i=i;return 238464+((((a|0)==0)<<2|((c|0)==0)<<1|(c|0)==(a|0))*3|0)|0}function Cac(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=zac(a,243312,b)|0;i=c;return d|0}function Dac(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=a;a=b;a:do{if((a>>2|0)!=0){g=c[f+12+(a<<2)-16>>2]|0}else{f=f+((-e|0)*76|0)|0;switch(d[f|0]|0|0){case 2:{g=3;break a;break};case 0:{g=0;break a;break};case 1:{g=2;break a;break};case 3:{g=1;break a;break};case 4:{g=c[f+12+(a<<2)+48>>2]|0;break a;break};default:{g=0;break a}}}}while(0);i=i;return g|0}function Eac(a,b){a=a|0;b=b|0;var e=0,f=0;e=a;a=b;a:do{if((a&3|0)!=0){f=c[e+12+(a<<2)-4>>2]|0}else{e=e-76|0;switch(d[e|0]|0|0){case 1:{f=2;break a;break};case 2:{f=3;break a;break};case 3:{f=1;break a;break};case 0:{f=0;break a;break};case 4:{f=c[e+12+(a<<2)+12>>2]|0;break a;break};default:{f=0;break a}}}}while(0);i=i;return f|0}function Fac(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=0;e=b-1|0;while(1){if((e|0)<0){break}a=a|(oac(d,128)|0)<<e;e=e-1|0}i=c;return a|0}function Gac(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b;b=c;c=0;do{g=242424+(c*19|0)|0;h=b+(c*19|0)|0;j=h+19|0;do{k=g;g=k+1|0;if((oac(f,d[k]|0)|0)!=0){k=(Fac(f,7)|0)&255;if((k&255|0)!=0){l=(k&255)<<1}else{l=1}a[h]=l}k=h+1|0;h=k;}while(k>>>0<j>>>0);j=c+1|0;c=j;}while((j|0)<2);i=e;return}function Hac(b){b=b|0;var d=0,e=0,f=0;d=i;e=b;b=c[e+3084>>2]|0;f=c[e+3088>>2]|0;mrc(b|0,0,8)|0;mrc(f|0,0,8)|0;if((a[(c[e+3032>>2]|0)+3|0]|0)!=0){i=d;return}a[f+8|0]=0;a[b+8|0]=0;i=d;return}function Iac(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=d;d=c[f+3160>>2]|0;g=b+10106|0;b=f+1984|0;h=0;j=c[f+3084>>2]|0;k=c[f+3088>>2]|0;l=0;m=f+384|0;if((a[(c[f+3032>>2]|0)+3|0]|0)!=0){n=g+811|0;l=0}else{o=j+8|0;p=k+8|0;n=g+283|0;q=Jac(d,n,(a[o]|0)+(a[p]|0)|0,0,m+768|0)|0;f=(q|0)>0&255;a[p]=f;a[o]=f;a[b+24|0]=q;h=h+(q-16)|0;n=g+19|0;l=1}f=0;while(1){if((f|0)>=16){break}o=j+(f&3)|0;p=k+((f&12)>>2)|0;q=Jac(d,n,(a[o]|0)+(a[p]|0)|0,l,m)|0;r=(q|0)>0&255;a[p]=r;a[o]=r;q=q+l|0;a[b+f|0]=q;h=h+q|0;m=m+32|0;f=f+1|0}n=g+547|0;j=j+4|0;k=k+4|0;f=16;while(1){if((f|0)>=24){break}o=j+(((f|0)>19)<<1)+(f&1)|0;p=k+(((f|0)>19)<<1)+((f&3|0)>1)|0;q=Jac(d,n,(a[o]|0)+(a[p]|0)|0,0,m)|0;g=(q|0)>0&255;a[p]=g;a[o]=g;a[b+f|0]=q;h=h+q|0;m=m+32|0;f=f+1|0}i=e;return h|0}function Jac(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;l=e;e=f;f=h;h=j;j=e+(f*33|0)+(g*11|0)|0;if((Kac(l,d[j|0]|0)|0)==0){m=0;n=m;i=k;return n|0}while(1){f=f+1|0;if((Kac(l,d[j+1|0]|0)|0)!=0){if((Kac(l,d[j+2|0]|0)|0)!=0){if((Kac(l,d[j+3|0]|0)|0)!=0){if((Kac(l,d[j+6|0]|0)|0)!=0){g=Kac(l,d[j+8|0]|0)|0;o=(g<<1)+(Kac(l,d[j+(g+9)|0]|0)|0)|0;p=0;g=c[1036872+(o<<2)>>2]|0;while(1){if((a[g]|0)==0){break}p=p+(p+(Kac(l,d[g]|0)|0))|0;g=g+1|0}p=p+((8<<o)+3)|0}else{if((Kac(l,d[j+7|0]|0)|0)!=0){p=((Kac(l,165)|0)<<1)+7|0;p=p+(Kac(l,145)|0)|0}else{p=(Kac(l,159)|0)+5|0}}}else{if((Kac(l,d[j+4|0]|0)|0)!=0){p=(Kac(l,d[j+5|0]|0)|0)+3|0}else{p=2}}j=e+((d[1036896+f|0]|0)*33|0)+22|0}else{j=e+((d[1036896+f|0]|0)*33|0)+11|0;p=1}g=d[1036824+(f-1)|0]|0;b[h+(g<<1)>>1]=Lac(l,p)|0;if((f|0)==16){q=27;break}if((Kac(l,d[j|0]|0)|0)==0){q=27;break}}else{j=e+((d[1036896+f|0]|0)*33|0)|0}if((f|0)==16){q=30;break}}if((q|0)==27){m=f;n=m;i=k;return n|0}else if((q|0)==30){m=16;n=m;i=k;return n|0}return 0}function Kac(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=0;g=((ca((c[f+16>>2]|0)-1|0,b)|0)>>>8)+1|0;if((c[f+12>>2]|0)<0){ypc(f)}b=c[f+8>>2]|0;h=c[f+12>>2]|0;j=g<<24;k=g;if(b>>>0>=j>>>0){k=(c[f+16>>2]|0)-g|0;b=b-j|0;a=1}j=d[242168+k|0]|0;k=k<<j;b=b<<j;h=h-j|0;c[f+8>>2]=b;c[f+12>>2]=h;c[f+16>>2]=k;i=e;return a|0}function Lac(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;b=((c[e+16>>2]|0)+1|0)>>>1;f=b<<24;if((c[e+12>>2]|0)<0){ypc(e)}if((c[e+8>>2]|0)>>>0<f>>>0){c[e+16>>2]=b;g=a}else{c[e+16>>2]=(c[e+16>>2]|0)-b;c[e+8>>2]=(c[e+8>>2]|0)-f;g=-a|0}a=e+16|0;c[a>>2]=(c[a>>2]|0)+(c[e+16>>2]|0);a=e+8|0;c[a>>2]=(c[a>>2]|0)+(c[e+8>>2]|0);a=e+12|0;c[a>>2]=(c[a>>2]|0)-1;i=d;return g|0}function Mac(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;j=e;e=f;f=e+(g<<3)|0;g=c[j+8>>2]|0;k=c[j+4>>2]|0;l=c[j>>2]|0;while(1){if(!(e>>>0<f>>>0)){break}m=d[e+6|0]|0;n=246592+(m<<3)|0;o=244840+(m<<4)|0;m=0;p=c[e>>2]|0;q=c[n>>2]|0;r=c[n+4>>2]|0;if((a[e+7|0]|0)!=0){r=r-1|0;m=2}do{n=r-1|0;r=n;s=q>>n&1;t=((ca(k-1|0,d[p+(m>>1)|0]|0)|0)>>>8)+1|0;m=a[246568+(m+s)|0]|0;if((s|0)!=0){l=l+t|0;k=k-t|0}else{k=t}u=d[242168+k|0]|0;k=k<<u;g=g+u|0;if((g|0)>=0){s=u-g|0;if((l<<s-1&-2147483648|0)!=0){n=(c[j+12>>2]|0)-1|0;while(1){if((n|0)>=0){v=(d[(c[j+16>>2]|0)+n|0]|0)==255}else{v=0}if(!v){break}a[(c[j+16>>2]|0)+n|0]=0;n=n-1|0}w=(c[j+16>>2]|0)+n|0;a[w]=(d[w]|0)+1}Nac((c[j+16>>2]|0)+(c[j+12>>2]|0)|0,1,c[j+20>>2]|0,c[j+24>>2]|0)|0;w=j+12|0;x=c[w>>2]|0;c[w>>2]=x+1;a[(c[j+16>>2]|0)+x|0]=l>>>((24-s|0)>>>0);l=l<<s;u=g;l=l&16777215;g=g-8|0}l=l<<u;}while((r|0)!=0);if((c[o+12>>2]|0)!=0){r=b[e+4>>1]|0;p=c[o+8>>2]|0;if((p|0)!=0){q=c[o+4>>2]|0;x=r>>1;w=p;m=0;do{p=w-1|0;w=p;y=x>>p&1;t=((ca(k-1|0,d[q+(m>>1)|0]|0)|0)>>>8)+1|0;m=a[(c[o>>2]|0)+(m+y)|0]|0;if((y|0)!=0){l=l+t|0;k=k-t|0}else{k=t}u=d[242168+k|0]|0;k=k<<u;g=g+u|0;if((g|0)>=0){y=u-g|0;if((l<<y-1&-2147483648|0)!=0){p=(c[j+12>>2]|0)-1|0;while(1){if((p|0)>=0){z=(d[(c[j+16>>2]|0)+p|0]|0)==255}else{z=0}if(!z){break}a[(c[j+16>>2]|0)+p|0]=0;p=p-1|0}s=(c[j+16>>2]|0)+p|0;a[s]=(d[s]|0)+1}Nac((c[j+16>>2]|0)+(c[j+12>>2]|0)|0,1,c[j+20>>2]|0,c[j+24>>2]|0)|0;s=j+12|0;n=c[s>>2]|0;c[s>>2]=n+1;a[(c[j+16>>2]|0)+n|0]=l>>>((24-y|0)>>>0);l=l<<y;u=g;l=l&16777215;g=g-8|0}l=l<<u;}while((w|0)!=0)}t=(k+1|0)>>>1;if((r&1|0)!=0){l=l+t|0;k=k-t|0}else{k=t}k=k<<1;if((l&-2147483648|0)!=0){w=(c[j+12>>2]|0)-1|0;while(1){if((w|0)>=0){A=(d[(c[j+16>>2]|0)+w|0]|0)==255}else{A=0}if(!A){break}a[(c[j+16>>2]|0)+w|0]=0;w=w-1|0}r=(c[j+16>>2]|0)+w|0;a[r]=(d[r]|0)+1}l=l<<1;r=g+1|0;g=r;if((r|0)==0){g=-8;Nac((c[j+16>>2]|0)+(c[j+12>>2]|0)|0,1,c[j+20>>2]|0,c[j+24>>2]|0)|0;r=j+12|0;m=c[r>>2]|0;c[r>>2]=m+1;a[(c[j+16>>2]|0)+m|0]=l>>>24;l=l&16777215}}e=e+8|0}c[j+8>>2]=g;c[j>>2]=l;c[j+4>>2]=k;i=h;return}function Nac(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;b=e;do{if((g+a|0)>>>0>g>>>0){if(!((g+a|0)>>>0<d>>>0)){break}h=1;j=h;i=f;return j|0}}while(0);ubc(b,7,2162336,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;h=0;j=h;i=f;return j|0}function Oac(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a;a=d+101264|0;e=c[a>>2]|0;f=(c[a+4>>2]|0)+(c[a+8>>2]|0)+(c[a+12>>2]|0)|0;g=(e*255|0|0)/(e+f|0)|0;c[d+142384>>2]=g;if((g|0)==0){c[d+142384>>2]=1}if((f|0)!=0){h=((c[a+4>>2]|0)*255|0|0)/(f|0)|0}else{h=128}c[d+142388>>2]=h;if((c[d+142388>>2]|0)==0){c[d+142388>>2]=1}if(((c[a+8>>2]|0)+(c[a+12>>2]|0)|0)!=0){j=((c[a+8>>2]|0)*255|0|0)/((c[a+8>>2]|0)+(c[a+12>>2]|0)|0)|0}else{j=128}c[d+142392>>2]=j;if((c[d+142392>>2]|0)!=0){i=b;return}c[d+142392>>2]=1;i=b;return}function Pac(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=d;d=e;if((a|0)>=0){}else{Cd(2305800,2552536,983,2651024)}if((a|0)<=255){}else{Cd(2422432,2552536,984,2651024)}if((b|0)>=0){}else{Cd(2340328,2552536,985,2651024)}if((b|0)<=255){}else{Cd(2281744,2552536,986,2651024)}if((d|0)>=0){}else{Cd(2232416,2552536,987,2651024)}if((d|0)<=255){}else{Cd(2193344,2552536,988,2651024)}c[g>>2]=c[238752+(a<<2)>>2];c[g+4>>2]=(c[238752+(255-a<<2)>>2]|0)+(c[238752+(b<<2)>>2]|0);c[g+8>>2]=(c[238752+(255-a<<2)>>2]|0)+(c[238752+(255-b<<2)>>2]|0)+(c[238752+(d<<2)>>2]|0);c[g+12>>2]=(c[238752+(255-a<<2)>>2]|0)+(c[238752+(255-b<<2)>>2]|0)+(c[238752+(255-d<<2)>>2]|0);i=f;return}function Qac(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+16|0;d=b|0;e=a;a=0;f=e+101264|0;g=c[f>>2]|0;h=(c[f+4>>2]|0)+(c[f+8>>2]|0)+(c[f+12>>2]|0)|0;OYb();if((c[e+107976>>2]|0)!=0){j=(g*255|0|0)/(g+h|0)|0;g=j;if((j|0)==0){g=1}if((h|0)!=0){k=((c[f+4>>2]|0)*255|0|0)/(h|0)|0}else{k=128}if(((c[f+8>>2]|0)+(c[f+12>>2]|0)|0)!=0){l=((c[f+8>>2]|0)*255|0|0)/((c[f+8>>2]|0)+(c[f+12>>2]|0)|0)|0}else{l=128}Pac(d|0,g,k,l);l=ca(c[f>>2]|0,c[d>>2]|0)|0;k=l+(ca(c[f+4>>2]|0,c[d+4>>2]|0)|0)|0;l=k+(ca(c[f+8>>2]|0,c[d+8>>2]|0)|0)|0;k=l+(ca(c[f+12>>2]|0,c[d+12>>2]|0)|0)|0;Pac(d|0,c[e+142384>>2]|0,c[e+142388>>2]|0,c[e+142392>>2]|0);l=ca(c[f>>2]|0,c[d>>2]|0)|0;g=l+(ca(c[f+4>>2]|0,c[d+4>>2]|0)|0)|0;l=g+(ca(c[f+8>>2]|0,c[d+8>>2]|0)|0)|0;a=a+((l+(ca(c[f+12>>2]|0,c[d+12>>2]|0)|0)-k|0)/256|0)|0}if((c[e+114256>>2]&2|0)!=0){a=a+(Rac(e)|0)|0;m=a;i=b;return m|0}else{a=a+(Sac(e)|0)|0;m=a;i=b;return m|0}return 0}function Rac(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+96|0;e=d|0;f=d+48|0;g=b;b=g+73728|0;h=0;j=0;do{k=0;do{l=0;mrc(e|0,0,48)|0;mrc(f|0,0,48)|0;m=b+6500+(j*1152|0)+(k*144|0)|0;if((c[g+107976>>2]|0)==0){m=1579840+(j*1152|0)+(k*144|0)|0}tbc(m,e|0);do{m=0;vpc(12,246592,246568,g+131760+(j*264|0)+(k*33|0)+(l*11|0)|0,g+133872+(j*2112|0)+(k*264|0)+(l*88|0)|0,e|0,256,1);do{n=a[g+131760+(j*264|0)+(k*33|0)+(l*11|0)+m|0]|0;o=a[g+112605+(j*264|0)+(k*33|0)+(l*11|0)+m|0]|0;p=Uac(g+133872+(j*2112|0)+(k*264|0)+(l*88|0)+(m<<3)|0,o,n,a[245512+(j*264|0)+(k*33|0)+(l*11|0)+m|0]|0)|0;do{if((c[g+107976>>2]|0)!=0){q=10}else{if((c[g+107976>>2]|0)!=0){break}if((n&255|0)!=(o&255|0)){q=10}}}while(0);if((q|0)==10){q=0;o=f+(m<<2)|0;c[o>>2]=(c[o>>2]|0)+p}o=m+1|0;m=o;}while((o|0)<11);m=l+1|0;l=m;}while((m|0)<3);l=0;do{if((c[f+(l<<2)>>2]|0)>0){q=18}else{if((c[g+107976>>2]|0)==0){q=18}}if((q|0)==18){q=0;h=h+(c[f+(l<<2)>>2]|0)|0}m=l+1|0;l=m;}while((m|0)<11);l=k+1|0;k=l;}while((l|0)<8);k=j+1|0;j=k;}while((k|0)<4);i=d;return h|0}function Sac(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;c=i;d=b;b=d+73728|0;e=0;f=0;do{g=0;do{h=0;do{j=0;vpc(12,246592,246568,d+131760+(f*264|0)+(g*33|0)+(h*11|0)|0,d+133872+(f*2112|0)+(g*264|0)+(h*88|0)|0,b+6500+(f*1152|0)+(g*144|0)+(h*48|0)|0,256,1);do{k=Uac(d+133872+(f*2112|0)+(g*264|0)+(h*88|0)+(j<<3)|0,a[d+112605+(f*264|0)+(g*33|0)+(h*11|0)+j|0]|0,a[d+131760+(f*264|0)+(g*33|0)+(h*11|0)+j|0]|0,a[245512+(f*264|0)+(g*33|0)+(h*11|0)+j|0]|0)|0;if((k|0)>0){e=e+k|0}k=j+1|0;j=k;}while((k|0)<11);j=h+1|0;h=j;}while((j|0)<3);h=g+1|0;g=h;}while((h|0)<8);g=f+1|0;f=g;}while((g|0)<4);i=c;return e|0}function Tac(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+48|0;f=e|0;g=b;b=0;h=g+113728|0;j=0;OYb();do{k=0;do{l=0;mrc(f|0,0,44)|0;if((c[g+114256>>2]&2|0)!=0){l=0;while(1){if((l|0)>=3){break}m=0;while(1){if((m|0)>=11){break}n=Uac(g+133872+(b*2112|0)+(k*264|0)+(l*88|0)+(m<<3)|0,a[g+112605+(b*264|0)+(k*33|0)+(l*11|0)+m|0]|0,a[g+131760+(b*264|0)+(k*33|0)+(l*11|0)+m|0]|0,a[245512+(b*264|0)+(k*33|0)+(l*11|0)+m|0]|0)|0;o=f+(m<<2)|0;c[o>>2]=(c[o>>2]|0)+n;m=m+1|0}l=l+1|0}l=0}do{m=0;do{n=a[g+131760+(b*264|0)+(k*33|0)+(l*11|0)+m|0]|0;o=g+112605+(b*264|0)+(k*33|0)+(l*11|0)+m|0;p=a[245512+(b*264|0)+(k*33|0)+(l*11|0)+m|0]|0;q=c[f+(m<<2)>>2]|0;r=0;if((c[g+114256>>2]&2|0)==0){q=Uac(g+133872+(b*2112|0)+(k*264|0)+(l*88|0)+(m<<3)|0,a[o]|0,n,p)|0}if((q|0)>0){r=1}do{if((c[g+114256>>2]&2|0)!=0){if((c[g+107976>>2]|0)!=0){break}if((n&255|0)==(d[o]|0|0)){break}r=1}}while(0);Vac(h,r,p&255);if((r|0)!=0){a[o]=n;ybc(h,n&255,8);j=j+q|0}s=m+1|0;m=s;}while((s|0)<11);m=l+1|0;l=m;}while((m|0)<3);l=k+1|0;k=l;}while((l|0)<8);k=b+1|0;b=k;}while((k|0)<4);i=e;return}function Uac(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=e;e=pbc(g,b)|0;b=pbc(g,d)|0;i=f;return e-b-((((c[238752+(255-(a&255)<<2)>>2]|0)-(c[238752+((a&255)<<2)>>2]|0)|0)>>>8)+8)|0}function Vac(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=b;b=c[h+8>>2]|0;j=c[h+4>>2]|0;k=c[h>>2]|0;l=((ca(j-1|0,f)|0)>>>8)+1|0;j=l;if((e|0)!=0){k=k+l|0;j=(c[h+4>>2]|0)-l|0}l=d[242168+j|0]|0;j=j<<l;b=b+l|0;if((b|0)<0){m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+8|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}e=l-b|0;if((k<<e-1&-2147483648|0)!=0){f=(c[h+12>>2]|0)-1|0;while(1){if((f|0)>=0){y=(d[(c[h+16>>2]|0)+f|0]|0|0)==255}else{y=0}if(!y){break}a[(c[h+16>>2]|0)+f|0]=0;f=f-1|0}y=(c[h+16>>2]|0)+f|0;a[y]=(d[y]|0)+1}Nac((c[h+16>>2]|0)+(c[h+12>>2]|0)|0,1,c[h+20>>2]|0,c[h+24>>2]|0)|0;y=h+12|0;f=c[y>>2]|0;c[y>>2]=f+1;a[(c[h+16>>2]|0)+f|0]=k>>>((24-e|0)>>>0);k=k<<e;l=b;k=k&16777215;b=b-8|0;m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+8|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}function Wac(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;i=i+8|0;j=h|0;k=b;b=e;e=g;g=k+105664|0;l=k+113728|0;m=k+76880|0;n=0;o=b;p=f;f=j;c[f>>2]=c[f>>2]&-17|(c[g+2316>>2]&1)<<4;f=j;c[f>>2]=c[f>>2]&-2|c[g+2312>>2]&1;f=j;c[f>>2]=c[f>>2]&-15|(c[g+8040>>2]&7)<<1;f=j;c[f>>2]=c[f>>2]&-16777185;f=243304;c[l+24>>2]=g;Nac(o,3,p,k+105664|0)|0;o=o+3|0;if((c[j>>2]&1|0)==0){Nac(o,7,p,k+105664|0)|0;a[o|0]=-99;a[o+1|0]=1;a[o+2|0]=42;q=c[g+1800>>2]<<14|c[g+1792>>2];a[o+3|0]=q;a[o+4|0]=q>>8;q=c[g+1804>>2]<<14|c[g+1796>>2];a[o+5|0]=q;a[o+6|0]=q>>8;n=7;o=o+n|0;vbc(l,o,p);Vac(l,0,128);Vac(l,c[g+1808>>2]|0,128)}else{vbc(l,o,p)}Vac(l,d[m+3092|0]|0,128);if((a[m+3092|0]|0)!=0){Vac(l,d[m+3093|0]|0,128);Vac(l,d[m+3094|0]|0,128);if((a[m+3094|0]|0)!=0){Vac(l,d[m+3095|0]|0,128);r=0;while(1){if((r|0)>=2){break}q=0;while(1){if((q|0)>=4){break}s=a[m+3099+(r<<2)+q|0]|0;if(s<<24>>24!=0){Vac(l,1,128);if((s<<24>>24|0)<0){s=-(s<<24>>24)&255;ybc(l,s<<24>>24,c[f+(r<<2)>>2]|0);Vac(l,1,128)}else{ybc(l,s<<24>>24,c[f+(r<<2)>>2]|0);Vac(l,0,128)}}else{Vac(l,0,128)}q=q+1|0}r=r+1|0}}if((a[m+3093|0]|0)!=0){r=0;while(1){if((r|0)>=3){break}f=d[m+3096+r|0]|0;if((f|0)!=255){Vac(l,1,128);ybc(l,f,8)}else{Vac(l,0,128)}r=r+1|0}}}Vac(l,c[g+2392>>2]|0,128);ybc(l,c[g+5744>>2]|0,6);ybc(l,c[g+5752>>2]|0,3);Vac(l,d[m+3107|0]|0,128);if((a[m+3107|0]|0)!=0){if((d[m+3108|0]|0)!=0){t=1}else{t=(c[k+114256>>2]|0)!=0}f=t&1;Vac(l,f,128);if((f|0)!=0){r=0;while(1){if((r|0)>=4){break}u=a[m+3113+r|0]|0;do{if((a[m+3113+r|0]|0)!=(a[m+3109+r|0]|0)){v=39}else{if((c[k+114256>>2]|0)!=0){v=39;break}Vac(l,0,128)}}while(0);if((v|0)==39){v=0;a[m+3109+r|0]=a[m+3113+r|0]|0;Vac(l,1,128);if((u|0)>0){ybc(l,u&63,6);Vac(l,0,128)}else{u=-u|0;ybc(l,u&63,6);Vac(l,1,128)}}r=r+1|0}r=0;while(1){if((r|0)>=4){break}u=a[m+3121+r|0]|0;do{if((a[m+3121+r|0]|0)!=(a[m+3117+r|0]|0)){v=50}else{if((c[k+114256>>2]|0)!=0){v=50;break}Vac(l,0,128)}}while(0);if((v|0)==50){v=0;a[m+3117+r|0]=a[m+3121+r|0]|0;Vac(l,1,128);if((u|0)>0){ybc(l,u&63,6);Vac(l,0,128)}else{u=-u|0;ybc(l,u&63,6);Vac(l,1,128)}}r=r+1|0}}}ybc(l,c[g+8044>>2]|0,2);ybc(l,c[g+2356>>2]|0,7);Xac(l,c[g+2360>>2]|0);Xac(l,c[g+2364>>2]|0);Xac(l,c[g+2368>>2]|0);Xac(l,c[g+2372>>2]|0);Xac(l,c[g+2376>>2]|0);if((c[g+2312>>2]|0)!=0){Vac(l,c[g+5760>>2]|0,128);Vac(l,c[g+5764>>2]|0,128);if((c[g+5760>>2]|0)==0){ybc(l,c[g+5768>>2]|0,2)}if((c[g+5764>>2]|0)==0){ybc(l,c[g+5772>>2]|0,2)}Vac(l,c[g+5788>>2]|0,128);Vac(l,c[g+5792>>2]|0,128)}if((c[k+114256>>2]&2|0)!=0){if((c[g+2312>>2]|0)==0){c[g+5776>>2]=1}else{c[g+5776>>2]=0}}Vac(l,c[g+5776>>2]|0,128);if((c[g+2312>>2]|0)!=0){Vac(l,c[g+5756>>2]|0,128)}OYb();if((c[g+5776>>2]|0)==0){nrc(k+111473|0,k+112586|0,1113)|0}Tac(k);Vac(l,c[g+2340>>2]|0,128);if((c[g+2312>>2]|0)==0){Yac(k)}else{Zac(k)}wbc(l);o=o+(c[l+12>>2]|0)|0;u=j;c[u>>2]=c[u>>2]&-16777185|(c[k+113740>>2]&524287)<<5;u=((c[j>>2]|0)>>>5&524287)<<5|((c[j>>2]|0)>>>4&1)<<4|((c[j>>2]|0)>>>1&7)<<1|c[j>>2]&1;a[b|0]=u;a[b+1|0]=u>>8;a[b+2|0]=u>>16;c[e>>2]=n+3+(c[k+113740>>2]|0);c[k+142664>>2]=c[e>>2];if((c[g+8044>>2]|0)==0){c[l+60>>2]=g;vbc(k+113764|0,o,p);Mac(k+113764|0,c[k+114728>>2]|0,c[k+114732>>2]|0);wbc(k+113764|0);l=e;c[l>>2]=(c[l>>2]|0)+(c[k+113776>>2]|0);c[k+142668>>2]=c[k+113776>>2];i=h;return}l=1<<c[g+8044>>2];n=k+142664|0;c[n>>2]=(c[n>>2]|0)+((l-1|0)*3|0);n=e;c[n>>2]=(c[n>>2]|0)+((l-1|0)*3|0);Nac(o,(l-1|0)*3|0,p,g|0)|0;r=1;while(1){if((r|0)>=(l+1|0)){break}c[k+113728+(r*36|0)+24>>2]=g;r=r+1|0}_ac(k,o+((l-1|0)*3|0)|0,p,l);r=1;while(1){if((r|0)>=(l|0)){break}c[k+142664+(r<<2)>>2]=c[k+113728+(r*36|0)+12>>2];$ac(o,c[k+142664+(r<<2)>>2]|0);o=o+3|0;p=e;c[p>>2]=(c[p>>2]|0)+(c[k+142664+(r<<2)>>2]|0);r=r+1|0}c[k+142664+(r<<2)>>2]=c[k+113728+(r*36|0)+12>>2];o=e;c[o>>2]=(c[o>>2]|0)+(c[k+142664+(r<<2)>>2]|0);i=h;return}function Xac(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=a;a=b;if((a|0)==0){Vac(d,0,128);i=c;return}Vac(d,1,128);ybc(d,R(a|0)|0,4);if((a|0)<0){Vac(d,1,128)}else{Vac(d,0,128)}i=c;return}function Yac(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b;b=f+113728|0;g=f+105664|0;h=c[g+2384>>2]|0;j=-1;k=0;if((c[g+2340>>2]|0)!=0){l=ca(c[g+2328>>2]|0,c[g+2332>>2]|0)|0;k=(l-(c[f+80224>>2]|0)<<8|0)/(l|0)|0;if((k|0)<=1){k=1}if((k|0)>=255){k=255}c[f+142396>>2]=k;ybc(b,k,8)}while(1){l=j+1|0;j=l;if((l|0)>=(c[g+2328>>2]|0)){break}l=-1;while(1){m=l+1|0;l=m;if((m|0)>=(c[g+2332>>2]|0)){break}m=d[h|0]|0;if((a[f+79973|0]|0)!=0){bbc(b,h|0,f+76880|0)}if((c[g+2340>>2]|0)!=0){Vac(b,d[h+9|0]|0,k)}qbc(b,m,243320);if((m|0)==4){m=c[g+2336>>2]|0;n=0;do{o=rbc(h,n,m)|0;p=sbc(h,n)|0;dbc(b,c[h+12+(n<<2)>>2]|0,243376+(o*90|0)+(p*9|0)|0);p=n+1|0;n=p;}while((p|0)<16)}n=h;h=n+76|0;ebc(b,d[n+1|0]|0,243368)}h=h+76|0}i=e;return}function Zac(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+72|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+48|0;m=e+56|0;n=e+64|0;o=b;b=o+105664|0;p=o+113728|0;q=b+7997|0;r=c[b+2384>>2]|0;s=c[b+2336>>2]|0;t=-1;u=0;c[o+80048>>2]=c[o+80052>>2];Oac(o);if((c[b+2340>>2]|0)!=0){v=ca(c[b+2328>>2]|0,c[b+2332>>2]|0)|0;u=(v-(c[o+80224>>2]|0)<<8|0)/(v|0)|0;if((u|0)<=1){u=1}if((u|0)>255){u=255}c[o+142396>>2]=u;ybc(p,u,8)}ybc(p,c[o+142384>>2]|0,8);ybc(p,c[o+142388>>2]|0,8);ybc(p,c[o+142392>>2]|0,8);abc(o);Dcc(o);while(1){v=t+1|0;t=v;if((v|0)>=(c[b+2328>>2]|0)){break}v=-1;while(1){w=v+1|0;v=w;if((w|0)>=(c[b+2332>>2]|0)){break}w=r|0;x=d[w+2|0]|0;y=d[w|0]|0;z=o+76880|0;c[z+3128>>2]=-(v<<4<<3);c[z+3132>>2]=(c[b+2332>>2]|0)-1-v<<4<<3;c[z+3136>>2]=-(t<<4<<3);c[z+3140>>2]=(c[b+2328>>2]|0)-1-t<<4<<3;if((a[o+79973|0]|0)!=0){bbc(p,w,o+76880|0)}if((c[b+2340>>2]|0)!=0){Vac(p,d[r+9|0]|0,u)}if((x|0)==0){Vac(p,0,c[o+142384>>2]|0);cbc(p,y,b+6931|0);if((y|0)==4){A=0;do{dbc(p,c[r+12+(A<<2)>>2]|0,b+6922|0);B=A+1|0;A=B;}while((B|0)<16)}ebc(p,d[w+1|0]|0,b+6935|0)}else{Vac(p,1,c[o+142384>>2]|0);if((x|0)==1){Vac(p,0,c[o+142388>>2]|0)}else{Vac(p,1,c[o+142388>>2]|0);Vac(p,(x|0)==2?0:1,c[o+142392>>2]|0)}Y7b(z,r,h,j,f,k|0,x,o+111444|0);fbc(f,z);a8b(g|0,k|0)|0;gbc(p,y,g|0);A=y;if((A|0)==8){hbc(p,w+4|0,f,q)}else if((A|0)==9){A=0;ibc(p,d[w+8|0]|0);do{B=242848+(d[w+8|0]<<6)|0;C=-1;D=c[(c[o+80048>>2]|0)+4+(A<<3)>>2]|0;c[l>>2]=c[(c[o+80048>>2]|0)+4+(A<<3)+4>>2];do{E=C+1|0;C=E;}while((A|0)!=(c[B+(E<<2)>>2]|0));c[m>>2]=jbc(r,C)|0;c[n>>2]=kbc(r,C,s)|0;lbc(p,D,238488+((LYb(m,n)|0)*3|0)|0);if((D|0)==13){hbc(p,l,f,q)}B=A+1|0;A=B;}while((B|0)<(c[c[o+80048>>2]>>2]|0))}}r=r+76|0;A=o+80048|0;c[A>>2]=(c[A>>2]|0)+132}r=r+76|0;v=o+80048|0;c[v>>2]=(c[v>>2]|0)+132}i=e;return}function _ac(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=e;e=b;b=d;d=0;while(1){if((d|0)>=(a|0)){break}h=g+113728+(d*36|0)+36|0;vbc(h,e,b);j=d;while(1){if((j|0)>=(c[g+107992>>2]|0)){break}k=c[(c[g+142660>>2]|0)+(j<<3)>>2]|0;Mac(h,k,((c[(c[g+142660>>2]|0)+(j<<3)+4>>2]|0)-k|0)/8|0);j=j+a|0}wbc(h);e=e+(c[h+12>>2]|0)|0;d=d+1|0}i=f;return}function $ac(b,c){b=b|0;c=c|0;var d=0;d=b;b=c;c=b&255;a[d]=c;c=b>>8&255;a[d+1|0]=c;c=b>>16&255;a[d+2|0]=c;i=i;return}function abc(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+72|0;c=a;a=c+105664|0;d=c+113728|0;obc(d,5,236144,236128,b|0,a+6931|0,b+8|0,c+101212|0);obc(d,4,236200,236184,b+40|0,a+6935|0,b+48|0,c+101232|0);i=b;return}function bbc(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0;e=i;f=a;a=c;if((d[a+3092|0]|0|0)==0){i=e;return}if((d[a+3093|0]|0|0)==0){i=e;return}c=d[b+11|0]|0;if((c|0)==3){Vac(f,1,d[a+3096|0]|0);Vac(f,1,d[a+3098|0]|0)}else if((c|0)==1){Vac(f,0,d[a+3096|0]|0);Vac(f,1,d[a+3097|0]|0)}else if((c|0)==0){Vac(f,0,d[a+3096|0]|0);Vac(f,0,d[a+3097|0]|0)}else if((c|0)==2){Vac(f,1,d[a+3096|0]|0);Vac(f,0,d[a+3098|0]|0)}else{Vac(f,0,d[a+3096|0]|0);Vac(f,0,d[a+3097|0]|0)}i=e;return}function cbc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;mbc(a,236128,c,236144+(b<<3)|0);i=d;return}function dbc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;mbc(a,246704,c,246744+(b<<3)|0);i=d;return}function ebc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;mbc(a,236184,c,236200+(b<<3)|0);i=d;return}function fbc(a,d){a=a|0;d=d|0;var e=0,f=0;e=i;f=a;a=d;if((b[f+2>>1]|0)<((c[a+3128>>2]|0)-128|0)){b[f+2>>1]=(c[a+3128>>2]|0)-128}else{if((b[f+2>>1]|0)>((c[a+3132>>2]|0)+128|0)){b[f+2>>1]=(c[a+3132>>2]|0)+128}}if((b[f>>1]|0)<((c[a+3136>>2]|0)-128|0)){b[f>>1]=(c[a+3136>>2]|0)-128;i=e;return}if((b[f>>1]|0)>((c[a+3140>>2]|0)+128|0)){b[f>>1]=(c[a+3140>>2]|0)+128}i=e;return}function gbc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;mbc(a,242504,c,242512+(b-5<<3)|0);i=d;return}function hbc(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;h=c;c=d;b[g>>1]=(b[h>>1]|0)-(b[c>>1]|0);b[g+2>>1]=(b[h+2>>1]|0)-(b[c+2>>1]|0);zcc(a,g,e);i=f;return}function ibc(a,b){a=a|0;b=b|0;var c=0;c=i;mbc(a,243104,243112,243184+(b<<3)|0);i=c;return}function jbc(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;do{if((a&3|0)==0){f=f-76|0;if((d[f|0]|0|0)==9){a=a+4|0;break}g=c[f+4>>2]|0;h=g;i=e;return h|0}}while(0);g=c[f+12+(a<<2)-4>>2]|0;h=g;i=e;return h|0}function kbc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;do{if((a>>2|0)==0){g=g+((-e|0)*76|0)|0;if((d[g|0]|0|0)==9){a=a+16|0;break}h=c[g+4>>2]|0;j=h;i=f;return j|0}}while(0);h=c[g+12+(a-4<<2)>>2]|0;j=h;i=f;return j|0}function lbc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;mbc(a,238456,c,238504+(b-10<<3)|0);i=d;return}function mbc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=e;nbc(a,b,d,c[g>>2]|0,c[g+4>>2]|0);i=f;return}function nbc(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;j=b;b=c;c=e;e=f;f=g;g=0;do{k=f-1|0;f=k;l=e>>k&1;Vac(j,l,d[c+(g<<24>>24>>1)|0]|0);g=a[b+((g<<24>>24)+l)|0]|0;}while((f|0)!=0);i=h;return}function obc(b,c,d,e,f,g,h,j){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=b;b=c;c=f;f=g;g=h;h=0;m=0;n=0;o=b;b=o-1|0;vpc(o,d,e,c,g,j,256,1);do{h=h+(pbc(g+(n<<3)|0,a[c+n|0]|0)|0)|0;m=m+(pbc(g+(n<<3)|0,a[f+n|0]|0)|0)|0;j=n+1|0;n=j;}while((j|0)<(b|0));if(!((h+(b<<8)|0)>>>0<m>>>0)){Vac(l,0,128);i=k;return}m=0;Vac(l,1,128);do{h=a[c+m|0]|0;if((h&255|0)!=0){p=h&255}else{p=1}h=p&255;a[f+m|0]=h;ybc(l,h&255,8);h=m+1|0;m=h;}while((h|0)<(b|0));i=k;return}function pbc(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;a=b;b=ca(c[d>>2]|0,c[238752+((a&255)<<2)>>2]|0)|0;e=(b+(ca(c[d+4>>2]|0,c[238752+(255-(a&255)<<2)>>2]|0)|0)|0)>>>8;i=i;return e|0}function qbc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;mbc(a,243312,c,243328+(b<<3)|0);i=d;return}function rbc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=a;a=b;a:do{if((a>>2|0)!=0){g=c[f+12+(a<<2)-16>>2]|0}else{f=f+((-e|0)*76|0)|0;switch(d[f|0]|0|0){case 0:{g=0;break a;break};case 3:{g=1;break a;break};case 1:{g=2;break a;break};case 4:{g=c[f+12+(a<<2)+48>>2]|0;break a;break};case 2:{g=3;break a;break};default:{g=0;break a}}}}while(0);i=i;return g|0}function sbc(a,b){a=a|0;b=b|0;var e=0,f=0;e=a;a=b;a:do{if((a&3|0)!=0){f=c[e+12+(a<<2)-4>>2]|0}else{e=e-76|0;switch(d[e|0]|0|0){case 1:{f=2;break a;break};case 2:{f=3;break a;break};case 3:{f=1;break a;break};case 4:{f=c[e+12+(a<<2)+12>>2]|0;break a;break};case 0:{f=0;break a;break};default:{f=0;break a}}}}while(0);i=i;return f|0}function tbc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=0;while(1){if((b|0)>=12){break}f=0;while(1){if((f|0)>=3){break}g=c[a+(b<<2)>>2]|0;h=a+(b<<2)|0;c[h>>2]=(c[h>>2]|0)+(c[e+(f*48|0)+(b<<2)>>2]|0);if((c[a+(b<<2)>>2]|0)>>>0<g>>>0){c[a+(b<<2)>>2]=-1}f=f+1|0}b=b+1|0}i=d;return}function ubc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function vbc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a;c[e>>2]=0;c[e+4>>2]=255;c[e+8>>2]=-24;c[e+16>>2]=b;c[e+20>>2]=d;c[e+12>>2]=0;i=i;return}function wbc(a){a=a|0;var b=0,c=0;b=i;c=a;a=0;while(1){if((a|0)>=32){break}xbc(c,0,128);a=a+1|0}i=b;return}function xbc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=b;b=c[h+8>>2]|0;j=c[h+4>>2]|0;k=c[h>>2]|0;l=((ca(j-1|0,f)|0)>>>8)+1|0;j=l;if((e|0)!=0){k=k+l|0;j=(c[h+4>>2]|0)-l|0}l=d[242168+j|0]|0;j=j<<l;b=b+l|0;if((b|0)<0){m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+8|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}e=l-b|0;if((k<<e-1&-2147483648|0)!=0){f=(c[h+12>>2]|0)-1|0;while(1){if((f|0)>=0){y=(d[(c[h+16>>2]|0)+f|0]|0|0)==255}else{y=0}if(!y){break}a[(c[h+16>>2]|0)+f|0]=0;f=f-1|0}y=(c[h+16>>2]|0)+f|0;a[y]=(d[y]|0)+1}zbc((c[h+16>>2]|0)+(c[h+12>>2]|0)|0,1,c[h+20>>2]|0,c[h+24>>2]|0)|0;y=h+12|0;f=c[y>>2]|0;c[y>>2]=f+1;a[(c[h+16>>2]|0)+f|0]=k>>>((24-e|0)>>>0);k=k<<e;l=b;k=k&16777215;b=b-8|0;m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+8|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}function ybc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=a;a=b;b=c-1|0;while(1){if((b|0)<0){break}xbc(e,1&a>>b,128);b=b-1|0}i=d;return}function zbc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;b=e;do{if((g+a|0)>>>0>g>>>0){if(!((g+a|0)>>>0<d>>>0)){break}h=1;j=h;i=f;return j|0}}while(0);Abc(b,7,2304768,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;h=0;j=h;i=f;return j|0}function Abc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function Bbc(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=c;c=d;d=a;a=f;g=0;while(1){if((g|0)>=4){break}h=(b[d>>1]|0)+(b[d+6>>1]|0)<<3;j=(b[d+2>>1]|0)+(b[d+4>>1]|0)<<3;k=(b[d+2>>1]|0)-(b[d+4>>1]|0)<<3;l=(b[d>>1]|0)-(b[d+6>>1]|0)<<3;b[a>>1]=h+j;b[a+4>>1]=h-j;b[a+2>>1]=(k*2217|0)+(l*5352|0)+14500>>12;b[a+6>>1]=(l*2217|0)-(k*5352|0)+7500>>12;d=d+(((c|0)/2|0)<<1)|0;a=a+8|0;g=g+1|0}d=f;a=f;g=0;while(1){if((g|0)>=4){break}h=(b[d>>1]|0)+(b[d+24>>1]|0)|0;j=(b[d+8>>1]|0)+(b[d+16>>1]|0)|0;k=(b[d+8>>1]|0)-(b[d+16>>1]|0)|0;l=(b[d>>1]|0)-(b[d+24>>1]|0)|0;b[a>>1]=h+j+7>>4;b[a+16>>1]=h-j+7>>4;b[a+8>>1]=((k*2217|0)+(l*5352|0)+12e3>>16)+((l|0)!=0);b[a+24>>1]=(l*2217|0)-(k*5352|0)+51e3>>16;d=d+2|0;a=a+2|0;g=g+1|0}i=e;return}function Cbc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=a;a=b;b=c;Bbc(e,a,b);Bbc(e+8|0,a+32|0,b);i=d;return}function Dbc(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c;c=d;d=a;a=f;g=0;while(1){if((g|0)>=4){break}h=(b[d>>1]|0)+(b[d+4>>1]|0)<<2;j=(b[d+2>>1]|0)+(b[d+6>>1]|0)<<2;k=(b[d+2>>1]|0)-(b[d+6>>1]|0)<<2;l=(b[d>>1]|0)-(b[d+4>>1]|0)<<2;b[a>>1]=h+j+((h|0)!=0);b[a+2>>1]=l+k;b[a+4>>1]=l-k;b[a+6>>1]=h-j;d=d+(((c|0)/2|0)<<1)|0;a=a+8|0;g=g+1|0}d=f;a=f;g=0;while(1){if((g|0)>=4){break}h=(b[d>>1]|0)+(b[d+16>>1]|0)|0;j=(b[d+8>>1]|0)+(b[d+24>>1]|0)|0;k=(b[d+8>>1]|0)-(b[d+24>>1]|0)|0;l=(b[d>>1]|0)-(b[d+16>>1]|0)|0;f=h+j|0;c=l+k|0;m=l-k|0;n=h-j|0;f=f+((f|0)<0)|0;c=c+((c|0)<0)|0;m=m+((m|0)<0)|0;n=n+((n|0)<0)|0;b[a>>1]=f+3>>3;b[a+8>>1]=c+3>>3;b[a+16>>1]=m+3>>3;b[a+24>>1]=n+3>>3;d=d+2|0;a=a+2|0;g=g+1|0}i=e;return}function Ebc(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+16|0;k=j|0;l=b;b=e;e=f;f=h;h=e+1600|0;m=16;n=(c[l+52>>2]|0)+f|0;o=c[l+16>>2]|0;l=(c[b+52>>2]|0)+f|0;p=c[b+16>>2]|0;q=0;r=k;c[r>>2]=c[61258];c[r+4>>2]=c[61259];c[r+8>>2]=c[61260];if(g>>>0<=24>>>0){g=0;while(1){if((g|0)>=3){break}r=k+(g<<2)|0;c[r>>2]=(c[r>>2]|0)+1;g=g+1|0}}g=0;while(1){if((g|0)>=16){break}r=0;while(1){if((r|0)>=16){break}s=0;t=0;u=0;s=(d[n+r|0]|0)-(d[h+r|0]|0)|0;u=R(s|0)|0;if((u|0)<=3){a[l+r|0]=a[n+r|0]|0;q=q+s|0}else{do{if((u|0)>=4){if((u|0)>7){v=16;break}t=c[k>>2]|0}else{v=16}}while(0);if((v|0)==16){v=0;do{if((u|0)>=8){if((u|0)>15){v=19;break}t=c[k+4>>2]|0}else{v=19}}while(0);if((v|0)==19){v=0;t=c[k+8>>2]|0}}if((s|0)>0){if(((d[h+r|0]|0)+t|0)>255){a[l+r|0]=-1}else{a[l+r|0]=(d[h+r|0]|0)+t}q=q+t|0}else{if(((d[h+r|0]|0)-t|0)<0){a[l+r|0]=0}else{a[l+r|0]=(d[h+r|0]|0)-t}q=q-t|0}}r=r+1|0}h=h+m|0;n=n+o|0;l=l+p|0;g=g+1|0}if((R(q|0)|0)>512){w=0;x=w;i=j;return x|0}else{O8b((c[b+52>>2]|0)+f|0,p,e+1600|0,m);w=1;x=w;i=j;return x|0}return 0}function Fbc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a;a=b;b=d;if((f|0)!=0){}else{Cd(2302840,2551408,141,2650984);return 0}d=0;while(1){if((d|0)>=4){break}c[f+(d*92|0)+88>>2]=0;if((J7b(f+(d*92|0)|0,a,b,32)|0)<0){g=6;break}mrc(c[f+(d*92|0)+68>>2]|0,0,c[f+(d*92|0)+80>>2]|0)|0;d=d+1|0}if((g|0)==6){Gbc(f);h=1;j=h;i=e;return j|0}c[f+456>>2]=0;if((J7b(f+368|0,a,b,32)|0)<0){Gbc(f);h=1;j=h;i=e;return j|0}else{mrc(c[f+436>>2]|0,0,c[f+448>>2]|0)|0;h=0;j=h;i=e;return j|0}return 0}function Gbc(a){a=a|0;var b=0,c=0;b=i;c=a;if((c|0)!=0){}else{Cd(2302840,2551408,175,2650960)}a=0;while(1){if((a|0)>=4){break}H7b(c+(a*92|0)|0)|0;a=a+1|0}H7b(c+368|0)|0;i=b;return}function Hbc(d,e,f,g,h,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=i;i=i+208|0;l=k|0;m=k+96|0;n=k+192|0;o=d;d=e;e=f;f=g;g=h;h=j;j=c[d+6484>>2]|0;p=c[d+6488>>2]|0;q=1;if((p|0)!=0){r=o+(j*92|0)|0;s=o+368|0;t=d+3152|0;u=c[t+3032>>2]|0;v=f-e|0;w=n;x=u;c[w>>2]=c[x>>2];c[w+4>>2]=c[x+4>>2];c[w+8>>2]=c[x+8>>2];a[u+2|0]=c[d+6484>>2];a[u|0]=c[d+6476>>2];c[u+4>>2]=c[d+6480>>2];a[u+10|0]=a[d+6492|0]|0;y=b[d+6482>>1]|0;z=b[d+6480>>1]|0;do{if((j|0)==0){A=5}else{if(!(((ca(z,z)|0)+(ca(y,y)|0)|0)>>>0<=625>>>0)){break}if((v|0)<5120){A=5}}}while(0);if((A|0)==5){a[u+2|0]=c[d+6488>>2];r=o+(p*92|0)|0;a[u|0]=7;c[u+4>>2]=0;c[d+6476>>2]=7;c[d+6480>>2]=0;e=f}nrc(l|0,t+2848|0,92)|0;nrc(m|0,t+2940|0,92)|0;c[t+2900>>2]=(c[r+52>>2]|0)+g;c[t+2904>>2]=(c[r+56>>2]|0)+h;c[t+2908>>2]=(c[r+60>>2]|0)+h;c[t+2992>>2]=(c[s+52>>2]|0)+g;c[t+2996>>2]=(c[s+56>>2]|0)+h;c[t+3e3>>2]=(c[s+60>>2]|0)+h;if((c[d+6448>>2]|0)!=0){W8b(t,c[t+2992>>2]|0,c[t+2996>>2]|0,c[t+3e3>>2]|0,c[t+2956>>2]|0,c[t+2976>>2]|0)}else{Y8b(t)}nrc(t+2848|0,l|0,92)|0;nrc(t+2940|0,m|0,92)|0;m=u;u=n;c[m>>2]=c[u>>2];c[m+4>>2]=c[u+4>>2];c[m+8>>2]=c[u+8>>2]}z=b[d+6480>>1]|0;y=b[d+6482>>1]|0;u=(ca(z,z)|0)+(ca(y,y)|0)|0;if(e>>>0>10240>>>0){A=12}else{if(u>>>0>5e3>>>0){A=12}}if((A|0)==12){q=0}if((q|0)==1){q=Ebc(o+368|0,o|0,d,u,g,h)|0}if((q|0)!=0){i=k;return}O8b(d+1600|0,16,(c[o+52>>2]|0)+g|0,c[o+16>>2]|0);i=k;return}function Ibc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=a;a=b;c[g>>2]=c[c[a+6380>>2]>>2];c[g+4>>2]=0;b=wrc(c[g>>2]|0,c[g+4>>2]|0,c[h+149716>>2]<<1,0)|0;c[e>>2]=b;c[e+4>>2]=G;b=Erc(2,0,c[g>>2]|0,c[g+4>>2]|0)|0;g=wrc(b,G,c[h+149716>>2]|0,0)|0;c[f>>2]=g;c[f+4>>2]=G;g=c[a+6376>>2]|0;b=Erc(g,(g|0)<0|0?-1:0,c[f>>2]|0,c[f+4>>2]|0)|0;f=c[e+4>>2]|0;g=wrc(b,G,(c[e>>2]|0)>>>1|f<<31,f>>1|((f|0)<0|0?-1:0)<<31)|0;f=Crc(g,G,c[e>>2]|0,c[e+4>>2]|0)|0;c[a+6376>>2]=f;c[a+6360>>2]=((c[a+6376>>2]|0)*100|0|0)/((c[a+6372>>2]|0)*110|0|0)|0;f=a+6360|0;c[f>>2]=(c[f>>2]|0)+((c[a+6360>>2]|0)==0);Jbc(h,a);i=d;return}function Jbc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=a;a=b;c[g>>2]=c[c[a+6380>>2]>>2];c[g+4>>2]=0;b=wrc(c[g>>2]|0,c[g+4>>2]|0,c[h+149716>>2]<<2,0)|0;c[e>>2]=b;c[e+4>>2]=G;b=Erc(4,0,c[g>>2]|0,c[g+4>>2]|0)|0;j=wrc(b,G,c[h+149716>>2]|0,0)|0;c[f>>2]=j;c[f+4>>2]=G;j=c[g+4>>2]|0;b=0;if((j|0)>(b|0)|(j|0)==(b|0)&(c[g>>2]|0)>>>0>(c[h+149716>>2]|0)>>>0){h=c[e+4>>2]|0;g=wrc(c[f>>2]|0,c[f+4>>2]|0,(c[e>>2]|0)>>>1|h<<31,h>>1|((h|0)<0|0?-1:0)<<31)|0;h=Crc(g,G,c[e>>2]|0,c[e+4>>2]|0)|0;c[a+6388>>2]=h-1;i=d;return}else{h=c[f+4>>2]|0;g=wrc(c[e>>2]|0,c[e+4>>2]|0,(c[f>>2]|0)>>>1|h<<31,h>>1|((h|0)<0|0?-1:0)<<31)|0;h=Crc(g,G,c[f>>2]|0,c[f+4>>2]|0)|0;c[a+6388>>2]=1-h;i=d;return}}function Kbc(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+48|0;f=e|0;g=e+8|0;h=e+24|0;j=e+32|0;k=b;b=k+73728|0;l=k+105664|0;m=b+3152|0;c[f>>2]=c[k+114728>>2];mrc(g|0,0,16)|0;c[h>>2]=0;if((c[k+142360>>2]|0)==2){if((c[k+114088>>2]|0)<0){c[k+142356>>2]=-(c[k+114088>>2]|0)}else{o$b(k)}}if((c[l+2348>>2]|0)!=0){c[m+3144>>2]=304;c[m+3148>>2]=274;c[m+3152>>2]=276;c[m+3156>>2]=264}else{c[m+3144>>2]=180;c[m+3148>>2]=212;c[m+3152>>2]=280;c[m+3156>>2]=242}c[k+80224>>2]=0;c[k+114732>>2]=0;c[m+3032>>2]=c[l+2384>>2];mrc(k+84836|0,0,16376)|0;Y_b(k);m$b(k,b,I8b(c[l+2356>>2]|0,c[l+2360>>2]|0)|0);l$b(k,c[l+2356>>2]|0);if((c[k+114284>>2]|0)==1){Lbc(k);Mbc(k)}Lbc(k);Nbc(j);n=0;while(1){if((n|0)>=(c[l+2328>>2]|0)){break}mrc(l+5800|0,0,9)|0;Obc(k,l,n,b,m,f,g|0,h);o=b+3112|0;c[o>>2]=(c[o>>2]|0)+((c[b+3076>>2]<<4)-(c[l+2332>>2]<<4));o=b+3116|0;c[o>>2]=(c[o>>2]|0)+((c[b+3096>>2]<<3)-(c[l+2332>>2]<<3));o=b+3120|0;c[o>>2]=(c[o>>2]|0)+((c[b+3096>>2]<<3)-(c[l+2332>>2]<<3));n=n+1|0}c[k+114732>>2]=((c[f>>2]|0)-(c[k+114728>>2]|0)|0)/8|0;Pbc(j);f=Qbc(j)|0;j=k+142992|0;n=wrc(c[j>>2]|0,c[j+4>>2]|0,f,G)|0;c[j>>2]=n;c[j+4>>2]=G;do{if((d[m+3092|0]|0|0)!=0){if((d[m+3093|0]|0|0)==0){break}mrc(m+3096|0,-1|0,3)|0;j=(c[g>>2]|0)+(c[g+4>>2]|0)+(c[g+8>>2]|0)+(c[g+12>>2]|0)|0;if((j|0)!=0){a[m+3096|0]=(((c[g>>2]|0)+(c[g+4>>2]|0)|0)*255|0|0)/(j|0)|0;j=(c[g>>2]|0)+(c[g+4>>2]|0)|0;if((j|0)>0){a[m+3097|0]=((c[g>>2]|0)*255|0|0)/(j|0)|0}j=(c[g+8>>2]|0)+(c[g+12>>2]|0)|0;if((j|0)>0){a[m+3098|0]=((c[g+8>>2]|0)*255|0|0)/(j|0)|0}j=0;while(1){if((j|0)>=3){break}if((d[m+3096+j|0]|0|0)==0){a[m+3096+j|0]=1}j=j+1|0}}}}while(0);c[k+131484>>2]=c[h>>2]>>8;if((c[l+2312>>2]|0)==0){c[k+142440>>2]=100}else{h=(c[k+101264>>2]|0)+(c[k+101268>>2]|0)+(c[k+101272>>2]|0)+(c[k+101276>>2]|0)|0;if((h|0)!=0){c[k+142440>>2]=((c[k+101264>>2]|0)*100|0|0)/(h|0)|0}}if((c[l+2312>>2]|0)==0){i=e;return}do{if(!((c[k+114288>>2]|0)>>>0>1>>>0)){if((c[l+5764>>2]|0)!=0){i=e;return}if((c[l+5760>>2]|0)==0){break}i=e;return}}while(0);Oac(k);i=e;return}function Lbc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;e=b;b=e+73728|0;f=e+105664|0;g=b+3152|0;c[b+6456>>2]=c[e+149724>>2];c[b+6380>>2]=c[e+149720>>2];c[b+6388>>2]=0;c[b+6320>>2]=c[b+6324>>2];c[g+3032>>2]=c[f+2384>>2];c[g+3036>>2]=c[f+2336>>2];c[g+3040>>2]=c[f+2312>>2];if((c[f+2312>>2]|0)==0){MYb(f)}nrc(b+3060|0,c[e+114504>>2]|0,92)|0;nrc(g+2848|0,f+1816+((c[f+2204>>2]|0)*92|0)|0,92)|0;nrc(g+2940|0,f+1816+((c[f+2200>>2]|0)*92|0)|0,92)|0;spc(f+1816+((c[f+2200>>2]|0)*92|0)|0);Sbc(b);a[c[g+3032>>2]|0]=0;a[(c[g+3032>>2]|0)+1|0]=0;c[g+3088>>2]=f+5800;c[b+6464>>2]=f+7997;mrc(c[f+5796>>2]|0,0,(c[f+2332>>2]|0)*9|0|0)|0;if((c[e+142448>>2]|0)==1){Pac(b+6332|0,c[e+142384>>2]|0,255,128)}else{do{if((c[e+114288>>2]|0)>>>0>1>>>0){if((c[e+142448>>2]|0)!=2){h=8;break}Pac(b+6332|0,c[e+142384>>2]|0,1,255)}else{h=8}}while(0);if((h|0)==8){do{if((c[e+114288>>2]|0)>>>0>1>>>0){if((c[e+142448>>2]|0)!=4){h=11;break}Pac(b+6332|0,c[e+142384>>2]|0,1,1)}else{h=11}}while(0);if((h|0)==11){Pac(b+6332|0,c[e+142384>>2]|0,c[e+142388>>2]|0,c[e+142392>>2]|0)}}}c[g+2844>>2]=-1;if((c[f+2352>>2]|0)==0){j=b;k=j+6500|0;l=k;mrc(l|0,0,4608)|0;m=b;n=m+27484|0;o=n;mrc(o|0,0,20)|0;p=b;q=p+27504|0;r=q;mrc(r|0,0,16)|0;s=b;t=s+27520|0;u=0;v=0;w=t|0;c[w>>2]=u;x=t+4|0;c[x>>2]=v;y=b;z=y+27528|0;A=0;B=0;C=z|0;c[C>>2]=A;D=z+4|0;c[D>>2]=B;E=b;F=E+27536|0;G=F;mrc(G|0,0,16)|0;i=d;return}c[g+2844>>2]=-8;j=b;k=j+6500|0;l=k;mrc(l|0,0,4608)|0;m=b;n=m+27484|0;o=n;mrc(o|0,0,20)|0;p=b;q=p+27504|0;r=q;mrc(r|0,0,16)|0;s=b;t=s+27520|0;u=0;v=0;w=t|0;c[w>>2]=u;x=t+4|0;c[x>>2]=v;y=b;z=y+27528|0;A=0;B=0;C=z|0;c[C>>2]=A;D=z+4|0;c[D>>2]=B;E=b;F=E+27536|0;G=F;mrc(G|0,0,16)|0;i=d;return}function Mbc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+8|0;d=b|0;e=a;a=e+73728|0;f=a+3152|0;g=e+105664|0;h=g+1816+((c[g+2200>>2]|0)*92|0)|0;j=c[h+16>>2]|0;c[d>>2]=0;c[d+4>>2]=0;k=0;while(1){if((k|0)>=(c[g+2328>>2]|0)){break}c[f+3044>>2]=(k|0)!=0;l=(ca(k,j)|0)<<4;m=0;while(1){if((m|0)>=(c[g+2332>>2]|0)){break}c[f+2992>>2]=(c[h+52>>2]|0)+l;c[f+3048>>2]=(m|0)!=0;l=l+16|0;O8b(c[a+3112>>2]|0,c[a+3076>>2]|0,a+1600|0,16);n=Ybc(e,a,k,m)|0;o=wrc(c[d>>2]|0,c[d+4>>2]|0,n,0)|0;c[d>>2]=o;c[d+4>>2]=G;c[c[a+6380>>2]>>2]=n;n=a+6380|0;c[n>>2]=(c[n>>2]|0)+4;n=a+3112|0;c[n>>2]=(c[n>>2]|0)+16;m=m+1|0}m=a+3112|0;c[m>>2]=(c[m>>2]|0)+((c[a+3076>>2]<<4)-(c[g+2332>>2]<<4));bpc(h,(c[f+2992>>2]|0)+16|0,(c[f+2996>>2]|0)+8|0,(c[f+3e3>>2]|0)+8|0);k=k+1|0}Zbc(e,c[d>>2]|0,c[d+4>>2]|0);i=b;return}function Nbc(a){a=a|0;var b=0;b=i;jd(a|0,0)|0;i=b;return}function Obc(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;m=i;n=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=c[b+2204>>2]|0;o=c[b+2200>>2]|0;p=c[b+1816+(l*92|0)+16>>2]|0;q=c[b+1816+(l*92|0)+36>>2]|0;l=ca(e,c[n+107996>>2]|0)|0;c[g+3084>>2]=c[b+5796>>2];c[g+3044>>2]=(e|0)!=0;r=(ca(e,p)|0)<<4;p=(ca(e,q)|0)<<3;c[(c[n+142660>>2]|0)+(e<<3)>>2]=c[h>>2];c[g+3136>>2]=-(e<<4<<3);c[g+3140>>2]=(c[b+2328>>2]|0)-1-e<<4<<3;c[f+6440>>2]=-((e<<4)+16|0);c[f+6444>>2]=((c[b+2328>>2]|0)-1-e<<4)+16;c[f+6380>>2]=(c[n+149720>>2]|0)+(l<<2);q=0;while(1){if((q|0)>=(c[b+2332>>2]|0)){break}c[g+3128>>2]=-(q<<4<<3);c[g+3132>>2]=(c[b+2332>>2]|0)-1-q<<4<<3;c[f+6432>>2]=-((q<<4)+16|0);c[f+6436>>2]=((c[b+2332>>2]|0)-1-q<<4)+16;c[g+2992>>2]=(c[b+1816+(o*92|0)+52>>2]|0)+r;c[g+2996>>2]=(c[b+1816+(o*92|0)+56>>2]|0)+p;c[g+3e3>>2]=(c[b+1816+(o*92|0)+60>>2]|0)+p;c[g+3048>>2]=(q|0)!=0;c[f+6372>>2]=c[n+114920>>2];c[f+6376>>2]=c[n+114916>>2];O8b(c[f+3112>>2]|0,c[f+3076>>2]|0,f+1600|0,16);if((c[n+114284>>2]|0)==1){Ibc(n,f)}if((a[g+3092|0]|0)!=0){if((d[(c[n+142600>>2]|0)+(l+q)|0]|0)<=3){a[(c[g+3032>>2]|0)+11|0]=a[(c[n+142600>>2]|0)+(l+q)|0]|0}else{a[(c[g+3032>>2]|0)+11|0]=0}W_b(n,f,1)}else{a[(c[g+3032>>2]|0)+11|0]=0}c[f+6460>>2]=(c[n+142628>>2]|0)+l+q;if((c[b+2312>>2]|0)==0){s=Tbc(n,f,h)|0;t=k;c[t>>2]=(c[t>>2]|0)+s}else{s=Wbc(n,f,h,r,p,e,q)|0;t=k;c[t>>2]=(c[t>>2]|0)+s;do{if((c[n+150216>>2]|0)==0){if((c[n+142636>>2]|0)==0){break}if((d[g+3092|0]|0)==0){break}a[(c[n+142600>>2]|0)+(l+q)|0]=a[(c[g+3032>>2]|0)+11|0]|0;if((a[(c[g+3032>>2]|0)+11|0]|0)!=0){a[(c[n+142652>>2]|0)+(l+q)|0]=-1}else{do{if((d[c[g+3032>>2]|0]|0)==7){if((d[(c[g+3032>>2]|0)+2|0]|0)!=1){u=23;break}if((a[(c[n+142652>>2]|0)+(l+q)|0]|0)==1){a[(c[n+142652>>2]|0)+(l+q)|0]=0}}else{u=23}}while(0);if((u|0)==23){u=0;a[(c[n+142652>>2]|0)+(l+q)|0]=1}}}}while(0)}c[(c[n+142660>>2]|0)+(e<<3)+4>>2]=c[h>>2];s=f+6456|0;c[s>>2]=(c[s>>2]|0)+1;s=f+6380|0;c[s>>2]=(c[s>>2]|0)+4;s=f+3112|0;c[s>>2]=(c[s>>2]|0)+16;s=f+3116|0;c[s>>2]=(c[s>>2]|0)+8;s=f+3120|0;c[s>>2]=(c[s>>2]|0)+8;r=r+16|0;p=p+8|0;s=j+(d[(c[g+3032>>2]|0)+11|0]<<2)|0;c[s>>2]=(c[s>>2]|0)+1;s=g+3032|0;c[s>>2]=(c[s>>2]|0)+76;s=f+6320|0;c[s>>2]=(c[s>>2]|0)+132;s=g+3084|0;c[s>>2]=(c[s>>2]|0)+9;q=q+1|0}bpc(b+1816+(o*92|0)|0,(c[g+2992>>2]|0)+16|0,(c[g+2996>>2]|0)+8|0,(c[g+3e3>>2]|0)+8|0);o=g+3032|0;c[o>>2]=(c[o>>2]|0)+76;o=f+6320|0;c[o>>2]=(c[o>>2]|0)+132;i=m;return}function Pbc(a){a=a|0;var b=0;b=i;jd(a+8|0,0)|0;i=b;return}function Qbc(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;e=a;c[d>>2]=(c[e+8>>2]|0)-(c[e>>2]|0);a=(c[e+12>>2]|0)-(c[e+4>>2]|0)|0;c[d+4>>2]=a;if((a|0)<0){a=d+4|0;c[a>>2]=(c[a>>2]|0)+1e6;a=d|0;e=c[a>>2]|0;c[a>>2]=e-1;f=(e|0)!=0}else{f=0}f=((c[d>>2]|0)*1e6|0)+(c[d+4>>2]|0)|0;i=b;return(G=(f|0)<0|0?-1:0,f)|0}function Rbc(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=0;while(1){if((a|0)>=4){break}e=0;while(1){if((e|0)>=4){break}c[d+1860+(((a<<2)+e|0)*48|0)>>2]=d+(a<<2<<4<<1)+(e<<2<<1);e=e+1|0}a=a+1|0}a=0;while(1){if((a|0)>=2){break}e=0;while(1){if((e|0)>=2){break}c[d+1860+(((a<<1)+16+e|0)*48|0)>>2]=d+512+(a<<2<<3<<1)+(e<<2<<1);e=e+1|0}a=a+1|0}a=0;while(1){if((a|0)>=2){break}e=0;while(1){if((e|0)>=2){break}c[d+1860+(((a<<1)+20+e|0)*48|0)>>2]=d+640+(a<<2<<3<<1)+(e<<2<<1);e=e+1|0}a=a+1|0}c[d+3012>>2]=d+768;a=0;while(1){if((a|0)>=25){break}c[d+1860+(a*48|0)+4>>2]=d+800+(a<<4<<1);a=a+1|0}i=b;return}function Sbc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=0;RYb(d+3152|0);c[d+1856>>2]=d+1600;e=0;while(1){if((e|0)>=4){break}f=0;while(1){if((f|0)>=4){break}g=d+1860+(a*48|0)|0;c[g+36>>2]=d+1856;c[g+44>>2]=16;c[g+40>>2]=(e<<2<<4)+(f<<2);a=a+1|0;f=f+1|0}e=e+1|0}e=0;while(1){if((e|0)>=2){break}f=0;while(1){if((f|0)>=2){break}g=d+1860+(a*48|0)|0;c[g+36>>2]=d+3116;c[g+44>>2]=c[d+3096>>2];c[g+40>>2]=(ca(e<<2,c[g+44>>2]|0)|0)+(f<<2);a=a+1|0;f=f+1|0}e=e+1|0}e=0;while(1){if((e|0)>=2){break}f=0;while(1){if((f|0)>=2){break}g=d+1860+(a*48|0)|0;c[g+36>>2]=d+3120;c[g+44>>2]=c[d+3096>>2];c[g+40>>2]=(ca(e<<2,c[g+44>>2]|0)|0)+(f<<2);a=a+1|0;f=f+1|0}e=e+1|0}i=b;return}function Tbc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=a;a=b;b=e;e=a+3152|0;do{if((c[h+142452>>2]|0)!=0){if((c[h+142360>>2]|0)==2){j=4;break}O$b(a,g)}else{j=4}}while(0);if((j|0)==4){y_b(a,g)}if((c[h+114284>>2]|0)==1){Jbc(h,a);X_b(h,a)}if((d[c[a+6184>>2]|0]|0|0)==4){dcc(a)}else{acc(a)}fcc(a);Ubc(h,a);n0b(h,a,b);if((d[c[e+3032>>2]|0]|0|0)!=4){Vbc(e)}rpc(e+896|0,e+2112|0,c[e+2996>>2]|0,c[e+3e3>>2]|0,c[e+2976>>2]|0,e+2e3|0);i=f;return c[g>>2]|0}function Ubc(a,b){a=a|0;b=b|0;var e=0,f=0;a=b;b=a+3152|0;e=d[(c[b+3032>>2]|0)+1|0]|0;f=a+27484+((d[c[b+3032>>2]|0]|0)<<2)|0;c[f>>2]=(c[f>>2]|0)+1;f=a+27504+(e<<2)|0;c[f>>2]=(c[f>>2]|0)+1;i=i;return}function Vbc(b){b=b|0;var e=0,f=0;e=i;f=b;b=f+2016|0;if((d[c[f+3032>>2]|0]|0)!=9){if((a[f+2008|0]|0)>1){e8b(c[f+2820>>2]|0,f+384|0)}else{f8b(c[f+2820>>2]|0,f+384|0)}Xbc(f+1984|0,f+384|0);b=f+2048|0}qpc(f+384|0,b,c[f+2992>>2]|0,c[f+2956>>2]|0,f+1984|0);i=e;return}function Wbc(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;l=i;i=i+24|0;m=l|0;n=l+8|0;o=l+16|0;p=b;b=e;e=f;f=g;g=h;h=j;j=k;k=b+3152|0;c[m>>2]=0;c[b+6448>>2]=0;if((a[k+3092|0]|0)!=0){c[b+6452>>2]=c[p+142612+(d[(c[k+3032>>2]|0)+11|0]<<2)>>2]}else{c[b+6452>>2]=c[p+114252>>2]}c[b+6484>>2]=0;c[b+6488>>2]=0;c[b+6476>>2]=0;c[b+6480>>2]=0;a[b+6492|0]=0;if((c[p+142452>>2]|0)!=0){q=c[b+27796>>2]|0;if((c[p+142580>>2]|0)!=0){c[b+31924>>2]=186;c[b+31928>>2]=822;c[b+27796>>2]=0}C$b(p,b,f,g,n,o,m);if((c[p+142460>>2]|0)!=0){c[b+31924>>2]=260;c[b+31928>>2]=366}c[b+27796>>2]=q}else{q_b(p,b,f,g,n,o,m,h,j)}j=c[o>>2]|0;o=b+27520|0;h=wrc(c[o>>2]|0,c[o+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[o>>2]=h;c[o+4>>2]=G;o=c[m>>2]|0;m=b+27528|0;h=wrc(c[m>>2]|0,c[m+4>>2]|0,o,(o|0)<0|0?-1:0)|0;c[m>>2]=h;c[m+4>>2]=G;if((c[p+114284>>2]|0)==1){Jbc(p,b)}if((a[k+3092|0]|0)!=0){do{if((c[p+150216>>2]|0)==0){if((c[p+142636>>2]|0)==0){break}do{if((d[(c[k+3032>>2]|0)+11|0]|0)==1){if((d[(c[k+3032>>2]|0)+2|0]|0)==1){if((d[c[k+3032>>2]|0]|0)==7){break}}a[(c[k+3032>>2]|0)+11|0]=0;W_b(p,b,1)}}while(0)}}while(0)}c[b+27800>>2]=0;if((c[b+27796>>2]|0)!=0){if((d[(c[k+3032>>2]|0)+2|0]|0)!=0){if((d[c[k+3032>>2]|0]|0)==7){do{if((d[(c[k+3032>>2]|0)+2|0]|0)!=1){if((c[p+114288>>2]|0)!=1){r=28;break}c[b+27800>>2]=12}else{r=28}}while(0);if((r|0)==28){c[b+27800>>2]=6}}else{if((d[c[k+3032>>2]|0]|0)==9){c[b+27800>>2]=0}else{c[b+27800>>2]=4}}}}if((c[p+142460>>2]|0)!=0){X_b(p,b)}r=b+27536+(d[(c[k+3032>>2]|0)+2|0]<<2)|0;c[r>>2]=(c[r>>2]|0)+1;if((d[(c[k+3032>>2]|0)+2|0]|0)==0){fcc(b);if((d[c[k+3032>>2]|0]|0)==4){dcc(b)}else{acc(b)}Ubc(p,b)}else{if((d[(c[k+3032>>2]|0)+2|0]|0)==1){s=c[p+107868>>2]|0}else{if((d[(c[k+3032>>2]|0)+2|0]|0)==2){s=c[p+107872>>2]|0}else{s=c[p+107876>>2]|0}}c[k+2900>>2]=(c[p+107480+(s*92|0)+52>>2]|0)+f;c[k+2904>>2]=(c[p+107480+(s*92|0)+56>>2]|0)+g;c[k+2908>>2]=(c[p+107480+(s*92|0)+60>>2]|0)+g;if((c[b+6448>>2]|0)!=0){W8b(k,c[k+2992>>2]|0,c[k+2996>>2]|0,c[k+3e3>>2]|0,c[k+2956>>2]|0,c[k+2976>>2]|0)}else{rcc(b)}}if((c[b+6448>>2]|0)==0){n0b(p,b,e);if((d[c[k+3032>>2]|0]|0)!=4){Vbc(k)}rpc(k+896|0,k+2112|0,c[k+2996>>2]|0,c[k+3e3>>2]|0,c[k+2976>>2]|0,k+2e3|0);t=c[n>>2]|0;i=l;return t|0}a[(c[k+3032>>2]|0)+9|0]=1;if((c[p+108004>>2]|0)!=0){g=b+6496|0;c[g>>2]=(c[g>>2]|0)+1;q0b(k)}else{p0b(p,b,e)}t=c[n>>2]|0;i=l;return t|0}function Xbc(c,d){c=c|0;d=d|0;var e=0,f=0,g=0;e=i;f=c;c=d;d=0;while(1){if((d|0)>=16){break}do{if((a[f+d|0]|0)==0){if((b[c>>1]|0)==0){break}g=f+d|0;a[g]=(a[g]|0)+1}}while(0);c=c+32|0;d=d+1|0}i=e;return}function Ybc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=c;c=d;if((c|0)!=0){g=3}else{if((b|0)!=0){g=3}else{h=0}}if((g|0)==3){if((c|0)!=0){j=(b|0)!=0^1}else{j=1}h=j}j=_bc(f,a,h&1)|0;if(!(j>>>0<64>>>0)){k=j;i=e;return k|0}j=64;k=j;i=e;return k|0}function Zbc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=a;c[f>>2]=b;c[f+4>>2]=d;d=c[g+107988>>2]|0;b=Crc(c[f>>2]|0,c[f+4>>2]|0,d,(d|0)<0|0?-1:0)|0;c[g+149716>>2]=b;if(!((c[g+149716>>2]|0)>>>0<64>>>0)){h=g;j=h+149716|0;c[j>>2]=1e5;i=e;return}c[g+149716>>2]=64;h=g;j=h+149716|0;c[j>>2]=1e5;i=e;return}function _bc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=$bc(a,b,c)|0;i=d;return e|0}function $bc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;b=i;f=d;d=0;if((e|0)!=0){a[c[f+6184>>2]|0]=0;a[(c[f+6184>>2]|0)+1|0]=0;a[(c[f+6184>>2]|0)+2|0]=0;acc(f);bcc(f+3152|0);g=f;h=g|0;j=h|0;k=A9b(j)|0;d=k;l=d;i=b;return l|0}e=0;while(1){if((e|0)>=16){break}c[f+5296+(e*28|0)+24>>2]=0;ccc(f,e);e=e+1|0}g=f;h=g|0;j=h|0;k=A9b(j)|0;d=k;l=d;i=b;return l|0}function acc(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=d+1860|0;e=d+3152|0;c9b(e,(c[e+2992>>2]|0)+(-(c[e+2956>>2]|0)|0)|0,(c[e+2992>>2]|0)-1|0,c[e+2956>>2]|0,c[e+2992>>2]|0,c[e+2956>>2]|0);jcc(d|0,c[c[a+36>>2]>>2]|0,c[a+44>>2]|0,c[e+2992>>2]|0,c[e+2956>>2]|0);lcc(d);P_b(d);if((c[d+6468>>2]|0)==0){i=b;return}ncc(d);i=b;return}function bcc(b){b=b|0;var e=0,f=0;e=i;f=b;b=f+2016|0;if((d[c[f+3032>>2]|0]|0)!=9){if((a[f+2008|0]|0)>1){e8b(c[f+2820>>2]|0,f+384|0)}else{f8b(c[f+2820>>2]|0,f+384|0)}gcc(f+1984|0,f+384|0);b=f+2048|0}qpc(f+384|0,b,c[f+2992>>2]|0,c[f+2956>>2]|0,f+1984|0);i=e;return}function ccc(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=d;d=e;e=g+5296+(d*28|0)|0;h=g+1860+(d*48|0)|0;d=c[g+6108>>2]|0;j=(c[g+6144>>2]|0)+(c[e+16>>2]|0)|0;k=j+(-d|0)|0;e9b(k,j-1|0,d,c[e+24>>2]|0,c[e+8>>2]|0,16,a[k-1|0]|0);hcc(h,e,16);ef[c[g+31912>>2]&4095](c[h>>2]|0,c[h+4>>2]|0,32);re[c[g+31924>>2]&1023](h,e);if((a[c[e+20>>2]|0]|0)>1){c8b(c[e+4>>2]|0,c[e+8>>2]|0,16,j,d);i=f;return}else{d8b(b[c[e+4>>2]>>1]|0,c[e+8>>2]|0,16,j,d);i=f;return}}function dcc(a){a=a|0;var b=0,d=0;b=i;d=a;a=d+3152|0;ecc(a,(c[a+2992>>2]|0)+(-(c[a+2956>>2]|0)|0)+16|0);a=0;while(1){if((a|0)>=16){break}ccc(d,a);a=a+1|0}i=b;return}function ecc(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;a=c[d+2956>>2]|0;e=(c[d+2992>>2]|0)+(-a|0)+16|0;d=b;c[e+(a<<2)>>2]=c[d>>2];c[e+(a<<3)>>2]=c[d>>2];c[e+(a*12|0)>>2]=c[d>>2];i=i;return}function fcc(a){a=a|0;var b=0,d=0;b=i;d=a;a=d+3152|0;d9b(a,(c[a+2996>>2]|0)+(-(c[a+2976>>2]|0)|0)|0,(c[a+3e3>>2]|0)+(-(c[a+2976>>2]|0)|0)|0,(c[a+2996>>2]|0)-1|0,(c[a+3e3>>2]|0)-1|0,c[a+2976>>2]|0,c[a+2996>>2]|0,c[a+3e3>>2]|0,c[a+2976>>2]|0);icc(d|0,c[d+3116>>2]|0,c[d+3120>>2]|0,c[d+3096>>2]|0,c[a+2996>>2]|0,c[a+3e3>>2]|0,c[a+2976>>2]|0);kcc(d);R_b(d);if((c[d+6468>>2]|0)==0){i=b;return}qcc(d);i=b;return}function gcc(c,d){c=c|0;d=d|0;var e=0,f=0,g=0;e=i;f=c;c=d;d=0;while(1){if((d|0)>=16){break}do{if((a[f+d|0]|0)==0){if((b[c>>1]|0)==0){break}g=f+d|0;a[g]=(a[g]|0)+1}}while(0);c=c+32|0;d=d+1|0}i=e;return}function hcc(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=a;a=f;f=(c[c[h+36>>2]>>2]|0)+(c[h+40>>2]|0)|0;j=c[h>>2]|0;k=c[e+8>>2]|0;e=c[h+44>>2]|0;h=0;while(1){if((h|0)>=4){break}l=0;while(1){if((l|0)>=4){break}b[j+(l<<1)>>1]=(d[f+l|0]|0)-(d[k+l|0]|0);l=l+1|0}j=j+(a<<1)|0;k=k+a|0;f=f+e|0;h=h+1|0}i=g;return}function icc(a,c,e,f,g,h,j){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0;k=i;l=a;a=c;c=e;e=f;f=g;g=h;h=j;j=l+512|0;m=l+640|0;l=0;while(1){if((l|0)>=8){break}n=0;while(1){if((n|0)>=8){break}b[j+(n<<1)>>1]=(d[a+n|0]|0)-(d[f+n|0]|0);n=n+1|0}j=j+16|0;f=f+h|0;a=a+e|0;l=l+1|0}l=0;while(1){if((l|0)>=8){break}n=0;while(1){if((n|0)>=8){break}b[m+(n<<1)>>1]=(d[c+n|0]|0)-(d[g+n|0]|0);n=n+1|0}m=m+16|0;g=g+h|0;c=c+e|0;l=l+1|0}i=k;return}function jcc(a,c,e,f,g){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;j=a;a=c;c=e;e=f;f=g;g=0;while(1){if((g|0)>=16){break}k=0;while(1){if((k|0)>=16){break}b[j+(k<<1)>>1]=(d[a+k|0]|0)-(d[e+k|0]|0);k=k+1|0}j=j+32|0;e=e+f|0;a=a+c|0;g=g+1|0}i=h;return}function kcc(a){a=a|0;var b=0,d=0;b=i;d=a;a=16;while(1){if((a|0)>=24){break}ef[c[d+31916>>2]&4095](c[d+1860+(a*48|0)>>2]|0,c[d+1860+(a*48|0)+4>>2]|0,16);a=a+2|0}i=b;return}function lcc(a){a=a|0;var b=0,d=0;b=i;d=a;a=0;while(1){if((a|0)>=16){break}ef[c[d+31916>>2]&4095](c[d+1860+(a*48|0)>>2]|0,c[d+1860+(a*48|0)+4>>2]|0,32);a=a+2|0}mcc(d);ef[c[d+31920>>2]&4095](c[d+3012>>2]|0,c[d+3016>>2]|0,8);i=b;return}function mcc(a){a=a|0;var c=0,d=0,e=0;c=i;d=a;a=d+768|0;e=0;while(1){if((e|0)>=16){break}b[a+(e<<1)>>1]=b[d+800+(e<<4<<1)>>1]|0;e=e+1|0}i=c;return}function ncc(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+32|0;e=b|0;f=b+16|0;g=a;if((c[g+6236>>2]|0)==0){i=b;return}if((c[g+6240>>2]|0)==0){i=b;return}nrc(e|0,c[g+6236>>2]|0,9)|0;nrc(f|0,c[g+6240>>2]|0,9)|0;a=e;e=f;if((d[c[g+6184>>2]|0]|0|0)!=4){h=(d[c[g+6184>>2]|0]|0|0)!=9}else{h=0}f=h&1;h=(f|0)!=0?0:3;j=0;while(1){if((j|0)>=16){break}occ(g,j,h,a+(d[246856+j|0]|0)|0,e+(d[246824+j|0]|0)|0);j=j+1|0}if((f|0)==0){i=b;return}j=24;occ(g,j,1,a+(d[246856+j|0]|0)|0,e+(d[246824+j|0]|0)|0);pcc(g+3152|0,1,a+(d[246856+j|0]|0)|0,e+(d[246824+j|0]|0)|0);i=b;return}function occ(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;k=i;i=i+416|0;l=k|0;m=k+408|0;n=e;e=f;f=g;g=h;h=j;j=0;o=n+5296+(e*28|0)|0;p=c[o+12>>2]|0;q=c[n+1860+(e*48|0)+4>>2]|0;e=c[o>>2]|0;r=c[o+4>>2]|0;s=((f|0)!=0^1)&1;t=a[c[o+20>>2]|0]|0;u=ca(c[n+6376>>2]|0,c[704240+(f<<2)>>2]|0)|0;if((d[(c[n+6184>>2]|0)+2|0]|0)==0){u=(u*9|0)>>4}v=c[n+6372>>2]|0;c[m+4>>2]=0;c[m>>2]=0;c[l+(t*24|0)>>2]=0;c[l+(t*24|0)+4>>2]=0;a[l+(t*24|0)+8|0]=16;a[l+(t*24|0)+9|0]=11;b[l+(t*24|0)+10>>1]=0;w=l+(t*24|0)+12|0;x=l+(t*24|0)|0;c[w>>2]=c[x>>2];c[w+4>>2]=c[x+4>>2];c[w+8>>2]=c[x+8>>2];x=t;w=t;while(1){y=w;w=y-1|0;if((y|0)<=(s|0)){break}z=c[245048+(w<<2)>>2]|0;A=b[e+(z<<1)>>1]|0;if((A|0)!=0){y=0;B=c[l+(x*24|0)+4>>2]|0;C=c[l+(x*24|0)+16>>2]|0;D=c[l+(x*24|0)>>2]|0;E=c[l+(x*24|0)+12>>2]|0;F=b[(c[61288]|0)+(A<<2)>>1]|0;if((x|0)<16){G=d[w+246689|0]|0;H=d[239776+F|0]|0;D=D+(c[(c[n+6428>>2]|0)+(f*1152|0)+(G*144|0)+(H*48|0)+(a[l+(x*24|0)+9|0]<<2)>>2]|0)|0;E=E+(c[(c[n+6428>>2]|0)+(f*1152|0)+(G*144|0)+(H*48|0)+(a[l+(x*24|0)+21|0]<<2)>>2]|0)|0}I=((ca(D,u)|0)+128>>8)+(ca(v,B)|0)|0;J=((ca(E,u)|0)+128>>8)+(ca(v,C)|0)|0;if((I|0)==(J|0)){I=(ca(D,u)|0)+128&255;J=(ca(E,u)|0)+128&255}K=(J|0)<(I|0)|0;L=b[(c[61290]|0)+(A<<1)>>1]|0;M=(b[r+(z<<1)>>1]|0)-(b[q+(z<<1)>>1]|0)|0;N=ca(M,M)|0;if((K|0)!=0){O=E}else{O=D}c[l+(w*24|0)>>2]=L+O;if((K|0)!=0){P=C}else{P=B}c[l+(w*24|0)+4>>2]=N+P;a[l+(w*24|0)+8|0]=x;a[l+(w*24|0)+9|0]=F;b[l+(w*24|0)+10>>1]=A;Q=m|0;c[Q>>2]=c[Q>>2]|K<<w;D=c[l+(x*24|0)>>2]|0;E=c[l+(x*24|0)+12>>2]|0;Q=R(A|0)|0;S=ca(Q,b[p+(z<<1)>>1]|0)|0;do{if((S|0)>(R(b[q+(z<<1)>>1]|0)|0)){Q=R(A|0)|0;T=ca(Q,b[p+(z<<1)>>1]|0)|0;Q=R(b[q+(z<<1)>>1]|0)|0;if((T|0)>=(Q+(b[p+(z<<1)>>1]|0)|0)){U=19;break}y=1}else{U=19}}while(0);if((U|0)==19){U=0;y=0}if((y|0)!=0){j=-((A|0)<0|0)|0;A=A-((j<<1)+1)|0}if((A|0)!=0){S=b[(c[61288]|0)+(A<<2)>>1]|0;V=S;F=S}else{F=(a[l+(x*24|0)+9|0]|0)==11?11:0;V=(a[l+(x*24|0)+21|0]|0)==11?11:0}if((x|0)<16){G=d[w+246689|0]|0;if((F|0)!=11){H=d[239776+F|0]|0;D=D+(c[(c[n+6428>>2]|0)+(f*1152|0)+(G*144|0)+(H*48|0)+(a[l+(x*24|0)+9|0]<<2)>>2]|0)|0}if((V|0)!=11){H=d[239776+V|0]|0;E=E+(c[(c[n+6428>>2]|0)+(f*1152|0)+(G*144|0)+(H*48|0)+(a[l+(x*24|0)+21|0]<<2)>>2]|0)|0}}I=((ca(D,u)|0)+128>>8)+(ca(v,B)|0)|0;J=((ca(E,u)|0)+128>>8)+(ca(v,C)|0)|0;if((I|0)==(J|0)){I=(ca(D,u)|0)+128&255;J=(ca(E,u)|0)+128&255}K=(J|0)<(I|0)|0;L=b[(c[61290]|0)+(A<<1)>>1]|0;if((y|0)!=0){M=M-((b[p+(z<<1)>>1]|0)+j^j)|0;N=ca(M,M)|0}if((K|0)!=0){W=E}else{W=D}c[l+(w*24|0)+12>>2]=L+W;if((K|0)!=0){X=C}else{X=B}c[l+(w*24|0)+16>>2]=N+X;a[l+(w*24|0)+20|0]=x;if((K|0)!=0){Y=V}else{Y=F}a[l+(w*24|0)+21|0]=Y;b[l+(w*24|0)+22>>1]=A;S=m+4|0;c[S>>2]=c[S>>2]|K<<w;x=w}else{G=d[w+246689|0]|0;F=a[l+(x*24|0)+9|0]|0;V=a[l+(x*24|0)+21|0]|0;if((F|0)!=11){S=l+(x*24|0)|0;c[S>>2]=(c[S>>2]|0)+(c[(c[n+6428>>2]|0)+(f*1152|0)+(G*144|0)+(F<<2)>>2]|0);a[l+(x*24|0)+9|0]=0}if((V|0)!=11){S=l+(x*24|0)+12|0;c[S>>2]=(c[S>>2]|0)+(c[(c[n+6428>>2]|0)+(f*1152|0)+(G*144|0)+(V<<2)>>2]|0);a[l+(x*24|0)+21|0]=0}}}G=d[w+246689|0]|0;H=(a[g]|0)+(a[h]|0)|0;D=c[l+(x*24|0)>>2]|0;E=c[l+(x*24|0)+12>>2]|0;B=c[l+(x*24|0)+4>>2]|0;C=c[l+(x*24|0)+16>>2]|0;F=a[l+(x*24|0)+9|0]|0;V=a[l+(x*24|0)+21|0]|0;D=D+(c[(c[n+6428>>2]|0)+(f*1152|0)+(G*144|0)+(H*48|0)+(F<<2)>>2]|0)|0;E=E+(c[(c[n+6428>>2]|0)+(f*1152|0)+(G*144|0)+(H*48|0)+(V<<2)>>2]|0)|0;I=((ca(D,u)|0)+128>>8)+(ca(v,B)|0)|0;J=((ca(E,u)|0)+128>>8)+(ca(v,C)|0)|0;if((I|0)==(J|0)){I=(ca(D,u)|0)+128&255;J=(ca(E,u)|0)+128&255}K=(J|0)<(I|0)|0;I=s-1|0;w=x;while(1){if((w|0)>=(t|0)){break}A=b[l+(w*24|0)+(K*12|0)+10>>1]|0;if((A|0)!=0){I=w}z=c[245048+(w<<2)>>2]|0;b[e+(z<<1)>>1]=A;b[r+(z<<1)>>1]=ca(A,b[p+(z<<1)>>1]|0)|0;x=a[l+(w*24|0)+(K*12|0)+8|0]|0;K=(c[m+(K<<2)>>2]|0)>>>(w>>>0)&1;w=x}I=I+1|0;x=(I|0)!=(((f|0)!=0^1)&1|0)&255;a[h]=x;a[g]=x;a[c[o+20>>2]|0]=I;i=k;return}function pcc(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=e;e=f;f=g;g=0;k=d+2816|0;do{if((b[c[k+12>>2]>>1]|0)>=35){if((b[(c[k+12>>2]|0)+2>>1]|0)<35){break}i=h;return}}while(0);d=0;while(1){if((d|0)>=(a[c[k+20>>2]|0]|0)){break}l=b[(c[k+4>>2]|0)+(c[245048+(d<<2)>>2]<<1)>>1]|0;if((l|0)>=0){m=l}else{m=-l|0}g=g+m|0;if((g|0)>=35){n=10;break}d=d+1|0}if((n|0)==10){i=h;return}if((g|0)>=35){i=h;return}d=0;while(1){if((d|0)>=(a[c[k+20>>2]|0]|0)){break}g=c[245048+(d<<2)>>2]|0;b[(c[k>>2]|0)+(g<<1)>>1]=0;b[(c[k+4>>2]|0)+(g<<1)>>1]=0;d=d+1|0}a[c[k+20>>2]|0]=0;d=(a[c[k+20>>2]|0]|0)!=(((j|0)!=0^1)&1|0)&255;a[f]=d;a[e]=d;i=h;return}function qcc(a){a=a|0;var b=0,e=0,f=0,g=0;b=i;i=i+32|0;e=b|0;f=b+16|0;g=a;if((c[g+6236>>2]|0)==0){i=b;return}if((c[g+6240>>2]|0)==0){i=b;return}nrc(e|0,c[g+6236>>2]|0,9)|0;nrc(f|0,c[g+6240>>2]|0,9)|0;a=e;e=f;f=16;while(1){if((f|0)>=24){break}occ(g,f,2,a+(d[246856+f|0]|0)|0,e+(d[246824+f|0]|0)|0);f=f+1|0}i=b;return}function rcc(a){a=a|0;var b=0,d=0;b=i;d=a;Y8b(d+3152|0);scc(d);tcc(d);Q_b(d);if((c[d+6468>>2]|0)==0){i=b;return}ucc(d);i=b;return}function scc(a){a=a|0;var b=0,d=0;b=i;d=a;a=d+1860|0;jcc(d|0,c[c[a+36>>2]>>2]|0,c[a+44>>2]|0,c[d+6144>>2]|0,c[d+6108>>2]|0);icc(d|0,c[d+3116>>2]|0,c[d+3120>>2]|0,c[d+3096>>2]|0,c[d+6148>>2]|0,c[d+6152>>2]|0,c[d+6128>>2]|0);i=b;return}function tcc(a){a=a|0;var b=0,e=0;b=i;e=a;a=0;while(1){if((a|0)>=16){break}ef[c[e+31916>>2]&4095](c[e+1860+(a*48|0)>>2]|0,c[e+1860+(a*48|0)+4>>2]|0,32);a=a+2|0}if((d[c[e+6184>>2]|0]|0|0)!=9){mcc(e)}a=16;while(1){if((a|0)>=24){break}ef[c[e+31916>>2]&4095](c[e+1860+(a*48|0)>>2]|0,c[e+1860+(a*48|0)+4>>2]|0,16);a=a+2|0}if((d[c[e+6184>>2]|0]|0|0)==9){i=b;return}ef[c[e+31920>>2]&4095](c[e+3012>>2]|0,c[e+3016>>2]|0,8);i=b;return}function ucc(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+32|0;e=b|0;f=b+16|0;g=a;nrc(e|0,c[g+6236>>2]|0,9)|0;nrc(f|0,c[g+6240>>2]|0,9)|0;a=e;e=f;if((d[c[g+6184>>2]|0]|0|0)!=4){h=(d[c[g+6184>>2]|0]|0|0)!=9}else{h=0}f=h&1;h=(f|0)!=0?0:3;j=0;while(1){if((j|0)>=16){break}occ(g,j,h,a+(d[246856+j|0]|0)|0,e+(d[246824+j|0]|0)|0);j=j+1|0}j=16;while(1){if((j|0)>=24){break}occ(g,j,2,a+(d[246856+j|0]|0)|0,e+(d[246824+j|0]|0)|0);j=j+1|0}if((f|0)==0){i=b;return}j=24;occ(g,j,1,a+(d[246856+j|0]|0)|0,e+(d[246824+j|0]|0)|0);pcc(g+3152|0,1,a+(d[246856+j|0]|0)|0,e+(d[246824+j|0]|0)|0);i=b;return}function vcc(a){a=a|0;var b=0,d=0;b=i;d=a;a=d+1860|0;V8b(d+3152|0,c[d+6144>>2]|0,c[d+6108>>2]|0);jcc(d|0,c[c[a+36>>2]>>2]|0,c[a+44>>2]|0,c[d+6144>>2]|0,c[d+6108>>2]|0);wcc(d);P_b(d);xcc(d+3152|0);i=b;return}function wcc(a){a=a|0;var b=0,e=0;b=i;e=a;a=0;while(1){if((a|0)>=16){break}ef[c[e+31916>>2]&4095](c[e+1860+(a*48|0)>>2]|0,c[e+1860+(a*48|0)+4>>2]|0,32);a=a+2|0}if((d[c[e+6184>>2]|0]|0|0)==9){i=b;return}mcc(e);ef[c[e+31920>>2]&4095](c[e+3012>>2]|0,c[e+3016>>2]|0,8);i=b;return}function xcc(b){b=b|0;var e=0,f=0;e=i;f=b;b=f+2016|0;if((d[c[f+3032>>2]|0]|0)!=9){if((a[f+2008|0]|0)>1){e8b(c[f+2820>>2]|0,f+384|0)}else{f8b(c[f+2820>>2]|0,f+384|0)}ycc(f+1984|0,f+384|0);b=f+2048|0}qpc(f+384|0,b,c[f+2992>>2]|0,c[f+2956>>2]|0,f+1984|0);i=e;return}function ycc(c,d){c=c|0;d=d|0;var e=0,f=0,g=0;e=i;f=c;c=d;d=0;while(1){if((d|0)>=16){break}do{if((a[f+d|0]|0)==0){if((b[c>>1]|0)==0){break}g=f+d|0;a[g]=(a[g]|0)+1}}while(0);c=c+32|0;d=d+1|0}i=e;return}function zcc(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=c;c=d;Acc(f,b[a>>1]>>1,c|0);Acc(f,b[a+2>>1]>>1,c+19|0);i=e;return}function Acc(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=c|0;if((a|0)<0){g=-a|0}else{g=a}c=g;do{if((c|0)<8){Icc(f,0,d[b|0]|0);Mcc(f,238536,b+2|0,c,3);if((c|0)!=0){break}i=e;return}else{g=0;Icc(f,1,d[b|0]|0);do{Icc(f,c>>g&1,d[b+(g+9)|0]|0);h=g+1|0;g=h;}while((h|0)<3);g=9;do{Icc(f,c>>g&1,d[b+(g+9)|0]|0);h=g-1|0;g=h;}while((h|0)>3);if((c&65520|0)!=0){Icc(f,c>>3&1,d[b+12|0]|0)}}}while(0);Icc(f,(a|0)<0|0,d[b+1|0]|0);i=e;return}function Bcc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=b;b=e;e=1;h=0;j=0;OYb();e=1;if((c[b>>2]|0)!=0){k=Ccc(0,a|0)|0;c[c[g>>2]>>2]=k;do{h=Ccc(e,a|0)|0;c[(c[g>>2]|0)+(e<<2)>>2]=h+(c[238752+((d[a+1|0]|0)<<2)>>2]|0);c[(c[g>>2]|0)+(-e<<2)>>2]=h+(c[238752+(255-(d[a+1|0]|0)<<2)>>2]|0);k=e+1|0;e=k;}while((k|0)<=1023)}e=1;if((c[b+4>>2]|0)==0){i=f;return}b=Ccc(0,a+19|0)|0;c[c[g+4>>2]>>2]=b;do{j=Ccc(e,a+19|0)|0;c[(c[g+4>>2]|0)+(e<<2)>>2]=j+(c[238752+((d[a+20|0]|0)<<2)>>2]|0);c[(c[g+4>>2]|0)+(-e<<2)>>2]=j+(c[238752+(255-(d[a+20|0]|0)<<2)>>2]|0);b=e+1|0;e=b;}while((b|0)<=1023);i=f;return}function Ccc(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=b|0;b=a;do{if((b|0)<8){a=c[238752+((d[f|0]|0)<<2)>>2]|0;g=a+(Lcc(238536,f+2|0,b,3)|0)|0;if((b|0)!=0){break}h=g;j=h;i=e;return j|0}else{a=0;g=c[238752+(255-(d[f|0]|0)<<2)>>2]|0;do{if((b>>a&1|0)!=0){k=255-(d[f+(a+9)|0]|0)|0}else{k=d[f+(a+9)|0]|0}g=g+(c[238752+(k<<2)>>2]|0)|0;l=a+1|0;a=l;}while((l|0)<3);a=9;do{if((b>>a&1|0)!=0){m=255-(d[f+(a+9)|0]|0)|0}else{m=d[f+(a+9)|0]|0}g=g+(c[238752+(m<<2)>>2]|0)|0;l=a-1|0;a=l;}while((l|0)>3);if((b&65520|0)!=0){if((b>>3&1|0)!=0){n=255-(d[f+12|0]|0)|0}else{n=d[f+12|0]|0}g=g+(c[238752+(n<<2)>>2]|0)|0}}}while(0);h=g;j=h;i=e;return j|0}function Dcc(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;e=a;a=e+113728|0;f=e+113661|0;mrc(d|0,0,8)|0;Ecc(a,f|0,245112,242424,e+84836|0,0,d|0);Ecc(a,f+19|0,245131,242443,e+93024|0,1,d+4|0);do{if((c[d>>2]|0)==0){if((c[d+4>>2]|0)!=0){break}i=b;return}}while(0);Bcc(e+80124|0,e+113661|0,d|0);i=b;return}function Ecc(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;i=i+216|0;k=h|0;l=h+8|0;m=h+16|0;n=h+96|0;o=h+128|0;p=h+184|0;q=h+208|0;r=b;b=g;g=j;j=d|0;d=f|0;nrc(p|0,e|0,19)|0;mrc(k|0,0,8)|0;mrc(l|0,0,8)|0;mrc(m|0,0,80)|0;mrc(n|0,0,32)|0;mrc(o|0,0,56)|0;e=c[b+4092>>2]|0;f=k|0;c[f>>2]=(c[f>>2]|0)+e;f=n|0;c[f>>2]=(c[f>>2]|0)+e;e=1;do{f=c[b+(e+1023<<2)>>2]|0;s=c[b+(1023-e<<2)>>2]|0;t=f+s|0;u=e;v=l|0;c[v>>2]=(c[v>>2]|0)+f;f=l+4|0;c[f>>2]=(c[f>>2]|0)+s;if((u|0)<8){s=k|0;c[s>>2]=(c[s>>2]|0)+t;s=n+(u<<2)|0;c[s>>2]=(c[s>>2]|0)+t}else{s=9;f=k+4|0;c[f>>2]=(c[f>>2]|0)+t;do{f=m+(s<<3)+((u>>s&1)<<2)|0;c[f>>2]=(c[f>>2]|0)+t;f=s-1|0;s=f;}while((f|0)>=0)}s=e+1|0;e=s;}while((s|0)<=1023);Fcc(p|0,k|0);Fcc(p+1|0,l|0);e=0;vpc(8,238552,238536,q|0,o|0,n|0,256,1);do{Fcc(p+2+e|0,o+(e<<3)|0);n=e+1|0;e=n;}while((n|0)<7);e=0;do{Fcc(p+9+e|0,m+(e<<3)|0);n=e+1|0;e=n;}while((n|0)<10);e=d;d=e+1|0;Gcc(r,k|0,j|0,a[p|0]|0,a[e]|0,g);e=d;d=e+1|0;Gcc(r,l|0,j+1|0,a[p+1|0]|0,a[e]|0,g);e=p+2|0;l=j+2|0;k=0;do{n=d;d=n+1|0;Gcc(r,o+(k<<3)|0,l+k|0,a[e+k|0]|0,a[n]|0,g);n=k+1|0;k=n;}while((n|0)<7);k=p+9|0;p=j+9|0;j=0;do{e=d;d=e+1|0;Gcc(r,m+(j<<3)|0,p+j|0,a[k+j|0]|0,a[e]|0,g);e=j+1|0;j=e;}while((e|0)<10);i=h;return}function Fcc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=d;d=(c[f>>2]|0)+(c[f+4>>2]|0)|0;if((d|0)==0){i=e;return}g=((((c[f>>2]|0)*255|0)>>>0)/(d>>>0)|0)&-2&255;if((g&255|0)!=0){h=g&255}else{h=1}a[b]=h;i=e;return}function Gcc(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0;j=i;k=b;b=d;d=e;e=f;f=g;g=Hcc(b,a[d]|0)|0;l=Hcc(b,e)|0;if((g-l|0)>((((c[238752+(255-(f&255)<<2)>>2]|0)-(c[238752+((f&255)<<2)>>2]|0)+128|0)>>>8)+6|0)){a[d]=e;Icc(k,1,f&255);ybc(k,(e&255)>>1,7);c[h>>2]=1;i=j;return}else{Icc(k,0,f&255);i=j;return}}function Hcc(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;a=b;b=ca(c[d>>2]|0,c[238752+((a&255)<<2)>>2]|0)|0;e=(b+(ca(c[d+4>>2]|0,c[238752+(255-(a&255)<<2)>>2]|0)|0)|0)>>>8;i=i;return e|0}function Icc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=b;b=c[h+8>>2]|0;j=c[h+4>>2]|0;k=c[h>>2]|0;l=((ca(j-1|0,f)|0)>>>8)+1|0;j=l;if((e|0)!=0){k=k+l|0;j=(c[h+4>>2]|0)-l|0}l=d[242168+j|0]|0;j=j<<l;b=b+l|0;if((b|0)<0){m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+8|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}e=l-b|0;if((k<<e-1&-2147483648|0)!=0){f=(c[h+12>>2]|0)-1|0;while(1){if((f|0)>=0){y=(d[(c[h+16>>2]|0)+f|0]|0|0)==255}else{y=0}if(!y){break}a[(c[h+16>>2]|0)+f|0]=0;f=f-1|0}y=(c[h+16>>2]|0)+f|0;a[y]=(d[y]|0)+1}Jcc((c[h+16>>2]|0)+(c[h+12>>2]|0)|0,1,c[h+20>>2]|0,c[h+24>>2]|0)|0;y=h+12|0;f=c[y>>2]|0;c[y>>2]=f+1;a[(c[h+16>>2]|0)+f|0]=k>>>((24-e|0)>>>0);k=k<<e;l=b;k=k&16777215;b=b-8|0;m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+8|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}function Jcc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;a=b;b=e;do{if((g+a|0)>>>0>g>>>0){if(!((g+a|0)>>>0<d>>>0)){break}h=1;j=h;i=f;return j|0}}while(0);Kcc(b,7,2296760,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;h=0;j=h;i=f;return j|0}function Kcc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function Lcc(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=b;b=e;e=f;f=g;g=0;k=0;do{l=f-1|0;f=l;m=e>>l&1;if((m|0)!=0){n=255-(d[b+(k<<24>>24>>1)|0]|0)|0}else{n=d[b+(k<<24>>24>>1)|0]|0}g=g+(c[238752+(n<<2)>>2]|0)|0;k=a[j+((k<<24>>24)+m)|0]|0;}while((f|0)!=0);i=h;return g|0}function Mcc(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;j=b;b=c;c=e;e=f;f=g;g=0;do{k=f-1|0;f=k;l=e>>k&1;Icc(j,l,d[c+(g<<24>>24>>1)|0]|0);g=a[b+((g<<24>>24)+l)|0]|0;}while((f|0)!=0);i=h;return}function Ncc(a){a=a|0;var b=0;b=i;Occ(a+146880|0);i=b;return}function Occ(a){a=a|0;var b=0;b=a;h[b>>3]=0.0;h[b+8>>3]=0.0;h[b+16>>3]=0.0;h[b+24>>3]=0.0;h[b+32>>3]=0.0;h[b+40>>3]=0.0;h[b+48>>3]=0.0;h[b+56>>3]=0.0;h[b+64>>3]=0.0;h[b+72>>3]=0.0;h[b+80>>3]=0.0;h[b+88>>3]=0.0;h[b+96>>3]=0.0;h[b+104>>3]=0.0;h[b+112>>3]=0.0;h[b+120>>3]=0.0;h[b+136>>3]=0.0;h[b+128>>3]=1.0;i=i;return}function Pcc(a){a=a|0;var b=0,d=0;b=i;d=a;Qcc(d,c[d+142336>>2]|0,d+146880|0);i=b;return}function Qcc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;a=i;i=i+136|0;e=a|0;c[e>>2]=1;c[e+8>>2]=d;c[e+12>>2]=144;qYb(b,e)|0;i=a;return}function Rcc(a){a=a|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0.0,_=0.0,$=0,aa=0,ba=0,da=0;d=i;i=i+224|0;e=d|0;f=d+8|0;g=d+16|0;j=d+24|0;k=d+32|0;l=d+40|0;m=d+48|0;n=d+56|0;o=d+64|0;p=d+72|0;q=d+80|0;r=a;a=r+73728|0;s=r+105664|0;t=a+3152|0;u=s+1816+((c[s+2204>>2]|0)*92|0)|0;v=s+1816+((c[s+2200>>2]|0)*92|0)|0;w=s+1816+((c[s+2208>>2]|0)*92|0)|0;x=c[u+16>>2]|0;y=c[u+36>>2]|0;c[e>>2]=0;c[e+4>>2]=0;c[f>>2]=0;c[f+4>>2]=0;z=0;A=0;B=0;C=0;D=0;E=0;F=0;H=0;I=0;J=256;K=0;L=0;M=0;N=0;c[g>>2]=0;OYb();nrc(a+3060|0,c[r+114504>>2]|0,92)|0;nrc(t+2848|0,u|0,92)|0;nrc(t+2940|0,v|0,92)|0;c[a+6320>>2]=c[a+6324>>2];c[t+3032>>2]=c[s+2384>>2];if((c[s+2348>>2]|0)!=0){c[t+3144>>2]=304;c[t+3148>>2]=274;c[t+3152>>2]=276;c[t+3156>>2]=264}else{c[t+3144>>2]=180;c[t+3148>>2]=212;c[t+3152>>2]=280;c[t+3156>>2]=242}Sbc(a);spc(v);Y_b(r);O=j;c[O>>2]=c[61208];c[O+4>>2]=c[61209];m$b(r,a,I8b(c[s+2356>>2]|0,c[s+2360>>2]|0)|0);nrc(s+7997|0,245112,38)|0;Bcc(r+80124|0,s+7997|0,j|0);j=0;while(1){if((j|0)>=(c[s+2328>>2]|0)){break}c[k>>2]=0;c[t+3044>>2]=(j|0)!=0;O=(ca(j,x)|0)<<4;P=(ca(j,y)|0)<<3;c[a+6440>>2]=-((j<<4)+16|0);c[a+6444>>2]=((c[s+2328>>2]|0)-1-j<<4)+16;Q=0;while(1){if((Q|0)>=(c[s+2332>>2]|0)){break}c[l>>2]=2147483647;if((Q|0)!=0){S=10}else{if((j|0)!=0){S=10}else{T=0}}if((S|0)==10){S=0;if((Q|0)!=0){U=(j|0)!=0^1}else{U=1}T=U}c[t+2992>>2]=(c[v+52>>2]|0)+O;c[t+2996>>2]=(c[v+56>>2]|0)+P;c[t+3e3>>2]=(c[v+60>>2]|0)+P;c[t+3048>>2]=(Q|0)!=0;O8b(c[a+3112>>2]|0,c[a+3076>>2]|0,a+1600|0,16);V=$bc(r,a,T&1)|0;V=V+J|0;W=V;X=wrc(c[e>>2]|0,c[e+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[e>>2]=X;c[e+4>>2]=G;c[a+6432>>2]=-((Q<<4)+16|0);c[a+6436>>2]=((c[s+2332>>2]|0)-1-Q<<4)+16;if((c[s+8036>>2]|0)>>>0>0>>>0){X=a+5296|0;mrc(m|0,0,4)|0;c[o>>2]=2147483647;c[p>>2]=2147483647;Scc(r,a,c[r+114604>>2]|0,p,u,o,O);b[X+24>>1]=0;b[X+26>>1]=0;if((c[p>>2]|0)>=(c[r+114252>>2]|0)){Tcc(r,a,k,X+24|0,u,o,O);if((c[k>>2]|0)!=0){c[n>>2]=2147483647;Tcc(r,a,g,m,u,n,O);if((c[n>>2]|0)<(c[o>>2]|0)){c[o>>2]=c[n>>2];b[X+24>>1]=b[m>>1]|0;b[X+26>>1]=b[m+2>>1]|0}}if((c[s+8036>>2]|0)>>>0>1>>>0){Tcc(r,a,g,m,w,l,O);do{if((c[l>>2]|0)<(c[o>>2]|0)){if((c[l>>2]|0)>=(V|0)){break}I=I+1|0}}while(0);c[t+2900>>2]=(c[u+52>>2]|0)+O;c[t+2904>>2]=(c[u+56>>2]|0)+P;c[t+2908>>2]=(c[u+60>>2]|0)+P}}c[k>>2]=0;if((c[o>>2]|0)<=(V|0)){do{if(((V-J|0)*9|0|0)<=((c[o>>2]|0)*10|0|0)){if((V|0)>=(J<<1|0)){break}K=K+1|0}}while(0);W=X+24|0;b[W>>1]=b[W>>1]<<3;W=X+26|0;b[W>>1]=b[W>>1]<<3;V=c[o>>2]|0;v$b(a,8,X+24|0);vcc(a);z=z+(b[X+24>>1]|0)|0;B=B+(R(b[X+24>>1]|0)|0)|0;A=A+(b[X+26>>1]|0)|0;C=C+(R(b[X+26>>1]|0)|0)|0;D=D+(ca(b[X+24>>1]|0,b[X+24>>1]|0)|0)|0;E=E+(ca(b[X+26>>1]|0,b[X+26>>1]|0)|0)|0;H=H+1|0;c[k>>2]=c[X+24>>2];if((c[X+24>>2]|0)!=0){F=F+1|0;if((c[X+24>>2]|0)!=(N|0)){L=L+1|0}N=c[X+24>>2]|0;if((j|0)<((c[s+2328>>2]|0)/2|0|0)){if((b[X+24>>1]|0)>0){M=M-1|0}else{if((b[X+24>>1]|0)<0){M=M+1|0}}}else{if((j|0)>((c[s+2328>>2]|0)/2|0|0)){if((b[X+24>>1]|0)>0){M=M+1|0}else{if((b[X+24>>1]|0)<0){M=M-1|0}}}}if((Q|0)<((c[s+2332>>2]|0)/2|0|0)){if((b[X+26>>1]|0)>0){M=M-1|0}else{if((b[X+26>>1]|0)<0){M=M+1|0}}}else{if((Q|0)>((c[s+2332>>2]|0)/2|0|0)){if((b[X+26>>1]|0)>0){M=M+1|0}else{if((b[X+26>>1]|0)<0){M=M-1|0}}}}}}}W=V;Y=wrc(c[f>>2]|0,c[f+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[f>>2]=Y;c[f+4>>2]=G;Y=a+3112|0;c[Y>>2]=(c[Y>>2]|0)+16;Y=a+3116|0;c[Y>>2]=(c[Y>>2]|0)+8;Y=a+3120|0;c[Y>>2]=(c[Y>>2]|0)+8;O=O+16|0;P=P+8|0;Q=Q+1|0}Q=a+3112|0;c[Q>>2]=(c[Q>>2]|0)+((c[a+3076>>2]<<4)-(c[s+2332>>2]<<4));Q=a+3116|0;c[Q>>2]=(c[Q>>2]|0)+((c[a+3096>>2]<<3)-(c[s+2332>>2]<<3));Q=a+3120|0;c[Q>>2]=(c[Q>>2]|0)+((c[a+3096>>2]<<3)-(c[s+2332>>2]<<3));bpc(v,(c[t+2992>>2]|0)+16|0,(c[t+2996>>2]|0)+8|0,(c[t+3e3>>2]|0)+8|0);OYb();j=j+1|0}OYb();Z=0.0;h[q>>3]=+((c[s+8036>>2]|0)>>>0>>>0);j=c[e+4>>2]|0;h[q+8>>3]=+(((c[e>>2]|0)>>>8|j<<24)>>>0)+ +(j>>8|((j|0)<0|0?-1:0)<<24|0)*4294967296.0;j=c[f+4>>2]|0;h[q+16>>3]=+(((c[f>>2]|0)>>>8|j<<24)>>>0)+ +(j>>8|((j|0)<0|0?-1:0)<<24|0)*4294967296.0;Z=+Ucc(c[r+114504>>2]|0);if(Z<.1){Z=.1}h[q+24>>3]=+h[q+16>>3]*Z;h[q+32>>3]=0.0;h[q+40>>3]=0.0;h[q+64>>3]=0.0;h[q+72>>3]=0.0;h[q+80>>3]=0.0;h[q+88>>3]=0.0;h[q+96>>3]=0.0;h[q+104>>3]=0.0;h[q+112>>3]=0.0;h[q+120>>3]=0.0;h[q+136>>3]=1.0;h[q+32>>3]=+(H|0)*1.0/+(c[s+2324>>2]|0);h[q+48>>3]=+(I|0)*1.0/+(c[s+2324>>2]|0);h[q+56>>3]=+(K|0)*1.0/+(c[s+2324>>2]|0);if((F|0)>0){h[q+64>>3]=+(z|0)/+(F|0);h[q+72>>3]=+(B|0)/+(F|0);h[q+80>>3]=+(A|0)/+(F|0);h[q+88>>3]=+(C|0)/+(F|0);h[q+96>>3]=(+(D|0)- +h[q+64>>3]*+h[q+64>>3]/+(F|0))/+(F|0);h[q+104>>3]=(+(E|0)- +h[q+80>>3]*+h[q+80>>3]/+(F|0))/+(F|0);h[q+112>>3]=+(M|0)/+(F<<1|0);h[q+120>>3]=+(L|0);h[q+40>>3]=+(F|0)*1.0/+(c[r+107988>>2]|0)}F=(c[r+114492>>2]|0)+104|0;L=(c[r+114492>>2]|0)+96|0;M=xrc(c[F>>2]|0,c[F+4>>2]|0,c[L>>2]|0,c[L+4>>2]|0)|0;h[q+128>>3]=+(M>>>0)+ +(G|0)*4294967296.0;nrc(r+147024|0,q|0,144)|0;Qcc(r,c[r+142336>>2]|0,r+147024|0);Vcc(r+146880|0,q);do{if((c[s+8036>>2]|0)>>>0>0>>>0){if(!(+h[r+147056>>3]>.2)){break}if(+h[r+147040>>3]<0.0){_=+h[r+147040>>3]-1.0e-6}else{_=+h[r+147040>>3]+1.0e-6}if(!(+h[r+147032>>3]/_>2.0)){break}S7b(u,w)}}while(0);upc(u,v);N7b(u);if((c[s+8036>>2]|0)!=0){$=s;aa=$+8036|0;ba=c[aa>>2]|0;da=ba+1|0;c[aa>>2]=da;i=d;return}S7b(u,w);$=s;aa=$+8036|0;ba=c[aa>>2]|0;da=ba+1|0;c[aa>>2]=da;i=d;return}function Scc(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0;a=i;j=b;b=d;d=h;h=j+3152|0;k=j+1860|0;l=j+5296|0;m=(c[c[k+36>>2]>>2]|0)+(c[k+40>>2]|0)|0;n=c[k+44>>2]|0;k=c[j+6016>>2]|0;H9b(m,n,(c[b+52>>2]|0)+d+(c[l+16>>2]|0)|0,c[b+16>>2]|0,e)|0;c[h+2900>>2]=(c[f+52>>2]|0)+d;H9b(m,n,(c[h+2900>>2]|0)+(c[l+16>>2]|0)|0,k,g)|0;i=a;return}function Tcc(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=i;i=i+64|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=a;a=d;d=e;e=f;f=h;h=a+1860|0;q=a+5296|0;r=3;s=7-r|0;nrc(o|0,p+142932|0,36)|0;t=256;c[o+4>>2]=250;c[a+6052>>2]=(c[g+52>>2]|0)+j;c[m>>2]=0;b[n+2>>1]=b[d+2>>1]>>3;b[n>>1]=b[d>>1]>>3;j=Be[c[p+142784>>2]&7](a,h,q,n,m,r,c[a+6364>>2]|0,l,o,a+6396|0,d)|0;if((j|0)<(2147483647-t|0)){j=j+t|0}if((j|0)<(c[f>>2]|0)){c[f>>2]=j;b[e>>1]=b[m>>1]|0;b[e+2>>1]=b[m+2>>1]|0}g=c[l>>2]|0;c[l>>2]=0;while(1){if((g|0)>=(s|0)){break}g=g+1|0;if((c[l>>2]|0)!=0){c[l>>2]=(c[l>>2]|0)-1}else{j=Be[c[p+142784>>2]&7](a,h,q,n,m,r+g|0,c[a+6364>>2]|0,l,o,a+6396|0,d)|0;if((j|0)<(2147483647-t|0)){j=j+t|0}if((j|0)<(c[f>>2]|0)){c[f>>2]=j;b[e>>1]=b[m>>1]|0;b[e+2>>1]=b[m+2>>1]|0}}}i=k;return}function Ucc(a){a=a|0;var b=0,e=0,f=0.0,g=0,j=0,k=0;b=i;e=a;a=c[e+52>>2]|0;f=0.0;g=c[e+4>>2]|0;do{j=c[e>>2]|0;do{f=f+ +h[154208+((d[a]|0)<<3)>>3];a=a+1|0;k=j-1|0;j=k;}while((k|0)!=0);a=a+(-(c[e>>2]|0)|0)|0;a=a+(c[e+16>>2]|0)|0;j=g-1|0;g=j;}while((j|0)!=0);f=f/+(ca(c[e+4>>2]|0,c[e>>2]|0)|0);i=b;return+f}function Vcc(a,b){a=a|0;b=b|0;var c=0;c=a;a=b;b=c|0;h[b>>3]=+h[b>>3]+ +h[a>>3];b=c+8|0;h[b>>3]=+h[b>>3]+ +h[a+8>>3];b=c+16|0;h[b>>3]=+h[b>>3]+ +h[a+16>>3];b=c+24|0;h[b>>3]=+h[b>>3]+ +h[a+24>>3];b=c+32|0;h[b>>3]=+h[b>>3]+ +h[a+32>>3];b=c+40|0;h[b>>3]=+h[b>>3]+ +h[a+40>>3];b=c+48|0;h[b>>3]=+h[b>>3]+ +h[a+48>>3];b=c+56|0;h[b>>3]=+h[b>>3]+ +h[a+56>>3];b=c+64|0;h[b>>3]=+h[b>>3]+ +h[a+64>>3];b=c+72|0;h[b>>3]=+h[b>>3]+ +h[a+72>>3];b=c+80|0;h[b>>3]=+h[b>>3]+ +h[a+80>>3];b=c+88|0;h[b>>3]=+h[b>>3]+ +h[a+88>>3];b=c+96|0;h[b>>3]=+h[b>>3]+ +h[a+96>>3];b=c+104|0;h[b>>3]=+h[b>>3]+ +h[a+104>>3];b=c+112|0;h[b>>3]=+h[b>>3]+ +h[a+112>>3];b=c+120|0;h[b>>3]=+h[b>>3]+ +h[a+120>>3];b=c+136|0;h[b>>3]=+h[b>>3]+ +h[a+136>>3];b=c+128|0;h[b>>3]=+h[b>>3]+ +h[a+128>>3];i=i;return}function Wcc(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0.0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0;b=i;i=i+144|0;d=b|0;e=a;f=+((((ca(c[e+114076>>2]|0,c[e+114216>>2]|0)|0)>>>0)/100|0)>>>0>>>0);Occ(e+146880|0);Occ(e+147184|0);if((c[e+147172>>2]|0)==0){i=b;return}nrc(e+146880|0,c[e+147172>>2]|0,144)|0;nrc(e+147184|0,e+146880|0,144)|0;nZb(e,+h[e+147016>>3]*1.0e7/+h[e+147008>>3]);h[e+131608>>3]=+h[e+131672>>3];g=+h[e+147008>>3]*+((c[e+114076>>2]|0)>>>0>>>0)/1.0e7;a=(F=+g,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);j=e+147336|0;c[j>>2]=~~+g>>>0;c[j+4>>2]=a;g=+h[e+147008>>3]*f/1.0e7;a=(F=+g,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);j=e+147336|0;k=xrc(c[j>>2]|0,c[j+4>>2]|0,~~+g>>>0,a)|0;c[j>>2]=k;c[j+4>>2]=G;h[e+147384>>3]=+((c[e+107988>>2]|0)*300|0|0);h[e+147392>>3]=+((c[e+107988>>2]|0)*200|0|0);g=0.0;j=c[e+147168>>2]|0;while(1){if(!((Xcc(e,d)|0)!=-1)){break}if(+h[d+16>>3]<0.0){l=+h[d+16>>3]-1.0e-6}else{l=+h[d+16>>3]+1.0e-6}f=+h[d+8>>3]/l;if(f<1.0){m=1.0}else{if(f>20.0){n=20.0}else{n=f}m=n}f=m;g=g+f}if(+h[e+147016>>3]<0.0){o=+h[e+147016>>3]-1.0e-6}else{o=+h[e+147016>>3]+1.0e-6}h[e+147352>>3]=g/o;Ycc(e,j);j=c[e+147168>>2]|0;h[e+147360>>3]=0.0;h[e+147368>>3]=0.0;while(1){if(!((Xcc(e,d)|0)!=-1)){break}o=+Zcc(e,d);k=e+147360|0;h[k>>3]=+h[k>>3]+o}h[e+147376>>3]=+h[e+147360>>3];Ycc(e,j);i=b;return}function Xcc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;if((c[e+147168>>2]|0)>>>0>=(c[e+147172>>2]|0)>>>0){f=-1;g=f;i=d;return g|0}else{nrc(b|0,c[e+147168>>2]|0,144)|0;c[e+147168>>2]=(c[e+147168>>2]|0)+144;f=1;g=f;i=d;return g|0}return 0}function Ycc(a,b){a=a|0;b=b|0;c[a+147168>>2]=b;i=i;return}function Zcc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0.0,g=0.0,j=0.0,k=0.0,l=0.0,m=0.0;d=i;e=a;f=+h[e+146904>>3]/+h[e+147016>>3];g=+h[b+24>>3];if(g>f){if(f<0.0){j=f-1.0e-6}else{j=f+1.0e-6}k=f*+T(+(g/j),+(+(c[e+114212>>2]|0)/100.0));l=k;i=d;return+l}else{if(f<0.0){m=f-1.0e-6}else{m=f+1.0e-6}k=f*+T(+(g/m),+(+(c[e+114212>>2]|0)/100.0));l=k;i=d;return+l}return 0.0}function _cc(a){a=a|0;i=i;return}function $cc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0.0,k=0.0,l=0,m=0,n=0,o=0.0,p=0.0,q=0,r=0,s=0;b=i;i=i+432|0;d=b|0;e=b+144|0;f=b+288|0;g=a;a=~~(+h[g+147016>>3]- +((c[g+113700>>2]|0)>>>0>>>0));mrc(d|0,0,144)|0;if((c[g+147168>>2]|0)==0){i=b;return}OYb();if(-1==(Xcc(g,d)|0)){i=b;return}j=+h[d+8>>3];k=+h[d+16>>3];if((c[g+147400>>2]|0)==0){nrc(e|0,d|0,144)|0;adc(g,e);if((c[g+114256>>2]|0)!=0){l=g+147432|0;m=c[l+4>>2]|0;n=g+147448|0;c[n>>2]=c[l>>2];c[n+4>>2]=m;c[g+147424>>2]=c[g+147440>>2];c[g+131552>>2]=c[g+147400>>2];c[g+131524>>2]=c[g+131552>>2];c[g+114612>>2]=0}}if((c[g+131524>>2]|0)==0){nrc(e|0,d|0,144)|0;bdc(g,e);do{if((c[g+114612>>2]|0)!=0){if((c[g+107976>>2]|0)==0){break}m=c[g+131588>>2]|0;nrc(e|0,d|0,144)|0;cdc(g,e);c[g+131588>>2]=m}}while(0)}else{if((c[g+114256>>2]|0)!=0){c[g+131524>>2]=c[g+147400>>2];if((c[g+107976>>2]|0)!=0){nrc(e|0,d|0,144)|0;cdc(g,e)}}else{nrc(e|0,d|0,144)|0;cdc(g,e)}}if(k<0.0){o=k-1.0e-6}else{o=k+1.0e-6}c[g+146876>>2]=~~(j/o);if((ddc(g,f)|0)!=-1){if(+h[f+16>>3]<0.0){p=+h[f+16>>3]-1.0e-6}else{p=+h[f+16>>3]+1.0e-6}c[g+146872>>2]=~~(+h[f+8>>3]/p)}c[g+142332>>2]=~~(+(c[g+131588>>2]|0)*+h[g+131608>>3]);if((c[g+142332>>2]|0)<0){c[g+142332>>2]=0}f=edc(g,g+147184|0)|0;e=f;if((c[g+113700>>2]|0)==0){h[g+147464>>3]=1.0;if((c[g+114116>>2]|0)==2){f=g+147336|0;m=a;n=Crc(c[f>>2]|0,c[f+4>>2]|0,m,(m|0)<0|0?-1:0)|0;m=fdc(g,g+147184|0,n,e)|0;c[g+131748>>2]=c[g+114188>>2];if((m|0)>(c[g+131748>>2]|0)){c[g+131748>>2]=m}}c[g+147404>>2]=c[g+131732>>2];c[g+147408>>2]=c[g+131740>>2];m=g+147336|0;n=a;f=Crc(c[m>>2]|0,c[m+4>>2]|0,n,(n|0)<0|0?-1:0)|0;q=gdc(g,g+147184|0,f,e)|0;if((q+32|0)<(c[g+131732>>2]|0)){r=q+32|0}else{r=c[g+131732>>2]|0}c[g+147404>>2]=r;if((q-32|0)>(c[g+131740>>2]|0)){s=q-32|0}else{s=c[g+131740>>2]|0}c[g+147408>>2]=s;c[g+131736>>2]=q;c[g+131640>>2]=q}else{do{if((c[g+113700>>2]|0)>>>0<(~~+h[g+147016>>3]*255|0)>>>8>>>0){if(!(((c[g+113700>>2]|0)+(c[g+131552>>2]|0)|0)>>>0<~~+h[g+147016>>3]>>>0)){break}if((a|0)<1){a=1}s=g+147336|0;r=a;f=Crc(c[s>>2]|0,c[s+4>>2]|0,r,(r|0)<0|0?-1:0)|0;q=gdc(g,g+147184|0,f,e)|0;if((q|0)>(c[g+131736>>2]|0)){f=g+131736|0;c[f>>2]=(c[f>>2]|0)+1}else{if((q|0)<(c[g+131736>>2]|0)){f=g+131736|0;c[f>>2]=(c[f>>2]|0)-1}}c[g+131736>>2]=(((c[g+131736>>2]|0)*3|0)+q+2|0)/4|0}}while(0)}q=g+147400|0;c[q>>2]=(c[q>>2]|0)-1;hdc(g+147184|0,d);i=b;return}function adc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,H=0.0,I=0.0,J=0,K=0,L=0.0,M=0,N=0,O=0.0,P=0,S=0,T=0.0,U=0.0,V=0.0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0.0,$=0.0,aa=0.0,da=0,ea=0,fa=0,ga=0.0,ia=0,ja=0.0,ka=0.0,la=0.0,ma=0.0,na=0;d=i;i=i+888|0;e=d|0;f=d+144|0;g=d+288|0;j=d+432|0;k=d+496|0;l=d+640|0;m=d+648|0;n=d+656|0;o=d+664|0;p=d+672|0;q=d+680|0;r=d+688|0;s=d+696|0;t=d+840|0;u=d+848|0;v=d+856|0;w=d+864|0;x=d+872|0;y=d+880|0;z=a;a=b;A=1.0;B=0.0;C=0.0;D=0.0;E=0.0;H=0.0;I=0.0;nrc(j|0,1223976,64)|0;mrc(g|0,0,144)|0;OYb();b=c[z+147168>>2]|0;c[z+107976>>2]=0;c[z+114744>>2]=c[z+114748>>2];c[z+114616>>2]=0;c[z+131524>>2]=0;c[z+147400>>2]=1;nrc(f|0,a|0,144)|0;J=z+147432|0;c[J>>2]=0;c[J+4>>2]=0;J=z+147440|0;c[J>>2]=0;c[J+4>>2]=0;D=+Zcc(z,a);J=0;a:while(1){if(!((c[z+147168>>2]|0)>>>0<(c[z+147172>>2]|0)>>>0)){break}E=E+ +Zcc(z,a);H=H+ +h[a+8>>3];I=I+ +h[a+16>>3];nrc(e|0,a|0,144)|0;Xcc(z,a)|0;do{if((c[z+114100>>2]|0)!=0){if(!((ddc(z,g)|0)!=-1)){K=17;break}if((J|0)>=4){if((idc(z,e,a,g)|0)!=0){K=7;break a}}L=+jdc(z,g);h[j+(((J|0)%8|0)<<3)>>3]=L;A=1.0;M=0;while(1){if((M|0)>=8){break}A=A*+h[j+(M<<3)>>3];M=M+1|0}if((kdc(z,J,(c[z+114740>>2]|0)-J|0,L,A)|0)!=0){K=13;break a}M=z+147400|0;c[M>>2]=(c[M>>2]|0)+1;if((c[z+147400>>2]|0)>=(c[z+114740>>2]<<1|0)){K=15;break a}}else{K=17}}while(0);if((K|0)==17){K=0;M=z+147400|0;c[M>>2]=(c[M>>2]|0)+1}J=J+1|0}do{if((c[z+114100>>2]|0)!=0){if((c[z+147400>>2]|0)<=(c[z+114740>>2]|0)){K=26;break}j=c[z+147168>>2]|0;e=z+147400|0;c[e>>2]=(c[e>>2]|0)/2|0;nrc(k|0,f|0,144)|0;Ycc(z,b);E=0.0;H=0.0;I=0.0;J=0;while(1){if((J|0)>=(c[z+147400>>2]|0)){break}E=E+ +Zcc(z,k);H=H+ +h[k+8>>3];I=I+ +h[k+16>>3];Xcc(z,k)|0;J=J+1|0}Ycc(z,j);c[z+114748>>2]=1}else{K=26}}while(0);if((K|0)==26){c[z+114748>>2]=0}if((c[z+147168>>2]|0)>>>0>=(c[z+147172>>2]|0)>>>0){E=E+ +Zcc(z,a);H=H+ +h[a+8>>3];I=I+ +h[a+16>>3]}a=z+147336|0;k=c[a+4>>2]|0;e=0;do{if((k|0)>(e|0)|(k|0)==(e|0)&(c[a>>2]|0)>>>0>0>>>0){if(!(+h[z+147376>>3]>0.0)){K=45;break}M=ldc(z)|0;N=z+147336|0;O=(+((c[N>>2]|0)>>>0)+ +(c[N+4>>2]|0)*4294967296.0)*(E/+h[z+147376>>3]);N=(F=+O,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);P=z+147432|0;c[P>>2]=~~+O>>>0;c[P+4>>2]=N;N=M;M=c[z+147400>>2]|0;P=Erc(N,(N|0)<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;c[l>>2]=P;c[l+4>>2]=G;P=z+147432|0;M=c[P+4>>2]|0;N=c[l+4>>2]|0;if((M|0)>(N|0)|(M|0)==(N|0)&(c[P>>2]|0)>>>0>(c[l>>2]|0)>>>0){P=c[l+4>>2]|0;N=z+147432|0;c[N>>2]=c[l>>2];c[N+4>>2]=P}if((c[z+114116>>2]|0)==1){P=z+114136|0;N=c[P+4>>2]|0;c[m>>2]=c[P>>2];c[m+4>>2]=N;N=z+131688|0;P=c[N+4>>2]|0;c[n>>2]=c[N>>2];c[n+4>>2]=P;P=c[n+4>>2]|0;N=c[m+4>>2]|0;if((P|0)>=(N|0)&((P|0)>(N|0)|(c[n>>2]|0)>>>0>=(c[m>>2]|0)>>>0)){N=z+114144|0;P=wrc(c[m>>2]|0,c[m+4>>2]|0,c[N>>2]|0,c[N+4>>2]|0)|0;N=G;c[o>>2]=P>>>1|N<<31;c[o+4>>2]=N>>1|((N|0)<0|0?-1:0)<<31;N=c[z+131592>>2]|0;P=c[z+147400>>2]|0;M=Erc(N,(N|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;c[p>>2]=M;c[p+4>>2]=G;M=z+131688|0;P=c[M+4>>2]|0;N=c[o+4>>2]|0;if((P|0)>=(N|0)&((P|0)>(N|0)|(c[M>>2]|0)>>>0>=(c[o>>2]|0)>>>0)){M=c[p>>2]|0;N=c[p+4>>2]|0;P=xrc(c[n>>2]|0,c[n+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;S=wrc(M,N,P,G)|0;c[q>>2]=S;c[q+4>>2]=G;S=z+147432|0;P=c[S+4>>2]|0;N=c[q+4>>2]|0;if((P|0)<(N|0)|(P|0)==(N|0)&(c[S>>2]|0)>>>0<(c[q>>2]|0)>>>0){S=c[q+4>>2]|0;N=z+147432|0;c[N>>2]=c[q>>2];c[N+4>>2]=S}}else{S=z+147432|0;N=c[S+4>>2]|0;P=c[p+4>>2]|0;if((N|0)<(P|0)|(N|0)==(P|0)&(c[S>>2]|0)>>>0<(c[p>>2]|0)>>>0){S=z+147432|0;P=xrc(c[p>>2]|0,c[p+4>>2]|0,c[S>>2]|0,c[S+4>>2]|0)|0;c[r>>2]=P;c[r+4>>2]=G;O=+((c[r>>2]|0)>>>0)+ +(c[r+4>>2]|0)*4294967296.0;P=xrc(c[n>>2]|0,c[n+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;T=O*(+(P>>>0)+ +(G|0)*4294967296.0);P=xrc(c[o>>2]|0,c[o+4>>2]|0,c[m>>2]|0,c[m+4>>2]|0)|0;O=T/(+(P>>>0)+ +(G|0)*4294967296.0);P=(F=+O,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);S=z+147432|0;N=wrc(c[S>>2]|0,c[S+4>>2]|0,~~+O>>>0,P)|0;c[S>>2]=N;c[S+4>>2]=G}}}}}else{K=45}}while(0);if((K|0)==45){m=z+147432|0;c[m>>2]=0;c[m+4>>2]=0}Ycc(z,b);A=1.0;B=0.0;L=1.0;J=0;while(1){if((J|0)>=(c[z+147400>>2]|0)){break}if(-1==(Xcc(z,g)|0)){K=49;break}if(+h[g+8>>3]>+h[z+147384>>3]){if(+h[g+16>>3]<0.0){U=+h[g+16>>3]-1.0e-6}else{U=+h[g+16>>3]+1.0e-6}V=1.5*+h[g+8>>3]/U}else{if(+h[g+16>>3]<0.0){W=+h[g+16>>3]-1.0e-6}else{W=+h[g+16>>3]+1.0e-6}V=1.5*+h[z+147384>>3]/W}if(V>14.0){V=14.0}L=+jdc(z,g);A=A*L;if(A<.1){X=.1}else{X=A}A=X;B=B+A*V;if((J|0)>4){if(B-C<1.0){K=66;break}}C=B;J=J+1|0}Occ(s);Ycc(z,b);J=0;while(1){if((J|0)>=(c[z+147400>>2]|0)){break}Xcc(z,g)|0;Vcc(s,g);J=J+1|0}mdc(s);if(+h[s+16>>3]<0.0){Y=+h[s+16>>3]-1.0e-6}else{Y=+h[s+16>>3]+1.0e-6}c[z+146856>>2]=~~(+h[s+8>>3]/Y);if(+h[s+16>>3]<0.0){Z=+h[s+16>>3]-1.0e-6}else{Z=+h[s+16>>3]+1.0e-6}h[z+146864>>3]=1.0-(+h[s+8>>3]/Z-10.0)*.025;if(+h[z+146864>>3]<.8){h[z+146864>>3]=.8}if((c[z+114116>>2]|0)==1){if((c[z+131752>>2]|0)!=0){s=c[z+114208>>2]|0;J=z+114136|0;g=Crc(c[J>>2]|0,c[J+4>>2]|0,100,0)|0;J=Erc(s,(s|0)<0|0?-1:0,g,G)|0;g=J;J=z+131688|0;s=c[J+4>>2]|0;m=g;o=(m|0)<0|0?-1:0;if((s|0)>(o|0)|(s|0)==(o|0)&(c[J>>2]|0)>>>0>m>>>0){m=z+131688|0;J=g;g=xrc(c[m>>2]|0,c[m+4>>2]|0,J,(J|0)<0|0?-1:0)|0;J=Erc(g,G,2,0)|0;g=Crc(J,G,3,0)|0;if(+(c[z+131592>>2]|0)<0.0){_=+(c[z+131592>>2]|0)-1.0e-6}else{_=+(c[z+131592>>2]|0)+1.0e-6}$=(+(g>>>0)+ +(G|0)*4294967296.0)*16.0/_}else{$=0.0}}else{g=z+131688|0;J=c[g+4>>2]|0;m=0;if((J|0)>(m|0)|(J|0)==(m|0)&(c[g>>2]|0)>>>0>0>>>0){g=z+131688|0;m=Erc(c[g>>2]|0,c[g+4>>2]|0,2,0)|0;g=Crc(m,G,3,0)|0;if(+(c[z+131592>>2]|0)<0.0){aa=+(c[z+131592>>2]|0)-1.0e-6}else{aa=+(c[z+131592>>2]|0)+1.0e-6}$=(+(g>>>0)+ +(G|0)*4294967296.0)*16.0/aa}else{$=0.0}}if(B>$){B=$}}Ycc(z,b);b=~~B;g=z+107480+((c[z+107868>>2]|0)*92|0)|0;if((b|0)<48){b=b+((c[z+147400>>2]|0)+1>>1)|0;if((b|0)>48){b=48}}if((ca(c[g>>2]|0,c[g+4>>2]|0)|0)>76800){b=b+(((ca(c[g>>2]|0,c[g+4>>2]|0)|0)<<1|0)/76800|0)|0}else{if((ca(c[g>>2]|0,c[g+4>>2]|0)|0)<76800){b=b-(307200/(ca(c[g>>2]|0,c[g+4>>2]|0)|0)|0)|0}}b=~~(+(b|0)*100.0)>>4;if((b|0)<250){b=250}if(A>=.99){da=(((c[z+147400>>2]|0)-1|0)*10|0)+b|0}else{da=(((c[z+147400>>2]|0)-1|0)*100|0)+b|0}while(1){if((b|0)<=1e3){break}b=(b|0)/2|0;da=(da|0)/2|0}g=z+147432|0;m=c[g+4>>2]|0;J=0;if((m|0)<(J|0)|(m|0)==(J|0)&(c[g>>2]|0)>>>0<0>>>0){ea=0;fa=0}else{g=z+147432|0;ea=c[g+4>>2]|0;fa=c[g>>2]|0}g=z+147432|0;c[g>>2]=fa;c[g+4>>2]=ea;ea=z+147432|0;c[z+147420>>2]=~~(+(b|0)*((+((c[ea>>2]|0)>>>0)+ +(c[ea+4>>2]|0)*4294967296.0)/+(da|0)));if((c[z+114116>>2]|0)==1){ea=c[z+147420>>2]|0;g=z+131688|0;fa=Erc(3,0,c[g>>2]|0,c[g+4>>2]|0)|0;g=G;g>>2|((g|0)<0|0?-1:0)<<30;if((ea|0)>(fa>>>2|g<<30|0)){g=z+131688|0;fa=Erc(3,0,c[g>>2]|0,c[g+4>>2]|0)|0;g=G;g>>2|((g|0)<0|0?-1:0)<<30;c[z+147420>>2]=fa>>>2|g<<30}}if(D<E/+(c[z+147400>>2]|0)){g=z+147336|0;if(+h[z+147376>>3]<0.0){ga=+h[z+147376>>3]-1.0e-6}else{ga=+h[z+147376>>3]+1.0e-6}ia=~~(+(b|0)*((+((c[g>>2]|0)>>>0)+ +(c[g+4>>2]|0)*4294967296.0)*D*+(c[z+147400>>2]|0)/ga/+(da|0)));if((c[z+147420>>2]|0)>(ia|0)){c[z+147420>>2]=ia}}else{da=z+147336|0;if(+h[z+147376>>3]<0.0){ja=+h[z+147376>>3]-1.0e-6}else{ja=+h[z+147376>>3]+1.0e-6}ia=~~((+((c[da>>2]|0)>>>0)+ +(c[da+4>>2]|0)*4294967296.0)*(D/ja));if((ia|0)>(c[z+147420>>2]|0)){c[z+147420>>2]=ia}}ia=c[z+147420>>2]|0;da=z+147432|0;g=xrc(c[da>>2]|0,c[da+4>>2]|0,ia,(ia|0)<0|0?-1:0)|0;c[da>>2]=g;c[da+4>>2]=G;da=z+147420|0;c[da>>2]=(c[da>>2]|0)+(c[z+131596>>2]|0);c[z+131588>>2]=c[z+147420>>2];c[z+142332>>2]=~~(+(c[z+147420>>2]|0)*+h[z+131608>>3]);da=~~(E-D);g=z+147440|0;c[g>>2]=da;c[g+4>>2]=(da|0)<0|0?-1:0;da=z+147376|0;h[da>>3]=+h[da>>3]-E;if((c[z+114192>>2]|0)==0){i=d;return}da=0;g=0;ia=0;b=c[z+114060>>2]|0;fa=c[z+114064>>2]|0;ea=c[z+131688>>2]|0;D=(H- +h[f+8>>3])/(I- +h[f+16>>3]);I=E/+(c[z+147400>>2]|0);if((c[z+107456>>2]|0)!=(c[z+114060>>2]|0)){K=140}else{if((c[z+107460>>2]|0)!=(c[z+114064>>2]|0)){K=140}}if((K|0)==140){g=1}c[z+107464>>2]=0;c[z+107468>>2]=0;if(+h[z+131672>>3]<0.0){ka=+h[z+131672>>3]-1.0e-6}else{ka=+h[z+131672>>3]+1.0e-6}E=+((c[z+114076>>2]|0)>>>0>>>0)/ka;if((c[z+114116>>2]|0)==1){la=E}else{f=z+147432|0;J=c[z+147400>>2]|0;m=Crc(c[f>>2]|0,c[f+4>>2]|0,J,(J|0)<0|0?-1:0)|0;la=+(m>>>0)+ +(G|0)*4294967296.0;if(la<E){la=E}}if(la<+((((ca(c[z+114076>>2]|0,c[z+114216>>2]|0)|0)>>>0)/100|0)>>>0>>>0)){la=+((((ca(c[z+114076>>2]|0,c[z+114216>>2]|0)|0)>>>0)/100|0)>>>0>>>0)}m=ndc(z,I,~~la,D)|0;ka=la;J=m;while(1){if((J|0)<=(c[z+131732>>2]|0)){break}ka=ka*1.04;J=J-1|0}J=z+131688|0;f=~~((ka-E)*+(c[z+147400>>2]|0));o=xrc(c[J>>2]|0,c[J+4>>2]|0,f,(f|0)<0|0?-1:0)|0;ea=o;if((c[z+114116>>2]|0)==1){o=ea;f=(o|0)<0|0?-1:0;J=c[z+114196>>2]|0;s=z+114136|0;n=Erc(J,(J|0)<0|0?-1:0,c[s>>2]|0,c[s+4>>2]|0)|0;s=Crc(n,G,100,0)|0;n=G;do{if((f|0)<(n|0)|(f|0)==(n|0)&o>>>0<s>>>0){K=158}else{if((g|0)!=0){J=ea;r=(J|0)<0|0?-1:0;p=c[z+114200>>2]|0;q=z+114136|0;l=Erc(p,(p|0)<0|0?-1:0,c[q>>2]|0,c[q+4>>2]|0)|0;q=Crc(l,G,100,0)|0;l=G;if((r|0)<(l|0)|(r|0)==(l|0)&J>>>0<q>>>0){K=158;break}}da=0}}while(0);if((K|0)==158){da=1}}else{if(+h[z+131672>>3]<0.0){ma=+h[z+131672>>3]-1.0e-6}else{ma=+h[z+131672>>3]+1.0e-6}E=+h[z+147016>>3]*+((c[z+114076>>2]|0)>>>0>>>0)/ma;ea=(F=+E,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);c[x>>2]=~~+E>>>0;c[x+4>>2]=ea;ea=z+114128|0;s=z+131688|0;o=xrc(c[ea>>2]|0,c[ea+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;c[y>>2]=o;c[y+4>>2]=G;if((g|0)!=0){if((m|0)>(c[z+131732>>2]|0)){K=168}else{K=166}}else{K=166}do{if((K|0)==166){if((m|0)>(c[z+131732>>2]|0)){g=c[y>>2]|0;o=c[y+4>>2]|0;s=Crc(c[x>>2]|0,c[x+4>>2]|0,20,0)|0;ea=G;if((o|0)>(ea|0)|(o|0)==(ea|0)&g>>>0>s>>>0){K=168;break}}da=0}}while(0);if((K|0)==168){da=1}}if((da|0)!=0){while(1){if((m|0)>=(c[z+131732>>2]|0)){na=(ia|0)<6}else{na=0}if(!na){break}ia=ia+1|0;c[z+107468>>2]=c[190336+(ia<<2)>>2];c[z+107464>>2]=c[1091304+(ia<<2)>>2];odc(c[z+107464>>2]|0,t,u);odc(c[z+107468>>2]|0,v,w);da=(c[u>>2]|0)-1+(ca(c[z+114060>>2]|0,c[t>>2]|0)|0)|0;b=(da|0)/(c[u>>2]|0)|0;da=(c[w>>2]|0)-1+(ca(c[z+114064>>2]|0,c[v>>2]|0)|0)|0;fa=(da|0)/(c[w>>2]|0)|0;E=+(ca(b,fa)|0);ma=E/+(ca(c[z+114060>>2]|0,c[z+114064>>2]|0)|0);ma=(3.0*ma+1.0)/4.0;m=ndc(z,I*ma,~~la,D)|0}}if((c[z+107456>>2]|0)!=(b|0)){K=180}else{if((c[z+107460>>2]|0)!=(fa|0)){K=180}}if((K|0)==180){c[z+107456>>2]=b;c[z+107460>>2]=fa;jZb(z)}i=d;return}function bdc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,H=0,I=0.0,J=0.0,K=0,L=0.0,M=0.0,N=0.0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,da=0.0,ea=0.0,fa=0,ga=0,ia=0.0,ja=0.0;d=i;i=i+344|0;e=d|0;f=d+144|0;g=d+152|0;j=d+160|0;k=d+168|0;l=d+176|0;m=d+184|0;n=d+192|0;o=d+200|0;p=a;a=b;q=0.0;r=0.0;s=0.0;t=0.0;u=0.0;h[f>>3]=0.0;v=1.0;w=1.0;h[g>>3]=0.0;h[j>>3]=0.0;h[k>>3]=0.0;x=0.0;b=ldc(p)|0;if((c[p+114224>>2]|0)!=0){y=(c[p+114112>>2]|0)!=0}else{y=0}z=y&1;y=0;c[l>>2]=0;c[m>>2]=0;A=p+147448|0;c[A>>2]=0;c[A+4>>2]=0;c[p+147412>>2]=0;OYb();A=c[p+147168>>2]|0;mrc(e|0,0,144)|0;u=+Zcc(p,a);t=u;if((c[p+107976>>2]|0)==0){s=s-t}B=0;a:while(1){if((B|0)<(c[p+147416>>2]|0)){C=8}else{if(((c[p+147400>>2]|0)-B|0)<4){C=8}else{D=0}}if((C|0)==8){C=0;D=(B|0)<(c[p+147400>>2]|0)}if(!D){break}B=B+1|0;u=+Zcc(p,a);s=s+u;if(+(c[p+107988>>2]|0)<0.0){E=+(c[p+107988>>2]|0)-1.0e-6}else{E=+(c[p+107988>>2]|0)+1.0e-6}x=x+u/E;if(-1==(Xcc(p,e)|0)){C=14;break}H=rdc(p,0)|0;sdc(p,e,g,j,k,f);I=+tdc(p,e,+h[g>>3]);if((H|0)==0){w=+jdc(p,e);v=v*w;if(v<.1){J=.1}else{J=v}v=J}q=q+v*I;if((kdc(p,B,5,w,v)|0)!=0){C=21;break}if((B|0)>=(c[p+131548>>2]|0)){if(v<.995){C=33;break}}do{if((B|0)>4){if(((c[p+147400>>2]|0)-B|0)<4){break}if(!(q>20.0)){if(!(+h[e+32>>3]<.75)){break}}if((H|0)!=0){break}if(+h[f>>3]>100.0){C=33;break a}if(+h[k>>3]>3.0){C=33;break a}if(+h[j>>3]<-2.0){C=33;break a}if(q-r<2.0){C=33;break a}}}while(0);nrc(a|0,e|0,144)|0;r=q}if((C|0)!=14)if((C|0)==21){z=0;q=r}else if((C|0)==33){q=r}if((B|0)>0){K=(~~((1.0-v)*100.0)|0)/(B|0)|0}else{K=0}c[p+147412>>2]=K;if((c[p+114116>>2]|0)==1){if((c[p+131752>>2]|0)!=0){K=c[p+114208>>2]|0;k=p+114136|0;f=Crc(c[k>>2]|0,c[k+4>>2]|0,100,0)|0;k=Erc(K,(K|0)<0|0?-1:0,f,G)|0;c[n>>2]=k;c[n+4>>2]=G;k=p+131688|0;f=c[k+4>>2]|0;K=c[n+4>>2]|0;if((f|0)>(K|0)|(f|0)==(K|0)&(c[k>>2]|0)>>>0>(c[n>>2]|0)>>>0){k=p+131688|0;K=xrc(c[k>>2]|0,c[k+4>>2]|0,c[n>>2]|0,c[n+4>>2]|0)|0;n=Erc(K,G,2,0)|0;K=Crc(n,G,3,0)|0;if(+(c[p+131592>>2]|0)<0.0){L=+(c[p+131592>>2]|0)-1.0e-6}else{L=+(c[p+131592>>2]|0)+1.0e-6}M=(+(K>>>0)+ +(G|0)*4294967296.0)*16.0/L}else{M=0.0}}else{K=p+131688|0;n=c[K+4>>2]|0;k=0;if((n|0)>(k|0)|(n|0)==(k|0)&(c[K>>2]|0)>>>0>0>>>0){K=p+131688|0;k=Erc(c[K>>2]|0,c[K+4>>2]|0,2,0)|0;K=Crc(k,G,3,0)|0;if(+(c[p+131592>>2]|0)<0.0){N=+(c[p+131592>>2]|0)-1.0e-6}else{N=+(c[p+131592>>2]|0)+1.0e-6}M=(+(K>>>0)+ +(G|0)*4294967296.0)*16.0/N}else{M=0.0}}if(q>M){q=M}}if(((c[p+147400>>2]|0)-B|0)<4){while(1){if((B|0)>=(c[p+147400>>2]|0)){break}B=B+1|0;if(-1==(Xcc(p,a)|0)){C=61;break}if((B|0)<(c[p+147400>>2]|0)){u=+Zcc(p,a);s=s+u}}}c[p+142320>>2]=~~(q*100.0)>>4;y=udc(p,0,B-1|0,B-1|0,l,m)|0;do{if((z|0)!=0){if((B|0)<4){C=111;break}if((B|0)>((c[p+147400>>2]|0)-4|0)){C=111;break}if(!(+h[e+32>>3]>.75)){if(!(+h[e+48>>3]>.5)){C=111;break}}if(!(+h[j>>3]/+(B|0)>-.2)){if(!(+h[j>>3]>-2.0)){C=111;break}}if((c[m>>2]|0)<=100){C=111;break}if((c[l>>2]|0)<=100){C=111;break}if((c[p+114176>>2]|0)<0){O=c[p+131492>>2]|0}else{O=c[p+114176>>2]|0}K=O;k=0;c[p+142320>>2]=y;n=p+147432|0;f=c[n+4>>2]|0;g=0;do{if((f|0)>(g|0)|(f|0)==(g|0)&(c[n>>2]|0)>>>0>0>>>0){D=p+147440|0;H=c[D+4>>2]|0;P=0;if(!((H|0)>(P|0)|(H|0)==(P|0)&(c[D>>2]|0)>>>0>0>>>0)){C=81;break}D=p+147432|0;P=p+147440|0;S=~~((+((c[D>>2]|0)>>>0)+ +(c[D+4>>2]|0)*4294967296.0)*(s/(+((c[P>>2]|0)>>>0)+ +(c[P+4>>2]|0)*4294967296.0)))}else{C=81}}while(0);if((C|0)==81){S=0}n=(ca(y,c[244320+(K<<2)>>2]|0)|0)/100|0;n=n+(B*50|0)|0;if((n|0)>(((c[p+131552>>2]|0)+1|0)*200|0|0)){n=((c[p+131552>>2]|0)+1|0)*200|0}else{if((n|0)<125){n=125}}g=(B*100|0)+n|0;while(1){if((n|0)<=1e3){break}n=(n|0)/2|0;g=(g|0)/2|0}k=~~(+(n|0)*(+(S|0)/+(g|0)));K=vdc(p,u,k)|0;if((K|0)<(c[p+131732>>2]|0)){K=(c[p+114260>>2]|0)-1|0;f=(c[p+114260>>2]|0)-1|0;c[p+114612>>2]=1;c[p+131552>>2]=B;P=c[p+131552>>2]>>1;D=~~(+h[p+147016>>3]- +h[a>>3]-1.0);H=c[p+114268>>2]|0;if((H|0)==1){f=0;if((K|0)>(P|0)){K=P}}else if((H|0)==2){if((f|0)>(P|0)){f=P}if((f|0)>(D|0)){f=D}K=0}else if((H|0)==3){C=101}else{C=101}if((C|0)==101){f=f>>1;if((f|0)>(D|0)){f=D}if((f|0)>(P|0)){f=P}K=f;if((K|0)<(P|0)){K=K+((c[p+114260>>2]|0)+1&1)|0}}c[p+131556>>2]=K+1+f}else{c[p+114612>>2]=0;c[p+131552>>2]=B}}else{C=111}}while(0);if((C|0)==111){c[p+114612>>2]=0;c[p+131552>>2]=B}if((c[p+147400>>2]|0)>=(~~(+h[p+147016>>3]- +((c[p+113700>>2]|0)>>>0>>>0))|0)){a=p+147336|0;S=c[a+4>>2]|0;O=0;if((S|0)>(O|0)|(S|0)==(O|0)&(c[a>>2]|0)>>>0>0>>>0){a=p+147336|0;T=c[a+4>>2]|0;U=c[a>>2]|0}else{T=0;U=0}a=p+147432|0;c[a>>2]=U;c[a+4>>2]=T}T=p+147432|0;a=c[T+4>>2]|0;U=0;do{if((a|0)>(U|0)|(a|0)==(U|0)&(c[T>>2]|0)>>>0>0>>>0){O=p+147440|0;S=c[O+4>>2]|0;l=0;if(!((S|0)>(l|0)|(S|0)==(l|0)&(c[O>>2]|0)>>>0>0>>>0)){C=120;break}O=p+147432|0;l=p+147440|0;q=(+((c[O>>2]|0)>>>0)+ +(c[O+4>>2]|0)*4294967296.0)*(s/(+((c[l>>2]|0)>>>0)+ +(c[l+4>>2]|0)*4294967296.0));l=(F=+q,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);O=p+147448|0;c[O>>2]=~~+q>>>0;c[O+4>>2]=l}else{C=120}}while(0);if((C|0)==120){T=p+147448|0;c[T>>2]=0;c[T+4>>2]=0}T=p+147448|0;U=c[T+4>>2]|0;a=0;if((U|0)<(a|0)|(U|0)==(a|0)&(c[T>>2]|0)>>>0<0>>>0){V=0;W=0}else{T=p+147448|0;a=c[T+4>>2]|0;U=p+147432|0;l=c[U+4>>2]|0;if((a|0)>(l|0)|(a|0)==(l|0)&(c[T>>2]|0)>>>0>(c[U>>2]|0)>>>0){U=p+147432|0;X=c[U+4>>2]|0;Y=c[U>>2]|0}else{U=p+147448|0;X=c[U+4>>2]|0;Y=c[U>>2]|0}V=X;W=Y}Y=p+147448|0;c[Y>>2]=W;c[Y+4>>2]=V;V=p+147448|0;Y=c[V>>2]|0;W=c[V+4>>2]|0;V=b;X=c[p+131552>>2]|0;U=Erc(V,(V|0)<0|0?-1:0,X,(X|0)<0|0?-1:0)|0;X=G;if((W|0)>(X|0)|(W|0)==(X|0)&Y>>>0>U>>>0){U=b;b=c[p+131552>>2]|0;Y=Erc(U,(U|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;b=p+147448|0;c[b>>2]=Y;c[b+4>>2]=G}Ycc(p,A);b=p+147368|0;h[b>>3]=+h[b>>3]+s;B=0;while(1){if((c[p+114612>>2]|0)!=0){Z=(c[p+107976>>2]|0)!=0}else{Z=0}if((B|0)>(Z&1|0)){break}if((c[p+114176>>2]|0)<0){_=c[p+131492>>2]|0}else{_=c[p+114176>>2]|0}b=_;do{if((c[p+114612>>2]|0)!=0){if((B|0)!=0){C=144;break}$=(ca(y,c[244320+(b<<2)>>2]|0)|0)/100|0;$=$+((c[p+131552>>2]|0)*50|0)|0;if(($|0)>(((c[p+131552>>2]|0)+1|0)*200|0|0)){$=((c[p+131552>>2]|0)+1|0)*200|0}else{if(($|0)<125){$=125}}aa=(((c[p+131552>>2]|0)+1|0)*100|0)+$|0}else{C=144}}while(0);if((C|0)==144){C=0;$=(ca(c[p+142320>>2]|0,c[244320+(b<<2)>>2]|0)|0)/100|0;if(($|0)>((c[p+131552>>2]|0)*150|0|0)){$=(c[p+131552>>2]|0)*150|0}else{if(($|0)<125){$=125}}aa=((c[p+131552>>2]|0)*100|0)+($-100)|0}while(1){if(($|0)<=1e3){break}$=($|0)/2|0;aa=(aa|0)/2|0}b=p+147448|0;k=~~(+($|0)*((+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0)/+(aa|0)));if(u<s/+(c[p+131552>>2]|0)){b=p+147432|0;g=p+147440|0;if(+((c[g>>2]|0)>>>0)+ +(c[g+4>>2]|0)*4294967296.0<0.0){g=p+147440|0;da=+((c[g>>2]|0)>>>0)+ +(c[g+4>>2]|0)*4294967296.0-1.0e-6}else{g=p+147440|0;da=+((c[g>>2]|0)>>>0)+ +(c[g+4>>2]|0)*4294967296.0+1.0e-6}g=~~(+($|0)*((+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0)*u*+(c[p+131552>>2]|0)/da/+(aa|0)));if((k|0)>(g|0)){k=g}}else{g=p+147432|0;b=p+147440|0;if(+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0<0.0){b=p+147440|0;ea=+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0-1.0e-6}else{b=p+147440|0;ea=+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0+1.0e-6}b=~~((+((c[g>>2]|0)>>>0)+ +(c[g+4>>2]|0)*4294967296.0)*u/ea);if((b|0)>(k|0)){k=b}}if((c[p+114116>>2]|0)==1){b=p+131688|0;g=c[b+4>>2]|0;g>>1|((g|0)<0|0?-1:0)<<31;if((c[p+147456>>2]|0)>((c[b>>2]|0)>>>1|g<<31|0)){g=p+131688|0;b=c[g+4>>2]|0;b>>1|((b|0)<0|0?-1:0)<<31;c[p+147456>>2]=(c[g>>2]|0)>>>1|b<<31}}if((k|0)<0){k=0}k=k+(c[p+131596>>2]|0)|0;if((B|0)==0){c[p+147456>>2]=k}do{if((B|0)==1){C=177}else{if((c[p+114612>>2]|0)!=0){break}if((c[p+107976>>2]|0)!=0){C=177}}}while(0);if((C|0)==177){C=0;c[p+131588>>2]=k}B=B+1|0}ea=s;aa=(F=+ea,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);$=p+147440|0;y=xrc(c[$>>2]|0,c[$+4>>2]|0,~~+ea>>>0,aa)|0;c[$>>2]=y;c[$+4>>2]=G;$=p+147448|0;y=p+147432|0;aa=xrc(c[y>>2]|0,c[y+4>>2]|0,c[$>>2]|0,c[$+4>>2]|0)|0;c[y>>2]=aa;c[y+4>>2]=G;y=p+147432|0;aa=c[y+4>>2]|0;$=0;if((aa|0)<($|0)|(aa|0)==($|0)&(c[y>>2]|0)>>>0<0>>>0){y=p+147432|0;c[y>>2]=0;c[y+4>>2]=0}do{if((c[p+114612>>2]|0)!=0){C=185}else{if((c[p+107976>>2]|0)==0){C=185;break}c[p+147424>>2]=~~(s-t)}}while(0);if((C|0)==185){c[p+147424>>2]=~~s}C=(c[p+147456>>2]|0)-(c[p+131596>>2]|0)|0;y=p+147448|0;$=xrc(c[y>>2]|0,c[y+4>>2]|0,C,(C|0)<0|0?-1:0)|0;c[y>>2]=$;c[y+4>>2]=G;y=p+147448|0;$=c[y+4>>2]|0;C=0;if(($|0)<(C|0)|($|0)==(C|0)&(c[y>>2]|0)>>>0<0>>>0){y=p+147448|0;c[y>>2]=0;c[y+4>>2]=0}if((c[p+131552>>2]|0)>=3){if((c[p+114612>>2]|0)!=0){fa=c[m>>2]|0}else{fa=c[p+142320>>2]|0}m=fa;if((m|0)>=150){fa=(m-100|0)/50|0;if((fa|0)>20){ga=20}else{ga=fa}fa=ga;ga=p+147448|0;m=fa;fa=Erc(c[ga>>2]|0,c[ga+4>>2]|0,m,(m|0)<0|0?-1:0)|0;c[p+147460>>2]=(fa|0)/100|0;fa=c[p+147460>>2]|0;m=p+147448|0;ga=xrc(c[m>>2]|0,c[m+4>>2]|0,fa,(fa|0)<0|0?-1:0)|0;c[m>>2]=ga;c[m+4>>2]=G;m=p+147460|0;c[m>>2]=(c[m>>2]|0)/((c[p+131552>>2]|0)-1>>1|0)|0}else{c[p+147460>>2]=0}}else{c[p+147460>>2]=0}if((c[p+107976>>2]|0)==0){i=d;return}Occ(o);Ycc(p,A);B=0;while(1){if((B|0)>=(c[p+131552>>2]|0)){break}Xcc(p,e)|0;Vcc(o,e);B=B+1|0}mdc(o);if(+h[o+16>>3]<0.0){ia=+h[o+16>>3]-1.0e-6}else{ia=+h[o+16>>3]+1.0e-6}c[p+146856>>2]=~~(+h[o+8>>3]/ia);if(+h[o+16>>3]<0.0){ja=+h[o+16>>3]-1.0e-6}else{ja=+h[o+16>>3]+1.0e-6}h[p+146864>>3]=1.0-(+h[o+8>>3]/ja-10.0)*.025;if(+h[p+146864>>3]<.8){h[p+146864>>3]=.8}Ycc(p,A);i=d;return}function cdc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0.0,g=0.0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;a=ldc(e)|0;f=+Zcc(e,b);if((c[e+147424>>2]|0)>0){g=f/+(c[e+147424>>2]|0)}else{g=0.0}b=e+147448|0;h=~~((+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0)*g);if((h|0)<0){h=0}else{if((h|0)>(a|0)){h=a}a=h;b=(a|0)<0|0?-1:0;j=e+147448|0;k=c[j+4>>2]|0;if((b|0)>(k|0)|(b|0)==(k|0)&a>>>0>(c[j>>2]|0)>>>0){h=c[e+147448>>2]|0}}j=e+147424|0;c[j>>2]=(c[j>>2]|0)-~~f;j=h;a=e+147448|0;k=xrc(c[a>>2]|0,c[a+4>>2]|0,j,(j|0)<0|0?-1:0)|0;c[a>>2]=k;c[a+4>>2]=G;a=e+147448|0;k=c[a+4>>2]|0;j=0;if((k|0)<(j|0)|(k|0)==(j|0)&(c[a>>2]|0)>>>0<0>>>0){a=e+147448|0;c[a>>2]=0;c[a+4>>2]=0}h=h+(c[e+131596>>2]|0)|0;if((c[e+131520>>2]&1|0)==0){l=h;m=e;n=m+131588|0;c[n>>2]=l;i=d;return}if((c[e+131524>>2]|0)<=0){l=h;m=e;n=m+131588|0;c[n>>2]=l;i=d;return}h=h+(c[e+147460>>2]|0)|0;l=h;m=e;n=m+131588|0;c[n>>2]=l;i=d;return}function ddc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;if((c[e+147168>>2]|0)>>>0>=(c[e+147172>>2]|0)>>>0){f=-1;g=f;i=d;return g|0}else{nrc(b|0,c[e+147168>>2]|0,144)|0;f=1;g=f;i=d;return g|0}return 0}function edc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;d=i;i=i+8|0;e=d|0;f=b;g=+h[f+32>>3]/+h[f+136>>3];j=+h[f+40>>3]/+h[f+136>>3];k=1.0-g;l=+qdc(g-j);m=+qdc(j);n=+qdc(k);b=~~(+h[f+120>>3]/+h[f+136>>3])<<3<<9;o=((g-j)*l+j*m+k*n)*+(c[a+107988>>2]|0);a=Erc(~~+o>>>0,(F=+o,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0),512,0)|0;c[e>>2]=a;c[e+4>>2]=G;a=b;b=wrc(a,(a|0)<0|0?-1:0,c[e>>2]|0,c[e+4>>2]|0)|0;e=G;i=d;return(G=e,b)|0}function fdc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0.0,k=0.0,l=0,m=0,n=0.0,o=0.0,p=0;f=i;g=a;a=b;b=d;d=c[g+107988>>2]|0;j=+h[a+16>>3]/+h[a+136>>3]/+(d|0);k=1.0;if((b|0)<1048576){l=(b<<9|0)/(d|0)|0}else{l=((b|0)/(d|0)|0)<<9}b=l;l=(e|0)/(d|0)|0;if((c[g+142360>>2]|0)==3){m=6}else{if((c[g+142360>>2]|0)==1){m=6}}if((m|0)==6){if((c[g+114088>>2]|0)<=5){k=1.04+ +(c[g+114088>>2]|0)*.04}else{k=1.25}}if(+h[g+146896>>3]<0.0){n=+h[g+146896>>3]-1.0e-6}else{n=+h[g+146896>>3]+1.0e-6}o=1.0-(+h[g+146888>>3]/n-10.0)*.025;if(o<.8){o=.8}d=0;while(1){if((d|0)>=127){break}n=+pdc(j,100.0,.4,.9,d);e=(c[247400+(d<<2)>>2]|0)+l|0;e=~~(n*k*o*+(e|0)+.5);l=~~(+(l|0)*.98);if((e|0)<=(b|0)){m=18;break}d=d+1|0}d=c[1634304+(d<<2)>>2]|0;if((d|0)>=(c[g+131732>>2]|0)){d=(c[g+131732>>2]|0)-1|0}if((d|0)>=(c[g+131740>>2]|0)){p=d;i=f;return p|0}d=c[g+131740>>2]|0;p=d;i=f;return p|0}function gdc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0.0,k=0.0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0;f=i;g=a;a=b;b=d;d=e;e=c[g+107988>>2]|0;j=+h[a+16>>3]/+h[a+136>>3]/+(e|0);k=1.0;if((b|0)<=0){l=c[g+147404>>2]|0;m=l;i=f;return m|0}if((b|0)<1048576){n=(b<<9|0)/(e|0)|0}else{n=((b|0)/(e|0)|0)<<9}b=n;do{if((c[g+131704>>2]|0)>0){if((c[g+131736>>2]|0)>=(c[g+131732>>2]|0)){break}o=+(c[g+131708>>2]|0)/+(c[g+131704>>2]|0);if(o<.95){n=g+147464|0;h[n>>3]=+h[n>>3]-.005}else{if(o>1.05){n=g+147464|0;h[n>>3]=+h[n>>3]+.005}}if(+h[g+147464>>3]<.1){p=.1}else{if(+h[g+147464>>3]>10.0){q=10.0}else{q=+h[g+147464>>3]}p=q}h[g+147464>>3]=p}}while(0);if((c[g+142360>>2]|0)==3){r=22}else{if((c[g+142360>>2]|0)==1){r=22}}if((r|0)==22){if((c[g+114088>>2]|0)<=5){k=1.04+ +(c[g+114088>>2]|0)*.04}else{k=1.25}}n=(d|0)/(e|0)|0;n=~~(+(n|0)*+T(+.98,+(+(c[g+147408>>2]|0))));e=c[g+147408>>2]|0;while(1){if((e|0)>=(c[g+147404>>2]|0)){break}p=+pdc(j,150.0,.4,.9,e);d=(c[247400+(e<<2)>>2]|0)+n|0;d=~~(p*k*+h[g+147464>>3]*+h[g+146864>>3]*+(d|0)+.5);n=~~(+(n|0)*.98);if((d|0)<=(b|0)){r=29;break}e=e+1|0}do{if((c[g+114116>>2]|0)==2){if((e|0)>=(c[g+131748>>2]|0)){break}e=c[g+131748>>2]|0}}while(0);do{if((c[g+131648>>2]|0)>(~~+h[g+147016>>3]>>8|0)){if((c[g+131648>>2]|0)<=150){break}if(((c[g+131640>>2]|0)+32|0)<(c[g+131732>>2]|0)){s=(c[g+131640>>2]|0)+32|0}else{s=c[g+131732>>2]|0}c[g+147404>>2]=s;if(((c[g+131640>>2]|0)-32|0)>(c[g+131740>>2]|0)){t=(c[g+131640>>2]|0)-32|0}else{t=c[g+131740>>2]|0}c[g+147408>>2]=t}}while(0);l=e;m=l;i=f;return m|0}function hdc(a,b){a=a|0;b=b|0;var c=0;c=a;a=b;b=c|0;h[b>>3]=+h[b>>3]- +h[a>>3];b=c+8|0;h[b>>3]=+h[b>>3]- +h[a+8>>3];b=c+16|0;h[b>>3]=+h[b>>3]- +h[a+16>>3];b=c+24|0;h[b>>3]=+h[b>>3]- +h[a+24>>3];b=c+32|0;h[b>>3]=+h[b>>3]- +h[a+32>>3];b=c+40|0;h[b>>3]=+h[b>>3]- +h[a+40>>3];b=c+48|0;h[b>>3]=+h[b>>3]- +h[a+48>>3];b=c+56|0;h[b>>3]=+h[b>>3]- +h[a+56>>3];b=c+64|0;h[b>>3]=+h[b>>3]- +h[a+64>>3];b=c+72|0;h[b>>3]=+h[b>>3]- +h[a+72>>3];b=c+80|0;h[b>>3]=+h[b>>3]- +h[a+80>>3];b=c+88|0;h[b>>3]=+h[b>>3]- +h[a+88>>3];b=c+96|0;h[b>>3]=+h[b>>3]- +h[a+96>>3];b=c+104|0;h[b>>3]=+h[b>>3]- +h[a+104>>3];b=c+112|0;h[b>>3]=+h[b>>3]- +h[a+112>>3];b=c+120|0;h[b>>3]=+h[b>>3]- +h[a+120>>3];b=c+136|0;h[b>>3]=+h[b>>3]- +h[a+136>>3];b=c+128|0;h[b>>3]=+h[b>>3]- +h[a+128>>3];i=i;return}function idc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0;f=i;i=i+144|0;g=f|0;j=a;a=b;b=d;d=e;e=0;if(!(+h[b+48>>3]<.1)){k=e;i=f;return k|0}if(!(+h[d+48>>3]<.1)){k=e;i=f;return k|0}do{if(!(+h[b+32>>3]<.05)){if(!(+h[b+32>>3]- +h[b+56>>3]<.25)){k=e;i=f;return k|0}if(+h[b+16>>3]<0.0){l=+h[b+16>>3]-1.0e-6}else{l=+h[b+16>>3]+1.0e-6}if(!(+h[b+8>>3]/l<2.5)){k=e;i=f;return k|0}m=+R(+(+h[a+16>>3]- +h[b+16>>3]));if(+h[b+16>>3]<0.0){n=+h[b+16>>3]-1.0e-6}else{n=+h[b+16>>3]+1.0e-6}if(m/n>.4){break}m=+R(+(+h[a+8>>3]- +h[b+8>>3]));if(+h[b+8>>3]<0.0){o=+h[b+8>>3]-1.0e-6}else{o=+h[b+8>>3]+1.0e-6}if(m/o>.4){break}if(+h[d+16>>3]<0.0){p=+h[d+16>>3]-1.0e-6}else{p=+h[d+16>>3]+1.0e-6}if(+h[d+8>>3]/p>3.5){break}k=e;i=f;return k|0}}while(0);p=0.0;o=0.0;n=1.0;nrc(g|0,d|0,144)|0;d=c[j+147168>>2]|0;b=0;while(1){if((b|0)>=16){break}if(+h[g+16>>3]<0.0){q=+h[g+16>>3]-1.0e-6}else{q=+h[g+16>>3]+1.0e-6}l=1.4*+h[g+8>>3]/q;if(l>14.0){l=14.0}if(+h[g+32>>3]>.85){n=n*+h[g+32>>3]}else{n=n*((+h[g+32>>3]+.85)/2.0)}p=p+n*l;if(+h[g+32>>3]<.05){r=37;break}if(l<1.5){r=37;break}if(+h[g+32>>3]- +h[g+56>>3]<.2){if(l<3.0){r=37;break}}if(p-o<.5){r=37;break}if(+h[g+8>>3]<200.0){r=37;break}o=p;if(-1==(Xcc(j,g)|0)){r=39;break}b=b+1|0}do{if(p>5.0){if((b|0)<=3){r=45;break}e=1}else{r=45}}while(0);if((r|0)==45){Ycc(j,d);e=0}k=e;i=f;return k|0}function jdc(a,b){a=a|0;b=b|0;var c=0,d=0.0,e=0.0,f=0.0,g=0.0,j=0.0,k=0.0;a=i;c=b;d=+h[c+40>>3];e=+h[c+32>>3];f=1.0-d/20.0;if(f<e){e=f}f=+R(+(+h[c+72>>3]*d));g=+R(+(+h[c+88>>3]*d));d=+S(f*f+g*g)/250.0;if(d>1.0){j=0.0}else{j=1.0-d}d=j;if(!(d<e)){k=e;i=a;return+k}e=d;k=e;i=a;return+k}function kdc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=+e;f=+f;var g=0,h=0,j=0,k=0.0,l=0,m=0,n=0;g=i;i=i+144|0;h=g|0;j=a;a=d;k=f;d=0;do{if((b|0)>4){if(!(e>=.999)){break}if(!(k<.9)){break}l=c[j+147168>>2]|0;m=0;while(1){if((m|0)>=(a|0)){break}if(-1==(Xcc(j,h)|0)){n=7;break}if(+jdc(j,h)<.999){n=9;break}m=m+1|0}Ycc(j,l);if((m|0)==(a|0)){d=1}}}while(0);i=g;return d|0}function ldc(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0.0,j=0,k=0,l=0;b=i;d=a;if((c[d+114116>>2]|0)==1){a=d+131688|0;e=d+114136|0;if(+((c[e>>2]|0)>>>0)+ +(c[e+4>>2]|0)*4294967296.0<0.0){e=d+114136|0;f=+((c[e>>2]|0)>>>0)+ +(c[e+4>>2]|0)*4294967296.0-1.0e-6}else{e=d+114136|0;f=+((c[e>>2]|0)>>>0)+ +(c[e+4>>2]|0)*4294967296.0+1.0e-6}g=(+((c[a>>2]|0)>>>0)+ +(c[a+4>>2]|0)*4294967296.0)/f;j=~~(+(c[d+131592>>2]|0)*(+(c[d+114220>>2]|0)/100.0));if(g<1.0){if((c[d+131592>>2]>>2|0)<(j>>2|0)){k=c[d+131592>>2]>>2}else{k=j>>2}a=k;j=~~(+(j|0)*g);if((j|0)<(a|0)){j=a}}}else{a=d+147336|0;j=~~((+((c[a>>2]|0)>>>0)+ +(c[a+4>>2]|0)*4294967296.0)/(+h[d+147016>>3]- +((c[d+113700>>2]|0)>>>0>>>0))*(+(c[d+114220>>2]|0)/100.0))}if((j|0)>=0){l=j;i=b;return l|0}j=0;l=j;i=b;return l|0}function mdc(a){a=a|0;var b=0,c=0;b=i;c=a;if(+h[c+136>>3]<1.0){i=b;return}else{a=c+8|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+16|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+24|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+32|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+48|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+56|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+40|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+64|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+72|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+80|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+88|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+96|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+104|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+112|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];a=c+128|0;h[a>>3]=+h[a>>3]/+h[c+136>>3];i=b;return}}function ndc(a,b,d,e){a=a|0;b=+b;d=d|0;e=+e;var f=0,g=0,h=0.0,j=0,k=0.0,l=0.0,m=0.0,n=0.0,o=0,p=0,q=0.0,r=0.0,s=0,t=0,u=0;f=i;g=a;h=e;a=c[g+107988>>2]|0;j=(d<<9|0)/(a|0)|0;e=b/+(a|0);b=1.0;k=1.0;if(+(c[g+114212>>2]|0)/100.0<.6){l=+(c[g+114212>>2]|0)/100.0+.3}else{l=.9}m=l;if(+(c[g+114212>>2]|0)/100.0<.7){n=+(c[g+114212>>2]|0)/100.0+.1}else{n=.8}l=n;n=1.0;if((j|0)<=0){o=254;p=o;i=f;return p|0}if((c[g+131712>>2]|0)<=0){k=10.0}else{k=+(c[g+131716>>2]|0)/+(c[g+131712>>2]|0);if(k>10.0){q=10.0}else{if(k<.1){r=.1}else{r=k}q=r}k=q}n=1.0-(h-6.0)*.1;if(n<.5){n=.5}if((c[g+142360>>2]|0)==3){s=22}else{if((c[g+142360>>2]|0)==1){s=22}}if((s|0)==22){if((c[g+114088>>2]|0)<=5){b=1.04+ +(c[g+114088>>2]|0)*.04}else{b=1.25}}h=b*n*k;g=0;while(1){if((g|0)>=127){break}k=+pdc(e,150.0,l,m,g)*h;t=~~(k*+(c[247400+(g<<2)>>2]|0)+.5);if((t|0)<=(j|0)){s=29;break}g=g+1|0}while(1){if((t|0)>(j|0)){u=(g|0)<254}else{u=0}if(!u){break}t=~~(+(t|0)*.96);g=g+1|0}o=g;p=o;i=f;return p|0}function odc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=b;b=d;d=a;if((d|0)==2){c[f>>2]=3;c[b>>2]=5;i=e;return}else if((d|0)==0){c[f>>2]=1;c[b>>2]=1;i=e;return}else if((d|0)==1){c[f>>2]=4;c[b>>2]=5;i=e;return}else if((d|0)==3){c[f>>2]=1;c[b>>2]=2;i=e;return}else{c[f>>2]=1;c[b>>2]=1;Cd(2295856,2548568,91,2653472)}}function pdc(a,b,c,d,e){a=+a;b=+b;c=+c;d=+d;e=e|0;var f=0,g=0.0,h=0.0,j=0.0,k=0.0,l=0.0;f=i;g=d;d=c+ +(e|0)*.01;if(d>g){h=g}else{h=d}d=h;h=+T(+(a/b),+d);if(h<.05){j=.05;h=j;k=h;i=f;return+k}if(h>5.0){l=5.0}else{l=h}j=l;h=j;k=h;i=f;return+k}function qdc(a){a=+a;var b=0,c=0.0,d=0.0,e=0.0;b=i;c=a;if(c>122.0e-6){d=(-0.0- +aa(c))/+aa(2.0);e=d;i=b;return+e}else{d=13.0;e=d;i=b;return+e}return 0.0}function rdc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=i;i=i+144|0;d=c|0;e=0;if(!((wdc(a,d,b)|0)!=-1)){f=e;i=c;return f|0}do{if(+h[d+48>>3]>+h[d+32>>3]){if(!(+h[d+48>>3]>=.5)){break}e=1}}while(0);f=e;i=c;return f|0}function sdc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;a=i;g=b;b=f;j=+h[g+40>>3];h[c>>3]=+h[g+112>>3]*j;c=d;h[c>>3]=+h[c>>3]+ +h[g+112>>3]*j;k=+R(+(+h[g+112>>3]*j));c=e;h[c>>3]=+h[c>>3]+k;if(!(j>.05)){i=a;return}k=+R(+(+h[g+72>>3]));if(+R(+(+h[g+64>>3]))<0.0){l=+R(+(+h[g+64>>3]))-1.0e-6}else{l=+R(+(+h[g+64>>3]))+1.0e-6}m=k/l;l=+R(+(+h[g+88>>3]));if(+R(+(+h[g+80>>3]))<0.0){n=+R(+(+h[g+80>>3]))-1.0e-6}else{n=+R(+(+h[g+80>>3]))+1.0e-6}k=l/n;if(m<+h[g+72>>3]){o=m*j}else{o=+h[g+72>>3]*j}c=b;h[c>>3]=+h[c>>3]+o;if(k<+h[g+88>>3]){p=k*j}else{p=+h[g+88>>3]*j}g=b;h[g>>3]=+h[g>>3]+p;i=a;return}function tdc(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0.0,g=0.0,j=0.0,k=0.0,l=0.0;d=i;e=a;a=b;f=c;if(+h[a+8>>3]>+h[e+147392>>3]){if(+h[a+16>>3]<0.0){g=+h[a+16>>3]-1.0e-6}else{g=+h[a+16>>3]+1.0e-6}j=1.5*+h[a+8>>3]/g}else{if(+h[a+16>>3]<0.0){k=+h[a+16>>3]-1.0e-6}else{k=+h[a+16>>3]+1.0e-6}j=1.5*+h[e+147392>>3]/k}if(f>0.0){j=j+j*f*2.0}else{j=j+j*(f/2.0)}if(!(j>48.0)){l=j;i=d;return+l}j=48.0;l=j;i=d;return+l}function udc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0,u=0.0,v=0,w=0.0,x=0,y=0.0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;j=i;i=i+176|0;k=j|0;l=j+144|0;m=j+152|0;n=j+160|0;o=j+168|0;p=a;a=b;b=d;d=e;e=f;f=g;q=0.0;h[l>>3]=0.0;r=1.0;h[m>>3]=0.0;h[n>>3]=0.0;h[o>>3]=0.0;g=0;s=0;while(1){if((s|0)>=(b|0)){break}if((wdc(p,k,s+a|0)|0)==-1){t=4;break}sdc(p,k,m,n,o,l);u=+tdc(p,k,+h[m>>3]);if((rdc(p,s+a|0)|0)!=0){v=1}else{v=(rdc(p,s+a+1|0)|0)!=0}g=v&1;if((g|0)==0){r=r*+jdc(p,k);if(r<.1){w=.1}else{w=r}r=w}q=q+r*u;if((g|0)==0){if(+h[l>>3]>100.0){t=16;break}if(+h[o>>3]>3.0){t=16;break}if(+h[n>>3]<-2.0){t=16;break}}s=s+1|0}c[e>>2]=~~(q*100.0)>>4;q=0.0;h[l>>3]=0.0;r=1.0;h[m>>3]=0.0;h[n>>3]=0.0;h[o>>3]=0.0;s=-1;while(1){if((s|0)<(-d|0)){t=37;break}if((wdc(p,k,s+a|0)|0)==-1){t=22;break}sdc(p,k,m,n,o,l);u=+tdc(p,k,+h[m>>3]);if((rdc(p,s+a|0)|0)!=0){x=1}else{x=(rdc(p,s+a+1|0)|0)!=0}g=x&1;if((g|0)==0){r=r*+jdc(p,k);if(r<.1){y=.1}else{y=r}r=y}q=q+r*u;if((g|0)==0){if(+h[l>>3]>100.0){t=34;break}if(+h[o>>3]>3.0){t=34;break}if(+h[n>>3]<-2.0){t=34;break}}s=s-1|0}if((t|0)==22){z=q;A=z*100.0;B=~~A;C=B>>4;D=f;c[D>>2]=C;E=e;F=c[E>>2]|0;G=f;H=c[G>>2]|0;I=F+H|0;i=j;return I|0}else if((t|0)==34){z=q;A=z*100.0;B=~~A;C=B>>4;D=f;c[D>>2]=C;E=e;F=c[E>>2]|0;G=f;H=c[G>>2]|0;I=F+H|0;i=j;return I|0}else if((t|0)==37){z=q;A=z*100.0;B=~~A;C=B>>4;D=f;c[D>>2]=C;E=e;F=c[E>>2]|0;G=f;H=c[G>>2]|0;I=F+H|0;i=j;return I|0}return 0}function vdc(a,b,d){a=a|0;b=+b;d=d|0;var e=0,f=0,g=0.0,j=0,k=0,l=0.0,m=0;e=i;f=a;a=d;d=c[f+107988>>2]|0;g=b/+(d|0);b=1.0;if((a|0)<1048576){j=(a<<9|0)/(d|0)|0}else{j=((a|0)/(d|0)|0)<<9}d=j;if((c[f+142360>>2]|0)==3){k=6}else{if((c[f+142360>>2]|0)==1){k=6}}if((k|0)==6){if((c[f+114088>>2]|0)<=5){b=1.04+ +(c[f+114088>>2]|0)*.04}else{b=1.25}}j=0;while(1){if((j|0)>=127){k=16;break}l=+pdc(g,150.0,.4,.9,j)*b;if((~~(l*+h[f+147464>>3]*+(c[247400+(j<<2)>>2]|0)/1.0+.5)|0)<=(d|0)){break}j=j+1|0}if((k|0)==16){m=j;i=e;return m|0}m=j;i=e;return m|0}function wdc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;d=c[f+147168>>2]|0;do{if((b|0)>=0){if(!((d+(b*144|0)|0)>>>0>=(c[f+147172>>2]|0)>>>0)){break}g=-1;h=g;i=e;return h|0}else{do{if((b|0)<0){if(!((d+(b*144|0)|0)>>>0<(c[f+147176>>2]|0)>>>0)){break}g=-1;h=g;i=e;return h|0}}while(0)}}while(0);nrc(a|0,d+(b*144|0)|0,144)|0;g=1;h=g;i=e;return h|0}function xdc(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)==0){i=b;return}if((c[d+16>>2]|0)!=0){a=0;while(1){if(!(a>>>0<(c[d>>2]|0)>>>0)){break}H7b((c[d+16>>2]|0)+(a*120|0)|0)|0;a=a+1|0}Qqc(c[d+16>>2]|0)}Qqc(d);i=b;return}function ydc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=d;d=0;if(b>>>0<1>>>0){b=1}else{if(b>>>0>25>>>0){b=25}}b=b+1|0;f=f+15&-16;a=a+15&-16;d=Rqc(1,20)|0;a:do{if((d|0)!=0){c[d>>2]=b;c[d+16>>2]=Rqc(b,120)|0;do{if((c[d+16>>2]|0)!=0){g=0;while(1){if(!(g>>>0<b>>>0)){h=15;break}if((J7b((c[d+16>>2]|0)+(g*120|0)|0,f,a,32)|0)!=0){h=12;break}g=g+1|0}if((h|0)==12){break}else if((h|0)==15){break a}}}while(0);xdc(d);j=0;k=j;i=e;return k|0}}while(0);j=d;k=j;i=e;return k|0}function zdc(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=i;i=i+16|0;m=l|0;n=l+8|0;o=b;b=d;c[m>>2]=e;c[m+4>>2]=f;c[n>>2]=g;c[n+4>>2]=h;h=j;j=k;k=(c[b+4>>2]|0)+15>>4;g=(c[b>>2]|0)+15>>4;if(((c[o+4>>2]|0)+2|0)>>>0>(c[o>>2]|0)>>>0){p=1;q=p;i=l;return q|0}f=o+4|0;c[f>>2]=(c[f>>2]|0)+1;f=Adc(o,o+12|0)|0;do{if((c[o>>2]|0)==1){if((j|0)==0){r=27;break}if((h|0)!=0){r=27;break}e=0;while(1){if((e|0)>=(k|0)){break}d=0;while(1){while(1){if((d|0)>=(g|0)){break}if((a[j+d|0]|0)!=0){r=12;break}d=d+1|0}if((r|0)==12){r=0}if((d|0)==(g|0)){break}s=d;while(1){if((s|0)>=(g|0)){break}if((a[j+s|0]|0)==0){r=20;break}s=s+1|0}if((r|0)==20){r=0}apc(b,f|0,e<<4,d<<4,16,s-d<<4);d=s}j=j+g|0;e=e+1|0}}else{r=27}}while(0);if((r|0)==27){_oc(b,f|0)}b=c[m+4>>2]|0;r=f+96|0;c[r>>2]=c[m>>2];c[r+4>>2]=b;b=c[n+4>>2]|0;r=f+104|0;c[r>>2]=c[n>>2];c[r+4>>2]=b;c[f+112>>2]=h;p=0;q=p;i=l;return q|0}function Adc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=a;a=b;b=c[a>>2]|0;f=(c[e+16>>2]|0)+(b*120|0)|0;if(b>>>0<(c[e>>2]|0)>>>0){}else{Cd(2338880,2548160,36,2651696);return 0}g=b+1|0;b=g;if(!(g>>>0>=(c[e>>2]|0)>>>0)){h=b;j=a;c[j>>2]=h;k=f;i=d;return k|0}b=b-(c[e>>2]|0)|0;h=b;j=a;c[j>>2]=h;k=f;i=d;return k|0}function Bdc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=0;if((c[e+4>>2]|0)==0){f=a;i=d;return f|0}do{if((b|0)==0){if((c[e+4>>2]|0)==((c[e>>2]|0)-1|0)){break}f=a;i=d;return f|0}}while(0);a=Adc(e,e+8|0)|0;b=e+4|0;c[b>>2]=(c[b>>2]|0)-1;f=a;i=d;return f|0}function Cdc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=b;b=d;d=0;if((b|0)==1){if(a>>>0<((c[f>>2]|0)-1|0)>>>0){}else{Cd(2294240,2548160,202,2650912);return 0}if(a>>>0<(c[f+4>>2]|0)>>>0){a=a+(c[f+8>>2]|0)|0;if(a>>>0>=(c[f>>2]|0)>>>0){a=a-(c[f>>2]|0)|0}d=(c[f+16>>2]|0)+(a*120|0)|0}g=d;i=e;return g|0}if((b|0)==-1){if((a|0)==1){}else{Cd(2419176,2548160,213,2650912);return 0}if((c[f+8>>2]|0)==0){a=(c[f>>2]|0)-1|0}else{a=(c[f+8>>2]|0)-a|0}d=(c[f+16>>2]|0)+(a*120|0)|0}g=d;i=e;return g|0}function Ddc(a){a=a|0;i=i;return c[a+4>>2]|0}function Edc(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=d;d=e;e=(ca((c[(c[d>>2]|0)+((b[g>>1]|0)-(b[a>>1]|0)>>1<<2)>>2]|0)+(c[(c[d+4>>2]|0)+((b[g+2>>1]|0)-(b[a+2>>1]|0)>>1<<2)>>2]|0)|0,f)|0)>>7;i=i;return e|0}function Fdc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=d;d=0;g=128;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=0;b[(c[f+6348>>2]|0)+(d<<3)>>1]=0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=0;d=d+1|0;while(1){if((g|0)<=0){break}b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=0;b[(c[f+6348>>2]|0)+(d<<3)>>1]=-g;h=ca(-g|0,a)|0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=h;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=0;b[(c[f+6348>>2]|0)+(d<<3)>>1]=g;h=ca(g,a)|0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=h;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=-g;b[(c[f+6348>>2]|0)+(d<<3)>>1]=0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=-g;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=g;b[(c[f+6348>>2]|0)+(d<<3)>>1]=0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=g;d=d+1|0;g=(g|0)/2|0}c[f+6352>>2]=d;c[f+6356>>2]=4;i=e;return}function Gdc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=d;d=0;g=128;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=0;b[(c[f+6348>>2]|0)+(d<<3)>>1]=0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=0;d=d+1|0;while(1){if((g|0)<=0){break}b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=0;b[(c[f+6348>>2]|0)+(d<<3)>>1]=-g;h=ca(-g|0,a)|0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=h;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=0;b[(c[f+6348>>2]|0)+(d<<3)>>1]=g;h=ca(g,a)|0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=h;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=-g;b[(c[f+6348>>2]|0)+(d<<3)>>1]=0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=-g;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=g;b[(c[f+6348>>2]|0)+(d<<3)>>1]=0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=g;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=-g;b[(c[f+6348>>2]|0)+(d<<3)>>1]=-g;h=(ca(-g|0,a)|0)-g|0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=h;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=g;b[(c[f+6348>>2]|0)+(d<<3)>>1]=-g;h=(ca(-g|0,a)|0)+g|0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=h;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=-g;b[(c[f+6348>>2]|0)+(d<<3)>>1]=g;h=(ca(g,a)|0)-g|0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=h;d=d+1|0;b[(c[f+6348>>2]|0)+(d<<3)+2>>1]=g;b[(c[f+6348>>2]|0)+(d<<3)>>1]=g;h=(ca(g,a)|0)+g|0;c[(c[f+6348>>2]|0)+(d<<3)+4>>2]=h;d=d+1|0;g=(g|0)/2|0}c[f+6352>>2]=d;c[f+6356>>2]=8;i=e;return}function Hdc(a,d,e,f,g,h,j,k,l,m){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0;n=i;i=i+8|0;o=n|0;p=a;a=d;d=f;f=g;g=h;h=j;j=k;k=l;l=m;m=(c[c[a+36>>2]>>2]|0)+(c[a+40>>2]|0)|0;q=b[f>>1]>>1;r=b[f+2>>1]>>1;s=b[d>>1]<<2;t=b[d+2>>1]<<2;u=s;v=t;w=4;x=4;if((c[p+6432>>2]<<2|0)>((b[f+2>>1]>>1)-1023|0)){y=c[p+6432>>2]<<2}else{y=(b[f+2>>1]>>1)-1023|0}z=y;if((c[p+6436>>2]<<2|0)<((b[f+2>>1]>>1)+1023|0)){A=c[p+6436>>2]<<2}else{A=(b[f+2>>1]>>1)+1023|0}y=A;if((c[p+6440>>2]<<2|0)>((b[f>>1]>>1)-1023|0)){B=c[p+6440>>2]<<2}else{B=(b[f>>1]>>1)-1023|0}A=B;if((c[p+6444>>2]<<2|0)<((b[f>>1]>>1)+1023|0)){C=c[p+6444>>2]<<2}else{C=(b[f>>1]>>1)+1023|0}B=C;C=c[p+6016>>2]|0;D=(c[p+6052>>2]|0)+(c[e+16>>2]|0)+(ca(b[d>>1]|0,C)|0)|0;e=D+(b[d+2>>1]|0)|0;D=C;C=ca(b[d>>1]|0,D)|0;p=C+(b[d+2>>1]|0)|0;C=d|0;b[C>>1]=b[C>>1]<<3;C=d+2|0;b[C>>1]=b[C>>1]<<3;C=Xe[c[h+4>>2]&511](e,D,m,c[a+44>>2]|0,l)|0;c[k>>2]=C;C=C+(Idc(d,f,j,g)|0)|0;while(1){E=w-1|0;w=E;if((E|0)==0){break}do{if((v-2|0)>=(z|0)){if((v-2|0)>(y|0)){F=25;break}if((u|0)<(A|0)){F=25;break}if((u|0)>(B|0)){F=25;break}E=e+((ca(u>>2,D)|0)+(v-2>>2)-p)|0;G=me[c[h+8>>2]&255](E,D,(v-2&3)<<1,(u&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){H=(ca((c[(c[j>>2]|0)+(u-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-2-r<<2)>>2]|0)|0,g)|0)+128>>8}else{H=0}E=H+G|0;I=E;if(E>>>0<C>>>0){C=I;s=u;t=v-2|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=25}}while(0);if((F|0)==25){F=0;I=-1}do{if((v+2|0)>=(z|0)){if((v+2|0)>(y|0)){F=36;break}if((u|0)<(A|0)){F=36;break}if((u|0)>(B|0)){F=36;break}E=e+((ca(u>>2,D)|0)+(v+2>>2)-p)|0;G=me[c[h+8>>2]&255](E,D,(v+2&3)<<1,(u&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){J=(ca((c[(c[j>>2]|0)+(u-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v+2-r<<2)>>2]|0)|0,g)|0)+128>>8}else{J=0}E=J+G|0;K=E;if(E>>>0<C>>>0){C=K;s=u;t=v+2|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=36}}while(0);if((F|0)==36){F=0;K=-1}do{if((v|0)>=(z|0)){if((v|0)>(y|0)){F=47;break}if((u-2|0)<(A|0)){F=47;break}if((u-2|0)>(B|0)){F=47;break}E=e+((ca(u-2>>2,D)|0)+(v>>2)-p)|0;G=me[c[h+8>>2]&255](E,D,(v&3)<<1,(u-2&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){L=(ca((c[(c[j>>2]|0)+(u-2-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-r<<2)>>2]|0)|0,g)|0)+128>>8}else{L=0}E=L+G|0;M=E;if(E>>>0<C>>>0){C=M;s=u-2|0;t=v;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=47}}while(0);if((F|0)==47){F=0;M=-1}do{if((v|0)>=(z|0)){if((v|0)>(y|0)){F=58;break}if((u+2|0)<(A|0)){F=58;break}if((u+2|0)>(B|0)){F=58;break}E=e+((ca(u+2>>2,D)|0)+(v>>2)-p)|0;G=me[c[h+8>>2]&255](E,D,(v&3)<<1,(u+2&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){N=(ca((c[(c[j>>2]|0)+(u+2-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-r<<2)>>2]|0)|0,g)|0)+128>>8}else{N=0}E=N+G|0;O=E;if(E>>>0<C>>>0){C=O;s=u+2|0;t=v;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=58}}while(0);if((F|0)==58){F=0;O=-1}P=(I>>>0<K>>>0?0:1)+(M>>>0<O>>>0?0:2)|0;E=P;if((E|0)==0){do{if((v-2|0)>=(z|0)){if((v-2|0)>(y|0)){F=70;break}if((u-2|0)<(A|0)){F=70;break}if((u-2|0)>(B|0)){F=70;break}Q=e+((ca(u-2>>2,D)|0)+(v-2>>2)-p)|0;G=me[c[h+8>>2]&255](Q,D,(v-2&3)<<1,(u-2&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){S=(ca((c[(c[j>>2]|0)+(u-2-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-2-r<<2)>>2]|0)|0,g)|0)+128>>8}else{S=0}Q=S+G|0;T=Q;if(Q>>>0<C>>>0){C=T;s=u-2|0;t=v-2|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=70}}while(0);if((F|0)==70){F=0;T=-1}}else if((E|0)==2){do{if((v-2|0)>=(z|0)){if((v-2|0)>(y|0)){F=94;break}if((u+2|0)<(A|0)){F=94;break}if((u+2|0)>(B|0)){F=94;break}Q=e+((ca(u+2>>2,D)|0)+(v-2>>2)-p)|0;G=me[c[h+8>>2]&255](Q,D,(v-2&3)<<1,(u+2&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){U=(ca((c[(c[j>>2]|0)+(u+2-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-2-r<<2)>>2]|0)|0,g)|0)+128>>8}else{U=0}Q=U+G|0;T=Q;if(Q>>>0<C>>>0){C=T;s=u+2|0;t=v-2|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=94}}while(0);if((F|0)==94){F=0;T=-1}}else if((E|0)==3){do{if((v+2|0)>=(z|0)){if((v+2|0)>(y|0)){F=106;break}if((u+2|0)<(A|0)){F=106;break}if((u+2|0)>(B|0)){F=106;break}Q=e+((ca(u+2>>2,D)|0)+(v+2>>2)-p)|0;G=me[c[h+8>>2]&255](Q,D,(v+2&3)<<1,(u+2&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){V=(ca((c[(c[j>>2]|0)+(u+2-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v+2-r<<2)>>2]|0)|0,g)|0)+128>>8}else{V=0}Q=V+G|0;T=Q;if(Q>>>0<C>>>0){C=T;s=u+2|0;t=v+2|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=106}}while(0);if((F|0)==106){F=0;T=-1}}else if((E|0)==1){do{if((v+2|0)>=(z|0)){if((v+2|0)>(y|0)){F=82;break}if((u-2|0)<(A|0)){F=82;break}if((u-2|0)>(B|0)){F=82;break}Q=e+((ca(u-2>>2,D)|0)+(v+2>>2)-p)|0;G=me[c[h+8>>2]&255](Q,D,(v+2&3)<<1,(u-2&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){W=(ca((c[(c[j>>2]|0)+(u-2-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v+2-r<<2)>>2]|0)|0,g)|0)+128>>8}else{W=0}Q=W+G|0;T=Q;if(Q>>>0<C>>>0){C=T;s=u-2|0;t=v+2|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=82}}while(0);if((F|0)==82){F=0;T=-1}}if((u|0)==(s|0)){if((v|0)==(t|0)){F=110;break}}u=s;v=t}while(1){W=x-1|0;x=W;if((W|0)==0){break}do{if((v-1|0)>=(z|0)){if((v-1|0)>(y|0)){F=124;break}if((u|0)<(A|0)){F=124;break}if((u|0)>(B|0)){F=124;break}W=e+((ca(u>>2,D)|0)+(v-1>>2)-p)|0;G=me[c[h+8>>2]&255](W,D,(v-1&3)<<1,(u&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){X=(ca((c[(c[j>>2]|0)+(u-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-1-r<<2)>>2]|0)|0,g)|0)+128>>8}else{X=0}W=X+G|0;I=W;if(W>>>0<C>>>0){C=I;s=u;t=v-1|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=124}}while(0);if((F|0)==124){F=0;I=-1}do{if((v+1|0)>=(z|0)){if((v+1|0)>(y|0)){F=135;break}if((u|0)<(A|0)){F=135;break}if((u|0)>(B|0)){F=135;break}W=e+((ca(u>>2,D)|0)+(v+1>>2)-p)|0;G=me[c[h+8>>2]&255](W,D,(v+1&3)<<1,(u&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){Y=(ca((c[(c[j>>2]|0)+(u-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v+1-r<<2)>>2]|0)|0,g)|0)+128>>8}else{Y=0}W=Y+G|0;K=W;if(W>>>0<C>>>0){C=K;s=u;t=v+1|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=135}}while(0);if((F|0)==135){F=0;K=-1}do{if((v|0)>=(z|0)){if((v|0)>(y|0)){F=146;break}if((u-1|0)<(A|0)){F=146;break}if((u-1|0)>(B|0)){F=146;break}W=e+((ca(u-1>>2,D)|0)+(v>>2)-p)|0;G=me[c[h+8>>2]&255](W,D,(v&3)<<1,(u-1&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){Z=(ca((c[(c[j>>2]|0)+(u-1-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-r<<2)>>2]|0)|0,g)|0)+128>>8}else{Z=0}W=Z+G|0;M=W;if(W>>>0<C>>>0){C=M;s=u-1|0;t=v;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=146}}while(0);if((F|0)==146){F=0;M=-1}do{if((v|0)>=(z|0)){if((v|0)>(y|0)){F=157;break}if((u+1|0)<(A|0)){F=157;break}if((u+1|0)>(B|0)){F=157;break}W=e+((ca(u+1>>2,D)|0)+(v>>2)-p)|0;G=me[c[h+8>>2]&255](W,D,(v&3)<<1,(u+1&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){_=(ca((c[(c[j>>2]|0)+(u+1-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-r<<2)>>2]|0)|0,g)|0)+128>>8}else{_=0}W=_+G|0;O=W;if(W>>>0<C>>>0){C=O;s=u+1|0;t=v;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=157}}while(0);if((F|0)==157){F=0;O=-1}P=(I>>>0<K>>>0?0:1)+(M>>>0<O>>>0?0:2)|0;W=P;if((W|0)==2){do{if((v-1|0)>=(z|0)){if((v-1|0)>(y|0)){F=193;break}if((u+1|0)<(A|0)){F=193;break}if((u+1|0)>(B|0)){F=193;break}V=e+((ca(u+1>>2,D)|0)+(v-1>>2)-p)|0;G=me[c[h+8>>2]&255](V,D,(v-1&3)<<1,(u+1&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){$=(ca((c[(c[j>>2]|0)+(u+1-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-1-r<<2)>>2]|0)|0,g)|0)+128>>8}else{$=0}V=$+G|0;T=V;if(V>>>0<C>>>0){C=T;s=u+1|0;t=v-1|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=193}}while(0);if((F|0)==193){F=0;T=-1}}else if((W|0)==1){do{if((v+1|0)>=(z|0)){if((v+1|0)>(y|0)){F=181;break}if((u-1|0)<(A|0)){F=181;break}if((u-1|0)>(B|0)){F=181;break}V=e+((ca(u-1>>2,D)|0)+(v+1>>2)-p)|0;G=me[c[h+8>>2]&255](V,D,(v+1&3)<<1,(u-1&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){aa=(ca((c[(c[j>>2]|0)+(u-1-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v+1-r<<2)>>2]|0)|0,g)|0)+128>>8}else{aa=0}V=aa+G|0;T=V;if(V>>>0<C>>>0){C=T;s=u-1|0;t=v+1|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=181}}while(0);if((F|0)==181){F=0;T=-1}}else if((W|0)==3){do{if((v+1|0)>=(z|0)){if((v+1|0)>(y|0)){F=205;break}if((u+1|0)<(A|0)){F=205;break}if((u+1|0)>(B|0)){F=205;break}V=e+((ca(u+1>>2,D)|0)+(v+1>>2)-p)|0;G=me[c[h+8>>2]&255](V,D,(v+1&3)<<1,(u+1&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){ba=(ca((c[(c[j>>2]|0)+(u+1-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v+1-r<<2)>>2]|0)|0,g)|0)+128>>8}else{ba=0}V=ba+G|0;T=V;if(V>>>0<C>>>0){C=T;s=u+1|0;t=v+1|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=205}}while(0);if((F|0)==205){F=0;T=-1}}else if((W|0)==0){do{if((v-1|0)>=(z|0)){if((v-1|0)>(y|0)){F=169;break}if((u-1|0)<(A|0)){F=169;break}if((u-1|0)>(B|0)){F=169;break}V=e+((ca(u-1>>2,D)|0)+(v-1>>2)-p)|0;G=me[c[h+8>>2]&255](V,D,(v-1&3)<<1,(u-1&3)<<1,m,c[a+44>>2]|0,o)|0;if((j|0)!=0){da=(ca((c[(c[j>>2]|0)+(u-1-q<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(v-1-r<<2)>>2]|0)|0,g)|0)+128>>8}else{da=0}V=da+G|0;T=V;if(V>>>0<C>>>0){C=T;s=u-1|0;t=v-1|0;c[k>>2]=G;c[l>>2]=c[o>>2]}}else{F=169}}while(0);if((F|0)==169){F=0;T=-1}}if((u|0)==(s|0)){if((v|0)==(t|0)){F=209;break}}u=s;v=t}b[d>>1]=s<<1;b[d+2>>1]=t<<1;do{if((R((b[d+2>>1]|0)-(b[f+2>>1]|0)|0)|0)<=2040){if((R((b[d>>1]|0)-(b[f>>1]|0)|0)|0)>2040){break}ea=C;fa=ea;i=n;return fa|0}}while(0);ea=2147483647;fa=ea;i=n;return fa|0}function Idc(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=d;d=e;if((d|0)!=0){j=(ca((c[(c[d>>2]|0)+((b[h>>1]|0)-(b[a>>1]|0)>>1<<2)>>2]|0)+(c[(c[d+4>>2]|0)+((b[h+2>>1]|0)-(b[a+2>>1]|0)>>1<<2)>>2]|0)|0,f)|0)+128>>8;k=j;i=g;return k|0}else{j=0;k=j;i=g;return k|0}return 0}function Jdc(a,d,e,f,g,h,j,k,l,m){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;n=i;i=i+24|0;o=n|0;p=n+8|0;q=n+16|0;r=a;a=d;d=f;f=g;g=h;h=j;j=k;k=l;l=m;m=2147483647;s=(c[c[a+36>>2]>>2]|0)+(c[a+40>>2]|0)|0;t=c[r+6016>>2]|0;u=(c[r+6052>>2]|0)+(c[e+16>>2]|0)+(ca(b[d>>1]|0,t)|0)|0;e=u+(b[d+2>>1]|0)|0;u=t;t=d|0;b[t>>1]=b[t>>1]<<3;t=d+2|0;b[t>>1]=b[t>>1]<<3;c[o>>2]=c[d>>2];m=Xe[c[h+4>>2]&511](e,u,s,c[a+44>>2]|0,l)|0;c[k>>2]=m;m=m+(Idc(d,f,j,g)|0)|0;b[p>>1]=b[o>>1]|0;b[p+2>>1]=(b[o+2>>1]|0)-8|4;t=Xe[c[h+12>>2]&511](e-1|0,u,s,c[a+44>>2]|0,q)|0;r=t+(Idc(p,f,j,g)|0)|0;if((r|0)<(m|0)){c[d>>2]=c[p>>2];m=r;c[k>>2]=t;c[l>>2]=c[q>>2]}v=p+2|0;b[v>>1]=(b[v>>1]|0)+8;t=Xe[c[h+12>>2]&511](e,u,s,c[a+44>>2]|0,q)|0;v=t+(Idc(p,f,j,g)|0)|0;if((v|0)<(m|0)){c[d>>2]=c[p>>2];m=v;c[k>>2]=t;c[l>>2]=c[q>>2]}b[p+2>>1]=b[o+2>>1]|0;b[p>>1]=(b[o>>1]|0)-8|4;t=Xe[c[h+16>>2]&511](e+(-u|0)|0,u,s,c[a+44>>2]|0,q)|0;w=t+(Idc(p,f,j,g)|0)|0;if((w|0)<(m|0)){c[d>>2]=c[p>>2];m=w;c[k>>2]=t;c[l>>2]=c[q>>2]}x=p|0;b[x>>1]=(b[x>>1]|0)+8;t=Xe[c[h+16>>2]&511](e,u,s,c[a+44>>2]|0,q)|0;x=t+(Idc(p,f,j,g)|0)|0;if((x|0)<(m|0)){c[d>>2]=c[p>>2];m=x;c[k>>2]=t;c[l>>2]=c[q>>2]}y=((r|0)<(v|0)?0:1)+((w|0)<(x|0)?0:2)|0;c[p>>2]=c[o>>2];z=y;if((z|0)==3){A=14}else if((z|0)==1){B=p+2|0;b[B>>1]=(b[B>>1]|0)+4;b[p>>1]=(b[p>>1]|0)-8|4;t=Xe[c[h+20>>2]&511](e+(-u|0)|0,u,s,c[a+44>>2]|0,q)|0}else if((z|0)==0){b[p+2>>1]=(b[p+2>>1]|0)-8|4;b[p>>1]=(b[p>>1]|0)-8|4;t=Xe[c[h+20>>2]&511](e-1+(-u|0)|0,u,s,c[a+44>>2]|0,q)|0}else if((z|0)==2){b[p+2>>1]=(b[p+2>>1]|0)-8|4;z=p|0;b[z>>1]=(b[z>>1]|0)+4;t=Xe[c[h+20>>2]&511](e-1|0,u,s,c[a+44>>2]|0,q)|0}else{A=14}if((A|0)==14){A=p+2|0;b[A>>1]=(b[A>>1]|0)+4;A=p|0;b[A>>1]=(b[A>>1]|0)+4;t=Xe[c[h+20>>2]&511](e,u,s,c[a+44>>2]|0,q)|0}A=t+(Idc(p,f,j,g)|0)|0;if((A|0)<(m|0)){c[d>>2]=c[p>>2];m=A;c[k>>2]=t;c[l>>2]=c[q>>2]}if((b[d>>1]|0)<(b[o>>1]|0)){e=e+(-u|0)|0}if((b[d+2>>1]|0)<(b[o+2>>1]|0)){e=e-1|0}c[o>>2]=c[d>>2];b[p>>1]=b[o>>1]|0;if((b[o+2>>1]&7|0)!=0){b[p+2>>1]=(b[o+2>>1]|0)-2;t=me[c[h+8>>2]&255](e,u,b[p+2>>1]&7,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}else{b[p+2>>1]=(b[o+2>>1]|0)-8|6;t=me[c[h+8>>2]&255](e-1|0,u,6,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}r=t+(Idc(p,f,j,g)|0)|0;if((r|0)<(m|0)){c[d>>2]=c[p>>2];m=r;c[k>>2]=t;c[l>>2]=c[q>>2]}z=p+2|0;b[z>>1]=(b[z>>1]|0)+4;t=me[c[h+8>>2]&255](e,u,b[p+2>>1]&7,b[p>>1]&7,s,c[a+44>>2]|0,q)|0;v=t+(Idc(p,f,j,g)|0)|0;if((v|0)<(m|0)){c[d>>2]=c[p>>2];m=v;c[k>>2]=t;c[l>>2]=c[q>>2]}b[p+2>>1]=b[o+2>>1]|0;if((b[o>>1]&7|0)!=0){b[p>>1]=(b[o>>1]|0)-2;t=me[c[h+8>>2]&255](e,u,b[p+2>>1]&7,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}else{b[p>>1]=(b[o>>1]|0)-8|6;t=me[c[h+8>>2]&255](e+(-u|0)|0,u,b[p+2>>1]&7,6,s,c[a+44>>2]|0,q)|0}w=t+(Idc(p,f,j,g)|0)|0;if((w|0)<(m|0)){c[d>>2]=c[p>>2];m=w;c[k>>2]=t;c[l>>2]=c[q>>2]}z=p|0;b[z>>1]=(b[z>>1]|0)+4;t=me[c[h+8>>2]&255](e,u,b[p+2>>1]&7,b[p>>1]&7,s,c[a+44>>2]|0,q)|0;x=t+(Idc(p,f,j,g)|0)|0;if((x|0)<(m|0)){c[d>>2]=c[p>>2];m=x;c[k>>2]=t;c[l>>2]=c[q>>2]}y=((r|0)<(v|0)?0:1)+((w|0)<(x|0)?0:2)|0;c[p>>2]=c[o>>2];x=y;if((x|0)==0){if((b[o>>1]&7|0)!=0){y=p|0;b[y>>1]=(b[y>>1]|0)-2;if((b[o+2>>1]&7|0)!=0){y=p+2|0;b[y>>1]=(b[y>>1]|0)-2;t=me[c[h+8>>2]&255](e,u,b[p+2>>1]&7,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}else{b[p+2>>1]=(b[o+2>>1]|0)-8|6;t=me[c[h+8>>2]&255](e-1|0,u,6,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}}else{b[p>>1]=(b[o>>1]|0)-8|6;if((b[o+2>>1]&7|0)!=0){y=p+2|0;b[y>>1]=(b[y>>1]|0)-2;t=me[c[h+8>>2]&255](e+(-u|0)|0,u,b[p+2>>1]&7,6,s,c[a+44>>2]|0,q)|0}else{b[p+2>>1]=(b[o+2>>1]|0)-8|6;t=me[c[h+8>>2]&255](e+(-u|0)-1|0,u,6,6,s,c[a+44>>2]|0,q)|0}}}else if((x|0)==1){y=p+2|0;b[y>>1]=(b[y>>1]|0)+2;if((b[o>>1]&7|0)!=0){y=p|0;b[y>>1]=(b[y>>1]|0)-2;t=me[c[h+8>>2]&255](e,u,b[p+2>>1]&7,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}else{b[p>>1]=(b[o>>1]|0)-8|6;t=me[c[h+8>>2]&255](e+(-u|0)|0,u,b[p+2>>1]&7,6,s,c[a+44>>2]|0,q)|0}}else if((x|0)==2){y=p|0;b[y>>1]=(b[y>>1]|0)+2;if((b[o+2>>1]&7|0)!=0){y=p+2|0;b[y>>1]=(b[y>>1]|0)-2;t=me[c[h+8>>2]&255](e,u,b[p+2>>1]&7,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}else{b[p+2>>1]=(b[o+2>>1]|0)-8|6;t=me[c[h+8>>2]&255](e-1|0,u,6,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}}else if((x|0)==3){x=p+2|0;b[x>>1]=(b[x>>1]|0)+2;x=p|0;b[x>>1]=(b[x>>1]|0)+2;t=me[c[h+8>>2]&255](e,u,b[p+2>>1]&7,b[p>>1]&7,s,c[a+44>>2]|0,q)|0}A=t+(Idc(p,f,j,g)|0)|0;if((A|0)>=(m|0)){C=m;i=n;return C|0}c[d>>2]=c[p>>2];m=A;c[k>>2]=t;c[l>>2]=c[q>>2];C=m;i=n;return C|0}function Kdc(a,d,e,f,g,h,j,k,l,m){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;n=i;i=i+24|0;o=n|0;p=n+8|0;q=n+16|0;r=a;a=d;d=f;f=g;g=h;h=j;j=k;k=l;l=m;m=2147483647;s=(c[c[a+36>>2]>>2]|0)+(c[a+40>>2]|0)|0;t=c[r+6016>>2]|0;u=(c[r+6052>>2]|0)+(c[e+16>>2]|0)+(ca(b[d>>1]|0,t)|0)|0;e=u+(b[d+2>>1]|0)|0;u=t;t=d|0;b[t>>1]=b[t>>1]<<3;t=d+2|0;b[t>>1]=b[t>>1]<<3;c[o>>2]=c[d>>2];m=Xe[c[h+4>>2]&511](e,u,s,c[a+44>>2]|0,l)|0;c[k>>2]=m;m=m+(Idc(d,f,j,g)|0)|0;b[p>>1]=b[o>>1]|0;b[p+2>>1]=(b[o+2>>1]|0)-8|4;t=Xe[c[h+12>>2]&511](e-1|0,u,s,c[a+44>>2]|0,q)|0;r=t+(Idc(p,f,j,g)|0)|0;if((r|0)<(m|0)){c[d>>2]=c[p>>2];m=r;c[k>>2]=t;c[l>>2]=c[q>>2]}v=p+2|0;b[v>>1]=(b[v>>1]|0)+8;t=Xe[c[h+12>>2]&511](e,u,s,c[a+44>>2]|0,q)|0;v=t+(Idc(p,f,j,g)|0)|0;if((v|0)<(m|0)){c[d>>2]=c[p>>2];m=v;c[k>>2]=t;c[l>>2]=c[q>>2]}b[p+2>>1]=b[o+2>>1]|0;b[p>>1]=(b[o>>1]|0)-8|4;t=Xe[c[h+16>>2]&511](e+(-u|0)|0,u,s,c[a+44>>2]|0,q)|0;w=t+(Idc(p,f,j,g)|0)|0;if((w|0)<(m|0)){c[d>>2]=c[p>>2];m=w;c[k>>2]=t;c[l>>2]=c[q>>2]}x=p|0;b[x>>1]=(b[x>>1]|0)+8;t=Xe[c[h+16>>2]&511](e,u,s,c[a+44>>2]|0,q)|0;x=t+(Idc(p,f,j,g)|0)|0;if((x|0)<(m|0)){c[d>>2]=c[p>>2];m=x;c[k>>2]=t;c[l>>2]=c[q>>2]}c[p>>2]=c[o>>2];o=((r|0)<(v|0)?0:1)+((w|0)<(x|0)?0:2)|0;if((o|0)==3){y=14}else if((o|0)==0){b[p+2>>1]=(b[p+2>>1]|0)-8|4;b[p>>1]=(b[p>>1]|0)-8|4;t=Xe[c[h+20>>2]&511](e-1+(-u|0)|0,u,s,c[a+44>>2]|0,q)|0}else if((o|0)==1){x=p+2|0;b[x>>1]=(b[x>>1]|0)+4;b[p>>1]=(b[p>>1]|0)-8|4;t=Xe[c[h+20>>2]&511](e+(-u|0)|0,u,s,c[a+44>>2]|0,q)|0}else if((o|0)==2){b[p+2>>1]=(b[p+2>>1]|0)-8|4;o=p|0;b[o>>1]=(b[o>>1]|0)+4;t=Xe[c[h+20>>2]&511](e-1|0,u,s,c[a+44>>2]|0,q)|0}else{y=14}if((y|0)==14){y=p+2|0;b[y>>1]=(b[y>>1]|0)+4;y=p|0;b[y>>1]=(b[y>>1]|0)+4;t=Xe[c[h+20>>2]&511](e,u,s,c[a+44>>2]|0,q)|0}a=t+(Idc(p,f,j,g)|0)|0;if((a|0)>=(m|0)){z=m;i=n;return z|0}c[d>>2]=c[p>>2];m=a;c[k>>2]=t;c[l>>2]=c[q>>2];z=m;i=n;return z|0}function Ldc(a,d,e,f,g,h,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=i;i=i+56|0;h=m|0;o=m+24|0;p=m+40|0;q=m+48|0;r=a;a=d;d=f;f=g;g=j;j=k;k=l;l=n;nrc(h|0,244296,24)|0;nrc(o|0,244280,16)|0;n=(c[c[a+36>>2]>>2]|0)+(c[a+40>>2]|0)|0;s=c[a+44>>2]|0;a=c[r+6016>>2]|0;t=c[r+6052>>2]|0;u=a;v=-1;w=-1;x=127;y=8;b[q>>1]=b[l>>1]>>3;b[q+2>>1]=b[l+2>>1]>>3;Mdc(d,c[r+6432>>2]|0,c[r+6436>>2]|0,c[r+6440>>2]|0,c[r+6444>>2]|0);l=b[d>>1]|0;z=b[d+2>>1]|0;d=t+(c[e+16>>2]|0)|0;e=d+(ca(l,a)|0)+z|0;b[p>>1]=l;b[p+2>>1]=z;a=Xe[c[j>>2]&511](n,s,e,u,-1)|0;t=a+(Ndc(p,q,k,g)|0)|0;a=1;a=a&(l-2|0)>=(c[r+6440>>2]|0);a=a&(l+2|0)<=(c[r+6444>>2]|0);a=a&(z-2|0)>=(c[r+6432>>2]|0);a=a&(z+2|0)<=(c[r+6436>>2]|0);if((a|0)!=0){A=0;while(1){if((A|0)>=6){break}b[p>>1]=l+(b[h+(A<<2)>>1]|0);b[p+2>>1]=z+(b[h+(A<<2)+2>>1]|0);B=d+(ca(b[p>>1]|0,u)|0)|0;e=B+(b[p+2>>1]|0)|0;C=Xe[c[j>>2]&511](n,s,e,u,t)|0;if(C>>>0<t>>>0){C=C+(Ndc(p,q,k,g)|0)|0;if(C>>>0<t>>>0){t=C;w=A}}A=A+1|0}}else{A=0;while(1){if((A|0)>=6){break}b[p>>1]=l+(b[h+(A<<2)>>1]|0);b[p+2>>1]=z+(b[h+(A<<2)+2>>1]|0);do{if((b[p+2>>1]|0)>=(c[r+6432>>2]|0)){if((b[p+2>>1]|0)>(c[r+6436>>2]|0)){break}if((b[p>>1]|0)<(c[r+6440>>2]|0)){break}if((b[p>>1]|0)>(c[r+6444>>2]|0)){break}B=d+(ca(b[p>>1]|0,u)|0)|0;e=B+(b[p+2>>1]|0)|0;C=Xe[c[j>>2]&511](n,s,e,u,t)|0;if(C>>>0<t>>>0){C=C+(Ndc(p,q,k,g)|0)|0;if(C>>>0<t>>>0){t=C;w=A}}}}while(0);A=A+1|0}}if(!((w|0)==-1)){l=l+(b[h+(w<<2)>>1]|0)|0;z=z+(b[h+(w<<2)+2>>1]|0)|0;v=w;D=1;while(1){if((D|0)>=(x|0)){break}w=-1;a=1;a=a&(l-2|0)>=(c[r+6440>>2]|0);a=a&(l+2|0)<=(c[r+6444>>2]|0);a=a&(z-2|0)>=(c[r+6432>>2]|0);a=a&(z+2|0)<=(c[r+6436>>2]|0);if((a|0)!=0){A=0;while(1){if((A|0)>=3){break}b[p>>1]=l+(b[785344+(v*12|0)+(A<<2)>>1]|0);b[p+2>>1]=z+(b[785344+(v*12|0)+(A<<2)+2>>1]|0);h=d+(ca(b[p>>1]|0,u)|0)|0;e=h+(b[p+2>>1]|0)|0;C=Xe[c[j>>2]&511](n,s,e,u,t)|0;if(C>>>0<t>>>0){C=C+(Ndc(p,q,k,g)|0)|0;if(C>>>0<t>>>0){t=C;w=A}}A=A+1|0}}else{A=0;while(1){if((A|0)>=3){break}b[p>>1]=l+(b[785344+(v*12|0)+(A<<2)>>1]|0);b[p+2>>1]=z+(b[785344+(v*12|0)+(A<<2)+2>>1]|0);do{if((b[p+2>>1]|0)>=(c[r+6432>>2]|0)){if((b[p+2>>1]|0)>(c[r+6436>>2]|0)){break}if((b[p>>1]|0)<(c[r+6440>>2]|0)){break}if((b[p>>1]|0)>(c[r+6444>>2]|0)){break}h=d+(ca(b[p>>1]|0,u)|0)|0;e=h+(b[p+2>>1]|0)|0;C=Xe[c[j>>2]&511](n,s,e,u,t)|0;if(C>>>0<t>>>0){C=C+(Ndc(p,q,k,g)|0)|0;if(C>>>0<t>>>0){t=C;w=A}}}}while(0);A=A+1|0}}if((w|0)==-1){E=61;break}l=l+(b[785344+(v*12|0)+(w<<2)>>1]|0)|0;z=z+(b[785344+(v*12|0)+(w<<2)+2>>1]|0)|0;v=v+(w+5)|0;if((v|0)>=12){v=v-12|0}else{if((v|0)>=6){v=v-6|0}}D=D+1|0}}D=0;while(1){if((D|0)>=(y|0)){E=105;break}w=-1;a=1;a=a&(l-1|0)>=(c[r+6440>>2]|0);a=a&(l+1|0)<=(c[r+6444>>2]|0);a=a&(z-1|0)>=(c[r+6432>>2]|0);a=a&(z+1|0)<=(c[r+6436>>2]|0);if((a|0)!=0){A=0;while(1){if((A|0)>=4){break}b[p>>1]=l+(b[o+(A<<2)>>1]|0);b[p+2>>1]=z+(b[o+(A<<2)+2>>1]|0);v=d+(ca(b[p>>1]|0,u)|0)|0;e=v+(b[p+2>>1]|0)|0;C=Xe[c[j>>2]&511](n,s,e,u,t)|0;if(C>>>0<t>>>0){C=C+(Ndc(p,q,k,g)|0)|0;if(C>>>0<t>>>0){t=C;w=A}}A=A+1|0}}else{A=0;while(1){if((A|0)>=4){break}b[p>>1]=l+(b[o+(A<<2)>>1]|0);b[p+2>>1]=z+(b[o+(A<<2)+2>>1]|0);do{if((b[p+2>>1]|0)>=(c[r+6432>>2]|0)){if((b[p+2>>1]|0)>(c[r+6436>>2]|0)){break}if((b[p>>1]|0)<(c[r+6440>>2]|0)){break}if((b[p>>1]|0)>(c[r+6444>>2]|0)){break}v=d+(ca(b[p>>1]|0,u)|0)|0;e=v+(b[p+2>>1]|0)|0;C=Xe[c[j>>2]&511](n,s,e,u,t)|0;if(C>>>0<t>>>0){C=C+(Ndc(p,q,k,g)|0)|0;if(C>>>0<t>>>0){t=C;w=A}}}}while(0);A=A+1|0}}if((w|0)==-1){break}l=l+(b[o+(w<<2)>>1]|0)|0;z=z+(b[o+(w<<2)+2>>1]|0)|0;D=D+1|0}if((E|0)==105){F=l;G=F&65535;H=f;I=H;J=I|0;b[J>>1]=G;K=z;L=K&65535;M=f;N=M;O=N+2|0;b[O>>1]=L;P=t;i=m;return P|0}F=l;G=F&65535;H=f;I=H;J=I|0;b[J>>1]=G;K=z;L=K&65535;M=f;N=M;O=N+2|0;b[O>>1]=L;P=t;i=m;return P|0}function Mdc(a,c,d,e,f){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;h=a;a=c;c=d;d=e;e=f;if((b[h+2>>1]|0)<(a|0)){j=a}else{j=b[h+2>>1]|0}b[h+2>>1]=j;if((b[h+2>>1]|0)>(c|0)){k=c}else{k=b[h+2>>1]|0}b[h+2>>1]=k;if((b[h>>1]|0)<(d|0)){l=d}else{l=b[h>>1]|0}b[h>>1]=l;if((b[h>>1]|0)>(e|0)){m=e;n=m&65535;o=h;p=o;q=p|0;b[q>>1]=n;i=g;return}else{m=b[h>>1]|0;n=m&65535;o=h;p=o;q=p|0;b[q>>1]=n;i=g;return}}function Ndc(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=d;d=e;if((d|0)!=0){j=(ca((c[(c[d>>2]|0)+((b[h>>1]|0)-(b[a>>1]|0)<<2)>>2]|0)+(c[(c[d+4>>2]|0)+((b[h+2>>1]|0)-(b[a+2>>1]|0)<<2)>>2]|0)|0,f)|0)+128>>8;k=j;i=g;return k|0}else{j=0;k=j;i=g;return k|0}return 0}function Odc(a,d,e,f,g,h,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;o=i;i=i+32|0;p=o|0;q=o+8|0;r=o+16|0;s=o+24|0;t=a;a=d;d=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=(c[c[a+36>>2]>>2]|0)+(c[a+40>>2]|0)|0;u=c[a+44>>2]|0;a=c[t+6016>>2]|0;v=c[t+6052>>2]|0;w=a;x=0;y=0;c[r>>2]=c[t+6404>>2];c[r+4>>2]=c[t+6408>>2];b[s>>1]=b[m>>1]>>3;b[s+2>>1]=b[m+2>>1]>>3;Mdc(d,c[t+6432>>2]|0,c[t+6436>>2]|0,c[t+6440>>2]|0,c[t+6444>>2]|0);z=b[d>>1]|0;A=b[d+2>>1]|0;c[j>>2]=0;b[f>>1]=z;b[f+2>>1]=A;d=v+(c[e+16>>2]|0)+(ca(z,a)|0)+A|0;A=d;a=Xe[c[k>>2]&511](n,u,d,w,-1)|0;z=a+(Ndc(f,s,r|0,h)|0)|0;a=ca(g,c[t+6356>>2]|0)|0;e=(c[t+6348>>2]|0)+(a<<3)|0;a=((c[t+6352>>2]|0)/(c[t+6356>>2]|0)|0)-g|0;g=1;v=0;while(1){if((v|0)>=(a|0)){break}B=0;while(1){if((B|0)>=(c[t+6356>>2]|0)){break}C=(b[f>>1]|0)+(b[e+(g<<3)>>1]|0)|0;D=(b[f+2>>1]|0)+(b[e+(g<<3)+2>>1]|0)|0;do{if((D|0)>(c[t+6432>>2]|0)){if((D|0)>=(c[t+6436>>2]|0)){break}if((C|0)<=(c[t+6440>>2]|0)){break}if((C|0)>=(c[t+6444>>2]|0)){break}c[q>>2]=Xe[c[k>>2]&511](n,u,A+(c[e+(g<<3)+4>>2]|0)|0,w,z)|0;if((c[q>>2]|0)>>>0<z>>>0){b[p>>1]=C;b[p+2>>1]=D;E=Ndc(p,s,r|0,h)|0;c[q>>2]=(c[q>>2]|0)+E;if((c[q>>2]|0)>>>0<z>>>0){z=c[q>>2]|0;x=g}}}}while(0);g=g+1|0;B=B+1|0}if((x|0)!=(y|0)){B=f|0;b[B>>1]=(b[B>>1]|0)+(b[e+(x<<3)>>1]|0);B=f+2|0;b[B>>1]=(b[B>>1]|0)+(b[e+(x<<3)+2>>1]|0);A=A+(c[e+(x<<3)+4>>2]|0)|0;y=x}else{if((A|0)==(d|0)){B=j;c[B>>2]=(c[B>>2]|0)+1}}v=v+1|0}b[p>>1]=b[f>>1]<<3;b[p+2>>1]=b[f+2>>1]<<3;f=Xe[c[k+4>>2]&511](n,u,A,w,q)|0;q=f+(Idc(p,m,l,c[t+6360>>2]|0)|0)|0;i=o;return q|0}function Pdc(a,d,e,f,g,h,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;m=i;i=i+32|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;r=a;a=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=(c[c[a+36>>2]>>2]|0)+(c[a+40>>2]|0)|0;s=c[a+44>>2]|0;a=c[r+6016>>2]|0;t=c[r+6052>>2]|0;u=a;v=a;w=d+24|0;x=b[e>>1]|0;y=b[e+2>>1]|0;e=x-g|0;z=x+g|0;A=y-g|0;B=y+g|0;c[p>>2]=c[r+6404>>2];c[p+4>>2]=c[r+6408>>2];b[q>>1]=b[k>>1]>>3;b[q+2>>1]=b[k+2>>1]>>3;g=t+(c[d+16>>2]|0)|0;d=g+(ca(x,a)|0)+y|0;b[w>>1]=x;b[w+2>>1]=y;y=Xe[c[h>>2]&511](l,s,d,u,-1)|0;x=y+(Ndc(w,q,p|0,f)|0)|0;if((A|0)<(c[r+6432>>2]|0)){A=c[r+6432>>2]|0}if((B|0)>(c[r+6436>>2]|0)){B=c[r+6436>>2]|0}if((e|0)<(c[r+6440>>2]|0)){e=c[r+6440>>2]|0}if((z|0)>(c[r+6444>>2]|0)){z=c[r+6444>>2]|0}y=e;while(1){if((y|0)>=(z|0)){break}b[n>>1]=y;e=g+(ca(y,v)|0)+A|0;a=A;while(1){if((a|0)>=(B|0)){break}c[o>>2]=Xe[c[h>>2]&511](l,s,e,u,x)|0;b[n+2>>1]=a;t=Ndc(n,q,p|0,f)|0;c[o>>2]=(c[o>>2]|0)+t;if((c[o>>2]|0)>>>0<x>>>0){x=c[o>>2]|0;b[w>>1]=y;b[w+2>>1]=a;d=e}e=e+1|0;a=a+1|0}y=y+1|0}b[n>>1]=b[w>>1]<<3;b[n+2>>1]=b[w+2>>1]<<3;w=Xe[c[h+4>>2]&511](l,s,d,u,o)|0;o=w+(Idc(n,k,j,c[r+6360>>2]|0)|0)|0;i=m;return o|0}function Qdc(a,d,e,f,g,h,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;m=i;i=i+48|0;n=m|0;o=m+16|0;p=m+24|0;q=m+32|0;r=m+40|0;s=a;a=d;d=f;f=g;g=h;h=j;j=k;k=l;nrc(n|0,238624,16)|0;l=c[a+44>>2]|0;t=c[s+6016>>2]|0;u=t;v=(c[c[a+36>>2]>>2]|0)+(c[a+40>>2]|0)|0;a=(c[s+6052>>2]|0)+(c[e+16>>2]|0)+(ca(b[d>>1]|0,t)|0)|0;t=a+(b[d+2>>1]|0)|0;c[q>>2]=c[s+6404>>2];c[q+4>>2]=c[s+6408>>2];b[r>>1]=b[k>>1]>>3;b[r+2>>1]=b[k+2>>1]>>3;a=Xe[c[h>>2]&511](v,l,t,u,-1)|0;e=a+(Ndc(d,r,q|0,f)|0)|0;a=0;while(1){if((a|0)>=(g|0)){w=21;break}x=-1;y=0;while(1){if((y|0)>=4){break}z=(b[d>>1]|0)+(b[n+(y<<2)>>1]|0)&65535;A=(b[d+2>>1]|0)+(b[n+(y<<2)+2>>1]|0)&65535;do{if((A<<16>>16|0)>(c[s+6432>>2]|0)){if((A<<16>>16|0)>=(c[s+6436>>2]|0)){break}if((z<<16>>16|0)<=(c[s+6440>>2]|0)){break}if((z<<16>>16|0)>=(c[s+6444>>2]|0)){break}B=ca(b[n+(y<<2)>>1]|0,u)|0;c[p>>2]=Xe[c[h>>2]&511](v,l,t+(B+(b[n+(y<<2)+2>>1]|0))|0,u,e)|0;if((c[p>>2]|0)>>>0<e>>>0){b[o>>1]=z;b[o+2>>1]=A;B=Ndc(o,r,q|0,f)|0;c[p>>2]=(c[p>>2]|0)+B;if((c[p>>2]|0)>>>0<e>>>0){e=c[p>>2]|0;x=y}}}}while(0);y=y+1|0}if((x|0)==-1){break}y=d|0;b[y>>1]=(b[y>>1]|0)+(b[n+(x<<2)>>1]|0);y=d+2|0;b[y>>1]=(b[y>>1]|0)+(b[n+(x<<2)+2>>1]|0);y=ca(b[n+(x<<2)>>1]|0,u)|0;t=t+(y+(b[n+(x<<2)+2>>1]|0))|0;a=a+1|0}if((w|0)==21){C=d;D=C;E=D|0;F=b[E>>1]|0;G=F<<16>>16;H=G<<3;I=H&65535;J=o;K=J|0;b[K>>1]=I;L=d;M=L;N=M+2|0;O=b[N>>1]|0;P=O<<16>>16;Q=P<<3;R=Q&65535;S=o;T=S+2|0;b[T>>1]=R;U=h;V=U+4|0;W=c[V>>2]|0;X=v;Y=l;Z=t;_=u;$=Xe[W&511](X,Y,Z,_,p)|0;aa=k;ba=j;da=s;ea=da+6360|0;fa=c[ea>>2]|0;ga=Idc(o,aa,ba,fa)|0;ha=$+ga|0;i=m;return ha|0}C=d;D=C;E=D|0;F=b[E>>1]|0;G=F<<16>>16;H=G<<3;I=H&65535;J=o;K=J|0;b[K>>1]=I;L=d;M=L;N=M+2|0;O=b[N>>1]|0;P=O<<16>>16;Q=P<<3;R=Q&65535;S=o;T=S+2|0;b[T>>1]=R;U=h;V=U+4|0;W=c[V>>2]|0;X=v;Y=l;Z=t;_=u;$=Xe[W&511](X,Y,Z,_,p)|0;aa=k;ba=j;da=s;ea=da+6360|0;fa=c[ea>>2]|0;ga=Idc(o,aa,ba,fa)|0;ha=$+ga|0;i=m;return ha|0}function Rdc(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=i;c=a;a=c+105664|0;d=c+151704|0;c=246704;e=0;do{f=0;do{w0b(d+20640+(e*400|0)+(f*40|0)|0,243376+(e*90|0)+(f*9|0)|0,c);g=f+1|0;f=g;}while((g|0)<10);f=e+1|0;e=f;}while((f|0)<10);w0b(d+24640|0,a+6922|0,c);w0b(d+24640|0,a+6938|0,238456);w0b(d+20520|0,a+6931|0,236128);w0b(d+20480|0,243320,243312);w0b(d+20600|0,a+6935|0,236184);w0b(d+20560|0,243368,236184);i=b;return}function Sdc(a){a=a|0;var b=0,d=0;b=i;d=a;a=0;while(1){if((a|0)>=12){break}K7b(d+8488+(a*108|0)+16|0)|0;do{if((c[d+8488+(a*108|0)>>2]|0)>0){if((c[d+8488+(a*108|0)+4>>2]|0)==0){break}We[c[d+36988>>2]&2047](c[d+36980>>2]|0,d+8488+(a*108|0)+4|0)|0;c[d+8488+(a*108|0)>>2]=0}}while(0);a=a+1|0}K7b(d+10012|0)|0;Tdc(d);FYb(c[d+10216>>2]|0);c[d+10216>>2]=0;FYb(c[d+37004>>2]|0);c[d+37004>>2]=0;FYb(c[d+37e3>>2]|0);c[d+37e3>>2]=0;i=b;return}function Tdc(a){a=a|0;var b=0,d=0;b=i;d=a;FYb(c[d+10184>>2]|0);FYb(c[d+10192>>2]|0);FYb(c[d+10200>>2]|0);FYb(c[d+10208>>2]|0);c[d+10184>>2]=0;c[d+10192>>2]=0;c[d+10200>>2]=0;c[d+10208>>2]=0;i=b;return}function Udc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;do{if((L7b(f+10012|0,a,b,c[f+8476>>2]|0,c[f+8480>>2]|0,32,0,0,0)|0)>=0){Vdc(f,a+7&-8,b+7&-8);Tdc(f);if((Wdc(f,ca(c[f+10160>>2]|0,(c[f+10148>>2]|0)+8|0)|0)|0)!=0){break}Xdc(f);FYb(c[f+10216>>2]|0);c[f+10216>>2]=DYb(ca(c[f+10148>>2]|0,c[f+10156>>2]|0)|0,1)|0;if((c[f+10216>>2]|0)==0){break}FYb(c[f+37004>>2]|0);c[f+37004>>2]=DYb((((c[f+10156>>2]|0)+7&-8)<<1)*3|0,1)|0;if((c[f+37004>>2]|0)==0){break}FYb(c[f+37e3>>2]|0);c[f+37e3>>2]=DYb((c[f+10156>>2]|0)+7&-8,1)|0;if((c[f+37e3>>2]|0)==0){break}g=0;h=g;i=e;return h|0}}while(0);Sdc(f);g=1;h=g;i=e;return h|0}function Vdc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a;c[e+10156>>2]=b>>3;c[e+10148>>2]=d>>3;c[e+10160>>2]=(c[e+10156>>2]|0)+8;c[e+10152>>2]=(c[e+10156>>2]|0)+1>>1;c[e+10144>>2]=(c[e+10148>>2]|0)+1>>1;c[e+10140>>2]=ca(c[e+10144>>2]|0,c[e+10152>>2]|0)|0;i=i;return}function Wdc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;c[e+10184>>2]=DYb(a,124)|0;if((c[e+10184>>2]|0)==0){f=1;g=f;i=d;return g|0}c[e+10192>>2]=DYb(a,124)|0;if((c[e+10192>>2]|0)==0){f=1;g=f;i=d;return g|0}c[e+10200>>2]=DYb(a,4)|0;if((c[e+10200>>2]|0)==0){f=1;g=f;i=d;return g|0}c[e+10208>>2]=DYb(a,4)|0;if((c[e+10208>>2]|0)==0){f=1;g=f;i=d;return g|0}else{f=0;g=f;i=d;return g|0}return 0}function Xdc(a){a=a|0;var b=0,d=0;b=i;d=a;c[d+10188>>2]=(c[d+10184>>2]|0)+((c[d+10160>>2]|0)*124|0)+124;c[d+10196>>2]=(c[d+10192>>2]|0)+((c[d+10160>>2]|0)*124|0)+124;c[d+10204>>2]=(c[d+10200>>2]|0)+(c[d+10160>>2]<<2)+4;c[d+10212>>2]=(c[d+10208>>2]|0)+(c[d+10160>>2]<<2)+4;mrc(c[d+10184>>2]|0,0,(ca(c[d+10160>>2]|0,(c[d+10148>>2]|0)+1|0)|0)*124|0|0)|0;mrc(c[d+10200>>2]|0,0,(ca(c[d+10160>>2]|0,(c[d+10148>>2]|0)+1|0)|0)<<2|0)|0;aec(d,c[d+10192>>2]|0);i=b;return}function Ydc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=a;a=b;b=d;d=a+7&-8;g=b+7&-8;h=c[f+8476>>2]|0;j=c[f+8480>>2]|0;Sdc(f);k=0;while(1){if((k|0)>=12){l=7;break}c[f+8488+(k*108|0)>>2]=0;if((M7b(f+8488+(k*108|0)+16|0,a,b,h,j,160)|0)<0){l=4;break}k=k+1|0}do{if((l|0)!=4)if((l|0)==7){c[f+10008>>2]=11;c[f+8488+((c[f+10008>>2]|0)*108|0)>>2]=1;k=0;while(1){if((k|0)>=8){break}c[f+9784+(k<<2)>>2]=k;c[f+8488+(k*108|0)>>2]=1;k=k+1|0}if((M7b(f+10012|0,a,b,h,j,160)|0)<0){break}Vdc(f,d,g);if((Wdc(f,ca(c[f+10160>>2]|0,(c[f+10148>>2]|0)+8|0)|0)|0)!=0){break}Xdc(f);c[f+10216>>2]=DYb(ca(c[f+10148>>2]|0,c[f+10156>>2]|0)|0,1)|0;if((c[f+10216>>2]|0)==0){break}c[f+37004>>2]=DYb((((c[f+10156>>2]|0)+7&-8)<<1)*3|0,1)|0;if((c[f+37004>>2]|0)==0){break}c[f+37e3>>2]=DYb((c[f+10156>>2]|0)+7&-8,1)|0;if((c[f+37e3>>2]|0)==0){break}m=0;n=m;i=e;return n|0}}while(0);Sdc(f);m=1;n=m;i=e;return n|0}function Zdc(a){a=a|0;var b=0,c=0;b=i;c=a;Sdc(c);A0b(c+36992|0);i=b;return}function _dc(a){a=a|0;var b=0,d=0;b=i;d=a;Vdc(d,(c[d+8452>>2]|0)+7&-8,(c[d+8456>>2]|0)+7&-8);Xdc(d);if((c[d+10216>>2]|0)==0){i=b;return}mrc(c[d+10216>>2]|0,0,ca(c[d+10148>>2]|0,c[d+10156>>2]|0)|0)|0;i=b;return}function $dc(a){a=a|0;var b=0,d=0;b=a;a=c[b+10192>>2]|0;d=c[b+10208>>2]|0;c[b+10192>>2]=c[b+10184>>2];c[b+10184>>2]=a;c[b+10208>>2]=c[b+10200>>2];c[b+10200>>2]=d;c[b+10188>>2]=(c[b+10184>>2]|0)+((c[b+10160>>2]|0)*124|0)+124;c[b+10196>>2]=(c[b+10192>>2]|0)+((c[b+10160>>2]|0)*124|0)+124;c[b+10204>>2]=(c[b+10200>>2]|0)+(c[b+10160>>2]<<2)+4;c[b+10212>>2]=(c[b+10208>>2]|0)+(c[b+10160>>2]<<2)+4;i=i;return}function aec(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=b;mrc(a|0,0,(c[e+10160>>2]|0)*124|0|0)|0;b=1;while(1){if((b|0)>=((c[e+10148>>2]|0)+1|0)){break}mrc(a+((ca(b,c[e+10160>>2]|0)|0)*124|0)|0,0,124)|0;b=b+1|0}i=d;return}function bec(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=d;do{if((b|0)!=0){if((b|0)==2){break}do{if((b|0)==1){g=1}else{if((b|0)==3){g=1;break}Cd(2288224,2545800,21,2650240);return 0}}while(0);h=c[f+76+((b-1|0)*12|0)>>2]|0;j=h;i=e;return j|0}}while(0);do{if((a|0)!=0){if(((c[a+20>>2]|0)>0|0)!=0){break}f=a;if((c[f>>2]|0)>>>0<3>>>0){k=c[f+76+((b+1|0)*12|0)>>2]|0}else{k=c[f+4>>2]|0}h=k;j=h;i=e;return j|0}}while(0);h=0;j=h;i=e;return j|0}function cec(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=d;do{if((b|0)!=0){if((b|0)==1){break}do{if((b|0)==2){g=1}else{if((b|0)==3){g=1;break}Cd(2417968,2545800,34,2650832);return 0}}while(0);h=c[f+76+((b-2|0)*12|0)>>2]|0;j=h;i=e;return j|0}}while(0);do{if((a|0)!=0){if(((c[a+20>>2]|0)>0|0)!=0){break}f=a;if((c[f>>2]|0)>>>0<3>>>0){k=c[f+76+((b+2|0)*12|0)>>2]|0}else{k=c[f+4>>2]|0}h=k;j=h;i=e;return j|0}}while(0);h=0;j=h;i=e;return j|0}function dec(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;h=a;a=b;b=d;d=e;e=f;f=h+(b*52|0)|0;j=c[c[h+160>>2]>>2]|0;if((b|0)!=0){k=j;l=c[k+8>>2]|0;m=c[k>>2]|0;if(m>>>0<3>>>0){n=0}else{k=c[558436+(m<<4)>>2]|0;if(l>>>0<(c[833024+(k<<2)>>2]|0)>>>0){o=l}else{o=c[833024+(k<<2)>>2]|0}n=o}p=n}else{p=c[j+8>>2]|0}j=p;p=f;n=c[558424+(a<<4)+(c[p+8>>2]<<3)+(c[p+12>>2]<<2)>>2]|0;if(!(n>>>0<13>>>0)){Cd(2338072,2280288,292,2652392)}p=n;n=c[777792+(p<<2)>>2]|0;a=c[777848+(p<<2)>>2]|0;o=1<<(j<<1);do{if((c[h+176>>2]|0)>=0){if((c[h+184>>2]|0)<0){break}q=0;while(1){if((q|0)>=(ca(n,a)|0)){break}pe[d&1023](b,q,p,j,e);q=q+o|0}i=g;return}}while(0);k=n;l=a;if((c[h+176>>2]|0)<0){k=k+(c[h+176>>2]>>(c[f+8>>2]|0)+5)|0}if((c[h+184>>2]|0)<0){l=l+(c[h+184>>2]>>(c[f+12>>2]|0)+5)|0}q=0;f=0;while(1){if((f|0)>=(a|0)){break}h=0;while(1){if((h|0)>=(n|0)){break}do{if((f|0)<(l|0)){if((h|0)>=(k|0)){break}pe[d&1023](b,q,p,j,e)}}while(0);q=q+o|0;h=h+(1<<j)|0}f=f+(1<<j)|0}i=g;return}function eec(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=c;c=d;d=0;while(1){if((d|0)>=3){break}dec(f,a,d,b,c);d=d+1|0}i=e;return}function fec(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=b;b=d;d=e;e=g;g=h;h=j;j=(c[b+44>>2]|0)+g|0;m=(c[b+48>>2]|0)+h|0;n=1<<f;do{if((e|0)!=0){if((c[l+176>>2]|0)>=0){o=14;break}f=(c[777792+(d<<2)>>2]|0)+(c[l+176>>2]>>(c[b+8>>2]|0)+5)|0;p=n;if((p+g|0)>(f|0)){p=f-g|0}f=0;while(1){if((f|0)>=(p|0)){break}a[j+f|0]=e;f=f+1|0}f=p;while(1){if((f|0)>=(n|0)){break}a[j+f|0]=0;f=f+1|0}}else{o=14}}while(0);if((o|0)==14){mrc(j|0,e&255|0,n|0)|0}do{if((e|0)!=0){if((c[l+184>>2]|0)>=0){break}j=(c[777848+(d<<2)>>2]|0)+(c[l+184>>2]>>(c[b+12>>2]|0)+5)|0;o=n;if((o+h|0)>(j|0)){o=j-h|0}j=0;while(1){if((j|0)>=(o|0)){break}a[m+j|0]=e;j=j+1|0}j=o;while(1){if((j|0)>=(n|0)){break}a[m+j|0]=0;j=j+1|0}i=k;return}}while(0);mrc(m|0,e&255|0,n|0)|0;i=k;return}function gec(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;d=0;while(1){if((d|0)>=3){break}c[f+(d*52|0)+4>>2]=(d|0)!=0?1:0;if((d|0)!=0){g=a}else{g=0}c[f+(d*52|0)+8>>2]=g;if((d|0)!=0){h=b}else{h=0}c[f+(d*52|0)+12>>2]=h;d=d+1|0}i=e;return}function hec(a,b,c,d,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;h=i;g=e;e=iec(g)|0;kec(a,b,c,d,e,jec(g,e)|0,f,j,k);i=h;return}function iec(a){a=a|0;i=i;return a&-256|0}function jec(a,b){a=a|0;b=b|0;i=i;return(a-b|0)/16|0|0}function kec(c,e,f,g,h,j,k,l,m){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=i;o=c;c=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;o=o-3|0;m=0;while(1){if((m|0)>=(l|0)){break}p=h;q=0;while(1){if((q|0)>=(k|0)){break}r=o+(p>>4)|0;s=g+((p&15)<<4)|0;t=0;u=0;while(1){if((u|0)>=8){break}t=t+(ca(d[r+u|0]|0,b[s+(u<<1)>>1]|0)|0)|0;u=u+1|0}u=t+64>>7;if((u|0)>255){v=255}else{if((u|0)<0){w=0}else{w=u}v=w}a[e+q|0]=v;p=p+j|0;q=q+1|0}o=o+c|0;e=e+f|0;m=m+1|0}i=n;return}function lec(a,b,c,d,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;h=i;g=e;e=iec(g)|0;mec(a,b,c,d,e,jec(g,e)|0,f,j,k);i=h;return}function mec(c,e,f,g,h,j,k,l,m){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=i;o=c;c=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;o=o-3|0;m=0;while(1){if((m|0)>=(l|0)){break}p=h;q=0;while(1){if((q|0)>=(k|0)){break}r=o+(p>>4)|0;s=g+((p&15)<<4)|0;t=0;u=0;while(1){if((u|0)>=8){break}t=t+(ca(d[r+u|0]|0,b[s+(u<<1)>>1]|0)|0)|0;u=u+1|0}u=d[e+q|0]|0;s=t+64>>7;if((s|0)>255){v=255}else{if((s|0)<0){w=0}else{w=s}v=w}a[e+q|0]=u+(v&255)+1>>1;p=p+j|0;q=q+1|0}o=o+c|0;e=e+f|0;m=m+1|0}i=n;return}function nec(a,b,c,d,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;f=i;e=g;g=iec(e)|0;oec(a,b,c,d,g,jec(e,g)|0,h,j,k);i=f;return}function oec(c,e,f,g,h,j,k,l,m){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;n=i;o=c;c=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;o=o+(-(c*3|0)|0)|0;m=0;while(1){if((m|0)>=(k|0)){break}p=h;q=0;while(1){if((q|0)>=(l|0)){break}r=o+(ca(p>>4,c)|0)|0;s=g+((p&15)<<4)|0;t=0;u=0;while(1){if((u|0)>=8){break}v=d[r+(ca(u,c)|0)|0]|0;t=t+(ca(v,b[s+(u<<1)>>1]|0)|0)|0;u=u+1|0}u=t+64>>7;if((u|0)>255){w=255}else{if((u|0)<0){x=0}else{x=u}w=x}a[e+(ca(q,f)|0)|0]=w;p=p+j|0;q=q+1|0}o=o+1|0;e=e+1|0;m=m+1|0}i=n;return}function pec(a,b,c,d,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;f=i;e=g;g=iec(e)|0;qec(a,b,c,d,g,jec(e,g)|0,h,j,k);i=f;return}function qec(c,e,f,g,h,j,k,l,m){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;n=i;o=c;c=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;o=o+(-(c*3|0)|0)|0;m=0;while(1){if((m|0)>=(k|0)){break}p=h;q=0;while(1){if((q|0)>=(l|0)){break}r=o+(ca(p>>4,c)|0)|0;s=g+((p&15)<<4)|0;t=0;u=0;while(1){if((u|0)>=8){break}v=d[r+(ca(u,c)|0)|0]|0;t=t+(ca(v,b[s+(u<<1)>>1]|0)|0)|0;u=u+1|0}u=d[e+(ca(q,f)|0)|0]|0;s=t+64>>7;if((s|0)>255){w=255}else{if((s|0)<0){x=0}else{x=s}w=x}a[e+(ca(q,f)|0)|0]=u+(w&255)+1>>1;p=p+j|0;q=q+1|0}o=o+1|0;e=e+1|0;m=m+1|0}i=n;return}function rec(a,b,c,d,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0;l=i;m=e;e=g;g=iec(m)|0;n=jec(m,g)|0;m=iec(e)|0;sec(a,b,c,d,g,n,f,m,jec(e,m)|0,h,j,k);i=l;return}function sec(a,b,c,d,e,f,g,h,j,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0;n=i;i=i+20736|0;o=n|0;p=b;b=g;g=k;k=l;l=m;m=((ca(l-1|0,g)|0)+15>>4)+8|0;if((k|0)<=64){}else{Cd(2286648,2545096,127,2653200)}if((l|0)<=64){}else{Cd(2417488,2545096,128,2653200)}if((g|0)<=80){}else{Cd(2337840,2545096,129,2653200)}if((b|0)<=80){}else{Cd(2280104,2545096,130,2653200)}if((m|0)<(l|0)){m=l}kec(a+(-(p*3|0)|0)|0,p,o|0,64,e,f,b,k,m);oec(o+192|0,64,c,d,h,j,g,k,l);i=n;return}function tec(a,b,c,d,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0;l=i;i=i+4120|0;m=j;j=k;k=l+16-1&-16;if((m|0)<=64){}else{Cd(2286648,2545096,220,2650680)}if((j|0)<=64){}else{Cd(2417488,2545096,221,2650680)}rec(a,b,k,64,e,f,g,h,m,j);uec(k,64,c,d,0,0,0,0,m,j);i=l;return}function uec(b,c,e,f,g,h,j,k,l,m){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;k=i;j=b;b=c;c=e;e=f;f=l;l=m;m=0;while(1){if((m|0)>=(l|0)){break}h=0;while(1){if((h|0)>=(f|0)){break}a[c+h|0]=(d[c+h|0]|0)+(d[j+h|0]|0)+1>>1;h=h+1|0}j=j+b|0;c=c+e|0;m=m+1|0}i=k;return}function vec(a,b,c,d,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;h=i;g=a;a=b;b=c;c=d;d=j;j=k;while(1){if((j|0)<=0){break}nrc(b|0,g|0,d)|0;g=g+a|0;b=b+c|0;j=j-1|0}i=h;return}function wec(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=i;e=b;b=c;if((b|0)!=(e|0)){c=b;f=e;a[c]=a[f]|0;a[c+1|0]=a[f+1|0]|0;a[c+2|0]=a[f+2|0]|0}xec(b+3|0,a[e+2|0]|0);i=d;return}function xec(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=b;b=(d&255)-1&255;d=b;nrc(a|0,207992+((b&255)<<3)|0,8)|0;i=c;return}function yec(a){a=a|0;var b=0,c=0;b=i;c=a;nrc(c+13714|0,1577488,432)|0;nrc(c+14146|0,1577056,432)|0;nrc(c+14578|0,1578352,432)|0;nrc(c+15010|0,1577920,432)|0;i=b;return}function zec(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=d;if((c[a+10108>>2]|0)==0){e=1}else{e=(c[a+10124>>2]|0)!=0}if((e&1|0)!=0){f=112;g=24}else{if((c[d+10104>>2]|0)==0){f=128;g=24}else{f=112;g=24}}e=0;while(1){if(!(e>>>0<=3>>>0)){break}Aec(d,e,g,f);e=e+1|0}i=b;return}function Aec(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;i=i+24|0;h=g|0;j=b;b=d;d=e;e=f;f=j+13714+(b*432|0)|0;k=j+15579+((c[j+23736>>2]|0)*2039|0)+174+(b*432|0)|0;l=j+24556+(b*2304|0)|0;m=j+33772+(b*576|0)|0;b=0;while(1){if((b|0)>=2){break}j=0;while(1){if((j|0)>=2){break}n=0;while(1){if((n|0)>=6){break}o=0;while(1){if((o|0)>=(((n|0)==0?3:6)|0)){break}p=c[l+(b*1152|0)+(j*576|0)+(n*96|0)+(o<<4)>>2]|0;q=c[l+(b*1152|0)+(j*576|0)+(n*96|0)+(o<<4)+4>>2]|0;r=c[l+(b*1152|0)+(j*576|0)+(n*96|0)+(o<<4)+8>>2]|0;s=c[l+(b*1152|0)+(j*576|0)+(n*96|0)+(o<<4)+12>>2]|0;t=h|0;u=t|0;c[u>>2]=s;c[u+4>>2]=(c[m+(b*288|0)+(j*144|0)+(n*24|0)+(o<<2)>>2]|0)-s;s=t+8|0;t=s|0;c[t>>2]=p;c[t+4>>2]=q+r;t=s+8|0;c[t>>2]=q;c[t+4>>2]=r;r=0;while(1){if((r|0)>=3){break}t=a[k+(b*216|0)+(j*108|0)+(n*18|0)+(o*3|0)+r|0]|0;q=h+(r<<3)|0;s=d;p=e;u=c[q>>2]|0;v=u+(c[q+4>>2]|0)|0;if((v|0)==0){w=128}else{x=((u<<8)+(v>>1)|0)/(v|0)|0;if((x|0)>255){y=255}else{if((x|0)<1){z=1}else{z=x}y=z}w=y&255}if(((c[q>>2]|0)+(c[q+4>>2]|0)|0)>>>0<s>>>0){A=(c[q>>2]|0)+(c[q+4>>2]|0)|0}else{A=s}q=((ca(p,A)|0)>>>0)/(s>>>0)|0;a[f+(b*216|0)+(j*108|0)+(n*18|0)+(o*3|0)+r|0]=(ca(t&255,256-q|0)|0)+(ca(w&255,q)|0)+128>>8;r=r+1|0}o=o+1|0}n=n+1|0}j=j+1|0}b=b+1|0}i=g;return}function Bec(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[a>>2]=c[d>>2];c[a+4>>2]=(c[d+4>>2]|0)+(c[d+8>>2]|0)+(c[d+12>>2]|0);c[a+8>>2]=c[d+4>>2];c[a+12>>2]=(c[d+8>>2]|0)+(c[d+12>>2]|0);c[a+16>>2]=c[d+8>>2];c[a+20>>2]=c[d+12>>2];i=i;return}function Cec(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[a>>2]=c[d>>2];c[a+4>>2]=(c[d+4>>2]|0)+(c[d+8>>2]|0);c[a+8>>2]=c[d+4>>2];c[a+12>>2]=c[d+8>>2];i=i;return}function Dec(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;c[a>>2]=c[d>>2];c[a+4>>2]=c[d+4>>2];i=i;return}function Eec(b){b=b|0;var c=0,d=0;c=i;d=b;nrc(d+36|0,1576544,90)|0;nrc(d|0,1576504,36)|0;nrc(d+1902|0,1567824,8)|0;nrc(d+126|0,1576352,48)|0;b=d+1931|0;a[b]=a[1576472]|0;a[b+1|0]=a[1576473]|0;a[b+2|0]=a[1576474]|0;a[b+3|0]=a[1576475]|0;b=d+1935|0;a[b]=a[1577048]|0;a[b+1|0]=a[1577049]|0;a[b+2|0]=a[1577050]|0;a[b+3|0]=a[1577051]|0;a[b+4|0]=a[1577052]|0;b=d+1950|0;a[b]=a[1577040]|0;a[b+1|0]=a[1577041]|0;a[b+2|0]=a[1577042]|0;a[b+3|0]=a[1577043]|0;a[b+4|0]=a[1577044]|0;nrc(d+1940|0,1572704,10)|0;nrc(d+1955|0,1567808,12)|0;b=d+1967|0;a[b]=a[1572696]|0;a[b+1|0]=a[1572697]|0;a[b+2|0]=a[1572698]|0;nrc(d+1910|0,1576480,21)|0;i=c;return}function Fec(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+48|0;e=d|0;f=d+8|0;g=d+24|0;h=b;b=h+13540|0;j=h+15579+((c[h+23736>>2]|0)*2039|0)|0;k=h+23740|0;l=0;while(1){if((l|0)>=4){break}a[b+1931+l|0]=Gec(a[j+1931+l|0]|0,k+12496+(l<<3)|0)|0;l=l+1|0}l=0;while(1){if((l|0)>=5){break}a[b+1935+l|0]=Gec(a[j+1935+l|0]|0,k+12528+(l<<3)|0)|0;l=l+1|0}l=0;while(1){if((l|0)>=5){break}a[b+1950+l|0]=Gec(a[j+1950+l|0]|0,k+12648+(l<<3)|0)|0;l=l+1|0}l=0;while(1){if((l|0)>=5){break}m=0;while(1){if((m|0)>=2){break}a[b+1940+(l<<1)+m|0]=Gec(a[j+1940+(l<<1)+m|0]|0,k+12568+(l<<4)+(m<<3)|0)|0;m=m+1|0}l=l+1|0}l=0;while(1){if((l|0)>=7){break}Hec(215488,j+1910+(l*3|0)|0,k+12384+(l<<4)|0,b+1910+(l*3|0)|0);l=l+1|0}l=0;while(1){if((l|0)>=4){break}Hec(215456,j+(l*9|0)|0,k+(l*40|0)|0,b+(l*9|0)|0);l=l+1|0}l=0;while(1){if((l|0)>=10){break}Hec(215456,j+36+(l*9|0)|0,k+160+(l*40|0)|0,b+36+(l*9|0)|0);l=l+1|0}l=0;while(1){if((l|0)>=16){break}Hec(207984,j+126+(l*3|0)|0,k+560+(l<<4)|0,b+126+(l*3|0)|0);l=l+1|0}if((c[h+10220>>2]|0)==4){l=0;while(1){if((l|0)>=4){break}Hec(202680,j+1902+(l<<1)|0,k+12336+(l*12|0)|0,b+1902+(l<<1)|0);l=l+1|0}}if((c[h+10164>>2]|0)==4){l=0;while(1){if((l|0)>=2){break}Dec(k+12744+(l<<3)|0,e|0);h=0;while(1){if((h|0)>=1){break}a[b+1965+l+h|0]=Gec(a[j+1965+l+h|0]|0,e+(h<<3)|0)|0;h=h+1|0}Cec(k+12720+(l*12|0)|0,f|0);h=0;while(1){if((h|0)>=2){break}a[b+1961+(l<<1)+h|0]=Gec(a[j+1961+(l<<1)+h|0]|0,f+(h<<3)|0)|0;h=h+1|0}Bec(k+12688+(l<<4)|0,g|0);h=0;while(1){if((h|0)>=3){break}a[b+1955+(l*3|0)+h|0]=Gec(a[j+1955+(l*3|0)+h|0]|0,g+(h<<3)|0)|0;h=h+1|0}l=l+1|0}}l=0;while(1){if((l|0)>=3){break}a[b+1967+l|0]=Gec(a[j+1967+l|0]|0,k+12760+(l<<3)|0)|0;l=l+1|0}i=d;return}function Gec(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;a=b;b=20;f=128;g=c[a>>2]|0;h=g+(c[a+4>>2]|0)|0;if((h|0)==0){j=128}else{k=((g<<8)+(h>>1)|0)/(h|0)|0;if((k|0)>255){l=255}else{if((k|0)<1){m=1}else{m=k}l=m}j=l&255}if(((c[a>>2]|0)+(c[a+4>>2]|0)|0)>>>0<b>>>0){n=(c[a>>2]|0)+(c[a+4>>2]|0)|0}else{n=b}a=((ca(f,n)|0)>>>0)/(b>>>0)|0;b=(ca(e&255,256-a|0)|0)+(ca(j&255,a)|0)+128>>8&255;i=d;return b|0}function Hec(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=i;kgc(a,b,c,20,128,d);i=e;return}function Iec(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;e=b;b=e+13380|0;Uhc(e+13408|0);a[e+13411|0]=0;if((c[e+10216>>2]|0)!=0){mrc(c[e+10216>>2]|0,0,ca(c[e+10148>>2]|0,c[e+10156>>2]|0)|0)|0}mrc(b+18|0,0,4)|0;mrc(b+24|0,0,2)|0;Jec(b);c[b+8>>2]=-1;yec(e);Eec(e+13540|0);Sec(e);do{if((c[e+10108>>2]|0)==0){f=6}else{if((c[e+36960>>2]|0)!=0){f=6;break}if((c[e+10132>>2]|0)==3){f=6;break}if((c[e+10132>>2]|0)==2){nrc(e+15579+((c[e+23736>>2]|0)*2039|0)|0,e+13540|0,2039)|0}}}while(0);if((f|0)==6){f=0;while(1){if((f|0)>=4){break}nrc(e+15579+(f*2039|0)|0,e+13540|0,2039)|0;f=f+1|0}}f=e;if((c[f+10108>>2]|0)==0){g=1}else{g=(c[f+10124>>2]|0)!=0}if((g&1|0)==0){h=e;j=h+10184|0;k=c[j>>2]|0;l=k;m=e;n=m+10160|0;o=c[n>>2]|0;p=e;q=p+10148|0;r=c[q>>2]|0;s=r+1|0;t=ca(o,s)|0;u=t*124|0;mrc(l|0,0,u|0)|0;v=e;w=v+13364|0;x=w;mrc(x|0,0,16)|0;y=e;z=y+23736|0;c[z>>2]=0;i=d;return}mrc(c[e+10192>>2]|0,0,(ca(c[e+10160>>2]|0,(c[e+10148>>2]|0)+1|0)|0)*124|0|0)|0;h=e;j=h+10184|0;k=c[j>>2]|0;l=k;m=e;n=m+10160|0;o=c[n>>2]|0;p=e;q=p+10148|0;r=c[q>>2]|0;s=r+1|0;t=ca(o,s)|0;u=t*124|0;mrc(l|0,0,u|0)|0;v=e;w=v+13364|0;x=w;mrc(x|0,0,16)|0;y=e;z=y+23736|0;c[z>>2]=0;i=d;return}function Jec(b){b=b|0;var c=0;c=b;a[c+12|0]=1;a[c+13|0]=1;a[c+14|0]=1;a[c+15|0]=0;a[c+16|0]=-1;a[c+17|0]=-1;a[c+22|0]=0;a[c+23|0]=0;i=i;return}function Kec(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a;a=b;if((f|0)>=8192){g=10}else{g=d[1004520+(f>>3)|0]|0}b=g;if((a|0)==0){h=b;i=e;return h|0}g=b;if((g|0)!=0){j=2<<g+2}else{j=0}c[a>>2]=f-j;h=b;i=e;return h|0}function Lec(a){a=a|0;var c=0,d=0,e=0,f=0;c=i;d=a;if(((R(b[d>>1]|0)|0)>>3|0)>=8){e=0;f=e&1;i=c;return f|0}e=((R(b[d+2>>1]|0)|0)>>3|0)<8;f=e&1;i=c;return f|0}function Mec(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;if((c|0)!=0){d=2<<c+2}else{d=0}i=i;return d+b|0}function Nec(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a;a=d;if((a|0)==0){i=e;return}d=f;if((b[d>>1]|0)==0){g=(b[d+2>>1]|0)==0?0:1}else{g=(b[d+2>>1]|0)==0?2:3}d=g;g=a+(d<<2)|0;c[g>>2]=(c[g>>2]|0)+1;g=d;if((g|0)==2){h=1}else{h=(g|0)==3}if((h&1|0)!=0){Oec(b[f>>1]|0,a+16|0,1,1)}h=d;if((h|0)==1){j=1}else{j=(h|0)==3}if((j&1|0)!=0){Oec(b[f+2>>1]|0,a+220|0,1,1)}i=e;return}function Oec(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+8|0;g=f|0;h=a;a=b;b=d;d=e;if((h|0)!=0){}else{Cd(2284016,2544184,145,2652088)}e=(h|0)<0|0;j=a+(e<<2)|0;c[j>>2]=(c[j>>2]|0)+b;if((e|0)!=0){k=-h|0}else{k=h}h=Kec(k-1|0,g)|0;k=a+8+(h<<2)|0;c[k>>2]=(c[k>>2]|0)+b;k=c[g>>2]>>3;e=c[g>>2]>>1&3;j=c[g>>2]&1;if((h|0)==0){g=a+52+(k<<2)|0;c[g>>2]=(c[g>>2]|0)+b;g=a+140+(k<<4)+(e<<2)|0;c[g>>2]=(c[g>>2]|0)+b;g=ca(d,b)|0;l=a+188+(j<<2)|0;c[l>>2]=(c[l>>2]|0)+g;i=f;return}g=h+1-1|0;h=0;while(1){if((h|0)>=(g|0)){break}l=a+60+(h<<3)+((k>>h&1)<<2)|0;c[l>>2]=(c[l>>2]|0)+b;h=h+1|0}h=a+172+(e<<2)|0;c[h>>2]=(c[h>>2]|0)+b;h=ca(d,b)|0;b=a+196+(j<<2)|0;c[b>>2]=(c[b>>2]|0)+h;i=f;return}function Pec(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b;b=d;d=f+15510|0;g=f+15579+((c[f+23736>>2]|0)*2039|0)+1970|0;h=f+36524|0;Qec(211840,g|0,h|0,d|0);f=0;while(1){if((f|0)>=2){break}j=d+3+(f*33|0)|0;k=g+3+(f*33|0)|0;l=h+16+(f*204|0)|0;a[j|0]=Rec(a[k|0]|0,l|0)|0;Qec(211888,k+1|0,l+8|0,j+1|0);Qec(211912,k+11|0,l+52|0,j+11|0);m=0;while(1){if((m|0)>=10){break}a[j+12+m|0]=Rec(a[k+12+m|0]|0,l+60+(m<<3)|0)|0;m=m+1|0}m=0;while(1){if((m|0)>=2){break}Qec(211856,k+22+(m*3|0)|0,l+140+(m<<4)|0,j+22+(m*3|0)|0);m=m+1|0}Qec(211856,k+28|0,l+172|0,j+28|0);if((b|0)!=0){a[j+31|0]=Rec(a[k+31|0]|0,l+188|0)|0;a[j+32|0]=Rec(a[k+32|0]|0,l+196|0)|0}f=f+1|0}i=e;return}function Qec(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=i;kgc(a,b,c,20,128,d);i=e;return}function Rec(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;a=b;b=20;f=128;g=c[a>>2]|0;h=g+(c[a+4>>2]|0)|0;if((h|0)==0){j=128}else{k=((g<<8)+(h>>1)|0)/(h|0)|0;if((k|0)>255){l=255}else{if((k|0)<1){m=1}else{m=k}l=m}j=l&255}if(((c[a>>2]|0)+(c[a+4>>2]|0)|0)>>>0<b>>>0){n=(c[a>>2]|0)+(c[a+4>>2]|0)|0}else{n=b}a=((ca(f,n)|0)>>>0)/(b>>>0)|0;b=(ca(e&255,256-a|0)|0)+(ca(j&255,a)|0)+128>>8&255;i=d;return b|0}function Sec(a){a=a|0;var b=0;b=i;nrc(a+15510|0,1576400,69)|0;i=b;return}function Tec(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)!=4){}else{Cd(2283504,2544104,103,2650472);return 0}i=b;return c[218512+(d<<2)>>2]|0}function Uec(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+32|0;h=g|0;j=e;e=f;f=c;c=h|0;k=0;while(1){if((k|0)>=4){break}l=b[f>>1]>>2;m=b[f+2>>1]>>2;n=b[f+4>>1]>>2;o=b[f+6>>1]>>2;l=l+m|0;n=n-o|0;p=l-n>>1;o=p-o|0;m=p-m|0;l=l-o|0;n=n+m|0;b[c>>1]=l;b[c+2>>1]=o;b[c+4>>1]=m;b[c+6>>1]=n;f=f+8|0;c=c+8|0;k=k+1|0}f=h|0;k=0;while(1){if((k|0)>=4){break}l=b[f>>1]|0;m=b[f+8>>1]|0;n=b[f+16>>1]|0;o=b[f+24>>1]|0;l=l+m|0;n=n-o|0;p=l-n>>1;o=p-o|0;m=p-m|0;l=l-o|0;n=n+m|0;h=(d[j+0|0]|0)+l|0;if((h|0)>255){q=255}else{if((h|0)<0){r=0}else{r=h}q=r}a[j+0|0]=q;h=(d[j+e|0]|0)+o|0;if((h|0)>255){s=255}else{if((h|0)<0){t=0}else{t=h}s=t}a[j+e|0]=s;h=(d[j+(e<<1)|0]|0)+m|0;if((h|0)>255){u=255}else{if((h|0)<0){v=0}else{v=h}u=v}a[j+(e<<1)|0]=u;h=(d[j+(e*3|0)|0]|0)+n|0;if((h|0)>255){w=255}else{if((h|0)<0){x=0}else{x=h}w=x}a[j+(e*3|0)|0]=w;f=f+2|0;j=j+1|0;k=k+1|0}i=g;return}function Vec(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+8|0;h=g|0;j=e;e=f;f=c;c=h|0;k=b[f>>1]>>2;l=k>>1;k=k-l|0;b[c>>1]=k;m=l&65535;b[c+6>>1]=m;b[c+4>>1]=m;b[c+2>>1]=m;f=h|0;h=0;while(1){if((h|0)>=4){break}l=b[f>>1]>>1;k=(b[f>>1]|0)-l|0;m=(d[j+0|0]|0)+k|0;if((m|0)>255){n=255}else{if((m|0)<0){o=0}else{o=m}n=o}a[j+0|0]=n;m=(d[j+e|0]|0)+l|0;if((m|0)>255){p=255}else{if((m|0)<0){q=0}else{q=m}p=q}a[j+e|0]=p;m=(d[j+(e<<1)|0]|0)+l|0;if((m|0)>255){r=255}else{if((m|0)<0){s=0}else{s=m}r=s}a[j+(e<<1)|0]=r;m=(d[j+(e*3|0)|0]|0)+l|0;if((m|0)>255){t=255}else{if((m|0)<0){u=0}else{u=m}t=u}a[j+(e*3|0)|0]=t;f=f+2|0;j=j+1|0;h=h+1|0}i=g;return}function Wec(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+48|0;h=g|0;j=g+32|0;k=g+40|0;l=c;c=e;e=f;f=h|0;m=0;while(1){if((m|0)>=4){break}Xec(l,f);l=l+8|0;f=f+8|0;m=m+1|0}m=0;while(1){if((m|0)>=4){break}f=0;while(1){if((f|0)>=4){break}b[j+(f<<1)>>1]=b[h+((f<<2)+m<<1)>>1]|0;f=f+1|0}Xec(j|0,k|0);f=0;while(1){if((f|0)>=4){break}l=((b[k+(f<<1)>>1]|0)+8>>4)+(d[c+((ca(f,e)|0)+m)|0]|0)|0;if((l|0)>255){n=255}else{if((l|0)<0){o=0}else{o=l}n=o}a[c+((ca(f,e)|0)+m)|0]=n;f=f+1|0}m=m+1|0}i=g;return}function Xec(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=a;a=c;c=((b[f>>1]|0)+(b[f+4>>1]|0)|0)*11585|0;g=((b[f>>1]|0)-(b[f+4>>1]|0)|0)*11585|0;b[e>>1]=(c+8192>>14&65535)<<16>>16;b[e+2>>1]=(g+8192>>14&65535)<<16>>16;c=((b[f+2>>1]|0)*6270|0)-((b[f+6>>1]|0)*15137|0)|0;g=((b[f+2>>1]|0)*15137|0)+((b[f+6>>1]|0)*6270|0)|0;b[e+4>>1]=(c+8192>>14&65535)<<16>>16;b[e+6>>1]=(g+8192>>14&65535)<<16>>16;b[a>>1]=(b[e>>1]|0)+(b[e+6>>1]|0);b[a+2>>1]=(b[e+2>>1]|0)+(b[e+4>>1]|0);b[a+4>>1]=(b[e+2>>1]|0)-(b[e+4>>1]|0);b[a+6>>1]=(b[e>>1]|0)-(b[e+6>>1]|0);i=d;return}function Yec(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;h=e;e=f;f=(((b[c>>1]|0)*11585|0)+8192>>14&65535)<<16>>16&65535;f=(((f<<16>>16)*11585|0)+8192>>14&65535)<<16>>16&65535;c=(f<<16>>16)+8>>4;f=0;while(1){if((f|0)>=4){break}j=(d[h|0]|0)+c|0;if((j|0)>255){k=255}else{if((j|0)<0){l=0}else{l=j}k=l}a[h|0]=k;j=(d[h+1|0]|0)+c|0;if((j|0)>255){m=255}else{if((j|0)<0){n=0}else{n=j}m=n}a[h+1|0]=m;j=(d[h+2|0]|0)+c|0;if((j|0)>255){o=255}else{if((j|0)<0){p=0}else{p=j}o=p}a[h+2|0]=o;j=(d[h+3|0]|0)+c|0;if((j|0)>255){q=255}else{if((j|0)<0){r=0}else{r=j}q=r}a[h+3|0]=q;h=h+e|0;f=f+1|0}i=g;return}function Zec(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+160|0;h=g|0;j=g+128|0;k=g+144|0;l=c;c=e;e=f;f=h|0;m=0;while(1){if((m|0)>=8){break}_ec(l,f);l=l+16|0;f=f+16|0;m=m+1|0}m=0;while(1){if((m|0)>=8){break}f=0;while(1){if((f|0)>=8){break}b[j+(f<<1)>>1]=b[h+((f<<3)+m<<1)>>1]|0;f=f+1|0}_ec(j|0,k|0);f=0;while(1){if((f|0)>=8){break}l=((b[k+(f<<1)>>1]|0)+16>>5)+(d[c+((ca(f,e)|0)+m)|0]|0)|0;if((l|0)>255){n=255}else{if((l|0)<0){o=0}else{o=l}n=o}a[c+((ca(f,e)|0)+m)|0]=n;f=f+1|0}m=m+1|0}i=g;return}function _ec(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=a;a=c;b[e>>1]=b[g>>1]|0;b[e+4>>1]=b[g+8>>1]|0;b[e+2>>1]=b[g+4>>1]|0;b[e+6>>1]=b[g+12>>1]|0;c=((b[g+2>>1]|0)*3196|0)-((b[g+14>>1]|0)*16069|0)|0;h=((b[g+2>>1]|0)*16069|0)+((b[g+14>>1]|0)*3196|0)|0;b[e+8>>1]=(c+8192>>14&65535)<<16>>16;b[e+14>>1]=(h+8192>>14&65535)<<16>>16;c=((b[g+10>>1]|0)*13623|0)-((b[g+6>>1]|0)*9102|0)|0;h=((b[g+10>>1]|0)*9102|0)+((b[g+6>>1]|0)*13623|0)|0;b[e+10>>1]=(c+8192>>14&65535)<<16>>16;b[e+12>>1]=(h+8192>>14&65535)<<16>>16;Xec(e|0,e|0);b[f+8>>1]=(b[e+8>>1]|0)+(b[e+10>>1]|0);b[f+10>>1]=(b[e+8>>1]|0)-(b[e+10>>1]|0);b[f+12>>1]=(-(b[e+12>>1]|0)|0)+(b[e+14>>1]|0);b[f+14>>1]=(b[e+12>>1]|0)+(b[e+14>>1]|0);b[e+8>>1]=b[f+8>>1]|0;c=((b[f+12>>1]|0)-(b[f+10>>1]|0)|0)*11585|0;h=((b[f+10>>1]|0)+(b[f+12>>1]|0)|0)*11585|0;b[e+10>>1]=(c+8192>>14&65535)<<16>>16;b[e+12>>1]=(h+8192>>14&65535)<<16>>16;b[e+14>>1]=b[f+14>>1]|0;b[a>>1]=(b[e>>1]|0)+(b[e+14>>1]|0);b[a+2>>1]=(b[e+2>>1]|0)+(b[e+12>>1]|0);b[a+4>>1]=(b[e+4>>1]|0)+(b[e+10>>1]|0);b[a+6>>1]=(b[e+6>>1]|0)+(b[e+8>>1]|0);b[a+8>>1]=(b[e+6>>1]|0)-(b[e+8>>1]|0);b[a+10>>1]=(b[e+4>>1]|0)-(b[e+10>>1]|0);b[a+12>>1]=(b[e+2>>1]|0)-(b[e+12>>1]|0);b[a+14>>1]=(b[e>>1]|0)-(b[e+14>>1]|0);i=d;return}function $ec(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=e;e=f;f=(((b[c>>1]|0)*11585|0)+8192>>14&65535)<<16>>16&65535;f=(((f<<16>>16)*11585|0)+8192>>14&65535)<<16>>16&65535;c=(f<<16>>16)+16>>5;f=0;while(1){if((f|0)>=8){break}j=0;while(1){if((j|0)>=8){break}k=(d[h+j|0]|0)+c|0;if((k|0)>255){l=255}else{if((k|0)<0){m=0}else{m=k}l=m}a[h+j|0]=l;j=j+1|0}h=h+e|0;f=f+1|0}i=g;return}function afc(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;i=i+48|0;k=j|0;l=j+32|0;m=j+40|0;n=e;e=f;f=g;g=h;h=k|0;o=0;while(1){if((o|0)>=4){break}re[c[215500+(g<<3)>>2]&1023](n,h);n=n+8|0;h=h+8|0;o=o+1|0}o=0;while(1){if((o|0)>=4){break}h=0;while(1){if((h|0)>=4){break}b[l+(h<<1)>>1]=b[k+((h<<2)+o<<1)>>1]|0;h=h+1|0}re[c[215496+(g<<3)>>2]&1023](l|0,m|0);h=0;while(1){if((h|0)>=4){break}n=((b[m+(h<<1)>>1]|0)+8>>4)+(d[e+((ca(h,f)|0)+o)|0]|0)|0;if((n|0)>255){p=255}else{if((n|0)<0){q=0}else{q=n}p=q}a[e+((ca(h,f)|0)+o)|0]=p;h=h+1|0}o=o+1|0}i=j;return}function bfc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a;a=c;c=b[e>>1]|0;f=b[e+2>>1]|0;g=b[e+4>>1]|0;h=b[e+6>>1]|0;if((c|f|g|h|0)!=0){e=c*5283|0;j=c*9929|0;k=f*13377|0;l=g*15212|0;m=c-g+h|0;c=e+l+(h*9929|0)|0;f=j-(g*5283|0)-(h*15212|0)|0;g=m*13377|0;h=k;e=c+h|0;j=f+h|0;k=g;l=c+f-h|0;b[a>>1]=(e+8192>>14&65535)<<16>>16;b[a+2>>1]=(j+8192>>14&65535)<<16>>16;b[a+4>>1]=(k+8192>>14&65535)<<16>>16;b[a+6>>1]=(l+8192>>14&65535)<<16>>16;i=d;return}else{b[a+6>>1]=0;b[a+4>>1]=0;b[a+2>>1]=0;b[a>>1]=0;i=d;return}}function cfc(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;i=i+168|0;k=j|0;l=j+128|0;m=j+144|0;n=j+160|0;o=e;e=f;f=g;g=k|0;p=n;q=2658904+(h<<3)|0;c[p>>2]=c[q>>2];c[p+4>>2]=c[q+4>>2];q=0;while(1){if((q|0)>=8){break}re[c[n+4>>2]&1023](o,g);o=o+16|0;g=g+16|0;q=q+1|0}q=0;while(1){if((q|0)>=8){break}g=0;while(1){if((g|0)>=8){break}b[l+(g<<1)>>1]=b[k+((g<<3)+q<<1)>>1]|0;g=g+1|0}re[c[n>>2]&1023](l|0,m|0);g=0;while(1){if((g|0)>=8){break}o=((b[m+(g<<1)>>1]|0)+16>>5)+(d[e+((ca(g,f)|0)+q)|0]|0)|0;if((o|0)>255){r=255}else{if((o|0)<0){s=0}else{s=o}r=s}a[e+((ca(g,f)|0)+q)|0]=r;g=g+1|0}q=q+1|0}i=j;return}function dfc(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+160|0;h=g|0;j=g+128|0;k=g+144|0;l=c;c=e;e=f;mrc(h|0,0,128)|0;f=h|0;m=0;while(1){if((m|0)>=4){break}_ec(l,f);l=l+16|0;f=f+16|0;m=m+1|0}m=0;while(1){if((m|0)>=8){break}f=0;while(1){if((f|0)>=8){break}b[j+(f<<1)>>1]=b[h+((f<<3)+m<<1)>>1]|0;f=f+1|0}_ec(j|0,k|0);f=0;while(1){if((f|0)>=8){break}l=((b[k+(f<<1)>>1]|0)+16>>5)+(d[c+((ca(f,e)|0)+m)|0]|0)|0;if((l|0)>255){n=255}else{if((l|0)<0){o=0}else{o=l}n=o}a[c+((ca(f,e)|0)+m)|0]=n;f=f+1|0}m=m+1|0}i=g;return}function efc(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+576|0;h=g|0;j=g+512|0;k=g+544|0;l=c;c=e;e=f;f=h|0;m=0;while(1){if((m|0)>=16){break}ffc(l,f);l=l+32|0;f=f+32|0;m=m+1|0}m=0;while(1){if((m|0)>=16){break}f=0;while(1){if((f|0)>=16){break}b[j+(f<<1)>>1]=b[h+((f<<4)+m<<1)>>1]|0;f=f+1|0}ffc(j|0,k|0);f=0;while(1){if((f|0)>=16){break}l=((b[k+(f<<1)>>1]|0)+32>>6)+(d[c+((ca(f,e)|0)+m)|0]|0)|0;if((l|0)>255){n=255}else{if((l|0)<0){o=0}else{o=l}n=o}a[c+((ca(f,e)|0)+m)|0]=n;f=f+1|0}m=m+1|0}i=g;return}function ffc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+64|0;e=d|0;f=d+32|0;g=a;a=c;b[e>>1]=b[g>>1]|0;b[e+2>>1]=b[g+16>>1]|0;b[e+4>>1]=b[g+8>>1]|0;b[e+6>>1]=b[g+24>>1]|0;b[e+8>>1]=b[g+4>>1]|0;b[e+10>>1]=b[g+20>>1]|0;b[e+12>>1]=b[g+12>>1]|0;b[e+14>>1]=b[g+28>>1]|0;b[e+16>>1]=b[g+2>>1]|0;b[e+18>>1]=b[g+18>>1]|0;b[e+20>>1]=b[g+10>>1]|0;b[e+22>>1]=b[g+26>>1]|0;b[e+24>>1]=b[g+6>>1]|0;b[e+26>>1]=b[g+22>>1]|0;b[e+28>>1]=b[g+14>>1]|0;b[e+30>>1]=b[g+30>>1]|0;b[f>>1]=b[e>>1]|0;b[f+2>>1]=b[e+2>>1]|0;b[f+4>>1]=b[e+4>>1]|0;b[f+6>>1]=b[e+6>>1]|0;b[f+8>>1]=b[e+8>>1]|0;b[f+10>>1]=b[e+10>>1]|0;b[f+12>>1]=b[e+12>>1]|0;b[f+14>>1]=b[e+14>>1]|0;g=((b[e+16>>1]|0)*1606|0)-((b[e+30>>1]|0)*16305|0)|0;c=((b[e+16>>1]|0)*16305|0)+((b[e+30>>1]|0)*1606|0)|0;b[f+16>>1]=(g+8192>>14&65535)<<16>>16;b[f+30>>1]=(c+8192>>14&65535)<<16>>16;g=((b[e+18>>1]|0)*12665|0)-((b[e+28>>1]|0)*10394|0)|0;c=((b[e+18>>1]|0)*10394|0)+((b[e+28>>1]|0)*12665|0)|0;b[f+18>>1]=(g+8192>>14&65535)<<16>>16;b[f+28>>1]=(c+8192>>14&65535)<<16>>16;g=((b[e+20>>1]|0)*7723|0)-((b[e+26>>1]|0)*14449|0)|0;c=((b[e+20>>1]|0)*14449|0)+((b[e+26>>1]|0)*7723|0)|0;b[f+20>>1]=(g+8192>>14&65535)<<16>>16;b[f+26>>1]=(c+8192>>14&65535)<<16>>16;g=((b[e+22>>1]|0)*15679|0)-((b[e+24>>1]|0)*4756|0)|0;c=((b[e+22>>1]|0)*4756|0)+((b[e+24>>1]|0)*15679|0)|0;b[f+22>>1]=(g+8192>>14&65535)<<16>>16;b[f+24>>1]=(c+8192>>14&65535)<<16>>16;b[e>>1]=b[f>>1]|0;b[e+2>>1]=b[f+2>>1]|0;b[e+4>>1]=b[f+4>>1]|0;b[e+6>>1]=b[f+6>>1]|0;g=((b[f+8>>1]|0)*3196|0)-((b[f+14>>1]|0)*16069|0)|0;c=((b[f+8>>1]|0)*16069|0)+((b[f+14>>1]|0)*3196|0)|0;b[e+8>>1]=(g+8192>>14&65535)<<16>>16;b[e+14>>1]=(c+8192>>14&65535)<<16>>16;g=((b[f+10>>1]|0)*13623|0)-((b[f+12>>1]|0)*9102|0)|0;c=((b[f+10>>1]|0)*9102|0)+((b[f+12>>1]|0)*13623|0)|0;b[e+10>>1]=(g+8192>>14&65535)<<16>>16;b[e+12>>1]=(c+8192>>14&65535)<<16>>16;b[e+16>>1]=(b[f+16>>1]|0)+(b[f+18>>1]|0);b[e+18>>1]=(b[f+16>>1]|0)-(b[f+18>>1]|0);b[e+20>>1]=(-(b[f+20>>1]|0)|0)+(b[f+22>>1]|0);b[e+22>>1]=(b[f+20>>1]|0)+(b[f+22>>1]|0);b[e+24>>1]=(b[f+24>>1]|0)+(b[f+26>>1]|0);b[e+26>>1]=(b[f+24>>1]|0)-(b[f+26>>1]|0);b[e+28>>1]=(-(b[f+28>>1]|0)|0)+(b[f+30>>1]|0);b[e+30>>1]=(b[f+28>>1]|0)+(b[f+30>>1]|0);g=((b[e>>1]|0)+(b[e+2>>1]|0)|0)*11585|0;c=((b[e>>1]|0)-(b[e+2>>1]|0)|0)*11585|0;b[f>>1]=(g+8192>>14&65535)<<16>>16;b[f+2>>1]=(c+8192>>14&65535)<<16>>16;g=((b[e+4>>1]|0)*6270|0)-((b[e+6>>1]|0)*15137|0)|0;c=((b[e+4>>1]|0)*15137|0)+((b[e+6>>1]|0)*6270|0)|0;b[f+4>>1]=(g+8192>>14&65535)<<16>>16;b[f+6>>1]=(c+8192>>14&65535)<<16>>16;b[f+8>>1]=(b[e+8>>1]|0)+(b[e+10>>1]|0);b[f+10>>1]=(b[e+8>>1]|0)-(b[e+10>>1]|0);b[f+12>>1]=(-(b[e+12>>1]|0)|0)+(b[e+14>>1]|0);b[f+14>>1]=(b[e+12>>1]|0)+(b[e+14>>1]|0);b[f+16>>1]=b[e+16>>1]|0;b[f+30>>1]=b[e+30>>1]|0;g=((-(b[e+18>>1]|0)|0)*15137|0)+((b[e+28>>1]|0)*6270|0)|0;c=((b[e+18>>1]|0)*6270|0)+((b[e+28>>1]|0)*15137|0)|0;b[f+18>>1]=(g+8192>>14&65535)<<16>>16;b[f+28>>1]=(c+8192>>14&65535)<<16>>16;g=((-(b[e+20>>1]|0)|0)*6270|0)-((b[e+26>>1]|0)*15137|0)|0;c=((-(b[e+20>>1]|0)|0)*15137|0)+((b[e+26>>1]|0)*6270|0)|0;b[f+20>>1]=(g+8192>>14&65535)<<16>>16;b[f+26>>1]=(c+8192>>14&65535)<<16>>16;b[f+22>>1]=b[e+22>>1]|0;b[f+24>>1]=b[e+24>>1]|0;b[e>>1]=(b[f>>1]|0)+(b[f+6>>1]|0);b[e+2>>1]=(b[f+2>>1]|0)+(b[f+4>>1]|0);b[e+4>>1]=(b[f+2>>1]|0)-(b[f+4>>1]|0);b[e+6>>1]=(b[f>>1]|0)-(b[f+6>>1]|0);b[e+8>>1]=b[f+8>>1]|0;g=((b[f+12>>1]|0)-(b[f+10>>1]|0)|0)*11585|0;c=((b[f+10>>1]|0)+(b[f+12>>1]|0)|0)*11585|0;b[e+10>>1]=(g+8192>>14&65535)<<16>>16;b[e+12>>1]=(c+8192>>14&65535)<<16>>16;b[e+14>>1]=b[f+14>>1]|0;b[e+16>>1]=(b[f+16>>1]|0)+(b[f+22>>1]|0);b[e+18>>1]=(b[f+18>>1]|0)+(b[f+20>>1]|0);b[e+20>>1]=(b[f+18>>1]|0)-(b[f+20>>1]|0);b[e+22>>1]=(b[f+16>>1]|0)-(b[f+22>>1]|0);b[e+24>>1]=(-(b[f+24>>1]|0)|0)+(b[f+30>>1]|0);b[e+26>>1]=(-(b[f+26>>1]|0)|0)+(b[f+28>>1]|0);b[e+28>>1]=(b[f+26>>1]|0)+(b[f+28>>1]|0);b[e+30>>1]=(b[f+24>>1]|0)+(b[f+30>>1]|0);b[f>>1]=(b[e>>1]|0)+(b[e+14>>1]|0);b[f+2>>1]=(b[e+2>>1]|0)+(b[e+12>>1]|0);b[f+4>>1]=(b[e+4>>1]|0)+(b[e+10>>1]|0);b[f+6>>1]=(b[e+6>>1]|0)+(b[e+8>>1]|0);b[f+8>>1]=(b[e+6>>1]|0)-(b[e+8>>1]|0);b[f+10>>1]=(b[e+4>>1]|0)-(b[e+10>>1]|0);b[f+12>>1]=(b[e+2>>1]|0)-(b[e+12>>1]|0);b[f+14>>1]=(b[e>>1]|0)-(b[e+14>>1]|0);b[f+16>>1]=b[e+16>>1]|0;b[f+18>>1]=b[e+18>>1]|0;g=((-(b[e+20>>1]|0)|0)+(b[e+26>>1]|0)|0)*11585|0;c=((b[e+20>>1]|0)+(b[e+26>>1]|0)|0)*11585|0;b[f+20>>1]=(g+8192>>14&65535)<<16>>16;b[f+26>>1]=(c+8192>>14&65535)<<16>>16;g=((-(b[e+22>>1]|0)|0)+(b[e+24>>1]|0)|0)*11585|0;c=((b[e+22>>1]|0)+(b[e+24>>1]|0)|0)*11585|0;b[f+22>>1]=(g+8192>>14&65535)<<16>>16;b[f+24>>1]=(c+8192>>14&65535)<<16>>16;b[f+28>>1]=b[e+28>>1]|0;b[f+30>>1]=b[e+30>>1]|0;b[a>>1]=(b[f>>1]|0)+(b[f+30>>1]|0);b[a+2>>1]=(b[f+2>>1]|0)+(b[f+28>>1]|0);b[a+4>>1]=(b[f+4>>1]|0)+(b[f+26>>1]|0);b[a+6>>1]=(b[f+6>>1]|0)+(b[f+24>>1]|0);b[a+8>>1]=(b[f+8>>1]|0)+(b[f+22>>1]|0);b[a+10>>1]=(b[f+10>>1]|0)+(b[f+20>>1]|0);b[a+12>>1]=(b[f+12>>1]|0)+(b[f+18>>1]|0);b[a+14>>1]=(b[f+14>>1]|0)+(b[f+16>>1]|0);b[a+16>>1]=(b[f+14>>1]|0)-(b[f+16>>1]|0);b[a+18>>1]=(b[f+12>>1]|0)-(b[f+18>>1]|0);b[a+20>>1]=(b[f+10>>1]|0)-(b[f+20>>1]|0);b[a+22>>1]=(b[f+8>>1]|0)-(b[f+22>>1]|0);b[a+24>>1]=(b[f+6>>1]|0)-(b[f+24>>1]|0);b[a+26>>1]=(b[f+4>>1]|0)-(b[f+26>>1]|0);b[a+28>>1]=(b[f+2>>1]|0)-(b[f+28>>1]|0);b[a+30>>1]=(b[f>>1]|0)-(b[f+30>>1]|0);i=d;return}function gfc(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;i=i+584|0;k=j|0;l=j+512|0;m=j+544|0;n=j+576|0;o=e;e=f;f=g;g=k|0;p=n;q=2658936+(h<<3)|0;c[p>>2]=c[q>>2];c[p+4>>2]=c[q+4>>2];q=0;while(1){if((q|0)>=16){break}re[c[n+4>>2]&1023](o,g);o=o+32|0;g=g+32|0;q=q+1|0}q=0;while(1){if((q|0)>=16){break}g=0;while(1){if((g|0)>=16){break}b[l+(g<<1)>>1]=b[k+((g<<4)+q<<1)>>1]|0;g=g+1|0}re[c[n>>2]&1023](l|0,m|0);g=0;while(1){if((g|0)>=16){break}o=((b[m+(g<<1)>>1]|0)+32>>6)+(d[e+((ca(g,f)|0)+q)|0]|0)|0;if((o|0)>255){r=255}else{if((o|0)<0){s=0}else{s=o}r=s}a[e+((ca(g,f)|0)+q)|0]=r;g=g+1|0}q=q+1|0}i=j;return}function hfc(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+576|0;h=g|0;j=g+512|0;k=g+544|0;l=c;c=e;e=f;mrc(h|0,0,512)|0;f=h|0;m=0;while(1){if((m|0)>=4){break}ffc(l,f);l=l+32|0;f=f+32|0;m=m+1|0}m=0;while(1){if((m|0)>=16){break}f=0;while(1){if((f|0)>=16){break}b[j+(f<<1)>>1]=b[h+((f<<4)+m<<1)>>1]|0;f=f+1|0}ffc(j|0,k|0);f=0;while(1){if((f|0)>=16){break}l=((b[k+(f<<1)>>1]|0)+32>>6)+(d[c+((ca(f,e)|0)+m)|0]|0)|0;if((l|0)>255){n=255}else{if((l|0)<0){o=0}else{o=l}n=o}a[c+((ca(f,e)|0)+m)|0]=n;f=f+1|0}m=m+1|0}i=g;return}function ifc(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=e;e=f;f=(((b[c>>1]|0)*11585|0)+8192>>14&65535)<<16>>16&65535;f=(((f<<16>>16)*11585|0)+8192>>14&65535)<<16>>16&65535;c=(f<<16>>16)+32>>6;f=0;while(1){if((f|0)>=16){break}j=0;while(1){if((j|0)>=16){break}k=(d[h+j|0]|0)+c|0;if((k|0)>255){l=255}else{if((k|0)<0){m=0}else{m=k}l=m}a[h+j|0]=l;j=j+1|0}h=h+e|0;f=f+1|0}i=g;return}function jfc(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+2208|0;h=g|0;j=g+2048|0;k=g+2112|0;l=g+2176|0;m=c;c=e;e=f;f=h|0;n=0;while(1){if((n|0)>=32){break}o=0;while(1){if((o|0)>=16){break}b[l+(o<<1)>>1]=b[m+(o<<1<<1)>>1]|b[m+((o<<1)+1<<1)>>1];o=o+1|0}o=0;while(1){if((o|0)>=8){break}b[l+(o<<1)>>1]=b[l+(o<<1<<1)>>1]|b[l+((o<<1)+1<<1)>>1];o=o+1|0}o=0;while(1){if((o|0)>=4){break}b[l+(o<<1)>>1]=b[l+(o<<1<<1)>>1]|b[l+((o<<1)+1<<1)>>1];o=o+1|0}o=0;while(1){if((o|0)>=2){break}b[l+(o<<1)>>1]=b[l+(o<<1<<1)>>1]|b[l+((o<<1)+1<<1)>>1];o=o+1|0}if((b[l>>1]|b[l+2>>1]|0)!=0){kfc(m,f)}else{mrc(f|0,0,64)|0}m=m+64|0;f=f+64|0;n=n+1|0}n=0;while(1){if((n|0)>=32){break}o=0;while(1){if((o|0)>=32){break}b[j+(o<<1)>>1]=b[h+((o<<5)+n<<1)>>1]|0;o=o+1|0}kfc(j|0,k|0);o=0;while(1){if((o|0)>=32){break}f=((b[k+(o<<1)>>1]|0)+32>>6)+(d[c+((ca(o,e)|0)+n)|0]|0)|0;if((f|0)>255){p=255}else{if((f|0)<0){q=0}else{q=f}p=q}a[c+((ca(o,e)|0)+n)|0]=p;o=o+1|0}n=n+1|0}i=g;return}function kfc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+128|0;e=d|0;f=d+64|0;g=a;a=c;b[e>>1]=b[g>>1]|0;b[e+2>>1]=b[g+32>>1]|0;b[e+4>>1]=b[g+16>>1]|0;b[e+6>>1]=b[g+48>>1]|0;b[e+8>>1]=b[g+8>>1]|0;b[e+10>>1]=b[g+40>>1]|0;b[e+12>>1]=b[g+24>>1]|0;b[e+14>>1]=b[g+56>>1]|0;b[e+16>>1]=b[g+4>>1]|0;b[e+18>>1]=b[g+36>>1]|0;b[e+20>>1]=b[g+20>>1]|0;b[e+22>>1]=b[g+52>>1]|0;b[e+24>>1]=b[g+12>>1]|0;b[e+26>>1]=b[g+44>>1]|0;b[e+28>>1]=b[g+28>>1]|0;b[e+30>>1]=b[g+60>>1]|0;c=((b[g+2>>1]|0)*804|0)-((b[g+62>>1]|0)*16364|0)|0;h=((b[g+2>>1]|0)*16364|0)+((b[g+62>>1]|0)*804|0)|0;b[e+32>>1]=(c+8192>>14&65535)<<16>>16;b[e+62>>1]=(h+8192>>14&65535)<<16>>16;c=((b[g+34>>1]|0)*12140|0)-((b[g+30>>1]|0)*11003|0)|0;h=((b[g+34>>1]|0)*11003|0)+((b[g+30>>1]|0)*12140|0)|0;b[e+34>>1]=(c+8192>>14&65535)<<16>>16;b[e+60>>1]=(h+8192>>14&65535)<<16>>16;c=((b[g+18>>1]|0)*7005|0)-((b[g+46>>1]|0)*14811|0)|0;h=((b[g+18>>1]|0)*14811|0)+((b[g+46>>1]|0)*7005|0)|0;b[e+36>>1]=(c+8192>>14&65535)<<16>>16;b[e+58>>1]=(h+8192>>14&65535)<<16>>16;c=((b[g+50>>1]|0)*15426|0)-((b[g+14>>1]|0)*5520|0)|0;h=((b[g+50>>1]|0)*5520|0)+((b[g+14>>1]|0)*15426|0)|0;b[e+38>>1]=(c+8192>>14&65535)<<16>>16;b[e+56>>1]=(h+8192>>14&65535)<<16>>16;c=((b[g+10>>1]|0)*3981|0)-((b[g+54>>1]|0)*15893|0)|0;h=((b[g+10>>1]|0)*15893|0)+((b[g+54>>1]|0)*3981|0)|0;b[e+40>>1]=(c+8192>>14&65535)<<16>>16;b[e+54>>1]=(h+8192>>14&65535)<<16>>16;c=((b[g+42>>1]|0)*14053|0)-((b[g+22>>1]|0)*8423|0)|0;h=((b[g+42>>1]|0)*8423|0)+((b[g+22>>1]|0)*14053|0)|0;b[e+42>>1]=(c+8192>>14&65535)<<16>>16;b[e+52>>1]=(h+8192>>14&65535)<<16>>16;c=((b[g+26>>1]|0)*9760|0)-((b[g+38>>1]|0)*13160|0)|0;h=((b[g+26>>1]|0)*13160|0)+((b[g+38>>1]|0)*9760|0)|0;b[e+44>>1]=(c+8192>>14&65535)<<16>>16;b[e+50>>1]=(h+8192>>14&65535)<<16>>16;c=((b[g+58>>1]|0)*16207|0)-((b[g+6>>1]|0)*2404|0)|0;h=((b[g+58>>1]|0)*2404|0)+((b[g+6>>1]|0)*16207|0)|0;b[e+46>>1]=(c+8192>>14&65535)<<16>>16;b[e+48>>1]=(h+8192>>14&65535)<<16>>16;b[f>>1]=b[e>>1]|0;b[f+2>>1]=b[e+2>>1]|0;b[f+4>>1]=b[e+4>>1]|0;b[f+6>>1]=b[e+6>>1]|0;b[f+8>>1]=b[e+8>>1]|0;b[f+10>>1]=b[e+10>>1]|0;b[f+12>>1]=b[e+12>>1]|0;b[f+14>>1]=b[e+14>>1]|0;c=((b[e+16>>1]|0)*1606|0)-((b[e+30>>1]|0)*16305|0)|0;h=((b[e+16>>1]|0)*16305|0)+((b[e+30>>1]|0)*1606|0)|0;b[f+16>>1]=(c+8192>>14&65535)<<16>>16;b[f+30>>1]=(h+8192>>14&65535)<<16>>16;c=((b[e+18>>1]|0)*12665|0)-((b[e+28>>1]|0)*10394|0)|0;h=((b[e+18>>1]|0)*10394|0)+((b[e+28>>1]|0)*12665|0)|0;b[f+18>>1]=(c+8192>>14&65535)<<16>>16;b[f+28>>1]=(h+8192>>14&65535)<<16>>16;c=((b[e+20>>1]|0)*7723|0)-((b[e+26>>1]|0)*14449|0)|0;h=((b[e+20>>1]|0)*14449|0)+((b[e+26>>1]|0)*7723|0)|0;b[f+20>>1]=(c+8192>>14&65535)<<16>>16;b[f+26>>1]=(h+8192>>14&65535)<<16>>16;c=((b[e+22>>1]|0)*15679|0)-((b[e+24>>1]|0)*4756|0)|0;h=((b[e+22>>1]|0)*4756|0)+((b[e+24>>1]|0)*15679|0)|0;b[f+22>>1]=(c+8192>>14&65535)<<16>>16;b[f+24>>1]=(h+8192>>14&65535)<<16>>16;b[f+32>>1]=(b[e+32>>1]|0)+(b[e+34>>1]|0);b[f+34>>1]=(b[e+32>>1]|0)-(b[e+34>>1]|0);b[f+36>>1]=(-(b[e+36>>1]|0)|0)+(b[e+38>>1]|0);b[f+38>>1]=(b[e+36>>1]|0)+(b[e+38>>1]|0);b[f+40>>1]=(b[e+40>>1]|0)+(b[e+42>>1]|0);b[f+42>>1]=(b[e+40>>1]|0)-(b[e+42>>1]|0);b[f+44>>1]=(-(b[e+44>>1]|0)|0)+(b[e+46>>1]|0);b[f+46>>1]=(b[e+44>>1]|0)+(b[e+46>>1]|0);b[f+48>>1]=(b[e+48>>1]|0)+(b[e+50>>1]|0);b[f+50>>1]=(b[e+48>>1]|0)-(b[e+50>>1]|0);b[f+52>>1]=(-(b[e+52>>1]|0)|0)+(b[e+54>>1]|0);b[f+54>>1]=(b[e+52>>1]|0)+(b[e+54>>1]|0);b[f+56>>1]=(b[e+56>>1]|0)+(b[e+58>>1]|0);b[f+58>>1]=(b[e+56>>1]|0)-(b[e+58>>1]|0);b[f+60>>1]=(-(b[e+60>>1]|0)|0)+(b[e+62>>1]|0);b[f+62>>1]=(b[e+60>>1]|0)+(b[e+62>>1]|0);b[e>>1]=b[f>>1]|0;b[e+2>>1]=b[f+2>>1]|0;b[e+4>>1]=b[f+4>>1]|0;b[e+6>>1]=b[f+6>>1]|0;c=((b[f+8>>1]|0)*3196|0)-((b[f+14>>1]|0)*16069|0)|0;h=((b[f+8>>1]|0)*16069|0)+((b[f+14>>1]|0)*3196|0)|0;b[e+8>>1]=(c+8192>>14&65535)<<16>>16;b[e+14>>1]=(h+8192>>14&65535)<<16>>16;c=((b[f+10>>1]|0)*13623|0)-((b[f+12>>1]|0)*9102|0)|0;h=((b[f+10>>1]|0)*9102|0)+((b[f+12>>1]|0)*13623|0)|0;b[e+10>>1]=(c+8192>>14&65535)<<16>>16;b[e+12>>1]=(h+8192>>14&65535)<<16>>16;b[e+16>>1]=(b[f+16>>1]|0)+(b[f+18>>1]|0);b[e+18>>1]=(b[f+16>>1]|0)-(b[f+18>>1]|0);b[e+20>>1]=(-(b[f+20>>1]|0)|0)+(b[f+22>>1]|0);b[e+22>>1]=(b[f+20>>1]|0)+(b[f+22>>1]|0);b[e+24>>1]=(b[f+24>>1]|0)+(b[f+26>>1]|0);b[e+26>>1]=(b[f+24>>1]|0)-(b[f+26>>1]|0);b[e+28>>1]=(-(b[f+28>>1]|0)|0)+(b[f+30>>1]|0);b[e+30>>1]=(b[f+28>>1]|0)+(b[f+30>>1]|0);b[e+32>>1]=b[f+32>>1]|0;b[e+62>>1]=b[f+62>>1]|0;c=((-(b[f+34>>1]|0)|0)*16069|0)+((b[f+60>>1]|0)*3196|0)|0;h=((b[f+34>>1]|0)*3196|0)+((b[f+60>>1]|0)*16069|0)|0;b[e+34>>1]=(c+8192>>14&65535)<<16>>16;b[e+60>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[f+36>>1]|0)|0)*3196|0)-((b[f+58>>1]|0)*16069|0)|0;h=((-(b[f+36>>1]|0)|0)*16069|0)+((b[f+58>>1]|0)*3196|0)|0;b[e+36>>1]=(c+8192>>14&65535)<<16>>16;b[e+58>>1]=(h+8192>>14&65535)<<16>>16;b[e+38>>1]=b[f+38>>1]|0;b[e+40>>1]=b[f+40>>1]|0;c=((-(b[f+42>>1]|0)|0)*9102|0)+((b[f+52>>1]|0)*13623|0)|0;h=((b[f+42>>1]|0)*13623|0)+((b[f+52>>1]|0)*9102|0)|0;b[e+42>>1]=(c+8192>>14&65535)<<16>>16;b[e+52>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[f+44>>1]|0)|0)*13623|0)-((b[f+50>>1]|0)*9102|0)|0;h=((-(b[f+44>>1]|0)|0)*9102|0)+((b[f+50>>1]|0)*13623|0)|0;b[e+44>>1]=(c+8192>>14&65535)<<16>>16;b[e+50>>1]=(h+8192>>14&65535)<<16>>16;b[e+46>>1]=b[f+46>>1]|0;b[e+48>>1]=b[f+48>>1]|0;b[e+54>>1]=b[f+54>>1]|0;b[e+56>>1]=b[f+56>>1]|0;c=((b[e>>1]|0)+(b[e+2>>1]|0)|0)*11585|0;h=((b[e>>1]|0)-(b[e+2>>1]|0)|0)*11585|0;b[f>>1]=(c+8192>>14&65535)<<16>>16;b[f+2>>1]=(h+8192>>14&65535)<<16>>16;c=((b[e+4>>1]|0)*6270|0)-((b[e+6>>1]|0)*15137|0)|0;h=((b[e+4>>1]|0)*15137|0)+((b[e+6>>1]|0)*6270|0)|0;b[f+4>>1]=(c+8192>>14&65535)<<16>>16;b[f+6>>1]=(h+8192>>14&65535)<<16>>16;b[f+8>>1]=(b[e+8>>1]|0)+(b[e+10>>1]|0);b[f+10>>1]=(b[e+8>>1]|0)-(b[e+10>>1]|0);b[f+12>>1]=(-(b[e+12>>1]|0)|0)+(b[e+14>>1]|0);b[f+14>>1]=(b[e+12>>1]|0)+(b[e+14>>1]|0);b[f+16>>1]=b[e+16>>1]|0;b[f+30>>1]=b[e+30>>1]|0;c=((-(b[e+18>>1]|0)|0)*15137|0)+((b[e+28>>1]|0)*6270|0)|0;h=((b[e+18>>1]|0)*6270|0)+((b[e+28>>1]|0)*15137|0)|0;b[f+18>>1]=(c+8192>>14&65535)<<16>>16;b[f+28>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[e+20>>1]|0)|0)*6270|0)-((b[e+26>>1]|0)*15137|0)|0;h=((-(b[e+20>>1]|0)|0)*15137|0)+((b[e+26>>1]|0)*6270|0)|0;b[f+20>>1]=(c+8192>>14&65535)<<16>>16;b[f+26>>1]=(h+8192>>14&65535)<<16>>16;b[f+22>>1]=b[e+22>>1]|0;b[f+24>>1]=b[e+24>>1]|0;b[f+32>>1]=(b[e+32>>1]|0)+(b[e+38>>1]|0);b[f+34>>1]=(b[e+34>>1]|0)+(b[e+36>>1]|0);b[f+36>>1]=(b[e+34>>1]|0)-(b[e+36>>1]|0);b[f+38>>1]=(b[e+32>>1]|0)-(b[e+38>>1]|0);b[f+40>>1]=(-(b[e+40>>1]|0)|0)+(b[e+46>>1]|0);b[f+42>>1]=(-(b[e+42>>1]|0)|0)+(b[e+44>>1]|0);b[f+44>>1]=(b[e+42>>1]|0)+(b[e+44>>1]|0);b[f+46>>1]=(b[e+40>>1]|0)+(b[e+46>>1]|0);b[f+48>>1]=(b[e+48>>1]|0)+(b[e+54>>1]|0);b[f+50>>1]=(b[e+50>>1]|0)+(b[e+52>>1]|0);b[f+52>>1]=(b[e+50>>1]|0)-(b[e+52>>1]|0);b[f+54>>1]=(b[e+48>>1]|0)-(b[e+54>>1]|0);b[f+56>>1]=(-(b[e+56>>1]|0)|0)+(b[e+62>>1]|0);b[f+58>>1]=(-(b[e+58>>1]|0)|0)+(b[e+60>>1]|0);b[f+60>>1]=(b[e+58>>1]|0)+(b[e+60>>1]|0);b[f+62>>1]=(b[e+56>>1]|0)+(b[e+62>>1]|0);b[e>>1]=(b[f>>1]|0)+(b[f+6>>1]|0);b[e+2>>1]=(b[f+2>>1]|0)+(b[f+4>>1]|0);b[e+4>>1]=(b[f+2>>1]|0)-(b[f+4>>1]|0);b[e+6>>1]=(b[f>>1]|0)-(b[f+6>>1]|0);b[e+8>>1]=b[f+8>>1]|0;c=((b[f+12>>1]|0)-(b[f+10>>1]|0)|0)*11585|0;h=((b[f+10>>1]|0)+(b[f+12>>1]|0)|0)*11585|0;b[e+10>>1]=(c+8192>>14&65535)<<16>>16;b[e+12>>1]=(h+8192>>14&65535)<<16>>16;b[e+14>>1]=b[f+14>>1]|0;b[e+16>>1]=(b[f+16>>1]|0)+(b[f+22>>1]|0);b[e+18>>1]=(b[f+18>>1]|0)+(b[f+20>>1]|0);b[e+20>>1]=(b[f+18>>1]|0)-(b[f+20>>1]|0);b[e+22>>1]=(b[f+16>>1]|0)-(b[f+22>>1]|0);b[e+24>>1]=(-(b[f+24>>1]|0)|0)+(b[f+30>>1]|0);b[e+26>>1]=(-(b[f+26>>1]|0)|0)+(b[f+28>>1]|0);b[e+28>>1]=(b[f+26>>1]|0)+(b[f+28>>1]|0);b[e+30>>1]=(b[f+24>>1]|0)+(b[f+30>>1]|0);b[e+32>>1]=b[f+32>>1]|0;b[e+34>>1]=b[f+34>>1]|0;c=((-(b[f+36>>1]|0)|0)*15137|0)+((b[f+58>>1]|0)*6270|0)|0;h=((b[f+36>>1]|0)*6270|0)+((b[f+58>>1]|0)*15137|0)|0;b[e+36>>1]=(c+8192>>14&65535)<<16>>16;b[e+58>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[f+38>>1]|0)|0)*15137|0)+((b[f+56>>1]|0)*6270|0)|0;h=((b[f+38>>1]|0)*6270|0)+((b[f+56>>1]|0)*15137|0)|0;b[e+38>>1]=(c+8192>>14&65535)<<16>>16;b[e+56>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[f+40>>1]|0)|0)*6270|0)-((b[f+54>>1]|0)*15137|0)|0;h=((-(b[f+40>>1]|0)|0)*15137|0)+((b[f+54>>1]|0)*6270|0)|0;b[e+40>>1]=(c+8192>>14&65535)<<16>>16;b[e+54>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[f+42>>1]|0)|0)*6270|0)-((b[f+52>>1]|0)*15137|0)|0;h=((-(b[f+42>>1]|0)|0)*15137|0)+((b[f+52>>1]|0)*6270|0)|0;b[e+42>>1]=(c+8192>>14&65535)<<16>>16;b[e+52>>1]=(h+8192>>14&65535)<<16>>16;b[e+44>>1]=b[f+44>>1]|0;b[e+46>>1]=b[f+46>>1]|0;b[e+48>>1]=b[f+48>>1]|0;b[e+50>>1]=b[f+50>>1]|0;b[e+60>>1]=b[f+60>>1]|0;b[e+62>>1]=b[f+62>>1]|0;b[f>>1]=(b[e>>1]|0)+(b[e+14>>1]|0);b[f+2>>1]=(b[e+2>>1]|0)+(b[e+12>>1]|0);b[f+4>>1]=(b[e+4>>1]|0)+(b[e+10>>1]|0);b[f+6>>1]=(b[e+6>>1]|0)+(b[e+8>>1]|0);b[f+8>>1]=(b[e+6>>1]|0)-(b[e+8>>1]|0);b[f+10>>1]=(b[e+4>>1]|0)-(b[e+10>>1]|0);b[f+12>>1]=(b[e+2>>1]|0)-(b[e+12>>1]|0);b[f+14>>1]=(b[e>>1]|0)-(b[e+14>>1]|0);b[f+16>>1]=b[e+16>>1]|0;b[f+18>>1]=b[e+18>>1]|0;c=((-(b[e+20>>1]|0)|0)+(b[e+26>>1]|0)|0)*11585|0;h=((b[e+20>>1]|0)+(b[e+26>>1]|0)|0)*11585|0;b[f+20>>1]=(c+8192>>14&65535)<<16>>16;b[f+26>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[e+22>>1]|0)|0)+(b[e+24>>1]|0)|0)*11585|0;h=((b[e+22>>1]|0)+(b[e+24>>1]|0)|0)*11585|0;b[f+22>>1]=(c+8192>>14&65535)<<16>>16;b[f+24>>1]=(h+8192>>14&65535)<<16>>16;b[f+28>>1]=b[e+28>>1]|0;b[f+30>>1]=b[e+30>>1]|0;b[f+32>>1]=(b[e+32>>1]|0)+(b[e+46>>1]|0);b[f+34>>1]=(b[e+34>>1]|0)+(b[e+44>>1]|0);b[f+36>>1]=(b[e+36>>1]|0)+(b[e+42>>1]|0);b[f+38>>1]=(b[e+38>>1]|0)+(b[e+40>>1]|0);b[f+40>>1]=(b[e+38>>1]|0)-(b[e+40>>1]|0);b[f+42>>1]=(b[e+36>>1]|0)-(b[e+42>>1]|0);b[f+44>>1]=(b[e+34>>1]|0)-(b[e+44>>1]|0);b[f+46>>1]=(b[e+32>>1]|0)-(b[e+46>>1]|0);b[f+48>>1]=(-(b[e+48>>1]|0)|0)+(b[e+62>>1]|0);b[f+50>>1]=(-(b[e+50>>1]|0)|0)+(b[e+60>>1]|0);b[f+52>>1]=(-(b[e+52>>1]|0)|0)+(b[e+58>>1]|0);b[f+54>>1]=(-(b[e+54>>1]|0)|0)+(b[e+56>>1]|0);b[f+56>>1]=(b[e+54>>1]|0)+(b[e+56>>1]|0);b[f+58>>1]=(b[e+52>>1]|0)+(b[e+58>>1]|0);b[f+60>>1]=(b[e+50>>1]|0)+(b[e+60>>1]|0);b[f+62>>1]=(b[e+48>>1]|0)+(b[e+62>>1]|0);b[e>>1]=(b[f>>1]|0)+(b[f+30>>1]|0);b[e+2>>1]=(b[f+2>>1]|0)+(b[f+28>>1]|0);b[e+4>>1]=(b[f+4>>1]|0)+(b[f+26>>1]|0);b[e+6>>1]=(b[f+6>>1]|0)+(b[f+24>>1]|0);b[e+8>>1]=(b[f+8>>1]|0)+(b[f+22>>1]|0);b[e+10>>1]=(b[f+10>>1]|0)+(b[f+20>>1]|0);b[e+12>>1]=(b[f+12>>1]|0)+(b[f+18>>1]|0);b[e+14>>1]=(b[f+14>>1]|0)+(b[f+16>>1]|0);b[e+16>>1]=(b[f+14>>1]|0)-(b[f+16>>1]|0);b[e+18>>1]=(b[f+12>>1]|0)-(b[f+18>>1]|0);b[e+20>>1]=(b[f+10>>1]|0)-(b[f+20>>1]|0);b[e+22>>1]=(b[f+8>>1]|0)-(b[f+22>>1]|0);b[e+24>>1]=(b[f+6>>1]|0)-(b[f+24>>1]|0);b[e+26>>1]=(b[f+4>>1]|0)-(b[f+26>>1]|0);b[e+28>>1]=(b[f+2>>1]|0)-(b[f+28>>1]|0);b[e+30>>1]=(b[f>>1]|0)-(b[f+30>>1]|0);b[e+32>>1]=b[f+32>>1]|0;b[e+34>>1]=b[f+34>>1]|0;b[e+36>>1]=b[f+36>>1]|0;b[e+38>>1]=b[f+38>>1]|0;c=((-(b[f+40>>1]|0)|0)+(b[f+54>>1]|0)|0)*11585|0;h=((b[f+40>>1]|0)+(b[f+54>>1]|0)|0)*11585|0;b[e+40>>1]=(c+8192>>14&65535)<<16>>16;b[e+54>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[f+42>>1]|0)|0)+(b[f+52>>1]|0)|0)*11585|0;h=((b[f+42>>1]|0)+(b[f+52>>1]|0)|0)*11585|0;b[e+42>>1]=(c+8192>>14&65535)<<16>>16;b[e+52>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[f+44>>1]|0)|0)+(b[f+50>>1]|0)|0)*11585|0;h=((b[f+44>>1]|0)+(b[f+50>>1]|0)|0)*11585|0;b[e+44>>1]=(c+8192>>14&65535)<<16>>16;b[e+50>>1]=(h+8192>>14&65535)<<16>>16;c=((-(b[f+46>>1]|0)|0)+(b[f+48>>1]|0)|0)*11585|0;h=((b[f+46>>1]|0)+(b[f+48>>1]|0)|0)*11585|0;b[e+46>>1]=(c+8192>>14&65535)<<16>>16;b[e+48>>1]=(h+8192>>14&65535)<<16>>16;b[e+56>>1]=b[f+56>>1]|0;b[e+58>>1]=b[f+58>>1]|0;b[e+60>>1]=b[f+60>>1]|0;b[e+62>>1]=b[f+62>>1]|0;b[a>>1]=(b[e>>1]|0)+(b[e+62>>1]|0);b[a+2>>1]=(b[e+2>>1]|0)+(b[e+60>>1]|0);b[a+4>>1]=(b[e+4>>1]|0)+(b[e+58>>1]|0);b[a+6>>1]=(b[e+6>>1]|0)+(b[e+56>>1]|0);b[a+8>>1]=(b[e+8>>1]|0)+(b[e+54>>1]|0);b[a+10>>1]=(b[e+10>>1]|0)+(b[e+52>>1]|0);b[a+12>>1]=(b[e+12>>1]|0)+(b[e+50>>1]|0);b[a+14>>1]=(b[e+14>>1]|0)+(b[e+48>>1]|0);b[a+16>>1]=(b[e+16>>1]|0)+(b[e+46>>1]|0);b[a+18>>1]=(b[e+18>>1]|0)+(b[e+44>>1]|0);b[a+20>>1]=(b[e+20>>1]|0)+(b[e+42>>1]|0);b[a+22>>1]=(b[e+22>>1]|0)+(b[e+40>>1]|0);b[a+24>>1]=(b[e+24>>1]|0)+(b[e+38>>1]|0);b[a+26>>1]=(b[e+26>>1]|0)+(b[e+36>>1]|0);b[a+28>>1]=(b[e+28>>1]|0)+(b[e+34>>1]|0);b[a+30>>1]=(b[e+30>>1]|0)+(b[e+32>>1]|0);b[a+32>>1]=(b[e+30>>1]|0)-(b[e+32>>1]|0);b[a+34>>1]=(b[e+28>>1]|0)-(b[e+34>>1]|0);b[a+36>>1]=(b[e+26>>1]|0)-(b[e+36>>1]|0);b[a+38>>1]=(b[e+24>>1]|0)-(b[e+38>>1]|0);b[a+40>>1]=(b[e+22>>1]|0)-(b[e+40>>1]|0);b[a+42>>1]=(b[e+20>>1]|0)-(b[e+42>>1]|0);b[a+44>>1]=(b[e+18>>1]|0)-(b[e+44>>1]|0);b[a+46>>1]=(b[e+16>>1]|0)-(b[e+46>>1]|0);b[a+48>>1]=(b[e+14>>1]|0)-(b[e+48>>1]|0);b[a+50>>1]=(b[e+12>>1]|0)-(b[e+50>>1]|0);b[a+52>>1]=(b[e+10>>1]|0)-(b[e+52>>1]|0);b[a+54>>1]=(b[e+8>>1]|0)-(b[e+54>>1]|0);b[a+56>>1]=(b[e+6>>1]|0)-(b[e+56>>1]|0);b[a+58>>1]=(b[e+4>>1]|0)-(b[e+58>>1]|0);b[a+60>>1]=(b[e+2>>1]|0)-(b[e+60>>1]|0);b[a+62>>1]=(b[e>>1]|0)-(b[e+62>>1]|0);i=d;return}function lfc(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+2176|0;h=g|0;j=g+2048|0;k=g+2112|0;l=c;c=e;e=f;mrc(h|0,0,2048)|0;f=h|0;m=0;while(1){if((m|0)>=8){break}kfc(l,f);l=l+64|0;f=f+64|0;m=m+1|0}m=0;while(1){if((m|0)>=32){break}f=0;while(1){if((f|0)>=32){break}b[j+(f<<1)>>1]=b[h+((f<<5)+m<<1)>>1]|0;f=f+1|0}kfc(j|0,k|0);f=0;while(1){if((f|0)>=32){break}l=((b[k+(f<<1)>>1]|0)+32>>6)+(d[c+((ca(f,e)|0)+m)|0]|0)|0;if((l|0)>255){n=255}else{if((l|0)<0){o=0}else{o=l}n=o}a[c+((ca(f,e)|0)+m)|0]=n;f=f+1|0}m=m+1|0}i=g;return}function mfc(c,e,f){c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=e;e=f;f=(((b[c>>1]|0)*11585|0)+8192>>14&65535)<<16>>16&65535;f=(((f<<16>>16)*11585|0)+8192>>14&65535)<<16>>16&65535;c=(f<<16>>16)+32>>6;f=0;while(1){if((f|0)>=32){break}j=0;while(1){if((j|0)>=32){break}k=(d[h+j|0]|0)+c|0;if((k|0)>255){l=255}else{if((k|0)<0){m=0}else{m=k}l=m}a[h+j|0]=l;j=j+1|0}h=h+e|0;f=f+1|0}i=g;return}function nfc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=c;if((d|0)>1){Wec(f,a,b);i=e;return}else{Yec(f,a,b);i=e;return}}function ofc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=c;if((d|0)>1){Uec(f,a,b);i=e;return}else{Vec(f,a,b);i=e;return}}function pfc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=c;c=d;if((c|0)==1){$ec(f,a,b);i=e;return}if((c|0)<=10){dfc(f,a,b)}else{Zec(f,a,b)}i=e;return}function qfc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=c;c=d;if((c|0)==1){ifc(f,a,b);i=e;return}if((c|0)<=10){hfc(f,a,b)}else{efc(f,a,b)}i=e;return}function rfc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=c;c=d;if((c|0)==1){mfc(f,a,b);i=e;return}if((c|0)<=34){lfc(f,a,b)}else{jfc(f,a,b)}i=e;return}function sfc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=c;c=d;if((g|0)==0){nfc(a,b,c,e);i=f;return}else{afc(a,b,c,g);i=f;return}}function tfc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=c;c=d;if((g|0)==0){pfc(a,b,c,e);i=f;return}else{cfc(a,b,c,g);i=f;return}}function ufc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=c;c=d;if((g|0)==0){qfc(a,b,c,e);i=f;return}else{gfc(a,b,c,g);i=f;return}}function vfc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=i;e=a;a=c;c=b[e+30>>1]|0;f=b[e>>1]|0;g=b[e+26>>1]|0;h=b[e+4>>1]|0;j=b[e+22>>1]|0;k=b[e+8>>1]|0;l=b[e+18>>1]|0;m=b[e+12>>1]|0;n=b[e+14>>1]|0;o=b[e+16>>1]|0;p=b[e+10>>1]|0;q=b[e+20>>1]|0;r=b[e+6>>1]|0;s=b[e+24>>1]|0;t=b[e+2>>1]|0;u=b[e+28>>1]|0;if((c|f|g|h|j|k|l|m|n|o|p|q|r|s|t|u|0)!=0){e=(c*16364|0)+(f*804|0)|0;v=(c*804|0)-(f*16364|0)|0;w=(g*15893|0)+(h*3981|0)|0;x=(g*3981|0)-(h*15893|0)|0;y=(j*14811|0)+(k*7005|0)|0;z=(j*7005|0)-(k*14811|0)|0;A=(l*13160|0)+(m*9760|0)|0;B=(l*9760|0)-(m*13160|0)|0;C=(n*11003|0)+(o*12140|0)|0;D=(n*12140|0)-(o*11003|0)|0;E=(p*8423|0)+(q*14053|0)|0;F=(p*14053|0)-(q*8423|0)|0;G=(r*5520|0)+(s*15426|0)|0;H=(r*15426|0)-(s*5520|0)|0;I=(t*2404|0)+(u*16207|0)|0;J=(t*16207|0)-(u*2404|0)|0;c=(e+C+8192>>14&65535)<<16>>16;f=(v+D+8192>>14&65535)<<16>>16;g=(w+E+8192>>14&65535)<<16>>16;h=(x+F+8192>>14&65535)<<16>>16;j=(y+G+8192>>14&65535)<<16>>16;k=(z+H+8192>>14&65535)<<16>>16;l=(A+I+8192>>14&65535)<<16>>16;m=(B+J+8192>>14&65535)<<16>>16;n=(e-C+8192>>14&65535)<<16>>16;o=(v-D+8192>>14&65535)<<16>>16;p=(w-E+8192>>14&65535)<<16>>16;q=(x-F+8192>>14&65535)<<16>>16;r=(y-G+8192>>14&65535)<<16>>16;s=(z-H+8192>>14&65535)<<16>>16;t=(A-I+8192>>14&65535)<<16>>16;u=(B-J+8192>>14&65535)<<16>>16;e=c;v=f;w=g;x=h;y=j;z=k;A=l;B=m;C=(n*16069|0)+(o*3196|0)|0;D=(n*3196|0)-(o*16069|0)|0;E=(p*9102|0)+(q*13623|0)|0;F=(p*13623|0)-(q*9102|0)|0;G=((-r|0)*3196|0)+(s*16069|0)|0;H=(r*16069|0)+(s*3196|0)|0;I=((-t|0)*13623|0)+(u*9102|0)|0;J=(t*9102|0)+(u*13623|0)|0;c=e+y|0;f=v+z|0;g=w+A|0;h=x+B|0;j=e-y|0;k=v-z|0;l=w-A|0;m=x-B|0;n=(C+G+8192>>14&65535)<<16>>16;o=(D+H+8192>>14&65535)<<16>>16;p=(E+I+8192>>14&65535)<<16>>16;q=(F+J+8192>>14&65535)<<16>>16;r=(C-G+8192>>14&65535)<<16>>16;s=(D-H+8192>>14&65535)<<16>>16;t=(E-I+8192>>14&65535)<<16>>16;u=(F-J+8192>>14&65535)<<16>>16;e=c;v=f;w=g;x=h;y=(j*15137|0)+(k*6270|0)|0;z=(j*6270|0)-(k*15137|0)|0;A=((-l|0)*6270|0)+(m*15137|0)|0;B=(l*15137|0)+(m*6270|0)|0;C=n;D=o;E=p;F=q;G=(r*15137|0)+(s*6270|0)|0;H=(r*6270|0)-(s*15137|0)|0;I=((-t|0)*6270|0)+(u*15137|0)|0;J=(t*15137|0)+(u*6270|0)|0;c=e+w|0;f=v+x|0;g=e-w|0;h=v-x|0;j=(y+A+8192>>14&65535)<<16>>16;k=(z+B+8192>>14&65535)<<16>>16;l=(y-A+8192>>14&65535)<<16>>16;m=(z-B+8192>>14&65535)<<16>>16;n=C+E|0;o=D+F|0;p=C-E|0;q=D-F|0;r=(G+I+8192>>14&65535)<<16>>16;s=(H+J+8192>>14&65535)<<16>>16;t=(G-I+8192>>14&65535)<<16>>16;u=(H-J+8192>>14&65535)<<16>>16;w=(g+h|0)*-11585|0;x=(g-h|0)*11585|0;A=(l+m|0)*11585|0;B=((-l|0)+m|0)*11585|0;E=(p+q|0)*11585|0;F=((-p|0)+q|0)*11585|0;I=(t+u|0)*-11585|0;J=(t-u|0)*11585|0;g=(w+8192>>14&65535)<<16>>16;h=(x+8192>>14&65535)<<16>>16;l=(A+8192>>14&65535)<<16>>16;m=(B+8192>>14&65535)<<16>>16;p=(E+8192>>14&65535)<<16>>16;q=(F+8192>>14&65535)<<16>>16;t=(I+8192>>14&65535)<<16>>16;u=(J+8192>>14&65535)<<16>>16;b[a>>1]=c;b[a+2>>1]=-n;b[a+4>>1]=r;b[a+6>>1]=-j;b[a+8>>1]=l;b[a+10>>1]=t;b[a+12>>1]=p;b[a+14>>1]=g;b[a+16>>1]=h;b[a+18>>1]=q;b[a+20>>1]=u;b[a+22>>1]=m;b[a+24>>1]=k;b[a+26>>1]=-s;b[a+28>>1]=o;b[a+30>>1]=-f;i=d;return}else{b[a+30>>1]=0;b[a+28>>1]=0;b[a+26>>1]=0;b[a+24>>1]=0;b[a+22>>1]=0;b[a+20>>1]=0;b[a+18>>1]=0;b[a+16>>1]=0;b[a+14>>1]=0;b[a+12>>1]=0;b[a+10>>1]=0;b[a+8>>1]=0;b[a+6>>1]=0;b[a+4>>1]=0;b[a+2>>1]=0;b[a>>1]=0;i=d;return}}function wfc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=a;a=c;c=b[e+14>>1]|0;f=b[e>>1]|0;g=b[e+10>>1]|0;h=b[e+4>>1]|0;j=b[e+6>>1]|0;k=b[e+8>>1]|0;l=b[e+2>>1]|0;m=b[e+12>>1]|0;if((c|f|g|h|j|k|l|m|0)!=0){e=(c*16305|0)+(f*1606|0)|0;n=(c*1606|0)-(f*16305|0)|0;o=(g*14449|0)+(h*7723|0)|0;p=(g*7723|0)-(h*14449|0)|0;q=(j*10394|0)+(k*12665|0)|0;r=(j*12665|0)-(k*10394|0)|0;s=(l*4756|0)+(m*15679|0)|0;t=(l*15679|0)-(m*4756|0)|0;c=(e+q+8192>>14&65535)<<16>>16;f=(n+r+8192>>14&65535)<<16>>16;g=(o+s+8192>>14&65535)<<16>>16;h=(p+t+8192>>14&65535)<<16>>16;j=(e-q+8192>>14&65535)<<16>>16;k=(n-r+8192>>14&65535)<<16>>16;l=(o-s+8192>>14&65535)<<16>>16;m=(p-t+8192>>14&65535)<<16>>16;e=c;n=f;o=g;p=h;q=(j*15137|0)+(k*6270|0)|0;r=(j*6270|0)-(k*15137|0)|0;s=(l*-6270|0)+(m*15137|0)|0;t=(l*15137|0)+(m*6270|0)|0;c=e+o|0;f=n+p|0;g=e-o|0;h=n-p|0;j=(q+s+8192>>14&65535)<<16>>16;k=(r+t+8192>>14&65535)<<16>>16;l=(q-s+8192>>14&65535)<<16>>16;m=(r-t+8192>>14&65535)<<16>>16;o=(g+h|0)*11585|0;p=(g-h|0)*11585|0;s=(l+m|0)*11585|0;t=(l-m|0)*11585|0;g=(o+8192>>14&65535)<<16>>16;h=(p+8192>>14&65535)<<16>>16;l=(s+8192>>14&65535)<<16>>16;m=(t+8192>>14&65535)<<16>>16;b[a>>1]=c;b[a+2>>1]=-j;b[a+4>>1]=l;b[a+6>>1]=-g;b[a+8>>1]=h;b[a+10>>1]=-m;b[a+12>>1]=k;b[a+14>>1]=-f;i=d;return}else{b[a+14>>1]=0;b[a+12>>1]=0;b[a+10>>1]=0;b[a+8>>1]=0;b[a+6>>1]=0;b[a+4>>1]=0;b[a+2>>1]=0;b[a>>1]=0;i=d;return}}function xfc(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=d+10224|0;e=d+13380|0;yfc(a,c[e+4>>2]|0);c[e+8>>2]=c[e+4>>2];e=0;while(1){if((e|0)>63){break}mrc(a+(e*48|0)+32|0,e>>4&255|0,16)|0;e=e+1|0}i=b;return}function yfc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>63){break}e=b>>((a|0)>0)+((a|0)>4);if((a|0)>0){if((e|0)>(9-a|0)){e=9-a|0}}if((e|0)<1){e=1}mrc(d+(b*48|0)+16|0,e&255|0,16)|0;mrc(d+(b*48|0)|0,(b+2<<1)+e&255|0,16)|0;b=b+1|0}i=c;return}function zfc(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;g=b;b=e;e=1<<(b>>5);h=g+10224|0;j=g+13380|0;k=g+13408|0;if((c[j+8>>2]|0)!=(c[j+4>>2]|0)){yfc(h,c[j+4>>2]|0);c[j+8>>2]=c[j+4>>2]}g=0;while(1){if((g|0)>=8){break}l=b;if((Thc(k,g,1)|0)!=0){m=Zhc(k,g,1)|0;if((d[k+3|0]|0)==1){n=m}else{n=b+m|0}m=n;o=0;p=63;if((m|0)<(o|0)){q=o}else{if((m|0)>(p|0)){r=p}else{r=m}q=r}l=q}if((a[j+12|0]|0)!=0){m=l+(ca(a[j+14|0]|0,e)|0)|0;p=0;o=63;if((m|0)<(p|0)){s=p}else{if((m|0)>(o|0)){t=o}else{t=m}s=t}a[h+3072+(g<<3)|0]=s;m=1;while(1){if((m|0)>=4){break}o=0;while(1){if((o|0)>=2){break}p=l+(ca(a[j+14+m|0]|0,e)|0)|0;u=p+(ca(a[j+22+o|0]|0,e)|0)|0;p=0;v=63;if((u|0)<(p|0)){w=p}else{if((u|0)>(v|0)){x=v}else{x=u}w=x}a[h+3072+(g<<3)+(m<<1)+o|0]=w;o=o+1|0}m=m+1|0}}else{mrc(h+3072+(g<<3)|0,l&255|0,8)|0}g=g+1|0}i=f;return}function Afc(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=i;i=i+80|0;l=k|0;m=k+16|0;n=k+32|0;o=k+48|0;p=k+56|0;q=k+64|0;r=k+72|0;s=a;a=d;d=f;f=g;g=h;h=j;j=s+10224|0;t=f;u=f;f=l|0;c[f>>2]=4;v=f+4|0;c[v>>2]=(g<<2)-4;f=v+4|0;c[f>>2]=4;c[f+4>>2]=(-(g<<2)|0)-4;f=m|0;c[f>>2]=2;v=f+4|0;c[v>>2]=(g<<1)-2;f=v+4|0;c[f>>2]=2;c[f+4>>2]=(-(g<<1)|0)-2;f=n|0;c[f>>2]=1;v=f+4|0;c[v>>2]=g-1;f=v+4|0;c[f>>2]=1;c[f+4>>2]=(-g|0)-1;if((a+8|0)>(c[s+10148>>2]|0)){w=(c[s+10148>>2]|0)-a|0}else{w=8}f=w;if((d+8|0)>(c[s+10156>>2]|0)){x=(c[s+10156>>2]|0)-d|0}else{x=8}w=x;mrc(h|0,0,176)|0;x=c[c[t>>2]>>2]|0;do{if((x|0)==11){Bfc(j,c[t>>2]|0,0,0,h);u=t+(g<<2<<2)|0;if(4>=(f|0)){break}else{Bfc(j,c[u>>2]|0,32,8,h);break}}else if((x|0)==12){Bfc(j,c[t>>2]|0,0,0,h)}else if((x|0)==10){Bfc(j,c[t>>2]|0,0,0,h);u=t+16|0;if(4>=(w|0)){break}else{Bfc(j,c[u>>2]|0,4,2,h);break}}else{v=0;while(1){if((v|0)>=4){break}y=c[204232+(v<<2)>>2]|0;z=c[204248+(v<<2)>>2]|0;A=(v&1)<<2;B=v>>1<<2;a:do{if((A|0)>=(w|0)){C=19}else{if((B|0)>=(f|0)){C=19;break}D=c[c[t>>2]>>2]|0;do{if((D|0)==7){Bfc(j,c[t>>2]|0,y,z,h);if((A+2|0)>=(w|0)){break a}else{u=t+8|0;Bfc(j,c[u>>2]|0,y+2|0,z+1|0,h);break}}else if((D|0)==8){Bfc(j,c[t>>2]|0,y,z,h);if((B+2|0)>=(f|0)){break a}else{u=t+(g<<1<<2)|0;Bfc(j,c[u>>2]|0,y+16|0,z+4|0,h);break}}else if((D|0)==9){Bfc(j,c[t>>2]|0,y,z,h)}else{E=0;while(1){if((E|0)>=4){break}F=(c[204232+(v<<2)>>2]|0)+(c[204264+(E<<2)>>2]|0)|0;H=(c[204248+(v<<2)>>2]|0)+(c[204280+(E<<2)>>2]|0)|0;I=A+((E&1)<<1)|0;J=B+(E>>1<<1)|0;b:do{if((I|0)>=(w|0)){C=32}else{if((J|0)>=(f|0)){C=32;break}K=c[c[t>>2]>>2]|0;do{if((K|0)==6){Bfc(j,c[t>>2]|0,F,H,h)}else if((K|0)==4){Bfc(j,c[t>>2]|0,F,H,h);if((I+1|0)>=(w|0)){break b}else{u=t+4|0;Cfc(j,c[u>>2]|0,F+1|0,h);break}}else if((K|0)==5){Bfc(j,c[t>>2]|0,F,H,h);if((J+1|0)>=(f|0)){break b}else{u=t+(g<<2)|0;Cfc(j,c[u>>2]|0,F+8|0,h);break}}else{Bfc(j,c[t>>2]|0,(c[204232+(v<<2)>>2]|0)+(c[204264+(E<<2)>>2]|0)+(c[51054]|0)|0,H,h);t=t+(c[n>>2]<<2)|0;L=1;while(1){if((L|0)>=4){break}M=(c[204232+(v<<2)>>2]|0)+(c[204264+(E<<2)>>2]|0)+(c[204216+(L<<2)>>2]|0)|0;do{if((I+(L&1)|0)>=(w|0)){C=45}else{if((J+(L>>1)|0)>=(f|0)){C=45;break}Cfc(j,c[t>>2]|0,M,h)}}while(0);if((C|0)==45){C=0}t=t+(c[n+(L<<2)>>2]<<2)|0;L=L+1|0}}}while(0)}}while(0);if((C|0)==32){C=0}t=t+(c[m+(E<<2)>>2]<<2)|0;E=E+1|0}}}while(0)}}while(0);if((C|0)==19){C=0}t=t+(c[l+(v<<2)>>2]<<2)|0;v=v+1|0}}}while(0);l=h+24|0;t=h+16|0;C=c[t+4>>2]|c[l+4>>2];c[t>>2]=c[t>>2]|c[l>>2];c[t+4>>2]=C;C=h+56|0;t=h+48|0;l=c[t+4>>2]|c[C+4>>2];c[t>>2]=c[t>>2]|c[C>>2];c[t+4>>2]=l;l=h+76|0;b[l>>1]=e[l>>1]|0|(e[h+78>>1]|0);l=h+84|0;b[l>>1]=e[l>>1]|0|(e[h+86>>1]|0);l=h|0;t=h+8|0;C=c[t+4>>2]|c[l+4>>2]&286331153;c[t>>2]=c[t>>2]|c[l>>2]&286331153;c[t+4>>2]=C;C=h|0;t=c[C+4>>2]&-286331154;c[C>>2]=c[C>>2]&-286331154;c[C+4>>2]=t;t=h+32|0;C=h+40|0;l=c[C+4>>2]|c[t+4>>2]&255;c[C>>2]=c[C>>2]|c[t>>2]&255;c[C+4>>2]=l;l=h+32|0;C=c[l+4>>2]&-256;c[l>>2]=c[l>>2]&-256;c[l+4>>2]=C;C=h+74|0;b[C>>1]=e[C>>1]|0|b[h+72>>1]&4369;C=h+72|0;b[C>>1]=(e[C>>1]|0)&-4370;C=h+82|0;b[C>>1]=e[C>>1]|0|b[h+80>>1]&15;C=h+80|0;b[C>>1]=(e[C>>1]|0)&-16;if((a+8|0)>(c[s+10148>>2]|0)){C=(c[s+10148>>2]|0)-a|0;c[o>>2]=C;c[o+4>>2]=(C|0)<0|0?-1:0;C=yrc(1,0,c[o>>2]<<3|0>>>29|0)|0;a=xrc(C,G,1,0)|0;c[p>>2]=a;c[p+4>>2]=G;a=wrc(c[o>>2]|0,c[o+4>>2]|0,1,0)|0;C=(1<<((a>>>1|G<<31)<<2|0>>>30))-1&65535;N=0;while(1){if((N|0)>=3){break}a=h+(N<<3)|0;l=c[a+4>>2]&c[p+4>>2];c[a>>2]=c[a>>2]&c[p>>2];c[a+4>>2]=l;l=h+32+(N<<3)|0;a=c[l+4>>2]&c[p+4>>2];c[l>>2]=c[l>>2]&c[p>>2];c[l+4>>2]=a;a=h+72+(N<<1)|0;b[a>>1]=(e[a>>1]|0)&(C&65535);a=h+80+(N<<1)|0;b[a>>1]=(e[a>>1]|0)&(C&65535);N=N+1|0}a=h+64|0;l=c[a+4>>2]&c[p+4>>2];c[a>>2]=c[a>>2]&c[p>>2];c[a+4>>2]=l;l=h+88|0;b[l>>1]=(e[l>>1]|0)&(C&65535);if((c[o>>2]|0)==1&(c[o+4>>2]|0)==0){C=h+82|0;b[C>>1]=e[C>>1]|0|(e[h+84>>1]|0);b[h+84>>1]=0}if((c[o>>2]|0)==5&(c[o+4>>2]|0)==0){o=h+82|0;b[o>>1]=e[o>>1]|0|b[h+84>>1]&65280;o=h+84|0;b[o>>1]=(e[o>>1]|0)&~(b[h+84>>1]&65280)}}if((d+8|0)>(c[s+10156>>2]|0)){o=(c[s+10156>>2]|0)-d|0;c[q>>2]=o;c[q+4>>2]=(o|0)<0|0?-1:0;o=(1<<c[q>>2])-1|0;s=Erc(o,(o|0)<0|0?-1:0,16843009,16843009)|0;c[r>>2]=s;c[r+4>>2]=G;s=wrc(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;o=(((1<<(s>>>1|G<<31))-1|0)*4369|0)&65535;s=(((1<<((c[q>>2]|0)>>>1|c[q+4>>2]<<31))-1|0)*4369|0)&65535;N=0;while(1){if((N|0)>=3){break}C=h+(N<<3)|0;l=c[C+4>>2]&c[r+4>>2];c[C>>2]=c[C>>2]&c[r>>2];c[C+4>>2]=l;l=h+32+(N<<3)|0;C=c[l+4>>2]&c[r+4>>2];c[l>>2]=c[l>>2]&c[r>>2];c[l+4>>2]=C;C=h+72+(N<<1)|0;b[C>>1]=(e[C>>1]|0)&(o&65535);C=h+80+(N<<1)|0;b[C>>1]=(e[C>>1]|0)&(o&65535);N=N+1|0}o=h+64|0;C=c[o+4>>2]&c[r+4>>2];c[o>>2]=c[o>>2]&c[r>>2];c[o+4>>2]=C;C=h+88|0;b[C>>1]=(e[C>>1]|0)&(s&65535);if((c[q>>2]|0)==1&(c[q+4>>2]|0)==0){s=h+74|0;b[s>>1]=e[s>>1]|0|(e[h+76>>1]|0);b[h+76>>1]=0}if((c[q>>2]|0)==5&(c[q+4>>2]|0)==0){q=h+74|0;b[q>>1]=e[q>>1]|0|b[h+76>>1]&52428;q=h+76|0;b[q>>1]=(e[q>>1]|0)&~(b[h+76>>1]&52428)}}if((d|0)==0){N=0;while(1){if((N|0)>=3){break}d=h+(N<<3)|0;q=c[d+4>>2]&-16843010;c[d>>2]=c[d>>2]&-16843010;c[d+4>>2]=q;q=h+72+(N<<1)|0;b[q>>1]=b[q>>1]&61166;N=N+1|0}}N=h+16|0;q=h+8|0;if((c[N>>2]&c[q>>2]|0)!=0|(c[N+4>>2]&c[q+4>>2]|0)!=0){Cd(2283232,2544e3,853,2650040)}else{}q=h+16|0;N=h|0;if((c[q>>2]&c[N>>2]|0)!=0|(c[q+4>>2]&c[N+4>>2]|0)!=0){Cd(2416928,2544e3,854,2650040)}else{}N=h+8|0;q=h|0;if((c[N>>2]&c[q>>2]|0)!=0|(c[N+4>>2]&c[q+4>>2]|0)!=0){Cd(2337472,2544e3,855,2650040)}else{}q=h+64|0;N=h+16|0;if((c[q>>2]&c[N>>2]|0)!=0|(c[q+4>>2]&c[N+4>>2]|0)!=0){Cd(2279768,2544e3,856,2650040)}else{}if(((e[h+76>>1]|0)&(e[h+74>>1]|0)|0)!=0){Cd(2230576,2544e3,857,2650040)}else{}if(((e[h+76>>1]|0)&(e[h+72>>1]|0)|0)!=0){Cd(2192240,2544e3,858,2650040)}else{}if(((e[h+74>>1]|0)&(e[h+72>>1]|0)|0)!=0){Cd(2161352,2544e3,859,2650040)}else{}if(((e[h+88>>1]|0)&(e[h+76>>1]|0)|0)!=0){Cd(2135872,2544e3,860,2650040)}else{}N=h+48|0;q=h+40|0;if((c[N>>2]&c[q>>2]|0)!=0|(c[N+4>>2]&c[q+4>>2]|0)!=0){Cd(2112480,2544e3,861,2650040)}else{}q=h+48|0;N=h+32|0;if((c[q>>2]&c[N>>2]|0)!=0|(c[q+4>>2]&c[N+4>>2]|0)!=0){Cd(2630232,2544e3,862,2650040)}else{}N=h+40|0;q=h+32|0;if((c[N>>2]&c[q>>2]|0)!=0|(c[N+4>>2]&c[q+4>>2]|0)!=0){Cd(2605504,2544e3,863,2650040)}else{}q=h+64|0;N=h+48|0;if((c[q>>2]&c[N>>2]|0)!=0|(c[q+4>>2]&c[N+4>>2]|0)!=0){Cd(2579872,2544e3,864,2650040)}else{}if(((e[h+84>>1]|0)&(e[h+82>>1]|0)|0)!=0){Cd(2559968,2544e3,865,2650040)}else{}if(((e[h+84>>1]|0)&(e[h+80>>1]|0)|0)!=0){Cd(2542824,2544e3,866,2650040)}else{}if(((e[h+82>>1]|0)&(e[h+80>>1]|0)|0)!=0){Cd(2525368,2544e3,867,2650040)}else{}if(((e[h+88>>1]|0)&(e[h+84>>1]|0)|0)==0){O=1;P=O&1;i=k;return}Cd(2510208,2544e3,868,2650040);P=O&1;i=k;return}function Bfc(a,f,g,h,j){a=a|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;k=i;l=a;a=g;g=h;h=j;j=f|0;f=c[j>>2]|0;m=c[j+8>>2]|0;n=j;o=c[n+8>>2]|0;p=c[n>>2]|0;if(p>>>0<3>>>0){q=0}else{n=c[558436+(p<<4)>>2]|0;if(o>>>0<(c[833024+(n<<2)>>2]|0)>>>0){r=o}else{r=c[833024+(n<<2)>>2]|0}q=r}r=q;q=(Kfc(l,j)|0)&255;l=h+(m<<3)|0;n=h+32+(m<<3)|0;o=h+64|0;p=h+72+(r<<1)|0;s=h+80+(r<<1)|0;t=h+88|0;if((q|0)==0){i=k;return}u=c[777680+(f<<2)>>2]|0;v=c[777736+(f<<2)>>2]|0;w=a;x=0;while(1){if((x|0)>=(v|0)){break}mrc(h+90+w|0,q&255|0,u|0)|0;w=w+8|0;x=x+1|0}x=2102960+(f<<3)|0;w=yrc(c[x>>2]|0,c[x+4>>2]|0,a|0)|0;x=n;u=c[x+4>>2]|G;c[x>>2]=c[x>>2]|w;c[x+4>>2]=u;u=s;b[u>>1]=e[u>>1]|0|(e[2102928+(f<<1)>>1]|0)<<g;u=1012496+(f<<3)|0;x=yrc(c[u>>2]|0,c[u+4>>2]|0,a|0)|0;u=l;w=c[u+4>>2]|G;c[u>>2]=c[u>>2]|x;c[u+4>>2]=w;w=p;b[w>>1]=e[w>>1]|0|(e[1012464+(f<<1)>>1]|0)<<g;do{if((d[j+12|0]|0|0)!=0){if(((c[j+20>>2]|0)>0|0)==0){break}i=k;return}}while(0);j=564712+(f<<3)|0;w=2103072+(m<<3)|0;u=yrc(c[j>>2]&c[w>>2]|0,c[j+4>>2]&c[w+4>>2]|0,a|0)|0;w=n;n=c[w+4>>2]|G;c[w>>2]=c[w>>2]|u;c[w+4>>2]=n;n=s;b[n>>1]=e[n>>1]|0|((e[564680+(f<<1)>>1]|0)&(e[2103064+(r<<1)>>1]|0))<<g;n=564712+(f<<3)|0;s=1012704+(m<<3)|0;w=yrc(c[n>>2]&c[s>>2]|0,c[n+4>>2]&c[s+4>>2]|0,a|0)|0;s=l;l=c[s+4>>2]|G;c[s>>2]=c[s>>2]|w;c[s+4>>2]=l;l=p;b[l>>1]=e[l>>1]|0|((e[564680+(f<<1)>>1]|0)&(e[1012696+(r<<1)>>1]|0))<<g;if((m|0)==0){m=564712+(f<<3)|0;l=yrc(c[m>>2]|0,c[m+4>>2]|0,a|0)|0;a=o;o=c[a+4>>2]|G;c[a>>2]=c[a>>2]|l;c[a+4>>2]=o}if((r|0)!=0){i=k;return}r=t;b[r>>1]=e[r>>1]|0|(b[564680+(f<<1)>>1]&65535)<<g;i=k;return}function Cfc(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;h=e;e=f;f=b|0;b=c[f>>2]|0;j=c[f+8>>2]|0;k=(Kfc(a,f)|0)&255;a=e+(j<<3)|0;l=e+32+(j<<3)|0;m=e+64|0;if((k|0)==0){i=g;return}n=c[777680+(b<<2)>>2]|0;o=c[777736+(b<<2)>>2]|0;p=h;q=0;while(1){if((q|0)>=(o|0)){break}mrc(e+90+p|0,k&255|0,n|0)|0;p=p+8|0;q=q+1|0}q=2102960+(b<<3)|0;p=yrc(c[q>>2]|0,c[q+4>>2]|0,h|0)|0;q=l;n=c[q+4>>2]|G;c[q>>2]=c[q>>2]|p;c[q+4>>2]=n;n=1012496+(b<<3)|0;q=yrc(c[n>>2]|0,c[n+4>>2]|0,h|0)|0;n=a;p=c[n+4>>2]|G;c[n>>2]=c[n>>2]|q;c[n+4>>2]=p;do{if((d[f+12|0]|0|0)!=0){if(((c[f+20>>2]|0)>0|0)==0){break}i=g;return}}while(0);f=564712+(b<<3)|0;p=2103072+(j<<3)|0;n=yrc(c[f>>2]&c[p>>2]|0,c[f+4>>2]&c[p+4>>2]|0,h|0)|0;p=l;l=c[p+4>>2]|G;c[p>>2]=c[p>>2]|n;c[p+4>>2]=l;l=564712+(b<<3)|0;p=1012704+(j<<3)|0;n=yrc(c[l>>2]&c[p>>2]|0,c[l+4>>2]&c[p+4>>2]|0,h|0)|0;p=a;a=c[p+4>>2]|G;c[p>>2]=c[p>>2]|n;c[p+4>>2]=a;if((j|0)!=0){i=g;return}j=564712+(b<<3)|0;b=yrc(c[j>>2]|0,c[j+4>>2]|0,h|0)|0;h=m;m=c[h+4>>2]|G;c[h>>2]=c[h>>2]|b;c[h+4>>2]=m;i=g;return}function Dfc(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+32|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=d;d=e;e=f;f=g;g=d+16|0;o=c[g>>2]|0;if((c[d+4>>2]|0)==0){p=f+16|0;q=c[p+4>>2]|0;c[j>>2]=c[p>>2];c[j+4>>2]=q;q=f+8|0;p=c[q+4>>2]|0;c[k>>2]=c[q>>2];c[k+4>>2]=p;p=f|0;q=c[p+4>>2]|0;c[l>>2]=c[p>>2];c[l+4>>2]=q;q=f+64|0;p=c[q+4>>2]|0;c[m>>2]=c[q>>2];c[m+4>>2]=p;r=0;while(1){if((r|0)<8){s=(e+r|0)<(c[n+10148>>2]|0)}else{s=0}if(!s){break}Efc(c[d+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0,c[j>>2]&65535,c[k>>2]&65535,c[l>>2]&65535,c[m>>2]&65535,n+10224|0,f+90+(r<<3)|0);p=g|0;c[p>>2]=(c[p>>2]|0)+(c[g+4>>2]<<4);p=c[j+4>>2]|0;c[j>>2]=(c[j>>2]|0)>>>16|p<<16;c[j+4>>2]=p>>>16|0<<16;p=c[k+4>>2]|0;c[k>>2]=(c[k>>2]|0)>>>16|p<<16;c[k+4>>2]=p>>>16|0<<16;p=c[l+4>>2]|0;c[l>>2]=(c[l>>2]|0)>>>16|p<<16;c[l+4>>2]=p>>>16|0<<16;p=c[m+4>>2]|0;c[m>>2]=(c[m>>2]|0)>>>16|p<<16;c[m+4>>2]=p>>>16|0<<16;r=r+2|0}c[g>>2]=o;s=f+48|0;p=c[s+4>>2]|0;c[j>>2]=c[s>>2];c[j+4>>2]=p;p=f+40|0;s=c[p+4>>2]|0;c[k>>2]=c[p>>2];c[k+4>>2]=s;s=f+32|0;p=c[s+4>>2]|0;c[l>>2]=c[s>>2];c[l+4>>2]=p;p=f+64|0;s=c[p+4>>2]|0;c[m>>2]=c[p>>2];c[m+4>>2]=s;r=0;while(1){if((r|0)<8){t=(e+r|0)<(c[n+10148>>2]|0)}else{t=0}if(!t){break}if((e+r|0)==0){u=0;v=0;w=0}else{u=c[j>>2]&255;v=c[k>>2]&255;w=c[l>>2]&255}Ffc(c[g>>2]|0,c[g+4>>2]|0,u,v,w,c[m>>2]&255,n+10224|0,f+90+(r<<3)|0);s=g|0;c[s>>2]=(c[s>>2]|0)+(c[g+4>>2]<<3);s=c[j+4>>2]|0;c[j>>2]=(c[j>>2]|0)>>>8|s<<24;c[j+4>>2]=s>>>8|0<<24;s=c[k+4>>2]|0;c[k>>2]=(c[k>>2]|0)>>>8|s<<24;c[k+4>>2]=s>>>8|0<<24;s=c[l+4>>2]|0;c[l>>2]=(c[l>>2]|0)>>>8|s<<24;c[l+4>>2]=s>>>8|0<<24;s=c[m+4>>2]|0;c[m>>2]=(c[m>>2]|0)>>>8|s<<24;c[m+4>>2]=s>>>8|0<<24;r=r+1|0}i=h;return}m=b[f+76>>1]|0;l=b[f+74>>1]|0;k=b[f+72>>1]|0;j=b[f+88>>1]|0;r=0;while(1){if((r|0)<8){x=(e+r|0)<(c[n+10148>>2]|0)}else{x=0}if(!x){break}if((c[d+4>>2]|0)==1){w=0;while(1){if((w|0)>=4){break}a[f+154+((r<<1)+w)|0]=a[f+90+((r<<3)+(w<<1))|0]|0;a[f+154+((r+2<<1)+w)|0]=a[f+90+((r+2<<3)+(w<<1))|0]|0;w=w+1|0}}Efc(c[d+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0,m&255,l&255,k&255,j&255,n+10224|0,f+154+(r<<1)|0);w=g|0;c[w>>2]=(c[w>>2]|0)+(c[g+4>>2]<<4);m=(m&65535)>>8&65535;l=(l&65535)>>8&65535;k=(k&65535)>>8&65535;j=(j&65535)>>8&65535;r=r+4|0}c[g>>2]=o;m=b[f+84>>1]|0;l=b[f+82>>1]|0;k=b[f+80>>1]|0;j=b[f+88>>1]|0;r=0;while(1){if((r|0)<8){y=(e+r|0)<(c[n+10148>>2]|0)}else{y=0}if(!y){break}if(((e+r|0)==((c[n+10148>>2]|0)-1|0)|0)!=0){z=0}else{z=j&15}if((e+r|0)==0){A=0;B=0;C=0}else{A=m&15;B=l&15;C=k&15}Ffc(c[g>>2]|0,c[g+4>>2]|0,A,B,C,z,n+10224|0,f+154+(r<<1)|0);o=g|0;c[o>>2]=(c[o>>2]|0)+(c[g+4>>2]<<3);m=(m&65535)>>4&65535;l=(l&65535)>>4&65535;k=(k&65535)>>4&65535;j=(j&65535)>>4&65535;r=r+2|0}i=h;return}function Efc(a,b,c,e,f,g,h,j,k){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=i;m=a;a=b;b=c;c=e;e=f;f=g;g=h;h=j;j=k;k=(m|0)!=0?4:8;n=(m|0)!=0?15:255;o=(m|0)!=0?4:8;m=c&n;p=e&n;q=f&n;r=g&n;s=c>>>(k>>>0)&n;c=e>>>(k>>>0)&n;e=f>>>(k>>>0)&n;f=g>>>(k>>>0)&n;n=m|p|q|r|s|c|e|f;while(1){if((n|0)==0){break}k=h+((d[j]|0)*48|0)|0;g=h+((d[j+o|0]|0)*48|0)|0;if((n&1|0)!=0){if(((m|s)&1|0)!=0){if((m&s&1|0)!=0){Xfc(a,b,k|0,k+16|0,k+32|0)}else{if((m&1|0)!=0){Vfc(a,b,k|0,k+16|0,k+32|0)}else{Vfc(a+(b<<3)|0,b,g|0,g+16|0,g+32|0)}}}if(((p|c)&1|0)!=0){if((p&c&1|0)!=0){Tfc(a,b,k|0,k+16|0,k+32|0,g|0,g+16|0,g+32|0)}else{if((p&1|0)!=0){Sfc(a,b,k|0,k+16|0,k+32|0,1)}else{Sfc(a+(b<<3)|0,b,g|0,g+16|0,g+32|0,1)}}}if(((q|e)&1|0)!=0){if((q&e&1|0)!=0){Pfc(a,b,k|0,k+16|0,k+32|0,g|0,g+16|0,g+32|0)}else{if((q&1|0)!=0){Ofc(a,b,k|0,k+16|0,k+32|0,1)}else{Ofc(a+(b<<3)|0,b,g|0,g+16|0,g+32|0,1)}}}if(((r|f)&1|0)!=0){if((r&f&1|0)!=0){Pfc(a+4|0,b,k|0,k+16|0,k+32|0,g|0,g+16|0,g+32|0)}else{if((r&1|0)!=0){Ofc(a+4|0,b,k|0,k+16|0,k+32|0,1)}else{Ofc(a+(b<<3)+4|0,b,g|0,g+16|0,g+32|0,1)}}}}a=a+8|0;j=j+1|0;m=m>>>1;p=p>>>1;q=q>>>1;r=r>>>1;s=s>>>1;c=c>>>1;e=e>>>1;f=f>>>1;n=n>>>1}i=l;return}function Ffc(a,b,c,e,f,g,h,j){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0;k=i;l=a;a=b;b=c;c=e;e=f;f=g;g=h;h=j;j=b|c|e|f;while(1){if((j|0)==0){break}m=g+((d[h]|0)*48|0)|0;n=1;if((j&1|0)!=0){if((b&1|0)!=0){if((b&3|0)==3){Ufc(l,a,m|0,m+16|0,m+32|0,2);n=2}else{Ufc(l,a,m|0,m+16|0,m+32|0,1)}}else{if((c&1|0)!=0){if((c&3|0)==3){o=g+((d[h+1|0]|0)*48|0)|0;Rfc(l,a,m|0,m+16|0,m+32|0,o|0,o+16|0,o+32|0);if((f&3|0)==3){Nfc(l+(a<<2)|0,a,m|0,m+16|0,m+32|0,o|0,o+16|0,o+32|0)}else{if((f&1|0)!=0){Mfc(l+(a<<2)|0,a,m|0,m+16|0,m+32|0,1)}else{if((f&2|0)!=0){Mfc(l+8+(a<<2)|0,a,o|0,o+16|0,o+32|0,1)}}}n=2}else{Qfc(l,a,m|0,m+16|0,m+32|0,1);if((f&1|0)!=0){Mfc(l+(a<<2)|0,a,m|0,m+16|0,m+32|0,1)}}}else{if((e&1|0)!=0){if((e&3|0)==3){o=g+((d[h+1|0]|0)*48|0)|0;Nfc(l,a,m|0,m+16|0,m+32|0,o|0,o+16|0,o+32|0);if((f&3|0)==3){Nfc(l+(a<<2)|0,a,m|0,m+16|0,m+32|0,o|0,o+16|0,o+32|0)}else{if((f&1|0)!=0){Mfc(l+(a<<2)|0,a,m|0,m+16|0,m+32|0,1)}else{if((f&2|0)!=0){Mfc(l+8+(a<<2)|0,a,o|0,o+16|0,o+32|0,1)}}}n=2}else{Mfc(l,a,m|0,m+16|0,m+32|0,1);if((f&1|0)!=0){Mfc(l+(a<<2)|0,a,m|0,m+16|0,m+32|0,1)}}}else{if((f&1|0)!=0){Mfc(l+(a<<2)|0,a,m|0,m+16|0,m+32|0,1)}}}}}l=l+(n<<3)|0;h=h+n|0;b=b>>>(n>>>0);c=c>>>(n>>>0);e=e>>>(n>>>0);f=f>>>(n>>>0);j=j>>>(n>>>0)}i=k;return}function Gfc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;i=i+176|0;j=h|0;k=a;a=b;b=d;d=e;e=f;f=g;g=(f|0)!=0?1:3;if((f|0)!=0){l=1}else{if((c[b+64>>2]|0)==1){m=(c[b+60>>2]|0)==1}else{m=0}l=m}m=l&1;l=d;while(1){if((l|0)>=(e|0)){break}d=(c[a+10204>>2]|0)+((ca(l,c[a+10160>>2]|0)|0)<<2)|0;f=0;while(1){if((f|0)>=(c[a+10156>>2]|0)){break}zgc(b,k,l,f);if((m|0)!=0){Afc(a,l,f,d+(f<<2)|0,c[a+10160>>2]|0,j)}n=0;while(1){if((n|0)>=(g|0)){break}if((m|0)!=0){Dfc(a,b+(n*52|0)|0,l,j)}else{Hfc(a,b+(n*52|0)|0,d+(f<<2)|0,l,f)}n=n+1|0}f=f+8|0}l=l+8|0}i=h;return}function Hfc(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;j=i;i=i+192|0;k=j|0;l=j+32|0;m=j+64|0;n=j+96|0;o=j+128|0;p=b;b=e;e=f;f=g;g=h;h=c[b+8>>2]|0;q=c[b+12>>2]|0;r=1<<h;s=1<<q;t=ca(c[p+10160>>2]|0,r)|0;u=b+16|0;v=c[u>>2]|0;mrc(k|0,0,32)|0;mrc(l|0,0,32)|0;mrc(m|0,0,32)|0;mrc(n|0,0,32)|0;w=0;while(1){if((w|0)<8){x=(f+w|0)<(c[p+10148>>2]|0)}else{x=0}if(!x){break}y=0;z=0;A=0;B=0;while(1){if((B|0)<8){C=(g+B|0)<(c[p+10156>>2]|0)}else{C=0}if(!C){break}D=c[e+(B<<2)>>2]|0;E=c[D>>2]|0;if((d[D+12|0]|0|0)!=0){F=((c[D+20>>2]|0)>0|0)!=0}else{F=0}G=F&1;if((c[777792+(E<<2)>>2]|0)>1){H=((B&(c[777680+(E<<2)>>2]|0)-1|0)!=0^1)&1}else{H=1}if((G|0)!=0){I=(H|0)!=0^1}else{I=0}J=I&1;if((c[777848+(E<<2)>>2]|0)>1){K=((w&(c[777736+(E<<2)>>2]|0)-1|0)!=0^1)&1}else{K=1}if((G|0)!=0){L=(K|0)!=0^1}else{L=0}E=L&1;if((c[b+4>>2]|0)==1){M=D|0;N=c[M+8>>2]|0;O=c[M>>2]|0;if(O>>>0<3>>>0){P=0}else{M=c[558436+(O<<4)>>2]|0;if(N>>>0<(c[833024+(M<<2)>>2]|0)>>>0){Q=N}else{Q=c[833024+(M<<2)>>2]|0}P=Q}R=P}else{R=c[D+8>>2]|0}M=R;if((h|0)!=0){S=(g+B|0)==((c[p+10156>>2]|0)-1|0)}else{S=0}N=S&1;if((q|0)!=0){T=(f+w|0)==((c[p+10148>>2]|0)-1|0)}else{T=0}O=T&1;U=Kfc(p+10224|0,D|0)|0;a[o+((w<<3)+(B>>h))|0]=U;if(U<<24>>24!=0){if((M|0)==3){do{if((J|0)==0){if((B>>h&3|0)!=0){break}if((N|0)!=0){z=z|1<<(B>>h)}else{y=y|1<<(B>>h)}}}while(0);do{if((E|0)==0){if((w>>q&3|0)!=0){break}if((O|0)!=0){U=l+(w<<2)|0;c[U>>2]=c[U>>2]|1<<(B>>h)}else{U=k+(w<<2)|0;c[U>>2]=c[U>>2]|1<<(B>>h)}}}while(0)}else{if((M|0)==2){do{if((J|0)==0){if((B>>h&1|0)!=0){break}if((N|0)!=0){z=z|1<<(B>>h)}else{y=y|1<<(B>>h)}}}while(0);do{if((E|0)==0){if((w>>q&1|0)!=0){break}if((O|0)!=0){U=l+(w<<2)|0;c[U>>2]=c[U>>2]|1<<(B>>h)}else{U=k+(w<<2)|0;c[U>>2]=c[U>>2]|1<<(B>>h)}}}while(0)}else{if((J|0)==0){do{if((M|0)==1){V=67}else{if((B>>h&3|0)==0){V=67;break}A=A|1<<(B>>h)}}while(0);if((V|0)==67){V=0;z=z|1<<(B>>h)}}if((E|0)==0){do{if((M|0)==1){V=73}else{if((w>>q&3|0)==0){V=73;break}J=m+(w<<2)|0;c[J>>2]=c[J>>2]|1<<(B>>h)}}while(0);if((V|0)==73){V=0;E=l+(w<<2)|0;c[E>>2]=c[E>>2]|1<<(B>>h)}}do{if((G|0)==0){if(!(M>>>0<1>>>0)){break}if((N|0)!=0){break}E=n+(w<<2)|0;c[E>>2]=c[E>>2]|1<<(B>>h)}}while(0)}}}B=B+s|0}B=~((g|0)==0);Lfc(c[u>>2]|0,c[u+4>>2]|0,y&B,z&B,A&B,c[n+(w<<2)>>2]|0,p+10224|0,o+(w<<3)|0);B=u|0;c[B>>2]=(c[B>>2]|0)+(c[u+4>>2]<<3);e=e+(t<<2)|0;w=w+r|0}c[u>>2]=v;w=0;while(1){if((w|0)<8){W=(f+w|0)<(c[p+10148>>2]|0)}else{W=0}if(!W){break}if((q|0)!=0){X=(f+w|0)==((c[p+10148>>2]|0)-1|0)}else{X=0}if((X&1|0)!=0){Y=0}else{Y=c[n+(w<<2)>>2]|0}if((f+w|0)==0){Z=0;_=0;$=0}else{Z=c[k+(w<<2)>>2]|0;_=c[l+(w<<2)>>2]|0;$=c[m+(w<<2)>>2]|0}Ffc(c[u>>2]|0,c[u+4>>2]|0,Z,_,$,Y,p+10224|0,o+(w<<3)|0);v=u|0;c[v>>2]=(c[v>>2]|0)+(c[u+4>>2]<<3);w=w+r|0}i=j;return}function Ifc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=b;b=d;d=e;if((b|0)==0){i=g;return}e=0;j=c[h+10148>>2]|0;do{if((f|0)!=0){if((c[h+10148>>2]|0)<=8){break}e=c[h+10148>>2]>>1;e=e&-8;if(((c[h+10148>>2]|0)/8|0|0)>8){k=(c[h+10148>>2]|0)/8|0}else{k=8}j=k}}while(0);zfc(h,b);Gfc(c[h+8484>>2]|0,h,a,e,e+j|0,d);i=g;return}function Jfc(a,b){a=a|0;b=b|0;var d=0;b=i;d=a;Gfc(c[d>>2]|0,c[d+4>>2]|0,d+16|0,c[d+50496>>2]|0,c[d+50500>>2]|0,c[d+50504>>2]|0);i=b;return 1}function Kfc(b,e){b=b|0;e=e|0;var f=0;f=e;i=i;return a[b+3072+((d[f+13|0]|0)<<3)+(c[f+20>>2]<<1)+(c[828920+(c[f+4>>2]<<2)>>2]|0)|0]|0}function Lfc(a,b,c,e,f,g,h,j){a=a|0;b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0;k=i;l=a;a=b;b=c;c=e;e=f;f=g;g=h;h=j;j=b|c|e|f;while(1){if((j|0)==0){break}m=g+((d[h]|0)*48|0)|0;if((j&1|0)!=0){if((b&1|0)!=0){Vfc(l,a,m|0,m+16|0,m+32|0)}else{if((c&1|0)!=0){Sfc(l,a,m|0,m+16|0,m+32|0,1)}else{if((e&1|0)!=0){Ofc(l,a,m|0,m+16|0,m+32|0,1)}}}}if((f&1|0)!=0){Ofc(l+4|0,a,m|0,m+16|0,m+32|0,1)}l=l+8|0;h=h+1|0;b=b>>>1;c=c>>>1;e=e>>>1;f=f>>>1;j=j>>>1}i=k;return}function Mfc(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=i;k=b;b=c;c=e;e=f;f=g;g=h;h=0;while(1){if((h|0)>=(g<<3|0)){break}l=a[e]|0;m=a[k+(b*-3|0)|0]|0;n=a[k+(b*-2|0)|0]|0;o=a[k+(-b|0)|0]|0;p=a[k+0|0]|0;q=a[k+b|0]|0;r=a[k+(b<<1)|0]|0;s=0;s=(s<<24>>24|(((R((d[k+(b*-4|0)|0]|0)-(m&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((m&255)-(n&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((n&255)-(o&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((q&255)-(p&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((r&255)-(q&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((d[k+(b*3|0)|0]|0)-(r&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((((R((o&255)-(p&255)|0)|0)<<1)+((R((n&255)-(q&255)|0)|0)/2|0)|0)>(d[c]|0)|0)*-1|0))&255;q=~(s<<24>>24)&255;s=k+(-(b<<1)|0)|0;n=k+(-b|0)|0;p=k;o=k+b|0;l=(a[s]^128)&255;r=(a[n]^128)&255;m=(a[p]^128)&255;t=(a[o]^128)&255;u=a[f]|0;v=0;v=(v<<24>>24|(((R((d[s]|0)-(d[n]|0)|0)|0)>(u&255|0)|0)*-1|0))&255;v=(v<<24>>24|(((R((d[o]|0)-(d[p]|0)|0)|0)>(u&255|0)|0)*-1|0))&255;u=v;v=(l<<24>>24)-(t<<24>>24)|0;w=-128;x=127;if((v|0)<(w|0)){y=w}else{if((v|0)>(x|0)){z=x}else{z=v}y=z}v=(y&255)<<24>>24&(u&255)&255;x=(v<<24>>24)+(((m<<24>>24)-(r<<24>>24)|0)*3|0)|0;w=-128;A=127;if((x|0)<(w|0)){B=w}else{if((x|0)>(A|0)){C=A}else{C=x}B=C}v=(B&255)<<24>>24&q<<24>>24&255;q=(v<<24>>24)+4|0;x=-128;A=127;if((q|0)<(x|0)){D=x}else{if((q|0)>(A|0)){E=A}else{E=q}D=E}q=(D&255)<<24>>24>>3&255;A=(v<<24>>24)+3|0;x=-128;w=127;if((A|0)<(x|0)){F=x}else{if((A|0)>(w|0)){G=w}else{G=A}F=G}A=(F&255)<<24>>24>>3&255;w=(m<<24>>24)-(q<<24>>24)|0;m=-128;x=127;if((w|0)<(m|0)){H=m}else{if((w|0)>(x|0)){I=x}else{I=w}H=I}a[p]=(H&255)<<24>>24^128;p=(r<<24>>24)+(A<<24>>24)|0;A=-128;r=127;if((p|0)<(A|0)){J=A}else{if((p|0)>(r|0)){K=r}else{K=p}J=K}a[n]=(J&255)<<24>>24^128;v=(q<<24>>24)+1>>1&~(u&255)&255;u=(t<<24>>24)-(v<<24>>24)|0;t=-128;q=127;if((u|0)<(t|0)){L=t}else{if((u|0)>(q|0)){M=q}else{M=u}L=M}a[o]=(L&255)<<24>>24^128;o=(l<<24>>24)+(v<<24>>24)|0;v=-128;l=127;if((o|0)<(v|0)){N=v}else{if((o|0)>(l|0)){O=l}else{O=o}N=O}a[s]=(N&255)<<24>>24^128;k=k+1|0;h=h+1|0}i=j;return}function Nfc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=a;a=b;Mfc(k,a,c,d,e,1);Mfc(k+8|0,a,f,g,h,1);i=j;return}function Ofc(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=i;k=b;b=c;c=e;e=f;f=g;g=h;h=0;while(1){if((h|0)>=(g<<3|0)){break}l=a[e]|0;m=a[k-3|0]|0;n=a[k-2|0]|0;o=a[k-1|0]|0;p=a[k|0]|0;q=a[k+1|0]|0;r=a[k+2|0]|0;s=0;s=(s<<24>>24|(((R((d[k-4|0]|0)-(m&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((m&255)-(n&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((n&255)-(o&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((q&255)-(p&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((r&255)-(q&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((R((d[k+3|0]|0)-(r&255)|0)|0)>(l&255|0)|0)*-1|0))&255;s=(s<<24>>24|(((((R((o&255)-(p&255)|0)|0)<<1)+((R((n&255)-(q&255)|0)|0)/2|0)|0)>(d[c]|0)|0)*-1|0))&255;q=~(s<<24>>24)&255;s=k-2|0;n=k-1|0;p=k;o=k+1|0;l=(a[s]^128)&255;r=(a[n]^128)&255;m=(a[p]^128)&255;t=(a[o]^128)&255;u=a[f]|0;v=0;v=(v<<24>>24|(((R((d[s]|0)-(d[n]|0)|0)|0)>(u&255|0)|0)*-1|0))&255;v=(v<<24>>24|(((R((d[o]|0)-(d[p]|0)|0)|0)>(u&255|0)|0)*-1|0))&255;u=v;v=(l<<24>>24)-(t<<24>>24)|0;w=-128;x=127;if((v|0)<(w|0)){y=w}else{if((v|0)>(x|0)){z=x}else{z=v}y=z}v=(y&255)<<24>>24&(u&255)&255;x=(v<<24>>24)+(((m<<24>>24)-(r<<24>>24)|0)*3|0)|0;w=-128;A=127;if((x|0)<(w|0)){B=w}else{if((x|0)>(A|0)){C=A}else{C=x}B=C}v=(B&255)<<24>>24&q<<24>>24&255;q=(v<<24>>24)+4|0;x=-128;A=127;if((q|0)<(x|0)){D=x}else{if((q|0)>(A|0)){E=A}else{E=q}D=E}q=(D&255)<<24>>24>>3&255;A=(v<<24>>24)+3|0;x=-128;w=127;if((A|0)<(x|0)){F=x}else{if((A|0)>(w|0)){G=w}else{G=A}F=G}A=(F&255)<<24>>24>>3&255;w=(m<<24>>24)-(q<<24>>24)|0;m=-128;x=127;if((w|0)<(m|0)){H=m}else{if((w|0)>(x|0)){I=x}else{I=w}H=I}a[p]=(H&255)<<24>>24^128;p=(r<<24>>24)+(A<<24>>24)|0;A=-128;r=127;if((p|0)<(A|0)){J=A}else{if((p|0)>(r|0)){K=r}else{K=p}J=K}a[n]=(J&255)<<24>>24^128;v=(q<<24>>24)+1>>1&~(u&255)&255;u=(t<<24>>24)-(v<<24>>24)|0;t=-128;q=127;if((u|0)<(t|0)){L=t}else{if((u|0)>(q|0)){M=q}else{M=u}L=M}a[o]=(L&255)<<24>>24^128;o=(l<<24>>24)+(v<<24>>24)|0;v=-128;l=127;if((o|0)<(v|0)){N=v}else{if((o|0)>(l|0)){O=l}else{O=o}N=O}a[s]=(N&255)<<24>>24^128;k=k+b|0;h=h+1|0}i=j;return}function Pfc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=a;a=b;Ofc(k,a,c,d,e,1);Ofc(k+(a<<3)|0,a,f,g,h,1);i=j;return}function Qfc(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0;j=i;k=b;b=c;c=e;e=f;f=g;g=h;h=0;while(1){if((h|0)>=(g<<3|0)){break}l=a[k+(b*-4|0)|0]|0;m=a[k+(b*-3|0)|0]|0;n=a[k+(b*-2|0)|0]|0;o=a[k+(-b|0)|0]|0;p=a[k+0|0]|0;q=a[k+b|0]|0;r=a[k+(b<<1)|0]|0;s=a[k+(b*3|0)|0]|0;t=a[e]|0;u=m;v=n;w=o;x=p;y=q;z=r;A=0;A=(A<<24>>24|(((R((l&255)-(u&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((u&255)-(v&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((v&255)-(w&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((y&255)-(x&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((z&255)-(y&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((s&255)-(z&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((((R((w&255)-(x&255)|0)|0)<<1)+((R((v&255)-(y&255)|0)|0)/2|0)|0)>(d[c]|0)|0)*-1|0))&255;y=1;v=o;o=p;p=0;p=(p<<24>>24|(((R((n&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((q&255)-(o&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((m&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((r&255)-(o&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((l&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((s&255)-(o&255)|0)|0)>(y&255|0)|0)*-1|0))&255;y=~(A<<24>>24)&255;A=a[f]|0;o=k+(-(b<<2)|0)|0;s=k+(-(b*3|0)|0)|0;v=k+(-(b<<1)|0)|0;l=k+(-b|0)|0;r=k;m=k+b|0;q=k+(b<<1)|0;n=k+(b*3|0)|0;do{if((~(p<<24>>24)&255|0)!=0){if((y<<24>>24|0)==0){B=6;break}x=a[o]|0;w=a[s]|0;t=a[v]|0;z=a[l]|0;u=a[r]|0;C=a[m]|0;D=a[q]|0;E=a[n]|0;a[s]=(x&255)+(x&255)+(x&255)+((w&255)<<1)+(t&255)+(z&255)+(u&255)+4>>3;a[v]=(x&255)+(x&255)+(w&255)+((t&255)<<1)+(z&255)+(u&255)+(C&255)+4>>3;a[l]=(x&255)+(w&255)+(t&255)+((z&255)<<1)+(u&255)+(C&255)+(D&255)+4>>3;a[r]=(w&255)+(t&255)+(z&255)+((u&255)<<1)+(C&255)+(D&255)+(E&255)+4>>3;a[m]=(t&255)+(z&255)+(u&255)+((C&255)<<1)+(D&255)+(E&255)+(E&255)+4>>3;a[q]=(z&255)+(u&255)+(C&255)+((D&255)<<1)+(E&255)+(E&255)+(E&255)+4>>3}else{B=6}}while(0);if((B|0)==6){B=0;q=y;s=v;n=l;o=r;p=m;E=(a[s]^128)&255;D=(a[n]^128)&255;C=(a[o]^128)&255;u=(a[p]^128)&255;z=A;t=0;t=(t<<24>>24|(((R((d[s]|0)-(d[n]|0)|0)|0)>(z&255|0)|0)*-1|0))&255;t=(t<<24>>24|(((R((d[p]|0)-(d[o]|0)|0)|0)>(z&255|0)|0)*-1|0))&255;z=t;t=(E<<24>>24)-(u<<24>>24)|0;w=-128;x=127;if((t|0)<(w|0)){F=w}else{if((t|0)>(x|0)){G=x}else{G=t}F=G}t=(F&255)<<24>>24&(z&255)&255;x=(t<<24>>24)+(((C<<24>>24)-(D<<24>>24)|0)*3|0)|0;w=-128;H=127;if((x|0)<(w|0)){I=w}else{if((x|0)>(H|0)){J=H}else{J=x}I=J}t=(I&255)<<24>>24&q<<24>>24&255;q=(t<<24>>24)+4|0;x=-128;H=127;if((q|0)<(x|0)){K=x}else{if((q|0)>(H|0)){L=H}else{L=q}K=L}q=(K&255)<<24>>24>>3&255;H=(t<<24>>24)+3|0;x=-128;w=127;if((H|0)<(x|0)){M=x}else{if((H|0)>(w|0)){N=w}else{N=H}M=N}H=(M&255)<<24>>24>>3&255;w=(C<<24>>24)-(q<<24>>24)|0;C=-128;x=127;if((w|0)<(C|0)){O=C}else{if((w|0)>(x|0)){P=x}else{P=w}O=P}a[o]=(O&255)<<24>>24^128;o=(D<<24>>24)+(H<<24>>24)|0;H=-128;D=127;if((o|0)<(H|0)){Q=H}else{if((o|0)>(D|0)){S=D}else{S=o}Q=S}a[n]=(Q&255)<<24>>24^128;t=(q<<24>>24)+1>>1&~(z&255)&255;z=(u<<24>>24)-(t<<24>>24)|0;u=-128;q=127;if((z|0)<(u|0)){T=u}else{if((z|0)>(q|0)){U=q}else{U=z}T=U}a[p]=(T&255)<<24>>24^128;p=(E<<24>>24)+(t<<24>>24)|0;t=-128;E=127;if((p|0)<(t|0)){V=t}else{if((p|0)>(E|0)){W=E}else{W=p}V=W}a[s]=(V&255)<<24>>24^128}k=k+1|0;h=h+1|0}i=j;return}function Rfc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=a;a=b;Qfc(k,a,c,d,e,1);Qfc(k+8|0,a,f,g,h,1);i=j;return}function Sfc(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0;j=i;k=b;b=c;c=e;e=f;f=g;g=h;h=0;while(1){if((h|0)>=(g<<3|0)){break}l=a[k-4|0]|0;m=a[k-3|0]|0;n=a[k-2|0]|0;o=a[k-1|0]|0;p=a[k|0]|0;q=a[k+1|0]|0;r=a[k+2|0]|0;s=a[k+3|0]|0;t=a[e]|0;u=m;v=n;w=o;x=p;y=q;z=r;A=0;A=(A<<24>>24|(((R((l&255)-(u&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((u&255)-(v&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((v&255)-(w&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((y&255)-(x&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((z&255)-(y&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((s&255)-(z&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((((R((w&255)-(x&255)|0)|0)<<1)+((R((v&255)-(y&255)|0)|0)/2|0)|0)>(d[c]|0)|0)*-1|0))&255;y=1;v=o;o=p;p=0;p=(p<<24>>24|(((R((n&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((q&255)-(o&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((m&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((r&255)-(o&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((l&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((s&255)-(o&255)|0)|0)>(y&255|0)|0)*-1|0))&255;y=~(A<<24>>24)&255;A=a[f]|0;o=k-4|0;s=k-3|0;v=k-2|0;l=k-1|0;r=k;m=k+1|0;q=k+2|0;n=k+3|0;do{if((~(p<<24>>24)&255|0)!=0){if((y<<24>>24|0)==0){B=6;break}x=a[o]|0;w=a[s]|0;t=a[v]|0;z=a[l]|0;u=a[r]|0;C=a[m]|0;D=a[q]|0;E=a[n]|0;a[s]=(x&255)+(x&255)+(x&255)+((w&255)<<1)+(t&255)+(z&255)+(u&255)+4>>3;a[v]=(x&255)+(x&255)+(w&255)+((t&255)<<1)+(z&255)+(u&255)+(C&255)+4>>3;a[l]=(x&255)+(w&255)+(t&255)+((z&255)<<1)+(u&255)+(C&255)+(D&255)+4>>3;a[r]=(w&255)+(t&255)+(z&255)+((u&255)<<1)+(C&255)+(D&255)+(E&255)+4>>3;a[m]=(t&255)+(z&255)+(u&255)+((C&255)<<1)+(D&255)+(E&255)+(E&255)+4>>3;a[q]=(z&255)+(u&255)+(C&255)+((D&255)<<1)+(E&255)+(E&255)+(E&255)+4>>3}else{B=6}}while(0);if((B|0)==6){B=0;q=y;s=v;n=l;o=r;p=m;E=(a[s]^128)&255;D=(a[n]^128)&255;C=(a[o]^128)&255;u=(a[p]^128)&255;z=A;t=0;t=(t<<24>>24|(((R((d[s]|0)-(d[n]|0)|0)|0)>(z&255|0)|0)*-1|0))&255;t=(t<<24>>24|(((R((d[p]|0)-(d[o]|0)|0)|0)>(z&255|0)|0)*-1|0))&255;z=t;t=(E<<24>>24)-(u<<24>>24)|0;w=-128;x=127;if((t|0)<(w|0)){F=w}else{if((t|0)>(x|0)){G=x}else{G=t}F=G}t=(F&255)<<24>>24&(z&255)&255;x=(t<<24>>24)+(((C<<24>>24)-(D<<24>>24)|0)*3|0)|0;w=-128;H=127;if((x|0)<(w|0)){I=w}else{if((x|0)>(H|0)){J=H}else{J=x}I=J}t=(I&255)<<24>>24&q<<24>>24&255;q=(t<<24>>24)+4|0;x=-128;H=127;if((q|0)<(x|0)){K=x}else{if((q|0)>(H|0)){L=H}else{L=q}K=L}q=(K&255)<<24>>24>>3&255;H=(t<<24>>24)+3|0;x=-128;w=127;if((H|0)<(x|0)){M=x}else{if((H|0)>(w|0)){N=w}else{N=H}M=N}H=(M&255)<<24>>24>>3&255;w=(C<<24>>24)-(q<<24>>24)|0;C=-128;x=127;if((w|0)<(C|0)){O=C}else{if((w|0)>(x|0)){P=x}else{P=w}O=P}a[o]=(O&255)<<24>>24^128;o=(D<<24>>24)+(H<<24>>24)|0;H=-128;D=127;if((o|0)<(H|0)){Q=H}else{if((o|0)>(D|0)){S=D}else{S=o}Q=S}a[n]=(Q&255)<<24>>24^128;t=(q<<24>>24)+1>>1&~(z&255)&255;z=(u<<24>>24)-(t<<24>>24)|0;u=-128;q=127;if((z|0)<(u|0)){T=u}else{if((z|0)>(q|0)){U=q}else{U=z}T=U}a[p]=(T&255)<<24>>24^128;p=(E<<24>>24)+(t<<24>>24)|0;t=-128;E=127;if((p|0)<(t|0)){V=t}else{if((p|0)>(E|0)){W=E}else{W=p}V=W}a[s]=(V&255)<<24>>24^128}k=k+b|0;h=h+1|0}i=j;return}function Tfc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=a;a=b;Sfc(k,a,c,d,e,1);Sfc(k+(a<<3)|0,a,f,g,h,1);i=j;return}function Ufc(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;j=i;k=b;b=c;c=e;e=f;f=g;g=h;h=0;while(1){if((h|0)>=(g<<3|0)){break}l=a[k+(b*-4|0)|0]|0;m=a[k+(b*-3|0)|0]|0;n=a[k+(b*-2|0)|0]|0;o=a[k+(-b|0)|0]|0;p=a[k+0|0]|0;q=a[k+b|0]|0;r=a[k+(b<<1)|0]|0;s=a[k+(b*3|0)|0]|0;t=a[e]|0;u=m;v=n;w=o;x=p;y=q;z=r;A=0;A=(A<<24>>24|(((R((l&255)-(u&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((u&255)-(v&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((v&255)-(w&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((y&255)-(x&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((z&255)-(y&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((s&255)-(z&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((((R((w&255)-(x&255)|0)|0)<<1)+((R((v&255)-(y&255)|0)|0)/2|0)|0)>(d[c]|0)|0)*-1|0))&255;y=1;v=o;x=p;w=0;w=(w<<24>>24|(((R((n&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((q&255)-(x&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((m&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((r&255)-(x&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((l&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((s&255)-(x&255)|0)|0)>(y&255|0)|0)*-1|0))&255;y=1;x=o;o=p;p=y;s=x;v=o;l=0;l=(l<<24>>24|(((R((d[k+(b*-5|0)|0]|0)-(s&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k+(b<<2)|0]|0)-(v&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k+(b*-6|0)|0]|0)-(s&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k+(b*5|0)|0]|0)-(v&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k+(b*-7|0)|0]|0)-(s&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k+(b*6|0)|0]|0)-(v&255)|0)|0)>(p&255|0)|0)*-1|0))&255;p=~((~(l<<24>>24)&255)<<24>>24)&255;p=(p<<24>>24|(((R((d[k+(b*-8|0)|0]|0)-(x&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((d[k+(b*7|0)|0]|0)-(o&255)|0)|0)>(y&255|0)|0)*-1|0))&255;y=~(A<<24>>24)&255;A=a[f]|0;o=~(w<<24>>24)&255;w=k+(-(b<<3)|0)|0;x=k+(-(b*7|0)|0)|0;l=k+(-(b*6|0)|0)|0;v=k+(-(b*5|0)|0)|0;s=k+(-(b<<2)|0)|0;r=k+(-(b*3|0)|0)|0;m=k+(-(b<<1)|0)|0;q=k+(-b|0)|0;n=k;t=k+b|0;z=k+(b<<1)|0;u=k+(b*3|0)|0;B=k+(b<<2)|0;C=k+(b*5|0)|0;D=k+(b*6|0)|0;E=k+(b*7|0)|0;do{if((~(p<<24>>24)&255|0)!=0){if((o&255|0)==0){F=7;break}if((y<<24>>24|0)==0){F=7;break}G=a[w]|0;H=a[x]|0;I=a[l]|0;J=a[v]|0;K=a[s]|0;L=a[r]|0;M=a[m]|0;N=a[q]|0;O=a[n]|0;P=a[t]|0;Q=a[z]|0;S=a[u]|0;T=a[B]|0;U=a[C]|0;V=a[D]|0;W=a[E]|0;a[x]=((G&255)*7|0)+((H&255)<<1)+(I&255)+(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+8>>4;a[l]=((G&255)*6|0)+(H&255)+((I&255)<<1)+(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+8>>4;a[v]=((G&255)*5|0)+(H&255)+(I&255)+((J&255)<<1)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+8>>4;a[s]=((G&255)<<2)+(H&255)+(I&255)+(J&255)+((K&255)<<1)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+8>>4;a[r]=((G&255)*3|0)+(H&255)+(I&255)+(J&255)+(K&255)+((L&255)<<1)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+8>>4;a[m]=((G&255)<<1)+(H&255)+(I&255)+(J&255)+(K&255)+(L&255)+((M&255)<<1)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+(U&255)+8>>4;a[q]=(G&255)+(H&255)+(I&255)+(J&255)+(K&255)+(L&255)+(M&255)+((N&255)<<1)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+(U&255)+(V&255)+8>>4;a[n]=(H&255)+(I&255)+(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+((O&255)<<1)+(P&255)+(Q&255)+(S&255)+(T&255)+(U&255)+(V&255)+(W&255)+8>>4;a[t]=(I&255)+(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+((P&255)<<1)+(Q&255)+(S&255)+(T&255)+(U&255)+(V&255)+((W&255)<<1)+8>>4;a[z]=(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+((Q&255)<<1)+(S&255)+(T&255)+(U&255)+(V&255)+((W&255)*3|0)+8>>4;a[u]=(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+((S&255)<<1)+(T&255)+(U&255)+(V&255)+((W&255)<<2)+8>>4;a[B]=(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+((T&255)<<1)+(U&255)+(V&255)+((W&255)*5|0)+8>>4;a[C]=(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+((U&255)<<1)+(V&255)+((W&255)*6|0)+8>>4;a[D]=(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+(U&255)+((V&255)<<1)+((W&255)*7|0)+8>>4}else{F=7}}while(0);if((F|0)==7){F=0;D=y;C=A;B=s;v=r;l=m;x=q;E=n;w=t;p=z;W=u;do{if((o&255|0)!=0){if((D<<24>>24|0)==0){F=10;break}V=a[B]|0;U=a[v]|0;T=a[l]|0;S=a[x]|0;Q=a[E]|0;P=a[w]|0;O=a[p]|0;N=a[W]|0;a[v]=(V&255)+(V&255)+(V&255)+((U&255)<<1)+(T&255)+(S&255)+(Q&255)+4>>3;a[l]=(V&255)+(V&255)+(U&255)+((T&255)<<1)+(S&255)+(Q&255)+(P&255)+4>>3;a[x]=(V&255)+(U&255)+(T&255)+((S&255)<<1)+(Q&255)+(P&255)+(O&255)+4>>3;a[E]=(U&255)+(T&255)+(S&255)+((Q&255)<<1)+(P&255)+(O&255)+(N&255)+4>>3;a[w]=(T&255)+(S&255)+(Q&255)+((P&255)<<1)+(O&255)+(N&255)+(N&255)+4>>3;a[p]=(S&255)+(Q&255)+(P&255)+((O&255)<<1)+(N&255)+(N&255)+(N&255)+4>>3}else{F=10}}while(0);if((F|0)==10){F=0;p=D;v=l;W=x;B=E;o=w;u=(a[v]^128)&255;z=(a[W]^128)&255;t=(a[B]^128)&255;n=(a[o]^128)&255;q=C;m=0;m=(m<<24>>24|(((R((d[v]|0)-(d[W]|0)|0)|0)>(q&255|0)|0)*-1|0))&255;m=(m<<24>>24|(((R((d[o]|0)-(d[B]|0)|0)|0)>(q&255|0)|0)*-1|0))&255;q=m;m=(u<<24>>24)-(n<<24>>24)|0;r=-128;s=127;if((m|0)<(r|0)){X=r}else{if((m|0)>(s|0)){Y=s}else{Y=m}X=Y}m=(X&255)<<24>>24&(q&255)&255;s=(m<<24>>24)+(((t<<24>>24)-(z<<24>>24)|0)*3|0)|0;r=-128;A=127;if((s|0)<(r|0)){Z=r}else{if((s|0)>(A|0)){_=A}else{_=s}Z=_}m=(Z&255)<<24>>24&p<<24>>24&255;p=(m<<24>>24)+4|0;s=-128;A=127;if((p|0)<(s|0)){$=s}else{if((p|0)>(A|0)){aa=A}else{aa=p}$=aa}p=($&255)<<24>>24>>3&255;A=(m<<24>>24)+3|0;s=-128;r=127;if((A|0)<(s|0)){ba=s}else{if((A|0)>(r|0)){ca=r}else{ca=A}ba=ca}A=(ba&255)<<24>>24>>3&255;r=(t<<24>>24)-(p<<24>>24)|0;t=-128;s=127;if((r|0)<(t|0)){da=t}else{if((r|0)>(s|0)){ea=s}else{ea=r}da=ea}a[B]=(da&255)<<24>>24^128;B=(z<<24>>24)+(A<<24>>24)|0;A=-128;z=127;if((B|0)<(A|0)){fa=A}else{if((B|0)>(z|0)){ga=z}else{ga=B}fa=ga}a[W]=(fa&255)<<24>>24^128;m=(p<<24>>24)+1>>1&~(q&255)&255;q=(n<<24>>24)-(m<<24>>24)|0;n=-128;p=127;if((q|0)<(n|0)){ha=n}else{if((q|0)>(p|0)){ia=p}else{ia=q}ha=ia}a[o]=(ha&255)<<24>>24^128;o=(u<<24>>24)+(m<<24>>24)|0;m=-128;u=127;if((o|0)<(m|0)){ja=m}else{if((o|0)>(u|0)){ka=u}else{ka=o}ja=ka}a[v]=(ja&255)<<24>>24^128}}k=k+1|0;h=h+1|0}i=j;return}function Vfc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=i;Wfc(a,b,c,d,e,8);i=f;return}function Wfc(b,c,e,f,g,h){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;j=i;k=b;b=c;c=e;e=f;f=g;g=h;h=0;while(1){if((h|0)>=(g|0)){break}l=a[k-4|0]|0;m=a[k-3|0]|0;n=a[k-2|0]|0;o=a[k-1|0]|0;p=a[k|0]|0;q=a[k+1|0]|0;r=a[k+2|0]|0;s=a[k+3|0]|0;t=a[e]|0;u=m;v=n;w=o;x=p;y=q;z=r;A=0;A=(A<<24>>24|(((R((l&255)-(u&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((u&255)-(v&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((v&255)-(w&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((y&255)-(x&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((z&255)-(y&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((R((s&255)-(z&255)|0)|0)>(t&255|0)|0)*-1|0))&255;A=(A<<24>>24|(((((R((w&255)-(x&255)|0)|0)<<1)+((R((v&255)-(y&255)|0)|0)/2|0)|0)>(d[c]|0)|0)*-1|0))&255;y=1;v=o;x=p;w=0;w=(w<<24>>24|(((R((n&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((q&255)-(x&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((m&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((r&255)-(x&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((l&255)-(v&255)|0)|0)>(y&255|0)|0)*-1|0))&255;w=(w<<24>>24|(((R((s&255)-(x&255)|0)|0)>(y&255|0)|0)*-1|0))&255;y=1;x=o;o=p;p=y;s=x;v=o;l=0;l=(l<<24>>24|(((R((d[k-5|0]|0)-(s&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k+4|0]|0)-(v&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k-6|0]|0)-(s&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k+5|0]|0)-(v&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k-7|0]|0)-(s&255)|0)|0)>(p&255|0)|0)*-1|0))&255;l=(l<<24>>24|(((R((d[k+6|0]|0)-(v&255)|0)|0)>(p&255|0)|0)*-1|0))&255;p=~((~(l<<24>>24)&255)<<24>>24)&255;p=(p<<24>>24|(((R((d[k-8|0]|0)-(x&255)|0)|0)>(y&255|0)|0)*-1|0))&255;p=(p<<24>>24|(((R((d[k+7|0]|0)-(o&255)|0)|0)>(y&255|0)|0)*-1|0))&255;y=~(A<<24>>24)&255;A=a[f]|0;o=~(w<<24>>24)&255;w=k-8|0;x=k-7|0;l=k-6|0;v=k-5|0;s=k-4|0;r=k-3|0;m=k-2|0;q=k-1|0;n=k;t=k+1|0;z=k+2|0;u=k+3|0;B=k+4|0;C=k+5|0;D=k+6|0;E=k+7|0;do{if((~(p<<24>>24)&255|0)!=0){if((o&255|0)==0){F=7;break}if((y<<24>>24|0)==0){F=7;break}G=a[w]|0;H=a[x]|0;I=a[l]|0;J=a[v]|0;K=a[s]|0;L=a[r]|0;M=a[m]|0;N=a[q]|0;O=a[n]|0;P=a[t]|0;Q=a[z]|0;S=a[u]|0;T=a[B]|0;U=a[C]|0;V=a[D]|0;W=a[E]|0;a[x]=((G&255)*7|0)+((H&255)<<1)+(I&255)+(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+8>>4;a[l]=((G&255)*6|0)+(H&255)+((I&255)<<1)+(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+8>>4;a[v]=((G&255)*5|0)+(H&255)+(I&255)+((J&255)<<1)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+8>>4;a[s]=((G&255)<<2)+(H&255)+(I&255)+(J&255)+((K&255)<<1)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+8>>4;a[r]=((G&255)*3|0)+(H&255)+(I&255)+(J&255)+(K&255)+((L&255)<<1)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+8>>4;a[m]=((G&255)<<1)+(H&255)+(I&255)+(J&255)+(K&255)+(L&255)+((M&255)<<1)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+(U&255)+8>>4;a[q]=(G&255)+(H&255)+(I&255)+(J&255)+(K&255)+(L&255)+(M&255)+((N&255)<<1)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+(U&255)+(V&255)+8>>4;a[n]=(H&255)+(I&255)+(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+((O&255)<<1)+(P&255)+(Q&255)+(S&255)+(T&255)+(U&255)+(V&255)+(W&255)+8>>4;a[t]=(I&255)+(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+((P&255)<<1)+(Q&255)+(S&255)+(T&255)+(U&255)+(V&255)+((W&255)<<1)+8>>4;a[z]=(J&255)+(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+((Q&255)<<1)+(S&255)+(T&255)+(U&255)+(V&255)+((W&255)*3|0)+8>>4;a[u]=(K&255)+(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+((S&255)<<1)+(T&255)+(U&255)+(V&255)+((W&255)<<2)+8>>4;a[B]=(L&255)+(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+((T&255)<<1)+(U&255)+(V&255)+((W&255)*5|0)+8>>4;a[C]=(M&255)+(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+((U&255)<<1)+(V&255)+((W&255)*6|0)+8>>4;a[D]=(N&255)+(O&255)+(P&255)+(Q&255)+(S&255)+(T&255)+(U&255)+((V&255)<<1)+((W&255)*7|0)+8>>4}else{F=7}}while(0);if((F|0)==7){F=0;D=y;C=A;B=s;v=r;l=m;x=q;E=n;w=t;p=z;W=u;do{if((o&255|0)!=0){if((D<<24>>24|0)==0){F=10;break}V=a[B]|0;U=a[v]|0;T=a[l]|0;S=a[x]|0;Q=a[E]|0;P=a[w]|0;O=a[p]|0;N=a[W]|0;a[v]=(V&255)+(V&255)+(V&255)+((U&255)<<1)+(T&255)+(S&255)+(Q&255)+4>>3;a[l]=(V&255)+(V&255)+(U&255)+((T&255)<<1)+(S&255)+(Q&255)+(P&255)+4>>3;a[x]=(V&255)+(U&255)+(T&255)+((S&255)<<1)+(Q&255)+(P&255)+(O&255)+4>>3;a[E]=(U&255)+(T&255)+(S&255)+((Q&255)<<1)+(P&255)+(O&255)+(N&255)+4>>3;a[w]=(T&255)+(S&255)+(Q&255)+((P&255)<<1)+(O&255)+(N&255)+(N&255)+4>>3;a[p]=(S&255)+(Q&255)+(P&255)+((O&255)<<1)+(N&255)+(N&255)+(N&255)+4>>3}else{F=10}}while(0);if((F|0)==10){F=0;p=D;v=l;W=x;B=E;o=w;u=(a[v]^128)&255;z=(a[W]^128)&255;t=(a[B]^128)&255;n=(a[o]^128)&255;q=C;m=0;m=(m<<24>>24|(((R((d[v]|0)-(d[W]|0)|0)|0)>(q&255|0)|0)*-1|0))&255;m=(m<<24>>24|(((R((d[o]|0)-(d[B]|0)|0)|0)>(q&255|0)|0)*-1|0))&255;q=m;m=(u<<24>>24)-(n<<24>>24)|0;r=-128;s=127;if((m|0)<(r|0)){X=r}else{if((m|0)>(s|0)){Y=s}else{Y=m}X=Y}m=(X&255)<<24>>24&(q&255)&255;s=(m<<24>>24)+(((t<<24>>24)-(z<<24>>24)|0)*3|0)|0;r=-128;A=127;if((s|0)<(r|0)){Z=r}else{if((s|0)>(A|0)){_=A}else{_=s}Z=_}m=(Z&255)<<24>>24&p<<24>>24&255;p=(m<<24>>24)+4|0;s=-128;A=127;if((p|0)<(s|0)){$=s}else{if((p|0)>(A|0)){aa=A}else{aa=p}$=aa}p=($&255)<<24>>24>>3&255;A=(m<<24>>24)+3|0;s=-128;r=127;if((A|0)<(s|0)){ba=s}else{if((A|0)>(r|0)){ca=r}else{ca=A}ba=ca}A=(ba&255)<<24>>24>>3&255;r=(t<<24>>24)-(p<<24>>24)|0;t=-128;s=127;if((r|0)<(t|0)){da=t}else{if((r|0)>(s|0)){ea=s}else{ea=r}da=ea}a[B]=(da&255)<<24>>24^128;B=(z<<24>>24)+(A<<24>>24)|0;A=-128;z=127;if((B|0)<(A|0)){fa=A}else{if((B|0)>(z|0)){ga=z}else{ga=B}fa=ga}a[W]=(fa&255)<<24>>24^128;m=(p<<24>>24)+1>>1&~(q&255)&255;q=(n<<24>>24)-(m<<24>>24)|0;n=-128;p=127;if((q|0)<(n|0)){ha=n}else{if((q|0)>(p|0)){ia=p}else{ia=q}ha=ia}a[o]=(ha&255)<<24>>24^128;o=(u<<24>>24)+(m<<24>>24)|0;m=-128;u=127;if((o|0)<(m|0)){ja=m}else{if((o|0)>(u|0)){ka=u}else{ka=o}ja=ka}a[v]=(ja&255)<<24>>24^128}}k=k+b|0;h=h+1|0}i=j;return}function Xfc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=i;Wfc(a,b,c,d,e,16);i=f;return}function Yfc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0;j=i;Zfc(a,b,c,d,e,f,-1,g,h);i=j;return}function Zfc(d,e,f,g,h,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;n=i;i=i+240|0;o=n|0;p=n+8|0;q=n+16|0;r=n+24|0;s=n+32|0;t=n+40|0;u=n+48|0;v=n+56|0;w=n+64|0;x=n+72|0;y=n+80|0;z=n+88|0;A=n+96|0;B=n+104|0;C=n+112|0;D=n+120|0;E=n+128|0;F=n+136|0;G=n+144|0;H=n+152|0;I=n+160|0;J=n+168|0;K=n+176|0;L=n+184|0;M=n+192|0;N=n+200|0;O=n+208|0;P=n+216|0;Q=n+224|0;R=n+232|0;S=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=S+13364|0;T=0;do{if((c[S+36968>>2]|0)!=0){if((c[S+10196>>2]|0)==0){U=4;break}V=(ca(k,c[d+156>>2]|0)|0)+l|0;W=c[(c[S+10212>>2]|0)+(V<<2)>>2]|0}else{U=4}}while(0);if((U|0)==4){W=0}V=W;if((V|0)!=0){X=V|0}else{X=0}V=X;X=791008+(c[f>>2]<<6)|0;W=0;Y=0;mrc(h|0,0,8)|0;Z=0;while(1){if((Z|0)>=2){U=61;break}_=X+(Z<<3)|0;$=e;aa=l;ba=k;da=c[S+10148>>2]|0;ea=_;do{if((ba+(c[ea>>2]|0)|0)<0){fa=1}else{if((aa+(c[ea+4>>2]|0)|0)<(c[$+8>>2]|0)){fa=1;break}if((ba+(c[ea>>2]|0)|0)>=(da|0)){fa=1;break}fa=(aa+(c[ea+4>>2]|0)|0)>=(c[$+12>>2]|0)}}while(0);if(((fa^1)&1|0)!=0){$=(c[_+4>>2]|0)+(ca(c[_>>2]|0,c[d+156>>2]|0)|0)|0;ga=c[(c[d+160>>2]|0)+($<<2)>>2]|0;$=ga|0;Y=Y+(c[829536+(c[$+4>>2]<<2)>>2]|0)|0;W=1;if((c[$+20>>2]|0)==(g|0)){if((T|0)!=0){ea=ga;aa=0;da=c[_+4>>2]|0;ba=j;do{if((ba|0)>=0){if(!((c[ea>>2]|0)>>>0<3>>>0)){U=21;break}c[A>>2]=c[ea+76+((c[1076472+(ba<<3)+(((da|0)==0)<<2)>>2]|0)*12|0)+4+(aa<<2)>>2]}else{U=21}}while(0);if((U|0)==21){U=0;c[A>>2]=c[ea+28+(aa<<2)>>2]}if((c[A>>2]|0)!=(c[h>>2]|0)){U=23;break}}else{da=T;T=da+1|0;ba=h+(da<<2)|0;da=ga;ha=0;ia=c[_+4>>2]|0;ja=j;do{if((ja|0)>=0){if(!((c[da>>2]|0)>>>0<3>>>0)){U=32;break}c[C>>2]=c[da+76+((c[1076472+(ja<<3)+(((ia|0)==0)<<2)>>2]|0)*12|0)+4+(ha<<2)>>2]}else{U=32}}while(0);if((U|0)==32){U=0;c[C>>2]=c[da+28+(ha<<2)>>2]}c[ba>>2]=c[C>>2]}}else{if((c[$+24>>2]|0)==(g|0)){if((T|0)!=0){ia=ga;ja=1;aa=c[_+4>>2]|0;ea=j;do{if((ea|0)>=0){if(!((c[ia>>2]|0)>>>0<3>>>0)){U=42;break}c[D>>2]=c[ia+76+((c[1076472+(ea<<3)+(((aa|0)==0)<<2)>>2]|0)*12|0)+4+(ja<<2)>>2]}else{U=42}}while(0);if((U|0)==42){U=0;c[D>>2]=c[ia+28+(ja<<2)>>2]}if((c[D>>2]|0)!=(c[h>>2]|0)){U=44;break}}else{aa=T;T=aa+1|0;ea=h+(aa<<2)|0;aa=ga;$=1;ba=c[_+4>>2]|0;ha=j;do{if((ha|0)>=0){if(!((c[aa>>2]|0)>>>0<3>>>0)){U=53;break}c[F>>2]=c[aa+76+((c[1076472+(ha<<3)+(((ba|0)==0)<<2)>>2]|0)*12|0)+4+($<<2)>>2]}else{U=53}}while(0);if((U|0)==53){U=0;c[F>>2]=c[aa+28+($<<2)>>2]}c[ea>>2]=c[F>>2]}}}}Z=Z+1|0}a:do{if((U|0)==23){F=h+(T<<2)|0;D=ga;C=0;A=c[_+4>>2]|0;fa=j;do{if((fa|0)>=0){if(!((c[D>>2]|0)>>>0<3>>>0)){U=26;break}c[B>>2]=c[D+76+((c[1076472+(fa<<3)+(((A|0)==0)<<2)>>2]|0)*12|0)+4+(C<<2)>>2]}else{U=26}}while(0);if((U|0)==26){c[B>>2]=c[D+28+(C<<2)>>2]}c[F>>2]=c[B>>2]}else if((U|0)==44){A=h+(T<<2)|0;fa=ga;ea=1;$=c[_+4>>2]|0;aa=j;do{if((aa|0)>=0){if(!((c[fa>>2]|0)>>>0<3>>>0)){U=47;break}c[E>>2]=c[fa+76+((c[1076472+(aa<<3)+((($|0)==0)<<2)>>2]|0)*12|0)+4+(ea<<2)>>2]}else{U=47}}while(0);if((U|0)==47){c[E>>2]=c[fa+28+(ea<<2)>>2]}c[A>>2]=c[E>>2]}else if((U|0)==61){while(1){if((Z|0)>=8){U=90;break}$=X+(Z<<3)|0;aa=e;F=l;C=k;D=c[S+10148>>2]|0;ba=$;do{if((C+(c[ba>>2]|0)|0)<0){ka=1}else{if((F+(c[ba+4>>2]|0)|0)<(c[aa+8>>2]|0)){ka=1;break}if((C+(c[ba>>2]|0)|0)>=(D|0)){ka=1;break}ka=(F+(c[ba+4>>2]|0)|0)>=(c[aa+12>>2]|0)}}while(0);if(((ka^1)&1|0)!=0){aa=(c[$+4>>2]|0)+(ca(c[$>>2]|0,c[d+156>>2]|0)|0)|0;la=c[(c[d+160>>2]|0)+(aa<<2)>>2]|0;W=1;if((c[la+20>>2]|0)==(g|0)){if((T|0)!=0){if((c[la+28>>2]|0)!=(c[h>>2]|0)){U=72;break}}else{aa=T;T=aa+1|0;c[h+(aa<<2)>>2]=c[la+28>>2]}}else{if((c[la+24>>2]|0)==(g|0)){if((T|0)!=0){if((c[la+32>>2]|0)!=(c[h>>2]|0)){U=81;break}}else{aa=T;T=aa+1|0;c[h+(aa<<2)>>2]=c[la+32>>2]}}}}Z=Z+1|0}if((U|0)==72){c[h+(T<<2)>>2]=c[la+28>>2];break}else if((U|0)==81){c[h+(T<<2)>>2]=c[la+32>>2];break}else if((U|0)==90){if((V|0)!=0){if((c[V+20>>2]|0)==(g|0)){do{if((T|0)!=0){if((c[V+28>>2]|0)!=(c[h>>2]|0)){c[h+(T<<2)>>2]=c[V+28>>2];break a}else{break}}else{A=T;T=A+1|0;c[h+(A<<2)>>2]=c[V+28>>2]}}while(0)}else{if((c[V+24>>2]|0)==(g|0)){do{if((T|0)!=0){if((c[V+32>>2]|0)!=(c[h>>2]|0)){c[h+(T<<2)>>2]=c[V+32>>2];break a}else{break}}else{A=T;T=A+1|0;c[h+(A<<2)>>2]=c[V+32>>2]}}while(0)}}}do{if((W|0)!=0){Z=0;b:while(1){if((Z|0)>=8){U=158;break}A=X+(Z<<3)|0;ea=e;fa=l;aa=k;ba=c[S+10148>>2]|0;F=A;do{if((aa+(c[F>>2]|0)|0)<0){ma=1}else{if((fa+(c[F+4>>2]|0)|0)<(c[ea+8>>2]|0)){ma=1;break}if((aa+(c[F>>2]|0)|0)>=(ba|0)){ma=1;break}ma=(fa+(c[F+4>>2]|0)|0)>=(c[ea+12>>2]|0)}}while(0);if(((ma^1)&1|0)!=0){ea=(c[A+4>>2]|0)+(ca(c[A>>2]|0,c[d+156>>2]|0)|0)|0;na=c[(c[d+160>>2]|0)+(ea<<2)>>2]|0;if(((c[na+20>>2]|0)>0|0)!=0){if((c[na+20>>2]|0)!=(g|0)){if((T|0)!=0){ea=na;F=0;fa=m;c[o>>2]=c[ea+28+(F<<2)>>2];if((c[fa+(c[ea+20+(F<<2)>>2]<<2)>>2]|0)!=(c[fa+(g<<2)>>2]|0)){fa=o|0;b[fa>>1]=(b[fa>>1]|0)*-1|0;fa=o+2|0;b[fa>>1]=(b[fa>>1]|0)*-1|0}c[G>>2]=c[o>>2];if((c[G>>2]|0)!=(c[h>>2]|0)){U=127;break}}else{fa=T;T=fa+1|0;F=na;ea=0;ba=m;c[q>>2]=c[F+28+(ea<<2)>>2];if((c[ba+(c[F+20+(ea<<2)>>2]<<2)>>2]|0)!=(c[ba+(g<<2)>>2]|0)){ba=q|0;b[ba>>1]=(b[ba>>1]|0)*-1|0;ba=q+2|0;b[ba>>1]=(b[ba>>1]|0)*-1|0}c[I>>2]=c[q>>2];c[h+(fa<<2)>>2]=c[I>>2]}}do{if(((c[na+24>>2]|0)>0|0)!=0){if((c[na+24>>2]|0)==(g|0)){break}if((c[na+32>>2]|0)==(c[na+28>>2]|0)){break}if((T|0)!=0){fa=na;ba=1;ea=m;c[r>>2]=c[fa+28+(ba<<2)>>2];if((c[ea+(c[fa+20+(ba<<2)>>2]<<2)>>2]|0)!=(c[ea+(g<<2)>>2]|0)){ea=r|0;b[ea>>1]=(b[ea>>1]|0)*-1|0;ea=r+2|0;b[ea>>1]=(b[ea>>1]|0)*-1|0}c[J>>2]=c[r>>2];if((c[J>>2]|0)!=(c[h>>2]|0)){U=144;break b}}else{ea=T;T=ea+1|0;ba=na;fa=1;F=m;c[t>>2]=c[ba+28+(fa<<2)>>2];if((c[F+(c[ba+20+(fa<<2)>>2]<<2)>>2]|0)!=(c[F+(g<<2)>>2]|0)){F=t|0;b[F>>1]=(b[F>>1]|0)*-1|0;F=t+2|0;b[F>>1]=(b[F>>1]|0)*-1|0}c[L>>2]=c[t>>2];c[h+(ea<<2)>>2]=c[L>>2]}}}while(0)}}Z=Z+1|0}if((U|0)==127){$=na;A=0;ea=m;c[p>>2]=c[$+28+(A<<2)>>2];if((c[ea+(c[$+20+(A<<2)>>2]<<2)>>2]|0)!=(c[ea+(g<<2)>>2]|0)){ea=p|0;b[ea>>1]=(b[ea>>1]|0)*-1|0;ea=p+2|0;b[ea>>1]=(b[ea>>1]|0)*-1|0}c[H>>2]=c[p>>2];c[h+(T<<2)>>2]=c[H>>2];break a}else if((U|0)==144){ea=na;A=1;$=m;c[s>>2]=c[ea+28+(A<<2)>>2];if((c[$+(c[ea+20+(A<<2)>>2]<<2)>>2]|0)!=(c[$+(g<<2)>>2]|0)){$=s|0;b[$>>1]=(b[$>>1]|0)*-1|0;$=s+2|0;b[$>>1]=(b[$>>1]|0)*-1|0}c[K>>2]=c[s>>2];c[h+(T<<2)>>2]=c[K>>2];break a}else if((U|0)==158){break}}}while(0);if((V|0)!=0){if(((c[V+20>>2]|0)>0|0)!=0){if((c[V+20>>2]|0)!=(g|0)){do{if((T|0)!=0){$=V;A=0;ea=m;c[u>>2]=c[$+28+(A<<2)>>2];if((c[ea+(c[$+20+(A<<2)>>2]<<2)>>2]|0)!=(c[ea+(g<<2)>>2]|0)){ea=u|0;b[ea>>1]=(b[ea>>1]|0)*-1|0;ea=u+2|0;b[ea>>1]=(b[ea>>1]|0)*-1|0}c[M>>2]=c[u>>2];if((c[M>>2]|0)==(c[h>>2]|0)){break}ea=V;A=0;$=m;c[v>>2]=c[ea+28+(A<<2)>>2];if((c[$+(c[ea+20+(A<<2)>>2]<<2)>>2]|0)!=(c[$+(g<<2)>>2]|0)){$=v|0;b[$>>1]=(b[$>>1]|0)*-1|0;$=v+2|0;b[$>>1]=(b[$>>1]|0)*-1|0}c[N>>2]=c[v>>2];c[h+(T<<2)>>2]=c[N>>2];break a}else{$=T;T=$+1|0;A=V;ea=0;F=m;c[w>>2]=c[A+28+(ea<<2)>>2];if((c[F+(c[A+20+(ea<<2)>>2]<<2)>>2]|0)!=(c[F+(g<<2)>>2]|0)){F=w|0;b[F>>1]=(b[F>>1]|0)*-1|0;F=w+2|0;b[F>>1]=(b[F>>1]|0)*-1|0}c[O>>2]=c[w>>2];c[h+($<<2)>>2]=c[O>>2]}}while(0)}do{if(((c[V+24>>2]|0)>0|0)!=0){if((c[V+24>>2]|0)==(g|0)){break}if((c[V+32>>2]|0)==(c[V+28>>2]|0)){break}do{if((T|0)!=0){$=V;F=1;ea=m;c[x>>2]=c[$+28+(F<<2)>>2];if((c[ea+(c[$+20+(F<<2)>>2]<<2)>>2]|0)!=(c[ea+(g<<2)>>2]|0)){ea=x|0;b[ea>>1]=(b[ea>>1]|0)*-1|0;ea=x+2|0;b[ea>>1]=(b[ea>>1]|0)*-1|0}c[P>>2]=c[x>>2];if((c[P>>2]|0)==(c[h>>2]|0)){break}ea=V;F=1;$=m;c[y>>2]=c[ea+28+(F<<2)>>2];if((c[$+(c[ea+20+(F<<2)>>2]<<2)>>2]|0)!=(c[$+(g<<2)>>2]|0)){$=y|0;b[$>>1]=(b[$>>1]|0)*-1|0;$=y+2|0;b[$>>1]=(b[$>>1]|0)*-1|0}c[Q>>2]=c[y>>2];c[h+(T<<2)>>2]=c[Q>>2];break a}else{$=T;T=$+1|0;F=V;ea=1;A=m;c[z>>2]=c[F+28+(ea<<2)>>2];if((c[A+(c[F+20+(ea<<2)>>2]<<2)>>2]|0)!=(c[A+(g<<2)>>2]|0)){A=z|0;b[A>>1]=(b[A>>1]|0)*-1|0;A=z+2|0;b[A>>1]=(b[A>>1]|0)*-1|0}c[R>>2]=c[z>>2];c[h+($<<2)>>2]=c[R>>2]}}while(0)}}while(0)}}break}}}while(0);a[f+68+g|0]=c[1635752+(Y<<2)>>2];Z=0;while(1){if((Z|0)>=2){break}bgc(h+(Z<<2)|0,d);Z=Z+1|0}i=n;return}function _fc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;j=a;a=d;d=e;e=f;f=g;g=0;while(1){if((g|0)>=2){break}$fc(d+(g<<2)|0,a);k=j;l=d+(g<<2)|0;m=(c[k+180>>2]|0)-1248|0;n=(c[k+184>>2]|0)+1248|0;o=b[l+2>>1]|0;p=(c[k+172>>2]|0)-1248|0;q=(c[k+176>>2]|0)+1248|0;if((o|0)<(p|0)){r=p}else{if((o|0)>(q|0)){s=q}else{s=o}r=s}b[l+2>>1]=r;o=b[l>>1]|0;q=m;m=n;if((o|0)<(q|0)){t=q}else{if((o|0)>(m|0)){u=m}else{u=o}t=u}b[l>>1]=t;g=g+1|0}c[e>>2]=c[d>>2];c[f>>2]=c[d+4>>2];i=h;return}function $fc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0;d=i;e=a;if((c|0)!=0){f=(Lec(e)|0)!=0}else{f=0}if((f&1|0)!=0){i=d;return}if((b[e>>1]&1|0)!=0){f=e|0;b[f>>1]=(b[f>>1]|0)+((b[e>>1]|0)>0?-1:1)}if((b[e+2>>1]&1|0)!=0){f=e+2|0;b[f>>1]=(b[f>>1]|0)+((b[e+2>>1]|0)>0?-1:1)}i=d;return}function agc(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;l=i;i=i+24|0;m=l|0;n=l+8|0;o=b;b=e;e=f;f=j;j=k;k=c[c[o+160>>2]>>2]|0;p=k+76|0;Zfc(a,o,d,k,c[k+20+(e<<2)>>2]|0,m|0,b,g,h);c[j>>2]=0;h=b;if((h|0)==1|(h|0)==2){c[f>>2]=c[p+4+(e<<2)>>2];q=0;while(1){if((q|0)>=2){break}if((c[f>>2]|0)!=(c[m+(q<<2)>>2]|0)){r=6;break}q=q+1|0}if((r|0)==6){c[j>>2]=c[m+(q<<2)>>2]}i=l;return}else if((h|0)==0){c[f>>2]=c[m>>2];c[j>>2]=c[m+4>>2];i=l;return}else if((h|0)==3){c[n>>2]=c[p+16+(e<<2)>>2];c[n+4>>2]=c[p+4+(e<<2)>>2];c[n+8>>2]=c[m>>2];c[n+12>>2]=c[m+4>>2];c[f>>2]=c[p+28+(e<<2)>>2];q=0;while(1){if((q|0)>=4){break}if((c[f>>2]|0)!=(c[n+(q<<2)>>2]|0)){r=13;break}q=q+1|0}if((r|0)==13){c[j>>2]=c[n+(q<<2)>>2]}i=l;return}else{if(1){}else{Cd(2543504,2416720,363,2650760)}i=l;return}}function bgc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=d;d=a;a=(c[f+180>>2]|0)-128|0;g=(c[f+184>>2]|0)+128|0;h=b[d+2>>1]|0;j=(c[f+172>>2]|0)-128|0;k=(c[f+176>>2]|0)+128|0;if((h|0)<(j|0)){l=j}else{if((h|0)>(k|0)){m=k}else{m=h}l=m}b[d+2>>1]=l;l=b[d>>1]|0;m=a;a=g;if((l|0)<(m|0)){n=m;o=n&65535;p=d;q=p|0;b[q>>1]=o;i=e;return}if((l|0)>(a|0)){r=a}else{r=l}n=r;o=n&65535;p=d;q=p|0;b[q>>1]=o;i=e;return}function cgc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a;a=d;if((c[a+168>>2]|0)!=0){e=c[(c[a+160>>2]|0)-4>>2]|0}else{e=0}a=e;if((a|0)!=0){f=a|0}else{f=0}a=f;do{if((a|0)!=0){if(((c[a+20>>2]|0)>0|0)==0){g=10;break}h=c[a+72>>2]|0}else{g=10}}while(0);if((g|0)==10){h=3}a=h;h=d;if((c[h+164>>2]|0)!=0){j=c[(c[h+160>>2]|0)+(-(c[h+156>>2]|0)<<2)>>2]|0}else{j=0}h=j;if((h|0)!=0){k=h|0}else{k=0}h=k;do{if((h|0)!=0){if(((c[h+20>>2]|0)>0|0)==0){g=20;break}l=c[h+72>>2]|0}else{g=20}}while(0);if((g|0)==20){l=3}g=l;if((a|0)==(g|0)){m=a;n=m;i=b;return n|0}do{if((a|0)==3){if((g|0)==3){break}m=g;n=m;i=b;return n|0}}while(0);do{if((a|0)!=3){if((g|0)!=3){break}m=a;n=m;i=b;return n|0}}while(0);m=3;n=m;i=b;return n|0}function dgc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a;a=d;if((c[a+164>>2]|0)!=0){e=c[(c[a+160>>2]|0)+(-(c[a+156>>2]|0)<<2)>>2]|0}else{e=0}a=e;if((a|0)!=0){f=a|0}else{f=0}a=f;f=d;if((c[f+168>>2]|0)!=0){g=c[(c[f+160>>2]|0)-4>>2]|0}else{g=0}f=g;if((f|0)!=0){h=f|0}else{h=0}f=h;h=(a|0)!=0|0;g=(f|0)!=0|0;do{if((h|0)!=0){if((g|0)==0){break}d=(((c[a+20>>2]|0)>0|0)!=0^1)&1;e=(((c[f+20>>2]|0)>0|0)!=0^1)&1;do{if((e|0)!=0){if((d|0)==0){j=18;break}k=3}else{j=18}}while(0);if((j|0)==18){if((e|0)!=0){l=1}else{l=(d|0)!=0}k=l&1}m=k;n=m;i=b;return n|0}}while(0);do{if((h|0)==0){if((g|0)!=0){break}m=0;n=m;i=b;return n|0}}while(0);if((h|0)!=0){o=a}else{o=f}m=((((c[o+20>>2]|0)>0|0)!=0^1)&1)<<1;n=m;i=b;return n|0}function egc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=a;a=b;b=a;if((c[b+164>>2]|0)!=0){f=c[(c[b+160>>2]|0)+(-(c[b+156>>2]|0)<<2)>>2]|0}else{f=0}b=f;if((b|0)!=0){g=b|0}else{g=0}b=g;g=a;if((c[g+168>>2]|0)!=0){h=c[(c[g+160>>2]|0)-4>>2]|0}else{h=0}g=h;if((g|0)!=0){j=g|0}else{j=0}g=j;j=(b|0)!=0|0;h=(g|0)!=0|0;do{if((j|0)!=0){if((h|0)==0){k=30;break}do{if(((c[b+24>>2]|0)>0|0)!=0){k=18}else{if(((c[g+24>>2]|0)>0|0)!=0){k=18;break}l=(c[b+20>>2]|0)==(c[e+13524>>2]|0)^(c[g+20>>2]|0)==(c[e+13524>>2]|0)}}while(0);if((k|0)==18){if(((c[b+24>>2]|0)>0|0)!=0){if(((c[g+24>>2]|0)>0|0)!=0){l=4}else{if((c[g+20>>2]|0)==(c[e+13524>>2]|0)){m=1}else{m=((c[g+20>>2]|0)>0|0)!=0^1}l=(m&1)+2|0}}else{if((c[b+20>>2]|0)==(c[e+13524>>2]|0)){n=1}else{n=((c[b+20>>2]|0)>0|0)!=0^1}l=(n&1)+2|0}}}else{k=30}}while(0);if((k|0)==30){do{if((j|0)!=0){k=32}else{if((h|0)!=0){k=32;break}l=1}}while(0);if((k|0)==32){if((j|0)!=0){o=b}else{o=g}g=o;if(((c[g+24>>2]|0)>0|0)!=0){l=3}else{l=(c[g+20>>2]|0)==(c[e+13524>>2]|0)|0}}}do{if((l|0)>=0){if((l|0)<5){p=1}else{break}e=p&1;e=l;i=d;return e|0}}while(0);Cd(2281904,2543376,108,2650328);return 0}function fgc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;e=a;a=b;b=a;if((c[b+164>>2]|0)!=0){f=c[(c[b+160>>2]|0)+(-(c[b+156>>2]|0)<<2)>>2]|0}else{f=0}b=f;if((b|0)!=0){g=b|0}else{g=0}b=g;g=a;if((c[g+168>>2]|0)!=0){h=c[(c[g+160>>2]|0)-4>>2]|0}else{h=0}g=h;if((g|0)!=0){j=g|0}else{j=0}g=j;j=(b|0)!=0|0;h=(g|0)!=0|0;a=((c[e+13364+(c[e+13524>>2]<<2)>>2]|0)!=0^1)&1;do{if((j|0)!=0){if((h|0)==0){k=74;break}f=(((c[b+20>>2]|0)>0|0)!=0^1)&1;l=(((c[g+20>>2]|0)>0|0)!=0^1)&1;do{if((f|0)!=0){if((l|0)==0){k=18;break}m=2}else{k=18}}while(0);if((k|0)==18){do{if((f|0)!=0){k=20}else{if((l|0)!=0){k=20;break}n=(((c[g+24>>2]|0)>0|0)!=0^1)&1;o=(((c[b+24>>2]|0)>0|0)!=0^1)&1;if((o|0)!=0){p=c[b+20>>2]|0}else{p=c[b+20+(a<<2)>>2]|0}q=p;if((n|0)!=0){r=c[g+20>>2]|0}else{r=c[g+20+(a<<2)>>2]|0}s=r;do{if((q|0)==(s|0)){if((c[e+13532>>2]|0)!=(q|0)){k=36;break}m=0}else{k=36}}while(0);if((k|0)==36){do{if((n|0)!=0){if((o|0)==0){k=48;break}if((q|0)==(c[e+13524>>2]|0)){if((s|0)==(c[e+13528>>2]|0)){k=42}else{k=40}}else{k=40}do{if((k|0)==40){if((s|0)==(c[e+13524>>2]|0)){if((q|0)==(c[e+13528>>2]|0)){k=42;break}}if((q|0)==(s|0)){m=3}else{m=1}}}while(0);if((k|0)==42){m=4}}else{k=48}}while(0);if((k|0)==48){do{if((n|0)!=0){k=50}else{if((o|0)!=0){k=50;break}if((q|0)==(s|0)){m=4}else{m=2}}}while(0);if((k|0)==50){if((n|0)!=0){t=q}else{t=s}u=t;if((o|0)!=0){v=q}else{v=s}w=v;do{if((u|0)==(c[e+13532>>2]|0)){if((w|0)==(c[e+13532>>2]|0)){k=59;break}m=1}else{k=59}}while(0);if((k|0)==59){do{if((w|0)==(c[e+13532>>2]|0)){if((u|0)==(c[e+13532>>2]|0)){k=62;break}m=2}else{k=62}}while(0);if((k|0)==62){m=4}}}}}}}while(0);if((k|0)==20){if((f|0)!=0){x=g}else{x=b}l=x;if(((c[l+24>>2]|0)>0|0)!=0){m=(((c[l+20+(a<<2)>>2]|0)!=(c[e+13532>>2]|0))<<1)+1|0}else{m=(((c[l+20>>2]|0)!=(c[e+13532>>2]|0))<<1)+1|0}}}}else{k=74}}while(0);if((k|0)==74){do{if((j|0)!=0){k=76}else{if((h|0)!=0){k=76;break}m=2}}while(0);if((k|0)==76){if((j|0)!=0){y=b}else{y=g}g=y;if(((c[g+20>>2]|0)>0|0)!=0){if(((c[g+24>>2]|0)>0|0)!=0){m=((c[g+20+(a<<2)>>2]|0)!=(c[e+13532>>2]|0))<<2}else{m=((c[g+20>>2]|0)!=(c[e+13532>>2]|0)|0)*3|0}}else{m=2}}}do{if((m|0)>=0){if((m|0)<5){z=1}else{break}e=z&1;e=m;i=d;return e|0}}while(0);Cd(2416648,2543376,190,2650440);return 0}function ggc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;d=a;a=d;if((c[a+164>>2]|0)!=0){e=c[(c[a+160>>2]|0)+(-(c[a+156>>2]|0)<<2)>>2]|0}else{e=0}a=e;if((a|0)!=0){f=a|0}else{f=0}a=f;f=d;if((c[f+168>>2]|0)!=0){g=c[(c[f+160>>2]|0)-4>>2]|0}else{g=0}f=g;if((f|0)!=0){h=f|0}else{h=0}f=h;h=(a|0)!=0|0;g=(f|0)!=0|0;do{if((h|0)!=0){if((g|0)==0){j=60;break}d=(((c[a+20>>2]|0)>0|0)!=0^1)&1;e=(((c[f+20>>2]|0)>0|0)!=0^1)&1;do{if((d|0)!=0){if((e|0)==0){j=18;break}k=2}else{j=18}}while(0);if((j|0)==18){do{if((d|0)!=0){j=20}else{if((e|0)!=0){j=20;break}l=(c[a+24>>2]|0)>0|0;m=(c[f+24>>2]|0)>0|0;n=c[a+20>>2]|0;o=c[a+24>>2]|0;p=c[f+20>>2]|0;q=c[f+24>>2]|0;do{if((l|0)!=0){if((m|0)==0){j=36;break}do{if((n|0)==1){r=1}else{if((o|0)==1){r=1;break}if((p|0)==1){r=1;break}r=(q|0)==1}}while(0);k=(r&1)+1|0}else{j=36}}while(0);if((j|0)==36){do{if((l|0)!=0){j=38}else{if((m|0)!=0){j=38;break}k=(((n|0)==1)<<1)+(((p|0)==1)<<1)|0}}while(0);if((j|0)==38){if((l|0)!=0){s=p}else{s=n}if((l|0)!=0){t=n}else{t=p}m=t;if((l|0)!=0){u=o}else{u=q}v=u;if((s|0)==1){if((m|0)==1){w=1}else{w=(v|0)==1}k=(w&1)+3|0}else{if((m|0)==1){x=1}else{x=(v|0)==1}k=x&1}}}}}while(0);if((j|0)==20){if((d|0)!=0){y=f}else{y=a}e=y;if(((c[e+24>>2]|0)>0|0)!=0){if((c[e+20>>2]|0)==1){z=1}else{z=(c[e+24>>2]|0)==1}k=(z&1)+1|0}else{k=((c[e+20>>2]|0)==1)<<2}}}}else{j=60}}while(0);if((j|0)==60){do{if((h|0)!=0){j=62}else{if((g|0)!=0){j=62;break}k=2}}while(0);if((j|0)==62){if((h|0)!=0){A=a}else{A=f}f=A;if(((c[f+20>>2]|0)>0|0)!=0){if(((c[f+24>>2]|0)>0|0)!=0){if((c[f+20>>2]|0)==1){B=1}else{B=(c[f+24>>2]|0)==1}k=(B&1)+1|0}else{k=((c[f+20>>2]|0)==1)<<2}}else{k=2}}}do{if((k|0)>=0){if((k|0)<5){C=1}else{break}f=C&1;f=k;i=b;return f|0}}while(0);Cd(2416648,2543376,257,2650400);return 0}function hgc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;d=a;a=d;if((c[a+164>>2]|0)!=0){e=c[(c[a+160>>2]|0)+(-(c[a+156>>2]|0)<<2)>>2]|0}else{e=0}a=e;if((a|0)!=0){f=a|0}else{f=0}a=f;f=d;if((c[f+168>>2]|0)!=0){g=c[(c[f+160>>2]|0)-4>>2]|0}else{g=0}f=g;if((f|0)!=0){h=f|0}else{h=0}f=h;h=(a|0)!=0|0;g=(f|0)!=0|0;do{if((h|0)!=0){if((g|0)==0){j=83;break}d=(((c[a+20>>2]|0)>0|0)!=0^1)&1;e=(((c[f+20>>2]|0)>0|0)!=0^1)&1;do{if((d|0)!=0){if((e|0)==0){j=18;break}k=2}else{j=18}}while(0);if((j|0)==18){do{if((d|0)!=0){j=20}else{if((e|0)!=0){j=20;break}l=(c[a+24>>2]|0)>0|0;m=(c[f+24>>2]|0)>0|0;n=c[a+20>>2]|0;o=c[a+24>>2]|0;p=c[f+20>>2]|0;q=c[f+24>>2]|0;do{if((l|0)!=0){if((m|0)==0){j=43;break}do{if((n|0)==(p|0)){if((o|0)!=(q|0)){j=41;break}do{if((n|0)==2){r=1}else{if((o|0)==2){r=1;break}if((p|0)==2){r=1;break}r=(q|0)==2}}while(0);k=(r&1)*3|0}else{j=41}}while(0);if((j|0)==41){k=2}}else{j=43}}while(0);if((j|0)==43){do{if((l|0)!=0){j=45}else{if((m|0)!=0){j=45;break}do{if((n|0)==1){if((p|0)!=1){j=70;break}k=3}else{j=70}}while(0);if((j|0)==70){do{if((n|0)==1){j=72}else{if((p|0)==1){j=72;break}k=(((n|0)==2)<<1)+(((p|0)==2)<<1)|0}}while(0);if((j|0)==72){if((n|0)==1){s=p}else{s=n}k=((s|0)==2)<<2}}}}while(0);if((j|0)==45){if((l|0)!=0){t=p}else{t=n}m=t;if((l|0)!=0){u=n}else{u=p}v=u;if((l|0)!=0){w=o}else{w=q}x=w;if((m|0)==2){if((v|0)==2){y=1}else{y=(x|0)==2}k=(y&1)+3|0}else{if((m|0)==3){if((v|0)==2){z=1}else{z=(x|0)==2}k=z&1}else{if((v|0)==2){A=1}else{A=(x|0)==2}k=((A&1)<<1)+1|0}}}}}}while(0);if((j|0)==20){if((d|0)!=0){B=f}else{B=a}e=B;if(((c[e+24>>2]|0)>0|0)!=0){if((c[e+20>>2]|0)==2){C=1}else{C=(c[e+24>>2]|0)==2}k=((C&1)<<1)+1|0}else{if((c[e+20>>2]|0)==1){k=3}else{k=((c[e+20>>2]|0)==2)<<2}}}}}else{j=83}}while(0);if((j|0)==83){do{if((h|0)!=0){j=85}else{if((g|0)!=0){j=85;break}k=2}}while(0);if((j|0)==85){if((h|0)!=0){D=a}else{D=f}f=D;do{if(((c[f+20>>2]|0)>0|0)!=0){if((c[f+20>>2]|0)==1){if(((c[f+24>>2]|0)>0|0)==0){j=91;break}}if(((c[f+24>>2]|0)>0|0)!=0){if((c[f+20>>2]|0)==2){E=1}else{E=(c[f+24>>2]|0)==2}k=(E&1)*3|0}else{k=((c[f+20>>2]|0)==2)<<2}}else{j=91}}while(0);if((j|0)==91){k=2}}}do{if((k|0)>=0){if((k|0)<5){F=1}else{break}j=F&1;j=k;i=b;return j|0}}while(0);Cd(2416648,2543376,343,2650360);return 0}function igc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=b;b=c[833024+(c[c[c[e+160>>2]>>2]>>2]<<2)>>2]|0;f=e;if((c[f+164>>2]|0)!=0){g=c[(c[f+160>>2]|0)+(-(c[f+156>>2]|0)<<2)>>2]|0}else{g=0}f=g;if((f|0)!=0){h=f|0}else{h=0}f=h;h=e;if((c[h+168>>2]|0)!=0){j=c[(c[h+160>>2]|0)-4>>2]|0}else{j=0}h=j;if((h|0)!=0){k=h|0}else{k=0}h=k;k=(f|0)!=0|0;j=(h|0)!=0|0;do{if((k|0)!=0){if((a[f+12|0]|0)!=0){l=16;break}m=c[f+8>>2]|0}else{l=16}}while(0);if((l|0)==16){m=b}f=m;do{if((j|0)!=0){if((a[h+12|0]|0)!=0){l=20;break}n=c[h+8>>2]|0}else{l=20}}while(0);if((l|0)==20){n=b}l=n;if((j|0)==0){l=f}if((k|0)!=0){o=f;p=l;q=o+p|0;r=b;s=(q|0)>(r|0);t=s&1;i=d;return t|0}f=l;o=f;p=l;q=o+p|0;r=b;s=(q|0)>(r|0);t=s&1;i=d;return t|0}function jgc(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;j=a;a=b;b=e;e=f;f=g;g=(ca(e,c[j+10156>>2]|0)|0)+f|0;k=c[777680+(b<<2)>>2]|0;l=c[777736+(b<<2)>>2]|0;if(((c[j+10156>>2]|0)-f|0)<(k|0)){m=(c[j+10156>>2]|0)-f|0}else{m=k}k=m;if(((c[j+10148>>2]|0)-e|0)<(l|0)){n=(c[j+10148>>2]|0)-e|0}else{n=l}l=n;n=2147483647;e=0;while(1){if((e|0)>=(l|0)){break}m=0;while(1){if((m|0)>=(k|0)){break}if((n|0)<(d[a+(g+(ca(e,c[j+10156>>2]|0)|0)+m)|0]|0|0)){o=n}else{o=d[a+(g+(ca(e,c[j+10156>>2]|0)|0)+m)|0]|0}n=o;m=m+1|0}e=e+1|0}do{if((n|0)>=0){if((n|0)<8){p=1}else{break}e=p&1;e=n;i=h;return e|0}}while(0);Cd(2337328,2543376,383,2650304);return 0}function kgc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;lgc(0,a,b,c,d,e,f)|0;i=g;return}function lgc(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+8|0;l=k|0;m=b;b=d;d=e;e=f;f=g;g=h;h=j;j=a[b+m|0]|0;if((j|0)<=0){n=c[e+(-j<<2)>>2]|0}else{n=lgc(j,b,d,e,f,g,h)|0}j=n;n=a[b+(m+1)|0]|0;if((n|0)<=0){o=c[e+(-n<<2)>>2]|0}else{o=lgc(n,b,d,e,f,g,h)|0}e=o;o=l|0;c[o>>2]=j;c[o+4>>2]=e;o=a[d+(m>>>1)|0]|0;d=l|0;l=f;f=g;g=c[d>>2]|0;b=g+(c[d+4>>2]|0)|0;if((b|0)==0){p=128}else{n=((g<<8)+(b>>1)|0)/(b|0)|0;if((n|0)>255){q=255}else{if((n|0)<1){r=1}else{r=n}q=r}p=q&255}if(((c[d>>2]|0)+(c[d+4>>2]|0)|0)>>>0<l>>>0){s=(c[d>>2]|0)+(c[d+4>>2]|0)|0}else{s=l}d=((ca(f,s)|0)>>>0)/(l>>>0)|0;a[h+(m>>>1)|0]=(ca(o&255,256-d|0)|0)+(ca(p&255,d)|0)+128>>8;i=k;return j+e|0}function mgc(){return}function ngc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;e=a+c|0;c=0;a=255;if((e|0)<(c|0)){f=c}else{if((e|0)>(a|0)){g=a}else{g=e}f=g}i=d;return b[1614376+(f<<1)>>1]|0}function ogc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;e=a+c|0;c=0;a=255;if((e|0)<(c|0)){f=c}else{if((e|0)>(a|0)){g=a}else{g=e}f=g}i=d;return b[2086096+(f<<1)>>1]|0}function pgc(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a;a=b;b=c;if((Thc(f,a,0)|0)==0){g=b;h=g;i=e;return h|0}c=Zhc(f,a,0)|0;if((d[f+3|0]|0|0)==1){j=c}else{j=b+c|0}c=j;j=0;b=255;if((c|0)<(j|0)){k=j}else{if((c|0)>(b|0)){l=b}else{l=c}k=l}g=k;h=g;i=e;return h|0}function qgc(a,d,e,f,g,h,j,k,l,m,n,o,p){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0;q=i;i=i+16|0;r=q|0;s=q+8|0;t=a;a=d;d=g;g=h;h=(n|0)==1|0;if((h|0)!=0){u=b[d>>1]|0}else{u=b[d>>1]<<1}b[r>>1]=u;if((h|0)!=0){v=b[d+2>>1]|0}else{v=b[d+2>>1]<<1}b[r+2>>1]=v;Jhc(s,r,o,p,g);p=ca(c[s>>2]>>4,a)|0;t=t+(p+(c[s+4>>2]>>4))|0;rgc(t,a,e,f,c[s+4>>2]&15,c[s>>2]&15,g,j,k,l,m,c[g+8>>2]|0,c[g+12>>2]|0);i=q;return}function rgc(a,b,d,e,f,g,h,j,k,l,m,n,o){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0;p=i;q=f;f=g;g=m;Ve[c[h+24+(((q|0)!=0)<<4)+(((f|0)!=0)<<3)+(l<<2)>>2]&127](a,b,d,e,g+(q<<4)|0,n,g+(f<<4)|0,o,j,k);i=p;return}function sgc(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;k=i;i=i+8|0;l=k|0;m=d;d=e;e=h;h=j;j=f+4<<4;f=g+4<<4;b[l>>1]=ca(b[d>>1]|0,1<<1-h)|0;b[l+2>>1]=ca(b[d+2>>1]|0,1<<1-e)|0;if((e|0)<=1){}else{Cd(2279752,2542792,130,2653248)}if((h|0)<=1){}else{Cd(2416376,2542792,131,2653248)}d=(ca(c[m+172>>2]|0,1<<1-e)|0)-j|0;g=(ca(c[m+176>>2]|0,1<<1-e)|0)+(j-16)|0;j=(ca(c[m+180>>2]|0,1<<1-h)|0)-f|0;e=l;n=j;j=(ca(c[m+184>>2]|0,1<<1-h)|0)+(f-16)|0;f=b[e+2>>1]|0;h=d;d=g;if((f|0)<(h|0)){o=h}else{if((f|0)>(d|0)){p=d}else{p=f}o=p}b[e+2>>1]=o;o=b[e>>1]|0;p=n;n=j;if((o|0)<(p|0)){q=p;r=q&65535;s=e;t=s|0;b[t>>1]=r;u=a;v=l;b[u>>1]=b[v>>1]|0;b[u+2>>1]=b[v+2>>1]|0;i=k;return}if((o|0)>(n|0)){w=n}else{w=o}q=w;r=q&65535;s=e;t=s|0;b[t>>1]=r;u=a;v=l;b[u>>1]=b[v>>1]|0;b[u+2>>1]=b[v+2>>1]|0;i=k;return}function tgc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=i;ugc(a,d,b,c,0,0);i=e;return}function ugc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=a;a=b;b=g;g=e<<3;e=d<<3;d=f;while(1){if((d|0)>(b|0)){k=20;break}f=j+(d*52|0)|0;l=c[558424+(a<<4)+(c[f+8>>2]<<3)+(c[f+12>>2]<<2)>>2]|0;if(!(l>>>0<13>>>0)){k=4;break}f=l;l=c[777792+(f<<2)>>2]|0;m=c[777848+(f<<2)>>2]|0;f=l<<2;n=m<<2;if((c[c[c[j+160>>2]>>2]>>2]|0)>>>0<3>>>0){o=0;if((a|0)==3){}else{Cd(2337168,2542792,217,2653392)}p=0;while(1){if((p|0)>=(m|0)){break}q=0;while(1){if((q|0)>=(l|0)){break}r=o;o=r+1|0;Dgc(j,d,r,f,n,q<<2,p<<2,4,4,g,e);q=q+1|0}p=p+1|0}}else{Dgc(j,d,0,f,n,0,0,f,n,g,e)}d=d+1|0}if((k|0)==4){Cd(2279536,2230272,292,2652368)}else if((k|0)==20){i=h;return}}function vgc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=i;ugc(a,d,b,c,1,2);i=e;return}function wgc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=i;ugc(a,d,b,c,0,2);i=e;return}function xgc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=a;a=e;e=d<<3;d=b<<3;b=0;while(1){if((b|0)>=3){h=20;break}j=g+(b*52|0)|0;k=c[558424+(a<<4)+(c[j+8>>2]<<3)+(c[j+12>>2]<<2)>>2]|0;if(!(k>>>0<13>>>0)){h=4;break}j=k;k=c[777792+(j<<2)>>2]|0;l=c[777848+(j<<2)>>2]|0;j=k<<2;m=l<<2;if((c[c[c[g+160>>2]>>2]>>2]|0)>>>0<3>>>0){n=0;if((a|0)==3){}else{Cd(2337168,2542792,400,2650584)}o=0;while(1){if((o|0)>=(l|0)){break}p=0;while(1){if((p|0)>=(k|0)){break}q=n;n=q+1|0;ygc(g,b,q,j,m,p<<2,o<<2,4,4,e,d);p=p+1|0}o=o+1|0}}else{ygc(g,b,0,j,m,0,0,j,m,e,d)}b=b+1|0}if((h|0)==4){Cd(2279536,2230272,292,2652368)}else if((h|0)==20){i=f;return}}function ygc(a,d,e,f,g,h,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;o=i;i=i+32|0;p=o|0;q=o+8|0;r=o+16|0;s=o+24|0;t=a;a=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=t+(a*52|0)|0;u=c[c[t+160>>2]>>2]|0;v=(c[u+24>>2]|0)>0|0;w=Tec(c[u+72>>2]|0)|0;x=0;while(1){if((x|0)>=(v+1|0)){break}y=(c[t+188+(x<<2)>>2]|0)+8|0;z=n+24+(x<<3)|0;A=n+16|0;B=(c[A>>2]|0)+(ca(c[A+4>>2]|0,h)|0)+g|0;if((c[u>>2]|0)>>>0<3>>>0){if((a|0)==0){C=p;D=u+76+(d*12|0)+4+(x<<2)|0;b[C>>1]=b[D>>1]|0;b[C+2>>1]=b[D+2>>1]|0}else{Bgc(p,u,x)}}else{D=p;C=u+28+(x<<2)|0;b[D>>1]=b[C>>1]|0;b[D+2>>1]=b[C+2>>1]|0}sgc(q,t,p,e,f,c[n+8>>2]|0,c[n+12>>2]|0);C=c[(c[t+188+(x<<2)>>2]|0)+4>>2]|0;if((a|0)==0){E=c[C+8>>2]|0;F=c[C+12>>2]|0;G=c[C+52>>2]|0}else{E=c[C+28>>2]|0;F=c[C+32>>2]|0;if((a|0)==1){H=c[C+56>>2]|0}else{H=c[C+60>>2]|0}G=H}C=y;if((c[C>>2]|0)!=16384){I=1}else{I=(c[C+4>>2]|0)!=16384}if((I&1|0)!=0){C=-(c[t+172>>2]|0)>>(c[n+8>>2]|0)+3;D=-(c[t+180>>2]|0)>>(c[n+12>>2]|0)+3;J=C+g<<4;K=D+h<<4;J=We[c[y+16>>2]&2047](J,y)|0;K=We[c[y+20>>2]&2047](K,y)|0;L=We[c[y+16>>2]&2047](C+g|0,y)|0;M=We[c[y+20>>2]&2047](D+h|0,y)|0;Jhc(s,q,l+g|0,m+h|0,y);D=r;C=s;c[D>>2]=c[C>>2];c[D+4>>2]=c[C+4>>2];N=c[y+8>>2]|0;O=c[y+12>>2]|0}else{L=(-(c[t+172>>2]|0)>>(c[n+8>>2]|0)+3)+g|0;M=(-(c[t+180>>2]|0)>>(c[n+12>>2]|0)+3)+h|0;J=L<<4;K=M<<4;c[r>>2]=b[q>>1]|0;c[r+4>>2]=b[q+2>>1]|0;O=16;N=16}C=c[r+4>>2]&15;D=c[r>>2]&15;L=L+(c[r+4>>2]>>4)|0;M=M+(c[r>>2]>>4)|0;J=J+(c[r+4>>2]|0)|0;K=K+(c[r>>2]|0)|0;P=G+(ca(M,c[z+4>>2]|0)|0)+L|0;Q=c[z+4>>2]|0;do{if((c[r+4>>2]|0)!=0){R=24}else{if((c[r>>2]|0)!=0){R=24;break}if((E&7|0)!=0){R=24;break}if((F&7|0)!=0){R=24}}}while(0);if((R|0)==24){R=0;S=(J+(ca(j-1|0,N)|0)>>4)+1|0;T=(K+(ca(k-1|0,O)|0)>>4)+1|0;U=0;V=0;if((C|0)!=0){R=26}else{if((c[y+8>>2]&15|0)!=0){R=26}}if((R|0)==26){R=0;L=L-3|0;S=S+4|0;U=1}if((D|0)!=0){R=29}else{if((c[y+12>>2]&15|0)!=0){R=29}}if((R|0)==29){R=0;M=M-3|0;T=T+4|0;V=1}do{if((L|0)<0){R=38}else{if((L|0)>(E-1|0)){R=38;break}if((S|0)<0){R=38;break}if((S|0)>(E|0)){R=38;break}if((M|0)<0){R=38;break}if((M|0)>(F-1|0)){R=38;break}if((T|0)<0){R=38;break}if((T|0)>(F-1|0)){R=38}}}while(0);if((R|0)==38){R=0;W=G+(ca(M,c[z+4>>2]|0)|0)+L|0;Cgc(W,c[z+4>>2]|0,t+208|0,S-L+1|0,L,M,S-L+1|0,T-M+1|0,E,F);Q=S-L+1|0;P=t+208+(ca(V*3|0,Q)|0)+(U*3|0)|0}}rgc(P,Q,B,c[A+4>>2]|0,C,D,y,j,k,x,w,N,O);x=x+1|0}i=o;return}function zgc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=f+16|0;j=a;a=b;b=d;d=e;e=g|0;c[e>>2]=c[a+52>>2];k=e+4|0;c[k>>2]=c[a+56>>2];e=k+4|0;c[e>>2]=c[a+60>>2];c[e+4>>2]=c[a+64>>2];e=h|0;c[e>>2]=c[a+16>>2];k=e+4|0;c[k>>2]=c[a+36>>2];e=k+4|0;c[e>>2]=c[a+36>>2];c[e+4>>2]=c[a+48>>2];a=0;while(1){if((a|0)>=3){break}e=j+(a*52|0)|0;k=e+16|0;l=c[h+(a<<2)>>2]|0;m=c[g+(a<<2)>>2]|0;n=d<<3>>c[e+8>>2];o=b<<3>>c[e+12>>2];e=0;if((e|0)!=0){p=We[c[e+16>>2]&2047](n,e)|0}else{p=n}if((e|0)!=0){q=We[c[e+20>>2]&2047](o,e)|0}else{q=o}c[k>>2]=m+((ca(q,l)|0)+p);c[k+4>>2]=l;a=a+1|0}i=f;return}function Agc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=a;a=b;b=d;d=e;e=f;f=g;if((b|0)==0){i=h;return}g=j|0;c[g>>2]=c[b+52>>2];m=g+4|0;c[m>>2]=c[b+56>>2];g=m+4|0;c[g>>2]=c[b+60>>2];c[g+4>>2]=c[b+64>>2];g=k|0;c[g>>2]=c[b+16>>2];m=g+4|0;c[m>>2]=c[b+36>>2];g=m+4|0;c[g>>2]=c[b+36>>2];c[g+4>>2]=c[b+48>>2];b=0;while(1){if((b|0)>=3){break}g=l+(b*52|0)|0;m=g+24+(a<<3)|0;n=c[k+(b<<2)>>2]|0;o=c[j+(b<<2)>>2]|0;p=e<<3>>c[g+8>>2];q=d<<3>>c[g+12>>2];g=f;if((g|0)!=0){r=We[c[g+16>>2]&2047](p,g)|0}else{r=p}if((g|0)!=0){s=We[c[g+20>>2]&2047](q,g)|0}else{s=q}c[m>>2]=o+((ca(s,n)|0)+r);c[m+4>>2]=n;b=b+1|0}i=h;return}function Bgc(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+8|0;f=e|0;g=c;c=d;d=(b[g+80+(c<<2)>>1]|0)+(b[g+92+(c<<2)>>1]|0)+(b[g+104+(c<<2)>>1]|0)+(b[g+116+(c<<2)>>1]|0)|0;if((d|0)<0){h=d-2|0}else{h=d+2|0}b[f>>1]=(h|0)/4|0;h=f+2|0;d=(b[g+80+(c<<2)+2>>1]|0)+(b[g+92+(c<<2)+2>>1]|0)+(b[g+104+(c<<2)+2>>1]|0)+(b[g+116+(c<<2)+2>>1]|0)|0;if((d|0)<0){j=d-2|0;k=(j|0)/4|0;l=k&65535;b[h>>1]=l;m=a;n=f;b[m>>1]=b[n>>1]|0;b[m+2>>1]=b[n+2>>1]|0;i=e;return}else{j=d+2|0;k=(j|0)/4|0;l=k&65535;b[h>>1]=l;m=a;n=f;b[m>>1]=b[n>>1]|0;b[m+2>>1]=b[n+2>>1]|0;i=e;return}}function Cgc(b,c,d,e,f,g,h,j,k,l){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0;m=i;n=c;c=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=b+(-e|0)+(-(ca(f,n)|0)|0)|0;if((f|0)>=(k|0)){l=l+(ca(k-1|0,n)|0)|0}else{if((f|0)>0){l=l+(ca(f,n)|0)|0}}do{b=0;if((e|0)<0){o=-e|0}else{o=0}p=o;if((p|0)>(g|0)){p=g}if((e+g|0)>(j|0)){b=e+g-j|0}if((b|0)>(g|0)){b=g}q=g-p-b|0;if((p|0)!=0){mrc(c|0,a[l|0]&255|0,p|0)|0}if((q|0)!=0){nrc(c+p|0,l+e+p|0,q)|0}if((b|0)!=0){mrc(c+p+q|0,a[l+(j-1)|0]&255|0,b|0)|0}c=c+d|0;f=f+1|0;do{if((f|0)>0){if((f|0)>=(k|0)){break}l=l+n|0}}while(0);b=h-1|0;h=b;}while((b|0)!=0);i=m;return}function Dgc(a,d,e,f,g,h,j,k,l,m,n){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;o=i;i=i+32|0;p=o|0;q=o+8|0;r=o+16|0;s=o+24|0;t=a;a=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=t+(a*52|0)|0;u=c[c[t+160>>2]>>2]|0;v=(c[u+24>>2]|0)>0|0;w=Tec(c[u+72>>2]|0)|0;x=0;while(1){if((x|0)>=(v+1|0)){break}y=(c[t+188+(x<<2)>>2]|0)+8|0;z=n+24+(x<<3)|0;A=n+16|0;B=(c[A>>2]|0)+(ca(c[A+4>>2]|0,h)|0)+g|0;if((c[u>>2]|0)>>>0<3>>>0){if((a|0)==0){C=p;D=u+76+(d*12|0)+4+(x<<2)|0;b[C>>1]=b[D>>1]|0;b[C+2>>1]=b[D+2>>1]|0}else{Bgc(p,u,x)}}else{D=p;C=u+28+(x<<2)|0;b[D>>1]=b[C>>1]|0;b[D+2>>1]=b[C+2>>1]|0}sgc(q,t,p,e,f,c[n+8>>2]|0,c[n+12>>2]|0);C=y;if((c[C>>2]|0)!=16384){E=1}else{E=(c[C+4>>2]|0)!=16384}if((E&1|0)!=0){C=c[z>>2]|0;D=g;F=h;G=c[z+4>>2]|0;H=y;if((H|0)!=0){I=We[c[H+16>>2]&2047](D,H)|0}else{I=D}if((H|0)!=0){J=We[c[H+20>>2]&2047](F,H)|0}else{J=F}K=C+((ca(J,G)|0)+I)|0;Jhc(s,q,l+g|0,m+h|0,y);G=r;C=s;c[G>>2]=c[C>>2];c[G+4>>2]=c[C+4>>2];L=c[y+8>>2]|0;M=c[y+12>>2]|0}else{K=(c[z>>2]|0)+((ca(h,c[z+4>>2]|0)|0)+g)|0;c[r>>2]=b[q>>1]|0;c[r+4>>2]=b[q+2>>1]|0;M=16;L=16}C=ca(c[r>>2]>>4,c[z+4>>2]|0)|0;K=K+(C+(c[r+4>>2]>>4))|0;rgc(K,c[z+4>>2]|0,B,c[A+4>>2]|0,c[r+4>>2]&15,c[r>>2]&15,y,j,k,x,w,L,M);x=x+1|0}i=o;return}function Egc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;e=i;g=b;b=c;c=4;h=f;f=0;while(1){if((f|0)>=(c-1|0)){break}a[g+(ca(f,b)|0)|0]=(d[h+f|0]|0)+(d[h+(f+1)|0]|0)+1>>1;f=f+1|0}a[g+(ca(c-1|0,b)|0)|0]=a[h+(c-1)|0]|0;g=g+1|0;f=0;while(1){if((f|0)>=(c-2|0)){break}a[g+(ca(f,b)|0)|0]=(d[h+f|0]|0)+((d[h+(f+1)|0]|0)<<1)+(d[h+(f+2)|0]|0)+2>>2;f=f+1|0}a[g+(ca(c-2|0,b)|0)|0]=(d[h+(c-2)|0]|0)+((d[h+(c-1)|0]|0)*3|0)+2>>2;a[g+(ca(c-1|0,b)|0)|0]=a[h+(c-1)|0]|0;g=g+1|0;j=0;while(1){if((j|0)>=(c-2|0)){break}a[g+((ca(c-1|0,b)|0)+j)|0]=a[h+(c-1)|0]|0;j=j+1|0}f=c-2|0;while(1){if((f|0)<0){break}j=0;while(1){if((j|0)>=(c-2|0)){break}a[g+((ca(f,b)|0)+j)|0]=a[g+((ca(f+1|0,b)|0)+j-2)|0]|0;j=j+1|0}f=f-1|0}i=e;return}function Fgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;e=i;g=b;b=c;c=8;h=f;f=0;while(1){if((f|0)>=(c-1|0)){break}a[g+(ca(f,b)|0)|0]=(d[h+f|0]|0)+(d[h+(f+1)|0]|0)+1>>1;f=f+1|0}a[g+(ca(c-1|0,b)|0)|0]=a[h+(c-1)|0]|0;g=g+1|0;f=0;while(1){if((f|0)>=(c-2|0)){break}a[g+(ca(f,b)|0)|0]=(d[h+f|0]|0)+((d[h+(f+1)|0]|0)<<1)+(d[h+(f+2)|0]|0)+2>>2;f=f+1|0}a[g+(ca(c-2|0,b)|0)|0]=(d[h+(c-2)|0]|0)+((d[h+(c-1)|0]|0)*3|0)+2>>2;a[g+(ca(c-1|0,b)|0)|0]=a[h+(c-1)|0]|0;g=g+1|0;j=0;while(1){if((j|0)>=(c-2|0)){break}a[g+((ca(c-1|0,b)|0)+j)|0]=a[h+(c-1)|0]|0;j=j+1|0}f=c-2|0;while(1){if((f|0)<0){break}j=0;while(1){if((j|0)>=(c-2|0)){break}a[g+((ca(f,b)|0)+j)|0]=a[g+((ca(f+1|0,b)|0)+j-2)|0]|0;j=j+1|0}f=f-1|0}i=e;return}function Ggc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;e=i;g=b;b=c;c=16;h=f;f=0;while(1){if((f|0)>=(c-1|0)){break}a[g+(ca(f,b)|0)|0]=(d[h+f|0]|0)+(d[h+(f+1)|0]|0)+1>>1;f=f+1|0}a[g+(ca(c-1|0,b)|0)|0]=a[h+(c-1)|0]|0;g=g+1|0;f=0;while(1){if((f|0)>=(c-2|0)){break}a[g+(ca(f,b)|0)|0]=(d[h+f|0]|0)+((d[h+(f+1)|0]|0)<<1)+(d[h+(f+2)|0]|0)+2>>2;f=f+1|0}a[g+(ca(c-2|0,b)|0)|0]=(d[h+(c-2)|0]|0)+((d[h+(c-1)|0]|0)*3|0)+2>>2;a[g+(ca(c-1|0,b)|0)|0]=a[h+(c-1)|0]|0;g=g+1|0;j=0;while(1){if((j|0)>=(c-2|0)){break}a[g+((ca(c-1|0,b)|0)+j)|0]=a[h+(c-1)|0]|0;j=j+1|0}f=c-2|0;while(1){if((f|0)<0){break}j=0;while(1){if((j|0)>=(c-2|0)){break}a[g+((ca(f,b)|0)+j)|0]=a[g+((ca(f+1|0,b)|0)+j-2)|0]|0;j=j+1|0}f=f-1|0}i=e;return}function Hgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;e=i;g=b;b=c;c=32;h=f;f=0;while(1){if((f|0)>=(c-1|0)){break}a[g+(ca(f,b)|0)|0]=(d[h+f|0]|0)+(d[h+(f+1)|0]|0)+1>>1;f=f+1|0}a[g+(ca(c-1|0,b)|0)|0]=a[h+(c-1)|0]|0;g=g+1|0;f=0;while(1){if((f|0)>=(c-2|0)){break}a[g+(ca(f,b)|0)|0]=(d[h+f|0]|0)+((d[h+(f+1)|0]|0)<<1)+(d[h+(f+2)|0]|0)+2>>2;f=f+1|0}a[g+(ca(c-2|0,b)|0)|0]=(d[h+(c-2)|0]|0)+((d[h+(c-1)|0]|0)*3|0)+2>>2;a[g+(ca(c-1|0,b)|0)|0]=a[h+(c-1)|0]|0;g=g+1|0;j=0;while(1){if((j|0)>=(c-2|0)){break}a[g+((ca(c-1|0,b)|0)+j)|0]=a[h+(c-1)|0]|0;j=j+1|0}f=c-2|0;while(1){if((f|0)<0){break}j=0;while(1){if((j|0)>=(c-2|0)){break}a[g+((ca(f,b)|0)+j)|0]=a[g+((ca(f+1|0,b)|0)+j-2)|0]|0;j=j+1|0}f=f-1|0}i=e;return}function Igc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;g=b;b=c;c=4;h=e;e=0;while(1){if((e|0)>=(c|0)){break}j=0;while(1){if((j|0)>=(c|0)){break}if((e&1|0)!=0){k=(d[h+(((e|0)/2|0)+j)|0]|0)+((d[h+(((e|0)/2|0)+j+1)|0]|0)<<1)+(d[h+(((e|0)/2|0)+j+2)|0]|0)+2>>2}else{k=(d[h+(((e|0)/2|0)+j)|0]|0)+(d[h+(((e|0)/2|0)+j+1)|0]|0)+1>>1}a[g+j|0]=k;j=j+1|0}g=g+b|0;e=e+1|0}i=f;return}function Jgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;g=b;b=c;c=8;h=e;e=0;while(1){if((e|0)>=(c|0)){break}j=0;while(1){if((j|0)>=(c|0)){break}if((e&1|0)!=0){k=(d[h+(((e|0)/2|0)+j)|0]|0)+((d[h+(((e|0)/2|0)+j+1)|0]|0)<<1)+(d[h+(((e|0)/2|0)+j+2)|0]|0)+2>>2}else{k=(d[h+(((e|0)/2|0)+j)|0]|0)+(d[h+(((e|0)/2|0)+j+1)|0]|0)+1>>1}a[g+j|0]=k;j=j+1|0}g=g+b|0;e=e+1|0}i=f;return}function Kgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;g=b;b=c;c=16;h=e;e=0;while(1){if((e|0)>=(c|0)){break}j=0;while(1){if((j|0)>=(c|0)){break}if((e&1|0)!=0){k=(d[h+(((e|0)/2|0)+j)|0]|0)+((d[h+(((e|0)/2|0)+j+1)|0]|0)<<1)+(d[h+(((e|0)/2|0)+j+2)|0]|0)+2>>2}else{k=(d[h+(((e|0)/2|0)+j)|0]|0)+(d[h+(((e|0)/2|0)+j+1)|0]|0)+1>>1}a[g+j|0]=k;j=j+1|0}g=g+b|0;e=e+1|0}i=f;return}function Lgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;g=b;b=c;c=32;h=e;e=0;while(1){if((e|0)>=(c|0)){break}j=0;while(1){if((j|0)>=(c|0)){break}if((e&1|0)!=0){k=(d[h+(((e|0)/2|0)+j)|0]|0)+((d[h+(((e|0)/2|0)+j+1)|0]|0)<<1)+(d[h+(((e|0)/2|0)+j+2)|0]|0)+2>>2}else{k=(d[h+(((e|0)/2|0)+j)|0]|0)+(d[h+(((e|0)/2|0)+j+1)|0]|0)+1>>1}a[g+j|0]=k;j=j+1|0}g=g+b|0;e=e+1|0}i=f;return}function Mgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;g=b;b=c;c=4;h=e;e=0;while(1){if((e|0)>=(c|0)){break}j=0;while(1){if((j|0)>=(c|0)){break}if((e+j+2|0)<(c<<1|0)){k=(d[h+(e+j)|0]|0)+((d[h+(e+j+1)|0]|0)<<1)+(d[h+(e+j+2)|0]|0)+2>>2}else{k=d[h+((c<<1)-1)|0]|0}a[g+j|0]=k;j=j+1|0}g=g+b|0;e=e+1|0}i=f;return}function Ngc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;g=b;b=c;c=8;h=e;e=0;while(1){if((e|0)>=(c|0)){break}j=0;while(1){if((j|0)>=(c|0)){break}if((e+j+2|0)<(c<<1|0)){k=(d[h+(e+j)|0]|0)+((d[h+(e+j+1)|0]|0)<<1)+(d[h+(e+j+2)|0]|0)+2>>2}else{k=d[h+((c<<1)-1)|0]|0}a[g+j|0]=k;j=j+1|0}g=g+b|0;e=e+1|0}i=f;return}function Ogc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;g=b;b=c;c=16;h=e;e=0;while(1){if((e|0)>=(c|0)){break}j=0;while(1){if((j|0)>=(c|0)){break}if((e+j+2|0)<(c<<1|0)){k=(d[h+(e+j)|0]|0)+((d[h+(e+j+1)|0]|0)<<1)+(d[h+(e+j+2)|0]|0)+2>>2}else{k=d[h+((c<<1)-1)|0]|0}a[g+j|0]=k;j=j+1|0}g=g+b|0;e=e+1|0}i=f;return}function Pgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;f=i;g=b;b=c;c=32;h=e;e=0;while(1){if((e|0)>=(c|0)){break}j=0;while(1){if((j|0)>=(c|0)){break}if((e+j+2|0)<(c<<1|0)){k=(d[h+(e+j)|0]|0)+((d[h+(e+j+1)|0]|0)<<1)+(d[h+(e+j+2)|0]|0)+2>>2}else{k=d[h+((c<<1)-1)|0]|0}a[g+j|0]=k;j=j+1|0}g=g+b|0;e=e+1|0}i=f;return}function Qgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=4;j=e;e=f;f=0;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-1)|0]|0)+(d[j+f|0]|0)+1>>1;f=f+1|0}h=h+b|0;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-2)|0]|0)+((d[j+(f-1)|0]|0)<<1)+(d[j+f|0]|0)+2>>2;f=f+1|0}h=h+b|0;a[h]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;j=3;while(1){if((j|0)>=(c|0)){break}a[h+(ca(j-2|0,b)|0)|0]=(d[e+(j-3)|0]|0)+((d[e+(j-2)|0]|0)<<1)+(d[e+(j-1)|0]|0)+2>>2;j=j+1|0}j=2;while(1){if((j|0)>=(c|0)){break}f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=a[h+((b*-2|0)+f-1)|0]|0;f=f+1|0}h=h+b|0;j=j+1|0}i=g;return}function Rgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=8;j=e;e=f;f=0;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-1)|0]|0)+(d[j+f|0]|0)+1>>1;f=f+1|0}h=h+b|0;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-2)|0]|0)+((d[j+(f-1)|0]|0)<<1)+(d[j+f|0]|0)+2>>2;f=f+1|0}h=h+b|0;a[h]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;j=3;while(1){if((j|0)>=(c|0)){break}a[h+(ca(j-2|0,b)|0)|0]=(d[e+(j-3)|0]|0)+((d[e+(j-2)|0]|0)<<1)+(d[e+(j-1)|0]|0)+2>>2;j=j+1|0}j=2;while(1){if((j|0)>=(c|0)){break}f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=a[h+((b*-2|0)+f-1)|0]|0;f=f+1|0}h=h+b|0;j=j+1|0}i=g;return}function Sgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=16;j=e;e=f;f=0;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-1)|0]|0)+(d[j+f|0]|0)+1>>1;f=f+1|0}h=h+b|0;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-2)|0]|0)+((d[j+(f-1)|0]|0)<<1)+(d[j+f|0]|0)+2>>2;f=f+1|0}h=h+b|0;a[h]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;j=3;while(1){if((j|0)>=(c|0)){break}a[h+(ca(j-2|0,b)|0)|0]=(d[e+(j-3)|0]|0)+((d[e+(j-2)|0]|0)<<1)+(d[e+(j-1)|0]|0)+2>>2;j=j+1|0}j=2;while(1){if((j|0)>=(c|0)){break}f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=a[h+((b*-2|0)+f-1)|0]|0;f=f+1|0}h=h+b|0;j=j+1|0}i=g;return}function Tgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=32;j=e;e=f;f=0;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-1)|0]|0)+(d[j+f|0]|0)+1>>1;f=f+1|0}h=h+b|0;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-2)|0]|0)+((d[j+(f-1)|0]|0)<<1)+(d[j+f|0]|0)+2>>2;f=f+1|0}h=h+b|0;a[h]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;j=3;while(1){if((j|0)>=(c|0)){break}a[h+(ca(j-2|0,b)|0)|0]=(d[e+(j-3)|0]|0)+((d[e+(j-2)|0]|0)<<1)+(d[e+(j-1)|0]|0)+2>>2;j=j+1|0}j=2;while(1){if((j|0)>=(c|0)){break}f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=a[h+((b*-2|0)+f-1)|0]|0;f=f+1|0}h=h+b|0;j=j+1|0}i=g;return}function Ugc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=4;j=e;e=f;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-2)|0]|0)+((d[j+(f-1)|0]|0)<<1)+(d[j+f|0]|0)+2>>2;f=f+1|0}a[h+b|0]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;j=2;while(1){if((j|0)>=(c|0)){break}a[h+(ca(j,b)|0)|0]=(d[e+(j-2)|0]|0)+((d[e+(j-1)|0]|0)<<1)+(d[e+j|0]|0)+2>>2;j=j+1|0}h=h+b|0;j=1;while(1){if((j|0)>=(c|0)){break}f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=a[h+((-b|0)+f-1)|0]|0;f=f+1|0}h=h+b|0;j=j+1|0}i=g;return}function Vgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=8;j=e;e=f;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-2)|0]|0)+((d[j+(f-1)|0]|0)<<1)+(d[j+f|0]|0)+2>>2;f=f+1|0}a[h+b|0]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;j=2;while(1){if((j|0)>=(c|0)){break}a[h+(ca(j,b)|0)|0]=(d[e+(j-2)|0]|0)+((d[e+(j-1)|0]|0)<<1)+(d[e+j|0]|0)+2>>2;j=j+1|0}h=h+b|0;j=1;while(1){if((j|0)>=(c|0)){break}f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=a[h+((-b|0)+f-1)|0]|0;f=f+1|0}h=h+b|0;j=j+1|0}i=g;return}function Wgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=16;j=e;e=f;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-2)|0]|0)+((d[j+(f-1)|0]|0)<<1)+(d[j+f|0]|0)+2>>2;f=f+1|0}a[h+b|0]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;j=2;while(1){if((j|0)>=(c|0)){break}a[h+(ca(j,b)|0)|0]=(d[e+(j-2)|0]|0)+((d[e+(j-1)|0]|0)<<1)+(d[e+j|0]|0)+2>>2;j=j+1|0}h=h+b|0;j=1;while(1){if((j|0)>=(c|0)){break}f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=a[h+((-b|0)+f-1)|0]|0;f=f+1|0}h=h+b|0;j=j+1|0}i=g;return}function Xgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=32;j=e;e=f;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=(d[j+(f-2)|0]|0)+((d[j+(f-1)|0]|0)<<1)+(d[j+f|0]|0)+2>>2;f=f+1|0}a[h+b|0]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;j=2;while(1){if((j|0)>=(c|0)){break}a[h+(ca(j,b)|0)|0]=(d[e+(j-2)|0]|0)+((d[e+(j-1)|0]|0)<<1)+(d[e+j|0]|0)+2>>2;j=j+1|0}h=h+b|0;j=1;while(1){if((j|0)>=(c|0)){break}f=1;while(1){if((f|0)>=(c|0)){break}a[h+f|0]=a[h+((-b|0)+f-1)|0]|0;f=f+1|0}h=h+b|0;j=j+1|0}i=g;return}function Ygc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=4;j=e;e=f;a[h]=(d[j-1|0]|0)+(d[e]|0)+1>>1;f=1;while(1){if((f|0)>=(c|0)){break}a[h+(ca(f,b)|0)|0]=(d[e+(f-1)|0]|0)+(d[e+f|0]|0)+1>>1;f=f+1|0}h=h+1|0;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;a[h+b|0]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;f=2;while(1){if((f|0)>=(c|0)){break}a[h+(ca(f,b)|0)|0]=(d[e+(f-2)|0]|0)+((d[e+(f-1)|0]|0)<<1)+(d[e+f|0]|0)+2>>2;f=f+1|0}h=h+1|0;e=0;while(1){if((e|0)>=(c-2|0)){break}a[h+e|0]=(d[j+(e-1)|0]|0)+((d[j+e|0]|0)<<1)+(d[j+(e+1)|0]|0)+2>>2;e=e+1|0}h=h+b|0;f=1;while(1){if((f|0)>=(c|0)){break}e=0;while(1){if((e|0)>=(c-2|0)){break}a[h+e|0]=a[h+((-b|0)+e-2)|0]|0;e=e+1|0}h=h+b|0;f=f+1|0}i=g;return}function Zgc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=8;j=e;e=f;a[h]=(d[j-1|0]|0)+(d[e]|0)+1>>1;f=1;while(1){if((f|0)>=(c|0)){break}a[h+(ca(f,b)|0)|0]=(d[e+(f-1)|0]|0)+(d[e+f|0]|0)+1>>1;f=f+1|0}h=h+1|0;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;a[h+b|0]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;f=2;while(1){if((f|0)>=(c|0)){break}a[h+(ca(f,b)|0)|0]=(d[e+(f-2)|0]|0)+((d[e+(f-1)|0]|0)<<1)+(d[e+f|0]|0)+2>>2;f=f+1|0}h=h+1|0;e=0;while(1){if((e|0)>=(c-2|0)){break}a[h+e|0]=(d[j+(e-1)|0]|0)+((d[j+e|0]|0)<<1)+(d[j+(e+1)|0]|0)+2>>2;e=e+1|0}h=h+b|0;f=1;while(1){if((f|0)>=(c|0)){break}e=0;while(1){if((e|0)>=(c-2|0)){break}a[h+e|0]=a[h+((-b|0)+e-2)|0]|0;e=e+1|0}h=h+b|0;f=f+1|0}i=g;return}function _gc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=16;j=e;e=f;a[h]=(d[j-1|0]|0)+(d[e]|0)+1>>1;f=1;while(1){if((f|0)>=(c|0)){break}a[h+(ca(f,b)|0)|0]=(d[e+(f-1)|0]|0)+(d[e+f|0]|0)+1>>1;f=f+1|0}h=h+1|0;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;a[h+b|0]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;f=2;while(1){if((f|0)>=(c|0)){break}a[h+(ca(f,b)|0)|0]=(d[e+(f-2)|0]|0)+((d[e+(f-1)|0]|0)<<1)+(d[e+f|0]|0)+2>>2;f=f+1|0}h=h+1|0;e=0;while(1){if((e|0)>=(c-2|0)){break}a[h+e|0]=(d[j+(e-1)|0]|0)+((d[j+e|0]|0)<<1)+(d[j+(e+1)|0]|0)+2>>2;e=e+1|0}h=h+b|0;f=1;while(1){if((f|0)>=(c|0)){break}e=0;while(1){if((e|0)>=(c-2|0)){break}a[h+e|0]=a[h+((-b|0)+e-2)|0]|0;e=e+1|0}h=h+b|0;f=f+1|0}i=g;return}function $gc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=c;c=32;j=e;e=f;a[h]=(d[j-1|0]|0)+(d[e]|0)+1>>1;f=1;while(1){if((f|0)>=(c|0)){break}a[h+(ca(f,b)|0)|0]=(d[e+(f-1)|0]|0)+(d[e+f|0]|0)+1>>1;f=f+1|0}h=h+1|0;a[h]=(d[e]|0)+((d[j-1|0]|0)<<1)+(d[j]|0)+2>>2;a[h+b|0]=(d[j-1|0]|0)+((d[e]|0)<<1)+(d[e+1|0]|0)+2>>2;f=2;while(1){if((f|0)>=(c|0)){break}a[h+(ca(f,b)|0)|0]=(d[e+(f-2)|0]|0)+((d[e+(f-1)|0]|0)<<1)+(d[e+f|0]|0)+2>>2;f=f+1|0}h=h+1|0;e=0;while(1){if((e|0)>=(c-2|0)){break}a[h+e|0]=(d[j+(e-1)|0]|0)+((d[j+e|0]|0)<<1)+(d[j+(e+1)|0]|0)+2>>2;e=e+1|0}h=h+b|0;f=1;while(1){if((f|0)>=(c|0)){break}e=0;while(1){if((e|0)>=(c-2|0)){break}a[h+e|0]=a[h+((-b|0)+e-2)|0]|0;e=e+1|0}h=h+b|0;f=f+1|0}i=g;return}function ahc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;d=i;e=a;a=b;b=4;f=c;c=0;while(1){if((c|0)>=(b|0)){break}nrc(e|0,f|0,b)|0;e=e+a|0;c=c+1|0}i=d;return}function bhc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;d=i;e=a;a=b;b=8;f=c;c=0;while(1){if((c|0)>=(b|0)){break}nrc(e|0,f|0,b)|0;e=e+a|0;c=c+1|0}i=d;return}function chc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;d=i;e=a;a=b;b=16;f=c;c=0;while(1){if((c|0)>=(b|0)){break}nrc(e|0,f|0,b)|0;e=e+a|0;c=c+1|0}i=d;return}function dhc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;d=i;e=a;a=b;b=32;f=c;c=0;while(1){if((c|0)>=(b|0)){break}nrc(e|0,f|0,b)|0;e=e+a|0;c=c+1|0}i=d;return}function ehc(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;d=i;f=b;b=c;c=4;g=e;e=0;while(1){if((e|0)>=(c|0)){break}mrc(f|0,a[g+e|0]&255|0,c|0)|0;f=f+b|0;e=e+1|0}i=d;return}function fhc(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;d=i;f=b;b=c;c=8;g=e;e=0;while(1){if((e|0)>=(c|0)){break}mrc(f|0,a[g+e|0]&255|0,c|0)|0;f=f+b|0;e=e+1|0}i=d;return}function ghc(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;d=i;f=b;b=c;c=16;g=e;e=0;while(1){if((e|0)>=(c|0)){break}mrc(f|0,a[g+e|0]&255|0,c|0)|0;f=f+b|0;e=e+1|0}i=d;return}function hhc(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;d=i;f=b;b=c;c=32;g=e;e=0;while(1){if((e|0)>=(c|0)){break}mrc(f|0,a[g+e|0]&255|0,c|0)|0;f=f+b|0;e=e+1|0}i=d;return}function ihc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=b;b=c;c=4;j=e;e=f;f=d[j-1|0]|0;k=0;while(1){if((k|0)>=(c|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}m=(d[e+k|0]|0)+(d[j+l|0]|0)-f|0;if((m|0)>255){n=255}else{if((m|0)<0){o=0}else{o=m}n=o}a[h+l|0]=n;l=l+1|0}h=h+b|0;k=k+1|0}i=g;return}function jhc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=b;b=c;c=8;j=e;e=f;f=d[j-1|0]|0;k=0;while(1){if((k|0)>=(c|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}m=(d[e+k|0]|0)+(d[j+l|0]|0)-f|0;if((m|0)>255){n=255}else{if((m|0)<0){o=0}else{o=m}n=o}a[h+l|0]=n;l=l+1|0}h=h+b|0;k=k+1|0}i=g;return}function khc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=b;b=c;c=16;j=e;e=f;f=d[j-1|0]|0;k=0;while(1){if((k|0)>=(c|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}m=(d[e+k|0]|0)+(d[j+l|0]|0)-f|0;if((m|0)>255){n=255}else{if((m|0)<0){o=0}else{o=m}n=o}a[h+l|0]=n;l=l+1|0}h=h+b|0;k=k+1|0}i=g;return}function lhc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=b;b=c;c=32;j=e;e=f;f=d[j-1|0]|0;k=0;while(1){if((k|0)>=(c|0)){break}l=0;while(1){if((l|0)>=(c|0)){break}m=(d[e+k|0]|0)+(d[j+l|0]|0)-f|0;if((m|0)>255){n=255}else{if((m|0)<0){o=0}else{o=m}n=o}a[h+l|0]=n;l=l+1|0}h=h+b|0;k=k+1|0}i=g;return}function mhc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=i;c=a;a=b;b=4;e=0;while(1){if((e|0)>=(b|0)){break}mrc(c|0,-128|0,b|0)|0;c=c+a|0;e=e+1|0}i=d;return}function nhc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=i;c=a;a=b;b=8;e=0;while(1){if((e|0)>=(b|0)){break}mrc(c|0,-128|0,b|0)|0;c=c+a|0;e=e+1|0}i=d;return}function ohc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=i;c=a;a=b;b=16;e=0;while(1){if((e|0)>=(b|0)){break}mrc(c|0,-128|0,b|0)|0;c=c+a|0;e=e+1|0}i=d;return}function phc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=i;c=a;a=b;b=32;e=0;while(1){if((e|0)>=(b|0)){break}mrc(c|0,-128|0,b|0)|0;c=c+a|0;e=e+1|0}i=d;return}function qhc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;c=i;f=a;a=b;b=4;g=e;e=0;h=0;while(1){if((h|0)>=(b|0)){break}e=e+(d[g+h|0]|0)|0;h=h+1|0}h=(e+(b>>1)|0)/(b|0)|0;e=0;while(1){if((e|0)>=(b|0)){break}mrc(f|0,h&255|0,b|0)|0;f=f+a|0;e=e+1|0}i=c;return}function rhc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;c=i;f=a;a=b;b=8;g=e;e=0;h=0;while(1){if((h|0)>=(b|0)){break}e=e+(d[g+h|0]|0)|0;h=h+1|0}h=(e+(b>>1)|0)/(b|0)|0;e=0;while(1){if((e|0)>=(b|0)){break}mrc(f|0,h&255|0,b|0)|0;f=f+a|0;e=e+1|0}i=c;return}function shc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;c=i;f=a;a=b;b=16;g=e;e=0;h=0;while(1){if((h|0)>=(b|0)){break}e=e+(d[g+h|0]|0)|0;h=h+1|0}h=(e+(b>>1)|0)/(b|0)|0;e=0;while(1){if((e|0)>=(b|0)){break}mrc(f|0,h&255|0,b|0)|0;f=f+a|0;e=e+1|0}i=c;return}function thc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;c=i;f=a;a=b;b=32;g=e;e=0;h=0;while(1){if((h|0)>=(b|0)){break}e=e+(d[g+h|0]|0)|0;h=h+1|0}h=(e+(b>>1)|0)/(b|0)|0;e=0;while(1){if((e|0)>=(b|0)){break}mrc(f|0,h&255|0,b|0)|0;f=f+a|0;e=e+1|0}i=c;return}function uhc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;e=i;f=a;a=b;b=4;g=c;c=0;h=0;while(1){if((h|0)>=(b|0)){break}c=c+(d[g+h|0]|0)|0;h=h+1|0}h=(c+(b>>1)|0)/(b|0)|0;c=0;while(1){if((c|0)>=(b|0)){break}mrc(f|0,h&255|0,b|0)|0;f=f+a|0;c=c+1|0}i=e;return}function vhc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;e=i;f=a;a=b;b=8;g=c;c=0;h=0;while(1){if((h|0)>=(b|0)){break}c=c+(d[g+h|0]|0)|0;h=h+1|0}h=(c+(b>>1)|0)/(b|0)|0;c=0;while(1){if((c|0)>=(b|0)){break}mrc(f|0,h&255|0,b|0)|0;f=f+a|0;c=c+1|0}i=e;return}function whc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;e=i;f=a;a=b;b=16;g=c;c=0;h=0;while(1){if((h|0)>=(b|0)){break}c=c+(d[g+h|0]|0)|0;h=h+1|0}h=(c+(b>>1)|0)/(b|0)|0;c=0;while(1){if((c|0)>=(b|0)){break}mrc(f|0,h&255|0,b|0)|0;f=f+a|0;c=c+1|0}i=e;return}function xhc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;e=i;f=a;a=b;b=32;g=c;c=0;h=0;while(1){if((h|0)>=(b|0)){break}c=c+(d[g+h|0]|0)|0;h=h+1|0}h=(c+(b>>1)|0)/(b|0)|0;c=0;while(1){if((c|0)>=(b|0)){break}mrc(f|0,h&255|0,b|0)|0;f=f+a|0;c=c+1|0}i=e;return}function yhc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=b;b=4;h=c;c=e;e=0;j=b<<1;k=0;while(1){if((k|0)>=(b|0)){break}e=e+(d[h+k|0]|0)|0;e=e+(d[c+k|0]|0)|0;k=k+1|0}k=(e+(j>>1)|0)/(j|0)|0;j=0;while(1){if((j|0)>=(b|0)){break}mrc(g|0,k&255|0,b|0)|0;g=g+a|0;j=j+1|0}i=f;return}function zhc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=b;b=8;h=c;c=e;e=0;j=b<<1;k=0;while(1){if((k|0)>=(b|0)){break}e=e+(d[h+k|0]|0)|0;e=e+(d[c+k|0]|0)|0;k=k+1|0}k=(e+(j>>1)|0)/(j|0)|0;j=0;while(1){if((j|0)>=(b|0)){break}mrc(g|0,k&255|0,b|0)|0;g=g+a|0;j=j+1|0}i=f;return}function Ahc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=b;b=16;h=c;c=e;e=0;j=b<<1;k=0;while(1){if((k|0)>=(b|0)){break}e=e+(d[h+k|0]|0)|0;e=e+(d[c+k|0]|0)|0;k=k+1|0}k=(e+(j>>1)|0)/(j|0)|0;j=0;while(1){if((j|0)>=(b|0)){break}mrc(g|0,k&255|0,b|0)|0;g=g+a|0;j=j+1|0}i=f;return}function Bhc(a,b,c,e){a=a|0;b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=b;b=32;h=c;c=e;e=0;j=b<<1;k=0;while(1){if((k|0)>=(b|0)){break}e=e+(d[h+k|0]|0)|0;e=e+(d[c+k|0]|0)|0;k=k+1|0}k=(e+(j>>1)|0)/(j|0)|0;j=0;while(1){if((j|0)>=(b|0)){break}mrc(g|0,k&255|0,b|0)|0;g=g+a|0;j=j+1|0}i=f;return}function Chc(a,b,d,e,f,g,h,j,k,l,m,n){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0;o=i;p=a;a=b;b=e;e=d-b|0;d=(1<<e)-1|0;if((a>>e|0)!=0){q=1}else{q=(c[p+164>>2]|0)!=0}if((a&d|0)!=0){r=1}else{r=(c[p+168>>2]|0)!=0}if((e|0)>=0){}else{Cd(2279192,2542584,449,2650216)}Dhc(p,g,h,j,k,f,b,q&1,r&1,(a&d|0)!=(d|0)|0,l<<2,m<<2,n);i=o;return}function Dhc(b,e,f,g,h,j,k,l,m,n,o,p,q){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;r=i;i=i+256|0;s=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=q;q=r+16-1&-16;t=(r+104-1&-16)+16|0;u=t;v=4<<j;w=s+(n*52|0)|0;Ehc(6);if((n|0)==0){x=c[c[s+196>>2]>>2]|0;y=c[(c[s+196>>2]|0)+4>>2]|0}else{x=c[(c[s+196>>2]|0)+20>>2]|0;y=c[(c[s+196>>2]|0)+24>>2]|0}n=(-(c[s+172>>2]|0)>>(c[w+8>>2]|0)+3)+o|0;o=(-(c[s+180>>2]|0)>>(c[w+12>>2]|0)+3)+p|0;mrc(q|0,-127|0,64)|0;if((l|0)!=0){if((c[s+184>>2]|0)<0){if((o+v|0)<=(y|0)){z=0;while(1){if((z|0)>=(v|0)){break}a[q+z|0]=a[b+((ca(z,e)|0)-1)|0]|0;z=z+1|0}}else{p=y-o|0;z=0;while(1){if((z|0)>=(p|0)){break}a[q+z|0]=a[b+((ca(z,e)|0)-1)|0]|0;z=z+1|0}while(1){if((z|0)>=(v|0)){break}a[q+z|0]=a[b+((ca(p-1|0,e)|0)-1)|0]|0;z=z+1|0}}}else{z=0;while(1){if((z|0)>=(v|0)){break}a[q+z|0]=a[b+((ca(z,e)|0)-1)|0]|0;z=z+1|0}}}if((k|0)!=0){z=b+(-e|0)|0;if((c[s+176>>2]|0)<0){if((n+(v<<1)|0)<=(x|0)){do{if((m|0)!=0){if((v|0)!=4){A=34;break}nrc(t|0,z|0,v<<1)|0}else{A=34}}while(0);if((A|0)==34){nrc(t|0,z|0,v)|0;mrc(t+v|0,a[t+(v-1)|0]&255|0,v|0)|0}}else{if((n+v|0)<=(x|0)){s=x-n|0;do{if((m|0)!=0){if((v|0)!=4){A=40;break}nrc(t|0,z|0,s)|0;mrc(t+s|0,a[t+(s-1)|0]&255|0,n+(v<<1)-x|0)|0}else{A=40}}while(0);if((A|0)==40){nrc(t|0,z|0,v)|0;mrc(t+v|0,a[t+(v-1)|0]&255|0,v|0)|0}}else{if((n|0)<=(x|0)){s=x-n|0;do{if((m|0)!=0){if((v|0)!=4){A=46;break}nrc(t|0,z|0,s)|0;mrc(t+s|0,a[t+(s-1)|0]&255|0,n+(v<<1)-x|0)|0}else{A=46}}while(0);if((A|0)==46){nrc(t|0,z|0,s)|0;mrc(t+s|0,a[t+(s-1)|0]&255|0,n+(v<<1)-x|0)|0}}}}if((l|0)!=0){B=d[z-1|0]|0}else{B=129}a[t-1|0]=B}else{do{if((v|0)==4){if((m|0)==0){A=58;break}if((l|0)==0){A=58;break}u=z}else{A=58}}while(0);if((A|0)==58){nrc(t|0,z|0,v)|0;do{if((v|0)==4){if((m|0)==0){A=61;break}nrc(t+v|0,z+v|0,v)|0}else{A=61}}while(0);if((A|0)==61){mrc(t+v|0,a[t+(v-1)|0]&255|0,v|0)|0}if((l|0)!=0){C=d[z-1|0]|0}else{C=129}a[t-1|0]=C}}}else{mrc(t|0,127,v<<1|0)|0;a[t-1|0]=127}if((h|0)==0){mf[c[9772184+(l<<5)+(k<<4)+(j<<2)>>2]&2047](f,g,u,q);i=r;return}else{mf[c[5453648+(h<<4)+(j<<2)>>2]&2047](f,g,u,q);i=r;return}}function Ehc(a){a=a|0;var b=0;b=i;if((c[1366888]|0)!=0){i=b;return}ff[a&15]();c[1366888]=1;i=b;return}function Fhc(){c[1363416]=896;c[1363417]=468;c[1363418]=216;c[1363419]=116;c[1363420]=218;c[1363421]=40;c[1363422]=238;c[1363423]=106;c[1363440]=34;c[1363441]=160;c[1363442]=312;c[1363443]=724;c[1363424]=470;c[1363425]=310;c[1363426]=592;c[1363427]=236;c[1363444]=52;c[1363445]=782;c[1363446]=10;c[1363447]=386;c[1363432]=370;c[1363433]=466;c[1363434]=532;c[1363435]=764;c[1363428]=228;c[1363429]=1026;c[1363430]=78;c[1363431]=750;c[1363436]=888;c[1363437]=1024;c[1363438]=986;c[1363439]=2;c[1363448]=578;c[1363449]=400;c[1363450]=220;c[1363451]=372;c[2443046]=810;c[2443047]=1e3;c[2443048]=422;c[2443049]=582;c[2443050]=946;c[2443051]=678;c[2443052]=544;c[2443053]=916;c[2443054]=146;c[2443055]=730;c[2443056]=570;c[2443057]=272;c[2443058]=172;c[2443059]=922;c[2443060]=604;c[2443061]=298;return}function Ghc(){U7b();Hhc(10);return}function Hhc(a){a=a|0;var b=0;b=i;if((c[1366886]|0)!=0){i=b;return}ff[a&15]();c[1366886]=1;i=b;return}function Ihc(){return}function Jhc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;i=i+8|0;j=h|0;k=d;d=g;g=e<<4;e=c[d>>2]|0;l=Erc(g,(g|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=G;e>>14|((e|0)<0|0?-1:0)<<18;g=f<<4;f=c[d+4>>2]|0;m=Erc(g,(g|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=G;f>>14|((f|0)<0|0?-1:0)<<18;g=b[k>>1]|0;n=c[d+4>>2]|0;o=Erc(g,(g|0)<0|0?-1:0,n,(n|0)<0|0?-1:0)|0;n=G;n>>14|((n|0)<0|0?-1:0)<<18;c[j>>2]=(o>>>14|n<<18)+((m>>>14|f<<18)&15);f=b[k+2>>1]|0;k=c[d>>2]|0;d=Erc(f,(f|0)<0|0?-1:0,k,(k|0)<0|0?-1:0)|0;k=G;k>>14|((k|0)<0|0?-1:0)<<18;c[j+4>>2]=(d>>>14|k<<18)+((l>>>14|e<<18)&15);e=a;a=j;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];i=h;return}function Khc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=c[b>>2]|0;b=Erc(e,(e|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=G;a>>14|((a|0)<0|0?-1:0)<<18;i=d;return b>>>14|a<<18|0}function Lhc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=c[b+4>>2]|0;b=Erc(e,(e|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=G;a>>14|((a|0)<0|0?-1:0)<<18;i=d;return b>>>14|a<<18|0}function Mhc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=a;a=b;b=d;d=e;e=f;if((Nhc(a,b,d,e)|0)==0){c[h>>2]=-1;c[h+4>>2]=-1;i=g;return}c[h>>2]=Ohc(a,d)|0;c[h+4>>2]=Ohc(b,e)|0;e=16;b=c[h>>2]|0;d=Erc(e,(e|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;b=G;b>>14|((b|0)<0|0?-1:0)<<18;c[h+8>>2]=d>>>14|b<<18;b=16;d=c[h+4>>2]|0;e=Erc(b,(b|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;d=G;d>>14|((d|0)<0|0?-1:0)<<18;c[h+12>>2]=e>>>14|d<<18;d=h;if((c[d>>2]|0)!=16384){j=1}else{j=(c[d+4>>2]|0)!=16384}if((j&1|0)!=0){c[h+16>>2]=1024;c[h+20>>2]=1022}else{c[h+16>>2]=406;c[h+20>>2]=406}if((c[h+8>>2]|0)==16){if((c[h+12>>2]|0)==16){c[h+24>>2]=34;c[h+28>>2]=40;c[h+32>>2]=8;c[h+36>>2]=54;c[h+40>>2]=62;c[h+44>>2]=80}else{c[h+24>>2]=8;c[h+28>>2]=54;c[h+32>>2]=8;c[h+36>>2]=54;c[h+40>>2]=64;c[h+44>>2]=6}}else{if((c[h+12>>2]|0)==16){c[h+24>>2]=62;c[h+28>>2]=80;c[h+32>>2]=64;c[h+36>>2]=6;c[h+40>>2]=62;c[h+44>>2]=80}else{c[h+24>>2]=64;c[h+28>>2]=6;c[h+32>>2]=64;c[h+36>>2]=6;c[h+40>>2]=64;c[h+44>>2]=6}}c[h+48>>2]=64;c[h+52>>2]=6;i=g;return}function Nhc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=b;b=c;c=d;do{if((b<<1|0)>=(f|0)){if((c<<1|0)<(a|0)){g=0;break}if((b|0)>(f<<4|0)){g=0;break}g=(c|0)<=(a<<4|0)}else{g=0}}while(0);i=e;return g&1|0}function Ohc(a,b){a=a|0;b=b|0;i=i;return(a<<14|0)/(b|0)|0|0}function Phc(a,b){a=a|0;b=b|0;i=i;return a|0}function Qhc(){Rhc(1573360,3345488,4,9344776);Rhc(677888,3344752,4,5357632);Rhc(1644672,3348224,4,9793424);Rhc(1573232,3345360,8,9344512);Rhc(677760,3344624,8,5357368);Rhc(1644544,3348096,8,9793160);Rhc(1575440,3347568,16,9348952);Rhc(677920,3344784,16,5357704);Rhc(1644704,3348256,16,9793496);Rhc(1573392,3345520,32,9344848);return}function Rhc(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=a;a=c;c=d;d=e;e=ca(c,c)|0;b[d>>1]=0;b[d+2>>1]=0;b[a>>1]=Shc(g,c,0)|0;h=1;while(1){if((h|0)>=(e|0)){break}j=b[g+(h<<1)>>1]|0;b[a+(h<<1)>>1]=Shc(g,c,h)|0;k=(j|0)/(c|0)|0;l=(j|0)%(c|0)|0;do{if((k|0)>0){if((l|0)<=0){m=16;break}j=(ca(k-1|0,c)|0)+l|0;n=(ca(k,c)|0)+l-1|0;do{if((g|0)==1644672){m=8}else{if((g|0)==1644544){m=8;break}if((g|0)==1644704){m=8;break}do{if((g|0)==677888){m=12}else{if((g|0)==677760){m=12;break}if((g|0)==677920){m=12;break}b[d+(h<<1<<1)>>1]=j;b[d+((h<<1)+1<<1)>>1]=n}}while(0);if((m|0)==12){m=0;o=n&65535;b[d+((h<<1)+1<<1)>>1]=o;b[d+(h<<1<<1)>>1]=o}}}while(0);if((m|0)==8){m=0;n=j&65535;b[d+((h<<1)+1<<1)>>1]=n;b[d+(h<<1<<1)>>1]=n}}else{m=16}}while(0);if((m|0)==16){m=0;if((k|0)>0){n=(ca(k-1|0,c)|0)+l&65535;b[d+((h<<1)+1<<1)>>1]=n;b[d+(h<<1<<1)>>1]=n}else{if((l|0)>0){}else{Cd(2278640,2542152,354,2652032)}n=(ca(k,c)|0)+l-1&65535;b[d+((h<<1)+1<<1)>>1]=n;b[d+(h<<1<<1)>>1]=n}}if((b[a+(b[d+(h<<1<<1)>>1]<<1)>>1]|0)<(h|0)){}else{Cd(2415368,2542152,358,2652032)}h=h+1|0}b[d+(e<<1<<1)>>1]=0;b[d+((e<<1)+1<<1)>>1]=0;i=f;return}function Shc(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=c;c=d;d=ca(a,a)|0;a=0;while(1){if((a|0)>=(d|0)){g=7;break}if((b[f+(a<<1)>>1]|0)==(c|0)){g=4;break}a=a+1|0}if((g|0)==4){i=e;return a|0}else if((g|0)==7){Cd(2337016,2542152,306,2652672);return 0}return 0}function Thc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;if((d[g|0]|0|0)==0){h=0;j=h&1;i=f;return j|0}h=(c[g+80+(b<<2)>>2]&1<<e|0)!=0;j=h&1;i=f;return j|0}function Uhc(a){a=a|0;var b=0,c=0;b=i;c=a;mrc(c+16|0,0,64)|0;mrc(c+80|0,0,32)|0;i=b;return}function Vhc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+80+(b<<2)|0;c[e>>2]=c[e>>2]|1<<d;i=i;return}function Whc(a){a=a|0;i=i;return c[601904+(a<<2)>>2]|0}function Xhc(a){a=a|0;i=i;return c[601888+(a<<2)>>2]|0}function Yhc(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=a;a=d;d=e;e=f;if((e|0)<=(c[601904+(d<<2)>>2]|0)){}else{Cd(2278440,2541928,54,2650080)}if((e|0)<0){if((c[601888+(d<<2)>>2]|0)!=0){}else{Cd(2415272,2541928,56,2650080)}if((-e|0)<=(c[601904+(d<<2)>>2]|0)){}else{Cd(2336952,2541928,57,2650080)}}b[h+16+(a<<3)+(d<<1)>>1]=e;i=g;return}function Zhc(a,c,d){a=a|0;c=c|0;d=d|0;i=i;return b[a+16+(c<<3)+(d<<1)>>1]|0}function _hc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=b;b=d;d=e;c[g>>2]=$hc(b,c[a+10148>>2]|0,c[a+36976>>2]|0)|0;c[g+4>>2]=$hc(b+1|0,c[a+10148>>2]|0,c[a+36976>>2]|0)|0;c[g+8>>2]=$hc(d,c[a+10156>>2]|0,c[a+36972>>2]|0)|0;c[g+12>>2]=$hc(d+1|0,c[a+10156>>2]|0,c[a+36972>>2]|0)|0;i=f;return}function $hc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=i;e=b;b=(ca(a,(e+7&-8)>>3)|0)>>c<<3;if((b|0)<(e|0)){f=b;i=d;return f|0}else{f=e;i=d;return f|0}return 0}function aic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=b;b=d;d=(a+7&-8)>>3;a=0;g=0;while(1){if((d>>g|0)<4){break}g=g+1|0}g=g-1|0;if((g|0)<0){g=0}while(1){if((64<<a|0)>=(d|0)){break}a=a+1|0}if((a|0)<=(g|0)){h=1;j=h&1;k=a;l=f;c[l>>2]=k;m=g;n=b;c[n>>2]=m;i=e;return}Cd(2278120,2541792,47,2650280);j=h&1;k=a;l=f;c[l>>2]=k;m=g;n=b;c[n>>2]=m;i=e;return}function bic(a){a=a|0;var d=0,e=0;d=i;e=a;a=0;while(1){if((a|0)>=256){break}b[e+256+(a<<4)>>1]=ngc(a,c[e+10172>>2]|0)|0;b[e+256+(a<<4)+2>>1]=ogc(a,0)|0;b[e+4352+(a<<4)>>1]=ngc(a,c[e+10176>>2]|0)|0;b[e+4352+(a<<4)+2>>1]=ogc(a,c[e+10180>>2]|0)|0;a=a+1|0}i=d;return}function cic(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+24|0;g=f|0;h=a;a=b;b=d;d=e;e=h+50480|0;j=h|0;c[g>>2]=a;c[g+4>>2]=b;c[g+8>>2]=0;c[g+12>>2]=e;c[g+16>>2]=26;k=eic(h,g)|0;l=(c[e+10108>>2]|0)==0|0;m=1<<c[e+36976>>2];n=1<<c[e+36972>>2];o=e;p=o+8488+((c[o+10008>>2]|0)*108|0)+16|0;c[j+196>>2]=p;if((k|0)==0){c[d>>2]=a+1;q=0;r=q;i=f;return r|0}do{if((c[h+87528>>2]|0)==0){if((l|0)!=0){break}q=-1;r=q;i=f;return r|0}}while(0);a=a+(V0b(g)|0)|0;if((fic(a,k,b)|0)==0){gic(e|0,7,2277800,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}if((c[e+36976>>2]|c[e+36972>>2]|0)==0){t=(c[e+13380>>2]|0)!=0}else{t=0}c[h+87532>>2]=t&1;do{if((c[h+87532>>2]|0)!=0){if((c[h+87544>>2]|0)!=0){break}c[h+87544>>2]=BYb(32,50528)|0;if((c[h+87544>>2]|0)==0){gic(e|0,2,2541664,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}c[h+87540>>2]=296;do{if((c[h+87500>>2]|0)>1){if(($0b(h+87536|0)|0)!=0){break}gic(e|0,1,2415200,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}}while(0)}}while(0);t=e;g=h|0;o=0;while(1){if((o|0)>=3){break}c[g+(o*52|0)>>2]=g+25824+(o<<13);c[g+50400+(o<<2)>>2]=(c[t+37004>>2]|0)+(ca(o<<1,(c[t+10156>>2]|0)+7&-8)|0);o=o+1|0}c[g+50460>>2]=c[t+37e3>>2];c[g+156>>2]=c[t+10160>>2];if((c[e+36968>>2]|0)!=0){t=e;do{if((c[t+8452>>2]|0)==(c[t+8468>>2]|0)){if((c[t+8456>>2]|0)!=(c[t+8472>>2]|0)){u=0;break}if((c[t+10124>>2]|0)!=0){u=0;break}u=(c[t+10116>>2]|0)!=0}else{u=0}}while(0);if((u&1|0)!=0){v=(c[t+10192>>2]|0)+((c[t+10160>>2]|0)*124|0)+124|0}else{v=0}c[t+10196>>2]=v}else{c[e+10196>>2]=0}hic(e,j,c[e+10168>>2]|0);gec(j,c[e+8476>>2]|0,c[e+8480>>2]|0);nrc(e+13540|0,e+15579+((c[e+23736>>2]|0)*2039|0)|0,2039)|0;mrc(e+23740|0,0,13208)|0;mrc(j+25824|0,0,24576)|0;c[j+25816>>2]=0;c[p+84>>2]=iic(h,a,k)|0;do{if((c[h+87500>>2]|0)>1){if((m|0)!=1){w=38;break}if((n|0)<=1){w=38;break}if((c[e+36964>>2]|0)==0){w=38;break}c[d>>2]=jic(h,a+k|0,b)|0}else{w=38}}while(0);if((w|0)==38){c[d>>2]=kic(h,a+k|0,b)|0}b=p+84|0;c[b>>2]=c[b>>2]|c[j+25816>>2];if((c[h+87528>>2]|0)==0){do{if((l|0)!=0){if((c[p+84>>2]|0)!=0){w=43;break}c[h+87528>>2]=1}else{w=43}}while(0);if((w|0)==43){gic(e|0,7,2336896,(s=i,i=i+1|0,i=i+7&-8,c[s>>2]=0,s)|0);i=s}}do{if((c[e+36960>>2]|0)!=0){w=52}else{if((c[e+36964>>2]|0)!=0){w=52;break}zec(e);s=e;if((c[s+10108>>2]|0)==0){x=1}else{x=(c[s+10124>>2]|0)!=0}if((x&1|0)==0){Fec(e);Pec(e,c[e+10128>>2]|0)}}}while(0);if((w|0)==52){lic(e)}if((c[e+13360>>2]|0)!=0){nrc(e+15579+((c[e+23736>>2]|0)*2039|0)|0,e+13540|0,2039)|0}q=0;r=q;i=f;return r|0}function dic(a){a=a|0;var b=0;b=i;gic(a|0,7,2258616,(a=i,i=i+1|0,i=i+7&-8,c[a>>2]=0,a)|0);i=a;i=b;return}function eic(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=a;a=b;b=e+50480|0;c[b+10104>>2]=c[b+10108>>2];if((X0b(a,2)|0)!=2){gic(b|0,5,2306440,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}c[b+36952>>2]=Qic(a)|0;if((c[b+36952>>2]|0)>>>0>=3>>>0){gic(b|0,5,2298192,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}c[b+10120>>2]=W0b(a)|0;if((c[b+10120>>2]|0)!=0){g=c[b+9784+((X0b(a,3)|0)<<2)>>2]|0;if((c[b+8488+(g*108|0)>>2]|0)<1){gic(b|0,5,2287888,(f=i,i=i+8|0,c[f>>2]=g,f)|0);i=f}h=b+8488|0;j=b+10008|0;k=g;g=c[j>>2]|0;do{if((g|0)>=0){if((c[h+(g*108|0)>>2]|0)<=0){break}l=h+(g*108|0)|0;c[l>>2]=(c[l>>2]|0)-1}}while(0);c[j>>2]=k;j=h+(k*108|0)|0;c[j>>2]=(c[j>>2]|0)+1;c[e+87524>>2]=0;c[b+13380>>2]=0;c[b+10112>>2]=1;m=0;n=m;i=d;return n|0}c[b+10108>>2]=W0b(a)|0;c[b+10112>>2]=W0b(a)|0;c[b+36960>>2]=W0b(a)|0;if((c[b+10108>>2]|0)==0){Ric(b,a);if((c[b+36952>>2]|0)>>>0>1>>>0){j=(W0b(a)|0)!=0;c[b+36956>>2]=j?2:1}c[b+8448>>2]=X0b(a,3)|0;if((c[b+8448>>2]|0)!=7){W0b(a)|0;if((c[b+36952>>2]|0)>>>0>=1>>>0){c[b+8476>>2]=W0b(a)|0;c[b+8480>>2]=W0b(a)|0;W0b(a)|0}else{c[b+8476>>2]=1;c[b+8480>>2]=1}}else{if((c[b+36952>>2]|0)>>>0>=1>>>0){c[b+8476>>2]=0;c[b+8480>>2]=0;W0b(a)|0}else{gic(b|0,5,2283288,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}}c[e+87524>>2]=255;o=0;while(1){if((o|0)>=3){break}c[b+9816+(o<<6)>>2]=c[b+10008>>2];j=b;c[b+9816+(o<<6)+4>>2]=j+8488+((c[j+10008>>2]|0)*108|0)+16;o=o+1|0}Sic(b,a)}else{if((c[b+10112>>2]|0)!=0){p=0}else{p=W0b(a)|0}c[b+10124>>2]=p;if((c[b+36960>>2]|0)!=0){q=0}else{q=X0b(a,2)|0}c[b+10132>>2]=q;if((c[b+10124>>2]|0)!=0){Ric(b,a);c[e+87524>>2]=X0b(a,8)|0;Sic(b,a)}else{c[e+87524>>2]=X0b(a,8)|0;o=0;while(1){if((o|0)>=3){break}q=c[b+9784+((X0b(a,3)|0)<<2)>>2]|0;c[b+9816+(o<<6)>>2]=q;c[b+9816+(o<<6)+4>>2]=b+8488+(q*108|0)+16;c[b+13364+(o+1<<2)>>2]=W0b(a)|0;o=o+1|0}Tic(b,a);c[b+10128>>2]=W0b(a)|0;c[b+10220>>2]=Uic(a)|0;o=0;while(1){if((o|0)>=3){break}q=b+9816+(o<<6)|0;Mhc(q+8|0,c[(c[q+4>>2]|0)+8>>2]|0,c[(c[q+4>>2]|0)+12>>2]|0,c[b+8452>>2]|0,c[b+8456>>2]|0);p=q+8|0;if((c[p>>2]|0)!=16384){r=1}else{r=(c[p+4>>2]|0)!=16384}if((r&1|0)!=0){P7b(c[q+4>>2]|0)}o=o+1|0}}}if((c[b+36960>>2]|0)!=0){c[b+36968>>2]=0;c[b+13360>>2]=0;c[b+36964>>2]=1}else{c[b+36968>>2]=1;c[b+13360>>2]=W0b(a)|0;c[b+36964>>2]=W0b(a)|0}c[b+23736>>2]=X0b(a,2)|0;o=b;if((c[o+10108>>2]|0)==0){s=1}else{s=(c[o+10124>>2]|0)!=0}if((s&1|0)!=0){t=58}else{if((c[b+36960>>2]|0)!=0){t=58}}if((t|0)==58){Iec(b)}Vic(b+13380|0,a);Wic(b,e|0,a);Xic(b+13408|0,a);Yic(b,a);e=X0b(a,16)|0;if((e|0)==0){gic(b|0,7,2279504,(f=i,i=i+1|0,i=i+7&-8,c[f>>2]=0,f)|0);i=f}m=e;n=m;i=d;return n|0}function fic(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=b;if((d|0)!=0){e=d>>>0<=(c-a|0)>>>0}else{e=0}i=i;return e&1|0}function gic(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function hic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a;a=b;b=d;c[a+40>>2]=f+256+(b<<4);d=1;while(1){if((d|0)>=3){break}c[a+(d*52|0)+40>>2]=f+4352+(b<<4);d=d+1|0}i=e;return}function iic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+24|0;f=e|0;g=a;a=g+50480|0;h=a+13540|0;if((Ljc(f,b,d)|0)!=0){gic(a|0,2,2310960,(d=i,i=i+1|0,i=i+7&-8,c[d>>2]=0,d)|0);i=d}if((c[g+25808>>2]|0)!=0){j=0}else{j=Cic(f)|0}c[a+10164>>2]=j;if((c[a+10164>>2]|0)==4){Dic(h+1955|0,f)}Eic(h,c[a+10164>>2]|0,f);j=0;while(1){if((j|0)>=3){break}Djc(f,h+1967+j|0);j=j+1|0}j=a;if((c[j+10108>>2]|0)==0){k=1}else{k=(c[j+10124>>2]|0)!=0}if((k&1|0)!=0){l=Pjc(f)|0;i=e;return l|0}k=h+1970|0;Fic(h,f);if((c[a+10220>>2]|0)==4){Gic(h,f)}j=0;while(1){if((j|0)>=4){break}Djc(f,h+1931+j|0);j=j+1|0}c[a+13536>>2]=Hic(a,f)|0;if((c[a+13536>>2]|0)!=0){Iic(a)}Jic(a,f);g=0;while(1){if((g|0)>=4){break}j=0;while(1){if((j|0)>=9){break}Djc(f,h+(g*9|0)+j|0);j=j+1|0}g=g+1|0}g=0;while(1){if((g|0)>=16){break}j=0;while(1){if((j|0)>=3){break}Djc(f,h+126+(g*3|0)+j|0);j=j+1|0}g=g+1|0}Kic(k,c[a+10128>>2]|0,f);l=Pjc(f)|0;i=e;return l|0}function jic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+792|0;f=e|0;g=e+8|0;h=e+776|0;j=a;c[f>>2]=b;b=d;d=j+50480|0;a=0;k=(c[d+10156>>2]|0)+7&-8;l=1<<c[d+36972>>2];m=1<<c[d+36976>>2];if((c[j+87500>>2]&-2|0)<(l|0)){n=c[j+87500>>2]&-2}else{n=l}o=n;n=-1;if((l|0)<=64){}else{Cd(2452680,2230144,881,2653e3);return 0}if((m|0)==1){}else{Cd(2337064,2230144,882,2653e3);return 0}if((c[j+87560>>2]|0)==0){m=c[j+87500>>2]&-2;c[j+87556>>2]=CYb(m*20|0)|0;if((c[j+87556>>2]|0)==0){gic(d|0,2,2331376,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}q=0;while(1){if((q|0)>=(m|0)){break}r=(c[j+87556>>2]|0)+(q*20|0)|0;s=j+87560|0;c[s>>2]=(c[s>>2]|0)+1;Z0b(r);c[r+8>>2]=BYb(32,101040)|0;if((c[r+8>>2]|0)==0){gic(d|0,2,2325792,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}c[r+12>>2]=CYb(16)|0;if((c[r+12>>2]|0)==0){gic(d|0,2,2319944,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}do{if((q|0)<(m-1|0)){if(($0b(r)|0)!=0){break}gic(d|0,1,2315304,(p=i,i=i+1|0,i=i+7&-8,c[p>>2]=0,p)|0);i=p}}while(0);q=q+1|0}}q=0;while(1){if((q|0)>=(o|0)){break}c[(c[j+87556>>2]|0)+(q*20|0)+4>>2]=628;q=q+1|0}mrc(c[d+37004>>2]|0,0,k*6|0|0)|0;mrc(c[d+37e3>>2]|0,0,k|0)|0;q=0;while(1){if((q|0)>=(l|0)){break}k=mic(b,(q|0)==(l-1|0)|0,d|0,f)|0;p=g+(q*12|0)|0;c[p>>2]=c[f>>2];c[p+4>>2]=k;c[p+8>>2]=q;c[f>>2]=(c[f>>2]|0)+k;q=q+1|0}cd(g|0,l|0,12,450);f=0;while(1){if((f|0)>=(l|0)){break}k=h;p=g+(f*12|0)|0;c[k>>2]=c[p>>2];c[k+4>>2]=c[p+4>>2];c[k+8>>2]=c[p+8>>2];if((f+o|0)<(l|0)){t=f+o|0}else{t=l}p=t-1|0;orc(g+(f*12|0)|0,g+(f*12|0)+12|0,(p-f|0)*12|0|0)|0;k=g+(p*12|0)|0;m=h;c[k>>2]=c[m>>2];c[k+4>>2]=c[m+4>>2];c[k+8>>2]=c[m+8>>2];f=p+1|0}q=0;while(1){if((q|0)>=(l|0)){break}f=0;while(1){if((f|0)<(o|0)){u=(q|0)<(l|0)}else{u=0}if(!u){break}h=(c[j+87556>>2]|0)+(f*20|0)|0;t=c[h+8>>2]|0;p=c[h+12>>2]|0;m=g+(q*12|0)|0;c[t>>2]=d;nrc(t+32|0,j|0,50480)|0;c[t+25848>>2]=0;_hc(p,c[t>>2]|0,0,c[m+8>>2]|0);nic(c[m>>2]|0,b,c[m+4>>2]|0,d|0,t+4|0);p=d;k=t+32|0;r=0;while(1){if((r|0)>=3){break}c[k+(r*52|0)>>2]=k+25824+(r<<13);c[k+50400+(r<<2)>>2]=(c[p+37004>>2]|0)+(ca(r<<1,(c[p+10156>>2]|0)+7&-8)|0);r=r+1|0}c[k+50460>>2]=c[p+37e3>>2];c[k+156>>2]=c[p+10160>>2];mrc(t+25856|0,0,24576)|0;c[h+16>>2]=0;do{if((f|0)==(o-1|0)){v=54}else{if((q|0)==(l-1|0)){v=54;break}b1b(h)}}while(0);if((v|0)==54){v=0;a1b(h)}if((c[m+8>>2]|0)==(l-1|0)){n=f}q=q+1|0;f=f+1|0}while(1){if((f|0)<=0){break}t=((_0b((c[j+87556>>2]|0)+((f-1|0)*20|0)|0)|0)!=0^1)&1;p=j+25816|0;c[p>>2]=c[p>>2]|t;f=f-1|0}if((n|0)>-1){a=Ojc((c[(c[j+87556>>2]|0)+(n*20|0)+8>>2]|0)+4|0)|0;n=-1}}i=e;return a|0}function kic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+3120|0;f=e|0;g=e+8|0;h=e+3080|0;j=e+3104|0;k=a;c[f>>2]=b;b=d;d=k+50480|0;a=(c[d+10156>>2]|0)+7&-8;l=1<<c[d+36972>>2];m=1<<c[d+36976>>2];n=0;if((m|0)<=4){}else{Cd(2465184,2230144,791,2653016);return 0}if((l|0)<=64){}else{Cd(2452680,2230144,792,2653016);return 0}mrc(c[d+37004>>2]|0,0,a*6|0|0)|0;mrc(c[d+37e3>>2]|0,0,a|0)|0;a=0;while(1){if((a|0)>=(m|0)){break}o=0;while(1){if((o|0)>=(l|0)){break}if((a|0)==(m-1|0)){p=(o|0)==(l-1|0)}else{p=0}q=mic(b,p&1,d|0,f)|0;r=g+(a*768|0)+(o*12|0)|0;c[r>>2]=c[f>>2];c[r+4>>2]=q;c[f>>2]=(c[f>>2]|0)+q;o=o+1|0}a=a+1|0}a=0;while(1){if((a|0)>=(m|0)){break}o=0;while(1){if((o|0)>=(l|0)){break}if((c[k+87504>>2]|0)!=0){s=l-o-1|0}else{s=o}f=s;if((a|0)==(m-1|0)){t=(f|0)==(l-1|0)}else{t=0}p=g+(a*768|0)+(f*12|0)|0;_hc(j,d,a,f);nic(c[p>>2]|0,b,c[p+4>>2]|0,d|0,h);oic(k,j,h);if((t&1|0)!=0){n=Ojc(h)|0}o=o+1|0}a=a+1|0}i=e;return n|0}function lic(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+13208|0;d=b|0;e=a;mrc(d|0,0,13208)|0;do{if((c[e+36964>>2]|0)!=0){f=0}else{if((c[e+36960>>2]|0)!=0){f=1;break}Cd(2279368,2230144,1229,2653056)}}while(0);if((grc(e+23740|0,d|0,160)|0)!=0){Cd(2191872,2230144,1231,2653056)}else{}if((grc(e+23900|0,d+160|0,400)|0)!=0){Cd(2161040,2230144,1233,2653056)}else{}if((grc(e+24300|0,d+560|0,256)|0)!=0){Cd(2135664,2230144,1235,2653056)}else{}if((grc(e+24556|0,d+816|0,9216)|0)!=0){Cd(2112248,2230144,1237,2653056)}else{}if((grc(e+33772|0,d+10032|0,2304)|0)!=0){Cd(2630040,2230144,1239,2653056)}else{}if((grc(e+36076|0,d+12336|0,48)|0)!=0){Cd(2605216,2230144,1241,2653056)}else{}if((grc(e+36124|0,d+12384|0,112)|0)!=0){Cd(2579656,2230144,1243,2653056)}else{}if((grc(e+36236|0,d+12496|0,32)|0)!=0){Cd(2559744,2230144,1245,2653056)}else{}if((grc(e+36268|0,d+12528|0,40)|0)!=0){Cd(2542616,2230144,1247,2653056)}else{}if((grc(e+36308|0,d+12568|0,80)|0)!=0){Cd(2525152,2230144,1249,2653056)}else{}if((grc(e+36388|0,d+12648|0,40)|0)!=0){Cd(2509976,2230144,1251,2653056)}else{}if((grc(e+36428|0,d+12688|0,72)|0)!=0){Cd(2496e3,2230144,1252,2653056)}else{}if((grc(e+36500|0,d+12760|0,24)|0)!=0){Cd(2485120,2230144,1253,2653056)}else{}if((grc(e+36524|0,d+12784|0,424)|0)==0){g=1;h=g&1;i=b;return}Cd(2473600,2230144,1254,2653056);h=g&1;i=b;return}function mic(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=a;a=d;d=e;if((b|0)!=0){h=g-(c[d>>2]|0)|0;j=h;i=f;return j|0}if((fic(c[d>>2]|0,4,g)|0)==0){gic(a,7,2363328,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k}h=zic(c[d>>2]|0)|0;b=d;c[b>>2]=(c[b>>2]|0)+4;if(h>>>0>(g-(c[d>>2]|0)|0)>>>0){gic(a,7,2342928,(k=i,i=i+1|0,i=i+7&-8,c[k>>2]=0,k)|0);i=k}j=h;i=f;return j|0}function nic(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=a;a=d;d=e;if((fic(h,a,b)|0)==0){gic(d,7,2363328,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}if((Ljc(f,h,a)|0)==0){i=g;return}gic(d,2,2349616,(j=i,i=i+8|0,c[j>>2]=1,j)|0);i=j;i=g;return}function oic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=a;a=b;b=d;d=c[f+87500>>2]|0;g=f+50480|0;h=f|0;if((c[f+87532>>2]|0)!=0){j=c[f+87544>>2]|0;k=g;c[j>>2]=k+8488+((c[k+10008>>2]|0)*108|0)+16;c[j+4>>2]=g;nrc(j+16|0,f|0,50480)|0;c[j+50500>>2]=0;c[j+50504>>2]=0;zfc(g,c[g+13380>>2]|0)}j=c[a>>2]|0;while(1){if((j|0)>=(c[a+4>>2]|0)){break}mrc(h+50412|0,0,48)|0;mrc(h+50464|0,0,8)|0;k=c[a+8>>2]|0;while(1){if((k|0)>=(c[a+12>>2]|0)){break}pic(g,h,a,j,k,b,12);k=k+8|0}do{if((c[f+87532>>2]|0)!=0){k=j-8|0;l=c[f+87544>>2]|0;if((k|0)<0){break}if((j+8|0)>=(c[a+4>>2]|0)){break}_0b(f+87536|0)|0;c[l+50496>>2]=k;c[l+50500>>2]=j;if((d|0)>1){b1b(f+87536|0)}else{a1b(f+87536|0)}m=18}else{m=18}}while(0);if((m|0)==18){m=0}j=j+8|0}if((c[f+87532>>2]|0)==0){i=e;return}j=c[f+87544>>2]|0;_0b(f+87536|0)|0;c[j+50496>>2]=c[j+50500>>2];c[j+50500>>2]=c[g+10148>>2];a1b(f+87536|0);i=e;return}function pic(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=b;b=d;d=e;e=f;f=g;g=h;h=j;j=(c[777680+(h<<2)>>2]|0)/2|0;do{if((e|0)<(c[l+10148>>2]|0)){if((f|0)>=(c[l+10156>>2]|0)){break}m=qic(l,b,j,e,f,h,g)|0;n=c[552416+(m*52|0)+(h<<2)>>2]|0;if(!(n>>>0<13>>>0)){Cd(2393e3,2399976,248,2652224)}o=n;if(o>>>0<3>>>0){ric(l,b,d,e,f,g,o)}else{n=m;if((n|0)==2){ric(l,b,d,e,f,g,o);if((f+j|0)<(c[l+10156>>2]|0)){ric(l,b,d,e,f+j|0,g,o)}}else if((n|0)==0){ric(l,b,d,e,f,g,o)}else if((n|0)==1){ric(l,b,d,e,f,g,o);if((e+j|0)<(c[l+10148>>2]|0)){ric(l,b,d,e+j|0,f,g,o)}}else if((n|0)==3){pic(l,b,d,e,f,g,o);pic(l,b,d,e,f+j|0,g,o);pic(l,b,d,e+j|0,f,g,o);pic(l,b,d,e+j|0,f+j|0,g,o)}else{Cd(2436392,2230144,440,2653032)}}if(!(h>>>0>=3>>>0)){i=k;return}do{if((h|0)!=3){if((m|0)!=3){break}i=k;return}}while(0);m=b;n=o;p=c[777680+(h<<2)>>2]|0;mrc((c[m+50460>>2]|0)+f|0,a[735216+(n<<1)|0]&255|0,p|0)|0;mrc(m+50464+(e&7)|0,a[735217+(n<<1)|0]&255|0,p|0)|0;i=k;return}}while(0);i=k;return}function qic(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=i;m=b;b=f;f=g;g=h;h=k;k=e;e=j;j=(c[k+50460>>2]|0)+g|0;n=k+50464+(f&7)|0;k=c[830920+(e<<2)>>2]|0;o=1<<k;p=0;q=0;if((c[1960336+(e<<2)>>2]|0)!=(c[1960696+(e<<2)>>2]|0)){Cd(2386208,2379112,329,2651752);return 0}if((k|0)<0){Cd(2373160,2379112,330,2651752);return 0}e=0;while(1){if((e|0)>=(o|0)){break}p=p|a[j+e|0];q=q|a[n+e|0];e=e+1|0}p=(p&o|0)>0|0;q=(q&o|0)>0|0;o=(q<<1)+p+(k<<2)|0;k=m;p=o;if((c[k+10108>>2]|0)==0){r=215328+(p*3|0)|0}else{r=k+13666+(p*3|0)|0}p=r;r=(f+b|0)<(c[m+10148>>2]|0)|0;f=(g+b|0)<(c[m+10156>>2]|0)|0;do{if((r|0)!=0){if((f|0)==0){s=14;break}t=xic(h,207984,p)|0}else{s=14}}while(0);if((s|0)==14){do{if((r|0)!=0){s=17}else{if((f|0)==0){s=17;break}b=(yic(h,d[p+1|0]|0)|0)!=0;t=b?3:1}}while(0);if((s|0)==17){do{if((r|0)!=0){if((f|0)!=0){s=20;break}b=(yic(h,d[p+2|0]|0)|0)!=0;t=b?3:2}else{s=20}}while(0);if((s|0)==20){t=3}}}if((c[m+36964>>2]|0)!=0){u=t;i=l;return u|0}s=m+24300+(o<<4)+(t<<2)|0;c[s>>2]=(c[s>>2]|0)+1;u=t;i=l;return u|0}function ric(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;l=i;i=i+40|0;m=l|0;n=l+16|0;o=l+24|0;p=b;b=e;e=f;f=g;g=h;h=j;j=k;k=j>>>0<3>>>0|0;q=sic(p,b,e,j,f,g)|0;cjc(p,b,e,f,g,h);if((k|0)!=0){j=3}do{if((a[q+12|0]|0)!=0){e=b;r=j;s=0;while(1){if((s|0)>=3){t=9;break}u=e+(s*52|0)|0;v=u;w=c[558424+(r<<4)+(c[v+8>>2]<<3)+(c[v+12>>2]<<2)>>2]|0;if(!(w>>>0<13>>>0)){t=7;break}v=w;mrc(c[u+44>>2]|0,0,c[777792+(v<<2)>>2]|0)|0;mrc(c[u+48>>2]|0,0,c[777848+(v<<2)>>2]|0)|0;s=s+1|0}if((t|0)==7){Cd(2407472,2399976,292,2652344)}else if((t|0)==9){break}}else{if((a[p+13408|0]|0)!=0){hic(p,b,pgc(p+13408|0,d[q+13|0]|0,c[p+10168>>2]|0)|0)}}}while(0);if(((c[q+20>>2]|0)>0|0)==0){c[m>>2]=p;c[m+4>>2]=b;c[m+8>>2]=h;eec(b,j,64,m);x=h;y=Pjc(x)|0;z=b;A=z+25816|0;B=c[A>>2]|0;C=B|y;c[A>>2]=C;i=l;return}uic(p,b,0,f,g);if(((c[q+24>>2]|0)>0|0)!=0){uic(p,b,1,f,g)}xgc(b,f,g,j);if((a[q+12|0]|0)==0){c[n>>2]=0;c[o>>2]=p;c[o+4>>2]=b;c[o+8>>2]=h;c[o+12>>2]=n;eec(b,j,494,o);do{if((k|0)==0){if((c[n>>2]|0)!=0){break}a[q+12|0]=1}}while(0)}x=h;y=Pjc(x)|0;z=b;A=z+25816|0;B=c[A>>2]|0;C=B|y;c[A>>2]=C;i=l;return}function sic(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;j=a;a=b;b=d;d=e;e=f;f=g;g=c[777680+(d<<2)>>2]|0;k=c[777736+(d<<2)>>2]|0;if((g|0)<((c[j+10156>>2]|0)-f|0)){l=g}else{l=(c[j+10156>>2]|0)-f|0}m=l;if((k|0)<((c[j+10148>>2]|0)-e|0)){n=k}else{n=(c[j+10148>>2]|0)-e|0}l=n;n=(ca(e,c[j+10160>>2]|0)|0)+f|0;c[a+160>>2]=(c[j+10204>>2]|0)+(n<<2);c[c[a+160>>2]>>2]=(c[j+10188>>2]|0)+(n*124|0);c[c[c[a+160>>2]>>2]>>2]=d;d=0;while(1){if((d|0)>=(l|0)){break}n=((d|0)!=0^1)&1;while(1){if((n|0)>=(m|0)){break}o=(ca(d,c[j+10160>>2]|0)|0)+n|0;c[(c[a+160>>2]|0)+(o<<2)>>2]=c[c[a+160>>2]>>2];n=n+1|0}d=d+1|0}d=a;m=f<<1;l=e<<1&15;n=0;while(1){if((n|0)>=3){break}o=d+(n*52|0)|0;c[o+44>>2]=(c[d+50400+(n<<2)>>2]|0)+(m>>c[o+8>>2]);c[o+48>>2]=d+50412+(n<<4)+(l>>c[o+12>>2]);n=n+1|0}n=a;l=e;d=f;m=c[j+10148>>2]|0;o=c[j+10156>>2]|0;c[n+180>>2]=-(l<<3<<3);c[n+184>>2]=m-k-l<<3<<3;c[n+172>>2]=-(d<<3<<3);c[n+176>>2]=o-g-d<<3<<3;c[n+164>>2]=(l|0)!=0;c[n+168>>2]=(d|0)>(c[b+8>>2]|0);b=j;zgc(a,b+8488+((c[b+10008>>2]|0)*108|0)+16|0,e,f);i=h;return c[c[a+160>>2]>>2]|0}function tic(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=b;b=d;d=e;e=f;f=g;g=c[f>>2]|0;m=c[f+4>>2]|0;n=m+(l*52|0)|0;o=c[c[m+160>>2]>>2]|0;if((l|0)==0){p=o;if((c[p>>2]|0)>>>0<3>>>0){q=c[p+76+(b*12|0)>>2]|0}else{q=c[p+4>>2]|0}r=q}else{r=c[o+16>>2]|0}q=e;p=(c[1960336+(d<<2)>>2]|0)-q|0;s=b>>(q<<1);c[j>>2]=(s&(1<<p)-1)<<q;c[k>>2]=s>>p<<q;q=ca(c[k>>2]<<2,c[n+20>>2]|0)|0;p=(c[n+16>>2]|0)+(q+(c[j>>2]<<2))|0;Chc(m,b>>(e<<1),c[1960336+(d<<2)>>2]|0,e,r,p,c[n+20>>2]|0,p,c[n+20>>2]|0,c[j>>2]|0,c[k>>2]|0,l);if((a[o+12|0]|0)!=0){i=h;return}o=zjc(g,m,l,b,d,c[j>>2]|0,c[k>>2]|0,e,c[f+8>>2]|0)|0;wic(m,l,b,e,p,c[n+20>>2]|0,o);i=h;return}function uic(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=b;b=d;d=h+9816+((c[(c[c[a+160>>2]>>2]|0)+20+(b<<2)>>2]|0)-1<<6)|0;c[a+188+(b<<2)>>2]=d;j=d+8|0;if((c[j>>2]|0)!=-1){k=(c[j+4>>2]|0)!=-1}else{k=0}if((k&1|0)==0){gic(h|0,5,2415496,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}Agc(a,b,c[d+4>>2]|0,e,f,d+8|0);f=a+25816|0;c[f>>2]=c[f>>2]|c[(c[d+4>>2]|0)+84>>2];i=g;return}function vic(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=a;a=b;b=d;d=e;e=f;f=c[e>>2]|0;l=c[e+4>>2]|0;m=l+(k*52|0)|0;n=d;o=(c[1960336+(b<<2)>>2]|0)-n|0;p=a>>(n<<1);c[h>>2]=(p&(1<<o)-1)<<n;c[j>>2]=p>>o<<n;n=zjc(f,l,k,a,b,c[h>>2]|0,c[j>>2]|0,d,c[e+8>>2]|0)|0;b=ca(c[j>>2]<<2,c[m+20>>2]|0)|0;wic(l,k,a,d,(c[m+16>>2]|0)+(b+(c[h>>2]<<2))|0,c[m+20>>2]|0,n);m=c[e+12>>2]|0;c[m>>2]=(c[m>>2]|0)+n;i=g;return}function wic(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;k=a;a=d;d=e;e=f;f=g;g=h;h=k+(b*52|0)|0;if((g|0)<=0){i=j;return}b=c[h+4>>2]|0;l=(c[h>>2]|0)+(a<<4<<1)|0;h=d;if((h|0)==1){m=c[c[k+160>>2]>>2]|0;do{if((b|0)!=0){n=17}else{if((c[m+20>>2]|0)>0){n=17;break}o=c[1064496+(c[m+4>>2]<<2)>>2]|0}}while(0);if((n|0)==17){o=0}p=o;tfc(p,l,e,f,g)}else if((h|0)==2){o=c[c[k+160>>2]>>2]|0;do{if((b|0)!=0){n=22}else{if((c[o+20>>2]|0)>0){n=22;break}q=c[1064496+(c[o+4>>2]<<2)>>2]|0}}while(0);if((n|0)==22){q=0}p=q;ufc(p,l,e,f,g)}else if((h|0)==3){p=0;rfc(l,e,f,g)}else if((h|0)==0){h=k;q=a;a=c[c[h+160>>2]>>2]|0;do{if((b|0)!=0){n=6}else{if((c[h+25808>>2]|0)!=0){n=6;break}if((c[a+20>>2]|0)>0){n=6;break}o=a;if((c[o>>2]|0)>>>0<3>>>0){r=c[o+76+(q*12|0)>>2]|0}else{r=c[o+4>>2]|0}s=c[1064496+(r<<2)>>2]|0}}while(0);if((n|0)==6){s=0}p=s;if((p|0)==0){mf[c[k+25812>>2]&2047](l,e,f,g)}else{afc(l,e,f,p)}}else{Cd(2426368,2230144,219,2651960)}if((g|0)==1){mrc(l|0,0,4)|0}else{do{if((p|0)==0){if(!(d>>>0<=2>>>0)){n=33;break}if((g|0)>10){n=33;break}mrc(l|0,0,4<<d<<2<<1|0)|0}else{n=33}}while(0);if((n|0)==33){do{if((d|0)==3){if((g|0)>34){n=36;break}mrc(l|0,0,512)|0}else{n=36}}while(0);if((n|0)==36){mrc(l|0,0,16<<(d<<1)<<1|0)|0}}}i=j;return}function xic(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=i;g=b;b=c;c=e;e=0;do{h=a[b+((e<<24>>24)+(yic(g,d[c+(e<<24>>24>>1)|0]|0)|0))|0]|0;e=h;}while((h<<24>>24|0)>0);i=f;return-(e<<24>>24)|0}function yic(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=0;g=((ca(c[f+16>>2]|0,a)|0)+(256-a)|0)>>>8;if((c[f+12>>2]|0)<0){Mjc(f)}a=c[f+8>>2]|0;h=c[f+12>>2]|0;j=g<<24;k=g;if(a>>>0>=j>>>0){k=(c[f+16>>2]|0)-g|0;a=a-j|0;b=1}j=d[211576+k|0]|0;k=k<<j;a=a<<j;h=h-j|0;c[f+8>>2]=a;c[f+12>>2]=h;c[f+16>>2]=k;i=e;return b|0}function zic(a){a=a|0;var b=0;b=a;a=(d[b|0]|0)<<24;a=a|(d[b+1|0]|0)<<16;a=a|(d[b+2|0]|0)<<8;a=a|(d[b+3|0]|0);i=i;return a|0}function Aic(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;b=c[a>>2]|0;while(1){if((b|0)>=(c[a+4>>2]|0)){break}mrc(e+50444|0,0,48)|0;mrc(e+50496|0,0,8)|0;f=c[a+8>>2]|0;while(1){if((f|0)>=(c[a+12>>2]|0)){break}pic(c[e>>2]|0,e+32|0,a,b,f,e+4|0,12);f=f+8|0}b=b+8|0}i=d;return((c[e+25848>>2]|0)!=0^1)&1|0}function Bic(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;if((c[e+4>>2]|0)>>>0<(c[a+4>>2]|0)>>>0){f=1;g=f;i=d;return g|0}if((c[e+4>>2]|0)==(c[a+4>>2]|0)){f=0;g=f;i=d;return g|0}else{f=-1;g=f;i=d;return g|0}return 0}function Cic(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;a=Mic(c,2)|0;if((a|0)!=3){d=a;i=b;return d|0}a=a+(Nic(c)|0)|0;d=a;i=b;return d|0}function Dic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>=2){break}e=0;while(1){if((e|0)>=1){break}Djc(a,d+10+b+e|0);e=e+1|0}b=b+1|0}b=0;while(1){if((b|0)>=2){break}e=0;while(1){if((e|0)>=2){break}Djc(a,d+6+(b<<1)+e|0);e=e+1|0}b=b+1|0}b=0;while(1){if((b|0)>=2){break}e=0;while(1){if((e|0)>=3){break}Djc(a,d+(b*3|0)+e|0);e=e+1|0}b=b+1|0}i=c;return}function Eic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a;a=d;d=c[301584+(b<<2)>>2]|0;b=0;while(1){if(!(b>>>0<=d>>>0)){break}Pic(f+174+(b*432|0)|0,a);b=b+1|0}i=e;return}function Fic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>=7){break}e=0;while(1){if((e|0)>=3){break}Djc(a,d+1910+(b*3|0)+e|0);e=e+1|0}b=b+1|0}i=c;return}function Gic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>=4){break}e=0;while(1){if((e|0)>=2){break}Djc(a,d+1902+(b<<1)+e|0);e=e+1|0}b=b+1|0}i=c;return}function Hic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;d=b;if((Oic(a)|0)==0){e=0;f=e;i=c;return f|0}if((Nic(d)|0)!=0){a=(Nic(d)|0)!=0;g=a?2:1}else{g=0}e=g;f=e;i=c;return f|0}function Iic(a){a=a|0;var b=0,d=0;b=i;d=a;if((c[d+13368>>2]|0)==(c[d+13372>>2]|0)){c[d+13524>>2]=3;c[d+13528>>2]=1;c[d+13532>>2]=2;i=b;return}if((c[d+13368>>2]|0)==(c[d+13376>>2]|0)){c[d+13524>>2]=2;c[d+13528>>2]=1;c[d+13532>>2]=3}else{c[d+13524>>2]=1;c[d+13528>>2]=2;c[d+13532>>2]=3}i=b;return}function Jic(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;b=e+13540|0;if((c[e+13536>>2]|0)==2){f=0;while(1){if((f|0)>=5){break}Djc(a,b+1935+f|0);f=f+1|0}}if((c[e+13536>>2]|0)!=1){f=0;while(1){if((f|0)>=5){break}Djc(a,b+1940+(f<<1)|0);Djc(a,b+1940+(f<<1)+1|0);f=f+1|0}}if((c[e+13536>>2]|0)==0){i=d;return}f=0;while(1){if((f|0)>=5){break}Djc(a,b+1950+f|0);f=f+1|0}i=d;return}function Kic(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=b;b=c;Lic(e|0,3,b);c=0;while(1){if((c|0)>=2){break}f=e+3+(c*33|0)|0;Lic(f|0,1,b);Lic(f+1|0,10,b);Lic(f+11|0,1,b);Lic(f+12|0,10,b);c=c+1|0}c=0;while(1){if((c|0)>=2){break}f=e+3+(c*33|0)|0;g=0;while(1){if((g|0)>=2){break}Lic(f+22+(g*3|0)|0,3,b);g=g+1|0}Lic(f+28|0,3,b);c=c+1|0}if((a|0)==0){i=d;return}c=0;while(1){if((c|0)>=2){break}a=e+3+(c*33|0)|0;Lic(a+31|0,1,b);Lic(a+32|0,1,b);c=c+1|0}i=d;return}function Lic(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=b;b=c;c=d;d=0;while(1){if((d|0)>=(b|0)){break}if((yic(c,252)|0)!=0){a[f+d|0]=(Mic(c,7)|0)<<1|1}d=d+1|0}i=e;return}function Mic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=0;e=b-1|0;while(1){if((e|0)<0){break}a=a|(Nic(d)|0)<<e;e=e-1|0}i=c;return a|0}function Nic(a){a=a|0;var b=0,c=0;b=i;c=yic(a,128)|0;i=b;return c|0}function Oic(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=1;while(1){if((a|0)>=3){e=7;break}if((c[d+13364+(a+1<<2)>>2]|0)!=(c[d+13368>>2]|0)){e=4;break}a=a+1|0}if((e|0)==4){f=1;g=f;i=b;return g|0}else if((e|0)==7){f=0;g=f;i=b;return g|0}return 0}function Pic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=i;d=a;a=b;if((Nic(a)|0)==0){i=c;return}b=0;while(1){if((b|0)>=2){break}e=0;while(1){if((e|0)>=2){break}f=0;while(1){if((f|0)>=6){break}g=0;while(1){if((g|0)>=(((f|0)==0?3:6)|0)){break}h=0;while(1){if((h|0)>=3){break}Djc(a,d+(b*216|0)+(e*108|0)+(f*18|0)+(g*3|0)+h|0);h=h+1|0}g=g+1|0}f=f+1|0}e=e+1|0}b=b+1|0}i=c;return}function Qic(a){a=a|0;var b=0,c=0;b=i;c=a;a=W0b(c)|0;a=a|(W0b(c)|0)<<1;i=b;return a|0}function Ric(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=b;do{if((X0b(a,8)|0)==73){if((X0b(a,8)|0)!=131){break}if((X0b(a,8)|0)!=66){break}i=d;return}}while(0);gic(e|0,5,2262576,(e=i,i=i+1|0,i=i+7&-8,c[e>>2]=0,e)|0);i=e;i=d;return}function Sic(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a;a=b;$ic(a,e,f);ajc(g,c[e>>2]|0,c[f>>2]|0);bjc(g,a);i=d;return}function Tic(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a;a=b;b=0;h=0;while(1){if((h|0)>=3){break}if((W0b(a)|0)!=0){j=4;break}h=h+1|0}if((j|0)==4){j=c[g+9816+(h<<6)+4>>2]|0;c[e>>2]=c[j+8>>2];c[f>>2]=c[j+12>>2];b=1}if((b|0)==0){$ic(a,e,f)}do{if((c[e>>2]|0)>0){if((c[f>>2]|0)<=0){break}k=g;l=c[e>>2]|0;m=c[f>>2]|0;ajc(k,l,m);n=g;o=a;bjc(n,o);i=d;return}}while(0);gic(g|0,7,2275296,(b=i,i=i+1|0,i=i+7&-8,c[b>>2]=0,b)|0);i=b;k=g;l=c[e>>2]|0;m=c[f>>2]|0;ajc(k,l,m);n=g;o=a;bjc(n,o);i=d;return}function Uic(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;if((W0b(d)|0)!=0){e=4;i=b;return e|0}else{e=c[682128+((X0b(d,2)|0)<<2)>>2]|0;i=b;return e|0}return 0}function Vic(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b;b=d;c[f>>2]=X0b(b,6)|0;c[f+4>>2]=X0b(b,3)|0;a[f+13|0]=0;a[f+12|0]=W0b(b)|0;if((a[f+12|0]|0)==0){i=e;return}a[f+13|0]=W0b(b)|0;if((a[f+13|0]|0)!=0){d=0;while(1){if((d|0)>=4){break}if((W0b(b)|0)!=0){a[f+14+d|0]=Y0b(b,6)|0}d=d+1|0}d=0;while(1){if((d|0)>=2){break}if((W0b(b)|0)!=0){a[f+22+d|0]=Y0b(b,6)|0}d=d+1|0}}i=e;return}function Wic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=b;b=d;d=0;c[f+10168>>2]=X0b(b,8)|0;d=d|(_ic(b,f+10172|0)|0);d=d|(_ic(b,f+10176|0)|0);d=d|(_ic(b,f+10180|0)|0);if((d|0)!=0){bic(f)}do{if((c[f+10168>>2]|0)==0){if((c[f+10172>>2]|0)!=0){g=0;break}if((c[f+10176>>2]|0)!=0){g=0;break}g=(c[f+10180>>2]|0)==0}else{g=0}}while(0);c[a+25808>>2]=g&1;c[a+25812>>2]=(c[a+25808>>2]|0)!=0?24:102;i=e;return}function Xic(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=b;b=c;a[e+1|0]=0;a[e+2|0]=0;a[e|0]=W0b(b)|0;if((a[e|0]|0)==0){i=d;return}a[e+1|0]=W0b(b)|0;if((a[e+1|0]|0)!=0){f=0;while(1){if((f|0)>=7){break}if((W0b(b)|0)!=0){g=X0b(b,8)|0}else{g=255}a[e+5+f|0]=g;f=f+1|0}a[e+4|0]=W0b(b)|0;if((a[e+4|0]|0)!=0){f=0;while(1){if((f|0)>=3){break}if((W0b(b)|0)!=0){h=X0b(b,8)|0}else{h=255}a[e+12+f|0]=h;f=f+1|0}}else{f=0;while(1){if((f|0)>=3){break}a[e+12+f|0]=-1;f=f+1|0}}}a[e+2|0]=W0b(b)|0;if((a[e+2|0]|0)==0){i=d;return}a[e+3|0]=W0b(b)|0;Uhc(e);f=0;while(1){if((f|0)>=8){break}h=0;while(1){if((h|0)>=4){break}g=0;if((W0b(b)|0)!=0){Vhc(e,f,h);g=Zic(b,Whc(h)|0)|0;if((Xhc(h)|0)!=0){if((W0b(b)|0)!=0){j=-g|0}else{j=g}g=j}}Yhc(e,f,h,g);h=h+1|0}f=f+1|0}i=d;return}function Yic(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a;a=b;aic(c[g+10156>>2]|0,e,f);b=(c[f>>2]|0)-(c[e>>2]|0)|0;c[g+36972>>2]=c[e>>2];while(1){e=b;b=e-1|0;if((e|0)!=0){h=(W0b(a)|0)!=0}else{h=0}if(!h){break}e=g+36972|0;c[e>>2]=(c[e>>2]|0)+1}c[g+36976>>2]=W0b(a)|0;if((c[g+36976>>2]|0)==0){i=d;return}h=W0b(a)|0;a=g+36976|0;c[a>>2]=(c[a>>2]|0)+h;i=d;return}function Zic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=i;d=b;b=d;if(b>>>0>0>>>0){e=(31^(rrc(b|0)|0))+1|0}else{e=0}b=X0b(a,e)|0;if((b|0)>(d|0)){f=d;i=c;return f|0}else{f=b;i=c;return f|0}return 0}function _ic(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;b=c[a>>2]|0;if((W0b(e)|0)!=0){f=Y0b(e,4)|0}else{f=0}c[a>>2]=f;i=d;return(b|0)!=(c[a>>2]|0)|0}function $ic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=(X0b(f,16)|0)+1|0;g=(X0b(f,16)|0)+1|0;c[b>>2]=a;c[d>>2]=g;i=e;return}function ajc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;if((c[f+8452>>2]|0)!=(a|0)){g=3}else{if((c[f+8456>>2]|0)!=(b|0)){g=3}}if((g|0)==3){if((a|0)>(c[f+8452>>2]|0)){g=5}else{if((b|0)>(c[f+8456>>2]|0)){g=5}}if((g|0)==5){if((Udc(f,a,b)|0)!=0){gic(f|0,2,2270504,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h}}c[f+8452>>2]=a;c[f+8456>>2]=b;_dc(f)}b=f;if((L7b(b+8488+((c[b+10008>>2]|0)*108|0)+16|0,c[f+8452>>2]|0,c[f+8456>>2]|0,c[f+8476>>2]|0,c[f+8480>>2]|0,32,f+8488+((c[f+10008>>2]|0)*108|0)+4|0,c[f+36984>>2]|0,c[f+36980>>2]|0)|0)==0){i=e;return}gic(f|0,2,2266e3,(h=i,i=i+1|0,i=i+7&-8,c[h>>2]=0,h)|0);i=h;i=e;return}function bjc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=b;c[e+8460>>2]=c[e+8452>>2];c[e+8464>>2]=c[e+8456>>2];if((W0b(a)|0)==0){i=d;return}$ic(a,e+8460|0,e+8464|0);i=d;return}function cjc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;j=a;a=b;b=e;e=f;f=g;g=j;if((c[g+10108>>2]|0)==0){k=1}else{k=(c[g+10124>>2]|0)!=0}if((k&1|0)!=0){djc(j,a,b,e,f);i=h;return}else{ejc(j,a,d,b,e,f);i=h;return}}function djc(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;k=b;b=e;e=h;h=c[c[b+160>>2]>>2]|0;l=h|0;m=c[(c[b+160>>2]|0)+(-(c[k+10160>>2]|0)<<2)>>2]|0;if((c[b+168>>2]|0)!=0){n=c[(c[b+160>>2]|0)-4>>2]|0}else{n=0}o=n;n=c[l>>2]|0;a[l+13|0]=yjc(k,b,f,g,e)|0;a[l+12|0]=gjc(k,b,d[l+13|0]|0,e)|0;c[l+8>>2]=ijc(k,b,c[k+10164>>2]|0,n,1,e)|0;c[l+20>>2]=0;c[l+24>>2]=-1;k=n;if((k|0)==0){n=0;while(1){if((n|0)>=4){break}b=h;g=n;f=cec(b,m,g)|0;c[h+76+(n*12|0)>>2]=njc(e,214328+(f*90|0)+((bec(b,o,g)|0)*9|0)|0)|0;n=n+1|0}c[l+4>>2]=c[h+112>>2];p=e;q=l;r=q+4|0;s=c[r>>2]|0;t=215232+(s*9|0)|0;u=t|0;v=njc(p,u)|0;w=l;x=w+16|0;c[x>>2]=v;i=j;return}else if((k|0)==2){n=h;g=0;b=cec(n,m,g)|0;f=njc(e,214328+(b*90|0)+((bec(n,o,g)|0)*9|0)|0)|0;c[h+88>>2]=f;c[h+76>>2]=f;f=h;g=2;n=cec(f,m,g)|0;b=njc(e,214328+(n*90|0)+((bec(f,o,g)|0)*9|0)|0)|0;c[l+4>>2]=b;c[h+112>>2]=b;c[h+100>>2]=b;p=e;q=l;r=q+4|0;s=c[r>>2]|0;t=215232+(s*9|0)|0;u=t|0;v=njc(p,u)|0;w=l;x=w+16|0;c[x>>2]=v;i=j;return}else if((k|0)==1){k=h;b=0;g=cec(k,m,b)|0;f=njc(e,214328+(g*90|0)+((bec(k,o,b)|0)*9|0)|0)|0;c[h+100>>2]=f;c[h+76>>2]=f;f=h;b=1;k=cec(f,m,b)|0;g=njc(e,214328+(k*90|0)+((bec(f,o,b)|0)*9|0)|0)|0;c[l+4>>2]=g;c[h+112>>2]=g;c[h+88>>2]=g;p=e;q=l;r=q+4|0;s=c[r>>2]|0;t=215232+(s*9|0)|0;u=t|0;v=njc(p,u)|0;w=l;x=w+16|0;c[x>>2]=v;i=j;return}else{g=h;h=0;b=cec(g,m,h)|0;c[l+4>>2]=njc(e,214328+(b*90|0)+((bec(g,o,h)|0)*9|0)|0)|0;p=e;q=l;r=q+4|0;s=c[r>>2]|0;t=215232+(s*9|0)|0;u=t|0;v=njc(p,u)|0;w=l;x=w+16|0;c[x>>2]=v;i=j;return}}function ejc(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0;k=i;l=b;b=e;e=g;g=h;h=j;j=c[c[b+160>>2]>>2]|0;m=j|0;c[m+28>>2]=0;c[m+32>>2]=0;a[m+13|0]=fjc(l,b,e,g,h)|0;a[m+12|0]=gjc(l,b,d[m+13|0]|0,h)|0;n=hjc(l,b,d[m+13|0]|0,h)|0;if((a[m+12|0]|0)!=0){o=(n|0)!=0^1}else{o=1}c[m+8>>2]=ijc(l,b,c[l+10164>>2]|0,c[m>>2]|0,o&1,h)|0;if((n|0)!=0){jjc(l,b,f,j,e,g,h);i=k;return}else{kjc(l,j,h);i=k;return}}function fjc(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;k=b;b=e;e=f;f=g;g=h;h=k+13408|0;l=c[c[b+160>>2]>>2]|0;m=c[l>>2]|0;if((a[h|0]|0)==0){n=0;o=n;i=j;return o|0}p=jgc(k,c[k+10216>>2]|0,m,e,f)|0;if((a[h+1|0]|0)==0){n=p;o=n;i=j;return o|0}if((a[h+4|0]|0)!=0){q=b;b=q;if((c[b+164>>2]|0)!=0){r=c[(c[b+160>>2]|0)+(-(c[b+156>>2]|0)<<2)>>2]|0}else{r=0}b=r;r=q;if((c[r+168>>2]|0)!=0){s=c[(c[r+160>>2]|0)-4>>2]|0}else{s=0}r=s;if((b|0)!=0){t=d[b+14|0]|0}else{t=0}if((r|0)!=0){u=d[r+14|0]|0}else{u=0}a[l+14|0]=pjc(g,d[h+12+(t+u)|0]|0)|0;if((d[l+14|0]|0)!=0){v=p}else{v=wjc(g,h)|0}w=v}else{w=wjc(g,h)|0}xjc(k,m,e,f,w);n=w;o=n;i=j;return o|0}function gjc(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=a;if((Thc(h+13408|0,e,3)|0)!=0){j=1;k=j;i=g;return k|0}e=b;b=e;if((c[b+164>>2]|0)!=0){l=c[(c[b+160>>2]|0)+(-(c[b+156>>2]|0)<<2)>>2]|0}else{l=0}b=l;l=e;if((c[l+168>>2]|0)!=0){m=c[(c[l+160>>2]|0)-4>>2]|0}else{m=0}l=m;if((b|0)!=0){n=d[b+12|0]|0}else{n=0}if((l|0)!=0){o=d[l+12|0]|0}else{o=0}l=n+o|0;o=pjc(f,d[h+15507+l|0]|0)|0;if((c[h+36964>>2]|0)==0){f=h+36500+(l<<3)+(o<<2)|0;c[f>>2]=(c[f>>2]|0)+1}j=o;k=j;i=g;return k|0}function hjc(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=e;if((Thc(h+13408|0,a,2)|0)!=0){j=(Zhc(h+13408|0,a,2)|0)!=0|0;k=j;i=g;return k|0}a=dgc(b)|0;b=pjc(f,d[h+15471+a|0]|0)|0;if((c[h+36964>>2]|0)==0){f=h+36236+(a<<3)+(b<<2)|0;c[f>>2]=(c[f>>2]|0)+1}j=b;k=j;i=g;return k|0}function ijc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=a;a=b;b=d;d=e;e=g;g=c[833024+(d<<2)>>2]|0;do{if((f|0)!=0){if((b|0)!=4){break}if(!(d>>>0>=3>>>0)){break}k=vjc(j,a,g,e)|0;l=k;i=h;return l|0}}while(0);if(g>>>0<(c[301584+(b<<2)>>2]|0)>>>0){m=g}else{m=c[301584+(b<<2)>>2]|0}k=m;l=k;i=h;return l|0}function jjc(a,e,f,g,h,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;l=i;i=i+56|0;m=l|0;n=l+8|0;o=l+16|0;p=l+24|0;q=l+32|0;r=l+40|0;s=l+48|0;t=a;a=e;e=f;f=g;g=h;h=j;j=k;k=f|0;u=c[k>>2]|0;v=c[t+10128>>2]|0;qjc(t,a,j,d[k+13|0]|0,k+20|0);w=(c[k+24>>2]|0)>0|0;x=0;while(1){if((x|0)>=(w+1|0)){break}y=c[k+20+(x<<2)>>2]|0;Yfc(t,a,e,f,y,k+36+(y<<3)|0,g,h);x=x+1|0}y=d[k+68+(c[k+20>>2]|0)|0]|0;do{if((Thc(t+13408|0,d[k+13|0]|0,3)|0)!=0){c[k+4>>2]=12;if(!(u>>>0<3>>>0)){break}rjc(t|0,5,2274864,(z=i,i=i+1|0,i=i+7&-8,c[z>>2]=0,z)|0);i=z;i=l;return}else{if(u>>>0>=3>>>0){c[k+4>>2]=sjc(t,j,y)|0}}}while(0);if(u>>>0<3>>>0){A=14}else{if((c[k+4>>2]|0)!=12){A=14}}if((A|0)==14){x=0;while(1){if((x|0)>=(w+1|0)){break}_fc(a,v,k+36+(c[k+20+(x<<2)>>2]<<3)|0,o+(x<<2)|0,p+(x<<2)|0);x=x+1|0}}if((c[t+10220>>2]|0)==4){z=t;B=cgc(a)|0;C=ojc(j,202680,z+15442+(B<<1)|0)|0;if((c[z+36964>>2]|0)==0){D=z+36076+(B*12|0)+(C<<2)|0;c[D>>2]=(c[D>>2]|0)+1}E=C}else{E=c[t+10220>>2]|0}c[k+72>>2]=E;if(!(u>>>0<3>>>0)){E=t;C=k+28|0;D=o|0;B=o|0;z=p|0;p=w;F=v;G=j;H=1;I=c[k+4>>2]|0;if((I|0)==13){if((c[E+36964>>2]|0)!=0){J=0}else{J=E+36524|0}K=J;J=0;while(1){if((J|0)>=(p+1|0)){break}L=G;M=C+(J<<2)|0;N=D+(J<<2)|0;O=E+15510|0;P=ojc(L,211840,O|0)|0;if((F|0)!=0){Q=(Lec(N)|0)!=0}else{Q=0}R=Q&1;mrc(n|0,0,4)|0;S=P;if((S|0)==2){T=1}else{T=(S|0)==3}if(T){b[n>>1]=tjc(L,O+3|0,R)|0}S=P;if((S|0)==1){U=1}else{U=(S|0)==3}if(U){b[n+2>>1]=tjc(L,O+36|0,R)|0}Nec(n,K);b[M>>1]=(b[N>>1]|0)+(b[n>>1]|0);b[M+2>>1]=(b[N+2>>1]|0)+(b[n+2>>1]|0);if((H|0)!=0){N=C+(J<<2)|0;do{if((b[N>>1]|0)>-16384){if((b[N>>1]|0)>=16383){V=0;break}if(!((b[N+2>>1]|0)>-16384)){V=0;break}V=(b[N+2>>1]|0)<16383}else{V=0}}while(0);W=V}else{W=0}H=W&1;J=J+1|0}A=118}else if((I|0)==11){c[C>>2]=c[z>>2];if((p|0)!=0){c[C+4>>2]=c[z+4>>2]}A=118}else if((I|0)==10){c[C>>2]=c[B>>2];if((p|0)!=0){c[C+4>>2]=c[B+4>>2]}A=118}else if((I|0)==12){c[C>>2]=0;if((p|0)!=0){c[C+4>>2]=0}A=118}else{X=0}if((A|0)==118){X=H}H=a+25816|0;c[H>>2]=c[H>>2]|((X|0)!=0^1)&1;i=l;return}X=c[777792+(u<<2)>>2]|0;H=c[777848+(u<<2)>>2]|0;u=0;while(1){if((u|0)>=2){break}C=0;while(1){if((C|0)>=2){break}p=(u<<1)+C|0;Y=sjc(t,j,y)|0;if((Y|0)==10){A=31}else{if((Y|0)==11){A=31}}if((A|0)==31){A=0;x=0;while(1){if((x|0)>=(w+1|0)){break}agc(t,a,e,p,x,g,h,q+(x<<2)|0,r+(x<<2)|0);x=x+1|0}}I=t;B=s|0;z=o|0;J=q|0;W=r|0;V=w;n=v;K=j;U=1;T=Y;if((T|0)==10){c[B>>2]=c[J>>2];if((V|0)!=0){c[B+4>>2]=c[J+4>>2]}A=70}else if((T|0)==12){c[B>>2]=0;if((V|0)!=0){c[B+4>>2]=0}A=70}else if((T|0)==13){if((c[I+36964>>2]|0)!=0){Z=0}else{Z=I+36524|0}J=Z;Q=0;while(1){if((Q|0)>=(V+1|0)){break}F=K;E=B+(Q<<2)|0;D=z+(Q<<2)|0;G=I+15510|0;N=ojc(F,211840,G|0)|0;if((n|0)!=0){_=(Lec(D)|0)!=0}else{_=0}M=_&1;mrc(m|0,0,4)|0;R=N;if((R|0)==2){$=1}else{$=(R|0)==3}if($){b[m>>1]=tjc(F,G+3|0,M)|0}R=N;if((R|0)==1){aa=1}else{aa=(R|0)==3}if(aa){b[m+2>>1]=tjc(F,G+36|0,M)|0}Nec(m,J);b[E>>1]=(b[D>>1]|0)+(b[m>>1]|0);b[E+2>>1]=(b[D+2>>1]|0)+(b[m+2>>1]|0);if((U|0)!=0){D=B+(Q<<2)|0;do{if((b[D>>1]|0)>-16384){if((b[D>>1]|0)>=16383){ba=0;break}if(!((b[D+2>>1]|0)>-16384)){ba=0;break}ba=(b[D+2>>1]|0)<16383}else{ba=0}}while(0);ca=ba}else{ca=0}U=ca&1;Q=Q+1|0}A=70}else if((T|0)==11){c[B>>2]=c[W>>2];if((V|0)!=0){c[B+4>>2]=c[W+4>>2]}A=70}else{da=0}if((A|0)==70){A=0;da=U}if((da|0)==0){A=72;break}c[f+76+(p*12|0)+4>>2]=c[s>>2];if((w|0)!=0){c[f+76+(p*12|0)+8>>2]=c[s+4>>2]}if((H|0)==2){Q=f+76+((p+2|0)*12|0)|0;J=f+76+(p*12|0)|0;c[Q>>2]=c[J>>2];c[Q+4>>2]=c[J+4>>2];c[Q+8>>2]=c[J+8>>2]}if((X|0)==2){J=f+76+((p+1|0)*12|0)|0;Q=f+76+(p*12|0)|0;c[J>>2]=c[Q>>2];c[J+4>>2]=c[Q+4>>2];c[J+8>>2]=c[Q+8>>2]}C=C+X|0}if((A|0)==72){A=0;C=a+25816|0;c[C>>2]=c[C>>2]|1}u=u+H|0}c[f+4>>2]=Y;c[k+28>>2]=c[f+116>>2];c[k+32>>2]=c[f+120>>2];i=l;return}function kjc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a;a=b;b=d;d=a|0;g=c[a>>2]|0;c[d+20>>2]=0;c[d+24>>2]=-1;h=g;if((h|0)==1){j=ljc(f,b,0)|0;c[a+100>>2]=j;c[a+76>>2]=j;j=ljc(f,b,0)|0;c[d+4>>2]=j;c[a+112>>2]=j;c[a+88>>2]=j}else if((h|0)==0){j=0;while(1){if((j|0)>=4){break}c[a+76+(j*12|0)>>2]=ljc(f,b,0)|0;j=j+1|0}c[d+4>>2]=c[a+112>>2]}else if((h|0)==2){h=ljc(f,b,0)|0;c[a+88>>2]=h;c[a+76>>2]=h;h=ljc(f,b,0)|0;c[d+4>>2]=h;c[a+112>>2]=h;c[a+100>>2]=h}else{c[d+4>>2]=ljc(f,b,c[564816+(g<<2)>>2]|0)|0}c[d+16>>2]=mjc(f,b,c[d+4>>2]|0)|0;i=e;return}function ljc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=d;d=njc(b,f+13540+(a*9|0)|0)|0;if((c[f+36964>>2]|0)!=0){g=d;i=e;return g|0}b=f+23740+(a*40|0)+(d<<2)|0;c[b>>2]=(c[b>>2]|0)+1;g=d;i=e;return g|0}function mjc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=d;d=njc(b,f+13576+(a*9|0)|0)|0;if((c[f+36964>>2]|0)!=0){g=d;i=e;return g|0}b=f+23900+(a*40|0)+(d<<2)|0;c[b>>2]=(c[b>>2]|0)+1;g=d;i=e;return g|0}function njc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=ojc(a,215456,b)|0;i=c;return d|0}function ojc(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0;f=i;g=b;b=c;c=e;e=0;do{h=a[b+((e<<24>>24)+(pjc(g,d[c+(e<<24>>24>>1)|0]|0)|0))|0]|0;e=h;}while((h<<24>>24|0)>0);i=f;return-(e<<24>>24)|0}function pjc(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=0;g=((ca(c[f+16>>2]|0,a)|0)+(256-a)|0)>>>8;if((c[f+12>>2]|0)<0){Mjc(f)}a=c[f+8>>2]|0;h=c[f+12>>2]|0;j=g<<24;k=g;if(a>>>0>=j>>>0){k=(c[f+16>>2]|0)-g|0;a=a-j|0;b=1}j=d[211576+k|0]|0;k=k<<j;a=a<<j;h=h-j|0;c[f+8>>2]=a;c[f+12>>2]=h;c[f+16>>2]=k;i=e;return b|0}function qjc(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;j=a;a=b;b=e;e=f;f=g;g=j+13540|0;k=j+23740|0;if((Thc(j+13408|0,e,2)|0)!=0){c[f>>2]=Zhc(j+13408|0,e,2)|0;c[f+4>>2]=-1;i=h;return}e=ujc(j,a,b)|0;if((e|0)==1){l=c[j+13364+(c[j+13524>>2]<<2)>>2]|0;m=fgc(j,a)|0;n=pjc(b,d[g+1950+m|0]|0)|0;if((c[j+36964>>2]|0)==0){o=k+12648+(m<<3)+(n<<2)|0;c[o>>2]=(c[o>>2]|0)+1}c[f+(l<<2)>>2]=c[j+13524>>2];c[f+((((l|0)!=0^1)&1)<<2)>>2]=c[j+13528+(n<<2)>>2]}else{if((e|0)!=0){Cd(2541024,2414848,311,2651448)}e=ggc(a)|0;n=pjc(b,d[g+1940+(e<<1)|0]|0)|0;if((c[j+36964>>2]|0)==0){l=k+12568+(e<<4)+(n<<2)|0;c[l>>2]=(c[l>>2]|0)+1}if((n|0)!=0){n=hgc(a)|0;a=pjc(b,d[g+1940+(n<<1)+1|0]|0)|0;if((c[j+36964>>2]|0)==0){j=k+12568+(n<<4)+8+(a<<2)|0;c[j>>2]=(c[j>>2]|0)+1}c[f>>2]=(a|0)!=0?3:2}else{c[f>>2]=1}c[f+4>>2]=-1}i=h;return}function rjc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function sjc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=d;d=ojc(b,215488,f+15450+(a*3|0)|0)|0;if((c[f+36964>>2]|0)!=0){g=d;h=g+10|0;i=e;return h|0}b=f+36124+(a<<4)+(d<<2)|0;c[b>>2]=(c[b>>2]|0)+1;g=d;h=g+10|0;i=e;return h|0}function tjc(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=a;a=b;b=c;c=pjc(f,d[a|0]|0)|0;g=ojc(f,211888,a+1|0)|0;h=(g|0)==0|0;if((h|0)!=0){j=ojc(f,211912,a+11|0)|0}else{k=g+1-1|0;j=0;l=0;while(1){if((l|0)>=(k|0)){break}j=j|(pjc(f,d[a+12+l|0]|0)|0)<<l;l=l+1|0}}if((h|0)!=0){m=a+22+(j*3|0)|0}else{m=a+28|0}l=ojc(f,211856,m)|0;if((b|0)!=0){if((h|0)!=0){n=d[a+31|0]|0}else{n=d[a+32|0]|0}o=pjc(f,n)|0}else{o=1}n=(Mec(g,j<<3|l<<1|o)|0)+1|0;if((c|0)!=0){p=-n|0;i=e;return p|0}else{p=n;i=e;return p|0}return 0}function ujc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=a;if((c[g+13536>>2]|0)!=2){h=c[g+13536>>2]|0;j=h;i=f;return j|0}a=egc(g,b)|0;b=pjc(e,d[g+15475+a|0]|0)|0;if((c[g+36964>>2]|0)==0){e=g+36268+(a<<3)+(b<<2)|0;c[e>>2]=(c[e>>2]|0)+1}h=b;j=h;i=f;return j|0}function vjc(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=a;a=e;e=f;f=igc(b)|0;b=f;j=h+15495|0;k=a;if((k|0)==2){l=j+6+(b<<1)|0}else if((k|0)==3){l=j+(b*3|0)|0}else if((k|0)==1){l=j+10+b|0}else{Cd(2336760,2279160,111,2652128);return 0}b=l;l=pjc(e,d[b|0]|0)|0;do{if((l|0)!=0){if(!(a>>>0>=2>>>0)){break}l=l+(pjc(e,d[b+1|0]|0)|0)|0;do{if((l|0)!=1){if(!(a>>>0>=3>>>0)){break}l=l+(pjc(e,d[b+2|0]|0)|0)|0}}while(0)}}while(0);if((c[h+36964>>2]|0)!=0){m=l;i=g;return m|0}b=l;e=f;f=h+36428|0;h=a;if((h|0)==3){n=f+(e<<4)|0}else if((h|0)==2){n=f+32+(e*12|0)|0}else if((h|0)==1){n=f+56+(e<<3)|0}else{Cd(2336760,2279160,132,2652176);return 0}e=n+(b<<2)|0;c[e>>2]=(c[e>>2]|0)+1;m=l;i=g;return m|0}function wjc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=ojc(a,204312,b+5|0)|0;i=c;return d|0}function xjc(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;j=b;b=d;d=e;e=f;f=g;g=(ca(d,c[j+10156>>2]|0)|0)+e|0;k=c[777680+(b<<2)>>2]|0;l=c[777736+(b<<2)>>2]|0;if(((c[j+10156>>2]|0)-e|0)<(k|0)){m=(c[j+10156>>2]|0)-e|0}else{m=k}k=m;if(((c[j+10148>>2]|0)-d|0)<(l|0)){n=(c[j+10148>>2]|0)-d|0}else{n=l}l=n;if((f|0)>=0){if((f|0)<8){}else{o=9}}else{o=9}if((o|0)==9){Cd(2229936,2414848,96,2651328)}o=0;while(1){if((o|0)>=(l|0)){break}n=0;while(1){if((n|0)>=(k|0)){break}d=g+(ca(o,c[j+10156>>2]|0)|0)+n|0;a[(c[j+10216>>2]|0)+d|0]=f;n=n+1|0}o=o+1|0}i=h;return}function yjc(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=b;b=j+13408|0;k=c[c[c[d+160>>2]>>2]>>2]|0;if((a[b|0]|0)==0){l=0;m=l;i=h;return m|0}if((a[b+1|0]|0)!=0){d=wjc(g,b)|0;xjc(j,k,e,f,d);l=d;m=l;i=h;return m|0}else{l=0;m=l;i=h;return m|0}return 0}function zjc(d,e,f,g,h,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;n=i;o=d;d=e;e=g;g=h;h=j;j=k;k=l;l=m;m=d+(f*52|0)|0;f=(c[m+44>>2]|0)+h|0;p=(c[m+48>>2]|0)+j|0;q=0;r=0;s=k;if((s|0)==0){q=(a[f]|0)!=0&255;r=(a[p]|0)!=0&255}else if((s|0)==3){t=f;q=((c[t>>2]|0)!=0|(c[t+4>>2]|0)!=0)&1;t=p;r=((c[t>>2]|0)!=0|(c[t+4>>2]|0)!=0)&1}else if((s|0)==1){q=(b[f>>1]|0)!=0&255;r=(b[p>>1]|0)!=0&255}else if((s|0)==2){q=(c[f>>2]|0)!=0&255;r=(c[p>>2]|0)!=0&255}else{Cd(2274568,2540784,170,2652512);return 0}p=((q<<24>>24|0)!=0)+((r<<24>>24|0)!=0)|0;r=d;q=k;f=e;s=c[c[r+160>>2]>>2]|0;do{if((c[s+20>>2]|0)<=0){if((c[m+4>>2]|0)!=0){break}if((c[r+25808>>2]|0)!=0){break}t=s;if((c[t>>2]|0)>>>0<3>>>0){u=c[t+76+(f*12|0)>>2]|0}else{u=c[t+4>>2]|0}v=204488+(q*48|0)+((c[1064496+(u<<2)>>2]|0)*12|0)|0;w=v;x=w;y=o;z=d;A=m;B=A+4|0;C=c[B>>2]|0;D=m;E=D|0;F=c[E>>2]|0;G=e;H=G<<4;I=F+(H<<1)|0;J=k;K=m;L=K+40|0;M=c[L>>2]|0;N=p;O=x;P=O|0;Q=c[P>>2]|0;R=x;S=R+8|0;T=c[S>>2]|0;U=l;V=Ajc(y,z,C,I,J,M,N,Q,T,U)|0;W=V;X=d;Y=m;Z=g;_=k;$=W;aa=($|0)>0;ba=aa&1;ca=h;da=j;fec(X,Y,Z,_,ba,ca,da);ea=W;i=n;return ea|0}}while(0);v=218736+(q*12|0)|0;w=v;x=w;y=o;z=d;A=m;B=A+4|0;C=c[B>>2]|0;D=m;E=D|0;F=c[E>>2]|0;G=e;H=G<<4;I=F+(H<<1)|0;J=k;K=m;L=K+40|0;M=c[L>>2]|0;N=p;O=x;P=O|0;Q=c[P>>2]|0;R=x;S=R+8|0;T=c[S>>2]|0;U=l;V=Ajc(y,z,C,I,J,M,N,Q,T,U)|0;W=V;X=d;Y=m;Z=g;_=k;$=W;aa=($|0)>0;ba=aa&1;ca=h;da=j;fec(X,Y,Z,_,ba,ca,da);ea=W;i=n;return ea|0}function Ajc(e,f,g,h,j,k,l,m,n,o){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;p=i;i=i+1024|0;q=p|0;r=e;e=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=16<<(h<<1);s=r+23740|0;t=(c[(c[c[f+160>>2]>>2]|0)+20>>2]|0)>0|0;f=0;u=r+13714+(h*432|0)+(e*216|0)+(t*108|0)|0;v=s+816+(h*2304|0)+(e*1152|0)+(t*576|0)|0;w=s+10032+(h*576|0)+(e*288|0)+(t*144|0)|0;t=(h|0)==0?233584:232560;e=(h|0)==3|0;h=b[j>>1]|0;a:while(1){if((f|0)>=(o|0)){break}s=t;t=s+1|0;x=d[s]|0;s=u+(x*18|0)+(k*3|0)|0;if((c[r+36964>>2]|0)==0){y=w+(x*24|0)+(k<<2)|0;c[y>>2]=(c[y>>2]|0)+1}if((Bjc(n,d[s|0]|0)|0)==0){z=6;break}while(1){if(!((Bjc(n,d[s+1|0]|0)|0)!=0^1)){break}if((c[r+36964>>2]|0)==0){y=v+(x*96|0)+(k<<4)|0;c[y>>2]=(c[y>>2]|0)+1}h=b[j+2>>1]|0;a[q+(b[l+(f<<1)>>1]|0)|0]=0;f=f+1|0;if((f|0)>=(o|0)){z=18;break a}y=m;A=q|0;B=f;k=(d[A+(b[y+(B<<1<<1)>>1]|0)|0]|0)+1+(d[A+(b[y+((B<<1)+1<<1)>>1]|0)|0]|0)>>1;B=t;t=B+1|0;x=d[B]|0;s=u+(x*18|0)+(k*3|0)|0}if((Bjc(n,d[s+2|0]|0)|0)==0){if((c[r+36964>>2]|0)==0){B=v+(x*96|0)+(k<<4)+4|0;c[B>>2]=(c[B>>2]|0)+1}C=h<<16>>16>>e;if((Cjc(n)|0)!=0){D=-C|0}else{D=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=D;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206857]|0;f=f+1|0;B=m;y=q|0;A=f;k=(d[y+(b[B+(A<<1<<1)>>1]|0)|0]|0)+1+(d[y+(b[B+((A<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}if((c[r+36964>>2]|0)==0){A=v+(x*96|0)+(k<<4)+8|0;c[A>>2]=(c[A>>2]|0)+1}s=207992+((d[s+2|0]|0)-1<<3)|0;if((Bjc(n,d[s|0]|0)|0)==0){if((Bjc(n,d[s+1|0]|0)|0)==0){C=h<<16>>16<<1>>e;if((Cjc(n)|0)!=0){E=-C|0}else{E=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=E;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206858]|0;f=f+1|0;A=m;B=q|0;y=f;k=(d[B+(b[A+(y<<1<<1)>>1]|0)|0]|0)+1+(d[B+(b[A+((y<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}if((Bjc(n,d[s+2|0]|0)|0)!=0){C=h<<16>>16<<2>>e;if((Cjc(n)|0)!=0){F=-C|0}else{F=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=F;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206860]|0;f=f+1|0;y=m;A=q|0;B=f;k=(d[A+(b[y+(B<<1<<1)>>1]|0)|0]|0)+1+(d[A+(b[y+((B<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}else{C=((h<<16>>16)*3|0)>>e;if((Cjc(n)|0)!=0){G=-C|0}else{G=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=G;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206859]|0;f=f+1|0;B=m;y=q|0;A=f;k=(d[y+(b[B+(A<<1<<1)>>1]|0)|0]|0)+1+(d[y+(b[B+((A<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}}if((Bjc(n,d[s+3|0]|0)|0)==0){if((Bjc(n,d[s+4|0]|0)|0)==0){H=5;H=H+((Bjc(n,159)|0)<<0)|0;C=(ca(H,h<<16>>16)|0)>>e;if((Cjc(n)|0)!=0){I=-C|0}else{I=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=I;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206861]|0;f=f+1|0;A=m;B=q|0;y=f;k=(d[B+(b[A+(y<<1<<1)>>1]|0)|0]|0)+1+(d[B+(b[A+((y<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}H=7;H=H+((Bjc(n,165)|0)<<1)|0;H=H+((Bjc(n,145)|0)<<0)|0;C=(ca(H,h<<16>>16)|0)>>e;if((Cjc(n)|0)!=0){J=-C|0}else{J=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=J;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206862]|0;f=f+1|0;y=m;A=q|0;B=f;k=(d[A+(b[y+(B<<1<<1)>>1]|0)|0]|0)+1+(d[A+(b[y+((B<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}if((Bjc(n,d[s+5|0]|0)|0)!=0){if((Bjc(n,d[s+7|0]|0)|0)!=0){H=0;B=1888832;while(1){if((a[B]|0)==0){break}y=B;B=y+1|0;H=H<<1|(Bjc(n,d[y]|0)|0)}H=H+67|0;C=(ca(H,h<<16>>16)|0)>>e;if((Cjc(n)|0)!=0){K=-C|0}else{K=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=K;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206866]|0;f=f+1|0;B=m;y=q|0;A=f;k=(d[y+(b[B+(A<<1<<1)>>1]|0)|0]|0)+1+(d[y+(b[B+((A<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}H=35;H=H+((Bjc(n,180)|0)<<4)|0;H=H+((Bjc(n,157)|0)<<3)|0;H=H+((Bjc(n,141)|0)<<2)|0;H=H+((Bjc(n,134)|0)<<1)|0;H=H+((Bjc(n,130)|0)<<0)|0;C=(ca(H,h<<16>>16)|0)>>e;if((Cjc(n)|0)!=0){L=-C|0}else{L=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=L;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206865]|0;f=f+1|0;A=m;B=q|0;y=f;k=(d[B+(b[A+(y<<1<<1)>>1]|0)|0]|0)+1+(d[B+(b[A+((y<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}if((Bjc(n,d[s+6|0]|0)|0)==0){H=11;H=H+((Bjc(n,173)|0)<<2)|0;H=H+((Bjc(n,148)|0)<<1)|0;H=H+((Bjc(n,140)|0)<<0)|0;C=(ca(H,h<<16>>16)|0)>>e;if((Cjc(n)|0)!=0){M=-C|0}else{M=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=M;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206863]|0;f=f+1|0;y=m;A=q|0;B=f;k=(d[A+(b[y+(B<<1<<1)>>1]|0)|0]|0)+1+(d[A+(b[y+((B<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0;continue}H=19;H=H+((Bjc(n,176)|0)<<3)|0;H=H+((Bjc(n,155)|0)<<2)|0;H=H+((Bjc(n,140)|0)<<1)|0;H=H+((Bjc(n,135)|0)<<0)|0;C=(ca(H,h<<16>>16)|0)>>e;if((Cjc(n)|0)!=0){N=-C|0}else{N=C}b[g+(b[l+(f<<1)>>1]<<1)>>1]=N;a[q+(b[l+(f<<1)>>1]|0)|0]=a[206864]|0;f=f+1|0;B=m;y=q|0;A=f;k=(d[y+(b[B+(A<<1<<1)>>1]|0)|0]|0)+1+(d[y+(b[B+((A<<1)+1<<1)>>1]|0)|0]|0)>>1;h=b[j+2>>1]|0}if((z|0)==18){O=f;P=O;i=p;return P|0}if((z|0)==6){if((c[r+36964>>2]|0)==0){r=v+(x*96|0)+(k<<4)+12|0;c[r>>2]=(c[r>>2]|0)+1}}O=f;P=O;i=p;return P|0}function Bjc(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=0;g=((ca(c[f+16>>2]|0,a)|0)+(256-a)|0)>>>8;if((c[f+12>>2]|0)<0){Mjc(f)}a=c[f+8>>2]|0;h=c[f+12>>2]|0;j=g<<24;k=g;if(a>>>0>=j>>>0){k=(c[f+16>>2]|0)-g|0;a=a-j|0;b=1}j=d[211576+k|0]|0;k=k<<j;a=a<<j;h=h-j|0;c[f+8>>2]=a;c[f+12>>2]=h;c[f+16>>2]=k;i=e;return b|0}function Cjc(a){a=a|0;var b=0,c=0;b=i;c=Bjc(a,128)|0;i=b;return c|0}function Djc(b,c){b=b|0;c=c|0;var e=0,f=0;e=i;f=b;b=c;if((Ejc(f,252)|0)==0){i=e;return}c=Fjc(f)|0;a[b]=Gjc(c,d[b]|0)|0;i=e;return}function Ejc(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=0;g=((ca(c[f+16>>2]|0,a)|0)+(256-a)|0)>>>8;if((c[f+12>>2]|0)<0){Mjc(f)}a=c[f+8>>2]|0;h=c[f+12>>2]|0;j=g<<24;k=g;if(a>>>0>=j>>>0){k=(c[f+16>>2]|0)-g|0;a=a-j|0;b=1}j=d[211576+k|0]|0;k=k<<j;a=a<<j;h=h-j|0;c[f+8>>2]=a;c[f+12>>2]=h;c[f+16>>2]=k;i=e;return b|0}function Fjc(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;do{if((Ijc(c)|0)!=0){if((Ijc(c)|0)==0){d=(Jjc(c,4)|0)+16|0;break}if((Ijc(c)|0)!=0){d=(Kjc(c)|0)+64|0;break}else{d=(Jjc(c,5)|0)+32|0;break}}else{d=Jjc(c,4)|0}}while(0);i=b;return d|0}function Gjc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a;a=b;b=e;f=0;g=253;if((b|0)<(f|0)){h=f}else{if((b|0)>(g|0)){j=g}else{j=b}h=j}e=h;e=c[1061792+(e<<2)>>2]|0;a=a-1|0;if((a<<1|0)<=255){k=(Hjc(e+1|0,a)|0)+1|0;l=k;i=d;return l|0}else{k=255-(Hjc(e+1|0,254-a|0)|0)|0;l=k;i=d;return l|0}return 0}function Hjc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;d=a;a=b;if((d|0)>(a<<1|0)){e=d;f=e;i=c;return f|0}if(((d|0)%2|0|0)!=0){g=a-((d+1|0)/2|0)|0}else{g=a+((d|0)/2|0)|0}e=g;f=e;i=c;return f|0}function Ijc(a){a=a|0;var b=0,c=0;b=i;c=Ejc(a,128)|0;i=b;return c|0}function Jjc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=0;e=b-1|0;while(1){if((e|0)<0){break}a=a|(Ijc(d)|0)<<e;e=e-1|0}i=c;return a|0}function Kjc(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;a=Jjc(c,7)|0;if((a|0)<65){d=a;i=b;return d|0}else{d=(a<<1)-65+(Ijc(c)|0)|0;i=b;return d|0}return 0}function Ljc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;do{if((b|0)!=0){if((a|0)!=0){break}g=1;h=g;i=e;return h|0}}while(0);c[f>>2]=a+b;c[f+4>>2]=a;c[f+8>>2]=0;c[f+12>>2]=-8;c[f+16>>2]=255;Mjc(f);g=(Njc(f)|0)!=0|0;h=g;i=e;return h|0}function Mjc(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;e=a;a=c[e+4>>2]|0;f=c[e+8>>2]|0;g=c[e+12>>2]|0;h=24-(g+8)|0;j=0;k=(c[e>>2]|0)-a<<3;l=h+8-k|0;if((l|0)>=0){g=g+1073741824|0;j=l}do{if((l|0)>=0){if((k|0)!=0){break}m=a;n=e;o=n+4|0;c[o>>2]=m;p=f;q=e;r=q+8|0;c[r>>2]=p;s=g;t=e;u=t+12|0;c[u>>2]=s;i=b;return}}while(0);while(1){if((h|0)<(j|0)){break}g=g+8|0;k=a;a=k+1|0;f=f|(d[k]|0)<<h;h=h-8|0}m=a;n=e;o=n+4|0;c[o>>2]=m;p=f;q=e;r=q+8|0;c[r>>2]=p;s=g;t=e;u=t+12|0;c[u>>2]=s;i=b;return}function Njc(a){a=a|0;var b=0,c=0;b=i;c=Qjc(a,128)|0;i=b;return c|0}function Ojc(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;while(1){if((c[d+12>>2]|0)>8){e=(c[d+12>>2]|0)<32}else{e=0}if(!e){break}a=d+12|0;c[a>>2]=(c[a>>2]|0)-8;a=d+4|0;c[a>>2]=(c[a>>2]|0)-1}i=b;return c[d+4>>2]|0}function Pjc(a){a=a|0;var b=0,d=0;b=a;if((c[b+12>>2]|0)>32){d=(c[b+12>>2]|0)<1073741824}else{d=0}i=i;return d&1|0}function Qjc(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=0;g=((ca(c[f+16>>2]|0,a)|0)+(256-a)|0)>>>8;if((c[f+12>>2]|0)<0){Mjc(f)}a=c[f+8>>2]|0;h=c[f+12>>2]|0;j=g<<24;k=g;if(a>>>0>=j>>>0){k=(c[f+16>>2]|0)-g|0;a=a-j|0;b=1}j=d[211576+k|0]|0;k=k<<j;a=a<<j;h=h-j|0;c[f+8>>2]=a;c[f+12>>2]=h;c[f+16>>2]=k;i=e;return b|0}function Rjc(b){b=b|0;var d=0,e=0,f=0,g=0,j=0;d=i;e=b;b=e+1434592|0;f=b+13408|0;do{if((c[b+10108>>2]|0)!=0){if((c[e+1472152>>2]|0)!=0){break}if((c[e+1472148>>2]|0)==0){i=d;return}if((c[e+2017236>>2]|0)==0){break}i=d;return}}while(0);mrc(c[e+2047180>>2]|0,0,ca(c[b+10148>>2]|0,c[b+10156>>2]|0)|0)|0;mrc(c[e+2047216>>2]|0,0,ca(c[b+10148>>2]|0,c[b+10156>>2]|0)|0)|0;J5b(f);Uhc(f);a[f+3|0]=0;L5b(f,0,0);g=1;while(1){if((g|0)>=2){break}j=s3b(e+2017128|0,c[b+10108>>2]|0,c[b+10168>>2]|0,+h[1072384+(g<<3)>>3])|0;Vhc(f,g,0);Yhc(f,g,0,j);g=g+1|0}i=d;return}function Sjc(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=b;b=d;d=e;e=g;g=j+1434592|0;k=(ca(b,c[g+10156>>2]|0)|0)+d|0;l=c[194432]|0;m=c[194446]|0;if(((c[g+10156>>2]|0)-d|0)<(l|0)){n=(c[g+10156>>2]|0)-d|0}else{n=l}d=n;if(((c[g+10148>>2]|0)-b|0)<(m|0)){o=(c[g+10148>>2]|0)-b|0}else{o=m}b=o;o=64;if((f|0)!=0){f=((ca(ca(c[j+2017136>>2]|0,d)|0,b)|0)<<8|0)/(ca(l,m)|0)|0;if((e|0)<((f|0)/4|0|0)){p=1}else{p=0}if((f|0)>0){m=(e<<6|0)/(f|0)|0;f=16;e=255;if((m|0)<(f|0)){q=f}else{if((m|0)>(e|0)){r=e}else{r=m}q=r}o=q}}else{p=0}q=0;while(1){if((q|0)>=(b|0)){break}r=0;while(1){if((r|0)>=(d|0)){break}m=k+(ca(q,c[g+10156>>2]|0)|0)+r|0;a[(c[j+2047180>>2]|0)+m|0]=p;m=k+(ca(q,c[g+10156>>2]|0)|0)+r|0;a[(c[j+2047216>>2]|0)+m|0]=o;r=r+1|0}q=q+1|0}i=h;return}function Tjc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=DYb(1,72)|0;if((e|0)==0){f=0;g=f;i=d;return g|0}c[e+32>>2]=DYb(ca(a,b)|0,1)|0;if((c[e+32>>2]|0)==0){FYb(e);f=0;g=f;i=d;return g|0}else{f=e;g=f;i=d;return g|0}return 0}function Ujc(a){a=a|0;var b=0,d=0;b=i;d=a;FYb(c[d+32>>2]|0);FYb(d);i=b;return}function Vjc(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;l=b;b=e;e=f;f=g;g=h;h=l+1434592|0;m=c[l+2047228>>2]|0;n=c[777680+(g<<2)>>2]|0;o=c[777736+(g<<2)>>2]|0;if(((c[h+10156>>2]|0)-f|0)<(n|0)){p=(c[h+10156>>2]|0)-f|0}else{p=n}n=p;if(((c[h+10148>>2]|0)-e|0)<(o|0)){q=(c[h+10148>>2]|0)-e|0}else{q=o}o=q;q=(ca(e,c[h+10156>>2]|0)|0)+f|0;f=Wjc(m,b,g,j)|0;j=a[(c[m+32>>2]|0)+q|0]|0;g=0;e=0;do{if((d[b+13|0]|0)>0){if((f|0)!=0){break}a[b+13|0]=0}}while(0);if((d[b+13|0]|0)==1){j=-(c[m+16>>2]|0)|0}else{if((f|0)!=0){if((a[(c[m+32>>2]|0)+q|0]|0)==1){j=0}}else{j=1}}e=0;while(1){if((e|0)>=(o|0)){break}g=0;while(1){if((g|0)>=(n|0)){break}f=q+(ca(e,c[h+10156>>2]|0)|0)+g|0;a[(c[m+32>>2]|0)+f|0]=j;f=q+(ca(e,c[h+10156>>2]|0)|0)+g|0;a[(c[l+2047180>>2]|0)+f|0]=a[b+13|0]|0;g=g+1|0}e=e+1|0}if((a[b+13|0]|0)==0){i=k;return}b=ca(n,o)|0;o=m+20|0;c[o>>2]=(c[o>>2]|0)+b;i=k;return}function Wjc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=a;a=b;b=d;if((e|0)==0){do{if(!(b>>>0<(c[g+8>>2]|0)>>>0)){if((c[a+28>>2]|0)!=0){break}if(((c[a+20>>2]|0)>0|0)==0){break}h=1;j=h;i=f;return j|0}}while(0);h=0;j=h;i=f;return j|0}e=g+40|0;d=c[e+4>>2]|0;k=g+56|0;l=c[k+4>>2]|0;if((d|0)<(l|0)|(d|0)==(l|0)&(c[e>>2]|0)>>>0<(c[k>>2]|0)>>>0){h=1;j=h;i=f;return j|0}do{if(!(b>>>0<(c[g+8>>2]|0)>>>0)){if((c[a+28>>2]|0)!=0){k=g+48|0;e=c[k+4>>2]|0;l=g+64|0;d=c[l+4>>2]|0;if((e|0)>(d|0)|(e|0)==(d|0)&(c[k>>2]|0)>>>0>(c[l>>2]|0)>>>0){break}}if(((c[a+20>>2]|0)>0|0)==0){break}h=1;j=h;i=f;return j|0}}while(0);h=0;j=h;i=f;return j|0}function Xjc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;e=b;b=e+1434592|0;f=e+2017128|0;g=c[e+2047228>>2]|0;h=b+13408|0;j=c[e+2047180>>2]|0;do{if((Yjc(b,f)|0)!=0){if((c[b+10108>>2]|0)==0){break}if((c[e+2050812>>2]|0)>0){break}k=0;l=+O2b(c[b+10168>>2]|0);c[g>>2]=10;c[g+4>>2]=50;c[g+8>>2]=3;c[g+16>>2]=1;m=c[f+8>>2]<<8>>2;n=g+56|0;c[n>>2]=m;c[n+4>>2]=(m|0)<0|0?-1:0;m=~~(l*l)<<3;n=g+64|0;c[n>>2]=m;c[n+4>>2]=(m|0)<0|0?-1:0;if((c[e+2047084>>2]|0)!=0){m=c[f+8>>2]<<8>>3;n=g+56|0;c[n>>2]=m;c[n+4>>2]=(m|0)<0|0?-1:0;m=~~(l*l)<<2;n=g+64|0;c[n>>2]=m;c[n+4>>2]=(m|0)<0|0?-1:0}c[g+20>>2]=0;mrc(j|0,0,ca(c[b+10148>>2]|0,c[b+10156>>2]|0)|0)|0;J5b(b+13408|0);Uhc(h);a[h+3|0]=0;L5b(h,0,0);Vhc(h,1,0);k=s3b(f,c[b+10108>>2]|0,c[b+10168>>2]|0,2.0)|0;if((-k|0)>((ca(c[g+4>>2]|0,c[b+10168>>2]|0)|0)/100|0|0)){k=(ca(-(c[g+4>>2]|0)|0,c[b+10168>>2]|0)|0)/100|0}m=(c[b+10168>>2]|0)+(c[b+10172>>2]|0)+k|0;n=0;o=255;if((m|0)<(n|0)){p=n}else{if((m|0)>(o|0)){q=o}else{q=m}p=q}c[g+28>>2]=z3b(e,p)|0;Yhc(h,1,0,k);k=((c[b+10156>>2]|0)+8-1|0)/8|0;m=ca(k,((c[b+10148>>2]|0)+8-1|0)/8|0)|0;o=(ca(c[g>>2]|0,m)|0)/100|0;if((c[g+12>>2]|0)<(m|0)){}else{Cd(2273824,2540488,265,2650624)}n=c[g+12>>2]|0;do{r=0;s=(n|0)/(k|0)|0;t=s<<3;u=n-(ca(s,k)|0)<<3;if((t|0)>=0){if((t|0)<(c[b+10148>>2]|0)){}else{v=22}}else{v=22}if((v|0)==22){v=0;Cd(2414624,2540488,274,2650624)}if((u|0)>=0){if((u|0)<(c[b+10156>>2]|0)){}else{v=25}}else{v=25}if((v|0)==25){v=0;Cd(2336608,2540488,275,2650624)}s=(ca(t,c[b+10156>>2]|0)|0)+u|0;if(((c[b+10156>>2]|0)-u|0)<(c[194432]|0)){w=(c[b+10156>>2]|0)-u|0}else{w=c[194432]|0}u=w;if(((c[b+10148>>2]|0)-t|0)<(c[194446]|0)){x=(c[b+10148>>2]|0)-t|0}else{x=c[194446]|0}t=x;y=0;while(1){if((y|0)>=(t|0)){break}z=0;while(1){if((z|0)>=(u|0)){break}A=s+(ca(y,c[b+10156>>2]|0)|0)+z|0;if((a[(c[g+32>>2]|0)+A|0]|0)==0){a[j+A|0]=1;r=r+1|0}else{if((a[(c[g+32>>2]|0)+A|0]|0)<0){B=(c[g+32>>2]|0)+A|0;a[B]=(a[B]|0)+1}}z=z+1|0}y=y+1|0}do{if((r|0)>0){if((r|0)>=(ca(u,t)|0)){break}B=(r|0)>=((ca(u,t)|0)/2|0|0)|0;y=0;while(1){if((y|0)>=(t|0)){break}z=0;while(1){if((z|0)>=(u|0)){break}a[j+(s+(ca(y,c[b+10156>>2]|0)|0)+z)|0]=B;z=z+1|0}y=y+1|0}}}while(0);n=n+1|0;if((n|0)==(m|0)){n=0}if((r|0)>=((ca(u,t)|0)/2|0|0)){o=o-1|0}if((o|0)!=0){C=(n|0)!=(c[g+12>>2]|0)}else{C=0}}while(C);c[g+12>>2]=n;i=d;return}}while(0);mrc(j|0,0,ca(c[b+10148>>2]|0,c[b+10156>>2]|0)|0)|0;K5b(b+13408|0);if((c[b+10108>>2]|0)==0){c[g+12>>2]=0}i=d;return}function Yjc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;a=ca(c[e+10148>>2]|0,c[e+10156>>2]|0)|0;do{if(!(+(c[b+112>>2]|0)<+(a|0)*.5)){if(((a|0)/64|0|0)<5){break}f=1;g=f;i=d;return g|0}}while(0);f=0;g=f;i=d;return g|0}function Zjc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=a;c[h>>2]=b;c[h+4>>2]=d;c[j>>2]=e;c[j+4>>2]=f;f=c[h+4>>2]|0;e=k+40|0;c[e>>2]=c[h>>2];c[e+4>>2]=f;f=c[j+4>>2]|0;e=k+48|0;c[e>>2]=c[j>>2];c[e+4>>2]=f;i=g;return}function _jc(a){a=a|0;i=i;return c[a+28>>2]|0}function $jc(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;if((d|0)>=-1){if((d|0)<=1){}else{e=3}}else{e=3}if((e|0)==3){Cd(2273472,2540400,39,2649936);return 0}i=b;return c[601856+(d+1<<2)>>2]|0}function akc(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;if((c|0)>=-1){if((c|0)<=1){}else{d=3}}else{d=3}if((d|0)==3){Cd(2273472,2540400,45,2649960);return 0.0}i=b;return+(+h[682152+(c+1<<3)>>3])}function bkc(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;if((c|0)>=-1){if((c|0)<=1){}else{d=3}}else{d=3}if((d|0)==3){Cd(2273472,2540400,53,2649984);return 0.0}i=b;return+(+h[696240+((-c|0)+1<<3)>>3])}function ckc(){var a=0,b=0.0,c=0;a=i;b=1.5;c=-1;while(1){if((c|0)>1){break}h[696240+(c+1<<3)>>3]=+T(+b,+(+(c|0)/3.0));c=c+1|0}i=a;return}function dkc(b){b=b|0;var d=0,e=0,f=0,g=0.0,j=0,k=0,l=0;d=i;e=b;b=e+1434592|0;f=b+13408|0;g=+O2b(c[b+10168>>2]|0);j=z3b(e,(c[b+10168>>2]|0)+(c[b+10172>>2]|0)|0)|0;do{if((c[b+10108>>2]|0)!=0){if((c[e+1472152>>2]|0)!=0){break}if((c[e+1472148>>2]|0)==0){i=d;return}if((c[e+2017236>>2]|0)==0){break}i=d;return}}while(0);J5b(f);Uhc(f);a[f+3|0]=0;k=-1;while(1){if((k|0)>1){break}if(+h[696240+(k+1<<3)>>3]==1.0){h[682152+(k+1<<3)>>3]=1.0}else{l=r3b(e+2017128|0,g,g*+h[696240+(k+1<<3)>>3])|0;Yhc(f,c[601856+(k+1<<2)>>2]|0,0,l);Vhc(f,c[601856+(k+1<<2)>>2]|0,0);h[682152+(k+1<<3)>>3]=+(z3b(e,(c[b+10168>>2]|0)+l+(c[b+10172>>2]|0)|0)|0)/+(j|0)}k=k+1|0}i=d;return}function ekc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;e=~~+Nb(+((+aa(+((fkc(a,b,c)|0)>>>0>>>0)+1.0)-10.0)*.9));c=-1;b=1;if((e|0)<(c|0)){f=c;i=d;return f|0}if((e|0)>(b|0)){g=b}else{g=e}f=g;i=d;return f|0}function fkc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a;a=b;b=d;d=a+24720|0;if((c[d+176>>2]|0)<0){j=-(c[d+176>>2]|0)>>3}else{j=0}k=j;if((c[d+184>>2]|0)<0){l=-(c[d+184>>2]|0)>>3}else{l=0}d=l;do{if((k|0)==0){if((d|0)!=0){break}m=Xe[c[h+2047252+(b*44|0)+8>>2]&511](c[a+8204>>2]|0,c[a+8208>>2]|0,3348864,0,f)|0;n=m<<8>>>((c[777552+(b<<2)>>2]|0)>>>0);o=n;i=e;return o|0}}while(0);h=(c[777680+(b<<2)>>2]<<3)-k|0;k=(c[777736+(b<<2)>>2]<<3)-d|0;w6b(c[a+8204>>2]|0,c[a+8208>>2]|0,3348864,0,h,k,f,g);a=c[f>>2]|0;f=c[g>>2]|0;d=c[g>>2]|0;g=Erc(f,(f|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;d=ca(h,k)|0;f=Crc(g,G,d,(d|0)<0|0?-1:0)|0;d=xrc(a,0,f,G)|0;m=d;n=(m<<8>>>0)/((ca(h,k)|0)>>>0)|0;o=n;i=e;return o|0}function gkc(){s6b(5899176,215456);s6b(5083480,202680);s6b(5467416,207984);s6b(5901928,215488);return}function hkc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=a;a=b;b=a;c[f>>2]=b;c[f+4>>2]=0;ikc(h,f);j=g;k=f;c[j>>2]=c[k>>2];c[j+4>>2]=c[k+4>>2];Moc(f,0,16);b=b+(Koc(f)|0)|0;zoc();f=jkc(h,b)|0;b=b+f|0;Moc(g,f,16);b=b+(kkc(h,b)|0)|0;c[d>>2]=b-a;i=e;return}function ikc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=a;a=b;b=e+1434592|0;Moc(a,2,2);Jkc(c[b+36952>>2]|0,a);Loc(a,0);Loc(a,c[b+10108>>2]|0);Loc(a,c[b+10112>>2]|0);Loc(a,c[b+36960>>2]|0);if((c[b+10108>>2]|0)==0){Kkc(a);if((c[b+36952>>2]|0)>>>0>1>>>0){if((c[b+36956>>2]|0)>>>0>0>>>0){}else{Cd(2452592,2540304,1058,2649656)}Loc(a,(c[b+36956>>2]|0)-1|0)}Moc(a,0,3);Loc(a,0);if((c[b+36952>>2]|0)>>>0>=1>>>0){Loc(a,c[b+8476>>2]|0);Loc(a,c[b+8480>>2]|0);Loc(a,0)}Lkc(b,a)}else{if((c[b+10112>>2]|0)==0){Loc(a,c[b+10124>>2]|0)}if((c[b+36960>>2]|0)==0){Moc(a,c[b+10132>>2]|0,2)}if((c[b+10124>>2]|0)!=0){Kkc(a);Moc(a,Mkc(e)|0,8);Lkc(b,a)}else{Moc(a,Mkc(e)|0,8);f=1;while(1){if((f|0)>3){break}g=a;h=e;j=f;do{if((j|0)==1){k=c[h+1472132>>2]|0}else{if((j|0)==2){k=c[h+1472136>>2]|0;break}else{k=c[h+1472140>>2]|0;break}}}while(0);Moc(g,k,3);Loc(a,c[b+13364+(f<<2)>>2]|0);f=f+1|0}Nkc(e,a);Loc(a,c[b+10128>>2]|0);Okc(b);Pkc(c[b+10220>>2]|0,a)}}if((c[b+36960>>2]|0)!=0){l=a;m=b;n=m+23736|0;o=c[n>>2]|0;Moc(l,o,2);p=b;q=p+13380|0;r=a;Qkc(q,r);s=b;t=a;Rkc(s,t);u=e;v=a;Skc(u,v);w=b;x=a;Tkc(w,x);i=d;return}Loc(a,c[b+13360>>2]|0);Loc(a,c[b+36964>>2]|0);l=a;m=b;n=m+23736|0;o=c[n>>2]|0;Moc(l,o,2);p=b;q=p+13380|0;r=a;Qkc(q,r);s=b;t=a;Rkc(s,t);u=e;v=a;Skc(u,v);w=b;x=a;Tkc(w,x);i=d;return}function jkc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+40|0;e=d|0;f=a;a=f+1434592|0;g=a+13540|0;Noc(e,b);if((c[f+83296>>2]|0)!=0){c[a+10164>>2]=0}else{Bkc(a,e)}Ckc(f,e);Dkc(a,e);f=a;if((c[f+10108>>2]|0)==0){h=1}else{h=(c[f+10124>>2]|0)!=0}if((h&1|0)==0){h=0;while(1){if((h|0)>=7){break}Ekc(215488,a+15450+(h*3|0)|0,a+36124+(h<<4)|0,4,e);h=h+1|0}mrc(a+36124|0,0,112)|0;if((c[a+10220>>2]|0)==4){Fkc(a,e)}h=0;while(1){if((h|0)>=4){break}Eoc(e,g+1931+h|0,a+36236+(h<<3)|0);h=h+1|0}if((c[a+13520>>2]|0)!=0){f=(c[a+13536>>2]|0)!=0|0;b=(c[a+13536>>2]|0)==2|0;ukc(e,f);if((f|0)!=0){ukc(e,b);if((b|0)!=0){h=0;while(1){if((h|0)>=5){break}Eoc(e,g+1935+h|0,a+36268+(h<<3)|0);h=h+1|0}}}}if((c[a+13536>>2]|0)!=1){h=0;while(1){if((h|0)>=5){break}Eoc(e,g+1940+(h<<1)|0,a+36308+(h<<4)|0);Eoc(e,g+1940+(h<<1)+1|0,a+36308+(h<<4)+8|0);h=h+1|0}}if((c[a+13536>>2]|0)!=0){h=0;while(1){if((h|0)>=5){break}Eoc(e,g+1950+h|0,a+36388+(h<<3)|0);h=h+1|0}}h=0;while(1){if((h|0)>=4){break}Ekc(215456,a+13540+(h*9|0)|0,a+23740+(h*40|0)|0,10,e);h=h+1|0}h=0;while(1){if((h|0)>=16){break}Ekc(207984,g+126+(h*3|0)|0,a+24300+(h<<4)|0,4,e);h=h+1|0}Mmc(a,c[a+10128>>2]|0,e)}Poc(e);if((c[e+16>>2]|0)>>>0<=65535>>>0){a=1;h=a&1;a=e+16|0;e=c[a>>2]|0;i=d;return e|0}Cd(2473520,2540304,1191,2649840);return 0}function kkc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+1080|0;e=d|0;f=d+40|0;g=d+1064|0;h=a;a=b;b=h+1434592|0;j=0;k=1<<c[b+36972>>2];l=1<<c[b+36976>>2];mrc(c[b+37e3>>2]|0,0,(c[b+10156>>2]|0)+7&-8|0)|0;c[f>>2]=c[h+1472272>>2];m=0;while(1){if((m|0)>=(l|0)){break}if((m|0)!=0){c[f+(m<<8)>>2]=(c[f+(m-1<<8)+(k-1<<2)>>2]|0)+(c[h+1472276+(m-1<<8)+(k-1<<2)>>2]<<3)}n=1;while(1){if((n|0)>=(k|0)){break}c[f+(m<<8)+(n<<2)>>2]=(c[f+(m<<8)+(n-1<<2)>>2]|0)+(c[h+1472276+(m<<8)+(n-1<<2)>>2]<<3);n=n+1|0}m=m+1|0}m=0;while(1){if((m|0)>=(l|0)){break}n=0;while(1){if((n|0)>=(k|0)){break}_hc(g,b,m,n);o=(c[f+(m<<8)+(n<<2)>>2]|0)+(c[h+1472276+(m<<8)+(n<<2)>>2]<<3)|0;do{if((n|0)<(k-1|0)){p=17}else{if((m|0)<(l-1|0)){p=17;break}Noc(e,a+j|0)}}while(0);if((p|0)==17){p=0;Noc(e,a+j+4|0)}lkc(h,g,e,f+(m<<8)+(n<<2)|0,o);if((c[f+(m<<8)+(n<<2)>>2]|0)==(o|0)){}else{Cd(2272904,2540304,964,2652824);return 0}Poc(e);if((n|0)<(k-1|0)){p=23}else{if((m|0)<(l-1|0)){p=23}}if((p|0)==23){p=0;mkc(a+j|0,c[e+16>>2]|0);j=j+4|0}j=j+(c[e+16>>2]|0)|0;n=n+1|0}m=m+1|0}i=d;return j|0}function lkc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=a;a=b;b=d;d=e;e=f;f=c[a>>2]|0;while(1){if((f|0)>=(c[a+4>>2]|0)){break}mrc(h+107952|0,0,8)|0;j=c[a+8>>2]|0;while(1){if((j|0)>=(c[a+12>>2]|0)){break}nkc(h,a,b,d,e,f,j,12);j=j+8|0}f=f+8|0}i=g;return}function mkc(b,c){b=b|0;c=c|0;var d=0;d=c;c=b;a[c|0]=d>>24&255;a[c+1|0]=d>>16&255;a[c+2|0]=d>>8&255;a[c+3|0]=d>>0&255;i=i;return}function nkc(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;m=i;n=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=n+1434592|0;o=n+57488|0;p=c[1960336+(k<<2)>>2]|0;q=(1<<p|0)/4|0;r=(ca(h,c[l+10160>>2]|0)|0)+j|0;s=c[(c[l+10204>>2]|0)+(r<<2)>>2]|0;do{if((h|0)<(c[l+10148>>2]|0)){if((j|0)>=(c[l+10156>>2]|0)){break}r=734952+(p*52|0)+(c[s>>2]<<2)|0;t=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;okc(l,o,q,h,j,t,k,e);r=c[552416+(t*52|0)+(k<<2)>>2]|0;if(!(r>>>0<13>>>0)){Cd(2605056,2579488,248,2652208)}u=r;if(u>>>0<3>>>0){pkc(n,b,e,f,g,h,j)}else{r=t;if((r|0)==1){pkc(n,b,e,f,g,h,j);if((h+q|0)<(c[l+10148>>2]|0)){pkc(n,b,e,f,g,h+q|0,j)}}else if((r|0)==0){pkc(n,b,e,f,g,h,j)}else if((r|0)==2){pkc(n,b,e,f,g,h,j);if((j+q|0)<(c[l+10156>>2]|0)){pkc(n,b,e,f,g,h,j+q|0)}}else if((r|0)==3){nkc(n,b,e,f,g,h,j,u);nkc(n,b,e,f,g,h,j+q|0,u);nkc(n,b,e,f,g,h+q|0,j,u);nkc(n,b,e,f,g,h+q|0,j+q|0,u)}else{Cd(2414608,2540304,462,2649784)}}if(!(k>>>0>=3>>>0)){i=m;return}do{if((k|0)!=3){if((t|0)!=3){break}i=m;return}}while(0);t=o;r=u;v=c[777680+(k<<2)>>2]|0;mrc((c[t+50460>>2]|0)+j|0,a[735216+(r<<1)|0]&255|0,v|0)|0;mrc(t+50464+(h&7)|0,a[735217+(r<<1)|0]&255|0,v|0)|0;i=m;return}}while(0);i=m;return}function okc(b,e,f,g,h,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;m=i;n=b;b=f;f=g;g=h;h=j;j=l;l=e;e=k;k=(c[l+50460>>2]|0)+g|0;o=l+50464+(f&7)|0;l=c[830920+(e<<2)>>2]|0;p=1<<l;q=0;r=0;if((c[1960336+(e<<2)>>2]|0)!=(c[1960696+(e<<2)>>2]|0)){Cd(2509816,2495832,329,2651728)}if((l|0)<0){Cd(2485064,2495832,330,2651728)}e=0;while(1){if((e|0)>=(p|0)){break}q=q|a[k+e|0];r=r|a[o+e|0];e=e+1|0}q=(q&p|0)>0|0;r=(r&p|0)>0|0;p=n;e=(r<<1)+q+(l<<2)|0;if((c[p+10108>>2]|0)==0){s=215328+(e*3|0)|0}else{s=p+13666+(e*3|0)|0}e=s;s=(f+b|0)<(c[n+10148>>2]|0)|0;f=(g+b|0)<(c[n+10156>>2]|0)|0;do{if((s|0)!=0){if((f|0)==0){break}n=5467416+(h<<3)|0;b=j;g=207984;p=e;l=c[n>>2]|0;q=c[n+4>>2]|0;n=0;do{r=q-1|0;q=r;o=l>>r&1;tkc(b,o,d[p+(n<<24>>24>>1)|0]|0);n=a[g+((n<<24>>24)+o)|0]|0;}while((q|0)!=0);i=m;return}}while(0);do{if((s|0)!=0){t=22}else{if((f|0)==0){t=22;break}do{if((h|0)==3){u=1}else{if((h|0)==1){u=1;break}Cd(2559632,2540304,406,2649752)}}while(0);tkc(j,(h|0)==3|0,d[e+1|0]|0)}}while(0);if((t|0)==22){do{if((s|0)!=0){if((f|0)!=0){t=28;break}do{if((h|0)==3){v=1}else{if((h|0)==2){v=1;break}Cd(2542464,2540304,409,2649752)}}while(0);tkc(j,(h|0)==3|0,d[e+2|0]|0)}else{t=28}}while(0);if((t|0)==28){if((h|0)==3){}else{Cd(2525008,2540304,412,2649752)}}}i=m;return}function pkc(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;k=a;a=d;d=e;e=f;f=g;g=h;h=k+1434592|0;l=k+57488|0;c[l+160>>2]=(c[h+10204>>2]|0)+((ca(f,c[h+10160>>2]|0)|0)+g<<2);m=c[c[l+160>>2]>>2]|0;n=l;o=f;f=c[777736+(c[m>>2]<<2)>>2]|0;p=g;g=c[777680+(c[m>>2]<<2)>>2]|0;q=c[h+10148>>2]|0;r=c[h+10156>>2]|0;c[n+180>>2]=-(o<<3<<3);c[n+184>>2]=q-f-o<<3<<3;c[n+172>>2]=-(p<<3<<3);c[n+176>>2]=r-g-p<<3<<3;c[n+164>>2]=(o|0)!=0;c[n+168>>2]=(p|0)>(c[b+8>>2]|0);b=h;if((c[b+10108>>2]|0)==0){s=1}else{s=(c[b+10124>>2]|0)!=0}if((s&1|0)!=0){qkc(k,c[l+160>>2]|0,a)}else{rkc(k,m,a)}if((c[d>>2]|0)>>>0<e>>>0){t=1;u=t&1;v=a;w=d;x=e;skc(v,w,x);i=j;return}Cd(2336560,2540304,391,2649800);u=t&1;v=a;w=d;x=e;skc(v,w,x);i=j;return}function qkc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=b;b=e;e=f;f=h+1434592|0;j=h+57488|0;k=f+13408|0;l=c[b>>2]|0;m=c[b+(-(c[j+156>>2]|0)<<2)>>2]|0;if((c[j+168>>2]|0)!=0){n=c[b-4>>2]|0}else{n=0}b=n;n=l|0;j=c[n>>2]|0;if((a[k+1|0]|0)!=0){vkc(e,k,d[n+13|0]|0)}wkc(h,d[n+13|0]|0,l,e)|0;do{if(j>>>0>=3>>>0){if((c[f+10164>>2]|0)!=4){break}xkc(h,c[n+8>>2]|0,j,e)}}while(0);if(j>>>0>=3>>>0){h=c[n+4>>2]|0;f=l;k=0;o=cec(f,m,k)|0;ykc(e,h,214328+(o*90|0)+((bec(f,b,k)|0)*9|0)|0);p=e;q=n;r=q+16|0;s=c[r>>2]|0;t=n;u=t+4|0;v=c[u>>2]|0;w=215232+(v*9|0)|0;x=w|0;ykc(p,s,x);i=g;return}k=c[777792+(j<<2)>>2]|0;f=c[777848+(j<<2)>>2]|0;j=0;while(1){if((j|0)>=2){break}o=0;while(1){if((o|0)>=2){break}h=(j<<1)+o|0;y=c[l+76+(h*12|0)>>2]|0;z=l;A=h;h=cec(z,m,A)|0;ykc(e,y,214328+(h*90|0)+((bec(z,b,A)|0)*9|0)|0);o=o+k|0}j=j+f|0}p=e;q=n;r=q+16|0;s=c[r>>2]|0;t=n;u=t+4|0;v=c[u>>2]|0;w=215232+(v*9|0)|0;x=w|0;ykc(p,s,x);i=g;return}



function rkc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=b;b=e;e=f;f=h+1434592|0;j=f+15510|0;k=h+57488|0;l=f+13408|0;m=b|0;n=c[m+4>>2]|0;o=d[m+13|0]|0;p=c[m>>2]|0;q=c[f+10128>>2]|0;r=(c[m+20>>2]|0)>0|0;s=(c[m+24>>2]|0)>0|0;if((a[l+1|0]|0)!=0){if((a[l+4|0]|0)!=0){t=d[m+14|0]|0;u=k;v=u;if((c[v+164>>2]|0)!=0){w=c[(c[v+160>>2]|0)+(-(c[v+156>>2]|0)<<2)>>2]|0}else{w=0}v=w;w=u;if((c[w+168>>2]|0)!=0){x=c[(c[w+160>>2]|0)-4>>2]|0}else{x=0}w=x;if((v|0)!=0){y=d[v+14|0]|0}else{y=0}if((w|0)!=0){z=d[w+14|0]|0}else{z=0}tkc(e,t,d[l+12+(y+z)|0]|0);if((t|0)==0){vkc(e,l,o)}}else{vkc(e,l,o)}}t=wkc(h,o,b,e)|0;if((Thc(l,o,2)|0)==0){tkc(e,r,d[f+15471+(dgc(k)|0)|0]|0)}do{if(p>>>0>=3>>>0){if((c[f+10164>>2]|0)!=4){break}if((r|0)!=0){if((t|0)!=0){break}if((Thc(l,o,3)|0)!=0){break}}xkc(h,c[m+8>>2]|0,p,e)}}while(0);if((r|0)==0){if(p>>>0>=3>>>0){ykc(e,n,f+13540+((c[564816+(p<<2)>>2]|0)*9|0)|0)}else{r=c[777792+(p<<2)>>2]|0;t=c[777848+(p<<2)>>2]|0;z=0;while(1){if((z|0)>=2){break}y=0;while(1){if((y|0)>=2){break}ykc(e,c[b+76+(((z<<1)+y|0)*12|0)>>2]|0,f+13540|0);y=y+r|0}z=z+t|0}}ykc(e,c[m+16>>2]|0,f+13576+(n*9|0)|0);i=g;return}t=d[m+68+(c[m+20>>2]|0)|0]|0;z=f+15450+(t*3|0)|0;zkc(h,e);if((Thc(l,o,3)|0)==0){if(p>>>0>=3>>>0){Akc(e,n,z);o=f+36124+(t<<4)+(n-10<<2)|0;c[o>>2]=(c[o>>2]|0)+1}}if((c[f+10220>>2]|0)==4){o=f+15442+((cgc(k)|0)<<1)|0;k=5083480+(c[m+72>>2]<<3)|0;l=e;r=202680;y=o;o=c[k>>2]|0;w=c[k+4>>2]|0;k=0;do{v=w-1|0;w=v;x=o>>v&1;tkc(l,x,d[y+(k<<24>>24>>1)|0]|0);k=a[r+((k<<24>>24)+x)|0]|0;}while((w|0)!=0)}else{if((c[m+72>>2]|0)==(c[f+10220>>2]|0)){}else{Cd(2279056,2540304,301,2651800)}}if(p>>>0<3>>>0){w=c[777792+(p<<2)>>2]|0;k=c[777848+(p<<2)>>2]|0;p=0;while(1){if((p|0)>=2){break}r=0;while(1){if((r|0)>=2){break}y=(p<<1)+r|0;l=c[b+76+(y*12|0)>>2]|0;Akc(e,l,z);o=f+36124+(t<<4)+(l-10<<2)|0;c[o>>2]=(c[o>>2]|0)+1;if((l|0)==13){A=0;while(1){if((A|0)>=(s+1|0)){break}Pmc(h,e,b+76+(y*12|0)+4+(A<<2)|0,m+36+(c[m+20+(A<<2)>>2]<<3)|0,j,q);A=A+1|0}}r=r+w|0}p=p+k|0}}else{if((n|0)==13){A=0;while(1){if((A|0)>=(s+1|0)){break}Pmc(h,e,m+28+(A<<2)|0,m+36+(c[m+20+(A<<2)>>2]<<3)|0,j,q);A=A+1|0}}}i=g;return}function skc(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;j=e;e=f;f=g;g=c[e>>2]|0;while(1){if(g>>>0<f>>>0){k=(d[g+6|0]|0)!=127}else{k=0}if(!k){break}l=d[g+6|0]|0;m=3348768+(l<<3)|0;n=218528+(l<<4)|0;o=0;p=c[m>>2]|0;q=c[m+4>>2]|0;if((a[g+7|0]|0)!=0){q=q-(d[g+7|0]|0)|0;o=d[g+7|0]<<1}do{if((l|0)>=2){if((l|0)>=11){r=14;break}m=3-(d[g+7|0]|0)|0;s=j;t=233600;u=c[g>>2]|0;v=p>>q-m;w=m;x=o&255;do{y=w-1|0;w=y;z=v>>y&1;tkc(s,z,d[u+(x<<24>>24>>1)|0]|0);x=a[t+((x<<24>>24)+z)|0]|0;}while((w|0)!=0);w=j;x=233624;t=207992+((d[(c[g>>2]|0)+2|0]|0)-1<<3)|0;u=p;s=q-m|0;v=0;do{z=s-1|0;s=z;y=u>>z&1;tkc(w,y,d[t+(v<<24>>24>>1)|0]|0);v=a[x+((v<<24>>24)+y)|0]|0;}while((s|0)!=0)}else{r=14}}while(0);if((r|0)==14){r=0;l=j;s=233600;v=c[g>>2]|0;x=p;t=q;w=o&255;do{u=t-1|0;t=u;m=x>>u&1;tkc(l,m,d[v+(w<<24>>24>>1)|0]|0);w=a[s+((w<<24>>24)+m)|0]|0;}while((t|0)!=0)}if((c[n+12>>2]|0)!=0){t=b[g+4>>1]|0;w=c[n+8>>2]|0;if((w|0)!=0){s=c[n+4>>2]|0;v=t>>1;l=w;w=0;do{x=l-1|0;l=x;o=v>>x&1;tkc(j,o,d[s+(w>>1)|0]|0);w=a[(c[n>>2]|0)+(w+o)|0]|0;}while((l|0)!=0)}ukc(j,t&1)}g=g+8|0}c[e>>2]=g+(((d[g+6|0]|0)==127)<<3);i=h;return}function tkc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=b;b=c[h+12>>2]|0;j=c[h+4>>2]|0;k=c[h>>2]|0;l=((ca(j-1|0,f)|0)>>>8)+1|0;j=l;if((e|0)!=0){k=k+l|0;j=(c[h+4>>2]|0)-l|0}l=d[211576+j|0]|0;j=j<<l;b=b+l|0;if((b|0)<0){m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+12|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}e=l-b|0;if((k<<e-1&-2147483648|0)!=0){f=(c[h+16>>2]|0)-1|0;while(1){if((f|0)>=0){y=(d[(c[h+20>>2]|0)+f|0]|0|0)==255}else{y=0}if(!y){break}a[(c[h+20>>2]|0)+f|0]=0;f=f-1|0}y=(c[h+20>>2]|0)+f|0;a[y]=(d[y]|0)+1}y=h+16|0;f=c[y>>2]|0;c[y>>2]=f+1;a[(c[h+20>>2]|0)+f|0]=k>>>((24-e|0)>>>0);k=k<<e;l=b;k=k&16777215;b=b-8|0;m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+12|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}function ukc(a,b){a=a|0;b=b|0;var c=0;c=i;tkc(a,b,128);i=c;return}function vkc(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=c;if((d[g|0]|0|0)==0){i=f;return}if((d[g+1|0]|0|0)==0){i=f;return}c=b;b=204312;h=g+5|0;g=e;e=3;j=0;do{k=e-1|0;e=k;l=g>>k&1;tkc(c,l,d[h+(j<<24>>24>>1)|0]|0);j=a[b+((j<<24>>24)+l)|0]|0;}while((e|0)!=0);i=f;return}function wkc(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=a;if((Thc(h+1448e3|0,b,3)|0)!=0){j=1;k=j;i=g;return k|0}b=d[e+12|0]|0;e=h+57488|0;a=e;if((c[a+164>>2]|0)!=0){l=c[(c[a+160>>2]|0)+(-(c[a+156>>2]|0)<<2)>>2]|0}else{l=0}a=l;l=e;if((c[l+168>>2]|0)!=0){m=c[(c[l+160>>2]|0)-4>>2]|0}else{m=0}l=m;if((a|0)!=0){n=d[a+12|0]|0}else{n=0}if((l|0)!=0){o=d[l+12|0]|0}else{o=0}tkc(f,b,d[h+1450099+(n+o)|0]|0);j=b;k=j;i=g;return k|0}function xkc(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=b;b=f;f=c[833024+(e<<2)>>2]|0;e=igc(h+57488|0)|0;j=h+1450087|0;h=f;if((h|0)==3){k=j+(e*3|0)|0}else if((h|0)==2){k=j+6+(e<<1)|0}else if((h|0)==1){k=j+10+e|0}else{Cd(2112136,2629952,111,2652112)}e=k;tkc(b,(a|0)!=0|0,d[e|0]|0);if((a|0)==0){i=g;return}if(!(f>>>0>=2>>>0)){i=g;return}tkc(b,(a|0)!=1|0,d[e+1|0]|0);do{if((a|0)!=1){if(!(f>>>0>=3>>>0)){break}tkc(b,(a|0)!=2|0,d[e+2|0]|0)}}while(0);i=g;return}function ykc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=5899176+(e<<3)|0;e=b;b=215456;j=f;f=c[h>>2]|0;k=c[h+4>>2]|0;h=0;do{l=k-1|0;k=l;m=f>>l&1;tkc(e,m,d[j+(h<<24>>24>>1)|0]|0);h=a[b+((h<<24>>24)+m)|0]|0;}while((k|0)!=0);i=g;return}function zkc(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=f+1434592|0;g=f+57488|0;f=c[c[g+160>>2]>>2]|0;h=(c[f+24>>2]|0)>0|0;j=d[f+13|0]|0;if((Thc(b+13408|0,j,2)|0)!=0){if((h|0)!=0){Cd(2191792,2540304,202,2649712)}else{}k=c[f+20>>2]|0;if((k|0)==(Zhc(b+13408|0,j,2)|0)){}else{Cd(2160880,2540304,204,2649712)}i=e;return}if((c[b+13536>>2]|0)==2){j=b;tkc(a,h,d[j+15475+(egc(j,g)|0)|0]|0)}else{if((((h|0)!=0^1)&1|0)==((c[b+13536>>2]|0)==0|0)){}else{Cd(2135528,2540304,211,2649712)}}if((h|0)!=0){h=(c[f+20>>2]|0)==2|0;j=b;tkc(a,h,d[j+15490+(fgc(j,g)|0)|0]|0)}else{j=(c[f+20>>2]|0)!=1|0;tkc(a,j,d[b+15480+((ggc(g)|0)<<1)|0]|0);if((j|0)!=0){j=(c[f+20>>2]|0)!=2|0;tkc(a,j,d[b+15480+((hgc(g)|0)<<1)+1|0]|0)}}i=e;return}function Akc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=e;e=h;if(e>>>0>=10>>>0){j=e>>>0<=13>>>0}else{j=0}if((j&1|0)!=0){}else{Cd(2229784,2540304,57,2649816)}j=5901928+(h-10<<3)|0;h=b;b=215488;e=f;f=c[j>>2]|0;k=c[j+4>>2]|0;j=0;do{l=k-1|0;k=l;m=f>>l&1;tkc(h,m,d[e+(j<<24>>24>>1)|0]|0);j=a[b+((j<<24>>24)+m)|0]|0;}while((k|0)!=0);i=g;return}function Bkc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+48|0;e=d|0;f=d+8|0;g=d+24|0;h=a;a=b;if((c[h+10164>>2]|0)>>>0<3>>>0){j=c[h+10164>>2]|0}else{j=3}Ikc(a,j,2);if((c[h+10164>>2]|0)>>>0>=3>>>0){ukc(a,(c[h+10164>>2]|0)==4|0)}if((c[h+10164>>2]|0)!=4){i=d;return}j=0;while(1){if((j|0)>=2){break}Dec(h+36484+(j<<3)|0,e|0);k=0;while(1){if((k|0)>=1){break}Eoc(a,h+15505+j+k|0,e+(k<<3)|0);k=k+1|0}j=j+1|0}j=0;while(1){if((j|0)>=2){break}Cec(h+36460+(j*12|0)|0,f|0);k=0;while(1){if((k|0)>=2){break}Eoc(a,h+15501+(j<<1)+k|0,f+(k<<3)|0);k=k+1|0}j=j+1|0}j=0;while(1){if((j|0)>=2){break}Bec(h+36428+(j<<4)|0,g|0);k=0;while(1){if((k|0)>=3){break}Eoc(a,h+15495+(j*3|0)+k|0,g+(k<<3)|0);k=k+1|0}j=j+1|0}i=d;return}function Ckc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+50688|0;e=d|0;f=a;a=b;b=c[301584+(c[f+1444756>>2]<<2)>>2]|0;g=0;while(1){if(!(g>>>0<=3>>>0)){break}Gkc(f,g,e+(g*12672|0)|0);g=g+1|0}g=0;while(1){if(!(g>>>0<=b>>>0)){break}Hkc(a,f,g,e+(g*12672|0)|0);g=g+1|0}i=d;return}function Dkc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>=3){break}Eoc(a,d+15507+b|0,d+36500+(b<<3)|0);b=b+1|0}i=c;return}function Ekc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+256|0;g=f|0;h=b;b=d;d=e;if((b|0)<=32){}else{Cd(2465152,2540304,75,2651664)}u6b(a,g|0,c);c=0;while(1){if((c|0)>=(b-1|0)){break}Eoc(d,h+c|0,g+(c<<3)|0);c=c+1|0}i=f;return}function Fkc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=a;a=b;b=0;while(1){if((b|0)>=4){break}Ekc(202680,d+15442+(b<<1)|0,d+36076+(b*12|0)|0,3,a);b=b+1|0}i=c;return}function Gkc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=b;b=d;d=e;e=g+2045020+(b*432|0)|0;h=g+2017372+(b*6912|0)|0;j=g+1468364+(b*576|0)|0;b=0;while(1){if((b|0)>=2){break}g=0;while(1){if((g|0)>=2){break}k=0;while(1){if((k|0)>=6){break}l=0;while(1){if((l|0)>=(((k|0)==0?3:6)|0)){break}u6b(233600,d+(b*6336|0)+(g*3168|0)+(k*528|0)+(l*88|0)|0,h+(b*3456|0)+(g*1728|0)+(k*288|0)+(l*48|0)|0);c[d+(b*6336|0)+(g*3168|0)+(k*528|0)+(l*88|0)+4>>2]=(c[j+(b*288|0)+(g*144|0)+(k*24|0)+(l<<2)>>2]|0)-(c[d+(b*6336|0)+(g*3168|0)+(k*528|0)+(l*88|0)>>2]|0);m=0;while(1){if((m|0)>=3){break}n=c[d+(b*6336|0)+(g*3168|0)+(k*528|0)+(l*88|0)+(m<<3)>>2]|0;o=n+(c[d+(b*6336|0)+(g*3168|0)+(k*528|0)+(l*88|0)+(m<<3)+4>>2]|0)|0;if((o|0)==0){p=128}else{q=((n<<8)+(o>>1)|0)/(o|0)|0;if((q|0)>255){r=255}else{if((q|0)<1){s=1}else{s=q}r=s}p=r&255}a[e+(b*216|0)+(g*108|0)+(k*18|0)+(l*3|0)+m|0]=p;m=m+1|0}l=l+1|0}k=k+1|0}g=g+1|0}b=b+1|0}i=f;return}function Hkc(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+32|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=b;b=e;e=f;f=g;g=b+2045020+(e*432|0)|0;o=b+1448306+(e*432|0)|0;e=c[b+2047080>>2]|0;if((e|0)==0){p=0;mrc(j|0,0,8)|0;q=0;while(1){if((q|0)>=2){break}r=0;while(1){if((r|0)>=2){break}s=0;while(1){if((s|0)>=6){break}t=0;while(1){if((t|0)>=(((s|0)==0?3:6)|0)){break}u=0;while(1){if((u|0)>=3){break}a[k]=a[g+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)+u|0]|0;v=a[o+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)+u|0]|0;w=0;if((u|0)==2){x=Doc(f+(q*6336|0)+(r*3168|0)+(s*528|0)+(t*88|0)|0,o+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)|0,k,-4)|0}else{x=Boc(f+(q*6336|0)+(r*3168|0)+(s*528|0)+(t*88|0)+(u<<3)|0,v,k,-4)|0}do{if((x|0)>0){if((d[k]|0|0)==(v&255|0)){break}w=1}}while(0);if((w|0)!=0){p=p+(x-(c[51970]|0))|0}else{p=p-(c[51970]|0)|0}v=j+(w<<2)|0;c[v>>2]=(c[v>>2]|0)+1;u=u+1|0}t=t+1|0}s=s+1|0}r=r+1|0}q=q+1|0}do{if((c[j+4>>2]|0)!=0){if((p|0)<0){break}ukc(n,1);q=0;while(1){if((q|0)>=2){break}r=0;while(1){if((r|0)>=2){break}s=0;while(1){if((s|0)>=6){break}t=0;while(1){if((t|0)>=(((s|0)==0?3:6)|0)){break}u=0;while(1){if((u|0)>=3){break}a[l]=a[g+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)+u|0]|0;x=o+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)+u|0;k=0;if((u|0)==2){y=Doc(f+(q*6336|0)+(r*3168|0)+(s*528|0)+(t*88|0)|0,o+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)|0,l,-4)|0}else{y=Boc(f+(q*6336|0)+(r*3168|0)+(s*528|0)+(t*88|0)+(u<<3)|0,a[x]|0,l,-4)|0}do{if((y|0)>0){if((d[l]|0|0)==(d[x]|0|0)){break}k=1}}while(0);tkc(n,k,252);if((k|0)!=0){woc(n,a[l]|0,a[x]|0);a[x]=a[l]|0}u=u+1|0}t=t+1|0}s=s+1|0}r=r+1|0}q=q+1|0}i=h;return}}while(0);ukc(n,0);i=h;return}else if((e|0)==1|(e|0)==2){e=(c[b+2047080>>2]|0)==2?3:6;l=(c[b+2047080>>2]|0)==2?3:6;b=0;y=0;q=0;while(1){if((q|0)>=2){break}r=0;while(1){if((r|0)>=2){break}s=0;while(1){if((s|0)>=6){break}t=0;while(1){if((t|0)>=(((s|0)==0?3:6)|0)){break}u=0;while(1){if((u|0)>=3){break}a[m]=a[g+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)+u|0]|0;p=o+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)+u|0;j=0;do{if((t|0)>=(e|0)){z=75}else{if((s|0)>=(l|0)){z=75;break}if((u|0)==2){A=Doc(f+(q*6336|0)+(r*3168|0)+(s*528|0)+(t*88|0)|0,o+(q*216|0)+(r*108|0)+(s*18|0)+(t*3|0)|0,m,-4)|0}else{A=Boc(f+(q*6336|0)+(r*3168|0)+(s*528|0)+(t*88|0)+(u<<3)|0,a[p]|0,m,-4)|0}do{if((A|0)>0){if((d[m]|0|0)==(d[p]|0|0)){break}j=1}}while(0)}}while(0);if((z|0)==75){z=0;j=0}b=b+j|0;do{if((j|0)==0){if((b|0)!=0){z=86;break}y=y+1|0}else{z=86}}while(0);if((z|0)==86){z=0;do{if((j|0)==1){if((b|0)!=1){break}ukc(n,1);x=0;while(1){if((x|0)>=(y|0)){break}tkc(n,0,252);x=x+1|0}}}while(0);tkc(n,j,252);if((j|0)!=0){woc(n,a[m]|0,a[p]|0);a[p]=a[m]|0}}u=u+1|0}t=t+1|0}s=s+1|0}r=r+1|0}q=q+1|0}if((b|0)==0){ukc(n,0)}i=h;return}else{Cd(2414608,2540304,664,2651120)}}function Ikc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=a;a=b;b=c-1|0;while(1){if((b|0)<0){break}ukc(e,1&a>>b);b=b-1|0}i=d;return}function Jkc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=a;a=b;if(d>>>0<3>>>0){}else{Cd(2436240,2540304,1036,2649736)}Loc(a,d&1);Loc(a,d>>>1);i=c;return}function Kkc(a){a=a|0;var b=0,c=0;b=i;c=a;Moc(c,73,8);Moc(c,131,8);Moc(c,66,8);i=b;return}function Lkc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=b;Moc(a,(c[e+8452>>2]|0)-1|0,16);Moc(a,(c[e+8456>>2]|0)-1|0,16);Wkc(e,a);i=d;return}function Mkc(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;do{if((c[d+1472148>>2]|0)!=0){if((c[d+1472152>>2]|0)!=0){break}if((c[d+2050800>>2]|0)!=0){break}e=c[d+1472144>>2]<<c[d+1472132>>2]|c[d+1472148>>2]<<c[d+1472140>>2];f=e;i=b;return f|0}}while(0);e=c[d+1472144>>2]<<c[d+1472132>>2]|c[d+1472148>>2]<<c[d+1472136>>2]|c[d+1472152>>2]<<c[d+1472140>>2];f=e;i=b;return f|0}function Nkc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=a;a=b;b=e+1434592|0;f=0;g=1;while(1){if((g|0)>3){break}h=e;j=h+1434592|0;k=h;h=g;do{if((h|0)==1){l=c[k+1472132>>2]|0}else{if((h|0)==2){l=c[k+1472136>>2]|0;break}else{l=c[k+1472140>>2]|0;break}}}while(0);k=j+8488+((c[j+9784+(l<<2)>>2]|0)*108|0)+16|0;if((c[b+8452>>2]|0)==(c[k+8>>2]|0)){m=(c[b+8456>>2]|0)==(c[k+12>>2]|0)}else{m=0}f=m&1;if((c[e+2050800>>2]|0)!=0){f=0}Loc(a,f);if((f|0)!=0){k=13;break}g=g+1|0}if((f|0)!=0){n=b;o=a;Wkc(n,o);i=d;return}Moc(a,(c[b+8452>>2]|0)-1|0,16);Moc(a,(c[b+8456>>2]|0)-1|0,16);n=b;o=a;Wkc(n,o);i=d;return}function Okc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+16|0;d=b|0;e=a;if((c[e+10220>>2]|0)!=4){i=b;return}a=0;f=0;while(1){if((f|0)>=3){break}c[d+(f<<2)>>2]=0;g=0;while(1){if((g|0)>=4){break}h=d+(f<<2)|0;c[h>>2]=(c[h>>2]|0)+(c[e+36076+(g*12|0)+(f<<2)>>2]|0);g=g+1|0}a=a+((c[d+(f<<2)>>2]|0)>0)|0;f=f+1|0}if((a|0)==1){f=0;while(1){if((f|0)>=3){break}if((c[d+(f<<2)>>2]|0)!=0){j=14;break}f=f+1|0}if((j|0)==14){c[e+10220>>2]=f}}i=b;return}function Pkc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=b;Loc(a,(e|0)==4|0);if((e|0)==4){i=d;return}Moc(a,c[110176+(e<<2)>>2]|0,2);i=d;return}function Qkc(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=b;b=e;Moc(b,c[g>>2]|0,6);Moc(b,c[g+4>>2]|0,3);Loc(b,d[g+12|0]|0);if((a[g+12|0]|0)==0){i=f;return}Loc(b,d[g+13|0]|0);if((a[g+13|0]|0)!=0){e=0;while(1){if((e|0)>=4){break}h=a[g+14+e|0]|0;j=(h|0)!=(a[g+18+e|0]|0)|0;Loc(b,j);if((j|0)!=0){a[g+18+e|0]=h;Moc(b,(R(h|0)|0)&63,6);Loc(b,(h|0)<0|0)}e=e+1|0}e=0;while(1){if((e|0)>=2){break}h=a[g+22+e|0]|0;j=(h|0)!=(a[g+24+e|0]|0)|0;Loc(b,j);if((j|0)!=0){a[g+24+e|0]=h;Moc(b,(R(h|0)|0)&63,6);Loc(b,(h|0)<0|0)}e=e+1|0}}i=f;return}function Rkc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;a=b;Moc(a,c[e+10168>>2]|0,8);Vkc(a,c[e+10172>>2]|0);Vkc(a,c[e+10176>>2]|0);Vkc(a,c[e+10180>>2]|0);i=d;return}function Skc(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=b;b=c;c=f+1448e3|0;Loc(b,d[c|0]|0);if((a[c|0]|0)==0){i=e;return}Loc(b,d[c+1|0]|0);if((a[c+1|0]|0)!=0){N5b(f);g=0;while(1){if((g|0)>=7){break}f=d[c+5+g|0]|0;h=(f|0)!=255|0;Loc(b,h);if((h|0)!=0){Moc(b,f,8)}g=g+1|0}Loc(b,d[c+4|0]|0);if((a[c+4|0]|0)!=0){g=0;while(1){if((g|0)>=3){break}f=d[c+12+g|0]|0;h=(f|0)!=255|0;Loc(b,h);if((h|0)!=0){Moc(b,f,8)}g=g+1|0}}}Loc(b,d[c+2|0]|0);if((a[c+2|0]|0)==0){i=e;return}Loc(b,d[c+3|0]|0);g=0;while(1){if((g|0)>=8){break}f=0;while(1){if((f|0)>=4){break}h=Thc(c,g,f)|0;Loc(b,h);if((h|0)!=0){h=Zhc(c,g,f)|0;j=Whc(f)|0;if((Xhc(f)|0)!=0){Ukc(b,R(h|0)|0,j);Loc(b,(h|0)<0|0)}else{Ukc(b,h,j)}}f=f+1|0}g=g+1|0}i=e;return}function Tkc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=a;a=b;aic(c[g+10156>>2]|0,e,f);b=(c[g+36972>>2]|0)-(c[e>>2]|0)|0;while(1){e=b;b=e-1|0;if((e|0)==0){break}Loc(a,1)}if((c[g+36972>>2]|0)<(c[f>>2]|0)){Loc(a,0)}Loc(a,(c[g+36976>>2]|0)!=0|0);if((c[g+36976>>2]|0)==0){i=d;return}Loc(a,(c[g+36976>>2]|0)!=1|0);i=d;return}function Ukc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=i;e=c;if(e>>>0>0>>>0){f=(31^(rrc(e|0)|0))+1|0}else{f=0}Moc(a,b,f);i=d;return}function Vkc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=a;a=b;if((a|0)!=0){Loc(d,1);Moc(d,R(a|0)|0,4);Loc(d,(a|0)<0|0);i=c;return}else{Loc(d,0);i=c;return}}function Wkc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;if((c[e+8452>>2]|0)!=(c[e+8460>>2]|0)){f=1}else{f=(c[e+8456>>2]|0)!=(c[e+8464>>2]|0)}b=f&1;Loc(a,b);if((b|0)==0){i=d;return}Moc(a,(c[e+8460>>2]|0)-1|0,16);Moc(a,(c[e+8464>>2]|0)-1|0,16);i=d;return}function Xkc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;Ykc(a,c,b,0,0);i=d;return}function Ykc(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=b;b=d;d=e;e=f;f=g;g=a[d+((e|0)/2|0)|0]|0;k=0;while(1){if((k|0)>1){break}if((k|0)!=0){l=255-(g&255)|0}else{l=g&255}m=f+(c[206872+(l<<2)>>2]|0)|0;n=a[b+(e+k)|0]|0;if((n<<24>>24|0)<=0){c[j+(-(n<<24>>24)<<2)>>2]=m}else{Ykc(j,b,d,n<<24>>24,m)}k=k+1|0}i=h;return}function Zkc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=e;e=f;if((a[e|0]|0)<=0){if((a[e+1|0]|0)>0){}else{j=3}}else{j=3}if((j|0)==3){Cd(2270424,2539872,58,2650656)}c[h+(-(a[e|0]|0)<<2)>>2]=c[206872+(d[b|0]<<2)>>2];Ykc(h,e,b,2,0);i=g;return}function _kc(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+64|0;g=f|0;h=f+32|0;j=f+48|0;k=d;d=e;e=a;a=g|0;l=0;a:while(1){if((l|0)>=2){m=27;break}n=0;while(1){if((n|0)>=4){break}if(0==(l|0)){c[h>>2]=b[e+(0<<1)>>1]<<4;c[h+4>>2]=b[e+(d<<1)>>1]<<4;c[h+8>>2]=b[e+(d<<1<<1)>>1]<<4;c[h+12>>2]=b[e+((d*3|0)<<1)>>1]<<4;do{if((n|0)==0){if((c[h>>2]|0)==0){break}o=h|0;c[o>>2]=(c[o>>2]|0)+1}}while(0)}else{c[h>>2]=b[e>>1]|0;c[h+4>>2]=b[e+8>>1]|0;c[h+8>>2]=b[e+16>>1]|0;c[h+12>>2]=b[e+24>>1]|0}c[j>>2]=(c[h>>2]|0)+(c[h+12>>2]|0);c[j+4>>2]=(c[h+4>>2]|0)+(c[h+8>>2]|0);c[j+8>>2]=(c[h+4>>2]|0)-(c[h+8>>2]|0);c[j+12>>2]=(c[h>>2]|0)-(c[h+12>>2]|0);o=((c[j>>2]|0)+(c[j+4>>2]|0)|0)*11585|0;p=((c[j>>2]|0)-(c[j+4>>2]|0)|0)*11585|0;q=o+8192>>14;if(!(-32768<=(q|0))){m=13;break a}if((q|0)>32767){m=13;break a}b[a>>1]=q;q=p+8192>>14;if(!(-32768<=(q|0))){m=16;break a}if((q|0)>32767){m=16;break a}b[a+4>>1]=q;o=((c[j+8>>2]|0)*6270|0)+((c[j+12>>2]|0)*15137|0)|0;p=((-(c[j+8>>2]|0)|0)*15137|0)+((c[j+12>>2]|0)*6270|0)|0;q=o+8192>>14;if(!(-32768<=(q|0))){m=19;break a}if((q|0)>32767){m=19;break a}b[a+2>>1]=q;q=p+8192>>14;if(!(-32768<=(q|0))){m=22;break a}if((q|0)>32767){m=22;break a}b[a+6>>1]=q;e=e+2|0;a=a+8|0;n=n+1|0}e=g|0;a=k;l=l+1|0}if((m|0)==13){Cd(2414424,2539808,23,2652784)}else if((m|0)==16){Cd(2414424,2539808,23,2652784)}else if((m|0)==19){Cd(2414424,2539808,23,2652784)}else if((m|0)==22){Cd(2414424,2539808,23,2652784)}else if((m|0)==27){m=0;while(1){if((m|0)>=4){break}l=0;while(1){if((l|0)>=4){break}b[k+(l+(m<<2)<<1)>>1]=(b[k+(l+(m<<2)<<1)>>1]|0)+1>>2;l=l+1|0}m=m+1|0}i=f;return}}function $kc(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+56|0;h=g|0;j=g+32|0;k=g+40|0;l=g+48|0;m=a;a=d;d=e;e=f;if((e|0)==0){_kc(m,a,d);i=g;return}f=h|0;n=l;o=2659272+(e<<3)|0;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];o=0;while(1){if((o|0)>=4){break}p=0;while(1){if((p|0)>=4){break}b[j+(p<<1)>>1]=b[m+((ca(p,d)|0)+o<<1)>>1]<<4;p=p+1|0}do{if((o|0)==0){if((b[j>>1]|0)==0){break}n=j|0;b[n>>1]=(b[n>>1]|0)+1}}while(0);re[c[l>>2]&1023](j|0,k|0);p=0;while(1){if((p|0)>=4){break}b[f+((p<<2)+o<<1)>>1]=b[k+(p<<1)>>1]|0;p=p+1|0}o=o+1|0}o=0;while(1){if((o|0)>=4){break}p=0;while(1){if((p|0)>=4){break}b[j+(p<<1)>>1]=b[h+(p+(o<<2)<<1)>>1]|0;p=p+1|0}re[c[l+4>>2]&1023](j|0,k|0);p=0;while(1){if((p|0)>=4){break}b[a+(p+(o<<2)<<1)>>1]=(b[k+(p<<1)>>1]|0)+1>>2;p=p+1|0}o=o+1|0}i=g;return}function alc(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e|0;g=a;a=c;c=d;d=f|0;h=0;while(1){if((h|0)>=8){j=35;break}k=(b[g+(0<<1)>>1]|0)+(b[g+((c*7|0)<<1)>>1]|0)<<2;l=(b[g+(c<<1)>>1]|0)+(b[g+((c*6|0)<<1)>>1]|0)<<2;m=(b[g+(c<<1<<1)>>1]|0)+(b[g+((c*5|0)<<1)>>1]|0)<<2;n=(b[g+((c*3|0)<<1)>>1]|0)+(b[g+(c<<2<<1)>>1]|0)<<2;o=(b[g+((c*3|0)<<1)>>1]|0)-(b[g+(c<<2<<1)>>1]|0)<<2;p=(b[g+(c<<1<<1)>>1]|0)-(b[g+((c*5|0)<<1)>>1]|0)<<2;q=(b[g+(c<<1)>>1]|0)-(b[g+((c*6|0)<<1)>>1]|0)<<2;r=(b[g+(0<<1)>>1]|0)-(b[g+((c*7|0)<<1)>>1]|0)<<2;s=k+n|0;t=l+m|0;u=l-m|0;m=k-n|0;n=(s+t|0)*11585|0;k=(s-t|0)*11585|0;l=(u*6270|0)+(m*15137|0)|0;v=((-u|0)*15137|0)+(m*6270|0)|0;w=n+8192>>14;if(!(-32768<=(w|0))){j=5;break}if((w|0)>32767){j=5;break}b[d>>1]=w;w=l+8192>>14;if(!(-32768<=(w|0))){j=8;break}if((w|0)>32767){j=8;break}b[d+32>>1]=w;w=k+8192>>14;if(!(-32768<=(w|0))){j=11;break}if((w|0)>32767){j=11;break}b[d+64>>1]=w;w=v+8192>>14;if(!(-32768<=(w|0))){j=14;break}if((w|0)>32767){j=14;break}b[d+96>>1]=w;n=(q-p|0)*11585|0;k=(q+p|0)*11585|0;p=n+8192>>14;if(!(-32768<=(p|0))){j=17;break}if((p|0)>32767){j=17;break}l=p;p=k+8192>>14;if(!(-32768<=(p|0))){j=20;break}if((p|0)>32767){j=20;break}v=p;s=o+l|0;t=o-l|0;u=r-v|0;m=r+v|0;n=(s*3196|0)+(m*16069|0)|0;k=(t*13623|0)+(u*9102|0)|0;l=(u*13623|0)+(t*-9102|0)|0;v=(m*3196|0)+(s*-16069|0)|0;s=n+8192>>14;if(!(-32768<=(s|0))){j=23;break}if((s|0)>32767){j=23;break}b[d+16>>1]=s;s=l+8192>>14;if(!(-32768<=(s|0))){j=26;break}if((s|0)>32767){j=26;break}b[d+48>>1]=s;s=k+8192>>14;if(!(-32768<=(s|0))){j=29;break}if((s|0)>32767){j=29;break}b[d+80>>1]=s;s=v+8192>>14;if(!(-32768<=(s|0))){j=32;break}if((s|0)>32767){j=32;break}b[d+112>>1]=s;g=g+2|0;d=d+2|0;h=h+1|0}if((j|0)==5){Cd(2414424,2539808,23,2652784)}else if((j|0)==8){Cd(2414424,2539808,23,2652784)}else if((j|0)==11){Cd(2414424,2539808,23,2652784)}else if((j|0)==14){Cd(2414424,2539808,23,2652784)}else if((j|0)==17){Cd(2414424,2539808,23,2652784)}else if((j|0)==20){Cd(2414424,2539808,23,2652784)}else if((j|0)==23){Cd(2414424,2539808,23,2652784)}else if((j|0)==26){Cd(2414424,2539808,23,2652784)}else if((j|0)==29){Cd(2414424,2539808,23,2652784)}else if((j|0)==32){Cd(2414424,2539808,23,2652784)}else if((j|0)==35){j=0;while(1){if((j|0)>=8){break}blc(f+(j<<3<<1)|0,a+(j<<3<<1)|0);h=0;while(1){if((h|0)>=8){break}d=a+(h+(j<<3)<<1)|0;b[d>>1]=(b[d>>1]|0)/2|0;h=h+1|0}j=j+1|0}i=e;return}}function blc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=a;a=c;c=(b[e>>1]|0)+(b[e+14>>1]|0)|0;f=(b[e+2>>1]|0)+(b[e+12>>1]|0)|0;g=(b[e+4>>1]|0)+(b[e+10>>1]|0)|0;h=(b[e+6>>1]|0)+(b[e+8>>1]|0)|0;j=(b[e+6>>1]|0)-(b[e+8>>1]|0)|0;k=(b[e+4>>1]|0)-(b[e+10>>1]|0)|0;l=(b[e+2>>1]|0)-(b[e+12>>1]|0)|0;m=(b[e>>1]|0)-(b[e+14>>1]|0)|0;e=c+h|0;n=f+g|0;o=f-g|0;g=c-h|0;h=(e+n|0)*11585|0;c=(e-n|0)*11585|0;f=(o*6270|0)+(g*15137|0)|0;p=((-o|0)*15137|0)+(g*6270|0)|0;q=h+8192>>14;if(!(-32768<=(q|0))){Cd(2414424,2539808,23,2652784)}if((q|0)>32767){Cd(2414424,2539808,23,2652784)}b[a>>1]=q;q=f+8192>>14;if(!(-32768<=(q|0))){Cd(2414424,2539808,23,2652784)}if((q|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+4>>1]=q;q=c+8192>>14;if(!(-32768<=(q|0))){Cd(2414424,2539808,23,2652784)}if((q|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+8>>1]=q;q=p+8192>>14;if(!(-32768<=(q|0))){Cd(2414424,2539808,23,2652784)}if((q|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+12>>1]=q;h=(l-k|0)*11585|0;c=(l+k|0)*11585|0;k=h+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}f=k;k=c+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}p=k;e=j+f|0;n=j-f|0;o=m-p|0;g=m+p|0;h=(e*3196|0)+(g*16069|0)|0;c=(n*13623|0)+(o*9102|0)|0;f=(o*13623|0)+(n*-9102|0)|0;p=(g*3196|0)+(e*-16069|0)|0;e=h+8192>>14;if(!(-32768<=(e|0))){Cd(2414424,2539808,23,2652784)}if((e|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+2>>1]=e;e=f+8192>>14;if(!(-32768<=(e|0))){Cd(2414424,2539808,23,2652784)}if((e|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+6>>1]=e;e=c+8192>>14;if(!(-32768<=(e|0))){Cd(2414424,2539808,23,2652784)}if((e|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+10>>1]=e;e=p+8192>>14;if(!(-32768<=(e|0))){Cd(2414424,2539808,23,2652784)}if((e|0)<=32767){b[a+14>>1]=e;i=d;return}else{Cd(2414424,2539808,23,2652784)}}function clc(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+640|0;g=f|0;h=f+512|0;j=f+544|0;k=f+576|0;l=f+608|0;m=d;d=e;e=a;a=g|0;n=0;a:while(1){if((n|0)>=2){o=90;break}p=0;while(1){if((p|0)>=16){break}if(0==(n|0)){c[l>>2]=(b[e+(0<<1)>>1]|0)+(b[e+((d*15|0)<<1)>>1]|0)<<2;c[l+4>>2]=(b[e+(d<<1)>>1]|0)+(b[e+((d*14|0)<<1)>>1]|0)<<2;c[l+8>>2]=(b[e+(d<<1<<1)>>1]|0)+(b[e+((d*13|0)<<1)>>1]|0)<<2;c[l+12>>2]=(b[e+((d*3|0)<<1)>>1]|0)+(b[e+((d*12|0)<<1)>>1]|0)<<2;c[l+16>>2]=(b[e+(d<<2<<1)>>1]|0)+(b[e+((d*11|0)<<1)>>1]|0)<<2;c[l+20>>2]=(b[e+((d*5|0)<<1)>>1]|0)+(b[e+((d*10|0)<<1)>>1]|0)<<2;c[l+24>>2]=(b[e+((d*6|0)<<1)>>1]|0)+(b[e+((d*9|0)<<1)>>1]|0)<<2;c[l+28>>2]=(b[e+((d*7|0)<<1)>>1]|0)+(b[e+(d<<3<<1)>>1]|0)<<2;c[h>>2]=(b[e+((d*7|0)<<1)>>1]|0)-(b[e+(d<<3<<1)>>1]|0)<<2;c[h+4>>2]=(b[e+((d*6|0)<<1)>>1]|0)-(b[e+((d*9|0)<<1)>>1]|0)<<2;c[h+8>>2]=(b[e+((d*5|0)<<1)>>1]|0)-(b[e+((d*10|0)<<1)>>1]|0)<<2;c[h+12>>2]=(b[e+(d<<2<<1)>>1]|0)-(b[e+((d*11|0)<<1)>>1]|0)<<2;c[h+16>>2]=(b[e+((d*3|0)<<1)>>1]|0)-(b[e+((d*12|0)<<1)>>1]|0)<<2;c[h+20>>2]=(b[e+(d<<1<<1)>>1]|0)-(b[e+((d*13|0)<<1)>>1]|0)<<2;c[h+24>>2]=(b[e+(d<<1)>>1]|0)-(b[e+((d*14|0)<<1)>>1]|0)<<2;c[h+28>>2]=(b[e+(0<<1)>>1]|0)-(b[e+((d*15|0)<<1)>>1]|0)<<2}else{c[l>>2]=((b[e>>1]|0)+1>>2)+((b[e+480>>1]|0)+1>>2);c[l+4>>2]=((b[e+32>>1]|0)+1>>2)+((b[e+448>>1]|0)+1>>2);c[l+8>>2]=((b[e+64>>1]|0)+1>>2)+((b[e+416>>1]|0)+1>>2);c[l+12>>2]=((b[e+96>>1]|0)+1>>2)+((b[e+384>>1]|0)+1>>2);c[l+16>>2]=((b[e+128>>1]|0)+1>>2)+((b[e+352>>1]|0)+1>>2);c[l+20>>2]=((b[e+160>>1]|0)+1>>2)+((b[e+320>>1]|0)+1>>2);c[l+24>>2]=((b[e+192>>1]|0)+1>>2)+((b[e+288>>1]|0)+1>>2);c[l+28>>2]=((b[e+224>>1]|0)+1>>2)+((b[e+256>>1]|0)+1>>2);c[h>>2]=((b[e+224>>1]|0)+1>>2)-((b[e+256>>1]|0)+1>>2);c[h+4>>2]=((b[e+192>>1]|0)+1>>2)-((b[e+288>>1]|0)+1>>2);c[h+8>>2]=((b[e+160>>1]|0)+1>>2)-((b[e+320>>1]|0)+1>>2);c[h+12>>2]=((b[e+128>>1]|0)+1>>2)-((b[e+352>>1]|0)+1>>2);c[h+16>>2]=((b[e+96>>1]|0)+1>>2)-((b[e+384>>1]|0)+1>>2);c[h+20>>2]=((b[e+64>>1]|0)+1>>2)-((b[e+416>>1]|0)+1>>2);c[h+24>>2]=((b[e+32>>1]|0)+1>>2)-((b[e+448>>1]|0)+1>>2);c[h+28>>2]=((b[e>>1]|0)+1>>2)-((b[e+480>>1]|0)+1>>2)}q=(c[l>>2]|0)+(c[l+28>>2]|0)|0;r=(c[l+4>>2]|0)+(c[l+24>>2]|0)|0;s=(c[l+8>>2]|0)+(c[l+20>>2]|0)|0;t=(c[l+12>>2]|0)+(c[l+16>>2]|0)|0;u=(c[l+12>>2]|0)-(c[l+16>>2]|0)|0;v=(c[l+8>>2]|0)-(c[l+20>>2]|0)|0;w=(c[l+4>>2]|0)-(c[l+24>>2]|0)|0;x=(c[l>>2]|0)-(c[l+28>>2]|0)|0;y=q+t|0;z=r+s|0;A=r-s|0;s=q-t|0;t=(y+z|0)*11585|0;q=(y-z|0)*11585|0;r=(s*15137|0)+(A*6270|0)|0;B=(s*6270|0)-(A*15137|0)|0;C=t+8192>>14;if(!(-32768<=(C|0))){o=10;break a}if((C|0)>32767){o=10;break a}b[a>>1]=C;C=r+8192>>14;if(!(-32768<=(C|0))){o=13;break a}if((C|0)>32767){o=13;break a}b[a+8>>1]=C;C=q+8192>>14;if(!(-32768<=(C|0))){o=16;break a}if((C|0)>32767){o=16;break a}b[a+16>>1]=C;C=B+8192>>14;if(!(-32768<=(C|0))){o=19;break a}if((C|0)>32767){o=19;break a}b[a+24>>1]=C;t=(w-v|0)*11585|0;q=(w+v|0)*11585|0;v=t+8192>>14;if(!(-32768<=(v|0))){o=22;break a}if((v|0)>32767){o=22;break a}r=v;v=q+8192>>14;if(!(-32768<=(v|0))){o=25;break a}if((v|0)>32767){o=25;break a}B=v;y=u+r|0;z=u-r|0;A=x-B|0;s=x+B|0;t=(y*3196|0)+(s*16069|0)|0;q=(z*13623|0)+(A*9102|0)|0;r=(A*13623|0)+(z*-9102|0)|0;B=(s*3196|0)+(y*-16069|0)|0;y=t+8192>>14;if(!(-32768<=(y|0))){o=28;break a}if((y|0)>32767){o=28;break a}b[a+4>>1]=y;y=r+8192>>14;if(!(-32768<=(y|0))){o=31;break a}if((y|0)>32767){o=31;break a}b[a+12>>1]=y;y=q+8192>>14;if(!(-32768<=(y|0))){o=34;break a}if((y|0)>32767){o=34;break a}b[a+20>>1]=y;y=B+8192>>14;if(!(-32768<=(y|0))){o=37;break a}if((y|0)>32767){o=37;break a}b[a+28>>1]=y;y=((c[h+20>>2]|0)-(c[h+8>>2]|0)|0)*11585|0;B=((c[h+16>>2]|0)-(c[h+12>>2]|0)|0)*11585|0;q=y+8192>>14;if(!(-32768<=(q|0))){o=40;break a}if((q|0)>32767){o=40;break a}c[j+8>>2]=q;q=B+8192>>14;if(!(-32768<=(q|0))){o=43;break a}if((q|0)>32767){o=43;break a}c[j+12>>2]=q;y=((c[h+16>>2]|0)+(c[h+12>>2]|0)|0)*11585|0;B=((c[h+20>>2]|0)+(c[h+8>>2]|0)|0)*11585|0;q=y+8192>>14;if(!(-32768<=(q|0))){o=46;break a}if((q|0)>32767){o=46;break a}c[j+16>>2]=q;q=B+8192>>14;if(!(-32768<=(q|0))){o=49;break a}if((q|0)>32767){o=49;break a}c[j+20>>2]=q;c[k>>2]=(c[h>>2]|0)+(c[j+12>>2]|0);c[k+4>>2]=(c[h+4>>2]|0)+(c[j+8>>2]|0);c[k+8>>2]=(c[h+4>>2]|0)-(c[j+8>>2]|0);c[k+12>>2]=(c[h>>2]|0)-(c[j+12>>2]|0);c[k+16>>2]=(c[h+28>>2]|0)-(c[j+16>>2]|0);c[k+20>>2]=(c[h+24>>2]|0)-(c[j+20>>2]|0);c[k+24>>2]=(c[h+24>>2]|0)+(c[j+20>>2]|0);c[k+28>>2]=(c[h+28>>2]|0)+(c[j+16>>2]|0);y=((c[k+4>>2]|0)*-15137|0)+((c[k+24>>2]|0)*6270|0)|0;B=((c[k+8>>2]|0)*-6270|0)-((c[k+20>>2]|0)*15137|0)|0;q=y+8192>>14;if(!(-32768<=(q|0))){o=52;break a}if((q|0)>32767){o=52;break a}c[j+4>>2]=q;q=B+8192>>14;if(!(-32768<=(q|0))){o=55;break a}if((q|0)>32767){o=55;break a}c[j+8>>2]=q;y=((c[k+8>>2]|0)*-15137|0)+((c[k+20>>2]|0)*6270|0)|0;B=((c[k+4>>2]|0)*6270|0)+((c[k+24>>2]|0)*15137|0)|0;q=y+8192>>14;if(!(-32768<=(q|0))){o=58;break a}if((q|0)>32767){o=58;break a}c[j+20>>2]=q;q=B+8192>>14;if(!(-32768<=(q|0))){o=61;break a}if((q|0)>32767){o=61;break a}c[j+24>>2]=q;c[h>>2]=(c[k>>2]|0)+(c[j+4>>2]|0);c[h+4>>2]=(c[k>>2]|0)-(c[j+4>>2]|0);c[h+8>>2]=(c[k+12>>2]|0)-(c[j+8>>2]|0);c[h+12>>2]=(c[k+12>>2]|0)+(c[j+8>>2]|0);c[h+16>>2]=(c[k+16>>2]|0)+(c[j+20>>2]|0);c[h+20>>2]=(c[k+16>>2]|0)-(c[j+20>>2]|0);c[h+24>>2]=(c[k+28>>2]|0)-(c[j+24>>2]|0);c[h+28>>2]=(c[k+28>>2]|0)+(c[j+24>>2]|0);y=((c[h>>2]|0)*1606|0)+((c[h+28>>2]|0)*16305|0)|0;B=((c[h+4>>2]|0)*12665|0)+((c[h+24>>2]|0)*10394|0)|0;q=y+8192>>14;if(!(-32768<=(q|0))){o=64;break a}if((q|0)>32767){o=64;break a}b[a+2>>1]=q;q=B+8192>>14;if(!(-32768<=(q|0))){o=67;break a}if((q|0)>32767){o=67;break a}b[a+18>>1]=q;y=((c[h+8>>2]|0)*7723|0)+((c[h+20>>2]|0)*14449|0)|0;B=((c[h+12>>2]|0)*15679|0)+((c[h+16>>2]|0)*4756|0)|0;q=y+8192>>14;if(!(-32768<=(q|0))){o=70;break a}if((q|0)>32767){o=70;break a}b[a+10>>1]=q;q=B+8192>>14;if(!(-32768<=(q|0))){o=73;break a}if((q|0)>32767){o=73;break a}b[a+26>>1]=q;y=((c[h+12>>2]|0)*-4756|0)+((c[h+16>>2]|0)*15679|0)|0;B=((c[h+8>>2]|0)*-14449|0)+((c[h+20>>2]|0)*7723|0)|0;q=y+8192>>14;if(!(-32768<=(q|0))){o=76;break a}if((q|0)>32767){o=76;break a}b[a+6>>1]=q;q=B+8192>>14;if(!(-32768<=(q|0))){o=79;break a}if((q|0)>32767){o=79;break a}b[a+22>>1]=q;y=((c[h+4>>2]|0)*-10394|0)+((c[h+24>>2]|0)*12665|0)|0;B=((c[h>>2]|0)*-16305|0)+((c[h+28>>2]|0)*1606|0)|0;q=y+8192>>14;if(!(-32768<=(q|0))){o=82;break a}if((q|0)>32767){o=82;break a}b[a+14>>1]=q;q=B+8192>>14;if(!(-32768<=(q|0))){o=85;break a}if((q|0)>32767){o=85;break a}b[a+30>>1]=q;e=e+2|0;a=a+32|0;p=p+1|0}e=g|0;a=m;n=n+1|0}if((o|0)==10){Cd(2414424,2539808,23,2652784)}else if((o|0)==13){Cd(2414424,2539808,23,2652784)}else if((o|0)==16){Cd(2414424,2539808,23,2652784)}else if((o|0)==19){Cd(2414424,2539808,23,2652784)}else if((o|0)==22){Cd(2414424,2539808,23,2652784)}else if((o|0)==25){Cd(2414424,2539808,23,2652784)}else if((o|0)==28){Cd(2414424,2539808,23,2652784)}else if((o|0)==31){Cd(2414424,2539808,23,2652784)}else if((o|0)==34){Cd(2414424,2539808,23,2652784)}else if((o|0)==37){Cd(2414424,2539808,23,2652784)}else if((o|0)==40){Cd(2414424,2539808,23,2652784)}else if((o|0)==43){Cd(2414424,2539808,23,2652784)}else if((o|0)==46){Cd(2414424,2539808,23,2652784)}else if((o|0)==49){Cd(2414424,2539808,23,2652784)}else if((o|0)==52){Cd(2414424,2539808,23,2652784)}else if((o|0)==55){Cd(2414424,2539808,23,2652784)}else if((o|0)==58){Cd(2414424,2539808,23,2652784)}else if((o|0)==61){Cd(2414424,2539808,23,2652784)}else if((o|0)==64){Cd(2414424,2539808,23,2652784)}else if((o|0)==67){Cd(2414424,2539808,23,2652784)}else if((o|0)==70){Cd(2414424,2539808,23,2652784)}else if((o|0)==73){Cd(2414424,2539808,23,2652784)}else if((o|0)==76){Cd(2414424,2539808,23,2652784)}else if((o|0)==79){Cd(2414424,2539808,23,2652784)}else if((o|0)==82){Cd(2414424,2539808,23,2652784)}else if((o|0)==85){Cd(2414424,2539808,23,2652784)}else if((o|0)==90){i=f;return}}function dlc(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+168|0;h=g|0;j=g+128|0;k=g+144|0;l=g+160|0;m=a;a=d;d=e;e=f;if((e|0)==0){alc(m,a,d);i=g;return}f=h|0;n=l;o=2659240+(e<<3)|0;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];o=0;while(1){if((o|0)>=8){break}p=0;while(1){if((p|0)>=8){break}b[j+(p<<1)>>1]=b[m+((ca(p,d)|0)+o<<1)>>1]<<2;p=p+1|0}re[c[l>>2]&1023](j|0,k|0);p=0;while(1){if((p|0)>=8){break}b[f+((p<<3)+o<<1)>>1]=b[k+(p<<1)>>1]|0;p=p+1|0}o=o+1|0}o=0;while(1){if((o|0)>=8){break}p=0;while(1){if((p|0)>=8){break}b[j+(p<<1)>>1]=b[h+(p+(o<<3)<<1)>>1]|0;p=p+1|0}re[c[l+4>>2]&1023](j|0,k|0);p=0;while(1){if((p|0)>=8){break}b[a+(p+(o<<3)<<1)>>1]=(b[k+(p<<1)>>1]|0)+((b[k+(p<<1)>>1]|0)<0)>>1;p=p+1|0}o=o+1|0}i=g;return}function elc(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=c;c=d;d=a;a=f;g=0;while(1){if((g|0)>=4){break}h=b[d+(0<<1)>>1]|0;j=b[d+(c<<1)>>1]|0;k=b[d+(c<<1<<1)>>1]|0;l=b[d+((c*3|0)<<1)>>1]|0;h=h+j|0;l=l-k|0;m=h-l>>1;j=m-j|0;k=m-k|0;h=h-k|0;l=l+j|0;b[a>>1]=h;b[a+8>>1]=k;b[a+16>>1]=l;b[a+24>>1]=j;d=d+2|0;a=a+2|0;g=g+1|0}d=f;a=f;g=0;while(1){if((g|0)>=4){break}h=b[d>>1]|0;j=b[d+2>>1]|0;k=b[d+4>>1]|0;l=b[d+6>>1]|0;h=h+j|0;l=l-k|0;m=h-l>>1;j=m-j|0;k=m-k|0;h=h-k|0;l=l+j|0;b[a>>1]=h<<2;b[a+2>>1]=k<<2;b[a+4>>1]=l<<2;b[a+6>>1]=j<<2;d=d+8|0;a=a+8|0;g=g+1|0}i=e;return}function flc(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+584|0;h=g|0;j=g+512|0;k=g+544|0;l=g+576|0;m=a;a=d;d=e;e=f;if((e|0)==0){clc(m,a,d);i=g;return}f=h|0;n=l;o=2659304+(e<<3)|0;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];o=0;while(1){if((o|0)>=16){break}p=0;while(1){if((p|0)>=16){break}b[j+(p<<1)>>1]=b[m+((ca(p,d)|0)+o<<1)>>1]<<2;p=p+1|0}re[c[l>>2]&1023](j|0,k|0);p=0;while(1){if((p|0)>=16){break}b[f+((p<<4)+o<<1)>>1]=(b[k+(p<<1)>>1]|0)+1+((b[k+(p<<1)>>1]|0)<0)>>2;p=p+1|0}o=o+1|0}o=0;while(1){if((o|0)>=16){break}p=0;while(1){if((p|0)>=16){break}b[j+(p<<1)>>1]=b[h+(p+(o<<4)<<1)>>1]|0;p=p+1|0}re[c[l+4>>2]&1023](j|0,k|0);p=0;while(1){if((p|0)>=16){break}b[a+(p+(o<<4)<<1)>>1]=b[k+(p<<1)>>1]|0;p=p+1|0}o=o+1|0}i=g;return}function glc(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+4608|0;g=f|0;h=f+4096|0;j=f+4224|0;k=f+4352|0;l=f+4480|0;m=a;a=d;d=e;e=0;while(1){if((e|0)>=32){break}n=0;while(1){if((n|0)>=32){break}c[h+(n<<2)>>2]=b[m+((ca(n,d)|0)+e<<1)>>1]<<2;n=n+1|0}hlc(h|0,j|0,0);n=0;while(1){if((n|0)>=32){break}c[g+((n<<5)+e<<2)>>2]=(c[j+(n<<2)>>2]|0)+1+((c[j+(n<<2)>>2]|0)>0)>>2;n=n+1|0}e=e+1|0}e=0;while(1){if((e|0)>=32){break}n=0;while(1){if((n|0)>=32){break}c[k+(n<<2)>>2]=c[g+(n+(e<<5)<<2)>>2];n=n+1|0}hlc(k|0,l|0,0);n=0;while(1){if((n|0)>=32){break}b[a+(n+(e<<5)<<1)>>1]=(c[l+(n<<2)>>2]|0)+1+((c[l+(n<<2)>>2]|0)<0)>>2;n=n+1|0}e=e+1|0}i=f;return}function hlc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+128|0;f=e|0;g=a;a=b;c[f>>2]=(c[g>>2]|0)+(c[g+124>>2]|0);c[f+4>>2]=(c[g+4>>2]|0)+(c[g+120>>2]|0);c[f+8>>2]=(c[g+8>>2]|0)+(c[g+116>>2]|0);c[f+12>>2]=(c[g+12>>2]|0)+(c[g+112>>2]|0);c[f+16>>2]=(c[g+16>>2]|0)+(c[g+108>>2]|0);c[f+20>>2]=(c[g+20>>2]|0)+(c[g+104>>2]|0);c[f+24>>2]=(c[g+24>>2]|0)+(c[g+100>>2]|0);c[f+28>>2]=(c[g+28>>2]|0)+(c[g+96>>2]|0);c[f+32>>2]=(c[g+32>>2]|0)+(c[g+92>>2]|0);c[f+36>>2]=(c[g+36>>2]|0)+(c[g+88>>2]|0);c[f+40>>2]=(c[g+40>>2]|0)+(c[g+84>>2]|0);c[f+44>>2]=(c[g+44>>2]|0)+(c[g+80>>2]|0);c[f+48>>2]=(c[g+48>>2]|0)+(c[g+76>>2]|0);c[f+52>>2]=(c[g+52>>2]|0)+(c[g+72>>2]|0);c[f+56>>2]=(c[g+56>>2]|0)+(c[g+68>>2]|0);c[f+60>>2]=(c[g+60>>2]|0)+(c[g+64>>2]|0);c[f+64>>2]=(-(c[g+64>>2]|0)|0)+(c[g+60>>2]|0);c[f+68>>2]=(-(c[g+68>>2]|0)|0)+(c[g+56>>2]|0);c[f+72>>2]=(-(c[g+72>>2]|0)|0)+(c[g+52>>2]|0);c[f+76>>2]=(-(c[g+76>>2]|0)|0)+(c[g+48>>2]|0);c[f+80>>2]=(-(c[g+80>>2]|0)|0)+(c[g+44>>2]|0);c[f+84>>2]=(-(c[g+84>>2]|0)|0)+(c[g+40>>2]|0);c[f+88>>2]=(-(c[g+88>>2]|0)|0)+(c[g+36>>2]|0);c[f+92>>2]=(-(c[g+92>>2]|0)|0)+(c[g+32>>2]|0);c[f+96>>2]=(-(c[g+96>>2]|0)|0)+(c[g+28>>2]|0);c[f+100>>2]=(-(c[g+100>>2]|0)|0)+(c[g+24>>2]|0);c[f+104>>2]=(-(c[g+104>>2]|0)|0)+(c[g+20>>2]|0);c[f+108>>2]=(-(c[g+108>>2]|0)|0)+(c[g+16>>2]|0);c[f+112>>2]=(-(c[g+112>>2]|0)|0)+(c[g+12>>2]|0);c[f+116>>2]=(-(c[g+116>>2]|0)|0)+(c[g+8>>2]|0);c[f+120>>2]=(-(c[g+120>>2]|0)|0)+(c[g+4>>2]|0);c[f+124>>2]=(-(c[g+124>>2]|0)|0)+(c[g>>2]|0);c[a>>2]=(c[f>>2]|0)+(c[f+60>>2]|0);c[a+4>>2]=(c[f+4>>2]|0)+(c[f+56>>2]|0);c[a+8>>2]=(c[f+8>>2]|0)+(c[f+52>>2]|0);c[a+12>>2]=(c[f+12>>2]|0)+(c[f+48>>2]|0);c[a+16>>2]=(c[f+16>>2]|0)+(c[f+44>>2]|0);c[a+20>>2]=(c[f+20>>2]|0)+(c[f+40>>2]|0);c[a+24>>2]=(c[f+24>>2]|0)+(c[f+36>>2]|0);c[a+28>>2]=(c[f+28>>2]|0)+(c[f+32>>2]|0);c[a+32>>2]=(-(c[f+32>>2]|0)|0)+(c[f+28>>2]|0);c[a+36>>2]=(-(c[f+36>>2]|0)|0)+(c[f+24>>2]|0);c[a+40>>2]=(-(c[f+40>>2]|0)|0)+(c[f+20>>2]|0);c[a+44>>2]=(-(c[f+44>>2]|0)|0)+(c[f+16>>2]|0);c[a+48>>2]=(-(c[f+48>>2]|0)|0)+(c[f+12>>2]|0);c[a+52>>2]=(-(c[f+52>>2]|0)|0)+(c[f+8>>2]|0);c[a+56>>2]=(-(c[f+56>>2]|0)|0)+(c[f+4>>2]|0);c[a+60>>2]=(-(c[f+60>>2]|0)|0)+(c[f>>2]|0);c[a+64>>2]=c[f+64>>2];c[a+68>>2]=c[f+68>>2];c[a+72>>2]=c[f+72>>2];c[a+76>>2]=c[f+76>>2];g=(((-(c[f+80>>2]|0)|0)+(c[f+108>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(g|0))){Cd(2270096,2539808,1e3,2653088)}if((g|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+80>>2]=g;g=(((-(c[f+84>>2]|0)|0)+(c[f+104>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(g|0))){Cd(2270096,2539808,1e3,2653088)}if((g|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+84>>2]=g;g=(((-(c[f+88>>2]|0)|0)+(c[f+100>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(g|0))){Cd(2270096,2539808,1e3,2653088)}if((g|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+88>>2]=g;g=(((-(c[f+92>>2]|0)|0)+(c[f+96>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(g|0))){Cd(2270096,2539808,1e3,2653088)}if((g|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+92>>2]=g;g=(((c[f+96>>2]|0)+(c[f+92>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(g|0))){Cd(2270096,2539808,1e3,2653088)}if((g|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+96>>2]=g;g=(((c[f+100>>2]|0)+(c[f+88>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(g|0))){Cd(2270096,2539808,1e3,2653088)}if((g|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+100>>2]=g;g=(((c[f+104>>2]|0)+(c[f+84>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(g|0))){Cd(2270096,2539808,1e3,2653088)}if((g|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+104>>2]=g;g=(((c[f+108>>2]|0)+(c[f+80>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(g|0))){Cd(2270096,2539808,1e3,2653088)}if((g|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+108>>2]=g;c[a+112>>2]=c[f+112>>2];c[a+116>>2]=c[f+116>>2];c[a+120>>2]=c[f+120>>2];c[a+124>>2]=c[f+124>>2];if((d|0)!=0){d=c[a>>2]|0;c[a>>2]=d+1+((d|0)<0)>>2;d=c[a+4>>2]|0;c[a+4>>2]=d+1+((d|0)<0)>>2;d=c[a+8>>2]|0;c[a+8>>2]=d+1+((d|0)<0)>>2;d=c[a+12>>2]|0;c[a+12>>2]=d+1+((d|0)<0)>>2;d=c[a+16>>2]|0;c[a+16>>2]=d+1+((d|0)<0)>>2;d=c[a+20>>2]|0;c[a+20>>2]=d+1+((d|0)<0)>>2;d=c[a+24>>2]|0;c[a+24>>2]=d+1+((d|0)<0)>>2;d=c[a+28>>2]|0;c[a+28>>2]=d+1+((d|0)<0)>>2;d=c[a+32>>2]|0;c[a+32>>2]=d+1+((d|0)<0)>>2;d=c[a+36>>2]|0;c[a+36>>2]=d+1+((d|0)<0)>>2;d=c[a+40>>2]|0;c[a+40>>2]=d+1+((d|0)<0)>>2;d=c[a+44>>2]|0;c[a+44>>2]=d+1+((d|0)<0)>>2;d=c[a+48>>2]|0;c[a+48>>2]=d+1+((d|0)<0)>>2;d=c[a+52>>2]|0;c[a+52>>2]=d+1+((d|0)<0)>>2;d=c[a+56>>2]|0;c[a+56>>2]=d+1+((d|0)<0)>>2;d=c[a+60>>2]|0;c[a+60>>2]=d+1+((d|0)<0)>>2;d=c[a+64>>2]|0;c[a+64>>2]=d+1+((d|0)<0)>>2;d=c[a+68>>2]|0;c[a+68>>2]=d+1+((d|0)<0)>>2;d=c[a+72>>2]|0;c[a+72>>2]=d+1+((d|0)<0)>>2;d=c[a+76>>2]|0;c[a+76>>2]=d+1+((d|0)<0)>>2;d=c[a+80>>2]|0;c[a+80>>2]=d+1+((d|0)<0)>>2;d=c[a+84>>2]|0;c[a+84>>2]=d+1+((d|0)<0)>>2;d=c[a+88>>2]|0;c[a+88>>2]=d+1+((d|0)<0)>>2;d=c[a+92>>2]|0;c[a+92>>2]=d+1+((d|0)<0)>>2;d=c[a+96>>2]|0;c[a+96>>2]=d+1+((d|0)<0)>>2;d=c[a+100>>2]|0;c[a+100>>2]=d+1+((d|0)<0)>>2;d=c[a+104>>2]|0;c[a+104>>2]=d+1+((d|0)<0)>>2;d=c[a+108>>2]|0;c[a+108>>2]=d+1+((d|0)<0)>>2;d=c[a+112>>2]|0;c[a+112>>2]=d+1+((d|0)<0)>>2;d=c[a+116>>2]|0;c[a+116>>2]=d+1+((d|0)<0)>>2;d=c[a+120>>2]|0;c[a+120>>2]=d+1+((d|0)<0)>>2;d=c[a+124>>2]|0;c[a+124>>2]=d+1+((d|0)<0)>>2}c[f>>2]=(c[a>>2]|0)+(c[a+28>>2]|0);c[f+4>>2]=(c[a+4>>2]|0)+(c[a+24>>2]|0);c[f+8>>2]=(c[a+8>>2]|0)+(c[a+20>>2]|0);c[f+12>>2]=(c[a+12>>2]|0)+(c[a+16>>2]|0);c[f+16>>2]=(-(c[a+16>>2]|0)|0)+(c[a+12>>2]|0);c[f+20>>2]=(-(c[a+20>>2]|0)|0)+(c[a+8>>2]|0);c[f+24>>2]=(-(c[a+24>>2]|0)|0)+(c[a+4>>2]|0);c[f+28>>2]=(-(c[a+28>>2]|0)|0)+(c[a>>2]|0);c[f+32>>2]=c[a+32>>2];c[f+36>>2]=c[a+36>>2];d=(((-(c[a+40>>2]|0)|0)+(c[a+52>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+40>>2]=d;d=(((-(c[a+44>>2]|0)|0)+(c[a+48>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+44>>2]=d;d=(((c[a+48>>2]|0)+(c[a+44>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+48>>2]=d;d=(((c[a+52>>2]|0)+(c[a+40>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+52>>2]=d;c[f+56>>2]=c[a+56>>2];c[f+60>>2]=c[a+60>>2];c[f+64>>2]=(c[a+64>>2]|0)+(c[a+92>>2]|0);c[f+68>>2]=(c[a+68>>2]|0)+(c[a+88>>2]|0);c[f+72>>2]=(c[a+72>>2]|0)+(c[a+84>>2]|0);c[f+76>>2]=(c[a+76>>2]|0)+(c[a+80>>2]|0);c[f+80>>2]=(-(c[a+80>>2]|0)|0)+(c[a+76>>2]|0);c[f+84>>2]=(-(c[a+84>>2]|0)|0)+(c[a+72>>2]|0);c[f+88>>2]=(-(c[a+88>>2]|0)|0)+(c[a+68>>2]|0);c[f+92>>2]=(-(c[a+92>>2]|0)|0)+(c[a+64>>2]|0);c[f+96>>2]=(-(c[a+96>>2]|0)|0)+(c[a+124>>2]|0);c[f+100>>2]=(-(c[a+100>>2]|0)|0)+(c[a+120>>2]|0);c[f+104>>2]=(-(c[a+104>>2]|0)|0)+(c[a+116>>2]|0);c[f+108>>2]=(-(c[a+108>>2]|0)|0)+(c[a+112>>2]|0);c[f+112>>2]=(c[a+112>>2]|0)+(c[a+108>>2]|0);c[f+116>>2]=(c[a+116>>2]|0)+(c[a+104>>2]|0);c[f+120>>2]=(c[a+120>>2]|0)+(c[a+100>>2]|0);c[f+124>>2]=(c[a+124>>2]|0)+(c[a+96>>2]|0);c[a>>2]=(c[f>>2]|0)+(c[f+12>>2]|0);c[a+4>>2]=(c[f+4>>2]|0)+(c[f+8>>2]|0);c[a+8>>2]=(-(c[f+8>>2]|0)|0)+(c[f+4>>2]|0);c[a+12>>2]=(-(c[f+12>>2]|0)|0)+(c[f>>2]|0);c[a+16>>2]=c[f+16>>2];d=(((-(c[f+20>>2]|0)|0)+(c[f+24>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+20>>2]=d;d=(((c[f+24>>2]|0)+(c[f+20>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+24>>2]=d;c[a+28>>2]=c[f+28>>2];c[a+32>>2]=(c[f+32>>2]|0)+(c[f+44>>2]|0);c[a+36>>2]=(c[f+36>>2]|0)+(c[f+40>>2]|0);c[a+40>>2]=(-(c[f+40>>2]|0)|0)+(c[f+36>>2]|0);c[a+44>>2]=(-(c[f+44>>2]|0)|0)+(c[f+32>>2]|0);c[a+48>>2]=(-(c[f+48>>2]|0)|0)+(c[f+60>>2]|0);c[a+52>>2]=(-(c[f+52>>2]|0)|0)+(c[f+56>>2]|0);c[a+56>>2]=(c[f+56>>2]|0)+(c[f+52>>2]|0);c[a+60>>2]=(c[f+60>>2]|0)+(c[f+48>>2]|0);c[a+64>>2]=c[f+64>>2];c[a+68>>2]=c[f+68>>2];d=((c[f+72>>2]|0)*-15137|0)+((c[f+116>>2]|0)*6270|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+72>>2]=d;d=((c[f+76>>2]|0)*-15137|0)+((c[f+112>>2]|0)*6270|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+76>>2]=d;d=((c[f+80>>2]|0)*-6270|0)+((c[f+108>>2]|0)*-15137|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+80>>2]=d;d=((c[f+84>>2]|0)*-6270|0)+((c[f+104>>2]|0)*-15137|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+84>>2]=d;c[a+88>>2]=c[f+88>>2];c[a+92>>2]=c[f+92>>2];c[a+96>>2]=c[f+96>>2];c[a+100>>2]=c[f+100>>2];d=((c[f+104>>2]|0)*6270|0)+((c[f+84>>2]|0)*-15137|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+104>>2]=d;d=((c[f+108>>2]|0)*6270|0)+((c[f+80>>2]|0)*-15137|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+108>>2]=d;d=((c[f+112>>2]|0)*15137|0)+((c[f+76>>2]|0)*6270|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+112>>2]=d;d=((c[f+116>>2]|0)*15137|0)+((c[f+72>>2]|0)*6270|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+116>>2]=d;c[a+120>>2]=c[f+120>>2];c[a+124>>2]=c[f+124>>2];d=(((c[a>>2]|0)+(c[a+4>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f>>2]=d;d=(((-(c[a+4>>2]|0)|0)+(c[a>>2]|0)|0)*11585|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+4>>2]=d;d=((c[a+8>>2]|0)*6270|0)+((c[a+12>>2]|0)*15137|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+8>>2]=d;d=((c[a+12>>2]|0)*6270|0)-((c[a+8>>2]|0)*15137|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+12>>2]=d;c[f+16>>2]=(c[a+16>>2]|0)+(c[a+20>>2]|0);c[f+20>>2]=(-(c[a+20>>2]|0)|0)+(c[a+16>>2]|0);c[f+24>>2]=(-(c[a+24>>2]|0)|0)+(c[a+28>>2]|0);c[f+28>>2]=(c[a+28>>2]|0)+(c[a+24>>2]|0);c[f+32>>2]=c[a+32>>2];d=((c[a+36>>2]|0)*-15137|0)+((c[a+56>>2]|0)*6270|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+36>>2]=d;d=((c[a+40>>2]|0)*-6270|0)+((c[a+52>>2]|0)*-15137|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+40>>2]=d;c[f+44>>2]=c[a+44>>2];c[f+48>>2]=c[a+48>>2];d=((c[a+52>>2]|0)*6270|0)+((c[a+40>>2]|0)*-15137|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+52>>2]=d;d=((c[a+56>>2]|0)*15137|0)+((c[a+36>>2]|0)*6270|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+56>>2]=d;c[f+60>>2]=c[a+60>>2];c[f+64>>2]=(c[a+64>>2]|0)+(c[a+76>>2]|0);c[f+68>>2]=(c[a+68>>2]|0)+(c[a+72>>2]|0);c[f+72>>2]=(-(c[a+72>>2]|0)|0)+(c[a+68>>2]|0);c[f+76>>2]=(-(c[a+76>>2]|0)|0)+(c[a+64>>2]|0);c[f+80>>2]=(-(c[a+80>>2]|0)|0)+(c[a+92>>2]|0);c[f+84>>2]=(-(c[a+84>>2]|0)|0)+(c[a+88>>2]|0);c[f+88>>2]=(c[a+88>>2]|0)+(c[a+84>>2]|0);c[f+92>>2]=(c[a+92>>2]|0)+(c[a+80>>2]|0);c[f+96>>2]=(c[a+96>>2]|0)+(c[a+108>>2]|0);c[f+100>>2]=(c[a+100>>2]|0)+(c[a+104>>2]|0);c[f+104>>2]=(-(c[a+104>>2]|0)|0)+(c[a+100>>2]|0);c[f+108>>2]=(-(c[a+108>>2]|0)|0)+(c[a+96>>2]|0);c[f+112>>2]=(-(c[a+112>>2]|0)|0)+(c[a+124>>2]|0);c[f+116>>2]=(-(c[a+116>>2]|0)|0)+(c[a+120>>2]|0);c[f+120>>2]=(c[a+120>>2]|0)+(c[a+116>>2]|0);c[f+124>>2]=(c[a+124>>2]|0)+(c[a+112>>2]|0);c[a>>2]=c[f>>2];c[a+4>>2]=c[f+4>>2];c[a+8>>2]=c[f+8>>2];c[a+12>>2]=c[f+12>>2];d=((c[f+16>>2]|0)*3196|0)+((c[f+28>>2]|0)*16069|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+16>>2]=d;d=((c[f+20>>2]|0)*13623|0)+((c[f+24>>2]|0)*9102|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+20>>2]=d;d=((c[f+24>>2]|0)*13623|0)+((c[f+20>>2]|0)*-9102|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+24>>2]=d;d=((c[f+28>>2]|0)*3196|0)+((c[f+16>>2]|0)*-16069|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+28>>2]=d;c[a+32>>2]=(c[f+32>>2]|0)+(c[f+36>>2]|0);c[a+36>>2]=(-(c[f+36>>2]|0)|0)+(c[f+32>>2]|0);c[a+40>>2]=(-(c[f+40>>2]|0)|0)+(c[f+44>>2]|0);c[a+44>>2]=(c[f+44>>2]|0)+(c[f+40>>2]|0);c[a+48>>2]=(c[f+48>>2]|0)+(c[f+52>>2]|0);c[a+52>>2]=(-(c[f+52>>2]|0)|0)+(c[f+48>>2]|0);c[a+56>>2]=(-(c[f+56>>2]|0)|0)+(c[f+60>>2]|0);c[a+60>>2]=(c[f+60>>2]|0)+(c[f+56>>2]|0);c[a+64>>2]=c[f+64>>2];d=((c[f+68>>2]|0)*-16069|0)+((c[f+120>>2]|0)*3196|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+68>>2]=d;d=((c[f+72>>2]|0)*-3196|0)+((c[f+116>>2]|0)*-16069|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+72>>2]=d;c[a+76>>2]=c[f+76>>2];c[a+80>>2]=c[f+80>>2];d=((c[f+84>>2]|0)*-9102|0)+((c[f+104>>2]|0)*13623|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+84>>2]=d;d=((c[f+88>>2]|0)*-13623|0)+((c[f+100>>2]|0)*-9102|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+88>>2]=d;c[a+92>>2]=c[f+92>>2];c[a+96>>2]=c[f+96>>2];d=((c[f+100>>2]|0)*13623|0)+((c[f+88>>2]|0)*-9102|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+100>>2]=d;d=((c[f+104>>2]|0)*9102|0)+((c[f+84>>2]|0)*13623|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+104>>2]=d;c[a+108>>2]=c[f+108>>2];c[a+112>>2]=c[f+112>>2];d=((c[f+116>>2]|0)*3196|0)+((c[f+72>>2]|0)*-16069|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+116>>2]=d;d=((c[f+120>>2]|0)*16069|0)+((c[f+68>>2]|0)*3196|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+120>>2]=d;c[a+124>>2]=c[f+124>>2];c[f>>2]=c[a>>2];c[f+4>>2]=c[a+4>>2];c[f+8>>2]=c[a+8>>2];c[f+12>>2]=c[a+12>>2];c[f+16>>2]=c[a+16>>2];c[f+20>>2]=c[a+20>>2];c[f+24>>2]=c[a+24>>2];c[f+28>>2]=c[a+28>>2];d=((c[a+32>>2]|0)*1606|0)+((c[a+60>>2]|0)*16305|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+32>>2]=d;d=((c[a+36>>2]|0)*12665|0)+((c[a+56>>2]|0)*10394|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+36>>2]=d;d=((c[a+40>>2]|0)*7723|0)+((c[a+52>>2]|0)*14449|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+40>>2]=d;d=((c[a+44>>2]|0)*15679|0)+((c[a+48>>2]|0)*4756|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+44>>2]=d;d=((c[a+48>>2]|0)*15679|0)+((c[a+44>>2]|0)*-4756|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+48>>2]=d;d=((c[a+52>>2]|0)*7723|0)+((c[a+40>>2]|0)*-14449|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+52>>2]=d;d=((c[a+56>>2]|0)*12665|0)+((c[a+36>>2]|0)*-10394|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+56>>2]=d;d=((c[a+60>>2]|0)*1606|0)+((c[a+32>>2]|0)*-16305|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[f+60>>2]=d;c[f+64>>2]=(c[a+64>>2]|0)+(c[a+68>>2]|0);c[f+68>>2]=(-(c[a+68>>2]|0)|0)+(c[a+64>>2]|0);c[f+72>>2]=(-(c[a+72>>2]|0)|0)+(c[a+76>>2]|0);c[f+76>>2]=(c[a+76>>2]|0)+(c[a+72>>2]|0);c[f+80>>2]=(c[a+80>>2]|0)+(c[a+84>>2]|0);c[f+84>>2]=(-(c[a+84>>2]|0)|0)+(c[a+80>>2]|0);c[f+88>>2]=(-(c[a+88>>2]|0)|0)+(c[a+92>>2]|0);c[f+92>>2]=(c[a+92>>2]|0)+(c[a+88>>2]|0);c[f+96>>2]=(c[a+96>>2]|0)+(c[a+100>>2]|0);c[f+100>>2]=(-(c[a+100>>2]|0)|0)+(c[a+96>>2]|0);c[f+104>>2]=(-(c[a+104>>2]|0)|0)+(c[a+108>>2]|0);c[f+108>>2]=(c[a+108>>2]|0)+(c[a+104>>2]|0);c[f+112>>2]=(c[a+112>>2]|0)+(c[a+116>>2]|0);c[f+116>>2]=(-(c[a+116>>2]|0)|0)+(c[a+112>>2]|0);c[f+120>>2]=(-(c[a+120>>2]|0)|0)+(c[a+124>>2]|0);c[f+124>>2]=(c[a+124>>2]|0)+(c[a+120>>2]|0);c[a>>2]=c[f>>2];c[a+64>>2]=c[f+4>>2];c[a+32>>2]=c[f+8>>2];c[a+96>>2]=c[f+12>>2];c[a+16>>2]=c[f+16>>2];c[a+80>>2]=c[f+20>>2];c[a+48>>2]=c[f+24>>2];c[a+112>>2]=c[f+28>>2];c[a+8>>2]=c[f+32>>2];c[a+72>>2]=c[f+36>>2];c[a+40>>2]=c[f+40>>2];c[a+104>>2]=c[f+44>>2];c[a+24>>2]=c[f+48>>2];c[a+88>>2]=c[f+52>>2];c[a+56>>2]=c[f+56>>2];c[a+120>>2]=c[f+60>>2];d=((c[f+64>>2]|0)*804|0)+((c[f+124>>2]|0)*16364|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+4>>2]=d;d=((c[f+68>>2]|0)*12140|0)+((c[f+120>>2]|0)*11003|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+68>>2]=d;d=((c[f+72>>2]|0)*7005|0)+((c[f+116>>2]|0)*14811|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+36>>2]=d;d=((c[f+76>>2]|0)*15426|0)+((c[f+112>>2]|0)*5520|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+100>>2]=d;d=((c[f+80>>2]|0)*3981|0)+((c[f+108>>2]|0)*15893|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+20>>2]=d;d=((c[f+84>>2]|0)*14053|0)+((c[f+104>>2]|0)*8423|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+84>>2]=d;d=((c[f+88>>2]|0)*9760|0)+((c[f+100>>2]|0)*13160|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+52>>2]=d;d=((c[f+92>>2]|0)*16207|0)+((c[f+96>>2]|0)*2404|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+116>>2]=d;d=((c[f+96>>2]|0)*16207|0)+((c[f+92>>2]|0)*-2404|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+12>>2]=d;d=((c[f+100>>2]|0)*9760|0)+((c[f+88>>2]|0)*-13160|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+76>>2]=d;d=((c[f+104>>2]|0)*14053|0)+((c[f+84>>2]|0)*-8423|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+44>>2]=d;d=((c[f+108>>2]|0)*3981|0)+((c[f+80>>2]|0)*-15893|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+108>>2]=d;d=((c[f+112>>2]|0)*15426|0)+((c[f+76>>2]|0)*-5520|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+28>>2]=d;d=((c[f+116>>2]|0)*7005|0)+((c[f+72>>2]|0)*-14811|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+92>>2]=d;d=((c[f+120>>2]|0)*12140|0)+((c[f+68>>2]|0)*-11003|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)>131071){Cd(2270096,2539808,1e3,2653088)}c[a+60>>2]=d;d=((c[f+124>>2]|0)*804|0)+((c[f+64>>2]|0)*-16364|0)+8192>>14;if(!(-131072<=(d|0))){Cd(2270096,2539808,1e3,2653088)}if((d|0)<=131071){c[a+124>>2]=d;i=e;return}else{Cd(2270096,2539808,1e3,2653088)}}function ilc(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+4608|0;g=f|0;h=f+4096|0;j=f+4224|0;k=f+4352|0;l=f+4480|0;m=a;a=d;d=e;e=0;while(1){if((e|0)>=32){break}n=0;while(1){if((n|0)>=32){break}c[h+(n<<2)>>2]=b[m+((ca(n,d)|0)+e<<1)>>1]<<2;n=n+1|0}hlc(h|0,j|0,0);n=0;while(1){if((n|0)>=32){break}c[g+((n<<5)+e<<2)>>2]=(c[j+(n<<2)>>2]|0)+1+((c[j+(n<<2)>>2]|0)>0)>>2;n=n+1|0}e=e+1|0}e=0;while(1){if((e|0)>=32){break}n=0;while(1){if((n|0)>=32){break}c[k+(n<<2)>>2]=c[g+(n+(e<<5)<<2)>>2];n=n+1|0}hlc(k|0,l|0,1);n=0;while(1){if((n|0)>=32){break}b[a+(n+(e<<5)<<1)>>1]=c[l+(n<<2)>>2];n=n+1|0}e=e+1|0}i=f;return}function jlc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+128|0;f=e|0;g=e+32|0;h=e+64|0;j=e+96|0;k=a;a=d;c[j>>2]=(b[k>>1]|0)+(b[k+30>>1]|0);c[j+4>>2]=(b[k+2>>1]|0)+(b[k+28>>1]|0);c[j+8>>2]=(b[k+4>>1]|0)+(b[k+26>>1]|0);c[j+12>>2]=(b[k+6>>1]|0)+(b[k+24>>1]|0);c[j+16>>2]=(b[k+8>>1]|0)+(b[k+22>>1]|0);c[j+20>>2]=(b[k+10>>1]|0)+(b[k+20>>1]|0);c[j+24>>2]=(b[k+12>>1]|0)+(b[k+18>>1]|0);c[j+28>>2]=(b[k+14>>1]|0)+(b[k+16>>1]|0);c[f>>2]=(b[k+14>>1]|0)-(b[k+16>>1]|0);c[f+4>>2]=(b[k+12>>1]|0)-(b[k+18>>1]|0);c[f+8>>2]=(b[k+10>>1]|0)-(b[k+20>>1]|0);c[f+12>>2]=(b[k+8>>1]|0)-(b[k+22>>1]|0);c[f+16>>2]=(b[k+6>>1]|0)-(b[k+24>>1]|0);c[f+20>>2]=(b[k+4>>1]|0)-(b[k+26>>1]|0);c[f+24>>2]=(b[k+2>>1]|0)-(b[k+28>>1]|0);c[f+28>>2]=(b[k>>1]|0)-(b[k+30>>1]|0);k=(c[j>>2]|0)+(c[j+28>>2]|0)|0;d=(c[j+4>>2]|0)+(c[j+24>>2]|0)|0;l=(c[j+8>>2]|0)+(c[j+20>>2]|0)|0;m=(c[j+12>>2]|0)+(c[j+16>>2]|0)|0;n=(c[j+12>>2]|0)-(c[j+16>>2]|0)|0;o=(c[j+8>>2]|0)-(c[j+20>>2]|0)|0;p=(c[j+4>>2]|0)-(c[j+24>>2]|0)|0;q=(c[j>>2]|0)-(c[j+28>>2]|0)|0;j=k+m|0;r=d+l|0;s=d-l|0;l=k-m|0;m=(j+r|0)*11585|0;k=(j-r|0)*11585|0;d=(l*15137|0)+(s*6270|0)|0;t=(l*6270|0)-(s*15137|0)|0;u=m+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}b[a>>1]=u;u=d+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+8>>1]=u;u=k+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+16>>1]=u;u=t+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+24>>1]=u;m=(p-o|0)*11585|0;k=(p+o|0)*11585|0;o=m+8192>>14;if(!(-32768<=(o|0))){Cd(2414424,2539808,23,2652784)}if((o|0)>32767){Cd(2414424,2539808,23,2652784)}d=o;o=k+8192>>14;if(!(-32768<=(o|0))){Cd(2414424,2539808,23,2652784)}if((o|0)>32767){Cd(2414424,2539808,23,2652784)}t=o;j=n+d|0;r=n-d|0;s=q-t|0;l=q+t|0;m=(j*3196|0)+(l*16069|0)|0;k=(r*13623|0)+(s*9102|0)|0;d=(s*13623|0)+(r*-9102|0)|0;t=(l*3196|0)+(j*-16069|0)|0;j=m+8192>>14;if(!(-32768<=(j|0))){Cd(2414424,2539808,23,2652784)}if((j|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+4>>1]=j;j=d+8192>>14;if(!(-32768<=(j|0))){Cd(2414424,2539808,23,2652784)}if((j|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+12>>1]=j;j=k+8192>>14;if(!(-32768<=(j|0))){Cd(2414424,2539808,23,2652784)}if((j|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+20>>1]=j;j=t+8192>>14;if(!(-32768<=(j|0))){Cd(2414424,2539808,23,2652784)}if((j|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+28>>1]=j;j=((c[f+20>>2]|0)-(c[f+8>>2]|0)|0)*11585|0;t=((c[f+16>>2]|0)-(c[f+12>>2]|0)|0)*11585|0;k=j+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}c[g+8>>2]=k;k=t+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}c[g+12>>2]=k;j=((c[f+16>>2]|0)+(c[f+12>>2]|0)|0)*11585|0;t=((c[f+20>>2]|0)+(c[f+8>>2]|0)|0)*11585|0;k=j+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}c[g+16>>2]=k;k=t+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}c[g+20>>2]=k;c[h>>2]=(c[f>>2]|0)+(c[g+12>>2]|0);c[h+4>>2]=(c[f+4>>2]|0)+(c[g+8>>2]|0);c[h+8>>2]=(c[f+4>>2]|0)-(c[g+8>>2]|0);c[h+12>>2]=(c[f>>2]|0)-(c[g+12>>2]|0);c[h+16>>2]=(c[f+28>>2]|0)-(c[g+16>>2]|0);c[h+20>>2]=(c[f+24>>2]|0)-(c[g+20>>2]|0);c[h+24>>2]=(c[f+24>>2]|0)+(c[g+20>>2]|0);c[h+28>>2]=(c[f+28>>2]|0)+(c[g+16>>2]|0);j=((c[h+4>>2]|0)*-15137|0)+((c[h+24>>2]|0)*6270|0)|0;t=((c[h+8>>2]|0)*-6270|0)-((c[h+20>>2]|0)*15137|0)|0;k=j+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}c[g+4>>2]=k;k=t+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}c[g+8>>2]=k;j=((c[h+8>>2]|0)*-15137|0)+((c[h+20>>2]|0)*6270|0)|0;t=((c[h+4>>2]|0)*6270|0)+((c[h+24>>2]|0)*15137|0)|0;k=j+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}c[g+20>>2]=k;k=t+8192>>14;if(!(-32768<=(k|0))){Cd(2414424,2539808,23,2652784)}if((k|0)>32767){Cd(2414424,2539808,23,2652784)}c[g+24>>2]=k;c[f>>2]=(c[h>>2]|0)+(c[g+4>>2]|0);c[f+4>>2]=(c[h>>2]|0)-(c[g+4>>2]|0);c[f+8>>2]=(c[h+12>>2]|0)-(c[g+8>>2]|0);c[f+12>>2]=(c[h+12>>2]|0)+(c[g+8>>2]|0);c[f+16>>2]=(c[h+16>>2]|0)+(c[g+20>>2]|0);c[f+20>>2]=(c[h+16>>2]|0)-(c[g+20>>2]|0);c[f+24>>2]=(c[h+28>>2]|0)-(c[g+24>>2]|0);c[f+28>>2]=(c[h+28>>2]|0)+(c[g+24>>2]|0);j=((c[f>>2]|0)*1606|0)+((c[f+28>>2]|0)*16305|0)|0;t=((c[f+4>>2]|0)*12665|0)+((c[f+24>>2]|0)*10394|0)|0;g=j+8192>>14;if(!(-32768<=(g|0))){Cd(2414424,2539808,23,2652784)}if((g|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+2>>1]=g;g=t+8192>>14;if(!(-32768<=(g|0))){Cd(2414424,2539808,23,2652784)}if((g|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+18>>1]=g;j=((c[f+8>>2]|0)*7723|0)+((c[f+20>>2]|0)*14449|0)|0;t=((c[f+12>>2]|0)*15679|0)+((c[f+16>>2]|0)*4756|0)|0;g=j+8192>>14;if(!(-32768<=(g|0))){Cd(2414424,2539808,23,2652784)}if((g|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+10>>1]=g;g=t+8192>>14;if(!(-32768<=(g|0))){Cd(2414424,2539808,23,2652784)}if((g|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+26>>1]=g;j=((c[f+12>>2]|0)*-4756|0)+((c[f+16>>2]|0)*15679|0)|0;t=((c[f+8>>2]|0)*-14449|0)+((c[f+20>>2]|0)*7723|0)|0;g=j+8192>>14;if(!(-32768<=(g|0))){Cd(2414424,2539808,23,2652784)}if((g|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+6>>1]=g;g=t+8192>>14;if(!(-32768<=(g|0))){Cd(2414424,2539808,23,2652784)}if((g|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+22>>1]=g;j=((c[f+4>>2]|0)*-10394|0)+((c[f+24>>2]|0)*12665|0)|0;t=((c[f>>2]|0)*-16305|0)+((c[f+28>>2]|0)*1606|0)|0;f=j+8192>>14;if(!(-32768<=(f|0))){Cd(2414424,2539808,23,2652784)}if((f|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+14>>1]=f;f=t+8192>>14;if(!(-32768<=(f|0))){Cd(2414424,2539808,23,2652784)}if((f|0)<=32767){b[a+30>>1]=f;i=e;return}else{Cd(2414424,2539808,23,2652784)}}function klc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=i;e=a;a=c;c=b[e+30>>1]|0;f=b[e>>1]|0;g=b[e+26>>1]|0;h=b[e+4>>1]|0;j=b[e+22>>1]|0;k=b[e+8>>1]|0;l=b[e+18>>1]|0;m=b[e+12>>1]|0;n=b[e+14>>1]|0;o=b[e+16>>1]|0;p=b[e+10>>1]|0;q=b[e+20>>1]|0;r=b[e+6>>1]|0;s=b[e+24>>1]|0;t=b[e+2>>1]|0;u=b[e+28>>1]|0;e=(c*16364|0)+(f*804|0)|0;v=(c*804|0)-(f*16364|0)|0;w=(g*15893|0)+(h*3981|0)|0;x=(g*3981|0)-(h*15893|0)|0;y=(j*14811|0)+(k*7005|0)|0;z=(j*7005|0)-(k*14811|0)|0;A=(l*13160|0)+(m*9760|0)|0;B=(l*9760|0)-(m*13160|0)|0;C=(n*11003|0)+(o*12140|0)|0;D=(n*12140|0)-(o*11003|0)|0;E=(p*8423|0)+(q*14053|0)|0;F=(p*14053|0)-(q*8423|0)|0;G=(r*5520|0)+(s*15426|0)|0;H=(r*15426|0)-(s*5520|0)|0;I=(t*2404|0)+(u*16207|0)|0;J=(t*16207|0)-(u*2404|0)|0;K=e+C+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}c=K;K=v+D+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}f=K;K=w+E+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}g=K;K=x+F+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}h=K;K=y+G+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}j=K;K=z+H+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}k=K;K=A+I+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}l=K;K=B+J+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}m=K;K=e-C+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}n=K;K=v-D+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}o=K;K=w-E+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}p=K;K=x-F+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}q=K;K=y-G+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}r=K;K=z-H+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}s=K;K=A-I+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}t=K;K=B-J+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}u=K;e=c;v=f;w=g;x=h;y=j;z=k;A=l;B=m;C=(n*16069|0)+(o*3196|0)|0;D=(n*3196|0)-(o*16069|0)|0;E=(p*9102|0)+(q*13623|0)|0;F=(p*13623|0)-(q*9102|0)|0;G=((-r|0)*3196|0)+(s*16069|0)|0;H=(r*16069|0)+(s*3196|0)|0;I=((-t|0)*13623|0)+(u*9102|0)|0;J=(t*9102|0)+(u*13623|0)|0;c=e+y|0;f=v+z|0;g=w+A|0;h=x+B|0;j=e-y|0;k=v-z|0;l=w-A|0;m=x-B|0;K=C+G+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}n=K;K=D+H+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}o=K;K=E+I+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}p=K;K=F+J+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}q=K;K=C-G+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}r=K;K=D-H+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}s=K;K=E-I+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}t=K;K=F-J+8192>>14;if(!(-32768<=(K|0))){Cd(2414424,2539808,23,2652784)}if((K|0)>32767){Cd(2414424,2539808,23,2652784)}u=K;e=c;v=f;w=g;x=h;y=(j*15137|0)+(k*6270|0)|0;z=(j*6270|0)-(k*15137|0)|0;A=((-l|0)*6270|0)+(m*15137|0)|0;B=(l*15137|0)+(m*6270|0)|0;C=n;D=o;E=p;F=q;G=(r*15137|0)+(s*6270|0)|0;H=(r*6270|0)-(s*15137|0)|0;I=((-t|0)*6270|0)+(u*15137|0)|0;J=(t*15137|0)+(u*6270|0)|0;c=e+w|0;f=v+x|0;g=e-w|0;h=v-x|0;v=y+A+8192>>14;if(!(-32768<=(v|0))){Cd(2414424,2539808,23,2652784)}if((v|0)>32767){Cd(2414424,2539808,23,2652784)}j=v;v=z+B+8192>>14;if(!(-32768<=(v|0))){Cd(2414424,2539808,23,2652784)}if((v|0)>32767){Cd(2414424,2539808,23,2652784)}k=v;v=y-A+8192>>14;if(!(-32768<=(v|0))){Cd(2414424,2539808,23,2652784)}if((v|0)>32767){Cd(2414424,2539808,23,2652784)}l=v;v=z-B+8192>>14;if(!(-32768<=(v|0))){Cd(2414424,2539808,23,2652784)}if((v|0)>32767){Cd(2414424,2539808,23,2652784)}m=v;n=C+E|0;o=D+F|0;p=C-E|0;q=D-F|0;D=G+I+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}r=D;D=H+J+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}s=D;D=G-I+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}t=D;D=H-J+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}u=D;w=(g+h|0)*-11585|0;x=(g-h|0)*11585|0;A=(l+m|0)*11585|0;B=((-l|0)+m|0)*11585|0;E=(p+q|0)*11585|0;F=((-p|0)+q|0)*11585|0;I=(t+u|0)*-11585|0;J=(t-u|0)*11585|0;D=w+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}g=D;D=x+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}h=D;D=A+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}l=D;D=B+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}m=D;D=E+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}p=D;D=F+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}q=D;D=I+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)>32767){Cd(2414424,2539808,23,2652784)}t=D;D=J+8192>>14;if(!(-32768<=(D|0))){Cd(2414424,2539808,23,2652784)}if((D|0)<=32767){u=D;b[a>>1]=c;b[a+2>>1]=-n;b[a+4>>1]=r;b[a+6>>1]=-j;b[a+8>>1]=l;b[a+10>>1]=t;b[a+12>>1]=p;b[a+14>>1]=g;b[a+16>>1]=h;b[a+18>>1]=q;b[a+20>>1]=u;b[a+22>>1]=m;b[a+24>>1]=k;b[a+26>>1]=-s;b[a+28>>1]=o;b[a+30>>1]=-f;i=d;return}else{Cd(2414424,2539808,23,2652784)}}function llc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;e=a;a=c;c=b[e+14>>1]|0;f=b[e>>1]|0;g=b[e+10>>1]|0;h=b[e+4>>1]|0;j=b[e+6>>1]|0;k=b[e+8>>1]|0;l=b[e+2>>1]|0;m=b[e+12>>1]|0;e=(c*16305|0)+(f*1606|0)|0;n=(c*1606|0)-(f*16305|0)|0;o=(g*14449|0)+(h*7723|0)|0;p=(g*7723|0)-(h*14449|0)|0;q=(j*10394|0)+(k*12665|0)|0;r=(j*12665|0)-(k*10394|0)|0;s=(l*4756|0)+(m*15679|0)|0;t=(l*15679|0)-(m*4756|0)|0;u=e+q+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}c=u;u=n+r+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}f=u;u=o+s+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}g=u;u=p+t+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}h=u;u=e-q+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}j=u;u=n-r+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}k=u;u=o-s+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}l=u;u=p-t+8192>>14;if(!(-32768<=(u|0))){Cd(2414424,2539808,23,2652784)}if((u|0)>32767){Cd(2414424,2539808,23,2652784)}m=u;e=c;n=f;o=g;p=h;q=(j*15137|0)+(k*6270|0)|0;r=(j*6270|0)-(k*15137|0)|0;s=(l*-6270|0)+(m*15137|0)|0;t=(l*15137|0)+(m*6270|0)|0;c=e+o|0;f=n+p|0;g=e-o|0;h=n-p|0;n=q+s+8192>>14;if(!(-32768<=(n|0))){Cd(2414424,2539808,23,2652784)}if((n|0)>32767){Cd(2414424,2539808,23,2652784)}j=n;n=r+t+8192>>14;if(!(-32768<=(n|0))){Cd(2414424,2539808,23,2652784)}if((n|0)>32767){Cd(2414424,2539808,23,2652784)}k=n;n=q-s+8192>>14;if(!(-32768<=(n|0))){Cd(2414424,2539808,23,2652784)}if((n|0)>32767){Cd(2414424,2539808,23,2652784)}l=n;n=r-t+8192>>14;if(!(-32768<=(n|0))){Cd(2414424,2539808,23,2652784)}if((n|0)>32767){Cd(2414424,2539808,23,2652784)}m=n;o=(g+h|0)*11585|0;p=(g-h|0)*11585|0;s=(l+m|0)*11585|0;t=(l-m|0)*11585|0;n=o+8192>>14;if(!(-32768<=(n|0))){Cd(2414424,2539808,23,2652784)}if((n|0)>32767){Cd(2414424,2539808,23,2652784)}g=n;n=p+8192>>14;if(!(-32768<=(n|0))){Cd(2414424,2539808,23,2652784)}if((n|0)>32767){Cd(2414424,2539808,23,2652784)}h=n;n=s+8192>>14;if(!(-32768<=(n|0))){Cd(2414424,2539808,23,2652784)}if((n|0)>32767){Cd(2414424,2539808,23,2652784)}l=n;n=t+8192>>14;if(!(-32768<=(n|0))){Cd(2414424,2539808,23,2652784)}if((n|0)<=32767){m=n;b[a>>1]=c;b[a+2>>1]=-j;b[a+4>>1]=l;b[a+6>>1]=-g;b[a+8>>1]=h;b[a+10>>1]=-m;b[a+12>>1]=k;b[a+14>>1]=-f;i=d;return}else{Cd(2414424,2539808,23,2652784)}}function mlc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=a;a=c;b[e>>1]=(b[f>>1]|0)+(b[f+6>>1]|0);b[e+2>>1]=(b[f+2>>1]|0)+(b[f+4>>1]|0);b[e+4>>1]=(b[f+2>>1]|0)-(b[f+4>>1]|0);b[e+6>>1]=(b[f>>1]|0)-(b[f+6>>1]|0);f=((b[e>>1]|0)+(b[e+2>>1]|0)|0)*11585|0;c=((b[e>>1]|0)-(b[e+2>>1]|0)|0)*11585|0;g=f+8192>>14;if(!(-32768<=(g|0))){Cd(2414424,2539808,23,2652784)}if((g|0)>32767){Cd(2414424,2539808,23,2652784)}b[a>>1]=g;g=c+8192>>14;if(!(-32768<=(g|0))){Cd(2414424,2539808,23,2652784)}if((g|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+4>>1]=g;f=((b[e+4>>1]|0)*6270|0)+((b[e+6>>1]|0)*15137|0)|0;c=((-(b[e+4>>1]|0)|0)*15137|0)+((b[e+6>>1]|0)*6270|0)|0;e=f+8192>>14;if(!(-32768<=(e|0))){Cd(2414424,2539808,23,2652784)}if((e|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+2>>1]=e;e=c+8192>>14;if(!(-32768<=(e|0))){Cd(2414424,2539808,23,2652784)}if((e|0)<=32767){b[a+6>>1]=e;i=d;return}else{Cd(2414424,2539808,23,2652784)}}function nlc(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a;a=c;c=b[e>>1]|0;f=b[e+2>>1]|0;g=b[e+4>>1]|0;h=b[e+6>>1]|0;if((c|f|g|h|0)==0){b[a+6>>1]=0;b[a+4>>1]=0;b[a+2>>1]=0;b[a>>1]=0;i=d;return}e=c*5283|0;j=c*15212|0;k=f*9929|0;l=f*5283|0;m=g*13377|0;n=c+f-h|0;c=e+k+(h*15212|0)|0;f=n*13377|0;g=j-l+(h*9929|0)|0;h=m;e=c+h|0;j=f;k=g-h|0;l=g-c+h|0;h=e+8192>>14;if(!(-32768<=(h|0))){Cd(2414424,2539808,23,2652784)}if((h|0)>32767){Cd(2414424,2539808,23,2652784)}b[a>>1]=h;h=j+8192>>14;if(!(-32768<=(h|0))){Cd(2414424,2539808,23,2652784)}if((h|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+2>>1]=h;h=k+8192>>14;if(!(-32768<=(h|0))){Cd(2414424,2539808,23,2652784)}if((h|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+4>>1]=h;h=l+8192>>14;if(!(-32768<=(h|0))){Cd(2414424,2539808,23,2652784)}if((h|0)>32767){Cd(2414424,2539808,23,2652784)}b[a+6>>1]=h;i=d;return}function olc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=f|0;g=a|0;h=wrc(c[b>>2]|0,c[b+4>>2]|0,c[g>>2]|0,c[g+4>>2]|0)|0;g=G;b=f+8|0;j=a+8|0;k=wrc(c[b>>2]|0,c[b+4>>2]|0,c[j>>2]|0,c[j+4>>2]|0)|0;plc(h,g,k,G,(c[f+16>>2]|0)+(c[a+16>>2]|0)|0,d);i=e;return}function plc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;i=i+16|0;j=h|0;k=h+8|0;c[j>>2]=a;c[j+4>>2]=b;c[k>>2]=d;c[k+4>>2]=e;e=f;f=g;g=c[j+4>>2]|0;d=f|0;c[d>>2]=c[j>>2];c[d+4>>2]=g;g=c[k+4>>2]|0;d=f+8|0;c[d>>2]=c[k>>2];c[d+4>>2]=g;c[f+16>>2]=e;if((e|0)>0){e=f|0;g=c[e>>2]|0;d=c[e+4>>2]|0;e=f+8|0;k=f+8|0;j=Erc(c[e>>2]|0,c[e+4>>2]|0,c[k>>2]|0,c[k+4>>2]|0)|0;k=c[f+16>>2]|0;e=Crc(j,G,k,(k|0)<0|0?-1:0)|0;k=xrc(g,d,e,G)|0;e=Erc(256,0,k,G)|0;k=c[f+16>>2]|0;d=Crc(e,G,k,(k|0)<0|0?-1:0)|0;c[f+20>>2]=d;i=h;return}else{c[f+20>>2]=0;i=h;return}}function qlc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=f+16|0;j=a;a=b;b=d;d=e;e=g|0;c[e>>2]=c[a+52>>2];k=e+4|0;c[k>>2]=c[a+56>>2];e=k+4|0;c[e>>2]=c[a+60>>2];c[e+4>>2]=c[a+64>>2];e=h|0;c[e>>2]=c[a+16>>2];k=e+4|0;c[k>>2]=c[a+36>>2];e=k+4|0;c[e>>2]=c[a+36>>2];c[e+4>>2]=c[a+48>>2];c[j+24916>>2]=a;a=0;while(1){if((a|0)>=3){break}e=j+(a*8240|0)+8204|0;k=c[h+(a<<2)>>2]|0;l=c[g+(a<<2)>>2]|0;m=d<<3>>c[j+24720+(a*52|0)+8>>2];n=b<<3>>c[j+24720+(a*52|0)+12>>2];o=0;if((o|0)!=0){p=We[c[o+16>>2]&2047](m,o)|0}else{p=m}if((o|0)!=0){q=We[c[o+20>>2]&2047](n,o)|0}else{q=n}c[e>>2]=l+((ca(q,k)|0)+p);c[e+4>>2]=k;a=a+1|0}i=f;return}function rlc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a;a=f+1434592|0;g=f+1473304|0;h=a;if((c[h+10108>>2]|0)==0){j=1}else{j=(c[h+10124>>2]|0)!=0}if((j&1|0)==0){do{if((c[a+13376>>2]|0)==(c[a+13372>>2]|0)){k=6}else{if((c[a+13376>>2]|0)==(c[a+13368>>2]|0)){k=6;break}c[a+13520>>2]=1;c[a+13524>>2]=3;c[a+13528>>2]=1;c[a+13532>>2]=2}}while(0);if((k|0)==6){c[a+13520>>2]=0}}if((c[f+2046876>>2]|0)==0){c[a+13536>>2]=0;c[a+10220>>2]=4;ulc(f);i=b;return}j=slc(f)|0;h=g+17016+(j*24|0)|0;l=g+17264+(j<<5)|0;do{if((j|0)==3){k=12}else{if((c[a+13520>>2]|0)==0){k=12;break}m=h+8|0;n=c[m+4>>2]|0;o=h|0;p=c[o+4>>2]|0;do{if((n|0)>(p|0)|(n|0)==(p|0)&(c[m>>2]|0)>>>0>(c[o>>2]|0)>>>0){q=h+8|0;r=c[q+4>>2]|0;s=h+16|0;t=c[s+4>>2]|0;if(!((r|0)>(t|0)|(r|0)==(t|0)&(c[q>>2]|0)>>>0>(c[s>>2]|0)>>>0)){k=18;break}if((tlc(f)|0)==0){k=18;break}if((c[f+2046856>>2]|0)!=100){k=18;break}c[a+13536>>2]=1}else{k=18}}while(0);if((k|0)==18){o=h|0;m=c[o+4>>2]|0;p=h+16|0;n=c[p+4>>2]|0;if((m|0)>(n|0)|(m|0)==(n|0)&(c[o>>2]|0)>>>0>(c[p>>2]|0)>>>0){c[a+13536>>2]=0}else{c[a+13536>>2]=2}}}}while(0);if((k|0)==12){c[a+13536>>2]=0}if((c[a+10220>>2]|0)==4){do{if((j|0)!=3){h=l+8|0;p=c[h+4>>2]|0;o=l|0;n=c[o+4>>2]|0;if(!((p|0)>(n|0)|(p|0)==(n|0)&(c[h>>2]|0)>>>0>(c[o>>2]|0)>>>0)){k=29;break}o=l+8|0;h=c[o+4>>2]|0;n=l+16|0;p=c[n+4>>2]|0;if(!((h|0)>(p|0)|(h|0)==(p|0)&(c[o>>2]|0)>>>0>(c[n>>2]|0)>>>0)){k=29;break}n=l+8|0;o=c[n+4>>2]|0;p=l+24|0;h=c[p+4>>2]|0;if(!((o|0)>(h|0)|(o|0)==(h|0)&(c[n>>2]|0)>>>0>(c[p>>2]|0)>>>0)){k=29;break}c[a+10220>>2]=1}else{k=29}}while(0);if((k|0)==29){p=l+16|0;n=c[p+4>>2]|0;h=l|0;o=c[h+4>>2]|0;do{if((n|0)>(o|0)|(n|0)==(o|0)&(c[p>>2]|0)>>>0>(c[h>>2]|0)>>>0){m=l+16|0;s=c[m+4>>2]|0;q=l+24|0;t=c[q+4>>2]|0;if(!((s|0)>(t|0)|(s|0)==(t|0)&(c[m>>2]|0)>>>0>(c[q>>2]|0)>>>0)){k=32;break}c[a+10220>>2]=2}else{k=32}}while(0);if((k|0)==32){h=l|0;p=c[h+4>>2]|0;o=l+24|0;l=c[o+4>>2]|0;if((p|0)>(l|0)|(p|0)==(l|0)&(c[h>>2]|0)>>>0>(c[o>>2]|0)>>>0){c[a+10220>>2]=0}}}}ulc(f);o=0;while(1){if((o|0)>=3){break}h=g+16992+(o<<3)|0;l=c[a+10140>>2]|0;p=Crc(c[h>>2]|0,c[h+4>>2]|0,l,(l|0)<0|0?-1:0)|0;l=p;p=g+17016+(j*24|0)+(o<<3)|0;h=wrc(c[p>>2]|0,c[p+4>>2]|0,l,(l|0)<0|0?-1:0)|0;c[p>>2]=h;c[p+4>>2]=G;p=g+17016+(j*24|0)+(o<<3)|0;h=c[p+4>>2]|0;c[p>>2]=(c[p>>2]|0)>>>1|h<<31;c[p+4>>2]=h>>1|((h|0)<0|0?-1:0)<<31;o=o+1|0}o=0;while(1){if((o|0)>=4){break}h=g+17232+(o<<3)|0;p=c[a+10140>>2]|0;l=Crc(c[h>>2]|0,c[h+4>>2]|0,p,(p|0)<0|0?-1:0)|0;c[d>>2]=l;c[d+4>>2]=G;l=g+17264+(j<<5)+(o<<3)|0;p=wrc(c[l>>2]|0,c[l+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0;l=Crc(p,G,2,0)|0;p=g+17264+(j<<5)+(o<<3)|0;c[p>>2]=l;c[p+4>>2]=G;o=o+1|0}o=0;while(1){if((o|0)>=5){break}d=g+17112+(o<<3)|0;p=c[d+4>>2]|0;c[e>>2]=c[d>>2];c[e+4>>2]=p;if((o|0)==4){p=c[f+108016>>2]|0;d=Erc(6144,0,p,(p|0)<0|0?-1:0)|0;p=wrc(128,0,d,G)|0;d=G;l=0<<c[f+108012>>2];h=wrc(p>>>8|d<<24,d>>8|((d|0)<0|0?-1:0)<<24,l,(l|0)<0|0?-1:0)|0;l=xrc(c[e>>2]|0,c[e+4>>2]|0,h,G)|0;c[e>>2]=l;c[e+4>>2]=G}l=c[a+10140>>2]|0;h=Crc(c[e>>2]|0,c[e+4>>2]|0,l,(l|0)<0|0?-1:0)|0;l=g+17152+(j*20|0)+(o<<2)|0;c[l>>2]=(c[l>>2]|0)+h;h=g+17152+(j*20|0)+(o<<2)|0;c[h>>2]=(c[h>>2]|0)/2|0;o=o+1|0}if((c[a+13536>>2]|0)==2){j=0;g=0;o=0;while(1){if((o|0)>=5){break}j=j+(c[a+36268+(o<<3)>>2]|0)|0;g=g+(c[a+36268+(o<<3)+4>>2]|0)|0;o=o+1|0}if((g|0)==0){c[a+13536>>2]=0;mrc(a+36268|0,0,40)|0}else{if((j|0)==0){c[a+13536>>2]=1;mrc(a+36268|0,0,40)|0}}}if((c[a+10164>>2]|0)==4){j=0;g=0;e=0;f=0;h=0;l=0;o=0;while(1){if((o|0)>=2){break}j=j+(c[a+36428+(o<<4)>>2]|0)|0;j=j+(c[a+36460+(o*12|0)>>2]|0)|0;j=j+(c[a+36484+(o<<3)>>2]|0)|0;g=g+(c[a+36428+(o<<4)+4>>2]|0)|0;g=g+(c[a+36460+(o*12|0)+4>>2]|0)|0;e=e+(c[a+36484+(o<<3)+4>>2]|0)|0;f=f+(c[a+36460+(o*12|0)+8>>2]|0)|0;h=h+(c[a+36428+(o<<4)+8>>2]|0)|0;l=l+(c[a+36428+(o<<4)+12>>2]|0)|0;o=o+1|0}do{if((j|0)==0){if((h|0)!=0){k=72;break}if((f|0)!=0){k=72;break}if((l|0)!=0){k=72;break}c[a+10164>>2]=1;vlc(a,1)}else{k=72}}while(0);if((k|0)==72){do{if((e|0)==0){if((f|0)!=0){k=78;break}if((g|0)!=0){k=78;break}if((h|0)!=0){k=78;break}if((l|0)!=0){k=78;break}c[a+10164>>2]=0;vlc(a,0)}else{k=78}}while(0);if((k|0)==78){do{if((g|0)==0){if((h|0)!=0){k=82;break}if((j|0)!=0){k=82;break}c[a+10164>>2]=3}else{k=82}}while(0);if((k|0)==82){do{if((l|0)==0){if((g|0)!=0){break}if((j|0)!=0){break}c[a+10164>>2]=2;vlc(a,2)}}while(0)}}}}i=b;return}function slc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;a=d+1434592|0;if((c[a+10108>>2]|0)==0){e=1}else{e=(c[a+10124>>2]|0)!=0}if((e&1|0)!=0){f=0;g=f;i=b;return g|0}do{if((c[d+2017236>>2]|0)!=0){if((c[d+1472148>>2]|0)==0){break}f=3;g=f;i=b;return g|0}}while(0);do{if((c[d+1472148>>2]|0)==0){if((c[d+1472152>>2]|0)!=0){break}f=2;g=f;i=b;return g|0}}while(0);f=1;g=f;i=b;return g|0}function tlc(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;a=c[d+2046872>>2]|0;if((Thc(d+1448e3|0,1,2)|0)!=0){e=0;f=e;i=b;return f|0}else{e=((((a&2|0)!=0^1^1)&1)+(((a&1|0)!=0^1^1)&1)+(((a&4|0)!=0^1^1)&1)|0)>=2|0;f=e;i=b;return f|0}return 0}function ulc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+40|0;d=b|0;e=b+16|0;f=b+24|0;g=a;a=g+2046876|0;h=g+1473304|0;j=g+32768|0;k=g+1434592|0;l=j+24720|0;c[l+160>>2]=c[k+10204>>2];c[c[l+160>>2]>>2]=c[k+10188>>2];mrc(k+23740|0,0,13208)|0;mrc(g+2017372|0,0,27648)|0;mrc(g+2050776|0,0,16)|0;mrc(h+16992|0,0,24)|0;mrc(h+17232|0,0,32)|0;mrc(h+17112|0,0,40)|0;mrc(h+17152|0,0,80)|0;c[k+10164>>2]=wlc(g)|0;do{if((c[k+10168>>2]|0)==0){if((c[k+10172>>2]|0)!=0){m=0;break}if((c[k+10176>>2]|0)!=0){m=0;break}m=(c[k+10180>>2]|0)==0}else{m=0}}while(0);c[g+83296>>2]=m&1;xlc(g,c[g+83296>>2]|0);J2b(g);B3b(g);A3b(g,c[k+10168>>2]|0);ylc(g);if((c[g+1471880>>2]|0)==1){zlc(g)}m=k;do{if((c[m+8452>>2]|0)==(c[m+8468>>2]|0)){if((c[m+8456>>2]|0)!=(c[m+8472>>2]|0)){n=0;break}if((c[m+10124>>2]|0)!=0){n=0;break}n=(c[m+10116>>2]|0)!=0}else{n=0}}while(0);if((n&1|0)!=0){o=(c[m+10192>>2]|0)+((c[m+10160>>2]|0)*124|0)+124|0}else{o=0}c[m+10196>>2]=o;if((c[a+208>>2]|0)!=0){o=j|0;m=l|0;l=g+1433384|0;n=0;while(1){if((n|0)>=3){break}c[o+(n*8240|0)+8196>>2]=c[l+272+(n*12|0)>>2];c[o+(n*8240|0)+8192>>2]=c[l+308+(n*12|0)>>2];c[m+(n*52|0)>>2]=c[l+344+(n*12|0)>>2];c[o+(n*8240|0)+8200>>2]=c[l+380+(n*12|0)>>2];n=n+1|0}mrc(j+1128252|0,0,1024)|0;do{if((c[a+84>>2]|0)==5){if(!((c[k+36948>>2]|0)>>>0>0>>>0)){break}j=c[a+280>>2]|0;if(((((c[k+36948>>2]|0)-1|0)>>>0)%(j>>>0)|0|0)==0){c[g+2055624>>2]=0}if(((((c[k+36948>>2]|0)-1|0)>>>0)%(j>>>0)|0|0)==1){n=ca((c[g+2055624>>2]|0)*100|0,1<<(c[490093]|0)-(c[490090]|0)+((c[490183]|0)-(c[490180]|0)))|0;c[g+2055624>>2]=(n|0)/(c[k+10140>>2]|0)|0}if(((((c[k+36948>>2]|0)-1|0)>>>0)%(j>>>0)|0)>>>0>=1>>>0){if((c[g+2055624>>2]|0)<15){c[a+84>>2]=1}}}}while(0)}Alc(d);c[e>>2]=c[g+1472272>>2];j=1<<c[k+36972>>2];n=1<<c[k+36976>>2];l=0;while(1){if((l|0)>=(n|0)){break}o=0;while(1){if((o|0)>=(j|0)){break}m=c[e>>2]|0;_hc(f,k,l,o);h=c[f>>2]|0;while(1){if((h|0)>=(c[f+4>>2]|0)){break}do{if((c[a+208>>2]|0)!=0){if((c[k+10108>>2]|0)==0){p=40;break}Blc(g,f,h,e)}else{p=40}}while(0);if((p|0)==40){p=0;Clc(g,f,h,e)}h=h+8|0}c[g+1472276+(l<<8)+(o<<2)>>2]=((c[e>>2]|0)-m|0)/8|0;if((((c[e>>2]|0)-(c[g+1472272>>2]|0)|0)/8|0|0)<=((ca(c[k+10144>>2]|0,c[k+10152>>2]|0)|0)*772|0|0)){}else{Cd(2269800,2539744,3319,2652920)}o=o+1|0}l=l+1|0}Dlc(d);l=Elc(d)|0;d=g+2047848|0;g=wrc(c[d>>2]|0,c[d+4>>2]|0,l,G)|0;c[d>>2]=g;c[d+4>>2]=G;if((c[a+52>>2]|0)==0){c[a+56>>2]=0;i=b;return}d=0;g=0;l=0;while(1){if((l|0)>=4){break}d=d+(c[k+36236+(l<<3)>>2]|0)|0;g=g+(c[k+36236+(l<<3)+4>>2]|0)|0;l=l+1|0}do{if(d<<2>>>0<g>>>0){if((c[k+10108>>2]|0)==0){q=0;break}q=(c[k+10112>>2]|0)!=0}else{q=0}}while(0);c[a+56>>2]=q&1;i=b;return}function vlc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=c[e+10160>>2]|0;f=c[e+10204>>2]|0;g=0;while(1){if((g|0)>=(c[e+10148>>2]|0)){break}h=0;while(1){if((h|0)>=(c[e+10156>>2]|0)){break}if((c[(c[f+(h<<2)>>2]|0)+8>>2]|0)>>>0>a>>>0){c[(c[f+(h<<2)>>2]|0)+8>>2]=a}h=h+1|0}g=g+1|0;f=f+(b<<2)|0}i=d;return}function wlc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;if((c[d+1471724>>2]|0)!=0){e=0;f=e;i=b;return f|0}if((c[d+1471540>>2]|0)==0){e=4;f=e;i=b;return f|0}if((c[d+2046944>>2]|0)==3){e=3;f=e;i=b;return f|0}if((c[d+2046944>>2]|0)==0){a=d+1473304|0;g=slc(d)|0;e=(c[a+17152+(g*20|0)+12>>2]|0)>(c[a+17152+(g*20|0)+16>>2]|0)?3:4;f=e;i=b;return f|0}g=0;a=0;while(1){if((a|0)>=4){break}g=g+(c[d+2050776+(a<<2)>>2]|0)|0;a=a+1|0}if((g|0)!=0){e=+((c[d+2050776>>2]|0)>>>0>>>0)/+(g>>>0>>>0)>.9?3:4;f=e;i=b;return f|0}else{e=c[d+1444756>>2]|0;f=e;i=b;return f|0}return 0}function xlc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;if((b|0)!=0){c[e+1434580>>2]=800;c[e+83300>>2]=24;c[e+1217352>>2]=0;c[e+1447972>>2]=0;c[e+2017092>>2]=0;c[e+1444756>>2]=0;i=d;return}else{c[e+1434580>>2]=230;c[e+83300>>2]=102;i=d;return}}function ylc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=a;a=d+32768|0;e=d+1434592|0;f=a+24720|0;g=(c[e+10156>>2]|0)+7&-8;c[a+75264>>2]=0;qlc(a,c[d+1471904>>2]|0,0,0);h=f;j=d;d=j+1434592|0;k=j;j=1;do{if((j|0)==1){l=c[k+1472132>>2]|0}else{if((j|0)==2){l=c[k+1472136>>2]|0;break}else{l=c[k+1472140>>2]|0;break}}}while(0);Agc(h,0,d+8488+((c[d+9784+(l<<2)>>2]|0)*108|0)+16|0,0,0,0);l=e;zgc(f,l+8488+((c[l+10008>>2]|0)*108|0)+16|0,0,0);gec(a+24720|0,c[e+8476>>2]|0,c[e+8480>>2]|0);c[(c[c[f+160>>2]>>2]|0)+4>>2]=0;c[(c[c[f+160>>2]>>2]|0)+16>>2]=0;mrc(c[f+50400>>2]|0,0,(g<<1)*3|0|0)|0;mrc(c[f+50460>>2]|0,0,g|0)|0;i=b;return}function zlc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+8|0;d=b|0;e=a;a=e+32768|0;f=a+24720|0;g=e+1434592|0;h=g;j=h+8488+((c[h+10008>>2]|0)*108|0)+16|0;h=c[j+16>>2]|0;c[d>>2]=0;c[d+4>>2]=0;c[a+75256>>2]=c[e+2050760>>2];k=0;while(1){if((k|0)>=(c[g+10144>>2]|0)){break}c[f+164>>2]=(k|0)!=0;l=(ca(k,h)|0)<<4;m=0;while(1){if((m|0)>=(c[g+10152>>2]|0)){break}c[f+16>>2]=(c[j+52>>2]|0)+l;c[f+168>>2]=(m|0)!=0;l=l+16|0;n=vmc(a,k,m)|0;o=wrc(c[d>>2]|0,c[d+4>>2]|0,n,0)|0;c[d>>2]=o;c[d+4>>2]=G;c[c[a+75256>>2]>>2]=n;n=a+75256|0;c[n>>2]=(c[n>>2]|0)+4;n=a+8204|0;c[n>>2]=(c[n>>2]|0)+16;m=m+1|0}m=a+8204|0;c[m>>2]=(c[m>>2]|0)+((c[a+8208>>2]<<4)-(c[g+10152>>2]<<4));k=k+1|0}wmc(e,c[d>>2]|0,c[d+4>>2]|0);i=b;return}function Alc(a){a=a|0;var b=0;b=i;jd(a|0,0)|0;i=b;return}function Blc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=a;a=b;b=d;d=e;e=j+1434592|0;k=j+57488|0;mrc(k+50412|0,0,48)|0;mrc(k+50464|0,0,8)|0;k=c[a+8>>2]|0;a:while(1){if((k|0)>=(c[a+12>>2]|0)){l=18;break}c[g>>2]=0;c[h>>2]=0;c[h+4>>2]=0;m=(ca(c[e+10160>>2]|0,b)|0)+k|0;n=(c[e+10204>>2]|0)+(m<<2)|0;o=(c[e+10212>>2]|0)+(m<<2)|0;c[j+108068>>2]=-1;mrc(j+1217364|0,0,16)|0;switch(c[j+2046960>>2]|0){case 5:{mmc(j,a,n,b,k);lmc(j,a,n,d,b,k,12,1,g,h);break};case 4:{Jlc(j,a,b,k);lmc(j,a,n,d,b,k,12,1,g,h);break};case 3:{do{if((c[j+2047012>>2]|0)!=0){l=12}else{if((Klc(e,o)|0)!=0){l=12;break}Olc(e,n,o);lmc(j,a,n,d,b,k,12,1,g,h)}}while(0);if((l|0)==12){l=0;omc(j,a,d,b,k,12,g,h,1,-1,2147483647)}break};case 2:case 1:{if((c[j+2046960>>2]|0)==1){p=c[j+2046964>>2]|0}else{p=nmc(j,b,k)|0}Glc(j,a,n,b,k,p);lmc(j,a,n,d,b,k,12,1,g,h);break};default:{l=15;break a}}k=k+8|0}if((l|0)==15){Cd(2524984,2539744,3209,2652872)}else if((l|0)==18){i=f;return}}function Clc(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=b;b=e;e=f;f=g;g=l+1434592|0;m=l+57488|0;n=l+2046876|0;mrc(m+50412|0,0,48)|0;mrc(m+50464|0,0,8)|0;m=c[b+8>>2]|0;a:while(1){if((m|0)>=(c[b+12>>2]|0)){o=74;break}p=l+32768|0;if((c[n+132>>2]|0)!=0){q=0;while(1){if(!(q>>>0<3>>>0)){break}r=c[777792+(q<<2)>>2]|0;s=c[777848+(q<<2)>>2]|0;if(4>(ca(r,s)|0)){t=4}else{t=ca(r,s)|0}s=t;a[p+1128232|0]=0;while(1){if((d[p+1128232|0]|0|0)>=4){break}a[p+1128233|0]=0;while(1){if((d[p+1128233|0]|0|0)>=4){break}a[p+1128234|0]=0;while(1){if((d[p+1128234|0]|0|0)>=(16/(s|0)|0|0)){break}r=p;switch(q|0){case 5:{u=r+1357416+((d[r+1128232|0]|0)*4800|0)+((d[r+1128233|0]|0)*1200|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 4:{u=r+1338216+((d[r+1128232|0]|0)*4800|0)+((d[r+1128233|0]|0)*1200|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 0:{u=r+1184616+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 8:{u=r+1386216+((d[r+1128232|0]|0)*1200|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 7:{u=r+1391016+((d[r+1128232|0]|0)*1200|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 2:{u=r+1223016+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 3:{u=r+1299816+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 1:{u=r+1261416+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 12:{u=r+1400616|0;break};case 10:{u=r+1398216+((d[r+1128232|0]|0)*600|0)|0;break};case 6:{u=r+1376616+((d[r+1128232|0]|0)*2400|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 11:{u=r+1399416+((d[r+1128232|0]|0)*600|0)|0;break};case 9:{u=r+1395816+((d[r+1128232|0]|0)*600|0)|0;break};default:{o=29;break a}}c[u+592>>2]=4;r=p+1128234|0;a[r]=(a[r]|0)+1}r=p+1128233|0;a[r]=(a[r]|0)+1}r=p+1128232|0;a[r]=(a[r]|0)+1}q=q+1|0}}mrc(l+1217364|0,0,16)|0;if((c[n+84>>2]|0)==0){if((c[n+64>>2]|0)!=0){o=44}else{o=41}}else{o=41}do{if((o|0)==41){o=0;if((c[n+84>>2]|0)==1){o=44;break}if((c[n+84>>2]|0)==4){o=44;break}if((c[n+84>>2]|0)==2){o=44;break}if((c[n+100>>2]|0)!=0){Flc(l,b,e,m,12);Llc(l,b,e,m,n+104|0,n+108|0)}Mlc(l,b,f,e,m,12,j,k,1,-1,2147483647)}}while(0);if((o|0)==44){o=0;q=(ca(c[g+10160>>2]|0,e)|0)+m|0;p=(c[g+10204>>2]|0)+(q<<2)|0;s=(c[g+10212>>2]|0)+(q<<2)|0;c[l+108068>>2]=-1;if((c[n+84>>2]|0)==1){Flc(l,b,e,m,12);Glc(l,b,p,e,m,c[n+88>>2]|0);Hlc(l,b,p,f,e,m,12,j,k,1)}else{if((c[n+84>>2]|0)==2){Flc(l,b,e,m,12);Glc(l,b,p,e,m,Ilc(l,e,m)|0);Hlc(l,b,p,f,e,m,12,j,k,1)}else{if((c[n+84>>2]|0)==4){Jlc(l,b,e,m);Hlc(l,b,p,f,e,m,12,j,k,1)}else{do{if((((c[g+36948>>2]|0)>>>0)%((c[n+116>>2]|0)>>>0)|0|0)==0){o=57}else{if((c[g+10196>>2]|0)==0){o=57;break}if((c[g+10112>>2]|0)==0){o=57;break}if((c[g+10108>>2]|0)==0){o=57;break}if((c[l+2017236>>2]|0)!=0){o=57;break}if((c[n+64>>2]|0)==1){if((Klc(g,s)|0)!=0){o=57;break}}do{if((c[n+120>>2]|0)!=0){if((Klc(g,s)|0)==0){o=63;break}Nlc(l,b,p,s,e,m,6)}else{o=63}}while(0);if((o|0)==63){o=0;Olc(g,p,s)}Hlc(l,b,p,f,e,m,12,j,k,1)}}while(0);if((o|0)==57){o=0;if((c[n+100>>2]|0)!=0){Flc(l,b,e,m,12);Llc(l,b,e,m,n+104|0,n+108|0)}Mlc(l,b,f,e,m,12,j,k,1,-1,2147483647)}}}}}m=m+8|0}if((o|0)==29){Cd(2524984,2415424,229,2652560)}else if((o|0)==74){i=h;return}}function Dlc(a){a=a|0;var b=0;b=i;jd(a+8|0,0)|0;i=b;return}function Elc(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;e=a;c[d>>2]=(c[e+8>>2]|0)-(c[e>>2]|0);a=(c[e+12>>2]|0)-(c[e+4>>2]|0)|0;c[d+4>>2]=a;if((a|0)<0){a=d+4|0;c[a>>2]=(c[a>>2]|0)+1e6;a=d|0;e=c[a>>2]|0;c[a>>2]=e-1;f=(e|0)!=0}else{f=0}f=((c[d>>2]|0)*1e6|0)+(c[d+4>>2]|0)|0;i=b;return(G=(f|0)<0|0?-1:0,f)|0}function Flc(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;k=b;b=e;e=f;f=g;g=h;h=k+32768|0;l=k+1434592|0;m=h+24720|0;n=c[777680+(g<<2)>>2]|0;o=c[777736+(g<<2)>>2]|0;p=(ca(e>>1,c[l+10152>>2]|0)|0)+(f>>1)|0;q=l+13408|0;r=m;s=f<<1;t=e<<1&15;u=0;while(1){if((u|0)>=3){break}v=r+(u*52|0)|0;c[v+44>>2]=(c[r+50400+(u<<2)>>2]|0)+(s>>c[v+8>>2]);c[v+48>>2]=r+50412+(u<<4)+(t>>c[v+12>>2]);u=u+1|0}c[h+75256>>2]=(c[k+2050760>>2]|0)+(p<<2);c[h+1129284>>2]=Plc(k,h,e,f,g)|0;p=l;u=m;t=(ca(c[u+156>>2]|0,e)|0)+f|0;c[u+160>>2]=(c[p+10204>>2]|0)+(t<<2);c[c[u+160>>2]>>2]=(c[p+10188>>2]|0)+(t*124|0);t=c[c[m+160>>2]>>2]|0;p=l;zgc(m,p+8488+((c[p+10008>>2]|0)*108|0)+16|0,e,f);c[h+1128244>>2]=-((e+o<<3)+4|0);c[h+1128236>>2]=-((f+n<<3)+4|0);c[h+1128248>>2]=((c[l+10148>>2]|0)-e<<3)+4;c[h+1128240>>2]=((c[l+10156>>2]|0)-f<<3)+4;if((f&n-1|0)!=0){w=6}else{if((e&o-1|0)!=0){w=6}else{}}if((w|0)==6){Cd(2426208,2539744,238,2651344)}w=m;m=e;p=f;u=c[l+10148>>2]|0;r=c[l+10156>>2]|0;c[w+180>>2]=-(m<<3<<3);c[w+184>>2]=u-o-m<<3<<3;c[w+172>>2]=-(p<<3<<3);c[w+176>>2]=r-n-p<<3<<3;c[w+164>>2]=(m|0)!=0;c[w+168>>2]=(p|0)>(c[b+8>>2]|0);qlc(h,c[k+1471904>>2]|0,e,f);c[h+75244>>2]=c[k+1490740>>2];c[h+75248>>2]=c[k+1490736>>2];if((a[q|0]|0)==0){a[t+13|0]=0;c[h+1129280>>2]=c[k+2047176>>2];i=j;return}if((c[k+1471728>>2]|0)!=1){if((d[q+1|0]|0)!=0){x=c[k+2047180>>2]|0}else{x=c[l+10216>>2]|0}a[t+13|0]=jgc(l,x,g,e,f)|0}H2b(k,h);c[h+1129280>>2]=c[k+2047184+(d[t+13|0]<<2)>>2];i=j;return}function Glc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=b;b=d;d=e;e=f;f=g;g=a+1434592|0;a=c[g+10160>>2]|0;m=(c[l+4>>2]|0)-d|0;n=(c[l+12>>2]|0)-e|0;l=(c[g+10188>>2]|0)+((ca(d,a)|0)*124|0)+(e*124|0)|0;c[j>>2]=c[777736+(f<<2)>>2];c[k>>2]=c[777680+(f<<2)>>2];if((m|0)>0){if((n|0)>0){}else{o=3}}else{o=3}if((o|0)==3){Cd(2414248,2539744,1330,2651360)}do{if((n|0)>=8){if((m|0)<8){break}p=0;while(1){if((p|0)>=8){break}q=0;while(1){if((q|0)>=8){break}o=(ca(p,a)|0)+q|0;c[b+(o<<2)>>2]=l+(o*124|0);c[c[b+(o<<2)>>2]>>2]=f;q=q+(c[k>>2]|0)|0}p=p+(c[j>>2]|0)|0}i=h;return}}while(0);p=0;while(1){if((p|0)>=8){break}q=0;while(1){if((q|0)>=8){break}o=(ca(p,a)|0)+q|0;f=emc(f,m-p|0,n-q|0,j,k)|0;c[b+(o<<2)>>2]=l+(o*124|0);c[c[b+(o<<2)>>2]>>2]=f;q=q+(c[k>>2]|0)|0}p=p+(c[j>>2]|0)|0}i=h;return}function Hlc(b,e,f,g,h,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0;o=i;i=i+352|0;p=o|0;q=o+48|0;r=o+96|0;s=o+104|0;t=o+112|0;u=o+120|0;v=o+128|0;w=o+136|0;x=o+144|0;y=o+152|0;z=o+160|0;A=o+168|0;B=o+176|0;C=o+184|0;D=o+192|0;E=o+200|0;F=o+208|0;H=o+216|0;I=o+224|0;J=o+232|0;K=o+240|0;L=o+288|0;M=o+336|0;N=o+344|0;O=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=O+1434592|0;P=O+32768|0;Q=P+24720|0;R=c[n+10160>>2]|0;S=c[1960336+(j<<2)>>2]|0;T=(c[777792+(j<<2)>>2]|0)/2|0;U=(1<<S|0)/4|0;V=0;c[t>>2]=2147483647;c[u>>2]=-1;c[u+4>>2]=2147483647;c[v>>2]=-1;c[v+4>>2]=2147483647;c[w>>2]=2147483647;c[x>>2]=-1;c[x+4>>2]=2147483647;c[y>>2]=-1;c[y+4>>2]=2147483647;W=2147483647;c[z>>2]=-1;c[z+4>>2]=2147483647;c[A>>2]=-1;c[A+4>>2]=2147483647;X=0;Y=0;Z=c[c[e>>2]>>2]|0;_=1;do{if((g|0)<(c[n+10148>>2]|0)){if((h|0)>=(c[n+10156>>2]|0)){break}if((c[777792+(j<<2)>>2]|0)==(c[777848+(j<<2)>>2]|0)){}else{Cd(2452472,2539744,1736,2651464)}$=734952+(S*52|0)+(Z<<2)|0;V=d[$]|d[$+1|0]<<8|d[$+2|0]<<16|d[$+3|0]<<24|0;$=c[552416+(V*52|0)+(j<<2)>>2]|0;if(!($>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}aa=$;do{if(j>>>0<3>>>0){if((d[P+1128235|0]|0)==0){break}c[k>>2]=0;$=l;c[$>>2]=0;c[$+4>>2]=0;i=o;return}else{c[(Tlc(P,j)|0)>>2]=aa}}while(0);Qlc(O,g,h,q|0,p|0,s|0,r|0,j);if((j|0)==6){Flc(O,b,g,h,j);c[P+75252>>2]=ekc(O,P,j)|0}else{c[P+1129284>>2]=Plc(O,P,g,h,j)|0}if((c[P+1129284>>2]|0)==0){_=0;do{if((g+(T>>1)|0)<(c[n+10148>>2]|0)){if((h+(T>>1)|0)>=(c[n+10156>>2]|0)){break}c[(Tlc(P,j)|0)>>2]=j;$=j;c[c[e>>2]>>2]=$;Z=$;aa=j;V=0}}while(0)}do{if((_|0)!=0){if((c[O+2046960>>2]|0)!=0){break}if((c[O+2046988>>2]|0)==0){break}do{if((V|0)==3){if(!(aa>>>0>3>>>0)){break}$=c[552416+(3*52|0)+(aa<<2)>>2]|0;if(!($>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}X=$;Y=1;ba=0;while(1){if((ba|0)>=4){break}$=c[e+((ca(ca(ba>>1,U)|0,R)|0)+(ca(ba&1,U)|0)<<2)>>2]|0;do{if(($|0)!=0){if(!((c[$>>2]|0)>>>0>=X>>>0)){break}Y=0}}while(0);ba=ba+1|0}}}while(0);do{if((V|0)!=0){if((Y|0)!=0){break}if((g+(T>>1)|0)>=(c[n+10148>>2]|0)){break}if((h+(T>>1)|0)>=(c[n+10156>>2]|0)){break}c[(Tlc(P,j)|0)>>2]=j;$=P;switch(j|0){case 8:{da=$+1386216+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 5:{da=$+1357416+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 2:{da=$+1223016+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 12:{da=$+1400616|0;break};case 9:{da=$+1395816+((d[$+1128232|0]|0)*600|0)|0;break};case 10:{da=$+1398216+((d[$+1128232|0]|0)*600|0)|0;break};case 11:{da=$+1399416+((d[$+1128232|0]|0)*600|0)|0;break};case 4:{da=$+1338216+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 6:{da=$+1376616+((d[$+1128232|0]|0)*2400|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 3:{da=$+1299816+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 7:{da=$+1391016+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 1:{da=$+1261416+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 0:{da=$+1184616+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Slc(O,b,g,h,w,x,j,da,-1,2147483647);$=Q;ea=j;fa=(c[$+50460>>2]|0)+h|0;ga=$+50464+(g&7)|0;$=c[830920+(ea<<2)>>2]|0;ha=1<<$;ia=0;ja=0;if((c[1960336+(ea<<2)>>2]|0)!=(c[1960696+(ea<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if(($|0)<0){Cd(2473496,2485024,330,2651704)}ea=0;while(1){if((ea|0)>=(ha|0)){break}ia=ia|a[fa+ea|0];ja=ja|a[ga+ea|0];ea=ea+1|0}ia=(ia&ha|0)>0|0;ja=(ja&ha|0)>0|0;ka=(ja<<1)+ia+($<<2)|0;if((c[w>>2]|0)<2147483647){c[w>>2]=(c[w>>2]|0)+(c[P+1401216+(ka<<4)>>2]|0);ea=c[w>>2]|0;ga=c[P+75248>>2]|0;fa=Erc(ea,(ea|0)<0|0?-1:0,ga,(ga|0)<0|0?-1:0)|0;ga=wrc(128,0,fa,G)|0;fa=G;ea=yrc(c[x>>2]|0,c[x+4>>2]|0,c[P+75244>>2]|0)|0;la=wrc(ga>>>8|fa<<24,fa>>8|((fa|0)<0|0?-1:0)<<24,ea,G)|0;c[y>>2]=la;c[y+4>>2]=G}Ulc(O,g,h,q|0,p|0,s|0,r|0,j);c[c[e>>2]>>2]=Z;c[(Tlc(P,j)|0)>>2]=aa}}while(0)}}while(0);la=V;a:do{if((la|0)==0){ea=P;switch(j|0){case 9:{ma=ea+1395816+((d[ea+1128232|0]|0)*600|0)|0;break};case 0:{ma=ea+1184616+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 8:{ma=ea+1386216+((d[ea+1128232|0]|0)*1200|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 7:{ma=ea+1391016+((d[ea+1128232|0]|0)*1200|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 3:{ma=ea+1299816+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 11:{ma=ea+1399416+((d[ea+1128232|0]|0)*600|0)|0;break};case 4:{ma=ea+1338216+((d[ea+1128232|0]|0)*4800|0)+((d[ea+1128233|0]|0)*1200|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 2:{ma=ea+1223016+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 5:{ma=ea+1357416+((d[ea+1128232|0]|0)*4800|0)+((d[ea+1128233|0]|0)*1200|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 6:{ma=ea+1376616+((d[ea+1128232|0]|0)*2400|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 1:{ma=ea+1261416+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 12:{ma=ea+1400616|0;break};case 10:{ma=ea+1398216+((d[ea+1128232|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Slc(O,b,g,h,t,u,j,ma,-1,2147483647)}else if((la|0)==2){ea=P;switch(aa|0){case 5:case 4:case 3:{na=ea+1128234|0;break};case 8:case 7:case 6:{na=ea+1128233|0;break};case 2:case 1:case 0:{na=ea+1128235|0;break};case 12:case 11:case 10:case 9:{na=ea+1128232|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[na]=0;ea=P;switch(aa|0){case 1:{oa=ea+1261416+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 0:{oa=ea+1184616+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 5:{oa=ea+1357416+((d[ea+1128232|0]|0)*4800|0)+((d[ea+1128233|0]|0)*1200|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 4:{oa=ea+1338216+((d[ea+1128232|0]|0)*4800|0)+((d[ea+1128233|0]|0)*1200|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 10:{oa=ea+1398216+((d[ea+1128232|0]|0)*600|0)|0;break};case 3:{oa=ea+1299816+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 2:{oa=ea+1223016+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 12:{oa=ea+1400616|0;break};case 7:{oa=ea+1391016+((d[ea+1128232|0]|0)*1200|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 6:{oa=ea+1376616+((d[ea+1128232|0]|0)*2400|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 9:{oa=ea+1395816+((d[ea+1128232|0]|0)*600|0)|0;break};case 11:{oa=ea+1399416+((d[ea+1128232|0]|0)*600|0)|0;break};case 8:{oa=ea+1386216+((d[ea+1128232|0]|0)*1200|0)+((d[ea+1128233|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Slc(O,b,g,h,t,u,aa,oa,-1,2147483647);b:do{if((c[t>>2]|0)!=2147483647){if(!(j>>>0>=3>>>0)){break}if((h+(T>>1)|0)>=(c[n+10156>>2]|0)){break}c[D>>2]=0;c[E>>2]=0;c[E+4>>2]=0;ea=P;switch(aa|0){case 12:{pa=ea+1400616|0;break};case 11:{pa=ea+1399416+((d[ea+1128232|0]|0)*600|0)|0;break};case 10:{pa=ea+1398216+((d[ea+1128232|0]|0)*600|0)|0;break};case 9:{pa=ea+1395816+((d[ea+1128232|0]|0)*600|0)|0;break};case 8:{pa=ea+1386216+((d[ea+1128232|0]|0)*1200|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 7:{pa=ea+1391016+((d[ea+1128232|0]|0)*1200|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 6:{pa=ea+1376616+((d[ea+1128232|0]|0)*2400|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 2:{pa=ea+1223016+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 1:{pa=ea+1261416+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 0:{pa=ea+1184616+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 4:{pa=ea+1338216+((d[ea+1128232|0]|0)*4800|0)+((d[ea+1128233|0]|0)*1200|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 3:{pa=ea+1299816+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 5:{pa=ea+1357416+((d[ea+1128232|0]|0)*4800|0)+((d[ea+1128233|0]|0)*1200|0)+((d[ea+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Vlc(O,pa,g,h,aa,0);Wlc(O,f,0,g,h,aa);ea=P;switch(aa|0){case 12:case 11:case 10:case 9:{qa=ea+1128232|0;break};case 8:case 7:case 6:{qa=ea+1128233|0;break};case 5:case 4:case 3:{qa=ea+1128234|0;break};case 2:case 1:case 0:{qa=ea+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[qa]=1;ea=P;switch(aa|0){case 12:{ra=ea+1400616|0;break};case 11:{ra=ea+1399416+((d[ea+1128232|0]|0)*600|0)|0;break};case 10:{ra=ea+1398216+((d[ea+1128232|0]|0)*600|0)|0;break};case 9:{ra=ea+1395816+((d[ea+1128232|0]|0)*600|0)|0;break};case 8:{ra=ea+1386216+((d[ea+1128232|0]|0)*1200|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 7:{ra=ea+1391016+((d[ea+1128232|0]|0)*1200|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 6:{ra=ea+1376616+((d[ea+1128232|0]|0)*2400|0)+((d[ea+1128233|0]|0)*600|0)|0;break};case 5:{ra=ea+1357416+((d[ea+1128232|0]|0)*4800|0)+((d[ea+1128233|0]|0)*1200|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 4:{ra=ea+1338216+((d[ea+1128232|0]|0)*4800|0)+((d[ea+1128233|0]|0)*1200|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 3:{ra=ea+1299816+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 2:{ra=ea+1223016+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 1:{ra=ea+1261416+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};case 0:{ra=ea+1184616+((d[ea+1128232|0]|0)*9600|0)+((d[ea+1128233|0]|0)*2400|0)+((d[ea+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Slc(O,b,g,h+(T>>1)|0,D,E,aa,ra,-1,2147483647);do{if((c[D>>2]|0)!=2147483647){if((c[E>>2]|0)==(-1|0)&(c[E+4>>2]|0)==2147483647){break}c[t>>2]=(c[t>>2]|0)+(c[D>>2]|0);ea=wrc(c[u>>2]|0,c[u+4>>2]|0,c[E>>2]|0,c[E+4>>2]|0)|0;c[u>>2]=ea;c[u+4>>2]=G;break b}}while(0);c[t>>2]=2147483647;c[u>>2]=-1;c[u+4>>2]=2147483647;break a}}while(0)}else if((la|0)==1){$=P;switch(aa|0){case 2:case 1:case 0:{sa=$+1128235|0;break};case 5:case 4:case 3:{sa=$+1128234|0;break};case 12:case 11:case 10:case 9:{sa=$+1128232|0;break};case 8:case 7:case 6:{sa=$+1128233|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[sa]=0;$=P;switch(aa|0){case 2:{ta=$+1223016+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 5:{ta=$+1357416+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 4:{ta=$+1338216+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 12:{ta=$+1400616|0;break};case 8:{ta=$+1386216+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 11:{ta=$+1399416+((d[$+1128232|0]|0)*600|0)|0;break};case 3:{ta=$+1299816+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 1:{ta=$+1261416+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 9:{ta=$+1395816+((d[$+1128232|0]|0)*600|0)|0;break};case 0:{ta=$+1184616+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 10:{ta=$+1398216+((d[$+1128232|0]|0)*600|0)|0;break};case 6:{ta=$+1376616+((d[$+1128232|0]|0)*2400|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 7:{ta=$+1391016+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Slc(O,b,g,h,t,u,aa,ta,-1,2147483647);c:do{if((c[t>>2]|0)!=2147483647){if(!(j>>>0>=3>>>0)){break}if((g+(T>>1)|0)>=(c[n+10148>>2]|0)){break}c[B>>2]=0;c[C>>2]=0;c[C+4>>2]=0;$=P;switch(aa|0){case 6:{ua=$+1376616+((d[$+1128232|0]|0)*2400|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 9:{ua=$+1395816+((d[$+1128232|0]|0)*600|0)|0;break};case 2:{ua=$+1223016+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 4:{ua=$+1338216+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 3:{ua=$+1299816+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 12:{ua=$+1400616|0;break};case 8:{ua=$+1386216+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 10:{ua=$+1398216+((d[$+1128232|0]|0)*600|0)|0;break};case 7:{ua=$+1391016+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 5:{ua=$+1357416+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 0:{ua=$+1184616+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 1:{ua=$+1261416+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 11:{ua=$+1399416+((d[$+1128232|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Vlc(O,ua,g,h,aa,0);Wlc(O,f,0,g,h,aa);$=P;switch(aa|0){case 12:case 11:case 10:case 9:{va=$+1128232|0;break};case 2:case 1:case 0:{va=$+1128235|0;break};case 8:case 7:case 6:{va=$+1128233|0;break};case 5:case 4:case 3:{va=$+1128234|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[va]=1;$=P;switch(aa|0){case 11:{wa=$+1399416+((d[$+1128232|0]|0)*600|0)|0;break};case 3:{wa=$+1299816+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 0:{wa=$+1184616+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 6:{wa=$+1376616+((d[$+1128232|0]|0)*2400|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 8:{wa=$+1386216+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 12:{wa=$+1400616|0;break};case 4:{wa=$+1338216+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 5:{wa=$+1357416+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 10:{wa=$+1398216+((d[$+1128232|0]|0)*600|0)|0;break};case 1:{wa=$+1261416+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 2:{wa=$+1223016+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 9:{wa=$+1395816+((d[$+1128232|0]|0)*600|0)|0;break};case 7:{wa=$+1391016+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Slc(O,b,g+(T>>1)|0,h,B,C,aa,wa,-1,2147483647);do{if((c[B>>2]|0)!=2147483647){if((c[C>>2]|0)==(-1|0)&(c[C+4>>2]|0)==2147483647){break}c[t>>2]=(c[t>>2]|0)+(c[B>>2]|0);$=wrc(c[u>>2]|0,c[u+4>>2]|0,c[C>>2]|0,c[C+4>>2]|0)|0;c[u>>2]=$;c[u+4>>2]=G;break c}}while(0);c[t>>2]=2147483647;c[u>>2]=-1;c[u+4>>2]=2147483647;break a}}while(0)}else if((la|0)==3){c[t>>2]=0;c[u>>2]=0;c[u+4>>2]=0;ba=0;d:while(1){if((ba|0)>=4){break}$=ca(ba&1,T>>1)|0;ia=ca(ba>>1,T>>1)|0;ja=ba>>1;ha=ba&1;do{if((g+ia|0)>=(c[n+10148>>2]|0)){xa=217}else{if((h+$|0)>=(c[n+10156>>2]|0)){xa=217;break}ea=P;switch(aa|0){case 12:case 11:case 10:case 9:{ya=ea+1128232|0;break};case 8:case 7:case 6:{ya=ea+1128233|0;break};case 5:case 4:case 3:{ya=ea+1128234|0;break};case 2:case 1:case 0:{ya=ea+1128235|0;break};default:{xa=223;break d}}a[ya]=ba;Hlc(O,b,e+((ca(ca(ja,U)|0,R)|0)<<2)+((ca(ha,U)|0)<<2)|0,f,g+ia|0,h+$|0,aa,F,H,(ba|0)!=3|0);if((c[F>>2]|0)==2147483647){xa=226;break d}if((c[H>>2]|0)==(-1|0)&(c[H+4>>2]|0)==2147483647){xa=226;break d}c[t>>2]=(c[t>>2]|0)+(c[F>>2]|0);ea=wrc(c[u>>2]|0,c[u+4>>2]|0,c[H>>2]|0,c[H+4>>2]|0)|0;c[u>>2]=ea;c[u+4>>2]=G}}while(0);if((xa|0)==217){xa=0}ba=ba+1|0}if((xa|0)==223){Cd(2524984,2539744,71,2652264)}else if((xa|0)==226){c[t>>2]=2147483647;c[u>>2]=-1;c[u+4>>2]=2147483647}}else{Cd(2524984,2539744,1893,2651464)}}while(0);la=Q;$=j;ia=(c[la+50460>>2]|0)+h|0;ha=la+50464+(g&7)|0;la=c[830920+($<<2)>>2]|0;ja=1<<la;ea=0;fa=0;if((c[1960336+($<<2)>>2]|0)!=(c[1960696+($<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((la|0)<0){Cd(2473496,2485024,330,2651704)}$=0;while(1){if(($|0)>=(ja|0)){break}ea=ea|a[ia+$|0];fa=fa|a[ha+$|0];$=$+1|0}ea=(ea&ja|0)>0|0;fa=(fa&ja|0)>0|0;ka=(fa<<1)+ea+(la<<2)|0;if((c[t>>2]|0)<2147483647){c[t>>2]=(c[t>>2]|0)+(c[P+1401216+(ka<<4)+(V<<2)>>2]|0);$=c[t>>2]|0;ha=c[P+75248>>2]|0;ia=Erc($,($|0)<0|0?-1:0,ha,(ha|0)<0|0?-1:0)|0;ha=wrc(128,0,ia,G)|0;ia=G;$=yrc(c[u>>2]|0,c[u+4>>2]|0,c[P+75244>>2]|0)|0;ga=wrc(ha>>>8|ia<<24,ia>>8|((ia|0)<0|0?-1:0)<<24,$,G)|0;c[v>>2]=ga;c[v+4>>2]=G}do{if((_|0)!=0){if((c[O+2046988>>2]|0)==0){break}if((c[O+2046960>>2]|0)!=0){break}if((V|0)==3){break}if(!(j>>>0>3>>>0)){break}if((g+T|0)>=(c[n+10148>>2]|0)){if((g+(T>>1)|0)!=(c[n+10148>>2]|0)){break}}if((h+T|0)>=(c[n+10156>>2]|0)){if((h+(T>>1)|0)!=(c[n+10156>>2]|0)){break}}ga=c[552416+(3*52|0)+(j<<2)>>2]|0;if(!(ga>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}$=ga;W=0;c[z>>2]=0;c[z+4>>2]=0;Ulc(O,g,h,q|0,p|0,s|0,r|0,j);ba=0;e:while(1){if((ba|0)>=4){break}ga=ca(ba&1,T>>1)|0;ia=ca(ba>>1,T>>1)|0;c[I>>2]=0;c[J>>2]=0;c[J+4>>2]=0;do{if((g+ia|0)>=(c[n+10148>>2]|0)){xa=255}else{if((h+ga|0)>=(c[n+10156>>2]|0)){xa=255;break}ha=P;switch($|0){case 12:case 11:case 10:case 9:{za=ha+1128232|0;break};case 8:case 7:case 6:{za=ha+1128233|0;break};case 5:case 4:case 3:{za=ha+1128234|0;break};case 2:case 1:case 0:{za=ha+1128235|0;break};default:{xa=261;break e}}a[za]=ba;c[(Tlc(P,j)|0)>>2]=$;c[(Tlc(P,$)|0)>>2]=$;Qlc(O,g,h,L|0,K|0,N|0,M|0,j);ha=P;switch($|0){case 1:{Aa=ha+1261416+((d[ha+1128232|0]|0)*9600|0)+((d[ha+1128233|0]|0)*2400|0)+((d[ha+1128234|0]|0)*600|0)|0;break};case 0:{Aa=ha+1184616+((d[ha+1128232|0]|0)*9600|0)+((d[ha+1128233|0]|0)*2400|0)+((d[ha+1128234|0]|0)*600|0)|0;break};case 12:{Aa=ha+1400616|0;break};case 11:{Aa=ha+1399416+((d[ha+1128232|0]|0)*600|0)|0;break};case 10:{Aa=ha+1398216+((d[ha+1128232|0]|0)*600|0)|0;break};case 9:{Aa=ha+1395816+((d[ha+1128232|0]|0)*600|0)|0;break};case 8:{Aa=ha+1386216+((d[ha+1128232|0]|0)*1200|0)+((d[ha+1128233|0]|0)*600|0)|0;break};case 7:{Aa=ha+1391016+((d[ha+1128232|0]|0)*1200|0)+((d[ha+1128233|0]|0)*600|0)|0;break};case 6:{Aa=ha+1376616+((d[ha+1128232|0]|0)*2400|0)+((d[ha+1128233|0]|0)*600|0)|0;break};case 5:{Aa=ha+1357416+((d[ha+1128232|0]|0)*4800|0)+((d[ha+1128233|0]|0)*1200|0)+((d[ha+1128234|0]|0)*600|0)|0;break};case 4:{Aa=ha+1338216+((d[ha+1128232|0]|0)*4800|0)+((d[ha+1128233|0]|0)*1200|0)+((d[ha+1128234|0]|0)*600|0)|0;break};case 3:{Aa=ha+1299816+((d[ha+1128232|0]|0)*9600|0)+((d[ha+1128233|0]|0)*2400|0)+((d[ha+1128234|0]|0)*600|0)|0;break};case 2:{Aa=ha+1223016+((d[ha+1128232|0]|0)*9600|0)+((d[ha+1128233|0]|0)*2400|0)+((d[ha+1128234|0]|0)*600|0)|0;break};default:{xa=276;break e}}Slc(O,b,g+ia|0,h+ga|0,I,J,$,Aa,-1,2147483647);Ulc(O,g,h,L|0,K|0,N|0,M|0,j);if((c[I>>2]|0)==2147483647){xa=279;break e}if((c[J>>2]|0)==(-1|0)&(c[J+4>>2]|0)==2147483647){xa=279;break e}W=W+(c[I>>2]|0)|0;ha=wrc(c[z>>2]|0,c[z+4>>2]|0,c[J>>2]|0,c[J+4>>2]|0)|0;c[z>>2]=ha;c[z+4>>2]=G;if((ba|0)!=3){Xlc(O,b,f,g+ia|0,h+ga|0,0,$)}ha=Q;Ba=$;Ca=(c[ha+50460>>2]|0)+(h+ga)|0;Da=ha+50464+(g+ia&7)|0;ha=c[830920+(Ba<<2)>>2]|0;Ea=1<<ha;Fa=0;Ga=0;if((c[1960336+(Ba<<2)>>2]|0)!=(c[1960696+(Ba<<2)>>2]|0)){xa=283;break e}if((ha|0)<0){xa=285;break e}Ba=0;while(1){if((Ba|0)>=(Ea|0)){break}Fa=Fa|a[Ca+Ba|0];Ga=Ga|a[Da+Ba|0];Ba=Ba+1|0}Fa=(Fa&Ea|0)>0|0;Ga=(Ga&Ea|0)>0|0;ka=(Ga<<1)+Fa+(ha<<2)|0;W=W+(c[P+1401216+(ka<<4)>>2]|0)|0}}while(0);if((xa|0)==255){xa=0}ba=ba+1|0}if((xa|0)==261){Cd(2524984,2539744,71,2652264)}else if((xa|0)==276){Cd(2524984,2415424,229,2652560)}else if((xa|0)==279){W=2147483647;c[z>>2]=-1;c[z+4>>2]=2147483647}else if((xa|0)==283){Cd(2495744,2485024,329,2651704)}else if((xa|0)==285){Cd(2473496,2485024,330,2651704)}$=Q;ia=j;ga=(c[$+50460>>2]|0)+h|0;Ba=$+50464+(g&7)|0;$=c[830920+(ia<<2)>>2]|0;Da=1<<$;Ca=0;Ha=0;if((c[1960336+(ia<<2)>>2]|0)!=(c[1960696+(ia<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if(($|0)<0){Cd(2473496,2485024,330,2651704)}ia=0;while(1){if((ia|0)>=(Da|0)){break}Ca=Ca|a[ga+ia|0];Ha=Ha|a[Ba+ia|0];ia=ia+1|0}Ca=(Ca&Da|0)>0|0;Ha=(Ha&Da|0)>0|0;ka=(Ha<<1)+Ca+($<<2)|0;if((W|0)<2147483647){W=W+(c[P+1401216+(ka<<4)+12>>2]|0)|0;ia=W;Ba=c[P+75248>>2]|0;ga=Erc(ia,(ia|0)<0|0?-1:0,Ba,(Ba|0)<0|0?-1:0)|0;Ba=wrc(128,0,ga,G)|0;ga=G;ia=yrc(c[z>>2]|0,c[z+4>>2]|0,c[P+75244>>2]|0)|0;Ia=wrc(Ba>>>8|ga<<24,ga>>8|((ga|0)<0|0?-1:0)<<24,ia,G)|0;c[A>>2]=Ia;c[A+4>>2]=G}}}while(0);la=c[v+4>>2]|0;ea=c[A+4>>2]|0;if((la|0)<(ea|0)|(la|0)==(ea|0)&(c[v>>2]|0)>>>0<(c[A>>2]|0)>>>0){c[c[e>>2]>>2]=j;if(j>>>0>=3>>>0){c[(Tlc(P,j)|0)>>2]=aa}W=c[t>>2]|0;ea=c[u+4>>2]|0;c[z>>2]=c[u>>2];c[z+4>>2]=ea;ea=c[v+4>>2]|0;c[A>>2]=c[v>>2];c[A+4>>2]=ea}ea=c[y+4>>2]|0;la=c[A+4>>2]|0;if((ea|0)<(la|0)|(ea|0)==(la|0)&(c[y>>2]|0)>>>0<(c[A>>2]|0)>>>0){if(j>>>0>=3>>>0){c[(Tlc(P,j)|0)>>2]=j}W=c[w>>2]|0;la=c[x+4>>2]|0;c[z>>2]=c[x>>2];c[z+4>>2]=la}Ulc(O,g,h,q|0,p|0,s|0,r|0,j);if((j|0)==12){if((W|0)<2147483647){la=c[z+4>>2]|0;ea=2147483647;if((la|0)<(ea|0)|(la|0)==(ea|0)&(c[z>>2]|0)>>>0<-1>>>0){}else{xa=312}}else{xa=312}if((xa|0)==312){Cd(2436144,2539744,1985,2651464)}}if((m|0)!=0){ea=(j|0)==12|0;do{if((c[O+1471728>>2]|0)==2){if((d[n+13409|0]|0)==0){break}Sjc(O,g,h,ea,W)}}while(0);if((c[O+1471728>>2]|0)==3){aa=W;Zjc(c[O+2047228>>2]|0,aa,(aa|0)<0|0?-1:0,c[z>>2]|0,c[z+4>>2]|0)}Xlc(O,b,f,g,h,ea,j)}c[k>>2]=W;aa=c[z+4>>2]|0;la=l;c[la>>2]=c[z>>2];c[la+4>>2]=aa;i=o;return}}while(0);i=o;return}function Ilc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=i;e=a;a=kmc(e,e+40972|0,b,c,12)|0;do{if(a>>>0<8>>>0){f=12}else{if(a>>>0<128>>>0){f=9;break}if(a>>>0<2048>>>0){f=6;break}else{f=3;break}}}while(0);i=d;return f|0}function Jlc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+16376|0;g=f|0;h=f+16344|0;j=f+16352|0;k=f+16360|0;l=f+16368|0;m=a;a=b;b=d;d=e;e=m+1434592|0;n=m+32768|0;o=m+57488|0;p=64;q=64;r=m;s=r+1434592|0;t=r;r=1;do{if((r|0)==1){u=c[t+1472132>>2]|0}else{if((r|0)==2){u=c[t+1472136>>2]|0;break}else{u=c[t+1472140>>2]|0;break}}}while(0);t=s+8488+((c[s+9784+(u<<2)>>2]|0)*108|0)+16|0;mrc(g|0,0,16344)|0;Flc(m,a,b,d,12);if((c[o+176>>2]|0)<0){p=p+(c[o+176>>2]>>3)|0}if((c[o+184>>2]|0)<0){q=q+(c[o+184>>2]>>3)|0}u=c[n+8204>>2]|0;s=c[n+8208>>2]|0;if((c[e+10108>>2]|0)!=0){Agc(o,0,t,b,d,e+9824|0);c[(c[c[o+160>>2]>>2]|0)+20>>2]=1;c[c[c[o+160>>2]>>2]>>2]=12;_fc(o,c[e+10128>>2]|0,(c[c[o+160>>2]>>2]|0)+44|0,h,j);c[(c[c[o+160>>2]>>2]|0)+28>>2]=c[h>>2];tgc(o,b,d,12);v=c[o+16>>2]|0;w=c[o+20>>2]|0}else{v=2653864;w=0}o=0;while(1){if((o|0)>=4){break}h=(o&1)<<5;j=o>>1<<5;x=0;while(1){if((x|0)>=4){break}t=h+((x&1)<<4)|0;n=j+(x>>1<<4)|0;r=g+120+(o*4056|0)+120+(x*984|0)|0;y=0;while(1){if((y|0)>=4){break}z=t+((y&1)<<3)|0;A=n+(y>>1<<3)|0;c[k>>2]=0;c[l>>2]=0;do{if((z|0)<(p|0)){if((A|0)>=(q|0)){break}T6b(u+(ca(A,s)|0)+z|0,s,v+(ca(A,w)|0)+z|0,w,k,l)}}while(0);z=c[l>>2]|0;plc(c[k>>2]|0,0,z,(z|0)<0|0?-1:0,64,r+120+(y*216|0)|0);y=y+1|0}x=x+1|0}o=o+1|0}o=0;while(1){if((o|0)>=4){break}x=0;while(1){if((x|0)>=4){break}fmc(g+120+(o*4056|0)+120+(x*984|0)|0,6);x=x+1|0}fmc(g+120+(o*4056|0)|0,9);o=o+1|0}fmc(g,12);if((gmc(m,g,a,12,b,d,8)|0)!=0){i=f;return}o=0;while(1){if((o|0)>=4){break}k=(o&1)<<2;l=o>>1<<2;if((gmc(m,g+120+(o*4056|0)|0,a,9,b+l|0,d+k|0,4)|0)==0){x=0;while(1){if((x|0)>=4){break}w=(x&1)<<1;v=x>>1<<1;do{if((b+l+v+1|0)<(c[e+10148>>2]|0)){if((b+k+w+1|0)>=(c[e+10156>>2]|0)){B=45;break}hmc(m,a,b+l+v|0,d+k+w|0,6)}else{B=45}}while(0);if((B|0)==45){B=0;y=0;while(1){if((y|0)>=4){break}hmc(m,a,b+l+v+(y>>1)|0,d+k+w+(y&1)|0,3);y=y+1|0}}x=x+1|0}}o=o+1|0}i=f;return}function Klc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=a;a=d;d=c[f+10160>>2]|0;do{if((c[f+10196>>2]|0)!=0){g=0;a:while(1){if((g|0)>=8){h=15;break}j=0;while(1){if((j|0)>=8){break}k=c[a+((ca(g,d)|0)+j<<2)>>2]|0;if((k|0)!=0){if((R(b[k+28>>1]|0)|0)>=8){break a}if((R(b[k+30>>1]|0)|0)>=8){break a}}j=j+1|0}g=g+1|0}if((h|0)==15){break}l=1;m=l;i=e;return m|0}}while(0);l=0;m=l;i=e;return m|0}function Llc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=i;i=i+32|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=a;a=b;b=d;d=e;e=f;f=g;g=n+1434592|0;o=n+57488|0;p=c[o+160>>2]|0;if((c[o+168>>2]|0)!=0){q=(c[p-4>>2]|0)!=0}else{q=0}r=q&1;if((c[o+164>>2]|0)!=0){s=(c[p+(-(c[o+156>>2]|0)<<2)>>2]|0)!=0}else{s=0}q=s&1;s=(c[a+4>>2]|0)-b|0;t=(c[a+12>>2]|0)-d|0;c[l>>2]=0;c[m>>2]=12;do{if((r|0)!=0){u=8}else{if((q|0)!=0){u=8;break}if((c[g+10108>>2]|0)!=0){u=8}}}while(0);if((u|0)==8){c[l>>2]=12;c[m>>2]=0;if((c[g+10108>>2]|0)!=0){u=(ca(b,c[o+156>>2]|0)|0)+d|0;dmc(n,(c[g+10212>>2]|0)+(u<<2)|0,l,m)}if((r|0)!=0){dmc(n,p-32|0,l,m)}if((q|0)!=0){dmc(n,p+(-(c[o+156>>2]|0)<<3<<2)|0,l,m)}if((c[n+2046976>>2]|0)==1){c[l>>2]=c[830864+(c[l>>2]<<2)>>2];c[m>>2]=c[833096+(c[m>>2]<<2)>>2]}}c[m>>2]=emc(c[m>>2]|0,s,t,j,k)|0;if((c[l>>2]|0)>>>0<(c[m>>2]|0)>>>0){v=c[l>>2]|0}else{v=c[m>>2]|0}c[l>>2]=v;if((c[n+2046972>>2]|0)==0){w=c[l>>2]|0;x=e;c[x>>2]=w;y=c[m>>2]|0;z=f;c[z>>2]=y;i=h;return}if(!((c[785272+(c[m>>2]<<2)>>2]|0)>>>0<(c[l>>2]|0)>>>0)){w=c[l>>2]|0;x=e;c[x>>2]=w;y=c[m>>2]|0;z=f;c[z>>2]=y;i=h;return}c[l>>2]=c[785272+(c[m>>2]<<2)>>2];w=c[l>>2]|0;x=e;c[x>>2]=w;y=c[m>>2]|0;z=f;c[z>>2]=y;i=h;return}function Mlc(b,e,f,g,h,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;p=i;i=i+184|0;q=p|0;r=p+8|0;s=p+56|0;t=p+104|0;u=p+112|0;v=p+120|0;w=p+128|0;x=p+136|0;y=p+144|0;z=p+152|0;A=p+160|0;B=p+168|0;C=p+176|0;D=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;c[q>>2]=n;c[q+4>>2]=o;o=D+1434592|0;n=D+32768|0;m=n+24720|0;E=(c[777680+(h<<2)>>2]|0)/2|0;F=c[e>>2]|0;H=n;switch(h|0){case 2:{I=H+1223016+((d[H+1128232|0]|0)*9600|0)+((d[H+1128233|0]|0)*2400|0)+((d[H+1128234|0]|0)*600|0)|0;break};case 5:{I=H+1357416+((d[H+1128232|0]|0)*4800|0)+((d[H+1128233|0]|0)*1200|0)+((d[H+1128234|0]|0)*600|0)|0;break};case 10:{I=H+1398216+((d[H+1128232|0]|0)*600|0)|0;break};case 0:{I=H+1184616+((d[H+1128232|0]|0)*9600|0)+((d[H+1128233|0]|0)*2400|0)+((d[H+1128234|0]|0)*600|0)|0;break};case 1:{I=H+1261416+((d[H+1128232|0]|0)*9600|0)+((d[H+1128233|0]|0)*2400|0)+((d[H+1128234|0]|0)*600|0)|0;break};case 12:{I=H+1400616|0;break};case 4:{I=H+1338216+((d[H+1128232|0]|0)*4800|0)+((d[H+1128233|0]|0)*1200|0)+((d[H+1128234|0]|0)*600|0)|0;break};case 8:{I=H+1386216+((d[H+1128232|0]|0)*1200|0)+((d[H+1128233|0]|0)*600|0)|0;break};case 9:{I=H+1395816+((d[H+1128232|0]|0)*600|0)|0;break};case 6:{I=H+1376616+((d[H+1128232|0]|0)*2400|0)+((d[H+1128233|0]|0)*600|0)|0;break};case 3:{I=H+1299816+((d[H+1128232|0]|0)*9600|0)+((d[H+1128233|0]|0)*2400|0)+((d[H+1128234|0]|0)*600|0)|0;break};case 11:{I=H+1399416+((d[H+1128232|0]|0)*600|0)|0;break};case 7:{I=H+1391016+((d[H+1128232|0]|0)*1200|0)+((d[H+1128233|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}H=I;c[w>>2]=0;I=2147483647;c[y>>2]=0;c[y+4>>2]=0;c[z>>2]=-1;c[z+4>>2]=2147483647;c[A>>2]=0;c[A+4>>2]=0;J=h>>>0>=3>>>0|0;K=1;L=(f+E|0)>=(c[o+10148>>2]|0)|0;M=(g+E|0)>=(c[o+10156>>2]|0)|0;N=c[n+24780>>2]|0;O=c[n+24784>>2]|0;if((L|0)!=0){P=0}else{P=(M|0)!=0^1}Q=P&1;do{if((M|0)!=0){R=0}else{if((O|0)>(N|0)){R=0;break}R=h>>>0>=3>>>0}}while(0);P=R&1;do{if((L|0)!=0){S=0}else{if((N|0)>(O|0)){S=0;break}S=h>>>0>=3>>>0}}while(0);O=S&1;do{if(h>>>0<3>>>0){if((d[n+1128235|0]|0)==0){break}c[j>>2]=0;S=k;c[S>>2]=0;c[S+4>>2]=0;i=p;return}}while(0);if((c[777680+(h<<2)>>2]|0)==(c[777736+(h<<2)>>2]|0)){}else{Cd(2336248,2539744,2185,2651488)}if((h|0)==6){Flc(D,b,f,g,h);c[n+75252>>2]=ekc(D,n,h)|0}else{c[n+1129284>>2]=Plc(D,n,f,g,h)|0}if((c[D+2046976>>2]|0)!=0){if(h>>>0<=(c[D+2046984>>2]|0)>>>0){T=h>>>0>=(c[D+2046980>>2]|0)>>>0}else{T=0}Q=Q&(T&1);if(h>>>0<=(c[D+2046984>>2]|0)>>>0){if(h>>>0>(c[D+2046980>>2]|0)>>>0){U=1}else{V=38}}else{V=38}if((V|0)==38){U=(L|0)!=0}P=P&(U&1);if(h>>>0<=(c[D+2046984>>2]|0)>>>0){if(h>>>0>(c[D+2046980>>2]|0)>>>0){W=1}else{V=41}}else{V=41}if((V|0)==41){W=(M|0)!=0}O=O&(W&1);J=J&h>>>0>(c[D+2046980>>2]|0)>>>0}if((c[D+2046972>>2]|0)!=0){P=P&L;O=O&M}Qlc(D,f,g,s|0,r|0,u|0,t|0,h);do{if((c[D+2047028>>2]|0)!=0){if((Q|0)==0){break}qlc(n,c[D+1471904>>2]|0,f,g);M=Rlc(D,n+8204|0,h)|0;if(M>>>0<(c[D+2047028>>2]|0)>>>0){J=0;if(M>>>0<(((c[D+2047028>>2]|0)>>>0)/2|0)>>>0){K=0}}}}while(0);do{if((c[n+1129284>>2]|0)==0){if((P|0)==0){if((O|0)==0){break}}J=0}}while(0);if((Q|0)!=0){Slc(D,b,f,g,v,x,h,H,c[q>>2]|0,c[q+4>>2]|0);if((c[v>>2]|0)!=2147483647){if(h>>>0>=3>>>0){M=m;L=h;W=(c[M+50460>>2]|0)+g|0;U=M+50464+(f&7)|0;M=c[830920+(L<<2)>>2]|0;T=1<<M;S=0;N=0;if((c[1960336+(L<<2)>>2]|0)!=(c[1960696+(L<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((M|0)<0){Cd(2473496,2485024,330,2651704)}L=0;while(1){if((L|0)>=(T|0)){break}S=S|a[W+L|0];N=N|a[U+L|0];L=L+1|0}S=(S&T|0)>0|0;N=(N&T|0)>0|0;X=(N<<1)+S+(M<<2)|0;c[v>>2]=(c[v>>2]|0)+(c[n+1401216+(X<<4)>>2]|0)}M=c[v>>2]|0;S=c[n+75248>>2]|0;N=Erc(M,(M|0)<0|0?-1:0,S,(S|0)<0|0?-1:0)|0;S=wrc(128,0,N,G)|0;N=G;M=yrc(c[x>>2]|0,c[x+4>>2]|0,c[n+75244>>2]|0)|0;T=wrc(S>>>8|N<<24,N>>8|((N|0)<0|0?-1:0)<<24,M,G)|0;c[A>>2]=T;c[A+4>>2]=G;T=c[A+4>>2]|0;M=c[q+4>>2]|0;if((T|0)<(M|0)|(T|0)==(M|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){c[B>>2]=4096;c[B+4>>2]=0;I=c[v>>2]|0;M=c[x+4>>2]|0;c[z>>2]=c[x>>2];c[z+4>>2]=M;M=c[A+4>>2]|0;c[q>>2]=c[A>>2];c[q+4>>2]=M;if(h>>>0>=3>>>0){c[(Tlc(n,h)|0)>>2]=h}M=Arc(c[B>>2]|0,c[B+4>>2]|0,8-((c[1960336+(h<<2)>>2]|0)+(c[1960696+(h<<2)>>2]|0))|0)|0;c[B>>2]=M;c[B+4>>2]=G;M=c[n+75248>>2]|0;T=Erc(0,0,M,(M|0)<0|0?-1:0)|0;M=wrc(128,0,T,G)|0;T=G;N=yrc(c[B>>2]|0,c[B+4>>2]|0,c[n+75244>>2]|0)|0;B=wrc(M>>>8|T<<24,T>>8|((T|0)<0|0?-1:0)<<24,N,G)|0;c[C>>2]=B;c[C+4>>2]=G;do{if((c[n+50528>>2]|0)==0){B=c[q+4>>2]|0;N=c[C+4>>2]|0;if(!((B|0)<(N|0)|(B|0)==(N|0)&(c[q>>2]|0)>>>0<(c[C>>2]|0)>>>0)){break}J=0;K=0}}while(0)}}if((c[n+1129284>>2]|0)==0){J=0;K=0}Ulc(D,f,g,s|0,r|0,u|0,t|0,h)}if((c[D+2047004>>2]|0)!=0){C=H+576|0;N=n+1184596|0;c[C>>2]=c[N>>2];c[C+4>>2]=c[N+4>>2];c[C+8>>2]=c[N+8>>2];c[C+12>>2]=c[N+12>>2]}c[A>>2]=0;c[A+4>>2]=0;do{if((J|0)!=0){N=c[552416+(3*52|0)+(h<<2)>>2]|0;if(!(N>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}Y=N;N=0;a:while(1){if((N|0)<4){C=c[A+4>>2]|0;B=c[q+4>>2]|0;Z=(C|0)<(B|0)|(C|0)==(B|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0}else{Z=0}if(!Z){V=122;break}B=ca(N&1,E)|0;C=ca(N>>1,E)|0;do{if((f+C|0)>=(c[o+10148>>2]|0)){V=89}else{if((g+B|0)>=(c[o+10156>>2]|0)){V=89;break}T=n;switch(Y|0){case 12:case 11:case 10:case 9:{_=T+1128232|0;break};case 5:case 4:case 3:{_=T+1128234|0;break};case 2:case 1:case 0:{_=T+1128235|0;break};case 8:case 7:case 6:{_=T+1128233|0;break};default:{V=95;break a}}a[_]=N;if((c[D+2047004>>2]|0)!=0){T=n+1184596|0;M=H+576|0;c[T>>2]=c[M>>2];c[T+4>>2]=c[M+4>>2];c[T+8>>2]=c[M+8>>2];c[T+12>>2]=c[M+12>>2]}do{if((c[D+2047008>>2]|0)!=0){if((h|0)!=3){break}if((Q|0)==0){break}M=n;switch(Y|0){case 2:{$=M+1223016+((d[M+1128232|0]|0)*9600|0)+((d[M+1128233|0]|0)*2400|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 10:{$=M+1398216+((d[M+1128232|0]|0)*600|0)|0;break};case 4:{$=M+1338216+((d[M+1128232|0]|0)*4800|0)+((d[M+1128233|0]|0)*1200|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 9:{$=M+1395816+((d[M+1128232|0]|0)*600|0)|0;break};case 5:{$=M+1357416+((d[M+1128232|0]|0)*4800|0)+((d[M+1128233|0]|0)*1200|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 8:{$=M+1386216+((d[M+1128232|0]|0)*1200|0)+((d[M+1128233|0]|0)*600|0)|0;break};case 7:{$=M+1391016+((d[M+1128232|0]|0)*1200|0)+((d[M+1128233|0]|0)*600|0)|0;break};case 0:{$=M+1184616+((d[M+1128232|0]|0)*9600|0)+((d[M+1128233|0]|0)*2400|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 3:{$=M+1299816+((d[M+1128232|0]|0)*9600|0)+((d[M+1128233|0]|0)*2400|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 6:{$=M+1376616+((d[M+1128232|0]|0)*2400|0)+((d[M+1128233|0]|0)*600|0)|0;break};case 11:{$=M+1399416+((d[M+1128232|0]|0)*600|0)|0;break};case 12:{$=M+1400616|0;break};case 1:{$=M+1261416+((d[M+1128232|0]|0)*9600|0)+((d[M+1128233|0]|0)*2400|0)+((d[M+1128234|0]|0)*600|0)|0;break};default:{V=115;break a}}c[$+592>>2]=c[H+72>>2]}}while(0);M=xrc(c[q>>2]|0,c[q+4>>2]|0,c[A>>2]|0,c[A+4>>2]|0)|0;Mlc(D,b,e,f+C|0,g+B|0,Y,v,x,(N|0)!=3|0,M,G);if((c[v>>2]|0)==2147483647){c[A>>2]=-1;c[A+4>>2]=2147483647}else{c[w>>2]=(c[w>>2]|0)+(c[v>>2]|0);M=wrc(c[y>>2]|0,c[y+4>>2]|0,c[x>>2]|0,c[x+4>>2]|0)|0;c[y>>2]=M;c[y+4>>2]=G;M=c[w>>2]|0;T=c[n+75248>>2]|0;S=Erc(M,(M|0)<0|0?-1:0,T,(T|0)<0|0?-1:0)|0;T=wrc(128,0,S,G)|0;S=G;M=yrc(c[y>>2]|0,c[y+4>>2]|0,c[n+75244>>2]|0)|0;L=wrc(T>>>8|S<<24,S>>8|((S|0)<0|0?-1:0)<<24,M,G)|0;c[A>>2]=L;c[A+4>>2]=G}}}while(0);if((V|0)==89){V=0}N=N+1|0}if((V|0)==95){Cd(2524984,2539744,71,2652264)}else if((V|0)==115){Cd(2524984,2415424,229,2652560)}else if((V|0)==122){B=c[A+4>>2]|0;C=c[q+4>>2]|0;do{if((B|0)<(C|0)|(B|0)==(C|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){if((N|0)!=4){V=134;break}L=m;M=h;S=(c[L+50460>>2]|0)+g|0;T=L+50464+(f&7)|0;L=c[830920+(M<<2)>>2]|0;U=1<<L;W=0;R=0;if((c[1960336+(M<<2)>>2]|0)!=(c[1960696+(M<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((L|0)<0){Cd(2473496,2485024,330,2651704)}M=0;while(1){if((M|0)>=(U|0)){break}W=W|a[S+M|0];R=R|a[T+M|0];M=M+1|0}W=(W&U|0)>0|0;R=(R&U|0)>0|0;X=(R<<1)+W+(L<<2)|0;c[w>>2]=(c[w>>2]|0)+(c[n+1401216+(X<<4)+12>>2]|0);M=c[w>>2]|0;T=c[n+75248>>2]|0;S=Erc(M,(M|0)<0|0?-1:0,T,(T|0)<0|0?-1:0)|0;T=wrc(128,0,S,G)|0;S=G;M=yrc(c[y>>2]|0,c[y+4>>2]|0,c[n+75244>>2]|0)|0;aa=wrc(T>>>8|S<<24,S>>8|((S|0)<0|0?-1:0)<<24,M,G)|0;c[A>>2]=aa;c[A+4>>2]=G;aa=c[A+4>>2]|0;M=c[q+4>>2]|0;if((aa|0)<(M|0)|(aa|0)==(M|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){I=c[w>>2]|0;M=c[y+4>>2]|0;c[z>>2]=c[y>>2];c[z+4>>2]=M;M=c[A+4>>2]|0;c[q>>2]=c[A>>2];c[q+4>>2]=M;c[(Tlc(n,h)|0)>>2]=Y}}else{V=134}}while(0);if((V|0)==134){if((c[D+2046968>>2]|0)!=0){K=K&(((Q|0)!=0^1)&1)}}Ulc(D,f,g,s|0,r|0,u|0,t|0,h);break}}}while(0);do{if((P|0)!=0){if((K|0)==0){break}V=c[552416+(1*52|0)+(h<<2)>>2]|0;if(!(V>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}Y=V;V=n;switch(Y|0){case 12:case 11:case 10:case 9:{ba=V+1128232|0;break};case 2:case 1:case 0:{ba=V+1128235|0;break};case 8:case 7:case 6:{ba=V+1128233|0;break};case 5:case 4:case 3:{ba=V+1128234|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[ba]=0;if((c[D+2047004>>2]|0)!=0){V=n+1184596|0;$=H+576|0;c[V>>2]=c[$>>2];c[V+4>>2]=c[$+4>>2];c[V+8>>2]=c[$+8>>2];c[V+12>>2]=c[$+12>>2]}do{if((c[D+2047008>>2]|0)!=0){if((h|0)!=3){break}if((Q|0)==0){break}$=c[H+72>>2]|0;V=n;switch(Y|0){case 2:{da=V+1223016+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 1:{da=V+1261416+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 10:{da=V+1398216+((d[V+1128232|0]|0)*600|0)|0;break};case 9:{da=V+1395816+((d[V+1128232|0]|0)*600|0)|0;break};case 0:{da=V+1184616+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 12:{da=V+1400616|0;break};case 11:{da=V+1399416+((d[V+1128232|0]|0)*600|0)|0;break};case 6:{da=V+1376616+((d[V+1128232|0]|0)*2400|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 5:{da=V+1357416+((d[V+1128232|0]|0)*4800|0)+((d[V+1128233|0]|0)*1200|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 8:{da=V+1386216+((d[V+1128232|0]|0)*1200|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 7:{da=V+1391016+((d[V+1128232|0]|0)*1200|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 4:{da=V+1338216+((d[V+1128232|0]|0)*4800|0)+((d[V+1128233|0]|0)*1200|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 3:{da=V+1299816+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}c[da+592>>2]=$}}while(0);$=n;switch(Y|0){case 11:{ea=$+1399416+((d[$+1128232|0]|0)*600|0)|0;break};case 10:{ea=$+1398216+((d[$+1128232|0]|0)*600|0)|0;break};case 9:{ea=$+1395816+((d[$+1128232|0]|0)*600|0)|0;break};case 8:{ea=$+1386216+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 7:{ea=$+1391016+((d[$+1128232|0]|0)*1200|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 6:{ea=$+1376616+((d[$+1128232|0]|0)*2400|0)+((d[$+1128233|0]|0)*600|0)|0;break};case 12:{ea=$+1400616|0;break};case 5:{ea=$+1357416+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 4:{ea=$+1338216+((d[$+1128232|0]|0)*4800|0)+((d[$+1128233|0]|0)*1200|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 3:{ea=$+1299816+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 2:{ea=$+1223016+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 1:{ea=$+1261416+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};case 0:{ea=$+1184616+((d[$+1128232|0]|0)*9600|0)+((d[$+1128233|0]|0)*2400|0)+((d[$+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Slc(D,b,f,g,w,y,Y,ea,c[q>>2]|0,c[q+4>>2]|0);$=c[w>>2]|0;V=c[n+75248>>2]|0;_=Erc($,($|0)<0|0?-1:0,V,(V|0)<0|0?-1:0)|0;V=wrc(128,0,_,G)|0;_=G;$=yrc(c[y>>2]|0,c[y+4>>2]|0,c[n+75244>>2]|0)|0;Z=wrc(V>>>8|_<<24,_>>8|((_|0)<0|0?-1:0)<<24,$,G)|0;c[A>>2]=Z;c[A+4>>2]=G;Z=c[A+4>>2]|0;$=c[q+4>>2]|0;do{if((Z|0)<($|0)|(Z|0)==($|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){if((f+E|0)>=(c[o+10148>>2]|0)){break}_=n;switch(Y|0){case 2:{fa=_+1223016+((d[_+1128232|0]|0)*9600|0)+((d[_+1128233|0]|0)*2400|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 1:{fa=_+1261416+((d[_+1128232|0]|0)*9600|0)+((d[_+1128233|0]|0)*2400|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 0:{fa=_+1184616+((d[_+1128232|0]|0)*9600|0)+((d[_+1128233|0]|0)*2400|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 7:{fa=_+1391016+((d[_+1128232|0]|0)*1200|0)+((d[_+1128233|0]|0)*600|0)|0;break};case 6:{fa=_+1376616+((d[_+1128232|0]|0)*2400|0)+((d[_+1128233|0]|0)*600|0)|0;break};case 5:{fa=_+1357416+((d[_+1128232|0]|0)*4800|0)+((d[_+1128233|0]|0)*1200|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 4:{fa=_+1338216+((d[_+1128232|0]|0)*4800|0)+((d[_+1128233|0]|0)*1200|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 3:{fa=_+1299816+((d[_+1128232|0]|0)*9600|0)+((d[_+1128233|0]|0)*2400|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 12:{fa=_+1400616|0;break};case 11:{fa=_+1399416+((d[_+1128232|0]|0)*600|0)|0;break};case 10:{fa=_+1398216+((d[_+1128232|0]|0)*600|0)|0;break};case 9:{fa=_+1395816+((d[_+1128232|0]|0)*600|0)|0;break};case 8:{fa=_+1386216+((d[_+1128232|0]|0)*1200|0)+((d[_+1128233|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Vlc(D,fa,f,g,Y,0);Wlc(D,e,0,f,g,Y);_=n;switch(Y|0){case 12:case 11:case 10:case 9:{ga=_+1128232|0;break};case 8:case 7:case 6:{ga=_+1128233|0;break};case 5:case 4:case 3:{ga=_+1128234|0;break};case 2:case 1:case 0:{ga=_+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[ga]=1;if((c[D+2047004>>2]|0)!=0){_=n+1184596|0;V=H+576|0;c[_>>2]=c[V>>2];c[_+4>>2]=c[V+4>>2];c[_+8>>2]=c[V+8>>2];c[_+12>>2]=c[V+12>>2]}do{if((c[D+2047008>>2]|0)!=0){if((h|0)!=3){break}if((Q|0)==0){break}V=c[H+72>>2]|0;_=n;switch(Y|0){case 12:{ha=_+1400616|0;break};case 11:{ha=_+1399416+((d[_+1128232|0]|0)*600|0)|0;break};case 10:{ha=_+1398216+((d[_+1128232|0]|0)*600|0)|0;break};case 9:{ha=_+1395816+((d[_+1128232|0]|0)*600|0)|0;break};case 8:{ha=_+1386216+((d[_+1128232|0]|0)*1200|0)+((d[_+1128233|0]|0)*600|0)|0;break};case 7:{ha=_+1391016+((d[_+1128232|0]|0)*1200|0)+((d[_+1128233|0]|0)*600|0)|0;break};case 6:{ha=_+1376616+((d[_+1128232|0]|0)*2400|0)+((d[_+1128233|0]|0)*600|0)|0;break};case 5:{ha=_+1357416+((d[_+1128232|0]|0)*4800|0)+((d[_+1128233|0]|0)*1200|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 4:{ha=_+1338216+((d[_+1128232|0]|0)*4800|0)+((d[_+1128233|0]|0)*1200|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 3:{ha=_+1299816+((d[_+1128232|0]|0)*9600|0)+((d[_+1128233|0]|0)*2400|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 2:{ha=_+1223016+((d[_+1128232|0]|0)*9600|0)+((d[_+1128233|0]|0)*2400|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 1:{ha=_+1261416+((d[_+1128232|0]|0)*9600|0)+((d[_+1128233|0]|0)*2400|0)+((d[_+1128234|0]|0)*600|0)|0;break};case 0:{ha=_+1184616+((d[_+1128232|0]|0)*9600|0)+((d[_+1128233|0]|0)*2400|0)+((d[_+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}c[ha+592>>2]=V}}while(0);L=n;switch(Y|0){case 12:{ia=L+1400616|0;break};case 11:{ia=L+1399416+((d[L+1128232|0]|0)*600|0)|0;break};case 10:{ia=L+1398216+((d[L+1128232|0]|0)*600|0)|0;break};case 9:{ia=L+1395816+((d[L+1128232|0]|0)*600|0)|0;break};case 8:{ia=L+1386216+((d[L+1128232|0]|0)*1200|0)+((d[L+1128233|0]|0)*600|0)|0;break};case 7:{ia=L+1391016+((d[L+1128232|0]|0)*1200|0)+((d[L+1128233|0]|0)*600|0)|0;break};case 6:{ia=L+1376616+((d[L+1128232|0]|0)*2400|0)+((d[L+1128233|0]|0)*600|0)|0;break};case 5:{ia=L+1357416+((d[L+1128232|0]|0)*4800|0)+((d[L+1128233|0]|0)*1200|0)+((d[L+1128234|0]|0)*600|0)|0;break};case 4:{ia=L+1338216+((d[L+1128232|0]|0)*4800|0)+((d[L+1128233|0]|0)*1200|0)+((d[L+1128234|0]|0)*600|0)|0;break};case 3:{ia=L+1299816+((d[L+1128232|0]|0)*9600|0)+((d[L+1128233|0]|0)*2400|0)+((d[L+1128234|0]|0)*600|0)|0;break};case 2:{ia=L+1223016+((d[L+1128232|0]|0)*9600|0)+((d[L+1128233|0]|0)*2400|0)+((d[L+1128234|0]|0)*600|0)|0;break};case 1:{ia=L+1261416+((d[L+1128232|0]|0)*9600|0)+((d[L+1128233|0]|0)*2400|0)+((d[L+1128234|0]|0)*600|0)|0;break};case 0:{ia=L+1184616+((d[L+1128232|0]|0)*9600|0)+((d[L+1128233|0]|0)*2400|0)+((d[L+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}L=xrc(c[q>>2]|0,c[q+4>>2]|0,c[A>>2]|0,c[A+4>>2]|0)|0;Slc(D,b,f+E|0,g,v,x,Y,ia,L,G);if((c[v>>2]|0)==2147483647){c[A>>2]=-1;c[A+4>>2]=2147483647}else{c[w>>2]=(c[w>>2]|0)+(c[v>>2]|0);L=wrc(c[y>>2]|0,c[y+4>>2]|0,c[x>>2]|0,c[x+4>>2]|0)|0;c[y>>2]=L;c[y+4>>2]=G;L=c[w>>2]|0;W=c[n+75248>>2]|0;R=Erc(L,(L|0)<0|0?-1:0,W,(W|0)<0|0?-1:0)|0;W=wrc(128,0,R,G)|0;R=G;L=yrc(c[y>>2]|0,c[y+4>>2]|0,c[n+75244>>2]|0)|0;U=wrc(W>>>8|R<<24,R>>8|((R|0)<0|0?-1:0)<<24,L,G)|0;c[A>>2]=U;c[A+4>>2]=G}}}while(0);$=c[A+4>>2]|0;Z=c[q+4>>2]|0;if(($|0)<(Z|0)|($|0)==(Z|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){Z=m;$=h;U=(c[Z+50460>>2]|0)+g|0;L=Z+50464+(f&7)|0;Z=c[830920+($<<2)>>2]|0;R=1<<Z;W=0;V=0;if((c[1960336+($<<2)>>2]|0)!=(c[1960696+($<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((Z|0)<0){Cd(2473496,2485024,330,2651704)}$=0;while(1){if(($|0)>=(R|0)){break}W=W|a[U+$|0];V=V|a[L+$|0];$=$+1|0}W=(W&R|0)>0|0;V=(V&R|0)>0|0;X=(V<<1)+W+(Z<<2)|0;c[w>>2]=(c[w>>2]|0)+(c[n+1401216+(X<<4)+4>>2]|0);$=c[w>>2]|0;L=c[n+75248>>2]|0;U=Erc($,($|0)<0|0?-1:0,L,(L|0)<0|0?-1:0)|0;L=wrc(128,0,U,G)|0;U=G;$=yrc(c[y>>2]|0,c[y+4>>2]|0,c[n+75244>>2]|0)|0;_=wrc(L>>>8|U<<24,U>>8|((U|0)<0|0?-1:0)<<24,$,G)|0;c[A>>2]=_;c[A+4>>2]=G;_=c[A+4>>2]|0;$=c[q+4>>2]|0;if((_|0)<($|0)|(_|0)==($|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){$=c[A+4>>2]|0;c[q>>2]=c[A>>2];c[q+4>>2]=$;I=c[w>>2]|0;$=c[y+4>>2]|0;c[z>>2]=c[y>>2];c[z+4>>2]=$;c[(Tlc(n,h)|0)>>2]=Y}}Ulc(D,f,g,s|0,r|0,u|0,t|0,h)}}while(0);do{if((O|0)!=0){if((K|0)==0){break}ia=c[552416+(2*52|0)+(h<<2)>>2]|0;if(!(ia>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}Y=ia;ia=n;switch(Y|0){case 12:case 11:case 10:case 9:{ja=ia+1128232|0;break};case 8:case 7:case 6:{ja=ia+1128233|0;break};case 5:case 4:case 3:{ja=ia+1128234|0;break};case 2:case 1:case 0:{ja=ia+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[ja]=0;if((c[D+2047004>>2]|0)!=0){ia=n+1184596|0;ha=H+576|0;c[ia>>2]=c[ha>>2];c[ia+4>>2]=c[ha+4>>2];c[ia+8>>2]=c[ha+8>>2];c[ia+12>>2]=c[ha+12>>2]}do{if((c[D+2047008>>2]|0)!=0){if((h|0)!=3){break}if((Q|0)==0){break}ha=c[H+72>>2]|0;ia=n;switch(Y|0){case 12:{ka=ia+1400616|0;break};case 11:{ka=ia+1399416+((d[ia+1128232|0]|0)*600|0)|0;break};case 10:{ka=ia+1398216+((d[ia+1128232|0]|0)*600|0)|0;break};case 9:{ka=ia+1395816+((d[ia+1128232|0]|0)*600|0)|0;break};case 8:{ka=ia+1386216+((d[ia+1128232|0]|0)*1200|0)+((d[ia+1128233|0]|0)*600|0)|0;break};case 7:{ka=ia+1391016+((d[ia+1128232|0]|0)*1200|0)+((d[ia+1128233|0]|0)*600|0)|0;break};case 6:{ka=ia+1376616+((d[ia+1128232|0]|0)*2400|0)+((d[ia+1128233|0]|0)*600|0)|0;break};case 5:{ka=ia+1357416+((d[ia+1128232|0]|0)*4800|0)+((d[ia+1128233|0]|0)*1200|0)+((d[ia+1128234|0]|0)*600|0)|0;break};case 4:{ka=ia+1338216+((d[ia+1128232|0]|0)*4800|0)+((d[ia+1128233|0]|0)*1200|0)+((d[ia+1128234|0]|0)*600|0)|0;break};case 3:{ka=ia+1299816+((d[ia+1128232|0]|0)*9600|0)+((d[ia+1128233|0]|0)*2400|0)+((d[ia+1128234|0]|0)*600|0)|0;break};case 2:{ka=ia+1223016+((d[ia+1128232|0]|0)*9600|0)+((d[ia+1128233|0]|0)*2400|0)+((d[ia+1128234|0]|0)*600|0)|0;break};case 1:{ka=ia+1261416+((d[ia+1128232|0]|0)*9600|0)+((d[ia+1128233|0]|0)*2400|0)+((d[ia+1128234|0]|0)*600|0)|0;break};case 0:{ka=ia+1184616+((d[ia+1128232|0]|0)*9600|0)+((d[ia+1128233|0]|0)*2400|0)+((d[ia+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}c[ka+592>>2]=ha}}while(0);Z=n;switch(Y|0){case 3:{la=Z+1299816+((d[Z+1128232|0]|0)*9600|0)+((d[Z+1128233|0]|0)*2400|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 12:{la=Z+1400616|0;break};case 11:{la=Z+1399416+((d[Z+1128232|0]|0)*600|0)|0;break};case 10:{la=Z+1398216+((d[Z+1128232|0]|0)*600|0)|0;break};case 9:{la=Z+1395816+((d[Z+1128232|0]|0)*600|0)|0;break};case 8:{la=Z+1386216+((d[Z+1128232|0]|0)*1200|0)+((d[Z+1128233|0]|0)*600|0)|0;break};case 7:{la=Z+1391016+((d[Z+1128232|0]|0)*1200|0)+((d[Z+1128233|0]|0)*600|0)|0;break};case 6:{la=Z+1376616+((d[Z+1128232|0]|0)*2400|0)+((d[Z+1128233|0]|0)*600|0)|0;break};case 5:{la=Z+1357416+((d[Z+1128232|0]|0)*4800|0)+((d[Z+1128233|0]|0)*1200|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 4:{la=Z+1338216+((d[Z+1128232|0]|0)*4800|0)+((d[Z+1128233|0]|0)*1200|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 2:{la=Z+1223016+((d[Z+1128232|0]|0)*9600|0)+((d[Z+1128233|0]|0)*2400|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 1:{la=Z+1261416+((d[Z+1128232|0]|0)*9600|0)+((d[Z+1128233|0]|0)*2400|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 0:{la=Z+1184616+((d[Z+1128232|0]|0)*9600|0)+((d[Z+1128233|0]|0)*2400|0)+((d[Z+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Slc(D,b,f,g,w,y,Y,la,c[q>>2]|0,c[q+4>>2]|0);Z=c[w>>2]|0;W=c[n+75248>>2]|0;V=Erc(Z,(Z|0)<0|0?-1:0,W,(W|0)<0|0?-1:0)|0;W=wrc(128,0,V,G)|0;V=G;Z=yrc(c[y>>2]|0,c[y+4>>2]|0,c[n+75244>>2]|0)|0;R=wrc(W>>>8|V<<24,V>>8|((V|0)<0|0?-1:0)<<24,Z,G)|0;c[A>>2]=R;c[A+4>>2]=G;R=c[A+4>>2]|0;Z=c[q+4>>2]|0;do{if((R|0)<(Z|0)|(R|0)==(Z|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){if((g+E|0)>=(c[o+10156>>2]|0)){break}V=n;switch(Y|0){case 3:{ma=V+1299816+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 2:{ma=V+1223016+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 1:{ma=V+1261416+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 0:{ma=V+1184616+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 12:{ma=V+1400616|0;break};case 11:{ma=V+1399416+((d[V+1128232|0]|0)*600|0)|0;break};case 10:{ma=V+1398216+((d[V+1128232|0]|0)*600|0)|0;break};case 9:{ma=V+1395816+((d[V+1128232|0]|0)*600|0)|0;break};case 8:{ma=V+1386216+((d[V+1128232|0]|0)*1200|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 7:{ma=V+1391016+((d[V+1128232|0]|0)*1200|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 6:{ma=V+1376616+((d[V+1128232|0]|0)*2400|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 5:{ma=V+1357416+((d[V+1128232|0]|0)*4800|0)+((d[V+1128233|0]|0)*1200|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 4:{ma=V+1338216+((d[V+1128232|0]|0)*4800|0)+((d[V+1128233|0]|0)*1200|0)+((d[V+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Vlc(D,ma,f,g,Y,0);Wlc(D,e,0,f,g,Y);V=n;switch(Y|0){case 12:case 11:case 10:case 9:{na=V+1128232|0;break};case 8:case 7:case 6:{na=V+1128233|0;break};case 5:case 4:case 3:{na=V+1128234|0;break};case 2:case 1:case 0:{na=V+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[na]=1;if((c[D+2047004>>2]|0)!=0){V=n+1184596|0;W=H+576|0;c[V>>2]=c[W>>2];c[V+4>>2]=c[W+4>>2];c[V+8>>2]=c[W+8>>2];c[V+12>>2]=c[W+12>>2]}do{if((c[D+2047008>>2]|0)!=0){if((h|0)!=3){break}if((Q|0)==0){break}W=c[H+72>>2]|0;V=n;switch(Y|0){case 12:{oa=V+1400616|0;break};case 11:{oa=V+1399416+((d[V+1128232|0]|0)*600|0)|0;break};case 10:{oa=V+1398216+((d[V+1128232|0]|0)*600|0)|0;break};case 9:{oa=V+1395816+((d[V+1128232|0]|0)*600|0)|0;break};case 8:{oa=V+1386216+((d[V+1128232|0]|0)*1200|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 7:{oa=V+1391016+((d[V+1128232|0]|0)*1200|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 6:{oa=V+1376616+((d[V+1128232|0]|0)*2400|0)+((d[V+1128233|0]|0)*600|0)|0;break};case 5:{oa=V+1357416+((d[V+1128232|0]|0)*4800|0)+((d[V+1128233|0]|0)*1200|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 4:{oa=V+1338216+((d[V+1128232|0]|0)*4800|0)+((d[V+1128233|0]|0)*1200|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 3:{oa=V+1299816+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 2:{oa=V+1223016+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 1:{oa=V+1261416+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};case 0:{oa=V+1184616+((d[V+1128232|0]|0)*9600|0)+((d[V+1128233|0]|0)*2400|0)+((d[V+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}c[oa+592>>2]=W}}while(0);W=n;switch(Y|0){case 12:{pa=W+1400616|0;break};case 11:{pa=W+1399416+((d[W+1128232|0]|0)*600|0)|0;break};case 10:{pa=W+1398216+((d[W+1128232|0]|0)*600|0)|0;break};case 9:{pa=W+1395816+((d[W+1128232|0]|0)*600|0)|0;break};case 8:{pa=W+1386216+((d[W+1128232|0]|0)*1200|0)+((d[W+1128233|0]|0)*600|0)|0;break};case 7:{pa=W+1391016+((d[W+1128232|0]|0)*1200|0)+((d[W+1128233|0]|0)*600|0)|0;break};case 6:{pa=W+1376616+((d[W+1128232|0]|0)*2400|0)+((d[W+1128233|0]|0)*600|0)|0;break};case 5:{pa=W+1357416+((d[W+1128232|0]|0)*4800|0)+((d[W+1128233|0]|0)*1200|0)+((d[W+1128234|0]|0)*600|0)|0;break};case 4:{pa=W+1338216+((d[W+1128232|0]|0)*4800|0)+((d[W+1128233|0]|0)*1200|0)+((d[W+1128234|0]|0)*600|0)|0;break};case 3:{pa=W+1299816+((d[W+1128232|0]|0)*9600|0)+((d[W+1128233|0]|0)*2400|0)+((d[W+1128234|0]|0)*600|0)|0;break};case 2:{pa=W+1223016+((d[W+1128232|0]|0)*9600|0)+((d[W+1128233|0]|0)*2400|0)+((d[W+1128234|0]|0)*600|0)|0;break};case 1:{pa=W+1261416+((d[W+1128232|0]|0)*9600|0)+((d[W+1128233|0]|0)*2400|0)+((d[W+1128234|0]|0)*600|0)|0;break};case 0:{pa=W+1184616+((d[W+1128232|0]|0)*9600|0)+((d[W+1128233|0]|0)*2400|0)+((d[W+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}W=xrc(c[q>>2]|0,c[q+4>>2]|0,c[A>>2]|0,c[A+4>>2]|0)|0;Slc(D,b,f,g+E|0,v,x,Y,pa,W,G);if((c[v>>2]|0)==2147483647){c[A>>2]=-1;c[A+4>>2]=2147483647}else{c[w>>2]=(c[w>>2]|0)+(c[v>>2]|0);W=wrc(c[y>>2]|0,c[y+4>>2]|0,c[x>>2]|0,c[x+4>>2]|0)|0;c[y>>2]=W;c[y+4>>2]=G;W=c[w>>2]|0;V=c[n+75248>>2]|0;ha=Erc(W,(W|0)<0|0?-1:0,V,(V|0)<0|0?-1:0)|0;V=wrc(128,0,ha,G)|0;ha=G;W=yrc(c[y>>2]|0,c[y+4>>2]|0,c[n+75244>>2]|0)|0;ia=wrc(V>>>8|ha<<24,ha>>8|((ha|0)<0|0?-1:0)<<24,W,G)|0;c[A>>2]=ia;c[A+4>>2]=G}}}while(0);Z=c[A+4>>2]|0;R=c[q+4>>2]|0;if((Z|0)<(R|0)|(Z|0)==(R|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){R=m;Z=h;ia=(c[R+50460>>2]|0)+g|0;W=R+50464+(f&7)|0;R=c[830920+(Z<<2)>>2]|0;ha=1<<R;V=0;ga=0;if((c[1960336+(Z<<2)>>2]|0)!=(c[1960696+(Z<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((R|0)<0){Cd(2473496,2485024,330,2651704)}Z=0;while(1){if((Z|0)>=(ha|0)){break}V=V|a[ia+Z|0];ga=ga|a[W+Z|0];Z=Z+1|0}V=(V&ha|0)>0|0;ga=(ga&ha|0)>0|0;X=(ga<<1)+V+(R<<2)|0;c[w>>2]=(c[w>>2]|0)+(c[n+1401216+(X<<4)+8>>2]|0);Z=c[w>>2]|0;W=c[n+75248>>2]|0;ia=Erc(Z,(Z|0)<0|0?-1:0,W,(W|0)<0|0?-1:0)|0;W=wrc(128,0,ia,G)|0;ia=G;Z=yrc(c[y>>2]|0,c[y+4>>2]|0,c[n+75244>>2]|0)|0;fa=wrc(W>>>8|ia<<24,ia>>8|((ia|0)<0|0?-1:0)<<24,Z,G)|0;c[A>>2]=fa;c[A+4>>2]=G;fa=c[A+4>>2]|0;Z=c[q+4>>2]|0;if((fa|0)<(Z|0)|(fa|0)==(Z|0)&(c[A>>2]|0)>>>0<(c[q>>2]|0)>>>0){I=c[w>>2]|0;Z=c[y+4>>2]|0;c[z>>2]=c[y>>2];c[z+4>>2]=Z;Z=c[A+4>>2]|0;c[q>>2]=c[A>>2];c[q+4>>2]=Z;c[(Tlc(n,h)|0)>>2]=Y}}Ulc(D,f,g,s|0,r|0,u|0,t|0,h)}}while(0);c[j>>2]=I;j=c[z+4>>2]|0;t=k;c[t>>2]=c[z>>2];c[t+4>>2]=j;do{if((I|0)<2147483647){j=c[z+4>>2]|0;t=2147483647;if(!((j|0)<(t|0)|(j|0)==(t|0)&(c[z>>2]|0)>>>0<-1>>>0)){break}if((l|0)==0){break}t=(h|0)==12|0;do{if((c[D+1471728>>2]|0)==2){if((d[o+13409|0]|0)==0){break}Sjc(D,f,g,t,I)}}while(0);if((c[D+1471728>>2]|0)==3){R=I;Zjc(c[D+2047228>>2]|0,R,(R|0)<0|0?-1:0,c[z>>2]|0,c[z+4>>2]|0)}Xlc(D,b,e,f,g,t,h)}}while(0);if((h|0)!=12){if((F|0)==(c[e>>2]|0)){}else{Cd(2160840,2539744,2453,2651488)}i=p;return}if(F>>>0<(c[e>>2]|0)>>>0){}else{Cd(2278952,2539744,2449,2651488)}if((I|0)<2147483647){}else{Cd(2229640,2539744,2450,2651488)}I=c[z+4>>2]|0;e=2147483647;if((I|0)<(e|0)|(I|0)==(e|0)&(c[z>>2]|0)>>>0<-1>>>0){}else{Cd(2191720,2539744,2451,2651488)}i=p;return}function Nlc(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;k=b;b=d;d=e;e=f;f=g;g=h;h=a+1434592|0;a=c[h+10160>>2]|0;l=(c[k+4>>2]|0)-e|0;m=(c[k+12>>2]|0)-f|0;k=(c[h+10188>>2]|0)+((ca(e,a)|0)*124|0)+(f*124|0)|0;f=c[777736+(g<<2)>>2]|0;e=c[777680+(g<<2)>>2]|0;if((l|0)>0){if((m|0)>0){}else{n=3}}else{n=3}if((n|0)==3){Cd(2414248,2539744,1392,2653216)}do{if((m|0)>=8){if((l|0)<8){break}o=0;while(1){if((o|0)>=8){break}p=0;while(1){if((p|0)>=8){break}q=(ca(o,a)|0)+p|0;r=c[d+(q<<2)>>2]|0;if((r|0)!=0){s=c[r>>2]|0}else{s=0}do{if((r|0)!=0){if(!(s>>>0<=g>>>0)){n=26;break}t=0;while(1){if((t|0)>=(f|0)){break}u=0;while(1){if((u|0)>=(e|0)){break}v=(ca(o+t|0,a)|0)+p+u|0;r=c[d+(v<<2)>>2]|0;if((r|0)!=0){c[b+(v<<2)>>2]=(c[h+10188>>2]|0)+(((r-(c[h+10196>>2]|0)|0)/124|0)*124|0);c[c[b+(v<<2)>>2]>>2]=c[r>>2]}u=u+1|0}t=t+1|0}}else{n=26}}while(0);if((n|0)==26){n=0;c[b+(q<<2)>>2]=k+(q*124|0);c[c[b+(q<<2)>>2]>>2]=g}p=p+e|0}o=o+f|0}i=j;return}}while(0);Olc(h,b,d);i=j;return}function Olc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=d;d=c[f+10160>>2]|0;g=0;while(1){if((g|0)>=8){break}h=0;while(1){if((h|0)>=8){break}j=c[b+((ca(g,d)|0)+h<<2)>>2]|0;if((j|0)!=0){k=c[j>>2]|0}else{k=0}if((j|0)!=0){c[a+((ca(g,d)|0)+h<<2)>>2]=(c[f+10188>>2]|0)+(((j-(c[f+10196>>2]|0)|0)/124|0)*124|0);c[c[a+((ca(g,d)|0)+h<<2)>>2]>>2]=k}h=h+1|0}g=g+1|0}i=e;return}function Plc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=d;d=e;e=f;do{if((c[h+2047224>>2]|0)!=0){if((c[b+50528>>2]|0)!=0){break}j=cmc(h,a,d,e)|0;k=j;i=g;return k|0}}while(0);j=1;k=j;i=g;return k|0}function Qlc(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=b;b=d;d=e;e=f;f=g;g=h;h=j;j=a+57488|0;a=c[777792+(h<<2)>>2]|0;m=c[777848+(h<<2)>>2]|0;n=c[777680+(h<<2)>>2]|0;o=c[777736+(h<<2)>>2]|0;h=0;while(1){if((h|0)>=3){break}p=d+(ca(a,h)|0)|0;nrc(p|0,(c[j+50400+(h<<2)>>2]|0)+(b<<1>>c[j+(h*52|0)+8>>2])|0,a>>>((c[j+(h*52|0)+8>>2]|0)>>>0))|0;p=e+(ca(m,h)|0)|0;nrc(p|0,j+50412+(h<<4)+((l&7)<<1>>c[j+(h*52|0)+12>>2])|0,m>>>((c[j+(h*52|0)+12>>2]|0)>>>0))|0;h=h+1|0}nrc(f|0,(c[j+50460>>2]|0)+b|0,n)|0;nrc(g|0,j+50464+(l&7)|0,o)|0;i=k;return}function Rlc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;i=i+8|0;f=b;b=d;d=Xe[c[a+2047252+(b*44|0)+8>>2]&511](c[f>>2]|0,c[f+4>>2]|0,2653864,0,e|0)|0;i=e;return(d+(1<<(c[777552+(b<<2)>>2]|0)-1)|0)>>>((c[777552+(b<<2)>>2]|0)>>>0)|0}function Slc(b,e,f,g,h,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;o=i;i=i+8|0;p=o|0;q=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;c[p>>2]=m;c[p+4>>2]=n;n=q+1434592|0;m=q+32768|0;l=m+24720|0;r=m|0;s=l|0;t=c[q+1471728>>2]|0;u=1.0;c[m+1184588>>2]=1;do{if(j>>>0<3>>>0){if((d[m+1128235|0]|0|0)==0){break}c[g>>2]=0;v=h;c[v>>2]=0;c[v+4>>2]=0;i=o;return}}while(0);Flc(q,b,e,f,j);v=c[c[l+160>>2]>>2]|0;c[v>>2]=j;l=0;while(1){if((l|0)>=3){break}c[r+(l*8240|0)+8196>>2]=c[k+272+(l*12|0)>>2];c[r+(l*8240|0)+8192>>2]=c[k+308+(l*12|0)>>2];c[s+(l*52|0)>>2]=c[k+344+(l*12|0)>>2];c[r+(l*8240|0)+8200>>2]=c[k+380+(l*12|0)>>2];l=l+1|0}c[k+416>>2]=0;c[m+75208>>2]=0;a[v+12|0]=0;c[m+75300>>2]=Rlc(q,m+8204|0,j)|0;l=c[m+75248>>2]|0;if((c[q+1471880>>2]|0)==1){bmc(q,m)}if((t|0)==1){if(j>>>0<=6>>>0){w=c[m+75252>>2]|0}else{w=ekc(q,m,j)|0}r=w;do{if((c[n+10108>>2]|0)==0){x=19}else{if((c[q+1472152>>2]|0)!=0){x=19;break}if((c[q+1472148>>2]|0)!=0){if((c[q+2017236>>2]|0)==0){x=19;break}}if((d[n+13409|0]|0|0)!=0){y=c[q+2047180>>2]|0}else{y=c[n+10216>>2]|0}a[v+13|0]=jgc(n,y,j,e,f)|0}}while(0);if((x|0)==19){a[v+13|0]=$jc(r)|0}u=+akc(r);H2b(q,m);c[m+75248>>2]=~~+Nb(+(+(c[m+75248>>2]|0)*u))}else{if((t|0)==2){r=(ca(e,c[n+10156>>2]|0)|0)+f|0;v=a[(c[q+2047216>>2]|0)+r|0]|0;do{if((e|0)<=1){z=1}else{if((e|0)>=((c[n+10148>>2]|0)-2|0)){z=1;break}if((f|0)<=1){z=1;break}z=(f|0)>=((c[n+10156>>2]|0)-2|0)}}while(0);do{if((z&1|0)==0){if((v&255|0)<=128){break}r=(ca(c[m+75248>>2]|0,(v&255)-128|0)|0)/256|0;x=m+75248|0;c[x>>2]=(c[x>>2]|0)+r}}while(0)}else{if((t|0)==3){if((d[n+13409|0]|0|0)!=0){A=c[q+2047180>>2]|0}else{A=c[n+10216>>2]|0}if((jgc(n,A,j,e,f)|0)!=0){c[m+75248>>2]=_jc(c[q+2047228>>2]|0)|0}}}}A=n;if((c[A+10108>>2]|0)==0){B=1}else{B=(c[A+10124>>2]|0)!=0}if((B&1|0)!=0){O3b(q,m,g,h,j,k,c[p>>2]|0,c[p+4>>2]|0)}else{if(j>>>0>=3>>>0){S3b(q,m,b,e,f,g,h,j,k,c[p>>2]|0,c[p+4>>2]|0)|0;}else{$3b(q,m,b,e,f,g,h,j,k,c[p>>2]|0,c[p+4>>2]|0)|0;}}c[m+75248>>2]=l;if((t|0)!=1){i=o;return}if((c[g>>2]|0)==2147483647){i=o;return}c[g>>2]=~~+Nb(+(+(c[g>>2]|0)*u));i=o;return}function Tlc(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0;c=i;e=a;a=b;if((a|0)==3){f=e+1401472+((d[e+1128232|0]|0)<<6)+((d[e+1128233|0]|0)<<4)+((d[e+1128234|0]|0)<<2)|0;g=f;i=c;return g|0}else if((a|0)==9){f=e+1401792+((d[e+1128232|0]|0)<<2)|0;g=f;i=c;return g|0}else if((a|0)==6){f=e+1401728+((d[e+1128232|0]|0)<<4)+((d[e+1128233|0]|0)<<2)|0;g=f;i=c;return g|0}else if((a|0)==12){f=e+1401808|0;g=f;i=c;return g|0}else{Cd(2524984,2539744,1127,2652240);return 0}return 0}function Ulc(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=b;b=d;d=e;e=f;f=g;g=h;h=j;j=a+57488|0;a=c[777792+(h<<2)>>2]|0;m=c[777848+(h<<2)>>2]|0;n=c[777680+(h<<2)>>2]|0;o=c[777736+(h<<2)>>2]|0;h=0;while(1){if((h|0)>=3){break}p=d+(ca(a,h)|0)|0;nrc((c[j+50400+(h<<2)>>2]|0)+(b<<1>>c[j+(h*52|0)+8>>2])|0,p|0,a>>>((c[j+(h*52|0)+8>>2]|0)>>>0))|0;p=e+(ca(m,h)|0)|0;nrc(j+50412+(h<<4)+((l&7)<<1>>c[j+(h*52|0)+12>>2])|0,p|0,m>>>((c[j+(h*52|0)+12>>2]|0)>>>0))|0;h=h+1|0}nrc((c[j+50460>>2]|0)+b|0,f|0,n)|0;nrc(j+50464+(l&7)|0,g|0,o)|0;i=k;return}function Vlc(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=i;l=b;b=e;e=f;f=g;g=h;h=j;j=l+1434592|0;m=l+1473304|0;n=l+32768|0;o=n+24720|0;p=n|0;q=o|0;r=b|0;s=c[c[o+160>>2]>>2]|0;t=c[c[o+160>>2]>>2]|0;u=j+13408|0;v=c[j+10160>>2]|0;w=c[777680+(g<<2)>>2]|0;x=c[777736+(g<<2)>>2]|0;if((c[r>>2]|0)==(g|0)){}else{Cd(2542400,2539744,837,2651056)}nrc(t|0,r|0,124)|0;do{if((d[u|0]|0|0)!=0){if((h|0)==0){break}if((c[l+1471728>>2]|0)==2){if((d[u+1|0]|0|0)!=0){y=c[l+2047180>>2]|0}else{y=c[j+10216>>2]|0}a[t+13|0]=jgc(j,y,g,e,f)|0}else{if((c[l+1471728>>2]|0)==3){Vjc(l,c[c[o+160>>2]>>2]|0,e,f,g,1);H2b(l,n)}}}}while(0);f=((c[s+20>>2]|0)>0|0)!=0?3:1;e=0;while(1){if((e|0)>=(f|0)){break}c[p+(e*8240|0)+8196>>2]=c[b+272+(e*12|0)+4>>2];c[p+(e*8240|0)+8192>>2]=c[b+308+(e*12|0)+4>>2];c[q+(e*52|0)>>2]=c[b+344+(e*12|0)+4>>2];c[p+(e*8240|0)+8200>>2]=c[b+380+(e*12|0)+4>>2];e=e+1|0}e=f;while(1){if((e|0)>=3){break}c[p+(e*8240|0)+8196>>2]=c[b+272+(e*12|0)+8>>2];c[p+(e*8240|0)+8192>>2]=c[b+308+(e*12|0)+8>>2];c[q+(e*52|0)>>2]=c[b+344+(e*12|0)+8>>2];c[p+(e*8240|0)+8200>>2]=c[b+380+(e*12|0)+8>>2];e=e+1|0}p=0;while(1){if((p|0)>=(x|0)){break}q=0;while(1){if((q|0)>=(w|0)){break}do{if(((c[o+176>>2]>>6)+w|0)>(q|0)){if(((c[o+184>>2]>>6)+x|0)<=(p|0)){break}f=q+(ca(p,v)|0)|0;c[(c[o+160>>2]|0)+(f<<2)>>2]=t}}while(0);q=q+1|0}p=p+1|0}if((c[l+1471728>>2]|0)!=0){H2b(l,n)}if(g>>>0<9>>>0){if(g>>>0<6>>>0){g=b+512|0;l=c[g+4>>2]|0;p=b+520|0;c[p>>2]=c[g>>2];c[p+4>>2]=l}l=b+520|0;p=c[l+4>>2]|0;g=b+528|0;c[g>>2]=c[l>>2];c[g+4>>2]=p}do{if(((c[s+20>>2]|0)>0|0)!=0){if(!((c[s>>2]|0)>>>0<3>>>0)){break}c[s+28>>2]=c[r+116>>2];c[s+32>>2]=c[r+120>>2]}}while(0);c[n+1129276>>2]=c[b+424>>2];nrc(n+1128252+(c[s+8>>2]<<8)|0,c[b+124>>2]|0,c[b+420>>2]|0)|0;if((h|0)==0){i=k;return}if((Thc(j+13408|0,d[s+13|0]|0,3)|0)==0){e=0;while(1){if((e|0)>=5){break}h=b+504+(e<<3)|0;n=m+17112+(e<<3)|0;r=wrc(c[n>>2]|0,c[n+4>>2]|0,c[h>>2]|0,c[h+4>>2]|0)|0;c[n>>2]=r;c[n+4>>2]=G;e=e+1|0}}n=j;if((c[n+10108>>2]|0)==0){z=1}else{z=(c[n+10124>>2]|0)!=0}if((z&1|0)!=0){i=k;return}if(((c[s+20>>2]|0)>0|0)!=0){Tmc(j,o);if((c[j+10220>>2]|0)==4){z=cgc(o)|0;o=j+36076+(z*12|0)+(c[s+72>>2]<<2)|0;c[o>>2]=(c[o>>2]|0)+1}}o=c[b+496>>2]|0;s=m+16992|0;z=wrc(c[s>>2]|0,c[s+4>>2]|0,o,(o|0)<0|0?-1:0)|0;c[s>>2]=z;c[s+4>>2]=G;s=c[b+492>>2]|0;z=m+17e3|0;o=wrc(c[z>>2]|0,c[z+4>>2]|0,s,(s|0)<0|0?-1:0)|0;c[z>>2]=o;c[z+4>>2]=G;z=c[b+488>>2]|0;o=m+17008|0;s=wrc(c[o>>2]|0,c[o+4>>2]|0,z,(z|0)<0|0?-1:0)|0;c[o>>2]=s;c[o+4>>2]=G;e=0;while(1){if((e|0)>=4){break}o=b+544+(e<<3)|0;s=m+17232+(e<<3)|0;z=wrc(c[s>>2]|0,c[s+4>>2]|0,c[o>>2]|0,c[o+4>>2]|0)|0;c[s>>2]=z;c[s+4>>2]=G;e=e+1|0}i=k;return}function Wlc(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=i;l=b;b=e;e=f;f=g;g=h;h=j;j=l+1434592|0;m=l+32768|0;n=m+24720|0;o=c[n+160>>2]|0;p=c[o>>2]|0;q=p|0;r=m;switch(h|0){case 12:{s=r+1400616|0;break};case 9:{s=r+1395816+((d[r+1128232|0]|0)*600|0)|0;break};case 2:{s=r+1223016+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 6:{s=r+1376616+((d[r+1128232|0]|0)*2400|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 7:{s=r+1391016+((d[r+1128232|0]|0)*1200|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 10:{s=r+1398216+((d[r+1128232|0]|0)*600|0)|0;break};case 4:{s=r+1338216+((d[r+1128232|0]|0)*4800|0)+((d[r+1128233|0]|0)*1200|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 3:{s=r+1299816+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 8:{s=r+1386216+((d[r+1128232|0]|0)*1200|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 11:{s=r+1399416+((d[r+1128232|0]|0)*600|0)|0;break};case 0:{s=r+1184616+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 1:{s=r+1261416+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 5:{s=r+1357416+((d[r+1128232|0]|0)*4800|0)+((d[r+1128233|0]|0)*1200|0)+((d[r+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}r=s;s=d[q+13|0]|0;t=c[j+10160>>2]|0;u=c[777680+(h<<2)>>2]|0;v=c[777736+(h<<2)>>2]|0;do{if((c[m+75204>>2]|0)!=0){w=0}else{if(!((c[q>>2]|0)>>>0>=3>>>0)){w=0;break}if((c[l+1471728>>2]|0)==2){w=0;break}if((c[l+1471728>>2]|0)==3){w=0;break}w=(c[l+2046936>>2]|0)!=0}}while(0);c[m+75208>>2]=w&1;c[m+75212>>2]=c[r+416>>2];c[r+416>>2]=1;c[m+1184588>>2]=c[l+2046948>>2];do{if((e|0)!=0){x=0}else{if((c[l+2046932>>2]|0)==0){x=0;break}x=(c[m+75216>>2]|0)<115}}while(0);c[m+1184592>>2]=x&1;if((c[m+1184592>>2]|0)!=0){i=k;return}if((c[j+10108>>2]|0)==0){if((c[l+1471880>>2]|0)==1){_lc(l,m);I2b(l,m)}}else{x=j;r=n;w=c[q+20>>2]|0;y=c[q+24>>2]|0;if((w|0)>=1){z=w-1|0}else{z=0}c[r+188>>2]=x+9816+(z<<6);if((y|0)>=1){A=y-1|0}else{A=0}c[r+192>>2]=x+9816+(A<<6);if((c[l+1471880>>2]|0)==1){_lc(l,m)}c[l+2017088>>2]=$lc(q,c[l+2017092>>2]|0)|0;I2b(l,m)}if(((c[q+20>>2]|0)>0|0)!=0){A=(c[q+24>>2]|0)>0|0;x=0;while(1){if((x|0)>=(A+1|0)){break}r=l;y=r+1434592|0;z=r;r=c[q+20+(x<<2)>>2]|0;do{if((r|0)==1){B=c[z+1472132>>2]|0}else{if((r|0)==2){B=c[z+1472136>>2]|0;break}else{B=c[z+1472140>>2]|0;break}}}while(0);Agc(n,x,y+8488+((c[y+9784+(B<<2)>>2]|0)*108|0)+16|0,f,g,(c[n+188+(x<<2)>>2]|0)+8|0);x=x+1|0}if(h>>>0>3>>>0){C=h}else{C=3}wgc(n,f,g,C);do{if((c[m+1129276>>2]|0)!=0){a[q+12|0]=1;if((e|0)!=0){C=n;x=C;if((c[x+164>>2]|0)!=0){D=c[(c[x+160>>2]|0)+(-(c[x+156>>2]|0)<<2)>>2]|0}else{D=0}x=D;B=C;if((c[B+168>>2]|0)!=0){E=c[(c[B+160>>2]|0)-4>>2]|0}else{E=0}B=E;if((x|0)!=0){F=d[x+12|0]|0}else{F=0}if((B|0)!=0){G=d[B+12|0]|0}else{G=0}B=j+36500+(F+G<<3)+4|0;c[B>>2]=(c[B>>2]|0)+1}if(h>>>0>3>>>0){H=h}else{H=3}B=n;x=H;C=0;while(1){if((C|0)>=3){I=95;break}A=B+(C*52|0)|0;z=A;r=c[558424+(x<<4)+(c[z+8>>2]<<3)+(c[z+12>>2]<<2)>>2]|0;if(!(r>>>0<13>>>0)){I=93;break}z=r;mrc(c[A+44>>2]|0,0,c[777792+(z<<2)>>2]|0)|0;mrc(c[A+48>>2]|0,0,c[777848+(z<<2)>>2]|0)|0;C=C+1|0}if((I|0)==93){Cd(2579304,2559560,292,2652320)}else if((I|0)==95){break}}else{a[q+12|0]=1;if(h>>>0>3>>>0){J=h}else{J=3}Dmc(m,J);if(h>>>0>3>>>0){K=h}else{K=3}n6b(l,b,((e|0)!=0^1)&1,K)}}while(0)}else{a[q+12|0]=1;K=0;while(1){if((K|0)>=3){break}if(h>>>0>3>>>0){L=h}else{L=3}Hmc(m,L,K);K=K+1|0}if((e|0)!=0){amc(j+23740|0,p)}if(h>>>0>3>>>0){M=h}else{M=3}n6b(l,b,((e|0)!=0^1)&1,M)}if((e|0)==0){i=k;return}do{if((c[j+10164>>2]|0)==4){if(!((c[q>>2]|0)>>>0>=3>>>0)){I=109;break}if(((c[q+20>>2]|0)>0|0)!=0){if((d[q+12|0]|0|0)!=0){I=109;break}if((Thc(j+13408|0,s,3)|0)!=0){I=109;break}}e=c[q+8>>2]|0;M=c[833024+(h<<2)>>2]|0;b=igc(n)|0;l=j+36428|0;K=M;if((K|0)==1){N=l+56+(b<<3)|0}else if((K|0)==2){N=l+32+(b*12|0)|0}else if((K|0)==3){N=l+(b<<4)|0}else{Cd(2629880,2605016,132,2652160)}b=N+(e<<2)|0;c[b>>2]=(c[b>>2]|0)+1}else{I=109}}while(0);if((I|0)==109){if(((c[p+20>>2]|0)>0|0)!=0){if((c[301584+(c[j+10164>>2]<<2)>>2]|0)>>>0<(c[833024+(h<<2)>>2]|0)>>>0){O=c[301584+(c[j+10164>>2]<<2)>>2]|0}else{O=c[833024+(h<<2)>>2]|0}P=O}else{if(h>>>0>=3>>>0){Q=c[q+8>>2]|0}else{Q=0}P=Q}Q=0;while(1){if((Q|0)>=(v|0)){break}q=0;while(1){if((q|0)>=(u|0)){break}do{if((g+q|0)<(c[j+10156>>2]|0)){if((f+Q|0)>=(c[j+10148>>2]|0)){break}c[(c[o+((ca(t,Q)|0)+q<<2)>>2]|0)+8>>2]=P}}while(0);q=q+1|0}Q=Q+1|0}}i=k;return}function Xlc(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;l=i;m=b;b=e;e=f;f=g;g=h;h=j;j=k;k=m+1434592|0;n=m+32768|0;o=n+24720|0;p=c[1960336+(j<<2)>>2]|0;q=(1<<p|0)/4|0;do{if((f|0)<(c[k+10148>>2]|0)){if((g|0)>=(c[k+10156>>2]|0)){break}if(j>>>0>=3>>>0){r=o;s=j;t=(c[r+50460>>2]|0)+g|0;u=r+50464+(f&7)|0;r=c[830920+(s<<2)>>2]|0;v=1<<r;w=0;x=0;if((c[1960336+(s<<2)>>2]|0)!=(c[1960696+(s<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((r|0)<0){Cd(2473496,2485024,330,2651704)}s=0;while(1){if((s|0)>=(v|0)){break}w=w|a[t+s|0];x=x|a[u+s|0];s=s+1|0}w=(w&v|0)>0|0;x=(x&v|0)>0|0;y=(x<<1)+w+(r<<2)|0;z=c[(Tlc(n,j)|0)>>2]|0}else{y=0;z=0}s=734952+(p*52|0)+(z<<2)|0;u=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24|0;s=u;if((s|0)==1){if((h|0)!=0){t=k+24300+(y<<4)+4|0;c[t>>2]=(c[t>>2]|0)+1}t=n;switch(z|0){case 12:case 11:case 10:case 9:{A=t+1128232|0;break};case 8:case 7:case 6:{A=t+1128233|0;break};case 5:case 4:case 3:{A=t+1128234|0;break};case 2:case 1:case 0:{A=t+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[A]=0;Ylc(m,b,e,f,g,h,z);if((f+q|0)<(c[k+10148>>2]|0)){t=n;switch(z|0){case 2:case 1:case 0:{B=t+1128235|0;break};case 5:case 4:case 3:{B=t+1128234|0;break};case 12:case 11:case 10:case 9:{B=t+1128232|0;break};case 8:case 7:case 6:{B=t+1128233|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[B]=1;Ylc(m,b,e,f+q|0,g,h,z)}}else if((s|0)==3){t=c[552416+(3*52|0)+(j<<2)>>2]|0;if(!(t>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}z=t;if((h|0)!=0){t=k+24300+(y<<4)+12|0;c[t>>2]=(c[t>>2]|0)+1}t=n;switch(z|0){case 5:case 4:case 3:{C=t+1128234|0;break};case 2:case 1:case 0:{C=t+1128235|0;break};case 8:case 7:case 6:{C=t+1128233|0;break};case 12:case 11:case 10:case 9:{C=t+1128232|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[C]=0;Xlc(m,b,e,f,g,h,z);t=n;switch(z|0){case 2:case 1:case 0:{D=t+1128235|0;break};case 8:case 7:case 6:{D=t+1128233|0;break};case 12:case 11:case 10:case 9:{D=t+1128232|0;break};case 5:case 4:case 3:{D=t+1128234|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[D]=1;Xlc(m,b,e,f,g+q|0,h,z);t=n;switch(z|0){case 12:case 11:case 10:case 9:{E=t+1128232|0;break};case 8:case 7:case 6:{E=t+1128233|0;break};case 5:case 4:case 3:{E=t+1128234|0;break};case 2:case 1:case 0:{E=t+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[E]=2;Xlc(m,b,e,f+q|0,g,h,z);t=n;switch(z|0){case 8:case 7:case 6:{F=t+1128233|0;break};case 2:case 1:case 0:{F=t+1128235|0;break};case 12:case 11:case 10:case 9:{F=t+1128232|0;break};case 5:case 4:case 3:{F=t+1128234|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[F]=3;Xlc(m,b,e,f+q|0,g+q|0,h,z)}else if((s|0)==2){if((h|0)!=0){t=k+24300+(y<<4)+8|0;c[t>>2]=(c[t>>2]|0)+1}t=n;switch(z|0){case 5:case 4:case 3:{G=t+1128234|0;break};case 12:case 11:case 10:case 9:{G=t+1128232|0;break};case 2:case 1:case 0:{G=t+1128235|0;break};case 8:case 7:case 6:{G=t+1128233|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[G]=0;Ylc(m,b,e,f,g,h,z);if((g+q|0)<(c[k+10156>>2]|0)){t=n;switch(z|0){case 8:case 7:case 6:{H=t+1128233|0;break};case 2:case 1:case 0:{H=t+1128235|0;break};case 12:case 11:case 10:case 9:{H=t+1128232|0;break};case 5:case 4:case 3:{H=t+1128234|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[H]=1;Ylc(m,b,e,f,g+q|0,h,z)}}else if((s|0)==0){do{if((h|0)!=0){if(!(j>>>0>=3>>>0)){break}s=k+24300+(y<<4)|0;c[s>>2]=(c[s>>2]|0)+1}}while(0);Ylc(m,b,e,f,g,h,z)}else{if(1){}else{Cd(2112096,2539744,1286,2652856)}}do{if((u|0)==3){if((j|0)==3){break}i=l;return}}while(0);u=o;r=z;w=c[777680+(j<<2)>>2]|0;mrc((c[u+50460>>2]|0)+g|0,a[735216+(r<<1)|0]&255|0,w|0)|0;mrc(u+50464+(f&7)|0,a[735217+(r<<1)|0]&255|0,w|0)|0;i=l;return}}while(0);i=l;return}function Ylc(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0;l=i;m=b;b=e;e=f;f=g;g=h;h=j;j=k;k=m+32768|0;do{if(j>>>0<3>>>0){if((d[k+1128235|0]|0|0)<=0){break}i=l;return}}while(0);Flc(m,b,f,g,j);b=k;switch(j|0){case 3:{n=b+1299816+((d[b+1128232|0]|0)*9600|0)+((d[b+1128233|0]|0)*2400|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 1:{n=b+1261416+((d[b+1128232|0]|0)*9600|0)+((d[b+1128233|0]|0)*2400|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 6:{n=b+1376616+((d[b+1128232|0]|0)*2400|0)+((d[b+1128233|0]|0)*600|0)|0;break};case 10:{n=b+1398216+((d[b+1128232|0]|0)*600|0)|0;break};case 11:{n=b+1399416+((d[b+1128232|0]|0)*600|0)|0;break};case 2:{n=b+1223016+((d[b+1128232|0]|0)*9600|0)+((d[b+1128233|0]|0)*2400|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 8:{n=b+1386216+((d[b+1128232|0]|0)*1200|0)+((d[b+1128233|0]|0)*600|0)|0;break};case 7:{n=b+1391016+((d[b+1128232|0]|0)*1200|0)+((d[b+1128233|0]|0)*600|0)|0;break};case 12:{n=b+1400616|0;break};case 4:{n=b+1338216+((d[b+1128232|0]|0)*4800|0)+((d[b+1128233|0]|0)*1200|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 5:{n=b+1357416+((d[b+1128232|0]|0)*4800|0)+((d[b+1128233|0]|0)*1200|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 9:{n=b+1395816+((d[b+1128232|0]|0)*600|0)|0;break};case 0:{n=b+1184616+((d[b+1128232|0]|0)*9600|0)+((d[b+1128233|0]|0)*2400|0)+((d[b+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}Vlc(m,n,f,g,j,h);Wlc(m,e,h,f,g,j);if((h|0)==0){i=l;return}Zlc(m);a[(c[e>>2]|0)+6|0]=127;m=e;c[m>>2]=(c[m>>2]|0)+8;i=l;return}function Zlc(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;e=a;a=e+1434592|0;f=e+57488|0;e=c[c[f+160>>2]>>2]|0;g=a;if((c[g+10108>>2]|0)==0){h=1}else{h=(c[g+10124>>2]|0)!=0}if((h&1|0)!=0){i=b;return}if((Thc(a+13408|0,d[e+13|0]|0,2)|0)==0){h=a+23740|0;g=(c[e+20>>2]|0)>0|0;j=h+12496+((dgc(f)|0)<<3)+(g<<2)|0;c[j>>2]=(c[j>>2]|0)+1;if((g|0)!=0){g=c[e+20>>2]|0;if((c[a+13536>>2]|0)==2){j=(c[e+24>>2]|0)>0|0;k=h+12528+((egc(a,f)|0)<<3)+(j<<2)|0;c[k>>2]=(c[k>>2]|0)+1}if(((c[e+24>>2]|0)>0|0)!=0){e=h+12648+((fgc(a,f)|0)<<3)+(((g|0)==2)<<2)|0;c[e>>2]=(c[e>>2]|0)+1}else{e=h+12568+((ggc(f)|0)<<4)+(((g|0)!=1)<<2)|0;c[e>>2]=(c[e>>2]|0)+1;if((g|0)!=1){e=h+12568+((hgc(f)|0)<<4)+8+(((g|0)!=2)<<2)|0;c[e>>2]=(c[e>>2]|0)+1}}}}i=b;return}function _lc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=a;a=b;c[e>>2]=c[c[a+75256>>2]>>2];c[e+4>>2]=0;b=wrc(c[e>>2]|0,c[e+4>>2]|0,c[h+2050756>>2]<<2,0)|0;c[f>>2]=b;c[f+4>>2]=G;b=Erc(4,0,c[e>>2]|0,c[e+4>>2]|0)|0;j=wrc(b,G,c[h+2050756>>2]|0,0)|0;c[g>>2]=j;c[g+4>>2]=G;j=c[e+4>>2]|0;b=0;if((j|0)>(b|0)|(j|0)==(b|0)&(c[e>>2]|0)>>>0>(c[h+2050756>>2]|0)>>>0){h=c[f+4>>2]|0;e=wrc(c[g>>2]|0,c[g+4>>2]|0,(c[f>>2]|0)>>>1|h<<31,h>>1|((h|0)<0|0?-1:0)<<31)|0;h=Crc(e,G,c[f>>2]|0,c[f+4>>2]|0)|0;c[a+75264>>2]=h-1;i=d;return}else{h=c[g+4>>2]|0;e=wrc(c[f>>2]|0,c[f+4>>2]|0,(c[g>>2]|0)>>>1|h<<31,h>>1|((h|0)<0|0?-1:0)<<31)|0;h=Crc(e,G,c[g>>2]|0,c[g+4>>2]|0)|0;c[a+75264>>2]=1-h;i=d;return}}function $lc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;do{if((b|0)!=0){if(((c[e+20>>2]|0)>0|0)==0){f=0;break}if((c[e+4>>2]|0)==12){f=(c[e+20>>2]|0)!=1?0:0;break}else{f=(c[e>>2]|0)>>>0<3>>>0?0:0;break}}else{f=0}}while(0);i=d;return f|0}function amc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=a;a=b;b=c[a+4>>2]|0;f=c[a+16>>2]|0;g=c[a>>2]|0;if(!(g>>>0<3>>>0)){h=e+((c[564816+(g<<2)>>2]|0)*40|0)+(b<<2)|0;c[h>>2]=(c[h>>2]|0)+1;j=f;k=b;l=e;m=l+160|0;n=m+(k*40|0)|0;o=n+(j<<2)|0;p=c[o>>2]|0;q=p+1|0;c[o>>2]=q;i=d;return}h=c[777792+(g<<2)>>2]|0;r=c[777848+(g<<2)>>2]|0;g=0;while(1){if((g|0)>=2){break}s=0;while(1){if((s|0)>=2){break}t=e+(c[a+76+(((g<<1)+s|0)*12|0)>>2]<<2)|0;c[t>>2]=(c[t>>2]|0)+1;s=s+h|0}g=g+r|0}j=f;k=b;l=e;m=l+160|0;n=m+(k*40|0)|0;o=n+(j<<2)|0;p=c[o>>2]|0;q=p+1|0;c[o>>2]=q;i=d;return}function bmc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=a;a=b;c[e>>2]=c[c[a+75256>>2]>>2];c[e+4>>2]=0;b=wrc(c[e>>2]|0,c[e+4>>2]|0,c[h+2050756>>2]<<1,0)|0;c[f>>2]=b;c[f+4>>2]=G;b=Erc(2,0,c[e>>2]|0,c[e+4>>2]|0)|0;e=wrc(b,G,c[h+2050756>>2]|0,0)|0;c[g>>2]=e;c[g+4>>2]=G;e=c[a+75248>>2]|0;b=Erc(e,(e|0)<0|0?-1:0,c[g>>2]|0,c[g+4>>2]|0)|0;g=c[f+4>>2]|0;e=wrc(b,G,(c[f>>2]|0)>>>1|g<<31,g>>1|((g|0)<0|0?-1:0)<<31)|0;g=Crc(e,G,c[f>>2]|0,c[f+4>>2]|0)|0;c[a+75248>>2]=g;c[a+75232>>2]=((c[a+75248>>2]|0)*100|0|0)/((c[a+75244>>2]|0)*110|0|0)|0;g=a+75232|0;c[g>>2]=(c[g>>2]|0)+((c[a+75232>>2]|0)==0);_lc(h,a);i=d;return}function cmc(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=b;b=g;g=j+1434592|0;k=c[g+10144>>2]|0;l=c[g+10152>>2]|0;g=e>>1;e=f>>1;f=c[777680+(b<<2)>>2]>>1;m=c[777736+(b<<2)>>2]>>1;if(b>>>0<=6>>>0){b=(ca(g,l)|0)+e|0;n=d[(c[j+2047220>>2]|0)+b|0]|0;o=n;i=h;return o|0}b=0;a:while(1){if((b|0)>=(m|0)){p=16;break}q=0;while(1){if((q|0)>=(f|0)){break}r=g+b|0;s=e+q|0;do{if((r|0)>=(k|0)){p=9}else{if((s|0)>=(l|0)){p=9;break}t=(ca(r,l)|0)+s|0;if((a[(c[j+2047220>>2]|0)+t|0]|0)!=0){p=11;break a}}}while(0);if((p|0)==9){p=0}q=q+1|0}b=b+1|0}if((p|0)==11){n=1;o=n;i=h;return o|0}else if((p|0)==16){n=0;o=n;i=h;return o|0}return 0}function dmc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b;b=d;d=e;e=a+57488|0;a=8;h=8;j=0;k=0;while(1){if((k|0)>=(h|0)){break}l=0;while(1){if((l|0)>=(a|0)){break}m=c[g+(j+l<<2)>>2]|0;if((m|0)!=0){n=c[m>>2]|0}else{n=0}m=n;if((c[b>>2]|0)>>>0<m>>>0){o=c[b>>2]|0}else{o=m}c[b>>2]=o;if((c[d>>2]|0)>>>0>m>>>0){p=c[d>>2]|0}else{p=m}c[d>>2]=p;l=l+1|0}j=j+(c[e+156>>2]|0)|0;k=k+1|0}i=f;return}function emc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=a;a=b;b=d;d=e;e=f;do{if((a|0)>0){if((b|0)<=0){break}while(1){if(!(h>>>0>0>>>0)){break}c[d>>2]=c[777736+(h<<2)>>2];c[e>>2]=c[777680+(h<<2)>>2];if((c[d>>2]|0)<=(a|0)){if((c[e>>2]|0)<=(b|0)){f=11;break}}h=h-3|0}j=h;k=j;i=g;return k|0}}while(0);if(h>>>0<3>>>0){l=h}else{l=3}j=l;k=j;i=g;return k|0}function fmc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+24|0;e=d|0;jmc(a,b,e);olc(c[e+4>>2]|0,c[e+8>>2]|0,(c[e>>2]|0)+24|0);olc(c[e+12>>2]|0,c[e+16>>2]|0,(c[e>>2]|0)+48|0);olc(c[e+4>>2]|0,c[e+12>>2]|0,(c[e>>2]|0)+72|0);olc(c[e+8>>2]|0,c[e+16>>2]|0,(c[e>>2]|0)+96|0);olc((c[e>>2]|0)+72|0,(c[e>>2]|0)+96|0,c[e>>2]|0);i=d;return}function gmc(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+40|0;j=h|0;k=h+24|0;l=h+32|0;m=a;a=d;d=e;e=f;f=g;g=m+1434592|0;n=c[777680+(d<<2)>>2]|0;o=c[777736+(d<<2)>>2]|0;c[k>>2]=25;c[k+4>>2]=0;k=c[m+1444760>>2]|0;p=Erc(25,0,k,(k|0)<0|0?-1:0)|0;c[l>>2]=p;c[l+4>>2]=G;if((o|0)==(n|0)){}else{Cd(2465112,2539744,416,2651272);return 0}jmc(b,d,j);do{if((f+((n|0)/2|0)|0)<(c[g+10156>>2]|0)){if((e+((o|0)/2|0)|0)>=(c[g+10148>>2]|0)){break}b=c[(c[j>>2]|0)+20>>2]|0;p=(b|0)<0|0?-1:0;k=c[l+4>>2]|0;if(!((p|0)<(k|0)|(p|0)==(k|0)&b>>>0<(c[l>>2]|0)>>>0)){break}hmc(m,a,e,f,d);q=1;r=q;i=h;return r|0}}while(0);do{if((e+((o|0)/2|0)|0)<(c[g+10148>>2]|0)){b=c[(c[j>>2]|0)+92>>2]|0;k=(b|0)<0|0?-1:0;p=c[l+4>>2]|0;if(!((k|0)<(p|0)|(k|0)==(p|0)&b>>>0<(c[l>>2]|0)>>>0)){break}b=c[(c[j>>2]|0)+116>>2]|0;p=(b|0)<0|0?-1:0;k=c[l+4>>2]|0;if(!((p|0)<(k|0)|(p|0)==(k|0)&b>>>0<(c[l>>2]|0)>>>0)){break}b=c[552416+(2*52|0)+(d<<2)>>2]|0;if(!(b>>>0<13>>>0)){Cd(2509776,2559560,248,2652192);return 0}k=b;hmc(m,a,e,f,k);hmc(m,a,e,f+((n|0)/2|0)|0,k);q=1;r=q;i=h;return r|0}}while(0);do{if((f+((n|0)/2|0)|0)<(c[g+10156>>2]|0)){k=c[(c[j>>2]|0)+44>>2]|0;b=(k|0)<0|0?-1:0;p=c[l+4>>2]|0;if(!((b|0)<(p|0)|(b|0)==(p|0)&k>>>0<(c[l>>2]|0)>>>0)){break}k=c[(c[j>>2]|0)+68>>2]|0;p=(k|0)<0|0?-1:0;b=c[l+4>>2]|0;if(!((p|0)<(b|0)|(p|0)==(b|0)&k>>>0<(c[l>>2]|0)>>>0)){break}k=c[552416+(1*52|0)+(d<<2)>>2]|0;if(!(k>>>0<13>>>0)){Cd(2509776,2559560,248,2652192);return 0}b=k;hmc(m,a,e,f,b);hmc(m,a,e+((o|0)/2|0)|0,f,b);q=1;r=q;i=h;return r|0}}while(0);q=0;r=q;i=h;return r|0}function hmc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;b=i;g=a;a=d;d=e;e=f;if((c[g+1444748>>2]|0)<=(d|0)){i=b;return}if((c[g+1444740>>2]|0)<=(a|0)){i=b;return}f=g+57488|0;h=g+1434592|0;j=f;k=(ca(c[j+156>>2]|0,a)|0)+d|0;c[j+160>>2]=(c[h+10204>>2]|0)+(k<<2);c[c[j+160>>2]>>2]=(c[h+10188>>2]|0)+(k*124|0);c[c[c[f+160>>2]>>2]>>2]=e;imc(g+1434592|0,f,a,d,e);i=b;return}function imc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=a;a=b;b=d;d=e;e=f;f=c[777680+(e<<2)>>2]|0;j=c[777736+(e<<2)>>2]|0;e=0;while(1){if((e|0)>=(j|0)){break}k=0;while(1){if((k|0)>=(f|0)){break}do{if((b+e|0)<(c[h+10148>>2]|0)){if((d+k|0)>=(c[h+10156>>2]|0)){break}l=(ca(e,c[a+156>>2]|0)|0)+k|0;c[(c[a+160>>2]|0)+(l<<2)>>2]=c[c[a+160>>2]>>2]}}while(0);k=k+1|0}e=e+1|0}i=g;return}function jmc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=d;d=b;if((d|0)==3){b=f;c[a>>2]=b;g=0;while(1){if((g|0)>=4){break}c[a+4+(g<<2)>>2]=b+120+(g*24|0);g=g+1|0}i=e;return}else if((d|0)==9){b=f;c[a>>2]=b;g=0;while(1){if((g|0)>=4){break}c[a+4+(g<<2)>>2]=b+120+(g*984|0);g=g+1|0}i=e;return}else if((d|0)==12){b=f;c[a>>2]=b;g=0;while(1){if((g|0)>=4){break}c[a+4+(g<<2)>>2]=b+120+(g*4056|0);g=g+1|0}i=e;return}else if((d|0)==6){d=f;c[a>>2]=d;g=0;while(1){if((g|0)>=4){break}c[a+4+(g<<2)>>2]=d+120+(g*216|0);g=g+1|0}i=e;return}else{Cd(2524984,2539744,368,2651152)}}function kmc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+8|0;h=g|0;j=a;a=b;b=d;d=e;e=f;f=j;k=f+1434592|0;l=f;f=1;do{if((f|0)==1){m=c[l+1472132>>2]|0}else{if((f|0)==2){m=c[l+1472136>>2]|0;break}else{m=c[l+1472140>>2]|0;break}}}while(0);l=k+8488+((c[k+9784+(m<<2)>>2]|0)*108|0)+16|0;m=(ca(b<<3,c[l+16>>2]|0)|0)+(d<<3)|0;d=Xe[c[j+2047252+(e*44|0)+8>>2]&511](c[a>>2]|0,c[a+4>>2]|0,(c[l+52>>2]|0)+m|0,c[l+16>>2]|0,h)|0;i=g;return(d+(1<<(c[777552+(e<<2)>>2]|0)-1)|0)>>>((c[777552+(e<<2)>>2]|0)>>>0)|0}function lmc(b,e,f,g,h,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;o=i;i=i+16|0;p=o|0;q=o+8|0;r=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=r+1434592|0;s=r+32768|0;t=s+24720|0;u=c[1960336+(j<<2)>>2]|0;v=(1<<u|0)/4|0;w=c[n+10160>>2]|0;c[p>>2]=2147483647;c[q>>2]=-1;c[q+4>>2]=2147483647;do{if((g|0)<(c[n+10148>>2]|0)){if((h|0)>=(c[n+10156>>2]|0)){break}if(j>>>0>=3>>>0){x=c[c[e>>2]>>2]|0}else{x=0}y=x;z=734952+(u*52|0)+(y<<2)|0;A=d[z]|d[z+1|0]<<8|d[z+2|0]<<16|d[z+3|0]<<24|0;if((A|0)==1){z=s;switch(y|0){case 5:case 4:case 3:{B=z+1128234|0;break};case 12:case 11:case 10:case 9:{B=z+1128232|0;break};case 8:case 7:case 6:{B=z+1128233|0;break};case 2:case 1:case 0:{B=z+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[B]=0;pmc(r,b,g,h,l,m,y);z=s;switch(y|0){case 9:{C=z+1395816+((d[z+1128232|0]|0)*600|0)|0;break};case 0:{C=z+1184616+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 1:{C=z+1261416+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 7:{C=z+1391016+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 2:{C=z+1223016+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 5:{C=z+1357416+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 6:{C=z+1376616+((d[z+1128232|0]|0)*2400|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 11:{C=z+1399416+((d[z+1128232|0]|0)*600|0)|0;break};case 4:{C=z+1338216+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 3:{C=z+1299816+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 12:{C=z+1400616|0;break};case 8:{C=z+1386216+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 10:{C=z+1398216+((d[z+1128232|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(C|0,c[c[t+160>>2]>>2]|0,76)|0;if((g+v|0)<(c[n+10148>>2]|0)){z=s;switch(y|0){case 12:case 11:case 10:case 9:{D=z+1128232|0;break};case 2:case 1:case 0:{D=z+1128235|0;break};case 8:case 7:case 6:{D=z+1128233|0;break};case 5:case 4:case 3:{D=z+1128234|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[D]=1;pmc(r,b,g+v|0,h,p,q,y);z=s;switch(y|0){case 10:{E=z+1398216+((d[z+1128232|0]|0)*600|0)|0;break};case 9:{E=z+1395816+((d[z+1128232|0]|0)*600|0)|0;break};case 6:{E=z+1376616+((d[z+1128232|0]|0)*2400|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 8:{E=z+1386216+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 4:{E=z+1338216+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 3:{E=z+1299816+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 11:{E=z+1399416+((d[z+1128232|0]|0)*600|0)|0;break};case 7:{E=z+1391016+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 5:{E=z+1357416+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 0:{E=z+1184616+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 2:{E=z+1223016+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 1:{E=z+1261416+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 12:{E=z+1400616|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(E|0,c[e>>2]|0,76)|0;do{if((c[p>>2]|0)!=2147483647){if(!((c[q>>2]|0)!=(-1|0)|(c[q+4>>2]|0)!=2147483647)){break}if((c[l>>2]|0)==2147483647){break}z=m;if(!((c[z>>2]|0)!=(-1|0)|(c[z+4>>2]|0)!=2147483647)){break}z=l;c[z>>2]=(c[z>>2]|0)+(c[p>>2]|0);z=m;F=wrc(c[z>>2]|0,c[z+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[z>>2]=F;c[z+4>>2]=G}}while(0)}}else if((A|0)==3){z=c[552416+(3*52|0)+(j<<2)>>2]|0;if(!(z>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}y=z;z=s;switch(y|0){case 12:case 11:case 10:case 9:{H=z+1128232|0;break};case 5:case 4:case 3:{H=z+1128234|0;break};case 8:case 7:case 6:{H=z+1128233|0;break};case 2:case 1:case 0:{H=z+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[H]=0;lmc(r,b,e,f,g,h,y,k,l,m);z=s;switch(y|0){case 12:case 11:case 10:case 9:{I=z+1128232|0;break};case 5:case 4:case 3:{I=z+1128234|0;break};case 2:case 1:case 0:{I=z+1128235|0;break};case 8:case 7:case 6:{I=z+1128233|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[I]=1;lmc(r,b,e+(v<<2)|0,f,g,h+v|0,y,k,p,q);do{if((c[p>>2]|0)!=2147483647){if(!((c[q>>2]|0)!=(-1|0)|(c[q+4>>2]|0)!=2147483647)){break}if((c[l>>2]|0)==2147483647){break}z=m;if(!((c[z>>2]|0)!=(-1|0)|(c[z+4>>2]|0)!=2147483647)){break}z=l;c[z>>2]=(c[z>>2]|0)+(c[p>>2]|0);z=m;F=wrc(c[z>>2]|0,c[z+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[z>>2]=F;c[z+4>>2]=G}}while(0);z=s;switch(y|0){case 5:case 4:case 3:{J=z+1128234|0;break};case 2:case 1:case 0:{J=z+1128235|0;break};case 12:case 11:case 10:case 9:{J=z+1128232|0;break};case 8:case 7:case 6:{J=z+1128233|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[J]=2;lmc(r,b,e+((ca(v,w)|0)<<2)|0,f,g+v|0,h,y,k,p,q);do{if((c[p>>2]|0)!=2147483647){if(!((c[q>>2]|0)!=(-1|0)|(c[q+4>>2]|0)!=2147483647)){break}if((c[l>>2]|0)==2147483647){break}z=m;if(!((c[z>>2]|0)!=(-1|0)|(c[z+4>>2]|0)!=2147483647)){break}z=l;c[z>>2]=(c[z>>2]|0)+(c[p>>2]|0);z=m;F=wrc(c[z>>2]|0,c[z+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[z>>2]=F;c[z+4>>2]=G}}while(0);z=s;switch(y|0){case 5:case 4:case 3:{K=z+1128234|0;break};case 2:case 1:case 0:{K=z+1128235|0;break};case 12:case 11:case 10:case 9:{K=z+1128232|0;break};case 8:case 7:case 6:{K=z+1128233|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[K]=3;lmc(r,b,e+((ca(v,w)|0)<<2)+(v<<2)|0,f,g+v|0,h+v|0,y,k,p,q);do{if((c[p>>2]|0)!=2147483647){if(!((c[q>>2]|0)!=(-1|0)|(c[q+4>>2]|0)!=2147483647)){break}if((c[l>>2]|0)==2147483647){break}z=m;if(!((c[z>>2]|0)!=(-1|0)|(c[z+4>>2]|0)!=2147483647)){break}z=l;c[z>>2]=(c[z>>2]|0)+(c[p>>2]|0);z=m;F=wrc(c[z>>2]|0,c[z+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[z>>2]=F;c[z+4>>2]=G}}while(0)}else if((A|0)==0){pmc(r,b,g,h,l,m,y);z=s;switch(y|0){case 9:{L=z+1395816+((d[z+1128232|0]|0)*600|0)|0;break};case 7:{L=z+1391016+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 12:{L=z+1400616|0;break};case 6:{L=z+1376616+((d[z+1128232|0]|0)*2400|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 0:{L=z+1184616+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 11:{L=z+1399416+((d[z+1128232|0]|0)*600|0)|0;break};case 2:{L=z+1223016+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 3:{L=z+1299816+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 10:{L=z+1398216+((d[z+1128232|0]|0)*600|0)|0;break};case 1:{L=z+1261416+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 4:{L=z+1338216+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 5:{L=z+1357416+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 8:{L=z+1386216+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(L|0,c[c[t+160>>2]>>2]|0,76)|0}else if((A|0)==2){z=s;switch(y|0){case 12:case 11:case 10:case 9:{M=z+1128232|0;break};case 8:case 7:case 6:{M=z+1128233|0;break};case 2:case 1:case 0:{M=z+1128235|0;break};case 5:case 4:case 3:{M=z+1128234|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[M]=0;pmc(r,b,g,h,l,m,y);z=s;switch(y|0){case 5:{N=z+1357416+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 12:{N=z+1400616|0;break};case 4:{N=z+1338216+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 1:{N=z+1261416+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 3:{N=z+1299816+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 8:{N=z+1386216+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 10:{N=z+1398216+((d[z+1128232|0]|0)*600|0)|0;break};case 11:{N=z+1399416+((d[z+1128232|0]|0)*600|0)|0;break};case 2:{N=z+1223016+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 9:{N=z+1395816+((d[z+1128232|0]|0)*600|0)|0;break};case 0:{N=z+1184616+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 7:{N=z+1391016+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 6:{N=z+1376616+((d[z+1128232|0]|0)*2400|0)+((d[z+1128233|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(N|0,c[c[t+160>>2]>>2]|0,76)|0;if((h+v|0)<(c[n+10156>>2]|0)){z=s;switch(y|0){case 12:case 11:case 10:case 9:{O=z+1128232|0;break};case 8:case 7:case 6:{O=z+1128233|0;break};case 5:case 4:case 3:{O=z+1128234|0;break};case 2:case 1:case 0:{O=z+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[O]=1;pmc(r,b,g,h+v|0,p,q,y);z=s;switch(y|0){case 8:{P=z+1386216+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 1:{P=z+1261416+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 2:{P=z+1223016+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 5:{P=z+1357416+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 12:{P=z+1400616|0;break};case 6:{P=z+1376616+((d[z+1128232|0]|0)*2400|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 9:{P=z+1395816+((d[z+1128232|0]|0)*600|0)|0;break};case 3:{P=z+1299816+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 10:{P=z+1398216+((d[z+1128232|0]|0)*600|0)|0;break};case 4:{P=z+1338216+((d[z+1128232|0]|0)*4800|0)+((d[z+1128233|0]|0)*1200|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 7:{P=z+1391016+((d[z+1128232|0]|0)*1200|0)+((d[z+1128233|0]|0)*600|0)|0;break};case 0:{P=z+1184616+((d[z+1128232|0]|0)*9600|0)+((d[z+1128233|0]|0)*2400|0)+((d[z+1128234|0]|0)*600|0)|0;break};case 11:{P=z+1399416+((d[z+1128232|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(P|0,c[c[t+160>>2]>>2]|0,76)|0;do{if((c[p>>2]|0)!=2147483647){if(!((c[q>>2]|0)!=(-1|0)|(c[q+4>>2]|0)!=2147483647)){break}if((c[l>>2]|0)==2147483647){break}z=m;if(!((c[z>>2]|0)!=(-1|0)|(c[z+4>>2]|0)!=2147483647)){break}z=l;c[z>>2]=(c[z>>2]|0)+(c[p>>2]|0);z=m;F=wrc(c[z>>2]|0,c[z+4>>2]|0,c[q>>2]|0,c[q+4>>2]|0)|0;c[z>>2]=F;c[z+4>>2]=G}}while(0)}}else{if(1){}else{Cd(2112096,2539744,3143,2651856)}}if((j|0)!=12){i=o;return}if((k|0)==0){i=o;return}if((c[r+1471728>>2]|0)==3){y=c[l>>2]|0;A=m;Zjc(c[r+2047228>>2]|0,y,(y|0)<0|0?-1:0,c[A>>2]|0,c[A+4>>2]|0)}rmc(r,b,f,g,h,1,j);i=o;return}}while(0);i=o;return}function mmc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=i;i=i+112|0;h=g|0;j=g+48|0;k=g+96|0;l=g+104|0;m=a;a=b;b=d;d=e;e=f;f=m+1434592|0;n=m+32768|0;o=c[f+10160>>2]|0;p=(c[a+4>>2]|0)-d|0;q=(c[a+12>>2]|0)-e|0;a=(c[f+10188>>2]|0)+((ca(d,o)|0)*124|0)+(e*124|0)|0;qlc(n,c[m+1471904>>2]|0,d,e);if((p|0)>0){if((q|0)>0){}else{r=3}}else{r=3}if((r|0)==3){Cd(2414248,2539744,1458,2651296)}do{if((q|0)>=8){if((p|0)<8){break}s=c[n+8208>>2]|0;t=c[(c[m+1471908>>2]|0)+16>>2]|0;u=c[n+8204>>2]|0;v=(ca(d<<3,t)|0)+(e<<3)|0;w=(c[(c[m+1471908>>2]|0)+52>>2]|0)+v|0;v=c[m+2047160>>2]|0;x=v<<1;y=0;z=0;while(1){if((z|0)>=4){break}A=0;while(1){if((A|0)>=4){break}B=c[1637144+((z<<2)+A<<3)>>2]|0;C=c[1637148+((z<<2)+A<<3)>>2]|0;D=(ca(B<<3,s)|0)+(C<<3)|0;P6b(u+D|0,s,w+D|0,t,j+(A*12|0)|0,j+(A*12|0)+4|0);c[j+(A*12|0)+8>>2]=(c[j+(A*12|0)>>2]|0)-((ca(c[j+(A*12|0)+4>>2]|0,c[j+(A*12|0)+4>>2]|0)|0)>>>8);E=(ca(B,o)|0)+C|0;c[b+(E<<2)>>2]=a+(E*124|0);c[c[b+(E<<2)>>2]>>2]=6;A=A+1|0}do{if((c[j+8>>2]|0)>>>0<v>>>0){if(!((c[j+20>>2]|0)>>>0<v>>>0)){r=23;break}if(!((c[j+32>>2]|0)>>>0<v>>>0)){r=23;break}if(!((c[j+44>>2]|0)>>>0<v>>>0)){r=23;break}c[h+(z*12|0)>>2]=c[j>>2];c[h+(z*12|0)+4>>2]=c[j+4>>2];A=1;while(1){if((A|0)>=4){break}C=h+(z*12|0)|0;c[C>>2]=(c[C>>2]|0)+(c[j+(A*12|0)>>2]|0);C=h+(z*12|0)+4|0;c[C>>2]=(c[C>>2]|0)+(c[j+(A*12|0)+4>>2]|0);A=A+1|0}C=c[h+(z*12|0)>>2]|0;B=c[h+(z*12|0)+4>>2]|0;D=c[h+(z*12|0)+4>>2]|0;F=Erc(B,(B|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;D=G;B=xrc(C,0,F>>>10|D<<22,D>>10|((D|0)<0|0?-1:0)<<22)|0;c[h+(z*12|0)+8>>2]=B;B=ca(c[1637144+(z<<2<<3)>>2]|0,o)|0;E=B+(c[1637148+(z<<2<<3)>>2]|0)|0;c[b+(E<<2)>>2]=a+(E*124|0);c[c[b+(E<<2)>>2]>>2]=9;if(((((c[f+36948>>2]|0)-1|0)>>>0)%((c[m+2047156>>2]|0)>>>0)|0|0)==0){B=m+2055624|0;c[B>>2]=(c[B>>2]|0)+1}}else{r=23}}while(0);if((r|0)==23){r=0;y=1}z=z+1|0}if((y|0)==0){do{if((c[h+8>>2]|0)>>>0<x>>>0){if(!((c[h+20>>2]|0)>>>0<x>>>0)){break}if(!((c[h+32>>2]|0)>>>0<x>>>0)){break}if(!((c[h+44>>2]|0)>>>0<x>>>0)){break}c[b>>2]=a;c[c[b>>2]>>2]=12}}while(0)}i=g;return}}while(0);h=6;c[k>>2]=c[777736+(h<<2)>>2];c[l>>2]=c[777680+(h<<2)>>2];r=0;while(1){if((r|0)>=8){break}m=0;while(1){if((m|0)>=8){break}f=(ca(r,o)|0)+m|0;c[b+(f<<2)>>2]=a+(f*124|0);E=emc(h,p-r|0,q-m|0,k,l)|0;c[c[b+(f<<2)>>2]>>2]=E;m=m+(c[l>>2]|0)|0}r=r+(c[k>>2]|0)|0}i=g;return}function nmc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=i;e=a;a=kmc(e,e+40972|0,b,c,12)|0;do{if(a>>>0<4>>>0){f=12}else{if(a>>>0<10>>>0){f=9;break}else{f=6;break}}}while(0);i=d;return f|0}function omc(b,e,f,g,h,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;p=i;i=i+64|0;q=p|0;r=p+8|0;s=p+16|0;t=p+24|0;u=p+32|0;v=p+40|0;w=p+48|0;x=p+56|0;y=b;b=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;c[q>>2]=n;c[q+4>>2]=o;o=y+1434592|0;n=y+32768|0;m=n+24720|0;z=(c[777680+(h<<2)>>2]|0)/2|0;A=c[e>>2]|0;B=n;switch(h|0){case 2:{C=B+1223016+((d[B+1128232|0]|0)*9600|0)+((d[B+1128233|0]|0)*2400|0)+((d[B+1128234|0]|0)*600|0)|0;break};case 11:{C=B+1399416+((d[B+1128232|0]|0)*600|0)|0;break};case 9:{C=B+1395816+((d[B+1128232|0]|0)*600|0)|0;break};case 0:{C=B+1184616+((d[B+1128232|0]|0)*9600|0)+((d[B+1128233|0]|0)*2400|0)+((d[B+1128234|0]|0)*600|0)|0;break};case 5:{C=B+1357416+((d[B+1128232|0]|0)*4800|0)+((d[B+1128233|0]|0)*1200|0)+((d[B+1128234|0]|0)*600|0)|0;break};case 7:{C=B+1391016+((d[B+1128232|0]|0)*1200|0)+((d[B+1128233|0]|0)*600|0)|0;break};case 4:{C=B+1338216+((d[B+1128232|0]|0)*4800|0)+((d[B+1128233|0]|0)*1200|0)+((d[B+1128234|0]|0)*600|0)|0;break};case 6:{C=B+1376616+((d[B+1128232|0]|0)*2400|0)+((d[B+1128233|0]|0)*600|0)|0;break};case 10:{C=B+1398216+((d[B+1128232|0]|0)*600|0)|0;break};case 8:{C=B+1386216+((d[B+1128232|0]|0)*1200|0)+((d[B+1128233|0]|0)*600|0)|0;break};case 3:{C=B+1299816+((d[B+1128232|0]|0)*9600|0)+((d[B+1128233|0]|0)*2400|0)+((d[B+1128234|0]|0)*600|0)|0;break};case 12:{C=B+1400616|0;break};case 1:{C=B+1261416+((d[B+1128232|0]|0)*9600|0)+((d[B+1128233|0]|0)*2400|0)+((d[B+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}B=C;C=0;D=2147483647;c[t>>2]=0;c[t+4>>2]=0;c[u>>2]=-1;c[u+4>>2]=2147483647;c[v>>2]=0;c[v+4>>2]=0;E=h>>>0>=3>>>0|0;F=1;H=(f+z|0)>=(c[o+10148>>2]|0)|0;I=(g+z|0)>=(c[o+10156>>2]|0)|0;J=c[n+24780>>2]|0;K=c[n+24784>>2]|0;if((H|0)!=0){L=0}else{L=(I|0)!=0^1}M=L&1;do{if((I|0)!=0){N=0}else{if((K|0)>(J|0)){N=0;break}N=h>>>0>=3>>>0}}while(0);L=N&1;do{if((H|0)!=0){O=0}else{if((J|0)>(K|0)){O=0;break}O=h>>>0>=3>>>0}}while(0);K=O&1;do{if(h>>>0<3>>>0){if((d[n+1128235|0]|0)==0){break}c[j>>2]=0;O=k;c[O>>2]=0;c[O+4>>2]=0;i=p;return}}while(0);if((c[777680+(h<<2)>>2]|0)==(c[777736+(h<<2)>>2]|0)){}else{Cd(2336248,2539744,2821,2651880)}c[n+1129284>>2]=Plc(y,n,f,g,h)|0;if((c[y+2046976>>2]|0)!=0){if(h>>>0<=(c[y+2046984>>2]|0)>>>0){P=h>>>0>=(c[y+2046980>>2]|0)>>>0}else{P=0}M=M&(P&1);if(h>>>0<=(c[y+2046984>>2]|0)>>>0){if(h>>>0>(c[y+2046980>>2]|0)>>>0){Q=1}else{R=35}}else{R=35}if((R|0)==35){Q=(H|0)!=0}L=L&(Q&1);if(h>>>0<=(c[y+2046984>>2]|0)>>>0){if(h>>>0>(c[y+2046980>>2]|0)>>>0){S=1}else{R=38}}else{R=38}if((R|0)==38){S=(I|0)!=0}K=K&(S&1);E=E&h>>>0>(c[y+2046980>>2]|0)>>>0}if((c[y+2046972>>2]|0)!=0){L=L&H;K=K&I}do{if((c[n+1129284>>2]|0)==0){if((L|0)==0){if((K|0)==0){break}}E=0}}while(0);if((M|0)!=0){pmc(y,b,f,g,r,s,h);nrc(B|0,c[c[m+160>>2]>>2]|0,76)|0;if((c[r>>2]|0)!=2147483647){I=m;H=h;S=(c[I+50460>>2]|0)+g|0;Q=I+50464+(f&7)|0;I=c[830920+(H<<2)>>2]|0;P=1<<I;O=0;J=0;if((c[1960336+(H<<2)>>2]|0)!=(c[1960696+(H<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((I|0)<0){Cd(2473496,2485024,330,2651704)}H=0;while(1){if((H|0)>=(P|0)){break}O=O|a[S+H|0];J=J|a[Q+H|0];H=H+1|0}O=(O&P|0)>0|0;J=(J&P|0)>0|0;c[r>>2]=(c[r>>2]|0)+(c[n+1401216+((J<<1)+O+(I<<2)<<4)>>2]|0);I=c[r>>2]|0;O=c[n+75248>>2]|0;J=Erc(I,(I|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;O=wrc(128,0,J,G)|0;J=G;I=yrc(c[s>>2]|0,c[s+4>>2]|0,c[n+75244>>2]|0)|0;P=wrc(O>>>8|J<<24,J>>8|((J|0)<0|0?-1:0)<<24,I,G)|0;c[v>>2]=P;c[v+4>>2]=G;P=c[v+4>>2]|0;I=c[q+4>>2]|0;if((P|0)<(I|0)|(P|0)==(I|0)&(c[v>>2]|0)>>>0<(c[q>>2]|0)>>>0){c[w>>2]=4096;c[w+4>>2]=0;D=c[r>>2]|0;I=c[s+4>>2]|0;c[u>>2]=c[s>>2];c[u+4>>2]=I;I=c[v+4>>2]|0;c[q>>2]=c[v>>2];c[q+4>>2]=I;if(h>>>0>=3>>>0){c[(Tlc(n,h)|0)>>2]=h}I=Arc(c[w>>2]|0,c[w+4>>2]|0,8-((c[1960336+(h<<2)>>2]|0)+(c[1960696+(h<<2)>>2]|0))|0)|0;c[w>>2]=I;c[w+4>>2]=G;I=c[n+75248>>2]|0;P=Erc(0,0,I,(I|0)<0|0?-1:0)|0;I=wrc(128,0,P,G)|0;P=G;J=yrc(c[w>>2]|0,c[w+4>>2]|0,c[n+75244>>2]|0)|0;w=wrc(I>>>8|P<<24,P>>8|((P|0)<0|0?-1:0)<<24,J,G)|0;c[x>>2]=w;c[x+4>>2]=G;do{if((c[n+50528>>2]|0)==0){w=c[q+4>>2]|0;J=c[x+4>>2]|0;if(!((w|0)<(J|0)|(w|0)==(J|0)&(c[q>>2]|0)>>>0<(c[x>>2]|0)>>>0)){break}E=0;F=0}}while(0)}}if((c[n+1129284>>2]|0)==0){E=0;F=0}}x=B+576|0;J=n+1184596|0;c[x>>2]=c[J>>2];c[x+4>>2]=c[J+4>>2];c[x+8>>2]=c[J+8>>2];c[x+12>>2]=c[J+12>>2];c[v>>2]=0;c[v+4>>2]=0;if((E|0)!=0){E=m;J=h;x=(c[E+50460>>2]|0)+g|0;w=E+50464+(f&7)|0;E=c[830920+(J<<2)>>2]|0;P=1<<E;I=0;O=0;if((c[1960336+(J<<2)>>2]|0)!=(c[1960696+(J<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((E|0)<0){Cd(2473496,2485024,330,2651704)}J=0;while(1){if((J|0)>=(P|0)){break}I=I|a[x+J|0];O=O|a[w+J|0];J=J+1|0}I=(I&P|0)>0|0;O=(O&P|0)>0|0;C=C+(c[n+1401216+((O<<1)+I+(E<<2)<<4)+12>>2]|0)|0;E=c[552416+(3*52|0)+(h<<2)>>2]|0;if(!(E>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}T=E;E=0;a:while(1){if((E|0)<4){I=c[v+4>>2]|0;O=c[q+4>>2]|0;U=(I|0)<(O|0)|(I|0)==(O|0)&(c[v>>2]|0)>>>0<(c[q>>2]|0)>>>0}else{U=0}if(!U){break}O=ca(E&1,z)|0;I=ca(E>>1,z)|0;do{if((f+I|0)>=(c[o+10148>>2]|0)){R=82}else{if((g+O|0)>=(c[o+10156>>2]|0)){R=82;break}P=n;switch(T|0){case 2:case 1:case 0:{V=P+1128235|0;break};case 12:case 11:case 10:case 9:{V=P+1128232|0;break};case 8:case 7:case 6:{V=P+1128233|0;break};case 5:case 4:case 3:{V=P+1128234|0;break};default:{R=88;break a}}a[V]=E;P=n+1184596|0;J=B+576|0;c[P>>2]=c[J>>2];c[P+4>>2]=c[J+4>>2];c[P+8>>2]=c[J+8>>2];c[P+12>>2]=c[J+12>>2];J=xrc(c[q>>2]|0,c[q+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;omc(y,b,e,f+I|0,g+O|0,T,r,s,0,J,G);if((c[r>>2]|0)==2147483647){c[v>>2]=-1;c[v+4>>2]=2147483647}else{C=C+(c[r>>2]|0)|0;J=wrc(c[t>>2]|0,c[t+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;c[t>>2]=J;c[t+4>>2]=G;J=C;P=c[n+75248>>2]|0;w=Erc(J,(J|0)<0|0?-1:0,P,(P|0)<0|0?-1:0)|0;P=wrc(128,0,w,G)|0;w=G;J=yrc(c[t>>2]|0,c[t+4>>2]|0,c[n+75244>>2]|0)|0;x=wrc(P>>>8|w<<24,w>>8|((w|0)<0|0?-1:0)<<24,J,G)|0;c[v>>2]=x;c[v+4>>2]=G}}}while(0);if((R|0)==82){R=0}E=E+1|0}if((R|0)==88){Cd(2524984,2539744,71,2652264)}R=c[v+4>>2]|0;E=c[q+4>>2]|0;if((R|0)<(E|0)|(R|0)==(E|0)&(c[v>>2]|0)>>>0<(c[q>>2]|0)>>>0){D=C;E=c[t+4>>2]|0;c[u>>2]=c[t>>2];c[u+4>>2]=E;E=c[v+4>>2]|0;c[q>>2]=c[v>>2];c[q+4>>2]=E;c[(Tlc(n,h)|0)>>2]=T}else{if((c[y+2046968>>2]|0)!=0){F=F&(((M|0)!=0^1)&1)}}}do{if((L|0)!=0){if((F|0)==0){break}M=c[552416+(1*52|0)+(h<<2)>>2]|0;if(!(M>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}T=M;M=n;switch(T|0){case 5:case 4:case 3:{W=M+1128234|0;break};case 8:case 7:case 6:{W=M+1128233|0;break};case 2:case 1:case 0:{W=M+1128235|0;break};case 12:case 11:case 10:case 9:{W=M+1128232|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[W]=0;if((c[y+2047004>>2]|0)!=0){M=n+1184596|0;E=B+576|0;c[M>>2]=c[E>>2];c[M+4>>2]=c[E+4>>2];c[M+8>>2]=c[E+8>>2];c[M+12>>2]=c[E+12>>2]}pmc(y,b,f,g,r,s,T);E=n;switch(T|0){case 1:{X=E+1261416+((d[E+1128232|0]|0)*9600|0)+((d[E+1128233|0]|0)*2400|0)+((d[E+1128234|0]|0)*600|0)|0;break};case 8:{X=E+1386216+((d[E+1128232|0]|0)*1200|0)+((d[E+1128233|0]|0)*600|0)|0;break};case 6:{X=E+1376616+((d[E+1128232|0]|0)*2400|0)+((d[E+1128233|0]|0)*600|0)|0;break};case 7:{X=E+1391016+((d[E+1128232|0]|0)*1200|0)+((d[E+1128233|0]|0)*600|0)|0;break};case 12:{X=E+1400616|0;break};case 10:{X=E+1398216+((d[E+1128232|0]|0)*600|0)|0;break};case 3:{X=E+1299816+((d[E+1128232|0]|0)*9600|0)+((d[E+1128233|0]|0)*2400|0)+((d[E+1128234|0]|0)*600|0)|0;break};case 5:{X=E+1357416+((d[E+1128232|0]|0)*4800|0)+((d[E+1128233|0]|0)*1200|0)+((d[E+1128234|0]|0)*600|0)|0;break};case 9:{X=E+1395816+((d[E+1128232|0]|0)*600|0)|0;break};case 0:{X=E+1184616+((d[E+1128232|0]|0)*9600|0)+((d[E+1128233|0]|0)*2400|0)+((d[E+1128234|0]|0)*600|0)|0;break};case 11:{X=E+1399416+((d[E+1128232|0]|0)*600|0)|0;break};case 2:{X=E+1223016+((d[E+1128232|0]|0)*9600|0)+((d[E+1128233|0]|0)*2400|0)+((d[E+1128234|0]|0)*600|0)|0;break};case 4:{X=E+1338216+((d[E+1128232|0]|0)*4800|0)+((d[E+1128233|0]|0)*1200|0)+((d[E+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(X|0,c[c[m+160>>2]>>2]|0,76)|0;E=C;M=c[n+75248>>2]|0;R=Erc(E,(E|0)<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;M=wrc(128,0,R,G)|0;R=G;E=yrc(c[t>>2]|0,c[t+4>>2]|0,c[n+75244>>2]|0)|0;V=wrc(M>>>8|R<<24,R>>8|((R|0)<0|0?-1:0)<<24,E,G)|0;c[v>>2]=V;c[v+4>>2]=G;V=c[v+4>>2]|0;E=c[q+4>>2]|0;do{if((V|0)<(E|0)|(V|0)==(E|0)&(c[v>>2]|0)>>>0<(c[q>>2]|0)>>>0){if((f+z|0)>=(c[o+10148>>2]|0)){break}R=n;switch(T|0){case 5:case 4:case 3:{Y=R+1128234|0;break};case 8:case 7:case 6:{Y=R+1128233|0;break};case 2:case 1:case 0:{Y=R+1128235|0;break};case 12:case 11:case 10:case 9:{Y=R+1128232|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[Y]=1;R=n+1184596|0;M=B+576|0;c[R>>2]=c[M>>2];c[R+4>>2]=c[M+4>>2];c[R+8>>2]=c[M+8>>2];c[R+12>>2]=c[M+12>>2];pmc(y,b,f+z|0,g,r,s,T);M=n;switch(T|0){case 2:{Z=M+1223016+((d[M+1128232|0]|0)*9600|0)+((d[M+1128233|0]|0)*2400|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 1:{Z=M+1261416+((d[M+1128232|0]|0)*9600|0)+((d[M+1128233|0]|0)*2400|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 10:{Z=M+1398216+((d[M+1128232|0]|0)*600|0)|0;break};case 12:{Z=M+1400616|0;break};case 3:{Z=M+1299816+((d[M+1128232|0]|0)*9600|0)+((d[M+1128233|0]|0)*2400|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 4:{Z=M+1338216+((d[M+1128232|0]|0)*4800|0)+((d[M+1128233|0]|0)*1200|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 7:{Z=M+1391016+((d[M+1128232|0]|0)*1200|0)+((d[M+1128233|0]|0)*600|0)|0;break};case 8:{Z=M+1386216+((d[M+1128232|0]|0)*1200|0)+((d[M+1128233|0]|0)*600|0)|0;break};case 9:{Z=M+1395816+((d[M+1128232|0]|0)*600|0)|0;break};case 0:{Z=M+1184616+((d[M+1128232|0]|0)*9600|0)+((d[M+1128233|0]|0)*2400|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 5:{Z=M+1357416+((d[M+1128232|0]|0)*4800|0)+((d[M+1128233|0]|0)*1200|0)+((d[M+1128234|0]|0)*600|0)|0;break};case 6:{Z=M+1376616+((d[M+1128232|0]|0)*2400|0)+((d[M+1128233|0]|0)*600|0)|0;break};case 11:{Z=M+1399416+((d[M+1128232|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(Z|0,c[c[m+160>>2]>>2]|0,76)|0;if((c[r>>2]|0)==2147483647){c[v>>2]=-1;c[v+4>>2]=2147483647}else{M=m;R=h;U=(c[M+50460>>2]|0)+g|0;O=M+50464+(f&7)|0;M=c[830920+(R<<2)>>2]|0;I=1<<M;x=0;J=0;if((c[1960336+(R<<2)>>2]|0)!=(c[1960696+(R<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((M|0)<0){Cd(2473496,2485024,330,2651704)}R=0;while(1){if((R|0)>=(I|0)){break}x=x|a[U+R|0];J=J|a[O+R|0];R=R+1|0}x=(x&I|0)>0|0;J=(J&I|0)>0|0;c[r>>2]=(c[r>>2]|0)+(c[n+1401216+((J<<1)+x+(M<<2)<<4)+4>>2]|0);C=C+(c[r>>2]|0)|0;R=wrc(c[t>>2]|0,c[t+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;c[t>>2]=R;c[t+4>>2]=G;R=C;O=c[n+75248>>2]|0;U=Erc(R,(R|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;O=wrc(128,0,U,G)|0;U=G;R=yrc(c[t>>2]|0,c[t+4>>2]|0,c[n+75244>>2]|0)|0;w=wrc(O>>>8|U<<24,U>>8|((U|0)<0|0?-1:0)<<24,R,G)|0;c[v>>2]=w;c[v+4>>2]=G}}}while(0);E=c[v+4>>2]|0;V=c[q+4>>2]|0;if((E|0)<(V|0)|(E|0)==(V|0)&(c[v>>2]|0)>>>0<(c[q>>2]|0)>>>0){V=c[v+4>>2]|0;c[q>>2]=c[v>>2];c[q+4>>2]=V;D=C;V=c[t+4>>2]|0;c[u>>2]=c[t>>2];c[u+4>>2]=V;c[(Tlc(n,h)|0)>>2]=T}}}while(0);do{if((K|0)!=0){if((F|0)==0){break}Z=c[552416+(2*52|0)+(h<<2)>>2]|0;if(!(Z>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}T=Z;Z=n;switch(T|0){case 12:case 11:case 10:case 9:{_=Z+1128232|0;break};case 8:case 7:case 6:{_=Z+1128233|0;break};case 5:case 4:case 3:{_=Z+1128234|0;break};case 2:case 1:case 0:{_=Z+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[_]=0;if((c[y+2047004>>2]|0)!=0){Z=n+1184596|0;Y=B+576|0;c[Z>>2]=c[Y>>2];c[Z+4>>2]=c[Y+4>>2];c[Z+8>>2]=c[Y+8>>2];c[Z+12>>2]=c[Y+12>>2]}pmc(y,b,f,g,r,s,T);Y=n;switch(T|0){case 6:{$=Y+1376616+((d[Y+1128232|0]|0)*2400|0)+((d[Y+1128233|0]|0)*600|0)|0;break};case 5:{$=Y+1357416+((d[Y+1128232|0]|0)*4800|0)+((d[Y+1128233|0]|0)*1200|0)+((d[Y+1128234|0]|0)*600|0)|0;break};case 4:{$=Y+1338216+((d[Y+1128232|0]|0)*4800|0)+((d[Y+1128233|0]|0)*1200|0)+((d[Y+1128234|0]|0)*600|0)|0;break};case 2:{$=Y+1223016+((d[Y+1128232|0]|0)*9600|0)+((d[Y+1128233|0]|0)*2400|0)+((d[Y+1128234|0]|0)*600|0)|0;break};case 1:{$=Y+1261416+((d[Y+1128232|0]|0)*9600|0)+((d[Y+1128233|0]|0)*2400|0)+((d[Y+1128234|0]|0)*600|0)|0;break};case 0:{$=Y+1184616+((d[Y+1128232|0]|0)*9600|0)+((d[Y+1128233|0]|0)*2400|0)+((d[Y+1128234|0]|0)*600|0)|0;break};case 12:{$=Y+1400616|0;break};case 11:{$=Y+1399416+((d[Y+1128232|0]|0)*600|0)|0;break};case 3:{$=Y+1299816+((d[Y+1128232|0]|0)*9600|0)+((d[Y+1128233|0]|0)*2400|0)+((d[Y+1128234|0]|0)*600|0)|0;break};case 10:{$=Y+1398216+((d[Y+1128232|0]|0)*600|0)|0;break};case 9:{$=Y+1395816+((d[Y+1128232|0]|0)*600|0)|0;break};case 8:{$=Y+1386216+((d[Y+1128232|0]|0)*1200|0)+((d[Y+1128233|0]|0)*600|0)|0;break};case 7:{$=Y+1391016+((d[Y+1128232|0]|0)*1200|0)+((d[Y+1128233|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc($|0,c[c[m+160>>2]>>2]|0,76)|0;Y=C;Z=c[n+75248>>2]|0;X=Erc(Y,(Y|0)<0|0?-1:0,Z,(Z|0)<0|0?-1:0)|0;Z=wrc(128,0,X,G)|0;X=G;Y=yrc(c[t>>2]|0,c[t+4>>2]|0,c[n+75244>>2]|0)|0;W=wrc(Z>>>8|X<<24,X>>8|((X|0)<0|0?-1:0)<<24,Y,G)|0;c[v>>2]=W;c[v+4>>2]=G;W=c[v+4>>2]|0;Y=c[q+4>>2]|0;do{if((W|0)<(Y|0)|(W|0)==(Y|0)&(c[v>>2]|0)>>>0<(c[q>>2]|0)>>>0){if((g+z|0)>=(c[o+10156>>2]|0)){break}X=n;switch(T|0){case 12:case 11:case 10:case 9:{aa=X+1128232|0;break};case 8:case 7:case 6:{aa=X+1128233|0;break};case 5:case 4:case 3:{aa=X+1128234|0;break};case 2:case 1:case 0:{aa=X+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[aa]=1;X=n+1184596|0;Z=B+576|0;c[X>>2]=c[Z>>2];c[X+4>>2]=c[Z+4>>2];c[X+8>>2]=c[Z+8>>2];c[X+12>>2]=c[Z+12>>2];pmc(y,b,f,g+z|0,r,s,T);Z=n;switch(T|0){case 8:{ba=Z+1386216+((d[Z+1128232|0]|0)*1200|0)+((d[Z+1128233|0]|0)*600|0)|0;break};case 7:{ba=Z+1391016+((d[Z+1128232|0]|0)*1200|0)+((d[Z+1128233|0]|0)*600|0)|0;break};case 6:{ba=Z+1376616+((d[Z+1128232|0]|0)*2400|0)+((d[Z+1128233|0]|0)*600|0)|0;break};case 5:{ba=Z+1357416+((d[Z+1128232|0]|0)*4800|0)+((d[Z+1128233|0]|0)*1200|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 4:{ba=Z+1338216+((d[Z+1128232|0]|0)*4800|0)+((d[Z+1128233|0]|0)*1200|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 3:{ba=Z+1299816+((d[Z+1128232|0]|0)*9600|0)+((d[Z+1128233|0]|0)*2400|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 10:{ba=Z+1398216+((d[Z+1128232|0]|0)*600|0)|0;break};case 9:{ba=Z+1395816+((d[Z+1128232|0]|0)*600|0)|0;break};case 12:{ba=Z+1400616|0;break};case 11:{ba=Z+1399416+((d[Z+1128232|0]|0)*600|0)|0;break};case 2:{ba=Z+1223016+((d[Z+1128232|0]|0)*9600|0)+((d[Z+1128233|0]|0)*2400|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 1:{ba=Z+1261416+((d[Z+1128232|0]|0)*9600|0)+((d[Z+1128233|0]|0)*2400|0)+((d[Z+1128234|0]|0)*600|0)|0;break};case 0:{ba=Z+1184616+((d[Z+1128232|0]|0)*9600|0)+((d[Z+1128233|0]|0)*2400|0)+((d[Z+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(ba|0,c[c[m+160>>2]>>2]|0,76)|0;if((c[r>>2]|0)==2147483647){c[v>>2]=-1;c[v+4>>2]=2147483647}else{Z=m;X=h;L=(c[Z+50460>>2]|0)+g|0;V=Z+50464+(f&7)|0;Z=c[830920+(X<<2)>>2]|0;E=1<<Z;w=0;R=0;if((c[1960336+(X<<2)>>2]|0)!=(c[1960696+(X<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((Z|0)<0){Cd(2473496,2485024,330,2651704)}X=0;while(1){if((X|0)>=(E|0)){break}w=w|a[L+X|0];R=R|a[V+X|0];X=X+1|0}w=(w&E|0)>0|0;R=(R&E|0)>0|0;c[r>>2]=(c[r>>2]|0)+(c[n+1401216+((R<<1)+w+(Z<<2)<<4)+8>>2]|0);C=C+(c[r>>2]|0)|0;X=wrc(c[t>>2]|0,c[t+4>>2]|0,c[s>>2]|0,c[s+4>>2]|0)|0;c[t>>2]=X;c[t+4>>2]=G;X=C;V=c[n+75248>>2]|0;L=Erc(X,(X|0)<0|0?-1:0,V,(V|0)<0|0?-1:0)|0;V=wrc(128,0,L,G)|0;L=G;X=yrc(c[t>>2]|0,c[t+4>>2]|0,c[n+75244>>2]|0)|0;M=wrc(V>>>8|L<<24,L>>8|((L|0)<0|0?-1:0)<<24,X,G)|0;c[v>>2]=M;c[v+4>>2]=G}}}while(0);Y=c[v+4>>2]|0;W=c[q+4>>2]|0;if((Y|0)<(W|0)|(Y|0)==(W|0)&(c[v>>2]|0)>>>0<(c[q>>2]|0)>>>0){D=C;W=c[t+4>>2]|0;c[u>>2]=c[t>>2];c[u+4>>2]=W;W=c[v+4>>2]|0;c[q>>2]=c[v>>2];c[q+4>>2]=W;c[(Tlc(n,h)|0)>>2]=T}}}while(0);c[j>>2]=D;j=c[u+4>>2]|0;T=k;c[T>>2]=c[u>>2];c[T+4>>2]=j;if((D|0)==2147483647){i=p;return}qmc(o,n,f,g,h,c[(Tlc(n,h)|0)>>2]|0);do{if((D|0)<2147483647){n=c[u+4>>2]|0;j=2147483647;if(!((n|0)<(j|0)|(n|0)==(j|0)&(c[u>>2]|0)>>>0<-1>>>0)){break}if((l|0)==0){break}j=(h|0)==12|0;do{if((c[y+1471728>>2]|0)==2){if((d[o+13409|0]|0)==0){break}Sjc(y,f,g,j,D)}}while(0);if((c[y+1471728>>2]|0)==3){n=D;Zjc(c[y+2047228>>2]|0,n,(n|0)<0|0?-1:0,c[u>>2]|0,c[u+4>>2]|0)}rmc(y,b,e,f,g,j,h)}}while(0);if((h|0)!=12){if((A|0)==(c[e>>2]|0)){}else{Cd(2160840,2539744,3045,2651880)}i=p;return}if(A>>>0<(c[e>>2]|0)>>>0){}else{Cd(2278952,2539744,3041,2651880)}if((D|0)<2147483647){}else{Cd(2229640,2539744,3042,2651880)}D=c[u+4>>2]|0;e=2147483647;if((D|0)<(e|0)|(D|0)==(e|0)&(c[u>>2]|0)>>>0<-1>>>0){}else{Cd(2191720,2539744,3043,2651880)}i=p;return}function pmc(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;k=a;a=b;b=d;d=e;e=h;h=k+1434592|0;l=k+32768|0;m=l+24720|0;Flc(k,a,b,d,e);c[c[c[m+160>>2]>>2]>>2]=e;n=h;if((c[n+10108>>2]|0)==0){o=1}else{o=(c[n+10124>>2]|0)!=0}if((o&1|0)!=0){umc(c[c[m+160>>2]>>2]|0,e,0);p=h;q=m;r=b;s=d;t=e;imc(p,q,r,s,t);i=j;return}else{soc(k,l,a,b,d,f,g,e)|0;p=h;q=m;r=b;s=d;t=e;imc(p,q,r,s,t);i=j;return}}function qmc(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;k=i;l=b;b=e;e=f;f=g;g=h;h=j;j=b+24720|0;m=c[1960336+(g<<2)>>2]|0;n=(1<<m|0)/4|0;o=734952+(m*52|0)+(h<<2)|0;m=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;if(g>>>0>=3>>>0){}else{Cd(2407400,2539744,2725,2652712)}do{if((e|0)<(c[l+10148>>2]|0)){if((f|0)>=(c[l+10156>>2]|0)){break}o=m;if((o|0)==2){p=b;switch(h|0){case 5:case 4:case 3:{q=p+1128234|0;break};case 12:case 11:case 10:case 9:{q=p+1128232|0;break};case 8:case 7:case 6:{q=p+1128233|0;break};case 2:case 1:case 0:{q=p+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[q]=0;p=l;r=j;s=(ca(c[r+156>>2]|0,e)|0)+f|0;c[r+160>>2]=(c[p+10204>>2]|0)+(s<<2);c[c[r+160>>2]>>2]=(c[p+10188>>2]|0)+(s*124|0);s=c[c[j+160>>2]>>2]|0;p=b;switch(h|0){case 3:{t=p+1299816+((d[p+1128232|0]|0)*9600|0)+((d[p+1128233|0]|0)*2400|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 5:{t=p+1357416+((d[p+1128232|0]|0)*4800|0)+((d[p+1128233|0]|0)*1200|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 7:{t=p+1391016+((d[p+1128232|0]|0)*1200|0)+((d[p+1128233|0]|0)*600|0)|0;break};case 11:{t=p+1399416+((d[p+1128232|0]|0)*600|0)|0;break};case 9:{t=p+1395816+((d[p+1128232|0]|0)*600|0)|0;break};case 8:{t=p+1386216+((d[p+1128232|0]|0)*1200|0)+((d[p+1128233|0]|0)*600|0)|0;break};case 10:{t=p+1398216+((d[p+1128232|0]|0)*600|0)|0;break};case 6:{t=p+1376616+((d[p+1128232|0]|0)*2400|0)+((d[p+1128233|0]|0)*600|0)|0;break};case 4:{t=p+1338216+((d[p+1128232|0]|0)*4800|0)+((d[p+1128233|0]|0)*1200|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 12:{t=p+1400616|0;break};case 2:{t=p+1223016+((d[p+1128232|0]|0)*9600|0)+((d[p+1128233|0]|0)*2400|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 1:{t=p+1261416+((d[p+1128232|0]|0)*9600|0)+((d[p+1128233|0]|0)*2400|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 0:{t=p+1184616+((d[p+1128232|0]|0)*9600|0)+((d[p+1128233|0]|0)*2400|0)+((d[p+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(s|0,t|0,124)|0;imc(l,j,e,f,g);if((f+n|0)<(c[l+10156>>2]|0)){s=b;switch(h|0){case 12:case 11:case 10:case 9:{u=s+1128232|0;break};case 8:case 7:case 6:{u=s+1128233|0;break};case 5:case 4:case 3:{u=s+1128234|0;break};case 2:case 1:case 0:{u=s+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[u]=1;s=l;p=j;r=(ca(c[p+156>>2]|0,e)|0)+(f+n)|0;c[p+160>>2]=(c[s+10204>>2]|0)+(r<<2);c[c[p+160>>2]>>2]=(c[s+10188>>2]|0)+(r*124|0);r=c[c[j+160>>2]>>2]|0;s=b;switch(h|0){case 12:{v=s+1400616|0;break};case 11:{v=s+1399416+((d[s+1128232|0]|0)*600|0)|0;break};case 10:{v=s+1398216+((d[s+1128232|0]|0)*600|0)|0;break};case 9:{v=s+1395816+((d[s+1128232|0]|0)*600|0)|0;break};case 8:{v=s+1386216+((d[s+1128232|0]|0)*1200|0)+((d[s+1128233|0]|0)*600|0)|0;break};case 7:{v=s+1391016+((d[s+1128232|0]|0)*1200|0)+((d[s+1128233|0]|0)*600|0)|0;break};case 6:{v=s+1376616+((d[s+1128232|0]|0)*2400|0)+((d[s+1128233|0]|0)*600|0)|0;break};case 5:{v=s+1357416+((d[s+1128232|0]|0)*4800|0)+((d[s+1128233|0]|0)*1200|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 4:{v=s+1338216+((d[s+1128232|0]|0)*4800|0)+((d[s+1128233|0]|0)*1200|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 3:{v=s+1299816+((d[s+1128232|0]|0)*9600|0)+((d[s+1128233|0]|0)*2400|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 2:{v=s+1223016+((d[s+1128232|0]|0)*9600|0)+((d[s+1128233|0]|0)*2400|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 1:{v=s+1261416+((d[s+1128232|0]|0)*9600|0)+((d[s+1128233|0]|0)*2400|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 0:{v=s+1184616+((d[s+1128232|0]|0)*9600|0)+((d[s+1128233|0]|0)*2400|0)+((d[s+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(r|0,v|0,124)|0;imc(l,j,e,f+n|0,g)}i=k;return}else if((o|0)==0){r=l;s=j;p=(ca(c[s+156>>2]|0,e)|0)+f|0;c[s+160>>2]=(c[r+10204>>2]|0)+(p<<2);c[c[s+160>>2]>>2]=(c[r+10188>>2]|0)+(p*124|0);p=c[c[j+160>>2]>>2]|0;r=b;switch(h|0){case 3:{w=r+1299816+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 5:{w=r+1357416+((d[r+1128232|0]|0)*4800|0)+((d[r+1128233|0]|0)*1200|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 0:{w=r+1184616+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 6:{w=r+1376616+((d[r+1128232|0]|0)*2400|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 1:{w=r+1261416+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 10:{w=r+1398216+((d[r+1128232|0]|0)*600|0)|0;break};case 9:{w=r+1395816+((d[r+1128232|0]|0)*600|0)|0;break};case 12:{w=r+1400616|0;break};case 2:{w=r+1223016+((d[r+1128232|0]|0)*9600|0)+((d[r+1128233|0]|0)*2400|0)+((d[r+1128234|0]|0)*600|0)|0;break};case 11:{w=r+1399416+((d[r+1128232|0]|0)*600|0)|0;break};case 8:{w=r+1386216+((d[r+1128232|0]|0)*1200|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 7:{w=r+1391016+((d[r+1128232|0]|0)*1200|0)+((d[r+1128233|0]|0)*600|0)|0;break};case 4:{w=r+1338216+((d[r+1128232|0]|0)*4800|0)+((d[r+1128233|0]|0)*1200|0)+((d[r+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(p|0,w|0,124)|0;imc(l,j,e,f,g);i=k;return}else if((o|0)==1){p=b;switch(h|0){case 12:case 11:case 10:case 9:{x=p+1128232|0;break};case 8:case 7:case 6:{x=p+1128233|0;break};case 5:case 4:case 3:{x=p+1128234|0;break};case 2:case 1:case 0:{x=p+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[x]=0;p=l;r=j;s=(ca(c[r+156>>2]|0,e)|0)+f|0;c[r+160>>2]=(c[p+10204>>2]|0)+(s<<2);c[c[r+160>>2]>>2]=(c[p+10188>>2]|0)+(s*124|0);s=c[c[j+160>>2]>>2]|0;p=b;switch(h|0){case 12:{y=p+1400616|0;break};case 11:{y=p+1399416+((d[p+1128232|0]|0)*600|0)|0;break};case 10:{y=p+1398216+((d[p+1128232|0]|0)*600|0)|0;break};case 9:{y=p+1395816+((d[p+1128232|0]|0)*600|0)|0;break};case 8:{y=p+1386216+((d[p+1128232|0]|0)*1200|0)+((d[p+1128233|0]|0)*600|0)|0;break};case 7:{y=p+1391016+((d[p+1128232|0]|0)*1200|0)+((d[p+1128233|0]|0)*600|0)|0;break};case 6:{y=p+1376616+((d[p+1128232|0]|0)*2400|0)+((d[p+1128233|0]|0)*600|0)|0;break};case 5:{y=p+1357416+((d[p+1128232|0]|0)*4800|0)+((d[p+1128233|0]|0)*1200|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 4:{y=p+1338216+((d[p+1128232|0]|0)*4800|0)+((d[p+1128233|0]|0)*1200|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 3:{y=p+1299816+((d[p+1128232|0]|0)*9600|0)+((d[p+1128233|0]|0)*2400|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 2:{y=p+1223016+((d[p+1128232|0]|0)*9600|0)+((d[p+1128233|0]|0)*2400|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 1:{y=p+1261416+((d[p+1128232|0]|0)*9600|0)+((d[p+1128233|0]|0)*2400|0)+((d[p+1128234|0]|0)*600|0)|0;break};case 0:{y=p+1184616+((d[p+1128232|0]|0)*9600|0)+((d[p+1128233|0]|0)*2400|0)+((d[p+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(s|0,y|0,124)|0;imc(l,j,e,f,g);if((e+n|0)<(c[l+10148>>2]|0)){s=b;switch(h|0){case 12:case 11:case 10:case 9:{z=s+1128232|0;break};case 8:case 7:case 6:{z=s+1128233|0;break};case 5:case 4:case 3:{z=s+1128234|0;break};case 2:case 1:case 0:{z=s+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[z]=1;s=l;p=j;r=(ca(c[p+156>>2]|0,e+n|0)|0)+f|0;c[p+160>>2]=(c[s+10204>>2]|0)+(r<<2);c[c[p+160>>2]>>2]=(c[s+10188>>2]|0)+(r*124|0);r=c[c[j+160>>2]>>2]|0;s=b;switch(h|0){case 12:{A=s+1400616|0;break};case 11:{A=s+1399416+((d[s+1128232|0]|0)*600|0)|0;break};case 10:{A=s+1398216+((d[s+1128232|0]|0)*600|0)|0;break};case 9:{A=s+1395816+((d[s+1128232|0]|0)*600|0)|0;break};case 8:{A=s+1386216+((d[s+1128232|0]|0)*1200|0)+((d[s+1128233|0]|0)*600|0)|0;break};case 7:{A=s+1391016+((d[s+1128232|0]|0)*1200|0)+((d[s+1128233|0]|0)*600|0)|0;break};case 6:{A=s+1376616+((d[s+1128232|0]|0)*2400|0)+((d[s+1128233|0]|0)*600|0)|0;break};case 5:{A=s+1357416+((d[s+1128232|0]|0)*4800|0)+((d[s+1128233|0]|0)*1200|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 4:{A=s+1338216+((d[s+1128232|0]|0)*4800|0)+((d[s+1128233|0]|0)*1200|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 3:{A=s+1299816+((d[s+1128232|0]|0)*9600|0)+((d[s+1128233|0]|0)*2400|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 2:{A=s+1223016+((d[s+1128232|0]|0)*9600|0)+((d[s+1128233|0]|0)*2400|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 1:{A=s+1261416+((d[s+1128232|0]|0)*9600|0)+((d[s+1128233|0]|0)*2400|0)+((d[s+1128234|0]|0)*600|0)|0;break};case 0:{A=s+1184616+((d[s+1128232|0]|0)*9600|0)+((d[s+1128233|0]|0)*2400|0)+((d[s+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}nrc(r|0,A|0,124)|0;imc(l,j,e+n|0,f,g)}i=k;return}else if((o|0)==3){o=b;switch(h|0){case 12:case 11:case 10:case 9:{B=o+1128232|0;break};case 8:case 7:case 6:{B=o+1128233|0;break};case 5:case 4:case 3:{B=o+1128234|0;break};case 2:case 1:case 0:{B=o+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[B]=0;qmc(l,b,e,f,h,c[(Tlc(b,h)|0)>>2]|0);o=b;switch(h|0){case 12:case 11:case 10:case 9:{C=o+1128232|0;break};case 8:case 7:case 6:{C=o+1128233|0;break};case 5:case 4:case 3:{C=o+1128234|0;break};case 2:case 1:case 0:{C=o+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[C]=1;qmc(l,b,e,f+n|0,h,c[(Tlc(b,h)|0)>>2]|0);o=b;switch(h|0){case 12:case 11:case 10:case 9:{D=o+1128232|0;break};case 8:case 7:case 6:{D=o+1128233|0;break};case 5:case 4:case 3:{D=o+1128234|0;break};case 2:case 1:case 0:{D=o+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[D]=2;qmc(l,b,e+n|0,f,h,c[(Tlc(b,h)|0)>>2]|0);o=b;switch(h|0){case 12:case 11:case 10:case 9:{E=o+1128232|0;break};case 8:case 7:case 6:{E=o+1128233|0;break};case 5:case 4:case 3:{E=o+1128234|0;break};case 2:case 1:case 0:{E=o+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[E]=3;qmc(l,b,e+n|0,f+n|0,h,c[(Tlc(b,h)|0)>>2]|0);i=k;return}else{i=k;return}}}while(0);i=k;return}function rmc(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;l=i;m=b;b=e;e=f;f=g;g=h;h=j;j=k;k=m+1434592|0;n=m+32768|0;o=n+24720|0;p=c[1960336+(j<<2)>>2]|0;q=(1<<p|0)/4|0;do{if((f|0)<(c[k+10148>>2]|0)){if((g|0)>=(c[k+10156>>2]|0)){break}if(j>>>0>=3>>>0){r=m+57488|0;s=(ca(c[r+156>>2]|0,f)|0)+g|0;t=(c[k+10204>>2]|0)+(s<<2)|0;s=r;r=j;u=(c[s+50460>>2]|0)+g|0;v=s+50464+(f&7)|0;s=c[830920+(r<<2)>>2]|0;w=1<<s;x=0;y=0;if((c[1960336+(r<<2)>>2]|0)!=(c[1960696+(r<<2)>>2]|0)){Cd(2495744,2485024,329,2651704)}if((s|0)<0){Cd(2473496,2485024,330,2651704)}r=0;while(1){if((r|0)>=(w|0)){break}x=x|a[u+r|0];y=y|a[v+r|0];r=r+1|0}x=(x&w|0)>0|0;y=(y&w|0)>0|0;z=(y<<1)+x+(s<<2)|0;A=c[c[t>>2]>>2]|0}else{z=0;A=0}r=734952+(p*52|0)+(A<<2)|0;v=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24|0;r=v;if((r|0)==1){if((h|0)!=0){u=k+24300+(z<<4)+4|0;c[u>>2]=(c[u>>2]|0)+1}u=n;switch(A|0){case 5:case 4:case 3:{B=u+1128234|0;break};case 8:case 7:case 6:{B=u+1128233|0;break};case 12:case 11:case 10:case 9:{B=u+1128232|0;break};case 2:case 1:case 0:{B=u+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[B]=0;smc(m,b,e,f,g,h,A);if((f+q|0)<(c[k+10148>>2]|0)){u=n;switch(A|0){case 2:case 1:case 0:{C=u+1128235|0;break};case 8:case 7:case 6:{C=u+1128233|0;break};case 5:case 4:case 3:{C=u+1128234|0;break};case 12:case 11:case 10:case 9:{C=u+1128232|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[C]=1;smc(m,b,e,f+q|0,g,h,A)}}else if((r|0)==3){u=c[552416+(3*52|0)+(j<<2)>>2]|0;if(!(u>>>0<13>>>0)){Cd(2509776,2559560,248,2652192)}A=u;if((h|0)!=0){u=k+24300+(z<<4)+12|0;c[u>>2]=(c[u>>2]|0)+1}u=n;switch(A|0){case 12:case 11:case 10:case 9:{D=u+1128232|0;break};case 2:case 1:case 0:{D=u+1128235|0;break};case 5:case 4:case 3:{D=u+1128234|0;break};case 8:case 7:case 6:{D=u+1128233|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[D]=0;rmc(m,b,e,f,g,h,A);u=n;switch(A|0){case 2:case 1:case 0:{E=u+1128235|0;break};case 8:case 7:case 6:{E=u+1128233|0;break};case 5:case 4:case 3:{E=u+1128234|0;break};case 12:case 11:case 10:case 9:{E=u+1128232|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[E]=1;rmc(m,b,e,f,g+q|0,h,A);u=n;switch(A|0){case 12:case 11:case 10:case 9:{F=u+1128232|0;break};case 2:case 1:case 0:{F=u+1128235|0;break};case 5:case 4:case 3:{F=u+1128234|0;break};case 8:case 7:case 6:{F=u+1128233|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[F]=2;rmc(m,b,e,f+q|0,g,h,A);u=n;switch(A|0){case 12:case 11:case 10:case 9:{G=u+1128232|0;break};case 8:case 7:case 6:{G=u+1128233|0;break};case 2:case 1:case 0:{G=u+1128235|0;break};case 5:case 4:case 3:{G=u+1128234|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[G]=3;rmc(m,b,e,f+q|0,g+q|0,h,A)}else if((r|0)==0){do{if((h|0)!=0){if(!(j>>>0>=3>>>0)){break}u=k+24300+(z<<4)|0;c[u>>2]=(c[u>>2]|0)+1}}while(0);smc(m,b,e,f,g,h,A)}else if((r|0)==2){if((h|0)!=0){t=k+24300+(z<<4)+8|0;c[t>>2]=(c[t>>2]|0)+1}t=n;switch(A|0){case 5:case 4:case 3:{H=t+1128234|0;break};case 8:case 7:case 6:{H=t+1128233|0;break};case 12:case 11:case 10:case 9:{H=t+1128232|0;break};case 2:case 1:case 0:{H=t+1128235|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[H]=0;smc(m,b,e,f,g,h,A);if((g+q|0)<(c[k+10156>>2]|0)){t=n;switch(A|0){case 8:case 7:case 6:{I=t+1128233|0;break};case 2:case 1:case 0:{I=t+1128235|0;break};case 5:case 4:case 3:{I=t+1128234|0;break};case 12:case 11:case 10:case 9:{I=t+1128232|0;break};default:{Cd(2524984,2539744,71,2652264)}}a[I]=1;smc(m,b,e,f,g+q|0,h,A)}}else{if(1){}else{Cd(2112096,2539744,1693,2652840)}}do{if((v|0)==3){if((j|0)==3){break}i=l;return}}while(0);v=o;r=A;t=c[777680+(j<<2)>>2]|0;mrc((c[v+50460>>2]|0)+g|0,a[735216+(r<<1)|0]&255|0,t|0)|0;mrc(v+50464+(f&7)|0,a[735217+(r<<1)|0]&255|0,t|0)|0;i=l;return}}while(0);i=l;return}function smc(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0;l=i;m=b;b=e;e=f;f=g;g=h;h=j;j=k;k=m+32768|0;do{if(j>>>0<3>>>0){if((d[k+1128235|0]|0|0)<=0){break}i=l;return}}while(0);Flc(m,b,f,g,j);b=k;switch(j|0){case 0:{n=b+1184616+((d[b+1128232|0]|0)*9600|0)+((d[b+1128233|0]|0)*2400|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 4:{n=b+1338216+((d[b+1128232|0]|0)*4800|0)+((d[b+1128233|0]|0)*1200|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 2:{n=b+1223016+((d[b+1128232|0]|0)*9600|0)+((d[b+1128233|0]|0)*2400|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 3:{n=b+1299816+((d[b+1128232|0]|0)*9600|0)+((d[b+1128233|0]|0)*2400|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 12:{n=b+1400616|0;break};case 8:{n=b+1386216+((d[b+1128232|0]|0)*1200|0)+((d[b+1128233|0]|0)*600|0)|0;break};case 7:{n=b+1391016+((d[b+1128232|0]|0)*1200|0)+((d[b+1128233|0]|0)*600|0)|0;break};case 10:{n=b+1398216+((d[b+1128232|0]|0)*600|0)|0;break};case 9:{n=b+1395816+((d[b+1128232|0]|0)*600|0)|0;break};case 11:{n=b+1399416+((d[b+1128232|0]|0)*600|0)|0;break};case 6:{n=b+1376616+((d[b+1128232|0]|0)*2400|0)+((d[b+1128233|0]|0)*600|0)|0;break};case 5:{n=b+1357416+((d[b+1128232|0]|0)*4800|0)+((d[b+1128233|0]|0)*1200|0)+((d[b+1128234|0]|0)*600|0)|0;break};case 1:{n=b+1261416+((d[b+1128232|0]|0)*9600|0)+((d[b+1128233|0]|0)*2400|0)+((d[b+1128234|0]|0)*600|0)|0;break};default:{Cd(2524984,2415424,229,2652560)}}tmc(m,n,f,g,j);Wlc(m,e,h,f,g,j);Zlc(m);a[(c[e>>2]|0)+6|0]=127;m=e;c[m>>2]=(c[m>>2]|0)+8;i=l;return}function tmc(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=a;a=b;b=e;e=f;f=g;g=j+1434592|0;k=j+32768|0;l=k+24720|0;m=c[c[l+160>>2]>>2]|0;nrc(c[c[l+160>>2]>>2]|0,a|0,124)|0;do{if((c[j+1471728>>2]|0)==3){if((d[g+13408|0]|0|0)==0){break}Vjc(j,c[c[l+160>>2]>>2]|0,b,e,f,1);H2b(j,k)}}while(0);if(((c[m+20>>2]|0)>0|0)==0){n=a;o=n+424|0;p=c[o>>2]|0;q=k;r=q+1129276|0;c[r>>2]=p;i=h;return}Tmc(g,l);if((c[g+10220>>2]|0)==4){j=cgc(l)|0;l=g+36076+(j*12|0)+(c[m+72>>2]<<2)|0;c[l>>2]=(c[l>>2]|0)+1}n=a;o=n+424|0;p=c[o>>2]|0;q=k;r=q+1129276|0;c[r>>2]=p;i=h;return}function umc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b;b=d;d=e;c[f+4>>2]=d;c[f+16>>2]=d;c[f+28>>2]=0;c[f+32>>2]=0;c[f+20>>2]=0;c[f+24>>2]=-1;c[f+8>>2]=c[833024+(b<<2)>>2];a[f+12|0]=0;c[f>>2]=b;a[f+13|0]=0;i=i;return}function vmc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a;a=b;b=c;if((b|0)!=0){f=3}else{if((a|0)!=0){f=3}else{g=0}}if((f|0)==3){if((b|0)!=0){h=(a|0)!=0^1}else{h=1}g=h}h=xmc(e,g&1)|0;if(h>>>0>64>>>0){j=h;i=d;return j|0}else{j=64;i=d;return j|0}return 0}function wmc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=a;c[f>>2]=b;c[f+4>>2]=d;d=c[g+1444732>>2]|0;b=Crc(c[f>>2]|0,c[f+4>>2]|0,d,(d|0)<0|0?-1:0)|0;c[g+2050756>>2]=b;if(!((c[g+2050756>>2]|0)>>>0<64>>>0)){h=g;j=h+2050756|0;c[j>>2]=1e5;i=e;return}c[g+2050756>>2]=64;h=g;j=h+2050756|0;c[j>>2]=1e5;i=e;return}function xmc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=Imc(a,b)|0;i=c;return d|0}function ymc(a,c,e,f,g,h,j,k){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0;l=i;m=a;a=c;c=e;e=f;f=g;g=h;h=j;j=k;k=0;while(1){if((k|0)>=(m|0)){break}n=0;while(1){if((n|0)>=(a|0)){break}b[c+(n<<1)>>1]=(d[f+n|0]|0)-(d[h+n|0]|0);n=n+1|0}c=c+(e<<1)|0;h=h+j|0;f=f+g|0;k=k+1|0}i=l;return}function zmc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=d;d=f+(a*8240|0)|0;g=f+24720+(a*52|0)|0;a=g;f=c[558424+(b<<4)+(c[a+8>>2]<<3)+(c[a+12>>2]<<2)>>2]|0;if(f>>>0<13>>>0){a=f;f=c[777792+(a<<2)>>2]<<2;ymc(c[777848+(a<<2)>>2]<<2,f,d|0,f,c[d+8204>>2]|0,c[d+8208>>2]|0,c[g+16>>2]|0,c[g+20>>2]|0);i=e;return}else{Cd(2229512,2191648,292,2652296)}}function Amc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=a;a=d;d=e;e=f;f=g;g=l+(a*8240|0)|0;m=l+24720+(a*52|0)|0;a=218736+(f*12|0)|0;n=(c[g+8196>>2]|0)+(d<<4<<1)|0;o=(c[g+8192>>2]|0)+(d<<4<<1)|0;p=(c[m>>2]|0)+(d<<4<<1)|0;q=(c[g+8200>>2]|0)+(d<<1)|0;r=c[777792+(e<<2)>>2]<<2;s=f;t=(c[1960336+(e<<2)>>2]|0)-s|0;e=d>>(s<<1);c[j>>2]=(e&(1<<t)-1)<<s;c[k>>2]=e>>t<<s;s=ca(c[k>>2]|0,r)|0;k=g+(s+(c[j>>2]|0)<<2<<1)|0;j=f;if((j|0)==2){clc(k,n,r);C2b(n,256,c[l+75200>>2]|0,c[g+8220>>2]|0,c[g+8224>>2]|0,c[g+8212>>2]|0,c[g+8216>>2]|0,o,p,c[m+40>>2]|0,b[g+8228>>1]|0,q,c[a>>2]|0,c[a+4>>2]|0);i=h;return}else if((j|0)==3){f=k;s=n;t=r;if((c[l+1184588>>2]|0)!=0){ilc(f,s,t)}else{glc(f,s,t)}D2b(n,1024,c[l+75200>>2]|0,c[g+8220>>2]|0,c[g+8224>>2]|0,c[g+8212>>2]|0,c[g+8216>>2]|0,o,p,c[m+40>>2]|0,b[g+8228>>1]|0,q,c[a>>2]|0,c[a+4>>2]|0);i=h;return}else if((j|0)==0){ef[c[l+1401812>>2]&4095](k,n,r);C2b(n,16,c[l+75200>>2]|0,c[g+8220>>2]|0,c[g+8224>>2]|0,c[g+8212>>2]|0,c[g+8216>>2]|0,o,p,c[m+40>>2]|0,b[g+8228>>1]|0,q,c[a>>2]|0,c[a+4>>2]|0);i=h;return}else if((j|0)==1){alc(k,n,r);C2b(n,64,c[l+75200>>2]|0,c[g+8220>>2]|0,c[g+8224>>2]|0,c[g+8212>>2]|0,c[g+8216>>2]|0,o,p,c[m+40>>2]|0,b[g+8228>>1]|0,q,c[a>>2]|0,c[a+4>>2]|0);i=h;return}else{Cd(2268520,2539128,350,2649864)}}function Bmc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=a;a=b;zmc(d,a,0);dec(d+24720|0,a,0,34,d);i=c;return}function Cmc(a,b,d,f,g){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+16|0;j=h|0;k=h+8|0;l=a;a=b;b=d;d=f;f=g;g=f+24720|0;m=f+(l*8240|0)|0;n=g+(l*52|0)|0;o=(c[n>>2]|0)+(a<<4<<1)|0;p=d;q=(c[1960336+(b<<2)>>2]|0)-p|0;r=a>>(p<<1);c[j>>2]=(r&(1<<q)-1)<<p;c[k>>2]=r>>q<<p;p=ca(c[k>>2]<<2,c[n+20>>2]|0)|0;k=(c[n+16>>2]|0)+(p+(c[j>>2]<<2))|0;Amc(f,l,a,b,d);if((e[(c[m+8200>>2]|0)+(a<<1)>>1]|0|0)<=0){i=h;return}mf[c[g+25812>>2]&2047](o,k,c[n+20>>2]|0,e[(c[m+8200>>2]|0)+(a<<1)>>1]|0);i=h;return}function Dmc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+112|0;e=d|0;f=d+96|0;g=a;a=b;b=g+24720|0;h=c[c[b+160>>2]>>2]|0;c[f>>2]=g;c[f+4>>2]=e;c[f+8>>2]=h+12;j=0;while(1){if((j|0)>=3){break}if((c[g+75208>>2]|0)==0){zmc(g,a,j)}do{if((c[g+1184584>>2]|0)!=0){if((c[g+75208>>2]|0)!=0){if((c[g+75212>>2]|0)!=0){break}}k=b+(j*52|0)|0;if((j|0)!=0){l=h;m=c[l+8>>2]|0;n=c[l>>2]|0;if(n>>>0<3>>>0){o=0}else{l=c[558436+(n<<4)>>2]|0;if(m>>>0<(c[833024+(l<<2)>>2]|0)>>>0){p=m}else{p=c[833024+(l<<2)>>2]|0}o=p}q=o}else{q=c[h+8>>2]|0}I3b(a,q,k,e+(j<<4)|0,e+48+(j<<4)|0)}}while(0);dec(b,a,j,286,f);j=j+1|0}i=d;return}function Emc(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=i;i=i+16|0;m=l|0;n=l+8|0;o=f;f=g;g=h;h=j;j=k;k=c[j>>2]|0;p=k+24720|0;q=c[j+4>>2]|0;r=k+(o*8240|0)|0;s=p+(o*52|0)|0;t=(c[s>>2]|0)+(f<<4<<1)|0;u=h;v=(c[1960336+(g<<2)>>2]|0)-u|0;w=f>>(u<<1);c[m>>2]=(w&(1<<v)-1)<<u;c[n>>2]=w>>v<<u;u=ca(c[n>>2]<<2,c[s+20>>2]|0)|0;v=(c[s+16>>2]|0)+(u+(c[m>>2]<<2))|0;u=q+(o<<4)+(c[m>>2]|0)|0;m=q+48+(o<<4)+(c[n>>2]|0)|0;do{if((d[k+1128252+(h<<8)+f|0]|0)!=0){if((o|0)!=0){break}b[(c[r+8200>>2]|0)+(f<<1)>>1]=0;a[m]=0;a[u]=0;i=l;return}}while(0);if((c[k+75208>>2]|0)==0){Amc(k,o,f,g,h)}do{if((c[k+1184584>>2]|0)!=0){if((c[k+75208>>2]|0)!=0){if((c[k+75212>>2]|0)!=0){x=10;break}}n=(Jmc(k,o,f,g,h,((a[u]|0)!=0)+((a[m]|0)!=0)|0)|0)>0&255;a[m]=n;a[u]=n}else{x=10}}while(0);if((x|0)==10){x=(e[(c[r+8200>>2]|0)+(f<<1)>>1]|0)>0&255;a[m]=x;a[u]=x}if((b[(c[r+8200>>2]|0)+(f<<1)>>1]|0)!=0){a[c[j+8>>2]|0]=0}do{if((c[k+1184592>>2]|0)==0){if((e[(c[r+8200>>2]|0)+(f<<1)>>1]|0)==0){break}j=h;if((j|0)==2){qfc(t,v,c[s+20>>2]|0,e[(c[r+8200>>2]|0)+(f<<1)>>1]|0);i=l;return}else if((j|0)==1){pfc(t,v,c[s+20>>2]|0,e[(c[r+8200>>2]|0)+(f<<1)>>1]|0);i=l;return}else if((j|0)==0){mf[c[p+25812>>2]&2047](t,v,c[s+20>>2]|0,e[(c[r+8200>>2]|0)+(f<<1)>>1]|0);i=l;return}else if((j|0)==3){rfc(t,v,c[s+20>>2]|0,e[(c[r+8200>>2]|0)+(f<<1)>>1]|0);i=l;return}else{Cd(2414048,2539128,412,2652968)}}}while(0);i=l;return}function Fmc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;h=i;i=i+16|0;j=h|0;c[j>>2]=a;c[j+4>>2]=0;c[j+8>>2]=g;Gmc(b,d,e,f,j);i=h;return}function Gmc(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=d;d=f;f=g;g=h;h=j;j=c[h>>2]|0;o=j+24720|0;p=c[c[o+160>>2]>>2]|0;q=j+(n*8240|0)|0;r=o+(n*52|0)|0;s=(c[q+8196>>2]|0)+(d<<4<<1)|0;t=(c[q+8192>>2]|0)+(d<<4<<1)|0;u=(c[r>>2]|0)+(d<<4<<1)|0;v=c[1960336+(f<<2)>>2]|0;w=1<<v<<2;x=(c[q+8200>>2]|0)+(d<<1)|0;y=c[q+8208>>2]|0;z=c[r+20>>2]|0;A=g;B=(c[1960336+(f<<2)>>2]|0)-A|0;f=d>>(A<<1);c[l>>2]=(f&(1<<B)-1)<<A;c[m>>2]=f>>B<<A;A=ca(c[m>>2]|0,z)|0;B=(c[r+16>>2]|0)+(A+(c[l>>2]|0)<<2)|0;A=ca(c[m>>2]|0,y)|0;f=(c[q+8204>>2]|0)+(A+(c[l>>2]|0)<<2)|0;A=ca(c[m>>2]|0,w)|0;C=q+(A+(c[l>>2]|0)<<2<<1)|0;A=g;if((A|0)==1){g=c[c[o+160>>2]>>2]|0;do{if((c[r+4>>2]|0)!=0){D=41}else{if((c[g+20>>2]|0)>0){D=41;break}E=c[1064496+(c[g+4>>2]<<2)>>2]|0}}while(0);if((D|0)==41){E=0}F=E;G=204536+(F*12|0)|0;if((n|0)==0){H=c[p+4>>2]|0}else{H=c[p+16>>2]|0}I=H;if((c[j+1184592>>2]|0)!=0){J=f}else{J=B}if((c[j+1184592>>2]|0)!=0){K=y}else{K=z}Chc(o,d>>2,v,1,I,J,K,B,z,c[l>>2]|0,c[m>>2]|0,n);if((c[j+75208>>2]|0)==0){ymc(8,8,C,w,f,y,B,z);dlc(C,s,w,F);C2b(s,64,c[j+75200>>2]|0,c[q+8220>>2]|0,c[q+8224>>2]|0,c[q+8212>>2]|0,c[q+8216>>2]|0,t,u,c[r+40>>2]|0,b[q+8228>>1]|0,x,c[G>>2]|0,c[G+4>>2]|0)}do{if((c[j+1184592>>2]|0)==0){if((e[x>>1]|0)==0){break}tfc(F,u,B,z,e[x>>1]|0)}}while(0)}else if((A|0)==3){G=218772;if((n|0)==0){L=c[p+4>>2]|0}else{L=c[p+16>>2]|0}I=L;if((c[j+1184592>>2]|0)!=0){M=f}else{M=B}if((c[j+1184592>>2]|0)!=0){N=y}else{N=z}Chc(o,d>>6,v,3,I,M,N,B,z,c[l>>2]|0,c[m>>2]|0,n);if((c[j+75208>>2]|0)==0){ymc(32,32,C,w,f,y,B,z);N=C;M=s;L=w;if((c[j+1184588>>2]|0)!=0){ilc(N,M,L)}else{glc(N,M,L)}D2b(s,1024,c[j+75200>>2]|0,c[q+8220>>2]|0,c[q+8224>>2]|0,c[q+8212>>2]|0,c[q+8216>>2]|0,t,u,c[r+40>>2]|0,b[q+8228>>1]|0,x,c[G>>2]|0,c[G+4>>2]|0)}do{if((c[j+1184592>>2]|0)==0){if((e[x>>1]|0)==0){break}rfc(u,B,z,e[x>>1]|0)}}while(0)}else if((A|0)==2){L=c[c[o+160>>2]>>2]|0;do{if((c[r+4>>2]|0)!=0){D=22}else{if((c[L+20>>2]|0)>0){D=22;break}O=c[1064496+(c[L+4>>2]<<2)>>2]|0}}while(0);if((D|0)==22){O=0}F=O;G=204584+(F*12|0)|0;if((n|0)==0){P=c[p+4>>2]|0}else{P=c[p+16>>2]|0}I=P;if((c[j+1184592>>2]|0)!=0){Q=f}else{Q=B}if((c[j+1184592>>2]|0)!=0){R=y}else{R=z}Chc(o,d>>4,v,2,I,Q,R,B,z,c[l>>2]|0,c[m>>2]|0,n);if((c[j+75208>>2]|0)==0){ymc(16,16,C,w,f,y,B,z);flc(C,s,w,F);C2b(s,256,c[j+75200>>2]|0,c[q+8220>>2]|0,c[q+8224>>2]|0,c[q+8212>>2]|0,c[q+8216>>2]|0,t,u,c[r+40>>2]|0,b[q+8228>>1]|0,x,c[G>>2]|0,c[G+4>>2]|0)}do{if((c[j+1184592>>2]|0)==0){if((e[x>>1]|0)==0){break}ufc(F,u,B,z,e[x>>1]|0)}}while(0)}else if((A|0)==0){A=o;R=d;Q=c[c[A+160>>2]>>2]|0;do{if((c[r+4>>2]|0)!=0){D=61}else{if((c[A+25808>>2]|0)!=0){D=61;break}if((c[Q+20>>2]|0)>0){D=61;break}P=Q;if((c[P>>2]|0)>>>0<3>>>0){S=c[P+76+(R*12|0)>>2]|0}else{S=c[P+4>>2]|0}T=c[1064496+(S<<2)>>2]|0}}while(0);if((D|0)==61){T=0}F=T;G=204488+(F*12|0)|0;if((n|0)==0){T=c[c[o+160>>2]>>2]|0;if((c[T>>2]|0)>>>0<3>>>0){U=c[T+76+(d*12|0)>>2]|0}else{U=c[T+4>>2]|0}V=U}else{V=c[p+16>>2]|0}I=V;if((c[j+1184592>>2]|0)!=0){W=f}else{W=B}if((c[j+1184592>>2]|0)!=0){X=y}else{X=z}Chc(o,d,v,0,I,W,X,B,z,c[l>>2]|0,c[m>>2]|0,n);if((c[j+75208>>2]|0)==0){ymc(4,4,C,w,f,y,B,z);if((F|0)!=0){$kc(C,s,w,F)}else{ef[c[j+1401812>>2]&4095](C,s,w)}C2b(s,16,c[j+75200>>2]|0,c[q+8220>>2]|0,c[q+8224>>2]|0,c[q+8212>>2]|0,c[q+8216>>2]|0,t,u,c[r+40>>2]|0,b[q+8228>>1]|0,x,c[G>>2]|0,c[G+4>>2]|0)}do{if((c[j+1184592>>2]|0)==0){if((e[x>>1]|0)==0){break}if((F|0)==0){mf[c[o+25812>>2]&2047](u,B,z,e[x>>1]|0)}else{afc(u,B,z,F)}}}while(0)}else{Cd(2268520,2539128,583,2652944)}if((b[x>>1]|0)==0){i=k;return}a[c[h+8>>2]|0]=0;i=k;return}function Hmc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=a;a=g+24720|0;c[f>>2]=g;c[f+4>>2]=0;c[f+8>>2]=(c[c[a+160>>2]>>2]|0)+12;dec(a,b,d,656,f);i=e;return}function Imc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=c[c[e+24880>>2]>>2]|0;c[e+1184592>>2]=0;c[a+4>>2]=0;c[a+20>>2]=0;if((b|0)!=0){f=(c[a>>2]|0)>>>0>=6>>>0?2:1}else{f=0}c[a+8>>2]=f;Hmc(e,c[a>>2]|0,0);a=x6b(e|0)|0;i=d;return a|0}function Jmc(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0;j=i;i=i+42056|0;m=j|0;n=j+32800|0;o=j+41e3|0;p=j+42024|0;q=j+42032|0;r=j+42040|0;s=j+42048|0;t=f;f=g;g=h;h=k;k=l;l=t+24720|0;u=t+(f*8240|0)|0;v=l+(f*52|0)|0;w=(c[(c[c[l+160>>2]>>2]|0)+20>>2]|0)>0|0;x=(c[t+(f*8240|0)+8196>>2]|0)+(g<<4<<1)|0;y=(c[u+8192>>2]|0)+(g<<4<<1)|0;z=(c[v>>2]|0)+(g<<4<<1)|0;A=e[(c[u+8200>>2]|0)+(g<<1)>>1]|0;u=c[v+4>>2]|0;B=16<<(h<<1);C=((h|0)==3)+1|0;D=c[v+40>>2]|0;v=(h|0)==0?233584:232560;E=l;l=h;F=g;H=c[c[E+160>>2]>>2]|0;do{if((c[H+20>>2]|0)>0){I=4}else{if((u|0)!=0){I=4;break}if((c[E+25808>>2]|0)!=0){I=4;break}J=H;if((c[J>>2]|0)>>>0<3>>>0){K=c[J+76+(F*12|0)>>2]|0}else{K=c[J+4>>2]|0}L=204488+(l*48|0)+((c[1064496+(K<<2)>>2]|0)*12|0)|0}}while(0);if((I|0)==4){L=218736+(l*12|0)|0}l=L;L=c[l>>2]|0;K=c[l+8>>2]|0;l=A;F=0;H=ca(c[t+75248>>2]|0,c[704232+(u<<2)>>2]|0)|0;c[p>>2]=H;c[p+4>>2]=(H|0)<0|0?-1:0;H=c[t+75244>>2]|0;c[q>>2]=H;c[q+4>>2]=(H|0)<0|0?-1:0;if((u|0)!=0){I=11}else{if((f|0)!=0){I=11}else{M=1}}do{if((I|0)==11){if((u|0)!=0){if((f|0)!=0){M=1;break}}Cd(2336096,2539128,128,2651840);return 0}}while(0);if((A|0)<=(B|0)){}else{Cd(2278824,2539128,129,2651840);return 0}if((w|0)==0){M=Erc(c[p>>2]|0,c[p+4>>2]|0,9,0)|0;H=G;c[p>>2]=M>>>4|H<<28;c[p+4>>2]=H>>4|((H|0)<0|0?-1:0)<<28}c[m+(A<<5)>>2]=0;c[m+(A<<5)+4>>2]=0;c[m+(A<<5)+8>>2]=B;a[m+(A<<5)+12|0]=11;b[m+(A<<5)+14>>1]=0;H=m+(A<<5)+16|0;M=m+(A<<5)|0;c[H>>2]=c[M>>2];c[H+4>>2]=c[M+4>>2];c[H+8>>2]=c[M+8>>2];c[H+12>>2]=c[M+12>>2];M=0;while(1){if((M|0)>=(A|0)){break}a[o+(b[L+(M<<1)>>1]|0)|0]=a[206856+(b[(c[837020]|0)+(b[y+(b[L+(M<<1)>>1]<<1)>>1]<<2)>>1]|0)|0]|0;M=M+1|0}M=A;while(1){H=M;M=H-1|0;if((H|0)<=0){break}H=b[L+(M<<1)>>1]|0;E=b[y+(H<<1)>>1]|0;if((E|0)!=0){J=0;N=c[m+(l<<5)+4>>2]|0;O=c[m+(l<<5)+20>>2]|0;P=c[m+(l<<5)>>2]|0;Q=c[m+(l<<5)+16>>2]|0;S=b[(c[837020]|0)+(E<<2)>>1]|0;if((l|0)<(B|0)){T=d[v+(M+1)|0]|0;U=Kmc(L,K,M,S,o|0)|0;P=P+(c[t+1129288+(h*13824|0)+(u*6912|0)+(w*3456|0)+(T*576|0)+(U*48|0)+(a[m+(l<<5)+12|0]<<2)>>2]|0)|0;Q=Q+(c[t+1129288+(h*13824|0)+(u*6912|0)+(w*3456|0)+(T*576|0)+(U*48|0)+(a[m+(l<<5)+28|0]<<2)>>2]|0)|0}V=P;W=Erc(V,(V|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;V=wrc(128,0,W,G)|0;W=G;X=N<<c[q>>2];Y=wrc(V>>>8|W<<24,W>>8|((W|0)<0|0?-1:0)<<24,X,(X|0)<0|0?-1:0)|0;c[r>>2]=Y;c[r+4>>2]=G;Y=Q;X=Erc(Y,(Y|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;Y=wrc(128,0,X,G)|0;X=G;W=O<<c[q>>2];V=wrc(Y>>>8|X<<24,X>>8|((X|0)<0|0?-1:0)<<24,W,(W|0)<0|0?-1:0)|0;c[s>>2]=V;c[s+4>>2]=G;if((c[r>>2]|0)==(c[s>>2]|0)&(c[r+4>>2]|0)==(c[s+4>>2]|0)){V=P;W=Erc(V,(V|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;V=wrc(128,0,W,G)|0;c[r>>2]=V&255;c[r+4>>2]=G&0;V=Q;W=Erc(V,(V|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;V=wrc(128,0,W,G)|0;c[s>>2]=V&255;c[s+4>>2]=G&0}V=c[s+4>>2]|0;W=c[r+4>>2]|0;Z=((V|0)<(W|0)|(V|0)==(W|0)&(c[s>>2]|0)>>>0<(c[r>>2]|0)>>>0)&1;W=b[(c[837022]|0)+(E<<1)>>1]|0;V=ca(C,(b[z+(H<<1)>>1]|0)-(b[x+(H<<1)>>1]|0)|0)|0;X=ca(V,V)|0;if((Z|0)!=0){_=Q}else{_=P}c[m+(M<<5)>>2]=W+_;if((Z|0)!=0){$=O}else{$=N}c[m+(M<<5)+4>>2]=X+$;c[m+(M<<5)+8>>2]=l;a[m+(M<<5)+12|0]=S;b[m+(M<<5)+14>>1]=E;c[n+(M<<3)>>2]=Z;P=c[m+(l<<5)>>2]|0;Q=c[m+(l<<5)+16>>2]|0;Y=R(E|0)|0;aa=ca(Y,b[D+(((H|0)!=0)<<1)>>1]|0)|0;do{if((aa|0)>(ca(R(b[x+(H<<1)>>1]|0)|0,C)|0)){Y=R(E|0)|0;ba=ca(Y,b[D+(((H|0)!=0)<<1)>>1]|0)|0;Y=ca(R(b[x+(H<<1)>>1]|0)|0,C)|0;if((ba|0)>=(Y+(b[D+(((H|0)!=0)<<1)>>1]|0)|0)){I=38;break}J=1}else{I=38}}while(0);if((I|0)==38){I=0;J=0}if((J|0)!=0){F=-((E|0)<0|0)|0;E=E-((F<<1)+1)|0}if((E|0)!=0){aa=b[(c[837020]|0)+(E<<2)>>1]|0;da=aa;S=aa}else{S=(a[m+(l<<5)+12|0]|0)==11?11:0;da=(a[m+(l<<5)+28|0]|0)==11?11:0}if((l|0)<(B|0)){T=d[v+(M+1)|0]|0;if((S|0)!=11){U=Kmc(L,K,M,S,o|0)|0;P=P+(c[t+1129288+(h*13824|0)+(u*6912|0)+(w*3456|0)+(T*576|0)+((((E|0)!=0^1)&1)*288|0)+(U*48|0)+(a[m+(l<<5)+12|0]<<2)>>2]|0)|0}if((da|0)!=11){U=Kmc(L,K,M,da,o|0)|0;Q=Q+(c[t+1129288+(h*13824|0)+(u*6912|0)+(w*3456|0)+(T*576|0)+((((E|0)!=0^1)&1)*288|0)+(U*48|0)+(a[m+(l<<5)+28|0]<<2)>>2]|0)|0}}aa=P;Y=Erc(aa,(aa|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;aa=wrc(128,0,Y,G)|0;Y=G;ba=N<<c[q>>2];ea=wrc(aa>>>8|Y<<24,Y>>8|((Y|0)<0|0?-1:0)<<24,ba,(ba|0)<0|0?-1:0)|0;c[r>>2]=ea;c[r+4>>2]=G;ea=Q;ba=Erc(ea,(ea|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;ea=wrc(128,0,ba,G)|0;ba=G;Y=O<<c[q>>2];aa=wrc(ea>>>8|ba<<24,ba>>8|((ba|0)<0|0?-1:0)<<24,Y,(Y|0)<0|0?-1:0)|0;c[s>>2]=aa;c[s+4>>2]=G;if((c[r>>2]|0)==(c[s>>2]|0)&(c[r+4>>2]|0)==(c[s+4>>2]|0)){aa=P;Y=Erc(aa,(aa|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;aa=wrc(128,0,Y,G)|0;c[r>>2]=aa&255;c[r+4>>2]=G&0;aa=Q;Y=Erc(aa,(aa|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;aa=wrc(128,0,Y,G)|0;c[s>>2]=aa&255;c[s+4>>2]=G&0}aa=c[s+4>>2]|0;Y=c[r+4>>2]|0;Z=((aa|0)<(Y|0)|(aa|0)==(Y|0)&(c[s>>2]|0)>>>0<(c[r>>2]|0)>>>0)&1;W=b[(c[837022]|0)+(E<<1)>>1]|0;if((J|0)!=0){V=V-((b[D+(((H|0)!=0)<<1)>>1]|0)+F^F)|0;X=ca(V,V)|0}if((Z|0)!=0){fa=Q}else{fa=P}c[m+(M<<5)+16>>2]=W+fa;if((Z|0)!=0){ga=O}else{ga=N}c[m+(M<<5)+20>>2]=X+ga;c[m+(M<<5)+24>>2]=l;if((Z|0)!=0){ha=da}else{ha=S}a[m+(M<<5)+28|0]=ha;b[m+(M<<5)+30>>1]=E;c[n+(M<<3)+4>>2]=Z;l=M}else{T=d[v+(M+1)|0]|0;S=a[m+(l<<5)+12|0]|0;da=a[m+(l<<5)+28|0]|0;if((S|0)!=11){Y=m+(l<<5)|0;c[Y>>2]=(c[Y>>2]|0)+(c[t+1129288+(h*13824|0)+(u*6912|0)+(w*3456|0)+(T*576|0)+288+(S<<2)>>2]|0);a[m+(l<<5)+12|0]=0}if((da|0)!=11){Y=m+(l<<5)+16|0;c[Y>>2]=(c[Y>>2]|0)+(c[t+1129288+(h*13824|0)+(u*6912|0)+(w*3456|0)+(T*576|0)+288+(da<<2)>>2]|0);a[m+(l<<5)+28|0]=0}c[n+(M<<3)+4>>2]=0;c[n+(M<<3)>>2]=0}}T=d[v+(M+1)|0]|0;P=c[m+(l<<5)>>2]|0;Q=c[m+(l<<5)+16>>2]|0;N=c[m+(l<<5)+4>>2]|0;O=c[m+(l<<5)+20>>2]|0;S=a[m+(l<<5)+12|0]|0;da=a[m+(l<<5)+28|0]|0;P=P+(c[t+1129288+(h*13824|0)+(u*6912|0)+(w*3456|0)+(T*576|0)+(k*48|0)+(S<<2)>>2]|0)|0;Q=Q+(c[t+1129288+(h*13824|0)+(u*6912|0)+(w*3456|0)+(T*576|0)+(k*48|0)+(da<<2)>>2]|0)|0;da=P;k=Erc(da,(da|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;da=wrc(128,0,k,G)|0;k=G;T=N<<c[q>>2];N=wrc(da>>>8|k<<24,k>>8|((k|0)<0|0?-1:0)<<24,T,(T|0)<0|0?-1:0)|0;c[r>>2]=N;c[r+4>>2]=G;N=Q;T=Erc(N,(N|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;N=wrc(128,0,T,G)|0;T=G;k=O<<c[q>>2];q=wrc(N>>>8|T<<24,T>>8|((T|0)<0|0?-1:0)<<24,k,(k|0)<0|0?-1:0)|0;c[s>>2]=q;c[s+4>>2]=G;if((c[r>>2]|0)==(c[s>>2]|0)&(c[r+4>>2]|0)==(c[s+4>>2]|0)){q=P;P=Erc(q,(q|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;q=wrc(128,0,P,G)|0;c[r>>2]=q&255;c[r+4>>2]=G&0;q=Q;Q=Erc(q,(q|0)<0|0?-1:0,c[p>>2]|0,c[p+4>>2]|0)|0;p=wrc(128,0,Q,G)|0;c[s>>2]=p&255;c[s+4>>2]=G&0}p=c[s+4>>2]|0;Q=c[r+4>>2]|0;Z=((p|0)<(Q|0)|(p|0)==(Q|0)&(c[s>>2]|0)>>>0<(c[r>>2]|0)>>>0)&1;r=-1;mrc(y|0,0,16<<(h<<1)<<1|0)|0;mrc(z|0,0,16<<(h<<1)<<1|0)|0;M=l;while(1){if((M|0)>=(A|0)){break}h=b[m+(M<<5)+(Z<<4)+14>>1]|0;s=b[L+(M<<1)>>1]|0;if((h|0)!=0){r=M}b[y+(s<<1)>>1]=h;b[z+(s<<1)>>1]=(ca(h,b[D+(((s|0)!=0)<<1)>>1]|0)|0)/(C|0)|0;l=c[m+(M<<5)+(Z<<4)+8>>2]|0;Z=c[n+(M<<3)+(Z<<2)>>2]|0;M=l}r=r+1|0;b[(c[t+(f*8240|0)+8200>>2]|0)+(g<<1)>>1]=r;i=j;return r|0}function Kmc(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0;j=c;c=f;f=h;h=d[f+(b[j+(c<<1)>>1]|0)|0]|0;a[f+(b[j+(c<<1)>>1]|0)|0]=a[206856+g|0]|0;g=e;e=f;k=c+1|0;l=(d[e+(b[g+(k<<1<<1)>>1]|0)|0]|0)+1+(d[e+(b[g+((k<<1)+1<<1)>>1]|0)|0]|0)>>1;a[f+(b[j+(c<<1)>>1]|0)|0]=h;i=i;return l|0}function Lmc(){s6b(5615792,211840);s6b(5615856,211888);s6b(5615944,211912);s6b(5615824,211856);return}function Mmc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a;a=b;b=c;c=e+15510|0;f=e+36524|0;Nmc(211840,c|0,f|0,4,b);e=0;while(1){if((e|0)>=2){break}g=c+3+(e*33|0)|0;h=f+16+(e*204|0)|0;Omc(b,h|0,g|0,-4)|0;Nmc(211888,g+1|0,h+8|0,11,b);Nmc(211912,g+11|0,h+52|0,2,b);j=0;while(1){if((j|0)>=10){break}Omc(b,h+60+(j<<3)|0,g+12+j|0,-4)|0;j=j+1|0}e=e+1|0}e=0;while(1){if((e|0)>=2){break}j=0;while(1){if((j|0)>=2){break}Nmc(211856,c+3+(e*33|0)+22+(j*3|0)|0,f+16+(e*204|0)+140+(j<<4)|0,4,b);j=j+1|0}Nmc(211856,c+3+(e*33|0)+28|0,f+16+(e*204|0)+172|0,4,b);e=e+1|0}if((a|0)==0){i=d;return}e=0;while(1){if((e|0)>=2){break}Omc(b,f+16+(e*204|0)+188|0,c+3+(e*33|0)+31|0,-4)|0;Omc(b,f+16+(e*204|0)+196|0,c+3+(e*33|0)+32|0,-4)|0;e=e+1|0}i=d;return}function Nmc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+256|0;g=f|0;h=b;b=d;d=e;if((b|0)<=32){}else{Cd(2413912,2538704,157,2649768)}u6b(a,g|0,c);c=0;while(1){if((c|0)>=(b-1|0)){break}Omc(d,g+(c<<3)|0,h+c|0,-4)|0;c=c+1|0}i=f;return}function Omc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=b;b=d;d=e;e=f;f=c[b>>2]|0;j=f+(c[b+4>>2]|0)|0;if((j|0)==0){k=128}else{l=((f<<8)+(j>>1)|0)/(j|0)|0;if((l|0)>255){m=255}else{if((l|0)<1){n=1}else{n=l}m=n}k=m&255}m=(k&255|1)&255;k=b;n=a[d]|0;l=ca(c[k>>2]|0,c[206872+((n&255)<<2)>>2]|0)|0;j=l+(ca(c[k+4>>2]|0,c[206872+(255-(n&255)<<2)>>2]|0)|0)|0;n=b;b=m;k=ca(c[n>>2]|0,c[206872+((b&255)<<2)>>2]|0)|0;l=k+(ca(c[n+4>>2]|0,c[206872+(255-(b&255)<<2)>>2]|0)|0)|0;b=(j+(c[206872+((e&255)<<2)>>2]|0)|0)>>>0>(l+(c[206872+(255-(e&255)<<2)>>2]|0)+1792|0)>>>0|0;Vmc(h,b,e&255);if((b|0)==0){o=b;i=g;return o|0}a[d]=m;Wmc(h,(m&255)>>1,7);o=b;i=g;return o|0}function Pmc(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=i;i=i+8|0;m=l|0;n=e;e=f;f=g;g=h;h=j;j=k;b[m>>1]=(b[f>>1]|0)-(b[g>>1]|0);b[m+2>>1]=(b[f+2>>1]|0)-(b[g+2>>1]|0);k=m;if((b[k>>1]|0)==0){o=(b[k+2>>1]|0)==0?0:1}else{o=(b[k+2>>1]|0)==0?2:3}k=o;if((j|0)!=0){p=(Lec(g)|0)!=0}else{p=0}j=p&1;p=5615792+(k<<3)|0;g=e;o=211840;q=h|0;r=c[p>>2]|0;s=c[p+4>>2]|0;p=0;do{t=s-1|0;s=t;u=r>>t&1;Vmc(g,u,d[q+(p<<24>>24>>1)|0]|0);p=a[o+((p<<24>>24)+u)|0]|0;}while((s|0)!=0);s=k;if((s|0)==2){v=1}else{v=(s|0)==3}if((v&1|0)!=0){Qmc(e,b[m>>1]|0,h+3|0,j)}v=k;if((v|0)==1){w=1}else{w=(v|0)==3}if((w&1|0)!=0){Qmc(e,b[m+2>>1]|0,h+36|0,j)}if((c[n+2050772>>2]|0)!=0){i=l;return}if((c[n+2046908>>2]|0)==0){i=l;return}j=R(b[f>>1]|0)|0;if((j|0)>(R(b[f+2>>1]|0)|0)){x=R(b[f>>1]|0)|0}else{x=R(b[f+2>>1]|0)|0}f=x>>3;if(f>>>0>(c[n+2047164>>2]|0)>>>0){y=f}else{y=c[n+2047164>>2]|0}c[n+2047164>>2]=y;i=l;return}function Qmc(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;i=i+8|0;j=h|0;k=b;b=e;e=f;f=g;g=(b|0)<0|0;if((g|0)!=0){l=-b|0}else{l=b}m=Kec(l-1|0,j)|0;l=c[j>>2]>>3;n=c[j>>2]>>1&3;o=c[j>>2]&1;if((b|0)!=0){}else{Cd(2266456,2538704,42,2652896)}Vmc(k,g,d[e|0]|0);g=5615856+(m<<3)|0;b=k;j=211888;p=e+1|0;q=c[g>>2]|0;r=c[g+4>>2]|0;g=0;do{s=r-1|0;r=s;t=q>>s&1;Vmc(b,t,d[p+(g<<24>>24>>1)|0]|0);g=a[j+((g<<24>>24)+t)|0]|0;}while((r|0)!=0);if((m|0)==0){r=5615944+(l<<3)|0;g=k;j=211912;p=e+11|0;b=c[r>>2]|0;q=c[r+4>>2]|0;r=0;do{t=q-1|0;q=t;s=b>>t&1;Vmc(g,s,d[p+(r<<24>>24>>1)|0]|0);r=a[j+((r<<24>>24)+s)|0]|0;}while((q|0)!=0)}else{q=m+1-1|0;r=0;while(1){if((r|0)>=(q|0)){break}Vmc(k,l>>r&1,d[e+12+r|0]|0);r=r+1|0}}if((m|0)==0){u=e+22+(l*3|0)|0}else{u=e+28|0}l=5615824+(n<<3)|0;n=k;r=211856;q=u;u=c[l>>2]|0;j=c[l+4>>2]|0;l=0;do{p=j-1|0;j=p;g=u>>p&1;Vmc(n,g,d[q+(l<<24>>24>>1)|0]|0);l=a[r+((l<<24>>24)+g)|0]|0;}while((j|0)!=0);if((f|0)==0){i=h;return}if((m|0)==0){v=d[e+31|0]|0}else{v=d[e+32|0]|0}Vmc(k,o,v);i=h;return}function Rmc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=b;b=d;d=e;Xkc(a,b|0,211840);Smc(c[g>>2]|0,b+3|0,d);Smc(c[g+4>>2]|0,b+36|0,d);i=f;return}function Smc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+216|0;g=f|0;h=f+8|0;j=f+56|0;k=f+64|0;l=f+144|0;m=f+176|0;n=f+192|0;o=f+200|0;p=f+208|0;q=a;a=b;b=e;c[g>>2]=c[206872+((d[a|0]|0)<<2)>>2];c[g+4>>2]=c[206872+(255-(d[a|0]|0)<<2)>>2];Xkc(h|0,a+1|0,211888);Xkc(j|0,a+11|0,211912);e=0;while(1){if((e|0)>=10){break}c[k+(e<<3)>>2]=c[206872+((d[a+12+e|0]|0)<<2)>>2];c[k+(e<<3)+4>>2]=c[206872+(255-(d[a+12+e|0]|0)<<2)>>2];e=e+1|0}e=0;while(1){if((e|0)>=2){break}Xkc(l+(e<<4)|0,a+22+(e*3|0)|0,211856);e=e+1|0}Xkc(m|0,a+28|0,211856);if((b|0)!=0){c[n>>2]=c[206872+((d[a+31|0]|0)<<2)>>2];c[n+4>>2]=c[206872+(255-(d[a+31|0]|0)<<2)>>2];c[o>>2]=c[206872+((d[a+32|0]|0)<<2)>>2];c[o+4>>2]=c[206872+(255-(d[a+32|0]|0)<<2)>>2]}c[q>>2]=0;a=1;while(1){if((a|0)>16383){break}e=0;r=Kec(a-1|0,p)|0;e=e+(c[h+(r<<2)>>2]|0)|0;s=c[p>>2]>>3;t=c[p>>2]>>1&3;u=c[p>>2]&1;if((r|0)==0){e=e+(c[j+(s<<2)>>2]|0)|0}else{v=r+1-1|0;w=0;while(1){if((w|0)>=(v|0)){break}e=e+(c[k+(w<<3)+((s>>w&1)<<2)>>2]|0)|0;w=w+1|0}}if((r|0)==0){e=e+(c[l+(s<<4)+(t<<2)>>2]|0)|0}else{e=e+(c[m+(t<<2)>>2]|0)|0}if((b|0)!=0){if((r|0)==0){e=e+(c[n+(u<<2)>>2]|0)|0}else{e=e+(c[o+(u<<2)>>2]|0)|0}}c[q+(a<<2)>>2]=e+(c[g>>2]|0);c[q+(-a<<2)>>2]=e+(c[g+4>>2]|0);a=a+1|0}i=f;return}function Tmc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=a;a=c[c[b+160>>2]>>2]|0;b=a|0;if(!((c[b>>2]|0)>>>0<3>>>0)){if((c[b+4>>2]|0)==13){Umc(b,b+28|0,e+36524|0)}i=d;return}f=c[777792+(c[b>>2]<<2)>>2]|0;g=c[777848+(c[b>>2]<<2)>>2]|0;h=0;while(1){if((h|0)>=2){break}j=0;while(1){if((j|0)>=2){break}k=(h<<1)+j|0;if((c[a+76+(k*12|0)>>2]|0)==13){Umc(b,a+76+(k*12|0)+4|0,e+36524|0)}j=j+f|0}h=h+g|0}i=d;return}function Umc(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=a;a=d;d=e;e=0;while(1){if((e|0)>=(((c[h+24>>2]|0)>0)+1|0)){break}j=h+36+(c[h+20+(e<<2)>>2]<<3)|0;b[g>>1]=(b[a+(e<<2)>>1]|0)-(b[j>>1]|0);b[g+2>>1]=(b[a+(e<<2)+2>>1]|0)-(b[j+2>>1]|0);Nec(g,d);e=e+1|0}i=f;return}function Vmc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=b;b=c[h+12>>2]|0;j=c[h+4>>2]|0;k=c[h>>2]|0;l=((ca(j-1|0,f)|0)>>>8)+1|0;j=l;if((e|0)!=0){k=k+l|0;j=(c[h+4>>2]|0)-l|0}l=d[211576+j|0]|0;j=j<<l;b=b+l|0;if((b|0)<0){m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+12|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}e=l-b|0;if((k<<e-1&-2147483648|0)!=0){f=(c[h+16>>2]|0)-1|0;while(1){if((f|0)>=0){y=(d[(c[h+20>>2]|0)+f|0]|0|0)==255}else{y=0}if(!y){break}a[(c[h+20>>2]|0)+f|0]=0;f=f-1|0}y=(c[h+20>>2]|0)+f|0;a[y]=(d[y]|0)+1}y=h+16|0;f=c[y>>2]|0;c[y>>2]=f+1;a[(c[h+20>>2]|0)+f|0]=k>>>((24-e|0)>>>0);k=k<<e;l=b;k=k&16777215;b=b-8|0;m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+12|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}function Wmc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=a;a=b;b=c-1|0;while(1){if((b|0)<0){break}Xmc(e,1&a>>b);b=b-1|0}i=d;return}function Xmc(a,b){a=a|0;b=b|0;var c=0;c=i;Vmc(a,b,128);i=c;return}function Ymc(a){a=a|0;var b=0;b=i;Zmc(a+2047872|0);i=b;return}function Zmc(a){a=a|0;var b=0;b=a;h[b>>3]=0.0;h[b+8>>3]=0.0;h[b+16>>3]=0.0;h[b+24>>3]=0.0;h[b+32>>3]=0.0;h[b+40>>3]=0.0;h[b+48>>3]=0.0;h[b+56>>3]=0.0;h[b+64>>3]=0.0;h[b+72>>3]=0.0;h[b+80>>3]=0.0;h[b+88>>3]=0.0;h[b+96>>3]=0.0;h[b+104>>3]=0.0;h[b+112>>3]=0.0;h[b+120>>3]=0.0;h[b+128>>3]=0.0;h[b+144>>3]=0.0;h[b+136>>3]=1.0;a=b+152|0;c[a>>2]=0;c[a+4>>2]=0;i=i;return}function _mc(a){a=a|0;var b=0,d=0;b=i;d=a;do{if((c[d+2050800>>2]|0)!=0){if((c[d+2050820>>2]|0)!=1){break}a=0;while(1){if((a|0)>=(c[d+2050816>>2]|0)){break}$mc(d+2050824+(a*960|0)+304|0,c[d+2046748>>2]|0);a=a+1|0}i=b;return}}while(0);$mc(d+2047872|0,c[d+2046748>>2]|0);i=b;return}function $mc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+136|0;e=d|0;c[e>>2]=1;c[e+8>>2]=a;c[e+12>>2]=160;qYb(b,e)|0;i=d;return}function anc(a){a=a|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0.0,ea=0,fa=0,ga=0,ha=0.0,ia=0,ja=0,ka=0,la=0;d=i;i=i+264|0;e=d|0;f=d+16|0;g=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+72|0;p=d+80|0;q=d+88|0;r=d+96|0;s=d+104|0;t=a;a=t+32768|0;u=t+1434592|0;v=a+24720|0;w=a|0;x=v|0;y=a+1400616|0;z=t;A=z+1434592|0;B=z;z=1;do{if((z|0)==1){C=c[B+1472132>>2]|0}else{if((z|0)==2){C=c[B+1472136>>2]|0;break}else{C=c[B+1472140>>2]|0;break}}}while(0);B=A+8488+((c[A+9784+(C<<2)>>2]|0)*108|0)+16|0;C=t;A=C+1434592|0;z=C;C=2;do{if((C|0)==1){D=c[z+1472132>>2]|0}else{if((C|0)==2){D=c[z+1472136>>2]|0;break}else{D=c[z+1472140>>2]|0;break}}}while(0);z=A+8488+((c[A+9784+(D<<2)>>2]|0)*108|0)+16|0;D=u;A=D+8488+((c[D+10008>>2]|0)*108|0)+16|0;D=c[B+16>>2]|0;C=c[B+36>>2]|0;E=16>>((c[B+4>>2]|0)>(c[B+24>>2]|0));c[f>>2]=0;c[f+4>>2]=0;c[g>>2]=0;c[g+4>>2]=0;c[j>>2]=0;c[j+4>>2]=0;F=0;H=0;I=0;J=0;c[k>>2]=0;c[k+4>>2]=0;c[l>>2]=0;c[l+4>>2]=0;K=0;L=0;M=0;N=256;O=0;P=0;Q=0;S=0;T=t+2047856|0;U=B;do{if((c[t+2050800>>2]|0)!=0){if((c[t+2050820>>2]|0)!=1){break}V=1;W=0;T=t+2050824+((c[t+2050808>>2]|0)*960|0)+288|0;E1b(t);if((c[t+2046872>>2]&1|0)!=0){W=M3b(t,1)|0;V=1}else{if((c[t+2046872>>2]&4|0)!=0){W=M3b(t,3)|0;V=3}}if((W|0)!=0){U=W;D=c[U+16>>2]|0;C=c[U+36>>2]|0;E=16>>((c[U+4>>2]|0)>(c[U+24>>2]|0))}z=0;W=u;X=v;Y=V;V=-1;if((Y|0)>=1){Z=Y-1|0}else{Z=0}c[X+188>>2]=W+9816+(Z<<6);if((V|0)>=1){_=V-1|0}else{_=0}c[X+192>>2]=W+9816+(_<<6)}}while(0);qlc(a,c[t+1471904>>2]|0,0,0);Agc(v,0,U,0,0,0);zgc(v,A,0,0);c[v+160>>2]=c[u+10204>>2];c[c[v+160>>2]>>2]=c[u+10188>>2];gec(a+24720|0,c[u+8476>>2]|0,c[u+8480>>2]|0);J2b(t);_=0;while(1){if((_|0)>=3){break}c[w+(_*8240|0)+8196>>2]=c[y+272+(_*12|0)+4>>2];c[w+(_*8240|0)+8192>>2]=c[y+308+(_*12|0)+4>>2];c[x+(_*52|0)>>2]=c[y+344+(_*12|0)+4>>2];c[w+(_*8240|0)+8200>>2]=c[y+380+(_*12|0)+4>>2];_=_+1|0}c[a+75208>>2]=0;Sec(u);B3b(t);_hc(e,u,0,0);_=0;while(1){if((_|0)>=(c[u+10144>>2]|0)){break}c[m>>2]=0;c[v+164>>2]=(_|0)!=0;y=(ca(_,D)|0)<<4;w=ca(ca(_,C)|0,E)|0;c[a+1128244>>2]=-((_<<4)+20|0);c[a+1128248>>2]=((c[u+10144>>2]|0)-1-_<<4)+20;x=0;while(1){if((x|0)>=(c[u+10152>>2]|0)){break}if((x|0)!=0){$=37}else{if((_|0)!=0){$=37}else{aa=0}}if(($|0)==37){$=0;if((x|0)!=0){ba=(_|0)!=0^1}else{ba=1}aa=ba}da=1.0;Z=bnc(u,_,x)|0;c[v+16>>2]=(c[A+52>>2]|0)+y;c[v+68>>2]=(c[A+56>>2]|0)+w;c[v+120>>2]=(c[A+60>>2]|0)+w;c[v+168>>2]=(x|0)!=0;c[c[c[v+160>>2]>>2]>>2]=Z;c[(c[c[v+160>>2]>>2]|0)+20>>2]=0;W=v;X=_<<1;V=c[777736+(Z<<2)>>2]|0;Y=x<<1;ea=c[777680+(Z<<2)>>2]|0;fa=c[u+10148>>2]|0;ga=c[u+10156>>2]|0;c[W+180>>2]=-(X<<3<<3);c[W+184>>2]=fa-V-X<<3<<3;c[W+172>>2]=-(Y<<3<<3);c[W+176>>2]=ga-ea-Y<<3<<3;c[W+164>>2]=(X|0)!=0;c[W+168>>2]=(Y|0)>(c[e+8>>2]|0);if((c[t+1471728>>2]|0)==1){da=+bkc(ekc(t,a,Z)|0)}Y=Imc(a,aa&1)|0;if((c[t+1471728>>2]|0)==1){Y=~~(+(Y|0)*da)}Y=Y+N|0;W=Y;X=wrc(c[f>>2]|0,c[f+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[f>>2]=X;c[f+4>>2]=G;c[a+1128236>>2]=-((x<<4)+20|0);c[a+1128240>>2]=((c[u+10152>>2]|0)-1-x<<4)+20;if((c[u+36948>>2]|0)>>>0>0>>>0){c[v+24>>2]=(c[U+52>>2]|0)+y;c[o>>2]=cnc(Z,a+8204|0,v+24|0)|0;c[q>>2]=0;c[p>>2]=0;dnc(t,a,m,p,o);if((c[t+1471728>>2]|0)==1){c[o>>2]=~~(+(c[o>>2]|0)*da)}if((c[m>>2]|0)!=0){c[n>>2]=2147483647;dnc(t,a,3345352,q,n);if((c[t+1471728>>2]|0)==1){c[n>>2]=~~(+(c[n>>2]|0)*da)}if((c[n>>2]|0)<(c[o>>2]|0)){c[o>>2]=c[n>>2];c[p>>2]=c[q>>2]}}do{if((c[u+36948>>2]|0)>>>0>1>>>0){if((z|0)==0){$=64;break}c[v+24>>2]=(c[z+52>>2]|0)+y;c[r>>2]=cnc(Z,a+8204|0,v+24|0)|0;dnc(t,a,3345352,q,r);if((c[t+1471728>>2]|0)==1){c[r>>2]=~~(+(c[r>>2]|0)*da)}do{if((c[r>>2]|0)<(c[o>>2]|0)){if((c[r>>2]|0)>=(Y|0)){break}M=M+1|0}}while(0);c[v+24>>2]=(c[U+52>>2]|0)+y;c[v+76>>2]=(c[U+56>>2]|0)+w;c[v+128>>2]=(c[U+60>>2]|0)+w;if((c[r>>2]|0)<(Y|0)){X=c[r>>2]|0;W=wrc(c[j>>2]|0,c[j+4>>2]|0,X,(X|0)<0|0?-1:0)|0;c[j>>2]=W;c[j+4>>2]=G}else{W=Y;X=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=X;c[j+4>>2]=G}}else{$=64}}while(0);if(($|0)==64){$=0;X=c[o>>2]|0;W=wrc(c[j>>2]|0,c[j+4>>2]|0,X,(X|0)<0|0?-1:0)|0;c[j>>2]=W;c[j+4>>2]=G}c[m>>2]=0;if((c[o>>2]|0)<=(Y|0)){do{if(((Y-N|0)*9|0|0)<=((c[o>>2]|0)*10|0|0)){if((Y|0)>=(N<<1|0)){break}O=O+1|0}}while(0);W=p|0;b[W>>1]=b[W>>1]<<3;W=p+2|0;b[W>>1]=b[W>>1]<<3;Y=c[o>>2]|0;c[(c[c[v+160>>2]>>2]|0)+4>>2]=13;c[(c[c[v+160>>2]>>2]|0)+28>>2]=c[p>>2];c[(c[c[v+160>>2]>>2]|0)+8>>2]=0;c[(c[c[v+160>>2]>>2]|0)+20>>2]=1;c[(c[c[v+160>>2]>>2]|0)+24>>2]=-1;tgc(v,_<<1,x<<1,Z);Bmc(a,Z);F=F+(b[p>>1]|0)|0;I=I+(R(b[p>>1]|0)|0)|0;H=H+(b[p+2>>1]|0)|0;J=J+(R(b[p+2>>1]|0)|0)|0;W=ca(b[p>>1]|0,b[p>>1]|0)|0;X=wrc(c[k>>2]|0,c[k+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[k>>2]=X;c[k+4>>2]=G;X=ca(b[p+2>>1]|0,b[p+2>>1]|0)|0;W=wrc(c[l>>2]|0,c[l+4>>2]|0,X,(X|0)<0|0?-1:0)|0;c[l>>2]=W;c[l+4>>2]=G;L=L+1|0;c[m>>2]=c[p>>2];if((c[p>>2]|0)!=0){K=K+1|0;if((c[p>>2]|0)!=(S|0)){P=P+1|0}S=c[p>>2]|0;if((_|0)<((c[u+10144>>2]|0)/2|0|0)){if((b[p>>1]|0)>0){Q=Q-1|0}else{if((b[p>>1]|0)<0){Q=Q+1|0}}}else{if((_|0)>((c[u+10144>>2]|0)/2|0|0)){if((b[p>>1]|0)>0){Q=Q+1|0}else{if((b[p>>1]|0)<0){Q=Q-1|0}}}}if((x|0)<((c[u+10152>>2]|0)/2|0|0)){if((b[p+2>>1]|0)>0){Q=Q-1|0}else{if((b[p+2>>1]|0)<0){Q=Q+1|0}}}else{if((x|0)>((c[u+10152>>2]|0)/2|0|0)){if((b[p+2>>1]|0)>0){Q=Q+1|0}else{if((b[p+2>>1]|0)<0){Q=Q-1|0}}}}}}}else{W=Y;X=wrc(c[j>>2]|0,c[j+4>>2]|0,W,(W|0)<0|0?-1:0)|0;c[j>>2]=X;c[j+4>>2]=G}X=Y;W=wrc(c[g>>2]|0,c[g+4>>2]|0,X,(X|0)<0|0?-1:0)|0;c[g>>2]=W;c[g+4>>2]=G;W=a+8204|0;c[W>>2]=(c[W>>2]|0)+16;W=a+16444|0;c[W>>2]=(c[W>>2]|0)+E;W=a+24684|0;c[W>>2]=(c[W>>2]|0)+E;y=y+16|0;w=w+E|0;x=x+1|0}x=a+8204|0;c[x>>2]=(c[x>>2]|0)+((c[a+8208>>2]<<4)-(c[u+10152>>2]<<4));x=ca(E,c[a+16448>>2]|0)|0;w=x-(ca(E,c[u+10152>>2]|0)|0)|0;x=a+16444|0;c[x>>2]=(c[x>>2]|0)+w;w=ca(E,c[a+16448>>2]|0)|0;x=w-(ca(E,c[u+10152>>2]|0)|0)|0;w=a+24684|0;c[w>>2]=(c[w>>2]|0)+x;_=_+1|0}h[s>>3]=+((c[u+36948>>2]|0)>>>0>>>0);_=c[t+2050808>>2]|0;a=s+152|0;c[a>>2]=_;c[a+4>>2]=(_|0)<0|0?-1:0;_=c[f+4>>2]|0;h[s+8>>3]=+(((c[f>>2]|0)>>>8|_<<24)>>>0)+ +(_>>8|((_|0)<0|0?-1:0)<<24|0)*4294967296.0;_=c[g+4>>2]|0;h[s+16>>3]=+(((c[g>>2]|0)>>>8|_<<24)>>>0)+ +(_>>8|((_|0)<0|0?-1:0)<<24|0)*4294967296.0;_=c[j+4>>2]|0;h[s+24>>3]=+(((c[j>>2]|0)>>>8|_<<24)>>>0)+ +(_>>8|((_|0)<0|0?-1:0)<<24|0)*4294967296.0;da=+h[s+16>>3];h[s+32>>3]=da*+enc(c[t+1471904>>2]|0);h[s+144>>3]=1.0;h[s+40>>3]=+(L|0)/+(c[u+10140>>2]|0);h[s+56>>3]=+(M|0)/+(c[u+10140>>2]|0);h[s+64>>3]=+(O|0)/+(c[u+10140>>2]|0);if((K|0)>0){h[s+72>>3]=+(F|0)/+(K|0);h[s+80>>3]=+(I|0)/+(K|0);h[s+88>>3]=+(H|0)/+(K|0);h[s+96>>3]=+(J|0)/+(K|0);h[s+104>>3]=(+((c[k>>2]|0)>>>0)+ +(c[k+4>>2]|0)*4294967296.0- +h[s+72>>3]*+h[s+72>>3]/+(K|0))/+(K|0);h[s+112>>3]=(+((c[l>>2]|0)>>>0)+ +(c[l+4>>2]|0)*4294967296.0- +h[s+88>>3]*+h[s+88>>3]/+(K|0))/+(K|0);h[s+120>>3]=+(Q|0)/+(K<<1|0);h[s+128>>3]=+(P|0);h[s+48>>3]=+(K|0)/+(c[u+10140>>2]|0)}else{h[s+72>>3]=0.0;h[s+80>>3]=0.0;h[s+88>>3]=0.0;h[s+96>>3]=0.0;h[s+104>>3]=0.0;h[s+112>>3]=0.0;h[s+120>>3]=0.0;h[s+128>>3]=0.0;h[s+48>>3]=0.0}K=(c[t+1471892>>2]|0)+104|0;P=(c[t+1471892>>2]|0)+96|0;Q=xrc(c[K>>2]|0,c[K+4>>2]|0,c[P>>2]|0,c[P+4>>2]|0)|0;h[s+136>>3]=+(Q>>>0)+ +(G|0)*4294967296.0;nrc(T+176|0,s|0,160)|0;$mc(T+176|0,c[t+2046748>>2]|0);fnc(T+16|0,s);a:do{if((c[T+640>>2]|0)>3){$=120}else{do{if((c[u+36948>>2]|0)>>>0>0>>>0){if(!(+h[T+216>>3]>.2)){break}if(+h[T+192>>3]<0.0){ha=+h[T+192>>3]-1.0e-6}else{ha=+h[T+192>>3]+1.0e-6}if(+h[T+184>>3]/ha>2.0){$=120;break a}}}while(0);s=T+640|0;c[s>>2]=(c[s>>2]|0)+1}}while(0);if(($|0)==120){if((z|0)!=0){S7b(B,z)}c[T+640>>2]=1}do{if((c[t+2050800>>2]|0)!=0){if((c[t+2050820>>2]|0)!=1){$=127;break}D1b(t)}else{$=127}}while(0);if(($|0)==127){gnc(B,A)}P7b(B);if((c[u+36948>>2]|0)!=0){ia=u;ja=ia+36948|0;ka=c[ja>>2]|0;la=ka+1|0;c[ja>>2]=la;i=d;return}if((z|0)==0){ia=u;ja=ia+36948|0;ka=c[ja>>2]|0;la=ka+1|0;c[ja>>2]=la;i=d;return}S7b(B,z);ia=u;ja=ia+36948|0;ka=c[ja>>2]|0;la=ka+1|0;c[ja>>2]=la;i=d;return}function bnc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;if(((d<<1)+1|0)<(c[f+10156>>2]|0)){g=((a<<1)+1|0)<(c[f+10148>>2]|0)?6:5;h=g;i=e;return h|0}else{g=((a<<1)+1|0)<(c[f+10148>>2]|0)?4:3;h=g;i=e;return h|0}return 0}function cnc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;g=b;b=d;d=Gnc(a)|0;Xe[d&511](c[g>>2]|0,c[g+4>>2]|0,c[b>>2]|0,c[b+4>>2]|0,f)|0;i=e;return c[f>>2]|0}function dnc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+72|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=a;a=d;d=e;e=f;f=g;mrc(j|0,0,4)|0;b[k>>1]=b[d>>1]>>3;b[k+2>>1]=b[d+2>>1]>>3;g=0;o=3;p=10-o|0;q=c[c[c[a+24880>>2]>>2]>>2]|0;nrc(m|0,n+2047252+(q*44|0)|0,44)|0;r=256;if((c[n+1443044>>2]|0)<(c[n+1443048>>2]|0)){s=c[n+1443044>>2]|0}else{s=c[n+1443048>>2]|0}t=s;while(1){if((t<<g|0)>=1023){break}g=g+1|0}o=o+g|0;p=p-g|0;c[m+8>>2]=Gnc(q)|0;q=gf[c[n+2047248>>2]&63](a,k,j,o,c[a+75236>>2]|0,l,m,d)|0;if((q|0)<2147483647){q=doc(a,j,d,m,1)|0}if((q|0)<(2147483647-r|0)){q=q+r|0}if((q|0)<(c[f>>2]|0)){c[f>>2]=q;b[e>>1]=b[j>>1]|0;b[e+2>>1]=b[j+2>>1]|0}g=c[l>>2]|0;c[l>>2]=0;while(1){if((g|0)>=(p|0)){break}g=g+1|0;if((c[l>>2]|0)!=0){c[l>>2]=(c[l>>2]|0)-1}else{q=gf[c[n+2047248>>2]&63](a,k,j,o+g|0,c[a+75236>>2]|0,l,m,d)|0;if((q|0)<2147483647){q=doc(a,j,d,m,1)|0}if((q|0)<(2147483647-r|0)){q=q+r|0}if((q|0)<(c[f>>2]|0)){c[f>>2]=q;b[e>>1]=b[j>>1]|0;b[e+2>>1]=b[j+2>>1]|0}}}i=h;return}function enc(a){a=a|0;var b=0,e=0,f=0.0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0;b=i;e=a;f=0.0;a=c[e+8>>2]|0;g=c[e+12>>2]|0;j=c[e+52>>2]|0;k=0;while(1){if((k|0)>=(g|0)){break}l=j;m=0;while(1){if((m|0)>=(a|0)){break}n=l;l=n+1|0;f=f+ +h[152160+((d[n]|0)<<3)>>3];m=m+1|0}j=j+(c[e+16>>2]|0)|0;k=k+1|0}if(.1>f/+(ca(a,g)|0)){o=.1;i=b;return+o}else{o=f/+(ca(a,g)|0);i=b;return+o}return 0.0}function fnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a;a=b;b=d|0;h[b>>3]=+h[b>>3]+ +h[a>>3];b=a+152|0;e=c[b+4>>2]|0;f=d+152|0;c[f>>2]=c[b>>2];c[f+4>>2]=e;e=d+8|0;h[e>>3]=+h[e>>3]+ +h[a+8>>3];e=d+16|0;h[e>>3]=+h[e>>3]+ +h[a+16>>3];e=d+24|0;h[e>>3]=+h[e>>3]+ +h[a+24>>3];e=d+32|0;h[e>>3]=+h[e>>3]+ +h[a+32>>3];e=d+40|0;h[e>>3]=+h[e>>3]+ +h[a+40>>3];e=d+48|0;h[e>>3]=+h[e>>3]+ +h[a+48>>3];e=d+56|0;h[e>>3]=+h[e>>3]+ +h[a+56>>3];e=d+64|0;h[e>>3]=+h[e>>3]+ +h[a+64>>3];e=d+72|0;h[e>>3]=+h[e>>3]+ +h[a+72>>3];e=d+80|0;h[e>>3]=+h[e>>3]+ +h[a+80>>3];e=d+88|0;h[e>>3]=+h[e>>3]+ +h[a+88>>3];e=d+96|0;h[e>>3]=+h[e>>3]+ +h[a+96>>3];e=d+104|0;h[e>>3]=+h[e>>3]+ +h[a+104>>3];e=d+112|0;h[e>>3]=+h[e>>3]+ +h[a+112>>3];e=d+120|0;h[e>>3]=+h[e>>3]+ +h[a+120>>3];e=d+128|0;h[e>>3]=+h[e>>3]+ +h[a+128>>3];e=d+144|0;h[e>>3]=+h[e>>3]+ +h[a+144>>3];e=d+136|0;h[e>>3]=+h[e>>3]+ +h[a+136>>3];i=i;return}function gnc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;i=i+96|0;d=c|0;e=a;a=b;nrc(d|0,e|0,92)|0;nrc(e|0,a|0,92)|0;nrc(a|0,d|0,92)|0;i=c;return}function hnc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,j=0.0,k=0.0,l=0,m=0,n=0,o=0;e=i;f=a;a=b;b=d;d=c[f+1444732>>2]|0;g=f+2017128|0;j=+h[a+16>>3]/+h[a+144>>3]/+(d|0);k=+(c[f+2046860>>2]|0)*.04+1.0;if((b|0)<=0){l=c[g+232>>2]|0;m=l;i=e;return m|0}a=b;b=a;n=d;d=Frc(b<<9|0>>>23,((a|0)<0|0?-1:0)<<9|b>>>23,n,(n|0)<0|0?-1:0)|0;n=d;d=c[g+236>>2]|0;while(1){if((d|0)>=(c[g+232>>2]|0)){break}if((Q2b(1,d,+inc(j,150.0,.5,.9,d)*k)|0)<=(n|0)){b=6;break}d=d+1|0}if((c[f+1471664>>2]|0)==2){if((d|0)>(c[f+2017368>>2]|0)){o=d}else{o=c[f+2017368>>2]|0}d=o}l=d;m=l;i=e;return m|0}function inc(a,b,c,d,e){a=+a;b=+b;c=+c;d=+d;e=e|0;var f=0,g=0.0,h=0,j=0.0,k=0.0,l=0.0;f=i;g=c;c=d;h=e;d=a/b;if(+O2b(h)*.0125+g<c){j=+O2b(h)*.0125+g}else{j=c}c=j;if(c<1.0){if(d>=0.0){}else{Cd(2265880,2538520,894,2653368);return 0.0}}j=+T(+d,+c);c=.05;d=5.0;if(j<c){k=c;i=f;return+k}if(j>d){l=d}else{l=j}k=l;i=f;return+k}function jnc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0;b=i;i=i+160|0;d=b|0;e=a;a=e+2050808|0;f=e+2047856|0;g=e+1471600|0;if((c[a+8>>2]|0)>1){j=(c[a+12>>2]|0)==1}else{j=0}k=j&1;if((k|0)!=0){f=a+16+((c[a>>2]|0)*960|0)+288|0}Zmc(f+16|0);Zmc(f+352|0);if((c[f+344>>2]|0)==0){i=b;return}nrc(f+16|0,c[f+344>>2]|0,160)|0;nrc(f+352|0,f+16|0,160)|0;l=+h[f+160>>3]*1.0e7/+h[f+152>>3];if((k|0)!=0){_5b(e,l);m=+h[f+152>>3]*+(c[a+16+((c[a>>2]|0)*960|0)+240>>2]|0)/1.0e7;a=(F=+m,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);j=f+520|0;c[j>>2]=~~+m>>>0;c[j+4>>2]=a}else{g1b(e,l);a=g+24|0;l=+h[f+152>>3]*(+((c[a>>2]|0)>>>0)+ +(c[a+4>>2]|0)*4294967296.0)/1.0e7;a=(F=+l,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);j=f+520|0;c[j>>2]=~~+l>>>0;c[j+4>>2]=a}if((k|0)==0){h[f+576>>3]=+((c[e+1444732>>2]|0)*150|0|0);h[f+584>>3]=+((c[e+1444732>>2]|0)*100|0|0)}c[f+640>>2]=1;l=0.0;k=c[f+336>>2]|0;while(1){if(!((knc(f,d)|0)!=-1)){break}if(+h[d+16>>3]<0.0){n=+h[d+16>>3]-1.0e-6}else{n=+h[d+16>>3]+1.0e-6}m=+h[d+8>>3]/n;o=1.0;p=20.0;if(m<o){q=o}else{if(m>p){r=p}else{r=m}q=r}l=l+q}if(+h[f+160>>3]<0.0){s=+h[f+160>>3]-1.0e-6}else{s=+h[f+160>>3]+1.0e-6}h[f+536>>3]=l/s;lnc(f,k);if(+h[f+160>>3]<0.0){t=+h[f+160>>3]-1.0e-6}else{t=+h[f+160>>3]+1.0e-6}s=+h[f+48>>3]/t;k=c[f+336>>2]|0;h[f+560>>3]=0.0;h[f+544>>3]=s*+(c[g+152>>2]|0)/100.0;h[f+552>>3]=s*+(c[g+156>>2]|0)/100.0;while(1){if(!((knc(f,d)|0)!=-1)){break}s=+mnc(e,d);g=f+560|0;h[g>>3]=+h[g>>3]+s}h[f+568>>3]=+h[f+560>>3];lnc(f,k);i=b;return}function knc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;if((c[e+336>>2]|0)>>>0>=(c[e+344>>2]|0)>>>0){f=-1;g=f;i=d;return g|0}else{nrc(b|0,c[e+336>>2]|0,160)|0;b=e+336|0;c[b>>2]=(c[b>>2]|0)+160;f=1;g=f;i=d;return g|0}return 0}function lnc(a,b){a=a|0;b=b|0;c[a+336>>2]=b;i=i;return}function mnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0.0,j=0.0,k=0.0,l=0.0,m=0.0;d=i;e=a;a=b;b=e+2047856|0;f=e+2050808|0;do{if((c[f+8>>2]|0)>1){if((c[f+12>>2]|0)!=1){break}b=f+16+((c[f>>2]|0)*960|0)+288|0}}while(0);f=b+16|0;g=+h[f+32>>3]/+h[f+144>>3];if(g<0.0){j=g-1.0e-6}else{j=g+1.0e-6}k=g*+T(+(+h[a+32>>3]/j),+(+(c[e+1471748>>2]|0)/100.0));j=k;k=+h[b+544>>3];g=+h[b+552>>3];if(j<k){l=k;i=d;return+l}if(j>g){m=g}else{m=j}l=m;i=d;return+l}function nnc(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=d+1434592|0;do{if((c[d+1472152>>2]|0)!=0){e=5}else{if((c[a+36948>>2]|0)!=0){if((c[a+10136>>2]&1|0)==0){e=5;break}}c[a+10108>>2]=0}}while(0);if((e|0)==5){c[a+10108>>2]=1}c[d+2017212>>2]=2147483647;i=b;return}function onc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0;b=i;i=i+480|0;d=b|0;e=b+160|0;f=b+320|0;g=a;a=g+1434592|0;j=g+2017128|0;k=g+2047856|0;l=0;if((c[g+2050800>>2]|0)!=0){m=(c[g+2050820>>2]|0)==1}else{m=0}n=m&1;if((n|0)!=0){l=g+2050824+((c[g+2050808>>2]|0)*960|0)|0;o=~~(+h[k+160>>3]- +((c[l+952>>2]|0)>>>0>>>0))}else{o=~~(+h[k+160>>3]- +((c[a+36948>>2]|0)>>>0>>>0))}if((c[k+336>>2]|0)==0){i=b;return}if((c[g+1472152>>2]|0)!=0){c[a+10108>>2]=1;d3b(g,c[k+632>>2]|0);i=b;return}do{if((n|0)!=0){if(!(+h[k+576>>3]==0.0)){break}h[k+576>>3]=+((c[g+1444732>>2]|0)*150|0|0);h[k+584>>3]=+((c[g+1444732>>2]|0)*100|0|0)}}while(0);if((c[g+1471664>>2]|0)==3){c[k+652>>2]=c[g+1471720>>2]}else{do{if((c[a+36948>>2]|0)==0){p=18}else{if((n|0)==0){break}if((c[l+952>>2]|0)==0){p=18}}}while(0);if((p|0)==18){l=k+520|0;n=o;o=Crc(c[l>>2]|0,c[l+4>>2]|0,n,(n|0)<0|0?-1:0)|0;n=hnc(g,k+352|0,o)|0;c[k+652>>2]=n;c[j+124>>2]=n;h[j+160>>3]=+O2b(n)}}mrc(d|0,0,160)|0;if(-1==(knc(k,d)|0)){i=b;return}q=+h[d+8>>3];r=+h[d+16>>3];do{if((c[j+84>>2]|0)==0){p=24}else{if((c[a+10136>>2]&1|0)!=0){p=24;break}c[a+10108>>2]=1}}while(0);if((p|0)==24){nrc(e|0,d|0,160)|0;pnc(g,e);do{if((c[g+2050800>>2]|0)!=0){if((c[g+2050820>>2]|0)!=1){break}if((c[g+2050808>>2]|0)<=0){break}c[a+10108>>2]=1}}while(0)}if((c[j+68>>2]|0)==0){nrc(e|0,d|0,160)|0;qnc(g,e);if((c[k+648>>2]|0)>995){if((c[a+10112>>2]|0)!=0){c[g+2047172>>2]=2}else{c[g+2047172>>2]=0}}c[j+68>>2]=c[j+80>>2];c[g+1472148>>2]=1}else{nrc(e|0,d|0,160)|0;rnc(g,e)}if(r<0.0){s=r-1.0e-6}else{s=r+1.0e-6}c[k+8>>2]=~~(q/s);if((snc(k,f)|0)!=-1){if(+h[f+16>>3]<0.0){t=+h[f+16>>3]-1.0e-6}else{t=+h[f+16>>3]+1.0e-6}c[k+4>>2]=~~(+h[f+8>>3]/t)}if((c[g+1444700>>2]|0)==0){u=S2b(g,c[j>>2]|0)|0}else{u=R2b(g,c[j>>2]|0)|0}d3b(g,u);tnc(k+352|0,d);i=b;return}function pnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0.0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,H=0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0.0,ga=0.0,ia=0.0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0.0,ra=0,sa=0,ta=0.0,ua=0.0,va=0.0;d=i;i=i+872|0;e=d|0;f=d+160|0;g=d+320|0;j=d+480|0;k=d+544|0;l=d+704|0;m=d+712|0;n=a;a=b;b=n+2017128|0;o=n+2047856|0;nrc(e|0,a|0,160)|0;p=c[o+336>>2]|0;q=1.0;r=1.0;s=0.0;t=0.0;u=0.0;nrc(j|0,1223912,64)|0;mrc(f|0,0,160)|0;c[n+1444700>>2]=0;c[b+92>>2]=c[b+96>>2];c[b+104>>2]=0;c[b+68>>2]=0;c[b+84>>2]=1;v=o+608|0;c[v>>2]=0;c[v+4>>2]=0;v=o+616|0;c[v>>2]=0;c[v+4>>2]=0;t=+mnc(n,a);v=0;a:while(1){if(!((c[o+336>>2]|0)>>>0<(c[o+344>>2]|0)>>>0)){break}u=u+ +mnc(n,a);nrc(g|0,a|0,160)|0;knc(o,a)|0;do{if((c[n+1471652>>2]|0)!=0){if(!((snc(o,f)|0)!=-1)){w=16;break}if((Fnc(o,g,a,f)|0)!=0){w=6;break a}x=+ync(n+1434592|0,f);h[j+(((v|0)%8|0)<<3)>>3]=x;q=1.0;y=0;while(1){if((y|0)>=8){break}q=q*+h[j+(y<<3)>>3];y=y+1|0}if((znc(o,v,(c[n+1472104>>2]|0)-v|0,x,q)|0)!=0){w=12;break a}y=b+84|0;c[y>>2]=(c[y>>2]|0)+1;if((c[b+84>>2]|0)>=(c[n+1472104>>2]<<1|0)){w=14;break a}}else{w=16}}while(0);if((w|0)==16){w=0;y=b+84|0;c[y>>2]=(c[y>>2]|0)+1}v=v+1|0}do{if((c[n+1471652>>2]|0)!=0){if((c[b+84>>2]|0)<=(c[n+1472104>>2]|0)){w=25;break}nrc(k|0,e|0,160)|0;j=b+84|0;c[j>>2]=(c[j>>2]|0)/2|0;lnc(o,p);u=0.0;v=0;while(1){if((v|0)>=(c[b+84>>2]|0)){break}u=u+ +mnc(n,k);knc(o,k)|0;v=v+1|0}c[b+96>>2]=1}else{w=25}}while(0);if((w|0)==25){if((c[o+336>>2]|0)==(c[o+344>>2]|0)){c[b+96>>2]=1}else{c[b+96>>2]=0}}if((c[o+336>>2]|0)>>>0>=(c[o+344>>2]|0)>>>0){u=u+ +mnc(n,a)}a=o+520|0;k=c[a+4>>2]|0;e=0;do{if((k|0)>(e|0)|(k|0)==(e|0)&(c[a>>2]|0)>>>0>0>>>0){if(!(+h[o+568>>3]>0.0)){w=36;break}j=vnc(b,n+1471600|0)|0;g=o+520|0;z=(+((c[g>>2]|0)>>>0)+ +(c[g+4>>2]|0)*4294967296.0)*(u/+h[o+568>>3]);g=(F=+z,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);y=o+608|0;c[y>>2]=~~+z>>>0;c[y+4>>2]=g;g=j;j=c[b+84>>2]|0;y=Erc(g,(g|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;c[l>>2]=y;c[l+4>>2]=G;y=o+608|0;j=c[y+4>>2]|0;g=c[l+4>>2]|0;if((j|0)>(g|0)|(j|0)==(g|0)&(c[y>>2]|0)>>>0>(c[l>>2]|0)>>>0){y=c[l+4>>2]|0;g=o+608|0;c[g>>2]=c[l>>2];c[g+4>>2]=y}}else{w=36}}while(0);if((w|0)==36){l=o+608|0;c[l>>2]=0;c[l+4>>2]=0}lnc(o,p);q=1.0;s=0.0;v=0;while(1){if((v|0)>=(c[b+84>>2]|0)){break}if(-1==(knc(o,f)|0)){w=40;break}if(+h[f+40>>3]- +h[f+48>>3]<r){r=+h[f+40>>3]- +h[f+48>>3]}if((v|0)<=(c[b+72>>2]<<1|0)){if(+h[f+8>>3]>+h[o+576>>3]){if(+h[f+16>>3]<0.0){A=+h[f+16>>3]-1.0e-6}else{A=+h[f+16>>3]+1.0e-6}B=+h[f+8>>3]*15.0/A}else{if(+h[f+16>>3]<0.0){C=+h[f+16>>3]-1.0e-6}else{C=+h[f+16>>3]+1.0e-6}B=+h[o+576>>3]*15.0/C}if(B>512.0){B=512.0}if((wnc(o,0)|0)==0){q=q*+ync(n+1434592|0,f);if(q>.1){D=q}else{D=.1}q=D}s=s+q*B}v=v+1|0}Zmc(m);lnc(o,p);v=0;while(1){if((v|0)>=(c[b+84>>2]|0)){break}knc(o,f)|0;fnc(m,f);v=v+1|0}Dnc(m);if(+h[m+16>>3]<0.0){E=+h[m+16>>3]-1.0e-6}else{E=+h[m+16>>3]+1.0e-6}c[o>>2]=~~(+h[m+8>>3]/E);lnc(o,p);p=~~s;if((p|0)<((c[b+84>>2]|0)*3|0|0)){p=(c[b+84>>2]|0)*3|0}if((p|0)<300){p=300}c[b+36>>2]=p;c[o+644>>2]=~~(r*100.0);if(r>=.99){H=(((c[b+84>>2]|0)-1|0)*10|0)+p|0}else{H=(((c[b+84>>2]|0)-1|0)*100|0)+p|0}if((p|0)>1028){m=p>>10;p=(p|0)/(m|0)|0;H=(H|0)/(m|0)|0}m=o+608|0;v=c[m+4>>2]|0;f=0;if((f|0)>(v|0)|(f|0)==(v|0)&0>>>0>(c[m>>2]|0)>>>0){I=0;J=0}else{m=o+608|0;I=c[m+4>>2]|0;J=c[m>>2]|0}m=o+608|0;c[m>>2]=J;c[m+4>>2]=I;I=o+608|0;c[o+592>>2]=~~(+(p|0)*((+((c[I>>2]|0)>>>0)+ +(c[I+4>>2]|0)*4294967296.0)/+(H|0)));if(t<u/+(c[b+84>>2]|0)){I=o+520|0;if(+h[o+568>>3]<0.0){K=+h[o+568>>3]-1.0e-6}else{K=+h[o+568>>3]+1.0e-6}m=~~(+(p|0)*((+((c[I>>2]|0)>>>0)+ +(c[I+4>>2]|0)*4294967296.0)*t*+(c[b+84>>2]|0)/K/+(H|0)));if((c[o+592>>2]|0)>(m|0)){c[o+592>>2]=m}L=o;M=L+592|0;N=c[M>>2]|0;O=N;P=(N|0)<0|0?-1:0;S=o;T=S+608|0;U=T|0;V=c[U>>2]|0;W=T+4|0;X=c[W>>2]|0;Y=xrc(V,X,O,P)|0;Z=G;_=T|0;c[_>>2]=Y;$=T+4|0;c[$>>2]=Z;aa=n;ca=o;da=ca+592|0;ea=c[da>>2]|0;d3b(aa,ea);fa=u;ga=t;ia=fa-ga;ja=~~ia;ka=ja;la=(ja|0)<0|0?-1:0;ma=o;na=ma+616|0;oa=na|0;c[oa>>2]=ka;pa=na+4|0;c[pa>>2]=la;qa=u;ra=o;sa=ra+568|0;ta=+h[sa>>3];ua=ta-qa;h[sa>>3]=ua;i=d;return}else{m=o+520|0;if(+h[o+568>>3]<0.0){va=+h[o+568>>3]-1.0e-6}else{va=+h[o+568>>3]+1.0e-6}H=~~((+((c[m>>2]|0)>>>0)+ +(c[m+4>>2]|0)*4294967296.0)*(t/va));if((H|0)>(c[o+592>>2]|0)){c[o+592>>2]=H}L=o;M=L+592|0;N=c[M>>2]|0;O=N;P=(N|0)<0|0?-1:0;S=o;T=S+608|0;U=T|0;V=c[U>>2]|0;W=T+4|0;X=c[W>>2]|0;Y=xrc(V,X,O,P)|0;Z=G;_=T|0;c[_>>2]=Y;$=T+4|0;c[$>>2]=Z;aa=n;ca=o;da=ca+592|0;ea=c[da>>2]|0;d3b(aa,ea);fa=u;ga=t;ia=fa-ga;ja=~~ia;ka=ja;la=(ja|0)<0|0?-1:0;ma=o;na=ma+616|0;oa=na|0;c[oa>>2]=ka;pa=na+4|0;c[pa>>2]=la;qa=u;ra=o;sa=ra+568|0;ta=+h[sa>>3];ua=ta-qa;h[sa>>3]=ua;i=d;return}}function qnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0,C=0,D=0.0,E=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0.0,V=0.0,W=0,X=0,Y=0,Z=0,_=0.0;d=i;i=i+368|0;e=d|0;f=d+160|0;g=d+168|0;j=d+176|0;k=d+184|0;l=d+192|0;m=d+200|0;n=d+208|0;o=a;a=b;b=o+2017128|0;p=o+1471600|0;q=o+2047856|0;mrc(e|0,0,160)|0;r=0.0;s=0.0;t=0.0;u=0.0;v=0.0;h[f>>3]=0.0;w=1.0;x=1.0;y=1.0;z=1.0;h[g>>3]=0.0;h[j>>3]=0.0;h[k>>3]=0.0;A=vnc(b,p)|0;if((c[p+228>>2]|0)!=0){B=(c[p+60>>2]|0)!=0}else{B=0}p=B&1;c[l>>2]=0;c[m>>2]=0;B=q+624|0;c[B>>2]=0;c[B+4>>2]=0;B=c[q+336>>2]|0;v=+mnc(o,a);u=v;if((c[o+1444700>>2]|0)==0){C=5}else{if((c[b+104>>2]|0)!=0){C=5}}if((C|0)==5){t=t-u}D=+((c[o+1443044>>2]|0)+(c[o+1443048>>2]|0)|0)/10.0;E=(~~+O2b(c[b+16>>2]|0)>>5)+12|0;if((E|0)>(c[b+72>>2]|0)){E=c[b+72>>2]|0}H=0;a:while(1){if((H|0)<(c[b+76>>2]|0)){I=(H|0)<(c[b+84>>2]|0)}else{I=0}if(!I){break}H=H+1|0;v=+mnc(o,a);t=t+v;if(-1==(knc(q,e)|0)){C=13;break}J=wnc(q,0)|0;xnc(e,g,j,k,f);if((J|0)==0){z=y;y=+ync(o+1434592|0,e);w=w*y;if(+h[e+40>>3]- +h[e+48>>3]<x){x=+h[e+40>>3]- +h[e+48>>3]}if((znc(q,H,5,y,z)|0)!=0){C=18;break}}r=r+w*+Anc(o,e,+h[g>>3]);if((H|0)>=(E|0)){if(x<.995){C=30;break}}do{if((H|0)>4){if(!(r>125.0)){if(!(+h[e+40>>3]<.75)){break}}if((J|0)!=0){break}if(+h[f>>3]>D){C=30;break a}if(+h[k>>3]>3.0){C=30;break a}if(+h[j>>3]<-2.0){C=30;break a}if(r-s<12.5){C=30;break a}}}while(0);nrc(a|0,e|0,160)|0;s=r}if((C|0)!=13)if((C|0)==18){p=0}else if((C|0)==30){r=s}c[q+648>>2]=~~(x*1.0e3);if(((c[b+84>>2]|0)-H|0)<4){while(1){if((H|0)>=((c[b+84>>2]|0)+(((c[b+96>>2]|0)!=0^1)&1)|0)){break}H=H+1|0;if(-1==(knc(q,a)|0)){C=36;break}if((H|0)<(c[b+84>>2]|0)){v=+mnc(o,a);t=t+v}}}do{if((c[o+1444700>>2]|0)==0){C=43}else{if((c[b+104>>2]|0)!=0){C=43;break}c[b+80>>2]=H}}while(0);if((C|0)==43){c[b+80>>2]=H-1}do{if((p|0)!=0){if((H|0)>=(c[o+1471660>>2]|0)){C=51;break}if((H|0)<4){C=51;break}if((c[b+96>>2]|0)==0){if((H|0)>((c[b+84>>2]|0)-4|0)){C=51;break}}c[b+28>>2]=Bnc(o,0,H-1|0,H-1|0,l,m)|0;c[b+100>>2]=1}else{C=51}}while(0);if((C|0)==51){c[b+28>>2]=~~r;c[b+100>>2]=0}l=q+608|0;p=c[l+4>>2]|0;a=0;do{if((p|0)>(a|0)|(p|0)==(a|0)&(c[l>>2]|0)>>>0>0>>>0){j=q+616|0;k=c[j+4>>2]|0;f=0;if(!((k|0)>(f|0)|(k|0)==(f|0)&(c[j>>2]|0)>>>0>0>>>0)){C=55;break}j=q+608|0;f=q+616|0;r=(+((c[j>>2]|0)>>>0)+ +(c[j+4>>2]|0)*4294967296.0)*(t/(+((c[f>>2]|0)>>>0)+ +(c[f+4>>2]|0)*4294967296.0));f=(F=+r,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);j=q+624|0;c[j>>2]=~~+r>>>0;c[j+4>>2]=f}else{C=55}}while(0);if((C|0)==55){l=q+624|0;c[l>>2]=0;c[l+4>>2]=0}l=q+624|0;a=c[l+4>>2]|0;p=0;if((a|0)<(p|0)|(a|0)==(p|0)&(c[l>>2]|0)>>>0<0>>>0){K=0;L=0}else{l=q+624|0;p=c[l+4>>2]|0;a=q+608|0;f=c[a+4>>2]|0;if((p|0)>(f|0)|(p|0)==(f|0)&(c[l>>2]|0)>>>0>(c[a>>2]|0)>>>0){a=q+608|0;M=c[a+4>>2]|0;N=c[a>>2]|0}else{a=q+624|0;M=c[a+4>>2]|0;N=c[a>>2]|0}K=M;L=N}N=q+624|0;c[N>>2]=L;c[N+4>>2]=K;K=q+624|0;N=c[K>>2]|0;L=c[K+4>>2]|0;K=A;M=c[b+80>>2]|0;a=Erc(K,(K|0)<0|0?-1:0,M,(M|0)<0|0?-1:0)|0;M=G;if((L|0)>(M|0)|(L|0)==(M|0)&N>>>0>a>>>0){a=A;A=c[b+80>>2]|0;N=Erc(a,(a|0)<0|0?-1:0,A,(A|0)<0|0?-1:0)|0;A=q+624|0;c[A>>2]=N;c[A+4>>2]=G}lnc(q,B);H=0;while(1){if((c[b+100>>2]|0)!=0){O=(c[o+1444700>>2]|0)!=0}else{O=0}if((H|0)>(O&1|0)){break}A=c[b+28>>2]|0;N=(ca(A,Cnc(c[b+16>>2]|0)|0)|0)/100|0;A=N;a=125;M=((c[b+80>>2]|0)+1|0)*200|0;if((A|0)<(a|0)){P=a}else{if((A|0)>(M|0)){S=M}else{S=A}P=S}N=P;do{if((c[b+100>>2]|0)!=0){if((H|0)!=0){C=77;break}T=(((c[b+80>>2]|0)+1|0)*100|0)+N|0}else{C=77}}while(0);if((C|0)==77){C=0;T=((c[b+80>>2]|0)*100|0)+(N-100)|0}if((N|0)>1023){A=N>>10;N=(N|0)/(A|0)|0;T=(T|0)/(A|0)|0}A=q+624|0;M=~~(+(N|0)*((+((c[A>>2]|0)>>>0)+ +(c[A+4>>2]|0)*4294967296.0)/+(T|0)));do{if((c[b+80>>2]|0)<1){C=82}else{if(v<t/+(c[b+80>>2]|0)){C=82;break}A=q+608|0;a=q+616|0;L=c[a+4>>2]|0;K=0;if((L|0)<(K|0)|(L|0)==(K|0)&(c[a>>2]|0)>>>0<0>>>0){a=q+616|0;U=+((c[a>>2]|0)>>>0)+ +(c[a+4>>2]|0)*4294967296.0-1.0e-6}else{a=q+616|0;U=+((c[a>>2]|0)>>>0)+ +(c[a+4>>2]|0)*4294967296.0+1.0e-6}a=~~((+((c[A>>2]|0)>>>0)+ +(c[A+4>>2]|0)*4294967296.0)*v/U);if((a|0)>(M|0)){M=a}}}while(0);if((C|0)==82){C=0;a=q+608|0;A=q+616|0;K=c[A+4>>2]|0;L=0;if((K|0)<(L|0)|(K|0)==(L|0)&(c[A>>2]|0)>>>0<0>>>0){A=q+616|0;V=+((c[A>>2]|0)>>>0)+ +(c[A+4>>2]|0)*4294967296.0-1.0e-6}else{A=q+616|0;V=+((c[A>>2]|0)>>>0)+ +(c[A+4>>2]|0)*4294967296.0+1.0e-6}A=~~(+(N|0)*((+((c[a>>2]|0)>>>0)+ +(c[a+4>>2]|0)*4294967296.0)*v*+(c[b+80>>2]|0)/V/+(T|0)));if((M|0)>(A|0)){M=A}}if((M|0)<0){M=0}if((H|0)==0){c[q+632>>2]=M}do{if((H|0)==1){C=101}else{if((c[b+100>>2]|0)!=0){break}if((c[o+1444700>>2]|0)!=0){C=101}}}while(0);if((C|0)==101){C=0;d3b(o,M)}H=H+1|0}V=t;C=(F=+V,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);T=q+616|0;P=xrc(c[T>>2]|0,c[T+4>>2]|0,~~+V>>>0,C)|0;c[T>>2]=P;c[T+4>>2]=G;if((c[b+100>>2]|0)!=0){V=t-v;T=(F=+V,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);P=q+600|0;c[P>>2]=~~+V>>>0;c[P+4>>2]=T}else{if((c[o+1444700>>2]|0)!=0){V=t-u;T=(F=+V,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);P=q+600|0;c[P>>2]=~~+V>>>0;c[P+4>>2]=T}else{V=t;T=(F=+V,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);P=q+600|0;c[P>>2]=~~+V>>>0;c[P+4>>2]=T}}if((c[b+80>>2]|0)>=3){if((c[b+100>>2]|0)!=0){W=c[m>>2]|0}else{W=c[b+28>>2]|0}m=W;if((m|0)>=150){if(20<((m-100|0)/50|0|0)){X=20}else{X=(m-100|0)/50|0}m=q+624|0;W=c[q+632>>2]|0;T=xrc(c[m>>2]|0,c[m+4>>2]|0,W,(W|0)<0|0?-1:0)|0;W=G;m=0;if((W|0)>(m|0)|(W|0)==(m|0)&T>>>0>0>>>0){T=q+624|0;m=c[q+632>>2]|0;W=xrc(c[T>>2]|0,c[T+4>>2]|0,m,(m|0)<0|0?-1:0)|0;Y=G;Z=W}else{Y=0;Z=0}W=X;X=Erc(Z,Y,W,(W|0)<0|0?-1:0)|0;W=Crc(X,G,100,0)|0;X=W;W=q+624|0;Y=xrc(c[W>>2]|0,c[W+4>>2]|0,X,(X|0)<0|0?-1:0)|0;c[W>>2]=Y;c[W+4>>2]=G}}if((c[o+1444700>>2]|0)==0){i=d;return}Zmc(n);lnc(q,B);H=0;while(1){if((H|0)>=(c[b+80>>2]|0)){break}knc(q,e)|0;fnc(n,e);H=H+1|0}Dnc(n);if(+h[n+16>>3]<0.0){_=+h[n+16>>3]-1.0e-6}else{_=+h[n+16>>3]+1.0e-6}c[q>>2]=~~(+h[n+8>>3]/_);lnc(q,B);i=d;return}function rnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0.0,h=0,j=0,k=0.0,l=0,m=0,n=0;d=i;e=a;a=e+2047856|0;f=vnc(e+2017128|0,e+1471600|0)|0;g=+mnc(e,b);b=a+600|0;h=c[b+4>>2]|0;j=0;if((h|0)>(j|0)|(h|0)==(j|0)&(c[b>>2]|0)>>>0>0>>>0){b=a+600|0;k=g/(+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0)}else{k=0.0}b=a+624|0;j=~~((+((c[b>>2]|0)>>>0)+ +(c[b+4>>2]|0)*4294967296.0)*k);if((f|0)<(c[a+624>>2]|0)){l=f}else{l=c[a+624>>2]|0}f=j;b=0;h=l;if((f|0)<(b|0)){m=b}else{if((f|0)>(h|0)){n=h}else{n=f}m=n}j=m;k=g;m=(F=+k,+R(F)>=1.0?F>0.0?(ha(+Q(F/4294967296.0),4294967295.0)|0)>>>0:~~+ba((F- +(~~F>>>0))/4294967296.0)>>>0:0);n=a+600|0;a=xrc(c[n>>2]|0,c[n+4>>2]|0,~~+k>>>0,m)|0;c[n>>2]=a;c[n+4>>2]=G;d3b(e,j);i=d;return}function snc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a;if((c[e+336>>2]|0)>>>0>=(c[e+344>>2]|0)>>>0){f=-1;g=f;i=d;return g|0}else{nrc(b|0,c[e+336>>2]|0,160)|0;f=1;g=f;i=d;return g|0}return 0}function tnc(a,b){a=a|0;b=b|0;var c=0;c=a;a=b;b=c|0;h[b>>3]=+h[b>>3]- +h[a>>3];b=c+8|0;h[b>>3]=+h[b>>3]- +h[a+8>>3];b=c+16|0;h[b>>3]=+h[b>>3]- +h[a+16>>3];b=c+24|0;h[b>>3]=+h[b>>3]- +h[a+24>>3];b=c+32|0;h[b>>3]=+h[b>>3]- +h[a+32>>3];b=c+40|0;h[b>>3]=+h[b>>3]- +h[a+40>>3];b=c+48|0;h[b>>3]=+h[b>>3]- +h[a+48>>3];b=c+56|0;h[b>>3]=+h[b>>3]- +h[a+56>>3];b=c+64|0;h[b>>3]=+h[b>>3]- +h[a+64>>3];b=c+72|0;h[b>>3]=+h[b>>3]- +h[a+72>>3];b=c+80|0;h[b>>3]=+h[b>>3]- +h[a+80>>3];b=c+88|0;h[b>>3]=+h[b>>3]- +h[a+88>>3];b=c+96|0;h[b>>3]=+h[b>>3]- +h[a+96>>3];b=c+104|0;h[b>>3]=+h[b>>3]- +h[a+104>>3];b=c+112|0;h[b>>3]=+h[b>>3]- +h[a+112>>3];b=c+120|0;h[b>>3]=+h[b>>3]- +h[a+120>>3];b=c+128|0;h[b>>3]=+h[b>>3]- +h[a+128>>3];b=c+144|0;h[b>>3]=+h[b>>3]- +h[a+144>>3];b=c+136|0;h[b>>3]=+h[b>>3]- +h[a+136>>3];i=i;return}function unc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+8|0;d=b|0;e=a;a=c[e+2017128>>2]|0;c[d>>2]=a;c[d+4>>2]=(a|0)<0|0?-1:0;a=e+2048376|0;f=xrc(c[a>>2]|0,c[a+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0;c[a>>2]=f;c[a+4>>2]=G;a=e+2048376|0;f=c[a+4>>2]|0;g=0;if((f|0)>(g|0)|(f|0)==(g|0)&(c[a>>2]|0)>>>0>0>>>0){a=e+2048376|0;h=c[a+4>>2]|0;j=c[a>>2]|0}else{h=0;j=0}a=e+2048376|0;c[a>>2]=j;c[a+4>>2]=h;if((c[e+1444700>>2]|0)==0){h=c[e+2017128>>2]|0;a=xrc(h,(h|0)<0|0?-1:0,c[d>>2]|0,c[d+4>>2]|0)|0;h=e+2048464|0;j=wrc(c[h>>2]|0,c[h+4>>2]|0,a,G)|0;c[h>>2]=j;c[h+4>>2]=G}else{h=e+2048464|0;j=xrc(c[h>>2]|0,c[h+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0;c[h>>2]=j;c[h+4>>2]=G;h=e+2048480|0;j=xrc(c[h>>2]|0,c[h+4>>2]|0,c[d>>2]|0,c[d+4>>2]|0)|0;c[h>>2]=j;c[h+4>>2]=G;h=e+2048480|0;j=c[h+4>>2]|0;d=0;if((j|0)>(d|0)|(j|0)==(d|0)&(c[h>>2]|0)>>>0>0>>>0){h=e+2048480|0;k=c[h+4>>2]|0;l=c[h>>2]|0}else{k=0;l=0}h=e+2048480|0;c[h>>2]=l;c[h+4>>2]=k}k=e+2048464|0;h=c[k+4>>2]|0;l=0;if((h|0)>(l|0)|(h|0)==(l|0)&(c[k>>2]|0)>>>0>0>>>0){k=e+2048464|0;m=c[k+4>>2]|0;n=c[k>>2]|0;o=e;p=o+2047856|0;q=p+608|0;r=q|0;c[r>>2]=n;s=q+4|0;c[s>>2]=m;i=b;return}else{m=0;n=0;o=e;p=o+2047856|0;q=p+608|0;r=q|0;c[r>>2]=n;s=q+4|0;c[s>>2]=m;i=b;return}}function vnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;f=a;a=c[f+112>>2]|0;g=c[b+156>>2]|0;b=Erc(a,(a|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;g=Crc(b,G,100,0)|0;c[e>>2]=g;c[e+4>>2]=G;g=c[e+4>>2]|0;b=0;if((g|0)<(b|0)|(g|0)==(b|0)&(c[e>>2]|0)>>>0<0>>>0){c[e>>2]=0;c[e+4>>2]=0;h=e|0;j=c[h>>2]|0;k=e+4|0;l=c[k>>2]|0;m=j;n=m;i=d;return n|0}b=c[e+4>>2]|0;g=c[f+120>>2]|0;a=(g|0)<0|0?-1:0;if((b|0)>(a|0)|(b|0)==(a|0)&(c[e>>2]|0)>>>0>g>>>0){g=c[f+120>>2]|0;c[e>>2]=g;c[e+4>>2]=(g|0)<0|0?-1:0}h=e|0;j=c[h>>2]|0;k=e+4|0;l=c[k>>2]|0;m=j;n=m;i=d;return n|0}function wnc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=i;i=i+160|0;d=c|0;e=0;if(!((Enc(a,d,b)|0)!=-1)){f=e;i=c;return f|0}do{if(+h[d+56>>3]>+h[d+40>>3]){if(!(+h[d+56>>3]>=.5)){break}e=1}}while(0);f=e;i=c;return f|0}function xnc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;f=i;g=a;a=e;j=+h[g+48>>3];h[b>>3]=+h[g+120>>3]*j;b=c;h[b>>3]=+h[b>>3]+ +h[g+120>>3]*j;k=+R(+(+h[g+120>>3]*j));b=d;h[b>>3]=+h[b>>3]+k;if(!(j>.05)){i=f;return}k=+R(+(+h[g+80>>3]));if(+R(+(+h[g+72>>3]))<0.0){l=+R(+(+h[g+72>>3]))-1.0e-6}else{l=+R(+(+h[g+72>>3]))+1.0e-6}m=k/l;l=+R(+(+h[g+96>>3]));if(+R(+(+h[g+88>>3]))<0.0){n=+R(+(+h[g+88>>3]))-1.0e-6}else{n=+R(+(+h[g+88>>3]))+1.0e-6}k=l/n;if(m<+h[g+80>>3]){o=m*j}else{o=+h[g+80>>3]*j}b=a;h[b>>3]=+h[b>>3]+o;if(k<+h[g+96>>3]){p=k*j}else{p=+h[g+96>>3]*j}g=a;h[g>>3]=+h[g>>3]+p;i=f;return}function ync(a,b){a=a|0;b=b|0;var d=0,e=0,f=0.0,g=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0;d=i;e=b;f=(+h[e+24>>3]- +h[e+16>>3])/+(c[a+10140>>2]|0);if(f<=512.0){g=+T(+(1.0-f/512.0),+.5);f=.85;j=1.0;if(g<f){k=f}else{if(g>j){l=j}else{l=g}k=l}m=k}else{m=.85}k=m;if(k<+h[e+40>>3]){n=k;i=d;return+n}else{n=+h[e+40>>3];i=d;return+n}return 0.0}function znc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=+e;f=+f;var g=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+160|0;j=g|0;k=a;a=d;d=0;if((b|0)<=4){l=d;i=g;return l|0}if(!(e>=.999)){l=d;i=g;return l|0}if(!(f<.9)){l=d;i=g;return l|0}b=c[k+336>>2]|0;m=0;while(1){if((m|0)>=(a|0)){break}if(-1==(knc(k,j)|0)){n=7;break}if(+h[j+40>>3]- +h[j+48>>3]<.999){n=9;break}m=m+1|0}lnc(k,b);if((m|0)==(a|0)){d=1}l=d;i=g;return l|0}function Anc(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0.0,g=0.0,j=0.0,k=0.0,l=0.0;d=i;e=a;a=b;f=c;if(+h[a+8>>3]>+h[e+2048440>>3]){if(+h[a+16>>3]<0.0){g=+h[a+16>>3]-1.0e-6}else{g=+h[a+16>>3]+1.0e-6}j=12.5*+h[a+8>>3]/g}else{if(+h[a+16>>3]<0.0){k=+h[a+16>>3]-1.0e-6}else{k=+h[a+16>>3]+1.0e-6}j=12.5*+h[e+2048440>>3]/k}if(f>0.0){j=j+j*f*2.0}else{j=j+j*(f/2.0)}if(j<96.0){l=j;i=d;return+l}else{l=96.0;i=d;return+l}return 0.0}function Bnc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0.0,z=0;j=i;i=i+192|0;k=j|0;l=j+160|0;m=j+168|0;n=j+176|0;o=j+184|0;p=a;a=b;b=d;d=e;e=f;f=g;g=p+2047856|0;q=0.0;h[l>>3]=0.0;r=1.0;h[m>>3]=0.0;h[n>>3]=0.0;h[o>>3]=0.0;s=0;t=0;while(1){if((t|0)>=(b|0)){break}if((Enc(g,k,t+a|0)|0)==-1){u=4;break}xnc(k,m,n,o,l);if((wnc(g,t+a|0)|0)!=0){v=1}else{v=(wnc(g,t+a+1|0)|0)!=0}s=v&1;if((s|0)==0){r=r*+ync(p+1434592|0,k);if(r<.1){w=.1}else{w=r}r=w}q=q+r*+Anc(p,k,+h[m>>3]);t=t+1|0}c[e>>2]=~~q;q=0.0;h[l>>3]=0.0;r=1.0;h[m>>3]=0.0;h[n>>3]=0.0;h[o>>3]=0.0;t=-1;while(1){if((t|0)<(-d|0)){break}if((Enc(g,k,t+a|0)|0)==-1){u=17;break}xnc(k,m,n,o,l);if((wnc(g,t+a|0)|0)!=0){x=1}else{x=(wnc(g,t+a+1|0)|0)!=0}s=x&1;if((s|0)==0){r=r*+ync(p+1434592|0,k);if(r<.1){y=.1}else{y=r}r=y}q=q+r*+Anc(p,k,+h[m>>3]);t=t-1|0}c[f>>2]=~~q;t=(c[e>>2]|0)+(c[f>>2]|0)|0;if((t|0)>=((d+b|0)*20|0|0)){z=t;i=j;return z|0}t=(d+b|0)*20|0;z=t;i=j;return z|0}function Cnc(a){a=a|0;var b=0,c=0.0;b=i;c=+O2b(a);i=b;return~~(828.0e-8*c*c*c+-.0055*c*c+1.32*c+79.3)|0}function Dnc(a){a=a|0;var b=0,c=0;b=i;c=a;if(+h[c+144>>3]<1.0){i=b;return}else{a=c+8|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+16|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+24|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+32|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+40|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+56|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+64|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+48|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+72|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+80|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+88|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+96|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+104|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+112|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+120|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];a=c+136|0;h[a>>3]=+h[a>>3]/+h[c+144>>3];i=b;return}}function Enc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;d=c[f+336>>2]|0;do{if((b|0)>=0){if(!((d+(b*160|0)|0)>>>0>=(c[f+344>>2]|0)>>>0)){break}g=-1;h=g;i=e;return h|0}else{do{if((b|0)<0){if(!((d+(b*160|0)|0)>>>0<(c[f+340>>2]|0)>>>0)){break}g=-1;h=g;i=e;return h|0}}while(0)}}while(0);nrc(a|0,d+(b*160|0)|0,160)|0;g=1;h=g;i=e;return h|0}function Fnc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0;f=i;i=i+160|0;g=f|0;j=a;a=b;b=d;d=e;e=0;if(!(+h[b+56>>3]<.1)){k=e;i=f;return k|0}if(!(+h[d+56>>3]<.1)){k=e;i=f;return k|0}do{if(!(+h[b+40>>3]<.05)){if(!(+h[b+40>>3]- +h[b+64>>3]<.35)){k=e;i=f;return k|0}if(+h[b+16>>3]<0.0){l=+h[b+16>>3]-1.0e-6}else{l=+h[b+16>>3]+1.0e-6}if(!(+h[b+8>>3]/l<2.5)){k=e;i=f;return k|0}m=+R(+(+h[a+16>>3]- +h[b+16>>3]));if(+h[b+16>>3]<0.0){n=+h[b+16>>3]-1.0e-6}else{n=+h[b+16>>3]+1.0e-6}if(m/n>.4){break}m=+R(+(+h[a+8>>3]- +h[b+8>>3]));if(+h[b+8>>3]<0.0){o=+h[b+8>>3]-1.0e-6}else{o=+h[b+8>>3]+1.0e-6}if(m/o>.4){break}if(+h[d+16>>3]<0.0){p=+h[d+16>>3]-1.0e-6}else{p=+h[d+16>>3]+1.0e-6}if(+h[d+8>>3]/p>3.5){break}k=e;i=f;return k|0}}while(0);b=c[j+336>>2]|0;nrc(g|0,d|0,160)|0;p=0.0;o=0.0;n=1.0;d=0;while(1){if((d|0)>=16){break}if(+h[g+16>>3]<0.0){q=+h[g+16>>3]-1.0e-6}else{q=+h[g+16>>3]+1.0e-6}l=12.5*+h[g+8>>3]/q;if(l>512.0){l=512.0}if(+h[g+40>>3]>.85){n=n*+h[g+40>>3]}else{n=n*((+h[g+40>>3]+.85)/2.0)}p=p+n*l;if(+h[g+40>>3]<.05){r=37;break}if(l<1.5){r=37;break}if(+h[g+40>>3]- +h[g+64>>3]<.2){if(l<3.0){r=37;break}}if(p-o<3.0){r=37;break}if(+h[g+8>>3]<200.0){r=37;break}o=p;if(-1==(knc(j,g)|0)){r=39;break}d=d+1|0}do{if(p>30.0){if((d|0)<=3){r=45;break}e=1}else{r=45}}while(0);if((r|0)==45){lnc(j,b);e=0}k=e;i=f;return k|0}function Gnc(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;if((c|0)==5){d=2}else if((c|0)==4){d=322}else if((c|0)==3){d=108}else{d=280}i=b;return d|0}function Hnc(a){a=a|0;var b=0,d=0;b=i;d=a;if((d|0)==0){i=b;return}if((c[d+16>>2]|0)!=0){a=0;while(1){if(!(a>>>0<(c[d>>2]|0)>>>0)){break}K7b((c[d+16>>2]|0)+(a*120|0)|0)|0;a=a+1|0}Qqc(c[d+16>>2]|0)}Qqc(d);i=b;return}function Inc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;h=a;a=b;b=d;d=e;e=f;f=0;j=e;k=1;l=25;if((j|0)<(k|0)){m=k}else{if((j|0)>(l|0)){n=l}else{n=j}m=n}e=m;e=e+1|0;f=Rqc(1,20)|0;a:do{if((f|0)!=0){c[f>>2]=e;c[f+16>>2]=Rqc(e,120)|0;do{if((c[f+16>>2]|0)!=0){m=0;while(1){if(!(m>>>0<e>>>0)){o=16;break}if((M7b((c[f+16>>2]|0)+(m*120|0)|0,h,a,b,d,160)|0)!=0){o=13;break}m=m+1|0}if((o|0)==13){break}else if((o|0)==16){break a}}}while(0);Hnc(f);p=0;q=p;i=g;return q|0}}while(0);p=f;q=p;i=g;return q|0}function Jnc(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=a;c[k>>2]=d;c[k+4>>2]=e;c[l>>2]=f;c[l+4>>2]=g;if(((c[m+4>>2]|0)+2|0)>>>0>(c[m>>2]|0)>>>0){n=1;o=n;i=j;return o|0}else{g=m+4|0;c[g>>2]=(c[g>>2]|0)+1;g=Knc(m,m+12|0)|0;zpc(b,g|0);b=c[k+4>>2]|0;m=g+96|0;c[m>>2]=c[k>>2];c[m+4>>2]=b;b=c[l+4>>2]|0;m=g+104|0;c[m>>2]=c[l>>2];c[m+4>>2]=b;c[g+112>>2]=h;n=0;o=n;i=j;return o|0}return 0}function Knc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=a;a=b;b=c[a>>2]|0;f=(c[e+16>>2]|0)+(b*120|0)|0;if(b>>>0<(c[e>>2]|0)>>>0){}else{Cd(2264936,2538072,36,2651688);return 0}g=b+1|0;b=g;if(!(g>>>0>=(c[e>>2]|0)>>>0)){h=b;j=a;c[j>>2]=h;k=f;i=d;return k|0}b=b-(c[e>>2]|0)|0;h=b;j=a;c[j>>2]=h;k=f;i=d;return k|0}function Lnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=0;if((c[e+4>>2]|0)==0){f=a;i=d;return f|0}do{if((b|0)==0){if((c[e+4>>2]|0)==((c[e>>2]|0)-1|0)){break}f=a;i=d;return f|0}}while(0);a=Knc(e,e+8|0)|0;b=e+4|0;c[b>>2]=(c[b>>2]|0)-1;f=a;i=d;return f|0}function Mnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;b=0;if((a|0)>=0){if((a|0)<(c[e+4>>2]|0)){a=a+(c[e+8>>2]|0)|0;if((a|0)>=(c[e>>2]|0)){a=a-(c[e>>2]|0)|0}b=(c[e+16>>2]|0)+(a*120|0)|0}f=b;i=d;return f|0}if((a|0)<0){if((-a|0)<=1){a=a+(c[e+8>>2]|0)|0;if((a|0)<0){a=a+(c[e>>2]|0)|0}b=(c[e+16>>2]|0)+(a*120|0)|0}}f=b;i=d;return f|0}function Nnc(a){a=a|0;i=i;return c[a+4>>2]|0}function Onc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=a;a=d+1434592|0;e=Nnc(c[d+1471888>>2]|0)|0;f=d;g=f+1434592|0;h=f;f=2;do{if((f|0)==1){j=c[h+1472132>>2]|0}else{if((f|0)==2){j=c[h+1472136>>2]|0;break}else{j=c[h+1472140>>2]|0;break}}}while(0);h=g+8488+((c[g+9784+(j<<2)>>2]|0)*108|0)+16|0;if((e|0)<=(c[d+2017196>>2]|0)){i=b;return}if((e|0)>25){e=25}c[d+2046852>>2]=e;j=0;while(1){if((j|0)>=(e|0)){break}mrc(c[d+2046752+(j<<2)>>2]|0,0,(ca(c[a+10144>>2]|0,c[a+10152>>2]|0)|0)<<5|0)|0;j=j+1|0}j=0;while(1){if((j|0)>=(e|0)){break}a=Mnc(c[d+1471888>>2]|0,j)|0;if((a|0)!=0){}else{Cd(2264720,2537728,406,2650008)}Pnc(d,d+2046752+(j<<2)|0,a|0,h,c[d+1471904>>2]|0);j=j+1|0}Qnc(d);i=b;return}function Pnc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;h=i;i=i+160|0;j=h|0;k=h+8|0;l=h+16|0;m=h+144|0;n=h+152|0;o=a;a=d;d=e;e=f;f=g;g=o+32768|0;p=g+24720|0;q=o+1434592|0;r=0;s=0;t=0;u=0;mrc(j|0,0,4)|0;mrc(k|0,0,4)|0;mrc(l|0,0,124)|0;c[g+1128244>>2]=-20;c[g+1128248>>2]=((c[q+10144>>2]|0)-1<<3)+20;c[p+164>>2]=0;c[p+20>>2]=c[d+16>>2];c[p+28>>2]=c[d+16>>2];c[p+72>>2]=c[d+36>>2];c[c[p+160>>2]>>2]=l;c[l>>2]=6;c[l+20>>2]=1;c[l+24>>2]=-1;l=0;while(1){if((l|0)>=(c[q+10144>>2]|0)){break}v=m;w=j;b[v>>1]=b[w>>1]|0;b[v+2>>1]=b[w+2>>1]|0;w=n;v=k;b[w>>1]=b[v>>1]|0;b[w+2>>1]=b[v+2>>1]|0;v=s;w=t;x=u;c[g+1128236>>2]=-20;c[g+1128240>>2]=((c[q+10152>>2]|0)-1<<3)+20;c[p+168>>2]=0;y=0;while(1){if((y|0)>=(c[q+10152>>2]|0)){break}z=(c[a>>2]|0)+(r+y<<5)|0;Snc(o,z,d,v,e,n,f,l,y);A=m;B=z+28|0;b[A>>1]=b[B>>1]|0;b[A+2>>1]=b[B+2>>1]|0;B=n;A=z+20|0;b[B>>1]=b[A>>1]|0;b[B+2>>1]=b[A+2>>1]|0;if((y|0)==0){A=j;B=m;b[A>>1]=b[B>>1]|0;b[A+2>>1]=b[B+2>>1]|0;B=k;A=n;b[B>>1]=b[A>>1]|0;b[B+2>>1]=b[A+2>>1]|0}c[p+168>>2]=1;v=v+16|0;x=x+16|0;w=w+16|0;A=g+1128236|0;c[A>>2]=(c[A>>2]|0)-16;A=g+1128240|0;c[A>>2]=(c[A>>2]|0)-16;y=y+1|0}c[p+164>>2]=1;s=s+(c[d+16>>2]<<4)|0;u=u+(c[e+16>>2]<<4)|0;if((f|0)!=0){t=t+(c[f+16>>2]<<4)|0}y=g+1128244|0;c[y>>2]=(c[y>>2]|0)-16;y=g+1128248|0;c[y>>2]=(c[y>>2]|0)-16;r=r+(c[q+10152>>2]|0)|0;l=l+1|0}i=h;return}function Qnc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+16|0;e=d|0;f=b;b=f+1434592|0;mrc(e|0,0,16)|0;g=c[f+2046852>>2]|0;h=DYb((ca(c[b+10144>>2]|0,c[b+10152>>2]|0)|0)<<2,1)|0;if((h|0)==0){Rnc(b|0,2,2413608,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0);i=j}if((g|0)>(c[f+2017196>>2]|0)){g=c[f+2017196>>2]|0}j=g-1|0;while(1){if((j|0)<0){break}g=f+2046752+(j<<2)|0;k=0;l=0;while(1){if((l|0)>=(c[b+10144>>2]|0)){break}m=0;while(1){if((m|0)>=(c[b+10152>>2]|0)){break}n=(c[g>>2]|0)+(k+m<<5)|0;o=c[n+24>>2]|0;p=c[n+16>>2]|0;do{if((o|0)>1e3){q=16}else{if((o|0)>(c[n>>2]|0)){q=16;break}if((o|0)>(p|0)){q=16}}}while(0);if((q|0)==16){q=0;p=h+(k+m<<2)|0;c[p>>2]=(c[p>>2]|0)+1}m=m+1|0}k=k+(c[b+10152>>2]|0)|0;l=l+1|0}j=j-1|0}j=0;while(1){if((j|0)>=(c[b+10148>>2]|0)){break}q=0;while(1){if((q|0)>=(c[b+10156>>2]|0)){break}if((c[h+((ca((j|0)/2|0,c[b+10152>>2]|0)|0)+((q|0)/2|0)<<2)>>2]|0)!=0){l=e|0;c[l>>2]=(c[l>>2]|0)+1;l=(ca(j,c[b+10156>>2]|0)|0)+q|0;a[(c[f+2047180>>2]|0)+l|0]=0}else{l=(ca(j,c[b+10156>>2]|0)|0)+q|0;a[(c[f+2047180>>2]|0)+l|0]=1;l=e+4|0;c[l>>2]=(c[l>>2]|0)+1}q=q+1|0}j=j+1|0}if((c[b+10140>>2]|0)!=0){c[f+2046856>>2]=((c[e+4>>2]|0)*100|0|0)/(ca(c[b+10148>>2]|0,c[b+10156>>2]|0)|0)|0;r=b;s=r+13408|0;J5b(s);t=h;u=t;FYb(u);i=d;return}else{c[f+2046856>>2]=0;r=b;s=r+13408|0;J5b(s);t=h;u=t;FYb(u);i=d;return}}function Rnc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=b;b=e;c[j>>2]=d;c[j+4>>2]=0;if((b|0)!=0){d=80;c[j+4>>2]=1;e=h|0;c[e>>2]=f;c[e+4>>2]=0;Ad(j+8|0,d-1|0,b|0,h|0)|0;a[j+8+(d-1)|0]=0}if((c[j+88>>2]|0)!=0){Xd(j+92|0,c[j>>2]|0)}else{i=g;return}}function Snc(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0;l=i;m=a;a=b;b=d;d=e;e=f;f=h;h=m+32768|0;n=h+24720|0;o=m+1434592|0;c[h+8204>>2]=(c[b+52>>2]|0)+d;c[h+8208>>2]=c[b+16>>2];b=o;c[n+16>>2]=(c[b+8488+((c[b+10008>>2]|0)*108|0)+68>>2]|0)+d;b=o;c[n+20>>2]=c[b+8488+((c[b+10008>>2]|0)*108|0)+32>>2];b=Tnc(m,a+4|0)|0;if((b|0)<=0){b=1}c[a>>2]=b;if((e|0)!=0){c[n+24>>2]=(c[e+52>>2]|0)+d;c[n+28>>2]=c[e+16>>2];c[a+16>>2]=Unc(m,g,a+20|0,j,k)|0}else{c[a+16>>2]=2147483647;c[a+20>>2]=0}if((f|0)!=0){c[n+24>>2]=(c[f+52>>2]|0)+d;c[n+28>>2]=c[f+16>>2];c[a+24>>2]=Vnc(m,a+28|0)|0;i=l;return}else{c[a+24>>2]=2147483647;c[a+28>>2]=0;i=l;return}}function Tnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=b;b=a+32768|0;a=b+24720|0;f=-1;g=2147483647;h=0;while(1){if(!(h>>>0<=9>>>0)){break}c[(c[c[a+160>>2]>>2]|0)+4>>2]=h;Chc(a,0,2,2,h,c[b+8204>>2]|0,c[b+8208>>2]|0,c[a+16>>2]|0,c[a+20>>2]|0,0,0,0);j=U4b(c[b+8204>>2]|0,c[b+8208>>2]|0,c[a+16>>2]|0,c[a+20>>2]|0,g)|0;if(j>>>0<g>>>0){g=j;f=h}h=h+1|0}if((e|0)==0){k=g;i=d;return k|0}c[e>>2]=f;k=g;i=d;return k|0}function Unc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=a;a=d;d=e;e=f;f=g;g=m+32768|0;n=g+24720|0;o=U4b(c[g+8204>>2]|0,c[g+8208>>2]|0,c[n+24>>2]|0,c[n+28>>2]|0,2147483647)|0;c[d>>2]=0;n=Wnc(m,a,j,e,f)|0;if(n>>>0<o>>>0){o=n;n=d;g=j;b[n>>1]=b[g>>1]|0;b[n+2>>1]=b[g+2>>1]|0}do{if((b[a>>1]|0)==0){if((b[a+2>>1]|0)!=0){break}p=o;i=h;return p|0}}while(0);mrc(k|0,0,4)|0;a=Wnc(m,k,l,e,f)|0;if(a>>>0<o>>>0){f=d;d=l;b[f>>1]=b[d>>1]|0;b[f+2>>1]=b[d+2>>1]|0;o=a}p=o;i=h;return p|0}function Vnc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a+32768|0;a=e+24720|0;f=U4b(c[e+8204>>2]|0,c[e+8208>>2]|0,c[a+24>>2]|0,c[a+28>>2]|0,2147483647)|0;c[b>>2]=0;i=d;return f|0}function Wnc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+72|0;j=h|0;k=h+48|0;l=a;a=d;d=e;e=l+32768|0;m=e+24720|0;nrc(j|0,l+2047516|0,44)|0;n=c[e+1128236>>2]|0;o=c[e+1128240>>2]|0;p=c[e+1128244>>2]|0;q=c[e+1128248>>2]|0;if((c[l+2046860>>2]|0)<8){r=(c[l+2046860>>2]|0)>5?1:0}else{r=2}s=(c[l+2046904>>2]|0)+r|0;if((s|0)<((c[l+2046900>>2]|0)-2|0)){t=s}else{t=(c[l+2046900>>2]|0)-2|0}s=t;Xnc(e,a);b[k+2>>1]=b[a+2>>1]>>3;b[k>>1]=b[a>>1]>>3;foc(e,k,s,c[e+75232>>2]|0,0,j,0,a,d)|0;Qe[c[l+2047232>>2]&3](e,d,a,c[l+1444720>>2]|0,c[e+75232>>2]|0,j,0,c[l+2046892>>2]|0,0,0,h+56|0,h+64|0)|0;c[(c[c[m+160>>2]>>2]|0)+4>>2]=13;l=(c[c[m+160>>2]>>2]|0)+28|0;j=d;b[l>>1]=b[j>>1]|0;b[l+2>>1]=b[j+2>>1]|0;tgc(m,f,g,6);c[e+1128236>>2]=n;c[e+1128240>>2]=o;c[e+1128244>>2]=p;c[e+1128248>>2]=q;q=U4b(c[e+8204>>2]|0,c[e+8208>>2]|0,c[m+16>>2]|0,c[m+20>>2]|0,2147483647)|0;i=h;return q|0}function Xnc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=a;a=d;d=(b[a+2>>1]>>3)-1023+((b[a+2>>1]&7|0)!=0?1:0)|0;g=(b[a>>1]>>3)-1023+((b[a>>1]&7|0)!=0?1:0)|0;h=(b[a+2>>1]>>3)+1023|0;j=(b[a>>1]>>3)+1023|0;if((d|0)>-2047){k=d}else{k=-2047}d=k;if((g|0)>-2047){l=g}else{l=-2047}g=l;if((h|0)<2046){m=h}else{m=2046}h=m;if((j|0)<2046){n=j}else{n=2046}j=n;if((c[f+1128236>>2]|0)<(d|0)){c[f+1128236>>2]=d}if((c[f+1128240>>2]|0)>(h|0)){c[f+1128240>>2]=h}if((c[f+1128244>>2]|0)<(g|0)){c[f+1128244>>2]=g}if((c[f+1128248>>2]|0)<=(j|0)){i=e;return}c[f+1128248>>2]=j;i=e;return}function Ync(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=0;if(16>(a|0)){f=16}else{f=a}a=f;while(1){if((a<<b|0)>=1023){break}b=b+1|0}b=b+(c[e+2046904>>2]|0)|0;if((b|0)<((c[e+2046900>>2]|0)-2|0)){g=b;b=g;h=b;i=d;return h|0}else{g=(c[e+2046900>>2]|0)-2|0;b=g;h=b;i=d;return h|0}return 0}function Znc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+8|0;j=h|0;k=a;a=d;b[j>>1]=(b[k>>1]|0)-(b[a>>1]|0);b[j+2>>1]=(b[k+2>>1]|0)-(b[a+2>>1]|0);a=j;j=f;f=a;if((b[f>>1]|0)==0){l=(b[f+2>>1]|0)==0?0:1}else{l=(b[f+2>>1]|0)==0?2:3}f=(ca((c[e+(l<<2)>>2]|0)+(c[(c[j>>2]|0)+(b[a>>1]<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(b[a+2>>1]<<2)>>2]|0)|0,g)|0)+64>>7;i=h;return f|0}function _nc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e|0;g=a;a=d;d=1;b[c[g+75220>>2]>>1]=0;b[(c[g+75220>>2]|0)+2>>1]=0;c[(c[g+75220>>2]|0)+4>>2]=0;h=1024;while(1){if((h|0)<=0){break}j=f|0;b[j>>1]=-h;b[j+2>>1]=0;k=j+4|0;b[k>>1]=h;b[k+2>>1]=0;j=k+4|0;b[j>>1]=0;b[j+2>>1]=-h;k=j+4|0;b[k>>1]=0;b[k+2>>1]=h;k=0;while(1){if((k|0)>=4){break}j=d;d=j+1|0;l=(c[g+75220>>2]|0)+(j<<3)|0;j=l|0;m=f+(k<<2)|0;b[j>>1]=b[m>>1]|0;b[j+2>>1]=b[m+2>>1]|0;m=ca(b[l>>1]|0,a)|0;c[l+4>>2]=m+(b[l+2>>1]|0);k=k+1|0}h=(h|0)/2|0}c[g+75224>>2]=d;c[g+75228>>2]=4;i=e;return}function $nc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+32|0;f=e|0;g=a;a=d;d=1;b[c[g+75220>>2]>>1]=0;b[(c[g+75220>>2]|0)+2>>1]=0;c[(c[g+75220>>2]|0)+4>>2]=0;h=1024;while(1){if((h|0)<=0){break}j=f|0;b[j>>1]=-h;b[j+2>>1]=0;k=j+4|0;b[k>>1]=h;b[k+2>>1]=0;j=k+4|0;b[j>>1]=0;b[j+2>>1]=-h;k=j+4|0;b[k>>1]=0;b[k+2>>1]=h;j=k+4|0;b[j>>1]=-h;b[j+2>>1]=-h;k=j+4|0;b[k>>1]=-h;b[k+2>>1]=h;j=k+4|0;b[j>>1]=h;b[j+2>>1]=-h;k=j+4|0;b[k>>1]=h;b[k+2>>1]=h;k=0;while(1){if((k|0)>=8){break}j=d;d=j+1|0;l=(c[g+75220>>2]|0)+(j<<3)|0;j=l|0;m=f+(k<<2)|0;b[j>>1]=b[m>>1]|0;b[j+2>>1]=b[m+2>>1]|0;m=ca(b[l>>1]|0,a)|0;c[l+4>>2]=m+(b[l+2>>1]|0);k=k+1|0}h=(h|0)/2|0}c[g+75224>>2]=d;c[g+75228>>2]=8;i=e;return}function aoc(a,d,e,f,g,h,j,k,l,m,n,o){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0;p=i;i=i+8|0;q=p|0;r=a;a=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=c[r+8204>>2]|0;s=c[r+8208>>2]|0;t=r+24720|0;u=2147483647;v=j;w=j;x=j;j=c[t+28>>2]|0;y=ca(b[a>>1]|0,j)|0;z=y+(b[a+2>>1]|0)|0;y=c[t+24>>2]|0;t=b[d>>1]|0;A=b[d+2>>1]|0;B=b[a>>1]<<3;C=b[a+2>>1]<<3;D=4;if((c[r+1128236>>2]<<3|0)>((b[d+2>>1]|0)-16383|0)){E=c[r+1128236>>2]<<3}else{E=(b[d+2>>1]|0)-16383|0}F=E;if((c[r+1128240>>2]<<3|0)<((b[d+2>>1]|0)+16383|0)){G=c[r+1128240>>2]<<3}else{G=(b[d+2>>1]|0)+16383|0}E=G;if((c[r+1128244>>2]<<3|0)>((b[d>>1]|0)-16383|0)){H=c[r+1128244>>2]<<3}else{H=(b[d>>1]|0)-16383|0}G=H;if((c[r+1128248>>2]<<3|0)<((b[d>>1]|0)+16383|0)){I=c[r+1128248>>2]<<3}else{I=(b[d>>1]|0)+16383|0}r=I;I=B;H=C;J=a|0;b[J>>1]=b[J>>1]<<3;J=a+2|0;b[J>>1]=b[J>>1]<<3;u=Xe[c[g+8>>2]&511](y+z|0,j,o,s,n)|0;c[m>>2]=u;u=u+(boc(a,d,k,l,f)|0)|0;do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=23;break}if((I|0)<(G|0)){K=23;break}if((I|0)>(r|0)){K=23;break}z=y+((ca(I>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](z,j,(H-D&7)<<1,(I&7)<<1,o,s,q)|0;if((l|0)!=0){M=(ca((c[k+((((I|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{M=0}z=M+L|0;N=z;if(z>>>0<u>>>0){u=N;B=I;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=23}}while(0);if((K|0)==23){N=2147483647}do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=34;break}if((I|0)<(G|0)){K=34;break}if((I|0)>(r|0)){K=34;break}M=y+((ca(I>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](M,j,(H+D&7)<<1,(I&7)<<1,o,s,q)|0;if((l|0)!=0){O=(ca((c[k+((((I|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{O=0}M=O+L|0;P=M;if(M>>>0<u>>>0){u=P;B=I;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=34}}while(0);if((K|0)==34){P=2147483647}do{if((H|0)>=(F|0)){if((H|0)>(E|0)){K=45;break}if((I-D|0)<(G|0)){K=45;break}if((I-D|0)>(r|0)){K=45;break}O=y+((ca(I-D>>3,j)|0)+(H>>3))|0;L=me[c[g+12>>2]&255](O,j,(H&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){Q=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Q=0}O=Q+L|0;S=O;if(O>>>0<u>>>0){u=S;B=I-D|0;C=H;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=45}}while(0);if((K|0)==45){S=2147483647}do{if((H|0)>=(F|0)){if((H|0)>(E|0)){K=56;break}if((I+D|0)<(G|0)){K=56;break}if((I+D|0)>(r|0)){K=56;break}Q=y+((ca(I+D>>3,j)|0)+(H>>3))|0;L=me[c[g+12>>2]&255](Q,j,(H&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){T=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{T=0}Q=T+L|0;U=Q;if(Q>>>0<u>>>0){u=U;B=I+D|0;C=H;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=56}}while(0);if((K|0)==56){U=2147483647}T=(N>>>0<P>>>0?0:1)+(S>>>0<U>>>0?0:2)|0;U=T;if((U|0)==0){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=68;break}if((I-D|0)<(G|0)){K=68;break}if((I-D|0)>(r|0)){K=68;break}S=y+((ca(I-D>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](S,j,(H-D&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){V=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{V=0}S=V+L|0;W=S;if(S>>>0<u>>>0){u=W;B=I-D|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=68}}while(0);if((K|0)==68){W=2147483647}}else if((U|0)==2){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=92;break}if((I+D|0)<(G|0)){K=92;break}if((I+D|0)>(r|0)){K=92;break}V=y+((ca(I+D>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](V,j,(H-D&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){X=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{X=0}V=X+L|0;W=V;if(V>>>0<u>>>0){u=W;B=I+D|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=92}}while(0);if((K|0)==92){W=2147483647}}else if((U|0)==3){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=104;break}if((I+D|0)<(G|0)){K=104;break}if((I+D|0)>(r|0)){K=104;break}X=y+((ca(I+D>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](X,j,(H+D&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){Y=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Y=0}X=Y+L|0;W=X;if(X>>>0<u>>>0){u=W;B=I+D|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=104}}while(0);if((K|0)==104){W=2147483647}}else if((U|0)==1){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=80;break}if((I-D|0)<(G|0)){K=80;break}if((I-D|0)>(r|0)){K=80;break}U=y+((ca(I-D>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](U,j,(H+D&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){Z=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Z=0}U=Z+L|0;W=U;if(U>>>0<u>>>0){u=W;B=I-D|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=80}}while(0);if((K|0)==80){W=2147483647}}if(v>>>0>1>>>0){do{if((I|0)!=(B|0)){if((H|0)==(C|0)){K=132;break}_=B-I|0;$=C-H|0;do{if((H+($<<1)|0)>=(F|0)){if((H+($<<1)|0)>(E|0)){K=119;break}if((I+_|0)<(G|0)){K=119;break}if((I+_|0)>(r|0)){K=119;break}v=y+((ca(I+_>>3,j)|0)+(H+($<<1)>>3))|0;L=me[c[g+12>>2]&255](v,j,(H+($<<1)&7)<<1,(I+_&7)<<1,o,s,q)|0;if((l|0)!=0){aa=(ca((c[k+((((I+_|0)!=(t|0))<<1)+((H+($<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+_-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+($<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{aa=0}v=aa+L|0;ba=v;if(v>>>0<u>>>0){u=ba;B=I+_|0;C=H+($<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=119}}while(0);if((K|0)==119){ba=2147483647}do{if((H+$|0)>=(F|0)){if((H+$|0)>(E|0)){K=130;break}if((I+(_<<1)|0)<(G|0)){K=130;break}if((I+(_<<1)|0)>(r|0)){K=130;break}v=y+((ca(I+(_<<1)>>3,j)|0)+(H+$>>3))|0;L=me[c[g+12>>2]&255](v,j,(H+$&7)<<1,(I+(_<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){da=(ca((c[k+((((I+(_<<1)|0)!=(t|0))<<1)+((H+$|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(_<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+$-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{da=0}v=da+L|0;ba=v;if(v>>>0<u>>>0){u=ba;B=I+(_<<1)|0;C=H+$|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=130}}while(0);if((K|0)==130){ba=2147483647}}else{K=132}}while(0);if((K|0)==132){do{if((I|0)==(B|0)){if((H|0)==(C|0)){K=182;break}$=C-H|0;do{if((H+($<<1)|0)>=(F|0)){if((H+($<<1)|0)>(E|0)){K=144;break}if((I+D|0)<(G|0)){K=144;break}if((I+D|0)>(r|0)){K=144;break}da=y+((ca(I+D>>3,j)|0)+(H+($<<1)>>3))|0;L=me[c[g+12>>2]&255](da,j,(H+($<<1)&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){ea=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+($<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+($<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ea=0}da=ea+L|0;ba=da;if(da>>>0<u>>>0){u=ba;B=I+D|0;C=H+($<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=144}}while(0);if((K|0)==144){ba=2147483647}do{if((H+($<<1)|0)>=(F|0)){if((H+($<<1)|0)>(E|0)){K=155;break}if((I-D|0)<(G|0)){K=155;break}if((I-D|0)>(r|0)){K=155;break}da=y+((ca(I-D>>3,j)|0)+(H+($<<1)>>3))|0;L=me[c[g+12>>2]&255](da,j,(H+($<<1)&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){fa=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+($<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+($<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{fa=0}da=fa+L|0;ba=da;if(da>>>0<u>>>0){u=ba;B=I-D|0;C=H+($<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=155}}while(0);if((K|0)==155){ba=2147483647}da=T;if((da|0)==0|(da|0)==1){do{if((H+$|0)>=(F|0)){if((H+$|0)>(E|0)){K=167;break}if((I+D|0)<(G|0)){K=167;break}if((I+D|0)>(r|0)){K=167;break}aa=y+((ca(I+D>>3,j)|0)+(H+$>>3))|0;L=me[c[g+12>>2]&255](aa,j,(H+$&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){ga=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+$|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+$-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ga=0}aa=ga+L|0;ba=aa;if(aa>>>0<u>>>0){u=ba;B=I+D|0;C=H+$|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=167}}while(0);if((K|0)==167){ba=2147483647}}else if((da|0)==2|(da|0)==3){do{if((H+$|0)>=(F|0)){if((H+$|0)>(E|0)){K=179;break}if((I-D|0)<(G|0)){K=179;break}if((I-D|0)>(r|0)){K=179;break}aa=y+((ca(I-D>>3,j)|0)+(H+$>>3))|0;L=me[c[g+12>>2]&255](aa,j,(H+$&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){ha=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+$|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+$-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ha=0}aa=ha+L|0;ba=aa;if(aa>>>0<u>>>0){u=ba;B=I-D|0;C=H+$|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=179}}while(0);if((K|0)==179){ba=2147483647}}}else{K=182}}while(0);if((K|0)==182){do{if((I|0)!=(B|0)){if((H|0)!=(C|0)){break}_=B-I|0;do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=194;break}if((I+(_<<1)|0)<(G|0)){K=194;break}if((I+(_<<1)|0)>(r|0)){K=194;break}$=y+((ca(I+(_<<1)>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255]($,j,(H+D&7)<<1,(I+(_<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){ia=(ca((c[k+((((I+(_<<1)|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(_<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ia=0}$=ia+L|0;ba=$;if($>>>0<u>>>0){u=ba;B=I+(_<<1)|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=194}}while(0);if((K|0)==194){ba=2147483647}do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=205;break}if((I+(_<<1)|0)<(G|0)){K=205;break}if((I+(_<<1)|0)>(r|0)){K=205;break}$=y+((ca(I+(_<<1)>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255]($,j,(H-D&7)<<1,(I+(_<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){ja=(ca((c[k+((((I+(_<<1)|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(_<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ja=0}$=ja+L|0;ba=$;if($>>>0<u>>>0){u=ba;B=I+(_<<1)|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=205}}while(0);if((K|0)==205){ba=2147483647}$=T;if(($|0)==1|($|0)==3){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=229;break}if((I+_|0)<(G|0)){K=229;break}if((I+_|0)>(r|0)){K=229;break}ha=y+((ca(I+_>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](ha,j,(H-D&7)<<1,(I+_&7)<<1,o,s,q)|0;if((l|0)!=0){ka=(ca((c[k+((((I+_|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+_-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ka=0}ha=ka+L|0;ba=ha;if(ha>>>0<u>>>0){u=ba;B=I+_|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=229}}while(0);if((K|0)==229){ba=2147483647}}else if(($|0)==0|($|0)==2){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=217;break}if((I+_|0)<(G|0)){K=217;break}if((I+_|0)>(r|0)){K=217;break}ha=y+((ca(I+_>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](ha,j,(H+D&7)<<1,(I+_&7)<<1,o,s,q)|0;if((l|0)!=0){la=(ca((c[k+((((I+_|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+_-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{la=0}ha=la+L|0;ba=ha;if(ha>>>0<u>>>0){u=ba;B=I+_|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=217}}while(0);if((K|0)==217){ba=2147483647}}}}while(0)}}}I=B;H=C;if((h|0)!=2){D=D>>1;do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=246;break}if((I|0)<(G|0)){K=246;break}if((I|0)>(r|0)){K=246;break}ba=y+((ca(I>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](ba,j,(H-D&7)<<1,(I&7)<<1,o,s,q)|0;if((l|0)!=0){ma=(ca((c[k+((((I|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ma=0}ba=ma+L|0;na=ba;if(ba>>>0<u>>>0){u=na;B=I;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=246}}while(0);if((K|0)==246){na=2147483647}do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=257;break}if((I|0)<(G|0)){K=257;break}if((I|0)>(r|0)){K=257;break}ma=y+((ca(I>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](ma,j,(H+D&7)<<1,(I&7)<<1,o,s,q)|0;if((l|0)!=0){oa=(ca((c[k+((((I|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{oa=0}ma=oa+L|0;pa=ma;if(ma>>>0<u>>>0){u=pa;B=I;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=257}}while(0);if((K|0)==257){pa=2147483647}do{if((H|0)>=(F|0)){if((H|0)>(E|0)){K=268;break}if((I-D|0)<(G|0)){K=268;break}if((I-D|0)>(r|0)){K=268;break}oa=y+((ca(I-D>>3,j)|0)+(H>>3))|0;L=me[c[g+12>>2]&255](oa,j,(H&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){qa=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{qa=0}oa=qa+L|0;ra=oa;if(oa>>>0<u>>>0){u=ra;B=I-D|0;C=H;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=268}}while(0);if((K|0)==268){ra=2147483647}do{if((H|0)>=(F|0)){if((H|0)>(E|0)){K=279;break}if((I+D|0)<(G|0)){K=279;break}if((I+D|0)>(r|0)){K=279;break}qa=y+((ca(I+D>>3,j)|0)+(H>>3))|0;L=me[c[g+12>>2]&255](qa,j,(H&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){sa=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{sa=0}qa=sa+L|0;ta=qa;if(qa>>>0<u>>>0){u=ta;B=I+D|0;C=H;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=279}}while(0);if((K|0)==279){ta=2147483647}T=(na>>>0<pa>>>0?0:1)+(ra>>>0<ta>>>0?0:2)|0;ta=T;if((ta|0)==1){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=303;break}if((I-D|0)<(G|0)){K=303;break}if((I-D|0)>(r|0)){K=303;break}ra=y+((ca(I-D>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](ra,j,(H+D&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){ua=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ua=0}ra=ua+L|0;va=ra;if(ra>>>0<u>>>0){u=va;B=I-D|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=303}}while(0);if((K|0)==303){va=2147483647}}else if((ta|0)==0){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=291;break}if((I-D|0)<(G|0)){K=291;break}if((I-D|0)>(r|0)){K=291;break}ua=y+((ca(I-D>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](ua,j,(H-D&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){wa=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{wa=0}ua=wa+L|0;va=ua;if(ua>>>0<u>>>0){u=va;B=I-D|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=291}}while(0);if((K|0)==291){va=2147483647}}else if((ta|0)==2){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=315;break}if((I+D|0)<(G|0)){K=315;break}if((I+D|0)>(r|0)){K=315;break}wa=y+((ca(I+D>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](wa,j,(H-D&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){xa=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{xa=0}wa=xa+L|0;va=wa;if(wa>>>0<u>>>0){u=va;B=I+D|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=315}}while(0);if((K|0)==315){va=2147483647}}else if((ta|0)==3){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=327;break}if((I+D|0)<(G|0)){K=327;break}if((I+D|0)>(r|0)){K=327;break}ta=y+((ca(I+D>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](ta,j,(H+D&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){ya=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ya=0}ta=ya+L|0;va=ta;if(ta>>>0<u>>>0){u=va;B=I+D|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=327}}while(0);if((K|0)==327){va=2147483647}}if(w>>>0>1>>>0){do{if((I|0)!=(B|0)){if((H|0)==(C|0)){K=355;break}za=B-I|0;Aa=C-H|0;do{if((H+(Aa<<1)|0)>=(F|0)){if((H+(Aa<<1)|0)>(E|0)){K=342;break}if((I+za|0)<(G|0)){K=342;break}if((I+za|0)>(r|0)){K=342;break}w=y+((ca(I+za>>3,j)|0)+(H+(Aa<<1)>>3))|0;L=me[c[g+12>>2]&255](w,j,(H+(Aa<<1)&7)<<1,(I+za&7)<<1,o,s,q)|0;if((l|0)!=0){Ba=(ca((c[k+((((I+za|0)!=(t|0))<<1)+((H+(Aa<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+za-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+(Aa<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ba=0}w=Ba+L|0;Ca=w;if(w>>>0<u>>>0){u=Ca;B=I+za|0;C=H+(Aa<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=342}}while(0);if((K|0)==342){Ca=2147483647}do{if((H+Aa|0)>=(F|0)){if((H+Aa|0)>(E|0)){K=353;break}if((I+(za<<1)|0)<(G|0)){K=353;break}if((I+(za<<1)|0)>(r|0)){K=353;break}w=y+((ca(I+(za<<1)>>3,j)|0)+(H+Aa>>3))|0;L=me[c[g+12>>2]&255](w,j,(H+Aa&7)<<1,(I+(za<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){Da=(ca((c[k+((((I+(za<<1)|0)!=(t|0))<<1)+((H+Aa|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(za<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+Aa-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Da=0}w=Da+L|0;Ca=w;if(w>>>0<u>>>0){u=Ca;B=I+(za<<1)|0;C=H+Aa|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=353}}while(0);if((K|0)==353){Ca=2147483647}}else{K=355}}while(0);if((K|0)==355){do{if((I|0)==(B|0)){if((H|0)==(C|0)){K=405;break}Aa=C-H|0;do{if((H+(Aa<<1)|0)>=(F|0)){if((H+(Aa<<1)|0)>(E|0)){K=367;break}if((I+D|0)<(G|0)){K=367;break}if((I+D|0)>(r|0)){K=367;break}Da=y+((ca(I+D>>3,j)|0)+(H+(Aa<<1)>>3))|0;L=me[c[g+12>>2]&255](Da,j,(H+(Aa<<1)&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){Ea=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+(Aa<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+(Aa<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ea=0}Da=Ea+L|0;Ca=Da;if(Da>>>0<u>>>0){u=Ca;B=I+D|0;C=H+(Aa<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=367}}while(0);if((K|0)==367){Ca=2147483647}do{if((H+(Aa<<1)|0)>=(F|0)){if((H+(Aa<<1)|0)>(E|0)){K=378;break}if((I-D|0)<(G|0)){K=378;break}if((I-D|0)>(r|0)){K=378;break}Da=y+((ca(I-D>>3,j)|0)+(H+(Aa<<1)>>3))|0;L=me[c[g+12>>2]&255](Da,j,(H+(Aa<<1)&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){Fa=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+(Aa<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+(Aa<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Fa=0}Da=Fa+L|0;Ca=Da;if(Da>>>0<u>>>0){u=Ca;B=I-D|0;C=H+(Aa<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=378}}while(0);if((K|0)==378){Ca=2147483647}Da=T;if((Da|0)==0|(Da|0)==1){do{if((H+Aa|0)>=(F|0)){if((H+Aa|0)>(E|0)){K=390;break}if((I+D|0)<(G|0)){K=390;break}if((I+D|0)>(r|0)){K=390;break}Ba=y+((ca(I+D>>3,j)|0)+(H+Aa>>3))|0;L=me[c[g+12>>2]&255](Ba,j,(H+Aa&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){Ga=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+Aa|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+Aa-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ga=0}Ba=Ga+L|0;Ca=Ba;if(Ba>>>0<u>>>0){u=Ca;B=I+D|0;C=H+Aa|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=390}}while(0);if((K|0)==390){Ca=2147483647}}else if((Da|0)==2|(Da|0)==3){do{if((H+Aa|0)>=(F|0)){if((H+Aa|0)>(E|0)){K=402;break}if((I-D|0)<(G|0)){K=402;break}if((I-D|0)>(r|0)){K=402;break}Ba=y+((ca(I-D>>3,j)|0)+(H+Aa>>3))|0;L=me[c[g+12>>2]&255](Ba,j,(H+Aa&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){Ha=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+Aa|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+Aa-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ha=0}Ba=Ha+L|0;Ca=Ba;if(Ba>>>0<u>>>0){u=Ca;B=I-D|0;C=H+Aa|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=402}}while(0);if((K|0)==402){Ca=2147483647}}}else{K=405}}while(0);if((K|0)==405){do{if((I|0)!=(B|0)){if((H|0)!=(C|0)){break}za=B-I|0;do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=417;break}if((I+(za<<1)|0)<(G|0)){K=417;break}if((I+(za<<1)|0)>(r|0)){K=417;break}Aa=y+((ca(I+(za<<1)>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](Aa,j,(H+D&7)<<1,(I+(za<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){Ia=(ca((c[k+((((I+(za<<1)|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(za<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ia=0}Aa=Ia+L|0;Ca=Aa;if(Aa>>>0<u>>>0){u=Ca;B=I+(za<<1)|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=417}}while(0);if((K|0)==417){Ca=2147483647}do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=428;break}if((I+(za<<1)|0)<(G|0)){K=428;break}if((I+(za<<1)|0)>(r|0)){K=428;break}Aa=y+((ca(I+(za<<1)>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](Aa,j,(H-D&7)<<1,(I+(za<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){Ja=(ca((c[k+((((I+(za<<1)|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(za<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ja=0}Aa=Ja+L|0;Ca=Aa;if(Aa>>>0<u>>>0){u=Ca;B=I+(za<<1)|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=428}}while(0);if((K|0)==428){Ca=2147483647}Aa=T;if((Aa|0)==0|(Aa|0)==2){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=440;break}if((I+za|0)<(G|0)){K=440;break}if((I+za|0)>(r|0)){K=440;break}Ha=y+((ca(I+za>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](Ha,j,(H+D&7)<<1,(I+za&7)<<1,o,s,q)|0;if((l|0)!=0){Ka=(ca((c[k+((((I+za|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+za-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ka=0}Ha=Ka+L|0;Ca=Ha;if(Ha>>>0<u>>>0){u=Ca;B=I+za|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=440}}while(0);if((K|0)==440){Ca=2147483647}}else if((Aa|0)==1|(Aa|0)==3){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=452;break}if((I+za|0)<(G|0)){K=452;break}if((I+za|0)>(r|0)){K=452;break}Ha=y+((ca(I+za>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](Ha,j,(H-D&7)<<1,(I+za&7)<<1,o,s,q)|0;if((l|0)!=0){La=(ca((c[k+((((I+za|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+za-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{La=0}Ha=La+L|0;Ca=Ha;if(Ha>>>0<u>>>0){u=Ca;B=I+za|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=452}}while(0);if((K|0)==452){Ca=2147483647}}}}while(0)}}}I=B;H=C}do{if((e|0)!=0){if((Lec(d)|0)==0){break}if((h|0)!=0){break}D=D>>1;do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=472;break}if((I|0)<(G|0)){K=472;break}if((I|0)>(r|0)){K=472;break}Ca=y+((ca(I>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H-D&7)<<1,(I&7)<<1,o,s,q)|0;if((l|0)!=0){Ma=(ca((c[k+((((I|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ma=0}Ca=Ma+L|0;Na=Ca;if(Ca>>>0<u>>>0){u=Na;B=I;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=472}}while(0);if((K|0)==472){Na=2147483647}do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=483;break}if((I|0)<(G|0)){K=483;break}if((I|0)>(r|0)){K=483;break}Ca=y+((ca(I>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H+D&7)<<1,(I&7)<<1,o,s,q)|0;if((l|0)!=0){Oa=(ca((c[k+((((I|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Oa=0}Ca=Oa+L|0;Pa=Ca;if(Ca>>>0<u>>>0){u=Pa;B=I;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=483}}while(0);if((K|0)==483){Pa=2147483647}do{if((H|0)>=(F|0)){if((H|0)>(E|0)){K=494;break}if((I-D|0)<(G|0)){K=494;break}if((I-D|0)>(r|0)){K=494;break}Ca=y+((ca(I-D>>3,j)|0)+(H>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){Qa=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Qa=0}Ca=Qa+L|0;Ra=Ca;if(Ca>>>0<u>>>0){u=Ra;B=I-D|0;C=H;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=494}}while(0);if((K|0)==494){Ra=2147483647}do{if((H|0)>=(F|0)){if((H|0)>(E|0)){K=505;break}if((I+D|0)<(G|0)){K=505;break}if((I+D|0)>(r|0)){K=505;break}Ca=y+((ca(I+D>>3,j)|0)+(H>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){Sa=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Sa=0}Ca=Sa+L|0;Ta=Ca;if(Ca>>>0<u>>>0){u=Ta;B=I+D|0;C=H;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=505}}while(0);if((K|0)==505){Ta=2147483647}T=(Na>>>0<Pa>>>0?0:1)+(Ra>>>0<Ta>>>0?0:2)|0;Ca=T;if((Ca|0)==0){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=517;break}if((I-D|0)<(G|0)){K=517;break}if((I-D|0)>(r|0)){K=517;break}za=y+((ca(I-D>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](za,j,(H-D&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){Ua=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ua=0}za=Ua+L|0;Va=za;if(za>>>0<u>>>0){u=Va;B=I-D|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=517}}while(0);if((K|0)==517){Va=2147483647}}else if((Ca|0)==1){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=529;break}if((I-D|0)<(G|0)){K=529;break}if((I-D|0)>(r|0)){K=529;break}za=y+((ca(I-D>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](za,j,(H+D&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){Wa=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Wa=0}za=Wa+L|0;Va=za;if(za>>>0<u>>>0){u=Va;B=I-D|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=529}}while(0);if((K|0)==529){Va=2147483647}}else if((Ca|0)==2){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=541;break}if((I+D|0)<(G|0)){K=541;break}if((I+D|0)>(r|0)){K=541;break}za=y+((ca(I+D>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](za,j,(H-D&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){Xa=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Xa=0}za=Xa+L|0;Va=za;if(za>>>0<u>>>0){u=Va;B=I+D|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=541}}while(0);if((K|0)==541){Va=2147483647}}else if((Ca|0)==3){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=553;break}if((I+D|0)<(G|0)){K=553;break}if((I+D|0)>(r|0)){K=553;break}za=y+((ca(I+D>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](za,j,(H+D&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){Ya=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ya=0}za=Ya+L|0;Va=za;if(za>>>0<u>>>0){u=Va;B=I+D|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=553}}while(0);if((K|0)==553){Va=2147483647}}if(x>>>0>1>>>0){do{if((I|0)!=(B|0)){if((H|0)==(C|0)){K=581;break}Za=B-I|0;_a=C-H|0;do{if((H+(_a<<1)|0)>=(F|0)){if((H+(_a<<1)|0)>(E|0)){K=568;break}if((I+Za|0)<(G|0)){K=568;break}if((I+Za|0)>(r|0)){K=568;break}Ca=y+((ca(I+Za>>3,j)|0)+(H+(_a<<1)>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H+(_a<<1)&7)<<1,(I+Za&7)<<1,o,s,q)|0;if((l|0)!=0){$a=(ca((c[k+((((I+Za|0)!=(t|0))<<1)+((H+(_a<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+Za-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+(_a<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{$a=0}Ca=$a+L|0;ab=Ca;if(Ca>>>0<u>>>0){u=ab;B=I+Za|0;C=H+(_a<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=568}}while(0);if((K|0)==568){ab=2147483647}do{if((H+_a|0)>=(F|0)){if((H+_a|0)>(E|0)){K=579;break}if((I+(Za<<1)|0)<(G|0)){K=579;break}if((I+(Za<<1)|0)>(r|0)){K=579;break}Ca=y+((ca(I+(Za<<1)>>3,j)|0)+(H+_a>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H+_a&7)<<1,(I+(Za<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){bb=(ca((c[k+((((I+(Za<<1)|0)!=(t|0))<<1)+((H+_a|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(Za<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+_a-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{bb=0}Ca=bb+L|0;ab=Ca;if(Ca>>>0<u>>>0){u=ab;B=I+(Za<<1)|0;C=H+_a|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=579}}while(0);if((K|0)==579){ab=2147483647}}else{K=581}}while(0);if((K|0)==581){do{if((I|0)==(B|0)){if((H|0)==(C|0)){K=631;break}_a=C-H|0;do{if((H+(_a<<1)|0)>=(F|0)){if((H+(_a<<1)|0)>(E|0)){K=593;break}if((I+D|0)<(G|0)){K=593;break}if((I+D|0)>(r|0)){K=593;break}Ca=y+((ca(I+D>>3,j)|0)+(H+(_a<<1)>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H+(_a<<1)&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){cb=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+(_a<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+(_a<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{cb=0}Ca=cb+L|0;ab=Ca;if(Ca>>>0<u>>>0){u=ab;B=I+D|0;C=H+(_a<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=593}}while(0);if((K|0)==593){ab=2147483647}do{if((H+(_a<<1)|0)>=(F|0)){if((H+(_a<<1)|0)>(E|0)){K=604;break}if((I-D|0)<(G|0)){K=604;break}if((I-D|0)>(r|0)){K=604;break}Ca=y+((ca(I-D>>3,j)|0)+(H+(_a<<1)>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H+(_a<<1)&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){db=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+(_a<<1)|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+(_a<<1)-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{db=0}Ca=db+L|0;ab=Ca;if(Ca>>>0<u>>>0){u=ab;B=I-D|0;C=H+(_a<<1)|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=604}}while(0);if((K|0)==604){ab=2147483647}Ca=T;if((Ca|0)==0|(Ca|0)==1){do{if((H+_a|0)>=(F|0)){if((H+_a|0)>(E|0)){K=616;break}if((I+D|0)<(G|0)){K=616;break}if((I+D|0)>(r|0)){K=616;break}za=y+((ca(I+D>>3,j)|0)+(H+_a>>3))|0;L=me[c[g+12>>2]&255](za,j,(H+_a&7)<<1,(I+D&7)<<1,o,s,q)|0;if((l|0)!=0){eb=(ca((c[k+((((I+D|0)!=(t|0))<<1)+((H+_a|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+_a-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{eb=0}za=eb+L|0;ab=za;if(za>>>0<u>>>0){u=ab;B=I+D|0;C=H+_a|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=616}}while(0);if((K|0)==616){ab=2147483647}}else if((Ca|0)==2|(Ca|0)==3){do{if((H+_a|0)>=(F|0)){if((H+_a|0)>(E|0)){K=628;break}if((I-D|0)<(G|0)){K=628;break}if((I-D|0)>(r|0)){K=628;break}za=y+((ca(I-D>>3,j)|0)+(H+_a>>3))|0;L=me[c[g+12>>2]&255](za,j,(H+_a&7)<<1,(I-D&7)<<1,o,s,q)|0;if((l|0)!=0){fb=(ca((c[k+((((I-D|0)!=(t|0))<<1)+((H+_a|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I-D-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+_a-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{fb=0}za=fb+L|0;ab=za;if(za>>>0<u>>>0){u=ab;B=I-D|0;C=H+_a|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=628}}while(0);if((K|0)==628){ab=2147483647}}}else{K=631}}while(0);if((K|0)==631){do{if((I|0)!=(B|0)){if((H|0)!=(C|0)){break}Za=B-I|0;do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=643;break}if((I+(Za<<1)|0)<(G|0)){K=643;break}if((I+(Za<<1)|0)>(r|0)){K=643;break}Ca=y+((ca(I+(Za<<1)>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H+D&7)<<1,(I+(Za<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){gb=(ca((c[k+((((I+(Za<<1)|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(Za<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{gb=0}Ca=gb+L|0;ab=Ca;if(Ca>>>0<u>>>0){u=ab;B=I+(Za<<1)|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=643}}while(0);if((K|0)==643){ab=2147483647}do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=654;break}if((I+(Za<<1)|0)<(G|0)){K=654;break}if((I+(Za<<1)|0)>(r|0)){K=654;break}Ca=y+((ca(I+(Za<<1)>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](Ca,j,(H-D&7)<<1,(I+(Za<<1)&7)<<1,o,s,q)|0;if((l|0)!=0){hb=(ca((c[k+((((I+(Za<<1)|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+(Za<<1)-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{hb=0}Ca=hb+L|0;ab=Ca;if(Ca>>>0<u>>>0){u=ab;B=I+(Za<<1)|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=654}}while(0);if((K|0)==654){ab=2147483647}Ca=T;if((Ca|0)==0|(Ca|0)==2){do{if((H+D|0)>=(F|0)){if((H+D|0)>(E|0)){K=666;break}if((I+Za|0)<(G|0)){K=666;break}if((I+Za|0)>(r|0)){K=666;break}za=y+((ca(I+Za>>3,j)|0)+(H+D>>3))|0;L=me[c[g+12>>2]&255](za,j,(H+D&7)<<1,(I+Za&7)<<1,o,s,q)|0;if((l|0)!=0){ib=(ca((c[k+((((I+Za|0)!=(t|0))<<1)+((H+D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+Za-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H+D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{ib=0}za=ib+L|0;ab=za;if(za>>>0<u>>>0){u=ab;B=I+Za|0;C=H+D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=666}}while(0);if((K|0)==666){ab=2147483647}}else if((Ca|0)==1|(Ca|0)==3){do{if((H-D|0)>=(F|0)){if((H-D|0)>(E|0)){K=678;break}if((I+Za|0)<(G|0)){K=678;break}if((I+Za|0)>(r|0)){K=678;break}za=y+((ca(I+Za>>3,j)|0)+(H-D>>3))|0;L=me[c[g+12>>2]&255](za,j,(H-D&7)<<1,(I+Za&7)<<1,o,s,q)|0;if((l|0)!=0){jb=(ca((c[k+((((I+Za|0)!=(t|0))<<1)+((H-D|0)!=(A|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(I+Za-t<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(H-D-A<<2)>>2]|0)|0,f)|0)+4096>>13}else{jb=0}za=jb+L|0;ab=za;if(za>>>0<u>>>0){u=ab;B=I+Za|0;C=H-D|0;c[m>>2]=L;c[n>>2]=c[q>>2]}}else{K=678}}while(0);if((K|0)==678){ab=2147483647}}}}while(0)}}}I=B;H=C}}while(0);b[a>>1]=B;b[a+2>>1]=C;do{if((R((b[a+2>>1]|0)-(b[d+2>>1]|0)|0)|0)<=8184){if((R((b[a>>1]|0)-(b[d>>1]|0)|0)|0)>8184){break}kb=u;lb=kb;i=p;return lb|0}}while(0);kb=2147483647;lb=kb;i=p;return lb|0}function boc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;i=i+8|0;j=h|0;k=a;a=d;d=f;if((d|0)==0){l=0;m=l;i=h;return m|0}b[j>>1]=(b[k>>1]|0)-(b[a>>1]|0);b[j+2>>1]=(b[k+2>>1]|0)-(b[a+2>>1]|0);a=j;j=d;d=a;if((b[d>>1]|0)==0){n=(b[d+2>>1]|0)==0?0:1}else{n=(b[d+2>>1]|0)==0?2:3}l=(ca((c[e+(n<<2)>>2]|0)+(c[(c[j>>2]|0)+(b[a>>1]<<2)>>2]|0)+(c[(c[j+4>>2]|0)+(b[a+2>>1]<<2)>>2]|0)|0,g)|0)+4096>>13;m=l;i=h;return m|0}function coc(a,d,e,f,g,h,j,k,l,m,n,o,p,q,r){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0;s=i;i=i+4128|0;t=s|0;u=a;a=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=p;p=q;q=c[u+8204>>2]|0;v=c[u+8208>>2]|0;w=u+24720|0;x=2147483647;y=j;z=j;A=j;j=s+24-1&-16;B=c[w+28>>2]|0;C=ca(b[a>>1]|0,B)|0;D=C+(b[a+2>>1]|0)|0;C=c[w+24>>2]|0;w=b[d>>1]|0;E=b[d+2>>1]|0;F=b[a>>1]<<3;G=b[a+2>>1]<<3;H=4;if((c[u+1128236>>2]<<3|0)>((b[d+2>>1]|0)-16383|0)){I=c[u+1128236>>2]<<3}else{I=(b[d+2>>1]|0)-16383|0}J=I;if((c[u+1128240>>2]<<3|0)<((b[d+2>>1]|0)+16383|0)){K=c[u+1128240>>2]<<3}else{K=(b[d+2>>1]|0)+16383|0}I=K;if((c[u+1128244>>2]<<3|0)>((b[d>>1]|0)-16383|0)){L=c[u+1128244>>2]<<3}else{L=(b[d>>1]|0)-16383|0}K=L;if((c[u+1128248>>2]<<3|0)<((b[d>>1]|0)+16383|0)){M=c[u+1128248>>2]<<3}else{M=(b[d>>1]|0)+16383|0}u=M;M=F;L=G;N=a|0;b[N>>1]=b[N>>1]<<3;N=a+2|0;b[N>>1]=b[N>>1]<<3;D6b(j,o,p,r,C+D|0,B);x=Xe[c[g+8>>2]&511](j,p,q,v,n)|0;c[m>>2]=x;x=x+(boc(a,d,k,l,f)|0)|0;do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=23;break}if((M|0)<(K|0)){O=23;break}if((M|0)>(u|0)){O=23;break}p=C+((ca(M>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](p,B,(L-H&7)<<1,(M&7)<<1,q,v,t,o)|0;if((l|0)!=0){Q=(ca((c[k+((((M|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Q=0}p=Q+P|0;S=p;if(p>>>0<x>>>0){x=S;F=M;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=23}}while(0);if((O|0)==23){S=2147483647}do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=34;break}if((M|0)<(K|0)){O=34;break}if((M|0)>(u|0)){O=34;break}Q=C+((ca(M>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Q,B,(L+H&7)<<1,(M&7)<<1,q,v,t,o)|0;if((l|0)!=0){T=(ca((c[k+((((M|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{T=0}Q=T+P|0;U=Q;if(Q>>>0<x>>>0){x=U;F=M;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=34}}while(0);if((O|0)==34){U=2147483647}do{if((L|0)>=(J|0)){if((L|0)>(I|0)){O=45;break}if((M-H|0)<(K|0)){O=45;break}if((M-H|0)>(u|0)){O=45;break}T=C+((ca(M-H>>3,B)|0)+(L>>3))|0;P=gf[c[g+16>>2]&63](T,B,(L&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){V=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{V=0}T=V+P|0;W=T;if(T>>>0<x>>>0){x=W;F=M-H|0;G=L;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=45}}while(0);if((O|0)==45){W=2147483647}do{if((L|0)>=(J|0)){if((L|0)>(I|0)){O=56;break}if((M+H|0)<(K|0)){O=56;break}if((M+H|0)>(u|0)){O=56;break}V=C+((ca(M+H>>3,B)|0)+(L>>3))|0;P=gf[c[g+16>>2]&63](V,B,(L&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){X=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{X=0}V=X+P|0;Y=V;if(V>>>0<x>>>0){x=Y;F=M+H|0;G=L;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=56}}while(0);if((O|0)==56){Y=2147483647}X=(S>>>0<U>>>0?0:1)+(W>>>0<Y>>>0?0:2)|0;Y=X;if((Y|0)==2){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=92;break}if((M+H|0)<(K|0)){O=92;break}if((M+H|0)>(u|0)){O=92;break}W=C+((ca(M+H>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](W,B,(L-H&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Z=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Z=0}W=Z+P|0;_=W;if(W>>>0<x>>>0){x=_;F=M+H|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=92}}while(0);if((O|0)==92){_=2147483647}}else if((Y|0)==3){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=104;break}if((M+H|0)<(K|0)){O=104;break}if((M+H|0)>(u|0)){O=104;break}Z=C+((ca(M+H>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Z,B,(L+H&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){$=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{$=0}Z=$+P|0;_=Z;if(Z>>>0<x>>>0){x=_;F=M+H|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=104}}while(0);if((O|0)==104){_=2147483647}}else if((Y|0)==0){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=68;break}if((M-H|0)<(K|0)){O=68;break}if((M-H|0)>(u|0)){O=68;break}$=C+((ca(M-H>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63]($,B,(L-H&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){aa=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{aa=0}$=aa+P|0;_=$;if($>>>0<x>>>0){x=_;F=M-H|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=68}}while(0);if((O|0)==68){_=2147483647}}else if((Y|0)==1){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=80;break}if((M-H|0)<(K|0)){O=80;break}if((M-H|0)>(u|0)){O=80;break}Y=C+((ca(M-H>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Y,B,(L+H&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){ba=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ba=0}Y=ba+P|0;_=Y;if(Y>>>0<x>>>0){x=_;F=M-H|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=80}}while(0);if((O|0)==80){_=2147483647}}if(y>>>0>1>>>0){do{if((M|0)!=(F|0)){if((L|0)==(G|0)){O=132;break}da=F-M|0;ea=G-L|0;do{if((L+(ea<<1)|0)>=(J|0)){if((L+(ea<<1)|0)>(I|0)){O=119;break}if((M+da|0)<(K|0)){O=119;break}if((M+da|0)>(u|0)){O=119;break}y=C+((ca(M+da>>3,B)|0)+(L+(ea<<1)>>3))|0;P=gf[c[g+16>>2]&63](y,B,(L+(ea<<1)&7)<<1,(M+da&7)<<1,q,v,t,o)|0;if((l|0)!=0){fa=(ca((c[k+((((M+da|0)!=(w|0))<<1)+((L+(ea<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+da-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(ea<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{fa=0}y=fa+P|0;ga=y;if(y>>>0<x>>>0){x=ga;F=M+da|0;G=L+(ea<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=119}}while(0);if((O|0)==119){ga=2147483647}do{if((L+ea|0)>=(J|0)){if((L+ea|0)>(I|0)){O=130;break}if((M+(da<<1)|0)<(K|0)){O=130;break}if((M+(da<<1)|0)>(u|0)){O=130;break}y=C+((ca(M+(da<<1)>>3,B)|0)+(L+ea>>3))|0;P=gf[c[g+16>>2]&63](y,B,(L+ea&7)<<1,(M+(da<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){ha=(ca((c[k+((((M+(da<<1)|0)!=(w|0))<<1)+((L+ea|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(da<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+ea-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ha=0}y=ha+P|0;ga=y;if(y>>>0<x>>>0){x=ga;F=M+(da<<1)|0;G=L+ea|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=130}}while(0);if((O|0)==130){ga=2147483647}}else{O=132}}while(0);if((O|0)==132){do{if((M|0)==(F|0)){if((L|0)==(G|0)){O=182;break}ea=G-L|0;do{if((L+(ea<<1)|0)>=(J|0)){if((L+(ea<<1)|0)>(I|0)){O=144;break}if((M+H|0)<(K|0)){O=144;break}if((M+H|0)>(u|0)){O=144;break}ha=C+((ca(M+H>>3,B)|0)+(L+(ea<<1)>>3))|0;P=gf[c[g+16>>2]&63](ha,B,(L+(ea<<1)&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){ia=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+(ea<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(ea<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ia=0}ha=ia+P|0;ga=ha;if(ha>>>0<x>>>0){x=ga;F=M+H|0;G=L+(ea<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=144}}while(0);if((O|0)==144){ga=2147483647}do{if((L+(ea<<1)|0)>=(J|0)){if((L+(ea<<1)|0)>(I|0)){O=155;break}if((M-H|0)<(K|0)){O=155;break}if((M-H|0)>(u|0)){O=155;break}ha=C+((ca(M-H>>3,B)|0)+(L+(ea<<1)>>3))|0;P=gf[c[g+16>>2]&63](ha,B,(L+(ea<<1)&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){ja=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+(ea<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(ea<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ja=0}ha=ja+P|0;ga=ha;if(ha>>>0<x>>>0){x=ga;F=M-H|0;G=L+(ea<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=155}}while(0);if((O|0)==155){ga=2147483647}ha=X;if((ha|0)==2|(ha|0)==3){do{if((L+ea|0)>=(J|0)){if((L+ea|0)>(I|0)){O=179;break}if((M-H|0)<(K|0)){O=179;break}if((M-H|0)>(u|0)){O=179;break}fa=C+((ca(M-H>>3,B)|0)+(L+ea>>3))|0;P=gf[c[g+16>>2]&63](fa,B,(L+ea&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){ka=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+ea|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+ea-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ka=0}fa=ka+P|0;ga=fa;if(fa>>>0<x>>>0){x=ga;F=M-H|0;G=L+ea|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=179}}while(0);if((O|0)==179){ga=2147483647}}else if((ha|0)==0|(ha|0)==1){do{if((L+ea|0)>=(J|0)){if((L+ea|0)>(I|0)){O=167;break}if((M+H|0)<(K|0)){O=167;break}if((M+H|0)>(u|0)){O=167;break}fa=C+((ca(M+H>>3,B)|0)+(L+ea>>3))|0;P=gf[c[g+16>>2]&63](fa,B,(L+ea&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){la=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+ea|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+ea-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{la=0}fa=la+P|0;ga=fa;if(fa>>>0<x>>>0){x=ga;F=M+H|0;G=L+ea|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=167}}while(0);if((O|0)==167){ga=2147483647}}}else{O=182}}while(0);if((O|0)==182){do{if((M|0)!=(F|0)){if((L|0)!=(G|0)){break}da=F-M|0;do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=194;break}if((M+(da<<1)|0)<(K|0)){O=194;break}if((M+(da<<1)|0)>(u|0)){O=194;break}ea=C+((ca(M+(da<<1)>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](ea,B,(L+H&7)<<1,(M+(da<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){ma=(ca((c[k+((((M+(da<<1)|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(da<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ma=0}ea=ma+P|0;ga=ea;if(ea>>>0<x>>>0){x=ga;F=M+(da<<1)|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=194}}while(0);if((O|0)==194){ga=2147483647}do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=205;break}if((M+(da<<1)|0)<(K|0)){O=205;break}if((M+(da<<1)|0)>(u|0)){O=205;break}ea=C+((ca(M+(da<<1)>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](ea,B,(L-H&7)<<1,(M+(da<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){na=(ca((c[k+((((M+(da<<1)|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(da<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{na=0}ea=na+P|0;ga=ea;if(ea>>>0<x>>>0){x=ga;F=M+(da<<1)|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=205}}while(0);if((O|0)==205){ga=2147483647}ea=X;if((ea|0)==1|(ea|0)==3){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=229;break}if((M+da|0)<(K|0)){O=229;break}if((M+da|0)>(u|0)){O=229;break}la=C+((ca(M+da>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](la,B,(L-H&7)<<1,(M+da&7)<<1,q,v,t,o)|0;if((l|0)!=0){oa=(ca((c[k+((((M+da|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+da-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{oa=0}la=oa+P|0;ga=la;if(la>>>0<x>>>0){x=ga;F=M+da|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=229}}while(0);if((O|0)==229){ga=2147483647}}else if((ea|0)==0|(ea|0)==2){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=217;break}if((M+da|0)<(K|0)){O=217;break}if((M+da|0)>(u|0)){O=217;break}la=C+((ca(M+da>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](la,B,(L+H&7)<<1,(M+da&7)<<1,q,v,t,o)|0;if((l|0)!=0){pa=(ca((c[k+((((M+da|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+da-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{pa=0}la=pa+P|0;ga=la;if(la>>>0<x>>>0){x=ga;F=M+da|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=217}}while(0);if((O|0)==217){ga=2147483647}}}}while(0)}}}M=F;L=G;if((h|0)!=2){H=H>>1;do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=246;break}if((M|0)<(K|0)){O=246;break}if((M|0)>(u|0)){O=246;break}ga=C+((ca(M>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](ga,B,(L-H&7)<<1,(M&7)<<1,q,v,t,o)|0;if((l|0)!=0){qa=(ca((c[k+((((M|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{qa=0}ga=qa+P|0;ra=ga;if(ga>>>0<x>>>0){x=ra;F=M;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=246}}while(0);if((O|0)==246){ra=2147483647}do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=257;break}if((M|0)<(K|0)){O=257;break}if((M|0)>(u|0)){O=257;break}qa=C+((ca(M>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](qa,B,(L+H&7)<<1,(M&7)<<1,q,v,t,o)|0;if((l|0)!=0){sa=(ca((c[k+((((M|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{sa=0}qa=sa+P|0;ta=qa;if(qa>>>0<x>>>0){x=ta;F=M;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=257}}while(0);if((O|0)==257){ta=2147483647}do{if((L|0)>=(J|0)){if((L|0)>(I|0)){O=268;break}if((M-H|0)<(K|0)){O=268;break}if((M-H|0)>(u|0)){O=268;break}sa=C+((ca(M-H>>3,B)|0)+(L>>3))|0;P=gf[c[g+16>>2]&63](sa,B,(L&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){ua=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ua=0}sa=ua+P|0;va=sa;if(sa>>>0<x>>>0){x=va;F=M-H|0;G=L;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=268}}while(0);if((O|0)==268){va=2147483647}do{if((L|0)>=(J|0)){if((L|0)>(I|0)){O=279;break}if((M+H|0)<(K|0)){O=279;break}if((M+H|0)>(u|0)){O=279;break}ua=C+((ca(M+H>>3,B)|0)+(L>>3))|0;P=gf[c[g+16>>2]&63](ua,B,(L&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){wa=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{wa=0}ua=wa+P|0;xa=ua;if(ua>>>0<x>>>0){x=xa;F=M+H|0;G=L;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=279}}while(0);if((O|0)==279){xa=2147483647}X=(ra>>>0<ta>>>0?0:1)+(va>>>0<xa>>>0?0:2)|0;xa=X;if((xa|0)==0){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=291;break}if((M-H|0)<(K|0)){O=291;break}if((M-H|0)>(u|0)){O=291;break}va=C+((ca(M-H>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](va,B,(L-H&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){ya=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ya=0}va=ya+P|0;za=va;if(va>>>0<x>>>0){x=za;F=M-H|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=291}}while(0);if((O|0)==291){za=2147483647}}else if((xa|0)==3){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=327;break}if((M+H|0)<(K|0)){O=327;break}if((M+H|0)>(u|0)){O=327;break}ya=C+((ca(M+H>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](ya,B,(L+H&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Aa=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Aa=0}ya=Aa+P|0;za=ya;if(ya>>>0<x>>>0){x=za;F=M+H|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=327}}while(0);if((O|0)==327){za=2147483647}}else if((xa|0)==2){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=315;break}if((M+H|0)<(K|0)){O=315;break}if((M+H|0)>(u|0)){O=315;break}Aa=C+((ca(M+H>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](Aa,B,(L-H&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ba=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ba=0}Aa=Ba+P|0;za=Aa;if(Aa>>>0<x>>>0){x=za;F=M+H|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=315}}while(0);if((O|0)==315){za=2147483647}}else if((xa|0)==1){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=303;break}if((M-H|0)<(K|0)){O=303;break}if((M-H|0)>(u|0)){O=303;break}xa=C+((ca(M-H>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](xa,B,(L+H&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ca=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ca=0}xa=Ca+P|0;za=xa;if(xa>>>0<x>>>0){x=za;F=M-H|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=303}}while(0);if((O|0)==303){za=2147483647}}if(z>>>0>1>>>0){do{if((M|0)!=(F|0)){if((L|0)==(G|0)){O=355;break}Da=F-M|0;Ea=G-L|0;do{if((L+(Ea<<1)|0)>=(J|0)){if((L+(Ea<<1)|0)>(I|0)){O=342;break}if((M+Da|0)<(K|0)){O=342;break}if((M+Da|0)>(u|0)){O=342;break}z=C+((ca(M+Da>>3,B)|0)+(L+(Ea<<1)>>3))|0;P=gf[c[g+16>>2]&63](z,B,(L+(Ea<<1)&7)<<1,(M+Da&7)<<1,q,v,t,o)|0;if((l|0)!=0){Fa=(ca((c[k+((((M+Da|0)!=(w|0))<<1)+((L+(Ea<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+Da-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(Ea<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Fa=0}z=Fa+P|0;Ga=z;if(z>>>0<x>>>0){x=Ga;F=M+Da|0;G=L+(Ea<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=342}}while(0);if((O|0)==342){Ga=2147483647}do{if((L+Ea|0)>=(J|0)){if((L+Ea|0)>(I|0)){O=353;break}if((M+(Da<<1)|0)<(K|0)){O=353;break}if((M+(Da<<1)|0)>(u|0)){O=353;break}z=C+((ca(M+(Da<<1)>>3,B)|0)+(L+Ea>>3))|0;P=gf[c[g+16>>2]&63](z,B,(L+Ea&7)<<1,(M+(Da<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ha=(ca((c[k+((((M+(Da<<1)|0)!=(w|0))<<1)+((L+Ea|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(Da<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+Ea-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ha=0}z=Ha+P|0;Ga=z;if(z>>>0<x>>>0){x=Ga;F=M+(Da<<1)|0;G=L+Ea|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=353}}while(0);if((O|0)==353){Ga=2147483647}}else{O=355}}while(0);if((O|0)==355){do{if((M|0)==(F|0)){if((L|0)==(G|0)){O=405;break}Ea=G-L|0;do{if((L+(Ea<<1)|0)>=(J|0)){if((L+(Ea<<1)|0)>(I|0)){O=367;break}if((M+H|0)<(K|0)){O=367;break}if((M+H|0)>(u|0)){O=367;break}Ha=C+((ca(M+H>>3,B)|0)+(L+(Ea<<1)>>3))|0;P=gf[c[g+16>>2]&63](Ha,B,(L+(Ea<<1)&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ia=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+(Ea<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(Ea<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ia=0}Ha=Ia+P|0;Ga=Ha;if(Ha>>>0<x>>>0){x=Ga;F=M+H|0;G=L+(Ea<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=367}}while(0);if((O|0)==367){Ga=2147483647}do{if((L+(Ea<<1)|0)>=(J|0)){if((L+(Ea<<1)|0)>(I|0)){O=378;break}if((M-H|0)<(K|0)){O=378;break}if((M-H|0)>(u|0)){O=378;break}Ha=C+((ca(M-H>>3,B)|0)+(L+(Ea<<1)>>3))|0;P=gf[c[g+16>>2]&63](Ha,B,(L+(Ea<<1)&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ja=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+(Ea<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(Ea<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ja=0}Ha=Ja+P|0;Ga=Ha;if(Ha>>>0<x>>>0){x=Ga;F=M-H|0;G=L+(Ea<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=378}}while(0);if((O|0)==378){Ga=2147483647}Ha=X;if((Ha|0)==0|(Ha|0)==1){do{if((L+Ea|0)>=(J|0)){if((L+Ea|0)>(I|0)){O=390;break}if((M+H|0)<(K|0)){O=390;break}if((M+H|0)>(u|0)){O=390;break}Fa=C+((ca(M+H>>3,B)|0)+(L+Ea>>3))|0;P=gf[c[g+16>>2]&63](Fa,B,(L+Ea&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ka=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+Ea|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+Ea-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ka=0}Fa=Ka+P|0;Ga=Fa;if(Fa>>>0<x>>>0){x=Ga;F=M+H|0;G=L+Ea|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=390}}while(0);if((O|0)==390){Ga=2147483647}}else if((Ha|0)==2|(Ha|0)==3){do{if((L+Ea|0)>=(J|0)){if((L+Ea|0)>(I|0)){O=402;break}if((M-H|0)<(K|0)){O=402;break}if((M-H|0)>(u|0)){O=402;break}Fa=C+((ca(M-H>>3,B)|0)+(L+Ea>>3))|0;P=gf[c[g+16>>2]&63](Fa,B,(L+Ea&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){La=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+Ea|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+Ea-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{La=0}Fa=La+P|0;Ga=Fa;if(Fa>>>0<x>>>0){x=Ga;F=M-H|0;G=L+Ea|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=402}}while(0);if((O|0)==402){Ga=2147483647}}}else{O=405}}while(0);if((O|0)==405){do{if((M|0)!=(F|0)){if((L|0)!=(G|0)){break}Da=F-M|0;do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=417;break}if((M+(Da<<1)|0)<(K|0)){O=417;break}if((M+(Da<<1)|0)>(u|0)){O=417;break}Ea=C+((ca(M+(Da<<1)>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Ea,B,(L+H&7)<<1,(M+(Da<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ma=(ca((c[k+((((M+(Da<<1)|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(Da<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ma=0}Ea=Ma+P|0;Ga=Ea;if(Ea>>>0<x>>>0){x=Ga;F=M+(Da<<1)|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=417}}while(0);if((O|0)==417){Ga=2147483647}do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=428;break}if((M+(Da<<1)|0)<(K|0)){O=428;break}if((M+(Da<<1)|0)>(u|0)){O=428;break}Ea=C+((ca(M+(Da<<1)>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](Ea,B,(L-H&7)<<1,(M+(Da<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){Na=(ca((c[k+((((M+(Da<<1)|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(Da<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Na=0}Ea=Na+P|0;Ga=Ea;if(Ea>>>0<x>>>0){x=Ga;F=M+(Da<<1)|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=428}}while(0);if((O|0)==428){Ga=2147483647}Ea=X;if((Ea|0)==0|(Ea|0)==2){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=440;break}if((M+Da|0)<(K|0)){O=440;break}if((M+Da|0)>(u|0)){O=440;break}La=C+((ca(M+Da>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](La,B,(L+H&7)<<1,(M+Da&7)<<1,q,v,t,o)|0;if((l|0)!=0){Oa=(ca((c[k+((((M+Da|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+Da-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Oa=0}La=Oa+P|0;Ga=La;if(La>>>0<x>>>0){x=Ga;F=M+Da|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=440}}while(0);if((O|0)==440){Ga=2147483647}}else if((Ea|0)==1|(Ea|0)==3){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=452;break}if((M+Da|0)<(K|0)){O=452;break}if((M+Da|0)>(u|0)){O=452;break}La=C+((ca(M+Da>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](La,B,(L-H&7)<<1,(M+Da&7)<<1,q,v,t,o)|0;if((l|0)!=0){Pa=(ca((c[k+((((M+Da|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+Da-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Pa=0}La=Pa+P|0;Ga=La;if(La>>>0<x>>>0){x=Ga;F=M+Da|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=452}}while(0);if((O|0)==452){Ga=2147483647}}}}while(0)}}}M=F;L=G}do{if((e|0)!=0){if((Lec(d)|0)==0){break}if((h|0)!=0){break}H=H>>1;do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=472;break}if((M|0)<(K|0)){O=472;break}if((M|0)>(u|0)){O=472;break}Ga=C+((ca(M>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L-H&7)<<1,(M&7)<<1,q,v,t,o)|0;if((l|0)!=0){Qa=(ca((c[k+((((M|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Qa=0}Ga=Qa+P|0;Ra=Ga;if(Ga>>>0<x>>>0){x=Ra;F=M;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=472}}while(0);if((O|0)==472){Ra=2147483647}do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=483;break}if((M|0)<(K|0)){O=483;break}if((M|0)>(u|0)){O=483;break}Ga=C+((ca(M>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L+H&7)<<1,(M&7)<<1,q,v,t,o)|0;if((l|0)!=0){Sa=(ca((c[k+((((M|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Sa=0}Ga=Sa+P|0;Ta=Ga;if(Ga>>>0<x>>>0){x=Ta;F=M;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=483}}while(0);if((O|0)==483){Ta=2147483647}do{if((L|0)>=(J|0)){if((L|0)>(I|0)){O=494;break}if((M-H|0)<(K|0)){O=494;break}if((M-H|0)>(u|0)){O=494;break}Ga=C+((ca(M-H>>3,B)|0)+(L>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ua=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ua=0}Ga=Ua+P|0;Va=Ga;if(Ga>>>0<x>>>0){x=Va;F=M-H|0;G=L;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=494}}while(0);if((O|0)==494){Va=2147483647}do{if((L|0)>=(J|0)){if((L|0)>(I|0)){O=505;break}if((M+H|0)<(K|0)){O=505;break}if((M+H|0)>(u|0)){O=505;break}Ga=C+((ca(M+H>>3,B)|0)+(L>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Wa=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Wa=0}Ga=Wa+P|0;Xa=Ga;if(Ga>>>0<x>>>0){x=Xa;F=M+H|0;G=L;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=505}}while(0);if((O|0)==505){Xa=2147483647}X=(Ra>>>0<Ta>>>0?0:1)+(Va>>>0<Xa>>>0?0:2)|0;Ga=X;if((Ga|0)==0){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=517;break}if((M-H|0)<(K|0)){O=517;break}if((M-H|0)>(u|0)){O=517;break}Da=C+((ca(M-H>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](Da,B,(L-H&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){Ya=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{Ya=0}Da=Ya+P|0;Za=Da;if(Da>>>0<x>>>0){x=Za;F=M-H|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=517}}while(0);if((O|0)==517){Za=2147483647}}else if((Ga|0)==1){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=529;break}if((M-H|0)<(K|0)){O=529;break}if((M-H|0)>(u|0)){O=529;break}Da=C+((ca(M-H>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Da,B,(L+H&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){_a=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{_a=0}Da=_a+P|0;Za=Da;if(Da>>>0<x>>>0){x=Za;F=M-H|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=529}}while(0);if((O|0)==529){Za=2147483647}}else if((Ga|0)==2){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=541;break}if((M+H|0)<(K|0)){O=541;break}if((M+H|0)>(u|0)){O=541;break}Da=C+((ca(M+H>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](Da,B,(L-H&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){$a=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{$a=0}Da=$a+P|0;Za=Da;if(Da>>>0<x>>>0){x=Za;F=M+H|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=541}}while(0);if((O|0)==541){Za=2147483647}}else if((Ga|0)==3){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=553;break}if((M+H|0)<(K|0)){O=553;break}if((M+H|0)>(u|0)){O=553;break}Da=C+((ca(M+H>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Da,B,(L+H&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){ab=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ab=0}Da=ab+P|0;Za=Da;if(Da>>>0<x>>>0){x=Za;F=M+H|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=553}}while(0);if((O|0)==553){Za=2147483647}}if(A>>>0>1>>>0){do{if((M|0)!=(F|0)){if((L|0)==(G|0)){O=581;break}bb=F-M|0;cb=G-L|0;do{if((L+(cb<<1)|0)>=(J|0)){if((L+(cb<<1)|0)>(I|0)){O=568;break}if((M+bb|0)<(K|0)){O=568;break}if((M+bb|0)>(u|0)){O=568;break}Ga=C+((ca(M+bb>>3,B)|0)+(L+(cb<<1)>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L+(cb<<1)&7)<<1,(M+bb&7)<<1,q,v,t,o)|0;if((l|0)!=0){db=(ca((c[k+((((M+bb|0)!=(w|0))<<1)+((L+(cb<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+bb-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(cb<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{db=0}Ga=db+P|0;eb=Ga;if(Ga>>>0<x>>>0){x=eb;F=M+bb|0;G=L+(cb<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=568}}while(0);if((O|0)==568){eb=2147483647}do{if((L+cb|0)>=(J|0)){if((L+cb|0)>(I|0)){O=579;break}if((M+(bb<<1)|0)<(K|0)){O=579;break}if((M+(bb<<1)|0)>(u|0)){O=579;break}Ga=C+((ca(M+(bb<<1)>>3,B)|0)+(L+cb>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L+cb&7)<<1,(M+(bb<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){fb=(ca((c[k+((((M+(bb<<1)|0)!=(w|0))<<1)+((L+cb|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(bb<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+cb-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{fb=0}Ga=fb+P|0;eb=Ga;if(Ga>>>0<x>>>0){x=eb;F=M+(bb<<1)|0;G=L+cb|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=579}}while(0);if((O|0)==579){eb=2147483647}}else{O=581}}while(0);if((O|0)==581){do{if((M|0)==(F|0)){if((L|0)==(G|0)){O=631;break}cb=G-L|0;do{if((L+(cb<<1)|0)>=(J|0)){if((L+(cb<<1)|0)>(I|0)){O=593;break}if((M+H|0)<(K|0)){O=593;break}if((M+H|0)>(u|0)){O=593;break}Ga=C+((ca(M+H>>3,B)|0)+(L+(cb<<1)>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L+(cb<<1)&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){gb=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+(cb<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(cb<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{gb=0}Ga=gb+P|0;eb=Ga;if(Ga>>>0<x>>>0){x=eb;F=M+H|0;G=L+(cb<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=593}}while(0);if((O|0)==593){eb=2147483647}do{if((L+(cb<<1)|0)>=(J|0)){if((L+(cb<<1)|0)>(I|0)){O=604;break}if((M-H|0)<(K|0)){O=604;break}if((M-H|0)>(u|0)){O=604;break}Ga=C+((ca(M-H>>3,B)|0)+(L+(cb<<1)>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L+(cb<<1)&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){hb=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+(cb<<1)|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+(cb<<1)-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{hb=0}Ga=hb+P|0;eb=Ga;if(Ga>>>0<x>>>0){x=eb;F=M-H|0;G=L+(cb<<1)|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=604}}while(0);if((O|0)==604){eb=2147483647}Ga=X;if((Ga|0)==0|(Ga|0)==1){do{if((L+cb|0)>=(J|0)){if((L+cb|0)>(I|0)){O=616;break}if((M+H|0)<(K|0)){O=616;break}if((M+H|0)>(u|0)){O=616;break}Da=C+((ca(M+H>>3,B)|0)+(L+cb>>3))|0;P=gf[c[g+16>>2]&63](Da,B,(L+cb&7)<<1,(M+H&7)<<1,q,v,t,o)|0;if((l|0)!=0){ib=(ca((c[k+((((M+H|0)!=(w|0))<<1)+((L+cb|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+cb-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{ib=0}Da=ib+P|0;eb=Da;if(Da>>>0<x>>>0){x=eb;F=M+H|0;G=L+cb|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=616}}while(0);if((O|0)==616){eb=2147483647}}else if((Ga|0)==2|(Ga|0)==3){do{if((L+cb|0)>=(J|0)){if((L+cb|0)>(I|0)){O=628;break}if((M-H|0)<(K|0)){O=628;break}if((M-H|0)>(u|0)){O=628;break}Da=C+((ca(M-H>>3,B)|0)+(L+cb>>3))|0;P=gf[c[g+16>>2]&63](Da,B,(L+cb&7)<<1,(M-H&7)<<1,q,v,t,o)|0;if((l|0)!=0){jb=(ca((c[k+((((M-H|0)!=(w|0))<<1)+((L+cb|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M-H-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+cb-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{jb=0}Da=jb+P|0;eb=Da;if(Da>>>0<x>>>0){x=eb;F=M-H|0;G=L+cb|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=628}}while(0);if((O|0)==628){eb=2147483647}}}else{O=631}}while(0);if((O|0)==631){do{if((M|0)!=(F|0)){if((L|0)!=(G|0)){break}bb=F-M|0;do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=643;break}if((M+(bb<<1)|0)<(K|0)){O=643;break}if((M+(bb<<1)|0)>(u|0)){O=643;break}Ga=C+((ca(M+(bb<<1)>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L+H&7)<<1,(M+(bb<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){kb=(ca((c[k+((((M+(bb<<1)|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(bb<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{kb=0}Ga=kb+P|0;eb=Ga;if(Ga>>>0<x>>>0){x=eb;F=M+(bb<<1)|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=643}}while(0);if((O|0)==643){eb=2147483647}do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=654;break}if((M+(bb<<1)|0)<(K|0)){O=654;break}if((M+(bb<<1)|0)>(u|0)){O=654;break}Ga=C+((ca(M+(bb<<1)>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](Ga,B,(L-H&7)<<1,(M+(bb<<1)&7)<<1,q,v,t,o)|0;if((l|0)!=0){lb=(ca((c[k+((((M+(bb<<1)|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+(bb<<1)-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{lb=0}Ga=lb+P|0;eb=Ga;if(Ga>>>0<x>>>0){x=eb;F=M+(bb<<1)|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=654}}while(0);if((O|0)==654){eb=2147483647}Ga=X;if((Ga|0)==0|(Ga|0)==2){do{if((L+H|0)>=(J|0)){if((L+H|0)>(I|0)){O=666;break}if((M+bb|0)<(K|0)){O=666;break}if((M+bb|0)>(u|0)){O=666;break}Da=C+((ca(M+bb>>3,B)|0)+(L+H>>3))|0;P=gf[c[g+16>>2]&63](Da,B,(L+H&7)<<1,(M+bb&7)<<1,q,v,t,o)|0;if((l|0)!=0){mb=(ca((c[k+((((M+bb|0)!=(w|0))<<1)+((L+H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+bb-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L+H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{mb=0}Da=mb+P|0;eb=Da;if(Da>>>0<x>>>0){x=eb;F=M+bb|0;G=L+H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=666}}while(0);if((O|0)==666){eb=2147483647}}else if((Ga|0)==1|(Ga|0)==3){do{if((L-H|0)>=(J|0)){if((L-H|0)>(I|0)){O=678;break}if((M+bb|0)<(K|0)){O=678;break}if((M+bb|0)>(u|0)){O=678;break}Da=C+((ca(M+bb>>3,B)|0)+(L-H>>3))|0;P=gf[c[g+16>>2]&63](Da,B,(L-H&7)<<1,(M+bb&7)<<1,q,v,t,o)|0;if((l|0)!=0){nb=(ca((c[k+((((M+bb|0)!=(w|0))<<1)+((L-H|0)!=(E|0))<<2)>>2]|0)+(c[(c[l>>2]|0)+(M+bb-w<<2)>>2]|0)+(c[(c[l+4>>2]|0)+(L-H-E<<2)>>2]|0)|0,f)|0)+4096>>13}else{nb=0}Da=nb+P|0;eb=Da;if(Da>>>0<x>>>0){x=eb;F=M+bb|0;G=L-H|0;c[m>>2]=P;c[n>>2]=c[t>>2]}}else{O=678}}while(0);if((O|0)==678){eb=2147483647}}}}while(0)}}}M=F;L=G}}while(0);b[a>>1]=F;b[a+2>>1]=G;do{if((R((b[a+2>>1]|0)-(b[d+2>>1]|0)|0)|0)<=8184){if((R((b[a>>1]|0)-(b[d>>1]|0)|0)|0)>8184){break}ob=x;pb=ob;i=s;return pb|0}}while(0);ob=2147483647;pb=ob;i=s;return pb|0}function doc(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+16|0;j=h|0;k=a;a=d;d=k+8204|0;l=k+24744|0;b[j>>1]=b[a>>1]<<3;b[j+2>>1]=b[a+2>>1]<<3;m=l;n=a;a=ca(b[n>>1]|0,c[m+4>>2]|0)|0;o=Xe[c[f+8>>2]&511](c[d>>2]|0,c[d+4>>2]|0,(c[m>>2]|0)+(a+(b[n+2>>1]|0))|0,c[l+4>>2]|0,h+8|0)|0;if((g|0)!=0){p=boc(j,e,k+75336|0,c[k+599640>>2]|0,c[k+75232>>2]|0)|0;q=o+p|0;i=h;return q|0}else{p=0;q=o+p|0;i=h;return q|0}return 0}function eoc(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=i;i=i+16|0;k=j|0;l=a;a=d;d=l+8204|0;m=l+24744|0;b[k>>1]=b[a>>1]<<3;b[k+2>>1]=b[a+2>>1]<<3;n=m;o=a;a=ca(b[o>>1]|0,c[n+4>>2]|0)|0;p=gf[c[g+16>>2]&63]((c[n>>2]|0)+(a+(b[o+2>>1]|0))|0,c[m+4>>2]|0,0,0,c[d>>2]|0,c[d+4>>2]|0,j+8|0,f)|0;if((h|0)!=0){q=boc(k,e,l+75336|0,c[l+599640>>2]|0,c[l+75232>>2]|0)|0;r=p+q|0;i=j;return r|0}else{q=0;r=p+q|0;i=j;return r|0}return 0}function foc(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0;k=i;l=goc(a,b,c,d,e,0,f,g,h,j,215528,215576)|0;i=k;return l|0}function goc(a,d,e,f,g,h,j,k,l,m,n,o){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0;p=i;i=i+88|0;q=p|0;r=p+8|0;s=p+16|0;t=p+24|0;u=p+32|0;v=p+40|0;w=p+56|0;x=p+64|0;y=p+72|0;z=p+80|0;A=a;a=d;d=f;f=g;g=h;h=j;j=k;k=l;l=m;m=n;n=o;o=A+8204|0;B=A+24744|0;C=2147483647;D=-1;b[q>>1]=b[k>>1]>>3;b[q+2>>1]=b[k+2>>1]>>3;k=c[207912+(e<<2)>>2]|0;e=a;E=c[A+1128244>>2]|0;F=c[A+1128248>>2]|0;G=b[e+2>>1]|0;H=c[A+1128236>>2]|0;I=c[A+1128240>>2]|0;if((G|0)<(H|0)){J=H}else{if((G|0)>(I|0)){K=I}else{K=G}J=K}b[e+2>>1]=J;J=b[e>>1]|0;K=E;E=F;if((J|0)<(K|0)){L=K}else{if((J|0)>(E|0)){M=E}else{M=J}L=M}b[e>>1]=L;L=b[a>>1]|0;e=b[a+2>>1]|0;M=B;J=a;E=ca(b[J>>1]|0,c[M+4>>2]|0)|0;K=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[M>>2]|0)+(E+(b[J+2>>1]|0))|0,c[B+4>>2]|0,2147483647)|0;C=K+(moc(A,a,q,d)|0)|0;if((f|0)!=0){N=k;k=-1;a=0;while(1){if((a|0)>(N|0)){break}K=-1;J=A;E=L;M=e;F=1<<a;if(((E-F|0)>=(c[J+1128244>>2]|0)&(E+F|0)<=(c[J+1128248>>2]|0)&(M-F|0)>=(c[J+1128236>>2]|0)&(M+F|0)<=(c[J+1128240>>2]|0)|0)!=0){O=0;while(1){if((O|0)>=(c[m+(a<<2)>>2]|0)){break}b[r>>1]=L+(b[n+(a<<5)+(O<<2)>>1]|0);b[r+2>>1]=e+(b[n+(a<<5)+(O<<2)+2>>1]|0);J=B;F=r;M=ca(b[F>>1]|0,c[J+4>>2]|0)|0;P=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[J>>2]|0)+(M+(b[F+2>>1]|0))|0,c[B+4>>2]|0,C)|0;if((P|0)<(C|0)){if((j|0)!=0){P=P+(moc(A,r,q,d)|0)|0}if((P|0)<(C|0)){C=P;K=O}}O=O+1|0}}else{O=0;while(1){if((O|0)>=(c[m+(a<<2)>>2]|0)){break}b[s>>1]=L+(b[n+(a<<5)+(O<<2)>>1]|0);b[s+2>>1]=e+(b[n+(a<<5)+(O<<2)+2>>1]|0);F=A;M=s;do{if((b[M+2>>1]|0)>=(c[F+1128236>>2]|0)){if((b[M+2>>1]|0)>(c[F+1128240>>2]|0)){Q=0;break}if((b[M>>1]|0)<(c[F+1128244>>2]|0)){Q=0;break}Q=(b[M>>1]|0)<=(c[F+1128248>>2]|0)}else{Q=0}}while(0);if((Q&1|0)!=0){F=B;M=s;J=ca(b[M>>1]|0,c[F+4>>2]|0)|0;P=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[F>>2]|0)+(J+(b[M+2>>1]|0))|0,c[B+4>>2]|0,C)|0;if((P|0)<(C|0)){if((j|0)!=0){P=P+(moc(A,s,q,d)|0)|0}if((P|0)<(C|0)){C=P;K=O}}}O=O+1|0}}if(!((K|0)==-1)){k=a;D=K}a=a+1|0}if((k|0)!=-1){L=L+(b[n+(k<<5)+(D<<2)>>1]|0)|0;e=e+(b[n+(k<<5)+(D<<2)+2>>1]|0)|0}}if((k|0)!=-1){a=-1;N=k;do{if((f|0)!=0){if((N|0)!=(k|0)){R=57}else{R=90}}else{R=57}do{if((R|0)==57){R=0;s=A;Q=L;r=e;M=1<<N;if(((Q-M|0)>=(c[s+1128244>>2]|0)&(Q+M|0)<=(c[s+1128248>>2]|0)&(r-M|0)>=(c[s+1128236>>2]|0)&(r+M|0)<=(c[s+1128240>>2]|0)|0)!=0){O=0;while(1){if((O|0)>=(c[m+(N<<2)>>2]|0)){break}b[t>>1]=L+(b[n+(N<<5)+(O<<2)>>1]|0);b[t+2>>1]=e+(b[n+(N<<5)+(O<<2)+2>>1]|0);s=B;M=t;r=ca(b[M>>1]|0,c[s+4>>2]|0)|0;P=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[s>>2]|0)+(r+(b[M+2>>1]|0))|0,c[B+4>>2]|0,C)|0;if((P|0)<(C|0)){if((j|0)!=0){P=P+(moc(A,t,q,d)|0)|0}if((P|0)<(C|0)){C=P;a=O}}O=O+1|0}}else{O=0;while(1){if((O|0)>=(c[m+(N<<2)>>2]|0)){break}b[u>>1]=L+(b[n+(N<<5)+(O<<2)>>1]|0);b[u+2>>1]=e+(b[n+(N<<5)+(O<<2)+2>>1]|0);M=A;r=u;do{if((b[r+2>>1]|0)>=(c[M+1128236>>2]|0)){if((b[r+2>>1]|0)>(c[M+1128240>>2]|0)){S=0;break}if((b[r>>1]|0)<(c[M+1128244>>2]|0)){S=0;break}S=(b[r>>1]|0)<=(c[M+1128248>>2]|0)}else{S=0}}while(0);if((S&1|0)!=0){M=B;r=u;s=ca(b[r>>1]|0,c[M+4>>2]|0)|0;P=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[M>>2]|0)+(s+(b[r+2>>1]|0))|0,c[B+4>>2]|0,C)|0;if((P|0)<(C|0)){if((j|0)!=0){P=P+(moc(A,u,q,d)|0)|0}if((P|0)<(C|0)){C=P;a=O}}}O=O+1|0}}if((a|0)==-1){break}L=L+(b[n+(N<<5)+(a<<2)>>1]|0)|0;e=e+(b[n+(N<<5)+(a<<2)+2>>1]|0)|0;D=a;R=90}}while(0);if((R|0)==90){R=0;do{a=-1;if((D|0)==0){T=(c[m+(N<<2)>>2]|0)-1|0}else{T=D-1|0}c[v>>2]=T;c[v+4>>2]=D;if((D|0)==((c[m+(N<<2)>>2]|0)-1|0)){U=0}else{U=D+1|0}c[v+8>>2]=U;K=A;r=L;s=e;M=1<<N;if(((r-M|0)>=(c[K+1128244>>2]|0)&(r+M|0)<=(c[K+1128248>>2]|0)&(s-M|0)>=(c[K+1128236>>2]|0)&(s+M|0)<=(c[K+1128240>>2]|0)|0)!=0){O=0;while(1){if((O|0)>=3){break}b[w>>1]=L+(b[n+(N<<5)+(c[v+(O<<2)>>2]<<2)>>1]|0);b[w+2>>1]=e+(b[n+(N<<5)+(c[v+(O<<2)>>2]<<2)+2>>1]|0);K=B;M=w;s=ca(b[M>>1]|0,c[K+4>>2]|0)|0;P=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[K>>2]|0)+(s+(b[M+2>>1]|0))|0,c[B+4>>2]|0,C)|0;if((P|0)<(C|0)){if((j|0)!=0){P=P+(moc(A,w,q,d)|0)|0}if((P|0)<(C|0)){C=P;a=O}}O=O+1|0}}else{O=0;while(1){if((O|0)>=3){break}b[x>>1]=L+(b[n+(N<<5)+(c[v+(O<<2)>>2]<<2)>>1]|0);b[x+2>>1]=e+(b[n+(N<<5)+(c[v+(O<<2)>>2]<<2)+2>>1]|0);M=A;s=x;do{if((b[s+2>>1]|0)>=(c[M+1128236>>2]|0)){if((b[s+2>>1]|0)>(c[M+1128240>>2]|0)){V=0;break}if((b[s>>1]|0)<(c[M+1128244>>2]|0)){V=0;break}V=(b[s>>1]|0)<=(c[M+1128248>>2]|0)}else{V=0}}while(0);if((V&1|0)!=0){M=B;s=x;K=ca(b[s>>1]|0,c[M+4>>2]|0)|0;P=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[M>>2]|0)+(K+(b[s+2>>1]|0))|0,c[B+4>>2]|0,C)|0;if((P|0)<(C|0)){if((j|0)!=0){P=P+(moc(A,x,q,d)|0)|0}if((P|0)<(C|0)){C=P;a=O}}}O=O+1|0}}if((a|0)!=-1){D=c[v+(a<<2)>>2]|0;L=L+(b[n+(N<<5)+(D<<2)>>1]|0)|0;e=e+(b[n+(N<<5)+(D<<2)+2>>1]|0)|0}}while((a|0)!=-1)}s=N;N=s-1|0;}while((s|0)!=0)}if((g|0)==0){W=L;X=W&65535;Y=l;Z=Y|0;b[Z>>1]=X;_=e;$=_&65535;aa=l;ba=aa+2|0;b[ba>>1]=$;da=C;i=p;return da|0}g=0;while(1){if((g|0)>=16){break}N=-1;a=A;D=L;n=e;v=1;if(((D-v|0)>=(c[a+1128244>>2]|0)&(D+v|0)<=(c[a+1128248>>2]|0)&(n-v|0)>=(c[a+1128236>>2]|0)&(n+v|0)<=(c[a+1128240>>2]|0)|0)!=0){O=0;while(1){if((O|0)>=4){break}b[y>>1]=L+(b[207960+(O<<2)>>1]|0);b[y+2>>1]=e+(b[207962+(O<<2)>>1]|0);a=B;v=y;n=ca(b[v>>1]|0,c[a+4>>2]|0)|0;P=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[a>>2]|0)+(n+(b[v+2>>1]|0))|0,c[B+4>>2]|0,C)|0;if((P|0)<(C|0)){if((j|0)!=0){P=P+(moc(A,y,q,d)|0)|0}if((P|0)<(C|0)){C=P;N=O}}O=O+1|0}}else{O=0;while(1){if((O|0)>=4){break}b[z>>1]=L+(b[207960+(O<<2)>>1]|0);b[z+2>>1]=e+(b[207962+(O<<2)>>1]|0);v=A;n=z;do{if((b[n+2>>1]|0)>=(c[v+1128236>>2]|0)){if((b[n+2>>1]|0)>(c[v+1128240>>2]|0)){ea=0;break}if((b[n>>1]|0)<(c[v+1128244>>2]|0)){ea=0;break}ea=(b[n>>1]|0)<=(c[v+1128248>>2]|0)}else{ea=0}}while(0);if((ea&1|0)!=0){v=B;n=z;a=ca(b[n>>1]|0,c[v+4>>2]|0)|0;P=Xe[c[h>>2]&511](c[o>>2]|0,c[o+4>>2]|0,(c[v>>2]|0)+(a+(b[n+2>>1]|0))|0,c[B+4>>2]|0,C)|0;if((P|0)<(C|0)){if((j|0)!=0){P=P+(moc(A,z,q,d)|0)|0}if((P|0)<(C|0)){C=P;N=O}}}O=O+1|0}}if((N|0)==-1){R=166;break}L=L+(b[207960+(N<<2)>>1]|0)|0;e=e+(b[207962+(N<<2)>>1]|0)|0;g=g+1|0}W=L;X=W&65535;Y=l;Z=Y|0;b[Z>>1]=X;_=e;$=_&65535;aa=l;ba=aa+2|0;b[ba>>1]=$;da=C;i=p;return da|0}function hoc(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0;k=i;l=goc(a,b,c,d,e,0,f,g,h,j,233904,233952)|0;i=k;return l|0}function ioc(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0;k=i;l=goc(a,b,c,d,e,0,f,g,h,j,203816,203864)|0;i=k;return l|0}function joc(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0;k=i;l=c;if(9>(l|0)){m=9}else{m=l}l=foc(a,b,m,d,e,f,g,h,j)|0;i=k;return l|0}function koc(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0;k=i;l=c;if(9>(l|0)){m=9}else{m=l}l=hoc(a,b,m,d,e,f,g,h,j)|0;i=k;return l|0}function loc(a,d,e,f,g,h,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;i=i+56|0;l=f|0;m=f+8|0;n=f+24|0;o=f+40|0;p=f+48|0;q=a;a=d;d=e;e=g;g=h;h=j;j=k;k=q+24720|0;r=c[q+8204>>2]|0;s=c[q+8208>>2]|0;t=c[k+28>>2]|0;u=2147483647;b[l>>1]=b[j>>1]>>3;b[l+2>>1]=b[j+2>>1]>>3;j=0;v=0;w=64;x=a;y=c[q+1128244>>2]|0;z=c[q+1128248>>2]|0;A=b[x+2>>1]|0;B=c[q+1128236>>2]|0;C=c[q+1128240>>2]|0;if((A|0)<(B|0)){D=B}else{if((A|0)>(C|0)){E=C}else{E=A}D=E}b[x+2>>1]=D;D=b[x>>1]|0;E=y;y=z;if((D|0)<(E|0)){F=E}else{if((D|0)>(y|0)){G=y}else{G=D}F=G}b[x>>1]=F;F=b[a>>1]|0;x=b[a+2>>1]|0;c[g>>2]=11;b[d>>1]=F;b[d+2>>1]=x;g=(c[k+24>>2]|0)+(ca(F,t)|0)+x|0;k=Xe[c[h>>2]&511](r,s,g,t,2147483647)|0;u=k+(moc(q,d,l,e)|0)|0;if((-w|0)>((c[q+1128244>>2]|0)-F|0)){H=-w|0}else{H=(c[q+1128244>>2]|0)-F|0}if((-w|0)>((c[q+1128236>>2]|0)-x|0)){I=-w|0}else{I=(c[q+1128236>>2]|0)-x|0}k=I;if((w|0)<((c[q+1128248>>2]|0)-F|0)){J=w}else{J=(c[q+1128248>>2]|0)-F|0}I=J;if((w|0)<((c[q+1128240>>2]|0)-x|0)){K=w}else{K=(c[q+1128240>>2]|0)-x|0}w=K;K=H;while(1){if((K|0)>(I|0)){break}H=k;while(1){if((H|0)>(w|0)){break}if((H+3|0)<=(w|0)){L=0;while(1){if((L|0)>=4){break}c[n+(L<<2)>>2]=g+(ca(K,t)|0)+H+L;L=L+1|0}pe[c[h+40>>2]&1023](r,s,n|0,t,m|0);L=0;while(1){if((L|0)>=4){break}if((c[m+(L<<2)>>2]|0)>>>0<u>>>0){b[o>>1]=F+K;b[o+2>>1]=x+H+L;J=c[m+(L<<2)>>2]|0;M=J+(moc(q,o,l,e)|0)|0;if(M>>>0<u>>>0){u=M;j=K;v=H+L|0}}L=L+1|0}}else{L=0;while(1){if((L|0)>=(w-H|0)){break}J=g+(ca(K,t)|0)+H+L|0;M=Xe[c[h>>2]&511](r,s,J,t,u)|0;if(M>>>0<u>>>0){b[p>>1]=F+K;b[p+2>>1]=x+H+L;M=M+(moc(q,p,l,e)|0)|0;if(M>>>0<u>>>0){u=M;j=K;v=H+L|0}}L=L+1|0}}H=H+4|0}K=K+1|0}K=d|0;b[K>>1]=(b[K>>1]|0)+j;j=d+2|0;b[j>>1]=(b[j>>1]|0)+v;i=f;return u|0}function moc(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+8|0;h=g|0;j=a;a=d;d=e;if((j+861796|0)==0){k=0;l=k;i=g;return l|0}b[h>>1]=(b[a>>1]|0)-(b[d>>1]|0);b[h+2>>1]=(b[a+2>>1]|0)-(b[d+2>>1]|0);d=h;h=j+861796|0;a=d;if((b[a>>1]|0)==0){m=(b[a+2>>1]|0)==0?0:1}else{m=(b[a+2>>1]|0)==0?2:3}k=(ca((c[j+599644+(m<<2)>>2]|0)+(c[(c[h>>2]|0)+(b[d>>1]<<2)>>2]|0)+(c[(c[h+4>>2]|0)+(b[d+2>>1]<<2)>>2]|0)|0,f)|0)+128>>8;l=k;i=g;return l|0}function noc(a,d,e,f,g,h,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;l=i;i=i+16|0;m=l|0;n=l+8|0;o=a;a=d;d=e;e=f;f=g;g=h;h=j;j=k;k=o+8204|0;p=o+24744|0;q=ca(e,c[o+75228>>2]|0)|0;r=(c[o+75220>>2]|0)+(q<<3)|0;q=((c[o+75224>>2]|0)/(c[o+75228>>2]|0)|0)-e|0;b[m>>1]=b[j>>1]>>3;b[m+2>>1]=b[j+2>>1]>>3;j=2147483647;e=0;s=0;t=a;u=c[o+1128244>>2]|0;v=c[o+1128248>>2]|0;w=b[t+2>>1]|0;x=c[o+1128236>>2]|0;y=c[o+1128240>>2]|0;if((w|0)<(x|0)){z=x}else{if((w|0)>(y|0)){A=y}else{A=w}z=A}b[t+2>>1]=z;z=b[t>>1]|0;A=u;u=v;if((z|0)<(A|0)){B=A}else{if((z|0)>(u|0)){C=u}else{C=z}B=C}b[t>>1]=B;B=p;t=a;C=ca(b[t>>1]|0,c[B+4>>2]|0)|0;z=(c[B>>2]|0)+(C+(b[t+2>>1]|0))|0;t=z;c[g>>2]=0;C=d;B=a;b[C>>1]=b[B>>1]|0;b[C+2>>1]=b[B+2>>1]|0;B=Xe[c[h>>2]&511](c[k>>2]|0,c[k+4>>2]|0,t,c[p+4>>2]|0,2147483647)|0;j=B+(moc(o,d,m,f)|0)|0;B=1;C=0;while(1){if((C|0)>=(q|0)){break}a=0;while(1){if((a|0)>=(c[o+75228>>2]|0)){break}b[n>>1]=(b[d>>1]|0)+(b[r+(B<<3)>>1]|0);b[n+2>>1]=(b[d+2>>1]|0)+(b[r+(B<<3)+2>>1]|0);u=o;A=n;do{if((b[A+2>>1]|0)>=(c[u+1128236>>2]|0)){if((b[A+2>>1]|0)>(c[u+1128240>>2]|0)){D=0;break}if((b[A>>1]|0)<(c[u+1128244>>2]|0)){D=0;break}D=(b[A>>1]|0)<=(c[u+1128248>>2]|0)}else{D=0}}while(0);if((D&1|0)!=0){u=Xe[c[h>>2]&511](c[k>>2]|0,c[k+4>>2]|0,t+(c[r+(B<<3)+4>>2]|0)|0,c[p+4>>2]|0,j)|0;if((u|0)<(j|0)){u=u+(moc(o,n,m,f)|0)|0;if((u|0)<(j|0)){j=u;e=B}}}B=B+1|0;a=a+1|0}if((e|0)!=(s|0)){a=d|0;b[a>>1]=(b[a>>1]|0)+(b[r+(e<<3)>>1]|0);a=d+2|0;b[a>>1]=(b[a>>1]|0)+(b[r+(e<<3)+2>>1]|0);t=t+(c[r+(e<<3)+4>>2]|0)|0;s=e}else{if((t|0)==(z|0)){a=g;c[a>>2]=(c[a>>2]|0)+1}}C=C+1|0}i=l;return j|0}function ooc(a,d,e,f,g,h,j,k,l,m){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;n=i;i=i+32|0;o=n|0;p=n+8|0;q=n+16|0;r=n+24|0;s=a;a=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;c[q>>2]=0;m=gf[c[s+2047248>>2]&63](a,d,o,e,f,p,j,k)|0;if((m|0)<2147483647){m=doc(a,o,k,j,1)|0}t=l;u=o;b[t>>1]=b[u>>1]|0;b[t+2>>1]=b[u+2>>1]|0;if((c[p>>2]|0)>(g|0)){h=0}while(1){if((c[p>>2]|0)>=(g|0)){break}c[p>>2]=(c[p>>2]|0)+1;if((c[q>>2]|0)!=0){c[q>>2]=(c[q>>2]|0)-1}else{v=gf[c[s+2047248>>2]&63](a,d,o,e+(c[p>>2]|0)|0,f,q,j,k)|0;if((v|0)<2147483647){v=doc(a,o,k,j,1)|0}if((c[q>>2]|0)>(g-(c[p>>2]|0)|0)){h=0}if((v|0)<(m|0)){m=v;u=l;t=o;b[u>>1]=b[t>>1]|0;b[u+2>>1]=b[t+2>>1]|0}}}if((h|0)==0){w=m;i=n;return w|0}h=r;o=l;b[h>>1]=b[o>>1]|0;b[h+2>>1]=b[o+2>>1]|0;v=se[c[s+2047244>>2]&127](a,r,f,8,j,k)|0;if((v|0)<2147483647){v=doc(a,r,k,j,1)|0}if((v|0)<(m|0)){m=v;v=l;l=r;b[v>>1]=b[l>>1]|0;b[v+2>>1]=b[l+2>>1]|0}w=m;i=n;return w|0}function poc(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+16|0;l=k|0;m=k+8|0;n=a;a=d;d=e;e=f;f=g;g=h;h=j;j=n+8204|0;o=n+24744|0;if(((b[a>>1]|0)-e|0)>(c[n+1128244>>2]|0)){p=(b[a>>1]|0)-e|0}else{p=c[n+1128244>>2]|0}if(((b[a>>1]|0)+e|0)<(c[n+1128248>>2]|0)){q=(b[a>>1]|0)+e|0}else{q=c[n+1128248>>2]|0}r=q;if(((b[a+2>>1]|0)-e|0)>(c[n+1128236>>2]|0)){s=(b[a+2>>1]|0)-e|0}else{s=c[n+1128236>>2]|0}q=s;if(((b[a+2>>1]|0)+e|0)<(c[n+1128240>>2]|0)){t=(b[a+2>>1]|0)+e|0}else{t=c[n+1128240>>2]|0}e=t;b[l>>1]=b[g>>1]>>3;b[l+2>>1]=b[g+2>>1]>>3;g=o;t=a;s=ca(b[t>>1]|0,c[g+4>>2]|0)|0;u=Xe[c[f>>2]&511](c[j>>2]|0,c[j+4>>2]|0,(c[g>>2]|0)+(s+(b[t+2>>1]|0))|0,c[o+4>>2]|0,2147483647)|0;t=u+(moc(n,a,l,d)|0)|0;u=h;s=a;b[u>>1]=b[s>>1]|0;b[u+2>>1]=b[s+2>>1]|0;s=p;while(1){if((s|0)>=(r|0)){break}p=q;while(1){if((p|0)>=(e|0)){break}b[m>>1]=s;b[m+2>>1]=p;u=o;a=m;g=ca(b[a>>1]|0,c[u+4>>2]|0)|0;v=Xe[c[f>>2]&511](c[j>>2]|0,c[j+4>>2]|0,(c[u>>2]|0)+(g+(b[a+2>>1]|0))|0,c[o+4>>2]|0,t)|0;a=v+(moc(n,m,l,d)|0)|0;if((a|0)<(t|0)){t=a;a=h;v=m;b[a>>1]=b[v>>1]|0;b[a+2>>1]=b[v+2>>1]|0}p=p+1|0}s=s+1|0}i=k;return t|0}function qoc(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=a;a=d;d=e;e=f;f=g;g=h;h=m+8204|0;n=m+24744|0;b[k>>1]=b[g>>1]>>3;b[k+2>>1]=b[g+2>>1]>>3;g=n;o=a;p=ca(b[o>>1]|0,c[g+4>>2]|0)|0;q=Xe[c[f>>2]&511](c[h>>2]|0,c[h+4>>2]|0,(c[g>>2]|0)+(p+(b[o+2>>1]|0))|0,c[n+4>>2]|0,2147483647)|0;o=q+(moc(m,a,k,d)|0)|0;q=0;while(1){if((q|0)>=(e|0)){r=22;break}p=-1;g=0;while(1){if((g|0)>=4){break}b[l>>1]=(b[a>>1]|0)+(b[206696+(g<<2)>>1]|0);b[l+2>>1]=(b[a+2>>1]|0)+(b[206698+(g<<2)>>1]|0);s=m;t=l;do{if((b[t+2>>1]|0)>=(c[s+1128236>>2]|0)){if((b[t+2>>1]|0)>(c[s+1128240>>2]|0)){u=0;break}if((b[t>>1]|0)<(c[s+1128244>>2]|0)){u=0;break}u=(b[t>>1]|0)<=(c[s+1128248>>2]|0)}else{u=0}}while(0);if((u&1|0)!=0){s=n;t=l;v=ca(b[t>>1]|0,c[s+4>>2]|0)|0;w=Xe[c[f>>2]&511](c[h>>2]|0,c[h+4>>2]|0,(c[s>>2]|0)+(v+(b[t+2>>1]|0))|0,c[n+4>>2]|0,o)|0;if(w>>>0<o>>>0){w=w+(moc(m,l,k,d)|0)|0;if(w>>>0<o>>>0){o=w;p=g}}}g=g+1|0}if((p|0)==-1){break}g=a|0;b[g>>1]=(b[g>>1]|0)+(b[206696+(p<<2)>>1]|0);g=a+2|0;b[g>>1]=(b[g>>1]|0)+(b[206698+(p<<2)>>1]|0);q=q+1|0}if((r|0)==22){x=o;i=j;return x|0}x=o;i=j;return x|0}function roc(a,d,e,f,g,h,j,k,l){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=i;i=i+16|0;k=l|0;m=l+8|0;n=a;a=d;d=e;e=f;f=g;g=h;h=j;j=n+8204|0;o=n+24744|0;b[k>>1]=b[g>>1]>>3;b[k+2>>1]=b[g+2>>1]>>3;g=o;p=a;q=ca(b[p>>1]|0,c[g+4>>2]|0)|0;r=se[c[f+4>>2]&127](c[j>>2]|0,c[j+4>>2]|0,(c[g>>2]|0)+(q+(b[p+2>>1]|0))|0,c[o+4>>2]|0,h,2147483647)|0;p=r+(moc(n,a,k,d)|0)|0;r=0;while(1){if((r|0)>=(e|0)){s=22;break}q=-1;g=0;while(1){if((g|0)>=8){break}b[m>>1]=(b[a>>1]|0)+(b[206712+(g<<2)>>1]|0);b[m+2>>1]=(b[a+2>>1]|0)+(b[206714+(g<<2)>>1]|0);t=n;u=m;do{if((b[u+2>>1]|0)>=(c[t+1128236>>2]|0)){if((b[u+2>>1]|0)>(c[t+1128240>>2]|0)){v=0;break}if((b[u>>1]|0)<(c[t+1128244>>2]|0)){v=0;break}v=(b[u>>1]|0)<=(c[t+1128248>>2]|0)}else{v=0}}while(0);if((v&1|0)!=0){t=o;u=m;w=ca(b[u>>1]|0,c[t+4>>2]|0)|0;x=se[c[f+4>>2]&127](c[j>>2]|0,c[j+4>>2]|0,(c[t>>2]|0)+(w+(b[u+2>>1]|0))|0,c[o+4>>2]|0,h,p)|0;if(x>>>0<p>>>0){x=x+(moc(n,m,k,d)|0)|0;if(x>>>0<p>>>0){p=x;q=g}}}g=g+1|0}if((q|0)==-1){break}g=a|0;b[g>>1]=(b[g>>1]|0)+(b[206712+(q<<2)>>1]|0);g=a+2|0;b[g>>1]=(b[g>>1]|0)+(b[206714+(q<<2)>>1]|0);r=r+1|0}if((s|0)==22){y=p;i=l;return y|0}y=p;i=l;return y|0}function soc(e,f,g,h,j,k,l,m){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0;n=i;i=i+496|0;o=n|0;p=n+224|0;q=n+320|0;r=n+328|0;s=n+336|0;t=n+344|0;u=n+352|0;v=n+360|0;w=n+368|0;x=n+424|0;y=n+432|0;z=n+440|0;A=n+448|0;B=n+456|0;C=n+472|0;D=e;e=f;f=g;g=h;h=j;j=k;k=l;l=m;m=e+24720|0;E=c[c[m+160>>2]>>2]|0;F=e|0;H=m|0;I=12;J=1;K=0;c[q>>2]=-1;c[q+4>>2]=2147483647;c[r>>2]=-1;c[r+4>>2]=2147483647;c[s>>2]=2147483647;c[t>>2]=-1;c[t+4>>2]=2147483647;L=D+1434592|0;M=((ngc(c[L+10168>>2]|0,c[L+10172>>2]|0)|0)<<16>>16)*20|0;L=M;N=c[e+75248>>2]|0;O=Erc(L,(L|0)<0|0?-1:0,N,(N|0)<0|0?-1:0)|0;N=wrc(128,0,O,G)|0;O=G;L=0<<c[e+75244>>2];P=wrc(N>>>8|O<<24,O>>8|((O|0)<0|0?-1:0)<<24,L,(L|0)<0|0?-1:0)|0;c[u>>2]=P;c[u+4>>2]=G;c[v>>2]=50;c[v+4>>2]=0;v=a[E+13|0]|0;P=D+1473448+((v&255)*1560|0)+(l*120|0)|0;L=D+1485928+(l*120|0)|0;mrc(w|0,0,56)|0;O=4;if((c[D+2046932>>2]|0)!=0){Q=(c[e+75216>>2]|0)<115}else{Q=0}c[e+1184592>>2]=Q&1;c[e+1129276>>2]=0;if((c[e+1129284>>2]|0)==0){c[e+1129276>>2]=1}c[j>>2]=2147483647;Q=k;c[Q>>2]=-1;c[Q+4>>2]=2147483647;mrc(E|0,0,76)|0;c[E>>2]=l;c[E+20>>2]=-1;c[E+24>>2]=-1;if((c[833024+(l<<2)>>2]|0)>>>0<(c[301584+(c[D+1444756>>2]<<2)>>2]|0)>>>0){R=c[833024+(l<<2)>>2]|0}else{R=c[301584+(c[D+1444756>>2]<<2)>>2]|0}c[E+8>>2]=R;if((c[D+1444812>>2]|0)==4){S=0}else{S=c[D+1444812>>2]|0}c[E+72>>2]=S;a[E+12|0]=0;a[E+13|0]=v;v=1;while(1){if((v|0)>1){break}c[e+75320+(v<<2)>>2]=2147483647;if((c[D+2046872>>2]&c[207896+(v<<2)>>2]|0)!=0){J3b(D,e,f,v,l,g,h,o+160|0,o+176|0,p|0)}c[o+208+(v<<2)>>2]=-2147450880;c[o+192+(v<<2)>>2]=0;v=v+1|0}if((c[m+164>>2]|0)!=0){O=c[(c[(c[m+160>>2]|0)+(-(c[m+156>>2]|0)<<2)>>2]|0)+72>>2]|0}else{if((c[m+168>>2]|0)!=0){O=c[(c[(c[m+160>>2]|0)-4>>2]|0)+72>>2]|0}}v=1;while(1){if((v|0)>1){break}if((c[D+2046872>>2]&c[207896+(v<<2)>>2]|0)!=0){S=m+24|0;R=p+(v*24|0)|0;c[S>>2]=c[R>>2];c[S+4>>2]=c[R+4>>2];R=m;S=o+160+(v<<2)|0;Q=(c[R+180>>2]|0)-1248|0;N=(c[R+184>>2]|0)+1248|0;T=b[S+2>>1]|0;U=(c[R+172>>2]|0)-1248|0;V=(c[R+176>>2]|0)+1248|0;if((T|0)<(U|0)){W=U}else{if((T|0)>(V|0)){X=V}else{X=T}W=X}b[S+2>>1]=W;T=b[S>>1]|0;V=Q;Q=N;if((T|0)<(V|0)){Y=V}else{if((T|0)>(Q|0)){Z=Q}else{Z=T}Y=Z}b[S>>1]=Y;S=m;T=o+176+(v<<2)|0;Q=(c[S+180>>2]|0)-1248|0;V=(c[S+184>>2]|0)+1248|0;N=b[T+2>>1]|0;U=(c[S+172>>2]|0)-1248|0;R=(c[S+176>>2]|0)+1248|0;if((N|0)<(U|0)){_=U}else{if((N|0)>(R|0)){$=R}else{$=N}_=$}b[T+2>>1]=_;N=b[T>>1]|0;R=Q;Q=V;if((N|0)<(R|0)){aa=R}else{if((N|0)>(Q|0)){ba=Q}else{ba=N}aa=ba}b[T>>1]=aa;c[E+20>>2]=v;if((v|0)==1){c[w+40>>2]=0;c[w+44>>2]=7;c[w+48>>2]=17;c[w+52>>2]=4}ca=10;while(1){if(!(ca>>>0<=13>>>0)){break}c[x>>2]=0;a:do{if((c[D+2047092+(l<<2)>>2]&1<<ca-10|0)==0){T=c[q>>2]|0;N=c[q+4>>2]|0;Q=c[P+(c[w+(ca<<2)>>2]<<2)>>2]|0;R=c[L+(ca<<2)>>2]|0;V=Erc(Q,(Q|0)<0|0?-1:0,R,(R|0)<0|0?-1:0)|0;R=G;Q=R>>5|((R|0)<0|0?-1:0)<<27;do{if(!((N|0)<(Q|0)|(N|0)==(Q|0)&T>>>0<(V>>>5|R<<27)>>>0)){if((c[P+(c[w+(ca<<2)>>2]<<2)>>2]|0)==2147483647){break}do{if((ca|0)==13){U=0;S=c[r+4>>2]|0;da=1<<c[777552+(l<<2)>>2];ea=(da|0)<0|0?-1:0;if((S|0)<(ea|0)|(S|0)==(ea|0)&(c[r>>2]|0)>>>0<da>>>0){break a}toc(D,e,f,l,g,h,o+208+(v<<2)|0,x);if((c[o+208+(v<<2)>>2]|0)==-2147450880){break a}U=c[e+1123992+(d[E+68+v|0]<<4)+(ca-10<<2)>>2]|0;da=c[x>>2]|0;ea=U;U=wrc(da,(da|0)<0|0?-1:0,ea,(ea|0)<0|0?-1:0)|0;ea=c[e+75248>>2]|0;da=Erc(U,G,ea,(ea|0)<0|0?-1:0)|0;ea=wrc(128,0,da,G)|0;da=G;U=0<<c[e+75244>>2];S=wrc(ea>>>8|da<<24,da>>8|((da|0)<0|0?-1:0)<<24,U,(U|0)<0|0?-1:0)|0;U=G;da=c[q+4>>2]|0;if((U|0)>(da|0)|(U|0)==(da|0)&S>>>0>(c[q>>2]|0)>>>0){break a}else{uoc(D,e,f,l,g,h,o+208+(v<<2)|0);break}}}while(0);do{if((ca|0)!=10){if((c[o+(ca<<4)+(v<<2)>>2]|0)==(c[o+160+(v<<2)>>2]|0)){break a}else{break}}}while(0);c[E+4>>2]=ca;c[E+28>>2]=c[o+(ca<<4)+(v<<2)>>2];if((ca|0)==13){fa=73}else{if((O|0)==4){fa=73}else{fa=85}}do{if((fa|0)==73){fa=0;if((b[E+28>>1]&7|0)==0){if((b[E+30>>1]&7|0)==0){fa=85;break}}c[y>>2]=-1;c[y+4>>2]=2147483647;c[z>>2]=-1;c[z+4>>2]=2147483647;c[A>>2]=-1;c[A+4>>2]=2147483647;c[E+72>>2]=0;tgc(m,g,h,l);voc(D,l,e,m,B|0,C|0);S=N3b(e)|0;da=c[B>>2]|0;U=wrc(S,(S|0)<0|0?-1:0,da,(da|0)<0|0?-1:0)|0;da=c[e+75248>>2]|0;S=Erc(U,G,da,(da|0)<0|0?-1:0)|0;da=wrc(128,0,S,G)|0;S=G;U=C|0;ea=yrc(c[U>>2]|0,c[U+4>>2]|0,c[e+75244>>2]|0)|0;U=wrc(da>>>8|S<<24,S>>8|((S|0)<0|0?-1:0)<<24,ea,G)|0;c[y>>2]=U;c[y+4>>2]=G;c[E+72>>2]=2;tgc(m,g,h,l);voc(D,l,e,m,B+8|0,C+16|0);U=N3b(e)|0;ea=c[B+8>>2]|0;S=wrc(U,(U|0)<0|0?-1:0,ea,(ea|0)<0|0?-1:0)|0;ea=c[e+75248>>2]|0;U=Erc(S,G,ea,(ea|0)<0|0?-1:0)|0;ea=wrc(128,0,U,G)|0;U=G;S=C+16|0;da=yrc(c[S>>2]|0,c[S+4>>2]|0,c[e+75244>>2]|0)|0;S=wrc(ea>>>8|U<<24,U>>8|((U|0)<0|0?-1:0)<<24,da,G)|0;c[z>>2]=S;c[z+4>>2]=G;c[E+72>>2]=1;tgc(m,g,h,l);voc(D,l,e,m,B+4|0,C+8|0);S=N3b(e)|0;da=c[B+4>>2]|0;U=wrc(S,(S|0)<0|0?-1:0,da,(da|0)<0|0?-1:0)|0;da=c[e+75248>>2]|0;S=Erc(U,G,da,(da|0)<0|0?-1:0)|0;da=wrc(128,0,S,G)|0;S=G;U=C+8|0;ea=yrc(c[U>>2]|0,c[U+4>>2]|0,c[e+75244>>2]|0)|0;U=wrc(da>>>8|S<<24,S>>8|((S|0)<0|0?-1:0)<<24,ea,G)|0;c[A>>2]=U;c[A+4>>2]=G;U=c[z+4>>2]|0;ea=c[y+4>>2]|0;if((U|0)<(ea|0)|(U|0)==(ea|0)&(c[z>>2]|0)>>>0<(c[y>>2]|0)>>>0){ea=c[z+4>>2]|0;U=c[A+4>>2]|0;if((ea|0)<(U|0)|(ea|0)==(U|0)&(c[z>>2]|0)>>>0<(c[A>>2]|0)>>>0){c[E+72>>2]=2}else{c[E+72>>2]=1}}else{U=c[y+4>>2]|0;ea=c[A+4>>2]|0;if((U|0)<(ea|0)|(U|0)==(ea|0)&(c[y>>2]|0)>>>0<(c[A>>2]|0)>>>0){c[E+72>>2]=0}else{c[E+72>>2]=1}}c[s>>2]=c[B+(c[E+72>>2]<<2)>>2];ea=C+(c[E+72>>2]<<3)|0;U=c[ea+4>>2]|0;c[t>>2]=c[ea>>2];c[t+4>>2]=U}}while(0);if((fa|0)==85){fa=0;if((O|0)==4){ga=0}else{ga=O}c[E+72>>2]=ga;tgc(m,g,h,l);voc(D,l,e,m,s,t)}c[s>>2]=(c[s>>2]|0)+(c[x>>2]|0);c[s>>2]=(c[s>>2]|0)+(c[e+1123992+(d[E+68+v|0]<<4)+(ca-10<<2)>>2]|0);U=c[s>>2]|0;ea=c[e+75248>>2]|0;S=Erc(U,(U|0)<0|0?-1:0,ea,(ea|0)<0|0?-1:0)|0;ea=wrc(128,0,S,G)|0;S=G;U=yrc(c[t>>2]|0,c[t+4>>2]|0,c[e+75244>>2]|0)|0;da=wrc(ea>>>8|S<<24,S>>8|((S|0)<0|0?-1:0)<<24,U,G)|0;c[r>>2]=da;c[r+4>>2]=G;da=c[r+4>>2]|0;U=c[q+4>>2]|0;if((da|0)<(U|0)|(da|0)==(U|0)&(c[r>>2]|0)>>>0<(c[q>>2]|0)>>>0){U=c[r+4>>2]|0;c[q>>2]=c[r>>2];c[q+4>>2]=U;c[j>>2]=c[s>>2];U=c[t+4>>2]|0;da=k;c[da>>2]=c[t>>2];c[da+4>>2]=U;I=ca;K=c[E+72>>2]|0;J=v}break a}}while(0)}}while(0);ca=ca+1|0}}v=v+1|0}c[E+4>>2]=I;c[E+72>>2]=K;c[E+20>>2]=J;c[E+28>>2]=c[o+(I<<4)+(J<<2)>>2];c[(c[c[m+160>>2]>>2]|0)+80>>2]=c[E+28>>2];J=c[q+4>>2]|0;I=c[u+4>>2]|0;if(!((J|0)>(I|0)|(J|0)==(I|0)&(c[q>>2]|0)>>>0>(c[u>>2]|0)>>>0)){ha=-1;ia=2147483647;i=n;return(G=ia,ha)|0}ca=0;while(1){if(!(ca>>>0<=0>>>0)){break}Chc(m,0,c[1960336+(l<<2)>>2]|0,c[E+8>>2]|0,ca,c[F+8204>>2]|0,c[F+8208>>2]|0,c[H+16>>2]|0,c[H+20>>2]|0,0,0,0);voc(D,l,e,m,s,t);c[s>>2]=(c[s>>2]|0)+(c[e+1123952+(ca<<2)>>2]|0);c[s>>2]=(c[s>>2]|0)+M;u=c[s>>2]|0;I=c[e+75248>>2]|0;J=Erc(u,(u|0)<0|0?-1:0,I,(I|0)<0|0?-1:0)|0;I=wrc(128,0,J,G)|0;J=G;u=yrc(c[t>>2]|0,c[t+4>>2]|0,c[e+75244>>2]|0)|0;o=wrc(I>>>8|J<<24,J>>8|((J|0)<0|0?-1:0)<<24,u,G)|0;c[r>>2]=o;c[r+4>>2]=G;o=wrc(c[r>>2]|0,c[r+4>>2]|0,50,0)|0;u=G;J=c[q+4>>2]|0;if((u|0)<(J|0)|(u|0)==(J|0)&o>>>0<(c[q>>2]|0)>>>0){o=c[r+4>>2]|0;c[q>>2]=c[r>>2];c[q+4>>2]=o;c[j>>2]=c[s>>2];o=c[t+4>>2]|0;J=k;c[J>>2]=c[t>>2];c[J+4>>2]=o;c[E+4>>2]=ca;c[E+20>>2]=0;c[E+16>>2]=ca;c[E+28>>2]=-2147450880}ca=ca+1|0}ha=-1;ia=2147483647;i=n;return(G=ia,ha)|0}function toc(a,d,e,f,g,h,j,k){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+40|0;l=e|0;m=e+24|0;n=e+32|0;o=a;a=d;d=f;f=g;g=h;h=j;j=k;k=a+24720|0;p=c[c[k+160>>2]>>2]|0;mrc(l|0,0,24)|0;q=c[a+75236>>2]|0;r=c[p+20>>2]|0;s=n;t=p+36+(r<<3)|0;b[s>>1]=b[t>>1]|0;b[s+2>>1]=b[t+2>>1]|0;t=c[a+1128236>>2]|0;s=c[a+1128240>>2]|0;u=c[a+1128244>>2]|0;v=c[a+1128248>>2]|0;w=M3b(o,r)|0;if((w|0)!=0){x=0;while(1){if((x|0)>=3){break}y=l+(x<<3)|0;z=k+(x*52|0)+24|0;c[y>>2]=c[z>>2];c[y+4>>2]=c[z+4>>2];x=x+1|0}Agc(k,0,w,f,g,0)}Xnc(a,n);g=6;f=1;while(1){if((f|0)<=1){A=(c[o+1444704>>2]|0)!=0}else{A=0}if(!A){break}if((c[a+75320+(r<<2)>>2]>>3|0)>(c[a+75320+(f<<2)>>2]|0)){B=12;break}f=f+1|0}if((B|0)==12){c[h>>2]=-2147450880;if((w|0)!=0){B=0;while(1){if((B|0)>=3){break}f=k+(B*52|0)+24|0;A=l+(B<<3)|0;c[f>>2]=c[A>>2];c[f+4>>2]=c[A+4>>2];B=B+1|0}}i=e;return}if((c[a+75268+(r<<2)>>2]|0)<=2){}else{Cd(2262256,2536976,79,2652608)}if((c[a+75268+(r<<2)>>2]|0)<2){B=m;A=p+36+(r<<3)+(c[a+75268+(r<<2)>>2]<<2)|0;b[B>>1]=b[A>>1]|0;b[B+2>>1]=b[A+2>>1]|0}else{A=m;B=a+1184596+(r<<2)|0;b[A>>1]=b[B>>1]|0;b[A+2>>1]=b[B+2>>1]|0}B=m+2|0;b[B>>1]=b[B>>1]>>3;B=m|0;b[B>>1]=b[B>>1]>>3;if((c[o+2046880>>2]|0)==6){koc(a,m,g,q,0,o+2047252+(d*44|0)|0,1,n,h)|0}else{if((c[o+2046880>>2]|0)==5){joc(a,m,g,q,0,o+2047252+(d*44|0)|0,1,n,h)|0}else{if((c[o+2046880>>2]|0)==2){foc(a,m,g,q,1,o+2047252+(d*44|0)|0,1,n,h)|0}else{if((c[o+2046880>>2]|0)==4){ioc(a,m,g,q,1,o+2047252+(d*44|0)|0,1,n,h)|0}else{if((c[o+2046880>>2]|0)==3){hoc(a,m,g,q,1,o+2047252+(d*44|0)|0,1,n,h)|0}else{ooc(o,a,m,g,q,(c[o+2046900>>2]|0)-1-g|0,1,o+2047252+(d*44|0)|0,n,h)|0}}}}}c[a+1128236>>2]=t;c[a+1128240>>2]=s;c[a+1128244>>2]=u;c[a+1128248>>2]=v;if((w|0)!=0){w=0;while(1){if((w|0)>=3){break}v=k+(w*52|0)+24|0;u=l+(w<<3)|0;c[v>>2]=c[u>>2];c[v+4>>2]=c[u+4>>2];w=w+1|0}}b[m>>1]=b[h>>1]<<3;b[m+2>>1]=b[h+2>>1]<<3;c[j>>2]=Znc(m,n,a+75336|0,c[a+599640>>2]|0,108)|0;i=e;return}function uoc(a,d,e,f,g,h,j){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+40|0;k=e|0;l=e+24|0;m=e+32|0;n=a;a=d;d=f;f=g;g=h;h=j;j=a+24720|0;o=c[c[j+160>>2]>>2]|0;mrc(k|0,0,24)|0;p=c[o+20>>2]|0;q=l;r=o+36+(p<<3)|0;b[q>>1]=b[r>>1]|0;b[q+2>>1]=b[r+2>>1]|0;r=M3b(n,p)|0;if((r|0)!=0){q=0;while(1){if((q|0)>=3){break}o=k+(q<<3)|0;s=j+(q*52|0)+24|0;c[o>>2]=c[s>>2];c[o+4>>2]=c[s+4>>2];q=q+1|0}Agc(j,0,r,f,g,0)}Qe[c[n+2047232>>2]&3](a,h,l,c[n+1444720>>2]|0,c[a+75232>>2]|0,n+2047252+(d*44|0)|0,c[n+2046896>>2]|0,c[n+2046892>>2]|0,a+75336|0,c[a+599640>>2]|0,m,a+75304+(p<<2)|0)|0;if((r|0)==0){t=p;u=a;v=u+1184596|0;w=v+(t<<2)|0;x=w;y=h;z=x;A=y;b[z>>1]=b[A>>1]|0;b[z+2>>1]=b[A+2>>1]|0;i=e;return}r=0;while(1){if((r|0)>=3){break}m=j+(r*52|0)+24|0;n=k+(r<<3)|0;c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];r=r+1|0}t=p;u=a;v=u+1184596|0;w=v+(t<<2)|0;x=w;y=h;z=x;A=y;b[z>>1]=b[A>>1]|0;b[z+2>>1]=b[A+2>>1]|0;i=e;return}function voc(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;n=d;d=e|0;e=f|0;f=Xe[c[a+2047252+(n*44|0)+8>>2]&511](c[d+8204>>2]|0,c[d+8208>>2]|0,c[e+16>>2]|0,c[e+20>>2]|0,k)|0;F3b((c[k>>2]|0)+f|0,1<<c[777552+(n<<2)>>2],b[(c[e+40>>2]|0)+2>>1]>>3,l,m);c[g>>2]=c[l>>2];l=c[m>>2]|0;g=c[m+4>>2]<<3|l>>>29;m=h;c[m>>2]=l<<3|0>>>29;c[m+4>>2]=g;i=j;return}function woc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;yoc(a,xoc(b&255,c&255)|0);i=d;return}function xoc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a;a=b;e=e-1|0;a=a-1|0;if((a<<1|0)<=255){f=(Joc(e,a)|0)-1|0}else{f=(Joc(254-e|0,254-a|0)|0)-1|0}f=c[680912+(f<<2)>>2]|0;i=d;return f|0}function yoc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;b=a;e=16;Goc(d,(b|0)>=(e|0)|0,1);if(((b|0)>=(e|0)|0)==0){Goc(d,a,4);i=c;return}e=a;b=32;Goc(d,(e|0)>=(b|0)|0,1);if(((e|0)>=(b|0)|0)!=0){b=a;e=64;Goc(d,(b|0)>=(e|0)|0,1);if(((b|0)>=(e|0)|0)!=0){Hoc(d,a-64|0)}else{Goc(d,a-32|0,5)}}else{Goc(d,a-16|0,4)}i=c;return}function zoc(){var a=0,b=0;a=i;b=0;while(1){if((b|0)>=254){break}c[3388144+(b<<2)>>2]=Aoc(b)|0;b=b+1|0}i=a;return}function Aoc(a){a=a|0;var b=0,c=0,d=0;b=i;c=a;do{if((c|0)<16){d=5}else{if((c|0)<32){d=6;break}if((c|0)<64){d=8;break}if((c|0)<129){d=10;break}else{d=11;break}}}while(0);i=b;return d|0}function Boc(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=b;b=e;e=f;f=g;g=j;k=b;l=ca(c[g>>2]|0,c[206872+((k&255)<<2)>>2]|0)|0;m=l+(ca(c[g+4>>2]|0,c[206872+(255-(k&255)<<2)>>2]|0)|0)|0;k=0;g=b;l=(d[e]|0|0)>(b&255|0)?-1:1;n=a[e]|0;while(1){if((n&255|0)==(b&255|0)){break}o=j;p=n;q=ca(c[o>>2]|0,c[206872+((p&255)<<2)>>2]|0)|0;r=q+(ca(c[o+4>>2]|0,c[206872+(255-(p&255)<<2)>>2]|0)|0)|0;p=Coc(n,b)|0;o=m-r-(p+((c[206872+(255-(f&255)<<2)>>2]|0)-(c[206872+((f&255)<<2)>>2]|0)))|0;if((o|0)>(k|0)){k=o;g=n}n=(n&255)+l&255}a[e]=g;i=h;return k|0}function Coc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=c[3388144+((xoc(a&255,b&255)|0)<<2)>>2]<<8;i=d;return e|0}function Doc(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=b;b=e;e=f;f=g;wec(b,k|0);g=j;m=b;a[g]=a[m]|0;a[g+1|0]=a[m+1|0]|0;a[g+2|0]=a[m+2|0]|0;m=3;g=0;while(1){if((m|0)>=11){break}n=l+(m<<1<<2)|0;o=a[k+m|0]|0;p=ca(c[n>>2]|0,c[206872+((o&255)<<2)>>2]|0)|0;g=g+(p+(ca(c[n+4>>2]|0,c[206872+(255-(o&255)<<2)>>2]|0)|0))|0;m=m+1|0}o=l+16|0;n=a[k+2|0]|0;k=ca(c[o>>2]|0,c[206872+((n&255)<<2)>>2]|0)|0;g=g+(k+(ca(c[o+4>>2]|0,c[206872+(255-(n&255)<<2)>>2]|0)|0))|0;n=0;o=a[b+2|0]|0;k=(d[e]|0|0)>(d[b+2|0]|0|0)?-1:1;p=d[e]|0;while(1){if((p|0)==(d[b+2|0]|0|0)){break}do{if((p|0)<1){q=9}else{if((p|0)>255){q=9;break}a[j+2|0]=p;wec(j|0,j|0);m=3;r=0;while(1){if((m|0)>=11){break}s=l+(m<<1<<2)|0;t=a[j+m|0]|0;u=ca(c[s>>2]|0,c[206872+((t&255)<<2)>>2]|0)|0;r=r+(u+(ca(c[s+4>>2]|0,c[206872+(255-(t&255)<<2)>>2]|0)|0))|0;m=m+1|0}t=l+16|0;s=a[j+2|0]|0;u=ca(c[t>>2]|0,c[206872+((s&255)<<2)>>2]|0)|0;r=r+(u+(ca(c[t+4>>2]|0,c[206872+(255-(s&255)<<2)>>2]|0)|0))|0;s=Coc(p&255,a[b+2|0]|0)|0;t=g-r-(s+((c[206872+(255-(f&255)<<2)>>2]|0)-(c[206872+((f&255)<<2)>>2]|0)))|0;if((t|0)>(n|0)){n=t;o=p&255}}}while(0);if((q|0)==9){q=0}p=p+k|0}a[e]=o;i=h;return n|0}function Eoc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+8|0;h=g|0;j=b;b=e;e=f;f=c[e>>2]|0;k=f+(c[e+4>>2]|0)|0;if((k|0)==0){l=128}else{m=((f<<8)+(k>>1)|0)/(k|0)|0;if((m|0)>255){n=255}else{if((m|0)<1){o=1}else{o=m}n=o}l=n&255}a[h]=l;l=Boc(e,a[b]|0,h,-4)|0;if((d[h]|0|0)>=1){}else{Cd(2262152,2536848,185,2650704)}if((l|0)>0){Foc(j,1,252);woc(j,a[h]|0,a[b]|0);a[b]=a[h]|0;i=g;return}else{Foc(j,0,252);i=g;return}}function Foc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=b;b=c[h+12>>2]|0;j=c[h+4>>2]|0;k=c[h>>2]|0;l=((ca(j-1|0,f)|0)>>>8)+1|0;j=l;if((e|0)!=0){k=k+l|0;j=(c[h+4>>2]|0)-l|0}l=d[211576+j|0]|0;j=j<<l;b=b+l|0;if((b|0)<0){m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+12|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}e=l-b|0;if((k<<e-1&-2147483648|0)!=0){f=(c[h+16>>2]|0)-1|0;while(1){if((f|0)>=0){y=(d[(c[h+20>>2]|0)+f|0]|0|0)==255}else{y=0}if(!y){break}a[(c[h+20>>2]|0)+f|0]=0;f=f-1|0}y=(c[h+20>>2]|0)+f|0;a[y]=(d[y]|0)+1}y=h+16|0;f=c[y>>2]|0;c[y>>2]=f+1;a[(c[h+20>>2]|0)+f|0]=k>>>((24-e|0)>>>0);k=k<<e;l=b;k=k&16777215;b=b-8|0;m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+12|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}function Goc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=a;a=b;b=c-1|0;while(1){if((b|0)<0){break}Ioc(e,1&a>>b);b=b-1|0}i=d;return}function Hoc(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=a;a=b;if((a|0)<65){Goc(d,a,7);i=c;return}else{Goc(d,(a-65>>1)+65|0,7);Goc(d,a-65&1,1);i=c;return}}function Ioc(a,b){a=a|0;b=b|0;var c=0;c=i;Foc(a,b,128);i=c;return}function Joc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;do{if((d|0)>(a<<1|0)){e=d}else{if((d|0)>=(a|0)){e=d-a<<1;break}else{e=(a-d<<1)-1|0;break}}}while(0);i=c;return e|0}function Koc(a){a=a|0;var b=0;b=a;i=i;return(((c[b+4>>2]|0)>>>0)/8|0)+((((c[b+4>>2]|0)>>>0)%8|0)>>>0>0>>>0)|0}function Loc(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=b;b=e;e=c[g+4>>2]|0;h=(e|0)/8|0;j=7-((e|0)%8|0)|0;if((j|0)==7){a[(c[g>>2]|0)+h|0]=b<<j;k=e;l=k+1|0;m=g;n=m+4|0;c[n>>2]=l;i=f;return}else{o=(c[g>>2]|0)+h|0;a[o]=(d[o]|0)&~(1<<j);o=(c[g>>2]|0)+h|0;a[o]=d[o]|0|b<<j;k=e;l=k+1|0;m=g;n=m+4|0;c[n>>2]=l;i=f;return}}function Moc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=a;a=b;b=c-1|0;while(1){if((b|0)<0){break}Loc(e,a>>b&1);b=b-1|0}i=d;return}function Noc(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;c[e>>2]=0;c[e+4>>2]=255;c[e+8>>2]=0;c[e+12>>2]=-24;c[e+20>>2]=b;c[e+16>>2]=0;Ooc(e,0);i=d;return}function Ooc(a,b){a=a|0;b=b|0;var c=0;c=i;Qoc(a,b,128);i=c;return}function Poc(b){b=b|0;var d=0,e=0,f=0;d=i;e=b;b=0;while(1){if((b|0)>=32){break}Ooc(e,0);b=b+1|0}if((a[(c[e+20>>2]|0)+((c[e+16>>2]|0)-1)|0]&224|0)!=192){i=d;return}b=e+16|0;f=c[b>>2]|0;c[b>>2]=f+1;a[(c[e+20>>2]|0)+f|0]=0;i=d;return}function Qoc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=b;b=c[h+12>>2]|0;j=c[h+4>>2]|0;k=c[h>>2]|0;l=((ca(j-1|0,f)|0)>>>8)+1|0;j=l;if((e|0)!=0){k=k+l|0;j=(c[h+4>>2]|0)-l|0}l=d[211576+j|0]|0;j=j<<l;b=b+l|0;if((b|0)<0){m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+12|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}e=l-b|0;if((k<<e-1&-2147483648|0)!=0){f=(c[h+16>>2]|0)-1|0;while(1){if((f|0)>=0){y=(d[(c[h+20>>2]|0)+f|0]|0|0)==255}else{y=0}if(!y){break}a[(c[h+20>>2]|0)+f|0]=0;f=f-1|0}y=(c[h+20>>2]|0)+f|0;a[y]=(d[y]|0)+1}y=h+16|0;f=c[y>>2]|0;c[y>>2]=f+1;a[(c[h+20>>2]|0)+f|0]=k>>>((24-e|0)>>>0);k=k<<e;l=b;k=k&16777215;b=b-8|0;m=l;n=k;o=n<<m;k=o;p=b;q=h;r=q+12|0;c[r>>2]=p;s=k;t=h;u=t|0;c[u>>2]=s;v=j;w=h;x=w+4|0;c[x>>2]=v;i=g;return}function Roc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=c;c=e;e=b;b=0;while(1){if(!(b>>>0<g>>>0)){break}h=d[e+1|0]|0;j=d[e+2|0]|0;k=d[e+3|0]|0;l=d[e+4|0]|0;a[c|0]=d[e|0]|0;a[c+1|0]=((h*192|0)+(j<<6)+128|0)>>>8;a[c+2|0]=((j<<7)+(k<<7)+128|0)>>>8;a[c+3|0]=((k<<6)+(l*192|0)+128|0)>>>8;e=e+5|0;c=c+4|0;b=b+5|0}i=f;return}function Soc(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=c;c=f;f=g;g=e;e=b;b=0;while(1){if(!(b>>>0<f>>>0)){break}k=d[e+j|0]|0;l=d[e+(j<<1)|0]|0;m=d[e+(j*3|0)|0]|0;n=d[e+(j<<2)|0]|0;a[g+0|0]=d[e+0|0]|0;a[g+c|0]=((k*192|0)+(l<<6)+128|0)>>>8;a[g+(c<<1)|0]=((l<<7)+(m<<7)+128|0)>>>8;a[g+(c*3|0)|0]=((m<<6)+(n*192|0)+128|0)>>>8;e=e+1|0;g=g+1|0;b=b+1|0}i=h;return}function Toc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;f=i;g=c;c=e;e=b;b=0;while(1){if(!(b>>>0<g>>>0)){break}h=d[e+1|0]|0;j=d[e+2|0]|0;k=d[e+3|0]|0;l=d[e+4|0]|0;a[c|0]=d[e|0]|0;a[c+1|0]=((h*85|0)+(j*171|0)+128|0)>>>8;a[c+2|0]=((k*171|0)+(l*85|0)+128|0)>>>8;e=e+5|0;c=c+3|0;b=b+5|0}i=f;return}function Uoc(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=c;c=f;f=g;g=e;e=b;b=0;while(1){if(!(b>>>0<f>>>0)){break}k=d[e+j|0]|0;l=d[e+(j<<1)|0]|0;m=d[e+(j*3|0)|0]|0;n=d[e+(j<<2)|0]|0;a[g+0|0]=d[e+0|0]|0;a[g+c|0]=((k*85|0)+(l*171|0)+128|0)>>>8;a[g+(c<<1)|0]=((m*171|0)+(n*85|0)+128|0)>>>8;e=e+1|0;g=g+1|0;b=b+1|0}i=h;return}function Voc(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0;f=i;g=c;c=e;e=b;b=0;while(1){if(!(b>>>0<g>>>0)){break}a[c|0]=d[e|0]|0;e=e+2|0;c=c+1|0;b=b+2|0}i=f;return}function Woc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;d=i;nrc(c|0,a|0,e)|0;i=d;return}function Xoc(b,c,e,f,g){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;var h=0,j=0;f=i;h=b;b=c;c=e;e=g;g=0;while(1){if((g|0)>=(e|0)){break}j=8;j=j+((d[h+(g-b)|0]|0)*3|0)|0;j=j+((d[h+g|0]|0)*10|0)|0;j=j+((d[h+(g+b)|0]|0)*3|0)|0;j=j>>4;a[c+g|0]=j;g=g+1|0}i=f;return}function Yoc(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;e=i;f=a;a=d;d=c[f+4>>2]|0;g=c[f>>2]|0;f=0;while(1){if((f|0)>=16){break}b[d+(f<<1)>>1]=ca(b[g+(f<<1)>>1]|0,b[a+(f<<1)>>1]|0)|0;f=f+1|0}i=e;return}function Zoc(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=a;a=c;c=d;d=e;e=0;while(1){if((e|0)>=16){break}b[g+(e<<1)>>1]=ca(b[a+(e<<1)>>1]|0,b[g+(e<<1)>>1]|0)|0;e=e+1|0}c8b(g,c,d,c,d);mrc(g|0,0,32)|0;i=f;return}function _oc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=c[a+76>>2]|0;f=c[a+76>>2]|0;g=(c[a+76>>2]|0)+(c[a+4>>2]|0)-(c[e+4>>2]|0)|0;h=(c[a+76>>2]|0)+(c[a>>2]|0)-(c[e>>2]|0)|0;$oc(c[e+52>>2]|0,c[e+16>>2]|0,c[a+52>>2]|0,c[a+16>>2]|0,c[e+4>>2]|0,c[e>>2]|0,b,f,g,h);b=c[a+76>>2]>>1;f=c[a+76>>2]>>1;g=(c[a+76>>2]>>1)+(c[a+24>>2]|0)-(c[e+24>>2]|0)|0;h=(c[a+76>>2]>>1)+(c[a+20>>2]|0)-(c[e+20>>2]|0)|0;$oc(c[e+56>>2]|0,c[e+36>>2]|0,c[a+56>>2]|0,c[a+36>>2]|0,c[e+24>>2]|0,c[e+20>>2]|0,b,f,g,h);$oc(c[e+60>>2]|0,c[e+36>>2]|0,c[a+60>>2]|0,c[a+36>>2]|0,c[e+24>>2]|0,c[e+20>>2]|0,b,f,g,h);i=d;return}function $oc(b,c,d,e,f,g,h,j,k,l){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0;m=i;n=b;b=c;c=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=n;o=n+f-1|0;n=c+(-h|0)|0;p=c+f|0;q=0;while(1){if((q|0)>=(e|0)){break}mrc(n|0,a[l|0]&255|0,h|0)|0;nrc(n+h|0,l|0,f)|0;mrc(p|0,a[o|0]&255|0,k|0)|0;l=l+b|0;o=o+b|0;n=n+d|0;p=p+d|0;q=q+1|0}l=c+(-h|0)|0;o=c+(ca(d,e-1|0)|0)+(-h|0)|0;n=c+(ca(d,-g|0)|0)+(-h|0)|0;p=c+(ca(d,e)|0)+(-h|0)|0;e=h+k+f|0;q=0;while(1){if((q|0)>=(g|0)){break}nrc(n|0,l|0,e)|0;n=n+d|0;q=q+1|0}q=0;while(1){if((q|0)>=(j|0)){break}nrc(p|0,o|0,e)|0;p=p+d|0;q=q+1|0}i=m;return}function apc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;j=a;a=b;b=d;d=e;e=f;f=g;g=c[a+76>>2]|0;k=c[a+76>>2]|0;l=(c[a+76>>2]|0)+(c[a+4>>2]|0)-(c[j+4>>2]|0)|0;m=(c[a+76>>2]|0)+(c[a>>2]|0)-(c[j>>2]|0)|0;n=(ca(b,c[j+16>>2]|0)|0)+d|0;o=(ca(b,c[a+16>>2]|0)|0)+d|0;p=((ca(b,c[j+36>>2]|0)|0)>>1)+(d>>1)|0;q=((ca(b,c[a+36>>2]|0)|0)>>1)+(d>>1)|0;if((b|0)!=0){g=0}if((d|0)!=0){k=0}if((b+e|0)!=(c[j+4>>2]|0)){l=0}if((d+f|0)!=(c[j>>2]|0)){m=0}$oc((c[j+52>>2]|0)+n|0,c[j+16>>2]|0,(c[a+52>>2]|0)+o|0,c[a+16>>2]|0,e,f,g,k,l,m);g=g+1>>1;k=k+1>>1;l=l+1>>1;m=m+1>>1;e=e+1>>1;f=f+1>>1;$oc((c[j+56>>2]|0)+p|0,c[j+36>>2]|0,(c[a+56>>2]|0)+q|0,c[a+36>>2]|0,e,f,g,k,l,m);$oc((c[j+60>>2]|0)+p|0,c[j+36>>2]|0,(c[a+60>>2]|0)+q|0,c[a+36>>2]|0,e,f,g,k,l,m);i=h;return}function bpc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=b;b=d;d=e;e=f;b=b+((c[h+16>>2]|0)*14|0)|0;d=d+((c[h+36>>2]|0)*6|0)|0;e=e+((c[h+36>>2]|0)*6|0)|0;f=0;while(1){if((f|0)>=4){break}a[b+f|0]=a[b-1|0]|0;a[d+f|0]=a[d-1|0]|0;a[e+f|0]=a[e-1|0]|0;f=f+1|0}b=b+(c[h+16>>2]|0)|0;d=d+(c[h+36>>2]|0)|0;e=e+(c[h+36>>2]|0)|0;f=0;while(1){if((f|0)>=4){break}a[b+f|0]=a[b-1|0]|0;a[d+f|0]=a[d-1|0]|0;a[e+f|0]=a[e-1|0]|0;f=f+1|0}i=g;return}function cpc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;dpc(a,e,b,f,238360+(c*12|0)|0,238360+(d*12|0)|0);i=g;return}function dpc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+144|0;h=g|0;j=c;fpc(a+(-(j<<1)|0)|0,h|0,j,1,9,4,e);gpc(h+32|0,b,d,4,4,4,4,f);i=g;return}function epc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+832|0;h=g|0;j=b;fpc(a+(-(j<<1)|0)|0,h|0,j,1,13,8,238360+(c*12|0)|0);gpc(h+64|0,e,f,8,8,8,8,238360+(d*12|0)|0);i=g;return}function fpc(a,e,f,g,h,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0;l=i;m=a;a=e;e=f;f=g;g=h;h=j;j=k;k=0;while(1){if(!(k>>>0<g>>>0)){break}n=0;while(1){if(!(n>>>0<h>>>0)){break}o=ca(d[m+(f*-2|0)|0]|0,b[j>>1]|0)|0;p=o+(ca(d[m+(f*-1|0)|0]|0,b[j+2>>1]|0)|0)|0;o=p+(ca(d[m|0]|0,b[j+4>>1]|0)|0)|0;p=o+(ca(d[m+f|0]|0,b[j+6>>1]|0)|0)|0;o=p+(ca(d[m+(f<<1)|0]|0,b[j+8>>1]|0)|0)|0;p=o+(ca(d[m+(f*3|0)|0]|0,b[j+10>>1]|0)|0)+64|0;p=p>>7;if((p|0)<0){p=0}else{if((p|0)>255){p=255}}c[a+(n<<2)>>2]=p;m=m+1|0;n=n+1|0}m=m+(e-h)|0;a=a+(h<<2)|0;k=k+1|0}i=l;return}function gpc(d,e,f,g,h,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0;m=i;n=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=0;while(1){if(!(l>>>0<h>>>0)){break}o=0;while(1){if(!(o>>>0<j>>>0)){break}p=ca(c[n+((g*-2|0)<<2)>>2]|0,b[k>>1]|0)|0;q=p+(ca(c[n+((g*-1|0)<<2)>>2]|0,b[k+2>>1]|0)|0)|0;p=q+(ca(c[n>>2]|0,b[k+4>>1]|0)|0)|0;q=p+(ca(c[n+(g<<2)>>2]|0,b[k+6>>1]|0)|0)|0;p=q+(ca(c[n+(g<<1<<2)>>2]|0,b[k+8>>1]|0)|0)|0;q=p+(ca(c[n+((g*3|0)<<2)>>2]|0,b[k+10>>1]|0)|0)+64|0;q=q>>7;if((q|0)<0){q=0}else{if((q|0)>255){q=255}}a[d+o|0]=q;n=n+4|0;o=o+1|0}n=n+(f-j<<2)|0;d=d+e|0;l=l+1|0}i=m;return}function hpc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+832|0;h=g|0;j=b;fpc(a+(-(j<<1)|0)|0,h|0,j,1,9,8,238360+(c*12|0)|0);gpc(h+64|0,e,f,8,8,4,8,238360+(d*12|0)|0);i=g;return}function ipc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+2016|0;h=g|0;j=b;fpc(a+(-(j<<1)|0)|0,h|0,j,1,21,16,238360+(c*12|0)|0);gpc(h+128|0,e,f,16,16,16,16,238360+(d*12|0)|0);i=g;return}function jpc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;kpc(a,e,b,f,247912+(c<<2)|0,247912+(d<<2)|0,4,4);i=g;return}function kpc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0;j=i;i=i+544|0;k=j|0;l=g;g=h;opc(a,k|0,c,g+1|0,l,e);ppc(k|0,b,d,g,l,f);i=j;return}function lpc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;kpc(a,e,b,f,247912+(c<<2)|0,247912+(d<<2)|0,8,8);i=g;return}function mpc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;kpc(a,e,b,f,247912+(c<<2)|0,247912+(d<<2)|0,8,4);i=g;return}function npc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;kpc(a,e,b,f,247912+(c<<2)|0,247912+(d<<2)|0,16,16);i=g;return}function opc(a,c,e,f,g,h){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;k=a;a=c;c=e;e=f;f=g;g=h;h=0;while(1){if(!(h>>>0<e>>>0)){break}l=0;while(1){if(!(l>>>0<f>>>0)){break}m=ca(d[k|0]|0,b[g>>1]|0)|0;b[a+(l<<1)>>1]=m+(ca(d[k+1|0]|0,b[g+2>>1]|0)|0)+64>>7;k=k+1|0;l=l+1|0}k=k+(c-f)|0;a=a+(f<<1)|0;h=h+1|0}i=j;return}function ppc(c,d,f,g,h,j){c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0;k=i;l=c;c=d;d=f;f=g;g=h;h=j;j=0;while(1){if(!(j>>>0<f>>>0)){break}m=0;while(1){if(!(m>>>0<g>>>0)){break}n=ca(e[l>>1]|0,b[h>>1]|0)|0;a[c+m|0]=n+(ca(e[l+(g<<1)>>1]|0,b[h+2>>1]|0)|0)+64>>7;l=l+2|0;m=m+1|0}c=c+d|0;j=j+1|0}i=k;return}function qpc(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;j=c;c=d;d=e;e=f;f=g;g=0;while(1){if((g|0)>=4){break}k=0;while(1){if((k|0)>=4){break}l=f;f=l+1|0;if((a[l]|0)>1){Zoc(j,c,d,e)}else{d8b((ca(b[j>>1]|0,b[c>>1]|0)|0)&65535,d,e,d,e);mrc(j|0,0,4)|0}j=j+32|0;d=d+4|0;k=k+1|0}d=d+((e<<2)-16)|0;g=g+1|0}i=h;return}function rpc(c,d,e,f,g,h){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;k=c;c=d;d=e;e=f;f=g;g=h;h=0;while(1){if((h|0)>=2){break}l=0;while(1){if((l|0)>=2){break}m=g;g=m+1|0;if((a[m]|0)>1){Zoc(k,c,d,f)}else{d8b((ca(b[k>>1]|0,b[c>>1]|0)|0)&65535,d,f,d,f);mrc(k|0,0,4)|0}k=k+32|0;d=d+4|0;l=l+1|0}d=d+((f<<2)-8)|0;h=h+1|0}h=0;while(1){if((h|0)>=2){break}l=0;while(1){if((l|0)>=2){break}d=g;g=d+1|0;if((a[d]|0)>1){Zoc(k,c,e,f)}else{d8b((ca(b[k>>1]|0,b[c>>1]|0)|0)&65535,e,f,e,f);mrc(k|0,0,4)|0}k=k+32|0;e=e+4|0;l=l+1|0}e=e+((f<<2)-8)|0;h=h+1|0}i=j;return}function spc(b){b=b|0;var d=0,e=0,f=0;d=i;e=b;mrc((c[e+52>>2]|0)-1+(-(c[e+16>>2]|0)|0)|0,127,(c[e>>2]|0)+5|0)|0;b=0;while(1){if((b|0)>=(c[e+4>>2]|0)){break}f=(ca(c[e+16>>2]|0,b)|0)-1|0;a[(c[e+52>>2]|0)+f|0]=-127;b=b+1|0}mrc((c[e+56>>2]|0)-1+(-(c[e+36>>2]|0)|0)|0,127,(c[e+20>>2]|0)+5|0)|0;b=0;while(1){if((b|0)>=(c[e+24>>2]|0)){break}f=(ca(c[e+36>>2]|0,b)|0)-1|0;a[(c[e+56>>2]|0)+f|0]=-127;b=b+1|0}mrc((c[e+60>>2]|0)-1+(-(c[e+36>>2]|0)|0)|0,127,(c[e+20>>2]|0)+5|0)|0;b=0;while(1){if((b|0)>=(c[e+24>>2]|0)){break}f=(ca(c[e+36>>2]|0,b)|0)-1|0;a[(c[e+60>>2]|0)+f|0]=-127;b=b+1|0}i=d;return}function tpc(a){a=a|0;var b=0,d=0;b=i;d=a;mrc((c[d+52>>2]|0)-1+(-(c[d+16>>2]|0)|0)|0,127,(c[d>>2]|0)+5|0)|0;mrc((c[d+56>>2]|0)-1+(-(c[d+36>>2]|0)|0)|0,127,(c[d+20>>2]|0)+5|0)|0;mrc((c[d+60>>2]|0)-1+(-(c[d+36>>2]|0)|0)|0,127,(c[d+20>>2]|0)+5|0)|0;i=b;return}function upc(a,b){a=a|0;b=b|0;var d=0;d=a;a=b;b=c[a+68>>2]|0;c[a+68>>2]=c[d+68>>2];c[d+68>>2]=b;b=c[a+52>>2]|0;c[a+52>>2]=c[d+52>>2];c[d+52>>2]=b;b=c[a+56>>2]|0;c[a+56>>2]=c[d+56>>2];c[d+56>>2]=b;b=c[a+60>>2]|0;c[a+60>>2]=c[d+60>>2];c[d+60>>2]=b;i=i;return}function vpc(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0;l=i;m=b;b=f;f=g;g=j;j=k;k=m-1|0;n=0;wpc(m,d,e,f,h);do{h=f+(n<<3)|0;e=(c[h>>2]|0)+(c[h+4>>2]|0)|0;if((e|0)!=0){d=ca(c[h>>2]|0,g)|0;if((j|0)!=0){o=e>>>1}else{o=0}h=((d+o|0)>>>0)/(e>>>0)|0;if(h>>>0<256>>>0){if((h|0)!=0){p=h}else{p=1}q=p}else{q=255}a[b+n|0]=q}else{a[b+n|0]=-128}h=n+1|0;n=h;}while((h|0)<(k|0));i=l;return}function wpc(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;j=b;b=d;d=e;e=f;f=g;g=j-1|0;k=0;do{c[e+(k<<3)+4>>2]=0;c[e+(k<<3)>>2]=0;l=k+1|0;k=l;}while((l|0)<(g|0));k=0;do{g=c[b+(k<<3)+4>>2]|0;l=c[b+(k<<3)>>2]|0;m=c[f+(k<<2)>>2]|0;n=0;do{o=g-1|0;g=o;p=l>>o&1;o=e+(n<<24>>24>>1<<3)+(p<<2)|0;c[o>>2]=(c[o>>2]|0)+m;n=a[d+((n<<24>>24)+p)|0]|0;}while((n<<24>>24|0)>0);n=k+1|0;k=n;}while((n|0)<(j|0));i=h;return}function xpc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a;a=b;b=d;c[h>>2]=a+b;c[h+4>>2]=a;c[h+8>>2]=0;c[h+12>>2]=-8;c[h+16>>2]=255;c[h+20>>2]=e;c[h+24>>2]=f;do{if((b|0)!=0){if((a|0)!=0){break}j=1;k=j;i=g;return k|0}}while(0);ypc(h);j=0;k=j;i=g;return k|0}function ypc(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+8|0;e=b|0;f=a;a=c[f+4>>2]|0;g=c[f+8>>2]|0;h=c[f+12>>2]|0;j=24-(h+8)|0;k=(c[f>>2]|0)-a|0;l=k<<3;m=j+8-l|0;n=0;if((c[f+20>>2]|0)!=0){if(k>>>0>5>>>0){o=5}else{o=k}mf[c[f+20>>2]&2047](c[f+24>>2]|0,a,e|0,o);a=e|0}if((m|0)>=0){h=h+1073741824|0;n=m}do{if((m|0)>=0){if((l|0)!=0){break}p=g;q=f;r=q+8|0;c[r>>2]=p;s=h;t=f;u=t+12|0;c[u>>2]=s;i=b;return}}while(0);while(1){if((j|0)<(n|0)){break}h=h+8|0;g=g|(d[a]|0)<<j;a=a+1|0;l=f+4|0;c[l>>2]=(c[l>>2]|0)+1;j=j-8|0}p=g;q=f;r=q+8|0;c[r>>2]=p;s=h;t=f;u=t+12|0;c[u>>2]=s;i=b;return}function zpc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a;a=b;if((((c[e>>2]|0)+63&-64)-(c[e>>2]|0)|0)>16){f=((c[e>>2]|0)+63&-64)-(c[e>>2]|0)|0}else{f=16}b=f;if((((c[e+4>>2]|0)+63&-64)-(c[e+4>>2]|0)|0)>16){g=((c[e+4>>2]|0)+63&-64)-(c[e+4>>2]|0)|0}else{g=16}f=g;g=(c[e+20>>2]|0)!=(c[e>>2]|0)|0;h=(c[e+24>>2]|0)!=(c[e+4>>2]|0)|0;j=16>>h;k=16>>g;l=b>>h;h=f>>g;Apc(c[e+52>>2]|0,c[e+16>>2]|0,c[a+52>>2]|0,c[a+16>>2]|0,c[e>>2]|0,c[e+4>>2]|0,16,16,b,f);Apc(c[e+56>>2]|0,c[e+36>>2]|0,c[a+56>>2]|0,c[a+36>>2]|0,c[e+20>>2]|0,c[e+24>>2]|0,j,k,l,h);Apc(c[e+60>>2]|0,c[e+36>>2]|0,c[a+60>>2]|0,c[a+36>>2]|0,c[e+20>>2]|0,c[e+24>>2]|0,j,k,l,h);i=d;return}function Apc(b,c,d,e,f,g,h,j,k,l){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0;m=i;n=b;b=c;c=d;d=e;e=f;f=g;g=h;h=j;j=k;k=l;l=n;o=n+e-1|0;n=c+(-h|0)|0;p=c+e|0;q=0;while(1){if((q|0)>=(f|0)){break}mrc(n|0,a[l|0]&255|0,h|0)|0;nrc(n+h|0,l|0,e)|0;mrc(p|0,a[o|0]&255|0,k|0)|0;l=l+b|0;o=o+b|0;n=n+d|0;p=p+d|0;q=q+1|0}l=c+(-h|0)|0;o=c+(ca(d,f-1|0)|0)+(-h|0)|0;n=c+(ca(d,-g|0)|0)+(-h|0)|0;p=c+(ca(d,f)|0)+(-h|0)|0;f=h+k+e|0;q=0;while(1){if((q|0)>=(g|0)){break}nrc(n|0,l|0,f)|0;n=n+d|0;q=q+1|0}q=0;while(1){if((q|0)>=(j|0)){break}nrc(p|0,o|0,f)|0;p=p+d|0;q=q+1|0}i=m;return}function Bpc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+56|0;h=g|0;j=b;c[h>>2]=d;c[h+4>>2]=e;c[h+12>>2]=a;c[h+16>>2]=c[j>>2];if((c[h+16>>2]|0)!=(c[j>>2]|0)){k=-5;l=k;i=g;return l|0}c[h+32>>2]=0;c[h+36>>2]=0;c[h+40>>2]=0;a=Gpc(h,f,2258400,56)|0;if((a|0)!=0){k=a;l=k;i=g;return l|0}a=Lpc(h,4)|0;if((a|0)==1){c[j>>2]=c[h+20>>2];a=Ipc(h)|0;k=a;l=k;i=g;return l|0}Ipc(h)|0;if((a|0)==0){m=-5}else{m=a}k=m;l=k;i=g;return l|0}function Cpc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=Bpc(a,b,c,d,-1)|0;i=e;return f|0}function Dpc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=b;b=d;d=e;do{if((b|0)==0){j=0}else{c[g>>2]=1;if((a[g]|0)!=0){j=Epc(h,b,d)|0;break}else{j=Fpc(h,b,d)|0;break}}}while(0);i=f;return j|0}function Epc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=b;b=e;e=a;e=~e;while(1){if((b|0)!=0){h=(g&3|0)!=0}else{h=0}if(!h){break}a=g;g=a+1|0;e=c[1626104+(((e^(d[a]|0))&255)<<2)>>2]^e>>>8;b=b-1|0}h=g;while(1){if(!(b>>>0>=32>>>0)){break}a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];b=b-32|0}while(1){if(!(b>>>0>=4>>>0)){break}a=h;h=a+4|0;e=e^c[a>>2];e=c[1629176+((e&255)<<2)>>2]^c[1628152+((e>>>8&255)<<2)>>2]^c[1627128+((e>>>16&255)<<2)>>2]^c[1626104+(e>>>24<<2)>>2];b=b-4|0}g=h;if((b|0)==0){j=e;k=~j;e=k;l=e;i=f;return l|0}do{h=g;g=h+1|0;e=c[1626104+(((e^(d[h]|0))&255)<<2)>>2]^e>>>8;h=b-1|0;b=h;}while((h|0)!=0);j=e;k=~j;e=k;l=e;i=f;return l|0}function Fpc(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;g=a;a=b;b=e;e=(g>>>24&255)+(g>>>8&65280)+((g&65280)<<8)+((g&255)<<24)|0;e=~e;while(1){if((b|0)!=0){h=(a&3|0)!=0}else{h=0}if(!h){break}g=a;a=g+1|0;e=c[1630200+((e>>>24^(d[g]|0))<<2)>>2]^e<<8;b=b-1|0}h=a;h=h-4|0;while(1){if(!(b>>>0>=32>>>0)){break}g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];b=b-32|0}while(1){if(!(b>>>0>=4>>>0)){break}g=h+4|0;h=g;e=e^c[g>>2];e=c[1630200+((e&255)<<2)>>2]^c[1631224+((e>>>8&255)<<2)>>2]^c[1632248+((e>>>16&255)<<2)>>2]^c[1633272+(e>>>24<<2)>>2];b=b-4|0}h=h+4|0;a=h;if((b|0)==0){j=e;k=~j;e=k;l=e;m=l>>>24;n=m&255;o=e;p=o>>>8;q=p&65280;r=n+q|0;s=e;t=s&65280;u=t<<8;v=r+u|0;w=e;x=w&255;y=x<<24;z=v+y|0;i=f;return z|0}do{h=a;a=h+1|0;e=c[1630200+((e>>>24^(d[h]|0))<<2)>>2]^e<<8;h=b-1|0;b=h;}while((h|0)!=0);j=e;k=~j;e=k;l=e;m=l>>>24;n=m&255;o=e;p=o>>>8;q=p&65280;r=n+q|0;s=e;t=s&65280;u=t<<8;v=r+u|0;w=e;x=w&255;y=x<<24;z=v+y|0;i=f;return z|0}function Gpc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;f=Hpc(a,b,8,15,8,0,c,d)|0;i=e;return f|0}function Hpc(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0;l=i;m=b;b=d;d=e;e=f;f=g;g=h;h=j;j=k;k=1;do{if((h|0)!=0){if((a[h|0]|0)!=(a[1567728]|0)){break}if((j|0)!=56){break}if((m|0)==0){n=-2;o=n;i=l;return o|0}c[m+24>>2]=0;if((c[m+32>>2]|0)==0){c[m+32>>2]=154;c[m+40>>2]=0}if((c[m+36>>2]|0)==0){c[m+36>>2]=432}if((b|0)==-1){b=6}if((e|0)<0){k=0;e=-e|0}else{if((e|0)>15){k=2;e=e-16|0}}do{if((f|0)>=1){if((f|0)>9){break}if((d|0)!=8){break}if((e|0)<8){break}if((e|0)>15){break}if((b|0)<0){break}if((b|0)>9){break}if((g|0)<0){break}if((g|0)>4){break}if((e|0)==8){e=9}p=Ee[c[m+32>>2]&511](c[m+40>>2]|0,1,5828)|0;if((p|0)==0){n=-4;o=n;i=l;return o|0}c[m+28>>2]=p;c[p>>2]=m;c[p+24>>2]=k;c[p+28>>2]=0;c[p+48>>2]=e;c[p+44>>2]=1<<c[p+48>>2];c[p+52>>2]=(c[p+44>>2]|0)-1;c[p+80>>2]=f+7;c[p+76>>2]=1<<c[p+80>>2];c[p+84>>2]=(c[p+76>>2]|0)-1;c[p+88>>2]=(((c[p+80>>2]|0)+3-1|0)>>>0)/3|0;c[p+56>>2]=Ee[c[m+32>>2]&511](c[m+40>>2]|0,c[p+44>>2]|0,2)|0;c[p+64>>2]=Ee[c[m+32>>2]&511](c[m+40>>2]|0,c[p+44>>2]|0,2)|0;mrc(c[p+64>>2]|0,0,c[p+44>>2]<<1|0)|0;c[p+68>>2]=Ee[c[m+32>>2]&511](c[m+40>>2]|0,c[p+76>>2]|0,2)|0;c[p+5824>>2]=0;c[p+5788>>2]=1<<f+6;q=Ee[c[m+32>>2]&511](c[m+40>>2]|0,c[p+5788>>2]|0,4)|0;c[p+8>>2]=q;c[p+12>>2]=c[p+5788>>2]<<2;do{if((c[p+56>>2]|0)!=0){if((c[p+64>>2]|0)==0){break}if((c[p+68>>2]|0)==0){break}if((c[p+8>>2]|0)==0){break}c[p+5796>>2]=q+((((c[p+5788>>2]|0)>>>0)/2|0)<<1);c[p+5784>>2]=(c[p+8>>2]|0)+((c[p+5788>>2]|0)*3|0);c[p+132>>2]=b;c[p+136>>2]=g;a[p+36|0]=d;n=Jpc(m)|0;o=n;i=l;return o|0}}while(0);c[p+4>>2]=666;c[m+24>>2]=c[176];Ipc(m)|0;n=-4;o=n;i=l;return o|0}}while(0);n=-2;o=n;i=l;return o|0}}while(0);n=-6;o=n;i=l;return o|0}function Ipc(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;do{if((d|0)!=0){if((c[d+28>>2]|0)==0){break}a=c[(c[d+28>>2]|0)+4>>2]|0;do{if((a|0)!=42){if((a|0)==69){break}if((a|0)==73){break}if((a|0)==91){break}if((a|0)==103){break}if((a|0)==113){break}if((a|0)==666){break}e=-2;f=e;i=b;return f|0}}while(0);if((c[(c[d+28>>2]|0)+8>>2]|0)!=0){re[c[d+36>>2]&1023](c[d+40>>2]|0,c[(c[d+28>>2]|0)+8>>2]|0)}if((c[(c[d+28>>2]|0)+68>>2]|0)!=0){re[c[d+36>>2]&1023](c[d+40>>2]|0,c[(c[d+28>>2]|0)+68>>2]|0)}if((c[(c[d+28>>2]|0)+64>>2]|0)!=0){re[c[d+36>>2]&1023](c[d+40>>2]|0,c[(c[d+28>>2]|0)+64>>2]|0)}if((c[(c[d+28>>2]|0)+56>>2]|0)!=0){re[c[d+36>>2]&1023](c[d+40>>2]|0,c[(c[d+28>>2]|0)+56>>2]|0)}re[c[d+36>>2]&1023](c[d+40>>2]|0,c[d+28>>2]|0);c[d+28>>2]=0;e=(a|0)==113?-3:0;f=e;i=b;return f|0}}while(0);e=-2;f=e;i=b;return f|0}function Jpc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;do{if((d|0)!=0){if((c[d+28>>2]|0)==0){break}if((c[d+32>>2]|0)==0){break}if((c[d+36>>2]|0)==0){break}c[d+20>>2]=0;c[d+8>>2]=0;c[d+24>>2]=0;c[d+44>>2]=2;a=c[d+28>>2]|0;c[a+20>>2]=0;c[a+16>>2]=c[a+8>>2];if((c[a+24>>2]|0)<0){c[a+24>>2]=-(c[a+24>>2]|0)}c[a+4>>2]=(c[a+24>>2]|0)!=0?42:113;if((c[a+24>>2]|0)==2){e=Dpc(0,0,0)|0}else{e=Dqc(0,0,0)|0}c[d+48>>2]=e;c[a+40>>2]=0;gqc(a);Kpc(a);f=0;g=f;i=b;return g|0}}while(0);f=-2;g=f;i=b;return g|0}function Kpc(a){a=a|0;var d=0,f=0;d=i;f=a;c[f+60>>2]=c[f+44>>2]<<1;b[(c[f+68>>2]|0)+((c[f+76>>2]|0)-1<<1)>>1]=0;mrc(c[f+68>>2]|0,0,(c[f+76>>2]|0)-1<<1|0)|0;c[f+128>>2]=e[1637946+((c[f+132>>2]|0)*12|0)>>1]|0;c[f+140>>2]=e[1637944+((c[f+132>>2]|0)*12|0)>>1]|0;c[f+144>>2]=e[1637948+((c[f+132>>2]|0)*12|0)>>1]|0;c[f+124>>2]=e[1637950+((c[f+132>>2]|0)*12|0)>>1]|0;c[f+108>>2]=0;c[f+92>>2]=0;c[f+116>>2]=0;c[f+120>>2]=2;c[f+96>>2]=2;c[f+112>>2]=0;c[f+104>>2]=0;c[f+72>>2]=0;i=d;return}function Lpc(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;h=e;e=f;do{if((h|0)!=0){if((c[h+28>>2]|0)==0){break}if((e|0)>5){break}if((e|0)<0){break}f=c[h+28>>2]|0;do{if((c[h+12>>2]|0)!=0){if((c[h>>2]|0)==0){if((c[h+4>>2]|0)!=0){break}}if((c[f+4>>2]|0)==666){if((e|0)!=4){break}}if((c[h+16>>2]|0)==0){c[h+24>>2]=c[177];j=-5;k=j;i=g;return k|0}c[f>>2]=h;l=c[f+40>>2]|0;c[f+40>>2]=e;if((c[f+4>>2]|0)==42){if((c[f+24>>2]|0)==2){c[h+48>>2]=Dpc(0,0,0)|0;m=f+20|0;n=c[m>>2]|0;c[m>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=31;n=f+20|0;m=c[n>>2]|0;c[n>>2]=m+1;a[(c[f+8>>2]|0)+m|0]=-117;m=f+20|0;n=c[m>>2]|0;c[m>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=8;if((c[f+28>>2]|0)==0){n=f+20|0;m=c[n>>2]|0;c[n>>2]=m+1;a[(c[f+8>>2]|0)+m|0]=0;m=f+20|0;n=c[m>>2]|0;c[m>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=0;n=f+20|0;m=c[n>>2]|0;c[n>>2]=m+1;a[(c[f+8>>2]|0)+m|0]=0;m=f+20|0;n=c[m>>2]|0;c[m>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=0;n=f+20|0;m=c[n>>2]|0;c[n>>2]=m+1;a[(c[f+8>>2]|0)+m|0]=0;if((c[f+132>>2]|0)==9){o=2}else{if((c[f+136>>2]|0)>=2){p=1}else{p=(c[f+132>>2]|0)<2}o=p?4:0}m=f+20|0;n=c[m>>2]|0;c[m>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=o;n=f+20|0;m=c[n>>2]|0;c[n>>2]=m+1;a[(c[f+8>>2]|0)+m|0]=3;c[f+4>>2]=113}else{m=((c[c[f+28>>2]>>2]|0)!=0?1:0)+((c[(c[f+28>>2]|0)+44>>2]|0)!=0?2:0)+((c[(c[f+28>>2]|0)+16>>2]|0)==0?0:4)+((c[(c[f+28>>2]|0)+28>>2]|0)==0?0:8)+((c[(c[f+28>>2]|0)+36>>2]|0)==0?0:16)&255;n=f+20|0;q=c[n>>2]|0;c[n>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=m;m=c[(c[f+28>>2]|0)+4>>2]&255;q=f+20|0;n=c[q>>2]|0;c[q>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=m;m=(c[(c[f+28>>2]|0)+4>>2]|0)>>>8&255;n=f+20|0;q=c[n>>2]|0;c[n>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=m;m=(c[(c[f+28>>2]|0)+4>>2]|0)>>>16&255;q=f+20|0;n=c[q>>2]|0;c[q>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=m;m=(c[(c[f+28>>2]|0)+4>>2]|0)>>>24&255;n=f+20|0;q=c[n>>2]|0;c[n>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=m;if((c[f+132>>2]|0)==9){r=2}else{if((c[f+136>>2]|0)>=2){s=1}else{s=(c[f+132>>2]|0)<2}r=s?4:0}m=f+20|0;q=c[m>>2]|0;c[m>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=r;q=c[(c[f+28>>2]|0)+12>>2]&255;m=f+20|0;n=c[m>>2]|0;c[m>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=q;if((c[(c[f+28>>2]|0)+16>>2]|0)!=0){q=c[(c[f+28>>2]|0)+20>>2]&255;n=f+20|0;m=c[n>>2]|0;c[n>>2]=m+1;a[(c[f+8>>2]|0)+m|0]=q;q=(c[(c[f+28>>2]|0)+20>>2]|0)>>>8&255;m=f+20|0;n=c[m>>2]|0;c[m>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=q}if((c[(c[f+28>>2]|0)+44>>2]|0)!=0){c[h+48>>2]=Dpc(c[h+48>>2]|0,c[f+8>>2]|0,c[f+20>>2]|0)|0}c[f+32>>2]=0;c[f+4>>2]=69}}else{q=((c[f+48>>2]|0)-8<<4)+8<<8;do{if((c[f+136>>2]|0)>=2){t=36}else{if((c[f+132>>2]|0)<2){t=36;break}if((c[f+132>>2]|0)<6){u=1}else{if((c[f+132>>2]|0)==6){u=2}else{u=3}}}}while(0);if((t|0)==36){u=0}q=q|u<<6;if((c[f+108>>2]|0)!=0){q=q|32}q=q+(31-((q>>>0)%31|0))|0;c[f+4>>2]=113;Npc(f,q);if((c[f+108>>2]|0)!=0){Npc(f,(c[h+48>>2]|0)>>>16);Npc(f,c[h+48>>2]&65535)}c[h+48>>2]=Dqc(0,0,0)|0}}if((c[f+4>>2]|0)==69){if((c[(c[f+28>>2]|0)+16>>2]|0)!=0){n=c[f+20>>2]|0;while(1){if(!((c[f+32>>2]|0)>>>0<(c[(c[f+28>>2]|0)+20>>2]&65535)>>>0)){break}if((c[f+20>>2]|0)==(c[f+12>>2]|0)){do{if((c[(c[f+28>>2]|0)+44>>2]|0)!=0){if(!((c[f+20>>2]|0)>>>0>n>>>0)){break}c[h+48>>2]=Dpc(c[h+48>>2]|0,(c[f+8>>2]|0)+n|0,(c[f+20>>2]|0)-n|0)|0}}while(0);Opc(h);n=c[f+20>>2]|0;if((c[f+20>>2]|0)==(c[f+12>>2]|0)){t=59;break}}m=a[(c[(c[f+28>>2]|0)+16>>2]|0)+(c[f+32>>2]|0)|0]|0;v=f+20|0;w=c[v>>2]|0;c[v>>2]=w+1;a[(c[f+8>>2]|0)+w|0]=m;m=f+32|0;c[m>>2]=(c[m>>2]|0)+1}do{if((c[(c[f+28>>2]|0)+44>>2]|0)!=0){if(!((c[f+20>>2]|0)>>>0>n>>>0)){break}c[h+48>>2]=Dpc(c[h+48>>2]|0,(c[f+8>>2]|0)+n|0,(c[f+20>>2]|0)-n|0)|0}}while(0);if((c[f+32>>2]|0)==(c[(c[f+28>>2]|0)+20>>2]|0)){c[f+32>>2]=0;c[f+4>>2]=73}}else{c[f+4>>2]=73}}if((c[f+4>>2]|0)==73){if((c[(c[f+28>>2]|0)+28>>2]|0)!=0){n=c[f+20>>2]|0;do{if((c[f+20>>2]|0)==(c[f+12>>2]|0)){do{if((c[(c[f+28>>2]|0)+44>>2]|0)!=0){if(!((c[f+20>>2]|0)>>>0>n>>>0)){break}c[h+48>>2]=Dpc(c[h+48>>2]|0,(c[f+8>>2]|0)+n|0,(c[f+20>>2]|0)-n|0)|0}}while(0);Opc(h);n=c[f+20>>2]|0;if((c[f+20>>2]|0)==(c[f+12>>2]|0)){t=78;break}}q=f+32|0;m=c[q>>2]|0;c[q>>2]=m+1;x=d[(c[(c[f+28>>2]|0)+28>>2]|0)+m|0]|0;m=f+20|0;q=c[m>>2]|0;c[m>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=x;}while((x|0)!=0);if((t|0)==78){x=1}do{if((c[(c[f+28>>2]|0)+44>>2]|0)!=0){if(!((c[f+20>>2]|0)>>>0>n>>>0)){break}c[h+48>>2]=Dpc(c[h+48>>2]|0,(c[f+8>>2]|0)+n|0,(c[f+20>>2]|0)-n|0)|0}}while(0);if((x|0)==0){c[f+32>>2]=0;c[f+4>>2]=91}}else{c[f+4>>2]=91}}if((c[f+4>>2]|0)==91){if((c[(c[f+28>>2]|0)+36>>2]|0)!=0){n=c[f+20>>2]|0;do{if((c[f+20>>2]|0)==(c[f+12>>2]|0)){do{if((c[(c[f+28>>2]|0)+44>>2]|0)!=0){if(!((c[f+20>>2]|0)>>>0>n>>>0)){break}c[h+48>>2]=Dpc(c[h+48>>2]|0,(c[f+8>>2]|0)+n|0,(c[f+20>>2]|0)-n|0)|0}}while(0);Opc(h);n=c[f+20>>2]|0;if((c[f+20>>2]|0)==(c[f+12>>2]|0)){t=98;break}}q=f+32|0;m=c[q>>2]|0;c[q>>2]=m+1;y=d[(c[(c[f+28>>2]|0)+36>>2]|0)+m|0]|0;m=f+20|0;q=c[m>>2]|0;c[m>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=y;}while((y|0)!=0);if((t|0)==98){y=1}do{if((c[(c[f+28>>2]|0)+44>>2]|0)!=0){if(!((c[f+20>>2]|0)>>>0>n>>>0)){break}c[h+48>>2]=Dpc(c[h+48>>2]|0,(c[f+8>>2]|0)+n|0,(c[f+20>>2]|0)-n|0)|0}}while(0);if((y|0)==0){c[f+4>>2]=103}}else{c[f+4>>2]=103}}if((c[f+4>>2]|0)==103){if((c[(c[f+28>>2]|0)+44>>2]|0)!=0){if(((c[f+20>>2]|0)+2|0)>>>0>(c[f+12>>2]|0)>>>0){Opc(h)}if(((c[f+20>>2]|0)+2|0)>>>0<=(c[f+12>>2]|0)>>>0){n=c[h+48>>2]&255;q=f+20|0;m=c[q>>2]|0;c[q>>2]=m+1;a[(c[f+8>>2]|0)+m|0]=n;n=(c[h+48>>2]|0)>>>8&255;m=f+20|0;q=c[m>>2]|0;c[m>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=n;c[h+48>>2]=Dpc(0,0,0)|0;c[f+4>>2]=113}}else{c[f+4>>2]=113}}do{if((c[f+20>>2]|0)!=0){Opc(h);if((c[h+16>>2]|0)!=0){break}c[f+40>>2]=-1;j=0;k=j;i=g;return k|0}else{do{if((c[h+4>>2]|0)==0){if((e|0)>(l|0)){break}if((e|0)==4){break}c[h+24>>2]=c[177];j=-5;k=j;i=g;return k|0}}while(0)}}while(0);do{if((c[f+4>>2]|0)==666){if((c[h+4>>2]|0)==0){break}c[h+24>>2]=c[177];j=-5;k=j;i=g;return k|0}}while(0);do{if((c[h+4>>2]|0)!=0){t=135}else{if((c[f+116>>2]|0)!=0){t=135;break}if((e|0)==0){break}if((c[f+4>>2]|0)!=666){t=135}}}while(0);a:do{if((t|0)==135){if((c[f+136>>2]|0)==2){z=Ppc(f,e)|0}else{if((c[f+136>>2]|0)==3){A=Qpc(f,e)|0}else{A=We[c[1637952+((c[f+132>>2]|0)*12|0)>>2]&2047](f,e)|0}z=A}l=z;if((l|0)==2){t=143}else{if((l|0)==3){t=143}}if((t|0)==143){c[f+4>>2]=666}do{if((l|0)!=0){if((l|0)==2){break}do{if((l|0)==1){if((e|0)==1){lqc(f)}else{if((e|0)!=5){jqc(f,0,0,0);if((e|0)==3){b[(c[f+68>>2]|0)+((c[f+76>>2]|0)-1<<1)>>1]=0;mrc(c[f+68>>2]|0,0,(c[f+76>>2]|0)-1<<1|0)|0;if((c[f+116>>2]|0)==0){c[f+108>>2]=0;c[f+92>>2]=0}}}}Opc(h);if((c[h+16>>2]|0)!=0){break}c[f+40>>2]=-1;j=0;k=j;i=g;return k|0}}while(0);break a}}while(0);if((c[h+16>>2]|0)==0){c[f+40>>2]=-1}j=0;k=j;i=g;return k|0}}while(0);if((e|0)!=4){j=0;k=j;i=g;return k|0}if((c[f+24>>2]|0)<=0){j=1;k=j;i=g;return k|0}if((c[f+24>>2]|0)==2){l=c[h+48>>2]&255;n=f+20|0;q=c[n>>2]|0;c[n>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=l;l=(c[h+48>>2]|0)>>>8&255;q=f+20|0;n=c[q>>2]|0;c[q>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=l;l=(c[h+48>>2]|0)>>>16&255;n=f+20|0;q=c[n>>2]|0;c[n>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=l;l=(c[h+48>>2]|0)>>>24&255;q=f+20|0;n=c[q>>2]|0;c[q>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=l;l=c[h+8>>2]&255;n=f+20|0;q=c[n>>2]|0;c[n>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=l;l=(c[h+8>>2]|0)>>>8&255;q=f+20|0;n=c[q>>2]|0;c[q>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=l;l=(c[h+8>>2]|0)>>>16&255;n=f+20|0;q=c[n>>2]|0;c[n>>2]=q+1;a[(c[f+8>>2]|0)+q|0]=l;l=(c[h+8>>2]|0)>>>24&255;q=f+20|0;n=c[q>>2]|0;c[q>>2]=n+1;a[(c[f+8>>2]|0)+n|0]=l}else{Npc(f,(c[h+48>>2]|0)>>>16);Npc(f,c[h+48>>2]&65535)}Opc(h);if((c[f+24>>2]|0)>0){c[f+24>>2]=-(c[f+24>>2]|0)}j=(c[f+20>>2]|0)!=0?0:1;k=j;i=g;return k|0}}while(0);c[h+24>>2]=c[174];j=-2;k=j;i=g;return k|0}}while(0);j=-2;k=j;i=g;return k|0}function Mpc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=b;b=d;d=b+((b+7|0)>>>3)+((b+63|0)>>>6)+5|0;do{if((f|0)!=0){if((c[f+28>>2]|0)==0){break}g=c[f+28>>2]|0;h=c[g+24>>2]|0;if((h|0)==2){j=18;if((c[g+28>>2]|0)!=0){if((c[(c[g+28>>2]|0)+16>>2]|0)!=0){j=j+((c[(c[g+28>>2]|0)+20>>2]|0)+2)|0}k=c[(c[g+28>>2]|0)+28>>2]|0;if((k|0)!=0){do{j=j+1|0;l=k;k=l+1|0;}while((a[l]|0)!=0)}k=c[(c[g+28>>2]|0)+36>>2]|0;if((k|0)!=0){do{j=j+1|0;l=k;k=l+1|0;}while((a[l]|0)!=0)}if((c[(c[g+28>>2]|0)+44>>2]|0)!=0){j=j+2|0}}}else if((h|0)==1){j=((c[g+108>>2]|0)!=0?4:0)+6|0}else if((h|0)==0){j=0}else{j=6}do{if((c[g+48>>2]|0)==15){if((c[g+80>>2]|0)!=15){break}m=b+(b>>>12)+(b>>>14)+(b>>>25)+13-6+j|0;n=m;i=e;return n|0}}while(0);m=d+j|0;n=m;i=e;return n|0}}while(0);m=d+6|0;n=m;i=e;return n|0}function Npc(b,d){b=b|0;d=d|0;var e=0,f=0;e=b;b=d;d=e+20|0;f=c[d>>2]|0;c[d>>2]=f+1;a[(c[e+8>>2]|0)+f|0]=b>>>8;f=e+20|0;d=c[f>>2]|0;c[f>>2]=d+1;a[(c[e+8>>2]|0)+d|0]=b&255;i=i;return}function Opc(a){a=a|0;var b=0,d=0,e=0;b=i;d=a;a=c[(c[d+28>>2]|0)+20>>2]|0;if(a>>>0>(c[d+16>>2]|0)>>>0){a=c[d+16>>2]|0}if((a|0)==0){i=b;return}nrc(c[d+12>>2]|0,c[(c[d+28>>2]|0)+16>>2]|0,a)|0;e=d+12|0;c[e>>2]=(c[e>>2]|0)+a;e=(c[d+28>>2]|0)+16|0;c[e>>2]=(c[e>>2]|0)+a;e=d+20|0;c[e>>2]=(c[e>>2]|0)+a;e=d+16|0;c[e>>2]=(c[e>>2]|0)-a;e=(c[d+28>>2]|0)+20|0;c[e>>2]=(c[e>>2]|0)-a;if((c[(c[d+28>>2]|0)+20>>2]|0)!=0){i=b;return}c[(c[d+28>>2]|0)+16>>2]=c[(c[d+28>>2]|0)+8>>2];i=b;return}function Ppc(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=d;d=e;while(1){if((c[g+116>>2]|0)==0){Rpc(g);if((c[g+116>>2]|0)==0){break}}c[g+96>>2]=0;e=a[(c[g+56>>2]|0)+(c[g+108>>2]|0)|0]|0;b[(c[g+5796>>2]|0)+(c[g+5792>>2]<<1)>>1]=0;h=g+5792|0;j=c[h>>2]|0;c[h>>2]=j+1;a[(c[g+5784>>2]|0)+j|0]=e;j=g+148+((e&255)<<2)|0;b[j>>1]=(b[j>>1]|0)+1;j=(c[g+5792>>2]|0)==((c[g+5788>>2]|0)-1|0)|0;e=g+116|0;c[e>>2]=(c[e>>2]|0)-1;e=g+108|0;c[e>>2]=(c[e>>2]|0)+1;if((j|0)!=0){if((c[g+92>>2]|0)>=0){k=(c[g+56>>2]|0)+(c[g+92>>2]|0)|0}else{k=0}nqc(g,k,(c[g+108>>2]|0)-(c[g+92>>2]|0)|0,0);c[g+92>>2]=c[g+108>>2];Opc(c[g>>2]|0);if((c[(c[g>>2]|0)+16>>2]|0)==0){l=13;break}}}if((l|0)==13){m=0;n=m;i=f;return n|0}if((d|0)==0){m=0;n=m;i=f;return n|0}if((c[g+92>>2]|0)>=0){o=(c[g+56>>2]|0)+(c[g+92>>2]|0)|0}else{o=0}nqc(g,o,(c[g+108>>2]|0)-(c[g+92>>2]|0)|0,(d|0)==4|0);c[g+92>>2]=c[g+108>>2];Opc(c[g>>2]|0);if((c[(c[g>>2]|0)+16>>2]|0)==0){m=(d|0)==4?2:0;n=m;i=f;return n|0}else{m=(d|0)==4?3:1;n=m;i=f;return n|0}return 0}function Qpc(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=e;e=f;while(1){if((c[h+116>>2]|0)>>>0<258>>>0){Rpc(h);if((c[h+116>>2]|0)>>>0<258>>>0){if((e|0)==0){j=5;break}}if((c[h+116>>2]|0)==0){j=7;break}}c[h+96>>2]=0;do{if((c[h+116>>2]|0)>>>0>=3>>>0){if(!((c[h+108>>2]|0)>>>0>0>>>0)){break}f=(c[h+56>>2]|0)+(c[h+108>>2]|0)-1|0;k=d[f]|0;l=f+1|0;f=l;do{if((k|0)==(d[l]|0|0)){m=f+1|0;f=m;if((k|0)!=(d[m]|0|0)){break}m=f+1|0;f=m;if((k|0)!=(d[m]|0|0)){break}m=(c[h+56>>2]|0)+(c[h+108>>2]|0)+258|0;do{n=f+1|0;f=n;do{if((k|0)==(d[n]|0|0)){o=f+1|0;f=o;if((k|0)!=(d[o]|0|0)){p=0;break}o=f+1|0;f=o;if((k|0)!=(d[o]|0|0)){p=0;break}o=f+1|0;f=o;if((k|0)!=(d[o]|0|0)){p=0;break}o=f+1|0;f=o;if((k|0)!=(d[o]|0|0)){p=0;break}o=f+1|0;f=o;if((k|0)!=(d[o]|0|0)){p=0;break}o=f+1|0;f=o;if((k|0)!=(d[o]|0|0)){p=0;break}o=f+1|0;f=o;if((k|0)!=(d[o]|0|0)){p=0;break}p=f>>>0<m>>>0}else{p=0}}while(0)}while(p);c[h+96>>2]=258-(m-f);if((c[h+96>>2]|0)>>>0>(c[h+116>>2]|0)>>>0){c[h+96>>2]=c[h+116>>2]}}}while(0)}}while(0);if((c[h+96>>2]|0)>>>0>=3>>>0){f=(c[h+96>>2]|0)-3&255;k=1;b[(c[h+5796>>2]|0)+(c[h+5792>>2]<<1)>>1]=k;l=h+5792|0;n=c[l>>2]|0;c[l>>2]=n+1;a[(c[h+5784>>2]|0)+n|0]=f;k=k-1&65535;n=h+148+((d[2644672+(f&255)|0]|0)+257<<2)|0;b[n>>1]=(b[n>>1]|0)+1;if((k&65535|0)<256){q=d[2644928+(k&65535)|0]|0}else{q=d[((k&65535)>>7)+2645184|0]|0}k=h+2440+(q<<2)|0;b[k>>1]=(b[k>>1]|0)+1;r=(c[h+5792>>2]|0)==((c[h+5788>>2]|0)-1|0)|0;k=h+116|0;c[k>>2]=(c[k>>2]|0)-(c[h+96>>2]|0);k=h+108|0;c[k>>2]=(c[k>>2]|0)+(c[h+96>>2]|0);c[h+96>>2]=0}else{k=a[(c[h+56>>2]|0)+(c[h+108>>2]|0)|0]|0;b[(c[h+5796>>2]|0)+(c[h+5792>>2]<<1)>>1]=0;n=h+5792|0;f=c[n>>2]|0;c[n>>2]=f+1;a[(c[h+5784>>2]|0)+f|0]=k;f=h+148+((k&255)<<2)|0;b[f>>1]=(b[f>>1]|0)+1;r=(c[h+5792>>2]|0)==((c[h+5788>>2]|0)-1|0)|0;f=h+116|0;c[f>>2]=(c[f>>2]|0)-1;f=h+108|0;c[f>>2]=(c[f>>2]|0)+1}if((r|0)!=0){if((c[h+92>>2]|0)>=0){s=(c[h+56>>2]|0)+(c[h+92>>2]|0)|0}else{s=0}nqc(h,s,(c[h+108>>2]|0)-(c[h+92>>2]|0)|0,0);c[h+92>>2]=c[h+108>>2];Opc(c[h>>2]|0);if((c[(c[h>>2]|0)+16>>2]|0)==0){j=41;break}}}if((j|0)==5){t=0;u=t;i=g;return u|0}else if((j|0)==7){if((c[h+92>>2]|0)>=0){v=(c[h+56>>2]|0)+(c[h+92>>2]|0)|0}else{v=0}nqc(h,v,(c[h+108>>2]|0)-(c[h+92>>2]|0)|0,(e|0)==4|0);c[h+92>>2]=c[h+108>>2];Opc(c[h>>2]|0);if((c[(c[h>>2]|0)+16>>2]|0)==0){t=(e|0)==4?2:0;u=t;i=g;return u|0}else{t=(e|0)==4?3:1;u=t;i=g;return u|0}}else if((j|0)==41){t=0;u=t;i=g;return u|0}return 0}function Rpc(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=a;a=c[g+44>>2]|0;do{h=(c[g+60>>2]|0)-(c[g+116>>2]|0)-(c[g+108>>2]|0)|0;if((c[g+108>>2]|0)>>>0>=(a+((c[g+44>>2]|0)-262)|0)>>>0){nrc(c[g+56>>2]|0,(c[g+56>>2]|0)+a|0,a)|0;j=g+112|0;c[j>>2]=(c[j>>2]|0)-a;j=g+108|0;c[j>>2]=(c[j>>2]|0)-a;j=g+92|0;c[j>>2]=(c[j>>2]|0)-a;k=c[g+76>>2]|0;j=(c[g+68>>2]|0)+(k<<1)|0;do{l=j-2|0;j=l;m=e[l>>1]|0;if(m>>>0>=a>>>0){n=m-a|0}else{n=0}b[j>>1]=n;l=k-1|0;k=l;}while((l|0)!=0);k=a;j=(c[g+64>>2]|0)+(k<<1)|0;do{l=j-2|0;j=l;m=e[l>>1]|0;if(m>>>0>=a>>>0){o=m-a|0}else{o=0}b[j>>1]=o;l=k-1|0;k=l;}while((l|0)!=0);h=h+a|0}if((c[(c[g>>2]|0)+4>>2]|0)==0){p=17;break}k=Spc(c[g>>2]|0,(c[g+56>>2]|0)+(c[g+108>>2]|0)+(c[g+116>>2]|0)|0,h)|0;j=g+116|0;c[j>>2]=(c[j>>2]|0)+k;if((c[g+116>>2]|0)>>>0>=3>>>0){c[g+72>>2]=d[(c[g+56>>2]|0)+(c[g+108>>2]|0)|0]|0;c[g+72>>2]=(c[g+72>>2]<<c[g+88>>2]^(d[(c[g+56>>2]|0)+((c[g+108>>2]|0)+1)|0]|0))&c[g+84>>2]}if((c[g+116>>2]|0)>>>0<262>>>0){q=(c[(c[g>>2]|0)+4>>2]|0)!=0}else{q=0}}while(q);if((p|0)==17){i=f;return}if(!((c[g+5824>>2]|0)>>>0<(c[g+60>>2]|0)>>>0)){i=f;return}p=(c[g+108>>2]|0)+(c[g+116>>2]|0)|0;if((c[g+5824>>2]|0)>>>0<p>>>0){r=(c[g+60>>2]|0)-p|0;if(r>>>0>258>>>0){r=258}mrc((c[g+56>>2]|0)+p|0,0,r|0)|0;c[g+5824>>2]=p+r}else{if((c[g+5824>>2]|0)>>>0<(p+258|0)>>>0){r=p+258-(c[g+5824>>2]|0)|0;if(r>>>0>((c[g+60>>2]|0)-(c[g+5824>>2]|0)|0)>>>0){r=(c[g+60>>2]|0)-(c[g+5824>>2]|0)|0}mrc((c[g+56>>2]|0)+(c[g+5824>>2]|0)|0,0,r|0)|0;p=g+5824|0;c[p>>2]=(c[p>>2]|0)+r}}i=f;return}function Spc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a;a=b;b=d;d=c[f+4>>2]|0;if(d>>>0>b>>>0){d=b}if((d|0)==0){g=0;h=g;i=e;return h|0}b=f+4|0;c[b>>2]=(c[b>>2]|0)-d;if((c[(c[f+28>>2]|0)+24>>2]|0)==1){c[f+48>>2]=Dqc(c[f+48>>2]|0,c[f>>2]|0,d)|0}else{if((c[(c[f+28>>2]|0)+24>>2]|0)==2){c[f+48>>2]=Dpc(c[f+48>>2]|0,c[f>>2]|0,d)|0}}nrc(a|0,c[f>>2]|0,d)|0;a=f|0;c[a>>2]=(c[a>>2]|0)+d;a=f+8|0;c[a>>2]=(c[a>>2]|0)+d;g=d;h=g;i=e;return h|0}function Tpc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a;a=b;b=65535;if(b>>>0>((c[e+12>>2]|0)-5|0)>>>0){b=(c[e+12>>2]|0)-5|0}while(1){if((c[e+116>>2]|0)>>>0<=1>>>0){Rpc(e);if((c[e+116>>2]|0)==0){if((a|0)==0){f=7;break}}if((c[e+116>>2]|0)==0){f=9;break}}g=e+108|0;c[g>>2]=(c[g>>2]|0)+(c[e+116>>2]|0);c[e+116>>2]=0;g=(c[e+92>>2]|0)+b|0;if((c[e+108>>2]|0)==0){f=13}else{if((c[e+108>>2]|0)>>>0>=g>>>0){f=13}}if((f|0)==13){f=0;c[e+116>>2]=(c[e+108>>2]|0)-g;c[e+108>>2]=g;if((c[e+92>>2]|0)>=0){h=(c[e+56>>2]|0)+(c[e+92>>2]|0)|0}else{h=0}nqc(e,h,(c[e+108>>2]|0)-(c[e+92>>2]|0)|0,0);c[e+92>>2]=c[e+108>>2];Opc(c[e>>2]|0);if((c[(c[e>>2]|0)+16>>2]|0)==0){f=17;break}}if(((c[e+108>>2]|0)-(c[e+92>>2]|0)|0)>>>0>=((c[e+44>>2]|0)-262|0)>>>0){if((c[e+92>>2]|0)>=0){j=(c[e+56>>2]|0)+(c[e+92>>2]|0)|0}else{j=0}nqc(e,j,(c[e+108>>2]|0)-(c[e+92>>2]|0)|0,0);c[e+92>>2]=c[e+108>>2];Opc(c[e>>2]|0);if((c[(c[e>>2]|0)+16>>2]|0)==0){f=24;break}}}if((f|0)==7){k=0;l=k;i=d;return l|0}else if((f|0)==9){if((c[e+92>>2]|0)>=0){m=(c[e+56>>2]|0)+(c[e+92>>2]|0)|0}else{m=0}nqc(e,m,(c[e+108>>2]|0)-(c[e+92>>2]|0)|0,(a|0)==4|0);c[e+92>>2]=c[e+108>>2];Opc(c[e>>2]|0);if((c[(c[e>>2]|0)+16>>2]|0)==0){k=(a|0)==4?2:0;l=k;i=d;return l|0}else{k=(a|0)==4?3:1;l=k;i=d;return l|0}}else if((f|0)==17){k=0;l=k;i=d;return l|0}else if((f|0)==24){k=0;l=k;i=d;return l|0}return 0}function Upc(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=e;e=f;while(1){if((c[h+116>>2]|0)>>>0<262>>>0){Rpc(h);if((c[h+116>>2]|0)>>>0<262>>>0){if((e|0)==0){j=5;break}}if((c[h+116>>2]|0)==0){j=7;break}}f=0;if((c[h+116>>2]|0)>>>0>=3>>>0){c[h+72>>2]=(c[h+72>>2]<<c[h+88>>2]^(d[(c[h+56>>2]|0)+((c[h+108>>2]|0)+2)|0]|0))&c[h+84>>2];k=b[(c[h+68>>2]|0)+(c[h+72>>2]<<1)>>1]|0;b[(c[h+64>>2]|0)+((c[h+108>>2]&c[h+52>>2])<<1)>>1]=k;f=k&65535;b[(c[h+68>>2]|0)+(c[h+72>>2]<<1)>>1]=c[h+108>>2]}do{if((f|0)!=0){if(!(((c[h+108>>2]|0)-f|0)>>>0<=((c[h+44>>2]|0)-262|0)>>>0)){break}c[h+96>>2]=Wpc(h,f)|0}}while(0);if((c[h+96>>2]|0)>>>0>=3>>>0){k=(c[h+96>>2]|0)-3&255;l=(c[h+108>>2]|0)-(c[h+112>>2]|0)&65535;b[(c[h+5796>>2]|0)+(c[h+5792>>2]<<1)>>1]=l;m=h+5792|0;n=c[m>>2]|0;c[m>>2]=n+1;a[(c[h+5784>>2]|0)+n|0]=k;l=l-1&65535;n=h+148+((d[2644672+(k&255)|0]|0)+257<<2)|0;b[n>>1]=(b[n>>1]|0)+1;if((l&65535|0)<256){o=d[2644928+(l&65535)|0]|0}else{o=d[((l&65535)>>7)+2645184|0]|0}l=h+2440+(o<<2)|0;b[l>>1]=(b[l>>1]|0)+1;p=(c[h+5792>>2]|0)==((c[h+5788>>2]|0)-1|0)|0;l=h+116|0;c[l>>2]=(c[l>>2]|0)-(c[h+96>>2]|0);do{if((c[h+96>>2]|0)>>>0<=(c[h+128>>2]|0)>>>0){if(!((c[h+116>>2]|0)>>>0>=3>>>0)){j=24;break}l=h+96|0;c[l>>2]=(c[l>>2]|0)-1;do{l=h+108|0;c[l>>2]=(c[l>>2]|0)+1;c[h+72>>2]=(c[h+72>>2]<<c[h+88>>2]^(d[(c[h+56>>2]|0)+((c[h+108>>2]|0)+2)|0]|0))&c[h+84>>2];l=b[(c[h+68>>2]|0)+(c[h+72>>2]<<1)>>1]|0;b[(c[h+64>>2]|0)+((c[h+108>>2]&c[h+52>>2])<<1)>>1]=l;f=l&65535;b[(c[h+68>>2]|0)+(c[h+72>>2]<<1)>>1]=c[h+108>>2];l=h+96|0;n=(c[l>>2]|0)-1|0;c[l>>2]=n;}while((n|0)!=0);n=h+108|0;c[n>>2]=(c[n>>2]|0)+1}else{j=24}}while(0);if((j|0)==24){j=0;f=h+108|0;c[f>>2]=(c[f>>2]|0)+(c[h+96>>2]|0);c[h+96>>2]=0;c[h+72>>2]=d[(c[h+56>>2]|0)+(c[h+108>>2]|0)|0]|0;c[h+72>>2]=(c[h+72>>2]<<c[h+88>>2]^(d[(c[h+56>>2]|0)+((c[h+108>>2]|0)+1)|0]|0))&c[h+84>>2]}}else{f=a[(c[h+56>>2]|0)+(c[h+108>>2]|0)|0]|0;b[(c[h+5796>>2]|0)+(c[h+5792>>2]<<1)>>1]=0;n=h+5792|0;l=c[n>>2]|0;c[n>>2]=l+1;a[(c[h+5784>>2]|0)+l|0]=f;l=h+148+((f&255)<<2)|0;b[l>>1]=(b[l>>1]|0)+1;p=(c[h+5792>>2]|0)==((c[h+5788>>2]|0)-1|0)|0;l=h+116|0;c[l>>2]=(c[l>>2]|0)-1;l=h+108|0;c[l>>2]=(c[l>>2]|0)+1}if((p|0)!=0){if((c[h+92>>2]|0)>=0){q=(c[h+56>>2]|0)+(c[h+92>>2]|0)|0}else{q=0}nqc(h,q,(c[h+108>>2]|0)-(c[h+92>>2]|0)|0,0);c[h+92>>2]=c[h+108>>2];Opc(c[h>>2]|0);if((c[(c[h>>2]|0)+16>>2]|0)==0){j=32;break}}}if((j|0)==5){r=0;s=r;i=g;return s|0}else if((j|0)==7){if((c[h+92>>2]|0)>=0){t=(c[h+56>>2]|0)+(c[h+92>>2]|0)|0}else{t=0}nqc(h,t,(c[h+108>>2]|0)-(c[h+92>>2]|0)|0,(e|0)==4|0);c[h+92>>2]=c[h+108>>2];Opc(c[h>>2]|0);if((c[(c[h>>2]|0)+16>>2]|0)==0){r=(e|0)==4?2:0;s=r;i=g;return s|0}else{r=(e|0)==4?3:1;s=r;i=g;return s|0}}else if((j|0)==32){r=0;s=r;i=g;return s|0}return 0}function Vpc(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;h=e;e=f;a:while(1){if((c[h+116>>2]|0)>>>0<262>>>0){Rpc(h);if((c[h+116>>2]|0)>>>0<262>>>0){if((e|0)==0){j=5;break}}if((c[h+116>>2]|0)==0){j=7;break}}f=0;if((c[h+116>>2]|0)>>>0>=3>>>0){c[h+72>>2]=(c[h+72>>2]<<c[h+88>>2]^(d[(c[h+56>>2]|0)+((c[h+108>>2]|0)+2)|0]|0))&c[h+84>>2];k=b[(c[h+68>>2]|0)+(c[h+72>>2]<<1)>>1]|0;b[(c[h+64>>2]|0)+((c[h+108>>2]&c[h+52>>2])<<1)>>1]=k;f=k&65535;b[(c[h+68>>2]|0)+(c[h+72>>2]<<1)>>1]=c[h+108>>2]}c[h+120>>2]=c[h+96>>2];c[h+100>>2]=c[h+112>>2];c[h+96>>2]=2;do{if((f|0)!=0){if(!((c[h+120>>2]|0)>>>0<(c[h+128>>2]|0)>>>0)){break}if(!(((c[h+108>>2]|0)-f|0)>>>0<=((c[h+44>>2]|0)-262|0)>>>0)){break}c[h+96>>2]=Wpc(h,f)|0;do{if((c[h+96>>2]|0)>>>0<=5>>>0){if((c[h+136>>2]|0)!=1){if((c[h+96>>2]|0)!=3){break}if(!(((c[h+108>>2]|0)-(c[h+112>>2]|0)|0)>>>0>4096>>>0)){break}}c[h+96>>2]=2}}while(0)}}while(0);do{if((c[h+120>>2]|0)>>>0>=3>>>0){if(!((c[h+96>>2]|0)>>>0<=(c[h+120>>2]|0)>>>0)){j=38;break}k=(c[h+108>>2]|0)+(c[h+116>>2]|0)-3|0;l=(c[h+120>>2]|0)-3&255;m=(c[h+108>>2]|0)-1-(c[h+100>>2]|0)&65535;b[(c[h+5796>>2]|0)+(c[h+5792>>2]<<1)>>1]=m;n=h+5792|0;o=c[n>>2]|0;c[n>>2]=o+1;a[(c[h+5784>>2]|0)+o|0]=l;m=m-1&65535;o=h+148+((d[2644672+(l&255)|0]|0)+257<<2)|0;b[o>>1]=(b[o>>1]|0)+1;if((m&65535|0)<256){p=d[2644928+(m&65535)|0]|0}else{p=d[((m&65535)>>7)+2645184|0]|0}m=h+2440+(p<<2)|0;b[m>>1]=(b[m>>1]|0)+1;q=(c[h+5792>>2]|0)==((c[h+5788>>2]|0)-1|0)|0;m=h+116|0;c[m>>2]=(c[m>>2]|0)-((c[h+120>>2]|0)-1);m=h+120|0;c[m>>2]=(c[m>>2]|0)-2;do{m=h+108|0;o=(c[m>>2]|0)+1|0;c[m>>2]=o;if(o>>>0<=k>>>0){c[h+72>>2]=(c[h+72>>2]<<c[h+88>>2]^(d[(c[h+56>>2]|0)+((c[h+108>>2]|0)+2)|0]|0))&c[h+84>>2];o=b[(c[h+68>>2]|0)+(c[h+72>>2]<<1)>>1]|0;b[(c[h+64>>2]|0)+((c[h+108>>2]&c[h+52>>2])<<1)>>1]=o;f=o&65535;b[(c[h+68>>2]|0)+(c[h+72>>2]<<1)>>1]=c[h+108>>2]}o=h+120|0;m=(c[o>>2]|0)-1|0;c[o>>2]=m;}while((m|0)!=0);c[h+104>>2]=0;c[h+96>>2]=2;k=h+108|0;c[k>>2]=(c[k>>2]|0)+1;if((q|0)!=0){if((c[h+92>>2]|0)>=0){r=(c[h+56>>2]|0)+(c[h+92>>2]|0)|0}else{r=0}nqc(h,r,(c[h+108>>2]|0)-(c[h+92>>2]|0)|0,0);c[h+92>>2]=c[h+108>>2];Opc(c[h>>2]|0);if((c[(c[h>>2]|0)+16>>2]|0)==0){j=35;break a}}}else{j=38}}while(0);if((j|0)==38){j=0;if((c[h+104>>2]|0)!=0){f=a[(c[h+56>>2]|0)+((c[h+108>>2]|0)-1)|0]|0;b[(c[h+5796>>2]|0)+(c[h+5792>>2]<<1)>>1]=0;k=h+5792|0;m=c[k>>2]|0;c[k>>2]=m+1;a[(c[h+5784>>2]|0)+m|0]=f;m=h+148+((f&255)<<2)|0;b[m>>1]=(b[m>>1]|0)+1;q=(c[h+5792>>2]|0)==((c[h+5788>>2]|0)-1|0)|0;if((q|0)!=0){if((c[h+92>>2]|0)>=0){s=(c[h+56>>2]|0)+(c[h+92>>2]|0)|0}else{s=0}nqc(h,s,(c[h+108>>2]|0)-(c[h+92>>2]|0)|0,0);c[h+92>>2]=c[h+108>>2];Opc(c[h>>2]|0)}m=h+108|0;c[m>>2]=(c[m>>2]|0)+1;m=h+116|0;c[m>>2]=(c[m>>2]|0)-1;if((c[(c[h>>2]|0)+16>>2]|0)==0){j=45;break}}else{c[h+104>>2]=1;m=h+108|0;c[m>>2]=(c[m>>2]|0)+1;m=h+116|0;c[m>>2]=(c[m>>2]|0)-1}}}if((j|0)==5){t=0;u=t;i=g;return u|0}else if((j|0)==7){if((c[h+104>>2]|0)!=0){s=a[(c[h+56>>2]|0)+((c[h+108>>2]|0)-1)|0]|0;b[(c[h+5796>>2]|0)+(c[h+5792>>2]<<1)>>1]=0;r=h+5792|0;p=c[r>>2]|0;c[r>>2]=p+1;a[(c[h+5784>>2]|0)+p|0]=s;p=h+148+((s&255)<<2)|0;b[p>>1]=(b[p>>1]|0)+1;q=(c[h+5792>>2]|0)==((c[h+5788>>2]|0)-1|0)|0;c[h+104>>2]=0}if((c[h+92>>2]|0)>=0){v=(c[h+56>>2]|0)+(c[h+92>>2]|0)|0}else{v=0}nqc(h,v,(c[h+108>>2]|0)-(c[h+92>>2]|0)|0,(e|0)==4|0);c[h+92>>2]=c[h+108>>2];Opc(c[h>>2]|0);if((c[(c[h>>2]|0)+16>>2]|0)==0){t=(e|0)==4?2:0;u=t;i=g;return u|0}else{t=(e|0)==4?3:1;u=t;i=g;return u|0}}else if((j|0)==35){t=0;u=t;i=g;return u|0}else if((j|0)==45){t=0;u=t;i=g;return u|0}return 0}function Wpc(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;h=b;b=f;f=c[h+124>>2]|0;j=(c[h+56>>2]|0)+(c[h+108>>2]|0)|0;k=c[h+120>>2]|0;l=c[h+144>>2]|0;if((c[h+108>>2]|0)>>>0>((c[h+44>>2]|0)-262|0)>>>0){m=(c[h+108>>2]|0)-((c[h+44>>2]|0)-262)|0}else{m=0}n=m;m=c[h+64>>2]|0;o=c[h+52>>2]|0;p=(c[h+56>>2]|0)+(c[h+108>>2]|0)+258|0;q=a[j+(k-1)|0]|0;r=a[j+k|0]|0;if((c[h+120>>2]|0)>>>0>=(c[h+140>>2]|0)>>>0){f=f>>>2}if(l>>>0>(c[h+116>>2]|0)>>>0){l=c[h+116>>2]|0}a:do{s=(c[h+56>>2]|0)+b|0;do{if((d[s+k|0]|0|0)!=(r&255|0)){t=13}else{if((d[s+(k-1)|0]|0|0)!=(q&255|0)){t=13;break}if((d[s]|0|0)!=(d[j]|0|0)){t=13;break}u=s+1|0;s=u;if((d[u]|0|0)!=(d[j+1|0]|0|0)){t=13;break}j=j+2|0;s=s+1|0;do{u=j+1|0;j=u;v=s+1|0;s=v;do{if((d[u]|0|0)==(d[v]|0|0)){w=j+1|0;j=w;x=s+1|0;s=x;if((d[w]|0|0)!=(d[x]|0|0)){y=0;break}x=j+1|0;j=x;w=s+1|0;s=w;if((d[x]|0|0)!=(d[w]|0|0)){y=0;break}w=j+1|0;j=w;x=s+1|0;s=x;if((d[w]|0|0)!=(d[x]|0|0)){y=0;break}x=j+1|0;j=x;w=s+1|0;s=w;if((d[x]|0|0)!=(d[w]|0|0)){y=0;break}w=j+1|0;j=w;x=s+1|0;s=x;if((d[w]|0|0)!=(d[x]|0|0)){y=0;break}x=j+1|0;j=x;w=s+1|0;s=w;if((d[x]|0|0)!=(d[w]|0|0)){y=0;break}w=j+1|0;j=w;x=s+1|0;s=x;if((d[w]|0|0)!=(d[x]|0|0)){y=0;break}y=j>>>0<p>>>0}else{y=0}}while(0)}while(y);v=258-(p-j)|0;j=p-258|0;if((v|0)>(k|0)){c[h+112>>2]=b;k=v;if((v|0)>=(l|0)){t=28;break a}q=a[j+(k-1)|0]|0;r=a[j+k|0]|0}}}while(0);if((t|0)==13){t=0}s=e[m+((b&o)<<1)>>1]|0;b=s;if(s>>>0>n>>>0){s=f-1|0;f=s;z=(s|0)!=0}else{z=0}}while(z);if(k>>>0<=(c[h+116>>2]|0)>>>0){A=k;B=A;i=g;return B|0}else{A=c[h+116>>2]|0;B=A;i=g;return B|0}return 0}function Xpc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=a;do{if((d|0)!=0){if((c[d+28>>2]|0)==0){break}a=c[d+28>>2]|0;c[a+28>>2]=0;c[d+20>>2]=0;c[d+8>>2]=0;c[d+24>>2]=0;c[d+48>>2]=1;c[a>>2]=0;c[a+4>>2]=0;c[a+12>>2]=0;c[a+20>>2]=32768;c[a+32>>2]=0;c[a+40>>2]=0;c[a+44>>2]=0;c[a+48>>2]=0;c[a+56>>2]=0;c[a+60>>2]=0;e=a+1328|0;c[a+108>>2]=e;c[a+80>>2]=e;c[a+76>>2]=e;c[a+7104>>2]=1;c[a+7108>>2]=-1;f=0;g=f;i=b;return g|0}}while(0);f=-2;g=f;i=b;return g|0}function Ypc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;do{if((e|0)!=0){if((c[e+28>>2]|0)==0){break}b=c[e+28>>2]|0;if((a|0)<0){f=0;a=-a|0}else{f=(a>>4)+1|0;if((a|0)<48){a=a&15}}do{if((a|0)!=0){if((a|0)>=8){if((a|0)<=15){break}}g=-2;h=g;i=d;return h|0}}while(0);do{if((c[b+52>>2]|0)!=0){if((c[b+36>>2]|0)==(a|0)){break}re[c[e+36>>2]&1023](c[e+40>>2]|0,c[b+52>>2]|0);c[b+52>>2]=0}}while(0);c[b+8>>2]=f;c[b+36>>2]=a;g=Xpc(e)|0;h=g;i=d;return h|0}}while(0);g=-2;h=g;i=d;return h|0}function Zpc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=b;b=d;d=e;e=f;do{if((d|0)!=0){if((a[d|0]|0)!=(a[2257608]|0)){break}if((e|0)!=56){break}if((h|0)==0){j=-2;k=j;i=g;return k|0}c[h+24>>2]=0;if((c[h+32>>2]|0)==0){c[h+32>>2]=154;c[h+40>>2]=0}if((c[h+36>>2]|0)==0){c[h+36>>2]=432}f=Ee[c[h+32>>2]&511](c[h+40>>2]|0,1,7116)|0;if((f|0)==0){j=-4;k=j;i=g;return k|0}c[h+28>>2]=f;c[f+52>>2]=0;l=Ypc(h,b)|0;if((l|0)!=0){re[c[h+36>>2]&1023](c[h+40>>2]|0,f);c[h+28>>2]=0}j=l;k=j;i=g;return k|0}}while(0);j=-6;k=j;i=g;return k|0}function _pc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=Zpc(a,15,b,c)|0;i=d;return e|0}function $pc(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;m=f;f=g;do{if((m|0)!=0){if((c[m+28>>2]|0)==0){break}if((c[m+12>>2]|0)==0){break}if((c[m>>2]|0)==0){if((c[m+4>>2]|0)!=0){break}}g=c[m+28>>2]|0;if((c[g>>2]|0)==11){c[g>>2]=12}n=c[m+12>>2]|0;o=c[m+16>>2]|0;p=c[m>>2]|0;q=c[m+4>>2]|0;r=c[g+56>>2]|0;s=c[g+60>>2]|0;t=q;u=o;v=0;a:while(1){b:do{switch(c[g>>2]|0){case 14:{w=272;break};case 11:{w=223;break};case 3:{w=88;break};case 15:{w=273;break};case 5:{w=129;break};case 17:{w=301;break};case 8:{w=188;break};case 4:{w=106;break};case 9:{while(1){if(!(s>>>0<32>>>0)){break}if((q|0)==0){w=211;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}x=(r>>>24&255)+(r>>>8&65280)+((r&65280)<<8)+((r&255)<<24)|0;c[g+24>>2]=x;c[m+48>>2]=x;r=0;s=0;c[g>>2]=10;w=218;break};case 1:{while(1){if(!(s>>>0<16>>>0)){break}if((q|0)==0){w=53;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}c[g+16>>2]=r;if((c[g+16>>2]&255|0)!=8){c[m+24>>2]=2412656;c[g>>2]=29;break b}if((c[g+16>>2]&57344|0)!=0){c[m+24>>2]=2278040;c[g>>2]=29;break b}if((c[g+32>>2]|0)!=0){c[c[g+32>>2]>>2]=r>>>8&1}if((c[g+16>>2]&512|0)!=0){a[l|0]=r;a[l+1|0]=r>>>8;c[g+24>>2]=Dpc(c[g+24>>2]|0,l|0,2)|0}r=0;s=0;c[g>>2]=2;w=70;break};case 2:{w=70;break};case 12:{w=227;break};case 6:{w=146;break};case 25:{if((o|0)==0){w=525;break a}x=n;n=x+1|0;a[x]=c[g+64>>2];o=o-1|0;c[g>>2]=20;break};case 26:{if((c[g+8>>2]|0)!=0){while(1){if(!(s>>>0<32>>>0)){break}if((q|0)==0){w=533;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}u=u-o|0;x=m+20|0;c[x>>2]=(c[x>>2]|0)+u;x=g+28|0;c[x>>2]=(c[x>>2]|0)+u;if((u|0)!=0){if((c[g+16>>2]|0)!=0){y=Dpc(c[g+24>>2]|0,n+(-u|0)|0,u)|0}else{y=Dqc(c[g+24>>2]|0,n+(-u|0)|0,u)|0}c[g+24>>2]=y;c[m+48>>2]=y}u=o;if((c[g+16>>2]|0)!=0){z=r}else{z=(r>>>24&255)+(r>>>8&65280)+((r&65280)<<8)+((r&255)<<24)|0}if((z|0)!=(c[g+24>>2]|0)){c[m+24>>2]=2495512;c[g>>2]=29;break b}r=0;s=0}c[g>>2]=27;w=551;break};case 7:{w=167;break};case 27:{w=551;break};case 28:{w=568;break a;break};case 29:{w=569;break a;break};case 30:{w=570;break a;break};case 31:{w=571;break a;break};case 23:{w=488;break};case 24:{w=502;break};case 0:{if((c[g+8>>2]|0)==0){c[g>>2]=12;break b}while(1){if(!(s>>>0<16>>>0)){break}if((q|0)==0){w=20;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}do{if((c[g+8>>2]&2|0)!=0){if((r|0)!=35615){break}c[g+24>>2]=Dpc(0,0,0)|0;a[l|0]=r;a[l+1|0]=r>>>8;c[g+24>>2]=Dpc(c[g+24>>2]|0,l|0,2)|0;r=0;s=0;c[g>>2]=1;break b}}while(0);c[g+16>>2]=0;if((c[g+32>>2]|0)!=0){c[(c[g+32>>2]|0)+48>>2]=-1}do{if((c[g+8>>2]&1|0)!=0){if((((((r&255)<<8)+(r>>>8)|0)>>>0)%31|0|0)!=0){break}if((r&15|0)!=8){c[m+24>>2]=2412656;c[g>>2]=29;break b}r=r>>>4;s=s-4|0;A=(r&15)+8|0;do{if((c[g+36>>2]|0)==0){c[g+36>>2]=A}else{if(A>>>0>(c[g+36>>2]|0)>>>0){c[m+24>>2]=2335056;c[g>>2]=29;break b}else{break}}}while(0);c[g+20>>2]=1<<A;x=Dqc(0,0,0)|0;c[g+24>>2]=x;c[m+48>>2]=x;c[g>>2]=(r&512|0)!=0?9:11;r=0;s=0;break b}}while(0);c[m+24>>2]=2535624;c[g>>2]=29;break};case 16:{while(1){if(!(s>>>0<14>>>0)){break}if((q|0)==0){w=287;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}c[g+96>>2]=(r&31)+257;r=r>>>5;s=s-5|0;c[g+100>>2]=(r&31)+1;r=r>>>5;s=s-5|0;c[g+92>>2]=(r&15)+4;r=r>>>4;s=s-4|0;do{if(!((c[g+96>>2]|0)>>>0>286>>>0)){if((c[g+100>>2]|0)>>>0>30>>>0){break}c[g+104>>2]=0;c[g>>2]=17;w=301;break b}}while(0);c[m+24>>2]=2134952;c[g>>2]=29;break};case 10:{w=218;break};case 19:{w=409;break};case 20:{w=410;break};case 13:{r=r>>>((s&7)>>>0);s=s-(s&7)|0;while(1){if(!(s>>>0<32>>>0)){break}if((q|0)==0){w=261;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}if((r&65535|0)!=(r>>>16^65535|0)){c[m+24>>2]=2160392;c[g>>2]=29;break b}c[g+64>>2]=r&65535;r=0;s=0;c[g>>2]=14;if((f|0)==6){w=270;break a}w=272;break};case 21:{w=449;break};case 22:{w=463;break};case 18:{w=321;break};default:{w=572;break a}}}while(0);do{if((w|0)==70){w=0;while(1){if(!(s>>>0<32>>>0)){break}if((q|0)==0){w=75;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}if((c[g+32>>2]|0)!=0){c[(c[g+32>>2]|0)+4>>2]=r}if((c[g+16>>2]&512|0)!=0){a[l|0]=r;a[l+1|0]=r>>>8;a[l+2|0]=r>>>16;a[l+3|0]=r>>>24;c[g+24>>2]=Dpc(c[g+24>>2]|0,l|0,4)|0}r=0;s=0;c[g>>2]=3;w=88}else if((w|0)==218){w=0;if((c[g+12>>2]|0)==0){w=219;break a}x=Dqc(0,0,0)|0;c[g+24>>2]=x;c[m+48>>2]=x;c[g>>2]=11;w=223}else if((w|0)==272){w=0;c[g>>2]=15;w=273}else if((w|0)==301){w=0;while(1){if(!((c[g+104>>2]|0)>>>0<(c[g+92>>2]|0)>>>0)){break}while(1){if(!(s>>>0<3>>>0)){break}if((q|0)==0){w=308;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}x=g+104|0;B=c[x>>2]|0;c[x>>2]=B+1;b[g+112+((e[1072072+(B<<1)>>1]|0)<<1)>>1]=r&7;r=r>>>3;s=s-3|0}while(1){if(!((c[g+104>>2]|0)>>>0<19>>>0)){break}B=g+104|0;x=c[B>>2]|0;c[B>>2]=x+1;b[g+112+((e[1072072+(x<<1)>>1]|0)<<1)>>1]=0}c[g+108>>2]=g+1328;c[g+76>>2]=c[g+108>>2];c[g+84>>2]=7;v=fqc(0,g+112|0,19,g+108|0,g+84|0,g+752|0)|0;if((v|0)!=0){c[m+24>>2]=2111608;c[g>>2]=29;break}else{c[g+104>>2]=0;c[g>>2]=18;w=321;break}}else if((w|0)==551){w=0;if((c[g+8>>2]|0)==0){w=567;break a}if((c[g+16>>2]|0)==0){w=567;break a}while(1){if(!(s>>>0<32>>>0)){break}if((q|0)==0){w=558;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}if((r|0)==(c[g+28>>2]|0)){w=564;break a}c[m+24>>2]=2484808;c[g>>2]=29}}while(0);do{if((w|0)==88){w=0;while(1){if(!(s>>>0<16>>>0)){break}if((q|0)==0){w=93;break a}q=q-1|0;x=p;p=x+1|0;r=r+((d[x]|0)<<s)|0;s=s+8|0}if((c[g+32>>2]|0)!=0){c[(c[g+32>>2]|0)+8>>2]=r&255;c[(c[g+32>>2]|0)+12>>2]=r>>>8}if((c[g+16>>2]&512|0)!=0){a[l|0]=r;a[l+1|0]=r>>>8;c[g+24>>2]=Dpc(c[g+24>>2]|0,l|0,2)|0}r=0;s=0;c[g>>2]=4;w=106}else if((w|0)==223){w=0;if((f|0)==5){w=225;break a}if((f|0)==6){w=225;break a}w=227}else if((w|0)==273){w=0;C=c[g+64>>2]|0;if((C|0)==0){c[g>>2]=11;break}if(C>>>0>q>>>0){C=q}if(C>>>0>o>>>0){C=o}if((C|0)==0){w=279;break a}nrc(n|0,p|0,C)|0;q=q-C|0;p=p+C|0;o=o-C|0;n=n+C|0;x=g+64|0;c[x>>2]=(c[x>>2]|0)-C}else if((w|0)==321){w=0;while(1){if(!((c[g+104>>2]|0)>>>0<((c[g+96>>2]|0)+(c[g+100>>2]|0)|0)>>>0)){break}while(1){x=j;B=(c[g+76>>2]|0)+((r&(1<<c[g+84>>2])-1)<<2)|0;b[x>>1]=b[B>>1]|0;b[x+2>>1]=b[B+2>>1]|0;if((d[j+1|0]|0)>>>0<=s>>>0){break}if((q|0)==0){w=328;break a}q=q-1|0;B=p;p=B+1|0;r=r+((d[B]|0)<<s)|0;s=s+8|0}if((e[j+2>>1]|0|0)<16){while(1){if(!(s>>>0<(d[j+1|0]|0)>>>0)){break}if((q|0)==0){w=337;break a}q=q-1|0;B=p;p=B+1|0;r=r+((d[B]|0)<<s)|0;s=s+8|0}r=r>>>((d[j+1|0]|0)>>>0);s=s-(d[j+1|0]|0)|0;B=b[j+2>>1]|0;x=g+104|0;D=c[x>>2]|0;c[x>>2]=D+1;b[g+112+(D<<1)>>1]=B}else{if((e[j+2>>1]|0|0)==16){while(1){if(!(s>>>0<((d[j+1|0]|0)+2|0)>>>0)){break}if((q|0)==0){w=350;break a}q=q-1|0;B=p;p=B+1|0;r=r+((d[B]|0)<<s)|0;s=s+8|0}r=r>>>((d[j+1|0]|0)>>>0);s=s-(d[j+1|0]|0)|0;if((c[g+104>>2]|0)==0){w=357;break}A=e[g+112+((c[g+104>>2]|0)-1<<1)>>1]|0;C=(r&3)+3|0;r=r>>>2;s=s-2|0}else{if((e[j+2>>1]|0|0)==17){while(1){if(!(s>>>0<((d[j+1|0]|0)+3|0)>>>0)){break}if((q|0)==0){w=367;break a}q=q-1|0;B=p;p=B+1|0;r=r+((d[B]|0)<<s)|0;s=s+8|0}r=r>>>((d[j+1|0]|0)>>>0);s=s-(d[j+1|0]|0)|0;A=0;C=(r&7)+3|0;r=r>>>3;s=s-3|0}else{while(1){if(!(s>>>0<((d[j+1|0]|0)+7|0)>>>0)){break}if((q|0)==0){w=381;break a}q=q-1|0;B=p;p=B+1|0;r=r+((d[B]|0)<<s)|0;s=s+8|0}r=r>>>((d[j+1|0]|0)>>>0);s=s-(d[j+1|0]|0)|0;A=0;C=(r&127)+11|0;r=r>>>7;s=s-7|0}}if(((c[g+104>>2]|0)+C|0)>>>0>((c[g+96>>2]|0)+(c[g+100>>2]|0)|0)>>>0){w=392;break}while(1){B=C;C=B-1|0;if((B|0)==0){break}B=g+104|0;D=c[B>>2]|0;c[B>>2]=D+1;b[g+112+(D<<1)>>1]=A}}}if((w|0)==357){w=0;c[m+24>>2]=2629312;c[g>>2]=29}else if((w|0)==392){w=0;c[m+24>>2]=2629312;c[g>>2]=29}if((c[g>>2]|0)==29){break}if((e[g+624>>1]|0|0)==0){c[m+24>>2]=2604352;c[g>>2]=29;break}c[g+108>>2]=g+1328;c[g+76>>2]=c[g+108>>2];c[g+84>>2]=9;v=fqc(1,g+112|0,c[g+96>>2]|0,g+108|0,g+84|0,g+752|0)|0;if((v|0)!=0){c[m+24>>2]=2578728;c[g>>2]=29;break}c[g+80>>2]=c[g+108>>2];c[g+88>>2]=6;v=fqc(2,g+112+(c[g+96>>2]<<1)|0,c[g+100>>2]|0,g+108|0,g+88|0,g+752|0)|0;if((v|0)!=0){c[m+24>>2]=2559144;c[g>>2]=29;break}c[g>>2]=19;if((f|0)==6){w=407;break a}w=409}}while(0);do{if((w|0)==106){w=0;if((c[g+16>>2]&1024|0)!=0){while(1){if(!(s>>>0<16>>>0)){break}if((q|0)==0){w=112;break a}q=q-1|0;D=p;p=D+1|0;r=r+((d[D]|0)<<s)|0;s=s+8|0}c[g+64>>2]=r;if((c[g+32>>2]|0)!=0){c[(c[g+32>>2]|0)+20>>2]=r}if((c[g+16>>2]&512|0)!=0){a[l|0]=r;a[l+1|0]=r>>>8;c[g+24>>2]=Dpc(c[g+24>>2]|0,l|0,2)|0}r=0;s=0}else{if((c[g+32>>2]|0)!=0){c[(c[g+32>>2]|0)+16>>2]=0}}c[g>>2]=5;w=129}else if((w|0)==227){w=0;if((c[g+4>>2]|0)!=0){r=r>>>((s&7)>>>0);s=s-(s&7)|0;c[g>>2]=26;break}while(1){if(!(s>>>0<3>>>0)){break}if((q|0)==0){w=236;break a}q=q-1|0;D=p;p=D+1|0;r=r+((d[D]|0)<<s)|0;s=s+8|0}c[g+4>>2]=r&1;r=r>>>1;s=s-1|0;D=r&3;if((D|0)==0){c[g>>2]=13}else if((D|0)==1){aqc(g);c[g>>2]=19;if((f|0)==6){w=245;break a}}else if((D|0)==2){c[g>>2]=16}else if((D|0)==3){c[m+24>>2]=2191056;c[g>>2]=29}r=r>>>2;s=s-2|0}else if((w|0)==409){w=0;c[g>>2]=20;w=410}}while(0);c:do{if((w|0)==129){w=0;if((c[g+16>>2]&1024|0)!=0){C=c[g+64>>2]|0;if(C>>>0>q>>>0){C=q}if((C|0)!=0){do{if((c[g+32>>2]|0)!=0){if((c[(c[g+32>>2]|0)+16>>2]|0)==0){break}A=(c[(c[g+32>>2]|0)+20>>2]|0)-(c[g+64>>2]|0)|0;if((A+C|0)>>>0>(c[(c[g+32>>2]|0)+24>>2]|0)>>>0){E=(c[(c[g+32>>2]|0)+24>>2]|0)-A|0}else{E=C}nrc((c[(c[g+32>>2]|0)+16>>2]|0)+A|0,p|0,E)|0}}while(0);if((c[g+16>>2]&512|0)!=0){c[g+24>>2]=Dpc(c[g+24>>2]|0,p,C)|0}q=q-C|0;p=p+C|0;D=g+64|0;c[D>>2]=(c[D>>2]|0)-C}if((c[g+64>>2]|0)!=0){w=143;break a}}c[g+64>>2]=0;c[g>>2]=6;w=146}else if((w|0)==410){w=0;do{if(q>>>0>=6>>>0){if(!(o>>>0>=258>>>0)){break}c[m+12>>2]=n;c[m+16>>2]=o;c[m>>2]=p;c[m+4>>2]=q;c[g+56>>2]=r;c[g+60>>2]=s;Eqc(m,u);n=c[m+12>>2]|0;o=c[m+16>>2]|0;p=c[m>>2]|0;q=c[m+4>>2]|0;r=c[g+56>>2]|0;s=c[g+60>>2]|0;if((c[g>>2]|0)==11){c[g+7108>>2]=-1}break c}}while(0);c[g+7108>>2]=0;while(1){D=j;B=(c[g+76>>2]|0)+((r&(1<<c[g+84>>2])-1)<<2)|0;b[D>>1]=b[B>>1]|0;b[D+2>>1]=b[B+2>>1]|0;if((d[j+1|0]|0)>>>0<=s>>>0){break}if((q|0)==0){w=424;break a}q=q-1|0;B=p;p=B+1|0;r=r+((d[B]|0)<<s)|0;s=s+8|0}do{if((d[j|0]|0|0)!=0){if((a[j|0]&240|0)!=0){break}B=k;D=j;b[B>>1]=b[D>>1]|0;b[B+2>>1]=b[D+2>>1]|0;while(1){D=j;B=(c[g+76>>2]|0)+((e[k+2>>1]|0)+((r&(1<<(d[k+1|0]|0)+(d[k|0]|0))-1)>>>((d[k+1|0]|0)>>>0))<<2)|0;b[D>>1]=b[B>>1]|0;b[D+2>>1]=b[B+2>>1]|0;if(((d[k+1|0]|0)+(d[j+1|0]|0)|0)>>>0<=s>>>0){break}if((q|0)==0){w=434;break a}q=q-1|0;B=p;p=B+1|0;r=r+((d[B]|0)<<s)|0;s=s+8|0}r=r>>>((d[k+1|0]|0)>>>0);s=s-(d[k+1|0]|0)|0;B=g+7108|0;c[B>>2]=(c[B>>2]|0)+(d[k+1|0]|0)}}while(0);r=r>>>((d[j+1|0]|0)>>>0);s=s-(d[j+1|0]|0)|0;B=g+7108|0;c[B>>2]=(c[B>>2]|0)+(d[j+1|0]|0);c[g+64>>2]=e[j+2>>1]|0;if((d[j|0]|0|0)==0){c[g>>2]=25;break}if((a[j|0]&32|0)!=0){c[g+7108>>2]=-1;c[g>>2]=11;break}if((a[j|0]&64|0)!=0){c[m+24>>2]=2541760;c[g>>2]=29;break}else{c[g+72>>2]=a[j|0]&15;c[g>>2]=21;w=449;break}}}while(0);if((w|0)==146){w=0;if((c[g+16>>2]&2048|0)!=0){if((q|0)==0){w=148;break}C=0;do{B=C;C=B+1|0;A=d[p+B|0]|0;do{if((c[g+32>>2]|0)!=0){if((c[(c[g+32>>2]|0)+28>>2]|0)==0){break}if(!((c[g+64>>2]|0)>>>0<(c[(c[g+32>>2]|0)+32>>2]|0)>>>0)){break}B=g+64|0;D=c[B>>2]|0;c[B>>2]=D+1;a[(c[(c[g+32>>2]|0)+28>>2]|0)+D|0]=A}}while(0);if((A|0)!=0){F=C>>>0<q>>>0}else{F=0}}while(F);if((c[g+16>>2]&512|0)!=0){c[g+24>>2]=Dpc(c[g+24>>2]|0,p,C)|0}q=q-C|0;p=p+C|0;if((A|0)!=0){w=161;break}}else{if((c[g+32>>2]|0)!=0){c[(c[g+32>>2]|0)+28>>2]=0}}c[g+64>>2]=0;c[g>>2]=7;w=167}else if((w|0)==449){w=0;if((c[g+72>>2]|0)!=0){while(1){if(!(s>>>0<(c[g+72>>2]|0)>>>0)){break}if((q|0)==0){w=455;break a}q=q-1|0;D=p;p=D+1|0;r=r+((d[D]|0)<<s)|0;s=s+8|0}D=g+64|0;c[D>>2]=(c[D>>2]|0)+(r&(1<<c[g+72>>2])-1);r=r>>>((c[g+72>>2]|0)>>>0);s=s-(c[g+72>>2]|0)|0;D=g+7108|0;c[D>>2]=(c[D>>2]|0)+(c[g+72>>2]|0)}c[g+7112>>2]=c[g+64>>2];c[g>>2]=22;w=463}do{if((w|0)==167){w=0;if((c[g+16>>2]&4096|0)!=0){if((q|0)==0){w=169;break a}C=0;do{D=C;C=D+1|0;A=d[p+D|0]|0;do{if((c[g+32>>2]|0)!=0){if((c[(c[g+32>>2]|0)+36>>2]|0)==0){break}if(!((c[g+64>>2]|0)>>>0<(c[(c[g+32>>2]|0)+40>>2]|0)>>>0)){break}D=g+64|0;B=c[D>>2]|0;c[D>>2]=B+1;a[(c[(c[g+32>>2]|0)+36>>2]|0)+B|0]=A}}while(0);if((A|0)!=0){G=C>>>0<q>>>0}else{G=0}}while(G);if((c[g+16>>2]&512|0)!=0){c[g+24>>2]=Dpc(c[g+24>>2]|0,p,C)|0}q=q-C|0;p=p+C|0;if((A|0)!=0){w=182;break a}}else{if((c[g+32>>2]|0)!=0){c[(c[g+32>>2]|0)+36>>2]=0}}c[g>>2]=8;w=188}else if((w|0)==463){w=0;while(1){B=j;D=(c[g+80>>2]|0)+((r&(1<<c[g+88>>2])-1)<<2)|0;b[B>>1]=b[D>>1]|0;b[B+2>>1]=b[D+2>>1]|0;if((d[j+1|0]|0)>>>0<=s>>>0){break}if((q|0)==0){w=468;break a}q=q-1|0;D=p;p=D+1|0;r=r+((d[D]|0)<<s)|0;s=s+8|0}if((a[j|0]&240|0)==0){D=k;B=j;b[D>>1]=b[B>>1]|0;b[D+2>>1]=b[B+2>>1]|0;while(1){B=j;D=(c[g+80>>2]|0)+((e[k+2>>1]|0)+((r&(1<<(d[k+1|0]|0)+(d[k|0]|0))-1)>>>((d[k+1|0]|0)>>>0))<<2)|0;b[B>>1]=b[D>>1]|0;b[B+2>>1]=b[D+2>>1]|0;if(((d[k+1|0]|0)+(d[j+1|0]|0)|0)>>>0<=s>>>0){break}if((q|0)==0){w=477;break a}q=q-1|0;D=p;p=D+1|0;r=r+((d[D]|0)<<s)|0;s=s+8|0}r=r>>>((d[k+1|0]|0)>>>0);s=s-(d[k+1|0]|0)|0;D=g+7108|0;c[D>>2]=(c[D>>2]|0)+(d[k+1|0]|0)}r=r>>>((d[j+1|0]|0)>>>0);s=s-(d[j+1|0]|0)|0;D=g+7108|0;c[D>>2]=(c[D>>2]|0)+(d[j+1|0]|0);if((a[j|0]&64|0)!=0){c[m+24>>2]=2524648;c[g>>2]=29;break}else{c[g+68>>2]=e[j+2>>1]|0;c[g+72>>2]=a[j|0]&15;c[g>>2]=23;w=488;break}}}while(0);do{if((w|0)==188){w=0;if((c[g+16>>2]&512|0)!=0){while(1){if(!(s>>>0<16>>>0)){break}if((q|0)==0){w=194;break a}q=q-1|0;D=p;p=D+1|0;r=r+((d[D]|0)<<s)|0;s=s+8|0}if((r|0)!=(c[g+24>>2]&65535|0)){c[m+24>>2]=2228648;c[g>>2]=29;break}r=0;s=0}if((c[g+32>>2]|0)!=0){c[(c[g+32>>2]|0)+44>>2]=c[g+16>>2]>>9&1;c[(c[g+32>>2]|0)+48>>2]=1}D=Dpc(0,0,0)|0;c[g+24>>2]=D;c[m+48>>2]=D;c[g>>2]=11}else if((w|0)==488){w=0;if((c[g+72>>2]|0)!=0){while(1){if(!(s>>>0<(c[g+72>>2]|0)>>>0)){break}if((q|0)==0){w=494;break a}q=q-1|0;D=p;p=D+1|0;r=r+((d[D]|0)<<s)|0;s=s+8|0}D=g+68|0;c[D>>2]=(c[D>>2]|0)+(r&(1<<c[g+72>>2])-1);r=r>>>((c[g+72>>2]|0)>>>0);s=s-(c[g+72>>2]|0)|0;D=g+7108|0;c[D>>2]=(c[D>>2]|0)+(c[g+72>>2]|0)}c[g>>2]=24;w=502}}while(0);d:do{if((w|0)==502){w=0;if((o|0)==0){w=503;break a}C=u-o|0;if((c[g+68>>2]|0)>>>0>C>>>0){C=(c[g+68>>2]|0)-C|0;do{if(C>>>0>(c[g+44>>2]|0)>>>0){if((c[g+7104>>2]|0)!=0){c[m+24>>2]=2509464;c[g>>2]=29;break d}else{break}}}while(0);if(C>>>0>(c[g+48>>2]|0)>>>0){C=C-(c[g+48>>2]|0)|0;H=(c[g+52>>2]|0)+((c[g+40>>2]|0)-C)|0}else{H=(c[g+52>>2]|0)+((c[g+48>>2]|0)-C)|0}if(C>>>0>(c[g+64>>2]|0)>>>0){C=c[g+64>>2]|0}}else{H=n+(-(c[g+68>>2]|0)|0)|0;C=c[g+64>>2]|0}if(C>>>0>o>>>0){C=o}o=o-C|0;D=g+64|0;c[D>>2]=(c[D>>2]|0)-C;do{D=H;H=D+1|0;B=n;n=B+1|0;a[B]=a[D]|0;D=C-1|0;C=D;}while((D|0)!=0);if((c[g+64>>2]|0)==0){c[g>>2]=20}}}while(0)}if((w|0)!=20)if((w|0)!=53)if((w|0)!=75)if((w|0)!=93)if((w|0)!=112)if((w|0)!=143)if((w|0)!=148)if((w|0)!=161)if((w|0)!=169)if((w|0)!=182)if((w|0)!=194)if((w|0)!=211)if((w|0)==219){c[m+12>>2]=n;c[m+16>>2]=o;c[m>>2]=p;c[m+4>>2]=q;c[g+56>>2]=r;c[g+60>>2]=s;I=2;J=I;i=h;return J|0}else if((w|0)!=225)if((w|0)!=236)if((w|0)==245){r=r>>>2;s=s-2|0}else if((w|0)!=261)if((w|0)!=270)if((w|0)!=279)if((w|0)!=287)if((w|0)!=308)if((w|0)!=328)if((w|0)!=337)if((w|0)!=350)if((w|0)!=367)if((w|0)!=381)if((w|0)!=407)if((w|0)!=424)if((w|0)!=434)if((w|0)!=455)if((w|0)!=468)if((w|0)!=477)if((w|0)!=494)if((w|0)!=503)if((w|0)!=525)if((w|0)!=533)if((w|0)!=558)if((w|0)==564){r=0;s=0;w=567}else if((w|0)==569){v=-3}else if((w|0)==570){I=-4;J=I;i=h;return J|0}else if((w|0)==571){w=572}if((w|0)==567){c[g>>2]=28;w=568}else if((w|0)==572){I=-2;J=I;i=h;return J|0}if((w|0)==568){v=1}c[m+12>>2]=n;c[m+16>>2]=o;c[m>>2]=p;c[m+4>>2]=q;c[g+56>>2]=r;c[g+60>>2]=s;do{if((c[g+40>>2]|0)!=0){w=579}else{if(!((c[g>>2]|0)>>>0<26>>>0)){break}if((u|0)!=(c[m+16>>2]|0)){w=579}}}while(0);do{if((w|0)==579){if((bqc(m,u)|0)==0){break}c[g>>2]=30;I=-4;J=I;i=h;return J|0}}while(0);t=t-(c[m+4>>2]|0)|0;u=u-(c[m+16>>2]|0)|0;s=m+8|0;c[s>>2]=(c[s>>2]|0)+t;s=m+20|0;c[s>>2]=(c[s>>2]|0)+u;s=g+28|0;c[s>>2]=(c[s>>2]|0)+u;do{if((c[g+8>>2]|0)!=0){if((u|0)==0){break}if((c[g+16>>2]|0)!=0){K=Dpc(c[g+24>>2]|0,(c[m+12>>2]|0)+(-u|0)|0,u)|0}else{K=Dqc(c[g+24>>2]|0,(c[m+12>>2]|0)+(-u|0)|0,u)|0}c[g+24>>2]=K;c[m+48>>2]=K}}while(0);if((c[g>>2]|0)==19){L=1}else{L=(c[g>>2]|0)==14}c[m+44>>2]=(c[g+60>>2]|0)+((c[g+4>>2]|0)!=0?64:0)+((c[g>>2]|0)==11?128:0)+(L?256:0);if((t|0)==0){if((u|0)==0){w=593}else{w=592}}else{w=592}if((w|0)==592){if((f|0)==4){w=593}}do{if((w|0)==593){if((v|0)!=0){break}v=-5}}while(0);I=v;J=I;i=h;return J|0}}while(0);I=-2;J=I;i=h;return J|0}function aqc(a){a=a|0;var b=0;b=a;c[b+76>>2]=1212920;c[b+84>>2]=9;c[b+80>>2]=1214968;c[b+88>>2]=5;i=i;return}function bqc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a;a=b;b=c[e+28>>2]|0;do{if((c[b+52>>2]|0)==0){c[b+52>>2]=Ee[c[e+32>>2]&511](c[e+40>>2]|0,1<<c[b+36>>2],1)|0;if((c[b+52>>2]|0)!=0){break}f=1;g=f;i=d;return g|0}}while(0);if((c[b+40>>2]|0)==0){c[b+40>>2]=1<<c[b+36>>2];c[b+48>>2]=0;c[b+44>>2]=0}h=a-(c[e+16>>2]|0)|0;if(h>>>0>=(c[b+40>>2]|0)>>>0){nrc(c[b+52>>2]|0,(c[e+12>>2]|0)+(-(c[b+40>>2]|0)|0)|0,c[b+40>>2]|0)|0;c[b+48>>2]=0;c[b+44>>2]=c[b+40>>2]}else{a=(c[b+40>>2]|0)-(c[b+48>>2]|0)|0;if(a>>>0>h>>>0){a=h}nrc((c[b+52>>2]|0)+(c[b+48>>2]|0)|0,(c[e+12>>2]|0)+(-h|0)|0,a)|0;h=h-a|0;if((h|0)!=0){nrc(c[b+52>>2]|0,(c[e+12>>2]|0)+(-h|0)|0,h)|0;c[b+48>>2]=h;c[b+44>>2]=c[b+40>>2]}else{h=b+48|0;c[h>>2]=(c[h>>2]|0)+a;if((c[b+48>>2]|0)==(c[b+40>>2]|0)){c[b+48>>2]=0}if((c[b+44>>2]|0)>>>0<(c[b+40>>2]|0)>>>0){h=b+44|0;c[h>>2]=(c[h>>2]|0)+a}}}f=0;g=f;i=d;return g|0}function cqc(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a;do{if((d|0)!=0){if((c[d+28>>2]|0)==0){break}if((c[d+36>>2]|0)==0){break}a=c[d+28>>2]|0;if((c[a+52>>2]|0)!=0){re[c[d+36>>2]&1023](c[d+40>>2]|0,c[a+52>>2]|0)}re[c[d+36>>2]&1023](c[d+40>>2]|0,c[d+28>>2]|0);c[d+28>>2]=0;e=0;f=e;i=b;return f|0}}while(0);e=-2;f=e;i=b;return f|0}function dqc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=b;do{if((f|0)!=0){if((c[f+28>>2]|0)==0){break}b=c[f+28>>2]|0;do{if((c[f+4>>2]|0)==0){if(!((c[b+60>>2]|0)>>>0<8>>>0)){break}g=-5;h=g;i=d;return h|0}}while(0);if((c[b>>2]|0)!=31){c[b>>2]=31;j=b+56|0;c[j>>2]=c[j>>2]<<(c[b+60>>2]&7);j=b+60|0;c[j>>2]=(c[j>>2]|0)-(c[b+60>>2]&7);k=0;while(1){if(!((c[b+60>>2]|0)>>>0>=8>>>0)){break}j=k;k=j+1|0;a[e+j|0]=c[b+56>>2];j=b+56|0;c[j>>2]=(c[j>>2]|0)>>>8;j=b+60|0;c[j>>2]=(c[j>>2]|0)-8}c[b+104>>2]=0;eqc(b+104|0,e|0,k)|0}k=eqc(b+104|0,c[f>>2]|0,c[f+4>>2]|0)|0;j=f+4|0;c[j>>2]=(c[j>>2]|0)-k;j=f|0;c[j>>2]=(c[j>>2]|0)+k;j=f+8|0;c[j>>2]=(c[j>>2]|0)+k;if((c[b+104>>2]|0)!=4){g=-3;h=g;i=d;return h|0}else{j=c[f+8>>2]|0;l=c[f+20>>2]|0;Xpc(f)|0;c[f+8>>2]=j;c[f+20>>2]=l;c[b>>2]=11;g=0;h=g;i=d;return h|0}}}while(0);g=-2;h=g;i=d;return h|0}function eqc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=b;b=e;e=f;f=c[h>>2]|0;j=0;while(1){if(j>>>0<e>>>0){k=f>>>0<4>>>0}else{k=0}if(!k){break}if((d[b+j|0]|0)==((f>>>0<2>>>0?0:255)|0)){f=f+1|0}else{if((a[b+j|0]|0)!=0){f=0}else{f=4-f|0}}j=j+1|0}c[h>>2]=f;i=g;return j|0}function fqc(d,f,g,h,j,k){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;l=i;i=i+72|0;m=l|0;n=l+8|0;o=l+40|0;p=d;d=f;f=g;g=h;h=j;j=k;k=0;while(1){if(!(k>>>0<=15>>>0)){break}b[n+(k<<1)>>1]=0;k=k+1|0}q=0;while(1){if(!(q>>>0<f>>>0)){break}r=n+((e[d+(q<<1)>>1]|0)<<1)|0;b[r>>1]=(b[r>>1]|0)+1;q=q+1|0}r=c[h>>2]|0;s=15;while(1){if(!(s>>>0>=1>>>0)){break}if((e[n+(s<<1)>>1]|0|0)!=0){t=12;break}s=s-1|0}if(r>>>0>s>>>0){r=s}if((s|0)==0){a[m|0]=64;a[m+1|0]=1;b[m+2>>1]=0;u=g;v=c[u>>2]|0;c[u>>2]=v+4;u=v;v=m;b[u>>1]=b[v>>1]|0;b[u+2>>1]=b[v+2>>1]|0;v=g;u=c[v>>2]|0;c[v>>2]=u+4;v=u;u=m;b[v>>1]=b[u>>1]|0;b[v+2>>1]=b[u+2>>1]|0;c[h>>2]=1;w=0;x=w;i=l;return x|0}u=1;while(1){if(!(u>>>0<s>>>0)){break}if((e[n+(u<<1)>>1]|0|0)!=0){t=22;break}u=u+1|0}if(r>>>0<u>>>0){r=u}v=1;k=1;while(1){if(!(k>>>0<=15>>>0)){break}v=v<<1;v=v-(e[n+(k<<1)>>1]|0)|0;if((v|0)<0){t=30;break}k=k+1|0}if((t|0)==30){w=-1;x=w;i=l;return x|0}do{if((v|0)>0){if((p|0)!=0){if((s|0)==1){break}}w=-1;x=w;i=l;return x|0}}while(0);b[o+2>>1]=0;k=1;while(1){if(!(k>>>0<15>>>0)){break}b[o+(k+1<<1)>>1]=(e[o+(k<<1)>>1]|0)+(e[n+(k<<1)>>1]|0);k=k+1|0}q=0;while(1){if(!(q>>>0<f>>>0)){break}if((e[d+(q<<1)>>1]|0|0)!=0){y=o+((e[d+(q<<1)>>1]|0)<<1)|0;z=b[y>>1]|0;b[y>>1]=z+1;b[j+((z&65535)<<1)>>1]=q}q=q+1|0}o=p;if((o|0)==0){f=j;A=f;B=f;C=19}else if((o|0)==1){B=1071880;B=B-514|0;A=1071816;A=A-514|0;C=256}else{B=1072008;A=1071944;C=-1}o=0;q=0;k=u;f=c[g>>2]|0;z=r;y=0;D=-1;E=1<<r;F=E-1|0;if((p|0)==1){if(!(E>>>0>=852>>>0)){t=53}}else{t=53}do{if((t|0)==53){if((p|0)==2){if(E>>>0>=592>>>0){break}}a:while(1){a[m+1|0]=k-y;if((e[j+(q<<1)>>1]|0|0)<(C|0)){a[m|0]=0;b[m+2>>1]=b[j+(q<<1)>>1]|0}else{if((e[j+(q<<1)>>1]|0|0)>(C|0)){a[m|0]=b[A+((e[j+(q<<1)>>1]|0)<<1)>>1];b[m+2>>1]=b[B+((e[j+(q<<1)>>1]|0)<<1)>>1]|0}else{a[m|0]=96;b[m+2>>1]=0}}G=1<<k-y;H=1<<z;u=H;do{H=H-G|0;I=f+((o>>>(y>>>0))+H<<2)|0;J=m;b[I>>1]=b[J>>1]|0;b[I+2>>1]=b[J+2>>1]|0;}while((H|0)!=0);G=1<<k-1;while(1){if((o&G|0)==0){break}G=G>>>1}if((G|0)!=0){o=o&G-1;o=o+G|0}else{o=0}q=q+1|0;H=n+(k<<1)|0;J=(b[H>>1]|0)-1&65535;b[H>>1]=J;if((J&65535|0)==0){if((k|0)==(s|0)){break}k=e[d+((e[j+(q<<1)>>1]|0)<<1)>>1]|0}do{if(k>>>0>r>>>0){if((o&F|0)==(D|0)){break}if((y|0)==0){y=r}f=f+(u<<2)|0;z=k-y|0;v=1<<z;while(1){if(!((z+y|0)>>>0<s>>>0)){break}v=v-(e[n+(z+y<<1)>>1]|0)|0;if((v|0)<=0){t=83;break}z=z+1|0;v=v<<1}if((t|0)==83){t=0}E=E+(1<<z)|0;if((p|0)==1){if(E>>>0>=852>>>0){t=89;break a}}if((p|0)==2){if(E>>>0>=592>>>0){t=89;break a}}D=o&F;a[(c[g>>2]|0)+(D<<2)|0]=z;a[(c[g>>2]|0)+(D<<2)+1|0]=r;b[(c[g>>2]|0)+(D<<2)+2>>1]=(f-(c[g>>2]|0)|0)/4|0}}while(0)}if((t|0)==89){w=1;x=w;i=l;return x|0}a[m|0]=64;a[m+1|0]=k-y;b[m+2>>1]=0;while(1){if((o|0)==0){break}do{if((y|0)!=0){if((o&F|0)==(D|0)){break}y=0;k=r;f=c[g>>2]|0;a[m+1|0]=k}}while(0);J=f+(o>>>(y>>>0)<<2)|0;H=m;b[J>>1]=b[H>>1]|0;b[J+2>>1]=b[H+2>>1]|0;G=1<<k-1;while(1){if((o&G|0)==0){break}G=G>>>1}if((G|0)!=0){o=o&G-1;o=o+G|0}else{o=0}}H=g;c[H>>2]=(c[H>>2]|0)+(E<<2);c[h>>2]=r;w=0;x=w;i=l;return x|0}}while(0);w=1;x=w;i=l;return x|0}function gqc(a){a=a|0;var d=0,e=0;d=i;e=a;hqc();c[e+2840>>2]=e+148;c[e+2848>>2]=558184;c[e+2852>>2]=e+2440;c[e+2860>>2]=558328;c[e+2864>>2]=e+2684;c[e+2872>>2]=558352;b[e+5816>>1]=0;c[e+5820>>2]=0;c[e+5812>>2]=8;iqc(e);i=d;return}function hqc(){return}function iqc(a){a=a|0;var d=0,e=0;d=i;e=a;a=0;while(1){if((a|0)>=286){break}b[e+148+(a<<2)>>1]=0;a=a+1|0}a=0;while(1){if((a|0)>=30){break}b[e+2440+(a<<2)>>1]=0;a=a+1|0}a=0;while(1){if((a|0)>=19){break}b[e+2684+(a<<2)>>1]=0;a=a+1|0}b[e+1172>>1]=1;c[e+5804>>2]=0;c[e+5800>>2]=0;c[e+5808>>2]=0;c[e+5792>>2]=0;i=d;return}function jqc(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=i;k=d;d=f;f=g;g=h;h=3;if((c[k+5820>>2]|0)>(16-h|0)){l=g|0;m=k+5816|0;b[m>>1]=e[m>>1]|0|(l&65535)<<c[k+5820>>2];m=(e[k+5816>>1]|0)&255;n=k+20|0;o=c[n>>2]|0;c[n>>2]=o+1;a[(c[k+8>>2]|0)+o|0]=m;m=(e[k+5816>>1]|0)>>8&255;o=k+20|0;n=c[o>>2]|0;c[o>>2]=n+1;a[(c[k+8>>2]|0)+n|0]=m;b[k+5816>>1]=(l&65535)>>16-(c[k+5820>>2]|0);l=k+5820|0;c[l>>2]=(c[l>>2]|0)+(h-16);p=k;q=d;r=f;kqc(p,q,r,1);i=j;return}else{l=k+5816|0;b[l>>1]=e[l>>1]|0|(g&65535)<<c[k+5820>>2];g=k+5820|0;c[g>>2]=(c[g>>2]|0)+h;p=k;q=d;r=f;kqc(p,q,r,1);i=j;return}}function kqc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=b;b=d;d=e;tqc(h);c[h+5812>>2]=8;if((f|0)!=0){f=h+20|0;e=c[f>>2]|0;c[f>>2]=e+1;a[(c[h+8>>2]|0)+e|0]=d&65535&255;e=h+20|0;f=c[e>>2]|0;c[e>>2]=f+1;a[(c[h+8>>2]|0)+f|0]=(d&65535)>>8;f=h+20|0;e=c[f>>2]|0;c[f>>2]=e+1;a[(c[h+8>>2]|0)+e|0]=~d&65535&255;e=h+20|0;f=c[e>>2]|0;c[e>>2]=f+1;a[(c[h+8>>2]|0)+f|0]=(~d&65535)>>8}while(1){f=d;d=f-1|0;if((f|0)==0){break}f=b;b=f+1|0;e=a[f]|0;f=h+20|0;j=c[f>>2]|0;c[f>>2]=j+1;a[(c[h+8>>2]|0)+j|0]=e}i=g;return}function lqc(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=d;d=3;if((c[g+5820>>2]|0)>(16-d|0)){h=2;j=g+5816|0;b[j>>1]=e[j>>1]|0|(h&65535)<<c[g+5820>>2];j=(e[g+5816>>1]|0)&255;k=g+20|0;l=c[k>>2]|0;c[k>>2]=l+1;a[(c[g+8>>2]|0)+l|0]=j;j=(e[g+5816>>1]|0)>>8&255;l=g+20|0;k=c[l>>2]|0;c[l>>2]=k+1;a[(c[g+8>>2]|0)+k|0]=j;b[g+5816>>1]=(h&65535)>>16-(c[g+5820>>2]|0);h=g+5820|0;c[h>>2]=(c[h>>2]|0)+(d-16)}else{h=g+5816|0;b[h>>1]=e[h>>1]|0|2<<c[g+5820>>2];h=g+5820|0;c[h>>2]=(c[h>>2]|0)+d}d=e[279029]|0;if((c[g+5820>>2]|0)>(16-d|0)){h=e[279028]|0;j=g+5816|0;b[j>>1]=e[j>>1]|0|(h&65535)<<c[g+5820>>2];j=(e[g+5816>>1]|0)&255;k=g+20|0;l=c[k>>2]|0;c[k>>2]=l+1;a[(c[g+8>>2]|0)+l|0]=j;j=(e[g+5816>>1]|0)>>8&255;l=g+20|0;k=c[l>>2]|0;c[l>>2]=k+1;a[(c[g+8>>2]|0)+k|0]=j;b[g+5816>>1]=(h&65535)>>16-(c[g+5820>>2]|0);h=g+5820|0;c[h>>2]=(c[h>>2]|0)+(d-16)}else{h=g+5816|0;b[h>>1]=e[h>>1]|0|(e[279028]|0)<<c[g+5820>>2];h=g+5820|0;c[h>>2]=(c[h>>2]|0)+d}mqc(g);if(((c[g+5812>>2]|0)+11-(c[g+5820>>2]|0)|0)>=9){m=g;n=m+5812|0;c[n>>2]=7;i=f;return}d=3;if((c[g+5820>>2]|0)>(16-d|0)){h=2;j=g+5816|0;b[j>>1]=e[j>>1]|0|(h&65535)<<c[g+5820>>2];j=(e[g+5816>>1]|0)&255;k=g+20|0;l=c[k>>2]|0;c[k>>2]=l+1;a[(c[g+8>>2]|0)+l|0]=j;j=(e[g+5816>>1]|0)>>8&255;l=g+20|0;k=c[l>>2]|0;c[l>>2]=k+1;a[(c[g+8>>2]|0)+k|0]=j;b[g+5816>>1]=(h&65535)>>16-(c[g+5820>>2]|0);h=g+5820|0;c[h>>2]=(c[h>>2]|0)+(d-16)}else{h=g+5816|0;b[h>>1]=e[h>>1]|0|2<<c[g+5820>>2];h=g+5820|0;c[h>>2]=(c[h>>2]|0)+d}d=e[279029]|0;if((c[g+5820>>2]|0)>(16-d|0)){h=e[279028]|0;j=g+5816|0;b[j>>1]=e[j>>1]|0|(h&65535)<<c[g+5820>>2];j=(e[g+5816>>1]|0)&255;k=g+20|0;l=c[k>>2]|0;c[k>>2]=l+1;a[(c[g+8>>2]|0)+l|0]=j;j=(e[g+5816>>1]|0)>>8&255;l=g+20|0;k=c[l>>2]|0;c[l>>2]=k+1;a[(c[g+8>>2]|0)+k|0]=j;b[g+5816>>1]=(h&65535)>>16-(c[g+5820>>2]|0);h=g+5820|0;c[h>>2]=(c[h>>2]|0)+(d-16)}else{h=g+5816|0;b[h>>1]=e[h>>1]|0|(e[279028]|0)<<c[g+5820>>2];h=g+5820|0;c[h>>2]=(c[h>>2]|0)+d}mqc(g);m=g;n=m+5812|0;c[n>>2]=7;i=f;return}function mqc(d){d=d|0;var f=0,g=0,h=0,j=0;f=i;g=d;if((c[g+5820>>2]|0)==16){d=(e[g+5816>>1]|0)&255;h=g+20|0;j=c[h>>2]|0;c[h>>2]=j+1;a[(c[g+8>>2]|0)+j|0]=d;d=(e[g+5816>>1]|0)>>8&255;j=g+20|0;h=c[j>>2]|0;c[j>>2]=h+1;a[(c[g+8>>2]|0)+h|0]=d;b[g+5816>>1]=0;c[g+5820>>2]=0;i=f;return}if((c[g+5820>>2]|0)>=8){d=b[g+5816>>1]&255;h=g+20|0;j=c[h>>2]|0;c[h>>2]=j+1;a[(c[g+8>>2]|0)+j|0]=d;d=g+5816|0;b[d>>1]=(e[d>>1]|0)>>8;d=g+5820|0;c[d>>2]=(c[d>>2]|0)-8}i=f;return}function nqc(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;k=d;d=f;f=g;g=h;h=0;if((c[k+132>>2]|0)>0){if((c[(c[k>>2]|0)+44>>2]|0)==2){l=oqc(k)|0;c[(c[k>>2]|0)+44>>2]=l}pqc(k,k+2840|0);pqc(k,k+2852|0);h=qqc(k)|0;m=((c[k+5800>>2]|0)+10|0)>>>3;n=((c[k+5804>>2]|0)+10|0)>>>3;if(n>>>0<=m>>>0){m=n}}else{l=f+5|0;n=l;m=l}do{if((f+4|0)>>>0<=m>>>0){if((d|0)==0){o=11;break}jqc(k,d,f,g)}else{o=11}}while(0);if((o|0)==11){do{if((c[k+136>>2]|0)==4){o=13}else{if((n|0)==(m|0)){o=13;break}f=3;if((c[k+5820>>2]|0)>(16-f|0)){d=g+4|0;l=k+5816|0;b[l>>1]=e[l>>1]|0|(d&65535)<<c[k+5820>>2];l=(e[k+5816>>1]|0)&255;p=k+20|0;q=c[p>>2]|0;c[p>>2]=q+1;a[(c[k+8>>2]|0)+q|0]=l;l=(e[k+5816>>1]|0)>>8&255;q=k+20|0;p=c[q>>2]|0;c[q>>2]=p+1;a[(c[k+8>>2]|0)+p|0]=l;b[k+5816>>1]=(d&65535)>>16-(c[k+5820>>2]|0);d=k+5820|0;c[d>>2]=(c[d>>2]|0)+(f-16)}else{d=k+5816|0;b[d>>1]=e[d>>1]|0|(g+4&65535)<<c[k+5820>>2];d=k+5820|0;c[d>>2]=(c[d>>2]|0)+f}sqc(k,(c[k+2844>>2]|0)+1|0,(c[k+2856>>2]|0)+1|0,h+1|0);rqc(k,k+148|0,k+2440|0)}}while(0);if((o|0)==13){o=3;if((c[k+5820>>2]|0)>(16-o|0)){h=g+2|0;m=k+5816|0;b[m>>1]=e[m>>1]|0|(h&65535)<<c[k+5820>>2];m=(e[k+5816>>1]|0)&255;n=k+20|0;f=c[n>>2]|0;c[n>>2]=f+1;a[(c[k+8>>2]|0)+f|0]=m;m=(e[k+5816>>1]|0)>>8&255;f=k+20|0;n=c[f>>2]|0;c[f>>2]=n+1;a[(c[k+8>>2]|0)+n|0]=m;b[k+5816>>1]=(h&65535)>>16-(c[k+5820>>2]|0);h=k+5820|0;c[h>>2]=(c[h>>2]|0)+(o-16)}else{h=k+5816|0;b[h>>1]=e[h>>1]|0|(g+2&65535)<<c[k+5820>>2];h=k+5820|0;c[h>>2]=(c[h>>2]|0)+o}rqc(k,557032,558208)}}iqc(k);if((g|0)==0){i=j;return}tqc(k);i=j;return}function oqc(a){a=a|0;var b=0,c=0,d=0,f=0,g=0,h=0;b=i;c=a;a=-201342849;d=0;while(1){if((d|0)>31){break}if((a&1|0)!=0){if((e[c+148+(d<<2)>>1]|0|0)!=0){f=5;break}}d=d+1|0;a=a>>>1}if((f|0)==5){g=0;h=g;i=b;return h|0}do{if((e[c+184>>1]|0|0)==0){if((e[c+188>>1]|0|0)!=0){break}if((e[c+200>>1]|0|0)!=0){break}d=32;while(1){if((d|0)>=256){f=18;break}if((e[c+148+(d<<2)>>1]|0|0)!=0){f=15;break}d=d+1|0}if((f|0)==15){g=1;h=g;i=b;return h|0}else if((f|0)==18){g=0;h=g;i=b;return h|0}}}while(0);g=1;h=g;i=b;return h|0}function pqc(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=f;f=g;g=c[f>>2]|0;k=c[c[f+8>>2]>>2]|0;l=c[(c[f+8>>2]|0)+12>>2]|0;m=-1;c[j+5200>>2]=0;c[j+5204>>2]=573;n=0;while(1){if((n|0)>=(l|0)){break}if((e[g+(n<<2)>>1]|0|0)!=0){o=n;m=o;p=j+5200|0;q=(c[p>>2]|0)+1|0;c[p>>2]=q;c[j+2908+(q<<2)>>2]=o;a[j+5208+n|0]=0}else{b[g+(n<<2)+2>>1]=0}n=n+1|0}while(1){if((c[j+5200>>2]|0)>=2){break}if((m|0)<2){o=m+1|0;m=o;r=o}else{r=0}o=j+5200|0;q=(c[o>>2]|0)+1|0;c[o>>2]=q;c[j+2908+(q<<2)>>2]=r;s=r;b[g+(s<<2)>>1]=1;a[j+5208+s|0]=0;q=j+5800|0;c[q>>2]=(c[q>>2]|0)-1;if((k|0)!=0){q=j+5804|0;c[q>>2]=(c[q>>2]|0)-(e[k+(s<<2)+2>>1]|0)}}c[f+4>>2]=m;n=(c[j+5200>>2]|0)/2|0;while(1){if((n|0)<1){break}wqc(j,g,n);n=n-1|0}s=l;do{n=c[j+2912>>2]|0;l=j+5200|0;k=c[l>>2]|0;c[l>>2]=k-1;c[j+2912>>2]=c[j+2908+(k<<2)>>2];wqc(j,g,1);k=c[j+2912>>2]|0;l=j+5204|0;r=(c[l>>2]|0)-1|0;c[l>>2]=r;c[j+2908+(r<<2)>>2]=n;r=j+5204|0;l=(c[r>>2]|0)-1|0;c[r>>2]=l;c[j+2908+(l<<2)>>2]=k;b[g+(s<<2)>>1]=(e[g+(n<<2)>>1]|0)+(e[g+(k<<2)>>1]|0);if((d[j+5208+n|0]|0|0)>=(d[j+5208+k|0]|0|0)){t=d[j+5208+n|0]|0}else{t=d[j+5208+k|0]|0}a[j+5208+s|0]=t+1;l=s&65535;b[g+(k<<2)+2>>1]=l;b[g+(n<<2)+2>>1]=l;l=s;s=l+1|0;c[j+2912>>2]=l;wqc(j,g,1);}while((c[j+5200>>2]|0)>=2);s=c[j+2912>>2]|0;n=j+5204|0;t=(c[n>>2]|0)-1|0;c[n>>2]=t;c[j+2908+(t<<2)>>2]=s;xqc(j,f);yqc(g,m,j+2876|0);i=h;return}function qqc(a){a=a|0;var b=0,f=0,g=0;b=i;f=a;vqc(f,f+148|0,c[f+2844>>2]|0);vqc(f,f+2440|0,c[f+2856>>2]|0);pqc(f,f+2864|0);a=18;while(1){if((a|0)<3){break}if((e[f+2684+((d[1904920+a|0]|0)<<2)+2>>1]|0|0)!=0){g=4;break}a=a-1|0}g=f+5800|0;c[g>>2]=(c[g>>2]|0)+(((a+1|0)*3|0)+14);i=b;return a|0}function rqc(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=i;k=f;f=g;g=h;h=0;if((c[k+5792>>2]|0)!=0){do{l=e[(c[k+5796>>2]|0)+(h<<1)>>1]|0;m=h;h=m+1|0;n=d[(c[k+5784>>2]|0)+m|0]|0;if((l|0)==0){m=e[f+(n<<2)+2>>1]|0;if((c[k+5820>>2]|0)>(16-m|0)){o=e[f+(n<<2)>>1]|0;p=k+5816|0;b[p>>1]=e[p>>1]|0|(o&65535)<<c[k+5820>>2];p=(e[k+5816>>1]|0)&255;q=k+20|0;r=c[q>>2]|0;c[q>>2]=r+1;a[(c[k+8>>2]|0)+r|0]=p;p=(e[k+5816>>1]|0)>>8&255;r=k+20|0;q=c[r>>2]|0;c[r>>2]=q+1;a[(c[k+8>>2]|0)+q|0]=p;b[k+5816>>1]=(o&65535)>>16-(c[k+5820>>2]|0);o=k+5820|0;c[o>>2]=(c[o>>2]|0)+(m-16)}else{o=k+5816|0;b[o>>1]=e[o>>1]|0|(e[f+(n<<2)>>1]|0)<<c[k+5820>>2];o=k+5820|0;c[o>>2]=(c[o>>2]|0)+m}}else{m=d[2644672+n|0]|0;o=e[f+(m+257<<2)+2>>1]|0;if((c[k+5820>>2]|0)>(16-o|0)){p=e[f+(m+257<<2)>>1]|0;q=k+5816|0;b[q>>1]=e[q>>1]|0|(p&65535)<<c[k+5820>>2];q=(e[k+5816>>1]|0)&255;r=k+20|0;s=c[r>>2]|0;c[r>>2]=s+1;a[(c[k+8>>2]|0)+s|0]=q;q=(e[k+5816>>1]|0)>>8&255;s=k+20|0;r=c[s>>2]|0;c[s>>2]=r+1;a[(c[k+8>>2]|0)+r|0]=q;b[k+5816>>1]=(p&65535)>>16-(c[k+5820>>2]|0);p=k+5820|0;c[p>>2]=(c[p>>2]|0)+(o-16)}else{p=k+5816|0;b[p>>1]=e[p>>1]|0|(e[f+(m+257<<2)>>1]|0)<<c[k+5820>>2];p=k+5820|0;c[p>>2]=(c[p>>2]|0)+o}o=c[1489256+(m<<2)>>2]|0;if((o|0)!=0){n=n-(c[1955928+(m<<2)>>2]|0)|0;p=o;if((c[k+5820>>2]|0)>(16-p|0)){q=n;r=k+5816|0;b[r>>1]=e[r>>1]|0|(q&65535)<<c[k+5820>>2];r=(e[k+5816>>1]|0)&255;s=k+20|0;t=c[s>>2]|0;c[s>>2]=t+1;a[(c[k+8>>2]|0)+t|0]=r;r=(e[k+5816>>1]|0)>>8&255;t=k+20|0;s=c[t>>2]|0;c[t>>2]=s+1;a[(c[k+8>>2]|0)+s|0]=r;b[k+5816>>1]=(q&65535)>>16-(c[k+5820>>2]|0);q=k+5820|0;c[q>>2]=(c[q>>2]|0)+(p-16)}else{q=k+5816|0;b[q>>1]=e[q>>1]|0|(n&65535)<<c[k+5820>>2];n=k+5820|0;c[n>>2]=(c[n>>2]|0)+p}}l=l-1|0;if(l>>>0<256>>>0){u=d[2644928+l|0]|0}else{u=d[(l>>>7)+2645184|0]|0}m=u;p=e[g+(m<<2)+2>>1]|0;if((c[k+5820>>2]|0)>(16-p|0)){n=e[g+(m<<2)>>1]|0;q=k+5816|0;b[q>>1]=e[q>>1]|0|(n&65535)<<c[k+5820>>2];q=(e[k+5816>>1]|0)&255;r=k+20|0;s=c[r>>2]|0;c[r>>2]=s+1;a[(c[k+8>>2]|0)+s|0]=q;q=(e[k+5816>>1]|0)>>8&255;s=k+20|0;r=c[s>>2]|0;c[s>>2]=r+1;a[(c[k+8>>2]|0)+r|0]=q;b[k+5816>>1]=(n&65535)>>16-(c[k+5820>>2]|0);n=k+5820|0;c[n>>2]=(c[n>>2]|0)+(p-16)}else{n=k+5816|0;b[n>>1]=e[n>>1]|0|(e[g+(m<<2)>>1]|0)<<c[k+5820>>2];n=k+5820|0;c[n>>2]=(c[n>>2]|0)+p}o=c[1489376+(m<<2)>>2]|0;if((o|0)!=0){l=l-(c[1956432+(m<<2)>>2]|0)|0;m=o;if((c[k+5820>>2]|0)>(16-m|0)){o=l;p=k+5816|0;b[p>>1]=e[p>>1]|0|(o&65535)<<c[k+5820>>2];p=(e[k+5816>>1]|0)&255;n=k+20|0;q=c[n>>2]|0;c[n>>2]=q+1;a[(c[k+8>>2]|0)+q|0]=p;p=(e[k+5816>>1]|0)>>8&255;q=k+20|0;n=c[q>>2]|0;c[q>>2]=n+1;a[(c[k+8>>2]|0)+n|0]=p;b[k+5816>>1]=(o&65535)>>16-(c[k+5820>>2]|0);o=k+5820|0;c[o>>2]=(c[o>>2]|0)+(m-16)}else{o=k+5816|0;b[o>>1]=e[o>>1]|0|(l&65535)<<c[k+5820>>2];l=k+5820|0;c[l>>2]=(c[l>>2]|0)+m}}}}while(h>>>0<(c[k+5792>>2]|0)>>>0)}h=e[f+1026>>1]|0;if((c[k+5820>>2]|0)>(16-h|0)){g=e[f+1024>>1]|0;u=k+5816|0;b[u>>1]=e[u>>1]|0|(g&65535)<<c[k+5820>>2];u=(e[k+5816>>1]|0)&255;m=k+20|0;l=c[m>>2]|0;c[m>>2]=l+1;a[(c[k+8>>2]|0)+l|0]=u;u=(e[k+5816>>1]|0)>>8&255;l=k+20|0;m=c[l>>2]|0;c[l>>2]=m+1;a[(c[k+8>>2]|0)+m|0]=u;b[k+5816>>1]=(g&65535)>>16-(c[k+5820>>2]|0);g=k+5820|0;c[g>>2]=(c[g>>2]|0)+(h-16);v=f;w=v+1024|0;x=w+2|0;y=x;z=b[y>>1]|0;A=z&65535;B=k;C=B+5812|0;c[C>>2]=A;i=j;return}else{g=k+5816|0;b[g>>1]=e[g>>1]|0|(e[f+1024>>1]|0)<<c[k+5820>>2];g=k+5820|0;c[g>>2]=(c[g>>2]|0)+h;v=f;w=v+1024|0;x=w+2|0;y=x;z=b[y>>1]|0;A=z&65535;B=k;C=B+5812|0;c[C>>2]=A;i=j;return}}function sqc(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;l=f;f=g;g=h;h=j;j=5;if((c[l+5820>>2]|0)>(16-j|0)){m=f-257|0;n=l+5816|0;b[n>>1]=e[n>>1]|0|(m&65535)<<c[l+5820>>2];n=(e[l+5816>>1]|0)&255;o=l+20|0;p=c[o>>2]|0;c[o>>2]=p+1;a[(c[l+8>>2]|0)+p|0]=n;n=(e[l+5816>>1]|0)>>8&255;p=l+20|0;o=c[p>>2]|0;c[p>>2]=o+1;a[(c[l+8>>2]|0)+o|0]=n;b[l+5816>>1]=(m&65535)>>16-(c[l+5820>>2]|0);m=l+5820|0;c[m>>2]=(c[m>>2]|0)+(j-16)}else{m=l+5816|0;b[m>>1]=e[m>>1]|0|(f-257&65535)<<c[l+5820>>2];m=l+5820|0;c[m>>2]=(c[m>>2]|0)+j}j=5;if((c[l+5820>>2]|0)>(16-j|0)){m=g-1|0;n=l+5816|0;b[n>>1]=e[n>>1]|0|(m&65535)<<c[l+5820>>2];n=(e[l+5816>>1]|0)&255;o=l+20|0;p=c[o>>2]|0;c[o>>2]=p+1;a[(c[l+8>>2]|0)+p|0]=n;n=(e[l+5816>>1]|0)>>8&255;p=l+20|0;o=c[p>>2]|0;c[p>>2]=o+1;a[(c[l+8>>2]|0)+o|0]=n;b[l+5816>>1]=(m&65535)>>16-(c[l+5820>>2]|0);m=l+5820|0;c[m>>2]=(c[m>>2]|0)+(j-16)}else{m=l+5816|0;b[m>>1]=e[m>>1]|0|(g-1&65535)<<c[l+5820>>2];m=l+5820|0;c[m>>2]=(c[m>>2]|0)+j}j=4;if((c[l+5820>>2]|0)>(16-j|0)){m=h-4|0;n=l+5816|0;b[n>>1]=e[n>>1]|0|(m&65535)<<c[l+5820>>2];n=(e[l+5816>>1]|0)&255;o=l+20|0;p=c[o>>2]|0;c[o>>2]=p+1;a[(c[l+8>>2]|0)+p|0]=n;n=(e[l+5816>>1]|0)>>8&255;p=l+20|0;o=c[p>>2]|0;c[p>>2]=o+1;a[(c[l+8>>2]|0)+o|0]=n;b[l+5816>>1]=(m&65535)>>16-(c[l+5820>>2]|0);m=l+5820|0;c[m>>2]=(c[m>>2]|0)+(j-16)}else{m=l+5816|0;b[m>>1]=e[m>>1]|0|(h-4&65535)<<c[l+5820>>2];m=l+5820|0;c[m>>2]=(c[m>>2]|0)+j}j=0;while(1){if((j|0)>=(h|0)){break}m=3;if((c[l+5820>>2]|0)>(16-m|0)){n=e[l+2684+((d[1904920+j|0]|0)<<2)+2>>1]|0;o=l+5816|0;b[o>>1]=e[o>>1]|0|(n&65535)<<c[l+5820>>2];o=(e[l+5816>>1]|0)&255;p=l+20|0;q=c[p>>2]|0;c[p>>2]=q+1;a[(c[l+8>>2]|0)+q|0]=o;o=(e[l+5816>>1]|0)>>8&255;q=l+20|0;p=c[q>>2]|0;c[q>>2]=p+1;a[(c[l+8>>2]|0)+p|0]=o;b[l+5816>>1]=(n&65535)>>16-(c[l+5820>>2]|0);n=l+5820|0;c[n>>2]=(c[n>>2]|0)+(m-16)}else{n=l+5816|0;b[n>>1]=e[n>>1]|0|(e[l+2684+((d[1904920+j|0]|0)<<2)+2>>1]|0)<<c[l+5820>>2];n=l+5820|0;c[n>>2]=(c[n>>2]|0)+m}j=j+1|0}uqc(l,l+148|0,f-1|0);uqc(l,l+2440|0,g-1|0);i=k;return}function tqc(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=d;if((c[g+5820>>2]|0)>8){d=(e[g+5816>>1]|0)&255;h=g+20|0;j=c[h>>2]|0;c[h>>2]=j+1;a[(c[g+8>>2]|0)+j|0]=d;d=(e[g+5816>>1]|0)>>8&255;j=g+20|0;h=c[j>>2]|0;c[j>>2]=h+1;a[(c[g+8>>2]|0)+h|0]=d;k=g;l=k+5816|0;b[l>>1]=0;m=g;n=m+5820|0;c[n>>2]=0;i=f;return}if((c[g+5820>>2]|0)>0){d=b[g+5816>>1]&255;h=g+20|0;j=c[h>>2]|0;c[h>>2]=j+1;a[(c[g+8>>2]|0)+j|0]=d}k=g;l=k+5816|0;b[l>>1]=0;m=g;n=m+5820|0;c[n>>2]=0;i=f;return}function uqc(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;j=d;d=f;f=g;g=-1;k=e[d+2>>1]|0;l=0;m=7;n=4;if((k|0)==0){m=138;n=3}o=0;while(1){if((o|0)>(f|0)){break}p=k;k=e[d+(o+1<<2)+2>>1]|0;q=l+1|0;l=q;do{if((q|0)<(m|0)){if((p|0)!=(k|0)){r=8;break}}else{r=8}}while(0);if((r|0)==8){r=0;if((l|0)<(n|0)){do{q=e[j+2684+(p<<2)+2>>1]|0;if((c[j+5820>>2]|0)>(16-q|0)){s=e[j+2684+(p<<2)>>1]|0;t=j+5816|0;b[t>>1]=e[t>>1]|0|(s&65535)<<c[j+5820>>2];t=(e[j+5816>>1]|0)&255;u=j+20|0;v=c[u>>2]|0;c[u>>2]=v+1;a[(c[j+8>>2]|0)+v|0]=t;t=(e[j+5816>>1]|0)>>8&255;v=j+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[j+8>>2]|0)+u|0]=t;b[j+5816>>1]=(s&65535)>>16-(c[j+5820>>2]|0);s=j+5820|0;c[s>>2]=(c[s>>2]|0)+(q-16)}else{s=j+5816|0;b[s>>1]=e[s>>1]|0|(e[j+2684+(p<<2)>>1]|0)<<c[j+5820>>2];s=j+5820|0;c[s>>2]=(c[s>>2]|0)+q}q=l-1|0;l=q;}while((q|0)!=0)}else{if((p|0)!=0){if((p|0)!=(g|0)){q=e[j+2684+(p<<2)+2>>1]|0;if((c[j+5820>>2]|0)>(16-q|0)){s=e[j+2684+(p<<2)>>1]|0;t=j+5816|0;b[t>>1]=e[t>>1]|0|(s&65535)<<c[j+5820>>2];t=(e[j+5816>>1]|0)&255;u=j+20|0;v=c[u>>2]|0;c[u>>2]=v+1;a[(c[j+8>>2]|0)+v|0]=t;t=(e[j+5816>>1]|0)>>8&255;v=j+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[j+8>>2]|0)+u|0]=t;b[j+5816>>1]=(s&65535)>>16-(c[j+5820>>2]|0);s=j+5820|0;c[s>>2]=(c[s>>2]|0)+(q-16)}else{s=j+5816|0;b[s>>1]=e[s>>1]|0|(e[j+2684+(p<<2)>>1]|0)<<c[j+5820>>2];s=j+5820|0;c[s>>2]=(c[s>>2]|0)+q}l=l-1|0}q=e[j+2750>>1]|0;if((c[j+5820>>2]|0)>(16-q|0)){s=e[j+2748>>1]|0;t=j+5816|0;b[t>>1]=e[t>>1]|0|(s&65535)<<c[j+5820>>2];t=(e[j+5816>>1]|0)&255;u=j+20|0;v=c[u>>2]|0;c[u>>2]=v+1;a[(c[j+8>>2]|0)+v|0]=t;t=(e[j+5816>>1]|0)>>8&255;v=j+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[j+8>>2]|0)+u|0]=t;b[j+5816>>1]=(s&65535)>>16-(c[j+5820>>2]|0);s=j+5820|0;c[s>>2]=(c[s>>2]|0)+(q-16)}else{s=j+5816|0;b[s>>1]=e[s>>1]|0|(e[j+2748>>1]|0)<<c[j+5820>>2];s=j+5820|0;c[s>>2]=(c[s>>2]|0)+q}q=2;if((c[j+5820>>2]|0)>(16-q|0)){s=l-3|0;t=j+5816|0;b[t>>1]=e[t>>1]|0|(s&65535)<<c[j+5820>>2];t=(e[j+5816>>1]|0)&255;u=j+20|0;v=c[u>>2]|0;c[u>>2]=v+1;a[(c[j+8>>2]|0)+v|0]=t;t=(e[j+5816>>1]|0)>>8&255;v=j+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[j+8>>2]|0)+u|0]=t;b[j+5816>>1]=(s&65535)>>16-(c[j+5820>>2]|0);s=j+5820|0;c[s>>2]=(c[s>>2]|0)+(q-16)}else{s=j+5816|0;b[s>>1]=e[s>>1]|0|(l-3&65535)<<c[j+5820>>2];s=j+5820|0;c[s>>2]=(c[s>>2]|0)+q}}else{if((l|0)<=10){q=e[j+2754>>1]|0;if((c[j+5820>>2]|0)>(16-q|0)){s=e[j+2752>>1]|0;t=j+5816|0;b[t>>1]=e[t>>1]|0|(s&65535)<<c[j+5820>>2];t=(e[j+5816>>1]|0)&255;u=j+20|0;v=c[u>>2]|0;c[u>>2]=v+1;a[(c[j+8>>2]|0)+v|0]=t;t=(e[j+5816>>1]|0)>>8&255;v=j+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[j+8>>2]|0)+u|0]=t;b[j+5816>>1]=(s&65535)>>16-(c[j+5820>>2]|0);s=j+5820|0;c[s>>2]=(c[s>>2]|0)+(q-16)}else{s=j+5816|0;b[s>>1]=e[s>>1]|0|(e[j+2752>>1]|0)<<c[j+5820>>2];s=j+5820|0;c[s>>2]=(c[s>>2]|0)+q}q=3;if((c[j+5820>>2]|0)>(16-q|0)){s=l-3|0;t=j+5816|0;b[t>>1]=e[t>>1]|0|(s&65535)<<c[j+5820>>2];t=(e[j+5816>>1]|0)&255;u=j+20|0;v=c[u>>2]|0;c[u>>2]=v+1;a[(c[j+8>>2]|0)+v|0]=t;t=(e[j+5816>>1]|0)>>8&255;v=j+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[j+8>>2]|0)+u|0]=t;b[j+5816>>1]=(s&65535)>>16-(c[j+5820>>2]|0);s=j+5820|0;c[s>>2]=(c[s>>2]|0)+(q-16)}else{s=j+5816|0;b[s>>1]=e[s>>1]|0|(l-3&65535)<<c[j+5820>>2];s=j+5820|0;c[s>>2]=(c[s>>2]|0)+q}}else{q=e[j+2758>>1]|0;if((c[j+5820>>2]|0)>(16-q|0)){s=e[j+2756>>1]|0;t=j+5816|0;b[t>>1]=e[t>>1]|0|(s&65535)<<c[j+5820>>2];t=(e[j+5816>>1]|0)&255;u=j+20|0;v=c[u>>2]|0;c[u>>2]=v+1;a[(c[j+8>>2]|0)+v|0]=t;t=(e[j+5816>>1]|0)>>8&255;v=j+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[j+8>>2]|0)+u|0]=t;b[j+5816>>1]=(s&65535)>>16-(c[j+5820>>2]|0);s=j+5820|0;c[s>>2]=(c[s>>2]|0)+(q-16)}else{s=j+5816|0;b[s>>1]=e[s>>1]|0|(e[j+2756>>1]|0)<<c[j+5820>>2];s=j+5820|0;c[s>>2]=(c[s>>2]|0)+q}q=7;if((c[j+5820>>2]|0)>(16-q|0)){s=l-11|0;t=j+5816|0;b[t>>1]=e[t>>1]|0|(s&65535)<<c[j+5820>>2];t=(e[j+5816>>1]|0)&255;u=j+20|0;v=c[u>>2]|0;c[u>>2]=v+1;a[(c[j+8>>2]|0)+v|0]=t;t=(e[j+5816>>1]|0)>>8&255;v=j+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[j+8>>2]|0)+u|0]=t;b[j+5816>>1]=(s&65535)>>16-(c[j+5820>>2]|0);s=j+5820|0;c[s>>2]=(c[s>>2]|0)+(q-16)}else{s=j+5816|0;b[s>>1]=e[s>>1]|0|(l-11&65535)<<c[j+5820>>2];s=j+5820|0;c[s>>2]=(c[s>>2]|0)+q}}}}l=0;g=p;if((k|0)==0){m=138;n=3}else{if((p|0)==(k|0)){m=6;n=3}else{m=7;n=4}}}o=o+1|0}i=h;return}function vqc(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=a;a=c;c=d;d=-1;h=e[a+2>>1]|0;j=0;k=7;l=4;if((h|0)==0){k=138;l=3}b[a+(c+1<<2)+2>>1]=-1;m=0;while(1){if((m|0)>(c|0)){break}n=h;h=e[a+(m+1<<2)+2>>1]|0;o=j+1|0;j=o;do{if((o|0)<(k|0)){if((n|0)!=(h|0)){p=8;break}}else{p=8}}while(0);if((p|0)==8){p=0;if((j|0)<(l|0)){o=g+2684+(n<<2)|0;b[o>>1]=(e[o>>1]|0)+j}else{if((n|0)!=0){if((n|0)!=(d|0)){o=g+2684+(n<<2)|0;b[o>>1]=(b[o>>1]|0)+1}o=g+2748|0;b[o>>1]=(b[o>>1]|0)+1}else{if((j|0)<=10){o=g+2752|0;b[o>>1]=(b[o>>1]|0)+1}else{o=g+2756|0;b[o>>1]=(b[o>>1]|0)+1}}}j=0;d=n;if((h|0)==0){k=138;l=3}else{if((n|0)==(h|0)){k=6;l=3}else{k=7;l=4}}}m=m+1|0}i=f;return}function wqc(a,b,f){a=a|0;b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=a;a=b;b=f;f=c[h+2908+(b<<2)>>2]|0;j=b<<1;while(1){if((j|0)>(c[h+5200>>2]|0)){k=13;break}do{if((j|0)<(c[h+5200>>2]|0)){if((e[a+(c[h+2908+(j+1<<2)>>2]<<2)>>1]|0|0)>=(e[a+(c[h+2908+(j<<2)>>2]<<2)>>1]|0|0)){if((e[a+(c[h+2908+(j+1<<2)>>2]<<2)>>1]|0|0)!=(e[a+(c[h+2908+(j<<2)>>2]<<2)>>1]|0|0)){break}if((d[h+5208+(c[h+2908+(j+1<<2)>>2]|0)|0]|0|0)>(d[h+5208+(c[h+2908+(j<<2)>>2]|0)|0]|0|0)){break}}j=j+1|0}}while(0);if((e[a+(f<<2)>>1]|0|0)<(e[a+(c[h+2908+(j<<2)>>2]<<2)>>1]|0|0)){break}if((e[a+(f<<2)>>1]|0|0)==(e[a+(c[h+2908+(j<<2)>>2]<<2)>>1]|0|0)){if((d[h+5208+f|0]|0|0)<=(d[h+5208+(c[h+2908+(j<<2)>>2]|0)|0]|0|0)){break}}c[h+2908+(b<<2)>>2]=c[h+2908+(j<<2)>>2];b=j;j=j<<1}if((k|0)==13){l=f;m=b;n=h;o=n+2908|0;p=o+(m<<2)|0;c[p>>2]=l;i=g;return}l=f;m=b;n=h;o=n+2908|0;p=o+(m<<2)|0;c[p>>2]=l;i=g;return}function xqc(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=a;a=d;d=c[a>>2]|0;h=c[a+4>>2]|0;j=c[c[a+8>>2]>>2]|0;k=c[(c[a+8>>2]|0)+4>>2]|0;l=c[(c[a+8>>2]|0)+8>>2]|0;m=c[(c[a+8>>2]|0)+16>>2]|0;a=0;n=0;while(1){if((n|0)>15){break}b[g+2876+(n<<1)>>1]=0;n=n+1|0}b[d+(c[g+2908+(c[g+5204>>2]<<2)>>2]<<2)+2>>1]=0;o=(c[g+5204>>2]|0)+1|0;while(1){if((o|0)>=573){break}p=c[g+2908+(o<<2)>>2]|0;n=(e[d+((e[d+(p<<2)+2>>1]|0)<<2)+2>>1]|0)+1|0;if((n|0)>(m|0)){n=m;a=a+1|0}b[d+(p<<2)+2>>1]=n;if((p|0)<=(h|0)){q=g+2876+(n<<1)|0;b[q>>1]=(b[q>>1]|0)+1;q=0;if((p|0)>=(l|0)){q=c[k+(p-l<<2)>>2]|0}r=b[d+(p<<2)>>1]|0;s=ca(r&65535,n+q|0)|0;t=g+5800|0;c[t>>2]=(c[t>>2]|0)+s;if((j|0)!=0){s=ca(r&65535,(e[j+(p<<2)+2>>1]|0)+q|0)|0;q=g+5804|0;c[q>>2]=(c[q>>2]|0)+s}}o=o+1|0}if((a|0)==0){i=f;return}do{n=m-1|0;while(1){if((e[g+2876+(n<<1)>>1]|0|0)!=0){break}n=n-1|0}j=g+2876+(n<<1)|0;b[j>>1]=(b[j>>1]|0)-1;j=g+2876+(n+1<<1)|0;b[j>>1]=(e[j>>1]|0)+2;j=g+2876+(m<<1)|0;b[j>>1]=(b[j>>1]|0)-1;a=a-2|0;}while((a|0)>0);n=m;while(1){if((n|0)==0){break}p=e[g+2876+(n<<1)>>1]|0;while(1){if((p|0)==0){break}m=o-1|0;o=m;a=c[g+2908+(m<<2)>>2]|0;if((a|0)>(h|0)){continue}if((e[d+(a<<2)+2>>1]|0|0)!=(n|0)){m=ca(n-(e[d+(a<<2)+2>>1]|0)|0,e[d+(a<<2)>>1]|0)|0;j=g+5800|0;c[j>>2]=(c[j>>2]|0)+m;b[d+(a<<2)+2>>1]=n}p=p-1|0}n=n-1|0}i=f;return}function yqc(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+32|0;g=f|0;h=a;a=c;c=d;d=0;j=1;while(1){if((j|0)>15){break}k=(d&65535)+(e[c+(j-1<<1)>>1]|0)<<1&65535;d=k;b[g+(j<<1)>>1]=k;j=j+1|0}j=0;while(1){if((j|0)>(a|0)){break}d=e[h+(j<<2)+2>>1]|0;if((d|0)!=0){c=g+(d<<1)|0;k=b[c>>1]|0;b[c>>1]=k+1;b[h+(j<<2)>>1]=zqc(k&65535,d)|0}j=j+1|0}i=f;return}function zqc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;d=a;a=b;b=0;do{b=b|d&1;d=d>>>1;b=b<<1;e=a-1|0;a=e;}while((e|0)>0);i=c;return b>>>1|0}function Aqc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+56|0;g=f|0;h=b;b=e;c[g>>2]=d;c[g+4>>2]=b;if((c[g+4>>2]|0)!=(b|0)){j=-5;k=j;i=f;return k|0}c[g+12>>2]=a;c[g+16>>2]=c[h>>2];if((c[g+16>>2]|0)!=(c[h>>2]|0)){j=-5;k=j;i=f;return k|0}c[g+32>>2]=0;c[g+36>>2]=0;a=_pc(g,2256216,56)|0;if((a|0)!=0){j=a;k=j;i=f;return k|0}a=$pc(g,4)|0;if((a|0)==1){c[h>>2]=c[g+20>>2];a=cqc(g)|0;j=a;k=j;i=f;return k|0}cqc(g)|0;do{if((a|0)!=2){if((a|0)==-5){if((c[g+4>>2]|0)==0){break}}j=a;k=j;i=f;return k|0}}while(0);j=-3;k=j;i=f;return k|0}function Bqc(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=b;b=c;if((a|0)!=0){e=e+(b-b)|0}a=Pqc(ca(e,b)|0)|0;i=d;return a|0}function Cqc(a,b){a=a|0;b=b|0;a=i;Qqc(b);i=a;return}function Dqc(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=a;a=b;b=c;c=f>>>16&65535;f=f&65535;if((b|0)==1){f=f+(d[a|0]|0)|0;if(f>>>0>=65521>>>0){f=f-65521|0}c=c+f|0;if(c>>>0>=65521>>>0){c=c-65521|0}g=f|c<<16;h=g;i=e;return h|0}if((a|0)==0){g=1;h=g;i=e;return h|0}if(b>>>0<16>>>0){while(1){j=b;b=j-1|0;if((j|0)==0){break}j=a;a=j+1|0;f=f+(d[j]|0)|0;c=c+f|0}if(f>>>0>=65521>>>0){f=f-65521|0}c=(c>>>0)%65521|0;g=f|c<<16;h=g;i=e;return h|0}while(1){if(!(b>>>0>=5552>>>0)){break}b=b-5552|0;j=347;do{f=f+(d[a|0]|0)|0;c=c+f|0;f=f+(d[a+1|0]|0)|0;c=c+f|0;f=f+(d[a+2|0]|0)|0;c=c+f|0;f=f+(d[a+3|0]|0)|0;c=c+f|0;f=f+(d[a+4|0]|0)|0;c=c+f|0;f=f+(d[a+5|0]|0)|0;c=c+f|0;f=f+(d[a+6|0]|0)|0;c=c+f|0;f=f+(d[a+7|0]|0)|0;c=c+f|0;f=f+(d[a+8|0]|0)|0;c=c+f|0;f=f+(d[a+9|0]|0)|0;c=c+f|0;f=f+(d[a+10|0]|0)|0;c=c+f|0;f=f+(d[a+11|0]|0)|0;c=c+f|0;f=f+(d[a+12|0]|0)|0;c=c+f|0;f=f+(d[a+13|0]|0)|0;c=c+f|0;f=f+(d[a+14|0]|0)|0;c=c+f|0;f=f+(d[a+15|0]|0)|0;c=c+f|0;a=a+16|0;k=j-1|0;j=k;}while((k|0)!=0);f=(f>>>0)%65521|0;c=(c>>>0)%65521|0}if((b|0)!=0){while(1){if(!(b>>>0>=16>>>0)){break}b=b-16|0;f=f+(d[a|0]|0)|0;c=c+f|0;f=f+(d[a+1|0]|0)|0;c=c+f|0;f=f+(d[a+2|0]|0)|0;c=c+f|0;f=f+(d[a+3|0]|0)|0;c=c+f|0;f=f+(d[a+4|0]|0)|0;c=c+f|0;f=f+(d[a+5|0]|0)|0;c=c+f|0;f=f+(d[a+6|0]|0)|0;c=c+f|0;f=f+(d[a+7|0]|0)|0;c=c+f|0;f=f+(d[a+8|0]|0)|0;c=c+f|0;f=f+(d[a+9|0]|0)|0;c=c+f|0;f=f+(d[a+10|0]|0)|0;c=c+f|0;f=f+(d[a+11|0]|0)|0;c=c+f|0;f=f+(d[a+12|0]|0)|0;c=c+f|0;f=f+(d[a+13|0]|0)|0;c=c+f|0;f=f+(d[a+14|0]|0)|0;c=c+f|0;f=f+(d[a+15|0]|0)|0;c=c+f|0;a=a+16|0}while(1){j=b;b=j-1|0;if((j|0)==0){break}j=a;a=j+1|0;f=f+(d[j]|0)|0;c=c+f|0}f=(f>>>0)%65521|0;c=(c>>>0)%65521|0}g=f|c<<16;h=g;i=e;return h|0}function Eqc(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;h=i;i=i+8|0;j=h|0;k=f;f=c[k+28>>2]|0;l=(c[k>>2]|0)-1|0;m=l+((c[k+4>>2]|0)-5)|0;n=(c[k+12>>2]|0)-1|0;o=n+(-(g-(c[k+16>>2]|0)|0)|0)|0;g=n+((c[k+16>>2]|0)-257)|0;p=c[f+40>>2]|0;q=c[f+44>>2]|0;r=c[f+48>>2]|0;s=c[f+52>>2]|0;t=c[f+56>>2]|0;u=c[f+60>>2]|0;v=c[f+76>>2]|0;w=c[f+80>>2]|0;x=(1<<c[f+84>>2])-1|0;y=(1<<c[f+88>>2])-1|0;a:do{if(u>>>0<15>>>0){z=l+1|0;l=z;t=t+((d[z]|0)<<u)|0;u=u+8|0;z=l+1|0;l=z;t=t+((d[z]|0)<<u)|0;u=u+8|0}z=j;A=v+((t&x)<<2)|0;b[z>>1]=b[A>>1]|0;b[z+2>>1]=b[A+2>>1]|0;while(1){B=d[j+1|0]|0;t=t>>>(B>>>0);u=u-B|0;B=d[j|0]|0;if((B|0)==0){C=6;break}if((B&16|0)!=0){C=8;break}if((B&64|0)!=0){C=74;break a}A=j;z=v+((e[j+2>>1]|0)+(t&(1<<B)-1)<<2)|0;b[A>>1]=b[z>>1]|0;b[A+2>>1]=b[z+2>>1]|0}if((C|0)==6){C=0;z=n+1|0;n=z;a[z]=b[j+2>>1]}else if((C|0)==8){C=0;D=e[j+2>>1]|0;B=B&15;if((B|0)!=0){if(u>>>0<B>>>0){z=l+1|0;l=z;t=t+((d[z]|0)<<u)|0;u=u+8|0}D=D+(t&(1<<B)-1)|0;t=t>>>(B>>>0);u=u-B|0}if(u>>>0<15>>>0){z=l+1|0;l=z;t=t+((d[z]|0)<<u)|0;u=u+8|0;z=l+1|0;l=z;t=t+((d[z]|0)<<u)|0;u=u+8|0}z=j;A=w+((t&y)<<2)|0;b[z>>1]=b[A>>1]|0;b[z+2>>1]=b[A+2>>1]|0;while(1){B=d[j+1|0]|0;t=t>>>(B>>>0);u=u-B|0;B=d[j|0]|0;if((B&16|0)!=0){break}if((B&64|0)!=0){C=70;break a}A=j;z=w+((e[j+2>>1]|0)+(t&(1<<B)-1)<<2)|0;b[A>>1]=b[z>>1]|0;b[A+2>>1]=b[z+2>>1]|0}z=e[j+2>>1]|0;B=B&15;if(u>>>0<B>>>0){A=l+1|0;l=A;t=t+((d[A]|0)<<u)|0;u=u+8|0;if(u>>>0<B>>>0){A=l+1|0;l=A;t=t+((d[A]|0)<<u)|0;u=u+8|0}}z=z+(t&(1<<B)-1)|0;t=t>>>(B>>>0);u=u-B|0;B=n-o|0;if(z>>>0>B>>>0){B=z-B|0;if(B>>>0>q>>>0){if((c[f+7104>>2]|0)!=0){C=23;break}}E=s-1|0;if((r|0)==0){E=E+(p-B)|0;if(B>>>0<D>>>0){D=D-B|0;do{A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;A=B-1|0;B=A;}while((A|0)!=0);E=n+(-z|0)|0}}else{if(r>>>0<B>>>0){E=E+(p+r-B)|0;B=B-r|0;if(B>>>0<D>>>0){D=D-B|0;do{A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;A=B-1|0;B=A;}while((A|0)!=0);E=s-1|0;if(r>>>0<D>>>0){B=r;D=D-B|0;do{A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;A=B-1|0;B=A;}while((A|0)!=0);E=n+(-z|0)|0}}}else{E=E+(r-B)|0;if(B>>>0<D>>>0){D=D-B|0;do{A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;A=B-1|0;B=A;}while((A|0)!=0);E=n+(-z|0)|0}}}while(1){if(!(D>>>0>2>>>0)){break}A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;D=D-3|0}if((D|0)!=0){A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;if(D>>>0>1>>>0){A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0}}}else{E=n+(-z|0)|0;do{A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;A=E+1|0;E=A;F=n+1|0;n=F;a[F]=a[A]|0;D=D-3|0;}while(D>>>0>2>>>0);if((D|0)!=0){z=E+1|0;E=z;A=n+1|0;n=A;a[A]=a[z]|0;if(D>>>0>1>>>0){z=E+1|0;E=z;A=n+1|0;n=A;a[A]=a[z]|0}}}}if(l>>>0<m>>>0){G=n>>>0<g>>>0}else{G=0}}while(G);do{if((C|0)==23){c[k+24>>2]=2254600;c[f>>2]=29}else if((C|0)==70){c[k+24>>2]=2534696;c[f>>2]=29}else if((C|0)==74){if((B&32|0)!=0){c[f>>2]=11;break}else{c[k+24>>2]=2412288;c[f>>2]=29;break}}}while(0);D=u>>>3;l=l+(-D|0)|0;u=u-(D<<3)|0;t=t&(1<<u)-1;c[k>>2]=l+1;c[k+12>>2]=n+1;if(l>>>0<m>>>0){H=m-l+5|0}else{H=5-(l-m)|0}c[k+4>>2]=H;if(n>>>0<g>>>0){I=g-n+257|0;J=k;K=J+16|0;c[K>>2]=I;L=t;M=f;N=M+56|0;c[N>>2]=L;O=u;P=f;Q=P+60|0;c[Q>>2]=O;i=h;return}else{I=257-(n-g)|0;J=k;K=J+16|0;c[K>>2]=I;L=t;M=f;N=M+56|0;c[N>>2]=L;O=u;P=f;Q=P+60|0;c[Q>>2]=O;i=h;return}}function Fqc(a,b){a=a|0;b=b|0;var e=0,f=0;e=Gqc(a)|0;do{if(!((e|0)==-1)){a=Gqc(b)|0;if((a|0)==-1){break}if((d[1707512+e|0]|0)>>>0>207>>>0){break}f=a<<16|e;return f|0}}while(0);c[(pd()|0)>>2]=22;f=-1;return f|0}function Gqc(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;c=a[b]|0;a:do{if(c<<24>>24==0){d=1707512;while(1){if((a[d]|0)==0){e=d;break a}f=lrc(d|0)|0;g=d+(f+1)|0;do{if((a[g]|0)==0){h=a[d+(f+2)|0]|0;if((h&255)>>>0>128>>>0){i=d+(f+3)|0;break}else{i=d+(f+3+(((128-(h&255)|0)>>>2)*5|0))|0;break}}else{i=g}}while(0);if((a[i]|0)==0){j=-1;break}else{d=i}}return j|0}else{d=1707512;while(1){g=b;f=d;h=c;while(1){k=a[f]|0;if(k<<24>>24==0){l=f;m=h;n=15;break}o=h&255;p=o|32;b:do{if(h<<24>>24==0){q=g;r=p}else{s=g;t=o;u=p;while(1){v=s+1|0;if(!((u-97|0)>>>0>26>>>0&(t-48|0)>>>0>10>>>0)){q=s;r=u;break b}w=a[v]|0;x=w&255;y=x|32;if(w<<24>>24==0){q=v;r=y;break}else{s=v;t=x;u=y}}}}while(0);if((r|0)!=(k&255|0)){break}p=q+1|0;o=f+1|0;u=a[p]|0;if(u<<24>>24==0){l=o;m=0;n=15;break}else{g=p;f=o;h=u}}if((n|0)==15){n=0;if(m<<24>>24==(a[l]|0)){break}}h=lrc(d|0)|0;f=d+(h+1)|0;do{if((a[f]|0)==0){g=a[d+(h+2)|0]|0;if((g&255)>>>0>128>>>0){z=d+(h+3)|0;break}else{z=d+(h+3+(((128-(g&255)|0)>>>2)*5|0))|0;break}}else{z=f}}while(0);if((a[z]|0)==0){j=-1;n=24;break}else{d=z}}if((n|0)==24){return j|0}if((a[d]|0)==0){e=d;break}else{A=d}while(1){f=A+((lrc(A|0)|0)+1)|0;if((a[f]|0)==0){e=f;break}else{A=f}}}}while(0);j=e+1-1707512|0;return j|0}function Hqc(a){a=a|0;return 0}function Iqc(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0;l=i;i=i+8|0;m=l|0;n=m;o=i;i=i+4|0;i=i+7&-8;p=i;i=i+4|0;i=i+7&-8;q=i;i=i+4|0;i=i+7&-8;r=i;i=i+4|0;i=i+7&-8;s=f;f=s&65535;t=s>>>16;s=t+1|0;u=f+1|0;c[m>>2]=0;c[m+4>>2]=0;m=a[1707512+t|0]|0;if((g|0)==0){v=0;i=l;return v|0}w=c[g>>2]|0;if((w|0)==0){v=0;i=l;return v|0}x=c[h>>2]|0;if((x|0)==0){v=0;i=l;return v|0}y=m&255;z=y+128|0;A=t+2|0;t=y&3;B=t^1;C=t^2;D=t^3;E=y&1;F=E^1;G=(y-196|0)>>>0<2>>>0;H=E|2;I=F|2;J=m<<24>>24==-38;K=m<<24>>24==-40;m=d[1707512+f|0]|0;L=m-192|0;M=L>>>0>8>>>0;N=f;O=2362720+L|0;L=m+128|0;P=128-m|0;Q=f+2|0;f=r|0;r=m&1;R=r^1;S=r|2;T=R|2;U=m&3;V=U^1;W=U^2;X=U^3;Y=(y-192|0)>>>0<7>>>0;Z=0;_=w;w=x;a:while(1){x=a[_]|0;$=x&255;b:do{if(x<<24>>24<0|Y){switch(y|0){case 200:{aa=Mqc(o,_,w,n)|0;if((aa|0)==0){ba=1}else if((aa|0)==(-1|0)){ca=84;da=114;break a}else if((aa|0)==(-2|0)){ea=22;break a}else{ba=aa}fa=ba;ga=c[o>>2]|0;da=90;break b;break};case 192:case 195:{if(w>>>0<4>>>0){ea=22;break a}ha=d[_+B|0]<<16|d[_+t|0]<<24|d[_+C|0]<<8|d[_+D|0];da=14;break};case 209:{if(($-161|0)>>>0<63>>>0){fa=1;ga=$+65216|0;da=90;break b}if(w>>>0<2>>>0){ea=22;break a}aa=a[_+1|0]|0;ia=aa&255;ja=$-129|0;if(ja>>>0<31>>>0){ka=ja}else{if(!(($-224|0)>>>0<16>>>0)){ca=84;da=114;break a}ka=$-193|0}ja=ka<<1;la=ia-64|0;if(la>>>0<95>>>0){if(aa<<24>>24==127){ca=84;da=114;break a}ma=la+(aa<<24>>24>>7<<24>>24)|0;na=ja}else{aa=ia-159|0;la=aa>>>0<94>>>0;ma=la?aa:ia;na=ja|la&1}la=b[1037216+(na*188|0)+(ma<<1)>>1]|0;if(la<<16>>16==0){ca=84;da=114;break a}else{fa=2;ga=la&65535;da=90;break b}break};case 196:case 197:case 194:case 193:{if(w>>>0<2>>>0){ea=22;break a}la=d[_+E|0]<<8|d[_+F|0];if((la-56320|0)>>>0<1024>>>0){ca=84;da=114;break a}if(!((la-55296|0)>>>0<1024>>>0)){fa=2;ga=la;da=90;break b}if(G){ca=84;da=114;break a}if(w>>>0<4>>>0){ea=22;break a}ja=(d[_+H|0]<<8|d[_+I|0])-56320|0;if(ja>>>0>1023>>>0){ca=84;da=114;break a}fa=4;ga=(la<<10)-56557568+ja|0;da=90;break b;break};case 198:{if(w>>>0<4>>>0){ea=22;break a}ha=c[_>>2]|0;da=14;break};case 208:{if(w>>>0<2>>>0){ea=22;break a}ja=d[_+1|0]|0;if(x<<24>>24==-114){if((ja-161|0)>>>0>62>>>0){ca=84;da=114;break a}fa=2;ga=ja+65216|0;da=90;break b}else{la=$-161|0;ia=ja-161|0;if(la>>>0>83>>>0|ia>>>0>93>>>0){ca=84;da=114;break a}ja=b[1037216+(la*188|0)+(ia<<1)>>1]|0;if(ja<<16>>16==0){ca=84;da=114;break a}else{fa=2;ga=ja&65535;da=90;break b}}break};case 218:{if((x&255)>>>0<161>>>0){ca=84;da=114;break a}break};case 217:case 216:{break};case 224:{if(w>>>0<2>>>0){ea=22;break a}ja=d[_+1|0]|0;ia=ja-64|0;if(ia>>>0>190>>>0|(ja-127|0)>>>0<34>>>0){ca=84;da=114;break a}la=ia>>>0>62>>>0?ja-98|0:ia;ia=$-161|0;if(!(ia>>>0>88>>>0)){ja=e[1924848+(ia*314|0)+(la<<1)>>1]|0;do{if((ia|0)==39){if((la|0)==60|(la|0)==58){oa=131072;break}oa=((la|0)==66)<<17}else{oa=0}}while(0);ia=oa|ja;if((ia|0)==0){ca=84;da=114;break a}else{fa=2;ga=ia;da=90;break b}}ia=$-135|0;if(ia>>>0>119>>>0){ca=84;da=114;break a}aa=la+(((x&255)>>>0<161>>>0?ia:$-224|0)*157|0)|0;ia=e[1091872+(aa<<1)>>1]|0;pa=ia|(((e[1091872+((aa>>>4)+4867<<1)>>1]|0)>>>((aa&15)>>>0)|0)%2|0)<<17;if((pa&-65792|0)!=56320){if((pa|0)==0){ca=84;da=114;break a}else{fa=2;ga=pa;da=90;break b}}if(M){qa=2}else{qa=a[O]|0}if(qa>>>0>(c[k>>2]|0)>>>0){ca=7;da=114;break a}c[p>>2]=2563096+(ia&255);c[q>>2]=4;ra=(Iqc(N,p,q,j,k)|0)+Z|0;sa=2;break b;break};case 232:{if(w>>>0<2>>>0){ea=22;break a}ia=a[_+1|0]|0;pa=ia&255;aa=$-161|0;ta=pa-161|0;if(!(aa>>>0>92>>>0|ta>>>0>93>>>0)){ua=b[1017248+(aa*188|0)+(ta<<1)>>1]|0;if(ua<<16>>16==0){ca=84;da=114;break a}else{fa=2;ga=ua&65535;da=90;break b}}ua=$-129|0;if(ua>>>0>92>>>0){ca=84;da=114;break a}if(ua>>>0>68>>>0&(ia&255)>>>0>82>>>0){ca=84;da=114;break a}ia=pa-65|0;do{if(ia>>>0<26>>>0){va=ia}else{if((pa-97|0)>>>0<26>>>0){va=pa-71|0;break}if(!((pa-129|0)>>>0<126>>>0)){ca=84;da=114;break a}va=pa-77|0}}while(0);if(ua>>>0<32>>>0){wa=ua*178|0}else{wa=(aa*84|0)+5696|0}pa=va+44032+wa|0;if(pa>>>0<44032>>>0){fa=2;ga=pa;da=90;break b}else{xa=pa;ya=44032}while(1){pa=xa-ya|0;ia=0;la=0;while(1){za=ia;ja=0;do{za=(((e[1017248+(la*188|0)+(ja<<1)>>1]|0)-ya|0)>>>0<=pa>>>0)+za|0;ja=ja+1|0;}while((ja|0)<94);ja=la+1|0;if((ja|0)<93){ia=za;la=ja}else{break}}la=xa+1|0;ia=za+xa|0;if(la>>>0>ia>>>0){fa=2;ga=ia;da=90;break b}else{xa=ia;ya=la}}break};case 199:{ca=84;da=114;break a;break};default:{if($>>>0<z>>>0){fa=1;ga=$;da=90;break b}aa=$-z|0;ua=(aa*5|0)>>>2;la=aa<<1&6;aa=d[1707512+(A+ua)|0]<<8-la&1023|(d[1707512+(ua+s)|0]|0)>>>(la>>>0);la=(aa|0)==0?$:e[1011184+(aa<<1)>>1]|0;if((la|0)==1){ca=84;da=114;break a}else{fa=1;ga=la;da=90;break b}}}if((da|0)==14){da=0;if((ha-55296|0)>>>0<2048>>>0|ha>>>0>1114111>>>0){ca=84;da=114;break a}else{fa=4;ga=ha;da=90;break}}la=$-129|0;if(la>>>0>125>>>0){ca=84;da=114;break a}if(w>>>0<2>>>0){ea=22;break a}aa=a[_+1|0]|0;ua=aa&255;if((aa&255)>>>0<161>>>0&J){ca=84;da=114;break a}ia=ua-64|0;if(!(ia>>>0>190>>>0|aa<<24>>24==127)){fa=2;ga=e[1150312+(la*380|0)+((ia>>>0>63>>>0?ua-65|0:ia)<<1)>>1]|0;da=90;break}if(!((ua-48|0)>>>0<10>>>0&K)){ca=84;da=114;break a}if(w>>>0<4>>>0){ea=22;break a}ia=(d[_+2|0]|0)-129|0;if(ia>>>0>126>>>0){ca=84;da=114;break a}aa=(d[_+3|0]|0)-48|0;if(aa>>>0>9>>>0){ca=84;da=114;break a}pa=((ua+(la*10|0)|0)*1260|0)-60352+(ia*10|0)+aa|0;aa=0;while(1){ia=pa-aa|0;la=0;ua=0;while(1){Aa=la;ja=0;do{Aa=(((e[1150312+(ua*380|0)+(ja<<1)>>1]|0)-aa|0)>>>0<=ia>>>0)+Aa|0;ja=ja+1|0;}while((ja|0)<190);ja=ua+1|0;if((ja|0)<126){la=Aa;ua=ja}else{break}}ua=pa+1|0;la=Aa+pa|0;if(ua>>>0>la>>>0){fa=4;ga=la;da=90;break}else{pa=la;aa=ua}}}else{fa=1;ga=$;da=90}}while(0);c:do{if((da|0)==90){da=0;switch(m|0){case 198:{if((c[k>>2]|0)>>>0<4>>>0){ca=7;da=114;break a}$=c[j>>2]|0;c[$>>2]=ga;c[j>>2]=$+4;c[k>>2]=(c[k>>2]|0)-4;ra=Z;sa=fa;break c;break};case 200:{if((c[k>>2]|0)>>>0<4>>>0){$=Oqc(f,ga)|0;if((c[k>>2]|0)>>>0<$>>>0){ca=7;da=114;break a}x=c[j>>2]|0;nrc(x|0,f|0,$)|0;Ba=$;Ca=x}else{x=c[j>>2]|0;Ba=Oqc(x,ga)|0;Ca=x}c[j>>2]=Ca+Ba;c[k>>2]=(c[k>>2]|0)-Ba;ra=Z;sa=fa;break c;break};case 199:{if(ga>>>0>127>>>0){Da=Z;da=99}else{Ea=Z;Fa=ga}break};case 196:case 197:case 194:case 193:{if(ga>>>0<65536>>>0|G){x=ga>>>0>65535>>>0?65533:ga;if((c[k>>2]|0)>>>0<2>>>0){ca=7;da=114;break a}$=c[j>>2]|0;a[$+r|0]=x>>>8;a[$+R|0]=x;c[j>>2]=$+2;c[k>>2]=(c[k>>2]|0)-2;ra=Z;sa=fa;break c}else{if((c[k>>2]|0)>>>0<4>>>0){ca=7;da=114;break a}$=ga-65536|0;x=c[j>>2]|0;a[x+r|0]=$>>>18|216;a[x+R|0]=$>>>10;a[x+S|0]=$>>>8&3|220;a[x+T|0]=$;c[j>>2]=x+4;c[k>>2]=(c[k>>2]|0)-4;ra=Z;sa=fa;break c}break};case 192:case 195:{if((c[k>>2]|0)>>>0<4>>>0){ca=7;da=114;break a}x=c[j>>2]|0;a[x+U|0]=ga>>>24;a[x+V|0]=ga>>>16;a[x+W|0]=ga>>>8;a[x+X|0]=ga;c[j>>2]=x+4;c[k>>2]=(c[k>>2]|0)-4;ra=Z;sa=fa;break c;break};default:{Ea=Z;Fa=ga}}d:while(1){if((da|0)==99){da=0;Ea=Da+1|0;Fa=42}if((c[k>>2]|0)==0){ca=7;da=114;break a}if(Fa>>>0<L>>>0){Ga=Fa&255;break}else{Ha=0}while(1){if(!(Ha>>>0<P>>>0)){Da=Ea;da=99;continue d}x=(Ha*5|0)>>>2;$=Ha<<1&6;if((Fa|0)==(e[1011184+((d[1707512+(Q+x)|0]<<8-$&1023|(d[1707512+(x+u)|0]|0)>>>($>>>0))<<1)>>1]|0)){da=105;break d}else{Ha=Ha+1|0}}}if((da|0)==105){da=0;Ga=Ha+128&255}$=c[j>>2]|0;c[j>>2]=$+1;a[$]=Ga;c[k>>2]=(c[k>>2]|0)-1;ra=Ea;sa=fa}}while(0);$=(c[g>>2]|0)+sa|0;c[g>>2]=$;x=w-sa|0;c[h>>2]=x;if((w|0)==(sa|0)){v=ra;da=116;break}else{Z=ra;_=$;w=x}}if((da|0)==114){ea=ca}else if((da|0)==116){i=l;return v|0}c[(pd()|0)>>2]=ea;v=-1;i=l;return v|0}function Jqc(a,b){a=+a;b=b|0;return+(+arc(a,b))}function Kqc(a,b){a=+a;b=b|0;return+(+Lqc(a,b))}function Lqc(a,b){a=+a;b=b|0;var d=0.0,e=0,f=0.0,h=0;do{if((b|0)>127){d=a*1.7014118346046923e+38;e=b-127|0;if((e|0)<=127){f=d;h=e;break}e=b-254|0;f=d*1.7014118346046923e+38;h=(e|0)>127?127:e}else{if(!((b|0)<-126)){f=a;h=b;break}d=a*1.1754943508222875e-38;e=b+126|0;if(!((e|0)<-126)){f=d;h=e;break}e=b+252|0;f=d*1.1754943508222875e-38;h=(e|0)<-126?-126:e}}while(0);return+(f*(c[k>>2]=(h<<23)+1065353216,+g[k>>2]))}function Mqc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+8|0;h=g|0;c[h>>2]=b;j=((f|0)==0?5790256:f)|0;f=c[j>>2]|0;a:do{if((d|0)==0){if((f|0)==0){k=0}else{break}i=g;return k|0}else{if((b|0)==0){l=h;c[h>>2]=l;m=l}else{m=b}if((e|0)==0){k=-2;i=g;return k|0}do{if((f|0)==0){l=a[d]|0;n=l&255;if(l<<24>>24>-1){c[m>>2]=n;k=l<<24>>24!=0|0;i=g;return k|0}else{l=n-194|0;if(l>>>0>50>>>0){break a}o=d+1|0;p=c[2653520+(l<<2)>>2]|0;q=e-1|0;break}}else{o=d;p=f;q=e}}while(0);b:do{if((q|0)==0){r=p}else{l=a[o]|0;n=(l&255)>>>3;if((n-16|n+(p>>26))>>>0>7>>>0){break a}else{s=o;t=p;u=q;v=l}while(1){s=s+1|0;t=(v&255)-128|t<<6;u=u-1|0;if((t|0)>=0){break}if((u|0)==0){r=t;break b}v=a[s]|0;if(((v&255)-128|0)>>>0>63>>>0){break a}}c[j>>2]=0;c[m>>2]=t;k=e-u|0;i=g;return k|0}}while(0);c[j>>2]=r;k=-2;i=g;return k|0}}while(0);c[j>>2]=0;c[(pd()|0)>>2]=84;k=-1;i=g;return k|0}function Nqc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((b|0)==0){f=1;return f|0}if(d>>>0<128>>>0){a[b]=d;f=1;return f|0}if(d>>>0<2048>>>0){a[b]=d>>>6|192;a[b+1|0]=d&63|128;f=2;return f|0}if(d>>>0<55296>>>0|(d-57344|0)>>>0<8192>>>0){a[b]=d>>>12|224;a[b+1|0]=d>>>6&63|128;a[b+2|0]=d&63|128;f=3;return f|0}if((d-65536|0)>>>0<1048576>>>0){a[b]=d>>>18|240;a[b+1|0]=d>>>12&63|128;a[b+2|0]=d>>>6&63|128;a[b+3|0]=d&63|128;f=4;return f|0}else{c[(pd()|0)>>2]=84;f=-1;return f|0}return 0}function Oqc(a,b){a=a|0;b=b|0;var c=0;if((a|0)==0){c=0}else{c=Nqc(a,b,0)|0}return c|0}function Pqc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;do{if(a>>>0<245>>>0){if(a>>>0<11>>>0){b=16}else{b=a+11&-8}d=b>>>3;e=c[2557694]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=10230816+(h<<2)|0;j=10230816+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[2557694]=e&~(1<<g)}else{if(l>>>0<(c[2557698]|0)>>>0){Hd();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{Hd();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(!(b>>>0>(c[2557696]|0)>>>0)){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=10230816+(p<<2)|0;m=10230816+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[2557694]=e&~(1<<r)}else{if(l>>>0<(c[2557698]|0)>>>0){Hd();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{Hd();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[2557696]|0;if((l|0)!=0){q=c[2557699]|0;d=l>>>3;l=d<<1;f=10230816+(l<<2)|0;k=c[2557694]|0;h=1<<d;do{if((k&h|0)==0){c[2557694]=k|h;s=f;t=10230816+(l+2<<2)|0}else{d=10230816+(l+2<<2)|0;g=c[d>>2]|0;if(!(g>>>0<(c[2557698]|0)>>>0)){s=g;t=d;break}Hd();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[2557696]=m;c[2557699]=e;n=i;return n|0}l=c[2557695]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[10231080+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[2557698]|0;if(r>>>0<i>>>0){Hd();return 0}e=r+b|0;m=e;if(!(r>>>0<e>>>0)){Hd();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){Hd();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){Hd();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){Hd();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{Hd();return 0}}}while(0);a:do{if((e|0)!=0){f=c[d+28>>2]|0;i=10231080+(f<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[2557695]=c[2557695]&~(1<<f);break a}else{if(e>>>0<(c[2557698]|0)>>>0){Hd();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break a}}}while(0);if(v>>>0<(c[2557698]|0)>>>0){Hd();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16>>>0){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[2557696]|0;if((f|0)!=0){e=c[2557699]|0;i=f>>>3;f=i<<1;q=10230816+(f<<2)|0;k=c[2557694]|0;g=1<<i;do{if((k&g|0)==0){c[2557694]=k|g;y=q;z=10230816+(f+2<<2)|0}else{i=10230816+(f+2<<2)|0;l=c[i>>2]|0;if(!(l>>>0<(c[2557698]|0)>>>0)){y=l;z=i;break}Hd();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[2557696]=p;c[2557699]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231>>>0){o=-1;break}f=a+11|0;g=f&-8;k=c[2557695]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215>>>0){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[10231080+(A<<2)>>2]|0;b:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break b}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=k&(i|-i);if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[10231080+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(!(J>>>0<((c[2557696]|0)-g|0)>>>0)){o=g;break}q=K;m=c[2557698]|0;if(q>>>0<m>>>0){Hd();return 0}p=q+g|0;k=p;if(!(q>>>0<p>>>0)){Hd();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){Hd();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){Hd();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){Hd();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{Hd();return 0}}}while(0);c:do{if((e|0)!=0){i=c[K+28>>2]|0;m=10231080+(i<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[2557695]=c[2557695]&~(1<<i);break c}else{if(e>>>0<(c[2557698]|0)>>>0){Hd();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break c}}}while(0);if(L>>>0<(c[2557698]|0)>>>0){Hd();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16>>>0){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256>>>0){e=i<<1;m=10230816+(e<<2)|0;r=c[2557694]|0;j=1<<i;do{if((r&j|0)==0){c[2557694]=r|j;O=m;P=10230816+(e+2<<2)|0}else{i=10230816+(e+2<<2)|0;d=c[i>>2]|0;if(!(d>>>0<(c[2557698]|0)>>>0)){O=d;P=i;break}Hd();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215>>>0){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=10231080+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[2557695]|0;l=1<<Q;if((m&l|0)==0){c[2557695]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=151;break}else{l=l<<1;m=j}}if((T|0)==151){if(S>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[2557698]|0;if(m>>>0<i>>>0){Hd();return 0}if(j>>>0<i>>>0){Hd();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[2557696]|0;if(!(o>>>0>K>>>0)){S=K-o|0;J=c[2557699]|0;if(S>>>0>15>>>0){R=J;c[2557699]=R+o;c[2557696]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[2557696]=0;c[2557699]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[2557697]|0;if(o>>>0<J>>>0){S=J-o|0;c[2557697]=S;J=c[2557700]|0;K=J;c[2557700]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[1422470]|0)==0){J=kb(30)|0;if((J-1&J|0)==0){c[1422472]=J;c[1422471]=J;c[1422473]=-1;c[1422474]=-1;c[1422475]=0;c[2557805]=0;c[1422470]=(ie(0)|0)&-16^1431655768;break}else{Hd();return 0}}}while(0);J=o+48|0;S=c[1422472]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(!(S>>>0>o>>>0)){n=0;return n|0}O=c[2557804]|0;do{if((O|0)!=0){P=c[2557802]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);d:do{if((c[2557805]&4|0)==0){O=c[2557700]|0;e:do{if((O|0)==0){T=181}else{L=O;P=10231224;while(1){U=P|0;M=c[U>>2]|0;if(!(M>>>0>L>>>0)){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=181;break e}else{P=M}}if((P|0)==0){T=181;break}L=R-(c[2557697]|0)&Q;if(!(L>>>0<2147483647>>>0)){W=0;break}m=Hb(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=190}}while(0);do{if((T|0)==181){O=Hb(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[1422471]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[2557802]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647>>>0)){W=0;break}m=c[2557804]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=Hb($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=190}}while(0);f:do{if((T|0)==190){m=-_|0;if(!((X|0)==-1)){aa=Y;ba=X;T=201;break d}do{if((Z|0)!=-1&_>>>0<2147483647>>>0&_>>>0<J>>>0){g=c[1422472]|0;O=K-_+g&-g;if(!(O>>>0<2147483647>>>0)){ca=_;break}if((Hb(O|0)|0)==-1){Hb(m|0)|0;W=Y;break f}else{ca=O+_|0;break}}else{ca=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ca;ba=Z;T=201;break d}}}while(0);c[2557805]=c[2557805]|4;da=W;T=198}else{da=0;T=198}}while(0);do{if((T|0)==198){if(!(S>>>0<2147483647>>>0)){break}W=Hb(S|0)|0;Z=Hb(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ca=Z-W|0;Z=ca>>>0>(o+40|0)>>>0;Y=Z?W:-1;if(!((Y|0)==-1)){aa=Z?ca:da;ba=Y;T=201}}}while(0);do{if((T|0)==201){da=(c[2557802]|0)+aa|0;c[2557802]=da;if(da>>>0>(c[2557803]|0)>>>0){c[2557803]=da}da=c[2557700]|0;g:do{if((da|0)==0){S=c[2557698]|0;if((S|0)==0|ba>>>0<S>>>0){c[2557698]=ba}c[2557806]=ba;c[2557807]=aa;c[2557809]=0;c[2557703]=c[1422470];c[2557702]=-1;S=0;do{Y=S<<1;ca=10230816+(Y<<2)|0;c[10230816+(Y+3<<2)>>2]=ca;c[10230816+(Y+2<<2)>>2]=ca;S=S+1|0;}while(S>>>0<32>>>0);S=ba+8|0;if((S&7|0)==0){ea=0}else{ea=-S&7}S=aa-40-ea|0;c[2557700]=ba+ea;c[2557697]=S;c[ba+(ea+4)>>2]=S|1;c[ba+(aa-36)>>2]=40;c[2557701]=c[1422474]}else{S=10231224;while(1){fa=c[S>>2]|0;ga=S+4|0;ha=c[ga>>2]|0;if((ba|0)==(fa+ha|0)){T=213;break}ca=c[S+8>>2]|0;if((ca|0)==0){break}else{S=ca}}do{if((T|0)==213){if((c[S+12>>2]&8|0)!=0){break}ca=da;if(!(ca>>>0>=fa>>>0&ca>>>0<ba>>>0)){break}c[ga>>2]=ha+aa;Y=(c[2557697]|0)+aa|0;Z=da+8|0;if((Z&7|0)==0){ia=0}else{ia=-Z&7}Z=Y-ia|0;c[2557700]=ca+ia;c[2557697]=Z;c[ca+(ia+4)>>2]=Z|1;c[ca+(Y+4)>>2]=40;c[2557701]=c[1422474];break g}}while(0);if(ba>>>0<(c[2557698]|0)>>>0){c[2557698]=ba}S=ba+aa|0;Y=10231224;while(1){ja=Y|0;if((c[ja>>2]|0)==(S|0)){T=223;break}ca=c[Y+8>>2]|0;if((ca|0)==0){break}else{Y=ca}}do{if((T|0)==223){if((c[Y+12>>2]&8|0)!=0){break}c[ja>>2]=ba;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ba+8|0;if((S&7|0)==0){ka=0}else{ka=-S&7}S=ba+(aa+8)|0;if((S&7|0)==0){la=0}else{la=-S&7}S=ba+(la+aa)|0;ca=S;Z=ka+o|0;W=ba+Z|0;_=W;K=S-(ba+ka)-o|0;c[ba+(ka+4)>>2]=o|3;do{if((ca|0)==(c[2557700]|0)){J=(c[2557697]|0)+K|0;c[2557697]=J;c[2557700]=_;c[ba+(Z+4)>>2]=J|1}else{if((ca|0)==(c[2557699]|0)){J=(c[2557696]|0)+K|0;c[2557696]=J;c[2557699]=_;c[ba+(Z+4)>>2]=J|1;c[ba+(J+Z)>>2]=J;break}J=aa+4|0;X=c[ba+(J+la)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;h:do{if(X>>>0<256>>>0){U=c[ba+((la|8)+aa)>>2]|0;Q=c[ba+(aa+12+la)>>2]|0;R=10230816+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[2557698]|0)>>>0){Hd();return 0}if((c[U+12>>2]|0)==(ca|0)){break}Hd();return 0}}while(0);if((Q|0)==(U|0)){c[2557694]=c[2557694]&~(1<<V);break}do{if((Q|0)==(R|0)){ma=Q+8|0}else{if(Q>>>0<(c[2557698]|0)>>>0){Hd();return 0}m=Q+8|0;if((c[m>>2]|0)==(ca|0)){ma=m;break}Hd();return 0}}while(0);c[U+12>>2]=Q;c[ma>>2]=U}else{R=S;m=c[ba+((la|24)+aa)>>2]|0;P=c[ba+(aa+12+la)>>2]|0;do{if((P|0)==(R|0)){O=la|16;g=ba+(J+O)|0;L=c[g>>2]|0;if((L|0)==0){e=ba+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){na=0;break}else{oa=O;pa=e}}else{oa=L;pa=g}while(1){g=oa+20|0;L=c[g>>2]|0;if((L|0)!=0){oa=L;pa=g;continue}g=oa+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{oa=L;pa=g}}if(pa>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[pa>>2]=0;na=oa;break}}else{g=c[ba+((la|8)+aa)>>2]|0;if(g>>>0<(c[2557698]|0)>>>0){Hd();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){Hd();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;na=P;break}else{Hd();return 0}}}while(0);if((m|0)==0){break}P=c[ba+(aa+28+la)>>2]|0;U=10231080+(P<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=na;if((na|0)!=0){break}c[2557695]=c[2557695]&~(1<<P);break h}else{if(m>>>0<(c[2557698]|0)>>>0){Hd();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=na}else{c[m+20>>2]=na}if((na|0)==0){break h}}}while(0);if(na>>>0<(c[2557698]|0)>>>0){Hd();return 0}c[na+24>>2]=m;R=la|16;P=c[ba+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[na+16>>2]=P;c[P+24>>2]=na;break}}}while(0);P=c[ba+(J+R)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[na+20>>2]=P;c[P+24>>2]=na;break}}}while(0);qa=ba+(($|la)+aa)|0;ra=$+K|0}else{qa=ca;ra=K}J=qa+4|0;c[J>>2]=c[J>>2]&-2;c[ba+(Z+4)>>2]=ra|1;c[ba+(ra+Z)>>2]=ra;J=ra>>>3;if(ra>>>0<256>>>0){V=J<<1;X=10230816+(V<<2)|0;P=c[2557694]|0;m=1<<J;do{if((P&m|0)==0){c[2557694]=P|m;sa=X;ta=10230816+(V+2<<2)|0}else{J=10230816+(V+2<<2)|0;U=c[J>>2]|0;if(!(U>>>0<(c[2557698]|0)>>>0)){sa=U;ta=J;break}Hd();return 0}}while(0);c[ta>>2]=_;c[sa+12>>2]=_;c[ba+(Z+8)>>2]=sa;c[ba+(Z+12)>>2]=X;break}V=W;m=ra>>>8;do{if((m|0)==0){ua=0}else{if(ra>>>0>16777215>>>0){ua=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;ua=ra>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=10231080+(ua<<2)|0;c[ba+(Z+28)>>2]=ua;c[ba+(Z+20)>>2]=0;c[ba+(Z+16)>>2]=0;X=c[2557695]|0;Q=1<<ua;if((X&Q|0)==0){c[2557695]=X|Q;c[m>>2]=V;c[ba+(Z+24)>>2]=m;c[ba+(Z+12)>>2]=V;c[ba+(Z+8)>>2]=V;break}if((ua|0)==31){va=0}else{va=25-(ua>>>1)|0}Q=ra<<va;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ra|0)){break}wa=X+16+(Q>>>31<<2)|0;m=c[wa>>2]|0;if((m|0)==0){T=296;break}else{Q=Q<<1;X=m}}if((T|0)==296){if(wa>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[wa>>2]=V;c[ba+(Z+24)>>2]=X;c[ba+(Z+12)>>2]=V;c[ba+(Z+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[2557698]|0;if(X>>>0<$>>>0){Hd();return 0}if(m>>>0<$>>>0){Hd();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ba+(Z+8)>>2]=m;c[ba+(Z+12)>>2]=X;c[ba+(Z+24)>>2]=0;break}}}while(0);n=ba+(ka|8)|0;return n|0}}while(0);Y=da;Z=10231224;while(1){xa=c[Z>>2]|0;if(!(xa>>>0>Y>>>0)){ya=c[Z+4>>2]|0;za=xa+ya|0;if(za>>>0>Y>>>0){break}}Z=c[Z+8>>2]|0}Z=xa+(ya-39)|0;if((Z&7|0)==0){Aa=0}else{Aa=-Z&7}Z=xa+(ya-47+Aa)|0;W=Z>>>0<(da+16|0)>>>0?Y:Z;Z=W+8|0;_=ba+8|0;if((_&7|0)==0){Ba=0}else{Ba=-_&7}_=aa-40-Ba|0;c[2557700]=ba+Ba;c[2557697]=_;c[ba+(Ba+4)>>2]=_|1;c[ba+(aa-36)>>2]=40;c[2557701]=c[1422474];c[W+4>>2]=27;c[Z>>2]=c[2557806];c[Z+4>>2]=c[2557807];c[Z+8>>2]=c[2557808];c[Z+12>>2]=c[2557809];c[2557806]=ba;c[2557807]=aa;c[2557809]=0;c[2557808]=Z;Z=W+28|0;c[Z>>2]=7;if((W+32|0)>>>0<za>>>0){_=Z;while(1){Z=_+4|0;c[Z>>2]=7;if((_+8|0)>>>0<za>>>0){_=Z}else{break}}}if((W|0)==(Y|0)){break}_=W-da|0;Z=Y+(_+4)|0;c[Z>>2]=c[Z>>2]&-2;c[da+4>>2]=_|1;c[Y+_>>2]=_;Z=_>>>3;if(_>>>0<256>>>0){K=Z<<1;ca=10230816+(K<<2)|0;S=c[2557694]|0;m=1<<Z;do{if((S&m|0)==0){c[2557694]=S|m;Ca=ca;Da=10230816+(K+2<<2)|0}else{Z=10230816+(K+2<<2)|0;Q=c[Z>>2]|0;if(!(Q>>>0<(c[2557698]|0)>>>0)){Ca=Q;Da=Z;break}Hd();return 0}}while(0);c[Da>>2]=da;c[Ca+12>>2]=da;c[da+8>>2]=Ca;c[da+12>>2]=ca;break}K=da;m=_>>>8;do{if((m|0)==0){Ea=0}else{if(_>>>0>16777215>>>0){Ea=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;W=(Y+520192|0)>>>16&4;Z=Y<<W;Y=(Z+245760|0)>>>16&2;Q=14-(W|S|Y)+(Z<<Y>>>15)|0;Ea=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=10231080+(Ea<<2)|0;c[da+28>>2]=Ea;c[da+20>>2]=0;c[da+16>>2]=0;ca=c[2557695]|0;Q=1<<Ea;if((ca&Q|0)==0){c[2557695]=ca|Q;c[m>>2]=K;c[da+24>>2]=m;c[da+12>>2]=da;c[da+8>>2]=da;break}if((Ea|0)==31){Fa=0}else{Fa=25-(Ea>>>1)|0}Q=_<<Fa;ca=c[m>>2]|0;while(1){if((c[ca+4>>2]&-8|0)==(_|0)){break}Ga=ca+16+(Q>>>31<<2)|0;m=c[Ga>>2]|0;if((m|0)==0){T=331;break}else{Q=Q<<1;ca=m}}if((T|0)==331){if(Ga>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[Ga>>2]=K;c[da+24>>2]=ca;c[da+12>>2]=da;c[da+8>>2]=da;break}}Q=ca+8|0;_=c[Q>>2]|0;m=c[2557698]|0;if(ca>>>0<m>>>0){Hd();return 0}if(_>>>0<m>>>0){Hd();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[da+8>>2]=_;c[da+12>>2]=ca;c[da+24>>2]=0;break}}}while(0);da=c[2557697]|0;if(!(da>>>0>o>>>0)){break}_=da-o|0;c[2557697]=_;da=c[2557700]|0;Q=da;c[2557700]=Q+o;c[Q+(o+4)>>2]=_|1;c[da+4>>2]=o|3;n=da+8|0;return n|0}}while(0);c[(pd()|0)>>2]=12;n=0;return n|0}function Qqc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[2557698]|0;if(b>>>0<e>>>0){Hd()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){Hd()}h=f&-8;i=a+(h-8)|0;j=i;a:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){Hd()}if((n|0)==(c[2557699]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[2557696]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256>>>0){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=10230816+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){Hd()}if((c[k+12>>2]|0)==(n|0)){break}Hd()}}while(0);if((s|0)==(k|0)){c[2557694]=c[2557694]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){Hd()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}Hd()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){Hd()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){Hd()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){Hd()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{Hd()}}}while(0);if((p|0)==0){q=n;r=o;break}v=c[a+(l+28)>>2]|0;m=10231080+(v<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[2557695]=c[2557695]&~(1<<v);q=n;r=o;break a}else{if(p>>>0<(c[2557698]|0)>>>0){Hd()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break a}}}while(0);if(A>>>0<(c[2557698]|0)>>>0){Hd()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[2557698]|0)>>>0){Hd()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[2557698]|0)>>>0){Hd()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(!(d>>>0<i>>>0)){Hd()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){Hd()}do{if((e&2|0)==0){if((j|0)==(c[2557700]|0)){B=(c[2557697]|0)+r|0;c[2557697]=B;c[2557700]=q;c[q+4>>2]=B|1;if((q|0)!=(c[2557699]|0)){return}c[2557699]=0;c[2557696]=0;return}if((j|0)==(c[2557699]|0)){B=(c[2557696]|0)+r|0;c[2557696]=B;c[2557699]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;b:do{if(e>>>0<256>>>0){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=10230816+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[2557698]|0)>>>0){Hd()}if((c[u+12>>2]|0)==(j|0)){break}Hd()}}while(0);if((g|0)==(u|0)){c[2557694]=c[2557694]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[2557698]|0)>>>0){Hd()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}Hd()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[2557698]|0)>>>0){Hd()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[2557698]|0)>>>0){Hd()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){Hd()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{Hd()}}}while(0);if((f|0)==0){break}t=c[a+(h+20)>>2]|0;u=10231080+(t<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[2557695]=c[2557695]&~(1<<t);break b}else{if(f>>>0<(c[2557698]|0)>>>0){Hd()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break b}}}while(0);if(E>>>0<(c[2557698]|0)>>>0){Hd()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[2557698]|0)>>>0){Hd()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[2557698]|0)>>>0){Hd()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[2557699]|0)){H=B;break}c[2557696]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256>>>0){d=r<<1;e=10230816+(d<<2)|0;A=c[2557694]|0;E=1<<r;do{if((A&E|0)==0){c[2557694]=A|E;I=e;J=10230816+(d+2<<2)|0}else{r=10230816+(d+2<<2)|0;h=c[r>>2]|0;if(!(h>>>0<(c[2557698]|0)>>>0)){I=h;J=r;break}Hd()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215>>>0){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=10231080+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[2557695]|0;d=1<<K;do{if((r&d|0)==0){c[2557695]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=129;break}else{A=A<<1;J=E}}if((N|0)==129){if(M>>>0<(c[2557698]|0)>>>0){Hd()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[2557698]|0;if(J>>>0<E>>>0){Hd()}if(B>>>0<E>>>0){Hd()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[2557702]|0)-1|0;c[2557702]=q;if((q|0)==0){O=10231232}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[2557702]=-1;return}function Rqc(a,b){a=a|0;b=b|0;var d=0,e=0;do{if((a|0)==0){d=0}else{e=ca(b,a)|0;if(!((b|a)>>>0>65535>>>0)){d=e;break}d=((e>>>0)/(a>>>0)|0|0)==(b|0)?e:-1}}while(0);b=Pqc(d)|0;if((b|0)==0){return b|0}if((c[b-4>>2]&3|0)==0){return b|0}mrc(b|0,0,d|0)|0;return b|0}function Sqc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==0){d=Pqc(b)|0;return d|0}if(b>>>0>4294967231>>>0){c[(pd()|0)>>2]=12;d=0;return d|0}if(b>>>0<11>>>0){e=16}else{e=b+11&-8}f=Tqc(a-8|0,e)|0;if((f|0)!=0){d=f+8|0;return d|0}f=Pqc(b)|0;if((f|0)==0){d=0;return d|0}e=c[a-4>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;nrc(f|0,a|0,g>>>0<b>>>0?g:b)|0;Qqc(a);d=f;return d|0}function Tqc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=a+4|0;e=c[d>>2]|0;f=e&-8;g=a;h=g+f|0;i=h;j=c[2557698]|0;if(g>>>0<j>>>0){Hd();return 0}k=e&3;if(!((k|0)!=1&g>>>0<h>>>0)){Hd();return 0}l=g+(f|4)|0;m=c[l>>2]|0;if((m&1|0)==0){Hd();return 0}if((k|0)==0){if(b>>>0<256>>>0){n=0;return n|0}do{if(!(f>>>0<(b+4|0)>>>0)){if((f-b|0)>>>0>c[1422472]<<1>>>0){break}else{n=a}return n|0}}while(0);n=0;return n|0}if(!(f>>>0<b>>>0)){k=f-b|0;if(!(k>>>0>15>>>0)){n=a;return n|0}c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|3;c[l>>2]=c[l>>2]|1;Xqc(g+b|0,k);n=a;return n|0}if((i|0)==(c[2557700]|0)){k=(c[2557697]|0)+f|0;if(!(k>>>0>b>>>0)){n=0;return n|0}l=k-b|0;c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=l|1;c[2557700]=g+b;c[2557697]=l;n=a;return n|0}if((i|0)==(c[2557699]|0)){l=(c[2557696]|0)+f|0;if(l>>>0<b>>>0){n=0;return n|0}k=l-b|0;if(k>>>0>15>>>0){c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|1;c[g+l>>2]=k;o=g+(l+4)|0;c[o>>2]=c[o>>2]&-2;p=g+b|0;q=k}else{c[d>>2]=e&1|l|2;e=g+(l+4)|0;c[e>>2]=c[e>>2]|1;p=0;q=0}c[2557696]=q;c[2557699]=p;n=a;return n|0}if((m&2|0)!=0){n=0;return n|0}p=(m&-8)+f|0;if(p>>>0<b>>>0){n=0;return n|0}q=p-b|0;e=m>>>3;a:do{if(m>>>0<256>>>0){l=c[g+(f+8)>>2]|0;k=c[g+(f+12)>>2]|0;o=10230816+(e<<1<<2)|0;do{if((l|0)!=(o|0)){if(l>>>0<j>>>0){Hd();return 0}if((c[l+12>>2]|0)==(i|0)){break}Hd();return 0}}while(0);if((k|0)==(l|0)){c[2557694]=c[2557694]&~(1<<e);break}do{if((k|0)==(o|0)){r=k+8|0}else{if(k>>>0<j>>>0){Hd();return 0}s=k+8|0;if((c[s>>2]|0)==(i|0)){r=s;break}Hd();return 0}}while(0);c[l+12>>2]=k;c[r>>2]=l}else{o=h;s=c[g+(f+24)>>2]|0;t=c[g+(f+12)>>2]|0;do{if((t|0)==(o|0)){u=g+(f+20)|0;v=c[u>>2]|0;if((v|0)==0){w=g+(f+16)|0;x=c[w>>2]|0;if((x|0)==0){y=0;break}else{z=x;A=w}}else{z=v;A=u}while(1){u=z+20|0;v=c[u>>2]|0;if((v|0)!=0){z=v;A=u;continue}u=z+16|0;v=c[u>>2]|0;if((v|0)==0){break}else{z=v;A=u}}if(A>>>0<j>>>0){Hd();return 0}else{c[A>>2]=0;y=z;break}}else{u=c[g+(f+8)>>2]|0;if(u>>>0<j>>>0){Hd();return 0}v=u+12|0;if((c[v>>2]|0)!=(o|0)){Hd();return 0}w=t+8|0;if((c[w>>2]|0)==(o|0)){c[v>>2]=t;c[w>>2]=u;y=t;break}else{Hd();return 0}}}while(0);if((s|0)==0){break}t=c[g+(f+28)>>2]|0;l=10231080+(t<<2)|0;do{if((o|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[2557695]=c[2557695]&~(1<<t);break a}else{if(s>>>0<(c[2557698]|0)>>>0){Hd();return 0}k=s+16|0;if((c[k>>2]|0)==(o|0)){c[k>>2]=y}else{c[s+20>>2]=y}if((y|0)==0){break a}}}while(0);if(y>>>0<(c[2557698]|0)>>>0){Hd();return 0}c[y+24>>2]=s;o=c[g+(f+16)>>2]|0;do{if((o|0)!=0){if(o>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[y+16>>2]=o;c[o+24>>2]=y;break}}}while(0);o=c[g+(f+20)>>2]|0;if((o|0)==0){break}if(o>>>0<(c[2557698]|0)>>>0){Hd();return 0}else{c[y+20>>2]=o;c[o+24>>2]=y;break}}}while(0);if(q>>>0<16>>>0){c[d>>2]=p|c[d>>2]&1|2;y=g+(p|4)|0;c[y>>2]=c[y>>2]|1;n=a;return n|0}else{c[d>>2]=c[d>>2]&1|b|2;c[g+(b+4)>>2]=q|3;d=g+(p|4)|0;c[d>>2]=c[d>>2]|1;Xqc(g+b|0,q);n=a;return n|0}return 0}function Uqc(a,b){a=a|0;b=b|0;var c=0;if(a>>>0<9>>>0){c=Pqc(b)|0;return c|0}else{c=Vqc(a,b)|0;return c|0}return 0}function Vqc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a>>>0<16>>>0?16:a;if((d-1&d|0)==0){e=d}else{a=16;while(1){if(a>>>0<d>>>0){a=a<<1}else{e=a;break}}}if(!((-64-e|0)>>>0>b>>>0)){c[(pd()|0)>>2]=12;f=0;return f|0}if(b>>>0<11>>>0){g=16}else{g=b+11&-8}b=Pqc(e+12+g|0)|0;if((b|0)==0){f=0;return f|0}a=b-8|0;d=a;h=e-1|0;do{if((b&h|0)==0){i=d}else{j=b+h&-e;k=j-8|0;l=a;if((k-l|0)>>>0>15>>>0){m=k}else{m=j+(e-8)|0}j=m;k=m-l|0;l=b-4|0;n=c[l>>2]|0;o=(n&-8)-k|0;if((n&3|0)==0){c[m>>2]=(c[a>>2]|0)+k;c[m+4>>2]=o;i=j;break}else{n=m+4|0;c[n>>2]=o|c[n>>2]&1|2;n=m+(o+4)|0;c[n>>2]=c[n>>2]|1;c[l>>2]=k|c[l>>2]&1|2;l=b+(k-4)|0;c[l>>2]=c[l>>2]|1;Xqc(d,k);i=j;break}}}while(0);d=i+4|0;b=c[d>>2]|0;do{if((b&3|0)!=0){m=b&-8;if(!(m>>>0>(g+16|0)>>>0)){break}a=m-g|0;e=i;c[d>>2]=g|b&1|2;c[e+(g|4)>>2]=a|3;h=e+(m|4)|0;c[h>>2]=c[h>>2]|1;Xqc(e+g|0,a)}}while(0);f=i+8|0;return f|0}function Wqc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if((b|0)==8){e=Pqc(d)|0}else{f=b>>>2;if((b&3|0)!=0|(f|0)==0){g=22;return g|0}if((f+1073741823&f|0)!=0){g=22;return g|0}if((-64-b|0)>>>0<d>>>0){g=12;return g|0}else{e=Vqc(b>>>0<16>>>0?16:b,d)|0;break}}}while(0);if((e|0)==0){g=12;return g|0}c[a>>2]=e;g=0;return g|0}function Xqc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;a:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[2557698]|0;if(i>>>0<l>>>0){Hd()}if((j|0)==(c[2557699]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[2557696]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256>>>0){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=10230816+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){Hd()}if((c[p+12>>2]|0)==(j|0)){break}Hd()}}while(0);if((q|0)==(p|0)){c[2557694]=c[2557694]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){Hd()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}Hd()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){Hd()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){Hd()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){Hd()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{Hd()}}}while(0);if((m|0)==0){n=j;o=k;break}t=c[d+(28-h)>>2]|0;l=10231080+(t<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[2557695]=c[2557695]&~(1<<t);n=j;o=k;break a}else{if(m>>>0<(c[2557698]|0)>>>0){Hd()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break a}}}while(0);if(y>>>0<(c[2557698]|0)>>>0){Hd()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[2557698]|0)>>>0){Hd()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[2557698]|0)>>>0){Hd()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[2557698]|0;if(e>>>0<a>>>0){Hd()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[2557700]|0)){A=(c[2557697]|0)+o|0;c[2557697]=A;c[2557700]=n;c[n+4>>2]=A|1;if((n|0)!=(c[2557699]|0)){return}c[2557699]=0;c[2557696]=0;return}if((f|0)==(c[2557699]|0)){A=(c[2557696]|0)+o|0;c[2557696]=A;c[2557699]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;b:do{if(z>>>0<256>>>0){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=10230816+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){Hd()}if((c[g+12>>2]|0)==(f|0)){break}Hd()}}while(0);if((t|0)==(g|0)){c[2557694]=c[2557694]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){Hd()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}Hd()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){Hd()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){Hd()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){Hd()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{Hd()}}}while(0);if((m|0)==0){break}l=c[d+(b+28)>>2]|0;g=10231080+(l<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[2557695]=c[2557695]&~(1<<l);break b}else{if(m>>>0<(c[2557698]|0)>>>0){Hd()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break b}}}while(0);if(C>>>0<(c[2557698]|0)>>>0){Hd()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[2557698]|0)>>>0){Hd()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[2557698]|0)>>>0){Hd()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[2557699]|0)){F=A;break}c[2557696]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256>>>0){z=o<<1;y=10230816+(z<<2)|0;C=c[2557694]|0;b=1<<o;do{if((C&b|0)==0){c[2557694]=C|b;G=y;H=10230816+(z+2<<2)|0}else{o=10230816+(z+2<<2)|0;d=c[o>>2]|0;if(!(d>>>0<(c[2557698]|0)>>>0)){G=d;H=o;break}Hd()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215>>>0){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=10231080+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[2557695]|0;z=1<<I;if((o&z|0)==0){c[2557695]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=126;break}else{I=I<<1;J=G}}if((L|0)==126){if(K>>>0<(c[2557698]|0)>>>0){Hd()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[2557698]|0;if(J>>>0<I>>>0){Hd()}if(L>>>0<I>>>0){Hd()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function Yqc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0.0,T=0.0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ha=0.0,ia=0.0,ja=0,ka=0,la=0.0,ma=0.0,na=0,oa=0.0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0.0,ya=0,za=0.0,Aa=0,Ba=0.0,Ca=0,Da=0,Ea=0,Fa=0.0,Ga=0,Ha=0.0,Ia=0.0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0.0,zc=0,Ac=0,Bc=0.0,Cc=0.0,Dc=0.0,Ec=0.0,Fc=0.0,Gc=0.0,Hc=0.0,Ic=0,Jc=0,Kc=0.0,Lc=0,Mc=0;g=i;i=i+512|0;h=g|0;if((e|0)==0){j=-149;k=24}else if((e|0)==2){j=-1074;k=53}else if((e|0)==1){j=-1074;k=53}else{l=0.0;i=g;return+l}e=b+4|0;m=b+100|0;do{n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;o=d[n]|0}else{o=$qc(b)|0}}while((zb(o|0)|0)!=0);do{if((o|0)==45|(o|0)==43){n=1-(((o|0)==45)<<1)|0;p=c[e>>2]|0;if(p>>>0<(c[m>>2]|0)>>>0){c[e>>2]=p+1;q=d[p]|0;t=n;break}else{q=$qc(b)|0;t=n;break}}else{q=o;t=1}}while(0);o=0;n=q;while(1){if((n|32|0)!=(a[2189760+o|0]|0)){u=o;v=n;break}do{if(o>>>0<7>>>0){q=c[e>>2]|0;if(q>>>0<(c[m>>2]|0)>>>0){c[e>>2]=q+1;w=d[q]|0;break}else{w=$qc(b)|0;break}}else{w=n}}while(0);q=o+1|0;if(q>>>0<8>>>0){o=q;n=w}else{u=q;v=w;break}}do{if((u|0)==3){x=23}else if((u|0)!=8){w=(f|0)==0;if(!(u>>>0<4>>>0|w)){if((u|0)==8){break}else{x=23;break}}do{if((u|0)==0){if((v|32|0)==110){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;y=d[n]|0}else{y=$qc(b)|0}if((y|32|0)!=97){break}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;z=d[n]|0}else{z=$qc(b)|0}if((z|32|0)!=110){break}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;A=d[n]|0}else{A=$qc(b)|0}if((A|0)==40){B=1}else{if((c[m>>2]|0)==0){l=+r;i=g;return+l}c[e>>2]=(c[e>>2]|0)-1;l=+r;i=g;return+l}while(1){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;C=d[n]|0}else{C=$qc(b)|0}if(!((C-48|0)>>>0<10>>>0|(C-65|0)>>>0<26>>>0)){if(!((C-97|0)>>>0<26>>>0|(C|0)==95)){break}}B=B+1|0}if((C|0)==41){l=+r;i=g;return+l}n=(c[m>>2]|0)==0;if(!n){c[e>>2]=(c[e>>2]|0)-1}if(w){c[(pd()|0)>>2]=22;_qc(b,0);l=0.0;i=g;return+l}if((B|0)==0|n){l=+r;i=g;return+l}else{D=B}while(1){n=D-1|0;c[e>>2]=(c[e>>2]|0)-1;if((n|0)==0){l=+r;break}else{D=n}}i=g;return+l}do{if((v|0)==48){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;E=d[n]|0}else{E=$qc(b)|0}if((E|32|0)!=120){if((c[m>>2]|0)==0){F=48;break}c[e>>2]=(c[e>>2]|0)-1;F=48;break}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;H=d[n]|0;I=0}else{H=$qc(b)|0;I=0}while(1){if((H|0)==46){x=68;break}else if((H|0)!=48){J=H;K=0;L=0;M=0;N=0;O=I;P=0;Q=0;S=1.0;T=0.0;U=0;break}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;H=d[n]|0;I=1;continue}else{H=$qc(b)|0;I=1;continue}}a:do{if((x|0)==68){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;V=d[n]|0}else{V=$qc(b)|0}if((V|0)==48){W=-1;X=-1}else{J=V;K=0;L=0;M=0;N=0;O=I;P=1;Q=0;S=1.0;T=0.0;U=0;break}while(1){n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;Y=d[n]|0}else{Y=$qc(b)|0}if((Y|0)!=48){J=Y;K=0;L=0;M=W;N=X;O=1;P=1;Q=0;S=1.0;T=0.0;U=0;break a}n=wrc(X,W,-1,-1)|0;W=G;X=n}}}while(0);b:while(1){n=J-48|0;do{if(n>>>0<10>>>0){Z=n;x=82}else{o=J|32;q=(J|0)==46;if(!((o-97|0)>>>0<6>>>0|q)){_=J;break b}if(q){if((P|0)==0){$=K;aa=L;ba=K;da=L;ea=O;fa=1;ga=Q;ha=S;ia=T;ja=U;break}else{_=46;break b}}else{Z=(J|0)>57?o-87|0:n;x=82;break}}}while(0);if((x|0)==82){x=0;n=0;do{if((K|0)<(n|0)|(K|0)==(n|0)&L>>>0<8>>>0){ka=Q;la=S;ma=T;na=Z+(U<<4)|0}else{o=0;if((K|0)<(o|0)|(K|0)==(o|0)&L>>>0<14>>>0){oa=S*.0625;ka=Q;la=oa;ma=T+oa*+(Z|0);na=U;break}if(!((Z|0)!=0&(Q|0)==0)){ka=Q;la=S;ma=T;na=U;break}ka=1;la=S;ma=T+S*.5;na=U}}while(0);n=wrc(L,K,1,0)|0;$=G;aa=n;ba=M;da=N;ea=1;fa=P;ga=ka;ha=la;ia=ma;ja=na}n=c[e>>2]|0;if(n>>>0<(c[m>>2]|0)>>>0){c[e>>2]=n+1;J=d[n]|0;K=$;L=aa;M=ba;N=da;O=ea;P=fa;Q=ga;S=ha;T=ia;U=ja;continue}else{J=$qc(b)|0;K=$;L=aa;M=ba;N=da;O=ea;P=fa;Q=ga;S=ha;T=ia;U=ja;continue}}if((O|0)==0){n=(c[m>>2]|0)==0;if(!n){c[e>>2]=(c[e>>2]|0)-1}do{if(w){_qc(b,0)}else{if(n){break}o=c[e>>2]|0;c[e>>2]=o-1;if((P|0)==0){break}c[e>>2]=o-2}}while(0);l=+(t|0)*0.0;i=g;return+l}n=(P|0)==0;o=n?L:N;q=n?K:M;n=0;if((K|0)<(n|0)|(K|0)==(n|0)&L>>>0<8>>>0){n=U;p=K;pa=L;while(1){qa=n<<4;ra=wrc(pa,p,1,0)|0;sa=G;ta=0;if((sa|0)<(ta|0)|(sa|0)==(ta|0)&ra>>>0<8>>>0){n=qa;p=sa;pa=ra}else{ua=qa;break}}}else{ua=U}do{if((_|32|0)==112){pa=Zqc(b,f)|0;p=G;if(!((pa|0)==0&(p|0)==(-2147483648|0))){va=p;wa=pa;break}if(w){_qc(b,0);l=0.0;i=g;return+l}else{if((c[m>>2]|0)==0){va=0;wa=0;break}c[e>>2]=(c[e>>2]|0)-1;va=0;wa=0;break}}else{if((c[m>>2]|0)==0){va=0;wa=0;break}c[e>>2]=(c[e>>2]|0)-1;va=0;wa=0}}while(0);pa=wrc(o<<2|0>>>30,q<<2|o>>>30,-32,-1)|0;p=wrc(pa,G,wa,va)|0;pa=G;if((ua|0)==0){l=+(t|0)*0.0;i=g;return+l}n=0;if((pa|0)>(n|0)|(pa|0)==(n|0)&p>>>0>(-j|0)>>>0){c[(pd()|0)>>2]=34;l=+(t|0)*1.7976931348623157e+308*1.7976931348623157e+308;i=g;return+l}n=j-106|0;qa=(n|0)<0|0?-1:0;if((pa|0)<(qa|0)|(pa|0)==(qa|0)&p>>>0<n>>>0){c[(pd()|0)>>2]=34;l=+(t|0)*2.2250738585072014e-308*2.2250738585072014e-308;i=g;return+l}if((ua|0)>-1){n=ua;oa=T;qa=pa;ra=p;while(1){sa=n<<1;if(oa<.5){xa=oa;ya=sa}else{xa=oa+-1.0;ya=sa|1}za=oa+xa;sa=wrc(ra,qa,-1,-1)|0;ta=G;if((ya|0)>-1){n=ya;oa=za;qa=ta;ra=sa}else{Aa=ya;Ba=za;Ca=ta;Da=sa;break}}}else{Aa=ua;Ba=T;Ca=pa;Da=p}ra=0;qa=xrc(32,0,j,(j|0)<0|0?-1:0)|0;n=wrc(Da,Ca,qa,G)|0;qa=G;if((ra|0)>(qa|0)|(ra|0)==(qa|0)&k>>>0>n>>>0){qa=n;Ea=(qa|0)<0?0:qa}else{Ea=k}do{if((Ea|0)<53){oa=+(t|0);za=+oc(+(+arc(1.0,84-Ea|0)),+oa);if(!((Ea|0)<32&Ba!=0.0)){Fa=Ba;Ga=Aa;Ha=za;Ia=oa;break}qa=Aa&1;Fa=(qa|0)==0?0.0:Ba;Ga=(qa^1)+Aa|0;Ha=za;Ia=oa}else{Fa=Ba;Ga=Aa;Ha=0.0;Ia=+(t|0)}}while(0);oa=Ia*Fa+(Ha+Ia*+(Ga>>>0>>>0))-Ha;if(!(oa!=0.0)){c[(pd()|0)>>2]=34}l=+brc(oa,Da);i=g;return+l}else{F=v}}while(0);p=j+k|0;pa=3-p|0;qa=F;n=0;while(1){if((qa|0)==46){x=137;break}else if((qa|0)!=48){Ja=qa;Ka=0;La=n;Ma=0;Na=0;break}ra=c[e>>2]|0;if(ra>>>0<(c[m>>2]|0)>>>0){c[e>>2]=ra+1;qa=d[ra]|0;n=1;continue}else{qa=$qc(b)|0;n=1;continue}}c:do{if((x|0)==137){qa=c[e>>2]|0;if(qa>>>0<(c[m>>2]|0)>>>0){c[e>>2]=qa+1;Oa=d[qa]|0}else{Oa=$qc(b)|0}if((Oa|0)==48){Pa=-1;Qa=-1}else{Ja=Oa;Ka=1;La=n;Ma=0;Na=0;break}while(1){qa=c[e>>2]|0;if(qa>>>0<(c[m>>2]|0)>>>0){c[e>>2]=qa+1;Ra=d[qa]|0}else{Ra=$qc(b)|0}if((Ra|0)!=48){Ja=Ra;Ka=1;La=1;Ma=Pa;Na=Qa;break c}qa=wrc(Qa,Pa,-1,-1)|0;Pa=G;Qa=qa}}}while(0);n=h|0;c[n>>2]=0;qa=Ja-48|0;ra=(Ja|0)==46;d:do{if(qa>>>0<10>>>0|ra){o=h+496|0;q=Ma;sa=Na;ta=0;Sa=0;Ta=0;Ua=La;Va=Ka;Wa=0;Xa=0;Ya=Ja;Za=qa;_a=ra;while(1){do{if(_a){if((Va|0)==0){$a=Xa;ab=Wa;bb=1;cb=Ua;db=Ta;eb=ta;fb=Sa;gb=ta;hb=Sa}else{ib=q;jb=sa;kb=ta;lb=Sa;mb=Ta;nb=Ua;ob=Wa;pb=Xa;qb=Ya;break d}}else{rb=wrc(Sa,ta,1,0)|0;sb=G;tb=(Ya|0)!=48;if((Wa|0)>=125){if(!tb){$a=Xa;ab=Wa;bb=Va;cb=Ua;db=Ta;eb=sb;fb=rb;gb=q;hb=sa;break}c[o>>2]=c[o>>2]|1;$a=Xa;ab=Wa;bb=Va;cb=Ua;db=Ta;eb=sb;fb=rb;gb=q;hb=sa;break}ub=h+(Wa<<2)|0;if((Xa|0)==0){vb=Za}else{vb=Ya-48+((c[ub>>2]|0)*10|0)|0}c[ub>>2]=vb;ub=Xa+1|0;wb=(ub|0)==9;$a=wb?0:ub;ab=(wb&1)+Wa|0;bb=Va;cb=1;db=tb?rb:Ta;eb=sb;fb=rb;gb=q;hb=sa}}while(0);rb=c[e>>2]|0;if(rb>>>0<(c[m>>2]|0)>>>0){c[e>>2]=rb+1;xb=d[rb]|0}else{xb=$qc(b)|0}rb=xb-48|0;sb=(xb|0)==46;if(rb>>>0<10>>>0|sb){q=gb;sa=hb;ta=eb;Sa=fb;Ta=db;Ua=cb;Va=bb;Wa=ab;Xa=$a;Ya=xb;Za=rb;_a=sb}else{yb=gb;Ab=hb;Bb=eb;Cb=fb;Db=db;Eb=cb;Fb=bb;Gb=ab;Hb=$a;Ib=xb;x=160;break}}}else{yb=Ma;Ab=Na;Bb=0;Cb=0;Db=0;Eb=La;Fb=Ka;Gb=0;Hb=0;Ib=Ja;x=160}}while(0);if((x|0)==160){ra=(Fb|0)==0;ib=ra?Bb:yb;jb=ra?Cb:Ab;kb=Bb;lb=Cb;mb=Db;nb=Eb;ob=Gb;pb=Hb;qb=Ib}ra=(nb|0)!=0;do{if(ra){if((qb|32|0)!=101){x=169;break}qa=Zqc(b,f)|0;_a=G;do{if((qa|0)==0&(_a|0)==(-2147483648|0)){if(w){_qc(b,0);l=0.0;i=g;return+l}else{if((c[m>>2]|0)==0){Jb=0;Kb=0;break}c[e>>2]=(c[e>>2]|0)-1;Jb=0;Kb=0;break}}else{Jb=_a;Kb=qa}}while(0);qa=wrc(Kb,Jb,jb,ib)|0;Lb=G;Nb=qa}else{x=169}}while(0);do{if((x|0)==169){if(!((qb|0)>-1)){Lb=ib;Nb=jb;break}if((c[m>>2]|0)==0){Lb=ib;Nb=jb;break}c[e>>2]=(c[e>>2]|0)-1;Lb=ib;Nb=jb}}while(0);if(!ra){c[(pd()|0)>>2]=22;_qc(b,0);l=0.0;i=g;return+l}qa=c[n>>2]|0;if((qa|0)==0){l=+(t|0)*0.0;i=g;return+l}_a=0;do{if((Nb|0)==(lb|0)&(Lb|0)==(kb|0)&((kb|0)<(_a|0)|(kb|0)==(_a|0)&lb>>>0<10>>>0)){if(!(k>>>0>30>>>0)){if((qa>>>(k>>>0)|0)!=0){break}}l=+(t|0)*+(qa>>>0>>>0);i=g;return+l}}while(0);qa=(j|0)/-2|0;_a=(qa|0)<0|0?-1:0;if((Lb|0)>(_a|0)|(Lb|0)==(_a|0)&Nb>>>0>qa>>>0){c[(pd()|0)>>2]=34;l=+(t|0)*1.7976931348623157e+308*1.7976931348623157e+308;i=g;return+l}qa=j-106|0;_a=(qa|0)<0|0?-1:0;if((Lb|0)<(_a|0)|(Lb|0)==(_a|0)&Nb>>>0<qa>>>0){c[(pd()|0)>>2]=34;l=+(t|0)*2.2250738585072014e-308*2.2250738585072014e-308;i=g;return+l}if((pb|0)==0){Ob=ob}else{if((pb|0)<9){qa=h+(ob<<2)|0;_a=pb;ra=c[qa>>2]|0;do{ra=ra*10|0;_a=_a+1|0;}while((_a|0)<9);c[qa>>2]=ra}Ob=ob+1|0}_a=Nb;do{if((mb|0)<9){if(!((mb|0)<=(_a|0)&(_a|0)<18)){break}if((_a|0)==9){l=+(t|0)*+((c[n>>2]|0)>>>0>>>0);i=g;return+l}if((_a|0)<9){l=+(t|0)*+((c[n>>2]|0)>>>0>>>0)/+(c[1586344+(8-_a<<2)>>2]|0);i=g;return+l}Za=k+27+(_a*-3|0)|0;Ya=c[n>>2]|0;if((Za|0)<=30){if((Ya>>>(Za>>>0)|0)!=0){break}}l=+(t|0)*+(Ya>>>0>>>0)*+(c[1586344+(_a-10<<2)>>2]|0);i=g;return+l}}while(0);n=(_a|0)%9|0;if((n|0)==0){Pb=0;Qb=Ob;Rb=0;Sb=_a}else{ra=(_a|0)>-1?n:n+9|0;n=c[1586344+(8-ra<<2)>>2]|0;do{if((Ob|0)==0){Tb=0;Ub=0;Vb=_a}else{qa=1e9/(n|0)|0;Ya=_a;Za=0;Xa=0;Wa=0;while(1){Va=h+(Xa<<2)|0;Ua=c[Va>>2]|0;Ta=((Ua>>>0)/(n>>>0)|0)+Wa|0;c[Va>>2]=Ta;Wb=ca((Ua>>>0)%(n>>>0)|0,qa)|0;Ua=Xa+1|0;if((Xa|0)==(Za|0)&(Ta|0)==0){Xb=Ua&127;Yb=Ya-9|0}else{Xb=Za;Yb=Ya}if((Ua|0)==(Ob|0)){break}else{Ya=Yb;Za=Xb;Xa=Ua;Wa=Wb}}if((Wb|0)==0){Tb=Ob;Ub=Xb;Vb=Yb;break}c[h+(Ob<<2)>>2]=Wb;Tb=Ob+1|0;Ub=Xb;Vb=Yb}}while(0);Pb=Ub;Qb=Tb;Rb=0;Sb=9-ra+Vb|0}e:while(1){n=h+(Pb<<2)|0;if((Sb|0)<18){_a=Qb;Wa=Rb;while(1){Xa=0;Za=_a+127|0;Ya=_a;while(1){qa=Za&127;Ua=h+(qa<<2)|0;Ta=c[Ua>>2]|0;Va=wrc(Ta<<29|0>>>3,0<<29|Ta>>>3,Xa,0)|0;Ta=G;Sa=0;if(Ta>>>0>Sa>>>0|Ta>>>0==Sa>>>0&Va>>>0>1e9>>>0){Sa=Frc(Va,Ta,1e9,0)|0;ta=Grc(Va,Ta,1e9,0)|0;Zb=Sa;_b=ta}else{Zb=0;_b=Va}c[Ua>>2]=_b;Ua=(qa|0)==(Pb|0);if((qa|0)!=(Ya+127&127|0)|Ua){$b=Ya}else{$b=(_b|0)==0?qa:Ya}if(Ua){break}else{Xa=Zb;Za=qa-1|0;Ya=$b}}Ya=Wa-29|0;if((Zb|0)==0){_a=$b;Wa=Ya}else{ac=Ya;bc=$b;cc=Zb;break}}}else{if((Sb|0)==18){dc=Qb;ec=Rb}else{fc=Pb;gc=Qb;hc=Rb;ic=Sb;break}while(1){if(!((c[n>>2]|0)>>>0<9007199>>>0)){fc=Pb;gc=dc;hc=ec;ic=18;break e}Wa=0;_a=dc+127|0;Ya=dc;while(1){Za=_a&127;Xa=h+(Za<<2)|0;qa=c[Xa>>2]|0;Ua=wrc(qa<<29|0>>>3,0<<29|qa>>>3,Wa,0)|0;qa=G;Va=0;if(qa>>>0>Va>>>0|qa>>>0==Va>>>0&Ua>>>0>1e9>>>0){Va=Frc(Ua,qa,1e9,0)|0;ta=Grc(Ua,qa,1e9,0)|0;jc=Va;kc=ta}else{jc=0;kc=Ua}c[Xa>>2]=kc;Xa=(Za|0)==(Pb|0);if((Za|0)!=(Ya+127&127|0)|Xa){lc=Ya}else{lc=(kc|0)==0?Za:Ya}if(Xa){break}else{Wa=jc;_a=Za-1|0;Ya=lc}}Ya=ec-29|0;if((jc|0)==0){dc=lc;ec=Ya}else{ac=Ya;bc=lc;cc=jc;break}}}n=Pb+127&127;if((n|0)==(bc|0)){Ya=bc+127&127;_a=h+((bc+126&127)<<2)|0;c[_a>>2]=c[_a>>2]|c[h+(Ya<<2)>>2];mc=Ya}else{mc=bc}c[h+(n<<2)>>2]=cc;Pb=n;Qb=mc;Rb=ac;Sb=Sb+9|0}f:while(1){nc=gc+1&127;ra=h+((gc+127&127)<<2)|0;n=fc;Ya=hc;_a=ic;while(1){Wa=(_a|0)==18;Za=(_a|0)>27?9:1;pc=n;qc=Ya;while(1){Xa=0;while(1){if((Xa|0)>=2){rc=Xa;break}Ua=Xa+pc&127;if((Ua|0)==(gc|0)){rc=2;break}ta=c[h+(Ua<<2)>>2]|0;Ua=c[1586336+(Xa<<2)>>2]|0;if(ta>>>0<Ua>>>0){rc=2;break}if(ta>>>0>Ua>>>0){rc=Xa;break}else{Xa=Xa+1|0}}if((rc|0)==2&Wa){break f}sc=Za+qc|0;if((pc|0)==(gc|0)){pc=gc;qc=sc}else{break}}Wa=(1<<Za)-1|0;Xa=1e9>>>(Za>>>0);tc=_a;uc=pc;Ua=pc;vc=0;do{ta=h+(Ua<<2)|0;Va=c[ta>>2]|0;qa=(Va>>>(Za>>>0))+vc|0;c[ta>>2]=qa;vc=ca(Va&Wa,Xa)|0;Va=(Ua|0)==(uc|0)&(qa|0)==0;Ua=Ua+1&127;tc=Va?tc-9|0:tc;uc=Va?Ua:uc;}while((Ua|0)!=(gc|0));if((vc|0)==0){n=uc;Ya=sc;_a=tc;continue}if((nc|0)!=(uc|0)){break}c[ra>>2]=c[ra>>2]|1;n=uc;Ya=sc;_a=tc}c[h+(gc<<2)>>2]=vc;fc=uc;gc=nc;hc=sc;ic=tc}_a=pc&127;if((_a|0)==(gc|0)){c[h+(nc-1<<2)>>2]=0;wc=nc}else{wc=gc}oa=+((c[h+(_a<<2)>>2]|0)>>>0>>>0);_a=pc+1&127;if((_a|0)==(wc|0)){Ya=wc+1&127;c[h+(Ya-1<<2)>>2]=0;xc=Ya}else{xc=wc}za=+(t|0);yc=za*(oa*1.0e9+ +((c[h+(_a<<2)>>2]|0)>>>0>>>0));_a=qc+53|0;Ya=_a-j|0;if((Ya|0)<(k|0)){zc=(Ya|0)<0?0:Ya;Ac=1}else{zc=k;Ac=0}if((zc|0)<53){oa=+oc(+(+arc(1.0,105-zc|0)),+yc);Bc=+Mb(+yc,+(+arc(1.0,53-zc|0)));Cc=oa;Dc=Bc;Ec=oa+(yc-Bc)}else{Cc=0.0;Dc=0.0;Ec=yc}n=pc+2&127;do{if((n|0)==(xc|0)){Fc=Dc}else{ra=c[h+(n<<2)>>2]|0;do{if(ra>>>0<5e8>>>0){if((ra|0)==0){if((pc+3&127|0)==(xc|0)){Gc=Dc;break}}Gc=za*.25+Dc}else{if(ra>>>0>5e8>>>0){Gc=za*.75+Dc;break}if((pc+3&127|0)==(xc|0)){Gc=za*.5+Dc;break}else{Gc=za*.75+Dc;break}}}while(0);if((53-zc|0)<=1){Fc=Gc;break}if(+Mb(+Gc,+1.0)!=0.0){Fc=Gc;break}Fc=Gc+1.0}}while(0);za=Ec+Fc-Cc;do{if((_a&2147483647|0)>(-2-p|0)){if(+R(+za)<9007199254740992.0){Hc=za;Ic=Ac;Jc=qc}else{Hc=za*.5;Ic=(Ac|0)!=0&(zc|0)==(Ya|0)?0:Ac;Jc=qc+1|0}if((Jc+53|0)<=(pa|0)){if(!((Ic|0)!=0&Fc!=0.0)){Kc=Hc;Lc=Jc;break}}c[(pd()|0)>>2]=34;Kc=Hc;Lc=Jc}else{Kc=za;Lc=qc}}while(0);l=+brc(Kc,Lc);i=g;return+l}}while(0);if((c[m>>2]|0)!=0){c[e>>2]=(c[e>>2]|0)-1}c[(pd()|0)>>2]=22;_qc(b,0);l=0.0;i=g;return+l}}while(0);do{if((x|0)==23){b=(c[m>>2]|0)==0;if(!b){c[e>>2]=(c[e>>2]|0)-1}if(u>>>0<4>>>0|(f|0)==0|b){break}else{Mc=u}do{c[e>>2]=(c[e>>2]|0)-1;Mc=Mc-1|0;}while(Mc>>>0>3>>>0)}}while(0);l=+(t|0)*s;i=g;return+l}function Zqc(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=a+4|0;f=c[e>>2]|0;g=a+100|0;if(f>>>0<(c[g>>2]|0)>>>0){c[e>>2]=f+1;h=d[f]|0}else{h=$qc(a)|0}do{if((h|0)==45|(h|0)==43){f=(h|0)==45|0;i=c[e>>2]|0;if(i>>>0<(c[g>>2]|0)>>>0){c[e>>2]=i+1;j=d[i]|0}else{j=$qc(a)|0}if((j-48|0)>>>0<10>>>0|(b|0)==0){k=f;l=j;break}if((c[g>>2]|0)==0){k=f;l=j;break}c[e>>2]=(c[e>>2]|0)-1;k=f;l=j}else{k=0;l=h}}while(0);if((l-48|0)>>>0>9>>>0){if((c[g>>2]|0)==0){m=-2147483648;n=0;return(G=m,n)|0}c[e>>2]=(c[e>>2]|0)-1;m=-2147483648;n=0;return(G=m,n)|0}else{o=l;p=0}while(1){q=o-48+p|0;l=c[e>>2]|0;if(l>>>0<(c[g>>2]|0)>>>0){c[e>>2]=l+1;r=d[l]|0}else{r=$qc(a)|0}if(!((r-48|0)>>>0<10>>>0&(q|0)<214748364)){break}o=r;p=q*10|0}p=q;o=(q|0)<0|0?-1:0;if((r-48|0)>>>0<10>>>0){q=r;l=o;h=p;while(1){j=Erc(h,l,10,0)|0;b=G;f=wrc(q,(q|0)<0|0?-1:0,-48,-1)|0;i=wrc(f,G,j,b)|0;b=G;j=c[e>>2]|0;if(j>>>0<(c[g>>2]|0)>>>0){c[e>>2]=j+1;s=d[j]|0}else{s=$qc(a)|0}j=21474836;if((s-48|0)>>>0<10>>>0&((b|0)<(j|0)|(b|0)==(j|0)&i>>>0<2061584302>>>0)){q=s;l=b;h=i}else{t=s;u=b;v=i;break}}}else{t=r;u=o;v=p}if((t-48|0)>>>0<10>>>0){do{t=c[e>>2]|0;if(t>>>0<(c[g>>2]|0)>>>0){c[e>>2]=t+1;w=d[t]|0}else{w=$qc(a)|0}}while((w-48|0)>>>0<10>>>0)}if((c[g>>2]|0)!=0){c[e>>2]=(c[e>>2]|0)-1}e=(k|0)!=0;k=xrc(0,0,v,u)|0;m=e?G:u;n=e?k:v;return(G=m,n)|0}function _qc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;c[a+104>>2]=b;d=c[a+8>>2]|0;e=c[a+4>>2]|0;f=d-e|0;c[a+108>>2]=f;if((b|0)!=0&(f|0)>(b|0)){c[a+100>>2]=e+b;return}else{c[a+100>>2]=d;return}}function $qc(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b+104|0;f=c[e>>2]|0;if((f|0)==0){g=3}else{if((c[b+108>>2]|0)<(f|0)){g=3}}do{if((g|0)==3){f=drc(b)|0;if((f|0)<0){break}h=c[e>>2]|0;i=c[b+8>>2]|0;do{if((h|0)==0){g=8}else{j=c[b+4>>2]|0;k=h-(c[b+108>>2]|0)-1|0;if((i-j|0)<=(k|0)){g=8;break}c[b+100>>2]=j+k}}while(0);if((g|0)==8){c[b+100>>2]=i}h=c[b+4>>2]|0;if((i|0)!=0){k=b+108|0;c[k>>2]=i+1-h+(c[k>>2]|0)}k=h-1|0;if((d[k]|0|0)==(f|0)){l=f;return l|0}a[k]=f;l=f;return l|0}}while(0);c[b+100>>2]=0;l=-1;return l|0}function arc(a,b){a=+a;b=b|0;var d=0.0,e=0,f=0.0,g=0;do{if((b|0)>1023){d=a*8.98846567431158e+307;e=b-1023|0;if((e|0)<=1023){f=d;g=e;break}e=b-2046|0;f=d*8.98846567431158e+307;g=(e|0)>1023?1023:e}else{if(!((b|0)<-1022)){f=a;g=b;break}d=a*2.2250738585072014e-308;e=b+1022|0;if(!((e|0)<-1022)){f=d;g=e;break}e=b+2044|0;f=d*2.2250738585072014e-308;g=(e|0)<-1022?-1022:e}}while(0);return+(f*(c[k>>2]=0<<20|0>>>12,c[k+4>>2]=g+1023<<20|0>>>12,+h[k>>3]))}function brc(a,b){a=+a;b=b|0;return+(+arc(a,b))}function crc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+74|0;e=a[d]|0;a[d]=e-1&255|e;e=b+20|0;d=b+44|0;if((c[e>>2]|0)>>>0>(c[d>>2]|0)>>>0){Ee[c[b+36>>2]&511](b,0,0)|0}c[b+16>>2]=0;c[b+28>>2]=0;c[e>>2]=0;e=b|0;f=c[e>>2]|0;if((f&20|0)==0){g=c[d>>2]|0;c[b+8>>2]=g;c[b+4>>2]=g;h=0;return h|0}if((f&4|0)==0){h=-1;return h|0}c[e>>2]=f|32;h=-1;return h|0}function drc(a){a=a|0;var b=0,e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;if((c[a+8>>2]|0)==0){if((crc(a)|0)==0){f=3}else{g=-1}}else{f=3}do{if((f|0)==3){if((Ee[c[a+32>>2]&511](a,e,1)|0)!=1){g=-1;break}g=d[e]|0}}while(0);i=b;return g|0}function erc(a){a=a|0;return+(+frc(a,0))}function frc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0.0,j=0,k=0;d=i;i=i+112|0;e=d|0;mrc(e|0,0,112)|0;f=e+4|0;c[f>>2]=a;g=e+8|0;c[g>>2]=-1;c[e+44>>2]=a;c[e+76>>2]=-1;_qc(e,0);h=+Yqc(e,1,1);j=(c[f>>2]|0)-(c[g>>2]|0)+(c[e+108>>2]|0)|0;if((b|0)==0){i=d;return+h}if((j|0)==0){k=a}else{k=a+j|0}c[b>>2]=k;i=d;return+h}function grc(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==0){e=0;return e|0}else{f=d;g=b;h=c}while(1){i=a[g]|0;j=a[h]|0;if(!(i<<24>>24==j<<24>>24)){break}c=f-1|0;if((c|0)==0){e=0;k=5;break}else{f=c;g=g+1|0;h=h+1|0}}if((k|0)==5){return e|0}e=(i&255)-(j&255)|0;return e|0}function hrc(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[b]|0;a:do{if(e<<24>>24==0){f=c;g=0}else{h=b;i=c;j=e;while(1){k=a[i]|0;if(k<<24>>24==0){f=i;g=j;break a}if(!(j<<24>>24==k<<24>>24)){k=vrc(j&255|0)|0;if((k|0)!=(vrc(d[i]|0|0)|0)){break}}k=h+1|0;l=i+1|0;m=a[k]|0;if(m<<24>>24==0){f=l;g=0;break a}else{h=k;i=l;j=m}}f=i;g=a[h]|0}}while(0);e=vrc(g&255|0)|0;return e-(vrc(d[f]|0|0)|0)|0}function irc(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a[b]|0;e=a[c]|0;if(d<<24>>24!=e<<24>>24|d<<24>>24==0|e<<24>>24==0){f=d;g=e;h=f&255;i=g&255;j=h-i|0;return j|0}else{k=b;l=c}while(1){c=k+1|0;b=l+1|0;e=a[c]|0;d=a[b]|0;if(e<<24>>24!=d<<24>>24|e<<24>>24==0|d<<24>>24==0){f=e;g=d;break}else{k=c;l=b}}h=f&255;i=g&255;j=h-i|0;return j|0}function jrc(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((e|0)==0){f=0;return f|0}g=a[b]|0;a:do{if(g<<24>>24==0){h=c;i=0}else{j=b;k=c;l=e;m=g;while(1){n=l-1|0;o=a[k]|0;if(o<<24>>24==0|(n|0)==0){h=k;i=m;break a}if(!(m<<24>>24==o<<24>>24)){o=vrc(m&255|0)|0;if((o|0)!=(vrc(d[k]|0|0)|0)){break}}o=j+1|0;p=k+1|0;q=a[o]|0;if(q<<24>>24==0){h=p;i=0;break a}else{j=o;k=p;l=n;m=q}}h=k;i=a[j]|0}}while(0);g=vrc(i&255|0)|0;f=g-(vrc(d[h]|0|0)|0)|0;return f|0}function krc(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((e|0)==0){f=0;return f|0}g=a[b]|0;a:do{if(g<<24>>24==0){h=c;i=0}else{j=b;k=c;l=e;m=g;while(1){n=l-1|0;o=a[k]|0;if(!((n|0)!=0&o<<24>>24!=0&m<<24>>24==o<<24>>24)){h=k;i=m;break a}o=j+1|0;p=k+1|0;q=a[o]|0;if(q<<24>>24==0){h=p;i=0;break}else{j=o;k=p;l=n;m=q}}}}while(0);f=(i&255)-(d[h]|0)|0;return f|0}function lrc(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function mrc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+e|0;if((e|0)>=20){d=d&255;g=b&3;h=d|d<<8|d<<16|d<<24;i=f&~3;if(g){g=b+4-g|0;while((b|0)<(g|0)){a[b]=d;b=b+1|0}}while((b|0)<(i|0)){c[b>>2]=h;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}return b-e|0}function nrc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((e|0)>=4096)return uc(b|0,d|0,e|0)|0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function orc(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if((c|0)<(b|0)&(b|0)<(c+d|0)){e=b;c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}b=e}else{nrc(b,c,d)|0}return b|0}function prc(b,c){b=b|0;c=c|0;var d=0;do{a[b+d|0]=a[c+d|0];d=d+1|0}while(a[c+(d-1)|0]|0);return b|0}function qrc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;c=b+d>>>0;d=c>>>0<b>>>0|0;if(e>>>0<a>>>0){c=c+1>>>0;d=d|!c}return(G=c,H=d,e|0)|0}function rrc(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function src(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function trc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;v=v+1|0;c[a>>2]=v;while((e|0)<40){if((c[d+(e<<2)>>2]|0)==0){c[d+(e<<2)>>2]=v;c[d+((e<<2)+4)>>2]=b;c[d+((e<<2)+8)>>2]=0;return 0}e=e+2|0}zc(116);zc(111);zc(111);zc(32);zc(109);zc(97);zc(110);zc(121);zc(32);zc(115);zc(101);zc(116);zc(106);zc(109);zc(112);zc(115);zc(32);zc(105);zc(110);zc(32);zc(97);zc(32);zc(102);zc(117);zc(110);zc(99);zc(116);zc(105);zc(111);zc(110);zc(32);zc(99);zc(97);zc(108);zc(108);zc(44);zc(32);zc(98);zc(117);zc(105);zc(108);zc(100);zc(32);zc(119);zc(105);zc(116);zc(104);zc(32);zc(97);zc(32);zc(104);zc(105);zc(103);zc(104);zc(101);zc(114);zc(32);zc(118);zc(97);zc(108);zc(117);zc(101);zc(32);zc(102);zc(111);zc(114);zc(32);zc(77);zc(65);zc(88);zc(95);zc(83);zc(69);zc(84);zc(74);zc(77);zc(80);zc(83);zc(10);da(0);return 0}function urc(a,b){a=a|0;b=b|0;var d=0,e=0;while((d|0)<20){e=c[b+(d<<2)>>2]|0;if((e|0)==0)break;if((e|0)==(a|0)){return c[b+((d<<2)+4)>>2]|0}d=d+2|0}return 0}function vrc(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function wrc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(G=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function xrc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(G=e,a-c>>>0|0)|0}function yrc(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}G=a<<c-32;return 0}function zrc(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=0;return b>>>c-32|0}function Arc(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=(b|0)<0?-1:0;return b>>c-32|0}function Brc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ca(d,c)|0;f=a>>>16;a=(e>>>16)+(ca(d,f)|0)|0;d=b>>>16;b=ca(d,c)|0;return(G=(a>>>16)+(ca(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function Crc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=xrc(e^a,f^b,e,f)|0;b=G;a=g^e;e=h^f;f=xrc((Hrc(i,b,xrc(g^c,h^d,g,h)|0,G,0)|0)^a,G^e,a,e)|0;return(G=G,f)|0}function Drc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=xrc(h^a,j^b,h,j)|0;b=G;Hrc(m,b,xrc(k^d,l^e,k,l)|0,G,g)|0;l=xrc(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=G;i=f;return(G=j,l)|0}function Erc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=Brc(e,a)|0;f=G;return(G=(ca(b,a)|0)+(ca(d,e)|0)+f|f&0,c|0|0)|0}function Frc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Hrc(a,b,c,d,0)|0;return(G=G,e)|0}function Grc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;Hrc(a,b,d,e,g)|0;i=f;return(G=c[g+4>>2]|0,c[g>>2]|0)|0}function Hrc(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(G=n,o)|0}else{if(!m){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(G=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(G=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(G=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((src(l|0)|0)>>>0);return(G=n,o)|0}p=(rrc(l|0)|0)-(rrc(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}else{if(!m){r=(rrc(l|0)|0)-(rrc(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(rrc(j|0)|0)+33-(rrc(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(G=n,o)|0}else{p=src(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(G=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;F=0;H=0}else{g=d|0|0;d=k|e&0;e=wrc(g,d,-1,-1)|0;k=G;i=w;w=v;v=u;u=t;t=s;s=0;while(1){I=w>>>31|i<<1;J=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;xrc(e,k,j,a)|0;b=G;h=b>>31|((b|0)<0?-1:0)<<1;K=h&1;L=xrc(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=G;b=t-1|0;if((b|0)==0){break}else{i=I;w=J;v=M;u=L;t=b;s=K}}B=I;C=J;D=M;E=L;F=0;H=K}K=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(K|0)>>>31|(B|C)<<1|(C<<1|K>>>31)&0|F;o=(K<<1|0>>>31)&-2|H;return(G=n,o)|0}function Irc(a){a=+a;return+Lb(+a)}function Jrc(a){a=+a;return+Z(+a)}function Krc(a){a=+a;return+aa(+a)}function Lrc(a){a=+a;return+X(+a)}function Mrc(a){a=+a;return+U(+a)}function Nrc(a){a=+a;return+R(+a)}function Orc(a){a=+a;return+Ub(+a)}function Prc(a){a=+a;return+W(+a)}function Qrc(a){a=+a;return+$(+a)}function Rrc(a){a=+a;return+V(+a)}function Src(a){a=+a;return+tc(+a)}function Trc(a){a=+a;return+Y(+a)}function Urc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Cd(a|0,b|0,c|0,d|0)}function Vrc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return me[a&255](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function Wrc(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;i=i|0;ne[a&3](b|0,c|0,d|0,e|0,f|0,g|0,+h,i|0)}function Xrc(a,b,c){a=a|0;b=b|0;c=+c;oe[a&3](b|0,+c)}function Yrc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;pe[a&1023](b|0,c|0,d|0,e|0,f|0)}function Zrc(a,b){a=a|0;b=b|0;qe[a&1023](b|0)}function _rc(a,b,c){a=a|0;b=b|0;c=c|0;re[a&1023](b|0,c|0)}function $rc(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return se[a&127](b|0,c|0,d|0,e|0,f|0,g|0)|0}function asc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;te[a&7](b|0,c|0,d|0,e|0,+f)}function bsc(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=+f;g=g|0;h=h|0;i=i|0;ue[a&3](b|0,c|0,d|0,+e,+f,g|0,h|0,i|0)}function csc(a,b){a=a|0;b=b|0;return ve[a&4095](b|0)|0}function dsc(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;we[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function esc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;xe[a&7](b|0,c|0,+d,e|0)}function fsc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;ye[a&3](b|0,c|0,+d,e|0)}function gsc(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=+l;ze[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,+l)}function hsc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return+Ae[a&7](b|0,c|0,d|0)}function isc(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;return Be[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)|0}function jsc(a){a=a|0;return Ce[a&1]()|0}function ksc(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=+i;j=+j;k=k|0;return+De[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,+i,+j,k|0)}function lsc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ee[a&511](b|0,c|0,d|0)|0}function msc(a,b,c,d,e,f,g,h){a=a|0;b=+b;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return Fe[a&7](+b,+c,d|0,e|0,f|0,g|0,h|0)|0}function nsc(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;Ge[a&255](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function osc(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=+i;He[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,+i)}function psc(a,b,c){a=a|0;b=b|0;c=c|0;return+Ie[a&3](b|0,c|0)}function qsc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;return Je[a&31](b|0,c|0,+d)|0}function rsc(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return Ke[a&63](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)|0}function ssc(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;return Le[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0,m|0,n|0,o|0,p|0)|0}function tsc(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=+f;g=g|0;Me[a&3](b|0,c|0,d|0,+e,+f,g|0)}function usc(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;return Ne[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0)|0}function vsc(a,b){a=a|0;b=+b;return+Oe[a&31](+b)}function wsc(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;Pe[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0,m|0,n|0,o|0)}function xsc(a,b,c,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;return Qe[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0,m|0)|0}function ysc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;h=h|0;Re[a&7](b|0,c|0,d|0,e|0,f|0,+g,h|0)}function zsc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;Se[a&1023](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function Asc(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;Te[a&255](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function Bsc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;Ue[a&3](b|0,c|0,d|0,e|0,f|0,g|0,+h)}function Csc(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;Ve[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0)}function Dsc(a,b,c){a=a|0;b=b|0;c=c|0;return We[a&2047](b|0,c|0)|0}function Esc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return Xe[a&511](b|0,c|0,d|0,e|0,f|0)|0}function Fsc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return+Ye[a&3](b|0,c|0,d|0)}function Gsc(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;return+Ze[a&15](b|0,+c,+d)}function Hsc(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;_e[a&511](b|0,c|0,d|0,e|0,f|0,g|0)}function Isc(a,b,c,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;i=i|0;j=j|0;k=k|0;l=+l;m=m|0;return $e[a&3](b|0,c|0,d|0,e|0,f|0,g|0,+h,i|0,j|0,k|0,+l,m|0)|0}function Jsc(a,b,c,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;af[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0,m|0)}function Ksc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;bf[a&15](b|0,c|0,d|0,+e)}function Lsc(a,b,c){a=a|0;b=b|0;c=+c;return+cf[a&15](b|0,+c)}function Msc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;g=g|0;h=h|0;df[a&7](b|0,c|0,d|0,e|0,+f,g|0,h|0)}function Nsc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ef[a&4095](b|0,c|0,d|0)}function Osc(a){a=a|0;ff[a&15]()}function Psc(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;return gf[a&63](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)|0}function Qsc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return hf[a&1023](b|0,c|0,d|0,e|0)|0}function Rsc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;jf[a&3](b|0,c|0,+d)}function Ssc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=f|0;kf[a&3](b|0,c|0,+d,+e,f|0)}function Tsc(a,b,c,d,e,f,g,h,i,j,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=+i;j=+j;k=+k;l=+l;m=+m;lf[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,+i,+j,+k,+l,+m)}function Usc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;mf[a&2047](b|0,c|0,d|0,e|0)}function Vsc(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;da(0);return 0}function Wsc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;h=h|0;da(1)}function Xsc(a,b){a=a|0;b=+b;da(2)}function Ysc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;da(3)}function Zsc(a){a=a|0;da(4)}function _sc(a,b){a=a|0;b=b|0;da(5)}function $sc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;da(6);return 0}function atc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;da(7)}function btc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=f|0;g=g|0;h=h|0;da(8)}function ctc(a){a=a|0;da(9);return 0}function dtc(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;da(10)}function etc(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;da(11)}function ftc(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;da(12)}function gtc(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=+k;da(13)}function htc(a,b,c){a=a|0;b=b|0;c=c|0;da(14);return 0.0}function itc(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;da(15);return 0}function jtc(){da(16);return 0}function ktc(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;i=+i;j=j|0;da(17);return 0.0}function ltc(a,b,c){a=a|0;b=b|0;c=c|0;da(18);return 0}function mtc(a,b,c,d,e,f,g){a=+a;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;da(19);return 0}function ntc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;da(20)}function otc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;da(21)}function ptc(a,b){a=a|0;b=b|0;da(22);return 0.0}function qtc(a,b,c){a=a|0;b=b|0;c=+c;da(23);return 0}function rtc(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;da(24);return 0}function stc(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;da(25);return 0}function ttc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=f|0;da(26)}function utc(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;da(27);return 0}function vtc(a){a=+a;da(28);return 0.0}function wtc(a,b,c,d,e,f,g,h,i,j,k,l,m,n){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;da(29)}function xtc(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;da(30);return 0}function ytc(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;g=g|0;da(31)}function ztc(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;da(32)}function Atc(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;da(33)}function Btc(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;da(34)}function Ctc(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;da(35)}function Dtc(a,b){a=a|0;b=b|0;da(36);return 0}function Etc(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;da(37);return 0}function Ftc(a,b,c){a=a|0;b=b|0;c=c|0;da(38);return 0.0}function Gtc(a,b,c){a=a|0;b=+b;c=+c;da(39);return 0.0}function Htc(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;da(40)}function Itc(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;h=h|0;i=i|0;j=j|0;k=+k;l=l|0;da(41);return 0}function Jtc(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;da(42)}function Ktc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;da(43)}function Ltc(a,b){a=a|0;b=+b;da(44);return 0.0}function Mtc(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=f|0;g=g|0;da(45)}function Ntc(a,b,c){a=a|0;b=b|0;c=c|0;da(46)}function Otc(){da(47)}function Ptc(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;da(48);return 0}function Qtc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;da(49);return 0}function Rtc(a,b,c){a=a|0;b=b|0;c=+c;da(50)}function Stc(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=e|0;da(51)}function Ttc(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;i=+i;j=+j;k=+k;l=+l;da(52)}function Utc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;da(53)}




// EMSCRIPTEN_END_FUNCS
var me=[Vsc,Vsc,RDb,Vsc,QDb,Vsc,yP,Vsc,I9b,Vsc,AP,Vsc,R9b,Vsc,kEb,Vsc,fEb,Vsc,$xb,Vsc,Txb,Vsc,jEb,Vsc,zP,Vsc,c7b,Vsc,QA,Vsc,g7b,Vsc,F6b,Vsc,SDb,Vsc,a7b,Vsc,Q9b,Vsc,uP,Vsc,$A,Vsc,e7b,Vsc,I6b,Vsc,VDb,Vsc,wA,Vsc,bEb,Vsc,vP,Vsc,_xb,Vsc,Uxb,Vsc,JRb,Vsc,wP,Vsc,BP,Vsc,eEb,Vsc,z7b,Vsc,Wxb,Vsc,z$a,Vsc,hEb,Vsc,WDb,Vsc,CP,Vsc,mEb,Vsc,sP,Vsc,XDb,Vsc,$q,Vsc,Qxb,Vsc,ayb,Vsc,z6b,Vsc,DP,Vsc,iEb,Vsc,Yxb,Vsc,v7b,Vsc,cEb,Vsc,gxb,Vsc,Zxb,Vsc,EP,Vsc,byb,Vsc,L6b,Vsc,Xxb,Vsc,FVb,Vsc,dEb,Vsc,JA,Vsc,Rxb,Vsc,L9b,Vsc,dB,Vsc,Sxb,Vsc,x7b,Vsc,i7b,Vsc,KWb,Vsc,xP,Vsc,TDb,Vsc,aEb,Vsc,Vxb,Vsc,A$a,Vsc,lEb,Vsc,KRb,Vsc,IRb,Vsc,_Db,Vsc,M9b,Vsc,$Db,Vsc,poc,Vsc,t7b,Vsc,ZDb,Vsc,tP,Vsc,YDb,Vsc,gEb,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc,Vsc];var ne=[Wsc,Wsc,xub,Wsc];var oe=[Xsc,Xsc,nZb,Xsc];var pe=[Ysc,Ysc,qeb,Ysc,kkb,Ysc,Cab,Ysc,VEb,Ysc,rka,Ysc,rma,Ysc,uwb,Ysc,wwb,Ysc,v9a,Ysc,Rea,Ysc,N8,Ysc,zwb,Ysc,s9b,Ysc,Jwb,Ysc,teb,Ysc,uma,Ysc,Cmc,Ysc,Ika,Ysc,Uoc,Ysc,Nka,Ysc,fFb,Ysc,VSa,Ysc,Sja,Ysc,Jea,Ysc,S8,Ysc,o5b,Ysc,leb,Ysc,r5b,Ysc,o9b,Ysc,vHa,Ysc,N3,Ysc,tic,Ysc,OZb,Ysc,Ogb,Ysc,Ngb,Ysc,Ggb,Ysc,Fgb,Ysc,Igb,Ysc,Hgb,Ysc,Jgb,Ysc,Mgb,Ysc,Lgb,Ysc,W8,Ysc,Mea,Ysc,yab,Ysc,w5b,Ysc,g5b,Ysc,myb,Ysc,cFb,Ysc,gpb,Ysc,u9b,Ysc,Vja,Ysc,otb,Ysc,n5b,Ysc,x9b,Ysc,oeb,Ysc,Dea,Ysc,w8a,Ysc,Oka,Ysc,yja,Ysc,i5b,Ysc,i6a,Ysc,lFb,Ysc,U5,Ysc,rI,Ysc,Dvb,Ysc,kpb,Ysc,kyb,Ysc,cla,Ysc,q5b,Ysc,Owb,Ysc,nOb,Ysc,X5,Ysc,s5b,Ysc,Gba,Ysc,m5b,Ysc,jla,Ysc,kla,Ysc,rJa,Ysc,LJa,Ysc,t5b,Ysc,G5b,Ysc,jma,Ysc,Xla,Ysc,Lea,Ysc,Z8,Ysc,QSa,Ysc,z5b,Ysc,xla,Ysc,E5b,Ysc,X8,Ysc,fma,Ysc,zx,Ysc,rwb,Ysc,ux,Ysc,Jqb,Ysc,tx,Ysc,Wja,Ysc,fJa,Ysc,tHa,Ysc,BJa,Ysc,u4a,Ysc,m9b,Ysc,swb,Ysc,pka,Ysc,V8,Ysc,Hwb,Ysc,ZPa,Ysc,oka,Ysc,vHb,Ysc,dOb,Ysc,tma,Ysc,sr,Ysc,Yob,Ysc,zab,Ysc,Gka,Ysc,Gwb,Ysc,qAb,Ysc,dFb,Ysc,Hvb,Ysc,QEb,Ysc,OPb,Ysc,jyb,Ysc,WEb,Ysc,Zba,Ysc,Yba,Ysc,Xba,Ysc,q9b,Ysc,xx,Ysc,Ewb,Ysc,z9b,Ysc,I5b,Ysc,Bvb,Ysc,ikb,Ysc,Tea,Ysc,_8,Ysc,r9b,Ysc,Jla,Ysc,Mla,Ysc,RRb,Ysc,twb,Ysc,yub,Ysc,Emc,Ysc,Nla,Ysc,fOb,Ysc,qyb,Ysc,O0b,Ysc,Fvb,Ysc,B5b,Ysc,CAb,Ysc,P8,Ysc,yAb,Ysc,Sea,Ysc,Xoc,Ysc,T5,Ysc,o6b,Ysc,Aeb,Ysc,Nja,Ysc,Kwb,Ysc,gJa,Ysc,uHa,Ysc,wja,Ysc,seb,Ysc,lyb,Ysc,vma,Ysc,hma,Ysc,w9b,Ysc,x8a,Ysc,Iwb,Ysc,Kea,Ysc,reb,Ysc,mAb,Ysc,SEb,Ysc,ZEb,Ysc,FPb,Ysc,lAb,Ysc,PZb,Ysc,yla,Ysc,y8a,Ysc,Vea,Ysc,uub,Ysc,qwb,Ysc,TEb,Ysc,v5b,Ysc,Vla,Ysc,Dwb,Ysc,O8,Ysc,ska,Ysc,Ala,Ysc,vx,Ysc,Fwb,Ysc,wHb,Ysc,Fea,Ysc,Qgb,Ysc,Pgb,Ysc,Sgb,Ysc,Rgb,Ysc,IPb,Ysc,mla,Ysc,p6b,Ysc,qI,Ysc,Oja,Ysc,Kgb,Ysc,ryb,Ysc,u5b,Ysc,$8,Ysc,Tja,Ysc,Mka,Ysc,Uea,Ysc,xeb,Ysc,n9b,Ysc,eOb,Ysc,XEb,Ysc,vja,Ysc,Woc,Ysc,gOb,Ysc,iFb,Ysc,HPb,Ysc,ela,Ysc,Dab,Ysc,V5,Ysc,aXa,Ysc,dla,Ysc,aFb,Ysc,uAb,Ysc,zeb,Ysc,mIa,Ysc,xja,Ysc,b9,Ysc,GPb,Ysc,Mkb,Ysc,W5,Ysc,peb,Ysc,Awb,Ysc,oja,Ysc,xAb,Ysc,Wea,Ysc,T8,Ysc,meb,Ysc,y9b,Ysc,neb,Ysc,hOb,Ysc,gma,Ysc,Lla,Ysc,v9b,Ysc,Kla,Ysc,vic,Ysc,DAb,Ysc,y5b,Ysc,Qka,Ysc,nyb,Ysc,YEb,Ysc,_Eb,Ysc,Y8,Ysc,kFb,Ysc,Iea,Ysc,syb,Ysc,jka,Ysc,D5b,Ysc,Hea,Ysc,UEb,Ysc,M3,Ysc,bFb,Ysc,vwb,Ysc,k5b,Ysc,Mwb,Ysc,gab,Ysc,ika,Ysc,R8,Ysc,Qea,Ysc,web,Ysc,wx,Ysc,Y5,Ysc,ywb,Ysc,pja,Ysc,F5b,Ysc,Pea,Ysc,Nwb,Ysc,uja,Ysc,Lwb,Ysc,BAb,Ysc,Ifc,Ysc,eFb,Ysc,zub,Ysc,Pka,Ysc,yx,Ysc,oOb,Ysc,Afa,Ysc,Bla,Ysc,j5b,Ysc,nIa,Ysc,zla,Ysc,kka,Ysc,l9b,Ysc,sma,Ysc,tyb,Ysc,M8,Ysc,Nea,Ysc,pyb,Ysc,a9,Ysc,oyb,Ysc,gFb,Ysc,ueb,Ysc,x5b,Ysc,l5b,Ysc,REb,Ysc,d4b,Ysc,U8,Ysc,yeb,Ysc,A5b,Ysc,h5b,Ysc,lla,Ysc,t9b,Ysc,Yla,Ysc,$ob,Ysc,oIa,Ysc,CGa,Ysc,ila,Ysc,Oea,Ysc,Q8,Ysc,qka,Ysc,ima,Ysc,pAb,Ysc,jFb,Ysc,Wla,Ysc,tAb,Ysc,p5b,Ysc,Gmc,Ysc,Uja,Ysc,$Eb,Ysc,Bwb,Ysc,C5b,Ysc,m6b,Ysc,Hka,Ysc,H5b,Ysc,Zla,Ysc,Soc,Ysc,sx,Ysc,Cwb,Ysc,Mja,Ysc,cpb,Ysc,Uob,Ysc,qja,Ysc,veb,Ysc,xwb,Ysc,p9b,Ysc,hFb,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc,Ysc];var qe=[Zsc,Zsc,Dca,Zsc,mv,Zsc,jnc,Zsc,DNa,Zsc,$dc,Zsc,cs,Zsc,cm,Zsc,OSb,Zsc,JWa,Zsc,zk,Zsc,Fda,Zsc,bPa,Zsc,dic,Zsc,Xub,Zsc,QYa,Zsc,S9b,Zsc,Pub,Zsc,tv,Zsc,YLa,Zsc,_Rb,Zsc,WI,Zsc,rw,Zsc,xl,Zsc,SSb,Zsc,LZb,Zsc,qr,Zsc,wi,Zsc,b7a,Zsc,u0a,Zsc,z0a,Zsc,yhb,Zsc,Fk,Zsc,NSb,Zsc,on,Zsc,qi,Zsc,QYb,Zsc,yZb,Zsc,cSb,Zsc,Kx,Zsc,hSb,Zsc,rq,Zsc,Ymc,Zsc,Tt,Zsc,bic,Zsc,Aga,Zsc,Cx,Zsc,INa,Zsc,Zkb,Zsc,Eu,Zsc,Z0b,Zsc,HNa,Zsc,ry,Zsc,Rub,Zsc,ySb,Zsc,qSb,Zsc,FYb,Zsc,JYb,Zsc,px,Zsc,AA,Zsc,Nq,Zsc,NLb,Zsc,NNb,Zsc,Zn,Zsc,FNa,Zsc,Ht,Zsc,b6b,Zsc,r1b,Zsc,u3,Zsc,bk,Zsc,Ux,Zsc,yha,Zsc,l2a,Zsc,uu,Zsc,aSb,Zsc,_r,Zsc,M0b,Zsc,Qs,Zsc,xda,Zsc,gy,Zsc,Rm,Zsc,co,Zsc,Dub,Zsc,B5,Zsc,Mub,Zsc,wda,Zsc,fSb,Zsc,ZRb,Zsc,Nlb,Zsc,Wcc,Zsc,Hp,Zsc,Bda,Zsc,mab,Zsc,Zs,Zsc,pOa,Zsc,rOa,Zsc,qOa,Zsc,HZb,Zsc,PSb,Zsc,D9a,Zsc,qRa,Zsc,yt,Zsc,gZb,Zsc,MSb,Zsc,lhb,Zsc,ji,Zsc,Oub,Zsc,uSb,Zsc,m9a,Zsc,dSb,Zsc,bSb,Zsc,Ncc,Zsc,MNb,Zsc,Qu,Zsc,F2,Zsc,uga,Zsc,L1,Zsc,Jj,Zsc,RSb,Zsc,Al,Zsc,wSb,Zsc,zda,Zsc,fv,Zsc,SZb,Zsc,tl,Zsc,ju,Zsc,Yub,Zsc,gSb,Zsc,cr,Zsc,pea,Zsc,Nub,Zsc,Rbc,Zsc,F5,Zsc,gs,Zsc,_wb,Zsc,PTa,Zsc,aab,Zsc,w7a,Zsc,kda,Zsc,$9a,Zsc,Cda,Zsc,Sub,Zsc,jSb,Zsc,blb,Zsc,Fz,Zsc,dhb,Zsc,uda,Zsc,vda,Zsc,Op,Zsc,fRa,Zsc,hlb,Zsc,ftb,Zsc,agb,Zsc,v2a,Zsc,et,Zsc,Vub,Zsc,fq,Zsc,Hn,Zsc,An,Zsc,Zt,Zsc,xSb,Zsc,yr,Zsc,YRb,Zsc,qYa,Zsc,Jh,Zsc,Un,Zsc,h8b,Zsc,eSb,Zsc,s1b,Zsc,Gqb,Zsc,uz,Zsc,zSa,Zsc,_w,Zsc,J3a,Zsc,Ida,Zsc,ida,Zsc,oSb,Zsc,Cw,Zsc,RZb,Zsc,_m,Zsc,UEa,Zsc,QNa,Zsc,LSb,Zsc,Zsb,Zsc,QSb,Zsc,Hda,Zsc,ENa,Zsc,Gda,Zsc,Qo,Zsc,Tub,Zsc,E9a,Zsc,itb,Zsc,Ei,Zsc,q0a,Zsc,TI,Zsc,bB,Zsc,Uub,Zsc,uLa,Zsc,sSb,Zsc,Pcc,Zsc,dab,Zsc,UA,Zsc,wZb,Zsc,Iq,Zsc,Kba,Zsc,rk,Zsc,dz,Zsc,lp,Zsc,Jl,Zsc,aq,Zsc,iSb,Zsc,uo,Zsc,Zy,Zsc,q4,Zsc,RI,Zsc,dw,Zsc,F2b,Zsc,Qub,Zsc,iz,Zsc,$Rb,Zsc,t1b,Zsc,pQa,Zsc,U_b,Zsc,Xp,Zsc,hZb,Zsc,tSb,Zsc,eab,Zsc,GZb,Zsc,_x,Zsc,tA,Zsc,rhb,Zsc,n1b,Zsc,Dda,Zsc,tbb,Zsc,Ada,Zsc,y0,Zsc,$o,Zsc,iga,Zsc,cRa,Zsc,jk,Zsc,Cp,Zsc,F0b,Zsc,RYb,Zsc,Ev,Zsc,rt,Zsc,Oh,Zsc,Z8a,Zsc,xfc,Zsc,JSa,Zsc,Ji,Zsc,oA,Zsc,jda,Zsc,yOa,Zsc,tia,Zsc,vs,Zsc,Wub,Zsc,SLa,Zsc,Ur,Zsc,Zub,Zsc,yda,Zsc,b0,Zsc,Jba,Zsc,Sx,Zsc,Mo,Zsc,Jm,Zsc,Py,Zsc,hB,Zsc,Js,Zsc,oOa,Zsc,Ju,Zsc,ex,Zsc,kr,Zsc,p1b,Zsc,_sb,Zsc,htb,Zsc,uSa,Zsc,XRb,Zsc,xjb,Zsc,ms,Zsc,pSb,Zsc,ESa,Zsc,Wj,Zsc,Eda,Zsc,GNa,Zsc,F9a,Zsc,nw,Zsc,Hr,Zsc,uhb,Zsc,_ub,Zsc,q1b,Zsc,tn,Zsc,TSb,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc,Zsc];var re=[_sc,_sc,blc,_sc,xZb,_sc,Qsa,_sc,_v,_sc,V5a,_sc,D0,_sc,ffc,_sc,GSb,_sc,jpa,_sc,jna,_sc,h5,_sc,Psa,_sc,Dna,_sc,VPb,_sc,Gra,_sc,Nsa,_sc,Hrb,_sc,z0,_sc,Hsa,_sc,vna,_sc,kra,_sc,Tv,_sc,Cra,_sc,Rjb,_sc,DNb,_sc,mtb,_sc,Woa,_sc,jqa,_sc,yra,_sc,oqa,_sc,Moa,_sc,aqa,_sc,Qjb,_sc,Zsa,_sc,Msa,_sc,Ana,_sc,Foa,_sc,tqa,_sc,_Qa,_sc,CNb,_sc,nra,_sc,RP,_sc,wra,_sc,wO,_sc,J0,_sc,Nra,_sc,wsa,_sc,nGb,_sc,Ena,_sc,o1b,_sc,gqa,_sc,sna,_sc,ura,_sc,h2a,_sc,Z9a,_sc,YZa,_sc,pqa,_sc,bGb,_sc,Zv,_sc,Fsa,_sc,tna,_sc,Ara,_sc,Yoa,_sc,lqa,_sc,B0,_sc,Qoa,_sc,dqa,_sc,sra,_sc,gpa,_sc,Pla,_sc,vR,_sc,iGa,_sc,A0,_sc,Una,_sc,Qla,_sc,H7a,_sc,UP,_sc,KTb,_sc,MTb,_sc,Bra,_sc,QP,_sc,Dsa,_sc,bpa,_sc,G7a,_sc,j2a,_sc,Koa,_sc,Kna,_sc,Bna,_sc,Xsa,_sc,$sa,_sc,Wv,_sc,RNb,_sc,N_b,_sc,Gsa,_sc,una,_sc,FSb,_sc,kSb,_sc,Jna,_sc,rqa,_sc,Jra,_sc,vra,_sc,i5,_sc,Usa,_sc,wfc,_sc,bfc,_sc,$la,_sc,hpa,_sc,klc,_sc,H0,_sc,$Kb,_sc,ira,_sc,Nna,_sc,Dra,_sc,sTb,_sc,uTb,_sc,ITb,_sc,GTb,_sc,xsa,_sc,Noa,_sc,zsa,_sc,Kjb,_sc,ata,_sc,lna,_sc,ONb,_sc,Ira,_sc,N0,_sc,SNb,_sc,Tj,_sc,sab,_sc,O_b,_sc,j5,_sc,Rob,_sc,G0,_sc,k5,_sc,txb,_sc,lSb,_sc,ktb,_sc,Tsa,_sc,_pa,_sc,Asa,_sc,Rv,_sc,C9a,_sc,Jub,_sc,ysa,_sc,hqa,_sc,Jjb,_sc,yqa,_sc,jlc,_sc,rra,_sc,Poa,_sc,cqa,_sc,fqa,_sc,ov,_sc,F0,_sc,Era,_sc,HSb,_sc,HNb,_sc,oZa,_sc,xna,_sc,Hoa,_sc,vqa,_sc,Vpa,_sc,Pna,_sc,Ypa,_sc,Vsa,_sc,mSb,_sc,L0,_sc,Wsa,_sc,d2a,_sc,mna,_sc,ama,_sc,Upa,_sc,Voa,_sc,iqa,_sc,xra,_sc,qqa,_sc,mqa,_sc,pv,_sc,Zpa,_sc,F7a,_sc,Ina,_sc,lma,_sc,BTb,_sc,zTb,_sc,G4,_sc,uqa,_sc,Sj,_sc,_ec,_sc,Xec,_sc,sqa,_sc,Csa,_sc,Esa,_sc,QNb,_sc,MZb,_sc,qra,_sc,Ooa,_sc,bqa,_sc,g2a,_sc,wqa,_sc,_oa,_sc,E7a,_sc,Osa,_sc,Cna,_sc,vTb,_sc,tTb,_sc,xTb,_sc,BSb,_sc,ipa,_sc,Jsa,_sc,ora,_sc,ona,_sc,_sa,_sc,lra,_sc,Ujb,_sc,rxb,_sc,Cqc,_sc,zNb,_sc,LNb,_sc,GNb,_sc,ETb,_sc,ATb,_sc,CTb,_sc,qda,_sc,Loa,_sc,Rna,_sc,Uoa,_sc,i2a,_sc,mlc,_sc,DSb,_sc,Rsa,_sc,Ssa,_sc,TNb,_sc,Hra,_sc,tab,_sc,yna,_sc,Isa,_sc,wna,_sc,TP,_sc,Soa,_sc,SP,_sc,QPb,_sc,qna,_sc,yA,_sc,Fna,_sc,wTb,_sc,yTb,_sc,Joa,_sc,Xpa,_sc,CSb,_sc,Kra,_sc,Wpa,_sc,pra,_sc,n5,_sc,rda,_sc,fB,_sc,C0,_sc,I0,_sc,kna,_sc,hra,_sc,zna,_sc,Fra,_sc,Zoa,_sc,mra,_sc,_Kb,_sc,DIb,_sc,ISb,_sc,pxb,_sc,Sna,_sc,dpa,_sc,jtb,_sc,nna,_sc,fpa,_sc,W5a,_sc,zra,_sc,kqa,_sc,Qna,_sc,Xoa,_sc,Ksa,_sc,EPb,_sc,apa,_sc,xma,_sc,Dla,_sc,nqa,_sc,Ela,_sc,xqa,_sc,Goa,_sc,ASb,_sc,$oa,_sc,$pa,_sc,llc,_sc,nlc,_sc,HTb,_sc,JTb,_sc,LTb,_sc,Mna,_sc,rna,_sc,Yv,_sc,Hna,_sc,vxb,_sc,epa,_sc,mma,_sc,vfc,_sc,Gna,_sc,Lsa,_sc,Vna,_sc,l5,_sc,FTb,_sc,DTb,_sc,Ysa,_sc,j0b,_sc,Roa,_sc,eqa,_sc,tra,_sc,Lna,_sc,K0,_sc,Iub,_sc,Toa,_sc,pna,_sc,cpa,_sc,JNb,_sc,M0,_sc,r_a,_sc,Lra,_sc,ESb,_sc,Ioa,_sc,jra,_sc,Mra,_sc,Ona,_sc,Tna,_sc,Wna,_sc,$Ta,_sc,SA,_sc,Bsa,_sc,E0,_sc,aw,_sc,yma,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc,_sc];var se=[$sc,$sc,rjb,$sc,Uga,$sc,X4b,$sc,wz,$sc,IOa,$sc,oea,$sc,f5b,$sc,Gv,$sc,R4b,$sc,L4b,$sc,Jp,$sc,sia,$sc,FQa,$sc,R4,$sc,At,$sc,d5b,$sc,$wb,$sc,N4b,$sc,O4a,$sc,b5b,$sc,A5,$sc,rSa,$sc,iy,$sc,jkb,$sc,$4b,$sc,S2a,$sc,V4b,$sc,Z4b,$sc,Ar,$sc,P4b,$sc,is,$sc,T4b,$sc,LRa,$sc,qoc,$sc,J4b,$sc,Ss,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc,$sc];var te=[atc,atc,Xtb,atc,aub,atc,atc,atc];var ue=[btc,btc,D4,btc];var ve=[ctc,ctc,j_,ctc,uWa,ctc,Io,ctc,xr,ctc,i3,ctc,lz,ctc,yib,ctc,vI,ctc,g_,ctc,NY,ctc,X5a,ctc,qq,ctc,Dp,ctc,ySa,ctc,ox,ctc,tz,ctc,o6a,ctc,hk,ctc,GV,ctc,zWa,ctc,F2a,ctc,rZ,ctc,j6a,ctc,z2a,ctc,En,ctc,Mi,ctc,Q_,ctc,JO,ctc,Pr,ctc,FXb,ctc,iK,ctc,Ft,ctc,Jq,ctc,$G,ctc,CV,ctc,So,ctc,WOa,ctc,vhb,ctc,wl,ctc,BV,ctc,VY,ctc,kL,ctc,ZVa,ctc,Ega,ctc,xXa,ctc,cn,ctc,lLa,ctc,ejb,ctc,Yo,ctc,Vm,ctc,qN,ctc,kZ,ctc,Pl,ctc,aQ,ctc,sB,ctc,FIb,ctc,rx,ctc,FE,ctc,gv,ctc,oz,ctc,ow,ctc,mL,ctc,BR,ctc,hS,ctc,J4,ctc,fS,ctc,w2,ctc,R_,ctc,c_,ctc,xN,ctc,CO,ctc,axb,ctc,ak,ctc,Vca,ctc,Ir,ctc,Jlb,ctc,Gk,ctc,jPa,ctc,vo,ctc,sy,ctc,xo,ctc,T$a,ctc,M8a,ctc,Y0a,ctc,l3,ctc,$La,ctc,Dw,ctc,uK,ctc,sYa,ctc,j4a,ctc,ZK,ctc,uG,ctc,St,ctc,KC,ctc,iQ,ctc,rXa,ctc,_$,ctc,si,ctc,BO,ctc,Pv,ctc,yT,ctc,Rs,ctc,Lib,ctc,ilb,ctc,by,ctc,RVa,ctc,MN,ctc,zea,ctc,$ca,ctc,nK,ctc,Zfb,ctc,PEa,ctc,gI,ctc,Fo,ctc,GXa,ctc,H_,ctc,dm,ctc,lv,ctc,D_,ctc,bz,ctc,RF,ctc,f$,ctc,Lca,ctc,MPa,ctc,kp,ctc,ls,ctc,mP,ctc,Jt,ctc,rca,ctc,Ufa,ctc,bUa,ctc,EQa,ctc,Eo,ctc,iZa,ctc,Zgb,ctc,nfa,ctc,qjb,ctc,rVa,ctc,dx,ctc,cLa,ctc,Ky,ctc,GW,ctc,yS,ctc,xi,ctc,nN,ctc,Rp,ctc,vK,ctc,On,ctc,nP,ctc,tE,ctc,JU,ctc,TG,ctc,hZ,ctc,Mq,ctc,Lq,ctc,lK,ctc,IE,ctc,xca,ctc,$kb,ctc,rU,ctc,$Ua,ctc,j2,ctc,oE,ctc,bF,ctc,bQa,ctc,ZLa,ctc,fhb,ctc,l6a,ctc,v0,ctc,_Y,ctc,_T,ctc,o5,ctc,Gib,ctc,ro,ctc,VW,ctc,oW,ctc,jC,ctc,AB,ctc,_K,ctc,yv,ctc,tC,ctc,Fl,ctc,pT,ctc,sw,ctc,Q0a,ctc,uB,ctc,st,ctc,up,ctc,m_,ctc,aTa,ctc,Oib,ctc,N4,ctc,Yy,ctc,R1a,ctc,gG,ctc,k3,ctc,ri,ctc,pu,ctc,BOa,ctc,Umb,ctc,JB,ctc,wS,ctc,Gn,ctc,DLa,ctc,LR,ctc,QG,ctc,e4,ctc,Dx,ctc,wNa,ctc,CY,ctc,q2,ctc,Aub,ctc,Xw,ctc,Xj,ctc,n_,ctc,ukb,ctc,vz,ctc,DC,ctc,bab,ctc,Ot,ctc,It,ctc,aL,ctc,C3,ctc,lS,ctc,DW,ctc,go,ctc,gq,ctc,oZ,ctc,WH,ctc,cz,ctc,Jo,ctc,dQa,ctc,yu,ctc,clb,ctc,c1,ctc,Vt,ctc,vv,ctc,dRa,ctc,OLa,ctc,Wy,ctc,yq,ctc,Ry,ctc,pW,ctc,LOa,ctc,sga,ctc,YY,ctc,oC,ctc,Kfa,ctc,c4a,ctc,rv,ctc,nn,ctc,sN,ctc,$S,ctc,Li,ctc,Mm,ctc,Om,ctc,rZa,ctc,EG,ctc,n_a,ctc,oq,ctc,mN,ctc,OE,ctc,xS,ctc,xt,ctc,WZ,ctc,ps,ctc,_E,ctc,xea,ctc,Pt,ctc,an,ctc,xJ,ctc,Pca,ctc,jJ,ctc,zB,ctc,b$,ctc,wWa,ctc,eQ,ctc,tW,ctc,sC,ctc,E5,ctc,_Wa,ctc,Ikb,ctc,njb,ctc,kw,ctc,Tr,ctc,D6a,ctc,Sr,ctc,dWa,ctc,r6,ctc,Gp,ctc,e0a,ctc,Fu,ctc,Wfa,ctc,XH,ctc,$fb,ctc,mp,ctc,eib,ctc,op,ctc,dxb,ctc,nSa,ctc,jG,ctc,tZa,ctc,HY,ctc,$ib,ctc,_Sa,ctc,bq,ctc,YWa,ctc,mZ,ctc,gQ,ctc,r2a,ctc,IVb,ctc,wE,ctc,ay,ctc,DH,ctc,hL,ctc,URa,ctc,LG,ctc,Vx,ctc,TOa,ctc,tJ,ctc,Zj,ctc,yW,ctc,Opb,ctc,GI,ctc,Xfb,ctc,ePa,ctc,kib,ctc,v6a,ctc,TE,ctc,Ut,ctc,j4,ctc,Xt,ctc,n0,ctc,rC,ctc,m2,ctc,E_,ctc,HG,ctc,FB,ctc,qs,ctc,ega,ctc,q_a,ctc,qS,ctc,ria,ctc,uNa,ctc,bm,ctc,Dn,ctc,ifa,ctc,Rfa,ctc,jWa,ctc,Ow,ctc,UG,ctc,WY,ctc,Dz,ctc,tkb,ctc,fw,ctc,tw,ctc,c$,ctc,XZa,ctc,fu,ctc,YYb,ctc,JY,ctc,$J,ctc,vy,ctc,TLa,ctc,lr,ctc,du,ctc,IN,ctc,Yp,ctc,fO,ctc,es,ctc,c0a,ctc,Mx,ctc,qK,ctc,CVa,ctc,rib,ctc,JS,ctc,$x,ctc,yH,ctc,XR,ctc,xK,ctc,qj,ctc,OF,ctc,Ku,ctc,bw,ctc,XF,ctc,AR,ctc,ARa,ctc,xO,ctc,SWa,ctc,hG,ctc,iW,ctc,C1a,ctc,Rq,ctc,FZ,ctc,GLa,ctc,dGb,ctc,TVa,ctc,aZb,ctc,Ffa,ctc,QU,ctc,CF,ctc,Zr,ctc,nS,ctc,Mw,ctc,OR,ctc,DOa,ctc,h0a,ctc,kT,ctc,en,ctc,PQa,ctc,KQ,ctc,rV,ctc,qXa,ctc,N8a,ctc,sk,ctc,aW,ctc,uZ,ctc,vH,ctc,UJ,ctc,iT,ctc,TU,ctc,Bw,ctc,g3a,ctc,ISa,ctc,yy,ctc,Up,ctc,hI,ctc,Xca,ctc,zZ,ctc,WMa,ctc,GR,ctc,aS,ctc,mH,ctc,jo,ctc,jjb,ctc,kfa,ctc,CZ,ctc,Bi,ctc,Zp,ctc,tS,ctc,RQa,ctc,ROa,ctc,tLa,ctc,TR,ctc,Pu,ctc,fs,ctc,fea,ctc,XXa,ctc,qZ,ctc,bjb,ctc,EO,ctc,mC,ctc,xU,ctc,mE,ctc,NYa,ctc,jq,ctc,sW,ctc,x4,ctc,r4a,ctc,MQ,ctc,Q3a,ctc,_t,ctc,G6a,ctc,gQa,ctc,nTb,ctc,bK,ctc,jca,ctc,tu,ctc,uF,ctc,$H,ctc,Do,ctc,ks,ctc,XT,ctc,Zx,ctc,In,ctc,Z5a,ctc,PE,ctc,gV,ctc,DE,ctc,Cgb,ctc,xWa,ctc,W3,ctc,Olb,ctc,wF,ctc,qhb,ctc,br,ctc,GT,ctc,uL,ctc,XE,ctc,Mfa,ctc,QY,ctc,Pfa,ctc,kE,ctc,DZa,ctc,wC,ctc,JWb,ctc,gt,ctc,qbb,ctc,ko,ctc,ZJ,ctc,BH,ctc,$r,ctc,TW,ctc,fJ,ctc,zn,ctc,wy,ctc,dk,ctc,Uda,ctc,AN,ctc,Oo,ctc,Pm,ctc,pK,ctc,i4,ctc,MG,ctc,B_,ctc,c_a,ctc,dgb,ctc,SE,ctc,EH,ctc,ki,ctc,oS,ctc,fgb,ctc,gfa,ctc,H4,ctc,Tu,ctc,WQa,ctc,cu,ctc,hn,ctc,rH,ctc,OOa,ctc,Ck,ctc,or,ctc,QZb,ctc,Su,ctc,Yj,ctc,Xl,ctc,uy,ctc,YU,ctc,cYa,ctc,ZB,ctc,r4,ctc,Vj,ctc,jLa,ctc,iwb,ctc,zF,ctc,zT,ctc,$j,ctc,ok,ctc,wSa,ctc,fl,ctc,l9a,ctc,M4,ctc,FQ,ctc,eV,ctc,jn,ctc,oQb,ctc,P8a,ctc,u2a,ctc,xk,ctc,vk,ctc,ln,ctc,LW,ctc,V0a,ctc,XV,ctc,LN,ctc,V2a,ctc,GSa,ctc,wL,ctc,kXa,ctc,N_,ctc,DD,ctc,lZa,ctc,g9a,ctc,dfa,ctc,Rn,ctc,Ew,ctc,Sm,ctc,Is,ctc,m6a,ctc,y_,ctc,a0,ctc,Dv,ctc,tib,ctc,t_,ctc,x6a,ctc,_V,ctc,X9a,ctc,dP,ctc,QOa,ctc,qfa,ctc,bJ,ctc,Oq,ctc,cPa,ctc,gga,ctc,QZ,ctc,Cga,ctc,To,ctc,dQ,ctc,CG,ctc,A6a,ctc,Y0,ctc,OG,ctc,YV,ctc,L_,ctc,rkb,ctc,Lo,ctc,C2,ctc,P0a,ctc,Vga,ctc,Xjb,ctc,gWa,ctc,UOa,ctc,H2a,ctc,pfa,ctc,rr,ctc,k0,ctc,LK,ctc,_Pa,ctc,jE,ctc,W9a,ctc,Bl,ctc,NR,ctc,lV,ctc,II,ctc,$hb,ctc,gw,ctc,aWa,ctc,pRa,ctc,cS,ctc,Yn,ctc,IZb,ctc,G9a,ctc,JG,ctc,jab,ctc,wn,ctc,at,ctc,az,ctc,xs,ctc,XVa,ctc,rL,ctc,P3a,ctc,Ln,ctc,ZR,ctc,_y,ctc,xv,ctc,ns,ctc,q3,ctc,sbb,ctc,ULa,ctc,NM,ctc,DZ,ctc,y8,ctc,Cl,ctc,aLa,ctc,TF,ctc,Np,ctc,$_,ctc,S4,ctc,ZH,ctc,Fx,ctc,Px,ctc,CB,ctc,ME,ctc,hs,ctc,xE,ctc,G$a,ctc,ew,ctc,OH,ctc,oXa,ctc,XJ,ctc,yga,ctc,q0,ctc,iPa,ctc,Sda,ctc,RU,ctc,ffa,ctc,KW,ctc,Ap,ctc,FP,ctc,_I,ctc,VV,ctc,Gi,ctc,oG,ctc,Z1a,ctc,Hu,ctc,UZ,ctc,AO,ctc,kV,ctc,Xib,ctc,ohb,ctc,DI,ctc,fx,ctc,$1a,ctc,J_,ctc,kk,ctc,MH,ctc,pr,ctc,VZ,ctc,vu,ctc,Cu,ctc,UR,ctc,f0a,ctc,Ov,ctc,uq,ctc,BG,ctc,tWa,ctc,tL,ctc,xq,ctc,oQa,ctc,VWa,ctc,C6a,ctc,zYa,ctc,PO,ctc,u2,ctc,Ym,ctc,AS,ctc,mx,ctc,LO,ctc,WB,ctc,rO,ctc,zI,ctc,nv,ctc,Qib,ctc,ZP,ctc,PM,ctc,zH,ctc,vca,ctc,P1a,ctc,Vn,ctc,bhb,ctc,xOa,ctc,WVa,ctc,Fp,ctc,rp,ctc,Ulb,ctc,mo,ctc,gZ,ctc,hTb,ctc,gTb,ctc,ik,ctc,yZa,ctc,sOa,ctc,bo,ctc,DS,ctc,MWa,ctc,rT,ctc,Y8a,ctc,VJa,ctc,lOa,ctc,p0,ctc,GZ,ctc,Bn,ctc,jy,ctc,_da,ctc,Xv,ctc,RG,ctc,oH,ctc,uYa,ctc,aT,ctc,iXa,ctc,I_,ctc,uOa,ctc,C5,ctc,vZa,ctc,cJ,ctc,Fi,ctc,eo,ctc,Tn,ctc,Xkb,ctc,cC,ctc,xZ,ctc,$Qa,ctc,LVa,ctc,a0a,ctc,wv,ctc,bRa,ctc,rS,ctc,Y_,ctc,OJ,ctc,dmb,ctc,Hx,ctc,iv,ctc,bWa,ctc,Wx,ctc,TEa,ctc,jz,ctc,pG,ctc,HP,ctc,Ll,ctc,_ba,ctc,gC,ctc,JVa,ctc,Qlb,ctc,B9a,ctc,Ip,ctc,ZOa,ctc,ev,ctc,pYa,ctc,Kr,ctc,flb,ctc,li,ctc,Gz,ctc,sSa,ctc,XUa,ctc,I6,ctc,ILa,ctc,k0a,ctc,EV,ctc,ou,ctc,WU,ctc,BZa,ctc,zt,ctc,sZ,ctc,mV,ctc,ht,ctc,SV,ctc,nea,ctc,lx,ctc,AZ,ctc,ao,ctc,NQa,ctc,VF,ctc,p2a,ctc,n4a,ctc,$m,ctc,DL,ctc,Flb,ctc,_s,ctc,kP,ctc,YH,ctc,REa,ctc,oJ,ctc,dZ,ctc,qx,ctc,F6,ctc,Tm,ctc,KE,ctc,mz,ctc,dV,ctc,CL,ctc,_R,ctc,i0a,ctc,T_,ctc,Pp,ctc,IZ,ctc,lYa,ctc,lH,ctc,kK,ctc,wT,ctc,EE,ctc,cw,ctc,A6,ctc,dq,ctc,_ca,ctc,rB,ctc,jV,ctc,KZa,ctc,PW,ctc,ck,ctc,qU,ctc,TN,ctc,i_,ctc,Mib,ctc,Mt,ctc,fQ,ctc,e9a,ctc,nZ,ctc,cGb,ctc,pE,ctc,ei,ctc,KRa,ctc,qWa,ctc,Z_,ctc,No,ctc,_0,ctc,s6a,ctc,hWa,ctc,Ul,ctc,_n,ctc,o2,ctc,JOa,ctc,PZa,ctc,sV,ctc,gS,ctc,Mhb,ctc,SKa,ctc,Av,ctc,oL,ctc,zQ,ctc,DN,ctc,O_,ctc,i2,ctc,s3,ctc,sE,ctc,CI,ctc,Gca,ctc,ui,ctc,eL,ctc,lk,ctc,Tib,ctc,IY,ctc,DYa,ctc,j9a,ctc,qt,ctc,FW,ctc,FY,ctc,a3a,ctc,Qx,ctc,Vjb,ctc,ap,ctc,GQ,ctc,mw,ctc,Gr,ctc,a4a,ctc,sjb,ctc,U3,ctc,XK,ctc,FL,ctc,qC,ctc,tp,ctc,Z3a,ctc,Hy,ctc,KYa,ctc,Uv,ctc,My,ctc,zv,ctc,UQa,ctc,r2,ctc,Iib,ctc,kH,ctc,Ml,ctc,vw,ctc,SZ,ctc,uV,ctc,Aib,ctc,hV,ctc,VPa,ctc,T2a,ctc,FU,ctc,Mj,ctc,Wl,ctc,Ifa,ctc,nRa,ctc,pw,ctc,BJ,ctc,$P,ctc,yk,ctc,XJa,ctc,Bp,ctc,SY,ctc,dea,ctc,_j,ctc,xB,ctc,gW,ctc,ii,ctc,p4,ctc,Zea,ctc,V3a,ctc,EUa,ctc,BT,ctc,fL,ctc,HO,ctc,lca,ctc,PF,ctc,hT,ctc,l4a,ctc,wB,ctc,EYa,ctc,l4,ctc,pH,ctc,yN,ctc,XWa,ctc,IF,ctc,VUa,ctc,xZa,ctc,k6,ctc,sl,ctc,jTb,ctc,KS,ctc,kTb,ctc,U4,ctc,wU,ctc,Hlb,ctc,ek,ctc,ojb,ctc,X3a,ctc,b_,ctc,yn,ctc,LJ,ctc,fda,ctc,B1,ctc,ZUa,ctc,bQ,ctc,VE,ctc,Mp,ctc,sfa,ctc,uC,ctc,z4,ctc,Lw,ctc,Zw,ctc,wYa,ctc,cZ,ctc,xQ,ctc,BS,ctc,aK,ctc,HF,ctc,bW,ctc,Uib,ctc,Vfb,ctc,bMa,ctc,tca,ctc,GS,ctc,Yca,ctc,Eib,ctc,kZa,ctc,aca,ctc,Lt,ctc,xga,ctc,GYa,ctc,K8a,ctc,Kv,ctc,lt,ctc,MXa,ctc,Fv,ctc,U1a,ctc,EVb,ctc,pP,ctc,ON,ctc,wjb,ctc,W_,ctc,Ly,ctc,R8a,ctc,vq,ctc,N$a,ctc,X0a,ctc,GF,ctc,V2,ctc,F3,ctc,g4,ctc,uv,ctc,iib,ctc,Qy,ctc,eq,ctc,mG,ctc,j1,ctc,e1,ctc,E2,ctc,c5,ctc,x0,ctc,ljb,ctc,Yf,ctc,tK,ctc,sWa,ctc,N9a,ctc,_Va,ctc,Cr,ctc,wp,ctc,dXa,ctc,Yt,ctc,Ek,ctc,xn,ctc,qV,ctc,Ys,ctc,AE,ctc,iJ,ctc,IXa,ctc,sn,ctc,Km,ctc,Y3,ctc,qE,ctc,cjb,ctc,Zlb,ctc,WJ,ctc,yYa,ctc,YQ,ctc,ft,ctc,kI,ctc,SJ,ctc,Rl,ctc,fi,ctc,_0a,ctc,l2,ctc,iC,ctc,Uhb,ctc,AI,ctc,y6a,ctc,Ki,ctc,CT,ctc,Lv,ctc,dlb,ctc,zs,ctc,Ks,ctc,Or,ctc,DF,ctc,hi,ctc,PB,ctc,hfa,ctc,OO,ctc,Hi,ctc,eC,ctc,kF,ctc,lTb,ctc,pp,ctc,mTb,ctc,iZ,ctc,P2,ctc,OWa,ctc,Dfa,ctc,mr,ctc,lab,ctc,lF,ctc,Du,ctc,L$a,ctc,AZa,ctc,hx,ctc,tH,ctc,GU,ctc,dF,ctc,jv,ctc,pib,ctc,y1a,ctc,GO,ctc,xy,ctc,Lu,ctc,eF,ctc,u_,ctc,Zhb,ctc,py,ctc,RZa,ctc,Hl,ctc,D6,ctc,Nv,ctc,Eca,ctc,CW,ctc,uU,ctc,e3a,ctc,bXa,ctc,I$a,ctc,Yib,ctc,By,ctc,RJ,ctc,cP,ctc,t1,ctc,fo,ctc,q6a,ctc,gn,ctc,eu,ctc,Lhb,ctc,cO,ctc,U9b,ctc,Wib,ctc,_l,ctc,fr,ctc,dr,ctc,Wp,ctc,yp,ctc,mS,ctc,W8a,ctc,GQa,ctc,El,ctc,_F,ctc,xhb,ctc,oQ,ctc,Ps,ctc,$v,ctc,Im,ctc,EI,ctc,HN,ctc,hy,ctc,Iv,ctc,Xlb,ctc,qL,ctc,$6a,ctc,xL,ctc,fF,ctc,Sca,ctc,oj,ctc,qQ,ctc,h0,ctc,qy,ctc,MJ,ctc,Kl,ctc,rJ,ctc,H6,ctc,_3a,ctc,Xn,ctc,tXa,ctc,CYb,ctc,DJ,ctc,eYa,ctc,QE,ctc,ihb,ctc,eG,ctc,zU,ctc,n3,ctc,c3a,ctc,Vr,ctc,wkb,ctc,GE,ctc,YB,ctc,EF,ctc,LQa,ctc,hF,ctc,n3a,ctc,bG,ctc,Qv,ctc,Dr,ctc,rLa,ctc,$l,ctc,$t,ctc,YT,ctc,PYa,ctc,q5,ctc,MU,ctc,A_,ctc,Kj,ctc,IW,ctc,s0,ctc,fy,ctc,gr,ctc,zOa,ctc,nF,ctc,HE,ctc,Sz,ctc,Ro,ctc,Mv,ctc,n9a,ctc,JR,ctc,Fw,ctc,Fr,ctc,Kh,ctc,iL,ctc,vi,ctc,zy,ctc,Sq,ctc,Hv,ctc,dS,ctc,Qca,ctc,zXa,ctc,F3a,ctc,cUa,ctc,cU,ctc,pVa,ctc,D3a,ctc,p_,ctc,E3,ctc,N0a,ctc,r1,ctc,bs,ctc,eJ,ctc,Fm,ctc,QR,ctc,K$a,ctc,KG,ctc,JK,ctc,_ib,ctc,ku,ctc,UZa,ctc,CE,ctc,t2,ctc,Iy,ctc,IU,ctc,uE,ctc,ut,ctc,ZG,ctc,P$a,ctc,WE,ctc,Vhb,ctc,Tfa,ctc,$F,ctc,ZI,ctc,IYa,ctc,$Y,ctc,t4,ctc,hz,ctc,hK,ctc,dn,ctc,mi,ctc,YOa,ctc,jr,ctc,O$a,ctc,R$a,ctc,Q$a,ctc,Xhb,ctc,S$a,ctc,U$a,ctc,V$a,ctc,lE,ctc,jOa,ctc,yF,ctc,vW,ctc,WQ,ctc,Jv,ctc,aea,ctc,rF,ctc,iI,ctc,HD,ctc,Lda,ctc,b6a,ctc,tO,ctc,Q4,ctc,Gm,ctc,Xea,ctc,nca,ctc,Lx,ctc,I0a,ctc,VR,ctc,spb,ctc,bC,ctc,WG,ctc,w4a,ctc,m1,ctc,N3a,ctc,pC,ctc,to,ctc,Rib,ctc,VU,ctc,zl,ctc,Vv,ctc,yO,ctc,I8a,ctc,Ay,ctc,RN,ctc,m6,ctc,iq,ctc,Zib,ctc,CN,ctc,Wga,ctc,lJ,ctc,ES,ctc,IC,ctc,K_,ctc,ZE,ctc,gPa,ctc,BLa,ctc,eWa,ctc,Wlb,ctc,dK,ctc,gJ,ctc,Nca,ctc,gu,ctc,Jib,ctc,s2a,ctc,UKa,ctc,NWb,ctc,Yw,ctc,Ru,ctc,DB,ctc,Ts,ctc,h3a,ctc,JQ,ctc,W0,ctc,B2a,ctc,Tl,ctc,L3a,ctc,Qq,ctc,PU,ctc,l1,ctc,Gx,ctc,sv,ctc,MO,ctc,OB,ctc,H3,ctc,Ns,ctc,_o,ctc,w1a,ctc,ix,ctc,h$,ctc,Ol,ctc,tk,ctc,Ci,ctc,WPa,ctc,wWb,ctc,dO,ctc,a1,ctc,vr,ctc,yvb,ctc,eA,ctc,khb,ctc,ty,ctc,hq,ctc,KU,ctc,Pn,ctc,Ho,ctc,n4,ctc,BC,ctc,C8a,ctc,g6a,ctc,qk,ctc,Sy,ctc,$w,ctc,OY,ctc,_Yb,ctc,Llb,ctc,Slb,ctc,fG,ctc,CSa,ctc,nQ,ctc,TPa,ctc,ir,ctc,tU,ctc,nLa,ctc,hp,ctc,kha,ctc,E1a,ctc,gi,ctc,ez,ctc,QWa,ctc,cx,ctc,lu,ctc,N2,ctc,Mu,ctc,Hca,ctc,lw,ctc,pn,ctc,DY,ctc,KB,ctc,BYa,ctc,xha,ctc,CJ,ctc,mt,ctc,g2,ctc,MR,ctc,ED,ctc,I6a,ctc,ujb,ctc,fK,ctc,S1a,ctc,Jx,ctc,AVa,ctc,iF,ctc,pJ,ctc,y4a,ctc,kga,ctc,bx,ctc,IZa,ctc,S3a,ctc,Ykb,ctc,AW,ctc,TV,ctc,_6a,ctc,WW,ctc,zr,ctc,lZ,ctc,Vmb,ctc,vga,ctc,qga,ctc,un,ctc,q_,ctc,d6a,ctc,t6a,ctc,Jca,ctc,RB,ctc,Ko,ctc,_3,ctc,ws,ctc,j3a,ctc,YF,ctc,nYa,ctc,t6,ctc,lq,ctc,Oy,ctc,OW,ctc,o1,ctc,qv,ctc,yjb,ctc,tF,ctc,gjb,ctc,dW,ctc,YQa,ctc,MB,ctc,qG,ctc,l3a,ctc,bib,ctc,kC,ctc,ss,ctc,w_,ctc,PJ,ctc,vl,ctc,UVa,ctc,xp,ctc,V_,ctc,iTb,ctc,cG,ctc,_C,ctc,sG,ctc,vOa,ctc,pq,ctc,e4a,ctc,mK,ctc,tI,ctc,r_,ctc,BF,ctc,F6a,ctc,wJ,ctc,ET,ctc,rn,ctc,K4,ctc,NU,ctc,Wm,ctc,X2,ctc,V$,ctc,BWa,ctc,k_,ctc,vT,ctc,io,ctc,Dl,ctc,G_,ctc,IT,ctc,bU,ctc,OXa,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc,ctc];var we=[dtc,dtc,wm,dtc,sm,dtc,UGa,dtc,om,dtc,RGa,dtc,DIa,dtc,em,dtc,km,dtc,um,dtc,lm,dtc,Cm,dtc,ttb,dtc,jm,dtc,gm,dtc,KHa,dtc,EIa,dtc,SGa,dtc,im,dtc,vm,dtc,qm,dtc,zm,dtc,tm,dtc,Bm,dtc,Am,dtc,pm,dtc,xm,dtc,rm,dtc,LHa,dtc,hm,dtc,MPb,dtc,MHa,dtc,ym,dtc,fm,dtc,GIa,dtc,nm,dtc,mm,dtc,NHa,dtc,TGa,dtc,FIa,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc,dtc];var xe=[etc,etc,zfa,etc,sHb,etc,tHb,etc];var ye=[ftc,ftc,uHb,ftc];var ze=[gtc,gtc,a5,gtc];var Ae=[htc,htc,R3,htc,SRb,htc,pHb,htc];var Be=[itc,itc,Odc,itc,Jn,itc,itc,itc];var Ce=[jtc,jtc];var De=[ktc,ktc,fub,ktc,hub,ktc,gub,ktc,eub,ktc,dub,ktc,cub,ktc,ktc,ktc];var Ee=[ltc,ltc,As,ltc,WNb,ltc,tM,ltc,EM,ltc,uM,ltc,Ug,ltc,VSb,ltc,$L,ltc,nNb,ltc,cM,ltc,Qr,ltc,QLa,ltc,xG,ltc,OZ,ltc,b9a,ltc,HM,ltc,cxb,ltc,ih,ltc,gg,ltc,AM,ltc,UNb,ltc,TRb,ltc,Cdc,ltc,_Vb,ltc,fE,ltc,hM,ltc,ZL,ltc,Zh,ltc,Grb,ltc,iB,ltc,_Xb,ltc,lh,ltc,Wg,ltc,sM,ltc,fg,ltc,WSb,ltc,K4a,ltc,qM,ltc,bM,ltc,PL,ltc,fI,ltc,yG,ltc,jM,ltc,RVb,ltc,Xf,ltc,UVb,ltc,XNb,ltc,CNa,ltc,YXb,ltc,kM,ltc,bXb,ltc,yi,ltc,ZO,ltc,Bs,ltc,vM,ltc,Xg,ltc,qWb,ltc,pWb,ltc,Eba,ltc,mh,ltc,oM,ltc,pM,ltc,gM,ltc,oWb,ltc,WZa,ltc,bV,ltc,dXb,ltc,Rf,ltc,UL,ltc,WLa,ltc,ZSb,ltc,aXb,ltc,Br,ltc,XL,ltc,zM,ltc,Mg,ltc,Bqc,ltc,qu,ltc,tWb,ltc,Og,ltc,_f,ltc,jh,ltc,VXb,ltc,YVb,ltc,XSb,ltc,ng,ltc,SVb,ltc,pg,ltc,zG,ltc,YSb,ltc,GM,ltc,dg,ltc,Cs,ltc,mg,ltc,Zf,ltc,VNb,ltc,Ng,ltc,XVb,ltc,sq,ltc,p_a,ltc,ZVb,ltc,ar,ltc,Vg,ltc,fh,ltc,VC,ltc,fW,ltc,KWa,ltc,Tg,ltc,av,ltc,gh,ltc,Zg,ltc,sg,ltc,kh,ltc,sWb,ltc,uWb,ltc,cE,ltc,smb,ltc,Yg,ltc,hXb,ltc,pmb,ltc,ANa,ltc,wM,ltc,rg,ltc,BA,ltc,o_a,ltc,IM,ltc,eg,ltc,ZXb,ltc,KP,ltc,ZWb,ltc,bxb,ltc,TVb,ltc,fXb,ltc,rWb,ltc,XWb,ltc,_Wb,ltc,FM,ltc,hh,ltc,SW,ltc,sba,ltc,UXb,ltc,YWb,ltc,mga,ltc,dh,ltc,gXb,ltc,os,ltc,YL,ltc,nWb,ltc,$Xb,ltc,pI,ltc,_g,ltc,Rg,ltc,wu,ltc,yM,ltc,WXb,ltc,cXb,ltc,TL,ltc,VL,ltc,Dm,ltc,Sg,ltc,lg,ltc,NL,ltc,cg,ltc,zNa,ltc,cab,ltc,Qg,ltc,mM,ltc,lM,ltc,nM,ltc,uia,ltc,eE,ltc,lA,ltc,SL,ltc,_L,ltc,DM,ltc,fM,ltc,eh,ltc,iXb,ltc,eM,ltc,dM,ltc,Pg,ltc,Au,ltc,tmb,ltc,eXb,ltc,GXb,ltc,QH,ltc,$g,ltc,nh,ltc,xM,ltc,qmb,ltc,B0b,ltc,QL,ltc,Qt,ltc,BM,ltc,WVb,ltc,VVb,ltc,aM,ltc,HL,ltc,umb,ltc,WL,ltc,VZa,ltc,rW,ltc,ig,ltc,xWb,ltc,ah,ltc,iM,ltc,kg,ltc,$Wb,ltc,ch,ltc,WWb,ltc,HYb,ltc,CM,ltc,aYb,ltc,BL,ltc,VA,ltc,c9a,ltc,Lg,ltc,rmb,ltc,nrc,ltc,og,ltc,TC,ltc,XXb,ltc,qg,ltc,wD,ltc,qA,ltc,OL,ltc,H9a,ltc,rM,ltc,RL,ltc,QVb,ltc,BNa,ltc,Kg,ltc,bh,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc,ltc];var Fe=[mtc,mtc,oB,mtc,nB,mtc,mB,mtc];var Ge=[ntc,ntc,us,ntc,Ija,ntc,Dka,ntc,KQa,ntc,F7b,ntc,mja,ntc,ts,ntc,zEb,ntc,IDb,ntc,hka,ntc,Eka,ntc,PEb,ntc,LEb,ntc,kja,ntc,GEb,ntc,rQb,ntc,KEb,ntc,NGa,ntc,EEb,ntc,MEb,ntc,vEb,ntc,mPb,ntc,NEb,ntc,JEb,ntc,FEb,ntc,HDb,ntc,lPb,ntc,uEb,ntc,sEb,ntc,lja,ntc,Lja,ntc,AEb,ntc,Gkb,ntc,yEb,ntc,Jja,ntc,Bt,ntc,$ka,ntc,Kja,ntc,PGa,ntc,BIa,ntc,OEb,ntc,eka,ntc,IHa,ntc,GHa,ntc,nja,ntc,DEb,ntc,ala,ntc,HEb,ntc,xEb,ntc,LPb,ntc,_ka,ntc,tEb,ntc,NPb,ntc,Cka,ntc,AIa,ntc,OGa,ntc,CEb,ntc,fka,ntc,bla,ntc,Fka,ntc,wEb,ntc,JHa,ntc,HHa,ntc,BEb,ntc,IEb,ntc,lxb,ntc,E7b,ntc,gka,ntc,CIa,ntc,QGa,ntc,G7b,ntc,zIa,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc,ntc];var He=[otc,otc,O2a,otc];var Ie=[ptc,ptc,gtb,ptc];var Je=[qtc,qtc,LA,qtc,eB,qtc,xA,qtc,nA,qtc,_q,qtc,aB,qtc,RA,qtc,sA,qtc,qtc,qtc,qtc,qtc,qtc,qtc,qtc,qtc,qtc,qtc,qtc,qtc,qtc,qtc];var Ke=[rtc,rtc,$V,rtc,Pdc,rtc,KO,rtc,YR,rtc,Qdc,rtc,qPb,rtc,_J,rtc,$T,rtc,vZ,rtc,FV,rtc,oF,rtc,PN,rtc,ZY,rtc,FO,rtc,wW,rtc,HS,rtc,NB,rtc,lL,rtc,fU,rtc,WV,rtc,fC,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc,rtc];var Le=[stc,stc,coc,stc];var Me=[ttc,ttc,zlb,ttc];var Ne=[utc,utc,n_b,utc,Jdc,utc,Kdc,utc,Hdc,utc,utc,utc,utc,utc,utc,utc];var Oe=[vtc,vtc,Irc,vtc,Jrc,vtc,cHb,vtc,Krc,vtc,Lrc,vtc,Mrc,vtc,Nrc,vtc,Orc,vtc,Prc,vtc,Qrc,vtc,Rrc,vtc,Src,vtc,Trc,vtc,vtc,vtc,vtc,vtc];var Pe=[wtc,wtc,N6,wtc];var Qe=[xtc,xtc,aoc,xtc];var Re=[ytc,ytc,t4a,ytc,YPa,ytc,ytc,ytc];var Se=[ztc,ztc,pdb,ztc,Hcb,ztc,ydb,ztc,nob,ztc,b5,ztc,$cb,ztc,jcb,ztc,Pcb,ztc,Obb,ztc,mdb,ztc,Ayb,ztc,EAb,ztc,hIa,ztc,k2a,ztc,Ndb,ztc,uPb,ztc,tPb,ztc,ucb,ztc,Ldb,ztc,mcb,ztc,MA,ztc,cRb,ztc,dRb,ztc,KIa,ztc,YGa,ztc,wdb,ztc,_5,ztc,VIa,ztc,Qab,ztc,Lbb,ztc,Gvb,ztc,kcb,ztc,yPb,ztc,APb,ztc,FAb,ztc,WIa,ztc,bcb,ztc,ddb,ztc,Fyb,ztc,Jbb,ztc,OHa,ztc,Ddb,ztc,sAb,ztc,czb,ztc,fzb,ztc,Z5,ztc,HIa,ztc,VGa,ztc,Wab,ztc,WHa,ztc,lzb,ztc,jzb,ztc,xcb,ztc,Lcb,ztc,Oyb,ztc,wAb,ztc,Fcb,ztc,Odb,ztc,Wbb,ztc,Kbb,ztc,Yab,ztc,hbb,ztc,zcb,ztc,wcb,ztc,Zbb,ztc,ycb,ztc,Hyb,ztc,Byb,ztc,Wdb,ztc,xdb,ztc,Syb,ztc,Uab,ztc,Pab,ztc,iyb,ztc,Gdb,ztc,_ab,ztc,Uyb,ztc,Sbb,ztc,Lab,ztc,gzb,ztc,Tyb,ztc,Mcb,ztc,Ccb,ztc,Ryb,ztc,Kab,ztc,sdb,ztc,odb,ztc,AAb,ztc,Vbb,ztc,Kcb,ztc,lbb,ztc,Evb,ztc,ncb,ztc,sPb,ztc,Dcb,ztc,uA,ztc,ezb,ztc,YHa,ztc,evb,ztc,Ybb,ztc,xyb,ztc,Gyb,ztc,dcb,ztc,g1a,ztc,Pyb,ztc,cbb,ztc,Zdb,ztc,tdb,ztc,izb,ztc,Hbb,ztc,$bb,ztc,fdb,ztc,IIa,ztc,WGa,ztc,zyb,ztc,klb,ztc,Bdb,ztc,Ucb,ztc,$Ga,ztc,Wyb,ztc,Nyb,ztc,Vcb,ztc,wyb,ztc,Wcb,ztc,iHa,ztc,NA,ztc,vPb,ztc,ARb,ztc,BRb,ztc,Hdb,ztc,_Ha,ztc,yVa,ztc,oAb,ztc,lcb,ztc,Jcb,ztc,i4a,ztc,ozb,ztc,Q5,ztc,Xyb,ztc,Cvb,ztc,lob,ztc,Yyb,ztc,mbb,ztc,zAb,ztc,ocb,ztc,Ivb,ztc,QIa,ztc,cHa,ztc,aRb,ztc,pzb,ztc,Cdb,ztc,z8a,ztc,Xab,ztc,Mab,ztc,Qcb,ztc,Dyb,ztc,hdb,ztc,jdb,ztc,hHa,ztc,LIa,ztc,ZGa,ztc,Mdb,ztc,$5,ztc,Tab,ztc,Acb,ztc,Myb,ztc,SIa,ztc,eHa,ztc,Zyb,ztc,XHa,ztc,mxb,ztc,kbb,ztc,UHa,ztc,bbb,ztc,Kdb,ztc,Adb,ztc,abb,ztc,Fbb,ztc,VHa,ztc,Tdb,ztc,ccb,ztc,Mbb,ztc,bIa,ztc,edb,ztc,kzb,ztc,Edb,ztc,Lyb,ztc,Qyb,ztc,bdb,ztc,dzb,ztc,fyb,ztc,Qbb,ztc,zPb,ztc,_bb,ztc,Jdb,ztc,fbb,ztc,Rdb,ztc,RHa,ztc,bHa,ztc,PIa,ztc,Mqb,ztc,Jyb,ztc,Ubb,ztc,Ycb,ztc,_Ga,ztc,MIa,ztc,gdb,ztc,Fdb,ztc,Vdb,ztc,vdb,ztc,Qdb,ztc,Nbb,ztc,xRb,ztc,eyb,ztc,nzb,ztc,PHa,ztc,Ibb,ztc,aJa,ztc,oHa,ztc,gcb,ztc,gyb,ztc,aHa,ztc,OIa,ztc,_cb,ztc,nbb,ztc,gbb,ztc,adb,ztc,Zcb,ztc,Pbb,ztc,SHa,ztc,Xbb,ztc,qdb,ztc,pcb,ztc,uyb,ztc,hyb,ztc,ZQb,ztc,kdb,ztc,Icb,ztc,mob,ztc,z8,ztc,jAb,ztc,tcb,ztc,idb,ztc,zRb,ztc,yRb,ztc,R5,ztc,TIa,ztc,fHa,ztc,hcb,ztc,bzb,ztc,vyb,ztc,Sab,ztc,Vyb,ztc,vAb,ztc,wPb,ztc,ndb,ztc,ZHa,ztc,xPb,ztc,Oab,ztc,_yb,ztc,ebb,ztc,Udb,ztc,$ab,ztc,zdb,ztc,aIa,ztc,Sdb,ztc,Ydb,ztc,Rcb,ztc,udb,ztc,Zab,ztc,_Qb,ztc,$Ha,ztc,ldb,ztc,THa,ztc,nxb,ztc,vcb,ztc,$yb,ztc,Iba,ztc,QHa,ztc,Pdb,ztc,Rbb,ztc,gHa,ztc,UIa,ztc,Gcb,ztc,Rab,ztc,rdb,ztc,Ecb,ztc,Ocb,ztc,Nab,ztc,yba,ztc,WPb,ztc,Iyb,ztc,fcb,ztc,cdb,ztc,OA,ztc,ecb,ztc,$Qb,ztc,azb,ztc,Kyb,ztc,Xdb,ztc,hzb,ztc,dbb,ztc,Eyb,ztc,obb,ztc,jbb,ztc,Gbb,ztc,Tcb,ztc,Lqb,ztc,oxb,ztc,mzb,ztc,rcb,ztc,Ncb,ztc,pbb,ztc,Iab,ztc,BPb,ztc,DPb,ztc,CPb,ztc,Vab,ztc,acb,ztc,ibb,ztc,bRb,ztc,Scb,ztc,oob,ztc,NIa,ztc,XGa,ztc,JIa,ztc,rAb,ztc,_db,ztc,dHa,ztc,RIa,ztc,Cyb,ztc,Bcb,ztc,icb,ztc,Idb,ztc,yyb,ztc,scb,ztc,Jab,ztc,Xcb,ztc,kAb,ztc,nAb,ztc,Tbb,ztc,qcb,ztc,jxb,ztc,DRb,ztc,CRb,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc,ztc];var Te=[Atc,Atc,TBb,Atc,jCb,Atc,Wu,Atc,rPb,Atc,MDb,Atc,vCb,Atc,tBb,Atc,BCb,Atc,w$a,Atc,UAb,Atc,aCb,Atc,Vu,Atc,Ww,Atc,qBb,Atc,wVa,Atc,Sw,Atc,XAb,Atc,Xr,Atc,BBb,Atc,XIa,Atc,jHa,Atc,IAb,Atc,Tw,Atc,Rw,Atc,Uu,Atc,gCb,Atc,Vw,Atc,QBb,Atc,bBb,Atc,hBb,Atc,yCb,Atc,nBb,Atc,iIa,Atc,RAb,Atc,HBb,Atc,Mha,Atc,LDb,Atc,yBb,Atc,Xu,Atc,BDb,Atc,XPb,Atc,EBb,Atc,dIa,Atc,eIa,Atc,mHa,Atc,_Ia,Atc,LAb,Atc,sCb,Atc,NDb,Atc,KBb,Atc,ECb,Atc,eBb,Atc,ZIa,Atc,lHa,Atc,kBb,Atc,mCb,Atc,RPb,Atc,Pw,Atc,Wr,Atc,CDb,Atc,VTa,Atc,ZBb,Atc,vBb,Atc,DDb,Atc,_Ab,Atc,v$a,Atc,pHa,Atc,ODb,Atc,YIa,Atc,kHa,Atc,Uw,Atc,pCb,Atc,pPb,Atc,OAb,Atc,dCb,Atc,KCb,Atc,cIa,Atc,A8a,Atc,fIa,Atc,EDb,Atc,NBb,Atc,FDb,Atc,WBb,Atc,bJa,Atc,HCb,Atc,Qw,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc,Atc];var Ue=[Btc,Btc,Ytb,Btc];var Ve=[Ctc,Ctc,bCb,Ctc,jBb,Ctc,tec,Ctc,nec,Ctc,UBb,Ctc,WAb,Ctc,JDb,Ctc,aBb,Ctc,sBb,Ctc,mBb,Ctc,NCb,Ctc,dBb,Ctc,nCb,Ctc,wBb,Ctc,IBb,Ctc,OBb,Ctc,vec,Ctc,HAb,Ctc,kCb,Ctc,uec,Ctc,_9a,Ctc,ZAb,Ctc,eCb,Ctc,LBb,Ctc,KDb,Ctc,NAb,Ctc,pec,Ctc,E8a,Ctc,ICb,Ctc,wCb,Ctc,hec,Ctc,rec,Ctc,RBb,Ctc,tCb,Ctc,QAb,Ctc,F8a,Ctc,TAb,Ctc,_Bb,Ctc,hCb,Ctc,lec,Ctc,pBb,Ctc,zBb,Ctc,qCb,Ctc,KAb,Ctc,XBb,Ctc,gBb,Ctc,zCb,Ctc,FBb,Ctc,LCb,Ctc,CBb,Ctc,FCb,Ctc,CCb,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc,Ctc];var We=[Dtc,Dtc,mJ,Dtc,LQ,Dtc,oP,Dtc,JN,Dtc,Ws,Dtc,iS,Dtc,PA,Dtc,_h,Dtc,Ig,Dtc,Gu,Dtc,uI,Dtc,GY,Dtc,_G,Dtc,nE,Dtc,so,Dtc,aG,Dtc,CS,Dtc,fab,Dtc,X_,Dtc,Ox,Dtc,Hfa,Dtc,Tx,Dtc,eP,Dtc,cQ,Dtc,EXb,Dtc,yWb,Dtc,rE,Dtc,_A,Dtc,qT,Dtc,Fha,Dtc,z_,Dtc,QJ,Dtc,FF,Dtc,nH,Dtc,_P,Dtc,fR,Dtc,mD,Dtc,kMa,Dtc,ZT,Dtc,yV,Dtc,ot,Dtc,pj,Dtc,Ix,Dtc,Xx,Dtc,kJ,Dtc,Rt,Dtc,MK,Dtc,pA,Dtc,ORb,Dtc,iV,Dtc,Tpc,Dtc,h_,Dtc,CR,Dtc,AH,Dtc,BYb,Dtc,bR,Dtc,cq,Dtc,pkb,Dtc,MW,Dtc,sla,Dtc,MRb,Dtc,XW,Dtc,Um,Dtc,ERb,Dtc,g$,Dtc,v_,Dtc,tZ,Dtc,zO,Dtc,hO,Dtc,Nt,Dtc,YEa,Dtc,kq,Dtc,_p,Dtc,Bx,Dtc,Qn,Dtc,gp,Dtc,GUa,Dtc,nk,Dtc,R4a,Dtc,L5,Dtc,VLa,Dtc,dC,Dtc,$n,Dtc,tt,Dtc,QF,Dtc,MWb,Dtc,Nl,Dtc,gz,Dtc,wo,Dtc,eS,Dtc,uR,Dtc,Jr,Dtc,yJ,Dtc,Vp,Dtc,s_,Dtc,Ty,Dtc,qw,Dtc,PLa,Dtc,mF,Dtc,$I,Dtc,eO,Dtc,zA,Dtc,Wt,Dtc,wq,Dtc,nx,Dtc,NO,Dtc,vn,Dtc,kz,Dtc,eKb,Dtc,vE,Dtc,yZ,Dtc,pMa,Dtc,wV,Dtc,nMa,Dtc,Wn,Dtc,Ep,Dtc,UW,Dtc,hC,Dtc,qR,Dtc,KA,Dtc,vp,Dtc,Khb,Dtc,Ai,Dtc,hJ,Dtc,uW,Dtc,Hq,Dtc,er,Dtc,VJ,Dtc,nz,Dtc,wk,Dtc,YK,Dtc,Il,Dtc,AF,Dtc,tR,Dtc,BB,Dtc,aVa,Dtc,yl,Dtc,SN,Dtc,f6a,Dtc,jT,Dtc,KV,Dtc,iR,Dtc,dt,Dtc,rK,Dtc,AT,Dtc,Kq,Dtc,pL,Dtc,Jfc,Dtc,Fn,Dtc,pS,Dtc,QEa,Dtc,Yh,Dtc,fUa,Dtc,HVb,Dtc,pV,Dtc,QO,Dtc,DYb,Dtc,sS,Dtc,mQ,Dtc,Vpc,Dtc,aR,Dtc,xF,Dtc,qn,Dtc,Xm,Dtc,js,Dtc,gB,Dtc,Gl,Dtc,dJ,Dtc,XU,Dtc,FS,Dtc,dv,Dtc,it,Dtc,Gy,Dtc,EZ,Dtc,gK,Dtc,p3a,Dtc,iE,Dtc,qH,Dtc,zp,Dtc,Jy,Dtc,YE,Dtc,mu,Dtc,FI,Dtc,gea,Dtc,iMa,Dtc,XY,Dtc,$R,Dtc,uH,Dtc,Er,Dtc,_H,Dtc,N$,Dtc,XQ,Dtc,Cg,Dtc,SG,Dtc,Kw,Dtc,zS,Dtc,ZV,Dtc,Upc,Dtc,YW,Dtc,Wo,Dtc,DV,Dtc,ax,Dtc,Phc,Dtc,l_,Dtc,Bu,Dtc,jR,Dtc,yQ,Dtc,Sn,Dtc,TJ,Dtc,iu,Dtc,dU,Dtc,kn,Dtc,hW,Dtc,Hz,Dtc,JVb,Dtc,Ex,Dtc,jK,Dtc,uJ,Dtc,pTb,Dtc,oTb,Dtc,ti,Dtc,d_,Dtc,Ckb,Dtc,Hm,Dtc,Bic,Dtc,a$,Dtc,jw,Dtc,tB,Dtc,NG,Dtc,yB,Dtc,zN,Dtc,cB,Dtc,DG,Dtc,eZ,Dtc,o_,Dtc,LS,Dtc,lC,Dtc,Jg,Dtc,RZ,Dtc,np,Dtc,yR,Dtc,SU,Dtc,Lm,Dtc,$s,Dtc,Nn,Dtc,jZ,Dtc,Nw,Dtc,RE,Dtc,wK,Dtc,jI,Dtc,Oj,Dtc,Zo,Dtc,nD,Dtc,Vl,Dtc,Bk,Dtc,gF,Dtc,Nu,Dtc,DO,Dtc,LV,Dtc,xu,Dtc,HRb,Dtc,nC,Dtc,XA,Dtc,xV,Dtc,EY,Dtc,qMa,Dtc,$Ra,Dtc,IA,Dtc,RR,Dtc,sH,Dtc,oMa,Dtc,lo,Dtc,Jk,Dtc,DVb,Dtc,C_,Dtc,GRb,Dtc,Yr,Dtc,IO,Dtc,Ms,Dtc,A8,Dtc,hR,Dtc,Zl,Dtc,FH,Dtc,YJ,Dtc,oK,Dtc,cMa,Dtc,cVa,Dtc,JC,Dtc,vWb,Dtc,JF,Dtc,IG,Dtc,NJ,Dtc,Po,Dtc,YA,Dtc,Zu,Dtc,qTb,Dtc,rTb,Dtc,aZ,Dtc,zW,Dtc,hQ,Dtc,CC,Dtc,yE,Dtc,kA,Dtc,HV,Dtc,Ni,Dtc,Rr,Dtc,vV,Dtc,WA,Dtc,Ql,Dtc,Go,Dtc,Ax,Dtc,vA,Dtc,AV,Dtc,Aic,Dtc,nR,Dtc,Ny,Dtc,zV,Dtc,eca,Dtc,tN,Dtc,xR,Dtc,NH,Dtc,FWb,Dtc,ey,Dtc,Nda,Dtc,HQ,Dtc,mA,Dtc,rA,Dtc,tV,Dtc,nj,Dtc,BE,Dtc,FUa,Dtc,Kt,Dtc,XB,Dtc,iUa,Dtc,R0b,Dtc,N5,Dtc,jF,Dtc,Sp,Dtc,EW,Dtc,oy,Dtc,DT,Dtc,qJ,Dtc,gL,Dtc,ru,Dtc,BI,Dtc,HT,Dtc,lP,Dtc,Nj,Dtc,am,Dtc,VG,Dtc,rG,Dtc,C0b,Dtc,P_,Dtc,$K,Dtc,gk,Dtc,GP,Dtc,TA,Dtc,RY,Dtc,ho,Dtc,KK,Dtc,__,Dtc,Lj,Dtc,kR,Dtc,pt,Dtc,Xo,Dtc,zi,Dtc,mR,Dtc,ul,Dtc,M$,Dtc,bn,Dtc,dR,Dtc,NRb,Dtc,Et,Dtc,dMa,Dtc,eMa,Dtc,fMa,Dtc,gMa,Dtc,hMa,Dtc,sMa,Dtc,tMa,Dtc,uMa,Dtc,vMa,Dtc,wMa,Dtc,xMa,Dtc,yMa,Dtc,zMa,Dtc,AMa,Dtc,BMa,Dtc,uca,Dtc,mMa,Dtc,LE,Dtc,pR,Dtc,GVb,Dtc,Lp,Dtc,jL,Dtc,UF,Dtc,Rx,Dtc,vC,Dtc,QB,Dtc,vB,Dtc,vJ,Dtc,sVa,Dtc,vU,Dtc,rs,Dtc,Cn,Dtc,Ez,Dtc,HW,Dtc,LB,Dtc,EL,Dtc,ur,Dtc,PR,Dtc,uw,Dtc,gUa,Dtc,pk,Dtc,ZF,Dtc,Zm,Dtc,Dk,Dtc,yU,Dtc,OM,Dtc,FRb,Dtc,Pq,Dtc,UV,Dtc,nt,Dtc,rN,Dtc,WR,Dtc,Kn,Dtc,Wda,Dtc,M5,Dtc,F_,Dtc,Bdc,Dtc,$E,Dtc,HZ,Dtc,HXb,Dtc,S_,Dtc,nL,Dtc,NN,Dtc,Ak,Dtc,cF,Dtc,dZb,Dtc,dTb,Dtc,IWb,Dtc,ds,Dtc,ZC,Dtc,OU,Dtc,LWb,Dtc,sL,Dtc,LU,Dtc,hUa,Dtc,cK,Dtc,JMa,Dtc,AWb,Dtc,vS,Dtc,Ii,Dtc,cW,Dtc,QW,Dtc,xT,Dtc,UE,Dtc,oN,Dtc,vF,Dtc,HI,Dtc,bT,Dtc,sU,Dtc,as,Dtc,vL,Dtc,rWa,Dtc,NE,Dtc,AXa,Dtc,tG,Dtc,HU,Dtc,Tjc,Dtc,pQ,Dtc,Uy,Dtc,Qm,Dtc,bu,Dtc,nr,Dtc,dG,Dtc,U_,Dtc,eTb,Dtc,FG,Dtc,$y,Dtc,a3,Dtc,di,Dtc,fV,Dtc,lMa,Dtc,BZ,Dtc,jMa,Dtc,qp,Dtc,pZ,Dtc,jH,Dtc,Q$,Dtc,wrb,Dtc,EN,Dtc,sO,Dtc,PY,Dtc,hr,Dtc,fn,Dtc,CH,Dtc,EB,Dtc,nG,Dtc,uVa,Dtc,B8,Dtc,gx,Dtc,lR,Dtc,d$,Dtc,oR,Dtc,sF,Dtc,KR,Dtc,ni,Dtc,JXb,Dtc,UU,Dtc,Lhc,Dtc,Khc,Dtc,gR,Dtc,Mtb,Dtc,JE,Dtc,Xy,Dtc,Vy,Dtc,qW,Dtc,iG,Dtc,ys,Dtc,VRa,Dtc,KY,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc,Dtc];var Xe=[Etc,Etc,Z6b,Etc,_Ta,Etc,rba,Etc,bZ,Etc,aba,Etc,i9b,Etc,fba,Etc,R6b,Etc,y6b,Etc,SB,Etc,_aa,Etc,pN,Etc,FN,Etc,IQ,Etc,eU,Etc,Fba,Etc,r7b,Etc,E6b,Etc,F9b,Etc,tjb,Etc,kba,Etc,cR,Etc,jba,Etc,GH,Etc,Y4b,Etc,N6b,Etc,lT,Etc,Uaa,Etc,l7b,Etc,HH,Etc,QRb,Etc,rR,Etc,URb,Etc,P4a,Etc,E9b,Etc,s7b,Etc,O6b,Etc,RW,Etc,aUa,Etc,Vaa,Etc,H8,Etc,L8,Etc,Yaa,Etc,K6b,Etc,V6b,Etc,G9b,Etc,zE,Etc,BN,Etc,gO,Etc,fZ,Etc,sQ,Etc,mT,Etc,qP,Etc,$6b,Etc,pba,Etc,nba,Etc,NQ,Etc,i8,Etc,aF,Etc,eK,Etc,mba,Etc,dba,Etc,hba,Etc,o7b,Etc,zWb,Etc,U4b,Etc,Q6b,Etc,n7b,Etc,GG,Etc,D9b,Etc,e_,Etc,PRb,Etc,Xaa,Etc,I4b,Etc,c5b,Etc,rQ,Etc,r1a,Etc,cba,Etc,m7b,Etc,bba,Etc,W6b,Etc,E8,Etc,qba,Etc,N9b,Etc,a5b,Etc,gba,Etc,x6,Etc,DWb,Etc,kG,Etc,TB,Etc,hkb,Etc,j9b,Etc,eba,Etc,Kqb,Etc,S6b,Etc,eR,Etc,P9b,Etc,p1a,Etc,J8,Etc,xC,Etc,drb,Etc,o1a,Etc,q7b,Etc,uS,Etc,B9b,Etc,DR,Etc,_4b,Etc,lI,Etc,O9b,Etc,$aa,Etc,lba,Etc,XG,Etc,U6b,Etc,W$,Etc,IXb,Etc,k7b,Etc,M4b,Etc,k9b,Etc,F8,Etc,e5b,Etc,K4b,Etc,Waa,Etc,q1a,Etc,p7b,Etc,H9b,Etc,zR,Etc,bS,Etc,H6b,Etc,JZ,Etc,jQ,Etc,SR,Etc,GB,Etc,$Yb,Etc,SF,Etc,jS,Etc,I8,Etc,W4b,Etc,iba,Etc,NW,Etc,Y6b,Etc,f9b,Etc,K8,Etc,cT,Etc,Taa,Etc,KN,Etc,h9b,Etc,sJ,Etc,GL,Etc,aJ,Etc,G8,Etc,Zaa,Etc,oba,Etc,dj,Etc,OQ,Etc,yK,Etc,O4b,Etc,fP,Etc,S4b,Etc,Q4b,Etc,x_,Etc,_6b,Etc,X6b,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc,Etc];var Ye=[Ftc,Ftc,EIb,Ftc];var Ze=[Gtc,Gtc,ep,Gtc,cp,Gtc,bp,Gtc,dp,Gtc,Gtc,Gtc,Gtc,Gtc,Gtc,Gtc];var _e=[Htc,Htc,GDb,Htc,Pia,Htc,Ezb,Htc,fAb,Htc,ZSa,Htc,aka,Htc,KJa,Htc,p$a,Htc,Gja,Htc,ip,Htc,u$a,Htc,ptb,Htc,rtb,Htc,Fzb,Htc,GJa,Htc,TQb,Htc,Uia,Htc,Zia,Htc,Lzb,Htc,rHa,Htc,dJa,Htc,Yka,Htc,SQb,Htc,$ia,Htc,Aka,Htc,$Ia,Htc,nHa,Htc,_ia,Htc,fqb,Htc,Qzb,Htc,qz,Htc,v8a,Htc,xJa,Htc,uIb,Htc,Ria,Htc,Yia,Htc,lIa,Htc,wRb,Htc,RJa,Htc,gIa,Htc,kIa,Htc,x$a,Htc,Zka,Htc,Xia,Htc,ija,Htc,Qia,Htc,Wia,Htc,Xzb,Htc,s$a,Htc,yka,Htc,eAb,Htc,Tia,Htc,Xka,Htc,Gzb,Htc,t8a,Htc,zLa,Htc,Hw,Htc,$zb,Htc,Eea,Htc,Tzb,Htc,vRb,Htc,Vzb,Htc,hja,Htc,u8a,Htc,sRb,Htc,Mzb,Htc,bQb,Htc,aQb,Htc,Gea,Htc,Sia,Htc,JJa,Htc,HJa,Htc,Hja,Htc,Jzb,Htc,VI,Htc,jja,Htc,q$a,Htc,rOb,Htc,cAb,Htc,vba,Htc,Pzb,Htc,Oia,Htc,UQb,Htc,zJa,Htc,qtb,Htc,stb,Htc,zka,Htc,ZPb,Htc,o$a,Htc,cpc,Htc,Szb,Htc,Kzb,Htc,apb,Htc,wJa,Htc,QJa,Htc,Wob,Htc,Wzb,Htc,kxb,Htc,t$a,Htc,USa,Htc,Wka,Htc,_Pb,Htc,$Pb,Htc,Hzb,Htc,Rzb,Htc,hpc,Htc,yJa,Htc,SJa,Htc,Jw,Htc,bka,Htc,Uzb,Htc,XQb,Htc,Nia,Htc,qRb,Htc,sz,Htc,Iw,Htc,dka,Htc,Bab,Htc,Czb,Htc,ALa,Htc,ipc,Htc,YQb,Htc,QI,Htc,rz,Htc,IJa,Htc,S5,Htc,gAb,Htc,dAb,Htc,Via,Htc,TJa,Htc,_zb,Htc,npc,Htc,Izb,Htc,rRb,Htc,aja,Htc,y$a,Htc,mpc,Htc,lpc,Htc,SI,Htc,epc,Htc,Eab,Htc,Eja,Htc,UI,Htc,kPb,Htc,Zzb,Htc,aAb,Htc,cka,Htc,VQb,Htc,Fab,Htc,sHa,Htc,eJa,Htc,jpc,Htc,r$a,Htc,gja,Htc,AJa,Htc,UJa,Htc,Fja,Htc,s8a,Htc,tRb,Htc,uRb,Htc,jp,Htc,cQb,Htc,Bka,Htc,wba,Htc,C4,Htc,Bub,Htc,Gw,Htc,yLa,Htc,Dzb,Htc,Aab,Htc,Nzb,Htc,hAb,Htc,Ozb,Htc,WQb,Htc,Yzb,Htc,pz,Htc,bAb,Htc,n$a,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc,Htc];var $e=[Itc,Itc,Zwb,Itc];var af=[Jtc,Jtc,lBb,Jtc,PBb,Jtc,SAb,Jtc,fBb,Jtc,rCb,Jtc,GBb,Jtc,jIa,Jtc,cJa,Jtc,qHa,Jtc,uBb,Jtc,YAb,Jtc,MBb,Jtc,DCb,Jtc,iBb,Jtc,VBb,Jtc,$Bb,Jtc,JAb,Jtc,JBb,Jtc,xCb,Jtc,SBb,Jtc,oCb,Jtc,cBb,Jtc,ACb,Jtc,oBb,Jtc,$Ab,Jtc,ABb,Jtc,YBb,Jtc,rBb,Jtc,lCb,Jtc,uCb,Jtc,MCb,Jtc,GAb,Jtc,iCb,Jtc,GCb,Jtc,JCb,Jtc,cCb,Jtc,MAb,Jtc,DBb,Jtc,fCb,Jtc,VAb,Jtc,PAb,Jtc,xBb,Jtc,xVa,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc,Jtc];var bf=[Ktc,Ktc,$tb,Ktc,Wtb,Ktc,_tb,Ktc,bub,Ktc,Ktc,Ktc,Ktc,Ktc,Ktc,Ktc];var cf=[Ltc,Ltc,Us,Ltc,Vs,Ltc,nq,Ltc,_Ya,Ltc,mq,Ltc,ZYa,Ltc,iw,Ltc];var df=[Mtc,Mtc,mlb,Mtc,ntb,Mtc,Mtc,Mtc];var ef=[Ntc,Ntc,nsb,Ntc,Uza,Ntc,baa,Ntc,xBa,Ntc,Wma,Ntc,$6,Ntc,Xta,Ntc,dDb,Ntc,H9,Ntc,NBa,Ntc,zta,Ntc,vya,Ntc,tnb,Ntc,Gla,Ntc,ynb,Ntc,uab,Ntc,W9,Ntc,upa,Ntc,oAa,Ntc,noa,Ntc,_la,Ntc,$ta,Ntc,Xua,Ntc,Cwa,Ntc,cua,Ntc,Vza,Ntc,A9a,Ntc,Gua,Ntc,$_a,Ntc,Dpa,Ntc,Yra,Ntc,jAa,Ntc,iDa,Ntc,yaa,Ntc,SCa,Ntc,usb,Ntc,axa,Ntc,jDa,Ntc,mDa,Ntc,uCa,Ntc,Xwa,Ntc,FDa,Ntc,MCa,Ntc,BAa,Ntc,d9,Ntc,lDa,Ntc,K_a,Ntc,IBa,Ntc,Yva,Ntc,oDa,Ntc,mCa,Ntc,TPb,Ntc,t0a,Ntc,CAa,Ntc,aO,Ntc,nua,Ntc,$za,Ntc,n8,Ntc,Bwa,Ntc,dxa,Ntc,HDa,Ntc,I7a,Ntc,Wza,Ntc,h$a,Ntc,znb,Ntc,ZCa,Ntc,ltb,Ntc,Pwa,Ntc,kDb,Ntc,vDa,Ntc,Ova,Ntc,Mxa,Ntc,Nnb,Ntc,U6,Ntc,yxa,Ntc,yNb,Ntc,wsb,Ntc,ewa,Ntc,owa,Ntc,y9a,Ntc,pCa,Ntc,EGa,Ntc,qIa,Ntc,qta,Ntc,Cba,Ntc,Gva,Ntc,jCa,Ntc,Fsb,Ntc,PBa,Ntc,uQb,Ntc,Qaa,Ntc,nDa,Ntc,hua,Ntc,Zya,Ntc,g9,Ntc,rCa,Ntc,nva,Ntc,isb,Ntc,zxa,Ntc,Pya,Ntc,Rwa,Ntc,xIa,Ntc,dpb,Ntc,qwa,Ntc,s9,Ntc,N7,Ntc,sxb,Ntc,ioa,Ntc,eqb,Ntc,w0a,Ntc,r0a,Ntc,dua,Ntc,Iya,Ntc,Onb,Ntc,_kc,Ntc,Eaa,Ntc,l7,Ntc,R9,Ntc,uBa,Ntc,o0a,Ntc,swa,Ntc,cja,Ntc,PCb,Ntc,KGa,Ntc,wIa,Ntc,qsb,Ntc,Gab,Ntc,nnb,Ntc,lya,Ntc,LCa,Ntc,t7,Ntc,bDb,Ntc,bua,Ntc,iqb,Ntc,q8,Ntc,maa,Ntc,$ga,Ntc,O9,Ntc,eDa,Ntc,vpa,Ntc,Tqa,Ntc,tPa,Ntc,zaa,Ntc,Aqa,Ntc,D7,Ntc,bva,Ntc,aya,Ntc,Rqa,Ntc,yDb,Ntc,_ob,Ntc,qva,Ntc,rza,Ntc,gob,Ntc,Oza,Ntc,Aua,Ntc,qCa,Ntc,vsb,Ntc,Mnb,Ntc,Hkb,Ntc,lua,Ntc,_Sb,Ntc,x9,Ntc,T9a,Ntc,n9,Ntc,Dta,Ntc,INb,Ntc,zza,Ntc,Nya,Ntc,a$a,Ntc,Wxa,Ntc,Fua,Ntc,job,Ntc,Asb,Ntc,k$a,Ntc,Cbc,Ntc,roa,Ntc,L7,Ntc,C9,Ntc,Xob,Ntc,Cnb,Ntc,pnb,Ntc,vta,Ntc,sva,Ntc,Yna,Ntc,T9,Ntc,AAa,Ntc,XAa,Ntc,dta,Ntc,X_a,Ntc,hAa,Ntc,gxa,Ntc,iAa,Ntc,z7,Ntc,HGa,Ntc,tIa,Ntc,Wva,Ntc,_Nb,Ntc,XBa,Ntc,pya,Ntc,yva,Ntc,z9a,Ntc,Owa,Ntc,bsa,Ntc,h9,Ntc,G_a,Ntc,YAa,Ntc,sya,Ntc,hva,Ntc,xsb,Ntc,vnb,Ntc,l$a,Ntc,yHa,Ntc,Mqa,Ntc,D9,Ntc,Jaa,Ntc,J7a,Ntc,iua,Ntc,qDa,Ntc,Nxa,Ntc,BHa,Ntc,Dua,Ntc,$nb,Ntc,NAa,Ntc,Cta,Ntc,QPa,Ntc,E7,Ntc,aua,Ntc,kua,Ntc,Gma,Ntc,Cma,Ntc,xxa,Ntc,Jma,Ntc,G7,Ntc,hpb,Ntc,nwb,Ntc,Gxa,Ntc,naa,Ntc,qDb,Ntc,Iza,Ntc,Swa,Ntc,yDa,Ntc,jva,Ntc,m$a,Ntc,fCa,Ntc,h7,Ntc,T6,Ntc,sDa,Ntc,BCa,Ntc,zua,Ntc,E9,Ntc,jwa,Ntc,jDb,Ntc,yta,Ntc,R9a,Ntc,DGa,Ntc,pIa,Ntc,Aba,Ntc,Kma,Ntc,yCa,Ntc,hwa,Ntc,ADa,Ntc,msb,Ntc,Iaa,Ntc,fua,Ntc,UAa,Ntc,K7,Ntc,Hpa,Ntc,Ywa,Ntc,NCa,Ntc,G9,Ntc,KCa,Ntc,RBa,Ntc,Gwa,Ntc,A0a,Ntc,bza,Ntc,_xa,Ntc,kDa,Ntc,Xza,Ntc,aCa,Ntc,Fla,Ntc,snb,Ntc,LAa,Ntc,Hza,Ntc,Eua,Ntc,Bqa,Ntc,fwa,Ntc,_Aa,Ntc,B9,Ntc,K7a,Ntc,qoa,Ntc,zqa,Ntc,iaa,Ntc,bDa,Ntc,$Aa,Ntc,Pqa,Ntc,mAa,Ntc,Ava,Ntc,eva,Ntc,kva,Ntc,c$a,Ntc,I3a,Ntc,tza,Ntc,fxa,Ntc,Bma,Ntc,Nma,Ntc,Zva,Ntc,xwa,Ntc,uza,Ntc,Cpa,Ntc,Jza,Ntc,zAa,Ntc,awa,Ntc,Jsb,Ntc,H_a,Ntc,Vua,Ntc,pwa,Ntc,vDb,Ntc,caa,Ntc,sCa,Ntc,sxa,Ntc,lza,Ntc,Sya,Ntc,Sqb,Ntc,iDb,Ntc,z9,Ntc,E0a,Ntc,V8a,Ntc,inb,Ntc,oxa,Ntc,_4,Ntc,Jkb,Ntc,ooa,Ntc,wya,Ntc,Znb,Ntc,fya,Ntc,Gaa,Ntc,kxa,Ntc,osb,Ntc,koa,Ntc,zva,Ntc,b$a,Ntc,uya,Ntc,Qqa,Ntc,xya,Ntc,l9,Ntc,hxa,Ntc,Qua,Ntc,Eza,Ntc,Dma,Ntc,knb,Ntc,lqb,Ntc,mqb,Ntc,hqb,Ntc,jqb,Ntc,oqb,Ntc,pqb,Ntc,_Ba,Ntc,zCa,Ntc,Lqa,Ntc,nya,Ntc,uDb,Ntc,c7,Ntc,m8,Ntc,rBa,Ntc,r9,Ntc,wza,Ntc,GCa,Ntc,dva,Ntc,dCa,Ntc,$sb,Ntc,Qza,Ntc,A_a,Ntc,JBa,Ntc,BQb,Ntc,ava,Ntc,wDa,Ntc,Kva,Ntc,vla,Ntc,Ima,Ntc,T_a,Ntc,RAa,Ntc,lxa,Ntc,Iva,Ntc,Kwa,Ntc,tba,Ntc,Q_a,Ntc,Fwa,Ntc,o9,Ntc,xpa,Ntc,Lma,Ntc,Vma,Ntc,z7a,Ntc,TAa,Ntc,tya,Ntc,eob,Ntc,_ua,Ntc,f$a,Ntc,GBa,Ntc,dAa,Ntc,elc,Ntc,txa,Ntc,zba,Ntc,aaa,Ntc,dob,Ntc,MAa,Ntc,Tta,Ntc,hza,Ntc,Enb,Ntc,$ra,Ntc,eja,Ntc,u_a,Ntc,yQb,Ntc,Gya,Ntc,$Sb,Ntc,mda,Ntc,wBa,Ntc,HAa,Ntc,Paa,Ntc,Eva,Ntc,r7,Ntc,bob,Ntc,W_a,Ntc,s7,Ntc,wCa,Ntc,pAa,Ntc,fnb,Ntc,x7,Ntc,S2,Ntc,Qma,Ntc,aBa,Ntc,Yza,Ntc,rDa,Ntc,uaa,Ntc,Tva,Ntc,Nva,Ntc,Hwa,Ntc,r8,Ntc,cob,Ntc,H8a,Ntc,vBa,Ntc,c2a,Ntc,Zta,Ntc,lpa,Ntc,eAa,Ntc,SPa,Ntc,saa,Ntc,ICa,Ntc,ppb,Ntc,R2,Ntc,S9a,Ntc,Z9,Ntc,gsa,Ntc,DHa,Ntc,Kxa,Ntc,Sla,Ntc,Mba,Ntc,Ewa,Ntc,v_a,Ntc,F9,Ntc,Nta,Ntc,Ixa,Ntc,Mwa,Ntc,C7,Ntc,Oaa,Ntc,wxa,Ntc,_Ca,Ntc,Bfa,Ntc,tta,Ntc,Qnb,Ntc,Bbc,Ntc,q9,Ntc,Fta,Ntc,taa,Ntc,w7,Ntc,Cxa,Ntc,_za,Ntc,Ula,Ntc,pob,Ntc,PAa,Ntc,L9,Ntc,J7,Ntc,V6,Ntc,twa,Ntc,Zwa,Ntc,Qta,Ntc,_9,Ntc,pma,Ntc,RPa,Ntc,dwa,Ntc,Hsb,Ntc,gwa,Ntc,wta,Ntc,eya,Ntc,Tya,Ntc,fDa,Ntc,dya,Ntc,$4,Ntc,mza,Ntc,I9,Ntc,wQb,Ntc,Tza,Ntc,Kaa,Ntc,cya,Ntc,Yua,Ntc,hBa,Ntc,VAa,Ntc,sta,Ntc,Tua,Ntc,Oya,Ntc,gua,Ntc,b7,Ntc,KNb,Ntc,p9,Ntc,aDa,Ntc,Uwa,Ntc,s8,Ntc,waa,Ntc,F7,Ntc,gva,Ntc,wAa,Ntc,wxb,Ntc,fpb,Ntc,c9,Ntc,e$a,Ntc,dBa,Ntc,Csb,Ntc,bCa,Ntc,Rla,Ntc,f1a,Ntc,Nqa,Ntc,mwa,Ntc,pO,Ntc,mBa,Ntc,_ta,Ntc,ipb,Ntc,Rza,Ntc,J9,Ntc,lva,Ntc,LGa,Ntc,xDa,Ntc,uDa,Ntc,zDb,Ntc,Gta,Ntc,RCa,Ntc,lwa,Ntc,HQb,Ntc,_na,Ntc,zya,Ntc,Isb,Ntc,cBa,Ntc,Hba,Ntc,nda,Ntc,Bza,Ntc,Snb,Ntc,wab,Ntc,k9,Ntc,hCa,Ntc,vaa,Ntc,Exa,Ntc,qxa,Ntc,x8,Ntc,mua,Ntc,pDb,Ntc,uAa,Ntc,jsa,Ntc,nza,Ntc,hsa,Ntc,Aaa,Ntc,gsb,Ntc,xnb,Ntc,Qya,Ntc,Rqb,Ntc,Wqa,Ntc,S6,Ntc,Vnb,Ntc,y7,Ntc,Sua,Ntc,Vva,Ntc,Lva,Ntc,aTb,Ntc,_Cb,Ntc,w8,Ntc,Lnb,Ntc,rnb,Ntc,$Ba,Ntc,LBa,Ntc,gya,Ntc,rua,Ntc,Hya,Ntc,Qra,Ntc,UCa,Ntc,goa,Ntc,EAa,Ntc,L_a,Ntc,j$a,Ntc,Rra,Ntc,qma,Ntc,TBa,Ntc,Ola,Ntc,dDa,Ntc,qaa,Ntc,Ora,Ntc,Epa,Ntc,onb,Ntc,_nb,Ntc,_N,Ntc,Qxa,Ntc,yBa,Ntc,Hab,Ntc,Pma,Ntc,Fxa,Ntc,ova,Ntc,DCa,Ntc,hsb,Ntc,Laa,Ntc,ssb,Ntc,O_a,Ntc,Mma,Ntc,wma,Ntc,mnb,Ntc,bxa,Ntc,Rva,Ntc,pBa,Ntc,$Cb,Ntc,y7a,Ntc,SCb,Ntc,kCa,Ntc,z_a,Ntc,Wua,Ntc,GGa,Ntc,sIa,Ntc,m9,Ntc,Dva,Ntc,_6,Ntc,Uta,Ntc,xza,Ntc,C7a,Ntc,aza,Ntc,tDb,Ntc,Mva,Ntc,fob,Ntc,Axa,Ntc,zBa,Ntc,eCa,Ntc,eza,Ntc,mya,Ntc,pua,Ntc,zpa,Ntc,ota,Ntc,Rua,Ntc,yAa,Ntc,Uva,Ntc,vva,Ntc,gza,Ntc,loa,Ntc,Ksb,Ntc,Bpa,Ntc,vAa,Ntc,wpa,Ntc,eta,Ntc,rAa,Ntc,U9a,Ntc,DBa,Ntc,CDa,Ntc,ABa,Ntc,xaa,Ntc,Lwa,Ntc,Zna,Ntc,UBa,Ntc,sua,Ntc,daa,Ntc,M9,Ntc,atb,Ntc,N_a,Ntc,$jb,Ntc,Fza,Ntc,Sta,Ntc,Zza,Ntc,Jwa,Ntc,sBa,Ntc,bya,Ntc,JCa,Ntc,WBa,Ntc,A7a,Ntc,asa,Ntc,xab,Ntc,VBa,Ntc,cDb,Ntc,fza,Ntc,qua,Ntc,J_a,Ntc,AHa,Ntc,Hxa,Ntc,Anb,Ntc,fja,Ntc,hDa,Ntc,VCb,Ntc,UCb,Ntc,Yma,Ntc,XCa,Ntc,xAa,Ntc,Awa,Ntc,ysb,Ntc,HBa,Ntc,$xa,Ntc,cwa,Ntc,csa,Ntc,uua,Ntc,D7a,Ntc,QCa,Ntc,Bsb,Ntc,lBa,Ntc,sza,Ntc,Jqa,Ntc,p7,Ntc,gDa,Ntc,w9,Ntc,oDb,Ntc,jaa,Ntc,Oua,Ntc,sub,Ntc,Dya,Ntc,v9,Ntc,sAa,Ntc,oCa,Ntc,wDb,Ntc,f9,Ntc,tCa,Ntc,Yya,Ntc,Uxa,Ntc,RCb,Ntc,Hua,Ntc,_ga,Ntc,jsb,Ntc,iCa,Ntc,DQb,Ntc,_jb,Ntc,Rxa,Ntc,nBa,Ntc,faa,Ntc,m7,Ntc,Kua,Ntc,_ra,Ntc,Pza,Ntc,jua,Ntc,gBa,Ntc,$va,Ntc,cDa,Ntc,iya,Ntc,Cua,Ntc,g$a,Ntc,Fkb,Ntc,akb,Ntc,Pnb,Ntc,AQb,Ntc,vwa,Ntc,ula,Ntc,JQb,Ntc,Rta,Ntc,y6,Ntc,WAa,Ntc,C_a,Ntc,Daa,Ntc,yua,Ntc,Mza,Ntc,wHa,Ntc,dqb,Ntc,ema,Ntc,qxb,Ntc,eDb,Ntc,VCa,Ntc,Aza,Ntc,foa,Ntc,laa,Ntc,Vqa,Ntc,cCa,Ntc,ksb,Ntc,Ila,Ntc,Gza,Ntc,W6,Ntc,fsa,Ntc,bpb,Ntc,Vta,Ntc,tua,Ntc,_va,Ntc,Yxa,Ntc,Naa,Ntc,lDb,Ntc,Yta,Ntc,psb,Ntc,esa,Ntc,e2a,Ntc,gaa,Ntc,qnb,Ntc,mxa,Ntc,xua,Ntc,tva,Ntc,Lya,Ntc,Q9,Ntc,Lua,Ntc,D_a,Ntc,Kya,Ntc,xCa,Ntc,Sqa,Ntc,f2a,Ntc,GDa,Ntc,eua,Ntc,sDb,Ntc,aob,Ntc,Rma,Ntc,Pxa,Ntc,oaa,Ntc,rsb,Ntc,rva,Ntc,dza,Ntc,Rya,Ntc,Qva,Ntc,SAa,Ntc,uva,Ntc,p8,Ntc,ypa,Ntc,gnb,Ntc,$N,Ntc,ixa,Ntc,vxa,Ntc,iza,Ntc,FAa,Ntc,tBa,Ntc,$ya,Ntc,WCb,Ntc,bma,Ntc,ACa,Ntc,rta,Ntc,L7a,Ntc,hya,Ntc,haa,Ntc,E_a,Ntc,O6,Ntc,Sva,Ntc,vza,Ntc,exa,Ntc,_ya,Ntc,Uma,Ntc,tga,Ntc,Knb,Ntc,Hla,Ntc,Hma,Ntc,DAa,Ntc,Jua,Ntc,FBa,Ntc,Zxa,Ntc,M_a,Ntc,qAa,Ntc,OBa,Ntc,Bua,Ntc,raa,Ntc,nAa,Ntc,mDb,Ntc,jpb,Ntc,Z_a,Ntc,cxa,Ntc,OCa,Ntc,kza,Ntc,B7a,Ntc,d7,Ntc,qya,Ntc,pva,Ntc,B_a,Ntc,eaa,Ntc,Mua,Ntc,vab,Ntc,Lba,Ntc,Xva,Ntc,_wa,Ntc,Fnb,Ntc,S9,Ntc,Fma,Ntc,xHa,Ntc,FQb,Ntc,ywa,Ntc,gCa,Ntc,tsb,Ntc,Cya,Ntc,Fya,Ntc,Jxa,Ntc,Kza,Ntc,Ama,Ntc,I_a,Ntc,Twa,Ntc,Tnb,Ntc,j9,Ntc,jnb,Ntc,kAa,Ntc,B0a,Ntc,xDb,Ntc,x9a,Ntc,Aya,Ntc,Uqa,Ntc,kqb,Ntc,Cqa,Ntc,z6,Ntc,nqb,Ntc,gqb,Ntc,Vya,Ntc,__a,Ntc,Hva,Ntc,Pta,Ntc,cma,Ntc,zDa,Ntc,poa,Ntc,pta,Ntc,V9,Ntc,BDa,Ntc,H7,Ntc,JGa,Ntc,vIa,Ntc,bwa,Ntc,Zjb,Ntc,nwa,Ntc,Ema,Ntc,q7,Ntc,PPb,Ntc,moa,Ntc,zwa,Ntc,TCa,Ntc,y9,Ntc,lnb,Ntc,Gnb,Ntc,kma,Ntc,cta,Ntc,kya,Ntc,P9,Ntc,tDa,Ntc,fDb,Ntc,gAa,Ntc,rDb,Ntc,t_a,Ntc,Unb,Ntc,e9,Ntc,sQb,Ntc,U_a,Ntc,paa,Ntc,wla,Ntc,A7,Ntc,BBa,Ntc,nCa,Ntc,eBa,Ntc,Dsb,Ntc,fBa,Ntc,uta,Ntc,DDa,Ntc,Oqa,Ntc,iBa,Ntc,CCa,Ntc,iva,Ntc,I7,Ntc,Saa,Ntc,EDa,Ntc,yya,Ntc,QCb,Ntc,Xxa,Ntc,Esb,Ntc,Apa,Ntc,kBa,Ntc,Hnb,Ntc,Sxa,Ntc,X9,Ntc,U9,Ntc,v8,Ntc,hoa,Ntc,rya,Ntc,vCa,Ntc,dD,Ntc,k7,Ntc,oza,Ntc,Faa,Ntc,dja,Ntc,Rnb,Ntc,iwa,Ntc,Cza,Ntc,Ynb,Ntc,Bxa,Ntc,Vxa,Ntc,nma,Ntc,isa,Ntc,fAa,Ntc,wva,Ntc,Mta,Ntc,jBa,Ntc,jxa,Ntc,Lsb,Ntc,Pqb,Ntc,kaa,Ntc,Nua,Ntc,Maa,Ntc,Xma,Ntc,ZCb,Ntc,YCb,Ntc,Sza,Ntc,M7,Ntc,Lza,Ntc,Bva,Ntc,Inb,Ntc,nxa,Ntc,i$a,Ntc,L0a,Ntc,N9,Ntc,j7,Ntc,Dwa,Ntc,t8,Ntc,pxa,Ntc,Ota,Ntc,Cva,Ntc,Dza,Ntc,SPb,Ntc,Wnb,Ntc,Y9,Ntc,XCb,Ntc,qza,Ntc,T2b,Ntc,Nwa,Ntc,y0a,Ntc,Uua,Ntc,B7,Ntc,xva,Ntc,mva,Ntc,Bta,Ntc,tla,Ntc,HKb,Ntc,D0a,Ntc,Iwa,Ntc,Phb,Ntc,Dkb,Ntc,y_a,Ntc,jza,Ntc,Qwa,Ntc,cza,Ntc,Lxa,Ntc,Bnb,Ntc,Xna,Ntc,FGa,Ntc,rIa,Ntc,Haa,Ntc,GAa,Ntc,Pra,Ntc,Wwa,Ntc,kpa,Ntc,kwb,Ntc,lwb,Ntc,mwb,Ntc,QAa,Ntc,dma,Ntc,T2,Ntc,Hta,Ntc,TCb,Ntc,F_a,Ntc,Pua,Ntc,Xnb,Ntc,oma,Ntc,Gsb,Ntc,Pva,Ntc,SBa,Ntc,P7,Ntc,aDb,Ntc,N7a,Ntc,YBa,Ntc,$wa,Ntc,Cla,Ntc,QBa,Ntc,EBa,Ntc,Tma,Ntc,CHa,Ntc,Oxa,Ntc,V_a,Ntc,Wta,Ntc,KBa,Ntc,M7a,Ntc,cva,Ntc,gDb,Ntc,d$a,Ntc,aAa,Ntc,Gpa,Ntc,vua,Ntc,u9,Ntc,unb,Ntc,Tla,Ntc,cTb,Ntc,Raa,Ntc,hnb,Ntc,ZBa,Ntc,uxb,Ntc,bBa,Ntc,u7,Ntc,uIa,Ntc,IGa,Ntc,Zra,Ntc,m0a,Ntc,K0a,Ntc,rwa,Ntc,ECa,Ntc,$ua,Ntc,FNb,Ntc,kwa,Ntc,w_a,Ntc,$Ca,Ntc,Zua,Ntc,OAa,Ntc,Kta,Ntc,IAa,Ntc,CBa,Ntc,lCa,Ntc,FHa,Ntc,WCa,Ntc,FCa,Ntc,Ekb,Ntc,Jnb,Ntc,Ita,Ntc,Bkb,Ntc,iob,Ntc,tAa,Ntc,R_a,Ntc,zsb,Ntc,a7,Ntc,i7,Ntc,Vwa,Ntc,Uya,Ntc,ENb,Ntc,zHa,Ntc,joa,Ntc,Lta,Ntc,Eta,Ntc,Dnb,Ntc,$9,Ntc,nDb,Ntc,Bya,Ntc,pza,Ntc,Qqb,Ntc,ZQa,Ntc,Baa,Ntc,lsb,Ntc,rxa,Ntc,wwa,Ntc,hDb,Ntc,X6,Ntc,Ohb,Ntc,EHa,Ntc,lAa,Ntc,x_a,Ntc,dsa,Ntc,hob,Ntc,ANb,Ntc,Jya,Ntc,ADb,Ntc,HCa,Ntc,fva,Ntc,yHb,Ntc,epb,Ntc,IKb,Ntc,oua,Ntc,x7a,Ntc,uwa,Ntc,A9,Ntc,bAa,Ntc,w9a,Ntc,Ata,Ntc,xta,Ntc,wnb,Ntc,jya,Ntc,wua,Ntc,MGa,Ntc,yIa,Ntc,S_a,Ntc,Fpa,Ntc,KAa,Ntc,pDa,Ntc,Eya,Ntc,oBa,Ntc,MBa,Ntc,qqb,Ntc,rqb,Ntc,yza,Ntc,YCa,Ntc,Nza,Ntc,Jta,Ntc,BNb,Ntc,K9,Ntc,UPb,Ntc,soa,Ntc,oya,Ntc,JAa,Ntc,qBa,Ntc,uxa,Ntc,Fva,Ntc,cAa,Ntc,Oma,Ntc,kob,Ntc,P_a,Ntc,o8,Ntc,Dxa,Ntc,PCa,Ntc,i9,Ntc,mpa,Ntc,Wya,Ntc,t9,Ntc,Kqa,Ntc,Mya,Ntc,Txa,Ntc,Y_a,Ntc,Sma,Ntc,Iua,Ntc,npa,Ntc,ZAa,Ntc,Xya,Ntc,Dbc,Ntc,Caa,Ntc,bta,Ntc,Jva,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc,Ntc];var ff=[Otc,Otc,W7b,Otc,Ghc,Otc,Fhc,Otc,D0b,Otc,Ihc,Otc,OYb,Otc,UYb,Otc];var gf=[Ptc,Ptc,mO,Ptc,G6b,Ptc,u7b,Ptc,frb,Ptc,j7b,Ptc,d7b,Ptc,f7b,Ptc,M6b,Ptc,A7b,Ptc,J6b,Ptc,h7b,Ptc,crb,Ptc,brb,Ptc,noc,Ptc,y7b,Ptc,arb,Ptc,w7b,Ptc,loc,Ptc,C6b,Ptc,b7b,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc,Ptc];var hf=[Qtc,Qtc,oYa,Qtc,v6,Qtc,WXa,Qtc,Lfa,Qtc,uXa,Qtc,q2a,Qtc,O4,Qtc,W0a,Qtc,b1,Qtc,KQb,Qtc,w0,Qtc,xQb,Qtc,KL,Qtc,QQb,Qtc,SEa,Qtc,J$a,Qtc,p2,Qtc,v2,Qtc,iab,Qtc,Efa,Qtc,$2a,Qtc,Xs,Qtc,$Wa,Qtc,WWa,Qtc,Y3a,Qtc,x1a,Qtc,qZa,Qtc,Ilb,Qtc,t3,Qtc,Pib,Qtc,POa,Qtc,E6,Qtc,Z0a,Qtc,w5,Qtc,Jfa,Qtc,o3,Qtc,kjb,Qtc,B6,Qtc,V3,Qtc,qVa,Qtc,Fca,Qtc,rUa,Qtc,chb,Qtc,LYa,Qtc,n6a,Qtc,L4,Qtc,CZa,Qtc,whb,Qtc,Vgb,Qtc,x4a,Qtc,mLa,Qtc,s6,Qtc,R3a,Qtc,Rlb,Qtc,oca,Qtc,Wjb,Qtc,M$a,Qtc,vQb,Qtc,eRb,Qtc,xib,Qtc,kPa,Qtc,rbb,Qtc,j3,Qtc,sca,Qtc,hda,Qtc,iP,Qtc,ada,Qtc,Dga,Qtc,D8a,Qtc,cXa,Qtc,AWa,Qtc,mRb,Qtc,cib,Qtc,egb,Qtc,oo,Qtc,pRb,Qtc,ofa,Qtc,J9a,Qtc,QQa,Qtc,jRb,Qtc,kRb,Qtc,dib,Qtc,iWa,Qtc,Nib,Qtc,Y5a,Qtc,NWa,Qtc,vkb,Qtc,sLa,Qtc,CLa,Qtc,M3a,Qtc,zib,Qtc,jfa,Qtc,oRb,Qtc,zQb,Qtc,h3,Qtc,aMa,Qtc,RLa,Qtc,Rca,Qtc,x5,Qtc,PH,Qtc,OQb,Qtc,$u,Qtc,nRb,Qtc,o2a,Qtc,oRa,Qtc,f3a,Qtc,CWb,Qtc,Cq,Qtc,uib,Qtc,Eq,Qtc,$Va,Qtc,jXa,Qtc,Y1a,Qtc,XQa,Qtc,t5,Qtc,OYa,Qtc,vjb,Qtc,E3a,Qtc,tOa,Qtc,qib,Qtc,y4,Qtc,s2,Qtc,p6a,Qtc,m4a,Qtc,T4,Qtc,wib,Qtc,o0,Qtc,yNa,Qtc,u6a,Qtc,m3,Qtc,lga,Qtc,W3a,Qtc,XOa,Qtc,Tp,Qtc,H6a,Qtc,X0,Qtc,WUa,Qtc,Mca,Qtc,BVa,Qtc,l0,Qtc,aRa,Qtc,QZa,Qtc,Glb,Qtc,VQa,Qtc,$Pa,Qtc,iRb,Qtc,hRb,Qtc,YNb,Qtc,v5,Qtc,Fib,Qtc,d4a,Qtc,yca,Qtc,HLa,Qtc,RQb,Qtc,Wca,Qtc,yWa,Qtc,i0,Qtc,XPa,Qtc,FSa,Qtc,phb,Qtc,Q8a,Qtc,mjb,Qtc,m3a,Qtc,zZa,Qtc,tYa,Qtc,z6a,Qtc,Bba,Qtc,PZ,Qtc,O2,Qtc,Wfb,Qtc,wZa,Qtc,E6a,Qtc,C6,Qtc,G2a,Qtc,O3a,Qtc,DSa,Qtc,Vfa,Qtc,Wba,Qtc,ZWa,Qtc,HQa,Qtc,i3a,Qtc,fQa,Qtc,Em,Qtc,W2,Qtc,Xga,Qtc,Sib,Qtc,jhb,Qtc,TWa,Qtc,eea,Qtc,alb,Qtc,_Ua,Qtc,Hib,Qtc,Sfa,Qtc,JP,Qtc,$Sa,Qtc,cWa,Qtc,RNa,Qtc,YVa,Qtc,lRb,Qtc,c6a,Qtc,YXa,Qtc,yea,Qtc,Whb,Qtc,Mlb,Qtc,Zca,Qtc,JZa,Qtc,$3a,Qtc,d0a,Qtc,h2,Qtc,pXa,Qtc,Ylb,Qtc,COa,Qtc,no,Qtc,CQa,Qtc,eFa,Qtc,s5,Qtc,Qp,Qtc,xba,Qtc,Aq,Qtc,TKa,Qtc,G3,Qtc,p5,Qtc,Oca,Qtc,ajb,Qtc,s1,Qtc,d3a,Qtc,AYa,Qtc,FYa,Qtc,djb,Qtc,r3,Qtc,HSa,Qtc,f1,Qtc,CQb,Qtc,o4,Qtc,zjb,Qtc,J0a,Qtc,C1,Qtc,g0a,Qtc,n2,Qtc,Mda,Qtc,Dq,Qtc,b0a,Qtc,fjb,Qtc,dPa,Qtc,G6,Qtc,_Jb,Qtc,w6a,Qtc,ZW,Qtc,AG,Qtc,skb,Qtc,k6a,Qtc,AOa,Qtc,fWa,Qtc,EQb,Qtc,KXb,Qtc,d5,Qtc,mYa,Qtc,k4,Qtc,nQa,Qtc,ZNb,Qtc,IP,Qtc,hP,Qtc,GQb,Qtc,f9a,Qtc,SOa,Qtc,F$a,Qtc,a7a,Qtc,l6,Qtc,h6a,Qtc,D1a,Qtc,n2a,Qtc,VVa,Qtc,Qfa,Qtc,s4,Qtc,WJa,Qtc,U2a,Qtc,b3a,Qtc,_1a,Qtc,sp,Qtc,y5,Qtc,f4,Qtc,vWa,Qtc,jP,Qtc,D3,Qtc,Q1a,Qtc,vNa,Qtc,tQb,Qtc,PQb,Qtc,kOa,Qtc,xSa,Qtc,efa,Qtc,h4,Qtc,UWa,Qtc,JL,Qtc,r0,Qtc,jZa,Qtc,LRb,Qtc,v4a,Qtc,LL,Qtc,po,Qtc,K9a,Qtc,Ica,Qtc,NXa,Qtc,rga,Qtc,yXa,Qtc,mZa,Qtc,B6a,Qtc,jib,Qtc,fRb,Qtc,RWa,Qtc,Tda,Qtc,r5,Qtc,bLa,Qtc,J6,Qtc,p3,Qtc,hab,Qtc,k2,Qtc,sXa,Qtc,R0a,Qtc,pjb,Qtc,eRa,Qtc,Vib,Qtc,u5,Qtc,wOa,Qtc,LWa,Qtc,k4a,Qtc,PXa,Qtc,i5a,Qtc,Plb,Qtc,IL,Qtc,Xfa,Qtc,cV,Qtc,VMa,Qtc,cic,Qtc,u6,Qtc,fib,Qtc,dca,Qtc,OC,Qtc,sib,Qtc,gRb,Qtc,SVa,Qtc,$ba,Qtc,t2a,Qtc,r6a,Qtc,wga,Qtc,J8a,Qtc,eda,Qtc,n1,Qtc,IQb,Qtc,O0a,Qtc,XLa,Qtc,wr,Qtc,CYa,Qtc,kLa,Qtc,Vlb,Qtc,Kib,Qtc,$$,Qtc,X1a,Qtc,kca,Qtc,KVa,Qtc,D2,Qtc,nXa,Qtc,Bq,Qtc,fga,Qtc,b_a,Qtc,mn,Qtc,MQa,Qtc,KOa,Qtc,Yhb,Qtc,hga,Qtc,_hb,Qtc,zq,Qtc,s4a,Qtc,Z0,Qtc,UPa,Qtc,rfa,Qtc,HYa,Qtc,k1,Qtc,$0,Qtc,NPa,Qtc,Z3,Qtc,gE,Qtc,dUa,Qtc,Bgb,Qtc,dYa,Qtc,T1a,Qtc,D5,Qtc,j0a,Qtc,L8a,Qtc,A2a,Qtc,bTa,Qtc,HXa,Qtc,wha,Qtc,k9a,Qtc,w6,Qtc,$da,Qtc,glb,Qtc,O8a,Qtc,qo,Qtc,Yea,Qtc,f5a,Qtc,su,Qtc,hPa,Qtc,_fb,Qtc,YO,Qtc,vSa,Qtc,I4,Qtc,X8a,Qtc,xYa,Qtc,sZa,Qtc,wca,Qtc,tSa,Qtc,ghb,Qtc,zga,Qtc,cQa,Qtc,H$a,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc,Qtc];var jf=[Rtc,Rtc,Ztb,Rtc];var kf=[Stc,Stc,Dba,Stc];var lf=[Ttc,Ttc,Dy,Ttc,Ey,Ttc,Fy,Ttc,Cy,Ttc,Ttc,Ttc,Ttc,Ttc,Ttc,Ttc];var mf=[Utc,Utc,$gc,Utc,p6,Utc,hNa,Utc,yw,Utc,Kgc,Utc,cfb,Utc,sNa,Utc,rKa,Utc,rzb,Utc,Cfb,Utc,f1b,Utc,ofc,Utc,qsa,Utc,CKa,Utc,Mvb,Utc,lka,Utc,Egc,Utc,Rfb,Utc,Y7,Utc,fhc,Utc,bNa,Utc,F4,Utc,zoa,Utc,Cz,Utc,tpa,Utc,Igc,Utc,Ska,Utc,Tpa,Utc,Coa,Utc,mka,Utc,yzb,Utc,Dt,Utc,KPb,Utc,U7,Utc,fKa,Utc,rsa,Utc,hTa,Utc,bTb,Utc,Wgc,Utc,rpa,Utc,ara,Utc,$7,Utc,m8a,Utc,fta,Utc,R7,Utc,Bz,Utc,doa,Utc,xfa,Utc,hXa,Utc,fTb,Utc,nfc,Utc,pfb,Utc,hhc,Utc,Zma,Utc,opa,Utc,_7,Utc,_ja,Utc,dhc,Utc,EKa,Utc,dfb,Utc,Jpa,Utc,Lkb,Utc,Az,Utc,Ovb,Utc,pEb,Utc,uba,Utc,mfb,Utc,xKa,Utc,Tfb,Utc,bna,Utc,wka,Utc,xzb,Utc,qhc,Utc,eTa,Utc,T7a,Utc,C8,Utc,qEb,Utc,Aw,Utc,_mb,Utc,Fgc,Utc,wub,Utc,oNa,Utc,f8a,Utc,e6,Utc,$ja,Utc,yhc,Utc,d6,Utc,dNa,Utc,aNa,Utc,Pfb,Utc,f8,Utc,fTa,Utc,fNa,Utc,Cfa,Utc,ifb,Utc,U7a,Utc,MKa,Utc,DKa,Utc,osa,Utc,pla,Utc,jKa,Utc,q8a,Utc,jta,Utc,bKa,Utc,nEb,Utc,ufb,Utc,g8a,Utc,chc,Utc,ehc,Utc,khc,Utc,ksa,Utc,Lpa,Utc,ffb,Utc,Ugc,Utc,iKa,Utc,AKa,Utc,FKa,Utc,Pgc,Utc,ghc,Utc,zz,Utc,Kkb,Utc,Yqa,Utc,vKa,Utc,mOb,Utc,eNa,Utc,lOb,Utc,hKa,Utc,rja,Utc,jNa,Utc,IIb,Utc,boa,Utc,Rvb,Utc,P7a,Utc,Opa,Utc,LKa,Utc,thc,Utc,gra,Utc,tzb,Utc,Qja,Utc,Zja,Utc,X7,Utc,Nvb,Utc,Lvb,Utc,Ieb,Utc,Iqb,Utc,psa,Utc,Jfb,Utc,o6,Utc,Bhc,Utc,Ura,Utc,tub,Utc,Z7a,Utc,tNa,Utc,yfb,Utc,Ngc,Utc,Ggc,Utc,Zeb,Utc,Eqa,Utc,pOb,Utc,dra,Utc,uPa,Utc,Kpa,Utc,Kfb,Utc,_qa,Utc,NZb,Utc,rNa,Utc,spa,Utc,sJa,Utc,MJa,Utc,T7,Utc,uoa,Utc,Ffb,Utc,Reb,Utc,gKa,Utc,Toc,Utc,lsa,Utc,Azb,Utc,Bzb,Utc,Beb,Utc,b6,Utc,_7a,Utc,fna,Utc,S_b,Utc,qKa,Utc,Qgc,Utc,lhc,Utc,Feb,Utc,Ct,Utc,ena,Utc,$eb,Utc,fla,Utc,Ph,Utc,Lgc,Utc,rHb,Utc,Xra,Utc,lKa,Utc,Bfb,Utc,npb,Utc,lpb,Utc,jhc,Utc,Meb,Utc,wzb,Utc,EJa,Utc,Tjb,Utc,Tka,Utc,Nfb,Utc,tKa,Utc,kZb,Utc,kta,Utc,a6,Utc,ohc,Utc,$Ja,Utc,tfb,Utc,Rka,Utc,c8,Utc,Vra,Utc,fra,Utc,xfb,Utc,yoa,Utc,sKa,Utc,$qa,Utc,Y7a,Utc,ina,Utc,$mb,Utc,HKa,Utc,EWb,Utc,ofb,Utc,fPa,Utc,gta,Utc,efb,Utc,Qfb,Utc,$7a,Utc,Rgc,Utc,bhc,Utc,Mgc,Utc,ppa,Utc,h8a,Utc,b8a,Utc,Dqa,Utc,xw,Utc,afb,Utc,Lka,Utc,qOb,Utc,opb,Utc,mpb,Utc,Xmb,Utc,kOb,Utc,Gfb,Utc,usa,Utc,lQb,Utc,Vob,Utc,tja,Utc,tJa,Utc,Qpa,Utc,Teb,Utc,Qeb,Utc,_Ja,Utc,iNa,Utc,JKa,Utc,mNa,Utc,bnb,Utc,O7a,Utc,KKa,Utc,Ppa,Utc,E4,Utc,Sgc,Utc,W7a,Utc,CJa,Utc,Ipa,Utc,d8,Utc,Roc,Utc,whc,Utc,uKa,Utc,szb,Utc,Yja,Utc,lNa,Utc,Z7,Utc,zzb,Utc,Afb,Utc,Ymb,Utc,c6,Utc,sja,Utc,Mpa,Utc,b8,Utc,shc,Utc,JSb,Utc,qfb,Utc,ELb,Utc,ihc,Utc,j8a,Utc,phc,Utc,V7a,Utc,NKa,Utc,nka,Utc,voa,Utc,Ogc,Utc,Uka,Utc,gTa,Utc,tsa,Utc,uJa,Utc,OJa,Utc,Ahc,Utc,Ff,Utc,Sjb,Utc,d8a,Utc,Nkb,Utc,Ctb,Utc,Zqa,Utc,Veb,Utc,rEb,Utc,Ftb,Utc,hna,Utc,Cja,Utc,Aoa,Utc,zw,Utc,$Ma,Utc,ztb,Utc,cNa,Utc,Zmb,Utc,a8,Utc,wKa,Utc,ana,Utc,vub,Utc,msa,Utc,dna,Utc,ZJa,Utc,Jeb,Utc,Btb,Utc,jOb,Utc,Voc,Utc,hta,Utc,zfb,Utc,bra,Utc,vka,Utc,yKa,Utc,tr,Utc,Vka,Utc,era,Utc,vhc,Utc,f6,Utc,_Ma,Utc,Xeb,Utc,wfb,Utc,dKa,Utc,Npa,Utc,tka,Utc,nKa,Utc,GKa,Utc,Gqa,Utc,Spa,Utc,JPb,Utc,oEb,Utc,qpa,Utc,Peb,Utc,FJa,Utc,DJa,Utc,c8a,Utc,BKa,Utc,kKa,Utc,Hqa,Utc,ww,Utc,Hgc,Utc,p8a,Utc,Efb,Utc,rhc,Utc,Zob,Utc,rfb,Utc,Urc,Utc,Sra,Utc,nla,Utc,toa,Utc,Mfb,Utc,gna,Utc,u8,Utc,Xgc,Utc,NJa,Utc,Aja,Utc,gfb,Utc,dTa,Utc,Etb,Utc,o8a,Utc,Tgc,Utc,_ma,Utc,Cub,Utc,qNa,Utc,Gtb,Utc,Yeb,Utc,qla,Utc,Ofb,Utc,cra,Utc,Jgc,Utc,cKa,Utc,FXa,Utc,Leb,Utc,nsa,Utc,$ma,Utc,Xqa,Utc,hfb,Utc,nfb,Utc,uzb,Utc,g8,Utc,aKa,Utc,q6,Utc,V7,Utc,mhc,Utc,jTa,Utc,r8a,Utc,Pja,Utc,iOb,Utc,S7a,Utc,T_b,Utc,X7a,Utc,Eoa,Utc,Rpa,Utc,W7,Utc,Kka,Utc,cnb,Utc,vzb,Utc,qzb,Utc,Q7a,Utc,xoa,Utc,eoa,Utc,pKa,Utc,bfb,Utc,eKa,Utc,ola,Utc,e8,Utc,Eeb,Utc,e8a,Utc,iTa,Utc,pNa,Utc,gNa,Utc,vsa,Utc,mKa,Utc,Boa,Utc,Dja,Utc,jfb,Utc,vfb,Utc,Rja,Utc,yz,Utc,k8a,Utc,Oeb,Utc,Wra,Utc,Ygc,Utc,aoa,Utc,lfb,Utc,Dg,Utc,ahc,Utc,sfb,Utc,woa,Utc,l8a,Utc,D8,Utc,_eb,Utc,gla,Utc,Ufb,Utc,xHb,Utc,hla,Utc,xhc,Utc,zja,Utc,Neb,Utc,zhc,Utc,kfb,Utc,Deb,Utc,a8a,Utc,VXa,Utc,oKa,Utc,Jka,Utc,Dfb,Utc,Atb,Utc,Heb,Utc,Pvb,Utc,zVa,Utc,uhc,Utc,kNa,Utc,nNa,Utc,n8a,Utc,Keb,Utc,S7,Utc,Dtb,Utc,uka,Utc,Ceb,Utc,Wmb,Utc,erb,Utc,cna,Utc,Qvb,Utc,xka,Utc,anb,Utc,Hfb,Utc,IKa,Utc,$na,Utc,Xja,Utc,Geb,Utc,_gc,Utc,Doa,Utc,zKa,Utc,Web,Utc,Fqa,Utc,Lfb,Utc,Bja,Utc,nhc,Utc,i8a,Utc,Iqa,Utc,Seb,Utc,Tra,Utc,Sfb,Utc,rla,Utc,ita,Utc,Ifb,Utc,Ueb,Utc,R7a,Utc,Svb,Utc,Zgc,Utc,Vgc,Utc,coa,Utc,ssa,Utc,PJa,Utc,vJa,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc,Utc];return{_testSetjmp:urc,_saveSetjmp:trc,_free:Qqc,_memset:mrc,_realloc:Sqc,_memmove:orc,_tolower:vrc,_strlen:lrc,_llvm_cttz_i32:src,_malloc:Pqc,_memcpy:nrc,_llvm_ctlz_i32:rrc,_llvm_uadd_with_overflow_i64:qrc,_strcpy:prc,_calloc:Rqc,_main:Nh,runPostSets:Df,stackAlloc:nf,stackSave:of,stackRestore:pf,setThrew:qf,setTempRet0:tf,setTempRet1:uf,setTempRet2:vf,setTempRet3:wf,setTempRet4:xf,setTempRet5:yf,setTempRet6:zf,setTempRet7:Af,setTempRet8:Bf,setTempRet9:Cf,dynCall_iiiiiiii:Vrc,dynCall_viiiiiifi:Wrc,dynCall_vid:Xrc,dynCall_viiiii:Yrc,dynCall_vi:Zrc,dynCall_vii:_rc,dynCall_iiiiiii:$rc,dynCall_viiiif:asc,dynCall_viiiffiii:bsc,dynCall_ii:csc,dynCall_viiiiiiiiiii:dsc,dynCall_viifi:esc,dynCall_viidi:fsc,dynCall_viiiiiiiiiif:gsc,dynCall_fiii:hsc,dynCall_iiiiiiiiiiii:isc,dynCall_i:jsc,dynCall_fiiiiiiiffi:ksc,dynCall_iiii:lsc,dynCall_iffiiiii:msc,dynCall_viiiiiiii:nsc,dynCall_viiiiiiif:osc,dynCall_fii:psc,dynCall_iiid:qsc,dynCall_iiiiiiiiii:rsc,dynCall_iiiiiiiiiiiiiiii:ssc,dynCall_viiiffi:tsc,dynCall_iiiiiiiiiii:usc,dynCall_dd:vsc,dynCall_viiiiiiiiiiiiii:wsc,dynCall_iiiiiiiiiiiii:xsc,dynCall_viiiiifi:ysc,dynCall_viiiiiii:zsc,dynCall_viiiiiiiii:Asc,dynCall_viiiiiif:Bsc,dynCall_viiiiiiiiii:Csc,dynCall_iii:Dsc,dynCall_iiiiii:Esc,dynCall_diii:Fsc,dynCall_didd:Gsc,dynCall_viiiiii:Hsc,dynCall_iiiiiiidiiidi:Isc,dynCall_viiiiiiiiiiii:Jsc,dynCall_viiif:Ksc,dynCall_did:Lsc,dynCall_viiiifii:Msc,dynCall_viii:Nsc,dynCall_v:Osc,dynCall_iiiiiiiii:Psc,dynCall_iiiii:Qsc,dynCall_viif:Rsc,dynCall_viiffi:Ssc,dynCall_viiiiiiiddddd:Tsc,dynCall_viiii:Usc}})


// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_viiiiiifi": invoke_viiiiiifi, "invoke_vid": invoke_vid, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_viiiif": invoke_viiiif, "invoke_viiiffiii": invoke_viiiffiii, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viifi": invoke_viifi, "invoke_viidi": invoke_viidi, "invoke_viiiiiiiiiif": invoke_viiiiiiiiiif, "invoke_fiii": invoke_fiii, "invoke_iiiiiiiiiiii": invoke_iiiiiiiiiiii, "invoke_i": invoke_i, "invoke_fiiiiiiiffi": invoke_fiiiiiiiffi, "invoke_iiii": invoke_iiii, "invoke_iffiiiii": invoke_iffiiiii, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_viiiiiiif": invoke_viiiiiiif, "invoke_fii": invoke_fii, "invoke_iiid": invoke_iiid, "invoke_iiiiiiiiii": invoke_iiiiiiiiii, "invoke_iiiiiiiiiiiiiiii": invoke_iiiiiiiiiiiiiiii, "invoke_viiiffi": invoke_viiiffi, "invoke_iiiiiiiiiii": invoke_iiiiiiiiiii, "invoke_dd": invoke_dd, "invoke_viiiiiiiiiiiiii": invoke_viiiiiiiiiiiiii, "invoke_iiiiiiiiiiiii": invoke_iiiiiiiiiiiii, "invoke_viiiiifi": invoke_viiiiifi, "invoke_viiiiiii": invoke_viiiiiii, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_viiiiiif": invoke_viiiiiif, "invoke_viiiiiiiiii": invoke_viiiiiiiiii, "invoke_iii": invoke_iii, "invoke_iiiiii": invoke_iiiiii, "invoke_diii": invoke_diii, "invoke_didd": invoke_didd, "invoke_viiiiii": invoke_viiiiii, "invoke_iiiiiiidiiidi": invoke_iiiiiiidiiidi, "invoke_viiiiiiiiiiii": invoke_viiiiiiiiiiii, "invoke_viiif": invoke_viiif, "invoke_did": invoke_did, "invoke_viiiifii": invoke_viiiifii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiiiiiii": invoke_iiiiiiiii, "invoke_iiiii": invoke_iiiii, "invoke_viif": invoke_viif, "invoke_viiffi": invoke_viiffi, "invoke_viiiiiiiddddd": invoke_viiiiiiiddddd, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_sysconf": _sysconf, "__scanString": __scanString, "_llvm_prefetch": _llvm_prefetch, "_fclose": _fclose, "_mkdir": _mkdir, "_strtoul": _strtoul, "_fflush": _fflush, "_strtol": _strtol, "_fputc": _fputc, "_strtok": _strtok, "_fwrite": _fwrite, "_send": _send, "_llvm_pow_f32": _llvm_pow_f32, "_fputs": _fputs, "_cbrt": _cbrt, "_isspace": _isspace, "_localtime": _localtime, "_read": _read, "_ceil": _ceil, "_strstr": _strstr, "_dlclose": _dlclose, "_fileno": _fileno, "_perror": _perror, "_sbrk": _sbrk, "_fsync": _fsync, "_munmap": _munmap, "_signal": _signal, "_tanh": _tanh, "_fmod": _fmod, "_round": _round, "_memchr": _memchr, "_llvm_va_end": _llvm_va_end, "_cosf": _cosf, "_snprintf": _snprintf, "_fgetc": _fgetc, "_stat": _stat, "_cosh": _cosh, "__getFloat": __getFloat, "_mknod": _mknod, "_hypot": _hypot, "_fgets": _fgets, "_close": _close, "_strchr": _strchr, "_tcgetattr": _tcgetattr, "_clock": _clock, "___setErrNo": ___setErrNo, "_access": _access, "_ftell": _ftell, "_abs": _abs, "_exit": _exit, "_sprintf": _sprintf, "_strrchr": _strrchr, "_atan2f": _atan2f, "_setrlimit": _setrlimit, "_fcntl": _fcntl, "_log2": _log2, "_strcspn": _strcspn, "__isLeapYear": __isLeapYear, "_copysign": _copysign, "_ferror": _ferror, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_gmtime": _gmtime, "_localtime_r": _localtime_r, "_sinh": _sinh, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_recv": _recv, "__parseInt64": __parseInt64, "_trunc": _trunc, "_cos": _cos, "_putchar": _putchar, "_mkport": _mkport, "_bsearch": _bsearch, "_mmap": _mmap, "__exit": __exit, "_nanosleep": _nanosleep, "_strftime": _strftime, "_rename": _rename, "_tzset": _tzset, "_fabsf": _fabsf, "_floorf": _floorf, "_llvm_va_copy": _llvm_va_copy, "_rint": _rint, "_dlopen": _dlopen, "_sinf": _sinf, "_printf": _printf, "_pread": _pread, "_fopen": _fopen, "_open": _open, "_sqrtf": _sqrtf, "_select": _select, "_getchar": _getchar, "_usleep": _usleep, "_frexp": _frexp, "__arraySum": __arraySum, "_log": _log, "_puts": _puts, "_mktime": _mktime, "_fdopen": _fdopen, "_exp2": _exp2, "_scanf": _scanf, "_qsort": _qsort, "_rmdir": _rmdir, "_strdup": _strdup, "_log10": _log10, "_isatty": _isatty, "__formatString": __formatString, "_getenv": _getenv, "_gettimeofday": _gettimeofday, "_atoi": _atoi, "_vfprintf": _vfprintf, "_llvm_pow_f64": _llvm_pow_f64, "_madvise": _madvise, "_fscanf": _fscanf, "___errno_location": ___errno_location, "_strerror": _strerror, "_getrusage": _getrusage, "_fstat": _fstat, "_llvm_lifetime_start": _llvm_lifetime_start, "_strspn": _strspn, "__parseInt": __parseInt, "_ungetc": _ungetc, "_exp": _exp, "_expf": _expf, "_gmtime_r": _gmtime_r, "_vsnprintf": _vsnprintf, "_sscanf": _sscanf, "___assert_fail": ___assert_fail, "_dlsym": _dlsym, "_fread": _fread, "_strtok_r": _strtok_r, "_globfree": _globfree, "_abort": _abort, "_fprintf": _fprintf, "_strtoll": _strtoll, "_tan": _tan, "___buildEnvironment": ___buildEnvironment, "__reallyNegative": __reallyNegative, "__addDays": __addDays, "_atanf": _atanf, "_fabs": _fabs, "_floor": _floor, "_fseek": _fseek, "_sqrt": _sqrt, "_write": _write, "_rewind": _rewind, "_sin": _sin, "_ceilf": _ceilf, "_longjmp": _longjmp, "_tcsetattr": _tcsetattr, "_atan": _atan, "_asin": _asin, "_glob": _glob, "_strpbrk": _strpbrk, "_unlink": _unlink, "_acos": _acos, "_pwrite": _pwrite, "_strerror_r": _strerror_r, "_atan2": _atan2, "_llrint": _llrint, "_llvm_bswap_i16": _llvm_bswap_i16, "_time": _time, "_llvm_bswap_i32": _llvm_bswap_i32, "_setvbuf": _setvbuf, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_vp8_mode_contexts": _vp8_mode_contexts, "_stdout": _stdout, "_stderr": _stderr }, buffer);
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _free = Module["_free"] = asm["_free"];
var _memset = Module["_memset"] = asm["_memset"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _llvm_cttz_i32 = Module["_llvm_cttz_i32"] = asm["_llvm_cttz_i32"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _llvm_ctlz_i32 = Module["_llvm_ctlz_i32"] = asm["_llvm_ctlz_i32"];
var _llvm_uadd_with_overflow_i64 = Module["_llvm_uadd_with_overflow_i64"] = asm["_llvm_uadd_with_overflow_i64"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var _calloc = Module["_calloc"] = asm["_calloc"];
var _main = Module["_main"] = asm["_main"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_viiiiiifi = Module["dynCall_viiiiiifi"] = asm["dynCall_viiiiiifi"];
var dynCall_vid = Module["dynCall_vid"] = asm["dynCall_vid"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_viiiif = Module["dynCall_viiiif"] = asm["dynCall_viiiif"];
var dynCall_viiiffiii = Module["dynCall_viiiffiii"] = asm["dynCall_viiiffiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viifi = Module["dynCall_viifi"] = asm["dynCall_viifi"];
var dynCall_viidi = Module["dynCall_viidi"] = asm["dynCall_viidi"];
var dynCall_viiiiiiiiiif = Module["dynCall_viiiiiiiiiif"] = asm["dynCall_viiiiiiiiiif"];
var dynCall_fiii = Module["dynCall_fiii"] = asm["dynCall_fiii"];
var dynCall_iiiiiiiiiiii = Module["dynCall_iiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiii"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_fiiiiiiiffi = Module["dynCall_fiiiiiiiffi"] = asm["dynCall_fiiiiiiiffi"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_iffiiiii = Module["dynCall_iffiiiii"] = asm["dynCall_iffiiiii"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_viiiiiiif = Module["dynCall_viiiiiiif"] = asm["dynCall_viiiiiiif"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_iiid = Module["dynCall_iiid"] = asm["dynCall_iiid"];
var dynCall_iiiiiiiiii = Module["dynCall_iiiiiiiiii"] = asm["dynCall_iiiiiiiiii"];
var dynCall_iiiiiiiiiiiiiiii = Module["dynCall_iiiiiiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiiiiiii"];
var dynCall_viiiffi = Module["dynCall_viiiffi"] = asm["dynCall_viiiffi"];
var dynCall_iiiiiiiiiii = Module["dynCall_iiiiiiiiiii"] = asm["dynCall_iiiiiiiiiii"];
var dynCall_dd = Module["dynCall_dd"] = asm["dynCall_dd"];
var dynCall_viiiiiiiiiiiiii = Module["dynCall_viiiiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiiiii"];
var dynCall_iiiiiiiiiiiii = Module["dynCall_iiiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiiii"];
var dynCall_viiiiifi = Module["dynCall_viiiiifi"] = asm["dynCall_viiiiifi"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_viiiiiif = Module["dynCall_viiiiiif"] = asm["dynCall_viiiiiif"];
var dynCall_viiiiiiiiii = Module["dynCall_viiiiiiiiii"] = asm["dynCall_viiiiiiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_diii = Module["dynCall_diii"] = asm["dynCall_diii"];
var dynCall_didd = Module["dynCall_didd"] = asm["dynCall_didd"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_iiiiiiidiiidi = Module["dynCall_iiiiiiidiiidi"] = asm["dynCall_iiiiiiidiiidi"];
var dynCall_viiiiiiiiiiii = Module["dynCall_viiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiii"];
var dynCall_viiif = Module["dynCall_viiif"] = asm["dynCall_viiif"];
var dynCall_did = Module["dynCall_did"] = asm["dynCall_did"];
var dynCall_viiiifii = Module["dynCall_viiiifii"] = asm["dynCall_viiiifii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiiiiiii = Module["dynCall_iiiiiiiii"] = asm["dynCall_iiiiiiiii"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viif = Module["dynCall_viif"] = asm["dynCall_viif"];
var dynCall_viiffi = Module["dynCall_viiffi"] = asm["dynCall_viiffi"];
var dynCall_viiiiiiiddddd = Module["dynCall_viiiiiiiddddd"] = asm["dynCall_viiiiiiiddddd"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];

Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };

// TODO: strip out parts of this we do not need

//======= begin closure i64 code =======

// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */

var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };


  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.

    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };


  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.


  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};


  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }

    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };


  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };


  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };


  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }

    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }

    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));

    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };


  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.


  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;


  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);


  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);


  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);


  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);


  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);


  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);


  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };


  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };


  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (this.isZero()) {
      return '0';
    }

    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }

    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));

    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);

      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };


  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };


  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };


  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };


  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };


  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };


  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };


  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };


  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }

    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }

    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };


  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };


  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };


  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }

    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }

    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }

    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));

      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);

      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }

      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }

      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };


  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };


  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };


  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };


  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };


  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };


  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };

  //======= begin jsbn =======

  var navigator = { appName: 'Modern Browser' }; // polyfill a little

  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/

  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */

  // Basic JavaScript BN library - subset useful for RSA encryption.

  // Bits per digit
  var dbits;

  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);

  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }

  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }

  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.

  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }

  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);

  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;

  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }

  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }

  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }

  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }

  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }

  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }

  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }

  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }

  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }

  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }

  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }

  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }

  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }

  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }

  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }

  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }

  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }

  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }

  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;

  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }

  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }

  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }

  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }

  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }

  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;

  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }

  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }

  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;

  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;

  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);

  // jsbn2 stuff

  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }

  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }

  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }

  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }

  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }

  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }

  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;

  //======= end jsbn =======

  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();

//======= end closure i64 code =======



// === Auto-generated postamble setup entry stuff ===

if (memoryInitializer) {
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    var data = Module['readBinary'](memoryInitializer);
    HEAPU8.set(data, STATIC_BASE);
  } else {
    addRunDependency('memory initializer');
    Browser.asyncLoad(memoryInitializer, function(data) {
      HEAPU8.set(data, STATIC_BASE);
      removeRunDependency('memory initializer');
    }, function(data) {
      throw 'could not load memory initializer ' + memoryInitializer;
    });
  }
}

function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun'] && shouldRunNow) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);

  initialStackTop = STACKTOP;

  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    ensureInitRuntime();

    preMain();

    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;

  // exit the runtime
  exitRuntime();

  // TODO We should handle this differently based on environment.
  // In the browser, the best we can do is throw an exception
  // to halt execution, but in node we could process.exit and
  // I'd imagine SM shell would have something equivalent.
  // This would let us set a proper exit status (which
  // would be great for checking test exit statuses).
  // https://github.com/kripken/emscripten/issues/1371

  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }

  ABORT = true;
  EXITSTATUS = 1;

  throw 'abort() at ' + stackTrace();
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}






// {{MODULE_ADDITIONS}}






  return Module['return'];
}

if (typeof(exports) !== 'undefined') {
  ffmpeg_run.call(this);
}

